#!/bin/sh
#
# Copyright (c) 1999-2004 SWsoft Inc.
# All rights reserved
#

#
# Plesk script
#


set_apache_params()
{
	apache_user="apache"
	apache_UID=80
	apache_group="apache"
	apache_GID=80
	apache_service_name="httpd"
	apache_new="1.3"

	apache_modules_d="/usr/local/psa/apache/libexec/"
	user_apxs="/usr/local/psa/apache/bin/apxs"

	apache_httpd_conf="$HTTPD_CONF_D/httpd.conf"
	apache_httpd_conf2="$HTTPD_CONF_D/httpd2.conf"
	apache_httpd_conf_in="$PRODUCT_ROOT_D/etc/httpd.conf.in"

	apache_httpd_include="$HTTPD_CONF_D/httpd.include"

	APACHE_CERT="$HTTPD_CONF_D/httpd.pem"

	apache_pid_file="$APACHE_ROOT/logs/httpd.pid"
	apache_lock_file="$APACHE_ROOT/logs/httpd.lock"
	product_lock_file="$HTTPD_CONF_D/cnf.lock"

	min_suexec_UID=10000
	max_suexec_UID=16000
	min_suexec_GID=$min_suexec_UID
	max_suexec_GID=$max_suexec_UID

	suexec_storage=/usr/local/psa/apache/bin
	suexec=/usr/local/psa/apache/bin/suexec
	suexec_dir=/usr/local/psa/apache/bin
	suexec_file=suexec

	rpm_httpd_bin=/usr/sbin/httpd
}

remove_tmp_state()
{
	if [ -d "/tmp/.state" ]; then
		rm -Rf "/tmp/.state" >> $product_log 2>&1
	fi
}

#admin

set_admin_params()
{

	ADMIN_ROOT=$PRODUCT_ROOT_D/admin

	UTILS_DIR=$ADMIN_ROOT/bin

	admin_user="${product}adm"
	admin_UID=8444
	admin_group="${product}adm"
	admin_GID=8444

	admin_httpsd_conf="$ADMIN_ROOT/conf/httpsd.conf"
	ADMIN_CERT="$ADMIN_ROOT/conf/httpsd.pem"

	admin_pid_file=$ADMIN_ROOT/logs/httpsd.pid
	admin_lock_file=$ADMIN_ROOT/logs/httpsd.lock
}

lock_keyupdate()
{
	export PLESK_KEYUPDATE_DISABLED=installation
}

get_admin_passwd()
{
	if [ -f "$mysql_passwd_file" ]; then
		admin_passwd=`cat "$mysql_passwd_file"`
	fi

	if [ -z "$admin_passwd" ]; then
		admin_passwd="$default_mysql_passwd"
	fi

}

#courier-imap

set_courier_imap_params()
{
	COURIER_IMAP_ROOT_D="$PRODUCT_ROOT_D/courier-imap"
	courier_imap_start="$PRODUCT_RC_D/courier-imap start"
	courier_imap_stop="$PRODUCT_RC_D/courier-imap stop"

	IMAPD_CERT="$COURIER_IMAP_ROOT_D/share/imapd.pem"
	POP3D_CERT="$COURIER_IMAP_ROOT_D/share/pop3d.pem"

	IMAPD_CONF="$COURIER_IMAP_ROOT_D/etc/imapd"
	POP3D_CONF="$COURIER_IMAP_ROOT_D/etc/pop3d"

	MAILPASSWD="$QMAIL_ROOT_D/users/poppasswd"
}

# db_test test_query awk_script
# Runs test_query and processes it with awk_script. If the output is
# not empty, return 0, otherwise return 1. Hint: supply '1' for
# awk_script to test just for the presence of any output.
db_test()
{
	local test_query="$1"
	local awk_script="$2"

	local output="`mysql_raw -e \"$test_query\" 2>>\"$product_log\"`"
	local status=$?
	if [ "$status" -ne 0 ]; then
		p_echo "$output"
		die "run the following SQL query: $1"
	fi

	echo -n "$output" | awk -F '\t' -- "$awk_script" | test `wc -l` -ne 0
}

# db_test_table table
# Returns 0 if the table exists
db_test_table()
{
	local table="$1"

	db_test "SHOW TABLES LIKE '$table'" 1
}
set_drweb_qmail_params()
{

	drweb_user="drweb"
	drweb_UID=89
	drweb_group="drweb"
	drweb_GID=89

	drweb_distrib="$PRODUCT_ROOT_D/drweb.tar"
	drweb_qmail_distrib="$PRODUCT_ROOT_D/drweb-qmail.tar"

	drweb_var_dir="/var/drweb"
}

#fp

set_fp_params()
{
	fp_i_dir="/usr/local/frontpage"
	fp_v="version5.0"
	fpsrvadm="$fp_i_dir/$fp_v/bin/owsadm.exe"
	fp_root_def_port=80
	fp_admin="fpadmin"
	fp_admin_passwd="setup"
	fp_distrib="$PRODUCT_ROOT_D/fp.tar"
	fp_apache_stub_conf="$PRODUCT_ROOT_D/apache_tmp.conf"
#	fp_stub_head="$PRODUCT_ROOT_D/apache/conf/httpd.stub.head"
#	fp_stub_tail="$PRODUCT_ROOT_D/apache/conf/httpd.stub.tail"
}

# Print an error message and exit the program.
error()
{
    die "Exiting due to an error!  Please fix the error and try again." 
}



#proftpd

set_ftpd_params()
{

	anonftp_user="${product}ftp"
	anonftp_UID=10002	#XXX
	anonftp_group="${product}ftp"
	anonftp_GID=10002	#XXX

	PROFTPD_ROOT="$PRODUCT_ROOT_D/ftpd"
}

set_jdk_params()
{
	jdk_distrib="$PRODUCT_ROOT_D/j2sdk.bin"
}


set_tomcat_params()
{
	tomcat_user="tomcat4"
	tomcat_UID=91
	tomcat_group="tomcat4"
	tomcat_GID=91

	tomcat_distrib="$PRODUCT_ROOT_D/jakarta-tomcat.tar"
}

p_echo()
{
echo "$*" >> "$product_log" 2>&1
echo "$*"
}

pnnl_echo()
{
if [ -z $necho_defined ]; then
	# set up echo
	case "`echo 'x\c'`" in
    	'x\c')
			echo="echo"
			echo_keys=" -n"
			nnl=
		;;
		x)
			echo="echo"
			echo_keys=
			nnl="\c"
		;;
		*)
			echo "ERROR: unable to set up echo."
		;;
	esac
	necho_defined=true
fi

${echo} ${echo_keys} "$*${nnl}" >> "$product_log" 2>&1
${echo} ${echo_keys} "$*${nnl}"
}

keyupdate_failure_report()
{
	if test -z "$KEYUPDATE_FAILURE_INFO"; then
		return
	fi

	p_echo
	p_echo " *****************************************************************************"
	p_echo " *                                                                           *"
	p_echo " *  ERROR:      The $PRODUCT_NAME license failed to upgrade. The failure     *"
	p_echo " *              follows:                                                     *"
	p_echo
	p_echo "$KEYUPDATE_FAILURE_INFO"
	p_echo
	p_echo " *              If you did not request the automatic key upgrade,            *"
	p_echo " *              please contact SWsoft, Inc sales department for assistance:  *"
	p_echo " *              ${sales_email}. If you want to proceed with upgrade without *"
	p_echo " *              the license upgrade, please create an empty file             *"
	p_echo " *				$prodkey                                             *"
	p_echo " *                                                                           *"
	p_echo " *****************************************************************************"
	p_echo
}

die()
{
	if [ "X$trigger_uninstall" != "X1" ]; then
		printf "\a\a"
		p_echo
		p_echo "ERROR while trying to $*"
		echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Aborting..."
			p_echo
		fi
	fi

	smart_undo_install

	keyupdate_failure_report

	selinux_close

	exit 1

}

err()
{

	if [ "X$trigger_uninstall" != "X1" ]; then
		p_echo
		p_echo "ERROR!"
		p_echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Exiting..."
			p_echo
		fi
	fi

	smart_undo_install

	exit 1
}
# This function needs for some print warning when some services cannot restart
# if called with arg, then we add arg to variable SR_WARNING and print warning
# message for arg, else print warning message for SR_WARNING
service_restart_warning(){
	if [ "X$1" != "X" ]; then
		if [ "X${SR_WARNING}" == "X" ]; then
			SR_WARNING=$1
		else
			for i in ${SR_WARNING}; do
				if [ "$i" == "$1" ]; then
					break
				fi
			done
			if [ "$1" != "$i" ]; then
				SR_WARNING=$SR_WARNING" "$1
			fi
		fi
		p_echo "WARNING!"
		p_echo "Some problems occured when $1 restart, check it after installation/upgrade complete"
	        p_echo
	 	p_echo "Continue..."
		p_echo
	else
		if [ "X${SR_WARNING}" != "X" ]; then
			p_echo "WARNING!"
		        p_echo "Some problems occured when following services restart:"
			for i in ${SR_WARNING}; do
				p_echo $i
			done
			p_echo "Don't forget to check it after installation/upgrade complete"
        		p_echo
	       	        p_echo "More information can be found in log file: ${product_log}"
			p_echo
		fi
	fi
}

warn()
{
local inten
inten="$1"
p_echo
p_echo "WARNING!"
pnnl_echo "During the $inten found some small problems"
echo "(see log file: ${product_log})"
p_echo
p_echo "Continue..."
p_echo

}


echo_try()
{
	msg="$*"
	pnnl_echo " Trying to $msg... "
}

suc()
{
	p_echo "done"
}


mk_backup()
{
	target="$1"
	dup="$2"
	opts="$3"

	if [ -L "$target" ]; then
		rm "$target"
	elif [ -$opts "$target" ]; then
		if [ ! -$opts "$target.$product_suffo" ]; then
			case "$dup" in
				mv)
					mv -f $target $target.$product_suffo || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suffo || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		else
			case "$dup" in
				mv)
					mv -f $target $target.$product_suff || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suff || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		fi
	else
		case "$opts" in
			f|d)
				;;
			*)
				p_echo " mk_backup: wrong option -- must be 'f' or 'd'"
				die "mk_backup"
				;;
		esac
	fi
}

# accumulates chown and chmod
set_ac()
{
	u_owner="$1"
	g_owner="$2"
	perms="$3"
	node="$4"

	chown $u_owner:$g_owner $node || die "chown $u_owner:$g_owner $node"
	chmod $perms $node || die "chmod $perms $node"
}

detect_vz()
{
	local vzcheck_file

	PLESK_VZ=0
	vzcheck_file="/proc/self/status"

	if [ ! -f ${vzcheck_file} ]; then
		return
	fi

	grep -q -E '^envID\:[[:space:]]*([[:digit:]]+)$' < ${vzcheck_file} >/dev/null 2>&1

	if [ $? -eq 0 ]; then
		PLESK_VZ=1
	fi
}

call_optional_function()
{
	local type_output="`type \"$1\" 2>/dev/null | head -n 1`"
	case "$type_output" in
		*function)
			"$@"
			;;
		*)
			return 0
			;;
	esac
}

# Super server internet library

super_server_type()
{
	case "$super_server" in

		'xinetd' | 'inetd')
			;;
		*)
			# check what super-server installed
			inten="define super-server internet daemon type"
			echo_try "$inten"
	
			if [ -f "$xinetd_conf" ]; then
				super_server="xinetd"
				xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2}' -`
			elif [ -f "$inetd_conf" ]; then
				super_server="inetd"
			else
				die "$inten"
			fi
			p_echo "$super_server"
			;;
	esac
}

restart_super_server()
{
	if [ -n "$CHROOTISH" ]; then
			return 0
	fi

	# if PLESK_INSTALLER_DEBUG = daemons then print process table and network status.
	# Usefull for research bugs like 63469, 51592 and other with listen/restart services.
	if [ "X$PLESK_INSTALLER_DEBUG" = "Xdaemon" ] ; then
		ps axl
		netstal -pl
	fi

	super_server_type

	case "$super_server" in

		'xinetd')

		    inten="restart xinetd daemon"
		    echo_try "$inten"
		    case "$machine" in

 		        linux)
				$PRODUCT_RC_D/xinetd reload >> $product_log 2>&1
			    ;;
	 
		        *)
	            	    # not Linux
			    xinetd_pid=`$ps | grep xinetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
				if [ "X${xinetd_pid}" = "X" ]; then
					service_restart_warning "xinetd"
				else
				    $K_USR2 $xinetd_pid >> $product_log 2>&1 && suc || die "$inten"
				fi
	            	    ;;
								 
	            esac

		;;

		'inetd')

			inetd_pid=`$ps | grep inetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
			inten="restart inetd daemon"
			echo_try "$inten"

			if [ "X${inetd_pid}" = "X" ]; then
				 service_restart_warning "inetd"
			else
				$K_HUP $inetd_pid >> $product_log 2>&1 && suc || die "$inten"
			fi
		;;
	esac
}

comment_service_xinetd()
{
	#comment service records
	local dir file service grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	for dir in $xinetd_dir; do

		for file in $dir/*; do

			grep_res=`grep "$service" $file`
			case "$?" in
				0)
					awk "/^[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
						{ print \"#\"\$0; next; }
						{print}
						" <$file >$file.tmp  &&
					mv -f $file.tmp $file || die "$inten" >> $product_log 2>&1
					restart_super_server
					;;
				*)
					;;
			esac

		done;

	done;

	suc

}

comment_service_inetd()
{
	local grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	grep_res=`grep "^$service[[:space:]]" $inetd_conf`

	case "$?" in
	
		0)
			sed -e "s|^$service|##commented_by_psa $service|g" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
			&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" \
			&& suc || die >> $product_log 2>&1
			restart_super_server
			;;
		*)
			p_echo " no record for service $service found in the $inetd_conf"
			;;
	esac
}

comment_service()
{
	local service
	service=$1
	
	super_server_type

	case "$super_server" in

		'xinetd')
			comment_service_xinetd "$service"
			;;

		'inetd')
			comment_service_inetd "$service"
			;;

		*)
			die "Super server type is undefined"
			;;
	esac

}


remove_xinetd()
{
	local service file
	service=$1;
	
	rm -f $xinetd_dir/${service}_${product}
	
	#uncomment old records
	inten="comment out ${product} record for service $service"

	for file in $xinetd_dir/*; do
		awk "/^[[:space:]]*#[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
			{ print substr(\$0,2); next; }
			{print}
			" <$file >$file.tmp &&
		mv -f $file.tmp $file >> $product_log 2>&1
	done;

	restart_super_server

}

remove_inetd()
{
	local service
	service=$1;

	case "$service" in

		ftp)
			inten="restore ftp service record in the $inetd_conf"

			sed -e "s|^ftp.*/${product}/ftpd/sbin/proftpd.*||g" \
				-e "s|ftp.*/${prev_product}/ftpd/sbin/proftpd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtp)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtp.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtp.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtp.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtps)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtps.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtps.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtps.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		pop3)
			inten="restore pop3 service record in the $inetd_conf"

			sed -e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				-e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			
		    ;;
		poppassd)
			# poppassd stream tcp nowait root /usr/sbin/tcpd /${PRODUCT_ROOT_D}/admin/bin/poppassd
			inten="restore poppassd service record in the $inetd_conf"

			sed -e "s|^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			;;
		
	esac

	# uncomment old records
	sed -e "s|^##commented_by_psa $service|$service|g" < $inetd_conf > $inetd_conf.${product}_tmp \
	&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1

	restart_super_server

}

remove_super_server()
{
	local service
	service=$1;

	super_server_type

	case "$super_server" in

		xinetd)
			remove_xinetd "$service"
			;;
		inetd)
			remove_inetd "$service"
			;;
	esac
}

setup_xinetd()
{
	local service file rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	#comment old records
	inten="comment out old record for service $service"
	echo_try "$inten"

	for file in $xinetd_dir/*; do
		egrep '^[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)' $file  > /dev/null
		[ $? -ne 0 ] && continue
		awk "/^[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
			{ print \"#\"\$0; next; }
			{print}
			" <$file >$file.tmp  &&
		mv -f $file.tmp $file || die "$inten" >> $product_log 2>&1
	done;
	suc

	#setup
	service=$1;
	inten="set up record for service $service"
	echo_try "$inten"

	case "$service" in

		ftp)
			echo "
service ftp
{
	socket_type		= stream
	protocol		= tcp
	wait			= no
	disable			= no
	user			= root
	instances		= UNLIMITED
	server			= $PRODUCT_ROOT_D/ftpd/sbin/proftpd
	server_args		= -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf
}" > "$xinetd_dir/ftp_${product}" || die "$inten"
			;;

		smtp)

			case "$rbl_on" in

				on)				
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;

				*)
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;
			esac	
			;;

		smtps)
			case "$rbl_on" in
				on)				
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
				*)
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
			esac	
			;;

		poppassd)
			echo "
service poppassd
{
	socket_type		= stream
	protocol		= tcp
	port			= 106
	wait			= no
	disable			= no
	user			= root
	instances		= 1000
	flags			= KEEPALIVE
	server			= $PRODUCT_ROOT_D/admin/bin/poppassd
}" > "$xinetd_dir/poppassd_${product}" || die "$inten"
			;;

	esac

	suc

}

setup_inetd()
{
	local service rbl_on rbl_server

	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	local ftp_rec smtp_rec pop3_rec 

	ftp_rec="ftp stream tcp nowait root $PRODUCT_ROOT_D/ftpd/sbin/proftpd -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf"

	case "$rbl_on" in
		on)
			smtp_rec="smtp stream tcp nowait root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
		*)
			smtp_rec="smtp stream tcp nowait root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
	esac

	case "$machine" in
		BSD*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/libexec/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
		*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/sbin/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
	esac

	case "$service" in

		ftp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "ftp"
				/usr/sbin/update-inetd --add "$ftp_rec"

			else
				grep_res=`egrep "^ftp.*/${product}/ftpd/sbin/proftpd*." $inetd_conf`
				inten="add ftp service (proftpd) record into the $inetd_conf file"
				echo_try $inten

				case "$grep_res" in
					ftp*)
						p_echo
						p_echo " ftp service (proftpd) is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$ftp_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;

		smtp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtp"
				/usr/sbin/update-inetd --add "$smtp_rec"

			else
				egrep "^smtp.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtp/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtp service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtp_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		smtps)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtps"
				/usr/sbin/update-inetd --add "$smtps_rec"

			else

				egrep "^smtps.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtps/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtps service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtps_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		poppassd)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "poppassd"
				/usr/sbin/update-inetd --add "$poppassd_rec"
			else
				#	^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*
				grep_res=`egrep "^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*" $inetd_conf`
				inten="add poppassd service record in the $inetd_conf"
				echo_try $inten
		
				case "$grep_res" in
					poppassd*)
						p_echo
						p_echo " poppassd service is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$poppassd_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;
	esac

}

setup_super_server()
{
	local service rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;

	super_server_type

	case "$super_server" in

		xinetd)
			setup_xinetd "$service" "$rbl_on" "$rbl_server"
			;;
		inetd)
			setup_inetd "$service" "$rbl_on" "$rbl_server"
			;;
	esac

	restart_super_server
}

get_pid()
{
	local i

	ex_f="$1"
	opt="$2"
	owner="$3"

	min_num=`expr 1`

	case "$opt" in
		false)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		true)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep "$owner" | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		*)
			p_echo "get_pid: wrong parameter"
			die "get_pid $ex_f $opt $owner"
			;;
	esac

	common_var=$min_num
	return $min_num
}

kill_pids()
{
	ex_f="$1"
	owner="$2"

	for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep $owner | awk '{print $2}' -`; do
		if [ $i -gt 1 ]; then
			$K_TERM $i >> $product_log 2>&1
		fi
	done
}

#lib_test

test_for_root()
{
	my_id="`id`"
	case "$my_id" in
		uid=0\(root\)*)
			;;
		*)	echo "$0: This script must be run as root"
			echo "Log in as root then run this script again."
			echo
			exit 1
			;;
	esac
}
get_userID()
{
# try to get UID
	common_var=`id -u "$1" 2>/dev/null` 

# if id returns 0 the all is ok
	if [ "$?" -eq "0" -a ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

get_groupID()
{
# try to get GID, id -g doesn't show groups without users
	common_var=`cat /etc/group | awk -F':' '$1 == "'$1'" {print $3}'` 

# We have non-empty value if success
	if [ ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

delete_user()
{
	local rm_user

	rm_user="$1"

	# if it is mailman user, remove its crontab from system
	if [ "X${rm_user}" = "X${mailman_user}" ]; then

		inten="remove crontab of ${rm_user}"
		echo "y" | $crontab -u "${mailman_user}" -r >> $product_log 2>&1 || die "$inten"

	fi

	inten="remove user $rm_user"
	echo_try "$inten"

	case "$machine" in
		BSD)
			echo "y" | pw userdel $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmuser $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1

		;;
		linux|solaris)
			userdel  $rm_user>> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
}

delete_group()
{
	local rm_group

	rm_group="$1"

	inten="remove group $rm_group"
	echo_try "$inten"

	case "$machine" in
		BSD)
			pw groupdel $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmgroup $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		linux|solaris)
			mk_backup "/etc/group" cp f
			if [ -f "/etc/group" ]; then
				sed -e "/$rm_group/d" < /etc/group > /etc/group.tmp || die $inten
				mv -f /etc/group.tmp /etc/group  >> $product_log 2>&1
				if [ "$?" -ne 0 ]; then
					rsr_backup "/etc/group" cp f
					die $inten
				fi
			fi
#		groupdel  $rm_group>> $product_log 2>&1
		;;
	esac
	suc
}

find_free_num()
{
	src_file="$1"
	min_trsh="$2"
	max_trsh="$3"

	if [ ! -f "$src_file" ]; then
		p_echo
		p_echo "ERROR!"
		p_echo "$src_file: no such file"
		p_echo "Exiting..."
		smart_undo_install
		exit 1
	fi

	[ $min_trsh -le 0 -o $min_trsh -ge $max_trsh ] && {
		p_echo "find_free_num(): wrong parameters"
		smart_undo_install
		exit 1
	}

	min_found=0
	last_found=0
	l_bnd=$min_trsh
	nums=`cat $src_file | awk -F: '{print $3}' -`

	for count in $nums; do
		for i in $nums; do
			[ $i -eq $min_trsh ] && l_bnd=0
			if [ $i -ge $min_trsh -a $i -le $max_trsh ]; then
				if [ $min_found -eq $i -o $min_found -eq 0 ]; then
					min_found=`expr $i + 1`
				fi
			fi
		done
		if [ "$min_found" = "$last_found" ]; then
			break
		fi
		eval last_found=$min_found
	done

	if [ $last_found -lt $max_trsh ]; then
		if [ "X$l_bnd" = "X0" ]; then
			common_var=$last_found
			return $last_found
		else
			common_var=$min_trsh
			return $min_trsh
		fi
	else
		common_var=0
		return 0
	fi
}

selinux_close()
{
	if [ -z "$SELINUX_ENFORCE" -o "$SELINUX_ENFORCE" = "Disabled" ]; then
		return
	fi

	setenforce "$SELINUX_ENFORCE"
}
#set_params

set_common_params()
{

	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	LANG=C
	export PATH LANG
	umask 022
	ulimit -n 65535 2>/dev/null

	K_HUP="/bin/kill -HUP"
	K_KILL="/bin/kill -KILL"
	K_TERM="/bin/kill -TERM"
	K_USR2="/bin/kill -USR2"

	users_created=""
	groups_created=""

	certificate_file="$PRODUCT_ROOT_D/etc/httpsd.pem"
	product=${PRODNAME}
	START_SH="$PRODUCT_RC_D/${product}"

	clients_group="${product}cln"
	clients_GID=10001

	services_group="${product}serv"
	services_GID=10003


#set mail user and group ID

	pop_user="popuser"
	pop_group="popuser"

	get_groupID "${pop_group}" 
	if [ "X$?" = "X0" ]; then
		find_free_num "/etc/group" 100 199
      	        pop_GID=$?		

		if [ "X${pop_GID}" = "X0" ]; then
		   p_echo "ERROR!!!"
		   p_echo "qmail GID was not set"
		   p_echo "Exiting.."
		   smart_undo_install
		   exit 1
		fi
	else
		pop_GID=`cat /etc/group | awk -F':' '$1 == "'${pop_group}'" {print $3}'`
	fi

	pop_UID=110

#end set mail user

	product_suff="saved_by_${product}".`date "+%m.%d;%H:%M"`
	product_suffo="saved_by_${product}"

	common_var=0

	services="/etc/services"
	fstab="/etc/fstab"
	mtab="/etc/mtab"
	xinetd_conf="/etc/xinetd.conf"
	xinetd_dir="/etc/xinetd.d"
	inetd_conf="/etc/inetd.conf"
	syslog_conf="/etc/syslog.conf"
	syslog_conf_ng="/etc/syslog-ng/syslog-ng.conf"
	get_hostname="hostname"
	get_domainname="domainname"

	#VZP used to determine that we're inside SVE
	vza_file="/var/vzagent"

	PREV_PRODUCT_ROOT_D="/usr/local/${prev_product}"

	#default parameters
	tar="tar"
	crontab="/usr/bin/crontab"

	#machine depended parameters
	TARGET_OS="`uname -a`"
	case "$TARGET_OS" in

		BSD/OS*BSDI*i386)
			machine="BSDI"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			compress="compress"
			uncompress="uncompress -c"
			uudecode="uudecode -o /dev/stdout"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			;;

		FreeBSD*i386)
			machine="BSD"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axfwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/usr/local/bin/bash"
			rbash_shell="/usr/local/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			os_version=`uname -v | sed -e 's/^.*FreeBSD[ \t][ \t]*\([0-9\.][0-9\.]*\)-.*$/\1/'`
			if tar --version | grep bsdtar; then
				echo "Use gtar"
				which gtar && tar="gtar" || exit 1
			fi
			named_osrelease=040100 # "must be >= 020218 for  named -u <named> "
			;;

		SunOS*5.*sun4*)
			machine="solaris"
			inetd_conf="/etc/inet/inetd.conf"
			services="/etc/inet/services"
			crontab="/bin/crontab"
			fdtl=""
			sendmail="/usr/lib/sendmail"
			sndml_ini="/etc/init.d/sendmail"
			mail_local="/usr/lib/mail.local"
			ps="ps -e"
			ps_long="ps -aef"
			dummy_shell="/bin/false"
			dummy_home="/"
			false_shell="/bin/false"
			compress="compress"
			uncompress="uncompress"
			uudecode="uudecode -p"
			uudecode_full="/bin/uudecode"
			tar="gtar"
			ifconfig="/usr/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			;;

		Linux*2.?.*i?86*| \
		Linux*2.?.*x86_64*)
			get_hostname="hostname -f"
			if [ -f /etc/slackware-version ]; then
			    machine="linux"
			    linux_distr="slackware"
			    fdtl=""
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/rc.d/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell=""
			    dummy_home="/"
			    false_shell="/bin/false"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=0
			else
			    machine="linux"
				if [ -f /etc/mandrake-release ]; then
			    	linux_distr="mandrake"
				elif [ -f /etc/fedora-release ]; then
			    	linux_distr="fedora"
				elif [ -f /etc/SuSE-release ]; then
			    	linux_distr="suse"
				elif [ -f /etc/debian_version ]; then
			    	linux_distr="debian"
					get_domainname="dnsdomainname"
				else
			    	linux_distr="redhat"
				fi
			    fdtl="-M"
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell="/bin/false"
			    dummy_home="/"
			    false_shell="/bin/false"
				bash_shell="/bin/bash"
				rbash_shell="/bin/rbash"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    uudecode_full="/usr/bin/uudecode"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=`cat /proc/sys/kernel/osrelease | perl -F"/[.-]/" -n -a  -e 'printf "%02u%02u%02u\n", $F[0],$F[1],$F[2]'`
			fi
			;;
		*)
			echo
			echo "Sorry, but your configuration isn't supported yet"
			echo "uname is $TARGET_OS"
			echo
			echo "For more information, please contact $support_email"
			echo
			;;
	esac

	# setup process
	if [ "X$process" = "X" ]; then
		if   [ "X$do_reconfigure" = "X1" ]; then
	    	process="reconfiguration"
		elif  [ "X$do_upgrade" = "X1" ]; then
	    	process="upgrade"
		else
		    process="installing"
		fi
	fi

#	common_var="real"
#	if [ -f $PRODUCT_ROOT_D/version -a "X$do_patch" = "X" ]; then
#	    common_var=`cat $PRODUCT_ROOT_D/version | tr '[:blank:]' '_'`
	product_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_${process}.log"
	product_problems_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_problems.log"
#	elif [ "X$my_name_1" != "X" ]; then
#	    product_log="/tmp/${my_name_1}.log"
#	else
#	    product_log="/tmp/${product}_default_${process}.log"
#	fi

	detect_vz
}


set_local_params()
{
	set_common_params

	for i in set_apache_params set_admin_params lock_keyupdate set_courier_imap_params set_drweb_qmail_params set_fp_params set_ftpd_params set_jdk_params set_tomcat_params set_logrotate_params set_mailman_params set_mysqld_params set_named_params set_openssl_params set_pgsql_params set_python_params set_qmail_params set_spamassassin_params set_vhosts_params set_webalizer_params set_horde_params ; do
		$i
		local res="$?"
		if [ "0$res" -gt 0 ]; then
			return "$res"
		fi
	done
}
set_logrotate_params()
{
	# primary Plesk logrotate config file
	logrotate_conf="${product_etc}/logrotate.conf"

	# directory for logrotate configs of virtual hosts
	logrotate_include_d="${PRODUCT_ROOT_D}/etc/logrotate.d"
}

#all functions in this file are valid for Standard builds only
set_mailman_params()
{
	mailman_user="mailman"
	mailman_group="mailman"
	mailman_UID=91
	mailman_GID=91
	MAILMAN_ROOT_D="${PRODUCT_ROOT_D}"/mailman
	MAILMAN_VHOST_D="${HTTPD_VHOSTS_D}"/mailman
}

remove_modules()
{
	p_echo
	p_echo "===> Removing modules"

	local moduledir
	for moduledir in $PRODUCT_ROOT_D/var/modules/*; do
		if [ -d "$moduledir" -a -x "$moduledir/uninstall" ]; then
			local module=`basename $moduledist`
			echo_try "uninstall $module module"
			"$moduledir/uninstall" && suc || warn "uninstallation of $module module"
		fi
	done
}

#mysql

set_mysqld_params()
{
	mysql_user="mysql"
	mysql_UID=3306
	mysql_group="mysql"
	mysql_GID=3306

	product_db_sql="$PRODUCT_ROOT_D/etc/${PRODNAME}_db.sql"

	mysql_passwd_file="$product_etc/.${PRODNAME}.shadow"
	default_mysql_passwd="$PRODUCT_DEFAULT_PASSWORD"
	prev_mysql_passwd_file="$PREV_PRODUCT_ROOT_D/admin/conf/admin.conf"

#	admin_passwd=${default_mysql_passwd}
	get_admin_passwd

	set_mysql_client_params
	set_mysql_server_params
}

## @@constructor set_mysqld_params

set_mysql_server_params()
{
	MYSQL_ROOT="$PRODUCT_ROOT_D/mysql"
	mysql_bindir="$MYSQL_BIN_D"
	mysql_service="mysqld"
}

set_mysql_client_params()
{
	mysql_client="$MYSQL_BIN_D/mysql"

	# Override these variables as needed
	mysql_db_name="$PRODNAME"
	mysql_auth="-uadmin -p$admin_passwd"
	mysql_args="-N"
	mysql_args_raw="-B -r"

	# For backward compatibility only, should use mysql() and mysql_raw() instead
	mysql="$mysql_client $mysql_auth $mysql_args -D$mysql_db_name"
	mysql_raw="$mysql $mysql_args_raw"
}

# Invoke mysql
mysql()
{
	$mysql_client $mysql_auth $mysql_args -D$mysql_db_name "$@"
}

# Invoke mysql in raw mode
mysql_raw()
{
	mysql $mysql_args_raw "$@"
}

#named

set_named_params()
{
	# set up default values
	bind_UID=53
	bind_GID=53
	bind_user="named";
	bind_group="named";

	# get UID of named user, if exists
	get_userID $bind_user
	if [ $? -ne 0 ]; then
	    bind_UID=$common_var;
        fi

	# get GID of named group, if exists
	get_groupID $bind_group
	if [ $? -ne 0 ]; then
	    bind_GID=$common_var;
	fi

	# old named is not able to run in non-root environment
	if [ 0$named_osrelease -lt 020218 ]; then
	    bind_user="root";
	    bind_UID=0;
	fi

	# path to directory of internal named
	NAMED_ROOT_D="${PRODUCT_ROOT_D:?'PRODUCT_ROOT_D is undefined'}/named"

	# path to directory of named pid file
	bind_run="${NAMED_RUN_ROOT_D:?'NAMED_RUN_ROOT_D is undefined'}/var/run/named"
	# Named start/stop script
	NAMED_RC_SCRIPT="/usr/local/psa/rc.d/named"
	
	# path to named config file
	named_conf="/etc/named.conf"
	rndc_conf="/etc/rndc.conf"
	rndc_namedb_conf="/etc/namedb/rndc.conf"
	rndc_bind_conf="/etc/bind/rndc.conf"
}
set_openssl_params()
{
    openssl_psa_bin=${PRODUCT_ROOT_D}/admin/sbin/openssl;
    openssl_std_bin=/usr/bin/openssl;
}
set_pgsql_params()
{
	pgsql_user="postgres"
	pgsql_group="postgres"
	pgsql_UID=5432
	pgsql_GID=5432

	# path to postgresql for Standard builds
	PGSQL_ROOT_D="$PRODUCT_ROOT_D/postgresql"
}


#values of variables in set_python_params are valid for Standard builds only
set_python_params()
{
	PYTHON_VERSION="python2.2"
	PYTHON_ROOT_D=${PRODUCT_ROOT_D}/${PYTHON_VERSION}
}

#qmail

set_qmail_params()
{
	echo
}
#values of variables in set_spamassassin_params are valid for Standard builds only

set_spamassassin_params()
{
	SPAMASSASSIN_ROOT_D=${PRODUCT_ROOT_D}/spamassassin
}

rsr_backup()
{
	target="$1"
	dup="$2"
	opts="$3"
	common_var=0

#	if [ -$opts "$target" ]; then
		if [ -$opts "$target.$product_suff" ]; then
			case "$dup" in
				mv)
					mv -f  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			esac
		else
			if [ -$opts "$target.$product_suffo" ]; then
			    case "$dup" in
				mv)
					mv -f  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			    esac
			fi
		fi
#	else
#		case "$opts" in
#			f|d)
#				;;
#			*)
#				p_echo " rsr_backup: wrong option -- must be 'f' or 'd'"
#				;;
#		esac
#	fi
}

restore_named()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1
	[ -f /etc/sysconfig/named ] && mv -f "/etc/sysconfig/named" "/etc/sysconfig/named.bak"
	rsr_backup "/etc/sysconfig/named" mv f

	[ -L $named_conf ] && rm -f "$named_conf"
	rsr_backup "$named_conf" mv f

	[ -L $rndc_conf ] && rm -f "$rndc_conf"
	rsr_backup "$rndc_conf" mv f

	case "$machine" in
		BSD*)
			rsr_backup /etc/named.boot mv f
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --add named >> $product_log 2>&1
#			    std_named_sh="/etc/rc.d/init.d/named"
#			    rsr_backup $std_named_sh mv f
#				if [ -f "$std_named_sh" ]; then
#					mv -f "$std_named_sh.${product}" "$std_named_sh"
#				fi
				;;
			slackware)
			    rsr_backup /etc/rc.d/rc.inet2 cp f
				;;
		    esac
			rsr_backup /etc/named.boot mv f
			;;
		solaris)
			rsr_backup /etc/named.boot mv f
			;;
	esac
}


restore_sendmail()
{
	[ -L $sendmail ] && rm -f "$sendmail"
	[ -L /usr/lib/sendmail ] && rm -f "/usr/lib/sendmail"

	rsr_backup "$sendmail" mv f

	case "$machine" in
		BSDI)
			rsr_backup /etc/sendmail.cf mv f
			;;
		*)
			;;
	esac

	if [ -f "$mail_local" ]; then
#		case "$machine" in
#			BSD)
#				chflags schg "$mail_local" >> $product_log 2>&1
#				;;
#			*)
#				;;
#		esac

		rsr_backup "$mail_local" mv f

		chmod 4555 "$mail_local" >> $product_log 2>&1
	fi
	case "$machine" in
		linux )
		    case "$linux_distr" in
			redhat)
			    chkconfig --add sendmail >> $product_log 2>&1
#			    rsr_backup "$sndml_ini" mv f
				;;
			slackware)
			     rsr_backup /etc/rc.d/rc.M mv f
				;;
		    esac
			;;
		solaris)
			rsr_backup "$sndml_ini" mv f
			;;
		*)
			;;
	esac

}

delete_startup_scripts()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1

	case "$machine" in
		BSD)
			rm -f /usr/local/etc/rc.d/${product}.sh >> $product_log 2>&1
	#		rsr_backup /etc/rc.conf cp f

#			inten="enable standard sendmail & named (within /etc/rc.conf)"
#			echo_try $inten
			sed -e 's/^sendmail_enable="NONE".*//g' \
				-e "s/^#named_enable/named_enable/g" \
				< /etc/rc.conf > /etc/rc.conf.${product}_tmp
			mv -f /etc/rc.conf.${product}_tmp /etc/rc.conf
#			suc
			;;
		BSDI)
			if [ -f /etc/rc.local.${product} ]; then
				cp -p  /etc/rc.local.${product} /etc/rc.local >> $product_log 2>&1
			fi
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --del ${product}
			    rm -f /etc/rc.d/init.d/${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc0.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc1.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc2.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc3.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc4.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc5.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc6.d/K15${product} >> $product_log 2>&1
				;;
			slackware)
			    if [ -f /etc/rc.d/rc.local.${product} ]; then
				cp -p  /etc/rc.d/rc.local.${product} /etc/rc.d/rc.local >> $product_log 2>&1
			    fi
				;;
		    esac
		    ;;
		solaris)
			rm -f  /etc/init.d/${product} >> $product_log 2>&1
			if [ -f /etc/rc0.d/K01${product} ]; then
				rm -f /etc/rc0.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc1.d/K01${product} ]; then
				rm -f /etc/rc1.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc2.d/S77${product} ]; then
				rm -f /etc/rc2.d/S77${product} >> $product_log 2>&1
			fi
			;;
	esac
}

delete_crontab()
{

	$crontab -l 2>/dev/null > /tmp/crontab.${product}

	sed -e "s/^.*\/${product}\/admin\/sbin\/statistics.*//g" \
		-e "s/^.*\/${product}\/bin\/mysqldump.*//g" \
		-e "s/^.*\/usr\/sbin\/ntpdate.*//g" \
		< /tmp/crontab.${product} > /tmp/crontab.${product}_tmp

	mv -f /tmp/crontab.${product}_tmp /tmp/crontab.${product} >> $product_log 2>&1

	$crontab /tmp/crontab.${product}  >> $product_log 2>&1

	rm -f /tmp/crontab.${product} >> $product_log 2>&1

}

remove_ftpuser()
{
	user=$1
	ftpusers_file="/etc/ftpusers"

	egrep "^$user" $ftpusers_file >> /dev/null 2>&1

	case "$?" in
			0)
				sed -e "/$user/d" < $ftpusers_file > $ftpusers_file.tmp
				mv -f $ftpusers_file.tmp $ftpusers_file
				;;
			1)
				;;
			*)
				;;
	esac

}

remove_product_users_groups()
{

#	delete users of this(unsuccessful) installation
	for i in $users_created; do
		delete_user "$i"
	done
#	delete users with group=psacln (ftpusers and webusers)
	for i in `perl -e '$gid=getgrnam("'$clients_group'"); exit if (($gid eq "") || ($gid == 0)); while(($n,$u,$g) = (getpwent)[0,2,3]) {print "$n\n" if (($gid == $g) && ($u >= 500))}'`
	do
		delete_user "$i"
		remove_ftpuser "$i"
	done
#	delete users psaadm, psaftp
#	delete_user "$admin_user"  >> "$product_log" 2>&1
#	delete_user "$anonftp_user"  >> "$product_log" 2>&1

#	delete groups of this(unsuccessful) installation
	for i in $groups_created; do
		delete_group "$i"
	done
#	delete groups psaadm, psaftp, psacln
	delete_group "$admin_group"  >> "$product_log" 2>&1
	delete_group "$anonftp_group"  >> "$product_log" 2>&1
	delete_group "$clients_group"  >> "$product_log" 2>&1

}


undo_install()
{
	p_echo
	p_echo
	p_echo "===>Removing installed ${product_bs} components ... "

	remove_modules

	get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
	req_pid=$common_var
	if [ $req_pid -gt 1 ]; then
		$K_KILL $req_pid >> $product_log 2>&1
		sleep 2
		mysql_pid_file=$mysql_bddir/*.pid
		kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
		sleep 2
		if [ -f "$mysql_pid_file" ]; then
			rm -f "$mysql_pid_file"
		fi
	fi

	$START_SH stop >> "$product_log" 2>&1
	sleep 2

	remove_super_server "ftp"
	remove_super_server "pop3"
	remove_super_server "pop-3"
	remove_super_server "imap4"
	remove_super_server "imap2"
	remove_super_server "imap"
	remove_super_server "smtp"
	remove_super_server "smtps"
	remove_super_server "poppassd"

	remove_product_users_groups

	if [ -f "/etc/ftpchroot" ]; then
	    sed -e "s/^@$clients_group//g" < /etc/ftpchroot > /etc/ftpchroot.tmp
	    mv -f /etc/ftpchroot.tmp /etc/ftpchroot  >> $product_log 2>&1
	fi

	if [ -f /etc/shells ]; then
	    case "$machine" in
		BSD|BSDI)
		    sed -e "s/[/]*sbin[/]*nologin//" < /etc/shells > /etc/shells.tmp
		;;
		linux|solaris)
		    sed -e "s/[/]*bin[/]*false//" < /etc/shells > /etc/shells.tmp
		;;
	    esac
	    mv -f /etc/shells.tmp /etc/shells  >> $product_log 2>&1
	fi

#	remove /tmp/.state for ASP
	remove_tmp_state

	restore_named
	restore_sendmail
#	rsr_backup $inetd_conf mv f
#	rsr_backup /etc/my.cnf mv f
#	rsr_backup /etc/named.boot mv f
	delete_startup_scripts
	delete_crontab

	rm -rf $fp_i_dir  >> $product_log 2>&1
	rsr_backup $fp_i_dir mv d
	cd /usr/local  >> $product_log 2>&1
	rm -Rf $PRODUCT_ROOT_D >> $product_log 2>&1
#	rm -Rf $product_etc
	p_echo "done"

}

smart_undo_install()
{
	[ "X$trigger_uninstall" = "X1" -o "X$do_patch" = "X1" -o "X$do_reconfigure" = "X1" ] && return
	[ "X$PLESK_INSTALLER_NOUNDO" != "X" ] && return
	# trigger_uninstall - trigger what smart_undo_install is already working now(recurrence)
	trigger_uninstall=1

	if [ "X$can_uninstall" = "X1" ]; then
		if [ "X$do_upgrade" = "X1" ]; then
			undo_upgrade
		else
			undo_install
		fi
	fi

	# put suggestions for user what to do
	call_optional_function failure_note
}
undo_upgrade()
{
	p_echo   "    The attempt to upgrade $prev_product_full"
	p_echo   "    from version $prev_version to $product_full $product_version has failed."

	if [ -f "$product_sav_tar" ]; then
	
		p_echo 

		p_echo "    Now restore contents of $product_bs from $product_sav_tar"
		p_echo 
		get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
		req_pid=$common_var
		if [ $req_pid -gt 1 ]; then
			$K_KILL $req_pid >> $product_log 2>&1 
			sleep 2
			mysql_pid_file=$mysql_bddir/*.pid
			kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
			sleep 2
			if [ -f "$mysql_pid_file" ]; then
				rm -f $mysql_pid_file
			fi
		fi

		$START_SH stop >> $product_log 2>&1
		sleep 2

		rm -Rf $PRODUCT_ROOT_D
		setup_super_server "smtp"
		setup_super_server "smtps"
		setup_super_server "ftp"
		setup_super_server "poppassd"
		

		cd /
        	tar xvf $product_sav_tar > /dev/null 2>&1
		case "$?" in
			0)
#				rm -f $product_sav_tar 		
			;;
			*)
				p_echo 
				p_echo 
				p_echo "ERROR: restoration of files from $product_sav_tar has failed."
				p_echo "       Please restore them manually."
				p_echo 
				p_echo "Exiting..."
				p_echo 
				exit 0
			;;
		esac
	fi
	
}

#vhosts

set_vhosts_params()
{
	SKEL_DIR="$HTTPD_VHOSTS_D/.skel"
#	SKEL_CERT_DIR="$SKEL_DIR/0/cert"
#	SKEL_CERT="$SKEL_CERT_DIR/httpd.pem"
	return 0
}

#webalizer

set_webalizer_params()
{
	WEBALIZER_ROOT_D="$PRODUCT_ROOT_D/webalizer"
}
set_horde_params()
{
	horde_datadir="/usr/local/psa/psa-horde"
	horde_confdir="/usr/local/psa/etc/psa-horde"
	horde_sysconfd="$horde_confdir/horde"
	horde_logdir="/usr/local/psa/var/log"
	horde_passwd_file="$product_etc/.webmail.shadow"
	horde_title="Horde Web Based mail client "

	imp_datadir="$horde_datadir/imp"
	imp_sysconfd="$horde_sysconfd/imp"

	turba_datadir="$horde_datadir/turba"
	turba_sysconfd="$horde_sysconfd/turba"

	kronolith_datadir="$horde_datadir/kronolith"
	kronolith_sysconfd="$horde_sysconfd/kronolith"

	ingo_datadir="$horde_datadir/ingo"
	ingo_sysconfd="$horde_sysconfd/ingo"

	mnemo_datadir="$horde_datadir/mnemo"
	mnemo_sysconfd="$horde_sysconfd/mnemo"
	
	passwd_datadir="$horde_datadir/passwd"
	passwd_sysconfd="$horde_sysconfd/passwd"
}

## @@constructor set_horde_params
set_horde_perms()
{
    local inten="install permissions for $horde_title"
    echo_try $inten
    chown -R root:0 $horde_datadir || die $inten
    chown -R root:0 $horde_confdir || die $inten
    [ -e $horde_logdir/psa-horde.log ] || touch $horde_logdir/psa-horde.log
	set_ac $apache_user $apache_group 640 $horde_logdir/psa-horde.log || die $inten
	suc
}

install_horde()
{
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		return 0;
	fi

	p_echo
	p_echo
	cd "$PRODUCT_ROOT_D" || err
	p_echo "===> Installing $horde_title"
	
	set_horde_params
	set_horde_perms
	
	# generate random password
	if [ ! -s $horde_passwd_file ]; then
		local inten="generate random password for $horde_title"
		echo_try $inten
		set_ac root 0 555 "$PRODUCT_ROOT_D/admin/sbin/random_str" || die $inten
		RANDOM_PASSWORD=`${PRODUCT_ROOT_D}/admin/sbin/random_str` || die $inten
		suc
		local inten="save password for $horde_title into $horde_passwd_file"
		echo_try $inten
		echo $RANDOM_PASSWORD > $horde_passwd_file || die $inten
		set_ac root $apache_group 640 $horde_passwd_file || die $inten
		suc
	else
		RANDOM_PASSWORD=`cat $horde_passwd_file`;
	fi
	
	# check if horde database exists
	# create new database horde
	if ! echo "use horde" | $mysql 2>/dev/null ; then
		inten="install database for $horde_title"
		cat "$horde_datadir/scripts/sql/create.mysql.sql" | sed -e "s/@WEBMAIL_PASSWORD@/$RANDOM_PASSWORD/" | ${mysql}
		cat "$turba_datadir/scripts/sql/turba_objects.mysql.sql" | ${mysql} horde
		cat "$kronolith_datadir/scripts/sql/kronolith.mysql.sql" | ${mysql} horde
		cat "$mnemo_datadir/scripts/sql/mnemo.sql" | ${mysql} horde
		suc
	elif ! echo "use horde; select * from horde_vfs LIMIT 1" | $mysql 2>/dev/null; then
		inten="Uprage database for $horde_title"
		local mysql_db_name="horde"
		cat "$horde_datadir/scripts/upgrades/2.2_to_3.0.mysql.sql" | ${mysql} horde
		echo "delete from horde_prefs where pref_scope!='horde' and pref_name='last_login'" | ${mysql} horde
		cat "$turba_datadir/scripts/upgrades/1.2_to_2.0.sql" | ${mysql} horde
		if ! db_test_table "kronolith_events"; then
			cat "$kronolith_datadir/scripts/sql/kronolith.mysql.sql" | ${mysql} horde
		elif ! db_test_table "kronolith_storage" ; then
			cat "$kronolith_datadir/scripts/upgrades/1.1_to_2.0.mysql.sql" | ${mysql} horde
		fi

		if db_test "SELECT user FROM mysql.user where user='horde' and host='%'" '/horde/'; then
#       Fix up creating passwordless user, bug 41358
			cat $mnemo_datadir/scripts/upgrades/upgrade-mnemo.sql | ${MYSQL} -Dhorde
		fi
		suc
	else
		echo "$horde_title database is up to date"
	fi
}


initial_conf()
{
	DEMO_VERSION="no"
	PRODNAME="psa"
	PRODUCT_NAME="Plesk"
	product_full="Plesk"
	PRODUCT_FULL_NAME="Plesk"

	product_etc="/etc/${PRODNAME}"
	prod_conf_t="/etc/psa/psa.conf"
	prodkey="$product_etc/$PRODNAME.key"

	minimal_changes=""

	MYSQL_VERS="4.1.11"
	POSTGRESQL_VERS="7.4.6"
	EXTERNAL_PACKAGES="expat libiconv"
	EXTERNAL_PACKAGES_DIR=""tmp/packages""

	BUILDER_UID="10007"

	PERL5LIB=/usr/local/psa/lib/perl5/site_perl/5.005
	export PERL5LIB

	product_bs=Plesk
	support_email="support@swsoft.com"
	sales_email="sales@swsoft.com"

	product_version="7.5.4"
	product_db_version="0754"
	product_build="75060413.12"
	conceived_os_vendor="FreeBSD"
	conceived_os_version="4.9"
	osrels="fr4.9"

	# This variable contains all versions, which is supported by
	# cumulative upgrade
	known_product_versions="71 75"

	prev_product="plesk"
	prev_clients_group="${prev_product}cln"

	# GID for mailman
	mm_mailgroup=110

	# plesk default password
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		PRODUCT_DEFAULT_PASSWORD="plesk"
	else
		PRODUCT_DEFAULT_PASSWORD="setup"
	fi

	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
		echo "Unable to determine current working directory."
		echo "Please fix the problem and run installation again."
		exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
		0)
			my_name="$my_name_2"
		;;
		1)
			my_name="$my_name_0"/"$my_name_2"
		;;
	    *)
			echo "Unable to determine the name of installer."
			echo "Please fix the problem and run installation again."
			exit 1
		;;
	esac
}

read_conf()
{
	initial_conf

	if [ -s $prod_conf_t ]; then
		tmp_var=`perl -e 'undef $/; $_=<>; s/#.*$//gm;
				s/^\s*(\S+)\s*/$1=/mg;
				print' $prod_conf_t`
		eval $tmp_var
	else
		[ 0$ignore_miss_conf -ne 1 ] && p_echo "Unable to find product configuration file: $prod_conf_t"
		return 1
#		die "find product configuration file: $prod_conf_t"
	fi
	return 0

}

check_opsys()
{
        case "$machine" in
	    BSD)
		dist_os_major_ver=`echo "$conceived_os_version" | \
							sed -e 's/^\(.\).*/\1/'`
		real_os_major_ver=`echo "$os_version" | sed -e 's/^\(.\).*/\1/'`
		dist_os_minor_ver=`echo "$conceived_os_version" | \
					sed -e 's/^[0-9]*\.\([0-9]*\).*/\1/'`
		real_os_minor_ver=`echo "$os_version" | \
					sed -e 's/^[0-9]*\.\([0-9]*\).*/\1/'`
		st=${real_os_major_ver}_${real_os_minor_ver}_${dist_os_major_ver}_${dist_os_minor_ver}
		case $st in
			4_9_4_9|4_10_4_9|4_11_4_9)
				perl_req_ver="5.00503"
			;;
			5_3_5_3|5_4_5_3)
				perl_req_ver="5.008007"
			;;
			*)
				p_echo "This installer does not support FreeBSD-$os_version."
				exit 1;
			;;
		esac

		if [ -x /usr/bin/perl ]; then
			perl_ver=`perl -e 'print $]'`
		else
			p_echo "Installation of this Plesk distribution\
			requires that Perl $perl_req_ver version be\
			installed on the server!"
			exit 1;
		fi
		if [ "$perl_req_ver" != "$perl_ver" ]; then
			p_echo "To continue installing, you should install\
			Perl $perl_req_ver (you have Perl $perl_ver\
			installed)"
			exit 1;
		fi
		return
	    ;;
	    BSDI)
	    ;;
	    linux)
	    ;;
	    solaris)
	    ;;
	esac
    p_echo "This installer does not support $machine platform."
    p_echo "Please obtain the appropriate installer for $machine system."
    exit 1
}
w
set_hotfix_permissions()
{
### Set perms for hotfix files
local inten="set proper permission on hotfixed files"
echo_try $inten

chown root:0 /usr/local/psa/etc/logrotate.d/psa-horde
chmod 0644 /usr/local/psa/etc/logrotate.d/psa-horde
chown root:0 /usr/local/psa/admin/sbin/backupmng
chmod 0550 /usr/local/psa/admin/sbin/backupmng
chown root:0 /usr/local/psa/admin/sbin/packagemng
chmod 0550 /usr/local/psa/admin/sbin/packagemng
chown root:0 /usr/local/psa/admin/plib/cmd_loginup.php
chmod 0644 /usr/local/psa/admin/plib/cmd_loginup.php

suc
}

### Some initial parameters
	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	export PATH

	PRODNAME="psa"
	PRODVERSION="7.5.4"

	build_number="75060413.12"

	read_conf
	product_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	product_problems_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	set_local_params
	check_opsys

	test_for_root

### My name define
	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
                echo "Unable to determine current working directory."
                echo "Please fix the problem and run installation again."
                exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
                0)
                        my_name="$my_name_2"
                ;;
                1)
                        my_name="$my_name_0"/"$my_name_2"
                ;;
            *)
                        err
                ;;
	esac

	if [ -d "$PRODUCT_ROOT_D" ]; then
	    plesk_ver=`awk '{print $1}' $PRODUCT_ROOT_D/version`
	    plesk_rel=`awk '{print $4;}' $PRODUCT_ROOT_D/version`
	    plesk_release=`echo "$plesk_rel" | sed -e 's/\./0/'`
	    PRODRELEASE=`echo "$build_number" | sed -e 's/\./0/'`
	    case "$plesk_ver" in
		$PRODVERSION)
			perl -e "{exit ((\"0$plesk_release\" > \"0$PRODRELEASE\") ? 0 : 1);}"
			if [ 0$? -eq 0 ]; then
				p_echo
				p_echo "The Plesk version ($plesk_ver $plesk_rel) you have does not require this hotfix ($PRODVERSION $build_number)."
				p_echo "Thank you for choosing our products!"
				p_echo
				exit 0
			fi

			START_SH=$PRODUCT_RC_D/${PRODNAME}

			### unpack hotfix
			p_echo "Extracting hotfix files"
			cat "$my_name" | $uudecode | tar -x -m -C / -f -

			set_hotfix_permissions
			
			set_mysqld_params
			install_horde
	
            sed -e 's/^\(.*\)[ \t][0-9][0-9]*\.[0-9][0-9]*$/\1 '$build_number'/' < "$PRODUCT_ROOT_D/version" > "$PRODUCT_ROOT_D/version.tmp" \
			&& mv -f "$PRODUCT_ROOT_D/version.tmp" "$PRODUCT_ROOT_D/version"

			;;
		*)
			p_echo
			p_echo "You have Plesk version $plesk_ver. In order for this script to work properly,"
			p_echo "please ensure that the version of the Plesk that you're attempting to hotfix"
			p_echo "is $PRODVERSION"
			p_echo "Thank you for choosing our products!"
			p_echo
			exit 0
			;;
	    esac
	else
		p_echo "ERROR: PSA directory '${PRODUCT_ROOT_D}' not found! Install PSA first."
		exit 1
	fi    

	p_echo "Done."
	p_echo
exit 0

begin 644 plesk_patch.tar
M+B\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S0S`#`Q,#`U,P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`,#$P-C8T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+P``````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T
M,P`P,3$W-38`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#$W`#`Q,C4S-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O971C+P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`,#$S,S$T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]E=&,O;&]G<F]T871E+F0O````````````````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<T,P`P,34U,S8`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V5T8R]L;V=R;W1A=&4N9"]P
M<V$M:&]R9&4`````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,3<W`#$P-#$W,S8R-S0S`#`Q-S,T-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O=7-R+VQO8V%L+W!S82]V
M87(O;&]G+W!S82UH;W)D92YL;V<@>PH);6]N=&AL>0H);6ES<VEN9V]K"@ER
M;W1A=&4@-`H)8V]M<')E<W,*"6-R96%T92`V-#`@87!A8VAE(&%P86-H90H)
M;F]T:69E;7!T>0H);F]M86EL"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+P``````````````````
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<T,P`P,34Q-S8`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R
M9&4O:W)O;F]L:71H+P``````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S`#`Q-S(P-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O971C+W!S82UH;W)D92]K<F]N;VQI=&@O:V5Y=V]R9',N<&AP````
M````````````````````````````````````````````````````````````
M,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,C8`,3`T,3<S-C(W
M-#,`,#(Q-38R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!+<F]N;VQI=&@@2V5Y=V]R9"!$969I;FET
M:6]N($9I;&4*("H*("H@5&AI<R!F:6QE(&ES('=H97)E('EO=2!D969I;F4@
M=&AE(&QI<W0@;V8@:V5Y=V]R9',@=&AA="!C86X@8F4@=7-E9`H@*B!T;R!C
M871E9V]R:7IE(&5V96YT<R!I;B!+<F]N;VQI=&@N"B`J"B`J(%1H97)E(&ES
M(&YO(&QI;6ET(&]N(&AO=R!M86YY(&ME>7=O<F1S(&]U="!O9B!A('-P96-I
M9FEC(&-A=&5G;W)Y"B`J(&%N(&5V96YT(&-A;B!H879E.R!T:&4@8V%T96=O
M<FEE<R!A<F4@9F]R(&QO9VEC86P@9W)O=7!I;F=S(&]N;'DN"B`J"B`J($5A
M8V@@8V%T96=O<GD@=VEL;"!G96YE<F%T92!A('1A8FQE(&-E;&PL('=I=&@@
M=&AE(&-A=&5G;W)Y(&YA;64@:6X*("H@8F]L9"!A;F0@8VAE8VMB;WAE<R!F
M;W(@96%C:"!E;G1R>2!I;B!T:&4@8V%T96=O<GD@8F5L;W<@:70N"B`J"B`J
M("1(;W)D93H@:W)O;F]L:71H+V-O;F9I9R]K97EW;W)D<RYP:'`N9&ES="QV
M(#$N,R`R,#`T+S$Q+S`V(#$X.C0W.C$U(&IA;B!%>'`@)`H@*B\*"B1K97EW
M;W)D<UM?*")4>7!E(BE=(#T@87)R87DH7R@B0FER=&AD87DB*2P@7R@B365E
M=&EN9R(I+"!?*")'86UE(BDI.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]K<F]N;VQI=&@O;65N=2YP:'``
M````````````````````````````````````````````````````````````
M````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-C8`,3`T
M,3<S-C(W-#,`,#(P-C8W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]C
M;VYF:6<O;65N=2YP:'`N9&ES="QV(#$N-"`R,#`T+S$Q+S`V(#$X.C0W.C$U
M(&IA;B!%>'`@)`H@*@H@*B!4:&ES(&9I;&4@;&5T<R!Y;W4@97AT96YD($MR
M;VYO;&ET:"=S(&UE;G4@=VET:"!Y;W5R(&]W;B!I=&5M<RX*("H*("H@5&\@
M861D(&$@;F5W(&UE;G4@:71E;2P@<VEM<&QY(&%D9"!A(&YE=R!E;G1R>2!T
M;R!T:&4@)%]M96YU(&%R<F%Y+@H@*B!686QI9"!A='1R:6)U=&5S(&9O<B!A
M(&YE=R!M96YU(&ET96T@87)E.@H@*@H@*B`@)W5R;"<@("`@("`@5&AE(%52
M3"!V86QU92!F;W(@=&AE(&UE;G4@:71E;2X*("H@("=T97AT)R`@("`@(%1H
M92!T97AT('1O(&%C8V]M<&%N>2!T:&4@;65N=2!I=&5M+@H@*@H@*B!4:&5S
M92!A='1R:6)U=&5S(&%R92!O<'1I;VYA;#H*("H*("H@("=I8V]N)R`@("`@
M(%1H92!F:6QE;F%M92!O9B!A;B!I8V]N('1O('5S92!F;W(@=&AE(&UE;G4@
M:71E;2X*("H@("=I8V]N7W!A=&@G(%1H92!P871H('1O('1H92!I8V]N(&EF
M(&ET(&1O97-N)W0@97AI<W0@:6X@=&AE(&=R87!H:6-S+PH@*B`@("`@("`@
M("`@("`@9&ER96-T;W)Y+@H@*B`@)W1A<F=E="<@("`@5&AE(")T87)G970B
M(&]F('1H92!L:6YK("AE+F<N("=?=&]P)RP@)U]B;&%N:R<I+@H@*B`@)V]N
M8VQI8VLG("`@06YY($IA=F%38W)I<'0@=&\@97AE8W5T92!O;B!T:&4@(F]N
M8VQI8VLB(&5V96YT+@H@*@H@*B!(97)E)W,@86X@97AA;7!L92!E;G1R>3H*
M("H*("H@("1?;65N=5M=(#T@87)R87DH("`@"B`J("`@("`@)W5R;"<@/3X@
M("`@("`@("=H='1P.B\O=W=W+F5X86UP;&4N8V]M+R<L"B`J("`@("`@)W1E
M>'0G(#T^("`@("`@("=%>&%M<&QE+"!);F,N)RP*("H@("`@("`G:6-O;B<@
M/3X@("`@("`@)V5X86UP;&4N<&YG)RP*("H@("`@("`G:6-O;E]P871H)R`]
M/B`@)VAT='`Z+R]W=W<N97AA;7!L92YC;VTO:6UA9V5S+R<L"B`J("`@("`@
M)W1A<F=E="<@/3X@("`@("=?8FQA;FLG+`H@*B`@("`@("=O;F-L:6-K)R`]
M/B`@("`G)PH@*B`@*3L*("H*("H@66]U(&-A;B!A;'-O(&%D9"!A(")S97!A
M<F%T;W(B("AA('-P86-E<BD@8F5T=V5E;B!M96YU(&ET96US+B`@5&\@861D
M(&$*("H@<V5P87)A=&]R+"!S:6UP;'D@861D(&$@;F5W('-T<FEN9R!T;R!T
M:&4@)%]M96YU(&%R<F%Y('-E="!T;R!T:&4@=&5X=`H@*B`G<V5P87)A=&]R
M)RX@($ET('-H;W5L9"!L;V]K(&QI:V4@=&AI<SH*("H*("H@("1?;65N=5M=
M(#T@)W-E<&%R871O<B<["B`J+PH*)%]M96YU(#T@87)R87DH*3L*"B\J($%D
M9"!Y;W5R(&-U<W1O;2!E;G1R:65S(&)E;&]W('1H:7,@;&EN92X@*B\*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]P<F5F<RYP:'``````````````````````````````
M```````````````````````````````````````P,3`P-#0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`R,S0W-``Q,#0Q-S,V,C<T,P`P,C$P-#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:W)O;F]L:71H+V-O;F9I9R]P<F5F<RYP:'`N9&ES="QV
M(#$N-C8N,BXV(#(P,#4O,3`O,C$@,C`Z,#8Z,C(@:F%N($5X<"`D"B`J"B`J
M(%-E92!H;W)D92]C;VYF:6<O<')E9G,N<&AP(&9O<B!D;V-U;65N=&%T:6]N
M(&]N('1H92!S=')U8W1U<F4@;V8@=&AI<R!F:6QE+@H@*B\*"B1P<F5F1W)O
M=7!S6R=V:65W)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H(D1I<W!L
M87D@3W!T:6]N<R(I+`H@("`@)VQA8F5L)R`]/B!?*")5<V5R($EN=&5R9F%C
M92(I+`H@("`@)V1E<V,G(#T^(%\H(E-E;&5C="!C;VYF:7)M871I;VX@;W!T
M:6]N<RP@:&]W('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@
M8VAO;W-E(&1E9F%U;'0@=FEE=RXB*2P*("`@("=M96UB97)S)R`]/B!A<G)A
M>2@G8V]N9FER;5]D96QE=&4G+"`G9&5F875L='9I97<G+`H@("`@("`@("`@
M("`@("`@("`@("`@("=T:6UE7V)E='=E96Y?9&%Y<R<L("=W965K7W-T87)T
M7VUO;F1A>2<L"B`@("`@("`@("`@("`@("`@("`@("`@)V1A>5]H;W5R7W-T
M87)T)RP@)V1A>5]H;W5R7V5N9"<L("=S;&]T<U]P97)?:&]U<B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@)W-H;W=?:6-O;G,G+"`G<VAO=U]L96=E;F0G
M+"`G<VAO=U]F8E]L96=E;F0G+`H@("`@("`@("`@("`@("`@("`@("`@("=S
M:&]W7W-H87)E9%]S:61E7V)Y7W-I9&4G*0HI.PH*)'!R969'<F]U<'-;)W-U
M;6UA<GDG72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B1&ES<&QA>2!/
M<'1I;VYS(BDL"B`@("`G;&%B96PG(#T^(%\H(E!O<G1A;"!/<'1I;VYS(BDL
M"B`@("`G9&5S8R<@/3X@7R@B4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W
M(&EN('1H92!P;W)T86PN(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)W-U
M;6UA<GE?9&%Y<R<L("=S=6UM87)Y7V%L87)M<R<I"BD["@II9B`H)')E9VES
M=')Y+3YH87--971H;V0H)W1A<VMS+VQI<W1487-K<R<I*2!["B`@("`D<')E
M9D=R;W5P<ULG=&%S:W,G72`](&%R<F%Y*`H@("`@("`@("=C;VQU;6XG(#T^
M(%\H(D1I<W!L87D@3W!T:6]N<R(I+`H@("`@("`@("=L86)E;"<@/3X@7R@B
M5&%S:W,B*2P*("`@("`@("`G9&5S8R<@/3X@7R@B1&\@>6]U('=A;G0@=&\@
M<VAO=R!T87-K<R!W:&EC:"!A<F4@9'5E(&]N('EO=7(@8V%L96YD87(_(BDL
M"B`@("`@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=S:&]W7W1A<VMS)RP@)W-H
M;W=?=&%S:U]C;VQO<G,G*0H@("`@*3L*?0H*)'!R969'<F]U<'-;)W-H87)E
M)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H(D-A;&5N9&%R<R(I+`H@
M("`@)VQA8F5L)R`]/B!?*")$969A=6QT($-A;&5N9&%R(BDL"B`@("`G9&5S
M8R<@/3X@7R@B0VAO;W-E('EO=7(@9&5F875L="!C86QE;F1A<BXB*2P*("`@
M("=M96UB97)S)R`]/B!A<G)A>2@G<VAA<F5S96QE8W0G*0HI.PH*)'!R969'
M<F]U<'-;)W)E;6]T92==(#T@87)R87DH"B`@("`G8V]L=6UN)R`]/B!?*")#
M86QE;F1A<G,B*2P*("`@("=L86)E;"<@/3X@7R@B4F5M;W1E($-A;&5N9&%R
M<R(I+`H@("`@)V1E<V,G(#T^(%\H(DUA;F%G92!R96UO=&4@8V%L96YD87)S
M+B(I+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=R96UO=&5?8V%L7VUA;F%G
M96UE;G0G*0HI.PH*)'!R969'<F]U<'-;)VYO=&EF:6-A=&EO;B==(#T@87)R
M87DH"B`@("`G8V]L=6UN)R`]/B!?*")#86QE;F1A<G,B*2P*("`@("=L86)E
M;"<@/3X@7R@B3F]T:69I8V%T:6]N<R(I+`H@("`@)V1E<V,G(#T^(%\H(D-H
M;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E
M9"P@86YD(&1E;&5T960@979E;G1S+B(I+`H@("`@)VUE;6)E<G,G(#T^(&%R
M<F%Y*"=E=F5N=%]N;W1I9FEC871I;VXG+"`G979E;G1?<F5M:6YD97(G*0HI
M.PH*)'!R969'<F]U<'-;)V9R965B=7-Y)UT@/2!A<G)A>2@*("`@("=C;VQU
M;6XG(#T^(%\H(D-A;&5N9&%R<R(I+`H@("`@)VQA8F5L)R`]/B!?*")&<F5E
M+T)U<WD@26YF;W)M871I;VXB*2P*("`@("=D97-C)R`]/B!?*")3970@>6]U
M<B!F<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H97(@
M=7-E<G,G(&9R964O8G5S>2!O<'1I;VYS+B(I+`H@("`@)VUE;6)E<G,G(#T^
M(&%R<F%Y*"=F8E]C86QS7W-E;&5C="<L("=F<F5E8G5S>5]D87ES)RD**3L*
M:68@*"1R96=I<W1R>2T^:&%S365T:&]D*"=C;VYT86-T<R]S;W5R8V5S)RDI
M('L*("`@("1P<F5F1W)O=7!S6R=F<F5E8G5S>2==6R=M96UB97)S)UU;72`]
M("=S96%R8VA?86)O;VM?<V5L96-T)SL*?0H*"B\O(&-O;F9I<FT@9&5L971I
M;VX@;V8@979E;G1S('=H:6-H(&1O;B=T(')E8W5R/PHD7W!R969S6R=C;VYF
M:7)M7V1E;&5T92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#$L"B`@("`G
M;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@
M)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B0V]N9FER
M;2!D96QE=&EO;B!O9B!E=F5N=',_(BD**3L*"B\O(&1E9F%U;'0@=FEE=PHD
M7W!R969S6R=D969A=6QT=FEE=R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M("=M;VYT:"<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("=E;G5M)R`]
M/B!A<G)A>2@G9&%Y)R`]/B!?*")$87DB*2P*("`@("`@("`@("`@("`@("`@
M("`G=V5E:R<@/3X@7R@B5V5E:R(I+`H@("`@("`@("`@("`@("`@("`@("=W
M;W)K=V5E:R<@/3X@7R@B5V]R:R!7965K(BDL"B`@("`@("`@("`@("`@("`@
M("`@)VUO;G1H)R`]/B!?*")-;VYT:"(I*2P*("`@("=D97-C)R`]/B!?*")3
M96QE8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O;B!S=&%R='5P.B(I"BD["@HO
M+R!$:7-P;&%Y('1H92!T:6UE<VQO=',@8F5T=V5E;B!E86-H(&1A>2!C;VQU
M;6XL(&EN('=E96L@=FEE=RX*)%]P<F5F<ULG=&EM95]B971W965N7V1A>7,G
M72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G
M8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(E-H;W<@=&EM92!O9B!D87D@
M8F5T=V5E;B!E86-H(&1A>2!I;B!W965K('9I97=S/R(I"BD["@HO+R!W:&%T
M(&1A>2!D;V5S('1H92!W965K('-T87)T('=I=&@*)%]P<F5F<ULG=V5E:U]S
M=&%R=%]M;VYD87DG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G,"<L"B`@
M("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@
M("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("=D97-C)R`]/B!?*")396QE8W0@
M=&AE(&9I<G-T('=E96MD87DZ(BDL"B`@("`G96YU;2<@/3X@87)R87DH)S`G
M(#T^(%\H(E-U;F1A>2(I+`H@("`@("`@("`@("`@("`@("`@("<Q)R`]/B!?
M*")-;VYD87DB*2D**3L*"B\O('-T87)T(&]F('1H92!T:6UE(')A;F=E(&EN
M(&1A>2]W965K('9I97=S.@HD7W!R969S6R=D87E?:&]U<E]S=&%R="==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^(#$V+`H@("`@)VQO8VME9"<@/3X@9F%L
M<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G<V5L
M96-T)RP*("`@("=D97-C)R`]/B!?*")7:&%T('1I;64@<VAO=6QD(&1A>2!A
M;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE
M<B!E=F5N=',_(BD**3L*"B\O(&5N9"!O9B!T:&4@=&EM92!R86YG92!I;B!D
M87DO=V5E:R!V:65W<SH*)%]P<F5F<ULG9&%Y7VAO=7)?96YD)UT@/2!A<G)A
M>2@*("`@("=V86QU92<@/3X@-#@L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=S96QE8W0G
M+`H@("`@)V1E<V,G(#T^(%\H(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W
M965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S
M/R(I"BD["@HO+R!N=6UB97(@;V8@<VQO=',@:6X@96%C:"!H;W5R.@HD7W!R
M969S6R=S;&]T<U]P97)?:&]U<B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M(#$L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A
M;'-E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("=D97-C)R`]/B!?*")(
M;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@=&AE(&1A>2!A;F0@
M=V5E:R!V:65W<R!B93\B*2P*("`@("=E;G5M)R`]/B!A<G)A>2@T(#T^(%\H
M(C$U(&UI;G5T97,B*2P*("`@("`@("`@("`@("`@("`@("`S(#T^(%\H(C(P
M(&UI;G5T97,B*2P*("`@("`@("`@("`@("`@("`@("`R(#T^(%\H(C,P(&UI
M;G5T97,B*2P*("`@("`@("`@("`@("`@("`@("`Q(#T^(%\H(C$@:&]U<B(I
M*0HI.PH*+R\@<VAO=R!D96QE=&4O86QA<FT@:6-O;G,@:6X@=&AE(&-A;&5N
M9&%R('9I97<_"B1?<')E9G-;)W-H;W=?:6-O;G,G72`](&%R<F%Y*`H@("`@
M)W9A;'5E)R`]/B`Q+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@
M)V1E<V,G(#T^(%\H(E-H;W<@9&5L971E+"!A;&%R;2P@86YD(')E8W5R<F5N
M8V4@:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_(BD**3L*"B\O('-H;W<@8V%T
M96=O<GD@;&5G96YD/PHO+R!A('9A;'5E(&]F(#`@/2!N;RP@,2`]('EE<PHD
M7W!R969S6R=S:&]W7VQE9V5N9"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M(#$L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A
M;'-E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@
M7R@B4VAO=R!C871E9V]R>2!L96=E;F0_(BD**3L*"B\O('-H;W<@9G)E92]B
M=7-Y(&QE9V5N9#\*+R\@82!V86QU92!O9B`P(#T@;F\L(#$@/2!Y97,*)%]P
M<F5F<ULG<VAO=U]F8E]L96=E;F0G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]
M/B`Q+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F
M86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^
M(%\H(E-H;W<@9G)E92]B=7-Y(&QE9V5N9#\B*0HI.PH*+R\@8V]L;&%P<V5D
M(&]R('-I9&4@8GD@<VED92!V:65W"B1?<')E9G-;)W-H;W=?<VAA<F5D7W-I
M9&5?8GE?<VED92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G
M;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@
M)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4VAO=R!S
M:&%R960@8V%L96YD87)S('-I9&4M8GDM<VED93\B*0HI.PH*+R\@9&%Y<R!T
M;R!S:&]W(&EN('-U;6UA<GD*)%]P<F5F<ULG<W5M;6%R>5]D87ES)UT@/2!A
M<G)A>2@*("`@("=V86QU92<@/3X@-RP*("`@("=L;V-K960G(#T^(&9A;'-E
M+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V5N=6TG
M+`H@("`@)V1E<V,G(#T^(%\H(E-E;&5C="!T:&4@=&EM92!S<&%N('1O('-H
M;W<Z(BDL"B`@("`G96YU;2<@/3X@87)R87DH,2`]/B`G,2`G("X@7R@B9&%Y
M(BDL"B`@("`@("`@("`@("`@("`@("`@,B`]/B`G,B`G("X@7R@B9&%Y<R(I
M+`H@("`@("`@("`@("`@("`@("`@(#,@/3X@)S,@)R`N(%\H(F1A>7,B*2P*
M("`@("`@("`@("`@("`@("`@("`T(#T^("<T("<@+B!?*")D87ES(BDL"B`@
M("`@("`@("`@("`@("`@("`@-2`]/B`G-2`G("X@7R@B9&%Y<R(I+`H@("`@
M("`@("`@("`@("`@("`@(#8@/3X@)S8@)R`N(%\H(F1A>7,B*2P*("`@("`@
M("`@("`@("`@("`@("`W(#T^("<Q("<@+B!?*")W965K(BDL"B`@("`@("`@
M("`@("`@("`@("`@,30@/3X@)S(@)R`N(%\H(G=E96MS(BDL"B`@("`@("`@
M("`@("`@("`@("`@,C$@/3X@)S,@)R`N(%\H(G=E96MS(BDL"B`@("`@("`@
M("`@("`@("`@("`@,C@@/3X@)S0@)R`N(%\H(G=E96MS(BDI"BD["@HO+R!S
M:&]W(&%L87)M<R!I;B!S=6UM87)Y/PHD7W!R969S6R=S=6UM87)Y7V%L87)M
M<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G;&]C:V5D)R`]
M/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^
M("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4VAO=R!O;FQY(&5V96YT
M<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/R(I"BD["@HO+R!S:&]W(&1U92!T
M87-K<R!I;B!T:&4@8V%L96YD87(@=FEE=W,_"B1?<')E9G-;)W-H;W=?=&%S
M:W,G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@
M/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]
M/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(E-H;W<@9'5E('1A<VMS
M(&EN('1H92!C86QE;F1A<C\B*0HI.PH*+R\@<VAO=R!T87-K(&-O;&]R<S\*
M)%]P<F5F<ULG<VAO=U]T87-K7V-O;&]R<R==(#T@87)R87DH"B`@("`G=F%L
M=64G(#T^(#$L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S
M8R<@/3X@7R@B4VAO=R!T87-K<R!U<VEN9R!C871E9V]R>2!C;VQO<G,_(BD*
M*3L*"B\O(&1E9F%U;'0@8V%L96YD87(@<V5L96-T:6]N('=I9&=E=`HD7W!R
M969S6R=S:&%R97-E;&5C="==(#T@87)R87DH)W1Y<&4G(#T^("=S<&5C:6%L
M)RD["@HO+R!S=&]R92!T:&4@8V%L96YD87)S('1O(&1I<&QA>0HD7W!R969S
M6R=D:7-P;&%Y7V-A;',G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G83HP
M.GM])RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@
M9F%L<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@9&5F875L
M="!C86QE;F1A<@HO+R!3970@;&]C:V5D('1O('1R=64@:68@>6]U(&1O;B=T
M('=A;G0@=7-E<G,@=&\@:&%V92!M=6QT:7!L92!C86QE;F1A<G,N"B1?<')E
M9G-;)V1E9F%U;'1?<VAA<F4G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!!
M=71H.CIG971!=71H*"D@/R!!=71H.CIG971!=71H*"D@.B`P+`H@("`@)VQO
M8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T
M>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO+R!M86YA9V4@<F5M;W1E(&-A;&5N
M9&%R<PHD7W!R969S6R=R96UO=&5?8V%L7VUA;F%G96UE;G0G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@
M("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)W-P96-I86PG
M+`H@("`@)V1E<V,G(#T^(%\H(D5D:70@4F5M;W1E($-A;&5N9&%R<R(I"BD[
M"@HO+R!S=&]R92!T:&4@<F5M;W1E(&-A;&5N9&%R<R!T;R!D:7-P;&%Y"B1?
M<')E9G-;)W)E;6]T95]C86QS)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)V$Z,#I[?2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O('-T
M;W)E('1H92!R96UO=&4@8V%L96YD87)S('1O(&1I<W!L87D*)%]P<F5F<ULG
M9&ES<&QA>5]R96UO=&5?8V%L<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M("=A.C`Z>WTG+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO+R!N
M97<@979E;G0@;F]T:69I8V%T:6]N<PHD7W!R969S6R=E=F5N=%]N;W1I9FEC
M871I;VXG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP
M92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y*"<G(#T^(%\H(DYO
M(BDL"B`@("`@("`@("`@("`@("`@("`@)V]W;F5R)R`]/B!?*")/;B!M>2!C
M86QE;F1A<G,@;VYL>2(I+`H@("`@("`@("`@("`@("`@("`@("=S:&]W)R`]
M/B!?*")/;B!A;&P@<VAO=VX@8V%L96YD87)S(BDL"B`@("`@("`@("`@("`@
M("`@("`@)W)E860G(#T^(%\H(D]N(&%L;"!C86QE;F1A<G,@22!H879E(')E
M860@86-C97-S('1O(BDI+`H@("`@)V1E<V,G(#T^(%\H(D-H;V]S92!I9B!Y
M;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E
M;&5T960@979E;G1S(&)Y(&5M86EL.B(I"BD["@HO+R!R96UI;F1E<B!N;W1I
M9FEC871I;VYS"B1?<')E9G-;)V5V96YT7W)E;6EN9&5R)UT@/2!A<G)A>2@*
M("`@("=V86QU92<@/3X@)V]W;F5R)RP*("`@("=L;V-K960G(#T^(&9A;'-E
M+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V5N=6TG
M+`H@("`@)V5N=6TG(#T^(&%R<F%Y*"<G(#T^(%\H(DYO(BDL"B`@("`@("`@
M("`@("`@("`@("`@)V]W;F5R)R`]/B!?*")/;B!M>2!C86QE;F1A<G,@;VYL
M>2(I+`H@("`@("`@("`@("`@("`@("`@("=S:&]W)R`]/B!?*")/;B!A;&P@
M<VAO=VX@8V%L96YD87)S(BDL"B`@("`@("`@("`@("`@("`@("`@)W)E860G
M(#T^(%\H(D]N(&%L;"!C86QE;F1A<G,@22!H879E(')E860@86-C97-S('1O
M(BDI+`H@("`@)V1E<V,G(#T^(%\H(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!R
M96-E:79E(&5M86EL(')E;6EN9&5R<R!F;W(@979E;G1S('=I=&@@86QA<FUS
M.B(I"BD["@HO+R!N=6UB97(@;V8@9&%Y<R!T;R!G96YE<F%T92!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@9F]R.@HD7W!R969S6R=F<F5E8G5S>5]D87ES)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@,S`L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=N
M=6UB97(G+`H@("`@)V1E<V,G(#T^(%\H(DAO=R!M86YY(&1A>7,@;V8@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N('-H;W5L9"!W92!G96YE<F%T93\B*0HI.PH*
M+R\@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS
M+@HD7W!R969S6R=S96%R8VA?86)O;VLG72`](&%R<F%Y*`H@("`@+R\@268@
M>6]U('=A;G0@=&AE(&QO8V%L<W%L(&%D9')E<W,@8F]O:R!T;R!B92!T:&4@
M9&5F875L="P@=7-E.@H@("`@+R\@)W9A;'5E)R`]/B`G83HQ.GMI.C`[<SHX
M.B)L;V-A;'-Q;"([?2<L"B`@("`G=F%L=64G(#T^("=A.C`Z>WTG+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@
M("=T>7!E)R`]/B`G:6UP;&EC:70G+`H@("`@)V1E<V,G(#T^(%\H(D-H;V]S
M92!T:&4@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!5
M4DQS.B(I"BD["@HO+R!A9&1R97-S(&)O;VMS('-E;&5C=&]R+@HD7W!R969S
M6R=S96%R8VA?86)O;VM?<V5L96-T)UT@/2!A<G)A>2@G='EP92<@/3X@)W-P
M96-I86PG*3L*"B\O($-A;&5N9&%R<R!T;R!I;F-L=61E(&EN(&=E;F5R871I
M;F<@9G)E92]B=7-Y(%523',N"B1?<')E9G-;)V9B7V-A;',G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B`G83HP.GM])RP*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM
M<&QI8VET)RP*("`@("=D97-C)R`]/B!?*")#:&]O<V4@=&AE(&-A;&5N9&%R
M<R!T;R!I;F-L=61E('=H96X@9V5N97)A=&EN9R!F<F5E+V)U<WD@55),<SHB
M*0HI.PH*+R\@1G)E92]B=7-Y(&-A;&5N9&%R<R!S96QE8W1O<BX*)%]P<F5F
M<ULG9F)?8V%L<U]S96QE8W0G72`](&%R<F%Y*"=T>7!E)R`]/B`G<W!E8VEA
M;"<I.PH*+R\@5&AE(&9O;&QO=VEN9R!T=V\@<')E9F5R96YC97,@87)E(&YO
M(&QO;F=E<B!U<V5D(&%N9"!O;FQY(&YE8V5S<V%R>2!F;W(@=&AE"B\O('5P
M9W)A9&4@<V-R:7!T+@HD7W!R969S6R=E=F5N=%]C871E9V]R:65S)UT@/2!A
M<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS
M92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L
M:6-I="<**3L*)%]P<F5F<ULG979E;G1?8V]L;W)S)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S
M:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]C;VYF+G!H<```````````````````````````````````
M```````````````````````````````````P,3`P-#0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,30V,0`Q,#0Q-S,V,C<T,P`P,C`V-#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@0T].
M1DE'(%-405)4+B!$3R!.3U0@0TA!3D=%($%.651(24Y'($E.($]2($%&5$52
M(%1(25,@3$E.12X@*B\*+R\@)$AO<F1E.B!K<F]N;VQI=&@O8V]N9FEG+V-O
M;F8N>&UL+'8@,2XQ-"XQ,"XT(#(P,#8O,#(O,#@@,3(Z,C<Z,S$@:F%N($5X
M<"`D"B1C;VYF6R=C86QE;F1A<B==6R=P87)A;7,G75LG=&%B;&4G72`]("=K
M<F]N;VQI=&A?979E;G1S)SL*)&-O;F9;)V-A;&5N9&%R)UU;)W!A<F%M<R==
M6R=D<FEV97)C;VYF:6<G72`]("=H;W)D92<["B1C;VYF6R=C86QE;F1A<B==
M6R=D<FEV97(G72`]("=S<6PG.PHD8V]N9ELG<W1O<F%G92==6R=P87)A;7,G
M75LG=&%B;&4G72`]("=K<F]N;VQI=&A?<W1O<F%G92<["B1C;VYF6R=S=&]R
M86=E)UU;)W!A<F%M<R==6R=D<FEV97)C;VYF:6<G72`]("=H;W)D92<["B1C
M;VYF6R=S=&]R86=E)UU;)V1R:79E<B==(#T@)W-Q;"<["B1C;VYF6R=M971A
M9&%T82==6R=K97EW;W)D<R==(#T@9F%L<V4["B1C;VYF6R=R96UI;F1E<B==
M6R=S97)V97)?;F%M92==(#T@)VQO8V%L:&]S="<["B1C;VYF6R=R96UI;F1E
M<B==6R=F<F]M7V%D9'(G72`]("=R;V]T)SL*)&-O;F9;)V%U=&]S:&%R92==
M6R=S:&%R97!E<FUS)UT@/2`G;F]N92<["B1C;VYF6R=M96YU)UU;)W!R:6YT
M)UT@/2!F86QS93L*)&-O;F9;)VUE;G4G75LG:6UP;W)T7V5X<&]R="==(#T@
M=')U93L*)&-O;F9;)VUE;G4G75LG87!P<R==(#T@87)R87DH)VEM<"<L("=I
M;F=O)RP@)VMR;VYO;&ET:"<I.PHO*B!#3TY&24<@14Y$+B!$3R!.3U0@0TA!
M3D=%($%.651(24Y'($E.($]2($)%1D]212!42$E3($Q)3D4N("HO"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A
M+6AO<F1E+VMR;VYO;&ET:"]C;VYF+GAM;```````````````````````````
M```````````````````````````````````````````P,3`P-#0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-C0Q-0`Q,#0Q-S,V,C<T,P`P,C`V-3<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]X;6P@
M=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!K<F]N;VQI=&@O8V]N9FEG
M+V-O;F8N>&UL+'8@,2XQ-"XQ,"XT(#(P,#8O,#(O,#@@,3(Z,C<Z,S$@:F%N
M($5X<"`D("TM/@H\8V]N9FEG=7)A=&EO;CX*(#QC;VYF:6=S96-T:6]N(&YA
M;64](F-A;&5N9&%R(CX*("`\8V]N9FEG:&5A9&5R/D-A;&5N9&%R($1R:79E
M<B!3971T:6YG<SPO8V]N9FEG:&5A9&5R/@H*("`\8V]N9FEG<W=I=&-H(&YA
M;64](F1R:79E<B(@9&5S8STB5VAA="!S=&]R86=E(&1R:79E<B!S:&]U;&0@
M=V4@=7-E/R(^<W%L"B`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB4U%,(CX*
M("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@/&-O;F9I
M9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](G1A8FQE(B!D97-C/2)$871A8F%S90H@("`@("`@=&%B
M;&4B/FMR;VYO;&ET:%]E=F5N=',\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O
M;F9I9W-Q;#X*("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@/"]C87-E/@H*("`@
M/&-A<V4@;F%M93TB:V]L86(B(&1E<V,](DMO;&%B(B`O/@H@(#PO8V]N9FEG
M<W=I=&-H/@H@/"]C;VYF:6=S96-T:6]N/@H*(#QC;VYF:6=S96-T:6]N(&YA
M;64](G-T;W)A9V4B/@H@(#QC;VYF:6=H96%D97(^1G)E92]"=7-Y($1R:79E
M<B!3971T:6YG<SPO8V]N9FEG:&5A9&5R/@H*("`\8V]N9FEG<W1R:6YG(&YA
M;64](F1E9F%U;'1?9&]M86EN(B!D97-C/2)$969A=6QT(&1O;6%I;B!T;R!A
M9&0@=&\@871T96YD964@96UA:6P@861D<F5S<V5S(&EF(&YO;F4@:7,@<W!E
M8VEF:65D+B(@<F5Q=6ER960](F9A;'-E(B`O/@H*("`\8V]N9FEG<W=I=&-H
M(&YA;64](F1R:79E<B(@9&5S8STB5VAA="!F<F5E+V)U<WD@9')I=F5R('-H
M;W5L9"!W92!U<V4_(CYS<6P*("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)3
M44PB/@H@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`\
M8V]N9FEG<W%L('-W:71C:&YA;64](F1R:79E<F-O;F9I9R(^"B`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(&1E<V,](D1A=&%B87-E"B`@("`@
M("!T86)L92(^:W)O;F]L:71H7W-T;W)A9V4\+V-O;F9I9W-T<FEN9SX*("`@
M("`\+V-O;F9I9W-Q;#X*("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@/"]C87-E
M/@H*("`@/&-A<V4@;F%M93TB:V]L86(B(&1E<V,](DMO;&%B(CX*("`@(#QC
M;VYF:6=S96-T:6]N(&YA;64](F9R965B=7-Y(CX*("`@("`\8V]N9FEG96YU
M;2!N86UE/2)P<F]T;V-O;"(@9&5S8STB4')O=&]C;VP@=&\@=7-E(&9O<B!A
M8V-E<W-I;F<@=&AE"B`@("`@2V]L86(@<V5R=F5R)W,@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N(CX*("`@("`@/'9A;'5E<SX*("`@("`@(#QV86QU93YH='1P
M<SPO=F%L=64^"B`@("`@("`\=F%L=64^:'1T<#PO=F%L=64^"B`@("`@(#PO
M=F%L=65S/@H@("`@(#PO8V]N9FEG96YU;3X*("`@("`\8V]N9FEG:6YT96=E
M<B!N86UE/2)P;W)T(B!D97-C/2)0;W)T('1O('5S92!F;W(@86-C97-S:6YG
M('1H90H@("`@($MO;&%B('-E<G9E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B(^-#0S/"]C;VYF:6=I;G1E9V5R/@H@("`@/"]C;VYF:6=S96-T:6]N/@H@
M("`\+V-A<V4^"B`@/"]C;VYF:6=S=VET8V@^"B`\+V-O;F9I9W-E8W1I;VX^
M"@H@/&-O;F9I9W-E8W1I;VX@;F%M93TB;65T861A=&$B/@H@(#QC;VYF:6=H
M96%D97(^365T861A=&$@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`\8V]N
M9FEG8F]O;&5A;B!N86UE/2)K97EW;W)D<R(@9&5S8STB4VAO=6QD(&ME>7=O
M<F1S(&)E(&QO861E9"!F<F]M"B`@(&-O;F9I9R]K97EW;W)D<RYP:'`@=&\@
M8F4@87-S:6=N960@=&\@979E;G1S/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^
M"B`\+V-O;F9I9W-E8W1I;VX^"@H@/&-O;F9I9W-E8W1I;VX@;F%M93TB<F5M
M:6YD97(B/@H@(#QC;VYF:6=H96%D97(^4F5M:6YD97(@4V5T=&EN9W,\+V-O
M;F9I9VAE861E<CX*("`\8V]N9FEG<W1R:6YG(&YA;64](G-E<G9E<E]N86UE
M(B!D97-C/2)397)V97(@;F%M92!F<F]M('=H:6-H(')E;6EN9&5R"B`@(&5M
M86EL<R!S:&]U;&0@8F4@<V5N="(O/@H@(#QC;VYF:6=S=')I;F<@;F%M93TB
M9G)O;5]A9&1R(B!D97-C/2)%;6%I;"!A9&1R97-S(&9R;VT@=VAI8V@@<F5M
M:6YD97(*("`@96UA:6QS('-H;W5L9"!B92!S96YT(B\^"B`\+V-O;F9I9W-E
M8W1I;VX^"@H@/&-O;F9I9W-E8W1I;VX@;F%M93TB875T;W-H87)E(CX*("`@
M/&-O;F9I9VAE861E<CY#86QE;F1A<B!A=71O+7-H87)I;F<\+V-O;F9I9VAE
M861E<CX*("`@("`\8V]N9FEG96YU;2!N86UE/2)S:&%R97!E<FUS(B!D97-C
M/2)7:&5N(&$@;F5W('5S97(@:7,@8W)E871E9"P@:&ES"B`@("`@9&5F875L
M="!C86QE;F1A<B!C86X@8F4@875T;VUA=&EC86QL>2!S:&%R960@=VET:"!H
M:7,@9W)O=7`H<RDN(%=H:6-H"B`@("`@<&5R;6ES<VEO;G,@<VAO=6QD('1H
M92!G<F]U<"!H879E/R(^"B`@("`@("`\=F%L=65S/@H@("`@("`@("`\=F%L
M=64@9&5S8STB3F]N92`H;F\@<VAA<FEN9RDB/FYO;F4\+W9A;'5E/@H@("`@
M("`@("`\=F%L=64@9&5S8STB4F5A9"UO;FQY(CYR96%D/"]V86QU93X*("`@
M("`@("`@/'9A;'5E(&1E<V,](E)E860@86YD('=R:71E(CYE9&ET/"]V86QU
M93X*("`@("`@("`@/'9A;'5E(&1E<V,](E)E860L('=R:71E(&%N9"!D96QE
M=&4B/F9U;&P\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@/"]C;VYF
M:6=E;G5M/@H@/"]C;VYF:6=S96-T:6]N/@H*(#QC;VYF:6=S96-T:6]N(&YA
M;64](FUE;G4B/@H@(#QC;VYF:6=H96%D97(^365N=2!3971T:6YG<SPO8V]N
M9FEG:&5A9&5R/@H@(#QC;VYF:6=B;V]L96%N(&YA;64](G!R:6YT(B!D97-C
M/2)3:&]U;&0@=V4@9&ES<&QA>2!A(%!R:6YT(&QI;FL@:6X@=&AE"B`@($MR
M;VYO;&ET:"!M96YU/R(^=')U93PO8V]N9FEG8F]O;&5A;CX*("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)I;7!O<G1?97AP;W)T(B!D97-C/2)3:&]U;&0@=V4@
M9&ES<&QA>2!A;B!);7!O<G0O17AP;W)T"B`@(&QI;FL@:6X@=&AE($AO<F1E
M(&%P<&QI8V%T:6]N(&UE;G5S/R(^=')U93PO8V]N9FEG8F]O;&5A;CX*("`\
M8V]N9FEG;75L=&EE;G5M(&YA;64](F%P<',B(&1E<V,](E-E;&5C="!A;GD@
M87!P;&EC871I;VYS('1H870@<VAO=6QD(&)E"B`@(&QI;FME9"!I;B!+<F]N
M;VQI=&@G<R!M96YU(CX*("`@/'9A;'5E<SX*("`@(#QC;VYF:6=S<&5C:6%L
M(&YA;64](FQI<W0M:&]R9&4M87!P<R(O/@H@("`\+W9A;'5E<SX*("`\+V-O
M;F9I9VUU;'1I96YU;3X*(#PO8V]N9FEG<V5C=&EO;CX*/"]C;VYF:6=U<F%T
M:6]N/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O971C+W!S
M82UH;W)D92]K<F]N;VQI=&@O+FAT86-C97-S````````````````````````
M````````````````````````````````````````````,#$P,#0T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S-C(W-#,`,#(P-S<U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$1E;GD@
M9G)O;2!A;&P*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:6UP
M+P``````````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S`#`Q-3<V,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M971C+W!S82UH;W)D92]I;7`O+FAT86-C97-S````````````````````````
M````````````````````````````````````````````````````,#$P,#0T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S-C(W-#,`,#$W
M-34Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$1E;GD@9G)O;2!A;&P*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R
M9&4O:6UP+VUE;G4N<&AP````````````````````````````````````````
M`````````````````````````````````````#`Q,#`T-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-#4R`#$P-#$W,S8R-S0S`#`Q-S0S-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!I;7`O8V]N9FEG+VUE;G4N<&AP+F1I<W0L=B`Q+C4@,C`P
M-"\Q,2\P-B`Q.#HT-SHQ-2!J86X@17AP("0*("H*("H@5&AI<R!F:6QE(&QE
M=',@>6]U(&5X=&5N9"!)35`G<R!M96YU('=I=&@@>6]U<B!O=VX@:71E;7,N
M"B`J"B`J(%1O(&%D9"!A(&YE=R!M96YU(&ET96TL('-I;7!L>2!A9&0@82!N
M97<@96YT<GD@=&\@=&AE("1?;65N=2!A<G)A>2X*("H@5F%L:60@871T<FEB
M=71E<R!F;W(@82!N97<@;65N=2!I=&5M(&%R93H*("H*("H@("=U<FPG("`@
M("`@(%1H92!54DP@=F%L=64@9F]R('1H92!M96YU(&ET96TN"B`J("`G=&5X
M="<@("`@("!4:&4@=&5X="!T;R!A8V-O;7!A;GD@=&AE(&UE;G4@:71E;2X*
M("H*("H@5&AE<V4@871T<FEB=71E<R!A<F4@;W!T:6]N86PZ"B`J"B`J("`G
M:6-O;B<@("`@("!4:&4@9FEL96YA;64@;V8@86X@:6-O;B!T;R!U<V4@9F]R
M('1H92!M96YU(&ET96TN"B`J("`G:6-O;E]P871H)R!4:&4@<&%T:"!T;R!T
M:&4@:6-O;B!I9B!I="!D;V5S;B=T(&5X:7-T(&EN('1H92!G<F%P:&EC<R\*
M("H@("`@("`@("`@("`@(&1I<F5C=&]R>2X*("H@("=T87)G970G("`@(%1H
M92`B=&%R9V5T(B!O9B!T:&4@;&EN:R`H92YG+B`G7W1O<"<L("=?8FQA;FLG
M*2X*("H@("=O;F-L:6-K)R`@($%N>2!*879A4V-R:7!T('1O(&5X96-U=&4@
M;VX@=&AE(")O;F-L:6-K(B!E=F5N="X*("H*("H@2&5R92=S(&%N(&5X86UP
M;&4@96YT<GDZ"B`J"B`J("`D7VUE;G5;72`](&%R<F%Y*"`@(`H@*B`@("`@
M("=U<FPG(#T^("`@("`@("`G:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2\G+`H@
M*B`@("`@("=T97AT)R`]/B`@("`@("`G17AA;7!L92P@26YC+B<L"B`J("`@
M("`@)VEC;VXG(#T^("`@("`@("=E>&%M<&QE+G!N9R<L"B`J("`@("`@)VEC
M;VY?<&%T:"<@/3X@("=H='1P.B\O=W=W+F5X86UP;&4N8V]M+VEM86=E<R\G
M+`H@*B`@("`@("=T87)G970G(#T^("`@("`G7V)L86YK)RP*("H@("`@("`G
M;VYC;&EC:R<@/3X@("`@)R<*("H@("D["B`J"B`J(%EO=2!C86X@86QS;R!A
M9&0@82`B<V5P87)A=&]R(B`H82!S<&%C97(I(&)E='=E96X@;65N=2!I=&5M
M<RX@(%1O(&%D9"!A"B`J('-E<&%R871O<BP@<VEM<&QY(&%D9"!A(&YE=R!S
M=')I;F<@=&\@=&AE("1?;65N=2!A<G)A>2!S970@=&\@=&AE('1E>'0*("H@
M)W-E<&%R871O<B<N("!)="!S:&]U;&0@;&]O:R!L:6ME('1H:7,Z"B`J"B`J
M("`D7VUE;G5;72`]("=S97!A<F%T;W(G.PH@*B\*"B1?;65N=2`](&%R<F%Y
M*"D["@HO*B!!9&0@>6]U<B!C=7-T;VT@96YT<FEE<R!B96QO=R!T:&ES(&QI
M;F4N("HO"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]I;7`O;6EM95]D<FEV97)S+G!H
M<```````````````````````````````````````````````````````````
M````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30V,#``,3`T
M,3<S-C(W-#,`,#(Q,34U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EM<"]C;VYF:6<O
M;6EM95]D<FEV97)S+G!H<"YD:7-T+'8@,2XS-2XQ,"XR(#(P,#4O,3`O,3@@
M,3(Z,3,Z,CD@:F%N($5X<"`D"B`J"B`J($1E8VED92!W:&EC:"!O=71P=70@
M9')I=F5R<R!Y;W4@=V%N="!T;R!A8W1I=F%T92!F;W(@=&AE($E-4"!A<'!L
M:6-A=&EO;BX*("H@4V5T=&EN9W,@:6X@=&AI<R!F:6QE(&]V97)R:61E('-E
M='1I;F=S(&EN(&AO<F1E+V-O;F9I9R]M:6UE7V1R:79E<G,N<&AP+@H@*@H@
M*B!4:&4@879A:6QA8FQE(&1R:79E<G,@87)E.@H@*B`M+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0H@*B!A;'1E<FYA=&EV92`@("!M=6QT:7!A<G0O86QT
M97)N871I=F4@<&%R=',*("H@87!P;&5D;W5B;&4@("`@;75L=&EP87)T+V%P
M<&QE9&]U8FQE('!A<G1S"B`J(&5N<FEC:&5D("`@("`@($5N<FEC:&5D('1E
M>'0@;65S<V%G97,*("H@:'1M;"`@("`@("`@("`@2%1-3"!M97-S86=E<PH@
M*B!I;6%G97,@("`@("`@("!!='1A8VAE9"!I;6%G97,@:6YL:6YE"B`J(&ET
M:7`@("`@("`@("`@(&E#86QE;F1A<B!4<F%N<W!O<G0M26YD97!E;F1E;G0@
M26YT97)O<&5R86)I;&ET>2!0<F]T;V-O;`H@*B!M=6QT:7!A<G0@("`@("!!
M;&P@;W1H97(@;75L=&EP87)T+RH@;65S<V%G97,*("H@;F]T:69I8V%T:6]N
M("`@3F]T:69I8V%T:6]N(&UE<W-A9V5S"B`J('!A<G1I86P@("`@("`@(&UE
M<W-A9V4O<&%R=&EA;"!P87)T<PH@*B!P9W`@("`@("`@("`@("!01U`@<VEG
M;F5D+V5N8W)Y<'1E9"!M97-S86=E<PH@*B!P:V-S-R`@("`@("`@("!3+TU)
M344@<VEG;F5D+V5N8W)Y<'1E9"!M97-S86=E<PH@*B!P;&%I;B`@("`@("`@
M("!54DP@<WEN=&%X(&AI9VAL:6=H=&EN9R!F;W(@=&5X="]P;&%I;B!P87)T
M<R`*("H@<F5L871E9"`@("`@("`@;75L=&EP87)T+W)E;&%T960@<&%R=',*
M("H@<F9C.#(R("`@("`@("`@1&EG97-T960@;65S<V%G97,*("H@<W1A='5S
M("`@("`@("`@36%I;"!D96QI=F5R>2!S=&%T=7,@;65S<V%G97,*("H@=&YE
M9B`@("`@("`@("`@35,M5$Y%1B!A='1A8VAM96YT<PH@*B!Z:7`@("`@("`@
M("`@("!:25`@871T86-H;65N=',*("HO"B1M:6UE7V1R:79E<G-?;6%P6R=I
M;7`G75LG<F5G:7-T97)E9"==(#T@87)R87DH"B`@("`G86QT97)N871I=F4G
M+"`G87!P;&5D;W5B;&4G+"`G96YR:6-H960G+"`G:'1M;"<L("=I;6%G97,G
M+"`G:71I<"<L"B`@("`G;75L=&EP87)T)RP@)VYO=&EF:6-A=&EO;B<L("=P
M87)T:6%L)RP@)W!G<"<L("=P:V-S-R<L("=P;&%I;B<L"B`@("`G<F5L871E
M9"<L("=R9F,X,C(G+"`G<W1A='5S)RP@)W1N968G+"`G>FEP)RD["@HO*BH*
M("H@268@>6]U('=A;G0@=&\@<W!E8VEF:6-A;&QY(&]V97)R:61E(&%N>2!-
M24U%('1Y<&4@=&\@8F4@:&%N9&QE9"!B>0H@*B!A('-P96-I9FEC(&1R:79E
M<BP@=&AE;B!E;G1E<B!I="!H97)E+B`@3F]R;6%L;'DL('1H:7,@:7,@<V%F
M92!T;PH@*B!L96%V92P@8G5T(&ET)W,@=7-E9G5L('=H96X@;75L=&EP;&4@
M9')I=F5R<R!H86YD;&4@=&AE('-A;64@34E-10H@*B!T>7!E+"!A;F0@>6]U
M('=A;G0@=&\@<W!E8VEF>2!E>&%C=&QY('=H:6-H(&]N92!S:&]U;&0@:&%N
M9&QE(&ET+@H@*B\*)&UI;65?9')I=F5R<U]M87!;)VEM<"==6R=O=F5R<FED
M97,G72`](&%R<F%Y*"D["@HO*BH*("H@1')I=F5R('-P96-I9FEC('-E='1I
M;F=S+B!3964@:&]R9&4O8V]N9FEG+VUI;65?9')I=F5R<RYP:'`@9F]R"B`J
M('1H92!F;W)M870N"B`J+PH*+RHJ"B`J(%1E>'0@9')I=F5R('-E='1I;F=S
M"B`J+PHD;6EM95]D<FEV97)S6R=I;7`G75LG<&QA:6XG75LG:6YL:6YE)UT@
M/2!T<G5E.PHD;6EM95]D<FEV97)S6R=I;7`G75LG<&QA:6XG75LG:&%N9&QE
M<R==(#T@87)R87DH"B`@("`G=&5X="]P;&%I;B<L("=T97AT+W)F8S@R,BUH
M96%D97)S)RP@)V%P<&QI8V%T:6]N+W!G<"<I.PHO*B!)9B!Y;W4@=V%N="!T
M;R!S8V%N($%,3"!I;F-O;6EN9R!M97-S86=E<R!F;W(@555E;F-O9&5D(&1A
M=&$L('-E=`H@("!T:&4@9F]L;&]W:6YG('1O('1R=64N("HO"B1M:6UE7V1R
M:79E<G-;)VEM<"==6R=P;&%I;B==6R=U=65N8V]D92==(#T@9F%L<V4["@HO
M*BH*("H@2%1-3"!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;
M)VEM<"==6R=H=&UL)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R
M<ULG:6UP)UU;)VAT;6PG75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G=&5X
M="]H=&UL)RD["B1M:6UE7V1R:79E<G-;)VEM<"==6R=H=&UL)UU;)VEC;VYS
M)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G:'1M;"YP;F<G*3L*+RH@
M268@>6]U(&1O;B=T('=A;G0@=&\@9&ES<&QA>2!T:&4@;&EN:R!T;R!O<&5N
M('1H92!(5$U,(&-O;G1E;G0@:6X@80H@*B!S97!A<F%T92!W:6YD;W<L('-E
M="!T:&4@9F]L;&]W:6YG('1O(&9A;'-E+B`J+PHD;6EM95]D<FEV97)S6R=I
M;7`G75LG:'1M;"==6R=E>'1E<FYA;"==(#T@=')U93L*"B\J*@H@*B!);6%G
M92!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VEM<"==6R=I
M;6%G97,G75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV97)S6R=I;7`G
M75LG:6UA9V5S)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)VEM86=E+RHG
M*3L*)&UI;65?9')I=F5R<ULG:6UP)UU;)VEM86=E<R==6R=I8V]N<R==(#T@
M87)R87DH"B`@("`G9&5F875L="<@/3X@)VEM86=E+G!N9R<I.PH*+RHJ"B`J
M($5N<FEC:&5D('1E>'0@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV
M97)S6R=I;7`G75LG96YR:6-H960G75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM
M95]D<FEV97)S6R=I;7`G75LG96YR:6-H960G75LG:&%N9&QE<R==(#T@87)R
M87DH"B`@("`G=&5X="]E;G)I8VAE9"<I.PHD;6EM95]D<FEV97)S6R=I;7`G
M75LG96YR:6-H960G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G
M(#T^("=T97AT+G!N9R<I.PH*+RHJ"B`J(%!'4"!S971T:6YG<PH@*B\*)&UI
M;65?9')I=F5R<ULG:6UP)UU;)W!G<"==6R=I;FQI;F4G72`]('1R=64["B1M
M:6UE7V1R:79E<G-;)VEM<"==6R=P9W`G75LG:6-O;G,G72`](&%R<F%Y*`H@
M("`@)V1E9F%U;'0G(#T^("=E;F-R>7!T:6]N+G!N9R<@*3L*)&UI;65?9')I
M=F5R<ULG:6UP)UU;)W!G<"==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A
M<'!L:6-A=&EO;B]P9W`M96YC<GEP=&5D)RP@)V%P<&QI8V%T:6]N+W!G<"UK
M97ES)RP@)V%P<&QI8V%T:6]N+W!G<"US:6=N871U<F4G*3L*"B\J*@H@*B!0
M2T-3-R!S971T:6YG<R`H4R]-24U%*0H@*B\*)&UI;65?9')I=F5R<ULG:6UP
M)UU;)W!K8W,W)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG
M:6UP)UU;)W!K8W,W)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT
M)R`]/B`G96YC<GEP=&EO;BYP;F<G("D["B1M:6UE7V1R:79E<G-;)VEM<"==
M6R=P:V-S-R==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO
M;B]X+7!K8W,W+7-I9VYA='5R92<L("=A<'!L:6-A=&EO;B]X+7!K8W,W+6UI
M;64G+`H@("`@)V%P<&QI8V%T:6]N+W!K8W,W+7-I9VYA='5R92<L("=A<'!L
M:6-A=&EO;B]P:V-S-RUM:6UE)RD["@HO*BH*("H@1&EG97-T(&UE<W-A9V4@
M*&UE<W-A9V4O<F9C.#(R*2!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG
M:6UP)UU;)W)F8S@R,B==6R=I;FQI;F4G72`](&9A;'-E.PHD;6EM95]D<FEV
M97)S6R=I;7`G75LG<F9C.#(R)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)VUE<W-A9V4O<F9C.#(R)RD["B1M:6UE7V1R:79E<G-;)VEM<"==6R=R9F,X
M,C(G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=M86EL
M+G!N9R<I.PH*+RHJ"B`J(%II<"!&:6QE($%T=&%C:&UE;G1S('-E='1I;F=S
M"B`J+PHD;6EM95]D<FEV97)S6R=I;7`G75LG>FEP)UU;)VEN;&EN92==(#T@
M9F%L<V4["B1M:6UE7V1R:79E<G-;)VEM<"==6R=Z:7`G75LG:&%N9&QE<R==
M(#T@87)R87DH"B`@("`G>"UE>'1E;G-I;VXO>FEP)RP*("`@("=A<'!L:6-A
M=&EO;B]X+6-O;7!R97-S960G+`H@("`@)V%P<&QI8V%T:6]N+W@M>FEP+6-O
M;7!R97-S960G*3L*)&UI;65?9')I=F5R<ULG:6UP)UU;)WII<"==6R=I8V]N
M<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)V-O;7!R97-S960N<&YG
M)RD["@HO*BH*("H@1&5L:79E<GD@4W1A='5S(&UE<W-A9V5S('-E='1I;F=S
M"B`J+PHD;6EM95]D<FEV97)S6R=I;7`G75LG<W1A='5S)UU;)VEN;&EN92==
M(#T@=')U93L*)&UI;65?9')I=F5R<ULG:6UP)UU;)W-T871U<R==6R=H86YD
M;&5S)UT@/2!A<G)A>2@*("`@("=M97-S86=E+V1E;&EV97)Y+7-T871U<R<I
M.PH*+RHJ"B`J($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B!M97-S86=E('-E
M='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=I;7`G75LG;F]T:69I8V%T:6]N
M)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:6UP)UU;)VYO
M=&EF:6-A=&EO;B==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=M97-S86=E
M+V1I<W!O<VET:6]N+6YO=&EF:6-A=&EO;B<I.PH*+RHJ"B`J(&UU;'1I<&%R
M="]A<'!L961O=6)L92!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:6UP
M)UU;)V%P<&QE9&]U8FQE)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I
M=F5R<ULG:6UP)UU;)V%P<&QE9&]U8FQE)UU;)VAA;F1L97,G72`](&%R<F%Y
M*`H@("`@)VUU;'1I<&%R="]A<'!L961O=6)L92<I.PH*+RHJ"B`J(&E#86QE
M;F1A<B!4<F%N<W!O<G0M26YD97!E;F1E;G0@26YT97)O<&5R86)I;&ET>2!0
M<F]T;V-O;`H@*B\*)&UI;65?9')I=F5R<ULG:6UP)UU;)VET:7`G75LG:6YL
M:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV97)S6R=I;7`G75LG:71I<"==6R=H
M86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+V-A;&5N9&%R)RP*("`@("=T
M97AT+W@M=F-A;&5N9&%R)RP*("`@("=T97AT+W@M:6-A;&5N9&%R)RP*("`@
M("=X+65X=&5N<VEO;B]V8W,G+`H@("`@)W@M97AT96YS:6]N+VEC<R<I.PHD
M;6EM95]D<FEV97)S6R=I;7`G75LG:71I<"==6R=I8V]N<R==(#T@87)R87DH
M"B`@("`G9&5F875L="<@/3X@)VET:7`N<&YG)RD["@HO*BH*("H@;75L=&EP
M87)T+V%L=&5R;F%T:79E('-E='1I;F=S"B`J(%E/52!32$]53$0@3D]4($Y/
M4DU!3$Q9($%,5$52(%1(25,@4T545$E.1RX*("HO"B1M:6UE7V1R:79E<G-;
M)VEM<"==6R=A;'1E<FYA=&EV92==6R=I;FQI;F4G72`]('1R=64["B1M:6UE
M7V1R:79E<G-;)VEM<"==6R=A;'1E<FYA=&EV92==6R=H86YD;&5S)UT@/2!A
M<G)A>2@*("`@("=M=6QT:7!A<G0O86QT97)N871I=F4G*3L*+RH@268@>6]U
M(&1O;B=T('=A;G0@=&\@9&ES<&QA>2!T:&4@;&EN:R!T;R!S:&]W(&%L=&5R
M;F%T:79E(&UE<W-A9V4@<&%R=',L"B`J('-E="!T:&4@9F]L;&]W:6YG('1O
M(&9A;'-E+B`J+PHD;6EM95]D<FEV97)S6R=I;7`G75LG86QT97)N871I=F4G
M75LG<VAO=R==(#T@=')U93L*"B\J*@H@*B!M=6QT:7!A<G0O<F5L871E9"!S
M971T:6YG<PH@*B!93U4@4TA/54Q$($Y/5"!.3U)-04Q,62!!3%1%4B!42$E3
M(%-%5%1)3D<N"B`J+PHD;6EM95]D<FEV97)S6R=I;7`G75LG<F5L871E9"==
M6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VEM<"==6R=R96QA
M=&5D)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)VUU;'1I<&%R="]R96QA
M=&5D)RD["B1M:6UE7V1R:79E<G-;)VEM<"==6R=R96QA=&5D)UU;)VEC;VYS
M)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G:'1M;"YP;F<G*3L*"B\J
M*@H@*B!M97-S86=E+W!A<G1I86P@<V5T=&EN9W,*("H@64]5(%-(3U5,1"!.
M3U0@3D]234%,3%D@04Q415(@5$A)4R!3151424Y'+@H@*B\*)&UI;65?9')I
M=F5R<ULG:6UP)UU;)W!A<G1I86PG75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM
M95]D<FEV97)S6R=I;7`G75LG<&%R=&EA;"==6R=H86YD;&5S)UT@/2!A<G)A
M>2@*("`@("=M97-S86=E+W!A<G1I86PG*3L*"B\J*@H@*B!!;&P@;W1H97(@
M;75L=&EP87)T+RH@;65S<V%G97,*("H@64]5(%-(3U5,1"!.3U0@3D]234%,
M3%D@04Q415(@5$A)4R!3151424Y'+@H@*B\*)&UI;65?9')I=F5R<ULG:6UP
M)UU;)VUU;'1I<&%R="==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E
M<G-;)VEM<"==6R=M=6QT:7!A<G0G75LG:&%N9&QE<R==(#T@87)R87DH"B`@
M("`G;75L=&EP87)T+RHG*3L*"B\J*@H@*B!-4RU43D5&($%T=&%C:&UE;G0@
M*&%P<&QI8V%T:6]N+VUS+71N968I('-E='1I;F=S"B`J(%E/52!32$]53$0@
M3D]4($Y/4DU!3$Q9($%,5$52(%1(25,@4T545$E.1RX*("HO"B1M:6UE7V1R
M:79E<G-;)VEM<"==6R=T;F5F)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE
M7V1R:79E<G-;)VEM<"==6R=T;F5F)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@
M("`@)V%P<&QI8V%T:6]N+VUS+71N968G*3L*)&UI;65?9')I=F5R<ULG:6UP
M)UU;)W1N968G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^
M("=B:6YA<GDN<&YG)RD["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:6UP+VUO
M=&0N<&AP````````````````````````````````````````````````````
M`````````````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`S,3$Q`#$P-#$W,S8R-S0S`#`Q-S0R-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\(2TM(%1H:7,@9FEL92!C;VYT
M86EN<R!A;GD@(DUE<W-A9V4@3V8@5&AE($1A>2(@5'EP92!I;F9O<FUA=&EO
M;B`M+3X*/"$M+2!)="!W:6QL(&)E(&EN8VQU9&5D(&)E;&]W('1H92!L;V<M
M:6X@9F]R;2!O;B!T:&4@;&]G:6X@<&%G92X@+2T^"@H\/W!H<`HO*BH*("H@
M)$AO<F1E.B!I;7`O8V]N9FEG+VUO=&0N<&AP+F1I<W0L=B`Q+C@N-BXR(#(P
M,#4O,3`O,3@@,3(Z,3,Z,CD@:F%N($5X<"`D"B`J"B`J($5X86UP;&4@8V]D
M92!F;W(@<W=I=&-H:6YG(&)E='=E96X@2%144"!A;F0@2%144%,N"B`J($-O
M;G1R:6)U=&5D(&)Y.B!*86UE<R`\:F%M97-`:F%M97,M=V5B+FYE=#X*("H@
M5&\@=7-E+"!U;FYC;VUM96YT(&%N9"!M;V1I9GD@=&AE<V4@=F%R:6%B;&5S
M.@H@*@H@*B`D4T525D527U-33%]03U)4("T@4&]R="!O;B!W:&EC:"!Y;W5R
M(%-33"!S97)V97(@;&ES=&5N<R`H57-U86QL>2`T-#,I"B`J("1315)615)?
M2%144%]03U)4("T@4&]R="!O;B!W:&EC:"!Y;W5R($A45%`@<V5R=F5R(&QI
M<W1E;G,@*%5S=6%L;'D@.#`I"B`J("1315)615)?4U-,7U523"`M($9U;&P@
M55),('1O('EO=7(@2%144%,@<V5R=F5R(&%N9"!(;W)D92!D:7)E8W1O<GD*
M("H@)%-%4E9%4E](5%107U523"`M($9U;&P@55),('1O('EO=7(@2%144"!S
M97)V97(@86YD($AO<F1E(&1I<F5C=&]R>0H@*B\*"B\O("1315)615)?4U-,
M7U!/4E0@/2`T-#,["B\O("1315)615)?2%144%]03U)4(#T@.#`["B\O("13
M15)615)?4U-,7U523"`]("=H='1P<SHO+W=W=RYE>&%M<&QE+F-O;2<["B\O
M("1315)615)?2%144%]54DP@/2`G:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2<[
M"B\O(`HO+R`D<&]R="`]("1?4T525D526R=315)615)?4$]25"==.PHO+R`*
M+R\@96-H;R`G/&)R("\^/&1I=B!A;&EG;CTB8V5N=&5R(B!C;&%S<STB;&EG
M:'0B/B<["B\O(`HO+R!S=VET8V@@*"1P;W)T*2!["B\O("`@("!C87-E("13
M15)615)?4U-,7U!/4E0Z"B\O("`@("`@("`@96-H;R!?*")9;W4@87)E(&-U
M<G)E;G1L>2!U<VEN9R!396-U<F4@2%144%,\8G(@+SXB*3L*+R\@("`@("`@
M("!B<F5A:SL*+R\@"B\O("`@("!C87-E("1315)615)?2%144%]03U)4.@HO
M+R`@("`@("`@(&5C:&\@7R@B66]U(&%R92!C=7)R96YT;'D@=7-I;F<@4W1A
M;F1A<F0@2%144#QB<B`O/B(I.PHO+R`@("`@("`@(&)R96%K.PHO+R!]"B\O
M(`HO+R!E8VAO("<\82!C;&%S<STB<VUA;&PB(&AR968](B<@+B`D4T525D52
M7TA45%!?55),("X@)R(@=&%R9V5T/2)?<&%R96YT(CXG("X@7R@B0VQI8VL@
M:&5R92!F;W(@4W1A;F1A<F0@2%144"(I("X@)SPO83X@+2`\82!C;&%S<STB
M<VUA;&PB(&AR968](B<@+B`D4T525D527U-33%]54DP@+B`G(B!T87)G970]
M(E]P87)E;G0B/B<@+B!?*")#;&EC:R!H97)E(&9O<B!396-U<F4@2%144%,B
M*2`N("<\+V$^/"]D:78^)SL*"C\^"CQB<B`O/@H\=&%B;&4@=VED=&@](C$P
M,"4B/CQT<CX\=&0@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!(;W)D93HZ
M:6UG*"=H;W)D92UP;W=E<C$N<&YG)RP@7R@B4&]W97)E9"!B>2!(;W)D92(I
M+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX\+W1D
M/CPO='(^/"]T86)L93X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VEM<"]P<F5F<RYP
M:'``````````````````````````````````````````````````````````
M```````````````````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P
M-S8R,P`Q,#0Q-S,V,C<T,P`P,3<V,3<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:6UP
M+V-O;F9I9R]P<F5F<RYP:'`N9&ES="QV(#$N,C$V+C0N.2`R,#`V+S`Q+S(P
M(#`Q.C,P.C(V(&IA;B!%>'`@)`H@*@H@*B!3964@:&]R9&4O8V]N9FEG+W!R
M969S+G!H<"!F;W(@9&]C=6UE;G1A=&EO;B!O;B!T:&4@<W1R=6-T=7)E(&]F
M('1H:7,@9FEL92X*("HO"@HO+R!-86ME('-U<F4@=&AA="!C;VYS=&%N=',@
M87)E(&1E9FEN960N"D!D969I;F4H)TE-4%]"05-%)RP@)R]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`G*3L*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@
M)R]L:6(O24U0+G!H<"<["@HD<')E9D=R;W5P<ULG:61E;G1I=&EE<R==(#T@
M87)R87DH"B`@("`G8V]L=6UN)R`]/B!?*")'96YE<F%L($]P=&EO;G,B*2P*
M("`@("=L86)E;"<@/3X@7R@B4&5R<V]N86P@26YF;W)M871I;VXB*2P*("`@
M("=D97-C)R`]/B!?*")#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S
M:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL+B(I+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y
M*"=R97!L>71O7V%D9'(G+"`G86QI87-?861D<B<L("=T:65T;U]A9&1R)RP@
M)V)C8U]A9&1R)RP*("`@("`@("`@("`@("`@("`@("`@("`G;6%I;%]H9'(G
M+"`G<VEG;F%T=7)E)RP@)W-I9U]D87-H97,G+"`G<VEG7V9I<G-T)RP*("`@
M("`@("`@("`@("`@("`@("`@("`G<V%V95]S96YT7VUA:6PG+"`G<V5N=%]M
M86EL7V9O;&1E<B<L("=S96YT;6%I;'-E;&5C="<I"BD["@HD<')E9D=R;W5P
M<ULG<V5R=F5R)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H(D=E;F5R
M86P@3W!T:6]N<R(I+`H@("`@)VQA8F5L)R`]/B!?*")397)V97(@86YD($9O
M;&1E<B!);F9O<FUA=&EO;B(I+`H@("`@)V1E<V,G(#T^(%\H(D-H86YG92!M
M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+B(I+`H@("`@)VUE;6)E
M<G,G(#T^(&%R<F%Y*"=S=6)S8W)I8F4G+"`G9F]L9&5R<V5L96-T)RP@)W1R
M87-H<V5L96-T)RP@)W-P86US96QE8W0G*0HI.PH*:68@*"%E;7!T>2@D7U-%
M4U-)3TY;)VEM<"==6R=A8VPG72DI('L*("`@("1P<F5F1W)O=7!S6R=A8VPG
M72`](&%R<F%Y*`H@("`@("`@("=C;VQU;6XG(#T^(%\H(D=E;F5R86P@3W!T
M:6]N<R(I+`H@("`@("`@("=L86)E;"<@/3X@7R@B4VAA<F4@1F]L9&5R<R(I
M+`H@("`@("`@("=D97-C)R`]/B!?*")3:&%R92!Y;W5R(&UA:6P@9F]L9&5R
M<R!W:71H(&]T:&5R('5S97)S+B(I+`H@("`@("`@("=U<FPG(#T^("=A8VPN
M<&AP)PH@("`@*3L*?0H*)'!R969'<F]U<'-;)VQO9VEN=&%S:W,G72`](&%R
M<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B1V5N97)A;"!/<'1I;VYS(BDL"B`@
M("`G;&%B96PG(#T^(%\H(DQO9VEN(%1A<VMS(BDL"B`@("`G9&5S8R<@/3X@
M<W!R:6YT9BA?*")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G*2DL
M"B`@("`G;65M8F5R<R<@/3X@87)R87DH)VEN:71I86QP86=E<V5L96-T)RP@
M)W)E;F%M95]S96YT;6%I;%]M;VYT:&QY)RP*("`@("`@("`@("`@("`@("`@
M("`@("`G9&5L971E7W-E;G1M86EL7VUO;G1H;'DG+`H@("`@("`@("`@("`@
M("`@("`@("`@("=D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K965P)RP@)V1E
M;&5T95]A='1A8VAM96YT<U]M;VYT:&QY)RP*("`@("`@("`@("`@("`@("`@
M("`@("`G9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'E?:V5E<"<L("=P=7)G
M95]T<F%S:"<L"B`@("`@("`@("`@("`@("`@("`@("`@)W!U<F=E7W1R87-H
M7VEN=&5R=F%L)RP@)W!U<F=E7W1R87-H7VME97`G*0HI.PH*)'!R969'<F]U
M<'-;)V-O;7!O<V4G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B365S
M<V%G92!/<'1I;VYS(BDL"B`@("`G;&%B96PG(#T^(%\H(DUE<W-A9V4@0V]M
M<&]S:71I;VXB*2P*("`@("=D97-C)R`]/B!?*")#=7-T;VUI>F4@:&]W('EO
M=2!S96YD(&UA:6PN(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)VUA:6Q?
M9&]M86EN)RP@)V-O;7!O<V5?<&]P=7`G+"`G8V]M<&]S95]H=&UL)RP*("`@
M("`@("`@("`@("`@("`@("`@("`G<W1A=&EO;F5R>5]L:6YK)RP@)V-O;7!O
M<V5?<W!E;&QC:&5C:R<L("=N=6U?=V]R9',G+`H@("`@("`@("`@("`@("`@
M("`@("`@("=C;VUP;W-E7V-O;F9I<FTG+"`G<F5P;'E?<75O=&4G+"`G<F5P
M;'E?:&5A9&5R<R<L"B`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8E]T
M97AT)RP@)V9O;&1E<G-E;&5C="<L("=C;&]S95]D<F%F="<L"B`@("`@("`@
M("`@("`@("`@("`@("`@)W5N<V5E;E]D<F%F=',G+"`G<V5T7W!R:6]R:71Y
M)RP@)W-E;F1I;F=?8VAA<G-E="<L"B`@("`@("`@("`@("`@("`@("`@("`@
M)V5N8W)Y<'1S96QE8W0G+"`G<V%V95]A='1A8VAM96YT<R<I"BD["@II9B`H
M(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)V-O;7!O<V4G75LG86QL;W=?<F5C
M96EP=',G72DI('L*("`@("1P<F5F1W)O=7!S6R=C;VUP;W-E)UU;)VUE;6)E
M<G,G72`](&%R<F%Y7VUE<F=E*"1P<F5F1W)O=7!S6R=C;VUP;W-E)UU;)VUE
M;6)E<G,G72P@87)R87DH)V1I<W!O<VET:6]N7W)E<75E<W1?<F5A9"<I*3L*
M?0H*)'!R969'<F]U<'-;)W9I97=I;F<G72`](&%R<F%Y*`H@("`@)V-O;'5M
M;B<@/3X@7R@B365S<V%G92!/<'1I;VYS(BDL"B`@("`G;&%B96PG(#T^(%\H
M(DUE<W-A9V4@5FEE=VEN9R(I+`H@("`@)V1E<V,G(#T^(%\H(D-O;F9I9W5R
M92!H;W<@;65S<V%G97,@87)E(&1I<W!L87EE9"XB*2P*("`@("=M96UB97)S
M)R`]/B!A<G)A>2@G9FEL=&5R:6YG)RP@)W-T<FEP7V%T=&%C:&UE;G1S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`G:'1M;%]I;6%G95]R97!L86-E;65N
M="<L("=H=&UL7VEM86=E7V%D9')B;V]K)RP*("`@("`@("`@("`@("`@("`@
M("`@("`G:&EG:&QI9VAT7W1E>'0G+"`G:&EG:&QI9VAT7W-I;7!L95]M87)K
M=7`G+"`G<VAO=U]Q=6]T96)L;V-K<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@)V1I;5]S:6=N871U<F4G+"`G96UO=&EC;VYS)RP@)V%T=&%C:&UE;G1?
M9&ES<&QA>2<I"BD["FEF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG;6%I
M;&QO9R==6R=U<V5?;6%I;&QO9R==*2D@>PH@("`@)'!R969'<F]U<'-;)W9I
M97=I;F<G75LG;65M8F5R<R==(#T@87)R87E?;65R9V4H)'!R969'<F]U<'-;
M)W9I97=I;F<G75LG;65M8F5R<R==+"!A<G)A>2@G9&ES<&]S:71I;VY?<V5N
M9%]M9&XG*2D["GT*"B1P<F5F1W)O=7!S6R=D96QM;W9E)UT@/2!A<G)A>2@*
M("`@("=C;VQU;6XG(#T^(%\H(DUE<W-A9V4@3W!T:6]N<R(I+`H@("`@)VQA
M8F5L)R`]/B!?*")$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S(BDL"B`@
M("`G9&5S8R<@/3X@7R@B4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E
M;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+B(I+`H@("`@
M)VUE;6)E<G,G(#T^(&%R<F%Y*"=M86EL8F]X7W)E='5R;B<L("=D96QE=&5?
M<W!A;5]A9G1E<E]R97!O<G0G+`H@("`@("`@("`@("`@("`@("`@("`@("=U
M<V5?=')A<V@G+"`G=7-E7W9T<F%S:"<L("=T<F%S:'-E;&5C="<L"B`@("`@
M("`@("`@("`@("`@("`@("`@)V5M<'1Y7W1R87-H7VUE;G4G+"`G96UP='E?
M<W!A;5]M96YU)RD**3L*"B1P<F5F1W)O=7!S6R=N97=M86EL)UT@/2!A<G)A
M>2@*("`@("=C;VQU;6XG(#T^(%\H(DUE<W-A9V4@3W!T:6]N<R(I+`H@("`@
M)VQA8F5L)R`]/B!?*").97<@36%I;"(I+`H@("`@)V1E<V,G(#T^(%\H(D-O
M;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@
M=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N
M(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)W)E9G)E<VA?=&EM92<L("=N
M879?<&]P=7`G+"`G;F%V7V%U9&EO)RD**3L*"FEF("@A96UP='DH)$=,3T)!
M3%-;)V-O;F8G75LG;6%I;&)O>"==6R=S:&]W7W!R979I97<G72DI('L*("`@
M("1P<F5F1W)O=7!S6R=M86EL<')E=FEE=R==(#T@87)R87DH"B`@("`@("`@
M)V-O;'5M;B<@/3X@7R@B365S<V%G92!/<'1I;VYS(BDL"B`@("`@("`@)VQA
M8F5L)R`]/B!?*")-86EL(%!R979I97=S(BDL"B`@("`@("`@)V1E<V,G(#T^
M(%\H(D-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB*2P*("`@("`@
M("`G;65M8F5R<R<@/3X@87)R87DH)W!R979I97=?96YA8FQE9"<L("=P<F5V
M:65W7VUA>&QE;B<L("=P<F5V:65W7W-T<FEP7VYL)RP@)W!R979I97=?<VAO
M=U]U;G)E860G+"`G<')E=FEE=U]S:&]W7W1O;VQT:7`G*0H@("`@*3L*?0H*
M)'!R969'<F]U<'-;)V9E=&-H;6%I;"==(#T@87)R87DH"B`@("`G8V]L=6UN
M)R`]/B!?*")-97-S86=E($]P=&EO;G,B*2P*("`@("=L86)E;"<@/3X@7R@B
M1F5T8V@@36%I;"(I+`H@("`@)V1E<V,G(#T^(%\H(D-U<W1O;6EZ92!A8V-O
M=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(I
M+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=F971C:&UA:6Q?;&EN:R<L("=F
M971C:&UA:6Q?<&]P=7`G+"`G9F5T8VAM86EL7VUE;G4G*0HI.PH*)'!R969'
M<F]U<'-;)V1I<W!L87DG72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B
M3W1H97(@3W!T:6]N<R(I+`H@("`@)VQA8F5L)R`]/B!?*")-86EL8F]X(&%N
M9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS(BDL"B`@("`G9&5S8R<@/3X@7R@B
M0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A
M9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@87)E
M('-O<G1E9"XB*2P*("`@("=M96UB97)S)R`]/B!A<G)A>2@G;6%I;&)O>%]S
M=&%R="<L("=S;W)T8GDG+"`G<V]R=&1I<B<L("=M87A?;7-G<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@)V9R;VU?;&EN:R<L("=T:6UE7V9O<FUA="<L
M("=N879?97AP86YD960G+`H@("`@("`@("`@("`@("`@("`@("`@("=S:&]W
M7VQE9V5N9"<I"BD["@HD<')E9D=R;W5P<ULG<V5A<F-H)UT@/2!A<G)A>2@*
M("`@("=C;VQU;6XG(#T^(%\H(D]T:&5R($]P=&EO;G,B*2P*("`@("=L86)E
M;"<@/3X@7R@B4V5A<F-H($]P=&EO;G,B*2P*("`@("=D97-C)R`]/B!?*")#
M;VYT<F]L(&]P=&EO;G,@<F5L871I;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG
M+B(I+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=D969A=6QT<V5A<F-H<V5L
M96-T)RD**3L*"B1P<F5F1W)O=7!S6R=F:6QT97)S)UT@/2!A<G)A>2@*("`@
M("=C;VQU;6XG(#T^(%\H(D]T:&5R($]P=&EO;G,B*2P*("`@("=L86)E;"<@
M/3X@7R@B1FEL=&5R<R(I+`H@("`@)V1E<V,G(#T^(%\H(D-R96%T92!F:6QT
M97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S
M;W)T(&ET(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+B(I+`H@("`@
M)W5R;"<@/3X@)V9I;'1E<G!R969S+G!H<"<**3L*"B1P<F5F1W)O=7!S6R=A
M9&1R97-S8F]O:W,G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B3W1H
M97(@3W!T:6]N<R(I+`H@("`@)VQA8F5L)R`]/B!?*")!9&1R97-S($)O;VMS
M(BDL"B`@("`G9&5S8R<@/3X@7R@B4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R
M8V5S(&9O<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+B(I
M+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=A=71O7V5X<&%N9"<L("=S879E
M7W)E8VEP:65N=',G+"`G9&ES<&QA>5]C;VYT86-T)RP@)W-O=7)C97-E;&5C
M="<I"BD["@II9B`H:7-S970H)$=,3T)!3%-;)V-O;F8G75LG=71I;',G75LG
M9VYU<&<G72DI('L*("`@("1P<F5F1W)O=7!S6R=P9W`G72`](&%R<F%Y*`H@
M("`@("`@("=C;VQU;6XG(#T^(%\H(D]T:&5R($]P=&EO;G,B*2P*("`@("`@
M("`G;&%B96PG(#T^(%\H(E!'4"!/<'1I;VYS(BDL"B`@("`@("`@)V1E<V,G
M(#T^('-P<FEN=&8H7R@B0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N(BDL
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G*2DL"B`@("`@("`@
M)W5R;"<@/3X@)W!G<"YP:'`G"B`@("`I.PI]"@II9B`H97AT96YS:6]N7VQO
M861E9"@G;W!E;G-S;"<I(&%N9"!I<W-E="@D1TQ/0D%,4ULG8V]N9B==6R=U
M=&EL<R==6R=O<&5N<W-L7V-A9FEL92==*2D@>PH@("`@)'!R969'<F]U<'-;
M)W-M:6UE)UT@/2!A<G)A>2@*("`@("`@("`G8V]L=6UN)R`]/B!?*")/=&AE
M<B!/<'1I;VYS(BDL"B`@("`@("`@)VQA8F5L)R`]/B!?*")3+TU)344@3W!T
M:6]N<R(I+`H@("`@("`@("=D97-C)R`]/B!S<')I;G1F*%\H(D-O;G1R;VP@
M4R]-24U%('-U<'!O<G0@9F]R("5S+B(I+"`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=N86UE)RDI+`H@("`@("`@("=U<FPG(#T^("=S;6EM92YP:'`G
M"B`@("`I.PI]"@HO+R!097)S;VYA;"!);F9O<FUA=&EO;B!P<F5F97)E;F-E
M<PH*+R\@=7-E<B!P<F5F97)R960@96UA:6P@861D<F5S<R!F;W(@4F5P;'DM
M5&\Z+"!I9B!D:69F97)E;G0@9G)O;2!&<F]M.@HD7W!R969S6R=R97!L>71O
M7V%D9'(G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP
M92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^(%\H(EEO=7(@4F5P;'DM=&\Z
M(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3XB*2D["@HO+R!U<V5R('!R
M969E<G)E9"!A;&EA<R!A9&1R97-S97,*)%]P<F5F<ULG86QI87-?861D<B==
M(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G
M=&5X=&%R96$G+`H@("`@)V1E<V,G(#T^(%\H(EEO=7(@86QI87,@861D<F5S
M<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N
M97<@;&EN92D\+V5M/B(I*3L*"B\O('5S97(@<')E9F5R<F5D("=T:64@=&\G
M(&%D9')E<W-E<PHD7W!R969S6R=T:65T;U]A9&1R)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S
M:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=T97AT87)E82<L"B`@
M("`G9&5S8R<@/3X@7R@B061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O
M('1H:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D
M<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(BDI.PH*+R\@075T;VUA=&EC86QL
M>2!"8V,@861D<F5S<V5S('=H96X@8V]M<&]S:6YG"B1?<')E9G-;)V)C8U]A
M9&1R)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D
M)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G
M(#T^("=T97AT87)E82<L"B`@("`G9&5S8R<@/3X@7R@B061D<F5S<V5S('1O
M($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@
M861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(BDI.PH*+R\@1&ES<&QA>2!C
M=7-T;VT@:&5A9&5R<R`H8V]N9FEG=7)E9"!V:6$@=&AE(&ED96YT:71Y('-C
M<F5E;BD@=VAE;B!V:65W:6YG"B\O(&UE<W-A9V5S/PHD7W!R969S6R=M86EL
M7VAD<B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME
M9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E
M)R`]/B`G=&5X=&%R96$G+`H@("`@)V1E<V,G(#T^(%\H(D%D9&ET:6]N86P@
M:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA
M;"P@96YT97(@96%C:"!H96%D97(@;VX@82!N97<@;&EN92D\+V5M/B(I*3L*
M"B\O('5S97(@<VEG;F%T=7)E"B1?<')E9G-;)W-I9VYA='5R92==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G=&5X=&%R
M96$G+`H@("`@)V1E<V,G(#T^(%\H(EEO=7(@<VEG;F%T=7)E.B(I*3L*"B\O
M('!R96-E9&4@=&AE('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/PHD
M7W!R969S6R=S:6=?9&%S:&5S)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L
M<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?
M*")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_
M(BDI.PH*+R\@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D
M<S\*)%]P<F5F<ULG<VEG7V9I<G-T)UT@/2!A<G)A>2@*("`@("=V86QU92<@
M/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@
M9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]
M/B!?*")0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@
M9F]R=V%R9',_(BDI.PH*+R\@<V%V92!A(&-O<'D@;V8@<V5N="!M97-S86=E
M<S\*)%]P<F5F<ULG<V%V95]S96YT7VUA:6PG72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`Q+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E
M<V,G(#T^(%\H(E-A=F4@<V5N="!M86EL/R(I*3L*"B\O('-E;G0@;6%I;"!F
M;VQD97(*)%]P<F5F<ULG<V5N=%]M86EL7V9O;&1E<B==(#T@87)R87DH"B`@
M("`G=F%L=64G(#T^("=S96YT+6UA:6PG+`HO+R!&;W(@17AC:&%N9V4@<V5R
M=F5R('5N8V]M;65N="!T:&4@;&EN92!B96QO=R!A;F0@9&5L971E('1H92!L
M:6YE(&%B;W9E"B\O("`@("=V86QU92<@/3X@)U-E;G0@271E;7,G+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@
M("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O('-E;G0@;6%I;"!F;VQD97(@
M<V5L96-T:6]N('=I9&=E="X@:6YC;'5D97,@<V]M92!J879A<V-R:7!T+"!S
M;R!I="=S"B\O('-P96-I9FEC('1O($E-4"X*)%]P<F5F<ULG<V5N=&UA:6QS
M96QE8W0G72`](&%R<F%Y*"=T>7!E)R`]/B`G<W!E8VEA;"<I.PH*+R\@16YD
M(%!E<G-O;F%L($EN9F]R;6%T:6]N('!R969E<F5N8V5S"@H*+R\@4V5R=F5R
M(&%N9"!&;VQD97(@26YF;W)M871I;VX@<')E9F5R96YC97,*"B\O('5S92!)
M34%0('-U8G-C<FEB93\*)%]P<F5F<ULG<W5B<V-R:6)E)UT@/2!A<G)A>2@*
M("`@("=V86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*
M("`@("=D97-C)R`]/B!?*")5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N
M<S\B*2D["@HO+R!D<F%F=',@9F]L9&5R('-E;&5C=&EO;B!W:61G970N(&EN
M8VQU9&5S('-O;64@:F%V87-C<FEP="P@<V\@:70G<R!S<&5C:69I8PHO+R!T
M;R!)35`N"B1?<')E9G-;)V9O;&1E<G-E;&5C="==(#T@87)R87DH)W1Y<&4G
M(#T^("=S<&5C:6%L)RD["@HO+R!D<F%F=',@9F]L9&5R"B1?<')E9G-;)V1R
M869T<U]F;VQD97(G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G9')A9G1S
M)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L
M<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)RD["@HO+R!T<F%S:"!F;VQD
M97(@<V5L96-T:6]N('=I9&=E="X@:6YC;'5D97,@<V]M92!J879A<V-R:7!T
M+"!S;R!I="=S"B\O('-P96-I9FEC('1O($E-4"X*)%]P<F5F<ULG=')A<VAS
M96QE8W0G72`](&%R<F%Y*"=T>7!E)R`]/B`G<W!E8VEA;"<I.PH*+R\@=')A
M<V@@9F]L9&5R"B1?<')E9G-;)W1R87-H7V9O;&1E<B==(#T@87)R87DH"B\O
M(&9O<B!%>&-H86YG92P@=6YC;VUM96YT('1H92!E;G1R>2!B96QO=R!A;F0@
M<F5M;W9E('1H92!D969A=6QT('9A;'5E(&5N=')Y"B\O("`@("=V86QU92<@
M/3X@)T1E;&5T960@271E;7,G+`H@("`@)W9A;'5E)R`]/B`G=')A<V@G+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*
M("`@("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O('-P86T@9F]L9&5R('-E
M;&5C=&EO;B!W:61G970N(&EN8VQU9&5S('-O;64@:F%V87-C<FEP="P@<V\@
M:70G<PHO+R!S<&5C:69I8R!T;R!)35`N"B1?<')E9G-;)W-P86US96QE8W0G
M72`](&%R<F%Y*"=T>7!E)R`]/B`G<W!E8VEA;"<I.PH*+R\@<W!A;2!F;VQD
M97(*)%]P<F5F<ULG<W!A;5]F;VQD97(G72`](&%R<F%Y*`H@("`@)W9A;'5E
M)R`]/B`G4W!A;2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<I.PH*)%]P
M<F5F<ULG=F9O;&1E<B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*
M("`@("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O($5N9"!397)V97(@86YD
M($9O;&1E<B!);F9O<FUA=&EO;B!P<F5F97)E;F-E<PH*"B\O($9O;&1E<B!S
M:&%R:6YG('!R969E<F5N8V5S"@HO+R!F;VQD97(@<VAA<FEN9R!O<'1I;VYS
M"B\O('-E="`G;&]C:V5D)R`]/B!T<G5E('1O(&1I<V%B;&4@9F]L9&5R('-H
M87)I;F<*)%]P<F5F<ULG86-L)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A
M;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<I.PH*+R\@16YD(&9O;&1E
M<B!S:&%R:6YG('!R969E<F5N8V5S"@H*+R\@3&]G:6XO36%I;G1E;F%N8V4@
M5&%S:W,@<')E9F5R96YC97,*"B\O('-E;&5C="!W:61G970@9F]R('1H92!I
M;FET:6%L7W!A9V4@<')E9F5R96YC90HD7W!R969S6R=I;FET:6%L<&%G97-E
M;&5C="==(#T@87)R87DH)W1Y<&4G(#T^("=S<&5C:6%L)RD["@HO+R!T:&4@
M<&%G92!T;R!D:7-P;&%Y+B!%:71H97(@82!F:6QE;F%M92!L:6ME("=F;VQD
M97)S+G!H<"<*+R\@;W(@82!M86EL8F]X(&YA;64N"B1?<')E9G-;)VEN:71I
M86Q?<&%G92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=)3D)/6"<L"B`@
M("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@
M("`@)W1Y<&4G(#T^("=I;7!L:6-I="<I.PH*+R\@=7-E<B!D969A=6QT(&UA
M:6QB;W@*)%]P<F5F<ULG;6%I;&)O>"==(#T@87)R87DH"B`@("`G=F%L=64G
M(#T^("=)3D)/6"<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<I.PH*+R\@
M<F5N86UE('-E;G0M;6%I;"!F;VQD97(@979E<GD@;6]N=&@_"B1?<')E9G-;
M)W)E;F%M95]S96YT;6%I;%]M;VYT:&QY)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C
M)R`]/B!?*")296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@
M;V8@;6]N=&@_(BDL"B`@("`G:&5L<"<@/3X@)W!R969S+7)E;F%M95]S96YT
M;6%I;%]M;VYT:&QY)RD["@HO+R!P=7)G92!S96YT+6UA:6P@9F]L9&5R<R!E
M=F5R>2!M;VYT:#\*)%]P<F5F<ULG9&5L971E7W-E;G1M86EL7VUO;G1H;'DG
M72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G
M8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(D1E;&5T92!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(I+`H@("`@)VAE
M;'`G(#T^("=P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2<I.PH*+R\@
M:&]W(&UA;GD@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@979E<GD@
M;6]N=&@_"B1?<')E9G-;)V1E;&5T95]S96YT;6%I;%]M;VYT:&QY7VME97`G
M72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`Q,BP*("`@("=L;V-K960G(#T^
M(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@
M)VYU;6)E<B<L"B`@("`G9&5S8R<@/3X@7R@B3G5M8F5R(&]F(&]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN(BDL
M"B`@("`G:&5L<"<@/3X@)W!R969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY
M7VME97`G*3L*"B\O('!U<F=E(&]L9"!A='1A8VAM96YT<R!E=F5R>2!M;VYT
M:#\*)%]P<F5F<ULG9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DG72`](&%R
M<F%Y*`H@("`@)W9A;'5E)R`]/B`Q+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB
M;W@G+`H@("`@)V1E<V,G(#T^(%\H(D1E;&5T92!O;&0@;&EN:V5D(&%T=&%C
M:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B*2P*("`@("=H96QP)R`]
M/B`G<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DG*3L*"B\O(&AO
M=R!M86YY(&]L9"!M;VYT:',@;V8@871T86-H;65N=',@=&\@:V5E<#\*)%]P
M<F5F<ULG9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'E?:V5E<"==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^(#8L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=N=6UB97(G
M+`H@("`@)V1E<V,G(#T^(%\H(DYU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O
M;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN(BDL
M"B`@("`G:&5L<"<@/3X@)W!R969S+61E;&5T95]A='1A8VAM96YT<U]M;VYT
M:&QY7VME97`G*3L*"B\O('!U<F=E(%1R87-H(&9O;&1E<C\*)%]P<F5F<ULG
M<'5R9V5?=')A<V@G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@
M("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(E!U<F=E
M(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(I+`H@("`@)VAE
M;'`G(#T^("=P<F5F<RUP=7)G95]T<F%S:"<I.PH*+R\@:&]W(&]F=&5N('1O
M('!U<F=E('1H92!4<F%S:"!F;VQD97(_"B\O("=V86QU92<Z('EE87)L>2`]
M(#$L(&UO;G1H;'D@/2`R+"!W965K;'D@/2`S+"!D86EL>2`](#0L(&5V97)Y
M(&QO9VEN(#T@-0HD7W!R969S6R=P=7)G95]T<F%S:%]I;G1E<G9A;"==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^("<R)RP*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)W-E
M;&5C="<L"B`@("`G9&5S8R<@/3X@7R@B4'5R9V4@5')A<V@@:&]W(&]F=&5N
M.B(I+`H@("`@)VAE;'`G(#T^("=P<F5F<RUP=7)G95]T<F%S:%]I;G1E<G9A
M;"<I.PH*+R\@=VAE;B!P=7)G:6YG(%1R87-H(&9O;&1E<BP@<'5R9V4@;65S
M<V%G97,@;VQD97(@=&AA;B!H;W<@;6%N>2!D87ES/PHD7W!R969S6R=P=7)G
M95]T<F%S:%]K965P)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@,S`L"B`@
M("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@
M("`@)W1Y<&4G(#T^("=N=6UB97(G+`H@("`@)V1E<V,G(#T^(%\H(E!U<F=E
M(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO
M=6YT(&]F(&1A>7,N(BDL"B`@("`G:&5L<"<@/3X@)W!R969S+7!U<F=E7W1R
M87-H7VME97`G*3L*"B\O('-H;W<@=&]S(&%G<F5E;65N=#\*)%]P<F5F<ULG
M=&]S7V%G<F5E;65N="==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@
M("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@
M("`@)W1Y<&4G(#T^("=I;7!L:6-I="<I.PH*+R\@16YD($QO9VEN+TUA:6YT
M96YA;F-E('!R969E<F5N8V5S"@H*+R\@365S<V%G92!#;VUP;W-I=&EO;B!P
M<F5F97)E;F-E<PH*+R\@9&5F875L="!O=71G;VEN9R!M86EL(&1O;6%I;B!A
M;F0@861D<F5S<R!C;VUP;&5T:6]N"B1?<')E9G-;)VUA:6Q?9&]M86EN)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=T
M97AT)RP*("`@("=D97-C)R`]/B!?*")7:&5N('-E;F1I;F<@;6%I;"!O<B!E
M>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P
M96YD('1O('5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S
M('=I=&AO=70@7")`7"(I/R(I*3L*"B\O(&-O;7!O<V4@:6X@82!S97!A<F%T
M92!W:6YD;W<_"B1?<')E9G-;)V-O;7!O<V5?<&]P=7`G72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`Q+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G
M<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@
M("`@)V1E<V,G(#T^(%\H(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T
M92!W:6YD;W<_(BDI.PH*+R\@268@8G)O=W-E<B!S=7!P;W)T<R!T:&4@2%1-
M3"!E9&ET;W(L('-H;W5L9"!W92!C;VUP;W-E(&EN($A434P@;6]D92!B>0HO
M+R!D969A=6QT/PHD7W!R969S6R=C;VUP;W-E7VAT;6PG72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G
M<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@
M("`@)V1E<V,G(#T^(%\H(D-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,
M($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92!F96%T
M=7)E*3\B*2D["@HO+R!,:6YK('1O('1H92!S=&%T:6]N97)Y('!R969E<F5N
M8V5S+@HD7W!R969S6R=S=&%T:6]N97)Y7VQI;FLG72`](&%R<F%Y*`H@("`@
M)W1Y<&4G(#T^("=L:6YK)RP*("`@("=U<FPG(#T^("=S=&%T:6]N97)Y+G!H
M<"<L"B`@("`G9&5S8R<@/3X@7R@B0W)E871E('-T871I;VYE<GD@86YD(&9O
M<FT@<F5S<&]N<V5S+B(I*3L*"B1?<')E9G-;)W-T871I;VYE<GDG72`](&%R
M<F%Y*`H@("`@)W9A;'5E)R`]/B`G83HP.GM])RP*("`@("=L;V-K960G(#T^
M(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@
M)VEM<&QI8VET)RD["@HO+R!#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN
M9R!T:&4@;65S<V%G93\*)%]P<F5F<ULG8V]M<&]S95]S<&5L;&-H96-K)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H
M96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")#:&5C:R!S<&5L;&EN9R!B969O
M<F4@<V5N9&EN9R!A(&UE<W-A9V4_(BDI.PH*+R\@;G5M8F5R(&]F('-P96QL
M:6YG(&-O<G)E8W1I;VYS('!E<B!S8W)E96X*)%]P<F5F<ULG;G5M7W=O<F1S
M)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@,RP*("`@("=L;V-K960G(#T^
M(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@
M)VYU;6)E<B<L"B`@("`G9&5S8R<@/3X@7R@B4W!E;&QI;F<@97)R;W)S('!E
M<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RXB*2D["@HO+R!C;VYF:7)M
M('-U8V-E<W-F=6P@<V5N9&EN9R!O9B!M97-S86=E<S\*)%]P<F5F<ULG8V]M
M<&]S95]C;VYF:7)M)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@,"P*("`@
M("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@
M("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")$:7-P
M;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\B*2D[
M"@HO+R!3:&]U;&0@=&AE(&]R:6=I;F%L(&UE<W-A9V4@8F4@:6YC;'5D960_
M"B1?<')E9G-;)W)E<&QY7W%U;W1E)UT@/2!A<G)A>2@*("`@("=V86QU92<@
M/3X@,2P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@
M9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]
M/B!?*"));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B*2D[
M"@HO+R!297!L>2!T;R!H96%D97(@<W5M;6%R>2`M(&QE879E(&$@8G)I968@
M<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN<VED90HO+R!T:&4@;65S<V%G92X*
M)%]P<F5F<ULG<F5P;'E?:&5A9&5R<R==(#T@87)R87DH"B`@("`G9&5S8R<@
M/3X@7R@B26YC;'5D92!A(&)R:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I
M;B!A(')E<&QY/R(I+`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@
M/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]
M/B`G8VAE8VMB;W@G*3L*"B\O($AO=R!S:&]U;&0@=V4@871T<FEB=71E('%U
M;W1E9"!L:6YE<R!I;B!A(')E<&QY"B1?<')E9G-;)V%T=')I8E]T97AT)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@7R@B475O=&EN9R`E9CHB*2P*("`@
M("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@
M("`G='EP92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^(%\H(DAO=R!T;R!A
M='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB*2P*("`@("=H96QP
M)R`]/B`G<')E9G,M871T<FEB7W1E>'0G*3L*"B\O(&-L;W-I;F<@=VEN9&]W
M(&%F=&5R('-A=FEN9R!A(&1R869T/PHD7W!R969S6R=C;&]S95]D<F%F="==
M(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#$L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=C
M:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4VAO=6QD('1H92!C;VUP;W-E
M('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_(BDI.PH*
M+R\@<V%V92!D<F%F=',@87,@<V5E;B!O<B!U;G-E96X*)%]P<F5F<ULG=6YS
M965N7V1R869T<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G
M;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@
M)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4V%V92!D
M<F%F=',@87,@=6YS965N/R(I*3L*"B\O(&%L;&]W('1H92!U<V5R('1O(&%D
M9"!A(")8+5!R:6]R:71Y(B!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G
M97,_"B1?<')E9G-;)W-E=%]P<FEO<FET>2==(#T@87)R87DH"B`@("`G=F%L
M=64G(#T^(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S
M8R<@/3X@7R@B4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O
M<VEN9R!M97-S86=E<S\B*2D["@HO+R!396QE8W0@=VED9V5T(&9O<B!T:&4@
M<&]S<VEB;&4@8VAA<G-E=',*)%]P<F5F<ULG<V5N9&EN9U]C:&%R<V5T)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V5N
M=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y7VUE<F=E*&%R<F%Y*"<G(#T^(%\H
M(D1E9F%U;'0B*2DL"B`@("`)"0D@("1'3$]"04Q36R=N;',G75LG96YC;V1I
M;F=S)UTI+`H@("`@)V1E<V,G(#T^(%\H(EEO=7(@9&5F875L="!C:&%R<V5T
M(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(I*3L*"B\O(%-E;&5C="!W:61G970@
M9F]R('1H92`G9&5F875L=%]E;F-R>7!T)R!P<F5F97)E;F-E"B1?<')E9G-;
M)V5N8W)Y<'1S96QE8W0G72`](&%R<F%Y*"=T>7!E)R`]/B`G<W!E8VEA;"<I
M.PH*+R\@5&AE(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@=&\@=7-E('=H
M96X@<V5N9&EN9R!M97-S86=E<PHD7W!R969S6R=D969A=6QT7V5N8W)Y<'0G
M72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!)35!?14Y#4EE05%].3TY%+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*
M("`@("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O(%-A=F4@871T86-H;65N
M=',@=VAE;B!S879I;F<@:6X@<V5N="UM86EL(&9O;&1E<C\*)%]P<F5F<ULG
M<V%V95]A='1A8VAM96YT<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=P
M<F]M<'1?;F\G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@
M/3X@87)R87DH)V%L=V%Y<R<@/3X@7R@B06QW87ES('-A=F4@871T86-H;65N
M=',B*2P*("`@("`@("`@("`@("`@("`@("`G<')O;7!T7WEE<R<@/3X@7R@B
M4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A
M=6QT('1O(%E%4R(I+`H@("`@("`@("`@("`@("`@("`@("=P<F]M<'1?;F\G
M(#T^(%\H(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N
M=#L@9&5F875L="!T;R!.3R(I+`H@("`@("`@("`@("`@("`@("`@("=N979E
M<B<@/3X@7R@B3F5V97(@<V%V92!A='1A8VAM96YT<R(I*2P*("`@("=D97-C
M)R`]/B!?*")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E
M(&%T=&%C:&UE;G0@9&%T83\B*2P*("`@("=H96QP)R`]/B`G<')E9G,M<V%V
M95]A='1A8VAM96YT<R<I.PH*+R\@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M(%!R969E<F5N8V5S"B1?<')E9G-;)V1I<W!O<VET:6]N7W)E<75E<W1?<F5A
M9"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=A<VLG+`H@("`@)VQO8VME
M9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E
M)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@87)R87DH)VYE=F5R)R`]/B!?
M*").979E<B(I+`H@("`@("`@("`@("`@("`@("`@("=A<VLG(#T^(%\H(D%S
M:R(I+`H@("`@("`@("`@("`@("`@("`@("=A;'=A>7,G(#T^(%\H(D%L=V%Y
M<R(I*2P*("`@("=D97-C)R`]/B!?*")297%U97-T(')E860@<F5C96EP=',_
M(BDL"B`@("`G:&5L<"<@/3X@)W!R969S+61I<W!O<VET:6]N7W)E<75E<W1?
M<F5A9"<**3L*"B\O($5N9"!-97-S86=E($-O;7!O<VET:6]N('!R969E<F5N
M8V5S"@H*+R\@365S<V%G92!6:65W:6YG('!R969E<F5N8V5S"@HO+R!F:6QT
M97(@;65S<V%G92!C;VYT96YT/PHD7W!R969S6R=F:6QT97)I;F<G72`](&%R
M<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB
M;W@G+`H@("`@)V1E<V,G(#T^(%\H(D9I;'1E<B!M97-S86=E(&-O;G1E;G0@
M9F]R('!R;V9A;FET>3\B*2D["@HO+R!3:&]U;&0@=V4@9&ES<&QA>2!A;B!I
M8V]N('1O('-T<FEP(&%T=&%C:&UE;G1S/PHD7W!R969S6R=S=')I<%]A='1A
M8VAM96YT<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G;&]C
M:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y
M<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4VAO=R!A;B!I
M8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE
M<W-A9V5S/R(I*3L*"B\O(%=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M
M97-S86=E<R!A9G1E<B!R97!O<G1I;F<@=&AE;3\*)%]P<F5F<ULG9&5L971E
M7W-P86U?869T97)?<F5P;W)T)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L
M<V4L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y
M*#`@/3X@7R@B3F]T:&EN9R(I+`H@("`@("`@("`@("`@("`@("`@(#$@/3X@
M7R@B1&5L971E('-P86T@;65S<V%G97,B*2P*("`@("`@("`@("`@("`@("`@
M("`R(#T^(%\H(DUO=F4@<W!A;2!M97-S86=E<R!T;R!S<&%M(&9O;&1E<B!A
M;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@24Y"3U@B*2DL"B`@("`G9&5S8R<@
M/3X@7R@B5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F
M=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@;W(@:6YN;V-E
M;G0_(BDL"B`@("`G:&5L<"<@/3X@)W!R969S+61E;&5T95]S<&%M7V%F=&5R
M7W)E<&]R="<**3L*"B\O(%)E<&QA8V4@:6UA9V4@=&%G<R!I;B!(5$U,(&UE
M<W-A9V5S('=I=&@@8FQA;FL@:6UA9V5S/PHD7W!R969S6R=H=&UL7VEM86=E
M7W)E<&QA8V5M96YT)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@,2P*("`@
M("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@
M("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")";&]C
M:R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E
M8VEF:6-A;&QY(')E<75E<W1E9#\B*2P*("`@("=H96QP)R`]/B`G<')E9G,M
M:'1M;%]I;6%G95]R97!L86-E;65N="<**3L*"B\O($)Y(&1E9F%U;'0L(&%U
M=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!I9B!T
M:&4@<V5N9&5R(&ES(&EN"B\O('1H92!U<V5R)W,@861D<F5S<V)O;VL_"B1?
M<')E9G-;)VAT;6Q?:6UA9V5?861D<F)O;VLG72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`Q+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E
M<V,G(#T^(%\H(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M
M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@861D<F5S<V)O;VL_
M(BDL"B`@("`G:&5L<"<@/3X@)W!R969S+6AT;6Q?:6UA9V5?861D<F)O;VLG
M"BD["@HO+R!S:&]U;&0@=V4@=')Y('1O(&UA<FL@9&EF9F5R96YT(&-O;G9E
M<G-A=&EO;G,@=VET:"!D:69F97)E;G0@8V]L;W)S/PHD7W!R969S6R=H:6=H
M;&EG:'1?=&5X="==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#$L"B`@("`G
M;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@
M)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B36%R:R!D
M:69F97)E;G0@;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L
M;W)S/R(I*3L*"B\O('-H;W5L9"!W92!T<GD@=&\@;6%R:R!S:6UP;&4@;6%R
M:W5P('=I=&@@:'1M;"!T86=S/PHD7W!R969S6R=H:6=H;&EG:'1?<VEM<&QE
M7VUA<FMU<"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#$L"B`@("`G;&]C
M:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y
M<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B36%R:R!S:6UP
M;&4@;6%R:W5P/R(I*3L*"B\O('-H;W5L9"!W92!S:&]W(&QA<F=E(&)L;V-K
M<R!O9B!Q=6]T960@=&5X="!O<B!H:61E('1H96T_"B1?<')E9G-;)W-H;W=?
M<75O=&5B;&]C:W,G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G=&AR96%D
M)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L
M<V4L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y
M*"=S:&]W;B<@/3X@7R@B4VAO=VXB*2P*("`@("`@("`@("`@("`@("`@("`G
M=&AR96%D)R`]/B!?*")(:61D96X@:6X@5&AR96%D(%9I97<B*2P*("`@("`@
M("`@("`@("`@("`@("`G:&ED9&5N)R`]/B!?*")(:61D96XB*2DL"B`@("`G
M9&5S8R<@/3X@7R@B4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X
M="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E('1O
M9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+B(I*3L*"B\O('-H
M;W5L9"!W92!D:6T@<VEG;F%T=7)E<S\*)%]P<F5F<ULG9&EM7W-I9VYA='5R
M92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#$L"B`@("`G;&]C:V5D)R`]
M/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^
M("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B1&EM('-I9VYA='5R97,_
M(BDI.PH*+R\@0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H
M:6-A;"!O;F5S/PHO+R!A('9A;'5E(&]F(#`@/2!N;RP@,2`]('EE<PHD7W!R
M969S6R=E;6]T:6-O;G,G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*
M("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(D-O
M;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\B
M*2D["@HO+R!H;W<@9&\@=V4@9&ES<&QA>2!A='1A8VAM96YT<S\*)%]P<F5F
M<ULG871T86-H;65N=%]D:7-P;&%Y)UT@/2!A<G)A>2@*("`@("=V86QU92<@
M/3X@)VQI<W0G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@
M/3X@87)R87DH)VQI<W0G("`@/3X@7R@B3&ES=&EN9R!I;B!T:&4@2&5A9&5R
M(BDL"B`@("`@("`@("`@("`@("`@("`@)VEN;&EN92<@/3X@7R@B1&ES<&QA
M>2!I;B!";V1Y(&]F($UE<W-A9V4B*2P*("`@("`@("`@("`@("`@("`@("`G
M8F]T:"<@("`]/B!?*")";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F
M($UE<W-A9V4B*2DL"B`@("`G9&5S8R<@/3X@7R@B2&]W(&1O('EO=2!W86YT
M('1O(&1I<W!L87D@871T86-H;65N=',_(BDI.PH*)%]P<F5F<ULG9&ES<&]S
M:71I;VY?<V5N9%]M9&XG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*
M("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(E-E
M;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD97(_
M(BDL"B`@("`G:&5L<"<@/3X@)W!R969S+61I<W!O<VET:6]N7W-E;F1?;61N
M)PHI.PH*+R\@16YD($UE<W-A9V4@5FEE=VEN9R!P<F5F97)E;F-E<PH*"B\O
M($1E;&5T:6YG(&%N9"!-;W9I;F<@365S<V%G97,@<')E9F5R96YC97,*"B\O
M('-H;W5L9"!W92!R971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E
M<B!D96QE=&EN9R!A(&UE<W-A9V4_"B1?<')E9G-;)VUA:6QB;WA?<F5T=7)N
M)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^
M(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@
M)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")2971U<FX@=&\@=&AE(&UA
M:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y
M:6YG(&$@;65S<V%G93\B*2D["@HO+R!S:&]U;&0@=V4@;6]V92!M97-S86=E
M<R!T;R!A('1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&IU<W0@;6%R:VEN9PHO
M+R!T:&5M(&%S(&1E;&5T960_"B1?<')E9G-;)W5S95]T<F%S:"==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O
M>"<L"B`@("`G9&5S8R<@/3X@7R@B5VAE;B!D96QE=&EN9R!M97-S86=E<RP@
M;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E860@;V8@;6%R
M:VEN9R!T:&5M(&%S(&1E;&5T960_(BDI.PH*+R\@=7-E(%9I<G1U86P@5')A
M<V@@9F]L9&5R"B1?<')E9G-;)W5S95]V=')A<V@G72`](&%R<F%Y*`H@("`@
M)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@
M)V1E<V,G(#T^(%\H(E5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\B*2D["@HO
M+R!V:7)T=6%L('1R87-H(&9O;&1E<B!I9&5N=&EF:65R"B1?<')E9G-;)W9T
M<F%S:%]I9"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO
M8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T
M>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O(&1I<W!L87D@=&AE("=%;7!T>2!4
M<F%S:"<@;&EN:R!I;B!T:&4@;65N=6)A<C\*)%]P<F5F<ULG96UP='E?=')A
M<VA?;65N=2==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#$L"B`@("`G;&]C
M:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y
M<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B1&ES<&QA>2!T
M:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(BDI.PH*
M+R\@9&ES<&QA>2!T:&4@)T5M<'1Y(%-P86TG(&QI;FL@:6X@=&AE(&UE;G5B
M87(_"B1?<')E9G-;)V5M<'1Y7W-P86U?;65N=2==(#T@87)R87DH"B`@("`G
M=F%L=64G(#T^(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G
M9&5S8R<@/3X@7R@B1&ES<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I
M;B!T:&4@;65N=6)A<C\B*2D["@HO+R!H:61E(&1E;&5T960*)%]P<F5F<ULG
M9&5L:&ED92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G;&]C
M:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y
M<&4G(#T^("=I;7!L:6-I="<I.PH*+R\@16YD($1E;&5T:6YG(&%N9"!-;W9I
M;F<@365S<V%G97,@<')E9F5R96YC97,*"@HO+R!.97<@36%I;"!P<F5F97)E
M;F-E<PH*+R\@=&EM92!B969O<F4@<F5L;V%D:6YG('1H92!N879I9V%T;W(@
M;W(@;6%I;&)O>"!P86=E"B1?<')E9G-;)W)E9G)E<VA?=&EM92==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*
M("`@("=E;G5M)R`]/B!A<G)A>2@P(#T^(%\H(DYE=F5R(BDL"B`@("`@("`@
M("`@("`@("`@("`@,S`@/3X@7R@B179E<GD@,S`@<V5C;VYD<R(I+`H@("`@
M("`@("`@("`@("`@("`@(#8P(#T^(%\H(D5V97)Y(&UI;G5T92(I+`H@("`@
M("`@("`@("`@("`@("`@(#,P,"`]/B!?*")%=F5R>2`U(&UI;G5T97,B*2P*
M("`@("`@("`@("`@("`@("`@("`Y,#`@/3X@7R@B179E<GD@,34@;6EN=71E
M<R(I+`H@("`@("`@("`@("`@("`@("`@(#$X,#`@/3X@7R@B179E<GD@:&%L
M9B!H;W5R(BDI+`H@("`@)V1E<V,G(#T^(%\H(E)E9G)E<V@@1F]L9&5R(%9I
M97=S.B(I*3L*"B\O(&IA=F%S8W)I<'0@<&]P=7`@:68@=&AE<F4G<R!N97<@
M;6%I;#\*)%]P<F5F<ULG;F%V7W!O<'5P)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C
M)R`]/B!?*")$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA
M:6P_(BDI.PH*)%]P<F5F<ULG;F%V7V%U9&EO)UT@/2!A<G)A>2@*("`@("=V
M86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E
M9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D
M97-C)R`]/B!?*")0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@5&AI<R!R97%U
M:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E9"!S;W5N9"!F
M:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A;F0@36%C+"!B=70@
M;W1H97(@<&QA=&9O<FUS('=I;&P@<F5Q=6ER92!A('!L=6=I;BXB*2D["@HO
M+R!%;F0@3F5W($UA:6P@<')E9F5R96YC97,*"@HO+R!-97-S86=E(%!R979I
M97<@4')E9F5R96YC97,*"B1?<')E9G-;)W!R979I97=?96YA8FQE9"==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^("<P)RP*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H
M96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")%;F%B;&4@;65S<V%G92!P<F5V
M:65W<S\B*0HI.PH*)%]P<F5F<ULG<')E=FEE=U]M87AL96XG72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B`R-3`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*
M("`@("=E;G5M)R`]/B!A<G)A>2@Q,#`@/3X@7R@B,3`P(&-H87)A8W1E<G,B
M*2P*("`@("`@("`@("`@("`@("`@("`R-3`@/3X@7R@B,C4P(&-H87)A8W1E
M<G,B*2P*("`@("`@("`@("`@("`@("`@("`U,#`@/3X@7R@B-3`P(&-H87)A
M8W1E<G,B*2P*("`@("`@("`@("`@("`@("`@("`Q,#`P(#T^(%\H(C$P,#`@
M8VAA<F%C=&5R<R(I+`H@("`@("`@("`@("`@("`@("`@("TQ(#T^(%\H(D%L
M;"(I*2P*("`@("=D97-C)R`]/B!?*")#:&%R86-T97)S('1O(&1I<W!L87DZ
M(BD**3L*"B1?<')E9G-;)W!R979I97=?<W1R:7!?;FPG72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`G,2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@
M("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L
M"B`@("`G9&5S8R<@/3X@7R@B4W1R:7`@;&EN96)R96%K<S\B*0HI.PH*)%]P
M<F5F<ULG<')E=FEE=U]S:&]W7W5N<F5A9"==(#T@87)R87DH"B`@("`G=F%L
M=64G(#T^("<Q)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E
M9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D
M97-C)R`]/B!?*")3:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@
M;VYL>3\B*0HI.PH*)%]P<F5F<ULG<')E=FEE=U]S:&]W7W1O;VQT:7`G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G,"<L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=C
M:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4VAO=R!P<F5V:65W<R!I;B!T
M;V]L=&EP<S\B*0HI.PH*+R\@16YD($UE<W-A9V4@4')E=FEE=PH*"B\O($9E
M=&-H($UA:6P@<')E9F5R96YC97,*"B\O($-H86YG92!T:&ES(&EF('EO=2!W
M86YT('1O(&-U<W1O;6EZ92!H;W<@9F5T8VAM86EL<')E9G,N<&AP('=O<FMS
M+@HD7W!R969S6R=F971C:&UA:6Q?;&EN:R==(#T@87)R87DH"B`@("`G='EP
M92<@/3X@)VQI;FLG+`H@("`@)W5R;"<@/3X@)V9E=&-H;6%I;'!R969S+G!H
M<"<L"B`@("`G:6UG)R`]/B`G9F5T8VAM86EL+G!N9R<L"B`@("`G9&5S8R<@
M/3X@7R@B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H
M97(@;6%I;"!A8V-O=6YT<RXB*2D["@HO+R!&971C:"!M86EL(&]N('-E<&%R
M871E('=I;F1O=S\*)%]P<F5F<ULG9F5T8VAM86EL7W!O<'5P)UT@/2!A<G)A
M>2@*("`@("=V86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@
M("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X
M)RP*("`@("=D97-C)R`]/B!?*")&971C:"!-86EL(&EN(&$@<V5P87)A=&4@
M=VEN9&]W/R(I*3L*"B\O(%-H;W<@=&AE($9E=&-H(&UA:6P@:6-O;B!O;B!T
M:&4@;65N=6)A<C\*)%]P<F5F<ULG9F5T8VAM86EL7VUE;G4G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B`Q+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@
M("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G
M+`H@("`@)V1E<V,G(#T^(%\H(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O
M;B!T:&4@;65N=6)A<C\B*2D["@HO+R!$;VXG="!C:&%N9V4@86YY=&AI;F<@
M:&5R92X*)%]P<F5F<ULG9FU?86-C;W5N=',G72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`G83HP.GM])RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)RD[
M"@HD7W!R969S6R=F971C:&UA:6Q?;&]G:6XG72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O($5N
M9"!&971C:"!-86EL('!R969E<F5N8V5S"@H*+R\@1&ES<&QA>2!/<'1I;VYS
M('!R969E<F5N8V5S"@HO+R!W:&EC:"!P86=E('1O('-T87)T(&]N('=H96X@
M;W!E;FEN9R!M86EL8F]X"B1?<')E9G-;)VUA:6QB;WA?<W1A<G0G72`](&%R
M<F%Y*`H@("`@)W9A;'5E)R`]/B!)35!?34%)3$)/6%-405)47T9)4E-454Y3
M145.+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F
M86QS92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@87)R
M87DH24U07TU!24Q"3UA35$%25%]&25)35%5.4T5%3B`]/B!?*")086=E('=I
M=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E(BDL"B`@("`@("`@("`@("`@
M("`@("`@24U07TU!24Q"3UA35$%25%],05-454Y3145.(#T^(%\H(E!A9V4@
M=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G92(I+`H@("`@("`@("`@("`@
M("`@("`@($E-4%]-04E,0D]84U1!4E1?1DE24U1004=%(#T^(%\H(D9I<G-T
M($UA:6QB;W@@4&%G92(I+`H@("`@("`@("`@("`@("`@("`@($E-4%]-04E,
M0D]84U1!4E1?3$%35%!!1T4@/3X@7R@B3&%S="!-86EL8F]X(%!A9V4B*2DL
M"B`@("`G9&5S8R<@/3X@7R@B5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L
M('=H:6-H('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_(BDL"B`@("`G
M:&5L<"<@/3X@)W!R969S+6UA:6QB;WA?<W1A<G0G*3L*"B\O('5S97(@<')E
M9F5R<F5D('-O<G1I;F<@8V]L=6UN"B1?<')E9G-;)W-O<G1B>2==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^(%-/4E1!4E))5D%,+`H@("`@)VQO8VME9"<@
M/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]
M/B`G96YU;2<L"B`@("`G96YU;2<@/3X@87)R87DH4T]25$%24DE604P@/3X@
M7R@B07)R:79A;"!4:6UE(BDL"B`@("`@("`@("`@("`@("`@("`@4T]25$1!
M5$4@/3X@7R@B365S<V%G92!$871E(BDL"B`@("`@("`@("`@("`@("`@("`@
M4T]25$923TT@/3X@7R@B1G)O;2!!9&1R97-S(BDL"B`@("`@("`@("`@("`@
M("`@("`@4T]25%1/(#T^(%\H(E1O($%D9')E<W,B*2P*("`@("`@("`@("`@
M("`@("`@("!33U)44U5"2D5#5"`]/B!?*")3=6)J96-T($9I96QD(BDL"B`@
M("`@("`@("`@("`@("`@("`@4T]25%-)6D4@/3X@7R@B365S<V%G92!3:7IE
M(BDL"B`@("`@("`@("`@("`@("`@("`@4T]25%1(4D5!1"`]/B!?*")4:')E
M860@5FEE=R(I*2P*("`@("=D97-C)R`]/B!?*")$969A=6QT('-O<G1I;F<@
M8W)I=&5R:6$Z(BDI.PH*+R\@=7-E<B!P<F5F97)R960@<V]R=&EN9R!D:7)E
M8W1I;VX*)%]P<F5F<ULG<V]R=&1I<B==(#T@87)R87DH"B`@("`G=F%L=64G
M(#T^(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^
M(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("=E;G5M)R`]/B!A
M<G)A>2@P(#T^(%\H(D%S8V5N9&EN9R(I+`H@("`@("`@("`@("`@("`@("`@
M(#$@/3X@7R@B1&5S8V5N9&EN9R(I*2P*("`@("=D97-C)R`]/B!?*")$969A
M=6QT('-O<G1I;F<@9&ER96-T:6]N.B(I*3L*"B\O(&UA:6QB;W@@8V]N<W1R
M86EN=',*)%]P<F5F<ULG;6%X7VUS9W,G72`](&%R<F%Y*`H@("`@)W9A;'5E
M)R`]/B`R,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VYU;6)E<B<L"B`@("`G9&5S8R<@
M/3X@7R@B365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB
M*2D["@HO+R!(;W<@=&AE(&9R;VT@9FEE;&0@<VAO=6QD(&)E(&1I<W!L87EE
M9"!O;B!T:&4@;6%I;&)O>"!S8W)E96X*)%]P<F5F<ULG9G)O;5]L:6YK)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@,2P*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V5N
M=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y*`H@("`@("`@(#`@/3X@7R@B0VQI
M8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A
M9V4@=&\@=&AE('-E;F1E<B(I+`H@("`@("`@(#$@/3X@7R@B0VQI8VMI;F<@
M;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E
M860B*2P*("`@("`@("`R(#T^(%\H(D1O(&YO="!G96YE<F%T92!A(&QI;FL@
M:6X@=&AE($9R;VTZ(&-O;'5M;B(I"B`@("`I+`H@("`@)V1E<V,G(#T^(%\H
M(E1H92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI
M;FME9#HB*2D["@HO+R!4:6UE(&9O<FUA="!F;W(@;65S<V%G97,@9&%T960@
M=&]D87D*)%]P<F5F<ULG=&EM95]F;W)M870G72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`G)5@G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU
M;2<@/3X@87)R87DH"B`@("`@("`@)R58)R`]/B!S=')F=&EM92@G)5@G*2P*
M("`@("`@("`G)4@Z)4TZ)5,G(#T^('-T<F9T:6UE*"<E2#HE33HE4R<I+`H@
M("`@("`@("<E23HE33HE4R`E<"<@/3X@<W1R9G1I;64H)R5).B5-.B53("5P
M)RDL"B`@("`@("`@)R5(.B5-)R`]/B!S=')F=&EM92@G)4@Z)4TG*2P*("`@
M("`@("`G)4DZ)4TE<"<@/3X@<W1R9G1I;64H)R5).B5-)7`G*2P*("`@("DL
M"B`@("`G9&5S8R<@/3X@7R@B1F]R;6%T(&]F(&UE<W-A9V4@9&%T97,@:6X@
M=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T960@=&]D87DB*2D[
M"@HO+R!E>'!A;F0@9F]L9&5R('1R964@8GD@9&5F875L=`HD7W!R969S6R=N
M879?97AP86YD960G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@
M("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@87)R87DH,"`]/B!?
M*").;R(I+`H@("`@("`@("`@("`@("`@("`@(#$@/3X@7R@B665S(BDL"B`@
M("`@("`@("`@("`@("`@("`@,B`]/B!?*")296UE;6)E<B!T:&4@;&%S="!V
M:65W(BDI+`H@("`@)V1E<V,G(#T^(%\H(D5X<&%N9"!T:&4@96YT:7)E(&9O
M;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\B*2D[
M"@HO+R!L:7-T(&]F(&9O;&1E<G,@=&\@97AP86YD(&)Y(&1E9F%U;'0*)%]P
M<F5F<ULG97AP86YD961?9F]L9&5R<R==(#T@87)R87DH"B`@("`G=F%L=64G
M(#T^("=A.C`Z>WTG+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O
M(&QI<W0@;V8@9F]L9&5R<R!T;R!P;VQL(&9O<B!N97<@;6%I;`HD7W!R969S
M6R=N879?<&]L;"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@
M("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O('-H;W<@;6%I;&)O>"!L96=E
M;F0_"B1?<')E9G-;)W-H;W=?;&5G96YD)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@,2P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C
M)R`]/B!?*")3:&]W(&QE9V5N9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(I*3L*
M"B\O($5N9"!$:7-P;&%Y($]P=&EO;G,@<')E9F5R96YC97,*"@HO+R!396%R
M8V@@<')E9F5R96YC97,*"B\O(&1E9F%U;'0@<V5A<F-H('-E;&5C=&EO;B!W
M:61G970N('1H:7,@;F5E9',@=&\@8F4@9'EN86UI8V%L;'D@8G5I;'0N"B1?
M<')E9G-;)V1E9F%U;'1S96%R8VAS96QE8W0G72`](&%R<F%Y*"=T>7!E)R`]
M/B`G<W!E8VEA;"<I.PH*+R\@9&5F875L="!S96%R8V@@9FEE;&0*)%]P<F5F
M<ULG9&5F875L=%]S96%R8V@G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G
M)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L
M<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)RD["@HO+R!%;F0@4V5A<F-H
M('!R969E<F5N8V5S"@H*+R\@1FEL=&5R('!R969E<F5N8V5S"@HO+R!R=6X@
M9FEL=&5R<R!O;B!L;V=I;C\*)%]P<F5F<ULG9FEL=&5R7V]N7VQO9VEN)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM
M<&QI8VET)RD["@HO+R!R=6X@9FEL=&5R<R!W:71H($E.0D]8(&1I<W!L87D_
M"B1?<')E9G-;)V9I;'1E<E]O;E]D:7-P;&%Y)UT@/2!A<G)A>2@*("`@("=V
M86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E
M9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)RD["@HO+R!S
M:&]W(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/PHD7W!R969S6R=F:6QT
M97)?;65N=6ET96TG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@
M("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B\O($%L;&]W(&9I;'1E<G,@=&\@
M8F4@87!P;&EE9"!T;R!A;GD@;6%I;&)O>#\*)%]P<F5F<ULG9FEL=&5R7V%N
M>5]M86EL8F]X)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@,"P*("`@("=L
M;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G
M='EP92<@/3X@)VEM<&QI8VET)RD["@HO+R!%;F0@1FEL=&5R('!R969E<F5N
M8V5S"@H*+R\@061D<F5S<R!B;V]K('!R969E<F5N8V5S"@HO+R!3:&]U;&0@
M;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&5X<&%N9&5D(&%U=&]M
M86=I8V%L;'D_"B1?<')E9G-;)V%U=&]?97AP86YD)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@,2P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H
M87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@
M("=D97-C)R`]/B!?*")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN
M9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(BDI.PH*+R\@
M4VAO=6QD(')E8VEP:65N=',@;V8@;W5T9V]I;F<@;65S<V%G97,@8F4@861D
M960@875T;VUA=&EC86QL>2!T;PHO+R!T:&4@861D<F5S<R!B;V]K/PHD7W!R
M969S6R=S879E7W)E8VEP:65N=',G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]
M/B`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F
M86QS92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^
M(%\H(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A
M=6QT(&%D9')E<W,@8F]O:S\B*2D["@HO+R!">2!D969A=6QT+"!D:7-P;&%Y
M(&%L;"!C;VYT86-T<R!I;B!T:&4@861D<F5S<R!B;V]K('=H96X@;&]A9&EN
M9PHO+R!T:&4@8V]N=&%C=',@<V-R965N+B`@268@>6]U<B!D969A=6QT(&%D
M9')E<W,@8F]O:R!I<R!L87)G92!A;F0*+R\@<VQO=R!T;R!D:7-P;&%Y+"!Y
M;W4@;6%Y('=A;G0@=&\@9&ES86)L92!A;F0@;&]C:R!T:&ES(&]P=&EO;BX*
M)%]P<F5F<ULG9&ES<&QA>5]C;VYT86-T)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@,2P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@=')U92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G
M(#T^(%\H(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N
M=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL(&]N;'D@<V5E
M(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2DB*2D[
M"@HO+R!A9&1R97-S(&)O;VL@<V5L96-T:6]N('=I9&=E=`HD7W!R969S6R=S
M;W5R8V5S96QE8W0G72`](&%R<F%Y*"=T>7!E)R`]/B`G<W!E8VEA;"<I.PH*
M+R\@861D<F5S<R!B;V]K*',I('1O('5S92!W:&5N(&5X<&%N9&EN9R!A9&1R
M97-S97,*+R\@66]U(&-A;B!P<F]V:61E(&1E9F%U;'0@=F%L=65S('1H:7,@
M=V%Y("AN;W1E('1H92!<="!A;F0@=&AE(&1O=6)L92!Q=6]T97,I.@HO+R`G
M=F%L=64G(#T^(")S;W5R8V5?;VYE7'1S;W5R8V5?='=O(@HO+R!R969E<B!T
M;R!T=7)B82]C;VYF:6<O<V]U<F-E<RYP:'`@9F]R('!O<W-I8FQE('-O=7)C
M92!V86QU97,*)%]P<F5F<ULG<V5A<F-H7W-O=7)C97,G72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`B(BP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)RD[
M"@HO+R!F:65L9"AS*2!T;R!U<V4@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S
M"B\O(%1H:7,@9&5P96YD<R!O;B!T:&4@<V5A<F-H7W-O=7)C97,@<')E9F5R
M96YC92!I9B!Y;W4@=V%N="!T;R!P<F]V:61E"B\O(&1E9F%U;'0@=F%L=65S
M.@HO+R`G=F%L=64G(#T^(")S;W5R8V5?;VYE7'1F:65L9%]O;F5<=&9I96QD
M7W1W;UQN<V]U<F-E7W1W;UQT9FEE;&1?=&AR964B"B\O('=I;&P@<V5A<F-H
M('1H92!F:65L9',@)V9I96QD7V]N92<@86YD("=F:65L9%]T=V\G(&EN('-O
M=7)C95]O;F4@86YD"B\O("=F:65L9%]T:')E92<@:6X@<V]U<F-E7W1W;RX*
M+R\@<F5F97(@=&\@='5R8F$O8V]N9FEG+W-O=7)C97,N<&AP(&9O<B!P;W-S
M:6)L92!S;W5R8V4@86YD(&9I96QD('9A;'5E<PHD7W!R969S6R=S96%R8VA?
M9FEE;&1S)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@(B(L"B`@("`G;&]C
M:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y
M<&4G(#T^("=I;7!L:6-I="<I.PH*+R\@861D<F5S<R!B;V]K('1O('5S92!F
M;W(@861D:6YG(&%D9')E<W-E<PHO+R!P=70@)&-F9U-O=7)C97,@87)R87D@
M96QE;65N="!N86UE(&EN('1H92!V86QU92!F:65L9"X*+R\@4V5T=&EN9R!V
M86QU92!T;R!L;V-A;'-Q;"!W;W5L9"!A;&QO=R!Y;W4@=&\@861D(&-O;G1A
M8W1S('1O($UY4U%,(&1A=&%B87-E"B\O(%-E92!T=7)B82]C;VYF:6<O<V]U
M<F-E<RYP:'`@9F]R(&UO<F4@:6YF;PHD7W!R969S6R=A9&1?<V]U<F-E)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B\O("`G=F%L=64G(#T^("=L
M;V-A;'-Q;"<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^('1R=64L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@16YD
M($%D9')E<W,@8F]O:R!P<F5F97)E;F-E<PH*"B\O(%!'4"!O<'1I;VYS"@HO
M+R!!8W1I=F%T92!01U`@<W5P<&]R=#\*)%]P<F5F<ULG=7-E7W!G<"==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS
M92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L
M:6-I="<**3L*"B\O(%EO=2!S:&]U;&0@;F]T(&UA;G5A;&QY(&-H86YG92!T
M:&4@<F5S="!O9B!T:&4@4$=0(&5N=')I97,*)%]P<F5F<ULG<&=P7V%T=&%C
M:%]P=6)K97DG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO
M8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T
M>7!E)R`]/B`G:6UP;&EC:70G*3L*"B1?<')E9G-;)W!G<%]S8V%N7V)O9'DG
M72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G
M:6UP;&EC:70G*3L*"B1?<')E9G-;)W!G<%]P<FEV871E7VME>2==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G:6UP;&EC
M:70G*3L*"B1?<')E9G-;)W!G<%]P=6)L:6-?:V5Y)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S
M:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<I.PH*
M+R\@16YD(%!'4"!/<'1I;VYS"@HO+R!3+TU)344@;W!T:6]N<PH*+R\@06-T
M:79A=&4@4R]-24U%('-U<'!O<G0_"B1?<')E9G-;)W5S95]S;6EM92==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS
M92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L
M:6-I="<I.PH*+R\@66]U('-H;W5L9"!N;W0@;6%N=6%L;'D@8VAA;F=E('1H
M92!R97-T(&]F('1H92!3+TU)344@96YT<FEE<PHD7W!R969S6R=S;6EM95]P
M<FEV871E7VME>2==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@
M("=T>7!E)R`]/B`G:6UP;&EC:70G*3L*"B1?<')E9G-;)W-M:6UE7W!U8FQI
M8U]K97DG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP
M92<@/3X@)VEM<&QI8VET)RD["@HD7W!R969S6R=S;6EM95]A9&1I=&EO;F%L
M7V-E<G0G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP
M92<@/3X@)VEM<&QI8VET)RD["@HO+R!%;F0@4R]-24U%($]P=&EO;G,*"B\O
M($]T:&5R(&5N=')I97,@*'5S960@:6YT97)N86QL>2!I;B!)35`I"@HO+R!V
M:7)T=6%L(&EN8F]X(&ED96YT:69I97(*)%]P<F5F<ULG=FEN8F]X7VED)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I
M;7!L:6-I="<I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+V5T8R]P<V$M:&]R9&4O:6UP+W-E<G9E<G,N<&AP````````````````````
M`````````````````````````````````````````````````````#`Q,#`T
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(W,3`V`#$P-#$W,S8R-S0S`#`R
M,#$V-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AO<F1E.B!I;7`O8V]N9FEG+W-E<G9E<G,N<&AP
M+F1I<W0L=B`Q+C4P+C(N,3,@,C`P-B\P,B\P-R`P-SHU,#HR-"!S;'5S87)Z
M($5X<"`D"B`J"B`J(%1H:7,@9FEL92!I<R!W:&5R92!Y;W4@<W!E8VEF>2!W
M:&%T(&UA:6P@<V5R=F5R<R!P96]P;&4@=7-I;F<@>6]U<@H@*B!I;G-T86QL
M871I;VX@;V8@24U0(&-A;B!L;V<@:6X@=&\N"B`J"B`J(%!R;W!E<G1I97,@
M=&AA="!C86X@8F4@<V5T(&9O<B!E86-H('-E<G9E<CH*("H*("H@;F%M93H@
M5&AI<R!I<R!T:&4@<&QA:6YT97AT+"!E;F=L:7-H(&YA;64@=&AA="!Y;W4@
M=V%N="!D:7-P;&%Y960*("H@("`@("`@=&\@<&5O<&QE(&EF('EO=2!A<F4@
M=7-I;F<@=&AE(&1R;W`@9&]W;B!S97)V97(@;&ES="X*("H*("H@<V5R=F5R
M.B!4:&4@:&]S=&YA;64@;V8@=&AE(&UA:6P@<V5R=F5R('1O(&-O;FYE8W0@
M=&\N"B`J"B`J(&AO<F1E875T:#H@268@=&AI<R!P87)A;65T97(@:7,@<')E
M<V5N="!A;F0@=')U92P@=&AE;B!)35`@=VEL;"!A='1E;7!T"B`J("`@("`@
M("`@("`@=&\@=7-E('1H92!U<V5R)W,@97AI<W1I;F<@8W)E9&5N=&EA;',@
M*'1H92!U<V5R;F%M92]P87-S=V]R9`H@*B`@("`@("`@("`@('1H97D@=7-E
M9"!T;R!L;V<@:6X@=&\@2&]R9&4I('1O(&QO9R!I;B!T;R!T:&ES('-O=7)C
M92X@268@=&AI<PH@*B`@("`@("`@("`@('!A<F%M971E<B!I<R`G9G5L;"<L
M('1H92!U<V5R;F%M92!W:6QL(&)E('5S960@=6YM;V1I9FEE9#L*("H@("`@
M("`@("`@("!O=&AE<G=I<V4@979E<GET:&EN9R!A9G1E<B!A;F0@:6YC;'5D
M:6YG('1H92!F:7)S="!`(&EN('1H90H@*B`@("`@("`@("`@('5S97)N86UE
M('=I;&P@8F4@<W1R:7!P960@;V9F(&)E9F]R92!A='1E;7!T:6YG(&%U=&AE
M;G1I8V%T:6]N+@H@*@H@*B!P<F]T;V-O;#H@3VYE(&]F('1H92!F;VQL;W=I
M;F<@<W1R:6YG<SH*("H@("`@("`@("`@("`@*R`G:6UA<"]N;W1L<R<*("H@
M("`@("`@("`@("`@*R`G:6UA<"]S<VPG"B`J("`@("`@("`@("`@("L@)VEM
M87`O=&QS)PH@*B`@("`@("`@("`@("`K("=P;W`S+VYO=&QS)PH@*B`@("`@
M("`@("`@("`K("=P;W`S+W-S;"<*("H@("`@("`@("`@("`@*R`G<&]P,R]T
M;',G"B`J"B`J("`@("`@("`@("!)9B!U<VEN9R`G<&]P,R\J)R!Y;W4@=VEL
M;"!C;VYN96-T('1O(&$@4$]0,R!M86EL('-E<G9E<B!A;F0*("H@("`@("`@
M("`@(&%L;"!F;VQD97(@;W!T:6]N<R!W:6QL(&)E(&%U=&]M871I8V%L;'D@
M='5R;F5D(&]F9B`H4$]0,R!D;V5S"B`J("`@("`@("`@("!N;W0@<W5P<&]R
M="!F;VQD97)S*2X@($EF('EO=2!W86YT(&9O;&1E<G,@*&%N9"!F;W(@;75C
M:`H@*B`@("`@("`@("`@:6UP<F]V960@<&5R9F]R;6%N8V4I(&ET(&ES($A)
M1TA,62!214-/34U%3D1%1"!T:&%T($E-05`@<VAO=6QD"B`J("`@("`@("`@
M("!B92!U<V5D(&EN<W1E860N"B`J"B`J("`@("`@("`@("!.3U1%.B!$=64@
M=&\@;&EM:71A=&EO;G,@=VET:&EN(%!(4"P@24U0(&-A;B!O;FQY('-U<'!O
M<G0@875T;RT*("H@("`@("`@("`@("`@("`@(&1E=&5C=&EO;B!O9B!N86UE
M<W!A8V4@<&%R86UE=&5R<R!W:71H($E-05`@5$Q3(&-O;FYE8W1I;VYS"B`J
M("`@("`@("`@("`@("`@("`H92YG("=I;6%P+W1L<R<I(&EF('5S:6YG(%!(
M4"!V97)S:6]N(#4N,2XP(&]R(&=R96%T97(N"B`J("`@("`@("`@("`@("`@
M("!)9B!U<VEN9R!A('9E<G-I;VX@;V8@4$A0(&QE<W,@=&AA;B`U+C$N,"P@
M=&AE(&9O;&QO=VEN9PH@*B`@("`@("`@("`@("`@("`@;W!T:6]N<R!A<F4@
M879A:6QA8FQE.@H@*B`@("`@("`@("`@("`@("`@,2X@4D5#3TU-14Y$140@
M+2!)9B!A('-E8W5R92!)34%0(&-O;FYE8W1I;VX@:7,@;F5E9&5D+"!U<V4*
M("H@("`@("`@("`@("`@("`@("`@(&$@9&ER96-T(&-O;FYE8W1I;VX@=&\@
M82!34TP@96YA8FQE9"!)34%0('!O<G0*("H@("`@("`@("`@("`@("`@("`@
M("AE+F<N("=I;6%P+W-S;"<I+@H@*B`@("`@("`@("`@("`@("`@,BX@268@
M>6]U(&%B<V]L=71E;'D@;75S="!U<V4@5$Q3+"!T:&5N(&ET(&ES(%)%455)
M4D5$('1O"B`J("`@("`@("`@("`@("`@("`@("!D969I;F4@=&AE("=N86UE
M<W!A8V4G('!A<F%M971E<B`H<V5E(&)E;&]W*2X*("H*("H@("`@("`@("`@
M(%1H92!S<VP@86YD('1L<R!O<'1I;VYS('=I;&P@;VYL>2!W;W)K(&EF('EO
M=2=V92!C;VUP:6QE9"!02%`*("H@("`@("`@("`@(&%G86EN<W0@82!34TPM
M96YA8FQE9"!V97)S:6]N(&]F(&,M8VQI96YT+"!U<V5D('1H90H@*B`@("`@
M("`@("`@+2UW:71H+6EM87`M<W-L(&%N9"`M+7=I=&@M;W!E;G-S;"!F;&%G
M<R!W:&5N(&-O;7!I;&EN9R!02%`L"B`J("`@("`@("`@("!A;F0@>6]U(&AA
M=F4@82!M86EL('-E<G9E<B!S97)V97(@=VAI8V@@<W5P<&]R=',@4U-,+@H@
M*@H@*B`@("`@("`@("`@*BH@5&AE('1E<W0@<V-R:7!T(&-A;B!H96QP(&%U
M=&]M871I8V%L;'D@9&5T97)M:6YE('1H92`@("HJ"B`J("`@("`@("`@("`J
M*B!C;W)R96-T('!R;W1O8V]L('9A;'5E('1O('5S92X@(%-E92!T:&4@)U1E
M<W1I;F<@24U0)R`@*BH*("H@("`@("`@("`@("HJ('-E8W1I;VX@;V8@:6UP
M+V1O8W,O24Y35$%,3"!F;W(@:6YS=')U8W1I;VYS(&]N(&AO=R!T;R`J*@H@
M*B`@("`@("`@("`@*BH@86-C97-S('1H92!T97-T('-C<FEP="X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("HJ"B`J"B`J("`@("`@("`@("!.
M3U1%("T@268@>6]U(&%R92!U<VEN9R!A('-E;&8M<VEG;F5D('-E<G9E<B!C
M97)T:69I8V%T92!W:71H"B`J("`@("`@("`@("!E:71H97(@:6UA<"]S<VPL
M(&EM87`O=&QS+"!P;W`S+W-S;"P@;W(@<&]P,R]T;',L('EO=2!-55-4(&%D
M9`H@*B`@("`@("`@("`@)R]N;W9A;&ED871E+6-E<G0G('1O('1H92!E;F0@
M;V8@=&AE('!R;W1O8V]L('-T<FEN9RX@1F]R(&EM87`L"B`J("`@("`@("`@
M("!T:&ES('=O=6QD(&)E("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G(&]R
M"B`J("`@("`@("`@("`G:6UA<"]T;',O;F]V86QI9&%T92UC97)T)RP@86YD
M(&9O<B!P;W`S(&ET('=O=6QD(&)E"B`J("`@("`@("`@("`G<&]P,R]S<VPO
M;F]V86QI9&%T92UC97)T)R!O<B`G<&]P,R]T;',O;F]V86QI9&%T92UC97)T
M)RX@5&AI<PH@*B`@("`@("`@("`@:7,@;F5C97-S87)Y('1O('1E;&P@8RUC
M;&EE;G0@;F]T('1O(&-O;7!L86EN(&%B;W5T('1H92!L86-K(&]F"B`J("`@
M("`@("`@("!A('9A;&ED($-!(&]N('1H92!C97)T:69I8V%T92X*("H*("H@
M<&]R=#H@5&AE('!O<G0@=&AA="!T:&4@;6%I;"!S97)V:6-E+W!R;W1O8V]L
M('EO=2!S96QE8W1E9"!R=6YS(&]N+@H@*B`@("`@("!$969A=6QT('9A;'5E
M<SH*("H@("`@("`@("`G<&]P,R<@("`@,3$P"B`J("`@("`@("`@)W!O<#-S
M)R`@(#DY-0H@*B`@("`@("`@("=I;6%P)R`@("`Q-#,*("H@("`@("`@("`G
M:6UA<',G("`@.3DS"B`J"B`J("`@("`@("HJ(%1H92!T97-T('-C<FEP="!C
M86X@:&5L<"!A=71O;6%T:6-A;&QY(&1E=&5R;6EN92!T:&4@("`@("`J*@H@
M*B`@("`@("`J*B!C;W)R96-T('!O<G0@=F%L=64@=&\@=7-E+B`@4V5E('1H
M92`G5&5S=&EN9R!)35`G('-E8W1I;VX@*BH*("H@("`@("`@*BH@;V8@:6UP
M+V1O8W,O24Y35$%,3"!F;W(@:6YS=')U8W1I;VYS(&]N(&AO=R!T;R!A8V-E
M<W,@=&AE("HJ"B`J("`@("`@("HJ('1E<W0@<V-R:7!T+B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`J*@H@*@H@*B!M
M86EL9&]M86EN.B!7:&%T('1O('!U="!A9G1E<B!T:&4@0"!W:&5N('-E;F1I
M;F<@;6%I;"X@:2YE+B!I9B!Y;W4@=V%N=`H@*B`@("`@("`@("`@("!A;&P@
M;6%I;"!T;R!L;V]K(&QI:V4@)T9R;VTZ('5S97)`97AA;7!L92YC;VTG('-E
M=`H@*B`@("`@("`@("`@("!M86EL9&]M86EN('1O("=E>&%M<&QE+F-O;2<N
M($ET(&ES(&=E;F5R86QL>2!U<V5F=6P@=VAE;@H@*B`@("`@("`@("`@("!T
M:&4@24U!4"!H;W-T(&ES(&1I9F9E<F5N="!F<F]M('1H92!M86EL(')E8V5I
M=FEN9R!H;W-T+B!4:&ES"B`J("`@("`@("`@("`@('=I;&P@86QS;R!B92!U
M<V5D('1O(&-O;7!L971E('5N<75A;&EF:65D(&%D9')E<W-E<R!W:&5N"B`J
M("`@("`@("`@("`@(&-O;7!O<VEN9R!M86EL+@H@*@H@*B!S;71P:&]S=#H@
M268@<W!E8VEF:65D+"!A;F0@)&-O;F9;)VUA:6QE<B==6R=T>7!E)UT@:7,@
M<V5T('1O("=S;71P)RP*("H@("`@("`@("`@($E-4"!W:6QL('5S92!T:&ES
M(&AO<W0@9F]R(&]U=&)O=6YD(%--5%`@8V]N;F5C=&EO;G,N("!4:&ES"B`J
M("`@("`@("`@("!V86QU92!O=F5R<FED97,@86YY(&5X:7-T:6YG("1C;VYF
M6R=M86EL97(G75LG<&%R86US)UU;)VAO<W0G70H@*B`@("`@("`@("`@=F%L
M=64@870@<G5N=&EM92X*("H*("H@<VUT<'!O<G0Z($EF('-P96-I9FEE9"P@
M86YD("1C;VYF6R=M86EL97(G75LG='EP92==(&ES('-E="!T;R`G<VUT<"<L
M"B`J("`@("`@("`@("!)35`@=VEL;"!U<V4@=&AI<R!P;W)T(&9O<B!O=71B
M;W5N9"!33510(&-O;FYE8W1I;VYS+B`@5&AI<R!V86QU90H@*B`@("`@("`@
M("`@;W9E<G)I9&5S(&%N>2!E>&ES=&EN9R`D8V]N9ELG;6%I;&5R)UU;)W!A
M<F%M<R==6R=P;W)T)UT@=F%L=64@870*("H@("`@("`@("`@(')U;G1I;64N
M"B`J"B`J(')E86QM.B!/3DQ9(%5312!214%,32!)1B!93U4@05)%(%5324Y'
M($E-4"!&3U(@2$]21$4@05542$5.5$E#051)3TXL"B`J("`@("`@("!!3D0@
M64]5($A!5D4@355,5$E03$4@4T525D524R!!3D0@55-%4DY!3453($]615),
M05`@0D545T5%3@H@*B`@("`@("`@5$A/4T4@4T525D524RX@268@>6]U(&]N
M;'D@:&%V92!O;F4@<V5R=F5R+"!O<B!H879E(&UU;'1I<&QE"B`J("`@("`@
M("!S97)V97)S('=I=&@@;F\@=7-E<FYA;64@8VQA<VAE<RP@;W(@:&%V92!F
M=6QL('5S97)`97AA;7!L92YC;VT*("H@("`@("`@('5S97)N86UE<RP@>6]U
M($1/($Y/5"!N965D(&$@<F5A;&T@<V5T=&EN9RX@268@>6]U('-E="!O;F4L
M(&%N"B`J("`@("`@("`G0"<@<WEM8F]L('!L=7,@=&AE(')E86QM('=I;&P@
M8F4@87!P96YD960@=&\@=&AE('5S97)N86UE('1H870*("H@("`@("`@('5S
M97)S(&QO9R!I;B!T;R!)35`@=VET:"!T;R!C<F5A=&4@=&AE('5S97)N86UE
M('1H870@2&]R9&4@=')E871S"B`J("`@("`@("!T:&4@=7-E<B!A<RX@4V\@
M=VET:"!A(')E86QM(&]F("=E>&%M<&QE+F-O;2<L('1H92!U<V5R;F%M90H@
M*B`@("`@("`@)VIA;F4G('=O=6QD(&)E('1R96%T960@8GD@2&]R9&4@*$Y/
M5"!Y;W5R($E-05`@<V5R=F5R*2!A<PH@*B`@("`@("`@)VIA;F5`97AA;7!L
M92YC;VTG+"!A;F0@=&AE('5S97)N86UE("=J86YE0&5X86UP;&4N8V]M)R!W
M;W5L9"!B90H@*B`@("`@("`@=')E871E9"!A<R`G:F%N94!E>&%M<&QE+F-O
M;4!E>&%M<&QE+F-O;2<@+2!A;B!O8V-A<VEO;B!W:&5R92!Y;W4*("H@("`@
M("`@('!R;V)A8FQY(&1O;B=T(&YE960@82!R96%L;2!S971T:6YG+@H@*@H@
M*B!P<F5F97)R960Z($]N;'D@=7-E9G5L(&EF('EO=2!W86YT('1O('5S92!T
M:&4@<V%M92!S97)V97)S+G!H<"!F:6QE"B`J("`@("`@("`@("`@9F]R(&1I
M9F9E<F5N="!M86-H:6YE<SH@:68@=&AE(&AO<W1N86UE(&]F('1H92!)35`@
M;6%C:&EN92!I<PH@*B`@("`@("`@("`@(&ED96YT:6-A;"!T;R!O;F4@;V8@
M=&AO<V4@:6X@=&AE('!R969E<G)E9"!L:7-T+"!T:&5N('1H90H@*B`@("`@
M("`@("`@(&-O<G)E<W!O;F1I;F<@;W!T:6]N(&EN('1H92!S96QE8W0@8F]X
M('=I;&P@:6YC;'5D92!314Q%0U1%1`H@*B`@("`@("`@("`@("AI+F4N(&ET
M(&ES('-E;&5C=&5D('!E<B!D969A=6QT*2X@3W1H97)W:7-E('1H92!F:7)S
M="!E;G1R>0H@*B`@("`@("`@("`@(&EN('1H92!L:7-T(&ES('-E;&5C=&5D
M+@H@*@H@*B!Q=6]T83H@57-E('1H:7,@:68@>6]U('=A;G0@=&\@9&ES<&QA
M>2!A('5S97)S('%U;W1A('-T871U<R!O;B!V87)I;W5S"B`J("`@("`@("!)
M35`@<&%G97,N(%-E="`G9')I=F5R)R!E<75A;"!T;R!T:&4@;6%I;'-E<G9E
M<B!A;F0@)W!A<F%M<R<*("H@("`@("`@(&5Q=6%L('1O(&%N>2!E>'1R82!P
M87)A;65T97)S(&YE961E9"!B>2!T:&4@9')I=F5R("AS964@=&AE"B`J("`@
M("`@("!C;VUM96YT<R!L;V-A=&5D(&%T('1H92!T;W`@;V8@:6UP+VQI8B]1
M=6]T82];<75O=&%D<FEV97)=+G!H<`H@*B`@("`@("`@9F]R('1H92!P87)A
M;65T97)S(&YE961E9"!F;W(@96%C:"!D<FEV97(I+@H@*@H@*B`@("`@("`@
M0W5R<F5N=&QY(&%V86EL86)L92!D<FEV97)S.@H@*B`@("`@("`@("!F86QS
M92`@("`@("`@+2T@($1I<V%B;&4@<75O=&$@8VAE8VMI;F<@*$1%1D%53%0I
M"B`J"B`J("`@("`@("`@("=C;VUM86YD)R`@("`M+2`@57-E('1H92!53DE8
M('%U;W1A(&-O;6UA;F0@=&\@9&5T97)M:6YE('%U;W1A<PH@*B`@("`@("`@
M("`G8V]U<FEE<B<@("`@+2T@(%5S92!T:&4@0V]U<FEE<BU)34%0('-E<G9E
M<B!T;R!H86YD;&4@<75O=&%S"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@66]U(&UU<W0@8F4@8V]N;F5C=&EN9R!T;R!A($-O=7)I97(M24U!4"!S
M97)V97(*("H@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!U<V4@=&AI
M<R!D<FEV97(*("H@("`@("`@("`@)V-Y<G5S)R`@("`@("TM("!5<V4@=&AE
M($-Y<G5S($E-05`@<V5R=F5R('1O(&AA;F1L92!Q=6]T87,*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!9;W4@;75S="!B92!C;VYN96-T:6YG('1O
M(&$@0WER=7,@24U!4"!S97)V97(*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T;R!U<V4@=&AI<R!D<FEV97(*("H@("`@("`@("`@)VQO9V9I;&4G
M("`@("TM("!!;&QO=R!Q=6]T87,@;VX@<V5R=F5R<R!W:&5R92!)34%0(%%U
M;W1A"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]M;6%N9',@87)E
M(&YO="!S=7!P;W)T960L(&)U="!Q=6]T82!I;F9O"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87!P96%R<R!I;B!T:&4@<V5R=F5R<R!M97-S86=E
M<R!L;V<@9F]R('1H92!)34%0"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<V5R=F5R+@H@*B`@("`@("`@("`G;61A96UO;B<@("`@+2T@(%5S92!-
M9&%E;6]N('-E<G9E<G,@=&\@:&%N9&QE('%U;W1A<PH@*B`@("`@("`@("`G
M;65R8W5R>3,R)R`@+2T@(%5S92!-97)C=7)Y+S,R('-E<G9E<G,@=&\@:&%N
M9&QE('%U;W1A<PH@*@H@*B!A9&UI;CH@57-E('1H:7,@:68@>6]U('=A;G0@
M=&\@96YA8FQE(&UA:6QB;W@@;6%N86=E;65N="!F;W(@861M:6YI<W1R871O
M<G,*("H@("`@("`@('9I82!(;W)D92=S('5S97(@861M:6YI<W1R871I;VX@
M:6YT97)F86-E+B`@5&AE(&UA:6QB;W@@;6%N86=E;65N=`H@*B`@("`@("`@
M9V5T<R!E;F%B;&5D(&EF('EO=2!L970@24U0(&AA;F1L92!T:&4@2&]R9&4@
M875T:&5N=&EC871I;VX@=VET:"!T:&4*("H@("`@("`@("=A<'!L:6-A=&EO
M;B<@875T:&5N=&EC871I;VX@9')I=F5R+B`@66]U<B!)34%0('-E<G9E<B!N
M965D<R!T;PH@*B`@("`@("`@<W5P<&]R="!M86EL8F]X(&UA;F%G96UE;G0@
M=FEA($E-05`@8V]M;6%N9',N"B`J("`@("`@("!$;R!N;W0@9&5F:6YE('1H
M:7,@=F%L=64@:68@>6]U(&1O(&YO="!W86YT(&UA:6QB;W@@;6%N86=E;65N
M="X*("H*("H@86-L.B!5<V4@=&AI<R!I9B!Y;W4@=V%N="!T;R!U<V4@06-C
M97-S($-O;G1R;VP@3&ES=',@*&9O;&1E<B!S:&%R:6YG*0H@*B`@("`@(%-E
M="`G9')I=F5R)R!E<75A;"!T;R!T:&4@='EP92!O9B!!0TP@>6]U<B!S97)V
M97(@<W5P<&]R=',@86YD"B`J("`@("`@)W!A<F%M<R<@=&\@86X@87)R87D@
M8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!P87)A;65T97)S('1H90H@*B`@
M("`@(&1R:79E<B!N965D<RX@3F]T(&%L;"!)34%0('-E<G9E<G,@8W5R<F5N
M=&QY('-U<'!O<G0@=&AI<PH@*B`@("`@(&9E871U<F4N"B`J"B`J("`@("`@
M070@<')E<V5N="!T:&4@;VYL>2!D<FEV97)S('-U<'!O<G1E9"!A<F4@)W)F
M8S(P.#8G(&%N9"`G<F9C-#,Q-"<@*&EN"BH@("`@("`@2&]R9&4@,RXQ*RDL
M(&YE:71H97(@;V8@=VAI8V@@<F5Q=6ER92!A;GD@<&%R86UE=&5R<RX*("H*
M("H@("`@("!314-54DE462!.3U1%.B!)9B!Y;W4@9&\@;F]T(&AA=F4@=&AE
M(%!%05(@075T:%]305-,(&UO9'5L90H@*B`@("`@(&EN<W1A;&QE9"P@=&AE
M("=R9F,R,#@V)R!D<FEV97(@=VEL;"!S96YD('5S97(@<&%S<W=O<F1S('1O
M('1H90H@*B`@("`@($E-05`@<V5R=F5R(&EN('!L86EN('1E>'0@=VAE;B!R
M971R:65V:6YG($%#3',N"B`J"B`J"B`J("HJ*B!4:&4@9F]L;&]W:6YG(&]P
M=&EO;G,@<VAO=6QD($Y/5"!B92!S970@=6YL97-S('EO=2!214%,3%D@:VYO
M=R!W:&%T("HJ*@H@*B`J*BH@>6]U(&%R92!D;VEN9R$@1D]2($U/4U0@4$5/
M4$Q%+"!!551/+41%5$5#5$E/3B!/1B!42$5312!005)!345415)3("`J*BH*
M("H@*BHJ("AT:&4@9&5F875L="!I9B!T:&4@<&%R86UE=&5R<R!A<F4@;F]T
M('-E="D@4TA/54Q$($)%(%53140A("`@("`@("`@*BHJ"B`J"B`J(&YA;65S
M<&%C93H@5&AE(&QI<W0@;V8@;F%M97-P86-E<R!T:&%T(&5X:7-T(&]N('1H
M92!S97)V97(N("!4:&ES(&5N=')Y"B`J("`@("`@("`@("`@;75S="!B92!A
M;B!A<G)A>2X@17AA;7!L93H*("H@("`@("`@("`@("`G;F%M97-P86-E)R`]
M/B!A<G)A>2@G(W-H87)E9"\G+"`G(VYE=W,O)RP@)R-F='`O)RP@)R-P=6)L
M:6,O)RD*("H@("`@("`@("`@("!4:&ES('!A<F%M971E<B!M=7-T(&)E('-E
M="!I9B!U<VEN9R!A(%1,4R!C;VYN96-T:6]N+@H@*B`@("`@("`@("`@($%D
M9&ET:6]N86QL>2P@=&AI<R!P87)A;65T97(@;6%Y(&)E('-E="!I9B!N;W0@
M=7-I;F<@82!43%,*("H@("`@("`@("`@("!C;VYN96-T:6]N(&%N9"!Y;W4@
M=V%N="!T;R!A;&QO=R!A8V-E<W,@=&\@;F%M97-P86-E<R!T:&%T(&UA>0H@
M*B`@("`@("`@("`@(&YO="!B92!P=6)L:6-L>2!A9'9E<G1I<V5D(&)Y('1H
M92!)34%0('-E<G9E<B`H<V5E(%)&0PH@*B`@("`@("`@("`@(#(S-#(@6S-=
M*2X@5&AE<V4@861D:71I;VYA;"!N86UE<W!A8V5S('=I;&P@8F4@861D960@
M=&\@=&AE(&QI<W0*("H@("`@("`@("`@("!O9B!A=F%I;&%B;&4@;F%M97-P
M86-E<R!R971U<FYE9"!B>2!T:&4@<V5R=F5R+@H@*@H@*B!I;6%P7V-O;F9I
M9SH@36%N=6%L;'D@<V5T($E-05`@<V5R=F5R(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VXN(%!L96%S92!S964*("H@("`@("`@("`@("`@(&AT='`Z+R]W
M:6MI+FAO<F1E+F]R9R]);7!);6%P0V]N9FEG(&9O<B!I;F9O<FUA=&EO;B!O
M;B!T:&ES"B`J("`@("`@("`@("`@("!P87)A;65T97(N("!42$E3(%!!4D%-
M151%4B!)4R!.3U0@3T9&24-)04Q,62!355!03U)4140@0ED@5$A%"B`J("`@
M("`@("`@("`@("!(3U)$12!04D]*14-4+B`@5&AI<R!E;G1R>2!M=7-T(&)E
M(&%N(&%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9PH@*B`@("`@("`@("`@("`@
M96QE;65N=',Z"B`J("`@("`@("`@("`@("`G8VAI;&1R96XG("T@*&)O;VQE
M86XI(%=H971H97(@=&AE($E-05`@<V5R=F5R('-U<'!O<G1S('1H90H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@($-(24Q$4D5.(&-O;6UA;F0N"B`J
M("`@("`@("`@("`@("`G;F%M97-P86-E)R`M("AA<G)A>2D@5&AE(&YA;65S
M<&%C92!C;VYF:6=U<F%T:6]N(&]F('1H90H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S97)V97(N("!3964@=&AE(')E='5R;B!F<F]M"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($E-05!?0VQI96YT.CIN86UE<W!A
M8V4H*2`H;&]C871E9"!I;@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I;7`O;&EB+TE-05`O0VQI96YT+G!H<"D@9F]R('1H92!S=')U8W1U<F4@
M;V8*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!A<G)A>2X*
M("H@("`@("`@("`@("`@("=S96%R8VA?8VAA<G-E="<@+2`H8F]O;&5A;BD@
M5VAE=&AE<B!T:&4@24U!4"!S97)V97(@<W5P<&]R=',*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C:&%R<V5T('-E;&5C=&EO;B!D=7)I
M;F<@<V5A<F-H97,N"B`J"B`J('1I;65O=70Z($UA;G5A;&QY('-E="!S97)V
M97(@=&EM96]U=',N(%1H:7,@;W!T:6]N(&]N;'D@=V]R:W,@=VET:"!02%`@
M/CT*("H@("`@("`@("`@-"XS+C,N(%1H:7,@96YT<GD@;75S="!B92!A;B!A
M<G)A>2!W:71H('1H92!F;VQL;W=I;F<@<&]S<VEB;&4*("H@("`@("`@("`@
M96QE;65N=',@*&EF(&%N(&5L96UE;G0@:7,@;6ES<VEN9RP@=&AE(&1E9F%U
M;'0@=F%L=64@:7,@=7-E9"DZ"B`J("`@("`@("`@($E-05!?3U!%3E1)345/
M550@+2`H:6YT96=E<BD@5&AE('1I;65O=70@9F]R(&]P96X@86-T:6]N<RX*
M("H@("`@("`@("`@24U!4%]214%$5$E-14]55"`M("AI;G1E9V5R*2!4:&4@
M=&EM96]U="!F;W(@<F5A9"!A8W1I;VYS+@H@*B`@("`@("`@("!)34%07U=2
M251%5$E-14]55"`M("AI;G1E9V5R*2!4:&4@=&EM96]U="!F;W(@=W)I=&4@
M86-T:6]N<RX*("H@("`@("`@("`@24U!4%]#3$]3151)345/550@+2`H:6YT
M96=E<BD@5&AE('1I;65O=70@9F]R(&-L;W-E(&%C=&EO;G,N"B`J+PH*+RH@
M06YY(&5N=')I97,@=VAO<V4@:V5Y('9A;'5E("@G9F]O)R!I;B`D<V5R=F5R
M<ULG9F]O)UTI(&)E9VEN('=I=&@@)U\G"B`J("AA;B!U;F1E<G-C;W)E(&-H
M87)A8W1E<BD@=VEL;"!B92!T<F5A=&5D(&%S('!R;VUP=',L(&%N9"!Y;W4@
M=V]N)W0@8F4*("H@86)L92!T;R!L;V<@:6X@=&\@=&AE;2X@5&AE(&]N;'D@
M<')O<&5R='D@=&AE<V4@96YT<FEE<R!N965D(&ES("=N86UE)RX*("H@5&AI
M<R!L971S('EO=2!P=70@;&%B96QS(&EN('1H92!L:7-T+"!L:6ME('1H:7,@
M97AA;7!L93H@*B\*)'-E<G9E<G-;)U]P<F]M<'0G72`](&%R<F%Y*`H@("`@
M)VYA;64G(#T^(%\H(D-H;V]S92!A(&UA:6P@<V5R=F5R.B(I"BD["@HO+R!G
M970@:&]S=&YA;64@9G)O;2!H='1P(%523"`H<&%T8V@@9F]R(%!L97-K*0HD
M:&5A9&5R<R`](&=E=&%L;&AE861E<G,H*3L*)%-E<G9E<DYA;64@/2!P<F5G
M7W)E<&QA8V4H)R]>=V5B;6%I;%PN+R<L("<G+"!P<F5G7W)E<&QA8V4H)R]>
M=W=W7"XO)RP@)R<L("1H96%D97)S6R=(;W-T)UTI*3L*)$1O;6%I;DYA;64@
M/2`H)%-E<G9E<DYA;64@(3T@)R<I(#\@)%-E<G9E<DYA;64@.B`G0$1%1D%5
M3%1?4T525D523D%-14`G.PH*)'-E<G9E<G-;)VEM87`G72`](&%R<F%Y*`H@
M("`@)VYA;64G(#T^("=)34%0(%-E<G9E<B<L"B`@("`G<V5R=F5R)R`]/B`G
M;&]C86QH;W-T)RP*("`@("=H;W)D96%U=&@G(#T^(&9A;'-E+`H@("`@)W!R
M;W1O8V]L)R`]/B`G:6UA<"]N;W1L<R<L"B`@("`G<&]R="<@/3X@,30S+`H@
M("`@)VUA:6QD;VUA:6XG(#T^("1$;VUA:6Y.86UE("P@"B`@("`G<VUT<&AO
M<W0G(#T^("=L;V-A;&AO<W0G+`H@("`@)W-M='!P;W)T)R`]/B`R-2P*("`@
M("=R96%L;2<@/3X@)R<L"B`@("`G<')E9F5R<F5D)R`]/B`G)RP**3L*"B1S
M97)V97)S6R=P;W`G72`](&%R<F%Y*`H@("`@)VYA;64G(#T^("=03U`S(%-E
M<G9E<B<L"B`@("`G<V5R=F5R)R`]/B`G;&]C86QH;W-T)RP*("`@("=H;W)D
M96%U=&@G(#T^(&9A;'-E+`H@("`@)W!R;W1O8V]L)R`]/B`G<&]P,R<L"B`@
M("`G<&]R="<@/3X@,3$P+`H@("`@)VUA:6QD;VUA:6XG(#T^("1$;VUA:6Y.
M86UE+`H@("`@)W-M='!H;W-T)R`]/B`G;&]C86QH;W-T)RP*("`@("=S;71P
M<&]R="<@/3X@,C4L"B`@("`G<F5A;&TG(#T^("<G+`H@("`@)W!R969E<G)E
M9"<@/3X@)R<L"BD["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]I;7`O=')A:6QE
M<BYT>'0`````````````````````````````````````````````````````
M````````````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`R,#,`,3`T,3<S-C(W-#,`,#(P,34T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"E1H
M:7,@;65S<V%G92!W87,@<V5N="!U<VEN9R!)35`L('1H92!);G1E<FYE="!-
M97-S86=I;F<@4')O9W)A;2X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:6UP+V-O;F8N<&AP````````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,3`T`#$P-#$W
M,S8R-S0S`#`Q-S0Q-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+R`D2&]R9&4Z(&EM<"]C;VYF:6<O8V]N9BYX
M;6PL=B`Q+C4S+C(N.2`R,#`V+S`Q+S$T(#$V.C4R.C,T(&5R:6-R($5X<"`D
M"B\J"B`J("!#;VYF:6<@9F]R('!L97-K(&EM<`H@*B\*(`HD8V]N9ELG=71I
M;',G75LG9VYU<&=?:V5Y<V5R=F5R)UT@/2!A<G)A>2@G=W=W:V5Y<RYP9W`N
M;F5T)RD["B1C;VYF6R=U=&EL<R==6R=G;G5P9U]T:6UE;W5T)UT@/2`G,3`G
M.PHD8V]N9ELG=71I;',G75LG;W!E;G-S;%]C869I;&4G72`]("<O=7-R+VQO
M8V%L+W!S82]A9&UI;B]C;VYF+W-S;"YC<G0O8V$M8G5N9&QE+F-R="<["B1C
M;VYF6R=U=&EL<R==6R=O<&5N<W-L7V)I;F%R>2==(#T@)R]U<W(O8FEN+V]P
M96YS<VPG.PHD8V]N9ELG;65N=2==6R=A<'!S)UT@/2!A<G)A>2@G:6UP)RP@
M)VEN9V\G+"`G:W)O;F]L:71H)RP@)W1U<F)A)RD["B1C;VYF6R=U<V5R)UU;
M)V%L;&]W7W9I97=?<V]U<F-E)UT@/2!T<G5E.PHD8V]N9ELG=7-E<B==6R=A
M;&QO=U]R97-U;65?86QL)UT@/2!F86QS93L*)&-O;F9;)W5S97(G75LG86QL
M;W=?<F5S=6UE7V%L;%]I;E]D<F%F=',G72`](&9A;'-E.PHD8V]N9ELG=7-E
M<B==6R=S96QE8W1?<V5N=&UA:6Q?9F]L9&5R)UT@/2!F86QS93L*)&-O;F9;
M)W5S97(G75LG86QL;W=?9F]L9&5R<R==(#T@=')U93L*)&-O;F9;)W5S97(G
M75LG86QT97)N871E7VQO9VEN)UT@/2!F86QS93L*)&-O;F9;)W5S97(G75LG
M<F5D:7)E8W1?;VY?;&]G;W5T)UT@/2!F86QS93L*)&-O;F9;)W5S97(G75LG
M<V5L96-T7W-E;G1M86EL7V9O;&1E<B==(#T@9F%L<V4["B1C;VYF6R=S97)V
M97(G75LG<V5R=F5R7VQI<W0G72`]("=N;VYE)SL*)&-O;F9;)W-E<G9E<B==
M6R=C:&%N9V5?<V5R=F5R)UT@/2!F86QS93L*)&-O;F9;)W-E<G9E<B==6R=C
M:&%N9V5?<&]R="==(#T@9F%L<V4["B1C;VYF6R=S97)V97(G75LG8VAA;F=E
M7W!R;W1O8V]L)UT@/2!F86QS93L*)&-O;F9;)W-E<G9E<B==6R=C:&%N9V5?
M<VUT<&AO<W0G72`](&9A;'-E.PHD8V]N9ELG<V5R=F5R)UU;)V-H86YG95]S
M;71P<&]R="==(#T@9F%L<V4["B1C;VYF6R=S97)V97(G75LG<V]R=%]L:6UI
M="==(#T@)S`G.PHD8V]N9ELG<V5R=F5R)UU;)V-A8VAE7V9O;&1E<G,G72`]
M(&9A;'-E.PHD8V]N9ELG<V5R=F5R)UU;)V-A8VAE7VUS9V)O9'DG72`](&9A
M;'-E.PHD8V]N9ELG;6%I;&)O>"==6R=S:&]W7V%T=&%C:&UE;G1S)UT@/2!F
M86QS93L*)&-O;F9;)VUA:6QB;W@G75LG<VAO=U]P<F5V:65W)UT@/2!F86QS
M93L*)&-O;F9;)VUA:6QB;W@G75LG<VAO=U]X<')I;W)I='DG72`](&9A;'-E
M.PHD8V]N9ELG9F5T8VAM86EL)UU;)W-H;W=?86-C;W5N=%]C;VQO<G,G72`]
M(&9A;'-E.PHD8V]N9ELG9F5T8VAM86EL)UU;)W-I>F5?;&EM:70G72`]("<T
M,#`P,#`P)SL*)&-O;F9;)VUS9W-E='1I;F=S)UU;)V9I;'1E<FEN9R==6R=W
M;W)D<R==(#T@)RXO8V]N9FEG+V9I;'1E<BYT>'0G.PHD8V]N9ELG;7-G<V5T
M=&EN9W,G75LG9FEL=&5R:6YG)UU;)W)E<&QA8V5M96YT)UT@/2`G*BHJ*B<[
M"B1C;VYF6R=S<&%M)UU;)W)E<&]R=&EN9R==(#T@9F%L<V4["B1C;VYF6R=N
M;W1S<&%M)UU;)W)E<&]R=&EN9R==(#T@9F%L<V4["B1C;VYF6R=M<V<G75LG
M<')E<&5N9%]H96%D97(G72`](&9A;'-E.PHD8V]N9ELG;7-G)UU;)V%P<&5N
M9%]T<F%I;&5R)UT@/2!F86QS93L*)&-O;F9;)V-O;7!O<V4G75LG=7-E7W9F
M<R==(#T@9F%L<V4["B1C;VYF6R=C;VUP;W-E)UU;)V%L;&]W7V-C)UT@/2!T
M<G5E.PHD8V]N9ELG8V]M<&]S92==6R=A;&QO=U]B8V,G72`]('1R=64["B1C
M;VYF6R=C;VUP;W-E)UU;)V%L;&]W7W)E8V5I<'1S)UT@/2!T<G5E.PHD8V]N
M9ELG8V]M<&]S92==6R=S<&5C:6%L7V-H87)A8W1E<G,G72`]('1R=64["B1C
M;VYF6R=C;VUP;W-E)UU;)VQI;FM?86QL7V%T=&%C:&UE;G1S)UT@/2!F86QS
M93L*)&-O;F9;)V-O;7!O<V4G75LG;&EN:U]A='1A8VAM96YT<R==(#T@=')U
M93L*)&-O;F9;)V-O;7!O<V4G75LG;&EN:U]A='1A8VAM96YT<U]N;W1I9GDG
M72`]('1R=64["B1C;VYF6R=C;VUP;W-E)UU;)V%D9%]M86EL9&]M86EN7W1O
M7W5N97AP86YD86)L92==(#T@9F%L<V4["B1C;VYF6R=C;VUP;W-E)UU;)V%T
M=&%C:%]S:7IE7VQI;6ET)UT@/2`G,"<["B1C;VYF6R=C;VUP;W-E)UU;)V%T
M=&%C:%]C;W5N=%]L:6UI="==(#T@)S`G.PHD8V]N9ELG:&]O:W,G75LG=FEN
M9F\G72`](&9A;'-E.PHD8V]N9ELG:&]O:W,G75LG<VEG;F%T=7)E)UT@/2!F
M86QS93L*)&-O;F9;)VAO;VMS)UU;)W1R86EL97(G72`](&9A;'-E.PHD8V]N
M9ELG:&]O:W,G75LG9F5T8VAM86EL7V9I;'1E<B==(#T@9F%L<V4["B1C;VYF
M6R=H;V]K<R==6R=M8F]X7W)E9&ER96-T)UT@/2!F86QS93L*)&-O;F9;)VAO
M;VMS)UU;)VUB;WA?:6-O;B==(#T@9F%L<V4["B1C;VYF6R=H;V]K<R==6R=S
M<&%M7V)O=6YC92==(#T@9F%L<V4["B1C;VYF6R=M86EL;&]G)UU;)W5S95]M
M86EL;&]G)UT@/2!T<G5E.PHD8V]N9ELG=&%S:VQI<W0G75LG=7-E7W1A<VML
M:7-T)UT@/2!T<G5E.PHD8V]N9ELG;F]T97!A9"==6R=U<V5?;F]T97!A9"==
M(#T@=')U93L*+RH@0T].1DE'($5.1"X@1$\@3D]4($-(04Y'12!!3EE42$E.
M1R!)3B!/4B!"149/4D4@5$A)4R!,24Y%+B`J+PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O971C+W!S
M82UH;W)D92]I;7`O8V]N9BYX;6P`````````````````````````````````
M````````````````````````````````````````````,#$P,#0T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-#0W,S8`,3`T,3<S-C(W-#,`,#$W-#0S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_>&UL
M('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:6UP+V-O;F9I9R]C;VYF
M+GAM;"QV(#$N-3,N,BXY(#(P,#8O,#$O,30@,38Z-3(Z,S0@97)I8W(@17AP
M("0@+2T^"CQC;VYF:6=U<F%T:6]N/@H@/&-O;F9I9W1A8B!N86UE/2)U=&EL
M<R(@9&5S8STB17AT97)N86P@571I;&ET:65S(&%N9"!-96YU(CX*("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)U=&EL<R(^"B`@(#QC;VYF:6=H96%D97(^17AT
M97)N86P@571I;&ET:65S/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB<W!E;&QC:&5C:V5R(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(D5N=&5R('1H92!L;V-A=&EO;@H@("!O9B!T:&4@8FEN87)Y('1O(&5I=&AE
M<B!A<W!E;&P@;W(@:7-P96QL('1O(&5N86)L92!T:&4@<W!E;&P@8VAE8VME
M<BX@268*("`@=&AI<R!I<R!E;7!T>2P@=&AE;B!S<&5L;"!C:&5C:VEN9R!W
M:6QL(&)E(&1I<V%B;&5D+B(^/"]C;VYF:6=S=')I;F<^"B`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB9VYU<&<B(')E<75I<F5D/2)F86QS92(@9&5S8STB268@
M>6]U('=A;G0@=7-E<G,@=&\@:&%V90H@("!T:&4@;W!T:6]N(&]F('5S:6YG
M('1H92!'3E4@4')I=F%C>2!'=6%R9"!P<F]G<F%M('1O(&1E8W)Y<'0O96YC
M<GEP="!01U`*("`@9FEL97,L(&5N=&5R('1H92!L;V-A=&EO;B!O9B!T:&4@
M)V=P9R<@8FEN87)Y(&AE<F4N("!)9B!T:&ES(&ES(&5M<'1Y('1H:7,*("`@
M9F5A='5R92!W:6QL(&)E(&1I<V%B;&5D+B(^/"]C;VYF:6=S=')I;F<^"B`@
M(#QC;VYF:6=M=6QT:65N=6T@;F%M93TB9VYU<&=?:V5Y<V5R=F5R(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E1H92!A9&1R97-S(&]F"B`@('1H92!P=6)L
M:6,@4$=0(&ME>7-E<G9E<BAS*2!T;R!U<V4N(CYW=W=K97ES+G!G<"YN970*
M("`@(#QV86QU97,^"B`@("`@/'9A;'5E/G=W=VME>7,N<&=P+FYE=#PO=F%L
M=64^"B`@("`@/'9A;'5E/G=W=RYK97ES97)V97(N;F5T/"]V86QU93X*("`@
M("`\=F%L=64^<&=P+FUI="YE9'4\+W9A;'5E/@H@("`@/"]V86QU97,^"B`@
M(#PO8V]N9FEG;75L=&EE;G5M/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](F=N
M=7!G7W1I;65O=70B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('1I;65O
M=70@9F]R"B`@(&-O;FYE8W1I;F<@=&\@=&AE(%!'4"!K97ES97)V97(N(%1I
M;65O=71S(&%R92!N;W0@<W5P<&]R=&5D(&]N(&%L;`H@("!S>7-T96US+B(^
M,3`\+V-O;F9I9W-T<FEN9SX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)O<&5N
M<W-L7V-A9FEL92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;&]C871I
M;VX@;V8*("`@=&AE(')O;W0@8V5R=&EF:6-A=&5S(&)U;F1L92P@92YG+B`O
M971C+W-S;"]C97)T<RX@4V5E"B`@(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU
M86PO96XO<F5F+F]P96YS<VPN<&AP(V]P96YS<VPN8V5R="YV97)I9FEC871I
M;VX@9F]R"B`@(&1E=&%I;',N(B\^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M;W!E;G-S;%]B:6YA<GDB(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&QO
M8V%T:6]N(&]F"B`@('1H92!/<&5N4U-,(&)I;F%R>2!O;B!Y;W5R('-Y<W1E
M;2P@92YG+B`O=7-R+V)I;B]O<&5N<W-L+B!4:&ES('!R;V=R86T@:7,*("`@
M4D5154E2140@=&\@:6UP;W)T('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T
M92!I;F9O<FUA=&EO;BP@87,@=&AE<F4@:7,@;F\*("`@;F%T:79E(%!(4"!F
M=6YC=&EO;B!T:&%T(&-A;B!R96%D('!K8W,Q,B!F:6QE<RXB+SX*("`\+V-O
M;F9I9W-E8W1I;VX^"@H@(#QC;VYF:6=S96-T:6]N(&YA;64](FUE;G4B/@H@
M("`\8V]N9FEG:&5A9&5R/DUE;G4@<V5T=&EN9W,\+V-O;F9I9VAE861E<CX*
M("`@/&-O;F9I9VUU;'1I96YU;2!N86UE/2)A<'!S(B!D97-C/2)396QE8W0@
M86YY(&%P<&QI8V%T:6]N<R!T:&%T('-H;W5L9"!B90H@("!L:6YK960@:6X@
M24U0)W,@;65N=2(^"B`@("`\=F%L=65S/@H@("`@(#QC;VYF:6=S<&5C:6%L
M(&YA;64](FQI<W0M:&]R9&4M87!P<R(@+SX*("`@(#PO=F%L=65S/@H@("`\
M+V-O;F9I9VUU;'1I96YU;3X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I
M9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](G5S97(B(&1E<V,](E5S97(@0V%P
M86)I;&ET:65S(&%N9"!#;VYS=')A:6YT<R(^"B`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB=7-E<B(^"B`@(#QC;VYF:6=H96%D97(^57-E<B!#87!A8FEL:71I
M97,@86YD($-O;G-T<F%I;G1S/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S
M=VET8V@@;F%M93TB86QL;W=?9F]L9&5R<R(@9&5S8STB4VAO=6QD('=E(&%L
M;&]W('5S97)S('1O('5S90H@("!F;VQD97)S(&%T(&%L;#\@3D]413H@<V5T
M=&EN9R!T:&ES('1O(&9A;'-E('=I;&P@;65A;B!T:&5R92!I<R!N;R!P;&%C
M92!T;PH@("!S879E('-E;G0M;6%I;"!O<B!P;W-T<&]N960@;65S<V%G97,L
M(&%L;VYG('=I=&@@=&AE(&]B=FEO=7,@869F96-T<R!O9@H@("!R97-T<FEC
M=&EN9R!T:&4@=7-E<B!T;R!T:&5I<B!)3D)/6"XB/G1R=64*("`@(#QC87-E
M(&YA;64](G1R=64B(&1E<V,](EEE<R(^"B`@("`@/&-O;F9I9V)O;VQE86X@
M;F%M93TB86QL;W=?=FEE=U]S;W5R8V4B(&1E<V,](DEF('1H:7,@:7,@=')U
M92P@=&AE;B!T:&5R90H@("`@('=I;&P@8F4@82`G365S<V%G92!3;W5R8V4G
M(&QI;FL@:6X@=&AE('!A<G1S(&QI<W0@;V8@979E<GD@;65S<V%G92P@86QL
M;W=I;F<*("`@("!T:&4@=7-E<B!T;R!V:65W('1H92!E;G1I<F4@<F%W(&UE
M<W-A9V4L(&]R('1O(&1O=VYL;V%D(&ET(&%N9"!S879E(&ET('1O"B`@("`@
M9&ES:RXB/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@("`@/&-O;F9I9V)O;VQE
M86X@;F%M93TB86QL;W=?<F5S=6UE7V%L;"(@9&5S8STB268@=&AI<R!I<R!T
M<G5E+"!T:&4@=7-E<B!W:6QL"B`@("`@8F4@86)L92!T;R!R97-U;64@86YY
M(&UE<W-A9V4@:6X@86YY(&UA:6QB;W@N("!/=&AE<G=I<V4L(&]N;'D@;65S
M<V%G97,*("`@("!M87)K960@87,@)V1R869T<R<@8V%N(&)E(')E<W5M960N
M(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`\8V]N9FEG8F]O;&5A;B!N
M86UE/2)A;&QO=U]R97-U;65?86QL7VEN7V1R869T<R(@9&5S8STB268@=&AI
M<R!I<R!T<G5E+"!T:&4*("`@("!U<V5R('=I;&P@8F4@86)L92!T;R!R97-U
M;64@86YY(&UE<W-A9V4@:6X@=&AE:7(@9')A9G0@;6%I;&)O>"`H=&\*("`@
M("!C;VUP96YS871E(&9O<B!S;VUE(&-L:65N=',@=&AA="!D;VXG="!B;W1H
M97(@<V5T=&EN9R!T:&4@9')A9G0@9FQA9RDN"B`@("`@3W1H97)W:7-E+"!O
M;FQY(&UE<W-A9V5S(&UA<FME9"!A<R`G9')A9G1S)R!C86X@8F4*("`@("!R
M97-U;65D+B(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/&-O;F9I9V)O
M;VQE86X@;F%M93TB<V5L96-T7W-E;G1M86EL7V9O;&1E<B(@9&5S8STB268@
M=&AI<R!I<R!T<G5E+"!T:&5N"B`@("`@=7-E<G,@=VEL;"!B92!G:79E;B!A
M(&1R;W`@9&]W;B!M96YU(&EN('1H92!C;VUP;W-E('=I;F1O=R!A;&QO=VEN
M9R!T:&5M('1O"B`@("`@8VAO;W-E('=H:6-H(&9O;&1E<B!T;R!S879E('1H
M96ER('-E;G0@;65S<V%G97,@=&\N($EF('1H:7,@:7,@9F%L<V4L('1H96X*
M("`@("!M97-S86=E<R!W:6QL(&)E('-A=F5D('1O('1H92!F;VQD97(@9&5F
M:6YE9"!I;B!T:&5I<@H@("`@('!R969E<F5N8V5S+B(^9F%L<V4\+V-O;F9I
M9V)O;VQE86X^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)F86QS92(@
M9&5S8STB3F\B("\^"B`@(#PO8V]N9FEG<W=I=&-H/@H@("`\8V]N9FEG<W1R
M:6YG(&YA;64](F%L=&5R;F%T95]L;V=I;B(@9&5S8STB268@=&AI<R!I<R!N
M;W0@9F%L<V4L(&ET(&ES"B`@(&%S<W5M960@=&\@8F4@=&AE(%523"!O9B!A
M;B!A;'1E<FYA=&4@;&]G:6X@<V-R965N('=H:6-H('=I;&P@8F4@=7-E9"!I
M;@H@("!P;&%C92!O9B!)35`G<R!D969A=6QT(&]N92X@)FQT.V(F9W0[5&AI
M<R!S971T:6YG('=I;&P@8F4@:6=N;W)E9"!I9B!A;@H@("!A;'1E<FYA=&4@
M;&]G:6X@<V-R965N(&ES(&-O;F9I9W5R960@9F]R(&AO<F1E+B9L=#LO8B9G
M=#LB/@H@("!F86QS93PO8V]N9FEG<W1R:6YG/@H@("`\8V]N9FEG<W1R:6YG
M(&YA;64](G)E9&ER96-T7V]N7VQO9V]U="(@9&5S8STB268@=&AI<R!I<R!N
M;W0@9F%L<V4L(&ET(&ES"B`@(&%S<W5M960@=&\@8F4@=&AE(%523"!O9B!A
M;B!A;'1E<FYA=&4@;&]G;W5T('!A9V4@=VAI8V@@=7-E<G,@=VEL;"!B92!S
M96YT"B`@('1O('=H96X@=&AE>2!L;V<@;W5T+B`F;'0[8B9G=#M4:&ES('-E
M='1I;F<@=VEL;"!B92!I9VYO<F5D(&EF(&%N(&%L=&5R;F%T90H@("!L;V=O
M=70@<&%G92!I<R!C;VYF:6=U<F5D(&9O<B!H;W)D929L=#LO8B9G=#LB/F9A
M;'-E/"]C;VYF:6=S=')I;F<^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF
M:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)S97)V97(B(&1E<V,](DUA:6P@
M4V5R=F5R(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S97)V97(B/@H@("`\
M8V]N9FEG:&5A9&5R/DUA:6P@4V5R=F5R(%-E='1I;F=S/"]C;VYF:6=H96%D
M97(^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB<V5R=F5R7VQI<W0B(&1E<V,]
M(E-H;W5L9"!W92!D:7-P;&%Y(&$@;&ES="!O9B!S97)V97)S"B`@("AD969I
M;F5D(&EN(&-O;F9I9R]S97)V97)S+G!H<"D@9F]R('5S97)S('1O(&-H;V]S
M92!F<F]M/R!4:&4@;W!T:6]N<R!A<F4*("`@)W-H;W=N)RP@)VAI9&1E;B<L
M(&%N9"`G;F]N92<N($EF('1H92!S97)V97(@;&ES="!I<R!H:61D96X@=&AE
M;B!Y;W4@8V%N('5S90H@("!T:&4@)W!R969E<G)E9"<@;65C:&%N:7-M('1O
M(&%U=&\M<V5L96-T(&9R;VT@:70@8F%S960@;VX@86X@2%144`H@("!V:7)T
M=6%L:&]S="!O<B!A;F]T:&5R('!I96-E(&]F(&1A=&$N($EF(&ET(&ES('-H
M;W=N+"!T:&4@=7-E<B!W:6QL(&)E(&%B;&4*("`@=&\@<&EC:R!F<F]M(&%N
M>2!O9B!T:&4@;W!T:6]N<RX@268@;F]N92P@;F\@<V5R=F5R(&QI<W0@=VEL
M;"!B92!S:&]W;B!A;F0*("`@=&AE(&1E9F%U;'1S('=I;&P@8F4@=7-E9"!U
M;FQE<W,@86YO=&AE<B!M96-H86YI<VT@8VAA;F=E<R!T:&5M+B(^;F]N90H@
M("`@/&-A<V4@;F%M93TB;F]N92(@9&5S8STB3F]N92(^"B`@("`@/&-O;F9I
M9V)O;VQE86X@;F%M93TB8VAA;F=E7W-E<G9E<B(@9&5S8STB4VAO=6QD('=E
M(&%L;&]W('5S97)S('1O('1Y<&4@:6X@82!M86EL"B`@("`@<V5R=F5R/R(^
M9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/&-O;F9I9V)O;VQE86X@;F%M
M93TB8VAA;F=E7W!O<G0B(&1E<V,](E-H;W5L9"!W92!A;&QO=R!U<V5R<R!T
M;R!S96QE8W0@=&AE(&UA:6P*("`@("!S97)V97(G<R!P;W)T/R(^9F%L<V4\
M+V-O;F9I9V)O;VQE86X^"B`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB8VAA
M;F=E7W!R;W1O8V]L(B!D97-C/2)3:&]U;&0@=V4@86QL;W<@=7-E<G,@=&\@
M<V5L96-T('1H90H@("`@(&UA:6P@<V5R=F5R)W,@<')O=&]C;VP_(CYF86QS
M93PO8V]N9FEG8F]O;&5A;CX*("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)C
M:&%N9V5?<VUT<&AO<W0B(&1E<V,](E-H;W5L9"!W92!A;&QO=R!U<V5R<R!T
M;R!S96QE8W0@=&AE"B`@("`@4TU44"`H;W5T8F]U;F0I(&UA:6P@<V5R=F5R
M/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/&-O;F9I9V)O;VQE86X@
M;F%M93TB8VAA;F=E7W-M='!P;W)T(B!D97-C/2)3:&]U;&0@=V4@86QL;W<@
M=7-E<G,@=&\@<V5L96-T('1H90H@("`@(%--5%`@<V5R=F5R)W,@<&]R=#\B
M/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@/"]C87-E/@H@("`@/&-A<V4@
M;F%M93TB<VAO=VXB(&1E<V,](E-H;W=N(B`O/@H@("`@/&-A<V4@;F%M93TB
M:&ED9&5N(B!D97-C/2)(:61D96XB("\^"B`@(#PO8V]N9FEG<W=I=&-H/@H@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G-O<G1?;&EM:70B(&1E<V,](D]N('-L
M;W=E<B!M86EL<V5R=F5R<RP@<V]R=&EN9R!B>2!A;GD*("`@9FEE;&0@;W1H
M97(@=&AA;B!T:&4@87)R:79A;"!O9B!T:&4@;65S<V%G92!M87D@<F5S=6QT
M(&EN('9E<GD@<VQO=PH@("!P97)F;W)M86YC92X@($EF('1H92!N=6UB97(@
M:&5R92!I<R!G<F5A=&5R('1H86X@,"P@=&AA="!I<R!T:&4@;G5M8F5R(&]F
M"B`@(&UE<W-A9V5S('1H870@;75S="!B92!P<F5S96YT(&EN(&$@;6%I;&)O
M>"!B969O<F4@=&AE(&1E9F%U;'0@<V]R="!I<PH@("!R97!L86-E9"!B>2!T
M:&4@;75C:"!F87-T97(@87)R:79A;"!T:6UE('-O<G0N(CXP/"]C;VYF:6=S
M=')I;F<^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](F-A8VAE7V9O;&1E<G,B
M(&1E<V,](DEF('5S:6YG($E-05`L('-H;W5L9"!W92!C86-H92!T:&4*("`@
M;&ES="!O9B!F;VQD97)S('-O('1H870@=&AE(&QI<W0@9&]E<R!N;W0@;F5E
M9"!T;R!B92!R96)U:6QT(&]N(&5V97)Y('!A9V4*("`@;&]A9#\@268@<V5T
M('1O('1R=64L(&YO=&4@=&AA="!A;GD@9F]L9&5R<R!C<F5A=&5D(&]N('1H
M92!S97)V97(@9'5R:6YG(&%N"B`@($E-4"!S97-S:6]N('1H870@:7,@3D]4
M(&-R96%T960@=FEA($E-4"!W:6QL(&YO="!B92!D:7-P;&%Y960@=6YT:6P@
M=&AE(&YE>'0*("`@;&]G:6XN($EF($E-4"!W:6QL(&)E('1H92!E>&-L=7-I
M=F4@;65A;G,@;V8@86-C97-S:6YG('1H92!M86EL('-E<G9E<BP@;W(*("`@
M>6]U(&%R92!N;W0@8V]N8V5R;F5D(&%B;W5T('1H:7,@8F5H879I;W(L('1H
M:7,@<V5T=&EN9R!S:&]U;&0@8F4@<V5T('1O"B`@('1R=64N(CYF86QS93PO
M8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB8V%C:&5?
M;7-G8F]D>2(@9&5S8STB4VAO=6QD('=E(&-A8VAE('1H92!C;VYT96YT<R!O
M9@H@("!S;6%L;"!M97-S86=E<R`H;&5S<R!T:&%N(#$P($M"*2!I;B!T:&4@
M<V5S<VEO;B!S;R!T:&%T('1H92!)34%0('-E<G9E<B!D;V5S"B`@(&YO="!H
M879E('1O(&)E(&%C8V5S<V5D(&%G86EN/R`@16YA8FQI;F<@=&AI<R!O<'1I
M;VX@=VEL;"!R97-U;'0@:6X@82!L87)G97(*("`@<V5S<VEO;B!S:7IE("AA
M<'!R;W@N(#$P,"`M(#(P,"!+0B!P97(@=7-E<BD@<V\@;6%K92!S=7)E('EO
M=7(@<V5S<VEO;@H@("!B86-K96YD(&-A;B!H86YD;&4@=&AE(&EN8W)E87-E
M9"!S=&]R86=E(&1E;6%N9',N(CX*("`@9F%L<V4\+V-O;F9I9V)O;VQE86X^
M"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A
M8B!N86UE/2)M86EL8F]X(B!D97-C/2)-86EL8F]X(&%N9"!&971C:&UA:6PB
M/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](FUA:6QB;W@B/@H@("`\8V]N9FEG
M:&5A9&5R/DUA:6QB;W@@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@/&-O
M;F9I9V)O;VQE86X@;F%M93TB<VAO=U]A='1A8VAM96YT<R(@9&5S8STB4VAO
M=6QD('=E(&1I<W!L87D@871T86-H;65N=`H@("!I;F9O<FUA=&EO;B!I;B!T
M:&4@;6%I;&)O>"!I;F1E>#\@5&AI<R!I<R!A('!E<F9O<FUA;F-E(&AI="P@
M8G5T(&UA>2!B92!O:V%Y"B`@(&]N('-M86QL97(@:6YS=&%L;&%T:6]N<RXB
M/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE
M/2)S:&]W7W!R979I97<B(&1E<V,](E-H;W5L9"!W92!A;&QO=R!U<V5R<R!T
M;R!D:7-P;&%Y"B`@(&UE<W-A9V4@<')E=FEE=W,@:6X@=&AE(&UA:6QB;W@@
M:6YD97@_(%1H:7,@:7,@82!P97)F;W)M86YC92!H:70L(&)U="!M87D@8F4@
M;VMA>0H@("!O;B!S;6%L;&5R(&EN<W1A;&QA=&EO;G,N(CYF86QS93PO8V]N
M9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<VAO=U]X<')I
M;W)I='DB(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y(&UE<W-A9V4*("`@<')I
M;W)I='D@:6YF;W)M871I;VX@:6X@=&AE(&UA:6QB;W@@:6YD97@_(%1H:7,@
M:7,@82!P97)F;W)M86YC92!H:70L(&)U="!M87D@8F4@;VMA>0H@("!O;B!S
M;6%L;&5R(&EN<W1A;&QA=&EO;G,N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*
M("`\+V-O;F9I9W-E8W1I;VX^"@H@(#QC;VYF:6=S96-T:6]N(&YA;64](F9E
M=&-H;6%I;"(^"B`@(#QC;VYF:6=H96%D97(^1F5T8VAM86EL(%-E='1I;F=S
M/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](G-H;W=?
M86-C;W5N=%]C;VQO<G,B(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y(&-O;&]R
M<R!F;W(*("`@;65S<V%G97,@9F5T8VAE9"!F<F]M(&]T:&5R(&%C8V]U;G1S
M(&EN('1H92!M86EL8F]X(&EN9&5X/R!4:&ES(&ES(&$*("`@<&5R9F]R;6%N
M8V4@:&ET+"!B=70@;6%Y(&)E(&]K87D@;VX@<VUA;&QE<B!I;G-T86QL871I
M;VYS+B(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<VEZ95]L:6UI="(@9&5S8STB5VAA="!I<R!T:&4@;6%X:6UU;2!T
M;W1A;"!S:7IE(&]F"B`@(&UA:6QS('1O(&)E(&9E=&-H960@*&EN(&)Y=&5S
M*3\@*%)E;65M8F5R('EO=2!N965D(&UO<F4@=&AA;B!T:&4@9&]U8FQE(&]F
M"B`@('1H:7,@=F%L=64@9F]R("=M96UO<GE?;&EM:70G(&EN('!H<"YI;FDN
M*2!3970@=&AI<R!V86QU92!T;R`P(&9O<B!N;PH@("!L:6UI="XB/C0P,#`P
M,#`\+V-O;F9I9W-T<FEN9SX*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I
M9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](FUS9W-E='1I;F=S(B!D97-C/2)-
M97-S86=E(&%N9"!3<&%M(CX*("`\8V]N9FEG:&5A9&5R/DUE<W-A9V4@4V5T
M=&EN9W,\+V-O;F9I9VAE861E<CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)M
M<V=S971T:6YG<R(^"B`@(#QC;VYF:6=S96-T:6]N(&YA;64](F9I;'1E<FEN
M9R(^"B`@("`\8V]N9FEG<W1R:6YG(&YA;64](G=O<F1S(B!D97-C/2))9B!F
M:6QT97)I;F<@;V8@;65S<V%G92!C;VYT96YT(&ES('1U<FYE9`H@("`@;VXL
M('=H97)E('-H;W5L9"!W92!F:6YD('1H92!L:7-T(&]F('=O<F1S('1O(&9I
M;'1E<@H@("`@;W5T/R(^+B]C;VYF:6<O9FEL=&5R+G1X=#PO8V]N9FEG<W1R
M:6YG/@H@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)R97!L86-E;65N="(@9&5S
M8STB5VAA="!S:&]U;&0@=V4@<F5P;&%C92!F:6QT97)E9`H@("`@=V]R9',@
M=VET:#\B/BHJ*BH\+V-O;F9I9W-T<FEN9SX*("`@/"]C;VYF:6=S96-T:6]N
M/@H@(#PO8V]N9FEG<V5C=&EO;CX*"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB
M<W!A;2(^"B`@(#QC;VYF:6=H96%D97(^4W!A;2!297!O<G1I;F<\+V-O;F9I
M9VAE861E<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)R97!O<G1I;F<B(&1E
M<V,](E-H;W5L9"!W92!D:7-P;&%Y(&$@)W)E<&]R="!T:&ES"B`@(&UE<W-A
M9V4@87,@<W!A;2<@;&EN:S\B/F9A;'-E"B`@("`\8V%S92!N86UE/2)T<G5E
M(B!D97-C/2)997,B/@H@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G-P86UF
M;VQD97(B(&1E<V,](E-H;W5L9"!T:&4@;&EN:R!A;'-O(&%P<&5A<B!I;B!T
M:&4@=7-E<B=S"B`@("`@<W!A;2!F;VQD97(_(CYF86QS93PO8V]N9FEG8F]O
M;&5A;CX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F5M86EL(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E-H;W5L9"!W92!R97!O<G0@<W!A;2!M97-S86=E
M<PH@("`@('9I82!E;6%I;#\@5&AE(&UE<W-A9V5S('=I;&P@8F4@<V5N="!T
M;R!T:&ES(&%D9')E<W,@:6X@82!S:6YG;&4*("`@("!M=6QT:7!A<G0O9&EG
M97-T(&UE<W-A9V4@*'5S969U;"!F;W(@<F5P;W)T:6YG('1O(&%N(&%D;6EN
M('5S97(L(&9O<@H@("`@(&5X86UP;&4I+B(O/@H@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB8F]U;F-E(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E-H;W5L
M9"!W92!B;W5N8V4@=&AE('-P86T*("`@("!M97-S86=E('1O(&%N(&5M86EL
M(&%D9')E<W,_(%1H:7,@:7,@=7-E9G5L(&9O<B!A=71O;6%T960@<W!A;2!P
M<F]C97-S:6YG"B`@("`@<')O9W)A;7,@=&AA="!N965D('1H92!O<FEG:6YA
M;"!M97-S86=E+B!)9B!Y;W4@;F5E9"!T;R!D>6YA;6EC86QL>2!S970@=&AE
M"B`@("`@96UA:6P@861D<F5S<R!F;W(@96%C:"!U<V5R("AE+F<N($134$%-
M*2P@=&AI<R!S971T:6YG('-H;W5L9"!B92!E;7!T>2!A;F0*("`@("!Y;W4@
M<VAO=6QD(&QO;VL@870@=&AE(%]I;7!?:&]O:U]S<&%M7V)O=6YC92!H;V]K
M(&EN<W1E860N(B\^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P<F]G<F%M
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E-H;W5L9"!W92!R97!O<G0@=&AE
M('-P86T*("`@("!M97-S86=E('9I82!A;B!E>'1E<FYA;"!P<F]G<F%M("AE
M+F<N("]U<W(O;&]C86PO8FEN+W-P86UA<W-A<W-I;B`M<BD_($EF('EO=0H@
M("`@(&EN8VQU9&4@=&AE('!L86-E:&]L9&5R("5U(&EN('1H:7,@<W1R:6YG
M+"!I="!W:6QL(&)E(')E<&QA8V5D('=I=&@@=&AE"B`@("`@8W5R<F5N="!U
M<V5R;F%M92XB+SX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](F9A;'-E
M(B!D97-C/2).;R(@+SX*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S
M96-T:6]N/@H*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)N;W1S<&%M(CX*("`@
M/&-O;F9I9W-W:71C:"!N86UE/2)R97!O<G1I;F<B(&1E<V,](E-H;W5L9"!W
M92!D:7-P;&%Y(&$@)W)E<&]R="!T:&ES"B`@(&UE<W-A9V4@87,@:6YN;V-E
M;G0G(&QI;FL_(CYF86QS90H@("`@/&-A<V4@;F%M93TB=')U92(@9&5S8STB
M665S(CX*("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)S<&%M9F]L9&5R(B!D
M97-C/2)3:&]U;&0@=&AE(&QI;FL@;VYL>2!A<'!E87(@:6X@=&AE('5S97(G
M<PH@("`@('-P86T@9F]L9&5R/R(^=')U93PO8V]N9FEG8F]O;&5A;CX*("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](F5M86EL(B!R97%U:7)E9#TB9F%L<V4B
M(&1E<V,](E-H;W5L9"!W92!R97!O<G0@:6YN;V-E;G0*("`@("!M97-S86=E
M<R!V:6$@96UA:6P_(%1H92!M97-S86=E<R!W:6QL(&)E('-E;G0@=&\@=&AI
M<R!A9&1R97-S(&EN(&$@<VEN9VQE"B`@("`@;75L=&EP87)T+V1I9V5S="!M
M97-S86=E("AU<V5F=6P@9F]R(')E<&]R=&EN9R!T;R!A;B!A9&UI;B!U<V5R
M+"!F;W(*("`@("!E>&%M<&QE*2XB+SX*("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](F)O=6YC92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)3:&]U;&0@=V4@
M8F]U;F-E('1H90H@("`@(&EN;F]C96YT(&UE<W-A9V4@=&\@86X@96UA:6P@
M861D<F5S<S\@5&AI<R!I<R!U<V5F=6P@9F]R(&%U=&]M871E9"!S<&%M('!R
M;V-E<W-I;F<*("`@("!P<F]G<F%M<R!T:&%T(&YE960@=&AE(&]R:6=I;F%L
M(&UE<W-A9V4N($EF('EO=2!N965D('1O(&1Y;F%M:6-A;&QY('-E="!T:&4*
M("`@("!E;6%I;"!A9&1R97-S(&9O<B!E86-H('5S97(@*&4N9RX@1%-004TI
M+"!T:&ES('-E='1I;F<@<VAO=6QD(&)E(&5M<'1Y(&%N9`H@("`@(&%N9"!Y
M;W4@<VAO=6QD(&QO;VL@870@=&AE(%]I;7!?:&]O:U]S<&%M7V)O=6YC92!H
M;V]K(&EN<W1E860N(B\^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P<F]G
M<F%M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E-H;W5L9"!W92!R97!O<G0@
M=&AE(&EN;F]C96YT"B`@("`@;65S<V%G92!V:6$@86X@97AT97)N86P@<')O
M9W)A;2`H92YG+B`O=7-R+VQO8V%L+V)I;B]S<&%M87-S87-S:6X@+6LI/R!)
M9B!Y;W4*("`@("!I;F-L=61E('1H92!P;&%C96AO;&1E<B`E=2!I;B!T:&ES
M('-T<FEN9RP@:70@=VEL;"!B92!R97!L86-E9"!W:71H('1H90H@("`@(&-U
M<G)E;G0@=7-E<FYA;64N(B\^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE
M/2)F86QS92(@9&5S8STB3F\B("\^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO
M8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M
M93TB8V]M<&]S92(@9&5S8STB0V]M<&]S92(^"B`@/&-O;F9I9VAE861E<CY#
M;VUP;W-E(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB;7-G(CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<')E<&5N
M9%]H96%D97(B(&1E<V,](E-H;W5L9"!W92!I;F-L=61E('1H92!C;VYT96YT
M<R!O9@H@("!I;7`O8V]N9FEG+VAE861E<BYT>'0@:6X@=&AE(&AE861E<G,@
M;V8@979E<GD@;65S<V%G90H@("!S96YT/R(^=')U93PO8V]N9FEG8F]O;&5A
M;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB87!P96YD7W1R86EL97(B(&1E
M<V,](E-H;W5L9"!W92!A<'!E;F0@=&AE(&-O;G1E;G1S(&]F"B`@(&EM<"]C
M;VYF:6<O=')A:6QE<BYT>'0@=&\@=&AE(&5N9"!O9B!E=F5R>2!M97-S86=E
M"B`@('-E;G0_(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@(#PO8V]N9FEG<V5C
M=&EO;CX*"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB8V]M<&]S92(^"B`@(#QC
M;VYF:6=B;V]L96%N(&YA;64](F%L;&]W7V-C(B!D97-C/2)3:&]U;&0@=V4@
M86QL;W<@=7-E<G,@=&\@<V5T('1H92!#8SH*("`@:&5A9&5R/R(^=')U93PO
M8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB86QL;W=?
M8F-C(B!D97-C/2)3:&]U;&0@=V4@86QL;W<@=7-E<G,@=&\@<V5T('1H92!"
M8V,Z"B`@(&AE861E<C\B/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF
M:6=B;V]L96%N(&YA;64](F%L;&]W7W)E8V5I<'1S(B!D97-C/2)#86X@=&AE
M('5S97(@<F5Q=65S="!A(')E='5R;@H@("!R96-E:7!T/R(^=')U93PO8V]N
M9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<W!E8VEA;%]C
M:&%R86-T97)S(B!D97-C/2)3:&]U;&0@=V4@9VEV92!T:&4@=7-E<B!A"B`@
M('!O<"UU<"!W:6YD;W<@=VET:"!S<&5C:6%L(&-H87)A8W1E<G,@:6X@:70_
M(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE
M/2)U<V5?=F9S(B!D97-C/2)3:&]U;&0@=V4@=7-E('1H92!(;W)D92!61E,@
M<WES=&5M(&9O<@H@("!S=&]R:6YG('5P;&]A9&5D(&%T=&%C:&UE;G1S/R(^
M9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB
M;&EN:U]A='1A8VAM96YT<R(@9&5S8STB4VAO=6QD('=E(&%L;&]W('1H92!U
M<V5R<R!T;PH@("!S96YD(&%T=&%C:&UE;G1S(&%S(&QI;FMS/R(^=')U90H@
M("`@/&-A<V4@;F%M93TB=')U92(@9&5S8STB665S(CX*("`@("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)L:6YK7V%L;%]A='1A8VAM96YT<R(@9&5S8STB4VAO
M=6QD($E-4"!S96YD(&%L;`H@("`@(&%T=&%C:&UE;G1S(&%S(&QI;FMS/R!)
M9B!T:&ES(&ES(&9A;'-E('1H92!U<V5R('=I;&P@8F4@9VEV96X@=&AE(&]P
M=&EO;@H@("`@('1O(&QI;FL@86YY(&%T=&%C:&UE;G0N(CYF86QS93PO8V]N
M9FEG8F]O;&5A;CX*("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)L:6YK7V%T
M=&%C:&UE;G1S7VYO=&EF>2(@9&5S8STB4VAO=6QD($E-4"!S96YD(&%N"B`@
M("`@92UM86EL(&YO=&EF:6-A=&EO;B!T;R!T:&4@<V5N9&5R('=H96X@=&AE
M(&9I<G-T('!E<G-O;B!A='1E;7!T<R!T;PH@("`@(&1O=VYL;V%D('1H92!L
M:6YK960@871T86-H;65N=#\@5&AI<R!N;W1I9FEC871I;VX@=VEL;"!I;F-L
M=61E(&$@;&EN:PH@("`@('1O(&1E;&5T92!T:&4@9FEL92XB/G1R=64\+V-O
M;F9I9V)O;VQE86X^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)F86QS
M92(@9&5S8STB3F\B("\^"B`@(#PO8V]N9FEG<W=I=&-H/@H@("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)A9&1?;6%I;&1O;6%I;E]T;U]U;F5X<&%N9&%B;&4B
M(&1E<V,](E-H;W5L9"!W92!A9&0@=&AE"B`@(&1E9F%U;'0@9&]M86EN('1O
M(&%D9')E<W-E<R!T:&%T(&-O=6QD;B=T(&)E(&5X<&%N9&5D"B`@(&%U=&]M
M871I8V%L;'D_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)A='1A8VA?<VEZ95]L:6UI="(@9&5S8STB5VAA="!I<R!T
M:&4@;6%X:6UU;2!T;W1A;"!S:7IE"B`@(&]F(&%T=&%C:&UE;G1S('!E<B!M
M97-S86=E("AI;B!B>71E<RD_(%-E="!T:&ES('9A;'5E('1O(#`@9F]R(&YO
M"B`@(&QI;6ET+B!;3F]T92P@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4@
M;V8@86YY(&EN9&EV:61U86P@871T86-H;65N="!I<R!S970*("`@=FEA('1H
M92!02%`@)W5P;&]A9%]M87A?9FEL97-I>F4G('!A<F%M971E<B`M('-E90H@
M("!I;7`O9&]C<R])3E-404Q,72(^,#PO8V]N9FEG<W1R:6YG/@H@("`\8V]N
M9FEG<W1R:6YG(&YA;64](F%T=&%C:%]C;W5N=%]L:6UI="(@9&5S8STB5VAA
M="!I<R!T:&4@;6%X:6UU;2!T;W1A;`H@("!N=6UB97(@;V8@871T86-H;65N
M=',@<&5R(&UE<W-A9V4_(%-E="!T:&ES('9A;'5E('1O(#`@9F]R(&YO"B`@
M(&QI;6ET+B(^,#PO8V]N9FEG<W1R:6YG/@H@(#PO8V]N9FEG<V5C=&EO;CX*
M(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB:&]O:W,B(&1E<V,]
M(D-U<W1O;2!(;V]K<R(^"B`@/&-O;F9I9VAE861E<CY#=7-T;VT@2&]O:W,\
M+V-O;F9I9VAE861E<CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)H;V]K<R(^
M"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](G9I;F9O(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E-H;W5L9"!W92!U<V4@82!C=7-T;VT*("`@=FER='5A;"!U
M<V5R<R!H;V]K/R!)9B!S;RP@;6%K92!S=7)E('EO=2!D969I;F4@7VEM<%]H
M;V]K7W9I;F9O*"D@:6X*("`@:&]R9&4O8V]N9FEG+VAO;VMS+G!H<"X@5&AE
M(&AO;VL@=VEL;"!B92!U<V5D('1O('-E="`D:6UP6R=U<V5R)UT@870@;&]G
M:6X*("`@=&EM92X@5&AE<F4@87)E(&5X86UP;&5S(&EN"B`@(&AO<F1E+V-O
M;F9I9R]H;V]K<RYP:'`N9&ES="XB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@
M("`\8V]N9FEG8F]O;&5A;B!N86UE/2)S:6=N871U<F4B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB4VAO=6QD('=E('5S92!A"B`@(&-U<W1O;2!S:6=N871U
M<F4@:&]O:S\@268@<V\L(&UA:V4@<W5R92!Y;W4@9&5F:6YE(%]I;7!?:&]O
M:U]S:6=N871U<F4H*2!I;@H@("!H;W)D92]C;VYF:6<O:&]O:W,N<&AP+B!4
M:&4@:&]O:R!W:6QL(&)E('5S960@=&\@<V5T("1I;7!;)W5S97(G72!W:&5N
M"B`@(&-O;7!O<VEN9R!A(&UE<W-A9V4N(%1H97)E(&ES(&%N(&5X86UP;&4@
M:6X*("`@:&]R9&4O8V]N9FEG+VAO;VMS+G!H<"YD:7-T+B(^9F%L<V4\+V-O
M;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](G1R86EL97(B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB4VAO=6QD('=E('5S92!A(&-U<W1O
M;0H@("!F=6YC=&EO;B!T;R!S970@=&AE('1R86EL97(@=&5X="`H:68@=')A
M:6QE<B!T97AT(&ES(&%P<&5N9&5D('1O(&]U=&=O:6YG"B`@(&UE<W-A9V5S
M*3\@268@<V\L(&UA:V4@<W5R92!Y;W4@9&5F:6YE(%]I;7!?:&]O:U]T<F%I
M;&5R*"D@:6X*("`@:&]R9&4O8V]N9FEG+VAO;VMS+G!H<"X@5&AE(&9U;F-T
M:6]N('=I;&P@8F4@=7-E9"!T;R!M;V1I9GD@=&AE('1R86EL97(@870*("`@
M<G5N=&EM92X@5&AE<F4@87)E(&5X86UP;&5S(&EN"B`@(&AO<F1E+V-O;F9I
M9R]H;V]K<RYP:'`N9&ES="XB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`\
M8V]N9FEG8F]O;&5A;B!N86UE/2)F971C:&UA:6Q?9FEL=&5R(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E-H;W5L9"!W92!U<V4*("`@82!C=7-T;VT@9G5N
M8W1I;VX@=&\@9FEL=&5R(&UA:6P@<F5T<FEE=F5D('=I=&@@=&AE($%C8V]U
M;G1S+T9E=&-H;6%I;"!I8V]N/PH@("!)9B!S;RP@;6%K92!S=7)E('EO=2!D
M969I;F4@7VEM<%]H;V]K7V9E=&-H;6%I;%]F:6QT97(H*2!I;@H@("!H;W)D
M92]C;VYF:6<O:&]O:W,N<&AP+B`@5&AE(&9U;F-T:6]N(&ES('5S960@=&\@
M9FEL=&5R(&UA:6P@9F]R(%-P86TL"B`@('9I<G5S97,L(&]R('=H871E=F5R
M(&5L<V4@>6]U('-E="!U<"!I;B!T:&4@9G5N8W1I;VXN(CYF86QS93PO8V]N
M9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB;6)O>%]R961I
M<F5C="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)3:&]U;&0@=V4@=7-E"B`@
M(&$@8W5S=&]M(&9U;F-T:6]N('1O(&1Y;F%M:6-A;&QY(')E9&ER96-T('1H
M92!U<V5R(&)A<V5D(&]N('=H870@;6%I;&)O>`H@("!I<R!O<&5N960_($EF
M('-O+"!M86ME('-U<F4@>6]U(&1E9FEN92!?:6UP7VAO;VM?;6)O>%]R961I
M<F5C="@I(&EN"B`@(&AO<F1E+V-O;F9I9R]H;V]K<RYP:'`N(CYF86QS93PO
M8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB;6)O>%]I
M8V]N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E-H;W5L9"!W92!U<V4*("`@
M82!C=7-T;VT@9G5N8W1I;VX@=&\@9'EN86UI8V%L;'D@9&5T97)M:6YE('1H
M92!I8V]N<R!S:&]W;B!F;W(@<W1A;F1A<F0*("`@9F]L9&5R<R!O;B!T:&4@
M9F]L9&5R('!A9V4_($EF('-O+"!M86ME('-U<F4@>6]U(&1E9FEN90H@("!?
M:6UP7VAO;VM?;6)O>%]I8V]N<R@I(&EN(&AO<F1E+V-O;F9I9R]H;V]K<RYP
M:'`N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@
M;F%M93TB<W!A;5]B;W5N8V4B(')E<75I<F5D/2)F86QS92(@9&5S8STB4VAO
M=6QD('=E('5S92!A"B`@(&-U<W1O;2!F=6YC=&EO;B!T;R!D>6YA;6EC86QL
M>2!G96YE<F%T92!T:&4@96UA:6P@861D<F5S<R!T;R!S96YD('-P86T*("`@
M<F5P;W)T:6YG(&5M86EL<R!T;S\@268@<V\L(&UA:V4@<W5R92!Y;W4@9&5F
M:6YE(%]I;7!?:&]O:U]S<&%M7V)O=6YC92@I(&EN"B`@(&AO<F1E+V-O;F9I
M9R]H;V]K<RYP:'`N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`\+V-O;F9I
M9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](F]T
M:&5R(B!D97-C/2)/=&AE<B!S971T:6YG<R(^"B`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB;6%I;&QO9R(^"B`@(#QC;VYF:6=H96%D97(^36%I;"!,;V=G:6YG
M/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](G5S95]M
M86EL;&]G(B!D97-C/2)">2!D969A=6QT+"!)35`@=VEL;"!K965P('1R86-K
M(&]F"B`@(&)O=&@@=VAO(&$@;65S<V%G92!W87,@<V5N="!T;R!A;F0@=&AE
M(&1A=&4@:70@=V%S('-E;G0@=VAE;B!F;W)W87)D:6YG+`H@("!R97!L>6EN
M9RP@;W(@<F5D:7)E8W1I;F<@82!M97-S86=E+B!4:&ES(&EN9F]R;6%T:6]N
M(&ES('-T;W)E9"!U<VEN9R!T:&4*("`@2&ES=&]R>2!C;&%S<R!P<F]V:61E
M9"!B>2!(;W)D92X@5&AE<V4@96YT<FEE<R!A<F4@9&5L971E9"!W:&5N('1H
M92!M86EL(&ES"B`@(&1E;&5T960@=7-I;F<@24U0(&EN(&%N(&%T=&5M<'0@
M=&\@:V5E<"!T:&4@;G5M8F5R(&]F(&5N=')I97,@=&\@=&AE"B`@(&UI;FEM
M=6T@<F5Q=6ER960@+2!I9B!N;W0@9&5L971E9"!T:&4@;6%I;&QO9R!E;G1R
M>2!W:6QL('!E<G-I<W0@9F]R979E<BX*("`@3VX@;&%R9V4@:6YS=&%L;&%T
M:6]N<RP@=&AE<F4@;6%Y(&)E('-I9VYI9FEC86YT(&QO;VMU<"!T:6UE<R!A
M;F0O;W(@;&%R9V4*("`@86UO=6YT<R!O9B!M86EL;&]G(&5N=')I97,@=VET
M:"!O;&1E<B!V97)S:6]N<R!O9B!(;W)D92!B969O<F4@2&]R9&4@,RXQ('-O
M"B`@('1H:7,@9G5N8W1I;VYA;&ET>2!C86X@8F4@='5R;F5D(&]F9BXB/G1R
M=64\+V-O;F9I9V)O;VQE86X^"B`@/"]C;VYF:6=S96-T:6]N/@H*("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)T87-K;&ES="(^"B`@(#QC;VYF:6=H96%D97(^
M061D('1O(%1A<VMS/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=B;V]L96%N
M(&YA;64](G5S95]T87-K;&ES="(@9&5S8STB268@3F%G(&ES(&EN<W1A;&QE
M9"!O;B!T:&4@;&]C86P*("`@<WES=&5M+"!)35`@8V%N(&%L;&]W('5S97)S
M('1O(&%D9"!T:&4@9&5T86EL<R!O9B!M86EL(&UE<W-A9V5S('1O(&$@;F5W
M"B`@('1A<VLN($EF('EO=2!D;R!N;W0@=V%N="!T:&ES(&9U;F-T:6]N86QI
M='D@96YA8FQE9"`H:70@=VEL;"!A9&0@=&\@<V5R=F5R"B`@(&QO860@8F5C
M875S92!T:&4@;&ES="!O9B!A=F%I;&%B;&4@=&%S:R!C871E9V]R:65S(&UU
M<W0@8F4@9V5N97)A=&5D(&]N"B`@(&5V97)Y('!A9V4@;&]A9"DL('EO=2!S
M:&]U;&0@9&ES86)L92!T:&ES(&-H96-K8F]X+B(^=')U93PO8V]N9FEG8F]O
M;&5A;CX*("`\+V-O;F9I9W-E8W1I;VX^"@H@(#QC;VYF:6=S96-T:6]N(&YA
M;64](FYO=&5P860B/@H@("`\8V]N9FEG:&5A9&5R/D%D9"!T;R!.;W1E<SPO
M8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)U<V5?;F]T
M97!A9"(@9&5S8STB268@36YE;6\@:7,@:6YS=&%L;&5D(&]N('1H92!L;V-A
M;`H@("!S>7-T96TL($E-4"!C86X@86QL;W<@=7-E<G,@=&\@861D('1H92!D
M971A:6QS(&]F(&UA:6P@;65S<V%G97,@=&\@82!N97<*("`@;F]T92X@268@
M>6]U(&1O(&YO="!W86YT('1H:7,@9G5N8W1I;VYA;&ET>2!E;F%B;&5D("AI
M="!W:6QL(&%D9"!T;R!S97)V97(*("`@;&]A9"!B96-A=7-E('1H92!L:7-T
M(&]F(&%V86EL86)L92!N;W1E(&-A=&5G;W)I97,@;75S="!B92!G96YE<F%T
M960@;VX*("`@979E<GD@<&%G92!L;V%D*2P@>6]U('-H;W5L9"!D:7-A8FQE
M('1H:7,@8VAE8VMB;W@N(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@(#PO8V]N
M9FEG<V5C=&EO;CX*"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB=&]S(CX*("`@
M/&-O;F9I9VAE861E<CY497)M<R!O9B!397)V:6-E($%G<F5E;65N=#PO8V]N
M9FEG:&5A9&5R/@H@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F:6QE(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](DEF('EO=2!W86YT('1O(')E<75I<F4@=7-E
M<G,@=&\*("`@(&%C8V5P="!C97)T86EN('1E<FUS(&)E9F]R92!T:&5Y(&-A
M;B!U<V4@=&AE('-Y<W1E;2P@96YT97(@=&AE(&YA;64@;V8@=&AE"B`@("!A
M9W)E96UE;G0@9FEL92!T;R!D:7-P;&%Y(&AE<F4N($%L<V\L(&UA:V4@<W5R
M92!T;R!A8W1I=F%T92!T:&4@<')E9F5R96YC92!I;@H@("`@<')E9G,N<&AP
M("AS970@=&AE('9A;'5E(&]F("=T;W-?86=R965M96YT)R!T;R`Q*2XB+SX*
M("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*/"]C;VYF:6=U<F%T
M:6]N/@H`````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:6UP+V9I;'1E<BYT>'0`````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S<S`#$P-#$W
M,S8R-S0S`#`R,#`P-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C("1(;W)D93H@:6UP+V-O;F9I9R]F:6QT97(N='AT+F1I
M<W0L=B`Q+C$@,C`P,"\P.2\Q-2`P,CHR,#HS-R!J;VX@17AP("0*(PHC($5N
M=&5R(&$@;&ES="!O9B!W;W)D<R!T:&%T('=I;&P@8F4@9FEL=&5R960N("!/
M;FQY('!U="!O;F4@=V]R9"!O;B!E86-H"B,@;&EN92X@($-O;6UE;G1S(&%R
M92!A;&QO=V5D+B`@02!C;VUM96YT('-T87)T<R!W:71H(&$@)R,G(&%N9"!E
M;F1S(&%T('1H90HC(&5N9"!O9B!T:&4@;&EN92X*(PIP;V]P"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]E
M=&,O<'-A+6AO<F1E+W1U<F)A+P``````````````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,38S
M,3,`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O='5R8F$O+FAT86-C97-S
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#$V
M`#$P-#$W,S8R-S0S`#`R,#$P,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!$96YY(&9R;VT@86QL"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]E=&,O<'-A+6AO<F1E+W1U<F)A+VUE;G4N<&AP````````````````
M```````````````````````````````````````````````````````````P
M,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0U-@`Q,#0Q-S,V,C<T
M,P`P,3<W-S(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(;W)D93H@='5R8F$O8V]N9FEG+VUE;G4N
M<&AP+F1I<W0L=B`Q+C0@,C`P-"\Q,2\P-B`Q.#HT-SHQ-2!J86X@17AP("0*
M("H*("H@5&AI<R!F:6QE(&QE=',@>6]U(&5X=&5N9"!4=7)B82=S(&UE;G4@
M=VET:"!Y;W5R(&]W;B!I=&5M<RX*("H*("H@5&\@861D(&$@;F5W(&UE;G4@
M:71E;2P@<VEM<&QY(&%D9"!A(&YE=R!E;G1R>2!T;R!T:&4@)%]M96YU(&%R
M<F%Y+@H@*B!686QI9"!A='1R:6)U=&5S(&9O<B!A(&YE=R!M96YU(&ET96T@
M87)E.@H@*@H@*B`@)W5R;"<@("`@("`@5&AE(%523"!V86QU92!F;W(@=&AE
M(&UE;G4@:71E;2X*("H@("=T97AT)R`@("`@(%1H92!T97AT('1O(&%C8V]M
M<&%N>2!T:&4@;65N=2!I=&5M+@H@*@H@*B!4:&5S92!A='1R:6)U=&5S(&%R
M92!O<'1I;VYA;#H*("H*("H@("=I8V]N)R`@("`@(%1H92!F:6QE;F%M92!O
M9B!A;B!I8V]N('1O('5S92!F;W(@=&AE(&UE;G4@:71E;2X*("H@("=I8V]N
M7W!A=&@G(%1H92!P871H('1O('1H92!I8V]N(&EF(&ET(&1O97-N)W0@97AI
M<W0@:6X@=&AE(&=R87!H:6-S+PH@*B`@("`@("`@("`@("`@9&ER96-T;W)Y
M+@H@*B`@)W1A<F=E="<@("`@5&AE(")T87)G970B(&]F('1H92!L:6YK("AE
M+F<N("=?=&]P)RP@)U]B;&%N:R<I+@H@*B`@)V]N8VQI8VLG("`@06YY($IA
M=F%38W)I<'0@=&\@97AE8W5T92!O;B!T:&4@(F]N8VQI8VLB(&5V96YT+@H@
M*@H@*B!(97)E)W,@86X@97AA;7!L92!E;G1R>3H*("H*("H@("1?;65N=5M=
M(#T@87)R87DH("`@"B`J("`@("`@)W5R;"<@/3X@("`@("`@("=H='1P.B\O
M=W=W+F5X86UP;&4N8V]M+R<L"B`J("`@("`@)W1E>'0G(#T^("`@("`@("=%
M>&%M<&QE+"!);F,N)RP*("H@("`@("`G:6-O;B<@/3X@("`@("`@)V5X86UP
M;&4N<&YG)RP*("H@("`@("`G:6-O;E]P871H)R`]/B`@)VAT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:6UA9V5S+R<L"B`J("`@("`@)W1A<F=E="<@/3X@("`@
M("=?8FQA;FLG+`H@*B`@("`@("=O;F-L:6-K)R`]/B`@("`G)PH@*B`@*3L*
M("H*("H@66]U(&-A;B!A;'-O(&%D9"!A(")S97!A<F%T;W(B("AA('-P86-E
M<BD@8F5T=V5E;B!M96YU(&ET96US+B`@5&\@861D(&$*("H@<V5P87)A=&]R
M+"!S:6UP;'D@861D(&$@;F5W('-T<FEN9R!T;R!T:&4@)%]M96YU(&%R<F%Y
M('-E="!T;R!T:&4@=&5X=`H@*B`G<V5P87)A=&]R)RX@($ET('-H;W5L9"!L
M;V]K(&QI:V4@=&AI<SH*("H*("H@("1?;65N=5M=(#T@)W-E<&%R871O<B<[
M"B`J+PH*)%]M96YU(#T@87)R87DH*3L*"B\J($%D9"!Y;W5R(&-U<W1O;2!E
M;G1R:65S(&)E;&]W('1H:7,@;&EN92X@*B\*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O='5R
M8F$O<')E9G,N<&AP````````````````````````````````````````````
M`````````````````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$R,34V`#$P-#$W,S8R-S0S`#`R,#$T,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!T=7)B82]C;VYF:6<O<')E9G,N<&AP+F1I<W0L=B`Q+C(X+C$P+C(@
M,C`P-2\Q,"\R-"`Q-3HS.3HQ,B!J86X@17AP("0*("H*("H@4V5E(&AO<F1E
M+V-O;F9I9R]P<F5F<RYP:'`@9F]R(&1O8W5M96YT871I;VX@;VX@=&AE('-T
M<G5C='5R92!O9B!T:&ES(&9I;&4N"B`J+PH*)'!R969'<F]U<'-;)V%D9')E
M<W-B;V]K<R==(#T@87)R87DH"B`@("`G8V]L=6UN)R`]/B!?*")$:7-P;&%Y
M($]P=&EO;G,B*2P*("`@("=L86)E;"<@/3X@7R@B061D<F5S<R!";V]K<R(I
M+`H@("`@)V1E<V,G(#T^(%\H(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS
M('1O('5S92XB*2P*("`@("=M96UB97)S)R`]/B!A<G)A>2@G9&5F875L=%]D
M:7(G+"`G861D<F5S<V)O;VMS96QE8W0G*0HI.PH*)'!R969'<F]U<'-;)V-O
M;'5M;G,G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B1&ES<&QA>2!/
M<'1I;VYS(BDL"B`@("`G;&%B96PG(#T^(%\H(D-O;'5M;B!/<'1I;VYS(BDL
M"B`@("`G9&5S8R<@/3X@7R@B4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P
M;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+B(I+`H@("`@)VUE;6)E<G,G(#T^
M(&%R<F%Y*"=C;VQU;6YS96QE8W0G*0HI.PH*)'!R969'<F]U<'-;)V1I<W!L
M87DG72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B1&ES<&QA>2!/<'1I
M;VYS(BDL"B`@("`G;&%B96PG(#T^(%\H(D1I<W!L87DB*2P*("`@("=D97-C
M)R`]/B!?*")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L('-O
M<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+B(I+`H@("`@)VUE;6)E
M<G,G(#T^(&%R<F%Y*"=I;FET:6%L7W!A9V4G+"`G<V]R=&)Y)RP@)W-O<G1D
M:7(G+"`G;6%X<&%G92<L("=P97)P86=E)RP@)V%D=E]R97-U;'1S7W!L86-E
M;65N="<I"BD["@HD<')E9D=R;W5P<ULG9F]R;6%T)UT@/2!A<G)A>2@*("`@
M("=C;VQU;6XG(#T^(%\H(D1I<W!L87D@3W!T:6]N<R(I+`H@("`@)VQA8F5L
M)R`]/B!?*").86UE($9O<FUA="(I+`H@("`@)V1E<V,G(#T^(%\H(E-E;&5C
M="!W:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RXB*2P*("`@("=M96UB
M97)S)R`]/B!A<G)A>2@G;F%M95]F;W)M870G*0HI.PH*)'!R969'<F]U<'-;
M)V%P<&QI8V%T:6]N)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H(D]T
M:&5R($]P=&EO;G,B*2P*("`@("=L86)E;"<@/3X@7R@B1&5L971E($-O;F9I
M<FUA=&EO;B(I+`H@("`@)V1E<V,G(#T^(%\H(D1E;&5T92!B=71T;VX@8F5H
M879I;W5R(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)V1E;&5T95]O<'0G
M*0HI.PH*:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=I;7-P)UU;)V5N
M86)L960G72D@?'P*("`@("%I<W-E="@D1TQ/0D%,4ULG8V]N9B==6R=I;7-P
M)UU;)V5N86)L960G72DI('L*("`@("1P<F5F1W)O=7!S6R=I;7-P)UT@/2!A
M<G)A>2@*("`@("`@("`G8V]L=6UN)R`]/B!?*")/=&AE<B!/<'1I;VYS(BDL
M"B`@("`@("`@)VQA8F5L)R`]/B!?*"))35-0($%D9')E<W,@0F]O:R!!9&UI
M;FES=')A=&EO;B(I+`H@("`@("`@("=D97-C)R`]/B!?*")!9&0@86YD($1E
M;&5T92!)35-0(&%D9')E<W,@8F]O:W,B*2P*("`@("`@("`G;65M8F5R<R<@
M/3X@87)R87DH)VEM<W!?;W!T)RD*("`@("D["GT*"B\O(&%D9')E<W,@8F]O
M:R!S96QE8W1I;VX@=VED9V5T"B1?<')E9G-;)V%D9')E<W-B;V]K<V5L96-T
M)UT@/2!A<G)A>2@*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G
M(#T^("=S<&5C:6%L)PHI.PH*+R\@861D<F5S<R!B;V]K<R!T;R!B92!D:7-P
M;&%Y960*)%]P<F5F<ULG861D<F5S<V)O;VMS)UT@/2!A<G)A>2@*("`@("=V
M86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O
M(&-O;'5M;G,@<V5L96-T:6]N('=I9&=E=`HD7W!R969S6R=C;VQU;6YS96QE
M8W0G72`](&%R<F%Y*`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G='EP
M92<@/3X@)W-P96-I86PG"BD["@HO+R!C;VQU;6YS('1O(&)E(&1I<W!L87EE
M9`HD7W!R969S6R=C;VQU;6YS)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M(FQO8V%L<W%L7'1E;6%I;"(L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@
M("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<*
M*3L*"B\O('5S97(@<')E9F5R<F5D('-O<G1I;F<@8V]L=6UN"B\O('IE<F\@
M8F%S960@:6YT(')E<')E<V5N=&EN9R!T:&4@8V]L=6UN(&YU;6)E<B!T;R!S
M;W)T(&)Y"B1?<')E9G-;)W-O<G1B>2==(#T@87)R87DH"B`@("`G=F%L=64G
M(#T^(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^
M(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O('5S97(@
M<')E9F5R<F5D('-O<G1I;F<@9&ER96-T:6]N"B1?<')E9G-;)W-O<G1D:7(G
M72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G
M96YU;2<L"B`@("`G96YU;2<@/3X@87)R87DH,"`]/B!?*")!<V-E;F1I;F<B
M*2P*("`@("`@("`@("`@("`@("`@("`Q(#T^(%\H(D1E<V-E;F1I;F<B*2DL
M"B`@("`G9&5S8R<@/3X@7R@B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB
M*0HI.PH*+R\@;G5M8F5R(&]F(&UA>&EM=6T@<&%G97,@86YD(&ET96US('!E
M<B!P86=E"B1?<')E9G-;)VUA>'!A9V4G72`](&%R<F%Y*`H@("`@)W9A;'5E
M)R`]/B`Q,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VYU;6)E<B<L"B`@("`G9&5S8R<@
M/3X@7R@B36%X:6UU;2!N=6UB97(@;V8@<&%G97,B*0HI.PH*)%]P<F5F<ULG
M<&5R<&%G92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#(P+`H@("`@)VQO
M8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T
M>7!E)R`]/B`G;G5M8F5R)RP*("`@("=D97-C)R`]/B!?*").=6UB97(@;V8@
M:71E;7,@<&5R('!A9V4B*0HI.PH*+R\@=&AE('!A9V4@=&\@9&ES<&QA>2X@
M($5I=&AE<B`G8G)O=W-E+G!H<"<@;W(@)W-E87)C:"YP:'`G"B1?<')E9G-;
M)VEN:71I86Q?<&%G92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=S96%R
M8V@N<&AP)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V1E<V,G(#T^
M(%\H(E9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.B(I+`H@("`@)V5N=6TG
M(#T^(&%R<F%Y*"=B<F]W<V4N<&AP)R`]/B!?*")!9&1R97-S($)O;VL@3&ES
M=&EN9R(I+`H@("`@("`@("`@("`@("`@("`@("=S96%R8V@N<&AP)R`]/B!?
M*")396%R8V@B*2D**3L*"B\O('1H92!F;W)M870@=&\@9&ES<&QA>2!N86UE
M<RX@($5I=&AE<B`G;&%S=%]F:7)S="<@;W(@)V9I<G-T7VQA<W0G"B1?<')E
M9G-;)VYA;65?9F]R;6%T)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)VYO
M;F4G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F
M86QS92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G9&5S8R<@/3X@7R@B
M4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA;65S.B(I+`H@
M("`@)V5N=6TG(#T^(&%R<F%Y*"=L87-T7V9I<G-T)R`]/B!?*")<(DQA<W1N
M86UE+"!&:7)S=&YA;65<(B`H:64N($1O92P@2F]H;BDB*2P*("`@("`@("`@
M("`@("`@("`@("`G9FER<W1?;&%S="<@/3X@7R@B7")&:7)S=&YA;64@3&%S
M=&YA;65<(B`@*&EE+B!*;VAN($1O92DB*2P*("`@("`@("`@("`@("`@("`@
M("`G;F]N92<@/3X@7R@B;F\@9F]R;6%T=&EN9R(I*0HI.PH*+R\@1&5F875L
M="!D:7)E8W1O<GD*)%]P<F5F<ULG9&5F875L=%]D:7(G72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`G)RP*("`@("\O("=V86QU92<@/3X@)VQO8V%L<W%L
M)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U
M92P*("`@("=T>7!E)R`]/B`G<V5L96-T)RP*("`@("=D97-C)R`]/B!?*")4
M:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D
M:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB*0HI.PH*+R\@061V86YC960@
M<V5A<F-H(')E<W5L=',@<&QA8V5M96YT+B!!<F4@<F5S=6QT<R!P;W-I=&EO
M;F5D(&%B;W9E(&]R(&)E;&]W"B\O('1H92!S96%R8V@@9F]R;3\*)%]P<F5F
M<ULG861V7W)E<W5L='-?<&QA8V5M96YT)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@)V)E;&]W)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H
M87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V1E
M<V,G(#T^(%\H(E-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V86YC960@<V5A
M<F-H(')E<W5L=',@=&\@87!P96%R+B(I+`H@("`@)V5N=6TG(#T^(&%R<F%Y
M*"=B96QO=R<@/3X@7R@B0F5L;W<@<V5A<F-H(&9O<FTB*2P*("`@("`@("`@
M("`@("`@("`@("`G86)O=F4G("`]/B!?*")!8F]V92!S96%R8V@@9F]R;2(I
M*0HI.PH*+R\@<')E9F5R96YC92!F;W(@:&]L9&EN9R!A;GD@<')E9F5R96YC
M97,M8F%S960@861D<F5S<V)O;VMS+@HD7W!R969S6R=P<F5F8F]O:W,G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM
M<&QI8VET)PHI.PH*+R\@<')E9F5R96YC92!F;W(@9&5L971E(&-O;F9I<FUA
M=&EO;B!D:6%L;V<N"B1?<')E9G-;)V1E;&5T95]O<'0G72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`G,"<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@
M("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L
M"B`@("`G9&5S8R<@/3X@7R@B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE
M=&EN9R!E;G1R:65S/R(I"BD["@II9B`H(65M<'1Y*"1'3$]"04Q36R=C;VYF
M)UU;)VEM<W`G75LG96YA8FQE9"==*2!\?`H@("`@(6ES<V5T*"1'3$]"04Q3
M6R=C;VYF)UU;)VEM<W`G75LG96YA8FQE9"==*2D@>PH@("`@)%]P<F5F<ULG
M:6US<%]O<'0G72`](&%R<F%Y*`H@("`@("`@("=L;V-K960G(#T^(&9A;'-E
M+`H@("`@("`@("=T>7!E)R`]/B`G<W!E8VEA;"<*("`@("D["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+V5T8R]P<V$M:&]R9&4O='5R8F$O<V]U<F-E<RYP:'``````````
M````````````````````````````````````````````````````````````
M`#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W-S4R`#$P-#$W,S8R
M-S0S`#`R,#4Q-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!T=7)B82]C;VYF:6<O<V]U
M<F-E<RYP:'`N9&ES="QV(#$N.3<N-BXQ-B`R,#`U+S$Q+S`W(#$P.C`S.C(V
M(&IA;B!%>'`@)`H@*@H@*B!4:&ES(&9I;&4@:7,@=VAE<F4@>6]U('-P96-I
M9GD@=&AE('-O=7)C97,@;V8@8V]N=&%C=',@879A:6QA8FQE('1O('5S97)S
M"B`J(&%T('EO=7(@:6YS=&%L;&%T:6]N+B!)="!C;VYT86EN<R!A(&QA<F=E
M(&YU;6)E<B!O9B!%6$%-4$Q%4RX@4&QE87-E"B`J(')E;6]V92!O<B!C;VUM
M96YT(&]U="!T:&]S92!E>&%M<&QE<R!T:&%T(%E/52!$3TXG5"!.145$+B!4
M:&5R92!A<F4@80H@*B!N=6UB97(@;V8@<')O<&5R=&EE<R!T:&%T('EO=2!C
M86X@<V5T(&9O<B!E86-H('-E<G9E<BP@:6YC;'5D:6YG.@H@*@H@*B!T:71L
M93H@("`@("`@5&AI<R!I<R!T:&4@8V]M;6]N("AU<V5R+79I<VEB;&4I(&YA
M;64@=&AA="!Y;W4@=V%N="!D:7-P;&%Y960*("H@("`@("`@("`@("`@(&EN
M('1H92!C;VYT86-T('-O=7)C92!D<F]P+61O=VX@8F]X+@H@*@H@*B!T>7!E
M.B`@("`@("`@5&AE('1Y<&5S("=L9&%P)RP@)W-Q;"<L("=I;7-P)R!A;F0@
M)W!R969S)R!A<F4@8W5R<F5N=&QY"B`J("`@("`@("`@("`@("!S=7!P;W)T
M960N(%!R969E<F5N8V5S+6)A<V5D(&%D9')E<W,@8F]O:W,@87)E(&YO="!I
M;G1E;F1E9`H@*B`@("`@("`@("`@("`@9F]R('!R;V1U8W1I;VX@:6YS=&%L
M;',@=6YL97-S('EO=2!R96%L;'D@:VYO=R!W:&%T('EO=2=R90H@*B`@("`@
M("`@("`@("`@9&]I;F<@+2!T:&5Y(&%R92!N;W0@<V5A<F-H86)L92P@86YD
M('1H97D@=V]N)W0@<V-A;&4@=V5L;"!I9@H@*B`@("`@("`@("`@("`@82!U
M<V5R(&AA<R!A(&QA<F=E(&YU;6)E<B!O9B!E;G1R:65S+@H@*@H@*B!P87)A
M;7,Z("`@("`@5&AE<V4@87)E('1H92!C;VYN96-T:6]N('!A<F%M971E<G,@
M<W!E8VEF:6,@=&\@=&AE(&-O;G1A8W0*("H@("`@("`@("`@("`@('-O=7)C
M92X@4V5E(&)E;&]W(&9O<B!E>&%M<&QE<R!O9B!H;W<@=&\@<V5T('1H97-E
M+@H@*@H@*B!3<&5C:6%L('!A<F%M<R!S971T:6YG<SH*("H*("H@("!C:&%R
M<V5T.B`@("`@("!4:&4@8VAA<F%C=&5R('-E="!T:&%T('1H92!B86-K96YD
M('-T;W)E<R!D871A(&EN+B!-86YY"B`J("`@("`@("`@("`@("`@("`@3$1!
M4"!S97)V97)S('5S92!U=&8M."X@1&%T86)A<V4@<V5R=F5R<R!T>7!I8V%L
M;'D@=7-E"B`J("`@("`@("`@("`@("`@("`@:7-O+3@X-3DM,2X*("H*("H@
M("!T;',Z("`@("`@("`@("!/;FQY(&%P<&QI97,@=&\@3$1!4"!S97)V97)S
M+B!)9B!T<G5E+"!T:&5N('1R>2!T;R!U<V4@80H@*B`@("`@("`@("`@("`@
M("`@(%1,4R!C;VYN96-T:6]N('1O('1H92!S97)V97(N"B`J"B`J("`@<V-O
M<&4Z("`@("`@("`@3VYL>2!A<'!L:65S('1O($Q$05`@<V5R=F5R<RX@0V%N
M(&)E('-E="!T;R`G;VYE)R!T;PH@*B`@("`@("`@("`@("`@("`@('-E87)C
M:"!O;F4@;&5V96P@;V8@=&AE($Q$05`@9&ER96-T;W)Y+"!O<B`G<W5B)R!T
M;R!S96%R8V@*("H@("`@("`@("`@("`@("`@("!A;&P@;&5V96QS+B`G;VYE
M)R!W:6QL('=O<FL@9F]R(&UO<W0@<V5T=7!S(&%N9"!S:&]U;&0@8F4*("H@
M("`@("`@("`@("`@("`@("!M=6-H(&9A<W1E<BX@2&]W979E<B!W92!D969A
M=6QT('1O("=S=6(G(&9O<B!B86-K=V%R9',*("H@("`@("`@("`@("`@("`@
M("!C;VUP871I8FEL:71Y+@H@*@H@*B`@(&-H96-K<F5Q=6ER960Z($]N;'D@
M87!P;&EE<R!T;R!,1$%0('-E<G9E<G,N($EF('!R97-E;G0L('1H:7,@=F%L
M=64@8V%U<V5S"B`J("`@("`@("`@("`@("`@("`@=&AE(&1R:79E<B!T;R!C
M;VYS=6QT('1H92!,1$%0('-C:&5M82!F;W(@86YY(&%T=')I8G5T97,*("H@
M("`@("`@("`@("`@("`@("!T:&%T(&%R92!R97%U:7)E9"!B>2!T:&4@9VEV
M96X@;V)J96-T8VQA<W,H97,I+B!297%U:7)E9`H@*B`@("`@("`@("`@("`@
M("`@(&%T=')I8G5T97,@=VEL;"!B92!P<F]V:61E9"!A=71O;6%T:6-A;&QY
M(&EF('1H90H@*B`@("`@("`@("`@("`@("`@("=C:&5C:W)E<75I<F5D7W-T
M<FEN9R<@<&%R86UE=&5R(&ES('!R97-E;G0N"B`J"B`J("`@8VAE8VMS>6YT
M87@Z("`@3VYL>2!A<'!L:65S('1O($Q$05`@<V5R=F5R<RX@268@<')E<V5N
M="P@=&AI<R!V86QU92!C875S97,*("H@("`@("`@("`@("`@("`@("!T:&4@
M9')I=F5R('1O(&EN<W!E8W0@=&AE($Q$05`@<V-H96UA(&9O<B!P87)T:6-U
M;&%R"B`J("`@("`@("`@("`@("`@("`@871T<FEB=71E<R!B>2!T:&4@='EP
M92!D969I;F5D(&EN('1H92!C;W)R97-P;VYD:6YG('-C:&5M80H@*@H@*B!M
M87`Z("`@("`@("`@5&AI<R!I<R!A(&QI<W0@;V8@;6%P<&EN9W,@9G)O;2!T
M:&4@<W1A;F1A<F0@5'5R8F$@871T<FEB=71E"B`J("`@("`@("`@("`@("!N
M86UE<R`H;VX@=&AE(&QE9G0I('1O('1H92!A='1R:6)U=&4@;F%M97,@8GD@
M=VAI8V@@=&AE>2!A<F4*("H@("`@("`@("`@("`@(&MN;W=N(&EN('1H:7,@
M8V]N=&%C="!S;W5R8V4@*&]N('1H92!R:6=H="DN(%1U<F)A(&%L<V\*("H@
M("`@("`@("`@("`@('-U<'!O<G1S(&-O;7!O<VET92!F:65L9',N($$@8V]M
M<&]S:71E(&9I96QD(&ES(&1E9FEN960@8GD*("H@("`@("`@("`@("`@(&UA
M<'!I;F<@=&AE(&9I96QD(&YA;64@=&\@86X@87)R87D@8V]N=&%I;FEN9R!A
M(&QI<W0@;V8*("H@("`@("`@("`@("`@(&-O;7!O;F5N="!F:65L9',@86YD
M(&$@9F]R;6%T('-T<FEN9R`H<VEM:6QA<B!T;R!A('!R:6YT9B@I"B`J("`@
M("`@("`@("`@("!F;W)M870@<W1R:6YG*2X@2&5R92!I<R!A;B!E>&%M<&QE
M.@H@*B`@("`@("`@("`@("`@+BXN"B`J("`@("`@("`@("`@("`G;F%M92<@
M/3X@87)R87DH)V9I96QD<R<@/3X@87)R87DH)V9I<G-T;F%M92<L("=L87-T
M;F%M92<I+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F;W)M
M870G(#T^("<E<R`E<R<I+`H@*B`@("`@("`@("`@("`@)V9I<G-T;F%M92<@
M/3X@)V]B:F5C=%]F:7)S=&YA;64G+`H@*B`@("`@("`@("`@("`@)VQA<W1N
M86UE)R`]/B`G;V)J96-T7VQA<W1N86UE)RP*("H@("`@("`@("`@("`@("XN
M+@H@*@H@*B!T86)S.B`@("`@("`@06QL(&9I96QD<R!C86X@8F4@9W)O=7!E
M9"!I;G1O('1A8G,@=VET:"!T:&ES(&]P=&EO;F%L(&5N=')Y+@H@*B`@("`@
M("`@("`@("`@5&AI<R!L:7-T(&ES(&UU;'1I9&EM96YS:6]N86P@:&%S:"P@
M=&AE(&ME>7,@87)E('1H92!T86(*("H@("`@("`@("`@("`@('1I=&QE<RX*
M("H@("`@("`@("`@("`@($AE<F4@:7,@86X@97AA;7!L93H*("H@("`@("`@
M("`@("`@("=T86)S)R`]/B!A<G)A>2@*("H@("`@("`@("`@("`@("`@("`G
M3F%M97,G(#T^(&%R<F%Y*"=F:7)S=&YA;64G+"`G;&%S=&YA;64G+"`G86QI
M87,G*2P*("H@("`@("`@("`@("`@("`@("`G061D<F5S<V5S)R`]/B!A<G)A
M>2@G:&]M94%D9')E<W,G+"`G=V]R:T%D9')E<W,G*0H@*B`@("`@("`@("`@
M("`@*3L*("H*("H@<V5A<F-H.B`@("`@($$@;&ES="!O9B!4=7)B82!A='1R
M:6)U=&4@;F%M97,@=&AA="!C86X@8F4@<V5A<F-H960@9F]R('1H:7,*("H@
M("`@("`@("`@("`@('-O=7)C92X*("H*("H@<W1R:6-T.B`@("`@($$@;&ES
M="!O9B!N871I=F4@9FEE;&0O871T<FEB=71E(&YA;65S('1H870@;75S="!A
M;'=A>7,@8F4*("H@("`@("`@("`@("`@(&UA=&-H960@97AA8W1L>2!I;B!A
M('-E87)C:"X*("H*("H@97AP;W)T.B`@("`@($EF('-E="!T;R!T<G5E+"!T
M:&ES('-O=7)C92!W:6QL(&%P<&5A<B!O;B!T:&4@17AP;W)T(&UE;G4L"B`J
M("`@("`@("`@("`@("!A;&QO=VEN9R!U<V5R<R!T;R!E>'!O<G0@=&AE(&-O
M;G1A8W1S('1O(&$@0U-6("AE=&,N*2!F:6QE+@H@*@H@*B!B<F]W<V4Z("`@
M("`@268@<V5T('1O('1R=64L('1H:7,@<V]U<F-E('=I;&P@8F4@8G)O=W-E
M86)L92!V:6$@=&AE($)R;W=S90H@*B`@("`@("`@("`@("`@;65N=2!I=&5M
M+"!A;F0@96UP='D@<V5A<F-H97,@86=A:6YS="!T:&4@<V]U<F-E('=I;&P@
M<F5T=7)N"B`J("`@("`@("`@("`@("!A;&P@8V]N=&%C=',N"B`J"B`J('5S
M95]S:&%R97,Z("!)9B!T:&ES(&ES('!R97-E;G0@86YD('1R=64L($AO<F1E
M7U-H87)E(&9U;F-T:6]N86QI='D@=VEL;`H@*B`@("`@("`@("`@("`@8F4@
M96YA8FQE9"!F;W(@=&AI<R!S;W5R8V4@+2!A;&QO=VEN9R!U<V5R<R!T;R!S
M:&%R92!T:&5I<@H@*B`@("`@("`@("`@("`@<&5R<V]N86P@861D<F5S<R!B
M;V]K<R!A<R!W96QL(&%S('1O(&-R96%T92!N97<@;VYE<RX@4VEN8V4*("H@
M("`@("`@("`@("`@(%1U<F)A(&]N;'D@<W5P<&]R=',@:&%V:6YG(&]N92!B
M86-K96YD(&-O;F9I9W5R960@9F]R"B`J("`@("`@("`@("`@("!C<F5A=&EN
M9R!N97<@<VAA<F5S+"!U<V4@=&AE("=S:&%R97,G(&-O;F9I9W5R871I;VX@
M;W!T:6]N('1O"B`J("`@("`@("`@("`@("!S<&5C:69Y('=H:6-H(&)A8VME
M;F0@=VEL;"!B92!U<V5D(&9O<B!C<F5A=&EN9R!N97<@<VAA<F5S+@H@*B`@
M("`@("`@("`@("`@06QL('!E<FUI<W-I;VX@8VAE8VMI;F<@=VEL;"!B92!D
M;VYE(&%G86EN<W0@2&]R9&5?4VAA<F4L(&)U=`H@*B`@("`@("`@("`@("`@
M;F]T92!T:&%T(&%N>2`G97AT96YD960G('!E<FUI<W-I;VYS("AS=6-H(&%S
M(&UA>%]C;VYT86-T<RD*("H@("`@("`@("`@("`@('=I;&P@<W1I;&P@8F4@
M96YF;W)C960N($%L<V\@;F]T92!T:&%T('1H92!B86-K96YD(&1R:79E<@H@
M*B`@("`@("`@("`@("`@;75S="!H879E('-U<'!O<G0@9F]R('5S:6YG('1H
M:7,N($-U<G)E;G1L>2!344P@;VYL>2X*("H*("H@2&5R92!A<F4@<V]M92!E
M>&%M<&QE(&-O;F9I9W5R871I;VYS.@H@*B\*"B\J*@H@*B!!(&QO8V%L(&%D
M9')E<W,@8F]O:R!I;B!A;B!344P@9&%T86)A<V4N(%1H:7,@:6UP;&5M96YT
M<R!A('!R:79A=&4*("H@<&5R+75S97(@861D<F5S<R!B;V]K+B!3:&%R:6YG
M(&]F('1H:7,@<V]U<F-E('=I=&@@;W1H97(@=7-E<G,@;6%Y(&)E"B`J(&%C
M8V]M<&QI<VAE9"!B>2!E;F%B;&EN9R!(;W)D95]3:&%R92!F;W(@=&AI<R!S
M;W5R8V4@8GD@<V5T=&EN9PH@*B`G=7-E7W-H87)E<R<@/3X@=')U92X*("H*
M("H@0F4@<W5R92!T;R!C<F5A=&4@82!T=7)B85]O8FIE8W1S('1A8FQE(&EN
M('EO=7(@2&]R9&4@9&%T86)A<V4@9G)O;2!T:&4*("H@<V-H96UA(&EN('1U
M<F)A+W-C<FEP=',O9&(O='5R8F$N<W%L(&EF('EO=2!U<V4@=&AI<R!S;W5R
M8V4N"B`J+PHD8V9G4V]U<F-E<ULG;&]C86QS<6PG72`](&%R<F%Y*`H@("`@
M)W1I=&QE)R`]/B!?*")->2!!9&1R97-S($)O;VLB*2P*("`@("=T>7!E)R`]
M/B`G<W%L)RP*("`@("\O(%1H92!D969A=6QT(&-O;FYE8W1I;VX@9&5T86EL
M<R!A<F4@<'5L;&5D(&9R;VT@=&AE($AO<F1E+7=I9&4@4U%,"B`@("`O+R!C
M;VYN96-T:6]N(&-O;F9I9W5R871I;VXN"B`@("`O+PH@("`@+R\@5&AE(&]L
M9"!E>&%M<&QE(&EL;'5S=')A=&5S(&AO=R!T;R!U<V4@86X@86QT97)N871E
M(&1A=&%B87-E"B`@("`O+R!C;VYF:6=U<F%T:6]N+@H@("`@+R\*("`@("\O
M($YE=R!%>&%M<&QE.@H@("`@)W!A<F%M<R<@/3X@87)R87E?;65R9V4H)&-O
M;F9;)W-Q;"==+"!A<G)A>2@G=&%B;&4G(#T^("=T=7)B85]O8FIE8W1S)RDI
M+`H*("`@("\O($]L9"!%>&%M<&QE.@H@("`@+R\@)W!A<F%M<R<@/3X@87)R
M87DH"B`@("`O+R`@("`@)W!H<'1Y<&4G(#T^("=M>7-Q;"<L"B`@("`O+R`@
M("`@)VAO<W1S<&5C)R`]/B`G;&]C86QH;W-T)RP*("`@("\O("`@("`G=7-E
M<FYA;64G(#T^("=H;W)D92<L"B`@("`O+R`@("`@)W!A<W-W;W)D)R`]/B`G
M*BHJ*BHG+`H@("`@+R\@("`@("=D871A8F%S92<@/3X@)VAO<F1E)RP*("`@
M("\O("`@("`G=&%B;&4G(#T^("=T=7)B85]O8FIE8W1S)RP*("`@("\O("`@
M("`G8VAA<G-E="<@/3X@)VES;RTX.#4Y+3$G"B`@("`O+R`I+`H@("`@)VUA
M<"<@/3X@87)R87DH"B`@("`@("`@)U]?:V5Y)R`]/B`G;V)J96-T7VED)RP*
M("`@("`@("`G7U]O=VYE<B<@/3X@)V]W;F5R7VED)RP*("`@("`@("`G7U]T
M>7!E)R`]/B`G;V)J96-T7W1Y<&4G+`H@("`@("`@("=?7VUE;6)E<G,G(#T^
M("=O8FIE8W1?;65M8F5R<R<L"B`@("`@("`@)U]?=6ED)R`]/B`G;V)J96-T
M7W5I9"<L"B`@("`@("`@)VYA;64G(#T^("=O8FIE8W1?;F%M92<L"B`@("`@
M("`@)V5M86EL)R`]/B`G;V)J96-T7V5M86EL)RP*("`@("`@("`G86QI87,G
M(#T^("=O8FIE8W1?86QI87,G+`H@("`@("`@("=H;VUE061D<F5S<R<@/3X@
M)V]B:F5C=%]H;VUE861D<F5S<R<L"B`@("`@("`@)W=O<FM!9&1R97-S)R`]
M/B`G;V)J96-T7W=O<FMA9&1R97-S)RP*("`@("`@("`G:&]M95!H;VYE)R`]
M/B`G;V)J96-T7VAO;65P:&]N92<L"B`@("`@("`@)W=O<FM0:&]N92<@/3X@
M)V]B:F5C=%]W;W)K<&AO;F4G+`H@("`@("`@("=C96QL4&AO;F4G(#T^("=O
M8FIE8W1?8V5L;'!H;VYE)RP*("`@("`@("`G9F%X)R`]/B`G;V)J96-T7V9A
M>"<L"B`@("`@("`@)W1I=&QE)R`]/B`G;V)J96-T7W1I=&QE)RP*("`@("`@
M("`G8V]M<&%N>2<@/3X@)V]B:F5C=%]C;VUP86YY)RP*("`@("`@("`G;F]T
M97,G(#T^("=O8FIE8W1?;F]T97,G+`H@("`@("`@("=P9W!0=6)L:6-+97DG
M(#T^("=O8FIE8W1?<&=P<'5B;&EC:V5Y)RP*("`@("`@("`G<VUI;650=6)L
M:6-+97DG(#T^("=O8FIE8W1?<VUI;65P=6)L:6-K97DG+`H@("`@("`@("=F
M<F5E8G5S>55R;"<@/3X@)V]B:F5C=%]F<F5E8G5S>75R;"<*("`@("DL"B`@
M("`G<V5A<F-H)R`]/B!A<G)A>2@*("`@("`@("`G;F%M92<L"B`@("`@("`@
M)V5M86EL)PH@("`@*2P*("`@("=S=')I8W0G(#T^(&%R<F%Y*`H@("`@("`@
M("=O8FIE8W1?:60G+`H@("`@("`@("=O=VYE<E]I9"<L"B`@("`@("`@)V]B
M:F5C=%]T>7!E)RP*("`@("DL"B`@("`G97AP;W)T)R`]/B!T<G5E+`H@("`@
M)V)R;W=S92<@/3X@=')U92P*("`@("=U<V5?<VAA<F5S)R`]/B!T<G5E+`HI
M.PH*+RHJ"B`J($$@<')E9F5R96YC97,M8F%S960@861R97-S8F]O:RX@5&AI
M<R!W:6QL(&%L=V%Y<R!B92!P<FEV871E+B!9;W4@8V%N(&%D9`H@*B!A;GD@
M871T<FEB=71E<R!Y;W4@;&EK92!T;R!T:&4@;6%P(&%N9"!I="!W:6QL(&IU
M<W0@=V]R:SL@>6]U(&-A;B!A;'-O"B`J(&-R96%T92!M=6QT:7!L92!P<F5F
M<RUB87-E9"!A9&1R97-S(&)O;VMS(&)Y(&-H86YG:6YG('1H92`G;F%M92<@
M<&%R86UE=&5R+@H@*B!4:&ES(&ES(&)E<W0@9F]R(&%D9')E<W,@8F]O:W,@
M=&AA="!A<F4@97AP96-T960@=&\@<F5M86EN('-M86QL.R!I="=S(&YO=`H@
M*B!T:&4@;6]S="!E9F9I8VEE;G0L(&)U="!I="!C86XG="!B92!B96%T(&9O
M<B!G971T:6YG('5P(&%N9"!R=6YN:6YG"B`J('%U:6-K;'DL(&5S<&5C:6%L
M;'D@:68@>6]U(&%L<F5A9'D@:&%V92!(;W)D92!P<F5F97)E;F-E<R!W;W)K
M:6YG+B!.;W1E"B`J('1H870@:70@:7,@;F]T('-E87)C:&%B;&4L('1H;W5G
M:"`M('-E87)C:&5S('=I;&P@<VEM<&QY(')E='5R;B!T:&4@=VAO;&4*("H@
M861D<F5S<R!B;V]K+@H@*B\*)&-F9U-O=7)C97-;)W!R969S)UT@/2!A<G)A
M>2@*("`@("=T:71L92<@/3X@7R@B4')I=F%T92!!9&1R97-S($)O;VLB*2P*
M("`@("=T>7!E)R`]/B`G<')E9G,G+`H@("`@)W!A<F%M<R<@/3X@87)R87DH
M"B`@("`@("`@)VYA;64G(#T^("=P<F5F<R<L"B`@("`@("`@)V-H87)S970G
M(#T^($Y,4SHZ9V5T0VAA<G-E="@I"B`@("`I+`H@("`@)VUA<"<@/3X@87)R
M87DH"B`@("`@("`@)U]?:V5Y)R`]/B`G:60G+`H@("`@("`@("=?7W1Y<&4G
M(#T^("=?='EP92<L"B`@("`@("`@)U]?;65M8F5R<R<@/3X@)U]M96UB97)S
M)RP*("`@("`@("`G7U]U:60G(#T^("=U:60G+`H@("`@("`@("=N86UE)R`]
M/B`G;F%M92<L"B`@("`@("`@)V5M86EL)R`]/B`G;6%I;"<L"B`@("`@("`@
M)V%L:6%S)R`]/B`G86QI87,G"B`@("`I+`H@("`@)W-E87)C:"<@/3X@87)R
M87DH"B`@("`@("`@)VYA;64G+`H@("`@("`@("=E;6%I;"<L"B`@("`@("`@
M)V%L:6%S)PH@("`@*2P*("`@("=S=')I8W0G(#T^(&%R<F%Y*`H@("`@("`@
M("=I9"<L"B`@("`@("`@)U]T>7!E)RP*("`@("DL"B`@("`G97AP;W)T)R`]
M/B!T<G5E+`H@("`@)V)R;W=S92<@/3X@=')U92P**3L*````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+W1U<F)A
M+V-O;F8N<&AP````````````````````````````````````````````````
M```````````````````````````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#8V,P`Q,#0Q-S,V,C<T,P`P,3<W-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RH@0T].1DE'(%-4
M05)4+B!$3R!.3U0@0TA!3D=%($%.651(24Y'($E.($]2($%&5$52(%1(25,@
M3$E.12X@*B\*+R\@)$AO<F1E.B!T=7)B82]C;VYF:6<O8V]N9BYX;6PL=B`Q
M+C8N,BXQ(#(P,#4O,3`O,3@@,3(Z-3`Z,#0@:F%N($5X<"`D"B1C;VYF6R=M
M96YU)UU;)VEM<&]R=%]E>'!O<G0G72`]('1R=64["B1C;VYF6R=M96YU)UU;
M)V%P<',G72`](&%R<F%Y*"=I;7`G+"`G:6YG;R<L("=K<F]N;VQI=&@G+"`G
M='5R8F$G*3L*)&-O;F9;)V-L:65N="==6R=A9&1R97-S8F]O:R==(#T@)VQO
M8V%L<W%L)SL*)&-O;F9;)V-O;6UE;G1S)UU;)V%L;&]W)UT@/2!T<G5E.PHD
M8V]N9ELG9&]C=6UE;G1S)UU;)W1Y<&4G72`]("=H;W)D92<["B\J($-/3D9)
M1R!%3D0N($1/($Y/5"!#2$%.1T4@04Y95$A)3D<@24X@3U(@0D5&3U)%(%1(
M25,@3$E.12X@*B\*````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]T=7)B82]M:6UE7V1R:79E
M<G,N<&AP````````````````````````````````````````````````````
M````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S,C,`
M,3`T,3<S-C(W-#,`,#(Q-3`S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z('1U<F)A+V-O
M;F9I9R]M:6UE7V1R:79E<G,N<&AP+F1I<W0L=B`Q+C(N,BXQ(#(P,#4O,3`O
M,3@@,3(Z-3`Z,#0@:F%N($5X<"`D"B`J"B`J($1E8VED92!W:&EC:"!O=71P
M=70@9')I=F5R<R!Y;W4@=V%N="!T;R!A8W1I=F%T92!F;W(@5'5R8F$N"B`J
M(%-E='1I;F=S(&EN('1H:7,@9FEL92!O=F5R<FED92!S971T:6YG<R!I;B!H
M;W)D92]C;VYF:6<O;6EM95]D<FEV97)S+G!H<"X*("HO"B1M:6UE7V1R:79E
M<G-?;6%P6R=T=7)B82==6R=R96=I<W1E<F5D)UT@/2!A<G)A>2@I.PH*+RHJ
M"B`J($EF('EO=2!W86YT('1O('-P96-I9FEC86QL>2!O=F5R<FED92!A;GD@
M34E-12!T>7!E('1O(&)E(&AA;F1L960@8GD*("H@82!S<&5C:69I8R!D<FEV
M97(L('1H96X@96YT97(@:70@:&5R92X@3F]R;6%L;'DL('1H:7,@:7,@<V%F
M92!T;PH@*B!L96%V92P@8G5T(&ET)W,@=7-E9G5L('=H96X@;75L=&EP;&4@
M9')I=F5R<R!H86YD;&4@=&AE('-A;64@34E-10H@*B!T>7!E+"!A;F0@>6]U
M('=A;G0@=&\@<W!E8VEF>2!E>&%C=&QY('=H:6-H(&]N92!S:&]U;&0@:&%N
M9&QE(&ET+@H@*B\*)&UI;65?9')I=F5R<U]M87!;)W1U<F)A)UU;)V]V97)R
M:61E<R==(#T@87)R87DH*3L*"B\J*@H@*B!$<FEV97(@<W!E8VEF:6,@<V5T
M=&EN9W,N(%-E92!H;W)D92]C;VYF:6<O;6EM95]D<FEV97)S+G!H<"!F;W(*
M("H@=&AE(&9O<FUA="X*("HO"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]T=7)B82]C;VYF
M+GAM;```````````````````````````````````````````````````````
M````````````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(S,C``,3`T,3<S-C(W-#,`,#$W-S4R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\
M(2TM("1(;W)D93H@='5R8F$O8V]N9FEG+V-O;F8N>&UL+'8@,2XV+C(N,2`R
M,#`U+S$P+S$X(#$R.C4P.C`T(&IA;B!%>'`@)"`M+3X*/&-O;F9I9W5R871I
M;VX^"B`\8V]N9FEG<V5C=&EO;B!N86UE/2)M96YU(CX*("`\8V]N9FEG:&5A
M9&5R/DUE;G4@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`\8V]N9FEG8F]O
M;&5A;B!N86UE/2)I;7!O<G1?97AP;W)T(B!D97-C/2)3:&]U;&0@=V4@9&ES
M<&QA>2!A;B!);7!O<G0O17AP;W)T(&QI;FL@:6X@5'5R8F$G<R!M96YU/R(^
M=')U93PO8V]N9FEG8F]O;&5A;CX*("`\8V]N9FEG;75L=&EE;G5M(&YA;64]
M(F%P<',B(&1E<V,](E-E;&5C="!A;GD@87!P;&EC871I;VYS('1H870@<VAO
M=6QD(&)E(&QI;FME9"!I;B!4=7)B82=S(&UE;G4B/@H@("`\=F%L=65S/@H@
M("`@/&-O;F9I9W-P96-I86P@;F%M93TB;&ES="UH;W)D92UA<'!S(B\^"B`@
M(#PO=F%L=65S/@H@(#PO8V]N9FEG;75L=&EE;G5M/@H@/"]C;VYF:6=S96-T
M:6]N/@H*(#QC;VYF:6=S96-T:6]N(&YA;64](F-L:65N="(^"B`@(#QC;VYF
M:6=H96%D97(^0VQI96YT<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG<W1R
M:6YG(&YA;64](F%D9')E<W-B;V]K(B!D97-C/2).86UE(&]F(&-L:65N="!A
M9&1R97-S8F]O:R(^;&]C86QS<6P\+V-O;F9I9W-T<FEN9SX*(#PO8V]N9FEG
M<V5C=&EO;CX*"B`\8V]N9FEG<V5C=&EO;B!N86UE/2)S:&%R97,B/@H@("`\
M8V]N9FEG:&5A9&5R/E-H87)E<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG
M<W1R:6YG(&YA;64](G-O=7)C92(@9&5S8STB3F%M92!O9B!S;W5R8V4@9F]R
M(&-R96%T:6YG(&YE=R!S:&%R97,B"B`@(')E<75I<F5D/2)F86QS92(O/@H@
M/"]C;VYF:6=S96-T:6]N/@H*(#QC;VYF:6=S96-T:6]N(&YA;64](F-O;6UE
M;G1S(CX*("`\8V]N9FEG:&5A9&5R/D-O;6UE;G1S/"]C;VYF:6=H96%D97(^
M"B`@/&-O;F9I9V)O;VQE86X@;F%M93TB86QL;W<B(&1E<V,](D-A;B!U<V5R
M<R!C;VUM96YT(&]N(&-O;G1A8W1S/R(^=')U93PO8V]N9FEG8F]O;&5A;CX*
M(#PO8V]N9FEG<V5C=&EO;CX*"B`\8V]N9FEG<V5C=&EO;B!N86UE/2)D;V-U
M;65N=',B/@H@(#QC;VYF:6=H96%D97(^5FER='5A;"!&:6QE(%-T;W)A9V4\
M+V-O;F9I9VAE861E<CX*("`\8V]N9FEG=F9S('-W:71C:&YA;64](G1Y<&4B
M("\^"B`\+V-O;F9I9W-E8W1I;VX^"CPO8V]N9FEG=7)A=&EO;CX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]E
M=&,O<'-A+6AO<F1E+W1U<F)A+V%T=')I8G5T97,N<&AP````````````````
M```````````````````````````````````````````````````P,3`P-#0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-30U-``Q,#0Q-S,V,C<T,P`P,C$R
M,38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1U<F)A($%T=')I8G5T97,@1FEL90H@*@H@*B!4:&ES
M(&9I;&4@8V]N=&%I;G,@=&AE(&%T=')I8G5T97,@=&AA="!4=7)B82!U;F1E
M<G-T86YD<RP@86YD('1H96ER"B`J('1Y<&5S+B!)="!M87D@8F4@<V%F96QY
M(&5D:71E9"!B>2!H86YD+B!5<V4@871T<FEB=71E<RYP:'`N9&ES="!A<PH@
M*B!A(')E9F5R96YC92X*("H*("H@1V5N97)A;"!C;VYF:6=U<F%T:6]N(&ES
M(&EN("=C;VYF+G!H<"<N"B`J($-O;G1A8W0@<V]U<F-E<R!A<F4@9&5F:6YE
M9"!I;B`G<V]U<F-E<RYP:'`G+@H@*B!$969A=6QT('5S97(@<')E9F5R96YC
M97,@87)E(&1E9FEN960@:6X@)W!R969S+G!H<"<N"B`J"B`J("1(;W)D93H@
M='5R8F$O8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0L=B`Q+C,V+C8N,R`R
M,#`U+S$P+S$X(#$R.C4P.C`T(&IA;B!%>'`@)`H@*B!4:&4@<WEN=&%X(&]F
M('1H:7,@87)R87D@:7,@87,@9F]L;&]W<SH*("H@("`@("!L86)E;"`@("`M
M('1H92!T97AT('1H870@=&AE('5S97(@=VEL;"!S964@871T86-H960@=&\@
M=&AI<R!F:65L9`H@*B`@("`@('1Y<&4@("`@("T@;VYE(&]F('1H92!F;VQL
M;W=I;F<Z"B`J("`@("`@("`@("`@("`@("`@("`@("T@<W!A8V5R("`@("`@
M("`@("`@+2!H96%D97(*("H@("`@("`@("`@("`@("`@("`@("`@+2!D97-C
M<FEP=&EO;B`@("`@("`M(&AT;6P*("H@("`@("`@("`@("`@("`@("`@("`@
M+2!N=6UB97(@("`@("`@("`@("`M(&EN=`H@*B`@("`@("`@("`@("`@("`@
M("`@("`M(&EN=&QI<W0@("`@("`@("`@("T@=&5X=`H@*B`@("`@("`@("`@
M("`@("`@("`@("`M(&QO;F=T97AT("`@("`@("`@("T@8V]U;G1E9'1E>'0*
M("H@("`@("`@("`@("`@("`@("`@("`@+2!A9&1R97-S("`@("`@("`@("`M
M(&9I;&4*("H@("`@("`@("`@("`@("`@("`@("`@+2!B;V]L96%N("`@("`@
M("`@("`M(&QI;FL*("H@("`@("`@("`@("`@("`@("`@("`@+2!E;6%I;"`@
M("`@("`@("`@("`M(&5M86EL8V]N9FER;0H@*B`@("`@("`@("`@("`@("`@
M("`@("`M('!A<W-W;W)D("`@("`@("`@("T@<&%S<W=O<F1C;VYF:7)M"B`J
M("`@("`@("`@("`@("`@("`@("`@("T@96YU;2`@("`@("`@("`@("`@+2!M
M=6QT:65N=6T*("H@("`@("`@("`@("`@("`@("`@("`@+2!R861I;R`@("`@
M("`@("`@("`M('-E=`H@*B`@("`@("`@("`@("`@("`@("`@("`M(&1A=&4@
M("`@("`@("`@("`@("T@=&EM90H@*B`@("`@("`@("`@("`@("`@("`@("`M
M(&UO;G1H>65A<B`@("`@("`@("T@;6]N=&AD87EY96%R"B`J("`@("`@("`@
M("`@("`@("`@("`@("T@8V]L;W)P:6-K97(@("`@("`@+2!S;W)T97(*("H@
M("`@("`@("`@("`@("`@("`@("`@+2!C<F5D:71C87)D("`@("`@("`M(&EN
M=F%L:60*("H@("`@("`@("`@("`@("`@("`@("`@+2!S=')I;F=L:7-T"B`J
M("`@("`@<F5Q=6ER960@+2!B;V]L96%N+"!T<G5E(&]R(&9A;'-E('=H971H
M97(@=&AI<R!F:65L9"!I<R!M86YD871O<GD*("H@("`@("!R96%D;VYL>2`M
M(&)O;VQE86XL('1R=64@;W(@9F%L<V4@=VAE=&AE<B!T:&ES(&5D:71A8FQE
M"B`J("`@("`@9&5S8R`@("`@+2!A;GD@:&5L<"!T97AT(&%T=&%C:&5D('1O
M('1H92!F:65L9`H@*B`@("`@('!A<F%M<R`@("T@86YY(&]T:&5R('!A<F%M
M971E<G,@=&AA="!N965D('1O(&)E('!A<W-E9"!T;R!T:&4@9FEE;&0*("H@
M("`@("`@("`@("`@("`@('-U8V@@87,@82!L:7-T('1O(&)E('5S960@:6X@
M=&AE(&5N=6T@9FEE;&0L('1H92!R;W<@86YD"B`J("`@("`@("`@("`@("`@
M("!C;VQU;6X@<VEZ:6YG(&9O<B!A(&QO;F=T97AT(&9I96QD+"!43T1/("AL
M:7-T(&UO<F4@='EP97,I"B`J+PH*)&%T=')I8G5T97-;)VYA;64G72`](&%R
M<F%Y*`H@("`@)VQA8F5L)R`]/B!?*").86UE(BDL"B`@("`G='EP92<@/3X@
M)W1E>'0G+`H@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@)W!A<F%M<R<@
M/3X@87)R87DH)R<L(#0P+"`R-34I"BD["B1A='1R:6)U=&5S6R=F:7)S=&YA
M;64G72`](&%R<F%Y*`H@("`@)VQA8F5L)R`]/B!?*")&:7)S="!.86UE(BDL
M"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)W)E<75I<F5D)R`]/B!T<G5E
M"BD["B1A='1R:6)U=&5S6R=L87-T;F%M92==(#T@87)R87DH"B`@("`G;&%B
M96PG(#T^(%\H(DQA<W0@3F%M92(I+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*
M("`@("=R97%U:7)E9"<@/3X@=')U90HI.PHD871T<FEB=71E<ULG96UA:6PG
M72`](&%R<F%Y*`H@("`@)VQA8F5L)R`]/B!?*")%;6%I;"(I+`H@("`@)W1Y
M<&4G(#T^("=E;6%I;"<L"B`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@
M)W!A<F%M<R<@/3X@87)R87DH)R<L(#0P+"`R-34I"BD["B1A='1R:6)U=&5S
M6R=A;&EA<R==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(D%L:6%S(BDL
M"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)W)E<75I<F5D)R`]/B!F86QS
M92P*("`@("=P87)A;7,G(#T^(&%R<F%Y*"<G+"`T,"P@,S(I"BD["B1A='1R
M:6)U=&5S6R=T:71L92==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(E1I
M=&QE(BDL"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)W)E<75I<F5D)R`]
M/B!F86QS92P*("`@("=P87)A;7,G(#T^(&%R<F%Y*"<G+"`T,"P@,C4U*0HI
M.PHD871T<FEB=71E<ULG8V]M<&%N>2==(#T@87)R87DH"B`@("`G;&%B96PG
M(#T^(%\H(D-O;7!A;GDB*2P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`G
M<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@)W!A<F%M<R<@/3X@87)R87DH)R<L
M(#0P+"`R-34I"BD["B1A='1R:6)U=&5S6R=H;VUE061D<F5S<R==(#T@87)R
M87DH"B`@("`G;&%B96PG(#T^(%\H(DAO;64@061D<F5S<R(I+`H@("`@)W1Y
M<&4G(#T^("=A9&1R97-S)RP*("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@
M("`G<&%R86US)R`]/B!A<G)A>2@G,R<L("<T,"<I"BD["B1A='1R:6)U=&5S
M6R=H;VUE4W1R965T)UT@/2!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B2&]M
M92!3=')E970@061D<F5S<R(I+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@
M("=R97%U:7)E9"<@/3X@9F%L<V4**3L*)&%T=')I8G5T97-;)VAO;65#:71Y
M)UT@/2!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B2&]M92!#:71Y(BDL"B`@
M("`G='EP92<@/3X@)W1E>'0G+`H@("`@)W)E<75I<F5D)R`]/B!F86QS90HI
M.PHD871T<FEB=71E<ULG:&]M95!R;W9I;F-E)UT@/2!A<G)A>2@*("`@("=L
M86)E;"<@/3X@7R@B2&]M92!3=&%T92]0<F]V:6YC92(I+`H@("`@)W1Y<&4G
M(#T^("=T97AT)RP*("`@("=R97%U:7)E9"<@/3X@9F%L<V4**3L*)&%T=')I
M8G5T97-;)VAO;650;W-T86Q#;V1E)UT@/2!A<G)A>2@*("`@("=L86)E;"<@
M/3X@7R@B2&]M92!0;W-T86P@0V]D92(I+`H@("`@)W1Y<&4G(#T^("=T97AT
M)RP*("`@("=R97%U:7)E9"<@/3X@9F%L<V4**3L*)&%T=')I8G5T97-;)VAO
M;65#;W5N=')Y)UT@/2!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B2&]M92!#
M;W5N=')Y(BDL"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)W)E<75I<F5D
M)R`]/B!F86QS90HI.PHD871T<FEB=71E<ULG=V]R:T%D9')E<W,G72`](&%R
M<F%Y*`H@("`@)VQA8F5L)R`]/B!?*")7;W)K($%D9')E<W,B*2P*("`@("=T
M>7!E)R`]/B`G861D<F5S<R<L"B`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@
M("`@)W!A<F%M<R<@/3X@87)R87DH)S,G+"`G-#`G*0HI.PHD871T<FEB=71E
M<ULG=V]R:U-T<F5E="==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(E=O
M<FL@4W1R965T($%D9')E<W,B*2P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@
M("`G<F5Q=6ER960G(#T^(&9A;'-E"BD["B1A='1R:6)U=&5S6R=W;W)K0VET
M>2==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(E=O<FL@0VET>2(I+`H@
M("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=R97%U:7)E9"<@/3X@9F%L<V4*
M*3L*)&%T=')I8G5T97-;)W=O<FM0<F]V:6YC92==(#T@87)R87DH"B`@("`G
M;&%B96PG(#T^(%\H(E=O<FL@4W1A=&4O4')O=FEN8V4B*2P*("`@("=T>7!E
M)R`]/B`G=&5X="<L"B`@("`G<F5Q=6ER960G(#T^(&9A;'-E"BD["B1A='1R
M:6)U=&5S6R=W;W)K4&]S=&%L0V]D92==(#T@87)R87DH"B`@("`G;&%B96PG
M(#T^(%\H(E=O<FL@4&]S=&%L($-O9&4B*2P*("`@("=T>7!E)R`]/B`G=&5X
M="<L"B`@("`G<F5Q=6ER960G(#T^(&9A;'-E"BD["B1A='1R:6)U=&5S6R=W
M;W)K0V]U;G1R>2==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(E=O<FL@
M0V]U;G1R>2(I+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=R97%U:7)E
M9"<@/3X@9F%L<V4**3L*)&%T=')I8G5T97-;)V-O;7!A;GE!9&1R97-S)UT@
M/2!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B0V]M<&%N>2!!9&1R97-S(BDL
M"B`@("`G='EP92<@/3X@)V%D9')E<W,G+`H@("`@)W)E<75I<F5D)R`]/B!F
M86QS92P*("`@("=P87)A;7,G(#T^(&%R<F%Y*"<S)RP@)S0P)RD**3L*)&%T
M=')I8G5T97-;)VAO;650:&]N92==(#T@87)R87DH"B`@("`G;&%B96PG(#T^
M(%\H(DAO;64@4&AO;F4B*2P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`G
M<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@)W!A<F%M<R<@/3X@87)R87DH)R<L
M(#0P+"`R-2D**3L*)&%T=')I8G5T97-;)W=O<FM0:&]N92==(#T@87)R87DH
M"B`@("`G;&%B96PG(#T^(%\H(E=O<FL@4&AO;F4B*2P*("`@("=T>7!E)R`]
M/B`G=&5X="<L"B`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@)W!A<F%M
M<R<@/3X@87)R87DH)R<L(#0P+"`R-2D**3L*)&%T=')I8G5T97-;)V-E;&Q0
M:&]N92==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(DUO8FEL92!0:&]N
M92(I+`H@("`@)W1Y<&4G(#T^("=C96QL<&AO;F4G+`H@("`@)W)E<75I<F5D
M)R`]/B!F86QS90HI.PHD871T<FEB=71E<ULG9F%X)UT@/2!A<G)A>2@*("`@
M("=L86)E;"<@/3X@7R@B1F%X(BDL"B`@("`G='EP92<@/3X@)W1E>'0G+`H@
M("`@)W)E<75I<F5D)R`]/B!F86QS92P*("`@("=P87)A;7,G(#T^(&%R<F%Y
M*"<G+"`T,"P@,C4I"BD["B1A='1R:6)U=&5S6R=B=7-I;F5S<T-A=&5G;W)Y
M)UT@/2!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B0G5S:6YE<W,@0V%T96=O
M<GDB*2P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`G<F5Q=6ER960G(#T^
M(&9A;'-E"BD["B1A='1R:6)U=&5S6R=B:7)T:&1A>2==(#T@87)R87DH"B`@
M("`G;&%B96PG(#T^(%\H(D)I<G1H9&%Y(BDL"B`@("`G='EP92<@/3X@)VUO
M;G1H9&%Y>65A<B<L"B`@("`G<&%R86US)R`]/B!A<G)A>2@Q.3`P+"!N=6QL
M+"!T<G5E+"`Q*2P*("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"BD["B1A='1R
M:6)U=&5S6R=N;W1E<R==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(DYO
M=&5S(BDL"B`@("`G='EP92<@/3X@)VQO;F=T97AT)RP*("`@("=R97%U:7)E
M9"<@/3X@9F%L<V4L"B`@("`G<&%R86US)R`]/B!A<G)A>2@G,R<L("<T,"<I
M"BD["B1A='1R:6)U=&5S6R=P9W!0=6)L:6-+97DG72`](&%R<F%Y*`H@("`@
M)VQA8F5L)R`]/B!?*")01U`@4'5B;&EC($ME>2(I+`H@("`@)W1Y<&4G(#T^
M("=L;VYG=&5X="<L"B`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@)W!A
M<F%M<R<@/3X@87)R87DH)S,G+"`G-#`G*0HI.PHD871T<FEB=71E<ULG<VUI
M;650=6)L:6-+97DG72`](&%R<F%Y*`H@("`@)VQA8F5L)R`]/B!?*")3+TU)
M344@4'5B;&EC($-E<G1I9FEC871E(BDL"B`@("`G='EP92<@/3X@)VQO;F=T
M97AT)RP*("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`G<&%R86US)R`]
M/B!A<G)A>2@G,R<L("<T,"<I"BD["B1A='1R:6)U=&5S6R=F<F5E8G5S>55R
M;"==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(D9R965B=7-Y(%523"(I
M+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=R97%U:7)E9"<@/3X@9F%L
M<V4L"B`@("`G<&%R86US)R`]/B!A<G)A>2@G)RP@-#`L(#(U-2D**3L*)&%T
M=')I8G5T97-;)W=E8G-I=&4G72`](&%R<F%Y*`H@("`@("=L86)E;"<@/3X@
M7R@B5V5B<VET92!54DPB*2P*("`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@
M("=R97%U:7)E9"<@/3X@9F%L<V4L"BD["B1A='1R:6)U=&5S6R=D97!A<G1M
M96YT)UT@/2!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B1&5P87)T;65N="(I
M+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=R97%U:7)E9"<@/3X@9F%L
M<V4L"BD["B1A='1R:6)U=&5S6R=N:6-K;F%M92==(#T@87)R87DH"B`@("`G
M;&%B96PG(#T^(%\H(DYI8VMN86UE(BDL"B`@("`G='EP92<@/3X@)W1E>'0G
M+`H@("`@)W)E<75I<F5D)R`]/B!F86QS92P**3L*)&%T=')I8G5T97-;)V]F
M9FEC92==(#T@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(D]F9FEC92(I+`H@
M("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=R97%U:7)E9"<@/3X@9F%L<V4*
M*3L*+RH@5&AI<R!A='1R:6)U=&4@=7-E<R!(;W)D92=S(&-A=&5G;W)I97,@
M86YD(&ES(&%N(&5X86UP;&4@:&]W('1O('5S92!A;B!E;G5M"B`J(&9I96QD
M+B`@1&]N)W0@9F]R9V5T('1O(&%D9"!A("=M87`G(&5N=')Y('1O(&-O;F9I
M9R]S;W5R8V5S+G!H<"!I9B!Y;W4@=V%N=`H@*B!T;R!U<V4@=&AI<R!A='1R
M:6)U=&4N("HO"B\O(')E<75I<F5?;VYC92`G2&]R9&4O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<"<["B\O("1C36%N86=E<B`]("9N97<@4')E9G-?0V%T
M96=O<GE-86YA9V5R*"D["B\O("1C871E9V]R:65S(#T@87)R87E?;65R9V4H
M87)R87DH7R@B56YF:6QE9"(I*2P@)&--86YA9V5R+3YG970H*2D["B\O("1A
M='1R:6)U=&5S6R=C871E9V]R>2==(#T@87)R87DH"B\O("`@("`G;&%B96PG
M(#T^(%\H(D-A=&5G;W)Y(BDL"B\O("`@("`G='EP92<@/3X@)V5N=6TG+`HO
M+R`@("`@)W!A<F%M<R<@/3X@87)R87DH)&-A=&5G;W)I97,I+`HO+R`@("`@
M)W)E<75I<F5D)R`]/B!F86QS90HO+R`I.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO
M<F1E+P``````````````````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,38R-S<`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+V5T8R]P<V$M:&]R9&4O:&]R9&4O<F5G:7-T<GDN9"\`````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S`#`R
M,#,W,0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]R96=I<W1R
M>2YD+VEM<"YP:'``````````````````````````````````````````````
M````````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P
M,#<`,3`T,3<S-C(W-#,`,#(Q-C8P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J"B`J"4%D9&]N(&9O<B!0;&5S
M:R!(;W)D92!C;VYF:6=U<F%T:6]N(&9R;VT@26UP+"`*("H);75S="!B92!P
M;&%C960@=&\@4%)/1%5#5%]23T]47T0O971C+VAO<F1E+W)E9VES=')Y+F0*
M("HO"B1T:&ES+3YA<'!L:6-A=&EO;G-;)VEM<"==(#T@87)R87DH"@DG9FEL
M97)O;W0G(#T^("1T:&ES+3YA<'!L:6-A=&EO;G-;)VAO<F1E)UU;)V9I;&5R
M;V]T)UT@+B`G+VEM<"<L"@DG=V5B<F]O="<@/3X@)'1H:7,M/F%P<&QI8V%T
M:6]N<ULG:&]R9&4G75LG=V5B<F]O="==("X@)R]I;7`G+`H))VYA;64G(#T^
M(%\H(DUA:6PB*2P*("`@("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@)W!R
M;W9I9&5S)R`]/B`G;6%I;"<L"BD["@HD=&AI<RT^87!P;&EC871I;VYS6R=I
M;7`M9F]L9&5R<R==(#T@87)R87DH"B`@("`G<W1A='5S)R`]/B`G8FQO8VLG
M+`H@("`@)V%P<"<@/3X@)VEM<"<L"B`@("`G8FQO8VMN86UE)R`]/B`G=')E
M95]F;VQD97)S)RP*("`@("=M96YU7W!A<F5N="<@/3X@)VEM<"<L"BD["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]R
M96=I<W1R>2YD+W1U<F)A+G!H<```````````````````````````````````
M````````````````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`T-#8`,3`T,3<S-C(W-#,`,#(R,C$V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B1T:&ES+3YA<'!L:6-A
M=&EO;G-;)W1U<F)A)UT@/2!A<G)A>2@*("`@("=F:6QE<F]O="<@/3X@)'1H
M:7,M/F%P<&QI8V%T:6]N<ULG:&]R9&4G75LG9FEL97)O;W0G72`N("<O='5R
M8F$G+`H@("`@)W=E8G)O;W0G(#T^("1T:&ES+3YA<'!L:6-A=&EO;G-;)VAO
M<F1E)UU;)W=E8G)O;W0G72`N("<O='5R8F$G+`H@("`@)VYA;64G(#T^(%\H
M(D%D9')E<W,@0F]O:R(I+`H@("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@
M("`G<')O=FED97,G(#T^(&%R<F%Y*"=C;VYT86-T<R<L("=C;&EE;G1S)RDL
M"BD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O<F5G:7-T<GDN9"]K
M<F]N;VQI=&@N<&AP````````````````````````````````````````````
M`````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S`S`#$P
M-#$W,S8R-S0S`#`R,S$P-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HD=&AI<RT^87!P;&EC871I;VYS6R=K<F]N
M;VQI=&@G72`](&%R<F%Y*`H@("`@)V9I;&5R;V]T)R`]/B`D=&AI<RT^87!P
M;&EC871I;VYS6R=H;W)D92==6R=F:6QE<F]O="==("X@)R]K<F]N;VQI=&@G
M+`H@("`@)W=E8G)O;W0G(#T^("1T:&ES+3YA<'!L:6-A=&EO;G-;)VAO<F1E
M)UU;)W=E8G)O;W0G72`N("<O:W)O;F]L:71H)RP*("`@("=N86UE)R`]/B!?
M*")#86QE;F1A<B(I+`H@("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@("`G
M<')O=FED97,G(#T^("=C86QE;F1A<B<**3L*"B1T:&ES+3YA<'!L:6-A=&EO
M;G-;)VMR;VYO;&ET:"UM96YU)UT@/2!A<G)A>2@*("`@("=S=&%T=7,G(#T^
M("=B;&]C:R<L"B`@("`G87!P)R`]/B`G:W)O;F]L:71H)RP*("`@("=B;&]C
M:VYA;64G(#T^("=T<F5E7VUE;G4G+`H@("`@)VUE;G5?<&%R96YT)R`]/B`G
M:W)O;F]L:71H)RP**3L*````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]E=&,O<'-A+6AO<F1E+VAO<F1E+W)E9VES=')Y+F0O:6YG;RYP:'``````
M```````````````````````````````````````````````````````P,3`P
M-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8W-0`Q,#0Q-S,V,C<T,P`P
M,C(P-#$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"B1T:&ES+3YA<'!L:6-A=&EO;G-;)VEN9V\G72`](&%R<F%Y
M*`H@("`@)V9I;&5R;V]T)R`]/B`D=&AI<RT^87!P;&EC871I;VYS6R=H;W)D
M92==6R=F:6QE<F]O="==("X@)R]I;F=O)RP@"B`@("`G=V5B<F]O="<@/3X@
M)'1H:7,M/F%P<&QI8V%T:6]N<ULG:&]R9&4G75LG=V5B<F]O="==("X@)R]I
M;F=O)RP*("`@("=N86UE)R`]/B!?*")&:6QT97)S(BDL"B`@("`G<W1A='5S
M)R`]/B`G86-T:79E)RP*("`@("=P<F]V:61E<R<@/3X@87)R87DH)VUA:6PO
M8FQA8VML:7-T1G)O;2<L("=M86EL+W-H;W=";&%C:VQI<W0G+"`G;6%I;"]W
M:&ET96QI<W1&<F]M)RP@)VUA:6PO<VAO=U=H:71E;&ES="<L("=M86EL+V%P
M<&QY1FEL=&5R<R<L("=M86EL+V-A;D%P<&QY1FEL=&5R<R<L("=M86EL+W-H
M;W=&:6QT97)S)RDL"B`@("`G;65N=5]P87)E;G0G(#T^("=I;7`G"BD["@``
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH
M;W)D92]H;W)D92]R96=I<W1R>2YD+VUN96UO+G!H<```````````````````
M````````````````````````````````````````,#$P,#0T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`T,34`,3`T,3<S-C(W-#,`,#(R,C$P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B1T
M:&ES+3YA<'!L:6-A=&EO;G-;)VUN96UO)UT@/2!A<G)A>2@*("`@("=F:6QE
M<F]O="<@/3X@)'1H:7,M/F%P<&QI8V%T:6]N<ULG:&]R9&4G75LG9FEL97)O
M;W0G72`N("<O;6YE;6\G+"`*("`@("=W96)R;V]T)R`]/B`D=&AI<RT^87!P
M;&EC871I;VYS6R=H;W)D92==6R=W96)R;V]T)UT@+B`G+VUN96UO)RP*("`@
M("=N86UE)R`]/B!?*").;W1E<R(I+`H@("`@)W-T871U<R<@/3X@)V%C=&EV
M92<L(`H@("`@)W!R;W9I9&5S)R`]/B`G;F]T97,G"BD[(`H*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O
M<F5G:7-T<GDN9"]P87-S=V0N<&AP````````````````````````````````
M`````````````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P-3<V`#$P-#$W,S8R-S0S`#`R,C0P-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HD=&AI<RT^87!P;&EC
M871I;VYS6R=M>6%C8V]U;G0G72`](&%R<F%Y*`H@("`@)VYA;64G(#T^(%\H
M(DUY($%C8V]U;G0B*2P*("`@("=S=&%T=7,G(#T^("=H96%D:6YG)RP**3L*
M"B1T:&ES+3YA<'!L:6-A=&EO;G-;)W!A<W-W9"==(#T@87)R87DH"B`@("`G
M9FEL97)O;W0G(#T^("1T:&ES+3YA<'!L:6-A=&EO;G-;)VAO<F1E)UU;)V9I
M;&5R;V]T)UT@+B`G+W!A<W-W9"<L"B`@("`G=V5B<F]O="<@/3X@)'1H:7,M
M/F%P<&QI8V%T:6]N<ULG:&]R9&4G75LG=V5B<F]O="==("X@)R]P87-S=V0G
M+`H@("`@)VYA;64G(#T^(%\H(E!A<W-W;W)D(BDL"B`@("`G<W1A='5S)R`]
M/B`G86-T:79E)RP*("`@("=M96YU7W!A<F5N="<@/3X@)VUY86-C;W5N="<*
M*3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+V-O;F8N<&AP````
M````````````````````````````````````````````````````````````
M```````````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C8P,P`Q
M,#0Q-S,V,C<T,P`P,3<W,S4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH@0T].1DE'(%-405)4+B!$3R!.3U0@
M0TA!3D=%($%.651(24Y'($E.($]2($%&5$52(%1(25,@3$E.12X@*B\*+R\@
M)$AO<F1E.B!H;W)D92]C;VYF:6<O8V]N9BYX;6PL=B`Q+C<T+C(N,S,@,C`P
M-B\P,R\R-2`Q,CHQ-#HR-2!J86X@17AP("0*+RHJ"BH@4&QE<VL@<')E9&5F
M:6YE9"!C;VYF:6=U<F%T:6]N(&9O<B!(;W)D93,**BHO"@HD8V]N9ELG9&5B
M=6=?;&5V96PG72`]($5?15)23U(["B1C;VYF6R=M87A?97AE8U]T:6UE)UT@
M/2`P.PHD8V]N9ELG=7-E7W-S;"==(#T@,CL*)&-O;F9;)W-E<G9E<B==6R=N
M86UE)UT@/2`D7U-%4E9%4ELG4T525D527TY!344G73L*)&-O;F9;)W-E<G9E
M<B==6R=P;W)T)UT@/2`D7U-%4E9%4ELG4T525D527U!/4E0G73L*)&-O;F9;
M)V-O;7!R97-S7W!A9V5S)UT@/2!T<G5E.PHD8V]N9ELG=6UA<VLG72`](#`W
M-SL*)&-O;F9;)W-E<W-I;VXG75LG;F%M92==(#T@)TAO<F1E,R<["B1C;VYF
M6R=S97-S:6]N)UU;)V-A8VAE7VQI;6ET97(G72`]("=N;V-A8VAE)SL*)&-O
M;F9;)W-E<W-I;VXG75LG=&EM96]U="==(#T@,#L*)&-O;F9;)V-O;VMI92==
M6R=D;VUA:6XG72`]("1?4T525D526R=315)615)?3D%-12==.PHD8V]N9ELG
M8V]O:VEE)UU;)W!A=&@G72`]("<O)SL*)&-O;F9;)W-Q;"==6R=P97)S:7-T
M96YT)UT@/2!F86QS93L*)&-O;F9;)W-Q;"==6R=H;W-T<W!E8R==(#T@)VQO
M8V%L:&]S="<["B1C;VYF6R=S<6PG75LG=7-E<FYA;64G72`]("=H;W)D92<[
M"B1C;VYF6R=S<6PG75LG<V]C:V5T)UT@/2`G+W9A<B]L:6(O;7ES<6PO;7ES
M<6PN<V]C:R<["B1C;VYF6R=S<6PG75LG<')O=&]C;VPG72`]("=U;FEX)SL*
M)&-O;F9;)W-Q;"==6R=D871A8F%S92==(#T@)VAO<F1E)SL*"B\O(&=E="!P
M87-S=V]R9"!F<F]M("]E=&,O<'-A+RYW96)M86EL+G-H861O=PII9B`H(2@D
M9F0@/2!F;W!E;B@B+V5T8R]P<V$O+G=E8FUA:6PN<VAA9&]W(BP@(G(B*2DI
M('L*("!E8VAO("(\<V-R:7!T/F%L97)T*"=5;F%B;&4@=&\@9V5T('=E8FUA
M:6P@<&%S<W=O<F0A)RD\+W-C<FEP=#XB.PH@(&5X:70H*3L*?0IF<V-A;F8H
M)&9D+"`B)7,B+"`D8G5F9BD["F9C;&]S92@D9F0I.PH*)&-O;F9;)W-Q;"==
M6R=P87-S=V]R9"==(#T@<')E9U]R97!L86-E*"(O7&XO(BP@(B(L("1B=69F
M*3L*)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UT@/2`G=71F."<["B1C;VYF6R=S
M<6PG75LG<&AP='EP92==(#T@)VUY<W%L)SL*)&-O;F9;)V%U=&@G75LG861M
M:6YS)UT@/2!A<G)A>2@I.PHD8V]N9ELG875T:"==6R=C:&5C:VEP)UT@/2!T
M<G5E.PHD8V]N9ELG875T:"==6R=C:&5C:V)R;W=S97(G72`]('1R=64["B1C
M;VYF6R=A=71H)UU;)V%L=&5R;F%T95]L;V=I;B==(#T@9F%L<V4["B1C;VYF
M6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO9V]U="==(#T@9F%L<V4["B1C;VYF
M6R=A=71H)UU;)W!A<F%M<R==6R=A<'`G72`]("=I;7`G.PHD8V]N9ELG875T
M:"==6R=D<FEV97(G72`]("=A<'!L:6-A=&EO;B<["B1C;VYF6R=S:6=N=7`G
M75LG86QL;W<G72`](&9A;'-E.PHD8V]N9ELG;&]G)UU;)W!R:6]R:71Y)UT@
M/2!014%27TQ/1U]%4E(["B1C;VYF6R=L;V<G75LG:61E;G0G72`]("=(3U)$
M12<["B1C;VYF6R=L;V<G75LG<&%R86US)UT@/2!A<G)A>2@I.PHD8V]N9ELG
M;&]G)UU;)VYA;64G72`]("<O=7-R+VQO8V%L+W!S82]V87(O;&]G+W!S82UH
M;W)D92YL;V<G.PHD8V]N9ELG;&]G)UU;)W!A<F%M<R==6R=A<'!E;F0G72`]
M('1R=64["B1C;VYF6R=L;V<G75LG='EP92==(#T@)V9I;&4G.PHD8V]N9ELG
M;&]G)UU;)V5N86)L960G72`]('1R=64["B1C;VYF6R=L;V=?86-C97-S:V5Y
M<R==(#T@9F%L<V4["B1C;VYF6R=P<F5F<R==6R=P87)A;7,G75LG9')I=F5R
M8V]N9FEG)UT@/2`G:&]R9&4G.PHD8V]N9ELG<')E9G,G75LG9')I=F5R)UT@
M/2`G<W%L)SL*)&-O;F9;)V1A=&%T<F5E)UU;)W!A<F%M<R==6R=D<FEV97)C
M;VYF:6<G72`]("=H;W)D92<["B1C;VYF6R=D871A=')E92==6R=D<FEV97(G
M72`]("=S<6PG.PHD8V]N9ELG9W)O=7`G75LG9')I=F5R)UT@/2`G9&%T871R
M964G.PHD8V]N9ELG8V%C:&4G75LG9&5F875L=%]L:69E=&EM92==(#T@,3@P
M,#L*)&-O;F9;)V-A8VAE)UU;)W!A<F%M<R==6R=D:7(G72`]($AO<F1E.CIG
M971496UP1&ER*"D["B1C;VYF6R=C86-H92==6R=P87)A;7,G75LG9V,G72`]
M(#@V-#`P.PHD8V]N9ELG8V%C:&4G75LG9')I=F5R)UT@/2`G9FEL92<["B1C
M;VYF6R=T;VME;B==6R=D<FEV97(G72`]("=N;VYE)SL*)&-O;F9;)VUA:6QE
M<B==6R=P87)A;7,G75LG:&]S="==(#T@)VQO8V%L:&]S="<["B1C;VYF6R=M
M86EL97(G75LG<&%R86US)UU;)V%U=&@G72`]("<P)SL*)&-O;F9;)VUA:6QE
M<B==6R=T>7!E)UT@/2`G<VUT<"<["B1C;VYF6R=V9G,G75LG<&%R86US)UU;
M)W9F<W)O;W0G72`]("<O=&UP)SL*)&-O;F9;)W9F<R==6R=T>7!E)UT@/2`G
M9FEL92<["B1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T>7!E)UT@/2`G;F]N
M92<["B1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UT@/2`G("]U<W(O<VAA<F4O
M;6ES8R]M86=I8R<["B1C;VYF6R=P<F]B;&5M<R==6R=E;6%I;"==(#T@)W=E
M8FUA<W1E<D!E>&%M<&QE+F-O;2<["B1C;VYF6R=P<F]B;&5M<R==6R=M86EL
M9&]M86EN)UT@/2`G97AA;7!L92YC;VTG.PHD8V]N9ELG<')O8FQE;7,G75LG
M=&EC:V5T<R==(#T@9F%L<V4["B1C;VYF6R=M96YU)UU;)V%P<',G72`](&%R
M<F%Y*"D["B1C;VYF6R=M96YU)UU;)V%L=V%Y<R==(#T@9F%L<V4["B1C;VYF
M6R=M96YU)UU;)VQI;FMS)UU;)VAE;'`G72`]("=A;&PG.PHD8V]N9ELG;65N
M=2==6R=L:6YK<R==6R=H96QP7V%B;W5T)UT@/2!T<G5E.PHD8V]N9ELG;65N
M=2==6R=L:6YK<R==6R=O<'1I;VYS)UT@/2`G875T:&5N=&EC871E9"<["B1C
M;VYF6R=M96YU)UU;)VQI;FMS)UU;)W!R;V)L96TG72`]("=N979E<B<["B1C
M;VYF6R=M96YU)UU;)VQI;FMS)UU;)VQO9VEN)UT@/2`G86QL)SL*)&-O;F9;
M)VUE;G4G75LG;&EN:W,G75LG;&]G;W5T)UT@/2`G875T:&5N=&EC871E9"<[
M"B1C;VYF6R=H;V]K<R==6R=P97)M<V1E;FEE9"==(#T@9F%L<V4["B1C;VYF
M6R=H;V]K<R==6R=U<V5R;F%M92==(#T@9F%L<V4["B1C;VYF6R=H;V]K<R==
M6R=P<F5A=71H96YT:6-A=&4G72`](&9A;'-E.PHD8V]N9ELG:&]O:W,G75LG
M<&]S=&%U=&AE;G1I8V%T92==(#T@9F%L<V4["B1C;VYF6R=H;V]K<R==6R=A
M=71H;&1A<"==(#T@9F%L<V4["B1C;VYF6R=P;W)T86PG75LG9FEX961?8FQO
M8VMS)UT@/2!A<G)A>2@I.PHD8V]N9ELG86-C;W5N=',G75LG9')I=F5R)UT@
M/2`G;G5L;"<["B1C;VYF6R=I;7-P)UU;)V5N86)L960G72`](&9A;'-E.PHD
M8V]N9ELG:V]L86(G75LG96YA8FQE9"==(#T@9F%L<V4["B\J($-/3D9)1R!%
M3D0N($1/($Y/5"!#2$%.1T4@04Y95$A)3D<@24X@3U(@0D5&3U)%(%1(25,@
M3$E.12X@*B\*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]M:6UE7V1R:79E
M<G,N<&AP````````````````````````````````````````````````````
M````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S8R,C<`
M,3`T,3<S-C(W-#,`,#(Q-3`R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V-O
M;F9I9R]M:6UE7V1R:79E<G,N<&AP+F1I<W0L=B`Q+CDW+C8N-R`R,#`U+S$P
M+S$X(#$Q.C,S.C,W(&IA;B!%>'`@)`H@*@H@*B!$96-I9&4@=VAI8V@@;W5T
M<'5T(&1R:79E<G,@>6]U('=A;G0@=&\@86-T:79A=&4@9F]R(&%L;"!(;W)D
M90H@*B!A<'!L:6-A=&EO;G,N($EN9&EV:61U86P@2&]R9&4@87!P;&EC871I
M;VYS(&-A;B!O=F5R<FED92!T:&5S92!S971T:6YG<PH@*B!I;B!T:&5I<B!C
M;VYF:6<O;6EM95]D<FEV97)S+G!H<"!F:6QE<RX*("H*("H@5&AE(&%V86EL
M86)L92!D<FEV97)S(&%R93H*("H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*("H@8W-S("`@("`@("`@("`@0U-3(%-T>6QE<PH@*B!D96(@("`@("`@
M("`@("!$96)I86X@<&%C:V%G97,*("H@96YR:6-H960@("`@("`@16YR:6-H
M960@=&5X="!F;W)M870*("H@96YS8W)I<'0@("`@("`@1TY5(&5N<V-R:7!T
M"B`J(&AT;6P@("`@("`@("`@($A434P@9&%T80H@*B!I;6%G97,@("`@("`@
M("!);6%G92!F:6QE<PH@*B!M<W=O<F0@("`@("`@("!-:6-R;W-O9G0@5V]R
M9"!F:6QE<R!V:6$@=W9(=&UL"B`J(&US97AC96P@("`@("`@($UI8W)O<V]F
M="!%>&-E;"!F:6QE<R!V:6$@>&QH=&UL"B`J(&US<&]W97)P;VEN="`@($UI
M8W)O<V]F="!0;W=E<G!O:6YT(&9I;&5S('9I82!P<'1H=&UL"B`J(&]O;R`@
M("`@("`@("`@($]P96Y/9F9I8V4N;W)G+U-T87)/9F9I8V4@1&]C=6UE;G1S
M"B`J('!D9B`@("`@("`@("`@(%!O<G1A8FQE($1O8W5M96YT($9O<FUA="`H
M4$1&*2!F:6QE<PH@*B!P:'`@("`@("`@("`@("!4:&4@:6YT97)N86P@4$A0
M-"!S>6YT87@@:&EG:&QI9VAT:6YG(&5N9VEN90H@*B!P;&%I;B`@("`@("`@
M("!2971U<FX@=&5X="P@=VET:"!L:6YK<R!M861E(&-L:6-K86)L92!A;F0@
M;W1H97(@2%1-3`H@*B`@("`@("`@("`@("`@("!F:6QT97)E9"!O=70*("H@
M<F%R("`@("`@("`@("`@4D%2(&%R8VAI=F5S"B`J(')E<&]R="`@("`@("`@
M(%)E<&]R="!M97-S86=E<R`H4D9#(#,T-3(I"B`J(')F8S@R,B`@("`@("`@
M($1I9V5S=&5D(&UE<W-A9V5S("A21D,@,C`T-B!;-2XR+C%=*0H@*B!R:6-H
M=&5X="`@("`@("!2:6-H=&5X="!T97AT(&9O<FUA="`H4D9#(#$S-#$@6S<N
M,2XS72D*("H@<G!M("`@("`@("`@("`@4E!-('!A8VMA9V5S"B`J('-E8W5R
M:71Y("`@("`@(%-E8W5R92!M=6QT:7!A<G1S("A21D,@,3@T-RD*("H@<VEM
M<&QE("`@("`@("`@3W5T<'5T('1E>'0@=VET:&]U="!M;V1I9FEC871I;VX*
M("H@<W)C:&EG:&QI=&4@("`@4V]U<F-E($AI9VAL:6=H=`H@*B!T9WH@("`@
M("`@("`@("!487)B86QL<RP@:6YC;'5D:6YG(&=Z:7!P960@;VYE<PH@*B!T
M;F5F("`@("`@("`@("!-4RU43D5&(&%T=&%C:&UE;G1S"B`J('9C87)D("`@
M("`@("`@('9#87)D<PH@*B!W96)C<'`@("`@("`@("!796(@0R!0;'5S(%!L
M=7,*("H@>FEP("`@("`@("`@("`@6FEP(&9I;&5S"B`J+PHD;6EM95]D<FEV
M97)S7VUA<%LG:&]R9&4G75LG<F5G:7-T97)E9"==(#T@87)R87DH"B`@("`G
M8W-S)RP@)V1E8B<L("=E;G)I8VAE9"<L("=E;G-C<FEP="<L("=H=&UL)RP@
M)VEM86=E<R<L("=M<W=O<F0G+`H@("`@)VUS97AC96PG+"`G;7-P;W=E<G!O
M:6YT)RP@)V]O;R<L("=P9&8G+"`G<&AP)RP@)W!L86EN)RP@)W)A<B<L("=R
M97!O<G0G+`H@("`@)W)F8S@R,B<L("=R:6-H=&5X="<L("=R<&TG+"`G<V5C
M=7)I='DG+"`G<VEM<&QE)RP@)W-R8VAI9VAL:71E)RP@)W1G>B<L"B`@("`G
M=&YE9B<L("=V8V%R9"<L("=W96)C<'`G+"`G>FEP)RD["@H*+RHJ"B`J($EF
M('EO=2!W86YT('1O('-P96-I9FEC86QL>2!O=F5R<FED92!A;GD@34E-12!T
M>7!E('1O(&)E(&AA;F1L960@8GD*("H@82!S<&5C:69I8R!D<FEV97(L('1H
M96X@96YT97(@:70@:&5R92X@($YO<FUA;&QY+"!T:&ES(&ES('-A9F4@=&\*
M("H@;&5A=F4L(&)U="!I="=S('5S969U;"!W:&5N(&UU;'1I<&QE(&1R:79E
M<G,@:&%N9&QE('1H92!S86UE($U)344*("H@='EP92P@86YD('EO=2!W86YT
M('1O('-P96-I9GD@97AA8W1L>2!W:&EC:"!O;F4@<VAO=6QD(&AA;F1L92!I
M="X*("HO"B1M:6UE7V1R:79E<G-?;6%P6R=H;W)D92==6R=O=F5R<FED97,G
M72`](&%R<F%Y*"D["@H*+RHJ"B`J($1R:79E<B!S<&5C:69I8R!S971T:6YG
M<RX@2&5R92P@>6]U(&AA=F4@=&\@8V]N9FEG=7)E(&5A8V@@9')I=F5R"B`J
M('=H:6-H('EO=2!C:&]S92!T;R!A8W1I=F%T92!A8F]V92X@1&5F875L="!S
M971T:6YG<R!H879E(&)E96X*("H@9FEL;&5D(&EN(&9O<B!T:&5M+"!A;F0@
M:68@>6]U(&AA=F5N)W0@86-T:79A=&5D(&ET+"!T:&5N(&IU<W0*("H@;&5A
M=F4@:70@87,@:70@:7,@+2!I="!W;VXG="!G970@;&]A9&5D+@H@*@H@*B!4
M:&4@)VAA;F1L97,G('-E='1I;F<@8F5L;W<@<VAO=6QD;B=T(&)E(&-H86YG
M960@:6X@;6]S=`H@*B!C:7)C=6US=&%N8V5S+B!)="!R96=I<W1E<G,@82!S
M970@;V8@34E-12!T>7!E('1H870@=&AE(&1R:79E<B!C86X*("H@:&%N9&QE
M+B!4:&4@)W@M97AT96YS:6]N)R!-24U%('1Y<&4@:7,@82!S<&5C:6%L(&]N
M92!T;R!(;W)D92!T:&%T"B`J(&UA<',@82!F:6QE(&5X=&5N<VEO;B!T;R!A
M($U)344@='EP92X@270G<R!U<V5F=6P@=VAE;B!Y;W4@:VYO=PH@*B!T:&%T
M(&%L;"!F:6QE<R!E;F1I;F<@:6X@)RYC)R!A<F4@0R!F:6QE<RP@9F]R(&5X
M86UP;&4N(%EO=2!C86X@<V5T"B`J('1H92!-24U%('-U8G1Y<&4@=&\@)RHG
M('1O(&UA=&-H(&%L;"!P;W-S:6)L92!S=6)T>7!E<PH@*B`H:2YE+B`G:6UA
M9V4O*B<I+@H@*@H@*B!4:&4@)VEC;VYS)R!E;G1R>2!I<R!F;W(@=&AE(&1R
M:79E<B!T;R!R96=I<W1E<B!V87)I;W5S(&EC;VYS(&9O<@H@*B!T:&4@34E-
M12!T>7!E<R!I="!H86YD;&5S+B!4:&4@87)R87D@8V]N<VES=',@;V8@82`G
M9&5F875L="<@:6-O;@H@*B!F;W(@=&AA="!D<FEV97(L(&%N9"!C86X@86QS
M;R!I;F-L=61E('-P96-I9FEC($U)344M='EP97,@=VAI8V@@8V%N"B`J(&AA
M=F4@=&AE:7(@;W=N(&EC;VYS+B!9;W4@8V%N('-E="!T:&4@34E-12!S=6)T
M>7!E('1O("<J)R!T;R!M871C:`H@*B!A;&P@<&]S<VEB;&4@<W5B='EP97,@
M*&DN92X@)VEM86=E+RHG*2X*("HO"@HO*BH*("H@1&5F875L="!D<FEV97(@
M<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V1E9F%U;'0G
M75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G("`@("`@("`@("`@
M("`@("`@("`@("`]/B`G=&5X="YP;F<G+`H@("`@)V%U9&EO+RHG("`@("`@
M("`@("`@("`@("`@("`@("`]/B`G875D:6\N<&YG)RP*("`@("=M97-S86=E
M+RHG("`@("`@("`@("`@("`@("`@("`@/3X@)VUA:6PN<&YG)RP*("`@("=U
M;FMN;W=N+RHG("`@("`@("`@("`@("`@("`@("`@/3X@)V)I;F%R>2YP;F<G
M+`H@("`@)W9I9&5O+RHG("`@("`@("`@("`@("`@("`@("`@("`]/B`G=FED
M96\N<&YG)RP*("`@("=A<'!L:6-A=&EO;B]P9W`M<VEG;F%T=7)E)R`@("`@
M/3X@)V5N8W)Y<'1I;VXN<&YG)RP*("`@("=A<'!L:6-A=&EO;B]X+7!K8W,W
M+7-I9VYA='5R92<@/3X@)V5N8W)Y<'1I;VXN<&YG)RP*("`@("=A<'!L:6-A
M=&EO;B]O8W1E="US=')E86TG("`@("`@/3X@)V)I;F%R>2YP;F<G*3L*"@HO
M*BH*("H@1&5F875L="!T97AT(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG<VEM<&QE)UU;)VAA;F1L97,G72`](&%R<F%Y
M*`H@("`@)W1E>'0O*B<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=S:6UP
M;&4G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=T97AT
M+G!N9R<I.PH*"B\J*@H@*B!0;&%I;B!T97AT(&1R:79E<B!S971T:6YG<PH@
M*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<&QA:6XG75LG:&%N9&QE<R==
M(#T@87)R87DH"B`@("`G=&5X="]P;&%I;B<I.PHD;6EM95]D<FEV97)S6R=H
M;W)D92==6R=P;&%I;B==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L
M="<@/3X@)W1E>'0N<&YG)RD["@H*+RHJ"B`J(%!(4"!D<FEV97(@<V5T=&EN
M9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!H<"==6R=I;FQI;F4G
M72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!H<"==6R=H86YD
M;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]X+7!H<"<L("=X+65X
M=&5N<VEO;B]P:'!S)RP*("`@("=X+65X=&5N<VEO;B]P:'`S<R<L("=A<'!L
M:6-A=&EO;B]X+6AT='!D+7!H<"<L"B`@("`G87!P;&EC871I;VXO>"UH='1P
M9"UP:'`S)RP@)V%P<&QI8V%T:6]N+W@M:'1T<&0M<&AP<R<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=P:'`G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@
M)V1E9F%U;'0G(#T^("=P:'`N<&YG)RD["@H*+RHJ"B`J($-34R!D<FEV97(@
M<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V-S<R==6R=I
M;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V-S<R==
M6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+V-S<R<L("=X+65X=&5N
M<VEO;B]C<W,G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG8W-S)UU;)VEC
M;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G:'1M;"YP;F<G*3L*
M"@HO*BH*("H@16YR:6-H960@=&5X="!D<FEV97(@<V5T=&EN9W,*("HO"B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VAT;6PG75LG:6YL:6YE)UT@/2!F86QS
M93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG:'1M;"==6R=H86YD;&5S)UT@
M/2!A<G)A>2@*("`@("=T97AT+VAT;6PG*3L*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG:'1M;"==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@
M/3X@)VAT;6PN<&YG)RD["@H*+RHJ"B`J($5N<FEC:&5D('1E>'0@9')I=F5R
M('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=E;G)I8VAE
M9"==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)V5N<FEC:&5D)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E>'0O96YR
M:6-H960G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YR:6-H960G75LG
M:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=T97AT+G!N9R<I
M.PH*"B\J*@H@*B!2:6-H=&5X="!T97AT(&1R:79E<B!S971T:6YG<PH@*B\*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<FEC:'1E>'0G75LG:6YL:6YE)UT@
M/2!T<G5E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R:6-H=&5X="==6R=H
M86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+W)I8VAT97AT)RD["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)W)I8VAT97AT)UU;)VEC;VYS)UT@/2!A<G)A
M>2@*("`@("=D969A=6QT)R`]/B`G=&5X="YP;F<G*3L*"@HO*BH*("H@5V5B
M($,@4&QU<R!0;'5S(&1R:79E<B!S971T:6YG<PH@*B!H='1P.B\O=V5B8W!P
M+G-O=7)C969O<F=E+FYE="\*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)W=E8F-P<"==6R=L;V-A=&EO;B==(#T@)R]U<W(O8FEN+W=E8F-P<"<["B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==6R=I;FQI;F4G72`]('1R
M=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==6R=H86YD;&5S
M)UT@/2!A<G)A>2@*("`@("=T97AT+WAM;"<L("=T97AT+W-G;6PG+"`G87!P
M;&EC871I;VXO>&UL)RP*("`@("=A<'!L:6-A=&EO;B]X+7-H)RP@)V%P<&QI
M8V%T:6]N+W@M:F%V87-C<FEP="<L("=A<'!L:6-A=&EO;B]X+71C;"<L"B`@
M("`G>"UE>'1E;G-I;VXO87-M)RP@)V%P<&QI8V%T:6]N+W@M87-P)RP@)W@M
M97AT96YS:6]N+V)A<R<L"B`@("`G>"UE>'1E;G-I;VXO8W,G+"`G=&5X="]X
M+6-S<F,G+"`G>"UE>'1E;G-I;VXO<F,G+`H@("`@)W1E>'0O>"UC*RMS<F,G
M+"`G=&5X="]X+6,K*W-R8R<L("=T97AT+W@M8RLK<W)C)RP*("`@("=T97AT
M+W@M8VAD<B<L("=X+65X=&5N<VEO;B]B870G+"`G=&5X="]X+69O<G1R86XG
M+`H@("`@)W@M97AT96YS:6]N+V8W-R<L("=X+65X=&5N<VEO;B]F.3`G+"`G
M>"UE>'1E;G-I;VXO9F]R)RP*("`@("=X+65X=&5N<VEO;B]F=&XG+"`G=&5X
M="]X+6IA=F$G+"`G87!P;&EC871I;VXO>"UJ879A<V-R:7!T)RP*("`@("=T
M97AT+W-G;6PG+"`G=&5X="]X;6PG+"`G=&5X="]X+7!A<V-A;"<L"B`@("`G
M87!P;&EC871I;VXO>"UC9VDG+"`G87!P;&EC871I;VXO>"UP97)L)RP@)V%P
M<&QI8V%T:6]N+W@M<'ET:&]N)RP*("`@("=T97AT+W@M<W%L)RP@)W1E>'0O
M>"UT8VPG+`H@("`@)V%P<&QI8V%T:6]N+W@M<VAE;&QS8W)I<'0G+"`G>"UE
M>'1E;G-I;VXO=FAD)RP@)W@M97AT96YS:6]N+W9H9&PG*3L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@
M("=D969A=6QT)R`@("`@("`@("`@("`@("`@(#T^("=T97AT+G!N9R<L"B`@
M("`G=&5X="]X;6PG("`@("`@("`@("`@("`@("`]/B`G>&UL+G!N9R<L"B`@
M("`G=&5X="]X+6-S<F,G("`@("`@("`@("`@("`]/B`G<V]U<F-E+6,N<&YG
M)RP*("`@("=T97AT+W@M8VAD<B<@("`@("`@("`@("`@(#T^("=S;W5R8V4M
M:"YP;F<G+`H@("`@)W1E>'0O>"UJ879A)R`@("`@("`@("`@("`@/3X@)W-O
M=7)C92UJ879A+G!N9R<L"B`@("`G87!P;&EC871I;VXO>"UJ879A<V-R:7!T
M)R`]/B`G<V-R:7!T+6IS+G!N9R<I.PH*+RHJ"B`J(%-O=7)C92U(:6=H;&EG
M:'0@9')I=F5R('-E='1I;F=S"B`J(&AT='`Z+R]W=W<N9VYU+F]R9R]S;V9T
M=V%R92]S<F,M:&EG:&QI=&4O"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=S<F-H:6=H;&ET92==6R=L;V-A=&EO;B==(#T@)R]U<W(O8FEN+W-O=7)C
M92UH:6=H;&EG:'0G.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=S<F-H:6=H
M;&ET92==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W-R8VAI9VAL:71E)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E
M>'0O>"UC<W)C)RP@)W1E>'0O>"UC*RMS<F,G+"`G=&5X="]X+6IA=F$G+`H@
M("`@)V%P<&QI8V%T:6]N+W@M<&5R;"<L("=A<'!L:6-A=&EO;B]X+7!Y=&AO
M;B<L("=T97AT+W@M8RLK<W)C)RP*("`@("=T97AT+V-P<"<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=S<F-H:6=H;&ET92==6R=I8V]N<R==(#T@87)R
M87DH"B`@("`G9&5F875L="<@("`@("`@("`@("`@("`@("`]/B`G=&5X="YP
M;F<G+`H@("`@)W1E>'0O>"UC<W)C)R`@("`@("`@("`@("`@/3X@)W-O=7)C
M92UC+G!N9R<L"B`@("`G=&5X="]X+6,K*W-R8R<@("`@("`@("`@("`]/B`G
M<V]U<F-E+6,N<&YG)RP*("`@("=T97AT+V-P<"<@("`@("`@("`@("`@("`@
M(#T^("=S;W5R8V4M8RYP;F<G+`H@("`@)W1E>'0O>"UJ879A)R`@("`@("`@
M("`@("`@/3X@)W-O=7)C92UJ879A+G!N9R<I.PH*+RHJ"B`J($=.52!%;G-C
M<FEP="!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)V5N<V-R:7!T)UU;)VQO8V%T:6]N)UT@/2`G+W5S<B]B:6XO96YS8W)I
M<'0G.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=E;G-C<FEP="==6R=I;FQI
M;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V5N<V-R:7!T
M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W@M8V=I
M)RP@)V%P<&QI8V%T:6]N+W@M<VAE;&QS8W)I<'0G+"`G87!P;&EC871I;VXO
M>"UJ879A<V-R:7!T)RP*("`@("=A<'!L:6-A=&EO;B]X+7!E<FPG+"`G87!P
M;&EC871I;VXO>&UL)RP@)W1E>'0O>&UL)RP*("`@("=T97AT+V1I9F8G+"`G
M=&5X="]X+61I9F8G+"`G=&5X="]X+7!A=&-H)RP@)W1E>'0O>"UC<W)C)RP*
M("`@("=X+65X=&5N<VEO;B]C<R<L("=T97AT+W@M:F%V82<L("=T97AT+W@M
M8VAD<B<L("=T97AT+W@M8RLK<W)C)RP*("`@("=T97AT+W@M8RLK:&1R)RP@
M)W@M97AT96YS:6]N+W9H9"<L("=X+65X=&5N<VEO;B]V:&1L)RP@)W1E>'0O
M>"US<6PG+`H@("`@)W@M97AT96YS:6]N+W9B)RP@)W@M97AT96YS:6]N+W9B
M82<L("=T97AT+W@M96UA8W,M;&ES<"<L("=T97AT+W@M=&5X)RD["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VEC;VYS)UT@/2!A<G)A
M>2@*("`@("=D969A=6QT)R`@("`@("`@("`@("`@("`@(#T^("=T97AT+G!N
M9R<L"B`@("`G=&5X="]X;6PG("`@("`@("`@("`@("`@("`]/B`G>&UL+G!N
M9R<L"B`@("`G87!P;&EC871I;VXO>&UL)R`@("`@("`@("`]/B`G>&UL+G!N
M9R<L"B`@("`G=&5X="]X+6-S<F,G("`@("`@("`@("`@("`]/B`G<V]U<F-E
M+6,N<&YG)RP*("`@("=T97AT+W@M8VAD<B<@("`@("`@("`@("`@(#T^("=S
M;W5R8V4M:"YP;F<G+`H@("`@)W1E>'0O>"UJ879A)R`@("`@("`@("`@("`@
M/3X@)W-O=7)C92UJ879A+G!N9R<L"B`@("`G87!P;&EC871I;VXO>"UJ879A
M<V-R:7!T)R`]/B`G<V-R:7!T+6IS+G!N9R<I.PH*"B\J*@H@*B!487(@9')I
M=F5R('-E='1I;F=S"B`J(%1O(&%C8V5S<R!G>FEP<&5D(&9I;&5S+"!T:&4@
M>FQI8B!L:6)R87)Y(&UU<W0@:&%V92!B965N(&)U:6QT(&EN=&\@4$A0"B`J
M("AW:71H('1H92`M+7=I=&@M>FQI8B!O<'1I;VXI+@H@*B\*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG=&=Z)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG=&=Z)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@
M("`@)V%P<&QI8V%T:6]N+W@M8V]M<')E<W-E9"UT87(G+`H@("`@)V%P<&QI
M8V%T:6]N+W@M=&%R)RP*("`@("=A<'!L:6-A=&EO;B]X+71G>B<L"B`@("`G
M87!P;&EC871I;VXO>"UG>FEP)RP*("`@("=A<'!L:6-A=&EO;B]X+6=T87(G
M+`H@("`@)V%P<&QI8V%T:6]N+V=Z:7`G+`H@("`@)V%P<&QI8V%T:6]N+W@M
M9WII<"UC;VUP<F5S<V5D)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W1G
M>B==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)V-O;7!R
M97-S960N<&YG)RD["@H*+RHJ"B`J(%II<"!F:6QE(&1R:79E<B!S971T:6YG
M<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG>FEP)UU;)VEN;&EN92==
M(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG>FEP)UU;)VAA;F1L
M97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+WII<"<L"B`@("`G87!P
M;&EC871I;VXO>"UC;VUP<F5S<V5D)RP*("`@("=A<'!L:6-A=&EO;B]X+7II
M<"UC;VUP<F5S<V5D)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)WII<"==
M6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)V-O;7!R97-S
M960N<&YG)RD["@H*+RHJ"B`J(%)!4B!A<F-H:79E(&1R:79E<B!S971T:6YG
M<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F%R)UU;)VEN;&EN92==
M(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F%R)UU;)VAA;F1L
M97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W@M<F%R)RP*("`@("=A
M<'!L:6-A=&EO;B]X+7)A<BUC;VUP<F5S<V5D)RD["B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)W)A<B==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L
M="<@/3X@)V-O;7!R97-S960N<&YG)RD["@H*+RHJ"B`J($U3(%=O<F0@9')I
M=F5R('-E='1I;F=S"B`J(%1H:7,@9')I=F5R(')E<75I<F5S('=V5V%R92!T
M;R!B92!I;G-T86QL960N"B`J('=V5V%R92!H;VUE<&%G93H@:'1T<#HO+W=V
M=V%R92YS;W5R8V5F;W)G92YN970O"B`J"B`J(%1H92`G;&]C871I;VXG(&5N
M=')Y('-H;W5L9"!P;VEN="!T;R!T:&4@)W=V2'1M;"<@<')O9W)A;2P@3D]4
M('1H90H@*B`G=W9787)E)R!P<F]G<F%M+@H@*B\*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG;7-W;W)D)UU;)VQO8V%T:6]N)UT@/2`G+W5S<B]B:6XO=W9(
M=&UL)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VEN;&EN
M92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS=V]R9"==
M6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]V;F0N;7,M
M=V]R9"<L"B`@("`G87!P;&EC871I;VXO;7-W;W)D)RP**3L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@
M("=D969A=6QT)R`]/B`G;7-W;W)D+G!N9R<L"BD["@H*+RHJ"B`J($U3($5X
M8V5L(&1R:79E<B!S971T:6YG<PH@*B!4:&ES(&1R:79E<B!R97%U:7)E<R!X
M;&AT;6P@=&\@8F4@:6YS=&%L;&5D+@H@*B!X;&AT;6P@:&]M97!A9V4Z(&AT
M='`Z+R]C:&EC86=O+G-O=7)C969O<F=E+FYE="]X;&AT;6PO"B`J+PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=M<V5X8V5L)UU;)VQO8V%T:6]N)UT@/2`G
M+W5S<B]L;V-A;"]B:6XO>&QH=&UL)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG;7-E>&-E;"==6R=I;FQI;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=M<V5X8V5L)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G87!P;&EC871I;VXO
M;7-E>&-E;"<L"B`@("`G87!P;&EC871I;VXO>"UM<V5X8V5L)RD["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC96PG75LG:6-O;G,G72`](&%R<F%Y
M*`H@("`@)V1E9F%U;'0G(#T^("=M<V5X8V5L+G!N9R<I.PH*"B\J*@H@*B!-
M4R!0;W=E<G!O:6YT(&1R:79E<B!S971T:6YG<PH@*B!4:&ES(&1R:79E<B!R
M97%U:7)E<R!P<'1H=&UL+"!I;F-L=61E9"!W:71H('AL:'1M;"P@=&\@8F4@
M:6YS=&%L;&5D+@H@*B!X;&AT;6P@:&]M97!A9V4Z(&AT='`Z+R]C:&EC86=O
M+G-O=7)C969O<F=E+FYE="]X;&AT;6PO"B`J+PHD;6EM95]D<FEV97)S6R=H
M;W)D92==6R=M<W!O=V5R<&]I;G0G75LG;&]C871I;VXG72`]("<O=7-R+VQO
M8V%L+V)I;B]P<'1H=&UL)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-P
M;W=E<G!O:6YT)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)VUS<&]W97)P;VEN="==6R=H86YD;&5S)UT@/2!A<G)A>2@*
M("`@("=A<'!L:6-A=&EO;B]V;F0N;7,M<&]W97)P;VEN="<L"B`@("`G87!P
M;&EC871I;VXO;7-P;W=E<G!O:6YT)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)VUS<&]W97)P;VEN="==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F
M875L="<@/3X@)VUS<&]W97)P;VEN="YP;F<G*3L*"@HO*BH*("H@=D-A<F0@
M9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=V
M8V%R9"==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+W@M=F-A<F0G
M+`H@("`@)W1E>'0O>"UV8V%L96YD87(G*3L*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG=F-A<F0G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G
M(#T^("=V8V%R9"YP;F<G*3L*"@HO*BH*("H@4E!-(&1R:79E<B!S971T:6YG
M<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<G!M)UU;)VQO8V%T:6]N
M)UT@/2`G+W5S<B]B:6XO<G!M)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M<G!M)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W)P;2==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO
M;B]X+7)P;2<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R<&TG75LG:6-O
M;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=R<&TN<&YG)RD["@H*
M+RHJ"B`J($1E8FEA;B!P86-K86=E(&1R:79E<B!S971T:6YG<PH@*B\*)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;)VQO8V%T:6]N)UT@/2`G+W5S
M<B]B:6XO9'!K9R<["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V1E8B==6R=I
M;FQI;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=D96(G
M75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G87!P;&EC871I;VXO>"UD96(G
M+`H@("`@)V%P<&QI8V%T:6]N+W@M9&5B:6%N+7!A8VMA9V4G*3L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@
M("=D969A=6QT)R`]/B`G9&5B+G!N9R<I.PH*"B\J*@H@*B!396-U<F4@;75L
M=&EP87)T<R`H4D9#(#$X-#<I"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=S96-U<FET>2==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)W-E8W5R:71Y)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)VUU;'1I<&%R="]E;F-R>7!T960G+"`G;75L=&EP87)T+W-I9VYE9"<I.PHD
M;6EM95]D<FEV97)S6R=H;W)D92==6R=S96-U<FET>2==6R=I8V]N<R==(#T@
M87)R87DH"B`@("`G9&5F875L="<@/3X@)V5N8W)Y<'1I;VXN<&YG)RD["@H*
M+RHJ"B`J($EM86=E('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D
M92==6R=I;6%G97,G75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG:6UA9V5S)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)VEM86=E+RHG*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG:6UA9V5S)UU;
M)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G:6UA9V4N<&YG
M)RD["@H*+RHJ"B`J($U3+51.148@071T86-H;65N="`H87!P;&EC871I;VXO
M;7,M=&YE9BD@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)W1N968G75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG=&YE9B==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A
M=&EO;B]M<RUT;F5F)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W1N968G
M75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=T97AT+G!N
M9R<I.PH*"B\J*@H@*B!$:6=E<W0@;65S<V%G92`H4D9#(#(P-#8@6S4N,BXQ
M72D@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)F8S@R
M,B==6R=I;FQI;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=R9F,X,C(G75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G;65S<V%G92]R
M9F,X,C(G+`H@("`@)W@M97AT96YS:6]N+V5M;"<I.PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=R9F,X,C(G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E
M9F%U;'0G(#T^("=M86EL+G!N9R<I.PH*"B\J*@H@*B!297!O<G0@;65S<V%G
M97,@*%)&0R`S-#4R*0H@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F5P
M;W)T)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG<F5P;W)T)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)VUU;'1I<&%R
M="]R97!O<G0G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F5P;W)T)UU;
M)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G;6%I;"YP;F<G
M*3L*"@HO*BH*("H@3W!E;D]F9FEC92YO<F<O4W1A<D]F9FEC92!S971T:6YG
M<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;V]O)UU;)VEN;&EN92==
M(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V]O;R==6R=H86YD
M;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YC
M86QC)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YC86QC+G1E;7!L
M871E)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YD<F%W)RP*("`@
M("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YD<F%W+G1E;7!L871E)RP*("`@
M("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YI;7!R97-S)RP*("`@("=A<'!L
M:6-A=&EO;B]V;F0N<W5N+GAM;"YI;7!R97-S+G1E;7!L871E)RP*("`@("=A
M<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YM871H)RP*("`@("=A<'!L:6-A=&EO
M;B]V;F0N<W5N+GAM;"YW<FET97(G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=6XN>&UL+G=R:71E<BYG;&]B86PG+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=6XN>&UL+G=R:71E<BYT96UP;&%T92<L"B`@("`G87!P;&EC871I;VXO=FYD
M+G-T87)D:79I<VEO;BYC86QC)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W1A
M<F1I=FES:6]N+F1R87<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV
M:7-I;VXN:6UP<F5S<R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I
M<VEO;BYM871H)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N
M+G=R:71E<B<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=O;V\G75LG:6-O
M;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=O;V]?8V%L8RYP;F<G
M+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F-A;&,G("`@("`@("`@
M("`@(#T^("=O;V]?8V%L8RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=&%R9&EV:7-I;VXN8V%L8R<@("`@("`@(#T^("=O;V]?8V%L8RYP;F<G+`H@
M("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F-A;&,N=&5M<&QA=&4G("`@
M(#T^("=O;V]?8V%L8RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN
M>&UL+F1R87<G("`@("`@("`@("`@(#T^("=O;V]?9')A=RYP;F<G+`H@("`@
M)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN9')A=R<@("`@("`@(#T^
M("=O;V]?9')A=RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL
M+F1R87<N=&5M<&QA=&4G("`@(#T^("=O;V]?9')A=RYP;F<G+`H@("`@)V%P
M<&QI8V%T:6]N+W9N9"YS=6XN>&UL+FEM<')E<W,G("`@("`@("`@(#T^("=O
M;V]?:6UP<F5S<RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV
M:7-I;VXN:6UP<F5S<R<@("`@(#T^("=O;V]?:6UP<F5S<RYP;F<G+`H@("`@
M)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+FEM<')E<W,N=&5M<&QA=&4G(#T^
M("=O;V]?:6UP<F5S<RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN
M>&UL+FUA=&@G("`@("`@("`@("`@(#T^("=O;V]?;6%T:"YP;F<G+`H@("`@
M)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN;6%T:"<@("`@("`@(#T^
M("=O;V]?;6%T:"YP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL
M+G=R:71E<B<@("`@("`@("`@(#T^("=O;V]?=W)I=&5R+G!N9R<L"B`@("`G
M87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYW<FET97(G("`@("`@/3X@
M)V]O;U]W<FET97(N<&YG)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM
M;"YW<FET97(N9VQO8F%L)R`@("`]/B`G;V]O7W=R:71E<BYP;F<G+`H@("`@
M)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYT96UP;&%T92<@(#T^
M("=O;V]?=W)I=&5R+G!N9R<I.PH*"B\J*@H@*B!0;W)T86)L92!$;V-U;65N
M="!&;W)M870@*%!$1BD@9FEL97,*("H@64]5(%-(3U5,1"!.3U0@3D]234%,
M3%D@04Q415(@5$A)4R!3151424Y'+@H@*B\*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG<&1F)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)W!D9B==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L
M:6-A=&EO;B]P9&8G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<&1F)UU;
M)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G<&1F+G!N9R<I
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O;6]T9"YP
M:'``````````````````````````````````````````````````````````
M`````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#,P`#$P-#$W,S8R-S0S`#`Q-S<T,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\(2TM(%1H:7,@9FEL92!C;VYT86EN<R!A
M;GD@(DUE<W-A9V4@3V8@5&AE($1A>2(@5'EP92!I;F9O<FUA=&EO;B`M+3X*
M/"$M+2!)="!W:6QL(&)E(&EN8VQU9&5D(&)E;&]W('1H92!L;V<M:6X@9F]R
M;2!O;B!T:&4@;&]G:6X@<&%G92X@+2T^"@H\8G(@+SX*/'1A8FQE('=I9'1H
M/2(Q,#`E(CX\='(^/'1D(&%L:6=N/2)C96YT97(B/CQI;6<@<W)C/2)T:&5M
M97,O9W)A<&AI8W,O:&]R9&4M<&]W97(Q+G!N9R(@86QT/2)0;W=E<F5D(&)Y
M($AO<F1E(B`O/CPO=&0^/"]T<CX\+W1A8FQE/@H*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+VYL<RYP:'``````````````
M````````````````````````````````````````````````````````````
M```P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,#`R-P`Q,#0Q-S,V
M,C<T,P`P,3<V,#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($Y,4R`H3F%T:6]N86P@3&%N9W5A9V4@
M4W5P<&]R="D@8V]N9FEG=7)A=&EO;B!F:6QE+@H@*@H@*B`D2&]R9&4Z(&AO
M<F1E+V-O;F9I9R]N;',N<&AP+F1I<W0L=B`Q+C4Y+C$P+C8@,C`P-B\P,B\Q
M,"`Q.#HU.#HS-"!J86X@17AP("0*("HO"@HO*BH*("HJ($1E9F%U;'1S"B`J
M*B\*"B\J(%1H92!L86YG=6%G92!T;R!F86QL(&)A8VL@;VX@:68@=V4@8V%N
M;F]T(&1E=&5R;6EN92!O;F4@86YY(&]T:&5R"B`@('=A>2`H=7-E<B!C:&]I
M8V4@;W(@<')E9F5R96YC97,I+B!)9B!E;7!T>2P@=V4@=VEL;"!T<GD@=&\@
M;F5G;W1I871E"B`@('=I=&@@=&AE(&)R;W=S97(@=7-I;F<@2%144%]!0T-%
M4%1?3$%.1U5!1T4N("HO"B1N;'-;)V1E9F%U;'1S)UU;)VQA;F=U86=E)UT@
M/2`G)SL*"@HO*BH*("HJ($QA;F=U86=E"B`J*B\*"B1N;'-;)VQA;F=U86=E
M<R==6R=A<E]/32==(#T@)T%R86)I8R`H3VUA;BD@*"8C>#`V,C<[)B-X,#8T
M-#LF(W@P-C,Y.R8C>#`V,S$[)B-X,#8R.#LF(W@P-C1A.R8C>#`V,CD[*2<[
M"B1N;'-;)VQA;F=U86=E<R==6R=A<E]362==(#T@)T%R86)I8R`H4WER:6$I
M("@F(W@P-C(W.R8C>#`V-#0[)B-X,#8S.3LF(W@P-C,Q.R8C>#`V,C@[)B-X
M,#8T83LF(W@P-C(Y.RDG.PHD;FQS6R=L86YG=6%G97,G75LG:61?240G72`]
M("="86AA<V$@26YD;VYE<VEA)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V)S7T)!
M)UT@/2`G0F]S86YS:VDG.PHD;FQS6R=L86YG=6%G97,G75LG8F=?0D<G72`]
M("="=6QG87)I86X@*"8C>#`T,3$[)B-X,#0T83LF(W@P-#-B.R8C>#`T,S,[
M)B-X,#0S,#LF(W@P-#0P.R8C>#`T-#$[)B-X,#0S83LF(W@P-#,X.RDG.PHD
M;FQS6R=L86YG=6%G97,G75LG8V%?15,G72`]("=#871A;"9A9W)A=F4[)SL*
M)&YL<ULG;&%N9W5A9V5S)UU;)WIH7T-.)UT@/2`G0VAI;F5S92`H4VEM<&QI
M9FEE9"D@*"8C>#=B.#`[)B-X-&8U,SLF(W@T93)D.R8C>#8U.#<[*2<["B1N
M;'-;)VQA;F=U86=E<R==6R=Z:%]45R==(#T@)T-H:6YE<V4@*%1R861I=&EO
M;F%L*2`H)B-X-F(V,SLF(W@Y860T.R8C>#1E,F0[)B-X-C4X-SLI)SL*)&YL
M<ULG;&%N9W5A9V5S)UU;)V-S7T-:)UT@/2`G0WIE8V@@*"8C>#`Q,&,[97-K
M>2DG.PHD;FQS6R=L86YG=6%G97,G75LG9&%?1$LG72`]("=$86YS:R<["B1N
M;'-;)VQA;F=U86=E<R==6R=D95]$12==(#T@)T1E=71S8V@G.PHD;FQS6R=L
M86YG=6%G97,G75LG96Y?55,G72`]("=%;F=L:7-H("A!;65R:6-A;BDG.PHD
M;FQS6R=L86YG=6%G97,G75LG96Y?1T(G72`]("=%;F=L:7-H("A"<FET:7-H
M*2<["B1N;'-;)VQA;F=U86=E<R==6R=E;E]#02==(#T@)T5N9VQI<V@@*$-A
M;F%D:6%N*2<["B1N;'-;)VQA;F=U86=E<R==6R=E<U]%4R==(#T@)T5S<&$F
M;G1I;&1E.V]L)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V5T7T5%)UT@/2`G165S
M=&DG.PHD;FQS6R=L86YG=6%G97,G75LG9G)?1E(G72`]("=&<F%N)F-C961I
M;#MA:7,G.PHD;FQS6R=L86YG=6%G97,G75LG9VQ?15,G72`]("='86QE9V\G
M.PHD;FQS6R=L86YG=6%G97,G75LG96Q?1U(G72`]("='<F5E:R`H)B-X,#,Y
M-3LF(W@P,V)B.R8C>#`S8F([)B-X,#-B-SLF(W@P,V)D.R8C>#`S8CD[)B-X
M,#-B83LF(W@P,V%C.RDG.PHD;FQS6R=L86YG=6%G97,G75LG:&5?24PG72`]
M("=(96)R97<@*"8C>#`U13([)B-X,#5$,3LF(W@P-44X.R8C>#`U1#D[)B-X
M,#5%03LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VES7TE3)UT@/2`G)DEA8W5T
M93MS;&5N<VMA)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VET7TE4)UT@/2`G271A
M;&EA;F\G.PHD;FQS6R=L86YG=6%G97,G75LG:F%?2E`G72`]("=*87!A;F5S
M92`H)B-X-C5E-3LF(W@V-S)C.R8C>#AA.64[*2<["B1N;'-;)VQA;F=U86=E
M<R==6R=K;5]+2"==(#T@)TMH;65R("@F(W@Q-S@Q.R8C>#$W9#([)B-X,3<Y
M.#LF(W@Q-V,R.R8C>#$W.6$[*2<["B1N;'-;)VQA;F=U86=E<R==6R=K;U]+
M4B==(#T@)TMO<F5A;B`H)B-X9#4U8SLF(WAA9#9D.R8C>&,U8C0[*2<["B1N
M;'-;)VQA;F=U86=E<R==6R=L=E],5B==(#T@)TQA='9I928C>#`Q-C$[=2<[
M"B1N;'-;)VQA;F=U86=E<R==6R=L=%],5"==(#T@)TQI971U=FDF(W@P,3<S
M.R<["B1N;'-;)VQA;F=U86=E<R==6R=M:U]-2R==(#T@)TUA8V5D;VYI86X@
M*"8C>#`T,6,[)B-X,#0S,#LF(W@P-#-A.R8C>#`T,S4[)B-X,#0S-#LF(W@P
M-#-E.R8C>#`T,V0[)B-X,#0T,3LF(W@P-#-A.R8C>#`T,S@[*2<["B1N;'-;
M)VQA;F=U86=E<R==6R=H=5](52==(#T@)TUA9WEA<B<["B1N;'-;)VQA;F=U
M86=E<R==6R=N;%].3"==(#T@)TYE9&5R;&%N9',G.PHD;FQS6R=L86YG=6%G
M97,G75LG;F)?3D\G72`]("=.;W)S:R!B;VMM)F%R:6YG.VPG.PHD;FQS6R=L
M86YG=6%G97,G75LG;FY?3D\G72`]("=.;W)S:R!N>6YO<G-K)SL*)&YL<ULG
M;&%N9W5A9V5S)UU;)V9A7TE2)UT@/2`G4&5R<VEA;B`H)B,Q-C`Q.R8C,34W
M-3LF(S$U.#4[)B,Q-3@W.R8C,38P.3LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;
M)W!L7U!,)UT@/2`G4&]L<VMI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W!T7U!4
M)UT@/2`G4&]R='5G=29E8VER8SMS)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W!T
M7T)2)UT@/2`G4&]R='5G=29E8VER8SMS($)R87-I;&5I<F\G.PHD;FQS6R=L
M86YG=6%G97,G75LG<F]?4D\G72`]("=2;VTF86-I<F,[;B9A=6UL.R<["B1N
M;'-;)VQA;F=U86=E<R==6R=R=5]252==(#T@)U)U<W-I86X@*"8C>#`T,C`[
M)B-X,#0T,SLF(W@P-#0Q.R8C>#`T-#$[)B-X,#0S83LF(W@P-#,X.R8C>#`T
M,SD[*2<["B1N;'-;)VQA;F=U86=E<R==6R=S:U]32R==(#T@)U-L;W9A:R`H
M4VQO=F5N)B-X,#$P9#MI;F$I)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W-L7U-)
M)UT@/2`G4VQO=F5N:6%N("A3;&]V96XF(W@P,38Q.R8C>#`Q,&0[:6YA*2<[
M"B1N;'-;)VQA;F=U86=E<R==6R=F:5]&22==(#T@)U-U;VUI)SL*)&YL<ULG
M;&%N9W5A9V5S)UU;)W-V7U-%)UT@/2`G4W9E;G-K82<["B1N;'-;)VQA;F=U
M86=E<R==6R=T:%]42"==(#T@)U1H86D@*"8C>#!E-#0[)B-X,&4Q-SLF(W@P
M93(R.RDG.PHD;FQS6R=L86YG=6%G97,G75LG=')?5%(G72`]("=4)G5U;6P[
M<FLF8V-E9&EL.V4G.PHD;FQS6R=L86YG=6%G97,G75LG=6M?54$G72`]("=5
M:W)A:6YI86X@*"8C>#`T,C,[)B-X,#0S83LF(W@P-#0P.R8C>#`T,S`[)B-X
M,#0U-SLF(W@P-#-D.R8C>#`T-#$[)B-X,#0T8SLF(W@P-#-A.R8C>#`T,S`[
M*2<["@H*+RHJ"B`J*B!!;&EA<V5S(&9O<B!L86YG=6%G97,@=VET:"!D:69F
M97)E;G0@8G)O=W-E<B!A;F0@9V5T=&5X="!C;V1E<PH@*BHO"@HD;FQS6R=A
M;&EA<V5S)UU;)V%R)UT@/2`G87)?4UDG.PHD;FQS6R=A;&EA<V5S)UU;)V)G
M)UT@/2`G8F=?0D<G.PHD;FQS6R=A;&EA<V5S)UU;)V)S)UT@/2`G8G-?0D$G
M.PHD;FQS6R=A;&EA<V5S)UU;)V-A)UT@/2`G8V%?15,G.PHD;FQS6R=A;&EA
M<V5S)UU;)V-S)UT@/2`G8W-?0UHG.PHD;FQS6R=A;&EA<V5S)UU;)V1A)UT@
M/2`G9&%?1$LG.PHD;FQS6R=A;&EA<V5S)UU;)V1E)UT@/2`G9&5?1$4G.PHD
M;FQS6R=A;&EA<V5S)UU;)V5L)UT@/2`G96Q?1U(G.PHD;FQS6R=A;&EA<V5S
M)UU;)V5N)UT@/2`G96Y?55,G.PHD;FQS6R=A;&EA<V5S)UU;)V5S)UT@/2`G
M97-?15,G.PHD;FQS6R=A;&EA<V5S)UU;)V5T)UT@/2`G971?144G.PHD;FQS
M6R=A;&EA<V5S)UU;)V9A)UT@/2`G9F%?25(G.PHD;FQS6R=A;&EA<V5S)UU;
M)V9I)UT@/2`G9FE?1DDG.PHD;FQS6R=A;&EA<V5S)UU;)V9R)UT@/2`G9G)?
M1E(G.PHD;FQS6R=A;&EA<V5S)UU;)V=L)UT@/2`G9VQ?15,G.PHD;FQS6R=A
M;&EA<V5S)UU;)VAE)UT@/2`G:&5?24PG.PHD;FQS6R=A;&EA<V5S)UU;)VAU
M)UT@/2`G:'5?2%4G.PHD;FQS6R=A;&EA<V5S)UU;)VED)UT@/2`G:61?240G
M.PHD;FQS6R=A;&EA<V5S)UU;)VES)UT@/2`G:7-?25,G.PHD;FQS6R=A;&EA
M<V5S)UU;)VET)UT@/2`G:71?250G.PHD;FQS6R=A;&EA<V5S)UU;)VIA)UT@
M/2`G:F%?2E`G.PHD;FQS6R=A;&EA<V5S)UU;)VMM)UT@/2`G:VU?2T@G.PHD
M;FQS6R=A;&EA<V5S)UU;)VMO)UT@/2`G:V]?2U(G.PHD;FQS6R=A;&EA<V5S
M)UU;)VQT)UT@/2`G;'1?3%0G.PHD;FQS6R=A;&EA<V5S)UU;)VQV)UT@/2`G
M;'9?3%8G.PHD;FQS6R=A;&EA<V5S)UU;)VUK)UT@/2`G;6M?34LG.PHD;FQS
M6R=A;&EA<V5S)UU;)VYL)UT@/2`G;FQ?3DPG.PHD;FQS6R=A;&EA<V5S)UU;
M)VYN)UT@/2`G;FY?3D\G.PHD;FQS6R=A;&EA<V5S)UU;)VYO)UT@/2`G;F)?
M3D\G.PHD;FQS6R=A;&EA<V5S)UU;)W!L)UT@/2`G<&Q?4$PG.PHD;FQS6R=A
M;&EA<V5S)UU;)W!T)UT@/2`G<'1?4%0G.PHD;FQS6R=A;&EA<V5S)UU;)W)O
M)UT@/2`G<F]?4D\G.PHD;FQS6R=A;&EA<V5S)UU;)W)U)UT@/2`G<G5?4E4G
M.PHD;FQS6R=A;&EA<V5S)UU;)W-K)UT@/2`G<VM?4TLG.PHD;FQS6R=A;&EA
M<V5S)UU;)W-L)UT@/2`G<VQ?4TDG.PHD;FQS6R=A;&EA<V5S)UU;)W-V)UT@
M/2`G<W9?4T4G.PHD;FQS6R=A;&EA<V5S)UU;)W1H)UT@/2`G=&A?5$@G.PHD
M;FQS6R=A;&EA<V5S)UU;)W1R)UT@/2`G=')?5%(G.PHD;FQS6R=A;&EA<V5S
M)UU;)W5K)UT@/2`G=6M?54$G.PH*"B\J*@H@*BH@0VAA<G-E=',*("HJ+PH*
M)&YL<ULG8VAA<G-E=',G75LG87)?3TTG72`]("=W:6YD;W=S+3$R-38G.PHD
M;FQS6R=C:&%R<V5T<R==6R=A<E]362==(#T@)W=I;F1O=W,M,3(U-B<["B1N
M;'-;)V-H87)S971S)UU;)V)G7T)')UT@/2`G=VEN9&]W<RTQ,C4Q)SL*)&YL
M<ULG8VAA<G-E=',G75LG8G-?0D$G72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG
M8VAA<G-E=',G75LG8W-?0UHG72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA
M<G-E=',G75LG96Q?1U(G72`]("=)4T\M.#@U.2TW)SL*)&YL<ULG8VAA<G-E
M=',G75LG9F%?25(G72`]("=55$8M."<["B1N;'-;)V-H87)S971S)UU;)VAE
M7TE,)UT@/2`G551&+3@G.PHD;FQS6R=C:&%R<V5T<R==6R=H=5](52==(#T@
M)TE33RTX.#4Y+3(G.PHD;FQS6R=C:&%R<V5T<R==6R=J85]*4"==(#T@)U-(
M24947TI)4R<["B1N;'-;)V-H87)S971S)UU;)VMM7TM()UT@/2`G551&+3@G
M.PHD;FQS6R=C:&%R<V5T<R==6R=K;U]+4B==(#T@)T550RU+4B<["B1N;'-;
M)V-H87)S971S)UU;)VQT7TQ4)UT@/2`G25-/+3@X-3DM,3,G.PHD;FQS6R=C
M:&%R<V5T<R==6R=L=E],5B==(#T@)W=I;F1O=W,M,3(U-R<["B1N;'-;)V-H
M87)S971S)UU;)VUK7TU+)UT@/2`G25-/+3@X-3DM-2<["B1N;'-;)V-H87)S
M971S)UU;)W!L7U!,)UT@/2`G25-/+3@X-3DM,B<["B1N;'-;)V-H87)S971S
M)UU;)W)U7U)5)UT@/2`G=VEN9&]W<RTQ,C4Q)SL*)&YL<ULG8VAA<G-E=',G
M75LG<G5?4E4N2T])."U2)UT@/2`G2T])."U2)SL*)&YL<ULG8VAA<G-E=',G
M75LG<VM?4TLG72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA<G-E=',G75LG
M<VQ?4TDG72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA<G-E=',G75LG=&A?
M5$@G72`]("=425,M-C(P)SL*)&YL<ULG8VAA<G-E=',G75LG=')?5%(G72`]
M("=)4T\M.#@U.2TY)SL*)&YL<ULG8VAA<G-E=',G75LG=6M?54$G72`]("=+
M3TDX+54G.PHD;FQS6R=C:&%R<V5T<R==6R=Z:%]#3B==(#T@)T=",C,Q,B<[
M"B1N;'-;)V-H87)S971S)UU;)WIH7U17)UT@/2`G0DE'-2<["@H*+RHJ"B`J
M*B!-=6QT:6)Y=&4@8VAA<G-E=',*("HJ+PH*)&YL<ULG;75L=&EB>71E)UU;
M)T))1S4G72`]('1R=64["B1N;'-;)VUU;'1I8GET92==6R=%54,M2U(G72`]
M('1R=64["B1N;'-;)VUU;'1I8GET92==6R='0C(S,3(G72`]('1R=64["B1N
M;'-;)VUU;'1I8GET92==6R=32$E&5%]*25,G72`]('1R=64["B1N;'-;)VUU
M;'1I8GET92==6R=55$8M."==(#T@=')U93L*"@HO*BH*("HJ(%)I9VAT+71O
M+6QE9G0@;&%N9W5A9V5S"B`J*B\*"B1N;'-;)W)T;"==6R=A<E]/32==(#T@
M=')U93L*)&YL<ULG<G1L)UU;)V%R7U-9)UT@/2!T<G5E.PHD;FQS6R=R=&PG
M75LG9F%?25(G72`]('1R=64["B1N;'-;)W)T;"==6R=H95])3"==(#T@=')U
M93L*"@HO*BH*("HJ(%!R969E<G)E9"!C:&%R<V5T<R!F;W(@96UA:6P@=')A
M9F9I8R!I9B!N;W0@=&AE(&QA;F=U86=E<R<@9&5F875L=`H@*BH@8VAA<G-E
M=',N"B`J*B\*"B1N;'-;)V5M86EL<R==6R=J85]*4"==(#T@)TE33RTR,#(R
M+4I0)SL*"@HO*BH*("HJ($%V86EL86)L92!C:&%R<V5T<R!F;W(@;W5T9V]I
M;F<@96UA:6P@=')A9F9I8RX*("HJ+PH*)&YL<ULG96YC;V1I;F=S)UU;)W=I
M;F1O=W,M,3(U-B==(#T@7R@B07)A8FEC("A7:6YD;W=S+3$R-38I(BD["B1N
M;'-;)V5N8V]D:6YG<R==6R=!4DU30TE)+3@G72`](%\H(D%R;65N:6%N("A!
M4DU30TE)+3@I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TQ,R==
M(#T@7R@B0F%L=&EC("A)4T\M.#@U.2TQ,RDB*3L*)&YL<ULG96YC;V1I;F=S
M)UU;)TE33RTX.#4Y+3$T)UT@/2!?*")#96QT:6,@*$E33RTX.#4Y+3$T*2(I
M.PHD;FQS6R=E;F-O9&EN9W,G75LG25-/+3@X-3DM,B==(#T@7R@B0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB*3L*)&YL<ULG96YC;V1I;F=S)UU;
M)T=",C,Q,B==(#T@7R@B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(BD[
M"B1N;'-;)V5N8V]D:6YG<R==6R="24<U)UT@/2!?*")#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG2T])."U2)UT@
M/2!?*")#>7)I;&QI8R`H2T])."U2*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG
M=VEN9&]W<RTQ,C4Q)UT@/2!?*")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(I
M.PHD;FQS6R=E;F-O9&EN9W,G75LG2T])."U5)UT@/2!?*")#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTX
M.#4Y+3<G72`](%\H(D=R965K("A)4T\M.#@U.2TW*2(I.PHD;FQS6R=E;F-O
M9&EN9W,G75LG25-/+3@X-3DM."U))UT@/2!?*")(96)R97<@*$E33RTX.#4Y
M+3@M22DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTR,#(R+4I0)UT@/2!?
M*")*87!A;F5S92`H25-/+3(P,C(M2E`I(BD["B1N;'-;)V5N8V]D:6YG<R==
M6R=%54,M2U(G72`](%\H(DMO<F5A;B`H155#+4M2*2(I.PHD;FQS6R=E;F-O
M9&EN9W,G75LG25-/+3@X-3DM,3`G72`](%\H(DYO<F1I8R`H25-/+3@X-3DM
M,3`I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TS)UT@/2!?*")3
M;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB*3L*)&YL<ULG96YC;V1I;F=S
M)UU;)U1)4RTV,C`G72`](%\H(E1H86D@*%1)4RTV,C`I(BD["B1N;'-;)V5N
M8V]D:6YG<R==6R=)4T\M.#@U.2TY)UT@/2!?*")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG551&+3@G72`](%\H(E5N:6-O
M9&4@*%541BTX*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG5DE30TE))UT@/2!?
M*")6:65T;F%M97-E("A625-#24DI(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)
M4T\M.#@U.2TQ)UT@/2!?*")797-T97)N("A)4T\M.#@U.2TQ*2(I.PHD;FQS
M6R=E;F-O9&EN9W,G75LG25-/+3@X-3DM,34G72`](%\H(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*2(I.PIA<V]R="@D;FQS6R=E;F-O9&EN9W,G72D["@H*+RHJ
M"B`J*B!-=6QT:2UL86YG=6%G92!S<&5L;&EN9R!S=7!P;W)T"B`J*B\*"B1N
M;'-;)W-P96QL:6YG)UU;)V-S7T-:)UT@/2`G+50@;&%T:6XR("UD(&-Z96-H
M)SL*)&YL<ULG<W!E;&QI;F<G75LG9&%?1$LG72`]("<M9"!D86YS:R<["B1N
M;'-;)W-P96QL:6YG)UU;)V1E7T1%)UT@/2`G+50@;&%T:6XQ("UD(&1E=71S
M8V@G.PHD;FQS6R=S<&5L;&EN9R==6R=E;%]'4B==(#T@)RU4(&QA=&EN,2`M
M9"!E;&QI;FEK82<["B1N;'-;)W-P96QL:6YG)UU;)V5N7T-!)UT@/2`G+60@
M8V%N861I86XG.PHD;FQS6R=S<&5L;&EN9R==6R=E;E]'0B==(#T@)RUD(&)R
M:71I<V@G.PHD;FQS6R=S<&5L;&EN9R==6R=E;E]54R==(#T@)RUD(&%M97)I
M8V%N)SL*)&YL<ULG<W!E;&QI;F<G75LG97-?15,G72`]("<M9"!E<W!A;F]L
M)SL*)&YL<ULG<W!E;&QI;F<G75LG9G)?1E(G72`]("<M9"!F<F%N8V%I<R<[
M"B1N;'-;)W-P96QL:6YG)UU;)VET7TE4)UT@/2`G+50@;&%T:6XQ("UD(&ET
M86QI86XG.PHD;FQS6R=S<&5L;&EN9R==6R=N;%].3"==(#T@)RUD(&YE9&5R
M;&%N9',G.PHD;FQS6R=S<&5L;&EN9R==6R=P;%]03"==(#T@)RUD('!O;&ES
M:"<["B1N;'-;)W-P96QL:6YG)UU;)W!T7T)2)UT@/2`G+60@8G(G.PHD;FQS
M6R=S<&5L;&EN9R==6R=P=%]05"==(#T@)RU4(&QA=&EN,2`M9"!P;W)T=6=U
M97-E)SL*)&YL<ULG<W!E;&QI;F<G75LG<G5?4E4G72`]("<M9"!R=7-S:6%N
M)SL*)&YL<ULG<W!E;&QI;F<G75LG<VQ?4TDG72`]("<M9"!S;&]V96YS:V\G
M.PHD;FQS6R=S<&5L;&EN9R==6R=S=E]312==(#T@)RUD('-V96YS:V$G.PH*
M)$=,3T)!3%-;)VYL<R==(#T@)B1N;',["@H*+RHJ"B`J*B!4:6UE>F]N97,*
M("HJ+PH*)'1Z6R=!9G)I8V$O06)I9&IA;B==(#T@)T%F<FEC82]!8FED:F%N
M)SL*)'1Z6R=!9G)I8V$O06-C<F$G72`]("=!9G)I8V$O06-C<F$G.PHD='I;
M)T%F<FEC82]!9&1I<U]!8F%B82==(#T@)T%F<FEC82]!9&1I<R!!8F%B82<[
M"B1T>ELG069R:6-A+T%L9VEE<G,G72`]("=!9G)I8V$O06QG:65R<R<["B1T
M>ELG069R:6-A+T%S;65R82==(#T@)T%F<FEC82]!<VUE<F$G.PHD='I;)T%F
M<FEC82]"86UA:V\G72`]("=!9G)I8V$O0F%M86MO)SL*)'1Z6R=!9G)I8V$O
M0F%N9W5I)UT@/2`G069R:6-A+T)A;F=U:2<["B1T>ELG069R:6-A+T)A;FIU
M;"==(#T@)T%F<FEC82]"86YJ=6PG.PHD='I;)T%F<FEC82]":7-S874G72`]
M("=!9G)I8V$O0FES<V%U)SL*)'1Z6R=!9G)I8V$O0FQA;G1Y<F4G72`]("=!
M9G)I8V$O0FQA;G1Y<F4G.PHD='I;)T%F<FEC82]"<F%Z>F%V:6QL92==(#T@
M)T%F<FEC82]"<F%Z>F%V:6QL92<["B1T>ELG069R:6-A+T)U:G5M8G5R82==
M(#T@)T%F<FEC82]"=6IU;6)U<F$G.PHD='I;)T%F<FEC82]#86ER;R==(#T@
M)T%F<FEC82]#86ER;R<["B1T>ELG069R:6-A+T-A<V%B;&%N8V$G72`]("=!
M9G)I8V$O0V%S86)L86YC82<["B1T>ELG069R:6-A+T-E=71A)UT@/2`G069R
M:6-A+T-E=71A)SL*)'1Z6R=!9G)I8V$O0V]N86MR>2==(#T@)T%F<FEC82]#
M;VYA:W)Y)SL*)'1Z6R=!9G)I8V$O1&%K87(G72`]("=!9G)I8V$O1&%K87(G
M.PHD='I;)T%F<FEC82]$87)?97-?4V%L86%M)UT@/2`G069R:6-A+T1A<B!E
M<R!386QA86TG.PHD='I;)T%F<FEC82]$:FEB;W5T:2==(#T@)T%F<FEC82]$
M:FEB;W5T:2<["B1T>ELG069R:6-A+T1O=6%L82==(#T@)T%F<FEC82]$;W5A
M;&$G.PHD='I;)T%F<FEC82]%;%]!86EU;B==(#T@)T%F<FEC82]%;"!!86EU
M;B<["B1T>ELG069R:6-A+T9R965T;W=N)UT@/2`G069R:6-A+T9R965T;W=N
M)SL*)'1Z6R=!9G)I8V$O1V%B;W)O;F4G72`]("=!9G)I8V$O1V%B;W)O;F4G
M.PHD='I;)T%F<FEC82](87)A<F4G72`]("=!9G)I8V$O2&%R87)E)SL*)'1Z
M6R=!9G)I8V$O2F]H86YN97-B=7)G)UT@/2`G069R:6-A+TIO:&%N;F5S8G5R
M9R<["B1T>ELG069R:6-A+TMA;7!A;&$G72`]("=!9G)I8V$O2V%M<&%L82<[
M"B1T>ELG069R:6-A+TMH87)T;W5M)UT@/2`G069R:6-A+TMH87)T;W5M)SL*
M)'1Z6R=!9G)I8V$O2VEG86QI)UT@/2`G069R:6-A+TMI9V%L:2<["B1T>ELG
M069R:6-A+TMI;G-H87-A)UT@/2`G069R:6-A+TMI;G-H87-A)SL*)'1Z6R=!
M9G)I8V$O3&%G;W,G72`]("=!9G)I8V$O3&%G;W,G.PHD='I;)T%F<FEC82],
M:6)R979I;&QE)UT@/2`G069R:6-A+TQI8G)E=FEL;&4G.PHD='I;)T%F<FEC
M82],;VUE)UT@/2`G069R:6-A+TQO;64G.PHD='I;)T%F<FEC82],=6%N9&$G
M72`]("=!9G)I8V$O3'5A;F1A)SL*)'1Z6R=!9G)I8V$O3'5B=6UB87-H:2==
M(#T@)T%F<FEC82],=6)U;6)A<VAI)SL*)'1Z6R=!9G)I8V$O3'5S86MA)UT@
M/2`G069R:6-A+TQU<V%K82<["B1T>ELG069R:6-A+TUA;&%B;R==(#T@)T%F
M<FEC82]-86QA8F\G.PHD='I;)T%F<FEC82]-87!U=&\G72`]("=!9G)I8V$O
M36%P=71O)SL*)'1Z6R=!9G)I8V$O36%S97)U)UT@/2`G069R:6-A+TUA<V5R
M=2<["B1T>ELG069R:6-A+TUB86)A;F4G72`]("=!9G)I8V$O36)A8F%N92<[
M"B1T>ELG069R:6-A+TUO9V%D:7-H=2==(#T@)T%F<FEC82]-;V=A9&ES:'4G
M.PHD='I;)T%F<FEC82]-;VYR;W9I82==(#T@)T%F<FEC82]-;VYR;W9I82<[
M"B1T>ELG069R:6-A+TYA:7)O8FDG72`]("=!9G)I8V$O3F%I<F]B:2<["B1T
M>ELG069R:6-A+TYD:F%M96YA)UT@/2`G069R:6-A+TYD:F%M96YA)SL*)'1Z
M6R=!9G)I8V$O3FEA;65Y)UT@/2`G069R:6-A+TYI86UE>2<["B1T>ELG069R
M:6-A+TYO=6%K8VAO='0G72`]("=!9G)I8V$O3F]U86MC:&]T="<["B1T>ELG
M069R:6-A+T]U86=A9&]U9V]U)UT@/2`G069R:6-A+T]U86=A9&]U9V]U)SL*
M)'1Z6R=!9G)I8V$O4&]R=&\M3F]V;R==(#T@)T%F<FEC82]0;W)T;RU.;W9O
M)SL*)'1Z6R=!9G)I8V$O4V%O7U1O;64G72`]("=!9G)I8V$O4V%O(%1O;64G
M.PHD='I;)T%F<FEC82]4:6UB=6MT=2==(#T@)T%F<FEC82]4:6UB=6MT=2<[
M"B1T>ELG069R:6-A+U1R:7!O;&DG72`]("=!9G)I8V$O5')I<&]L:2<["B1T
M>ELG069R:6-A+U1U;FES)UT@/2`G069R:6-A+U1U;FES)SL*)'1Z6R=!9G)I
M8V$O5VEN9&AO96LG72`]("=!9G)I8V$O5VEN9&AO96LG.PHD='I;)T%M97)I
M8V$O061A:R==(#T@)T%M97)I8V$O061A:R<["B1T>ELG06UE<FEC82]!;F-H
M;W)A9V4G72`]("=!;65R:6-A+T%N8VAO<F%G92<["B1T>ELG06UE<FEC82]!
M;F=U:6QL82==(#T@)T%M97)I8V$O06YG=6EL;&$G.PHD='I;)T%M97)I8V$O
M06YT:6=U82==(#T@)T%M97)I8V$O06YT:6=U82<["B1T>ELG06UE<FEC82]!
M<F%G=6%I;F$G72`]("=!;65R:6-A+T%R86=U86EN82<["B1T>ELG06UE<FEC
M82]!<G5B82==(#T@)T%M97)I8V$O07)U8F$G.PHD='I;)T%M97)I8V$O07-U
M;F-I;VXG72`]("=!;65R:6-A+T%S=6YC:6]N)SL*)'1Z6R=!;65R:6-A+T)A
M<F)A9&]S)UT@/2`G06UE<FEC82]"87)B861O<R<["B1T>ELG06UE<FEC82]"
M96QE;2==(#T@)T%M97)I8V$O0F5L96TG.PHD='I;)T%M97)I8V$O0F5L:7IE
M)UT@/2`G06UE<FEC82]"96QI>F4G.PHD='I;)T%M97)I8V$O0F]A7U9I<W1A
M)UT@/2`G06UE<FEC82]";V$@5FES=&$G.PHD='I;)T%M97)I8V$O0F]G;W1A
M)UT@/2`G06UE<FEC82]";V=O=&$G.PHD='I;)T%M97)I8V$O0F]I<V4G72`]
M("=!;65R:6-A+T)O:7-E)SL*)'1Z6R=!;65R:6-A+T)U96YO<U]!:7)E<R==
M(#T@)T%M97)I8V$O0G5E;F]S($%I<F5S)SL*)'1Z6R=!;65R:6-A+T-A;6)R
M:61G95]"87DG72`]("=!;65R:6-A+T-A;6)R:61G92!"87DG.PHD='I;)T%M
M97)I8V$O0V%N8W5N)UT@/2`G06UE<FEC82]#86YC=6XG.PHD='I;)T%M97)I
M8V$O0V%R86-A<R==(#T@)T%M97)I8V$O0V%R86-A<R<["B1T>ELG06UE<FEC
M82]#871A;6%R8V$G72`]("=!;65R:6-A+T-A=&%M87)C82<["B1T>ELG06UE
M<FEC82]#87EE;FYE)UT@/2`G06UE<FEC82]#87EE;FYE)SL*)'1Z6R=!;65R
M:6-A+T-A>6UA;B==(#T@)T%M97)I8V$O0V%Y;6%N)SL*)'1Z6R=!;65R:6-A
M+T-H:6-A9V\G72`]("=!;65R:6-A+T-H:6-A9V\G.PHD='I;)T%M97)I8V$O
M0VAI:'5A:'5A)UT@/2`G06UE<FEC82]#:&EH=6%H=6$G.PHD='I;)T%M97)I
M8V$O0V]R9&]B82==(#T@)T%M97)I8V$O0V]R9&]B82<["B1T>ELG06UE<FEC
M82]#;W-T85]2:6-A)UT@/2`G06UE<FEC82]#;W-T82!2:6-A)SL*)'1Z6R=!
M;65R:6-A+T-U:6%B82==(#T@)T%M97)I8V$O0W5I86)A)SL*)'1Z6R=!;65R
M:6-A+T-U<F%C86\G72`]("=!;65R:6-A+T-U<F%C86\G.PHD='I;)T%M97)I
M8V$O1&%W<V]N)UT@/2`G06UE<FEC82]$87=S;VXG.PHD='I;)T%M97)I8V$O
M1&%W<V]N7T-R965K)UT@/2`G06UE<FEC82]$87=S;VX@0W)E96LG.PHD='I;
M)T%M97)I8V$O1&5N=F5R)UT@/2`G06UE<FEC82]$96YV97(G.PHD='I;)T%M
M97)I8V$O1&5T<F]I="==(#T@)T%M97)I8V$O1&5T<F]I="<["B1T>ELG06UE
M<FEC82]$;VUI;FEC82==(#T@)T%M97)I8V$O1&]M:6YI8V$G.PHD='I;)T%M
M97)I8V$O161M;VYT;VXG72`]("=!;65R:6-A+T5D;6]N=&]N)SL*)'1Z6R=!
M;65R:6-A+T5I<G5N97!E)UT@/2`G06UE<FEC82]%:7)U;F5P92<["B1T>ELG
M06UE<FEC82]%;%]386QV861O<B==(#T@)T%M97)I8V$O16P@4V%L=F%D;W(G
M.PHD='I;)T%M97)I8V$O1F]R=&%L97IA)UT@/2`G06UE<FEC82]&;W)T86QE
M>F$G.PHD='I;)T%M97)I8V$O1VQA8V5?0F%Y)UT@/2`G06UE<FEC82]';&%C
M92!"87DG.PHD='I;)T%M97)I8V$O1V]D=&AA8B==(#T@)T%M97)I8V$O1V]D
M=&AA8B<["B1T>ELG06UE<FEC82]';V]S95]"87DG72`]("=!;65R:6-A+T=O
M;W-E($)A>2<["B1T>ELG06UE<FEC82]'<F%N9%]4=7)K)UT@/2`G06UE<FEC
M82]'<F%N9"!4=7)K)SL*)'1Z6R=!;65R:6-A+T=R96YA9&$G72`]("=!;65R
M:6-A+T=R96YA9&$G.PHD='I;)T%M97)I8V$O1W5A9&5L;W5P92==(#T@)T%M
M97)I8V$O1W5A9&5L;W5P92<["B1T>ELG06UE<FEC82]'=6%T96UA;&$G72`]
M("=!;65R:6-A+T=U871E;6%L82<["B1T>ELG06UE<FEC82]'=6%Y87%U:6PG
M72`]("=!;65R:6-A+T=U87EA<75I;"<["B1T>ELG06UE<FEC82]'=7EA;F$G
M72`]("=!;65R:6-A+T=U>6%N82<["B1T>ELG06UE<FEC82](86QI9F%X)UT@
M/2`G06UE<FEC82](86QI9F%X)SL*)'1Z6R=!;65R:6-A+TAA=F%N82==(#T@
M)T%M97)I8V$O2&%V86YA)SL*)'1Z6R=!;65R:6-A+TAE<FUO<VEL;&\G72`]
M("=!;65R:6-A+TAE<FUO<VEL;&\G.PHD='I;)T%M97)I8V$O26YD:6%N82]+
M;F]X)UT@/2`G06UE<FEC82]);F1I86YA+TMN;W@G.PHD='I;)T%M97)I8V$O
M26YD:6%N82]-87)E;F=O)UT@/2`G06UE<FEC82]);F1I86YA+TUA<F5N9V\G
M.PHD='I;)T%M97)I8V$O26YD:6%N82]6979A>2==(#T@)T%M97)I8V$O26YD
M:6%N82]6979A>2<["B1T>ELG06UE<FEC82]);F1I86YA<&]L:7,G72`]("=!
M;65R:6-A+TEN9&EA;F%P;VQI<R<["B1T>ELG06UE<FEC82]);G5V:6LG72`]
M("=!;65R:6-A+TEN=79I:R<["B1T>ELG06UE<FEC82])<6%L=6ET)UT@/2`G
M06UE<FEC82])<6%L=6ET)SL*)'1Z6R=!;65R:6-A+TIA;6%I8V$G72`]("=!
M;65R:6-A+TIA;6%I8V$G.PHD='I;)T%M97)I8V$O2G5J=7DG72`]("=!;65R
M:6-A+TIU:G5Y)SL*)'1Z6R=!;65R:6-A+TIU;F5A=2==(#T@)T%M97)I8V$O
M2G5N96%U)SL*)'1Z6R=!;65R:6-A+TME;G1U8VMY+TUO;G1I8V5L;&\G72`]
M("=!;65R:6-A+TME;G1U8VMY+TUO;G1I8V5L;&\G.PHD='I;)T%M97)I8V$O
M3&%?4&%Z)UT@/2`G06UE<FEC82],82!087HG.PHD='I;)T%M97)I8V$O3&EM
M82==(#T@)T%M97)I8V$O3&EM82<["B1T>ELG06UE<FEC82],;W-?06YG96QE
M<R==(#T@)T%M97)I8V$O3&]S($%N9V5L97,G.PHD='I;)T%M97)I8V$O3&]U
M:7-V:6QL92==(#T@)T%M97)I8V$O3&]U:7-V:6QL92<["B1T>ELG06UE<FEC
M82]-86-E:6\G72`]("=!;65R:6-A+TUA8V5I;R<["B1T>ELG06UE<FEC82]-
M86YA9W5A)UT@/2`G06UE<FEC82]-86YA9W5A)SL*)'1Z6R=!;65R:6-A+TUA
M;F%U<R==(#T@)T%M97)I8V$O36%N875S)SL*)'1Z6R=!;65R:6-A+TUA<G1I
M;FEQ=64G72`]("=!;65R:6-A+TUA<G1I;FEQ=64G.PHD='I;)T%M97)I8V$O
M36%Z871L86XG72`]("=!;65R:6-A+TUA>F%T;&%N)SL*)'1Z6R=!;65R:6-A
M+TUE;F1O>B==(#T@)T%M97)I8V$O365N9&]Z)SL*)'1Z6R=!;65R:6-A+TUE
M;F]M:6YE92==(#T@)T%M97)I8V$O365N;VUI;F5E)SL*)'1Z6R=!;65R:6-A
M+TUE<FED82==(#T@)T%M97)I8V$O365R:61A)SL*)'1Z6R=!;65R:6-A+TUE
M>&EC;U]#:71Y)UT@/2`G06UE<FEC82]-97AI8V\@0VET>2<["B1T>ELG06UE
M<FEC82]-:7%U96QO;B==(#T@)T%M97)I8V$O36EQ=65L;VXG.PHD='I;)T%M
M97)I8V$O36]N=&5R<F5Y)UT@/2`G06UE<FEC82]-;VYT97)R97DG.PHD='I;
M)T%M97)I8V$O36]N=&5V:61E;R==(#T@)T%M97)I8V$O36]N=&5V:61E;R<[
M"B1T>ELG06UE<FEC82]-;VYT<F5A;"==(#T@)T%M97)I8V$O36]N=')E86PG
M.PHD='I;)T%M97)I8V$O36]N='-E<G)A="==(#T@)T%M97)I8V$O36]N='-E
M<G)A="<["B1T>ELG06UE<FEC82].87-S874G72`]("=!;65R:6-A+TYA<W-A
M=2<["B1T>ELG06UE<FEC82].97=?66]R:R==(#T@)T%M97)I8V$O3F5W(%EO
M<FLG.PHD='I;)T%M97)I8V$O3FEP:6=O;B==(#T@)T%M97)I8V$O3FEP:6=O
M;B<["B1T>ELG06UE<FEC82].;VUE)UT@/2`G06UE<FEC82].;VUE)SL*)'1Z
M6R=!;65R:6-A+TYO<F]N:&$G72`]("=!;65R:6-A+TYO<F]N:&$G.PHD='I;
M)T%M97)I8V$O4&%N86UA)UT@/2`G06UE<FEC82]086YA;6$G.PHD='I;)T%M
M97)I8V$O4&%N9VYI<G1U;F<G72`]("=!;65R:6-A+U!A;F=N:7)T=6YG)SL*
M)'1Z6R=!;65R:6-A+U!A<F%M87)I8F\G72`]("=!;65R:6-A+U!A<F%M87)I
M8F\G.PHD='I;)T%M97)I8V$O4&AO96YI>"==(#T@)T%M97)I8V$O4&AO96YI
M>"<["B1T>ELG06UE<FEC82]0;W)T+6%U+5!R:6YC92==(#T@)T%M97)I8V$O
M4&]R="UA=2U0<FEN8V4G.PHD='I;)T%M97)I8V$O4&]R=&]?5F5L:&\G72`]
M("=!;65R:6-A+U!O<G1O(%9E;&AO)SL*)'1Z6R=!;65R:6-A+U!O<G1?;V9?
M4W!A:6XG72`]("=!;65R:6-A+U!O<G0@;V8@4W!A:6XG.PHD='I;)T%M97)I
M8V$O4'5E<G1O7U)I8V\G72`]("=!;65R:6-A+U!U97)T;R!2:6-O)SL*)'1Z
M6R=!;65R:6-A+U)A:6YY7U)I=F5R)UT@/2`G06UE<FEC82]286EN>2!2:79E
M<B<["B1T>ELG06UE<FEC82]286YK:6Y?26YL970G72`]("=!;65R:6-A+U)A
M;FMI;B!);FQE="<["B1T>ELG06UE<FEC82]296-I9F4G72`]("=!;65R:6-A
M+U)E8VEF92<["B1T>ELG06UE<FEC82]296=I;F$G72`]("=!;65R:6-A+U)E
M9VEN82<["B1T>ELG06UE<FEC82]2:6]?0G)A;F-O)UT@/2`G06UE<FEC82]2
M:6\@0G)A;F-O)SL*)'1Z6R=!;65R:6-A+U)O<V%R:6\G72`]("=!;65R:6-A
M+U)O<V%R:6\G.PHD='I;)T%M97)I8V$O4V%N=&EA9V\G72`]("=!;65R:6-A
M+U-A;G1I86=O)SL*)'1Z6R=!;65R:6-A+U-A;G1O7T1O;6EN9V\G72`]("=!
M;65R:6-A+U-A;G1O($1O;6EN9V\G.PHD='I;)T%M97)I8V$O4V%O7U!A=6QO
M)UT@/2`G06UE<FEC82]386\@4&%U;&\G.PHD='I;)T%M97)I8V$O4V-O<F5S
M8GES=6YD)UT@/2`G06UE<FEC82]38V]R97-B>7-U;F0G.PHD='I;)T%M97)I
M8V$O4VAI<')O8VLG72`]("=!;65R:6-A+U-H:7!R;V-K)SL*)'1Z6R=!;65R
M:6-A+U-T7TIO:&YS)UT@/2`G06UE<FEC82]3="!*;VAN<R<["B1T>ELG06UE
M<FEC82]3=%]+:71T<R==(#T@)T%M97)I8V$O4W0@2VET=',G.PHD='I;)T%M
M97)I8V$O4W1?3'5C:6$G72`]("=!;65R:6-A+U-T($QU8VEA)SL*)'1Z6R=!
M;65R:6-A+U-T7U1H;VUA<R==(#T@)T%M97)I8V$O4W0@5&AO;6%S)SL*)'1Z
M6R=!;65R:6-A+U-T7U9I;F-E;G0G72`]("=!;65R:6-A+U-T(%9I;F-E;G0G
M.PHD='I;)T%M97)I8V$O4W=I9G1?0W5R<F5N="==(#T@)T%M97)I8V$O4W=I
M9G0@0W5R<F5N="<["B1T>ELG06UE<FEC82]496=U8VEG86QP82==(#T@)T%M
M97)I8V$O5&5G=6-I9V%L<&$G.PHD='I;)T%M97)I8V$O5&AU;&4G72`]("=!
M;65R:6-A+U1H=6QE)SL*)'1Z6R=!;65R:6-A+U1H=6YD97)?0F%Y)UT@/2`G
M06UE<FEC82]4:'5N9&5R($)A>2<["B1T>ELG06UE<FEC82]4:6IU86YA)UT@
M/2`G06UE<FEC82]4:6IU86YA)SL*)'1Z6R=!;65R:6-A+U1O<G1O;&$G72`]
M("=!;65R:6-A+U1O<G1O;&$G.PHD='I;)T%M97)I8V$O5F%N8V]U=F5R)UT@
M/2`G06UE<FEC82]686YC;W5V97(G.PHD='I;)T%M97)I8V$O5VAI=&5H;W)S
M92==(#T@)T%M97)I8V$O5VAI=&5H;W)S92<["B1T>ELG06UE<FEC82]7:6YN
M:7!E9R==(#T@)T%M97)I8V$O5VEN;FEP96<G.PHD='I;)T%M97)I8V$O66%K
M=71A="==(#T@)T%M97)I8V$O66%K=71A="<["B1T>ELG06UE<FEC82]996QL
M;W=K;FEF92==(#T@)T%M97)I8V$O665L;&]W:VYI9F4G.PHD='I;)T%N=&%R
M8W1I8V$O0V%S97DG72`]("=!;G1A<F-T:6-A+T-A<V5Y)SL*)'1Z6R=!;G1A
M<F-T:6-A+T1A=FES)UT@/2`G06YT87)C=&EC82]$879I<R<["B1T>ELG06YT
M87)C=&EC82]$=6UO;G1$57)V:6QL92==(#T@)T%N=&%R8W1I8V$O1'5M;VYT
M1%5R=FEL;&4G.PHD='I;)T%N=&%R8W1I8V$O36%W<V]N)UT@/2`G06YT87)C
M=&EC82]-87=S;VXG.PHD='I;)T%N=&%R8W1I8V$O36--=7)D;R==(#T@)T%N
M=&%R8W1I8V$O36--=7)D;R<["B1T>ELG06YT87)C=&EC82]086QM97(G72`]
M("=!;G1A<F-T:6-A+U!A;&UE<B<["B1T>ELG06YT87)C=&EC82]3;W5T:%]0
M;VQE)UT@/2`G06YT87)C=&EC82]3;W5T:"!0;VQE)SL*)'1Z6R=!;G1A<F-T
M:6-A+U-Y;W=A)UT@/2`G06YT87)C=&EC82]3>6]W82<["B1T>ELG06YT87)C
M=&EC82]6;W-T;VLG72`]("=!;G1A<F-T:6-A+U9O<W1O:R<["B1T>ELG07)C
M=&EC+TQO;F=Y96%R8GEE;B==(#T@)T%R8W1I8R],;VYG>65A<F)Y96XG.PHD
M='I;)T%S:6$O061E;B==(#T@)T%S:6$O061E;B<["B1T>ELG07-I82]!;&UA
M='DG72`]("=!<VEA+T%L;6%T>2<["B1T>ELG07-I82]!;6UA;B==(#T@)T%S
M:6$O06UM86XG.PHD='I;)T%S:6$O06YA9'ER)UT@/2`G07-I82]!;F%D>7(G
M.PHD='I;)T%S:6$O07%T874G72`]("=!<VEA+T%Q=&%U)SL*)'1Z6R=!<VEA
M+T%Q=&]B92==(#T@)T%S:6$O07%T;V)E)SL*)'1Z6R=!<VEA+T%S:&=A8F%T
M)UT@/2`G07-I82]!<VAG86)A="<["B1T>ELG07-I82]"86=H9&%D)UT@/2`G
M07-I82]"86=H9&%D)SL*)'1Z6R=!<VEA+T)A:')A:6XG72`]("=!<VEA+T)A
M:')A:6XG.PHD='I;)T%S:6$O0F%K=2==(#T@)T%S:6$O0F%K=2<["B1T>ELG
M07-I82]"86YG:V]K)UT@/2`G07-I82]"86YG:V]K)SL*)'1Z6R=!<VEA+T)E
M:7)U="==(#T@)T%S:6$O0F5I<G5T)SL*)'1Z6R=!<VEA+T)I<VAK96LG72`]
M("=!<VEA+T)I<VAK96LG.PHD='I;)T%S:6$O0G)U;F5I)UT@/2`G07-I82]"
M<G5N96DG.PHD='I;)T%S:6$O0V%L8W5T=&$G72`]("=!<VEA+T-A;&-U='1A
M)SL*)'1Z6R=!<VEA+T-H=6YG:VEN9R==(#T@)T%S:6$O0VAU;F=K:6YG)SL*
M)'1Z6R=!<VEA+T-O;&]M8F\G72`]("=!<VEA+T-O;&]M8F\G.PHD='I;)T%S
M:6$O1&%M87-C=7,G72`]("=!<VEA+T1A;6%S8W5S)SL*)'1Z6R=!<VEA+T1H
M86MA)UT@/2`G07-I82]$:&%K82<["B1T>ELG07-I82]$:6QI)UT@/2`G07-I
M82]$:6QI)SL*)'1Z6R=!<VEA+T1U8F%I)UT@/2`G07-I82]$=6)A:2<["B1T
M>ELG07-I82]$=7-H86YB92==(#T@)T%S:6$O1'5S:&%N8F4G.PHD='I;)T%S
M:6$O1V%Z82==(#T@)T%S:6$O1V%Z82<["B1T>ELG07-I82](87)B:6XG72`]
M("=!<VEA+TAA<F)I;B<["B1T>ELG07-I82](;VYG7TMO;F<G72`]("=!<VEA
M+TAO;F<@2V]N9R<["B1T>ELG07-I82](;W9D)UT@/2`G07-I82](;W9D)SL*
M)'1Z6R=!<VEA+TER:W5T<VLG72`]("=!<VEA+TER:W5T<VLG.PHD='I;)T%S
M:6$O2F%K87)T82==(#T@)T%S:6$O2F%K87)T82<["B1T>ELG07-I82]*87EA
M<'5R82==(#T@)T%S:6$O2F%Y87!U<F$G.PHD='I;)T%S:6$O2F5R=7-A;&5M
M)UT@/2`G07-I82]*97)U<V%L96TG.PHD='I;)T%S:6$O2V%B=6PG72`]("=!
M<VEA+TMA8G5L)SL*)'1Z6R=!<VEA+TMA;6-H871K82==(#T@)T%S:6$O2V%M
M8VAA=&MA)SL*)'1Z6R=!<VEA+TMA<F%C:&DG72`]("=!<VEA+TMA<F%C:&DG
M.PHD='I;)T%S:6$O2V%S:&=A<B==(#T@)T%S:6$O2V%S:&=A<B<["B1T>ELG
M07-I82]+871M86YD=2==(#T@)T%S:6$O2V%T;6%N9'4G.PHD='I;)T%S:6$O
M2W)A<VYO>6%R<VLG72`]("=!<VEA+TMR87-N;WEA<G-K)SL*)'1Z6R=!<VEA
M+TMU86QA7TQU;7!U<B==(#T@)T%S:6$O2W5A;&$@3'5M<'5R)SL*)'1Z6R=!
M<VEA+TMU8VAI;F<G72`]("=!<VEA+TMU8VAI;F<G.PHD='I;)T%S:6$O2W5W
M86ET)UT@/2`G07-I82]+=7=A:70G.PHD='I;)T%S:6$O36%C86\G72`]("=!
M<VEA+TUA8V%O)SL*)'1Z6R=!<VEA+TUA9V%D86XG72`]("=!<VEA+TUA9V%D
M86XG.PHD='I;)T%S:6$O36%N:6QA)UT@/2`G07-I82]-86YI;&$G.PHD='I;
M)T%S:6$O375S8V%T)UT@/2`G07-I82]-=7-C870G.PHD='I;)T%S:6$O3FEC
M;W-I82==(#T@)T%S:6$O3FEC;W-I82<["B1T>ELG07-I82].;W9O<VEB:7)S
M:R==(#T@)T%S:6$O3F]V;W-I8FER<VLG.PHD='I;)T%S:6$O3VUS:R==(#T@
M)T%S:6$O3VUS:R<["B1T>ELG07-I82]0:&YO;5]096YH)UT@/2`G07-I82]0
M:&YO;2!096YH)SL*)'1Z6R=!<VEA+U!Y;VYG>6%N9R==(#T@)T%S:6$O4'EO
M;F=Y86YG)SL*)'1Z6R=!<VEA+U%A=&%R)UT@/2`G07-I82]1871A<B<["B1T
M>ELG07-I82]286YG;V]N)UT@/2`G07-I82]286YG;V]N)SL*)'1Z6R=!<VEA
M+U)I>6%D:"==(#T@)T%S:6$O4FEY861H)SL*)'1Z6R=!<VEA+U-A:6=O;B==
M(#T@)T%S:6$O4V%I9V]N)SL*)'1Z6R=!<VEA+U-A;6%R:V%N9"==(#T@)T%S
M:6$O4V%M87)K86YD)SL*)'1Z6R=!<VEA+U-E;W5L)UT@/2`G07-I82]396]U
M;"<["B1T>ELG07-I82]3:&%N9VAA:2==(#T@)T%S:6$O4VAA;F=H86DG.PHD
M='I;)T%S:6$O4VEN9V%P;W)E)UT@/2`G07-I82]3:6YG87!O<F4G.PHD='I;
M)T%S:6$O5&%I<&5I)UT@/2`G07-I82]486EP96DG.PHD='I;)T%S:6$O5&%S
M:&ME;G0G72`]("=!<VEA+U1A<VAK96YT)SL*)'1Z6R=!<VEA+U1B:6QI<VDG
M72`]("=!<VEA+U1B:6QI<VDG.PHD='I;)T%S:6$O5&5H<F%N)UT@/2`G07-I
M82]496AR86XG.PHD='I;)T%S:6$O5&AI;7!H=2==(#T@)T%S:6$O5&AI;7!H
M=2<["B1T>ELG07-I82]4;VMY;R==(#T@)T%S:6$O5&]K>6\G.PHD='I;)T%S
M:6$O56IU;F=?4&%N9&%N9R==(#T@)T%S:6$O56IU;F<@4&%N9&%N9R<["B1T
M>ELG07-I82]5;&%A;F)A871A<B==(#T@)T%S:6$O56QA86YB86%T87(G.PHD
M='I;)T%S:6$O57)U;7%I)UT@/2`G07-I82]5<G5M<6DG.PHD='I;)T%S:6$O
M5FEE;G1I86YE)UT@/2`G07-I82]6:65N=&EA;F4G.PHD='I;)T%S:6$O5FQA
M9&EV;W-T;VLG72`]("=!<VEA+U9L861I=F]S=&]K)SL*)'1Z6R=!<VEA+UEA
M:W5T<VLG72`]("=!<VEA+UEA:W5T<VLG.PHD='I;)T%S:6$O665K871E<FEN
M8G5R9R==(#T@)T%S:6$O665K871E<FEN8G5R9R<["B1T>ELG07-I82]997)E
M=F%N)UT@/2`G07-I82]997)E=F%N)SL*)'1Z6R=!=&QA;G1I8R]!>F]R97,G
M72`]("=!=&QA;G1I8R]!>F]R97,G.PHD='I;)T%T;&%N=&EC+T)E<FUU9&$G
M72`]("=!=&QA;G1I8R]"97)M=61A)SL*)'1Z6R=!=&QA;G1I8R]#86YA<GDG
M72`]("=!=&QA;G1I8R]#86YA<GDG.PHD='I;)T%T;&%N=&EC+T-A<&5?5F5R
M9&4G72`]("=!=&QA;G1I8R]#87!E(%9E<F1E)SL*)'1Z6R=!=&QA;G1I8R]&
M865R;V4G72`]("=!=&QA;G1I8R]&865R;V4G.PHD='I;)T%T;&%N=&EC+TIA
M;E]-87EE;B==(#T@)T%T;&%N=&EC+TIA;B!-87EE;B<["B1T>ELG071L86YT
M:6,O36%D96ER82==(#T@)T%T;&%N=&EC+TUA9&5I<F$G.PHD='I;)T%T;&%N
M=&EC+U)E>6MJ879I:R==(#T@)T%T;&%N=&EC+U)E>6MJ879I:R<["B1T>ELG
M071L86YT:6,O4V]U=&A?1V5O<F=I82==(#T@)T%T;&%N=&EC+U-O=71H($=E
M;W)G:6$G.PHD='I;)T%T;&%N=&EC+U-T86YL97DG72`]("=!=&QA;G1I8R]3
M=&%N;&5Y)SL*)'1Z6R=!=&QA;G1I8R]3=%](96QE;F$G72`]("=!=&QA;G1I
M8R]3="!(96QE;F$G.PHD='I;)T%U<W1R86QI82]!9&5L86ED92==(#T@)T%U
M<W1R86QI82]!9&5L86ED92<["B1T>ELG075S=')A;&EA+T)R:7-B86YE)UT@
M/2`G075S=')A;&EA+T)R:7-B86YE)SL*)'1Z6R=!=7-T<F%L:6$O0G)O:V5N
M7TAI;&PG72`]("=!=7-T<F%L:6$O0G)O:V5N($AI;&PG.PHD='I;)T%U<W1R
M86QI82]$87)W:6XG72`]("=!=7-T<F%L:6$O1&%R=VEN)SL*)'1Z6R=!=7-T
M<F%L:6$O2&]B87)T)UT@/2`G075S=')A;&EA+TAO8F%R="<["B1T>ELG075S
M=')A;&EA+TQI;F1E;6%N)UT@/2`G075S=')A;&EA+TQI;F1E;6%N)SL*)'1Z
M6R=!=7-T<F%L:6$O3&]R9%](;W=E)UT@/2`G075S=')A;&EA+TQO<F0@2&]W
M92<["B1T>ELG075S=')A;&EA+TUE;&)O=7)N92==(#T@)T%U<W1R86QI82]-
M96QB;W5R;F4G.PHD='I;)T%U<W1R86QI82]097)T:"==(#T@)T%U<W1R86QI
M82]097)T:"<["B1T>ELG075S=')A;&EA+U-Y9&YE>2==(#T@)T%U<W1R86QI
M82]3>61N97DG.PHD='I;)T5U<F]P92]!;7-T97)D86TG72`]("=%=7)O<&4O
M06US=&5R9&%M)SL*)'1Z6R=%=7)O<&4O06YD;W)R82==(#T@)T5U<F]P92]!
M;F1O<G)A)SL*)'1Z6R=%=7)O<&4O071H96YS)UT@/2`G175R;W!E+T%T:&5N
M<R<["B1T>ELG175R;W!E+T)E;&9A<W0G72`]("=%=7)O<&4O0F5L9F%S="<[
M"B1T>ELG175R;W!E+T)E;&=R861E)UT@/2`G175R;W!E+T)E;&=R861E)SL*
M)'1Z6R=%=7)O<&4O0F5R;&EN)UT@/2`G175R;W!E+T)E<FQI;B<["B1T>ELG
M175R;W!E+T)R871I<VQA=F$G72`]("=%=7)O<&4O0G)A=&ES;&%V82<["B1T
M>ELG175R;W!E+T)R=7-S96QS)UT@/2`G175R;W!E+T)R=7-S96QS)SL*)'1Z
M6R=%=7)O<&4O0G5C:&%R97-T)UT@/2`G175R;W!E+T)U8VAA<F5S="<["B1T
M>ELG175R;W!E+T)U9&%P97-T)UT@/2`G175R;W!E+T)U9&%P97-T)SL*)'1Z
M6R=%=7)O<&4O0VAI<VEN874G72`]("=%=7)O<&4O0VAI<VEN874G.PHD='I;
M)T5U<F]P92]#;W!E;FAA9V5N)UT@/2`G175R;W!E+T-O<&5N:&%G96XG.PHD
M='I;)T5U<F]P92]$=6)L:6XG72`]("=%=7)O<&4O1'5B;&EN)SL*)'1Z6R=%
M=7)O<&4O1VEB<F%L=&%R)UT@/2`G175R;W!E+T=I8G)A;'1A<B<["B1T>ELG
M175R;W!E+TAE;'-I;FMI)UT@/2`G175R;W!E+TAE;'-I;FMI)SL*)'1Z6R=%
M=7)O<&4O27-T86YB=6PG72`]("=%=7)O<&4O27-T86YB=6PG.PHD='I;)T5U
M<F]P92]+86QI;FEN9W)A9"==(#T@)T5U<F]P92]+86QI;FEN9W)A9"<["B1T
M>ELG175R;W!E+TMI978G72`]("=%=7)O<&4O2VEE=B<["B1T>ELG175R;W!E
M+TQI<V)O;B==(#T@)T5U<F]P92],:7-B;VXG.PHD='I;)T5U<F]P92],:G5B
M;&IA;F$G72`]("=%=7)O<&4O3&IU8FQJ86YA)SL*)'1Z6R=%=7)O<&4O3&]N
M9&]N)UT@/2`G175R;W!E+TQO;F1O;B<["B1T>ELG175R;W!E+TQU>&5M8F]U
M<F<G72`]("=%=7)O<&4O3'5X96UB;W5R9R<["B1T>ELG175R;W!E+TUA9')I
M9"==(#T@)T5U<F]P92]-861R:60G.PHD='I;)T5U<F]P92]-86QT82==(#T@
M)T5U<F]P92]-86QT82<["B1T>ELG175R;W!E+TUI;G-K)UT@/2`G175R;W!E
M+TUI;G-K)SL*)'1Z6R=%=7)O<&4O36]N86-O)UT@/2`G175R;W!E+TUO;F%C
M;R<["B1T>ELG175R;W!E+TUO<V-O=R==(#T@)T5U<F]P92]-;W-C;W<G.PHD
M='I;)T5U<F]P92]/<VQO)UT@/2`G175R;W!E+T]S;&\G.PHD='I;)T5U<F]P
M92]087)I<R==(#T@)T5U<F]P92]087)I<R<["B1T>ELG175R;W!E+U!R86=U
M92==(#T@)T5U<F]P92]0<F%G=64G.PHD='I;)T5U<F]P92]2:6=A)UT@/2`G
M175R;W!E+U)I9V$G.PHD='I;)T5U<F]P92]2;VUE)UT@/2`G175R;W!E+U)O
M;64G.PHD='I;)T5U<F]P92]386UA<F$G72`]("=%=7)O<&4O4V%M87)A)SL*
M)'1Z6R=%=7)O<&4O4V%N7TUA<FEN;R==(#T@)T5U<F]P92]386X@36%R:6YO
M)SL*)'1Z6R=%=7)O<&4O4V%R86IE=F\G72`]("=%=7)O<&4O4V%R86IE=F\G
M.PHD='I;)T5U<F]P92]3:6UF97)O<&]L)UT@/2`G175R;W!E+U-I;69E<F]P
M;VPG.PHD='I;)T5U<F]P92]3:V]P:F4G72`]("=%=7)O<&4O4VMO<&IE)SL*
M)'1Z6R=%=7)O<&4O4V]F:6$G72`]("=%=7)O<&4O4V]F:6$G.PHD='I;)T5U
M<F]P92]3=&]C:VAO;&TG72`]("=%=7)O<&4O4W1O8VMH;VQM)SL*)'1Z6R=%
M=7)O<&4O5&%L;&EN;B==(#T@)T5U<F]P92]486QL:6YN)SL*)'1Z6R=%=7)O
M<&4O5&ER86YE)UT@/2`G175R;W!E+U1I<F%N92<["B1T>ELG175R;W!E+U5Z
M:&=O<F]D)UT@/2`G175R;W!E+U5Z:&=O<F]D)SL*)'1Z6R=%=7)O<&4O5F%D
M=7HG72`]("=%=7)O<&4O5F%D=7HG.PHD='I;)T5U<F]P92]6871I8V%N)UT@
M/2`G175R;W!E+U9A=&EC86XG.PHD='I;)T5U<F]P92]6:65N;F$G72`]("=%
M=7)O<&4O5FEE;FYA)SL*)'1Z6R=%=7)O<&4O5FEL;FEU<R==(#T@)T5U<F]P
M92]6:6QN:75S)SL*)'1Z6R=%=7)O<&4O5V%R<V%W)UT@/2`G175R;W!E+U=A
M<G-A=R<["B1T>ELG175R;W!E+UIA9W)E8B==(#T@)T5U<F]P92]:86=R96(G
M.PHD='I;)T5U<F]P92]:87!O<F]Z:'EE)UT@/2`G175R;W!E+UIA<&]R;WIH
M>64G.PHD='I;)T5U<F]P92]:=7)I8V@G72`]("=%=7)O<&4O6G5R:6-H)SL*
M)'1Z6R=);F1I86XO06YT86YA;F%R:79O)UT@/2`G26YD:6%N+T%N=&%N86YA
M<FEV;R<["B1T>ELG26YD:6%N+T-H86=O<R==(#T@)TEN9&EA;B]#:&%G;W,G
M.PHD='I;)TEN9&EA;B]#:')I<W1M87,G72`]("=);F1I86XO0VAR:7-T;6%S
M)SL*)'1Z6R=);F1I86XO0V]C;W,G72`]("=);F1I86XO0V]C;W,G.PHD='I;
M)TEN9&EA;B]#;VUO<F\G72`]("=);F1I86XO0V]M;W)O)SL*)'1Z6R=);F1I
M86XO2V5R9W5E;&5N)UT@/2`G26YD:6%N+TME<F=U96QE;B<["B1T>ELG26YD
M:6%N+TUA:&4G72`]("=);F1I86XO36%H92<["B1T>ELG26YD:6%N+TUA;&1I
M=F5S)UT@/2`G26YD:6%N+TUA;&1I=F5S)SL*)'1Z6R=);F1I86XO36%U<FET
M:75S)UT@/2`G26YD:6%N+TUA=7)I=&EU<R<["B1T>ELG26YD:6%N+TUA>6]T
M=&4G72`]("=);F1I86XO36%Y;W1T92<["B1T>ELG26YD:6%N+U)E=6YI;VXG
M72`]("=);F1I86XO4F5U;FEO;B<["B1T>ELG4&%C:69I8R]!<&EA)UT@/2`G
M4&%C:69I8R]!<&EA)SL*)'1Z6R=086-I9FEC+T%U8VML86YD)UT@/2`G4&%C
M:69I8R]!=6-K;&%N9"<["B1T>ELG4&%C:69I8R]#:&%T:&%M)UT@/2`G4&%C
M:69I8R]#:&%T:&%M)SL*)'1Z6R=086-I9FEC+T5A<W1E<B==(#T@)U!A8VEF
M:6,O16%S=&5R)SL*)'1Z6R=086-I9FEC+T5F871E)UT@/2`G4&%C:69I8R]%
M9F%T92<["B1T>ELG4&%C:69I8R]%;F1E<F)U<GDG72`]("=086-I9FEC+T5N
M9&5R8G5R>2<["B1T>ELG4&%C:69I8R]&86MA;V9O)UT@/2`G4&%C:69I8R]&
M86MA;V9O)SL*)'1Z6R=086-I9FEC+T9I:FDG72`]("=086-I9FEC+T9I:FDG
M.PHD='I;)U!A8VEF:6,O1G5N869U=&DG72`]("=086-I9FEC+T9U;F%F=71I
M)SL*)'1Z6R=086-I9FEC+T=A;&%P86=O<R==(#T@)U!A8VEF:6,O1V%L87!A
M9V]S)SL*)'1Z6R=086-I9FEC+T=A;6)I97(G72`]("=086-I9FEC+T=A;6)I
M97(G.PHD='I;)U!A8VEF:6,O1W5A9&%L8V%N86PG72`]("=086-I9FEC+T=U
M861A;&-A;F%L)SL*)'1Z6R=086-I9FEC+T=U86TG72`]("=086-I9FEC+T=U
M86TG.PHD='I;)U!A8VEF:6,O2&]N;VQU;'4G72`]("=086-I9FEC+TAO;F]L
M=6QU)SL*)'1Z6R=086-I9FEC+TIO:&YS=&]N)UT@/2`G4&%C:69I8R]*;VAN
M<W1O;B<["B1T>ELG4&%C:69I8R]+:7)I=&EM871I)UT@/2`G4&%C:69I8R]+
M:7)I=&EM871I)SL*)'1Z6R=086-I9FEC+TMO<W)A92==(#T@)U!A8VEF:6,O
M2V]S<F%E)SL*)'1Z6R=086-I9FEC+TMW86IA;&5I;B==(#T@)U!A8VEF:6,O
M2W=A:F%L96EN)SL*)'1Z6R=086-I9FEC+TUA:G5R;R==(#T@)U!A8VEF:6,O
M36%J=7)O)SL*)'1Z6R=086-I9FEC+TUA<G%U97-A<R==(#T@)U!A8VEF:6,O
M36%R<75E<V%S)SL*)'1Z6R=086-I9FEC+TUI9'=A>2==(#T@)U!A8VEF:6,O
M36ED=V%Y)SL*)'1Z6R=086-I9FEC+TYA=7)U)UT@/2`G4&%C:69I8R].875R
M=2<["B1T>ELG4&%C:69I8R].:75E)UT@/2`G4&%C:69I8R].:75E)SL*)'1Z
M6R=086-I9FEC+TYO<F9O;&LG72`]("=086-I9FEC+TYO<F9O;&LG.PHD='I;
M)U!A8VEF:6,O3F]U;65A)UT@/2`G4&%C:69I8R].;W5M96$G.PHD='I;)U!A
M8VEF:6,O4&%G;U]086=O)UT@/2`G4&%C:69I8R]086=O(%!A9V\G.PHD='I;
M)U!A8VEF:6,O4&%L874G72`]("=086-I9FEC+U!A;&%U)SL*)'1Z6R=086-I
M9FEC+U!I=&-A:7)N)UT@/2`G4&%C:69I8R]0:71C86ER;B<["B1T>ELG4&%C
M:69I8R]0;VYA<&4G72`]("=086-I9FEC+U!O;F%P92<["B1T>ELG4&%C:69I
M8R]0;W)T7TUO<F5S8GDG72`]("=086-I9FEC+U!O<G0@36]R97-B>2<["B1T
M>ELG4&%C:69I8R]287)O=&]N9V$G72`]("=086-I9FEC+U)A<F]T;VYG82<[
M"B1T>ELG4&%C:69I8R]386EP86XG72`]("=086-I9FEC+U-A:7!A;B<["B1T
M>ELG4&%C:69I8R]486AI=&DG72`]("=086-I9FEC+U1A:&ET:2<["B1T>ELG
M4&%C:69I8R]487)A=V$G72`]("=086-I9FEC+U1A<F%W82<["B1T>ELG4&%C
M:69I8R]4;VYG871A<'4G72`]("=086-I9FEC+U1O;F=A=&%P=2<["B1T>ELG
M4&%C:69I8R]4<G5K)UT@/2`G4&%C:69I8R]4<G5K)SL*)'1Z6R=086-I9FEC
M+U=A:V4G72`]("=086-I9FEC+U=A:V4G.PHD='I;)U!A8VEF:6,O5V%L;&ES
M)UT@/2`G4&%C:69I8R]786QL:7,G.PHD='I;)U!A8VEF:6,O66%P)UT@/2`G
M4&%C:69I8R]987`G.PH*)$=,3T)!3%-;)W1Z)UT@/2`F)'1Z.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O971C+W!S82UH;W)D92]H;W)D92]P<F5F<RYP:'``````````````````
M````````````````````````````````````````````````````````,#$P
M,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#$V-S``,3`T,3<S-C(W-#,`
M,#(P,3,R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V-O;F9I9R]P<F5F<RYP
M:'`N9&ES="QV(#$N.#4N,BXU(#(P,#4O,3(O,C<@,3<Z,#`Z,3`@8VAU8VL@
M17AP("0*("H*("H@4')E9F5R96YC97,@26YF;W)M871I;VX*("H@/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*("H@0VAA;F=E<R!Y;W4@;6%K92!T;R!T:&4@
M<')E9G,N<&AP(&9I;&4H<RD@=VEL;"!N;W0@8F4@<F5F;&5C=&5D('5N=&EL
M('1H90H@*B!U<V5R(&QO9W,@;W5T(&%N9"!L;V=S(&EN(&%G86EN+@H@*@H@
M*B!)9B!Y;W4@8VAA;F=E('1H97-E('!R969E<F5N8V5S(&EN(&$@<')O9'5C
M=&EO;B!S>7-T96TL('EO=2!W:6QL"B`J(&YE960@=&\@9&5L971E(&%N>2!H
M;W)D95]P<F5F<R!I;B!Y;W5R('!R969E<F5N8V5S(&1A=&%B87-E+@H@*@H@
M*B!P<F5F1W)O=7!S(&%R<F%Y"B`J("TM+2TM+2TM+2TM+2TM+2T*("H@)'!R
M969'<F]U<',@87)E(&9O<B!D:7-P;&%Y('!U<G!O<V5S('=H96X@>6]U('!R
M97-S('1H92!O<'1I;VYS(&)U='1O;BX*("H@5&AE(&]P=&EO;G,@8VAO:6-E
M('=I;&P@87!P96%R('=H96X@>6]U('-E="!Y;W5R('!R969E<F5N8V5S(&1R
M:79E<@H@*B!I;B!T:&4@:&]R9&4O8V]N9FEG+V-O;F8N<&AP(&9I;&4N"B`J
M"B`J("1P<F5F1W)O=7!S(&%R<F%Y(&1E9FEN:71I;VXZ"B`J("`@(&-O;'5M
M;CH@(%=H870@8V]L=6UN(&AE860@=&AI<R!G<F]U<"!W:6QL(&=O('5N9&5R
M"B`J("`@("!L86)E;#H@($QA8F5L(&9O<B!T:&4@9W)O=7`@;V8@<V5T=&EN
M9W,*("H@("`@("!D97-C.B`@1&5S8W)I<'1I;VX@=&AA="!W:6QL('-H;W<@
M=6YD97(@;&%B96P*("H@("!M96UB97)S.B`@3&ES="!O9B!P<F5F97)E;F-E
M<R!S=7!P;W)T960@8GD@=&AI<R!G<F]U<`H@*@H@*B!?<')E9G,@87)R87D*
M("H@+2TM+2TM+2TM+2TM"B`J(%1H92`D7W!R969S(&%R<F%Y)W,@87)E(&QI
M<W1E9"!I;B!T:&4@<V%M92!O<F1E<B!A<R!L:7-T960@:6X@=&AE"B`J(&UE
M;6)E<G,@96QE;65N="!O9B`D<')E9D=R;W5P<RX*("H*("H@("!V86QU93H@
M5&AI<R!E;G1R>2!W:6QL(&5I=&AE<B!H;VQD(&$@;G5M8F5R(&]R(&$@=&5X
M="!V86QU92!B87-E9"!O;B!T:&4*("H@("`@("`@("`@<')E9F5R96YC92!T
M>7!E.@H@*B`@("`@("`@("`@(&EM<&QI8VET.B`@4V5E(%!R969E<F5N8V4@
M='EP90H@*B`@("`@("`@("`@("`@("!T97AT.B`@5&5X="!V86QU90H@*B`@
M("`@("`@("`@("`@;G5M8F5R.B`@3G5M8F5R('9A;'5E"B`J("`@("`@("`@
M("`@8VAE8VMB;W@Z("!686QU92!S:&]U;&0@8F4@,"!F;W(@=6YC:&5C:V5D
M+"`Q(&9O<B!C:&5C:V5D"B`J("`@("`@("`@("`@("!S96QE8W0Z("!686QU
M92!A<W-O8VEA=&5D('=I=&@@=&AA="!S96QE8W1I;VX@;&ES=`H@*@H@*B`@
M;&]C:V5D.B!!;&QO=R!P<F5F97)E;F-E('1O(&)E(&-H86YG960@9G)O;2!5
M20H@*B`@("`@("`@("`@("!T<G5E.B`@1&\@;F]T('-H;W<@=&AI<R!P<F5F
M97)E;F-E(&EN('1H92!520H@*B`@("`@("`@("`@(&9A;'-E.B`@4VAO=R!T
M:&ES('!R969E<F5N8V4@:6X@=&AE(%5)(&%N9"!A;&QO=R!C:&%N9VEN9PH@
M*@H@*B`@<VAA<F5D.B!3:&%R92!W:71H(&]T:&5R(&AO<F1E(&%P<',*("H@
M("`@("`@("`@("`@=')U93H@(%-H87)E('1H:7,@<')E9B!W:71H(&]T:&5R
M($AO<F1E(&%P<',*("H@("`@("`@("`@("!F86QS93H@($ME97`@=&AI<R!P
M<F5F(&QO8V%L('1O('1H92!C=7)R96YT(&%P<`H@*@H@*B`@("!T>7!E.B!0
M<F5F97)E;F-E('1Y<&4*("H@("`@("`@("`@("`@<W!E8VEA;#H@(%!R;W9I
M9&5S(&$@54D@=VED9V5T"B`J("`@("`@("`@("`@("!S96QE8W0Z("!0<F]V
M:61E<R!A('-E;&5C=&EO;B!L:7-T(&EN('1H92!520H@*B`@("`@("`@("`@
M(&-H96-K8F]X.B`@4')O=FED97,@82!C:&5C:V)O>`H@*B`@("`@("`@("`@
M(&EM<&QI8VET.B`@4')O=FED97,@<W1O<F%G92!F;W(@)W-P96-I86PG('1Y
M<&5S"B`J("`@("`@("`@("`@<&%S<W=O<F0Z("!0<F]V:61E<R!A('1E>'1B
M;W@@9F]R('!A<W-W;W)D(&5N=')Y+@H@*B`@("`@("`@("`@("`@("!E;G5M
M.B`@57-E('-T871I8R!L:7-T(&]F(&5L96UE;G1S+BXN<VEM:6QA<B!T;R`G
M<V5L96-T)PH@*@H@*B`@("!E;G5M.B!3=&%T:6,@;&ES="!O9B!E;&5M96YT
M<RX*("H*("H@97-C87!E9#H@1F]R(&%N(&5N=6T@;W(@82!S96QE8W0L(&%R
M92!T:&4@:V5Y<R!A;F0@=F%L=65S(&%L<F5A9'D@:'1M;"UE<V-A<&5D/PH@
M*B`@("`@("`@("!$969A=6QT<R!T;R!F86QS92!I9B!N;W0@<')E<V5N="X*
M("H*("H@("`@:&]O:SH@0V%L;"!A(&AO;VL@9G5N8W1I;VX@9F]R('1H92!V
M86QU92!O9B!T:&ES('!R969E<F5N8V4*("H@("`@("`@("`@("`@=')U93H@
M(%=I;&P@8V%L;"!T:&4@9G5N8W1I;VX@7W!R969S7VAO;VM?/'!R969N86UE
M/@H@*B`@("`@("`@("`@("`@("`@("`@=&\@9FEL;"!I;B!T:&4@=F%L=64@
M;V8@=&AI<R!P<F5F97)E;F-E+@H@*B`@("`@("`@("`@("`@("`@("`@4V5E
M(&AO;VMS+G!H<"!F;W(@;6]R92!D971A:6QS+@H@*B`@("`@("`@("`@(&9A
M;'-E.B`@3F]R;6%L(&)E:&%V:6]U<B`M(&YO(&AO;VL@:7,@8V%L;&5D+@H@
M*B\*"B1P<F5F1W)O=7!S6R=I9&5N=&ET:65S)UT@/2!A<G)A>2@*("`@("=C
M;VQU;6XG(#T^(%\H(EEO=7(@26YF;W)M871I;VXB*2P*("`@("=L86)E;"<@
M/3X@7R@B4&5R<V]N86P@26YF;W)M871I;VXB*2P*("`@("=D97-C)R`]/B!?
M*")#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E
M('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RXB*2P*
M("`@("=M96UB97)S)R`]/B!A<G)A>2@G9&5F875L=%]I9&5N=&ET>2<L("=I
M9&5N=&ET>7-E;&5C="<L("=D96QE=&5I9&5N=&ET>2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@)VED)RP@)V9U;&QN86UE)RP@)V9R;VU?861D<B<I"BD[
M"@HD875T:"`]("9!=71H.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG
M875T:"==6R=D<FEV97(G72D["FEF("AI<U]A*"1A=71H+"`G075T:"<I("8F
M("1A=71H+3YH87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@("`@)'!R969'
M<F]U<'-;)V9O<F=O='!A<W,G72`](&%R<F%Y*`H@("`@("`@("=C;VQU;6XG
M(#T^(%\H(EEO=7(@26YF;W)M871I;VXB*2P*("`@("`@("`G;&%B96PG(#T^
M(%\H(D%C8V]U;G0@4&%S<W=O<F0B*2P*("`@("`@("`G9&5S8R<@/3X@7R@B
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(I+`H@("`@("`@("=M96UB97)S
M)R`]/B!A<G)A>2@G<V5C=7)I='E?<75E<W1I;VXG+"`G<V5C=7)I='E?86YS
M=V5R)RP@)V%L=&5R;F%T95]E;6%I;"<I"B`@("`I.PI]"@HD<')E9D=R;W5P
M<ULG;&%N9W5A9V4G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B66]U
M<B!);F9O<FUA=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?*"),;V-A;&4@86YD
M(%1I;64B*2P*("`@("=D97-C)R`]/B!?*")3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(BDL"B`@("`G
M;65M8F5R<R<@/3X@87)R87DH)VQA;F=U86=E)RP@)W1I;65Z;VYE)RP@)W1W
M96YT>49O=7(G+"`G9&%T95]F;W)M870G*0HI.PH*)'!R969'<F]U<'-;)V-A
M=&5G;W)I97,G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B66]U<B!)
M;F9O<FUA=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?*")#871E9V]R:65S(&%N
M9"!,86)E;',B*2P*("`@("=D97-C)R`]/B!?*")-86YA9V4@=&AE(&QI<W0@
M;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A
M;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(I
M+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=C871E9V]R>6UA;F%G96UE;G0G
M*0HI.PH*)'!R969'<F]U<'-;)V1I<W!L87DG72`](&%R<F%Y*`H@("`@)V-O
M;'5M;B<@/3X@7R@B3W1H97(@26YF;W)M871I;VXB*2P*("`@("=L86)E;"<@
M/3X@7R@B1&ES<&QA>2!/<'1I;VYS(BDL"B`@("`G9&5S8R<@/3X@7R@B4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N(BDL"B`@
M("`G;65M8F5R<R<@/3X@87)R87DH)VEN:71I86Q?87!P;&EC871I;VXG+"`G
M<VAO=U]L87-T7VQO9VEN)RP@)W1H96UE)RP*("`@("`@("`@("`@("`@("`@
M("`@("`G<W5M;6%R>5]R969R97-H7W1I;64G+"`G<VAO=U]S:61E8F%R)RP@
M)W-I9&5B87)?=VED=&@G+`H@("`@("`@("`@("`@("`@("`@("`@("=M;WI?
M<VED96)A<B<L("=M96YU7W9I97<G+"`G;65N=5]R969R97-H7W1I;64G+`H@
M("`@("`@("`@("`@("`@("`@("`@("=W:61G971?86-C97-S:V5Y)RP@)V%L
M<&AA7V9I;'1E<B<I"BD["@HD<')E9D=R;W5P<ULG;&]G:6YT87-K<R==(#T@
M87)R87DH"B`@("`G8V]L=6UN)R`]/B!?*")/=&AE<B!);F9O<FUA=&EO;B(I
M+`H@("`@)VQA8F5L)R`]/B!?*"),;V=I;B!487-K<R(I+`H@("`@)V1E<V,G
M(#T^('-P<FEN=&8H7R@B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+B(I+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE
M)RDI+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=D;U]M86EN=&5N86YC92<L
M("=C;VYF:7)M7VUA:6YT96YA;F-E)RD**3L*"B1P<F5F1W)O=7!S6R=R96UO
M=&4G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B3W1H97(@26YF;W)M
M871I;VXB*2P*("`@("=L86)E;"<@/3X@7R@B4F5M;W1E(%-E<G9E<G,B*2P*
M("`@("=D97-C)R`]/B!?*")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y
M;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB*2P*("`@("=U
M<FPG(#T^("=S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<"<**3L*"B\O($9O
M<B!A;'1E<FYA=&4@24U34"!A=71H96YT:6-A=&EO;BX*:68@*"%E;7!T>2@D
M1TQ/0D%,4ULG8V]N9B==6R=I;7-P)UU;)V5N86)L960G72DI('L*("`@("1P
M<F5F1W)O=7!S6R=I;7-P875T:"==(#T@87)R87DH"B`@("`@("`@)V-O;'5M
M;B<@/3X@7R@B3W1H97(@26YF;W)M871I;VXB*2P*("`@("`@("`G;&%B96PG
M(#T^(%\H(D%L=&5R;F%T92!)35-0($QO9VEN(BDL"B`@("`@("`@)V1E<V,G
M(#T^(%\H(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@
M24U34"!S97)V97(N(BDL"B`@("`@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=I
M;7-P7V%U=&A?=7-E<B<L("=I;7-P7V%U=&A?<&%S<R<I"B`@("`I.PI]"@HO
M+R!$971E<FUI;F4@9G5N8W1I;VYA;&ET>2!O9B!R:6-H=&5X="!E9&ET;W(*
M)'!R969'<F]U<'-;)W)I8VAT97AT)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG
M(#T^(%\H(D]T:&5R($EN9F]R;6%T:6]N(BDL"B`@("`G;&%B96PG(#T^(%\H
M(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(I+`H@("`@)V1E<V,G(#T^(%\H
M(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BXB*2P*("`@("=M96UB97)S)R`]/B!A<G)A>2@G8V]N=&5X=&UE;G4G
M+"`G=&%B;&5O<&5R871I;VYS)RP@)VQI<W1T>7!E)RDL"BD["FEF("@D<F5G
M:7-T<GDM/FAA<TEN=&5R9F%C92@G:6UA9V5S)RDI('L*("`@("1P<F5F1W)O
M=7!S6R=R:6-H=&5X="==6R=M96UB97)S)UU;72`]("=A;G-E;&EM86=E)SL*
M?0H*)'!R969'<F]U<'-;)W-Y;F-M;"==(#T@87)R87DH"B`@("`G8V]L=6UN
M)R`]/B!?*")/=&AE<B!);F9O<FUA=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?
M*")3>6YC34PB*2P*("`@("=D97-C)R`]/B!?*")#;VYF:6=U<F%T:6]N(&9O
M<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN
M(BDL"B`@("`G=7)L)R`]/B`G<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`G
M+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"D**3L*"B\O(%!E<G-O;F%L($EN
M9F]R;6%T:6]N('!R969E<F5N8V5S"@HO+R!D969A=6QT(&ED96YT:71Y"B\O
M(%-E="!L;V-K960@=&\@=')U92!I9B!Y;W4@9&]N)W0@=V%N="!T:&4@=7-E
M<G,@=&\@:&%V92!M=6QT:7!L92!I9&5N=&ET:65S+@HD7W!R969S6R=D969A
M=6QT7VED96YT:71Y)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@,"P*("`@
M("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@
M("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@*&ES<V5T*"1I9&5N
M=&ET>2D@)B8@:7-?;V)J96-T*"1I9&5N=&ET>2DI(#\@)&ED96YT:71Y+3YG
M971!;&PH)VED)RD@.B!A<G)A>2@I+`H@("`@)V1E<V,G(#T^(%\H(EEO=7(@
M9&5F875L="!I9&5N=&ET>3HB*0HI.PH*+R\@:61E;G1I=&EE<R!A<G)A>0HO
M+R!$;VXG="!C:&%N9V4@86YY=&AI;F<@:&5R92X*)%]P<F5F<ULG:61E;G1I
M=&EE<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=A.C`Z>WTG+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@
M)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O(&ED96YT:71Y('-E;&5C=&EO
M;B!W:61G970*)%]P<F5F<ULG:61E;G1I='ES96QE8W0G72`](&%R<F%Y*`H@
M("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G<W!E8VEA;"<*
M*3L*"B\O(&1E;&5T92!B=71T;VX*)%]P<F5F<ULG9&5L971E:61E;G1I='DG
M72`](&%R<F%Y*`H@("`@)W1Y<&4G(#T^("=S<&5C:6%L)RP*("`@("=S:&%R
M960G(#T^('1R=64**3L*"B\O(&ED96YT:71Y(&YA;64*+R\@268@>6]U(&QO
M8VL@=&AI<R!P<F5F97)E;F-E+"!Y;W4@;75S="!S<&5C:69Y(&$@=F%L=64@
M;W(@82!H;V]K(&9O<B!I="!I;@HO+R!H;W)D92]C;VYF:6<O:&]O:W,N<&AP
M+@HD7W!R969S6R=I9"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@
M("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=D97-C)R`]/B!?*"))9&5N=&ET
M>2=S(&YA;64Z(BD**3L*"B\O('5S97(@9G5L;"!N86UE(&9O<B!&<F]M.B!L
M:6YE"B\O($EF('EO=2!L;V-K('1H:7,@<')E9F5R96YC92P@>6]U(&UU<W0@
M<W!E8VEF>2!A('9A;'5E(&]R(&$@:&]O:R!F;W(@:70@:6X*+R\@:&]R9&4O
M8V]N9FEG+VAO;VMS+G!H<"X*)%]P<F5F<ULG9G5L;&YA;64G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@
M("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@
M("`G9&5S8R<@/3X@7R@B66]U<B!F=6QL(&YA;64Z(BD**3L*"B\O('5S97(@
M<')E9F5R<F5D(&5M86EL(&%D9')E<W,@9F]R($9R;VTZ(&QI;F4*+R\@268@
M>6]U(&QO8VL@=&AI<R!P<F5F97)E;F-E+"!Y;W4@;75S="!S<&5C:69Y(&$@
M=F%L=64@;W(@82!H;V]K(&9O<B!I="!I;@HO+R!H;W)D92]C;VYF:6<O:&]O
M:W,N<&AP+@HD7W!R969S6R=F<F]M7V%D9'(G72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E
M9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`G9&5S8R<@
M/3X@(%\H(EEO=7(@1G)O;3H@861D<F5S<SHB*0HI.PH*+R\@=7-E<B!S96-U
M<FET>2!Q=65S=&EO;@HD7W!R969S6R=S96-U<FET>5]Q=65S=&EO;B==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@/3X@9F%L
M<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=T97AT
M)RP*("`@("=D97-C)R`]/B!?*")%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N
M('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SHB*0HI.PH*+R\@=7-E<B!S96-U<FET>2!A;G-W97(*)%]P<F5F
M<ULG<V5C=7)I='E?86YS=V5R)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^(%\H(DEN
M<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S
M=&EO;CHB*0HI.PH*+R\@=7-E<B!A;'1E<FYA=&4@96UA:6P*)%]P<F5F<ULG
M86QT97)N871E7V5M86EL)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L
M"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L
M"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^(%\H(DEN<V5R
M="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T
M:&4@;F5W('!A<W-W;W)D.B(I"BD["@HO+R!U<V5R(&QA;F=U86=E"B1?<')E
M9G-;)VQA;F=U86=E)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@
M("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@
M("`G='EP92<@/3X@)W-E;&5C="<L"B`@("`G97-C87!E9"<@/3X@=')U92P*
M("`@("=D97-C)R`]/B!?*")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z(BD**3L*"B\O('5S97(@=&EM92!Z;VYE"B1?<')E9G-;)W1I;65Z;VYE
M)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]
M/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@
M)W-E;&5C="<L"B`@("`G9&5S8R<@/3X@7R@B66]U<B!C=7)R96YT('1I;64@
M>F]N93HB*0HI.PH*+R\@=&EM92!F;W)M870*)%]P<F5F<ULG='=E;G1Y1F]U
M<B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(&9A;'-E+`H@("`@)VQO8VME
M9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G
M(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(I"BD["@HO+R!D871E(&9O<FUA=`HD7W!R969S6R=D871E
M7V9O<FUA="==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<E>"<L"B`@("`G
M;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G
M='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y*`H@("`@("`@
M("<E>"<@/3X@<W1R9G1I;64H)R5X)RDL"B`@("`@("`@)R59+25M+25D)R`]
M/B!S=')F=&EM92@G)5DM)6TM)60G*2P*("`@("`@("`G)4$@)4(@)60L("59
M)R`]/B!S=')F=&EM92@G)4$@)4(@)60L("59)RDL"B`@("`@("`@)R5!+"`E
M9"X@)4(@)5DG(#T^('-T<F9T:6UE*"<E02P@)60N("5"("59)RDL"B`@("`@
M("`@)R5!+"`E9"`E0B`E62<@/3X@<W1R9G1I;64H)R5!+"`E9"`E0B`E62<I
M+`H@("`@("`@("<E82P@)6(@)64L("59)R`]/B!S=')F=&EM92@G)6$L("5B
M("5E+"`E62<I+`H@("`@("`@("<E82P@)6(@)64L("5Y)R`]/B!S=')F=&EM
M92@G)6$L("5B("5E+"`E>2<I+`H@("`@("`@("<E82P@)6(@)64G(#T^('-T
M<F9T:6UE*"<E82P@)6(@)64G*2P*("`@("`@("`G)6$L("5E("5B("59)R`]
M/B!S=')F=&EM92@G)6$L("5E("5B("59)RDL"B`@("`@("`@)R5A+"`E92`E
M8B`E>2<@/3X@<W1R9G1I;64H)R5A+"`E92`E8B`E>2<I+`H@("`@("`@("<E
M82`E9"`E8B`E62<@/3X@<W1R9G1I;64@*"<E82`E9"`E8B`E62<I+`H@("`@
M("`@("<E82`E>"<@/3X@<W1R9G1I;64@*"<E82`E>"<I+`H@("`@("`@("<E
M82`E62TE;2TE9"<@/3X@<W1R9G1I;64@*"<E82`E62TE;2TE9"<I+`H@("`@
M("`@("<E92`E8B`E62<@/3X@<W1R9G1I;64H)R5E("5B("59)RDL"B`@("`@
M("`@)R5E+B`E8B`E62<@/3X@<W1R9G1I;64H)R5E+B`E8B`E62<I+`H@("`@
M("`@("<E92X@)6T@)5DG(#T^('-T<F9T:6UE*"<E92`E;2`E62<I+`H@("`@
M("`@("<E92X@)6TN)R`]/B!S=')F=&EM92@G)64N("5M+B<I+`H@("`@("`@
M("<E92X@)4(G(#T^('-T<F9T:6UE*"<E92X@)4(G*2P*("`@("`@("`G)64N
M("5"("59)R`]/B!S=')F=&EM92@G)64N("5"("59)RDL"B`@("`@("`@)R5E
M+B`E0B`E>2<@/3X@<W1R9G1I;64H)R5E+B`E0B`E>2<I+`H@("`@("`@("<E
M0B`E92P@)5DG(#T^('-T<F9T:6UE*"<E0B`E92P@)5DG*2P*("`@("DL"B`@
M("`G9&5S8R<@/3X@7R@B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(I
M*3L*"B\O(%5)('1H96UE"B1?<')E9G-;)W1H96UE)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@)V)L=65W:&ET92<L"B`@("`G;&]C:V5D)R`]/B!F86QS
M92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)W-E;&5C
M="<L"B`@("`G9&5S8R<@/3X@7R@B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+B(I"BD["@HO+R!C871E9V]R:65S"B1?<')E9G-;)V-A=&5G;W)I97,G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G:6UP
M;&EC:70G"BD["@HO+R!C871E9V]R>2!C;VQO<G,*)%]P<F5F<ULG8V%T96=O
M<GE?8V]L;W)S)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G
M;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G
M='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@54D@9F]R(&-A=&5G;W)Y(&UA
M;F%G96UE;G0N"B1?<')E9G-;)V-A=&5G;W)Y;6%N86=E;65N="==(#T@87)R
M87DH"B`@("`G='EP92<@/3X@)W-P96-I86PG"BD["@HD7W!R969S6R=S=6UM
M87)Y7W)E9G)E<VA?=&EM92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#,P
M,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L
M<V4L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y
M*#`@/3X@7R@B3F5V97(B*2P*("`@("`@("`@("`@("`@("`@("`S,"`]/B!?
M*")%=F5R>2`S,"!S96-O;F1S(BDL"B`@("`@("`@("`@("`@("`@("`@-C`@
M/3X@7R@B179E<GD@;6EN=71E(BDL"B`@("`@("`@("`@("`@("`@("`@,S`P
M(#T^(%\H(D5V97)Y(#4@;6EN=71E<R(I+`H@("`@("`@("`@("`@("`@("`@
M(#DP,"`]/B!?*")%=F5R>2`Q-2!M:6YU=&5S(BDL"B`@("`@("`@("`@("`@
M("`@("`@,3@P,"`]/B!?*")%=F5R>2!H86QF(&AO=7(B*2DL"B`@("`G9&5S
M8R<@/3X@7R@B4F5F<F5S:"!0;W)T86P@5FEE=SHB*0HI.PH*)%]P<F5F<ULG
M<VAO=U]S:61E8F%R)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@=')U92P*
M("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*
M("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^('-P<FEN
M=&8H7R@B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B*2P@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<L("=H;W)D92<I*0HI.PH*)%]P
M<F5F<ULG<VED96)A<E]W:61T:"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M(#$U,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@
M9F%L<V4L"B`@("`G='EP92<@/3X@)VYU;6)E<B<L"B`@("`G9&5S8R<@/3X@
M<W!R:6YT9BA?*")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB*2P@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G;F%M92<L("=H;W)D92<I*0HI.PH*)%]P<F5F<ULG
M;6]Z7W-I9&5B87(G72`](&%R<F%Y*`H@("`@)W1Y<&4G(#T^("=L:6YK)RP*
M("`@("=X=7)L)R`]/B!S<')I;G1F*"=J879A<V-R:7!T.FEF("AW:6YD;W<N
M<VED96)A<B`F)B!W:6YD;W<N<VED96)A<BYA9&1086YE;"D@=VEN9&]W+G-I
M9&5B87(N861D4&%N96PH7"<E<UPG+"!<)R5S7"<L(%PG)7-<)RD[(&5L<V4@
M86QE<G0H7"<E<UPG*3LG+`H@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<L("=H;W)D92<I+`H@("`@("`@
M("`@("`@("`@("`@("`@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU<FPH
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I
M("X@)R]S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`G+"!T<G5E+"`M,2DL
M("=M;WIB87(G+"`G,2<I+`H@("`@("`@("`@("`@("`@("`@("`@2&]R9&4Z
M.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W!R969S+G!H<"<L('1R=64L("TQ*2P*("`@("`@("`@("`@
M("`@("`@("`@(&%D9'-L87-H97,H7R@B0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB
M*2DI+`H@("`@)V1E<V,G(#T^('-P<FEN=&8H7R@B061D('1H92`E<R!-96YU
M(&%S(&$@36]Z:6QL82!3:61E8F%R(BDL("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)VYA;64G+"`G:&]R9&4G*2D**3L*"B1?<')E9G-;)VUE;G5?=FEE
M=R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=B;W1H)RP*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E
M)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@87)R87DH)W1E>'0G(#T^(%\H
M(E1E>'0@3VYL>2(I+`H@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B!?
M*"))8V]N<R!/;FQY(BDL"B`@("`@("`@("`@("`@("`@("`@)V)O=&@G(#T^
M(%\H(DEC;VYS('=I=&@@=&5X="(I*2P*("`@("=D97-C)R`]/B!?*")-96YU
M(&UO9&4Z(BD**3L*"B1?<')E9G-;)VUE;G5?<F5F<F5S:%]T:6UE)UT@/2!A
M<G)A>2@*("`@("=V86QU92<@/3X@,S`P+`H@("`@)VQO8VME9"<@/3X@9F%L
M<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=E;G5M
M)RP*("`@("=E;G5M)R`]/B!A<G)A>2@P(#T^(%\H(DYE=F5R(BDL"B`@("`@
M("`@("`@("`@("`@("`@,S`@/3X@7R@B179E<GD@,S`@<V5C;VYD<R(I+`H@
M("`@("`@("`@("`@("`@("`@(#8P(#T^(%\H(D5V97)Y(&UI;G5T92(I+`H@
M("`@("`@("`@("`@("`@("`@(#$R,"`]/B!?*")%=F5R>2`R(&UI;G5T97,B
M*2P*("`@("`@("`@("`@("`@("`@("`S,#`@/3X@7R@B179E<GD@-2!M:6YU
M=&5S(BDI+`H@("`@)V1E<V,G(#T^(%\H(E)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.B(I"BD["@H*+R\@3&]G:6XO36%I;G1E;F%N8V4@5&%S:W,@
M<')E9F5R96YC97,*"B\O(%1O(&1I<V%B;&4@;6%I;G1E;F%N8V4@96YT:7)E
M;'DL('-E="`G=F%L=64G(#T@9F%L<V4@86YD"B\O("=L;V-K960G(#T@=')U
M92!F;W(@86QL(&]F('1H97-E+B!4;R!J=7-T('1U<FX@:70@;V9F(&)Y(&1E
M9F%U;'0L"B\O('-E="`G=F%L=64G(&9A;'-E(&9O<B!D;U]M86EN=&5N86YC
M92X*+R\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS/PHD7W!R969S
M6R=D;U]M86EN=&5N86YC92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^('1R
M=64L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?
M*")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(BDL
M"B`@("`G:&5L<"<@/3X@)W!R969S+61O7VUA:6YT96YA;F-E)RD["@HO+R!L
M87-T('1I;64@;6%I;G1E;F%N8V4@=V%S(')U;BX*+R\@=F%L=64@:7,@82!5
M3DE8('1I;65S=&%M<"!O9B!T:&4@;&%S="!T:6UE(&UA:6YT96YA;F-E(')A
M;B!F;W(@=&AE('5S97(N"B1?<')E9G-;)VQA<W1?;6%I;G1E;F%N8V4G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@9F%L
M<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=I;7!L
M:6-I="<**3L*"B\O(&-O;F9I<FT@=VAE;B!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/R!)9B!F86QS92P@=&AE>2!W:6QL"B\O(&)E('!E<F9O<FUE
M9"!W:71H(&YO(&EN<'5T(&9R;VTO8VAE8VL@=VET:"!T:&4@=7-E<BX*)%]P
M<F5F<ULG8V]N9FER;5]M86EN=&5N86YC92==(#T@87)R87DH"B`@("`G=F%L
M=64G(#T^('1R=64L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D
M97-C)R`]/B!?*")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B*2P*("`@("=H96QP)R`]/B`G<')E
M9G,M8V]N9FER;5]M86EN=&5N86YC92<I.PH*+R\@16YD($QO9VEN+TUA:6YT
M96YA;F-E('!R969E<F5N8V5S"@H*+R\@=VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@=V4@9V\@=&\@869T97(@;&]G:6X_"B1?<')E9G-;)VEN:71I86Q?87!P
M;&EC871I;VXG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G:&]R9&4G+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@
M("`@)W1Y<&4G(#T^("=S96QE8W0G+`H@("`@)V1E<V,G(#T^('-P<FEN=&8H
M7R@B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L
M;V=I;C\B*2P@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<I*0HI
M.PH*+R\@<VAO=6QD('=E(&-R96%T92!A8V-E<W,@:V5Y<S\*)%]P<F5F<ULG
M=VED9V5T7V%C8V5S<VME>2==(#T@87)R87DH"B`@("`G=F%L=64G(#T^('1R
M=64L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?
M*")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\B*0HI.PH*+R\@<VAO=6QD('=E(&YO="!U<V4@=&AE(&%L<&AA(&EM86=E
M(&QO861E<B!F;W(@244_"B1?<')E9G-;)V%L<&AA7V9I;'1E<B==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^(&9A;'-E+`H@("`@)VQO8VME9"<@/3X@=')U
M92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V-H96-K
M8F]X)RP*("`@("=D97-C)R`]/B!?*"))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I
M8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O
M(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M(BD**3L*"B\O('1H92!L87EO=70@;V8@=&AE('!O<G1A;"!P86=E+@HD7W!R
M969S6R=P;W)T86Q?;&%Y;W5T)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)V$Z,#I[?2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O('1H
M92!R96UO=&4@<V5R=F5R<RX*)%]P<F5F<ULG<F5M;W1E7W-U;6UA<FEE<R==
M(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=A.C`Z>WTG+`H@("`@)VQO8VME
M9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E
M)R`]/B`G:6UP;&EC:70G"BD["@HO+R!L87-T(&QO9VEN('1I;64@;V8@=7-E
M<@HO+R!V86QU92!I<R!A('-E<FEA;&EZ960@87)R87D@;V8@=&AE(%5.25@@
M=&EM97-T86UP(&]F('1H92!L87-T"B\O(&QO9VEN+"!A;F0@=&AE(&AO<W0@
M=&AA="!T:&4@;&%S="!L;V=I;B!W87,@9G)O;2X*)%]P<F5F<ULG;&%S=%]L
M;V=I;B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=A.C`Z>WTG+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@
M)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O('-H;W<@=&AE(&QA<W0@;&]G
M:6X@=&EM92!O9B!U<V5R"B1?<')E9G-;)W-H;W=?;&%S=%]L;V=I;B==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^('1R=64L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V-H
M96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_(BD**3L*"FEF("@A96UP='DH)$=,3T)!3%-;
M)V-O;F8G75LG:6US<"==6R=E;F%B;&5D)UTI*2!["B`@("`D7W!R969S6R=I
M;7-P7V%U=&A?=7-E<B==(#T@87)R87DH"B`@("`@("`@)W9A;'5E)R`]/B`G
M)RP*("`@("`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@("`@
M("=D97-C)R`]/B!?*")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(I"B`@("`I
M.PH*("`@("1?<')E9G-;)VEM<W!?875T:%]P87-S)UT@/2!A<G)A>2@*("`@
M("`@("`G=F%L=64G(#T^("<G+`H@("`@("`@("=L;V-K960G(#T^(&9A;'-E
M+`H@("`@("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@("`@("=T>7!E)R`]
M/B`G<&%S<W=O<F0G+`H@("`@("`@("=D97-C)R`]/B!?*")!;'1E<FYA=&4@
M24U34"!087-S=V]R9"(I"B`@("`I.PI]"@HO+R!2:6-H(%1E>'0@161I=&]R
M('!R969E<F5N8V5S+@H*)%]P<F5F<ULG8V]N=&5X=&UE;G4G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O
M>"<L"B`@("`G9&5S8R<@/3X@7R@B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\B*0HI.PH*)%]P<F5F<ULG=&%B;&5O<&5R871I;VYS)UT@/2!A
M<G)A>2@*("`@("=V86QU92<@/3X@9F%L<V4L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V-H
M96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_(BD**3L*"B1?<')E9G-;)VQI<W1T>7!E)UT@/2!A<G)A
M>2@*("`@("=V86QU92<@/3X@=')U92P*("`@("=L;V-K960G(#T^(&9A;'-E
M+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G8VAE8VMB
M;W@G+`H@("`@)V1E<V,G(#T^(%\H(D%L;&]W('-E='1I;F<@;V8@;W)D97)E
M9"!L:7-T('1Y<&4_(BD**3L*"FEF("@D<F5G:7-T<GDM/FAA<TEN=&5R9F%C
M92@G:6UA9V5S)RDI('L*("`@("1?<')E9G-;)V%N<V5L:6UA9V4G72`](&%R
M<F%Y*`H@("`@("`@("=V86QU92<@/3X@=')U92P*("`@("`@("`G;&]C:V5D
M)R`]/B!F86QS92P*("`@("`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@("`@
M("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@("`@("=D97-C)R`]/B!?*")%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/R(I"B`@("`I.PI]"@HO+R!%;F0@4FEC:"!497AT($5D:71O
M<B!P<F5F97)E;F-E<RX*````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O<F5G:7-T<GDN<&AP
M````````````````````````````````````````````````````````````
M`````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-C,R`#$P
M-#$W,S8R-S0S`#`R,#8V,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@<F5G:7-T<GDN<&AP("TM($AO
M<F1E(&%P<&QI8V%T:6]N(')E9VES=')Y+@H@*@H@*B`D2&]R9&4Z(&AO<F1E
M+V-O;F9I9R]R96=I<W1R>2YP:'`N9&ES="QV(#$N,C4U+C(N,30@,C`P-B\P
M,R\Q,R`Q.#HQ,SHP-"!J86X@17AP("0*("H*("H@5&AI<R!C;VYF:6=U<F%T
M:6]N(&9I;&4@:7,@=7-E9"!B>2!(;W)D92!T;R!D971E<FUI;F4@=VAI8V@@
M2&]R9&4*("H@87!P;&EC871I;VYS(&%R92!I;G-T86QL960@86YD('=H97)E
M+"!A<R!W96QL(&%S(&AO=R!T:&5Y(&EN=&5R86-T+@H@*@H@*B!!<'!L:6-A
M=&EO;B!R96=I<W1R>0H@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+0H@*B!4:&4@
M9F]L;&]W:6YG('-E='1I;F=S(')E9VES=&5R(&EN<W1A;&QE9"!(;W)D92!A
M<'!L:6-A=&EO;G,N"B`J($)Y(&1E9F%U;'0L($AO<F1E(&%S<W5M97,@=&AA
M="!T:&4@87!P;&EC871I;VX@9&ER96-T;W)I97,@;&EV90H@*B!I;G-I9&4@
M=&AE(&AO<F1E(&1I<F5C=&]R>2X*("H*("H@071T<FEB=71E("`@("!4>7!E
M("`@("!$97-C<FEP=&EO;@H@*B`M+2TM+2TM+2T@("`@("TM+2T@("`@("TM
M+2TM+2TM+2TM"B`J(&9I;&5R;V]T("`@("`@<W1R:6YG("`@5&AE(&)A<V4@
M9FEL97-Y<W1E;2!P871H(&9O<B!T:&4@;6]D=6QE)W,@9FEL97,N"B`J('=E
M8G)O;W0@("`@("`@<W1R:6YG("`@5&AE(&)A<V4@55))(&9O<B!T:&4@;6]D
M=6QE+@H@*B!J<W5R:2`@("`@("`@('-T<FEN9R`@(%1H92!B87-E(%5222!F
M;W(@<W1A=&EC(&IA=F%S8W)I<'0@9FEL97,N"B`J(&IS9G,@("`@("`@("`@
M<W1R:6YG("`@5&AE(&)A<V4@9FEL97-Y<W1E;2!P871H(&9O<B!S=&%T:6,@
M:F%V87-C<FEP="!F:6QE<RX*("H@=&AE;65S=7)I("`@("!S=')I;F<@("!4
M:&4@8F%S92!54DD@9F]R('1H92!T:&5M97,N(%1H:7,@8V%N(&)E('5S960@
M=&\*("H@("`@("`@("`@("`@("`@("`@("`@("!S97)V92!A;&P@:6-O;G,@
M86YD('-T>6QE('-H965T<R!F<F]M(&$@<V5P87)A=&4*("H@("`@("`@("`@
M("`@("`@("`@("`@("!S97)V97(N"B`J('1H96UE<V9S("`@("`@<W1R:6YG
M("`@5&AE(&)A<V4@9FEL92!S>7-T96T@9&ER96-T;W)Y(&9O<B!T:&4@=&AE
M;65S+@H@*B!I8V]N("`@("`@("`@('-T<FEN9R`@(%1H92!54DD@9F]R(&%N
M(&EC;VX@=&\@<VAO=R!I;B!M96YU<R!F;W(@=&AE(&UO9'5L92X*("H@("`@
M("`@("`@("`@("`@("`@("`@("!3971T:6YG('1H:7,@=VEL;"!O=F5R<FED
M92!T:&4@9&5F875L="!T:&5M92UB87-E9`H@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&QO9VEC(&EN('1H92!C;V1E+@H@*B!N86UE("`@("`@("`@('-T
M<FEN9R`@(%1H92!N86UE('5S960@:6X@;65N=7,@86YD(&1E<V-R:7!T:6]N
M<R!F;W(@82!M;V1U;&4*("H@<W1A='5S("`@("`@("!S=')I;F<@("`G:6YA
M8W1I=F4G+"`G:&ED9&5N)RP@)VYO=&]O;&)A<B<L("=H96%D:6YG)RP*("H@
M("`@("`@("`@("`@("`@("`@("`@("`G8FQO8VLG+"`G861M:6XG+"!O<B`G
M86-T:79E)RX*("H@<')O=FED97,@("`@("!S=')I;F<@("!397)V:6-E('1Y
M<&5S('1H92!M;V1U;&4@<')O=FED97,N"B`J(&EN:71I86Q?<&%G92`@<W1R
M:6YG("`@5&AE(&EN:71I86P@*&1E9F%U;'0I('!A9V4@*&9I;&5N86UE*2!F
M;W(@=&AE(&UO9'5L92X*("H@=&5M<&QA=&5S("`@("!S=')I;F<@("!4:&4@
M9FEL97-Y<W1E;2!P871H('1O('1H92!T96UP;&%T97,@9&ER96-T;W)Y+@H@
M*B!M96YU7W!A<F5N="`@('-T<FEN9R`@(%1H92!N86UE(&]F('1H92`G:&5A
M9&EN9R<@9W)O=7`@=&AA="!T:&ES(&%P<"!S:&]U;&0*("H@("`@("`@("`@
M("`@("`@("`@("`@("!S:&]W('5P('5N9&5R+@H@*B!T87)G970@("`@("`@
M('-T<FEN9R`@(%1H92`H;W!T:6]N86PI('1A<F=E="!F<F%M92!F;W(@=&AE
M(&QI;FLN"B`J('5R;"`@("`@("`@("`@<W1R:6YG("`@5&AE("AO<'1I;VYA
M;"D@55),(&]F("=H96%D:6YG)R!E;G1R:65S+@H@*B\*"B\O(%=E('1R>2!T
M;R!A=71O;6%T:6-A;&QY(&1E=&5R;6EN92!T:&4@<')O<&5R('=E8G)O;W0@
M9F]R($AO<F1E"B\O(&AE<F4N(%1H:7,@<W1I;&P@87-S=6UE<R!T:&%T(&%P
M<&QI8V%T:6]N<R!L:79E('5N9&5R(&AO<F1E+RX@268*+R\@=&AI<R!R97-U
M;'1S(&EN(&EN8V]R<F5C="!R97-U;'1S(&9O<B!Y;W4L('-I;7!L>2!C:&%N
M9V4@=&AE('1W;PHO+R!U<V5S(&]F('1H92`D=V5B<F]O="!V87)I86)L92!I
M;B!T:&4@)VAO<F1E)R!S=&%N>F$@8F5L;W<N"B\O"B\O($YO=&4@9F]R(%=I
M;F1O=W,@=7-E<G,Z('1H92!B96QO=R!A<W-U;65S('1H870@>6]U<B!02%!?
M4T5,1@HO+R!V87)I86)L92!U<V5S(&9O<G=A<F0@<VQA<VAE<RX@268@:70@
M9&]E<R!N;W0L('EO=2=L;"!H879E('1O('1W96%K"B\O('1H:7,N"FEF("AI
M<W-E="@D7U-%4E9%4ELG4$A07U-%3$8G72DI('L*("`@("1W96)R;V]T(#T@
M<')E9U]S<&QI="@G.R\[)RP@)%]315)615);)U!(4%]314Q&)UTL(#(L(%!2
M14=?4U!,251?3D]?14U05%DI.PH@("`@)'=E8G)O;W0@/2!S=')S='(H9&ER
M;F%M92A?7T9)3$5?7RDL("<O)R`N(&%R<F%Y7W-H:69T*"1W96)R;V]T*2D[
M"B`@("!I9B`H)'=E8G)O;W0@(3T](&9A;'-E*2!["B`@("`@("`@)'=E8G)O
M;W0@/2!P<F5G7W)E<&QA8V4H)SLO8V]N9FEG)#LG+"`G)RP@)'=E8G)O;W0I
M.PH@("`@?2!E;'-E:68@*"1W96)R;V]T(#T]/2!F86QS92D@>PH@("`@("`@
M("1W96)R;V]T(#T@)R<["B`@("!](&5L<V4@>PH@("`@("`@("1W96)R;V]T
M(#T@)R]H;W)D92<["B`@("!]"GT@96QS92!["B`@("`D=V5B<F]O="`]("<O
M:&]R9&4G.PI]"@HD=&AI<RT^87!P;&EC871I;VYS6R=H;W)D92==(#T@87)R
M87DH"B`@("`G9FEL97)O;W0G(#T^("<O=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4G+`H@("`@)W=E8G)O;W0G(#T^("1W96)R;V]T+`H@("`@)VEN:71I86Q?
M<&%G92<@/3X@)VQO9VEN+G!H<"<L"B`@("`G;F%M92<@/3X@7R@B2&]R9&4B
M*2P*("`@("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@)W1E;7!L871E<R<@
M/3X@)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,G+`H@("`@
M)W!R;W9I9&5S)R`]/B`G:&]R9&4G"BD["@HO*B`*("H@2&%C:R!T;R!M86ME
M(')E9VES=&5R:6YG(&]F('!A8VMA9V5S(&5A<WD@=VET:&]U="!E9&ET:6YG
M"B`J(&-O;F9I9W5R871I;VX@9FEL97,L('-T;VQE;B!F<F]M($1E8FEA;@H@
M*B\*"FEF("@D9"`]($!O<&5N9&ER*"<O=7-R+VQO8V%L+W!S82]E=&,O<'-A
M+6AO<F1E+VAO<F1E+W)E9VES=')Y+F0G*2D@>PH@("`@=VAI;&4@*"1F(#T@
M<F5A9&1I<B@D9"DI('L@"B`@("`@("`@:68@*&5R96<H(BYP:'`D(BP@)&8I
M*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G+R]U<W(O;&]C86PO<'-A
M+V5T8R]P<V$M:&]R9&4O:&]R9&4O<F5G:7-T<GDN9"\G("X@)&8["B`@("`@
M("`@?0H@("`@?0H@("`@8VQO<V5D:7(H)&0I.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+VAO;VMS+G!H<```
M````````````````````````````````````````````````````````````
M```````````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R,C`S-P`Q
M,#0Q-S,V,C<T,P`P,C`Q,S,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($AO<F1E($AO;VMS(&-O;F9I
M9W5R871I;VX@9FEL92X*("H*("H@5$A%($A/3TM3(%!23U9)1$5$($E.(%1(
M25,@1DE,12!!4D4@15A!35!,15,@3TY,62X@($1/($Y/5"!%3D%"3$4@5$A%
M30H@*B!"3$E.1$Q9($E&(%E/52!$3R!.3U0@2TY/5R!72$%4(%E/52!!4D4@
M1$])3D<N("!93U4@2$%612!43R!#55-43TU)6D4@5$A%30H@*B!43R!-051#
M2"!93U52(%-014-)1DE#($Y%1413($%.1"!365-414T@14Y625)/3DU%3E0N
M"B`J"B`J(%1H:7,@9FEL92!I<R!W:&5R92!Y;W4@9&5F:6YE(&%N>2!H;V]K
M<RP@9F]R('!R969E<F5N8V5S(&]R(&=E;F5R86P@2&]R9&4*("H@=7-E+"!T
M:&%T('EO=7(@:6YS=&%L;&%T:6]N('5S97,N(%1H92!F=6YC=&EO;G,@:6X@
M=&AI<R!F:6QE(&-A;B!V87-T;'D*("H@8VAA;F=E(&AO=R!Y;W5R(&EN<W1A
M;&QA=&EO;B!B96AA=F5S+"!S;R!M86ME('-U<F4@=&\@=&5S="!O=70@86YY
M(&-H86YG97,*("H@:&5R92!B969O<F4@9&]I;F<@=&AE;2!I;B!A('!R;V1U
M8W1I;VX@96YV:7)O;FUE;G0N"B`J"B`J($AO;VL@9G5N8W1I;VX@;F%M97,@
M87)E(&%U=&]M871I8V%L;'D@9&5T97)M:6YE9"X@5&AE(&9O<FUA="!O9B!T
M:&4@;F%M90H@*B!I<SH*("H*("H@7SQT>7!E(&]F(&AO;VL^7VAO;VM?/&YA
M;64@;V8@:&]O:SXN"B`J"B`J(%1Y<&5S(&]F(&AO;VMS('1H870@87)E(&1E
M9FEN960@:6X@=&AI<R!F:6QE(&%R92`G<')E9G,G("AH;V]K<R!T;R!S970@
M=&AE"B`J('9A;'5E(&]F('!R969E<F5N8V5S*2P@)VAO<F1E)R`H:&]O:W,@
M9F]R('1H92!(;W)D92!&<F%M97=O<FL@<V-R:7!T<RD@86YD"B`J("=A<'`G
M("AW:&5R92!A<'`@:7,@86YY($AO<F1E(&%P<&QI8V%T:6]N(&YA;64L(&QI
M:V4@)VEM<"<I(&AO;VMS('1H870@87)E"B`J(&%P<&QI8V%T:6]N('-P96-I
M9FEC+@H@*@H@*B!3;RP@82!H;V]K('1O('-E="!T:&4@<')E9F5R96YC92`G
M=&AE;64G('=O=6QD(&)E(&YA;65D"B`J(")?<')E9G-?:&]O:U]T:&5M92(N
M"B`J"B`J($Y/5$4@,3H@2&%V:6YG(&$@:&]O:R!F=6YC=&EO;B!I;B!T:&ES
M(&9I;&4@9&]E<R!.3U0@;65A;B!T:&%T('1H92!H;V]K"B`J('=I;&P@875T
M;VUA=&EC86QL>2!B92!U<V5D+B!93U4@35535"!E;F%B;&4@=&AE(&AO;VLN
M($9O<B!P<F5F97)E;F-E<RP@<V5T"B`J("=H;V]K)R`]/B!T<G5E(&EN('1H
M870@<')E9F5R96YC97,@871T<FEB=71E<SL@9F]R(&]T:&5R(&AO;VMS+"!T
M:&5R92!W:6QL"B`J(&)E(&$@8V]N9FEG=7)A=&EO;B!O<'1I;VX@:6X@96%C
M:"!A<'!L:6-A=&EO;B=S(&-O;F8N<&AP(&9I;&4@<W5C:"!A<PH@*B`D8V]N
M9ELG:&]O:W,G75LG:&]O:VYA;64G72!W:&EC:"!M=7-T(&)E('-E="!T;R!T
M<G5E+@H@*@H@*B!.3U1%(#(Z(%!R969E<F5N8V5S(&AO;VMS(&%R92!/3DQ9
M(&5X96-U=&5D(&]N(&QO9VEN+B!0<F5F97)E;F-E<R!A<F4*("H@8V%C:&5D
M(&1U<FEN9R!A('5S97)S('-E<W-I;VX@86YD+"!T;R!A=F]I9"!U;FYE8V5S
M<V%R>2!O=F5R:&5A9"!E=F5R>2!T:6UE"B`J(&$@<')E9F5R96YC92!I<R!A
M8V-E<W-E9"P@=&AE(')E<W5L=',@;V8@:&]O:W,@87)E(&-A8VAE9"!A<R!W
M96QL+B!4:&ES"B`J(&QE861S('1O("XN+@H@*@H@*B!.3U1%(#,Z($%N>2!P
M<F5F97)E;F-E('1H870@:7,@3D]4($Q/0TM%1"P@=&AA="!I<R!S970@8GD@
M82!H;V]K+"!724Q,($)%"B`J(%-!5D5$(%=)5$@@5$A!5"!604Q512X@5&AI
M<R!M96%N<R!S979E<F%L('1H:6YG<SH*("H@,2D@57-E<G,@=VEL;"!G970@
M=&AE(')E<W5L=',@;V8@=&AE(&AO;VL@<V5T(&9O<B!T:&5M(&EN('1H96ER
M"B`J("`@('!R969E<F5N8V5S+@H@*B`R*2!">2!V:7)T=64@;V8@=&AI<RP@
M=&AE(&YE>'0@=&EM92!T:&5Y(&QO9R!I;B!A;F0@;&]A9"!T:&5I<@H@*B`@
M("!P<F5F97)E;F-E<RP@=&AE(&AO;VL@=VEL;"!.3U0@8F4@8V%L;&5D+"!B
M96-A=7-E(&EN('1H96ER(&QA<W0@<V5S<VEO;BP*("H@("`@=V4@<V%V960@
M=&AE(')E<W5L=',@;V8@=&AE(&AO;VL@9F]R('1H96TN($AO=V5V97(L(&EF
M('1H92!P<F5F97)E;F-E(&ES"B`J("`@(&QO8VME9"P@=&AE(')E<W5L="!O
M9B!T:&4@:&]O:R!W:6QL(&YE=F5R(&)E('-A=F5D+@H@*@H@*B`D2&]R9&4Z
M(&AO<F1E+V-O;F9I9R]H;V]K<RYP:'`N9&ES="QV(#$N-S,N-BXQ,2`R,#`V
M+S`S+S(W(#`X.C`Q.C(Q(&IA;B!%>'`@)`H@*B\*"B\O($5X86UP;&4@=&AE
M;64@:&]O:R!F=6YC=&EO;BX@5&AI<R!S:&]W<R!H;W<@>6]U(&-A;B!A8V-E
M<W,@=&AI;F=S(&QI:V4@=&AE"B\O(&-U<G)E;G1L>2!L;V=G960@:6X@=7-E
M<BP@9VQO8F%L('9A<FEA8FQE<RP@<V5R=F5R(&-O;F9I9RP@971C+B!)="!I
M<VXG="P*+R\@:&]W979E<BP@<V]M971H:6YG('EO=2!P<F]B86)L>2!W86YT
M('1O(&%C='5A;&QY('5S92!I;B!P<F]D=6-T:6]N+"!B>0HO+R!V:7)T=64@
M;V8@9&5M;VYS=')A=&EN9R!A;&P@=&AO<V4N(#HI"@HO+R!I9B`H(69U;F-T
M:6]N7V5X:7-T<R@G7W!R969S7VAO;VM?=&AE;64G*2D@>PHO+R`@("`@9G5N
M8W1I;VX@7W!R969S7VAO;VM?=&AE;64H)'5S97)N86UE(#T@;G5L;"D*+R\@
M("`@('L*+R\@("`@("`@("!I9B`H075T:#HZ9V5T075T:"@I("$]("=C:'5C
M:R<I('L*+R\@("`@("`@("`@("`@<F5T=7)N("=M;WII;&QA)SL*+R\@("`@
M("`@("!]"B\O"B\O("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*+R\@("`@
M("`@("!S=VET8V@@*"1R96=I<W1R>2T^9V5T07!P*"DI('L*+R\@("`@("`@
M("!C87-E("=I;7`G.@HO+R`@("`@("`@("`@("!R971U<FX@)V)R;W=N)SL*
M+R\*+R\@("`@("`@("!C87-E("=T=7)B82<Z"B\O("`@("`@("`@("`@(')E
M='5R;B`G;W)A;F=E)SL*+R\*+R\@("`@("`@("!C87-E("=K<F]N;VQI=&@G
M.@HO+R`@("`@("`@("`@("!R971U<FX@)V=R965N)SL*+R\*+R\@("`@("`@
M("!D969A=6QT.@HO+R`@("`@("`@("`@("!R971U<FX@)R<["B\O("`@("`@
M("`@?0HO+R`@("`@?0HO+R!]"@HO+R!%>&%M<&QE(&9R;VU?861D<B!H;V]K
M(&9U;F-T:6]N+B!42$E3($953D-424].($%34U5-15,@5$A!5"!93U4@05)%
M(%5324Y'"B\O($%.($Q$05`@4T525D52(&%N9"!T:&%T('EO=7(@+V5T8R]L
M9&%P+F-O;F8@;W(@=VAE<F5V97(@:70@:7,@8V]R<F5C=&QY('-E=`HO+R!T
M;R!A('9A;&ED(&AO<W0N"B\O"B\O(%EO=2!G970@<&%S<V5D($Y/5$A)3D<[
M('EO=2!A<F4@<F5S<&]N<VEB;&4@9F]R(&)R:6YG:6YG(&EN('1O('-C;W!E
M(&%N>0HO+R!I;F9O<FUA=&EO;B!Y;W4@;F5E9"X@66]U(&-A;B`B9VQO8F%L
M(B!A;GET:&EN9R!E;'-E('EO=2!N965D+B!2971U<FX@86X*+R\@861D<F5S
M<R`M(&5I=&AE<B!J=7-T('1H92!U<V5R0"!S:61E(&]R(&$@9G5L;"!A9&1R
M97-S("T@86YD(&ET('=I;&P@8F4*+R\@=7-E9"X*+R\*+R\@268@>6]U('=A
M;G0@=&\@=7-E('1H:7,@8V]D92!Y;W4@=VEL;"!N965D('1O('5N8V]M;65N
M="!I="!B96QO=RX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<')E9G-?
M:&]O:U]F<F]M7V%D9'(G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!R969S7VAO
M;VM?9G)O;5]A9&1R*"1N86UE(#T@;G5L;"D*+R\@("`@('L*+R\@("`@("`@
M("!I9B`H:7-?;G5L;"@D;F%M92DI('L*+R\@("`@("`@("`@("`@)&YA;64@
M/2!!=71H.CIG971!=71H*"D["B\O("`@("`@("`@?0HO+R`@("`@("`@(&EF
M("@A96UP='DH)&YA;64I*2!["B\O("`@("`@("`@("`@("1B87-E7V-O;G1E
M>'0@/2`G;SUM>6]R9R<["B\O("`@("`@("`@("`@("1S8V]P92`]("=S=6(G
M.PHO+PHO+R`@("`@("`@("`@("`O+R!9;W4@=VEL;"!P<F]B86)L>2!N965D
M('1O(')E<&QA8V4@8V0]('=I=&@@=6ED/3L@=&AI<PHO+R`@("`@("`@("`@
M("`O+R!S>6YT87@@:7,@9F]R($YE='=A<F4@-2XQ(&YL9&%P+@HO+R`@("`@
M("`@("`@("`D8VUD("`]("<O=7-R+V)I;B]L9&%P<V5A<F-H("UB("<@+B`D
M8F%S95]C;VYT97AT("X@)R`M<R`G("X@)'-C;W!E("X@)R!C;CTG.PHO+R`@
M("`@("`@("`@("`D8VUD("X](&5S8V%P95-H96QL0VUD*$%U=&@Z.F=E=$%U
M=&@H*2D["B\O("`@("`@("`@("`@("1C;60@+CT@)R!\("]U<W(O8FEN+V=R
M97`@;6%I;"!\("]U<W(O8FEN+V%W:R!<)WMP<FEN="`D,GU<)R<["B\O("`@
M("`@("`@("`@("1M86EL<R`](&`D8VUD8#L*+R\@("`@("`@("`@("`@)&UA
M:6Q?87)R87D@/2!E>'!L;V1E*")<;B(L("1M86EL<RD["B\O"B\O("`@("`@
M("`@("`@("\O(%-E;F0@8F%C:R!T:&4@9FER<W0@96UA:6P@9F]U;F0L(&YO
M="!T:&4@=VAO;&4@;&ES="X*+R\@("`@("`@("`@("`@)&UA:6P@/2`D;6%I
M;%]A<G)A>5LG,"==.PHO+PHO+R`@("`@("`@("`@("`O+R!)9B!N;R!E;6%I
M;"!A9&1R97-S(&ES(&9O=6YD+"!T:&5N('1H92!L;V=I;B!N86UE('=I;&P*
M+R\@("`@("`@("`@("`@+R\@8F4@=7-E9"X*+R\@("`@("`@("`@("`@<F5T
M=7)N("AE;7!T>2@D;6%I;"D@/R`G)R`Z("1M86EL*3L*+R\@("`@("`@("!]
M"B\O"B\O("`@("`@("`@<F5T=7)N("<G.PHO+R`@("`@?0HO+R!]"@HO+R!(
M97)E(&ES(&%N;W1H97(@=V%Y(&]F(&1O:6YG('1H92!S86UE('1H:6YG+@H*
M+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7V9R;VU?861D
M<B<I*2!["B\O("`@("!F=6YC=&EO;B!?<')E9G-?:&]O:U]F<F]M7V%D9'(H
M)'5S97(@/2!N=6QL*0HO+R`@("`@>PHO+R`@("`@("`@("1L9&%P4V5R=F5R
M(#T@)S$W,BXS,2XP+C(S-B<["B\O("`@("`@("`@)&QD87!0;W)T(#T@)S,X
M.2<["B\O("`@("`@("`@)'-E87)C:$)A<V4@/2`G;SUM>6]R9R<["B\O"B\O
M("`@("`@("`@)&1S(#T@0&QD87!?8V]N;F5C="@D;&1A<%-E<G9E<BP@)&QD
M87!0;W)T*3L*+R\*+R\@("`@("`@("!I9B`H:7-?;G5L;"@D=7-E<BDI('L*
M+R\@("`@("`@("`@("`@)'5S97(@/2!!=71H.CIG971!=71H*"D["B\O("`@
M("`@("`@?0HO+PHO+R`@("`@("`@("\O(%EO=2!W:6QL('!R;V)A8FQY(&YE
M960@=&\@<F5P;&%C92!C;CT@=VET:"!U:60].R!T:&ES"B\O("`@("`@("`@
M+R\@<WEN=&%X(&ES(&9O<B!.971W87)E(#4N,2!N;&1A<"X*+R\@("`@("`@
M("`D<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A<F-H*"1D<RP@)'-E87)C:$)A
M<V4L("=C;CTG("X@)'5S97(I.PHO+R`@("`@("`@("1I;F9O<FUA=&EO;B`]
M($!L9&%P7V=E=%]E;G1R:65S*"1D<RP@)'-E87)C:%)E<W5L="D["B\O("`@
M("`@("`@:68@*"1I;F9O<FUA=&EO;ELP75LG;6%I;"==6S!=("$]("<G*2![
M"B\O("`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T:6]N6S!=6R=M86EL
M)UU;,%T["B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@)&YA
M;64@/2`D:6YF;W)M871I;VY;,%U;)V-N)UU;,%T["B\O("`@("`@("`@?0HO
M+PHO+R`@("`@("`@(&QD87!?8VQO<V4H)&1S*3L*+R\*+R\@("`@("`@("!R
M971U<FX@*&5M<'1Y*"1N86UE*2`_("1U<V5R(#H@)&YA;64I.PHO+R`@("`@
M?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@9G5L;&YA;64@:&]O:R!F
M=6YC=&EO;B!T;R!S970@=&AE(&9U;&QN86UE(&9R;VT@=&AE($=%0T]3"B\O
M(&EN9F]R;6%T:6]N(&EN('1H92!P87-S=V0@9FEL92X*"B\O(&EF("@A9G5N
M8W1I;VY?97AI<W1S*"=?<')E9G-?:&]O:U]F=6QL;F%M92<I*2!["B\O("`@
M("!F=6YC=&EO;B!?<')E9G-?:&]O:U]F=6QL;F%M92@D=7-E<B`](&YU;&PI
M"B\O("`@("!["B\O("`@("`@("`@:68@*&ES7VYU;&PH)'5S97(I*2!["B\O
M("`@("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T0F%R94%U=&@H*3L*+R\@
M("`@("`@("!]"B\O("`@("`@("`@)&%R<F%Y(#T@<&]S:7A?9V5T<'=N86TH
M)'5S97(I.PHO+R`@("`@("`@("1G96-O<U]A<G)A>2`](&5X<&QO9&4H)RPG
M+"`D87)R87E;)V=E8V]S)UTI.PHO+R`@("`@("`@(')E='5R;B`H96UP='DH
M)&=E8V]S7V%R<F%Y*2`_("1U<V5R(#H@)&=E8V]S7V%R<F%Y6S!=*3L*+R\@
M("`@('T*+R\@?0H*+R\@5&AI<R!I<R!A;F]T:&5R(&5X86UP;&4@;V8@:&]W
M('1O(&=E="!T:&4@=7-E<B=S(&9U;&P@;F%M92P@:6X@=&AI<R!C87-E"B\O
M(&9R;VT@86X@;&1A<"!S97)V97(N($EN('1H:7,@97AA;7!L92!W92!L;V]K
M(&EF(&$@4W!A;FES:"!N86UE(&5X:7-T<R!A;F0*+R\@<F5T=7)N('1H:7,@
M;W(@=&AE('-T86YD87)D("=C;B<@96YT<GD@:68@;F]T+@H*+R\@:68@*"%F
M=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7V9U;&QN86UE)RDI('L*+R\@
M("`@(&9U;F-T:6]N(%]P<F5F<U]H;V]K7V9U;&QN86UE*"1U<V5R(#T@;G5L
M;"D*+R\@("`@('L*+R\@("`@("`@("`D;&1A<%-E<G9E<B`]("=L9&%P+F5X
M86UP;&4N8V]M)SL*+R\@("`@("`@("`D;&1A<%!O<G0@/2`G,S@Y)SL*+R\@
M("`@("`@("`D<V5A<F-H0F%S92`]("=O=3UP96]P;&4L;SUE>&%M<&QE+F-O
M;2<["B\O("`@("`@("`@)&QD87!C:&%R<V5T(#T@)W5T9BTX)SL*+R\@("`@
M("`@("`D;W5T<'5T8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PHO+PHO
M+R`@("`@("`@("1D<R`]($!L9&%P7V-O;FYE8W0H)&QD87!397)V97(L("1L
M9&%P4&]R="D["B\O"B\O("`@("`@("`@:68@*&ES7VYU;&PH)'5S97(I*2![
M"B\O("`@("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T:"@I.PHO+R`@
M("`@("`@('T*+R\@("`@("`@("`D<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A
M<F-H*"1D<RP@)'-E87)C:$)A<V4L("=U:60])R`N("1U<V5R*3L*+R\@("`@
M("`@("`D:6YF;W)M871I;VX@/2!`;&1A<%]G971?96YT<FEE<R@D9',L("1S
M96%R8VA297-U;'0I.PHO+R`@("`@("`@(&EF("@D:6YF;W)M871I;VY;,%U;
M)V-N.VQA;F<M97,G75LP72`A/2`G)RD@>PHO+R`@("`@("`@("`@("`D;F%M
M92`]("1I;F9O<FUA=&EO;ELP75LG8VX[;&%N9RUE<R==6S!=.PHO+R`@("`@
M("`@('T@96QS92!["B\O("`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T
M:6]N6S!=6R=C;B==6S!=.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!L
M9&%P7V-L;W-E*"1D<RD["B\O"B\O("`@("`@("`@)&YA;64@/2!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1N86UE+"`D;&1A<&-H87)S970L("1O=71P=71C
M:&%R<V5T*3L*+R\@("`@("`@("!R971U<FX@*&5M<'1Y*"1N86UE*2`_("1U
M<V5R(#H@)&YA;64I.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X
M86UP;&4@<VEG;F%T=7)E(&AO;VL@9G5N8W1I;VX@=&\@<V5T('1H92!S:6=N
M871U<F4@9G)O;2!T:&4*+R\@<WES=&5M('1A9VQI;F5S(&9I;&4[('1H92!S
M=')I;F<@(B5404<E(B`H:68@<')E<V5N="!I;B!A('5S97(G<R!S:6=N871U
M<F4I"B\O('=I;&P@8F4@<F5P;&%C960@8GD@=&AE(&-O;G1E;G0@;V8@=&AE
M(&9I;&4@(B]U<W(O<VAA<F4O=&%G;&EN92(@*&=E;F5R871E9`HO+R!B>2!T
M:&4@(E1A4E0B('5T:6QI='DI+@HO+PHO+R!.;W1I8V4@:&]W('=E(&=L;V)A
M;"!I;B!T:&4@)'!R969S(&%R<F%Y('1O(&=E="!T:&4@=7-E<B=S(&-U<G)E
M;G0*+R\@<VEG;F%T=7)E+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P
M<F5F<U]H;V]K7W-I9VYA='5R92<I*2!["B\O("`@("!F=6YC=&EO;B!?<')E
M9G-?:&]O:U]S:6=N871U<F4H)'5S97)N86UE(#T@;G5L;"D*+R\@("`@('L*
M+R\@("`@("`@("`D<VEG(#T@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E
M*"=S:6=N871U<F4G*3L*+R\@("`@("`@("!I9B`H<')E9U]M871C:"@G+R54
M04<E+R<L("1S:6<I*2!["B\O("`@("`@("`@("`@("1T86<@/2!@8V%T("]U
M<W(O<VAA<F4O=&%G;&EN96`["B\O("`@("`@("`@("`@("1S:6<@/2!P<F5G
M7W)E<&QA8V4H)WPE5$%')7PG+"`D=&%G+"`D<VEG*3L*+R\@("`@("`@("!]
M"B\O("`@("`@("`@<F5T=7)N("1S:6<["B\O("`@("!]"B\O('T*"B\O($E%
M(&]N($UA8R!H86YG<R!W:&5N('1H97)E(&%R92!S979E<F%L(&EC;VYS('1O
M(&)E(&QO861E9"X@070@;&5A<W0@;VX@<V]M90HO+R!S>7-T96US+B!4:&ES
M(&AO;VL@9&ES86)L97,@=&AE('-H;W=?:6-O;G,@<')E9F5R96YC92!F<F]M
M($MR;VYO;FQI=&@@9F]R"B\O('1H97-E(&)R;W=S97)S+@H*+R\@:68@*"%F
M=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7W-H;W=?:6-O;G,G*2D@>PHO
M+R`@("`@9G5N8W1I;VX@7W!R969S7VAO;VM?<VAO=U]I8V]N<R@I"B\O("`@
M("!["B\O("`@("`@("`@9VQO8F%L("1B<F]W<V5R.PHO+R`@("`@("`@(&EF
M("@D8G)O=W-E<BT^9V5T4&QA=&9O<FTH*2`]/2`G;6%C)R`F)@HO+R`@("`@
M("`@("`@("`D8G)O=W-E<BT^9V5T0G)O=W-E<B@I(#T]("=M<VEE)RD@>PHO
M+R`@("`@("`@("`@("!R971U<FX@9F%L<V4["B\O("`@("`@("`@?2!E;'-E
M('L*+R\@("`@("`@("`@("`@<F5T=7)N('1R=64["B\O("`@("`@("`@?0HO
M+R`@("`@?0HO+R!]"@HO+R!4:&ES(&AO;VL@:7,@8V%L;&5D('=H96X@82!U
M<V5R('-U8FUI=',@82!S:6=N=7`@<F5Q=65S="X@($ET(&%L;&]W<PHO+R!A
M(&-H86YC92!T;R!A;'1E<B!O<B!V86QI9&%T92!T:&4@9&%T82!S=6)M:71T
M960@8GD@82!U<V5R(&)E9F]R92!A;GD*+R\@871T96UP=',@87)E(&UA9&4@
M=&\@861D('1H96T@=&\@=&AE('-Y<W1E;2X*"B\O(&EF("@A9G5N8W1I;VY?
M97AI<W1S*"=?:&]R9&5?:&]O:U]S:6=N=7!?<')E<')O8V5S<R<I*2!["B\O
M("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?<')E<')O8V5S<R@D
M:6YF;RD@>PHO+R`@("`@("`@("1I;F9O6R=U<V5R7VYA;64G72`](%-T<FEN
M9SHZ;&]W97(H)&EN9F];)W5S97)?;F%M92==*3L*+R\@("`@("`@("!R971U
M<FX@)&EN9F\["B\O("`@("!]"B\O('T*"B\O(%1H:7,@:&]O:R!I<R!C86QL
M960@=VAE;B!A('-I9VYU<"!I<R!Q=65U960@9F]R(&%D;6EN:7-T<F%T:79E
M(&%P<')O=F%L+@HO+R!4:&ES(&5X86UP;&4@<V5N9',@82!N;W1I9FEC871I
M;VX@;65S<V%G92!T;R!T:&4@=V5B('-E<G9E<@HO+R!A9&UI;FES=')A=&]R
M)W,@92UM86EL(&%D9')E<W,N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G
M7VAO<F1E7VAO;VM?<VEG;G5P7W%U975E9"<I*2!["B\O("`@("!F=6YC=&EO
M;B!?:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D7W=A;&MD871A*"1F:65L9',L
M("1D871A*0HO+R`@("`@>PHO+R`@("`@("`@("1M<V<@/2`G)SL*+R\@("`@
M("`@("!F;W)E86-H("@D9&%T82!A<R`D9FEE;&0@/3X@)'9A;'5E*2!["B\O
M("`@("`@("`@("`@(&EF("@D9FEE;&0@/3T@)W!A<W-W;W)D)R!\?"`D9FEE
M;&0@/3T@)W5R;"<I('L*+R\@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PHO
M+R`@("`@("`@("`@("!]"B\O"B\O("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=F%L=64I*2!["B\O("`@("`@("`@("`@("`@("`D;7-G("X](%]H;W)D
M95]H;V]K7W-I9VYU<%]Q=65U961?=V%L:V1A=&$H)&9I96QD<RP@)'9A;'5E
M*3L*+R\@("`@("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@("`@
M("1F:65L9"`](&ES<V5T*"1F:65L9'-;)&9I96QD75LG;&%B96PG72D@/PHO
M+R`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD<ULD9FEE;&1=6R=L
M86)E;"==(#H@)&9I96QD.PHO+R`@("`@("`@("`@("`@("`@)&US9R`N/2`B
M)&9I96QD.B`D=F%L=65<;B(["B\O("`@("`@("`@("`@('T*+R\@("`@("`@
M("!]"B\O("`@("`@("`@<F5T=7)N("1M<V<["B\O("`@("!]"B\O"B\O("`@
M("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D*"1U<V5R240L
M("1D871A*0HO+R`@("`@>PHO+R`@("`@("`@(')E<75I<F5?;VYC92`G36%I
M;"YP:'`G.PHO+R`@("`@("`@(&=L;V)A;"`D8V]N9BP@)')E9VES=')Y.PHO
M+PHO+R`@("`@("`@("1H96%D97)S(#T@87)R87DH"B\O("`@("`@("`@("`@
M("=4;R<@("`@("`]/B`D7U-%4E9%4ELG4T525D527T%$34E.)UTL"B\O("`@
M("`@("`@("`@("=&<F]M)R`@("`]/B`D7U-%4E9%4ELG4T525D527T%$34E.
M)UTL"B\O("`@("`@("`@("`@("=3=6)J96-T)R`]/B`G3F5W("<@+B`D<F5G
M:7-T<GDM/F=E="@G;F%M92<L("=H;W)D92<I("X@)R!3:6=N=7`G"B\O("`@
M("`@("`@*3L*+R\*+R\@("`@("`@("`D97AT<F%&:65L9',@/2!(;W)D93HZ
M8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]G971E>'1R82<I.PHO+PHO
M+R`@("`@("`@("1M<V<@(#T@7R@B02!N97<@<VEG;G5P(&AA<R!B965N(')E
M8V5I=F5D(&%N9"!I<R!A=V%I=&EN9R!Y;W5R(&%P<')O=F%L+B(I.PHO+R`@
M("`@("`@("1M<V<@+CT@(EQN7&XB.PHO+R`@("`@("`@("1M<V<@+CT@7VAO
M<F1E7VAO;VM?<VEG;G5P7W%U975E9%]W86QK9&%T82@D97AT<F%&:65L9',L
M("1D871A*3L*+R\@("`@("`@("`D;7-G("X](")<;B(["B\O("`@("`@("`@
M)&US9R`N/2!S<')I;G1F*%\H(EEO=2!C86X@87!P<F]V92!T:&ES('-I9VYU
M<"!A="`E<R(I+"!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W5S97(N
M<&AP)RP@=')U92P@+3$I*3L*+R\*+R\@("`@("`@("`D;6%I;&5R(#T@36%I
M;#HZ9F%C=&]R>2@D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G72P@)&-O;F9;)VUA
M:6QE<B==6R=P87)A;7,G72D["B\O("`@("`@("`@<F5T=7)N("1M86EL97(M
M/G-E;F0H)%]315)615);)U-%4E9%4E]!1$U)3B==+"`D:&5A9&5R<RP@)&US
M9RD["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?:&]R
M9&5?:&]O:U]S:6=N=7!?9V5T97AT<F$@9G5N8W1I;VXN($ET(')E='5R;G,@
M86YY"B\O(&5X=')A(&9I96QD<R!W:&EC:"!N965D('1O(&)E(&9I;&QE9"!I
M;B!W:&5N(&$@;F]N(')E9VES=&5R960@=7-E<B!W:7-H97,*+R\@=&\@<VEG
M;B!U<"X*+R\@5&AE(&5X86UP;&4@:&5R92!T86ME<R!T:&4@:'EP;W1H971I
M8V%L(&-A<V4@=VAE<F4@=V4@=V]U;&0@=V%N="!T;R!S=&]R90HO+R!E>'1R
M82!I;F9O<FUA=&EO;B!A8F]U="!A('5S97(@:6YT;R!A('1U<F)A('-Q;"!A
M9&1R97-S(&)O;VLN($%L;"!T:&ES"B\O(&9U;F-T:6]N(&1O97,@=&AE;B!I
M<R!T;R!I;F-L=61E('1H92!A='1R:6)U=&5S+G!H<"!F:6QE(&9R;VT@=&AE
M('1U<F)A"B\O(&-O;F9I9R!D:7)E8W1O<GD@86YD(')E='5R;B!T:&4@)&%T
M=')I8G5T97,@87)R87DN"B\O($]T:&5R=VES92!A;GD@<W1R=6-T=7)E('1H
M870@=V]U;&0@<F5T=7)N(&%N(&%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9PHO
M+R!S>6YT87@@=V]U;&0@8F4@=F%L:60Z"B\O("`@)'-O;65A<G)A>5LG<V]M
M969I96QD;F%M92==(#T@87)R87DH+BXN"B\O("`@("`@;&%B96P@("`@+2!T
M:&4@=&5X="!T:&%T('1H92!U<V5R('=I;&P@<V5E(&%T=&%C:&5D('1O('1H
M:7,@9FEE;&0*+R\@("`@("!T>7!E("`@("`M(&%N>2!A;&QO=V5D($AO<F1E
M7T9O<FT@9FEE;&0@='EP90HO+R`@("`@('!A<F%M<R`@("T@86YY(&%L;&]W
M960@<&%R86UE=&5R('1O($AO<F1E7T9O<FT@9FEE;&0@='EP97,*+R\@("`@
M("!R97%U:7)E9"`M(&)O;VQE86XL('1R=64@;W(@9F%L<V4@=VAE=&AE<B!T
M:&ES(&9I96QD(&ES(&UA;F1A=&]R>0HO+R`@("`@(')E861O;FQY("T@8F]O
M;&5A;BP@=')U92!O<B!F86QS92!W:&5T:&5R('1H:7,@961I=&%B;&4*+R\@
M("`@("!D97-C("`@("`M(&%N>2!H96QP('1E>'0@871T86-H960@=&\@=&AE
M(&9I96QD"B\O($Y/5$4Z(%EO=2!$3R!.145$(%1U<F)A('1O(&)E(&-O<G)E
M8W1L>2!I;G-T86QL960@8F5F;W)E('EO=2!C86X@=7-E('1H:7,*+R\@97AA
M;7!L92!B96QO=RX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?
M:&]O:U]S:6=N=7!?9V5T97AT<F$G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO
M<F1E7VAO;VM?<VEG;G5P7V=E=&5X=')A*"D*+R\@("`@('L*+R\@("`@("`@
M("!G;&]B86P@)')E9VES=')Y.PHO+R`@("`@("`@(')E<75I<F4@)')E9VES
M=')Y+3YG970H)V9I;&5R;V]T)RP@)W1U<F)A)RD@+B`G+V-O;F9I9R]A='1R
M:6)U=&5S+G!H<"<["B\O("`@("`@("`@<F5T=7)N("1A='1R:6)U=&5S.PHO
M+R`@("`@?0HO+R!]"@HO+R!&;VQL;W=I;F<@;VX@9G)O;2!T:&4@97AA;7!L
M92!I;B!T:&4@86)O=F4@9G5N8W1I;VXL('1H:7,@:7,@:&]W(&$@<V%M<&QE
M"B\O(%]H;W)D95]H;V]K7W-I9VYU<%]A9&1E>'1R82!F=6YC=&EO;B!W;W5L
M9"!L;V]K(&QI:V4N"B\O($AE<F4@=V4@8V]N;F5C="!T;R!T:&4@9&%T86)A
M<V4@=7-I;F<@=&AE('-Q;"!P87)A;65T97)S(&-O;F9I9W5R960@:6X*+R\@
M)&-O;F8@86YD('-T;W)E('1H92!E>'1R82!F:65L9',@:6X@='5R8F%?;V)J
M96-T<RP@=7-I;F<@=&AE("1U<V5R260@87,@=&AE"B\O(&ME>2!F;W(@=&AE
M(&]B:F5C="!A;F0@=F%L=65S(&9R;VT@=&AE("1E>'1R82!A<G)A>2X*+R\@
M66]U(&-O=6QD(&-R96%T92!Y;W5R(&]W;B!S<6P@<WEN=&%X(&]R(&-O9&4@
M=&\@<W1O<F4@=&AI<R!I;B!W:&EC:&5V97(*+R\@8F%C:V5N9"!Y;W4@<F5Q
M=6ER92X*+R\@3D]413H@66]U($1/($Y%140@5'5R8F$@=&\@8F4@8V]R<F5C
M=&QY(&EN<W1A;&QE9"!B969O<F4@>6]U(&-A;B!U<V4@=&AI<PHO+R!E>&%M
M<&QE(&)E;&]W+B!)="!A;'-O(&%S<W5M97,@=&AA="!Y;W4@87)E('5S:6YG
M(&%N(%-13"!B86-K96YD+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H
M;W)D95]H;V]K7W-I9VYU<%]A9&1E>'1R82<I*2!["B\O("`@("!F=6YC=&EO
M;B!?:&]R9&5?:&]O:U]S:6=N=7!?861D97AT<F$H)'5S97))1"P@)&5X=')A
M*0HO+R`@("`@>PHO+R`@("`@("`@(&=L;V)A;"`D8V]N9CL*+R\*+R\@("`@
M("`@("!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B\O("`@("`@("`@)%]D8B`]
M("9$0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTL('1R=64I.PHO+PHO+R`@("`@
M("`@("1F:65L9',@/2!A<G)A>2@I.PHO+R`@("`@("`@("1V86QU97,@/2!A
M<G)A>2@I.PHO+R`@("`@("`@(&9O<F5A8V@@*"1E>'1R82!A<R`D9FEE;&0@
M/3X@)'9A;'5E*2!["B\O("`@("`@("`@("`@("1F:65L9'-;72`]("=O8FIE
M8W1?)R`N(%-T<FEN9SHZ;&]W97(H)&9I96QD*3L*+R\@("`@("`@("`@("`@
M)'9A;'5E<UM=(#T@)%]D8BT^<75O=&4H4W1R:6YG.CIC;VYV97)T0VAA<G-E
M="@D=F%L=64L($Y,4SHZ9V5T0VAA<G-E="@I+"`D8V]N9ELG<W%L)UU;)V-H
M87)S970G72DI.PHO+R`@("`@("`@('T*+R\@("`@("`@("`D9FEE;&1S6UT@
M/2`G;V)J96-T7VED)SL*+R\@("`@("`@("`D=F%L=65S6UT@/2`D7V1B+3YQ
M=6]T92@D=7-E<DE$*3L*+R\*+R\@("`@("`@("`D<75E<GD@(#T@)TE.4T52
M5"!)3E1/('1U<F)A7V]B:F5C=',@*"!O=VYE<E]I9"P@)R`N(&EM<&QO9&4H
M)RP@)RP@)&9I96QD<RD@+B`G*2<["B\O("`@("`@("`@)'%U97)Y("X]("<@
M5D%,5453("@@7"=A9&UI;EPG+"`G("X@:6UP;&]D92@G+"`G+"`D=F%L=65S
M*2`N("<I)SL*+R\@("`@("`@("`D<F5S=6QT(#T@)%]D8BT^<75E<GDH)'%U
M97)Y*3L*+R\*+R\@("`@("`@("!R971U<FX@:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I(#\@)')E<W5L="`Z('1R=64["B\O("`@("!]"B\O('T*"B\O
M($AE<F4@:7,@86X@97AA;7!L92!?:&]R9&5?:&]O:U]P<F5A=71H96YT:6-A
M=&4@=&AA="!M86ME($AO<F1E(')E<W!E8W0@=&AE"B\O(%5N:7@@8V]N=F5N
M=&EO;B!O9B!N;W0@86QL;W=I;F<@;&]G:6X@=VAE;B!A(&9I;&4@;F%M960@
M+V5T8R]N;VQO9VEN(&5X:7-T+@HO+R!4:&ES(&9U;F-T:6]N(&=E="!P87-S
M960@=&AE('5S97)N86UE+"!C<F5D96YT:6%L(&%N9"!R96%L;2!I;F9O<FUA
M=&EO;B!B=70*+R\@=&AE>2!A<F4@;F]T('5S960@:6X@=&AI<R!E>&%M<&QE
M+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W!R96%U
M=&AE;G1I8V%T92<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]P
M<F5A=71H96YT:6-A=&4H)'5S97))1"P@)&-R961E;G1I86PL("1R96%L;2D*
M+R\@("`@('L*+R\@("`@("`@("!R971U<FX@(69I;&5?97AI<W1S*"<O971C
M+VYO;&]G:6XG*3L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M
M<&QE(&]F('9A;&ED871I;F<@=&AE('5S97(G<R!R:6=H="!T;R!L;V=I;B!T
M;R!(;W)D92!B>0HO+R!C;VYS=6QT:6YG(&=R;W5P(&UE;6)E<G-H:7`@:6X@
M86X@3$1!4"!D:7)E8W1O<GDN("!4:&%T('=A>2P@:68@>6]U<B!(;W)D90HO
M+R!I;G-T86QL871I;VX@:7,@8V]N9FEG=7)E9"!T;R!A=71H96YT:6-A=&4@
M86=A:6YS="!)35`@=VAI8V@@:6X@='5R;@HO+R!A=71H96YT:6-A=&4@=FEA
M($E-05`L(&ET(&ES('-T:6QL('!O<W-I8FQE('1O(&QI;6ET(&%C8V5S<R!T
M;R!(;W)D92!B>0HO+R!G<F]U<"!M96UB97)S:&EP+B`@5&AE(&9O;&QO=VEN
M9R!E>&%M<&QE(&AA9"!B965N(&UA9&4@=VET:"!A;B!-4R!!8W1I=F4*+R\@
M1&ER96-T;W)Y(&EN(&UI;F0N("!.;W1E('1H870@:68@=&AE($Q$05`@9&ER
M96-T;W)Y(&ES('5N879A:6QA8FQE(&]R('-O;64*+R\@;W1H97(@97)R;W(@
M;V-C=7(L(&%U=&AE;G1I8V%T:6]N('=I;&P@9F%I;"X*"B\O(&EF("@A9G5N
M8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P;W-T875T:&5N=&EC871E)RDI
M('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W!O<W1A=71H96YT:6-A
M=&4H)'5S97))1"P@)&-R961E;G1I86PL("1R96%L;2D*+R\@("`@('L*+R\@
M("`@("`@("`D;&1A<%-E<G9E<B`]("=A9"YE>&%M<&QE+F-O;2<["B\O("`@
M("`@("`@)&QD87!0;W)T(#T@)S,X.2<["B\O("`@("`@("`@+R\@3F]T92!T
M:&%T(&-R961E;G1I86P@:7,@<V5N="!P;&%I;BUT97AT(&EN('1H:7,@8V%S
M92P@<V\@9&]N)W0@=7-E"B\O("`@("`@("`@+R\@<')I=FEL96=E9"!A8V-O
M=6YT(&AE<F4@;W(@<V5T=7`@4U-,("AB>2!U<VEN9R!P;W)T(#8S-B!A8F]V
M92DN"B\O("`@("`@("`@)&)I;F1D;B`]("=C;CU7:71H;W5T4')I=FEL96=E
M+&1C/75L879A;"UD978L9&,]8V$G.PHO+R`@("`@("`@("1B:6YD<'<@/2`G
M4F5M96UB97(@=&AI<R!I<R!S96YT(&EN('1H92!C;&5A<B!U;FQE<W,@4U-,
M(&ES('5S960G.PHO+R`@("`@("`@("1S96%R8VA"87-E(#T@)V]U/5!E;W!L
M92QD8SUE>&%M<&QE+&1C/6-O;2<["B\O("`@("`@("`@+R\@071T<FEB=71E
M('1O(&UA=&-H("1U<V5R240@86=A:6YS="!I;B!S96%R8V@*+R\@("`@("`@
M("`D=7-E<D%T='(@/2`G<T%-06-C;W5N=$YA;64G.PHO+R`@("`@("`@("\O
M($=R;W5P(&UE;6)E<G-H:7`@871T<FEB=71E+"!N965D('1O(&)E(&%L;"!L
M;W=E<F-A<V4*+R\@("`@("`@("`D9W)O=7!!='1R(#T@)VUE;6)E<F]F)SL*
M+R\@("`@("`@("`O+R!!='1R:6)U=&4@=&\@8VAE8VL@9F]R(')I9VAT('1O
M('5S92!(;W)D90HO+R`@("`@("`@("1G<F]U<&1N(#T@)V-N/4AO<F1E57-E
M<BQO=3U096]P;&4L9&,]97AA;7!L92QD8SUC;VTG.PHO+R`@("`@("`@("1R
M970@/2!T<G5E.PHO+PHO+R`@("`@("`@("1D<R`]($!L9&%P7V-O;FYE8W0H
M)&QD87!397)V97(L("1L9&%P4&]R="D["B\O"B\O("`@("`@("`@:68@*$!L
M9&%P7V)I;F0H)&1S+"`D8FEN9&1N+"`D8FEN9'!W*2D@>PHO+R`@("`@("`@
M("`@("`D<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A<F-H*"1D<RP@)'-E87)C
M:$)A<V4L("1U<V5R071T<B`N("<])R`N("1U<V5R240L(&%R<F%Y*"1G<F]U
M<$%T='(I+"`P+"`Q+"`U*3L*+R\@("`@("`@("`@("`@:68@*"1I;F9O<FUA
M=&EO;B`]($!L9&%P7V=E=%]E;G1R:65S*"1D<RP@)'-E87)C:%)E<W5L="DI
M('L*+R\@("`@("`@("`@("`@("`@("\O(&UA:V4@<&%T=&5R;B!C87-E+6EN
M<V5N<VET:79E"B\O("`@("`@("`@("`@("`@("`D<&%T=&5R;B`]("<O)R`N
M("1G<F]U<&1N("X@)R]I)SL*+R\@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1I;F9O<FUA=&EO;ELP75LD9W)O=7!!='1R72!A<R`D9W)O=7`I('L*+R\@
M("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<&%T=&5R;BP@
M)&=R;W5P*2D@>PHO+R`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@
M=')U93L*+R\@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B\O("`@
M("`@("`@("`@("`@("`@("`@?0HO+R`@("`@("`@("`@("`@("`@?0HO+R`@
M("`@("`@("`@("!]"B\O("`@("`@("`@?0HO+PHO+R`@("`@("`@(&QD87!?
M8VQO<V4H)&1S*3L*+R\@("`@("`@("!R971U<FX@)')E=#L*+R\@("`@('T*
M+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(&]F(&-R96%T:6YG(&-R961E
M;G1I86QS(&YE961E9"!B>2!T:&4@3$1!4"!!=71H(&1R:79E<@HO+R!F;W(@
M861D:6YG+V1E;&5T:6YG+W5P9&%T:6YG('5S97)S+@H*+R\@:68@*"%F=6YC
M=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RDI('L*+R\@("`@
M(&9U;F-T:6]N(%]H;W)D95]H;V]K7V%U=&AL9&%P*"1U<V5R240L("1C<F5D
M96YT:6%L<R`](&YU;&PI"B\O("`@("!["B\O("`@("`@("`@)&5N=')Y6R=D
M;B==(#T@)W5I9#TG("X@)'5S97))1"`N("<L;W4]4&5O<&QE+&1C/65X86UP
M;&4N8V]M)SL*+R\@("`@("`@("!I9B`H:7-S970H)&-R961E;G1I86QS*2`F
M)B!I<W-E="@D8W)E9&5N=&EA;'-;)W5S97)?9G5L;&YA;64G72DI('L*+R\@
M("`@("`@("`@("`@)&5N=')Y6R=C;B==(#T@)&-R961E;G1I86QS6R=U<V5R
M7V9U;&QN86UE)UT["B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@
M("`@)&5N=')Y6R=C;B==(#T@)'5S97))1#L*+R\@("`@("`@("!]"B\O("`@
M("`@("`@)&5N=')Y6R=S;B==(#T@)'5S97))1#L*+R\@("`@("`@("`D96YT
M<GE;)V]B:F5C=&-L87-S)UU;,%T@/2`G=&]P)SL*+R\@("`@("`@("`D96YT
M<GE;)V]B:F5C=&-L87-S)UU;,5T@/2`G<&5R<V]N)SL*+R\@("`@("`@("`D
M96YT<GE;)V]B:F5C=&-L87-S)UU;,ET@/2`G<6UA:6QU<V5R)SL*+R\@("`@
M("`@("`D96YT<GE;)V]B:F5C=&-L87-S)UU;,UT@/2`G0V]U<FEE<DUA:6Q!
M0V-O=6YT)SL*+R\@("`@("`@("`D96YT<GE;)VUA:6QH;W-T)UT@/2`G;6%I
M;"YE>&%M<&QE+F-O;2<["B\O("`@("`@("`@)&5N=')Y6R=M86EL365S<V%G
M95-T;W)E)UT@/2`G+VAO;64O;6%I;"\G("X@)'5S97))1#L*+R\@("`@("`@
M("`D96YT<GE;)VAO;65$:7)E8W1O<GDG72`]("<O:&]M92]M86EL+R<@+B`D
M=7-E<DE$.PHO+R`@("`@("`@("1E;G1R>5LG;6%I;&)O>"==(#T@)&5N=')Y
M6R=H;VUE1&ER96-T;W)Y)UT@+B`G+TUA:6QD:7(G.PHO+R`@("`@("`@("1E
M;G1R>5LG=6ED)UT@/2`D=7-E<DE$.PHO+R`@("`@("`@("1E;G1R>5LG86-C
M;W5N=%-T871U<R==(#T@)V%C=&EV92<["B\O("`@("`@("`@)&5N=')Y6R=M
M86EL475O=&$G72`]("<Q,#0X-3<V,#!3)SL*+R\@("`@("`@("`D96YT<GE;
M)VUA:6PG72`]("1U<V5R240["B\O("`@("`@("`@)&5N=')Y6R=U:61.=6UB
M97(G72`](#4P,3L*+R\@("`@("`@("`D96YT<GE;)V=I9$YU;6)E<B==(#T@
M-3`Q.PHO+PHO+R`@("`@("`@("\O(&YE960@=&\@8VAE8VL@9F]R(&YE=R!U
M<V5R<R`H<&%S<W=O<F0I(&%N9"!E9&ET960@=7-E<G,@*'5S97)?<&%S<U\R
M*0HO+R`@("`@("`@(&EF("AI<W-E="@D8W)E9&5N=&EA;',I("8F(&ES<V5T
M*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*+R\@("`@("`@("`@("`@
M)&5N=')Y6R=U<V5R4&%S<W=O<F0G72`]("`G>TU$-7TG("X@8F%S938T7V5N
M8V]D92AM2&%S:"A-2$%32%]-1#4L("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G
M72DI.PHO+R`@("`@("`@('T@96QS96EF("AI<W-E="@D8W)E9&5N=&EA;',I
M("8F(&ES<V5T*"1C<F5D96YT:6%L<ULG=7-E<E]P87-S7S(G72DI('L*+R\@
M("`@("`@("`@("`@)&5N=')Y6R=U<V5R4&%S<W=O<F0G72`]("`G>TU$-7TG
M("X@8F%S938T7V5N8V]D92AM2&%S:"A-2$%32%]-1#4L("1C<F5D96YT:6%L
M<ULG=7-E<E]P87-S7S(G72DI.PHO+R`@("`@("`@('T*+R\@("`@("`@("`D
M96YT<GE;)V1E;&EV97)Y36]D92==(#T@)VYO;&]C86PG.PHO+R`@("`@("`@
M(')E='5R;B`D96YT<GD["B\O("`@("!]"B\O('T*"B\O(%1H:7,@9G5N8W1I
M;VX@:7,@8V%L;&5D('=H96X@82!(;W)D95]3:&%R92!O8FIE8W0@:7,@8W)E
M871E9"X@270@=&%K97,@80HO+R!R969E<F5N8V4@=&\@=&AE($AO<F1E7U-H
M87)E(&]B:F5C="!T:&%T(&ES(&)E:6YG(&-R96%T960@87,@=V5L;"!A<R!T
M:`HO+R!N86UE(&]F('1H92!A<'!L:6-A=&EO;B!F;W(@=VAI8V@@=&AE($AO
M<F1E7U-H87)E(&]B:F5C="!I<R!B96EN9R!C<F5A=&5D(&%S"B\O('!A<F%M
M971E<G,N(%1H92!R971U<FX@=F%L=64@:7,@:6=N;W)E9"X*"B\O(&EF("@A
M9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]S:&%R95]I;FET)RDI('L*
M+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7VEN:70H)B1S:&%R
M95]O8FIE8W0L("1A<'`I"B\O("`@("!["B\O("`@("`@("`@:68@*"1'3$]"
M04Q36R=C;VYF)UU;)VMO;&%B)UU;)V5N86)L960G72D@>PHO+R`@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O("`@("`@
M("`@("`@($MO;&%B.CIS>6YC:')O;FES95-H87)E<R@D<VAA<F5?;V)J96-T
M+"`D87!P*3L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O(%1H92!F
M;VQL;W=I;F<@=&AR964@9G5N8W1I;VYS(&%R92!E>&%M<&QE<R!O9B!T:&]S
M92!T:&%T(&-A;B!B92!C86QL960@=VAE;@HO+R!A9&1I;F<L(&UO9&EF>6EN
M9R!A;F0@<F5M;W9I;F<@<VAA<F5S+"!R97-P96-T:79E;'DN(%1H97D@87)E
M(&-A;&QE9"!W:71H"B\O('1H92!S:&%R92!T:&%T(&ES(&)E:6YG(&%D9&5D
M+"!M;V1I9FEE9"!O<B!R96UO=F5D(&%S('1H96ER('-I;F=L90HO+R!P87)A
M;65T97(N("!)9B!A(%!%05)?17)R;W(@;V)J96-T(&ES(')E='5R;F5D('1H
M92!R97-P96-T:79E('-H87)E"B\O(&]P97)A=&EO;B!W:6QL(&9A:6P@=VET
M:"!T:&4@97)R;W(@<F5S=6QT+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H
M)U]H;W)D95]H;V]K7W-H87)E7V%D9"<I*2!["B\O("`@("!F=6YC=&EO;B!?
M:&]R9&5?:&]O:U]S:&%R95]A9&0H)B1S:&%R92D*+R\@("`@('L*+R\@("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O("`@("`@
M("`@<F5T=7)N($MO;&%B.CIU<&1A=&53:&%R92@D<VAA<F4I.PHO+R`@("`@
M?0HO+R!]"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?
M<VAA<F5?;6]D:69Y)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K
M7W-H87)E7VUO9&EF>2@F)'-H87)E*0HO+R`@("`@>PHO+R`@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O2V]L86(N<&AP)SL*+R\@("`@("`@("!R971U
M<FX@2V]L86(Z.G5P9&%T95-H87)E*"1S:&%R92D["B\O("`@("!]"B\O('T*
M+R\*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-H87)E
M7W)E;6]V92<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:&%R
M95]R96UO=F4H)B1S:&%R92D*+R\@("`@('L*+R\@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O("`@("`@("`@<F5T=7)N($MO
M;&%B.CIR96UO=F53:&%R92@D<VAA<F4I.PHO+R`@("`@?0HO+R!]"@HO+R!4
M:&ES(&5X86UP;&4@:7,@;V8@82!F=6YC=&EO;B!T:&%T(&-A;B!B92!C86QL
M960@=VAE;B!A('-H87)E(&QI<W1I;F<@:7,*+R\@<F5Q=65S=&5D+B!)="!T
M86ME<R!A('5S97)I9"P@82!P97)M:7-S:6]N<R!L979E;"P@86X@;W!T:6]N
M86P@<W1R:6YG"B\O(&-O;G1A:6YI;F<@82!U<V5R:60@=&\@<F5S=')I8W0@
M=&AE(&]W;F5R(&]F('1H92!S:&%R97,@<F5T=7)N960L(&%N9"!T:&4*+R\@
M<F5S=6QT(&]F('1H92!C;W)R97-P;VYD:6YG($AO<F1E7U-H87)E.CIL:7-T
M4VAA<F5S*"D@8V%L;"!A<R!I=',*+R\@<&%R86UE=&5R<RX@07,@:7,@=&AE
M(&-A<V4@:6X@=&AE('!R979I;W5S('1H<F5E(&9U;F-T:6]N<RP@:68@82!0
M14%27T5R<F]R"B\O(')E<W5L="!I<R!R971U<FYE9"!T:&4@2&]R9&5?4VAA
M<F4Z.FQI<W13:&%R97,H*2!C86QL('1H870@=')I9V=E<F5D('1H:7,*+R\@
M:&]O:R!W:6QL(&9A:6P@=VET:"!T:&4@<F5T=7)N960@<F5S=6QT+@H*+R\@
M:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-H87)E7VQI<W0G
M*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA<F5?;&ES="@D
M=7-E<FED+"`D<&5R;2P@)&]W;F5R+"`F)'-H87)E7VQI<W0I"B\O("`@("![
M"B\O("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*+R\@("`@("`@("`O+V5R
M<F]R7VQO9R@G3G5M8F5R(&]F("<@+B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T07!P*"D@+B`G('-H87)E<R<@+B`H)&]W;F5R(#\*+R\@("`@("`@("`O
M+R`@("`G(&]W;F5D(&)Y("<@+B`D;W=N97(@.B`G)RD@+B`G(&%V86EL86)L
M92!T;R`G("X@)'5S97)I9"`N("<@870@<&5R;7,@;&5V96P@)R`N"B\O("`@
M("`@("`@+R\@("`@)'!E<FT@+B`G.B`G("X@(&-O=6YT*"1S:&%R95]L:7-T
M*2D["B\O("`@("`@("`@<F5T=7)N('1R=64["B\O("`@("!]"B\O('T*"B\O
M($AE<F4@:7,@86X@97AA;7!L92!?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N
M9"!F=6YC=&EO;BX@270@87!P96YD<R!T:&4*+R\@=FER='5A;"!D;VUA:6X@
M=&\@=&AE('5S97(@;F%M92X*+R\*+R\@97@N("1(5%107TA/4U0@/2`G;6%I
M;"YM>61O;6%I;BYC;VTG+"`D=7-E<DE$(#T@)VUY;F%M92<@<F5T=7)N<SH*
M+R\@("`G;7EN86UE0&UY9&]M86EN+F-O;2<*"B\O(&EF("@A9G5N8W1I;VY?
M97AI<W1S*"=?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"<I*2!["B\O("`@
M("!F=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"@D=7-E<DE$
M*0HO+R`@("`@>PHO+R`@("`@("`@("1V9&]M86EN(#T@9V5T96YV*"=(5%10
M7TA/4U0G*3L*+R\@("`@("`@("`D=F1O;6%I;B`]('!R96=?<F5P;&%C92@G
M?%YM86EL7"Y\:2<L("<G+"`D=F1O;6%I;BD["B\O("`@("`@("`@)'9D;VUA
M:6X@/2!3=')I;F<Z.FQO=V5R*"1V9&]M86EN*3L*+R\*+R\@("`@("`@("!R
M971U<FX@)'5S97))1"`N("=`)R`N("1V9&]M86EN.PHO+R`@("`@?0HO+R!]
M"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@7W5S97)N86UE7VAO;VM?=&]B86-K
M96YD(&9U;F-T:6]N(&%S(&$@8V]U;G1E<G!A<G0@;V8@=&AE"B\O('!R979I
M;W5S(&5X86UP;&4N($ET('-T<FEP<R!T:&4@=FER='5A;"!D;VUA:6X@9G)O
M;2!T:&4@=7-E<B!N86UE+@HO+PHO+R!E>"X@)$A45%!?2$]35"`]("=M86EL
M+FUY9&]M86EN+F-O;2<L("1U<V5R240@/2`G;7EN86UE)R!R971U<FYS.@HO
M+R`@("=M>6YA;65`;7ED;VUA:6XN8V]M)PH*+R\@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]U<V5R;F%M95]H;V]K7W1O8F%C:V5N9"<I*2!["B\O("`@("!F
M=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]T;V)A8VME;F0H)'5S97))1"D*+R\@
M("`@('L*+R\@("`@("`@("`D=F1O;6%I;B`](&=E=&5N=B@G2%144%](3U-4
M)RD["B\O("`@("`@("`@)'9D;VUA:6X@/2!P<F5G7W)E<&QA8V4H)WQ>;6%I
M;%PN?&DG+"`G)RP@)'9D;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@
M)T`G("X@4W1R:6YG.CIL;W=E<B@D=F1O;6%I;BD["B\O"B\O("`@("`@("`@
M:68@*'-U8G-T<B@D=7-E<DE$+"`M<W1R;&5N*"1V9&]M86EN*2D@/3T@)'9D
M;VUA:6XI('L*+R\@("`@("`@("`@("`@)'5S97))1"`]('-U8G-T<B@D=7-E
M<DE$+"`P+"`M<W1R;&5N*"1V9&]M86EN*2D["B\O("`@("`@("`@?0HO+PHO
M+R`@("`@("`@(')E='5R;B`D=7-E<DE$.PHO+R`@("`@?0HO+R!]"@HO+R!(
M97)E(&ES(&%N(&5X86UP;&4@7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0@
M9G5N8W1I;VXN($ET(&-O;G9E<G1S('1H92!U<V5R"B\O(&YA;64@=&\@86QL
M(&QO=V5R(&-A<V4N(%1H:7,@;6EG:'0@8F4@;F5C97-S87)Y(&EF(&%N(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0*+R\@:7,@8V%S92!I;G-E;G-I=&EV92!T
M;R!T86ME(&EN=&\@86-C;W5N="!T:&%T($AO<F1E)W,@<')E9F5R96YC92!S
M>7-T96T@:7,*+R\@8V%S92!S96YS:71I=F4N"B\O"B\O(&5X+B`D=7-E<DE$
M(#T@)TUY3F%M92<@<F5T=7)N<SH@)VUY;F%M92<*"B\O(&EF("@A9G5N8W1I
M;VY?97AI<W1S*"=?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"<I*2!["B\O
M("`@("!F=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"@D=7-E
M<DE$*0HO+R`@("`@>PHO+R`@("`@("`@(')E='5R;B!3=')I;F<Z.FQO=V5R
M*"1U<V5R240I.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP
M;&4@7W!E<FUS7VAO;VM?9&5N:65D(&9U;F-T:6]N+B`@270@:7,@8V%L;&5D
M(&EF(&$@=7-E<@HO+R!T<FEE<R!T;R!M86ME(&%N(&%C=&EO;B!T:&%T(&ES
M('5N9&5R('!E<FUI<W-I;VX@8V]N=')O;"!A;F0@=&AA="!H90HO+R!D;V5S
M;B=T(&AA=F4@<W5F9FEC:65N="!P97)M:7-S:6]N<R!F;W(N("!)="!C86X@
M8F4@=7-E9"!T;R!S:&]W('1H92!U<V5R(&$*+R\@8W5S=&]M(&UE<W-A9V4@
M:6YC;'5D:6YG($A434P@8V]D92`H>6]U(&AA=F4@=&\@=&%K92!C87)E(&%B
M;W5T($A434P*+R\@97-C87!I;F<@;VX@>6]U<B!O=VXI+"!O<B!T;R!I;G1E
M<G)U<'0@=&AE(&-O9&4@9FQO=R!A;F0@<V5N9"!T:&4@=7-E<B!T;R!A"B\O
M(&1I9F9E<F5N="!P86=E(&9O<B!E>&%M<&QE+@H*+R\@:68@*"%F=6YC=&EO
M;E]E>&ES=',H)U]P97)M<U]H;V]K7V1E;FEE9"<I*2!["B\O("`@("!F=6YC
M=&EO;B!?<&5R;7-?:&]O:U]D96YI960H)'!E<FUI<W-I;VXI"B\O("`@("![
M"B\O("`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1P97)M:7-S:6]N+"`G
M.B<I*2`]/3T@9F%L<V4I('L*+R\@("`@("`@("`@("`@)&%P<"`]("1P97)M
M:7-S:6]N.PHO+R`@("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@("1A
M<'`@/2!S=6)S='(H)'!E<FUI<W-I;VXL(#`L("1P;W,I.PHO+R`@("`@("`@
M('T*+R\*+R\@("`@("`@("!R971U<FX@<W!R:6YT9B@G4&5R;6ES<VEO;B!D
M96YI960N($-L:6-K(#QA(&AR968](FAT='`Z+R]W=W<N97AA;7!L92YC;VTO
M=7!G<F%D92YP:'`_87!P/25S(CY(15)%/"]A/B!T;R!U<&=R861E("5S+B<L
M"B\O("`@("`@("`@("`@("`@("`@("`@("`@)&%P<"P@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G;F%M92<I*3L*+R\@("`@('T*+R\@?0H*+R\@5&AI
M<R!I<R!A;B!E>&%M<&QE(&]F(&$@9W)O=7`@:&]O:RX@(%1O('5S92!I="!Y
M;W4@;75S="!S970@=&AE(&=R;W5P"B\O(&1R:79E<B!T;R!H;V]K<R!I;B!C
M;VYF+G!H<"X@(%1H96X@>6]U(&UU<W0@8W)E871E(&$@251?9&5P87)T;65N
M="!G<F]U<`HO+R`H8F5C875S92!T:&%T(&ES(&AO=R!W92!K;F]W('=H870@
M:&]O:R!T;R!C86QL*2X@(%EO=2!C86X@861D('5S97)S('1O('1H90HO+R!G
M<F]U<"!A<R!N;W)M86PL(&%N9"!I;B!A9&1I=&EO;B!T:&ES(&9U;F-T:6]N
M('=I;&P@8F4@8V%L;&5D('1O"B\O(&1Y;F%M:6-A;&QY(&EN8VQU9&4@=7-E
M<G,@:6X@=&AE(&=R;W5P+B`@26X@=&AI<R!E>&%M<&QE('=E('=I;&P@;&]O
M:R!U<`HO+R!W:&5T:&5R(&]R(&YO="!T:&ES('5S97(@:7,@<&%R="!O9B!T
M:&4@250@9&5P87)T;65N="!U<VEN9R!A;B!E>'1E<FYA;`HO+R!D871A8F%S
M92X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?9W)O=7!?:&]O:U])5%]D
M97!A<G1M96YT)RDI('L*+R\@("`@(&9U;F-T:6]N(%]G<F]U<%]H;V]K7TE4
M7V1E<&%R=&UE;G0H)'5S97).86UE*0HO+R`@("`@>PHO+R`@("`@("`@(&=L
M;V)A;"`D8V]N9CL*+R\*+R\@("`@("`@("`D9&5P="`]("=)5"<["B\O("`@
M("`@("`@:6YC;'5D95]O;F-E("=$0BYP:'`G.PHO+R`@("`@("`@("1?9&(@
M/2`F1$(Z.F-O;FYE8W0H)&-O;F9;)W-Q;"==+"!T<G5E*3L*+R\@("`@("`@
M("`D<75E<GD@/2`G4T5,14-4($-/54Y4*"HI($923TT@9&5P87)T;65N=',@
M5TA%4D4@=7-E<E]N86UE(#T@/R!!3D0@9&5P87)T;65N="`](#\G.PHO+R`@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D=7-E<DYA;64L("1D97!T*3L*+R\@
M("`@("`@("`D<F5S=6QT(#T@)%]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E
M<RD["B\O("`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RD@)B8@)')E<W5L="`^(#`I('L*+R\@("`@("`@("`@("`@<F5T=7)N('1R
M=64["B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PHO+R`@("`@("`@('T*+R\@("`@('T*+R\@?0H*+R\@5&AI<R!I
M<R!A;B!E>&%M<&QE(&]F(&$@<&]S="UP=7-H(&AO;VL[(&ET(&ES(&-A;&QE
M9"!R:6=H="!A9G1E<B!A;@HO+R!A<'!L:6-A=&EO;B!I<R!P=7-H960@<W5C
M8V5S<V9U;&QY(&]N=&\@=&AE(&%P<"!S=&%C:RX*"B\O(&EF("@A9G5N8W1I
M;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P;W-T7W!U<VAA<'`G*2D@>PHO+R`@
M("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<&]S=%]P=7-H87!P*"1A<'`I"B\O
M("`@("!["B\O("`@("`@("`@:68@*&EN7V%R<F%Y*"1A<'`L(&%R<F%Y*"=K
M<F]N;VQI=&@G+"`G='5R8F$G+"`G:&]R9&4G+"`G:6YG;R<I*2!\?`HO+R`@
M("`@("`@("`@("`@<W1R<&]S*"1?4T525D526R=02%!?4T5,1B==+"`G<')E
M9G,N<&AP)RD@(3T](&9A;'-E*2!["B\O("`@("`@("`@("`@(')E<75I<F5?
M;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("=D
M:6UP)RD@+B`G+VQI8B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S3W9E
M<G)I9&4N<&AP)SL*+R\@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A
M=&EO;B==(#T@)DYO=&EF:6-A=&EO;CHZ<VEN9VQE=&]N*"D["B\O("`@("`@
M("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^871T86-H*"=S=&%T
M=7,G+"!N=6QL+"`G3F]T:69I8V%T:6]N7TQI<W1E;F5R7V1I;7!?<W1A='5S
M3W9E<G)I9&4G*3L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O($AE
M<F4@:7,@86X@97AA;7!L92!?:6UP7VAO;VM?=')A:6QE<B!F=6YC=&EO;B!T
M;R!S970@=&AE('1R86EL97(@9G)O;2!T:&4*+R\@<WES=&5M('1A9VQI;F5S
M(&9I;&4[('1H92!S=')I;F<@(D!`5$%'0$`B("AI9B!P<F5S96YT(&EN(&$@
M=')A:6QE<BD@=VEL;"!B90HO+R!R97!L86-E9"!B>2!T:&4@8V]N=&5N="!O
M9B!T:&4@9FEL92`B+W5S<B]S:&%R92]T86=L:6YE(B`H9V5N97)A=&5D(&)Y
M('1H90HO+R`B5&%25"(@=71I;&ET>2DN"@HO+R!I9B`H(69U;F-T:6]N7V5X
M:7-T<R@G7VEM<%]H;V]K7W1R86EL97(G*2D@>PHO+R`@("`@9G5N8W1I;VX@
M7VEM<%]H;V]K7W1R86EL97(H)'1R86EL97(I"B\O("`@("!["B\O("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]`0%1!1T!`+R<L("1T<F%I;&5R*2D@>PHO
M+R`@("`@("`@("`@("`D=&%G(#T@8&-A="`O=7-R+W-H87)E+W1A9VQI;F5@
M.PHO+R`@("`@("`@("`@("`D=')A:6QE<B`]('!R96=?<F5P;&%C92@G?$!`
M5$%'0$!\)RP@)'1A9RP@)'1R86EL97(I.PHO+R`@("`@("`@('T*+R\@("`@
M("`@("!R971U<FX@)'1R86EL97(["B\O("`@("!]"B\O('T*"B\O($AE<F4@
M:7,@86X@86YO=&AE<B!E>&%M<&QE(%]I;7!?:&]O:U]T<F%I;&5R(&9U;F-T
M:6]N('1O('-E="!T:&4@=')A:6QE<@HO+R!F<F]M('1H92!,1$%0(&1I<F5C
M=&]R>2!F;W(@96%C:"!D;VUA:6XN(%1H:7,@9G5N8W1I;VX@<F5P;&%C97,@
M=&AE(&-U<G)E;G0*+R\@=')A:6QE<B!W:71H('1H92!D871A(&ET(&=E=',@
M9G)O;2!I<W!M86Y$;VUA:6Y3:6=N871U<F4N"@HO+R!I9B`H(69U;F-T:6]N
M7V5X:7-T<R@G7VEM<%]H;V]K7W1R86EL97(G*2D@>PHO+R`@("`@9G5N8W1I
M;VX@7VEM<%]H;V]K7W1R86EL97(H)'1R86EL97(I"B\O("`@("!["B\O("`@
M("`@("`@)'9D;VUA:6X@/2!G971E;G8H)TA45%!?2$]35"<I.PHO+R`@("`@
M("`@("1V9&]M86EN(#T@<')E9U]R97!L86-E*"=\7BXJ/UPN?&DG+"`G)RP@
M)'9D;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@4W1R:6YG.CIL;W=E
M<B@D=F1O;6%I;BD["B\O("`@("`@("`@)&QD87!397)V97(@/2`G;&]C86QH
M;W-T)SL*+R\@("`@("`@("`D;&1A<%!O<G0@/2`G,S@Y)SL*+R\@("`@("`@
M("`D<V5A<F-H0F%S92`]("=I<W!M86Y$;VUA:6X])R`N("1V9&]M86EN("`N
M("(L;SUI<W!M86XB.PHO+PHO+R`@("`@("`@("1D<R`]($!L9&%P7V-O;FYE
M8W0H)&QD87!397)V97(L("1L9&%P4&]R="D["B\O("`@("`@("`@)'-E87)C
M:%)E<W5L="`]($!L9&%P7W-E87)C:"@D9',L("1S96%R8VA"87-E+"`G=6ED
M/2<@+B`D=F1O;6%I;BD["B\O("`@("`@("`@)&EN9F]R;6%T:6]N(#T@0&QD
M87!?9V5T7V5N=')I97,H)&1S+"`D<V5A<F-H4F5S=6QT*3L*+R\@("`@("`@
M("`D=')A:6QE<CT@)&EN9F]R;6%T:6]N6S!=6R=I<W!M86YD;VUA:6YS:6=N
M871U<F4G75LP73L*+R\@("`@("`@("!L9&%P7V-L;W-E*"1D<RD["B\O"B\O
M("`@("`@("`@<F5T=7)N("1T<F%I;&5R.PHO+R`@("`@?0HO+R!]"@HO+R!(
M97)E(&ES(&%N(&5X86UP;&4@7VEM<%]H;V]K7W9I;F9O(&9U;F-T:6]N+B!)
M9B`D='EP92`]/2`G=F1O;6%I;B<L('1H:7,*+R\@9G5N8W1I;VX@<F5T=7)N
M<R!T:&4@2%144%](3U-4('9A<FEA8FQE(&%F=&5R(')E;6]V:6YG('1H92`G
M;6%I;"XG"B\O('-U8F1O;6%I;BX*+R\*+R\@268@)'1Y<&4@/3T@)W5S97)N
M86UE)RP@=&AI<R!F=6YC=&EO;B!R971U<FYS(&$@=6YI<75E('5S97)N86UE
M(&-O;7!O<V5D(&]F"B\O("1?4T534TE/3ELG:6UP)UU;)W5S97(G72`K('9D
M;VUA:6XN"B\O"B\O(&5X+B`D2%144%](3U-4(#T@)VUA:6PN;7ED;VUA:6XN
M8V]M)RP@)%]315-324].6R=I;7`G75LG=7-E<B==(#T@)VUY;F%M92<Z"B\O
M("`@)'9D;VUA:6X@(#T@)VUY9&]M86EN+F-O;2<*+R\@("`D=7-E<FYA;64@
M/2`G;7EN86UE7VUY9&]M86EN7V-O;2<*"B\O(&EF("@A9G5N8W1I;VY?97AI
M<W1S*"=?:6UP7VAO;VM?=FEN9F\G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VEM
M<%]H;V]K7W9I;F9O*"1T>7!E(#T@)W5S97)N86UE)RD*+R\@("`@('L*+R\@
M("`@("`@("`D=F1O;6%I;B`](&=E=&5N=B@G2%144%](3U-4)RD["B\O("`@
M("`@("`@)'9D;VUA:6X@/2!P<F5G7W)E<&QA8V4H)WQ>;6%I;%PN?&DG+"`G
M)RP@)'9D;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@4W1R:6YG.CIL
M;W=E<B@D=F1O;6%I;BD["B\O"B\O("`@("`@("`@:68@*"1T>7!E(#T]("=U
M<V5R;F%M92<I('L*+R\@("`@("`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C
M92@G?%PN?"<L("=?)RP@)%]315-324].6R=I;7`G75LG=7-E<B==("X@)U\G
M("X@)'9D;VUA:6XI.PHO+R`@("`@("`@('T@96QS96EF("@D='EP92`]/2`G
M=F1O;6%I;B<I('L*+R\@("`@("`@("`@("`@<F5T=7)N("1V9&]M86EN.PHO
M+R`@("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=I;G9A;&ED('1Y<&4Z("<@+B`D='EP92D["B\O("`@
M("`@("`@?0HO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@
M;V8@=&AE(%]I;7!?:&]O:U]F971C:&UA:6Q?9FEL=&5R(&9U;F-T:6]N('1O
M(')U;@HO+R!3<&%M07-S87-S:6X@;VX@96UA:6P@8F5F;W)E(&ET(&ES('=R
M:71T96X@=&\@=&AE(&UA:6QB;W@N"B\O($YO=&4Z('1O('5S92!T:&4@<W!A
M;6%S<V%S<VEN(&EN<W1E860@;V8@<W!A;60L(&-H86YG92`G<W!A;6,G('1O
M"B\O("=S<&%M87-S87-S:6X@+5`G(&%N9"!A9&0@86YY(&]T:&5R(&EM<&]R
M=&%N="!A<F=U;65N=',L(&)U="!R96%L:7IE('-P86UC"B\O(&ES($U50T@@
M9F%S=&5R('1H86X@<W!A;6%S<V%S<VEN+@HO+R!705).24Y'.B!-86ME('-U
M<F4@=&\@=7-E('1H92`M+6YO861D+69R;VT@9FEL=&5R(&]N('-P86UD(&]R
M('-P86UA<W-A<W-I;@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]I;7!?
M:&]O:U]F971C:&UA:6Q?9FEL=&5R)RDI('L*+R\@("`@(&9U;F-T:6]N(%]I
M;7!?:&]O:U]F971C:&UA:6Q?9FEL=&5R*"1M97-S86=E*0HO+R`@("`@>PHO
M+R`@("`@("`@("\O(%=H97)E(&1O97,@4W!A;4%S<V%S<VEN(&QI=F4L(&%N
M9"!W:&%T('5S97)N86UE('-H;W5L9"!W92!U<V4*+R\@("`@("`@("`O+R!F
M;W(@<')E9F5R96YC97,_"B\O("`@("`@("`@)&-M9"`]("<O=7-R+VQO8V%L
M+V)I;B]S<&%M8R<["B\O("`@("`@("`@)'5S97)N86UE(#T@075T:#HZ9V5T
M075T:"@I.PHO+R`@("`@("`@("\O($EF('EO=2!U<V4@=&AE(%]S86U?:&]O
M:U]U<V5R;F%M92@I(&AO;VLL('5N8V]M;65N="!T:&4@;F5X="!L:6YE"B\O
M("`@("`@("`@+R\D=7-E<FYA;64@/2!?<V%M7VAO;VM?=7-E<FYA;64H)'5S
M97)N86UE*3L*+R\@("`@("`@("`D=7-E<FYA;64@/2!E<V-A<&5S:&5L;&%R
M9R@D=7-E<FYA;64I.PHO+PHO+R`@("`@("`@("\O($%L<V\L('=E(')E;6]V
M92!T:&4@9FEL92!O=7)S96QV97,[('1H:7,@:&]O:R!M87D@8F4@8V%L;&5D
M"B\O("`@("`@("`@+R\@:'5N9')E9',@;V8@=&EM97,@<&5R(')U;B!D97!E
M;F1I;F<@;VX@:&]W(&UA;GD@;65S<V%G97,@=V4@9F5T8V@*+R\@("`@("`@
M("`D9FEL92`]($AO<F1E.CIG971496UP1FEL92@G:&]R9&4G+"!F86QS92D[
M"B\O"B\O("`@("`@("`@+R\@0V%L;"!3<&%M07-S87-S:6X[('!I<&4@=&AE
M(&YE=R!M97-S86=E('1O(&]U<B!T96UP9FEL90HO+R`@("`@("`@("1F<"`]
M('!O<&5N*"(D8VUD("UU("1U<V5R;F%M92`^("1F:6QE(BP@)W<G*3L*+R\@
M("`@("`@("!F=W)I=&4H)&9P+"`D;65S<V%G92D["B\O("`@("`@("`@<&-L
M;W-E*"1F<"D["B\O"B\O("`@("`@("`@+R\@4F5A9"!T:&4@;F5W(&UE<W-A
M9V4@9G)O;2!T:&4@=&5M<&]R87)Y(&9I;&4*+R\@("`@("`@("`D9G`@/2!F
M;W!E;B@D9FEL92P@)W(G*3L*+R\@("`@("`@("`D;65S<V%G92`](&9R96%D
M*"1F<"P@9FEL97-I>F4H)&9I;&4I*3L*+R\@("`@("`@("!F8VQO<V4H)&9P
M*3L*+R\@("`@("`@("!U;FQI;FLH)&9I;&4I.PHO+R`@("`@("`@(')E='5R
M;B`D;65S<V%G93L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M
M<&QE('-I9VYA='5R92!H;V]K(&9U;F-T:6]N('1O('-E="!T:&4@<VEG;F%T
M=7)E(&9R;VT@=&AE"B\O('-Y<W1E;2!T86=L:6YE<R!F:6QE.R!T:&4@<W1R
M:6YG("(E5$%')2(@*&EF('!R97-E;G0@:6X@82!U<V5R)W,@<VEG;F%T=7)E
M*0HO+R!W:6QL(&)E(')E<&QA8V5D(&)Y('1H92!C;VYT96YT(&]F('1H92!F
M:6QE("(O=7-R+W-H87)E+W1A9VQI;F4B("AG96YE<F%T960*+R\@8GD@=&AE
M(")485)4(B!U=&EL:71Y*2X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?
M:6UP7VAO;VM?<VEG;F%T=7)E)RDI('L*+R\@("`@(&9U;F-T:6]N(%]I;7!?
M:&]O:U]S:6=N871U<F4H)'-I9RD*+R\@("`@('L*+R\@("`@("`@("!I9B`H
M<')E9U]M871C:"@G+R5404<E+R<L("1S:6<I*2!["B\O("`@("`@("`@("`@
M("1T86<@/2!@8V%T("]U<W(O<VAA<F4O=&%G;&EN96`["B\O("`@("`@("`@
M("`@("1S:6<@/2!P<F5G7W)E<&QA8V4H)R\E5$%')2\G+"`D=&%G+"`D<VEG
M*3L*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@<F5T=7)N("1S:6<["B\O
M("`@("!]"B\O('T*"B\O(%1H:7,@:7,@86X@97AA;7!L92!H;V]K(&9U;F-T
M:6]N(&9O<B!T:&4@24U0(')E9&ER96-T:6]N('-C:&5M92X@5&AI<PHO+R!F
M=6YC=&EO;B!I<R!C86QL960@=VAE;B!T:&4@=7-E<B!O<&5N<R!A(&UA:6QB
M;W@@:6X@24U0+"!A;F0@86QL;W=S('1H90HO+R!C;&EE;G0@=&\@8F4@<F5D
M:7)E8W1E9"!B87-E9"!O;B!T:&4@;6%I;&)O>"!N86UE+B!4:&4@<F5T=7)N
M('9A;'5E(&]F('1H:7,*+R\@9G5N8W1I;VX@<VAO=6QD(&)E(&$@=F%L:60@
M<&%G92!W:71H:6X@82!H;W)D92!A<'!L:6-A=&EO;B!W:&EC:"!W:6QL(&)E
M"B\O('!L86-E9"!I;B!A("),;V-A=&EO;B(@:&5A9&5R('1O(')E9&ER96-T
M('1H92!C;&EE;G0N("!4:&4@;VYL>2!P87)A;65T97(*+R\@:7,@=&AE(&YA
M;64@;V8@=&AE(&UA:6QB;W@@=VAI8V@@=&AE('5S97(@:&%S(&]P96YE9"X@
M($EF(&%N(&5M<'1Y('-T<FEN9PHO+R!I<R!R971U<FYE9"!T:&4@=7-E<B!I
M<R!N;W0@<F5D:7)E8W1E9"X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?
M:6UP7VAO;VM?;6)O>%]R961I<F5C="<I*2!["B\O("`@("!F=6YC=&EO;B!?
M:6UP7VAO;VM?;6)O>%]R961I<F5C="@D;6%I;&)O>"D*+R\@("`@('L*+R\@
M("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O"B\O
M("`@("`@("`@:68@*'-T<G!O<R@D;6%I;&)O>"P@(DE.0D]8+T-A;&5N9&%R
M(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H(B%>
M=7-E<B];7B]=*R]#86QE;F1A<B$B+"`D;6%I;&)O>"DI('L*+R\@("`@("`@
M("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O
M;W0G+"`G:W)O;F]L:71H)RD["B\O("`@("`@("`@?2!E;'-E:68@*'-T<G!O
M<R@D;6%I;&)O>"P@(DE.0D]8+U1A<VMS(BD@(3T](&9A;'-E"B\O("`@("`@
M("`@("`@('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R]487-K<R$B+"`D
M;6%I;&)O>"DI('L*+R\@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G;F%G)RD["B\O("`@("`@("`@
M?2!E;'-E:68@*'-T<G!O<R@D;6%I;&)O>"P@(DE.0D]8+TYO=&5S(BD@(3T]
M(&9A;'-E"B\O("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H(B%>=7-E<B];
M7B]=*R].;W1E<R$B+"`D;6%I;&)O>"DI('L*+R\@("`@("`@("`@("`@<F5T
M=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G;6YE
M;6\G*3L*+R\@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1M86EL8F]X+"`B
M24Y"3U@O0V]N=&%C=',B*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@?'P@
M<')E9U]M871C:"@B(5YU<V5R+UM>+UTK+T-O;G1A8W1S(2(L("1M86EL8F]X
M*2D@>PHO+R`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G=V5B<F]O="<L("=T=7)B82<I.PHO+R`@("`@("`@('T*+R\*
M+R\@("`@("`@("!R971U<FX@)R<["B\O("`@("!]"B\O('T*"B\O(%1H:7,@
M:7,@86X@97AA;7!L92!H;V]K(&9U;F-T:6]N(&9O<B!T:&4@24U0(&UA:6QB
M;W@@:6-O;B!S8VAE;64N(%1H:7,*+R\@9G5N8W1I;VX@:7,@8V%L;&5D('=H
M96X@=&AE(&9O;&1E<B!L:7-T(&ES(&-R96%T960@86YD(&$@(G-T86YD87)D
M(B!F;VQD97(*+R\@:7,@=&\@8F4@9&ES<&QA>65D("T@:70@86QL;W=S(&-U
M<W1O;2!F;VQD97(@:6-O;G,@=&\@8F4@<W!E8VEF:65D+@HO+R`H(E-T86YD
M87)D(B!M96%N<R!A;&P@9F]L9&5R<R!E>&-E<'0@=&AE($E.0D]8+"!S96YT
M+6UA:6P@9F]L9&5R<R!A;F0*+R\@=')A<V@@9F]L9&5R<RXI"B\O($EF(&$@
M;6%I;&)O>"!N86UE(&1O97-N)W0@87!P96%R(&EN('1H92!B96QO=R!L:7-T
M+"!T:&4@9&5F875L="!M86EL8F]X"B\O(&EC;VX@:7,@9&ES<&QA>65D+@H*
M+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]I;7!?:&]O:U]M8F]X7VEC;VYS
M)RDI('L*+R\@("`@(&9U;F-T:6]N(%]I;7!?:&]O:U]M8F]X7VEC;VYS*"D*
M+R\@("`@('L*+R\@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B
M+G!H<"<["B\O"B\O("`@("`@("`@)&MC(#T@;F5W($MO;&%B7T-Y<G5S*"1'
M3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)W-E<G9E<B==*3L*+R\@("`@("`@
M("`D;6%I;&)O>&5S(#T@)&MC+3YL:7-T36%I;$)O>&5S*"D["B\O("`@("`@
M("`@)&YE=VUA:6QB;WAE<R`](&%R<F%Y*"D["B\O"B\O("`@("`@("`@9F]R
M96%C:"`H)&UA:6QB;WAE<R!A<R`D8F]X*2!["B\O("`@("`@("`@("`@("1B
M;W@@/2!P<F5G7W)E<&QA8V4H(B]>>UM>?5TK?2\B+"`B(BP@)&)O>"D["B\O
M("`@("`@("`@("`@(&EF("AS=')P;W,H)&)O>"P@(DE.0D]8+T-A;&5N9&%R
M(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H
M*"(A7G5S97(O6UXO72LO0V%L96YD87(A(BP@)&)O>"DI('L*+R\@("`@("`@
M("`@("`@("`@("1N97=M86EL8F]X97-;)&)O>%T@/2!(;W)D93HZ:6UG*`HO
M+R`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG
M970H)VEC;VXG+"`G:W)O;F]L:71H)RDL"B\O("`@("`@("`@("`@("`@("`@
M("`@7R@B0V%L96YD87(B*2P*+R\@("`@("`@("`@("`@("`@("`@("`G=VED
M=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED
M9&QE(B<L"B\O("`@("`@("`@("`@("`@("`@("`@)R<*+R\@("`@("`@("`@
M("`@("`@("D["B\O("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&)O
M>"P@(DE.0D]8+U1A<VMS(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@("`@
M("!\?"!P<F5G7VUA=&-H*"(A7G5S97(O6UXO72LO5&%S:W,A(BP@)&)O>"DI
M('L*+R\@("`@("`@("`@("`@("`@("1N97=M86EL8F]X97-;)&)O>%T@/2!(
M;W)D93HZ:6UG*`HO+R`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)VEC;VXG+"`G;F%G)RDL"B\O("`@("`@("`@("`@
M("`@("`@("`@7R@B5&%S:W,B*2P*+R\@("`@("`@("`@("`@("`@("`@("`G
M=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB=F5R=&EC86PM86QI9VXZ
M;6ED9&QE(B<L"B\O("`@("`@("`@("`@("`@("`@("`@)R<*+R\@("`@("`@
M("`@("`@("`@("D["B\O("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H
M)&)O>"P@(DE.0D]8+TYO=&5S(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@
M("`@("!\?"!P<F5G7VUA=&-H*"(A7G5S97(O6UXO72LO3F]T97,A(BP@)&)O
M>"DI('L*+R\@("`@("`@("`@("`@("`@("1N97=M86EL8F]X97-;)&)O>%T@
M/2!(;W)D93HZ:6UG*`HO+R`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G;6YE;6\G*2P*+R\@("`@("`@
M("`@("`@("`@("`@("!?*").;W1E<R(I+`HO+R`@("`@("`@("`@("`@("`@
M("`@("=W:61T:#TB,38B(&AE:6=H=#TB,38B('-T>6QE/2)V97)T:6-A;"UA
M;&EG;CIM:61D;&4B)RP*+R\@("`@("`@("`@("`@("`@("`@("`G)PHO+R`@
M("`@("`@("`@("`@("`@*3L*+R\@("`@("`@("`@("`@?2!E;'-E:68@*'-T
M<G!O<R@D8F]X+"`B24Y"3U@O0V]N=&%C=',B*2`A/3T@9F%L<V4*+R\@("`@
M("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R]#;VYT
M86-T<R$B+"`D8F]X*2D@>PHO+R`@("`@("`@("`@("`@("`@)&YE=VUA:6QB
M;WAE<ULD8F]X72`]($AO<F1E.CII;6<H"B\O("`@("`@("`@("`@("`@("`@
M("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G:6-O;B<L("=T=7)B82<I
M+`HO+R`@("`@("`@("`@("`@("`@("`@(%\H(D-O;G1A8W1S(BDL"B\O("`@
M("`@("`@("`@("`@("`@("`@)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(@<W1Y
M;&4](G9E<G1I8V%L+6%L:6=N.FUI9&1L92(G+`HO+R`@("`@("`@("`@("`@
M("`@("`@("<G"B\O("`@("`@("`@("`@("`@("`I.PHO+R`@("`@("`@("`@
M("!]"B\O("`@("`@("`@?0HO+PHO+R`@("`@("`@(')E='5R;B`D;F5W;6%I
M;&)O>&5S.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&ES(&%N(&5X86UP;&4@
M:&]O:R!F=6YC=&EO;B!F;W(@=&AE($E-4"!S<&%M(')E<&]R=&EN9R!B;W5C
M92!O<'1I;VXN"B\O(%1H:7,@9G5N8W1I;VX@:7,@8V%L;&5D('=H96X@=&AE
M(&UE<W-A9V4@:7,@86)O=70@=&\@8F4@8F]U;F-E9"`M(&ET"B\O('=I;&P@
M<F5T=7)N('1H92!E;6%I;"!A9&1R97-S('1O(&)O=6YC92!T;RX@(%1H:7,@
M:7,@:&%N9'D@9F]R('-P86T*+R\@<F5P;W)T:6YG('-O9G1W87)E("AE+F<N
M($134$%-*2!W:&EC:"!H87,@9&EF9F5R96YT(&4M;6%I;"!A;&EA<V5S(&9O
M<@HO+R!S<&%M(')E<&]R=&EN9R!F;W(@96%C:"!U<V5R+@H*+R\@:68@*"%F
M=6YC=&EO;E]E>&ES=',H)U]I;7!?:&]O:U]S<&%M7V)O=6YC92<I*2!["B\O
M("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?<W!A;5]B;W5N8V4H)&%C=&EO;BD*
M+R\@("`@('L*+R\@("`@("`@("`D<')E9FEX(#T@*"1A8W1I;VX@/3T@)W-P
M86TG*2`_("=S<&%M+2<@.B`G9G`M)SL*+R\@("`@("`@("!R971U<FX@)'!R
M969I>"`N($%U=&@Z.F=E=$)A<F5!=71H*"D@+B`G0&5X86UP;&4N8V]M)SL*
M+R\@("`@('T*+R\@?0H*+R\@2&5R92!A;B!E>&%M<&QE(%]S86U?:&]O:U]U
M<V5R;F%M92!F=6YC=&EO;B!T;R!S970@=&AE('5S97)N86UE('1H870*+R\@
M4W!A;4%S<V%S<VEN('-E97,@=&\@;VYE(&1I9F9E<F5N="!F<F]M('1H92!(
M;W)D92!U<V5R;F%M92X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<V%M
M7VAO;VM?=7-E<FYA;64G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W-A;5]H;V]K
M7W5S97)N86UE*"1H;W)D95]U:60I"B\O("`@("!["B\O("`@("`@("`@:68@
M*'-T<G-T<B@D:&]R9&5?=6ED+"`G0"<I*2!["B\O("`@("`@("`@("`@("1P
M87)T<R`](&5X<&QO9&4H)T`G+"`D:&]R9&5?=6ED*3L*+R\@("`@("`@("`@
M("`@<F5T=7)N("1P87)T<ULP73L*+R\@("`@("`@("!](&5L<V4@>PHO+R`@
M("`@("`@("`@("!R971U<FX@)&AO<F1E7W5I9#L*+R\@("`@("`@("!]"B\O
M("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?='5R8F%?:&]O
M:U]E;F-O9&5?<&%S<W=O<F0@*&%N9"!D96-O9&4I+B!E;F-O9&4@:7,*+R\@
M8V%L;&5D('=H96X@=V4@<W1O<F4@82!V86QU93L@9&5C;V1E('=H96X@=V4@
M9&ES<&QA>2!I="X@(%!A<W-W;W)D<R!S:&]U;&0*+R\@8F4@340U(&5N8V]D
M960L(&)U="!N;W0@9&ES<&QA>65D+@HO+PHO+R!)35!/4E1!3E0Z(%1H92!L
M87-T('!A<F%M971E<B!I;B!T:&5S92!E>&%M<&QE<R`H)B1O8FIE8W0I(&ES
M(&]N;'D*+R\@<&%S<V5D(&)Y(%1U<F)A(#(N,2!A;F0@;&%T97(N($EF('EO
M=2!A<F4@=7-I;F<@5'5R8F$@,BXP+"!T:&5N('EO=0HO+R!M=7-T(')E;6]V
M92!T:&4@)B1O8FIE8W0@<&%R86UE=&5R+@H*+R\@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]T=7)B85]H;V]K7V5N8V]D95]P87-S=V]R9"<I*2!["B\O("`@
M("!F=6YC=&EO;B!?='5R8F%?:&]O:U]E;F-O9&5?<&%S<W=O<F0H)&YE=U]P
M87-S=V]R9"P@)&]L9%]P87-S=V]R9"P@)B1C;VYT86-T*0HO+R`@("`@>PHO
M+R`@("`@("`@(&EF("AI<U]N=6QL*"1N97=?<&%S<W=O<F0I('Q\("1N97=?
M<&%S<W=O<F0@/3T@)R<@?'P*+R\@("`@("`@("`@("`@)&YE=U]P87-S=V]R
M9"`]/2`G6TYO="!$:7-P;&%Y961=)RD@>PHO+R`@("`@("`@("`@("!R971U
M<FX@)&]L9%]P87-S=V]R9#L*+R\@("`@("`@("!](&5L<V4@>PHO+R`@("`@
M("`@("`@("!R971U<FX@;60U*"1N97=?<&%S<W=O<F0I.PHO+R`@("`@("`@
M('T*+R\@("`@('T*+R\@("`@(&9U;F-T:6]N(%]T=7)B85]H;V]K7V1E8V]D
M95]P87-S=V]R9"@D<&%S<W=O<F0L("8D8V]N=&%C="D*+R\@("`@('L*+R\@
M("`@("`@("!I9B`H<W1R<W1R*"1?4T525D526R=02%!?4T5,1B==+"`G961I
M=&]B:F5C="<I*2!["B\O("`@("`@("`@("`@(')E='5R;B!N=6QL.PHO+R`@
M("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@(')E='5R;B`G6TYO="!$
M:7-P;&%Y961=)SL*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O($AE
M<F4@:7,@86X@97AA;7!L92!?<&%S<W=D7VAO;VM?=7-E<FYA;64@9G5N8W1I
M;VX@=&\@=')A;G-L871E('=H870@=&AE"B\O('5S97(@96YT97)S+"!I;B!T
M:&4@=7-E<FYA;64@8F]X+"!I;G1O('=H870@=&AE(&)A8VME;F0@97AP96-T
M<RX@268@=V4@=V%N=`HO+R!T;R!A9&0@0&5X86UP;&4N8V]M('1O('1H92!E
M;F0@;V8@=&AE('5S97)N86UE('1H96X@96YA8FQE('1H92!H;V]K(&%N9"!U
M<V4*+R\@=&AI<R!F=6YC=&EO;BX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S
M*"=?<&%S<W=D7VAO;VM?=7-E<FYA;64G*2D@>PHO+R`@("`@9G5N8W1I;VX@
M7W!A<W-W9%]H;V]K7W5S97)N86UE*"1U<V5R:60I"B\O("`@("!["B\O("`@
M("`@("`@<F5T=7)N("1U<V5R:60@+B`G0&5X86UP;&4N8V]M)SL*+R\@("`@
M('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(%]P87-S=V1?:&]O:U]D
M969A=6QT7W5S97)N86UE(&9U;F-T:6]N('1O('-E="!T:&4*+R\@=7-E<FYA
M;64@=&AE('!A<W-W9"!M;V1U;&4@<V5E<R!W:&5N(')E<V5T=&EN9R!P87-S
M=V]R9',@8F%S960@;VX@=7-E<FED"B\O(&%N9"!R96%L;2X@(%1H92!D969A
M=6QT(&ES('1O('1A:V4@82!U<V5R;F%M92!O9B!U<V5R0&1O;6%I;BYT;&0@
M86YD(&-H86YG90HO+R!I="!T;R!U<V5R+B`@268@=V4@=V%N="!T;R!L96%V
M92!I="!U;G1O=6-H960L(&5N86)L92!T:&4@:&]O:R!A;F0@=7-E('1H:7,*
M+R\@9G5N8W1I;VXN"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7W!A<W-W
M9%]H;V]K7V1E9F%U;'1?=7-E<FYA;64G*2D@>PHO+R`@("`@9G5N8W1I;VX@
M7W!A<W-W9%]H;V]K7V1E9F%U;'1?=7-E<FYA;64H)'5S97)I9"D*+R\@("`@
M('L*+R\@("`@("`@("!R971U<FX@)'5S97)I9#L*+R\@("`@('T*+R\@?0H*
M+R\@2&5R92!I<R!A;B!E>&%M<&QE(%]P87-S=V1?:&]O:U]U<V5R9&X@9G5N
M8W1I;VX@=&AA="!Y;W4@8V%N('5S92!T;R!P<F]V:61E"B\O('EO=7(@;&1A
M<"!S97)V97(@=VET:"!A('5S97)D;B!S;R!T:&%T('EO=2!D;R!N;W0@:&%V
M92!T;R!P97)F;W)M(&%N;VYY;6]U<PHO+R!B:6YD<RX@5&AE(&9U;F-T:6]N
M('1A:V5S($%U=&@Z.F=E=$%U=&@H*2!A<R!A('!A<F%M971E<@H*+R\@:68@
M*"%F=6YC=&EO;E]E>&ES=',H)U]P87-S=V1?:&]O:U]U<V5R9&XG*2D@>PHO
M+R`@("`@9G5N8W1I;VX@7W!A<W-W9%]H;V]K7W5S97)D;B@D875T:"D*+R\@
M("`@('L*+R\@("`@("`@("!R971U<FX@)W5I9#TG("X@)&%U=&@@+B`G+&\]
M97AA;7!L92YC;VTG.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&ES(&%N(&5X
M86UP;&4@;V8@82!H;V]K('1O('-E="!C=7-T;VT@=&%G<R!T;R!B92!I;F-L
M=61E9"!I;B!A($=I87!E=&\*+R\@<&%G92!T96UP;&%T92X@26X@=&AI<R!E
M>&%M<&QE(&$@=&%G(&-O;G1A:6YI;F<@=&AE(&-U<G)E;G0@9&%T92!I<R!S
M970@=&\*+R\@=&AE("1T96UP;&%T92!O8FIE8W0@86YD('=H:6-H(&ES('1H
M96X@879A:6QA8FQE(&EN('1H92!P86=E('1E;7!L871E(&%S.@HO+R`@("`@
M/'1A9SID871E("\^"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7V=I87!E
M=&]?:&]O:U]S971T86=S)RDI('L*+R\@("`@(&9U;F-T:6]N(%]G:6%P971O
M7VAO;VM?<V5T=&%G<R@F)'1E;7!L871E*0HO+R`@("`@>PHO+R`@("`@("`@
M("1T96UP;&%T92T^<V5T*"=D871E)RP@<W1R9G1I;64H)R5A+"`E92`E8B`E
M62<I*3L*+R\@("`@('T*+R\@?0H*+R\@5&AI<R!I<R!A;B!E>&%M<&QE(&]F
M(&$@9W)O=7`@:&]O:RX@(%1O('5S92!I="!Y;W4@;75S="!S970@=&AE(&=R
M;W5P"B\O(&1R:79E<B!T;R!H;V]K<R!I;B!C;VYF+G!H<"X@(%1H96X@>6]U
M(&UU<W0@8W)E871E(&$@251?9&5P87)T;65N="!G<F]U<`HO+R`H8F5C875S
M92!T:&%T(&ES(&AO=R!W92!K;F]W('=H870@:&]O:R!T;R!C86QL*2X@(%EO
M=2!C86X@861D('5S97)S('1O('1H90HO+R!G<F]U<"!A<R!N;W)M86PL(&%N
M9"!I;B!A9&1I=&EO;B!T:&ES(&9U;F-T:6]N('=I;&P@8F4@8V%L;&5D('1O
M"B\O(&1Y;F%M:6-A;&QY(&EN8VQU9&4@=7-E<G,@:6X@=&AE(&=R;W5P+B`@
M26X@=&AI<R!E>&%M<&QE('=E('=I;&P@;&]O:R!U<`HO+R!W:&5T:&5R(&]R
M(&YO="!T:&ES('5S97(@:7,@<&%R="!O9B!T:&4@250@9&5P87)T;65N="!U
M<VEN9R!A;B!E>'1E<FYA;`HO+R!D871A8F%S92X*"B\O($1E9F%U;'0@2V]L
M86(@:&]O:W,Z"FEF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G
M75LG96YA8FQE9"==*2D@>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]+;VQA
M8BYP:'`G.PH@("`@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K
M7W-H87)E7VEN:70G*2D@>PH@("`@("`@(&9U;F-T:6]N(%]U<V5R;F%M95]H
M;V]K7V9R;VUB86-K96YD*"1U<V5R240I"B`@("`@("`@>PH@("`@("`@("`@
M("`O+R!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX*("`@("`@("`@("`@
M)&1S(#T@;&1A<%]C;VYN96-T*`H@("`@("`@("`@("`@("`@)$=,3T)!3%-;
M)V-O;F8G75LG:V]L86(G75LG;&1A<"==6R=S97)V97(G72P*("`@("`@("`@
M("`@("`@("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG<&]R
M="=="B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF("@A)&1S*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'5S97))1#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!L9&%P7W-E=%]O<'1I;VXH)&1S+"!,1$%07T]05%]04D]4
M3T-/3%]615)324].+"`S*3L*("`@("`@("`@("`@+R\@0FEN9"!A;F]N>6UO
M=7-L>2X*("`@("`@("`@("`@)')E<W5L="`]($!L9&%P7V)I;F0H)&1S*3L*
M("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'5S97))1#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`O+R!&
M:6YD('1H92!U<V5R)W,@1$XN"B`@("`@("`@("`@("1R97-U;'0@/2!L9&%P
M7W-E87)C:"@*("`@("`@("`@("`@("`@("1D<RP*("`@("`@("`@("`@("`@
M("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG8F%S961N)UTL
M"B`@("`@("`@("`@("`@("`G=6ED/2<@+B`D=7-E<DE$"B`@("`@("`@("`@
M("D["B`@("`@("`@("`@("1E;G1R>2`](&QD87!?9FER<W1?96YT<GDH)&1S
M+"`D<F5S=6QT*3L*("`@("`@("`@("`@:68@*"1E;G1R>2`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("\O(%1H92!U<V5R(&%L<F5A9'D@875T:&5N
M=&EC871E9"!W:71H(&AI<R!E;6%I;"!A9&1R97-S+@H@("`@("`@("`@("`@
M("`@<F5T=7)N("1U<V5R240["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&5M86EL(#T@;&1A<%]G971?=F%L=65S*"1D<RP@)&5N=')Y+"`G;6%I;"<I
M.PH@("`@("`@("`@("!R971U<FX@)&5M86EL6S!=.PH@("`@("`@('T*("`@
M("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:&%R95]I;FET*"8D<VAA<F5?
M;V)J96-T+"`D87!P*0H@("`@("`@('L*("`@("`@("`@("`@2V]L86(Z.G-Y
M;F-H<F]N:7-E4VAA<F5S*"1S:&%R95]O8FIE8W0L("1A<'`I.PH@("`@("`@
M('T*("`@("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:&%R95]A9&0H)B1S
M:&%R92D*("`@("`@("!["B`@("`@("`@("`@(')E='5R;B!+;VQA8CHZ=7!D
M871E4VAA<F4H)'-H87)E*3L*("`@("`@("!]"B`@("`@("`@9G5N8W1I;VX@
M7VAO<F1E7VAO;VM?<VAA<F5?;6]D:69Y*"8D<VAA<F4I"B`@("`@("`@>PH@
M("`@("`@("`@("!R971U<FX@2V]L86(Z.G5P9&%T95-H87)E*"1S:&%R92D[
M"B`@("`@("`@?0H@("`@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E
M7W)E;6]V92@F)'-H87)E*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N
M($MO;&%B.CIR96UO=F53:&%R92@D<VAA<F4I.PH@("`@("`@('T*("`@("`@
M("!F=6YC=&EO;B!?:6UP7VAO;VM?;6)O>%]R961I<F5C="@D;6%I;&)O>"D*
M("`@("`@("!["B`@("`@("`@("`@('-W:71C:"`H2V]L86(Z.F=E=$UA:6QB
M;WA4>7!E*"1M86EL8F]X*2D@>PH@("`@("`@("`@("!C87-E("=E=F5N="<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G=V5B<F]O="<L("=K<F]N;VQI=&@G*3L*"B`@("`@("`@("`@(&-A
M<V4@)W1A<VLG.@H@("`@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G;F%G)RD["@H@("`@("`@("`@
M("!C87-E("=N;W1E)SH*("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VUN96UO)RD["@H@("`@
M("`@("`@("!C87-E("=C;VYT86-T)SH*("`@("`@("`@("`@("`@(')E='5R
M;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)W1U<F)A
M)RD["@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&9U;F-T
M:6]N(%]I;7!?:&]O:U]M8F]X7VEC;VYS*"D*("`@("`@("!["B`@("`@("`@
M("`@("1F;VQD97)S(#T@2V]L86(Z.FQI<W1&;VQD97)S*"D["@H@("`@("`@
M("`@("`D:6-O;G,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@9F]R96%C:"`H
M)&9O;&1E<G,@87,@)&9O;&1E<BD@>PH@("`@("`@("`@("`@("`@)&YA;64@
M/2!P<F5G7W)E<&QA8V4H)R]>>UM>?5TK?2\G+"`G)RP@)&9O;&1E<ELP72D[
M"@H@("`@("`@("`@("`@("`@<W=I=&-H("@D9F]L9&5R6S%=*2!["B`@("`@
M("`@("`@("`@("!C87-E("=E=F5N="<Z"B`@("`@("`@("`@("`@("`@("`@
M)&EC;VYS6R1N86UE72`]($AO<F1E.CII;6<H"B`@("`@("`@("`@("`@("`@
M("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G:W)O
M;F]L:71H)RDL"B`@("`@("`@("`@("`@("`@("`@("`@(%\H(D-A;&5N9&%R
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB,38B(&AE:6=H
M=#TB,38B('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@)R<*("`@("`@("`@("`@("`@("`@("`I.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A
M<V4@)W1A<VLG.@H@("`@("`@("`@("`@("`@("`@("1I8V]N<ULD;F%M95T@
M/2!(;W)D93HZ:6UG*`H@("`@("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=I8V]N)RP@)VYA9R<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("!?*")487-K<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB=F5R=&EC86PM
M86QI9VXZ;6ED9&QE(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<G"B`@
M("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("=N;W1E)SH*("`@("`@("`@("`@
M("`@("`@("`D:6-O;G-;)&YA;65=(#T@2&]R9&4Z.FEM9R@*("`@("`@("`@
M("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G:6-O
M;B<L("=M;F5M;R<I+`H@("`@("`@("`@("`@("`@("`@("`@("!?*").;W1E
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG
M:'0](C$V(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("<G"B`@("`@("`@("`@("`@("`@("`@*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("=C;VYT86-T)SH*("`@("`@("`@("`@("`@("`@("`D:6-O;G-;)&YA
M;65=(#T@2&]R9&4Z.FEM9R@*("`@("`@("`@("`@("`@("`@("`@("`@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G:6-O;B<L("=T=7)B82<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("!?*")#;VYT86-T<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB
M=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("<G"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@<F5T=7)N("1I8V]N<SL*("`@("`@("!]"B`@("!]"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]E=&,O<'-A+6AO<F1E+VAO<F1E+V-O;F8N>&UL````````````````````
M```````````````````````````````````````````````````````P,3`P
M-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(P,S(R-P`Q,#0Q-S,V,C<T,P`P
M,3<W-#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]C
M;VYF:6<O8V]N9BYX;6PL=B`Q+C<T+C(N,S,@,C`P-B\P,R\R-2`Q,CHQ-#HR
M-2!J86X@17AP("0@+2T^"CQC;VYF:6=U<F%T:6]N/@H@/&-O;F9I9W1A8B!N
M86UE/2)G96YE<F%L(B!D97-C/2)'96YE<F%L(CX*("`\8V]N9FEG:&5A9&5R
M/D=E;F5R86P@2&]R9&4@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`\8V]N
M9FEG96YU;2!N86UE/2)D96)U9U]L979E;"(@<75O=&4](F9A;'-E(B!D97-C
M/2)4:&4@=F%L=64@=&\@<V5T"B`@97)R;W)?<F5P;W)T:6YG*"D@=&\N"B`@
M4V5E(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO9G5N8W1I;VXN97)R;W(M
M<F5P;W)T:6YG+G!H<"!F;W(@;6]R90H@(&EN9F]R;6%T:6]N+B(^15]!3$P*
M("`@/'9A;'5E<SX*("`@(#QV86QU93Y%7T524D]2/"]V86QU93X*("`@(#QV
M86QU93Y%7U=!4DY)3D<\+W9A;'5E/@H@("`@/'9A;'5E/D5?4$%24T4\+W9A
M;'5E/@H@("`@/'9A;'5E/D5?3D]424-%/"]V86QU93X*("`@(#QV86QU93Y%
M7T-/4D5?15)23U(\+W9A;'5E/@H@("`@/'9A;'5E/D5?0T]215]705).24Y'
M/"]V86QU93X*("`@(#QV86QU93Y%7T%,3#PO=F%L=64^"B`@(#PO=F%L=65S
M/@H@(#PO8V]N9FEG96YU;3X*("`\8V]N9FEG:6YT96=E<B!N86UE/2)M87A?
M97AE8U]T:6UE(B!D97-C/2))9B!W92!N965D('1O('!E<F9O<FT@82!L;VYG
M"B`@;W!E<F%T:6]N+"!W:&%T('-H;W5L9"!W92!S970@;6%X7V5X96-U=&EO
M;E]T:6UE('1O("AI;B!S96-O;F1S*3\@,"!M96%N<R!N;PH@(&QI;6ET.R!H
M;W=E=F5R+"!A('9A;'5E(&]F(#`@=VEL;"!C875S92!A('=A<FYI;F<@:68@
M>6]U(&%R92!R=6YN:6YG(&EN('-A9F4*("!M;V1E+B!3964@:'1T<#HO+W=W
M=RYP:'`N;F5T+VUA;G5A;"]F=6YC=&EO;BYS970M=&EM92UL:6UI="YP:'`@
M9F]R(&UO<F4*("!I;F9O<FUA=&EO;BXB/C`\+V-O;F9I9VEN=&5G97(^"B`@
M/&-O;F9I9V5N=6T@;F%M93TB=7-E7W-S;"(@<75O=&4](F9A;'-E(B!D97-C
M/2)$971E<FUI;F5S(&AO=R!W92!G96YE<F%T90H@(&9U;&P@55),<R`H9F]R
M(&QO8V%T:6]N(&AE861E<G,@86YD('-U8V@I+B9L=#MB<B`O)F=T.TY/5$4Z
M($EF('EO=2!C:&]O<V4@=&\*("!A;'=A>7,@9V5N97)A=&4@:'1T<',@55),
M<RP@>6]U($U54U0@:&%R9&-O9&4@=&AE(&-O<G)E8W0@2%144%,@<&]R="!N
M=6UB97(*("!I;B!T:&4@<V5R=F5R('!O<G0@<V5T=&EN9R!B96QO=RX@3W1H
M97)W:7-E($AO<F1E('=I;&P@8F4@=6YA8FQE('1O(&=E;F5R871E"B`@8V]R
M<F5C="!(5%104R!54DQS('=H96X@82!U<V5R('1R:65S('1O(&%C8V5S<R!(
M;W)D92!V:6$@82!N;VXM2%144%,@<&]R="XB/C(*("`@/'9A;'5E<SX*("`@
M(#QV86QU92!D97-C/2)!<W-U;64@=&AA="!W92!A<F4@;F]T('5S:6YG(%-3
M3"!A;F0@;F5V97(@9V5N97)A=&4@:'1T<',@55),<RXB/C`\+W9A;'5E/@H@
M("`@/'9A;'5E(&1E<V,](D%S<W5M92!T:&%T('=E(&%R92!U<VEN9R!34TP@
M86YD(&%L=V%Y<R!G96YE<F%T92!H='1P<R!54DQS+B(^,3PO=F%L=64^"B`@
M("`\=F%L=64@9&5S8STB071T96UP="!T;R!A=71O+61E=&5C="P@86YD(&=E
M;F5R871E(%523',@87!P<F]P<FEA=&5L>2(^,CPO=F%L=64^"B`@("`\=F%L
M=64@9&5S8STB07-S=6UE('1H870@=V4@87)E(&YO="!U<VEN9R!34TP@86YD
M(&=E;F5R871E(&AT='!S(%523',@;VYL>0H@("`@9F]R(&QO9VEN+B(^,SPO
M=F%L=64^"B`@(#PO=F%L=65S/@H@(#PO8V]N9FEG96YU;3X*("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)S97)V97(B/@H@("`\8V]N9FEG<&AP(&YA;64](FYA
M;64B(&1E<V,](E=H870@<V5R=F5R(&YA;64@<VAO=6QD('=E('5S93\@66]U
M)VQL('!R;V)A8FQY"B`@(&MN;W<@:68@>6]U(&YE960@=&\@8VAA;F=E('1H
M:7,@9&5F875L=#L@;VYL>2!I;B!S:71U871I;VYS('=H97)E('EO=2!N965D
M('1O"B`@(&]V97)R:61E('=H870@07!A8VAE('1H:6YK<R!T:&4@<V5R=F5R
M(&YA;64*("`@:7,N(CXD7U-%4E9%4ELG4T525D527TY!344G73PO8V]N9FEG
M<&AP/@H@("`\8V]N9FEG<&AP(&YA;64](G!O<G0B(&1E<V,](E=H870@<&]R
M="!N=6UB97(@:7,@=&AE('=E8G-E<G9E<B!R=6YN:6YG(&]N/PH@("!!9V%I
M;BP@>6]U('-H;W5L9&XG="!N965D('1O(&-H86YG92!T:&4@9&5F875L="P@
M86YD('EO=2!P<F]B86)L>2!K;F]W(&ET(&EF"B`@('EO=2!D;RX@5&AE(&5X
M8V5P=&EO;B!I<R!I9B!Y;W4@:&%V92!C:&]S96X@=&\@86QW87ES(&=E;F5R
M871E(&AT='!S(%523',L(&%S"B`@(&1E<V-R:6)E9"!A8F]V92XB/B1?4T52
M5D526R=315)615)?4$]25"==/"]C;VYF:6=P:'`^"B`@/"]C;VYF:6=S96-T
M:6]N/@H@(#QC;VYF:6=B;V]L96%N(&YA;64](F-O;7!R97-S7W!A9V5S(B!D
M97-C/2))9B!T:&ES(&]P=&EO;B!I<R!S970@=&\@=')U92P@86YD"B`@>6]U
M(&AA=F4@=&AE('!H<"!Z;&EB(&5X=&5N<VEO;BP@<&%G97,@;W9E<B!A(&-E
M<G1A:6X@<VEZ92!W:6QL(&)E(&-O;7!R97-S960*("!A;F0@<V5N="!T;R!T
M:&4@8G)O=W-E<B!A<R!G>FEP+65N8V]D960@9&%T82!I;B!O<F1E<B!T;R!S
M879E"B`@8F%N9'=I9'1H+B!4:&5R92!I<R!A($-052UU<V%G92!P96YA;'1Y
M('1O('!A>2!F;W(@=&AI<RP@8G5T('1H92!D96-R96%S92!I;@H@('!A9V4@
M<VEZ92!C86X@8F4@9')A;6%T:6,@*#<P:R!T;R!U;F1E<B`Q,&L@9F]R(&$@
M9G5L;"!M86EL8F]X('!A9V4I+"!A;F0@:7,*("!M;W)E('1H86X@=V]R=&@@
M:70@;W9E<B!A;GET:&EN9R!B=70@86X@97AT<F5M96QY(&9A<W0*("!L:6YK
M+B(^=')U93PO8V]N9FEG8F]O;&5A;CX*("`\8V]N9FEG:6YT96=E<B!N86UE
M/2)U;6%S:R(@;V-T86P](G1R=64B(&1E<V,](E=H870@=6UA<VL@<VAO=6QD
M('=E(')U;B!W:71H/R!4:&ES('=I;&P@869F96-T('1H92!P97)M:7-S:6]N
M<R!O;B!A;GD@=&5M<&]R87)Y(&9I;&5S('1H870@87)E(&-R96%T960N(%1H
M:7,@=F%L=64@:7,@86X@:6YT96=E<BXB/C`W-SPO8V]N9FEG:6YT96=E<CX*
M("`\8V]N9FEG<W1R:6YG(&YA;64](G1M<&1I<B(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2))9B!Y;W4@=V%N="!T;R!U<V4@80H@('1E;7!O<F%R>2!D:7)E
M8W1O<GD@;W1H97(@=&AA;B!T:&4@<WES=&5M(&1E9F%U;'0@;W(@=&AE(&]N
M92!S<&5C:69I960@:6X*("!P:'`G<R!U<&QO861?=&UP7V1I<B!V86QU92P@
M96YT97(@:70@:&5R92XB+SX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S97-S
M:6]N(CX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)N86UE(B!D97-C/2)7:&%T
M(&YA;64@<VAO=6QD('=E('5S92!F;W(@=&AE('-E<W-I;VX@=&AA=`H@("!(
M;W)D92!A<'!S('-H87)E/R!)9B!Y;W4@=V%N="!T;R!S:&%R92!S97-S:6]N
M<R!W:71H(&]T:&5R(&%P<&QI8V%T:6]N<R!O;@H@("!Y;W5R('=E8G-E<G9E
M<BP@>6]U('=I;&P@;F5E9"!T;R!M86ME('-U<F4@=&AA="!T:&5Y(&%R92!U
M<VEN9R!T:&4@<V%M90H@("!S97-S:6]N(&YA;64N("!.;W1E.B!397-S:6]N
M(&YA;65S(&UU<W0@8V]N<VES="!O9B!O;FQY(&%L<&AA;G5M97)I8PH@("!C
M:&%R86-T97)S+B(^2&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)C86-H95]L:6UI=&5R(B!D97-C/2)7:&%T(&-A8VAI;F<@
M;&5V96P@<VAO=6QD('=E('5S90H@("!F;W(@=&AE('-E<W-I;VX_($1/($Y/
M5"!#2$%.1T4@5$A)4R!53DQ%4U,@64]5("9L=#MS=')O;F<F9W0[4D5!3$Q9
M)FQT.R]S=')O;F<F9W0[($M.3U<*("`@5TA!5"!93U4@05)%($1/24Y'+B!3
M971T:6YG('1H:7,@=&\@86YY=&AI;F<@;W1H97(@=&AA;B`G;F]C86-H92<@
M=VEL;"!A;&UO<W0*("`@8V5R=&%I;FQY(')E<W5L="!I;B!S979E<F5L>2!B
M<F]K96X@<V-R:7!T(&)E:&%V:6]R+B(^;F]C86-H93PO8V]N9FEG<W1R:6YG
M/@H@("`\8V]N9FEG:6YT96=E<B!N86UE/2)T:6UE;W5T(B!D97-C/2)(;W<@
M;&]N9R!S:&]U;&0@<V5S<VEO;G,@;&%S="`H:6X@<V5C;VYD<RD_(#`@;65A
M;G,*("`@=&AA="!T:&4@<V5S<VEO;B!E;F1S('=H96X@=&AE('5S97(@8VQO
M<V5S('1H96ER(&)R;W=S97(N(%-E="!O=&AE<B!V86QU97,*("`@=VET:"!C
M87)E("T@<V5E"B`@(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N
M8W1I;VXN<V5S<VEO;BUS970M8V]O:VEE+7!A<F%M<RYP:'`N(CXP/"]C;VYF
M:6=I;G1E9V5R/@H@(#PO8V]N9FEG<V5C=&EO;CX*("`\8V]N9FEG<V5C=&EO
M;B!N86UE/2)C;V]K:64B/@H@("`\8V]N9FEG<&AP(&YA;64](F1O;6%I;B(@
M9&5S8STB5VAA="!D;VUA:6X@<VAO=6QD('=E('-E="!C;V]K:65S(&9R;VT_
M($EF"B`@('EO=2!H879E(&$@8VQU<W1E<B!T:&%T(&YE961S('1O('-H87)E
M(&-O;VMI97,L('1H:7,@;6EG:'0@8F4@)RYE>&%M<&QE+F-O;2<*("`@+2!T
M:&4@;&5A9&EN9R`G+B<@:7,@:6UP;W)T86YT+B!-;W-T(&QI:V5L>2P@=&AO
M=6=H+"!Y;W4@=V]N)W0@:&%V92!T;R!C:&%N9V4*("`@=&AE(&1E9F%U;'0N
M(CXD7U-%4E9%4ELG4T525D527TY!344G73PO8V]N9FEG<&AP/@H@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G!A=&@B(&1E<V,](E=H870@<&%T:"!S:&]U;&0@
M=V4@<V5T(&-O;VMI97,@=&\_(%1H:7,*("`@<VAO=6QD(&UA=&-H('=H97)E
M($AO<F1E(&ES(&]N('EO=7(@=V5B<V5R=F5R("T@:68@:70@:7,@870@+VAO
M<F1E+"!T:&5N('1H:7,*("`@<VAO=6QD(&)E("<O:&]R9&4G+B!)9B!(;W)D
M92!I<R!I;G-T86QL960@87,@=&AE(&1O8W5M96YT(')O;W0L('1H96X@=&AI
M<PH@("!N965D<R!T;R!B92`G+R<@+2!.3U0@)R<N)FQT.V)R("\F9W0[)FQT
M.W-T<F]N9R9G=#M"550F;'0[+W-T<F]N9R9G=#LL(&EF($E%('=I;&P@8F4*
M("`@=7-E9"!T;R!A8V-E<W,@2&]R9&4@;6]D=6QE<RP@>6]U('-H;W5L9"!R
M96%D('1H:7,@9FER<W0@*&1I<V-U<W-I;F<@:7-S=65S"B`@('=I=&@@244G
M<R!#;VYT96YT($%D=FES;W(I.@H@("!H='1P.B\O;&ES=',N:&]R9&4N;W)G
M+V%R8VAI=F5S+VEM<"]7965K+6]F+4UO;BTR,#`S,#$Q,R\P,CDQ-#DN:'1M
M;"(^+VAO<F1E/"]C;VYF:6=S=')I;F<^"B`@/"]C;VYF:6=S96-T:6]N/@H@
M/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)S<6PB(&1E<V,](D1A
M=&%B87-E(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S<6PB/@H@("`\8V]N
M9FEG:&5A9&5R/DAO<F1E($1A=&%B87-E(%-E='1I;F=S/"]C;VYF:6=H96%D
M97(^"B`@(#QC;VYF:6=D97-C<FEP=&EO;CXF;'0[<W1R;VYG)F=T.TY/5$4Z
M)FQT.R]S=')O;F<F9W0[(%1H97-E(&%R92!O;FQY('1H90H@("`F;'0[96TF
M9W0[9&5F875L="9L=#LO96TF9W0[('9A;'5E<R!F;W(@86YY(&1A=&%B87-E
M(&1R:79E;B!B86-K96YD<RX@66]U"B`@('-T:6QL(&YE960@=&\@8V]N9FEG
M=7)E('1H92!D:69F97)E;G0@<WES=&5M<R!L:6ME(")0<F5F97)E;F-E<R(@
M;W(*("`@(D1A=&%4<F5E(B!T;R!A8W1U86QL>2`F;'0[96TF9W0[=7-E)FQT
M.R]E;29G=#L@82!D871A8F%S90H@("!B86-K96YD+CPO8V]N9FEG9&5S8W)I
M<'1I;VX^"B`@(#QC;VYF:6=S<6P@<W=I=&-H;F%M93TB<&AP='EP92(@8F%S
M96-O;F9I9STB=')U92(@+SX*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I
M9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](F%U=&@B(&1E<V,](D%U=&AE;G1I
M8V%T:6]N(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)A=71H(CX*("`@/&-O
M;F9I9VAE861E<CY(;W)D92!!=71H96YT:6-A=&EO;CPO8V]N9FEG:&5A9&5R
M/@H@("`\8V]N9FEG;&ES="!N86UE/2)A9&UI;G,B(&1E<V,](E=H:6-H('5S
M97)S('-H;W5L9"!B92!T<F5A=&5D(&%S"B`@(&%D;6EN:7-T<F%T;W)S("AR
M;V]T+"!S=7!E<BUU<V5R*2!B>2!(;W)D93\B(')E<75I<F5D/2)F86QS92(O
M/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)C:&5C:VEP(B!D97-C/2)3:&]U
M;&0@=V4@86QW87ES('-T;W)E(&%N9"!V86QI9&%T90H@("!T:&4@25`@861D
M<F5S<R!O9B!T:&4@8VQI96YT("AA<R!S965N(&)Y('1H92!W96(@<V5R=F5R
M*2!I;B!T:&4@<V5S<VEO;C\*("`@1&]I;F<@<V\@=VEL;"!H96QP(&EN8W)E
M87-E('-E8W5R:71Y(&)Y(&5N<W5R:6YG('1H870@86X@871T86-K97(@9G)O
M;0H@("!A;F]T:&5R(&AO<W0@8V%N;F]T('1R>2!T;R!H:6IA8VL@=&AE('-E
M<W-I;VXN(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@("`\8V]N9FEG8F]O;&5A
M;B!N86UE/2)C:&5C:V)R;W=S97(B(&1E<V,](E-H;W5L9"!W92!A;'=A>7,@
M<W1O<F4@86YD('9A;&ED871E"B`@('1H92!B<F]W<V5R('-T<FEN9R!O9B!T
M:&4@8VQI96YT("AA<R!S965N(&)Y('1H92!W96(@<V5R=F5R*2!I;B!T:&4@
M<V5S<VEO;C\*("`@1&]I;F<@<V\@=VEL;"!H96QP(&EN8W)E87-E('-E8W5R
M:71Y(&)Y(&5N<W5R:6YG('1H870@86X@871T86-K97(@9G)O;0H@("!A;F]T
M:&5R(&AO<W0@8V%N;F]T('1R>2!T;R!H:6IA8VL@=&AE('-E<W-I;VXN(CYT
M<G5E/"]C;VYF:6=B;V]L96%N/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](F%L
M=&5R;F%T95]L;V=I;B(@9&5S8STB268@=&AI<R!I<R!N;W0@9F%L<V4L(&ET
M(&ES"B`@(&%S<W5M960@=&\@8F4@=&AE(%523"!O9B!A;B!A;'1E<FYA=&4@
M;&]G:6X@<V-R965N('=H:6-H('=I;&P@8F4@=7-E9"!I;@H@("!P;&%C92!O
M9B!H;W)D92=S(&1E9F%U;'0@;&]G:6X@<V-R965N+B(^9F%L<V4\+V-O;F9I
M9W-T<FEN9SX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)R961I<F5C=%]O;E]L
M;V=O=70B(&1E<V,](DEF('1H:7,@:7,@;F]T(&9A;'-E+"!I="!I<PH@("!A
M<W-U;65D('1O(&)E('1H92!54DP@;V8@86X@86QT97)N871E(&QO9V]U="!P
M86=E('=H:6-H('5S97)S('=I;&P@8F4@<V5N=`H@("!T;R!W:&5N('1H97D@
M;&]G(&]U="XB/F9A;'-E/"]C;VYF:6=S=')I;F<^"B`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB9')I=F5R(B!D97-C/2)7:&%T(&)A8VME;F0@<VAO=6QD('=E
M('5S92!F;W(*("`@875T:&5N=&EC871I;F<@=7-E<G,@=&\@2&]R9&4_(CX*
M"B`@("`\8V%S92!N86UE/2)A<'!L:6-A=&EO;B(@9&5S8STB3&5T(&$@2&]R
M9&4@87!P;&EC871I;VX@:&%N9&QE"B`@("!A=71H96YT:6-A=&EO;B(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I
M9V5N=6T@;F%M93TB87!P(B!D97-C/2)4:&4@87!P;&EC871I;VX@=VAI8V@@
M:7,@<')O=FED:6YG"B`@("`@(&%U=&AE;G1I8V%T:6]N(CYI;7`*("`@("`@
M(#QV86QU97,^"B`@("`@("`@/&-O;F9I9W-P96-I86P@;F%M93TB;&ES="UH
M;W)D92UA<'!S(B\^"B`@("`@("`\+W9A;'5E<SX*("`@("`@/"]C;VYF:6=E
M;G5M/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\
M8V%S92!N86UE/2)A=71O(B!D97-C/2)!=71O;6%T:6,@875T:&5N=&EC871I
M;VX@87,@82!C97)T86EN('5S97(B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA
M;64B(&1E<V,](E1H92!U<V5R;F%M92!T;R!A=71H96YT:6-A=&4@979E<GEO
M;F4@87,B/FAO<F1E7W5S97(\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@9&5S8STB5&AE('!A<W-W;W)D('1O
M('5S92!F;W(@=&AE('5S97(G<R!C<F5D96YT:6%L<R(@<F5Q=6ER960](F9A
M;'-E(B\^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G)E<75E<W1U<V5R
M(B!D97-C/2)!;&QO=R!U<V5R;F%M92!T;R!B92!P87-S960@8GD@1T54+"!0
M3U-4(&]R(&-O;VMI93\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@(#PO
M8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)C
M;VUP;W-I=&4B(&1E<V,](D-O;7!O<VET92!A=71H96YT:6-A=&EO;B(^"B`@
M("`@/&-O;F9I9V1E<V-R:7!T:6]N/@H@("`@("!4:&ES(&%U=&AE;G1I8V%T
M:6]N(&1R:79E<B!N965D<R!M86YU86P@8V]N9FEG=7)A=&EO;B!N;W0@<&]S
M<VEB;&4*("`@("`@=&AR;W5G:"!T:&ES(&EN=&5R9F%C92X@061D('1H92!A
M<'!R;W!R:6%T92!C;VYF:6=U<F%T:6]N(&QI;F5S(&%T('1H90H@("`@("!E
M;F0@;V8@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&9I;&4N"B`@("`@
M/"]C;VYF:6=D97-C<FEP=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N
M86UE/2)F='`B(&1E<V,](D944"!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5&AE(&AO<W1N86UE(&]R($E0(&%D
M9')E<W,@;V8@=&AE($944`H@("`@("!S97)V97(B/FQO8V%L:&]S=#PO8V]N
M9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!D
M97-C/2)4:&4@<V5R=F5R('!O<G0@=&\@8V]N;F5C=`H@("`@("!T;R(^,C$\
M+V-O;F9I9VEN=&5G97(^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C
M87-E/@H*("`@(#QC87-E(&YA;64](FAT='`B(&1E<V,](DA45%`@*$)A<VEC
M($%U=&AE;G1I8V%T:6]N+RYH='!A<W-W9"D*("`@(&%U=&AE;G1I8V%T:6]N
M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](FAT<&%S<W=D7V9I;&4B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AE(&QO8V%T:6]N(&]F"B`@("`@('1H92!H='!A<W-W
M9"!F:6QE(&-O;G1A:6YI;F<@=&AE('5S97(@;F%M97,@86YD('!A<W-W;W)D
M<R(O/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)E;F-R>7!T:6]N(B!D97-C
M/2)3<&5C:69I97,@=VAA="!K:6YD(&]F('!A<W-W;W)D<R!A<F4*("`@("`@
M:6X@=&AE(&AT<&%S<W=D(&9I;&4B/F1E<PH@("`@("`@/'9A;'5E<SX*("`@
M("`@("`\=F%L=64^87!R;60U/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y
M<'0\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UB;&]W9FES:#PO=F%L
M=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+61E<SPO=F%L=64^"B`@("`@("`@
M/'9A;'5E/F-R>7!T+6UD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/FUD-2UB
M87-E-C0\+W9A;'5E/@H@("`@("`@(#QV86QU93YM9#4M:&5X/"]V86QU93X*
M("`@("`@("`\=F%L=64^<&QA:6X\+W9A;'5E/@H@("`@("`@(#QV86QU93YS
M:&$\+W9A;'5E/@H@("`@("`@(#QV86QU93YS;60U/"]V86QU93X*("`@("`@
M("`\=F%L=64^<W-H83PO=F%L=64^"B`@("`@("`\+W9A;'5E<SX*("`@("`@
M/"]C;VYF:6=E;G5M/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S
M93X*"B`@("`\8V%S92!N86UE/2)I;6%P(B!D97-C/2))34%0(&%U=&AE;G1I
M8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@
M("`@("`\8V]N9FEG<W=I=&-H(&YA;64](FEM87!C;VYF:6<B(&1E<V,](D-O
M;F9I9W5R871I;VX@='EP92(^"B`@("`@("`\8V%S92!N86UE/2)D<VXB(&1E
M<V,](D133B(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D<VXB(&1E
M<V,](E1H92!F=6QL($E-05`@8V]N;F5C=&EO;@H@("`@("`@('-T<FEN9R(^
M>VQO8V%L:&]S=#HQ-#,O:6UA<"]N;W1L<WT\+V-O;F9I9W-T<FEN9SX*("`@
M("`@(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G-E<&%R871E(B!D97-C
M/2)397!A<F%T92!V86QU97,B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB:&]S='-P96,B(&1E<V,](E1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S
M(&]F('1H90H@("`@("`@('-E<G9E<B(^;&]C86QH;W-T/"]C;VYF:6=S=')I
M;F<^"B`@("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@9&5S8STB
M5&AE('-E<G9E<B!P;W)T('1O('=H:6-H('=E('=I;&P*("`@("`@("!C;VYN
M96-T+B!)34%0(&ES(&=E;F5R86QL>2`Q-#,L('=H:6QE($E-05`M4U-,(&ES
M(&=E;F5R86QL>0H@("`@("`@(#DY,RXB/C$T,SPO8V]N9FEG:6YT96=E<CX*
M("`@("`@("`\8V]N9FEG96YU;2!N86UE/2)P<F]T;V-O;"(@9&5S8STB5&AE
M(&-O;FYE8W1I;VX@<')O=&]C;VPB/FEM87`O;F]T;',*("`@("`@("`@/'9A
M;'5E<SX*("`@("`@("`@(#QV86QU93YI;6%P/"]V86QU93X*("`@("`@("`@
M(#QV86QU93YI;6%P+VYO=F%L:61A=&4M8V5R=#PO=F%L=64^"B`@("`@("`@
M("`\=F%L=64^:6UA<"]N;W1L<SPO=F%L=64^"B`@("`@("`@("`\=F%L=64^
M:6UA<"]T;',\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E/FEM87`O=&QS+VYO
M=F%L:61A=&4M8V5R=#PO=F%L=64^"B`@("`@("`@("`\=F%L=64^:6UA<"]S
M<VP\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E/FEM87`O<W-L+VYO=F%L:61A
M=&4M8V5R=#PO=F%L=64^"B`@("`@("`@(#PO=F%L=65S/@H@("`@("`@(#PO
M8V]N9FEG96YU;3X*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF:6=S=VET
M8V@^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC
M87-E(&YA;64](FEM<W`B(&1E<V,](DE-4U`@<V5R=F5R(&%U=&AE;G1I8V%T
M:6]N(B`O/@H*("`@(#QC87-E(&YA;64](FEP8F%S:6,B(&1E<V,](E-I;7!L
M92!)4"!B87-E9"!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9VQI<W0@;F%M93TB8FQO
M8VMS(B!D97-C/2)!(&QI<W0@;V8@0TE$4B!M87-K<R!W:&EC:"!A<F4@86QL
M;W=E9`H@("`@("!A8V-E<W,B+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@
M("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB:7!M87`B(&1E<V,](DE0(&)A
M<V5D(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE
M/2)P87)A;7,B/@H@("`@("`\8V]N9FEG;&ES="!N86UE/2)B;&]C:W,B(&1E
M<V,](D$@;&ES="!O9B!#2412(&UA<VMS('=H:6-H(&%R92!A;&QO=V5D"B`@
M("`@(&%C8V5S<R(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S
M93X*"B`@("`\8V%S92!N86UE/2)K<F(U(B!D97-C/2)+97)B97)O<R!A=71H
M96YT:6-A=&EO;B(O/@H*("`@(#QC87-E(&YA;64](FMO;&%B(B!D97-C/2)+
M;VQA8B!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB<&%R86US(CX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB;&]G:6Y?
M8FQO8VLB(&1E<V,](E-H;W5L9"!T:&4@;&]G:6X@8F4@8FQO8VME9"!A9G1E
M<B!A(&=I=F5N(&YU;6)E<B!O9B!F86EL960@;&]G:6YS/R(^"B`@("`@(&9A
M;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE
M/2)L;V=I;E]B;&]C:U]C;W5N="(@9&5S8STB069T97(@:&]W;6%N>2!F86EL
M960@;&]G:6YS('1H92!L;V=I;B!S:&]U;&0@8F4@8FQO8VME9#\B/C,\+V-O
M;F9I9VEN=&5G97(^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](FQO9VEN
M7V)L;V-K7W1I;64B(&1E<V,](DAO=VUA;GD@;6EN=71E<R!T:&4@;&]G:6X@
M<VAO=6QD(&)E(&)L;V-K960_(CXU/"]C;VYF:6=I;G1E9V5R/@H@("`@(#PO
M8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)L
M9&%P(B!D97-C/2),1$%0(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](FAO<W1S<&5C(B!D97-C/2)4:&4@:&]S=&YA;64@;V8@=&AE($Q$05`@
M<V5R=F5R(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)B87-E9&XB(&1E<V,](E1H92!B87-E($1.(&9O<B!T
M:&4@3$1!4"!S97)V97(B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)B
M:6YD9&XB(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE($1.('5S960@=&\@
M8FEN9"!T;R!T:&4@3$1!4"!S97)V97(B+SX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@
M<&%S<W=O<F0@=7-E9"!T;R!B:6YD('1O('1H92!,1$%0('-E<G9E<B(O/@H@
M("`@("`\8V]N9FEG96YU;2!N86UE/2)V97)S:6]N(B!D97-C/2),1$%0(%!R
M;W1O8V]L(%9E<G-I;VXB/C,*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A
M;'5E(&1E<V,](DQ$05!V,B`H1&5P<F5C871E9"DB/C(\+W9A;'5E/@H@("`@
M("`@(#QV86QU92!D97-C/2),1$%0=C,B/C,\+W9A;'5E/@H@("`@("`@/"]V
M86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@/&-O;F9I9V)O;VQE
M86X@;F%M93TB860B(&1E<V,](DES('1H:7,@86X@040@<V5R=F5R/R(^9F%L
M<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M=6ED(B!D97-C/2)4:&4@=7-E<FYA;64@<V5A<F-H(&ME>2`H<V5T('1O('-A
M;6%C8V]U;G1N86UE(&9O<B!!1"DB+SX*("`@("`@/&-O;F9I9V5N=6T@;F%M
M93TB96YC<GEP=&EO;B(@9&5S8STB06QG;W)I=&AM('1O(&5N8W)Y<'0@<&%S
M<W=O<F1S(CYM9#4M:&5X"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU
M92!D97-C/2)A<')M9#4B/F%P<FUD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E
M(&1E<V,](F-R>7!T(CYC<GEP=#PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E
M<V,](F-R>7!T+61E<R(^8W)Y<'0M9&5S/"]V86QU93X*("`@("`@("`\=F%L
M=64@9&5S8STB8W)Y<'0M;60U(CYC<GEP="UM9#4\+W9A;'5E/@H@("`@("`@
M(#QV86QU92!D97-C/2)C<GEP="UB;&]W9FES:"(^8W)Y<'0M8FQO=V9I<V@\
M+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)M9#4M8F%S938T(CYM9#4M
M8F%S938T/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB;60U+6AE>"(^
M;60U+6AE>#PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](FUS860B/FUS
M860\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)P;&%I;B(^<&QA:6X\
M+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)S<VAA(CYS<VAA/"]V86QU
M93X*("`@("`@("`\=F%L=64@9&5S8STB<VUD-2(^<VUD-3PO=F%L=64^"B`@
M("`@("`\+W9A;'5E<SX*("`@("`@/"]C;VYF:6=E;G5M/@H*("`@("`@/&-O
M;F9I9VQI<W0@;F%M93TB;F5W=7-E<E]O8FIE8W1C;&%S<R(@9&5S8STB5VAA
M="!O8FIE8W1C;&%S<V5S('-H;W5L9"!A(&YE=R!U<V5R(&%C8V]U;G0@8F4@
M;65M8F5R(&]F/R!4:&5S92!O8FIE8W1C;&%S<V5S('-H;W5L9"!C;W9E<B!T
M:&4@8VXL<VXL=7-E<E!A<W-W;W)D(&%T=')I8G5T97,@87,@=V5L;"!A<R!T
M:&4@=7-E<FYA;64@<V5A<F-H(&ME>2(^<VAA9&]W06-C;W5N="QI;F5T3W)G
M4&5R<V]N/"]C;VYF:6=L:7-T/@H*("`@("`@/&-O;F9I9W-W:71C:"!N86UE
M/2)F:6QT97)?='EP92(@9&5S8STB2&]W('1O('-P96-I9GD@82!F:6QT97(@
M9F]R('1H92!U<V5R(&QI<W1S(CYO8FIE8W1C;&%S<PH@("`@("`@/&-A<V4@
M;F%M93TB;V)J96-T8VQA<W,B(&1E<V,](D]N92!O<B!M;W)E(&]B:F5C=&-L
M87-S(&9I;'1E<G,B/@H@("`@("`@(#QC;VYF:6=L:7-T(&YA;64](F]B:F5C
M=&-L87-S(B!D97-C/2)4:&4@;V)J96-T8VQA<W,@9FEL=&5R('5S960@=&\@
M<V5A<F-H(&9O<B!U<V5R<RX@0V%N(&)E(&$@<VEN9VQE(&]B:F5C=&-L87-S
M(&]R(&$@;&ES="XB+SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC87-E(&YA
M;64](F9R964B(&1E<V,](D$@8V]M<&QE=&4@3$1!4"!F:6QT97(@97AP<F5S
M<VEO;B(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F:6QT97(B(&1E
M<V,](E1H92!,1$%0(%)&0R!F;W)M871T960@9FEL=&5R('5S960@=&\@<V5A
M<F-H(&9O<B!U<V5R<RXB+SX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF
M:6=S=VET8V@^"@H@("`@("`\8V]N9FEG<W=I=&-H(&YA;64](G!A<W-W;W)D
M7V5X<&ER871I;VXB(&1E<V,](D5N86)L92!T:&4@8W)E871I;F<@;V8@86-C
M;W5N=',@=VET:"!E>'!I<FEN9R!P87-S=V]R9',_("A.;W1E.B!.97<@=7-E
M<G,@<VAO=6QD(&AA=F4@=&AE('-H861O=T%C8V]U;G0@;V)J96-T8VQA<W,I
M(CYN;PH@("`@("`@/&-A<V4@;F%M93TB;F\B(&1E<V,](FYO(B`O/@H@("`@
M("`@/&-A<V4@;F%M93TB>65S(B!D97-C/2)Y97,B/@H@("`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB;6EN86=E(B!D97-C/2)!9G1E<B!H;W<@;6%N>2!D
M87ES(&UA>2!A('!A<W-W;W)D(&)E(&-H86YG960@86=A:6X_(CXU/"]C;VYF
M:6=S=')I;F<^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)M87AA9V4B
M(&1E<V,](DAO=R!M86YY(&1A>7,@=VEL;"!A('!A<W-W;W)D(')E;6%I;B!V
M86QI9#\B/C,P/"]C;VYF:6=S=')I;F<^"B`@("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)W87)N86=E(B!D97-C/2)(;W<@;6%N>2!D87ES(&)E9F]R92!E
M>'!I<F5R>2!S:&]U;&0@82!U<V5R(&)E('=A<FYE9#\B/C4\+V-O;F9I9W-T
M<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@
M("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA
M;64](FQO9VEN(B!D97-C/2),;V=I;B`H<W4I(&%U=&AE;G1I8V%T:6]N(CX*
M("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](FQO8V%T:6]N(B!D97-C/2),;V-A=&EO;B!O9B!T
M:&4@<W4@8FEN87)Y(CXO8FEN+W-U/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C
M;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](FUC
M86PB(&1E<V,](DU#04P@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S
M96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB8V%L96YD87(B(&1E<V,](E1H92!-0T%,(&-A;&5N9&%R(&YA;64B+SX*
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@
M;F%M93TB<&%M(B!D97-C/2)004T@*%!L=6=G86)L92!!=71H96YT:6-A=&EO
M;B!-;V1U;&5S*2!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S
M97)V:6-E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@4$%-('-E<G9I8V4@=&\@
M=7-E('=H96X@875T:&5N=&EC871I;F<B/G!H<#PO8V]N9FEG<W1R:6YG/@H@
M("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N
M86UE/2)P87-S=V0B(&1E<V,](G!A<W-W9"!F:6QE(&%U=&AE;G1I8V%T:6]N
M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](F9I;&5N86UE(B!D97-C/2)4:&4@<&%S<W=D
M(&9I;&4@=&\@=7-E(CXO971C+W!A<W-W9#PO8V]N9FEG<W1R:6YG/@H@("`@
M("`\8V]N9FEG8F]O;&5A;B!N86UE/2)L;V-K(B!D97-C/2)3:&]U;&0@=V4@
M;&]C:R!T:&4@<&%S<W=D(&9I;&4_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@
M;F%M93TB<F%D:75S(B!D97-C/2)2861I=7,@875T:&5N=&EC871I;VXB/@H@
M("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB:&]S="(@9&5S8STB5&AE(%)!1$E54R!H;W-T('1O
M('5S92`H25`@861D<F5S<R!O<B!F=6QL>2!Q=6%L:69I960@:&]S=&YA;64I
M(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9VEN=&5G
M97(@;F%M93TB<&]R="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@<&]R
M="!T;R!U<V4@;VX@=&AE(%)!1$E54R!S97)V97(B+SX*("`@("`@/&-O;F9I
M9V5N=6T@;F%M93TB;65T:&]D(B!D97-C/2)4:&4@4D%$2553(&UE=&AO9"!T
M;R!U<V4@9F]R('9A;&ED871I;F<@=&AE(')E<75E<W0B/E!!4`H@("`@("`@
M/'9A;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB4$%0(CY005`\+W9A;'5E
M/@H@("`@("`@(#QV86QU92!D97-C/2)#2$%07TU$-2`H;F]T('-U<'!O<G1E
M9"!A="!T:&4@;6]M96YT*2(^0TA!4%]-1#4\+W9A;'5E/@H@("`@("`@(#QV
M86QU92!D97-C/2)-4T-(05!V,2`H;F]T('-U<'!O<G1E9"!A="!T:&4@;6]M
M96YT*2(^35-#2$%0=C$\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)-
M4T-(05!V,B`H;F]T('-U<'!O<G1E9"!A="!T:&4@;6]M96YT*2(^35-#2$%0
M=C(\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU
M;3X*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)N87,B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AE(%)!1$E54R!.05,@:61E;G1I9FEE<B!T;R!U<V4N
M(B`O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-E8W)E="(@9&5S8STB
M5&AE(%)!1$E54R!S:&%R960@<V5C<F5T('-T<FEN9R!F;W(@=&AE"B`@("`@
M(&AO<W0N(%1H92!2041)55,@<')O=&]C;VP@:6=N;W)E<R!A;&P@8G5T('1H
M92!L96%D:6YG(#$R."!B>71E<R!O9B!T:&4*("`@("`@<VAA<F5D('-E8W)E
M="XB+SX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<F5T<FEE<R(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)4:&4@;6%X:6UU;2!N=6UB97(*("`@("`@
M;V8@<F5P96%T960@<F5Q=65S=',@=&\@;6%K92!B969O<F4@9VEV:6YG('5P
M(%LS72(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-U9F9I>"(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)4:&4@9&]M86EN(&YA;64@=&\@861D"B`@
M("`@('1O('5N<75A;&EF:65D('5S97(@;F%M97,B+SX*("`@("`@/&-O;F9I
M9VEN=&5G97(@;F%M93TB=&EM96]U="(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)4:&4@=&EM96]U="!F;W(*("`@("`@<F5C96EV:6YG(')E<&QI97,@9G)O
M;2!T:&4@<V5R=F5R("AI;B!S96-O;F1S*2!;,UTB+SX*("`@("`\+V-O;F9I
M9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB<V%S;"(@
M9&5S8STB4T%33"!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A
M<'`B(&1E<V,](E1H92!N86UE(&]F('1H92!A=71H96YT:6-A=&EN9PH@("`@
M("!A<'!L:6-A=&EO;B(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)S97)V:6-E(B!D97-C/2)4:&4@;F%M92!O9B!T
M:&4@4T%33"!S97)V:6-E('1O('5S90H@("`@("!W:&5N(&%U=&AE;G1I8V%T
M:6YG(CYP:'`\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I;VX^
M"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB<VUB(B!D97-C/2)334(@
M875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A
M<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E
M<V,](DE0+"!$3E,@3F%M92P@;W(@3F5T0FEO<R!.86UE(&]F('1H90H@("`@
M("!334(@<V5R=F5R('1O(&%U=&AE;G1I8V%T92!W:71H(CYL;V-A;&AO<W0\
M+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D;VUA
M:6XB(&1E<V,](E1H92!D;VUA:6X@;F%M92!T;R!A=71H96YT:6-A=&4@=VET
M:"(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F=R;W5P(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](D]P=&EO;F%L(&=R;W5P(&YA;64*("`@("`@=&AA
M="!T:&4@=7-E<B!M=7-T(&)E(&$@;65M8F5R(&]F(B\^"B`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](G-Q;"(@
M9&5S8STB4U%,(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO
M;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W%L('-W:71C:&YA;64]
M(F1R:79E<F-O;F9I9R(@+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T
M86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@
M875T:`H@("`@("!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W5S97)S
M72(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE7V9I96QD
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!N86UE(&]F('1H90H@("`@
M("!U<V5R;F%M92!F:65L9"!I;B!T:&4@875T:"!T86)L92!;=7-E<E]U:61=
M(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O<F1?9FEE;&0B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE"B`@("`@
M('!A<W-W;W)D(&9I96QD(&EN('1H92!A=71H('1A8FQE(%MU<V5R7W!A<W-=
M(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]F=%]E>'!I<F%T:6]N
M7V9I96QD(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H90H@("`@("!N86UE
M(&]F(&$@9FEE;&0@8V]N=&%I;FEN9R!A(%5.25@@=&EM97-T86UP+B`@5VAE
M;B!A('5S97(@;&]G<R!I;B!A9G1E<@H@("`@("!T:&4@<W!E8VEF:65D('1I
M;64L(&EF("=P87-S=V0G(&ES(&EN<W1A;&QE9"P@=&AA="!U<V5R('=I;&P@
M8F4@87-K960@=&\*("`@("`@8VAA;F=E(&AI<R!O<B!H97(@<&%S<W=O<F0N
M("!4:&ES(&9E871U<F4@:7,@9&ES86)L960@8GD@9&5F875L="XB+SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H87)D7V5X<&ER871I;VY?9FEE;&0B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE"B`@("`@(&YA;64@;V8@82!F
M:65L9"!C;VYT86EN:6YG(&$@54Y)6"!T:6UE<W1A;7`N("!!('5S97(@=VEL
M;"!N;W0@8F4@86)L92!T;PH@("`@("!L;V<@:6X@869T97(@=&AE('-P96-I
M9FEE9"!T:6UE+B`@5&AI<R!F96%T=7)E(&ES(&1I<V%B;&5D(&)Y(&1E9F%U
M;'0N(B\^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G-O9G1?97AP:7)A
M=&EO;E]W:6YD;W<B(')E<75I<F5D/2)F86QS92(*("`@("`@9&5S8STB5&AI
M<R!I<R!H;W<@;V9T96XL(&EN(&1A>7,L('1H92!U<V5R(&UU<W0@8VAA;F=E
M(&AI<R!O<B!H97(*("`@("`@<&%S<W=O<F0N("!7:&5N('1H92!U<V5R)W,@
M<&%S<W=O<F0@:7,@=7!D871E9"P@=&AE("9Q=6]T.W-O9G0F<75O=#L*("`@
M("`@97AP:7)A=&EO;B!I<R!S970@=&AI<R!M86YY(&1A>7,@:6X@=&AE(&9U
M='5R92X@($EF(&YO="!P<F]V:61E9"P*("`@("`@=&AE('5S97(G<R!P87-S
M=V]R9"!W:6QL(&YO="!E>'!I<F4@8GD@9&5F875L="XB+SX*("`@("`@/&-O
M;F9I9VEN=&5G97(@;F%M93TB:&%R9%]E>'!I<F%T:6]N7W=I;F1O=R(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)4:&4*("`@("`@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&=R86-E('!E<FEO9"!T:&4@=7-E<B!H87,@=&\@8VAA;F=E(&AI
M<R!O<B!H97(*("`@("`@<&%S<W=O<F0@869T97(@:70@:&%S(&5X<&ER960N
M("!)9B!N;W0@<')O=FED960L('1H92!G<F%C92!P97)I;V0@=VEL;`H@("`@
M("!N;W0@97AP:7)E+B(O/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)E;F-R
M>7!T:6]N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!E;F-R>7!T:6]N
M('1O('5S90H@("`@("!T;R!S=&]R92!T:&4@<&%S<W=O<F0@:6X@=&AE('1A
M8FQE(CYM9#4M:&5X"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU93YC
M<GEP=#PO=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+6)L;W=F:7-H/"]V
M86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M9&5S/"]V86QU93X*("`@("`@
M("`\=F%L=64^8W)Y<'0M;60U/"]V86QU93X*("`@("`@("`\=F%L=64^;60U
M+6)A<V4V-#PO=F%L=64^"B`@("`@("`@/'9A;'5E/FUD-2UH97@\+W9A;'5E
M/@H@("`@("`@(#QV86QU93YP;&%I;CPO=F%L=64^"B`@("`@("`@/'9A;'5E
M/G-H83PO=F%L=64^"B`@("`@("`@/'9A;'5E/G-M9#4\+W9A;'5E/@H@("`@
M("`@(#QV86QU93YS<VAA/"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@("`@
M("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G-H
M;W=?96YC<GEP=&EO;B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)0<F5P96YD
M('1H90H@("`@("!E;F-R>7!T:6]N(&EN('1H92!P87-S=V]R9"!F:65L9#\B
M/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*
M("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)C=7-T;VUS<6PB(&1E<V,]
M(E-13"!A=71H96YT:6-A=&EO;B!W+V-U<W1O;2UM861E('%U97)I97,B/@H@
M("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF
M:6=E;G5M(&YA;64](G!H<'1Y<&4B(&1E<V,](E1H92!N86UE(&]F('1H92!D
M871A8F%S92(^;7ES<6P*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A;'5E
M(&1E<V,](DUI8W)O<V]F="!344P@4V5R=F5R(CYM<W-Q;#PO=F%L=64^"B`@
M("`@("`@/'9A;'5E(&1E<V,](DUY4U%,(CYM>7-Q;#PO=F%L=64^"B`@("`@
M("`@/'9A;'5E(&1E<V,](D]$0D,B/F]D8F,\+W9A;'5E/@H@("`@("`@(#QV
M86QU92!D97-C/2)/<F%C;&4@."(^;V-I.#PO=F%L=64^"B`@("`@("`@/'9A
M;'5E(&1E<V,](E!O<W1G<F5344PB/G!G<W%L/"]V86QU93X*("`@("`@(#PO
M=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL;"!W
M92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@("`@
M("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@("`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I9W-T
M<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C<"(@
M9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P
M;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES(')U
M;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^-30S,CPO8V]N9FEG:6YT96=E
M<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@:&]S
M=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O<B!W
M:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B/FQO
M8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U=&AE
M;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R
M9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O('=E
M(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,](E=H
M870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R92!W92!U<VEN9S\B/FAO
M<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=D97-C<FEP=&EO;CX*
M("`@("`@(%-O;64@<W!E8VEA;"!T;VME;G,@8V%N(&)E('5S960@:6X@=&AE
M('-Q;"!Q=65R>2X@5&AE>2!A<F4@<F5P;&%C960@870*("`@("`@('1H92!Q
M=65R>2!S=&%G93HF;'0[=6PF9W0["B`@("`@("`F;'0[;&DF9W0[(EQ,(B!W
M:6QL(&)E(')E<&QA8V5D(&)Y('1H92!U<V5R)W,@;&]G:6XF;'0[+VQI)F=T
M.PH@("`@("`@)FQT.VQI)F=T.R)<4"(@=VEL;"!B92!R97!L86-E9"!B>2!T
M:&4@=7-E<B=S('!A<W-W;W)D)FQT.R]L:29G=#L*("`@("`@("9L=#ML:29G
M=#LB7$\B('=I;&P@8F4@<F5P;&%C960@8GD@=&AE(&]L9"!U<V5R)W,@;&]G
M:6X@*')E<75I<F5D(&9O<@H@("`@("`@=7!D871E*29L=#LO;&DF9W0[)FQT
M.R]U;"9G=#L*("`@("`@($5G.B`B4T5,14-4("H@1E)/32!U<V5R<R!72$52
M12!U:60@/2!<3"!!3D0@<&%S<W=D(#T@7%`@04Y$(&)I;&QI;F<@/0H@("`@
M("`@)W!A:60G(@H@("`@("`\+V-O;F9I9V1E<V-R:7!T:6]N/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G%U97)Y7V%U=&@B(&1E<V,](D%U=&AE;G1I
M8V%T92!T:&4@=7-E<B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G%U
M97)Y7V%D9"(@9&5S8STB061D('5S97(B+SX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)Q=65R>5]U<&1A=&4B(&1E<V,](E5P9&%T92!U<V5R(B\^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<75E<GE?<F5M;W9E(B!D97-C/2)2
M96UO=F4@=7-E<B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G%U97)Y
M7VQI<W0B(&1E<V,](DQI<W0@=7-E<G,B+SX*("`@("`@/&-O;F9I9V5N=6T@
M;F%M93TB96YC<GEP=&EO;B(@9&5S8STB5&AE(&5N8W)Y<'1I;VX@=&\@=7-E
M('1O('-T;W)E('1H90H@("`@("!P87-S=V]R9"!I;B!T:&4@=&%B;&4B/FUD
M-2UH97@*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A;'5E/F%P<FUD-3PO
M=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T/"]V86QU93X*("`@("`@("`\
M=F%L=64^8W)Y<'0M8FQO=V9I<V@\+W9A;'5E/@H@("`@("`@(#QV86QU93YC
M<GEP="UD97,\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UM9#4\+W9A
M;'5E/@H@("`@("`@(#QV86QU93YM9#4M8F%S938T/"]V86QU93X*("`@("`@
M("`\=F%L=64^;60U+6AE>#PO=F%L=64^"B`@("`@("`@/'9A;'5E/G!L86EN
M/"]V86QU93X*("`@("`@("`\=F%L=64^<VAA/"]V86QU93X*("`@("`@("`\
M=F%L=64^<VUD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/G-S:&$\+W9A;'5E
M/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@
M/&-O;F9I9V)O;VQE86X@;F%M93TB<VAO=U]E;F-R>7!T:6]N(B!D97-C/2)0
M<F5P96YD('1H92!E;F-R>7!T:6]N(&EN('1H90H@("`@("!P87-S=V]R9"!F
M:65L9#\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)C>7)S<6PB(&1E
M<V,](E-13"!I;7!L96UE;G1A=&EO;B!F;W(@=&AE($-Y<G5S($E-05`@<V5R
M=F5R(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](F-Y<F%D;6EN(B!D97-C/2)4:&4@=7-E
M<FYA;64@;V8@=&AE(&-Y<G5S"B`@("`@(&%D;6EN:7-T<F%T;W(B+SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)C>7)P87-S(B!D97-C/2)4:&4@<&%S
M<W=O<F0@9F]R('1H92!C>7)U<PH@("`@("!A9&UI;FES=')A=&]R(B\^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:6UA<%]D<VXB(&1E<V,](E1H92!F
M=6QL($E-05`@1%-."B`@("`@("AI+F4N('ML;V-A;&AO<W0Z.3DS+VEM87`O
M<W-L+VYO=F%L:61A=&4M8V5R='TI(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA
M;64](G!H<'1Y<&4B(&1E<V,](E1H92!N86UE(&]F('1H92!D871A8F%S92(^
M;7ES<6P*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A;'5E(&1E<V,](DUI
M8W)O<V]F="!344P@4V5R=F5R(CYM<W-Q;#PO=F%L=64^"B`@("`@("`@/'9A
M;'5E(&1E<V,](DUY4U%,(CYM>7-Q;#PO=F%L=64^"B`@("`@("`@/'9A;'5E
M(&1E<V,](DUY4U%,("AM>7-Q;&DI(CYM>7-Q;&D\+W9A;'5E/@H@("`@("`@
M(#QV86QU92!D97-C/2)/1$)#(CYO9&)C/"]V86QU93X*("`@("`@("`\=F%L
M=64@9&5S8STB3W)A8VQE(#@B/F]C:3@\+W9A;'5E/@H@("`@("`@(#QV86QU
M92!D97-C/2)0;W-T9W)E4U%,(CYP9W-Q;#PO=F%L=64^"B`@("`@("`\+W9A
M;'5E<SX*("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`\8V]N9FEG<W=I=&-H
M(&YA;64](G!R;W1O8V]L(B!D97-C/2)7:&%T('!R;W1O8V]L('=I;&P@=V4@
M=7-E('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E/R(^=6YI>`H@("`@("`@
M/&-A<V4@;F%M93TB=6YI>"(@9&5S8STB54Y)6"!3;V-K971S(CX*("`@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G-O8VME="(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2),;V-A=&EO;B!O9B!53DE8('-O8VME="(^/"]C;VYF:6=S=')I
M;F<^"B`@("`@("`\+V-A<V4^"B`@("`@("`\8V%S92!N86UE/2)T8W`B(&1E
M<V,](E1#4"])4"(^"B`@("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R
M="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)0;W)T('1H92!$0B!I<R!R=6YN
M:6YG(&]N+"!I9B!N;VXM<W1A;F1A<F0B/C4T,S(\+V-O;F9I9VEN=&5G97(^
M"B`@("`@("`\+V-A<V4^"B`@("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2)7:&%T(&AO<W1N
M86UE(&ES('1H92!D871A8F%S92!S97)V97(@<G5N;FEN9R!O;BP@;W(@=VAA
M="!I<R!T:&4@;F%M92!O9B!T:&4@<WES=&5M($133B!T;R!U<V4_(CYL;V-A
M;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)U<V5R;F%M92(@9&5S8STB5VAA="!U<V5R;F%M92!D;R!W92!A=71H96YT
M:6-A=&4@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!A<S\B/FAO<F1E/"]C;VYF
M:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O<F0B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB5VAA="!P87-S=V]R9"!D;R!W92!A
M=71H96YT:6-A=&4@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!W:71H/R(O/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F1A=&%B87-E(B!D97-C/2)7:&%T
M(&1A=&%B87-E(&YA;64O=&%B;&5S<&%C92!A<F4@=V4*("`@("`@=7-I;F<_
M(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G1A8FQE(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@875T:"!T86)L92!I
M;B!T:&4*("`@("`@9&%T86)A<V4B/FAO<F1E7W5S97)S/"]C;VYF:6=S=')I
M;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;65?9FEE;&0B
M(&1E<V,](E1H92!N86UE(&]F('1H92!U<V5R;F%M92!F:65L9`H@("`@("!I
M;B!T:&4@875T:"!T86)L92(^=7-E<E]U:60\+V-O;F9I9W-T<FEN9SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R9%]F:65L9"(@9&5S8STB
M5&AE(&YA;64@;V8@=&AE('!A<W-W;W)D(&9I96QD"B`@("`@(&EN('1H92!A
M=71H('1A8FQE(CYU<V5R7W!A<W,\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)D;VUA:6Y?9FEE;&0B(&1E<V,](DEF('-E="!T
M;R!A;GET:&EN9R!O=&AE<B!T:&%N"B`@("`@("=N;VYE)R!T:&ES(&ES('5S
M960@87,@9FEE;&0@;F%M92!W:&5R92!D;VUA:6X@:7,*("`@("`@<W1O<F5D
M(CYN;VYE/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64]
M(F5N8W)Y<'1I;VXB(&1E<V,](E1H92!E;F-R>7!T:6]N('1O('5S92!T;R!S
M=&]R92!T:&4*("`@("`@<&%S<W=O<F0@:6X@=&AE('1A8FQE(CYM9#4M:&5X
M"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU93YA<')M9#4\+W9A;'5E
M/@H@("`@("`@(#QV86QU93YC<GEP=#PO=F%L=64^"B`@("`@("`@/'9A;'5E
M/F-R>7!T+6)L;W=F:7-H/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M
M9&5S/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M;60U/"]V86QU93X*
M("`@("`@("`\=F%L=64^;60U+6)A<V4V-#PO=F%L=64^"B`@("`@("`@/'9A
M;'5E/FUD-2UH97@\+W9A;'5E/@H@("`@("`@(#QV86QU93YP;&%I;CPO=F%L
M=64^"B`@("`@("`@/'9A;'5E/G-H83PO=F%L=64^"B`@("`@("`@/'9A;'5E
M/G-M9#4\+W9A;'5E/@H@("`@("`@(#QV86QU93YS<VAA/"]V86QU93X*("`@
M("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF
M:6=L:7-T(&YA;64](F9O;&1E<G,B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M02!L:7-T(&]F(&9O;&1E<G,@=&\@8W)E871E('5N9&5R"B`@("`@('5S97)N
M86UE(B\^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G%U;W1A(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E1H92!Q=6]T82`H:6X*("`@("`@:VEL;V)Y
M=&5S*2!T;R!G<F%N="!O;B!T:&4@;6%I;&)O>"(O/@H@("`@("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)U;FEX:&EE<B(@9&5S8STB5&AE('9A;'5E(&]F(&EM
M87!D+F-O;F8G<PH@("`@("!U;FEX:&EE<F%R8VAY<V5P('-E='1I;F<N($-H
M96-K('1H:7,@:68@=&AE('9A;'5E(&ES('1R=64@:6X*("`@("`@:6UA<&0N
M8V]N9BXB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)Y86AO;R(@9&5S
M8STB66%H;V\A(&%U=&AE;G1I8V%T:6]N(B\^"B`@(#PO8V]N9FEG<W=I=&-H
M/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T
M86(@;F%M93TB<VEG;G5P(B!D97-C/2)3:6=N(%5P(CX*("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)S:6=N=7`B/@H@("`\8V]N9FEG:&5A9&5R/DAO<F1E(%-I
M9VX@57`\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)A
M;&QO=R(@9&5S8STB06QL;W<@;F]N+7)E9VES=&5R960@=7-E<G,@=&\@<F5G
M:7-T97(@86YD"B`@('!R;W9I9&4@82!L:6YK(&]N('1H92!L;V=I;B!S8W)E
M96X_(CYF86QS90H@("`@/&-A<V4@;F%M93TB=')U92(@9&5S8STB665S(CX*
M("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)A<'!R;W9E(B!D97-C/2)!9&UI
M;B!H87,@=&\@87!P<F]V92!A;GD@=7-E<B!S=6)M:71T960*("`@("!R96=I
M<W1R871I;VX@<F5Q=65S=',_("A705).24Y'.B!3971T:6YG('1O(&9A;'-E
M('=O=6QD(&UE86X@=&AA="!E=F5R>2!U<V5R"B`@("`@=VAO('-I9VYS('5P
M('=O=6QD(&AA=F4@875T;VUA=&EC(&%C8V5S<R!T;R!Y;W5R(&AO<F1E('-Y
M<W1E;2XI(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@("`@(#QC;VYF:6=B;V]L
M96%N(&YA;64](G!R97!R;V-E<W,B(&1E<V,](E!A<W,@=&AE('5S97(@<W5B
M;6ET=&5D(&EN9F]R;6%T:6]N"B`@("`@=&AR;W5G:"!T:&4@7VAO<F1E7VAO
M;VM?<VEG;G5P7W!R97!R;V-E<W,@9G5N8W1I;VX@:6X@:&]O:W,N<&AP(&)E
M9F]R90H@("`@('!R;V-E<W-I;F<@=&AE(')E<75E<W0_(CYF86QS93PO8V]N
M9FEG8F]O;&5A;CX*("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)Q=65U92(@
M9&5S8STB4&%S<R!T:&4@=7-E<B!S=6)M:71T960@:6YF;W)M871I;VX*("`@
M("!T:')O=6=H('1H92!?:&]R9&5?:&]O:U]S:6=N=7!?<75E=64@9G5N8W1I
M;VX@:6X@:&]O:W,N<&AP(&%F=&5R('!R;V-E<W-I;F<*("`@("!T:&4@<F5Q
M=65S="!B=70@8F5F;W)E(&%C='5A;&QY('%U975E:6YG(&ET/R(^9F%L<V4\
M+V-O;F9I9V)O;VQE86X^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)F
M86QS92(@9&5S8STB3F\B("\^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N
M9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB
M;&]G(B!D97-C/2),;V=G:6YG(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)L
M;V<B/@H@("`\8V]N9FEG:&5A9&5R/DAO<F1E($QO9V=I;F<\+V-O;F9I9VAE
M861E<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)E;F%B;&5D(B!Q=6]T93TB
M9F%L<V4B(&1E<V,](E-H;W5L9"!(;W)D92!L;V<@97)R;W)S(&%N9"!O=&AE
M<B!U<V5F=6P*("`@:6YF;W)M871I;VX_(CYT<G5E"B`@("`\8V%S92!N86UE
M/2)T<G5E(B!D97-C/2)997,B/@H@("`@(#QC;VYF:6=E;G5M(&YA;64](G!R
M:6]R:71Y(B!Q=6]T93TB9F%L<V4B(&1E<V,](E=H870@;&5V96P@;V8@;65S
M<V%G97,*("`@("!S:&]U;&0@=V4@;&]G/R!%86-H(&QE=F5L(&QO9W,@:71S
M96QF(&%N9"!A;&P@=&AO<V4@=&AA="!C;VUE(&)E9F]R92!I=#H*("`@("!0
M14%27TQ/1U]!3$525"!W;W5L9"!O;FQY(&QO9R!A;&5R=',@86YD(&5M97)G
M96YC:65S+"!B=70@4$5!4E],3T=?1$5"54<*("`@("!W;W5L9"!L;V<@979E
M<GET:&EN9RXB/E!%05)?3$]'7TY/5$E#10H@("`@("`\=F%L=65S/@H@("`@
M("`@/'9A;'5E(&1E<V,](E!%05)?3$]'7T5-15)'(CY014%27TQ/1U]%3452
M1SPO=F%L=64^"B`@("`@("`\=F%L=64@9&5S8STB4$5!4E],3T=?04Q%4E0B
M/E!%05)?3$]'7T%,15)4/"]V86QU93X*("`@("`@(#QV86QU92!D97-C/2)0
M14%27TQ/1U]#4DE4(CY014%27TQ/1U]#4DE4/"]V86QU93X*("`@("`@(#QV
M86QU92!D97-C/2)014%27TQ/1U]%4E(B/E!%05)?3$]'7T524CPO=F%L=64^
M"B`@("`@("`\=F%L=64@9&5S8STB4$5!4E],3T=?5T%23DE.1R(^4$5!4E],
M3T=?5T%23DE.1SPO=F%L=64^"B`@("`@("`\=F%L=64@9&5S8STB4$5!4E],
M3T=?3D]424-%(CY014%27TQ/1U].3U1)0T4\+W9A;'5E/@H@("`@("`@/'9A
M;'5E(&1E<V,](E!%05)?3$]'7TE.1D\B/E!%05)?3$]'7TE.1D\\+W9A;'5E
M/@H@("`@("`@/'9A;'5E(&1E<V,](E!%05)?3$]'7T1%0E5'(CY014%27TQ/
M1U]$14)51SPO=F%L=64^"B`@("`@(#PO=F%L=65S/@H@("`@(#PO8V]N9FEG
M96YU;3X*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FED96YT(B!D97-C/2)7
M:&%T(&ED96YT:69I97(@<VAO=6QD('=E('5S92!I;B!T:&4*("`@("!L;V=S
M/R(^2$]21$4\+V-O;F9I9W-T<FEN9SX*"B`@("`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W!L86-E:&]L9&5R+SX*("`@
M("`\+V-O;F9I9W-E8W1I;VX^"@H@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB
M='EP92(@9&5S8STB5VAA="!L;V<@9')I=F5R('-H;W5L9"!W92!U<V4_(CYF
M:6QE"B`@("`@(#QC87-E(&YA;64](F-O;G-O;&4B(&1E<V,](D-O;G-O;&4B
M/@H@("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@
M("`\8V]N9FEG<&AP(&YA;64](G-T<F5A;2(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)4:&4@;W5T<'5T('-T<F5A;2!T;PH@("`@("`@('5S92(O/@H@("`@
M("`@(#QC;VYF:6=B;V]L96%N(&YA;64](F)U9F9E<FEN9R(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)3:&]U;&0@=&AE"B`@("`@("`@;W5T<'5T(&)E(&)U
M9F9E<F5D('5N=&EL('-H=71D;W=N/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^
M"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)L:6YE1F]R;6%T(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](DQO9R!L:6YE(&9O<FUA=`H@("`@("`@('-P
M96-I9FEC871I;VXB+SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G1I
M;65&;W)M870B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&EM92!S=&%M<`H@
M("`@("`@(&9O<FUA="(O/@H@("`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@
M("`\+V-A<V4^"@H@("`@("`\8V%S92!N86UE/2)D:7-P;&%Y(B!D97-C/2)$
M:7-P;&%Y(CX*("`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^
M"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)E<G)O<E]P<F5P96YD(B!R
M97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H:7,@<W1R:6YG"B`@("`@("`@=VEL
M;"!B92!P<F5P96YD960@=&\@=&AE(&QO9R!O=71P=70B+SX*("`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](F5R<F]R7V%P<&5N9"(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:&ES('-T<FEN9PH@("`@("`@('=I;&P@8F4@87!P96YD
M960@=&\@=&AE(&QO9R!O=71P=70B+SX*("`@("`@(#PO8V]N9FEG<V5C=&EO
M;CX*("`@("`@/"]C87-E/@H*("`@("`@/&-A<V4@;F%M93TB97)R;W)?;&]G
M(B!D97-C/2)%<G)O<B!,;V<B/@H@("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F1E<W1I
M;F%T:6]N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](D]P=&EO;F%L"B`@("`@
M("`@9&5S=&EN871I;VX@=F%L=64@9F]R(&5R<F]R7VQO9R@I+B!3964*("`@
M("`@("!H='1P.B\O=W=W+FEN9&5L:6)L92YO<F<O<&5A<B],;V<O9W5I9&4N
M:'1M;"-E<G)O<BUL;V<M='EP97,@9F]R(&UO<F4*("`@("`@("!D971A:6QS
M+B(O/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB97AT<F%?:&5A9&5R
M<R(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)!9&1I=&EO;F%L"B`@("`@("`@
M:&5A9&5R<R!T;R!P87-S('1O('1H92!M86EL*"D@9G5N8W1I;VX@=VAE;B!T
M:&4@4$5!4E],3T=?5%E015]-04E,('1Y<&4*("`@("`@("!I<R!S<&5C:69I
M960B+SX*("`@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@("`@/"]C87-E/@H*
M("`@("`@/&-A<V4@;F%M93TB9FEL92(@9&5S8STB1FEL92(^"B`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](FYA;64B(&1E<V,](E!A=&@@=&\@=&AE(&QO
M9PH@("`@("`@9FEL92(^+W1M<"]H;W)D92YL;V<\+V-O;F9I9W-T<FEN9SX*
M("`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`@
M/&-O;F9I9V)O;VQE86X@;F%M93TB87!P96YD(B!R97%U:7)E9#TB9F%L<V4B
M(&1E<V,](E-H;W5L9"!N97<@;&]G"B`@("`@("`@96YT<FEE<R!B92!A<'!E
M;F1E9"!T;R!A;B!E>&ES=&EN9R!L;V<@9FEL93\@268@=&AI<R!I<R!F86QS
M92P@;F5W(&QO9R!F:6QE<PH@("`@("`@('=I;&P@;W9E<G=R:71E(&5X:7-T
M:6YG(&]N97,N(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@("`@("`@(#QC;VYF
M:6=I;G1E9V5R(&YA;64](FUO9&4B(&]C=&%L/2)T<G5E(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](D]C=&%L"B`@("`@("`@<F5P<F5S96YT871I;VX@;V8@
M=&AE(&QO9R!F:6QE)W,@<&5R;6ES<VEO;G,@;6]D92(O/@H@("`@("`@(#QC
M;VYF:6=P:'`@;F%M93TB96]L(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H
M92!E;F0M;V8M;&EN92!C:&%R86-T97(*("`@("`@("!S97%U96YC92(O/@H@
M("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;&EN949O<FUA="(@<F5Q=6ER
M960](F9A;'-E(B!D97-C/2),;V<@;&EN92!F;W)M870*("`@("`@("!S<&5C
M:69I8V%T:6]N(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T:6UE
M1F]R;6%T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1I;64@<W1A;7`*("`@
M("`@("!F;W)M870B+SX*("`@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@("`@
M/"]C87-E/@H*("`@("`@/&-A<V4@;F%M93TB;6%I;"(@9&5S8STB36%I;"(^
M"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FYA;64B(&1E<V,](E1H92!R
M96-I<&EE;G0@9F]R('1H92!M97-S86=E(B\^"B`@("`@("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB9G)O;2(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)686QU92!F;W(@=&AE
M"B`@("`@("`@;65S<V%G92=S($9R;VTZ(&AE861E<B(O/@H@("`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB<W5B:F5C="(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)686QU92!F;W(@=&AE"B`@("`@("`@;65S<V%G92=S(%-U8FIE8W0Z
M(&AE861E<B(O/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<')E86UB
M;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB4')E86UB;&4@9F]R('1H90H@
M("`@("`@(&UE<W-A9V4B+SX*("`@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@
M("`@/"]C87-E/@H*("`@("`@/&-A<V4@;F%M93TB;6-A;"(@9&5S8STB36-A
M;"(^"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8V%L96YD87(B(&1E<V,](E1H92!-
M0T%,(&-A;&5N9&%R(&YA;64B+SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G5S97)N86UE(B!D97-C/2)#;VYN96-T('1O($U#04P@87,B+SX*("`@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!D97-C/2)087-S
M=V]R9"!T;R!C;VYN96-T('=I=&@B+SX*("`@("`@(#PO8V]N9FEG<V5C=&EO
M;CX*("`@("`@/"]C87-E/@H*("`@("`@/&-A<V4@;F%M93TB;G5L;"(@9&5S
M8STB3G5L;"(O/@H*("`@("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)344PB
M/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)N86UE(B!D97-C/2)4:&4@
M=&%B;&4@=&\@;&]G"B`@("`@("!T;R(^;&]G7W1A8FQE/"]C;VYF:6=S=')I
M;F<^"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@
M("`@(#QC;VYF:6=P:'`@;F%M93TB9'-N(B!D97-C/2)!($1A=&$@4V]U<F-E
M"B`@("`@("`@3F%M92(^)&-O;F9;)W-Q;"==/"]C;VYF:6=P:'`^"B`@("`@
M("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*"B`@("`@(#QC87-E
M(&YA;64](G-Q;&ET92(@9&5S8STB4U%,:71E(CX*("`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB;F%M92(@9&5S8STB5&AE('1A8FQE('1O(&QO9PH@("`@
M("`@=&\B/FQO9U]T86)L93PO8V]N9FEG<W1R:6YG/@H@("`@("`@/&-O;F9I
M9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](F9I;&5N86UE(B!D97-C/2)0871H('1O(&%N(%-Q;&ET92!D871A
M8F%S92(O/@H@("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](FUO9&4B(&]C
M=&%L/2)T<G5E(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](D]C=&%L"B`@("`@
M("`@;6]D92!U<V5D('1O(&]P96X@=&AE(&1A=&%B87-E(%LP-C8V72(O/@H@
M("`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G!E<G-I<W1E;G0B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB57-E(&$*("`@("`@("!P97)S:7-T96YT(&-O
M;FYE8W1I;VXB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"@H@("`@("`\8V%S92!N86UE/2)S
M>7-L;V<B(&1E<V,](E-Y<VQO9R(^"B`@("`@("`\8V]N9FEG<&AP(&YA;64]
M(FYA;64B('%U;W1E/2)F86QS92(@9&5S8STB4WES;&]G(&9A8VEL:71Y('1O
M('5S92(O/@H@("`@("`\+V-A<V4^"@H@("`@("`\8V%S92!N86UE/2)W:6XB
M(&1E<V,](E=I;F1O=R(^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FYA
M;64B(&1E<V,](DYA;64@;V8@=&AE(&]P96YE9"!W:6YD;W<B+SX*("`@("`@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)T:71L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4
M:&4@=&ET;&4@;V8@=&AE"B`@("`@("`@;W5T<'5T('=I;F1O=R(O/@H@("`@
M("`@/"]C;VYF:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"B`@("`@/"]C;VYF
M:6=S=VET8V@^"@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB9F%L<V4B
M(&1E<V,](DYO(B\^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N9FEG<V5C
M=&EO;CX*("`\8V]N9FEG8F]O;&5A;B!N86UE/2)L;V=?86-C97-S:V5Y<R(@
M9&5S8STB4VAO=6QD($AO<F1E(&QO9R!S=&%T:7-T:6-S(&%B;W5T"B`@('5S
M960@86-C97-S(&ME>7,_(%1H:7,@:7,@;VYL>2!U<V5F=6P@9F]R('1R86YS
M;&%T;W)S(&]F('1H90H@("!522X@66]U(&%L<V\@;F5E9"!T;R!S970@=&AE
M(&QO9R!L979E;"!T;R!A="!L96%S=`H@("!014%27TQ/1U])3D9/+B(^9F%L
M<V4\+V-O;F9I9V)O;VQE86X^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B
M(&YA;64](G!R969S(B!D97-C/2)0<F5F97)E;F-E(%-Y<W1E;2(^"B`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<')E9G,B/@H@("`\8V]N9FEG:&5A9&5R/E!R
M969E<F5N8V4@4WES=&5M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@(#QC
M;VYF:6=I;G1E9V5R(&YA;64](FUA>'-I>F4B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5&AE('-I>F4@;V8@=&AE"B`@('!R969E<F5N8V5S(&9I96QD(&EN
M('EO=7(@8F%C:V5N9"!I;B!B>71E<RX@2&]R9&4@=VEL;"!R96IE8W0@86YY
M('=R:71E('1O"B`@('1H92!P<F5F97)E;F-E<R!B86-K96YD(&EF(&ET<R!L
M96YG=&@@97AC965D<R!T:&ES('9A;'5E+B!,96%V92!E;7!T>2!T;PH@("!S
M:VEP('1H:7,@8VAE8VMI;F<N($4N9RX@37E344P@<W1O<F5S('1H92!P<F5F
M97)E;F-E(&1A=&$@:6X@82!,3TY'5$585`H@("!F:65L9"X@5&AI<R!F:65L
M9"!C86X@:&]L9"`T,CDT.38W,CDU(&)Y=&5S('-O(&UO<W0@;&EK96QY(&-H
M96-K:6YG(&ES(&YO=`H@("!N965D960N($AO=V5V97(@;W1H97(@1$(@:6YS
M=&%L;&%T:6]N<R!M87D@;VYL>2!H879E(&$@<W1O<F%G92!S:7IE(&]F(#8T
M"B`@($M"("@V-34S-2!B>71E<RDN(%1H97-E(&EN<W1A;&QA=&EO;G,@=V]U
M;&0@=V%N="!T;R!T=7)N(&-H96-K:6YG(&]N+B(O/@H@("`\8V]N9FEG<W=I
M=&-H(&YA;64](F1R:79E<B(@9&5S8STB5VAA="!P<F5F97)E;F-E<R!D<FEV
M97(@<VAO=6QD('=E('5S93\B/FYO;F4*("`@("`\8V%S92!N86UE/2)N;VYE
M(B!D97-C/2).;VYE(B`O/@H@("`@(#QC87-E(&YA;64](FEM<W`B(&1E<V,]
M(DE-4U`@4V5R=F5R(B`O/@H@("`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB
M4U%,($1A=&%B87-E(CX*("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R
M86US(CX*("`@("`@(#QC;VYF:6=S<6P@<W=I=&-H;F%M93TB9')I=F5R8V]N
M9FEG(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G1A8FQE(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E1H92!N86UE(&]F('1H90H@("`@("`@('!R
M969E<F5N8V4@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]P<F5F<UTB
M+SX*("`@("`@(#PO8V]N9FEG<W%L/@H@("`@("`\+V-O;F9I9W-E8W1I;VX^
M"B`@("`@/"]C87-E/@H@("`@(#QC87-E(&YA;64](FQD87`B(&1E<V,](DQ$
M05`B/@H@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5&AE(&AO
M<W1N86UE(&]F('1H92!,1$%0('-E<G9E<B(^;&]C86QH;W-T/"]C;VYF:6=S
M=')I;F<^"B`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!D97-C
M/2)4:&4@<&]R="!O9B!T:&4@3$1!4"!S97)V97(B/C,X.3PO8V]N9FEG:6YT
M96=E<CX*("`@("`@(#QC;VYF:6=E;G5M(&YA;64](G9E<G-I;VXB(&1E<V,]
M(DQ$05`@4')O=&]C;VP@5F5R<VEO;B(^,PH@("`@("`@(#QV86QU97,^"B`@
M("`@("`@(#QV86QU92!D97-C/2),1$%0=C(@*$1E<')E8V%T960I(CXR/"]V
M86QU93X*("`@("`@("`@/'9A;'5E(&1E<V,](DQ$05!V,R(^,SPO=F%L=64^
M"B`@("`@("`@/"]V86QU97,^"B`@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](F)A<V5D;B(@9&5S8STB5&AE(&)A<V4@
M1$X@9F]R('1H92!,1$%0('-E<G9E<B(O/@H@("`@("`@/&-O;F9I9V)O;VQE
M86X@;F%M93TB9F5T8VAD;B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)3:&]U
M;&0@2&]R9&4@8FEN9`IA<R!E86-H('5S97(@9F]R('1H870@=7-E<B=S('=R
M:71E(&]P97)A=&EO;G,_(B\^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(G)O;W1D;B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2))9B!N;W0L('!R;W9I
M9&4@=&AE"D1.(&]F('1H92!R;V]T("AA9&UI;FES=')A=&EV92D@86-C;W5N
M="!T;R!B:6YD(&9O<B!W<FET92!O<&5R871I;VYS(B\^"B`@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H92!P87-S=V]R9"!O9B!T:&4@<F]O="!$3B!F;W(@8FEN9"!A=71H
M96YT:6-A=&EO;B(O/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U:60B
M(&1E<V,](E1H92!U<V5R;F%M92!S96%R8V@@:V5Y(B\^"B`@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@("`\+V-A<V4^"B`@("`@/&-A<V4@;F%M93TB<V5S
M<VEO;B(@9&5S8STB4$A0(%-E<W-I;VYS(B\^"B`@("`@/&-A<V4@;F%M93TB
M:V]L86(B(&1E<V,](DMO;&%B("A,1$%0*2(@+SX*("`@/"]C;VYF:6=S=VET
M8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I
M9W1A8B!N86UE/2)D871A=')E92(@9&5S8STB1&%T851R964@4WES=&5M(CX*
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)D871A=')E92(^"B`@(#QC;VYF:6=H
M96%D97(^1&%T851R964@4WES=&5M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^
M"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB9')I=F5R(B!D97-C/2)7:&%T(&)A
M8VME;F0@<VAO=6QD('=E('5S92!F;W(@2&]R9&4*("`@1&%T851R964@<W1O
M<F%G93\B/FYU;&P*("`@("`\8V%S92!N86UE/2)N=6QL(B!D97-C/2).;VYE
M(B\^"B`@("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)344P@1&%T86)A<V4B
M/@H@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@
M/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B/@H@("`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5&AE(&YA;64@;V8@=&AE"B`@("`@("`@9&%T82!T86)L92!I;B!T
M:&4@9&%T86)A<V4@6VAO<F1E7V1A=&%T<F5E72(O/@H@("`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB=&%B;&5?871T<FEB=71E<R(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:&4@;F%M90H@("`@("`@(&]F('1H92!D871A(&%T=')I
M8G5T97,@=&%B;&4@:6X@=&AE(&1A=&%B87-E"B`@("`@("`@6VAO<F1E7V1A
M=&%T<F5E7V%T=')I8G5T97-=(B\^"B`@("`@("`\+V-O;F9I9W-Q;#X*("`@
M("`@/"]C;VYF:6=S96-T:6]N/@H@("`@(#PO8V%S93X*("`@/"]C;VYF:6=S
M=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O
M;F9I9W1A8B!N86UE/2)G<F]U<"(@9&5S8STB1W)O=7!S(CX*("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)G<F]U<"(^"B`@(#QC;VYF:6=H96%D97(^1W)O=7!S
M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=D97-C<FEP=&EO
M;CX*("`@(%1H92!(;V]K<R!B86-K96YD(&5X=&5N9',@=&AE($1A=&%4<F5E
M(&)A8VME;F0@=&\@86QL;W<@:&]O:W,@=&\@97AT96YD(&$*("`@(&=R;W5P
M('1O(&1Y;F%M:6-A;&QY(&EN8VQU9&4@;65M8F5R<R!I;G1O(&$@9W)O=7`N
M("!3964@:&]O:W,N<&AP+F1I<W0@9F]R"B`@("!A;B!E>&%M<&QE+@H@("`\
M+V-O;F9I9V1E<V-R:7!T:6]N/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F1R
M:79E<B(@9&5S8STB5VAA="!B86-K96YD('-H;W5L9"!W92!U<V4@9F]R($AO
M<F1E"B`@($=R;W5P<S\B/F1A=&%T<F5E"B`@("`@/&-A<V4@;F%M93TB9&%T
M871R964B(&1E<V,](D1A=&%4<F5E(B\^"B`@("`@/&-A<V4@;F%M93TB:&]O
M:W,B(&1E<V,](DAO;VMS(B\^"@H@("`@(#QC87-E(&YA;64](FQD87`B(&1E
M<V,](DQ$05`B/@H@("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C
M/2)4:&4@:&]S=&YA;64@;V8@=&AE($Q$05`@<V5R=F5R(CYL;V-A;&AO<W0\
M+V-O;F9I9W-T<FEN9SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F)A
M<V5D;B(@9&5S8STB5&AE(&)A<V4@1$X@9F]R('1H92!,1$%0('-E<G9E<B(O
M/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8FEN9&1N(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E1H92!$3B!U<V5D('1O(&)I;F0@=&\@=&AE($Q$
M05`@<V5R=F5R(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S
M=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@<&%S<W=O<F0@=7-E
M9"!T;R!B:6YD('1O('1H92!,1$%0('-E<G9E<B(O/@H@("`@("`@(#QC;VYF
M:6=E;G5M(&YA;64](G9E<G-I;VXB(&1E<V,](DQ$05`@4')O=&]C;VP@5F5R
M<VEO;B(^,PH@("`@("`@("`\=F%L=65S/@H@("`@("`@("`@/'9A;'5E(&1E
M<V,](DQ$05!V,B`H1&5P<F5C871E9"DB/C(\+W9A;'5E/@H@("`@("`@("`@
M/'9A;'5E(&1E<V,](DQ$05!V,R(^,SPO=F%L=64^"B`@("`@("`@(#PO=F%L
M=65S/@H@("`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](F=I9"(@9&5S8STB5&AE(&=R;W5P('-E87)C:"!K97DB/F-N
M/"]C;VYF:6=S=')I;F<^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)M
M96UB97)U:60B(&1E<V,](D=R;W5P(&UE;6)E<G-H:7`@9FEE;&0B/FUE;6)E
M<E5I9#PO8V]N9FEG<W1R:6YG/@H@("`@("`@(#QC;VYF:6=L:7-T(&YA;64]
M(FYE=V=R;W5P7V]B:F5C=&-L87-S(B!D97-C/2)7:&%T(&]B:F5C=&-L87-S
M97,@<VAO=6QD(&$@;F5W(&=R;W5P(&)E(&UE;6)E<B!O9C\@5&AE<V4@;V)J
M96-T8VQA<W-E<R!S:&]U;&0@8V]V97(@=&AE(&UA:6P@86YD(&=I9&YU;6)E
M<B!A='1R:6)U=&5S(&%S('=E;&P@87,@=&AE(&=R;W5P('-E87)C:"!K97DB
M/G!O<VEX1W)O=7`L:&]R9&5'<F]U<#PO8V]N9FEG;&ES=#X*("`@("`@("`\
M8V]N9FEG<W=I=&-H(&YA;64](F9I;'1E<E]T>7!E(B!D97-C/2)(;W<@=&\@
M<W!E8VEF>2!A(&9I;'1E<B!F;W(@=&AE(&=R;W5P(&QI<W1S(CYO8FIE8W1C
M;&%S<PH@("`@("`@("`\8V%S92!N86UE/2)O8FIE8W1C;&%S<R(@9&5S8STB
M3VYE(&]R(&UO<F4@;V)J96-T8VQA<W,@9FEL=&5R<R(^"B`@("`@("`@("`\
M8V]N9FEG;&ES="!N86UE/2)O8FIE8W1C;&%S<R(@9&5S8STB5&AE(&]B:F5C
M=&-L87-S(&9I;'1E<B!U<V5D('1O('-E87)C:"!F;W(@9W)O=7!S+B!#86X@
M8F4@82!S:6YG;&4@;V)J96-T8VQA<W,@;W(@82!L:7-T+B(^<&]S:7A'<F]U
M<#PO8V]N9FEG;&ES=#X*("`@("`@("`@/"]C87-E/@H@("`@("`@("`\8V%S
M92!N86UE/2)F<F5E(B!D97-C/2)!(&-O;7!L971E($Q$05`@9FEL=&5R(&5X
M<')E<W-I;VXB/@H@("`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F:6QT
M97(B(&1E<V,](E1H92!,1$%0(%)&0R!F;W)M871T960@9FEL=&5R('5S960@
M=&\@<V5A<F-H(&9O<B!G<F]U<',N(B\^"B`@("`@("`@(#PO8V%S93X*("`@
M("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`@/"]C;VYF:6=S96-T:6]N/@H@
M("`@(#PO8V%S93X*"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N9FEG<V5C
M=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB8V%C:&4B
M(&1E<V,](D-A8VAE(%-Y<W1E;2(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB
M8V%C:&4B/@H@("`\8V]N9FEG:&5A9&5R/D-A8VAE(%-Y<W1E;2!3971T:6YG
M<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG:6YT96=E<B!N86UE/2)D969A
M=6QT7VQI9F5T:6UE(B!D97-C/2)(;W<@;&]N9RP@:6X@<V5C;VYD<RP@<VAO
M=6QD"B`@(&]B:F5C=',@8F4@8V%C:&5D(&)Y(&1E9F%U;'0_(CXQ.#`P/"]C
M;VYF:6=I;G1E9V5R/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F1R:79E<B(@
M9&5S8STB268@>6]U('=A;G0@=&\@96YA8FQE('1H92!(;W)D92!#86-H92P*
M("`@<V5L96-T(&$@9')I=F5R(&AE<F4N(%1H:7,@:7,@=7-E9"!T;R!S<&5E
M9"!U<"!P;W)T:6]N<R!O9B!(;W)D92!B>2!S=&]R:6YG"B`@(&-O;6UO;FQY
M('!R;V-E<W-E9"!O8FIE8W1S('1O(&1I<VLN(CYF:6QE"B`@("`\8V%S92!N
M86UE/2)N;VYE(B!D97-C/2)$;VXG="!C86-H92!A;GD@;V)J96-T<R(O/@H@
M("`@/&-A<V4@;F%M93TB9FEL92(@9&5S8STB4W1O<F4@;V)J96-T<R!I;B!F
M:6QE<WES=&5M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B
M/@H@("`@("`\8V]N9FEG<&AP(&YA;64](F1I<B(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)4:&4@;&]C871I;VX@=&\@<W1O<F4@=&AE"B`@("`@(&-A8VAE
M9"!F:6QE<R(^2&]R9&4Z.F=E=%1E;7!$:7(H*3PO8V]N9FEG<&AP/@H@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G!R969I>"(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)4:&4@9FEL96YA;64@<')E9FEX('1O"B`@("`@('5S92!F;W(@
M=&AE(&-A8VAE(&9I;&5S+B(O/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE
M/2)G8R(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)097)F;W)M(&=A<F)A9V4*
M("`@("`@8V]L;&5C=&EO;B!O;B!C86-H92!F:6QE<S\@26YP=70@=&AE(&YU
M;6)E<B!O9B!S96-O;F1S(&]L9"!T:&4@9FEL92!H87,*("`@("`@=&\@8F4@
M=VET:&]U="!M;V1I9FEC871I;VX@8F5F;W)E('1H92!C86-H92!S>7-T96T@
M8V%N(&1E;&5T92!T:&4@9FEL92X*("`@("`@26YP=70@,"!T;R!S:VEP(&=A
M<F)A9V4@8V]L;&5C=&EO;BXB/C@V-#`P/"]C;VYF:6=I;G1E9V5R/@H@("`@
M("!A9G1E<B!W:&EC:"!C86-H90H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@
M(#PO8V%S93X*("`@(#QC87-E(&YA;64](GIP<S0B(&1E<V,](E5S92!T:&4@
M6F5N9"!097)F;W)M86YC92!3=6ET92!O=71P=70@8V%C:&4B+SX*("`@/"]C
M;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^
M"@H@/&-O;F9I9W1A8B!N86UE/2)T;VME;B(@9&5S8STB5&]K96X@4WES=&5M
M(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)T;VME;B(^"B`@(#QC;VYF:6=H
M96%D97(^5&]K96X@4WES=&5M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@
M(#QC;VYF:6=I;G1E9V5R(&YA;64](G1I;65O=70B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB5&AE('!E<FEO9"`H:6X*("`@<V5C;VYD<RD@869T97(@=VAI
M8V@@86X@:60@:7,@<'5R9V5D(B\^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB
M9')I=F5R(B!D97-C/2))9B!Y;W4@=V%N="!T;R!E;F%B;&4@1F]R;2!4;VME
M;G,L('-E;&5C=`H@("!A(&1R:79E<B!H97)E+B!4:&ES(&ES('5S960@8GD@
M=&AE($AO<F1E.CI&;W)M.CH@05!)(&%N9"!S;VUE(&]T:&5R('!A<G1S"B`@
M(&]F($AO<F1E('1O(&5N<W5R92!T:&%T(&$@9F]R;2!C86X@;VYL>2!B92!S
M=6)M:71T960@;VYC92XB/FYO;F4*("`@(#QC87-E(&YA;64](FYO;F4B(&1E
M<V,](D1I<V%B;&4@1F]R;2!4;VME;G,B+SX*("`@(#QC87-E(&YA;64](F9I
M;&4B(&1E<V,](DQO8V%L(&9I;&5S>7-T96T@=&]K96X@<W1O<F%G92(^"B`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T;VME;E]D:7(B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AE(&1I<F5C=&]R>2!W:&5R90H@("`@('1O(&ME97`@
M=&]K96X@9FEL97,B+SX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](G-Q
M;"(@9&5S8STB4U%,+6)A<V5D('1O:V5N('-T;W)A9V4B/@H@("`@(#QC;VYF
M:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S<6P@<W=I
M=&-H;F%M93TB9')I=F5R8V]N9FEG(CX*("`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@
M;V8@=&AE"B`@("`@("!T;VME;G,@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH
M;W)D95]T;VME;G-=(B\^"B`@("`@(#PO8V]N9FEG<W%L/@H@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@/"]C;VYF:6=S=VET8V@^"B`@
M/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N
M86UE/2)M86EL97(B(&1E<V,](DUA:6QE<B(^"B`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB;6%I;&5R(CX*("`@/&-O;F9I9VAE861E<CY-86EL97(\+V-O;F9I
M9VAE861E<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)T>7!E(B!D97-C/2)7
M:&%T(&UE=&AO9"!S:&]U;&0@=V4@=7-E(&9O<B!S96YD:6YG"B`@(&UA:6P_
M(CYS96YD;6%I;`H@("`@/&-A<V4@;F%M93TB;G5L;"(@9&5S8STB1&ES86)L
M92!M86EL:6YG(B`O/@H@("`@/&-A<V4@;F%M93TB<V5N9&UA:6PB(&1E<V,]
M(E5S92!T:&4@;&]C86P@<V5N9&UA:6P@8FEN87)Y(CX*("`@("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G-E;F1M86EL7W!A=&@B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE
M(&QO8V%T:6]N"B`@("`@(&]F('1H92!S96YD;6%I;"!B:6YA<GD@;VX@=&AE
M(&9I;&5S>7-T96T*("`@("`@6R]U<W(O<V)I;B]S96YD;6%I;%TB/B]U<W(O
M;&EB+W-E;F1M86EL/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB<V5N9&UA:6Q?87)G<R(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)!;GD@97AT<F$*("`@("`@<&%R86UE=&5R<R!T;R!P87-S('1O('1H92!S
M96YD;6%I;"!O<B!S96YD;6%I;"!W<F%P<&5R"B`@("`@(&)I;F%R>2(^+6]I
M/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C
M87-E/@H@("`@/&-A<V4@;F%M93TB<VUT<"(@9&5S8STB57-E(&$@4TU44"!S
M97)V97(B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S="(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)4:&4@<V5R=F5R('1O(&-O;FYE8W0*("`@("`@=&\@6VQO8V%L
M:&]S=%TB+SX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)4:&4@<&]R="!T;R!C;VYN96-T"B`@("`@
M('1O(%LR-5TB+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)L;V-A;&AO
M<W0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&QO8V%L(&AO<W1N86UE
M"B`@("`@("\@9&]M86EN(%ML;V-A;&AO<W1=(B\^"B`@("`@(#QC;VYF:6=E
M;G5M(&YA;64](F%U=&@B(&1E<V,](E--5%`@875T:&5N=&EC871I;VXB/C`*
M("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A;'5E(&1E<V,](DYO(&%U=&AE
M;G1I8V%T:6]N(CXP/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB0F5S
M="!A=F%I;&%B;&4@875T:&5N=&EC871I;VXB/C$\+W9A;'5E/@H@("`@("`@
M(#QV86QU93Y$24=%4U0M340U/"]V86QU93X*("`@("`@("`\=F%L=64^0U)!
M32U-1#4\+W9A;'5E/@H@("`@("`@(#QV86QU93Y,3T=)3CPO=F%L=64^"B`@
M("`@("`@/'9A;'5E/E!,04E./"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@
M("`@("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M=7-E<FYA;64B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('5S97)N86UE
M('1O('5S92!F;W(@4TU44"!A=71H(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<&%S<W=O<F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A
M<W-W;W)D('1O('5S92!F;W(@4TU44"!A=71H(B\^"B`@("`@/"]C;VYF:6=S
M96-T:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O
M;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64]
M(G9F<R(@9&5S8STB5FER='5A;"!&:6QE(%-T;W)A9V4B/@H@(#QC;VYF:6=S
M96-T:6]N(&YA;64](G9F<R(^"B`@(#QC;VYF:6=H96%D97(^5FER='5A;"!&
M:6QE(%-T;W)A9V4\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9W-W:71C:"!N
M86UE/2)T>7!E(B!D97-C/2))9B!A(%9&4R`H=FER='5A;"!F:6QE<WES=&5M
M*2!B86-K96YD(&ES"B`@(')E<75I<F5D+"!W:&EC:"!O;F4@<VAO=6QD('=E
M('5S93\B/F9I;&4*("`@(#QC87-E(&YA;64](F9I;&4B(&1E<V,](D9I;&5S
M(&]N('1H92!L;V-A;"!S>7-T96TB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=F9S<F]O
M="(@9&5S8STB5VAE<F4@;VX@=&AE(')E86P@9FEL97-Y<W1E;2!S:&]U;&0*
M("`@("`@2&]R9&4@=7-E(&%S(')O;W0@;V8@=&AE('9I<G1U86P@9FEL97-Y
M<W1E;3\B/B]T;7`\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I
M;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)S<6PB(&1E<V,](E-1
M3"!D871A8F%S92(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B
M/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)V9G-?=&%B;&4B(&1E<V,]
M(E1H92!N86UE(&]F('1H92!61E,@=&%B;&4@:6X@=&AE"B`@("`@("!D871A
M8F%S92!;:&]R9&5?=F9S72(@<F5Q=6ER960](F9A;'-E(B\^"B`@("`@(#PO
M8V]N9FEG<W%L/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*
M("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF
M:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)S97-S:6]N(B!D97-C/2)#=7-T
M;VT@4V5S<VEO;B!(86YD;&5R(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S
M97-S:6]N:&%N9&QE<B(^"B`@(#QC;VYF:6=H96%D97(^0W5S=&]M(%-E<W-I
M;VX@2&%N9&QE<CPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA
M;64](G1Y<&4B(&1E<V,](E=H870@<V5S<VEO;FAA;F1L97(@9')I=F5R('-H
M;W5L9"!W90H@("!U<V4_(CYN;VYE"B`@("`\8V%S92!N86UE/2)N;VYE(B!D
M97-C/2)5<V4@=&AE(&1E9F%U;'0@4$A0("AF:6QE+6)A<V5D*2!S97-S:6]N
M(&AA;F1L97(B+SX*("`@(#QC87-E(&YA;64](F5X=&5R;F%L(B!D97-C/2)5
M<V4@>6]U<B!O=VX@8W5S=&]M('-E<W-I;VX@:&%N9&QE<B(^"B`@("`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)O<&5N(B!D97-C/2)9;W5R(&]P96XH*2!F=6YC=&EO;B(O/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F-L;W-E(B!D97-C/2)9;W5R(&-L
M;W-E*"D@9G5N8W1I;VXB+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)R
M96%D(B!D97-C/2)9;W5R(')E860H*2!F=6YC=&EO;B(O/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G=R:71E(B!D97-C/2)9;W5R('=R:71E*"D@9G5N
M8W1I;VXB+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D97-T<F]Y(B!D
M97-C/2)9;W5R(&1E<W1R;WDH*2!F=6YC=&EO;B(O/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](F=C(B!D97-C/2)9;W5R(&=C*"D@9G5N8W1I;VXB+SX*
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N
M86UE/2)D8FTB(&1E<V,](D1"32!B87-E9"!S97-S:6]N<R(O/@H@("`@/&-A
M<V4@;F%M93TB;7ES<6PB(&1E<V,](DUY4U%,(&)A<V5D('-E<W-I;VYS(CX*
M("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N
M9FEG8F]O;&5A;B!N86UE/2)P97)S:7-T96YT(B!D97-C/2)297%U97-T('!E
M<G-I<W1E;G0@8V]N;F5C=&EO;G,_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*
M("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<F]W;&]C:VEN9R(@9&5S8STB
M4VAO=6QD('=E('5S92!R;W<M;&5V96P@;&]C:VEN9PH@("`@("!A;F0@=')A
M;G-A8W1I;VYS/R!4:&ES(&ES('-T<F]N9VQY(')E8V]M;65N9&5D+"!B=70@
M<F5Q=6ER97,@82!T86)L90H@("`@("!T>7!E('1H870@:7,@=')A;G-A8W1I
M;VXM<V%F92!A;F0@<W5P<&]R=',@<F]W+6QE=F5L(&QO8VMI;F<L(&QI:V4*
M("`@("`@26YN;T1"+B!)9B!Y;W4@9&]N)W0@:&%V92!S=6-H(&$@=&%B;&4@
M='EP92P@9&ES86)L92!T:&ES('-E='1I;F<@86YD('=E"B`@("`@('=I;&P@
M=7-E('1A8FQE+6QE=F5L(&QO8VMI;F<@86YD(&YO(&QO8VMI;F<*("`@("`@
M:6YS=&5A9"XB/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S
M=VET8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL
M;"!W92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@
M("`@("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@
M("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I
M9W-T<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C
M<"(@9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE
M/2)P;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES
M(')U;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^,S,P-CPO8V]N9FEG:6YT
M96=E<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@
M:&]S=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O
M<B!W:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B
M/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U
M=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\
M+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S
M=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O
M('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_
M(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,]
M(E=H870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R92!W92!U<VEN9S\B
M/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@
M=&AE('-E<W-I;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]S97-S
M:6]N:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A
M<V4^"B`@("`\8V%S92!N86UE/2)O8VDX(B!D97-C/2)/<F%C;&4@8F%S960@
M<V5S<VEO;G,B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^
M"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G!E<G-I<W1E;G0B(&1E<V,]
M(E)E<75E<W0@<&5R<VES=&5N="!C;VYN96-T:6]N<S\B/@H@("`@("!F86QS
M93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H
M;W-T<W!E8R(@9&5S8STB1&%T86)A<V4@;F%M92!O<B!%87-Y($-O;FYE8W0*
M("`@("`@<&%R86UE=&5R(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N
M86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;PH@("`@("!T:&4@9&%T86)A<V4@
M<V5R=F5R(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)7:&%T('!A<W-W;W)D(&1O('=E"B`@("`@(&%U=&AE;G1I8V%T92!T;R!T
M:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA
M;64@;V8@=&AE('-E<W-I;VX*("`@("`@=&%B;&4@:6X@=&AE(&1A=&%B87-E
M(%MH;W)D95]S97-S:6]N:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I
M;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)P9W-Q;"(@9&5S8STB
M4&]S=&=R95-13"!B87-E9"!S97-S:6]N<R(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB
M<&5R<VES=&5N="(@9&5S8STB4F5Q=65S="!P97)S:7-T96YT(&-O;FYE8W1I
M;VYS/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL;"!W
M92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@("`@
M("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@("`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I9W-T
M<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C<"(@
M9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P
M;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES(')U
M;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^-30S,CPO8V]N9FEG:6YT96=E
M<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@:&]S
M=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O<B!W
M:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B/FQO
M8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U=&AE
M;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R
M9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O('=E
M(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,](E=H
M870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R92!W92!U<VEN9S\B/FAO
M<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE
M('-E<W-I;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]S97-S:6]N
M:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^
M"B`@("`\8V%S92!N86UE/2)S87!D8B(@9&5S8STB57-E(%!%05(G<R!$0B!A
M8G-T<F%C=&EO;B!L87EE<B!W+T]$0D,B/@H@("`@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S
M='-P96,B(&1E<V,](E=H870@:&]S=&YA;64@:7,@=&AE(&1A=&%B87-E('-E
M<G9E<B!R=6YN:6YG(&]N+"!O<B!W:&%T(&ES('1H92!N86UE(&]F('1H92!S
M>7-T96T@1%-.('1O('5S93\B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T
M('5S97)N86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@
M<V5R=F5R(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)7:&%T('!A<W-W;W)D(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T
M86)A<V4@<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB9&%T86)A<V4B(&1E<V,](E=H870@9&%T86)A<V4@;F%M92]T86)L97-P
M86-E(&%R92!W92!U<VEN9S\B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(&1E<V,](E1H92!N86UE(&]F
M('1H92!S97-S:6]N('1A8FQE(&EN('1H92!D871A8F%S92(O/@H@("`@(#PO
M8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](G-Q
M;"(@9&5S8STB57-E(%!%05(G<R!$0B!A8G-T<F%C=&EO;B!L87EE<B(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I
M9V)O;VQE86X@;F%M93TB<&5R<VES=&5N="(@9&5S8STB4F5Q=65S="!P97)S
M:7-T96YT(&-O;FYE8W1I;VYS/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@
M("`@(#QC;VYF:6=S=VET8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H870@
M<')O=&]C;VP@=VEL;"!W92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A
M<V4_(CYU;FEX"B`@("`@("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)53DE8
M(%-O8VME=',B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C:V5T
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@<V]C
M:V5T(CX\+V-O;F9I9W-T<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC
M87-E(&YA;64](G1C<"(@9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N9FEG
M:6YT96=E<B!N86UE/2)P;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!O
M<G0@=&AE($1"(&ES(')U;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^-30S
M,CPO8V]N9FEG:6YT96=E<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF
M:6=S=VET8V@^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B
M(&1E<V,](E=H870@:&]S=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R
M=6YN:6YG(&]N+"!O<B!W:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@
M1%-.('1O('5S93\B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N
M86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R
M(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T
M('!A<W-W;W)D(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@
M<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T
M86)A<V4B(&1E<V,](E=H870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R
M92!W92!U<VEN9S\B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M5&AE(&YA;64@;V8@=&AE('-E<W-I;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E
M(%MH;W)D95]S97-S:6]N:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I
M;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)M96UC86-H960B(&1E
M<V,](DUE;6-A8VAE9"!S97)V97(B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=L:7-T(&YA;64](FAO<W1S<&5C
M(B!D97-C/2)7:&%T(&AO<W1N86UE(&ES('1H92!M96UC86-H960@<V5R=F5R
M"B`@("`@(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE
M('-Y<W1E;2!$4TX@=&\@=7-E/R`@4W!E8VEF>0H@("`@("!M=6QT:7!L92!S
M97)V97)S('-E<&%R871E9"!B>2!C;VUM87,N(CYL;V-A;&AO<W0\+V-O;F9I
M9VQI<W0^"B`@("`@(#QC;VYF:6=L:7-T(&YA;64](G!O<G0B(')E<75I<F5D
M/2)F86QS92(@9&5S8STB4&]R="AS*2!T:&4@;65M8V%C:&5D"B`@("`@('-E
M<G9E<B!I<R!R=6YN:6YG(&]N+B!)9B!M;W)E('1H86X@;VYE(&AO<W0@:7,@
M=7-E9"P@<W!E8VEF>2!P;W)T<R!F;W(*("`@("`@<F5S<&5C=&EV92!S97)V
M97)S+"!S97!A<F%T960@8GD@8V]M;6%S(CXQ,3(Q,3PO8V]N9FEG;&ES=#X*
M("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<&5R<VES=&5N="(@<F5Q=6ER
M960](F9A;'-E(B!D97-C/2)297%U97-T"B`@("`@('!E<G-I<W1E;G0@8V]N
M;F5C=&EO;B!T;R!S97)V97(N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@
M("`@/&-O;F9I9V)O;VQE86X@;F%M93TB8V]M<')E<W-I;VXB(')E<75I<F5D
M/2)F86QS92(@9&5S8STB16YA8FQE"B`@("`@(&-O;7!R97-S:6]N(&9O<B!S
M=&]R:6YG(&5N=')I97,@;VX@<V5R=F5R+B(^9F%L<V4\+V-O;F9I9V)O;VQE
M86X^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;&]C:U]D:7(B(&1E<V,]
M(E-P96-I9GD@82!D:7)E8W1O<GD@=&\@=VAI8V@@=&AE"B`@("`@('-E<W-I
M;VX@;&]C:W,@<VAO=6QD(&)E('=R:71T96XB/B]T;7`\+V-O;F9I9W-T<FEN
M9SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@(#PO8V]N
M9FEG<W=I=&-H/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*
M(#QC;VYF:6=T86(@;F%M93TB:6UA9V4B(&1E<V,](DEM86=E($UA;FEP=6QA
M=&EO;B(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB:6UA9V4B/@H@("`\8V]N
M9FEG:&5A9&5R/DEM86=E($UA;FEP=6QA=&EO;CPO8V]N9FEG:&5A9&5R/@H@
M("`\8V]N9FEG<W1R:6YG(&YA;64](F-O;G9E<G0B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB2&]R9&4@<F5Q=6ER97,@96ET:&5R"B`@($=$('-U<'!O<G0@
M8G5I;'0M:6X@=&\@4$A0("@M+7=I=&@M9V0I(&]R('1H92!);6%G94UA9VEC
M:R!S;V9T=V%R90H@("!P86-K86=E("AH='1P.B\O=W=W+FEM86=E;6%G:6-K
M+F]R9R\I('1O(&1O(&EM86=E"B`@(&UA;FEP=6QA=&EO;B]C<F5A=&EO;BX@
M268@=7-I;F<@26UA9V5-86=I8VLL('-P96-I9GD@=&AE(&9U;&P@<&%T:`H@
M("!N86UE('1O('1H92`G8V]N=F5R="<@<')O9W)A;2X@3VX@5VEN9&]W<RP@
M=&AI<R!P871H("IC86YN;W0J(&AA=F4*("`@<W!A8V5S(&EN(&ET+B!5<V4@
M1$]3+7-T>6QE(&%B8G)E=FEA=&EO;G,@:68@;F5C97-S87)Y.B!0<F]G<F%^
M,0H@("!I;G-T96%D(&]F(%!R;V=R86T@1FEL97,L(&9O<B!I;G-T86YC92X@
M268@=7-I;F<@1T0L(&]R('5S:6YG"B`@(&YE:71H97(L(&QE879E('1H:7,@
M9FEE;&0@8FQA;FLN(B\^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T
M86(^"@H@/&-O;F9I9W1A8B!N86UE/2)M:6UE(B!D97-C/2)-24U%($1E=&5C
M=&EO;B(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB;6EM92(^"B`@(#QC;VYF
M:6=H96%D97(^34E-12!$971E8W1I;VX\+V-O;F9I9VAE861E<CX*("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)M86=I8U]D8B(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2),;V-A=&EO;B!O9B!T:&4@34E-10H@("!M86=I8R!D871A8F%S92X@
M57-U86QL>2`O=7-R+W-H87)E+VUI<V,O;6%G:6,@;W(@+V5T8R]M86=I8RXB
M+SX*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG
M=&%B(&YA;64](F=E;VEP(B!D97-C/2)(;W-T;F%M92TF9W0[0V]U;G1R>2!,
M;V]K=7`B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](F=E;VEP(CX*("`@/&-O
M;F9I9VAE861E<CY(;W-T;F%M92TF9W0[0V]U;G1R>2!,;V]K=7`\+V-O;F9I
M9VAE861E<CX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D871A9FEL92(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)(;W)D92P@8GD@9&5F875L="P@8V%N"B`@
M(&1O($AO<W1N86UE("TF9W0[($-O=6YT<GD@;&]O:W5P('5S:6YG('1H92!T
M;W`@;&5V96P@9&]M86EN("AE+F<N("=U:R<L"B`@("=D92<I(&]F('1H92!H
M;W-T;F%M92X@($AO=V5V97(L(&UA;GD@<&]P=6QA<B!T;W`@;&5V96P@9&]M
M86EN<PH@("`H92YG+B`G8V]M)RP@)VYE="<I('-P86X@;6]R92!T:&%N(&]N
M92!C;W5N=')Y+B`@26X@=&AE<V4@:6YS=&%N8V5S+"!(;W)D90H@("!C86X@
M=7-E('1H92!-87A-:6YD($=E;TE0($AO<W1N86UE('1O($-O=6YT<GD@;&]O
M:W5P('1O('1R>2!T;R!D971E<FUI;F4*("`@=&AE(&-O<G)E8W0@8V]U;G1R
M>2X@(%1O(&%C=&EV871E('1H:7,@9G5N8W1I;VYA;&ET>2P@=&AE($=E;TE0
M+F1A="!C;W5N=')Y"B`@(&1A=&%B87-E(&UU<W0@8F4@<')E<V5N="!O;B!Y
M;W5R(&QO8V%L('-Y<W1E;2X@(%1H:7,@9FEL92!C86X@8F4@9&]W;FQO861E
M9`H@("!F<F5E(&]F(&-H87)G92!F<F]M(&AT='`Z+R]W=W<N;6%X;6EN9"YC
M;VTO9&]W;FQO860O9V5O:7`O9&%T86)A<V4O+B`@268*("`@=&AI<R!D871A
M8F%S92!I<R!P<F5S96YT+"!S<&5C:69Y('1H92!F=6QL('!A=&@@;F%M92!T
M;R!T:&4@9&%T86)A<V4@8F5L;W<N"B`@($EF(&5M<'1Y+"!T:&4@1V5O25`@
M;&]O:W5P('=I;&P@;F]T(&)E('!E<F9O<FUE9"XB+SX*("`\+V-O;F9I9W-E
M8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](G!R;V)L
M96US(B!D97-C/2)0<F]B;&5M(%)E<&]R=&EN9R(^"B`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<')O8FQE;7,B/@H@("`\8V]N9FEG:&5A9&5R/E!R;V)L96T@
M4F5P;W)T:6YG/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=VET8V@@;F%M
M93TB=&EC:V5T<R(@9&5S8STB268@82!T:6-K970@<WES=&5M('=I=&@@80H@
M("!T:6-K971S+V%D9%1I8VME="!!4$D@;65T:&]D(&ES('!R97-E;G0L('-H
M;W5L9"!W92!C<F5A=&4@=&EC:V5T<R!F;W(*("`@<')O8FQE;2!R97!O<G1S
M(&EN<W1E860@;V8@96UA:6QI;F<@=&AE;3\B/F9A;'-E"B`@("`\8V%S92!N
M86UE/2)T<G5E(B!D97-C/2)997,B/@H@("`@(#QC;VYF:6=P:'`@;F%M93TB
M=&EC:V5T7W!A<F%M<R(@9&5S8STB16YT97(@87,@82!02%`@87)R87D@86YY
M"B`@("`@861D:71I;VYA;"!A<F=U;65N=',@9F]R('1H92!C<F5A=&5D('1I
M8VME="`H<75E=64L('-T871E+"!P<FEO<FET>2P*("`@("!E=&,I+B!%>&%M
M<&QE(&9O<B!7:'5P<SH@87)R87DH)W%U975E)R`]/B`R+"`G<W1A=&4G(#T^
M(#$L("=P<FEO<FET>2<@/3X@,2P*("`@("`G='EP92<@/3X@,2DN(%EO=2!W
M:6QL(&YE960@=&\@;&]O:R!U<"!T:&4@87!P<F]P<FEA=&4@241S(&EN(%=H
M=7!S)W,*("`@("!D871A8F%S92P@;W(@=VAA=&5V97(@:7,@87!P<F]P<FEA
M=&4@9F]R('1H92!T:6-K970@<WES=&5M('EO=2!A<F4*("`@("!U<VEN9RXB
M/F%R<F%Y*"D\+V-O;F9I9W!H<#X*("`@(#PO8V%S93X*("`@(#QC87-E(&YA
M;64](F9A;'-E(B!D97-C/2).;R(^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)E;6%I;"(@9&5S8STB5VAE<F4@<VAO=6QD('!R;V)L96T@<F5P;W)T(&5M
M86EL<R!B92!S96YT/R(^"B`@("`@=V5B;6%S=&5R0&5X86UP;&4N8V]M/"]C
M;VYF:6=S=')I;F<^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)M86EL9&]M
M86EN(B!D97-C/2))9B!(;W)D92!C86YN;W0@9&5T97)M:6YE(&$@=7-E<B=S
M"B`@("`@96UA:6P@861D<F5S<RP@=&AI<R!D;VUA:6X@=VEL;"!B92!A<'!E
M;F1E9"!T;R!T:&5I<@H@("`@('5S97)N86UE+B(^97AA;7!L92YC;VT\+V-O
M;F9I9W-T<FEN9SX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DEF(')E<75I<FEN9R!33510"B`@
M("`@875T:&5N=&EC871I;VX@=VET:&]U="!A(&=L;V)A;"!33510('5S97(@
M*&EN('-E8W1I;VX@)G%U;W0[36%I;&5R)G%U;W0["B`@("`@86YD(&%L;&]W
M:6YG('!R;V)L96T@<F5P;W)T:6YG(&9O<B!N;W0@875T:&5N=&EC871E9"!U
M<V5R<R`H:6X@<V5C=&EO;@H@("`@("9Q=6]T.TUE;G4@4V5T=&EN9W,F<75O
M=#LI+"!W:&%T('5S97)N86UE('-H;W5L9"!B92!U<V4@9F]R(%--5%`*("`@
M("!A=71H96YT:6-A=&EO;C\B+SX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!P87-S=V]R
M9"!T;R!U<V4B+SX*("`@(#PO8V%S93X*("`@/"]C;VYF:6=S=VET8V@^"B`@
M/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N
M86UE/2)M96YU(B!D97-C/2)-96YU(%-E='1I;F=S(CX*("`\8V]N9FEG:&5A
M9&5R/DUE;G4@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)M96YU(CX*("`@/&-O;F9I9VUU;'1I96YU;2!N86UE/2)A
M<'!S(B!D97-C/2)396QE8W0@86YY(&%P<&QI8V%T:6]N<R!T:&%T('-H;W5L
M9"!B90H@("!L:6YK960@:6X@2&]R9&4G<R!M96YU(CX*("`@(#QV86QU97,^
M"B`@("`@/&-O;F9I9W-P96-I86P@;F%M93TB;&ES="UH;W)D92UA<'!S(B`O
M/@H@("`@/"]V86QU97,^"B`@(#PO8V]N9FEG;75L=&EE;G5M/@H*("`@/&-O
M;F9I9V)O;VQE86X@;F%M93TB86QW87ES(B!D97-C/2)3:&]U;&0@=V4*("`@
M)FQT.W-T<F]N9R9G=#MA;'=A>7,F;'0[+W-T<F]N9R9G=#L@9&ES<&QA>2!T
M:&4@2&]R9&4*("`@9G)A;65S970_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*
M"B`@(#QC;VYF:6=S96-T:6]N(&YA;64](FQI;FMS(CX*("`@(#QC;VYF:6=E
M;G5M(&YA;64](FAE;'`B(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y(&AE;'`@
M;&EN:W,@:6X@=&AE"B`@("!M96YU/R(^86QL"B`@("`@/'9A;'5E<SX*("`@
M("`@/'9A;'5E(&1E<V,](D%L;"!U<V5R<R(^86QL/"]V86QU93X*("`@("`@
M/'9A;'5E(&1E<V,](D%U=&AE;G1I8V%T960@=7-E<G,B/F%U=&AE;G1I8V%T
M960\+W9A;'5E/@H@("`@("`\=F%L=64@9&5S8STB3F5V97(B/FYE=F5R/"]V
M86QU93X*("`@("`\+W9A;'5E<SX*("`@(#PO8V]N9FEG96YU;3X*("`@(#QC
M;VYF:6=B;V]L96%N(&YA;64](FAE;'!?86)O=70B(&1E<V,](E-H;W5L9"!W
M92!D:7-P;&%Y('1H92!A8F]U="!L:6YK(&EN"B`@("!T:&4@:&5L<"!M96YU
M/R(^=')U93PO8V]N9FEG8F]O;&5A;CX*("`@(#QC;VYF:6=E;G5M(&YA;64]
M(F]P=&EO;G,B(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y(&]P=&EO;G,@;&EN
M:W,@:6X@=&AE"B`@("!M96YU/R!9;W4@<W1I;&P@;F5E9"!T;R!C;VYF:6=U
M<F4@82!P<F5F97)E;F-E(&)A8VME;F0@:6X@=&AE"B`@("`F<75O=#M0<F5F
M97)E;F-E(%-Y<W1E;29Q=6]T.R!S96-T:6]N+B(^875T:&5N=&EC871E9`H@
M("`@(#QV86QU97,^"B`@("`@(#QV86QU92!D97-C/2)!;&P@=7-E<G,B/F%L
M;#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C/2)!=71H96YT:6-A=&5D('5S
M97)S(CYA=71H96YT:6-A=&5D/"]V86QU93X*("`@("`@/'9A;'5E(&1E<V,]
M(DYE=F5R(CYN979E<CPO=F%L=64^"B`@("`@/"]V86QU97,^"B`@("`\+V-O
M;F9I9V5N=6T^"B`@("`\8V]N9FEG96YU;2!N86UE/2)P<F]B;&5M(B!D97-C
M/2)3:&]U;&0@=V4@9&ES<&QA>2!P<F]B;&5M(')E<&]R=&EN9R!L:6YK<PH@
M("`@:6X@=&AE(&UE;G4_(CYA;&P*("`@("`\=F%L=65S/@H@("`@("`\=F%L
M=64@9&5S8STB06QL('5S97)S(CYA;&P\+W9A;'5E/@H@("`@("`\=F%L=64@
M9&5S8STB075T:&5N=&EC871E9"!U<V5R<R(^875T:&5N=&EC871E9#PO=F%L
M=64^"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V97(\+W9A;'5E/@H@
M("`@(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@/&-O;F9I9V5N
M=6T@;F%M93TB;&]G:6XB(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y(&$@;&]G
M:6X@;&EN:R!I;B!T:&4@;65N=0H@("`@=VAE;B!N;W0@;&]G9V5D(&EN/R(^
M86QL"B`@("`@/'9A;'5E<SX*("`@("`@/'9A;'5E(&1E<V,](D%L;"!U<V5R
M<R(^86QL/"]V86QU93X*("`@("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN979E
M<CPO=F%L=64^"B`@("`@/"]V86QU97,^"B`@("`\+V-O;F9I9V5N=6T^"B`@
M("`\8V]N9FEG96YU;2!N86UE/2)L;V=O=70B(&1E<V,](E-H;W5L9"!W92!D
M:7-P;&%Y(&$@;&]G;W5T(&QI;FL@:6X@=&AE"B`@("!M96YU('=H96X@;&]G
M9V5D(&EN/R(^875T:&5N=&EC871E9`H@("`@(#QV86QU97,^"B`@("`@(#QV
M86QU92!D97-C/2)!=71H96YT:6-A=&5D('5S97)S(CYA=71H96YT:6-A=&5D
M/"]V86QU93X*("`@("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN979E<CPO=F%L
M=64^"B`@("`@/"]V86QU97,^"B`@("`\+V-O;F9I9V5N=6T^"B`@("`\8V]N
M9FEG96YU;2!N86UE/2)L;V=I;B(@9&5S8STB4VAO=6QD('=E(&1I<W!L87D@
M82!L;V=I;B!L:6YK(&EN('1H92!M96YU"B`@("!W:&5N(&YO="!L;V=G960@
M:6X_(CYA;&P*("`@("`\=F%L=65S/@H@("`@("`\=F%L=64@9&5S8STB06QL
M('5S97)S(CYA;&P\+W9A;'5E/@H@("`@("`\=F%L=64@9&5S8STB3F5V97(B
M/FYE=F5R/"]V86QU93X*("`@("`\+W9A;'5E<SX*("`@(#PO8V]N9FEG96YU
M;3X*("`@(#QC;VYF:6=E;G5M(&YA;64](FQO9V]U="(@9&5S8STB4VAO=6QD
M('=E(&1I<W!L87D@82!L;V=O=70@;&EN:R!I;B!T:&4*("`@(&UE;G4@=VAE
M;B!L;V=G960@:6X_(CYA=71H96YT:6-A=&5D"B`@("`@/'9A;'5E<SX*("`@
M("`@/'9A;'5E(&1E<V,](D%U=&AE;G1I8V%T960@=7-E<G,B/F%U=&AE;G1I
M8V%T960\+W9A;'5E/@H@("`@("`\=F%L=64@9&5S8STB3F5V97(B/FYE=F5R
M/"]V86QU93X*("`@("`\+W9A;'5E<SX*("`@(#PO8V]N9FEG96YU;3X*("`@
M/"]C;VYF:6=S96-T:6]N/@H@(#PO8V]N9FEG<V5C=&EO;CX*"B`@/&-O;F9I
M9W-E8W1I;VX@;F%M93TB;&]G;R(^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M:6UA9V4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(%523"!O9B!A;B!I
M;6%G92!F;W(*("`@=&AE('1O<"!O9B!T:&4@2&]R9&4@;65N=2X@5&AE(&EM
M86=E('-H;W5L9"!B92!N;R!L87)G97(@=&AA;B`Q-#`@<&EX96QS"B`@('=I
M9&4@8GD@-#`@<&EX96QS(&AI9V@@=&\@<')E=F5N="!T:&4@9G)A;64@9G)O
M;2!S8W)O;&QI;F<N(B\^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB;&EN:R(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2))9B!A(&QO9V\@:7,@9&ES<&QA>65D
M(&EN"B`@('1H92!(;W)D92!M96YU+"!W:&%T(%523"`H:68@86YY*2!S:&]U
M;&0@:70@;&EN:R!T;S\B+SX*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I
M9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](FAO;VMS(B!D97-C/2)#=7-T;VT@
M1G5N8W1I;VX@2&]O:W,B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](FAO;VMS
M(CX*("`@/&-O;F9I9VAE861E<CY#=7-T;VT@1G5N8W1I;VX@2&]O:W,\+V-O
M;F9I9VAE861E<CX*("`@/&-O;F9I9V1E<V-R:7!T:6]N/@H@("`@5&AE<F4@
M87)E(&5X86UP;&4@9G5N8W1I;VYS(&9O<B!A;&P@:&]O:W,@:6X@:&]R9&4O
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T+@H@("`\+V-O;F9I9V1E<V-R:7!T:6]N
M/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)P97)M<V1E;FEE9"(@9&5S8STB
M268@=&AI<R!I<R!C:&5C:V5D+"!T:&4*("`@9G5N8W1I;VX@7W!E<FUS7VAO
M;VM?9&5N:65D*"D@=VEL;"!B92!C86QL960@=&\@<F5T=7)N(&%N(&5R<F]R
M(&UE<W-A9V4@:68*("`@82!P97)M:7-S:6]N(&AA<R!B965N(&1E;FEE9"X@
M3W1H97)W:7-E(&$@<W1A;F1A<F0@;65S<V%G92!W:6QL(&)E('-H;W=N"B`@
M(&%N9"!T:&4@=7-E<B!W;VXG="!S964@86YY(&%C=&EO;B!W:61G971S('1H
M870@:&4@9&]E<VXG="!H879E(&%C8V5S<PH@("!T;RXB/F9A;'-E/"]C;VYF
M:6=B;V]L96%N/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)U<V5R;F%M92(@
M9&5S8STB268@=&AI<R!I<R!C:&5C:V5D+"!T:&4@9G5N8W1I;VX*("`@7W5S
M97)N86UE7VAO;VM?9G)O;6)A8VME;F0H*2!W:6QL(&)E('5S960@=&\@<V5T
M('1H92!U<V5R(&YA;64@870@;&]G:6X*("`@=&EM92X@5&AE(&-O=6YT97)P
M87)T(&9U;F-T:6]N(%]U<V5R;F%M95]H;V]K7W1O8F%C:V5N9"@I('=I;&P@
M8F4@=7-E9"!T;PH@("!C;VYV97)T('5S97(@;F%M97,@8F%C:RP@9F]R(&5X
M86UP;&4@=VAE;B!S:&]W:6YG(&YA;64@;&ES=',@=&\@=&AE"B`@('5S97(N
M(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M
M93TB<')E875T:&5N=&EC871E(B!D97-C/2))9B!T:&ES(&ES(&-H96-K960@
M86YD('1H90H@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]P<F5A=71H96YT:6-A
M=&4H*2!R971U<FYS(&9A;'-E+"!A=71H96YT:6-A=&EO;B!W:6QL"B`@(&9A
M:6PN(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@
M;F%M93TB<&]S=&%U=&AE;G1I8V%T92(@9&5S8STB268@=&AI<R!I<R!C:&5C
M:V5D(&%N9"!T:&4*("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<&]S=&%U=&AE
M;G1I8V%T92@I(')E='5R;G,@9F%L<V4L(&%U=&AE;G1I8V%T:6]N('=I;&P*
M("`@9F%I;"XB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`\8V]N9FEG8F]O
M;&5A;B!N86UE/2)A=71H;&1A<"(@9&5S8STB268@=&AI<R!I<R!C:&5C:V5D
M+"!T:&4@9G5N8W1I;VX*("`@7VAO<F1E7VAO;VM?875T:&QD87`H*2!W:6QL
M(&)E('5S960@=&\@8W)E871E(&%N9"!S970@=&AE(&%T=')I8G5T97,@;F5E
M9&5D"B`@('1O(&%D9"]E9&ET+V1E;&5T92!U<V5R<R!B>2!T:&4@3$1!4"!!
M=71H(&1R:79E<BXB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@(#PO8V]N9FEG
M<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB8FQO
M8VLB(&1E<V,](E!O<G1A;"!";&]C:R!#;VYF:6=U<F%T:6]N(CX*("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)P;W)T86PB/@H@("`\8V]N9FEG:&5A9&5R/D9I
M>&5D($)L;V-K<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG;75L=&EE;G5M
M(&YA;64](F9I>&5D7V)L;V-K<R(@;75L9&5S8STB5VAI8V@@8FQO8VMS('-H
M;W5L9"!A;'=A>7,@8F4*("`@(&1I<W!L87EE9"!I;B!T:&4@<&]R=&%L/R(^
M"B`@("`\=F%L=65S/@H@("`@(#QC;VYF:6=S<&5C:6%L(&YA;64](FQI<W0M
M8FQO8VMS(B`O/@H@("`@/"]V86QU97,^"B`@(#PO8V]N9FEG;75L=&EE;G5M
M/@H@(#PO8V]N9FEG<V5C=&EO;CX*("`\8V]N9FEG:&5A9&5R/G=E871H97(N
M8V]M($-O;F9I9W5R871I;VX\+V-O;F9I9VAE861E<CX*("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)W96%T:&5R9&]T8V]M(CX*("`@/&-O;F9I9V1E<V-R:7!T
M:6]N/@H@("`@57-E(&]F('1H92!W96%T:&5R+F-O;2!B;&]C:R!R97%U:7)E
M<R!F<F5E(')E9VES=')A=&EO;B!F;W(@=&AE(%A-3`H@("`@9F5E9"!A="!H
M='1P.B\O=W=W+G=E871H97(N8V]M+W-E<G9I8V5S+WAM;&]A<"YH=&UL+@H@
M("`@069T97(@<F5G:7-T<F%T:6]N+"!A;B!E;6%I;"!W:6QL(&)E(')E='5R
M;F5D('=I=&@@=&AE(%!A<G1N97(@240@86YD"B`@("!L:6-E;G-E(&ME>2XF
M;'0[8G(@+R`F9W0["B`@("!.3U1%.B!W96%T:&5R+F-O;2!G=6ED96QI;F5S
M(')E<75I<F4@<F5G:7-T<F%T:6]N(&%N9"!U<V4@;V8@=&AE(')E='5R;F5D
M"B`@("!V86QU97,L(&)U="!T:&4@87!P;&EC871I;VX@87!P96%R<R!T;R!F
M=6YC=&EO;B!W:71H(&%N>2!S=')I;F<@=F%L=65S+@H@("`\+V-O;F9I9V1E
M<V-R:7!T:6]N/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<G1N97)?:60B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A<G1N97(@22Y$+@H@("!F
M<F]M('=E871H97(N8V]M(B\^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB;&EC
M96YS95]K97DB(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&QI8V5N<V4@
M:V5Y"B`@(&9R;VT@=V5A=&AE<BYC;VTB+SX*("`\+V-O;F9I9W-E8W1I;VX^
M"@H@(#QC;VYF:6=H96%D97(^1F]R='5N92!#;VYF:6=U<F%T:6]N/"]C;VYF
M:6=H96%D97(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB9F]R='5N92(^"B`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB97AE8U]P871H(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E!A=&@@=&\@9F]R='5N90H@("!E>&5C=71A8FQE+"!E+F<N
M("]U<W(O9V%M97,O9F]R='5N92(O/@H@(#PO8V]N9FEG<V5C=&EO;CX*"B`@
M/&-O;F9I9VAE861E<CY!8V-O=6YT($EN9F\@0V]N9FEG=7)A=&EO;CPO8V]N
M9FEG:&5A9&5R/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](F%C8V]U;G1S(CX*
M("`@/&-O;F9I9W-W:71C:"!N86UE/2)D<FEV97(B(&1E<V,](E=H870@(&1R
M:79E<B!S:&]U;&0@=V4@=7-E/R(^;G5L;`H@("`@/&-A<V4@;F%M93TB;G5L
M;"(@9&5S8STB;G5L;"(O/@H@("`@/&-A<V4@;F%M93TB;&]C86QH;W-T(B!D
M97-C/2)L;V-A;&AO<W0B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A
M<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<75O=&%?<&%T:"(@
M9&5S8STB4&%T:"!T;R!T:&4@<75O=&$@<')O9W)A;2(^+W5S<B]B:6XO<75O
M=&$\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)G
M<F5P7W!A=&@B(&1E<V,](E!A=&@@=&\@=&AE(&=R97`@<')O9W)A;2(^+V)I
M;B]G<F5P/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA
M;64](G1R86YS;&%T94UO=6YT4&]I;G0B(&1E<V,](E-H;W5L9"!W92!T<F%N
M<VQA=&4@:&]M92!D:7)E8W1O<FEE<R!T;R!M;W5N="!P;VEN="!D979I8V4@
M;F%M97,_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)T<F%N<VQA=&EO;E1A8FQE(B!D97-C/2)&:6QE('1O('1R
M86YS;&%T92!D:7)E8W1O<GD@;F%M97,@=&\@;6]U;G0@<&]I;G0@9&5V:6-E
M(&YA;65S/R(^+V5T8R]M=&%B/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB;&1A<"(@
M9&5S8STB3$1!4"(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T(B!D97-C/2),1$%0
M('-E<G9E<B]H;W-T(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@
M/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)0;W)T($Q$05`@:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD87)D
M(CXS.#D\+V-O;F9I9VEN=&5G97(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB8F%S961N(B!D97-C/2)B87-E9&X@<W1R:6YG(CYO/65X86UP;&4N8V]M
M+&,]55,\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)A='1R(B!D97-C/2),1$%0(&%T=')I8G5T92!T;R!S96%R8V@@;VXB/G5I
M9#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)V97)S
M:6]N(B!D97-C/2),1$%0(%!R;W1O8V]L(%9E<G-I;VXB/C,*("`@("`@(#QV
M86QU97,^"B`@("`@("`@/'9A;'5E(&1E<V,](DQ$05!V,B`H1&5P<F5C871E
M9"DB/C(\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2),1$%0=C,B/C,\
M+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@(#PO8V]N9FEG
M<W=I=&-H/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H@/&-O
M;F9I9W1A8B!N86UE/2)I;7-P(B!D97-C/2))35-0('-E<G9E<B!S971T:6YG
M<R(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB:6US<"(^"B`@(#QC;VYF:6=D
M97-C<FEP=&EO;CX*("`@"4EF('EO=2!P;&%N('1O('5S92!A;GD@;V8@2&]R
M9&4G<R!)35-0('-E<G9E<B!S=7!P;W)T+"!E;F%B;&4@=&AI<R!O<'1I;VX@
M86YD"B`@(`EC;VYF:6=U<F4@=&AE('-E<G9E<B!S971T:6YG<R!B96QO=RX@
M($YO=&4@=&AA="!Y;W4@;75S="!S=&EL;"!C;VYF:6=U<F4O96YA8FQE"B`@
M(`ES<&5C:69I8R!)35-0('-U<'!O<G0@:6X@=&AE(&%P<')O<')I871E('-E
M8W1I;VXN"B`@(#PO8V]N9FEG9&5S8W)I<'1I;VX^"B`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB96YA8FQE9"(^9F%L<V4*("`@(#QC87-E(&YA;64](F9A;'-E
M(B!D97-C/2)$:7-A8FQE9"(@+SX*("`@(#QC87-E(&YA;64](G1R=64B(&1E
M<V,](D5N86)L960B/@H@("`@(#QC;VYF:6=H96%D97(^24U34"!397)V97(@
M4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G-E<G9E<B(@9&5S8STB4V5R=F5R($%D9')E<W,Z(CYL;V-A;&AO<W0\
M+V-O;F9I9W-T<FEN9SX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!O<G0B
M(&1E<V,](E-E<G9E<B!P;W)T.B(^-#`V/"]C;VYF:6=S=')I;F<^"B`@("`@
M/&-O;F9I9W-W:71C:"!N86UE/2)A=71H7VUE=&AO9"(@9&5S8STB5&AE(&%U
M=&AE;G1I8V%T:6]N(&UE=&AO9"!T;R!U<V4B/G!L86EN=&5X=`H@("`@("`\
M8V%S92!N86UE/2)P;&%I;G1E>'0B(&1E<V,](E!L86EN=&5X="(@+SX*("`@
M("`@/&-A<V4@;F%M93TB8W)A;5]M9#4B(&1E<V,](D-204TM340U(B`O/@H@
M("`@("`\8V%S92!N86UE/2)I;71E<W0B(&1E<V,](D-Y<G5S(&EM=&5S="(^
M"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-O8VME="(@9&5S8STB4&%T
M:"!T;R!T:&4@9&ER96-T;W)Y('1H870@=VEL;"!H;VQD('1H92!S;V-K970N
M"B`@("`@("`H5&AE('-O8VME="!W:6QL(&)E(&YA;65D("=I;7-P7W5S97)N
M86UE+G-C:R<I+B(^+W1M<"\\+V-O;F9I9W-T<FEN9SX*("`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB8V]M;6%N9"(@9&5S8STB4&%T:"!T;R!I;71E<W0@
M8FEN87)Y(CXO8WER=7,O=7-R+V-Y<G5S+V)I;B]I;71E<W0\+V-O;F9I9W-T
M<FEN9SX*("`@("`@(#QC;VYF:6=E;G5M(&YA;64](F%U=&A?;65C:&%N:7-M
M(B!D97-C<FEP=&EO;CTB5VAA="!A=71H96YT:6-A=&EO;B!M971H;V0@9&\@
M>6]U('=A;G0*("`@("`@('1O('5S92!W:71H('1H92!I;71E<W0@=71I;&ET
M>3\B/@H@("`@("`@(#QV86QU97,^"B`@("`@("`@(#QV86QU92!D97-C/2)0
M;&%I;G1E>'0@*$Q/1TE.*2(^3$]'24X\+W9A;'5E/@H@("`@("`@("`\=F%L
M=64@9&5S8STB1U-305!)(CYG<W-A<&D\+W9A;'5E/@H@("`@("`@(#PO=F%L
M=65S/@H@("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`\+V-A<V4^"B`@("`@
M/"]C;VYF:6=S=VET8V@^"B`@("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I=&-H
M/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T
M86(@;F%M93TB:V]L86(B(&1E<V,](DMO;&%B($=R;W5P=V%R92!397)V97(B
M/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](FMO;&%B(CX*("`@/&-O;F9I9V1E
M<V-R:7!T:6]N/@H@("`@)FQT.V1I=B!S='EL93TB=&5X="UA;&EG;CIC96YT
M97(B)F=T.R9L=#MS=')O;F<F9W0[*BHJ($E&(%E/52!(059%($Y/($E$14$*
M("`@(%=(050@2T],04(@25,@5$A%3B!93U4@0T%.(%-!1D5,62!)1TY/4D4@
M5$A)4R!404(*("`@("HJ*B9L=#LO<W1R;VYG)F=T.R9L=#LO9&EV)F=T.R!+
M;VQA8B!I<R!I;B!N;R!W87D@<F5Q=6ER960@9F]R(&YO<FUA;`H@("`@2&]R
M9&4@=7-A9V4N($EF+"!H;W=E=F5R+"!Y;W4@:6YT96YD('1O('5S92!(;W)D
M92!A<R!A('=E8F-L:65N="!F;W(@2V]L86(*("`@('1H96X@>6]U('=I;&P@
M;F5E9"!T;R!E;G-U<F4@=&AA="!T:&4@9F]L;&]W:6YG(&9I96QD<R!C;W)R
M97-P;VYD('1O('1H;W-E"B`@("!R97%U:7)E9"!B>2!Y;W5R($MO;&%B(&EN
M<W1A;&QA=&EO;BX@(%EO=2!C86X@9FEN9"!S;VUE(&]F('1H92!R97%U:7)E
M9`H@("`@=F%L=65S(&EN('1H92`F;'0[8V]D929G=#L@)$M/3$%"7U)/3U0O
M971C+VMO;&%B+VMO;&%B+F-O;F8F;'0[+V-O9&4F9W0["B`@("!C;VYF:6=U
M<F%T:6]N(&9I;&4N(%!L96%S92!N;W1E('1H870@=&AE(&]L9"!I0V%L+W9#
M87)D('-T;W)A9V4@9F]R;6%T(&AA<PH@("`@8F5E;B!D<F]P<&5D(&EN(&9A
M=F]U<B!O9B!T:&4@;F5W(%A-3"!S=&]R86=E(&9O<FUA="`F86UP.R!)34%0
M(&9O;&1E<@H@("`@86YN;W1A=&EO;G,[('-U8G-E<75E;G1L>2!T:&4@2&]R
M9&4@2V]L86(@;6]D=6QE<R!W:6QL(&]N;'D@=V]R:R!W:71H"B`@("!V97)S
M:6]N(#(@;V8@=&AE($MO;&%B('-E<G9E<BX@("9L=#MD:78@<W1Y;&4](G1E
M>'0M86QI9VXZ8V5N=&5R(B9G=#M)9@H@("`@>6]U('=O=6QD(&QI:V4@=&\@
M9FEN9"!O=70@;6]R92!A8F]U="!+;VQA8B!T:&5N('!L96%S92!V:7-I="!T
M:&4@2V]L86(*("`@(&-O;6UU;FET>2!W96)S:71E(&%T(&AT='`Z+R]W=W<N
M:V]L86(N;W)G+R9L=#LO9&EV)F=T.PH@("`\+V-O;F9I9V1E<V-R:7!T:6]N
M/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F5N86)L960B('%U;W1E/2)F86QS
M92(@9&5S8STB2&]R9&4O2V]L86(@:6YT96=R871I;VX*("`@('-T871U<R(^
M9F%L<V4*("`@(#QC87-E(&YA;64](F9A;'-E(B!D97-C/2)$:7-A8FQE9"(@
M+SX*("`@(#QC87-E(&YA;64](G1R=64B(&1E<V,](D5N86)L960B/@H@("`@
M(#QC;VYF:6=H96%D97(^2V]L86(@3$1!4"!397)V97(@4V5T=&EN9W,\+V-O
M;F9I9VAE861E<CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)L9&%P(CX*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S97)V97(B(&1E<V,](E-E<G9E
M<@H@("`@("!A9&1R97-S.B(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@
M("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E-E<G9E<B!P
M;W)T.B(^,S@Y/"]C;VYF:6=I;G1E9V5R/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](F)A<V5D;B(@9&5S8STB0F%S92!$3CHB/F1C/65X86UP;&4L"B`@
M("`@(&1C/6-O;3PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](F)I;F1D;B(@9&5S8STB0FEN9"!$3CHB/F-N/6UA;F%G97(L(&-N
M/6EN=&5R;F%L+`H@("`@("!D8SUE>&%M<&QE+"!D8SUC;VT\+V-O;F9I9W-T
M<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)B:6YD<'<B(&1E<V,]
M(D)I;F0@4&%S<W=O<F0Z(CYP87-S=V]R9#PO8V]N9FEG<W1R:6YG/@H@("`@
M(#PO8V]N9FEG<V5C=&EO;CX*("`@("`\8V]N9FEG:&5A9&5R/DMO;&%B($-Y
M<G5S($E-05`@4V5R=F5R(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@("`@
M/&-O;F9I9W-E8W1I;VX@;F%M93TB:6UA<"(^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB<V5R=F5R(B!D97-C/2)397)V97(*("`@("`@861D<F5S<SHB
M/FUA:6PN97AA;7!L92YC;VT\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9VEN=&5G97(@;F%M93TB<&]R="(@9&5S8STB4V5R=F5R('!O<G0Z(CXQ-#,\
M+V-O;F9I9VEN=&5G97(^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G-I
M979E<&]R="(@9&5S8STB4VEE=F4@<&]R=#HB/C(P,#`\+V-O;F9I9VEN=&5G
M97(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;6%I;&1O;6%I;B(@9&5S
M8STB1&5F875L=`H@("`@("!M86EL9&]M86EN.B(^97AA;7!L92YC;VT\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A9&UI;G5S
M97(B(&1E<V,](D%D;6EN:7-T<F%T;W(*("`@("`@=7-E<CHB/FUA;F%G97(\
M+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A9&UI
M;G!W(B!D97-C/2)!9&UI;FES=')A=&]R"B`@("`@('!A<W-W;W)D.B(^<&%S
M<W=O<F0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M
M93TB=FER=&1O;6%I;G,B(&1E<V,](E9I<G1U86P*("`@("`@9&]M86EN<SHB
M/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@
M("`@(#QC;VYF:6=H96%D97(^2V]L86(@4TU44"!397)V97(@4V5T=&EN9W,\
M+V-O;F9I9VAE861E<CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S;71P
M(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S97)V97(B(&1E<V,](E-E
M<G9E<@H@("`@("!A9&1R97-S.B(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^
M"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E-E<G9E
M<B!P;W)T.B(^,C4\+V-O;F9I9VEN=&5G97(^"B`@("`@/"]C;VYF:6=S96-T
M:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I
M9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*/"]C;VYF:6=U<F%T:6]N/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O+FAT86-C97-S````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#$V`#$P
M-#$W,S8R-S0S`#`R,#`V-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!$96YY(&9R;VT@86QL"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]E=&,O<'-A+6AO<F1E+VEN9V\O````````````````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P
M,38Q,S(`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:6YG;R]B86-K96YD
M<RYP:'``````````````````````````````````````````````````````
M`````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S
M-#<T`#$P-#$W,S8R-S0S`#`R,#0R,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!I;F=O
M+V-O;F9I9R]B86-K96YD<RYP:'`N9&ES="QV(#$N,C`N."XT(#(P,#8O,#(O
M,#(@,C(Z-3<Z,S$@:F%N($5X<"`D"B`J"B`J($EN9V\@=V]R:W,@<'5R96QY
M(&]N(&$@<')E9F5R<F5D(&UE8VAA;FES;2!F;W(@<V5R=F5R('-E;&5C=&EO
M;BX@5&AE<F4@87)E"B`J(&$@;G5M8F5R(&]F('!R;W!E<G1I97,@=&AA="!Y
M;W4@8V%N('-E="!F;W(@96%C:"!B86-K96YD.@H@*@H@*B!D<FEV97(Z("`@
M("`@(%1H92!);F=O7T1R:79E<B!D<FEV97(@=&\@=7-E('1O(&=E="!T:&4@
M<V-R:7!T('1O('1H90H@*B`@("`@("`@("`@("`@(&)A8VME;F0@<V5R=F5R
M+B!686QI9"!O<'1I;VYS.@H@*B`@("`@("`@("`@("`@("`@("`G;G5L;"<@
M("`@("`@+2T@($YO(&)A8VME;F0@<V5R=F5R"B`J("`@("`@("`@("`@("`@
M("`@("=T:6US:65V960G("`M+2`@0WER=7,@=&EM<VEE=F5D('-E<G9E<@H@
M*B`@("`@("`@("`@("`@("`@("`G=F9S)R`@("`@("`@+2T@(%5S92!(;W)D
M92!61E,*("H*("H@<')E9F5R<F5D.B`@("!4:&ES(&ES('1H92!F:65L9"!T
M:&%T(&ES('5S960@=&\@8VAO;W-E('=H:6-H('-E<G9E<B!I<PH@*B`@("`@
M("`@("`@("`@('5S960N(%1H92!V86QU92!F;W(@=&AI<R!F:65L9"!M87D@
M8F4@82!S:6YG;&4@<W1R:6YG(&]R(&%N"B`J("`@("`@("`@("`@("`@87)R
M87D@;V8@<W1R:6YG<R!C;VYT86EN:6YG('1H92!H;W-T;F%M97,@=&\@=7-E
M('=I=&@@=&AI<PH@*B`@("`@("`@("`@("`@('-E<G9E<BX*("H*("H@:&]R
M9&5A=71H.B`@("!);F=O('5S97,@=&AE(&-U<G)E;G0@;&]G9V5D(&EN('5S
M97)N86UE(&%N9"!P87-S=V]R9"X@268*("H@("`@("`@("`@("`@("!Y;W4@
M=V%N="!T:&4@9G5L;"!U<V5R;F%M94!R96%L;2!T;R!B92!U<V5D('1O(&-O
M;FYE8W0@=&AE;@H@*B`@("`@("`@("`@("`@('-E="!T:&ES('1O("=F=6QL
M)R!O=&AE<G=I<V4@<V5T('1H:7,@=&\@=')U92!A;F0@:G5S="!T:&4*("H@
M("`@("`@("`@("`@("!U<V5R;F%M92!W:6QL(&)E('5S960@=&\@8V]N;F5C
M="!T;R!T:&4@9')I=F5R+@H@*@H@*B!P87)A;7,Z("`@("`@($%N(&%R<F%Y
M(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@:6YF;W)M871I;VX@=&AA="!T
M:&4*("H@("`@("`@("`@("`@("!);F=O7T1R:79E<B!C;&%S<R!N965D<RX*
M("H*("H@<V-R:7!T.B`@("`@("!4:&4@='EP92!O9B!);F=O7U-C<FEP="!D
M<FEV97(@=&AI<R!S97)V97(@=7-E<RX*("H@("`@("`@("`@("`@("!686QI
M9"!O<'1I;VYS.@H@*B`@("`@("`@("`@("`@("`@("`G:6UA<"<@("`@("`M
M+2`@24U!4"!C;&EE;G0@<VED92!F:6QT97)I;F<*("H@("`@("`@("`@("`@
M("`@("`@)VUA:6QD<F]P)R`@+2T@($UA:6QD<F]P('-C<FEP=',*("H@("`@
M("`@("`@("`@("`@("`@)W!R;V-M86EL)R`@+2T@(%!R;V-M86EL('-C<FEP
M=',*("H@("`@("`@("`@("`@("`@("`@)W-I979E)R`@("`@+2T@(%-I979E
M('-C<FEP=',*("H*("H@<V-R:7!T<&%R86US.B!!;B!A<G)A>2!C;VYT86EN
M:6YG(&%N>2!A9&1I=&EO;F%L(&EN9F]R;6%T:6]N('1H870@=&AE"B`J("`@
M("`@("`@("`@("`@26YG;U]38W)I<'0@9')I=F5R(&YE961S+@H@*B\*"B\J
M($E-05`@17AA;7!L92`J+PHD8F%C:V5N9'-;)VEM87`G72`](&%R<F%Y*`H@
M("`@)V1R:79E<B<@/3X@)VYU;&PG+`H@("`@)W!R969E<G)E9"<@/3X@)VQO
M8V%L:&]S="<L"B`@("`G:&]R9&5A=71H)R`]/B!T<G5E+`H@("`@)W!A<F%M
M<R<@/3X@87)R87DH*2P*("`@("=S8W)I<'0G(#T^("=I;6%P)RP*("`@("=S
M8W)I<'1P87)A;7,G(#T^(&%R<F%Y*"D**3L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VEN9V\O8V]N9BYX;6P`````
M````````````````````````````````````````````````````````````
M```````````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$S,P`Q
M,#0Q-S,V,C<T,P`P,3<U-S0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO
M<F1E.B!I;F=O+V-O;F9I9R]C;VYF+GAM;"QV(#$N,3,@,C`P-"\P,B\Q,2`Q
M.3HR-#HR,R!S;'5S87)Z($5X<"`D("TM/@H\8V]N9FEG=7)A=&EO;CX*(#QC
M;VYF:6=S96-T:6]N(&YA;64](FUE;G4B(&1E<V,](DUE;G4@<V5T=&EN9W,B
M/@H@("`\8V]N9FEG:&5A9&5R/@H@("`@("`@($UE;G4@<V5T=&EN9W,*("`@
M/"]C;VYF:6=H96%D97(^"B`@/&-O;F9I9VUU;'1I96YU;2!N86UE/2)A<'!S
M(B!D97-C/2)396QE8W0@86YY(&%P<&QI8V%T:6]N<R!T:&%T('-H;W5L9"!B
M92!L:6YK960@:6X@26YG;R=S(&UE;G4B/@H@("`\=F%L=65S/@H@("`@/&-O
M;F9I9W-P96-I86P@;F%M93TB;&ES="UH;W)D92UA<'!S(B`O/@H@("`\+W9A
M;'5E<SX*("`\+V-O;F9I9VUU;'1I96YU;3X*(#PO8V]N9FEG<V5C=&EO;CX*
M"B`\8V]N9FEG<V5C=&EO;B!N86UE/2)S=&]R86=E(B!D97-C/2));F=O(%)U
M;&5S(%-T;W)A9V4B/@H@(#QC;VYF:6=H96%D97(^"B`@26YG;R!2=6QE<R!3
M=&]R86=E"B`@/"]C;VYF:6=H96%D97(^"B`@/&-O;F9I9V5N=6T@;F%M93TB
M9')I=F5R(B!D97-C/2)7:&%T('-T;W)A9V4@9')I=F5R('-H;W5L9"!W92!U
M<V4_(CYP<F5F<PH@("`\=F%L=65S/@H@("`@/'9A;'5E/G!R969S/"]V86QU
M93X*("`@/"]V86QU97,^"B`@/"]C;VYF:6=E;G5M/@H@(#QC;VYF:6=I;G1E
M9V5R(&YA;64](FUA>&)L86-K;&ES="(@9&5S8STB5&AE(&UA>&EM=6T@;G5M
M8F5R(&]F(&)L86-K;&ES="!A9&1R97-S97,@82!U<V5R(&-A;B!S=&]R92X@
M(%-E="!T;R`P(&9O<B!N;R!L:6UI="XB/C`\+V-O;F9I9VEN=&5G97(^"B`@
M/&-O;F9I9VEN=&5G97(@;F%M93TB;6%X=VAI=&5L:7-T(B!D97-C/2)4:&4@
M;6%X:6UU;2!N=6UB97(@;V8@=VAI=&5L:7-T(&%D9')E<W-E<R!A('5S97(@
M8V%N('-T;W)E+B`@4V5T('1O(#`@9F]R(&YO(&QI;6ET+B(^,#PO8V]N9FEG
M:6YT96=E<CX*(#PO8V]N9FEG<V5C=&EO;CX*"B`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)R=6QE<R(@9&5S8STB26YG;R!2=6QE<R!/<'1I;VYS(CX*("`\8V]N
M9FEG:&5A9&5R/@H@($EN9V\@4G5L97,@3W!T:6]N<PH@(#PO8V]N9FEG:&5A
M9&5R/@H@(#QC;VYF:6=B;V]L96%N(&YA;64](G5S97)H96%D97(B(&1E<V,]
M(D%L;&]W('5S97)S('1O(&UA;G5A;&QY(&5N=&5R($AE861E<B!F:65L9',@
M=&\@<V5A<F-H(&)Y(&EN('1H92!2=6QE(&5D:70@<V-R965N/R(^=')U93PO
M8V]N9FEG8F]O;&5A;CX*("`\8V]N9FEG8F]O;&5A;B!N86UE/2)U<V5F;VQD
M97)A<&DB(&1E<V,](E5S92!T:&4@2&]R9&4@)VUA:6PO9F]L9&5R;&ES="<@
M05!)(&-A;&P@=&\@;V)T86EN('1H92!L:7-T(&]F(&UA:6P@9F]L9&5R<R!T
M;R!U<V4@9F]R('9A<FEO=7,@9FEL=&5R:6YG(')U;&5S/R!)9B!)35`@:7,@
M:6YS=&%L;&5D(&ET('=I;&P@<')O=FED92!T:&4@05!)(&-A;&PL('-O('EO
M=2!S:&]U;&0@<V%Y('1R=64N($EF(&9A;'-E+"!T:&4@=7-E<B!M=7-T(&UA
M;G5A;&QY(&5N=&5R('1H92!N86UE(&]F('1H92!F;VQD97(@*$Y/5"!214-/
M34U%3D1%1"DN(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@/"]C;VYF:6=S96-T
M:6]N/@H\+V-O;F9I9W5R871I;VX^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O971C+W!S82UH;W)D92]I;F=O+RYH=&%C8V5S<P``````````
M````````````````````````````````````````````````````````````
M````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S
M-C(W-#,`,#$W-S(P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$1E;GD@9G)O;2!A;&P*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+V5T
M8R]P<V$M:&]R9&4O:6YG;R]F:65L9',N<&AP````````````````````````
M`````````````````````````````````````````````````#`Q,#`T-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,#0T`#$P-#$W,S8R-S0S`#`R,#$P
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AO<F1E.B!I;F=O+V-O;F9I9R]F:65L9',N<&AP+F1I
M<W0L=B`Q+C4@,C`P,R\P."\Q.2`Q-SHP.#HT,2!S;'5S87)Z($5X<"`D"B`J
M"B`J(%1H:7,@9FEL92!D969I;F5S('1H92!S970@;V8@9&5F875L="!M871C
M:"!I=&5M<R!T;R!D:7-P;&%Y('=H96X@8W)E871I;F<*("H@82!N97<@9FEL
M=&5R(')U;&4N"B`J(%1H97-E(&9I96QD<R!W:6QL(&]N;'D@87!P96%R(&EF
M('1H92!D<FEV97(@8V%N(&AA;F1L92!I="X*("H@57-E<G,@=VEL;"!H879E
M('1O(&UA;G5A;&QY(&EN<V5R="!T:&4@;F%M92!O9B!T:&4@:&5A9&5R(&]N
M('1H92!R=6QE"B`J(&-R96%T:6]N('-C<F5E;B!I9B!I="!D;V5S(&YO="!A
M<'!E87(@:6X@=&AI<R!L:7-T+@H@*@H@*B!&;W)M870@;V8@)&EN9V]?9FEE
M;&1S(&%R<F%Y.@H@*B`@("=,04)%3"<@/3X@87)R87DH"B`J("`@("!-04Y$
M051/4EDZ"B`J("`@("`G;&%B96PG(#T^("AS=')I;F<I("!4:&4@9V5T=&5X
M="!L86)E;"!F;W(@=&AE(&5N=')Y+@H@*B`@("`@)W1Y<&4G("`]/B`H:6YT
M96=E<BD@5&AE('1Y<&4@;V8@=&5S="X@16ET:&5R.@H@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@24Y'3U]35$]204=%7U194$5?2$5!1$52("`M+2`@
M2&5A9&5R('1E<W0*("H@("`@("`@("`@("`@("`@("`@("`@("`@($E.1T]?
M4U1/4D%'15]465!%7U-)6D4@("`@+2T@($UE<W-A9V4@<VEZ92!T97-T"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!)3D=/7U-43U)!1T5?5%E015]"
M3T19("`@("TM("!";V1Y('1E<W0*("H@("`@($]05$E/3D%,.@H@*B`@("`@
M)W1E<W1S)R`]/B`H87)R87DI("`@1F]R8V4@=&AE<V4@=&5S=',@=&\@8F4@
M=7-E9"!O;FQY+@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@268@;F]T
M('-E="P@=VEL;"!U<V4@=&AE(&9I96QD<R!G96YE<F%L;'D*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%V86EL86)L92!T;R!T:&4@9')I=F5R+@H@
M*B`@("D*("HO"B1I;F=O7V9I96QD<R`](&%R<F%Y*`H@("=4;R<@/3X@87)R
M87DH"B`@("`G;&%B96PG(#T^(%\H(E1O(BDL"B`@("`G='EP92<@/3X@24Y'
M3U]35$]204=%7U194$5?2$5!1$52"B`@*2P*("`G4W5B:F5C="<@/3X@87)R
M87DH"B`@("`G;&%B96PG(#T^(%\H(E-U8FIE8W0B*2P*("`@("=T>7!E)R`]
M/B!)3D=/7U-43U)!1T5?5%E015](14%$15(*("`I+`H@("=396YD97(G(#T^
M(&%R<F%Y*`H@("`@)VQA8F5L)R`]/B!?*")396YD97(B*2P*("`@("=T>7!E
M)R`]/B!)3D=/7U-43U)!1T5?5%E015](14%$15(*("`I+`H@("=&<F]M)R`]
M/B!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B1G)O;2(I+`H@("`@)W1Y<&4G
M(#T^($E.1T]?4U1/4D%'15]465!%7TA%041%4@H@("DL"B`@)T-C)R`]/B!A
M<G)A>2@*("`@("=L86)E;"<@/3X@7R@B0V,B*2P*("`@("=T>7!E)R`]/B!)
M3D=/7U-43U)!1T5?5%E015](14%$15(*("`I+`H@("="8V,G(#T^(&%R<F%Y
M*`H@("`@)VQA8F5L)R`]/B!?*")"8V,B*2P*("`@("=T>7!E)R`]/B!)3D=/
M7U-43U)!1T5?5%E015](14%$15(*("`I+`H@("=297-E;G0M9G)O;2<@/3X@
M87)R87DH"B`@("`G;&%B96PG(#T^(%\H(E)E<V5N="UF<F]M(BDL"B`@("`G
M='EP92<@/3X@24Y'3U]35$]204=%7U194$5?2$5!1$52"B`@*2P*("`G4F5S
M96YT+71O)R`]/B!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B4F5S96YT(%1O
M(BDL"B`@("`G='EP92<@/3X@24Y'3U]35$]204=%7U194$5?2$5!1$52"B`@
M*2P*("`G3&ES="U)9"<@/3X@87)R87DH"B`@("`G;&%B96PG(#T^(%\H(DQI
M<W0M240B*2P*("`@("=T>7!E)R`]/B!)3D=/7U-43U)!1T5?5%E015](14%$
M15(*("`I+`H@("=296-E:79E9"<@/3X@87)R87DH"B`@("`G;&%B96PG(#T^
M(%\H(E)E8V5I=F5D(BDL"B`@("`G='EP92<@/3X@24Y'3U]35$]204=%7U19
M4$5?2$5!1$52"B`@*2P*("`G6"U3<&%M+4QE=F5L)R`]/B!A<G)A>2@*("`@
M("=L86)E;"<@/3X@7R@B6"U3<&%M+4QE=F5L(BDL"B`@("`G='EP92<@/3X@
M24Y'3U]35$]204=%7U194$5?2$5!1$52"B`@*2P*("`G6"U3<&%M+5-C;W)E
M)R`]/B!A<G)A>2@*("`@("=L86)E;"<@/3X@7R@B6"U3<&%M+5-C;W)E(BDL
M"B`@("`G='EP92<@/3X@24Y'3U]35$]204=%7U194$5?2$5!1$52"B`@*2P*
M("`G6"U3<&%M+5-T871U<R<@/3X@87)R87DH"B`@("`G;&%B96PG(#T^(%\H
M(E@M4W!A;2U3=&%T=7,B*2P*("`@("=T>7!E)R`]/B!)3D=/7U-43U)!1T5?
M5%E015](14%$15(*("`I+`H@("=8+5!R:6]R:71Y)R`]/B!A<G)A>2@*("`@
M("=L86)E;"<@/3X@7R@B6"U0<FEO<FET>2(I+`H@("`@)W1Y<&4G(#T^($E.
M1T]?4U1/4D%'15]465!%7TA%041%4@H@("DL"B`@)U-I>F4G(#T^(&%R<F%Y
M*`H@("`@)VQA8F5L)R`]/B!?*")3:7IE(BDL"B`@("`G='EP92<@/3X@24Y'
M3U]35$]204=%7U194$5?4TE:12P*("`@("=T97-T<R<@/3X@87)R87DH)V=R
M96%T97(@=&AA;B<L("=L97-S('1H86XG*0H@("DL"B`@)T)O9'DG(#T^(&%R
M<F%Y*`H@("`@)VQA8F5L)R`]/B!?*")";V1Y(BDL"B`@("`G='EP92<@/3X@
M24Y'3U]35$]204=%7U194$5?0D]$60H@("D**3L*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]I;F=O
M+W!R969S+G!H<```````````````````````````````````````````````
M````````````````````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#4W,S8`,3`T,3<S-C(W-#,`,#$W-S<P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&EN9V\O8V]N9FEG+W!R969S+G!H<"YD:7-T+'8@,2XS,"`R,#`T+S`T
M+S$U(#`R.C`Y.C4T(&UA>"!%>'`@)`H@*@H@*B!3964@:&]R9&4O8V]N9FEG
M+W!R969S+G!H<"!F;W(@9&]C=6UE;G1A=&EO;B!O;B!T:&4@<W1R=6-T=7)E
M(&]F('1H:7,@9FEL92X*("HO"@HO+R!-86ME('-U<F4@=&AA="!)3D=/7U-4
M3U)!1T5?*B!C;VYS=&%N=',@87)E(&1E9FEN960N"D!D969I;F4H)TE.1T]?
M0D%312<L("<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R<I.PIR97%U
M:7)E7V]N8V4@24Y'3U]"05-%("X@)R]L:6(O4W1O<F%G92YP:'`G.PH*+R\@
M5&AI<R!P<F5F97)E;F-E(&=R;W5P('=I;&P@;VYL>2!B92!D:7-P;&%Y960@
M:68@=&AE(&-O;F9I9W5R960*+R\@26YG;U]38W)I<'0Z.B!D<FEV97(@8V%N
M(&-R96%T92!S8W)I<'0@9FEL97,N"FEF("@A:7-S970H)%]315-324].6R=I
M;F=O)UU;)W-C<FEP=%]G96YE<F%T92==*2!\?`H@("`@)%]315-324].6R=I
M;F=O)UU;)W-C<FEP=%]G96YE<F%T92==*2!["B`@("`D<')E9D=R;W5P<ULG
M<V-R:7!T)UT@/2!A<G)A>2@*("`@("`@("`G8V]L=6UN)R`]/B!?*")/=&AE
M<B!/<'1I;VYS(BDL"B`@("`@("`@)VQA8F5L)R`]/B!?*")38W)I<'0@57!D
M871I;F<B*2P*("`@("`@("`G9&5S8R<@/3X@7R@B3W!T:6]N<R!A8F]U="!S
M8W)I<'0@=7!D871I;F<N(BDL"B`@("`@("`@)VUE;6)E<G,G(#T^(&%R<F%Y
M*"=A=71O7W5P9&%T92<I*3L*?0H*"B\O(%1H92!F;VQL;W=I;F<@<')E9F5R
M96YC97,@87)E(&]N;'D@=7-E9"!F;W(@2&]R9&5?4V-R:7!T.CH@9')I=F5R
M<R!T:&%T"B\O('5S92!S8W)I<'1S"@HO+R!A=71O;6%T:6-A;&QY('5P9&%T
M92!T:&4@<V-R:7!T"B1?<')E9G-;)V%U=&]?=7!D871E)UT@/2!A<G)A>2@*
M("`@("=V86QU92<@/3X@,2P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*
M("`@("=D97-C)R`]/B!?*")!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R
M:7!T(&%F=&5R(&5A8V@@8VAA;F=E/R(I"BD["@HO+R!%3D0@<V-R:7!T('!R
M969E<F5N8V5S"@HO+R!4:&4@9F]L;&]W:6YG('!R969E<F5N8V5S(&%R92!O
M;FQY('5S960@9F]R($AO<F1E7U-C<FEP=#HZ(&1R:79E<G,@=&AA=`HO+R!C
M86X@9&\@;VXM9&5M86YD(&9I;'1E<FEN9PH*+R\@4VAO=R!D971A:6QE9"!F
M:6QT97(@<W1A='5S(&UE<W-A9V5S/PHO+R!A('9A;'5E(&]F(#`@/2!N;RP@
M,2`]('EE<PHD7W!R969S6R=S:&]W7V9I;'1E<E]M<V<G72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`Q+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G
M<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD[
M"@HO+R!/;FQY(&9I;'1E<B!;=6Y=<V5E;B!M97-S86=E<S\*+R\@5F%L=65S
M.B`P+"!)3D=/7U-43U)!1T5?1DE,5$527U5.4T5%3BP@24Y'3U]35$]204=%
M7T9)3%1%4E]3145."B1?<')E9G-;)V9I;'1E<E]S965N)UT@/2!A<G)A>2@*
M("`@("=V86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI
M.PH*+R\@14Y$(&]N+61E;6%N9"!F:6QT97)I;F<@<')E9F5R96YC97,*"B\O
M($EF($Y/5"!U<VEN9R!T:&4@)W!R969S)R!S=&]R86=E(&1R:79E<B`H<V5E
M(&-O;F8N<&AP*2P@>6]U(&-A;B!C;VUM96YT"B\O(&]U="!T:&4@8F5L;W<@
M96YT<FEE<RX*"B\O(&9I;'1E<B!R=6QE<PHD7W!R969S6R=R=6QE<R==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^("=A.C0Z>VDZ,#MA.C(Z>W,Z-#HB;F%M
M92([<SHY.B)7:&ET96QI<W0B.W,Z-CHB86-T:6]N(CMI.B<@+B!)3D=/7U-4
M3U)!1T5?04-424].7U=(251%3$E35"`N("<[?6DZ,3MA.C,Z>W,Z-#HB;F%M
M92([<SHX.B)686-A=&EO;B([<SHV.B)A8W1I;VXB.VDZ)R`N($E.1T]?4U1/
M4D%'15]!0U1)3TY?5D%#051)3TX@+B`G.W,Z-SHB9&ES86)L92([8CHQ.WUI
M.C([83HR.GMS.C0Z(FYA;64B.W,Z.3HB0FQA8VML:7-T(CMS.C8Z(F%C=&EO
M;B([:3HG("X@24Y'3U]35$]204=%7T%#5$E/3E]"3$%#2TQ)4U0@+B`G.WUI
M.C,[83HR.GMS.C0Z(FYA;64B.W,Z-SHB1F]R=V%R9"([<SHV.B)A8W1I;VXB
M.VDZ)R`N($E.1T]?4U1/4D%'15]!0U1)3TY?1D]25T%21"`N("<[?7TG+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*
M("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO+R!B;&%C:VQI<W0*)%]P
M<F5F<ULG8FQA8VML:7-T)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)V$Z
M,CI[<SHQ.B)A(CMA.C`Z>WUS.C$Z(F8B.W,Z,#HB(CM])RP*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP
M92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@=VAI=&5L:7-T"B1?<')E9G-;)W=H
M:71E;&ES="==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=A.C`Z>WTG+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*
M("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO+R!V86-A=&EO;@HD7W!R
M969S6R=V86-A=&EO;B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=A.C8Z
M>W,Z.3HB861D<F5S<V5S(CMA.C`Z>WUS.C0Z(F1A>7,B.VDZ-SMS.C@Z(F5X
M8VQU9&5S(CMA.C`Z>WUS.C$P.B)I9VYO<F5L:7-T(CMB.C$[<SHV.B)R96%S
M;VXB.W,Z,#HB(CMS.C<Z(G-U8FIE8W0B.W,Z,#HB(CM])RP*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP
M92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@9F]R=V%R9',*)%]P<F5F<ULG9F]R
M=V%R9"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=A.C(Z>W,Z,3HB82([
M83HP.GM]<SHQ.B)K(CMI.C`[?2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I
M="<**3L*`````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VEN9V\O8V]N9BYP:'``````````
M````````````````````````````````````````````````````````````
M```````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<R-``Q,#0Q
M-S,V,C<T,P`P,3<U-C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RH@0T].1DE'(%-405)4+B!$3R!.3U0@0TA!
M3D=%($%.651(24Y'($E.($]2($%&5$52(%1(25,@3$E.12X@*B\*+R\@)$AO
M<F1E.B!I;F=O+V-O;F9I9R]C;VYF+GAM;"QV(#$N,3,@,C`P-"\P,B\Q,2`Q
M.3HR-#HR,R!S;'5S87)Z($5X<"`D"B1C;VYF6R=M96YU)UU;)V%P<',G72`]
M(&%R<F%Y*"=I;7`G+"`G:6YG;R<L("=K<F]N;VQI=&@G+"`G='5R8F$G*3L*
M)&-O;F9;)W-T;W)A9V4G75LG9')I=F5R)UT@/2`G<')E9G,G.PHD8V]N9ELG
M<W1O<F%G92==6R=M87AB;&%C:VQI<W0G72`](#`["B1C;VYF6R=S=&]R86=E
M)UU;)VUA>'=H:71E;&ES="==(#T@,#L*)&-O;F9;)W)U;&5S)UU;)W5S97)H
M96%D97(G72`]('1R=64["B1C;VYF6R=R=6QE<R==6R=U<V5F;VQD97)A<&DG
M72`]('1R=64["B\J($-/3D9)1R!%3D0N($1/($Y/5"!#2$%.1T4@04Y95$A)
M3D<@24X@3U(@0D5&3U)%(%1(25,@3$E.12X@*B\*````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M971C+W!S82UH;W)D92]M;F5M;R\`````````````````````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`,#$V
M,S$Q`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VUN96UO+W!R969S+G!H
M<```````````````````````````````````````````````````````````
M```````````````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3$Q
M-@`Q,#0Q-S,V,C<T,P`P,C`Q,S<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@;6YE;6\O
M8V]N9FEG+W!R969S+G!H<"YD:7-T+'8@,2XR-"XR+C$@,C`P-2\Q,"\R,B`Q
M,3HT,CHQ-2!J86X@17AP("0*("H*("H@4V5E(&AO<F1E+V-O;F9I9R]P<F5F
M<RYP:'`@9F]R(&1O8W5M96YT871I;VX@;VX@=&AE('-T<G5C='5R92!O9B!T
M:&ES(&9I;&4N"B`J+PH*+R\@36%K92!S=7)E('1H870@8V]N<W1A;G1S(&%R
M92!D969I;F5D+@I`9&5F:6YE*"=-3D5-3U]"05-%)RP@)R]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]M;F5M;R<I.PIR97%U:7)E7V]N8V4@34Y%34]?0D%3
M12`N("<O;&EB+TUN96UO+G!H<"<["@HD<')E9D=R;W5P<ULG9&ES<&QA>2==
M(#T@87)R87DH"B`@("`G8V]L=6UN)R`]/B!?*")'96YE<F%L($]P=&EO;G,B
M*2P*("`@("=L86)E;"<@/3X@7R@B1&ES<&QA>2!/<'1I;VYS(BDL"B`@("`G
M9&5S8R<@/3X@7R@B0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P
M;&%Y(&]P=&EO;G,N(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)W-O<G1B
M>2<L("=S;W)T9&ER)RD**3L*"B1P<F5F1W)O=7!S6R=S:&%R92==(#T@87)R
M87DH"B`@("`G8V]L=6UN)R`]/B!?*")'96YE<F%L($]P=&EO;G,B*2P*("`@
M("=L86)E;"<@/3X@7R@B1&5F875L="!.;W1E<&%D(BDL"B`@("`G9&5S8R<@
M/3X@7R@B0VAO;W-E('EO=7(@9&5F875L="!.;W1E<&%D+B(I+`H@("`@)VUE
M;6)E<G,G(#T^(&%R<F%Y*"=N;W1E<&%D<V5L96-T)RD**3L*"B1P<F5F1W)O
M=7!S6R=D96QE=&EO;B==(#T@87)R87DH"B`@("`G8V]L=6UN)R`]/B!?*")'
M96YE<F%L($]P=&EO;G,B*2P*("`@("=L86)E;"<@/3X@7R@B1&5L971E($-O
M;F9I<FUA=&EO;B(I+`H@("`@)V1E<V,G(#T^(%\H(D1E;&5T92!B=71T;VX@
M8F5H879I;W5R(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)V1E;&5T95]O
M<'0G*0HI.PH*"B\O('5S97(@<')E9F5R<F5D('-O<G1I;F<@8V]L=6UN"B1?
M<')E9G-;)W-O<G1B>2==(#T@87)R87DH"B`@("`G=F%L=64G(#T^($U.14U/
M7U-/4E1?1$530RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E
M9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG
M(#T^(&%R<F%Y*$U.14U/7U-/4E1?1$530R`]/B!?*").;W1E(%1E>'0B*2P*
M("`@("`@("`@("`@("`@("`@("!-3D5-3U]33U)47T-!5$5'3U)9(#T^(%\H
M(DYO=&4@0V%T96=O<GDB*2DL"B`@("`G9&5S8R<@/3X@7R@B1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.B(I"BD["@HO+R!U<V5R('!R969E<G)E9"!S;W)T
M:6YG(&1I<F5C=&EO;@HD7W!R969S6R=S;W)T9&ER)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H
M87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N
M=6TG(#T^(&%R<F%Y*$U.14U/7U-/4E1?05-#14Y$(#T^(%\H(D%S8V5N9&EN
M9R(I+`H@("`@("`@("`@("`@("`@("`@($U.14U/7U-/4E1?1$530T5.1"`]
M/B!?*")$97-C96YD:6YG(BDI+`H@("`@)V1E<V,G(#T^(%\H(D1E9F%U;'0@
M<V]R=&EN9R!D:7)E8W1I;VXZ(BD**3L*"B\O('5S97(@;F]T92!C871E9V]R
M:65S"B1?<')E9G-;)VUE;6]?8V%T96=O<FEE<R==(#T@87)R87DH"B`@("`G
M=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO
M+R!C871E9V]R>2!H:6=H;&EG:'0@8V]L;W)S"B1?<')E9G-;)VUE;6]?8V]L
M;W)S)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D
M)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G
M(#T^("=I;7!L:6-I="<**3L*"B\O(&1E9F%U;'0@;F]T97!A9"!S96QE8W1I
M;VX@=VED9V5T"B1?<')E9G-;)VYO=&5P861S96QE8W0G72`](&%R<F%Y*"=T
M>7!E)R`]/B`G<W!E8VEA;"<I.PH*+R\@9&5F875L="!N;W1E<&%D"B\O(%-E
M="!L;V-K960@=&\@=')U92!I9B!Y;W4@9&]N)W0@=V%N="!U<V5R<R!T;R!H
M879E(&UU;'1I<&QE(&YO=&5P861S+@HD7W!R969S6R=D969A=6QT7VYO=&5P
M860G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!!=71H.CIG971!=71H*"D@
M/R!!=71H.CIG971!=71H*"D@.B`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I
M="<**3L*"B\O('-T;W)E('1H92!N;W1E<&%D<R!T;R!D:7!L87D*)%]P<F5F
M<ULG9&ES<&QA>5]N;W1E<&%D<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M("=A.C`Z>WTG+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO+R!P
M<F5F97)E;F-E(&9O<B!D96QE=&4@8V]N9FER;6%T:6]N(&1I86QO9RX*)%]P
M<F5F<ULG9&5L971E7V]P="==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#$L
M"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E
M+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B
M1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R:65S/R(I"BD[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+V5T8R]P<V$M:&]R9&4O;6YE;6\O8V]N9BYX;6P`````````````````````
M`````````````````````````````````````````````````````#`Q,#`T
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C$R`#$P-#$W,S8R-S0S`#`Q
M-S<U,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&UN96UO+V-O
M;F9I9R]C;VYF+GAM;"QV(#$N,3<@,C`P-"\Q,"\P,R`Q,SHP-SHS-R!S='5A
M<G0@17AP("0@+2T^"CQC;VYF:6=U<F%T:6]N/@H@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB<W1O<F%G92(^"B`@/&-O;F9I9VAE861E<CY3=&]R86=E(%-Y<W1E
M;2!3971T:6YG<SPO8V]N9FEG:&5A9&5R/@H*("`\8V]N9FEG<W=I=&-H(&YA
M;64](F1R:79E<B(@9&5S8STB5VAA="!S=&]R86=E(&1R:79E<B!S:&]U;&0@
M=V4@=7-E/R(^<W%L"B`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB4U%,(CX*
M("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@/&-O;F9I
M9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](G1A8FQE(B!D97-C/2)$871A8F%S92!T86)L92(^;6YE
M;6]?;65M;W,\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-Q;#X*("`@
M(#PO8V]N9FEG<V5C=&EO;CX*("`@/"]C87-E/@H*("`@/&-A<V4@;F%M93TB
M:V]L86(B(&1E<V,](DMO;&%B(B`O/@H*("`\+V-O;F9I9W-W:71C:#X*(#PO
M8V]N9FEG<V5C=&EO;CX*"B`\8V]N9FEG<V5C=&EO;B!N86UE/2)M96YU(CX*
M("`\8V]N9FEG:&5A9&5R/DUE;G4@<V5T=&EN9W,\+V-O;F9I9VAE861E<CX*
M("`\8V]N9FEG8F]O;&5A;B!N86UE/2)P<FEN="(@9&5S8STB4VAO=6QD('=E
M(&1I<W!L87D@82!0<FEN="!L:6YK(&EN('1H92!(;W)D92!A<'!L:6-A=&EO
M;B!M96YU<S\B/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@/&-O;F9I9V)O;VQE
M86X@;F%M93TB:6UP;W)T7V5X<&]R="(@9&5S8STB4VAO=6QD('=E(&1I<W!L
M87D@86X@26UP;W)T+T5X<&]R="!L:6YK(&EN('1H92!-;F5M;R!A<'!L:6-A
M=&EO;B!M96YU<S\B/G1R=64*("`\+V-O;F9I9V)O;VQE86X^"B`@/&-O;F9I
M9VUU;'1I96YU;2!N86UE/2)A<'!S(B!D97-C/2)396QE8W0@86YY(&%P<&QI
M8V%T:6]N<R!T:&%T('-H;W5L9"!B92!L:6YK960@:6X@36YE;6\G<R!M96YU
M(CX*("`@/'9A;'5E<SX*("`@(#QC;VYF:6=S<&5C:6%L(&YA;64](FQI<W0M
M:&]R9&4M87!P<R(@+SX*("`@/"]V86QU97,^"B`@/"]C;VYF:6=M=6QT:65N
M=6T^"B`\+V-O;F9I9W-E8W1I;VX^"CPO8V]N9FEG=7)A=&EO;CX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]M;F5M;R\N
M:'1A8V-E<W,`````````````````````````````````````````````````
M````````````````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,38`,3`T,3<S-C(W-#,`,#(P,#<W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$1E;GD@9G)O;2!A;&P*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O;6YE;6\O8V]N9BYP:'``````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S(P`#$P
M-#$W,S8R-S0S`#`Q-S<T,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*B!#3TY&24<@4U1!4E0N($1/($Y/5"!#
M2$%.1T4@04Y95$A)3D<@24X@3U(@049415(@5$A)4R!,24Y%+B`J+PHO+R`D
M2&]R9&4Z(&UN96UO+V-O;F9I9R]C;VYF+GAM;"QV(#$N,3<@,C`P-"\Q,"\P
M,R`Q,SHP-SHS-R!S='5A<G0@17AP("0*)&-O;F9;)W-T;W)A9V4G75LG<&%R
M86US)UU;)W1A8FQE)UT@/2`G;6YE;6]?;65M;W,G.PHD8V]N9ELG<W1O<F%G
M92==6R=P87)A;7,G75LG9')I=F5R8V]N9FEG)UT@/2`G:&]R9&4G.PHD8V]N
M9ELG<W1O<F%G92==6R=D<FEV97(G72`]("=S<6PG.PHD8V]N9ELG;65N=2==
M6R=P<FEN="==(#T@9F%L<V4["B1C;VYF6R=M96YU)UU;)VEM<&]R=%]E>'!O
M<G0G72`]('1R=64["B1C;VYF6R=M96YU)UU;)V%P<',G72`](&%R<F%Y*"=M
M;F5M;R<I.PHO*B!#3TY&24<@14Y$+B!$3R!.3U0@0TA!3D=%($%.651(24Y'
M($E.($]2($)%1D]212!42$E3($Q)3D4N("HO"@``````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]E=&,O<'-A+6AO<F1E+W!A<W-W9"\`````````````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P
M,38T-S<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O<&%S<W=D+V)A8VME
M;F1S+G!H<```````````````````````````````````````````````````
M`````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R
M-C,W`#$P-#$W,S8R-S0S`#`R,#<V-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!P87-S
M=V0O8V]N9FEG+V)A8VME;F1S+G!H<"YD:7-T+'8@,2XT,2`R,#`U+S`X+S(T
M(#`W.C$Q.C`U(&IA;B!%>'`@)`H@*@H@*B!4:&ES(&9I;&4@:7,@=VAE<F4@
M>6]U('-P96-I9GD@=VAA="!B86-K96YD<R!P96]P;&4@=7-E('1O(&-H86YG
M90H@*B!T:&5I<B!P87-S=V]R9',N(%1H97)E(&%R92!A(&YU;6)E<B!O9B!P
M<F]P97)T:65S('1H870@>6]U(&-A;B!S970*("H@9F]R(&5A8V@@8F%C:V5N
M9#H*("H*("H@;F%M93H@5&AI<R!I<R!T:&4@<&QA:6YT97AT+"!E;F=L:7-H
M(&YA;64@=&AA="!Y;W4@=V%N="!D:7-P;&%Y960*("H@("`@("`@=&\@<&5O
M<&QE(&EF('EO=2!A<F4@=7-I;F<@=&AE(&1R;W`@9&]W;B!S97)V97(@;&ES
M="X@($%L<V\*("H@("`@("`@9&ES<&QA>65D(&]N('1H92!M86EN('!A9V4@
M*&EN<'5T(&9O<FTI+@H@*@H@*B!P87-S=V]R9"!P;VQI8WDZ(%1H92!P87-S
M=V]R9"!P;VQI8VEE<R!F;W(@=&AI<R!B86-K96YD+B!9;W4@87)E(')E<W!O
M;G-I8FQE"B`J("`@("`@("`@("`@("`@("`@9F]R('1H92!S86YI='D@8VAE
M8VMS(&]F('1H97-E(&]P=&EO;G,N($]P=&EO;G,@87)E.@H@*B`@("`@("`@
M("`@("`@;6EN3&5N9W1H("`@36EN:6UU;2!L96YG=&@@;V8@=&AE('!A<W-W
M;W)D"B`J("`@("`@("`@("`@("!M87A,96YG=&@@("!-87AI;75M(&QE;F=T
M:"!O9B!T:&4@<&%S<W=O<F0*("H@("`@("`@("`@("`@(&UA>%-P86-E("`@
M($UA>&EM=6T@;G5M8F5R(&]F('=H:71E('-P86-E(&-H87)A8W1E<G,*("H*
M("H@("`@("`@("`@("`@("`@("!4:&4@9F]L;&]W:6YG(&%R92!T:&4@='EP
M97,@;V8@8VAA<F%C=&5R<R!R97%U:7)E9`H@*B`@("`@("`@("`@("`@("`@
M(&EN(&$@<&%S<W=O<F0N("!%:71H97(@<W!E8VEF:6,@8VAA<F%C=&5R<RP@
M8VAA<F%C=&5R"B`J("`@("`@("`@("`@("`@("`@8VQA<W-E<RP@;W(@8F]T
M:"!C86X@8F4@<F5Q=6ER960N("!3<&5C:69I8R!T>7!E<R!A<F4Z"B`J"B`J
M("`@("`@("`@("`@("!M:6Y5<'!E<B`@("!-:6YI;75M(&YU;6)E<B!O9B!U
M<'!E<F-A<V4@8VAA<F%C=&5R<PH@*B`@("`@("`@("`@("`@;6EN3&]W97(@
M("`@36EN:6UU;2!N=6UB97(@;V8@;&]W97)C87-E(&-H87)A8W1E<G,*("H@
M("`@("`@("`@("`@(&UI;DYU;65R:6,@($UI;FEM=6T@;G5M8F5R(&]F(&YU
M;65R:6,@8VAA<F%C=&5R<R`H,"TY*0H@*B`@("`@("`@("`@("`@;6EN06QP
M:&%.=6T@36EN:6UU;2!N=6UB97(@;V8@86QP:&%N=6UE<FEC(&-H87)A8W1E
M<G,*("H@("`@("`@("`@("`@(&UI;D%L<&AA("`@($UI;FEM=6T@;G5M8F5R
M(&]F(&%L<&AA8F5T:6,@8VAA<F%C=&5R<PH@*B`@("`@("`@("`@("`@;6EN
M4WEM8F]L("`@36EN:6UU;2!N=6UB97(@;V8@86QP:&%B971I8R!C:&%R86-T
M97)S"B`J"B`J("`@("`@("`@("`@("`@("`@06QT97)N871I=F5L>2`H;W(@
M:6X@861D:71I;VX@=&\I+"!T:&4@;6EN:6UU;2!N=6UB97(@;V8*("H@("`@
M("`@("`@("`@("`@("!C:&%R86-T97(@8VQA<W-E<R!C86X@8F4@8V]N9FEG
M=7)E9"!B>2!S971T:6YG('1H90H@*B`@("`@("`@("`@("`@("`@(&9O;&QO
M=VEN9RX@(%1H92!V86QI9"!R86YG92!I<R`P('1H<F]U9V@@-"!C:&%R86-T
M97(*("H@("`@("`@("`@("`@("`@("!C;&%S<V5S(&UA>2!B92!R97%U:7)E
M9"!F;W(@82!P87-S=V]R9"X@5&AE(&-L87-S97,@87)E.@H@*B`@("`@("`@
M("`@("`@("`@("=U<'!E<B<L("=L;W=E<B<L("=N=6UB97(G+"!A;F0@)W-Y
M;6)O;"<N("!&;W(@97AA;7!L93H*("H@("`@("`@("`@("`@("`@("!!('!A
M<W-W;W)D(&]F("=P0'-S=S!R9"<@<V%T:7-F:65S('1H<F5E(&-L87-S97,@
M*"=N=6UB97(G+`H@*B`@("`@("`@("`@("`@("`@("=L;W=E<B<L(&%N9"`G
M<WEM8F]L)RDL('=H:6QE("=P87-S=S!R9"<@;VYL>2!S871I<V9I97,*("H@
M("`@("`@("`@("`@("`@("!T=V\@8VQA<W-E<R`H)VQO=V5R)R!A;F0@)W-Y
M;6)O;',G*2X*("H*("H@("`@("`@("`@("`@(&UI;D-L87-S97,@($UI;FEM
M=6T@;G5M8F5R("@P('1H<F]U9V@@-"D@;V8@8VAA<F%C=&5R(&-L87-S97,N
M"B`J"B`J(&1R:79E<CH@("`@5&AE(%!A<W-W9"!D<FEV97(@=7-E9"!T;R!C
M:&%N9V4@=&AE('!A<W-W;W)D+B!686QI9`H@*B`@("`@("`@("`@(%9A;&ED
M('9A;'5E<R!A<F4@8W5R<F5N=&QY.@H@*B`@("`@("`@("`@("`@;&1A<"`@
M("`@("`@($-H86YG92!T:&4@<&%S<W=O<F0@;VX@82!L9&%P('-E<G9E<@H@
M*B`@("`@("`@("`@("`@<VUB;&1A<"`@("`@($-H86YG92!T:&4@<&%S<W=O
M<F0@;VX@82!L9&%P('-E<G9E<B!F;W(@8F]T:`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&QD87`@86YD('-A;6)A(&%U=&@*("H@("`@("`@("`@
M("`@('-Q;"`@("`@("`@("!#:&%N9V4@=&AE('!A<W-W;W)D(&9O<B!S<6P@
M875T:&5N=&EC871I;VX*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`H
M97AI;2P@<&%M7VUY<W%L+"!H;W)D92D*("H@("`@("`@("`@("`@('!O<'!A
M<W-D("`@("!#:&%N9V4@=&AE('!A<W-W;W)D('9I82!A('!O<'!A<W-D('-E
M<G9E<@H@*B`@("`@("`@("`@("`@<VUB<&%S<W=D("`@($-H86YG92!T:&4@
M<&%S<W=O<F0@=FEA('1H92!S;6)P87-S=V0@8V]M;6%N9`H@*B`@("`@("`@
M("`@("`@97AP96-T("`@("`@($-H86YG92!T:&4@<&%S<W=O<F0@=FEA(&%N
M(&5X<&5C="!S8W)I<'0*("H@("`@("`@("`@("`@('9M86EL;6=R("`@("!#
M:&%N9V4@=&AE('!A<W-W;W)D('9I82!A(&QO8V%L('9M86EL;6=R(&1A96UO
M;@H@*B`@("`@("`@("`@("`@=G!O<&UA:6P@("`@($-H86YG92!T:&4@<&%S
M<W=O<F0@9F]R('-Q;"!B87-E9"!V<&]P;6%I;`H@*B`@("`@("`@("`@("`@
M<V5R=G5F='`@("`@($-H86YG92!T:&4@<&%S<W=O<F0@=FEA(&$@<V5R=G5F
M='`@<V5R=F5R"B`J("`@("`@("`@("`@("!P:6YE("`@("`@("`@0VAA;F=E
M('1H92!P87-S=V]R9"!I;B!A(%!I;F4M96YC;V1E9"!F:6QE"B`J("`@("`@
M("`@("`@("!C;VUP;W-I=&4@("`@06QL;W=S('EO=2!T;R!C:&%I;B!M=6QT
M:7!L92!D<FEV97)S('1O9V5T:&5R"B`J"B`J(&YO7W)E<V5T.B`@1&\@;F]T
M(')E<V5T('1H92!A=71H96YT:6-A=&5D('5S97(G<R!C<F5D96YT:6%L<R!O
M;B!S=6-C97-S+@H@*@H@*B!P87)A;7,Z("`@($$@<&%R86US(&%R<F%Y(&-O
M;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@:6YF;W)M871I;VX@=&AA="!T:&4*
M("H@("`@("`@("`@("!087-S=V0@9')I=F5R(&YE961S+@H@*@H@*B`@("`@
M("`@("`@(%1H92!F;VQL;W=I;F<@:7,@82!L:7-T(&]F('-U<'!O<G1E9"!E
M;F-R>7!T:6]N+VAA<VAI;F<*("H@("`@("`@("`@("!M971H;V1S('-U<'!O
M<G1E9"!B>2!087-S=V0N"B`J"B`J("`@("`@("`@("`@,2D@<&QA:6X*("H@
M("`@("`@("`@("`R*2!C<GEP="!O<B!C<GEP="UD97,*("H@("`@("`@("`@
M("`S*2!C<GEP="UM9#4*("H@("`@("`@("`@("`T*2!C<GEP="UB;&]W9FES
M:`H@*B`@("`@("`@("`@(#4I(&UD-2UH97@*("H@("`@("`@("`@("`V*2!M
M9#4M8F%S938T"B`J("`@("`@("`@("`@-RD@<VUD-0H@*B`@("`@("`@("`@
M(#@I('-H80H@*B`@("`@("`@("`@(#DI('-S:&$*("H*("H@("`@("`@("`@
M("!#=7)R96YT;'DL(&UD-2UB87-E-C0L('-M9#4L('-H82P@86YD('-S:&$@
M<F5Q=6ER92!T:&4*("H@("`@("`@("`@("!M:&%S:"!P:'`@;&EB<F%R>2!I
M;B!O<F1E<B!T;R!W;W)K('!R;W!E<FQY+B`@4V5E('1H90H@*B`@("`@("`@
M("`@($E.4U1!3$P@9FEL92!F;W(@9&ER96-T:6]N<R!O;B!E;F%B;&EN9R!T
M:&ES+B`@;60U"B`J("`@("`@("`@("`@<&%S<W=O<F1S(&AA=F4@8V%U<V5D
M('-O;64@<')O8FQE;7,@:6X@=&AE('!A<W0@8F5C875S90H@*B`@("`@("`@
M("`@('1H97)E(&%R92!D:69F97)E;G0@9&5F:6YI=&EO;G,@;V8@=VAA="!I
M<R!A(")M9#4*("H@("`@("`@("`@("!P87-S=V]R9"(N("!3>7-T96US(&EM
M<&QE;65N="!T:&5M(&EN(&$@9&EF9F5R96YT"B`J("`@("`@("`@("`@;6%N
M;F5R+B`@268@>6]U(&%R92!U<VEN9R!/<&5N3$1!4"!A<R!Y;W5R(&)A8VME
M;F0@;W(*("H@("`@("`@("`@("!H879E(&UI9W)A=&5D('EO=7(@<&%S<W=O
M<F1S(&9R;VT@>6]U<B!/4R!B87-E9"!P87-S=V0*("H@("`@("`@("`@("!F
M:6QE+"!Y;W4@=VEL;"!N965D('1O('5S92!T:&4@;60U+6)A<V4V-"!H87-H
M:6YG"B`J("`@("`@("`@("`@;65T:&]D+B`@268@>6]U(&%R92!U<VEN9R!A
M(%-13"!D871A8F%S92!O<B!U<V5D('1H92!02%`*("H@("`@("`@("`@("!M
M9#4H*2!M971H;V0@=&\@8W)E871E('EO=7(@<&%S<W=O<F1S+"!Y;W4@=VEL
M;"!N965D('1O"B`J("`@("`@("`@("`@=7-E('1H92!M9#4M:&5X(&AA<VAI
M;F<@;65T:&]D+@H@*@H@*B!P<F5F97)R960Z(%1H:7,@:7,@;VYL>2!U<V5F
M=6P@:68@>6]U('=A;G0@=&\@=7-E('1H92!S86UE"B`J("`@("`@("`@("`@
M8F%C:V5N9"YP:'`@9FEL92!F;W(@9&EF9F5R96YT(&UA8VAI;F5S.B!I9B!T
M:&4@2&]S=&YA;64*("H@("`@("`@("`@("!O9B!T:&4@4&%S<W=D($UA8VAI
M;F4@:7,@:61E;G1I8V%L('1O(&]N92!O9B!T:&]S92!I;@H@*B`@("`@("`@
M("`@('1H92!P<F5F97)R960@;&ES="P@=&AE;B!T:&4@8V]R<F5S<&]N9&EN
M9R!O<'1I;VX@:6X@=&AE"B`J("`@("`@("`@("`@<V5L96-T(&)O>"!W:6QL
M(&EN8VQU9&4@4T5,14-4140L(&DN92X@:70@:7,@<V5L96-T960*("H@("`@
M("`@("`@("!P97(@9&5F875L="X@3W1H97)W:7-E('1H92!F:7)S="!E;G1R
M>2!I;B!T:&4@;&ES="!I<PH@*B`@("`@("`@("`@('-E;&5C=&5D+@H@*@H@
M*B!S:&]W7V5N8W)Y<'1I;VXZ($EF('EO=2!A<F4@=7-I;F<@=&AE('-Q;"!O
M<B!T:&4@=G!O<&UA:6P@8F%C:V5N9`H@*B`@("`@("`@("`@("`@("`@('EO
M=2!H879E('1H92!C:&]I8V4@=VAE=&AE<B!O<B!N;W0@=&\@<W1O<F4@=&AE
M"B`J("`@("`@("`@("`@("`@("`@96YC<GEP=&EO;B!T>7!E('=I=&@@=&AE
M('!A<W-W;W)D+B!)9B!Y;W4@87)E"B`J("`@("`@("`@("`@("`@("`@=7-I
M;F<@9F]R(&5X86UP;&4@86X@4U%,(&)A<V5D(%!!32!Y;W4@=VEL;"!M;W-T
M"B`J("`@("`@("`@("`@("`@("`@;&EK96QY(&YO="!W86YT('1O('-T;W)E
M('1H92!E;F-R>7!T:6]N('1Y<&4@87,@:70*("H@("`@("`@("`@("`@("`@
M("!W;W5L9"!C875S92!004T@=&\@;F5V97(@;6%T8V@@=&AE('!A<W-W;W)D
M<RX*("H*("HO"@HD8F%C:V5N9'-;)W!O<'!A<W-D)UT@/2!A<G)A>2@*("`@
M("=N86UE)R`]/B`G4&]P<&%S<V0@4V5R=F5R)RP*("`@("=P<F5F97)R960G
M(#T^("<G+`H@("`@)W!A<W-W;W)D('!O;&EC>2<@/3X@87)R87DH*2P*("`@
M("=D<FEV97(G(#T^("=P;W!P87-S9"<L"B`@("`G<&%R86US)R`]/B!A<G)A
M>2@*("`@("`@("`G:&]S="<@/3X@)VQO8V%L:&]S="<L"B`@("`@("`@)W!O
M<G0G(#T^(#$P-@H@("`@*0HI.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+V5T
M8R]P<V$M:&]R9&4O<&%S<W=D+V-O;F8N>&UL````````````````````````
M`````````````````````````````````````````````````#`Q,#`T-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S(W`#$P-#$W,S8R-S0S`#`R,#$U
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z('!A<W-W9"]C;VYF
M:6<O8V]N9BYX;6PL=B`Q+C$R(#(P,#4O,3`O,#D@,30Z-#@Z-3@@:F%N($5X
M<"`D("TM/@H\8V]N9FEG=7)A=&EO;CX*(#QC;VYF:6=S96-T:6]N(&YA;64]
M(FUE;G4B(&1E<V,](DUE;G4@<V5T=&EN9W,B/@H@(#QC;VYF:6=H96%D97(^
M365N=2!S971T:6YG<SPO8V]N9FEG:&5A9&5R/@H@(#QC;VYF:6=M=6QT:65N
M=6T@;F%M93TB87!P<R(@9&5S8STB4V5L96-T(&%N>2!A<'!L:6-A=&EO;G,@
M=&AA="!S:&]U;&0@8F4*("!L:6YK960@:6X@4&%S<W=D)W,@;65N=2(^"B`@
M(#QV86QU97,^"B`@("`\8V]N9FEG<W!E8VEA;"!N86UE/2)L:7-T+6AO<F1E
M+6%P<',B("\^"B`@(#PO=F%L=65S/@H@(#PO8V]N9FEG;75L=&EE;G5M/@H@
M/"]C;VYF:6=S96-T:6]N/@H*(#QC;VYF:6=S96-T:6]N(&YA;64](F)A8VME
M;F0B/@H@(#QC;VYF:6=H96%D97(^0F%C:V5N9"!3971T:6YG<SPO8V]N9FEG
M:&5A9&5R/@H@(#QC;VYF:6=E;G5M(&YA;64](F)A8VME;F1?;&ES="(@9&5S
M8STB4VAO=6QD('=E(&1I<W!L87D@82!L:7-T(&]F(&)A8VME;F1S"B`@*&1E
M9FEN960@:6X@8V]N9FEG+V)A8VME;F1S+G!H<"D@9F]R('5S97)S('1O(&-H
M;V]S92!F<F]M/R!4:&4@;W!T:6]N<R!A<F4*("`G<VAO=VXG+"`G:&ED9&5N
M)RX@268@=&AE(&)A8VME;F0@;&ES="!I<R!H:61D96X@=&AE;B!Y;W4@8V%N
M('5S92!T:&4*("`G<')E9F5R<F5D)R!M96-H86YI<VT@=&\@875T;RUS96QE
M8W0@9G)O;2!I="!B87-E9"!O;B!A;B!(5%10('9I<G1U86QH;W-T(&]R"B`@
M86YO=&AE<B!P:65C92!O9B!D871A+B!)9B!I="!I<R!S:&]W;BP@=&AE('5S
M97(@=VEL;"!B92!A8FQE('1O('!I8VL@9G)O;0H@(&%N>2!O9B!T:&4@;W!T
M:6]N<RXB/FAI9&1E;B`*("`@/'9A;'5E<SX*("`@(#QV86QU93YS:&]W;CPO
M=F%L=64^"B`@("`\=F%L=64^:&ED9&5N/"]V86QU93X*("`@/"]V86QU97,^
M"B`@/"]C;VYF:6=E;G5M/@H@/"]C;VYF:6=S96-T:6]N/@H*(#QC;VYF:6=S
M96-T:6]N(&YA;64](G5S97(B/@H@(#QC;VYF:6=B;V]L96%N(&YA;64](F-H
M86YG92(@9&5S8STB4VAO=6QD('=E(&%L;&]W('1H92!U<V5R('1O('-P96-I
M9GD@=&AE"B`@=7-E<FYA;64_(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@(#QC
M;VYF:6=L:7-T(&YA;64](G)E9G5S960B(')E<75I<F5D/2)F86QS92(@9&5S
M8STB1&5F:6YE('5S97)N86UE<R!F;W(@=VAI8V@*("!W92!W:6QL(')E9G5S
M92!T;R!C:&%N9V4@<&%S<W=O<F1S+B(^"B`@<F]O="QB:6XL9&%E;6]N+&%D
M;2QL<"QS:'5T9&]W;BQH86QT+'5U8W`L9G1P+&%N;VYY;6]U<RQN;V)O9'DL
M:'1T<&0L;W!E<F%T;W(L9W5E<W0L9&EG:6YE>'0L8FEN9"QC>7)U<RQC;W5R
M:65R+&=A;65S+&MM96TL;6%I;&YU;&PL;6%N+&UY<W%L+&YE=W,L<&]S=&9I
M>"QS<VAD+'1T>2QW=W<*("`\+V-O;F9I9VQI<W0^"B`\+V-O;F9I9W-E8W1I
M;VX^"@H@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%S<W=O<F0B/@H@(#QC;VYF
M:6=B;V]L96%N(&YA;64](G-T<F5N9W1H=&5S=',B(&1E<V,](E-H;W5L9"!S
M=')E;F=T:"!T97-T<R!B92!D;VYE(&]N"B`@=&AE(&YE=R!P87-S=V]R9"(^
M9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`\+V-O;F9I9W-E8W1I;VX^"@H@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB:&]O:W,B/@H@(#QC;VYF:6=B;V]L96%N(&YA
M;64](F9U;&Q?;F%M92(@9&5S8STB268@=&AI<R!I<R!C:&5C:V5D+"!T:&4@
M9G5L;"!U<V5R(&YA;64*("!I<R!U<V5D('1O(&-H86YG92!T:&4@<&%S<W=O
M<F0L('1H92!U<V5R(&YA;64@=VET:&]U="!T:&4@9&]M86EN('!A<G0*("!O
M=&AE<G=I<V4N(%1H:7,@<V5T=&EN9R!I<R!O=F5R<FED9&5N(&)Y(&5N86)L
M:6YG('1H92!H;V]K"B`@8F5L;W<N(CYT<G5E/"]C;VYF:6=B;V]L96%N/@H@
M(#QC;VYF:6=B;V]L96%N(&YA;64](F1E9F%U;'1?=7-E<FYA;64B(&1E<V,]
M(E5S92!A(&-U<W1O;2!H;V]K(&9O<@H@(&1E=&5R;6EN:6YG('1H92!D969A
M=6QT('5S97)N86UE(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)U<V5R;F%M92(@9&5S8STB57-E(&$@8W5S=&]M(&AO
M;VL@=&\@=')A;G-L871E('1H90H@('5S97)N86UE(&9O<B!T:&4@8F%C:V5N
M9"(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@/&-O;F9I9V)O;VQE86X@;F%M
M93TB=7-E<F1N(B!D97-C/2))9B!W92!A<F4@=7-I;F<@=&AE($Q$05`@9')I
M=F5R+"!U<V4@80H@(&-U<W1O;2!H;V]K('1O('!R;W9I9&4@82!U<V5R9&X@
M9F]R(&)I;F1I;F<N($)Y(&1E9F%U;'0@=&AE($Q$05`@9')I=F5R"B`@9FEN
M9',@;W5T('1H92!C;W)R96-T('5S97)D;B!F;W(@8FEN9&EN9R!B>2!S96%R
M8VAI;F<@9F]R('1H92!U:60@=VET:"!T:&4*("!C;VYF:6=U<F5D(&)A<V4@
M;W(@8FEN9',@=VET:"!A9&UI;F1N(&EF('-E="XB/F9A;'-E/"]C;VYF:6=B
M;V]L96%N/@H@/"]C;VYF:6=S96-T:6]N/@H\+V-O;F9I9W5R871I;VX^"@``
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O<&%S<W=D+RYH=&%C8V5S<P``````
M````````````````````````````````````````````````````````````
M`````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#$V`#$P-#$W
M,S8R-S0S`#`R,#(V-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!$96YY(&9R;VT@86QL"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]E
M=&,O<'-A+6AO<F1E+W!A<W-W9"]C;VYF+G!H<```````````````````````
M```````````````````````````````````````````````````P,3`P-#0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,30T-``Q,#0Q-S,V,C<T,P`P,C`Q
M,S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@0T].1DE'(%-405)4+B!$3R!.3U0@0TA!3D=%($%.651(24Y'
M($E.($]2($%&5$52(%1(25,@3$E.12X@*B\*+R\@)$AO<F1E.B!P87-S=V0O
M8V]N9FEG+V-O;F8N>&UL+'8@,2XQ,B`R,#`U+S$P+S`Y(#$T.C0X.C4X(&IA
M;B!%>'`@)`HD8V]N9ELG;65N=2==6R=A<'!S)UT@/2!A<G)A>2@G:6UP)RD[
M"B1C;VYF6R=B86-K96YD)UU;)V)A8VME;F1?;&ES="==(#T@)VAI9&1E;B<[
M"B1C;VYF6R=U<V5R)UU;)V-H86YG92==(#T@9F%L<V4["B1C;VYF6R=U<V5R
M)UU;)W)E9G5S960G72`](&%R<F%Y*"=R;V]T)RP@)V)I;B<L("=D865M;VXG
M+"`G861M)RP@)VQP)RP@)W-H=71D;W=N)RP@)VAA;'0G+"`G=75C<"<L("=F
M='`G+"`G86YO;GEM;W5S)RP@)VYO8F]D>2<L("=H='1P9"<L("=O<&5R871O
M<B<L("=G=65S="<L("=D:6=I;F5X="<L("=B:6YD)RP@)V-Y<G5S)RP@)V-O
M=7)I97(G+"`G9V%M97,G+"`G:VUE;2<L("=M86EL;G5L;"<L("=M86XG+"`G
M;7ES<6PG+"`G;F5W<R<L("=P;W-T9FEX)RP@)W-S:&0G+"`G='1Y)RP@)W=W
M=R<I.PHD8V]N9ELG<&%S<W=O<F0G75LG<W1R96YG=&AT97-T<R==(#T@9F%L
M<V4["B1C;VYF6R=H;V]K<R==6R=F=6QL7VYA;64G72`]('1R=64["B1C;VYF
M6R=H;V]K<R==6R=D969A=6QT7W5S97)N86UE)UT@/2!F86QS93L*)&-O;F9;
M)VAO;VMS)UU;)W5S97)N86UE)UT@/2!F86QS93L*)&-O;F9;)VAO;VMS)UU;
M)W5S97)D;B==(#T@9F%L<V4["B\J($-/3D9)1R!%3D0N($1/($Y/5"!#2$%.
M1T4@04Y95$A)3D<@24X@3U(@0D5&3U)%(%1(25,@3$E.12X@*B\*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O````````````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q
M-@`P,30T,34`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R\`````````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S0S`#`Q-3`S-P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VIS+V%D9$5V96YT+G!H<```````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(V-#(`,3`T,3<S-C(W-#,`,#$W,S`S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"\J*@H@
M*B!'96YE<FEC(&9U;F-T:6]N('1O(&%D9"!A;B!E=F5N="!H86YD;&5R('1O
M(&%N>2!$3TT@96QE;65N="X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]A9&1%
M=F5N="YP:'`L=B`Q+C$N,BXR(#(P,#8O,#$O,#$@,C$Z,CDZ,#(@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J*@H@*B!!
M9&1S('1H92!G:79E;B!E=F5N="!T;R!A;B!E;&5M96YT+B!)9B!T:&4@96QE
M;65N="!A;')E861Y(&AA<PH@*B!H86YD;&5R<R!F;W(@=&AE(&5V96YT+"!T
M:&4@;F5W(&5V96YT(&ES(&%P<&5N9&5D+@H@*@H@*B!`<&%R86T@;V)J96-T
M(&5L96UE;G0@("!4:&4@96QE;65N="!T;R!A9&0@=&AE(&5V96YT('1O+@H@
M*B!`<&%R86T@<W1R:6YG(&5V96YT("`@("!4:&4@;F%M92!O9B!T:&4@979E
M;G0N"B`J($!P87)A;2!S=')I;F=\9G5N8W1I;VX@9G5N8W1I;VX@(%1H92!J
M879A<V-R:7!T('1O(&5X96-U=&4N"B`J+PIF=6YC=&EO;B!A9&1%=F5N="AE
M;&5M96YT+"!E=F5N="P@8V]D92D*>PH@("`@:68@*"%E;&5M96YT*2!["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O($%S<VEG;B!N97<@
M86YO;GEM;W5S(&9U;F-T:6]N(&EF('=E)W)E('!A<W-E9"!A(&IS('-T<FEN
M9PH@("`@+R\@:6YS=&5A9"!O9B!A(&9U;F-T:6]N(')E9F5R96YC92X*("`@
M(&EF("AT>7!E;V8@8V]D92`]/2`G<W1R:6YG)RD@>PH@("`@("`@(&-O9&4@
M/2!N97<@1G5N8W1I;VXH8V]D92D["B`@("!]"@H@("`@:68@*&5L96UE;G0N
M861D179E;G1,:7-T96YE<BD@>PH@("`@("`@(&5L96UE;G0N861D179E;G1,
M:7-T96YE<BAE=F5N="YR97!L86-E*"]O;B\L("<G*2P@8V]D92P@9F%L<V4I
M.PH@("`@?2!E;'-E(&EF("AE;&5M96YT+F%T=&%C:$5V96YT*2!["B`@("`@
M("`@96QE;65N="YA='1A8VA%=F5N="AE=F5N="P@8V]D92D["B`@("!](&5L
M<V4@:68@*&5L96UE;G0N;VYL;V%D("$](&YU;&PI('L*("`@("`@("!E=F%L
M*"=V87(@3VQD179E;G0@/2!E;&5M96YT+B<@*R!E=F5N="D["B`@("`@("`@
M;F5W0V]D92`]($9U;F-T:6]N*&4I"B`@("`@("`@>PH@("`@("`@("`@("!O
M;&1%=F5N="AE*3L*("`@("`@("`@("`@8V]D92@I.PH@("`@("`@('T["B`@
M("`@("`@979A;"@G96QE;65N="XG("L@979E;G0@*R`G(#T@;F5W0V]D92<I
M.PH@("`@?2!E;'-E('L*("`@("`@("!E=F%L*"=E;&5M96YT+B<@*R!E=F5N
M="`K("<@/2!C;V1E)RD["B`@("!]"@H@("`@<F5T=7)N('1R=64["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O86QP:&%);6%G94QO861E
M<BYP:'``````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<W
M-P`Q,#0Q-S,V,C<T,P`P,C`W-#$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M:G,O86QP:&%);6%G94QO861E<BYP:'`L=B`Q+C(N."XT(#(P,#8O,#$O,#$@
M,C$Z,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@
M0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O
M;&EB+V-O<F4N<&AP)SL*"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE
M=&]N*$A/4D1%7U-%4U-)3TY?3D].12D["@HO*B!4:&ES('-H;W5L9"!B92!C
M86-H960N("HO"B1M;V1?9VUT(#T@9VUD871E*"=$+"!D($T@62!(.FDZ<R<L
M(&9I;&5M=&EM92A?7T9)3$5?7RDI("X@)R!'350G.PIH96%D97(H)TQA<W0M
M36]D:69I960Z("<@+B`D;6]D7V=M="D["FAE861E<B@G0V%C:&4M0V]N=')O
M;#H@<'5B;&EC+"!M87@M86=E/3@V-#`P)RD["FAE861E<B@G0V]N=&5N="U4
M>7!E.B!T97AT+W@M8V]M<&]N96YT)RD["@H_/@H\<'5B;&EC.F-O;7!O;F5N
M=#X*/'!U8FQI8SIA='1A8V@@979E;G0](F]N<')O<&5R='EC:&%N9V4B(&9O
M<CTB96QE;65N="(@;VY%=F5N=#TB<')O<&5R='E#:&%N9V5D*"DB("\^"CQS
M8W)I<'0^"@IV87(@=')A;G-P87)E;G1);6%G92`]("(\/W!H<"!E8VAO("1R
M96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RD@/SXO8FQA;FLN9VEF(CL*
M"G!N9TAA8VLH*3L*"F9U;F-T:6]N('!R;W!E<G1Y0VAA;F=E9"@I"GL*("`@
M(&EF("AE=F5N="YP<F]P97)T>4YA;64@/3T@(G-R8R(I('L*("`@("`@("!P
M;F=(86-K*"D["B`@("!]"GT*"F9U;F-T:6]N('!N9TAA8VLH*0I["B`@("!V
M87(@=R`](&5L96UE;G0N=VED=&@["B`@("!V87(@:"`](&5L96UE;G0N:&5I
M9VAT.PH@("`@=F%R('-R8R`](&5L96UE;G0N<W)C.PH@("`@:68@*'-R8RYI
M;F1E>$]F*'1R86YS<&%R96YT26UA9V4I("$]("TQ*2!["B`@("`@("`@+R\@
M06QR96%D>2!F:7AE9"X*("`@("`@("!R971U<FX["B`@("!]"@H@("`@:68@
M*'-R8RYI;F1E>$]F*")P;F<B*2`]/2`M,2D@>PH@("`@("`@(&5L96UE;G0N
M<G5N=&EM95-T>6QE+F9I;'1E<B`]("(B.PH@("`@("`@(')E='5R;CL*("`@
M('T*"B`@("!E;&5M96YT+G-R8R`]('1R86YS<&%R96YT26UA9V4["B`@("!E
M;&5M96YT+G=I9'1H(#T@=SL*("`@(&5L96UE;G0N:&5I9VAT(#T@:#L*("`@
M(&5L96UE;G0N<G5N=&EM95-T>6QE+F9I;'1E<B`](")P<F]G:60Z1%A);6%G
M951R86YS9F]R;2Y-:6-R;W-O9G0N06QP:&%);6%G94QO861E<BAS<F,])R(@
M*R!S<F,@*R`B)RQS:7II;F=-971H;V0])W-C86QE)RDB.PI]"@H\+W-C<FEP
M=#X*/"]P=6)L:6,Z8V]M<&]N96YT/@H`+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]J<R]E;G1E<E]K97E?=')A<"YJ<P``````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S,W`#$P-#$W,S8R-S0S`#`R,#0Q-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH*
M("H@2F%V87-C<FEP="!T;R!T<F%P(&9O<B!T:&4@96YT97(@:V5Y+@H@*@H@
M*B`D2&]R9&4Z(&AO<F1E+VIS+V5N=&5R7VME>5]T<F%P+FIS+'8@,2XR+C$P
M+C(@,C`P-2\Q,"\Q."`Q,3HS,SHS."!J86X@17AP("0*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*9G5N8W1I;VX@96YT97)?:V5Y7W1R87`H92D*>PH@("`@=F%R(&4@
M/2!E('Q\('=I;F1O=RYE=F5N=#L*"B`@("!I9B`H92YK97E#;V1E*2!["B`@
M("`@("`@:V5Y(#T@92YK97E#;V1E.PH)?2!E;'-E(&EF("AE+G=H:6-H*2![
M"B`@("`@("`@:V5Y(#T@92YW:&EC:#L*("`@('T*"B`@("!R971U<FX@*&ME
M>2`]/2`Q,"!\?"!K97D@/3T@,3,I.PI]"@``````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O9F]R
M;5]A<W-I9VXN:G,`````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#$S,``Q,#0Q-S,V,C<T,P`P,3<V-S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RHJ"B`J($AO<F1E($9O
M<FT@07-S:6=N($9I96QD($IA=F%S8W)I<'0@0VQA<W,*("H*("H@4')O=FED
M97,@=&AE(&IA=F%S8W)I<'0@8VQA<W,@=&\@86-C;VUP86YY('1H92!(;W)D
M95]&;W)M(&%S<VEG;B!F:65L9"X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]F
M;W)M7V%S<VEG;BYJ<RQV(#$N,BXQ,"XT(#(P,#8O,#,O,C0@,#4Z,3<Z-3D@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*2&]R
M9&5?1F]R;5]!<W-I9VX@/2!N97<@3V)J96-T*"D["@I(;W)D95]&;W)M7T%S
M<VEG;BYD97-E;&5C=$AE861E<G,@/2!F=6YC=&EO;BAN86UE+"!S:61E*0I[
M"B`@("!I9B`H<VED92D@>PH@("`@("`@(&1O8W5M96YT6VYA;64@*R`G7U]R
M:6=H="==6S!=+G-E;&5C=&5D(#T@9F%L<V4["B`@("!](&5L<V4@>PH@("`@
M("`@(&1O8W5M96YT6VYA;64@*R`G7U]L969T)UU;,%TN<V5L96-T960@/2!F
M86QS93L*("`@('T*?0H*2&]R9&5?1F]R;5]!<W-I9VXN;6]V92`](&9U;F-T
M:6]N*&YA;64L(&1I<F5C=&EO;BD*>PH@("`@=F%R(&QE9G0@/2!D;V-U;65N
M=%MN86UE("L@)U]?;&5F="==.PH@("`@=F%R(')I9VAT(#T@9&]C=6UE;G1;
M;F%M92`K("=?7W)I9VAT)UT["@H@("`@:68@*&1I<F5C=&EO;BD@>PH@("`@
M("`@('9A<B!F<F]M(#T@<FEG:'0["B`@("`@("`@=F%R('1O(#T@;&5F=#L*
M("`@('T@96QS92!["B`@("`@("`@=F%R(&9R;VT@/2!L969T.PH@("`@("`@
M('9A<B!T;R`](')I9VAT.PH@("`@?0H*("`@(&9O<B`H=F%R(&D@/2`P.R!I
M(#P@9G)O;2YL96YG=&@[("LK:2D@>PH@("`@("`@(&EF("AF<F]M6VE=+G-E
M;&5C=&5D*2!["B`@("`@("`@("`@('1O6W1O+FQE;F=T:%T@/2!N97<@3W!T
M:6]N*&9R;VU;:5TN=&5X="P@9G)O;5MI72YV86QU92D["B`@("`@("`@("`@
M('1O6W1O+FQE;F=T:"`M(#%=+F]N9&)L8VQI8VL@/2!F=6YC=&EO;B@I"B`@
M("`@("`@("`@('L*("`@("`@("`@("`@("`@($AO<F1E7T9O<FU?07-S:6=N
M+FUO=F4H;F%M92P@,2`M(&1I<F5C=&EO;BD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@9G)O;5MI72`](&YU;&P["B`@("`@("`@("`@("TM:3L*("`@
M("`@("!]"B`@("!]"@H@("`@=&AI<RYS971&:65L9"AN86UE*3L*?0H*2&]R
M9&5?1F]R;5]!<W-I9VXN<V5T1FEE;&0@/2!F=6YC=&EO;BAN86UE*0I["B`@
M("!V87(@;&5F="`](&1O8W5M96YT6VYA;64@*R`G7U]L969T)UT["B`@("!V
M87(@<FEG:'0@/2!D;V-U;65N=%MN86UE("L@)U]?<FEG:'0G73L*"B`@("!V
M87(@=F%L=65S(#T@)R<["B`@("!V87(@:&ET(#T@9F%L<V4["B`@("!F;W(@
M*'9A<B!I(#T@,#L@:2`\(&QE9G0N;W!T:6]N<RYL96YG=&@[("LK:2D@>PH@
M("`@("`@(&EF("AI(#T](#`@)B8@(6QE9G1;:5TN=F%L=64I('L*("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@('9A;'5E<R`K/2!L
M969T+F]P=&EO;G-;:5TN=F%L=64@*R`G7'0G.PH@("`@("`@(&AI="`]('1R
M=64["B`@("!]"B`@("!I9B`H:&ET*2!["B`@("`@("`@=F%L=65S(#T@=F%L
M=65S+G-U8G-T<FEN9R@P+"!V86QU97,N;&5N9W1H("T@,2D["B`@("!]"B`@
M("!V86QU97,@*ST@)UQT7'0G.PH@("`@:&ET(#T@9F%L<V4["B`@("!F;W(@
M*'9A<B!I(#T@,#L@:2`\(')I9VAT+F]P=&EO;G,N;&5N9W1H.R`K*VDI('L*
M("`@("`@("!I9B`H:2`]/2`P("8F("%R:6=H=%MI72YV86QU92D@>PH@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@=F%L=65S("L]
M(')I9VAT+F]P=&EO;G-;:5TN=F%L=64@*R`G7'0G.PH@("`@("`@(&AI="`]
M('1R=64["B`@("!]"B`@("!I9B`H:&ET*2!["B`@("`@("`@=F%L=65S(#T@
M=F%L=65S+G-U8G-T<FEN9R@P+"!V86QU97,N;&5N9W1H("T@,2D["B`@("!]
M"B`@("!D;V-U;65N=%MN86UE("L@)U]?=F%L=65S)UTN=F%L=64@/2!V86QU
M97,["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:G,O9F]R;5]H96QP97)S+FIS````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,34U-``Q,#0Q-S,V,C<T,P`P,C`P-C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+RHJ
M"B`J($IA=F%S8W)I<'0@=&\@861D(&5V96YT<R!T;R!F;W)M(&5L96UE;G1S
M"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O9F]R;5]H96QP97)S+FIS+'8@,2XS
M+C0N-B`R,#`V+S`S+S(T(#`U.C$W.C4Y(&-H=6-K($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#8@36%T="!+>6YA<W1O;B`\;6%T=$!K>6YX+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*+RHJ"B`J($%D9',@=&AE(&=I=F5N(&5V
M96YT('1O(&%N(&5L96UE;G0N($EF('1H92!E;&5M96YT(&%L<F5A9'D@:&%S
M"B`J('-C<FEP="!F;W(@=&AE(&5V96YT+"!T:&4@;F5W(&5V96YT(&ES(&%P
M<&5N9&5D+@H@*@H@*B!`<&%R86T@;V)J96-T(&5L96UE;G0@("!4:&4@96QE
M;65N="!T;R!A9&0@=&AE(&5V96YT('1O+@H@*B!`<&%R86T@<W1R:6YG(&5V
M96YT("`@("!4:&4@;F%M92!O9B!T:&4@979E;G0N"B`J($!P87)A;2!S=')I
M;F=\9G5N8W1I;VX@9G5N8W1I;VX@(%1H92!J879A<V-R:7!T('1O(&5X96-U
M=&4N"B`J+PIF=6YC=&EO;B!A9&1%=F5N="AE;&5M96YT+"!E=F5N="P@8V]D
M92D*>PH@("`@:68@*"%E;&5M96YT*2!["B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\O($%S<VEG;B!N97<@86YO;GEM;W5S(&9U;F-T:6]N
M(&EF('=E)W)E('!A<W-E9"!A(&IS('-T<FEN9PH@("`@+R\@:6YS=&5A9"!O
M9B!A(&9U;F-T:6]N(')E9F5R96YC92X*("`@(&EF("AT>7!E;V8@8V]D92`]
M/2`G<W1R:6YG)RD@>PH@("`@("`@(&-O9&4@/2!N97<@1G5N8W1I;VXH8V]D
M92D["B`@("!]"@H@("`@:68@*&5L96UE;G0N861D179E;G1,:7-T96YE<BD@
M>PH@("`@("`@(&5L96UE;G0N861D179E;G1,:7-T96YE<BAE=F5N="YR97!L
M86-E*"]O;B\L("<G*2P@8V]D92P@9F%L<V4I.PH@("`@?2!E;'-E(&EF("AE
M;&5M96YT+F%T=&%C:$5V96YT*2!["B`@("`@("`@96QE;65N="YA='1A8VA%
M=F5N="AE=F5N="P@8V]D92D["B`@("!](&5L<V4@:68@*&5L96UE;G0N;VYL
M;V%D("$](&YU;&PI('L*("`@("`@("!V87(@3VQD179E;G0@/2!E;&5M96YT
M6V5V96YT73L*("`@("`@("!N97=#;V1E(#T@1G5N8W1I;VXH92D*("`@("`@
M("!["B`@("`@("`@("`@(&]L9$5V96YT*&4I.PH@("`@("`@("`@("!C;V1E
M*"D["B`@("`@("`@?3L*("`@("`@("!E;&5M96YT6V5V96YT72`](&YE=T-O
M9&4["B`@("!](&5L<V4@>PH@("`@("`@(&5L96UE;G1;979E;G1=(#T@8V]D
M93L*("`@('T*"B`@("!R971U<FX@=')U93L*?0H*+RHJ"B`J(%)E='5R;G,@
M9VEV96X@=F%L=64@87,@82!N=6UB97(L(&]R('IE<F\@:68@3F%.+@H@*@H@
M*B!`<&%R86T@;6EX960@('9A;`H@*@H@*B!`<F5T=7)N(&YU;6)E<@H@*B\*
M9G5N8W1I;VX@=&].=6UB97(H=F%L*0I["B`@("!I9B`H:7-.84XH=F%L*2D@
M>PH@("`@("`@(')E='5R;B`P.PH@("`@?2!E;'-E('L*("`@("`@("!R971U
M<FX@3G5M8F5R*'9A;"D["B`@("!]"GT*"B\J*@H@*B!3971S('1H92!E;F%B
M;&5D('-T871E(&]F(&]N92!E;&5M96YT(&)A<V5D(&]N('1H92!V86QU97,@
M;V8@86YO=&AE<BX*("H*("H@5&%K97,@9F]U<B!O<B!M;W)E(&%R9W5M96YT
M<RP@:6X@=&AE(&9O<FTZ"B`J("`@8VAE8VM%;F%B;&5D*'-O=7)C92P@=&%R
M9V5T+"!T<G5E+"!V86QU93$L('9A;'5E,BP@=F%L=64S+BXN*0H@*@H@*B!`
M<&%R86T@;V)J96-T("`@5&AE(&5L96UE;G0@=&\@8VAE8VL*("H@0'!A<F%M
M('-T<FEN9R`@(%1H92!E;&5M96YT('1O(&5N86)L92]D:7-A8FQE"B`J($!P
M87)A;2!B;V]L96%N("!7:&5T:&5R('1O(&5N86)L92!O<B!D:7-A8FQE('1H
M92!T87)G970*("H@0'!A<F%M(&UI>&5D("`@(%1H92!V86QU92!T;R!C:&5C
M:R!A9V%I;G-T"B`J+PIF=6YC=&EO;B!C:&5C:T5N86)L960H*0I["B`@("!I
M9B`H87)G=6UE;G1S+FQE;F=T:"`^(#(I('L*("`@("`@("!O8FI3<F,@/2!A
M<F=U;65N='-;,%T["B`@("`@("`@;V)J5&%R9V5T(#T@;V)J4W)C+F9O<FTN
M96QE;65N='-;87)G=6UE;G1S6S%=73L*("`@("`@("!E;F%B;&5D(#T@87)G
M=6UE;G1S6S)=.PH@("`@("`@('1O9V=L92`](&9A;'-E.PH@("`@("`@(&EF
M("AO8FI487)G970I('L*("`@("`@("`@("`@<W=I=&-H("AO8FI3<F,N='EP
M92YT;TQO=V5R0V%S92@I*2!["B`@("`@("`@("`@(&-A<V4@)W-E;&5C="UO
M;F4G(#H*("`@("`@("`@("`@("`@('9A;"`](&]B:E-R8RYO<'1I;VYS6V]B
M:E-R8RYS96QE8W1E9$EN9&5X72YV86QU93L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G<V5L96-T+6UU;'1I<&QE)R`Z"B`@
M("`@("`@("`@("`@("!V86P@/2!N97<@07)R87DH*3L*("`@("`@("`@("`@
M("`@(&-O=6YT(#T@,#L*("`@("`@("`@("`@("`@(&9O<B`H=F%R(&D@/2`P
M.R!I(#P@;V)J4W)C+FQE;F=T:#L@*RMI*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*&]B:E-R8RYO<'1I;VYS6VE=+G-E;&5C=&5D*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@('9A;%MC;W5N=%T@/2!O8FI3<F,N;W!T:6]N<UMI
M72YV86QU93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)V-H96-K8F]X)R`Z"B`@("`@("`@("`@("`@("!I9B`H;V)J4W)C+F-H96-K
M960I('L*("`@("`@("`@("`@("`@("`@("!V86P@/2!O8FI3<F,N=F%L=64[
M"B`@("`@("`@("`@("`@("`@("`@=&]G9VQE(#T@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M9&5F875L="`Z"B`@("`@("`@("`@("`@("!V86P@/2!O8FI3<F,N=F%L=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<B`H=F%R(&D@/2`S.R!I
M(#P@87)G=6UE;G1S+FQE;F=T:#L@*RMI*2!["B`@("`@("`@("`@("`@("!I
M9B`H='EP96]F*'9A;"D@/3T@)V]B:F5C="<@)B8@*&%R9W5M96YT<UMI72!I
M;B!V86PI*2!["B`@("`@("`@("`@("`@("`@("`@=&]G9VQE(#T@=')U93L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@
M96QS92!I9B`H87)G=6UE;G1S6VE=(#T]('9A;"D@>PH@("`@("`@("`@("`@
M("`@("`@('1O9V=L92`]('1R=64["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&]B:E1A<F=E="YD:7-A8FQE9"`]('1O9V=L92`_("%E;F%B;&5D(#H@
M96YA8FQE9#L*("`@("`@("`@("`@:68@*"%O8FI487)G970N9&ES86)L960I
M('L*("`@("`@("`@("`@("`@(&]B:E1A<F=E="YF;V-U<R@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0I]"@HO*BH*("H@4V5T<R!T:&4@=&%R
M9V5T(&9I96QD('1O('1H92!S=6T@;V8@82!R86YG92!O9B!F:65L9',N"B`J
M"B`J(%1A:V5S('1H<F5E(&]R(&UO<F4@87)G=6UE;G1S+"!I;B!T:&4@9F]R
M;3H*("H@("`@<W5M1FEE;&1S*&9O<FTL('1A<F=E="P@9FEE;&0Q+"!F:65L
M9#(L(&9I96QD,RXN+BD*("H*("H@0'!A<F%M(&]B:F5C="`@5&AE(&9O<FT@
M=&\@8VAE8VL*("H@0'!A<F%M('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE('1A
M<F=E="!E;&5M96YT"B`J($!P87)A;2!S=')I;F<@($]N92!O<B!M;W)E(&9I
M96QD(&YA;65S('1O('-U;0H@*B\*9G5N8W1I;VX@<W5M1FEE;&1S*"D*>PH@
M("`@:68@*&%R9W5M96YT<RYL96YG=&@@/B`R*2!["B`@("`@("`@;V)J1G)M
M(#T@87)G=6UE;G1S6S!=.PH@("`@("`@(&]B:E1A<F=E="`](&]B:D9R;2YE
M;&5M96YT<UMA<F=U;65N='-;,5U=.PH@("`@("`@('-U;2`](#`["B`@("`@
M("`@:68@*&]B:E1A<F=E="D@>PH@("`@("`@("`@("!F;W(@*'9A<B!I(#T@
M,CL@:2`\(&%R9W5M96YT<RYL96YG=&@[("LK:2D@>PH@("`@("`@("`@("`@
M("`@;V)J4W)C(#T@;V)J1G)M+F5L96UE;G1S6V%R9W5M96YT<UMI75T["B`@
M("`@("`@("`@("`@("!I9B`H;V)J4W)C*2!["B`@("`@("`@("`@("`@("`@
M("`@<W=I=&-H("AO8FI3<F,N='EP92YT;TQO=V5R0V%S92@I*2!["B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G<V5L96-T+6]N92<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@('-U;2`K/2!T;TYU;6)E<BAO8FI3<F,N;W!T:6]N<UMO
M8FI3<F,N<V5L96-T961);F1E>%TN=F%L=64I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<V5L
M96-T+6UU;'1I<&QE)R`Z"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H
M=F%R(&H@/2`P.R!J(#P@;V)J4W)C+FQE;F=T:#L@*RMJ*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=6T@*ST@=&].=6UB97(H;V)J4W)C+F]P
M=&EO;G-;:ETN=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M("`@("!C87-E("=C:&5C:V)O>"<@.@H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H;V)J4W)C+F-H96-K960I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-U;2`K/2!T;TYU;6)E<BAO8FI3<F,N=F%L=64I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@("`@("!D969A=6QT(#H*("`@("`@("`@
M("`@("`@("`@("`@("`@<W5M("L]('1O3G5M8F5R*&]B:E-R8RYV86QU92D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!O8FI487)G970N=F%L=64@/2!S=6T[
M"B`@("`@("`@?0H@("`@?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VIS+VAI9&5A8FQE+FIS````````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V,C<`,3`T,3<S-C(W-#,`
M,#$W,3,V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J*@H@*B!*879A<V-R:7!T(&]B:F5C="!F;W(@:&ED:6YG("8@<VAO
M=VEN9R!$3TT@96QE;65N=',N"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O:&ED
M96%B;&4N:G,L=B`Q+C(@,C`P-"\Q,"\Q.2`Q.3HP.#HU,R!C:'5C:R!%>'`@
M)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"@HO*BH*("H@0V]N<W1R=6-T;W(@9F]R($AO
M<F1E($AI9&5A8FQE($1/32!E;&5M96YT<RX*("H*("H@0'!A<F%M(&ED("`@
M("`@("`@("`@5&AE($1/32!I9"!O9B!T:&4@96QE;65N="!W92!W86YT('1O
M('=O<FL@=VET:"X*("H@0'!A<F%M(&1I<W!L87E3='EL92`@5VAA="!D:7-P
M;&%Y('-T>6QE('-H;W=S('1H:7,@96QE;65N=#\@1&5F875L=',*("H@("`@
M("`@("`@("`@("`@("`@("`@=&\@)V)L;V-K)RX*("HO"F9U;F-T:6]N($AO
M<F1E7TAI9&5A8FQE*"D*>PH@("`@=&AI<RYI9"`](&%R9W5M96YT<ULP73L*
M("`@('1H:7,N96QE;65N="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1H
M:7,N:60I.PH*("`@(&EF("AA<F=U;65N=',N;&5N9W1H(#T](#(I('L*("`@
M("`@("!T:&ES+F1I<W!L87E3='EL92`](&%R9W5M96YT<ULQ73L*("`@('T*
M?3L*"DAO<F1E7TAI9&5A8FQE+G!R;W1O='EP92`]('L*"B`@("`O*BH*("`@
M("`J($ED(&]F('1H92!$3TT@96QE;65N="X*("`@("`J($!V87(@:60*("`@
M("`J+PH@("`@:60Z(&YU;&PL"@H@("`@+RHJ"B`@("`@*B!$3TT@96QE;65N
M="!R969E<F5N8V4N"B`@("`@*B!`=F%R(&5L96UE;G0*("`@("`J+PH@("`@
M96QE;65N=#H@;G5L;"P*"B`@("`O*BH*("`@("`J(%1H92!D:7-P;&%Y('-T
M>6QE('1O('5S92X@1&5F875L="!I<R`G8FQO8VLG+@H@("`@("H@0'9A<B!D
M:7-P;&%Y4W1Y;&4*("`@("`J+PH@("`@9&ES<&QA>5-T>6QE.B`G8FQO8VLG
M+`H*("`@('-H;W=N.B!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N
M('1H:7,N96QE;65N="YS='EL92YD:7-P;&%Y("$]("=N;VYE)SL*("`@('TL
M"@H@("`@:&ED93H@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@('1H:7,N96QE
M;65N="YS='EL92YD:7-P;&%Y(#T@)VYO;F4G.PH@("`@("`@(')E='5R;B!T
M:&ES.PH@("`@?2P*"B`@("!S:&]W.B!F=6YC=&EO;B@I"B`@("!["B`@("`@
M("`@=&AI<RYE;&5M96YT+G-T>6QE+F1I<W!L87D@/2!T:&ES+F1I<W!L87E3
M='EL93L*("`@("`@("!R971U<FX@=&AI<SL*("`@('TL"@H@("`@=&]G9VQE
M.B!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N('1H:7,N<VAO=VXH
M*2`_('1H:7,N:&ED92@I(#H@=&AI<RYS:&]W*"D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O:&]R9&4N
M:64N:G,`````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,3(Q,``Q,#0Q-S,V,C<T,P`P,3<P-C$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J($=E;F5R86P@2&]R
M9&4@54D@969F96-T<R!J879A<V-R:7!T("T@9FEX97,@9F]R($E%('1H870@
M8V%N)W0*("H@96%S:6QY(&)E(&1O;F4@=VET:&]U="!B<F]W<V5R(&1E=&5C
M=&EO;BX*("H*("H@)$AO<F1E.B!H;W)D92]J<R]H;W)D92YI92YJ<RQV(#$N
M,2XR+C(@,C`P-B\P,2\R.2`Q,#HQ.#HR,"!C:'5C:R!%>'`@)`H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@I4;V]L5&EP<U]/<'1I;VY?5VEN9&]W961?0V]N=')O;',@
M/2`Q.PH*:68@*'1Y<&5O9B!!<G)A>2YP<F]T;W1Y<&4N<'5S:"`]/2`G=6YD
M969I;F5D)RD@>PH@("`@($%R<F%Y+G!R;W1O='EP92YP=7-H(#T@9G5N8W1I
M;VXH*2!["B`@("`@("`@('9A<B!L(#T@=&AI<RYL96YG=&@["B`@("`@("`@
M(&9O<B`H=F%R(&D@/2`P.R!I(#P@87)G=6UE;G1S+FQE;F=T:#L@:2LK*2![
M"B`@("`@("`@("`@("!T:&ES6VP@*R!I72`](&%R9W5M96YT<UMI73L*("`@
M("`@("`@?0H@("`@("`@("!R971U<FX@=&AI<RYL96YG=&@*("`@("!]"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O
M:&]R9&4N:G,`````````````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q-38U-``Q,#0Q-S,V,C<T,P`P,38U,#8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($=E;F5R
M86P@2&]R9&4@54D@969F96-T<R!J879A<V-R:7!T+@H@*@H@*B`D2&]R9&4Z
M(&AO<F1E+VIS+VAO<F1E+FIS+'8@,2XQ-"XR+C0@,C`P-B\P,B\Q-B`R,SHU
M,3HR,B!C:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IV87(@5&]O;%1I
M<',@/2!["B`@("!#55)214Y4.B!N=6QL+`H@("`@5$E-14]55#H@;G5L;"P*
M("`@($Q)3DLZ(&YU;&PL"@H@("`@871T86-H0F5H879I;W(Z(&9U;F-T:6]N
M*"D*("`@('L*("`@("`@("!L:6YK<R`](&1O8W5M96YT+F=E=$5L96UE;G1S
M0GE486=.86UE*"=A)RD["B`@("`@("`@9F]R("AI(#T@,#L@:2`\(&QI;FMS
M+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@(&EF("AL:6YK<UMI72YT:71L
M92D@>PH@("`@("`@("`@("`@("`@;&EN:W-;:5TN<V5T071T<FEB=71E*"=N
M:6-E=&ET;&4G+"!L:6YK<UMI72YT:71L92D["B`@("`@("`@("`@("`@("!L
M:6YK<UMI72YR96UO=F5!='1R:6)U=&4H)W1I=&QE)RD["@H@("`@("`@("`@
M("`@("`@861D179E;G0H;&EN:W-;:5TL("=M;W5S96]V97(G+"!4;V]L5&EP
M<RYO=F5R*3L*("`@("`@("`@("`@("`@(&%D9$5V96YT*&QI;FMS6VE=+"`G
M;6]U<V5O=70G+"!4;V]L5&EP<RYO=70I.PH@("`@("`@("`@("`@("`@861D
M179E;G0H;&EN:W-;:5TL("=F;V-U<R<L(%1O;VQ4:7!S+F]V97(I.PH@("`@
M("`@("`@("`@("`@861D179E;G0H;&EN:W-;:5TL("=B;'5R)RP@5&]O;%1I
M<',N;W5T*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('TL"@H@("`@
M;W9E<CH@9G5N8W1I;VXH92D*("`@('L*("`@("`@("!I9B`H='EP96]F(%1O
M;VQ4:7!S(#T]("=U;F1E9FEN960G*2!["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"@H@("`@("`@(&EF("A4;V]L5&EP<RY424U%3U54*2!["B`@
M("`@("`@("`@('=I;F1O=RYC;&5A<E1I;65O=70H5&]O;%1I<',N5$E-14]5
M5"D["B`@("`@("`@?0H*("`@("`@("!I9B`H=VEN9&]W+F5V96YT("8F('=I
M;F1O=RYE=F5N="YS<F-%;&5M96YT*2!["B`@("`@("`@("`@(%1O;VQ4:7!S
M+DQ)3DL@/2!W:6YD;W<N979E;G0N<W)C16QE;65N=#L*("`@("`@("!](&5L
M<V4@:68@*&4@)B8@92YT87)G970I('L*("`@("`@("`@("`@5&]O;%1I<',N
M3$E.2R`](&4N=&%R9V5T.PH@("`@("`@('T*"B`@("`@("`@5&]O;%1I<',N
M5$E-14]55"`]('=I;F1O=RYS9714:6UE;W5T*"=4;V]L5&EP<RYS:&]W*"DG
M+"`S,#`I"B`@("!]+`H*("`@(&]U=#H@9G5N8W1I;VXH*0H@("`@>PH@("`@
M("`@(&EF("AT>7!E;V8@5&]O;%1I<',@/3T@)W5N9&5F:6YE9"<I('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*%1O;VQ4
M:7!S+E1)345/550I('L*("`@("`@("`@("`@=VEN9&]W+F-L96%R5&EM96]U
M="A4;V]L5&EP<RY424U%3U54*3L*("`@("`@("!]"@H@("`@("`@(&EF("A4
M;V]L5&EP<RY#55)214Y4*2!["B`@("`@("`@("`@(&1O8W5M96YT+F=E=$5L
M96UE;G1S0GE486=.86UE*"=B;V1Y)RE;,%TN<F5M;W9E0VAI;&0H5&]O;%1I
M<',N0U524D5.5"D["B`@("`@("`@("`@(%1O;VQ4:7!S+D-54E)%3E0@/2!N
M=6QL.PH*("`@("`@("`@("`@=F%R(&EF<F%M92`](&1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*"=I9G)A;65?='0G*3L*("`@("`@("`@("`@:68@*&EF<F%M
M92`A/2!N=6QL*2!["B`@("`@("`@("`@("`@("!I9G)A;64N<W1Y;&4N9&ES
M<&QA>2`]("=N;VYE)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('TL
M"@H@("`@<VAO=SH@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@(&EF("AT>7!E
M;V8@5&]O;%1I<',@/3T@)W5N9&5F:6YE9"<@?'P@(51O;VQ4:7!S+DQ)3DLI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@
M*%1O;VQ4:7!S+D-54E)%3E0I('L*("`@("`@("`@("`@5&]O;%1I<',N;W5T
M*"D["B`@("`@("`@?0H*("`@("`@("!L:6YK(#T@5&]O;%1I<',N3$E.2SL*
M("`@("`@("!W:&EL92`H(6QI;FLN9V5T071T<FEB=71E*"=N:6-E=&ET;&4G
M*2`F)B!L:6YK+FYO9&5.86UE+G1O3&]W97)#87-E*"D@(3T@)V)O9'DG*2![
M"B`@("`@("`@("`@(&QI;FL@/2!L:6YK+G!A<F5N=$YO9&4["B`@("`@("`@
M?0H@("`@("`@(&YI8V5T:71L92`](&QI;FLN9V5T071T<FEB=71E*"=N:6-E
M=&ET;&4G*3L*("`@("`@("!I9B`H(6YI8V5T:71L92D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!D(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@G9&EV)RD["B`@("`@("`@9"YC;&%S<TYA;64@/2`G;FEC
M971I=&QE)SL*("`@("`@("!D+FEN;F5R2%1-3"`](&YI8V5T:71L93L*"B`@
M("`@("`@4U1$7U=)1%1((#T@,3`P.PH@("`@("`@($U!6%]724142"`](#8P
M,#L*("`@("`@("!I9B`H=VEN9&]W+FEN;F5R5VED=&@I('L*("`@("`@("`@
M("`@34%87U=)1%1((#T@36%T:"YM:6XH34%87U=)1%1(+"!W:6YD;W<N:6YN
M97)7:61T:"`M(#(P*3L*("`@("`@("!]"B`@("`@("`@:68@*&1O8W5M96YT
M+F)O9'D@)B8@9&]C=6UE;G0N8F]D>2YS8W)O;&Q7:61T:"D@>PH@("`@("`@
M("`@("!-05A?5TE$5$@@/2!-871H+FUI;BA-05A?5TE$5$@L(&1O8W5M96YT
M+F)O9'DN<V-R;VQL5VED=&@@+2`R,"D["B`@("`@("`@?0H*("`@("`@("!N
M:6-E=&ET;&5?;&5N9W1H(#T@,#L*("`@("`@("!L:6YE<R`](&YI8V5T:71L
M92YR97!L86-E*"\\8G(@/UPO/B]G+"`B7&XB*2YS<&QI="@B7&XB*3L*("`@
M("`@("!F;W(@*&D@/2`P.R!I(#P@;&EN97,N;&5N9W1H.R!I*RLI('L*("`@
M("`@("`@("`@;FEC971I=&QE7VQE;F=T:"`]($UA=&@N;6%X*&YI8V5T:71L
M95]L96YG=&@L(&QI;F5S6VE=+FQE;F=T:"D["B`@("`@("`@?0H*("`@("`@
M("!H7W!I>&5L<R`](&YI8V5T:71L95]L96YG=&@@*B`W.PH@("`@("`@('1?
M<&EX96QS(#T@;FEC971I=&QE7VQE;F=T:"`J(#$P.PH*("`@("`@("!I9B`H
M:%]P:7AE;',@/B!35$1?5TE$5$@I('L*("`@("`@("`@("`@=R`](&A?<&EX
M96QS.PH@("`@("`@('T@96QS92!I9B`H4U1$7U=)1%1((#X@=%]P:7AE;',I
M('L*("`@("`@("`@("`@=R`]('1?<&EX96QS.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@('<@/2!35$1?5TE$5$@["B`@("`@("`@?0H*("`@("`@
M("!M<&]S(#T@9FEN9%!O<RAL:6YK*3L*("`@("`@("!M>"`](&UP;W-;,%T[
M"B`@("`@("`@;7D@/2!M<&]S6S%=.PH*("`@("`@("!L969T(#T@;7@@*R`R
M,#L*("`@("`@("!I9B`H=VEN9&]W+FEN;F5R5VED=&@@)B8@*"AL969T("L@
M=RD@/B!W:6YD;W<N:6YN97)7:61T:"DI('L*("`@("`@("`@("`@;&5F="`]
M('=I;F1O=RYI;FYE<E=I9'1H("T@=R`M(#0P.PH@("`@("`@('T*("`@("`@
M("!I9B`H9&]C=6UE;G0N8F]D>2`F)B!D;V-U;65N="YB;V1Y+G-C<F]L;%=I
M9'1H("8F("@H;&5F="`K('<I(#X@9&]C=6UE;G0N8F]D>2YS8W)O;&Q7:61T
M:"DI('L*("`@("`@("`@("`@;&5F="`](&1O8W5M96YT+F)O9'DN<V-R;VQL
M5VED=&@@+2!W("T@,C4["B`@("`@("`@?0H*("`@("`@("!D+FED(#T@)W1O
M;VQ4:7`G.PH@("`@("`@(&0N<W1Y;&4N;&5F="`]($UA=&@N;6%X*&QE9G0L
M(#4I("L@)W!X)SL*("`@("`@("!D+G-T>6QE+G=I9'1H(#T@36%T:"YM:6XH
M=RP@34%87U=)1%1(*2`K("=P>"<["B`@("`@("`@9"YS='EL92YT;W`@/2`H
M;7D@*R`R,"D@*R`G<'@G.PH@("`@("`@(&0N<W1Y;&4N9&ES<&QA>2`](")B
M;&]C:R(["@H@("`@("`@('1R>2!["B`@("`@("`@("`@(&1O8W5M96YT+F=E
M=$5L96UE;G1S0GE486=.86UE*"=B;V1Y)RE;,%TN87!P96YD0VAI;&0H9"D[
M"B`@("`@("`@("`@(%1O;VQ4:7!S+D-54E)%3E0@/2!D.PH*("`@("`@("`@
M("`@:68@*'1Y<&5O9B!4;V]L5&EP<U]/<'1I;VY?5VEN9&]W961?0V]N=')O
M;',@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`@("`@("`@('9A<B!I9G)A
M;64@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G:69R86UE7W1T)RD["B`@
M("`@("`@("`@("`@("!I9B`H:69R86UE(#T](&YU;&PI('L*("`@("`@("`@
M("`@("`@("`@("!I9G)A;64@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"(\
M:69R86UE('-R8STG:F%V87-C<FEP=#IF86QS93LG(&YA;64])VEF<F%M95]T
M="<@:60])VEF<F%M95]T="<@<V-R;VQL:6YG/2=N;R<@9G)A;65B;W)D97(]
M)S`G('-T>6QE/2=P;W-I=&EO;CIA8G-O;'5T93L@=&]P.C!P>#L@;&5F=#HP
M<'@[(&1I<W!L87DZ;F]N93LG/CPO:69R86UE/B(I.PH@("`@("`@("`@("`@
M("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*"=B;V1Y)RE;
M,%TN87!P96YD0VAI;&0H:69R86UE*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&0N<W1Y;&4N>DEN9&5X(#T@,3`P.PH@("`@("`@("`@
M("`@("`@:69R86UE+G-T>6QE+G=I9'1H(#T@9"YS='EL92YW:61T:#L*("`@
M("`@("`@("`@("`@(&EF<F%M92YS='EL92YH96EG:'0@/2!D+F]F9G-E=$AE
M:6=H=#L*("`@("`@("`@("`@("`@(&EF<F%M92YS='EL92YT;W`@/2!D+G-T
M>6QE+G1O<#L*("`@("`@("`@("`@("`@(&EF<F%M92YS='EL92YL969T(#T@
M9"YS='EL92YL969T.PH@("`@("`@("`@("`@("`@:69R86UE+G-T>6QE+GI)
M;F1E>"`](&0N<W1Y;&4N>DEN9&5X("T@,3L*("`@("`@("`@("`@("`@(&EF
M<F%M92YS='EL92YP;W-I=&EO;B`](")A8G-O;'5T92(["B`@("`@("`@("`@
M("`@("!I9G)A;64N<W1Y;&4N9&ES<&QA>2`](")B;&]C:R(["B`@("`@("`@
M("`@('T*("`@("`@("!](&-A=&-H("AE*2!["B`@("`@("`@?0H@("`@?0H*
M?3L*"B\J*@H@*B!2971U<FX@=&AE(%MX+'E=('!O<VET:6]N(&]F(&%N(&]B
M:F5C="X*("HO"F9U;F-T:6]N(&9I;F10;W,H;V)J*0I["B`@("!I9B`H;V)J
M+F]F9G-E=%!A<F5N="D@>PH@("`@("`@(&9O<B`H<&]S6"`](#`L('!O<UD@
M/2`P.R!O8FHN;V9F<V5T4&%R96YT.R!O8FH@/2!O8FHN;V9F<V5T4&%R96YT
M*2!["B`@("`@("`@("`@('!O<U@@*ST@;V)J+F]F9G-E=$QE9G0["B`@("`@
M("`@("`@('!O<UD@*ST@;V)J+F]F9G-E=%1O<#L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N(%MP;W-8+"!P;W-973L*("`@('T@96QS92!["B`@("`@("`@
M<F5T=7)N(%MO8FHN>"P@;V)J+GE=.PH@("`@?0I]"@HO*BH*("H@061D(&%N
M(&5V96YT(&QI<W1E;F5R(&%S(&QO;F<@87,@=&AE(&)R;W=S97(@<W5P<&]R
M=',@:70N($1I9F9E<F5N=`H@*B!B<F]W<V5R<R!S=&EL;"!H86YD;&4@=&AE
M<V4@979E;G1S('-L:6=H=&QY(&1I9F9E<F5N=&QY.R!I;@H@*B!P87)T:6-U
M;&%R(&%V;VED('5S:6YG(")T:&ES(B!I;B!E=F5N="!F=6YC=&EO;G,N"B`J
M"B`J($!A=71H;W(@4V-O='0@06YD<F5W"B`J($!A=71H;W(@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J+PIF=6YC=&EO;B!A9&1%=F5N
M="AO8FHL(&5V5'EP92P@9FXI"GL*("`@(&EF("AO8FHN861D179E;G1,:7-T
M96YE<BD@>PH@("`@("`@(&]B:BYA9&1%=F5N=$QI<W1E;F5R*&5V5'EP92P@
M9FXL('1R=64I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2!E;'-E(&EF
M("AO8FHN871T86-H179E;G0I('L*("`@("`@("!V87(@<B`](&]B:BYA='1A
M8VA%=F5N="@G;VXG("L@9794>7!E+"!F;BD["B`@("`@("`@179E;G1#86-H
M92YA9&0H;V)J+"!E=E1Y<&4L(&9N*3L*("`@("`@("!R971U<FX@<CL*("`@
M('T@96QS92!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0I]"@IV87(@
M179E;G1#86-H92`](&9U;F-T:6]N*"D*>PH@("`@=F%R(&QI<W1%=F5N=',@
M/2!;73L*"B`@("!R971U<FX@>PH@("`@("`@(&QI<W1%=F5N=',Z(&QI<W1%
M=F5N=',L"@H@("`@("`@(&%D9#H@9G5N8W1I;VXH;F]D92P@<T5V96YT3F%M
M92P@9DAA;F1L97(L(&)#87!T=7)E*0H@("`@("`@('L*("`@("`@("`@("`@
M;&ES=$5V96YT<RYP=7-H*&%R9W5M96YT<RD["B`@("`@("`@?2P*"B`@("`@
M("`@9FQU<V@Z(&9U;F-T:6]N*"D*("`@("`@("!["B`@("`@("`@("`@('9A
M<B!I+"!I=&5M.PH@("`@("`@("`@("!F;W(@*&D@/2!L:7-T179E;G1S+FQE
M;F=T:"`M(#$[(&D@/CT@,#L@:2`](&D@+2`Q*2!["B`@("`@("`@("`@("`@
M("!I=&5M(#T@;&ES=$5V96YT<UMI73L*"B`@("`@("`@("`@("`@("!I9B`H
M:71E;5LP72YR96UO=F5%=F5N=$QI<W1E;F5R*2!["B`@("`@("`@("`@("`@
M("`@("`@:71E;5LP72YR96UO=F5%=F5N=$QI<W1E;F5R*&ET96U;,5TL(&ET
M96U;,ETL(&ET96U;,UTI.PH@("`@("`@("`@("`@("`@?3L*"B`@("`@("`@
M("`@("`@("`O*B!&<F]M('1H:7,@<&]I;G0@;VX@=V4@;F5E9"!T:&4@979E
M;G0@;F%M97,@=&\@8F4*("`@("`@("`@("`@("`@("`J('!R969I>&5D('=I
M=&@@)V]N)RX@*B\*("`@("`@("`@("`@("`@(&EF("AI=&5M6S%=+G-U8G-T
M<FEN9R@P+"`R*2`A/2`G;VXG*2!["B`@("`@("`@("`@("`@("`@("`@:71E
M;5LQ72`]("=O;B<@*R!I=&5M6S%=.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@(&EF("AI=&5M6S!=+F1E=&%C:$5V96YT*2!["B`@("`@
M("`@("`@("`@("`@("`@:71E;5LP72YD971A8VA%=F5N="AI=&5M6S%=+"!I
M=&5M6S)=*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I
M=&5M6S!=6VET96U;,5U=(#T@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T["GTH*3L*"FEF("AD;V-U;65N="YC<F5A=&5%;&5M96YT("8F
M(&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*2!["B`@("!A9&1%=F5N
M="AW:6YD;W<L("=L;V%D)RP@5&]O;%1I<',N871T86-H0F5H879I;W(I.PH@
M("`@861D179E;G0H=VEN9&]W+"`G=6YL;V%D)RP@5&]O;%1I<',N;W5T*3L*
M("`@(&%D9$5V96YT*'=I;F1O=RP@)W5N;&]A9"<L($5V96YT0V%C:&4N9FQU
M<V@I.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O:'1T<&-L:65N="YJ<P``
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3`W
M-@`Q,#0Q-S,V,C<T,P`P,3<U-34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+RHJ"B`J($IA=F%S8W)I<'0@;&EB<F%R>2!F
M;W(@=V]R:VEN9R!W:71H(%AM;$AT='!297%U97-T(&]B:F5C=',@86YD"B`J
M($AO<F1E+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VAT='!C;&EE;G0N:G,L
M=B`Q+C(N,3`N,R`R,#`U+S$P+S$X(#$Q.C,S.C,X(&IA;B!%>'`@)`H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@HO+R!#;VYS=')U8W1O<B!F;W(@9V5N97)I8R!(5%10
M(&-L:65N="X*9G5N8W1I;VX@2%144$-L:65N="@I('M].PH*+R\@061D(&UE
M=&AO9',@86YD('!R;W!E<G1I97,@87,@87)R87DN"DA45%!#;&EE;G0N<')O
M=&]T>7!E(#T@>PH@("`@=7)L.B!N=6QL+`H*("`@("\O($EN<W1A;F-E(&]F
M(%A-3$AT='!297%U97-T+@H@("`@<F5Q=65S=#H@;G5L;"P*"B`@("`O+R!5
M<V5D('1O(&UA:V4@<W5R92!M=6QT:7!L92!C86QL<R!A<F4@;F]T('!L86-E
M9"!W:71H('1H92!S86UE"B`@("`O+R!C;&EE;G0@;V)J96-T('=H:6QE(&%N
M;W1H97(@:6X@<')O9W)E<W,N"B`@("!C86QL26Y0<F]G<F5S<SH@9F%L<V4L
M"@H@("`@+R\@5&AE('5S97(@9&5F:6YE9"!H86YD;&5R("T@<V5E($UY2&%N
M9&QE<B!B96QO=RX*("`@('5S97)H86YD;&5R.B!N=6QL+`H*("`@(&EN:70Z
M(&9U;F-T:6]N*'5R;"D*("`@('L*("`@("`@("!T:&ES+G5R;"`]('5R;#L*
M"B`@("`@("`@=')Y('L*("`@("`@("`@("`@+R\@36]Z:6QL82P@4V%F87)I
M+@H@("`@("`@("`@("!T:&ES+G)E<75E<W0@/2!N97<@6$U,2'1T<%)E<75E
M<W0H*3L*("`@("`@("!](&-A=&-H("AE*2!["B`@("`@("`@("`@("\O($E%
M+@H@("`@("`@("`@("!V87(@35-834Q?6$U,2%144%]04D]'2413(#T@;F5W
M($%R<F%Y*`H@("`@("`@("`@("`@("`@(DU36$U,,BY834Q(5%10+C0N,"(L
M"B`@("`@("`@("`@("`@("`B35-834PR+EA-3$A45%`N,RXP(BP*("`@("`@
M("`@("`@("`@(")-4UA-3#(N6$U,2%144"(L"B`@("`@("`@("`@("`@("`B
M36EC<F]S;V9T+EA-3$A45%`B"B`@("`@("`@("`@("`@("`I.PH@("`@("`@
M("`@("!V87(@<W5C8V5S<R`](&9A;'-E.PH@("`@("`@("`@("!F;W(@*'9A
M<B!I(#T@,#L@:2`\($U36$U,7UA-3$A45%!?4%)/1TE$4RYL96YG=&@@)B8@
M(7-U8V-E<W,[(&DK*RD@>PH@("`@("`@("`@("`@("`@=')Y('L*("`@("`@
M("`@("`@("`@("`@("!T:&ES+G)E<75E<W0@/2!N97<@06-T:79E6$]B:F5C
M="A-4UA-3%]834Q(5%107U!23T=)1%-;:5TI.PH@("`@("`@("`@("`@("`@
M("`@('-U8V-E<W,@/2!T<G5E.PH@("`@("`@("`@("`@("`@?2!C871C:"`H
M92D@>WT*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(7-U8V-E<W,I
M('L*("`@("`@("`@("`@("`@('1H<F]W(")5;F%B;&4@=&\@8W)E871E(%A-
M3$AT='!297%U97-T+B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M+`H*("`@("\O($AA;F1L97(@87)G=6UE;G0@:7,@82!U<V5R(&1E9FEN960@
M;V)J96-T('1O(&)E(&-A;&QE9"X*("`@(&%S>6YC1T54.B!F=6YC=&EO;BAH
M86YD;&5R*0H@("`@>PH@("`@("`@("\O($1E9W)A9&4@;W(@<V]M92!S=6-H
M+@H@("`@("`@(&EF("@A=&AI<RYR97%U97-T*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!].PH*("`@("`@("`O+R!0<F5V96YT(&UU
M;'1I<&QE(&-A;&QS"B`@("`@("`@:68@*'1H:7,N8V%L;$EN4')O9W)E<W,I
M('L*("`@("`@("`@("`@=&AR;W<@(D-A;&P@:6X@<')O9W)E<W,B.PH@("`@
M("`@('T["@H@("`@("`@('1H:7,N8V%L;$EN4')O9W)E<W,@/2!T<G5E.PH*
M("`@("`@("!T:&ES+G5S97)H86YD;&5R(#T@:&%N9&QE<CL*"B`@("`@("`@
M+R\@3W!E;B!A;B!A<WEN8R!R97%U97-T("T@=&AI<F0@87)G=6UE;G0@;6%K
M97,@:70*("`@("`@("`O+R!A<WEN8VAR;VYO=7,N"B`@("`@("`@=&AI<RYR
M97%U97-T+F]P96XH)T=%5"<L('1H:7,N=7)L+"!T<G5E*3L*"B`@("`@("`@
M+R\@2&%V92!T;R!A<W-I9VX@(G1H:7,B('1O(&$@=F%R:6%B;&4N"B`@("`@
M("`@=F%R('-E;&8@/2!T:&ES.PH*("`@("`@("`O+R!!<W-I9VX@82!C;&]S
M=7)E('1O('1H92!O;G)E861Y<W1A=&5C:&%N9V4@8V%L;&)A8VLN"B`@("`@
M("`@=&AI<RYR97%U97-T+F]N<F5A9'ES=&%T96-H86YG92`](&9U;F-T:6]N
M*"D*("`@("`@("!["B`@("`@("`@("`@('-E;&8N<W1A=&5#:&%N9V5#86QL
M8F%C:RAS96QF*3L*("`@("`@("!]"@H@("`@("`@('1H:7,N<F5Q=65S="YS
M96YD*&YU;&PI.PH@("`@?2P*"B`@("!S=&%T94-H86YG94-A;&QB86-K.B!F
M=6YC=&EO;BAC;&EE;G0I"B`@("!["B`@("`@("`@<W=I=&-H("AC;&EE;G0N
M<F5Q=65S="YR96%D>5-T871E*2!["B`@("`@("`@("`@("\O(%)E<75E<W0@
M;F]T('EE="!M861E+@H@("`@("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@
M('1R>2!["B`@("`@("`@("`@("`@("!C;&EE;G0N=7-E<FAA;F1L97(N;VY)
M;FET*"D["B`@("`@("`@("`@('T@8V%T8V@@*&4I('L@+RH@2&%N9&QE<B!M
M971H;V0@;F]T(&1E9FEN960N("HO('T*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`O+R!#;VYT86-T(&5S=&%B;&ES:&5D('=I=&@@<V5R=F5R
M(&)U="!N;W1H:6YG(&1O=VYL;V%D960*("`@("`@("`@("`@+R\@>65T+@H@
M("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@('1R>2!["B`@("`@("`@
M("`@("`@("!S=&%T=7,@/2!C;&EE;G0N<F5Q=65S="YS=&%T=7,["B`@("`@
M("`@("`@("`@("`O+R!#:&5C:R!F;W(@2%144"!S=&%T=7,@,C`P+@H@("`@
M("`@("`@("`@("`@:68@*'-T871U<R`A/2`R,#`I('L*("`@("`@("`@("`@
M("`@("`@("!C;&EE;G0N=7-E<FAA;F1L97(N;VY%<G)O<B@*("`@("`@("`@
M("`@("`@("`@("`@("`@<W1A='5S+`H@("`@("`@("`@("`@("`@("`@("`@
M("!C;&EE;G0N<F5Q=65S="YS=&%T=7-497AT"B`@("`@("`@("`@("`@("`@
M("`@("`@("D["@H@("`@("`@("`@("`@("`@("`@("\O($%B;W)T('1H92!R
M97%U97-T+@H@("`@("`@("`@("`@("`@("`@(&-L:65N="YR97%U97-T+F%B
M;W)T*"D["@H@("`@("`@("`@("`@("`@("`@("\O($-A;&P@;F\@;&]N9V5R
M(&EN('!R;V=R97-S+@H@("`@("`@("`@("`@("`@("`@(&-L:65N="YC86QL
M26Y0<F]G<F5S<R`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&-A=&-H("AE*2!["B`@("`@("`@("`@("`@("`O*B!-4UA-3$A4
M5%`@,RYX*R!D;V5S;B=T('!O<'5L871E('-T871U<R!U;G1I;`H@("`@("`@
M("`@("`@("`@("H@<F5A9'E3=&%T92`T+B`J+PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@0V%L;&5D(&UU;'1I
M<&QE('1I;65S('=H:6QE(&1O=VYL;V%D(&ES(&EN('!R;V=R97-S+@H@("`@
M("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@("\O($YO=&EF>2!U<V5R(&AA
M;F1L97(@;V8@9&]W;FQO860@<')O9W)E<W,N"B`@("`@("`@("`@('1R>2![
M"B`@("`@("`@("`@("`@("`O+R!'970@=&AE('1O=&%L(&-O;G1E;G0@;&5N
M9W1H("AU<V5F=6P@=&\@=V]R:PH@("`@("`@("`@("`@("`@+R\@;W5T(&AO
M=R!M=6-H(&AA<R!B965N(&1O=VYL;V%D960I+@H@("`@("`@("`@("`@("`@
M=')Y('L*("`@("`@("`@("`@("`@("`@("!V87(@8V]N=&5N=$QE;F=T:"`]
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-L:65N="YR97%U97-T+F=E=%)E
M<W!O;G-E2&5A9&5R*")#;VYT96YT+4QE;F=T:"(I.PH@("`@("`@("`@("`@
M("`@?2!C871C:"`H92D@>PH@("`@("`@("`@("`@("`@("`@('9A<B!C;VYT
M96YT3&5N9W1H(#T@3F%..PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("\O($-A;&P@=&AE('!R;V=R97-S(&AA;F1L97(@=VET:"!W:&%T
M('=E)W9E(&=O="X*("`@("`@("`@("`@("`@(&-L:65N="YU<V5R:&%N9&QE
M<BYO;E!R;V=R97-S*`H@("`@("`@("`@("`@("`@("`@(&-L:65N="YR97%U
M97-T+G)E<W!O;G-E5&5X="P*("`@("`@("`@("`@("`@("`@("!C;VYT96YT
M3&5N9W1H"B`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@('T@
M8V%T8V@@*&4I('L@+RH@2&%N9&QE<B!M971H;V0@;F]T(&1E9FEN960N("HO
M('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!$;W=N;&]A
M9"!C;VUP;&5T92X*("`@("`@("`@("`@8V%S92`T.@H@("`@("`@("`@("!T
M<GD@>PH@("`@("`@("`@("`@("`@8VQI96YT+G5S97)H86YD;&5R+F]N3&]A
M9"AC;&EE;G0N<F5Q=65S="YR97-P;VYS951E>'0I.PH@("`@("`@("`@("!]
M(&-A=&-H("AE*2!["B`@("`@("`@("`@("`@("`O*B!(86YD;&5R(&UE=&AO
M9"!N;W0@9&5F:6YE9"X@*B\*("`@("`@("`@("`@?2!F:6YA;&QY('L*("`@
M("`@("`@("`@("`@("\O($-A;&P@;F\@;&]N9V5R(&EN('!R;V=R97-S+@H@
M("`@("`@("`@("`@("`@8VQI96YT+F-A;&Q);E!R;V=R97-S(#T@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+VEE17-C1W5A
M<F0N:G,`````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#,T-#$`,3`T,3<S-C(W-#,`,#$W-#`W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B!*879A<V-R:7!T(&-O
M9&4@9F]R(&%T=&%C:&EN9R!A;B!O;FME>61O=VX@;&ES=&5N97(@=&\@=&5X
M=&%R96$@86YD"B`J('1E>'0@:6YP=70@96QE;65N=',@=&\@<')E=F5N="!L
M;W-S(&]F(&1A=&$@=VAE;B!T:&4@=7-E<B!H:71S('1H90H@*B!%4T,@:V5Y
M+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VEE17-C1W5A<F0N:G,L=B`Q+C$N
M,BXS(#(P,#4O,3`O,3@@,3$Z,S,Z,S@@:F%N($5X<"`D"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"B\J(%1H:7,@8V]D92!I<R!O;FQY(')E;&5V86YT(&9O<B!)12X@
M5&AE<F5F;W)E('1R>2!N;W0@=&\@9&\@86YY=&AI;F<*("H@:68@=&AE('5S
M97(@:7-N)W0@=7-I;F<@244L(&5V96X@:68@=&AI<R!S8W)I<'0@:7,@:6YC
M;'5D960N(%1H:7,*("H@8VAE8VL@=VEL;"!C871C:"!S;VUE(&)R;W=S97)S
M('1H870@87)E(&YO="!)12!B=70@:61E;G1I9GD*("H@=&AE;7-E;'9E<R!A
M<R!)12X@2&]P969U;&QY(&EF('1H97D@<&%S<R!T:')O=6=H('1H97D@<W5P
M<&]R="!W:&%T"B`J($E%('-U<'!O<G1S+B`J+PII9B`H;F%V:6=A=&]R+F%P
M<%9E<G-I;VXN:6YD97A/9B@G35-)12<I("$]("TQ("8F(&1O8W5M96YT+F%L
M;"D@>PH@("`@+RH@5V4@9&\@979E<GET:&EN9R!O;FQO860@<V\@=&AA="!T
M:&4@96YT:7)E(&1O8W5M96YT(&ES('!R97-E;G0*("`@("`J(&)E9F]R92!W
M92!S=&%R="!S96%R8VAI;F<@:70N("HO"B`@("!W:6YD;W<N871T86-H179E
M;G0H)V]N;&]A9"<L(&=U87)D*3L*?0H*+RHJ"B`J($9I;F1S(&%L;"!T97AT
M(&EN<'5T<R`H:6YP=70@='EP93TB=&5X="(I(&%N9"!T97AT87)E82!T86=S
M+"!A;F0*("H@871T86-H97,@=&AE(&]N:V5Y9&]W;B!L:7-T96YE<B!T;R!T
M:&5M('1O(&%V;VED($530R!C;&5A<FEN9R!T:&4*("H@=&5X="X*("HO"F9U
M;F-T:6]N(&=U87)D*"D*>PH@("`@+RH@1FEN9',@86QL('1E>'1A<F5A<RX@
M*B\*("`@('9A<B!T97AT87)E87,@/2!D;V-U;65N="YA;&PN=&%G<R@G5$58
M5$%214$G*3L*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@=&5X=&%R96%S+FQE
M;F=T:#L@:2LK*2!["B`@("`@("`@=&5X=&%R96%S6VE=+F%T=&%C:$5V96YT
M*"=O;FME>61O=VXG+"!D:7-A8FQE17-C87!E*3L*("`@('T*"B`@("`O*B!&
M:6YD<R!?86QL7R`\:6YP=70^('1A9W,N("HO"B`@("!V87(@:6YP=71S(#T@
M9&]C=6UE;G0N86QL+G1A9W,H)TE.4%54)RD["B`@("!F;W(@*'9A<B!I(#T@
M,#L@:2`\(&EN<'5T<RYL96YG=&@[(&DK*RD@>PH@("`@("`@("\J($]N;'D@
M871T86-H('1O(#QI;G!U="!T>7!E/2)T97AT(CX@=&%G<RX@*B\*("`@("`@
M("!I9B`H:6YP=71S6VE=+G1Y<&4@/3T@)W1E>'0G*2!["B`@("`@("`@("`@
M(&EN<'5T<UMI72YA='1A8VA%=F5N="@G;VYK97ED;W=N)RP@9&ES86)L945S
M8V%P92D["B`@("`@("`@?0H@("`@?0I]"@HO*BH*("H@4F5T=7)N<R!F86QS
M92!I9B!T:&4@=7-E<B!H:70@=&AE($530R!K97DL('!R979E;G1I;F<@244@
M9G)O;0H@*B!B;&%N:VEN9R!T:&4@9FEE;&0N($]T:&5R=VES92!R971U<FYS
M('1R=64N"B`J"B`J(')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T
M;R!A;&QO=R!T:&4@:V5Y(&5V96YT+@H@*B\*9G5N8W1I;VX@9&ES86)L945S
M8V%P92@I"GL*("`@(')E='5R;B!W:6YD;W<N979E;G0N:V5Y0V]D92`A/2`R
M-SL*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]I;6%G92YJ<P``````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S
M-#0R`#$P-#$W,S8R-S0S`#`Q-C0U-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````O*BH*("H@2&]R9&4@26UA9V4@2F%V87-C
M<FEP=`H@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!T;R!H96QP(&1U
M<FEN9R!T:&4@=7!L;V%D:6YG(&]F(&EM86=E<R!I;B!(;W)D95]&;W)M+@H@
M*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VEM86=E+FIS+'8@,2XS+C0N,R`R,#`V
M+S`Q+S`Q(#(Q.C(Y.C`R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*B\*"B\J*@H@*B!#:&%N9V5S('1H92!S<F,@;V8@86X@:6UA9V4@
M=&%R9V5T+"!O<'1I;VYA;&QY(&%T=&%C:&EN9R!A('1I;64@=F%L=64@=&\@
M=&AE"B`J(%523"!T;R!M86ME('-U<F4@=&AA="!T:&4@:6UA9V4@9&]E<R!U
M<&1A=&4@86YD(&YO="!U<V4@=&AE(&)R;W=S97(@8V%C:&4N"B`J"B`J($!P
M87)A;2!S=')I;F<@<W)C("`@("`@("`@("`@("!4:&4@<W)O=6-E('1O(&EN
M<V5R=&5D(&EN=&\@=&AE(&EM86=E(&5L96UE;G0N"B`J($!P87)A;2!S=')I
M;F<@=&%R9V5T("`@("`@("`@("!4:&4@=&%R9V5T(&5L96UE;G0N"B`J($!P
M87)A;2!O<'1I;VYA;"!B;V]L(&YO7V-A8VAE("!)9B!S970@=&\@=')U92!W
M:6QL(&%P<&5N9"!T:&4@=&EM92X*("H*("H@0')E='5R;B!B;V]L("!&86QS
M92!T;R!S=&]P('1H92!B<F]W<V5R(&QO861I;F<@86YY=&AI;F<N"B`J+PIF
M=6YC=&EO;B!S:&]W26UA9V4H<W)C+"!T87)G970L(&YO7V-A8VAE*0I["B`@
M("!V87(@:6UG(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R9V5T*3L*
M("`@(&EF("AT>7!E;V8@;F]?8V%C:&4@/3T@)W5N9&5F:6YE9"<I('L*("`@
M("`@("!V87(@;F]?8V%C:&4@/2!F86QS93L*("`@('T*"B`@("!I9B`H;F]?
M8V%C:&4I('L*("`@("`@("!V87(@;F]W(#T@;F5W($1A=&4H*3L*("`@("`@
M("!S<F,@/2!S<F,@*R`G)B<@*R!N;W<N9V5T5&EM92@I.PH@("`@?0H*("`@
M(&EM9RYS<F,@/2!S<F,["@H@("`@<F5T=7)N(&9A;'-E.PI]"@HO*BH*("H@
M061D<R!T;R!T:&4@9VEV96X@<V]U<F-E('1H92!H96EG:'0O=VED=&@@9FEE
M;&0@=F%L=65S(&9O<B!T:&4@9VEV96X@=&%R9V5T+@H@*@H@*B!`<&%R86T@
M<W1R:6YG('-R8R`@("`@("`@("`@5&AE('-R;W5C92!T;R!A<'!E;F0@=&\@
M=&AE(')E<VEZ92!P87)A;7,N"B`J($!P87)A;2!S=')I;F<@=&%R9V5T("`@
M("`@("!4:&4@=&%R9V5T(&5L96UE;G0N"B`J($!P87)A;2!O<'1I;VYA;"!B
M;V]L(')A=&EO("!)9B!S970@=&\@=')U92!W:6QL(&%P<&5N9"!F:7@@=&AE
M(')A=&EO+@H@*@H@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('-O
M=7)C92!T;R!I;F-L=61E('1H92!R97-I>F4@9&%T82X*("HO"F9U;F-T:6]N
M(&=E=%)E<VEZ95-R8RAS<F,L('1A<F=E="P@<F%T:6\I"GL*("`@('9A<B!W
M:61T:"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=?=U\G("L@=&%R9V5T
M*2YV86QU93L*("`@('9A<B!H96EG:'0@/2!D;V-U;65N="YG971%;&5M96YT
M0GE)9"@G7VA?)R`K('1A<F=E="DN=F%L=64["B`@("!I9B`H='EP96]F(')A
M=&EO(#T]("=U;F1E9FEN960G*2!["B`@("`@("`@=F%R(')A=&EO(#T@,#L*
M("`@('T*"B`@("!S<F,@/2!S<F,@*R`G)B<@*R`G=CTG("L@=VED=&@@*R`G
M+B<@*R!H96EG:'0@*R`G+B<@*R!R871I;SL*"B`@("!R971U<FX@<W)C.PI]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O;W!E;E]C;VQO<G!I8VME<BYJ
M<P``````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-34U,``Q
M,#0Q-S,V,C<T,P`P,C`W,S0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RHJ"B`J($AO<F1E($-O;&]R<&EC:V5R($IA=F%3
M8W)I<'0N"B`J"B`J(%!R;W9I9&5S('1H92!J879A<V-R:7!T('1O(&-R96%T
M92!A(&-O;&]R<&EC:V5R+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+V]P96Y?
M8V]L;W)P:6-K97(N:G,L=B`Q+C(@,C`P-"\Q,"\Q.2`Q.3HP.#HU,R!C:'5C
M:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T
M"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!O<&5N0V]L;W)0
M:6-K97(H=&%R9V5T*0I["B`@("!V87(@;&%Y(#T@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)V-O;&]R<&EC:V5R7R<@*R!T87)G970I.PH@("`@:68@*&QA
M>2YS='EL92YD:7-P;&%Y(#T]("=B;&]C:R<I('L*("`@("`@("!L87DN<W1Y
M;&4N9&ES<&QA>2`]("=N;VYE)SL*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@:68@*&QA>2YF:7)S=$-H:6QD*2!["B`@("`@("`@:68@*&QA
M>2YF:7)S=$-H:6QD+FYO9&54>7!E(#T](#$I('L*("`@("`@("`@("`@;&%Y
M+G-T>6QE+F1I<W!L87D@/2`G8FQO8VLG.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!L
M87DN<F5M;W9E0VAI;&0H;&%Y+F9I<G-T0VAI;&0I.PH@("`@("`@('T*("`@
M('T*"B`@("!V87(@=&%B;&4@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=T
M86)L92<I.PH@("`@=F%R('1B;V1Y(#T@9&]C=6UE;G0N8W)E871E16QE;65N
M="@G=&)O9'DG*3L*("`@('1A8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*("`@
M('1A8FQE+F-E;&Q3<&%C:6YG(#T@,#L*("`@('1A8FQE+F)O<F1E<B`](#`[
M"B`@("!T86)L92YS='EL92YC=7)S;W(@/2`G8W)O<W-H86ER)SL*("`@('1A
M8FQE+F]N;6]U<V5O=70@/2!F=6YC=&EO;B@I('L*("`@("`@("!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G8V]L;W)D96UO7R<@*R!T87)G970I+G-T>6QE
M+F)A8VMG<F]U;F1#;VQO<B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A
M<F=E="DN=F%L=64["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\O(%1H92!P86QE='1E"B`@("!R(#T@,#L@9R`](#`[(&(@/2`P.PH@("`@
M9F]R("AB(#T@,#L@8B`\(#8[(&(K*RD@>PH@("`@("`@(')O=R`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H)W1R)RD["B`@("`@("`@8V]L;W(@/2!M86ME
M0V]L;W(H8B`J(#4Q+"!B("H@-3$L(&(@*B`U,2D["B`@("`@("`@8V5L;"`]
M(&UA:V5#96QL*'1A<F=E="P@8V]L;W(I.PH@("`@("`@(')O=RYA<'!E;F1#
M:&EL9"AC96QL*3L*("`@("`@("!F;W(@*&<@/2`P.R!G(#P@-CL@9RLK*2![
M"B`@("`@("`@("`@(&9O<B`H<B`](#`[('(@/"`V.R!R*RLI('L*("`@("`@
M("`@("`@("`@(&EF("AR("$](&(@)B8@8B`A/2!G*2!["B`@("`@("`@("`@
M("`@("`@("`@8V]L;W(@/2!M86ME0V]L;W(H<B`J(#4Q+"!G("H@-3$L(&(@
M*B`U,2D["B`@("`@("`@("`@("`@("`@("`@8V5L;"`](&UA:V5#96QL*'1A
M<F=E="P@8V]L;W(I.PH@("`@("`@("`@("`@("`@("`@(')O=RYA<'!E;F1#
M:&EL9"AC96QL*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH@("`@
M?0H*("`@('1A8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*("`@(&QA>2YA<'!E
M;F1#:&EL9"AT86)L92D["B`@("!L87DN<W1Y;&4N9&ES<&QA>2`]("=B;&]C
M:R<["GT*"F9U;F-T:6]N(&UA:V5#96QL*'1A<F=E="P@8V]L;W(I"GL*("`@
M(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=T9"<I.PH@("`@8V5L
M;"YH96EG:'0@/2`S.PH@("`@8V5L;"YW:61T:"`](#8["B`@("!C96QL+FED
M(#T@8V]L;W(["B`@("!C96QL+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`](&-O
M;&]R.PH@("`@8V5L;"YO;FUO=7-E;W9E<B`](&9U;F-T:6]N*"D@>PH@("`@
M("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=C;VQO<F1E;6]?)R`K('1A
M<F=E="DN<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@=&AI<RYS='EL92YB86-K
M9W)O=6YD0V]L;W(["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@
M8V5L;"YO;F-L:6-K(#T@9G5N8W1I;VXH*2!["B`@("`@("`@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)V-O;&]R9&5M;U\G("L@=&%R9V5T*2YS='EL92YB
M86-K9W)O=6YD0V]L;W(@/2!T:&ES+G-T>6QE+F)A8VMG<F]U;F1#;VQO<CL*
M("`@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"AT87)G970I+G9A;'5E
M(#T@=&AI<RYI9#L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M<F5T=7)N(&-E;&P["GT*"F9U;F-T:6]N(&UA:V5#;VQO<BAR+"!G+"!B*0I[
M"B`@("!C;VQO<B`]("(C(CL*("`@(&-O;&]R("L](&AE>"A-871H+F9L;V]R
M*'(@+R`Q-BDI.PH@("`@8V]L;W(@*ST@:&5X*'(@)2`Q-BD["B`@("!C;VQO
M<B`K/2!H97@H36%T:"YF;&]O<BAG("\@,38I*3L*("`@(&-O;&]R("L](&AE
M>"AG("4@,38I.PH@("`@8V]L;W(@*ST@:&5X*$UA=&@N9FQO;W(H8B`O(#$V
M*2D["B`@("!C;VQO<B`K/2!H97@H8B`E(#$V*3L*("`@(')E='5R;B!C;VQO
M<CL*?0H*9G5N8W1I;VX@:&5X*$1E8RD*>PH@("`@:68@*$1E8R`]/2`Q,"D@
M<F5T=7)N(")A(CL*("`@(&EF("A$96,@/3T@,3$I(')E='5R;B`B8B(["B`@
M("!I9B`H1&5C(#T](#$R*2!R971U<FX@(F,B.PH@("`@:68@*$1E8R`]/2`Q
M,RD@<F5T=7)N(")D(CL*("`@(&EF("A$96,@/3T@,30I(')E='5R;B`B92([
M"B`@("!I9B`H1&5C(#T](#$U*2!R971U<FX@(F8B.PH@("`@<F5T=7)N("(B
M("L@1&5C.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]J<R]P;W!U<"YJ<P``````````````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S4R`#$P-#$W,S8R-S0S`#`Q-C4T
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````O
M*BH*("H@2&]R9&4@4&]P=7`@2F%V85-C<FEP="X*("H*("H@4')O=FED97,@
M=&AE(&IA=F%S8W)I<'0@=&\@;W!E;B!P;W!U<"!W:6YD;W=S+@H@*@H@*B`D
M2&]R9&4Z(&AO<F1E+VIS+W!O<'5P+FIS+'8@,2XR+C$P+C0@,C`P-B\P,B\Q
M,"`Q.#HQ-#HU-"!C:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"F9U;F-T
M:6]N('!O<'5P*'5R;"P@=VED=&@L(&AE:6=H="D*>PH@("`@:68@*"%W:61T
M:"D@>PH@("`@("`@('=I9'1H(#T@-C`P.PH@("`@?0H@("`@:68@*"%H96EG
M:'0I('L*("`@("`@("!H96EG:'0@/2`U,#`["B`@("!]"@H@("`@=F%R(&YA
M;64@/2`H;F5W($1A=&4H*2DN9V5T5&EM92@I.PH@("`@=F%R('!A<F%M(#T@
M(G1O;VQB87(];F\L;&]C871I;VX];F\L<W1A='5S/7EE<RQS8W)O;&QB87)S
M/7EE<RQR97-I>F%B;&4]>65S+'=I9'1H/2(@*R!W:61T:"`K("(L:&5I9VAT
M/2(@*R!H96EG:'0@*R`B+&QE9G0],"QT;W`],"(["B`@("!V87(@=VEN(#T@
M=VEN9&]W+F]P96XH=7)L+"!N86UE+"!P87)A;2D["B`@("!I9B`H(7=I;BD@
M>PH@("`@("`@(&%L97)T*")!('!O<'5P('=I;F1O=R!C;W5L9"!N;W0@8F4@
M;W!E;F5D+B!9;W5R(&)R;W=S97(@;6%Y(&)E(&)L;V-K:6YG('!O<'5P<R!F
M;W(@=&AI<R!A<'!L:6-A=&EO;BXB*3L*("`@('T@96QS92!["B`@("`@("`@
M:68@*'1Y<&5O9B!W:6XN;F%M92`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@
M("`@("!W:6XN;F%M92`](&YA;64["B`@("`@("`@?0H@("`@("`@(&EF("AT
M>7!E;V8@=VEN+F]P96YE<B`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@("`@
M("!W:6XN;W!E;F5R(#T@<V5L9CL*("`@("`@("!]"B`@("!]"@H@("`@<F5T
M=7)N('=I;CL*?0H`````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]J<R]S;W)T97(N:G,`````````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-3,V`#$P-#$W,S8R-S0S
M`#`Q-C<R,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O*BH*("H@2&]R9&4@1F]R;2!3;W)T97(@1FEE;&0@2F%V87-C<FEP
M="!#;&%S<PH@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!C;&%S<R!T
M;R!A8V-O;7!A;GD@=&AE($AO<F1E7T9O<FT@<V]R=&5R"B`J(&9I96QD+@H@
M*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+W-O<G1E<BYJ<RQV(#$N,BXQ,"XS(#(P
M,#8O,#$O,#$@,C$Z,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*B\*"F9U;F-T:6]N($AO<F1E7T9O<FU?4V]R=&5R*&EN<W1A
M;F-E3F%M92P@=F%R3F%M92P@:&5A9&5R*0I["B`@("`O*B!3970@=7`@=&AI
M<R!C;&%S<R!I;G-T86YC92!F;W(@9G5N8W1I;VX@8V%L;',@9G)O;2!T:&4@
M<&%G92X@*B\*("`@('1H:7,N7VEN<W1A;F-E3F%M92`](&EN<W1A;F-E3F%M
M93L*"B`@("!T:&ES+E]V87).86UE(#T@=F%R3F%M93L*"B`@("`O*B!3;W)T
M97(@=F%R:6%B;&5S+B`J+PH@("`@=&AI<RY?:&5A9&5R(#T@)R<["B`@("!T
M:&ES+FUI;DQE;F=T:"`](#`["B`@("!I9B`H:&5A9&5R("$]("<G*2!["B`@
M("`@("`@=&AI<RY?:&5A9&5R(#T@:&5A9&5R.PH@("`@("`@('1H:7,N;6EN
M3&5N9W1H(#T@,3L*("`@('T*("`@('1H:7,N<V]R=&5R3&ES="`](&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*'1H:7,N7W9A<DYA;64@*R`G6VQI<W1=)RD[
M"B`@("!T:&ES+G-O<G1E<D%R<F%Y(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H=&AI<RY?=F%R3F%M92`K("=;87)R87E=)RD["@H@("`@=&AI<RYD97-E
M;&5C=$AE861E<B`](&9U;F-T:6]N*"D*("`@('L*("`@("`@("!I9B`H=&AI
M<RY?:&5A9&5R("$]("<G*2!["B`@("`@("`@("`@('1H:7,N<V]R=&5R3&ES
M=%LP72YS96QE8W1E9"`](&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("!T
M:&ES+G-E=$AI9&1E;B`](&9U;F-T:6]N*"D*("`@('L*("`@("`@("!V87(@
M=&UP07)R87D@/2!N97<@07)R87DH*3L*"B`@("`@("`@9F]R("AV87(@:2`]
M('1H:7,N;6EN3&5N9W1H.R!I(#P@=&AI<RYS;W)T97),:7-T+FQE;F=T:#L@
M:2LK*2!["B`@("`@("`@("`@(&EF("AT:&ES+G-O<G1E<DQI<W1;:5TN=F%L
M=64I('L*("`@("`@("`@("`@("`@('1M<$%R<F%Y6VD@+2!T:&ES+FUI;DQE
M;F=T:%T@/2!T:&ES+G-O<G1E<DQI<W1;:5TN=F%L=64["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@('1H:7,N<V]R=&5R07)R87DN=F%L=64@
M/2!T;7!!<G)A>2YJ;VEN*")<="(I.PH@("`@?0H*("`@('1H:7,N;6]V94-O
M;'5M;E5P(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@('9A<B!S96P@/2!T
M:&ES+G-O<G1E<DQI<W0N<V5L96-T961);F1E>#L*"B`@("`@("`@:68@*'-E
M;"`\/2!T:&ES+FUI;DQE;F=T:"!\?"!T:&ES+G-O<G1E<DQI<W0N;&5N9W1H
M(#P]('1H:7,N;6EN3&5N9W1H("L@,2D@<F5T=7)N.PH*("`@("`@("`O*B!$
M97-E;&5C="!E=F5R>71H:6YG(&)U="!T:&4@9FER<W0@<V5L96-T960@:71E
M;2X@*B\*("`@("`@("!T:&ES+G-O<G1E<DQI<W0N<V5L96-T961);F1E>"`]
M('-E;#L*("`@("`@("!V87(@=7`@/2!T:&ES+G-O<G1E<DQI<W1;<V5L72YV
M86QU93L*"B`@("`@("`@=&UP(#T@;F5W($%R<F%Y*"D["B`@("`@("`@9F]R
M("AI(#T@=&AI<RYM:6Y,96YG=&@[(&D@/"!T:&ES+G-O<G1E<DQI<W0N;&5N
M9W1H.R!I*RLI('L*("`@("`@("`@("`@=&UP6VD@+2!T:&ES+FUI;DQE;F=T
M:%T@/2!N97<@3W!T:6]N*'1H:7,N<V]R=&5R3&ES=%MI72YT97AT+"!T:&ES
M+G-O<G1E<DQI<W1;:5TN=F%L=64I"B`@("`@("`@?0H*("`@("`@("!F;W(@
M*&D@/2`P.R!I(#P@=&UP+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@(&EF
M("AI("L@=&AI<RYM:6Y,96YG=&@@/3T@<V5L("T@,2D@>PH@("`@("`@("`@
M("`@("`@=&AI<RYS;W)T97),:7-T6VD@*R!T:&ES+FUI;DQE;F=T:%T@/2!T
M;7!;:2`K(#%=.PH@("`@("`@("`@("!](&5L<V4@:68@*&D@*R!T:&ES+FUI
M;DQE;F=T:"`]/2!S96PI('L*("`@("`@("`@("`@("`@('1H:7,N<V]R=&5R
M3&ES=%MI("L@=&AI<RYM:6Y,96YG=&A=(#T@=&UP6VD@+2`Q73L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@('1H:7,N<V]R=&5R3&ES
M=%MI("L@=&AI<RYM:6Y,96YG=&A=(#T@=&UP6VE=.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!T:&ES+G-O<G1E<DQI<W0N<V5L96-T961)
M;F1E>"`]('-E;"`M(#$["@H@("`@("`@('1H:7,N<V5T2&ED9&5N*"D["B`@
M("!]"@H@("`@=&AI<RYM;W9E0V]L=6UN1&]W;B`](&9U;F-T:6]N*"D*("`@
M('L*("`@("`@("!V87(@<V5L(#T@=&AI<RYS;W)T97),:7-T+G-E;&5C=&5D
M26YD97@["@H@("`@("`@(&EF("AS96P@/3T@+3$@?'P@<V5L(#T]('1H:7,N
M<V]R=&5R3&ES="YL96YG=&@@+2`Q*2!R971U<FX["@H@("`@("`@("\J($1E
M<V5L96-T(&5V97)Y=&AI;F<@8G5T('1H92!F:7)S="!S96QE8W1E9"!I=&5M
M+B`J+PH@("`@("`@('1H:7,N<V]R=&5R3&ES="YS96QE8W1E9$EN9&5X(#T@
M<V5L.PH@("`@("`@('9A<B!D;W=N(#T@=&AI<RYS;W)T97),:7-T6W-E;%TN
M=F%L=64["@H@("`@("`@('1M<"`](&YE=R!!<G)A>2@I.PH@("`@("`@(&9O
M<B`H:2`]('1H:7,N;6EN3&5N9W1H.R!I(#P@=&AI<RYS;W)T97),:7-T+FQE
M;F=T:#L@:2LK*2!["B`@("`@("`@("`@('1M<%MI("T@=&AI<RYM:6Y,96YG
M=&A=(#T@;F5W($]P=&EO;BAT:&ES+G-O<G1E<DQI<W1;:5TN=&5X="P@=&AI
M<RYS;W)T97),:7-T6VE=+G9A;'5E*0H@("`@("`@('T*"B`@("`@("`@9F]R
M("AI(#T@,#L@:2`\('1M<"YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!I
M9B`H:2`K('1H:7,N;6EN3&5N9W1H(#T]('-E;"D@>PH@("`@("`@("`@("`@
M("`@=&AI<RYS;W)T97),:7-T6VD@*R!T:&ES+FUI;DQE;F=T:%T@/2!T;7!;
M:2`K(#%=.PH@("`@("`@("`@("!](&5L<V4@:68@*&D@*R!T:&ES+FUI;DQE
M;F=T:"`]/2!S96P@*R`Q*2!["B`@("`@("`@("`@("`@("!T:&ES+G-O<G1E
M<DQI<W1;:2`K('1H:7,N;6EN3&5N9W1H72`]('1M<%MI("T@,5T["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!T:&ES+G-O<G1E<DQI
M<W1;:2`K('1H:7,N;6EN3&5N9W1H72`]('1M<%MI73L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@=&AI<RYS;W)T97),:7-T+G-E;&5C=&5D
M26YD97@@/2!S96P@*R`Q.PH*("`@("`@("!T:&ES+G-E=$AI9&1E;B@I.PH@
M("`@?0I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:G,O<W1R:7!E+FIS````````````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#$P,0`Q,#0Q-S,V,C<T
M,P`P,38V-S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RHJ"B`J($IA=F%S8W)I<'0@8V]D92!F;W(@9FEN9&EN9R!A;&P@
M=&%B;&5S('=I=&@@8VQA<W-N86UE(")S=')I<&5D(B!A;F0*("H@9'EN86UI
M8V%L;'D@<W1R:7!I;F<@=&AE:7(@<F]W(&-O;&]R<RX*("H*("H@)$AO<F1E
M.B!H;W)D92]J<R]S=')I<&4N:G,L=B`Q+C,N,BXR(#(P,#4O,3`O,3@@,3$Z
M,S,Z,S@@:F%N($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J(%=E(&1O(&5V
M97)Y=&AI;F<@;VYL;V%D('-O('1H870@=&AE(&5N=&ER92!D;V-U;65N="!I
M<R!P<F5S96YT"B`J(&)E9F]R92!W92!S=&%R="!S96%R8VAI;F<@:70@9F]R
M('1A8FQE<RX@*B\*:68@*'=I;F1O=RYA9&1%=F5N=$QI<W1E;F5R*2!["B`@
M("!W:6YD;W<N861D179E;G1,:7-T96YE<B@G;&]A9"<L(&9I;F13=')I<&5D
M5&%B;&5S+"!F86QS92D["GT@96QS92!I9B`H=VEN9&]W+F%T=&%C:$5V96YT
M*2!["B`@("!W:6YD;W<N871T86-H179E;G0H)V]N;&]A9"<L(&9I;F13=')I
M<&5D5&%B;&5S*3L*?2!E;'-E(&EF("AW:6YD;W<N;VYL;V%D("$](&YU;&PI
M('L*("`@('9A<B!O;&1/;DQO860@/2!W:6YD;W<N;VYL;V%D.PH@("`@=VEN
M9&]W+F]N;&]A9"`](&9U;F-T:6]N*&4I"B`@("!["B`@("`@("`@;VQD3VY,
M;V%D*&4I.PH@("`@("`@(&9I;F13=')I<&5D5&%B;&5S*"D["B`@("!].PI]
M(&5L<V4@>PH@("`@=VEN9&]W+F]N;&]A9"`](&9I;F13=')I<&5D5&%B;&5S
M.PI]"@IF=6YC=&EO;B!F:6YD4W1R:7!E9%1A8FQE<R@I"GL*("`@(&EF("@A
M9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64I('L*("`@("`@("!R971U
M<FX["B`@("!]"B`@("!T86)L97,@/2!D;V-U;65N="YG971%;&5M96YT<T)Y
M5&%G3F%M92@G=&%B;&4G*3L*("`@(&9O<B`H:2`](#`[(&D@/"!T86)L97,N
M;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H=&%B;&5S6VE=+F-L87-S3F%M
M92YI;F1E>$]F*"=S=')I<&5D)RD@(3T@+3$I('L*("`@("`@("`@("`@<W1R
M:7!E*'1A8FQE<UMI72D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO;B!S
M=')I<&4H=&%B;&4I"GL*("`@("\O(%1H92!F;&%G('=E)VQL('5S92!T;R!K
M965P('1R86-K(&]F('=H971H97(@=&AE(&-U<G)E;G0@<F]W(&ES"B`@("`O
M+R!O9&0@;W(@979E;BX*("`@('9A<B!E=F5N(#T@9F%L<V4["@H@("`@+R\@
M5&%B;&5S(&-A;B!H879E(&UO<F4@=&AA;B!O;F4@=&)O9'D@96QE;65N=#L@
M9V5T(&%L;"!C:&EL9`H@("`@+R\@=&)O9'D@=&%G<R!A;F0@:6YT97)A=&4@
M=&AR;W5G:"!T:&5M+@H@("`@=F%R('1B;V1I97,@/2!T86)L92YC:&EL9$YO
M9&5S.PH@("`@9F]R("AV87(@8R`](#`[(&,@/"!T8F]D:65S+FQE;F=T:#L@
M8RLK*2!["B`@("`@("`@:68@*'1B;V1I97-;8UTN=&%G3F%M92`]/2`G5$)/
M1%DG*2!["B`@("`@("`@("`@('9A<B!T<G,@/2!T8F]D:65S6V-=+F-H:6QD
M3F]D97,["B`@("`@("`@("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@=')S+FQE
M;F=T:#L@:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H=')S6VE=+G1A9TYA
M;64@/3T@)U12)RD@>PH@("`@("`@("`@("`@("`@("`@('1R<UMI72YC;&%S
M<TYA;64@/2!T<G-;:5TN8VQA<W-.86UE+G)E<&QA8V4H+R`_<F]W179E;B`_
M+RP@)R<I+G)E<&QA8V4H+R`_<F]W3V1D(#\O+"`G)RD["B`@("`@("`@("`@
M("`@("`@("`@:68@*'1R<UMI72YC;&%S<TYA;64I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@=')S6VE=+F-L87-S3F%M92`K/2`G("<["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('1R<UMI72YC;&%S
M<TYA;64@*ST@979E;B`_("=R;W=%=F5N)R`Z("=R;W=/9&0G.PH*("`@("`@
M("`@("`@("`@("`@("`O+R!&;&EP(&9R;VT@;V1D('1O(&5V96XL(&]R('9I
M8V4M=F5R<V$N"B`@("`@("`@("`@("`@("`@("`@979E;B`]("%E=F5N.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O=&%B;&5S+FIS````````
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C8R
M-P`Q,#0Q-S,V,C<T,P`P,38V-34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+RHJ"B`J($IA=F%S8W)I<'0@8V]D92!F;W(@
M9FEN9&EN9R!A;&P@=&%B;&5S('=I=&@@8VQA<W-N86UE(")S=')I<&5D(B!A
M;F0*("H@9'EN86UI8V%L;'D@<W1R:7!I;F<@=&AE:7(@<F]W(&-O;&]R<RP@
M86YD(&9I;F1I;F<@86QL('1A8FQE<R!W:71H"B`J(&-L87-S;F%M92`B<V]R
M=&%B;&4B(&%N9"!M86MI;F<@=&AE;2!D>6YA;6EC86QL>2!S;W)T86)L92X*
M("H*("H@)$AO<F1E.B!H;W)D92]J<R]T86)L97,N:G,L=B`Q+C0N,BXS(#(P
M,#4O,3(O,#$@,C(Z-3@Z,C8@8VAU8VL@17AP("0*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*+RH@5V4@9&\@979E<GET:&EN9R!O;FQO860@<V\@=&AA="!T:&4@96YT
M:7)E(&1O8W5M96YT(&ES('!R97-E;G0*("H@8F5F;W)E('=E('-T87)T('-E
M87)C:&EN9R!I="!F;W(@=&%B;&5S+B`J+PII9B`H=VEN9&]W+F%D9$5V96YT
M3&ES=&5N97(I('L*("`@('=I;F1O=RYA9&1%=F5N=$QI<W1E;F5R*"=L;V%D
M)RP@=&%B;&5?:6YI="P@9F%L<V4I.PI](&5L<V4@:68@*'=I;F1O=RYA='1A
M8VA%=F5N="D@>PH@("`@=VEN9&]W+F%T=&%C:$5V96YT*"=O;FQO860G+"!T
M86)L95]I;FET*3L*?2!E;'-E(&EF("AW:6YD;W<N;VYL;V%D("$](&YU;&PI
M('L*("`@('9A<B!O;&1?;VYL;V%D(#T@=VEN9&]W+F]N;&]A9#L*("`@('=I
M;F1O=RYO;FQO860@/2!F=6YC=&EO;BAE*0H@("`@>PH@("`@("`@(&]L9%]O
M;FQO860H92D["B`@("`@("`@=&%B;&5?:6YI="@I.PH@("`@?3L*?2!E;'-E
M('L*("`@('=I;F1O=RYO;FQO860@/2!T86)L95]I;FET.PI]"@IV87(@4T]2
M5%]#3TQ534Y?24Y$15@["@IF=6YC=&EO;B!T86)L95]I;FET*"D*>PH@("`@
M:68@*"%D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92D@>PH@("`@("`@
M(')E='5R;CL*("`@('T*("`@('1A8FQE<R`](&1O8W5M96YT+F=E=$5L96UE
M;G1S0GE486=.86UE*"=T86)L92<I.PH@("`@9F]R("AI(#T@,#L@:2`\('1A
M8FQE<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AH87-#;&%S<RAT86)L
M97-;:5TL("=S=')I<&5D)RDI('L*("`@("`@("`@("`@=&%B;&5?<W1R:7!E
M*'1A8FQE<UMI72D["B`@("`@("`@?0H@("`@("`@(&EF("AH87-#;&%S<RAT
M86)L97-;:5TL("=S;W)T86)L92<I("8F('1A8FQE<UMI72YI9"D@>PH@("`@
M("`@("`@("!T86)L95]M86ME4V]R=&%B;&4H=&%B;&5S6VE=*3L*("`@("`@
M("!]"B`@("!]"GT*"F9U;F-T:6]N('1A8FQE7W-T<FEP92AT86)L92D*>PH@
M("`@+R\@5&AE(&9L86<@=V4G;&P@=7-E('1O(&ME97`@=')A8VL@;V8@=VAE
M=&AE<B!T:&4@8W5R<F5N="!R;W<@:7,*("`@("\O(&]D9"!O<B!E=F5N+@H@
M("`@=F%R(&5V96X@/2!F86QS93L*"B`@("`O+R!486)L97,@8V%N(&AA=F4@
M;6]R92!T:&%N(&]N92!T8F]D>2!E;&5M96YT.R!G970@86QL(&-H:6QD"B`@
M("`O+R!T8F]D>2!T86=S(&%N9"!I;G1E<F%T92!T:')O=6=H('1H96TN"B`@
M("!V87(@=&)O9&EE<R`]('1A8FQE+F-H:6QD3F]D97,["B`@("!F;W(@*'9A
M<B!C(#T@,#L@8R`\('1B;V1I97,N;&5N9W1H.R!C*RLI('L*("`@("`@("!I
M9B`H=&)O9&EE<UMC72YT86=.86UE("$]("=40D]$62<I('L*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("!V87(@=')S(#T@=&)O
M9&EE<UMC72YC:&EL9$YO9&5S.PH@("`@("`@(&9O<B`H=F%R(&D@/2`P.R!I
M(#P@=')S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@(&EF("AT<G-;:5TN
M=&%G3F%M92`]/2`G5%(G*2!["B`@("`@("`@("`@("`@("!R96UO=F5#;&%S
M<RAT<G-;:5TL("=R;W=%=F5N)RD["B`@("`@("`@("`@("`@("!R96UO=F5#
M;&%S<RAT<G-;:5TL("=R;W=/9&0G*3L*("`@("`@("`@("`@("`@(&%D9$-L
M87-S*'1R<UMI72P@979E;B`_("=R;W=%=F5N)R`Z("=R;W=/9&0G*3L*"B`@
M("`@("`@("`@("`@("`O+R!&;&EP(&9R;VT@;V1D('1O(&5V96XL(&]R('9I
M8V4M=F5R<V$N"B`@("`@("`@("`@("`@("!E=F5N(#T@(65V96X["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N('1A8FQE7VUA
M:V53;W)T86)L92AT86)L92D*>PH@("`@:68@*'1A8FQE+G)O=W,@)B8@=&%B
M;&4N<F]W<RYL96YG=&@@/B`P*2!["B`@("`@("`@=F%R(&9I<G-T4F]W(#T@
M=&%B;&4N<F]W<ULP73L*("`@('T*("`@(&EF("@A9FER<W12;W<I('L*("`@
M("`@("!R971U<FX["B`@("!]"@H@("`@+R\@5V4@:&%V92!A(&9I<G-T(')O
M=SH@87-S=6UE(&ET)W,@=&AE(&AE861E<BP@86YD(&UA:V4@:71S"B`@("`O
M+R!C;VYT96YT<R!C;&EC:V%B;&4@;&EN:W,N"B`@("!F;W(@*'9A<B!I(#T@
M,#L@:2`\(&9I<G-T4F]W+F-E;&QS+FQE;F=T:#L@:2LK*2!["B`@("`@("`@
M=F%R(&-E;&P@/2!F:7)S=%)O=RYC96QL<UMI73L*("`@("`@("!I9B`H:&%S
M0VQA<W,H8V5L;"P@)VYO<V]R="<I*2!["B`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@('T*"B`@("`@("`@8V5L;"YC;VQU;6Y);F1E>"`](&D["B`@
M("`@("`@8V5L;"YS='EL92YC=7)S;W(@/2`G<&]I;G1E<B<["B`@("`@("`@
M8V5L;"YO;F-L:6-K(#T@9G5N8W1I;VXH92D*("`@("`@("!["B`@("`@("`@
M("`@('9A<B!E(#T@92!\?"!W:6YD;W<N979E;G0["@H@("`@("`@("`@("!I
M9B`H92YT87)G970I('L*("`@("`@("`@("`@("`@(&EF("AE+G1A<F=E="YN
M;V1E5'EP92`]/2`S*2!["B`@("`@("`@("`@("`@("`@("`@92YT87)G970@
M/2!E+G1A<F=E="YP87)E;G1.;V1E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@:68@*&4N<W)C16QE;65N="D@>PH@("`@("`@("`@
M("`@("`@92YT87)G970@/2!E+G-R8T5L96UE;G0["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&5L(#T@:&%S4&%R96YT*&4N=&%R9V5T+"`G02<L("=4
M2"<I.PH@("`@("`@("`@("!I9B`H96P@)B8@(6AA<T-L87-S*&5L+"`G<V]R
M=&QI;FLG*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('1A8FQE7W)E<V]R=%1A8FQE*&=E=%!A
M<F5N="AE+G1A<F=E="P@)U1()RDI.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO;B!T86)L95]G971);FYE
M<E1E>'0H96PI"GL*("`@(&EF("AT>7!E;V8@96P@/3T@)W-T<FEN9R<I('L*
M("`@("`@("!R971U<FX@96P["B`@("!]"B`@("!I9B`H='EP96]F(&5L(#T]
M("=U;F1E9FEN960G*2!["B`@("`@("`@<F5T=7)N(&5L.PH@("`@?0H@("`@
M:68@*&5L+FEN;F5R5&5X="D@>PH@("`@("`@("\O($YO="!N965D960@8G5T
M(&ET(&ES(&9A<W1E<BX*("`@("`@("!R971U<FX@96PN:6YN97)497AT.PH@
M("`@?0H*("`@('9A<B!S='(@/2`B(CL*("`@('9A<B!C<R`](&5L+F-H:6QD
M3F]D97,["B`@("!V87(@;"`](&-S+FQE;F=T:#L*("`@(&9O<B`H=F%R(&D@
M/2`P.R!I(#P@;#L@:2LK*2!["B`@("`@("`@<W=I=&-H("AC<UMI72YN;V1E
M5'EP92D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@+R\@14Q%345.
M5%].3T1%"B`@("`@("`@("`@('-T<B`K/2!T86)L95]G971);FYE<E1E>'0H
M8W-;:5TI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`S.@H@
M("`@("`@("`@("`O+R!415A47TY/1$4*("`@("`@("`@("`@<W1R("L](&-S
M6VE=+FYO9&5686QU93L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@?0H*("`@(')E='5R;B!S='(["GT*"F9U;F-T:6]N('1A8FQE7W)E<V]R
M=%1A8FQE*'1H*0I["B`@("!T86)L92`](&=E=%!A<F5N="AT:"P@)U1!0DQ%
M)RD["B`@("!S;W)T0V]L=6UN(#T@=&@N8V]L=6UN26YD97@["B`@("!S;W)T
M1&]W;B`](#`["@H@("`@+R\@3&]O<"!T:')O=6=H(#QT:&5A9#X@=&\@9FEN
M9"!T:&4@8W5R<F5N="!S;W)T(&-O;'5M;B!A;F0*("`@("\O(&1I<F5C=&EO
M;BX*("`@('1H96%D<R`]('1A8FQE+G1(96%D+F=E=$5L96UE;G1S0GE486=.
M86UE*"=T:"<I.PH@("`@9F]R("AI(#T@,#L@:2`\('1H96%D<RYL96YG=&@[
M(&DK*RD@>PH@("`@("`@(&EF("AT:"`]/2!T:&5A9'-;:5TI('L*("`@("`@
M("`@("`@:68@*&AA<T-L87-S*'1H96%D<UMI72P@)W-O<G1U<"<I*2!["B`@
M("`@("`@("`@("`@("!R96UO=F5#;&%S<RAT:&5A9'-;:5TL("=S;W)T=7`G
M*3L*("`@("`@("`@("`@("`@(&%D9$-L87-S*'1H96%D<UMI72P@)W-O<G1D
M;W=N)RD["B`@("`@("`@("`@('T@96QS92!I9B`H:&%S0VQA<W,H=&AE861S
M6VE=+"`G<V]R=&1O=VXG*2D@>PH@("`@("`@("`@("`@("`@<F5M;W9E0VQA
M<W,H=&AE861S6VE=+"`G<V]R=&1O=VXG*3L*("`@("`@("`@("`@("`@(&%D
M9$-L87-S*'1H96%D<UMI72P@)W-O<G1U<"<I.PH@("`@("`@("`@("`@("`@
M<V]R=$1O=VX@/2`Q.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@861D0VQA<W,H=&AE861S6VE=+"`G<V]R=&1O=VXG*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E;6]V94-L
M87-S*'1H96%D<UMI72P@)W-O<G1U<"<I.PH@("`@("`@("`@("!R96UO=F5#
M;&%S<RAT:&5A9'-;:5TL("=S;W)T9&]W;B<I.PH@("`@("`@('T*("`@('T*
M"B`@("`O+R!7;W)K(&]U="!A('1Y<&4@9F]R('1H92!C;VQU;6X*("`@(&EF
M("AT86)L92YR;W=S+FQE;F=T:"`\/2`Q*2!["B`@("`@("`@<F5T=7)N.PH@
M("`@?0H*("`@('9A<B!I=&T@/2!T86)L95]G971);FYE<E1E>'0H=&%B;&4N
M<F]W<ULQ72YC96QL<UMS;W)T0V]L=6UN72D["B`@("!S;W)T9FX@/2!T86)L
M95]S;W)T7V-A<V5I;G-E;G-I=&EV93L*("`@(&EF("AI=&TN;6%T8V@H+UY<
M9%QD6UPO+5U<9%QD6UPO+5U<9%QD7&1<9"0O*2D@>PH@("`@("`@('-O<G1F
M;B`]('1A8FQE7W-O<G1?9&%T93L*("`@('T*("`@(&EF("AI=&TN;6%T8V@H
M+UY<9%QD6UPO+5U<9%QD6UPO+5U<9%QD)"\I*2!["B`@("`@("`@<V]R=&9N
M(#T@=&%B;&5?<V]R=%]D871E.PH@("`@?0H@("`@:68@*&ET;2YM871C:"@O
M7ENC)%TO*2D@>PH@("`@("`@('-O<G1F;B`]('1A8FQE7W-O<G1?8W5R<F5N
M8WD["B`@("!]"B`@("!I9B`H:71M+FUA=&-H*"]>6UQD7"Y=*R0O*2D@>PH@
M("`@("`@('-O<G1F;B`]('1A8FQE7W-O<G1?;G5M97)I8SL*("`@('T*"B`@
M("!33U)47T-/3%5-3E])3D1%6"`]('-O<G1#;VQU;6X["@H@("`@+R\@1&]N
M)W0@;6EX('5P('-E<&5R871E('1B;V1I97,[('-O<G0@96%C:"!I;B!T=7)N
M+@H@("`@9F]R("AI(#T@,#L@:2`\('1A8FQE+G1";V1I97,N;&5N9W1H.R!I
M*RLI('L*("`@("`@("!T<G,@/2!T86)L92YT0F]D:65S6VE=+F=E=$5L96UE
M;G1S0GE486=.86UE*"=T<B<I.PH@("`@("`@(&YE=U)O=W,@/2!N97<@07)R
M87DH*3L*("`@("`@("!F;W(@*&H@/2`P.R!J(#P@=')S+FQE;F=T:#L@:BLK
M*2!["B`@("`@("`@("`@(&YE=U)O=W-;:ET@/2!T<G-;:ET["B`@("`@("`@
M?0H*("`@("`@("!N97=2;W=S+G-O<G0H<V]R=&9N*3L*("`@("`@("!I9B`H
M<V]R=$1O=VXI('L*("`@("`@("`@("`@;F5W4F]W<RYR979E<G-E*"D["B`@
M("`@("`@?0H*("`@("`@("`O+R!792!A<'!E;F1#:&EL9"!R;W=S('1H870@
M86QR96%D>2!E>&ES="!T;R!T:&4@=&)O9'DL('-O(&ET"B`@("`@("`@+R\@
M;6]V97,@=&AE;2!R871H97(@=&AA;B!C<F5A=&EN9R!N97<@;VYE<RX@1&]N
M)W0@9&\*("`@("`@("`O+R!S;W)T8F]T=&]M(')O=W,N"B`@("`@("`@9F]R
M("AJ(#T@,#L@:B`\(&YE=U)O=W,N;&5N9W1H.R!J*RLI('L*("`@("`@("`@
M("`@:68@*"%H87-#;&%S<RAN97=2;W=S6VI=+"`G<V]R=&)O='1O;2<I*2![
M"B`@("`@("`@("`@("`@("!T86)L92YT0F]D:65S6VE=+F%P<&5N9$-H:6QD
M*&YE=U)O=W-;:ETI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!$;R!S;W)T8F]T=&]M(')O=W,@;VYL>2X*("`@("`@("!F;W(@*&H@
M/2`P.R!J(#P@;F5W4F]W<RYL96YG=&@[(&HK*RD@>PH@("`@("`@("`@("!I
M9B`H:&%S0VQA<W,H;F5W4F]W<UMJ72P@)W-O<G1B;W1T;VTG*2D@>PH@("`@
M("`@("`@("`@("`@=&%B;&4N=$)O9&EE<UMI72YA<'!E;F1#:&EL9"AN97=2
M;W=S6VI=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M+R!)9B!W92!J=7-T(')E<V]R=&5D(&$@<W1R:7!E9"!T86)L92P@<F4M<W1R
M:7!E(&ET+@H@("`@:68@*&AA<T-L87-S*'1A8FQE+"`G<W1R:7!E9"<I*2![
M"B`@("`@("`@=&%B;&5?<W1R:7!E*'1A8FQE*3L*("`@('T*"B`@("`O+R!&
M:6YA;&QY+"!S964@:68@=V4@:&%V92!A(&-A;&QB86-K(&9U;F-T:6]N('1O
M('1R:6=G97(N"B`@("!I9B`H='EP96]F*'1A8FQE7W-O<G1#86QL8F%C:RD@
M/3T@)V9U;F-T:6]N)RD@>PH@("`@("`@('1A8FQE7W-O<G1#86QL8F%C:RAT
M86)L92YI9"P@=&@N:60L('-O<G1$;W=N*3L*("`@('T*?0H*9G5N8W1I;VX@
M9V5T4&%R96YT*&5L+"!P5&%G3F%M92D*>PH@("`@:68@*&5L(#T](&YU;&PI
M('L*("`@("`@("!R971U<FX@;G5L;#L*("`@('T@96QS92!I9B`H<%1A9TYA
M;64@/3T@;G5L;"D@>PH@("`@("`@(')E='5R;B!E;"YP87)E;G1.;V1E.PH@
M("`@?2!E;'-E(&EF("AE;"YN;V1E5'EP92`]/2`Q("8F(&5L+G1A9TYA;64N
M=&],;W=E<D-A<V4H*2`]/2!P5&%G3F%M92YT;TQO=V5R0V%S92@I*2!["B`@
M("`@("`@+R\@1V5C:V\@8G5G+"!S=7!P;W-E9"!T;R!B92!U<'!E<F-A<V4N
M"B`@("`@("`@<F5T=7)N(&5L.PH@("`@?2!E;'-E('L*("`@("`@("!R971U
M<FX@9V5T4&%R96YT*&5L+G!A<F5N=$YO9&4L('!486=.86UE*3L*("`@('T*
M?0H*9G5N8W1I;VX@=&%B;&5?<V]R=%]D871E*&$L(&(I"GL*("`@("\O(%1W
M;R!D:6=I="!Y96%R<R!L97-S('1H86X@-3`@87)E('1R96%T960@87,@,C!8
M6"P@9W)E871E<B!T:&%N"B`@("`O+R`U,"!A<F4@=')E871E9"!A<R`Q.5A8
M+@H@("`@86$@/2!T86)L95]G971);FYE<E1E>'0H82YC96QL<UM33U)47T-/
M3%5-3E])3D1%6%TI.PH@("`@8F(@/2!T86)L95]G971);FYE<E1E>'0H8BYC
M96QL<UM33U)47T-/3%5-3E])3D1%6%TI.PH@("`@:68@*&%A+FQE;F=T:"`]
M/2`Q,"D@>PH@("`@("`@(&1T,2`](&%A+G-U8G-T<B@V+"`T*2`K(&%A+G-U
M8G-T<B@S+"`R*2`K(&%A+G-U8G-T<B@P+"`R*3L*("`@('T@96QS92!["B`@
M("`@("`@>7(@/2!A82YS=6)S='(H-BP@,BD["B`@("`@("`@:68@*'!A<G-E
M26YT*'ER*2`\(#4P*2!["B`@("`@("`@("`@('ER(#T@)S(P)R`K('ER.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@('ER(#T@)S$Y)R`K('ER.PH@
M("`@("`@('T*("`@("`@("!D=#$@/2!Y<BMA82YS=6)S='(H,RP@,BD@*R!A
M82YS=6)S='(H,"P@,BD["B`@("!]"B`@("!I9B`H8F(N;&5N9W1H(#T](#$P
M*2!["B`@("`@("`@9'0R(#T@8F(N<W5B<W1R*#8L(#0I("L@8F(N<W5B<W1R
M*#,L(#(I("L@8F(N<W5B<W1R*#`L(#(I.PH@("`@?2!E;'-E('L*("`@("`@
M("!Y<B`](&)B+G-U8G-T<B@V+"`R*3L*("`@("`@("!I9B`H<&%R<V5);G0H
M>7(I(#P@-3`I('L*("`@("`@("`@("`@>7(@/2`G,C`G("L@>7(["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@>7(@/2`G,3DG("L@>7(["B`@("`@
M("`@?0H@("`@("`@(&1T,B`]('ER("L@8F(N<W5B<W1R*#,L(#(I("L@8F(N
M<W5B<W1R*#`L(#(I.PH@("`@?0H@("`@:68@*&1T,2`]/2!D=#(I('L*("`@
M("`@("!R971U<FX@,#L*("`@('T@96QS92!I9B`H9'0Q(#P@9'0R*2!["B`@
M("`@("`@<F5T=7)N("TQ.PH@("`@?0H@("`@<F5T=7)N(#$["GT*"F9U;F-T
M:6]N('1A8FQE7W-O<G1?8W5R<F5N8WDH82P@8BD*>PH@("`@86$@/2!T86)L
M95]G971);FYE<E1E>'0H82YC96QL<UM33U)47T-/3%5-3E])3D1%6%TI+G)E
M<&QA8V4H+UM>,"TY+ETO9RP@)R<I.PH@("`@8F(@/2!T86)L95]G971);FYE
M<E1E>'0H8BYC96QL<UM33U)47T-/3%5-3E])3D1%6%TI+G)E<&QA8V4H+UM>
M,"TY+ETO9RP@)R<I.PH@("`@<F5T=7)N('!A<G-E1FQO870H86$I("T@<&%R
M<V5&;&]A="AB8BD["GT*"F9U;F-T:6]N('1A8FQE7W-O<G1?;G5M97)I8RAA
M+"!B*0I["B`@("!A82`]('!A<G-E1FQO870H=&%B;&5?9V5T26YN97)497AT
M*&$N8V5L;'-;4T]25%]#3TQ534Y?24Y$15A=*2D["B`@("!I9B`H:7-.84XH
M86$I*2!["B`@("`@("`@86$@/2`P.PH@("`@?0H@("`@8F(@/2!P87)S949L
M;V%T*'1A8FQE7V=E=$EN;F5R5&5X="AB+F-E;&QS6U-/4E1?0T],54U.7TE.
M1$5872DI.PH@("`@:68@*&ES3F%.*&)B*2D@>PH@("`@("`@(&)B(#T@,#L*
M("`@('T*("`@(')E='5R;B!A82`M(&)B.PI]"@IF=6YC=&EO;B!T86)L95]S
M;W)T7V-A<V5I;G-E;G-I=&EV92AA+"!B*0I["B`@("!A82`]('1A8FQE7V=E
M=$EN;F5R5&5X="AA+F-E;&QS6U-/4E1?0T],54U.7TE.1$5872DN=&],;W=E
M<D-A<V4H*3L*("`@(&)B(#T@=&%B;&5?9V5T26YN97)497AT*&(N8V5L;'-;
M4T]25%]#3TQ534Y?24Y$15A=*2YT;TQO=V5R0V%S92@I.PH@("`@:68@*&%A
M(#T](&)B*2!["B`@("`@("`@<F5T=7)N(#`["B`@("!](&5L<V4@:68@*&%A
M(#P@8F(I('L*("`@("`@("!R971U<FX@+3$["B`@("!]"B`@("!R971U<FX@
M,3L*?0H*9G5N8W1I;VX@=&%B;&5?<V]R=%]D969A=6QT*&$L8BD*>PH@("`@
M86$@/2!T86)L95]G971);FYE<E1E>'0H82YC96QL<UM33U)47T-/3%5-3E])
M3D1%6%TI.PH@("`@8F(@/2!T86)L95]G971);FYE<E1E>'0H8BYC96QL<UM3
M3U)47T-/3%5-3E])3D1%6%TI.PH@("`@:68@*&%A(#T](&)B*2!["B`@("`@
M("`@<F5T=7)N(#`["B`@("!](&5L<V4@:68@*&%A(#P@8F(I('L*("`@("`@
M("!R971U<FX@+3$["B`@("!]"B`@("!R971U<FX@,3L*?0H*+RHJ"B`J($1/
M32!U=&EL:71Y(&9U;F-T:6]N<RX*("HO"F9U;F-T:6]N(&AA<U!A<F5N="AE
M;"P@=&%G3F%M92P@=&%G4W1O<"D*>PH@("`@:68@*&5L+G1A9TYA;64@/3T@
M=&%G3F%M92D@>PH@("`@("`@(')E='5R;B!E;#L*("`@('T@96QS92!I9B`H
M=&%G4W1O<"`A/2!N=6QL("8F(&5L+G1A9TYA;64@/3T@=&%G4W1O<"D@>PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T@96QS92!["B`@("`@("`@<F5T
M=7)N(&AA<U!A<F5N="AG971087)E;G0H96PI+"!T86=.86UE+"!T86=3=&]P
M*3L*("`@('T*?0H*9G5N8W1I;VX@861D0VQA<W,H96PL(&-L87-S3F%M92D*
M>PH@("`@96PN8VQA<W-.86UE("L](&5L+F-L87-S3F%M92`_("<@)R`K(&-L
M87-S3F%M92`Z(&-L87-S3F%M93L*?0H*9G5N8W1I;VX@<F5M;W9E0VQA<W,H
M96PL(&-L87-S3F%M92D*>PH@("`@96PN8VQA<W-.86UE(#T@96PN8VQA<W-.
M86UE+G)E<&QA8V4H;F5W(%)E9T5X<"@G(#\G("L@8VQA<W-.86UE("L@)R`_
M)RDL("<G*3L*?0H*9G5N8W1I;VX@:&%S0VQA<W,H96PL(&-L87-S3F%M92D*
M>PH@("`@<F5T=7)N("AE;"YC;&%S<TYA;64N:6YD97A/9BAC;&%S<TYA;64I
M("$]("TQ*3L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VIS+W1O;VQT:7`N:G,`````````````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R-S0`,3`T,3<S-C(W-#,`,#$W,#<S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M*@H@*B!(;W)D92!4;V]L=&EP($IA=F%S8W)I<'0*("H*("H@4')O=FED97,@
M=&AE(&IA=F%S8W)I<'0@=&\@9&ES<&QA>2!T;V]L=&EP<RX*("H*("H@)$AO
M<F1E.B!H;W)D92]J<R]T;V]L=&EP+FIS+'8@,2XR+C$P+C(@,C`P-2\P-2\P
M,2`Q-CHU,SHS,"!C:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*=F%R
M(&%C=&EV951I;65O=70["@II9B`H='EP96]F(&1O8W5M96YT+F-A<'1U<F5%
M=F5N=',@(3T@)W5N9&5F:6YE9"<I('L*("`@(&1O8W5M96YT+F-A<'1U<F5%
M=F5N=',H179E;G0N34]54T5-3U9%*3L*("`@(&1O8W5M96YT+F]N;6]U<V5M
M;W9E(#T@;6]U<V50;W,["B`@("!V87(@;F5T6"P@;F5T63L*?0H*9G5N8W1I
M;VX@<&]S6"@I"GL*("`@('1E;7!8(#T@9&]C=6UE;G0N8F]D>2YS8W)O;&Q,
M969T("L@979E;G0N8VQI96YT6#L*("`@(&EF("AT96UP6"`\(#`I('L*("`@
M("`@("!T96UP6"`](#`["B`@("!]"B`@("!R971U<FX@=&5M<%@["GT*"F9U
M;F-T:6]N('!O<UDH*0I["B`@("!T96UP62`](&1O8W5M96YT+F)O9'DN<V-R
M;VQL5&]P("L@979E;G0N8VQI96YT63L*("`@(&EF("AT96UP62`\(#`I('L*
M("`@("`@("!T96UP62`](#`["B`@("!]"B`@("!R971U<FX@=&5M<%D["GT*
M"F9U;F-T:6]N(&UO=7-E4&]S*&4I"GL*("`@(&YE=%@@/2!E+G!A9V58.PH@
M("`@;F5T62`](&4N<&%G95D["GT*"F9U;F-T:6]N('1O;VQT:7!3:&]W*'!8
M+"!P62P@<W)C*0I["B`@("!I9B`H<%@@/"`Q*2!["B`@("`@("`@<%@@/2`Q
M.PH@("`@?0H@("`@:68@*'!9(#P@,2D@>PH@("`@("`@('!9(#T@,3L*("`@
M('T*("`@(&EF("AD;V-U;65N="YG971%;&5M96YT0GE)9"D@>PH@("`@("`@
M('1T(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)W1O;VQT:7`G*3L*("`@
M("`@("!T="YS='EL92YL969T(#T@<%@@*R`G<'@G.PH@("`@("`@('1T+G-T
M>6QE+G1O<"`]('!9("L@)W!X)SL*("`@("`@("!T="YS='EL92YV:7-I8FEL
M:71Y(#T@)W9I<VEB;&4G.PH@("`@("`@('1T+FEN;F5R2%1-3"`]('-R8SL*
M("`@('T@96QS92!["B`@("`@("`@9&]C=6UE;G0N86QL+G1O;VQT:7`N<W1Y
M;&4N;&5F="`]('!8("L@)W!X)SL*("`@("`@("!D;V-U;65N="YA;&PN=&]O
M;'1I<"YS='EL92YT;W`@/2!P62`K("=P>"<["B`@("`@("`@9&]C=6UE;G0N
M86QL+G1O;VQT:7`N<W1Y;&4N=FES:6)I;&ET>2`]("=V:7-I8FQE)SL*("`@
M("`@("!D;V-U;65N="YA;&PN=&]O;'1I<"YI;FYE<DA434P@/2!S<F,["B`@
M("!]"GT*"F9U;F-T:6]N('1O;VQT:7!#;&]S92@I"GL*("`@(&EF("AD;V-U
M;65N="YG971%;&5M96YT0GE)9"D@>PH@("`@("`@('1T(#T@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)W1O;VQT:7`G*3L*("`@("`@("!T="YS='EL92YV
M:7-I8FEL:71Y(#T@)VAI9&1E;B<["B`@("`@("`@='0N:6YN97)(5$U,(#T@
M)R<["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M96YT+F%L;"YT;V]L=&EP
M+G-T>6QE+G9I<VEB:6QI='D@/2`G:&ED9&5N)SL*("`@("`@("!D;V-U;65N
M="YA;&PN=&]O;'1I<"YI;FYE<DA434P@/2`G)SL*("`@('T*("`@(&-L96%R
M5&EM96]U="AA8W1I=F54:6UE;W5T*3L*("`@('=I;F1O=RYS=&%T=7,@/2`G
M)SL*?0H*9G5N8W1I;VX@=&]O;'1I<$QI;FLH=&]O;'1E>'0L('-T871U<VQI
M;F4I"GL*("`@('1E>'0@/2`G/&1I=B!C;&%S<STB=&]O;'1I<"(^)R`K('1O
M;VQT97AT("L@)SPO9&EV/B<["B`@("!I9B`H='EP96]F(&1O8W5M96YT+F-A
M<'1U<F5%=F5N=',@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!X<&]S(#T@
M;F5T6#L*("`@("`@("!Y<&]S(#T@;F5T63L*("`@('T@96QS92!["B`@("`@
M("`@>'!O<R`]('!O<U@H*3L*("`@("`@("!Y<&]S(#T@<&]S62@I.PH@("`@
M?0H@("`@86-T:79E5&EM96]U="`]('-E=%1I;65O=70H)W1O;VQT:7!3:&]W
M*'AP;W,@+2`Q,3`L('EP;W,@*R`Q-2P@=&5X="D[)RP@,S`P*3L*("`@('=I
M;F1O=RYS=&%T=7,@/2!S=&%T=7-L:6YE.PI]"@ID;V-U;65N="YW<FET92@G
M/&1I=B!I9#TB=&]O;'1I<"(@<W1Y;&4](G!O<VET:6]N.F%B<V]L=71E.R!V
M:7-I8FEL:71Y.FAI9&1E;CLB/CPO9&EV/B<I.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O````````````````````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-#,`,#$U,S4S`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]54$=2
M041)3D<`````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-C$V-@`Q,#0Q-S,V,C<T,P`P,38V,C0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/3T]/3T]/3T]/3T]/3T]/3T*
M(%5P9W)A9&EN9R!(;W)D90H]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D
M871E.B`@("1$871E.B`R,#`V+S`S+S(U(#`P.C(P.C(U("0*.E)E=FES:6]N
M.B`@("`@("12979I<VEO;CH@,2XT+C0N-B`D"CI#;VYT86-T.B`@("`@("!H
M;W)D94!L:7-T<RYH;W)D92YO<F<*"@I4:&5S92!A<F4@:6YS=')U8W1I;VYS
M('1O('5P9W)A9&4@9G)O;2!E87)L:65R($AO<F1E('9E<G-I;VYS+B!0;&5A
M<V4@8F%C:W5P"GEO=7(@97AI<W1I;F<@9&%T82!B969O<F4@<G5N;FEN9R!A
M;GD@;V8@=&AE('-T97!S(&1E<V-R:6)E9"!B96QO=RX@66]U(&-A;B=T"G5S
M92!T:&4@=7!D871E9"!D871A('=I=&@@>6]U<B!O;&0@2&]R9&4@=F5R<VEO
M;B!A;GEM;W)E+@H*069T97(@=7!D871I;F<@=&\@82!N97=E<B!(;W)D92!V
M97)S:6]N+"!O<B!A(&YE=V5R('9E<G-I;VX@;V8@*BIA;GDJ*B!(;W)D90IA
M<'!L:6-A=&EO;BP@>6]U("HJ86QW87ES*BH@;F5E9"!T;R!U<&1A=&4@*BIA
M;&PJ*B!C;VYF:6=U<F%T:6]N(&9I;&5S+@H*"E5P9W)A9&EN9R!(;W)D92!F
M<F]M(#,N,2!T;R`S+C$N,0H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"@I->5-13"!397-S:6]N($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM"@I4:&4@;7ES<6P@<V5S<VEO;B!H86YD;&5R(&AA<R!B965N(&EM
M<')O=F5D('1O(&-O<G)E8W1L>2!L;V-K(&-O;F-U<G)E;G0*86-C97-S97,@
M=&\@=&AE('-A;64@<V5S<VEO;BX@66]U(&YE960@=&\@<V5T(&EN('1H92!(
M;W)D92!C;VYF:6=U<F%T:6]N(&EF"GEO=2!W86YT('1O('5S92!R;W<M;&5V
M96P@;&]C:VEN9R!A;F0@=')A;G-A8W1I;VYS(&]R('1A8FQE+6QE=F5L"FQO
M8VMI;F<N(%)O=RUL979E;"!L;V-K:6YG(&%N9"!T<F%N<V%C=&EO;G,@87)E
M(&]N;'D@<W5P<&]R=&5D(&)Y('-O;64@=&%B;&4*96YG:6YE<R!L:6ME($EN
M;F]$0BP@86YD(&ES(')E8V]M;65N9&5D(&9O<B!S97-S:6]N('1A8FQE<RX@
M5&AE(&1E9F%U;'0@=&%B;&4*='EP92!F;W(@37E344P@:7,@37E)4T%-('1H
M;W5G:"P@=&AA="!O;FQY('-U<'!O<G1S('1A8FQE+6QE=F5L(&QO8VMI;F<N
M($EF"GEO=2!U<V5D('1H92!344P@<V-R:7!T<R!F<F]M($AO<F1E(#,N,2!O
M<B!E87)L:65R('1O(&-R96%T92!T:&4@<V5S<VEO;@IT86)L92P@=&AI<R!I
M<R!P<F]B86)L>2!T:&4@8W5R<F5N="!E;F=I;F4@;V8@>6]U('-E<W-I;VX@
M=&%B;&4N($EF('EO=2!W86YT"G1O(&-H86YG92!T:&4@=&%B;&4@='EP92!T
M;R!);FYO1$(L(&5X96-U=&4@=&AE(&9O;&QO=VEN9R!344P@<W1A=&5M96YT
M.CH*"B`@($%,5$52(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R($5.1TE.
M12`]($EN;F]$0B`*"@H*57!G<F%D:6YG($AO<F1E(&9R;VT@,RXP+G@@=&\@
M,RXQ+G@*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"@I3
M44P@0F%C:V5N9',*+2TM+2TM+2TM+2TM"@I!(&9E=R!N97<@=&%B;&5S(&AA
M=F4@8F5E;B!A9&1E9"!T;R!(;W)D92X*"D5X96-U=&4@=&AE('!R;W9I9&5D
M(%-13"!S8W)I<'0@=&\@=7!D871E('EO=7(@9&%T82!T;R!T:&4@;F5W($AO
M<F1E('9E<G-I;VXZ.@H*("`@;7ES<6P@+2UU<V5R/7)O;W0@+2UP87-S=V]R
M9#T\37E344PM<F]O="UP87-S=V]R9#X@/&1B(&YA;64^(#P@<V-R:7!T<R]U
M<&=R861E<R\S+C!?=&]?,RXQ+FUY<W%L+G-Q;`H*"D=R;W5P<PHM+2TM+2T*
M"E1H92!(;W)D95]'<F]U<"!!4$D@=7-E<R!G<F]U<"!)1',@:6YS=&5A9"!O
M9B!G<F]U<"!N86UE<R!T;R!A=F]I9"!A;6)I9W5I='DN"D)E('-U<F4@=&\@
M=7!D871E(&%N>2!C=7-T;VT@8V]D92!T:&%T('5S97,@2&]R9&5?1W)O=7`N
M"@H*2&ES=&]R>0HM+2TM+2TM"@I4:&4@2&]R9&5?2&ES=&]R>2!S=&]R86=E
M(&AA<R!B965N(&UO=F5D(&]U="!T;R!A('-E<&%R871E(&1A=&%B87-E('1A
M8FQE('1O"F1R87-T:6-A;&QY(&EM<')O=F4@<&5R9F]R;6%N8V4N"@HN+B!7
M87)N:6YG.CH@36EG<F%T:6]N(&]F('1H92!(;W)D95](:7-T;W)Y(&1A=&$@
M;6%Y('1A:V4@82!V97)Y(&QO;F<@=&EM92P*("`@("`@("`@("`@('!O<W-I
M8FQY(&1A>7,L(&1E<&5N9&EN9R!O;B!T:&4@;G5M8F5R(&]F(&5N=')I97,N
M("!"92!S=7)E('1O"B`@("`@("`@("`@("!E>&5C=71E('1H:7,@<V-R:7!T
M(&9R;VT@82!L;V-A=&EO;B!W:&5R92!I="!W:6QL(&YO="!B92!T:6UE9`H@
M("`@("`@("`@("`@;W5T(&)Y(&9I<F5W86QL(&]R('1E<FUI;F%L('1I;65O
M=71S+@H*17AE8W5T92!T:&4@<')O=FED960@4$A0('-C<FEP="!T;R!M:6=R
M871E('EO=7(@:&ES=&]R:65S('1O('1H92!N97<@=&%B;&4Z.@H*("`@<&AP
M('-C<FEP=',O=7!G<F%D97,O;6]V95]H:7-T;W)Y7V]U=%]O9E]D871A=')E
M92YP:'`*"@H*57!G<F%D:6YG($AO<F1E(&9R;VT@,BYX('1O(#,N,"YX"CT]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*"D-O;F9I9W5R871I
M;VX@9FEL97,*+2TM+2TM+2TM+2TM+2TM+2TM+0H*5&AE(&-O;F9I9W5R871I
M;VX@9FEL97,@:&%V92!B965N(&-H86YG960@=&\@6$U,(&9O<FUA="X@(%1O
M(&=E;F5R871E(&$@=F%L:60*8V]N9FEG=7)A=&EO;B!F:6QE(&9R;VT@=&AE
M(%A-3"!F:6QE+"!F;VQL;W<@=&AE(&-O;F9I9W5R871I;VX@:6YS=')U8W1I
M;VYS"FEN('1H92!A<'!L:6-A=&EO;G,G(&!@9&]C<R])3E-404Q,8&`@9FEL
M92X*"@I0<F5F97)E;F-E<PHM+2TM+2TM+2TM+0H*5&AE(&!@;&%S=%]L;V=I
M;F!@(&%N9"!@8&1A=&5?9F]R;6%T8&`@<')E9F5R96YC97,@:&%V92!C:&%N
M9V5D('1H96ER(&9O<FUA=`IA;F0O;W(@<V-O<&4N("!*=7-T(')E;6]V92!A
M;&P@8&!L87-T7VQO9VEN8&`@86YD(&!@9&%T95]F;W)M871@8"!P<F5F97)E
M;F-E<PIF<F]M('1H92!P<F5F97)E;F-E<R!B86-K96YD+@H*"E-13"!"86-K
M96YD<PHM+2TM+2TM+2TM+2T*"D$@9F5W(&YE=R!T86)L97,@:&%V92!B965N
M(&%D9&5D('1O($AO<F1E+@H*17AE8W5T92!T:&4@<')O=FED960@4U%,('-C
M<FEP="!T;R!U<&1A=&4@>6]U<B!D871A('1O('1H92!N97<@2&]R9&4@=F5R
M<VEO;CHZ"@H@("!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W;W)D/3Q->5-1
M3"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"!S8W)I<'1S+W5P9W)A9&5S
M+S(N,E]T;U\S+C`N;7ES<6PN<W%L"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O4D5!
M1$U%````````````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#8W,S(`,3`T,3<S-C(W-#,`,#$V,C0P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````%=H870@:7,@2&]R9&4_"CT]
M/3T]/3T]/3T]/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#4O,3`O
M,3@@,3$Z,S,Z,S4@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`R+C$S
M+C$P+C$@)`HZ0V]N=&%C=#H@("`@("`@:&]R9&5`;&ES=',N:&]R9&4N;W)G
M"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"BXN('-E8W1I;VXM;G5M8F5R:6YG
M.CH*"E1H92!(;W)D92!0<F]J96-T(&ES(&$@9W)O=7`@;V8@9&5V96QO<&5R
M<R!W:&\@=W)I=&4@5V5B(&%P<&QI8V%T:6]N<R!U<VEN9PIT:&4@2&]R9&4@
M07!P;&EC871I;VX@1G)A;65W;W)K+"!I='-E;&8@82!P<F]D=6-T(&]F('1H
M92!0<F]J96-T+@H*5&AE($AO<F1E($%P<&QI8V%T:6]N($9R86UE=V]R:R!I
M<R!W<FET=&5N(&EN(%!(4"P@86YD('!R;W9I9&5S('1H92!C;VUM;VX*=&]O
M;',@82!796(@87!P;&EC871I;VX@<F5Q=6ER97,Z(&-L87-S97,@9F]R(&1E
M86QI;F<@=VET:"!P<F5F97)E;F-E<RP*8V]M<')E<W-I;VXL(&)R;W=S97(@
M9&5T96-T:6]N+"!C;VYN96-T:6]N('1R86-K:6YG+"!-24U%+"!A;F0@;6]R
M92X*"E1H92!(;W)D92!&<F%M97=O<FLL(&)Y(&ET<V5L9BP@9&]E<R!N;W0@
M<')O=FED92!A;GD@<VEG;FEF:6-A;G0@96YD('5S97(*9G5N8W1I;VYA;&ET
M>3L@:70@<')O=FED97,@82!B87-E(&9O<B!O=&AE<B!A<'!L:6-A=&EO;G,@
M86YD('1O;VQS(&9O<@ID979E;&]P97)S+B!9;W4@=VEL;"!P<F]B86)L>2!W
M86YT('1O(&EN<W1A;&P@<V]M92!O9B!T:&4@879A:6QA8FQE($AO<F1E"F%P
M<&QI8V%T:6]N<RP@<W5C:"!A<R!)35`@*&$@=V5B;6%I;"!C;&EE;G0I+"!O
M<B!+<F]N;VQI=&@@*&$@8V%L96YD87(I+B!4:&5R90II<R!A(&QI<W0@;V8@
M2&]R9&4@87!P;&EC871I;VYS(&%N9"!P<F]J96-T<R!A=`IH='1P.B\O=W=W
M+FAO<F1E+F]R9R]P<F]J96-T<RYP:'`N"@I4:&ES('-O9G1W87)E(&ES($]3
M22!#97)T:69I960@3W!E;B!3;W5R8V4@4V]F='=A<F4N("!/4TD@0V5R=&EF
M:65D(&ES(&$*8V5R=&EF:6-A=&EO;B!M87)K(&]F('1H92!@3W!E;B!3;W5R
M8V4@26YI=&EA=&EV96!?+@H*+BX@7V!/<&5N(%-O=7)C92!);FET:6%T:79E
M8#H@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R\*"@I/8G1A:6YI;F<@2&]R
M9&4*+2TM+2TM+2TM+2TM+2TM"@I&=7)T:&5R(&EN9F]R;6%T:6]N(&]N($AO
M<F1E(&%N9"!T:&4@;&%T97-T('9E<G-I;VX@8V%N(&)E(&]B=&%I;F5D(&%T
M"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VAO<F1E+PH*26YF;W)M871I;VX@
M;VX@87!P;&EC871I;VYS('1H870@=7-E('1H92!(;W)D92!F<F%M97=O<FL@
M8V%N(&)E(&9O=6YD(&%T"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W!R;VIE
M8W1S+G!H<`H*"D1O8W5M96YT871I;VX*+2TM+2TM+2TM+2TM+0H*5&AE(&9O
M;&QO=VEN9R!D;V-U;65N=&%T:6]N(&ES(&%V86EL86)L92!I;B!T:&4@2&]R
M9&4@9&ES=')I8G5T:6]N.@H*.E)%041-15\Z("`@("`@("`@("`@("`@("`@
M(%1H:7,@9FEL90HZ0T]064E.1U\Z("`@("`@("`@("`@("`@("`@0V]P>7)I
M9VAT(&%N9"!L:6-E;G-E(&EN9F]R;6%T:6]N"CI@9&]C<R]#2$%.1T538%\Z
M("`@("`@("`@("!#:&%N9V5S(&)Y(')E;&5A<V4*.F!D;V-S+T-/1$E.1U]3
M5$%.1$%21%-@7SH@($-O9&EN9R!S=&%N9&%R9',@9F]R($AO<F1E('!R;VIE
M8W1S"CI@9&]C<R]#3TY44DE"551)3D=@7SH@("`@("!(;W<@=&\@8V]N=')I
M8G5T92!T;R!(;W)D90HZ8&1O8W,O0U)%1$E44V!?.B`@("`@("`@("`@4')O
M:F5C="!D979E;&]P97)S"CI@9&]C<R](04-+24Y'8%\Z("`@("`@("`@("!(
M;W<@=&\@9V5T($AO<F1E('9I82!#5E,*.F!D;V-S+TE.4U1!3$Q@7SH@("`@
M("`@("`@($EN<W1A;&QA=&EO;B!I;G-T<G5C=&EO;G,@86YD(&YO=&5S"CI@
M9&]C<R]015)&3U)-04Y#16!?.B`@("`@("!097)F;W)M86YC92!G=6ED90HZ
M8&1O8W,O4D5,14%316!?.B`@("`@("`@("`@4F5L96%S92!P<F]C97-S(&YO
M=&5S"CI@9&]C<R]314-54DE466!?.B`@("`@("`@("!396-U<FET>2!N;W1E
M<PHZ8&1O8W,O5$]$3V!?.B`@("`@("`@("`@("`@1&5V96QO<&UE;G0@5$]$
M3R!L:7-T"CI@9&]C<R]54$=2041)3D=@7SH@("`@("`@("!0;VEN=&5R<R!O
M;B!U<&=R861I;F<@9G)O;2!P<F5V:6]U<R!(;W)D92!V97)S:6]N<PH*"DEN
M<W1A;&QA=&EO;@HM+2TM+2TM+2TM+2T*"DEN<W1R=6-T:6]N<R!F;W(@:6YS
M=&%L;&EN9R!(;W)D92!C86X@8F4@9F]U;F0@:6X@=&AE(&9I;&4@24Y35$%,
M3%\@:6X@=&AE"F!@9&]C<R]@8"!D:7)E8W1O<GD@;V8@=&AE($AO<F1E(&1I
M<W1R:6)U=&EO;BX*"@I!<W-I<W1A;F-E"BTM+2TM+2TM+2T*"DEF('EO=2!E
M;F-O=6YT97(@<')O8FQE;7,@=VET:"!(;W)D92P@:&5L<"!I<R!A=F%I;&%B
M;&4A(`H*5&AE($AO<F1E($9R97%U96YT;'D@07-K960@475E<W1I;VYS($QI
M<W0@*$9!42DL(&%V86EL86)L92!O;B!T:&4@5V5B(&%T"B`*("!H='1P.B\O
M=W=W+FAO<F1E+F]R9R]F87$O"@I4:&4@2&]R9&4@4')O:F5C="!R=6YS(&$@
M;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',L(&9O<B!I;F1I=FED=6%L(&%P<&QI
M8V%T:6]N<PIA;F0@9F]R(&ES<W5E<R!R96QA=&EN9R!T;R!T:&4@<')O:F5C
M="!A<R!A('=H;VQE+B`@26YF;W)M871I;VXL(&%R8VAI=F5S+"!A;F0*<W5B
M<V-R:7!T:6]N(&EN9F]R;6%T:6]N(&-A;B!B92!F;W5N9"!A=`H*("!H='1P
M.B\O=W=W+FAO<F1E+F]R9R]M86EL+PH*3&%S=&QY+"!(;W)D92!D979E;&]P
M97)S+"!C;VYT<FEB=71O<G,@86YD('5S97)S(&%L<V\@;6%K92!O8V-A<VEO
M;F%L"F%P<&5A<F%N8V5S(&]N($E20RP@;VX@=&AE(&-H86YN96P@(VAO<F1E
M(&]N('1H92!F<F5E;F]D92!.971W;W)K"BAI<F,N9G)E96YO9&4N;F5T*2X*
M"@I,:6-E;G-I;F<*+2TM+2TM+2TM"@I&;W(@;&EC96YS:6YG(&%N9"!C;W!Y
M<FEG:'0@:6YF;W)M871I;VXL('!L96%S92!S964@=&AE(&9I;&4@0T]064E.
M1U\@:6X@=&AE"DAO<F1E(&1I<W1R:6)U=&EO;BX*"E1H86YK<RP*"E1H92!(
M;W)D92!T96%M"@H*+BX@7U)%041-13H@/V8]4D5!1$U%+FAT;6P*+BX@7T-/
M4%E)3D<Z(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+VQG<&PN<&AP
M"BXN(%]D;V-S+T-(04Y'15,Z(#]F/4-(04Y'15,N:'1M;`HN+B!?9&]C<R]#
M3T1)3D=?4U1!3D1!4D13.B`_9CU#3T1)3D=?4U1!3D1!4D13+FAT;6P*+BX@
M7V1O8W,O0T].5%))0E5424Y'.B`_9CU#3TY44DE"551)3D<N:'1M;`HN+B!?
M9&]C<R]#4D5$2513.B`_9CU#4D5$2513+FAT;6P*+BX@7V1O8W,O2$%#2TE.
M1SH@/V8]2$%#2TE.1RYH=&UL"BXN(%])3E-404Q,.@HN+B!?9&]C<R])3E-4
M04Q,.B`_9CU)3E-404Q,+FAT;6P*+BX@7V1O8W,O4$521D]234%.0T4Z(#]F
M/5!%4D9/4DU!3D-%+FAT;6P*+BX@7V1O8W,O4D5,14%313H@/V8]4D5,14%3
M12YH=&UL"BXN(%]D;V-S+U-%0U522519.B`_9CU314-54DE462YH=&UL"BXN
M(%]D;V-S+U1/1$\Z(#]F/51/1$\N:'1M;`HN+B!?9&]C<R]54$=2041)3D<Z
M(#]F/5501U)!1$E.1RYH=&UL"@``````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+T-(
M04Y'15,`````````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,C(Q-#`W`#$P-#$W,S8R-S0S`#`Q-C,U,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+2TM+2T*=C,N,2XQ"BTM
M+2TM+0H*6V-J:%T@1FEX(')E;6]T92!C;V1E(&5X96-U=&EO;B!V=6QN97)A
M8FEL:71Y(&9O=6YD(&)Y($IA;B!38VAN96ED97(N"EMC:FA=($9I>"!E>'!O
M<G0@86YD('-Y;F-H<F]N:7IA=&EO;B!O9B!E=F5N=',@86-R;W-S(&1A>6QI
M9VAT('-A=FEN9R!T:6UE"B`@("`@(&-H86YG97,N"EMJ86Y=($%D9"!P<F]P
M97(@;&]C:VEN9R!T;R!M>7-Q;"!S97-S:6]N(&AA;F1L97(@*$)U9R`C,S8V
M,"DN"EMC:FA=(&EE+F-S<R!I<R!N;W0@;F5C97-S87)Y(&9O<B!)13<L('-O
M(')E;F%M92!A<'!R;W!R:6%T96QY("A"=6<@(S,V-S$I+@I;:F%N72!&:7@@
M<75O=&$@<W5P<&]R="!F;W(@<V]M92!61E,@9')I=F5R<R`H0G5G(",S-C0W
M*2X*6V-J:%T@0F5T=&5R($]P97)A($UI;FD@9&5T96-T:6]N("A"=6<@(S(Y
M-C$I+@I;:F%N72!&:7@@;65N=2!W<F%P<&EN9R!W:71H($MO;&%B(&%N9"!0
M=7)P;&4@=&AE;64@*$)U9R`C,S4Y-"DN"@H*+2TM+0IV,RXQ"BTM+2T*"EMC
M:FA=(%)E;6]V92!B;V=U<R!#;VYT96YT+4QO8V%T:6]N(&AE861E<B!I;B!T
M:&4@5TU,($UO8FEL92!R96YD97)E<@H@("`@("`H0G5G(",S-#<V*2X*6VIA
M;ET@061D(&]P=&EO;B!T;R!B;&]C:R!+;VQA8B!A=71H96YT:6-A=&EO;B!A
M9G1E<B!F86EL960@;&]G:6YS"B`@("`@("AT;VMO94!K9&4N;W)G+"!297%U
M97-T(",S-#<T*2X*6VIA;ET@06QL;W<@=&\@<V5T(&AE:6=H="!O9B!I9G)A
M;64@<&]R=&%L(&)L;V-K("AT979A;G-`=&%C:&]M971R>2YC;VTL"B`@("`@
M(%)E<75E<W0@(S,U,#0I+@I;8VIH72!5<&1A=&4@5&]O;%1I<',@2F%V85-C
M<FEP="!O8FIE8W0@=&\@86QL;W<@=&]O;'1I<',@;VX@;F]N+3QA/B!E;&5M
M96YT<RX*6VUM<UT@4V]R="!A;B!)34%07U1R964@;V)J96-T(&)Y(&1I<W!L
M87D@;F%M92P@;F]T(&9U;&P@;6%I;&)O>"!N86UE+@I;;6%S72!-86ME('-U
M<F4@9&%T86)A<V4@<&]R=&%B:6QI='D@;W!T:6]N<R!A<F4@87!P;&EE9"!I
M;B!(:7-T;W)Y(&UO9'5L92X*("`@("`@*$)U9R`C,S0X,BD*"@HM+2TM+2TM
M+0IV,RXQ+5)#,PHM+2TM+2TM+0H*6VIA;ET@36%K92!S=7)E('1H870@2V]L
M86(@=7-E<G,@86QW87ES(&AA=F4@=&AE('-A;64@=7-E<B!N86UE("A"=6<@
M(S$S,3<I+@I;:F%N72!&:7@@;6]V:6YG(&]B:F5C=',@=VET:"!+;VQA8B!D
M<FEV97)S("AT;VMO94!K9&4N;W)G+"!"=6<@(S(X,3$I+@I;:F%N72!!9&0@
M<F5S970@8G5T=&]N('1O(&EM86=E(&9O<FT@9FEE;&1S+@I;:F%N72!&:7@@
M<V5L96-T:6]N(&]F(&1E9F%U;'0@:61E;G1I='D@*$)U9R`C,S0Q-BDN"EMM
M87-=($%D9"!(96)R97<@=')A;G-L871I;VXN"EMM87-=($%D9"!S=7!P;W)T
M(&9O<B!21D,@-#,Q-"US='EL92!)34%0($%#3',N"EMM;7-=($-O<G)E8W1L
M>2!E;F-O9&4@-RUB:70@34E-12!M97-S86=E<R!W:71H($Y53$P@8VAA<F%C
M=&5R<R`H0G5G(",S,SDU*2X*6VIA;ET@2&ED92!A<'!L:6-A=&EO;G,@=VET
M:"!S=&%T=7,@)VYO=&]O;&)A<B<@9G)O;2!O<'1I;VYS(&UE;G4@*$)U9R`C
M,S,X,RDN"@H*+2TM+2TM+2T*=C,N,2U20S(*+2TM+2TM+2T*"EMJ86Y=($%D
M9"!+:&UE<B!T<F%N<VQA=&EO;B`H3&5A;F<@0VAU;7-O8F5N(#QS;V)E;D!K
M:&UE<F]S+FEN9F\^*2X*6VUM<UT@2&%N9&QE('%U;W1E9"!T97AT('=H96X@
M<&%R<VEN9R!-1$X@<F5Q=65S=',@*$)U9R`C,S,T,"DN"EMB96Y=($)E='1E
M<B!S=7!P;W)T(&9O<B!-4RU344PN"EMJ86Y=(%-H;W<@8V]R<F5C="!A9&1R
M97-S(&EN(&QA<W0M;&]G:6X@;65S<V%G92!I9B!C;VYN96-T:6YG('1H<F]U
M9V@@82!P<F]X>0H@("`@("`H0G5G(",S,C@X*2X*6VUM<UT@06QL;W<@861M
M:6X@=&\@9&ES86)L92!B<F]W<V5R('-T<FEN9R!C:&5C:W,@*$)U9R`C,S(X
M,BDN"EMJ86Y=($-O<G)E8W1L>2!E;F-O9&4@96UA:6P@9W)O=7`@;F%M97,@
M*$)U9R`C,S(S-"DN"EMC:FA=($%D9"!A(&1I<W!L87D@;65T:&]D(&9O<B!H
M;W5R36EN=71E4V5C;VYD(&9O<FT@9FEE;&1S("A"=6<@(S,Q-C4I+@I;8VIH
M72!(;W)D92=S('!R969E<F5N8V5S(&YO=R!A<F4@<F5F97)R960@=&\@87,@
M1VQO8F%L($]P=&EO;G,@<V\@=&AE('5S97(*("`@("`@9&]E<VXG="!N965D
M('1O(&MN;W<@=VAA="!(;W)D92!I<RP@86YD(&%L=V%Y<R!A<'!E87(@870@
M=&AE('1O<"!O9@H@("`@("!L:7-T<R!O9B!A<'!S(&9O<B!W:&EC:"!P<F5F
M97)E;F-E<R!A<F4@879A:6QA8FQE+@I;:F%N72!!9&0@=7!G<F%D92!I;G-T
M<G5C=&EO;G,@*$ME=FEN($UY97(@:V5V:6Y?;7EE<D!I=3$S+F]R9RP@0G5G
M(",S,C(R*2X*6V-J:%T@07!P;&EC871I;VYS('=H:6-H(&1O(&YO="!H879E
M(&$@8V]N9FEG+W!R969S+G!H<"!F:6QE(&YO(&QO;F=E<@H@("`@("!A<'!E
M87(@:6X@;&ES=',@;V8@87!P;&EC871I;VYS('1O('-E="!O<'1I;VYS(&9O
M<B!T;R!A=F]I9"!C;VYF=7-I;VXN"@H*+2TM+2TM+2T*=C,N,2U20S$*+2TM
M+2TM+2T*"EMC:FA=($UA:V4@=&AE(&QO8VL@9&ER96-T;W)Y(&9O<B!T:&4@
M;65M8V%C:&5D(%-E<W-I;VY(86YD;&5R(&-O;F9I9W5R86)L90H@("`@("`H
M0G5G(",S,3(P*2X*6VUM<UT@57!D871E(%1E>'1?1FQO=V5D.CH@=&\@<W5P
M<&]R="!21D,@,S8W-BX*6V-J:%T@1FEX(&]U='!U="!E<V-A<&EN9R!O9B!(
M;W)D95]&;W)M7U1Y<&5?8V5L;'!H;VYE(&EN(%5)7U9A<E)E;F1E<F5R7VAT
M;6PN"EMC:FA=($%L;&]W(&-H;V]S:6YG(%M.;VYE72!A<R!A(&1A=&%B87-E
M(&9O<B`D8V]N9ELG<W%L)UT@*$)U9R`C,C<U-"DN"EMJ86Y=($%D9"!)8V5L
M86YD:6,@=')A;G-L871I;VX@*$)J;W)N($1A=FED<W-O;B`\8FIO<W-I0'-N
M97)P82YI<SXI+@I;;6US72!7;W)K(&%R;W5N9"!B<F]K96X@:6UA<%\X8FET
M*"D@:6UP;&5M96YT871I;VX@:6X*("`@("`@34E-13HZ<75O=&5D4')I;G1A
M8FQE16YC;V1E("A"=6<@(S(Y-S4I+@I;;6US72!!9&0@9V%R8F%G92!C;VQL
M96-T:6]N('1O($AO<F1E7T-A8VAE+@I;8VIH72!&:7@@1W)O=7`Z.FQI<W1!
M;&Q5<V5R<R`H0V%R;&]S(%!E9')I;F%C:2P@0G5G(",R.3,W*2X*6VIA;ET@
M061D(&AI9V@@8V]N=')A<W0@=&AE;64@*'1M97)R:71T0&5M86EL+F%R:7IO
M;F$N961U+"!297%U97-T(",Q-3DX*2X*6VIA;ET@2V5E<',@<VED96)A<B!E
M>'!A;G-I;VX@<W1A=&4@86-R;W-S('-E<W-I;VYS("A297%U97-T(",Q-38T
M*2X*6VIA;ET@061D(&-O;F9I9W5R871I;VX@9F]R(&UA:6P@9&]M86EN('5S
M960@9F]R('!R;V)L96T@<F5P;W)T<PH@("`@("`H9'5S=&EN0'EW;&-S+F]R
M9RP@4F5Q=65S="`C,3,W-BDN"EMC:FA=($%D9"!D>6YA;6EC('1A8FQE(')E
M+7-O<G1I;F<@=&AR;W5G:"!J879A<V-R:7!T+@I;8VIH72!);G-P96-T(&UE
M=&AO9"!S:6=N871U<F5S('-O('1H870@=&AE(%)%4U0@9')I=F5R(&ES;B=T
M(&1E<&5N9&5N="!O;@H@("`@("!T:&4@;W)D97(@;V8@1T54('!A<F%M971E
M<G,N"EMC:FA=($%D9"!H;W)D92]G9710<F5F97)E;F-E(&%N9"!H;W)D92]S
M9710<F5F97)E;F-E($%022!M971H;V1S+@I;8VIH72!!9&0@82!L:7-T(&]F
M(&%C=&EV92!U<V5R<R!A;F0@86-T:79E('-E<W-I;VYS('1O('1H92!A9&UI
M;B!A<F5A+@I;8VIH72!!9&0@=6YO8G1R=7-I=F4@:F%V87-C<FEP="!T;V]L
M=&EP<R!B87-E9"!O;B!T:&4@=&ET;&4@871T<FEB=71E+@I;:F%N72!-;W9E
M('-I9&5B87(@8V]L;&%P<V4O97AP86YD(&)U='1O;B!B96QO=R!T:&4@;65N
M=2!B87(@*$]L:79E<B!+=6AL"B`@("`@(#QO:W5H;$!N971C;VQO9VYE+F1E
M/BDN"EMJ86Y=($%D9"!)9&5A<R!T:&5M92`H4F]E;"!';&]U9&5M86YS(#QR
M;V5L0&=L;W5D96UA;G,N:6YF;SXI+@I;8VIH72!-;W9E($AO<F1E7TAI<W1O
M<GD@9&%T82!T;R!I=',@;W=N(%-13"!T86)L92`H0G5G(",R,CDX*2X*6VIA
M;ET@061D($AO<F1E7T9O<FU?='EP95]F:6=L970@9F]R($-!4%1#2$$@9FEE
M;&1S('=I=&@@9FEG;&5T(&9O;G1S+@I;:F%N72!!9&0@2&]R9&5?1F]R;5]4
M>7!E7V1B;&]O:W5P(&9O<B!F;W)M(&9I96QD<R!W:71H(&1A=&%B87-E(&QO
M;VMU<',*("`@("`@*%)E<75E<W0@(S,R,BDN"EMJ86Y=($%D9"!C;VYF:6=U
M<F%T:6]N('1O(&1I<V%B;&4@(D%B;W5T(B!L:6YK<R!I;B!H96QP('=I;F1O
M=W,@*")-871T:&5W"B`@("`@($TN($=A;6)L92(@/&AO<F1E+61E=D!M9V%M
M8FQE+F-A/BDN"EMC:FA=($%L;&]W('-E;F1I;F<@<')O8FQE;2!R97!O<G1S
M('1O(&$@=&EC:V5T('-Y<W1E;2!U<VEN9R!T:&4*("`@("`@=&EC:V5T<R]A
M9&14:6-K970@05!)(&-A;&P@*$)U9R`C,3DQ-RDN"EMC:FA=($1E9FEN92!2
M5$P@<W1Y;&5S('9I82!A;B!A9&1I=&EO;F%L('-T>6QE<VAE970N"EMC:FA=
M(%5S86)I;&ET>2!I;7!R;W9E;65N=',@=&\@=&AE(&ED96YT:71I97,@;6%N
M86=E;65N="!P86=E("A"=6<@(S$X-#8I+@I;8F5N72!!9&0@3$1!4"!S=7!P
M;W)T('1O($=R;W5P('!A8VMA9V4N"EMC:FA=($%D9"!334(@9')I=F5R('1O
M(%9&4R!P86-K86=E+@I;8VIH72!!;&QO=R!C<F5A=&EO;B!O9B!E>'!I<FEN
M9R!A8V-O=6YT<R!I;B!,1$%0"B`@("`@("A2;V5L($=L;W5D96UA;G,@/')O
M96Q`9VQO=61E;6%N<RYI;F9O/BDN"EMC:FA=($%D9"!C;VYF:6=U<F%T:6]N
M(&]P=&EO;B!T;R!S96%R8V@@9F]R('1H92!U<V5R)W,@1$X@:6X@=&AE(%!R
M969S7VQD87`*("`@("`@9')I=F5R("A"=6<@(S$W.#8I+@I;:F%N72!!;&QO
M=R!T;R!S<&5C:69Y('1H92!O8FIE8W1C;&%S<R!F;W(@;F5W('5S97)S(&%D
M9&5D('1H<F]U9V@@3$1!4`H@("`@("`H4F]E;"!';&]U9&5M86YS(#QR;V5L
M0&=L;W5D96UA;G,N:6YF;SXI+@I;:F%N72!!9&0@<&%S<W=O<F0@97AP:7)A
M=&EO;B!A;F0@<&%S<W=O<F0@96YC<GEP=&EO;B!T;R!,1$%0(&%U=&AE;G1I
M8V%T:6]N"B`@("`@(&1R:79E<B`H4F]E;"!';&]U9&5M86YS(#QR;V5L0&=L
M;W5D96UA;G,N:6YF;SXI+@I;:F%N72!!9&0@<&5R;6ES<VEO;G,@=&\@<F5S
M=')I8W0@;G5M8F5R(&]F('!O<G1A;"!B;&]C:W,N"EMJ86Y=($%D9"!C;VYF
M:6=U<F%T:6]N(&9O<B!F:7AE9"!P;W)T86P@8FQO8VMS+@I;:FUF72!!9&0@
M875D:6\@;F]T:69I8V%T:6]N(&QI<W1E;F5R+"!M86ME('!O<G1A;"!H86YD
M;&4@875D:6\@;F]T:69I8V%T:6]N<PH@("`@("!B>2!B;&]C:W,@*&4N9RX@
M=&AE($E-4"!F;VQD97(@<W5M;6%R>2DN"EMM;7-=($-A8VAE(&-E<G1A:6X@
M<F5G:7-T<GD@9&%T82!T;R!P<F5V96YT('5N;F5E9&5D(&9I;&4@;&]A9&EN
M9R]P87)S:6YG"B`@("`@(&%F=&5R('1H92!I;FET:6%L(&QO9VEN+@I;;6%S
M72!!9&0@<W5P<&]R="!F;W(@8V]U;G1I;F<@875T:&5N=&EC871E9"!S97-S
M:6]N<R!V:6$@4V5S<VEO;DAA;F1L97)S+@I;8VIH72!292UW;W)K(%1A8G,@
M<V\@=&AA="!B86-K9W)O=6YD(&EM86=E<R!C86X@8F4@=7-E9"!I;B!C<F5A
M=&EV92!W87ES+@I;:F%N72!!9&0@(DUY($%C8V]U;G0@26YF;W)M871I;VXB
M(&)L;V-K('1H870@;6EM:6-S('1H92!!8V-O=6YT<R!M;V1U;&4N"EMJ86Y=
M($EM<')O=F4@<F5N9&5R:6YG(&9O<B!R:6=H="UT;RUL969T(&QA;F=U86=E
M<R`H06UI<FMA8FER($UE=&%.150@3'1D+BDN"EMJ86Y=($%D9"!S=7!P;W)T
M(&9O<B!A<F)I=')A<GDL(&YO;BUB;V]L96%N('!E<FUI<W-I;VX@=F%L=65S
M+@I;8F5N72!!9&0@86QT97)N871E7VQO9VEN(&%N9"!R961I<F5C=%]O;E]L
M;V=O=70@9F5A='5R97,N"EMJ86Y=($%D9"!G96YE<FEC(%--5%`@9')I=F5R
M('1O($YE=%]335,@<&%C:V%G92`H26%N($5U<F4@/&EE=7)E0'!H<"YN970^
M*2X*6VUJ<ET@3F5T7TE-4U`@=VEL;"!N;W<@875T;VUA=&EC86QL>2!C<F5A
M=&4@=7-E<B=S(&1E9F%U;'0@861D<F5S<V)O;VL@:68*("`@("`@:70@9&]E
M<R!N;W0@86QR96%D>2!E>&ES="!I;G-T96%D(&]F(&IU<W0@8V]M<&QA:6YI
M;F<@86)O=70@:70N"EMC:FA=($%D9"!S96QE8W0@86QL+"!N;VYE+"!A;F0@
M:6YV97)T(&]P=&EO;F%L;'D@=&\@2&]R9&5?1F]R;5]4>7!E7W-E=`H@("`@
M("!F:65L9',@*$1U8VL@/&1U8VM`;V)A;&$N;F5T/BDN"EMC:FA=(%!R969E
M<F5N8V5S(&]V97)V:65W(&ES(&YO=R!B=6EL="!W:71H(&$@9&5F:6YI=&EO
M;B!L:7-T("@\9&P^*2!S='EL960*("`@("`@=VET:"!#4U,N"EMJ86Y=($%D
M9"!S;W)T*"D@;65T:&]D('1O($AO<F1E7U1R964@8VQA<W,N"EMM9&I=($-H
M86YG92!A;GD@;W5T<'5T(&]F(#QB/B!A;F0@/&D^('1A9W,@=&\@/'-T<F]N
M9SX@86YD(#QE;3X@9F]R(&)E='1E<@H@("`@("!A8V-E<W-I8FEL:71Y('-U
M<'!O<G0N"EMJ;69=($%L;&]W($AO<F1E('1E;7!L871E<R!T;R!I;F-L=61E
M(&%P<&QI8V%T:6]N(&)L;V-K<RX*6VIA;ET@061D(&5X=&5N9&5D(&9O<F5C
M87-T<R!T;R!W96%T:&5R9&]T8V]M($)L;V-K("A2:6-K($5M97)Y"B`@("`@
M(#QR:6-K0&5M97)Y+FAO;65L:6YU>"YN970^*2X*6V-J:%T@06QL;W<@9F]R
M(&%R8FET<F%R>2!A='1R:6)U=&4@9FEL=&5R<R!W:&5N(&QI<W1I;F<@;W(@
M8V]U;G1I;F<@4VAA<F4*("`@("`@;V)J96-T<R`H1'5C:R`\9'5C:T!O8F%L
M82YN970^*2X*6V-J:%T@061D($1A=&%4<F5E.CIG9713;W)T9614<F5E*"D@
M*$1U8VL@/&1U8VM`;V)A;&$N;F5T/BDN"EMM:G)=(%-U<'!O<G0@9F]R(&EM
M=&5S="!A=71H96YT:6-A=&EO;B!A9&1E9"!T;R!0<F5F<U]I;7-P+@I;8VIH
M72!!9&0@4D535"!24$,@9')I=F5R("AS<G)A9F%`=7-C+F5S+"!"=6<@(S$U
M,#`I+@I;8VIH72!!9&0@<W5P<&]R="!F;W(@9F5T8VAI;F<@=&AE(&AI9VAE
M<W0@86YD(&QO=V5S="!I9',@:6X@86YY($1A=&%4<F5E"B`@("`@(&=R;W5P
M("A$=6-K(#QD=6-K0&]B86QA+FYE=#XI+@I;8VIH72!!9&0@1&%T851R964Z
M.G-O<G1">4%T=')I8G5T97,H*2!F;W(@<V]R=&EN9R!$871A5')E94]B:F5C
M=',@8F%S960@;VX*("`@("`@=&AE:7(@871T<FEB=71E<R`H1'5C:R`\9'5C
M:T!O8F%L82YN970^*2X*6VUJ<ET@26YI=&EA;"!S=7!P;W)T(&%D9&5D('1O
M($YE=%])35-0(&9O<B!I;71E<W0@9')I=F5R("AP<F]V:61E<R!P97)S:7-T
M96YT"B`@("`@($E-4U`@8V]N;F5C=&EO;G,@=7-I;F<@0WER=7,@:6UT97-T
M('5T:6QI='DI+@I;:F%N72!!9&0@;6%P(&QI;FMS('1O(%5+(&%N9"!!=7-T
M<F%L:6%N(&%D9')E<W,@9FEE;&1S"B`@("`@("AT=7)B82YL:7-T0'-U8F]R
M8FET+F-O;2P@0G5G(",Q-#8Q*2X*6VUM<UT@1&5T96-T:6]N(&]F(")P:&ES
M:&EN9R(@=&%C=&EC<R!I;B!T:&4@2%1-3"!-24U%7U9I97=E<B`H5&]D9"!-
M97)R:71T"B`@("`@(#QT;65R<FET=$!E;6%I;"YA<FEZ;VYA+F5D=3XL($)U
M9R`C,30S-"DN"EMM;7-=(%1E>'1?1FQO=V5D('!A8VMA9V4@;F]W(&-O<G)E
M8W1L>2!H86YD;&5S(&UU;'1I8GET92!C:&%R86-T97)S+@I;;6US72!-86EN
M=&5N86YC92!C;VYF:7)M871I;VX@<&%G97,@;F]W(')E;F1E<F5D('9I82!(
M;W)D95]496UP;&%T92`H5FEL:75S"B`@("`@(%-U;7-K87,@/'9I;&EU<T!L
M;FLN;'0^*2X*6VIA;ET@06QL;W<@=&\@<W!E8VEF>2!C:&%R<V5T(&]F(&EM
M<&]R=&5D($-35B!F:6QE<RX*6VIA;ET@061D($9I;&5?0U-6('!A8VMA9V4N
M"EMJ86Y=(%-H;W<@87!P;&EC871I;VX@;F%M97,@:6X@<&5R;6ES<VEO;G,@
M861M:6YI<W1R871I;VXN"EMJ;69=($%L;&]W('1H92!A=71H(&)A8VME;F0@
M=&\@<F5Q=65S="!A('!A<W-W;W)D(&-H86YG92P@<W5P<&]R="!E>'!I<FEN
M9PH@("`@("!P87-S=V]R9"!I;B!T:&4@4U%,(&)A8VME;F0N"EMC:FA=(%-H
M;W<@;65N=2!C:&EL9')E;B!F;W(@979E<GD@87!P;&EC871I;VX@=VET:"!P
M<F5F97)E;F-E<R!U;F1E<B!/<'1I;VYS"B`@("`@(&EN('1H92!S:61E8F%R
M(&UE;G4@*$)U9R`C,3`U."DN"EMM;7-=($%L;&]W(&EN9&EV:61U86P@34E-
M15]6:65W97)S('1O(&]V97)R:61E('1H92!#;VYT96YT+41I<W!O<VET:6]N
M($U)344*("`@("`@<&%R86UE=&5R(&%N9"!F;W)C92!V:65W:6YG(&EN;&EN
M92X*"@HM+2TM+2T*=C,N,"XY"BTM+2TM+0H*6V-J:%T@1FEX('-H;W=S=&]P
M<&5R(&)U9R!I;B!(;W)D95]&;W)M('-E;&5C="!F:65L9',@*$)U9R`C,S$R
M,RDN"@H*+2TM+2TM"G8S+C`N.`HM+2TM+2T*"EMC:FA=(%=H96X@9&5L971I
M;F<@86X@:61E;G1I='DL(&1O;B=T('-H;W<@=&AE(&1E;&5T960@:61E;G1I
M='D*("`@("`@:6X@=&AE(&1E9F%U;'0@:61E;G1I='D@<V5L96-T(&1R;W!D
M;W=N(&]N('1H92!N97AT('!A9V4@;&]A9"X*6V-J:%T@1FEX(&5S8V%P:6YG
M(&]F(&1A=&$@:6X@=&AE('!R969E<F5N8V5S('1E;7!L871E<RX*6V-J:%T@
M1FEX(&5S8V%P:6YG(&]F(&1A=&$@:6X@=&AE(&1A=&$@:6UP;W)T('1E;7!L
M871E<RX*6V-J:%T@1FEX(&]U='!U="!E<V-A<&EN9R!O9B!(;W)D95]&;W)M
M7U1Y<&5?8V5L;'!H;VYE(&EN(%5)7U9A<E)E;F1E<F5R7VAT;6PN"EMC:FA=
M($-L;W-E('-E=F5R86P@6%-3('!R;V)L96US(&EN('1H92!S:&%R92!E9&ET
M('=I;F1O=RX*6VIA;ET@1FEX('=E871H97(N8V]M('!O<G1A;"!B;&]C:RX*
M"@HM+2TM+2T*=C,N,"XW"BTM+2TM+0H*6VIA;ET@1FEX(%A34R!V=6QN97)A
M8FEL:71I97,@:6X@9WII<"]T87(@86YD(&-S<R!-24U%('9I97=E<G,N"EMC
M:FA=($%D9"!M:7-S:6YG($-/34U)5"!I;B!->5-13"!397-S:6]N2&%N9&QE
M<B!D<FEV97(*("`@("`@*&1G96AL0&EN=F5R<V4N8V$L($)U9R`C,C<S,2DN
M"@H*+2TM+2TM"G8S+C`N-@HM+2TM+2T*"EMJ86Y=(%!A<W,@86QL(%523"!P
M87)A;65T97)S('=H97)E(&QI;FMI;F<@96UA:6P@861D<F5S<V5S("A297%U
M97-T(",Q-3,P*2X*6VIA;ET@4VAO=R!7;W)D('9I97=E<B!C;VYT96YT('=I
M=&@@8V]R<F5C="!C:&%R<V5T("AS9W)O;F1I;D!C<V)F+G%C+F-A+`H@("`@
M("!"=6<@(S(W,S<I+@H*"BTM+2TM+2TM+2T*=C,N,"XV+5)#,0HM+2TM+2TM
M+2TM"@I;8VIH72!&:7@@=')A;G-A8W1I;VYS(&%N9"!B:6YA<GD@9&%T82!I
M;B!0;W-T9W)E4U%,('-E<W-I;VX@:&%N9&QE<@H@("`@("`H8V)S0&-T<RYU
M8VQA+F5D=2P@0G5G(",R-S0Y+"`C,C<X.2DN"EMJ86Y=($9I>"!S:61E8F%R
M(&UE;G4@;&%Y;W5T(&9O<B!/<&5R82`H0G5G(",R-S(R*2X*6V-J:%T@061D
M(#QP<F4^('1O('-U<'!O<G1E9"!H96QP('1A9W,@*'9I:F%Y+FUA:')R84!E
M<RYE87-Y;F5T+FYE="P*("`@("`@0G5G(",R-C,S*2X*6V-J:%T@1FEX('9A
M;&ED871I;VX@;VX@:7!A9&1R97-S($AO<F1E7T9O<FT@9FEE;&1S("A"=6<@
M(S(U.#,I+@I;8VIH72!!9&0@075T:#HZ9V5T075T:$1O;6%I;B@I("A"=6<@
M(S(U-S,I+@I;;6IR72!!9&0@86)I;&ET>2!T;R!E;F%B;&4O9&ES86)L92!)
M35-0(&=L;V)A;&QY('9I82!C;VYF:6=U<F%T:6]N('-E='1I;F=S+@I;:F%N
M72!&:7@@8V%L96YD87(@<&]P=7`@=VET:"!3869A<FD@8G)O=W-E<G,@*'0N
M>F5L;$!G;7@N9&4L($)U9R`C,C0T."DN"EMC:FA=(%=H96X@=7-I;F<@0T=)
M(%!(4"P@4T-225!47TY!344@;6%Y(&-O;G1A:6X@=&AE('!A=&@@=&\@=&AE
M(%!(4"!B:6YA<GD*("`@("`@:6YS=&5A9"!O9B!T:&4@<V-R:7!T(&)E:6YG
M(')U;CL@=7-E(%!(4%]314Q&(&EN<W1E860@*$)U9R`C,C0P,2DN"EMJ86Y=
M($9I>"!S:&%R:6YG('=I=&@@9W)O=7!S(&EF('5S:6YG(&=R;W5P(&AO;VMS
M("A"=6<@(S(R.3(I+@H*"BTM+2TM+0IV,RXP+C4*+2TM+2TM"@I;;6US72!&
M:7@@5D93)W,@875T;V-R96%T95!A=&@H*2!F;W(@9&ER96-T;W)Y('!A=&AS
M(&-O;G1A:6YI;F<@=&AE(')O;W0*("`@("`@9&ER96-T;W)Y+@I;:F%N72!&
M:7@@8WER<W%L(&%U=&AE;G1I8V%T:6]N(&1R:79E<B!W:71H('5N:7AH:65R
M87)C:'ES97`@96YA8FQE9`H@("`@("`H<V=R;VYD:6Y`8W-B9BYQ8RYC82P@
M0G5G(",R,S8W*2X*6VUM<UT@1FEX(&YE<W1E9"!)34%0($%.1"!S96%R8VAE
M<RX*6VUM<UT@26X@<W%L(%9&4R!D<FEV97(L(&%L;&]W('1H92!U<V4@;V8@
M)R\G(&%T('1H92!B96=I;FYI;F<@;V8@82!P871H('1O"B`@("`@(&EN9&EC
M871E('1H92!B87-E(&1I<F5C=&]R>2X*6VIA;ET@1FEX(')E='5R;FEN9R!T
M;R!L87-T('!A9V4@869T97(@<V5N9&EN9R!P<F]B;&5M(')E<&]R="`H0G5G
M(",R,S4P*2X*6VUM<UT@1FEX(&$@8G5G('1H870@8V%U<V5D(&AO;VL@8V]D
M92!T;R!B92!R=6X@=6YN96-E<W-A<FEL>2!A9G1E<B!A('5S97(*("`@("`@
M:7,@86QR96%D>2!L;V=G960@:6XN"@H*+2TM+2TM+2TM+0IV,RXP+C4M4D,R
M"BTM+2TM+2TM+2T*"EMC:FA=($9I>"!A(&9A<BUR96%C:&EN9R!$871A5')E
M92!B=6<@:6X@;&]A9&EN9R!P87)E;G0@:61S("A"=6<@(S(R,#,I+@H*"BTM
M+2TM+2TM+2T*=C,N,"XU+5)#,0HM+2TM+2TM+2TM"@I;:F%N72!!9&0@0F]S
M;FEA;B!T<F%N<VQA=&EO;B`H5F5D<F%N($QJ=6)O=FEC(#QV;&IU8F]V:6-`
M<VUA<G1N970N8F$^*2X*6V-J:%T@3&5T($AO<F1E7U1R964@:&%N9&QE(&%L
M;"!I;F1E;G0@8V%L8W5L871I;VX@8F%S960@;VX@<&%R96YT+V-H:6QD"B`@
M("`@(')E;&%T:6]N<VAI<',@*$)U9R`C,C$Y."DN"EMC:FA=($%D9"!I;FET
M:6%L($Q$05`@4V5S<VEO;DAA;F1L97(@9')I=F5R+@I;8VIH72!5<V4@<F]W
M+6QE=F5L(&QO8VMI;F<@;W(@=')A;G-A8W1I;VYS('=H97)E('!O<W-I8FQE
M('1O(&%V;VED"B`@("`@('-E<W-I;VX@8V]R<G5P=&EO;B!I;B!397-S:6]N
M2&%N9&QE<B`H0G5G(",Q-3@P*2X*6VUM<UT@061D('1H92!M96UC86-H960@
M4V5S<VEO;DAA;F1L97(Z.B!D<FEV97(@*%)O;F<M16X@1F%N(#QR869A;D!C
M<VEE+F]R9SXI+@I;;6US72!&:7@@=F5R:69I8V%T:6]N(&]F($U)344@<W1R
M:6YG<R!W:71H(&5S8V%P960@<75O=&5S("A"=6<@(S(Q-C@I+@I;:F%N72!&
M:7@@9V5N97)A=&EO;B!O9B!F<F5E('!E<FEO9',@:6X@9G)E92]B=7-Y(&-O
M9&4@=VET:"!O=F5R;&%P<&EN9R!E=F5N=',N"EMJ86Y=($1O;B=T('-H;W<@
M3W!T:6]N<R!B=71T;VX@:6X@<')O8FQE;2!R97!O<G1I;F<@<&%G92X*6VIA
M;ET@061D(%5T:6PZ.G)E86Q0871H*"D@;65T:&]D+@I;;6%S72!);F-L=61E
M('9E<G-I;VX@;G5M8F5R<R!F;W(@87!P;&EC871I;VYS(&]N($%D;6EN(%-E
M='5P('-C<F5E;BX@*$)U9PH@("`@("`C,30R,"D*6VUA<UT@0VAA;F=E($E-
M05`@075T:"!D<FEV97(@=&\@=7-E(&EM87`O;F]T;',@8GD@9&5F875L="!I
M;B!N;VXM1%-.(&UO9&4@=&\*("`@("`@;6%T8V@@1%-.(&UO9&4N"EMM87-=
M($%D9"!T;',@86YD('-E;&8M<VEG;F5D(&-E<G1I9FEC871E(&-O;F9I9W5R
M871I;VX@;W!T:6]N<R!T;R!)34%0($%U=&@*("`@("`@9')I=F5R+B`H0G5G
M(",Q,S4W*0I;8VIH72!296-O9VYI>F4@3W!E<F$@."L@87,@<')O=FED:6YG
M(&%D=F%N8V5D(&9E871U<F5S("A"=6<@(S(P-C8I+@I;8VIH72!&:7@@<F5A
M9&EN9R!O9B!B:6YA<GD@9FEL97,@;VX@5VEN9&]W<R!I;B!60U]S=FX@*$)U
M9R`C,C`S-BDN"EMM87-=($9I>"!344P@)TQ)2T4G(&-A<V4M:6YS96YS:71I
M=F4@8V]M<&%R:7-O;BX@*$)U9R`C,C`S,"D*6VIA;ET@06QL;W<@8VAA<G-E
M="!A=V%R92!)34%0('-E87)C:&5S+@I;:F%N72!&:7@@1V]O9VQE('-E87)C
M:"!B;&]C:R!F;W(@;F]N+6%S8VEI(&-H87)A8W1E<G,@*$)U9R`C,3,R.2DN
M"EMJ86Y=($%D9"!Q=6EC:RUI;G-T86QL(&EN<W1R=6-T:6]N<RX*6VIA;ET@
M26UP<F]V92!P97)F;W)M86YC92!O9B!S979E<F%L(&9R86UE=V]R:R!P86-K
M86=E<RX*6VUM<UT@1FEX($U)345?0V]N=&5N=',Z.B!C86-H:6YG(&EN(%!(
M4"`U("A"=6<@(S$T,3`I+@I;:F%N72!&:7@@5D,@4U9.(&)A8VME;F0@=&\@
M<W5P<&]R="!U<V5R(&YA;65S('=I=&@@<W!A8V5S"B`@("`@("AS:&EM;6%N
M;FEN9T!G;6%I;"YC;VTL($)U9R`C,3DQ.2DN"EMC:FA=($5S8V%P92!(5$U,
M(&EN(&ED96YT:71Y(&YA;65S("A"=6<@(S$Y,3`I+@I;;6%S72!5<V4@=7!D
M871E9"!0;W-T9W)E4U%,(&9U;F-T:6]N(&YA;65S+@I;8F5N72!5<&1A=&4@
M87!P;&EC871I;VX@;&ES="!I;B!H;W)D92=S($Q$05`@<V-H96UA"EMC:FA=
M($5N9F]R8V4@;6%X;&5N9W1H(')E<W1R:6-T:6]N<R!I;B!(;W)D95]&;W)M
M('9A;&ED871I;VX@*$)U9R`C,3@Y-2DN"EMJ86Y=($1I<V%B;&4@=V5A=&AE
M<BYC;VT@0FQO8VL@:68@;F]T(&-O;F9I9W5R960N"EMC:FA=($EN8VQU9&4@
M<V]U<F-E<F]O="!I;B!60R!C86-H92!K97ES("A"=6<@(S$W.#,I+@I;:F%N
M72!!9&0@4U%,('-C<FEP="!A;F0@:6YS=')U8W1I;VYS(&9O<B!-4T1%(&1A
M=&%B87-E<R`H0G5G<R`C,3@V,BP@(S$X-S`L"B`@("`@(&IE9F9`:6UA9V4M
M<W)C+F-O;2DN"EMJ86Y=($%L;&]W('!O<G1A;"!B;&]C:W,@=&\@8F4@;&%R
M9V5R('1H86X@='=O(&-O;'5M;B]R;W=S("A"=6=S(",Q,3@Y+"`Q-C,R*2X*
M6VIA;ET@061D(%--5%`@875T:&5N=&EC871I;VX@=&\@<')O8FQE;2!R97!O
M<G1I;F<@*$)U9R`C,3$R."DN"EMJ86Y=(%-U<'!O<G0@:&5L<"!F:6QE<R!I
M;B!A9&UI;B!D:7)E8W1O<GD@=VET:"!T<F%N<VQA=&EO;G,N<&AP("A"=6<@
M(S$S-#0I+@I;:F%N72!&:7AE9"!344P@8FEN9&EN9R!F;W(@3T1"0R!A;F0@
M35-344P@9')I=F5R<R`H0G5G(",Q.#$V*2X*6VIA;ET@061D(&-O;F9I9W5R
M871I;VX@;W!T:6]N('1O('-E="!L;V-A=&EO;B!O9B!-24U%(&UA9VEC(&1A
M=&%B87-E+@I;;6US72!-86ME('-U<F4@:&5A9&5R<R!I;B!A($U)345?4&%R
M="!A<F4@96YC;V1E9"!W:71H('1H92!S86UE(&-H87)A8W1E<@H@("`@("!S
M970@=7-E9"!I;B!T:&%T($U)345?4&%R="`H0G5G(",Q-3DQ*2X*6VUM<UT@
M061D($QI<W0M2&5A9&5R<R!L:7-T960@:6X@4D9#(#(S-CD@=&\@=&AE(&QI
M<W0@;V8@34E-12!(96%D97)S('1H870*("`@("`@8V%N(&]N;'D@87!P96%R
M(&]N8V4@:6X@82!S:6YG;&4@:&5A9&5R("A"=6<@(S$W-C8I+@I;8VIH72!&
M:7@@='EP;R!I;B!P87)S:6YG(&]F($92145"55-9(&1A=&$@*$)U9R`C,34Y
M,"DN"EMJ86Y=(%-U<'!O<G0@4U%,:71E(&%N9"!/<F%C;&4@:6X@86QL(%-1
M3"!B86-K96YD(&-O;F9I9W5R871I;VYS+@I;8VIH72!5<V4@8FEN9"!V87)I
M86)L97,@:6X@=&AE($%U=&@L(%9&4RP@86YD(%-E<W-I;VY(86YD;&5R(%-1
M3"!D<FEV97)S+`H@("`@("!A;F0@:6X@<V-R:7!T<R]R96UO=F5?<')E9G,N
M<&AP("AS96QS:WE`8V]L=6UB:6$N961U+"!"=6=S(",Q-C8U+`H@("`@("`C
M,38V-BP@(S$V-C<L(",Q-C8X+"`C,38W-RDN"EMC:FA=('-E<W-I;VY?<V5T
M7V-O;VMI95]P87)A;7,H*2!E>'!E8W1S(&$@<F5L871I=F4@=&EM96]U=#L@
M<V5T8V]O:VEE('=A;G1S"B`@("`@(&%B<V]L=71E+B!';R!B86-K('1O(&$@
M8V]N9FEG:6YT96=E<B!F;W(@)&-O;F9;)W-E<W-I;VXG75LG=&EM96]U="==
M(&%N9`H@("`@("!A9&0@=&EM92@I('1O('1H870@=F%L=64@:6X@<V5T8V]O
M:VEE*"D@8V%L;',@*$)U9W,@(S$S,#(L(",Q-C4X*2X*("`@("`@5$A)4R!-
M05D@0E)%04L@0T].1DE'55)!5$E/3E,@4T54(%1/(%5312!02%`@0T]$12X@
M34%+12!355)%(%1/(%501$%410H@("`@("!93U52("1C;VYF6R=S97-S:6]N
M)UU;)W1I;65O=70G72!3151424Y'($%&5$52(%501U)!1$E.1RX*6V-J:%T@
M57-E(&)I;F0@=F%R:6%B;&5S(&EN('1H92!0<F5F<R!A;F0@5&]K96X@4U%,
M(&1R:79E<G,*("`@("`@*'-E;'-K>4!C;VQU;6)I82YE9'4L($)U9W,@(S$V
M-3(L(",Q-C4S*2X*6VUM<UT@4')U;F4@97AP86YD960@9F]L9&5R<R!T:&%T
M(&YO(&QO;F=E<B!E>&ES="!I;B!)34%07U1R964@*$)U9R`C,34Q-RDN"EMC
M:FA=($1O;B=T('1R>2!T;R!C;VUP<F5S<R!O=71P=70@:68@6E!3(&-O;7!R
M97-S:6]N(&ES(&]N("A"=6<@(S$V,C8I+@I;8VIH72!)9B!A;B!A<'`@;VYL
M>2!H87,@;VYE('!R969'<F]U<"P@86QW87ES('-H;W<@=&AA="!P<F5F1W)O
M=7`@:6YS=&5A9`H@("`@("!O9B!S:&]W:6YG(&%N(&]V97)V:65W('-C<F5E
M;B!W:71H(&]N;'D@;VYE(&5N=')Y+@H*"BTM+2TM+0IV,RXP+C0*+2TM+2TM
M"@I;8VIH72!5<V4@9G5L;'D@<75A;&EF:65D(%523',@:6X@=&AE($%N<V5L
M26UA9V4@2%1-3$%R96$@<&QU9VEN("A"=6<@(S$R-3DI+@I;8VIH72!#;&]S
M92!84U,@=VAE;B!S971T:6YG('1H92!P87)E;G0@9G)A;64G<R!P86=E('1I
M=&QE(&)Y(&IA=F%S8W)I<'0N"EMB;&-=($%D9"!0;W-T9W)E4U%,('5P9W)A
M9&4@<V-R:7!T("A"<F%D(%=I='1E(#QB<F%D0&1I<W1A;G1H87IE+F-O;2D*
M6V-J:%T@079O:60@9&EV:7-I;VX@8GD@>F5R;R!I9B!A;&P@<')E9F5R96YC
M97,@87)E(&QO8VME9"`H0G5G(",Q-C(W*2X*6VIA;ET@1FEX('-I9&5B87(@
M<F5F<F5S:&EN9R!W:71H($]P97)A+@H*"BTM+2TM+2TM+2T*=C,N,"XT+5)#
M,@HM+2TM+2TM+2TM"@I;:F%N72!);7!R;W9E(")L;V=I;B(@875T:&5N=&EC
M871I;VX@9')I=F5R("A"=6<@(S$U-S$I+@I;:F%N72!3:&]W(&1A=&%B87-E
M('-P96-I9FEC(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!I;B!G;&]B86P@4U%,
M(&-O;F9I9W5R871I;VX*("`@("`@=&]O+@I;:F%N72!&:7@@;&5F="!M96YU
M(&]V97)F;&]W(&EN($E%(&%N9"!3869A<FD@*$)U9R`C,34R-BDN"EMJ86Y=
M($9I>"!A=71O8W)E871I;F<@;V8@9&ER96-T;W)I97,@86YD('5P9&%T:6YG
M(&]F(&5X:7-T:6YG(&9I;&5S(&EN('1H90H@("`@("!S<6Q?9FEL92!61E,@
M9')I=F5R("AE9&1I94!O;65G87=A<F4N8V]M+"!"=6=S(",Q-34R(&%N9"`C
M,34U,RDN"EMJ86Y=($UA:V4@=W)A<'!I;F<@;65N=7,@=FES:6)L92!W:71H
M($=E8VMO(#$N-"!B<F]W<V5R<R`H92YG+B!.971S8V%P92`W+C$I+@I;:F%N
M72!5<V4@4U%,(&)I;F1I;F<@9F]R('-O;64@1&%T851R964@;W!E<F%T:6]N
M<RX*6VIA;ET@1FEX($1A=&%4<F5E(%-13"!S=7!P;W)T(&9O<B!/<F%C;&4N
M"EMJ86Y=($9I>"!344P@8V]N9FEG=7)A=&EO;B!F;W(@3W)A8VQE+@I;;6US
M72!-86ME('-U<F4@5D93(&=A<F)A9V4@8V]L;&5C=&EO;B!I<R!D;VYE(')E
M8W5R<VEV96QY+@H*"BTM+2TM+2TM+2T*=C,N,"XT+5)#,0HM+2TM+2TM+2TM
M"@I;:F%N72!!9&0@2&]R9&5?5')E95]S96QE8W0@8VQA<W,@*$)E;B!#:&%V
M970@/&)E;D!H;W)D92YO<F<^*2X*6VUJ<ET@1FEX($YE=%])35-0('1O('!R
M;W!E<FQY(&AA;F1L92!M=6QT:7!L92!L:6YE<R!I;B!A9&1R97-S8F]O:R!F
M:65L9',N"EMJ86Y=($9I>"!-24U%(&1E8V]D:6YG(&]F('-T<FEN9W,@=&AA
M="!C;VYT86EN("(E(B!I;B!M=6QT:6)Y=&4@<V5Q=65N8V5S"B`@("`@("A"
M=6<@(S$T,C,I+@I;8VIH72!#;VYT<F]L('-P86-E('5N9&5R('1H92!M96YU
M(&)A<B!W:71H(&$@=&AE;65A8FQE('-T>6QE("A"=6<@(S$T,C$I+@I;8VIH
M72!&:7@@2&]R9&5?5')E92!W:71H('1H92!M=6QT:6QI;F4@;W!T:6]N('-O
M('1H870@<F]W('-T>6QE<R!E>'1E;F0@;W9E<@H@("`@("!T:&4@=VAO;&4@
M:&5I9VAT(&]F('1H92!R;W<N"EMC:FA=($EF(&-O;F9I9W5R871I;VX@9FEL
M97,@=&AA="!H879E(&$@+F1I<W0@=F5R<VEO;B!A<F4@;6ES<VEN9RP*("`@
M("`@2&]R9&5?5&5S=#HZ8V]N9FEG1FEL97--:7-S:6YG*"D@=VEL;"!C;W!Y
M('1H92!D969A=6QT<R!O=F5R(&EF($AO<F1E"B`@("`@(&-A;B!W<FET92!T
M;R!T:&4@9FEL97-Y<W1E;2`H0G5G(",Q,#$U*2X*6V-J:%T@1FEX($%N<V5L
M26UA9V4@2%1-3$%R96$@<&QU9VEN("A"=6<@(S$T-S`I+@I;8VIH72!*=7-T
M(')E=')I979E('5I9"!W:&5N(&QI<W1I;F<@=7-E<G,@:6X@=&AE($Q$05`@
M075T:&5N=&EC871I;VX@9')I=F5R+@I;8VIH72!!9&0@8VAO<F%0<F5F<R!T
M;R!T:&4@:&]R9&5097)S;VX@3$1!4"!S8VAE;6$@*$)U9R`C,30U,BDN"EMC
M:FA=("=R;V]T9&XG(&ES(&YO="!R97%U:7)E9"!F;W(@3$1!4"!P<F5F97)E
M;F-E<R`H0G5G(",Q-#4S*2X*6VUM<UT@1FEX($E-05`@=&AR96%D(&-R96%T
M:6]N('=H96X@=&AE(&)A<V4@;&5V96P@8V]N=&%I;G,@;6]R92!T:&%N(&]N
M90H@("`@("!M97-S86=E+@I;:F%N72!!;&QO=R!V0V%R9',@=VET:"!L;W=E
M<F-A<V4@9FEE;&0@9&5S8W)I<'1O<G,N"EMJ86Y=($EM<')O=F4@=&%R+V=Z
M:7`@34E-12!V:65W97(@=&\@8F5T=&5R('-H;W<@=6YZ:7!P960@8V]N=&5N
M="X*6VUJ<ET@0F5T=&5R(&5R<F]R(&AA;F1L:6YG(&EN($YE=%])35-0+@I;
M;6US72!3<&5E9"!I;7!R;W9E;65N=',@86YD('-O<G1I;F<@9FEX97,@9F]R
M($E-05!?5')E92X*6VUM<UT@24U!4%]4<F5E(&YO=R!H86YD;&5S(&YO;BUU
M<'!E<F-A<V5D("=)3D)/6"<@<W1R:6YG<R!R971U<FYE9"!F<F]M('1H90H@
M("`@("!M86EL('-E<G9E<B`H0G5G(",Q.3DI+@I;;6US72!296)U:6QD(&-E
M<G1A:6X@:6YT97)N86P@34E-15]087)T(&1A=&$@=VAE;B!R971R:65V:6YG
M(&9R;VT@82!C86-H92X*6VIA;ET@4VAO=R!D871A8F%S92!S<&5C:69I8R!C
M;VYN96-T:6]N('!A<F%M971E<G,@:6X@8V]N9FEG=7)A=&EO;B!S8W)E96XN
M"EMM;7-=($E-05!?5')E92!N;W<@8V]R<F5C=&QY('5P9&%T960@=VAE;B!S
M=6)S8W)I8FEN9R]U;G-U8G-C<FEB:6YG(&9R;VT@80H@("`@("!M86EL8F]X
M("A"=6<@(S$Q,3$I+@I;;6US72!-86ME($E-05`@<V5A<F-H97,@;V8@;F]N
M+2)S=&%N9&%R9"(@:&5A9&5R<R!W;W)K('=I=&@@=&AE($Y/5"!D:7)E8W1I
M=F4*("`@("`@*$)U9R`C,3,V."DN"EMJ86Y=($9I>&5D(&1O=6)L92!L:6YE
M(&YU;6)E<G,@:6X@4V]U<F-E+6AI9VAL:6=H="!-24U%('9I97=E<B`H0G5G
M(",Q,S@S*2X*6VUM<UT@1FEX($E-05!?5&AR96%D('=H96X@9&5A;&EN9R!W
M:71H('1H92!F:7)S="!M97-S86=E(&EN('1H92!M86EL8F]X"B`@("`@("A"
M=6<@(S$R-3<I+@I;8VIH72!&:7@@;65N=2!H96EG:'1S(&EN(%-A9F%R:2X*
M6VIA;ET@0V%T8V@@97)R;W)S(&9R;VT@8V]N9FEG=7)A=&EO;B!F:6QE<R!T
M;R!A=F]I9"!B;&%N:R!P86=E<RX*6VIA;ET@4W5P<&]R="!M:6UE7VUA9VEC
M(&5X=&5N<VEO;B!A9V%I;B!I9B!F:6QE:6YF;R!I<R!N;W0@<')E<V5N="X*
M"@HM+2TM+2T*=C,N,"XS"BTM+2TM+0H*6VUJ<ET@3F5T7TE-4U`@;F]W(&-O
M<G)E8W1L>2!H86YD;&5S(&%D9')E<W-B;V]K(&YA;65S(&-O;G1A:6YI;F<@
M<W!A8V5S"B`@("`@("A"=6<@(S$R.#8I+@I;8VIH72!);7!L96UE;G0@8VQE
M87(H*2!I;B!T:&4@3$1!4"!P<F5F<R!D<FEV97(@*$)U9R`C,3,S-2DN"EMC
M:FA=($1O;B=T(&QI<W0@=6YI;G-T86QL960@87!P;&EC871I;VYS(&%S(&EN
M:71I86Q?87!P;&EC871I;VX@;W!T:6]N<PH@("`@("`H0G5G(",Q,S(T*2X*
M6VIA;ET@1FEX('!O<W1A=71H96YT:6-A=&4@:&]O:RP@;F]T(&-O;7!L971E
M;'D@9&5N>6EN9R!A8V-E<W,@869T97(@82!F86EL960*("`@("`@;&]G:6X@
M*$)U9R`C,3,R,"DN"EMJ86Y=($-H96-K8F]X97,@:6X@<&]R=&%L(&)L;V-K
M('-E='5P(&9O<FUS(&%R92!C;W)R96-T;'D@8VAE8VME9"!N;W<*("`@("`@
M*$)U9R`C,3(T-RDN"EMM;7-=($%L;&]W($E-05`@<V5A<F-H97,@=&\@=V]R
M:R!O;B!H96%D97)S('=I=&@@;75L=&EP;&4@96YT<FEE<PH@("`@("`H:V]L
M8D!B:71L86(N:'4I("A"=6<@(S$S,S`I+@I;;6US72!#;W)R96-T;'D@<V]R
M="!)3D)/6"!S=6)F;VQD97)S(&EN($E-05!?4V]R="`H0G5G(",Q,CDQ*2X*
M6V-J:%T@5'5R;B!O9F8@1F]R;2!4;VME;G,@:6X@=&AE(&-O;F9I9W5R871I
M;VX@:6YT97)F86-E+@I;:F%N72!3;W)T('5S97(@86YD(&=R;W5P(&QI<W1S
M(&EN('!E<FUI<W-I;VYS(&EN=&5R9F%C92`H0G5G(",Q,S`U*2X*6VIA;ET@
M06QL;W<@=&\@96YT97(@4$A0(&-O9&4@:6X@=&AE('-E<W-I;VX@=&EM96]U
M="!C;VYF:6=U<F%T:6]N("A"=6<@(S$S,#(I+@H*"BTM+2TM+2TM+2T*=C,N
M,"XS+5)#,0HM+2TM+2TM+2TM"@I;;6US72!&:7@@8G5G(&EN(%1E>'1?1FQO
M=V5D('=H97)E('5N<75O=&5D(&QI;F5S(&-O=6QD(&YO="!B92!F;&]W960N
M"EMC:FA=($9I>"!L;V=I8R!P<F]B;&5M<R!W:71H('1H92!->5-13"!A;F0@
M3T-)."!S97-S:6]N(&AA;F1L97)S('1H870*("`@("`@<')E=F5N=&5D('1H
M96T@9G)O;2!H86YD;&EN9R!R97-T87)T:6YG(&$@<V5S<VEO;B!C;&5A;FQY
M("A"=6<@(S$P.3<I+@I;8VIH72!&:7@@<&5R<VES=&5N8V4@;V8@)&-O;F9;
M)VUA:6QE<B==6R=P87)A;7,G75LG875T:"==(&EN('1H92!3971U<"!520H@
M("`@("`H0G5G(",Q,C@W*2X*6VIA;ET@26UP<F]V92!P97)F;W)M86YC92!O
M9B!$871A5')E92!O<&5R871I;VYS(&QI:V4@<F5A9&EN9R!E;6%I;"!M97-S
M86=E"B`@("`@(&AI<W1O<FEE<RX*6VIA;ET@3&]G('-U8V-E<W-F=6P@;&]G
M:6YS(&%N9"!L;V=O=71S('=I=&@@=&AE($Y/5$E#12!L979E;"`H5FEL:75S
M(%-U;7-K87,*("`@("`@/'9I;&EU<T!L;FLN;'0^*2X*6V-J:%T@16YC;V1E
M($A434P@96YT:71I97,@:6X@2&]R9&5?1F]R;5]4>7!E7VQO;F=T97AT(&1I
M<W!L87D@*$)U9R`C,3(V-RDN"EMM;7-=($9I>"!S97-S:6]N(&AA;F1L:6YG
M('1O(&5N<W5R92!V87)I86)L97,@87)E('!E<G-I<W1E;G0@86-R;W-S(&9U
M;F-T:6]N"B`@("`@(&-A;&QS("A'87)Y(%=I;F1H86T@/'=I;F1H86UG0&5M
M86EL+F%R:7IO;F$N961U/BDN"EMM;7-=($EM<')O=F5M96YT<R!T;R!796)#
M4%`@34E-15]6:65W97(@<F5N9&5R960@;W5T<'5T+@I;;6US72!-;W)E(&9I
M>&5S(&9O<B!54DQS('=I=&@@)R9A;7`G('=H96X@<&%S<VEN9R!T:')O=6=H
M('1H92!S86YI=&EZ97(N"EMJ86Y=($UA:V4@=W)A<'!I;F<@;65N=7,@;&]O
M:VEN9R!N:6-E<B!I;B!'96-K;R!A;F0@2TA434P@8F%S960@8G)O=W-E<G,N
M"EMJ86Y=($9I>"!-24U%('9I97=E<B!F;W(@9WII<"!F:6QE<R!T:&%T(&1O
M;B=T(&-O;G1A:6X@=&%R(&9I;&5S+@I;8VIH72!&:7@@=FES:6)I;&ET>2!O
M9B`\82`^('1A9W,@:6YS:61E('-M86QL:&5A9&5R(&)L;V-K<R!F;W(@=&AE
M($-O<FYF;&]W97(*("`@("`@=&AE;64@*$)U9R`C,3(P-BDN"EMC:FA=($1O
M(&YO="!C86-H92!J879A<V-R:7!T('-E<G9E9"!V:6$@<V5R=FEC97,O:F%V
M87-C<FEP="YP:'`@*$)U9R`C,3$T,"DN"EMC:FA=($9I>"!M86YA9V5M96YT
M(&]F(&-A=&5G;W)I97,@=&AA="!C;VYT86EN('%U;W1E<R`H0G5G(",Q,C`R
M*2X*6V-J:%T@2&%N9&QE(&%D9')E<W-E<R!T:&%T(&%R92!A;')E861Y('-U
M<G)O=6YD960@8GD@<75O=&5S(&EN"B`@("`@($U)344Z.E]R9F,X,C)%;F-O
M9&4H*2`H0G5G(",Q,30S*2X*6V-J:%T@1FEX(%9#7W-V;B=S(&AA;F1L:6YG
M(&]F(&1I<F5C=&]R>2!N86UE<R!W:71H('-P86-E<R`H0G5G(",Q,3(S*2X*
M6V-J:%T@1FEX(&-A8VAI;F<@;&]G:6,@=&AA="!W87,@8V%U<VEN9R!60R!T
M;R!N;W0@<')O<&5R;'D@<F5F<F5S:"!O8FIE8W1S(&EN"B`@("`@(&$@=&EM
M96QY(&UA;FYE<BX*6VIA;ET@06QL;W<@=&\@<V5T(&9I>&5D('1A8FQE(&-E
M;&P@=VED=&AS(&EN(%=94TE764<@961I=&]R+@H*"BTM+2TM+0IV,RXP+C(*
M+2TM+2TM"@I;8VIH72!-86ME('-U<F4@;F]T('1O('1H<F]W(&5R<F]R<R!W
M:&5N(&)A9"!E;6%I;',@87)E('-U<'!L:65D(&EN"B`@("`@('-E<G9I8V5S
M+W!R;V)L96TN<&AP("A"=6<@(S$P-S`I+@I;:F%N72!&:7@@=W)O;F<@8VAA
M<G-E="!O9B!R969R97-H960@;65N=2!F<F%M92!I9B!N;W0@=7-I;F<@551&
M+3@@*$)U9W,*("`@("`@(S$P-3(L(",Q,#4U*2X*6VIA;ET@1FEX(&QE9G0@
M;65N=2!T<F5E(&-O;&QA<'-I;F<@869T97(@96%C:"!R969R97-H("A"=6<@
M(S$P-S(I+@I;:F%N72!&:7@@<VED96)A<B!B96EN9R!L;V%D960@='=I8V4@
M:68@;F]T('5S:6YG(&-O;VMI97,@*$)U9R`C,3`W-BDN"@H*+2TM+2TM"G8S
M+C`N,0HM+2TM+2T*"EMJ86Y=(%1E<W0@9F]R('-E<W-I;VXN875T;U]S=&%R
M="X*6VUM<UT@1FEX('!A<G-I;F<@;V8@:&5A9&5R('=I=&@@=6YD:7-C;&]S
M960M<F5C:7!I96YT<R`H0G5G(",Q,#4W*2X*6V-J:%T@061D(&$@8G)O=W-E
M<B!Q=6ER:R!F;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&]V97)F
M;&]W.FAI9&1E;B!I;@H@("`@("!T86)L92!C96QL<R`H2TA434PI+@I;:F%N
M72!&:7@@87!P;&EC871I;VX@;&EN:W,@:68@;F]T('5S:6YG(&-O;VMI97,@
M*$)U9R`C,3`R.2DN"EMM;7-=($9I>"!D:7-A8FQI;F<@;V8@;6%I;G1E;F%N
M8V4@8V]N9FER;6%T:6]N<R`H0G5G(",Q,#(W*2X*6V-J:%T@1FEX(&%L:6=N
M;65N="!O9B!(96QP('=I;F1O=R!H96%D97(@:6X@35-)12`H0G5G(",Q,#(S
M*2X*6V-J:%T@1FEX('1H92!(;W)D95]";&]C:R!G<F%P:&EC<R!T;R!B92!I
M;F1E>&5D+"!N;W0@9W)A>7-C86QE("A"=6<@(S$P-3$I+@I;8VIH72!#;&]S
M92!S979E<F%L(%A34R!V=6QN97)A8FEL:71I97,N"EMM;7-=($UA:V4@<W5R
M92!E>'1E<FYA;"!54DPG<R!W;W)K(&-O<G)E8W1L>2!W:&5N('1H92!54DP@
M8V]N=&%I;G,@)R9A;7`G(&%S"B`@("`@('1H92!D96QI;6ET97(N"EMC:FA=
M($9I>"!I;F9I;FET92!L;V]P('=I=&@@075T:%]A<'!L:6-A=&EO;B!D<FEV
M97(@*$)U9R`C,3`P-"DN"EMC:FA=($YE=F5R('-E="!A;B!E;7!T>2!(;W)D
M95]4<F5E(&-O;VMI92`H0G5G(",Q,#(R*2X*6VUM<UT@1FEX(&1I<W!L87EI
M;F<@;V8@9F]L9&5R<R!I;B!)34%07U1R964Z.B!F;W(@24U!4"!S97)V97)S
M('1H870@9&]N)W0@=7-E"B`@("`@("=)3D)/6"<@87,@=&AE:7(@9&5L:6UI
M=&5R("A"=6<@(S$P,30I+@I;8VIH72!(3U)$15]-14Y57TU!4TM?3D].12!N
M;W<@<F5A;&QY(&UE86YS(&]N;'D@97AP;&EC:71L>2!A9&1E9"!M96YU(&ET
M96US"B`@("`@(&%R92!D:7-P;&%Y960N"EMC:FA=($EG;F]R92!(,R!I;B!V
M97)S:6]N(&-O;7!A<FES;VYS("A"=6<@(S$P,3<I+@I;8VIH72!$871A5')E
M95]N=6QL(&YO=R!S='5B<R!O=70@=&AE(&9U;&P@1&%T851R964@05!)('1O
M(&%V;VED(&9A=&%L(&5R<F]R<PH@("`@("!W:&5N(&YO="!U<VEN9R!A('!E
M<FUA;F5N="!B86-K96YD+@I;:F%N72!&:7@@9&5L971I;F<@;V8@:61E;G1I
M=&EE<R`H0G5G(",Q,#$X*2X*"@HM+2TM"G8S+C`*+2TM+0H*6V-J:%T@5')Y
M('1O(&-A=&-H(&1A;F=E<F]U<R!54DQS(&EN('1H92!D97)E9F5R<F5R("AG
M;RYP:'`I+@I;8VIH72!);7!R;W9E('1R964@9W)A<&AI8W,@9F]R(')I9VAT
M+71O+6QE9G0@;&%N9W5A9V5S("A686AI9"!':&%F87)P;W5R"B`@("`@(#QV
M86AI9$!G:&%F87)P;W5R+F-O;3XI+@I;;6US72!&:7@@24U!4%]4<F5E(&1I
M<W!L87D@:68@9F]L9&5R(&-O;G1A:6YS('1H92!T97AT("=P;W`S)RX*6V-J
M:%T@1FEX('1H92!(;W)D95]&;W)M(&1A=&4@<&EC:V5R('!O<'5P(&EN($MO
M;G%U97)O<B]3869A<FD@*$)U9R`C.38S*2X*6VIA;ET@4W!A8V5S(&EN('1R
M964@=FEE=W,@=VET:"!);G1E<FYE="!%>'!L;W)E<B!H879E(&)E96X@9FEX
M960N"@H*+2TM+2TM+2T*=C,N,"U20S,*+2TM+2TM+2T*"EMC:FA=($%L=V%Y
M<R!R96QO860@9G)A;65S970@869T97(@;&]G9VEN9R!I;B`H0G5G(",X,30I
M+@I;8VIH72!&:7@@;65N=2!R96YD97)I;F<@9F]R($E%(#4N,"]-86,N"EMC
M:FA=(%1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WD@9F]R($E%(&)Y(&1E9F%U
M;'0N"EMC:FA=($%L;&]W('1O('!A<W,@86X@87)R87D@;V8@871T<FEB=71E
M<R!T;R!(;W)D93HZ:6UG*"DN"EMC:FA=($%L;&]W('1O('-E="!A('!A<W-W
M;W)D(&9O<B!T:&4@875T;R!A=71H96YT:6-A=&EO;B!D<FEV97(N"EMJ86Y=
M($%D9"!O<'1I;VX@9F]R(&YU;&P@9')I=F5R('1O(&UA:6QE<B!C;VYF:6=U
M<F%T:6]N+@I;:F%N72!&:7@@8V]N9FEG=7)A=&EO;B!O9B!:4%,@8V%C:&4N
M"EMJ86Y=($9I>"!S;VUE(&IA=F%S8W)I<'0@97)R;W)S('=I=&@@244@-2XP
M+@I;8VIH72!4:&4@(DAO<F1E(%!U<G!L92(@=&AE;64@:7,@;F]W('-I;7!L
M>2!A;F]T:&5R('1H96UE('1H870@:6YH97)I=',@9G)O;0H@("`@("!T:&4@
M9VQO8F%L($-34R!S971T:6YG<RP@:6YS=&5A9"!O9B!B96EN9R!B;W1H('1H
M92!P87)E;G0@=&AE;64@87,@=V5L;`H@("`@("!A<R!A('5S97(M8VAO;W-E
M86)L92!O<'1I;VXN("!4:&4@9&5F875L="!G<F%P:&EC<R!A<F4@;F]W(&EN
M(&$*("`@("`@=&]P+6QE=F5L('1H96UE<R]G<F%P:&EC<R!D:7)E8W1O<GD@
M87,@=V5L;"!F;W(@=7-E(&)Y(&%L;"!T:&5M97,N"@H*+2TM+2TM+2T*=C,N
M,"U20S(*+2TM+2TM+2T*"EMJ86Y=(%-H;W<@=&%B('=I=&@@=&AE(&9I96QD
M('1H870@9&ED;B=T('9A;&ED871E(&]N('-U8FUI='1E9"!F;W)M<RX*6VUM
M<UT@061D(&$@9V5N97)I8R!-24U%7U9I97=E<B!T:&%T('=I;&P@9&ES<&QA
M>2!T:&4@<F%W('1E>'0@;V8@=&5X="\J"B`@("`@('!A<G1S('1H870@=V4@
M9&\@;F]T(&AA=F4@82!S<&5C:69I8R!V:65W97(@9F]R+@H*"BTM+2TM+2TM
M"G8S+C`M4D,Q"BTM+2TM+2TM"@I;8VIH72!5<V4@2$]21$5?345.55]-05-+
M7RH@8V]N<W1A;G1S(&9O<B!D971E<FUI;FEN9R!W:&%T(&QI;FMS(&%R92!S
M:&]W;@H@("`@("!O;B!M96YU<RX*6VIA;ET@0W)E871E(&1E9F%U;'0@<&%R
M86UE=&5R<R!W:&5N(&%D9&EN9R!A(&YE=R!B;&]C:R!T;R!T:&4@<&]R=&%L
M+@I;;6US72!!=71O9&5T96-T(&5X86-T('9E<G-I;VX@;V8@244@*#4N,"LI
M(&]N(&QO9VEN(&%N9"!T=7)N(&]F9B!C;VUP<F5S<VEO;@H@("`@("!O;FQY
M(&9O<B!B=6=G>2!V97)S:6]N<RX*6V-J:%T@57-E(&%N($E%(&)E:&%V:6]R
M(&9O<B!H86YD;&EN9R!A;'!H82!T<F%N<W!A<F5N8WD@=VET:"!03D<@:6UA
M9V5S"B`@("`@(&EN<W1E860@;V8@86X@;VYL;V%D(&AA;F1L97(N"EMM;7-=
M($%L;&]W(&%L;"!F;VQD97)S('1O(&)E('!R92UF971C:&5D('=H96X@:6YT
M:6%L:7II;F<@24U!4%]4<F5E.CHN"EMM;7-=($%D9&5D(&5X=&5N<VEO;G,@
M=&\@=&AE(&9O<FT@<F5N9&5R97(@9F]R('1H92!F:6QE('-E;&5C=&EO;B!!
M4$DN"EMC:FA=(%)E;F1E<B!A;&P@;65N=7,@87,@/'5L/B!T86=S+"!F;W)M
M871T960@=VET:"!#4U,N"EMM;7-=($%D9&5D(&5X86UP;&4@;V8@7VEM<%]H
M;V]K7W-P86U?8F]U;F-E('1O(&-O;F9I9R]H;V]K<RYP:'`N9&ES="X*"@HM
M+2TM+2TM+2T*=C,N,"U"151!"BTM+2TM+2TM+0H*6V-J:%T@06QL;W<@=&\@
M:6YS97)T(&EM86=E<R!F<F]M(&=A;&QE<FEE<R!I;B!T:&4@5UE325=91R!(
M5$U,(&5D:71O<B`H1'5C:PH@("`@("`\9'5C:T!O8F%L82YN970^+"!2;V5L
M($=L;W5D96UA;G,@/')O96Q`9VQO=61E;6%N<RYI;F9O/BDN"EMM9&I=($%L
M;"!(;W)D92!I8V]N<R!C:&%N9V5D(&9R;VT@1TE&('1O(%!.1RX*6VUD:ET@
M061D("]T:&5M97,@9&ER96-T;W)Y(&%N9"!G<F]U<"!A;&P@;V8@96%C:"!T
M:&5M92=S(&9I;&5S('5N9&5R(&$@<W5B9&ER"B`@("`@(&]F('1H:7,@9&ER
M96-T;W)Y+@I;:F%N72!3=VET8V@@9G)O;2!D>6YA;6EC('1O('-T871I8R!#
M4U,@9FEL97,N"EMM;7-=($%D9"!S=7!P;W)T(&9O<B!-97-S86=E($1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;G,@*%)&0R`R,CDX*2X*6VIA;ET@061D(%1A
M8FQE3W!E<F%T:6]N<RP@0V]N=&5X=$UE;G4@86YD($QI<W14>7!E('!L=6=I
M;G,@=&\@<FEC:"!T97AT"B`@("`@(&5D:71O<BX*6VIA;ET@061D($1A=&%4
M<F5E(&)R;W=S97(@=&\@861M:6X@:6YT97)F86-E+@I;8VIH72!4:&4@2&]R
M9&5?0V%C:&4Z.B!!4$D@:&%S(&)E96X@8V]M<&QE=&5L>2!R97=R:71T96X@
M=&\@=&%K90H@("`@("!A9'9A;G1A9V4@;V8@=&AE(&YE=R!:4%,T(&%P:2!F
M;W(@8V]N=&5N="!C86-H:6YG+"!W:&EC:"!A;&QO=W,*("`@("`@82!M;W)E
M(&9A;6EL:6%R(&-A8VAI;F<@05!)(&]V97)A;&PN(%1H92!O;&0@>G!S(&1R
M:79E<B!H87,@8F5E;@H@("`@("!D<F]P<&5D(&)E8V%U<V4@;V8@=&AI<RX*
M6VIA;ET@061D(%!E<G-I86X@*%=E<W1E<FXI('1R86YS;&%T:6]N("A686AI
M9"!':&%F87)P;W5R"B`@("`@(#QV86AI9$!G:&%F87)P;W5R+F-O;3XI+@I;
M:F%N72!$<F]P('5S86=E(&]F(&%R9U]S97!A<F%T;W(N;W5T<'5T+@I;:F%N
M72!-86ME('-I9&5B87(@=VED=&@@82!P<F5F97)E;F-E("A2:6-K($5M97)Y
M(#QR:6-K0&5M97)Y+FAO;65L:6YU>"YN970^*2X*6V-J:%T@5&AE(%!R969S
M7W-Q;"!D<FEV97(@;F]W('5S97,@1$(Z.G!R97!A<F4O1$(Z.F5X96-U=&4@
M9F]R(&)E='1E<B!S=7!P;W)T"B`@("`@(&]F(&QA<F=E(&9I96QD<R!O;B!D
M871A8F%S92!B86-K96YD<R!S=6-H(&%S($]R86-L92X*6V-J:%T@4W5P<&]R
M="!C=7-T;VT@9FEE;&0@;6%P<&EN9W,@:6X@0U-6(&5X<&]R=',L(&%N9"!A
M9&0@86X@3W5T;&]O:R!E>'!O<G0*("`@("`@='EP92X*6V-J:%T@5&AE($AO
M<F1E('-I9&5B87(@;65N=2!I<R!N;W<@8G5I;'0@=VET:"!(;W)D95]4<F5E
M+@I;:F%N72!#;&]S92!A;B!84U,@:&]L92!I;B!T:&4@2%1-3"!V:65W97(L
M(&$@=F%R:6%T:6]N('1O('1H92!O;F4@<F5P;W)T960@:6X*("`@("`@:'1T
M<#HO+W=W=RYG<F5Y;6%G:6,N8V]M+W-E8W5R:71Y+V%D=FES;W)I97,O9VTP
M,#4M;6,O+@I;:F%N72!!9&0@8V]N9FEG=7)A=&EO;B!O<'1I;VX@=&\@96YA
M8FQE(%-33"!F;W(@;&]G:6YS(&]N;'DN"EMJ86Y=(%)E;6]V92!S:&%R92!T
M>7!E("AP<FEV871E+W!U8FQI8RDN"EMJ86Y=($%D9"!F<F%M97=O<FL@=&\@
M8VQE87(@;W5T('5S97(@9&%T82P@92YG+B!W:&5N(')E;6]V:6YG('5S97)S
M+@I;:F%N72!!9&0@86-C97-S(&ME>7,N"EMJ86Y=($1O;B=T(')E<75I<F4@
M8FQO8VMS('1O(&)E(')E9VES=&5R960@:6X@=&AE(&%P<&QI8V%T:6]N<R<@
M05!)<RX*6V-J:%T@26YT<F]D=6-E(&$@)U]D969A=6QT7R<@8V]L;W(@86YD
M(&)E='1E<B!H86YD;&EN9R!O9B!U<V5R+7-P96-I9FEE9`H@("`@("!5;F9I
M;&5D(&-O;&]R<RX*6VIA;ET@06QL;W<@=&AE;65S('1O('5S92!T:&5I<B!O
M=VX@:6-O;B!S971S+@I;8VIH72!#871E9V]R:65S(&%N9"!C871E9V]R>2!C
M;VQO<B!L86)E;',@87)E(&YO=R!H86YD;&5D(&=L;V)A;&QY(&)Y($AO<F1E
M+`H@("`@("!A;F0@<')O=FED960@=&\@86QL(&%P<&QI8V%T:6]N<R!T:&%T
M('5S92!T:&5M+@I;:F%N72!)9&5N=&ET:65S(&%R92!N;W<@;6%N86=E9"!W
M:71H('1H92!P<F5F97)E;F-E<R!C;V1E(&%N9"!C86X@8F4@86-C97-S960*
M("`@("`@9G)O;2!E=F5R>2!A<'!L:6-A=&EO;BX*6VUM<UT@2&%N9&QE(%)&
M0R`R,C,Q(&5N8V]D960@<&%R86UE=&5R('9A;'5E<RX*6VUM<UT@061D($E-
M05!?4V]R="!C;&%S<R!T;R!P<F]V:61E('-O<G1I;F<@9F]R($E-05`@;6%I
M;&)O>"!L:7-T<RX*6VIA;ET@061D('5S97(@;6%N86=E;65N="!T;R!)34%0
M(&%U=&AE;G1I8V%T:6]N(&1R:79E<BX*6VIA;ET@061D($E-05!?061M:6X@
M8VQA<W,@=&\@;6%N86=E($E-05`@;6%I;&)O>&5S+@I;;6US72!!9&1E9"!A
M(&=E;F5R:6,@=&5X="]H=&UL($U)345?5FEE=V5R(&1R:79E<B!F;W(@86QL
M($AO<F1E(&%P<&QI8V%T:6]N<PH@("`@("!T:&%T(&%T=&5M<'1S('1O('-A
M;FET:7IE(&UA;&EC:6]U<R!C;V1E(&AI9&1E;B!I;B!(5$U,+@I;;6US72!!
M9&1E9"!A(&=E;F5R:6,@;65S<V%G92]R9F,X,C(@34E-15]6:65W97(@9')I
M=F5R+@I;8VIH72!296UO=F4@2$]21$5?3$E"4R!C;VYS=&%N="!A;F0@87-S
M=6UE(&QI8G)A<FEE<R!A<F4@:6X@=&AE(&EN8VQU9&5?<&%T:"X*6VIA;ET@
M061D('-E87)C:&EN9R!A;F0@<&%G:6YG('1O('1H92!U<V5R(&%D;6EN:7-T
M<F%T:6]N(&EN=&5R9F%C92`H2F]E;`H@("`@("!686YD86P@/&IV86YD86Q`
M:6YF;W1E8VLN<6,N8V$^*2X*"@HM+2TM+2TM+2TM"G8S+C`M04Q02$$*+2TM
M+2TM+2TM+0H*6VIA;ET@06-C97-S(&ME>7,@87)E(&YO(&QO;F=E<B!G96YE
M<F%T960@875T;VUA=&EC86QL>2!B=70@9&5F:6YE9"!B>2!T:&4*("`@("`@
M9&5V96QO<&5R<R!A;F0@=')A;G-L871O<G,N"EMC:FA=(%1H92!N97<@<V5R
M=FEC97,O<')E9G,N<&AP(&9I;&4@:7,@;F]W('1H92!O;FQY(%5)('!A9V4@
M;F5C97-S87)Y"B`@("`@(&9O<B!P<F5F97)E;F-E<R!F;W(@86QL(&%P<&QI
M8V%T:6]N<R`M(&%L;"!A<'`O<')E9G,N<&AP(&9I;&5S"B`@("`@(&%R92!N
M;W<@;V)S;VQE=&4N"EMC:FA=(%!R969S.CIG9710<F5F*"D@:&%S(&)E96X@
M9&5P<F5C871E9"!A;F0@:7,@;F\@;&]N9V5R('!R97-E;G0N"EMC:FA=($AO
M<F1E.CHL(%)E9VES=')Y.CHL(&%N9"!T:&4@;&%S="!O9B!T:&4@;&EB<R!T
M:&%T(&%R92!M;W9I;F<@<VAO=6QD(&)E"B`@("`@(&UO=F5D('1O(&9R86UE
M=V]R:R!P86-K86=E<R!N;W<N"EMC:FA=($5D:71O<CHZ+"!-96YU+G!H<"P@
M3DQ3.CHL(&%N9"!3:6=N=7`N<&AP(&AA=F4@86QL(&)E96X@;6]V960@=&\*
M("`@("`@9G)A;65W;W)K('!A8VMA9V5S+@I;;6US72!-;W9E9"!T:&4@24U!
M4"!4<F5E(&=E;F5R871I;VX@8VQA<W,@9G)O;2!)35`@=&\@9G)A;65W;W)K
M('-O(&ET(&-A;@H@("`@("!B92!U<V5D(&)Y(&]T:&5R(&%P<&QI8V%T:6]N
M<RX*6VUD:ET@4V5T=7`@;F]W(&AA<R!A(&UO<F4@:6YF;W)M871I=F4@9F]R
M;6%T+B!4:&4@0U93('9E<G-I;VX@=&%G(&ES(&-O<&EE9`H@("`@("!F<F]M
M('1H92!C;VYF+GAM;"!F:6QE(&EN=&\@=&AE(&-O;F8N<&AP(&9I;&4@<V\@
M=&AA="!I="!B92!U<V5D('1O('=A<FX*("`@("`@=VAI8V@@87!P;&EC871I
M;VYS(&YE960@=&AE:7(@8V]N9B!U<&1A=&5D+@I;8VIH72!5<V4@:F%V87-C
M<FEP="!T;R!A=71O9&5T96-T('=H971H97(@;W(@;F]T('1H92!F<F%M97-E
M="!I<R!P<F5S96YT+@I;8VIH72!(;W)D95](:7-T;W)Y+"!(;W)D95],:6YK
M<RP@86YD($AO<F1E7U-E87)C:"!H879E(&)E96X@;6]V960@=&\*("`@("`@
M9G)A;65W;W)K('!A8VMA9V5S+@I;8VIH72!!;&QO=R!A<'!S(&EN8VQU9&EN
M9R!H;W)D92]L:6(O8F%S92YP:'`@=&\@<W!E8VEF>2!T:&%T(&$@9&EF9F5R
M96YT"B`@("`@(')E9VES=')Y(&%P<&QI8V%T:6]N('-H;W5L9"!A8W1U86QL
M>2!B92!P=7-H960@;VYT;R!T:&4@4F5G:7-T<GD*("`@("`@87!P;&EC871I
M;VX@<W1A8VLN(%1H:7,@;&5T<R!T:&4@9FEC=&EO;B!O9B!P<F]B;&5M+G!H
M<"!B96EN9R!I=',*("`@("`@;W=N(&%P<&QI8V%T:6]N('!L87D@;FEC96QY
M('=I=&@@=&AE(&YE=R!P97)M:7-S:6]N<R!C:&5C:VEN9RX*6V-J:%T@5&AE
M(&YE=R!A<'!L:6-A=&EO;B!P97)M:7-S:6]N<R!C:&5C:VEN9R!H87,@8F5E
M;B!M;V1I9FEE9"!T;PH@("`@("!A;&QO=R!A8V-E<W,@=&\@86QL(&%U=&AE
M;G1I8V%T960@=7-E<G,@8GD@9&5F875L="P@86YD('1O(&1E;GD*("`@("`@
M9W5E<W0@86-C97-S(&)Y(&1E9F%U;'0N($%L;"!V87)I871I;VYS(&]N('1H
M870@;75S="!B92!S970*("`@("`@97AP;&EC:71L>2X*6V-J:%T@4F5M;W9E
M('1H92!'=65S="!397)V:6-E<R!L:6YK.R!I="=S(&)E96X@;V)S;VQE=&5D
M(&)Y"B`@("`@("1C;VYF6R=M96YU)UU;)V%L=V%Y<R==+@I;8VIH72!687)I
M;W5S("1N;U]A=71H(&%N9"`D<V5L9E]C;VYT86EN961?875T:"!F;&%G<R!H
M879E(&)E96X@<W1A;F1A<F1I>F5D"B`@("`@(&EN=&\@86X@05542%](04Y$
M3$52(&-O;G-T86YT+"!W:&EC:"!I9B!D969I;F5D('-I9VYA;',@=&AE(&%P
M<&QI8V%T:6]N"B`@("`@('1H870@:70@<VAO=6QD(&YO="!C:&5C:R!P97)M
M:7-S:6]N<R!U<&]N(&-A;&QI;F<@)')E9VES=')Y+3YP=7-H07!P*"DL"B`@
M("`@(&%S('1H92!C86QL:6YG('-C<FEP="!W:6QL(&AA;F1L92!T:&%T(&ET
M<V5L9BP@;W(@:7,@82!S>7-T96TM;&5V96P@8W)O;@H@("`@("!J;V(O<V-R
M:7!T+V5T8RX*6V-J:%T@061D(&%N(&]P=&EO;B!T;R`D<F5G:7-T<GDM/G!U
M<VA!<'`H*2!T;R!S<&5C:69Y('=H971H97(@;W(@;F]T('1O(&-H96-K"B`@
M("`@(&%P<&QI8V%T:6]N('!E<FUI<W-I;VYS+@I;8VIH72!4:&4@)V%L;&]W
M7V=U97-T<R<@<V5T=&EN9RP@86YD("1R96=I<W1R>2T^86QL;W='=65S=',H
M*2P@:&%V92!B965N"B`@("`@(')E;6]V960@:6X@9F%V;W(@;V8@2&]R9&5?
M4&5R;7,@87!P;&EC871I;VX@<&5R;6ES<VEO;G,N"EMM;7-=($%D9&5D('1H
M92!T97AT+W)I8VAT97AT($U)345?5FEE=V5R+@I;:F%N72!);G-T86YT:6%T
M92!T:&4@9VQO8F%L(%!E<FUS(&]B:F5C="!I;B!296=I<W1R>2YP:'`N"EMC
M:FA=($-A=&5G;W)Y(&AA<R!B965N(&UO=F5D('1O(&$@9G)A;65W;W)K('!A
M8VMA9V4L(&%N9"!A;'-O(')E;F%M960*("`@("`@=&\@1&%T851R964@<V\@
M=&AA="!I="!H87,@82!M;W)E(&EN='5I=&EV92!N86UE(&9O<B!T:&4@05!)
M+@I;:F%N72!!9&0@26YD;VYE<VEA;B!L86YG=6%G92`H4VQA;6EN(#QS;&%M
M:6Y`=6YE:BYA8RYI9#XI+@I;:F%N72!!9&0@075T:%]L;V=I;B!C;&%S<RX*
M6VIA;ET@061D($AO<F1E.CIE>'1E<FYA;%5R;"@I+@I;;61J72!097)M<R!I
M<R!N;W<@82!G;&]B86QL>2!A=F%I;&%B;&4@;V)J96-T+"!S970@8GD@=&AE
M(')E9VES=')Y)W,*("`@("`@;&]A9%!E<FUS*"DN"EMJ86Y=($%D9"`B06)O
M=70B('!A9V4@9F]R('1H92!H96QP('-Y<W1E;2X*6VIA;ET@061D(%-/05`@
M<V5R=F5R('1O(%)00R!F<F%M97=O<FLN"EMC:FA=($UO=F4@4')E9G-522!T
M;R!0<F5F<R]522YP:'`@9F]R('!A8VMA9V4@8V]N<VES=&5N8WDN"EMM;7-=
M($%D9&5D($Y,4U]'96])4#HZ('1O(&1O($AO<W1N86UE("T^($-O=6YT<GD@
M;&]O:W5P<RX@($Y,4SHZ('=I;&P@9&\*("`@("`@;&]O:W5P<R!B>2!D969A
M=6QT(&YO=R!U<VEN9R!C;W5N=')Y(%1,1"!C;V1E<RX*6VUI<ET@061D('!R
M97!R;V-E<W,@:&]O:R!F;W(@4VEG;G5P('-Y<W1E;2X*6VIA;ET@36]V92!(
M;W)D95]#3$DL($AO<F1E7T-A8VAE+"!(;W)D95]#:7!H97(L($AO<F1E7T-O
M;7!R97-S+`H@("`@("!(;W)D95]4;VME;B!A;F0@2&]R9&5?571I;"!P86-K
M86=E<R!T;R!T:&4@9G)A;65W;W)K(&UO9'5L92X*6V-J:%T@4F5O<F=A;FEZ
M92!A(&YU;6)E<B!O9B!F:6QE<R!F<F]M('1H92!T;W`@;&5V96P@86YD(&9R
M;VT@=71I;"\@:6YT;R!A"B`@("`@(&YE=R!S97)V:6-E<R\@9&ER96-T;W)Y
M(&%N9"!A(&YU;6)E<B!O9B!S97)V:6-E<R\J('-U8F1I<F5C=&]R:65S+@H@
M("`@("!4:&ES('-H;W5L9"!G:79E('5S(&$@8F5T=&5R(&)A<V4@9F]R(&5X
M<&%N9&EN9R!T:&4@<V5R=FEC97,@<')O=FED960*("`@("`@8GD@=&AE(&-O
M<F4@2&]R9&4@;6]D=6QE(&EN('1H92!F=71U<F4N"EMM87A=($%D9"!S=7!P
M;W)T(&9O<B`\8CX@86YD(#QI/B!T86=S('1O('1H92!(96QP('AM;"!P87)S
M97(N"EMC:FA=($%D9"!T:&4@2&]R9&5?2&ES=&]R>2!!4$DL(&9O<B!S=&]R
M:6YG('1I;65S=&%M<&5D(&5V96YT<R!F;W(*("`@("`@87)B:71R87)Y(&]B
M:F5C=',N"EMC:FA=($AO<F1E7U1E;7!L871E(&YO=R!A;&QO=W,@:68Z(&-O
M;F1I=&EO;G,@;VX@87)R87D@=F%L=65S"B`@("`@("A.=6YO($QO=7)E:7)O
M(#QN=6YO0&-O+G-A<&\N<'0^*2X*6VIA;ET@5&AE(&%D;6EN:7-T<F%T;W(@
M8V%N(&YO=R!F;W)C92!T:&4@9&5F875L="!L86YG=6%G92!I;B!N;',N<&AP
M"B`@("`@("A%=&EE;FYE($=O>65R(#QE=&EE;FYE+F=O>65R0&QI;G5X<75E
M8F5C+F-O;3XI+@I;;61J72!(;W)D95]&;W)M(&YO=R!S=7!P;W)T<R!S971T
M:6YG(&]F(&$@:&5L<"!I8V]N(&QI;FME9"!T;R!H96QP+GAM;"X*6V-J:%T@
M;6EM95]M87!P:6YG+G!H<"!I<R!N;R!L;VYG97(@82!C;VYF:6<@9FEL93L@
M<F5P;&%C960@=VET:`H@("`@("!M:6UE+FUA<'!I;F<N<&AP(&EN<VED92!T
M:&4@34E-12!P86-K86=E+@I;8VIH72!!9&0@1V]O9VQE('-E87)C:"!A<'!L
M970@*$IO92!7:6QS;VX@/&IO92YW:6QS;VY`;6EN9&-A;F1Y+F]R9SXI+@I;
M:F%N72!55$8M."!S=7!P;W)T(&ES(&5N86)L960@8GD@9&5F875L="!N;W<N
M"EMJ86Y=(%1H96UE<R!A<F4@;F]W(&%U=&]M871I8V%L;'D@<F5A9"!F<F]M
M('1H92!C;VYF:6<O=&AE;65S(&1I<F5C=&]R>2X*6V-J:%T@061D('-U<'!O
M<G0@9F]R(&]T:&5R(&MI;F1S(&]F('-E<G9E<G,@86YD(&]T:&5R(&MI;F1S
M(&]F(')E<W!O;G-E<R!T;PH@("`@("!R<&,N<&AP(&%N9"!T:&4@4E!#.CH@
M05!)+@I;:G=M72!!9&0@<W5P<&]R="!F;W(@87!P<F]V:6YG('%U975E9"!S
M:6=N=7`@87!P;&EC871I;VYS+@I;8VIH72!'<F]U<',@8V%N(&YO=R!H879E
M(&%N(&5M86EL(&%D9')E<W,@87-S;V-I871E9"!W:71H('1H96TN"EMC:FA=
M($UA:V4@2&]R9&4M;&5V96P@0FQO8VMS(&-O;F9I9W5R86)L92!T:')O=6=H
M('1H92!R96=I<W1R>2P@86QL;W=I;F<*("`@("`@96%S:65R(&%D9&EN9R!O
M9B!N97<@8FQO8VMS("A*;V4@5VEL<V]N(#QJ;V4N=VEL<V]N0&UI;F1C86YD
M>2YO<F<^*2X*6V-J:%T@0V%T96=O<GE4<F5E(&ES(&YO=R!D97!R96-A=&5D
M(&EN(&9A=F]R(&]F($AO<F1E7U1R964N"EMC:FA=($UO=F4@=&AE(&%D;6EN
M('!E<FUI<W-I;VYS(&%N9"!G<F]U<',@<&%G97,@=&\@=7-E($AO<F1E7U1R
M964N"EMM87A=($%D9"!?8V]M<&%R95!A<W-W;W)D<R@I(&9U;F-T:6]N('1O
M($%U=&A?<W%L('1O(&-O<G)E8W1L>2!C;VUP87)E"B`@("`@(&%L;"!C<GEP
M=&5D('!A<W-W;W)D<R!S:6UI;&%R('1O('1H92!087-S=V0@;6]D=6QE+@I;
M;6%X72!!9&0@8W)Y<'0M9&5S("AW:&EC:"!I<R!T:&4@<V%M92!A<R!C<GEP
M="DL(&-R>7!T+6UD-2P@86YD(&-R>7!T+6)L;W=F:7-H"B`@("`@(&5N8W)Y
M<'1I;VX@='EP97,L('1O(&UA=&-H(%!A<W-W9"!M;V1U;&4N"EMM87A=($%D
M9"!O<'1I;VYA;"!S:&]W7V5N8W)Y<'1I;VX@<&%R86T@=&\@075T:%]S<6PL
M('1O(&UA=&-H(%!A<W-W9"!M;V1U;&4N"EMM;7-=($%D9&5D($E0($%D9')E
M<W,@8VAE8VL@=&\@075T:#HZ875T:&5N=&EC871E*"D@=&\@:6YC<F5A<V4@
M<V5C=7)I='DN"EMJ86Y=(%)E;6]V92!.3%,Z.F1E8VEM86Q&<F]M3&]C86QE
M*"D@86YD($Y,4SHZ9&5C:6UA;%1O3&]C86QE*"DN"EMC:FA=($AO<F1E7U9&
M4SHZ(&ES(&YO=R!61E,Z.B!A9V%I;BP@86YD(&AA<R!N;R!E>'1E<FYA;"!(
M;W)D92!D97!E;F1A;F-I97,N"EMC:FA=(%)O=6YD(&]U="!T:&4@=F%R:6]U
M<R!S:&5L;"!T;V]L<R!W:71H(&$@8V]M;6%N9"!S:&5L;"X*6V-J:%T@061D
M('-I9&5B87(N<&AP(&%N9"!A<'!R;W!R:6%T92!P<F5F<R!E;G1R:65S(&9O
M<B!U<VEN9R!(;W)D92!W:71H('1H90H@("`@("!M96YU(&%S(&$@36]Z:6QL
M82!S:61E8F%R+@I;;6US72!!9&0@24U!4%]#86-H93HZ(&-L87-S('1O(&AA
M;F1L92!C86-H960@24U!4"!S97)V97(@9&%T82X*6V-J:%T@36%K92!G971#
M871E9V]R:65S0GE!='1R:6)U=&5S*"D@;75C:"!M;W)E('-O<&AI<W1I8V%T
M960@+2!I="!C86X*("`@("`@;F]W(&AA;F1L92!A('!R971T>2!M=6-H(&%R
M8FET<F%R>2!L;V=I8R!T<F5E("T@86YD('5S92!I="!T;R!O<'1I;6EZ90H@
M("`@("!(;W)D95]3:&%R93HZ;&ES=%-H87)E<R@I+@I;8VIH72!!9&0@9V5T
M0V%T96=O<FEE<T)Y071T<FEB=71E<R@I+"!A;F0@=7-E(&ET(&EN"B`@("`@
M($=R;W5P.CIG971'<F]U<$UE;6)E<G-H:7!S*"DN"EMC:FA=($%D9"!C;V1E
M('1H870@;&5T<R!A($-A=&5G;W)Y3V)J96-T('-U8F-L87-S(&1E9FEN92!A
M(&UA<'!I;F<@9G)O;2!I=',*("`@("`@:6YT97)N86P@9&%T82!T;R!T:&4@
M;F5W(&AO<F1E7V-A=&5G;W)Y7V%T=')I8G5T97,@=&%B;&4N"EMM;7-=($E-
M05!?4V5A<F-H.CH@;F]W('5S97,@82!)34%07U-E87)C:%]1=65R>3HZ(&]B
M:F5C="!T;R!B=6EL9"!T:&4*("`@("`@86-T=6%L($E-05`@<V5A<F-H+@I;
M;6US72!!9&1E9"!A('-E8W5R92!D96QE=&4@=&5M<"!F:6QE(&]P=&EO;B!T
M:&%T('=I;&P@;W9E<G=R:71E(&%N>2!T96UP(&9I;&4*("`@("`@=VET:"!R
M86YD;VT@9&%T82!B969O<F4@=6YL:6YK:6YG+@I;:F%N72!!9&0@3&%V96YD
M97(@=&AE;64@*%II875R(%)A:&UA;B`\>FEA0'%A;&%C;VTN8V]M/BDN"EMC
M:FA=($AO<F1E7U1E;7!L871E.CH@:7,@;F]W(&-A<&%B;&4@;V8@=')A;G-L
M871I;F<@=&5X="!I;G-I9&4*("`@("`@/&=E='1E>'0^/"]G971T97AT/B!T
M86=S+@I;8VIH72!(;W)D95]-;V)I;&4Z.B!N;W<@<')O<&5R;'D@<W5P<&]R
M=',@;75L=&EP;&4@<W5B;6ET(&5L96UE;G1S(&EN(&9O<FUS+@I;;6%C72!!
M9&0@9V5N97)I8R!#>7)U<R!A=71H(&1R:79E<BP@075T:%]C>7)U<RX*6VUA
M8UT@061D(&]P=&EO;F%L(&5N8W)Y<'1I;VX@<&%R86T@=&\@075T:%]S<6PL
M('1O(&UA=&-H(%!A<W-W9"!M;V1U;&4N"EMJ86Y=($%D9"!N97<@:&]O:W,@
M*')E<&QA8VEN9R!?:&]R9&5?:&]O:U]U<V5R;F%M92D@=&\@8V]N=F5R="!U
M<V5R(&YA;65S"B`@("`@(&9R;VT@=&AE(&)A8VME;F0@=&\@2&]R9&4@86YD
M(&)A8VLN"EMC:FA=($%D9"!A(&YE=R!!4$D@8V%L;"P@075T:#HZ:7-!=71H
M96YT:6-A=&5D*"1R96%L;2`](&YU;&PI+"!F;W(*("`@("`@9&5T97)M:6YI
M;F<@=VAE=&AE<B!O<B!N;W0@82!U<V5R(&ES(&QO9V=E9"!I;B!T;R!T:&4@
M8W5R<F5N=`H@("`@("!R96%L;2`H8GD@9&5F875L="!N=6QL*2X@075T:#HZ
M9V5T075T:"@I(&ES('-T:6QL('5S960@=&\@9V5T"B`@("`@('1H92!C=7)R
M96YT('5S97(L(&)U="!N;W<@>6]U(&1O;B=T(&YE960@=&\@:VYO=R!T:&4@
M875T:"!R96%L;0H@("`@("!T;R!G970@=&AE(&-U<G)E;G0@=7-E<B`M(&IU
M<W0@=&\@8VAE8VL@875T:&5N=&EC871I;VXN"EMC:FA=($1(5$U,(&1A=&4@
M<&EC:V5R(&YO=R!O<&5N<R!R:6=H="!O=F5R('1H92!I;6%G92!U<V5D('1O
M(&%N8VAO<B!I="X*6V-J:%T@5&AE(&QA<W1?;&]G:6X@<')E9F5R96YC92!I
M<R!N;W<@96YT:7)E;'D@:&%N9&QE9"!B>2!(;W)D92X*6VUM<UT@061D($AO
M<F1E7U1E<W0Z.B!C;&%S<R]T96UP;&%T97,@=&\@86ED(&EN(&-R96%T:6YG
M('1E<W0N<&AP('-C<FEP=',N"EMM;7-=($UO=F4@8V]M<&QE>"!)34%0('-E
M87)C:&EN9R!C;V1E(&9R;VT@24U07U-E87)C:#HZ('1O($E-05!?4V5A<F-H
M.CHN"EMC:FA=(%)E+7=O<FL@=&AE($AO<F1E($Q$05`@<V-H96UA(&)I=',@
M=&\@8F4@;6]R92!C;W)R96-T(&%N9`H@("`@("!C;VYS:7-T96YT("A!9&%M
M(%1A=6YO(%=I;&QI86US(#QA9&%M0&UO<G)I<V]N+6EN9"YC;VT^*2X*6VUM
M<UT@061D($1/32!T;V]L=&EP(&-A<&%B:6QI='D@=FEA($AO<F1E.CIL:6YK
M5&]O;'1I<"@I+@I;;6US72!!9&0@9V%R8F%G92!C;VQL96-T:6]N(&-L87-S
M("A(;W)D95]61E-?1T,Z.BD@9F]R(%9&4RX*6VUM<UT@061D('1I;65O=70@
M=&\@4$=0(&ME>7-E<G9E<B!L;V]K=7`N"EMC:FA=($%D9"!N879I9V%T:6]N
M(&9O<B!P<F5V:6]U<R]N97AT('!R969E<F5N8V5S(&)L;V-K(&EN(%!R969S
M54D*("`@("`@*$UA=&AI974@0TQ!0D%55"`\;6%T:&EE=2YC;&%B875T0&9R
M964N9G(^*2X*6V-J:%T@061D($AO<F1E7TQI;FMS($%022`H:BYH=6EN:6YK
M0'=A;F%D;V\N;FPI+@I;8VIH72!!9&0@;6]R92!I;G1R;W-P96-T:6]N+"!I
M;B!T:&4@9F]R;2!O9B!G971#;VYT96YT5'EP92@I(&%N9`H@("`@("!G971,
M:6YK*"DL('1O('1H92!(;W)D95]);6%G93HZ($%022X*6V-J:%T@061D('5T
M:6PO8V%C:&5V:65W+G!H<"!F;W(@=FEE=VEN9R!A;GD@9&%T82!W:71H(&$@
M0V]N=&5N="UT>7!E"B`@("`@('!U="!I;G1O('1H92!C86-H92X*6V-J:%T@
M061D($AO<F1E7T-A8VAE.CIC86-H94]B:F5C="@I(&9O<B!U<V4@:6X@8V%C
M:&EN9R!T:&4@<F5S=6QT<R!O9@H@("`@("!N;VXM<W1A=&EC(&]B:F5C="!M
M971H;V1S+@I;8VIH72!296YA;64@0V%C:&4Z.B!T;R!(;W)D95]#86-H93HZ
M+@I;8VIH72!-;W9E($-A8VAE7W-E<W-I;VXZ.B!T;R!(;W)D95]397-S:6]N
M3V)J96-T<SHZ+@I;;6US72!!9&1E9"!(;W)D93HZ97AT96YS:6]N17AI<W1S
M*"D@=&\@8V%C:&4@97AT96YS:6]N7VQO861E9"@I(&-A;&QS+@I;8VIH72!!
M9&0@3DQ3.CID96-I;6%L5&],;V-A;&4H*2!A;F0@3DQ3.CID96-I;6%L1G)O
M;4QO8V%L92@I('1O(&AA;F1L90H@("`@("!C;VYV97)T:6YG(&)E='=E96X@
M9&EF9F5R96YT(&1E8VEM86P@<&]I;G0@<V5P87)A=&]R<RX*6V-J:%T@061D
M960@34E-15](96%D97)S.CHN"EMM;7-=($UO=F5D(&=Z:7`@86YD('1A<B!F
M:6QE(&AA;F1L:6YG('1O($AO<F1E7T-O;7!R97-S7RHZ.B!M;V1U;&5S+@I;
M;6US72!-;W9E9"!:25`@:&%N9&QI;F<@=&\@=&AE($AO<F1E7T-O;7!R97-S
M7WII<#HZ(&UO9'5L92X*6VUM<UT@36]V960@5$Y%1B!H86YD;&EN9R!T;R!T
M:&4@2&]R9&5?0V]M<')E<W-?=&YE9CHZ(&UO9'5L92X*6VUM<UT@061D960@
M2&]R9&5?0V]M<')E<W,Z.B!!4$D@+2!U<V5D('1O(&-O;7!R97-S+V1E8V]M
M<')E<W,@9&%T82X*6VUD:ET@061D960@=&AE($1/32!C86QE;F1A<B!D871E
M('!I8VME<B!T;R!(;W)D95]&;W)M+"!B87-E9"!O;B!W;W)K(&)Y"B`@("`@
M($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^(&%N9"!"
M<FEA;B!+96EF97(*("`@("`@/&)R:6%N0'9A;&EN;W(N;F5T/BX*6VUM<UT@
M061D960@;75L=&EP87)T+W)E<&]R="!-24U%7U9I97=E<CHZ+@I;;6US72!!
M9&1E9"!-24U%.CIG96YE<F%T94UE<W-A9V5)1"@I('1O(&=E;F5R871E($U)
M344M8V]M<&QI86YT(&UE<W-A9V4@241S+@I;8VIH72!!9&0@8V]M;6%N9"UL
M:6YE('-E='5P+G!H<"!S8W)I<'0N(%)I9VAT(&YO=RP@=&AI<R!O;FQY(&=E
M;F5R871E<R]U<&1A=&5S"B`@("`@(&-O;F9I9W5R871I;VYS.R!Y;W4@8V%N
M;F]T("IE9&ET*B!A(&-O;F9I9W5R871I;VX@=VET:"!I="X*6VIA;ET@061D
M(%-T<FEN9SHZ(&-L87-S('=I=&@@;&]C86QE+V-H87)S970@<V%F92!S=')I
M;F<@9G5N8W1I;VYS+@I;;6US72!!9&1E9"!(;W)D93HZ875T:&5N=&EC871I
M;VY&86EL=7)E4F5D:7)E8W0H*2X*6VUM<UT@061D960@0G)O=W-E<CHZ97-C
M87!E2E-#;V1E*"D@=&\@97-C87!E(&-E<G1A:6X@8VAA<F%C=&5R<R!I;@H@
M("`@("!J879A<V-R:7!T(&-O9&4@9&5P96YD:6YG(&]N('1H92!B<F]W<V5R
M('1Y<&4N"EMJ86Y=($%D9"!.3%,Z.G-T<G1O;&]W97(H*2!A;F0@=7-E(&ET
M(&5V97)Y=VAE<F4@=VAE<F4@;&]C86QE(&EN9&5P96YD86YC90H@("`@("!I
M<R!N96-E<W-A<GDN"EMJ86Y=($%D9"!4=7)K:7-H('1R86YS;&%T:6]N("A'
M96YC;R!9:6QM87H@/&=E;F-O>6EL;6%Z0'EA:&]O+F-O;3XI+@I;;6US72!!
M9&0@)VQI;FLG('!A<F%M971E<B!T;R!T:&4@<')E9F5R96YC97,@8V]N9FEG
M('1O(&%L;&]W(&9O<B!H96QP(&QI;FMS"B`@("`@('1O(&)E(&%D9&5D('1O
M('1H92!P<F5F97)E;F-E<R!P86=E<RX*6VUM<UT@06YO=&AE<B!-86EN=&5N
M86YC93HZ(')E=W)I=&4@+2!N;W<@<W1O<F4@86QL(&1A=&$@:6X@=&AE(&-A
M8VAE9`H@("`@("!-86EN=&5N86YC95]487-K;&ES="!O8FIE8W0N"EMM;7-=
M($%D9&5D(&-H96-K('1O(%!R969S.CH@=&\@96YS=7)E('1H92!D871A('-T
M;W)E9"!D;V5S(&YO="!E>&-E960@=&AE"B`@("`@(&UA>&EM=6T@<W1O<F%G
M92!S:7IE(&]F('1H92!P<F5F97)E;F-E<R!S=&]R86=E('-Y<W1E;2X*6VIA
M;ET@061D(%541BTX('-U<'!O<G0N($%N>2!C;VYT96YT('=I=&@@86YY(&-H
M87)S970@8V%N(&YO=R!B92!D:7-P;&%Y960@=VET:`H@("`@("!A;GD@=')A
M;G-L871I;VXN"EMM;7-=($%D9"!.3%,Z.F-H96-K0VAA<G-E="@I('1O(&1E
M=&5R;6EN92!W:&5T:&5R(&$@9VEV96X@8VAA<F%C=&5R('-E="!I<PH@("`@
M("!V86QI9"!O;B!T:&4@8W5R<F5N="!S>7-T96TN"EMC:FA=($1E<')E8V%T
M960@4F5G:7-T<GDZ.FEN8VQU9&5&:6QE<R@I(&%N9"!296=I<W1R>3HZ<VAU
M=&1O=VXH*2X*6VUM<UT@061D('-U<'!O<G0@:6X@34E-15]-86=I8SHZ('1O
M('5S92!T:&4@54Y)6"!F:6QE(&9U;F-T:6]N('1O(&1E=&5R;6EN90H@("`@
M("!T:&4@34E-12!T>7!E(&]F('5N:VYO=VX@9FEL97,N"EMM;7-=($%D9&5D
M(&%N(&5X86UP;&4@8W)O;B!S8W)I<'0@=&\@9&5L971E(&]L9"!T96UP;W)A
M<GD@9FEL97,N"EMM;7-=($-O<G)E8W1L>2!G970@8VAA<G-E="!I;F9O<FUA
M=&EO;B!F;W(@34E-15]087)T<R!I;B!-24U%7U-T<G5C='5R92X*6VUM<UT@
M4F5W<F]T92!-24U%7TUE<W-A9V4@=&\@97AT96YD($U)345?4&%R="X*6V-J
M:%T@061D(&]R9&5R:6YG(&5X=&5N<VEO;G,@=&\@=&AE($-A=&5G;W)Y.CH@
M9G)A;65W;W)K"B`@("`@("A-87)K;R`\;6%R:V]`;V)L;RYC;VT^*2X*6V-J
M:%T@061D(&$@<VEM<&QE('1E;7!L871E(&5N9VEN92P@9&5R:79E9"!F<F]M
M(&)496UP;&%T92P*("`@("`@9F]R($AO<F1E(&%P<&QI8V%T:6]N<R!T;R!U
M<V4N"EMC:FA=($%D9"!!=71H7WEA:&]O.CH@=VAI8V@@;&5T<R!Y;W4@:&%V
M92!N;R!L;V-A;"!A=71H(&%N9"!R96QY(&]N"B`@("`@(%EA:&]O(2!M86EL
M('5S97)N86UE<RX*6VUM<UT@36]V960@4V5R=F5R(&-O;F9I9W5R871I;VX@
M8VAE8VMI;F<@9G5N8W1I;VYS('1O(%-E<G9E<CHZ+@I;8VIH72!4:&4@=7-E
M<B!A9&UI;B!P86=E(&-A;B!N;W<@<V5T(&9U;&QN86UE(&%N9"!F<F]M7V%D
M9'(@<')E9F5R96YC97,*("`@("`@9F]R(&%N>2!U<V5R(&%S(&QO;F<@87,@
M=&AE($%U=&@@8F%C:V5N9"!I<R!C87!A8FQE(&]F(&%T(&QE87-T"B`@("`@
M(&QI<W1I;F<@=7-E<G,@*&1O97-N)W0@:&%V92!T;R!B92!A8FQE('1O('5P
M9&%T92!T:&5M*2X*6V-J:%T@4VAA<F4Z.B!I<R!N;W<@2&]R9&5?4VAA<F4Z
M.BP@86YD(&ES(')E=V]R:V5D('1O(&AO;&0@<&5R;6ES<VEO;G,*("`@("`@
M:6YT97)N86QL>2X@5V4@8V%N(&YO=R!A<W-I9VX@9W)O=7`O9&5F875L="]G
M=65S="!P97)M:7-S:6]N<PH@("`@("!M;W)E(&5A<VEL>2X*6VIA;ET@061D
M(%)00SHZ<&%R<V55<FPH*2X*6VIA;ET@061D(%)00R!B87-E9"!R96UO=&4@
M<W5M;6%R:65S+@I;8VIH72!!9&0@82!344P@4VAE;&P@=&\@=&AE($AO<F1E
M(&%D;6EN('-E8W1I;VXN"EMC:FA=($1O;B=T('!R969I>"!(;W)D92!A9&UI
M;B!M96YU:71E;7,@=VET:"`B2&]R9&4B('1O('-A=F4@<W!A8V4N"EMC:FA=
M($AO<F1E7T9O<FTZ.B!F;W)M<R!N;W<@=7-E('1H92!(;W)D95]4;VME;CHZ
M($%022!B>2!D969A=6QT('1O"B`@("`@(&UA:V4@<W5R92!T:&%T('1H97D@
M8V%N;F]T(&)E(')E;&]A9&5D+@I;8VIH72!296YA;64@5&]K96XZ.B!T;R!(
M;W)D95]4;VME;CHZ(&9O<B!F=71U<F4@<&%C:V%G:6YG+@I;:F%N72!!9&0@
M4F5G:7-T<GDZ.FQI<W1!4$ES*"D@86YD(%)E9VES=')Y.CIL:7-T365T:&]D
M<R@I+@I;8VIH72!4:&4@4&5R;7,Z.B!S>7-T96T@;F]W('-U<'!O<G1S(&1E
M9F%U;'0@86YD(&=U97-T('!E<FUI<W-I;VYS+@I;8VIH72!!<'!L:6-A=&EO
M;G,@8V%N(&YO=R!P<F]V:61E(&EN9&EV:61U86P@<F5G:7-T<GD@;65T:&]D
M<RP@;F]T(&IU<W0@=VAO;&4*("`@("`@:6YT97)F86-E<RX@07!P;&EC871I
M;VYS(&-A;B!O=F5R<FED92!A('-I;F=L92!M971H;V0@;W5T(&]F(&%N(&EN
M=&5R9F%C90H@("`@("!A<R!W96QL("T@86X@87!P('!R;W9I9&EN9R!A(&UA
M:6PO9FEL=&5R('=H:6QE($E-4"!P<F]V:61E<R!M86EL+RHL(&4N9RX*6V-J
M:%T@4F5N86UE9"!&;W)M4W!R;V-K970Z.B!T;R!(;W)D95]&;W)M.CH@86YD
M($=R87!H4W!R;V-K970Z.B!T;PH@("`@("!(;W)D95]'<F%P:#HZ(&9O<B!C
M;VYS:7-T96YC>2!A;F0@9G5T=7)E(%!%05(@<&%C:V%G:6YG+@I;;6ER72!!
M9&1E9"!E>&%M<&QE(&]F(%]I;7!?:&]O:W-?9F5T8VAM86EL7V9I;'1E<B!T
M;R!C;VYF:6<O:&]O:W,N<&AP+F1I<W0*6VUM<UT@061D960@=&AE($U)345?
M0V]N=&5N=',Z.B!C;&%S<SL@9G5N8W1I;VYS('1O(&AE;'`@:6X@=&AE(&]U
M='!U=`H@("`@("!O9B!-24U%(&-O;G1E;G0N"EMC:FA=(%)E=W)I=&4@=&AE
M($-A=&5G;W)Y.CH@<WES=&5M('1O(&%L;&]W(&UU;'1I<&QE(&QE879E<R!W
M:71H('1H92!S86UE"B`@("`@(&YA;64@*&%S(&QO;F<@87,@=&AE>2!H879E
M(&1I9F9E<F5N="!P87)E;G1S*2!A;F0@<F5W<FET92!E=F5R>71H:6YG"B`@
M("`@("A097)M<SHZ+"!'<F]U<#HZ+"!3:&%R93HZ+"!E=&,N*2!T;R!U<V4@
M:70N"EMC:FA=($UO=F4@7V9I;&5#;&5A;G5P*"D@:6YT;R!(;W)D93HZ(&%S
M($AO<F1E.CID96QE=&5!=%-H=71D;W=N*"DL"B`@("`@(&%N9"!A9&0@2&]R
M9&4Z.E]D96QE=&5!=%-H=71D;W=N*"D@=&\@9&\@=&AE(&%C='5A;"!D96QE
M=&EN9RX*6V-J:%T@26YI=&EA;"!S=7!P;W)T(&9O<B!C;VYF:6=U<FEN9R!T
M:&4@<W5M;6%R>2!S8W)E96X*("`@("`@*$5R:6,@4F5C:&QI;B`\97)I8T!H
M<&-A;&,N;W)G/BDN"EMC:FA=($%D9"!A('-Y<W1E;2!F;W(@9&5F:6YI;F<@
M9V5N97)I8R!H;V]K<R!F;W(@86YY('!R969E<F5N8V4N"B`@("`@(%-E92!H
M;W)D92]C;VYF:6<O:&]O:W,N<&AP+F1I<W0@9F]R(&QO=',@;V8@97AA;7!L
M97,@86YD(&1O8W,N"EMC:FA=($%D9"!A(&-O;&]R<&EC:V5R('5T:6QI='D@
M=&\@2&]R9&4*("`@("`@*$UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^*2X*6V-J:%T@061D(&$@9W5E<W0@<V5R=FEC97,@96YT
M<GD@<&%G92!A;F0@;&EN:W,@=&\@:70@9G)O;2!A;&P*("`@("`@;&]G:6X@
M<&%G97,N"EMJ86Y=($%D9"!T<F%N<VQA=&EO;B!H96QP97(@<V-R:7!T+@I;
M;6US72!3='EL97-H965T(&QI;FL@9V5N97)A=&EO;B!H86YD;&5D(&)Y($AO
M<F1E.CIS='EL97-H965T3&EN:R@I+@I;8VIH72!!9&0@=&AE(&YE=R!#;VYF
M:6<Z.B!!4$D@86YD('-E='5P+G!H<"P@82!S>7-T96T@=VAI8V@@<F5A9',*
M("`@("`@8V]N9FEG=7)A=&EO;G,@9G)O;2!834P@9FEL97,@86YD(&5X:7-T
M:6YG(&-O;F8N<&AP(&9I;&5S+`H@("`@("!T86MI;F<@8V%R92!O9B!M97)G
M97,@86YD(&%D9&EN9R!N97<@<&%R86UE=&5R<RX@0W5R<F5N=&QY('=E"B`@
M("`@(&AA=F4@82!W96(@=VEZ87)D+@I;8VIH72!C<W,N<&AP(&YO=R!S=7!P
M;W)T<R!L;V%D:6YG($-34R!C;&%S<V5S(&9O<B!M=6QT:7!L92!A<'!L:6-A
M=&EO;G,N"EMM;7-=(%)E;6]V960@=&AE(%-E<W-I;VY#86-H92!C;&%S<RX@
M17%U:79A;&5N="!C;V1E(&ES(&YO=R!A=F%I;&%B;&4@:6X*("`@("`@=&AE
M($-A8VAE7W-E<W-I;VXZ.B!C;&%S<RX*6VUM<UT@061D960@244@8G)O:V5N
M+6)R;W=S97(@9&]W;FQO861I;F<@8V]D92!T;R!"<F]W<V5R.CHN"EMM;7-=
M($%D9&5D(&$@<V5S<VEO;B!D<FEV97(@=&\@0V%C:&4Z.BX*6V-J:%T@4F5N
M86UE(&-O;F9I9R]H;W)D92YP:'`@=&\@8V]N9FEG+V-O;F8N<&AP+@I;8VIH
M72!-;W9E(&-O;VMI95]D;VUA:6XL(&-O;VMI95]P871H+"!S97)V97)?;F%M
M92P@86YD('-E<G9E<E]P;W)T(&EN=&\*("`@("`@:&]R9&4O8V]N9BYP:'`N
M"EMC:FA=($%D9"!A('!A<F%M971E<B!F;W(@<V5T=&EN9R!T:&4@<V5S<VEO
M;B!C86-H95]L:6UI=&5R+@I;8VIH72!!9&0@34E-15]6:65W97)?=&5X="!T
M;R!(;W)D92X*6V-J:%T@4F5W<FET92!A;&P@9F%C=&]R>2]S:6YG;&5T;VX@
M;65T:&]D<R!T;R!A;&QO=R!I;F1I=FED=6%L(&%P<&QI8V%T:6]N<PH@("`@
M("!T;R!P<F]V:61E(&$@8W5S=&]M(&)A8VME;F0L(&%N9"!T;R!A;&QO=R!S
M:71E<R!T;R!P<F]V:61E(&-U<W1O;0H@("`@("!B86-K96YD<R!I;B!T:&5I
M<B!I;F-L=61E7W!A=&@@<V5T=&EN9W,N"EMM;7-=($AA;F1L:6YG(&]F($-O
M;G1E;G0M5'EP92!P87)A;65T97)S(&UO=F5D('1O($U)345?4&%R="!F<F]M
M($U)345?365S<V%G92X*6VUM<UT@0W)Y<'1?<&=P.CH@8V%N(&YO=R!U<&QO
M860@:V5Y<R!T;R!A('!U8FQI8R!K97ES97)V97(N"EMM;7-=(%)E;F%M960@
M=&AE($QA;F<Z.B!C;&%S<R!T;R!.3%,Z.B!A;F0@;6]V960@=&AE('1I;65Z
M;VYE('-E='1I;F<*("`@("`@;65T:&]D(&EN=&\@:70N"EMM;7-=(%1H92!L
M;V-A;"!T:6UE>F]N92!C86X@;F]W(&)E('-E="!V:6$@=&AE($AO<F1E.CIS
M9714:6UE>F]N92@I(&-A;&PN"EMM;7-=($%L;"!B<F]W<V5R(&AE861E<G,@
M9F]R(&1O=VYL;V%D:6YG(&$@9FEL92!H879E(&)E96X@;6]V960@=&\@=&AE
M"B`@("`@($)R;W=S97(Z.B!C;&%S<RX*6V-J:%T@061D(&9I;&5S('1O('5T
M:6P@=&\@<W5P<&]R="!E;6)E9&1I;F<@82!'54D@961I=&]R(&EN=&\@;W5R
M('!A9V5S+@I;;6US72!-24U%.CH@;F\@;&]N9V5R(&5X<&]R=',@)&UI;65?
M='EP97,@86YD("1M:6UE7V5N8V]D:6YG<R!A<R!G;&]B86P*("`@("`@=F%R
M:6%B;&5S("T@<F%T:&5R+"!-24U%.CIT>7!E*"D@86YD($U)344Z.F5N8V]D
M:6YG*"D@<VAO=6QD(&)E('5S960N"EMM;7-=(%1H92!T9WH@34E-15]6:65W
M97(@;F]W(&QI<W1S(&%L;"!F:6QE<R!W:71H;W5T('5S:6YG(&%N(&5X=&5R
M;F%L(&AE;'!E<@H@("`@("!P<F]G<F%M("A-:6-H865L($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/BDN"EMM;7-=(%1H92!R87(@34E-15]6
M:65W97(@;F]W(&QI<W1S(&%L;"!F:6QE<R!W:71H;W5T('5S:6YG(&%N(&5X
M=&5R;F%L(&AE;'!E<@H@("`@("!P<F]G<F%M("A-:6-H865L($-O8VAR86YE
M(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/BDN"EMM;7-=(%1H92!Z:7`@34E-
M15]6:65W97(@;F]W(&QI<W1S(&%L;"!F:6QE<R!W:71H;W5T('5S:6YG(&%N
M(&5X=&5R;F%L(&AE;'!E<@H@("`@("!P<F]G<F%M("A-:6-H865L($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/BDN"EMM;7-=($UA:6YT96YA
M;F-E.CH@;F]W('5S97,@<V5S<VEO;B!V87)I86)L97,@=&\@<')O=FED92!M
M=6-H(&-L96%N97(@86YD(&UO<F4*("`@("`@<F]B=7-T('!E<F9O<FUA;F-E
M+@I;;6US72!-4RU43D5&(&%T=&%C:&UE;G1S(&%R92!N;W<@:&%N9&QE9"!C
M;VUP;&5T96QY('9I82!02%`@<F%T:&5R('1H86X@=VET:`H@("`@("!A;B!E
M>'1E<FYA;"!P<F]G<F%M+@I;;6US72!!9&1E9"!A<'!L:6-A=&EO;B]M<RUT
M;F5F($U)345?5FEE=V5R+@I;;6US72!(;W)D95]#<GEP=%]P9W`@8VQA<W,@
M8V%N('%U97)Y('!U8FQI8R!K97ES97)V97)S+@I;;6US72!-24U%7U-T<G5C
M='5R93HZ<&%R<V5-24U%2&5A9&5R<R@I(&-A;B!N;W<@<&%R<V4@86QL(&AE
M861E<G,@;V8@82!-24U%"B`@("`@(&UE<W-A9V4@86YD(')E='5R;B!A;B!O
M8FIE8W0N"EMJ86Y=($%D9"!-24U%.CIR9F,X,C)7<FET94%D9')E<W,H*2!T
M;R!R97!L86-E(&EM87!?<F9C.#(R7W=R:71E7V%D9')E<W,H*2X*6VUM<UT@
M061D960@4R]-24U%($U)345?5FEE=V5R+@I;:F]N72!3=7!P;W)T(')E9F5R
M<F%L<R!B971W965N($Q$05`@<V5R=F5R<R!I;B!T:&4@3$1!4"!P<F5F97)E
M;F-E<R!D<FEV97(*("`@("`@*$ME=FEN($AI;&1E8G)A;F0@/&ME=FEN0&AQ
M+F5N<V]P;W)T+F-O;3XI+@I;8VIH72!-24U%7U-T<G5C='5R93HZ<&%R<V4H
M*2!N;W<@<F5T=7)N<R!A($U)345?365S<V%G92!O8FIE8W0*("`@("`@*$UI
M8VAA96P@32!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/BDN"EMC:FA=($-O;F9I9W5R92!A9&UI;FES=')A=&EO;B!S97)V:6-E<R!I
M;B!T:&4@4F5G:7-T<GD*("`@("`@*$UA<F-U<R!)+B!2>6%N(#QM87)C=7-`
M<FEB;V9L879I;BYN970^*2X*6V-J:%T@061D($%022!M971H;V1S(&9O<B!G
M971T:6YG('1H92!P<F5F97)E;F-E<R!A;F0@:61E;G1I=&EE<R!O9B!U<V5R
M<PH@("`@("!O=&AE<B!T:&%N('1H92!L;V=G960M:6X@=7-E<BX*6V-J:%T@
M06QL;W<@<V5T=&EN9R!T:&4@0V]N=&5N="U$:7-P;W-I=&EO;B!O9B!-24U%
M7U!A<G0@;V)J96-T<RX*6V-J:%T@061D($-R>7!T.CH@9G)A;65W;W)K("A-
M:6-H865L($T@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3XI+@I;;6%X72!!9&0@0G)O=VX@2&]R9&4@=&AE;64@*$UA<F-O($]B86ED
M(#QM87)C;T!M=7<N961U/BDN"EMJ;VY=($%L;&]W('1H92!,1$%0('9E<G-I
M;VX@=&\@8F4@<W!E8VEF:65D(&9O<B!T:&4@3$1!4"!P<F5F97)E;F-E<R!D
M<FEV97(N"EMJ86Y=($%D9"!T:&5M92!P<F5F97)E;F-E+@I;:F%N72!!9&0@
M8V%L;&)A8VL@9G5N=&EO;B!F;W(@<')E9F5R96YC97,N"EMJ;VY=(%)E;6]V
M92!T:&4@)&-O;F9;)VUE;G4G75LG9FQO871I;F=?8F%R)UT@9G5N8W1I;VYA
M;&ET>2X*6VIA;ET@3&]A9"!O;FQY(&QO9VEN('!A9V4@;VX@<W1A<G1U<"!A
M;F0@<F5D:7)E8W0@=&\@9G)A;65S970@869T97(@;&]G:6XN"EMC:FA=($1O
M;B=T(&%L;&]W(&%N;VYY;6]U<R!A8V-E<W,@=&\@<')O8FQE;2YP:'`N"EMC
M:FA=($%D9"!E;E]'0B!L;V-A;&4N"EMC:FA=(%)E;6]V92!E>'1E;G-I;VYS
M(&]N('1E;7!O<F%R>2!F:6QE<SL@=&AI<R!I<R!A('1E;7`@<F%C92!H;VQE
M+@I;8VIH72!!;&QO=R!F;W(@875T;RUC<F5A=&EO;B!O9B!P97)M:7-S:6]N
M<R`H;75L=&EP;&4@;&5V96QS(&]F(&AI97)A<F-H>2DN"EMC:FA=($%D9"!A
M9&1I;F<O<F5M;W9I;F<@;V8@=7-E<G,@9G)O;2!G<F]U<',N"EMC:FA=($-R
M96%T92!T96UP(&9I;&5S('=I=&@@=&AE(')I9VAT(&5X=&5N<VEO;B!I;B!-
M24U%7U9I97=E<E]E;G-C<FEP=#HZ('-O"B`@("`@(&5N<V-R:7!T(&AA<R!M
M;W)E(&-L=65S('1O(&=U97-S(&9I;&4@='EP92X*6V-J:%T@5&AE(&%D;6EN
M:6YS=')A=&EO;B!I;G1E<F9A8V4@9F]R($=R;W5P<R!A;F0@4&5R;6ES<VEO
M;G,@:7,@;F]W"B`@("`@(&UO<W1L>2!F=6YC=&EO;F%L+@I;8VIH72!-86ME
M(&%P<&QI8V%T:6]N(&%U=&AE;G1I8V%T:6]N(&%N($%U=&@Z.B!D<FEV97(L
M(&EN<W1E860@;V8@82!S<&5C:6%L"B`@("`@(%)E9VES=')Y(&-A<V4N"EMC
M:FA=($9I>"!P<F]B;&5M<R!W:71H('1H92!.;W1I9FEC871I;VX@<W1A8VL@
M86YD(')E9VES=&5R7V=L;V)A;',@8F5I;F<@;V9F+@I;:F]N72!!;'1E<B!(
M;W)D93HZ:6UG*"D@=&\@97AP;&EC:71L>2!A8V-E<'0@86X@86QT/2(B(&%T
M=')I8G5T92X*("`@("`@2&]R9&4Z.FEM9R@I(&YO=R!G96YE<F%T97,@=&ET
M;&4](B(@871T<FEB=71E<R!B87-E9"!O;B!T:&4@86QT/2(B('1E>'0L"B`@
M("`@('1O;RX*6V-J:%T@3F]T:69I8V%T:6]N.CIN;W1I9GDH*2!P87-S97,@
M=&AE(&UE<W-A9V4@<W1A8VL@=&\@86QL(&QI<W1E;F5R<RP@<V\@=&AA=`H@
M("`@("!L:7-T96YE<G,@9&]N)W0@:&%V92!T;R!K;F]W(&%B;W5T('1H92!M
M97-S86=E('-T86-K+"!A;F0@87!P('=R:71E<G,*("`@("`@9&]N)W0@:&%V
M92!T;R!K;F]W(&%B;W5T(&%L;"!P;W-S:6)L92!L:7-T96YE<G,N"EMC:FA=
M(%)E<&QA8V4@=&AE($A/4D1%7RH@;65S<V%G92!C;VYS=&%N=',@=VET:"`G
M:&]R9&4N97)R;W(G+"!E=&,N(&9O<@H@("`@("!G<F5A=&5R(&9L97AI8FEL
M:71Y+@I;8VIH72!296UO=F4@2&]R9&4Z.G)A:7-E365S<V%G92@I(&YO=R!T
M:&%T('1H92!.;W1I9FEC871I;VX@<WES=&5M"B`@("`@('!R;W9I9&5S('1H
M870@9G5N8W1I;VYA;&ET>2X*6V-J:%T@57-E('1H92!N97<@3F]T:69I8V%T
M:6]N('-Y<W1E;2X*6V-J:%T@4F5M;W9E(&]T:&5R(%)E9VES=')Y(&=E="@I
M(&UE=&AO9',N"EMJ;VY=(%)E;6]V92!S=7!P;W)T(&9O<B!T:&4@:&]R9&5?
M;&%N9W5A9V4@8V]O:VEE+@I;:F%N72!-;W9E('1H92!M86EN=&5N86-E(&9R
M86UE=V]R:R!F<F]M($E-4"!T;R!(;W)D92`H36EC:&%E;"!-(%-L=7-A<GH*
M("`@("`@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^*2X*"@HM+2TM
M+2T*=C(N,BXY"BTM+2TM+0H*6VIA;ET@1FEX('!O=&5N=&EA;"!84U,@=G5L
M;F5R86)I;&ET>2!D=64@=&\@;F]T('!R;W!E<FQY(&5S8V%P960@97)R;W(*
M("`@("`@;65S<V%G97,N"@H*+2TM+2TM"G8R+C(N.`HM+2TM+2T*"EMJ86Y=
M($-L;W-E(%A34R!W:&5N('-E='1I;F<@=&AE('!A<F5N="!F<F%M92=S('!A
M9V4@=&ET;&4@8GD@:F%V87-C<FEP="`H8VIH*2X*"@HM+2TM+2T*=C(N,BXW
M"BTM+2TM+0H*6V-J:%T@4F5S=&]R92!C;VUP871I8FEL:71Y('=I=&@@4$A0
M(#0N,2X*6VIA;ET@1FEX('!O=&5N=&EA;"!84U,@=G5L;F5R86)I;&ET>2!I
M;B!T:&4@:&5L<"!W:6YD;W<N"EMJ86Y=($9I>"!C:&%R<V5T(&9O<B!,871V
M:6%N('1R86YS;&%T:6]N("A"=6<@(S8U-BDN"@H*+2TM+2TM"G8R+C(N-@HM
M+2TM+2T*"EMJ86Y=(%5S92!$0CHZ<')E<&%R92]$0CHZ97AE8W5T92!/3DQ9
M(&9O<B!/<F%C;&4@=&\@879O:60@:6UP;&EC:71L>2!R97%U:7)I;F<*("`@
M("`@4$A0(#0N,B!F;W(@86QL(&]T:&5R(%)$0DUS+@I;8VIH72!&:7@@3W)A
M8VQE('-E<W-I;VX@:&%N9&QE<BX*6V-J:%T@061D(%-13"!S8W)I<'1S(&9O
M<B!/<F%C;&4@86YD(%!O<W1G<F5344P@<V5S<VEO;B!H86YD;&5R<RX*6VIA
M;ET@1&]N)W0@<W1R:7`@=')A:6QI;F<@<W!A8V5S(&9R;VT@<VEG;F%T=7)E
M(&1A<VAE<R!I;B!)35`N"@H*+2TM+2TM+2TM+0IV,BXR+C8M4D,Q"BTM+2TM
M+2TM+2T*"EMC:FA=($9I>"!S=7!P;W)T(&9O<B!C=7-T;VT@<V5S<VEO;B!H
M86YD;&5R<RX*6V-J:%T@57-E($1".CIP<F5P87)E+T1".CIE>&5C=71E(&EN
M('1H92!0<F5F<U]S<6P@9')I=F5R(&9O<B!B971T97(@<W5P<&]R=`H@("`@
M("!O9B!L87)G92!F:65L9',@;VX@9&%T86)A<V5S('-U8V@@87,@3W)A8VQE
M+@I;:F%N72!3:&]W('1H92!U<V5R)W,@9G5L;"!N86UE(&]N('1H92!S=6UM
M87)Y('-C<F5E;B!D:7)E8W1L>2!A9G1E<B!L;V=G:6YG"B`@("`@(&EN("A$
M+B!!9&%M($MA<FEM(#QA9&%M0&%K87)S;V9T+F-O;3XI+@I;:F%N72!&:7@@
M:F%V87-C<FEP="!E<G)O<B!I;B`B4')O8FQE;2(@<&%G92!W:71H('-O;64@
M=')A;G-L871I;VYS("A"=6<@(S8Q*2X*6V-J:%T@1FEX(&AA;F1L:6YG(&]F
M(%!O<W1G<F5344P@8FQO8G,@*$)U9R`C-#0I+@H*"BTM+2TM+0IV,BXR+C4*
M+2TM+2TM"@I;:F%N72!!9&0@26YD;VYE<VEA;B!L86YG=6%G92`H4VQA;6EN
M(#QS;&%M:6Y`=6YE:BYA8RYI9#XI+@I;:F%N72!!9&0@1V%L:6-I86X@=')A
M;G-L871I;VX@*%)A9F%E;"!687)E;&$@4&5T(#QS<G)A9F%`=7-C+F5S/BP@
M1W5I;&QE<FUO"B`@("`@($UE;F1E>B`\9W5I;&QE0'5S8RYE<SXI+@I;;6US
M72!&:7@@9&]W;FQO861I;F<@;V8@9FEL97,@=VET:"!S<&%C97,@:6X@36]Z
M:6QL82X*"@HM+2TM+2T*=C(N,BXT"BTM+2TM+0H*6VUD:ET@4T5#55))5%DZ
M($%D9"!D97)E9F5R97(@=&\@<W1R:7`@;V9F('-E<W-I;VX@:6YF;W)M871I
M;VX@9G)O;2!L:6YK<R!T;PH@("`@("!T:&4@;W5T<VED92!O9B!T:&4@2&]R
M9&4@<WES=&5M('1O('!R;W1E8W0@86=A:6YS="!S97-S:6]N(&AI:F%C:VEN
M9RX*6VUM<UT@4T5#55))5%DZ($%D9"!C;V1E('1O('!R;W1E8W0@86=A:6YS
M="!S97-S:6]N(&9I>&%T:6]N(&ES<W5E<RX*6VIA;ET@1FEX(&$@8G5G('=I
M=&@@:6UP;W)T:6YG('9#87)D(#(N,2!D871A+@I;:F%N72!!9&0@07)A8FEC
M("A3>7)I82D@=')A;G-L871I;VX@*%!L871I;G5M($1E=F5L;W!M96YT(%1E
M86T*("`@("`@/&1E=G1E86U`<&QA=&EN=6TM<WDN;F5T/BDN"EMJ86Y=($%D
M9"!-86-E9&]N:6%N('1R86YS;&%T:6]N("A3=&]J86X@4&5S;W8@/'-S<$!E
M=7)E:V$N8V]M+FUK/BDN"EMM:7)=($9I>"!A(&)U9R!T:&%T(&EN8V]R<F5C
M=&QY('%U;W1E<R!P<F5F('9A;'5E<R`H0G5G(",Q,C(T*0I;8VIH72!&:7@@
M82!B=6<@=&AA="!P<F5V96YT960@;&]G9VEN9RX*6VUM<UT@1$(@<V5S<VEO
M;B!H86YD;&5R<R!D;R!N;W0@=7-E('!E<G-I<W1E;G0@8V]N;F5C=&EO;G,@
M8GD@9&5F875L="X*"@HM+2TM+2T*=C(N,BXS"BTM+2TM+0H*6VUM<UT@1FEX
M('!A<G-E(&5R<F]R(&EN($AO<F1E7T-I<&AE<E]";&]C:TUO9&5?;V9B-C0Z
M.BX*"@HM+2TM+2T*=C(N,BXR"BTM+2TM+0H*6VUM<UT@3W!T:6UI>F%T:6]N
M(&]F(%-E8W)E=#HZ(&%N9"!(;W)D95]#:7!H97(Z.B!D<FEV97)S+@I;:F%N
M72!!9&0@0V%T86QA;B!T<F%N<VQA=&EO;B`H06YG96QS($=U:6UE<N`@/&%N
M9V5L<RY'=6EM97)A0'5A8BYE<SXI+@I;;6US72!!9&1E9"!A(%)!1$E54R!!
M=71H.CH@9')I=F5R+@I;;6ER72!!9&1E9"!A(%-A;6)A($%U=&@Z.B!D<FEV
M97(N"EMC:FA=($%D9&5D('1H92!(;W)D95]);6%G93HZ(&-L87-S+@H*"BTM
M+2TM+0IV,BXR+C$*+2TM+2TM"@I;:F%N72!&:7@@:6YC;VUP871I8FEL:71Y
M('=I=&@@4$A0(#P@-"XR+C`@:6X@=&AE(%-13"!61E,@9')I=F5R+@I;:F%N
M72!&:7@@=6YD969I;F5D('9A<FEA8FQE(&EN($-I<&AE<BYP:'`@*&-J:"DN
M"EMM;7-=($-O;7!L971E(&UE<F=I;F<@;V8@4U%,('-E<W-I;VX@:&%N9&QE
M<BX*"@HM+2TM"G8R+C(*+2TM+0H*6V-J:%T@061D('-U<'!O<G0@9F]R('5S
M97(M9&5F:6YE9"!S97-S:6]N(&AA;F1L97)S"B`@("`@("A-:6ME($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/BDN"EMM86-=($-H86YG92!3
M96-R970Z.B!F<F]M('5S:6YG(%!%05(@0W)Y<'1?2$-%340U('1O('1H92!(
M;W)D95]#:7!H97(@8VQA<W,N"EMM86-=($%D9"!(;W)D95]#:7!H97(Z.B!C
M;&%S<R!T;R!P<F]V:61E(&$@8V]M;6]N(&%B<W1R86-T960@:6YT97)F86-E
M('1O"B`@("`@('9A<FEO=7,@0VEP:&5R<R!F;W(@96YC<GEP=&EO;B!O9B!A
M<F)I=')A<GD@;&5N9W1H('!I96-E<R!O9B!D871A+@I;;6US72!#;W)R96-T
M;'D@9V5T(&-H87)S970@:6YF;W)M871I;VX@9F]R($U)345?4&%R=',@:6X@
M34E-15]3=')U8W1U<F4N"EMJ86Y=($%D9"!,871V:6%N('1R86YS;&%T:6]N
M("A+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^*2X*6VIA;ET@
M061D(%)O;6%N:6%N('1R86YS;&%T:6]N("A#;W)N96QI=2!-55-!5"`\8VUU
M<V%T0'1I86UA="YK97ES>7,N<F\^*2X*6VIO;ET@061D960@<W5P<&]R="!F
M;W(@86X@/&5R968^(&5N=&ET>2!T;R!T:&4@:&5L<"!S>7-T96TN("!4:&ES
M(&%L;&]W<R!A;@H@("`@("!E>'1E<FYA;"!L:6YK('1O(&)E(&5M8F5D9&5D
M(&EN(&$@:&5L<"!E;G1R>2X@*#QG+FAO<G1`=6YS=RYE9'4N874^*0I;8VIH
M72!296YA;64@5D93.CH@=&\@2&]R9&5?5D93.CH@9F]R(%!%05(@<&%C:V%G
M:6YG+@I;8VIH72!61E,Z.B!I<R!N;W<@<&%C:V%G960@<V\@=&AA="!I="!C
M86X@8F4@97AP;W)T960@87,@82!014%2(&-O;7!O;F5N="X*6V-J:%T@061D
M(&$@;75L=&DM=7-E<B!344P@5D93(&)A8VME;F0@*$UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6V-J:%T@5&AE(%9&4R!A<&D@
M;F]W(&-O;G-I<W1E;G1L>2!T86ME<R!A('1E;7`@9FEL92!I;B!T:&4@=W)I
M=&4H*2!M971H;V0*("`@("`@86-R;W-S(&%L;"!B86-K96YD<R`H36EC:&%E
M;"!687)G:&5S92`\;6EK92YV87)G:&5S94!A<V-E;&QA=&5C:"YC;VT^*2X*
M6V-J:%T@061D(&$@5D93($%022!F;W(@<W1O<F%G92!O9B!F:6QE<R!I;B!A
M;B!A8G-T<F%C=&5D(&9I;&5S>7-T96TN"EMC:FA=($%D9"!A('!R969E<F5N
M8V4@=&\@86QL;W<@;6%I;G1E;F%N8V4@;W!S('=I=&@@;F\@8V]N9FER;6%T
M:6]N('-C<F5E;@I;8VIH72!297!L86-E("=S:&]W)R!A='1R:6)U=&4@:6X@
M=&AE(')E9VES=')Y('=I=&@@82!M;W)E(&9L97AI8FQE("=S=&%T92<*("`@
M("`@871T<FEB=71E+@I;:F%N72!!;&QO=R!S971T:6YG('1H92!N=6UB97(@
M;V8@8V]L=6UN<R!I;B!T:&4@<W5M;6%R>2!S8W)E96X@87,@82!U<V5R"B`@
M("`@('!R969E<F5N8V4@*$)R:6%N($ME:69E<B`\8G)I86Y`=F%L:6YO<BYN
M970^*2X*6V-J:%T@061D($AO<F1E.CIG971'970H*2!A;F0@2&]R9&4Z.F=E
M=%!O<W0H*2X*6V-J:%T@061D(&%N(&EN:71I86Q?87!P;&EC871I;VX@<')E
M9F5R96YC92!S;R!U<V5R<R!C86X@<V5L96-T(&%N(&%P<`H@("`@("!T;R!B
M92!T86ME;B!T;R!I;G-T96%D(&]F('1H92!(;W)D92!3=6UM87)Y(&]N(&QO
M9VEN+@I;8VIH72!-86ME('1E>'0L(&EC;VXL(&]R(&)O=&@@;65N=7,@82!U
M<V5R('!R969E<F5N8V4*("`@("`@*$MA86Q((2`\:V%A;&A`<VUO;"YO<F<^
M*2X*6V-J:%T@061D(&$@<&%R86UE=&5R(&9O<B!S971T:6YG('1H92!S97-S
M:6]N('1I;65O=70N"EMC:FA=($%D9"!A('!A<F%M971E<B!F;W(@<V5T=&EN
M9R!T:&4@<V5S<VEO;B!D96QI;6ET97(N"EMM;7-=($%D9"!-24U%7TUA9VEC
M.CIF:6QE;F%M951O34E-12@I+@I;:F%N72!5<V4@87)G7W-E<&%R871O<BYO
M=71P=70@:6YS=&5A9"!O9B!H87)D8V]D:6YG("<F)R`H1&%V:60@56QE=FET
M8V@*("`@("`@/&1A=FED=4!E=F5R>61N<RYN970^*2X*6VIA;ET@061D($YO
M=&EF:6-A=&EO;CHZ8V]U;G0H*2`H1&%V:60@56QE=FET8V@@/&1A=FED=4!E
M=F5R>61N<RYN970^*2X*6V-J:%T@061D($%U=&@Z.FES061M:6XH*2X*6V-J
M:%T@06QL;W<@;&]A9&EN9R!O9B!S=6(M8VQA<W-E<R!F<F]M('-E=F5R86P@
M861D:71I;VYA;"!S;W5R8V5S+@I;:F%N72!296UO=F4@<F5F97)E;F-E<R!T
M;R!N;W0@>65T(')E;&5A<V5D(&%P<&QI8V%T:6]N<R`H1V]L;&5M+"!4<F]L
M;"DN"EMC:FA=(%)E=W)I=&4@0V%T96=O<GE?<W%L(&EM<&QE;65N=&%T:6]N
M('1O(&)E(&UU8V@@;6]R92!E9F9I8VEE;G0N"EMJ86Y=($%D9"!,:71H=6%N
M:6%N('1R86YS;&%T:6]N("A$87)I=7,@36%T=6QI875S:V%S(#QD87)I=7-`
M;&YK+FQT/BDN"EMM;7-=($%D9"!(;W)D93HZ8V]M<')E<W-/=71P=70H*2X*
M6VUM<UT@061D(&$@:V5R8F5R;W,@075T:#HZ(&1R:79E<BX*6VIA;ET@061D
M($)U;&=A<FEA;B!T<F%N<VQA=&EO;B`H36ER;W-L878@4&5N9&5V(#QP96YD
M979`:&]T;6%I;"YC;VT^*2X*6VIA;ET@4F5M;W9E(&1E<')E8V%T960@1$(Z
M.FES5V%R;FEN9R@I(&-A;&QS+@I;;6US72!!9&0@2&]R9&4Z.F-R96%T951E
M;7!$:7(H*2X*6V-J:%T@061D($AO<F1E.CIU<VEN9U-33$-O;FYE8W1I;VXH
M*2X*6V-J:%T@4F5P;&%C92`\/ST@=VET:"`\/W!H<"!E8VAO('1O(')E;6]V
M92!T:&4@<VAO<G1?;W!E;E]T86=S(')E<75I<F5M96YT+@I;:F%N72!!9&0@
M5&5X=#HZ=&](5$U,*"DL(%1E>'0Z.FAI9VAL:6=H=%%U;W1E<R@I(&%N9"!4
M97AT.CID:6U3:6=N871U<F4H*2X*6V-J:%T@061D(%)E9VES=')Y.CIL:7-T
M07!P<R@I+@I;8VIH72!!9&0@4')E9G,Z.F=E=%!R968H*2!F;W(@9V5T=&EN
M9R!P<F5F97)E;F-E<R!F;W(@<V]M96]N92!O=&AE<B!T:&%N('1H90H@("`@
M("!L;V=G960M:6X@=7-E<BX*6V-J:%T@061D('1H92!A8FEL:71Y('1O(&QO
M860@:61E;G1I=&EE<R!F;W(@<V]M96]N92!O=&AE<B!T:&%N('1H92!L;V=G
M960M:6X*("`@("`@=7-E<BX*6VUM<UT@061D($AO<F1E.CIR96UO=F5087)A
M;65T97(H*2X*6VUM<UT@06QL(&)R;W=S97(@:&5A9&5R<R!F;W(@9&]W;FQO
M861I;F<@82!F:6QE(&AA=F4@8F5E;B!M;W9E9"!T;R!T:&4*("`@("`@0G)O
M=W-E<CHZ(&-L87-S+@I;:F%N72!!9&0@9&5T96-T:6]N(&9O<B!55$8@8V%P
M86)I;&ET>2!T;R!"<F]W<V5R(&-L87-S+@I;;6US72!!9&1E9"!I;6%G97,@
M34E-15]6:65W97(N"EMB:FY=($%D9"!0;W-T9W)E4U%,(&-O;6UA;F0@9FQA
M9R`H4FEC:&%R9"!'($MO;FQO;B`\4D=+;VYL;VY`,4UA:6Q0;&%C92YC;VT^
M*2X*"@HM+2TM"G8R+C$*+2TM+0H*6VIA;ET@061D($AU;F=A<FEA;B!T<F%N
M<VQA=&EO;B`H3&%S>FQO($PN(%1O<FYO8VD@/'1O<FQA<WI`>&5N:6$N<V]T
M92YH=3XI+@I;:F%N72!!9&0@3F]R=V5G:6%N($YY;F]R<VL@=')A;G-L871I
M;VX@*%!E<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R9SXI+@I;:F]N72!-
M86IO<B!O=F5R:&%U;"!T;R!T:&4@3$1!4"!P<F5F97)E;F-E<R!D<FEV97(N
M($YO=&4@=&AE(&-H86YG97,@=&\*("`@("`@8V]N9FEG+VAO<F1E+G!H<"!A
M;F0@<V-R:7!T<R]L9&%P+VAO<F1E+G-C:&5M82!W:&5N('5P9W)A9&EN9RX*
M6VIA;ET@061D(%-L;W9E;FEA;B!T<F%N<VQA=&EO;B`H2G5R92!+<F%S;W9I
M8R`\:G5R96M`<F-C+6ER8RYS:3XI+@I;8VIH72!!9&0@82!(;W)D92!P<F5F
M97)E;F-E<R!S8W)E96XL(&%N9"!A('!R969E<F5N8V4@=&\@<F5F<F5S:"!T
M:&4@<W5M;6%R>0H@("`@("!S8W)E96XN"EMC:FA=($%D9"!T97AT+V5N<FEC
M:&5D($U)345?5FEE=V5R"B`@("`@("A%<FEC(%)O<W1E='1E<B`\97)I8RYR
M;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/BDN"EMJ86Y=($EM<')O=F4@
M;&%N9W5A9V4@<V5L96-T:6]N+@I;:F%N72!!9&0@2F%P86YE<V4@=')A;G-L
M871I;VX@*$(N2BX@0FQA8VL@/'=I;&QI86TN8FQA8VM`<W5N+F-O;3XI+@I;
M8VIH72!#;&]S92!A('!O=&5N=&EA;"!P<F]B;&5M('=I=&@@<F5G:7-T97)?
M9VQO8F%L<R!/;B!A;F0@)&IS7V]N3&]A9"X*6VIA;ET@061D(%!R969S.CII
M<T1E9F%U;'0H*2!M971H;V0@=&\@9&5T97)M:6YE(&EF(&$@<')E9F5R96YC
M92=S('9A;'5E(&ES"B`@("`@('-E="!B>2!T:&4@=7-E<B!O<B!T:&4@9&5F
M875L="!V86QU92!F<F]M('!R969S+G!H<"X*6VIO;ET@3W9E<FAA=6QE9"!,
M1$%0('!R969E<F5N8V5S(&1R:79E<BX*6V-J:%T@36%K92!(;W)D93HZ9&ES
M<&5L36%G:6-1=6]T97,H*2!R96-U<G-I=F4L('-O('1H870@:70@:&%N9&QE
M<R!A<G)A>7,N"EMC:FA=($AA=F4@4V5C<F5T.CIS971+97DH*2!C:&5C:R!F
M;W(@=&AE('-E<W-I;VX@8V]O:VEE(&5X<&QI8VET;'DL('1O(&%V;VED"B`@
M("`@('!R;V)L96US('=I=&@@;VQD(&-O;VMI97,@8F5I;F<@<V5N="!T;R!A
M('-I=&4@=VAE;B!T:&5Y(&%R92!R96%L;'D*("`@("`@9&ES86)L960N"EMC
M:FA=($%D9"!A(%!R969S54D@8VQA<W,@9F]R(&AA;F1L:6YG('1H92!F;W)M
M('!R;V-E<W-I;F<@86YD(%5)(&=E;F5R871I;VX*("`@("`@9F]R('5S97(@
M<')E9F5R96YC97,[('1H:7,@8V]D92!W87,@9'5P;&EC871E9"!A;&P@=&AR
M;W5G:"!(;W)D92X*6V-J:%T@061D(&$@;6%P<&EN9R!F=6YC=&EO;B!T;R!T
M:&4@96YS8W)I<'0@9')I=F5R('=H:6-H(&UA<',@9FEL90H@("`@("!E>'1E
M;G-I;VYS('1O(&5N<V-R:7!T(&QA;F=U86=E(&-O9&5S+"!A;F0@<&%S<R!T
M:&4@;&%N9W5A9V4*("`@("`@9&ER96-T;'D@=&\@96YS8W)I<'0L('1O(&%V
M;VED(&AA=FEN9R!T;R!U<V4@82!F:6QE(&5X=&5N<VEO;BX*6V-J:%T@1FEX
M($U)345?36%G:6,Z.DU)3454;T5X="@I('1O('=O<FL@=VET:"!X+65X=&5N
M<VEO;B]E>'0@='EP97,N"EMC:FA=($%D9"!-24U%7TUA9VEC.CI-24U%5&]%
M>'0H*2!T;R!M87`@34E-12!T>7!E<R!T;R!F:6QE(&5X=&5N<VEO;G,N"EMC
M:FA=(%)E=W)I=&4@4&5R;7,Z.B!T;R!U<V4@=&AE($-A=&5G;W)I97,@8F%C
M:V5N9"X*6VIA;ET@0VAA;F=E('1H92!.;W)W96=I86X@0F]K;6%L(&QO8V%L
M92!F<F]M(&YO7T)/2R!T;R!N8E].3R!A;F0@;6%K92!I="!T:&4*("`@("`@
M9&5F875L="!L86YG=6%G92!F;W(@3F]R=V5G:6%N('5S97)S+@I;8VIH72!-
M86ME($AO<F1E)W,@;&]G:6X@<V-R965N(&YI8V5R.R!I;F-L=61E(')E87-O
M;G,@:6X@:70N"EMC:FA=(%5S92!(3U)$15]414U03$%415,@9F]R(&%L;"!T
M96UP;&%T92!P871H<RX*6V-J:%T@57-E("1R96=I<W1R>2T^9V5T*"D@9F]R
M(&%L;"!296=I<W1R>2!I;F9O<FUA=&EO;BX*6V-J:%T@4F5M;W9E9"!A9&UI
M;FES=')A=&EO;B!C;V1E('=H:6-H(&ES(&EN8V]M<&QE=&4@86YD(&-O;F9U
M<VEN9R!T;R!U<V5R<RX*6VIA;ET@061D($5S=&]N:6%N('1R86YS;&%T:6]N
M("A4;V]M87,@06%S(#QT;V]M87,N86%S0')A860N=&%R='4N964^*2X*6VIA
M;ET@061D(%-L;W9A:R!T<F%N<VQA=&EO;B`H3&5O($UR869K;R`\;&5O0&]E
M;"YS:SXI+@I;:F]N72!%;F%B;&4@=&AE(")P;W)T86)I;&ET>2(@;W!T:6]N
M(&EN('1H92!014%2($1"("AS<6PI(&1R:79E<G,N"EMC:FA=(%5S92!(;W)D
M92=S("=I;FET:6%L7W!A9V4G(&-O;F9I9W5R871I;VX@=F%L=64@:6X@=&AE
M($AO<F1E(&9R86UE<V5T+@I;:F%N72!!9&0@4&]R='5G=65S('1R86YS;&%T
M:6]N("A.=6YO($QO=7)E:7)O(#QN=6YO0&5T:"YP=#XI+@I;:F%N72!296)U
M:6QD('1H92!L86YG=6%G92!S96QE8W1I;VX@;&]G:6,N(%1H92!L86YG=6%G
M92!S96QE8W1E9"!O;B!T:&4@;&]G:6X*("`@("`@<V-R965N(&ES(&YO=R!R
M97-P96-T960@86YD('1H92!S:71E)W,@<W1A;F1A<F0@;&%N9W5A9V4@:7,@
M9&5F:6YE9"!I;@H@("`@("!L86YG+G!H<"!I;G-T96%D(&]F(&5A8V@@87!P
M;&EC871I;VXG<R!P<F5F97)E;F-E<RX*6VIA;ET@061D(&IA=F%S8W)I<'0@
M=&\@<V5T('1H92!F<F%M97-E="=S('!A9V4@=&ET;&4@*$UI8VAA96P@0V]C
M:')A;F4*("`@("`@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VIA;ET@
M061D(%5K<F%I;FEA;B!T<F%N<VQA=&EO;B`H06YD<FEY($MO<'ES='EA;G-K
M>2`\86YR:4!P;VQY;F5T+FQV:78N=6$^*2X*6VIA;ET@57!D871E(&=E='1E
M>'0@9&]C=6UE;G1A=&EO;B!A;F0@36%K969I;&5S(&9O<B!3;VQA<FES(&%N
M9"!$96)I86XN"EMJ;VY=($UA:6YT96YA;F-E(&9I>&5S(&9R;VT@36EC:&%E
M;"!-(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^+@I;
M:F%N72!!9&0@1&%N:7-H('1R86YS;&%T:6]N("A-87)T:6X@3&ES="U0971E
M<G-E;B`\;6%R=&EN0&QI<W0M<&5T97)S96XN9&L^*2X*"@HM+2TM"G8R+C`*
M+2TM+0H*6VIA;ET@061D($YO<G=E9VEA;B!";V]K;6%L('1R86YS;&%T:6]N
M("A/>7-T96EN(%-T96EM;&5R(#QO>7-T96EN0')E>'1A+FYE=#XI+@I;879S
M;5T@061D("YH=&%C8V5S<R!F:6QE<R!T;R!D96YY(&%C8V5S<R!T;R!D871A
M(&1I<F5C=&]R:65S+@I;:F%N72!!9&0@1FEN;FES:"!T<F%N<VQA=&EO;B`H
M3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3XI+@I;8VIH72!&:7@@;VYE(&QA
M<W0@<')O8FQE;2!W:71H(%!/4#,@86YD(&UU;'1I<&%R="]A;'1E<FYA=&EV
M92!A='1A8VAM96YT<RX*"@HM+2TM+2TM+0IV,BXP+5)#-`HM+2TM+2TM+0H*
M6W)I8VA=($EN8VQU9&4@<F5W<FET=&5N(&%N9"!R96]R9V%N:7IE9"!D;V-U
M;65N=&%T:6]N+@I;8VIH72!!9&0@86X@35-0;W=E<G!O:6YT($U)345?5FEE
M=V5R+@I;:F%N72!4:&4@;&%N9W5A9V4@8V]O:VEE('=A<R!R96UO=F5D(&EN
M(&9A=F]R(&]F(&YE=R!M971H;V1S(&EN('1H92!,86YG.CH*("`@("`@8VQA
M<W,@=&AA="!S96QE8W0@=&AE(&QA;F=U86=E(&%N9"!S970@=&AE(&=E='1E
M>'0@9&]M86EN+@I;879S;5T@26YC;'5D92!#:&]R82!I;B!T:&ES(')E;&5A
M<V4@8WEC;&4L(&)U="!N;W0@<VAO=VEN9R!I;B!T:&4@=&]O;&)A<BX*6V-J
M:%T@061D($U)345?5FEE=V5R7WII<"X*6V-J:%T@5')I;2!R96=I<W1R>2YP
M:'`N9&ES="!T;R!O;FQY(&QI<W0@87!P<R!I;B!T:&ES(')E;&5A<V4@8WEC
M;&4N"EMJ86Y=($%D9"!D96QE=&5/8FIE8W0H*2!M971H;V0@=&\@=&AE(%-E
M<W-I;VY#86-H92!C;&%S<RX*6V)J;ET@0VAA;F=E("=E;B<@86YD("=E;E]%
M3B<@;&]C86QE<R!T;R`G96Y?55,G("AD969A=6QT*2X*"@HM+2TM+2TM+0IV
M,BXP+5)#,PHM+2TM+2TM+0H*6V-J:%T@4F5C;V=N:7IE(&$@9F5W(%!A;&TN
M;F5T(&)R;W=S97)S(&%N9"!S970@<75I<FMS+V9E871U<F5S(&%C8V]R9&EN
M9VQY+@I;8VIH72!3=7!P;W)T(&9O<B!A9&1I;F<@86YD(&QI<W1I;F<@3$1!
M4"!U<V5R<R!G:79E;B!A('-E="!S8VAE;6$N"EMC:FA=(%-E="!T:&4@<V5S
M<VEO;B!C;V]K:64@<&%R86UE=&5R<R!W:71H(&]U<B!C;V]K:65?<&%T:"]C
M;V]K:65?9&]M86EN"B`@("`@('-E='1I;F=S+B!4:&ES(&UE86YS('1H870@
M>6]U(&-A;B!B92!L;V=G960@:6YT;R!M=6QT:7!L92!(;W)D90H@("`@("!I
M;G-T86QL871I;VYS(&]N('1H92!S86UE('-E<G9E<B`H9&EF9F5R96YT('!A
M=&AS*2!A;F0@;F]T(&AA=F4@=&AE"B`@("`@('-E<W-I;VYS(&EN=&5R9F5R
M92X*6V-J:%T@57-E("=H;W-T<W!E8R<@8V]N<VES=&5N=&QY(&EN($%U=&@@
M9')I=F5R<RX*"@HM+2TM+2TM+0IV,BXP+5)#,0HM+2TM+2TM+0H*6VIA;ET@
M061D($)R87II;&EA;B!0;W)T=6=U97-E('1R86YS;&%T:6]N("A#87)L;W,@
M1&%N:65L($MI8G)I="`\:VEB<FET0'1E<G)A+F-O;2YB<CXI+@I;:F%N72!!
M9&0@1W)E96L@=')A;G-L871I;VX@*%-T969A;F]S($DN($1I;6ET<FEO=2`\
M<V1I;6ET<FE`=&5I871H+F=R/BDN"EMJ86Y=($%D9"!V0V%R9"!-24U%(&1R
M:79E<BX@0VAA;F=E9"!C;VYF:6<O;6EM95]D<FEV97)S+G!H<"YD:7-T+@I;
M:F%N72!!9&0@4W=E9&ES:"!T<F%N<VQA=&EO;B`H06YD<F5A<R!$86ALZ6X@
M/&%N9')E87-`9&%H;&5N+G=S/BDN"EMJ86Y=($%D9"!+;W)E86X@=')A;G-L
M871I;VX@*$HN22!+:6T@/&%P;W)I94!N971I86XN8V]M/BDN"@H*+2TM+2TM
M"G8Q+C,N-0HM+2TM+2T*"EMJ;VY=($%D9&5D("1F:6QE(&%N9"`D;&EN92!P
M87)A;65T97)S('1O($AO<F1E.CIF871A;"@I+@I;:F]N72!296UO=F5D('1H
M92!04D5&4U\J(&%N9"!!551(7RH@8V]N<W1A;G1S(&EN(&9A=F]R(&]F(%!%
M05)?17)R;W(@;V)J96-T<RX*6V%V<VU=($1O;B=T(&1E<&5N9"!O;B!T:&4@
M<F5G:7-T<GD@8F5I;F<@879A:6QA8FQE('=H96X@9&ES<&QA>6EN9PH@("`@
M("!T:&4@)TAO<F1E(&ES(&YO="!C;VYF:6=U<F5D)R!M97-S86=E+@I;8VIH
M72!#;&5A;B!U<"!T:&4@261E;G1I='D@8VQA<W,@=&\@8F4@82!G96YE<F%L
M:7IE9"P@8VQE86X@<&EE8V4@;V8@=&AE"B`@("`@(&9R86UE=V]R:R!T:&%T
M(&-A;B!B92!U<V5D(&EN(&]T:&5R(&%P<',@86YD('-U8F-L87-S960@:68@
M;F5C97-S87)Y+@I;8VIH72!-86ME(&9A:6QU<F4@=&\@8V]N;F5C="!T;R!T
M:&4@<')E9F5R96YC97,@9&%T87-O=7)C92!A(&9A=&%L(&5R<F]R+@I;8VIH
M72!!9&1E9"!T:&4@4V5R:6%L:7IE.CH@8VQA<W,@9F]R('9A<FEO=7,@;65T
M:&]D<R!O9B!E;F-A<'-U;&%T:6YG(&1A=&$*("`@("`@*'-T97!H(#QS:'5T
M:&5R0'EA:&]O+F9R/BDN"EMC:FA=($%D9&5D('1H92!C87!A8FEL:71Y('1O
M(&=E="!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<R!O=&AE<B!T:&%N"B`@
M("`@('5S97)N86UE(&)A8VL@9G)O;2!T:&4@075T:"!F<F%M97=O<FLL(&%N
M9"!C;VUP;&5T960@=&AE"B`@("`@(&%U=&AE;G1I8V%T:6]N(')E86QM(&9U
M;F-T:6]N86QI='DN"EMJ;VY=($%L;&]W('1H92!T86)L92!C96QL(&%N9"!L
M:6YK($-34R!C;&%S<V5S('1O(&)E('-P96-I9FEE9"!W:&5N(&-R96%T:6YG
M"B`@("`@(&UE;G4@:71E;7,N"EMJ86Y=($%D9"!R96=I<W1R>2!M971H;V0@
M9F]R(&QI;FMI;F<@=&\@82!N86<@=&%S:RX*6VIA;ET@061D(&ED96YT:71Y
M(&-L87-S+@I;;6%X72!!9&0@4F5G:7-T<GDZ.F=E=$YA;64H*2!F;W(@<75E
M<GEI;F<@87!P;&EC871I;VX@;F%M97,N"EMC:FA=($AO<F1E(&YO=R!P<F]V
M:61E<R!T:&4@2&]R9&4Z.FQO9TUE<W-A9V4H*2!M971H;V0@9F]R(&QO9V=I
M;F<@;V8*("`@("`@:6YF;W)M871I;VX@86-C;W)D:6YG('1O(&-O;F9I9W5R
M86)L92!P<FEO<FET:65S+"!E=&,N"EMJ86Y=($%D9"!F=6YC=&EO;F%L:71Y
M('1O(&UA<"!D871E(&%N9"!T:6UE(&9I96QD<R!T;R!T:&4@1&%T82!C;&%S
M<RX*6V-J:%T@061D('1H92!B96=I;FYI;F=S(&]F(&$@=7-E<B!A9&UI;FES
M=')A=&EO;B!S>7-T96TN"EMC:FA=($%D9"!#:&EN97-E("A4<F%D:71I;VYA
M;"D@=')A;G-L871I;VX@*$1A=FED($-H86YG"B`@("`@(#QD879I9$!T:&)U
M;RYG;W8N='<^*2X*6VIA;ET@061D($ET86QI86X@=')A;G-L871I;VX@*$=I
M;W9A;FYI($UE;F5G:&5T=&D@/&=M96YE9VAE='1I0&EN9G9I8RYI=#XI+@I;
M:F%N72!!9&0@1&%T82!C;&%S<R!F;W(@:6UP;W)T:6YG(&%N9"!E>'!O<G1I
M;F<@9&%T82X*6VIO;ET@0VQE86YE9"!U<"!T:&4@:&5L<"!S>7-T96T@82!B
M:70N"EMC:FA=($%D9"!(;W)D93HZ9F%T86PH*2!F;W(@9&ES<&QA>6EN9R!0
M14%27T5R<F]R(&]B:F5C=',@86YD(&%B;W)T:6YG+@I;879S;5T@17AT96YD
M($AO<F1E.CIG971496UP1FEL92@I('1O(&%L;&]W(&1I<F5C=&]R>2!T;R!B
M92!O=F5R<FED9&5N+@I;879S;5T@06QL;W<@=&5M<&]R87)Y(&9I;&5S('1O
M(&)E('5N<F5G:7-T97)E9"!F<F]M(&1E;&5T:6]N+@I;879S;5T@061D(&$@
M0V%C:&4@9G)A;65W;W)K(&9O<B!P97)S:7-T96YT;'D@<W1O<FEN9R!O8FIE
M8W1S+"!A;&]N9PH@("`@("`@=VET:"!A(&9I;&5S>7-T96T@9')I=F5R+@I;
M:F%N72!!9&0@4&]L:7-H('1R86YS;&%T:6]N+@I;8VIH72!&:7@@82!P<F]B
M;&5M('=I=&@@)')E9VES=')Y+3YC86QL*"D@86YD('-W:71C:&EN9R!A<'!L
M:6-A=&EO;@H@("`@("!C;VYT97AT<RX*6V-J:%T@1V5T(')I9"!O9B!T:&4@
M:6YV;VME*"D@;65T:&]D<R!I;B!T:&4@<F5G:7-T<GDN"EMC:FA=($1O;B=T
M(')E+6EN8VQU9&4@87!P;&EC871I;VX@8V]N9FEG(&9I;&5S.R!S879E(&-O
M;F9I9W,@:6X@82!C86-H92!S;PH@("`@("!T:&%T('=E(&-A;B!J=7-T('!O
M:6YT("1'3$]"04Q36R=C;VYF)UT@870@=&AE(&]L9"!C;VYF:6<@;VX*("`@
M("`@)')E9VES=')Y+3YP;W!!<'`H*2P@971C+@I;:F%N72!!9&0@1G)E;F-H
M('1R86YS;&%T:6]N("A&<F5D97)I8R!4<G5D96%U(#QF=')U9&5A=4!#04TN
M3U)'/BDN"EMC:FA=($%D9"!#>F5C:"!T<F%N<VQA=&EO;B`H<&-H>71I;$!A
M<W`N;V=I+F5D=2DN"EMJ86Y=($%D9"!N97<@=&EM97IO;F4@:&%N9&QI;F<@
M=VET:"!C;&5A<G1E>'0@=&EM97IO;F4@;F%M97,@:6X@;&%N9RYP:'`N"EMC
M:FA=($%D9"!2=7-S:6%N('1R86YS;&%T:6]N("A)9VYA="!):W)Y86YO=B`\
M:6=N871`:6)D+G)U/BDN"EMJ;VY=($YE=R!M971H;V1S(&EN($)R;W=S97(N
M<&AP(&9O<B!R971R:65V:6YG('9E<G-I;VYS+B`\:7IZ>4!Q=6UR86XN;W)G
M/@I;:F]N72!"<F]W<V5R+G!H<"!N;W<@9&5T96-T<R!/<&5R82X@/&EZ>GE`
M<75M<F%N+F]R9SX*6V-J:%T@36]V92!T:&4@;&%N9W5A9V4@86YD(&-H87)S
M970@9&5F875L=',@:6YT;R!C;VYF:6<O;&%N9RYP:'`L(&%N9"!A9&0@80H@
M("`@("!296=I<W1R>2!M971H;V0@=&\@9V5T('1H92!C=7)R96YT(&-H87)S
M970N"EMC:FA=($UA<"!B<F]W<V5R(&-O9&5S('-U8V@@87,@)VYL)R!T;R!T
M:&4@9G5L;"!C;V1E("@G;FQ?3DPG+"!E=&,N*2X*6V%V<VU=(%)E<&QA8V4@
M)&-O;F9;)W!A=&AS)UT@=VET:"!T:&4@)')E9VES=')Y(&5Q=6EV86QE;G1S
M+@I;879S;5T@061D(&9O=7(@<F5G:7-T<GD@9G5N8W1I;VYS('1O('%U97)Y
M('=E8G)O;W1S(&%N9"!P871H<RX*6V%V<VU=($UA;GD@34E-15]6:65W97(@
M8VAA;F=E<SH@05!)('1W96%K<RP@;F5W(&1R:79E<G,L('=O<FMS('=I=&@@
M24U0+@I;8VIH72`D8V]N9ELG=7-E<B==6R=O;FQI;F5?:&5L<"==(&ES(&YO
M=R!A($AO<F1E+6QE=F5L('-E='1I;F<N"EMA=G-M72!%;F%B;&4@87!P;&EC
M871I;VYS('1O(&AA=F4@;&]C86P@34E-15]6:65W97(@9')I=F5R<R!I;B!A
M9&1I=&EO;@H@("`@("`@=&\@=&AE(&=L;V)A;"!(;W)D92!O;F5S+@I;879S
M;5T@4VAU9F9L92!A<F]U;F0@=&AE($U)345?5FEE=V5R($%023H@9V5T1')I
M=F5R*"D@:7,@;F]W('!R:79A=&4*6V%V<VU=($%D9"!A;B`G:6YI=&EA;%]P
M86=E)R!O<'1I;VX@=&\@=&AE(')E9VES=')Y+"!T;R!L970@=7,@;&EN:R!I
M;G1O"B`@("`@(&%N>2!P86=E(&EN<VED92!A;B!A<'!L:6-A=&EO;BX*6V-J
M:%T@061D(&$@9G)A;65W;W)K+6QE=F5L(&)A<V4N<&AP(&9I;&4@86YD(&UA
M:V4@9G)A;65W;W)K('-C<FEP=',@=7-E(&ET+@I;8VIH72!!9&0@<F4M;W)G
M86YI>F5D(&)U="!S=&EL;"!M;W-T;'D@;W5T(&]F(&1A=&4@2$5,4"],25-4
M4R]33U520T4@9FEL97,*("`@("`@*$IO<V@@36EL;&5R(#QJ;W-H;&ES='-`
M;F5B;VYE="YC;VT^*2X*6V-J:%T@061D(&$@<&%R86UE=&5R('1H870@9&5T
M97)M:6YE<R!W:&5T:&5R(&]R(&YO="!A<'!S(&%R92!L:6YK960@;VX@=&AE
M"B`@("`@($AO<F1E(&UE;G5B87(N"EMC:FA=($-L96%R('1H92!W:&]L92!S
M97-S:6]N('=H96X@=&AE('5S97(@;&]G<R!O=70@;V8@2&]R9&4N"EMJ;VY=
M($%D9&5D(%!R969S.CII<T5M<'1Y*"D@9F]R(&1E=&5R;6EN:6YG('=H971H
M97(@82!P<F5F97)E;F-E(&ES(&5M<'1Y+@I;:F]N72!!9&1E9"!A;B`D;VYC
M;&EC:R!P87)A;65T97(@=&\@2&]R9&4Z.FQI;FLH*2!F;W(@<W!E8VEF>6EN
M9R!A;B!A;F-H;W(G<PH@("`@("`G;VYC;&EC:R<@2F%V85-C<FEP="!E=F5N
M="X*6V-J:%T@57-E('1H92`J=7)L*"D@9G5N8W1I;VYS(&UO<F4@8V]N<VES
M=&5N=&QY('1O(&UA:V4@<W5R92!T:&%T"B`@("`@(&-O;VMI92UL97-S('-E
M<W-I;VYS('=O<FLN"EMC:FA=($UO9&EF>2!C<W,N<&AP('1O('5S92!T:&4@
M4F5G:7-T<GD@=&\@9V5T(&%P<&QI8V%T:6]N(&9I;&4@<&%T:',N"EMC:FA=
M($%D9"!C;V]K:65?<&%T:"!A;F0@8V]O:VEE7V1O;6%I;B!S971T:6YG<R!F
M;W(@<&5O<&QE('=H;R!K965P(&%P<',*("`@("`@;W5T<VED92!O9B!T:&4@
M2&]R9&4@=V5B<F]O="!O<B!O;B!M=6QT:7!L92!S97)V97)S+@H*"BTM+2TM
M+0IV,2XS+C0*+2TM+2TM"@I;8VIH72!!9&0@82!(;W)D92!S=6UM87)Y(&9R
M86UE=V]R:RP@=VAI8V@@=7-E<R!T:&4@4F5G:7-T<GD@=&\@9V5T"B`@("`@
M('-U;6UA<FEE<R!O9B!A=F%I;&%B;&4@9&%T82`M('1A<VMS+"!E=F5N=',L
M(&5T8RX@+2!F;W(@=&AE($AO<F1E"B`@("`@(&QO9VEN('-C<F5E;BX*6V-J
M:%T@5&AE('!R969E<F5N8V5S('-E='1I;F=S('-H;W5L9"!B92!(;W)D92UW
M:61E+"!A;F0@<V\@:&%V92!B965N(&UO=F5D('1O"B`@("`@(&AO<F1E+V-O
M;F9I9R]H;W)D92YP:'`N"EMC:FA=($UO=F4@<')E9G,N9VEF(&%N9"!G96YE
M<FEC('!R969S('1E;7!L871E<R!I;G1O($AO<F1E+@I;8VIH72!-;W9E('-E
M='1I;F<@;V8@=&AE(&=E='1E>'0@9&]M86EN(&EN=&\@=&AE(%)E9VES=')Y
M+@I;:F]N72!3:6UP;&EF:65D('1H92!P<F5F97)E;F-E('-Y<W1E;2=S(&-L
M96%N=7`@9G5N8W1I;VYS+@I;:F]N72!-97)G92!D;V-T>7!E+FEN8R!I;G1O
M(&-O;6UO;BUH96%D97(N:6YC+@I;:F]N72!!9&1E9"!497AT.CIH=&UL<W!A
M8V5S*"D@86YD(%1E>'0Z.FAT;6QA;&QS<&%C97,H*2X*6V-J:%T@061D(&%N
M(&]P=&EO;B!T;R!(;W)D93HZ9V5T5&5M<$9I;&4H*2!T;R!N;W0@9&5L971E
M('1H92!F:6QE(&%T('1H90H@("`@("!E;F0@;V8@=&AE(')E<75E<W0N"EMC
M:FA=($%D9"!A("9S:6YG;&5T;VXH*2!M971H;V0@=&\@=&AE(%)E9VES=')Y
M(&-L87-S+@I;:F]N72!!9&1E9"!.86<@:6YT97)F86-E('1O('1H92!R96=I
M<W1R>2X*6VIO;ET@17AP86YD960@=&AE(')E9VES=')Y('1O(&AA;F1L92!I
M;7!O<G1I;F<@87!P;&EC871I;VXM<W!E8VEF:6,*("`@("`@8V]N9FEG=7)A
M=&EO;B!V86QU97,N"EMM87A=($%D9"!A=71H+VQO9VEN(&%N9"!A=71H+VQO
M9V]U="!O<'1I;VYS(&9O<B!';VQL96T@:6X@=&AE(')E9VES=')Y+@I;;6%X
M72!!9&0@4F5G:7-T<GDZ.F=E=$UE=&AO9"!F=6YC=&EO;BX*6VUA>%T@061D
M(&-O;G1A8W1S+W-O=7)C97,@<V5R=FEC92!T;R!T:&4@<F5G:7-T<GDN"EMC
M:FA=(%)E;F%M92!T:&4@0V]N;F5C=&EO;B!C;&%S<V5S('1O(%1O:V5N+@I;
M8VIH72!296YA;64@=&AE($]B:F5C=%-T;W)E(&-L87-S('1O(%-E<W-I;VY#
M86-H92X*6VIO;ET@061D:6YG($1U=&-H(&QA;F=U86=E+@I;879S;5T@061D
M(&EC;VX@<W5P<&]R="!T;R!T:&4@34E-15]6:65W97(@9G)A;65W;W)K"EMA
M=G-M72!5<&1A=&4@=&AE($U)345?5FEE=V5R($%022!T;R!I;F-L=61E(&=E
M=$1R:79E<B@I(&%N9"!G971)8V]N*"D*6VIO;ET@3W9E<FAA=6QE9"!T:&4@
M<')E9F5R96YC97,@8V%C:&EN9R!S>7-T96T@82!B:70N"EMC:FA=(%5P9&%T
M92!"<F]W<V5R.CH@=&\@<F5C;V=N:7IE($E%-BX*6VIO;ET@061D960@2&]R
M9&4M=VED92!A;F0@9')I=F5R+7-P96-I9FEC(&-L96%N=7`@;65T:&]D<R!T
M;R!T:&4@<')E9F5R96YC97,*("`@("`@<WES=&5M+@I;8VIH72!296UO=F4@
M=&AE('-T<G1O;&]W97(H*2!F<F]M($QA;F<Z.G-E;&5C="@I('=H:6-H('=A
M<R!P<F5V96YT:6YG"B`@("`@('!R;W!E<B!L;V-A;&4@;F%M97,@*&QI:V4@
M<'1?0E(I(&9R;VT@=V]R:VEN9R!C;W)R96-T;'DN"EMM87A=($%D9&5D(&%U
M=&AE;G1I8V%T:6]N(&AA;F1L97(@=&\@=&AE(%)E9VES=')Y+@I;:F]N72!4
M:&4@)W-E<W-I;VXG('!R969E<F5N8V5S(&1R:79E<B!N;W<@:&]N;W)S('!R
M969E<F5N8V4@<V-O<&4N"EMM87A=($UA9&4@<VET96YA;64@=&ET;&4@8V]N
M9FEG=7)A8FQE+@I;:F]N72!297=O<FME9"!T:&4@365N=3HZ8W5S=&]M271E
M;2@I('1O(&%C8V5P="!02%`@9&%T82!S=')U8W1U<F5S(&EN<W1E860*("`@
M("`@;V8@82!S=')I;F<@;V8@96YC;V1E9"!P87)A;65T97)S+@I;879S;5T@
M061D960@34E-15]6:65W97(@9G)A;65W;W)K('1O(&AA;F1L92!R96YD97)I
M;F<@9FEL97,@:6YT;R!(5$U,"B`@("`@("`H86YD(&]T:&5R*2!F;W)M871S
M(&EN(&$@=7-E<BUE>'1E;G-I8FQE(&9A<VAI;VX@*&5X<&5R:6UE;G1A;"D*
M6V%V<VU=($YE=R!-24U%7TUA9VEC(&%N9"!M:6UE7VUA<'!I;F<N<&AP(&-O
M;F9I9R!F:6QE("AE>'!E<FEM96YT86PI"EMA=G-M72!4=V\@;F5W('1E;7!O
M<F%R>2!F:6QE(&AA;F1L:6YG(&9U;F-T:6]N<RP@2&]R9&4Z.F=E=%1E;7!&
M:6QE*"D@86YD"B`@("`@($AO<F1E.CIG971496UP1&ER*"D@=&\@=&%K92!C
M87)E(&]F('1H92!H;W5S96ME97!I;F<@;V8@=&5M<"!F:6QE<RX*6VUA>%T@
M061D960@8V]N=&%C=',O861D('-E<G9I8V4@=&\@<F5G:7-T<GDN"EMC:FA=
M(%)E9VES=')Y.CIC86QL*"D@:7,@;F]W(%)E9VES=')Y.CIL:6YK*"DN(%1H
M97)E(&ES(&$@;F5W"B`@("`@(%)E9VES=')Y.CIC86QL*"D@=VAI8V@@86-T
M=6%L;'D@<F5T=7)N<R!T:&4@<F5S=6QT(&]F(&$@9G5N8W1I;VX@8V%L;`H@
M("`@("!M861E('1O(&%N;W1H97(@87!P;&EC871I;VXN"EMC:FA=($9I>"!$
M0B!Q=65R>2!R97-U;'0@8VAE8VMI;F<@:6X@<W%L(&1R:79E<G,N"EMC:FA=
M($9I>"!H96QP('-O('1H870@9V5N97)I8R!H96QP(&QI;FMS("AO;B!M96YU
M(&)A<G,I('-H;W<@=&AE('1O<&EC(&QI<W0*("`@("`@8V]R<F5C=&QY+@I;
M8VIH72!-86ME('1H92!L;V=I;B!F;W)M(&YI8V5R+"!A;F0@861D(&$@;&]G
M;W5T(&QI;FLN"EMC:FA=($UA:V4@<W5R92!A;&P@;V8@=&AE('-Q;"!D<FEV
M97)S('5S92!$0CHZ<75O=&53=')I;F<H*2!O;B!A;&P@<W1R:6YG<RX*6V-J
M:%T@4F5P;&%C92!A($!M>7-Q;%]Q=65R>2@I('1H870@=V%S(&AI9&EN9R!I
M;B!#;VYN96-T:6]N+W-Q;"YP:'`@=VET:`H@("`@("`D=&AI<RT^9&(M/G%U
M97)Y*"DN"EMC:FA=(%)E='5R;B!B87-E;F%M92@D;&%N9W5A9V4I(&9R;VT@
M3&%N9SHZ4V5L96-T*"D@=&\@879O:60@<&]S<VEB;&4*("`@("`@97AP;&]I
M=',N"EMC:FA=($%D9"!296=I<W1R>3HZ:&%S365T:&]D*"D@9F]R(&-H96-K
M:6YG(&EF(&$@<&EE8V4@;V8@9G5N8W1I;VYA;&ET>2!H87,*("`@("`@8F5E
M;B!R96=I<W1E<F5D('=I=&@@2&]R9&4N"EMJ;VY=($%N;W1H97(@;&%R9V4@
M;W9E<FAA=6P@=&\@=&AE('!R969E<F5N8V5S('-Y<W1E;2X@($YO=&4@=&AA
M="!T:&4*("`@("`@:7-#:&%N9V5A8FQE*"D@9G5N8W1I;VX@:&%S(&)E96X@
M<F5N86UE9"!I<TQO8VME9"@I+B`@5&AE<F4@:7,@86QS;PH@("`@("!S=7!P
M;W)T(&9O<B!P<F5F97)E;F-E('-C;W!E("AV:6$@:7-3:&%R960H*2!A;F0@
M<V5T4VAA<F5D*"DI+@I;:F]N72!!9&1E9"!C87!A:6)L:71Y('1E<W1S('1O
M('1H;W-E(&1R:79E<G,@=&AA="!R97%U:7)E(&YO;BUS=&%N9&%R9"!02%`*
M("`@("`@97AT96YS:6]N<R`H:&%N9&QE9"!B>2!(;W)D93HZ9G5N8W1I;VY#
M:&5C:R@I*2X*6VIO;ET@061D960@86X@075T:%],1$%0($AO<F1E(&%U=&AE
M;G1I8V%T:6]N(&1R:79E<BX*6V-J:%T@061D(&QI='1L92!S;FEP<&5T+71E
M;7!L871E<R!F;W(@9'EN86UI8V%L;'D@8G5I;&1I;F<@<')E9F5R96YC92!'
M54ES+@I;8VIH72!296YA;64@=&AE($%U=&@@:6YT97)F86-E)W,@875T:"@I
M(&UE=&AO9"!T;R!A=71H96YT:6-A=&4H*2!T;R!A=F]I9`H@("`@("!O=F5R
M;&%P<&EN9R!T:&4@;F%M92!O9B!T:&4@8V]N<W1R=6-T;W(@9F]R('1H92!!
M=71H('!A<F5N="!C;&%S<RX*6V-J:%T@5&AE(&-O;F9I9W5R871I;VX@87)R
M87D@:7,@;F]W('-I;7!L>2`D8V]N9BX@06YY('-E='1I;F=S('1H870@;75S
M="!B90H@("`@("!A8V-E<W-I8FQE('5N8VAA;F=E9"`H;F]T(&]V97)R:61D
M96XI('-H;W5L9"!B92!P=70@:6YT;R`D8V]N9ELG:&]R9&4G72X*("`@("`@
M179E<GET:&EN9R!E;'-E(&ES(&9A:7(@9V%M92!F;W(@87!P;&EC871I;VYS
M('1O(&]V97)R:61E+@I;8VIH72!!9&0@82!W;6PO=V%P(&QO9VEN(&9O<FTN
M"EMM87A=($%D9"!A;B!!=71H7T944"!(;W)D92!A=71H96YT:6-A=&EO;B!D
M<FEV97(N"EMC:FA=($%D9"!A;B!!=71H7TU#04P@2&]R9&4@875T:&5N=&EC
M871I;VX@9')I=F5R+@I;8VIH72!4:&4@2&]R9&4@;&]G:6X@9F]R;2!N;W<@
M86-T=6%L;'D@9&]E<R!S;VUE=&AI;F<N($QO9V=I;F<@:6X@=&\@:70*("`@
M("`@9V5T<R!Y;W4@82!T;VME;B!I;B!Y;W5R('-E<W-I;VX@<V%Y:6YG('1H
M870@>6]U)W9E(&%U=&AE;G1I8V%T960@86YD"B`@("`@('=H;R!Y;W4@87)E
M+B!!<'!S(&-A;B!T:&5N('5S92!T:&ES(&EN9F]R;6%T:6]N('1O(&%L;&]W
M(&]R(&1E;GD*("`@("`@86-C97-S+"!A;F0@=&\@:61E;G1I9GD@=7-E<G,N
M"EMC:FA=(%1H92!F;W)M870@;V8@=&AE(&-O;F9I9R]R96=I<W1R>2YP:'`@
M9FEL92!H87,@8VAA;F=E9"!D<F%S=&EC86QL>2!T;PH@("`@("!B92!M;W)E
M(')E861A8FQE(&%N9"!L97-S(&EN9&ER96-T+B!4:&5R92!I<R!A;'-O(&$@
M;F5W(&%P<"!P87)A;65T97(L"B`@("`@("=A;&QO=U]G=65S=',G+"!W:&EC
M:"!D969I;F5S('=H971H97(@;W(@;F]T(&$@=7-E<B!I<R!A;&QO=V5D('1O
M"B`@("`@(&%C8V5S<R!T:&4@87!P;&EC871I;VX@=VET:&]U="!L;V=G:6YG
M(&EN('1O($AO<F1E+@I;8VIH72!4:&4@075T:#HZ(&-L87-S97,@;F]W(&5X
M<&5C="!T;R!R96-E:79E(&$@=7-E<FED(&%N9"!A;B!A<G)A>2!O9@H@("`@
M("!C<F5D96YT:6%L<RX@4FEG:'0@;F]W(&%L;"!B86-K96YD<R!A<W-U;64@
M=&AA="!T:&]S92!C<F5D96YT:6%L<PH@("`@("!C;VYT86EN(&$@<&%S<W=O
M<F0L(&)U="!T:&4@=V%Y(&ES(&-L96%R('1O(&AA=F4@;W1H97(@:VEN9',@
M;V8@875T:`H@("`@("`H25`L('1I;64M8F%S960L('=H871E=F5R*2X*6VIO
M;ET@061D960@82!N97<@<&%R86UE=&5R('1O('1H92!,1$%0('!R969E<F5N
M8V5S(&1R:79E<CH@)V%L=V%Y<U]B:6YD)RX*6V-J:%T@061D960@82!-96YU
M.CH@8VQA<W,@=&AA="!A;&P@;6]D=6QE<R!C86X@=7-E('1O(&=E;F5R871E
M(&UE;G4@:71E;7,N"EMJ;VY=($-L96%N960@=7`@=&AE($Q$05`@<')E9F5R
M96YC97,@9')I=F5R(&$@8FET+@I;:F]N72!!9&1E9"!S97-S:6]N+6QE=F5L
M('!R969E<F5N8V5S(&-A8VAI;F<@=&\@=&AE('!R969E<F5N8V5S('-Y<W1E
M;2X*6V-J:%T@2&%V92!(;W)D93HZ;&EN:R@I(&UA:V4@<W5R92!T:&%T('1H
M92!S=&%T=7,@=&5X="!I<R!S869E(&9O<@H@("`@("!J879A<V-R:7!T("AH
M=&UL96YT:71I97,L(&%D9'-L87-H97,I+@I;8VIH72!&:7@@3V)J96-T4W1O
M<F4@=&\@=V]R:R!W:&5N(')E9VES=&5R7V=L;V)A;',@/2!/;BX*6VIO;ET@
M061D960@82!397-S:6]N+6)A<V5D('!R969E<F5N8V5S(&1R:79E<BX*"@HM
M+2TM+2T*=C$N,RXS"BTM+2TM+0H*6V-J:%T@1G5R=&AE<B!R979A;7`@=&AE
M($U)344@:6YT97)F86-E+B!"92!C;VYS:7-T96YT(&EN(&-A<&ET86QI>F%T
M:6]N"B`@("`@("AA8W)O;GEM<R!A<F4@8V%P:71A;&EZ960I+"!B<F5A:R!O
M=70@34E-15]3=')U8W1U<F4@86YD($U)345?365S<V%G90H@("`@("!I;G1O
M('-E<&5R871E(&9I;&5S+"!A;F0@<'5T(&%L;"!M971H;V1S(&EN=&\@8VQA
M<W-E<RX*6V-J:%T@061D($AO<F1E.CIG971&;W)M1&%T82@I('1O(&9E=&-H
M(&$@=F%R:6%B;&4@9G)O;2!E:71H97(*("`@("`@)$A45%!?4$]35%]605)3
M(&]R("1(5%107T=%5%]605)3("AA;F0@=&\@8VQE86X@;6%G:6,@<75O=&5S
M+"!I9@H@("`@("!N96-E<W-A<GDI+@I;8VIH72!296UO=F4@=&AE($QO9SHZ
M(&-L87-S+B!4:&ES(&ES('!A<G0@;V8@4$5!4B!N;W<N"EMC:FA=($%D9"!A
M(%-E<W-I;VY#86-H93HZ(&-L87-S+B!4:&ES(&ES(&EN=&5N9&5D(&9O<B!S
M=&]R:6YG(&]B:F5C=',@:6X*("`@("`@=&AE('-E<W-I;VX@:6YT96YD960@
M9F]R(&YE87(M=&5R;2!U<V4L(&%N9"!W:6QL(&-U<G)E;G1L>2!S=&%R=`H@
M("`@("!T:')O=VEN9R!O=70@;V)J96-T<R!W:&5N(&UO<F4@=&AA;B`R,"!A
M<F4@<'5T(&EN+B!4:&ES('=I;&P@:&]P969U;&QY"B`@("`@(&ME97`@86YY
M(&]N92!S97-S:6]N(&9R;VT@9W)O=VEN9R!T;V\@;&%R9V4N"EMC:FA=(%5S
M92!T:&4@;F5W(%!%05(@8VQA<W,@36%I;%]R9F,X,C(Z.B!T;R!P87)S92!A
M9&1R97-S(&QI<W1S+"!S;R!T:&%T"B`@("`@('=E(&=E="!R9F,@.#(R(&=R
M;W5P('-U<'!O<G0@*&UY+6)U9&1I97,Z(&IO;D!H;W)D92QO<F<L"B`@("`@
M(&UA>$!H;W)D92YO<F<[*2P@=VAI8V@@:6UA<%]R9F,X,C)?<&%R<V5?861R
M;&ES="@I(&1O97-N)W0@:&%V92X*6VUA>%T@36%K92!(;W)D92!82%1-3"`Q
M+C`@8V]M<&QI86YT+@I;8VIH72!!9&0@82!F97<@9FEE;&1S('1O('1H92!P
M<F]B;&5M(')E<&]R="!A;F0@=')Y('1O(&UA:V4@:70@;6]R92!F<FEE;F1L
M>2X*6V-J:%T@1FQE<V@@;W5T('1H92!-:6UE.CH@8VQA<W,N"EMC:FA=($UO
M=F4@=')I;45M86EL061D<F5S<R@I(&EN=&\@=&AE(&YE=R!-:6UE.CH@8VQA
M<W,N"EMC:FA=($UO=F4@<V5T7V5N=E]I;E]S=')I;F<H*2!T;R!497AT.CIE
M>'!A;F1%;G9I<F]N;65N="@I+@I;8VIH72!296YA;64@:&]R9&5?8VQE86YU
M<"@I('1O(%]F:6QE0VQE86YU<"@I+@I;8VIH72!4:&4@>FQI8B!M;V1U;&4@
M;F]W('-U<'!L:65S(&$@9WIE;F-O9&4H*2!F=6YC=&EO;B!T:&%T(&]B<V]L
M971E<PH@("`@("!(5%107T-A8VAE.CIG>D5N8V]D92@I+@I;8VIH72!-;V1I
M9GD@2&]R9&4Z.G5R;"@I('-O('1H870@:70@9&5F875L=',@)&-O;F9;)W5S
M95]S<VPG72!T;R`R"B`@("`@("AA=71O+61E=&5C="!C=7)R96YT(&UO9&4I
M+@I;8VIH72!-;V1E<FYI>F4@<V]M92!O9B!T:&4@2&]R9&4@9G)O;G1E;F0@
M*'-T:6QL(&QO=',@=&\@9&\@:&5R92D[(&=E="!R:60*("`@("`@;V8@<&%C
M:V%G92Y(5$U,1&]C=6UE;G0N<&AP(&]N8V4@86YD(&9O<B!A;&PN"EMA=G-M
M72!"<F5A:V1O=VX@86QL('-P96-I86P@8VAA<F%C=&5R<R!I;B!54DQS('1O
M(&5N=&ET:65S+"!T;R!A=F]I9`H@("`@("!A;6)I9W5I='D@:6X@:&]W('9A
M<FEO=7,@8G)O=W-E<G,@<&%R<V4@=&AE;2X*6V-J:%T@061D($AO<F1E.CIR
M86ES94UE<W-A9V4H*2!F;W(@8W)E871I;F<@2&]R9&4@;65S<V%G97,@=&\@
M8F4@9&ES<&QA>65D"B`@("`@('1O('1H92!U<V5R+@I;8VIH72!3;VUE(&=E
M;F5R86P@54D@='=E86MS("T@9F]N="!S:7IE+"!E=&,N"EMC:FA=(%)E;6]V
M92!R9F-D871E*"D@:6X@9F%V;W(@;V8@=&AE(&YE=R`G<B<@<&%R86UE=&5R
M('1O(&1A=&4N"EMC:FA=($%D9&5D(&%P<&QI8V%T:6]N("=W96)R;V]T)R!A
M;F0@)V9I;&5R;V]T)R!P<F]P97)T:65S('1O('1H92!R96=I<W1R>0H@("`@
M("!C;VYF:6<@9FEL92X@5&AE<V4@86QL;W<@;6]R92!F;&5X:6)I;&ET>2!I
M;B!P;&%C:6YG(&%P<',L(&%N9"!L970@=&AE"B`@("`@(')E9VES=')Y('=O
M<FL@9G)O;2!M;W)E('!L86-E<RX*6V-J:%T@36]V960@<&%C:V%G92Y296=I
M<W1R>2YP:'`@=&\@4F5G:7-T<GDN<&AP+@I;8VIH72!#;VUM96YT960@8V]N
M9FEG+VAO<F1E+G!H<"YD:7-T(&AE879I;'DN"EMC:FA=($%D9"!A(%-E8W)E
M=#HZ(&-L87-S('1O($AO<F1E+G!H<"!T:&%T('!R;W9I9&5S(&$@=')A;G-P
M87)E;G0*("`@("`@:6YT97)F86-E('1O(&5I=&AE<B!T:&4@;6-R>7!T(&5X
M=&5N<VEO;B`H<')E9F5R<F5D*2!O<B!T:&4@4$5!4@H@("`@("!#<GEP=%](
M0T5-1#4Z.B!C;&%S<RX*6VIO;ET@06-C97!T(&$@=7-E<BUD969I;F5D(&9U
M;F-T:6]N(&9O<B!P97)F;W)M:6YG('5S97)N86UE(&QO;VMU<',@:6X@=&AE
M"B`@("`@('!R969E<F5N8V5S(&-O9&4N("!4:&4@<')E9F5R96YC97,@8V]N
M<W1R=6-T;W(@;&]O:W,@9F]R('1H92!F=6YC=&EO;@H@("`@("!I;B`D<&%R
M86US6R=U<V5R7VAO;VLG72X*6V-J:%T@0VAE8VL@2%144%]%3E9?5D%24R!F
M;W(@=&AE('5S97(M86=E;G0@87,@=V5L;"!A<R!(5%107U-%4E9%4E]605)3
M+@I;8VIH72!296UO=F4@;6%I;&9R;VTH*2!I;B!F879O<B!O9B!T:&4@4$5!
M4B!-86EL.CH@:6YT97)F86-E+B!!9&IU<W0@=&AE"B`@("`@(&-O;F8@9FEL
M97,@86YD('!R;V)L96TN<&AP(&%C8V]R9&EN9VQY+@I;8VIH72!!9&0@82!S
M970@;V8@:6YV;VME*"D@;65T:&]D<R!T;R!T:&4@4F5G:7-T<GDZ.B!C;&%S
M<R!F;W(@9&ER96-T;'D*("`@("`@:6YV;VMI;F<@<V5R=FEC97,@*&EE+"!A
M8W1U86QL>2!P;W!P:6YG('5P(&$@=VEN9&]W*2!I;G-T96%D(&]F"B`@("`@
M('!R:6YT:6YG(&QI;FMS('1O(&EN=F]K92!T:&5M+@I;8VIH72!#;&5A;B!U
M<"!P86-K86=E+DUI;64N<&AP(&$@8FET.R!D;VXG="!S970@82!C:&%R<V5T
M(&]N($U)344@<&%R=',*("`@("`@=&AA="!A<F5N)W0@=&5X="X*6V-J:%T@
M061D960@82!F:6QE(&1R:79E<B!F;W(@=&AE($-O;FYE8W1I;VXZ.B!C;&%S
M<RX*6V-J:%T@061D960@82!705`@:6YD97@@=&\@<')O=FED92!Q=6EC:R!L
M:6YK<R!T;R!A;&P@2&]R9&4@=VER96QE<W,@<&%G97,N"EMC:FA=($%D9"!B
M87-I8R!705`@8G)O=W-E<B!D971E8W1I;VX@=&\@0G)O=W-E<CHZ+B!#=7)R
M96YT;'D@=&AI<R!I<R!O9B!T:&4*("`@("`@(FET(&1E=&5C=',@=&AE('!H
M;VYE($D@:&%V92!A;F0@=&AE('-I;75L871O<B!)('5S92(@=F%R:65T>3L@
M:70@:7,*("`@("`@7W9E<GE?(&9A<B!F<F]M(&-O;7!L971E+@I;8VIH72!!
M9&1E9"!-87@@2V%L:6MA)W,@0V]N;F5C=&EO;CHZ(&-L87-S(&9O<B!C;VYN
M96-T:6]N('1R86-K:6YG+@I;8VIH72!(5%107T-A8VAE.CH@;F]W(&-O;7!R
M97-S97,@8V]N=&5N="!W:71H;W5T('1H92!U<V4@;V8@82!T96UP(&9I;&4N
M"EMC:FA=($9L97-H960@;W5T('1H92!!=71H.CH@8VQA<W,@=VET:"!T:&4@
M86)I;&ET>2!T;R!C86-H92!A=71H;W)I>F%T:6]N"B`@("`@(&EN('1H92!S
M97-S:6]N+@I;:F]N72!296UO=F5D('1H92!S8W)I<'1E9"!W;W)D=W)A<"!I
M;B!F879O<B!O9B!T:&4@;F%T:79E(&9U;F-T:6]N+B`@36]V960*("`@("`@
M=&AE('=R87!?;65S<V%G92@I(&9U;F-T:6]N('1O(%1E>'0Z.G=R87`H*2X*
M6VIO;ET@4W1A;F1A<F1I>F4@;VX@=&AE(')F8V1A=&4H*2!F=6YC=&EO;B!I
M;B!L:6(O2&]R9&4N<&AP+@I;8VIH72!4:&4@<')E9G,@9')I=F5R<R!N;W<@
M97AP96-T("1P87)A;7-;)VAO<W1S<&5C)UTL(&9O<B!C;VYS:7-T96YC>2!W
M:71H"B`@("`@(%!%05(N"EMC:FA=(%1H92!014%2('-Q;"!P<F5F<R!D<FEV
M97(@;F]W('=O<FMS+@I;8VIH72!-;W9E(&AO<F1E(&-O;F9I9W5R871I;VX@
M=F%L=65S('1H870@<VAO=6QD(&YO="!B92!O=F5R<FED9&5D(&)Y"B`@("`@
M(&UO9'5L97,@:6YT;R`D:&]R9&5;)VAO<F1E)UU;72!T;R!A;&QO=R!M;V1U
M;&5S('1O(&1O"B`@("`@(&]V97)R:61I;F<O:6YH97)I=&%N8V4@;V8@;W1H
M97(@;W!T:6]N<RX*6V-J:%T@061D('1H92!(5%107T-A8VAE.CH@8VQA<W,@
M=&\@2&]R9&4N<&AP(&9O<B!%5&%G(&=E;F5R871I;VXL(&=Z:7`*("`@("`@
M8V]M<')E<W-I;VX@;V8@:'1T<"!C;VYT96YT+"!E=&,N"EMC:FA=(%)E<&QA
M8V4@)&AO<F1E6R=L;V-A;&AO<W0G72!W:71H("1(5%107U-%4E9%4E]605)3
M6R=315)615)?3D%-12==+@I;8VIH72!296IE8W0@;W5T<FEG:'0@96YV96QO
M<&4@1G)O;2!A9&1R97-S97,@=VET:"!S<&%C97,@:6X@=&AE;2X*6V-J:%T@
M475O=&4@=&AE(&9R;VT@861D<F5S<R!P87-S960@=&\@<V5N9&UA:6P@=&\@
M<')E=F5N="!S:&5L;"!E>'!L;VET<RX*6V-J:%T@57!D871E($)R;W=S97(N
M<&AP('1O('5S92!(5%107U-%4E9%4E]605)3+"!C;VYS;VQI9&%T92!T:&4@
M:F%V87-C<FEP=`H@("`@("!V97)S:6]N(&EN9F]R;6%T:6]N+"!A;F0@861D
M('-S;%]D;W=N;&]A9%]H86-K(&9O<B!B<F]W<V5R<R!T:&%T(&YE960*("`@
M("`@9&]W;FQO861S('1O(&)E(&-A8VAE86)L92X*6VIO;ET@061D(%1E>'0Z
M.F9I;'1E<B!T;R!L:6(O2&]R9&4N<&AP+@I;8VIH72!#:&5C:R!T:&4@<F5T
M=7)N('9A;'5E(&]F('!C;&]S92@I(&-O<G)E8W1L>2!I;B!M86EL9G)O;2@I
M+@I;:F]N72!396-U<FET>2!F:7@@9F]R("1F<F]M('9A;'5E(&EN(&UA:6QF
M<F]M*"DN(#QC=T!C;V,M86<N;F5T/@I;:F]N72!3:6QE;F-E('-E<W-I;VY?
M<W1A<G0@=V%R;FEN9W,N"EMJ;VY=($%D9&5D(&YE=R!\97AT<F%\('-U8G-T
M:71U=&EO;B!T;R!C;VYF:6<O<F5G:7-T<GDN<&AP(&9O<B!E>'1R82P*("`@
M("`@;F]N+7-T86YD87)D('!A<F%M971E<B!P87-S:6YG+@I;:F]N72!296UO
M=F4@8G5I;&154DPH*2X@($ET)W,@8F5E;B!R97!L86-E9"!B>2!(;W)D93HZ
M=7)L*"DN"EMJ;VY=(%)E<W1R=6-T=7)E9"!T:&4@4U%,('!R969E<F5N8V5S
M('-C:&5M82X*6V-J:%T@061D960@)&AO<F1E6R=S97-S:6]N7VYA;64G72!T
M;R!C;VYT<F]L('1H92!S97-S:6]N(&YA;64@9VQO8F%L;'DN"EMC:FA=(%-E
M<W-I;VXZ.B!D;V5S;B=T(')E86QL>2!B=7D@=7,@86YY=&AI;F<L('-O('=E
M)W9E(&UO=F5D('1H92!U=&EL:71Y"B`@("`@(&UE=&AO9',@=&AA="!D;R!I
M;G1O($AO<F1E.CHL(&%N9"!A<F4@:G5S="!U<VEN9R!P:'`T('-E<W-I;VX@
M8V%L;',*("`@("`@96QS97=H97)E+@I;8VIH72!!9&1E9"!T:&4@8F5G:6YN
M:6YG<R!O9B!5<V5R(&%N9"!!=71H(&EN=&5R9F%C97,L('=I=&@@82!B87)E
M+6)O;F5S"B`@("`@('=O<FMI;F<@075T:%]S<6P@:6UP;&5M96YT871I;VXN
M"EMJ;VY=(%)E=W)O=&4@=&AE(%-E<W-I;VX@8VQA<W,@9F]R(&EN<W1A;G1I
M871I;VX@=VET:"!H;V]K<R!F;W(*("`@("`@=7-E<BUD969I;F5D('-E<W-I
M;VX@:&%N9&QE<G,N"EMC:FA=(%1H92!B87)E+6)O;F5S(&EM<&QE;65N=&%T
M:6]N(&]F('1H92!097)M<R!S8VAE;64L('=I=&@@82!S<6P@9')I=F5R+`H@
M("`@("!W;W)K<RX@268@>6]U('!A<W,@:70@82!F=6QL('!A=&@@:70@=VEL
M;"!T<F%V97)S92!U<"!I="P@<F5T=7)N:6YG"B`@("`@('1H92!F:7)S="!P
M97)M:7-S:6]N(&ET(&9I;F1S+@I;:F]N72!-;W9E9"!T:&4@;&%N9W5A9V4@
M:&%N9&QI;F<@9G5N8W1I;VYS(&EN($AO<F1E+G!H<"!I;G1O('1H96ER(&]W
M;@H@("`@("!C;&%S<V5D(&YA;65D($QA;F<N"EMC:FA=($UO<F4@8V]N<VES
M=&5N="]C<W,M8F%S960@;&]O:R!F;W(@=&AE(&AE;'`@<WES=&5M+@I;8VIH
M72!3=&%R=&EN9R!T;R!R96UO=F4@86QL('5S97,@;V8@8V%L;"UT:6UE('!A
M<W,M8GDM<F5F97)E;F-E+@I;8VIH72!!9&1E9"!C<W,N<&AP(&9O<B!A=71O
M;6%G:6-A;"!G96YE<F%T:6]N(&]F('-T>6QE<VAE971S(&9O<B!A<'!S+@I;
M:F]N72!0<F]M;W1E9"!T:&4@5V5B0VQI96YT(&-L87-S(&9R;VT@;&EB+TAO
M<F1E+G!H<"!T;R!I=',@;W=N(&-O;7!O;F5N=`H@("`@("!N86UE9"!"<F]W
M<V5R+G!H<"X*6V-J:%T@57-E('=O<F1W<F%P(&EN(&$@<VQI9VAT;'D@9&EF
M9F5R96YT('=A>2P@=VAI8V@@<V5E;7,@=&\@<')O9'5C92!M=6-H"B`@("`@
M('!R971T:65R('%U;W1I;F<@;V8@;65S<V%G97,N"EMJ;VY=($%D9&5D(%!R
M969S+VUY<W%L+G!H<"!D<FEV97(@9G)O;2!-87@@2V%L:6MA(#QM87A`=&AE
M+71R:75M=FER871E+FYE=#XN"EMJ;VY=($YE=R!834PM8F%S960@:&5L<"!S
M=6)S>7-T96TN"EMC:FA=(%)E;F%M960@<&%C:V%G92YH;W)D92YP:'`@=&\@
M2&]R9&4N<&AP+@I;8VIH72!!9&0@:6UG*"D@86YD('!I;6<H*2!F=6YC=&EO
M;G,@=&\@=&AE($AO<F1E.CH@8VQA<W,@<V\@=&AA="!M;V1U;&5S"B`@("`@
M('5S:6YG(&]N;'D@<W1Y;&5S:&5E=',@9&]N)W0@;F5E9"!T:&4@2%1-3$1O
M8W5M96YT('!A8VMA9V4N"EMC:FA=($]M:70@=&AE('-E<W-I;VX@;F%M92]I
M9"!F<F]M('1H92!54DP@:68@=V4@8V%N('9E<FEF>2!T:&%T(&-O;VMI97,*
M("`@("`@87)E(&)E:6YG(&%C8V5P=&5D+@I;:F]N72!.97<@=W)A<%]M97-S
M86=E(&9U;F-T:6]N('1H870@=7-E<R!T:&4@;F%T:79E('=O<F1W<F%P(&9U
M;F-T:6]N(&EF(&ET"B`@("`@(&5X:7-T<RX*6VIO;ET@57!D871I;F<@:&5A
M9&5R(&-O;6UE;G0@8V]P>7)I9VAT(&EN9F]R;6%T:6]N+@I;:F]N72!297!O
M<G0@;6]D=6QE('9E<G-I;VYS(&EN('1E<W0N<&AP(&]U='!U="X*6V-J:%T@
M;6EM95]E;F-A<'-U;&%T92@I(&YO=R!U<V5S(&%N(&%R<F%Y(&EN<W1E860@
M;V8@86X@;V)J96-T+@I;:F]N72!296UO=F5D('1H92`D7VAT;6Q;)V-O;7!O
M<V4J)UT@<VEZ:6YG('!A<F%M971E<G,@9G)O;2!C;VYF:6<O:'1M;"YP:'`N
M"EMC:FA=($QE879E($)C8SH@;W5T(&]F('1H92!H96%D97)S('1H870@87)E
M('!A<W-E9"!T;R!S96YD;6%I;"X*6VIO;ET@4F5W<FET92!A(&=O;V0@<&]R
M=&EO;B!O9B!T:&4@<V-R:7!T<R]S971?<&5R;7,N<V@@<V-R:7!T('-O"B`@
M("`@('1H870@:70@96YF;W)C97,@86X@97AT<F5M96QY(&AI9V@@;&5V96P@
M;V8@<V5C=7)I='DN"EMC:FA=(%1H92!V86QI9%]L86YG*"D@9G5N8W1I;VX@
M;F]W(')E<75I<F5S("1N;'-;)VQA;F=U86=E<R==6SQL86YG=6%G93Y="B`@
M("`@('1O(&)E('-E="!F;W(@82!L86YG=6%G92!T;R!B92!C;VYS:61E<F5D
M('9A;&ED("AI;G-T96%D(&]F(&IU<W0@=&AE"B`@("`@(&QO8V%L92!D:7)E
M8W1O<GD@97AI<W1I;F<I+@I;8VIH72!!9&1E9"!A("9S:6YG;&5T;VXH*2!M
M971H;V0@=&\@;6%K92!I="!E87-I97(@=&\@;VYL>2!C<F5A=&4@;VYE(&QO
M9PH@("`@("!I;G-T86YC92P@;F\@;6%T=&5R('=H96X@>6]U(&YE960@:70N
M"EMC:FA=($YO=R!M86EL9G)O;2@I('=O<FMS(&9O<B!R96-I<&EE;G0@861D
M<F5S<V5S('=I=&@@<VEN9VQE('%U;W1E<R!O<@H@("`@("!O=&AE<B!C:&%R
M86-T97)S('1H870@;F5E9"!T;R!B92!E<V-A<&5D(&EN('1H96TN"EMC:FA=
M($QO9R!C;&%S<R!N;W<@:&%S(&%N(&UC86P@:6YS=&%N8V4L(&$@8V]M<&]S
M:71E("AF;W(@9W)O=7!I;F<@;75L=&EP;&4*("`@("`@;&]G(&)A8VME;F1S
M*2P@86YD(&]B<V5R=F5R<R!R96=I<W1E<B!T:&4@;&5V96P@;V8@979E;G1S
M('1H97D@=V%N="!T;PH@("`@("!H96%R(&%B;W5T+"!A;F0@;VYL>2!G970@
M;F]T:69I960@;V8@979E;G1S(&%S(&EM<&]R=&%N="!O<B!M;W)E"B`@("`@
M(&EM<&]R=&%N="!T:&%N('1H870@;&5V96PN"EMC:FA=($%D9&5D(&$@3&]G
M.CH@9G)A;65W;W)K(&%N9"!S>7-L;V<@:6UP;&5M96YT871I;VXL(&EN8VQU
M9&EN9R!A"B`@("`@($QO9U]O8G-E<G9E<B!C;&%S<R!I;G1E;F1E9"!T;R!S
M:70@;VX@=&]P(&]F($QO8B!O8FIE8W1S(&%N9"!T86ME"B`@("`@(&%C=&EO
M;B!I;B!E>&-E<'1I;VYA;"!C:7)C=6US=&%N8V5S+@I;8VIH72!-86ME('-U
M<F4@=&\@86QW87ES('-E;F0@82!C:&%R<V5T('=I=&@@96UA:6QS+@I;8VIH
M72!);7!R;W9E9"!T:&4@;6EM95]D96-O9&4H*2!A;F0@;6EM95]E;F-O9&4H
M*2!F=6YC=&EO;G,N"EMC:FA=(%5P9&%T960@=&5S="YP:'`@=&\@<F5C;V=N
M:7IE('!H<#0@<W1A8FQE(')E;&5A<V5S+@I;:F]N72!296UO=F5D(&%L;"!O
M9B!T:&4@;&]C86QE+RHN;&%N9R!D97!E;F1E;F-I97,N"EMJ;VY=($%S<W5M
M92!T:&4@8G)O=W-E<B!I<R!F<F%M97,M8V%P86)L92!B>2!D969A=6QT+@I;
M8VIH72!!9&0@:&]R9&5?8VQE86YU<"@D9FEL96YA;64I+"!W:&EC:"!T86ME
M<R!C87)E(&]F(&1E;&5T:6YG(&9I;&5S('1H870*("`@("`@<VAO=6QD(&)E
M('5N;&EN:V5D(')E9V%R9&QE<W,@;V8@=VAE=&AE<B!O<B!N;W0@=&AE(')E
M<75E<W0@:7,*("`@("`@8V%N8V5L960@8GD@=&AE('5S97(@8F5F;W)E('=E
M(&9I;FES:"!E>&5C=71I;F<N"EMC:FA=(%)E;6]V92!P:'!L:6(@9&5P96YD
M86YC>2!I;B!F879O<B!O9B!P:'`T('-E<W-I;VYS+U!%05(N"EMC:FA=(%)E
M<&QA8V4@=7-E('=I=&@@<F5Q=6ER95]O;F-E+@I;8VIH72!&:7AE9"!U<"!S
M96QE8W1?;&%N9R@I('1O('=O<FL@*&ED96YT:6-A;"!T;R`Q+C(@;F]W*0I;
M8VIH72!(;W)D92!I<R!N;W<@=6YD97(@=&AE($Q'4$PN"EMC:FA=($9I>"!M
M86EL9G)O;2@I('-O(&ET(&1O97-N)W0@<V5N9"!E>'1R82!H96%D97)S('=H
M96X@=7-I;F<@;6%I;"@I"EMC:FA=($%D9&EN9R!A("=M87)G:6YS)R!A='1R
M:6)U=&4@=&\@2%1-3$1O8W5M96YT('1O(&5N86)L92!T=7)N:6YG(&]F9@H@
M("`@("!D;V-U;65N="!M87)G:6YS+@H*"BTM+2TM+0IV,2XS+C(*+2TM+2TM
M"@I;8VIH72!297!L86-E9"!M;V1U;&4N6$U,7U)$1BYP:'`@=VET:"!A('=O
M<FMI;F<@8V]P>2X*"@HM+2TM+2T*=C$N,RXQ"BTM+2TM+0H*6V-J:%T@4F5V
M86UP960@=&AE($UI;65-97-S86=E(&-L87-S('1O(&)E(&UU8V@@<VUA;&QE
M<B!A;F0@<VEM<&QE<BX*6V-J:%T@4F5P;&%C960@=&AE($UI;65087)T1&%T
M82!C;&%S<R!W:71H(&$@<V5T(&]F(&9U;F-T:6]N<R!T:&%T(&UO<F4*("`@
M("`@8VQE86YL>2!A;F0@8V]R<F5C=&QY(&EM<&QE;65N="!T:&4@34E-12!S
M=&%N9&%R9"X*6V-J:%T@<V5L96-T7VQA;F<H*2!N;W<@8VAE8VMS(&9O<B!E
M;B!W:&5N('1H92!B<F]W<V5R(')E<75E<W1S(&5N7T="+"!E=&,N"EMC:FA=
M(%)E<&QA8V5D(&%L;"!C86QL<R!T;R!E<F5G*B!F=6YC=&EO;G,@=VET:"!P
M<F5G*B!F=6YC=&EO;G,L(&9O<B!S<&5E9"X*("`@("`@0F5C875S92!O9B!T
M:&ES('=E(&YO=R!R97%U:7)E('!H<"`S+C`N,3(@;W(@;&%T97(N"@H*+2TM
M+2TM"G8Q+C,N,`HM+2TM+2T*"EL@("!=($=E<FUA;B!U<&1A=&5D"EL@("!=
M($9I>&5D('1H92!B<F]K96X@)V)A8VLG(&QI;FL@:6X@<V5T=7`N<&AP,R!F
M;W(@;F]N+45N9VQI<V@@=7-E<G,*6R`@(%T@;6%N86=E<BYP:'`S+"!D8BYL
M:6(L(&%N9"!C;VAO<G1S(&%R92!N;W<@9V]N92X@5&AE>2!W97)E(&%L;"!U
M;FUA:6YT86EN960L(&]U="!O9B!D871E+"!A;F0@;F]T('9E<GD@=7-E9G5L
M+@H@("`@("!687)I;W5S(&)U:6QD('-C<FEP=',@87)E('5P9&%T960@=&\@
M<F5F;&5C="!T:&ES+@I;:F]N72!296UO=F5D(&-O;F9I9R]D969A=6QT<RYP
M:'`S(&EN('!R969E<F5N8V4@;V8@:&]R9&4N<&AP,PI;("`@72!&:7AE9"!A
M('-E='5P+G!H<#,@8G5G('=H97)E("(@=V%S('5S960@:6YS=&5A9"!O9B`G
M(&9O<B`D9&5F875L="!V86QU97,@*&UI:V4I"EL@("!=($YE=R!&:6YN:7-H
M('1R86YS;&%T:6]N<R`H5&AA;FMS('1O.B!L96\N:F%A<VME;&%I;F5N0&MO
M;'5M8G5S+F9I*0I;("`@72!&:7AE9"!L>6YX('-U<'!O<G0@:7-S=64@=VET
M:"!L;V=I;BYP:'`S"EL@("!=($9I>&5D('-I9VYU<"YP:'`S('!R;V)L96US
M"EL@("!=($9I>&5D('!R;V)L96TN<&AP,R!P<F]B;&5M<R`H;'EN>"!S=7!P
M;W)T*0I;("`@72!!9&1E9"!D871A8F%S92!C<F5A=&EO;B!S8W)I<'1S(&9O
M<B!B=6EL9&EN9R!P:'!L:6(@8V]M<&QI86X@=&%B;&5S"EL@("!=($UO=F5D
M(&%L;"!D;V-U;65N=&%T:6]N("AE>&-E<'0@4D5!1$U%(&%N9"!#3U!924Y'
M*2!I;G1O(&1O8W,O('-U8F1I<@I;("`@72!!9&1E9"!A(&-A8VAI;F<@8VQA
M<W,@<V\@=&AA="!C86-H:6YG(&-A;B!B92!T=7)N960@;VX@<&5R('!A9V4@
M:68@;F5E9&5D"@H*+2TM+2TM"G8Q+C$N,0HM+2TM+2T*"EL@("!=($AO<F1E
M('5N9&5R<W1A;F1S($9R96YC:"`H=&AA;FMS('1O($UA=&AI974@0VQA8F%U
M=`H@("`@("`\8VQA8F%U;'1`;75L=&EM86YI82YC;VT^*0I;("`@72!-86IO
M<B!F<F%M97-E="!R961E<VEG;@I;("`@72!!=71O(')E9VES=')A=&EO;B]C
M;VYG:7)U871I;VX@;V8@;6]D=6QE<PH*"BTM+2TM+0IV,2XP+C,*+2TM+2TM
M"@I;("`@72!(;W)D92!I<R!N;W<@=V5B('-U<F9A8FQE+@I;("`@72!(;W)D
M92!H86YD;&5S(&QY;G@@*'!S975D;VQY*0I;("`@72!%>'1E;F1A8FQE(&UE
M;G5S+B`H;65N=2YT>'0@:6X@:&]R9&4O8V]N9FEG*0I;("`@72!3:6=N=7`L
M('!R;V)L96T@<F5P;W)T:6YG+"!H96QP(&9U;F-T:6]N<R!A<F4@;F]W('!A
M<G0@;V8@:&]R9&4*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]D;V-S+T-/1$E.1U]35$%.1$%21%,`````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8Q-3`V`#$P-#$W,S8R
M-S0S`#`Q-S8U,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*($AO<F1E($-O9&EN
M9R!3=&%N9&%R9',*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S="!U
M<&1A=&4Z("`@)$1A=&4Z(#(P,#8O,#,O,3<@,#8Z,3@Z,#<@)`HZ4F5V:7-I
M;VXZ("`@("`@)%)E=FES:6]N.B`Q+C@T+C$P+C$U("0*.D%U=&AO<G,Z("`@
M("`@($IO;B!087)I<V4L($-H=6-K($AA9V5N8G5C:`HZ0V]N=&%C=#H@("`@
M("`@9&5V0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z.B!#;VYT96YT
M<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I);F1E;G1I;F<*/3T]/3T]/3T]
M"@I5<V4@86X@:6YD96YT(&]F(#0@<W!A8V5S+"!W:71H(&YO('1A8G,N"@H*
M0V]N=')O;"!3=')U8W1U<F5S"CT]/3T]/3T]/3T]/3T]/3T]/0H*5&AE<V4@
M:6YC;'5D92!@8&EF8&`L(&!@9F]R8&`L(&!@=VAI;&5@8"P@8&!S=VET8VA@
M8"P@971C+B`@2&5R92!I<R!A;B!E>&%M<&QE"F!@:69@8"!S=&%T96UE;G0L
M('-I;F-E(&ET(&ES('1H92!M;W-T(&-O;7!L:6-A=&5D(&]F('1H96TZ.@H*
M("!I9B`H*&-O;F1I=&EO;C$I('Q\("AC;VYD:71I;VXR*2D@>PH@("`@("!A
M8W1I;VXQ.PH@('T@96QS96EF("@H8V]N9&ET:6]N,RD@)B8@*&-O;F1I=&EO
M;C0I*2!["B`@("`@(&%C=&EO;C(["B`@?2!E;'-E('L*("`@("`@9&5F875L
M=&%C=&EO;CL*("!]"@I-=6QT:2UL:6YE(&EF(&-O;F1I=&EO;G,@87)E(&)R
M86-E9"!T:&ES('=A>3HZ"@H@(&EF("@H8V]N9&ET:6]N,2D@?'P@*&-O;F1I
M=&EO;C(I('Q\("AC;VYD:71I;VXS*2!\?`H@("`@("`H8V]N9&ET:6]N-"DI
M('L*("`@("`@86-T:6]N,3L*("!]"@I#;VYT<F]L('-T871E;65N=',@<VAO
M=6QD(&AA=F4@;VYE('-P86-E(&)E='=E96X@=&AE(&-O;G1R;VP@:V5Y=V]R
M9"!A;F0*;W!E;FEN9R!P87)E;G1H97-I<RP@=&\@9&ES=&EN9W5I<V@@=&AE
M;2!F<F]M(&9U;F-T:6]N(&-A;&QS+@H*1&\@;F]T(&]M:70@=&AE(&-U<FQY
M(&)R86-E<R!U;F1E<B!A;GD@8VER8W5M<W1A;F-E+B`@26X@=&AE(&-A<V4@
M;V8@82!L87)G90IN=6UB97(@;V8@<VAO<G0@=&5S=',@86YD(&%C=&EO;G,L
M('1H92!F;VQL;W=I;F<@:7,@86-C97!T86)L93HZ"@H@(&EF("AC;VYD:71I
M;VXI("`@>R!A8W1I;VX[('T*("!I9B`H8V]N9&ET:6]N(#(I('L@86-T:6]N
M(#([('T*("`N+BX*"D9O<B!S=VET8V@@<W1A=&5M96YT<SHZ"@H@('-W:71C
M:"`H8V]N9&ET:6]N*2!["B`@8V%S92`Q.@H@("`@("!A8W1I;VXQ.PH@("`@
M("!B<F5A:SL*"B`@8V%S92`R.@H@("`@("!A8W1I;VXR.PH@("`@("!B<F5A
M:SL*"B`@9&5F875L=#H*("`@("`@9&5F875L=&%C=&EO;CL*("`@("`@8G)E
M86L["B`@?0H*"D9U;F-T:6]N($-A;&QS"CT]/3T]/3T]/3T]/3T]"@I&=6YC
M=&EO;G,@<VAO=6QD(&)E(&-A;&QE9"!W:71H(&YO('-P86-E<R!B971W965N
M('1H92!F=6YC=&EO;B!N86UE+"!T:&4*;W!E;FEN9R!P87)E;G1H97-I<RP@
M86YD('1H92!F:7)S="!P87)A;65T97([('-P86-E<R!B971W965N(&-O;6UA
M<R!A;F0@96%C:`IP87)A;65T97(L(&%N9"!N;R!S<&%C92!B971W965N('1H
M92!L87-T('!A<F%M971E<BP@=&AE(&-L;W-I;F<@<&%R96YT:&5S:7,L"F%N
M9"!T:&4@<V5M:6-O;&]N+B`@2&5R92=S(&%N(&5X86UP;&4Z.@H*("`D=F%R
M(#T@9F]O*"1B87(L("1B87HL("1Q=75X*3L*"D%S(&1I<W!L87EE9"!A8F]V
M92P@=&AE<F4@<VAO=6QD(&)E(&]N92!S<&%C92!O;B!E:71H97(@<VED92!O
M9B!A;B!E<75A;',@<VEG;@IU<V5D('1O(&%S<VEG;B!T:&4@<F5T=7)N('9A
M;'5E(&]F(&$@9G5N8W1I;VX@=&\@82!V87)I86)L92X@($EN('1H92!C87-E
M(&]F(&$*8FQO8VL@;V8@<F5L871E9"!A<W-I9VYM96YT<RP@;6]R92!S<&%C
M92!M87D@8F4@:6YS97)T960@=&\@<')O;6]T90IR96%D86)I;&ET>3HZ"@H@
M("1S:&]R="`@("`@("`@(#T@9F]O*"1B87(I.PH@("1L;VYG7W9A<FEA8FQE
M(#T@9F]O*"1B87HI.PH*"D9U;F-T:6]N($1E9FEN:71I;VYS"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]"@I&=6YC=&EO;B!D96-L87)A=&EO;G,@9F]L;&]W('1H
M92`B0E-$+T%L;&UA;B(@8V]N=F5N=&EO;CHZ"@H@(&9U;F-T:6]N(&9O;T9U
M;F-T:6]N*"1A<F<Q+"`D87)G,B`]("<G*0H@('L*("`@("`@:68@*&-O;F1I
M=&EO;BD@>PH@("`@("`@("`@<W1A=&5M96YT.PH@("`@("!]"B`@("`@(')E
M='5R;B`D=F%L.PH@('T*"D%R9W5M96YT<R!W:71H(&1E9F%U;'0@=F%L=65S
M(&=O(&%T('1H92!E;F0@;V8@=&AE(&%R9W5M96YT(&QI<W0N("!!;'=A>7,*
M871T96UP="!T;R!R971U<FX@82!M96%N:6YG9G5L('9A;'5E(&9R;VT@82!F
M=6YC=&EO;B!I9B!O;F4@:7,@87!P<F]P<FEA=&4N"@I&=6YC=&EO;G,@=7-E
M9"!O;FQY(&EN('1H92!C=7)R96YT('-C<FEP="]C;&%S<R`H92YG+B!P<FEV
M871E(&UE;6)E<B!M971H;V1S*0IS:&]U;&0@8F5G:6X@=VET:"!A(&!@7V!@
M(&-H87)A8W1E<B`H92YG+B!@8%]E>&%M<&QE3&EB<F%R>6!@*2X@(%1H:7,@
M:&5L<',*9&ES=&EN9W5I<V@@=&AE<V4@<')I=F%T92!F=6YC=&EO;B!C86QL
M<R!F<F]M(&]T:&5R+"!P=6)L:6,@9G5N8W1I;VX@8V%L;',N"@H*0VQA<W,@
M1&5F:6YI=&EO;G,*/3T]/3T]/3T]/3T]/3T]/3T*"D-L87-S(&1E9FEN:71I
M;VYS(&9O;&QO=R!T:&4@(DLF4B]+97)N96PB(&-O;G9E;G1I;VXZ.@H*("!C
M;&%S<R!3;VUE7T-L87-S('L*"B`@("`@('9A<B`D7W9A<FEA8FQE.PH*("`@
M("`@9G5N8W1I;VX@9F]O1G5N8W1I;VXH*0H@("`@("!["B`@("`@("`@("!S
M=&%T96UE;G0["B`@("`@('T*"B`@?0H*3F]T92!T:&4@8FQA;FL@;&EN97,@
M870@=&AE(&)E9VEN;FEN9R!A;F0@96YD(&]F('1H92!C;&%S<R!D969I;FET
M:6]N+@H*"DYA;6EN9R!,:6)R87)I97,*/3T]/3T]/3T]/3T]/3T]/0H*3&EB
M<F%R:65S("AA;GD@9FEL92!L;V-A=&5D(&EN('1H92!@8&QI8B]@8"!D:7)E
M8W1O<GD@;V8@=&AE(&%P<&QI8V%T:6]N*0IS:&]U;&0@8F4@;F%M960@=VET
M:"!C87!I=&%L(&QE='1E<G,@870@=&AE(&)E9VEN;FEN9R!O9B!E86-H('=O
M<F0N("!5<V4*<W1U9&QY8V%P<R!F;W(@;F%M:6YG.R!A('-E<W-I;VX@8V%C
M:&4@8VQA<W,@=V]U;&0@8F4@<W1O<F5D(&EN"F!@;&EB+U-E<W-I;VY#86-H
M92YP:'!@8"X*"DEF('1H92!L:6)R87)Y+V-L87-S(&ES(&5X=&5N9&5D+"!T
M:&4@97AT96YD:6YG(&9I;&5S('-H;W5L9"!B92!S=&]R960@:6X@80ID:7)E
M8W1O<GD@=6YD97(@8&!L:6(O8&`@=VET:"!T:&4@<V%M92!N86UE(&%S('1H
M92!O<FEG:6YA;"!L:6)R87)Y+@I3=6)C;&%S<V5S(&9O;&QO=R!T:&4@97AA
M8W0@<V%M92!N86UI;F<@<F5Q=6ER96UE;G1S+"!E>&-E<'0@=&AA="!I9B!T
M:&4*<W5B8VQA<W,@:7,@:6YS=&%N=&EA=&5D(&)Y(&$@9F%C=&]R>2!M971H
M;V0L(&ET('-H;W5L9"!B92!A;&P@;&]W97)C87-E+@H*17AA;7!L90HM+2TM
M+2TM"@I4:&4@(D5X86UP;&4@3&EB<F%R>2(@;&EB<F%R>2!S:&]U;&0@8F4@
M<V%V960@87,@8&!L:6(O17AA;7!L94QI8G)A<GDN<&AP8&`N"D%N>2!F:6QE
M(&5X=&5N9&EN9R!T:&4@;&EB<F%R>2]C;&%S<R!S:&]U;&0@8F4@<W1O<F5D
M(&EN('1H92!D:7)E8W1O<GD*8&!L:6(O17AA;7!L94QI8G)A<GDO8&`N"@H*
M0V]M;65N=',*/3T]/3T]/3T*"DEN;&EN92!D;V-U;65N=&%T:6]N(&9O<B!C
M;&%S<V5S('-H;W5L9"!F;VQL;W<@=&AE(&!*879A9&]C(&-O;G9E;G1I;VY@
M7RX*"BXN(%]*879A9&]C(&-O;G9E;G1I;VXZ(&AT='`Z+R]J879A+G-U;BYC
M;VTO<')O9'5C=',O:F1K+VIA=F%D;V,O=W)I=&EN9V1O8V-O;6UE;G1S+VEN
M9&5X+FAT;6P*"E%U:6-K(&5X86UP;&4@9F]R('!R:79A=&4@=F%R:6%B;&4@
M9&5F:6YI=&EO;B!F;W(@2&]R9&4Z.@H*("`@("\J*@H@("`@("H@5F%R:6%B
M;&4@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!D871A='EP90H@
M("`@("HO"@I1=6EC:R!E>&%M<&QE(&9U;F-T:6]N(&1E9FEN:71I;VX@9F]R
M($AO<F1E.CH*"B`@("`O*BH*("`@("`J(%1H92!D97-C<FEP=&EO;B!O9B!T
M:&4@9G5N8W1I;VX@9V]E<R!H97)E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M6W!R:79A=&4@?"!P<F]T96-T961="B`@("`@*B!;1&]N)W0@8F]T:&5R('=I
M=&@@(G!U8FQI8R(@<VEN8V4@:70@:7,@=&AE(&1E9F%U;'0@:68@;F]T('-P
M96-I9FEE9"Y="B`@("`@*@H@("`@("H@0'!A<F%M(&1A=&%T>7!E("1V87)I
M86)L96YA;64@("!$97-C<FEP=&EO;B!O9B!V87)I86)L92X*("`@("`J($!P
M87)A;2!D871A='EP92`D=F%R:6%B;&4R;F%M92`@1&5S8W)I<'1I;VX@;V8@
M=F%R:6%B;&4R+@H@("`@("H@+BXN"B`@("`@*B!;26YS97)T(#(@<W!A8V5S
M(&%F=&5R('1H92!L;VYG97-T("1V87)I86)L92!D969I;FET:6]N+"!A;F0@
M=&AE;B!L:6YE"B`@("`@*B`@=7`@86QL(&1E<V-R:7!T:6]N<R!W:71H('1H
M:7,@9&5S8W)I<'1I;VY="B`@("`@*@H@("`@("H@0')E='5R;B!D871A='EP
M92`@1&5S8W)I<'1I;VX@;V8@<F5T=7)N('9A;'5E+@H@("`@("H@6T]N8V4@
M86=A:6XL(&EN<V5R="`R('-P86-E<R!A9G1E<B!T:&4@9&%T871Y<&4L(&%N
M9"!L:6YE('5P(&%L;`H@("`@("H@('-U8G-E<75E;G0@;&EN97,L(&EF(&%N
M>2P@=VET:"!T:&ES(&-H87)A8W1E<BY="B`@("`@*@H@("`@("H@0&%B<W1R
M86-T(%M/;FQY(&EF(&YE8V5S<V%R>5T*("`@("`J"B`@("`@*B!`<VEN8V4@
M2&]R9&4@>"YX(%M/;FQY(&EF(&YE8V5S<V%R>2`M('5S92!I9B!F=6YC=&EO
M;B!I<R!A9&1E9"!T;R!T:&4*("`@("`J(&-U<G)E;G0@<F5L96%S92!V97)S
M:6]N<R!T;R!I;F1I8V%T92!T:&%T('1H92!F=6YC=&EO;B!H87,@;F]T(&)E
M96X*("`@("`J(&%V86EL86)L92!I;B!P<F5V:6]U<R!V97)S:6]N<RY="B`@
M("`@*B\*"@I);F-L=61I;F<@0V]D90H]/3T]/3T]/3T]/3T]/0H*268@>6]U
M(&%R92!I;F-L=61I;F<@82!C;&%S<RP@9G5N8W1I;VX@;&EB<F%R>2P@;W(@
M86YY=&AI;F<@96QS92!W:&EC:"!W;W5L9`IC875S92!A('!A<G-E(&5R<F]R
M(&EF(&EN8VQU9&5D('1W:6-E+"!A;'=A>7,@=7-E(&!I;F-L=61E7V]N8V5@
M7RX@(%1H:7,@=VEL;`IE;G-U<F4@=&AA="!N;R!M871T97(@:&]W(&UA;GD@
M9F%C=&]R>2!M971H;V1S('=E('5S92!O<B!H;W<@;75C:"!D>6YA;6EC"FEN
M8VQU<VEO;B!W92!D;RP@=&AE(&QI8G)A<GD@=VEL;"!O;FQY(&)E(&EN8VQU
M9&5D(&]N8V4N"@I)9B!Y;W4@87)E(&EN8VQU9&EN9R!A('-T871I8R!F:6QE
M;F%M92P@<W5C:"!A<R!A(&-O;F8@9FEL92!O<B!A('1E;7!L871E('1H870*
M:7,@*F%L=V%Y<RH@=7-E9"P@=7-E(&!R97%U:7)E8%\N"@I)9B!Y;W4@87)E
M(&1Y;F%M:6-A;&QY(&EN8VQU9&EN9R!A(&9I;&5N86UE+"!O<B!W86YT('1H
M92!C;V1E('1O(&]N;'D@8F4@=7-E9`IC;VYD:71I;VYA;&QY("AA;B!O<'1I
M;VYA;"!T96UP;&%T92DL('5S92!@:6YC;'5D96!?+@H*+BX@7VEN8VQU9&5?
M;VYC93H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYI
M;F-L=61E+6]N8V4N<&AP"BXN(%]R97%U:7)E.B!H='1P.B\O=W=W+G!H<"YN
M970O;6%N=6%L+V5N+V9U;F-T:6]N+G)E<75I<F4N<&AP"BXN(%]I;F-L=61E
M.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+FEN8VQU
M9&4N<&AP"@H*4$A0($-O9&4@5&%G<PH]/3T]/3T]/3T]/3T]"@I!;'=A>7,@
M=7-E(&!@/#]P:'`@/SY@8"!T;R!D96QI;6ET(%!(4"!C;V1E+"!N;W0@=&AE
M(&!@/#\@/SY@8"!S:&]R=&AA;F0N"E1H:7,@:7,@<F5Q=6ER960@9F]R(%!%
M05(@8V]M<&QI86YC92!A;F0@:7,@86QS;R!T:&4@;6]S="!P;W)T86)L92!W
M87D@=&\*:6YC;'5D92!02%`@8V]D92!O;B!D:69F97)I;F<@;W!E<F%T:6YG
M('-Y<W1E;7,@86YD('-E='5P<RX*"DEN('1E;7!L871E<RP@;6%K92!S=7)E
M('1O('5S92!T:&ES(&%S('=E;&P@*&!@/#]P:'`@96-H;R`D=F%R;F%M92`_
M/F!@*2P@87,*=&AE('-H;W)T8W5T('9E<G-I;VX@*&!@/#\]("1V87(@/SY@
M8"D@9&]E<R!N;W0@=V]R:R!W:71H(&!S:&]R=%]O<&5N7W1A9V!?"G1U<FYE
M9"!O9F8N"@HN+B!?<VAO<G1?;W!E;E]T86<Z(&AT='`Z+R]W=W<N<&AP+FYE
M="]M86YU86PO96XO8V]N9FEG=7)A=&EO;BYD:7)E8W1I=F5S+G!H<"-I;FDN
M<VAO<G0M;W!E;BUT86<*"@I(96%D97(@0V]M;65N="!";&]C:W,*/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"@I!;&P@<V]U<F-E(&-O9&4@9FEL97,@:6X@=&AE
M($AO<F1E(&1I<W1R:6)U=&EO;B!S:&]U;&0@8V]N=&%I;B!T:&4@9F]L;&]W
M:6YG"F-O;6UE;G0@8FQO8VL@87,@=&AE(&AE861E<CH*"D5X86UP;&4@9F]R
M(&!,1U!,8%\G960@2&]R9&4@8V]D93HZ"@H@("`@+RHJ"B`@("`@*B!4:&4@
M2&]R9&5?1F]O.CH@8VQA<W,@<')O=FED97,@86X@05!)(&9O<B!V87)I;W5S
M(&9O;PH@("`@("H@=&5C:&YI<75E<R!T:&%T(&-A;B!B92!U<V5D(&)Y($AO
M<F1E(&%P<&QI8V%T:6]N<RX*("`@("`J"B`@("`@*B`D2&]R9&4*("`@("`J
M"B`@("`@*B!#;W!Y<FEG:'0@,3DY.2TR,#`Q($]R:6=I;F%L($%U=&AO<B`\
M875T:&]R0&5X86UP;&4N8V]M/@H@("`@("H@0V]P>7)I9VAT(#(P,#$@66]U
M<B!.86UE(#QY;W5`97AA;7!L92YC;VT^"B`@("`@*@H@("`@("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("`@("`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@("`@("H*("`@("`J($!A=71H;W(@($]R:6=I;F%L($%U=&AO<B`\
M875T:&]R0&5X86UP;&4N8V]M/@H@("`@("H@0&%U=&AO<B`@66]U<B!.86UE
M(#QY;W5`97AA;7!L92YC;VT^"B`@("`@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("`@("`J($!P86-K86=E($AO<F1E7U!A8VMA9V4*("`@("`J+PH*+BX@7TQ'
M4$PZ(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O;&=P;"UL
M:6-E;G-E+G!H<`H*17AA;7!L92!F;W(@8$=03&!?)V5D(&%P<&QI8V%T:6]N
M(&-O9&4Z.@H*("`@("\J*@H@("`@("H@5&AE($%P<%]"87(Z.B!C;&%S<R!C
M;VYT86EN<R!A;&P@9G5N8W1I;VYS(')E;&%T960@=&\@:&%N9&QI;F<*("`@
M("`J(&)A<G,@:6X@07!P+@H@("`@("H*("`@("`J("1(;W)D90H@("`@("H*
M("`@("`J($-O<'ER:6=H="`Q.3DY+3(P,#$@3W)I9VEN86P@075T:&]R(#QA
M=71H;W)`97AA;7!L92YC;VT^"B`@("`@*B!#;W!Y<FEG:'0@,C`P,2!9;W5R
M($YA;64@/'EO=4!E>&%M<&QE+F-O;3X*("`@("`J"B`@("`@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H1U!,*2X@268@>6]U"B`@("`@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL
M+@H@("`@("H*("`@("`J($!A=71H;W(@($]R:6=I;F%L($%U=&AO<B`\875T
M:&]R0&5X86UP;&4N8V]M/@H@("`@("H@0&%U=&AO<B`@66]U<B!.86UE(#QY
M;W5`97AA;7!L92YC;VT^"B`@("`@*B!`<VEN8V4@("!!<'`@,2XP"B`@("`@
M*B!`<&%C:V%G92!A<'`*("`@("`J+PH*"BXN(%]'4$PZ(&AT='`Z+R]W=W<N
M;W!E;G-O=7)C92YO<F<O;&EC96YS97,O9W!L+6QI8V5N<V4N<&AP"@I4:&5R
M92=S(&YO(&AA<F0@<G5L92!T;R!D971E<FUI;F4@=VAE;B!A(&YE=R!C;V1E
M(&-O;G1R:6)U=&5R('-H;W5L9"!B92!A9&1E9`IT;R!T:&4@;&ES="!O9B!A
M=71H;W)S(&9O<B!A(&=I=F5N('-O=7)C92!F:6QE+B`@26X@9V5N97)A;"P@
M=&AE:7(@8VAA;F=E<PIS:&]U;&0@9F%L;"!I;G1O('1H92`B<W5B<W1A;G1I
M86PB(&-A=&5G;W)Y("AM96%N:6YG('-O;65W:&5R92!A<F]U;F0@,3`E('1O
M"C(P)2!O9B!C;V1E(&-H86YG97,I+B`@17AC97!T:6]N<R!C;W5L9"!B92!M
M861E(&9O<B!R97=R:71I;F<@9G5N8W1I;VYS(&]R"F-O;G1R:6)U=&EN9R!N
M97<@;&]G:6,N"@I3:6UP;&4@8V]D92!R96]R9V%N:7IA=&EO;B!O<B!B=6<@
M9FEX97,@=V]U;&0@;F]T(&IU<W1I9GD@=&AE(&%D9&ET:6]N(&]F(&$*;F5W
M(&EN9&EV:61U86P@=&\@=&AE(&QI<W0@;V8@875T:&]R<RX*"@I#5E,@5&%G
M<PH]/3T]/3T]/0H*26YC;'5D92!T:&4@/&1O;&QA<CY(;W)D93H@/&1O;&QA
M<CX@0U93('9E;F1O<B!T86<@:6X@96%C:"!F:6QE+B`@07,@96%C:"!F:6QE
M"FES(&5D:71E9"P@861D('1H:7,@=&%G(&EF(&ET)W,@;F]T('EE="!P<F5S
M96YT("AO<B!R97!L86-E(&5X:7-T:6YG(&9O<FUS"G-U8V@@87,@/&1O;&QA
M<CY)9#QD;VQL87(^+"`B3&%S="!-;V1I9FEE9#HB+"!E=&,N*2X*"D580T50
M5$E/3CH@1&]N)W0@:6YC;'5D92!T:&5S92!I;B!T96UP;&%T97,N"@H*17AA
M;7!L92!54DQS"CT]/3T]/3T]/3T]/0H*57-E(&!@97AA;7!L92YC;VU@8"!F
M;W(@86QL(&5X86UP;&4@55),<RP@<&5R(&!21D,@,C8P-F!?+@H*+BX@7U)&
M0R`R-C`V.B!H='1P.B\O=W=W+F9A<7,N;W)G+W)F8W,O<F9C,C8P-BYH=&UL
M"@H*<&AP+FEN:2!S971T:6YG<PH]/3T]/3T]/3T]/3T]/3T]"@I!;&P@2&]R
M9&4@8V]D92!S:&]U;&0@=V]R:R!W:71H(&!R96=I<W1E<E]G;&]B86QS8%\@
M9&ES86)L960N("!4:&ES(&UE86YS"G5S:6YG(&!@)%]#3T]+245@8"P@8&`D
M7U-%4U-)3TY@8"P@8&`D7U-%4E9%4F!@(&%N9"!@8"1?14Y68&`@=&\@86-C
M97-S(&%L;`IC;V]K:64L('-E<W-I;VXL('-E<G9E<B!A;F0@96YV:7)O;FUE
M;G0@9&%T82P@<F5S<&5C=&EV96QY+@H*5&\@<F5T<FEE=F4@<&]S=&5D(&1A
M=&$@*&EN('1H92!G;&]B86P@8&`D7T=%5&!@(&%N9"!@8"1?4$]35&!@('9A
M<FEA8FQE<RDL"GEO=2!S:&]U;&0@;F]R;6%L;'D@=7-E(&!5=&EL.CIG971&
M;W)M1&%T82@I8%\@=VAI8V@@=VEL;"!A=71O;6%T:6-A;&QY(')U;@I@571I
M;#HZ9&ES<&5L36%G:6-1=6]T97,H*6!?+B!4:&ES('=I;&P@96YS=7)E('1H
M870@86QL($AO<F1E(&-O9&4@=VEL;"!W;W)K"G)E9V%R9&QE<W,@;V8@=&AE
M('-E='1I;F<@;V8@8&UA9VEC7W%U;W1E<U]G<&-@7RX@5&AE(&]N;'D@=&EM
M92!Y;W4@<VAO=6QD(&YO=`IU<V4@8%5T:6PZ.F=E=$9O<FU$871A*"E@7R!I
M<R!I9B!Y;W4@=V%N="!T;R!D:7)E8W1L>2!A8V-E<W,@82!'150@;W(@4$]3
M5`IV87)I86)L92!I;G-T96%D.R!I;B!T:&ES(&-A<V4L('EO=2!S:&]U;&0@
M=7-E(&!5=&EL.CIG971'970H*6!?(&]R"F!5=&EL.CIG9710;W-T*"E@7R!R
M97-P96-T:79E;'DN"@I!;&P@2&]R9&4@8V]D92!S:&]U;&0@=V]R:R!W:71H
M(&!E<G)O<E]R97!O<G1I;F=@7R`]($5?04Q,+B!&86EL=7)E('1O(&1O('-O
M"G=O=6QD(')E<W5L="!I;B!U9VQY(&]U='!U="P@97)R;W(@;&]G<R!G971T
M:6YG(&9I;&QE9"!W:71H(&QO=',@;V8@=V%R;FEN9PIM97-S86=E<RP@;W(@
M979E;B!D;W=N<FEG:'0@8G)O:V5N('-C<FEP=',N"@I.;R!(;W)D92!C;V1E
M('-H;W5L9"!A<W-U;64@=&AA="`G+B<@:7,@:6X@=&AE(&EN8VQU9&4@<&%T
M:"X@06QW87ES('-P96-I9GD*)RXO)R!I;B!F<F]N="!O9B!A(&9I;&5N86UE
M('=H96X@>6]U(&%R92!I;F-L=61I;F<@82!F:6QE(&EN('1H92!S86UE"F1I
M<F5C=&]R>2X*"BXN(%]R96=I<W1E<E]G;&]B86QS.B!H='1P.B\O=W=W+G!H
M<"YN970O;6%N=6%L+V5N+W-E8W5R:71Y+G)E9VES=&5R9VQO8F%L<RYP:'`*
M+BX@7VUA9VEC7W%U;W1E<U]G<&,Z(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU
M86PO96XO<F5F+FEN9F\N<&AP(VEN:2YM86=I8RUQ=6]T97,M9W!C"BXN(%]E
M<G)O<E]R97!O<G1I;F<Z(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO
M<F5F+F5R<F]R9G5N8RYP:'`C:6YI+F5R<F]R+7)E<&]R=&EN9PHN+B!?571I
M;#HZ9V5T1F]R;41A=&$H*3H@:'1T<#HO+V1E=BYH;W)D92YO<F<O87!I+V9R
M86UE=V]R:R](;W)D95]5=&EL+U5T:6PN:'1M;"-M971H;V1G971&;W)M1&%T
M80HN+B!?571I;#HZ9&ES<&5L36%G:6-1=6]T97,H*3H@:'1T<#HO+V1E=BYH
M;W)D92YO<F<O87!I+V9R86UE=V]R:R](;W)D95]5=&EL+U5T:6PN:'1M;"-M
M971H;V1D:7-P96Q-86=I8U%U;W1E<PHN+B!?571I;#HZ9V5T1V5T*"DZ(&AT
M='`Z+R]D978N:&]R9&4N;W)G+V%P:2]F<F%M97=O<FLO2&]R9&5?571I;"]5
M=&EL+FAT;6PC;65T:&]D9V5T1V5T"BXN(%]5=&EL.CIG9710;W-T*"DZ(&AT
M='`Z+R]D978N:&]R9&4N;W)G+V%P:2]F<F%M97=O<FLO2&]R9&5?571I;"]5
M=&EL+FAT;6PC;65T:&]D9V5T4&]S=`H*"EA(5$U,(#$N,"!#;VUP;&EA;F-E
M"CT]/3T]/3T]/3T]/3T]/3T]/3T]"@I!;&P@=&%G(&YA;65S(&%N9"!P87)A
M;65T97)S(&UU<W0@8F4@;&]W97(@8V%S92!I;F-L=61I;F<@:F%V87-C<FEP
M="!E=F5N=`IH86YD;&5R<SHZ"@H@("`@/&9O;G0@8V]L;W(](B-&1D9&1D8B
M/BXN+CPO9F]N=#X*("`@(#QA(&AR968](FAT='`Z+R]E>&%M<&QE+F-O;2(@
M;VYM;W5S96]V97(](G-T871U<STG)R(@;VYM;W5S96]U=#TB<W1A='5S/2<G
M(CXN+BX\+V$^"@I!;&P@=&%G('!A<F%M971E<G,@;75S="!B92!O9B!A('9A
M;&ED('!A<F%M971E<CTB=F%L=64B(&9O<FT@*&YU;65R:6,@=F%L=65S"FUU
M<W0@86QS;R!B92!S=7)R;W5N9&5D(&)Y('%U;W1E<RDN("!&;W(@<&%R86UE
M=&5R<R!T:&%T(&AA9"!N;R!V86QU92!I;B!(5$U,+`IT:&4@<&%R86UE=&5R
M(&YA;64@:7,@=&AE('9A;'5E+B`@1F]R(&5X86UP;&4Z.@H*("`@(#QI;G!U
M="!T>7!E/2)C:&5C:V)O>"(@8VAE8VME9#TB8VAE8VME9"(^"B`@("`\<V5L
M96-T(&YA;64](F5X86UP;&4B/@H@("`@("`@(#QO<'1I;VX@<V5L96-T960]
M(G-E;&5C=&5D(B!V86QU93TB,2(^17AA;7!L93PO;W!T:6]N/@H@("`@/"]S
M96QE8W0^"B`@("`\=&0@;F]W<F%P/2)N;W=R87`B/D5X86UP;&4\+W1D/@H*
M06QL('1A9W,@;75S="!B92!P<F]P97)L>2!C;&]S960N("!486=S('=H97)E
M(&-L;W-I;F<@:7,@9F]R8FED9&5N(&UU<W0@96YD"G=I=&@@82!S<&%C92!A
M;F0@82!S;&%S:#HZ"@H@("`@/&)R("\^"B`@("`\:'(@+SX*("`@(#QI;6<@
M<W)C/2)E>&%M<&QE+F=I9B(@86QT/2)%>&%M<&QE(B`O/@H@("`@/&EN<'5T
M('1Y<&4](G-U8FUI="(@=F%L=64](D5X86UP;&4B("\^"@I!;&P@9F]R;2!D
M969I;FET:6]N<R!M=7-T(&)E(&]N('1H96ER(&]W;B!L:6YE(&%N9"!E:71H
M97(@9G5L;'D@9&5F:6YE9"!W:71H:6X*82!@8#QT9#X\+W1D/F!@('!A:7(@
M;W(@8F4@;W5T<VED92!T86)L92!T86=S+B`@1F]R;7,@;75S="!A;'-O(&%L
M=V%Y<R!H879E(&%N"F%C=&EO;B!P87)A;65T97(Z.@H*("`@(#QF;W)M(&UE
M=&AO9#TB<&]S="(@86-T:6]N/2)H='1P.B\O97AA;7!L92YC;VTO97AA;7!L
M92YC9VDB/@H@("`@/'1A8FQE/@H@("`@("`@(#QT<CX\=&0^97AA;7!L93PO
M=&0^/"]T<CX*("`@(#PO=&%B;&4^"B`@("`\+V9O<FT^"@H@("`@/'1A8FQE
M/@H@("`@("`@(#QT<CX\=&0^"B`@("`@("`@("`@(#QF;W)M(&%C=&EO;CTB
M:F%V87-C<FEP=#IV;VED*#`I(B!O;G-U8FUI=#TB<F5T=7)N(&9A;'-E.R(^
M"B`@("`@("`@("`@(#PO9F]R;3X*("`@("`@("`\+W1D/CPO='(^"B`@("`\
M+W1A8FQE/@H*06QL($IA=F%38W)I<'0@=&%G<R!M=7-T(&AA=F4@82!V86QI
M9"!T>7!E('!A<F%M971E<CHZ"@H@("`@/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/@H@("`@/"$M+0H@("`@+BXN"B`@("`O+R`M+3X*("`@(#PO
M<V-R:7!T/@H*3F]T:&EN9R!M87D@87!P96%R(&%F=&5R(&!@/"]H=&UL/F!@
M+"!T:&5R969O<F4@:6YC;'5D92!A;GD@8V]M;6]N(&9O;W1E<G,*869T97(@
M86QL(&]T:&5R(&]U='!U="X*"D%L;"!I;6%G97,@;75S="!H879E(&%N(&!@
M86QT8&`@871T<FEB=71E.CH*"B`@("`\:6UG('-R8STB97AA;7!L92YG:68B
M(&%L=#TB/#]P:'`@96-H;R!?*")%>&%M<&QE(BD@/SXB("\^"B`@("`\/W!H
M<"!E8VAO($AO<F1E.CII;6<H)V5X86UP;&4N9VEF)RP@7R@B17AA;7!L92(I
M*2`_/B`@("`@("`@("`@("`@("`@("A/;B!T:&4@2$5!1"!B<F%N8V@I"B`@
M("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V5X86UP;&4N9VEF)RP@)V%L=#TB
M)R`N(%\H(D5X86UP;&4B*2`N("<B)RD@/SX@("A/;B!T:&4@4D5,14Y'7S(@
M8G)A;F-H*0H*26YP=70@9FEE;&1S(&]F('1Y<&4@(FEM86=E(B!D;R!N;W0@
M86QL;W<@=&AE(&)O<F1E<B!A='1R:6)U=&4@86YD(&UA>2!R96YD97(*=VET
M:"!A(&)O<F1E<B!O;B!S;VUE(&)R;W=S97)S+B`@57-E('1H92!F;VQL;W=I
M;F<@:6YS=&5A9#HZ"@H@("`\82!H<F5F/2(B(&]N8VQI8VL](F1O8W5M96YT
M+F9O<FUN86UE+G-U8FUI="@I.R!R971U<FX@9F%L<V4[(CX\/W!H<"!E8VAO
M($AO<F1E.CII;6<H(F5X86UP;&4N9VEF(BP@7R@B17AA;7!L92(I*2`_/CPO
M83X*"@I$871A8F%S92!.86UI;F<@0V]N=F5N=&EO;G,*/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"@I!;&P@9&%T86)A<V4@=&%B;&5S('5S960@8GD@
M2&]R9&4@<F5S;W5R8V5S(&%N9"!(;W)D92!A<'!L:6-A=&EO;G,@;F5E9"!T
M;PIM86ME('-U<F4@=&AA="!T:&5I<B!T86)L92!A;F0@9FEE;&0@;F%M97,@
M=V]R:R!I;B!A;&P@9&%T86)A<V5S+B`@36%N>0ID871A8F%S97,@<F5S97)V
M92!W;W)D<R!L:6ME("=U:60G+"`G=7-E<B<L(&5T8RX@9F]R(&EN=&5R;F%L
M('5S92P@86YD(&9O<F)I9`IW;W)D<R!T:&%T(&%R92!344P@:V5Y=V]R9',@
M*'-E;&5C="P@=VAE<F4L(&5T8RXI+B`@06QS;RP@86QL(&YA;65S('-H;W5L
M9"!B90IL;W=E<F-A<V4L('=I=&@@=6YD97)S8V]R97,@*"=?)RD@=&\@<V5P
M87)A=&4@=V]R9',L('1O(&%V;VED(&-A<V4@<V5N<VET:79I='D*:7-S=65S
M+@H*02!G;V]D('=A>2!T;R!D;R!T:&ES(&9O<B!F:65L9"!N86UE<R!I<R!T
M;R!M86ME('1H92!F:65L9"!N86UE"G1A8FQE;F%M95]F:65L9&YA;64N"@I/
M=&AE<B!G96YE<F%L(&=U:61E;&EN97,Z(%1A8FQE(&YA;65S('-H;W5L9"!B
M92!P;'5R86P@*'5S97)S*3L@9FEE;&0@;F%M97,*<VAO=6QD(&)E('-I;F=U
M;&%R("AU<V5R7VYA;64I+@H*"E)E9W5L87(@17AP<F5S<VEO;B!5<V4*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H*06QW87ES('5S92!T:&4@8'!R96=?8%\@
M9G5N8W1I;VYS(&EF('!O<W-I8FQE(&EN<W1E860@;V8@8&5R96=?8%\@*&%N
M9`I@<')E9U]S<&QI="@I8%\@:6YS=&5A9"!O9B!@<W!L:70H*6!?*3L@=&AE
M>2!A<F4@:6YC;'5D960@:6X@4$A0(&)Y(&1E9F%U;'0*86YD(&UU8V@@;6]R
M92!E9F9I8VEE;G0@86YD(&UU8V@@9F%S=&5R('1H86X@8&5R96=?8%\N"@HJ
M*DY%5D52*BH@=7-E(&$@<F5G=6QA<B!E>'!R97-S:6]N('1O(&UA=&-H(&]R
M(')E<&QA8V4@82!S=&%T:6,@<W1R:6YG+@I@97AP;&]D92@I8%\@*&EN('!L
M86-E(&]F(&!S<&QI="@I8%\I+"!@<W1R7W)E<&QA8V4H*6!?+"!@<W1R<&]S
M*"E@7RP@;W(*8'-T<G1R*"E@7R!D;R!T:&4@:F]B(&UU8V@@;6]R92!E9F9I
M8VEE;G1L>2X*"BXN(%]P<F5G7SH@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A
M;"]E;B]R968N<&-R92YP:'`*+BX@7V5R96=?.B!H='1P.B\O=W=W+G!H<"YN
M970O;6%N=6%L+V5N+W)E9BYR96=E>"YP:'`*+BX@7W!R96=?<W!L:70H*3H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYP<F5G+7-P
M;&ET+G!H<`HN+B!?<W!L:70H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A
M;"]E;B]F=6YC=&EO;BYS<&QI="YP:'`*+BX@7V5X<&QO9&4H*3H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYE>'!L;V1E+G!H<`HN
M+B!?<W1R7W)E<&QA8V4H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E
M;B]F=6YC=&EO;BYS='(M<F5P;&%C92YP:'`*+BX@7W-T<G!O<R@I.B!H='1P
M.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+G-T<G!O<RYP:'`*
M+BX@7W-T<G1R*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N
M8W1I;VXN<W1R='(N<&AP"@H*4&%R86UE=&5R(%!A<W-I;F<*/3T]/3T]/3T]
M/3T]/3T]/3T*"D]B:F5C=',@<VAO=6QD(&)E('!A<W-E9"!B>2!R969E<F5N
M8V4N("!%=F5R>71H:6YG(&5L<V4L(&EN8VQU9&EN9R!A<G)A>7,L"G-H;W5L
M9"!B92!P87-S960@8GD@=F%L=64@=VAE<F5V97(@<V5M86YT:6-A;&QY('!O
M<W-I8FQE+@H*6UIE;F0@16YG:6YE(#(Z(&]B:F5C=',@<VAO=6QD(&%L<V\@
M8F4@<&%S<V5D(&)Y('9A;'5E70H*5&AI<R!P<F%C=&EC92!T86ME<R!F=6QL
M(&%D=F%N=&%G92!O9B!R969E<F5N8V4@8V]U;G1I;F<N"@HN+B!.;W1E.CH@
M5&AE(&!T97)N87)Y(&]P97)A=&]R8%\@875T;VUA=&EC86QL>2!R971U<FYS
M(&$@8V]P>2!O9B!I=',*("`@("`@("`@(&]P97)A;F1S+"!S;R!D;VXG="!U
M<V4@:70@=VET:"!O8FIE8W1S+"!O<B!I9B!Y;W4@87)E('-U<F4@>6]U('=A
M;G0*("`@("`@("`@('1O(')E='5R;B!A;B!O8FIE8W0@8V]P>2X*"BXN(%]@
M=&5R;F%R>2!O<&5R871O<F`Z(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO
M96XO;&%N9W5A9V4N;W!E<F%T;W)S+F-O;7!A<FES;VXN<&AP(VQA;F=U86=E
M+F]P97)A=&]R<RYC;VUP87)I<V]N+G1E<FYA<GD*"@I,;VYG($QI;F5S"CT]
M/3T]/3T]/3T*"E=R87`@;&EN97,@870@.#`@8VAA<F%C=&5R<RP@:6YC;'5D
M:6YG(&-O;6UE;G1S+"!U;FQE<W,@=&AI<R!S979E<F5L>2!I;7!A8W1S"G1H
M92!C;&%R:71Y(&]F('1H92!C;V1E+B`@06QW87ES('=R87`@8V]M;65N=',N
M"@H*3&EN92!"<F5A:W,*/3T]/3T]/3T]/3T*"D]N;'D@=7-E(%5.25@@<W1Y
M;&4@;V8@;&EN96)R96%K("A@8%QN8&`I+"!N;W0@5VEN9&]W<R]$3U,O36%C
M('-T>6QE"BA@8%QR7&Y@8"DN"@I5<VEN9R!V:6TL('1O(&-O;G9E<G0@9G)O
M;2!$3U,@<W1Y;&4@='EP93HZ"@H@("`@.G-E="!F9CUU;FEX"@I5<VEN9R!V
M:2P@=&\@8V]N=F5R="!F<F]M($1/4R!S='EL92!T>7!E.CH*"B`@("`Z9R]>
M32]S+R\O9PH**$YO=&4@=&AA="!T:&4@8&!>36!@(&ES(&$@8V]N=')O;"!C
M:&%R86-T97(L(&%N9"!T;R!R97!R;V1U8V4@:70@=VAE;B!Y;W4*='EP92!I
M;B!T:&4@=FD@8V]M;6%N9"!Y;W4@:&%V92!T;R!P860@:70@9FER<W0@=7-I
M;F<@=&AE('-P96-I86P@8&!>5F!@"F-H87)A8W1E<BXI"@H*4')I=F%T92!6
M87)I86)L97,*/3T]/3T]/3T]/3T]/3T]/3T*"E9A<FEA8FQE<R!U<V5D(&5X
M8VQU<VEV96QY('=I=&AI;B!A(&-L87-S('-H;W5L9"!B96=I;B!W:71H(&$@
M=6YD97)S8V]R92`H)U\G*0IC:&%R86-T97(N("!!;B!E>&%M<&QE(&-L87-S
M('9A<FEA8FQE(&1E9FEN:71I;VXZ("!@8'9A<B`D7W9A<FEA8FQE;F%M93M@
M8`H*"D%R<F%Y($1E9FEN:71I;VYS"CT]/3T]/3T]/3T]/3T]/3T]"@I7:&5N
M(&1E9FEN:6YG(&%R<F%Y<RP@;W(@;F5S=&5D(&%R<F%Y<RP@=7-E('1H92!F
M;VQL;W=I;F<@9F]R;6%T+"!W:&5R90II;F1E;G1A=&EO;B!I<R!N;W1E9"!V
M:6$@=&AE(&-L;W-I;F<@<&%R96YT:&5S:7,@8VAA<F%C=&5R<SHZ"@H@("`@
M)&%R<F%Y;F%M95LG:6YD97@G72`](&%R<F%Y*`H@("`@("`@("=N86UE,2<@
M/3X@)W9A;'5E,2<L"B`@("`@("`@)VYA;64R)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W-U8FYA;64Q)R`]/B`G<W5B=F%L=64Q)RP*("`@("`@("`@("`@
M)W-U8FYA;64R)R`]/B`G<W5B=F%L=64R)PH@("`@("`@("D*("`@("D["@I4
M:&4@;VYL>2!E>&-E<'1I;VX@<VAO=6QD(&)E(&9O<B!E;7!T>2!O<B!S:&]R
M="!A<G)A>7,@=&AA="!F:70@;VX@;VYE(&QI;F4L"G=H:6-H(&UA>2!B92!W
M<FET=&5N(&%S.CH*"B`@("`D87)R87EN86UE6R=I;F1E>"==(#T@87)R87DH
M*3L*"@I);G1E<FYA=&EO;F%L:7IA=&EO;B`H23$X;BD*/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"@I-87)K(&%L;"!S=')I;F=S('!R97-E;G1E9"!T
M;R!T:&4@=7-E<B!A<R!G971T97AT('-T<FEN9W,@8GD@8V%L;&EN9R!T:&4*
M9V5T=&5X="!S:&]R=&-U="!F=6YC=&EO;B`H8&!?*"E@8"DZ.@H*("`@(&5C
M:&\@7R@B2&5L;&\@=V]R;&0B*3L*"D1O;B=T('5S92!T:&4@9V5T=&5X="!F
M=6YC=&EO;G,@9F]R('-T<FEN9W,@=&AA="!W:6QL(&)E('=R:71T96X@=&\@
M82!L;V<@9FEL90IO<B!O=&AE<G=I<V4@<')E<V5N=&5D('1O('1H92!A9&UI
M;FES=')A=&]R+@H*5&AE(%-T<FEN9SHZ(&-L87-S(&-O;G1A:6YS('-E=F5R
M86P@<W1R:6YG(&UA;FEP=6QA=&EO;B!M971H;V1S('1H870@87)E+"!A<PIO
M<'!O<V5D('1O('1H96ER(%!(4"!E<75I=F%L96YT<RP@;&]C86QE(&%N9"!C
M:&%R<V5T('-A9F4N"@I5<V4@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@I(&EF
M('EO=2!N965D('1O(&-O;G9E<G0@8F5T=V5E;B!D:69F97)E;G0*8VAA<F%C
M=&5R('-E="!E;F-O9&EN9W,@*&9O<B!E>&%M<&QE+"!B971W965N('5S97(@
M:6YP=70@86YD(&$@<W1O<F%G92!B86-K96YD"F]R(&1A=&$@9G)O;2!A;B!E
M>'1E<FYA;"!S;W5R8V4@86YD('1H92!U<V5R(&EN=&5R9F%C92DN("!9;W4@
M9&]N)W0@;F5E9"!T;PIC87)E(&EF('1H92!C:&%R86-T97(@<V5T<R!A<F4@
M<F5A;&QY(&1I9F9E<F5N="X*"E5S92!T:&4@4W1R:6YG.CIL;W=E<B@I(&%N
M9"!3=')I;F<Z.G5P<&5R*"D@;65T:&]D<R!W:71H;W5T(&$@<V5C;VYD"G!A
M<F%M971E<B!I9B!Y;W4@;F5E9"!T;R!P97)F;W)M(&$@;&]C86QE+6EN9&5P
M96YD96YT('-T<FEN9R!C;VYV97)S:6]N+@I4:&%T)W,@=&AE(&-A<V4@9F]R
M(&%L;"!S=')I;F=S('1H870@87)E(&9U<G1H97(@<')O8V5S<V5D(&]R(&EN
M=&5R<')E=&5D(&)Y"F-O9&4N("!5<V4@=&AE<V4@;65T:&]D<R!W:71H('1H
M92!S96-O;F0@<&%R86UE=&5R('-E="!T;R!T<G5E(&9O<B!S=')I;F=S"G1H
M870@;F5E9"!T;R!B92!C;VYV97)T960@8V]R<F5C=&QY(&%C8V]R9&EN9R!T
M;R!T:&4@8W5R<F5N="`H;W(@<W!E8VEF:65D*0IC:&%R86-T97(@<V5T+@H*
M57-E('1H92!O=&AE<B!3=')I;F<Z.B!E<75I=F%L96YT<R!O9B!02%`@<W1R
M:6YG(&9U;F-T:6]N<R!T;R!M86YI<'5L871E"G-T<FEN9W,@8V]R<F5C=&QY
M(&%C8V]R9&EN9R!T;R!T:&4@8W5R<F5N="`H;W(@<W!E8VEF:65D*2!C:&%R
M86-T97(@<V5T(&)U=`IU<V4@=&AE(%!(4"!F=6YC=&EO;G,@9F]R(&-O9&4O
M;6%C:&EN92!P<F]C97-S960@<W1R:6YG<RX*"@I%<G)O<B!C:&5C:VEN9PH]
M/3T]/3T]/3T]/3T]/0H*2&]R9&4@8V]D92!S:&]U;&0@=7-E(&!014%27T5R
M<F]R8%\@;V)J96-T<R!T;R!R971U<FX@;6]S="!E<G)O<B!C;VYD:71I;VYS
M"F9R;VT@;&EB<F%R>2!C86QL<RP@86YD(&UA;GD@=&EM97,@=V4@=VEL;"!S
M:6UP;'D@<&%S<R!B86-K(&$@8%!%05)?17)R;W)@7PIO8FIE8W0@9V5N97)A
M=&5D(&)Y(&%N('5N9&5R;'EI;F<@;&EB<F%R>2`H<W5C:"!A<R!-86EL(&]R
M(%!%05(@1$(I+@H*1F]R('1H97-E(&-A<V5S+"!U<V4@=&AE(&9O;&QO=VEN
M9R!S='EL92!O9B!C;V1E(&)L;V-K('1O(&-H96-K(&9O<B!S=6-C97-S"F%F
M=&5R(&%N>2!C86QL('=H:6-H(&-O=6QD(&=E;F5R871E(&%N(&5R<F]R(&-O
M;F1I=&EO;CHZ"@H@("`@)')E<W5L="`]("1S;VUE=&AI;F<M/F-A;&PH)VUA
M>2!E<G)O<B<I.PH@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("\O($AA;F1L92!E<G)O<B!C;VYD:71I;VXN"B`@("!]
M(&5L<V4@>PH@("`@("`@("\O(%-U8V-E961E9"X*("`@('T*"DYO=&4@=&AA
M="!@:7-?82@I8%\@8VAE8VMS(&9O<B!S=6)C;&%S<V5S(&]F('1H92!N86UE
M9"!C;&%S<RP@87,@=V5L;"P@<V\@:68*=&AE(&]B:F5C="!Y;W4@9V5T(&)A
M8VL@:7,@<F5A;&QY(&$@8$1"7T5R<F]R8%\@;V)J96-T+"!T:&ES('=I;&P@
M<W1I;&P@8V%T8V@*:70@*'-I;F-E(&!$0E]%<G)O<F!?(&5X=&5N9',@8%!%
M05)?17)R;W)@7RDN"@I#86QL:6YG(%!%05(Z.FES17)R;W(H*2!R97-U;'1S
M(&EN('1H92!S86UE(&)E:&%V:6]R+"!B=70@:7-?82@I"F%C8V]M<&QI<VAE
M<R!T:&4@<V%M92!R97-U;'0@=VET:"!A('-I;F=L92!N871I=F4@4$A0(&9U
M;F-T:6]N(&-A;&PN"@HN+B!?4$5!4E]%<G)O<CH@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO8V]R92YP96%R+G!E87(M97)R;W(N<&AP"BXN(%]$
M0E]%<G)O<CH@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYD8BUE<G)O<BYP:'`*+BX@7VES7V$H*3H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYI<RUA+G!H<`H*"D5X
M:7-T96YC92!C:&5C:VEN9PH]/3T]/3T]/3T]/3T]/3T]/3T*"D]F=&5N('EO
M=2=L;"!N965D('1O(&-H96-K('=H971H97(@;W(@;F]T(&$@=F%R:6%B;&4@
M;W(@<')O<&5R='D@97AI<W1S+@I4:&5R92!A<F4@<V5V97)A;"!C87-E<R!H
M97)E.@H*82X@268@>6]U(&YE960@=&\@:VYO=R!I9B!A('9A<FEA8FQE(&5X
M:7-T<R!A="!A;&P@86YD(&ES(&YO="!@8&YU;&Q@8"P@=7-E"F!I<W-E="@I
M8%\Z.@H*("`@("\O($-H96-K('1O('-E92!I9B`D<&%R86T@:7,@9&5F:6YE
M9"X*("`@(&EF("AI<W-E="@D<&%R86TI*2!["B`@("`@("`@+R\@)'!A<F%M
M(&UA>2!B92!F86QS92P@8G5T(&ET)W,@=&AE<F4N"B`@("!]"@IB+B!)9B!Y
M;W4@;F5E9"!T;R!K;F]W(&EF(&$@=F%R:6%B;&4@97AI<W1S($%.1"!H87,@
M82!N;VXM96UP='D@=F%L=64@*&YO=`I@8&YU;&Q@8"P@,"P@8&!F86QS96!@
M+"!E;7!T>2!S=')I;F<@;W(@=6YD969I;F5D*2P@=7-E("%@96UP='DH*6!?
M.CH*"B`@("`O+R!-86ME('-U<F4@=&AA="`D86YS=V5R(&5X:7-T<RP@:7,@
M;F]T(&%N(&5M<'1Y('-T<FEN9RP@86YD(&ES"B`@("`O+R!N;W0@,#H*("`@
M(&EF("@A96UP='DH)&%N<W=E<BDI('L*("`@("`@("`O+R`D86YS=V5R(&AA
M<R!S;VUE(&YO;BUF86QS92!C;VYT96YT+@H@("`@?2!E;'-E('L*("`@("`@
M("`O+R`H8F]O;"DD86YS=V5R('=O=6QD(&)E(&9A;'-E+@H@("`@?0H*07,@
M<&]I;G1E9"!O=70@:6X@=&AE(&-O;6UE;G0@;V8@=&AE(&5L<V4@8VQA=7-E
M+"!@96UP='DH*6!?(&5S<V5N=&EA;&QY(&1O97,*=&AE('-A;64@8VAE8VL@
M87,@8&ES<V5T*"E@7R`M+2!I<R!T:&ES('9A<FEA8FQE(&1E9FEN960@:6X@
M=&AE(&-U<G)E;G0@<V-O<&4_"BTM(&%N9"!T:&5N+"!I9B!I="!I<RP@<F5T
M=7)N<R!W:&%T('1H92!V87)I86)L92!W;W5L9"!E=F%L=6%T92!T;R!A<R!A
M"F)O;VQE86XN(%1H:7,@;65A;G,@=&AA="`P+"!W:&EL92!P;W1E;G1I86QL
M>2!V86QI9"!I;G!U="P@:7,@(F5M<'1Y(B`M('-O(&EF"C`@:7,@=F%L:60@
M9&%T82!F;W(@>6]U<B!C87-E+"!D;VXG="!U<V4@(6!E;7!T>2@I8%\N"@IC
M+B!)9B!Y;W4@:VYO=R!Y;W4@87)E('=O<FMI;F<@=VET:"!A(&UI>&5D('9A
M<FEA8FQE('1H96X@=7-I;F<@:G5S=`I@:7-S970H*6!?(&%N9"!@96UP='DH
M*6!?(&-O=6QD(&-A=7-E('5N97AP96-T960@<F5S=6QT<RP@9F]R(&5X86UP
M;&4@:68*=&5S=&EN9R!F;W(@82!K97D@86YD('1H92!V87)I86)L92!I<R!A
M8W1U86QL>2!A('-T<FEN9SHZ"@H@("`@)&9O;R`]("=B87(G.PH@("`@:68@
M*&ES<V5T*"1F;V];)W-O;65K97DG72DI('L*("`@("`@("`O+R!4:&ES('=I
M;&P@979A;'5A=&4@=&\@5%)512$*("`@('T*"DEF('EO=2!K;F]W('1H870@
M=&AE<F4@:7,@82!P;W-S:6)I;&ET>2!O9B!A(&UI>&5D('1Y<&4@=F%R:6%B
M;&4@=&AE('-O;'5T:6]N"FEN('1H:7,@8V%S92!W;W5L9"!B92!T;R!A9&0@
M86X@8&ES7V%R<F%Y*"E@7R!C:&5C:R!I;B!T:&4@8&!I9B@I8&`@<W1A=&5M
M96YT+@H*9"X@57-E(&!A<G)A>5]K97E?97AI<W1S*"E@7R!W:&5N('EO=2!W
M86YT('1O(&-H96-K(&EF(&%N(&%R<F%Y(&ME>2!I<R!D969I;F5D"F5V96X@
M:68@:70@:&%S(&$@=F%L=64@;V8@8&!N=6QL8&`Z.@H*("`@("\O($UA:V4@
M<W5R92!W92!H879E(&$@8VAA<G-E="!P87)A;65T97(N(%9A;'5E(&-O=6QD
M(&%L<V\@8F4@;G5L;"X*("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@G8VAA
M<G-E="<L("1P87)A;7,I*2!["B`@("`@("`@2&]R9&4Z.F9A=&%L*"=);F-O
M;7!L971E(&-O;F9I9W5R871I;VXN)RD["B`@("!]"@I0;&5A<V4@;F]T92!T
M:&%T(&!A<G)A>5]K97E?97AI<W1S*"E@7R!I<R!A('!E<F9O<FUA;F-E(&AI
M="`H,C4E+3$P,"4I(&%N9`IS:&]U;&0@;VYL>2!B92!U<V5D('=H96X@;F5C
M97-S87)Y+B!);G-T96%D('1R>2!T;R!U<V4@(6!E;7!T>2@I8%\@;W(*8&ES
M<V5T*"E@7R!I;G-T96%D+@H*+BX@7VES<V5T*"DZ(&AT='`Z+R]W=W<N<&AP
M+FYE="]M86YU86PO96XO9G5N8W1I;VXN:7-S970N<&AP"BXN(%]E;7!T>2@I
M.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+F5M<'1Y
M+G!H<`HN+B!?:7-?87)R87DH*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A
M;"]E;B]F=6YC=&EO;BYI<RUA<G)A>2YP:'`*+BX@7V%R<F%Y7VME>5]E>&ES
M=',H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYA
M<G)A>2UK97DM97AI<W1S+G!H<`H*"E%U;W1E<PH]/3T]/3T*"EEO=2!S:&]U
M;&0@86QW87ES('5S92!S:6YG;&4@<75O=&4@*"<I(&-H87)A8W1E<G,@87)O
M=6YD('-T<FEN9W,L(&5X8V5P="!W:&5R90ID;W5B;&4@<75O=&4@*"(I(&-H
M87)A8W1E<G,@87)E(')E<75I<F5D+B`@06QL(&QI=&5R86P@<W1R:6YG<R!S
M:&]U;&0@8F4@:6X*<VEN9VQE('%U;W1E<RX@($$@8V]M<&%R:7-O;B!O9B!S
M:6YG;&4@86YD(&1O=6)L92!Q=6]T92!U<V%G92!F;VQL;W=S.@H*4VEN9VQE
M(%%U;W1E<SH*("`J(%9A<FEA8FQE<R!I;B!T:&4@<W1R:6YG(&%R92!N;W0@
M<&%R<V5D(&]R(&5X<&%N9&5D+@H@("H@3F5W(&QI;F4@<WEM8F]L<R!C86X@
M8F4@:6YC;'5D960@87,@;&ET97)A;"!L:6YE(&5N9',@*&YO="!R96-O;6UE
M;F1E9"DN"B`@*B!4;R!I;F-L=61E(&$@<VEN9VQE('%U;W1E(&-H87)A8W1E
M<BP@97-C87!E(&ET('=I=&@@82!@8%Q@8"`H8F%C:W-L87-H*0H@("`@8VAA
M<F%C=&5R+"!A<R!I;CH@8&!E8VAO("=(97)E7"=S(&%N(&5X86UP;&4G.V!@
M"B`@*B!4;R!S<&5C:69Y(&$@8&!<8&`@*&)A8VMS;&%S:"D@8VAA<F%C=&5R
M+"!D;W5B;&4@:70Z(&!@96-H;R`G8SI<7'1E;7`G.V!@"@I$;W5B;&4@475O
M=&5S.@H@("H@4&%R<V5S(&%N9"!E>'!A;F1S('9A<FEA8FQE<R!I;B!T:&4@
M<W1R:6YG+@H@("H@57-E<R!A9'9A;F-E9"`H8'-P<FEN=&9@7RUS='EL92D@
M97-C87!E('-E<75E;F-E<R!L:6ME(&!@7&Y@8"P@8&!<)&!@+`H@("`@8&!<
M=&!@+"!E=&,N"B`@*B!3:&]U;&0@8F4@=7-E9"!I;B!T:&4@9V5T=&5X="!S
M:&]R=&-U="!@8%\H(B(I8&`@9F]R;6%T+@H@("H@57-E('=I=&@@8V%R92P@
M87,@;6%N>2!C;W)R96-T(&QO;VMI;F<@<W1R:6YG<R!A<F4@<F5A;&QY(&EN
M=F%L:60N"@I4:&4@9F]L;&]W:6YG(&%R92!A;&P@:6YC;W)R96-T.CH*"B`@
M("!E8VAO(")4;V1A>2!I<R!T:&4@)&1A=&5;)V1A>2==(&]F("1D871E6R=M
M;VYT:"==(@H@("`@)%]315-324].6VEN9&5X72`]("1?4T534TE/3ELB;VQD
M7VEN9&5X(ET["@HN+B!?<W!R:6YT9CH@:'1T<#HO+W=W=RYP:'`N;F5T+W-P
M<FEN=&8*"@ID969I;F4H*0H]/3T]/3T]/0H*4W5R<')I<VEN9VQY(&5N;W5G
M:"P@8&1E9FEN92@I8%\@:7,@82!S;VUE=VAA="!S;&]W(&9U;F-T:6]N(&EN
M(%!(4"`H87,@;V8@4$A0"C0N,RYX*2!S;R!E>&-E<W-I=F4@=7-E(&ES(&1I
M<V-O=7)A9V5D+@H*57-I;F<@8&1E9FEN92@I8%\@:6X@8VQA<W-E<R!S:&]U
M;&0@8F4@3TL@+2!W92!W:6QL('-A8W)I9FEC92!A('1I;GD@8FET(&]F"G-P
M965D(&9O<B!R96%D86)I;&ET>2!O9B!C;V1E+B`@8&1E9FEN92@I8%\@<VAO
M=6QD($Y/5"!B92!U<V5D(&9O<B!A8W1I;VY)1',@+0IU<V4@82!P;&%I;B!O
M;&0@<W1R:6YG(&EN<W1E860N("!&;W(@86YY=&AI;F<@96QS92P@=7-E('EO
M=7(@8F5S="!J=61G;65N="X*"D%D9&ET:6]N86QL>2P@979E<GD@8V]N<W1A
M;G0@<VAO=6QD(&)E('!R969I>&5D('=I=&@@8&!(3U)$15]@8"P@:71S('!A
M8VMA9V4*;F%M92P@;W(@=&AE(&%P<&QI8V%T:6]N(&YA;64N"@HN+B!?9&5F
M:6YE*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN
M9&5F:6YE+G!H<`H*"E-E8W5R:71Y($-O;G-I9&5R871I;VYS"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"@I4:&4@9F]L;&]W:6YG(&%R92!A(&YO;BUE>&AA
M=7-T:79E(&QI<W0@;V8@9F5A='5R97,O9G5N8W1I;VYS('1O('1A:V4*<W!E
M8VEA;"!C87)E('=I=&@Z"@I02%`@0V]D92!%>&5C=71I;VXZ"BTM+2TM+2TM
M+2TM+2TM+2TM+2T*"G)E<75I<F4L(&EN8VQU9&4L(')E<75I<F5?;VYC92P@
M:6YC;'5D95]O;F-E("T@0V%R969U;&QY(&%U9&ET(&%N>0IV87)I86)L97,@
M=7-E9"!I;B!T:&5S92!F=6YC=&EO;G,L(&%N9"!C:&5C:R!T:&4@<V]U<F-E
M(&]F(&%N>0IC;VYS=&%N=',@87,@=V5L;"X*"F5V86P@+2!/8G9I;W5S(&1A
M;F=E<B!I9B!U<V5R(&EN<'5T(&ES('-U<'!L:65D('1O(&ET(&EN('5N8V]N
M=')O;&QE9"!C;VYD:71I;VYS+@H*<')E9U]R97!L86-E("T@5&AE("]E(&UO
M9&EF:65R(&-A=7-E<R!T:&4@<F5P;&%C96UE;G0@<W1R:6YG('1O(&)E"F5V
M86QU871E9"!A<R!02%`@8V]D92X*"D-O;6UA;F0@17AE8W5T:6]N.@HM+2TM
M+2TM+2TM+2TM+2TM+2T*"F5X96,@+2!%>&5C=71E<R!A('-P96-I9FEE9"!C
M;VUM86YD(&%N9"!R971U<FYS('1H92!L87-T(&QI;F4@;V8@;W5T<'5T+@H*
M<&%S<W1H<G4@+2!%>&5C=71E<R!A('-P96-I9FEE9"!C;VUM86YD(&%N9"!W
M<FET97,@=&AE(&]U='!U="!T;R!35$1/550N"@I@8"`H8F%C:W1I8VMS*2`M
M($5X96-U=&5S('1H92!S<&5C:69I960@8V]M;6%N9"!A;F0@<F5T=7)N<R!A
M;&P@=&AE"F]U='!U="!I;B!A;B!A<G)A>2X*"G-Y<W1E;2`M($QI:V4@<&%S
M<W1H<G4H*2!B=70@9&]E<VXG="!H86YD;&4@8FEN87)Y(&1A=&$N"@IP;W!E
M;B`M($5X96-U=&5S(&$@<W!E8VEF:65D(&-O;6UA;F0@86YD(&-O;FYE8W1S
M(&ET<R!O=71P=70@;W(@:6YP=70*<W1R96%M('1O(&$@4$A0(&9I;&4@9&5S
M8W)I<'1O<BX*"D9I;&4@1&ES8VQO<W5R93H*+2TM+2TM+2TM+2TM+2TM+0H*
M1FEL92!F=6YC=&EO;G,@=VAI8V@@8V%N(&)E('!O=&5N=&EA;&QY('5S960@
M=&\@;W!E;B!R96UO=&4@;W(*=6YI;G1E;F1E9"!F:6QE<SH@9F]P96XL(')E
M861F:6QE+"!F:6QE+"!F:6QE7V=E=%]C;VYT96YT<RX*"@I/<'1I;6EZ871I
M;VYS"CT]/3T]/3T]/3T]/3T*"E1H92!F;VQL;W=I;F<@;W!T:6UI>F%T:6]N
M<R!S:&]U;&0@8F4@=7-E9"P@:68@<&]S<VEB;&4Z"@IE>'1E;G-I;VY?;&]A
M9&5D*"D*+2TM+2TM+2TM+2TM+2TM+2TM"E1H:7,@87!P96%R<R!T;R!B92!A
M;B!E>'!E;G-I=F4@4$A0(&-A;&PN("!5<V4@571I;#HZ97AT96YS:6]N17AI
M<W1S*"D*:6YS=&5A9"P@=VAI8V@@=VEL;"!C86-H92!T:&4@<F5S=6QT<R!O
M9B!T:&4@8V%L;"X*"D-O;F-A=&5N871E('-T<FEN9W,*+2TM+2TM+2TM+2TM
M+2TM+2TM+0I"=6EL9&EN9R!A('-T<FEN9R!W:71H(&-O;F-A=&5N871I;VX@
M*'1H92`B+B(@;W!E<F%T;W(I('5S:6YG"G-I;F=L92UQ=6]T960@<W1R:6YG
M<R!A;F0@=F%R:6%B;&5S(&ES(&9A<W1E<B!T:&%N('5S:6YG(&%N"FEN=&5R
M<&]L871E9"!S=')I;F<@*&$@<W1R:6YG(&EN<VED92!D;W5B;&4@<75O=&5S
M('=I=&@@=F%R:6%B;&5S"FEN<VED92!T:&4@<W1R:6YG(&ET<V5L9BDN("!)
M;B!A9&1I=&EO;BP@8V]N8V%T96YA=&EO;B!I<R!E87-I97(@=&\*<F5A9"!A
M;F0@875D:70@9F]R(&QO9VEC(&%N9"!S96-U<FET>2!P<F]B;&5M<RX*"E!R
M92UI;F-R96UE;G0O9&5C<F5M96YT"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"D)E8V%U<V4@;V8@=&AE('=A>2!C;VUP:6QE<G,O:6YT97)P<F5T97)S('=O
M<FLL('!O<W0M:6YC<F5M96YT:6YG"B@D=F%R*RLI(')E<75I<F5S('-T;W)I
M;F<@8F]T:"!T:&4@;W)I9VEN86P@86YD(&YE=R!V86QU97,@;V8@=&AE"G9A
M<FEA8FQE(&EN(&UE;6]R>2!B96-A=7-E('1H92!O;&0@=F%L=64@;6%Y(&)E
M('5S960@869T97(@=&AE"F]P97)A=&EO;B!I;B!Q=65S=&EO;B!I<R!C;VUP
M;&5T92X@($)Y(&-O;7!A<FES;VXL('!R92UI;F-R96UE;G1I;F<**"LK)'9A
M<BD@86QM;W-T(&YE=F5R(&YE961S('1O('-T;W)E(&)O=&@@=F%L=65S+B`@
M270G<R!A(&UA<F=I;F%L"G-P965D=7`@8G5T(&ET)W,@86QS;R!S:6UP;'D@
M8VAA;F=I;F<@=&AE(&]R9&5R(&]F(&$@9F5W(&-H87)A8W1E<G,N"@I,;V]P
M<PHM+2TM+0I-86ME('-U<F4@=&AA="!Y;W4@9&\@;F]T(&-O;G1I;G5E('1O
M(&1E9FEN92!T:&4@<V%M92!V87)I86)L92!W:71H:6X@80IL;V]P+B`@26YS
M=&5A9"P@9&5C;&%R92!T:&4@=F%R:6%B;&4@82!S:6YG;&4@=&EM92!B969O
M<F4@=&AE(&QO;W`@:7,@<G5N+@H*07)R87D*+2TM+2T*079O:60@9G)E<75E
M;G0@87)R87D@86-C97-S97,N("!)9B!Y;W4@=7-E(&%N(&%R<F%Y(&]R(&%N
M(&%R<F%Y(&UE;6)E<B!I;B!A"FQO;W`L(&%S<VEG;B!I="!T;R!A('9A<FEA
M8FQE(&9I<G-T.CH*"B`@("`D82`](&%R<F%Y*"=X)R`]/B`G>2<I.PH@("`@
M)&5N=')I97,@/2!A<G)A>2@N+BXI.PH*("`@("1L96YG=&@@/2!C;W5N="@D
M96YT<FEE<RD["B`@("`D>"`]("1A6R=X)UT["B`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D;&5N9W1H.R`K*R1I*2!["B`@("`@("`@96-H;R`D>#L*("`@('T*
M"E5S97(@9&5F:6YE9"!F=6YC=&EO;G,*+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0I5<V5R(&1E9FEN960@9G5N8W1I;VYS(&%R92!M;W)E(&5X<&5N<VEV92!T
M:&%N(")R96=U;&%R(B!F=6YC=&EO;G,N("!5<V4@=&AE;0IO;FQY(&EF('1H
M97D@:6UP<F]V92!T:&4@8V]D92!R96%D86)I;&ET>2!M;W)E('1H96X@<F5G
M=6QA<B!F=6YC=&EO;G,N"@I$:7-K($DO3PHM+2TM+2TM+0I$:7-K(')E860@
M86YD('=R:71E(&]P97)A=&EO;G,@87)E('-L;W<N("!)9B!P;W-S:6)L92!R
M96%D(&%N9"!W<FET92!F:6QE<R!I;@IL87)G92!C:'5N:W,N("!!8V-O<F1I
M;F<@=&\@4$A0(&1O8W5M96YT871I;VXL(&9I;&5?9V5T7V-O;G1E;G1S*"D@
M:7,*<&]T96YT:6%L;'D@;75C:"!F87-T97(@=&AA;B!U<VEN9R!F;W!E;B@I
M+V9R96%D*"DO9F-L;W-E*"DN"@H*4U1$24XO4U1$3U54+U-41$524@H]/3T]
M/3T]/3T]/3T]/3T]/3T]"@I4;R!A8V-E<W,@96ET:&5R(%-41$E.+"!35$1/
M550L(&]R(%-41$524BP@=&AE(&9O;&QO=VEN9R!C;V1E('-H;W5L9"!B92!U
M<V5D.CH*"B`@("!W:&EL92`H(69E;V8H6U-41$E.?%-41$]55'Q35$1%4E)=
M*2D@>PH@("`@("`@("1L:6YE(#T@9F=E=',H6U-41$E.?%-41$]55'Q35$1%
M4E)=*3L*("`@("`@("`O+R!P<F]C97-S("1L:6YE(&AE<F4*("`@('T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+T-/3E1224)55$E.
M1P``````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S
M,30T`#$P-#$W,S8R-S0S`#`Q-S(P-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````]/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R
M9&4Z($AO=R!T;R!(96QP"CT]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S="!U
M<&1A=&4Z("`@)$1A=&4Z(#(P,#0O,#DO,C0@,C$Z,#(Z,#$@)`HZ4F5V:7-I
M;VXZ("`@("`@)%)E=FES:6]N.B`Q+C0@)`HZ0V]N=&%C=#H@("`@("`@8V]R
M94!H;W)D92YO<F<*"E1H97)E(&%R92!M86YY('=A>7,@:6X@=VAI8V@@>6]U
M(&-A;B!H96QP(&]U="!I;B!T:&4@9&5V96QO<&UE;G0@;V8@86YY(&]F('1H
M90I(;W)D92!P<F]J96-T<RX@5&AE(&9I<G-T(&%N9"!B97-T('=A>2!Y;W4@
M87)E(&%L<F5A9'D@9&]I;F<Z('EO=2=R92!U<VEN9PIT:&5M+B!/;F4@;V8@
M=&AE(&ME>7,@=&\@82!G<F5A="!P<F]D=6-T(&ES(&ET<R!U<V5R<RX@5VET
M:&]U="!U<V5R<R!W92!C86XG=`IF:6YD(&)U9W,@;W(@9V5T(&9E961B86-K
M(&]N('=H870G<R!G;V]D(&%N9"!W:&%T)W,@8F%D+@H*270@:7,@9&%R;B!N
M96%R(&EM<&]S<VEB;&4@9F]R('1H92!D979E;&]P97)S('1O('1E<W0@=&AE
M(&-O9&4@;VX@979E<GD*3W!E<F%T:6YG(%-Y<W1E;2!A;F0@979E<GD@9&EF
M9F5R96YT('9E<G-I;VX@;V8@5V5B($)R;W=S97(@879A:6QA8FQE('1O(&UA
M:V4*<W5R92!T:&4@8V]D92!R=6YS('-M;V]T:&QY(&5V97)Y=VAE<F4N("!,
M:6YU>"!I<R!N;W0@5VEN9&]W<RP@86YD($E%(&ES(&YO=`I-;WII;&QA+"!A
M;F0@:70@:7,@*&9R97%U96YT;'DI(&1I9F9I8W5L="!T;R!T;R!P<F5D:6-T
M(&)E:&%V:6]R(&)E='=E96X*<&QA=&9O<FUS+V)R;W=S97)S+@H*5VET:"!T
M:&ES('-A:60L(&]N92!O9B!T:&4@8F5S="!W87ES('EO=2!C86X@:&5L<"!I
M<R!T;R!T97-T+B!)9B!Y;W4@8V%N(&AE;'`*=7,@<VUO;W1H(&]U="!T:&4@
M8V]D92!A8W)O<W,@86QL("AO<B!E=F5N(&%N>2D@<&QA=&9O<FUS+"!Y;W4G
M<F4@9&]I;F<@80IG<F5A="!S97)V:6-E('1O('1H92!P<F]J96-T+@H*3F]W
M+"!I9B!T:&%T)W,@;F]T(&5N;W5G:"!A;F0@>6]U('=A;G0@=&\@9&EG(&EN
M(&%N9"!H96QP(&-O9&4L('EO=2!S:&]U;&0*9FER<W0@<W5B<V-R:6)E('1O
M('1H92!P<F]J96-T(&QI<W1S+"!P87)T:6-U;&%R;'D@=&AE(&=E;F5R86P@
M2&]R9&4*9&5V96QO<&5R<R!L:7-T(&1E=D!L:7-T<RYH;W)D92YO<F<@*'-E
M92!H='1P.B\O=W=W+FAO<F1E+F]R9R]M86EL+R!F;W(*:6YF;W)M871I;VX@
M;VX@<W5B<V-R:6)I;F<@=&\@=&AE(&UA:6QI;F<@;&ES=',I+B`@061D:71I
M;VYA;&QY+"!Y;W4@*BI-55-4*BH*<F5A9"!T:&4@8$AO<F1E($-O9&EN9R!3
M=&%N9&%R9'-@7R!T;R!E;G-U<F4@=&AA="!T:&4@8V]D92!Y;W5R('-U8FUI
M='1I;F<*=VEL;"!W86YT('1O(&)E(&%N86QY>F5D(&%N9"!P;W1E;G1I86QL
M>2!C;VUM:71T960@8GD@=&AE(&1E=F5L;W!E<G,N("!9;W4*<VAO=6QD('!R
M;V)A8FQY(')E860@=&AE('9A<FEO=7,@4D5!1$U%(&9I;&5S("AF;W(@=&AA
M="!M871T97(L(&%L;"!T:&4*9&]C=6UE;G1A=&EO;B!I;B!T:&4@8&!D;V-S
M+V!@(&1I<F5C=&]R>2D@9F]R('1H92!P87)T:6-U;&%R(&%P<&QI8V%T:6]N
M('EO=0IA<F4@=V]R:VEN9R!O;B!A;'-O+@H*+BX@7V!(;W)D92!#;V1I;F<@
M4W1A;F1A<F1S8#H@/V8]0T]$24Y'7U-404Y$05)$4RYH=&UL````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]#4D5$2513````````````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#0R-@`Q
M,#0Q-S,V,C<T,P`P,38S-S<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!(;W)D
M92!$979E;&]P;65N="!496%M"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`V+S`S+S(W(#`W.C,Q.C,V("0*
M.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XX-"XR+C(V("0*.D-O;G1A
M8W0Z("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*"D-O<F4@1&5V96QO
M<&5R<PH]/3T]/3T]/3T]/3T]/3T*"D-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@I*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@I-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H*"DQO8V%L:7IA=&EO
M;@H]/3T]/3T]/3T]/3T*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/2`@(#T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0I!<F%B:6,@*%-Y<FEA*2`@("`@("`@("!0;&%T:6YU;2!$979E;&]P
M;65N="!496%M(#QD979T96%M0'!L871I;G5M+7-Y+FYE=#X*0F]S;FEA;B`@
M("`@("`@("`@("`@("`@06QE;B!387)K:6YO=FEC(#QA;&5N0&QI;G5X+F]R
M9RYB83X*("`@("`@("`@("`@("`@("`@("`@("`@5F5D<F%N($QJ=6)O=FEC
M(#QV;&IU8F]V:6-`<VUA<G1N970N8F$^"D)R87II;&EA;B!0;W)T=6=U97-E
M("`@($-A<FQO<R!$86YI96P@2VEB<FET(#QK:6)R:71`=&5R<F$N8V]M+F)R
M/@H@("`@("`@("`@("`@("`@("`@("`@("!&86)I;R!';VUE<R`\9FQG;VUS
M0'5O;"YC;VTN8G(^"D)U;&=A<FEA;B`@("`@("`@("`@("`@($UI<F]S;&%V
M(%!E;F1E=B`\<&5N9&5V0&AO=&UA:6PN8V]M/@I#871A;&%N("`@("`@("`@
M("`@("`@("!!;F=E;',@1W5I;65RX"`\86YG96QS+D=U:6UE<F%`=6%B+F5S
M/@I#:&EN97-E("A3:6UP;&EF:65D*2`@("!786YG2&5N9U=E;B`\=VAW0&UY
M,38Y+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@3&EA;V)I;B`\;&EA
M;V)I;D!J:71E+FYE=#X*0VAI;F5S92`H5')A9&ET:6]N86PI("`@1&%V:60@
M0VAA;F<@/&1A=FED0'1M=BYG;W8N='<^"D-Z96-H("`@("`@("`@("`@("`@
M("`@(%!A=F5L($-H>71I;"`\<&%J84!A<W`N;V=I+F5D=3X*1&%N:7-H("`@
M("`@("`@("`@("`@("`@36%R=&EN($QI<W0M4&5T97)S96X@/&UA<G1I;D!L
M:7-T+7!E=&5R<V5N+F1K/@H@("`@("`@("`@("`@("`@("`@("`@("!"<FEA
M;B!4<G5E;'-E;B`\:&]R9&4K:3$X;D!B<FEA;G1R=65L<V5N+F1K/@I$=71C
M:"`@("`@("`@("`@("`@("`@("!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA
M=7=E<G-C;VQL96=E+FYL/@H@("`@("`@("`@("`@("`@("`@("`@("!0971E
M<B!!<FEE;B`\<&5T97(N87)I96Y`8V,N:W5L975V96XN86,N8F4^"B`@("`@
M("`@("`@("`@("`@("`@("`@($AA;B!3<')U>70@/&AA;BYS<')U>71`:6IS
M<V5L9W)O97`N;FP^"D5S=&]N:6%N("`@("`@("`@("`@("`@(%1O;VUA<R!!
M87,@/'1O;VUA<RYA87-`<F%A9"YT87)T=2YE93X*1FEN;FES:"`@("`@("`@
M("`@("`@("`@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3X*1G)E;F-H("`@
M("`@("`@("`@("`@("`@1G)E9&5R:6,@5')U9&5A=2`\9G1R=61E875`8V%M
M+F]R9SX*("`@("`@("`@("`@("`@("`@("`@("`@5&AI97)R>2!4:&]M87,@
M/'1H:65R<GE`<&]M<&\N;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!"
M96YO:70@4W0M06YD<ND@/&)E;D!B96YO:71S="UA;F1R92YN970^"B`@("`@
M("`@("`@("`@("`@("`@("`@(%!I97)R92!,86-H86YC92`\<&Q`<&EE<G)E
M;&%C:&%N8V4N;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!'<F5G;W)Y
M($-O;'!A<G0@/&=C;VQP87)T0&5V;VQI>"YN970^"D=A;&EC:6%N("`@("`@
M("`@("`@("`@(%)A9F%E;"!687)E;&$@/')A9F%E;"YV87)E;&%`=7-C+F5S
M/@H@("`@("`@("`@("`@("`@("`@("`@("!'=6EL;&5R;6\@365N9&5Z(#QG
M=6EL;&5`=7-C+F5S/@I'97)M86X@("`@("`@("`@("`@("`@("!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@I'<F5E:R`@("`@("`@("`@("`@("`@
M("!3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-U<'!O<G1`=&5I871H+F=R/@H@
M("`@("`@("`@("`@("`@("`@("`@("!3:6QL:6=A<F1O<R!8<FES=&]F;W)O
M<PH@("`@("`@("`@("`@("`@("`@("`@("!!;F%G;F]S=&]P;W5L;W,@07!O
M<W1O;&ES"B`@("`@("`@("`@("`@("`@("`@("`@($MO;G-T86YT:6YO<R!#
M+B!-:6QO<VES(#QK;6EL;W-I<T!Y86AO;RYC;VT^"DAE8G)E=R`@("`@("`@
M("`@("`@("`@($UA='0@4V5L<VMY(#QS96QS:WE`8V]L=6UB:6$N961U/@I(
M=6YG87)I86X@("`@("`@("`@("`@("!,87-Z;&\@3"X@5&]R;F]C:2`\=&]R
M;&%S>D!X96YI82YS;W1E+FAU/@I)8V5L86YD:6,@("`@("`@("`@("`@("!"
M:F]R;B!$879I9'-S;VX@/&)J;W-S:4!S;F5R<&$N:7,^"DEN9&]N97-I86X@
M("`@("`@("`@("`@(%-L86UI;B`\<VQA;6EN0'5N96HN86,N:60^"B`@("`@
M("`@("`@("`@("`@("`@("`@($IA;65S($1O92`\:F%M97-`86-T:6]N;65S
M<V%G92YC;VT^"DET86QI86X@("`@("`@("`@("`@("`@(%!A;VQA($-A<G!E
M;G1E<B`\<&-A<G!E;G1E<D!I;F9V:6,N:70^"B`@("`@("`@("`@("`@("`@
M("`@("`@($=I;W9A;FYI($UE;F5G:&5T=&D@/&=M96YE9VAE='1I0&EN9G9I
M8RYI=#X*("`@("`@("`@("`@("`@("`@("`@("`@1F5D97)I8V\@1VEA;FYI
M8VD@/&=I86YN:6-I0&YE;VUE9&EA+FET/@H@("`@("`@("`@("`@("`@("`@
M("`@("!-87)C;R!0:7)O=F%N;R`\;6%R8V\N<&ER;W9A;F]`=6YI8F]C8V]N
M:2YI=#X*("`@("`@("`@("`@("`@("`@("`@("`@0W)I<W1I86X@36%N;VYI
M(#QC<FES=&EA;BYM86YO;FE`;F5T:&5S:7,N:70^"DIA<&%N97-E("`@("`@
M("`@("`@("`@($(N2BX@0FQA8VL@/'=I;&QI86TN8FQA8VM`<W5N+F-O;3X*
M("`@("`@("`@("`@("`@("`@("`@("`@5&%K97-H:2!-;W)I<VAI;6$@/'1M
M0&]N97!O<W0N;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!(:7)O;6D@
M2VEM=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N:G`^"DMH;65R("`@("`@
M("`@("`@("`@("`@($QE86YG($-H=6US;V)E;B`\<V]B96Y`:VAM97)O<RYI
M;F9O/@I+;W)E86X@("`@("`@("`@("`@("`@("!*+DD@2VEM(#QA<&]R:65`
M;F5T:6%N+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@2FEN:'EO:R!(
M96\@/&YO=F5M8G)E0&]U<FYA='5R92YO<F<^"DQA='9I86X@("`@("`@("`@
M("`@("`@($MA<W!A<G,@2V%P96YI96MS(#QK87-P87)S0')C8RYL=CX*3&ET
M:'5A;FEA;B`@("`@("`@("`@("`@1&%R:75S($UA='5L:6%U<VMA<R`\9&%R
M:75S0&QN:RYL=#X*("`@("`@("`@("`@("`@("`@("`@("`@5FEL:75S(%-U
M;7-K87,@/'9I;&EU<T!L;FLN;'0^"DUA8V5D;VYI86X@("`@("`@("`@("`@
M(%-T;VIA;B!097-O=B`\<W-P0&5U<F5K82YC;VTN;6L^"DYO<G=E9VEA;B!"
M;VMM86%L("`@("`@($]Y<W1E:6X@4W1E:6UL97(@/&]Y<W1E:6Y`<F5X=&$N
M;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!4;W)S=&5I;B!3+B!(86YS
M96X@/&AU;&5B;V5R0'1E8VAB964N;F\^"B`@("`@("`@("`@("`@("`@("`@
M("`@($%N9')E87,@1W5N;&5I:W-K86%S(#QA;F1R96%S0&=U;FQE:6MS:V%A
M<RYN;SX*("`@("`@("`@("`@("`@("`@("`@("`@5')O;F0@0FKX<G-T860@
M/'1R8D!N9&XN;F\^"B`@("`@("`@("`@("`@("`@("`@("`@(%1H;VUA<R!#
M:'(N($1A:&P@/'1C9$!N9&XN;F\^"B`@("`@("`@("`@("`@("`@("`@("`@
M($=E:7(@3RX@2&]G8F5R9R`\:&]R9&5`<VMY9&EV97(N;F\^"DYO<G=E9VEA
M;B!.>6YO<G-K("`@("`@(%!E<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R
M9SX*4&5R<VEA;B`@("`@("`@("`@("`@("`@365T84Y%5"!!;6ER:V%B:7(@
M/'!E<G-I86XM:&]R9&5`;65T86YE='=O<FMI;F<N8V]M/@I0;VQI<V@@("`@
M("`@("`@("`@("`@("!-87)I=7-Z(%IY;F5L(#QM87)I=7-Z0&UA=&@N=7=B
M+F5D=2YP;#X*("`@("`@("`@("`@("`@("`@("`@("`@2W)Z>7-Z=&]F($MO
M>FQO=W-K:2`\:V]Z:6LQ0&\R+G!L/@I0;W)T=6=U97-E("`@("`@("`@("`@
M("!.=6YO($QO=7)E:7)O(#QN=6YO0&5T:"YP=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@36%N=65L($UE;F5Z97,@9&4@4V5Q=65I<F$@/$UA;G5E;"Y3
M97%U96ER83X*4F]M86YI86X@("`@("`@("`@("`@("`@0V]R;F5L:74@375S
M870@/&-M=7-A=$!T:6%M870N:V5Y<WES+G)O/@I2=7-S:6%N("`@("`@("`@
M("`@("`@("!)9VYA="!):W)Y86YO=B`\:6=N871`:6)D+G)U/@H@("`@("`@
M("`@("`@("`@("`@("`@("!&961O<B!!+B!&971I<V]V(#QF869`<W-C+G)U
M/@H@("`@("`@("`@("`@("`@("`@("`@("!!;&5X97D@6F%K:&%R;W8@/&%L
M97A`8FMS+F)Y/@I3;&]V86L@("`@("`@("`@("`@("`@("!,96\@37)A9FMO
M(#QL96]`;V5L+G-K/@H@("`@("`@("`@("`@("`@("`@("`@("!)=F%N($YO
M<FES(#QN;W)I<T!B9W,N<VL^"E-L;W9E;FEA;B`@("`@("`@("`@("`@($IU
M<F4@2W)A<V]V:6,@/&IU<F5K0')C8RUI<F,N<VD^"B`@("`@("`@("`@("`@
M("`@("`@("`@($UA=&EC($1O;&%R(#QM871I8T!M961I=6TN<VD^"E-P86YI
M<V@@("`@("`@("`@("`@("`@(%)A^FP@06QV87)E>B!696YE9V%S(#QR879`
M=&5C;VUA;BYU8V]L+FUX/@H@("`@("`@("`@("`@("`@("`@("`@("!-86YU
M96P@4&5R97H@07EA;&$@/&UP97)A>6%`86QC87IA8F$N=6YE>"YE<SX*4W=E
M9&ES:"`@("`@("`@("`@("`@("`@06YD<F5A<R!$86ALZ6X@/&%N9')E87-`
M9&%H;&5N+G=S/@H@("`@("`@("`@("`@("`@("`@("`@("!*;V%Q=6EM($AO
M;7)I9VAA=7-E;B`\:F]H;T!W96)B<&QA='-E;BYS93X*5'5R:VES:"`@("`@
M("`@("`@("`@("`@1V5N8V\@66EL;6%Z(#QG96YC;WEI;&UA>D!Y86AO;RYC
M;VT^"B`@("`@("`@("`@("`@("`@("`@("`@($ES=&%N8G5L(%1E8VAN:6-A
M;"!5;FEV97)S:71Y($E4($1E<&%R=&UE;G0*("`@("`@("`@("`@("`@("`@
M("`@("`@/&ET=6)I;4!I='4N961U+G1R/@H@("`@("`@("`@("`@("`@("`@
M("`@("!397)V970@1_QN97D@/'-G=6YE>4!M971U+F5D=2YT<CX*("`@("`@
M("`@("`@("`@("`@("`@("`@06AM970@UGIT_')K(#QO86AM971`;65T=2YE
M9'4N='(^"E5K<F%I;FEA;B`@("`@("`@("`@("`@($%N9')I>2!+;W!Y<W1Y
M86YS:WD@/&%N<FE`<&]L>6YE="YL=FEV+G5A/@H]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*"@I4:&5M97,*/3T]/3T]"@H]/3T]/3T]/3T]
M/3T]("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*0F%R8FEE("`@("`@("`@($%T:68@1VAA9F9A<B`\86=H869F87)`9&5V
M96QO<&5R+F-H/@I"<F]W;B`@("`@("`@("`@36%R8V\@3V)A:60@/&UA<F-O
M0&UU=RYE9'4^"D-A;6]U9FQA9V4@("`@("!!=&EF($=H869F87(@/&%G:&%F
M9F%R0&1E=F5L;W!E<BYC:#X*0VAE<G)Y("`@("`@("`@($-H<FES=&]P:&4@
M1W5I;&QO=7@@/')O;W1I>$!B;V]T:7@N;F5T/@I'<F5E;B`@("`@("`@("`@
M3F%C97(@3&%R861J:2`\;&%R861J:4!T=7AF86UI;'DN;W)G/@I'<F5Y("`@
M("`@("`@("`@3F%C97(@3&%R861J:2`\;&%R861J:4!T=7AF86UI;'DN;W)G
M/@I,879E;F1E<B`@("`@("`@6FEA=7(@4F%H;6%N(#QZ:6%`<6%L86-O;2YC
M;VT^"DQI9VAT+4)L=64@("`@("!!=&EF($=H869F87(@/&%G:&%F9F%R0&1E
M=F5L;W!E<BYC:#X*36]Z:6QL82`@("`@("`@($UI8VAA96P@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"D]R86YG92`@("`@("`@("!2;VYN
M:64@1V%R8VEA(#QR;VYN:65`;6LR+FYE=#X*4VEM<&QE>"`@("`@("`@($-A
M<FEA9"!);&W@<F$@/&-A<FEA9$!A9&YX+FYE=#X*4W5N("`@("`@("`@("`@
M($-H<FES=&]P:&4@1W5I;&QO=7@@/')O;W1I>$!B;V]T:7@N;F5T/@H]/3T]
M/3T]/3T]/3T]("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"@I#;VYT<FEB=71I;VYS"CT]/3T]/3T]/3T]/3T*"DA434P@
M=&\@5&5X="!#;VYV97)T97(Z($IO;B!!8F5R;F%T:'D@/&IO;D!C:'5G9VYU
M='0N8V]M/@H*"DEN86-T:79E($1E=F5L;W!E<G,*/3T]/3T]/3T]/3T]/3T]
M/3T]/0H*+2!)=F%N($4N($UO;W)E($E)(#QR:W)U<W1Y0'1D>6,N8V]M/@HM
M($UI:V4@2&%R9'D@/&UI:V5`:71S<')O:F5C=',N8V]M/@HM($IO;B!087)I
M<V4@/&IO;D!C<V@N<FET+F5D=3X*+2!!;FEL($UA9&AA=F%P961D>2`\86YI
M;$!R96-O:6PN;W)G/@HM(%)I8V@@3&%F9F5R='D@/')I8VA`:&]R9&4N;W)G
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O2$%#
M2TE.1P``````````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,38W,C(`,3`T,3<S-C(W-#,`,#$V,S0W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"B!(;W)D92!$979E;&]P;65N="!297-O=7)C97,*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D
M1&%T93H@,C`P-B\P,B\P,2`P.3HR,#HR.2`D"CI2979I<VEO;CH@("`@("`D
M4F5V:7-I;VXZ(#$N-RXQ,"XQ("0*.D%U=&AO<CH@("`@("`@($EV86X@12X@
M36]O<F4@24D@/')K<G5S='E`=&1Y8RYC;VT^+"!-:6ME($AA<F1Y"B`@("`@
M("`@("`@("`@("`\;6EK96A`<W!A<FLN8V]M/@HZ0V]N=&%C=#H@("`@("`@
M:&]R9&5`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S
M"BXN('-E8W1I;VXM;G5M8F5R:6YG.CH*"D]N;&EN92!R97-O=7)C97,@9F]R
M(&1E=F5L;W!I;F<@=VET:"!(;W)D92`H:6YC;'5D:6YG($AO<F1E($9R86UE
M=V]R:R!!4$D*9&]C=6UE;G1A=&EO;BD@87)E(&%V86EL86)L92!A=#H*"B`@
M(&AT='`Z+R]D978N:&]R9&4N;W)G+R`@(`H*"DAA8VMI;F<@;VX@2&]R9&4@
M9G)O;2!#5E,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*2&]R9&4@86YD
M(&ET<R!M;V1U;&5S('5S92!#5E,@9F]R('-O=7)C92!C;VYT<F]L+B`@0U93
M(&ES('=E;&PM9&]C=6UE;G1E9"P@8G5T"G1H92!M86YU86P@<&%G92!A<W-U
M;65S('EO=2!A;')E861Y(&MN;W<@:&]W(&ET('=O<FMS+B`@06X@97AC96QL
M96YT(&=U:61E('1O"F=E='1I;F<@<W1A<G1E9"!W:71H($-64R!I<R`B3W!E
M;B!3;W5R8V4@1&5V96QO<&UE;G0@=VET:"!#5E,B(&)Y($MA<FP@1F]G96PN
M"DET)W,@<'5B;&ES:&5D(&)Y($-O<FEO;&ES+"!A;F0@=&AE('1E8VAN:6-A
M;"!P87)T(&]F('1H92!B;V]K(&ES(&%V86EL86)L90IF;W(@9G)E92!O;B!T
M:&4@5V5B(&%T"@H@("!H='1P.B\O8W9S8F]O:RYR960M8F5A;BYC;VTO"@I4
M:&4@<&%P97(@=F5R<VEO;B!I;F-L=61E<R!C:&%P=&5R<R!O;B!O<F=A;FEZ
M:6YG(&%N9"!M86YA9VEN9R!/<&5N(%-O=7)C90ID979E;&]P;65N="X@(%EO
M=2!C86X@;V)T86EN(&$@0U93(&-L:65N="!F;W(@>6]U<B!O<&5R871I;F<@
M<WES=&5M(&%T"D-64TA/344L(&%T"@H@("!H='1P.B\O=W=W+F-V<VAO;64N
M;W)G+V1O=VYL;V%D<RYH=&UL"@IO9B!T:&5M(&UA>2!B92!F;W5N9"!A="!H
M='1P.B\O=W=W+F-Y8VQI8RYC;VT@+2!T:&5Y('-U<'!O<G0@0U93(&-O;6UE
M<F-I86QL>2P*979E;B!T:&]U9V@@:70@:7,@86X@;W!E;B!S;W5R8V4@<')O
M9W)A;2X*"EEO=2!W:6QL(&YE960@82!#5E,@8VQI96YT('1O(&1O(&%N>2!O
M9B!T:&4@9F]L;&]W:6YG("AC:&5C:R!O=70@=&AE($-Y8VQI8PIH;VUE<&%G
M92!I9B!Y;W4@9&]N)W0@:&%V92!O;F4I+@H*1F]R('1H;W-E(&%L<F5A9'D@
M9F%M:6QI87(@=VET:"!#5E,L('1H92!A;F]N>6UO=7,@0U934D]/5"!I<SHZ
M"@H@("`Z<'-E<G9E<CIC=G-R96%D0&%N;VYC=G,N:&]R9&4N;W)G.B]R97!O
M<VET;W)Y"@H*1&]W;FQO861I;F<@2&]R9&4@;6]D=6QE<R!F<F]M($-64PHM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I9;W4@=VEL;"!W
M86YT('1O(&1O('1H:7,@:68@>6]U('=A;G0@8FQE961I;F<@961G92!C;V1E
M+@H*,2X@1V\@=&\@=&AE(&1I<F5C=&]R>2!Y;W4@=V%N="!T;R!D;W=N;&]A
M9"!T:&4@8V]D92!T;SHZ"@H@("`@("!C9"!^+W=O<FL*"C(N(%-E="!@8$-6
M4U)/3U1@8"!T;R!T:&4@;&]C871I;VX@;V8@=&AE($-64R!R97!O<VET;W)Y
M+B`@66]U(&-O=6QD(&%L<V\@<&%S<PH@("!C=G,@=&AE(&YA;64@;V8@=&AE
M($-64R!R;V]T('=I=&@@=&AE(&!@+61@8"!O<'1I;VXN("!"92!S=7)E('1O
M(&YO=&4@=&AE"B`@(&-O;&]N(&!@.F!@(&EN(&9R;VYT(&]F(&!@<'-E<G9E
M<F!@+@H*("`@*&EN('-H+"!K<V@L(&)A<V@L('IS:"DZ.@H*("`@("`@0U93
M4D]/5#TZ<'-E<G9E<CIC=G-R96%D0&%N;VYC=G,N:&]R9&4N;W)G.B]R97!O
M<VET;W)Y"B`@("`@(&5X<&]R="!#5E-23T]4"@H@("`H:6X@8W-H+"!T8W-H
M*3HZ"@H@("`@("!S971E;G8@0U934D]/5"`Z<'-E<G9E<CIC=G-R96%D0&%N
M;VYC=G,N:&]R9&4N;W)G.B]R97!O<VET;W)Y"@HS+B!,;V=I;B!T;R!T:&4@
M86YO;GEM;W5S($-64R!R97!O<VET;W)Y+B`@5VAE;B!P<F]M<'1E9"!F;W(@
M82!P87-S=V]R9"P@96YT97(*("`@8&!H;W)D96!@.CH*("`@("`@"B`@("`@
M(&-V<R!L;V=I;@H*-"X@0VAE8VL@;W5T('1H92!M;V1U;&4@>6]U('=A;G0@
M=&\@9&]W;FQO860@9G)O;2!T:&4@<F5P;W-I=&]R>2X@(%)E<&QA8V4*("`@
M8&!-3T153$5@8"!W:71H(&AO<F1E+"!I;7`L('1U<F)A+"!T<F]L;"P@86YD
M('-O(&9O<G1H+B`@*%1H92!@8"UZ,V!@('1E;&QS"B`@(&-V<R!T;R!C;VUP
M<F5S<R!T:&4@9&%T82!I="!S96YD<R!O=F5R('1H92!N971W;W)K+"!U;F-O
M;7!R97-S:6YG(&ET('=H96X*("`@>6]U(#\_/S\Z.@H*("`@("`@8W9S("UZ
M,R!C;R!-3T153$4*"B`@($EF('EO=2!W86YT('1O(&-H96-K(&]U="!A('!A
M<G1I8W5L87(@8G)A;F-H(&]F(&$@;6]D=6QE("AF;W(@97AA;7!L92P@=&AE
M"B`@(&!@4D5,14Y'7S-@8"!B<F%N8V@@;V8@24U0*2P@:6YC;'5D92!T:&4@
M8G)A;F-H('1A9R!L:6ME('-O+"!R97!L86-I;F<*("`@8&!404=@8"!W:71H
M('1H92!N86UE(&]F('1H92!B<F%N8V@Z.@H*("`@("`@8W9S("UZ,R!C;R`M
M<B!404<@34]$54Q%"@HU+B!!<R!Y;W4@=V]R:R!W:71H('1H92!S;V9T=V%R
M92P@>6]U(&-A;B!P97)I;V1I8V%L;'D@=7!D871E('EO=7(@=')E92!T;PH@
M("!M871C:"!T:&4@;6%S=&5R('1R964@870@86YY('1I;64L(&9R;VT@=&AE
M('1O<"!D:7)E8W1O<GD@;V8@=&AE"B`@(&UO9'5L92X@(%5S:6YG(&!@:&]R
M9&5@8"!A<R!A;B!E>&%M<&QE(&UO9'5L93HZ"@H@("`@("!C9"!^+W=O<FLO
M:&]R9&4*("`@("`@8W9S("UZ,R!U<&1A=&4*"@I/8G1A:6YI;F<@82!#5E,@
M86-C;W5N=`HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*268@>6]U)W)E(&=O
M:6YG('1O(&)E(&$@<F5G=6QA<B!C;VYT<FEB=71O<B!T;R!(;W)D92P@=&AE
M;B!Y;W4@8V%N(')E<75E<W0@80I#5E,@86-C;W5N="!I;B!O<F1E<B!T;R!C
M;VUM:70@>6]U<B!C:&%N9V5S('1O('1H92!R97!O<VET;W)Y('EO=7)S96QF
M+B`@*$EF"GEO=2=R92!O;FQY(&=O:6YG('1O(&)E(&-O;G1R:6)U=&EN9R!O
M;F-E(&EN(&$@=VAI;&4L('1H97)E('1R=6QY(&ES(&YO(&YE960*9F]R('EO
M=2!T;R!H879E(&]N92P@87,@<&]S=&EN9R!Y;W5R(&-H86YG97,@=&\@=&AE
M(&%P<&QI8V%T:6]N)W,@;6%I;&EN9R!L:7-T"G=I;&P@<W5F9FEC92!T;R!G
M970@>6]U<B!C:&%N9V5S(')E=FEE=V5D(&%N9"!I;F-L=61E9"XI"@I)9B!Y
M;W4@9&\@9V5T(&-O;6UI="!A8V-E<W,@=&\@=&AE($-64R!T<F5E+"!Y;W4@
M=VEL;"!H879E('1H92!A8FEL:71Y('1O(&UE<W,*<V]M92!T:&EN9W,@=7`N
M("!.;W0@9F]R(&=O;V0L(&UI;F0@>6]U+"!A<R!#5E,@86QL;W=S('5P9&%T
M97,@=&\@8F4@8F%C:V5D"F]F9BP@8G5T('EO=2!S=&EL;"!N965D('1O(')E
M;65M8F5R('=H870@>6]U)W)E(&1O:6YG(&%N9"!B92!C87)E9G5L('=H870@
M>6]U"F-O;6UI="!A;F0@=VAE;B!Y;W4@8V]M;6ET(&ET+B`@0F5C875S92!O
M9B!T:&ES+"!W92!P<F5F97(@=&AA="!Y;W4@<W5B;6ET"GEO=7(@=V]R:R!T
M;R!T:&4@;6%I;&EN9R!L:7-T(&9O<B!A('=H:6QE('-O('=E(&-A;B!T96QL
M('EO=2!K;F]W('=H870@>6]U)W)E"F1O:6YG+@H*268@>6]U)W)E(&YO="!A
M(&-O;6UI='1E<BP@=&AE(&)E<W0@=V%Y('1O('-U8FUI="!A('!A=&-H(&ES
M('1O('-E;F0@:70@96ET:&5R"G1O('1H92!A<'!L:6-A=&EO;B=S(&UA:6QI
M;F<@;&ES="!O<B!T;R!D979`;&ES=',N:&]R9&4N;W)G+B`@1F]R(&UO<F4*
M:6YF;W)M871I;VX@;VX@2&]R9&4@;6%I;&EN9R!L:7-T<RP@<V5E"@H@("!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]M86EL+PH*"D-O;6UI='1I;F<@8VAA;F=E
M<R!T;R!#5E,*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*3VYC92!Y;W4@
M:&%V92!A($-64R!A8V-O=6YT+"!Y;W4@=VEL;"!N965D('1O(&QO9R!I;G1O
M('1H92!#5E,@<V5R=F5R('-O(&ET"FMN;W=S('=H;R!Y;W4@87)E(&%N9"!C
M86X@9W)A;G0@>6]U('1H92!A<'!R;W!R:6%T92!R:6=H=',@=&\@=V]R:R!O
M;B!T:&4*<V]U<F-E<RX*"E1H92!@8$-64U)/3U1@8"!I<R!D:69F97)E;G0@
M9F]R(&-O;6UI='1E<G,[(&EN<W1E860@;V8@=&AE(')E<&]S:71O<GD@;&ES
M=&5D"F%B;W9E+"!S970@8&!#5E-23T]48&`@=&\Z.@H*("`@.F5X=#I54T52
M3D%-14!C=G,N:&]R9&4N;W)G.B]R97!O<VET;W)Y"@IR97!L86-I;F<@8&!5
M4T523D%-16!@('=I=&@@>6]U<B!C=G,@=7-E<FYA;64N"@I4:&4@8V]M;6ET
M=&5R<R<@<F5P;W-I=&]R>2!D;V5S(&YO="!U<V4@<'-E<G9E<BX@(%EO=2!W
M:6QL(&YE960@=&\@:&%V92!S<V@*:6YS=&%L;&5D(&]N('EO=7(@<WES=&5M
M+"!A;F0@:&%V92!A<G)A;F=E9"!W:71H(&]N92!O9B!T:&4@8V]R92!D979E
M;&]P97)S('1O"G!U="!Y;W5R(%-32"!K97D@;VX@=&AE('-Y<W1E;2X@($EF
M('EO=2!H879E(&YO="!D;VYE('1H:7,L('1A;&L@=&\@;VYE(&]F('1H90IC
M;W)E(&1E=F5L;W!E<G,N"@I4;R!G970@8W9S('1O('5S92!S<V@L('EO=2!W
M:6QL(&YE960@=&\@<V5T('1H92!E;G9I<F]N;65N="!V87)I86)L90I@8$-6
M4U]24TA@8"!T;R!@8'-S:&!@(&EN('EO=7(@<VAE;&PN"@I9;W4@9&\@;F]T
M(&YE960@=&\@9&\@8&!C=G,@;&]G:6Y@8#L@>6]U('=I;&P@8F4@<')O;7!T
M960@9F]R('1H92!P87-S<&AR87-E"F9O<B!Y;W5R(%-32"!K97D@=VAE;F5V
M97(@>6]U(&%C8V5S<R!T:&4@<F5P;W-I=&]R>2X*"EEO=2!M87D@86QS;R!W
M:7-H('1O('-E="!T:&4@96YV:7)O;FUE;G0@=F%R:6%B;&4@8&!%1$E43U)@
M8"!T;R!P;VEN="!T;R!Y;W5R"F9A=F]R:71E('1E>'0@961I=&]R+B!4:&ES
M('=A>2!W:&5N('EO=2!C;VUM:70@<V]F='=A<F4@8VAA;F=E<R!A;F0@:70@
M87-K<PIY;W4@=&\@96YT97(@82!C:&%N9V4@9&5S8W)I<'1I;VXL('EO=2!C
M86X@9&\@<V\@:6X@>6]U<B!F879O<FET92!E9&ET;W(N"@I4:&5N+"!F;W(@
M=V]R:R!O;B!D979E;&]P;65N=&%L+"!B;&5E9&EN9RUE9&=E('9E<G-I;VYS
M.@H*,2D@0VAE8VL@;W5T('1H92!C;V1E(&)Y('1Y<&EN9R!@8&-V<R!C;R!-
M3T153$5@8`HR*2!7;W)K(&]N('1H92!C;V1E(#QH86-K+"!H86-K+"!H86-K
M/@HS*2!#;VUM:70@86YY(&-H86YG97,@=VET:"!@8&-V<R!C;VUM:70@1DE,
M14Y!34538&`@:6X@=&AE(&1I<F5C=&]R>2!T:&4@9FEL97,*("`@87)E(&EN
M+@H*4V]M971I;65S+"!O=&AE<G,@=VEL;"!M86ME(&-H86YG97,@86YD('EO
M=2!W:6QL(&YE960@=&\@=7!D871E('EO=7(@=')E92!S;PIT:&4@8VAA;F=E
M<R!S:&]W('5P(&EN('EO=7(@;&]C86P@<V]U<F-E<RX@(%EO=2!D;R!T:&ES
M('=I=&@@=&AE(&!@8W9S"G5P9&%T96!@(&-O;6UA;F0@:6X@=&AE(&AO<F1E
M(&1I<F5C=&]R>2X@(%!L96%S92!B92!S=7)E('1O('5P9&%T92!Y;W5R('1R
M964*<F5G=6QA<FQY.R!M97)G:6YG(&-H86YG97,@:7,@8V]N<VED97)A8FQY
M(&UO<F4@=V]R:R!T:&%N(')U;FYI;F<@8&!C=G,*=7!D871E8&`N"@I4;R!W
M;W)K('=I=&@@86YY('1A9V=E9"!B<F%N8V@@*'1O('!A=&-H(&$@<W1A8FQE
M(')E;&5A<V4L(&9O<B!I;G-T86YC92DZ"@HQ*2!#:&5C:R!O=70@=&AE(&-O
M9&4@=VET:"!@8&-V<R!C;R`M<B!404<@34]$54Q%8&`*,BD@5V]R:R!O;B!T
M:&4@8V]D92`\:&%C:RP@:&%C:RP@:&%C:SX*,RD@0V]M;6ET(&%N>2!C:&%N
M9V5S('=I=&@@8&!C=G,@8V]M;6ET($9)3$5.04U%4V!@(&EN('1H92!D:7)E
M8W1O<GD@=&AE(&9I;&5S"B`@(&%R92!I;BX*"DEF('-O;65B;V1Y(&5L<V4@
M86QS;R!M86ME<R!C:&%N9V5S('1O('1H92!L86)E;&5D('9E<G-I;VXL('EO
M=2!C86X@9V5T('1H96T*:6X@>6]U<B!L;V-A;"!S;W5R8V4@=')E92!W:71H
M('1H92!@8&-V<R!U<&1A=&5@8"!C;VUM86YD(&ES<W5E9"!I;B!T:&4@;6]D
M=6QE"F1I<F5C=&]R>2X*"DEF('EO=2!A<F4@9&]N92!W;W)K:6YG('=I=&@@
M=&AE(&QA8F5L960@<V]U<F-E(&)R86YC:"P@86YD('=O=6QD(&QI:V4@=&\@
M;6]V90IB86-K(&EN=&\@=&AE(&)L965D:6YG+65D9V4@9&5V96QO<&UE;G0@
M<V]U<F-E('1R964L('EO=2!C86X@:7-S=64@=&AE(&-O;6UA;F0*8&!C=G,@
M=7!D871E("U!8&`@=&\@=7!D871E(&5V97)Y=&AI;F<@=&\@=&AE(&-U<G)E
M;G0@8&!(14%$8&`@=F5R<VEO;BX*"BA792!U<V5D('1O(&1O8W5M96YT(&AO
M=R!T;R!M97)G92!C;V1E(&9R;VT@2$5!1"!I;G1O(&$@;&%B96QE9"!B<F%N
M8V@@:&5R92P*8G5T('-I;F-E(&ET('=A<R!H96%V:6QY('!E<'!E<F5D('=I
M=&@@(G1A;&L@=&\@8V]R92!D979E;&]P97)S(&9I<G-T(BP@:70G<PIB965N
M(&5L:61E9"!T;R!P<F5V96YT(&5R<F]R<R!O9B!E>'!E<FEM96YT871I;VXN
M("!)9B!Y;W4@=&AI;FL@>6]U(&YE960@=&\@9&\*=&AA="P@>6]U(&AA=F4@
M=&\@=&%L:R!T;R!C;W)E(&1E=F5L;W!E<G,@86YY:&]W("TM('1H97DG;&P@
M97AP;&%I;B!H;W<N*0H*"D]T:&5R($-64R!.;W1E<PHM+2TM+2TM+2TM+2TM
M+2T*"DEF('EO=2!D;R!E;F0@=7`@9V5T=&EN9R!A($-64R!A8V-O=6YT+"!H
M97)E(&%R92!S;VUE('1I<',@=&\@:&5L<"!K965P('1H:6YG<PIG;VEN9R!S
M;6]O=&AL>3H*"C$N(%-U8G-C<FEB92!T;R!T:&4@8W9S0&QI<W1S+FAO<F1E
M+F]R9R!A;F0@9&5V0&QI<W1S+FAO<F1E+F]R9R!M86EL:6YG(&QI<W1S+@H*
M,BX@0F4@<W5R92!T;R!M;V1I9GD@=&AE(&9I;&4@8&!D;V-S+T-(04Y'15-@
M8"!T;R!R969L96-T('1H92!C:&%N9V5S('1O('1H90H@("!C;V1E('EO=2!A
M<F4@8V]M;6ET=&EN9RX*"C,N($EF('EO=2=R92!P;&%N;FEN9R!O;B!D;VEN
M9R!A;GET:&EN9R!M86IO<BP@<&QE87-E(&QE="!P96]P;&4@:VYO=R!I;@H@
M("!A9'9A;F-E(&]N('1H92!D979`(&]R(&%P<&QI8V%T:6]N(&UA:6QI;F<@
M;&ES=',@87,@87!P<F]P<FEA=&4N"@H@("!$979E;&]P97)S(&YE960@=&\@
M8V]M;75N:6-A=&4@97AT96YS:79E;'D@:6X@;W)D97(@=&\@;6%K92!S=7)E
M(&5V97)Y;VYE"B`@(&MN;W=S('=H870G<R!G;VEN9R!O;BX@(%1H:7,@:7,@
M97AT<F5M96QY(&EM<&]R=&%N="!W:&5N('EO=2!W;W)K(&]N(&ME>0H@("!C
M;VUP;VYE;G1S+@H*-"X@57-E('1H92!"=6<@5')A8VMI;F<@4WES=&5M(&]N
M(&AT='`Z+R]B=6=S+FAO<F1E+F]R9RX@($%L;"!N97<@<W5B;6ES<VEO;G,*
M("`@87)E(&)E:6YG(&-C)V0@=&\@=&AE(&)U9W-`;&ES=',N:&]R9&4N;W)G
M(&UA:6QI;F<@;&ES="!S;R!T:&%T(&EF('=E(&%R96XG=`H@("!P87EI;F<@
M871T96YT:6]N+"!W92=L;"!A="!L96%S="!G970@;6%I;"!A8F]U="!I="X@
M(%5S:6YG('1H92!"=6=S"B`@(&1A=&%B87-E(&AE;'!S('5S(&ME97`@=')A
M8VL@;V8@:7-S=65S('=E(&%R92!H879I;F<@86YD('=H97)E('=E('-T86YD
M"B`@('=I=&@@=&AE('!R;V1U8W0N"@HU+B!296UE;6)E<B!T;R!A9'9A;F-E
M('1H92!L:6)R87)Y('9E<G-I;VX@=VAE;F5V97(@86YY=&AI;F<@;6%J;W(@
M:7,@8VAA;F=E9"X*````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R])
M3E-404Q,````````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`V-C,W-0`Q,#0Q-S,V,C<T,P`P,38T,C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!);G-T86QL:6YG('1H92!(;W)D92`S
M+C$@1G)A;65W;W)K"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`U+S$P+S$X(#$R.C`V
M.C$Y("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XY,"XV+C$U("0*
M.D-O;G1A8W0Z("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N
M=&5N=',Z.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I4:&ES
M(&1O8W5M96YT(&-O;G1A:6YS(&EN<W1R=6-T:6]N<R!F;W(@:6YS=&%L;&EN
M9R!T:&4@2&]R9&4@1G)A;65W;W)K(&]N('EO=7(*<WES=&5M+@H*5&AE($AO
M<F1E($9R86UE=V]R:RP@8GD@:71S96QF+"!D;V5S(&YO="!P<F]V:61E(&%N
M>2!S:6=N:69I8V%N="!E;F0@=7-E<@IF=6YC=&EO;F%L:71Y.R!I="!P<F]V
M:61E<R!A(&)A<V4@9F]R(&]T:&5R(&%P<&QI8V%T:6]N<R!A;F0@=&]O;',@
M9F]R"F1E=F5L;W!E<G,N(%=H96X@>6]U(&AA=F4@:6YS=&%L;&5D($AO<F1E
M(&%S(&1E<V-R:6)E9"!B96QO=RP@>6]U('=I;&P*<')O8F%B;'D@=V%N="!T
M;R!I;G-T86QL('-O;64@;V8@=&AE(&%V86EL86)L92!(;W)D92!A<'!L:6-A
M=&EO;G,L('-U8V@@87,*24U07R`H82!W96)M86EL(&-L:65N="DL(&]R($MR
M;VYO;&ET:%\@*&$@8V%L96YD87(I+B!4:&5R92!I<R!A(&QI<W0@;V8@2&]R
M9&4*87!P;&EC871I;VYS(&%N9"!P<F]J96-T<R!A="!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]P<F]J96-T<RYP:'`N"@I)9B!Y;W4@87)E(&EN=&5R97-T960@
M:6X@9&5V96QO<&EN9R!A<'!L:6-A=&EO;G,@9F]R($AO<F1E+"!T:&5R92!I
M<R!D979E;&]P97(*9&]C=6UE;G1A=&EO;B!A;F0@<F5F97)E;F-E<R!A=F%I
M;&%B;&4@870@:'1T<#HO+V1E=BYH;W)D92YO<F<O+"!A;F0@<V]M90IT=71O
M<FEA;',@86YD('!A<&5R<R!O;B!(;W)D92!A=F%I;&%B;&4@870@:'1T<#HO
M+W=W=RYH;W)D92YO<F<O<&%P97)S+RX*"D9O<B!I;F9O<FUA=&EO;B!O;B!T
M:&4@8V%P86)I;&ET:65S(&%N9"!F96%T=7)E<R!O9B!(;W)D92P@<V5E('1H
M92!F:6QE"F!@4D5!1$U%8&`@:6X@=&AE('1O<"UL979E;"!D:7)E8W1O<GD@
M;V8@=&AE($AO<F1E(&1I<W1R:6)U=&EO;BX*"BXN(%])35`Z(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+VEM<"\*+BX@7TMR;VYO;&ET:#H@:'1T<#HO+W=W=RYH
M;W)D92YO<F<O:W)O;F]L:71H+PH*"D]B=&%I;FEN9R!(;W)D90H]/3T]/3T]
M/3T]/3T]/3T*"E1H92!(;W)D92!&<F%M97=O<FL@8V%N(&)E(&]B=&%I;F5D
M(&9R;VT@=&AE($AO<F1E('=E8G-I=&4@86YD($944"!S97)V97(L(&%T"@H@
M("!H='1P.B\O=W=W+FAO<F1E+F]R9R]H;W)D92\*"B`@(&9T<#HO+V9T<"YH
M;W)D92YO<F<O<'5B+VAO<F1E+PH*3W(L(&)E='1E<B!Y970L('5S92!A(&UI
M<G)O<B!T:&%T(&ES(&-L;W-E<B!T;R!Y;W4N("!4:&4@;6ER<F]R(&QI<W0@
M8V%N(&)E"F9O=6YD(&%T.@H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O;6ER
M<F]R<RYP:'`*"BI&;W(@=&AE(')E<W0@;V8@=&AE(&1O8W5M96YT871I;VXL
M(&%L;"!L:6YK<R!W:6QL('!O:6YT('1O('1H92!M86EN($AO<F1E"G=E8G-I
M=&4@+2!S:6UP;'D@<F5P;&%C92!W=W<N:&]R9&4N;W)G('=I=&@@=&AE(&AO
M<W1N86UE(&]F('EO=7(@<')E9F5R<F5D"FUI<G)O<B!T;R!A8V-E<W,@=&AE
M(&9I;&5S(&%T(&$@;6ER<F]R960@;&]C871I;VXN*@H*5&AE($944"!D:7)E
M8W1O<GD@8V]N=&%I;G,@=&AE($AO<F1E(%!(4"!F:6QE<R!W:&EC:"!C86X@
M8F4@=6YP86-K960@=7-I;F<*8&!T87)@8"!A;F0@8&!G=6YZ:7!@8"`H<V5E
M(&!);G-T86QL:6YG($AO<F1E8%\L(&)E;&]W*2X@($EF('EO=2!A<F4@=7-I
M;F<@4F5D"DAA="!,:6YU>"!A;F0@<')E9F5R('1O('5S92!24$US+"!T:&5Y
M(&-A;B!B92!F;W5N9"!H97)E.@H*("`@9G1P.B\O9G1P+FAO<F1E+F]R9R]P
M=6(O4E!-4R\*"D)L965D:6YG+65D9V4@9&5V96QO<&UE;G0@=F5R<VEO;G,@
M;V8@2&]R9&4@86YD(&ET<R!A<'!L:6-A=&EO;G,@87)E(&%V86EL86)L90IV
M:6$@0U93.R!S964@=&AE(&9I;&4@8&1O8W,O2$%#2TE.1V!?+"!O<B!V:7-I
M="!T:&4@=V5B<VET90IH='1P.B\O=W=W+FAO<F1E+F]R9R]S;W5R8V4O+"!F
M;W(@:6YF;W)M871I;VX@;VX@86-C97-S:6YG('1H92!(;W)D92!#5E,*<F5P
M;W-I=&]R>2X*"EEO=2!W:6QL('!R;V)A8FQY(&%L<V\@=V%N="!O;F4@;W(@
M;6]R92!(;W)D92!A<'!L:6-A=&EO;G,L('-I;F-E($AO<F1E"F1O97-N)W0@
M9&\@;75C:"!B>2!I='-E;&8[(&$@;&ES="!O9B!A=F%I;&%B;&4@87!P;&EC
M871I;VYS+"!W:71H(&QI;FMS('1O"F1E<V-R:7!T:6]N<R!A;F0@9&]W;FQO
M861S+"!C86X@8F4@9F]U;F0@870*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G
M+W!R;VIE8W1S+G!H<`H*5VAI;&4@<')E=FEO=7,@=F5R<VEO;G,@;V8@2&]R
M9&4@=V5R92!N=6UB97)E9"!T;R!C;W)R97-P;VYD('=I=&@@82!P87)T:6-U
M;&%R"G9E<G-I;VX@;V8@=&AE($E-4"!W96)M86EL(&%P<&QI8V%T:6]N+"!T
M:&%T(&ES(&YO(&QO;F=E<B!T<G5E(&%S(&]F($AO<F1E"G9E<G-I;VX@,BXP
M+B!4:&4@8W5R<F5N="!V97)S:6]N(&]F($AO<F1E('=I;&P@=V]R:R!W:71H
M('1H92!C=7)R96YT('9E<G-I;VX*;V8@2&]R9&4@87!P;&EC871I;VYS+B!&
M;W(@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!W:&EC:"!V97)S:6]N<R!A<F4*
M8V]M<&%T:6)L92!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O<V]U<F-E+W9E
M<G-I;VYS+G!H<"X*"@I1=6EC:R!);G-T86QL"CT]/3T]/3T]/3T]/3T*"E1H
M97-E(&%R92!V97)Y('1E<G-E(&EN<W1R=6-T:6]N<R!H;W<@=&\@:6YS=&%L
M;"!(;W)D92!A;F0@:71S('!R97)E<75I<VET97,*;VX@82!,04U0('-Y=&5M
M+B`@5&AE>2!A<F4@861D<F5S<V5D('1O(&5X<&5R:65N8V5D(&%D;6EN:7-T
M<F%T;W)S('=H;R!K;F]W"F5X86-T;'D@=VAA="!T:&5Y(&%R92!D;VEN9RX@
M($9O<B!M;W)E(&1E=&%I;&5D(&EN<W1R=6-T:6]N<RP@<W1A<G0@<F5A9&EN
M9PIB96QO=R!A="!0<F5R97%U:7-I=&5S7RX*"C$N($-O;7!I;&EN9R!02%`@
M9F]R($%P86-H93HZ"@H@("`@(&-D('!H<"UX+G@N>"\*("`@("`N+V-O;F9I
M9W5R92`M+7=I=&@M87!X<STO=7-R+W-B:6XO87!X<R!<"B`@("`@("`@("`@
M("`@("`@+2UW:71H+6=E='1E>'0@+2UW:71H+61O;2`M+7=I=&@M;6-R>7!T
M(%P*("`@("`@("`@("`@("`@("`M+7=I=&@M:6-O;G8@+2UE;F%B;&4M;6)S
M=')I;F<]86QL("TM96YA8FQE+6UB<F5G97@@7`H@("`@("`@("`@("`@("`@
M("TM=VET:"UG9"`M+7=I=&@M<&YG+61I<CTO=7-R("TM=VET:"UJ<&5G+61I
M<CTO=7-R(%P*("`@("`@("`@("`@("`@("`M+7=I=&@M;6EM92UM86=I8STO
M=7-E<B]S:&%R92]M:7-C+VUA9VEC+FUI;64@7`H@("`@("`@("`@("`@("`@
M(%LM+7=I=&@M;7ES<6Q\+2UW:71H+7!G<W%L?"TM=VET:"UO8VDX?"TM=VET
M:"UL9&%P70H@("`@(&UA:V4*("`@("!M86ME(&EN<W1A;&P*"C(N(%)E<W1A
M<G0@07!A8VAE+@H*,RX@26YS=&%L;"!014%2('!A8VMA9V5S.CH*"B`@("`@
M<&5A<B!I;G-T86QL("UO($QO9R!-86EL($UA:6Q?36EM92!$0B!$871E($9I
M;&4*("`@("!P96%R("UD('!R969E<G)E9%]S=&%T93UB971A(&EN<W1A;&P@
M+6$@4V5R=FEC97-?5V5A=&AE<@H*-"X@17AT<F%C="!T87)B86QL.CH*"B`@
M("`@8V0@+W5S<B]L;V-A;"]A<&%C:&4O:'1D;V-S"B`@("`@=&%R('IX=F8@
M+W!A=&@O=&\O:&]R9&4M>"YY+GHN=&%R+F=Z"B`@("`@;78@:&]R9&4M>"YY
M+GH@:&]R9&4*"C4N($-O;F9I9W5R92!(;W)D93HZ"@H@("`@(&-D(&-O;F9I
M9R\*("`@("!F;W(@9B!I;B`J+F1I<W0[(&1O(&-P("1F(&!B87-E;F%M92`D
M9B`N9&ES=&`[(&1O;F4*"C8N($-R96%T92!D871A8F%S92!T86)L97,Z.@H*
M("`@("!C9"`N+B]S8W)I<'1S+W-Q;`H@("`@('9I(&-R96%T92YM>7-Q;"YS
M<6P*("`@("!M>7-Q;"`M=2!R;V]T("UP(#P@8W)E871E+FUY<W%L+G-Q;`H*
M-RX@5&5S="!(;W)D93HZ"@H@("`@(&AT='`Z+R]Y;W5R+7-E<G9E<B]H;W)D
M92]T97-T+G!H<`H*."X@1FEN:7-H(&-O;F9I9W5R871I;VXZ.@H*("`@("!H
M='1P.B\O>6]U<BUS97)V97(O:&]R9&4O"@H@("!';R!T;R!!9&UI;G-T<F%T
M:6]N(#T^(%-E='5P(#T^($AO<F1E"@H*4')E<F5Q=6ES:71E<PH]/3T]/3T]
M/3T]/3T]"@I4:&4@9F]L;&]W:6YG('!R97)E<75I<VET97,@87)E("HJ4D51
M54E2140J*B!F;W(@2&]R9&4@=&\@9G5N8W1I;VX@<')O<&5R;'DN"@HQ+B!!
M('=E8G-E<G9E<B!T:&%T('-U<'!O<G1S(%!(4"X*"B`@($AO<F1E(&%N9"!I
M=',@87!P;&EC871I;VYS(&%R92!D979E;&]P960@=6YD97(@=&AE($%P86-H
M92!W96)S97)V97(L('=H:6-H"B`@('=E(')E8V]M;65N9"X@07!A8VAE(&ES
M(&%V86EL86)L92!F<F]M"@H@("`@("!H='1P.B\O:'1T<&0N87!A8VAE+F]R
M9R\*"B`@($AO<F1E(&AA<R!A;'-O(&)E96X@<F5P;W)T961L>2!U<V5D('-U
M8V-E<W-F=6QL>2!U;F1E<B!-:6-R;W-O9G0@24E3+"!A;6]N9PH@("!O=&AE
M<G,N"@H@("`N+B!.;W1E.CH@268@>6]U('5S92!!<&%C:&4@=VET:"!M;V1?
M<&5R;"P@>6]U(&UA>2!N965D('1O(&5I=&AE<B!R96UO=F4*("`@("`@("`@
M("`@(&UO9%]P97)L+"!U<V4@82!N97=E<B!V97)S:6]N(&]F(&UO9%]P97)L
M+"!O<B!R97!L86-E('-E=&5N=B@I"B`@("`@("`@("`@("!C86QL<R!I;B!T
M:&4@2&]R9&4@<V]U<F-E(&-O9&4@=VET:"!C86QL<R!T;R!A<&%C:&5?<V5T
M96YV*"DN(%-E90H@("`@("`@("`@("`@:'1T<#HO+W=W=RYZ96YD+F-O;2]L
M:7-T<R]P:'`M9&5V+S(P,#,P.2]M<V<P,#$X.2YH=&UL(&9O<B!A;@H@("`@
M("`@("`@("`@97AP;&%N871I;VXN"@HR+B!02%`@-"XS+C`@;W(@86)O=F4N
M"@H@("!02%`@:7,@=&AE(&EN=&5R<')E=&5D(&QA;F=U86=E(&EN('=H:6-H
M($AO<F1E(&ES('=R:71T96XN"B`@(%EO=2!C86X@;V)T86EN(%!(4"!A=`H*
M("`@("`@:'1T<#HO+W=W=RYP:'`N;F5T+PH*("`@1F]L;&]W('1H92!I;G-T
M<G5C=&EO;G,@:6X@=&AE(%!(4"!P86-K86=E('1O(&)U:6QD(%!(4"!F;W(@
M>6]U<B!S>7-T96TN($EF"B`@('EO=2!U<V4@07!A8VAE+"!B92!S=7)E('1O
M(&)U:6QD(%!(4"!A<R!A(&QI8G)A<GD@=VET:"!O;F4@;V8@=&AE(&9O;&QO
M=VEN9PH@("!O<'1I;VYS.CH*"B`@("`@("`M+7=I=&@M87!A8VAE"B`@("`@
M("`M+7=I=&@M87!X<PH@("`@("`@+2UW:71H+6%P>',R"@H@("!O<'1I;VYS
M('1O(&!@+B]C;VYF:6=U<F5@8"P@86YD(&YO="!A<R!A('-T86YD86QO;F4@
M97AE8W5T86)L92X*"B`@(%1H92!F;VQL;W=I;F<@4$A0(&]P=&EO;G,@87)E
M("HJ4D5154E2140J*B!B>2!(;W)D92`H;&ES=&5D('=I=&@@=&AE:7(@;W=N
M"B`@('!R97)E<75I<VET97,@86YD(&-O;F9I9W5R92!O<'1I;VYS*2X@26X@
M;6%N>2!C87-E<RP@=&AE(')E<75I<F5D(&QI8G)A<FEE<PH@("!A;F0@=&]O
M;',@8V%N(&)E(&]B=&%I;F5D(&%S('!A8VMA9V5S(&9R;VT@>6]U<B!O<&5R
M871I;F<@<WES=&5M('9E;F1O<BX*"B`@(&$N($=E='1E>'0@<W5P<&]R="X@
M8&`M+7=I=&@M9V5T=&5X=&!@"@H@("`@("!'971T97AT(&ES('1H92!'3E4@
M5')A;G-L871I;VX@4')O:F5C="=S(&QO8V%L:7IA=&EO;B!L:6)R87)Y+@H@
M("`@("!(;W)D92!U<V5S(&=E='1E>'0@=&\@<')O=FED92!L;V-A;"!T<F%N
M<VQA=&EO;G,@;V8@=&5X="!D:7-P;&%Y960@8GD*("`@("`@87!P;&EC871I
M;VYS+B!);F9O<FUA=&EO;B!O;B!O8G1A:6YI;F<@=&AE(&=E='1E>'0@<&%C
M:V%G92!I<R!A=F%I;&%B;&4*("`@("`@870*"B`@("`@("`@(&AT='`Z+R]W
M=W<N9VYU+F]R9R]S;V9T=V%R92]G971T97AT+V=E='1E>'0N:'1M;`H*("`@
M("`@4V5E(&%L<V\@;F]T92!B96QO=R!O;B!C;VYF:6=U<FEN9R!T<F%N<VQA
M=&EO;G-?+@H*("`@8BX@6$U,(&%N9"!$3TU834P@<W5P<&]R="X@8&`M+7=I
M=&@M9&]M8&`*"B`@("`@($AO<F1E)W,@:&5L<"!E;F=I;F4@86YD(&-O;7!O
M;F5N="!S971U<"!R97%U:7)E(%A-3"!S=7!P;W)T+B!7:&EL92!S;VUE"B`@
M("`@('=E8G-E<G9E<G,@*&EN8VQU9&EN9R!R96-E;G0@07!A8VAE('9E<G-I
M;VYS*2!H879E(%A-3"!L:6)R87)I97,*("`@("`@8G5I;'0M:6XL(&]T:&5R
M<R!W:6QL(')E<75I<F4@=&AE(&5X<&%T(%A-3"!P87)S97(@;&EB<F%R:65S
M+"!A=F%I;&%B;&4*("`@("`@9G)O;0H*("`@("`@("!H='1P.B\O97AP870N
M<V]U<F-E9F]R9V4N;F5T+PH*("`@("`@+BX@26UP;W)T86YT.CH@66]U(&UU
M<W0@:&%V92`J*F)O=&@J*B!834P@;&EB<F%R:65S(&EN<W1A;&QE9"!F;W(@
M2&]R9&4*("`@("`@("`@("`@("`@("`@("`@=&\@=V]R:R!P<F]P97)L>2$*
M"B`@("`@($]L9&5R('9E<G-I;VYS(&]F(%!(4"!A;'-O(')E<75I<F4@8&`M
M+7=I=&@M>&UL8&`@=&\@96YA8FQE('1H90H@("`@("!305@@6$U,(&9U;F-T
M:6]N<RX@5VET:"!R96-E;G0@=F5R<VEO;G,@;V8@4$A0+"!T:&ES(&ES(&5N
M86)L960*("`@("`@8GD@9&5F875L="X*"B`@(%1H92!F;VQL;W=I;F<@4$A0
M(&]P=&EO;G,@87)E("HJ4D5#3TU-14Y$140J*B!T;R!E;F%B;&4@861V86YC
M960@9F5A='5R97,@:6X*("`@2&]R9&4Z"@H@("!A+B!!('!R969E<F5N8V5S
M(&-O;G1A:6YE<BX*"B`@("`@($AO<F1E(&%P<&QI8V%T:6]N<R!C86X@<W1O
M<F4@=7-E<B!P<F5F97)E;F-E<R!I;B!A;B!344P@9&%T86)A<V4L(&%N"B`@
M("`@($Q$05`@9&ER96-T;W)Y+"!A;B!)35-0('-E<G9E<BP@82!+;VQA8B!S
M97)V97(L(&]R(&EN(%!(4"!S97-S:6]N<RX*"B`@("`@($9O<B!344P@9&%T
M86)A<V4@<')E9F5R96YC97,@<W1O<F%G92P@2&]R9&4@:7,@=&AO<F]U9VAL
M>2!T97-T960@;VX*("`@("`@37E344P@*&!@+2UW:71H+6UY<W%L8&`I(&%N
M9"!0;W-T9W)E4U%,("A@8"TM=VET:"UP9W-Q;&!@*2!A;F0@:&%S(&)E96X*
M("`@("`@<F5P;W)T960@=&\@=V]R:R!W:71H($]R86-L92`H8&`M+7=I=&@M
M;V-I.&!@*2X@($ET(&UA>2!A;'-O('=O<FL@=VET:`H@("`@("!A;GD@;W1H
M97(@9&%T86)A<V4@<W5P<&]R=&5D(&)Y(%!%05(L(&)U="!T:&5Y(&%R92!U
M;G1E<W1E9"X*"B`@("`@(%!R969E<F5N8V5S(&-A;B!A;'-O(&)E('-T;W)E
M9"!V:6$@3$1!4"`H8&`M+7=I=&@M;&1A<&!@*2P@2V]L86(*("`@("`@*&!@
M+2UW:71H+6QD87!@8"DL(&%N9"!)35-0+@H*("`@("`@06QT97)N871I=F5L
M>2P@<')E9F5R96YC97,@8V%N(&)E('-T;W)E9"!I;B!02%`@<V5S<VEO;G,L
M('=H:6-H"B`@("`@(')E<75I<F5S(&YO(&5X=&5R;F%L('!R;V=R86US(&]R
M(&-O;F9I9W5R92!O<'1I;VYS+"!B=70@=VAI8V@@=VEL;"!N;W0*("`@("`@
M;6%I;G1A:6X@<')E9F5R96YC97,@8F5T=V5E;B!S97-S:6]N<RX*"B`@("`@
M(%=H:6QE('1H92!,1$%0+"!D871A8F%S92P@2V]L86(L(&]R($E-4U`@<V5R
M=F5R(&YE960@;F]T(&)E(')U;FYI;F<@;VX*("`@("`@=&AE(&UA8VAI;F4@
M;VYT;R!W:&EC:"!Y;W4@87)E(&EN<W1A;&QI;F<@2&]R9&4L('1H92!A<'!R
M;W!R:6%T90H@("`@("!C;&EE;G0@;&EB<F%R:65S('1O(&%C8V5S<R!T:&4@
M<V5R=F5R(&UU<W0@8F4@879A:6QA8FQE(&QO8V%L;'DN"@H@("`@("!)9B!A
M('!R969E<F5N8V4@8V]N=&%I;F5R(&ES(&YO="!C;VYF:6=U<F5D+"!N;R!P
M<F5F97)E;F-E(&]P=&EO;G,*("`@("`@=VEL;"!B92!C;VYF:6=U<F%B;&4@
M=FEA($AO<F1E)W,@=V5B(&EN=&5R9F%C92`M('1H92!D969A=6QT('9A;'5E
M<PH@("`@("!S=&]R960@:6X@96%C:"!A<'!L:6-A=&EO;G,@8&!C;VYF:6<O
M<')E9G,N<&AP8&`@9FEL92!W:6QL(&)E('5S960N"@H@("!B+B!-8W)Y<'0@
M<W5P<&]R="!@8"TM=VET:"UM8W)Y<'1@8`H*("`@("`@36-R>7!T(&ES(&$@
M9V5N97)A;"UP=7)P;W-E(&-R>7!T;V=R87!H>2!L:6)R87)Y('=H:6-H(&ES
M(&)R;V%D97(@86YD"B`@("`@('-I9VYI9FEC86YT;'D@;6]R92!E9F9I8VEE
M;G0@*$9!4U1%4B$I('1H86X@4$A0)W,@;W=N(&-R>7!T;V=R87!H:6,*("`@
M("`@8V]D92X@66]U(&-A;B!O8G1A:6X@;6-R>7!T(&9R;VT*"B`@("`@("`@
M(&AT='`Z+R]M8W)Y<'0N<V]U<F-E9F]R9V4N;F5T+PH*("`@("`@0G5I;&1I
M;F<@4$A0('=I=&AO=70@;6-R>7!T('-U<'!O<G0@=VEL;"!N;W0@<W1O<"!(
M;W)D92!F<F]M('=O<FMI;F<L"B`@("`@(&)U="!W:6QL(&9O<F-E(&ET('1O
M('5S92!W96%K97(@*&%N9"!M=6-H('-L;W=E<BD@96YC<GEP=&EO;BX*"B`@
M(&,N(%541BTX('-U<'!O<G0@8&`M+7=I=&@M:6-O;G8@+2UE;F%B;&4M;6)S
M=')I;F<]86QL("TM96YA8FQE+6UB<F5G97A@8`H*("`@("`@268@=&AE<V4@
M97AT96YS:6]N<R!A<F4@96YA8FQE9"P@2&]R9&4@8V%N('-U<'!O<G0@=&AE
M(%541BTX(&-H87)A8W1E<@H@("`@("!S970@*&UE86YI;F<@=&AA="!C;VYT
M96YT('=I=&@@86YY(&-H87)S970@8V%N(&)E('9I97=E9"!W:71H(&%N>0H@
M("`@("!T<F%N<VQA=&EO;BDN"@H@("!D+B!'1"!S=7!P;W)T(&!@+2UW:71H
M+6=D8&`*"B`@("`@($AO<F1E('=I;&P@=7-E('1H92!'1"!E>'1E;G-I;VX@
M=&\@<&5R9F]R;2!M86YI<'5L871I;VYS(&]N(&EM86=E(&1A=&$*("`@("`@
M=&AR;W5G:"!T:&4@2&]R9&5?26UA9V4@;&EB<F%R>2X*"B`@("`@($EF('EO
M=2!W86YT($=$('1O(&)E(&%B;&4@=&\@=V]R:R!W:71H(%!.1R!I;6%G97,L
M('EO=2!S:&]U;&0@=7-E('1H90H@("`@("!@8"TM=VET:"UP;F<M9&ER8&`@
M;W!T:6]N('1O(&UA:V4@<W5R92!02%`@8V%N(&9I;F0@=&AE(%!.1R!L:6)R
M87)I97,*("`@("`@:70@;F5E9',@=&\@8V]M<&EL92X*"B`@("`@($EF('EO
M=2!W86YT($=$('1O(&)E(&%B;&4@=&\@=V]R:R!W:71H($I014<@:6UA9V5S
M+"!Y;W4@<VAO=6QD('5S92!T:&4*("`@("`@8&`M+7=I=&@M:G!E9RUD:7)@
M8"!O<'1I;VX@=&\@;6%K92!S=7)E(%!(4"!C86X@9FEN9"!T:&4@2E!%1R!L
M:6)R87)I97,*("`@("`@:70@;F5E9',@=&\@8V]M<&EL92X*"B`@("`@(%EO
M=2!C86X@86QS;R!U<V4@=&AE($EM86=E36%G:6-K7R!P86-K86=E('1O(&1O
M('1H97-E(&UA;FEP=6QA=&EO;G,*("`@("`@:6YS=&5A9"X@(%-E92!T:&4@
M8&!);6%G92!-86YI<'5L871I;VY@8"!T86(@;V8@=&AE($AO<F1E('-E='5P
M(&9O<B!M;W)E"B`@("`@(&1E=&%I;',N"@H@("`@("`N+B!?26UA9V5-86=I
M8VLZ(&AT='`Z+R]W=W<N:6UA9V5M86=I8VLN;W)G"@H@("!E+B!-24U%($UA
M9VEC('-U<'!O<G0@8&`M+7=I=&@M;6EM92UM86=I8V!@"@H@("`@("!(;W)D
M92!W:6QL('5S92!T:&4@34E-12!-86=I8R!E>'1E;G-I;VX@=&\@9W5E<W,@
M=&AE($U)344@='EP92!O9B!F:6QE<PH@("`@("!B>2!A;F%L>7II;F<@=&AE
M:7(@8V]N=&5N=',N"@H@("`@("`N+B!.;W1E.CH@5&AI<R!E>'1E;G-I;VX@
M:7,@<F5P;W)T960@=&\@8F4@9&5P<F5C871E9%\@:6X@9F%V;W(@;V8@=&AE
M"B`@("`@("`@("`@("`@("!F:6QE:6YF;R!014-,(&5X=&5N<VEO;B`H<V5E
M(&)E;&]W*2X@($AO=V5V97(L('-O;64@=7-E<G,@:&%V90H@("`@("`@("`@
M("`@("`@<F5P;W)T960@=&AA="!T:&4@9FEL96EN9F\@97AT96YS:6]N('=I
M;&P@;F]T(&)U:6QD(&-O<G)E8W1L>0H@("`@("`@("`@("`@("`@;VX@=&AE
M:7(@<WES=&5M+B`@268@<V\L('1H86X@=&AE($U)344@36%G:6,@97AT96YS
M:6]N('-H;W5L9`H@("`@("`@("`@("`@("`@8F4@=7-E9"!I;G-T96%D+B`@
M4&EC:R!O;F4@;W(@=&AE(&]T:&5R("T@=&AE<F4@:7,@;F\@;F5E9"!T;PH@
M("`@("`@("`@("`@("`@8V]M<&EL92!B;W1H+@H*("`@("`@268@=7-I;F<@
M4$A0(#0N,RXP("T^(#0N,RXQ+"!Y;W4@<VAO=6QD('5S92!@8"TM96YA8FQE
M+6UI;64M;6%G:6-@8`H@("`@("!I;G-T96%D(&]F(&!@+2UW:71H+6UI;64M
M;6%G:6-@8"X*"B`@("`@("XN(%]D97!R96-A=&5D.B!H='1P.B\O=W=W+G!H
M<"YN970O;6EM95]M86=I8PH*("`@+BX@26UP;W)T86YT.CH@061D:71I;VYA
M;&QY+"!I;F1I=FED=6%L($AO<F1E(&%P<&QI8V%T:6]N<R!M87D@*BI215%5
M25)%*BH*("`@("`@("`@("`@("`@("`@;W1H97(@;W!T:6]N<R!T;R!B92!B
M=6EL="!I;G1O(%!(4"!A;'-O+B!0;&5A<V4@8VAE8VL*("`@("`@("`@("`@
M("`@("`@8&!D;V-S+TE.4U1!3$Q@8"!F;W(@86QL(&%P<&QI8V%T:6]N<R!Y
M;W4@=VES:"!T;R!U<V4@=&\@<V5E"B`@("`@("`@("`@("`@("`@(&EF(&]T
M:&5R(%!(4"!O<'1I;VYS(&%R92!N965D960N"@HS+B!!9&1I=&EO;F%L(%!%
M05(@36]D=6QE<PH*("`@4$5!4B!I<R!S:&]R="!F;W(@(E!(4"!%>'1E;G-I
M;VX@86YD($%P<&QI8V%T:6]N(%)E<&]S:71O<GDB+B`@5&AE(&=O86P@;V8*
M("`@4$5!4B!I<R!T;R!P<F]V:61E(&$@;65A;G,@;V8@9&ES=')I8G5T:6YG
M(')E=7-A8FQE(&-O9&4N"@H@("!&;W(@;6]R92!I;F9O<FUA=&EO;BP@<V5E
M(&AT='`Z+R]P96%R+G!H<"YN970O"@H@("`N+B!);7!O<G1A;G0Z.B!-86ME
M('-U<F4@>6]U(&%R92!R=6YN:6YG(&$@<W5P<&]R=&5D("AI+F4N(&YE=R!E
M;F]U9V@I"B`@("`@("`@("`@("`@("`@('9E<G-I;VX@;V8@4$5!4CH@=7-E
M('1H92!T97-T('-C<FEP="!D97-C<FEB960@8F5L;W<@=6YD97(*("`@("`@
M("`@("`@("`@("`@(F!#;VYF:6=U<FEN9R!(;W)D96!?(BX@($1O("HJ;F]T
M*BH@=7-E('1H92!014%2('9E<G-I;VX*("`@("`@("`@("`@("`@("`@9G)O
M;2!F='`N:&]R9&4N;W)G+@H*("`@0VAE8VL@=&AA="!T:&4@<&%T:"!W:&5R
M92!T:&4@4$5!4B!P86-K86=E<R!A<F4@:6YS=&%L;&5D(&%R92!P87)T(&]F
M('1H90H@("!@8&EN8VQU9&5?<&%T:&!@('!A<F%M971E<B!T:&%T(%!(4"!U
M<V5S('1O(&9I;F0@4$5!4B!P86-K86=E<RX*"B`@(%)U;B!T:&4@8V]M;6%N
M9#HZ"@H@("`@('!E87(@8V]N9FEG+7-H;W<*"B`@(%EO=2!W:6QL('-E92!S
M;VUE=&AI;F<@;&EK93HZ"@H@("`@(%!%05(@9&ER96-T;W)Y("`@("`@("`@
M("`@("`@("!P:'!?9&ER("`@("`@("`@+W5S<B]S:&%R92]P:'`*"B`@($YO
M=R!O<&5N('1H92!P:'`N:6YI(&9I;&4@;V8@>6]U<B!S>7-T96TL(&9O<B!E
M>&%M<&QE(&!@+V5T8R]P:'`N:6YI8&`L"B`@(&9I;F0@=&AE(&!@:6YC;'5D
M95]P871H8&`@86YD(&UA:V4@<W5R92!T:&%T(&!@+W5S<B]S:&%R92]P:'!@
M8"!I<R!P87)T(&]F"B`@('1H92!L:7-T+B`@268@>6]U(&AA9"!T;R!C:&%N
M9V4@=&AA="!V86QU92P@<F5S=&%R="!T:&4@=V5B('-E<G9E<B!A9G1E<@H@
M("!S879I;F<@8&!P:'`N:6YI8&`N"@H@("!4:&5S92!014%2(&UO9'5L97,@
M87)E("HJ4D5154E2140J*B!T;R!B92!I;G-T86QL960@9F]R(&-O;7!L971E
M($AO<F1E"B`@(&9U;F-T:6]N86QI='DZ"@H@("!A+B!,;V<*("`@8BX@36%I
M;`H@("!C+B!-86EL7TUI;64*"B`@("`@(%1O(&EN<W1A;&PL(&5N=&5R('1H
M92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@("`@("`@
M<&5A<B!I;G-T86QL($QO9R!-86EL($UA:6Q?36EM90H*("`@5&AE<V4@4$5!
M4B!M;V1U;&5S(&%R92`J*E)%0T]-345.1$5$*BH@=&\@8F4@:6YS=&%L;&5D
M.@H*("`@82X@1$(@*#X](#$N-BXP*0H*("`@("`@*BI215%525)%1"HJ(&%S
M('-O;VX@87,@>6]U('=A;G0@;W(@;F5E9"!T;R!S=&]R92!A;GET:&EN9R!I
M;B!A(&1A=&%B87-E+@H@("`@("!4;R!I;G-T86QL+"!E;G1E<B!T:&4@9F]L
M;&]W:6YG(&%T('1H92!C;VUM86YD('!R;VUP=#HZ"@H@("`@("`@('!E87(@
M:6YS=&%L;"!$0@H*("`@("`@5&\@=7!G<F%D92P@96YT97(@=&AE(&9O;&QO
M=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M<'0Z.@H*("`@("`@("!P96%R('5P
M9W)A9&4@1$(*"B`@(&(N($9I;&4*"B`@("`@("HJ4D5154E2140J*B!O;FQY
M(&EF('EO=2!W:7-H('1O(&EM<&]R="!#4U8@9FEL97,N"B`@("`@(%1O(&EN
M<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O
M;7!T.CH*"B`@("`@("`@<&5A<B!I;G-T86QL($9I;&4*"B`@(&,N($1A=&4*
M"B`@("`@("HJ4D5154E2140J*B!O;FQY(&EF('EO=2!A<F4@9&5A;&EN9R!W
M:71H(&-A;&5N9&%R(&1A=&$N"B`@("`@(%1O(&EN<W1A;&PL(&5N=&5R('1H
M92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@("`@("`@
M<&5A<B!I;G-T86QL($1A=&4*"B`@(&0N(%-E<G9I8V5S7U=E871H97(@*#X]
M(#$N,RXQ*0H*("`@("`@*BI215%525)%1"HJ(&]N;'D@:68@>6]U('=I<V@@
M=&\@=7-E('1H92!W96%T:&5R+F-O;2!B;&]C:R!O;@H@("`@("!T:&4@<&]R
M=&%L('!A9V4N"B`@("`@(%1O(&EN<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I
M;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@("`@("`@<&5A<B`M9"!P
M<F5F97)R961?<W1A=&4]8F5T82!I;G-T86QL("UA(%-E<G9I8V5S7U=E871H
M97(*"B`@(%1H:7,@;65T:&]D(&]F(&EN<W1A;&QI;F<@4$5!4B!M;V1U;&5S
M(')E<75I<F5S('1H870@>6]U(&AA=F4@82!02%`@=F5R<VEO;@H@("!T:&%T
M(&AA<R!B965N(&-O;7!I;&5D(&%S(&$@<W1A=&EC(&)I;F%R>2X@($%L;"!V
M97)S:6]N<R!O9B!02%`@-"XS+C`K"B`@(&)U:6QD(&)O=&@@82!305!)(&UO
M9'5L92`H07!A8VAE+"!#1TDL(&5T8RXI(&%N9"!A(&-O;6UA;F0M;&EN92`H
M0TQ)*0H@("!B:6YA<GD@870@=&AE('-A;64@=&EM92X@($-H96-K(&EF('EO
M=2!H879E(&$@<&AP(&)I;F%R>2!I;@H@("!@8"]U<W(O;&]C86PO8FEN8&`@
M*&!@+W5S<B]B:6Y@8"!I9B!I9B!Y;W4@:6YS=&%L;&5D(&9R;VT@86X@;W!E
M<F%T:6YG"B`@('-Y<W1E;2!P86-K86=E*2!B969O<F4@<F5C;VUP:6QI;F<N
M"@H@("!)9B!Y;W4@<F5C96EV92!T:&4@97)R;W(@8&!#;W5L9"!N;W0@<F5A
M9"!C;60@87)G<V!@('EO=2!S:&]U;&0@<G5N('1H92!P96%R"B`@('-C<FEP
M="!T:&ES('=A>3HZ"@H@("`@('!H<"`M9"!R96=I<W1E<E]A<F=C7V%R9W8]
M,2!?4$5!4E\@:6YS=&%L;"!?55),7PH*("`@7U!%05)?(&ES('1H92!C;VUP
M;&5T92!P871H(&]F('1H92!P96%R('-C<FEP="!I;G-T86QL960@8GD@4$A0
M(&1U<FEN9PH@("!I;G-T86QL871I;VX@*&4N9RX@8&`O=7-R+VQO8V%L+V)I
M;B]P96%R8&`I+B`@36%K92!S=7)E('1H92!@8'!E87)@8"!S8W)I<'0*("`@
M87!P96%R<R!I;B!Y;W5R('!A=&@N(%1H92!D969A=6QT(&EN<W1A;&QA=&EO
M;B!P871H(&9O<B!P96%R(&ES"B`@(&!@+W5S<B]L;V-A;"]B:6XO<&5A<F!@
M+@H*("`@7U523%\@:7,@=&AE(%523"P@;&ES=&5D(&%B;W9E+"!W:&EC:"!Y
M;W4@=VES:"!T;R!D;W=N;&]A9"!F<F]M+@H*("`@268@>6]U(&%R92!U;F%B
M;&4@=&\@9FEN9"!A;GD@;V8@=&AE(&%B;W9E(%!%05(@<&%C:V%G97,L(&UA
M:V4@<W5R92!Y;W4*("`@:&%V92!A;&QO=V5D('1H92!I;G-T86QL871I;VX@
M;V8@8F5T82!P86-K86=E<RX@0VAE8VL@9F]R('1H:7,@8GD@='EP:6YG"B`@
M('1H92!F;VQL;W=I;F<@;VX@=&AE(&-O;6UA;F0@;&EN93HZ"@H@("`@('!E
M87(@8V]N9FEG+6=E="!P<F5F97)R961?<W1A=&4*"B`@($EF(%!%05(@<F5P
M;W)T<R!T:&4@<')E9F5R<F5D7W-T871E(&%S("=S=&%B;&4G+"!T:&5N(')U
M;B!T:&4@9F]L;&]W:6YG"B`@(&-O;6UA;F0@=&\@861D('-U<'!O<G0@9F]R
M(&EN<W1A;&QI;F<@8F5T82!P86-K86=E<SHZ"@H@("`@('!E87(@8V]N9FEG
M+7-E="!P<F5F97)R961?<W1A=&4@8F5T80H*("`@1F]R(&UO<F4@9&5T86EL
M960@9&ER96-T:6]N<R!O;B!I;G-T86QL:6YG(%!%05(@;6]D=6QE<RP@<V5E
M('1H92!014%2"B`@(&1O8W5M96YT871I;VX@870@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO"@HT+B!!9&1I=&EO;F%L(%!%0TP@36]D=6QE<PH*("`@
M4$5#3"!I<R!S:&]R="!F;W(@(E!(4"!%>'1E;G-I;VX@0V]M;75N:71Y($QI
M8G)A<GDB+B`@5&AE(&=O86P@;V8@4$5#3"!I<PH@("!T;R!P<F]V:61E(&$@
M;65A;G,@;V8@96%S:6QY(&1I<W1R:6)U=&EN9R!02%`@97AT96YS:6]N<RX*
M"B`@($9O<B!M;W)E(&EN9F]R;6%T:6]N+"!S964@:'1T<#HO+W!E8VPN<&AP
M+FYE="\*"B`@(%!%0TP@:7,@=&AE(")S:7-T97(B(&]F(%!%05(@86YD('5S
M97,@=&AE('-A;64@<&%C:V%G:6YG(&%N9"!D:7-T<FEB=71I;VX*("`@<WES
M=&5M(&%S(%!%05(L('-O('1H92!C;VYF:6=U<F%T:6]N+W-E='5P(&ES(&5S
M<V5N=&EA;&QY(&ED96YT:6-A;"!T;R!T:&4*("`@4$5!4B!I;G-T<G5C=&EO
M;G,@86)O=F4N"@H@("!7:&5N('EO=2!I;G-T86QL(&$@4$5#3"!E>'1E;G-I
M;VXL('EO=2!H879E('1O(&%D9"!I="!T;R!Y;W5R(&!@<&AP+FEN:6!@"B`@
M('-O(&ET(&=E=',@;&]A9&5D+B`@061D('1H92!F;VQL;W=I;F<@;&EN92!T
M;R!Y;W5R(&!@<&AP+FEN:6!@(&9I;&4@=&\@;&]A9`H@("!T:&4@97AT96YS
M:6]N("AT:&4@97AT96YS:6]N('-H;W5L9"!B92!I;G-T86QL960@:6X@=&AE
M(&1I<F5C=&]R>2!S<&5C:69I960*("`@8GD@=&AE(&!@97AT96YS:6]N7V1I
M<F!@(&]P=&EO;B!I;B!@8'!H<"YI;FE@8"DZ.@H*("`@("!E>'1E;G-I;VX]
M9FEL96EN9F\N<V\*"B`@($]R(&]N(%=I;F1O=W,Z.@H*("`@("!E>'1E;G-I
M;VX]9FEL96EN9F\N9&QL"@H@("!!9G1E<B!T:&%T+"!R97-T87)T('EO=7(@
M=V5B<V5R=F5R+@H*("`@5&AE<V4@4$5#3"!M;V1U;&5S(&%R92`J*E)%0T]-
M345.1$5$*BH@=&\@8F4@:6YS=&%L;&5D.@H*("`@82X@9FEL96EN9F\*"B`@
M("`@($%L;&]W<R!(;W)D92!M;V1U;&5S('1O(&=U97-S('1H92!-24U%('1Y
M<&4@;V8@9FEL97,@8GD@86YA;'EZ:6YG"B`@("`@('1H96ER(&-O;G1E;G1S
M+@H*("`@("`@268@;F]T(&5N86)L960L($AO<F1E('=I;&P@=7-E(&ET<R!O
M=VX@4$A0(&-O9&4@=&\@<&5R9F]R;2!-24U%(&UA9VEC"B`@("`@(&QO;VMU
M<',N("!(;W=E=F5R+"!T:&ES(&QO;VMU<"!I<R!S;&]W97(L(&QE<W,@86-C
M=7)A=&4L(&%N9"!D971E8W1S"B`@("`@(&9E=V5R($U)344@='EP97,@=&AA
M;B!T:&4@4$5#3"!E>'1E;G-I;VX@=VEL;"X*"B`@("`@(%1O(&EN<W1A;&PL
M(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*
M"B`@("`@("`@<&5A<B!I;G-T86QL(&9I;&5I;F9O"@H@("!4:&5S92!014-,
M(&UO9'5L97,@87)E("HJ4D5#3TU-14Y$140J*B!T;R!B92!I;G-T86QL960@
M:68@>6]U(&YE960*("`@861V86YC960@9G5N8W1I;VYA;&ET>3H*"B`@(&$N
M(&UE;6-A8VAE"@H@("`@("!)9B!U<VEN9R!T:&4@;65M8V%C:&5D(%-E<W-I
M;VY(86YD;&5R+"!T:&4@;65M8V%C:&4@4$5#3"!E>'1E;G-I;VX@;75S=`H@
M("`@("!B92!I;G-T86QL960N"@H@("`@("!4;R!I;G-T86QL+"!E;G1E<B!T
M:&4@9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R;VUP=#HZ"@H@("`@("`@
M('!E87(@:6YS=&%L;"!M96UC86-H90H*("`@1F]R(&%D9&ET:6]N86P@:&5L
M<"!O;B!U<VEN9R!T:&4@<&5A<B!C;VUM86YD+6QI;F4@<')O9W)A;2!T;R!I
M;G-T86QL(%!%0TP*("`@97AT96YS:6]N<RP@<V5E('1H92!014%2(&EN<W1A
M;&QA=&EO;B!S96-T:6]N(&%B;W9E+@H*"E1H92!F;VQL;W=I;F<@;F]N+5!(
M4"!P<F5R97%U:7-I=&5S(&%R92`J*E)%0T]-345.1$5$*BHL(&]R(&%R92`J
M*E)%455)4D5$*BH*:68@>6]U('5S92!A('-P96-I9FEC($AO<F1E(&%P<&QI
M8V%T:6]N("AA<R!N;W1E9"!I;B!;8G)A8VME='-=*3H*"C$N(%-E;F1M86EL
M(&]R(&5Q=6EV86QE;G0N"@H@("!(;W)D92!U<V5S('-E;F1M86EL+"!O<B!A
M('!R;V=R86T@=&AA="!I;7!L96UE;G1S('1H92!@8'-E;F1M86EL*#@I8&`@
M05!)"B`@("AA<R!I;F-L=61E9"!W:71H('!O<W1F:7@L('%M86EL+"!A;F0@
M97AI;2P@86UO;F<@;W1H97)S*2X@268@>6]U<B!S>7-T96T*("`@9&]E<R!N
M;W0@86QR96%D>2!H879E(&$@9G5L;"!M86EL('1R86YS<&]R="!W:71H(&$@
M<V5N9&UA:6P@:6YT97)F86-E+"!Y;W4*("`@8V%N(&-O;F9I9W5R92!(;W)D
M92!T;R!S<&5A:R!D:7)E8W1L>2!W:71H(&$@<F5M;W1E(%--5%`@<V5R=F5R
M+"!B=70@=&AI<PH@("!M87D@:6YC=7(@82!P97)F;W)M86YC92!P96YA;'1Y
M+@H*"DEN<W1A;&QI;F<@2&]R9&4*/3T]/3T]/3T]/3T]/3T]/0H*2&]R9&4@
M:7,@=W)I='1E;B!I;B!02%`L(&%N9"!M=7-T(&)E(&EN<W1A;&QE9"!I;B!A
M('=E8BUA8V-E<W-I8FQE(&1I<F5C=&]R>2X*5&AE('!R96-I<V4@;&]C871I
M;VX@;V8@=&AI<R!D:7)E8W1O<GD@=VEL;"!D:69F97(@9G)O;2!S>7-T96T@
M=&\@<WES=&5M+B!)9@IY;W4@:&%V92!N;R!I9&5A('=H97)E('EO=2!S:&]U
M;&0@8F4@:6YS=&%L;&EN9R!(;W)D92P@:6YS=&%L;"!I="!D:7)E8W1L>0IU
M;F1E<B!T:&4@<F]O="!O9B!Y;W5R('=E8G-E<G9E<B=S(&1O8W5M96YT('1R
M964N"@H*26YS=&%L;&EN9R!F<F]M(%)E;&5A<V4@5&%R8F%L;',*?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GX*"E-I;F-E($AO<F1E(&ES('=R
M:71T96X@:6X@4$A0+"!T:&5R92!I<R!N;R!C;VUP:6QA=&EO;B!N96-E<W-A
M<GD[('-I;7!L>0IE>'!A;F0@=&AE(&1I<W1R:6)U=&EO;B!W:&5R92!Y;W4@
M=V%N="!I="!T;R!R97-I9&4@86YD(')E;F%M92!T:&4@<F]O=`ID:7)E8W1O
M<GD@;V8@=&AE(&1I<W1R:6)U=&EO;B!T;R!W:&%T979E<B!Y;W4@=VES:"!T
M;R!A<'!E87(@:6X@=&AE(%523"X@($9O<@IE>&%M<&QE+"!W:71H('1H92!!
M<&%C:&4@=V5B<V5R=F5R)W,@9&5F875L="!D;V-U;65N="!R;V]T(&]F"F!@
M+W5S<B]L;V-A;"]A<&%C:&4O:'1D;V-S8&`L('EO=2!W;W5L9"!T>7!E.CH*
M"B`@(&-D("]U<W(O;&]C86PO87!A8VAE+VAT9&]C<PH@("!T87(@>GAV9B`O
M<&%T:"]T;R]H;W)D92UX+GDN>BYT87(N9WH*("`@;78@:&]R9&4M>"YY+GH@
M:&]R9&4*"EEO=2!W;W5L9"!T:&5N(&9I;F0@2&]R9&4@870@=&AE(%523#HZ
M"@H@("!H='1P.B\O>6]U<BUS97)V97(O:&]R9&4O"@H*26YS=&%L;&EN9R!F
M<F]M($-64R!O<B!3;F%P:&]T<PI^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^"@I!="!T:&ES('!O:6YT+"!T:&4@2&]R9&4@9G)A;65W;W)K(&UO
M9'5L97,@;F5E9"!T;R!B92!C:&5C:V5D(&]U="!F<F]M($-64R!A;F0*:6YS
M=&%L;&5D+B`@5&AI<R!M=7-T(&)E(&1O;F4@87,@<F]O="`H;W(@86YO=&AE
M<B!U<V5R('=I=&@@<W5F9FEC:65N=`IA9&UI;FES=')A=&]R('!R:79I;&5D
M9V5S*3HZ"@H@("!C9"!H;W)D90H@("!C=G,@8V\@9G)A;65W;W)K"B`@(&-D
M(&9R86UE=V]R:PH@("!P:'`@+7$@:6YS=&%L;"UP86-K86=E<RYP:'`*"D9O
M<B!7:6YD;W=S('-Y<W1E;7,@+2!U<V4@=&AE(&!@:6YS=&%L;"UP86-K86=E
M<RYB871@8"!F:6QE(&EN<W1E860N"D9O<B!$96)I86X@<WES=&5M<R`M('1H
M92!C;VUM86YD+6QI;F4@4$A0(&EN=&5R<')E=&5R(&UI9VAT(&)E(&-A;&QE
M9"!@8'!H<#1@8`II;G-T96%D(&]F(&!@<&AP8&`N"@H*0V]N9FEG=7)I;F<@
M2&]R9&4*/3T]/3T]/3T]/3T]/3T]/3T*"C$N($-O;F9I9W5R:6YG('1H92!W
M96(@<V5R=F5R"@H@("!(;W)D92!R97%U:7)E<R!T:&4@9F]L;&]W:6YG('=E
M8G-E<G9E<B!S971T:6YG<RX@17AA;7!L97,@<VAO=VX@87)E(&9O<@H@("!!
M<&%C:&4[(&]T:&5R('=E8G-E<G9E<G,G(&-O;F9I9W5R871I;VYS('=I;&P@
M9&EF9F5R+@H*("`@82X@4$A0(&EN=&5R<')E=&%T:6]N(&9O<B!F:6QE<R!M
M871C:&EN9R!@8"HN<&AP8&`Z.@H*("`@("`@("`@061D5'EP92!A<'!L:6-A
M=&EO;B]X+6AT='!D+7!H<"`N<&AP"@H@("`@("`N+B!.;W1E.CH@5&AE(&%B
M;W9E(&EN<W1R=6-T:6]N<R!M87D@;F]T('=O<FL@:68@>6]U(&AA=F4@<W!E
M8VEF:65D(%!(4`H@("`@("`@("`@("`@("`@87,@86X@;W5T<'5T(&9I;'1E
M<B!W:71H(&!@4V5T3W5T<'5T1FEL=&5R8&`@9&ER96-T:79E(&EN"B`@("`@
M("`@("`@("`@("!!<&%C:&4@,BYX('9E<G-I;VYS+B`@26X@<&%R=&EC=6QA
M<BP@4F5D($AA="`X+C`@86YD(&%B;W9E"B`@("`@("`@("`@("`@("!!<&%C
M:&4@,BYX(%)035,@:&%V92!T:&4@;W5T<'5T(&9I;'1E<B!S970L(&%N9"`J
M*DU54U0@3D]4*BH*("`@("`@("`@("`@("`@(&AA=F4@=&AE(&%B;W9E(&!@
M061D5'EP96!@(&1I<F5C=&EV92!A9&1E9"X*"B`@(&(N(&!@:6YD97@N<&AP
M8&`@87,@86X@:6YD97@@9FEL92`H8G)O=6=H="!U<"!W:&5N(&$@=7-E<B!R
M97%U97-T<R!A(%523"!F;W(*("`@("`@82!D:7)E8W1O<GDI.CH*"B`@("`@
M("`@($1I<F5C=&]R>4EN9&5X(&EN9&5X+G!H<`H*,BX@0W)E871I;F<@9&%T
M86)A<V5S"@H@("!4:&4@<W!E8VEF:6,@<W1E<',@=&\@8W)E871E(&$@<')E
M9F5R96YC97,@<W1O<F%G92!C;VYT86EN97(@9&5P96YD(&]N"B`@('=H:6-H
M(&1A=&%B87-E('EO=2=V92!C:&]S96X@=&\@=7-E+@H*("`@1FER<W0L(&QO
M;VL@:6X@8&!S8W)I<'1S+W-Q;&!@+R!T;R!S964@:68@82!@8&-R96%T92Y@
M8"!S8W)I<'0@86QR96%D>0H@("!E>&ES=',@9F]R('EO=7(@9&%T86)A<V4N
M("!)9B!S;RP@>6]U('-H;W5L9"!B92!A8FQE('1O('-I;7!L>2!E>&5C=71E
M('1H870*("`@<V-R:7!T(&%S('-U<&5R=7-E<B!I;B!Y;W5R(&1A=&%B87-E
M+B`@0V]N<W5L="!T:&4@8&!S8W)I<'1S+W-Q;"]214%$345@8`H@("!F:6QE
M(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H*("`@0F4@<W5R92!T;R!C:&%N9V4@
M=&AE(&1E9F%U;'0@<&%S<W=O<F0L(&!@:&]R9&5@8"P@=&\@<V]M971H:6YG
M(&5L<V4@8F5F;W)E"B`@(&-R96%T:6YG('1H92!T86)L97,A("A296UE;6)E
M<B!T;R!U<V4@=&AI<R!P87-S=V]R9"!W:&5N('EO=2!C;VYF:6=U<F4*("`@
M2&]R9&4@:6X@=&AE(&YE>'0@<W1E<"XI"@H@("!)9B!S=6-H(&$@<V-R:7!T
M(&1O97,@;F]T(&5X:7-T+"!Y;W4G;&P@;F5E9"!T;R!B=6EL9"!Y;W5R(&]W
M;BP@=7-I;F<@=&AE"B`@(&9I;&5S(&!@:&]R9&5?=7-E<G,N<W%L8&`L(&!@
M:&]R9&5?<')E9G,N<W%L8&`L(&%N9"!@8&AO<F1E7V1A=&%T<F5E+G-Q;&!@
M"B`@(&%S(&$@<W1A<G1I;F<@<&]I;G0N("!)9B!Y;W4@;F5E9"!A<W-I<W1A
M;F-E(&EN(&-R96%T:6YG(&1A=&%B87-E<R!F;W(@80H@("!D871A8F%S92!F
M;W(@=VAI8V@@;F\@8&!C<F5A=&4N8&`@<V-R:7!T(&5X:7-T<RP@>6]U(&UA
M>2!W:7-H('1O(&QE="!U<PH@("!K;F]W(&]N('1H92!@2&]R9&4@;6%I;&EN
M9R!L:7-T8%\N"@H@("!)9B!Y;W4@87)E(&=O:6YG('1O('5S92!D871A8F%S
M92!B87-E9"!S97-S:6]N<RP@8W)E871E(&$@=&%B;&4@=7-I;F<@=&AE"B`@
M(&9I;&5S(&!@<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(J+G-Q
M;&!@(&%S(&$@<W1A<G1I;F<@<&]I;G0N"@H@("`N+B!?8$AO<F1E(&UA:6QI
M;F<@;&ES=&`Z(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*,RX@0V]N9FEG=7)I
M;F<@2&]R9&4*"B`@(%1O(&-O;F9I9W5R92!(;W)D92P@8VAA;F=E('1O('1H
M92!@8&-O;F9I9R]@8"!D:7)E8W1O<GD@;V8@=&AE(&EN<W1A;&QE9`H@("!D
M:7-T<FEB=71I;VXL(&%N9"!M86ME(&-O<&EE<R!O9B!A;&P@;V8@=&AE(&-O
M;F9I9W5R871I;VX@8&`N9&ES=&!@(&9I;&5S"B`@('=I=&AO=70@=&AE(&!@
M+F1I<W1@8"!S=69F:7@Z.@H*("`@("`@8V0@8V]N9FEG+PH@("`@("!F;W(@
M9B!I;B`J+F1I<W0[(&1O(&-P("1F(&!B87-E;F%M92`D9B`N9&ES=&`[(&1O
M;F4*"B`@($]R(&EF('EO=2!A<F4@:6YS=&%L;&EN9R!(;W)D92!A;B!A(%=I
M;F1O=W,@<WES=&5M.CH*"B`@("`@(&-D(&-O;F9I9PH@("`@("!C;W!Y("HN
M9&ES="`J+@H*("`@+BX@5V%R;FEN9SHZ(%EO=2!O;FQY(&YE960@=&AE(&!@
M:&]O:W,N<&AP8&`@9FEL92!I9B!Y;W4@=V%N="!T;R!C<F5A=&4*("`@("`@
M("`@("`@("`@(&-U<W1O;2!H;V]K<R!F;W(@<V]M92!O9B!(;W)D92=S(&9E
M871U<F5S(&%N9"!D969A=6QT('9A;'5E<RX*("`@("`@("`@("`@("`@($)E
M<VED92!T:&%T+"!T:&ES(&9I;&4@;VYL>2!C;VYT86EN<R!E>&%M<&QE<R!T
M:&%T('EO=2!S:&]U;&0*("`@("`@("`@("`@("`@(&YO="!U<V4@87,@=&AE
M>2!A<F4@86YD('1H870@979E;B!C875S92!F871A;"!E<G)O<B!I9B!Y;W4*
M("`@("`@("`@("`@("`@(&ME97`@=&AI<R!F:6QE('5N8VAA;F=E9"X@($EF
M('EO=2!D;VXG="!N965D(&AO;VMS(&ET)W,@82!G;V]D"B`@("`@("`@("`@
M("`@("!I9&5A('1O(')E;6]V92!T:&ES(&9I;&4@;F]W.CH*"B`@("`@("`@
M("`@("`@("`@("!R;2!H;V]K<RYP:'`*"B`@($1O8W5M96YT871I;VX@;VX@
M=&AE(&9O<FUA="!O9B!T:&]S92!F:6QE<R!C86X@8F4@9F]U;F0@:6X@96%C
M:"!F:6QE+B`@66]U"B`@(&UU<W0@870@;&5A<W0@<')O=FED92!P871H<R!T
M;R!H96QP97(@87!P;&EC871I;VYS(&EN(&!@;6EM95]D<FEV97)S+G!H<&!@
M+@H*("`@+BX@5V%R;FEN9SHZ($%L;"!C;VYF:6=U<F%T:6]N(&9I;&5S(&EN
M($AO<F1E(&%R92!02%`@<V-R:7!T<R!T:&%T(&%R90H@("`@("`@("`@("`@
M("`@97AE8W5T960@8GD@=&AE('=E8B!S97)V97(N("!)9B!Y;W4@;6%K92!A
M;B!E<G)O<B!I;B!O;F4@;V8*("`@("`@("`@("`@("`@('1H97-E(&9I;&5S
M+"!(;W)D92!M:6=H="!S=&]P('=O<FMI;F<N("!4:'5S(&ET(&ES(&%L=V%Y
M<R!A"B`@("`@("`@("`@("`@("!G;V]D(&ED96$@=&\@=&5S="!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE<R!A9G1E<B!Y;W4@961I=&5D"B`@("`@("`@("`@
M("`@("!T:&5M+B`@268@>6]U('=A;G0@=&\@=&5S="!M:6UE7V1R:79E<G,N
M<&AP(&9O<B!E>&%M<&QE(')U;CHZ"@H@("`@("`@("`@("`@("`@("`@<&AP
M("UL(&UI;65?9')I=F5R<RYP:'`*"C0N(%1E<W1I;F<@2&]R9&4*"B`@($]N
M8V4@>6]U(&AA=F4@8V]N9FEG=7)E9"!Y;W5R('=E8G-E<G9E<BP@4$A0+"!A
M;F0@2&]R9&4L(&)R:6YG('5P('1H90H@("!I;F-L=61E9"!T97-T('!A9V4@
M:6X@>6]U<B!796(@8G)O=W-E<B!T;R!E;G-U<F4@=&AA="!A;&P@;F5C97-S
M87)Y"B`@('!R97)E<75I<VET97,@:&%V92!B965N(&UE="X@268@>6]U(&EN
M<W1A;&QE9"!(;W)D92!A<R!D97-C<FEB960@86)O=F4L('1H90H@("!54DP@
M=&\@=&AE('1E<W0@<&%G92!W;W5L9"!B93HZ"@H@("`@("!H='1P.B\O>6]U
M<BUS97)V97(O:&]R9&4O=&5S="YP:'`*"B`@($-H96-K('1H870@>6]U<B!0
M2%`@86YD(%!%05(@=F5R<VEO;G,@87)E(&%C8V5P=&%B;'D@<F5C96YT+"!T
M:&%T(&%L;`H@("!R97%U:7)E9"!M;V1U;&4@8V%P86)I;&ET:65S(&%R92!P
M<F5S96YT+"!A;F0@=&AA="!@8&UA9VEC7W%U;W1E<U]R=6YT:6UE8&`*("`@
M:7,@<V5T('1O(&!@3V9F8&`N(%1H96X@;F]T92!T:&4@8&!397-S:6]N(&-O
M=6YT97(Z(#%@8"!L:6YE('5N9&5R(&!@4$A0"B`@(%-E<W-I;VYS8&`L(&%N
M9"!R96QO860@=&AE('!A9V4N(%1H92!S97-S:6]N(&-O=6YT97(@<VAO=6QD
M(&EN8W)E;65N="X*"B`@($EF('EO=2!G970@82!W87)N:6YG(&QI:V4@8&!&
M86EL960@;W!E;FEN9R`G+W!A=&@O=&\O=&5S="YP:'`G(&9O<@H@("!I;F-L
M=7-I;VY@8"P@;6%K92!S=7)E('1H870@=&AE('=E8B!S97)V97(@:&%S('1H
M92!P97)M:7-S:6]N('1O(')E860@=&AE"B`@('1E<W0N<&AP(&9I;&4N"@HU
M+B!#;VUP;&5T:6YG($-O;F9I9W5R871I;VX*"B`@(%EO=2!C86X@;F]W(&%C
M8V5S<R!(;W)D92!W:71H;W5T(&$@<&%S<W=O<F0L(&%N9"!Y;W4@=VEL;"!B
M92!L;V=G960@:6X@87,*("`@86X@861M:6YI<W1R871O<BX@66]U('-H;W5L
M9"!F:7)S="!C;VYF:6=U<F4@82!R96%L(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0N"B`@($-L:6-K(&]N(&!@4V5T=7!@8"!I;B!T:&4@8&!!9&UI;FES=')A
M=&EO;F!@(&UE;G4@86YD(&-O;F9I9W5R90H@("!(;W)D92X@(%-T87)T(&EN
M('1H92!@8$%U=&AE;G1I8V%T:6]N8&`@=&%B+@H*("`@2&5R92!I<R!A;B!E
M>&%M<&QE(&9O<B!C;VYF:6=U<FEN9R!A=71H96YT:6-A=&EO;B!A9V%I;G-T
M(&$@<F5M;W1E($E-05`*("`@<V5R=F5R+B`@4VEM:6QA<B!S=&5P<R!A<'!L
M>2!F;W(@875T:&5N=&EC871I;F<@86=A:6YS="!A(&1A=&%B87-E+"!A;B!,
M1$%0"B`@('-E<G9E<BP@971C+@H*("`@82X@26X@=&AE(&!@5VAI8V@@=7-E
M<G,@<VAO=6QD(&)E('1R96%T960@87,@861M:6YI<W1R871O<G-@8"!F:65L
M9"!E;G1E<B!A"B`@("`@(&-O;6UA('-E<&%R871E9"!L:7-T(&]F('5S97(@
M;F%M97,@;V8@>6]U<B!C:&]O<VEN9RX@(%1H:7,@=VEL;"!C;VYT<F]L"B`@
M("`@('=H;R!I<R!A;&QO=V5D('1O(&UA:V4@8V]N9FEG=7)A=&EO;B!C:&%N
M9V5S+"!S964@<&%S<W=O<F1S+"!P;W1E;G1I86QL>0H@("`@("!A9&0@=7-E
M<G,L(&5T8RX*"B`@(&(N($EN('1H92!@8%=H870@8F%C:V5N9"!S:&]U;&0@
M=V4@=7-E(&9O<B!A=71H96YT:6-A=&EN9R!U<V5R<R!T;R!(;W)D96!@"B`@
M("`@('!U;&QD;W=N(&UE;G4@<V5L96-T(&!@24U!4"!A=71H96YT:6-A=&EO
M;F!@+B`@5&AE('!A9V4@=VEL;"!R96QO860@86YD"B`@("`@('EO=2!W:6QL
M(&AA=F4@<W!E8VEF:6,@;W!T:6]N<R!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX*"B`@(&,N($EN('1H92!@8$-O;F9I9W5R871I;VX@='EP96!@('!U;&QD
M;W=N(&UE;G4@<V5L96-T(&!@4V5P87)A=&4@=F%L=65S8&`N"B`@("`@(%1H
M92!P86=E('=I;&P@<F5L;V%D('=I=&@@861D:71I;VYA;"!O<'1I;VYS+B`@
M1FEL;"!I;B!T:&4@<F5M86EN:6YG"B`@("`@('1H<F5E(&9I96QD<R!A<'!R
M;W!R:6%T96QY.@H*("`@("`@+2!)4"!N86UE+VYU;6)E<B!O9B!T:&4@24U!
M4"!S97)V97(*("`@("`@+2!&;W(@82!S96-U<F4@8V]N;F5C=&EO;BP@<V5L
M96-T('!O<G0@.3DS+@H@("`@("`M(%-E;&5C="!T:&4@<')O=&]C;VP[(&9O
M<B!A('-E8W5R92!C;VYN96-T:6]N(&5I=&AE<B!@8&EM87`O<W-L8&`@;W(*
M("`@("`@("!@8&EM87`O<W-L+VYO=F%L:61A=&4M8V5R=&!@("AF;W(@<V5L
M9BUS:6=N960@8V5R=&EF:6-A=&5S*2X*"B`@($-O;G1I;G5E('1O(&-O;F9I
M9W5R92!(;W)D92!T:')O=6=H(&%L;"!T:&4@=&%B<R!O9B!T:&4@<V5T=7`@
M:6YT97)F86-E(&%N9`H@("!C;&EC:R!O;B!@8$=E;F5R871E($AO<F1E($-O
M;F9I9W5R871I;VY@8"X@($EM<&]R=&%N="!I=&5M<R!T:&%T('EO=0H@("!P
M<F]B86)L>2!W86YT('1O(&-O;F9I9W5R92!A<F4@=&AE(&!@4')E9F5R96YC
M92!3>7-T96U@8"!T:&%T(&QE=',@=7-E<G,*("`@<V%V92!T:&5I<B!P97)S
M;VYA;"!O<'1I;VYS+"!A;F0@=&AE(&!@1&%T851R964@4WES=&5M8&`@=&AA
M="!I<R!R97%U:7)E9`H@("!F;W(@<V]M92!A<'!L:6-A=&EO;G,@=&\@=V]R
M:R!A="!A;&PN"@H@("!#;VYF:6=U<F%T:6]N(&]F(&%P<&QI8V%T:6]N<R!I
M;B!@8')E9VES=')Y+G!H<&!@(&ES(&1O8W5M96YT960@:6X@=&AE"B`@(&!@
M24Y35$%,3&!@(&9I;&4@;V8@96%C:"!A<'!L:6-A=&EO;BX@($UO<W0@87!P
M;&EC871I;VYS(')E<75I<F4@>6]U('1O"B`@(&-O;F9I9W5R92!T:&5M('=I
M=&@@82`B2&]R9&4@861M:6YI<W1R871O<B(@86-C;W5N="X@($$@2&]R9&4@
M861M:6YI<W1R871O<@H@("!A8V-O=6YT(&ES(&%N>2!N;W)M86P@2&]R9&4@
M86-C;W5N="!T:&%T(&AA<R!B965N(&%D9&5D('1O('1H90H@("!A9&UI;FES
M=')A=&]R(&QI<W0@:6X@=&AE(&!@075T:&5N=&EC871I;VY@8"!T86(@;V8@
M=&AE($AO<F1E('-E='5P+@H*("`@5&AE(&]T:&5R(&9I;&5S(&EN('1H870@
M9&ER96-T;W)Y(&YE960@;VYL>2!B92!M;V1I9FEE9"!I9B!Y;W4@=VES:"!T
M;PH@("!C=7-T;VUI>F4@2&]R9&4G<R!A<'!E87)A;F-E(&]R(&)E:&%V:6]U
M<B`M+2!T:&4@9&5F875L=',@=VEL;"!W;W)K(&%T(&UO<W0*("`@<VET97,N
M"@H@("`N+B!?=')A;G-L871I;VYS.@H*("`@3F]T92!F;W(@:6YT97)N871I
M;VYA;"!U<V5R<SH@2&]R9&4@=7-E<R!'3E4@9V5T=&5X="!T;R!P<F]V:61E
M(&QO8V%L"B`@('1R86YS;&%T:6]N<R!O9B!T97AT(&1I<W!L87EE9"!B>2!A
M<'!L:6-A=&EO;G,[('1H92!T<F%N<VQA=&EO;G,@87)E(&9O=6YD"B`@(&EN
M('1H92!P;R\@9&ER96-T;W)Y+B`@268@82!T<F%N<VQA=&EO;B!I<R!N;W0@
M>65T(&%V86EL86)L92!F;W(@>6]U<@H@("!L;V-A;&4@*&%N9"!Y;W4@=VES
M:"!T;R!C<F5A=&4@;VYE*2P@<V5E('1H92!@8&AO<F1E+W!O+U)%041-16!@
M(&9I;&4L(&]R"B`@(&EF('EO=2=R92!H879I;F<@=')O=6)L92!U<VEN9R!A
M('!R;W9I9&5D('1R86YS;&%T:6]N+"!P;&5A<V4@<V5E('1H90H@("!@:&]R
M9&4O9&]C<R]44D%.4TQ!5$E/3E-@7R!F:6QE(&9O<B!I;G-T<G5C=&EO;G,N
M"@HV+B!396-U<FEN9R!(;W)D90H*("`@82X@4&%S<W=O<F1S"@H@("`@("!3
M;VUE(&]F($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!C;VYT86EN('!A
M<W-W;W)D<R!W:&EC:"!L;V-A;"!U<V5R<PH@("`@("!C;W5L9"!U<V4@=&\@
M86-C97-S('EO=7(@9&%T86)A<V4N("!)="!I<R!R96-O;6UE;F1E9"!T;R!E
M;G-U<F4@=&AA="!A=`H@("`@("!L96%S="!T:&4@2&]R9&4@8V]N9FEG=7)A
M=&EO;B!F:6QE<R`H:6X@8&!C;VYF:6<O8&`I(&%R92!N;W0@<F5A9&%B;&4@
M=&\*("`@("`@<WES=&5M('5S97)S+B`@5&AE<F4@87)E(&!@+FAT86-C97-S
M8&`@9FEL97,@<F5S=')I8W1I;F<@86-C97-S('1O"B`@("`@(&1I<F5C=&]R
M:65S('1H870@9&\@;F]T(&YE960@=&\@8F4@86-C97-S960@9&ER96-T;'D[
M(&)E9F]R92!R96QY:6YG(&]N"B`@("`@('1H;W-E+"!E;G-U<F4@=&AA="!Y
M;W5R('=E8G-E<G9E<B!S=7!P;W)T<R!@8"YH=&%C8V5S<V!@(&%N9"!I<PH@
M("`@("!C;VYF:6=U<F5D('1O('5S92!T:&5M+"!A;F0@=&AA="!T:&4@9FEL
M97,@:6X@=&AO<V4@9&ER96-T;W)I97,@87)E(&EN"B`@("`@(&9A8W0@:6YA
M8V-E<W-I8FQE('9I82!T:&4@8G)O=W-E<BX*"B`@("`@($%N(&%D9&ET:6]N
M86P@87!P<F]A8V@@:7,@=&\@;6%K92!(;W)D92=S(&-O;F9I9W5R871I;VX@
M9FEL97,@;W=N960@8GD*("`@("`@=&AE('5S97(@8&!R;V]T8&`@86YD(&)Y
M(&$@9W)O=7`@=VAI8V@@;VYL>2!T:&4@=V5B<V5R=F5R('5S97(@8F5L;VYG
M<PH@("`@("!T;RP@86YD('1H96X@;6%K:6YG('1H96T@<F5A9&%B;&4@;VYL
M>2!T;R!O=VYE<B!A;F0@9W)O=7`N("!&;W(@97AA;7!L92P*("`@("`@:68@
M>6]U<B!W96)S97)V97(@<G5N<R!A<R!@8'=W=RYW=W=@8"P@9&\@87,@9F]L
M;&]W<SHZ"@H@("`@("`@("!C:&]W;B!R;V]T+G=W=R!C;VYF:6<O*@H@("`@
M("`@("!C:&UO9"`P-#0P(&-O;F9I9R\J"@H@("!B+B!397-S:6]N<PH*("`@
M("`@4V5S<VEO;B!D871A("TM(&EN8VQU9&EN9R!H87-H960@=F5R<VEO;G,@
M;V8@>6]U<B!U<V5R<R<@<&%S<W=O<F1S+"!I;@H@("`@("!S;VUE(&%P<&QI
M8V%T:6]N<R`M+2!M87D@;F]T(&)E('-T;W)E9"!A<R!S96-U<F5L>2!A<R!N
M96-E<W-A<GDN"@H@("`@("!)9B!Y;W4@87)E('5S:6YG(&9I;&4M8F%S960@
M4$A0('-E<W-I;VYS("AW:&EC:"!A<F4@=&AE(&1E9F%U;'0I+"!B90H@("`@
M("!S=7)E('1H870@<V5S<VEO;B!F:6QE<R!A<F4@;F]T(&)E:6YG('=R:71T
M96X@:6YT;R!@8"]T;7!@8"!W:71H"B`@("`@('!E<FUI<W-I;VYS('1H870@
M86QL;W<@;W1H97(@=7-E<G,@=&\@<F5A9"!T:&5M+B!)9&5A;&QY+"!C:&%N
M9V4@=&AE"B`@("`@(&!@<V5S<VEO;BYS879E7W!A=&A@8"!S971T:6YG(&EN
M(&!@<&AP+FEN:6!@('1O(&$@9&ER96-T;W)Y(&]N;'D*("`@("`@<F5A9&%B
M;&4@86YD('=R:71E86)L92!B>2!Y;W5R('=E8G-E<G9E<BX*"B`@("`@($%D
M9&ET:6]N86QL>2P@>6]U(&-A;B!C:&%N9V4@=&AE('-E<W-I;VX@:&%N9&QE
M<B!O9B!02%`@=&\@=7-E(&%N>0H@("`@("!S=&]R86=E(&)A8VME;F0@<F5Q
M=65S=&5D("AE+F<N(%-13"!D871A8F%S92D@=FEA('1H92!@8$-U<W1O;2!3
M97-S:6]N"B`@("`@($AA;F1L97)@8"!T86(@:6X@=&AE($AO<F1E('-E='5P
M+@H*-RX@16YT97)I;F<@=&AE('-U<G9E>0H*("`@268@>6]U(&QI:V4L(&=O
M('1O(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W-U<G9E>2\@86YD(&5N=&5R('1H
M92!D971A:6QS(&]F"B`@('EO=7(@<WES=&5M+@H*"D-O;F9I9W5R:6YG($%P
M<&QI8V%T:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"D$@;&ES="!O
M9B!A=F%I;&%B;&4@2&]R9&4@87!P;&EC871I;VYS(&-A;B!B92!F;W5N9"!A
M=`H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O<')O:F5C=',N<&AP"@I);G-T
M<G5C=&EO;G,@;VX@8V]N9FEG=7)I;F<@2&]R9&4@87!P;&EC871I;VYS(&-A
M;B!B92!F;W5N9"!I;B!T:&4@8&!)3E-404Q,8&`*9FEL92!I;B!T:&4@87!P
M;&EC871I;VXG<R!@8&1O8W,O8&`@9&ER96-T;W)Y+@H*"E1E;7!O<F%R>2!&
M:6QE<PH]/3T]/3T]/3T]/3T]/3T*"E9A<FEO=7,@2&]R9&4@87!P;&EC871I
M;VYS('=I;&P@9V5N97)A=&4@=&5M<&]R87)Y(&9I;&5S(&EN(%!(4"=S('1E
M;7!O<F%R>0ID:7)E8W1O<GD@*'-E92!T:&4@8&!'96YE<F%L8&`@=&%B(&EN
M('1H92!(;W)D92!S971U<"DN("!&;W(@=F%R:6]U<R!R96%S;VYS+`IS;VUE
M(&]F('1H97-E(&9I;&5S(&UA>2!N;W0@8F4@<F5M;W9E9"!W:&5N('1H92!U
M<V5R)W,@<V5S<VEO;B!E;F1S+B!4;PIR96-L86EM('1H:7,@9&ES:R!S<&%C
M92P@:70@;6%Y(&)E(&YE8V5S<V%R>2!T;R!P97)I;V1I8V%L;'D@9&5L971E
M('1H97-E(&]L9`IT96UP;W)A<GD@9FEL97,N"@I!;B!E>&%M<&QE(&-R;VXM
M8F%S960@<V]L=71I;VX@8V%N(&)E(&9O=6YD(&%T(&!@<V-R:7!T<R]T96UP
M+6-L96%N=7`N8W)O;F!@+@I!;F]T:&5R('!O<W-I8FQE('-O;'5T:6]N(&ES
M('1O('5S92!2960@2&%T)W,@8&!T;7!W871C:&!@('5T:6QI='D@=&\@<F5M
M;W9E"F]L9"!F:6QE<R`H<V5E(&AT='`Z+R]W=W<N<F5D:&%T+F-O;2\I+@H*
M"D]B=&%I;FEN9R!3=7!P;W)T"CT]/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W4@
M96YC;W5N=&5R('!R;V)L96US('=I=&@@2&]R9&4L(&AE;'`@:7,@879A:6QA
M8FQE(0H*5&AE($AO<F1E($9R97%U96YT;'D@07-K960@475E<W1I;VYS($QI
M<W0@*$9!42DL(&%V86EL86)L92!O;B!T:&4@5V5B(&%T"@H@(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+V9A<2\*"E1H92!(;W)D92!0<F]J96-T(')U;G,@82!N
M=6UB97(@;V8@;6%I;&EN9R!L:7-T<RP@9F]R(&EN9&EV:61U86P@87!P;&EC
M871I;VYS"F%N9"!F;W(@:7-S=65S(')E;&%T:6YG('1O('1H92!P<F]J96-T
M(&%S(&$@=VAO;&4N("!);F9O<FUA=&EO;BP@87)C:&EV97,L(&%N9`IS=6)S
M8W)I<'1I;VX@:6YF;W)M871I;VX@8V%N(&)E(&9O=6YD(&%T"@H@(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VUA:6PO"@I&:6YA;&QY+"!(;W)D92!D979E;&]P
M97)S+"!C;VYT<FEB=71O<G,@86YD('5S97)S(&%L<V\@;6%K92!O8V-A<VEO
M;F%L"F%P<&5A<F%N8V5S(&]N($E20RP@;VX@=&AE(&-H86YN96P@(VAO<F1E
M(&]N('1H92!F<F5E;F]D92!.971W;W)K"BAI<F,N9G)E96YO9&4N;F5T*2X*
M"E!L96%S92!K965P(&EN(&UI;F0@=&AA="!(;W)D92!I<R!F<F5E('-O9G1W
M87)E('=R:71T96X@8GD@=F]L=6YT965R<RX*1F]R(&EN9F]R;6%T:6]N(&]N
M(')E87-O;F%B;&4@<W5P<&]R="!E>'!E8W1A=&EO;G,L('!L96%S92!R96%D
M"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W-U<'!O<G0N<&AP"@I4:&%N:W,@
M9F]R('5S:6YG($AO<F1E(0H*5&AE($AO<F1E(%1E86T*"@HN+B!?9&]C<R](
M04-+24Y'.B`_9CU(04-+24Y'+FAT;6P*+BX@7V!H;W)D92]D;V-S+U1204Y3
M3$%424].4V`Z(#]F/51204Y33$%424].4RYH=&UL"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+V1O8W,O4$521D]234%.0T4`````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,34Q-3,`,3`T,3<S-C(W-#,`,#$W,#0Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*($AO<F1E(%!E<F9O<FUA;F-E($=U:61E"CT]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T
M93H@,C`P-B\P,R\P-B`R,CHQ,SHQ,2`D"CI2979I<VEO;CH@("`@("`D4F5V
M:7-I;VXZ(#$N.2XQ,"XQ,B`D"CI#;VYT86-T.B`@("`@("!H;W)D94!L:7-T
M<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*"@I3;VUE('1I
M<',@;VX@<&5R9F]R;6%N8V4@='5N:6YG('-Y<W1E;7,@9F]R($AO<F1E+B`@
M5&AI<R!D;V5S(&YO="!C;W9E<@IH87)D=V%R92!T=6YI;F<@;W(@979E;B!L
M;W<@;&5V96P@<WES=&5M("AN971W;W)K+"!F:6QE<WES=&5M+"!E=&,I('1U
M;FEN9RX*"D1O;B=T(&%P<&QY('1H92!F;VQL;W=I;F<@='5N:6YG(&AI;G1S
M(&)L:6YD;'DN("!497-T('EO=7(@87!P;&EC871I;VYS(&)E9F]R90IA;F0@
M869T97(@=&AE(&-H86YG97,@=6YD97(@=&AE(&-O;F1I=&EO;G,@=&AA="!A
M<F4@:6UP;W)T86YT(&9O<B!Y;W4N("!&;W(*<V]M92!P96]P;&4@:70G<R!M
M;W)E(&EM<&]R=&%N="!T;R!M86ME('1H96T@87,@9F%S="!A<R!P;W-S:6)L
M92!F;W(@82!S;6%L;`IU<V5R(&)A<V4L(&]T:&5R<R!R97%U:7)E('1H92!A
M<'!L:6-A=&EO;G,@=&\@<V-A;&4@=V5L;"!U;F1E<B!A(&AI9V@@;&]A9"X*
M4V]M92!O9B!T:&5S92!H:6YT<R!M:6=H="!E=F5N(&UA:V4@=&AE(&%P<&QI
M8V%T:6]N<R!S;&]W97(@=6YD97(@8V5R=&%I;@IC;VYD:71I;VYS(&]R('5S
M:6YG(&$@8V5R=&%I;B!H87)D=V%R92X*"@I,:6YU>"!4=6YI;F<*/3T]/3T]
M/3T]/3T]"@HJ(%)E8V]M<&EL92!24$U3(&9O<B!Y;W5R(&%R8VAI=&5C='5R
M92`H92YG+B!I-3@V+"!I-C@V+"!A=&AL;VXL(&5T8RDN"B`@5&AI<R!A<'!L
M:65S(&UO<W0@=&\@>6]U<B!!<&%C:&4L(%!(4"P@24U!4"P@86YD(%!/4#,@
M<&%C:V%G97,N"@H*07!A8VAE+U!(4"!T=6YI;F<*/3T]/3T]/3T]/3T]/3T]
M/3T*"BH@0V]N<VED97(@82!02%`@86-C96QE<F%T;W(@<')O9W)A;2X@(%-E
M92!F;W(@97AA;7!L92!@5&AE(%IE;F0@4&5R9F]R;6%N8V4*("!3=6ET96!?
M+"!4:&4@8&EO;D-U8F4@4$A0($%C8V5L97)A=&]R8%\L(&!4=7)C:R!-34-A
M8VAE(&9O<B!02%!@7RP@;W(*("!E06-C96QE<F%T;W)?+B`@5&AE<V4@86-C
M96QE<F%T;W)S('-P965D('5P(&%C8V5S<R!B>2!C86-H:6YG('1H92!C;VUP
M:6QE9`H@(%!(4"!C;V1E+"!E;&EM:6YA=&EN9R!T:&4@;F5E9"!T;R!R96-O
M;7!I;&4@=&AE(&-O9&4@9F]R(&5V97)Y('-I;F=L92!P86=E"B`@;&]A9"X@
M("HJ5&AI<R!I<R!P<F]B86)L>2!T:&4@96%S:65S="!W87D@=&\@:6UP<F]V
M92!T:&4@<&5R9F]R;6%N8V4@;V8*("!(;W)D92HJ+B`@268@=7-I;F<@5'5R
M8VL@34U#86-H92P@*BI03$5!4T4J*B!R96%D(&!4=7)C:R!-34-A8VAE"B`@
M5')O=6)L97-H;V]T:6YG8%\N"@HJ($-O;7!I;&4@4$A0('=I=&@@=&AE(&!@
M+2UE;F%B;&4M:6YL:6YE+6]P=&EM:7IA=&EO;F!@(&]P=&EO;B!T;R!G96YE
M<F%T92!T:&4*("!F87-T97-T('!O<W-I8FQE(%!(4"!E>&5C=71A8FQE+@H*
M*B!5<V4@;V8@=&AE(&UC<GEP="!02%`@97AT96YS:6]N('-H;W5L9"!S:6=N
M:69I8V%N=&QY(&EN8W)E87-E('!E<F9O<FUA;F-E"B`@=VAI;&4@86QS;R!I
M;F-R96%S:6YG('-E8W5R:71Y+@H**B!%;F%B;&4@4$A0(&]U='!U="!C;VUP
M<F5S<VEO;B`H96ET:&5R(&EN(&!@<&AP+FEN:6!@(&]R"B`@8&!H;W)D92]C
M;VYF:6<O8V]N9BYP:'!@8"DN"@HJ($1I<V%B;&4@=&AE(&UE;6]R>2!L:6UI
M="!I;B!@8'!H<"YI;FE@8"X*"BH@2V5E<"!T:&4@:6YC;'5D92!P871H(&1E
M9FEN960@:6X@8&!P:'`N:6YI8&`@87,@<VAO<G0@87,@<&]S<VEB;&4L('=I
M=&@@=&AE"B`@;6]S="!F<F5Q=65N=&QY('5S960@;&EB<F%R>2!P871H<R!F
M:7)S="X@(%EO=2!D;VXG="!N965D('1O(&EN8VQU9&4@=&AE"B`@;&]C86P@
M9&ER96-T;W)Y(&!@+F!@(&)E8V%U<V4@2&]R9&4@86QW87ES('5S97,@9G5L
M;"!P871H<R!I;G-T96%D(&]F"B`@<F5L871I=F4@<&%T:',N"@HJ(%5S92!A
M;B!O<'1I;6EZ960@8&!P:'`N:6YI8&`L('-T87)T(&9R;VT@8&!P:'`N:6YI
M+7)E8V]M;65N9&5D8&`@;V8@>6]U<B!02%`*("!D<VET<FEB=71I;VXN"@HJ
M($1O;B=T(')U;B!02%`@<V5S<VEO;B!G87)B86=E(&-O;&QE8W1I;VX@=&]O
M(&]F=&5N(&EF('5S:6YG(&$@<VQO=R!S=&]R86=E"B`@;65D:75M("AL:6ME
M(%-13"DN("A3964@8&!S97-S:6]N+F=C7W!R;V)A8FEL:71Y8&`@:6X@8&!P
M:'`N:6YI8&`I"@HJ($EF('EO=2!H879E(&$@;&%R9V4@;G5M8F5R(&]F('-E
M<W-I;VYS+"!C;VYS:61E<B!S=&]R:6YG('1H96T@:6X@:&%S:&5D"B`@9&ER
M96-T;W)Y(&QE=F5L<RX@*%-E92!@8'-E<W-I;VXN<V%V95]P871H8&`@870@
M:'1T<#HO+W=W=RYP:'`N;F5T+W-E<W-I;VXI"@HJ($-O;G-I9&5R('5S:6YG
M(&$@9F%S=&5R('-T;W)A9V4@;65D:75M(&9O<B!S97-S:6]N<RP@<W5C:"!A
M<R!A('1M<&9S(&]R"B`@;W1H97(@;65M;W)Y(&)A<V5D(&9I;&4@<WES=&5M
M+B`@268@>6]U(&%R92!S=7)E('EO=7(@87!A8VAE('-E='5P(&ES(')O8VL*
M("!S;VQI9"!A;F0@>6]U(&1O;B=T(')E<W1A<G0@:70@=&AE<F4@:7,@82!M
M;2!S97-S:6]N(&1R:79E<BX@($AO=V5V97(L(&)E"B`@87=A<F4@=&AA="!C
M97)T86EN($AO<F1E(&%P<&QI8V%T:6]N<R`H;&EK92!)35`I(&UA:V4@:&5A
M=GD@=7-E(&]F(&-A8VAI;F<*("!D871A(&EN('-E<W-I;VYS('-O(&UE;6]R
M>2!B87-E9"!S;VQU=&EO;G,@;6%Y(&)E(&5X:&%U<W1E9"!Q=6EC:VQY+`H@
M('!A<G1I8W5L87)L>2!I9B!T:&5R92!W:6QL(&)E(&UO<F4@=&AA;B!A('-I
M;F=L92!U<V5R+@H**B!/;FQY(&QO860@87,@;6%N>2!!<&%C:&4@86YD(%!(
M4"!E>'1E;G-I;VYS(&%S(&YE961E9"`H=&\@<F5D=6-E(&UE;6]R>0H@('5S
M86=E*2X*"BH@57-E('-T871I8V%L;'D@8V]M<&EL960@07!A8VAE(&UO9'5L
M97,L(&EN8VQU9&EN9R!T:&4@4$A0(&UO9'5L92X*"BH@57-E(&-O;7!I;&5R
M(&]P=&EM:7IA=&EO;G,@*"TM<')E9F5R+6YO;BUP:6,L("U/,RP@+6UA<F-H
M("UM8W!U+"`M;7-S92P*("`M;6UM>"P@+6UF<&UA=&@]<W-E+"!E=&,N*0H*
M*B!)9B!U<VEN9R!34TP@=VET:"!A(&QA<F=E('-I=&4L(&-O;G-I9&5R(&$@
M:&%R9'=A<F4@4U-,(&%C8V5L97)A=&]R+@H**B!5<V4@<VAA<F5D(&UE;6]R
M>2!F;W(@=&AE($%P86-H92!34TP@8V%C:&4@:68@<&]S<VEB;&4N"@HJ(%1O
M(&EM<')O=F4@8V%C:&EN9R!O9B!S=&%T:6,@8V]N=&5N="!I9B!A8V-E<W-I
M;F<@07!A8VAE(%-33"!W:71H($EN=&5R;F5T"B`@17AP;&]R97(L('1R>2!S
M971T:6YG(&QO;F=E<B!E>'!I<F%T:6]N('!E<FEO9',Z.@H*("`@($5X<&ER
M97-!8W1I=F4@3VX*("`@($5X<&ER97-">51Y<&4@:6UA9V4O<&YG(")N;W<@
M<&QU<R`Q(&UO;G1H(@H@("`@17AP:7)E<T)Y5'EP92!I;6%G92]G:68@(FYO
M=R!P;'5S(#$@;6]N=&@B"B`@("!%>'!I<F5S0GE4>7!E('1E>'0O:F%V87-C
M<FEP="`B;F]W('!L=7,@,2!M;VYT:"(*("`@($5X<&ER97-">51Y<&4@87!P
M;&EC871I;VXO>"UJ879A<V-R:7!T(")N;W<@<&QU<R`Q(&UO;G1H(@H@("`@
M17AP:7)E<T)Y5'EP92!T97AT+V-S<R`B;F]W('!L=7,@,2!M;VYT:"(*"B`@
M+BX@3F]T93HZ(%EO=2!M=7-T(&-O;7!I;&4@=&AE(&!@;6]D7V5X<&ER97-@
M8"!E>'1E;G-I;VX@:6YT;R!!<&%C:&4@:6X*("`@("`@("`@("`@;W)D97(@
M=&\@=7-E('1H97-E(&1I<F5C=&EV97,N"@H@("XN(%=A<FYI;F<Z.B!4:&ES
M(&UI9VAT(&-A=7-E('!R;V)L96US(&EF('EO=2!U<&=R861E($AO<F1E(&%N
M9"!T:&4@=7-E<G,G"B`@("`@("`@("`@("`@(&)R;W=S97)S('-T:6QL('5S
M92!T:&4@;VQD(&9I;&4@=F5R<VEO;G,N"@HJ($1I<V%B;&4@1$Y3(&QO;VMU
M<',@:6X@>6]U<B!!<&%C:&4@;&]G9VEN9RP@;W(@=7-E(&$@8V%C:&EN9R!$
M3E,@<V5R=F5R(&]N"B`@=&AE('=E8B!S97)V97(@:&]S="X*"BH@16YA8FQE
M($%P86-H92!K965P86QI=F5S+@H*+BX@7V!4:&4@6F5N9"!097)F;W)M86YC
M92!3=6ET96`Z(&AT='`Z+R]W=W<N>F5N9"YC;VTO:&]R9&4N<&AP"BXN(%]@
M:6]N0W5B92!02%`@06-C96QE<F%T;W)@.B!H='1P.B\O=W=W+G!H<"UA8V-E
M;&5R871O<BYC;RYU:PHN+B!?8%1U<F-K($U-0V%C:&4@9F]R(%!(4&`Z(&AT
M='`Z+R]T=7)C:RUM;6-A8VAE+G-O=7)C969O<F=E+FYE=`HN+B!?94%C8V5L
M97)A=&]R.B!H='1P.B\O96%C8V5L97)A=&]R+FYE=`HN+B!?8%1U<F-K($U-
M0V%C:&4@5')O=6)L97-H;V]T:6YG8#H@:'1T<#HO+W=I:VDN:&]R9&4N;W)G
M+V1I<W!L87DN<&AP/W!A9V4]5'5R8VM-34-A8VAE5')O=6)L97-H;V]T:6YG
M"@H*4V5N9&EN9R!-86EL"CT]/3T]/3T]/3T]/0H**B!'96YE<F%L;'D@=7-I
M;F<@82!L;V-A;"!S96YD;6%I;"!C;VUM86YD('1O('-E;F0@;6%I;"!W:6QL
M(')E<W5L="!I;B!B971T97(*("!P969O<FUA;F-E('1H86X@=7-I;F<@82!3
M3510(&-O;FYE8W1I;VXN"@HJ(%-O;64@351!('-E<G9E<G,@;6%Y(&)E(&9A
M<W1E<B!O<B!M;W)E(&5F9FEC:65N="!T:&%N(&]T:&5R<RX@($-O;G-I9&5R
M"B`@<W=I=&-H:6YG('1O(&$@9F%S=&5R(&9O<FUA="!I9B!N965D960N"@H*
M24U!4"!T=6YI;F<*/3T]/3T]/3T]/3T*"BH@0V]N<VED97(@86X@24U!4"!P
M<F]X>2!F;W(@;6]R92!P97)S:7-T96YT(&-O;FYE8W1I;VYS+B`@4V]M92!)
M34%0('!R;WAI97,*("!A<F4@=7`M:6UA<'!R;WAY7R!A;F0@4&5R9&ET:6]N
M7RX@(%1O(&UA:V4@<V5N<V4L('1H92!P<F]X>0H@('-H;W5L9"!B92!I;G-T
M86QL960@;VX@=&AE('-E<G9E<B!R=6YN:6YG($AO<F1E+"!A;F0@=&AI<R!S
M97)V97(@;F5E9',*("!E;F]U9V@@0U!5('!O=V5R('1O(&AA;F1L92!T:&4@
M861D:71I;VYA;"!L;V%D+@H**B!3;VUE($E-05`@<V5R=F5R<R`H;W(@24U!
M4"!M86EL8F]X('-T;W)E(&9O<FUA=',I('!E<F9O<FT@8F5T=&5R('1H86X*
M("!O=&AE<G,N("!#;VYS:61E<B!S=VET8VAI;F<@=&\@82!F87-T97(@9F]R
M;6%T(&EF(&YE961E9"X*"BH@1F]L;&]W('1H92!)34%0('-E<G9E<G,G('!E
M<F9O<FUA;F-E(&AI;G1S.@H*("`M($-Y<G5S.B!H='1P.B\O87-G+G=E8BYC
M;74N961U+V-Y<G5S+V1O=VYL;V%D+VEM87!D+VEN<W1A;&PM<&5R9BYH=&UL
M"@HN+B!?=7`M:6UA<'!R;WAY.B!H='1P.B\O=W=W+FEM87!P<F]X>2YO<F<O
M"BXN(%]097)D:71I;VXZ(&AT='`Z+R]W=W<N=F5R9V5N970N;F5T+VQI;G5X
M+W!E<F1I=&EO;B\*"@I0;W-T9W)E<W%L('1U;FEN9PH]/3T]/3T]/3T]/3T]
M/3T]/0H**B!$;R!A('9A8W5U;2!C;VUM86YD('!E<FEO9&EC86QL>2!T;R!T
M=6YE('EO=7(@9&%T86)A<V4*"BH@26YC<F5A<V4@8&!S:&%R961?8G5F9F5R
M<V!@(&%N9"!@8'-O<G1?;65M8&`@;65M;W)Y('-E='1I;F=S+@H**B!)9B!W
M96(@<V5R=F5R(&%N9"!D871A8F%S92!I<R!O;B!T:&4@<V%M92!U;FEX(&AO
M<W0L('5S92!U;FEX('-O8VME=',*("!I;G-T96%D(&]F(&YE='=O<FL@8V]N
M;F5C=&EO;G,@9F]R(&1A=&%B87-E(&%C8V5S<RX*"@I->5-13"!T=6YI;F<*
M/3T]/3T]/3T]/3T]"@HJ($EF('=E8B!S97)V97(@86YD(&1A=&%B87-E(&ES
M(&]N('1H92!S86UE('5N:7@@:&]S="P@=7-E('5N:7@@<V]C:V5T<PH@(&EN
M<W1E860@;V8@;F5T=V]R:R!C;VYN96-T:6]N<R!F;W(@9&%T86)A<V4@86-C
M97-S+@H**B!%;F%B;&4@;7ES<6P@<75E<GD@8V%C:&4@:68@>6]U(&AA=F4@
M<W5F9FEC:65N="!204TN("!%9&ET('EO=7(@8&!M>2YC;F9@8`H@(&9I;&4@
M86YD(&%D9"!T:&4@9F]L;&]W:6YG('1O('1H92!@8%MM>7-Q;&1=8&`@<V5C
M=&EO;B`H8VAA;F=E('1H92!M96UO<GD*("!S:7IE('1O(&UE970@>6]U<B!N
M965D<RDZ.@H*("`@('-E="UV87)I86)L92`]('%U97)Y7V-A8VAE7W-I>F4]
M,3(X30H*"DAO<F1E('1U;FEN9PH]/3T]/3T]/3T]/3T*"BH@66]U(&-A;B!C
M;VYF:6=U<F4@2&]R9&4@=&\@<V5R=F4@86QL(&EM86=E<R!A;F0@<W1Y;&4@
M<VAE971S(&9R;VT@80H@(&1I9F9E<F5N="!S97)V97(N(%1H:7,@8V]U;&0@
M8F4@82!V97)Y(&QI9VAT=V5I9VAT('-E<G9E<B!W:71H;W5T(&%L;"!T:&4*
M("!O=F5R:&5A9"!F;W(@<')O8V5S<VEN9R!02%`@9FEL97,L(&QI:V4@;&EG
M:'1T<&0N(%EO=2!N965D('1O('-E="!T:&4*("!@8'1H96UE<W5R:6!@('!A
M<F%M971E<B!I;B!@8&-O;F9I9R]R96=I<W1R>2YP:'!@8"!F;W(@86QL(&%P
M<&QI8V%T:6]N<R!A;F0*("!C;W!Y(&%L;"!@8'1H96UE<V!@(&1I<F5C=&]R
M:65S(&EN('1H92!S86UE(&1I<F5C=&]R>2!L87EO=70@=&\@=&AE(&]T:&5R
M"B`@<V5R=F5R+@H*+BX@7VQI9VAT='!D.B!H='1P.B\O=W=W+FQI9VAT='!D
M+FYE="\*"@I!<'!L:6-A=&EO;B!T=6YI;F<*/3T]/3T]/3T]/3T]/3T]/3T]
M"@HJ(%-O;64@87!P;&EC871I;VYS(&-O;G1A:6X@861V86YC960@9F5A='5R
M97,@=&AA="!M:6=H="!H879E(&$@8V5R=&%I;B!I;7!A8W0*("!O;B!T:&4@
M<&5R9F]R;6%N8V4N("!4:&5S92!F96%T=7)E<R!C86X@=7-U86QL>2!B92!T
M=7)N960@;V9F(&EN('1H90H@(&%P<&QI8V%T:6]N)W,@8V]N9FEG=7)A=&EO
M;B!A;F0@87)E(&5X<&QI8VET;'D@9&5S8W)I8F5D(&%S(&)E:6YG(&$*("!P
M97)F;W)M86YC92!H:70@:6X@=&AE(&-O;F9I9W5R871I;VX@=V5B(&9R;VYT
M96YD+@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O4T5#55))5%D`
M````````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,C0T-#8`,3`T,3<S-C(W-#,`,#$V-34T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*
M($AO<F1E(%-E8W5R:71Y($YO=&5S"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T*
M"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-"\P.2\R-B`R,SHS,SHP-R`D
M"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N.2`D"CI#;VYT86-T.B`@
M("`@("!H;W)D94!L:7-T<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N
M=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*"E1E;7!O<F%R>2!F:6QE
M<PH]/3T]/3T]/3T]/3T]/3T*"DAO<F1E(&%P<&QI8V%T:6]N<R!M86ME(&5X
M=&5N<VEV92!U<V4@;V8@=&5M<&]R87)Y(&9I;&5S+B`@26X@;W)D97(@=&\@
M;6%K90IS=7)E('1H97-E(&9I;&5S(&%R92!S96-U<F4L('EO=2!S:&]U;&0@
M;6%K92!S=7)E('EO=7(@:6YS=&%L;&%T:6]N(&UE971S('1H90IF;VQL;W=I
M;F<@8W)I=&5R:6$N"@I3:71E<R!M87D@9V%I;B!I;F-R96%S960@<V5C=7)I
M='D@8GD@9&5F:6YI;F<@82!T96UP;W)A<GD@9&ER96-T;W)Y(&EN('1H90I(
M;W)D92!C;VYF:6=U<F%T:6]N('=H:6-H(&ES('=R:71A8FQE(&)Y('1H92!W
M96(@<V5R=F5R+"!B=70@;F]T('=R:71A8FQE(&)Y"F]T:&5R('5S97)S+B`@
M4VEN8V4@=&AE('1E;7!O<F%R>2!F:6QE<R!M87D@8V]N=&%I;B!S96YS:71I
M=F4@:6YF;W)M871I;VX@:70*:7,@8F5S="!T;R!A;'-O(&UA:V4@=&AE<V4@
M9FEL92!U;G)E861A8FQE(&)Y(&]T:&5R('5S97)S+B`@5&AA="!I<RP@=&AE
M>2!C86X*8F4@;6%D92!R96%D86)L92!A;F0@=W)I=&%B;&4@;VYL>2!B>2!T
M:&4@=V5B('-E<G9E<B!U<V5R+@H*"E!(4"!397-S:6]N<PH]/3T]/3T]/3T]
M/3T*"D9O<B!T:&4@;6]S="!S96-U<FET>2P@>6]U('-H;W5L9"!E;F%B;&4@
M4$A0('-E<W-I;VX@8V]O:VEE<R!B>2!E;F%B;&EN9R!T:&4*<&AP('-E='1I
M;F<@8&!S97-S:6]N+G5S95]C;V]K:65S8&`N("!7:&5N(&1O:6YG('-O+"!B
M92!S=7)E('1O('-E="!A;@IA<'!R;W!R:6%T92!@8'-E<W-I;VXN8V]O:VEE
M7W!A=&A@8"!A;F0@8&!S97-S:6]N+F-O;VMI95]D;VUA:6Y@8"!A;'-O('1O
M"G-E8W5R92!Y;W5R(&-O;VMI97,N"@I)9B!02%`@<V5S<VEO;G,@87)E('-E
M="!T;R!U<V4@=&AE(&!@9FEL97-@8"!S879E7VAA;F1L97(L('1H96X@=&AE
M<V4@9FEL97,*<VAO=6QD(&)E('-E8W5R960@<')O<&5R;'DN("!3:71E<R!C
M86X@:6YC<F5A<V4@<V5C=7)I='D@8GD@<V5T=&EN9R!T:&4@<&AP"G-E='1I
M;F<@8&!S97-S:6]N+G-A=F5?<&%T:&!@('1O(&$@9&ER96-T;W)Y('1H870@
M:7,@;VYL>2!R96%D86)L92!A;F0*=W)I=&%B;&4@8GD@=&AE('=E8B!S97)V
M97(@<')O8V5S<RX*"E-I=&5S('=I=&@@82!L87)G92!U<V5R(&)A<V4@<VAO
M=6QD(&-O;G-I9&5R('-E='1I;F<@=&AE"F!@<V5S<VEO;BYE;G1R;W!Y7V9I
M;&5@8"!A;F0@8&!S97-S:6]N+F5N=')O<'E?;&5N9W1H8&`@=&\@87!P<F]P
M<FEA=&4@=F%L=65S+@H*2&]R9&4@=VEL;"!E;F-R>7!T('1H92!U<V5R(&-R
M961E;G1I86QS(&)E9F]R92!S=&]R:6YG('1H96T@:6X@=&AE('-E<W-I;VXN
M"DAO=V5V97(L('1H:7,@96YC<GEP=&EO;B!C86X@8F4@:6UP<F]V960@:68@
M>6]U(&AA=F4@86YD(&5N86)L92!T:&4@<&AP"F5X=&5N<VEO;B`B;6-R>7!T
M(B!W:&EC:"!A;&QO=W,@9F]R('-T<F]N9V5R(&5N8W)Y<'1I;VX@=&AA;B!I
M<R!O=&AE<G=I<V4*<')O=FED960@8GD@2&]R9&4N"@H*1&5F875L="!D871A
M8F%S92!P87-S=V]R9',*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H
M92!(;W)D92!D;V-U;65N=&%T:6]N(&%N9"!S86UP;&4@9&%T86)A<V4@8W)E
M871I;VX@<V-R:7!T<R!C<F5A=&4@82!D969A=6QT"G5S97(@86YD('!A<W-W
M;W)D(&9O<B!A8V-E<W-I;F<@=&AE(&AO<F1E(&1A=&%B87-E+B`@57-I;F<@
M=&AI<R!P87-S=V]R9"!I;B!A"G!R;V1U8W1I;VX@96YV:7)O;FUE;G0@:7,@
M82!S96-U<FET>2!H;VQE+"!S:6YC92!A;B!A='1A8VME<B!W:6QL(&5A<VEL
M>2!G=65S<PII="X*"DET(&ES('9E<GD@:6UP;W)T86YT('1H870@<VET97,@
M8VAA;F=E(&%T(&QE87-T('1H92!P87-S=V]R9"!T;R!S;VUE=&AI;F<*<V5C
M=7)E+@H*"E!R979E;G0@8V]N9FEG=7)A=&EO;B!F:6QE(')E861I;F<@86YD
M('=R:71I;F<@"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*"E1H92!C;VYF:6=U<F%T:6]N(&9I;&5S(&UA>2!C;VYT
M86EN('-E;G-I=&EV92!D871A("AS=6-H(&%S(&1A=&%B87-E"G!A<W-W;W)D
M<RD@=&AA="!S:&]U;&0@;F]T(&)E(')E860@;W(@=W)I='1E;B!B>2!L;V-A
M;"!S>7-T96T@=7-E<G,@;W(@<F5M;W1E"G=E8B!U<V5R<RX*"DEF('EO=2!U
M<V4@82!5;FEX('-Y<W1E;2P@;VYE('=A>2!T;R!M86ME('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&5S(&%N9`ID:7)E8W1O<FEE<R!A8V-E<W-I8FQE(&]N;'D@
M=&\@=&AE('=E8B!S97)V97(@:7,@87,@9F]L;&]W<RX@($AE<F4@=V4@87-S
M=6UE"G1H870@=&AE('=E8B!S97)V97(@<G5N<R!A<R!T:&4@=7-E<B!@8&%P
M86-H96!@(&%N9"!T:&4@9FEL97,@87)E(&QO8V%T960@:6X*8&`O:&]M92]H
M='1P9"]H=&UL8&`@+2T@<W5B<W1I='5T92!T:&4@8V]R<F5C="!U<V5R(&]R
M(&9I;&4@<&%T:"!I9B!N965D960Z.@H*)"!C:&]W;B`M4B!A<&%C:&4@+VAO
M;64O:'1T<&0O:'1M;"]H;W)D92]C;VYF:6<*)"!C:&]W;B`M4B!A<&%C:&4@
M+VAO;64O:'1T<&0O:'1M;"]H;W)D92\J+V-O;F9I9PHD(&-H;6]D("U2(&=O
M+7)W>"`O:&]M92]H='1P9"]H=&UL+VAO<F1E+V-O;F9I9PHD(&-H;6]D("U2
M(&=O+7)W>"`O:&]M92]H='1P9"]H=&UL+VAO<F1E+RHO8V]N9FEG"@I&;W(@
M8V]M<&QE=&5L>2!F87-C:7-T('!E<FUI<W-I;VYS+"!Y;W4@8V%N(&UA:V4@
M=&AE(&5N=&ER92!(;W)D92!T<F5E"FEN86-C97-S:6)L92!B>2!A;GEO;F4@
M97AC97!T('1H92!W96(@<V5R=F5R('5S97(@*&%N9"!R;V]T*3HZ"@HD(&-H
M;W=N("U2(&%P86-H92`O:&]M92]H='1P9"]H=&UL+VAO<F1E"B0@8VAM;V0@
M+5(@9V\M<G=X("`O:&]M92]H='1P9"]H=&UL+VAO<F1E"B0@8VAM;V0@+5(@
M82UW("`@+VAO;64O:'1T<&0O:'1M;"]H;W)D92\*"DYO=&4@=&AA="!T:&4@
M;&%S="!L:6YE(&UA:V5S(&%L;"!F:6QE<R!U;G=R:71A8FQE(&)Y(&%N>2!U
M<V5R("AO;FQY(')O;W0@8V%N"F]V97)R:61E('1H:7,I+B`@5&AI<R!M86ME
M<R!T:&4@<VET92!S96-U<F4L(&)U="!M87D@;6%K92!I="!M;W)E(&1I9F9I
M8W5L="!T;PIA9&UI;FES=')A=&4N("!);B!P87)T:6-U;&%R+"!I="!W:6QL
M(&1E9F5A="!T:&4@2&]R9&4@861M:6YI<W1R871I=F4*8V]N9FEG=7)A=&EO
M;B!I;G1E<F9A8V4L(&9O<F-I;F<@>6]U('1O('5P9&%T92!T:&4@2&]R9&4@
M8V]N9FEG=7)A=&EO;B!F:6QE<PIM86YU86QL>2`H87,@<&5R('1H92!)3E-4
M04Q,7R!I;G-T<G5C=&EO;G,I+@H*5&AE(&%B;W9E('=I;&P@;F]T('-E8W5R
M92!T:&4@9FEL97,@:68@;W1H97(@=7-E<B=S(&]N('1H92!S86UE(&UA8VAI
M;F4@8V%N"G)U;B!S8W)I<'1S(&%S('1H92!A<&%C:&4@=7-E<BX@($EF('EO
M=2!N965D('1O('!R;W1E8W0@86=A:6YS="!T:&ES('EO=0IS:&]U;&0@;6%K
M92!O=&AE<B!U<V5R)W,@<V-R:7!T<R!R=6X@=6YD97(@=&AE:7(@;W=N(&%C
M8V]U;G0@=VET:"!S;VUE"F9A8VEL:71Y('-U8V@@87,@87!A8VAE)W,@<W5E
M>&5C(&UO9'5L92X@(%EO=2!N965D('1O('=A=&-H(&]U="!N;W0@;VYL>2!F
M;W(*8V=I('-C<FEP=',L(&)U="!A;'-O(&9O<B!O=&AE<B!M;V1U;&5S(&QI
M:V4@;6]D7W!H<"P@;6]D7W!E<FPL(&UO9%]P>71H;VXL"F5T8RX@=&AA="!M
M87D@8F4@:6X@=7-E(&]N('EO=7(@<V5R=F5R+@H*+BX@7TE.4U1!3$PZ(#]F
M/4E.4U1!3$PN:'1M;`H*"E)E<W1R:6-T:6YG('1E<W0N<&AP(&9I;&5S"CT]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I4:&4@8&!T97-T+G!H<&!@(&9I
M;&5S('!R;W9I9&4@82!W96%L=&@@;V8@:6YF;W)M871I;VX@=&AA="!C86X@
M8F4@=7-E9`IA9V%I;G-T('1H92!S:71E(&)Y(&%T=&%C:V5R<RX@($]N92!Y
M;W4@:&%V92!C;VYF:7)M960@=&AA="!E=F5R>71H:6YG(&ES"G=O<FMI;F<L
M('EO=2!S:&]U;&0@9&ES86)L92!A8V-E<W,@=&\@=&AE('1E<W0N<&AP(&9I
M;&5S+B`@66]U(&-A;B!D;R!T:&ES('9I80IT:&4@=V5B('-E<G9E<BP@;W(@
M=FEA('-Y<W1E;2!F:6QE('!E<FUI<W-I;VYS+B`@3VX@82!U;FEX('-Y<W1E
M;2P@>6]U(&UI9VAT"FES<W5E(&$@8V]M;6%N9"!S=6-H(&%S.CH*"B0@8VAM
M;V0@82UR=W@@+VAO;64O:'1T<&0O:'1M;"]H;W)D92]T97-T+G!H<`HD(&-H
M;6]D(&$M<G=X("]H;VUE+VAT='!D+VAT;6PO:&]R9&4O*B]T97-T+G!H<`H*
M"E!R979E;G1I;F<@07!A8VAE(&9R;VT@<V5R=FEN9R!C;VYF:6=U<F%T:6]N
M(&%N9"!S;W5R8V4@9FEL97,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!(;W)D
M92!C;VYF:6=U<F%T:6]N(&9I;&5S(&UA>2!C;VYT86EN('-E;G-I=&EV92!D
M871A("AS=6-H(&%S(&1A=&%B87-E"G!A<W-W;W)D<RD@=&AA="!S:&]U;&0@
M;F]T(&)E('-E<G9E9"!B>2!T:&4@=V5B('-E<G9E<BX@3W1H97(@9&ER96-T
M;W)I97,*8V]N=&%I;B!02%`@<V]U<F-E(&-O9&4@=&AA="!I<VXG="!I;G1E
M;F1E9"!F;W(@=FEE=VEN9R!B>2!E;F0M=7-E<G,N(%1H90I(;W)D92!G<F]U
M<"!H87,@<')O=FED960@8&`N:'1A8V-E<W-@8"!F:6QE<R!I;B!V87)I;W5S
M(&1I<F5C=&]R:65S('1O(&AE;'`*<')O=&5C="!T:&5S92!F:6QE<RX@($AO
M=V5V97(L('1H870@9&5P96YD<R!O;B!Y;W5R('=E8B!S97)V97(@:&]N;W)I
M;F<*8&`N:'1A8V5S<V!@(&9I;&5S("AW:&EC:"!I<R!A('!E<F9O<FUA;F-E
M(&AI="P@86YD(&UA>2!N;W0@8F4@879A:6QA8FQE(&EN"F%L;"!W96(@<V5R
M=F5R<RDN"@I!;B!!<&%C:&4@<VET92!C86X@86QS;R!P<F5V96YT('1H92!W
M96(@<V5R=F5R(&9R;VT@<V5R=FEN9R!T:&5S90IF:6QE<R!B>2!A9&1I;F<@
M<V5C=&EO;G,@=&\@8&!H='1P9"YC;VYF8&`@<W5C:"!A<R!T:&4@9F]L;&]W
M:6YG.CH*"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O
M8V]N9FEG(CX*("`@("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@
M9G)O;2!A;&P*("`@/"]$:7)E8W1O<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE
M+VAT='!D+VAT;6PO:&]R9&4O;&EB(CX*("`@("`@(&]R9&5R(&1E;GDL86QL
M;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$:7)E8W1O<GD^"B`@(#Q$
M:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O;&]C86QE(CX*("`@
M("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@
M/"]$:7)E8W1O<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO
M:&]R9&4O<&\B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N
M>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO
M;64O:'1T<&0O:'1M;"]H;W)D92]S8W)I<'1S(CX*("`@("`@(&]R9&5R(&1E
M;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$:7)E8W1O<GD^
M"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O=&5M<&QA
M=&5S(CX*("`@("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O
M;2!A;&P*("`@/"]$:7)E8W1O<GD^"@I297!E870@=&AI<R!P871T97)N(&9O
M<B!E86-H($AO<F1E(&%P<&QI8V%T:6]N+B`@1F]R(&5X86UP;&4L(&9O<B!)
M35`@>6]U"G=O=6QD('1H96X@861D.CH*"B`@(#Q$:7)E8W1O<GD@(B]H;VUE
M+VAT='!D+VAT;6PO:&]R9&4O:6UP+V-O;F9I9R(^"B`@("`@("!O<F1E<B!D
M96YY+&%L;&]W"B`@("`@("!D96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y
M/@H@("`\1&ER96-T;W)Y("(O:&]M92]H='1P9"]H=&UL+VAO<F1E+VEM<"]L
M:6(B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M
M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T
M<&0O:'1M;"]H;W)D92]I;7`O;&]C86QE(CX*("`@("`@(&]R9&5R(&1E;GDL
M86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$:7)E8W1O<GD^"B`@
M(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O:6UP+W!O(CX*
M("`@("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*
M("`@/"]$:7)E8W1O<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT
M;6PO:&]R9&4O:6UP+W-C<FEP=',B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO
M=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I
M<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]I;7`O=&5M<&QA=&5S
M(CX*("`@("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A
M;&P*("`@/"]$:7)E8W1O<GD^"@H*4V5T=7`@<V-R:7!T<PH]/3T]/3T]/3T]
M/3T]"@I4:&5R92!A<F4@=F%R:6]U<R!S8W)I<'1S('5S92!T;R!S971U<"!O
M<B!C;VYF:6=U<F4@2&]R9&4N("!)9B!Y;W4@86QL;W<@;W1H97(*=7-E<G,@
M;VX@=&AE('=E8B!S97)V97(@;6%C:&EN92P@>6]U('-H;W5L9"!P<F]T96-T
M('1H97-E(&9I;&5S(&9R;VT@8F5I;F<*86-C97-S960@8GD@=&AE;2X@($]N
M(&$@=6YI>"!S>7-T96TL('EO=2!M:6=H="!R97-T<FEC="!T:&5S92!F:6QE
M<R!T;R!R;V]T"F%C8V5S<R!B>2!U<VEN9R!T:&4@9F]L;&]W:6YG('1Y<&4@
M;V8@8V]M;6%N9',Z.@H*)"!C:&]W;B`M4B!R;V]T("]H;VUE+VAT='!D+VAT
M;6PO:&]R9&4O<V-R:7!T<PHD(&-H;W=N("U2(')O;W0@+VAO;64O:'1T<&0O
M:'1M;"]H;W)D92\J+W-C<FEP=',*)"!C:&UO9"`M4B!G;RUR=W@@+VAO;64O
M:'1T<&0O:'1M;"]H;W)D92]S8W)I<'1S"B0@8VAM;V0@+5(@9V\M<G=X("]H
M;VUE+VAT='!D+VAT;6PO:&]R9&4O*B]S8W)I<'1S"@H*57-I;F<@82!C:')O
M;W0@=V5B('-E<G9E<B!S971U<`H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"@I5;FEX('5S97)S(&UA>2!W86YT('1O(&-O;G-I9&5R('5S:6YG
M(&$@8VAR;V]T(&5N=FER;VYM96YT(&9O<B!T:&5I<B!W96(*<V5R=F5R+B`@
M2&]W('1O(&1O('1H:7,@:7,@8F5Y;VYD('1H92!S8V]P92!O9B!T:&ES(&1O
M8W5M96YT+"!B=70@<W5F9FEC:65N=`II;F9O<FUA=&EO;B!E>&ES=',@;VX@
M=&AE('=O<FQD('=I9&4@=V5B(&%N9"]O<B!I;B!Y;W5R('-E<G9E<B!D;V-U
M;65N=&%T:6]N"G1O(&-O;7!L971E('1H:7,@=&%S:RX*"@I(:61I;F<@4$A0
M(&EN9F\@9G)O;2!T:&4@=7-E<@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H*66]U('-H;W5L9"!C;VYS:61E<B!S971T:6YG('1H92!F;VQL;W=I
M;F<@4$A0('9A<FEA8FQE<R!I;B!Y;W5R(&!@<&AP+FEN:6!@"F9I;&4@=&\@
M<')E=F5N="!I;F9O<FUA=&EO;B!L96%K('1O('1H92!U<V5R+"!O<B!G;&]B
M86P@:6YS97)T:6]N(&)Y('1H90IU<V5R.CH*"B`@(&5X<&]S95]P:'`@/2!/
M9F8*("`@9&ES<&QA>5]E<G)O<G,@/2!/9F8*("`@;&]G7V5R<F]R<R`]($]N
M"B`@(')E9VES=&5R7V=L;V)A;',@/2!/9F8*"EEO=2!S:&]U;&0@86QS;R!S
M970@=7`@97)R;W(@;&]G9VEN9R`H=7-I;F<@=&AE(%!(4"!@8&5R<F]R7VQO
M9V!@('9A<FEA8FQE*0IT;R!L;V<@=&\@82!F:6QE+"!S>7-L;V<L(&]R(&]T
M:&5R(&QO9R!D97-T:6YA=&EO;BX*"@I5<VEN9R!A('-E8W5R92!W96(@<V5R
M=F5R"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DAO<F1E(&1E<&5N9',@
M;VX@<&%S<VEN9R!S96YS:71I=F4@:6YF;W)M871I;VX@*'-U8V@@87,@<&%S
M<W=O<F1S(&%N9"!S97-S:6]N"FEN9F]R;6%T:6]N*2!B971W965N('1H92!W
M96(@<V5R=F5R(&%N9"!T:&4@=V5B(&-L:65N="X@(%5S:6YG(&$@<V5C=7)E
M"BA34TPM96YA8FQE9"D@=V5B('-E<G9E<B!W:6QL(&AE;'`@<')O=&5C="!T
M:&ES(&EN9F]R;6%T:6]N(&%S(&ET('1R879E<G-I;F<*=&AE(&YE='=O<FLN
M"@H*57-I;F<@82!S96-U<F4@4$]0,R])34%0('-E<G9E<@H]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W4@87)E('5S:6YG(&$@4$]0
M,R])34%0('-E<G9E<B!W:71H($AO<F1E("AE+F<N(&9O<B!A=71H96YT:6-A
M=&EO;B!O<B!F;W(*24U0*2!T:&5N($AO<F1E(&ES('!A<W-I;F<@=&AE('5S
M97(G<R!L;V=I;B!C<F5D96YT:6%L<R!B971W965N('1H92!W96(@<V5R=F5R
M"F%N9"!T:&4@;6%I;"!S97)V97(N"@I)9B!Y;W5R('=E8B!S97)V97(@86YD
M($E-05`@<V5R=F5R(&%R92!O;B!T:&4@<V%M92!H;W-T+"!Y;W4@8V%N(&EN
M8W)E87-E"G-E8W5R:71Y(&)Y(&9O<F-I;F<@86QL('1R869F:6,@;W9E<B!T
M:&4@;&]O<&)A8VL@;W(@;&]C86QH;W-T(&EN=&5R9F%C92!S;PIT:&%T(&ET
M(&ES(&YO="!E>'!O<V5D('1O('EO=7(@;F5T=V]R:RX*"DEN(&-A<V5S('=H
M97)E('1H870@:7,@;F]T('!O<W-I8FQE+"!W92!R96-O;6UE;F0@=7-I;F<@
M82!S96-U<F4@;6%I;`IC;VYN96-T:6]N('-U8V@@87,@24U!4"U34TP@;W(@
M4$]0,RU34TP@=&\@96YS=7)E('1H870@<&%S<W=O<F1S(')E;6%I;B!S869E
M+@H*"DQ$05`@4V5C=7)I='D*/3T]/3T]/3T]/3T]/0H*3$1!4"!S96-U<FET
M>2!I<R!S:6UI;&%R('1O('1H92!A8F]V92!03U`S+TE-05`@<V5R=F5R('-E
M8W5R:71Y(&ES<W5E+B`@268@>6]U"F%R92!U<VEN9R!,1$%0+"!Y;W4@<VAO
M=6QD(&UA:V4@<W5R92!T:&%T('EO=2!A<F4@;F]T(&5X<&]S:6YG(&QD87`@
M<&%S<W=O<F1S"F]R(&%N>2!S96YS:71I=F4@9&%T82!I;B!Y;W5R($Q$05`@
M9&%T86)A<V4N"@H*1&%T86)A<V4@<V]C:V5T('-E8W5R:71Y"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H*268@>6]U<B!D871A8F%S92`H92YG+B!->5-1
M3"!O<B!0;W-T9W)E4U%,*2!I<R!O;B!T:&4@<V%M92!H;W-T(&%S('EO=7(@
M=V5B"G-E<G9E<BP@>6]U(&UA>2!U<V4@=6YI>"!S;V-K971S(')A=&AE<B!T
M:&%N('1C<"!C;VYN96-T:6]N<R!T;R!H96QP(&EM<')O=F4*>6]U<B!S96-U
M<FET>2`H86YD('!E<F9O<FUA;F-E*2X@($EF(&ET(&1O97-N)W0@<W5P<&]R
M="!U;FEX('-O8VME=',L('EO=2!C86X*86-H:65V92!S;VUE(&)E='1E<B!S
M96-U<FET>2!B>2!R97-T<FEC=&EN9R!T:&4@=&-P('-U<'!O<G0@=&\@=&AE
M(&QO;W!B86-K(&]R"FQO8V%L:&]S="!I;G1E<F9A8V4N"@I)9B!T:&4@9&%T
M86)A<V4@:V5E<',@:71S('-O8VME="!F:6QE("AE+F<N(&!@;7ES<6PN<V]C
M:V!@*2!I;B!A(&1I<F5C=&]R>0IL:6ME(&!@+W1M<&!@(&]R(&!@+W9A<B]T
M;7!@8"P@>6]U('-H;W5L9"!S970@<&5R;6ES<VEO;G,@8V%R969U;&QY('1O
M(&5N<W5R90IT:&%T(&QO8V%L('5S97)S("AI9B!Y;W4@:&%V92!A;GDI(&-A
M;B=T(&1E;&5T92!T:&4@<V]C:V5T+B`@5&AE('5N:7@@(G-T:6-K>2(*8FET
M('-H;W5L9"!A;')E861Y(&)E('-E;G0@;VX@=&AE('1E;7!O<F%R>2!D:7)E
M8W1O<GD@:71S96QF+"!B=70@>6]U(&%L<V\*;F5E9"!T;R!M86ME('-U<F4@
M=&AE('-O8VME="!I='-E;&8@:7-N)W0@=W)I=&%B;&4@8GD@(F]T:&5R(B!O
M<B!U<V5R<R!C86X*9&5L971E(&ET+@H*66]U(&UI9VAT(&-O;G-I9&5R(&UO
M=FEN9R!T:&4@<V]C:V5T(&9I;&4@=&\@86YO=&AE<B!L;V-A=&EO;B!S=6-H
M(&%S"F!@+W9A<B]R=6Y@8"!O<B!T:&4@=&]P+6QE=F5L(&1I<F5C=&]R>2!O
M9B!Y;W5R(&1A=&%B87-E('!R;V=R86T@*&4N9RX*8&`O=F%R+VQI8B]M>7-Q
M;&!@(&]R(&!@+W9A<B]L:6(O<&=S<6Q@8"DN"@H*4V5N9&UA:6P@;W(@4TU4
M4"!C;VYS:61E<F%T:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"@I);B!S;VUE(&-A<V5S+"!Y;W4@8V%N(&EN8W)E87-E('-E8W5R:71Y
M(&)Y('-E;F1I;F<@;6%I;"!V:6$@=&AE(&QO8V%L"F-O;6UA;F0M;&EN92!S
M96YD;6%I;"!P<F]G<F%M(&]N('EO=7(@=V5B('-E<G9E<BP@<F%T:&5R('1H
M86X@=7-I;F<@4TU44"X*2&]W979E<BP@=&AE<F4@;6%Y(&)E(')E87-O;G,@
M=&\@=7-E(%--5%`@:6YS=&5A9"P@<W5C:"!A<R!I9B!Y;W5R('-M='`@<V5R
M=F5R"F1O97,@<W!A;2!O<B!V:7)U<R!C:&5C:VEN9R!W:&EC:"!W;W5L9"!B
M92!S:VEP<&5D('5S:6YG('1H92!L;V-A;"!S96YD;6%I;`IP<F]G<F%M+@H*
M"D%D9&ET:6]N86P@3F]T97,*/3T]/3T]/3T]/3T]/3T]/0H*5&AI<R!I<R!B
M>2!F87(@;F]T(&$@8V]M<&QE=&4@<V5C=7)I='D@2$]75$\N(%1H:7,@:7,@
M:G5S="!A(&-O;7!I;&5D(&QI<W0@;V8*=VAA="!P96]P;&4@:&%V92!C;VYT
M<FEB=71E9"!S;R!F87(N($EF('EO=2!H879E('1I<',L(&ED96%S+"!S=6=G
M97-T:6]N<R!O<@IA;GET:&EN9R!E;'-E('1H870@>6]U('1H:6YK(&-O=6QD
M(&AE;'`@;W1H97)S(&EN('-E8W5R:6YG('1H96ER($AO<F1E"FEN<W1A;&QA
M=&EO;BP@<&QE87-E(&QE="!U<R!K;F]W+@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M9&]C<R]43T1/````````````````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,S<R,0`Q,#0Q-S,V,C<T,P`P,38P-#,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T*($AO<F1E($1E=F5L;W!M96YT(%1/1$\@
M3&ES=`H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D
M871E.B`@("1$871E.B`R,#`T+S$R+S$X(#$Y.C4W.C,R("0*.E)E=FES:6]N
M.B`@("`@("12979I<VEO;CH@,2XR-R`D"CI#;VYT86-T.B`@("`@("!H;W)D
M94!L:7-T<RYH;W)D92YO<F<*"DEN(&YO('!A<G1I8W5L87(@;W)D97(Z"@HM
M("A/<'1I;VYA;&QY*2!"=6YD;&4@4$5!4B!P86-K86=E<R!W:71H('1H92!T
M87)B86QL<RX@1VEV96X@82!P86-K86=E(&QI<W0L"B`@;6%K92UR96QE87-E
M+G!H<"!S:&]U;&0@9V5T('1H92!P86-K86=E<R!A;F0@=6YP86-K('1H96T@
M:6YT;R!L:6(O('=H97)E('=E"B`@:6YS=&%L;"!O=7(@;W=N('!A8VMA9V5S
M(&%N>7=A>2X@5&]G971H97(@=VET:"!P96%R+FAO<F1E+F]R9R!T:&ES('-H
M;W5L9`H@(&QE860@=&\@(FQI=&4B('1A<F)A;&QS(&]N;'D@8V]N=&%I;FEN
M9R!A<'!L:6-A=&EO;B!C;V1E(&%N9"`B9G5L;"(@=&%R8F%L;',*("!T:&%T
M(&1O;B=T(&YE960@86YY(&5X=&5R;F%L(&1E<&5N8V5N8VEE<R!A;GEM;W)E
M+@H*+2`B8G)O=W-E(B!D<FEV97(@9F]R(%9&4R!T:&%T('5S97,@2&]R9&4G
M<R!B<F]W<V4@05!)+@H*+2!#86-H92!T:&4@4F5G:7-T<GD@;V)J96-T('-O
M('1H870@9FEL92!O=F5R:&5A9"!O9B!R96%D:6YG(&EN(&5N=')I97,@9G)O
M;2!A"B`@9&ER96-T;W)Y("AR96=I<W1R>2YD*2!I<R!M:71I9V%T960N"@HM
M($EM<&QE;65N="!A9&UI;B]D96QE=&55<V5R(&UE=&AO9',@:6X@87!P;&EC
M871I;VYS)R!!4$ES('1O(&1E;&5T92!U<V5R"B`@<W!E8VEF:6,@9&%T82X*
M"BT@061D(&$@+W-E<G9I8V5S+V=R;W5P<R\@<V5C=&EO;BX@26YC;'5D92!P
M=6)L:6,@9W)O=7`@:&]M97!A9V5S+"!I;F-L=61I;F<*("!A;GD@:6YF;W)M
M871I;VX@;6%R:V5D('!U8FQI8R!F;W(@=&AE(&=R;W5P("AL970@=&AE(&UE
M;6)E<G,@;&ES="!B92!M87)K960*("!P=6)L:6,O9W)O=7`@;VYL>2]A9&UI
M;B!O;FQY*2P@861D(&=R;W5P(&%D;6EN:7-T<F%T;W)S("AJ=7-T(&$@9FQA
M9R!F;W(*("!U<V5R<RDL(&%D9"!T:&4@86)I;&ET>2!T;R!S:&]W(&%L;"!C
M86QE;F1A<G,O;W1H97(@<VAA<F5S('1H870@82!G<F]U<"!H87,*("!P97)M
M:7-S:6]N<R!T;RP@86QL;W<@8W)E871I;F<@82!N97<@8V%L96YD87(O<&]L
M;"]E=&,N(&9O<B!A(&=R;W5P+@H*+2!!9&0@=&AE(&%B:6QI='D@=&\@8G)E
M86L@;W5T($1A=&%4<F5E(&=R;W5P7W5I9',@:6YT;R!T:&5I<B!O=VX@=&%B
M;&5S("AO;F4*("!T86)L92!P97(@9W)O=7`I+@H*+2!5<V4@=&AE(&9R965D
M97-K=&]P('-H87)E9"UM:6UE+6EN9F]?(%A-3"!F:6QE('1O(&)U:6QD(&]U
M<B!-24U%7TUA9VEC(&UA9VEC"B`@9&%T82!F:6QE<RX*"BT@061D('-U<'!O
M<G0@9F]R('1H92!34DT@87!P;&EC871I;VX@<V5R=F5R("AH='1P.B\O=W=W
M+G9L+7-R;2YN970O*2X*"BT@061D(%5)('-U<'!O<G0@9F]R(&UO<F4@8V]N
M9FEG=7)A=&EO;B!F:6QE<RX*"BT@4VEN8V4@0V]N=&5N="U$:7-P;W-I=&EO
M;B`H4D9#(#(Q.#,I(&ES(&YO="!A($U54U0@:6UP;&5M96YT+"!A;&QO=PH@
M(&EN9&EV:61U86P@34E-12!6:65W97)S('1O(&%L;&]W(&5X<&QI8VET(&]V
M97)R:61E("AI+F4N('1O(&%U=&\@:6YL:6YE(`H@(&1I<W!L87D@82!P87)T
M(&EN<W1E860@;V8@<F5N9&5R:6YG(&%S(&%N(&%T=&%C:&UE;G0@+2!U<V5F
M=6P@9F]R(%,O34E-10H@(&5N8W)Y<'1E9"!P87)T<RP@9F]R(&5X86UP;&4I
M+@H*+2!3:&]W('-H87)E9"!P<F5F97)E;F-E<R!O;B!A;&P@<')E9G,@<W5M
M;6%R>2!S8W)E96YS('1O(&UA:V4@:70*("!E87-I97(@9F]R('5S97(@=&\@
M9FEN9"!G;&]B86P@<')E9F5R96YC97,N"@H*+BX@7W-H87)E9"UM:6UE+6EN
M9F\Z(&AT='`Z+R]W=W<N9G)E961E<VMT;W`N;W)G+U-O9G1W87)E+W-H87)E
M9"UM:6UE+6EN9F\*````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O
M5%)!3E-,051)3TY3````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3(U-S$`,3`T,3<S-C(W-#,`,#$W,C(R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*($AO<F1E(%1R86YS;&%T:6]N($=U:61E"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P
M-2\Q,"\Q."`Q,3HS,SHS."`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ
M(#$N."XQ,"XR("0*.D%U=&AO<CH@("`@("`@($IO<FES($)R86%K;6%N(#QJ
M8G)A86MM86Y`>6%H;V\N8V]M/@HZ075T:&]R.B`@("`@("`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"CI!=71H;W(Z("`@("`@("!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@HZ0V]N=&%C=#H@("`@("`@:&]R
M9&5`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"@H*
M1TY5(&=E='1E>'0L(%!(4"!A;F0@2&]R9&4*/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"DAO<F1E('5S97,@1TY5(&=E='1E>'0@9F]R(&EN=&5R;F%T
M:6]N86QI>F%T:6]N("AI,3AN*2!A;F0@;&]C86QI>F%T:6]N"BAL,3!N*2X@
M(%1H92!M86YU86P@870@:'1T<#HO+W=W=RYG;G4N;W)G+VUA;G5A;"]G971T
M97AT+VEN9&5X+FAT;6P@:7,@8FEA<V5D"F%G86EN<W0@0R!A;F0@=7-I;F<@
M16UA8W,N("!4:&ES(&ES(&UO<F4@9F]R($AO<F1E+@H*5&AE<F4@:7,@82!G
M;V]D(&5X<&QA;F%T:6]N(&9O<B!02%`@86YD(&=E='1E>'0@870Z"FAT='`Z
M+R]W=W<N9F%Q=',N8V]M+VMN;W=L961G92UB87-E+W9I97<N<&AT;6PO86ED
M+S(Y-3,O9FED+S0R,@H*4&5O<&QE('-E96T@=&\@;&EK92!L96%R;FEN9R!F
M<F]M(&5X86UP;&5S(&)E='1E<BP@<V\@22!H879E('5S960@9'5T8V@**&YL
M7TY,*2!A<R!A;B!E>&%M<&QE(&5V97)Y=VAE<F4N"@I4:&5R92!I<R!A(&-O
M;6UA;F0@;&EN92!T;V]L('=R:71T96X@:6X@4$A0(&9O<B!C<F5A=&EN9R!A
M;F0@;6%N86=I;F<*=')A;G-L871I;VYS(&EN('1H92!@8&AO<F1E+W!O+V!@
M(&1I<F5C=&]R>2X@(%5S86=E(&EN<W1R=6-T:6]N<R!C86X@8F4@9F]U;F0*
M:6X@8&!H;W)D92]P;R]214%$345@8"!A<R!W96QL(&%S(&EN<W1R=6-T:6]N
M<R!O;B!H;W<@=&\@<W1A<G0@86YD(&UA:6YT86EN"G1R86YS;&%T:6]N<RX*
M"@I4<F%N<VQA=&EO;G,@9&]N)W0@=V]R:PH]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H*268@86QL(&]R('-O;64@=')A;G-L871I;VYS(&1O;B=T('=O<FL@
M;VX@>6]U<B!S>7-T96TL('!L96%S92!F;VQL;W<@=&AE('-T97!S"F1E<V-R
M:6)E9"!B96QO=RX@($EF('EO=2!W86YT('1O(&%S:R!F;W(@:&5L<"!E:71H
M97(@;VX@=&AE(&!I,3AN(&UA:6QI;F<*;&ES=&!?(&]R(&]N(&!(;W)D92=S
M(&)U9R!S>7-T96U@7RP@<&QE87-E(&5X<&QA:6X@=VAI8V@@<W1E<',@>6]U
M('1R:65D(&%N9`IW:&EC:"!F86EL960N"@I9;W4@;6EG:'0@86QS;R!F:6YD
M('-O;64@;6]R92!I;F9O<FUA=&EO;B!I;B!T:&4@1D%17RX*"E!L96%S92!N
M;W1E('1H870@1'5T8V@@*&YL7TY,*2!I<R!O;FQY('5S960@87,@86X@97AA
M;7!L92!H97)E+B`@268@>6]U(&AA=F4*<')O8FQE;7,@=VET:"!A(&-E<G1A
M:6X@=')A;G-L871I;VX@=7-E('1H:7,@=')A;G-L871I;VXG<R!L86YG=6%G
M92!C;V1E"FEN<W1E860N"@HQ+B!)<R!T:&ES(&QO8V%L92`H;FQ?3DPI(&EN
M<W1A;&QE9"!A="!A;&P_"@H@("!@8&QO8V%L92`M86!@('-H;W5L9"!L:7-T
M(&%L;"!L;V-A;&5S(&EN<W1A;&QE9"!O;B!Y;W5R('-Y<W1E;2X*"B`@($]N
M($1E8FEA;B!N;W0@86QL(&QO8V%L97,@;6%Y(&)E(&5N86)L960@8GD@9&5F
M875L="X@($5D:70*("`@8&`O971C+VQO8V%L92YG96Y@8"!A;F0@<G5N(&!@
M;&]C86QE+6=E;F!@(&EF('EO=2!C:&%N9V5D('1H92!L:7-T(&]F"B`@(&5N
M86)L960@;&]C86QE<RX*"C(N($1O('EO=2!H879E(&%N>2`N;6\@9FEL97,_
M"@H@("!5<W5A;&QY(&EN(&!@+W5S<B]S:&%R92]L;V-A;&4O8&`*("`@92YG
M+B!@8"]U<W(O<VAA<F4O;&]C86QE+VYL+TQ#7TU%4U-!1T53+W1A<BYM;V!@
M"@HS+B!$;V5S(&=E='1E>'0@979E;B!W;W)K/PH*("`@1V5T(&$@<W1R:6YG
M('1O('1R86YS;&%T93HZ"@H@("`@("`D('-T<FEN9W,@+V)I;B]T87(@?"!G
M<F5P($UE;6]R>0H@("`@("!-96UO<GD@97AH875S=&5D"B`@("`@("0@*$Q!
M3D<];FQ?3DP[($Q!3D=504=%/6YL7TY,.R!,0U]-15-304=%4SUN;%].3#L@
M9V5T=&5X="!T87(@(DUE;6]R>2!E>&AA=7-T960B("D*("`@("`@1V5H975G
M96X@=6ET9V5P=70*"C0N($1O97,@=&AE(&QO8V%L($AO<F1E(&9I;&4@=V]R
M:S\*"B`@($%S<W5M:6YG('1H870@>6]U(&AA=F4@<'5T('1H92!T<F%N<VQA
M=&5D($AO<F1E(&9I;&4@:6X*("`@8&`O9&%T82]W=W<O:&]R9&4O;&]C86QE
M+VYL7TY,+TQ#7TU%4U-!1T53+VAO<F1E+FUO8&`Z.@H*("`@("`@)"!E>'!O
M<G0@5$585$1/34%)3D1)4CTO9&%T82]W=W<O:&]R9&4O;&]C86QE"B`@("`@
M("0@*$Q!3D<];FQ?3DP[($Q!3D=504=%/6YL7TY,.R!,0U]-15-304=%4SUN
M;%].3#L@9V5T=&5X="!H;W)D92`B365S<V%G92(@*0H@("`@("!"97)I8VAT
M"@H@("!#<F5A=&4@82!F:6QE(&EN('1H92!H;W)D92!D:7)E8W1O<GDL(&QA
M;F=T97-T+G!H<#HZ"@H@("`@("`\/W!H<`H*("`@("`@<V5T;&]C86QE*$Q#
M7TU%4U-!1T53+"`G;FQ?3DPG*3L*("`@("`@<'5T96YV*"=,04Y'/6YL7TY,
M)RD["B`@("`@('!U=&5N=B@G3$%.1U5!1T4];FQ?3DPG*3L*("`@("`@+R\@
M=7-E('1H92!T87(@=&5S="X*("`@("`@96-H;R!D9V5T=&5X="@G=&%R)RP@
M)TUE;6]R>2!E>&AA=7-T960G*3L*("`@("`@96-H;R`G/&)R("\^)SL*"B`@
M("`@("\O(%-P96-I9GD@;&]C871I;VX@;V8@=')A;G-L871I;VX@=&%B;&5S
M"B`@("`@(&)I;F1T97AT9&]M86EN*"=H;W)D92<L("<N+VQO8V%L92<I.PH*
M("`@("`@+R\@0VAO;W-E(&1O;6%I;@H@("`@("!T97AT9&]M86EN*"=H;W)D
M92<I.PH*("`@("`@+R\@4')I;G0@=&AE(&%L<F5A9'D@=&5S=&5D(&UE<W-A
M9V4*("`@("`@96-H;R!?*")-97-S86=E(BD["B`@("`@(&5C:&\@)SQB<B`O
M/B<["@H@("`@("`O+R!T:&ES('-H;W5L9"!P<FEN="!T:&4@<V%M92X*("`@
M("`@96-H;R!D9V5T=&5X="@G:&]R9&4G+"`G365S<V%G92<I.PH*("`@("`@
M/SX*"B`@($]U='!U="!W96(@8G)O=W-E<CHZ"@H@("`@("!'96AE=6=E;B!U
M:71G97!U=`H@("`@("!"97)I8VAT"B`@("`@($)E<FEC:'0*"@HN+B!?8&DQ
M.&X@;6%I;&EN9R!L:7-T8#H@:'1T<#HO+VAO<F1E+F]R9R]M86EL+PHN+B!?
M8$AO<F1E)W,@8G5G('-Y<W1E;6`Z(&AT='`Z+R]B=6=S+FAO<F1E+F]R9PHN
M+B!?1D%1.B!H='1P.B\O:&]R9&4N;W)G+V9A<2\*"@I3;VQA<FES"CT]/3T]
M/3T*"E-I;F-E('1H92`N;6\@9FEL97,@87)E(&)I;F%R>2P@=&AE>2!A<F4@
M<&QA=&9O<FT@<W!E8VEF:6,N("!9;W4@:&%V92!T;R!R97)U;@IM86ME(&EN
M(&%L;"!P;R!D:7)E8W1O<FEE<RX*"D]N(%-O;&%R:7,@-RP@>6]U(&1O;B=T
M(&AA=F4@=&AE(&!@4&%R=&EA;"!,;V-A;&5S("A354Y7<&QO8RE@8"!A;F0*
M8&!3=7!P;&5M96YT87)Y(%!A<G1I86P@3&]C86QE<R`H4U5.5W!L;V,Q*6!@
M('!A8VMA9V5S(&EN<W1A;&QE9"!I9B!Y;W4@9V5T.CH*"B`@("0@3$%.1SUN
M;%].3`H@("!C;W5L9&XG="!S970@;&]C86QE(&-O<G)E8W1L>0H*3VX@4V]L
M87)I<R`X+"!Y;W4@;75S="!I;G-T86QL('1H92!L;V-A;"!P86-K86=E<R!R
M97%U:7)E9"!F;W(@=&AE(&QO8V%L97,@>6]U"F1E<VER92`H9F]R(&5X86UP
M;&4L('EO=2!M87D@;F5E9"!T;R!I;G-T86QL(&!@4U5.5W=E=6]S8&`@9F]R
M(%=E<W1E<FX*175R;W!E86X@;&]C86QE<R!O<B!@8%-53E=M96%O<V!@(&9O
M<B!-:61D;&4@16%S=&5R;B!L;V-A;&5S*2X@(%1H92!P86-K86=E<PIA<F4@
M;&]C871E9"!O;B!3;V9T=V%R92!$:7-K(#$@;V8@,B!I;B!T:&4@9&ER96-T
M;W)Y.@I@8'-O;%\X7S$P,#%?<W!A<F,O<S`O4V]L87)I<U\X+U!R;V1U8W1@
M8`H*5&AI<R!I<R!W:&%T(&ET('-H;W5L9"!S87DZ"@I3;VQA<FES(#<Z.@H*
M("`@)"!P:V=I;F9O('P@9W)E<"!P;&]C"B`@('-Y<W1E;2`@("`@(%-53E=P
M;&]C("`@("`@(%!A<G1I86P@3&]C86QE<PH@("!S>7-T96T@("`@("!354Y7
M<&QO8S$@("`@("!3=7!P;&5M96YT87)Y(%!A<G1I86P@3&]C86QE<PH*4V]L
M87)I<R`X.CH*"B`@("0@<&MG:6YF;R!\(&=R97`@975O"B`@('-Y<W1E;2`@
M("`@(%-53E=C975O<R`@("`@($-E;G1R86P@175R;W!E($]3(%-U<'!O<G0*
M("`@<WES=&5M("`@("`@4U5.5V-E=6]X("`@("`@0V5N=')A;"!%=7)O<&4@
M-C0M8FET($]3(%-U<'!O<G0*("`@<WES=&5M("`@("`@4U5.5V5E=6]S("`@
M("`@16%S=&5R;B!%=7)O<&4@3U,@4W5P<&]R=`H@("!S>7-T96T@("`@("!3
M54Y7965U;W@@("`@("!%87-T97)N($5U<F]P92`V-"UB:70@3U,@4W5P<&]R
M=`H@("!S>7-T96T@("`@("!354Y7;F5U;W,@("`@("!.;W)T:&5R;B!%=7)O
M<&4@3U,@4W5P<&]R=`H@("!S>7-T96T@("`@("!354Y7;F5U;W@@("`@("!.
M;W)T:&5R;B!%=7)O<&4@-C0M8FET($]3(%-U<'!O<G0*("`@<WES=&5M("`@
M("`@4U5.5W-E=6]S("`@("`@4V]U=&AE<FX@175R;W!E($]3(%-U<'!O<G0*
M("`@<WES=&5M("`@("`@4U5.5W-E=6]X("`@("`@4V]U=&AE<FX@175R;W!E
M(#8T+6)I="!/4R!3=7!P;W)T"B`@('-Y<W1E;2`@("`@(%-53E=W975O<R`@
M("`@(%=E<W1E<FX@175R;W!E($]3(%-U<'!O<G0*("`@<WES=&5M("`@("`@
M4U5.5W=E=6]X("`@("`@5V5S=&5R;B!%=7)O<&4@-C0M8FET($]3(%-U<'!O
M<G0*"E1H92!S='5F9B!I<R!I;G-T86QL960@:6X@8&`O=7-R+VQI8B]L;V-A
M;&5@8#HZ"@H@("`D(&QS("]U<W(O;&EB+VQO8V%L92]N;`H@("!,0U]#3TQ,
M051%("`@3$-?0U194$4@("`@($Q#7TU%4U-!1T53("!,0U]-3TY%5$%262`@
M3$-?3E5-15))0R`@($Q#7U1)344@("`@("!N;"YS;RXQ"@I)="!W87,@<F5P
M;W)T960@=&AA="!T:&4@2%144"!S97)V97(@:&%S('1O(&)E(&QI;FME9"!T
M;R!T:&4@<V%M92!L:6)I;G1L+G-O"F9I;&4@87,@4$A0(&]N(%-O;&%R:7,N
M("!!;'-O+"!I="!M87D@8F4@<F5Q=6ER960@=&AA="!L:6)I;G1L+G-O(&)E
M(&QO861E9`IB969O<F4@;&EB8R!I<R!L;V%D960N("!)9B!Y;W4@87)E(&AA
M=FEN9R!C;VYF;&EC=',L('EO=2!M87D@8F4@86)L92!T;R!R97-I9&4*=&AE
M;2!B>2!S=&%R=&EN9R!A<&%C:&4@=VET:"!O;F4@;V8@=&AE(&9O;&QO=VEN
M9R!C;VUM86YD<SHZ"@H@("`D($Q$7U!214Q/040];&EB:6YT;"YS;R!A<&%C
M:&5C=&P@<W1A<G0*"@I&<F5E0E-$"CT]/3T]/3T*"E1O(&5N86)L92!55$8M
M."!S=7!P;W)T(&EN($AO<F1E+"!Y;W4@86QS;R!N965D(%541BTX('-U<'!O
M<G0@:6X*1G)E94)31"X@(%1H:7,@:7,@;F]T(&EN<W1A;&QE9"!B>2!D969A
M=6QT+"!Y;W4@;F5E9"!T;R!I;G-T86QL('1H90I@8'5T9CAL;V-A;&4M=VET
M:&]U="US=VED=&@M,#0P,S$Y8&`@<&%C:V%G92!O<B!P;W)T+@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O0T]064E.1P``````````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C$R-S,`,3`T,3<S
M-C(W-#,`,#$V-#$T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````D)("!'3E4@3$E"4D%262!'14Y%4D%,(%!50DQ)0R!,24-%
M3E-%"@D)("`@("`@(%9E<G-I;VX@,BP@2G5N92`Q.3DQ"@H@0V]P>7)I9VAT
M("A#*2`Q.3DQ($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BP@26YC+@H@("`@
M"0D@("`@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP@34$@
M(#`R,3$Q+3$S,#<@(%5300H@179E<GEO;F4@:7,@<&5R;6ET=&5D('1O(&-O
M<'D@86YD(&1I<W1R:6)U=&4@=F5R8F%T:6T@8V]P:65S"B!O9B!T:&ES(&QI
M8V5N<V4@9&]C=6UE;G0L(&)U="!C:&%N9VEN9R!I="!I<R!N;W0@86QL;W=E
M9"X*"EM4:&ES(&ES('1H92!F:7)S="!R96QE87-E9"!V97)S:6]N(&]F('1H
M92!L:6)R87)Y($=03"X@($ET(&ES"B!N=6UB97)E9"`R(&)E8V%U<V4@:70@
M9V]E<R!W:71H('9E<G-I;VX@,B!O9B!T:&4@;W)D:6YA<GD@1U!,+ET*"@D)
M"2`@("!0<F5A;6)L90H*("!4:&4@;&EC96YS97,@9F]R(&UO<W0@<V]F='=A
M<F4@87)E(&1E<VEG;F5D('1O('1A:V4@87=A>2!Y;W5R"F9R965D;VT@=&\@
M<VAA<F4@86YD(&-H86YG92!I="X@($)Y(&-O;G1R87-T+"!T:&4@1TY5($=E
M;F5R86P@4'5B;&EC"DQI8V5N<V5S(&%R92!I;G1E;F1E9"!T;R!G=6%R86YT
M964@>6]U<B!F<F5E9&]M('1O('-H87)E(&%N9"!C:&%N9V4*9G)E92!S;V9T
M=V%R92TM=&\@;6%K92!S=7)E('1H92!S;V9T=V%R92!I<R!F<F5E(&9O<B!A
M;&P@:71S('5S97)S+@H*("!4:&ES(&QI8V5N<V4L('1H92!,:6)R87)Y($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4L(&%P<&QI97,@=&\@<V]M90IS<&5C:6%L
M;'D@9&5S:6=N871E9"!&<F5E(%-O9G1W87)E($9O=6YD871I;VX@<V]F='=A
M<F4L(&%N9"!T;R!A;GD*;W1H97(@;&EB<F%R:65S('=H;W-E(&%U=&AO<G,@
M9&5C:61E('1O('5S92!I="X@(%EO=2!C86X@=7-E(&ET(&9O<@IY;W5R(&QI
M8G)A<FEE<RP@=&]O+@H*("!7:&5N('=E('-P96%K(&]F(&9R964@<V]F='=A
M<F4L('=E(&%R92!R969E<G)I;F<@=&\@9G)E961O;2P@;F]T"G!R:6-E+B`@
M3W5R($=E;F5R86P@4'5B;&EC($QI8V5N<V5S(&%R92!D97-I9VYE9"!T;R!M
M86ME('-U<F4@=&AA="!Y;W4*:&%V92!T:&4@9G)E961O;2!T;R!D:7-T<FEB
M=71E(&-O<&EE<R!O9B!F<F5E('-O9G1W87)E("AA;F0@8VAA<F=E(&9O<@IT
M:&ES('-E<G9I8V4@:68@>6]U('=I<V@I+"!T:&%T('EO=2!R96-E:79E('-O
M=7)C92!C;V1E(&]R(&-A;B!G970@:70*:68@>6]U('=A;G0@:70L('1H870@
M>6]U(&-A;B!C:&%N9V4@=&AE('-O9G1W87)E(&]R('5S92!P:65C97,@;V8@
M:70*:6X@;F5W(&9R964@<')O9W)A;7,[(&%N9"!T:&%T('EO=2!K;F]W('EO
M=2!C86X@9&\@=&AE<V4@=&AI;F=S+@H*("!4;R!P<F]T96-T('EO=7(@<FEG
M:'1S+"!W92!N965D('1O(&UA:V4@<F5S=')I8W1I;VYS('1H870@9F]R8FED
M"F%N>6]N92!T;R!D96YY('EO=2!T:&5S92!R:6=H=',@;W(@=&\@87-K('EO
M=2!T;R!S=7)R96YD97(@=&AE(')I9VAT<RX*5&AE<V4@<F5S=')I8W1I;VYS
M('1R86YS;&%T92!T;R!C97)T86EN(')E<W!O;G-I8FEL:71I97,@9F]R('EO
M=2!I9@IY;W4@9&ES=')I8G5T92!C;W!I97,@;V8@=&AE(&QI8G)A<GDL(&]R
M(&EF('EO=2!M;V1I9GD@:70N"@H@($9O<B!E>&%M<&QE+"!I9B!Y;W4@9&ES
M=')I8G5T92!C;W!I97,@;V8@=&AE(&QI8G)A<GDL('=H971H97(@9W)A=&ES
M"F]R(&9O<B!A(&9E92P@>6]U(&UU<W0@9VEV92!T:&4@<F5C:7!I96YT<R!A
M;&P@=&AE(')I9VAT<R!T:&%T('=E(&=A=F4*>6]U+B`@66]U(&UU<W0@;6%K
M92!S=7)E('1H870@=&AE>2P@=&]O+"!R96-E:79E(&]R(&-A;B!G970@=&AE
M('-O=7)C90IC;V1E+B`@268@>6]U(&QI;FL@82!P<F]G<F%M('=I=&@@=&AE
M(&QI8G)A<GDL('EO=2!M=7-T('!R;W9I9&4*8V]M<&QE=&4@;V)J96-T(&9I
M;&5S('1O('1H92!R96-I<&EE;G1S('-O('1H870@=&AE>2!C86X@<F5L:6YK
M('1H96T*=VET:"!T:&4@;&EB<F%R>2P@869T97(@;6%K:6YG(&-H86YG97,@
M=&\@=&AE(&QI8G)A<GD@86YD(')E8V]M<&EL:6YG"FET+B`@06YD('EO=2!M
M=7-T('-H;W<@=&AE;2!T:&5S92!T97)M<R!S;R!T:&5Y(&MN;W<@=&AE:7(@
M<FEG:'1S+@H*("!/=7(@;65T:&]D(&]F('!R;W1E8W1I;F<@>6]U<B!R:6=H
M=',@:&%S('1W;R!S=&5P<SH@*#$I(&-O<'ER:6=H=`IT:&4@;&EB<F%R>2P@
M86YD("@R*2!O9F9E<B!Y;W4@=&AI<R!L:6-E;G-E('=H:6-H(&=I=F5S('EO
M=2!L96=A;`IP97)M:7-S:6]N('1O(&-O<'DL(&1I<W1R:6)U=&4@86YD+V]R
M(&UO9&EF>2!T:&4@;&EB<F%R>2X*"B`@06QS;RP@9F]R(&5A8V@@9&ES=')I
M8G5T;W(G<R!P<F]T96-T:6]N+"!W92!W86YT('1O(&UA:V4@8V5R=&%I;@IT
M:&%T(&5V97)Y;VYE('5N9&5R<W1A;F1S('1H870@=&AE<F4@:7,@;F\@=V%R
M<F%N='D@9F]R('1H:7,@9G)E90IL:6)R87)Y+B`@268@=&AE(&QI8G)A<GD@
M:7,@;6]D:69I960@8GD@<V]M96]N92!E;'-E(&%N9"!P87-S960@;VXL('=E
M"G=A;G0@:71S(')E8VEP:65N=',@=&\@:VYO=R!T:&%T('=H870@=&AE>2!H
M879E(&ES(&YO="!T:&4@;W)I9VEN86P*=F5R<VEO;BP@<V\@=&AA="!A;GD@
M<')O8FQE;7,@:6YT<F]D=6-E9"!B>2!O=&AE<G,@=VEL;"!N;W0@<F5F;&5C
M="!O;@IT:&4@;W)I9VEN86P@875T:&]R<R<@<F5P=71A=&EO;G,N"@P*("!&
M:6YA;&QY+"!A;GD@9G)E92!P<F]G<F%M(&ES('1H<F5A=&5N960@8V]N<W1A
M;G1L>2!B>2!S;V9T=V%R90IP871E;G1S+B`@5V4@=VES:"!T;R!A=F]I9"!T
M:&4@9&%N9V5R('1H870@8V]M<&%N:65S(&1I<W1R:6)U=&EN9R!F<F5E"G-O
M9G1W87)E('=I;&P@:6YD:79I9'5A;&QY(&]B=&%I;B!P871E;G0@;&EC96YS
M97,L('1H=7,@:6X@969F96-T"G1R86YS9F]R;6EN9R!T:&4@<')O9W)A;2!I
M;G1O('!R;W!R:65T87)Y('-O9G1W87)E+B`@5&\@<')E=F5N="!T:&ES+`IW
M92!H879E(&UA9&4@:70@8VQE87(@=&AA="!A;GD@<&%T96YT(&UU<W0@8F4@
M;&EC96YS960@9F]R(&5V97)Y;VYE)W,*9G)E92!U<V4@;W(@;F]T(&QI8V5N
M<V5D(&%T(&%L;"X*"B`@36]S="!'3E4@<V]F='=A<F4L(&EN8VQU9&EN9R!S
M;VUE(&QI8G)A<FEE<RP@:7,@8V]V97)E9"!B>2!T:&4@;W)D:6YA<GD*1TY5
M($=E;F5R86P@4'5B;&EC($QI8V5N<V4L('=H:6-H('=A<R!D97-I9VYE9"!F
M;W(@=71I;&ET>2!P<F]G<F%M<RX@(%1H:7,*;&EC96YS92P@=&AE($=.52!,
M:6)R87)Y($=E;F5R86P@4'5B;&EC($QI8V5N<V4L(&%P<&QI97,@=&\@8V5R
M=&%I;@ID97-I9VYA=&5D(&QI8G)A<FEE<RX@(%1H:7,@;&EC96YS92!I<R!Q
M=6ET92!D:69F97)E;G0@9G)O;2!T:&4@;W)D:6YA<GD*;VYE.R!B92!S=7)E
M('1O(')E860@:70@:6X@9G5L;"P@86YD(&1O;B=T(&%S<W5M92!T:&%T(&%N
M>71H:6YG(&EN(&ET(&ES"G1H92!S86UE(&%S(&EN('1H92!O<F1I;F%R>2!L
M:6-E;G-E+@H*("!4:&4@<F5A<V]N('=E(&AA=F4@82!S97!A<F%T92!P=6)L
M:6,@;&EC96YS92!F;W(@<V]M92!L:6)R87)I97,@:7,@=&AA=`IT:&5Y(&)L
M=7(@=&AE(&1I<W1I;F-T:6]N('=E('5S=6%L;'D@;6%K92!B971W965N(&UO
M9&EF>6EN9R!O<B!A9&1I;F<@=&\@80IP<F]G<F%M(&%N9"!S:6UP;'D@=7-I
M;F<@:70N("!,:6YK:6YG(&$@<')O9W)A;2!W:71H(&$@;&EB<F%R>2P@=VET
M:&]U=`IC:&%N9VEN9R!T:&4@;&EB<F%R>2P@:7,@:6X@<V]M92!S96YS92!S
M:6UP;'D@=7-I;F<@=&AE(&QI8G)A<GDL(&%N9"!I<PIA;F%L;V=O=7,@=&\@
M<G5N;FEN9R!A('5T:6QI='D@<')O9W)A;2!O<B!A<'!L:6-A=&EO;B!P<F]G
M<F%M+B`@2&]W979E<BP@:6X*82!T97AT=6%L(&%N9"!L96=A;"!S96YS92P@
M=&AE(&QI;FME9"!E>&5C=71A8FQE(&ES(&$@8V]M8FEN960@=V]R:RP@80ID
M97)I=F%T:79E(&]F('1H92!O<FEG:6YA;"!L:6)R87)Y+"!A;F0@=&AE(&]R
M9&EN87)Y($=E;F5R86P@4'5B;&EC($QI8V5N<V4*=')E871S(&ET(&%S('-U
M8V@N"@H@($)E8V%U<V4@;V8@=&AI<R!B;'5R<F5D(&1I<W1I;F-T:6]N+"!U
M<VEN9R!T:&4@;W)D:6YA<GD@1V5N97)A;`I0=6)L:6,@3&EC96YS92!F;W(@
M;&EB<F%R:65S(&1I9"!N;W0@969F96-T:79E;'D@<')O;6]T92!S;V9T=V%R
M90IS:&%R:6YG+"!B96-A=7-E(&UO<W0@9&5V96QO<&5R<R!D:60@;F]T('5S
M92!T:&4@;&EB<F%R:65S+B`@5V4*8V]N8VQU9&5D('1H870@=V5A:V5R(&-O
M;F1I=&EO;G,@;6EG:'0@<')O;6]T92!S:&%R:6YG(&)E='1E<BX*"B`@2&]W
M979E<BP@=6YR97-T<FEC=&5D(&QI;FMI;F<@;V8@;F]N+69R964@<')O9W)A
M;7,@=V]U;&0@9&5P<FEV92!T:&4*=7-E<G,@;V8@=&AO<V4@<')O9W)A;7,@
M;V8@86QL(&)E;F5F:70@9G)O;2!T:&4@9G)E92!S=&%T=7,@;V8@=&AE"FQI
M8G)A<FEE<R!T:&5M<V5L=F5S+B`@5&AI<R!,:6)R87)Y($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@:7,@:6YT96YD960@=&\*<&5R;6ET(&1E=F5L;W!E<G,@
M;V8@;F]N+69R964@<')O9W)A;7,@=&\@=7-E(&9R964@;&EB<F%R:65S+"!W
M:&EL90IP<F5S97)V:6YG('EO=7(@9G)E961O;2!A<R!A('5S97(@;V8@<W5C
M:"!P<F]G<F%M<R!T;R!C:&%N9V4@=&AE(&9R964*;&EB<F%R:65S('1H870@
M87)E(&EN8V]R<&]R871E9"!I;B!T:&5M+B`@*%=E(&AA=F4@;F]T('-E96X@
M:&]W('1O(&%C:&EE=F4*=&AI<R!A<R!R96=A<F1S(&-H86YG97,@:6X@:&5A
M9&5R(&9I;&5S+"!B=70@=V4@:&%V92!A8VAI979E9"!I="!A<R!R96=A<F1S
M"F-H86YG97,@:6X@=&AE(&%C='5A;"!F=6YC=&EO;G,@;V8@=&AE($QI8G)A
M<GDN*2`@5&AE(&AO<&4@:7,@=&AA="!T:&ES"G=I;&P@;&5A9"!T;R!F87-T
M97(@9&5V96QO<&UE;G0@;V8@9G)E92!L:6)R87)I97,N"@H@(%1H92!P<F5C
M:7-E('1E<FUS(&%N9"!C;VYD:71I;VYS(&9O<B!C;W!Y:6YG+"!D:7-T<FEB
M=71I;VX@86YD"FUO9&EF:6-A=&EO;B!F;VQL;W<N("!087D@8VQO<V4@871T
M96YT:6]N('1O('1H92!D:69F97)E;F-E(&)E='=E96X@80HB=V]R:R!B87-E
M9"!O;B!T:&4@;&EB<F%R>2(@86YD(&$@(G=O<FL@=&AA="!U<V5S('1H92!L
M:6)R87)Y(BX@(%1H90IF;W)M97(@8V]N=&%I;G,@8V]D92!D97)I=F5D(&9R
M;VT@=&AE(&QI8G)A<GDL('=H:6QE('1H92!L871T97(@;VYL>0IW;W)K<R!T
M;V=E=&AE<B!W:71H('1H92!L:6)R87)Y+@H*("!.;W1E('1H870@:70@:7,@
M<&]S<VEB;&4@9F]R(&$@;&EB<F%R>2!T;R!B92!C;W9E<F5D(&)Y('1H92!O
M<F1I;F%R>0I'96YE<F%L(%!U8FQI8R!,:6-E;G-E(')A=&AE<B!T:&%N(&)Y
M('1H:7,@<W!E8VEA;"!O;F4N"@P*"0D@($=.52!,24)205)9($=%3D5204P@
M4%5"3$E#($Q)0T5.4T4*("`@5$5235,@04Y$($-/3D1)5$E/3E,@1D]2($-/
M4%E)3D<L($1)4U1224)55$E/3B!!3D0@34]$249)0T%424]."@H@(#`N(%1H
M:7,@3&EC96YS92!!9W)E96UE;G0@87!P;&EE<R!T;R!A;GD@<V]F='=A<F4@
M;&EB<F%R>2!W:&EC:`IC;VYT86EN<R!A(&YO=&EC92!P;&%C960@8GD@=&AE
M(&-O<'ER:6=H="!H;VQD97(@;W(@;W1H97(@875T:&]R:7IE9`IP87)T>2!S
M87EI;F<@:70@;6%Y(&)E(&1I<W1R:6)U=&5D('5N9&5R('1H92!T97)M<R!O
M9B!T:&ES($QI8G)A<GD*1V5N97)A;"!0=6)L:6,@3&EC96YS92`H86QS;R!C
M86QL960@(G1H:7,@3&EC96YS92(I+B`@16%C:"!L:6-E;G-E92!I<PIA9&1R
M97-S960@87,@(GEO=2(N"@H@($$@(FQI8G)A<GDB(&UE86YS(&$@8V]L;&5C
M=&EO;B!O9B!S;V9T=V%R92!F=6YC=&EO;G,@86YD+V]R(&1A=&$*<')E<&%R
M960@<V\@87,@=&\@8F4@8V]N=F5N:65N=&QY(&QI;FME9"!W:71H(&%P<&QI
M8V%T:6]N('!R;V=R86US"BAW:&EC:"!U<V4@<V]M92!O9B!T:&]S92!F=6YC
M=&EO;G,@86YD(&1A=&$I('1O(&9O<FT@97AE8W5T86)L97,N"@H@(%1H92`B
M3&EB<F%R>2(L(&)E;&]W+"!R969E<G,@=&\@86YY('-U8V@@<V]F='=A<F4@
M;&EB<F%R>2!O<B!W;W)K"G=H:6-H(&AA<R!B965N(&1I<W1R:6)U=&5D('5N
M9&5R('1H97-E('1E<FUS+B`@02`B=V]R:R!B87-E9"!O;B!T:&4*3&EB<F%R
M>2(@;65A;G,@96ET:&5R('1H92!,:6)R87)Y(&]R(&%N>2!D97)I=F%T:79E
M('=O<FL@=6YD97(*8V]P>7)I9VAT(&QA=SH@=&AA="!I<R!T;R!S87DL(&$@
M=V]R:R!C;VYT86EN:6YG('1H92!,:6)R87)Y(&]R(&$*<&]R=&EO;B!O9B!I
M="P@96ET:&5R('9E<F)A=&EM(&]R('=I=&@@;6]D:69I8V%T:6]N<R!A;F0O
M;W(@=')A;G-L871E9`IS=')A:6=H=&9O<G=A<F1L>2!I;G1O(&%N;W1H97(@
M;&%N9W5A9V4N("`H2&5R96EN869T97(L('1R86YS;&%T:6]N(&ES"FEN8VQU
M9&5D('=I=&AO=70@;&EM:71A=&EO;B!I;B!T:&4@=&5R;2`B;6]D:69I8V%T
M:6]N(BXI"@H@(")3;W5R8V4@8V]D92(@9F]R(&$@=V]R:R!M96%N<R!T:&4@
M<')E9F5R<F5D(&9O<FT@;V8@=&AE('=O<FL@9F]R"FUA:VEN9R!M;V1I9FEC
M871I;VYS('1O(&ET+B`@1F]R(&$@;&EB<F%R>2P@8V]M<&QE=&4@<V]U<F-E
M(&-O9&4@;65A;G,*86QL('1H92!S;W5R8V4@8V]D92!F;W(@86QL(&UO9'5L
M97,@:70@8V]N=&%I;G,L('!L=7,@86YY(&%S<V]C:6%T960*:6YT97)F86-E
M(&1E9FEN:71I;VX@9FEL97,L('!L=7,@=&AE('-C<FEP=',@=7-E9"!T;R!C
M;VYT<F]L(&-O;7!I;&%T:6]N"F%N9"!I;G-T86QL871I;VX@;V8@=&AE(&QI
M8G)A<GDN"@H@($%C=&EV:71I97,@;W1H97(@=&AA;B!C;W!Y:6YG+"!D:7-T
M<FEB=71I;VX@86YD(&UO9&EF:6-A=&EO;B!A<F4@;F]T"F-O=F5R960@8GD@
M=&AI<R!,:6-E;G-E.R!T:&5Y(&%R92!O=71S:61E(&ET<R!S8V]P92X@(%1H
M92!A8W0@;V8*<G5N;FEN9R!A('!R;V=R86T@=7-I;F<@=&AE($QI8G)A<GD@
M:7,@;F]T(')E<W1R:6-T960L(&%N9"!O=71P=70@9G)O;0IS=6-H(&$@<')O
M9W)A;2!I<R!C;W9E<F5D(&]N;'D@:68@:71S(&-O;G1E;G1S(&-O;G-T:71U
M=&4@82!W;W)K(&)A<V5D"F]N('1H92!,:6)R87)Y("AI;F1E<&5N9&5N="!O
M9B!T:&4@=7-E(&]F('1H92!,:6)R87)Y(&EN(&$@=&]O;"!F;W(*=W)I=&EN
M9R!I="DN("!7:&5T:&5R('1H870@:7,@=')U92!D97!E;F1S(&]N('=H870@
M=&AE($QI8G)A<GD@9&]E<PIA;F0@=VAA="!T:&4@<')O9W)A;2!T:&%T('5S
M97,@=&AE($QI8G)A<GD@9&]E<RX*("`*("`Q+B!9;W4@;6%Y(&-O<'D@86YD
M(&1I<W1R:6)U=&4@=F5R8F%T:6T@8V]P:65S(&]F('1H92!,:6)R87)Y)W,*
M8V]M<&QE=&4@<V]U<F-E(&-O9&4@87,@>6]U(')E8V5I=F4@:70L(&EN(&%N
M>2!M961I=6TL('!R;W9I9&5D('1H870*>6]U(&-O;G-P:6-U;W5S;'D@86YD
M(&%P<')O<')I871E;'D@<'5B;&ES:"!O;B!E86-H(&-O<'D@86X*87!P<F]P
M<FEA=&4@8V]P>7)I9VAT(&YO=&EC92!A;F0@9&ES8VQA:6UE<B!O9B!W87)R
M86YT>3L@:V5E<"!I;G1A8W0*86QL('1H92!N;W1I8V5S('1H870@<F5F97(@
M=&\@=&AI<R!,:6-E;G-E(&%N9"!T;R!T:&4@86)S96YC92!O9B!A;GD*=V%R
M<F%N='D[(&%N9"!D:7-T<FEB=71E(&$@8V]P>2!O9B!T:&ES($QI8V5N<V4@
M86QO;F<@=VET:"!T:&4*3&EB<F%R>2X*"B`@66]U(&UA>2!C:&%R9V4@82!F
M964@9F]R('1H92!P:'ES:6-A;"!A8W0@;V8@=')A;G-F97)R:6YG(&$@8V]P
M>2P*86YD('EO=2!M87D@870@>6]U<B!O<'1I;VX@;V9F97(@=V%R<F%N='D@
M<')O=&5C=&EO;B!I;B!E>&-H86YG92!F;W(@80IF964N"@P*("`R+B!9;W4@
M;6%Y(&UO9&EF>2!Y;W5R(&-O<'D@;W(@8V]P:65S(&]F('1H92!,:6)R87)Y
M(&]R(&%N>2!P;W)T:6]N"F]F(&ET+"!T:'5S(&9O<FUI;F<@82!W;W)K(&)A
M<V5D(&]N('1H92!,:6)R87)Y+"!A;F0@8V]P>2!A;F0*9&ES=')I8G5T92!S
M=6-H(&UO9&EF:6-A=&EO;G,@;W(@=V]R:R!U;F1E<B!T:&4@=&5R;7,@;V8@
M4V5C=&EO;B`Q"F%B;W9E+"!P<F]V:61E9"!T:&%T('EO=2!A;'-O(&UE970@
M86QL(&]F('1H97-E(&-O;F1I=&EO;G,Z"@H@("`@82D@5&AE(&UO9&EF:65D
M('=O<FL@;75S="!I='-E;&8@8F4@82!S;V9T=V%R92!L:6)R87)Y+@H*("`@
M(&(I(%EO=2!M=7-T(&-A=7-E('1H92!F:6QE<R!M;V1I9FEE9"!T;R!C87)R
M>2!P<F]M:6YE;G0@;F]T:6-E<PH@("`@<W1A=&EN9R!T:&%T('EO=2!C:&%N
M9V5D('1H92!F:6QE<R!A;F0@=&AE(&1A=&4@;V8@86YY(&-H86YG92X*"B`@
M("!C*2!9;W4@;75S="!C875S92!T:&4@=VAO;&4@;V8@=&AE('=O<FL@=&\@
M8F4@;&EC96YS960@870@;F\*("`@(&-H87)G92!T;R!A;&P@=&AI<F0@<&%R
M=&EE<R!U;F1E<B!T:&4@=&5R;7,@;V8@=&AI<R!,:6-E;G-E+@H*("`@(&0I
M($EF(&$@9F%C:6QI='D@:6X@=&AE(&UO9&EF:65D($QI8G)A<GD@<F5F97)S
M('1O(&$@9G5N8W1I;VX@;W(@80H@("`@=&%B;&4@;V8@9&%T82!T;R!B92!S
M=7!P;&EE9"!B>2!A;B!A<'!L:6-A=&EO;B!P<F]G<F%M('1H870@=7-E<PH@
M("`@=&AE(&9A8VEL:71Y+"!O=&AE<B!T:&%N(&%S(&%N(&%R9W5M96YT('!A
M<W-E9"!W:&5N('1H92!F86-I;&ET>0H@("`@:7,@:6YV;VME9"P@=&AE;B!Y
M;W4@;75S="!M86ME(&$@9V]O9"!F86ET:"!E9F9O<G0@=&\@96YS=7)E('1H
M870L"B`@("!I;B!T:&4@979E;G0@86X@87!P;&EC871I;VX@9&]E<R!N;W0@
M<W5P<&QY('-U8V@@9G5N8W1I;VX@;W(*("`@('1A8FQE+"!T:&4@9F%C:6QI
M='D@<W1I;&P@;W!E<F%T97,L(&%N9"!P97)F;W)M<R!W:&%T979E<B!P87)T
M(&]F"B`@("!I=',@<'5R<&]S92!R96UA:6YS(&UE86YI;F=F=6PN"@H@("`@
M*$9O<B!E>&%M<&QE+"!A(&9U;F-T:6]N(&EN(&$@;&EB<F%R>2!T;R!C;VUP
M=71E('-Q=6%R92!R;V]T<R!H87,*("`@(&$@<'5R<&]S92!T:&%T(&ES(&5N
M=&ER96QY('=E;&PM9&5F:6YE9"!I;F1E<&5N9&5N="!O9B!T:&4*("`@(&%P
M<&QI8V%T:6]N+B`@5&AE<F5F;W)E+"!3=6)S96-T:6]N(#)D(')E<75I<F5S
M('1H870@86YY"B`@("!A<'!L:6-A=&EO;BUS=7!P;&EE9"!F=6YC=&EO;B!O
M<B!T86)L92!U<V5D(&)Y('1H:7,@9G5N8W1I;VX@;75S=`H@("`@8F4@;W!T
M:6]N86PZ(&EF('1H92!A<'!L:6-A=&EO;B!D;V5S(&YO="!S=7!P;'D@:70L
M('1H92!S<75A<F4*("`@(')O;W0@9G5N8W1I;VX@;75S="!S=&EL;"!C;VUP
M=71E('-Q=6%R92!R;V]T<RXI"@I4:&5S92!R97%U:7)E;65N=',@87!P;'D@
M=&\@=&AE(&UO9&EF:65D('=O<FL@87,@82!W:&]L92X@($EF"FED96YT:69I
M86)L92!S96-T:6]N<R!O9B!T:&%T('=O<FL@87)E(&YO="!D97)I=F5D(&9R
M;VT@=&AE($QI8G)A<GDL"F%N9"!C86X@8F4@<F5A<V]N86)L>2!C;VYS:61E
M<F5D(&EN9&5P96YD96YT(&%N9"!S97!A<F%T92!W;W)K<R!I;@IT:&5M<V5L
M=F5S+"!T:&5N('1H:7,@3&EC96YS92P@86YD(&ET<R!T97)M<RP@9&\@;F]T
M(&%P<&QY('1O('1H;W-E"G-E8W1I;VYS('=H96X@>6]U(&1I<W1R:6)U=&4@
M=&AE;2!A<R!S97!A<F%T92!W;W)K<RX@($)U="!W:&5N('EO=0ID:7-T<FEB
M=71E('1H92!S86UE('-E8W1I;VYS(&%S('!A<G0@;V8@82!W:&]L92!W:&EC
M:"!I<R!A('=O<FL@8F%S960*;VX@=&AE($QI8G)A<GDL('1H92!D:7-T<FEB
M=71I;VX@;V8@=&AE('=H;VQE(&UU<W0@8F4@;VX@=&AE('1E<FUS(&]F"G1H
M:7,@3&EC96YS92P@=VAO<V4@<&5R;6ES<VEO;G,@9F]R(&]T:&5R(&QI8V5N
M<V5E<R!E>'1E;F0@=&\@=&AE"F5N=&ER92!W:&]L92P@86YD('1H=7,@=&\@
M96%C:"!A;F0@979E<GD@<&%R="!R96=A<F1L97-S(&]F('=H;R!W<F]T90II
M="X*"E1H=7,L(&ET(&ES(&YO="!T:&4@:6YT96YT(&]F('1H:7,@<V5C=&EO
M;B!T;R!C;&%I;2!R:6=H=',@;W(@8V]N=&5S=`IY;W5R(')I9VAT<R!T;R!W
M;W)K('=R:71T96X@96YT:7)E;'D@8GD@>6]U.R!R871H97(L('1H92!I;G1E
M;G0@:7,@=&\*97AE<F-I<V4@=&AE(')I9VAT('1O(&-O;G1R;VP@=&AE(&1I
M<W1R:6)U=&EO;B!O9B!D97)I=F%T:79E(&]R"F-O;&QE8W1I=F4@=V]R:W,@
M8F%S960@;VX@=&AE($QI8G)A<GDN"@I);B!A9&1I=&EO;BP@;65R92!A9V=R
M96=A=&EO;B!O9B!A;F]T:&5R('=O<FL@;F]T(&)A<V5D(&]N('1H92!,:6)R
M87)Y"G=I=&@@=&AE($QI8G)A<GD@*&]R('=I=&@@82!W;W)K(&)A<V5D(&]N
M('1H92!,:6)R87)Y*2!O;B!A('9O;'5M92!O9@IA('-T;W)A9V4@;W(@9&ES
M=')I8G5T:6]N(&UE9&EU;2!D;V5S(&YO="!B<FEN9R!T:&4@;W1H97(@=V]R
M:R!U;F1E<@IT:&4@<V-O<&4@;V8@=&AI<R!,:6-E;G-E+@H*("`S+B!9;W4@
M;6%Y(&]P="!T;R!A<'!L>2!T:&4@=&5R;7,@;V8@=&AE(&]R9&EN87)Y($=.
M52!'96YE<F%L(%!U8FQI8PI,:6-E;G-E(&EN<W1E860@;V8@=&AI<R!,:6-E
M;G-E('1O(&$@9VEV96X@8V]P>2!O9B!T:&4@3&EB<F%R>2X@(%1O(&1O"G1H
M:7,L('EO=2!M=7-T(&%L=&5R(&%L;"!T:&4@;F]T:6-E<R!T:&%T(')E9F5R
M('1O('1H:7,@3&EC96YS92P@<V\*=&AA="!T:&5Y(')E9F5R('1O('1H92!O
M<F1I;F%R>2!'3E4@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@=F5R<VEO;B`R
M+`II;G-T96%D(&]F('1O('1H:7,@3&EC96YS92X@("A)9B!A(&YE=V5R('9E
M<G-I;VX@=&AA;B!V97)S:6]N(#(@;V8@=&AE"F]R9&EN87)Y($=.52!'96YE
M<F%L(%!U8FQI8R!,:6-E;G-E(&AA<R!A<'!E87)E9"P@=&AE;B!Y;W4@8V%N
M('-P96-I9GD*=&AA="!V97)S:6]N(&EN<W1E860@:68@>6]U('=I<V@N*2`@
M1&\@;F]T(&UA:V4@86YY(&]T:&5R(&-H86YG92!I;@IT:&5S92!N;W1I8V5S
M+@H,"B`@3VYC92!T:&ES(&-H86YG92!I<R!M861E(&EN(&$@9VEV96X@8V]P
M>2P@:70@:7,@:7)R979E<G-I8FQE(&9O<@IT:&%T(&-O<'DL('-O('1H92!O
M<F1I;F%R>2!'3E4@1V5N97)A;"!0=6)L:6,@3&EC96YS92!A<'!L:65S('1O
M(&%L;`IS=6)S97%U96YT(&-O<&EE<R!A;F0@9&5R:79A=&EV92!W;W)K<R!M
M861E(&9R;VT@=&AA="!C;W!Y+@H*("!4:&ES(&]P=&EO;B!I<R!U<V5F=6P@
M=VAE;B!Y;W4@=VES:"!T;R!C;W!Y('!A<G0@;V8@=&AE(&-O9&4@;V8*=&AE
M($QI8G)A<GD@:6YT;R!A('!R;V=R86T@=&AA="!I<R!N;W0@82!L:6)R87)Y
M+@H*("`T+B!9;W4@;6%Y(&-O<'D@86YD(&1I<W1R:6)U=&4@=&AE($QI8G)A
M<GD@*&]R(&$@<&]R=&EO;B!O<@ID97)I=F%T:79E(&]F(&ET+"!U;F1E<B!3
M96-T:6]N(#(I(&EN(&]B:F5C="!C;V1E(&]R(&5X96-U=&%B;&4@9F]R;0IU
M;F1E<B!T:&4@=&5R;7,@;V8@4V5C=&EO;G,@,2!A;F0@,B!A8F]V92!P<F]V
M:61E9"!T:&%T('EO=2!A8V-O;7!A;GD*:70@=VET:"!T:&4@8V]M<&QE=&4@
M8V]R<F5S<&]N9&EN9R!M86-H:6YE+7)E861A8FQE('-O=7)C92!C;V1E+"!W
M:&EC:`IM=7-T(&)E(&1I<W1R:6)U=&5D('5N9&5R('1H92!T97)M<R!O9B!3
M96-T:6]N<R`Q(&%N9"`R(&%B;W9E(&]N(&$*;65D:75M(&-U<W1O;6%R:6QY
M('5S960@9F]R('-O9G1W87)E(&EN=&5R8VAA;F=E+@H*("!)9B!D:7-T<FEB
M=71I;VX@;V8@;V)J96-T(&-O9&4@:7,@;6%D92!B>2!O9F9E<FEN9R!A8V-E
M<W,@=&\@8V]P>0IF<F]M(&$@9&5S:6=N871E9"!P;&%C92P@=&AE;B!O9F9E
M<FEN9R!E<75I=F%L96YT(&%C8V5S<R!T;R!C;W!Y('1H90IS;W5R8V4@8V]D
M92!F<F]M('1H92!S86UE('!L86-E('-A=&ES9FEE<R!T:&4@<F5Q=6ER96UE
M;G0@=&\*9&ES=')I8G5T92!T:&4@<V]U<F-E(&-O9&4L(&5V96X@=&AO=6=H
M('1H:7)D('!A<G1I97,@87)E(&YO=`IC;VUP96QL960@=&\@8V]P>2!T:&4@
M<V]U<F-E(&%L;VYG('=I=&@@=&AE(&]B:F5C="!C;V1E+@H*("`U+B!!('!R
M;V=R86T@=&AA="!C;VYT86EN<R!N;R!D97)I=F%T:79E(&]F(&%N>2!P;W)T
M:6]N(&]F('1H90I,:6)R87)Y+"!B=70@:7,@9&5S:6=N960@=&\@=V]R:R!W
M:71H('1H92!,:6)R87)Y(&)Y(&)E:6YG(&-O;7!I;&5D(&]R"FQI;FME9"!W
M:71H(&ET+"!I<R!C86QL960@82`B=V]R:R!T:&%T('5S97,@=&AE($QI8G)A
M<GDB+B`@4W5C:"!A"G=O<FLL(&EN(&ES;VQA=&EO;BP@:7,@;F]T(&$@9&5R
M:79A=&EV92!W;W)K(&]F('1H92!,:6)R87)Y+"!A;F0*=&AE<F5F;W)E(&9A
M;&QS(&]U='-I9&4@=&AE('-C;W!E(&]F('1H:7,@3&EC96YS92X*"B`@2&]W
M979E<BP@;&EN:VEN9R!A(")W;W)K('1H870@=7-E<R!T:&4@3&EB<F%R>2(@
M=VET:"!T:&4@3&EB<F%R>0IC<F5A=&5S(&%N(&5X96-U=&%B;&4@=&AA="!I
M<R!A(&1E<FEV871I=F4@;V8@=&AE($QI8G)A<GD@*&)E8V%U<V4@:70*8V]N
M=&%I;G,@<&]R=&EO;G,@;V8@=&AE($QI8G)A<GDI+"!R871H97(@=&AA;B!A
M(")W;W)K('1H870@=7-E<R!T:&4*;&EB<F%R>2(N("!4:&4@97AE8W5T86)L
M92!I<R!T:&5R969O<F4@8V]V97)E9"!B>2!T:&ES($QI8V5N<V4N"E-E8W1I
M;VX@-B!S=&%T97,@=&5R;7,@9F]R(&1I<W1R:6)U=&EO;B!O9B!S=6-H(&5X
M96-U=&%B;&5S+@H*("!7:&5N(&$@(G=O<FL@=&AA="!U<V5S('1H92!,:6)R
M87)Y(B!U<V5S(&UA=&5R:6%L(&9R;VT@82!H96%D97(@9FEL90IT:&%T(&ES
M('!A<G0@;V8@=&AE($QI8G)A<GDL('1H92!O8FIE8W0@8V]D92!F;W(@=&AE
M('=O<FL@;6%Y(&)E(&$*9&5R:79A=&EV92!W;W)K(&]F('1H92!,:6)R87)Y
M(&5V96X@=&AO=6=H('1H92!S;W5R8V4@8V]D92!I<R!N;W0N"E=H971H97(@
M=&AI<R!I<R!T<G5E(&ES(&5S<&5C:6%L;'D@<VEG;FEF:6-A;G0@:68@=&AE
M('=O<FL@8V%N(&)E"FQI;FME9"!W:71H;W5T('1H92!,:6)R87)Y+"!O<B!I
M9B!T:&4@=V]R:R!I<R!I='-E;&8@82!L:6)R87)Y+B`@5&AE"G1H<F5S:&]L
M9"!F;W(@=&AI<R!T;R!B92!T<G5E(&ES(&YO="!P<F5C:7-E;'D@9&5F:6YE
M9"!B>2!L87<N"@H@($EF('-U8V@@86X@;V)J96-T(&9I;&4@=7-E<R!O;FQY
M(&YU;65R:6-A;"!P87)A;65T97)S+"!D871A"G-T<G5C='5R92!L87EO=71S
M(&%N9"!A8V-E<W-O<G,L(&%N9"!S;6%L;"!M86-R;W,@86YD('-M86QL(&EN
M;&EN90IF=6YC=&EO;G,@*'1E;B!L:6YE<R!O<B!L97-S(&EN(&QE;F=T:"DL
M('1H96X@=&AE('5S92!O9B!T:&4@;V)J96-T"F9I;&4@:7,@=6YR97-T<FEC
M=&5D+"!R96=A<F1L97-S(&]F('=H971H97(@:70@:7,@;&5G86QL>2!A(&1E
M<FEV871I=F4*=V]R:RX@("A%>&5C=71A8FQE<R!C;VYT86EN:6YG('1H:7,@
M;V)J96-T(&-O9&4@<&QU<R!P;W)T:6]N<R!O9B!T:&4*3&EB<F%R>2!W:6QL
M('-T:6QL(&9A;&P@=6YD97(@4V5C=&EO;B`V+BD*"B`@3W1H97)W:7-E+"!I
M9B!T:&4@=V]R:R!I<R!A(&1E<FEV871I=F4@;V8@=&AE($QI8G)A<GDL('EO
M=2!M87D*9&ES=')I8G5T92!T:&4@;V)J96-T(&-O9&4@9F]R('1H92!W;W)K
M('5N9&5R('1H92!T97)M<R!O9B!396-T:6]N(#8N"D%N>2!E>&5C=71A8FQE
M<R!C;VYT86EN:6YG('1H870@=V]R:R!A;'-O(&9A;&P@=6YD97(@4V5C=&EO
M;B`V+`IW:&5T:&5R(&]R(&YO="!T:&5Y(&%R92!L:6YK960@9&ER96-T;'D@
M=VET:"!T:&4@3&EB<F%R>2!I='-E;&8N"@P*("`V+B!!<R!A;B!E>&-E<'1I
M;VX@=&\@=&AE(%-E8W1I;VYS(&%B;W9E+"!Y;W4@;6%Y(&%L<V\@8V]M<&EL
M92!O<@IL:6YK(&$@(G=O<FL@=&AA="!U<V5S('1H92!,:6)R87)Y(B!W:71H
M('1H92!,:6)R87)Y('1O('!R;V1U8V4@80IW;W)K(&-O;G1A:6YI;F<@<&]R
M=&EO;G,@;V8@=&AE($QI8G)A<GDL(&%N9"!D:7-T<FEB=71E('1H870@=V]R
M:PIU;F1E<B!T97)M<R!O9B!Y;W5R(&-H;VEC92P@<')O=FED960@=&AA="!T
M:&4@=&5R;7,@<&5R;6ET"FUO9&EF:6-A=&EO;B!O9B!T:&4@=V]R:R!F;W(@
M=&AE(&-U<W1O;65R)W,@;W=N('5S92!A;F0@<F5V97)S90IE;F=I;F5E<FEN
M9R!F;W(@9&5B=6=G:6YG('-U8V@@;6]D:69I8V%T:6]N<RX*"B`@66]U(&UU
M<W0@9VEV92!P<F]M:6YE;G0@;F]T:6-E('=I=&@@96%C:"!C;W!Y(&]F('1H
M92!W;W)K('1H870@=&AE"DQI8G)A<GD@:7,@=7-E9"!I;B!I="!A;F0@=&AA
M="!T:&4@3&EB<F%R>2!A;F0@:71S('5S92!A<F4@8V]V97)E9"!B>0IT:&ES
M($QI8V5N<V4N("!9;W4@;75S="!S=7!P;'D@82!C;W!Y(&]F('1H:7,@3&EC
M96YS92X@($EF('1H92!W;W)K"F1U<FEN9R!E>&5C=71I;VX@9&ES<&QA>7,@
M8V]P>7)I9VAT(&YO=&EC97,L('EO=2!M=7-T(&EN8VQU9&4@=&AE"F-O<'ER
M:6=H="!N;W1I8V4@9F]R('1H92!,:6)R87)Y(&%M;VYG('1H96TL(&%S('=E
M;&P@87,@82!R969E<F5N8V4*9&ER96-T:6YG('1H92!U<V5R('1O('1H92!C
M;W!Y(&]F('1H:7,@3&EC96YS92X@($%L<V\L('EO=2!M=7-T(&1O(&]N90IO
M9B!T:&5S92!T:&EN9W,Z"@H@("`@82D@06-C;VUP86YY('1H92!W;W)K('=I
M=&@@=&AE(&-O;7!L971E(&-O<G)E<W!O;F1I;F<*("`@(&UA8VAI;F4M<F5A
M9&%B;&4@<V]U<F-E(&-O9&4@9F]R('1H92!,:6)R87)Y(&EN8VQU9&EN9R!W
M:&%T979E<@H@("`@8VAA;F=E<R!W97)E('5S960@:6X@=&AE('=O<FL@*'=H
M:6-H(&UU<W0@8F4@9&ES=')I8G5T960@=6YD97(*("`@(%-E8W1I;VYS(#$@
M86YD(#(@86)O=F4I.R!A;F0L(&EF('1H92!W;W)K(&ES(&%N(&5X96-U=&%B
M;&4@;&EN:V5D"B`@("!W:71H('1H92!,:6)R87)Y+"!W:71H('1H92!C;VUP
M;&5T92!M86-H:6YE+7)E861A8FQE(")W;W)K('1H870*("`@('5S97,@=&AE
M($QI8G)A<GDB+"!A<R!O8FIE8W0@8V]D92!A;F0O;W(@<V]U<F-E(&-O9&4L
M('-O('1H870@=&AE"B`@("!U<V5R(&-A;B!M;V1I9GD@=&AE($QI8G)A<GD@
M86YD('1H96X@<F5L:6YK('1O('!R;V1U8V4@82!M;V1I9FEE9`H@("`@97AE
M8W5T86)L92!C;VYT86EN:6YG('1H92!M;V1I9FEE9"!,:6)R87)Y+B`@*$ET
M(&ES('5N9&5R<W1O;V0*("`@('1H870@=&AE('5S97(@=VAO(&-H86YG97,@
M=&AE(&-O;G1E;G1S(&]F(&1E9FEN:71I;VYS(&9I;&5S(&EN('1H90H@("`@
M3&EB<F%R>2!W:6QL(&YO="!N96-E<W-A<FEL>2!B92!A8FQE('1O(')E8V]M
M<&EL92!T:&4@87!P;&EC871I;VX*("`@('1O('5S92!T:&4@;6]D:69I960@
M9&5F:6YI=&EO;G,N*0H*("`@(&(I($%C8V]M<&%N>2!T:&4@=V]R:R!W:71H
M(&$@=W)I='1E;B!O9F9E<BP@=F%L:60@9F]R(&%T"B`@("!L96%S="!T:')E
M92!Y96%R<RP@=&\@9VEV92!T:&4@<V%M92!U<V5R('1H92!M871E<FEA;',*
M("`@('-P96-I9FEE9"!I;B!3=6)S96-T:6]N(#9A+"!A8F]V92P@9F]R(&$@
M8VAA<F=E(&YO(&UO<F4*("`@('1H86X@=&AE(&-O<W0@;V8@<&5R9F]R;6EN
M9R!T:&ES(&1I<W1R:6)U=&EO;BX*"B`@("!C*2!)9B!D:7-T<FEB=71I;VX@
M;V8@=&AE('=O<FL@:7,@;6%D92!B>2!O9F9E<FEN9R!A8V-E<W,@=&\@8V]P
M>0H@("`@9G)O;2!A(&1E<VEG;F%T960@<&QA8V4L(&]F9F5R(&5Q=6EV86QE
M;G0@86-C97-S('1O(&-O<'D@=&AE(&%B;W9E"B`@("!S<&5C:69I960@;6%T
M97)I86QS(&9R;VT@=&AE('-A;64@<&QA8V4N"@H@("`@9"D@5F5R:69Y('1H
M870@=&AE('5S97(@:&%S(&%L<F5A9'D@<F5C96EV960@82!C;W!Y(&]F('1H
M97-E"B`@("!M871E<FEA;',@;W(@=&AA="!Y;W4@:&%V92!A;')E861Y('-E
M;G0@=&AI<R!U<V5R(&$@8V]P>2X*"B`@1F]R(&%N(&5X96-U=&%B;&4L('1H
M92!R97%U:7)E9"!F;W)M(&]F('1H92`B=V]R:R!T:&%T('5S97,@=&AE"DQI
M8G)A<GDB(&UU<W0@:6YC;'5D92!A;GD@9&%T82!A;F0@=71I;&ET>2!P<F]G
M<F%M<R!N965D960@9F]R"G)E<')O9'5C:6YG('1H92!E>&5C=71A8FQE(&9R
M;VT@:70N("!(;W=E=F5R+"!A<R!A('-P96-I86P@97AC97!T:6]N+`IT:&4@
M<V]U<F-E(&-O9&4@9&ES=')I8G5T960@;F5E9"!N;W0@:6YC;'5D92!A;GET
M:&EN9R!T:&%T(&ES(&YO<FUA;&QY"F1I<W1R:6)U=&5D("AI;B!E:71H97(@
M<V]U<F-E(&]R(&)I;F%R>2!F;W)M*2!W:71H('1H92!M86IO<@IC;VUP;VYE
M;G1S("AC;VUP:6QE<BP@:V5R;F5L+"!A;F0@<V\@;VXI(&]F('1H92!O<&5R
M871I;F<@<WES=&5M(&]N"G=H:6-H('1H92!E>&5C=71A8FQE(')U;G,L('5N
M;&5S<R!T:&%T(&-O;7!O;F5N="!I='-E;&8@86-C;VUP86YI97,*=&AE(&5X
M96-U=&%B;&4N"@H@($ET(&UA>2!H87!P96X@=&AA="!T:&ES(')E<75I<F5M
M96YT(&-O;G1R861I8W1S('1H92!L:6-E;G-E"G)E<W1R:6-T:6]N<R!O9B!O
M=&AE<B!P<F]P<FEE=&%R>2!L:6)R87)I97,@=&AA="!D;R!N;W0@;F]R;6%L
M;'D*86-C;VUP86YY('1H92!O<&5R871I;F<@<WES=&5M+B`@4W5C:"!A(&-O
M;G1R861I8W1I;VX@;65A;G,@>6]U(&-A;FYO=`IU<V4@8F]T:"!T:&5M(&%N
M9"!T:&4@3&EB<F%R>2!T;V=E=&AE<B!I;B!A;B!E>&5C=71A8FQE('1H870@
M>6]U"F1I<W1R:6)U=&4N"@P*("`W+B!9;W4@;6%Y('!L86-E(&QI8G)A<GD@
M9F%C:6QI=&EE<R!T:&%T(&%R92!A('=O<FL@8F%S960@;VX@=&AE"DQI8G)A
M<GD@<VED92UB>2US:61E(&EN(&$@<VEN9VQE(&QI8G)A<GD@=&]G971H97(@
M=VET:"!O=&AE<B!L:6)R87)Y"F9A8VEL:71I97,@;F]T(&-O=F5R960@8GD@
M=&AI<R!,:6-E;G-E+"!A;F0@9&ES=')I8G5T92!S=6-H(&$@8V]M8FEN960*
M;&EB<F%R>2P@<')O=FED960@=&AA="!T:&4@<V5P87)A=&4@9&ES=')I8G5T
M:6]N(&]F('1H92!W;W)K(&)A<V5D(&]N"G1H92!,:6)R87)Y(&%N9"!O9B!T
M:&4@;W1H97(@;&EB<F%R>2!F86-I;&ET:65S(&ES(&]T:&5R=VES90IP97)M
M:71T960L(&%N9"!P<F]V:61E9"!T:&%T('EO=2!D;R!T:&5S92!T=V\@=&AI
M;F=S.@H*("`@(&$I($%C8V]M<&%N>2!T:&4@8V]M8FEN960@;&EB<F%R>2!W
M:71H(&$@8V]P>2!O9B!T:&4@<V%M92!W;W)K"B`@("!B87-E9"!O;B!T:&4@
M3&EB<F%R>2P@=6YC;VUB:6YE9"!W:71H(&%N>2!O=&AE<B!L:6)R87)Y"B`@
M("!F86-I;&ET:65S+B`@5&AI<R!M=7-T(&)E(&1I<W1R:6)U=&5D('5N9&5R
M('1H92!T97)M<R!O9B!T:&4*("`@(%-E8W1I;VYS(&%B;W9E+@H*("`@(&(I
M($=I=F4@<')O;6EN96YT(&YO=&EC92!W:71H('1H92!C;VUB:6YE9"!L:6)R
M87)Y(&]F('1H92!F86-T"B`@("!T:&%T('!A<G0@;V8@:70@:7,@82!W;W)K
M(&)A<V5D(&]N('1H92!,:6)R87)Y+"!A;F0@97AP;&%I;FEN9PH@("`@=VAE
M<F4@=&\@9FEN9"!T:&4@86-C;VUP86YY:6YG('5N8V]M8FEN960@9F]R;2!O
M9B!T:&4@<V%M92!W;W)K+@H*("`X+B!9;W4@;6%Y(&YO="!C;W!Y+"!M;V1I
M9GDL('-U8FQI8V5N<V4L(&QI;FL@=VET:"P@;W(@9&ES=')I8G5T90IT:&4@
M3&EB<F%R>2!E>&-E<'0@87,@97AP<F5S<VQY('!R;W9I9&5D('5N9&5R('1H
M:7,@3&EC96YS92X@($%N>0IA='1E;7!T(&]T:&5R=VES92!T;R!C;W!Y+"!M
M;V1I9GDL('-U8FQI8V5N<V4L(&QI;FL@=VET:"P@;W(*9&ES=')I8G5T92!T
M:&4@3&EB<F%R>2!I<R!V;VED+"!A;F0@=VEL;"!A=71O;6%T:6-A;&QY('1E
M<FUI;F%T92!Y;W5R"G)I9VAT<R!U;F1E<B!T:&ES($QI8V5N<V4N("!(;W=E
M=F5R+"!P87)T:65S('=H;R!H879E(')E8V5I=F5D(&-O<&EE<RP*;W(@<FEG
M:'1S+"!F<F]M('EO=2!U;F1E<B!T:&ES($QI8V5N<V4@=VEL;"!N;W0@:&%V
M92!T:&5I<B!L:6-E;G-E<PIT97)M:6YA=&5D('-O(&QO;F<@87,@<W5C:"!P
M87)T:65S(')E;6%I;B!I;B!F=6QL(&-O;7!L:6%N8V4N"@H@(#DN(%EO=2!A
M<F4@;F]T(')E<75I<F5D('1O(&%C8V5P="!T:&ES($QI8V5N<V4L('-I;F-E
M('EO=2!H879E(&YO=`IS:6=N960@:70N("!(;W=E=F5R+"!N;W1H:6YG(&5L
M<V4@9W)A;G1S('EO=2!P97)M:7-S:6]N('1O(&UO9&EF>2!O<@ID:7-T<FEB
M=71E('1H92!,:6)R87)Y(&]R(&ET<R!D97)I=F%T:79E('=O<FMS+B`@5&AE
M<V4@86-T:6]N<R!A<F4*<')O:&EB:71E9"!B>2!L87<@:68@>6]U(&1O(&YO
M="!A8V-E<'0@=&AI<R!,:6-E;G-E+B`@5&AE<F5F;W)E+"!B>0IM;V1I9GEI
M;F<@;W(@9&ES=')I8G5T:6YG('1H92!,:6)R87)Y("AO<B!A;GD@=V]R:R!B
M87-E9"!O;B!T:&4*3&EB<F%R>2DL('EO=2!I;F1I8V%T92!Y;W5R(&%C8V5P
M=&%N8V4@;V8@=&AI<R!,:6-E;G-E('1O(&1O('-O+"!A;F0*86QL(&ET<R!T
M97)M<R!A;F0@8V]N9&ET:6]N<R!F;W(@8V]P>6EN9RP@9&ES=')I8G5T:6YG
M(&]R(&UO9&EF>6EN9PIT:&4@3&EB<F%R>2!O<B!W;W)K<R!B87-E9"!O;B!I
M="X*"B`@,3`N($5A8V@@=&EM92!Y;W4@<F5D:7-T<FEB=71E('1H92!,:6)R
M87)Y("AO<B!A;GD@=V]R:R!B87-E9"!O;B!T:&4*3&EB<F%R>2DL('1H92!R
M96-I<&EE;G0@875T;VUA=&EC86QL>2!R96-E:79E<R!A(&QI8V5N<V4@9G)O
M;2!T:&4*;W)I9VEN86P@;&EC96YS;W(@=&\@8V]P>2P@9&ES=')I8G5T92P@
M;&EN:R!W:71H(&]R(&UO9&EF>2!T:&4@3&EB<F%R>0IS=6)J96-T('1O('1H
M97-E('1E<FUS(&%N9"!C;VYD:71I;VYS+B`@66]U(&UA>2!N;W0@:6UP;W-E
M(&%N>2!F=7)T:&5R"G)E<W1R:6-T:6]N<R!O;B!T:&4@<F5C:7!I96YT<R<@
M97AE<F-I<V4@;V8@=&AE(')I9VAT<R!G<F%N=&5D(&AE<F5I;BX*66]U(&%R
M92!N;W0@<F5S<&]N<VEB;&4@9F]R(&5N9F]R8VEN9R!C;VUP;&EA;F-E(&)Y
M('1H:7)D('!A<G1I97,@=&\*=&AI<R!,:6-E;G-E+@H,"B`@,3$N($EF+"!A
M<R!A(&-O;G-E<75E;F-E(&]F(&$@8V]U<G0@:G5D9VUE;G0@;W(@86QL96=A
M=&EO;B!O9B!P871E;G0*:6YF<FEN9V5M96YT(&]R(&9O<B!A;GD@;W1H97(@
M<F5A<V]N("AN;W0@;&EM:71E9"!T;R!P871E;G0@:7-S=65S*2P*8V]N9&ET
M:6]N<R!A<F4@:6UP;W-E9"!O;B!Y;W4@*'=H971H97(@8GD@8V]U<G0@;W)D
M97(L(&%G<F5E;65N="!O<@IO=&AE<G=I<V4I('1H870@8V]N=')A9&EC="!T
M:&4@8V]N9&ET:6]N<R!O9B!T:&ES($QI8V5N<V4L('1H97D@9&\@;F]T"F5X
M8W5S92!Y;W4@9G)O;2!T:&4@8V]N9&ET:6]N<R!O9B!T:&ES($QI8V5N<V4N
M("!)9B!Y;W4@8V%N;F]T"F1I<W1R:6)U=&4@<V\@87,@=&\@<V%T:7-F>2!S
M:6UU;'1A;F5O=7-L>2!Y;W5R(&]B;&EG871I;VYS('5N9&5R('1H:7,*3&EC
M96YS92!A;F0@86YY(&]T:&5R('!E<G1I;F5N="!O8FQI9V%T:6]N<RP@=&AE
M;B!A<R!A(&-O;G-E<75E;F-E('EO=0IM87D@;F]T(&1I<W1R:6)U=&4@=&AE
M($QI8G)A<GD@870@86QL+B`@1F]R(&5X86UP;&4L(&EF(&$@<&%T96YT"FQI
M8V5N<V4@=V]U;&0@;F]T('!E<FUI="!R;WEA;'1Y+69R964@<F5D:7-T<FEB
M=71I;VX@;V8@=&AE($QI8G)A<GD@8GD*86QL('1H;W-E('=H;R!R96-E:79E
M(&-O<&EE<R!D:7)E8W1L>2!O<B!I;F1I<F5C=&QY('1H<F]U9V@@>6]U+"!T
M:&5N"G1H92!O;FQY('=A>2!Y;W4@8V]U;&0@<V%T:7-F>2!B;W1H(&ET(&%N
M9"!T:&ES($QI8V5N<V4@=V]U;&0@8F4@=&\*<F5F<F%I;B!E;G1I<F5L>2!F
M<F]M(&1I<W1R:6)U=&EO;B!O9B!T:&4@3&EB<F%R>2X*"DEF(&%N>2!P;W)T
M:6]N(&]F('1H:7,@<V5C=&EO;B!I<R!H96QD(&EN=F%L:60@;W(@=6YE;F9O
M<F-E86)L92!U;F1E<B!A;GD*<&%R=&EC=6QA<B!C:7)C=6US=&%N8V4L('1H
M92!B86QA;F-E(&]F('1H92!S96-T:6]N(&ES(&EN=&5N9&5D('1O(&%P<&QY
M+`IA;F0@=&AE('-E8W1I;VX@87,@82!W:&]L92!I<R!I;G1E;F1E9"!T;R!A
M<'!L>2!I;B!O=&AE<B!C:7)C=6US=&%N8V5S+@H*270@:7,@;F]T('1H92!P
M=7)P;W-E(&]F('1H:7,@<V5C=&EO;B!T;R!I;F1U8V4@>6]U('1O(&EN9G)I
M;F=E(&%N>0IP871E;G1S(&]R(&]T:&5R('!R;W!E<G1Y(')I9VAT(&-L86EM
M<R!O<B!T;R!C;VYT97-T('9A;&ED:71Y(&]F(&%N>0IS=6-H(&-L86EM<SL@
M=&AI<R!S96-T:6]N(&AA<R!T:&4@<V]L92!P=7)P;W-E(&]F('!R;W1E8W1I
M;F<@=&AE"FEN=&5G<FET>2!O9B!T:&4@9G)E92!S;V9T=V%R92!D:7-T<FEB
M=71I;VX@<WES=&5M('=H:6-H(&ES"FEM<&QE;65N=&5D(&)Y('!U8FQI8R!L
M:6-E;G-E('!R86-T:6-E<RX@($UA;GD@<&5O<&QE(&AA=F4@;6%D90IG96YE
M<F]U<R!C;VYT<FEB=71I;VYS('1O('1H92!W:61E(')A;F=E(&]F('-O9G1W
M87)E(&1I<W1R:6)U=&5D"G1H<F]U9V@@=&AA="!S>7-T96T@:6X@<F5L:6%N
M8V4@;VX@8V]N<VES=&5N="!A<'!L:6-A=&EO;B!O9B!T:&%T"G-Y<W1E;3L@
M:70@:7,@=7`@=&\@=&AE(&%U=&AO<B]D;VYO<B!T;R!D96-I9&4@:68@:&4@
M;W(@<VAE(&ES('=I;&QI;F<*=&\@9&ES=')I8G5T92!S;V9T=V%R92!T:')O
M=6=H(&%N>2!O=&AE<B!S>7-T96T@86YD(&$@;&EC96YS964@8V%N;F]T"FEM
M<&]S92!T:&%T(&-H;VEC92X*"E1H:7,@<V5C=&EO;B!I<R!I;G1E;F1E9"!T
M;R!M86ME('1H;W)O=6=H;'D@8VQE87(@=VAA="!I<R!B96QI979E9"!T;PIB
M92!A(&-O;G-E<75E;F-E(&]F('1H92!R97-T(&]F('1H:7,@3&EC96YS92X*
M"B`@,3(N($EF('1H92!D:7-T<FEB=71I;VX@86YD+V]R('5S92!O9B!T:&4@
M3&EB<F%R>2!I<R!R97-T<FEC=&5D(&EN"F-E<G1A:6X@8V]U;G1R:65S(&5I
M=&AE<B!B>2!P871E;G1S(&]R(&)Y(&-O<'ER:6=H=&5D(&EN=&5R9F%C97,L
M('1H90IO<FEG:6YA;"!C;W!Y<FEG:'0@:&]L9&5R('=H;R!P;&%C97,@=&AE
M($QI8G)A<GD@=6YD97(@=&AI<R!,:6-E;G-E(&UA>2!A9&0*86X@97AP;&EC
M:70@9V5O9W)A<&AI8V%L(&1I<W1R:6)U=&EO;B!L:6UI=&%T:6]N(&5X8VQU
M9&EN9R!T:&]S92!C;W5N=')I97,L"G-O('1H870@9&ES=')I8G5T:6]N(&ES
M('!E<FUI='1E9"!O;FQY(&EN(&]R(&%M;VYG(&-O=6YT<FEE<R!N;W0@=&AU
M<PIE>&-L=61E9"X@($EN('-U8V@@8V%S92P@=&AI<R!,:6-E;G-E(&EN8V]R
M<&]R871E<R!T:&4@;&EM:71A=&EO;B!A<R!I9@IW<FET=&5N(&EN('1H92!B
M;V1Y(&]F('1H:7,@3&EC96YS92X*"B`@,3,N(%1H92!&<F5E(%-O9G1W87)E
M($9O=6YD871I;VX@;6%Y('!U8FQI<V@@<F5V:7-E9"!A;F0O;W(@;F5W"G9E
M<G-I;VYS(&]F('1H92!,:6)R87)Y($=E;F5R86P@4'5B;&EC($QI8V5N<V4@
M9G)O;2!T:6UE('1O('1I;64N"E-U8V@@;F5W('9E<G-I;VYS('=I;&P@8F4@
M<VEM:6QA<B!I;B!S<&ER:70@=&\@=&AE('!R97-E;G0@=F5R<VEO;BP*8G5T
M(&UA>2!D:69F97(@:6X@9&5T86EL('1O(&%D9')E<W,@;F5W('!R;V)L96US
M(&]R(&-O;F-E<FYS+@H*16%C:"!V97)S:6]N(&ES(&=I=F5N(&$@9&ES=&EN
M9W5I<VAI;F<@=F5R<VEO;B!N=6UB97(N("!)9B!T:&4@3&EB<F%R>0IS<&5C
M:69I97,@82!V97)S:6]N(&YU;6)E<B!O9B!T:&ES($QI8V5N<V4@=VAI8V@@
M87!P;&EE<R!T;R!I="!A;F0*(F%N>2!L871E<B!V97)S:6]N(BP@>6]U(&AA
M=F4@=&AE(&]P=&EO;B!O9B!F;VQL;W=I;F<@=&AE('1E<FUS(&%N9`IC;VYD
M:71I;VYS(&5I=&AE<B!O9B!T:&%T('9E<G-I;VX@;W(@;V8@86YY(&QA=&5R
M('9E<G-I;VX@<'5B;&ES:&5D(&)Y"G1H92!&<F5E(%-O9G1W87)E($9O=6YD
M871I;VXN("!)9B!T:&4@3&EB<F%R>2!D;V5S(&YO="!S<&5C:69Y(&$*;&EC
M96YS92!V97)S:6]N(&YU;6)E<BP@>6]U(&UA>2!C:&]O<V4@86YY('9E<G-I
M;VX@979E<B!P=6)L:7-H960@8GD*=&AE($9R964@4V]F='=A<F4@1F]U;F1A
M=&EO;BX*#`H@(#$T+B!)9B!Y;W4@=VES:"!T;R!I;F-O<G!O<F%T92!P87)T
M<R!O9B!T:&4@3&EB<F%R>2!I;G1O(&]T:&5R(&9R964*<')O9W)A;7,@=VAO
M<V4@9&ES=')I8G5T:6]N(&-O;F1I=&EO;G,@87)E(&EN8V]M<&%T:6)L92!W
M:71H('1H97-E+`IW<FET92!T;R!T:&4@875T:&]R('1O(&%S:R!F;W(@<&5R
M;6ES<VEO;BX@($9O<B!S;V9T=V%R92!W:&EC:"!I<PIC;W!Y<FEG:'1E9"!B
M>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+"!W<FET92!T;R!T:&4@
M1G)E90I3;V9T=V%R92!&;W5N9&%T:6]N.R!W92!S;VUE=&EM97,@;6%K92!E
M>&-E<'1I;VYS(&9O<B!T:&ES+B`@3W5R"F1E8VES:6]N('=I;&P@8F4@9W5I
M9&5D(&)Y('1H92!T=V\@9V]A;',@;V8@<')E<V5R=FEN9R!T:&4@9G)E92!S
M=&%T=7,*;V8@86QL(&1E<FEV871I=F5S(&]F(&]U<B!F<F5E('-O9G1W87)E
M(&%N9"!O9B!P<F]M;W1I;F<@=&AE('-H87)I;F<*86YD(')E=7-E(&]F('-O
M9G1W87)E(&=E;F5R86QL>2X*"@D)"2`@("!.3R!705)204Y460H*("`Q-2X@
M0D5#055312!42$4@3$E"4D%262!)4R!,24-%3E-%1"!&4D5%($]&($-(05)'
M12P@5$A%4D4@25,@3D\*5T%24D%.5%D@1D]2(%1(12!,24)205)9+"!43R!4
M2$4@15A414Y4(%!%4DU)5%1%1"!"62!!4%!,24-!0DQ%($Q!5RX*15A#15!4
M(%=(14X@3U1(15)725-%(%-4051%1"!)3B!74DE424Y'(%1(12!#3U!94DE'
M2%0@2$],1$524R!!3D0O3U(*3U1(15(@4$%25$E%4R!04D]6241%(%1(12!,
M24)205)9(")!4R!)4R(@5TE42$]55"!705)204Y462!/1B!!3ED*2TE.1"P@
M14E42$52($584%)%4U-%1"!/4B!)35!,245$+"!)3D-,541)3D<L($)55"!.
M3U0@3$E-251%1"!43RP@5$A%"DE-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#
M2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4@I055)0
M3U-%+B`@5$A%($5.5$E212!225-+($%3(%1/(%1(12!154%,2519($%.1"!0
M15)&3U)-04Y#12!/1B!42$4*3$E"4D%262!)4R!7251((%E/52X@(%-(3U5,
M1"!42$4@3$E"4D%262!04D]612!$149%0U1)5D4L(%E/52!!4U-5344*5$A%
M($-/4U0@3T8@04Q,($Y%0T534T%262!315)624-)3D<L(%)%4$%)4B!/4B!#
M3U)214-424].+@H*("`Q-BX@24X@3D\@159%3E0@54Y,15-3(%)%455)4D5$
M($)9($%04$Q)0T%"3$4@3$%7($]2($%'4D5%1"!43R!)3@I74DE424Y'(%=)
M3$P@04Y9($-/4%E224=(5"!(3TQ$15(L($]2($%.62!/5$A%4B!005)462!7
M2$\@34%9($U/1$E&60I!3D0O3U(@4D5$25-44DE"551%(%1(12!,24)205)9
M($%3(%!%4DU)5%1%1"!!0D]612P@0D4@3$E!0DQ%(%1/(%E/50I&3U(@1$%-
M04=%4RP@24Y#3%5$24Y'($%.62!'14Y%4D%,+"!34$5#24%,+"!)3D-)1$5.
M5$%,($]2"D-/3E-%455%3E1)04P@1$%-04=%4R!!4DE324Y'($]55"!/1B!4
M2$4@55-%($]2($E.04))3$E462!43R!54T4@5$A%"DQ)0E)!4ED@*$E.0TQ5
M1$E.1R!"550@3D]4($Q)34E4140@5$\@3$]34R!/1B!$051!($]2($1!5$$@
M0D5)3D<*4D5.1$52140@24Y!0T-54D%412!/4B!,3U-315,@4U535$%)3D5$
M($)9(%E/52!/4B!42$E21"!005)42453($]2($$*1D%)3%5212!/1B!42$4@
M3$E"4D%262!43R!/4$52051%(%=)5$@@04Y9($]42$52(%-/1E1705)%*2P@
M159%3B!)1@I354-(($A/3$1%4B!/4B!/5$A%4B!005)462!(05,@0D5%3B!!
M1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-("D1!34%'15,N"@H)
M"2`@("`@14Y$($]&(%1%4DU3($%.1"!#3TY$251)3TY3"@P*("`@("`@("`@
M("!(;W<@=&\@07!P;'D@5&AE<V4@5&5R;7,@=&\@66]U<B!.97<@3&EB<F%R
M:65S"@H@($EF('EO=2!D979E;&]P(&$@;F5W(&QI8G)A<GDL(&%N9"!Y;W4@
M=V%N="!I="!T;R!B92!O9B!T:&4@9W)E871E<W0*<&]S<VEB;&4@=7-E('1O
M('1H92!P=6)L:6,L('=E(')E8V]M;65N9"!M86MI;F<@:70@9G)E92!S;V9T
M=V%R92!T:&%T"F5V97)Y;VYE(&-A;B!R961I<W1R:6)U=&4@86YD(&-H86YG
M92X@(%EO=2!C86X@9&\@<V\@8GD@<&5R;6ET=&EN9PIR961I<W1R:6)U=&EO
M;B!U;F1E<B!T:&5S92!T97)M<R`H;W(L(&%L=&5R;F%T:79E;'DL('5N9&5R
M('1H92!T97)M<R!O9B!T:&4*;W)D:6YA<GD@1V5N97)A;"!0=6)L:6,@3&EC
M96YS92DN"@H@(%1O(&%P<&QY('1H97-E('1E<FUS+"!A='1A8V@@=&AE(&9O
M;&QO=VEN9R!N;W1I8V5S('1O('1H92!L:6)R87)Y+B`@270@:7,*<V%F97-T
M('1O(&%T=&%C:"!T:&5M('1O('1H92!S=&%R="!O9B!E86-H('-O=7)C92!F
M:6QE('1O(&UO<W0@969F96-T:79E;'D*8V]N=F5Y('1H92!E>&-L=7-I;VX@
M;V8@=V%R<F%N='D[(&%N9"!E86-H(&9I;&4@<VAO=6QD(&AA=F4@870@;&5A
M<W0@=&AE"B)C;W!Y<FEG:'0B(&QI;F4@86YD(&$@<&]I;G1E<B!T;R!W:&5R
M92!T:&4@9G5L;"!N;W1I8V4@:7,@9F]U;F0N"@H@("`@/&]N92!L:6YE('1O
M(&=I=F4@=&AE(&QI8G)A<GDG<R!N86UE(&%N9"!A(&)R:65F(&ED96$@;V8@
M=VAA="!I="!D;V5S+CX*("`@($-O<'ER:6=H="`H0RD@/'EE87(^("`\;F%M
M92!O9B!A=71H;W(^"@H@("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A
M<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("`@;6]D:69Y
M(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QI8G)A<GD@1V5N97)A
M;"!0=6)L:6,*("`@($QI8V5N<V4@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E
M(%-O9G1W87)E($9O=6YD871I;VX[(&5I=&AE<@H@("`@=F5R<VEO;B`R(&]F
M('1H92!,:6-E;G-E+"!O<B`H870@>6]U<B!O<'1I;VXI(&%N>2!L871E<B!V
M97)S:6]N+@H*("`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T
M:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("`@8G5T(%=)5$A/
M550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R
M<F%N='D@;V8*("`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!
M(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@("!,:6)R87)Y
M($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@
M("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@
M3&EB<F%R>2!'96YE<F%L(%!U8FQI8PH@("`@3&EC96YS92!A;&]N9R!W:71H
M('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E90H@("`@
M1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L
M($)O<W1O;BP@34$@(#`R,3$Q+3$S,#<@(%5300H*06QS;R!A9&0@:6YF;W)M
M871I;VX@;VX@:&]W('1O(&-O;G1A8W0@>6]U(&)Y(&5L96-T<F]N:6,@86YD
M('!A<&5R(&UA:6PN"@I9;W4@<VAO=6QD(&%L<V\@9V5T('EO=7(@96UP;&]Y
M97(@*&EF('EO=2!W;W)K(&%S(&$@<')O9W)A;6UE<BD@;W(@>6]U<@IS8VAO
M;VPL(&EF(&%N>2P@=&\@<VEG;B!A(")C;W!Y<FEG:'0@9&ES8VQA:6UE<B(@
M9F]R('1H92!L:6)R87)Y+"!I9@IN96-E<W-A<GDN("!(97)E(&ES(&$@<V%M
M<&QE.R!A;'1E<B!T:&4@;F%M97,Z"@H@(%EO>6]D>6YE+"!);F,N+"!H97)E
M8GD@9&ES8VQA:6US(&%L;"!C;W!Y<FEG:'0@:6YT97)E<W0@:6X@=&AE"B`@
M;&EB<F%R>2!@1G)O8B<@*&$@;&EB<F%R>2!F;W(@='=E86MI;F<@:VYO8G,I
M('=R:71T96X@8GD@2F%M97,@4F%N9&]M($AA8VME<BX*"B`@/'-I9VYA='5R
M92!O9B!4>2!#;V]N/BP@,2!!<')I;"`Q.3DP"B`@5'D@0V]O;BP@4')E<VED
M96YT(&]F(%9I8V4*"E1H870G<R!A;&P@=&AE<F4@:7,@=&\@:70A"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"\`````````
M````````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#0`,#$U-S(U`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+W!O+P``````````````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,38S-#(`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O<&\O97-?15,N<&\`````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V-3(Q`#$P-#$W
M,S8R-S0S`#`Q-S<P,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C(%-P86YI<V@@=')A;G-L871I;VYS(&9O<B!H;W)D92!P
M86-K86=E"B,@5')A9'5C8VEO;F5S(&%L(&5S<&'Q;VP@<&%R82!E;"!P87%U
M971E(&AO<F1E+@HC($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J96-T
M"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI
M8V5N<V4@87,@=&AE(&AO<F1E('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G
M96YE<F%T960L(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T
M+4ED+59E<G-I;VXZ(%!A<W-W9"`S+C`M8W9S7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#0M,#8M,C(@,3@Z,S`K,#(P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-"TP-BTR,B`Q.#HS,"LP,C`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($UA;G5E;"!0+B!!>6%L82`\;6%Y86QA0'5N97@N97,^7&XB"B),86YG
M=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A
M/2`Q*3M<;B(*"B,Z(&QI8B]$<FEV97(O8V]M<&]S:71E+G!H<#HU.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<SH@=6YA8FQE('1O(&QO860@9')I=F5R.B`E
M<R(*;7-G<W1R("(E<SH@;F\@<V4@<'5E9&4@8V%R9V%R(&5L(&-O;G1R;VQA
M9&]R.B`E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C@P"FUS9VED(")"86-K96YD
M(&YO="!C;W)R96-T;'D@:6UP;&5M96YT960N(@IM<V=S='(@(DYO('-E(&AA
M(&1E<V%R<F]L;&%D;R!A9&5C=6%D86UE;G1E(&5L(&UO=&]R+B(*"B,Z(&UA
M:6XN<&AP.C(S,B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHY,PIM<V=I9"`B
M0VAA;F=E(%!A<W-W;W)D(@IM<V=S='(@(D-A;6)I87(@;&$@8V]N=')A<V7Q
M82(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C<X"FUS9VED(")#:&%N
M9V4@<&%S<W=O<F0@;VXZ(@IM<V=S='(@(D-A;6)I87(@8V]N=')A<V7Q82!E
M;CHB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ,PIM<V=I9"`B0VAA
M;F=E('EO=7(@<&%S<W=O<F0B"FUS9W-T<B`B0V%M8FEA<B!L82!C;VYT<F%S
M9?%A(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,B"FUS9W-T<B`B
M0V%M8FEA;F1O(&QA(&-O;G1R87-E\6$@96X@)7,B"@HC.B!T96UP;&%T97,O
M;6%I;B]M86EN+FEN8SHV-0IM<V=I9"`B0V]N9FER;2!N97<@<&%S<W=O<F0Z
M(@IM<V=S='(@(D-O;F9I<FUA<B!L82!N=65V82!C;VYT<F%S9?%A.B(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z.#0@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M-C,@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HX.`HC.B!L:6(O1')I=F5R+W-M
M8FQD87`N<&AP.C$V-@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S
M97)V97(B"FUS9W-T<B`B3F\@<V4@<'5E9&4@96YL87IA<B!A;"!S97)V:61O
M<B!L9&%P(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HV,"!L:6(O1')I=F5R
M+W-M8FQD87`N<&AP.C8U"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L
M9&%P('-E<G9E<B(*;7-G<W1R(").;R!S92!P=65D92!C;VYE8W1A<B!A;"!S
M97)V:61O<B!L9&%P(@H*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N<&AP.C4R
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"XB"FUS
M9W-T<B`B3F\@<V4@<'5E9&4@86)R:7(@=6YA(&-A;F%L:7IA8VGS;B!A('-M
M8G!A<W-W9"XB"@HC.B!L:6(O1')I=F5R+W-M8G!A<W-W9"YP:'`Z-C8*;7-G
M:60@(D5R<F]R('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N(@IM<V=S='(@
M(D5R<F]R(&%L(&5N=FEA<B!L;W,@9&%T;W,@82!S;6)P87-S=V0N(@H*(SH@
M;6%I;BYP:'`Z,3DS(&QI8B]$<FEV97(O8V]M<&]S:71E+G!H<#HY,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL=7)E(&EN(&-H86YG:6YG('!A<W-W;W)D
M(&]N("5S.B`E<R(*;7-G<W1R(")&86QL;R!A;"!C86UB:6%R(&QA(&-O;G1R
M87-E\6$@96X@)7,Z("5S(@H*(SH@=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z
M,3,*;7-G:60@(DAE;'`B"FUS9W-T<B`B07EU9&$B"@HC.B!L:6(O1')I=F5R
M+G!H<#HU,2!L:6(O1')I=F5R+VQD87`N<&AP.C$V-"!L:6(O1')I=F5R+W!O
M<'!A<W-D+G!H<#HQ,#8*(SH@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HQ-C<@
M;&EB+T1R:79E<B]V;6%I;&UG<BYP:'`Z,S4*;7-G:60@(DEN8V]R<F5C="!0
M87-S=V]R9"(*;7-G<W1R(")#;VYT<F%S9?%A(&EN8V]R<F5C=&$B"@HC.B!T
M96UP;&%T97,O;6%I;B]M86EN+FEN8SHU,PIM<V=I9"`B3F5W('!A<W-W;W)D
M.B(*;7-G<W1R(").=65V82!C;VYT<F%S9?%A.B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!S=6-H(&)A8VME;F0@
M)R5S)R!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@96P@;6]T;W(@
M)R5S)RXB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHT,0IM<V=I9"`B
M3VQD('!A<W-W;W)D.B(*;7-G<W1R(")!;G1I9W5A(&-O;G1R87-E\6$Z(@H*
M(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N<&AP.C0R"FUS9VED(")087-S=V0@
M:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960N(@IM<V=S='(@(E!A<W-W9"!N
M;R!E<W3A(&)I96X@8V]N9FEG=7)A9&\N(@H*(SH@;6%I;BYP:'`Z,3DP"B,L
M('!H<"UF;W)M870*;7-G:60@(E!A<W-W;W)D(&-H86YG960@;VX@)7,N(@IM
M<V=S='(@(E-E(&AA(&-A;6)I861O(&QA(&-O;G1R87-E\6$@96X@)7,N(@H*
M(SH@;6%I;BYP:'`Z,3<Q(&QI8B]$<FEV97(O<V5R=G5F='`N<&AP.C8V"FUS
M9VED(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R
M960B"FUS9W-T<B`B16P@;?-D=6QO(&1E(&-O;G1R87-E\6%S(&YO(&5S=.$@
M8FEE;B!C;VYF:6=U<F%D;R(*"B,Z(&QI8B]$<FEV97(O<V5R=G5F='`N<&AP
M.CDS"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O
M;F9I9W5R960N(@IM<V=S='(@(D5L(&WS9'5L;R!D92!C;VYT<F%S9?%A<R!N
M;R!E<W3A(&)I96X@8V]N9FEG=7)A9&\N(@H*(SH@;&EB+T1R:79E<B]C;VUP
M;W-I=&4N<&AP.C,T"FUS9VED(")297%U:7)E9"`G9')I=F5R<R<@:7,@;6ES
M8V]N9FEG=7)E9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HB3&]S("=C;VYT<F]L861O<F5S)R!R97%U97)I9&]S(&5S=.%N(&1E
M<V-O;F9I9W5R861O<R!E;B!L82!C;VYF:6=U<F%C:?-N(&1E("(*(E)E9&%C
M8VGS;BXB"@HC.B!L:6(O1')I=F5R+W-Q;"YP:'`Z-#`*;7-G:60@(E)E<75I
M<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%!A<W-W9"!344P@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F\@<V4@:&$@97-P96-I9FEC861O
M(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@4&%S<W=D(%-13"!E;"`G<&AP='EP
M92<@(@HB<F5Q=65R:61O+B(*"B,Z(&QI8B]$<FEV97(O=G!O<&UA:6PN<&AP
M.C0R"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I
M;B!344P@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F\@<V4@:&$@97-P
M96-I9FEC861O(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@4U%,(&5L("=P:'!T
M>7!E)R!R97%U97)I9&\N(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z
M.30*;7-G:60@(E)E<V5T(@IM<V=S='(@(DQI;7!I87(B"@HC.B!L:6(O1')I
M=F5R+W-Q;"YP:'`Z-CD@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z-S8*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@
M(DEN8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!344PN(@H*(SH@
M;&EB+T1R:79E<B]P;W!P87-S9"YP:'`Z,3`P(&QI8B]$<FEV97(O<W%L+G!H
M<#HQ,3@*(SH@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z,3,U"FUS9VED(")5
M<V5R(&YO="!F;W5N9"(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!U<W5A
M<FEO(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,C$@;&EB+T1R:79E<B]P
M:6YE+G!H<#HR,3D@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HQ,C0*;7-G:60@
M(E5S97(@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!U
M<W5A<FEO+B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C(X"FUS9VED
M(")5<V5R;F%M93HB"FUS9W-T<B`B57-U87)I;SHB"@HC.B!M86EN+G!H<#HS
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N)W0@8VAA;F=E('!A<W-W
M;W)D(&9O<B!U<V5R("5S(@IM<V=S='(@(DYO('!U961E(&-A;6)I87(@;&$@
M8VQA=F4@9&5L('5S=6%R:6\@)7,B"@HC.B!M86EN+G!H<#HT-PIM<V=I9"`B
M66]U(&UU<W0@9VEV92!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T<B`B
M5&EE;F4@<75E(&EN=')O9'5C:7(@<W4@8V]N=')A<V7Q82!A8W1U86PB"@HC
M.B!M86EN+G!H<#HU-@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y;W5R(&YE=R!P
M87-S=V]R9"(*;7-G<W1R(")4:65N92!Q=64@:6YT<F]D=6-I<B!S=2!N=65V
M82!C;VYT<F%S9?%A(@H*(SH@;6%I;BYP:'`Z-C`*;7-G:60@(EEO=2!M=7-T
M('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")4:65N92!Q=64@
M8V]M<')O8F%R(&QA(&-O;G1R87-E\6$@;G5E=F$B"@HC.B!M86EN+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&YE=R!P87-S=V]R9"!I
M<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@8F4@;6]R92!T:&%N("5D
M(&-H87)A8W1E<G,@(@HB;&]N9R$B"FUS9W-T<B`B(@HB4W4@;G5E=F$@8V]N
M=')A<V7Q82!E<R!D96UA<VEA9&\@;&%R9V$[(*%L87,@8V]N=')A<V7Q87,@
M;F\@<'5E9&5N('1E;F5R(&WA<R`B"B)D92`E9"!C87)A8W1E<F5S(2(*"B,Z
M(&UA:6XN<&AP.C$U.0IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O
M('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N9V5D(2(*;7-G<W1R("(B"B*A
M4W4@;G5E=F$@8V]N=')A<V7Q82!E<R!D96UA<VEA9&\@9N%C:6P@9&4@861I
M=FEN87(A(*%.;R!S92!H82!C86UB:6%D;R$B"@HC.B!M86EN+G!H<#HQ-3`*
M;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E
M<W,N($YO="!C:&%N9V5D(2(*;7-G<W1R("(B"B*A4W4@;G5E=F$@8V]N=')A
M<V7Q82!E<R!D96UA<VEA9&\@9N%C:6P@9&4@861I=FEN87(A(*%.;R!S92!H
M82!C86UB:6%D;R$B"@HC.B!M86EN+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H
M87)A8W1E<G,@;&]N9R$B"FUS9W-T<B`BH5-U(&YU979A(&-O;G1R87-E\6$@
M=&EE;F4@<75E('1E;F5R(&%L(&UE;F]S("5D(&-A<F%C=&5R97,A(@H*(SH@
M;6%I;BYP:'`Z-C@*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@
M9&EF9F5R96YT(&9R;VT@>6]U<B!C=7)R96YT('!A<W-W;W)D(@IM<V=S='(@
M(E-U(&YU979A(&-O;G1R87-E\6$@=&EE;F4@<75E('-E<B!D:7-T:6YT82!D
M92!L82!A8W1U86PB"@HC.B!M86EN+G!H<#HQ,C`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T
M("5D(&%L<&AA8F5T:6,@8VAA<F%C=&5R<RXB"FUS9W-T<B`B(@HB4W4@;G5E
M=F$@8V]N=')A<V7Q82!T:65N92!Q=64@8V]N=&5N97(@86P@;65N;W,@)60@
M8V%R86-T97)E<R!A;&9A8NET:6-O<RXB"@HC.B!M86EN+G!H<#HQ,C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT
M86EN(&%T(&QE87-T("5D(&%L<&AA;G5M97)I8R!C:&%R86-T97)S+B(*;7-G
M<W1R("(B"B)3=2!N=65V82!C;VYT<F%S9?%A('1I96YE('%U92!C;VYT96YE
M<B!A;"!M96YO<R`E9"!C87)A8W1E<F5S(&%L9F%N=6WI<FEC;W,N(@H*(SH@
M;6%I;BYP:'`Z,3,P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@;F5W
M('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!D:69F97)E;G0@
M='EP97,@;V8@8VAA<F%C=&5R<RX@(@HB5&AE('1Y<&5S(&%R93H@;&]W97(L
M('5P<&5R+"!N=6UE<FEC+"!A;F0@<WEM8F]L<RXB"FUS9W-T<B`B(@HB4W4@
M;G5E=F$@8V]N=')A<V7Q82!T:65N92!Q=64@8V]N=&5N97(@86P@;65N;W,@
M)60@=&EP;W,@9&ES=&EN=&]S(&1E("(*(F-A<F%C=&5R97,N($QO<R!T:7!O
M<R!S;VXZ(&UI;OIS8W5L87,L(&UA>?IS8W5L87,L(&[Z;65R;W,@>2!S[6UB
M;VQO<RXB"@HC.B!M86EN+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&QO
M=V5R8V%S92!C:&%R86-T97)S+B(*;7-G<W1R("(B"B)3=2!N=65V82!C;VYT
M<F%S9?%A('1I96YE('%U92!C;VYT96YE<B!A;"!M96YO<R`E9"!C87)A8W1E
M<F5S(&5N(&UI;OIS8W5L87,N(@H*(SH@;6%I;BYP:'`Z,3$U"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A
M="!L96%S="`E9"!N=6UE<FEC(&-H87)A8W1E<G,N(@IM<V=S='(@(B(*(E-U
M(&YU979A(&-O;G1R87-E\6$@=&EE;F4@<75E(&-O;G1E;F5R(&%L(&UE;F]S
M("5D(&-A<F%C=&5R97,@;G5MZ7)I8V]S+B(*"B,Z(&UA:6XN<&AP.C$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O
M;G1A:6X@870@;&5A<W0@)60@=7!P97)C87-E(&-H87)A8W1E<G,N(@IM<V=S
M='(@(B(*(E-U(&YU979A(&-O;G1R87-E\6$@=&EE;F4@<75E(&-O;G1E;F5R
M(&%L(&UE;F]S("5D(&-A<F%C=&5R97,@96X@;6%Y^G-C=6QA<RXB"@HC.B!M
M86EN+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&QE<W,@=&AA;B`E9"!W:&ET97-P86-E(&-H
M87)A8W1E<G,N(@IM<V=S='(@(E-U(&YU979A(&-O;G1R87-E\6$@=&EE;F4@
M<75E(&-O;G1E;F5R(&UE;F]S(&1E("5D(&5S<&%C:6]S+B(*"B,Z(&UA:6XN
M<&AP.C$S.`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!N;W0@8V]N
M=&%I;B!W:&ET97-P86-E(&-H87)A8W1E<G,N(@IM<V=S='(@(E-U(&YU979A
M(&-O;G1R87-E\6$@;F\@<'5E9&4@8V]N=&5N97(@97-P86-I;W,N(@H*(SH@
M;6%I;BYP:'`Z-C0*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D<R!D:61N)W0@
M;6%T8V@B"FUS9W-T<B`B3&$@8V]N=')A<V7Q82!N=65V82!Y(&QA(&%N=&EG
M=6$@;F\@8V]N8W5E<F1A;B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-C8@
M;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HW,0IM<V=I9"`B;&1A<%]S=&%R=%]T
M;',@9F%I;&5D(@IM<V=S='(@(FAA(&9A;&QA9&\@;&1A<%]S=&%R=%]T;',B
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]P;R]Z:%]#3BYP;P``````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`U-3``,3`T
M,3<S-C(W-#,`,#$W-S`Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````",@4&%S<W=D(&UO9'5L92!T<F%N<VQA=&EO;G,*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#(@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+"!)
M;F,N"B,@5V5N>FAU;R!::&%N9R`\=V5N>FAU;T!Z:&UA:6PN8V]M/BP@,C`P
M,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@
M<&%S<W=D7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P,BTQ,BTP-2`R,CHU
M-BLP.#`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R+3$R+3$R(#$R.C(S
M*S`X,#!<;B(*(DQA<W0M5')A;G-L871O<CH@5V5N>FAU;R!::&%N9R`\=V5N
M>FAU;T!Z:&UA:6PN8V]M/EQN(@HB3&%N9W5A9V4M5&5A;3H@4VEM<&QI9FEE
M9"!#:&EN97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R
M<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]1T(R,S$R7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M7&XB"@IM<V=I9"`B0VAA;F=E('EO=7(@<&%S<W=O<F0B"FUS9W-T<B`BT-ZX
MQ,/<PNLB"@IM<V=I9"`B0V]N9FER;2!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(LBWR,_0PL/<PNLB"@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S
M97)V97(B"FUS9W-T<B`BSMZWJ+#SMJBUO2!L9&%P(+?^SO'&]R(*"FUS9VED
M(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("+.
MWK>HP:R]T[6](&QD87`@M_[.\<;W(@H*;7-G:60@(D-O=6QD(&YO="!O<&5N
M('!I<&4@=&\@<VUB<&%S<W=D+B(*;7-G<W1R("+.WK>HM/*_JK6]('-M8G!A
M<W-W9""UQ+G<M<"AHR(*"FUS9VED(")%<G)O<B!C;&]S:6YG('!I<&4@=&\@
M<VUB<&%S<W=D(@IM<V=S='(@(KG8L=6UO2!S;6)P87-S=V0@M<2YW+7`RK&W
MHLGZM.W.\R(*"FUS9VED(")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S
M<W=D+B(*;7-G<W1R("*WHLO-ROV^W;6]('-M8G!A<W-W9"#*L;>BR?JT[<[S
M(@H*;7-G:60@(D5R<F]R(@IM<V=S='(@(K3MSO,B"@IM<V=I9"`B1F%I;'5R
M92!I;B!C:&%N9VEN9R!P87-S=V]R9"`Z("(*;7-G<W1R("+0WKC$P]S"Z\JG
ML-PB"@IM<V=I9"`B2&5L<"(*;7-G<W1R("*P[];Z(@H*;7-G:60@(DEN=&5R
M;F%L($5R<F]R(@IM<V=S='(@(L3:LK^T[<[S(@H*;7-G:60@(DQO9V]U="(*
M;7-G<W1R("+7HL_Z(@H*;7-G:60@(DUD865M;VX@<&%T:"!N;W0@9F]U;F0B
M"FUS9W-T<B`B361A96UO;B#"M[ZVSK35TK6](@H*;7-G:60@(DUD865M;VX@
M=7-E<FQI<W0@9FEL92!N;W0@86-C97-S86)L92!O<B!N;W0@9F]U;F0N(@IM
M<V=S='(@(DUD865M;VX@=7-E<FQI<W0@SL2\_K*[O\FWP\[*N_+.M-72M;VA
MHR(*"FUS9VED(")-97-S86=E(@IM<V=S='(@(L_[SZ(B"@IM<V=I9"`B3F5W
M('!A<W-W;W)D.B(*;7-G<W1R("+0PL/<PNNCNB(*"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("+#N]/0SJH@4U%,(,C/UJ3)Z+:HM<3%Y-;#
MT,7/HJ&C(@H*;7-G:60@(DYO="!A8FQE('1O(&-R96%T92!L;V-K(&9I;&4B
M"FUS9W-T<B`BSMZWJ+2TO:@@;&]C:R#.Q+S^(@H*;7-G:60@(DYO="!A8FQE
M('1O(&-R96%T92!S96UA<&AO<F4@9FEL92(*;7-G<W1R("+.WK>HM+2]J"!S
M96UA<&AO<F4@SL2\_B(*"FUS9VED(").;W0@86)L92!T;R!R971R:65V92!C
M=7)R96YT(&1E=&%I;',N(@IM<V=S='(@(L[>MZB[\<BAM;''L+7$S^K/N-#%
MSZ(B"@IM<V=I9"`B(@HB3F]T93H@66]U('=I;&P@;F5E9"!T;R!L;V=O=70@
M86YD(&)A8VL@:6X@869T97(@>6]U(&-H86YG92!Y;W5R('!A<W-W;W)D(2(*
M;7-G<W1R("+7HM+BH[K0WKC$P]S"Z[KSL=C0Z\W+L_;6V-#"M<?"O"$B"@IM
M<V=I9"`B3VQD('!A<W-W;W)D.B(*;7-G<W1R("*^R</<PNNCNB(*"FUS9VED
M(")087-S=V]R9"!C:&%N9V5D(2(*;7-G<W1R("+#W,+KTM'0WKC$(2(*"FUS
M9VED(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R
M960@340U(@IM<V=S='(@(L/<PNO$H[_IQ>36P[*[U?W(MR!-1#4B"@IM<V=I
M9"`B4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D
M(2(*;7-G<W1R("+#W,+KQ*._Z<7DUL.RN]7]R+<A(@H*;7-G:60@(E!A<W-W
M;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*;7-G<W1R
M("+#W,+KQ*._Z<7DUL.RN]7]R+<B"@IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE
M(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+B(*;7-G<W1R("+#W,+KQ*._
MZ<7DUL.RN]7]R+>AHR(*"FUS9VED(")0<F]B;&5M/R(*;7-G<W1R("+.RLSB
M/R(*"FUS9VED(")297%U:7)E9"`G9&%T86)A<V4G(&YO="!S<&5C:69I960@
M:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BR,_6
MI,7DUL/6T,ZTR>BVJ+'8T.BUQ"`G9&%T86)A<V4GH:,B"@IM<V=I9"`B4F5Q
M=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T
M:6]N(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(LC/UJ3%Y-;#UM#.M,GHMJBQ
MV-#HM<0@)VAO<W1S<&5C)Z&C(@H*;7-G:60@(E)E<75I<F5D("=P87-S=V]R
M9"<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("+(S]:DQ>36P];0SK3)Z+:HL=C0Z+7$("=P87-S=V]R
M9">AHR(*"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE
M9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+(
MS]:DQ>36P];0SK3)Z+:HL=C0Z+7$("=P:'!T>7!E)Z&C(@H*;7-G:60@(E)E
M<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO
M;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+(S]:DQ>36P];0SK3)Z+:HL=C0
MZ+7$("=T86)L92>AHR(*"FUS9VED(")297%U:7)E9"`G=7-E<FYA;64G(&YO
M="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BR,_6I,7DUL/6T,ZTR>BVJ+'8T.BUQ"`G=7-E<FYA;64GH:,B
M"@IM<V=I9"`B4F5S970B"FUS9W-T<B`BUMC6PR(*"FUS9VED(")3;VUE(&]F
M(%!A<W-W;W)D(&UO9'5L92=S(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI
M<W-I;F<Z(@IM<V=S='(@(L/<PNO$H[_IM<2RO[?6Q>36P\[$O/ZVJLJGH[HB
M"@IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("*SR;FF(@H*;7-G:60@(B(*(E1H
M:7,@:7,@=&AE(&UA:6X@4&%S<W=O<F0@;6]D=6QE(&-O;F9I9W5R871I;VX@
M9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD("(*(F]P=&EO;G,@9F]R(&%L
M;"!087-S=V]R9"!M;V1U;&4@<V-R:7!T<RXB"FUS9W-T<B`BU>+*Q\/<PNO$
MH[_IM<36]\7DUL/.Q+S^H:/+_+#\NJS+^=/0Q*._Z;W%L;ZUQ,*WOK:\L-&A
MS^ZAHR(*"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+B(*;7-G<W1R("+.WK>HP:R]T[6](%-13""W_L[QQO>AHR(*"B,L(&,M9F]R
M;6%T"FUS9VED(")5<V5R("5S0"5S(&YO="!F;W5N9"(*;7-G<W1R("+3P[NG
M("5S0"5S(,ZTU=*UO2(*"FUS9VED(")787)N:6YG(@IM<V=S='(@(KZON.8B
M"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H86YG92!P87-S=V]R
M9"!F;W(@=7-E<B`E<R(*;7-G<W1R("+$X[*[Q-S0WKC$T\.[IR`E<R"UQ,/<
MPNLB"@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9"(*
M;7-G<W1R("+$X['8T.O*Y,CKT,+#W,+K(@H*;7-G:60@(EEO=2!M=7-T(&=I
M=F4@>6]U<B!O;&0@<&%S<W=O<F0B"FUS9W-T<B`BQ..QV-#KS.&YJ;[)P]S"
MZR(*"FUS9VED(")9;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0B
M"FUS9W-T<B`BQ..QV-#KR+?(S]#"P]S"ZR(*"B,L(&,M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S
M(&UA>2!N;W0@8F4@;6]R92!T:&%N("5D(&-H87)A8W1E<G,@(@HB;&]N9R$B
M"FUS9W-T<B`BQ..UQ-#"P]S"Z\RKLZ0[(,/<PNNSI+;(LKO$W+.LN?T@)60@
MN/;7UK?[(2(*"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@<VEM
M<&QE('1O(&=U97-S(2`@3F]T(&-H86YG960A(@IM<V=S='(@(L3CM<30PL/<
MPNO,J[SRM:72U[+"(2#.M-?WT-ZXQ"$B"@HC+"!C+69O<FUA=`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!A="!L96%S="`E9"!C:&%R86-T
M97)S(&QO;F<A(@IM<V=S='(@(L3CM<30PL/<PNNQV-#KUL')V2`E9""X]M?6
MM_NSI"$B"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C
M:"(*;7-G<W1R("+$X[7$T,+#W,+KLKO2N];"(@H*;7-G:60@(EEO=7(@;VQD
M('!A<W-W;W)D(&ES;B=T(&-O<G)E8W0B"FUS9W-T<B`BQ..UQ+[)P]S"Z[*[
MU?W(MR(*"FUS9VED(")T96UP;F%M*"D@9F%I;&5D(2(*;7-G<W1R(")T96UP
M;F%M92@I(,JGL-PA(@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&%S<W=D+W!O+WIH7U17+G!O````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C`V,P`Q,#0Q-S,V,C<T,P`P
M,3<W-#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R!087-S=V0@;6]D=6QE('1R86YS;&%T:6]N<PHC($-O<'ER:6=H="`H
M0RD@,C`P,B!$879I9"!#:&%N9RX@L6FH?:3E+*5XQE<*(R!$879I9"!#:&%N
M9R`\9&%V:61`=&UV+F=O=BYT=SXL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R
M("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ('!A<W-W9"`R+C(M8W9S7&XB"B)2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,#@M,C$@,3,Z,38K,#@P,%QN(@HB
M4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP,BTQ.2`Q,#HR,RTP-C`P7&XB"B),
M87-T+51R86YS;&%T;W(Z($1A=FED($-H86YG(#QD879I9$!T;78N9V]V+G1W
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@5')A9&ET:6]N86P@0VAI;F5S92`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4)I9S5<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]$<FEV
M97(O97AP96-T+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S
M(&YO="!E>&ES="!O<B!I<R!N;W0@97AE8W5T86)L92XB"FUS9W-T<B`B)7,@
MI*.F<Z9BJ<ZU3*IKL/6FYBXB"@HC.B!L:6(O1')I=F5R+V-O;7!O<VET92YP
M:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z('5N86)L92!T;R!L;V%D
M(&1R:79E<CH@)7,B"FUS9W-T<B`B)7,Z(+5,JFNX_*1*Q5BPRK5[IJ$Z("5S
M(@H*(SH@;&EB+T1R:79E<B]A9'-I+G!H<#HU-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!1%-)(&5R<F]R("5S+B(*;7-G<W1R(")!1%-)(+_YNWX@)7,N(@H*
M(SH@;&EB+T1R:79E<B]A9'-I+G!H<#HU-R!L:6(O1')I=F5R+W!S<&%S<W=D
M+G!H<#HY-PIM<V=I9"`B06-C97-S($1E;FEE9"XB"FUS9W-T<B`BIG.H^KY$
MJ=HN(@H*(SH@;&EB+T1R:79E<BYP:'`Z.#`*;7-G:60@(D)A8VME;F0@;F]T
M(&-O<G)E8W1L>2!I;7!L96UE;G1E9"XB"FUS9W-T<B`BJ^&ZW:;XJD&^N:E\
MI;REO[U4I[FFJ"XB"@HC.B!M86EN+G!H<#HR-#8@=&5M<&QA=&5S+VUA:6XO
M;6%I;BYI;F,Z,30R"FUS9VED(")#:&%N9V4@4&%S<W=O<F0B"FUS9W-T<B`B
MI_.G[[%+O5@B"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ,C<*;7-G
M:60@(D-H86YG92!P87-S=V]R9"!O;CHB"FUS9W-T<B`BI_.G[[%+O5BI\SHB
M"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHV,@IM<V=I9"`B0VAA;F=E
M('EO=7(@<&%S<W=O<F0B"FUS9W-T<B`BI_.G[[%+O5@B"@HC.B!T96UP;&%T
M97,O;6%I;B]M86EN+FEN8SHV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#:&%N
M9VEN9R!P87-S=V]R9"!O;B`E<R(*;7-G<W1R("+%W*?SIF(@)7,@JKJQ2[U8
MI*0B"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ,30*;7-G:60@(D-O
M;F9I<FT@;F5W('!A<W-W;W)D.B(*;7-G<W1R("*]5+M[MW.Q2[U8.B(*"B,Z
M(&QI8B]$<FEV97(O:V]L86(N<&AP.C0X(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M.3,@;&EB+T1R:79E<B]L9&%P+G!H<#HR-#`*(SH@;&EB+T1R:79E<B]S;6)L
M9&%P+G!H<#HY,"!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C$W,0IM<V=I9"`B
M0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`BM4RJ:\.T
MM;(@;&1A<""F^*I!OKDB"@HC.B!L:6(O1')I=F5R+VMO;&%B+G!H<#HT,"!L
M:6(O1')I=F5R+VQD87`N<&AP.C8T(&QI8B]$<FEV97(O<VUB;&1A<"YP:'`Z
M-C<*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(K5,JFNS<[6R(&QD87`@IOBJ0;ZY(@H*(SH@;&EB+T1R:79E<B]S
M;6)P87-S=V0N<&AP.C4S"FUS9VED(")#;W5L9"!N;W0@;W!E;B!P:7!E('1O
M('-M8G!A<W-W9"XB"FUS9W-T<B`BM4RJ:[9]L=*H["!S;6)P87-S=V0@JKJZ
MWKUU+B(*"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HW-0IM<V=I9"`B
M17)R;W(@<V5N9&EN9R!D871A('1O('-M8G!A<W-W9"XB"FUS9W-T<B`BML>P
M9;CJKL:H["!S;6)P87-S=V0@KLFU;Z7-O_F[?BXB"@HC.B!L:6(O1')I=F5R
M+W!S<&%S<W=D+G!H<#HX-0IM<V=I9"`B1F%I;&5D('1O('9E<FEF>2!O;&0@
M<&%S<W=O<F0N(@IM<V=S='(@(L+"L4N]6+U4NWNEHK'1+B(*"B,Z(&UA:6XN
M<&AP.C(P,R!L:6(O1')I=F5R+V-O;7!O<VET92YP:'`Z.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"!O;B`E
M<SH@)7,B"FUS9W-T<B`BQ=RG\R`E<R"Q2[U8I:*QT3H@)7,B"@HC.B!L:6(O
M1')I=F5R+G!H<#HU,2!L:6(O1')I=F5R+VMO;&%B+G!H<#HW,B!L:6(O1')I
M=F5R+VQD87`N<&AP.C(T,0HC.B!L:6(O1')I=F5R+W!O<'!A<W-D+G!H<#HQ
M,#D@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HQ-S(*(SH@;&EB+T1R:79E<B]V
M;6%I;&UG<BYP:'`Z,S4*;7-G:60@(DEN8V]R<F5C="!087-S=V]R9"(*;7-G
M<W1R("*DHZ6_O52JNK%+O5@B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(R
M,PIM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP
M:7)E9"(*;7-G<W1R("+"PK%+O5BEO+E&I$"I=ZC/I<ZNR;:A(@H*(SH@=&5M
M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,3`R"FUS9VED(").97<@<&%S<W=O<F0Z
M(@IM<V=S='(@(K=SL4N]6#HB"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@<W5C:"!B86-K96YD("<E<R<@9F]U;F0N
M(@IM<V=S='(@(J?DI*.H[*:YIOBJ0;K=NMT@)R5S)RXB"@HC.B!T96UP;&%T
M97,O;6%I;B]M86EN+FEN8SHY,`IM<V=I9"`B3VQD('!A<W-W;W)D.B(*;7-G
M<W1R("+"PK%+O5@Z(@H*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N<&AP.C0S
M"FUS9VED(")087-S=V0@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960N(@IM
M<V=S='(@(E!A<W-W9""\TK+5J7REO*>YON.S5[FZ+B(*"B,Z(&UA:6XN<&AP
M.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")087-S=V]R9"!C:&%N9V5D(&]N
M("5S+B(*;7-G<W1R("(E<R"JNK%+O5BD=\7<I_,N(@H*(SH@;&EB+T1R:79E
M<B]P<W!A<W-W9"YP:'`Z-C<*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!C86XG
M="!F:6YD('1H92!S=7!P;&EE9"!B:6XN(@IM<V=S='(@(E!A<W-W;W)D(+S2
MLM6GY*2CJ.RDY+2IJKJU>Z:A+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S=V0N
M<&AP.C8U"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!R97%U
M:7)E9"!P87)A;65T97)S+B(*;7-G<W1R(")087-S=V]R9""\TK+5I^2DHZCL
MI;*M;JJZL-&\QBXB"@HC.B!L:6(O1')I=F5R+V%D<VDN<&AP.C0T"FUS9VED
M(")087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!T87)G970@<&%R86UE=&5R
M+B(*;7-G<W1R(")087-S=V]R9""\TK+5I^2DHZCLI=B\T+#1O,8N(@H*(SH@
M;6%I;BYP:'`Z,3<V(&QI8B]$<FEV97(O<V5R=G5F='`N<&AP.C8V"FUS9VED
M(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960B
M"FUS9W-T<B`B4&%S<W=O<F0@O-*RU:E\I;RGN;[CLU>YNB(*"B,Z(&QI8B]$
M<FEV97(O<V5R=G5F='`N<&AP.CDS"FUS9VED(")087-S=V]R9"!M;V1U;&4@
M:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960N(@IM<V=S='(@(E!A<W-W;W)D
M(+S2LM6I?*6\I[F^X[-7N;HN(@H*(SH@;&EB+T1R:79E<B]C;VUP;W-I=&4N
M<&AP.C,U"FUS9VED(")297%U:7)E9"`G9')I=F5R<R<@:7,@;6ES8V]N9FEG
M=7)E9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BNNZF
M6+-=J7?`R:2D+*?DI*.H[,/VJ?,@)V1R:79E<G,GLUVI=[CJKL8N(@H*(SH@
M;&EB+T1R:79E<B]S<6PN<&AP.C0Q"FUS9VED(")297%U:7)E9"`G<&AP='EP
M92<@;F]T('-P96-I9FEE9"!I;B!087-S=V0@4U%,(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E!A<W-W9""JNB!344P@LUVI=Z6RMK>K_*EW("=P:'!T>7!E
M)R(*"B,Z(&QI8B]$<FEV97(O=G!O<&UA:6PN<&AP.C0T"FUS9VED(")297%U
M:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!344P@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B4U%,(+-=J7>ELK:WJ_RI=R`G<&AP='EP92<B"@HC
M.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ-#,*;7-G:60@(E)E<V5T(@IM
M<V=S='(@(JVKLUTB"@HC.B!L:6(O1')I=F5R+W-Q;"YP:'`Z-S`@;&EB+T1R
M:79E<B]V<&]P;6%I;"YP:'`Z-S@*;7-G:60@(E5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N(@IM<V=S='(@(K5,JFNS<[6R(%-13""F^*I!OKDN
M(@H*(SH@;&EB+T1R:79E<B]P;W!P87-S9"YP:'`Z,3`S(&QI8B]$<FEV97(O
M<W%L+G!H<#HQ,C`*(SH@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z,3,X"FUS
M9VED(")5<V5R(&YO="!F;W5N9"(*;7-G<W1R("*GY*2CJ.RHSZ7.JLPB"@HC
M.B!L:6(O1')I=F5R+VMO;&%B+G!H<#HV-"!L:6(O1')I=F5R+VQD87`N<&AP
M.C$S,"!L:6(O1')I=F5R+W!I;F4N<&AP.C(R-0HC.B!L:6(O1')I=F5R+W-M
M8FQD87`N<&AP.C$R-PIM<V=I9"`B57-E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(J?DI*.H[*C/I<ZJS"XB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHW
M-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(JC/I<ZJS*97NMDZ(@H*(SH@
M;6%I;BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H
M86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<R(*;7-G<W1R("*G0:2CK^#%W*?S
MJ,^ESJK,("5S(*JZL4N]6"(*"B,Z(&UA:6XN<&AP.C4S"FUS9VED(")9;W4@
M;75S="!G:79E('EO=7(@8W5R<F5N="!P87-S=V]R9"(*;7-G<W1R("*G0:6R
MMK>_Z:1*I=BK9:JZL4N]6"(*"B,Z(&UA:6XN<&AP.C8R"FUS9VED(")9;W4@
M;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(J=!I;*VM[_I
MI$JW<[%+O5@B"@HC.B!M86EN+G!H<#HV-@IM<V=I9"`B66]U(&UU<W0@=F5R
M:69Y('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(J=!I;*VM[U4J7>G0:JZ
MMW.Q2[U8(@H*(SH@;6%I;BYP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO;F<[('!A<W-W;W)D<R!M
M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T97)S("(*(FQO;F<A(@IM
M<V=S='(@(J=!JKJW<[%+O5BDTZKX.[/,IFBDHZ_@ME>Y3"`E9""MTZ9R(2(*
M"B,Z(&UA:6XN<&AP.C$V-0IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@:7,@
M=&]O('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N9V5D(2(*;7-G<W1R("*G
M0:JZMW.Q2[U8I-.Y3,*RL^:FL[-1LG&H[*JZI6FOX"$@M4RJ:\7<I_,A(@H*
M(SH@;6%I;BYP:'`Z,34V"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!I<R!T
M;V\@<VEM<&QE('1O(&=U97-S+B!.;W0@8VAA;F=E9"$B"FUS9W-T<B`BIT&J
MNK=SL4N]6*33N4S"LK/FIK.S4;)QJ.RJNJ5IK^`A(+5,JFO%W*?S(2(*"B,Z
M(&UA:6XN<&AP.C@Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8F4@870@;&5A<W0@)60@8VAA<F%C=&5R<R!L;VYG(2(*
M;7-G<W1R("*G0:JZMW.Q2[U8IMRDUJUNIK,@)60@K=.F<B$B"@HC.B!M86EN
M+G!H<#HW-`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F
M97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T<B`BIT&J
MNK=SL4N]6*6RMK>[4*78JV6JNK%+O5BFLZG2I*.F4"(*"B,Z(&UA:6XN<&AP
M.C$R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%B971I8R!C:&%R86-T97)S
M+B(*;7-G<W1R("*G0:JZMW.Q2[U8IMRDUJUNI5VG="`E9""MTZ5(I%>JNJU>
MI.6F<BXB"@HC.B!M86EN+G!H<#HQ,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L
M<&AA;G5M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R("*G0:JZMW.Q2[U8IMRD
MUJUNI5VG="`E9""MTZ5(I%>JNJU>I.6F<KM0O,:F<BXB"@HC.B!M86EN+G!H
M<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!N97<@<&%S<W=O
M<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&1I9F9E<F5N="!T>7!E<R!O
M9B!C:&%R86-T97)S+B`B"B)4:&4@='EP97,@87)E.B!L;W=E<BP@=7!P97(L
M(&YU;65R:6,L(&%N9"!S>6UB;VQS+B(*;7-G<W1R("(B"B*G0:JZMW.Q2[U8
MIMRDUJUNI5VG="`E9""ZV*2CIE"KK+I!JKJDY:9R+K-OJ,>KK+I!I5VL03JD
M<+QGK5ZDY:9R+*1JO&>M7J3EIG(L(@HBO,:F<J5(I,ZRQ;BY+B(*"B,Z(&UA
M:6XN<&AP.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;&]W97)C87-E(&-H87)A
M8W1E<G,N(@IM<V=S='(@(J=!JKJW<[%+O5BFW*36K6ZE7:=T("5D(*W3I4BD
M5ZJZI'"\9ZU>I.6F<BXB"@HC.B!M86EN+G!H<#HQ,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE
M87-T("5D(&YU;65R:6,@8VAA<F%C=&5R<RXB"FUS9W-T<B`BIT&JNK=SL4N]
M6*;<I-:M;J5=IW0@)60@K=.E2*17JKJ\QJ9R+B(*"B,Z(&UA:6XN<&AP.C$Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T
M(&-O;G1A:6X@870@;&5A<W0@)60@=7!P97)C87-E(&-H87)A8W1E<G,N(@IM
M<V=S='(@(J=!JKJW<[%+O5BFW*36K6ZE7:=T("5D(*W3I4BD5ZJZI&J\9ZU>
MI.6F<BXB"@HC.B!M86EN+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&QE<W,@=&AA;B`E9"!W
M:&ET97-P86-E(&-H87)A8W1E<G,N(@IM<V=S='(@(J=!JKJW<[%+O5BDH[%O
MI5VG="`E9""MTZ5(I%>JNJK%I=6F<BXB"@HC.B!M86EN+G!H<#HQ-#0*;7-G
M:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S
M<&%C92!C:&%R86-T97)S+B(*;7-G<W1R("*G0:JZMW.Q2[U8I*.Q;Z5=IW2J
MQ:75IG(N(@H*(SH@;6%I;BYP:'`Z-S`*;7-G:60@(EEO=7(@;F5W('!A<W-W
M;W)D<R!D:61N)W0@;6%T8V@B"FUS9W-T<B`BIT&JNK=SL4N]6*2CLL6F6"(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S`@;&EB+T1R:79E<B]S;6)L9&%P
M+G!H<#HW,PIM<V=I9"`B;&1A<%]S=&%R=%]T;',@9F%I;&5D(@IM<V=S='(@
M(FQD87!?<W1A<G1?=&QS(*6BL=$B"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P87-S=V0O<&\O:'5?2%4N<&\`````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-C<W`#$P-#$W,S8R-S0S
M`#`Q-S<R-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C('!A<W-W9"!M;V1U;&4@=')A;G-L871I;VYS"B,@0V]P>7)I9VAT
M("A#*2`R,#`R($AO<F1E(%!R;VIE8W0N"B,@1WEU;&$@4WIA8F\@/&=Y=69I
M0'-Z=&%K:2YH=3XL(#(P,#,N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ('!A<W-W9%QN(@HB4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#,M,#,M,#8@,3$Z-#8K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@
M,C`P,RTP,RTP-B`Q,3HT.2LP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($=Y
M=6QA(%-Z86)O(#QG>75F:4!S>G1A:VDN:'4^7&XB"B),86YG=6%G92U496%M
M.B!(=6YG87)I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#UI<V\M.#@U.2TR7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X+6)I=%QN(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3DW"FUS9VED(")"86-K
M96YD(&YO="!C;W)R96-T;'D@:6UP;&5M96YT960N(@IM<V=S='(@(D$@0F%C
M:V5N9"!N:6YC<R!M96=F96QE;/5E;B!B96EL;&5S>G1V92XB"@HC.B!M86EN
M+G!H<#HR,C$*;7-G:60@(D-H86YG92!087-S=V]R9"(*;7-G<W1R(")*96QS
M>O,@;?-D;W/M=.%S(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,C8@
M=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z-SD*;7-G:60@(D-H86YG92!Y;W5R
M('!A<W-W;W)D(@IM<V=S='(@(DIE;'-Z\R!M\V1O<^UTX7,B"@HC.B!T96UP
M;&%T97,O;6%I;B]M86EN+FEN8SHS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M:&%N9VEN9R!087-S=V]R9"!O;B`E<R(*;7-G<W1R(")*96QS>O-M\V1O<^UT
MX7,@82`E<R!S>F5R=F5R96XB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN
M8SHU-PIM<V=I9"`B0V]N9FER;2!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(OIJ
M(&IE;'-Z\R!M96=E<O5S[73I<V4Z(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HV,2!L:6(O1')I=F5R+VQD87`N<&AP.C$S,PIM<V=I9"`B0V]U;&0@;F]T
M(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B07H@3$1!4"!S>F5R=F5R
M:&5Z(&YE;2!L96AE="!K87!C<V]L\V1N:2(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z-3$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R
M=F5R(@IM<V=S='(@(D%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+B(*
M"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HU,0IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N(@IM<V=S='(@(DYE;2!L96AE
M="!C<V%T;&%K;WIN:2!A>B!S;6)P87-S=V0@8W/U=F5Z973I:VAE>BXB"@HC
M.B!S=&%T=7,N<&AP.C$V"FUS9VED(")%<G)O<B(*;7-G<W1R(")(:6)A(@H*
M(SH@;&EB+T1R:79E<B]P;W!P87-S9"YP:'`Z,3`X"FUS9VED(")%<G)O<B!#
M:&%N9VEN9R!087-S=V]R9"(*;7-G<W1R(")*96QS>O-M\V1O<^UTX7-I(&AI
M8F$B"@HC.B!L:6(O1')I=F5R+W-M8G!A<W-W9"YP:'`Z-S(*;7-G:60@(D5R
M<F]R('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N(@IM<V=S='(@(D%D871T
M;W;A8F+M=.%S:2!H:6)A(&%Z('-M8G!A<W-W9"UH97HN(@H*(SH@;6%I;BYP
M:'`Z,3<Y"FUS9VED(")&86EL=7)E(&EN(&-H86YG:6YG('!A<W-W;W)D(#H@
M(@IM<V=S='(@(DAI8F$@82!J96QS>O-M\V1O<^UTX7-NX6PZ("(*"B,Z('1E
M;7!L871E<R]M96YU+VUE;G4N:6YC.C,P"FUS9VED(")(96QP(@IM<V=S='(@
M(E-E9^UT<^EG(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,S0@;&EB+T1R
M:79E<B]V;6%I;&UG<BYP:'`Z-3,*(SH@;&EB+T1R:79E<B]P;W!P87-S9"YP
M:'`Z,3`R"FUS9VED("));F-O<F5C="!087-S=V]R9"(*;7-G<W1R(")(:6+A
M<R!J96QS>O,B"@HC.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHT,0IM<V=I
M9"`B3&]G;W5T(@IM<V=S='(@(DMI:F5L96YT:V5ZZ7,B"@HC.B!S=&%T=7,N
M<&AP.C(Y"FUS9VED(")-97-S86=E(@IM<V=S='(@(MQZ96YE="(*"B,Z('1E
M;7!L871E<R]M86EN+VUA:6XN:6YC.C4Q"FUS9VED(").97<@<&%S<W=O<F0Z
M(@IM<V=S='(@(MIJ(&IE;'-Z\SHB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN
M+FEN8SHT-0IM<V=I9"`B3VQD('!A<W-W;W)D.B(*;7-G<W1R(")*96QE;FQE
M9VD@:F5L<WKS.B(*"B,Z(&UA:6XN<&AP.C$W-PIM<V=I9"`B4&%S<W=O<F0@
M8VAA;F=E9"$B"FUS9W-T<B`B02!J96QS>O,@;65G=N%L=&]Z;W1T(2(*"B,Z
M(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HT-"!L:6(O1')I=F5R+W-E<G9U
M9G1P+G!H<#HX-0HC.B!L:6(O1')I=F5R+W-E<G9U9G1P+G!H<#HQ,C(@;&EB
M+T1R:79E<BYP:'`Z,3<Y(&UA:6XN<&AP.C$V,@HC.B!T96UP;&%T97,O:6YD
M97@O;F]T8V]N9FEG=7)E9"YI;F,Z-`IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE
M(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D(@IM<V=S='(@(D$@2F5L<WKS
M(&UO9'5L(&YI;F-S(&UE9V9E;&5L]65N(&MO;F9I9W5RX6QV82(*"B,Z('1E
M;7!L871E<R]M96YU+VUE;G4N:6YC.C,W"FUS9VED(")0<F]B;&5M/R(*;7-G
M<W1R(")0<F]B;.EM82(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H<#HS-R!L:6(O
M1')I=F5R+W9P;W!M86EL+G!H<#HS.0IM<V=I9"`B4F5Q=6ER960@)W!H<'1Y
M<&4G(&YO="!S<&5C:69I960@:6X@4U%,(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B=P:'!T>7!E)R!N:6YC<R!S<&5C:69I:^%L=F$@87H@4U%,(&MO;F9I
M9W5RX6-I\V)A;BXB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHX,`IM
M<V=I9"`B4F5S970B"FUS9W-T<B`B5&ES>G1A(/MR;&%P(@H*(SH@=&5M<&QA
M=&5S+VUA:6XO;6%I;BYI;F,Z-C0*;7-G:60@(E-E<G9E<B(*;7-G<W1R(")3
M97)V97(B"@HC.B!T96UP;&%T97,O:6YD97@O;F]T8V]N9FEG=7)E9"YI;F,Z
M-#`*;7-G:60@(E-O;64@;V8@4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A
M=&EO;B!F:6QE<R!A<F4@;6ES<VEN9SHB"FUS9W-T<B`B02!K]G9E=&ME>O4@
M4&%S<W=O<F0@;6]D=6P@:V]N9FEG=7+A8VGS<R#A;&QO;>%N>6]K(&AIX6YY
M>F]Z;F%K.B(*"B,Z('-T871U<RYP:'`Z,C`*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`B4VEK97+\;'0B"@HC.B!T96UP;&%T97,O:6YD97@O;F]T8V]N9FEG
M=7)E9"YI;F,Z-3(*;7-G:60@(B(*(E1H:7,@9FEL92!C;VYT86EN<R!B86-K
M960@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!F;W(@=&AE(%!A<W-W;W)D
M(&UO9'5L92`B"B)S8W)I<'1S+B(*;7-G<W1R("(B"B)%>B!A(&9I;&4@=&%R
M=&%L;6%Z>F$@82!087-S=V0@;6]D=6P@<WIK<FEP=&IE:6YE:R!K;VYF:6=U
M<N%C:?-S:6YF;W)MX6-I\VET+B(*"B,Z('1E;7!L871E<R]I;F1E>"]N;W1C
M;VYF:6=U<F5D+FEN8SHT-0IM<V=I9"`B(@HB5&AI<R!I<R!T:&4@;6%I;B!0
M87-S=V]R9"!M;V1U;&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN
M<R!P871H<R!A;F0@(@HB;W!T:6]N<R!F;W(@86QL(%!A<W-W;W)D(&UO9'5L
M92!S8W)I<'1S+B(*;7-G<W1R("(B"B)%>B!A(%!A<W-W9"!M;V1U;"!F]2!K
M;VYF:6=U<N%C:?-S(.%L;&]MX6YY82X@17H@=&%R=&%L;6%Z>F$@87H@Z6SI
M<NES:2`B"B+Z='9O;F%L86MA="SI<R!A>B!O<&-I\VMA="!A(%!A<W-W9"!M
M;V1U;"#V<W-Z97,@<WIK<FEP=&KI:&5Z+B(*"B,Z(&QI8B]$<FEV97(O<W%L
M+G!H<#HV."!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HW,PIM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B07H@4U%,
M('-Z97)V97(@;F5M(.ER:&5T]2!E;"XB"@HC.B!L:6(O1')I=F5R+W-Q;"YP
M:'`Z,3(W(&QI8B]$<FEV97(O<&]P<&%S<V0N<&AP.CDV"B,Z(&QI8B]$<FEV
M97(O=G!O<&UA:6PN<&AP.C$S-0IM<V=I9"`B57-E<B!N;W0@9F]U;F0B"FUS
M9W-T<B`B3FEN8W,@:6QY96X@9F5L:&%S>F[A;/,B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.CDY"FUS9VED(")5<V5R(&YO="!F;W5N9"XB"FUS9W-T<B`B
M3FEN8W,@:6QY96X@9F5L:&%S>F[A;/,B"@HC.B!T96UP;&%T97,O;6%I;B]M
M86EN+FEN8SHS.0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D9E;&AA<WIN
M\VSS:2!NZ78Z(@H*(SH@<W1A='5S+G!H<#HR-`IM<V=I9"`B5V%R;FEN9R(*
M;7-G<W1R(")&:6=Y96QM97IT973I<R(*"B,Z(&UA:6XN<&AP.C0Q"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!C86XG="!C:&%N9V4@<&%S<W=O<F0@9F]R
M('5S97(@)7,B"FUS9W-T<B`B3F5M('1U9&]D(&UE9W;A;'1O>G1A=&YI("5S
M(&IE;'-Z87;A="$B"@HC.B!M86EN+G!H<#HU-PIM<V=I9"`B66]U(&UU<W0@
M9VEV92!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")-96<@:V5L;"!A9&YO
M9"!A>B#Z:B!J96QS>O-T(@H*(SH@;6%I;BYP:'`Z-#D*;7-G:60@(EEO=2!M
M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O<F0B"FUS9W-T<B`B365G(&ME;&P@
M861N;V0@87H@97)E9&5T:2!J96QS>O-T(@H*(SH@;6%I;BYP:'`Z-C$*;7-G
M:60@(EEO=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R
M(")!>B#Z:B!J96QS>F%V861A="!KZ71S>F5R(&ME;&P@;65G861N;V0B"@HC
M.B!M86EN+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&YE
M=R!P87-S=V]R9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@8F4@
M;6]R92!T:&%N("5D(&-H87)A8W1E<G,@(@HB;&]N9R$B"FUS9W-T<B`B02!J
M96QS>F%V860@=/IL(&AO<W-Z^B$@02!J96QS>O,@;F5M(&QE:&5T('3V8F(@
M)60@:V%R86MT97)NZ6PA(@H*(SH@;6%I;BYP:'`Z,30T(&UA:6XN<&AP.C$U
M,@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G
M=65S<R$@($YO="!C:&%N9V5D(2(*;7-G<W1R(")!(&IE;'-Z879A9"!T^FP@
M:_9N;GEE;B!K:71A;.%L:&%T\R$@3F5M(&WS9&]S[71O;2$B"@HC.B!M86EN
M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R
M9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@;&]N9R$B"FUS9W-T
M<B`B07H@^FH@:F5L<WKS;F%K(&QE9V%LX6)B("5D(&MA<F%K=&5N96L@:V5L
M;"!L96YN:64A(@H*(SH@;6%I;BYP:'`Z-S$*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8F4@9&EF9F5R96YT(&9R;VT@>6]U<B!C=7)R96YT('!A
M<W-W;W)D(@IM<V=S='(@(D%Z(/IJ(.ES(&$@:F5L96YL96=I(&IE;'-Z\VYA
M:R!K_&SV;F+V>FYI92!K96QL(@H*(SH@;6%I;BYP:'`Z,3(P"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A
M="!L96%S="`E9"!A;'!H86)E=&EC(&-H87)A8W1E<G,N(@IM<V=S='(@(D%Z
M(/IJ(&IE;'-Z\VYA:R!L96=A;.%B8B`E9"!B973[="!K96QL('1A<G1A;&UA
M>FYI82XB"@HC.B!M86EN+G!H<#HQ,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L
M<&AA;G5M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R(")!>B#Z:B!J96QS>O-N
M86L@;&5G86SA8F(@)60@86QF86YU;65R:6MU<R!K87)A:W1E<G0@:V5L;"!T
M87)T86QM87IN:6$N(@H*(SH@;6%I;BYP:'`Z,3$P"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S
M="`E9"!L;W=E<F-A<V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`B07H@^FH@:F5L
M<WKS;F%K(&QE9V%LX6)B("5D(&MI<V)E=/MT(&ME;&P@=&%R=&%L;6%Z;FEA
M+B(*"B,Z(&UA:6XN<&AP.C$Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R
M(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;G5M97)I
M8R!C:&%R86-T97)S+B(*;7-G<W1R(")!>B#Z:B!J96QS>O-N86L@;&5G86SA
M8F(@)60@<WKA;6]T(&ME;&P@=&%R=&%L;6%Z;FEA+B(*"B,Z(&UA:6XN<&AP
M.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@=7!P97)C87-E(&-H87)A8W1E<G,N
M(@IM<V=S='(@(D%Z(/IJ(&IE;'-Z\VYA:R!L96=A;.%B8B`E9"!N86=Y8F5T
M^W0@:V5L;"!T87)T86QM87IN:6$N(@H*(SH@;6%I;BYP:'`Z,3,P"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I
M;B!A="!L97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T97)S+B(*;7-G
M<W1R(")!>B#Z:B!J96QS>O,@;F5M('1A<G1A;&UA>FAA="`E9"UNX6P@=/9B
M8B#\<F5S(&MA<F%K=&5R="XB"@HC.B!M86EN+G!H<#HQ,S(*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C
M:&%R86-T97)S+B(*;7-G<W1R(")!>B#Z:B!J96QS>O,@;F5M('1A<G1A;&UA
M>FAA="#\<F5S(&MA<F%K=&5R="XB"@HC.B!M86EN+G!H<#HV-@IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:"(*;7-G<W1R(")!>B#Z
M:B!J96QS>F%V86L@;F5M(&5G>65Z;F5K(2(*"B,Z(&QI8B]$<FEV97(O<VUB
M<&%S<W=D+G!H<#HY-PIM<V=I9"`B=&5M<&YA;2@I(&9A:6QE9"$B"FUS9W-T
M<B`B=&5M<&YA;2@I('-I:V5R=&5L96XA(@H`````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+W!O+V9I7T9)+G!O
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#0T
M-P`Q,#0Q-S,V,C<T,P`P,3<V-C(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!&:6YN:7-H('1R86YS;&%T:6]N(&9O<B!0
M87-S=V0N"B,@0V]P>7)I9VAT("A#*0HC(%1E<F\@36%T:6YL87-S:2`\=&5R
M;RYM871I;FQA<W-I0&5D=2YV86YT86$N9FD^+"`R,#`R+@HC($QE96YA($AE
M:6YO(#QL:6EN=4!U=&$N9FD^+"`R,#`R+3(P,#0N"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%!A<W-W9"`S+C`M8W9S7&XB
M"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN
M(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,#@M,CD@,34Z,3DK,#,P,%QN
M(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,BTQ,"`Q,CHU.2LP,C`P7&XB
M"B),87-T+51R86YS;&%T;W(Z($QE96YA($AE:6YO(#QL:6EN=4!U=&$N9FD^
M7&XB"B),86YG=6%G92U496%M.B!&:6YN:7-H(#QI,3AN0&QI<W1S+FAO<F1E
M+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z(&QI8B]$<FEV97(O97AP
M96-T+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!E
M>&ES="!O<B!I<R!N;W0@97AE8W5T86)L92XB"FUS9W-T<B`B)7,@96D@;VQE
M(&]L96UA<W-A('1A:2!E:2!O;&4@86IE='1A=F$@;VAJ96QM82XB"@HC.B!L
M:6(O1')I=F5R+V-O;7!O<VET92YP:'`Z-C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,Z('5N86)L92!T;R!L;V%D(&1R:79E<CH@)7,B"FUS9W-T<B`B)7,Z
M(&5I('9O:2!L861A=&$@86IU<FEA.B`E<R(*"B,Z(&QI8B]$<FEV97(O861S
M:2YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B041322!E<G)O<B`E<RXB
M"FUS9W-T<B`B041322!V:7)H92`E<RXB"@HC.B!L:6(O1')I=F5R+V%D<VDN
M<&AP.C8T(&QI8B]$<FEV97(O<'-P87-S=V0N<&AP.C$P-0IM<V=I9"`B06-C
M97-S($1E;FEE9"XB"FUS9W-T<B`B2^1Y='3V(&MI96QL971T>2XB"@HC.B!L
M:6(O1')I=F5R+G!H<#HX-0IM<V=I9"`B0F%C:V5N9"!N;W0@8V]R<F5C=&QY
M(&EM<&QE;65N=&5D+B(*;7-G<W1R(")4875S=&%JY')J97-T96QMY"!E:2!T
M;VEM:6YU="!O:6ME:6XN(@H*(SH@;6%I;BYP:'`Z,C4P('1E;7!L871E<R]M
M86EN+VUA:6XN:6YC.C$T,@IM<V=I9"`B0VAA;F=E(%!A<W-W;W)D(@IM<V=S
M='(@(E9A:6AD82!S86QA<V%N87-I(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I
M;BYI;F,Z,3(W"FUS9VED(")#:&%N9V4@<&%S<W=O<F0@;VXZ(@IM<V=S='(@
M(E9A:6AD82!S86QA<V%N83HB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN
M8SHV,@IM<V=I9"`B0VAA;F=E('EO=7(@<&%S<W=O<F0B"FUS9W-T<B`B5F%I
M:&1A('-A;&%S86YA<VDB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHV
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#:&%N9VEN9R!P87-S=V]R9"!O;B`E
M<R(*;7-G<W1R(")686EH9&5T86%N('-A;&%S86YA82`E<SIL;&4B"@HC.B!T
M96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ,30*;7-G:60@(D-O;F9I<FT@;F5W
M('!A<W-W;W)D.B(*;7-G<W1R(")686AV:7-T82!U=7-I('-A;&%S86YA(@H*
M(SH@;&EB+T1R:79E<B]K;VQA8BYP:'`Z-30@;&EB+T1R:79E<B]L9&%P+G!H
M<#HY.2!L:6(O1')I=F5R+VQD87`N<&AP.C(V-PIM<V=I9"`B0V]U;&0@;F]T
M(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3$1!4"UP86QV96QI;G1A
M(&5I('9O:71U(&OD>71TY.0B"@HC.B!L:6(O1')I=F5R+VMO;&%B+G!H<#HT
M-B!L:6(O1')I=F5R+VQD87`N<&AP.C<P"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("),1$%0+7!A;'9E;&EM965N
M(&5I('-A871U('EH=&5Y='3D(@H*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N
M<&AP.C4W"FUS9VED(")#;W5L9"!N;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W
M9"XB"FUS9W-T<B`B16D@=F]I='4@875K86ES=&$@<'5T:V5A('-M8G!A<W-W
M9"UO:&IE;&UA;&QE+B(*"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HW
M.0IM<V=I9"`B17)R;W(@<V5N9&EN9R!D871A('1O('-M8G!A<W-W9"XB"FUS
M9W-T<B`B5&%P86AT=6D@=FER:&4@;.1H971E='3D97-SY"!T:65T;V$@<VUB
M<&%S<W=D+6]H:F5L;6%L;&4N(@H*(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP
M:'`Z.3,*;7-G:60@(D9A:6QE9"!T;R!V97)I9GD@;VQD('!A<W-W;W)D+B(*
M;7-G<W1R(")686YH82!S86QA<V%N82!O;B!VY.1RY"XB"@HC.B!M86EN+G!H
M<#HR,#<@;&EB+T1R:79E<B]C;VUP;W-I=&4N<&AP.CDY"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,Z
M("5S(@IM<V=S='(@(E-A;&%S86YA;B!V86EH=&\@97#D;VYN:7-T=6D@)7,Z
M("5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z-38@;&EB+T1R:79E<B]K;VQA8BYP
M:'`Z-S@@;&EB+T1R:79E<B]L9&%P+G!H<#HR-C@*(SH@;&EB+T1R:79E<B]P
M;W!P87-S9"YP:'`Z,3$T(&QI8B]$<FEV97(O=FUA:6QM9W(N<&AP.C0R"FUS
M9VED("));F-O<G)E8W0@4&%S<W=O<F0B"FUS9W-T<B`B5N3D<N0@<V%L87-A
M;F$B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(U.0IM<V=I9"`B36EN:6UU
M;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")3
M86QA<V%N86X@=F%I:'1A;6ES96YE<W1O86EK82!E:2!O;&4@=FEE;.0@:W5L
M=6YU="!U;7!E96XB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ,#(*
M;7-G:60@(DYE=R!P87-S=V]R9#HB"FUS9W-T<B`B575S:2!S86QA<V%N83HB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@<W5C:"!B86-K96YD(%PB)7-<(B!F;W5N9"XB"FUS9W-T<B`B5&%U<W1A
M:N1R:F5S=&5L;>3D(%PB)7-<(B!E:2!L]GET>6YY="XB"@HC.B!T96UP;&%T
M97,O;6%I;B]M86EN+FEN8SHY,`IM<V=I9"`B3VQD('!A<W-W;W)D.B(*;7-G
M<W1R(")686YH82!S86QA<V%N83HB"@HC.B!L:6(O1')I=F5R+W-M8G!A<W-W
M9"YP:'`Z-#<*;7-G:60@(E!A<W-W9"!I<R!N;W0@<')O<&5R;'D@8V]N9FEG
M=7)E9"XB"FUS9W-T<B`B4&%S<W=O<F0M;VAJ96QM:7-T;R!E:2!O;&4@87-E
M;FYE='1U(&]I:V5I;BXB"@HC.B!M86EN+G!H<#HQ.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!O;B`E<RXB"FUS9W-T<B`B4V%L
M87-A;F$@=F%I:&1E='1U("5S+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S=V0N
M<&AP.C<U"FUS9VED(")087-S=V]R9"!M;V1U;&4@8V%N)W0@9FEN9"!T:&4@
M<W5P<&QI960@8FEN+B(*;7-G<W1R(")087-S=V]R9"UM;V1U=6QI(&5I(&SV
M>63D(&%N;F5T='5A(&MO;65N=&]A+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S
M=V0N<&AP.C<S"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!R
M97%U:7)E9"!P87)A;65T97)S+B(*;7-G<W1R(")087-S=V]R9"UM;V1U=6QI
M;'1A('!U=71T=74@=&%R=FET=&%V:6$@<&%R86UE=')E:N0N(@H*(SH@;&EB
M+T1R:79E<B]A9'-I+G!H<#HU,0IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&ES
M(&UI<W-I;F<@=&%R9V5T('!A<F%M971E<BXB"FUS9W-T<B`B4&%S<W=O<F0M
M;6]D=75L:6QL92!E:2!O;&4@;>3D<FET96QT>2!T87)G970@<&%R86UE=')I
M82XB"@HC.B!M86EN+G!H<#HQ-S8@;&EB+T1R:79E<B]S97)V=69T<"YP:'`Z
M-S$*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N
M9FEG=7)E9"(*;7-G<W1R(")087-S=V]R9"UM;V1U=6QI(&5I(&]L92!A<V5N
M;F5T='4@;VEK96EN(@H*(SH@;&EB+T1R:79E<B]S97)V=69T<"YP:'`Z.3@*
M;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG
M=7)E9"XB"FUS9W-T<B`B4&%S<W=O<F0M;6]D=75L:2!E:2!O;&4@87-E;FYE
M='1U(&]I:V5I;BXB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ,0IM
M<V=I9"`B4&QE87-E('!R;W9I9&4@82!N97<@<&%S<W=O<F0B"FUS9W-T<B`B
M4VEN=6X@=.1Y='EY(&%N=&%A('5U<VD@<V%L87-A;F%S:2(*"B,Z('1E;7!L
M871E<R]M86EN+VUA:6XN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E('EO
M=7(@8W5R<F5N="!P87-S=V]R9"(*;7-G<W1R(")3:6YU;B!TY'ET>7D@86YT
M86$@;GEK>6EN96X@<V%L87-A;F%S:2(*"B,Z('1E;7!L871E<R]M86EN+VUA
M:6XN:6YC.C$U"FUS9VED(")0;&5A<V4@=F5R:69Y('EO=7(@;F5W('!A<W-W
M;W)D(@IM<V=S='(@(E-I;G5N('3D>71Y>2!V86AV:7-T86$@=75S:2!S86QA
M<V%N87-I(@H*(SH@;&EB+T1R:79E<B]C;VUP;W-I=&4N<&AP.C0Q"FUS9VED
M(")297%U:7)E9"`G9')I=F5R<R<@:7,@;6ES8V]N9FEG=7)E9"!I;B!#;VUP
M;W-I=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB5&%R=FET=&%V86$@
M)V1R:79E<G,G+6%S971U<W1A(&5I(&]L;'5T(&WDY')I=&5L='D@0V]M<&]S
M:71E+6%S971U:W-I<W-A+B(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H<#HT-@IM
M<V=I9"`B4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@4&%S
M<W=D(%-13"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)487)V:71T879A
M82`G<&AP='EP92<M87-E='5S=&$@96D@;VQL=70@;>3D<FET96QT>2!087-S
M=V0@4U%,+6%S971U:W-I<W-A+B(*"B,Z(&QI8B]$<FEV97(O=G!O<&UA:6PN
M<&AP.C0Y"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE
M9"!I;B!344P@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&%R=FET=&%V86$@
M)W!H<'1Y<&4G+6%S971U<W1A(&5I(&]L;'5T(&WDY')I=&5L='D@4U%,+6%S
M971U:W-I<W-A+B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$T,PIM
M<V=I9"`B4F5S970B"FUS9W-T<B`B5'EH:F5N;N0B"@HC.B!L:6(O1')I=F5R
M+W-Q;"YP:'`Z-S4@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z.#,*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(E-1
M3"UP86QV96QI;65E;B!E:2!S86%D82!Y:'1E>71TY"XB"@HC.B!L:6(O1')I
M=F5R+W!O<'!A<W-D+G!H<#HQ,#@@;&EB+T1R:79E<B]S<6PN<&AP.C$R-0HC
M.B!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HQ-#,*;7-G:60@(E5S97(@;F]T
M(&9O=6YD(@IM<V=S='(@(DOD>71TY&KDY"!E:2!L]GET>6YY="(*"B,Z(&QI
M8B]$<FEV97(O:V]L86(N<&AP.C<P(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3,U
M(&QI8B]$<FEV97(O<&EN92YP:'`Z,C,Q"FUS9VED(")5<V5R(&YO="!F;W5N
M9"XB"FUS9W-T<B`B2^1Y='3D:N3D(&5I(&SV>71Y;GET+B(*"B,Z('1E;7!L
M871E<R]M86EN+VUA:6XN:6YC.C<W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`B2^1Y='3D:N1T=6YN=7,Z(@H*(SH@;6%I;BYP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E
M<B`E<R(*;7-G<W1R(")%="!V;VD@=F%I:'1A82!KY'ET=.1JY&X@)7,@<V%L
M87-A;F%A(@H*(SH@;6%I;BYP:'`Z-3,*;7-G:60@(EEO=2!M=7-T(&=I=F4@
M>6]U<B!C=7)R96YT('!A<W-W;W)D(@IM<V=S='(@(E-I;G5N('3D>71Y>2!A
M;G1A82!N>6MY:6YE;B!S86QA<V%N87-I(@H*(SH@;6%I;BYP:'`Z-C(*;7-G
M:60@(EEO=2!M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`B
M4VEN=6X@=.1Y='EY(&%N=&%A(&AA;'5A;6%S:2!U=7-I('-A;&%S86YA(@H*
M(SH@;6%I;BYP:'`Z-C8*;7-G:60@(EEO=2!M=7-T('9E<FEF>2!Y;W5R(&YE
M=R!P87-S=V]R9"(*;7-G<W1R(")3:6YU;B!TY'ET>7D@=F%H=FES=&%A('5U
M<VD@<V%L87-A;F%S:2(*"B,Z(&UA:6XN<&AP.C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!L;VYG.R!P87-S
M=V]R9',@;6%Y(&YO="!B92!M;W)E('1H86X@)60@8VAA<F%C=&5R<R`B"B)L
M;VYG(2(*;7-G<W1R("(B"B)5=7-I('-A;&%S86YA<VD@;VX@;&EI86X@<&ET
M:^0[('-A;&%S86YA="!E:7;D="!S86$@;VQL82`E9"!M97)K:VGD('!I9&5M
M<&GD(2(*"B,Z(&UA:6XN<&AP.C$V-0IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@:7,@=&]O('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N9V5D(2(*;7-G
M<W1R(")5=7-I('-A;&%S86YA<VD@;VX@;&EI86X@:&5L<'!O(&%R=F%T82X@
M4V%L87-A;F%A(&5I('9A:6AD971T=2$B"@HC.B!M86EN+G!H<#HQ-38*;7-G
M:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,N
M($YO="!C:&%N9V5D(2(*;7-G<W1R(")5=7-I('-A;&%S86YA<VD@;VX@;&EI
M86X@:&5L<'!O(&%R=F%T82X@4V%L87-A;F%A(&5I('9A:6AD971T=2$B"@HC
M.B!M86EN+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@;&]N9R$B
M"FUS9W-T<B`B575D96X@<V%L87-A;F%S:2!TY'ET>7D@;VQL82!VY&AI;G3D
MY&X@)60@;65R:VMIY"!P:71KY"$B"@HC.B!M86EN+G!H<#HW-`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F97)E;G0@9G)O;2!Y;W5R
M(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T<B`B575S:2!S86QA<V%N82!E:2!S
M86$@;VQL82!S86UA(&MU:6X@;GEK>6EN96X@<V%L87-A;F%S:2(*"B,Z(&UA
M:6XN<&AP.C$R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%B971I8R!C:&%R
M86-T97)S+B(*;7-G<W1R(")5=61E<W-A('-A;&%S86YA<W-A('!I=.3D(&]L
M;&$@=N1H:6YTY.1N("5D(&MI<FIA:6YT82(*"B,Z(&UA:6XN<&AP.C$S,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O
M;G1A:6X@870@;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N(@IM
M<V=S='(@(E5U9&5S<V$@<V%L87-A;F%S<V$@<&ETY.0@;VQL82!VY&AI;G3D
MY&X@)60@:VER:F%I;G1A(&IA(&YU;65R;V$N(@H*(SH@;6%I;BYP:'`Z,3,V
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!D:69F97)E;G0@='EP97,@;V8@8VAA
M<F%C=&5R<RX@(@HB5&AE('1Y<&5S(&%R93H@;&]W97(L('5P<&5R+"!N=6UE
M<FEC+"!A;F0@<WEM8F]L<RXB"FUS9W-T<B`B(@HB575D96X@<V%L87-A;F%N
M('!I=.3D('3D>71TY.0@=N1H:6YTY.1N("5D('9A871I;75S=&$N(%9A871I
M;75K<V5T(&]V870Z("(*(G!I96YIY"!K:7)J86EM:6$L(&ES;VIA(&MI<FIA
M:6UI82P@;G5M97)O:71A(&IA('-Y;6)O;&5I=&$N(@H*(SH@;6%I;BYP:'`Z
M,3$V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!L;W=E<F-A<V4@8VAA<F%C=&5R<RXB
M"FUS9W-T<B`B575D97-S82!S86QA<V%N87-S82!P:73DY"!O;&QA(';D:&EN
M=.3D;B`E9"!P:65N=.0@:VER:F%I;G1A+B(*"B,Z(&UA:6XN<&AP.C$R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O
M;G1A:6X@870@;&5A<W0@)60@;G5M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R
M(")5=61E<W-A('-A;&%S86YA<W-A('!I=.3D(&]L;&$@=N1H:6YTY.1N("5D
M(&YU;65R;V$N(@H*(SH@;6%I;BYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E
M9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`B575D97-S82!S86QA
M<V%N87-S82!P:73DY"!O;&QA(';D:&EN=.3D;B`E9"!I<V]A(&MI<FIA:6YT
M82XB"@HC.B!M86EN+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&QE<W,@=&AA;B`E9"!W:&ET
M97-P86-E(&-H87)A8W1E<G,N(@IM<V=S='(@(E5U9&5S<V$@<V%L87-A;F%S
M<V$@<&ETY.0@;VQL82!VY&AI;G3DY&X@)60@=N1L:6QY]FYT:6UE<FMK:>0N
M(@H*(SH@;6%I;BYP:'`Z,30T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA<F%C=&5R<RXB"FUS9W-T
M<B`B575D97-S82!S86QA<V%N87-S82!E:2!S86$@;VQL82!VY&QI;'GV;G1I
M;65R:VME:N0N(@H*(SH@;6%I;BYP:'`Z-S`*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D<R!D:61N)W0@;6%T8V@B"FUS9W-T<B`B06YT86UA<VD@=75D970@
M<V%L87-A;F%T(&5I=N1T('3D<VWDY"(*"B,Z('1E;7!L871E<R]M86EN+VUA
M:6XN:6YC.C$Y"FUS9VED(")9;W5R('!A<W-W;W)D<R!D;R!N;W0@;6%T8V@B
M"FUS9W-T<B`B06YT86UA<VD@<V%L87-A;F%T(&5I=N1T('3D<VWDY"(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S8*;7-G:60@(FQD87!?<W1A<G1?=&QS
M(&9A:6QE9"(*;7-G<W1R(")L9&%P7W-T87)T7W1L<R!E<.1O;FYI<W1U:2(*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+W!O+V5T7T5%+G!O````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3,T,``Q,#0Q-S,V
M,C<T,P`P,3<V-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!005-35T0@15-43TY)04X@5%)!3E-,051)3TX*(R`*(R!4
M;V]M87,@06%S+"`R,#`T"B,@"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C
M="U)9"U697)S:6]N.B!087-S=V1<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`T+3`V+3`Q(#$U.C$Y*S`S
M,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#8M,#$@,3DZ-#`K,#,P
M,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!4;V]M87,@06%S(#QT;V]M87,N86%S
M0&UA:6PN964^7&XB"B),86YG=6%G92U496%M.B!%<W1O;FEA;B`\:3$X;D!L
M:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$S7&XB
M"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@IM<V=I9"`B
M0F%C:V5N9"!N;W0@8V]R<F5C=&QY(&EM<&QE;65N=&5D+B(*;7-G<W1R(")!
M;'5S<F%K96YD=7,@96D@;VQE(&MO<G)A;&EK=6QT('!A:6=A;&1A='5D+B(*
M"FUS9VED(")#:&%N9V4@4&%S<W=O<F0B"FUS9W-T<B`B5F%H971A('-A;&%S
M]6YA(@H*;7-G:60@(D-H86YG92!Y;W5R('!A<W-W;W)D(@IM<V=S='(@(DUU
M=61A(&]M82!S86QA<_5N82(*"B,L(&,M9F]R;6%T"FUS9VED(")#:&%N9VEN
M9R!087-S=V]R9"!O;B`E<R(*;7-G<W1R(")386QA<_5N82!M=75T;6EN92!S
M_'-T965M:7,Z("5S(@H*;7-G:60@(D-O;F9I<FT@;F5W('!A<W-W;W)D.B(*
M;7-G<W1R(")+;W)D82!U=70@<V%L87/U;F$Z(@H*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(D5I('-A86YU9"#\:&5N
M9'5S="!,1$%0('-E<G9E<FEG82(*"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C
M="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")%:2!S86%N=60@_&AE;F1U<W0@
M3$1!4"!S97)V97)I9V$B"@IM<V=I9"`B0V]U;&0@;F]T(&]P96X@<&EP92!T
M;R!S;6)P87-S=V0N(@IM<V=S='(@(D5I(/5N;F5S='5N=60@879A9&$@=&]R
M=2!S;6)P87-S=V0M9V$N(@H*;7-G:60@(D5R<F]R('-E;F1I;F<@9&%T82!T
M;R!S;6)P87-S=V0N(@IM<V=S='(@(E9I9V$@86YD;65T92!S86%T;6ES96P@
M<VUB<&%S<W=D+6QE+B(*"FUS9VED(")%<G)O<B(*;7-G<W1R(")6:6=A(@H*
M;7-G:60@(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@.B`B"FUS9W-T
M<B`B4V%L87/U;F$@;75U=&UI;F4@96)A]6YN97-T=7,@.B`B"@IM<V=I9"`B
M2&5L<"(*;7-G<W1R(")!8FDB"@IM<V=I9"`B26YC;W)R96-T(%!A<W-W;W)D
M(@IM<V=S='(@(E9A;&4@<V%L87/U;F$B"@IM<V=I9"`B3&]G;W5T(@IM<V=S
M='(@(DQO9VD@=N1L:F$B"@IM<V=I9"`B365S<V%G92(*;7-G<W1R(")496%D
M92(*"FUS9VED(").97<@<&%S<W=O<F0Z(@IM<V=S='(@(E5U<R!S86QA<_5N
M83HB"@IM<V=I9"`B3VQD('!A<W-W;W)D.B(*;7-G<W1R(")686YA('-A;&%S
M]6YA.B(*"FUS9VED(")087-S=V]R9"!C:&%N9V5D(2(*;7-G<W1R(")386QA
M<_5N82!M=75D971U9"$B"@IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&ES(&YO
M="!P<F]P97)L>2!C;VYF:6=U<F5D(@IM<V=S='(@(E!A<W-W;W)D(&UO;V1U
M;"!E:2!O;&4@:V]R<F%L:6MU;'0@:.3D;&5S=&%T=60B"@IM<V=I9"`B4')O
M8FQE;3\B"FUS9W-T<B`B4')O8FQE96T_(@H*;7-G:60@(E)E<75I<F5D("=P
M:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%-13"!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")344P@:.3D;&5S='5S97,@<'5U9'5B('9A:F%L:6L@)W!H<'1Y
M<&4G+B(*"FUS9VED(")297-E="(*;7-G<W1R("(B"@IM<V=I9"`B4V5R=F5R
M(@IM<V=S='(@(B(*"FUS9VED(")3;VUE(&]F(%!A<W-W;W)D(&UO9'5L92=S
M(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I;F<Z(@IM<V=S='(@(DWU
M;F5D(%!A<W-W;W)D(&UO;V1U;&D@:V]N9FEG=7)A='-I;V]N:69A:6QI9"!O
M;B!P=75D=3HB"@IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+5;FYE<W1U<R(*
M"FUS9VED("(B"B)4:&ES(&9I;&4@8V]N=&%I;G,@8F%C:V5N9"!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N(&9O<B!T:&4@4&%S<W=O<F0@;6]D=6QE("(*
M(G-C<FEP=',N(@IM<V=S='(@(E-E92!F86EL('-I<V%L9&%B(%!A<W-W;W)D
M(&UO;V1U;&D@86QU<W)A:V5N9'5S92!HY.1L97-T=7-I;F9O="XB"@IM<V=I
M9"`B(@HB5&AI<R!I<R!T:&4@;6%I;B!087-S=V]R9"!M;V1U;&4@8V]N9FEG
M=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P871H<R!A;F0@(@HB;W!T:6]N
M<R!F;W(@86QL(%!A<W-W;W)D(&UO9'5L92!S8W)I<'1S+B(*;7-G<W1R("(B
M"B)3964@;VX@4&%S<W=O<F0@;6]O9'5L:2!P96%M:6YE(&MO;F9I9W5R871S
M:6]O;FEF86EL+B!3964@<VES86QD86(@9F%I;&ED92`B"B)A<W5K;VAT:6YI
M;F<@<V5A9&5I9"!K]6EG:2!087-S=V]R9"!M;V]D=6QI('-K<FEP=&ED92!J
M86]K<RXB"@IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BXB"FUS9W-T<B`B16D@<V%A(/QH96YD=7-T(%-13"!S97)V97)I9V$N(@H*
M;7-G:60@(E5S97(@;F]T(&9O=6YD(@IM<V=S='(@(DMA<W5T86IA="!E:2!L
M96ET=60B"@IM<V=I9"`B57-E<B!N;W0@9F]U;F0N(@IM<V=S='(@(DMA<W5T
M86IA="!E:2!L96ET=60N(@H*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")+
M87-U=&%J86YI;6DZ(@H*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B2&]I871U
M<R(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W4@8V%N)W0@8VAA;F=E('!A<W-W
M;W)D(&9O<B!U<V5R("5S(@IM<V=S='(@(E-A(&5I('-A82!M=75T82!K87-U
M=&%J82`E<R!S86QA<_5N82(*"FUS9VED(")9;W4@;75S="!G:79E('EO=7(@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(E-A('!E860@<VES97-T86UA(&]M82!U
M=64@<V%L87/U;F$B"@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y;W5R(&]L9"!P
M87-S=V]R9"(*;7-G<W1R(")382!P96%D('-I<V5S=&%M82!O;6$@=F%N82!S
M86QA<_5N82(*"FUS9VED(")9;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S
M<W=O<F0B"FUS9W-T<B`B575S('-A;&%S]6YA('1U;&5B('-I<V5S=&%D82!K
M86MS(&MO<F1A(@H*(RP@8RUF;W)M870*;7-G:60@(B(*(EEO=7(@;F5W('!A
M<W-W;W)D(&ES('1O;R!L;VYG.R!P87-S=V]R9',@;6%Y(&YO="!B92!M;W)E
M('1H86X@)60@8VAA<F%C=&5R<R`B"B)L;VYG(2(*;7-G<W1R(")5=7,@<V%L
M87/U;F$@;VX@;&EI9V$@<&EK:SL@<V%L87/U;F$@96D@=&]H:2!O;&QA('!I
M:V5M(&MU:2`E9"!MY')K:2$B"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M:7,@=&]O('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N9V5D(2(*;7-G<W1R
M(")5=70@<V%L87/U;F$@;VX@;&EI9V$@;&EH=&YE(.1R82!A<G9A=&$A(%-A
M;&%S]6YA(&5I(&UU=61E='5D(2(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W5R
M(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@
M;&]N9R$B"FUS9W-T<B`B575S('-A;&%S]6YA('!E86(@;VQE;6$@=N1H96UA
M;'0@)60@;>1R:VD@<&EK:R$B"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M;75S="!B92!D:69F97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B
M"FUS9W-T<B`B575S('-A;&%S]6YA('!E86(@97)I;F5M82!P<F%E9W5S97-T
M('-A;&%S]6YA<W0B"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA
M<F%C=&5R<RXB"FUS9W-T<B`B575S('-A;&%S]6YA('!E86(@<VES86QD86UA
M(';D:&5M86QE("5D('3D:'1E+B(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W5R
M(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%N
M=6UE<FEC(&-H87)A8W1E<G,N(@IM<V=S='(@(E5U<R!S86QA<_5N82!P96%B
M('-I<V%L9&%M82!VY&AE;6%L="`E9"!TY&AT92!V]6D@;G5M8G)I="XB"@HC
M+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT
M86EN(&%T(&QE87-T("5D(&QO=V5R8V%S92!C:&%R86-T97)S+B(*;7-G<W1R
M(")5=7,@<V%L87/U;F$@<&5A8B!S:7-A;&1A;6$@=N1H96UA;'0@)60@=N1I
M:V5TY&AT92XB"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&YU;65R:6,@8VAA<F%C=&5R
M<RXB"FUS9W-T<B`B575S('-A;&%S]6YA('!E86(@<VES86QD86UA(';D:&5M
M86QT("5D(&YU;6)R:70N(@H*(RP@8RUF;W)M870*;7-G:60@(EEO=7(@;F5W
M('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@
M8VAA<F%C=&5R<RXB"FUS9W-T<B`B575S('-A;&%S]6YA('!E86(@<VES86QD
M86UA(';D:&5M86QT("5D('-U=7)TY&AT92XB"@HC+"!C+69O<FUA=`IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&QE<W,@=&AA;B`E
M9"!W:&ET97-P86-E(&-H87)A8W1E<G,N(@IM<V=S='(@(E5U<R!S86QA<_5N
M82!P96%B('-I<V%L9&%M82!VY&AE;2!K=6D@)60@=/QH:6MU="XB"@IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!N;W0@8V]N=&%I;B!W:&ET97-P
M86-E(&-H87)A8W1E<G,N(@IM<V=S='(@(E5U<R!S86QA<_5N82!E:2!T;VAI
M('-I<V%L9&%D82!T_&AI:W5I9"XB"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F1S(&1I9&XG="!M871C:"(*;7-G<W1R(")3:7-E<W1A='5D('-A;&%S]6YA
M9"!E:2!K;&%P:2(*"FUS9VED(")T96UP;F%M*"D@9F%I;&5D(2(*;7-G<W1R
M(")T96UP;F%M*"D@96)A]6YN97-T=7,A(@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]P;R]214%$344`````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,C,`
M,3`T,3<S-C(W-#,`,#$W,C$R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'-E92!H;W)D92]P;R]214%$344`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P87-S=V0O<&\O<G5?4E4N<&\`````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P,S8P`#$P-#$W,S8R-S0S
M`#`Q-S<S-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C(%)U<W-I86X@=')A;G-L871I;VYS(&9O<B!087-S=V0@<&%C:V%G
M90HC($-O<'ER:6=H="`H0RD@,C`P-2!(;W)D92!0<F]J96-T"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE(%!A<W-W9"!P86-K86=E+@HC($%U=&]M871I8V%L;'D@9V5N97)A=&5D
M+"`R,#`U+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S
M:6]N.B!087-S=V0@2#,@*#,N,"UC=G,I7&XB"B)297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#4M,#@M,C(@,C,Z,3$K,#DP,%QN(@HB4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-2TP."TR,B`Q-CHT,"LP,#`P7&XB"B),87-T+51R86YS;&%T;W(Z
M($EL;'EA($)E;&]V(#QB96QO=D!I;W`N:7)K<',N<G4^7&XB"B),86YG=6%G
M92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#
M4#$R-3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*
M(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU<F%L/2AN)3$P/3TQ("8F
M(&XE,3`P(3TQ,2`_(#`@.B!N)3$P/CTR("8F(&XE(@HB,3`\/30@)B8@*&XE
M,3`P/#$P('Q\(&XE,3`P/CTR,"D@/R`Q(#H@,BD[7&XB"@HC.B!L:6(O1')I
M=F5R+V5X<&5C="YP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E
M<R!N;W0@97AI<W0@;W(@:7,@;F]T(&5X96-U=&%B;&4N(@IM<V=S='(@(B5S
M(.WE(/'S^>7Q\N+SY?(@Z.OH(.WE(.CQ[^[K[?_E[/OI(@H*(SH@;&EB+T1R
M:79E<B]C;VUP;W-I=&4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M.B!U;F%B;&4@=&\@;&]A9"!D<FEV97(Z("5S(@IM<V=S='(@(B5S.B#MY>+N
MY^SNYNWN(.?@X_#SY^CR_"#D\.#IXN7P.B`E<R(*"B,Z(&QI8B]$<FEV97(O
M861S:2YP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B041322!E<G)O<B`E
M<RXB"FUS9W-T<B`BSOCHX>K@($%$4TD@)7,B"@HC.B!L:6(O1')I=F5R+V%D
M<VDN<&AP.C4W(&QI8B]$<FEV97(O<'-P87-S=V0N<&AP.CDW"FUS9VED(")!
M8V-E<W,@1&5N:65D+B(*;7-G<W1R("+$[O'R\^\@Y^#O\.7YY>TB"@HC.B!L
M:6(O1')I=F5R+G!H<#HX,`IM<V=I9"`B0F%C:V5N9"!N;W0@8V]R<F5C=&QY
M(&EM<&QE;65N=&5D+B(*;7-G<W1R(")"86-K96YD(.WE(.KN\/#EZO+M[B#M
MX/'R\.[E[2(*"B,Z(&UA:6XN<&AP.C(T-B!T96UP;&%T97,O;6%I;B]M86EN
M+FEN8SHQ-#(*;7-G:60@(D-H86YG92!087-S=V]R9"(*;7-G<W1R("+1[.7M
MZ/+\(._@\.[K_"(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$R-PIM
M<V=I9"`B0VAA;F=E('!A<W-W;W)D(&]N.B(*;7-G<W1R("+1[.7MZ/+\(._@
M\.[K_"#MX#HB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHV,@IM<V=I
M9"`B0VAA;F=E('EO=7(@<&%S<W=O<F0B"FUS9W-T<B`BT>SE[>CR_"#OX/#N
MZ_PB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHV.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#:&%N9VEN9R!P87-S=V]R9"!O;B`E<R(*;7-G<W1R("+1
M[.7MZ/+\(._@\.[K_"#MX"`E<R(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN
M:6YC.C$Q-`IM<V=I9"`B0V]N9FER;2!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(L_NY/+BY?#DZ/+E(.WNXOOI(._@\.[K_#HB"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.CDS(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C0P(&QI8B]$<FEV97(O
M<VUB;&1A<"YP:'`Z.3`*(SH@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HQ-S$@
M;&EB+T1R:79E<B]K;VQA8BYP:'`Z-#@*;7-G:60@(D-O=6QD(&YO="!B:6YD
M('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(LWEXN[G[.[F[>X@\>+_Y^#R_/'_
M(/$@;&1A<"#QY?#BY?#N["XB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C8T
M(&QI8B]$<FEV97(O<VUB;&1A<"YP:'`Z-C<@;&EB+T1R:79E<B]K;VQA8BYP
M:'`Z-#`*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R
M(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+Q_R#Q(&QD87`@\>7PXN7P
M[NPN(@H*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N<&AP.C4S"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"XB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#N\NKP^_+\('!I<&4@Y.O_('-M8G!A<W-W9"XB"@HC.B!L:6(O
M1')I=F5R+W-M8G!A<W-W9"YP:'`Z-S4*;7-G:60@(D5R<F]R('-E;F1I;F<@
M9&%T82!T;R!S;6)P87-S=V0N(@IM<V=S='(@(L[XZ.'JX"#N\N_PX.+JZ"#D
MX.WM^_4@Y.O_('-M8G!A<W-W9"XB"@HC.B!L:6(O1')I=F5R+W!S<&%S<W=D
M+G!H<#HX-0IM<V=I9"`B1F%I;&5D('1O('9E<FEF>2!O;&0@<&%S<W=O<F0N
M(@IM<V=S='(@(LWE\^3@Z^[Q_"#O[N3RXN7PY.CR_"#Q\N#P^^D@[^#P[NO\
M(@H*(SH@;6%I;BYP:'`Z,C`S(&QI8B]$<FEV97(O8V]M<&]S:71E+G!H<#HY
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL=7)E(&EN(&-H86YG:6YG('!A
M<W-W;W)D(&]N("5S.B`E<R(*;7-G<W1R("+-Y2#SY.#E\O'_(/'LY>WH\OP@
M[^#P[NO\(.W@("5S.B`E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C4Q(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,C0Q(&QI8B]$<FEV97(O<&]P<&%S<V0N<&AP.C$P
M.0HC.B!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C$W,B!L:6(O1')I=F5R+W9M
M86EL;6=R+G!H<#HS-0HC.B!L:6(O1')I=F5R+VMO;&%B+G!H<#HW,@IM<V=I
M9"`B26YC;W)R96-T(%!A<W-W;W)D(@IM<V=S='(@(LWEXN7P[?OI(._@\.[K
M_"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C(S"FUS9VED(")-:6YI;75M
M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(LSH
M[>CLX.O\[?OI(/'P[NH@Y.7I\?+BZ/\@[^#P[NO_(.7YY2#MY2#H\?+EZB(*
M"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$P,@IM<V=I9"`B3F5W('!A
M<W-W;W)D.B(*;7-G<W1R("+-[N+[Z2#OX/#NZ_PB"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<W5C:"!B86-K96YD
M("<E<R<@9F]U;F0N(@IM<V=S='(@(LWE(.W@Z>3E[2!B86-K96YD("5S(@H*
M(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z.3`*;7-G:60@(D]L9"!P87-S
M=V]R9#HB"FUS9W-T<B`BT?+@\/OI(._@\.[K_#HB"@HC.B!L:6(O1')I=F5R
M+W-M8G!A<W-W9"YP:'`Z-#,*;7-G:60@(E!A<W-W9"!I<R!N;W0@<')O<&5R
M;'D@8V]N9FEG=7)E9"XB"FUS9W-T<B`B4&%S<W=D(.WE(/'J[NWTZ./S\.CP
M[N+@[2#D[NOF[?OL(.[A\.#G[NPB"@HC.B!M86EN+G!H<#HQ.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!O;B`E<RXB"FUS9W-T
M<B`BS^#P[NO\(.CG[.7MY>T@[>`@)7,B"@HC.B!L:6(O1')I=F5R+W!S<&%S
M<W=D+G!H<#HV-PIM<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&-A;B=T(&9I;F0@
M=&AE('-U<'!L:65D(&)I;BXB"FUS9W-T<B`B4&%S<W=D(.SNY//K_"#MY2#L
M[N;E\B#MX.GRZ"#MY>[A]>[DZ.S[Y2(*"B,Z(&QI8B]$<FEV97(O<'-P87-S
M=V0N<&AP.C8U"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!R
M97%U:7)E9"!P87)A;65T97)S+B(*;7-G<W1R(")087-S=V0@[.[D\^O\+B#.
M\O'S\O'RXO/^\B#MY>[A]>[DZ.S[Y2#OX/#@[.7R\/LB"@HC.B!L:6(O1')I
M=F5R+V%D<VDN<&AP.C0T"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;6ES
M<VEN9R!T87)G970@<&%R86UE=&5R+B(*;7-G<W1R(")087-S=V0@[.[D\^O\
M+B#.\O'S\O'RXO/^\B#B^_7NY.W[Y2#OX/#@[.7R\/LB"@HC.B!M86EN+G!H
M<#HQ-S8@;&EB+T1R:79E<B]S97)V=69T<"YP:'`Z-C8*;7-G:60@(E!A<W-W
M;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*;7-G<W1R
M(")087-S=V0@[.[D\^O\(.WE(.W@\?+P[N7M(.3NZ^;M^^P@[N'PX.?N["(*
M"B,Z(&QI8B]$<FEV97(O<V5R=G5F='`N<&AP.CDS"FUS9VED(")087-S=V]R
M9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960N(@IM<V=S='(@
M(E!A<W-W9"#L[N3SZ_P@[>4@[>#Q\O#NY>T@Y.[KYNW[["#NX?#@Y^[L(@H*
M(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,3$*;7-G:60@(E!L96%S92!P
M<F]V:61E(&$@;F5W('!A<W-W;W)D(@IM<V=S='(@(LWE[N'U[N3H["#M[N+[
MZ2#OX/#NZ_PB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHW"FUS9VED
M(")0;&5A<V4@<')O=FED92!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T
M<B`BS>7NX?7NY.CL(/+EZO/YZ.D@[^#P[NO\(@H*(SH@=&5M<&QA=&5S+VUA
M:6XO;6%I;BYI;F,Z,34*;7-G:60@(E!L96%S92!V97)I9GD@>6]U<B!N97<@
M<&%S<W=O<F0B"FUS9W-T<B`BPOL@Y.[KYNW[(._NY/+BY?#DZ/+\(.WNXOOI
M(._@\.[K_"(*"B,Z(&QI8B]$<FEV97(O8V]M<&]S:71E+G!H<#HS-0IM<V=I
M9"`B4F5Q=6ER960@)V1R:79E<G,G(&ES(&UI<V-O;F9I9W5R960@:6X@0V]M
M<&]S:71E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M+PY>'SY>S[Y2#D
M\.#IXN7PX"#MY2#QZN[M].CC\_#H\.[BX.W[(.(@\>[Q\N#B[>[I("A#;VUP
M;W-I=&4I(.KN[?3HX_/PX/;HZ"(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H<#HT
M,0IM<V=I9"`B4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@
M4&%S<W=D(%-13"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+2\.7A\^7L^^D@
M)W!H<'1Y<&4G(.WE(.[O\.7DY>OE[2#B(.KN[?3HX_/PX/;HZ"!087-S=V0@
M4U%,(@H*(SH@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z-#0*;7-G:60@(E)E
M<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%-13"!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("+2\.7A\^7L^^D@)W!H<'1Y<&4G(.WE(.[O\.7D
MY>OE[2#B(.KN[?3HX_/PX/;HZ"!344PB"@HC.B!T96UP;&%T97,O;6%I;B]M
M86EN+FEN8SHQ-#,*;7-G:60@(E)E<V5T(@IM<V=S='(@(M'A\.[QZ/+\(@H*
M(SH@;&EB+T1R:79E<B]S<6PN<&AP.C<P(&QI8B]$<FEV97(O=G!O<&UA:6PN
M<&AP.C<X"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+B(*;7-G<W1R("+-Y2#L[N/S(/'NY>3H[>CR\?\@\2!344P@\>7PXN7P[NPB
M"@HC.B!L:6(O1')I=F5R+W!O<'!A<W-D+G!H<#HQ,#,@;&EB+T1R:79E<B]S
M<6PN<&AP.C$R,`HC.B!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HQ,S@*;7-G
M:60@(E5S97(@;F]T(&9O=6YD(@IM<V=S='(@(L_NZ_SG[N+@\N7K_"#MY2#M
MX.GDY>TB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$S,"!L:6(O1')I=F5R
M+W!I;F4N<&AP.C(R-2!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C$R-PHC.B!L
M:6(O1')I=F5R+VMO;&%B+G!H<#HV-`IM<V=I9"`B57-E<B!N;W0@9F]U;F0N
M(@IM<V=S='(@(L_NZ_SG[N+@\N7K_"#MY2#MX.GDY>TB"@HC.B!T96UP;&%T
M97,O;6%I;B]M86EN+FEN8SHW-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@
M(LCL_R#O[NO\Y^[BX/+EZ_\Z(@H*(SH@;6%I;BYP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E
M<B`E<R(*;7-G<W1R("+"^R#MY2#L[N;E\N4@[.7M__+\(._@\.[K_"#DZ_\@
M[^[K_.?NXN#RY>O_("5S(@H*(SH@;6%I;BYP:'`Z-3,*;7-G:60@(EEO=2!M
M=7-T(&=I=F4@>6]U<B!C=7)R96YT('!A<W-W;W)D(@IM<V=S='(@(LWE[N'U
M[N3H["#RY>KS^>CI(._@\.[K_"(*"B,Z(&UA:6XN<&AP.C8R"FUS9VED(")9
M;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(LWE[N'U
M[N3H["#M[N+[Z2#OX/#NZ_PB"@HC.B!M86EN+G!H<#HV-@IM<V=I9"`B66]U
M(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(L+[(.3N
MZ^;M^R#O[N3RXN7PY.CR_"#M[N+[Z2#OX/#NZ_PB"@HC.B!M86EN+G!H<#HX
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&YE=R!P87-S=V]R9"!I
M<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@8F4@;6]R92!T:&%N("5D
M(&-H87)A8W1E<G,@(@HB;&]N9R$B"FUS9W-T<B`BS^#P[NO\(/'KZ/CJ[NP@
MY.OH[>W[Z3L@[^#P[NO\(.WE(.3NZ^;MY2#O\.CB^_C@\OP@Y.OH[>WS("5D
M(/'H[.+NZ^[B(@H*(SH@;6%I;BYP:'`Z,38U"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H86YG960A
M(@IM<V=S='(@(L_@\.[K_"#QZ^CXZN[L(.OEX^KHZ2$@R.?LY>WE[>CI(.WE
M(._P[NCGXN7DY>WN(@H*(SH@;6%I;BYP:'`Z,34V"FUS9VED(")9;W5R(&YE
M=R!P87-S=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S+B!.;W0@8VAA;F=E
M9"$B"FUS9W-T<B`BS^#P[NO\(/'KZ/CJ[NP@Z^7CZNCI(2#(Y^SE[>7MZ.D@
M[>4@[_#NZ.?BY>3E[>XB"@HC.B!M86EN+G!H<#HX,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D
M(&-H87)A8W1E<G,@;&]N9R$B"FUS9W-T<B`BS^#P[NO\(.3NZ^;E[2#A^_+\
M(.'NZ^7E("5D(/'H[.+NZ^[B(@H*(SH@;6%I;BYP:'`Z-S0*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@9&EF9F5R96YT(&9R;VT@>6]U<B!C
M=7)R96YT('!A<W-W;W)D(@IM<V=S='(@(LWNXOOI(._@\.[K_"#D[NOFY>T@
M[O+KZ/?@\OSQ_R#N\B#RY>KS^>7C[B(*"B,Z(&UA:6XN<&AP.C$R-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A
M:6X@870@;&5A<W0@)60@86QP:&%B971I8R!C:&%R86-T97)S+B(*;7-G<W1R
M("+-[N+[Z2#OX/#NZ_P@Y.[KYN7M(/'NY.7PYN#R_"#JX.H@[.CMZ.SS["`E
M9"#@Z_3@XNCR[?OU(/'H[.+NZ^[B(@H*(SH@;6%I;BYP:'`Z,3,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I
M;B!A="!L96%S="`E9"!A;'!H86YU;65R:6,@8VAA<F%C=&5R<RXB"FUS9W-T
M<B`BS>[B^^D@[^#P[NO\(.3NZ^;E[2#Q[N3E\.;@\OP@ZN#J(.SH[>CL\^P@
M)60@X.OTX.+H\NW[]2#QZ.SB[NONXB(*"B,Z(&UA:6XN<&AP.C$S-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O
M;G1A:6X@870@;&5A<W0@)60@9&EF9F5R96YT('1Y<&5S(&]F(&-H87)A8W1E
M<G,N("(*(E1H92!T>7!E<R!A<F4Z(&QO=V5R+"!U<'!E<BP@;G5M97)I8RP@
M86YD('-Y;6)O;',N(@IM<V=S='(@(B(*"B,Z(&UA:6XN<&AP.C$Q-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A
M:6X@870@;&5A<W0@)60@;&]W97)C87-E(&-H87)A8W1E<G,N(@IM<V=S='(@
M(B(*(LWNXOOI(._@\.[K_"#D[NOFY>T@\>[DY?#FX/+\(.K@ZB#LZ.WH[//L
M("5D(/'H[.+NZ^[B(.(@[>CF[>7L(/#EX^CQ\O#E(@H*(SH@;6%I;BYP:'`Z
M,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!N=6UE<FEC(&-H87)A8W1E<G,N(@IM
M<V=S='(@(LWNXOOI(._@\.[K_"#D[NOFY>T@\>[DY?#FX/+\(.K@ZB#LZ.WH
M[//L("5D(/?H\>ONXOOU(/'H[.+NZ^[B(@H*(SH@;6%I;BYP:'`Z,3$Q"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N
M=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RXB"FUS9W-T
M<B`B(@HBS>[B^^D@[^#P[NO\(.3NZ^;E[2#Q[N3E\.;@\OP@ZN#J(.SH[>CL
M\^P@)60@\>CLXN[K[N(@XB#BY?#U[>7L(/#EX^CQ\O#E(@H*(SH@;6%I;BYP
M:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D
M(&UU<W0@8V]N=&%I;B!L97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T
M97)S+B(*;7-G<W1R("+-[N+[Z2#OX/#NZ_P@Y.[KYN7M(/'NY.7PYN#R_"#O
M\.[AY>O[+B#*X.H@[.CMZ.SS["`E9"#X\BXB"@HC.B!M86EN+G!H<#HQ-#0*
M;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI
M=&5S<&%C92!C:&%R86-T97)S+B(*;7-G<W1R("+-[N+[Z2#OX/#NZ_P@Y.[K
MYN7M(.WE(.3NZ^;E[2#Q[N3E\.;@\OP@[_#NX>7K[N(B"@HC.B!M86EN+G!H
M<#HW,`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:"(*
M;7-G<W1R("+-[N+[Z2#OX/#NZ_P@[>4@\>[B[^#DX.7R(@H*(SH@=&5M<&QA
M=&5S+VUA:6XO;6%I;BYI;F,Z,3D*;7-G:60@(EEO=7(@<&%S<W=O<F1S(&1O
M(&YO="!M871C:"(*;7-G<W1R("+/X/#NZ^@@[>4@\>[B[^#DX/[R(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HW,"!L:6(O1')I=F5R+W-M8FQD87`N<&AP
M.C<S"FUS9VED(")L9&%P7W-T87)T7W1L<R!F86EL960B"FUS9W-T<B`B;&1A
M<%]S=&%R=%]T;',@[>7SY.#K\?\B"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P87-S=V0O<&\O9VQ?15,N<&\`````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,3,R`#$P-#$W,S8R-S0S`#`Q-S8W,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C('!A
M<W-W9"`R+C(@1V%L:6-I86X@=')A;G-L871I;VX*(PHC(%9E<G-I;VX@:6YI
M8VEA;"!D93H*(PHC(%)A9F%E;"!687)E;&$@/')A9F%E;"YV87)E;&%`=7-C
M+F5S/@HC($=U:6QL97)M;R!-96YD97H@/&=U:6QL94!U<V,N97,^"B,@4V5R
M=FEC:6\@9&4@871E;F-I;VX@82!U<W5A<FEO<R!E('-I<W1E;6%S"B,@56YI
M=F5R<VED861E(&1E(%-A;G1I86=O(&1E($-O;7!O<W1E;&$*(PHC(%)E=FES
M861A('D@8V]R<F5G:61A('!O<CH*(R`*(R!397)V:6-I;R!D92!N;W)M86QI
M>F%C:6]N(&QI;F=U:7-T:6-A(#QS;FQU<V-`=7-C+F5S/@HC(%5N:79E<G-I
M9&%D92!D92!386YT:6%G;R!D92!#;VUP;W-T96QA"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ('!A<W-W9%QN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#(M,#(M,C@@,#`Z,30M,#8P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,RTP."TQ.2`Q,CHT,D=-5"LQ7&XB"B),87-T+51R
M86YS;&%T;W(Z(&=U:6QL92`\9W5I;&QE0'5S8RYE<SY<;B(*(DQA;F=U86=E
M+51E86TZ($=A;&5G;UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)8+4=E;F5R871O
M<CH@2T)A8F5L(#`N.2XU7&XB"@IM<V=I9"`B0VAA;F=E('EO=7(@<&%S<W=O
M<F0B"FUS9W-T<B`B0V%M8FEE(&$@<_IA(&-H879E(&1E(&%C8V5S;R(*"FUS
M9VED(")#;VYF:7)M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B0V]N9FER;64@
M;R!N;W9A(&-H879E(&1E(&%C8V5S;R(*"FUS9VED(")%<G)O<B(*;7-G<W1R
M(")%<G)O(@H*;7-G:60@(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@
M.B`B"FUS9W-T<B`B1F%L;&]U(&\@8V%M8FEO(&1E(&-H879E(&1E(&%C8V5S
M;R(*"FUS9VED(")(96QP(@IM<V=S='(@(D%X=61A(@H*;7-G:60@(DQA;F=U
M86=E(@IM<V=S='(@(DQI;F=U82(*"FUS9VED("),;V=O=70B"FUS9W-T<B`B
M1FEN86QI>F%R(&$@<V5S:?-N(@H*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B
M365N<V%X92(*"FUS9VED(").97<@<&%S<W=O<F0Z(@IM<V=S='(@(D-H879E
M(&1E(&%C8V5S;R!N;W9A.B(*"FUS9VED(")/;&0@<&%S<W=O<F0Z(@IM<V=S
M='(@(D-H879E(&1E(&%C8V5S;R!A;G1E<FEO<CHB"@IM<V=I9"`B4&%S<W=O
M<F0@8VAA;F=E9"$B"FUS9W-T<B`BH4-H879E(&1E(&%C8V5S;R!C86UB:6%D
M82$B"@IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C
M;VYF:6=U<F5D(@IM<V=S='(@(D\@;?-D=6QO('!A<F$@8V%M8FEA<B!A(&-H
M879E(&1E(&%C8V5S;R!N;VX@<V4@8V]N9FEG=7)O=2(*"FUS9VED(")0<F]B
M;&5M/R(*;7-G<W1R("*_4')O8FQE;6%S/R(*"FUS9VED(")297-E="(*;7-G
M<W1R(")296EN:6-I87(B"@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.B(*;7-G<W1R(")396QE8V-I;VYE(&$@;&EN9W5A.B(*"FUS
M9VED(")3970@=&AE(&QA;F=U86=E('1H870@;65N=2!I=&5M<RP@97AP;&%N
M871I;VYS+"!A;F0@:&5L<"!A<F4@:6XN(@IM<V=S='(@(D5S=&%B;&5C92!A
M(&QI;F=U82!D;W,@;65N^G,L(&1A<R!E>'!L:6-A8VGS;G,@92!D82!A>'5D
M82XB"@IM<V=I9"`B4V]M92!O9B!087-S=V]R9"!M;V1U;&4G<R!C;VYF:6=U
M<F%T:6]N(&9I;&5S(&%R92!M:7-S:6YG.B(*;7-G<W1R("(B"B)!;&?Z;G,@
M9&]S(&%R<75I=F]S(&1E(&-O;F9I9W5R86-I\VX@9&\@;?-D=6QO('!A<F$@
M8V%M8FEA<B!A(&-H879E(&YO;B!S92`B"B)D86X@871O<&%D;SHB"@IM<V=I
M9"`B4W5C8V5S<R(*;7-G<W1R(")#;W)R96-T86UE;G1E(@H*;7-G:60@(B(*
M(E1H:7,@9FEL92!C;VYT<F]L<R!T:&4@9&5F875L="!P<F5F97)E;F-E<R!F
M;W(@4&%S<W=O<F0@;6]D=6QE+"!A;F0@86QS;R`B"B)C;VYT<F]L<R!W:&EC
M:"!P<F5F97)E;F-E<R!U<V5R<R!C86X@86QT97(N(@IM<V=S='(@(B(*(D5S
M=&4@87)Q=6EV;R!C;VYT<F]L82!A<R!P<F5F97)E;F-I87,@<')E9&5T97)M
M:6YA9&%S(&1O(&WS9'5L;R!P87)A(&-A;6)I87(@(@HB82!C:&%V964@861E
M;6%I<R!C;VYT<F]L82!Q=64@<')E9F5R96YC:6%S('!O9&4@;75D87(@;R!U
M<W5A<FEO+B(*"FUS9VED("(B"B)4:&ES(&9I;&4@8V]N=')O;',@=&AE('-T
M>6QE<VAE970@=&AA="!I<R!U<V5D('1O('-E="!C;VQO<G,@86YD(&9O;G1S
M(&EN("(*(F%D9&ET:6]N('1O(&]R(&]V97)R:61I;F<@2&]R9&4@9&5F875L
M=',N(@IM<V=S='(@(B(*(D5S=&4@87)Q=6EV;R!C;VYT<F]L82!A<R!F;VQL
M87,@9&4@97-T:6QO('%U92!S92!U<V%N('!A<F$@97-T86)L96-E<B!A<R`B
M"B)C;W)E<R!E('1I<&]S(&1E(&QE=')A+"!E(&-O;7!L96UE;G1E;G1A(&]U
M('-U8G-T:73Z92!O<R!V86QO<F5S("(*(G!R961E=&5R;6EN861O<R!D92!(
M;W)D92XB"@IM<V=I9"`B(@HB5&AI<R!I<R!T:&4@;6%I;B!087-S=V]R9"!M
M;V1U;&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P871H<R!A
M;F0@(@HB;W!T:6]N<R!F;W(@86QL(%!A<W-W;W)D(&UO9'5L92!S8W)I<'1S
M+B(*;7-G<W1R("(B"B)%<W1E(.D@;R!A<G%U:79O('!R:6YC:7!A;"!D92!C
M;VYF:6=U<F%C:?-N(&1O(&WS9'5L;R!P87)A(&-A;6)I87(@82!C:&%V92`B
M"B)D92!A8V-E<V\N($-O;G3I;B!A<R!R=71A<R!E(&]P8VGS;G,@<&%R82!T
M\V1O;&]S('!R;V=R86UA<R`H9&5S=&4@;?-D=6QO*2XB"@IM<V=I9"`B57-E
M<FYA;64Z(@IM<V=S='(@(E5S=6%R:6\Z(@H*;7-G:60@(E=A<FYI;F<B"FUS
M9W-T<B`B061V97)T96YC:6$B"@IM<V=I9"`B66]U(&-A;B!N;W0@8VAA;F=E
M('!A<W-W9"!F;W(@;W1H97(@=7-E<B(*;7-G<W1R(").;VX@<&]D92!M=61A
M<B!A(&-H879E(&1E(&%C8V5S;R!D;W5T<F\@=7-U87)I;R(*"B,L(&,M9F]R
M;6%T"FUS9VED(")9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O<B!U<V5R
M("5S(@IM<V=S='(@(DYO;B!P;V1E(&-A;6)I87(@82!C:&%V92!D92!A8V-E
M<V\@9&\@=7-U87)I;R`E<R(*"FUS9VED(")9;W4@;75S="!G:79E('EO=7(@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(D5S8W)I8F$@82!N;W9A(&-H879E(&1E
M(&%C8V5S;R(*"FUS9VED(")9;W4@;75S="!G:79E('EO=7(@;VQD('!A<W-W
M;W)D(@IM<V=S='(@(D5S8W)I8F$@82!C:&%V92!D92!A8V-E<V\@86YT97)I
M;W(B"@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y;W5R('5S97)I9"(*;7-G<W1R
M(")%<V-R:6)A(&\@<V5U(&YO;64@9&4@=7-U87)I;R(*"FUS9VED(")9;W4@
M;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`B4F5P:71A
M(&$@;F]V82!C:&%V92!D92!A8V-E<V\B"@IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")!('/Z82!I;F9O<FUA8VGS;B(*"FUS9VED(")9;W5R
M(&YE=R!P87-S=V]R9',@9&ED;B=T(&UA=&-H(@IM<V=S='(@(D%S(&YO=F%S
M(&-H879E<R!D92!A8V-E<V\@<V]N(&1I9F5R96YT97,B"@IM<V=I9"`B06-C
M;W5N="!-86YA9V5R(@IM<V=S='(@(EAE<W1O<B!D82!C;VYT82(*"FUS9VED
M(")#:&%N9VEN9R!087-S=V]R9"!O;B`E<R(*;7-G<W1R(")#86UB:6%N9&\@
M82!C:&%V92!D92!A8V-E<V\@96X@)7,B"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O<&\O8V%?15,N<&\`````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-#,Q`#$P
M-#$W,S8R-S0S`#`Q-S8U-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C(%1R861U8V-I\R!A;"!C871A;&$@9&5L(&WS9'5L
M(&1E(&-A;G9I(&1E('!A<W-W;W)D"B,@0V]P>7)I9VAT("A#*2`R,#`R($9R
M964@4V]F='=A<F4@1F]U;F1A=&EO;BP@26YC+@HC($9)4E-4($%55$A/4B`\
M:F]A;BYJ;W)B84!R=7-C+FYE=#XL(#(P,#0N"B,@"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!P87-S=V1<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`T+3$Q+3(Y(#(S.C`Y+3`V,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#0M,3$M,CD@,C,Z,C0@1TU4*S5<;B(*(DQA<W0M5')A
M;G-L871O<CH@2F]A;B!*;W)B82!#86QS:6YA(#QJ;V%N+FIO<F)A0')U<V,N
M;F5T/EQN(@HB3&%N9W5A9V4M5&5A;3H@0V%T86QA(&-A7T53(#QI;F9O0')U
M<V,N;F5T/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*;7-G:60@(D-H86YG92!Y
M;W5R('!A<W-W;W)D(@IM<V=S='(@(D-A;G9I82!L82!C;VYT<F%S96YY82(*
M"FUS9VED(")#;VYF:7)M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B0V]N9FER
M;6$@;&$@;F]V82!C;VYT<F%S96YY83HB"@IM<V=I9"`B17)R;W(B"FUS9W-T
M<B`B17)R;W(B"@IM<V=I9"`B1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R
M9"`Z("(*;7-G<W1R(")&86QL:70@96P@8V%N=FD@9&4@8V]N=')A<V5N>6$B
M"@IM<V=I9"`B2&5L<"(*;7-G<W1R(")!:G5D82(*"FUS9VED("),86YG=6%G
M92(*;7-G<W1R("),;&5N9W5A=&=E(@H*;7-G:60@(DQO9V]U="(*;7-G<W1R
M(")&:6YA;&ET>F%R(%-E<W-I\R(*"FUS9VED(")-97-S86=E(@IM<V=S='(@
M(DUI<W-A=&=E(@H*;7-G:60@(DYE=R!P87-S=V]R9#HB"FUS9W-T<B`B3F]V
M82!#;VYT<F%S96YY82(*"FUS9VED(")/;&0@<&%S<W=O<F0Z(@IM<V=S='(@
M(D%N=&EG82!#;VYT<F%S96YY82(*"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M(2(*;7-G<W1R(")#;VYT<F%S96YY82!#86YV:6%D82(*"FUS9VED(")087-S
M=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960B"FUS9W-T
M<B`B3?)D=6P@9&4@8V%N=FD@9&4@0VQA=2!N;R!C;VYF:6=U<F%T(&%D96-U
M861A;65N="(*"FUS9VED(")0<F]B;&5M/R(*;7-G<W1R("*_4')O8FQE;6$_
M(@H*;7-G:60@(E)E<V5T(@IM<V=S='(@(E)E:6YI8VEA<B(*"FUS9VED(")3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5C
M8VEO;FD@96P@<V5U(&QL96YG=6%T9V4@<')E9F5R:70B"@IM<V=I9"`B4V5T
M('1H92!L86YG=6%G92!T:&%T(&UE;G4@:71E;7,L(&5X<&QA;F%T:6]N<RP@
M86YD(&AE;'`@87)E(&EN+B(*;7-G<W1R("(B"B)%<W1A8FQE:7@@96P@;&QE
M;F=U871G92!E;B!E;"!Q=64@97-T86X@96QS(&UE;G5S+"!E>'!L:6-A8VEO
M;G,@:2!L82!A:G5D82(*"FUS9VED(")3;VUE(&]F(%!A<W-W;W)D(&UO9'5L
M92=S(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I;F<Z(@IM<V=S='(@
M(B(*(D%L9W5N<R!D96QS(&%R>&EU<R!D92!M\F1U;"!D92!C;VYF:6=U<F%C
M:?,@9&4@8V%N=FD@9&4@8VQA=2!N;R!E<R!T<F]B96XZ(@H*;7-G:60@(E-U
M8V-E<W,B"FUS9W-T<B`BR'AI="(*"FUS9VED("(B"B)4:&ES(&9I;&4@8V]N
M=')O;',@=&AE(&1E9F%U;'0@<')E9F5R96YC97,@9F]R(%!A<W-W;W)D(&UO
M9'5L92P@86YD(&%L<V\@(@HB8V]N=')O;',@=VAI8V@@<')E9F5R96YC97,@
M=7-E<G,@8V%N(&%L=&5R+B(*;7-G<W1R("(B"B)!<75E<W0@87)X:74@8V]N
M=')O;&$@;&5S('!R969E<F5N8VEE<R!P97(@9&5F96-T92!D96P@;?)D=6P@
M9&4@8V%N=FD@9&4@(@HB8V]N=')A<V5N>6$@:2!A(&UE<R!A(&UE<R!C;VYT
M<F]L82!Q=6EN97,@<V]N(&QE<R!P<F5F97)E;F-I97,@<75E('!O9&5N('-E
M<B`B"B)A;'1E<F%D97,@<&5L<R!U<W5A<FES+B(*"FUS9VED("(B"B)4:&ES
M(&9I;&4@8V]N=')O;',@=&AE('-T>6QE<VAE970@=&AA="!I<R!U<V5D('1O
M('-E="!C;VQO<G,@86YD(&9O;G1S(&EN("(*(F%D9&ET:6]N('1O(&]R(&]V
M97)R:61I;F<@2&]R9&4@9&5F875L=',N(@IM<V=S='(@(B(*(D%Q=65S="!A
M<GAI=2!C;VYT<F]L82!E;',@97-T:6QS('%U92!S;VX@=7-A=',@<&5R(&5S
M=&%B;&ER(&-O;&]R<R!I(&9O;G1S(/,@(@HB<V]B<F5E<V-R:75R92!E;',@
M=F%L;W)S('!E<B!D969E8W1E(&1E($AO<F1E+B(*"FUS9VED("(B"B)4:&ES
M(&ES('1H92!M86EN(%!A<W-W;W)D(&UO9'5L92!C;VYF:6=U<F%T:6]N(&9I
M;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N9"`B"B)O<'1I;VYS(&9O<B!A;&P@
M4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N(@IM<V=S='(@(B(*(D%Q=65S="!E
M<R!E;"!A<GAI=2!P<FEN8VEP86P@9&4@8V]N9FEG=7)A8VGS(&1E;"!M\F1U
M;"!D92!C86YV:6\@9&4@(@HB8V]N=')A<V5N>6$N($-O;G3I(')U=&5S(&D@
M;W!C:6]N<R!P97(@=&]T<R!E;',@9W5I;VYS(&1E;"!M\F1U;R!D92!C86YV
M:2!D92`B"B)C;VYT<F%S96YY82XB"@IM<V=I9"`B57-E<FYA;64Z(@IM<V=S
M='(@(E5S=6%R:3HB"@IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!9'9E<G3H
M;F-I82(*"FUS9VED(")9;W4@8V%N(&YO="!C:&%N9V4@<&%S<W=D(&9O<B!O
M=&AE<B!U<V5R(@IM<V=S='(@(DYO('!O=',@8V%N=FEA<B!L82!C;&%U(&$@
M=6X@86QT<F4@=7-U87)I(@H*(RP@8RUF;W)M870*;7-G:60@(EEO=2!C86XG
M="!C:&%N9V4@<&%S<W=O<F0@9F]R('5S97(@)7,B"FUS9W-T<B`B5F]S=.@@
M;F\@<&]T(&-A;G9I87(@;&$@8VQA=2!P96P@=7-U87)I("5S(@H*;7-G:60@
M(EEO=2!M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`B2&%S
M(&0G97-C<FEU<F4@;&$@=&5V82!N;W9A(&-O;G1R87-E;GEA(@H*;7-G:60@
M(EEO=2!M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O<F0B"FUS9W-T<B`B2&%S
M(&1E(&5S8W)I=7)E(&QA(&%N=&EG82!C;VYT<F%S96YY82(*"FUS9VED(")9
M;W4@;75S="!G:79E('EO=7(@=7-E<FED(@IM<V=S='(@(DAA<R!D)V5S8W)I
M=7)E(&5L('1E=2!U<W5A<FDB"@IM<V=I9"`B66]U(&UU<W0@=F5R:69Y('EO
M=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(DAA<R!D92!V97)I9FEC87(@;&$@
M=&5V82!N;W9A(&-O;G1R87-E;GEA(@H*;7-G:60@(EEO=7(@26YF;W)M871I
M;VXB"FUS9W-T<B`B3&$@<V5V82!);F9O<FUA8VGS(@H*;7-G:60@(EEO=7(@
M;F5W('!A<W-W;W)D<R!D:61N)W0@;6%T8V@B"FUS9W-T<B`B3&$@8V]N=')A
M<V5N>6$@;F]V82!I(&QA(&%N=&EG82!N;R!C;VYC;W)D96XB"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+W!O+VED7TE$+G!O````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C`S-P`Q
M,#0Q-S,V,C<T,P`P,3<V-3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!33TU%($1%4T-225!4259%(%1)5$Q%+@HC($-O
M<'ER:6=H="`H0RD@645!4B!42$4@4$%#2T%'12=3($-/4%E224=(5"!(3TQ$
M15(*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@
M;&EC96YS92!A<R!T:&4@4$%#2T%'12!P86-K86=E+@HC($9)4E-4($%55$A/
M4B`\14U!24Q`041$4D534SXL(%E%05(N"B,*;7-G:60@(B(*;7-G<W1R("(B
M"B)0<F]J96-T+4ED+59E<G-I;VXZ(%!A<W-W9"!V,BXQ7&XB"B)03U0M0W)E
M871I;VXM1&%T93H@,C`P-"TP,2TP.2`P.3HS-RLP-S`P7&XB"B)03RU2979I
M<VEO;BU$871E.B`R,#`T+3`Q+3`Y(#$S.C4V*S`W,#!<;B(*(DQA<W0M5')A
M;G-L871O<CH@4VQA;6EN(#QS;&%M:6Y`=6YE:BYA8RYI9#Y<;B(*(DQA;F=U
M86=E+51E86TZ(%505"!422!53D5*(#QU<'1T:4!U;F5J+F%C+FED/EQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"@IM<V=I9"`B0F%C:V5N9"!N;W0@8V]R<F5C=&QY
M(&EM<&QE;65N=&5D+B(*;7-G<W1R(")"86-K96YD('1I9&%K(&1I:6UP;&5M
M96YT87-I:V%N(&1E;F=A;B!B96YA<BXB"@IM<V=I9"`B0VAA;F=E(%!A<W-W
M;W)D(@IM<V=S='(@(E5B86@@4&%S<W=O<F0B"@IM<V=I9"`B0VAA;F=E('EO
M=7(@<&%S<W=O<F0B"FUS9W-T<B`B56)A:"!P87-S=V]R9"!A;F1A(@H*(RP@
M8RUF;W)M870*;7-G:60@(D-H86YG:6YG(%!A<W-W;W)D(&]N("5S(@IM<V=S
M='(@(DUE;F=U8F%H(%!A<W-W;W)D('!A9&$@)7,B"@IM<V=I9"`B0V]N9FER
M;2!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(DMO;F9I<FUA<VD@<&%S<W=O<F0@
M8F%R=3HB"@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B
M"FUS9W-T<B`B5&ED86L@8FES82!D:6MI<FEM(&ME('-E<G9E<B!L9&%P(@H*
M;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S
M='(@(E1I9&%K(&)I<V$@:V]N96MS:2!K92!S97)V97(@;&1A<"(*"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"XB"FUS9W-T<B`B
M5&ED86L@8FES82!M96UB=6MA('!I<&4@:V4@<VUB<&%S<W=D+B(*"FUS9VED
M(")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+B(*;7-G<W1R(")+
M97-A;&%H86X@;65N9VER:6T@9&%T82!K92!S;6)P87-S=V0N(@H*;7-G:60@
M(D5R<F]R(@IM<V=S='(@(DME<V%L86AA;B(*"FUS9VED(")&86EL=7)E(&EN
M(&-H86YG:6YG('!A<W-W;W)D(#H@(@IM<V=S='(@(D=A9V%L(&UE;F=U8F%H
M('!A<W-W;W)D(#H@(@H*;7-G:60@(DAE;'`B"FUS9W-T<B`B0F%N='5A;B(*
M"FUS9VED("));F-O<F5C="!087-S=V]R9"(*;7-G<W1R(")087-S=V]R9"!3
M86QA:"(*"FUS9VED("),;V=O=70B"FUS9W-T<B`B2V5L=6%R(@H*;7-G:60@
M(DUE<W-A9V4B"FUS9W-T<B`B4&5S86XB"@IM<V=I9"`B3F5W('!A<W-W;W)D
M.B(*;7-G<W1R(")087-S=V]R9"!B87)U.B(*"FUS9VED(")/;&0@<&%S<W=O
M<F0Z(@IM<V=S='(@(E!A<W-W;W)D(&QA;6$Z(@H*;7-G:60@(E!A<W-W;W)D
M(&-H86YG960A(@IM<V=S='(@(E!A<W-W;W)D(&)E<G5B86@A(@H*;7-G:60@
M(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*
M;7-G<W1R(")-;V1U;"!P87-S=V]R9"!T:61A:R!D:6MO;F9I9W5R87-I(&1E
M;F=A;B!S96UP=7)N82(*"FUS9VED(")0<F]B;&5M/R(*;7-G<W1R(")-87-A
M;&%H/R(*"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE
M9"!I;B!344P@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)W!H<'1Y<&4G('EA
M;F<@9&EP97)L=6MA;B!T:61A:R!D:7-P97-I9FEK87-I('!A9&$@:V]N9FEG
M=7)A<VD@4U%,+B(*"FUS9VED(")297-E="(*;7-G<W1R(")297-E="(*"FUS
M9VED(")397)V97(B"FUS9W-T<B`B4V5R=F5R(@H*;7-G:60@(E-O;64@;V8@
M4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@;6ES
M<VEN9SHB"FUS9W-T<B`B0F5B97)A<&$@9FEL92!K;VYF:6=U<F%S:2!M;V1U
M;"!087-S=V]R9"!H:6QA;F<Z(@H*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B
M4W5K<V5S(@H*;7-G:60@(B(*(E1H:7,@9FEL92!C;VYT86EN<R!B86-K96YD
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@9F]R('1H92!087-S=V]R9"!M
M;V1U;&4@(@HB<V-R:7!T<RXB"FUS9W-T<B`B(@HB1FEL92!I;FD@8F5R:7-I
M(&EN9F]R;6%S:2!K;VYF:6=U<F%S:2!B86-K96YD('5N='5K('-C<FEP="!M
M;V1U;"!087-S=V]R9"XB"@IM<V=I9"`B(@HB5&AI<R!I<R!T:&4@;6%I;B!0
M87-S=V]R9"!M;V1U;&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN
M<R!P871H<R!A;F0@(@HB;W!T:6]N<R!F;W(@86QL(%!A<W-W;W)D(&UO9'5L
M92!S8W)I<'1S+B(*;7-G<W1R("(B"B));FD@861A;&%H(&9I;&4@=71A;6$@
M:V]N9FEG=7)A<VD@;6]D=6P@4&%S<W=O<F0N($9I;&4@:6YI(&)E<FES:2!P
M871H(&1A;B`B"B)P:6QI:&%N('5N='5K('-E;75A('-C<FEP="!M;V1U;"!0
M87-S=V]R9"XB"@IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BXB"FUS9W-T<B`B5&ED86L@8FES82!K;VYE:W-I(&ME('-E<G9E<B!3
M44PN(@H*;7-G:60@(E5S97(@;F]T(&9O=6YD(@IM<V=S='(@(E!E;6%K86D@
M=&ED86L@9&ET96UU:V%N(@H*;7-G:60@(E5S97(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")096UA:V%I('1I9&%K(&1I=&5M=6MA;BXB"@IM<V=I9"`B57-E<FYA
M;64Z(@IM<V=S='(@(E5S97)N86UE.B(*"FUS9VED(")787)N:6YG(@IM<V=S
M='(@(E!E<FEN9V%T86XB"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U(&-A;B=T
M(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<R(*;7-G<W1R(")!;F1A('1I
M9&%K(&)I<V$@;65N9W5B86@@<&%S<W=O<F0@=6YT=6L@=7-E<B`E<R(*"FUS
M9VED(")9;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@
M(D%N9&$@:&%R=7,@;65M8F5R:2!P87-S=V]R9"!B87)U(&%N9&$B"@IM<V=I
M9"`B66]U(&UU<W0@9VEV92!Y;W5R(&]L9"!P87-S=V]R9"(*;7-G<W1R(")!
M;F1A(&AA<G5S(&UE;6)E<FD@<&%S<W=O<F0@;&%M82!A;F1A(@H*;7-G:60@
M(EEO=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")!
M;F1A(&AA<G5S('9E<FEF:6MA<VD@<&%S<W=O<F0@8F%R=2!A;F1A(@H*(RP@
M8RUF;W)M870*;7-G:60@(B(*(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!L
M;VYG.R!P87-S=V]R9',@;6%Y(&YO="!B92!M;W)E('1H86X@)60@8VAA<F%C
M=&5R<R`B"B)L;VYG(2(*;7-G<W1R("(B"B)087-S=V]R9"!B87)U(&%N9&$@
M=&5R;&%L=2!P86YJ86YG.R!P87-S=V]R9"!M=6YG:VEN('1I9&%K(&QE8FEH
M('!A;FIA;F<@(@HB9&%R:2`E9"!K87)A:W1E<B$B"@IM<V=I9"`B66]U<B!N
M97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N
M9V5D(2(*;7-G<W1R(")087-S=V]R9"!B87)U(&%N9&$@=&5R;&%L=2!S:6UP
M96P@=6YT=6L@9&ET96)A:R$@5&ED86L@8F5R=6)A:"$B"@HC+"!C+69O<FUA
M=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!A="!L96%S="`E
M9"!C:&%R86-T97)S(&QO;F<A(@IM<V=S='(@(E!A<W-W;W)D(&)A<G4@86YD
M82!H87)U<R!P86QI;F<@<V5D:6MI="!S97!A;FIA;F<@)60@:V%R86MT97(B
M"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F97)E;G0@
M9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O<F0@
M8F%R=2!A;F1A(&AA<G5S(&)E<F)E9&$@9&5N9V%N('!A<W-W;W)D(&%N9&$@
M<V%A="!I;FDB"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA<F%C
M=&5R<RXB"FUS9W-T<B`B4&%S<W=O<F0@8F%R=2!A;F1A(&AA<G5S(&)E<FES
M:2!P86QI;F<@<V5D:6MI="`E9"!K87)A:W1E<B!A;&9A8F5T+B(*"B,L(&,M
M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@
M870@;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N(@IM<V=S='(@
M(B(*(E!A<W-W;W)D(&)A<G4@86YD82!H87)U<R!B97)I<VD@<&%L:6YG('-E
M9&EK:70@)60@:V%R86MT97(@86QF86YU;65R:6LN(@H*(RP@8RUF;W)M870*
M;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S
M="`E9"!L;W=E<F-A<V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`B4&%S<W=O<F0@
M8F%R=2!A;F1A(&AA<G5S(&)E<FES:2!P86QI;F<@<V5D:6MI="`E9"!H=7)U
M9B!K96-I;"XB"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&YU;65R:6,@8VAA<F%C=&5R
M<RXB"FUS9W-T<B`B4&%S<W=O<F0@8F%R=2!A;F1A(&AA<G5S(&)E<FES:2!P
M86QI;F<@<V5D:6MI="`E9"!K87)A:W1E<B!N=6UE<FEK+B(*"B,L(&,M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@
M;&5A<W0@)60@=7!P97)C87-E(&-H87)A8W1E<G,N(@IM<V=S='(@(E!A<W-W
M;W)D(&)A<G4@86YD82!H87)U<R!B97)I<VD@<&%L:6YG('-E9&EK:70@)60@
M:'5R=68@8F5S87(N(@H*(RP@8RUF;W)M870*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L97-S('1H86X@)60@=VAI=&5S<&%C
M92!C:&%R86-T97)S+B(*;7-G<W1R(")087-S=V]R9"!B87)U(&%N9&$@:&%R
M=7,@8F5R:7-I(&MU<F%N9R!D87)I("5D(&MA<F%K=&5R('-P87-I+B(*"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&YO="!C;VYT86EN('=H:71E
M<W!A8V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`B4&%S<W=O<F0@8F%R=2!A;F1A
M('1I9&%K(&)O;&5H(&)E<FES:2!K87)A:W1E<B!S<&%S:2XB"@IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:"(*;7-G<W1R(")087-S
M=V]R9"!B87)U(&%N9&$@=&ED86L@8V]C;VLB"@IM<V=I9"`B=&5M<&YA;2@I
M(&9A:6QE9"$B"FUS9W-T<B`B=&5M<&YA;2@I(&=A9V%L(2(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+W!O+W)O7U)/+G!O````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,34Q-P`Q,#0Q-S,V,C<T,P`P,3<W,C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R!087-S
M=V0@4F]M86YI86X@5')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`S
M($AO<F1E(%!R;VIE8W0*(R!%=6=E;B!(;V%N8V$@/&5U9V5N:$!U<F)A;BUG
M<F%F>"YR;SXL(#(P,#,N"B,@36%R:75S($1R86=U;&5S8W4@/&UA<FEU<V1`
M=7)B86XM9W)A9G@N<F\^+"`R,#`S+@IM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@4&%S<W=D(#(N,EQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#,M,#(M,C0@,30Z-#DK,#(P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P,RTP,RTP,2`Q,CHP,"LP,C`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($5U9V5N($AO86YC82`\975G96YH0'5R8F%N+6=R869X+G)O/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@4F]M86YI86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"@IM<V=I9"`B0F%C:V5N9"!N;W0@8V]R
M<F5C=&QY(&EM<&QE;65N=&5D+B(*;7-G<W1R(")"86-K96YD(&EN8V]R96-T
M(&EM<&QE;65N=&%T+B(*"FUS9VED(")#:&%N9V4@4&%S<W=O<F0B"FUS9W-T
M<B`B4V-H:6UB82!P87)O;&$B"@IM<V=I9"`B0VAA;F=E('EO=7(@<&%S<W=O
M<F0B"FUS9W-T<B`B4V-H:6UB82!P87)O;&$@=&$B"@HC+"!C+69O<FUA=`IM
M<V=I9"`B0VAA;F=I;F<@4&%S<W=O<F0@;VX@)7,B"FUS9W-T<B`B4V-H:6UB
M87)E('!A<F]L82!L82`E<R(*"FUS9VED(")#;VYF:7)M(&YE=R!P87-S=V]R
M9#HB"FUS9W-T<B`B0V]N9FER;6%R92!P87)O;&$@;F]U83HB"@IM<V=I9"`B
M0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B0V]N96-T
M87)E(&YE<F5U<VET82!L82!S97)V97)U;"!L9&%P(@H*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(D-O;F5C=&%R
M92!N97)E=7-I=&$@;&$@<V5R=F5R=6P@;&1A<"(*"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"XB"FUS9W-T<B`B3&5G871U<F$@
M:6UP;W-I8FEL82!C=2!S;6)P87-S=V0B"@IM<V=I9"`B17)R;W(@<V5N9&EN
M9R!D871A('1O('-M8G!A<W-W9"XB"FUS9W-T<B`B17)O87)E(&QA('1R:6UI
M=&5R96$@9&%T96QO<B!C871R92!S;6)P87-S=V0N(@H*;7-G:60@(D5R<F]R
M(@IM<V=S='(@(D5R;V%R92(*"FUS9VED(")&86EL=7)E(&EN(&-H86YG:6YG
M('!A<W-W;W)D(#H@(@IM<V=S='(@(D5R;V%R92!I;B!S8VAI;6)A<F5A('!A
M<F]L96D@.B`B"@IM<V=I9"`B2&5L<"(*;7-G<W1R(")!:G5T;W(B"@IM<V=I
M9"`B26YC;W)E8W0@4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA(&EN8V]R96-T
M82(*"FUS9VED("),;V=O=70B"FUS9W-T<B`B265S:7)E(@H*;7-G:60@(DUE
M<W-A9V4B"FUS9W-T<B`B365S86HB"@IM<V=I9"`B3F5W('!A<W-W;W)D.B(*
M;7-G<W1R(")087)O;&$@;F]U83HB"@IM<V=I9"`B3VQD('!A<W-W;W)D.B(*
M;7-G<W1R(")087)O;&$@=F5C:&4Z(@H*;7-G:60@(E!A<W-W;W)D(&-H86YG
M960A(@IM<V=S='(@(E!A<F]L82!S8VAI;6)A=&$A(@H*;7-G:60@(E!A<W-W
M;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*;7-G<W1R
M(")-;V1U;'5L(&1E('!A<F]L92!I;F-O<F5C="!C;VYF:6=U<F%T(@H*;7-G
M:60@(E!R;V)L96T_(@IM<V=S='(@(E!R;V)L96UA/R(*"FUS9VED(")297%U
M:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!344P@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B)W!H<'1Y<&4G(&YE<W!E8VEF:6-A="!I;B!C;VYF
M:6=U<F%T:6$@4U%,+B(*"FUS9VED(")297-E="(*;7-G<W1R(")297-E=&%R
M92(*"FUS9VED(")397)V97(B"FUS9W-T<B`B4V5R=F5R(@H*;7-G:60@(E-O
M;64@;V8@4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A
M<F4@;6ES<VEN9SHB"FUS9W-T<B`B06YU;6ET92!F:7-I97)E(&1E(&-O;F9I
M9W5R87)E(%!A<W-W;W)D(&QI<'-E<V,Z(@H*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`B4W5C8V5S(@H*;7-G:60@(B(*(E1H:7,@9FEL92!C;VYT86EN<R!B
M86-K96YD(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@9F]R('1H92!087-S
M=V]R9"!M;V1U;&4@(@HB<V-R:7!T<RXB"FUS9W-T<B`B(@HB06-E<W0@9FES
M:65R(&-O;G1I;F4@:6YF;W)M871I:6QE(&1E(&-O;F9I9W5R87)E('!E;G1R
M=2!M;V1U;'5L(%!A<W-W;W)D("(*"FUS9VED("(B"B)4:&ES(&ES('1H92!M
M86EN(%!A<W-W;W)D(&UO9'5L92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET(&-O
M;G1A:6YS('!A=&AS(&%N9"`B"B)O<'1I;VYS(&9O<B!A;&P@4&%S<W=O<F0@
M;6]D=6QE('-C<FEP=',N(@IM<V=S='(@(B(*(D%C97-T82!E(&9I<VEE<G5L
M('!R:6YC:7!A;"!D92!C;VYF:6=U<F%R92!087-S=V]R9"X@0V]N=&EN92!C
M86EL92!S:2`B"B)O<'1I=6YI;&4@<&5N=')U('-C<FEP='5R:6QE(%!A<W-W
M9"X@(@H*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M(@IM<V=S='(@(D-O;F5C=&%R92!L82!S97)V97)U;"!344P@97-U871A+B(*
M"FUS9VED(")5<V5R(&YO="!F;W5N9"(*;7-G<W1R(")5=&EL:7IA=&]R(&YE
M9V%S:70B"@IM<V=I9"`B57-E<B!N;W0@9F]U;F0N(@IM<V=S='(@(E5T:6QI
M>F%T;W(@;F5G87-I="XB"@IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E5T
M:6QI>F%T;W(Z(@H*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B079E<G1I<VUE
M;G0B"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H86YG92!P87-S
M=V]R9"!F;W(@=7-E<B`E<R(*;7-G<W1R(").=2!P;W1I('-C:&EM8F$@<&%R
M;VQA('!E;G1R=2!U=&EL:7IA=&]R=6P@)7,B"@IM<V=I9"`B66]U(&UU<W0@
M9VEV92!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")4<F5B=6EE(&EN=')O
M9'5S82!O(&YO=6$@<&%R;VQA(@H*;7-G:60@(EEO=2!M=7-T(&=I=F4@>6]U
M<B!O;&0@<&%S<W=O<F0B"FUS9W-T<B`B5')E8G5I92!I;G1R;V1U<V$@=F5C
M:&5A('!A<F]L82(*"FUS9VED(")9;W4@;75S="!V97)I9GD@>6]U<B!N97<@
M<&%S<W=O<F0B"FUS9W-T<B`B5')E8G5I92!V97)I9FEC871A(&YO=6$@<&%R
M;VQA(@H*(RP@8RUF;W)M870*;7-G:60@(B(*(EEO=7(@;F5W('!A<W-W;W)D
M(&ES('1O;R!L;VYG.R!P87-S=V]R9',@;6%Y(&YO="!B92!M;W)E('1H86X@
M)60@8VAA<F%C=&5R<R`B"B)L;VYG(2(*;7-G<W1R("(B"B).;W5A('!A<F]L
M82!E('!R96$@;'5N9V$[('!A<F]L96QE(&YU('!O="!F:2!M86D@;'5N9VD@
M9&4@)60@8V%R86-T97)E(2(*"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!I
M<R!T;V\@<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H86YG960A(@IM<V=S='(@
M(DYO=6$@<&%R;VQA(&4@<')E82!S:6UP;'4@9&4@9VAI8VET(2!.97-C:&EM
M8F%T82$B"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M;75S="!B92!A="!L96%S="`E9"!C:&%R86-T97)S(&QO;F<A(@IM<V=S='(@
M(DYO=6$@<&%R;VQA('1R96)U:64@<V$@9FEE(&1E(&UI;FEM("5D(&-A<F%C
M=&5R92$B"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F
M97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T<B`B3F]U
M82!P87)O;&$@=')E8G5I92!S82!F:64@9&EF97)I=&$@9&4@<&%R;VQA(&-U
M<F5N=&$B"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA<F%C=&5R
M<RXB"FUS9W-T<B`B3F]U82!P87)O;&$@=')E8G5I92!S82!C;VYT:6YA(&UI
M;FEM("5D(&-A<F%C=&5R92!A;&9A8F5T:6-E+B(*"B,L(&,M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@
M)60@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N(@IM<V=S='(@(DYO=6$@<&%R
M;VQA('1R96)U:64@<V$@8V]N=&EN82!M:6YI;2`E9"!C87)A8W1E<F4@86QF
M86YU;65R:6-E+B(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;&]W97)C87-E(&-H87)A
M8W1E<G,N(@IM<V=S='(@(DYO=6$@<&%R;VQA('1R96)U:64@<V$@8V]N=&EN
M82!M:6YI;2`E9"!C87)A8W1E<F4@;6EN=7-C=6QE+B(*"B,L(&,M9F]R;6%T
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@;G5M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R(").;W5A('!A<F]L
M82!T<F5B=6EE('-A(&-O;G1I;F$@8V5L('!U=&EN("5D(&-A<F%C=&5R92!N
M=6UE<FEC92XB"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D('5P<&5R8V%S92!C:&%R86-T
M97)S+B(*;7-G<W1R(").;W5A('!A<F]L82!T<F5B=6EE('-A(&-O;G1I;F$@
M;6EN:6T@)60@8V%R86-T97)E(&UA:G5S8W5L92XB"@HC+"!C+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE<W,@
M=&AA;B`E9"!W:&ET97-P86-E(&-H87)A8W1E<G,N(@IM<V=S='(@(DYO=6$@
M<&%R;VQA('1R96)U:64@<V$@8V]N=&EN82!M86D@<'5T:6X@9&4@)60@<W!A
M=&EI+B(*"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&YO="!C;VYT
M86EN('=H:71E<W!A8V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`B3F]U82!P87)O
M;&$@;G4@=')E8G5I92!S82!C;VYT:6YA('-P871I:2XB"@IM<V=I9"`B66]U
M<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:"(*;7-G<W1R(")087)O;&5L
M92!N;VD@;G4@<V4@<&]T<FEV97-C(@H*;7-G:60@(G1E;7!N86TH*2!F86EL
M960A(@IM<V=S='(@(G1E;7!N86TH*2!E<W5A=&$A(@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!A<W-W9"]P;R]S:U]32RYP;P``````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`T-#,`,3`T,3<S-C(W-#,`,#$W
M-S$T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",@4VQO=F%K('1R86YS;&%T:6]N<R!F;W(@<&%S<W=D('!A8VMA9V4*(R!3
M;&]V96YS:^D@<')E:VQA9'D@<')E(&)A;.UK('!A<W-W9"X*(R!#;W!Y<FEG
M:'0@*$,I(#(P,#4@279A;B!.;W)I<R`\=FEX0'9A>FMA+G-K/@HC(%1H:7,@
M9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S
M('1H92!H;W)D92!P86-K86=E+@HC("A#*2`R,#`U($EV86X@3F]R:7,@/'9I
M>$!V87IK82YS:SX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M
M5F5R<VEO;CH@<&%S<W=D(#,N,%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3`Y+3$V(#(R.C$W*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#4M,#DM,38@,C(Z,3<K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!)=F%N
M($YO<FES(#QV:7A`=F%Z:V$N<VL^7&XB"B),86YG=6%G92U496%M.B!3;&]V
M86L@/'9I>$!V87IK82YS:SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,EQN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L
M+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&X]/3$I(#\@,"`Z("AN/CTR
M("8F(&X\/30I(#\@,2`Z(#([7&XB"@HC.B!L:6(O1')I=F5R+V5X<&5C="YP
M:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E<R!N;W0@97AI<W0@
M;W(@:7,@;F]T(&5X96-U=&%B;&4N(@IM<V=S='(@(B5S(&YE97AI<W1U:F4@
M86QE8F\@<V$@;F5DX2!S<'5S=&F[+B(*"B,Z(&QI8B]$<FEV97(O8V]M<&]S
M:71E+G!H<#HV-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@=6YA8FQE('1O
M(&QO860@9')I=F5R.B`E<R(*;7-G<W1R("(E<SH@;F5P;V1A<FEL;R!S82!N
M8>CM=&&[(&]V;.%D8>@Z("5S(@H*(SH@;&EB+T1R:79E<B]A9'-I+G!H<#HV
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!1%-)(&5R<F]R("5S+B(*;7-G<W1R
M(")#:'EB82!!1%-)("5S+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S=V0N<&AP
M.C$P-2!L:6(O1')I=F5R+V%D<VDN<&AP.C8T"FUS9VED(")!8V-E<W,@1&5N
M:65D+B(*;7-G<W1R(")0<NUS='5P('IA;6EE=&YU=/TN(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z.#4*;7-G:60@(D)A8VME;F0@;F]T(&-O<G)E8W1L>2!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B0F%C:V5N9"!N:64@:F4@<W!RX79N92!I;7!L
M96UE;G1O=F%N_2XB"@HC.B!M86EN+G!H<#HR-3`@=&5M<&QA=&5S+VUA:6XO
M;6%I;BYI;F,Z,30R"FUS9VED(")#:&%N9V4@4&%S<W=O<F0B"FUS9W-T<B`B
M6FUE;FF[(&AE<VQO(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,3(W
M"FUS9VED(")#:&%N9V4@<&%S<W=O<F0@;VXZ(@IM<V=S='(@(EIM96YINR!H
M97-L;R!N83HB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHV,@IM<V=I
M9"`B0VAA;F=E('EO=7(@<&%S<W=O<F0B"FUS9W-T<B`B6FUE;FF[(%9AN64@
M:&5S;&\B"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHV.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#:&%N9VEN9R!P87-S=V]R9"!O;B`E<R(*;7-G<W1R
M(")-96[M('-A(&AE<VQO(&YA("5S(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I
M;BYI;F,Z,3$T"FUS9VED(")#;VYF:7)M(&YE=R!P87-S=V]R9#HB"FUS9W-T
M<B`B4&]T=G+O=&4@;F]VZ2!H97-L;SHB"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.CDU(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C8S(&QI8B]$<FEV97(O:V]L
M86(N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E
M<B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R:6ALX7-INR!K(&QD87`@<V5R
M=F5R=2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S`@;&EB+T1R:79E<B]K
M;VQA8BYP:'`Z-#8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@
M<V5R=F5R(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!L9&%P
M('-E<G9E<G4B"@HC.B!L:6(O1')I=F5R+W-M8G!A<W-W9"YP:'`Z-3<*;7-G
M:60@(D-O=6QD(&YO="!O<&5N('!I<&4@=&\@<VUB<&%S<W=D+B(*;7-G<W1R
M(").97!O9&%R:6QO('-A('!R:7!O:FF[(&L@<')O9W)A;74@<VUB<&%S<W=D
M+B(*"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HW.0IM<V=I9"`B17)R
M;W(@<V5N9&EN9R!D871A('1O('-M8G!A<W-W9"XB"FUS9W-T<B`B3F%S=&%L
M82!C:'EB82!P<FD@<&]S:65L86[M(/ID86IO=B!P<F]G<F%M=2!S;6)P87-S
M=V0N(@H*(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z.3,*;7-G:60@(D9A
M:6QE9"!T;R!V97)I9GD@;VQD('!A<W-W;W)D+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A(&]V97)INR!S=&%RZ2!H97-L;RXB"@HC.B!M86EN+G!H<#HR,#<@
M;&EB+T1R:79E<B]C;VUP;W-I=&4N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,Z("5S(@IM
M<V=S='(@(D-H>6)A('!R:2!Z;65N92!H97-L82!N82`E<SH@)7,B"@HC.B!L
M:6(O1')I=F5R+G!H<#HU-B!L:6(O1')I=F5R+VQD87`N<&AP.C(V-"!L:6(O
M1')I=F5R+W9M86EL;6=R+G!H<#HT,@HC.B!L:6(O1')I=F5R+VMO;&%B+G!H
M<#HW."!L:6(O1')I=F5R+W!O<'!A<W-D+G!H<#HQ,30*;7-G:60@(DEN8V]R
M<F5C="!087-S=V]R9"(*;7-G<W1R(").97-P<N%V;F4@:&5S;&\B"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C(U-0IM<V=I9"`B36EN:6UU;2!P87-S=V]R
M9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")-:6YI;>%L;F$@
M<&QA=&YO<[L@:&5S;&$@9;ET92!N979Y<'*Y86QA(@H*(SH@=&5M<&QA=&5S
M+VUA:6XO;6%I;BYI;F,Z,3`R"FUS9VED(").97<@<&%S<W=O<F0Z(@IM<V=S
M='(@(DYO=ND@:&5S;&\Z(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3$R"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO('-U8V@@8F%C:V5N9"!<(B5S7"(@9F]U;F0N
M(@IM<V=S='(@(D)A8VME;F0@7"(E<UPB(&YE8F]L(&[A:F1E;OTN(@H*(SH@
M=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z.3`*;7-G:60@(D]L9"!P87-S=V]R
M9#HB"FUS9W-T<B`B4W1A<ND@:&5S;&\Z(@H*(SH@;&EB+T1R:79E<B]S;6)P
M87-S=V0N<&AP.C0W"FUS9VED(")087-S=V0@:7,@;F]T('!R;W!E<FQY(&-O
M;F9I9W5R960N(@IM<V=S='(@(DUO9'5L(%!A<W-W9"!N:64@:F4@<W!RX79N
M92!N86MO;F9I9W5R;W9A;OTN(@H*(SH@;6%I;BYP:'`Z,3DY"B,L('!H<"UF
M;W)M870*;7-G:60@(E!A<W-W;W)D(&-H86YG960@;VX@)7,N(@IM<V=S='(@
M(DAE<VQO(&YA("5S('IM96YE;NDN(@H*(SH@;&EB+T1R:79E<B]P<W!A<W-W
M9"YP:'`Z-S4*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!C86XG="!F:6YD('1H
M92!S=7!P;&EE9"!B:6XN(@IM<V=S='(@(DUO9'5L(&YA('IM96YU(&AE<VEE
M;"!N96UO:&]L(&[A:G.[(&1O9&%N_2!B:6[A<FYY('!R;V=R86TN(@H*(SH@
M;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z-S,*;7-G:60@(E!A<W-W;W)D(&UO
M9'5L92!I<R!M:7-S:6YG(')E<75I<F5D('!A<F%M971E<G,N(@IM<V=S='(@
M(DUO9'5L=2!087-S=V]R9"!C:/UB86KZ('!OOF%D;W9A;ND@<&%R86UE=')E
M+B(*"B,Z(&QI8B]$<FEV97(O861S:2YP:'`Z-3$*;7-G:60@(E!A<W-W;W)D
M(&UO9'5L92!I<R!M:7-S:6YG('1A<F=E="!P87)A;65T97(N(@IM<V=S='(@
M(DUO9'5L=2!087-S=V]R9"!C:/UB82!P87)A;65T97(@8VEEM6$N(@H*(SH@
M;6%I;BYP:'`Z,3<V(&QI8B]$<FEV97(O<V5R=G5F='`N<&AP.C<Q"FUS9VED
M(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960B
M"FUS9W-T<B`B36]D=6P@4&%S<W=O<F0@;FEE(&IE('-P<N%V;F4@;F%K;VYF
M:6=U<F]V86[](@H*(SH@;&EB+T1R:79E<B]S97)V=69T<"YP:'`Z.3@*;7-G
M:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E
M9"XB"FUS9W-T<B`B36]D=6P@4&%S<W=O<F0@;FEE(&IE('-P<N%V;F4@;F%K
M;VYF:6=U<F]V86[]+B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$Q
M"FUS9VED(")0;&5A<V4@<')O=FED92!A(&YE=R!P87-S=V]R9"(*;7-G<W1R
M(")0<F]S[6T@>F%D86IT92!N;W;I(&AE<VQO(@H*(SH@=&5M<&QA=&5S+VUA
M:6XO;6%I;BYI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!C=7)R
M96YT('!A<W-W;W)D(@IM<V=S='(@(E!R;W/M;2!Z861A:G1E(&%K='7A;&YE
M(&AE<VQO(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,34*;7-G:60@
M(E!L96%S92!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`B4')O
M<^UM('IA9&%J=&4@9;ET92!R87H@;F]VZ2!H97-L;R(*"B,Z(&QI8B]$<FEV
M97(O8V]M<&]S:71E+G!H<#HT,0IM<V=I9"`B4F5Q=6ER960@)V1R:79E<G,G
M(&ES(&UI<V-O;F9I9W5R960@:6X@0V]M<&]S:71E(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*(E8@:V]N9FEG=7+A8VEI($-O;7!O<VET92!N:64@:F4@
MN7!E8VEF:6MO=F%NX2!P;[YA9&]V86[A('!O;&^^:V$@)V1R:79E<G,G(@H*
M(SH@;&EB+T1R:79E<B]S<6PN<&AP.C0V"FUS9VED(")297%U:7)E9"`G<&AP
M='EP92<@;F]T('-P96-I9FEE9"!I;B!087-S=V0@4U%,(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(E8@:V]N9FEG=7+A8VEI(%!A<W-W9"!344P@;FEE
M(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA("=P:'!T>7!E
M)R(*"B,Z(&QI8B]$<FEV97(O=G!O<&UA:6PN<&AP.C0Y"FUS9VED(")297%U
M:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!344P@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5B!K;VYF:6=U<N%C:6D@4U%,(&YI92!J92"Y<&5C
M:69I:V]V86[A('!OOF%D;W9A;N$@<&]L;[YK82`G<&AP='EP92<B"@HC.B!T
M96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ-#,*;7-G:60@(E)E<V5T(@IM<V=S
M='(@(E9Y;6%Z8;L@9F]R;75LX7(B"@HC.B!L:6(O1')I=F5R+W-Q;"YP:'`Z
M-S4@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z.#,*;7-G:60@(E5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@<W!O:FF[(',@4U%,('-E<G9E<F]M+B(*"B,Z(&QI8B]$<FEV97(O<W%L
M+G!H<#HQ,C4@;&EB+T1R:79E<B]P;W!P87-S9"YP:'`Z,3`X"B,Z(&QI8B]$
M<FEV97(O=G!O<&UA:6PN<&AP.C$T,PIM<V=I9"`B57-E<B!N;W0@9F]U;F0B
M"FUS9W-T<B`B4&]UONUV871EM2!N96)O;"!NX6ID96[](@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HQ,S$@;&EB+T1R:79E<B]K;VQA8BYP:'`Z-S`@;&EB
M+T1R:79E<B]P:6YE+G!H<#HR,S$*;7-G:60@(E5S97(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")0;W6^[79A=&6U(&YE8F]L(&[A:F1E;OTN(@H*(SH@=&5M<&QA
M=&5S+VUA:6XO;6%I;BYI;F,Z-S<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M(")0;W6^[79A=&6U<VOI(&UE;F\Z(@H*(SH@;6%I;BYP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@
M=7-E<B`E<R(*;7-G<W1R(").96WTOF5T92!Z;65N:;L@:&5S;&\@<')E('!O
M=;[M=F%T9;5A("5S(@H*(SH@;6%I;BYP:'`Z-3,*;7-G:60@(EEO=2!M=7-T
M(&=I=F4@>6]U<B!C=7)R96YT('!A<W-W;W)D(@IM<V=S='(@(DUU<^UT92!Z
M861ANR!68;EE(&%K='7A;&YE(&AE<VQO(@H*(SH@;6%I;BYP:'`Z-C(*;7-G
M:60@(EEO=2!M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`B
M375S[71E('IA9&&[(%9AN64@;F]VZ2!H97-L;R(*"B,Z(&UA:6XN<&AP.C8V
M"FUS9VED(")9;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0B"FUS
M9W-T<B`B375S[71E(&6Y=&4@<F%Z('IA9&&[(%9AN64@;F]VZ2!H97-L;R(*
M"B,Z(&UA:6XN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@
M;F5W('!A<W-W;W)D(&ES('1O;R!L;VYG.R!P87-S=V]R9',@;6%Y(&YO="!B
M92!M;W)E('1H86X@)60@8VAA<F%C=&5R<R`B"B)L;VYG(2(*;7-G<W1R(")6
M8;EE(&YO=ND@:&5S;&\@:F4@<'+M;&FY(&1L:.D[(&AE<VSA(&YE<VWZ(&)Y
MNR!D;&BY:64@86MO("5D('IN86MO=B$B"@HC.B!M86EN+G!H<#HQ-C4*;7-G
M:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,A
M("!.;W0@8VAA;F=E9"$B"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO(&IE('!R
M[6QIN2!J961N;V1U8VCI(&YA('5HX61N=71I92$@3F5Z;65N96[I(2(*"B,Z
M(&UA:6XN<&AP.C$U-@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O
M('-I;7!L92!T;R!G=65S<RX@3F]T(&-H86YG960A(@IM<V=S='(@(E9AN64@
M;F]VZ2!H97-L;R!J92!P<NUL:;D@:F5D;F]D=6-HZ2!N82!U:.%D;G5T:64N
M($YE>FUE;F5NZ2$B"@HC.B!M86EN+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H
M87)A8W1E<G,@;&]N9R$B"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO(&UU<^T@
M;6&[(&%S<&_R("5D('IN86MO=B$B"@HC.B!M86EN+G!H<#HW-`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F97)E;G0@9G)O;2!Y;W5R
M(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO(&UU
M<^T@8GF[(&ENZ2!A:V\@86MT=>%L;F4@:&5S;&\B"@HC.B!M86EN+G!H<#HQ
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S
M="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA<F%C=&5R<RXB
M"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO(&UU<^T@;V)S86AO=F&[(&YA:FUE
M;F5J("5D('#M<VUE;BXB"@HC.B!M86EN+G!H<#HQ,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE
M87-T("5D(&%L<&AA;G5M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R(")68;EE
M(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V8;L@;F%J;65N96H@)60@86QF86YU
M;65R:6-K_6-H('IN86MO=BXB"@HC.B!M86EN+G!H<#HQ,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN
M(&%T(&QE87-T("5D(&1I9F9E<F5N="!T>7!E<R!O9B!C:&%R86-T97)S+B`B
M"B)4:&4@='EP97,@87)E.B!L;W=E<BP@=7!P97(L(&YU;65R:6,L(&%N9"!S
M>6UB;VQS+B(*;7-G<W1R("(B"B)68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A
M:&]V8;L@;F%J;65N96H@)60@='EP;W8@>FYA:V]V+B!4>7!Y('IN86MO=B!S
M^CH@(@HB;6%LZ2!P[7-M96[A+"!V9;5KZ2!P[7-M96[A+"#H[7-L:6-E(&$@
M<WEM8F]L>2XB"@HC.B!M86EN+G!H<#HQ,38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D
M(&QO=V5R8V%S92!C:&%R86-T97)S+B(*;7-G<W1R(")68;EE(&YO=ND@:&5S
M;&\@;75S[2!O8G-A:&]V8;L@;F%J;65N96H@)60@;6%L_6-H('#M<VUE;BXB
M"@HC.B!M86EN+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N
M97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&YU;65R:6,@
M8VAA<F%C=&5R<RXB"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO(&UU<^T@;V)S
M86AO=F&[(&YA:FUE;F5J("5D(.CM<VQI8RXB"@HC.B!M86EN+G!H<#HQ,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C
M;VYT86EN(&%T(&QE87-T("5D('5P<&5R8V%S92!C:&%R86-T97)S+B(*;7-G
M<W1R(")68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V8;L@;F%J;65N96H@
M)60@=F6U:_UC:"!P[7-M96XN(@H*(SH@;6%I;BYP:'`Z,30R"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!L
M97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T97)S+B(*;7-G<W1R(")6
M8;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V8;L@;65N96H@86MO("5D(&UE
M9'II97(N(@H*(SH@;6%I;BYP:'`Z,30T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA<F%C=&5R<RXB
M"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO(&YE<VUI92!O8G-A:&]V8;L@;65D
M>F5R>2XB"@HC.B!M86EN+G!H<#HW,`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F1S(&1I9&XG="!M871C:"(*;7-G<W1R(")68;EE(&YO=ND@:&5S;.$@;FEE
M('/Z(')O=FYA:^DB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ.0IM
M<V=I9"`B66]U<B!P87-S=V]R9',@9&\@;F]T(&UA=&-H(@IM<V=S='(@(E9A
MN64@:&5S;.$@;FEE('/Z(')O=FYA:^DB"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C<V"FUS9VED(")L9&%P7W-T87)T7W1L<R!F86EL960B"FUS9W-T<B`B
M;&1A<%]S=&%R=%]T;',@>FQY:&%L;R(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!A<W-W9"]P;R\N:'1A8V-E<W,`````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S-C(W-#,`,#(P,3,R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$1E;GD@9G)O
M;2!A;&P*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O<&\O
M;'1?3%0N<&\`````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$W-#0V`#$P-#$W,S8R-S0S`#`Q-S<S,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C($QI=&AU86YI86X@=')A;G-L
M871I;VYS(&9O<B!087-S=V0@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P
M,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U
M;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!087-S=V0@<&%C:V%G92X*
M(R!$87)I=7,@36%T=6QI875S:V%S(#QD87)I=7-`;&YK+FQT/BP@,C`P,RX*
M(R!6:6QI=7,@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#XL(#(P,#0N"B,*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%!A<W-W9"`S
M+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#0M,3$M,C0@,38Z
M-#0K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,2TS,"`R,#HT
M-RLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%9I;&EU<R!3=6US:V%S(#QV
M:6QI=7-`;&YK+FQT/EQN(@HB3&%N9W5A9V4M5&5A;3H@3&ET:'5A;FEA;B`\
M=FEL:75S0&QN:RYL=#Y<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,3-<;B(*
M(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]$
M<FEV97(O8V]M<&]S:71E+G!H<#HU.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@=6YA8FQE('1O(&QO860@9')I=F5R.B`E<R(*;7-G<W1R("(E<SH@;F5P
M879Y:V\@=?YK<F%U=&D@='9A<FMY:VSK<SH@)7,B"@HC.B!L:6(O1')I=F5R
M+V%D<VDN<&AP.C4T"B,L('!H<"UF;W)M870*;7-G:60@(D%$4TD@97)R;W(@
M)7,N(@IM<V=S='(@(D%$4TD@:VQA:61A("5S+B(*"B,Z(&QI8B]$<FEV97(O
M<'-P87-S=V0N<&AP.CDW(&QI8B]$<FEV97(O861S:2YP:'`Z-3<*;7-G:60@
M(D%C8V5S<R!$96YI960N(@IM<V=S='(@(DYE=?YT96YK82!T96ES:?@N(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z.#`*;7-G:60@(D)A8VME;F0@;F]T(&-O<G)E
M8W1L>2!I;7!L96UE;G1E9"XB"FUS9W-T<B`B4VQA<'1A_F]D_FEO(&ME:71I
M;6\@<&]S:7-T96WK(&YE=&5I<VEN9V%I(')E86QI>G5O=&$N(@H*(SH@;6%I
M;BYP:'`Z,C,Q('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$T-`IM<V=I9"`B
M0VAA;F=E(%!A<W-W;W)D(@IM<V=S='(@(E-L87!T8?YO9/YI;R!K96ET:6UA
M<R(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$R.0IM<V=I9"`B0VAA
M;F=E('!A<W-W;W)D(&]N.B(*;7-G<W1R(")3;&%P=&'^;V3^:6\@:V5I=&EM
M87,@<V5R=F5R>6IE.B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C8T
M"FUS9VED(")#:&%N9V4@>6]U<B!P87-S=V]R9"(*;7-G<W1R(")3;&%P=&'^
M;V3^:6\@:V5I=&EM87,B"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#:&%N9VEN9R!P87-S=V]R9"!O;B`E
M<R(*;7-G<W1R(")3;&%P=&'^;V3^:6\@:V5I=&EM87,@<V5R=F5R>6IE("5S
M(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,3$V"FUS9VED(")#;VYF
M:7)M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B4&%K87)T;VMI=&4@;F%U:N`@
M<VQA<'1A_F]DX3HB"@HC.B!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C@X(&QI
M8B]$<FEV97(O<VUB;&1A<"YP:'`Z,38V(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M.#8*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE<&%V>6MO(&%U=&5N
M=&EF:6MU;W1I<R#A($Q$05`@<V5R=F5RX2(*"B,Z(&QI8B]$<FEV97(O<VUB
M;&1A<"YP:'`Z-C4@;&EB+T1R:79E<B]L9&%P+G!H<#HV,@IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3F5P879Y
M:V\@<')I<VEJ=6YG=&D@<')I92!,1$%0('-E<G9E<FEO(@H*(SH@;&EB+T1R
M:79E<B]S;6)P87-S=V0N<&AP.C4R"FUS9VED(")#;W5L9"!N;W0@;W!E;B!P
M:7!E('1O('-M8G!A<W-W9"XB"FUS9W-T<B`B2VQA:61A(&IU;F=I86YT:7,@
M<')I92!S;6)P87-S=V0N(@H*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N<&AP
M.C<T"FUS9VED(")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+B(*
M;7-G<W1R(")+;&%I9&$@<VEU;NAI86YT(&1U;VUE;FES('-M8G!A<W-W9"!K
M;VUA;F1A:2XB"@HC.B!L:6(O1')I=F5R+W!S<&%S<W=D+G!H<#HX-0IM<V=I
M9"`B1F%I;&5D('1O('9E<FEF>2!O;&0@<&%S<W=O<F0N(@IM<V=S='(@(DYE
M<&%V>6MO('!A=&EK<FEN=&D@<V5N;R!S;&%P=&'^;V3^:6\N(@H*(SH@;6%I
M;BYP:'`Z,3DR(&QI8B]$<FEV97(O8V]M<&]S:71E+G!H<#HY,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL=7)E(&EN(&-H86YG:6YG('!A<W-W;W)D(&]N
M("5S.B`E<R(*;7-G<W1R(")+;&%I9&$@:V5IZ&EA;G0@<VQA<'1A_F]DX2!S
M97)V97)Y:F4@)7,Z("5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z-3$@;&EB+T1R
M:79E<B]S;6)L9&%P+G!H<#HQ-C<@;&EB+T1R:79E<B]P;W!P87-S9"YP:'`Z
M,3`V"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C(T(&QI8B]$<FEV97(O=FUA
M:6QM9W(N<&AP.C,U"FUS9VED("));F-O<G)E8W0@4&%S<W=O<F0B"FUS9W-T
M<B`B4VQA<'1A_F]D:7,@;F5T96ES:6YG87,B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C(P-PIM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO
M="!Y970@97AP:7)E9"(*;7-G<W1R(")-:6YI;6%L=7,@<VQA<'1A_F]D_FEO
M(&=A;&EO:FEM;R!L86EK87,@9&%R(&YE<&%S:6)A:6?K(@H*(SH@=&5M<&QA
M=&5S+VUA:6XO;6%I;BYI;F,Z,3`T"FUS9VED(").97<@<&%S<W=O<F0Z(@IM
M<V=S='(@(DYA=6IA<R!S;&%P=&'^;V1I<SHB"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<W5C:"!B86-K96YD("<E
M<R<@9F]U;F0N(@IM<V=S='(@(B<E<R<@<&]S:7-T96WK<R!NZW)A+B(*"B,Z
M('1E;7!L871E<R]M86EN+VUA:6XN:6YC.CDR"FUS9VED(")/;&0@<&%S<W=O
M<F0Z(@IM<V=S='(@(E-E;F%S('-L87!T8?YO9&ES.B(*"B,Z(&QI8B]$<FEV
M97(O<VUB<&%S<W=D+G!H<#HT,@IM<V=I9"`B4&%S<W=D(&ES(&YO="!P<F]P
M97)L>2!C;VYF:6=U<F5D+B(*;7-G<W1R(")3;&%P=&'^;V3^:6\@:V5I=&EM
M;R!M;V1U;&ES(&YE<W5K;VYF:6?[<G5O=&%S+B(*"B,Z(&UA:6XN<&AP.C$X
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")087-S=V]R9"!C:&%N9V5D(&]N("5S
M+B(*;7-G<W1R(")3;&%P=&'^;V1I<R!S97)V97)Y:F4@)7,@<&%K96ES=&%S
M+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S=V0N<&AP.C8W"FUS9VED(")087-S
M=V]R9"!M;V1U;&4@8V%N)W0@9FEN9"!T:&4@<W5P<&QI960@8FEN+B(*;7-G
M<W1R(")3;&%P=&'^;V3^:6\@:V5I=&EM;R!M;V1U;&ES(&YE9V%L:2!R87-T
M:2!R96EK:6%M^"!D=6]M96[X+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S=V0N
M<&AP.C8U"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!R97%U
M:7)E9"!P87)A;65T97)S+B(*;7-G<W1R(")3;&%P=&'^;V3^:6\@:V5I=&EM
M;R!M;V1U;&ES(&YE<F%N9&$@<F5I:V%L:6YG^"!P87)A;65T<O@N(@H*(SH@
M;&EB+T1R:79E<B]A9'-I+G!H<#HT-`IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE
M(&ES(&UI<W-I;F<@=&%R9V5T('!A<F%M971E<BXB"FUS9W-T<B`B4VQA<'1A
M_F]D_FEO(&ME:71I;6\@;6]D=6QI<R!N97)A;F1A(&YU<W1A='ET^"!P87)A
M;65T<O@N(@H*(SH@;6%I;BYP:'`Z,3<P(&QI8B]$<FEV97(O<V5R=G5F='`N
M<&AP.C8V"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY
M(&-O;F9I9W5R960B"FUS9W-T<B`B4VQA<'1A_F]D_FEO(&ME:71I;6\@;6]D
M=6QI<R!N97-U:V]N9FEG^W)U;W1A<R(*"B,Z(&QI8B]$<FEV97(O<V5R=G5F
M='`N<&AP.CDS"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E
M<FQY(&-O;F9I9W5R960N(@IM<V=S='(@(E-L87!T8?YO9/YI;R!K96ET:6UO
M(&UO9'5L:7,@;F5S=6MO;F9I9_MR=6]T87,N(@H*(SH@;&EB+T1R:79E<B]C
M;VUP;W-I=&4N<&AP.C,T"FUS9VED(")297%U:7)E9"`G9')I=F5R<R<@:7,@
M;6ES8V]N9FEG=7)E9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B4&%R86UE=')A<R`G9')I=F5R<R<@;F5T96ES:6YG86D@<W5K;VYF
M:6?[<G5O=&%S(&YU<W1A='EM=6]S92XB"@HC.B!L:6(O1')I=F5R+W-Q;"YP
M:'`Z-#`*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D
M(&EN(%!A<W-W9"!344P@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&%R86UE
M=')A<R`G<&AP='EP92<@;F5N=7)O9'ET87,@4&%S<W=D(%-13"!K;VYF:6?[
M<F%C:6IO:F4N(@H*(SH@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z-#(*;7-G
M:60@(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%-13"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")087)A;65T<F%S("=P:'!T>7!E)R!N
M96YU<F]D>71A<R!344P@:V]N9FEG^W)A8VEJ;VIE+B(*"B,Z('1E;7!L871E
M<R]M86EN+VUA:6XN:6YC.C$T-0IM<V=I9"`B4F5S970B"FUS9W-T<B`B2?!V
M86QY=&DB"@HC.B!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HW-B!L:6(O1')I
M=F5R+W-Q;"YP:'`Z-CD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@
M4U%,('-E<G9E<FEO+B(*"B,Z(&QI8B]$<FEV97(O<&]P<&%S<V0N<&AP.C$P
M,"!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HQ,S4*(SH@;&EB+T1R:79E<B]S
M<6PN<&AP.C$Q.`IM<V=I9"`B57-E<B!N;W0@9F]U;F0B"FUS9W-T<B`B5F%R
M=&]T;VIA<R!N97)A<W1A<R(*"B,Z(&QI8B]$<FEV97(O<VUB;&1A<"YP:'`Z
M,3(T(&QI8B]$<FEV97(O<&EN92YP:'`Z,C$Y(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,3(S"FUS9VED(")5<V5R(&YO="!F;W5N9"XB"FUS9W-T<B`B5F%R=&]T
M;VIA<R!N97)A<W1A<RXB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHW
M.0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E9A<G1O=&]J;R!V87)D87,Z
M(@H*(SH@;6%I;BYP:'`Z,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A
M;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<R(*;7-G<W1R(")*^W,@
M;F5G86QI=&4@<&%K96ES=&D@=F%R=&]T;VIO("5S('-L87!T8?YO9/YI;R(*
M"B,Z(&UA:6XN<&AP.C0W"FUS9VED(")9;W4@;75S="!G:79E('EO=7(@8W5R
M<F5N="!P87-S=V]R9"(*;7-G<W1R(")0<FEV86QO=&4@;G5R;V1Y=&D@9&%B
M87)T:6[A('-L87!T8?YO9.$B"@HC.B!M86EN+G!H<#HU-@IM<V=I9"`B66]U
M(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R("+!=F5S:VET
M92!N875JX"!S;&%P=&'^;V3A(@H*(SH@;6%I;BYP:'`Z-C`*;7-G:60@(EEO
M=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")086MA
M<G1O:VET92!N875JX"!S;&%P=&'^;V3A(@H*(SH@;6%I;BYP:'`Z.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O
M(&QO;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R
M86-T97)S("(*(FQO;F<A(@IM<V=S='(@(B(*(DK[<_@@;F%U:F%S:7,@<VQA
M<'1A_F]D:7,@<&5R(&EL9V%S.R!J86UE(&=A;&D@8OMT:2!N961A=6=I874@
M;F5I("5D("(*(G-I;6)O;&EA:2(*"B,Z(&UA:6XN<&AP.C$U.0IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G=65S<R$@($YO
M="!C:&%N9V5D(2(*;7-G<W1R(")3;&%P=&'^;V1I<R!P97(@<&%P<F%S=&%S
M("T@X79E<VMI=&4@<W5DZW1I;F=E<V[A(2(*"B,Z(&UA:6XN<&AP.C$U,`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G=65S
M<RX@3F]T(&-H86YG960A(@IM<V=S='(@(E-L87!T8?YO9&ES('!E<B!P87!R
M87-T87,@+2#A=F5S:VET92!S=63K=&EN9V5S;N$N(@H*(SH@;6%I;BYP:'`Z
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S
M="!B92!A="!L96%S="`E9"!C:&%R86-T97)S(&QO;F<A(@IM<V=S='(@(E-L
M87!T8?YO9&ES('1U<FD@8OMT:2!B96YT("5D('-I;6)O;&GX(&EL9VEO(2(*
M"B,Z(&UA:6XN<&AP.C8X"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T
M(&)E(&1I9F9E<F5N="!F<F]M('EO=7(@8W5R<F5N="!P87-S=V]R9"(*;7-G
M<W1R(").875J87-I<R!S;&%P=&'^;V1I<R!T=7)I('-K:7)T:7,@;G5O(&1A
M8F%R=&EN:6\B"@HC.B!M86EN+G!H<#HQ,C`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D
M(&%L<&AA8F5T:6,@8VAA<F%C=&5R<RXB"FUS9W-T<B`B4VQA<'1A_F]D>6IE
M('!R:79A;&\@8OMT:2!B96YT("5D(')A:63K<RXB"@HC.B!M86EN+G!H<#HQ
M,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S
M="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA;G5M97)I8R!C:&%R86-T97)S
M+B(*;7-G<W1R(")3;&%P=&'^;V1Y:F4@<')I=F%L;R!B^W1I(&)E;G0@)60@
M<VEM8F]L:6%I+B(*"B,Z(&UA:6XN<&AP.C$S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@9&EF9F5R96YT('1Y<&5S(&]F(&-H87)A8W1E<G,N("(*(E1H92!T
M>7!E<R!A<F4Z(&QO=V5R+"!U<'!E<BP@;G5M97)I8RP@86YD('-Y;6)O;',N
M(@IM<V=S='(@(B(*(DK[<_@@;F%U:N!JX2!S;&%P=&'^;V3A('1U<FD@<W5D
M87)Y=&D@8F5N="`E9"!S:VER=&EN9VD@<VEM8F]L:?@@=&EP86DN("(*(E1I
M<&%I.B!D:63^:6]S:6]S(')A:63K<RP@;6'^;W-I;W,@<F%I9.MS+"!S:V%I
MZ&EA:2!I<B!K:71I('-I;6)O;&EA:2XB"@HC.B!M86EN+G!H<#HQ,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT
M86EN(&%T(&QE87-T("5D(&QO=V5R8V%S92!C:&%R86-T97)S+B(*;7-G<W1R
M(")3;&%P=&'^;V1Y:F4@<')I=F%L;R!B^W1I(&)E;G0@)60@;6'^;W-I;W,@
M<F%I9.MS+B(*"B,Z(&UA:6XN<&AP.C$Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@
M;G5M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R(")3;&%P=&'^;V1Y=&4@<')I
M=F%L;R!B^W1I(&)E;G0@)60@<VMA:>AI86DN(@H*(SH@;6%I;BYP:'`Z,3`U
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@
M8V]N=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RXB"FUS
M9W-T<B`B4VQA<'1A_F]D>6IE('!R:79A;&\@8OMT:2!B96YT("5D(&1I9/YI
M;W-I;W,@<F%I9.MS+B(*"B,Z(&UA:6XN<&AP.C$S-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@;&5S<R!T
M:&%N("5D('=H:71E<W!A8V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`B3F%U:F%J
M86UE('-L87!T8?YO9'EJ92!G86QI(&+[=&D@;F5D875G:6%U(&YE:2`E9"!T
M87)P^"XB"@HC.B!M86EN+G!H<#HQ,S@*;7-G:60@(EEO=7(@;F5W('!A<W-W
M;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C:&%R86-T97)S+B(*
M;7-G<W1R(").875J86IA;64@<VQA<'1A_F]D>6IE(&YE9V%L:2!B^W1I('1A
M<G#X+B(*"B,Z(&UA:6XN<&AP.C8T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R
M9',@9&ED;B=T(&UA=&-H(@IM<V=S='(@(DYA=6II('-L87!T8?YO9/YI86D@
M;F5S=71A;7!A(@H*(SH@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HW,2!L:6(O
M1')I=F5R+VQD87`N<&AP.C8X"FUS9VED(")L9&%P7W-T87)T7W1L<R!F86EL
M960B"FUS9W-T<B`B;&1A<%]S=&%R=%]T;',@:VQA:61A(@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&%S<W=D+W!O+V1E7T1%+G!O````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#<P,P`Q,#0Q-S,V,C<T,P`P,3<V
M-#$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R!P87-S=V0@;6]D=6QE('1R86YS;&%T:6]N<PHC($-O<'ER:6=H="`H0RD@
M,C`P,BTR,#`T($AO<F1E(%!R;VIE8W0N"B,@2F5N<R!4:V]T>B`\:F5N<RYT
M:V]T>D!F,F@Y+F1E/BP@,C`P,BX*(R!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/BP@,C`P,BTR,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!P87-S=V1<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-2TQ,"TP.2`Q-CHU,2LP,C`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`U+3$P+3`Y(#$W.C`W*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SY<;B(*(DQA;F=U86=E+51E
M86TZ($=E<FUA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E
M<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#@M8FET7&XB"@HC.B!L:6(O1')I=F5R+V5X<&5C="YP:'`Z,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@9&]E<R!N;W0@97AI<W0@;W(@:7,@;F]T(&5X
M96-U=&%B;&4N(@IM<V=S='(@(B5S(&5X:7-T:65R="!N:6-H="!O9&5R(&ES
M="!N:6-H="!A=7-F_&AR8F%R+B(*"B,Z(&QI8B]$<FEV97(O8V]M<&]S:71E
M+G!H<#HV-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@=6YA8FQE('1O(&QO
M860@9')I=F5R.B`E<R(*;7-G<W1R("(E<SH@5')E:6)E<B!K;VYN=&4@;FEC
M:'0@9V5L861E;B!W97)D96XZ("5S(@H*(SH@;&EB+T1R:79E<B]A9'-I+G!H
M<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!1%-)(&5R<F]R("5S+B(*;7-G
M<W1R(")!1%-)($9E:&QE<B`E<RXB"@HC.B!L:6(O1')I=F5R+W!S<&%S<W=D
M+G!H<#HQ,#4@;&EB+T1R:79E<B]A9'-I+G!H<#HV-`IM<V=I9"`B06-C97-S
M($1E;FEE9"XB"FUS9W-T<B`B6G5G<FEF9B!V97)W96EG97)T+B(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C@U"FUS9VED(")"86-K96YD(&YO="!C;W)R96-T;'D@
M:6UP;&5M96YT960N(@IM<V=S='(@(D1A<R!"86-K96YD('=U<F1E(&YI8VAT
M(&MO<G)E:W0@:6UP;&5M96YT:65R="XB"@HC.B!M86EN+G!H<#HR-34@=&5M
M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,30R"FUS9VED(")#:&%N9V4@4&%S<W=O
M<F0B"FUS9W-T<B`B4&%S<W=O<G0@Y&YD97)N(@H*(SH@=&5M<&QA=&5S+VUA
M:6XO;6%I;BYI;F,Z,3(W"FUS9VED(")#:&%N9V4@<&%S<W=O<F0@;VXZ(@IM
M<V=S='(@(E!A<W-W;W)T(.1N9&5R;B!A=68Z(@H*(SH@=&5M<&QA=&5S+VUA
M:6XO;6%I;BYI;F,Z-C(*;7-G:60@(D-H86YG92!Y;W5R('!A<W-W;W)D(@IM
M<V=S='(@(L1N9&5R;B!3:64@26AR(%!A<W-W;W)T(@H*(SH@=&5M<&QA=&5S
M+VUA:6XO;6%I;BYI;F,Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VAA;F=I
M;F<@<&%S<W=O<F0@;VX@)7,B"FUS9W-T<B`B4&%S<W=O<G0@875F("5S(.1N
M9&5R;B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$Q-`IM<V=I9"`B
M0V]N9FER;2!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(DYE=65S(%!A<W-W;W)T
M(&)E<W3D=&EG96XZ(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HY-2!L:6(O
M1')I=F5R+VQD87`N<&AP.C(V,R!L:6(O1')I=F5R+VMO;&%B+G!H<#HU-`IM
M<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B
M5F5R8FEN9'5N9R!Z=6T@3$1!4"U397)V97(@9F5H;&=E<V-H;&%G96XB"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C<P(&QI8B]$<FEV97(O:V]L86(N<&AP
M.C0V"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*
M;7-G<W1R(")697)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!F96AL9V5S8VAL
M86=E;B(*"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HU-PIM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N(@IM<V=S='(@(E9E
M<F)I;F1U;F<@>G4@<VUB<&%S<W=D(&MO;FYT92!N:6-H="!H97)G97-T96QL
M="!W97)D96XN(@H*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N<&AP.C<Y"FUS
M9VED(")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+B(*;7-G<W1R
M(")"96EM(%9E<G-E;F1E;B!V;VX@1&%T96X@>G4@<VUB<&%S<W=D(&ES="!E
M:6X@1F5H;&5R(&%U9F=E=')E=&5N+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S
M=V0N<&AP.CDS"FUS9VED(")&86EL960@=&\@=F5R:69Y(&]L9"!P87-S=V]R
M9"XB"FUS9W-T<B`B1&%S(&%L=&4@4&%S<W=O<G0@:V]N;G1E(&YI8VAT(&)E
M<W3D=&EG="!W97)D96XN(@H*(SH@;6%I;BYP:'`Z,C$Q(&QI8B]$<FEV97(O
M8V]M<&]S:71E+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL=7)E
M(&EN(&-H86YG:6YG('!A<W-W;W)D(&]N("5S.B`E<R(*;7-G<W1R(")&96AL
M97(@8F5I;2#$;F1E<FX@9&5S(%!A<W-W;W)T<R!A=68@)7,Z("5S(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z-38@;&EB+T1R:79E<B]L9&%P+G!H<#HR-C0@;&EB
M+T1R:79E<B]V;6%I;&UG<BYP:'`Z-#(*(SH@;&EB+T1R:79E<B]K;VQA8BYP
M:'`Z-S@@;&EB+T1R:79E<B]P;W!P87-S9"YP:'`Z,3$T"FUS9VED("));F-O
M<G)E8W0@4&%S<W=O<F0B"FUS9W-T<B`B1F%L<V-H97,@4&%S<W=O<G0B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C(U-0IM<V=I9"`B36EN:6UU;2!P87-S
M=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")$87,@;6EN
M:6UA;&4@4&%S<W=O<G1A;'1E<B!I<W0@;F]C:"!N:6-H="!A8F=E;&%U9F5N
M(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,3`R"FUS9VED(").97<@
M<&%S<W=O<F0Z(@IM<V=S='(@(DYE=65S(%!A<W-W;W)T.B(*"B,Z(&QI8B]$
M<FEV97(N<&AP.C$Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!S=6-H(&)A
M8VME;F0@7"(E<UPB(&9O=6YD+B(*;7-G<W1R(")%:6X@0F%C:V5N9"!N86UE
M;G,@7"(E<UPB(&MO;FYT92!N:6-H="!G969U;F1E;B!W97)D96XN(@H*(SH@
M=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z.3`*;7-G:60@(D]L9"!P87-S=V]R
M9#HB"FUS9W-T<B`B06QT97,@4&%S<W=O<G0Z(@H*(SH@;&EB+T1R:79E<B]S
M;6)P87-S=V0N<&AP.C0W"FUS9VED(")087-S=V0@:7,@;F]T('!R;W!E<FQY
M(&-O;F9I9W5R960N(@IM<V=S='(@(E!A<W-W9"!I<W0@;FEC:'0@=F]L;'-T
MY&YD:6<@:V]N9FEG=7)I97)T+B(*"B,Z(&UA:6XN<&AP.C(P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")087-S=V]R9"!C:&%N9V5D(&]N("5S+B(*;7-G<W1R
M(")087-S=V]R="!A=68@)7,@9V7D;F1E<G0N(@H*(SH@;&EB+T1R:79E<B]P
M<W!A<W-W9"YP:'`Z-S4*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!C86XG="!F
M:6YD('1H92!S=7!P;&EE9"!B:6XN(@IM<V=S='(@(E!A<W-W9"!K86YN(&1A
M<R!A;F=E9V5B96YE(%!R;V=R86UM(&YI8VAT(&9I;F1E;BXB"@HC.B!L:6(O
M1')I=F5R+W!S<&%S<W=D+G!H<#HW,PIM<V=I9"`B4&%S<W=O<F0@;6]D=6QE
M(&ES(&UI<W-I;F<@<F5Q=6ER960@<&%R86UE=&5R<RXB"FUS9W-T<B`B4&%S
M<W=D(&9E:&QE;B!B96[V=&EG=&4@4&%R86UE=&5R+B(*"B,Z(&QI8B]$<FEV
M97(O861S:2YP:'`Z-3$*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!M:7-S
M:6YG('1A<F=E="!P87)A;65T97(N(@IM<V=S='(@(E!A<W-W9"!F96AL="!D
M97(@7")::65L7"(M4&%R86UE=&5R+B(*"B,Z(&UA:6XN<&AP.C$W."!L:6(O
M1')I=F5R+W-E<G9U9G1P+G!H<#HW,0IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE
M(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D(@IM<V=S='(@(E!A<W-W9"!I
M<W0@;FEC:'0@=F]L;'-TY&YD:6<@:V]N9FEG=7)I97)T(@H*(SH@;&EB+T1R
M:79E<B]S97)V=69T<"YP:'`Z.3@*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I
M<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"XB"FUS9W-T<B`B4&%S<W=D(&ES
M="!N:6-H="!V;VQL<W3D;F1I9R!K;VYF:6=U<FEE<G0N(@H*(SH@=&5M<&QA
M=&5S+VUA:6XO;6%I;BYI;F,Z,3$*;7-G:60@(E!L96%S92!P<F]V:61E(&$@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(D)I='1E(&=E8F5N(%-I92!E:6X@;F5U
M97,@4&%S<W=O<G0@86XB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHW
M"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B
M"FUS9W-T<B`B0FET=&4@9V5B96X@4VEE($EH<B!A:W1U96QL97,@4&%S<W=O
M<G0@86XB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ-0IM<V=I9"`B
M4&QE87-E('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")":71T
M92!B97-TY'1I9V5N(%-I92!):'(@;F5U97,@4&%S<W=O<G0B"@HC.B!L:6(O
M1')I=F5R+V-O;7!O<VET92YP:'`Z-#$*;7-G:60@(E)E<75I<F5D("=D<FEV
M97)S)R!I<R!M:7-C;VYF:6=U<F5D(&EN($-O;7!O<VET92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(G9')I=F5R<R<@:7-T(&EN(&1E<B!#;VUP;W-I=&4M
M2V]N9FEG=7)A=&EO;B!F96AL97)H869T(&MO;F9I9W5R:65R="XB"@HC.B!L
M:6(O1')I=F5R+W-Q;"YP:'`Z-#8*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E
M)R!N;W0@<W!E8VEF:65D(&EN(%!A<W-W9"!344P@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B)W!H<'1Y<&4G('=U<F1E(&EN(&1E<B!344PM2V]N9FEG=7)A
M=&EO;B!N:6-H="!A;F=E9V5B96XN(@H*(SH@;&EB+T1R:79E<B]V<&]P;6%I
M;"YP:'`Z-#D*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF
M:65D(&EN(%-13"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G<&AP='EP92<@
M=W5R9&4@:6X@9&5R(%-13"U+;VYF:6=U<F%T:6]N(&YI8VAT(&%N9V5G96)E
M;BXB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ-#,*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(EIU<OQC:W-E='IE;B(*"B,Z(&QI8B]$<FEV97(O<W%L
M+G!H<#HW-2!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HX,PIM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN
M9'5N9R!Z=6T@4U%,(%-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E
M<F1E;BXB"@HC.B!L:6(O1')I=F5R+W-Q;"YP:'`Z,3(U(&QI8B]$<FEV97(O
M<&]P<&%S<V0N<&AP.C$P.`HC.B!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HQ
M-#,*;7-G:60@(E5S97(@;F]T(&9O=6YD(@IM<V=S='(@(D)E;G5T>F5R(&YI
M8VAT(&=E9G5N9&5N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,S$@;&EB
M+T1R:79E<B]K;VQA8BYP:'`Z-S`@;&EB+T1R:79E<B]P:6YE+G!H<#HR,S$*
M;7-G:60@(E5S97(@;F]T(&9O=6YD+B(*;7-G<W1R(")"96YU='IE<B!N:6-H
M="!G969U;F1E;BXB"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHW-PIM
M<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D)E;G5T>F5R;F%M93HB"@HC.B!M
M86EN+G!H<#HT-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N)W0@8VAA
M;F=E('!A<W-W;W)D(&9O<B!U<V5R("5S(@IM<V=S='(@(E-I92!K]FYN96X@
M9&%S(%!A<W-W;W)T('9O;B!"96YU='IE<B`E<R!N:6-H="#D;F1E<FXB"@HC
M.B!M86EN+G!H<#HU-0IM<V=I9"`B66]U(&UU<W0@9VEV92!Y;W5R(&-U<G)E
M;G0@<&%S<W=O<F0B"FUS9W-T<B`B4VEE(&W\<W-E;B!):'(@86QT97,@4&%S
M<W=O<G0@86YG96)E;B(*"B,Z(&UA:6XN<&AP.C8T"FUS9VED(")9;W4@;75S
M="!G:79E('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(E-I92!M_'-S96X@
M26AR(&YE=65S(%!A<W-W;W)T(&%N9V5B96XB"@HC.B!M86EN+G!H<#HV.`IM
M<V=I9"`B66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S
M='(@(E-I92!M_'-S96X@26AR(&YE=65S(%!A<W-W;W)T(&)E<W3D=&EG96XB
M"@HC.B!M86EN+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M(&YE=R!P87-S=V]R9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@
M8F4@;6]R92!T:&%N("5D(&-H87)A8W1E<G,@(@HB;&]N9R$B"FUS9W-T<B`B
M(@HB26AR(&YE=65S(%!A<W-W;W)T(&ES="!Z=2!L86YG+"!D87,@4&%S<W=O
M<G0@9&%R9B!N:6-H="!LY&YG97(@86QS("5D("(*(EIE:6-H96X@<V5I;B$B
M"@HC.B!M86EN+G!H<#HQ-C<*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES
M('1O;R!S:6UP;&4@=&\@9W5E<W,A("!.;W0@8VAA;F=E9"$B"FUS9W-T<B`B
M26AR(&YE=65S(%!A<W-W;W)T(&ES="!Z=2!L96EC:'0@>G4@97)R871E;B$@
M3FEC:'0@9V7D;F1E<G0A(@H*(SH@;6%I;BYP:'`Z,34X"FUS9VED(")9;W5R
M(&YE=R!P87-S=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S+B!.;W0@8VAA
M;F=E9"$B"FUS9W-T<B`B26AR(&YE=65S(%!A<W-W;W)T(&ES="!Z=2!L96EC
M:'0@>G4@97)R871E;BX@3FEC:'0@9V7D;F1E<G0A(@H*(SH@;6%I;BYP:'`Z
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S
M="!B92!A="!L96%S="`E9"!C:&%R86-T97)S(&QO;F<A(@IM<V=S='(@(DEH
M<B!N975E<R!087-S=V]R="!M=7-S(&UI;F1E<W1E;G,@)60@6F5I8VAE;B!L
M86YG('-E:6XA(@H*(SH@;6%I;BYP:'`Z-S8*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8F4@9&EF9F5R96YT(&9R;VT@>6]U<B!C=7)R96YT('!A
M<W-W;W)D(@IM<V=S='(@(DEH<B!N975E<R!087-S=V]R="!M=7-S('-I8V@@
M=F]N($EH<F5M(&%L=&5N('5N=&5R<V-H96ED96XB"@HC.B!M86EN+G!H<#HQ
M,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S
M="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA<F%C=&5R<RXB
M"FUS9W-T<B`B26AR(&YE=65S(%!A<W-W;W)T(&UU<W,@;6EN9&5S=&5N<R`E
M9"!"=6-H<W1A8F5N(&5N=&AA;'1E;BXB"@HC.B!M86EN+G!H<#HQ,S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT
M86EN(&%T(&QE87-T("5D(&%L<&AA;G5M97)I8R!C:&%R86-T97)S+B(*;7-G
M<W1R("(B"B)):'(@;F5U97,@4&%S<W=O<G0@;75S<R!M:6YD97-T96YS("5D
M($)U8VAS=&%B96X@;V1E<B!:86AL96X@96YT:&%L=&5N+B(*"B,Z(&UA:6XN
M<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@9&EF9F5R96YT('1Y<&5S
M(&]F(&-H87)A8W1E<G,N("(*(E1H92!T>7!E<R!A<F4Z(&QO=V5R+"!U<'!E
M<BP@;G5M97)I8RP@86YD('-Y;6)O;',N(@IM<V=S='(@(B(*(DEH<B!N975E
M<R!087-S=V]R="!M=7-S(&UI;F1E<W1E;G,@)60@=F5R<V-H:65D96YE;B!:
M96EC:&5N='EP96X@96YH86QT96XN("(*(E1Y<&5N('-I;F0Z($ML96EN8G5C
M:'-T86)E;BP@1W)OWV)U8VAS=&%B96XL(%IA:&QE;B!U;F0@4V]N9&5R>F5I
M8VAE;BXB"@HC.B!M86EN+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&QO
M=V5R8V%S92!C:&%R86-T97)S+B(*;7-G<W1R(")):'(@;F5U97,@4&%S<W=O
M<G0@;75S<R!M:6YD97-T96YS("5D($ML96EN8G5C:'-T86)E;B!E;G1H86QT
M96XN(@H*(SH@;6%I;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!N=6UE
M<FEC(&-H87)A8W1E<G,N(@IM<V=S='(@(DEH<B!N975E<R!087-S=V]R="!M
M=7-S(&UI;F1E<W1E;G,@)60@6F%H;&5N(&5N=&AA;'1E;BXB"@HC.B!M86EN
M+G!H<#HQ,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D('5P<&5R8V%S92!C:&%R86-T
M97)S+B(*;7-G<W1R(")):'(@;F5U97,@4&%S<W=O<G0@;75S<R!M:6YD97-T
M96YS("5D($=R;]]B=6-H<W1A8F5N(&5N=&AA;'1E;BXB"@HC.B!M86EN+G!H
M<#HQ-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M;75S="!C;VYT86EN(&QE<W,@=&AA;B`E9"!W:&ET97-P86-E(&-H87)A8W1E
M<G,N(@IM<V=S='(@(DEH<B!N975E<R!087-S=V]R="!D87)F(&YI8VAT(&UE
M:'(@86QS("5D($QE97)Z96EC:&5N(&5N=&AA;'1E;BXB"@HC.B!M86EN+G!H
M<#HQ-#8*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A
M:6X@=VAI=&5S<&%C92!C:&%R86-T97)S+B(*;7-G<W1R(")):'(@;F5U97,@
M4&%S<W=O<G0@9&%R9B!K96EN92!,965R>F5I8VAE;B!E;G1H86QT96XN(@H*
M(SH@;6%I;BYP:'`Z-S(*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D<R!D:61N
M)W0@;6%T8V@B"FUS9W-T<B`B26AR92!N975E;B!087-S=_9R=&5R('-T:6UM
M96X@;FEC:'0@_&)E<F5I;B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC
M.C$Y"FUS9VED(")9;W5R('!A<W-W;W)D<R!D;R!N;W0@;6%T8V@B"FUS9W-T
M<B`B26AR92!087-S=_9R=&5R('-T:6UM96X@;FEC:'0@_&)E<F5I;B(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S8*;7-G:60@(FQD87!?<W1A<G1?=&QS
M(&9A:6QE9"(*;7-G<W1R(")L9&%P7W-T87)T7W1L<R!F96AL9V5S8VAL86=E
M;B(*````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&%S<W=D+W!O+VYL7TY,+G!O````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-C(R-P`Q,#0Q-S,V,C<T,P`P,3<W,3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R!087-S=V0@
M;6]D=6QE('1R86YS;&%T:6]N<PHC($-O<'ER:6=H="`H0RD@,C`P,B!&<F5E
M(%-O9G1W87)E($9O=6YD871I;VXL($EN8RX*(R!%<FEC(%)O<W1E='1E<B`\
M<F]S=&5T=&5R0&UA:6PN=71E>&%S+F5D=3XL(#(P,#(N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ('!A<W-W9%QN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#(M,#(M,3D@,3`Z,C,M,#8P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-2TP-BTP,2`Q,CHP,"LP,C`P7&XB"B),87-T
M+51R86YS;&%T;W(Z(%)E<V%N(%-A+4%R9&YU86T@/&AO<F1E0'-A+6%R9&YU
M86TN;FQ<;B(*(DQA;F=U86=E+51E86TZ(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*;7-G:60@(D-H86YG92!Y;W5R('!A
M<W-W;W)D(@IM<V=S='(@(E=I:GII9R!W86-H='=O;W)D(@H*;7-G:60@(D-O
M;F9I<FT@;F5W('!A<W-W;W)D.B(*;7-G<W1R(").;V=M86%L<R!N:65U=R!W
M86-H='=O;W)D.B(*"FUS9VED(")%<G)O<B(*;7-G<W1R(")&;W5T(@H*;7-G
M:60@(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@.B`B"FUS9W-T<B`B
M1F]U="!B:6H@=F5R86YD97)E;B!V86X@=V%C:'1W;V]R9"`Z("(*"FUS9VED
M(")(96QP(@IM<V=S='(@(DAE;'`B"@IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T
M<B`B5&%A;"(*"FUS9VED("),;V=O=70B"FUS9W-T<B`B069M96QD96XB"@IM
M<V=I9"`B365S<V%G92(*;7-G<W1R(")"97)I8VAT(@H*;7-G:60@(DYE=R!P
M87-S=V]R9#HB"FUS9W-T<B`B3FEE=7<@=V%C:'1W;V]R9#HB"@IM<V=I9"`B
M3VQD('!A<W-W;W)D.B(*;7-G<W1R(")/=60@=V%C:'1W;V]R9#HB"@IM<V=I
M9"`B4&%S<W=O<F0@8VAA;F=E9"$B"FUS9W-T<B`B5V%C:'1W;V]R9"!V97)A
M;F1E<F0A(@H*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R
M;'D@8V]N9FEG=7)E9"(*;7-G<W1R(")087-S=V]R9"!I<R!N:65T(&IU:7-T
M(&=E8V]N9FEG=7)E97)D(@H*;7-G:60@(E!R;V)L96T_(@IM<V=S='(@(E!R
M;V)L965M/R(*"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z(@IM<V=S='(@(E-E;&5C=&5E<B!U=R!T86%L('9O;W)K975R.B(*"FUS
M9VED(")3970@=&AE(&QA;F=U86=E('1H870@;65N=2!I=&5M<RP@97AP;&%N
M871I;VYS+"!A;F0@:&5L<"!A<F4@:6XN(@IM<V=S='(@(E-T96P@9&4@=&%A
M;"!I;B!V;V]R(&UE;G4@:71E;7,L('9E<FML87)I;F=E;B!E;B!H96QP(&EN
M("(*"FUS9VED(")3;VUE(&]F(%!A<W-W;W)D(&UO9'5L92=S(&-O;F9I9W5R
M871I;VX@9FEL97,@87)E(&UI<W-I;F<Z(@IM<V=S='(@(D5E;B!A86YT86P@
M8V]N9FEG=7)A=&EE(&)E<W1A;F1E;B!V86X@9&4@4&%S<W=O<F0@;6]D=6QE
M(&]N=&)R96ME;CHB"@IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")'96QU:W0B
M"@IM<V=I9"`B(@HB5&AI<R!F:6QE(&-O;G1R;VQS('1H92!D969A=6QT('!R
M969E<F5N8V5S(&9O<B!087-S=V]R9"!M;V1U;&4L(&%N9"!A;'-O("(*(F-O
M;G1R;VQS('=H:6-H('!R969E<F5N8V5S('5S97)S(&-A;B!A;'1E<BXB"FUS
M9W-T<B`B(@HB1&ET(&)E<W1A;F0@<F5G96QT(&1E('-T86YD86%R9"!I;G-T
M96QL:6YG96X@=F]O<B!D92!087-S=V]R9"!M;V1U;&4L(&5N("(*(F]O:W=E
M;&ME(&EN<W1E;&QI;F=E;B!D92!G96)R=6EK97(@:V%N('9E<F%N9&5R96XN
M(@H*;7-G:60@(B(*(E1H:7,@9FEL92!C;VYT<F]L<R!T:&4@<W1Y;&5S:&5E
M="!T:&%T(&ES('5S960@=&\@<V5T(&-O;&]R<R!A;F0@9F]N=',@:6X@(@HB
M861D:71I;VX@=&\@;W(@;W9E<G)I9&EN9R!(;W)D92!D969A=6QT<RXB"FUS
M9W-T<B`B(@HB1&ET(&)E<W1A;F0@8F5H965R="!D92!S='EL97-H965T(&1I
M92!G96)R=6EK="!W;W)D="!O;2!K;&5U<F5N(&5N("(*(FQE='1E<G1Y<&5N
M('1O92!T92!V;V5G96X@;V8@9&4@<W1A;F1A87)D(&EN<W1E;&QI;F<@=F%N
M($AO<F1E(&1E("(*(F]V97)S8VAR:6IV96XB"@IM<V=I9"`B(@HB5&AI<R!I
M<R!T:&4@;6%I;B!087-S=V]R9"!M;V1U;&4@8V]N9FEG=7)A=&EO;B!F:6QE
M+B!)="!C;VYT86EN<R!P871H<R!A;F0@(@HB;W!T:6]N<R!F;W(@86QL(%!A
M<W-W;W)D(&UO9'5L92!S8W)I<'1S+B(*;7-G<W1R("(B"B)$:70@:7,@:&5T
M(&)E;&%N9W)I:FMS=&4@8V]N9FEG=7)A=&EE(&)E<W1A;F0@=F%N(&1E(%!A
M<W-W;W)D(&UO9'5L92X@2&5T("(*(F)E=F%T('!A9&5N(&5N(&]P=&EE<R!V
M;V]R(&%L;&4@4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N(@H*;7-G:60@(E5S
M97)N86UE.B(*;7-G<W1R(")'96)U:6ME<G-N86%M.B(*"FUS9VED(")787)N
M:6YG(@IM<V=S='(@(E=A87)S8VAU=VEN9R(*"FUS9VED(")9;W4@8V%N(&YO
M="!C:&%N9V4@<&%S<W=D(&9O<B!O=&AE<B!U<V5R(@IM<V=S='(@(E4@:V%N
M(&YI970@965N('=A8VAT=V]O<F0@=F5R86YD97)E;B!V86X@965N(&%N9&5R
M92!G96)R=6EK97(B"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H
M86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<R(*;7-G<W1R(")5(&MA;B!N:65T
M(&AE="!W86-H='=O;W)D('=I:GII9V5N('9O;W(@9V5B<G5I:V5R("5S(@H*
M;7-G:60@(EEO=2!M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T
M<B`B52!M;V5T('5W(&YI975W92!W86-H='=O;W)D(&=E=F5N(@H*;7-G:60@
M(EEO=2!M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O<F0B"FUS9W-T<B`B52!M
M;V5T('5W(&]U9&4@=V%C:'1W;V]R9"!G979E;B(*"FUS9VED(")9;W4@;75S
M="!G:79E('EO=7(@=7-E<FED(@IM<V=S='(@(E4@;6]E="!U=R!N:65U=V4@
M9V5B<G5I:V5R<VYA86T@9V5V96XB"@IM<V=I9"`B66]U(&UU<W0@=F5R:69Y
M('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(E4@;6]E="!U=R!N:65U=V4@
M=V%C:'1W;V]R9"!V97)I9FGK<F5N(@H*;7-G:60@(EEO=7(@26YF;W)M871I
M;VXB"FUS9W-T<B`B57<@26YF;W)M871I92(*"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9',@9&ED;B=T(&UA=&-H(@IM<V=S='(@(E5W(&YI975W92!W86-H
M='=O;W)D(&MW86T@;FEE="!O=F5R965N(@H*;7-G:60@(E!A<W-W;W)D(@IM
M<V=S='(@(E=A8VAT=V]O<F0B"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!A<W-W9"]P;R]B9U]"1RYP;P``````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,3,P,S0`,3`T,3<S-C(W-#,`,#$W-C0P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@0G5L9V%R
M:6%N('1R86YS;&%T:6]N<R!F;W(@4&%S<W=D('!A8VMA9V4N"B,@0V]P>7)I
M9VAT("A#*2`R,#`R($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES
M=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@4&%S<W=D
M('!A8VMA9V4N"B,@36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N
M=7,^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U6
M97)S:6]N.B!087-S=V0@,BXP+C$M8W9S7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P,BTP.2TQ-"`P,#HS."TP-#`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`R+3$Q+3$Y(#(P.C0T+3`U,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^7&XB"B),86YG
M=6%G92U496%M.B!"1R!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U#4#$R-3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:71<;B(*"FUS9VED(")"86-K96YD(&YO="!C;W)R96-T;'D@:6UP;&5M96YT
M960N(@IM<V=S='(@(L+QY2#N^>4@[>4@Y2#D[N'PY2#PX.?PX.'N\N7M[BXN
M+B(*"FUS9VED(")#:&%N9V4@4&%S<W=O<F0B"FUS9W-T<B`BT>S_[>`@[>`@
M[^#P[NO@\N`B"@IM<V=I9"`B0VAA;F=E('EO=7(@<&%S<W=O<F0B"FUS9W-T
M<B`BT>S_[>`@[>`@[^#P[NO@\N`@PN@B"@HC+"!C+69O<FUA=`IM<V=I9"`B
M0VAA;F=I;F<@4&%S<W=O<F0@;VX@)7,B"FUS9W-T<B`BS_#NX>OE["#O\.@@
M\>S_[>`@[>`@[^#P[NO@\N`@[>`@)7,B"@IM<V=I9"`B0V]N9FER;2!.97<@
M<&%S<W=O<F0Z(@IM<V=S='(@(L_N\N+Z\.3E\N4@[>[BX/+@(._@\.[KX#HB
M"@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T
M<B`BS>7B^N?L[N;M[O'R(.?@(.+P^N?JX"#Q($Q$05`@\?KPXOKPX"(*"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R
M("+-Y>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@(/$@3$1!4"#Q^O#B^O`B"@IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N(@IM<V=S='(@
M(LWEXOKG[.[F[>[Q\B#DX"#QY2#N\N+N\.@@ZN#MX.L@Y.X@<VUB<&%S<W=D
M+B(*"FUS9VED(")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+B(*
M;7-G<W1R("+#\.7XZN`@[_#H(.CG[_#@^>#MY2#MX"#DX.WMZ"#D[B!S;6)P
M87-S=V0N(@H*;7-G:60@(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0Z
M("(*;7-G<W1R("+/\.[AZ^7L(._PZ"#Q[/_MX"#MX"#OX/#NZ^#RX"`Z(@H*
M;7-G:60@(DAE;'`B"FUS9W-T<B`BS^[L[ODB"@IM<V=I9"`B26YC;W)E8W0@
M4&%S<W=O<F0B"FUS9W-T<B`BS>7J[O#EZO+MX"#OX/#NZ^`B"@IM<V=I9"`B
M3&]G;W5T(@IM<V=S='(@(LCG]>[D(@H*;7-G:60@(DUD865M;VX@<&%T:"!N
M;W0@9F]U;F0B"FUS9W-T<B`BS_KR__(@Y.X@361A96UO;B#MY2#E(.W@[.7P
MY>TB"@IM<V=I9"`B361A96UO;B!U<V5R;&ES="!F:6QE(&YO="!A8V-E<W-A
M8FQE(&]R(&YO="!F;W5N9"XB"FUS9W-T<B`B361A96UO;B#TX.GK(/$@[^[R
M\.7AZ/+EZ^@@[>4@Y2#D[O'R^N_E[2#HZ^@@[>4@X>7XY2#MX.SE\.7M+B(*
M"FUS9VED(").97<@<&%S<W=O<F0Z(@IM<V=S='(@(LWNXN`@[^#P[NO@.B(*
M"FUS9VED(").;W0@86)L92!T;R!C<F5A=&4@;&]C:R!F:6QE(@IM<V=S='(@
M(LWEXOKG[.[F[>[Q\B#DX"#QY2#Q^N?DX.3E(.?@ZNO^]^+@^2`H;&]C:RD@
M].#IZR(*"FUS9VED(").;W0@86)L92!T;R!C<F5A=&4@<V5M87!H;W)E(&9I
M;&4B"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(/'ZY^3@Y.4@\>7LX/3N
M\.7M(/3@Z>LB"@IM<V=I9"`B3F]T(&%B;&4@=&\@<F5T<FEE=F4@8W5R<F5N
M="!D971A:6QS+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@Z.?RY>/K
M__(@\N7J\_GH\N4@Y.7RX.GKZ"XB"@IM<V=I9"`B(@HB3F]T93H@66]U('=I
M;&P@;F5E9"!T;R!L;V=O=70@86YD(&)A8VL@:6X@869T97(@>6]U(&-H86YG
M92!Y;W5R('!A<W-W;W)D(2(*;7-G<W1R("(B"B+-Y>[A]>[DZ.SN(.4@Y.`@
MZ.?KY>?E\N4@Z"#BZ^7GY?+E(.[R[>[B[B#Q(.WNXN#RX"#OX/#NZ^`L(/'K
MY>0@\>S_[>#RX"#I(2(*"FUS9VED(")/;&0@<&%S<W=O<F0Z(@IM<V=S='(@
M(M'RX/#@(._@\.[KX#HB"@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"XB"FUS
M9W-T<B`BS^#P[NO@\N`@X>7XY2#Q[.7MY>W@(2(*"FUS9VED(")087-S=V]R
M9"!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*;7-G<W1R(")087-S=V]R
M9"#MY2#E(.KN[?3HX_/PZ/#@[2#O\.#BZ.OM[B(*"FUS9VED(")087-S=V]R
M9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960B"FUS9W-T<B`B
MS.[D\^OZ\B#GX"#OX/#NZ^@@[>4@Y2#J[NWTZ./S\.CPX.T@[_#@XNCK[>XB
M"@IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF
M:6=U<F5D+B(*;7-G<W1R("+,[N3SZ_KR(.?@(._@\.[KZ"#MY2#E(.KN[?3H
MX_/PZ/#@[2#O\.#BZ.OM[BXB"@IM<V=I9"`B4F5Q=6ER960@)W!H<'1Y<&4G
M(&YO="!S<&5C:69I960@:6X@4U%,(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(LWE[N'U[N3H[.C_("=P:'!T>7!E)R#MY2#E(.?@Y.#DY>T@XOKB(%-13"#J
M[NWTZ./S\.#VZ/_RX"XB"@IM<V=I9"`B4V5R=F5R(@IM<V=S='(@(M'Z\.+Z
M\"(*"FUS9VED(")3;VUE(&]F(%!A<W-W;W)D)W,@8V]N9FEG=7)A=&EO;B!F
M:6QE<R!A<F4@;6ES<VEN9SHB"FUS9W-T<B`BS?_J[N@@[O(@ZN[M].CC\_#@
M]NCN[>WH\N4@].#IZ^[BY2#MX"!087-S=V]R9"#KZ._QXN#R.B(*"FUS9VED
M("(B"B)4:&ES(&ES('1H92!M86EN(%!A<W-W;W)D(&-O;F9I9W5R871I;VX@
M9FEL92X@270@8V]N=&%I;G,@;W!T:6]N<R!F;W(@86QL("(*(E!A<W-W;W)D
M('-C<FEP=',N(@IM<V=S='(@(B(*(M+NXN`@Y2#CZ^#B[>C_(.KN[?3HX_/P
MX/;H[NWE[2#TX.GK(.W@(%!A<W-W;W)D+B#2[ND@\?KD^O#FX"#O^O+H^>`@
MZ"#N[_;HZ"`B"B+GX"#QZO#H[_+NXN7RY2#MX"!087-S=V]R9"XB"@IM<V=I
M9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B
MS>7B^N?L[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N(@H*(RP@8RUF
M;W)M870*;7-G:60@(E5S97(@)7-`)7,@;F]T(&9O=6YD(@IM<V=S='(@(L_N
M\O#EX>CRY>L@)7-`)7,@[>4@X>7XY2#MX.SE\.7M(@H*;7-G:60@(E5S97(@
M;F]T(&9O=6YD(@IM<V=S='(@(LW_[.`@\N#J^N(@[^[R\.7AZ/+EZR(*"FUS
M9VED(")5<V5R(&YO="!F;W5N9"XB"FUS9W-T<B`BS?_LX"#RX.KZXB#O[O+P
MY>'H\N7K+B(*"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`BR.SE.B(*"B,L
M(&,M9F]R;6%T"FUS9VED(")9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O
M<B!U<V5R("5S(@IM<V=S='(@(LWE(.SNYN7RY2#DX"#Q[.7MZ/+E(._@\.[K
MX/+@(.W@(._N\O#EX>CRY>L@)7,B"@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y
M;W5R(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T<B`BTO#_X>+@(.3@(.+ZXN7D
MY?+E(/+EZO/YX/+@(,+H(._@\.[KX"(*"FUS9VED(")9;W4@;75S="!G:79E
M('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(M+P_^'BX"#DX"#B^N+EY.7R
MY2#M[N+@\N`@PN@@[^#P[NO@(@H*;7-G:60@(EEO=2!M=7-T('9E<FEF>2!Y
M;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R("+2\/_AXN`@Y.`@[^[RXOKPY.CR
MY2#"X/C@\N`@[>[BX"#OX/#NZ^`B"@HC+"!C+69O<FUA=`IM<V=I9"`B(@HB
M66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO;F<[('!A<W-W;W)D<R!M87D@
M;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T97)S("(*(FQO;F<A(@IM<V=S
M='(@(B(*(LWNXN#RX"#"Z"#OX/#NZ^`@Y2#RXOKPY.4@Y/KKX^`[(._@\.[K
MZ/+E(.WE(.SNX^#R(.3@(/'@(._N+>3ZZ^/H(.[R("5D("(*(O'H[.+NZ^`A
M(@H*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@
M9W5E<W,A("!.;W0@8VAA;F=E9"$B"FUS9W-T<B`BS>[BX/+@(,+H(._@\.[K
MX"#E(._PY>K@Z^7M[B#KY?'MX"#GX"#N\N/@\N+@[>4A(,W_[.`@Y.`@X?KD
MY2#Q[.7MY>W@(2(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@;&]N9R$B"FUS
M9W-T<B`BS>[BX/+@(,+H(._@\.[KX"#R\/_AXN`@Y.`@Y2#D^NOCX"#O[NWE
M("5D(/'H[.+NZ^`A(@H*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@
M8F4@9&EF9F5R96YT(&9R;VT@>6]U<B!C=7)R96YT('!A<W-W;W)D(@IM<V=S
M='(@(LWNXN#RX"#"Z"#OX/#NZ^`@\O#_X>+@(.3@(.4@\.#GZ^CW[>`@[O(@
M\N7J\_G@\N`B"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA<F%C
M=&5R<RXB"FUS9W-T<B`BS>[BX/+@(,+H(._@\.[KX"#R\/_AXN`@Y.`@\?KD
M^O#FX"#O[NWE("5D(/'H[.+NZ^`A(@H*(RP@8RUF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!A;'!H
M86YU;65R:6,@8VAA<F%C=&5R<RXB"FUS9W-T<B`BS>[BX/+@(,+H(._@\.[K
MX"#R\/_AXN`@Y.`@\?KD^O#FX"#O[NWE("5D(/'H[.+NZ^`@*.'SZN+H(.@@
M]NCT\.@I+B(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R
M9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;&]W97)C87-E(&-H87)A8W1E
M<G,N(@IM<V=S='(@(LWNXN#RX"#"Z"#OX/#NZ^`@\O#_X>+@(.3@(/'ZY/KP
MYN`@[^[MY2`E9"#QZ.SB[NO@("CLX.OJZ"#A\^KBZ"DN(@H*(RP@8RUF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L
M96%S="`E9"!N=6UE<FEC(&-H87)A8W1E<G,N(@IM<V=S='(@(LWNXN#RX"#"
MZ"#OX/#NZ^`@\O#_X>+@(.3@(/'ZY/KPYN`@[^[MY2`E9"#QZ.SB[NO@("CV
MZ/3PZ"DN(@H*(RP@8RUF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D
M(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R
M<RXB"FUS9W-T<B`BS>[BX/+@(,+H(._@\.[KX"#R\/_AXN`@Y.`@\?KD^O#F
MX"#O[NWE("5D(/'H[.+NZ^`@*./NZ^7LZ"#A\^KBZ"DN(@H*(RP@8RUF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L
M97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T97)S+B(*;7-G<W1R("+-
M[N+@\N`@PN@@[^#P[NO@(/+P_^'BX"#DX"#Q^N3Z\.;@(._N[>4@)60@\>CL
MXN[KX"`HZ.WRY?#BX.O@*2XB"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M;75S="!N;W0@8V]N=&%I;B!W:&ET97-P86-E(&-H87)A8W1E<G,N(@IM<V=S
M='(@(LWNXN#RX"#"Z"#OX/#NZ^`@\O#_X>+@(.3@(.WE(/'ZY/KPYN`@Z.WR
MY?#BX.OH+B(*"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9',@9&ED;B=T(&UA
M=&-H(@IM<V=S='(@(LWNXN#RX"#"Z"#OX/#NZ^`@[>4@X>7XY2#O[N+R[O#E
M[>`@ZN[PY>KR[>XA(@H*;7-G:60@(G1E;7!N86TH*2!F86EL960A(@IM<V=S
M='(@(N/PY?CJX"#O\.@@=&5M<&YA;2@I(2(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S
M<W=D+W!O+V9R7T92+G!O````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`R,3(S-@`Q,#0Q-S,V,C<T,P`P,3<W,#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!087-S=V0M:#,@
M;6]D=6QE('1R86YS;&%T:6]N<RX*(R!T<F%N<VQA=&EO;B!O9B!F<E]&4BYP
M;R!T;R!&<F%NYV%I<PHC($-O<'ER:6=H="`H0RD@,C`P,RP@,C`P-"!&<F5E
M(%-O9G1W87)E($9O=6YD871I;VXL($EN8RX*(R!%<FEC(%)O<W1E='1E<B`\
M<F]S=&5T=&5R0&UA:6PN=71E>&%S+F5D=3XL(#(P,#(N"B,@4&EE<G)E($QA
M8VAA;F-E(#QP;$!P:65R<F5L86-H86YC92YN970^(&5T($)E;F]I="!3="U!
M;F1RZ2`H8F5N0&)E;F]I='-T+6%N9')E+FYE="DL(#(P,#,L(#(P,#0N"B,@
M5&AI97)R>2!4:&]M87,@/'1H:65R<GE`<&]M<&\N;F5T/BP@,C`P-2X*(PHC
M+"!F=7IZ>0IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO
M;CH@4&%S<W=D+6@S+3,N,%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3`X+3(V(#(S.C`S*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M
M,#@M,C8@,C,Z,S`K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!4:&EE<G)Y
M(%1H;VUA<R`\=&AI97)R>4!P;VUP;RYN970^7&XB"B),86YG=6%G92U496%M
M.B!&<F5N8V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`^
M(#$I.UQN(@H*(SH@;&EB+T1R:79E<B]E>'!E8W0N<&AP.C,T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&1O97,@;F]T(&5X:7-T(&]R(&ES(&YO="!E>&5C
M=71A8FQE+B(*;7-G<W1R("(E<R!N)V5X:7-T92!P87,@;W4@;B=E<W0@<&%S
M(&5XZ6-U=&%B;&4N(@H*(SH@;&EB+T1R:79E<B]C;VUP;W-I=&4N<&AP.C4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B!U;F%B;&4@=&\@;&]A9"!D<FEV
M97(Z("5S(@IM<V=S='(@(B5SH#H@8VAA<F=E;65N="!D=2!P:6QO=&4@)7,@
M:6UP;W-S:6)L92(*"B,Z(&QI8B]$<FEV97(O861S:2YP:'`Z-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B041322!E<G)O<B`E<RXB"FUS9W-T<B`B17)R975R
M($%$4TD@)7,N(@H*(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z.3<@;&EB
M+T1R:79E<B]A9'-I+G!H<#HU-PIM<V=I9"`B06-C97-S($1E;FEE9"XB"FUS
M9W-T<B`B06-CZ',@<F5F=7/I+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C@P"FUS
M9VED(")"86-K96YD(&YO="!C;W)R96-T;'D@:6UP;&5M96YT960N(@IM<V=S
M='(@(D1O<G-A;"!I;F-O<G)E8W1E;65N="!I;7!LZ6UE;G3I+B(*"B,Z(&UA
M:6XN<&AP.C(T-B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ-#(*;7-G:60@
M(D-H86YG92!087-S=V]R9"(*;7-G<W1R(")-;V1I9FEC871I;VX@9'4@;6]T
M(&1E('!A<W-E(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,3(W"FUS
M9VED(")#:&%N9V4@<&%S<W=O<F0@;VXZ(@IM<V=S='(@(DUO9&EF:6-A=&EO
M;B!D=2!M;W0@9&4@<&%S<V4@<W5RH#HB"@HC.B!T96UP;&%T97,O;6%I;B]M
M86EN+FEN8SHV,@IM<V=I9"`B0VAA;F=E('EO=7(@<&%S<W=O<F0B"FUS9W-T
M<B`B36]D:69I8V%T:6]N(&1E('9O=')E(&UO="!D92!P87-S92(*"B,Z('1E
M;7!L871E<R]M86EN+VUA:6XN:6YC.C8Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-H86YG:6YG('!A<W-W;W)D(&]N("5S(@IM<V=S='(@(DUO9&EF:65R('9O
M=')E(&UO="!D92!P87-S92!S=7(@)7,B"@HC.B!T96UP;&%T97,O;6%I;B]M
M86EN+FEN8SHQ,30*;7-G:60@(D-O;F9I<FT@;F5W('!A<W-W;W)D.B(*;7-G
M<W1R(")#;VYF:7)M97(@;&4@;F]U=F5A=2!M;W0@9&4@<&%S<V6@.B(*"B,Z
M(&QI8B]$<FEV97(O:V]L86(N<&AP.C0X(&QI8B]$<FEV97(O<VUB;&1A<"YP
M:'`Z.3`*(SH@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HQ-S$@;&EB+T1R:79E
M<B]L9&%P+G!H<#HY,R!L:6(O1')I=F5R+VQD87`N<&AP.C(T,`IM<V=I9"`B
M0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3F4@<&5U
M="!S92!C;VYN96-T97(@874@<V5R=F5U<B!,1$%0(@H*(SH@;&EB+T1R:79E
M<B]K;VQA8BYP:'`Z-#`@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HV-R!L:6(O
M1')I=F5R+VQD87`N<&AP.C8T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!L9&%P('-E<G9E<B(*;7-G<W1R("+)8VAE8R!D92!L82!C;VYN97AI;VX@
M874@<V5R=F5U<B!,1$%0(@H*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N<&AP
M.C4S"FUS9VED(")#;W5L9"!N;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"XB
M"FUS9W-T<B`B26UP;W-S:6)L92!D92!C;VUM=6YI<75E<B!A=F5C('-M8G!A
M<W-W9"XB"@HC.B!L:6(O1')I=F5R+W-M8G!A<W-W9"YP:'`Z-S4*;7-G:60@
M(D5R<F]R('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N(@IM<V=S='(@(D5R
M<F5U<B!L;W)S(&1E(&PG96YV;VD@9&4@9&]N;NEE<R!V97)S('-M8G!A<W-W
M9"XB"@HC.B!L:6(O1')I=F5R+W!S<&%S<W=D+G!H<#HX-0IM<V=I9"`B1F%I
M;&5D('1O('9E<FEF>2!O;&0@<&%S<W=O<F0N(@IM<V=S='(@(LEC:&5C(&1E
M(&QA(';I<FEF:6-A=&EO;B!D92!L)V%N8VEE;B!M;W0@9&4@<&%S<V4N(@H*
M(SH@;6%I;BYP:'`Z,C`S(&QI8B]$<FEV97(O8V]M<&]S:71E+G!H<#HY,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL=7)E(&EN(&-H86YG:6YG('!A<W-W
M;W)D(&]N("5S.B`E<R(*;7-G<W1R("),82!M;V1I9FEC871I;VX@9&4@=F]T
M<F4@;6]T(&1E('!A<W-E('-U<B`E<R!A(.EC:&]UZ:`Z("5S(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z-3$@;&EB+T1R:79E<B]V;6%I;&UG<BYP:'`Z,S4@;&EB
M+T1R:79E<B]K;VQA8BYP:'`Z-S(*(SH@;&EB+T1R:79E<B]P;W!P87-S9"YP
M:'`Z,3`Y(&QI8B]$<FEV97(O<VUB;&1A<"YP:'`Z,3<R"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,C0Q"FUS9VED("));F-O<G)E8W0@4&%S<W=O<F0B"FUS
M9W-T<B`B36]T(&1E('!A<W-E(&EN8V]R<F5C="(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,C(S"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@
M;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(DPGXF=E(&UI;FEM=6T@9'4@;6]T
M(&1E('!A<W-E(&XG97-T('!A<R!E;F-O<F4@97AP:7+I(@H*(SH@=&5M<&QA
M=&5S+VUA:6XO;6%I;BYI;F,Z,3`R"FUS9VED(").97<@<&%S<W=O<F0Z(@IM
M<V=S='(@(DYO=79E874@;6]T(&1E('!A<W-EH#HB"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<W5C:"!B86-K96YD
M("<E<R<@9F]U;F0N(@IM<V=S='(@(D%U8W5N(&1O<G-A;""KH"5SH+L@=')O
M=7;I+B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.CDP"FUS9VED(")/
M;&0@<&%S<W=O<F0Z(@IM<V=S='(@(D%N8VEE;B!M;W0@9&4@<&%S<V6@.B(*
M"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HT,PIM<V=I9"`B4&%S<W=D
M(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+B(*;7-G<W1R("(B"B),92!M
M;V1U;&4@9&4@8VAA;F=E;65N="!D92!M;W0@9&4@<&%S<V4@;B=E<W0@<&%S
M(&-O<G)E8W1E;65N="!C;VYF:6=U<NDN(@H*(SH@;6%I;BYP:'`Z,3DU"B,L
M('!H<"UF;W)M870*;7-G:60@(E!A<W-W;W)D(&-H86YG960@;VX@)7,N(@IM
M<V=S='(@(DUO="!D92!P87-S92!M;V1I9FGI('-U<B`E<RXB"@HC.B!L:6(O
M1')I=F5R+W!S<&%S<W=D+G!H<#HV-PIM<V=I9"`B4&%S<W=O<F0@;6]D=6QE
M(&-A;B=T(&9I;F0@=&AE('-U<'!L:65D(&)I;BXB"FUS9W-T<B`B(@HB3&4@
M;6]D=6QE(&1E(&-H86YG96UE;G0@9'4@;6]T(&1E('!A<W-E(&YE('1R;W5V
M92!P87,@;&4@<')O9W)A;6UE(&EN9&EQ=>DN(@H*(SH@;&EB+T1R:79E<B]P
M<W!A<W-W9"YP:'`Z-C4*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!M:7-S
M:6YG(')E<75I<F5D('!A<F%M971E<G,N(@IM<V=S='(@(B(*(E!A<F%MZ'1R
M97,@;V)L:6=A=&]I<F5S(&%B<V5N=',@<&]U<B!L92!M;V1U;&4@9&4@8VAA
M;F=E;65N="!D=2!M;W0@9&4@<&%S<V4N(@H*(SH@;&EB+T1R:79E<B]A9'-I
M+G!H<#HT-`IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&ES(&UI<W-I;F<@=&%R
M9V5T('!A<F%M971E<BXB"FUS9W-T<B`B4&%R86WH=')E(&-I8FQE(&%B<V5N
M="!P;W5R(&QE(&UO9'5L92!D92!C:&%N9V5M96YT(&1U(&UO="!D92!P87-S
M92XB"@HC.B!M86EN+G!H<#HQ-S8@;&EB+T1R:79E<B]S97)V=69T<"YP:'`Z
M-C8*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N
M9FEG=7)E9"(*;7-G<W1R("(B"B),92!M;V1U;&4@9&4@8VAA;F=E;65N="!D
M=2!M;W0@9&4@<&%S<V4@;B=E<W0@<&%S(&-O<G)E8W1E;65N="!C;VYF:6=U
M<NDB"@HC.B!L:6(O1')I=F5R+W-E<G9U9G1P+G!H<#HY,PIM<V=I9"`B4&%S
M<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+B(*;7-G
M<W1R("(B"B),92!M;V1U;&4@9&4@8VAA;F=E;65N="!D=2!M;W0@9&4@<&%S
M<V4@;B=E<W0@<&%S(&-O<G)E8W1E;65N="!C;VYF:6=U<NDN(@H*(SH@;&EB
M+T1R:79E<B]C;VUP;W-I=&4N<&AP.C,U"FUS9VED(")297%U:7)E9"`G9')I
M=F5R<R<@:7,@;6ES8V]N9FEG=7)E9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B3&4@<&EL;W1E(&XG97-T('!A<R!C;W)R96-T96UE
M;G0@8V]N9FEG=7+I+B(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H<#HT,0IM<V=I
M9"`B4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@4&%S<W=D
M(%-13"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G<&AP='EP92<@<F5Q=6ES
M(&YO;B!I;F1I<77I(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B!D92!087-S=V0@
M4U%,+B(*"B,Z(&QI8B]$<FEV97(O=G!O<&UA:6PN<&AP.C0T"FUS9VED(")2
M97%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!344P@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B)W!H<'1Y<&4G(')E<75I<R!N;VX@:6YD:7%U
MZ2!D86YS(&QA(&-O;F9I9W5R871I;VX@9&4@4U%,+B(*"B,Z('1E;7!L871E
M<R]M86EN+VUA:6XN:6YC.C$T,PIM<V=I9"`B4F5S970B"FUS9W-T<B`B4L!:
M(@H*(SH@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z-S@@;&EB+T1R:79E<B]S
M<6PN<&AP.C<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+B(*;7-G<W1R(")#;VYN97AI;VX@:6UP;W-S:6)L92!A=2!S97)V975R
M(%-13"XB"@HC.B!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HQ,S@@;&EB+T1R
M:79E<B]S<6PN<&AP.C$R,`HC.B!L:6(O1')I=F5R+W!O<'!A<W-D+G!H<#HQ
M,#,*;7-G:60@(E5S97(@;F]T(&9O=6YD(@IM<V=S='(@(E5T:6QI<V%T975R
M(&YO;B!T<F]U=NDB"@HC.B!L:6(O1')I=F5R+VMO;&%B+G!H<#HV-"!L:6(O
M1')I=F5R+W!I;F4N<&AP.C(R-2!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C$R
M-PHC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$S,`IM<V=I9"`B57-E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E5T:6QI<V%T975R(&YO;B!T<F]U=NDN(@H*(SH@
M=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z-S<*;7-G:60@(E5S97)N86UE.B(*
M;7-G<W1R(")5=&EL:7-A=&5U<J`Z(@H*(SH@;6%I;BYP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@
M=7-E<B`E<R(*;7-G<W1R(")6;W5S(&YE('!O=79E>B!P87,@8VAA;F=E<B!L
M92!M;W0@9&4@<&%S<V4@<&]U<B!L)W5T:6QI<V%T975R("5S(@H*(SH@;6%I
M;BYP:'`Z-3,*;7-G:60@(EEO=2!M=7-T(&=I=F4@>6]U<B!C=7)R96YT('!A
M<W-W;W)D(@IM<V=S='(@(E9O=7,@9&5V97H@<V%I<VER('9O=')E(&UO="!D
M92!P87-S92!A8W1U96PB"@HC.B!M86EN+G!H<#HV,@IM<V=I9"`B66]U(&UU
M<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")6;W5S(&1E=F5Z
M('-A:7-I<B!V;W1R92!N;W5V96%U(&UO="!D92!P87-S92(*"B,Z(&UA:6XN
M<&AP.C8V"FUS9VED(")9;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O
M<F0B"FUS9W-T<B`B5F]U<R!D979E>B!R97-S86ES:7(@=F]T<F4@;F]U=F5A
M=2!M;W0@9&4@<&%S<V4B"@HC.B!M86EN+G!H<#HX-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@;&]N9SL@<&%S
M<W=O<F1S(&UA>2!N;W0@8F4@;6]R92!T:&%N("5D(&-H87)A8W1E<G,@(@HB
M;&]N9R$B"FUS9W-T<B`B(@HB5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@
M97-T('1R;W`@;&]N9Z`[('5N(&UO="!D92!P87-S92!N92!P975T('!O<W/I
M9&5R("(*(G!L=7,@9&4@)60@8V%R86-TZ')E<Z`A(@H*(SH@;6%I;BYP:'`Z
M,38U"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@<VEM<&QE('1O
M(&=U97-S(2`@3F]T(&-H86YG960A(@IM<V=S='(@(E9O=')E(&YO=79E874@
M;6]T(&1E('!A<W-E(&5S="!T<F]P('-I;7!L9:`A($YO;B!M;V1I9FGIH"$B
M"@HC.B!M86EN+G!H<#HQ-38*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES
M('1O;R!S:6UP;&4@=&\@9W5E<W,N($YO="!C:&%N9V5D(2(*;7-G<W1R(")6
M;W1R92!N;W5V96%U(&UO="!D92!P87-S92!E<W0@=')O<"!S:6UP;&4N($YO
M;B!M;V1I9FGIH"$B"@HC.B!M86EN+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H
M87)A8W1E<G,@;&]N9R$B"FUS9W-T<B`B5F]T<F4@;F]U=F5A=2!M;W0@9&4@
M<&%S<V4@9&]I="!A=F]I<B!A=2!M;VEN<R`E9"!C87)A8W3H<F5SH"$B"@HC
M.B!M86EN+G!H<#HW-`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!B
M92!D:69F97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T
M<B`B5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@9&]I="#J=')E(&1I9F;I
M<F5N="!D92!L)V%C='5E;*`A(@H*(SH@;6%I;BYP:'`Z,3(V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A
M="!L96%S="`E9"!A;'!H86)E=&EC(&-H87)A8W1E<G,N(@IM<V=S='(@(B(*
M(E9O=')E(&YO=79E874@;6]T(&1E('!A<W-E(&1O:70@879O:7(@874@;6]I
M;G,@)60@8V%R86-TZ')E<R!A;'!H86+I=&EQ=65S+B(*"B,Z(&UA:6XN<&AP
M.C$S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A8W1E
M<G,N(@IM<V=S='(@(B(*(E9O=')E(&YO=79E874@;6]T(&1E('!A<W-E(&1O
M:70@879O:7(@874@;6]I;G,@)60@8V%R86-TZ')E<R!A;'!H86YU;>ER:7%U
M97,N(@H*(SH@;6%I;BYP:'`Z,3,V"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!D
M:69F97)E;G0@='EP97,@;V8@8VAA<F%C=&5R<RX@(@HB5&AE('1Y<&5S(&%R
M93H@;&]W97(L('5P<&5R+"!N=6UE<FEC+"!A;F0@<WEM8F]L<RXB"FUS9W-T
M<B`B(@HB5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@9&]I="!A=F]I<B!A
M=2!M;VEN<R`E9"!T>7!E<R!D92!C87)A8W3H<F5S("(*(F1I9F;I<F5N=',N
M3&5S('1Y<&5S('-O;G2@.B!M:6YU<V-U;&4L(&UA:G5S8W5L92P@;G5MZ7)I
M<75E(&5T('-Y;6)O;&5S+B(*"B,Z(&UA:6XN<&AP.C$Q-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@
M;&5A<W0@)60@;&]W97)C87-E(&-H87)A8W1E<G,N(@IM<V=S='(@(B(*(E9O
M=')E(&YO=79E874@;6]T(&1E('!A<W-E(&1O:70@879O:7(@874@;6]I;G,@
M)60@8V%R86-TZ')E<R!M:6YU<V-U;&5S+B(*"B,Z(&UA:6XN<&AP.C$R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O
M;G1A:6X@870@;&5A<W0@)60@;G5M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R
M("(B"B)6;W1R92!N;W5V96%U(&UO="!D92!P87-S92!D;VET(&%V;VER(&%U
M(&UO:6YS("5D(&-A<F%C=.AR97,@;G5MZ7)I<75E<RXB"@HC.B!M86EN+G!H
M<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M;75S="!C;VYT86EN(&%T(&QE87-T("5D('5P<&5R8V%S92!C:&%R86-T97)S
M+B(*;7-G<W1R("(B"B)6;W1R92!N;W5V96%U(&UO="!D92!P87-S92!D;VET
M(&%V;VER(&%U(&UO:6YS("5D(&-A<F%C=.AR97,@;6%J=7-C=6QE<RXB"@HC
M.B!M86EN+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@
M<&%S<W=O<F0@;75S="!C;VYT86EN(&QE<W,@=&AA;B`E9"!W:&ET97-P86-E
M(&-H87)A8W1E<G,N(@IM<V=S='(@(E9O=')E(&YO=79E874@;6]T(&1E('!A
M<W-E(&1O:70@879O:7(@;6]I;G,@9&4@)60@8V%R86-TZ')E<R!E<W!A8V4N
M(@H*(SH@;6%I;BYP:'`Z,30T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA<F%C=&5R<RXB"FUS9W-T
M<B`B5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@;F4@9&]I="!P87,@8V]N
M=&5N:7(@9&4@8V%R86-TZ')E<R!E<W!A8V4N(@H*(SH@;6%I;BYP:'`Z-S`*
M;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D<R!D:61N)W0@;6%T8V@B"FUS9W-T
M<B`B5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@;F4@8V]R<F5S<&]N9"!P
M87,B"@HC.B!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C<S(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z-S`*;7-G:60@(FQD87!?<W1A<G1?=&QS(&9A:6QE9"(*;7-G
M<W1R("+)8VAE8R!D92!L9&%P7W-T87)T7W1S;"(*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P87-S=V0O<&\O87)?4UDN<&\`````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S8Q`#$P-#$W,S8R-S0S`#`Q-S<R-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C(%!A
M<W-W9"!M;V1U;&4@=')A;G-L871I;VYS+@HC(%1H:7,@9FEL92!I<R!D:7-T
M<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!087-S=V0@
M<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#,@4&QA=&EN=6T@26YC+B`\
M<&Q`=&EN=6TN:6YF;SX*(R!#=7-T;VT@5V5B($%P<&QI8V%T:6]N<R`\:'1T
M<#HO+W!L871I;G5M+7-Y+F-O;3X*(R!0;&%T:6YU;2!$979E;&]P;65N="!4
M96%M(#QD979T96%M0'!L871I;G5M+7-Y+FYE=#X*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@4&%S<W=D(%QN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#,M,#0M,S`@,3(Z,#`K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,RTP-"TS,"`Q,CHP,"LP,C`P7&XB"B),87-T+51R
M86YS;&%T;W(Z("!0;&%T:6YU;2!$979E;&]P;65N="!496%M(#QD979T96%M
M0'!L871I;G5M+7-Y+F-O;3Y<;B(*(DQA;F=U86=E+51E86TZ($%R86)I8R`\
M:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U-EQN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*;7-G:60@
M(D-H86YG92!Y;W5R('!A<W-W;W)D(@IM<V=S='(@(LK;[>W1(-_AX\D@Q^'C
MT>;1(@H*;7-G:60@(D-O;F9I<FT@;F5W('!A<W-W;W)D.B(*;7-G<W1R("+*
MP]_MSR#?X>/)(,?AX]'FT2#'X<S/[<_).B(*"FUS9VED(")%<G)O<B(*;7-G
M<W1R("+-U>$@SMC#(@H*;7-G:60@(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S
M<W=O<F0@.B`B"FUS9W-T<B`BSMC#(-WM(,K;[>W1(-_AX\D@Q^'CT>;1(@H*
M;7-G:60@(DAE;'`B"FUS9W-T<B`BQ^'CT\?:S\DB"@IM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`BQ^'AV\DB"@IM<V=I9"`B3&]G;W5T(@IM<V=S='(@(L[1
MYLPB"@IM<V=I9"`B365S<V%G92(*;7-G<W1R("+1T\?AR2(*"FUS9VED(").
M97<@<&%S<W=O<F0Z(@IM<V=S='(@(M_AX\D@Q^'CT>;1(,?AS,_MS\DZ(@H*
M;7-G:60@(D]L9"!P87-S=V]R9#HB"FUS9W-T<B`BW^'CR2#'X>/1YM$@Q^'>
MS^WCR3HB"@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"$B"FUS9W-T<B`BRN,@
MRMOM[=$@W^'CR2#'X>/1YM$A(@H*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I
M<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*;7-G<W1R("+.V,,@W>T@Q=K/
MQ\_'RB#(T>WCS"#?X>/)(,?AX]'FT2(*"FUS9VED(")0<F]B;&5M/R(*;7-G
M<W1R("+CU-_AR;\B"@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.B(*;7-G<W1R("+'SLK1(.';RM\@Q^'CW=;AR3HB"@IM<V=I9"`B
M4V5T('1H92!L86YG=6%G92!T:&%T(&UE;G4@:71E;7,L(&5X<&QA;F%T:6]N
M<RP@86YD(&AE;'`@87)E(&EN+B(*;7-G<W1R("+-S\\@X=O)(,?AP^;'X]&A
M(,?AU-'-(.;'X>/3Q]K/R2XB"@IM<V=I9"`B4V]M92!O9B!087-S=V]R9"!M
M;V1U;&4G<R!C;VYF:6=U<F%T:6]N(&9I;&5S(&%R92!M:7-S:6YG.B(*;7-G
M<W1R("+(VM8@X^'=Q\H@Q=K/Q\_'RB#(T>WCS,?*(-_AX\D@Q^'CT>;1(./=
MWN;/R2(*"FUS9VED(")3=6-C97-S(@IM<V=S='(@(LKC(,?AP^/1(,CDS,?-
M(@H*;7-G:60@(B(*(E1H:7,@9FEL92!C;VYT<F]L<R!T:&4@9&5F875L="!P
M<F5F97)E;F-E<R!F;W(@4&%S<W=O<F0@;6]D=6QE+"!A;F0@86QS;R`B"B)C
M;VYT<F]L<R!W:&EC:"!P<F5F97)E;F-E<R!U<V5R<R!C86X@86QT97(N(@IM
M<V=S='(@(B(*(NW*S=_C(.70QR#'X>/AW2#(Q^'%VL_'S\?*(,?AQ]W*T<?6
M[<D@X<C1[>/,Q\H@W^'CR2#'X>/1YM&A(-_CQR#MS<_/("(*(L?AQ=K/Q\_'
MRB#'X<KM(.WCW^0@X>'CT\K.S^,@RMK/[>'EQRXB"@IM<V=I9"`B(@HB5&AI
M<R!F:6QE(&-O;G1R;VQS('1H92!S='EL97-H965T('1H870@:7,@=7-E9"!T
M;R!S970@8V]L;W)S(&%N9"!F;VYT<R!I;B`B"B)A9&1I=&EO;B!T;R!O<B!O
M=F5R<FED:6YG($AO<F1E(&1E9F%U;'1S+B(*;7-G<W1R("(B"B+MRLW?XR#E
MT,<@Q^'CX=T@R.'FQ\;-(,?AP^'FQ^0@YL?ASMCFV"#%UL?=R2##YB#(S^''
M\"#CY"#%VL_'S\?*(.7FT<_M("(*(B=(;W)D92<N(@H*;7-G:60@(B(*(E1H
M:7,@:7,@=&AE(&UA:6X@4&%S<W=O<F0@;6]D=6QE(&-O;F9I9W5R871I;VX@
M9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD("(*(F]P=&EO;G,@9F]R(&%L
M;"!087-S=V]R9"!M;V1U;&4@<V-R:7!T<RXB"FUS9W-T<B`B(@HBY=#'(./A
MW2#'X<7:S\?/Q\H@Q^'1QNW3[2#AW^'CR2#'X>/1YM$@YNW-YNT@X]/'T<?*
M(.8@SNW'T<?*(,SC[=H@R.W1X\S'RB`B"B+?X>/)(,?AX]'FT2(*"FUS9VED
M(")5<V5R;F%M93HB"FUS9W-T<B`BQ]/C(,?AX]/*SL_C.B(*"FUS9VED(")7
M87)N:6YG(@IM<V=S='(@(LKDR.WE(@H*;7-G:60@(EEO=2!C86X@;F]T(&-H
M86YG92!P87-S=V0@9F]R(&]T:&5R('5S97(B"FUS9W-T<B`BX<?MX]_D(,K;
M[>W1(-_AX\D@Q^'CT>;1(.'CT\K.S^,@X<+.T2XB"@HC+"!C+69O<FUA=`IM
M<V=I9"`B66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<R(*
M;7-G<W1R("+AQ^WCW^0@RMOM[=$@W^'CR2#'X>/1YM$@X>'CT\K.S^,@)7,B
M"@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G
M<W1R("+MS,@@Q<_.Q^$@W^'CR2#CT>;1(,S/[<_)(@H*;7-G:60@(EEO=2!M
M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O<F0B"FUS9W-T<B`B[<S((,7/SL?A
M(-_AX\D@Q^'CT>;1(,?AWL_MX\DB"@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y
M;W5R('5S97)I9"(*;7-G<W1R("+MS,@@Q<_.Q^$@X]K1W2#'X>/3RL[/XR(*
M"FUS9VED(")9;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0B"FUS
M9W-T<B`B[<S((,K#W^W/(-_AX\D@Q^'CT>;1(,?AS,_MS\DB"@IM<V=I9"`B
M66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+'X>/:X>;CQ\H@Q^'4SM7MR2(*
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9',@9&ED;B=T(&UA=&-H(@IM<V=S
M='(@(MK/XR#*V,?(WB#=[2#?X>/)(,?AX]'FT2#'X<S/[<_)(@H`````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]P;R]I
M=%])5"YP;P``````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,38Q-#$`,3`T,3<S-C(W-#,`,#$W-S$R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@4&%S<W=D(&UO9'5L92!T<F%N
M<VQA=&EO;G,*(R!#;W!Y<FEG:'0@*$,I(#(P,#,@1G)E92!3;V9T=V%R92!&
M;W5N9&%T:6]N+"!);F,N"B,@1VEA;G)I8V\@1FEC:&5R82`\9VEA;G)I8V\N
M9FEC:&5R84!I=&5S>7,N:70^+"`R,#`S+@HC"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!P87-S=V1<;B(*(E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I
M;VXM1&%T93H@,C`P-"TP."TS,"`Q-#HQ,2LP,C`P7&XB"B)03RU2979I<VEO
M;BU$871E.B`R,#`S+3`S+3(U(#`T.C$P+2TQ,#!<;B(*(DQA<W0M5')A;G-L
M871O<CH@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3Y<;B(*(DQA;F=U
M86=E+51E86TZ($ET86QI86X@/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]$<FEV97(O8V]M<&]S:71E+G!H<#HU
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,Z('5N86)L92!T;R!L
M;V%D(&1R:79E<CH@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E(&PG
M87)C:&EV:6\@8V]M<')E<W-O+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C@P"FUS
M9VED(")"86-K96YD(&YO="!C;W)R96-T;'D@:6UP;&5M96YT960N(@IM<V=S
M='(@(B(*"B,Z(&UA:6XN<&AP.C(S,B!T96UP;&%T97,O;6%I;B]M86EN+FEN
M8SHY,PIM<V=I9"`B0VAA;F=E(%!A<W-W;W)D(@IM<V=S='(@(D-A;6)I82!0
M87-S=V]R9"(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C<X"B,L(&9U
M>GIY"FUS9VED(")#:&%N9V4@<&%S<W=O<F0@;VXZ(@IM<V=S='(@(D-A;6)I
M82!087-S=V]R9"(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$S"FUS
M9VED(")#:&%N9V4@>6]U<B!P87-S=V]R9"(*;7-G<W1R(")#86UB:6$@;&$@
M='5A('!A<W-W;W)D(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,C`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-H86YG:6YG('!A<W-W;W)D
M(&]N("5S(@IM<V=S='(@(D-A;6)I;R!087-S=V]R9"!S=2`E<R(*"B,Z('1E
M;7!L871E<R]M86EN+VUA:6XN:6YC.C8U"FUS9VED(")#;VYF:7)M(&YE=R!P
M87-S=V]R9#HB"FUS9W-T<B`B0V]N9F5R;6$@;&$@='5A(&YU;W9A('!A<W-W
M;W)D.B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z.#8@;&EB+T1R:79E<B]L
M9&%P+G!H<#HR,C,@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HX.`HC.B!L:6(O
M1')I=F5R+W-M8FQD87`N<&AP.C$V-@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HV,B!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C8U"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("));7!O<W-I
M8FEL92!C;VYN971T97)S:2!A;"!S97)V97(@;&1A<"(*"B,Z(&QI8B]$<FEV
M97(O<VUB<&%S<W=D+G!H<#HU,@IM<V=I9"`B0V]U;&0@;F]T(&]P96X@<&EP
M92!T;R!S;6)P87-S=V0N(@IM<V=S='(@(DYO;B!P;W1E=F\@87!R:7)E('5N
M('!I<&4@82!S;6)P87-S=V0N(@H*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N
M<&AP.C8V"FUS9VED(")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D
M+B(*;7-G<W1R(")%<G)O<F4@;F5L(&EN=FEO(&1I(&1A=&D@82!S;6)P87-S
M=V0N(@H*(SH@;6%I;BYP:'`Z,3DS(&QI8B]$<FEV97(O8V]M<&]S:71E+G!H
M<#HY,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;'5R92!I;B!C
M:&%N9VEN9R!P87-S=V]R9"!O;B`E<SH@)7,B"FUS9W-T<B`B17)R;W)E(&YE
M;"!C86UB:6%M96YT;R!D:2!P87-S=V]R9#H@(@H*(SH@=&5M<&QA=&5S+VUE
M;G4O;65N=2YI;F,Z,3`*;7-G:60@(DAE;'`B"FUS9W-T<B`B06EU=&\B"@HC
M.B!L:6(O1')I=F5R+G!H<#HU,2!L:6(O1')I=F5R+VQD87`N<&AP.C(R-"!L
M:6(O1')I=F5R+W!O<'!A<W-D+G!H<#HQ,#8*(SH@;&EB+T1R:79E<B]S;6)L
M9&%P+G!H<#HQ-C<@;&EB+T1R:79E<B]V;6%I;&UG<BYP:'`Z,S4*;7-G:60@
M(DEN8V]R<F5C="!087-S=V]R9"(*;7-G<W1R(")087-S=V]R9"!%<G)A=&$B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(P-PIM<V=I9"`B36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHU,PIM<V=I9"`B3F5W('!A<W-W
M;W)D.B(*;7-G<W1R(").=6]V82!P87-S=V]R9#HB"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('-U8V@@
M8F%C:V5N9"`G)7,G(&9O=6YD+B(*;7-G<W1R(").97-S=6X@8F%C:V5N9"`G
M)7,G('1R;W9A=&\B"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHT,0IM
M<V=I9"`B3VQD('!A<W-W;W)D.B(*;7-G<W1R(")696-C:&EA('!A<W-W;W)D
M.B(*"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HT,@HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=D(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+B(*;7-G
M<W1R("));"!M;V1U;&\@<&%S<W=O<F0@;F]N(&4G(&-O;F9I9W5R871O(&-O
M<G)E='1A;65N=&4B"@HC.B!M86EN+G!H<#HQ.3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E!A<W-W;W)D(&-H86YG960@;VX@)7,N(@IM<V=S='(@
M(DQA('!A<W-W;W)D(&4G('-T871A(&-A;6)I871A+B(*"B,Z(&UA:6XN<&AP
M.C$W,2!L:6(O1')I=F5R+W-E<G9U9G1P+G!H<#HV-@IM<V=I9"`B4&%S<W=O
M<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D(@IM<V=S='(@
M(DEL(&UO9'5L;R!P87-S=V]R9"!N;VX@92<@8V]N9FEG=7)A=&\@8V]R<F5T
M=&%M96YT92(*"B,Z(&QI8B]$<FEV97(O<V5R=G5F='`N<&AP.CDS"B,L(&9U
M>GIY"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O
M;F9I9W5R960N(@IM<V=S='(@(DEL(&UO9'5L;R!P87-S=V]R9"!N;VX@92<@
M8V]N9FEG=7)A=&\@8V]R<F5T=&%M96YT92(*"B,Z(&QI8B]$<FEV97(O8V]M
M<&]S:71E+G!H<#HS-`HC+"!F=7IZ>0IM<V=I9"`B4F5Q=6ER960@)V1R:79E
M<G,G(&ES(&UI<V-O;F9I9W5R960@:6X@0V]M<&]S:71E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B<E<R<@;F]N('-P96-I9FEC871A(&YE;&QA(&-O;F9I
M9W5R87II;VYE(&1E;&QE(&-A=&5G;W)I92XB"@HC.B!L:6(O1')I=F5R+W-Q
M;"YP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E)R!N
M;W0@<W!E8VEF:65D(&EN(%!A<W-W9"!344P@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B)W!H<'1Y<&4G(&YO;B!S<&5C:69I8V%T;R!N96QL82!C;VYF:6=U
M<F%Z:6]N92!344P@9&5L;&4@8V%T96=O<FEE+B(*"B,Z(&QI8B]$<FEV97(O
M=G!O<&UA:6PN<&AP.C0R"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T
M('-P96-I9FEE9"!I;B!344P@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)W!H
M<'1Y<&4G(&YO;B!S<&5C:69I8V%T;R!N96QL82!C;VYF:6=U<F%Z:6]N92!3
M44P@9&5L;&4@8V%T96=O<FEE+B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN
M:6YC.CDT"FUS9VED(")297-E="(*;7-G<W1R(")!;FYU;&QA(@H*(SH@;&EB
M+T1R:79E<B]S<6PN<&AP.C8Y(&QI8B]$<FEV97(O=G!O<&UA:6PN<&AP.C<V
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G
M<W1R("));7!O<W-I8FEL92!C;VYN971T97)S:2!A;"!S97)V97(@4U%,+B(*
M"B,Z(&QI8B]$<FEV97(O<&]P<&%S<V0N<&AP.C$P,"!L:6(O1')I=F5R+W-Q
M;"YP:'`Z,3$X"B,Z(&QI8B]$<FEV97(O=G!O<&UA:6PN<&AP.C$S-0IM<V=I
M9"`B57-E<B!N;W0@9F]U;F0B"FUS9W-T<B`B571E;G1E(&YO;B!T<F]V871O
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,C,@;&EB+T1R:79E<B]P:6YE
M+G!H<#HR,3D@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HQ,C0*;7-G:60@(E5S
M97(@;F]T(&9O=6YD+B(*;7-G<W1R(")5=&5N=&4@;F]N('1R;W9A=&\N(@H*
M(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,C@*;7-G:60@(E5S97)N86UE
M.B(*;7-G<W1R(").;VUE('5T96YT93HB"@HC(&,M9F]R;6%T"B,Z(&UA:6XN
M<&AP.C,Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!C86XG="!C:&%N9V4@
M<&%S<W=O<F0@9F]R('5S97(@)7,B"FUS9W-T<B`B3F]N('!U;VD@8V%M8FEA
M<F4@;&$@<&%S<W=O<F0@<&5R(&PG=71E;G1E("5S(@H*(SH@;6%I;BYP:'`Z
M-#<*;7-G:60@(EEO=2!M=7-T(&=I=F4@>6]U<B!C=7)R96YT('!A<W-W;W)D
M(@IM<V=S='(@(D1E=FD@:6YS97)I<F4@;&$@='5A('!A<W-W;W)D(&%T='5A
M;&4B"@HC.B!M86EN+G!H<#HU-@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y;W5R
M(&YE=R!P87-S=V]R9"(*;7-G<W1R(")$979I(&EN<V5R:7)E(&QA('1U82!N
M=6]V82!P87-S=V]R9"(*"B,Z(&UA:6XN<&AP.C8P"FUS9VED(")9;W4@;75S
M="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`B1&5V:2!I;G-E
M<FER92!L82!T=6$@;G5O=F$@<&%S<W=O<F0@;F5L;&$@=F5R:69I8V$B"@HC
M.B!M86EN+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&YE
M=R!P87-S=V]R9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@8F4@
M;6]R92!T:&%N("5D(&-H87)A8W1E<G,@(@HB;&]N9R$B"FUS9W-T<B`B(@HB
M3&$@='5A('!A<W-W;W)D(&4G('1R;W!P;R!L=6YG83L@=6YA('!A<W-W;W)D
M(&YO;B!P=6\G(&5S<V5R92!P:74G(&1I("5D("(*(F-A<F%T=&5R:2$B"@HC
M.B!M86EN+G!H<#HQ-3D*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O
M;R!S:6UP;&4@=&\@9W5E<W,A("!.;W0@8VAA;F=E9"$B"FUS9W-T<B`B3&$@
M='5A('!A<W-W;W)D(&4G('1R;W!P;R!F86-I;&4@860@:6YD;W9I;F%R92$@
M3F]N(&4G('-T871A(&-A;6)I871A(2(*"B,Z(&UA:6XN<&AP.C$U,`HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T
M;R!G=65S<RX@3F]T(&-H86YG960A(@IM<V=S='(@(DQA('1U82!P87-S=V]R
M9"!E)R!T<F]P<&\@9F%C:6QE(&%D(&EN9&]V:6YA<F4A($YO;B!E)R!S=&%T
M82!C86UB:6%T82$B"@HC.B!M86EN+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H
M87)A8W1E<G,@;&]N9R$B"FUS9W-T<B`B3&$@='5A('!A<W-W;W)D(&1E=F4@
M97-S97)E(&QU;F=A(&UI;FEM;R`E9"!C87)A='1E<FDA(@H*(SH@;6%I;BYP
M:'`Z-C@*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@9&EF9F5R
M96YT(&9R;VT@>6]U<B!C=7)R96YT('!A<W-W;W)D(@IM<V=S='(@(DQA('1U
M82!N=6]V82!P87-S=V]R9"!D979E(&5S<V5R92!D:69F97)E;G1E(&1A;&QA
M('9E8V-H:6$N(@H*(SH@;6%I;BYP:'`Z,3(P"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E
M9"!A;'!H86)E=&EC(&-H87)A8W1E<G,N(@IM<V=S='(@(DQA('1U82!N=6]V
M82!P87-S=V]R9"!D979E(&-O;G1E;F5R92!M:6YI;6\@)60@;&5T=&5R92XB
M"@HC.B!M86EN+G!H<#HQ,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N
M97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA;G5M
M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R("(B"B),82!T=6$@;G5O=F$@<&%S
M<W=O<F0@9&5V92!C;VYT96YE<F4@;6EN:6UO("5D(&-A<F%T=&5R:2!A;'!H
M86YU;65R:6-I+B(*"B,Z(&UA:6XN<&AP.C$S,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN
M(&%T(&QE87-T("5D(&1I9F9E<F5N="!T>7!E<R!O9B!C:&%R86-T97)S+B`B
M"B)4:&4@='EP97,@87)E.B!L;W=E<BP@=7!P97(L(&YU;65R:6,L(&%N9"!S
M>6UB;VQS+B(*;7-G<W1R("),82!T=6$@;G5O=F$@<&%S<W=O<F0@9&5V92!C
M;VYT96YE<F4@;6EN:6UO("5D(&-A<F%T=&5R:2!M:6YU<V-O;&DN(@H*(SH@
M;6%I;BYP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!L;W=E<F-A<V4@8VAA
M<F%C=&5R<RXB"FUS9W-T<B`B3&$@='5A(&YU;W9A('!A<W-W;W)D(&1E=F4@
M8V]N=&5N97)E(&UI;FEM;R`E9"!C87)A='1E<FD@;6EN=7-C;VQI+B(*"B,Z
M(&UA:6XN<&AP.C$Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;G5M97)I8R!C:&%R
M86-T97)S+B(*;7-G<W1R("),82!T=6$@;G5O=F$@<&%S<W=O<F0@9&5V92!C
M;VYT96YE<F4@;6EN:6UO("5D(&-A<F%T=&5R:2!N=6UE<FEC:2XB"@HC.B!M
M86EN+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D('5P<&5R8V%S92!C:&%R
M86-T97)S+B(*;7-G<W1R("),82!T=6$@;G5O=F$@<&%S<W=O<F0@9&5V92!C
M;VYT96YE<F4@;6EN:6UO("5D(&-A<F%T=&5R:2!M86EU<V-O;&DN(@H*(SH@
M;6%I;BYP:'`Z,3,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8V]N=&%I;B!L97-S('1H86X@)60@=VAI=&5S<&%C92!C
M:&%R86-T97)S+B(*;7-G<W1R("(B"B),82!T=6$@;G5O=F$@<&%S<W=O<F0@
M9&5V92!C;VYT96YE<F4@;65N;R!D:2`E9"!C87)A='1E<FD@9&5L('1I<&\@
M<W!A>FD@(@HB8FEA;F-H:2XB"@HC.B!M86EN+G!H<#HQ,S@*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C
M:&%R86-T97)S+B(*;7-G<W1R("(B"B),82!T=6$@;G5O=F$@<&%S<W=O<F0@
M;F]N('!U\B!C;VYT96YE<F4@8V%R871T97)I(&1E;"!T:7!O('-P87II(&)I
M86YC:&DN(@H*(SH@;6%I;BYP:'`Z-C0*;7-G:60@(EEO=7(@;F5W('!A<W-W
M;W)D<R!D:61N)W0@;6%T8V@B"FUS9W-T<B`B3&4@9'5E(&YU;W9E('!A<W-W
M;W)D('-O;F\@9&EF9F5R96YT:2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M-C@@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HW,0IM<V=I9"`B;&1A<%]S=&%R
M=%]T;',@9F%I;&5D(@IM<V=S='(@(FQD87!?<W1A<G1?=&QS(&9A;&ET;R(*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+W!O
M+VYN7TY/+G!O````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-30U-P`Q,#0Q-S,V,C<T,P`P,3<W,C$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!087-S=V0@3F]R=V5G:6%N
M($YY;F]R<VL@=')A;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@4&5R
M+5-T:6%N(%9A=&YE"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R
M('1H92!S86UE(&QI8V5N<V4@87,@=&AE(%!A<W-W9"!P86-K86=E+@HC(%!E
M<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R9SXL(#(P,#(N"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%!A<W-W9"`P+C`N
M,2UC=G-<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`R+3`V+3`Y(#`Q.C`Q
M*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#8M,#D@,#$Z,3(K
M,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!097(M4W1I86X@5F%T;F4@/'!S
M=D!O<G-T82YO<F<^7&XB"B),86YG=6%G92U496%M.B!.;W)W96=I86X@3GEN
M;W)S:R`\;GEN;W)S:T!O<G-T82YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N
M,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX
M.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*
M"FUS9VED(")#:&%N9V4@>6]U<B!P87-S=V]R9"(*;7-G<W1R(")%;F1R92!P
M87-S;W)D(@H*;7-G:60@(D-O;F9I<FT@;F5W('!A<W-W;W)D.B(*;7-G<W1R
M(")3=&%D9F5S="!N>71T('!A<W-O<F0Z(@H*;7-G:60@(D9A:6QU<F4@:6X@
M8VAA;F=I;F<@<&%S<W=O<F0@.B`B"FUS9W-T<B`B1F5I;"!V960@96YD<FEN
M9R!A=B!P87-S;W)D.B(*"FUS9VED(")(96QP(@IM<V=S='(@(DAJ96QP(@H*
M;7-G:60@(DEN=&5R;F%L($5R<F]R(@IM<V=S='(@(DEN=&5R;B!F96EL(@H*
M;7-G:60@(DQO9V]U="(*;7-G<W1R("),;V=G('5T(@H*;7-G:60@(DYE=R!P
M87-S=V]R9#HB"FUS9W-T<B`B3GET="!P87-S;W)D.B(*"FUS9VED("(B"B).
M;W1E.B!9;W4@=VEL;"!N965D('1O(&QO9V]U="!A;F0@8F%C:R!I;B!A9G1E
M<B!Y;W4@8VAA;F=E('EO=7(@<&%S<W=O<F0A(@IM<V=S='(@(DUE<FLZ($1U
M(&WE(&QO9V=E('5T(&]G(&EN;B!I9VIE;B!E='1E<B!A="!D=2!E;F1R87(@
M<&%S<V]R9&5T(&1I='0A(@H*;7-G:60@(D]L9"!P87-S=V]R9#HB"FUS9W-T
M<B`B1V%M;6%L="!P87-S;W)D.B(*"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M(2(*;7-G<W1R(")087-S;W)D(&5N9')A(2(*"FUS9VED(")087-S=V]R9"!M
M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960B"FUS9W-T<B`B4&%S
M<V]R9"UM;V1U;&5N(&5R(&EK:VIE(&]R9&5N=&QE9R!K;VYF:6=U<F5R="(*
M"FUS9VED(")0<F]B;&5M/R(*;7-G<W1R(")0<F]B;&5M/R(*"FUS9VED(")2
M97-E="(*;7-G<W1R(").=6QL<W1I;&PB"@IM<V=I9"`B4V]M92!O9B!087-S
M=V]R9"!M;V1U;&4G<R!C;VYF:6=U<F%T:6]N(&9I;&5S(&%R92!M:7-S:6YG
M.B(*;7-G<W1R(").;VMR92!A=B!087-S;W)D+6UO9'5L96X@<VEN9&4@:V]N
M9FEG=7)A<VIO;G-F:6QE<B!M86YG;&%R.B(*"FUS9VED("(B"B)4:&ES(&9I
M;&4@8V]N=')O;',@=&AE(&1E9F%U;'0@<')E9F5R96YC97,@9F]R(%!A<W-W
M;W)D(&UO9'5L92P@86YD(&%L<V\@(@HB8V]N=')O;',@=VAI8V@@<')E9F5R
M96YC97,@=7-E<G,@8V%N(&%L=&5R+B(*;7-G<W1R("(B"B)$96YN92!F:6QA
M(&MO;G1R;VQL97)E<B!S=&%N9&%R9&EN;G-T:6QL:6YG86YE(&9O<B!087-S
M;W)D+6UO9'5L96XL(&]G("(*(FMO;G1R;VQL97)E<B!O9W/E(&MV82!I;FYS
M=&EL;&EN9V%R(&)R=6MA<F%N92!K86X@96YD<F4N(@H*;7-G:60@(B(*(E1H
M:7,@9FEL92!C;VYT<F]L<R!T:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S960@
M=&\@<V5T(&-O;&]R<R!A;F0@9F]N=',@:6X@(@HB861D:71I;VX@=&\@;W(@
M;W9E<G)I9&EN9R!(;W)D92!D969A=6QT<RXB"FUS9W-T<B`B(@HB1&5N;F4@
M9FEL82!K;VYT<F]L;&5R97(@<W1I;&%R:V5T('-O;2!B;&ER(&)R=6MT('1I
M;"#E(&1E9FEN97)E(&9A<F=A<B!O9R`B"B)S:W)I9G1T>7!A<BP@;V<@;&5G
M9R!T:6P@96QL97(@;W9E<G-T>7)E<B!S=&%N9&%R9'9E<F1I86YE('1I;"!(
M;W)D92XB"@IM<V=I9"`B(@HB5&AI<R!I<R!T:&4@;6%I;B!087-S=V]R9"!M
M;V1U;&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P871H<R!A
M;F0@(@HB;W!T:6]N<R!F;W(@86QL(%!A<W-W;W)D(&UO9'5L92!S8W)I<'1S
M+B(*;7-G<W1R("(B"B)$971T92!E<B!H;W9E9&MO;F9I9W5R87-J;VYS9FEL
M82!F;W(@4&%S<V]R9"UM;V1U;&5N+B!$96X@:6YN96AE;&0@(@HB:V%T86QO
M9VYA;6X@;V<@:6YN<W1I;&QI;F=A<B!F;W(@86QL92!S:W)I<'1A(&D@4&%S
M<V]R9"UM;V1U;&5N+B(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W4@8V%N)W0@
M8VAA;F=E('!A<W-W;W)D(&9O<B!U<V5R("5S(@IM<V=S='(@(D1U(&MA;B!I
M:VMJ92!E;F1R92!P87-S;W)D(&9O<B!B<G5K87)E;B`E<R(*"FUS9VED(")9
M;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(D1U(&WE
M('-K<FEV92!I;FX@9&ET="!N>64@<&%S<V]R9"(*"FUS9VED(")9;W4@;75S
M="!G:79E('EO=7(@;VQD('!A<W-W;W)D(@IM<V=S='(@(D1U(&WE('-K<FEV
M92!I;FX@9&ET="!G86UL92!P87-S;W)D(@H*;7-G:60@(EEO=2!M=7-T('9E
M<FEF>2!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")$=2!MY2!S=&%D9F5S
M=&4@9&ET="!N>64@<&%S<V]R9"(*"FUS9VED(")9;W5R(&YE=R!P87-S=V]R
M9',@9&ED;B=T(&UA=&-H(@IM<V=S='(@(D1I;F4@;GEE('!A<W-O<F0@<V%M
M<W9A<G1E(&EK:VIE(@H*;7-G:60@(EEO=7(@;VQD('!A<W-W;W)D(&ES;B=T
M(&-O<G)E8W0B"FUS9W-T<B`B1&ET="!G86UL92!P87-S;W)D(&5R(&EK:VIE
M(&MO<G)E:W0B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O<&\O<&Q?4$PN<&\`````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-#8P`#$P-#$W
M,S8R-S0S`#`Q-S<Q,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C(%!A<W-W9"!M;V1U;&4@=')A;G-L871I;VYS"B,@0V]P
M>7)I9VAT("A#*2`R,#`R($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BP@26YC
M+@HC($5R:6,@4F]S=&5T=&5R(#QR;W-T971T97)`;6%I;"YU=&5X87,N961U
M/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R
M<VEO;CH@<&%S<W=D7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P,BTP."TR
M.2`Q-3HU,"LP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R+3`R+3$Y
M(#$P.C(S+3`V,#!<;B(*(DQA<W0M5')A;G-L871O<CH@36%R:75S>B!:>6YE
M;"`\;6%R:75S>D!S;VQA<FES+7@X-BYO<F<^7&XB"B),86YG=6%G92U496%M
M.B!0;VQI<V@@/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I
M;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/6ES;RTX.#4Y+3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:71<;B(*"FUS9VED(")#:&%N9V4@>6]U<B!P87-S=V]R9"(*;7-G<W1R("):
M;6EE\2!H87.S;R(*"FUS9VED(")#;VYF:7)M(&YE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B4&]T=VEE<F2\(&AA<[-O(@H*;7-G:60@(D9A:6QU<F4@:6X@8VAA
M;F=I;F<@<&%S<W=O<F0@.B`B"FUS9W-T<B`B0K.Q9"!P;V1C>F%S('IM:6%N
M>2!H87.S82`Z("(*"FUS9VED("));G1E<FYA;"!%<G)O<B(*;7-G<W1R(")"
ML[%D('=E=V[J=')Z;GDB"@IM<V=I9"`B3&]G;W5T(@IM<V=S='(@(E=Y;&]G
M=6HB"@IM<V=I9"`B3F5W('!A<W-W;W)D.B(*;7-G<W1R(").;W=E(&AA<[-O
M(@H*;7-G:60@(B(*(DYO=&4Z(%EO=2!W:6QL(&YE960@=&\@;&]G;W5T(&%N
M9"!B86-K(&EN(&%F=&5R('EO=2!C:&%N9V4@>6]U<B!P87-S=V]R9"$B"FUS
M9W-T<B`B57=A9V$Z(%!O('IM:6%N:64@:&%SLV$@;75S:2!S:>H@=WEL;V=O
M=V'F(&D@>F%L;V=O=V'F('!O;F]W;FEE(2(*"FUS9VED(")/;&0@<&%S<W=O
M<F0Z(@IM<V=S='(@(E-T87)E(&AA<[-O(@H*;7-G:60@(E!A<W-W;W)D(&-H
M86YG960A(@IM<V=S='(@(DAA<[-O('IM:65N:6]N92$B"@IM<V=I9"`B4&%S
M<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D(@IM<V=S
M='(@(DUO9'6S(%!A<W-W;W)D(&YI92!J97-T('!R87=I9+-O=V\@<VMO;F9I
M9W5R;W=A;GDB"@IM<V=I9"`B4')O8FQE;3\B"FUS9W-T<B`B36%S>B!P<F]B
M;&5M>3\B"@IM<V=I9"`B4F5S970B"FUS9W-T<B`B5WEC>GFVYB(*"FUS9VED
M(")3;VUE(&]F(%!A<W-W;W)D(&UO9'5L92=S(&-O;F9I9W5R871I;VX@9FEL
M97,@87)E(&UI<W-I;F<Z(@IM<V=S='(@(D)R86L@<&QI:_-W(&MO;F9I9W5R
M86-Y:FYY8V@@;6]D=;-U(%!A<W-W;W)D(@H*;7-G:60@(B(*(E1H:7,@9FEL
M92!C;VYT<F]L<R!T:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S960@=&\@<V5T
M(&-O;&]R<R!A;F0@9F]N=',@:6X@(@HB861D:71I;VX@=&\@;W(@;W9E<G)I
M9&EN9R!(;W)D92!D969A=6QT<RXB"FUS9W-T<B`B5&5N('!L:6L@;V1P;W=I
M861A('IA('-T>6P@9F]N=/-W(&D@:V]L;W+S=RXB"@IM<V=I9"`B(@HB5&AI
M<R!I<R!T:&4@;6%I;B!087-S=V]R9"!M;V1U;&4@8V]N9FEG=7)A=&EO;B!F
M:6QE+B!)="!C;VYT86EN<R!P871H<R!A;F0@(@HB;W!T:6]N<R!F;W(@86QL
M(%!A<W-W;W)D(&UO9'5L92!S8W)I<'1S+B(*;7-G<W1R("(B"B)4;R!J97-T
M(&>S\W=N>2!P;&EK(&MO;F9I9W5R86-Y:FYY(&UO9'6S=2!087-S=V]R9"P@
M6F%W:65R82!O;B"V8VEEOVMI("!I("(*(F]P8VIE(&1L82!W<WIY<W1K:6-H
M('-K<GEP=/-W(&UO9'6S=2!087-S=V]R9"XB"@IM<V=I9"`B57-E<B!N86UE
M.B(*;7-G<W1R(").87IW82!UOWET:V]W;FEK83HB"@HC+"!C+69O<FUA=`IM
M<V=I9"`B66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<R(*
M;7-G<W1R(").:64@;6^_97-Z('IM:65N:>8@:&%SLV$@=;]Y=&MO=VYI:V]W
M:2`E<R(*"FUS9VED(")9;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D
M(@IM<V=S='(@(DUU<VES>B!P;V1AYB!N;W=E(&AA<[-O(@H*;7-G:60@(EEO
M=2!M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O<F0B"FUS9W-T<B`B375S:7-Z
M('!O9&'F('-T87)E(&AA<[-O(@H*;7-G:60@(EEO=2!M=7-T('9E<FEF>2!Y
M;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")-=7-I<WH@>G=E<GEF:6MO=V'F
M(&YO=V4@:&%SLV\B"@HC+"!C+69O<FUA=`IM<V=I9"`B(@HB66]U<B!N97<@
M<&%S<W=O<F0@:7,@=&]O(&QO;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E(&UO
M<F4@=&AA;B`E9"!C:&%R86-T97)S("(*(FQO;F<A(@IM<V=S='(@(B(*(E1W
M;VIE(&AA<[-O(&AE<W0@>F)Y="!DLW5G:64[(&AA<[-A(&YI92!M;V>Q('IA
M=VEE<F'F('=IZF-E:B!N:;\@)60@>FYA:_-W(2(*"FUS9VED(")9;W5R(&YE
M=R!P87-S=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H86YG
M960A(@IM<V=S='(@(E1W;VIE(&YO=V4@:&%SLV\@:F5S="!A8GET(+-A='=E
M('1O(&]D9V%D;FGJ8VEA(2`@2&%SLV\@;FEE('IM:65N:6]N92$B"@HC+"!C
M+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!A="!L
M96%S="`E9"!C:&%R86-T97)S(&QO;F<A(@IM<V=S='(@(E1W;VIE(&YO=V4@
M:&%SLV\@;75S:2!Z87=I97)AYB!P<GIY;F%J;6YI96H@)60@>FYA:_-W(2(*
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9',@9&ED;B=T(&UA=&-H(@IM<V=S
M='(@(E1W;VIE(&YO=V4@:&%SLV$@;FEE('!A<W5JL2!D;R!S:65B:64B"@IM
M<V=I9"`B66]U<B!O;&0@<&%S<W=O<F0@:7-N)W0@8V]R<F5C="(*;7-G<W1R
M(")4=V]J92!S=&%R92!H87.S;R!J97-T(&YI97!R87=I9+-O=V4B"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!A<W-W9"]P;R]D85]$2RYP;P``````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3$W,S0`,3`T,3<S-C(W-#,`,#$W-C0W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",@4&%S
M<W=D(&1A;FES:"!T<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,R!4
M:&4@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U
M;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!087-S=V0@<&%C:V%G92X*
M(R!!;F1E<G,@0G)U=6X@3VQS96X@/&%N9&5R<T!B<G5U;BUO;'-E;BYN970^
M+"`R,#`S+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S
M:6]N.B!P87-S=V1<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`S+3`W+3$R
M(#`S.C,Y*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#<M,3(@
M,#0Z,#`K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!!;F1E<G,@0G)U=6X@
M3VQS96X@/&%N9&5R<T!B<G5U;BUO;'-E;BYN970^7&XB"B),86YG=6%G92U4
M96%M.B!$86YI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET7&XB"@IM<V=I9"`B0F%C:V5N9"!N;W0@8V]R<F5C=&QY(&EM<&QE
M;65N=&5D+B(*;7-G<W1R(")"86-K96YD(&5R(&EK:V4@:V]R<F5K="!I;7!L
M96UE;G1E<F5T+B(*"FUS9VED(")#:&%N9V4@4&%S<W=O<F0B"FUS9W-T<B`B
M4VMI9G0@:V]D96]R9"(*"FUS9VED(")#:&%N9V4@>6]U<B!P87-S=V]R9"(*
M;7-G<W1R(")3:VEF="!D:70@:V]D96]R9"(*"B,L(&,M9F]R;6%T"FUS9VED
M(")#:&%N9VEN9R!087-S=V]R9"!O;B`E<R(*;7-G<W1R(")3:VEF="!K;V1E
M;W)D('#E("5S(@H*;7-G:60@(D-O;F9I<FT@;F5W('!A<W-W;W)D.B(*;7-G
M<W1R(")"96MRYF9T(&YY="!K;V1E;W)D.B(*"FUS9VED(")#;W5L9"!N;W0@
M8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")+=6YN92!I:VME(&QA=F4@
M96X@8FEN9&EN9R!T:6P@;&1A<"!S97)V97)E;B(*"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")+=6YN92!I:VME
M(&]P;N4@9F]R8FEN9&5L<V4@=&EL(&QD87`@<V5R=F5R96XB"@IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@Y6)N92!F;W)B:6YD96QS92!T:6P@<VUB<&%S<W=D+B(*"FUS
M9VED(")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+B(*;7-G<W1R
M(")&96IL('9E9"!D871A;W9E<F;X<G-E;"!T:6P@<VUB<&%S<W=D+B(*"FUS
M9VED(")%<G)O<B(*;7-G<W1R(")&96IL(@H*;7-G:60@(D9A:6QU<F4@:6X@
M8VAA;F=I;F<@<&%S<W=O<F0@.B`B"FUS9W-T<B`B1&5R('-K971E(&5N(&9E
M:FP@=F5D(.9N9')I;F<@868@:V]D96]R9#HB"@IM<V=I9"`B2&5L<"(*;7-G
M<W1R(")(:N9L<"(*"FUS9VED("));F-O<F5C="!087-S=V]R9"(*;7-G<W1R
M(")&;W)K97)T(&MO9&5O<F0B"@IM<V=I9"`B3&]G;W5T(@IM<V=S='(@(DQO
M9R!U9"(*"FUS9VED(")-97-S86=E(@IM<V=S='(@(D)E<VME9"(*"FUS9VED
M(").97<@<&%S<W=O<F0Z(@IM<V=S='(@(DYY="!K;V1E;W)D.B(*"FUS9VED
M(")/;&0@<&%S<W=O<F0Z(@IM<V=S='(@(D=A;6UE;'0@:V]D96]R9#HB"@IM
M<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"$B"FUS9W-T<B`B2V]D96]R9"!E<B!N
M=2!S:VEF=&5T(2(*"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R
M;W!E<FQY(&-O;F9I9W5R960B"FUS9W-T<B`B4&%S<W=D(&UO9'5L970@97(@
M:6MK92!K;W)R96MT(&]P<V%T(@H*;7-G:60@(E!R;V)L96T_(@IM<V=S='(@
M(E!R;V)L96T_(@H*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E
M8VEF:65D(&EN(%-13"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0Y6MRYG9E
M="`G<&AP='EP92<@97(@:6MK92!S<&5C:69I8V5R970@:2!344P@;W!SYG1N
M:6YG(@H*;7-G:60@(E)E<V5T(@IM<V=S='(@(DYU;'-T:6PB"@IM<V=I9"`B
M4V5R=F5R(@IM<V=S='(@(E-E<G9E<B(*"FUS9VED(")3;VUE(&]F(%!A<W-W
M;W)D(&UO9'5L92=S(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I;F<Z
M(@IM<V=S='(@(DYO9VQE(&%F(%!A<W-W9"!M;V1U;&5T<R!O<'/F=&YI;F=S
M9FEL97(@;6%N9VQE<CHB"@IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")3=6-C
M97-S(@H*;7-G:60@(B(*(E1H:7,@9FEL92!C;VYT86EN<R!B86-K96YD(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@9F]R('1H92!087-S=V]R9"!M;V1U
M;&4@(@HB<V-R:7!T<RXB"FUS9W-T<B`B(@HB1&5N;F4@9FEL(&EN9&5H;VQD
M97(@8F%C:V5N9"!O<'/F=&YI;F=S:6YF;W)M871I;VX@=&EL(%!A<W-W9"!M
M;V1U;&5T<R`B"B)S8W)I<'1S+B(*"FUS9VED("(B"B)4:&ES(&ES('1H92!M
M86EN(%!A<W-W;W)D(&UO9'5L92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET(&-O
M;G1A:6YS('!A=&AS(&%N9"`B"B)O<'1I;VYS(&9O<B!A;&P@4&%S<W=O<F0@
M;6]D=6QE('-C<FEP=',N(@IM<V=S='(@(B(*(D1E='1E(&5R(&AO=F5D;W!S
MYG1N:6YG<V9I;&5N(&9O<B!087-S=V0@;6]D=6QE="X@1&5N(&EN9&5H;VQD
M97(@<W1I97(@;V<@(@HB;W!SYG1N:6YG<W9A;&<@=&EL(&%L;&4@4&%S<W=D
M(&UO9'5L971S('-C<FEP=',N(@H*;7-G:60@(E5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!NY2!F;W)B
M:6YD96QS92!T:6P@4U%,('-E<G9E<F5N+B(*"FUS9VED(")5<V5R(&YO="!F
M;W5N9"(*;7-G<W1R(")"<G5G97)N879N(&EK:V4@9G5N9&5T(@H*;7-G:60@
M(E5S97(@;F]T(&9O=6YD+B(*;7-G<W1R(")"<G5G97)N879N(&EK:V4@9G5N
M9&5T+B(*"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B0G)U9V5R;F%V;CHB
M"@IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!9'9A<G-E;"(*"B,L(&,M9F]R
M;6%T"FUS9VED(")9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O<B!U<V5R
M("5S(@IM<V=S='(@(D1U(&MA;B!I:VME('-K:69T92!K;V1E;W)D(&9O<B!B
M<G5G97)E;B`E<R(*"FUS9VED(")9;W4@;75S="!G:79E('EO=7(@;F5W('!A
M<W-W;W)D(@IM<V=S='(@(D1U('-K86P@86YG:79E(&5T(&YY="!K;V1E;W)D
M(@H*;7-G:60@(EEO=2!M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O<F0B"FUS
M9W-T<B`B1'4@<VMA;"!A;F=I=F4@9&ET(&=A;6QE(&MO9&5O<F0B"@IM<V=I
M9"`B66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@
M(D1U('-K86P@8F5K<N9F=&4@9&ET(&YY92!K;V1E;W)D(@H*(RP@8RUF;W)M
M870*;7-G:60@(B(*(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!L;VYG.R!P
M87-S=V]R9',@;6%Y(&YO="!B92!M;W)E('1H86X@)60@8VAA<F%C=&5R<R`B
M"B)L;VYG(2(*;7-G<W1R("(B"B)$:70@;GEE(&MO9&5O<F0@97(@9F]R(&QA
M;F=T+B!+;V1E;W)D(&WE(&EK:V4@=N9R92!M97)E(&5N9"`E9"!T96=N(&QA
M;F=E(2(*"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@<VEM<&QE
M('1O(&=U97-S(2`@3F]T(&-H86YG960A(@IM<V=S='(@(D1I="!N>64@:V]D
M96]R9"!E<B!F;W(@<VEM<&5L="!A="!GYG1T92$@($1E="!E<B!I:VME(&)L
M979E="!S:VEF=&5T(2(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@;&]N9R$B
M"FUS9W-T<B`B1&ET(&YY92!K;V1E;W)D('-K86P@=N9R92!M:6YD<W0@)60@
M=&5G;B!L86YG="$B"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!B
M92!D:69F97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B"FUS9W-T
M<B`B1&ET(&YY92!K;V1E;W)D('-K86P@=N9R92!F;W)S:V5L;&EG="!F<F$@
M9&ET(&YU=N9R96YD92!K;V1E;W)D(@H*(RP@8RUF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!A;'!H
M86)E=&EC(&-H87)A8W1E<G,N(@IM<V=S='(@(D1I="!N>64@:V]D96]R9"!S
M:V%L(&EN9&5H;VQD92!M:6YD<W0@)60@8F]G<W1A=F5R+B(*"B,L(&,M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@
M;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N(@IM<V=S='(@(D1I
M="!N>64@:V]D96]R9"!S:V%L(&EN9&5H;VQD92!M:6YD<W0@)60@86QF86YU
M;65R:7-K92!T96=N+B(*"B,L(&,M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;&]W97)C87-E(&-H
M87)A8W1E<G,N(@IM<V=S='(@(D1I="!N>64@:V]D96]R9"!S:V%L(&EN9&5H
M;VQD92!M:6YD<W0@)60@<VWE(&)O9W-T879E<BXB"@HC+"!C+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T
M("5D(&YU;65R:6,@8VAA<F%C=&5R<RXB"FUS9W-T<B`B1&ET(&YY92!K;V1E
M;W)D('-K86P@:6YD96AO;&1E(&UI;F1S="`E9"!T86PN(@H*(RP@8RUF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L
M96%S="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`B1&ET(&YY
M92!K;V1E;W)D('-K86P@:6YD96AO;&1E(&UI;F1S="`E9"!S=&]R92!B;V=S
M=&%V97(N(@H*(RP@8RUF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D
M(&UU<W0@8V]N=&%I;B!A="!L97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R
M86-T97)S+B(*;7-G<W1R(")$:70@;GEE(&MO9&5O<F0@;>4@:6MK92!I;F1E
M:&]L9&4@;65R92!E;F0@)60@;65L;&5M<G5M<W1E9VXN(@H*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C
M:&%R86-T97)S+B(*;7-G<W1R(")$:70@;GEE(&MO9&5O<F0@;>4@:6MK92!I
M;F1E:&]L9&4@;65L;&5M<G5M<W1E9VXN(@H*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D<R!D:61N)W0@;6%T8V@B"FUS9W-T<B`B1&ET(&YY92!K;V1E;W)D
M(&5R(&EK:V4@96YS(&D@8F5G9V4@9F5L=&5R(@H*;7-G:60@(G1E;7!N86TH
M*2!F86EL960A(@IM<V=S='(@(G1E;7!N86TH*2!F96IL961E(2(*````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P87-S=V0O<&\O8W-?0UHN<&\`````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W,C<U`#$P-#$W,S8R-S0S`#`Q
M-S<Q-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C($-Z96-H('1R86YS;&%T:6]N<R!F;W(@4&%S<W=D('!A8VMA9V4N"B,@
M0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@
M:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@
M2&]R9&4@<&%C:V%G92X*(R!0879E;"!#:'ET:6P@/'!A=F5L0&-H>71I;"YT
M:SXL(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ(%!A<W-W9%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`T+3$Q
M+3(U(#`Y.C$Y+3`X,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,3$M
M,C4@,#DZ,3DM,#@P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!0879E;"!#:'ET
M:6P@/'!A=F5L0&-H>71I;"YT:SY<;B(*(DQA;F=U86=E+51E86TZ($-Z96-H
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB
M4&QU<F%L+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]/3$@)B8@
M;B4Q,#`A/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@;B4B"B(Q,#P]-"`F)B`H;B4Q
M,#`\,3`@?'P@;B4Q,#`^/3(P*2`_(#$@.B`R*3M<;B(*"B,Z(&QI8B]$<FEV
M97(O8V]M<&]S:71E+G!H<#HU.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@
M=6YA8FQE('1O(&QO860@9')I=F5R.B`E<R(*;7-G<W1R("(E<SH@;F5L>F4@
M<&]UONUT(&1R:79E<B`Z("5S(@H*(SH@;&EB+T1R:79E<B]A9'-I+G!H<#HU
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!1%-)(&5R<F]R("5S+B(*;7-G<W1R
M(")!1%-)(&-H>6)A("5S+B(*"B,Z(&QI8B]$<FEV97(O861S:2YP:'`Z-3<@
M;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z.3<*;7-G:60@(D%C8V5S<R!$96YI
M960N(@IM<V=S='(@(E#X[7-T=7`@6F%M[71N=70N(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z.#`*;7-G:60@(D)A8VME;F0@;F]T(&-O<G)E8W1L>2!I;7!L96UE
M;G1E9"XB"FUS9W-T<B`B0F%C:V5N9"!N96[M('-P<N%V;NP@:6UP;&5M96YT
M;W;A;BXB"@HC.B!M86EN+G!H<#HR,S$@=&5M<&QA=&5S+VUA:6XO;6%I;BYI
M;F,Z,30T"FUS9VED(")#:&%N9V4@4&%S<W=O<F0B"FUS9W-T<B`B6FWL;FET
M($AE<VQO(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,3(Y"FUS9VED
M(")#:&%N9V4@<&%S<W=O<F0@;VXZ(@IM<V=S='(@(EIM[&YI="!H97-L;R!V
M.B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C8T"FUS9VED(")#:&%N
M9V4@>6]U<B!P87-S=V]R9"(*;7-G<W1R("):;>QN:70@5F&Y92!H97-L;R(*
M"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D-H86YG:6YG('!A<W-W;W)D(&]N("5S(@IM<V=S='(@(EIM[&YI
M="!H97-L;R!V("5S(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,3$V
M"FUS9VED(")#;VYF:7)M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B4&]T=G)D
M:70@;F]VZ2!H97-L;SHB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C@V(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,C(S(&QI8B]$<FEV97(O<VUB;&1A<"YP:'`Z
M.#@*(SH@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HQ-C8*;7-G:60@(D-O=6QD
M(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE;'IE('-E(&1O
M;6QU=FET(',@;&1A<"!S97)V97)E;2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z-C(@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HV-0IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3F5L>F4@<V4@
M</AI<&]J:70@;F$@;&1A<"!S97)V97(B"@HC.B!L:6(O1')I=F5R+W-M8G!A
M<W-W9"YP:'`Z-3(*;7-G:60@(D-O=6QD(&YO="!O<&5N('!I<&4@=&\@<VUB
M<&%S<W=D+B(*;7-G<W1R(").96QZ92!O=&5V^.UT(&QI;FMU(&YA('-M8G!A
M<W-W9"XB"@HC.B!L:6(O1')I=F5R+W-M8G!A<W-W9"YP:'`Z-S0*;7-G:60@
M(D5R<F]R('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N(@IM<V=S='(@(DYA
M<W1A;&$@8VAY8F$@</AI('IA<^ULX6[M(&1A="!D;R!S;6)P87-S=V0N(@H*
M(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z.#4*;7-G:60@(D9A:6QE9"!T
M;R!V97)I9GD@;VQD('!A<W-W;W)D+B(*;7-G<W1R(")396QH86QA('9E<FEF
M:6MA8V4@<W1A<NEH;R!H97-L82XB"@HC.B!M86EN+G!H<#HQ.3(@;&EB+T1R
M:79E<B]C;VUP;W-I=&4N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,Z("5S(@IM<V=S='(@
M(EIM[&YA(&AE<VQA('-E;&AA;&$@<')O("5S.B`E<R(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C4Q(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C(T(&QI8B]$<FEV97(O
M<&]P<&%S<V0N<&AP.C$P-@HC.B!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C$V
M-R!L:6(O1')I=F5R+W9M86EL;6=R+G!H<#HS-0IM<V=I9"`B26YC;W)R96-T
M(%!A<W-W;W)D(@IM<V=S='(@(DYE<&QA=&[I($AE<VQO(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HR,#<*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E
M(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B36EN:6WA;&[M(&1O8F$@
M<&QA=&YO<W1I(&AE<VQA(&IEN73L(&YE=GEP<KEE;&$B"@HC.B!T96UP;&%T
M97,O;6%I;B]M86EN+FEN8SHQ,#0*;7-G:60@(DYE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B3F]VZ2!H97-L;SHB"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@<W5C:"!B86-K96YD("<E<R<@9F]U;F0N
M(@IM<V=S='(@(B<E<R<@8F%C:V5N9"!N96)Y;"!N86QE>F5N+B(*"B,Z('1E
M;7!L871E<R]M86EN+VUA:6XN:6YC.CDR"FUS9VED(")/;&0@<&%S<W=O<F0Z
M(@IM<V=S='(@(E-T87+I(&AE<VQO.B(*"B,Z(&QI8B]$<FEV97(O<VUB<&%S
M<W=D+G!H<#HT,@IM<V=I9"`B4&%S<W=D(&ES(&YO="!P<F]P97)L>2!C;VYF
M:6=U<F5D+B(*;7-G<W1R(")087-S=V0@;F5N[2!S<'+A=F[L(&YA:V]N9FEG
M=7)O=N%N+B(*"B,Z(&UA:6XN<&AP.C$X.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")087-S=V]R9"!C:&%N9V5D(&]N("5S+B(*;7-G<W1R(")(97-L;R!Z;>QN
M[&YO('8@)7,N(@H*(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z-C<*;7-G
M:60@(E!A<W-W;W)D(&UO9'5L92!C86XG="!F:6YD('1H92!S=7!P;&EE9"!B
M:6XN(@IM<V=S='(@(E!A<W-W;W)D(&UO9'5L(&YE;F%L97IL('!O<VMY=&YU
M=&]U('-C:'+A;FMU+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S=V0N<&AP.C8U
M"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!R97%U:7)E9"!P
M87)A;65T97)S+B(*;7-G<W1R(")#:'EB[2!P;[YA9&]V86[I('!A<F%M971R
M>2!P<F\@;6]D=6P@4&%S<W=O<F0N(@H*(SH@;&EB+T1R:79E<B]A9'-I+G!H
M<#HT-`IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&ES(&UI<W-I;F<@=&%R9V5T
M('!A<F%M971E<BXB"FUS9W-T<B`B0VAY8NT@8^UL;W;]('!A<F%M971R('!R
M;R!M;V1U;"!087-S=V]R9"XB"@HC.B!M86EN+G!H<#HQ-S`@;&EB+T1R:79E
M<B]S97)V=69T<"YP:'`Z-C8*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N
M;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*;7-G<W1R(")-;V1U;"!087-S=V]R
M9"!N96[M('-P<N%V;NP@:V]N9FEG=7)O=N%N(@H*(SH@;&EB+T1R:79E<B]S
M97)V=69T<"YP:'`Z.3,*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@
M<')O<&5R;'D@8V]N9FEG=7)E9"XB"FUS9W-T<B`B36]D=6P@4&%S<W=O<F0@
M;F5N[2!S<'+A=F[L(&MO;F9I9W5R;W;A;BXB"@HC.B!L:6(O1')I=F5R+V-O
M;7!O<VET92YP:'`Z,S0*;7-G:60@(E)E<75I<F5D("=D<FEV97)S)R!I<R!M
M:7-C;VYF:6=U<F5D(&EN($-O;7!O<VET92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B)0;[YA9&]V86[I("=D<FEV97)Y)R!J<V]U(&YE<W!RX79N["!K
M;VYF:6=U<F]VX6YY('8@2V]M<&]Z:>AN[2!K;VYF:6=U<F%C:2XB"@HC.B!L
M:6(O1')I=F5R+W-Q;"YP:'`Z-#`*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E
M)R!N;W0@<W!E8VEF:65D(&EN(%!A<W-W9"!344P@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B3F5B>6P@>F%DX6X@<&^^861O=F%N_2`G<&AP='EP92<@=B!K
M;VYF:6=U<F%C:2!087-S=V0@4U%,+B(*"B,Z(&QI8B]$<FEV97(O=G!O<&UA
M:6PN<&AP.C0R"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I
M9FEE9"!I;B!344P@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F5B>6P@>F%D
MX6X@<&^^861O=F%N_2`G<&AP='EP92<@=B!K;VYF:6=U<F%C:2!344PN(@H*
M(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z,30U"FUS9VED(")297-E="(*
M;7-G<W1R(")3;6%Z870B"@HC.B!L:6(O1')I=F5R+W-Q;"YP:'`Z-CD@;&EB
M+T1R:79E<B]V<&]P;6%I;"YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET
M(&YA(%-13"!S97)V97(N(@H*(SH@;&EB+T1R:79E<B]P;W!P87-S9"YP:'`Z
M,3`P(&QI8B]$<FEV97(O<W%L+G!H<#HQ,3@*(SH@;&EB+T1R:79E<B]V<&]P
M;6%I;"YP:'`Z,3,U"FUS9VED(")5<V5R(&YO="!F;W5N9"(*;7-G<W1R(")5
MOFEV871E;"!N96)Y;"!N86QE>F5N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HQ,C,@;&EB+T1R:79E<B]P:6YE+G!H<#HR,3D@;&EB+T1R:79E<B]S;6)L
M9&%P+G!H<#HQ,C0*;7-G:60@(E5S97(@;F]T(&9O=6YD+B(*;7-G<W1R(")5
MOFEV871E;"!N96)Y;"!N86QE>F5N+B(*"B,Z('1E;7!L871E<R]M86EN+VUA
M:6XN:6YC.C<Y"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B5;YI=F%T96QS
M:^D@2FWI;F\Z(@H*(SH@;6%I;BYP:'`Z,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<R(*;7-G
M<W1R(").96QZ92!M;V1I9FEK;W9A="!H97-L;R!P<F\@=;YI=F%T96QE("5S
M(@H*(SH@;6%I;BYP:'`Z-#<*;7-G:60@(EEO=2!M=7-T(&=I=F4@>6]U<B!C
M=7)R96YT('!A<W-W;W)D(@IM<V=S='(@(E!R;W/M;2!Z861E:G1E(%9AN64@
M<V]UZ&%S;ND@:&5S;&\B"@HC.B!M86EN+G!H<#HU-@IM<V=I9"`B66]U(&UU
M<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")0<F]S[6T@>F%D
M96IT92!68;EE(&YO=ND@:&5S;&\B"@HC.B!M86EN+G!H<#HV,`IM<V=I9"`B
M66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(DUU
M<^UT92!V97)I9FEK;W9A="!68;EE(&YO=ND@:&5S;&\B"@HC.B!M86EN+G!H
M<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&YE=R!P87-S=V]R
M9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@8F4@;6]R92!T:&%N
M("5D(&-H87)A8W1E<G,@(@HB;&]N9R$B"FUS9W-T<B`B5F&Y92!N;W;I(&AE
M<VQO(&IE('#X[6QIN2!D;&]U:.D[(&AE<VQO(&YE<VWM(&+]="!D96RY[2!N
M9;X@)60@>FYA:_DA(@H*(SH@;6%I;BYP:'`Z,34Y"FUS9VED(")9;W5R(&YE
M=R!P87-S=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H86YG
M960A(@IM<V=S='(@(B(*(E9AN64@;F]VZ2!H97-L;R!J92!P^.UL:;D@:F5D
M;F]D=6-HZ2!K('5HX61N=73M(2`@2&5S;&\@;F5B>6QO('IM[&[L;F\A(@H*
M(SH@;6%I;BYP:'`Z,34P"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!I<R!T
M;V\@<VEM<&QE('1O(&=U97-S+B!.;W0@8VAA;F=E9"$B"FUS9W-T<B`B5F&Y
M92!N;W;I(&AE<VQO(&IE('#X[6QIN2!J961N;V1U8VCI(&L@=6CA9&YU=.TN
M($AE<VQO(&YE8GEL;R!Z;>QN[&YO(2(*"B,Z(&UA:6XN<&AP.C<U"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@870@
M;&5A<W0@)60@8VAA<F%C=&5R<R!L;VYG(2(*;7-G<W1R(")68;EE(&YO=ND@
M:&5S;&\@;75S[2!B_70@86QE<W!O\B`E9"!Z;F%K^2!D;&]U:.DA(@H*(SH@
M;6%I;BYP:'`Z-C@*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@
M9&EF9F5R96YT(&9R;VT@>6]U<B!C=7)R96YT('!A<W-W;W)D(@IM<V=S='(@
M(E9AN64@;F]VZ2!H97-L;R!M=7/M(&+]="!J:6[I(&YEOB!68;EE('-T87+I
M(&AE<VQO(@H*(SH@;6%I;BYP:'`Z,3(P"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!A
M;'!H86)E=&EC(&-H87)A8W1E<G,N(@IM<V=S='(@(E9AN64@;F]VZ2!H97-L
M;R!M=7/M(&]B<V%H;W9A="!A;&5S<&_R("5D('!I<VUE;BXB"@HC.B!M86EN
M+G!H<#HQ,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA;G5M97)I8R!C:&%R
M86-T97)S+B(*;7-G<W1R(")68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V
M870@86QE<W!O\B`E9"!A;&9A;G5M97)I8VO]8V@@>FYA:_DN(@H*(SH@;6%I
M;BYP:'`Z,3,P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!D:69F97)E;G0@='EP
M97,@;V8@8VAA<F%C=&5R<RX@(@HB5&AE('1Y<&5S(&%R93H@;&]W97(L('5P
M<&5R+"!N=6UE<FEC+"!A;F0@<WEM8F]L<RXB"FUS9W-T<B`B(@HB5F&Y92!N
M;W;I(&AE<VQO(&UU<^T@;V)S86AO=F%T(&%L97-P;_(@)60@<OEZ;OUC:"!T
M>7#Y('IN86OY+B!4>7!Y(&IS;W4Z("(*(FUA;.DL('9E;&OI('#M<VUE;F$L
M(.CM<VQI8V4@82!R^7INZ2!Z;F%K>2XB"@HC.B!M86EN+G!H<#HQ,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT
M86EN(&%T(&QE87-T("5D(&QO=V5R8V%S92!C:&%R86-T97)S+B(*;7-G<W1R
M(")68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V870@86QE<W!O\B`E9"!M
M86S]8V@@<.US;65N+B(*"B,Z(&UA:6XN<&AP.C$Q-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@;G5M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R(")68;EE(&YO=ND@
M:&5S;&\@;75S[2!O8G-A:&]V870@86QE<W!O\B`E9"#H[7-L:6,N(@H*(SH@
M;6%I;BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@8VAA
M<F%C=&5R<RXB"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO(&UU<^T@;V)S86AO
M=F%T(&%L97-P;_(@)60@=F5L:_UC:"!P[7-M96XN(@H*(SH@;6%I;BYP:'`Z
M,3,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!L97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T97)S
M+B(*;7-G<W1R(")68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V870@86QE
M<W!O\B`E9"!M97IE<BXB"@HC.B!M86EN+G!H<#HQ,S@*;7-G:60@(EEO=7(@
M;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C:&%R
M86-T97)S+B(*;7-G<W1R(")68;EE(&YO=ND@:&5S;&\@;F5S;>T@;V)S86AO
M=F%T(&UE>F5R>2XB"@HC.B!M86EN+G!H<#HV-`IM<V=I9"`B66]U<B!N97<@
M<&%S<W=O<F1S(&1I9&XG="!M871C:"(*;7-G<W1R(")68;EE(&YO=ND@:&5S
M;&$@<V4@;F5S:&]D=6KM(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HV."!L
M:6(O1')I=F5R+W-M8FQD87`N<&AP.C<Q"FUS9VED(")L9&%P7W-T87)T7W1L
M<R!F86EL960B"FUS9W-T<B`B;&1A<%]S=&%R=%]T;',@<V5L:&%L(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+W!O+W!T7T)2
M+G!O````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-30P-@`Q,#0Q-S,V,C<T,P`P,3<W,3(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(R!0;W)T=6=U97-E+4)R87II;"!T<F%N
M<VQA=&EO;B!F;W(@2&]R9&4@4&%S<W=D+@HC($-O<'ER:6=H="`H0RD@645!
M4B!&<F5E(%-O9G1W87)E($9O=6YD871I;VXL($EN8RX*(R!$87)C:2!!;G1O
M;FEO(%1A<G1A<FD@/&1T87)T87)I0'!O<G1O<FEO9W)A;F1E+F-O;2YB<CXL
M(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#(N,2!087-S=V1<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`R+3`U+3`S(#$T.C`Y+3`S,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#(M,#4M,#,@,30Z,#DM,#,P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!$87)C
M:2!!;G1O;FEO(%1A<G1A<FD@/&1T87)T87)I0'!O<G1O<FEO9W)A;F1E+F-O
M;2YB<CY<;B(*(DQA;F=U86=E+51E86TZ(%!O<G1U9W5E<V4M0G)A>FEL(#Q,
M3$!L:2YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@IM<V=I9"`B0VAA;F=E
M('EO=7(@<&%S<W=O<F0B"FUS9W-T<B`B36]D:69I<75E('-U82!S96YH82(*
M"FUS9VED(")#;VYF:7)M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B0V]N9FER
M;64@<W5A('-E;FAA(&YO=F$Z(@H*;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R
M<F\B"@IM<V=I9"`B1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"`Z("(*
M;7-G<W1R(")/8V]R<F5U('5M82!F86QH82!A;R!M;V1I9FEC87(@<W5A('-E
M;FAA(#HB"@IM<V=I9"`B2&5L<"(*;7-G<W1R(")!:G5D82(*"FUS9VED("))
M;G1E<FYA;"!%<G)O<B(*;7-G<W1R(")%<G)O($EN=&5R;F\B"@IM<V=I9"`B
M3&]G;W5T(@IM<V=S='(@(E-A:61A(@H*;7-G:60@(DUE<W-A9V4B"FUS9W-T
M<B`B365N<W-A9V5M(@H*;7-G:60@(DYE=R!P87-S=V]R9#HB"FUS9W-T<B`B
M4V5N:&$@;F]V83HB"@IM<V=I9"`B(@HB3F]T93H@66]U('=I;&P@;F5E9"!T
M;R!L;V=O=70@86YD(&)A8VL@:6X@869T97(@>6]U(&-H86YG92!Y;W5R('!A
M<W-W;W)D(2(*;7-G<W1R(")!=FES;SH@5F]CZB!D979E<N$@<V%I<B!E(')E
M=&]R;F%R(&%P\W,@82!M=61A;N=A(&1A('-U82!S96YH82$B"@IM<V=I9"`B
M3VQD('!A<W-W;W)D.B(*;7-G<W1R(")396YH82!A;G1I9V$Z(@H*;7-G:60@
M(E!A<W-W;W)D(&-H86YG960A(@IM<V=S='(@(E-E;FAA(&UO9&EF:6-A9&$A
M(@H*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N
M9FEG=7)E9"(*;7-G<W1R(")/(&WS9'5L;R!D92!S96YH82!NXV\@97-TX2!C
M;VYF:6=U<F%D;R!C;W)R971A;65N=&4B"@IM<V=I9"`B4')O8FQE;3\B"FUS
M9W-T<B`B4')O8FQE;6$_(@H*;7-G:60@(E)E<V5T(@IM<V=S='(@(DQI;7!A
M<B(*"FUS9VED(")3;VUE(&]F(%!A<W-W;W)D(&UO9'5L92=S(&-O;F9I9W5R
M871I;VX@9FEL97,@87)E(&UI<W-I;F<Z(@IM<V=S='(@(D%L9W5N<R!A<G%U
M:79O<R!D;R!M\V1U;&\@4V5N:&$@;N-O(&9O<F%M(&5N8V]N=')A9&]S(@H*
M;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5C97-S;R(*"FUS9VED("(B"B)4
M:&ES(&9I;&4@8V]N=')O;',@=&AE(&1E9F%U;'0@<')E9F5R96YC97,@9F]R
M(%!A<W-W;W)D(&UO9'5L92P@86YD(&%L<V\@(@HB8V]N=')O;',@=VAI8V@@
M<')E9F5R96YC97,@=7-E<G,@8V%N(&%L=&5R+B(*;7-G<W1R("(B"B)%<W1E
M(&%R<75I=F\@8V]N=')O;&$@87,@<')E9F5RZFYC:6%S('!A9'+C;R!P87)A
M(&\@;?-D=6QO(&1E(%-E;FAA(&4@=&%M8NEM("(*(F-O;G1R;VQA('%U86ES
M('!R969E<NIN8VEA<R!O('5S=>%R:6\@<&]D92!M;V1I9FEC87(B"@IM<V=I
M9"`B(@HB5&AI<R!F:6QE(&-O;G1R;VQS('1H92!S='EL97-H965T('1H870@
M:7,@=7-E9"!T;R!S970@8V]L;W)S(&%N9"!F;VYT<R!I;B`B"B)A9&1I=&EO
M;B!T;R!O<B!O=F5R<FED:6YG($AO<F1E(&1E9F%U;'1S+B(*;7-G<W1R("(B
M"B)%<W1E(&%R<75I=F\@8V]N=')O;&$@;R!E<W1I;&\@=71I;&EZ861O('!A
M<F$@9&5F:6YI<B!C;W)E<R!E(&9O;G1E<R!E;2`B"B)C;VUP;&5M96YT;R!O
M=2!S;V)R965S8W)E=F5N9&\@;R!E<W1I;&\@<&%D<N-O(&1O($AO<F1E(@H*
M;7-G:60@(B(*(E1H:7,@:7,@=&AE(&UA:6X@4&%S<W=O<F0@;6]D=6QE(&-O
M;F9I9W5R871I;VX@9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD("(*(F]P
M=&EO;G,@9F]R(&%L;"!087-S=V]R9"!M;V1U;&4@<V-R:7!T<RXB"FUS9W-T
M<B`B17-T92#I(&\@87)Q=6EV;R!P<FEN8VEP86P@9&4@8V]N9FEG=7)AY^-O
M(&1O(&WS9'5L;R!D92!S96YH82(*"FUS9VED(")787)N:6YG(@IM<V=S='(@
M(D%T96[GXV\B"@HC+"!C+69O<FUA=`IM<V=I9"`B66]U(&-A;B=T(&-H86YG
M92!P87-S=V]R9"!F;W(@=7-E<B`E<R(*;7-G<W1R(")6;V/J(&[C;R!P;V1E
M(&UU9&%R(&$@<V5N:&$@<&%R82!O('5S=>%R:6\@)7,B"@IM<V=I9"`B66]U
M(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R(")6;V/J(&1E
M=F4@9F]R;F5C97(@<W5A('-E;FAA(&YO=F$B"@IM<V=I9"`B66]U(&UU<W0@
M9VEV92!Y;W5R(&]L9"!P87-S=V]R9"(*;7-G<W1R(")6;V/J(&1E=F4@9F]R
M;F5C97(@<W5A('-E;FAA(&%N=&EG82(*"FUS9VED(")9;W4@;75S="!V97)I
M9GD@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`B5F]CZB!D979E(&-O;F9I
M<FUA<B!S=6$@<V5N:&$@;F]V82(*"FUS9VED(")9;W5R(&YE=R!P87-S=V]R
M9',@9&ED;B=T(&UA=&-H(@IM<V=S='(@(E-U82!S96YH82!N;W9A(&[C;R!C
M;VUB:6YA(@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P87-S=V0O<&\O<W9?4T4N<&\`````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-34Q`#$P-#$W,S8R-S0S
M`#`Q-S<R-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C(%!A<W-W9"!M;V1U;&4@=')A;G-L871I;VYS+@HC($-O<'ER:6=H
M="`H0RD@645!4B!&<F5E(%-O9G1W87)E($9O=6YD871I;VXL($EN8RX*(R!-
M871T:6%S(%=E8FKV<FX@17)I:W-S;VX@/&UA='1I87-`=V5B:F]R;CXL(#(P
M,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M('!A<W-W9%QN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#(M,#8M,38@,C,Z
M,S(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP-BTQ-2`P,SHQ
M,RLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($UA='1I87,@5V5B:O9R;B!%
M<FEK<W-O;B`\;6%T=&EA<T!W96)J;W)N/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M4W=E9&ES:"`\4T5`;&DN;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*
M(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ
M7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*;7-G
M:60@(D-H86YG92!Y;W5R('!A<W-W;W)D(@IM<V=S='(@(D)Y="!L]G-E;F]R
M9"(*"FUS9VED(")#;VYF:7)M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B0F5K
M<N1F=&$@9&ET="!L]G-E;F]R9#HB"@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@;&1A<"!S97)V97(@87,@9W5E<W0B"FUS9W-T<B`B2W5N9&4@:6YT92!B
M:6YD82!T:6QL(&QD87`@<V5R=F5R;B!S;VT@9^1S="(*"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")+=6YD92!I
M;G1E(&%N<VQU=&$@=&EL;"!L9&%P('-E<G9E<FXB"@IM<V=I9"`B1F%I;'5R
M92!I;B!C:&%N9VEN9R!P87-S=V]R9"`Z("(*;7-G<W1R(")-:7-S;'EC:V%D
M97,@;65D(&%T="#D;F1R82!L]G-E;F]R9"`Z("(*"FUS9VED(")(96QP(@IM
M<V=S='(@(DAJY&QP(@H*;7-G:60@(DEN=&5R;F%L($5R<F]R(@IM<V=S='(@
M(DEN=&5R;G0@9F5L(@H*;7-G:60@(DQO9V]U="(*;7-G<W1R("),;V=G82!U
M="(*"FUS9VED(").97<@<&%S<W=O<F0Z(@IM<V=S='(@(DYY='0@;/9S96YO
M<F0Z(@H*;7-G:60@(B(*(DYO=&4Z(%EO=2!W:6QL(&YE960@=&\@;&]G;W5T
M(&%N9"!B86-K(&EN(&%F=&5R('EO=2!C:&%N9V4@>6]U<B!P87-S=V]R9"$B
M"FUS9W-T<B`B3T)3(2!$=2!MY7-T92!L;V=G82!U="!D:7)E:W0@969T97(@
M871T(&1U(&AA<B!B>70@;/9S96YO<F0A(@H*;7-G:60@(D]L9"!P87-S=V]R
M9#HB"FUS9W-T<B`B1V%M;6%L="!L]G-E;F]R9#HB"@IM<V=I9"`B4&%S<W=O
M<F0@8VAA;F=E9"$B"FUS9W-T<B`B3/9S96YO<F1E="#D;F1R861E<R$B"@IM
M<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U
M<F5D(@IM<V=S='(@(DSV<V5N;W)D<VUO9'5L96X@Y'(@:6YT92!C;W)R96-T
M(&MO;F9I9W5R97)A9"(*"FUS9VED(")0<F]B;&5M/R(*;7-G<W1R(")0<F]B
M;&5M/R(*"FUS9VED(")297-E="(*;7-G<W1R("+%=&5R<W3D;&PB"@IM<V=I
M9"`B4V]M92!O9B!087-S=V]R9"!M;V1U;&4G<R!C;VYF:6=U<F%T:6]N(&9I
M;&5S(&%R92!M:7-S:6YG.B(*;7-G<W1R(").Y6=R82!A=B!L]G-E;F]R9'-M
M;V1U;&5N<R!K;VYF:6=U<F%T:6]N<R!F:6QE<B!S86MN87,B"@IM<V=I9"`B
M(@HB5&AI<R!F:6QE(&-O;G1R;VQS('1H92!D969A=6QT('!R969E<F5N8V5S
M(&9O<B!087-S=V]R9"!M;V1U;&4L(&%N9"!A;'-O("(*(F-O;G1R;VQS('=H
M:6-H('!R969E<F5N8V5S('5S97)S(&-A;B!A;'1E<BXB"FUS9W-T<B`B(@HB
M1&5N;F$@9FEL(&AA;G1E<F%R('-T86YD87)D(&EN<W3D;&QN:6YG87)N82!F
M]G(@;/9S96YO<F1S;6]D=6QE;BP@<V%M="!V:6QK82`B"B)I;G-TY&QL;FEN
M9V%R('-O;2!A;G;D;F1A<FYA(&MA;B#D;F1R82(*"FUS9VED("(B"B)4:&ES
M(&9I;&4@8V]N=')O;',@=&AE('-T>6QE<VAE970@=&AA="!I<R!U<V5D('1O
M('-E="!C;VQO<G,@86YD(&9O;G1S(&EN("(*(F%D9&ET:6]N('1O(&]R(&]V
M97)R:61I;F<@2&]R9&4@9&5F875L=',N(@IM<V=S='(@(B(*(D1E;B!HY'(@
M9FEL96X@:&%N=&5R87(@<W1Y;&5S:&5E=',L('9I;&ME="!A;G;D;F1S(&;V
M<B!FY')G97(@;V-H(&9O;G1E<BP@(@HB=73V=F5R(&1E('-T86YD87)D(';D
M<F1E;B!F<N5N($AO<F1E;6]D=6QE;B(*"FUS9VED("(B"B)4:&ES(&ES('1H
M92!M86EN(%!A<W-W;W)D(&UO9'5L92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET
M(&-O;G1A:6YS('!A=&AS(&%N9"`B"B)O<'1I;VYS(&9O<B!A;&P@4&%S<W=O
M<F0@;6]D=6QE('-C<FEP=',N(@IM<V=S='(@(B(*(D1E="!HY'(@Y'(@:'5V
M=61K;VYF:6=U<F%T:6]N<V9I;&5N(&;V<B!L]G-E;F]R9'-M;V1U;&5N+B!$
M96X@:6YN96CE;&QE<B!V86P@(@HB9O9R(&%L;&$@<VMR:7!T+B(*"B,L(&,M
M9F]R;6%T"FUS9VED(")9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O<B!U
M<V5R("5S(@IM<V=S='(@(D1U(&MA;B!I;G1E(.1N9')A(&SV<V5N;W)D(&;V
M<B!A;G;D;F1A<F4@)7,B"@IM<V=I9"`B66]U(&UU<W0@9VEV92!Y;W5R(&YE
M=R!P87-S=V]R9"(*;7-G<W1R(")$=2!MY7-T92!A;F=E(&1I='0@;GEA(&SV
M<V5N;W)D(@H*;7-G:60@(EEO=2!M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O
M<F0B"FUS9W-T<B`B1'4@;>5S=&4@86YG92!D:71T(&=A;6QA(&SV<V5N;W)D
M(@H*;7-G:60@(EEO=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9"(*
M;7-G<W1R(")$=2!MY7-T92!V97)I9FEE<F$@9&ET="!N>6$@;/9S96YO<F0B
M"@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:"(*;7-G
M<W1R(")$:71T(&YY82!L]G-E;F]R9"!V97)I9FEE<F%D97,@:6YT92!K;W)R
M96MT(@H*;7-G:60@(EEO=7(@;VQD('!A<W-W;W)D(&ES;B=T(&-O<G)E8W0B
M"FUS9W-T<B`B1&ET="!G86UL82!L]G-E;F]R9"#D<B!I;G1E(&MO<G)E:W0B
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A
M<W-W9"]P;R]P87-S=V0N<&]T````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3,V-3<`,3`T,3<S-C(W-#,`,#(P-#`P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@4T]-12!$15-#
M4DE05$E612!4251,12X*(R!#;W!Y<FEG:'0@*$,I(%E%05(@2&]R9&4@4')O
M:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M
M92!L:6-E;G-E(&%S('1H92!004-+04=%('!A8VMA9V4N"B,@1DE24U0@0554
M2$]2(#Q%34%)3$!!1$1215-3/BP@645!4BX*(PHC+"!F=7IZ>0IM<V=I9"`B
M(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@4$%#2T%'12!615)3
M24].7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,#D@,38Z-3$K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@645!4BU-3RU$02!(3SI-22M:
M3TY%7&XB"B),87-T+51R86YS;&%T;W(Z($953$P@3D%-12`\14U!24Q`041$
M4D534SY<;B(*(DQA;F=U86=E+51E86TZ($Q!3D=504=%(#Q,3$!L:2YO<F<^
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/4-(05)3151<;B(*(D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]$<FEV97(O97AP96-T+G!H<#HS
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!E>&ES="!O<B!I
M<R!N;W0@97AE8W5T86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]C
M;VUP;W-I=&4N<&AP.C8U"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B!U;F%B
M;&4@=&\@;&]A9"!D<FEV97(Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV
M97(O861S:2YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B041322!E<G)O
M<B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z
M,3`U(&QI8B]$<FEV97(O861S:2YP:'`Z-C0*;7-G:60@(D%C8V5S<R!$96YI
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C@U"FUS9VED(")"
M86-K96YD(&YO="!C;W)R96-T;'D@:6UP;&5M96YT960N(@IM<V=S='(@(B(*
M"B,Z(&UA:6XN<&AP.C(U-2!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ-#(*
M;7-G:60@(D-H86YG92!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;B]M86EN+FEN8SHQ,C<*;7-G:60@(D-H86YG92!P87-S=V]R9"!O
M;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z-C(*
M;7-G:60@(D-H86YG92!Y;W5R('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EN+VUA:6XN:6YC.C8Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-H86YG:6YG('!A<W-W;W)D(&]N("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN+VUA:6XN:6YC.C$Q-`IM<V=I9"`B0V]N9FER;2!N97<@<&%S
M<W=O<F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z.34@
M;&EB+T1R:79E<B]L9&%P+G!H<#HR-C,@;&EB+T1R:79E<B]K;VQA8BYP:'`Z
M-30*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S`@;&EB+T1R:79E<B]K
M;VQA8BYP:'`Z-#8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@
M<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H
M<#HU-PIM<V=I9"`B0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HW.0IM
M<V=I9"`B17)R;W(@<V5N9&EN9R!D871A('1O('-M8G!A<W-W9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z.3,*;7-G:60@(D9A
M:6QE9"!T;R!V97)I9GD@;VQD('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!M
M86EN+G!H<#HR,3$@;&EB+T1R:79E<B]C;VUP;W-I=&4N<&AP.CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@
M;VX@)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C4V(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,C8T(&QI8B]$<FEV97(O=FUA:6QM9W(N<&AP
M.C0R"B,Z(&QI8B]$<FEV97(O:V]L86(N<&AP.C<X(&QI8B]$<FEV97(O<&]P
M<&%S<V0N<&AP.C$Q-`IM<V=I9"`B26YC;W)R96-T(%!A<W-W;W)D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C4U"FUS9VED(")-:6YI
M;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$P,@IM<V=I9"`B3F5W
M('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<W5C:"!B86-K96YD(%PB)7-<(B!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z
M.3`*;7-G:60@(D]L9"!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<B]S;6)P87-S=V0N<&AP.C0W"FUS9VED(")087-S=V0@:7,@;F]T('!R
M;W!E<FQY(&-O;F9I9W5R960N(@IM<V=S='(@(B(*"B,Z(&UA:6XN<&AP.C(P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")087-S=V]R9"!C:&%N9V5D(&]N("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+W!S<&%S<W=D+G!H<#HW-0IM
M<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&-A;B=T(&9I;F0@=&AE('-U<'!L:65D
M(&)I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z
M-S,*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG(')E<75I<F5D
M('!A<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O861S:2YP
M:'`Z-3$*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG('1A<F=E
M="!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&UA:6XN<&AP.C$W."!L:6(O
M1')I=F5R+W-E<G9U9G1P+G!H<#HW,0IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE
M(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D(@IM<V=S='(@(B(*"B,Z(&QI
M8B]$<FEV97(O<V5R=G5F='`N<&AP.CDX"FUS9VED(")087-S=V]R9"!M;V1U
M;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C$Q"FUS9VED(")0;&5A<V4@<')O
M=FED92!A(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;B]M86EN+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R(&-U
M<G)E;G0@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6XO
M;6%I;BYI;F,Z,34*;7-G:60@(E!L96%S92!V97)I9GD@>6]U<B!N97<@<&%S
M<W=O<F0B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]C;VUP;W-I=&4N<&AP
M.C0Q"FUS9VED(")297%U:7)E9"`G9')I=F5R<R<@:7,@;6ES8V]N9FEG=7)E
M9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T1R:79E<B]S<6PN<&AP.C0V"FUS9VED(")297%U:7)E9"`G<&AP='EP
M92<@;F]T('-P96-I9FEE9"!I;B!087-S=V0@4U%,(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O=G!O<&UA:6PN<&AP.C0Y"FUS
M9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!344P@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6XO
M;6%I;BYI;F,Z,30S"FUS9VED(")297-E="(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+W-Q;"YP:'`Z-S4@;&EB+T1R:79E<B]V<&]P;6%I;"YP:'`Z.#,*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H<#HQ,C4@;&EB+T1R:79E<B]P
M;W!P87-S9"YP:'`Z,3`X"B,Z(&QI8B]$<FEV97(O=G!O<&UA:6PN<&AP.C$T
M,PIM<V=I9"`B57-E<B!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HQ,S$@;&EB+T1R:79E<B]K;VQA8BYP:'`Z-S`@;&EB
M+T1R:79E<B]P:6YE+G!H<#HR,S$*;7-G:60@(E5S97(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHW-PIM<V=I
M9"`B57-E<FYA;64Z(@IM<V=S='(@(B(*"B,Z(&UA:6XN<&AP.C0W"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!C86XG="!C:&%N9V4@<&%S<W=O<F0@9F]R
M('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@;6%I;BYP:'`Z-34*;7-G:60@(EEO
M=2!M=7-T(&=I=F4@>6]U<B!C=7)R96YT('!A<W-W;W)D(@IM<V=S='(@(B(*
M"B,Z(&UA:6XN<&AP.C8T"FUS9VED(")9;W4@;75S="!G:79E('EO=7(@;F5W
M('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&UA:6XN<&AP.C8X"FUS9VED(")9
M;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*
M(SH@;6%I;BYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!N
M97<@<&%S<W=O<F0@:7,@=&]O(&QO;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E
M(&UO<F4@=&AA;B`E9"!C:&%R86-T97)S("(*(FQO;F<A(@IM<V=S='(@(B(*
M"B,Z(&UA:6XN<&AP.C$V-PIM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@:7,@
M=&]O('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N9V5D(2(*;7-G<W1R("(B
M"@HC.B!M86EN+G!H<#HQ-3@*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES
M('1O;R!S:6UP;&4@=&\@9W5E<W,N($YO="!C:&%N9V5D(2(*;7-G<W1R("(B
M"@HC.B!M86EN+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE
M=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@;&]N
M9R$B"FUS9W-T<B`B(@H*(SH@;6%I;BYP:'`Z-S8*;7-G:60@(EEO=7(@;F5W
M('!A<W-W;W)D(&UU<W0@8F4@9&EF9F5R96YT(&9R;VT@>6]U<B!C=7)R96YT
M('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&UA:6XN<&AP.C$R.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@
M870@;&5A<W0@)60@86QP:&%B971I8R!C:&%R86-T97)S+B(*;7-G<W1R("(B
M"@HC.B!M86EN+G!H<#HQ,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N
M97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA;G5M
M97)I8R!C:&%R86-T97)S+B(*;7-G<W1R("(B"@HC.B!M86EN+G!H<#HQ,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!N97<@<&%S<W=O<F0@;75S
M="!C;VYT86EN(&%T(&QE87-T("5D(&1I9F9E<F5N="!T>7!E<R!O9B!C:&%R
M86-T97)S+B`B"B)4:&4@='EP97,@87)E.B!L;W=E<BP@=7!P97(L(&YU;65R
M:6,L(&%N9"!S>6UB;VQS+B(*;7-G<W1R("(B"@HC.B!M86EN+G!H<#HQ,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@;75S="!C
M;VYT86EN(&%T(&QE87-T("5D(&QO=V5R8V%S92!C:&%R86-T97)S+B(*;7-G
M<W1R("(B"@HC.B!M86EN+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&YU
M;65R:6,@8VAA<F%C=&5R<RXB"FUS9W-T<B`B(@H*(SH@;6%I;BYP:'`Z,3$S
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@
M8V]N=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RXB"FUS
M9W-T<B`B(@H*(SH@;6%I;BYP:'`Z,30T"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!L97-S('1H86X@)60@
M=VAI=&5S<&%C92!C:&%R86-T97)S+B(*;7-G<W1R("(B"@HC.B!M86EN+G!H
M<#HQ-#8*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A
M:6X@=VAI=&5S<&%C92!C:&%R86-T97)S+B(*;7-G<W1R("(B"@HC.B!M86EN
M+G!H<#HW,@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C
M:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;B]M86EN+FEN8SHQ.0IM
M<V=I9"`B66]U<B!P87-S=V]R9',@9&\@;F]T(&UA=&-H(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S8*;7-G:60@(FQD87!?<W1A<G1?
M=&QS(&9A:6QE9"(*;7-G<W1R("(B"@``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D
M+W!O+V9A7TE2+G!O````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R,S0V,``Q,#0Q-S,V,C<T,P`P,3<V-C0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!097)S:6%N('1R86YS
M;&%T:6]N<R!F;W(@4&%S<W=D('!A8VMA9V4N"B,@5&AI<R!F:6QE(&ES(&1I
M<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(%!A<W-W
M9"!P86-K86=E+@HC(`HC($-O<'ER:6=H="`H0RD@,C`P-"!(:6=H($-O;F-I
M;"!O9B!);F9O<FUA=&EC<R`H=W=W+G-H8VDN:7(I"B,@4')O=FED960@8GD@
M($%M:7)K86)I<B!-971A;F5T=V]R:VEN9R!,=&0L(#(P,#0@/&AO<F1E0&UE
M=&%N971W;W)K:6YG+F-O;3X*(R!-;VAS96X@3F%D97(M0F%D<B`@("`@("`\
M;F%D97)I0&UE=&%N971W;W)K:6YG+F-O;3X*(R!#:&%K86UE:"!-;W)T97IA
M;FEA("`@("`\;6]R=&5Z86YI84!M971A;F5T=V]R:VEN9RYC;VT^"B,@4V%L
M;6%N($YI:W-E9F%T("`@("`@("`@/&YI:W-E9F%T0&UE=&%N971W;W)K:6YG
M+F-O;3X*(R!H86UE9"!':&5Y8FET("`@("`@("`@("`\9VAE>6)I0&UE=&%N
M971W;W)K:6YG+F-O;3X*(R!686AI9"!':&%F87)P;W5R("`@("`@("`\9VAA
M9F%R<&]U<D!M971A;F5T=V]R:VEN9RYC;VT^"B,@6F%H<F$@06AM861I($9I
M<F]U>FIA964@/&%H;6%D:4!M971A;F5T=V]R:VEN9RYC;VT^"B,@"FUS9VED
M("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!087-S=V0@,R!!
M3%!(05QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3`W+3$T(#$Q.C0X
M*S`T,S!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#<M,#@@,3(Z-#4K
M,#0S,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!!;6ER:V%B:7(@365T86YE='=O
M<FMI;F<@;'1D+B`\<&5R<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RXB"B)C
M;VT^7&XB"B),86YG=6%G92U496%M.B!097)S:6%N(#QI,3AN0&QI<W1S+FAO
M<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]551&+3A<;B(*(D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]$<FEV97(O97AP96-T
M+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!E>&ES
M="!O<B!I<R!N;W0@97AE8W5T86)L92XB"FUS9W-T<B`B)7,@V879B-BLV8C8
MKR#9AMN,V+/8JB#9B"#;C-BG(-F"V*?8J-F$(-BGV*S8L=BG(-F&VXS8L]BJ
M(@H*(SH@;&EB+T1R:79E<B]C;VUP;W-I=&4N<&AP.C4Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S.B!U;F%B;&4@=&\@;&]A9"!D<FEV97(Z("5S(@IM<V=S
M='(@(B5S.B#9AMF%VXSB@(S8JMF(V*?9AB#8L=BGV8?B@(S8I]F&V*_8I]BR
M(-BQV*<@V*C8I]BQVJG8L=BO.B`E<R(*"B,Z(&QI8B]$<FEV97(O861S:2YP
M:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B041322!E<G)O<B`E<RXB"FUS
M9W-T<B`BV*[8M]BGVXP@041322`E<RXB"@HC.B!L:6(O1')I=F5R+W!S<&%S
M<W=D+G!H<#HY-R!L:6(O1')I=F5R+V%D<VDN<&AP.C4W"FUS9VED(")!8V-E
M<W,@1&5N:65D+B(*;7-G<W1R("+8N=BOV84@V*?8K-BGV++9A]F4(-BOV+/8
MJMBQV+/;C"XB"@HC.B!L:6(O1')I=F5R+G!H<#HX,`IM<V=I9"`B0F%C:V5N
M9"!N;W0@8V]R<F5C=&QY(&EM<&QE;65N=&5D+B(*;7-G<W1R("+9OMBTV*K;
MC-BHV*?9AB#8J-F'(-BOV+'8L]BJVXP@V;[;C-BGV*_9A^*`C-BSV*?8LMN,
M(-F&V+38K]F'XH",V*?8L]BJ+B(*"B,Z(&UA:6XN<&AP.C(T-"!T96UP;&%T
M97,O;6%I;B]M86EN+FEN8SHQ-#0*;7-G:60@(D-H86YG92!087-S=V]R9"(*
M;7-G<W1R("+8JMBZVXS;C-BQ(-BGV+/9A2#8L=F%V+(B"@HC.B!T96UP;&%T
M97,O;6%I;B]M86EN+FEN8SHQ,CD*;7-G:60@(D-H86YG92!P87-S=V]R9"!O
M;CHB"FUS9W-T<B`BV*K8NMN,VXS8L2#8I]BSV84@V+'9A=BR(-BHV+$@V+'9
MB-N,.B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.C8T"FUS9VED(")#
M:&%N9V4@>6]U<B!P87-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BN
MV8C8KR#8L=BG(-BJV+K;C-N,V+$@V*_9A]N,V*\B"@HC.B!T96UP;&%T97,O
M;6%I;B]M86EN+FEN8SHW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#:&%N9VEN
M9R!P87-S=V]R9"!O;B`E<R(*;7-G<W1R("+8JMBZVXS;C-BQ(-BGV+/9A2#8
ML=F%V+(@V*C8L2#8L=F(VXP@)7,B"@HC.B!T96UP;&%T97,O;6%I;B]M86EN
M+FEN8SHQ,38*;7-G:60@(D-O;F9I<FT@;F5W('!A<W-W;W)D.B(*;7-G<W1R
M("+8JMBCVXS;C-BO(-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\Z(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HY,R!L:6(O1')I=F5R+VQD87`N<&AP.C(T,"!L
M:6(O1')I=F5R+VMO;&%B+G!H<#HT.`HC.B!L:6(O1')I=F5R+W-M8FQD87`N
M<&AP.CDP(&QI8B]$<FEV97(O<VUB;&1A<"YP:'`Z,3<Q"FUS9VED(")#;W5L
M9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!L9&%P(-F^VXS9B-BSV*HB"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C8T(&QI8B]$<FEV97(O:V]L86(N<&AP
M.C0P(&QI8B]$<FEV97(O<VUB;&1A<"YP:'`Z-C<*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR(&QD87`@V878JMBUV80@V+38KR(*
M"B,Z(&QI8B]$<FEV97(O<VUB<&%S<W=D+G!H<#HU,PIM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-BQV*?9A]N,(-BHV8<@<VUB<&%S<W=D(-BHV*?8LB#:J=BQ
MV*\N(@H*(R`*(SH@;&EB+T1R:79E<B]S;6)P87-S=V0N<&AP.C<U"FUS9VED
M(")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+B(*;7-G<W1R("+8
MKMBWV*<@V*_8L2#8I]BQV+/8I]F$(-BOV*?8K]F'(-BHV8<@<VUB<&%S<W=D
M+B(*"B,Z(&QI8B]$<FEV97(O<'-P87-S=V0N<&AP.C@U"FUS9VED(")&86EL
M960@=&\@=F5R:69Y(&]L9"!P87-S=V]R9"XB"FUS9W-T<B`BV*C8I]BRV*C;
MC-F&VXP@V*?8L]F%(-BQV878LB#9@MBOVXS9A=N,(-F&V*?9A=F(V8'9D=F"
M(-BHV8C8KRXB"@HC.B!M86EN+G!H<#HR,#4@;&EB+T1R:79E<B]C;VUP;W-I
M=&4N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QU<F4@:6X@8VAA
M;F=I;F<@<&%S<W=O<F0@;VX@)7,Z("5S(@IM<V=S='(@(MBYV*_9A2#9A=F(
MV8'9D=F"VXS9D=BJ(-BOV+$@V*K8NMN,VXS8L2#8I]BSV84@V+'9A=BR(-BH
MV+$@)7,@.B`E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C4Q(&QI8B]$<FEV97(O
M=FUA:6QM9W(N<&AP.C,U(&QI8B]$<FEV97(O<&]P<&%S<V0N<&AP.C$P.0HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C(T,2!L:6(O1')I=F5R+VMO;&%B+G!H
M<#HW,B!L:6(O1')I=F5R+W-M8FQD87`N<&AP.C$W,@IM<V=I9"`B26YC;W)R
M96-T(%!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V8;8I]BOV+'8
ML]BJ(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,C,*;7-G:60@(DUI;FEM
M=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B
MV*W8K]BGV8+9A"#8N=F%V+$@V*?8L]F%(-BQV878LB#9A]F&V8C8LB#9A=F&
MV8+8MMN,(-F&V+38K]F'XH",V*?8L]BJ(@H*(SH@=&5M<&QA=&5S+VUA:6XO
M;6%I;BYI;F,Z,3`T"FUS9VED(").97<@<&%S<W=O<F0Z(@IM<V=S='(@(MBG
MV+/9A2#8L=F%V+(@V*S8K]N,V*\Z(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`W
M"B,L('!H<"UF;W)M870*;7-G:60@(DYO('-U8V@@8F%C:V5N9"`G)7,G(&9O
M=6YD+B(*;7-G<W1R("+9OMBTV*K;C-BHV*?9AB`G)7,G(-F^VXS8K]BGV8;8
MM-BO+B(*"B,Z('1E;7!L871E<R]M86EN+VUA:6XN:6YC.CDR"FUS9VED(")/
M;&0@<&%S<W=O<F0Z(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V8+8K]N,V87;
MC#HB"@HC.B!L:6(O1')I=F5R+W-M8G!A<W-W9"YP:'`Z-#,*;7-G:60@(E!A
M<W-W9"!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"XB"FUS9W-T<B`B4&%S
M<W=D(-BHV8<@V+?9B-BQ(-JIV*?9A=F$(-F^VXS:J=BQV*C9AMBOVXP@V8;8
MM-BOV8<@V*?8L]BJ+B(*"B,Z(&UA:6XN<&AP.C$Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")087-S=V]R9"!C:&%N9V5D(&]N("5S+B(*;7-G<W1R("+8I]BS
MV84@V+'9A=BR(-BHV+$@)7,@V*K8NMN,VXS8L2#;C-BGV8'8JBXB"@HC.B!L
M:6(O1')I=F5R+W!S<&%S<W=D+G!H<#HV-PIM<V=I9"`B4&%S<W=O<F0@;6]D
M=6QE(&-A;B=T(&9I;F0@=&AE('-U<'!L:65D(&)I;BXB"FUS9W-T<B`BV878
MK]F(V80@V*?8L]F%(-BQV878LB#8J-BGVXS9AMBQVXP@V879B-BQV*\@V8;;
MC-BGV+(@V+'8IR#9AMBJV8C8I]F&V+/8JB#9OMN,V*_8IR#:J=F&V*\N(@H*
M(SH@;&EB+T1R:79E<B]P<W!A<W-W9"YP:'`Z-C4*;7-G:60@(E!A<W-W;W)D
M(&UO9'5L92!I<R!M:7-S:6YG(')E<75I<F5D('!A<F%M971E<G,N(@IM<V=S
M='(@(MF%V*_9B-F$(-BGV+/9A2#8L=F%V+(@V;[8I]BQV*?9A=BJV+'9A]BG
MVXP@V879B-BQV*_9AMN,V*?8LB#8L=BG(-F&V*_8I]BQV*\N(@H*(SH@;&EB
M+T1R:79E<B]A9'-I+G!H<#HT-`IM<V=I9"`B4&%S<W=O<F0@;6]D=6QE(&ES
M(&UI<W-I;F<@=&%R9V5T('!A<F%M971E<BXB"FUS9W-T<B`BV878K]F(V80@
MV*?8L]F%(-BQV878LB#9OMBGV+'8I]F%V*K8L=F'V*?;C"#9A=F"V+78KR#8
ML=BG(-F&V*_8I]BQV*\N(@H*(SH@;6%I;BYP:'`Z,3<X(&QI8B]$<FEV97(O
M<V5R=G5F='`N<&AP.C8V"FUS9VED(")087-S=V]R9"!M;V1U;&4@:7,@;F]T
M('!R;W!E<FQY(&-O;F9I9W5R960B"FUS9W-T<B`BV878K]F(V80@V*?8L]F%
M(-BQV878LB#8J-F'(-BWV8C8L2#9A=F&V*?8L]BH(-F^VXS:J=BQV*C9AMBO
MVXP@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@;&EB+T1R:79E<B]S97)V=69T<"YP
M:'`Z.3,*;7-G:60@(E!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@
M8V]N9FEG=7)E9"XB"FUS9W-T<B`BV878K]F(V80@V*?8L]F%(-BQV878LB#8
MJ-F'(-BWV8C8L2#:J=BGV879A"#9OMN,VJG8L=BHV8;8K]N,(-F&V+38K]F'
M(-BGV+/8JBXB"@HC.B!L:6(O1')I=F5R+V-O;7!O<VET92YP:'`Z,S4*;7-G
M:60@(E)E<75I<F5D("=D<FEV97)S)R!I<R!M:7-C;VYF:6=U<F5D(&EN($-O
M;7!O<VET92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+9@=N,V838KR`G9')I
M=F5R<R<@V*_8L2#9OMN,VJG8L=BHV8;8K]N,V(P@V+K9A-BW(-F^VXS:J=BQ
MV*C9AMBOVXP@V+38K]F'(-BGV+/8JBXB"@HC.B!L:6(O1')I=F5R+W-Q;"YP
M:'`Z-#$*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D
M(&EN(%!A<W-W9"!344P@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BV8';C-F$
MV*\@)W!H<'1Y<&4G(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#9A=BOV8C9A"!P
M87-S=V0@(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JBXB"@HC.B!L:6(O1')I
M=F5R+W9P;W!M86EL+G!H<#HT-`IM<V=I9"`B4F5Q=6ER960@)W!H<'1Y<&4G
M(&YO="!S<&5C:69I960@:6X@4U%,(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(MF!VXS9A-BO("=P:'!T>7!E)R#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@4U%,
M(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JBXB"@HC.B!T96UP;&%T97,O;6%I
M;B]M86EN+FEN8SHQ-#4*;7-G:60@(E)E<V5T(@IM<V=S='(@(MBHV*?8LMF&
MV+38I]F&VXPB"@HC.B!L:6(O1')I=F5R+W9P;W!M86EL+G!H<#HW."!L:6(O
M1')I=F5R+W-Q;"YP:'`Z-S`*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N(@IM<V=S='(@(MBGV87:J=BGV88@V*?8JMBUV*?9A"#8
MJ-F'(-JIV*?8L=BSV*?8LB!346P@V8;9A=N,XH",V*C8I]BTV*\N(@H*(SH@
M;&EB+T1R:79E<B]P;W!P87-S9"YP:'`Z,3`S(&QI8B]$<FEV97(O=G!O<&UA
M:6PN<&AP.C$S.`HC.B!L:6(O1')I=F5R+W-Q;"YP:'`Z,3(P"FUS9VED(")5
M<V5R(&YO="!F;W5N9"(*;7-G<W1R("+:J=BGV+'8J-BQ(-F^VXS8K]BG(-F&
MV+38KR(*"B,Z(&QI8B]$<FEV97(O<&EN92YP:'`Z,C(U(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,3,P(&QI8B]$<FEV97(O:V]L86(N<&AP.C8T"B,Z(&QI8B]$
M<FEV97(O<VUB;&1A<"YP:'`Z,3(W"FUS9VED(")5<V5R(&YO="!F;W5N9"XB
M"FUS9W-T<B`BVJG8I]BQV*C8L2#9OMN,V*_8IR#9AMBTV*\N(@H*(SH@=&5M
M<&QA=&5S+VUA:6XO;6%I;BYI;F,Z-SD*;7-G:60@(E5S97)N86UE.B(*;7-G
M<W1R("+9AMBGV84@VJG8I]BQV*C8L3HB"@HC.B!M86EN+G!H<#HT-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O
M<B!U<V5R("5S(@IM<V=S='(@(MBTV878IR#9AMF%VXSB@(S8JMF(V*?9AMN,
MV*\@V*?8L]F%(-BQV878LB#:J=BGV+'8J-BQ("5S(-BQV*<@V*K8NMN,VXS8
ML2#8K]F'VXS8KR(*"B,Z(&UA:6XN<&AP.C4U"FUS9VED(")9;W4@;75S="!G
M:79E('EO=7(@8W5R<F5N="!P87-S=V]R9"(*;7-G<W1R("+8M-F%V*<@V*C8
MI]N,V*\@V*?8L]F%(-BQV878LB#:J=F&V8C9AMN,(-BNV8C8KR#8L=BG(-BH
MV*_9A]N,V*\B"@HC.B!M86EN+G!H<#HV-`IM<V=I9"`B66]U(&UU<W0@9VEV
M92!Y;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@
MV*?8L]F%(-BQV878LB#8K-BOVXS8KR#8KMF(V*\@V+'8IR#8J-BOV8?;C-BO
M("(*"B,Z(&UA:6XN<&AP.C8X"FUS9VED(")9;W4@;75S="!V97)I9GD@>6]U
M<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-BGV+/9
MA2#8L=F%V+(@V*S8K]N,V*\@V*[9B-BO(-BQV*<@V*C8I]BRV*C;C-F&VXP@
MVJG9AMN,V*\B"@HC.B!M86EN+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S
M(&UA>2!N;W0@8F4@;6]R92!T:&%N("5D(&-H87)A8W1E<G,@(@HB;&]N9R$B
M"FUS9W-T<B`B(@HBV*?8L]F%(-BQV878LB#8K-BOVXS8KR#8M-F%V*<@V*C8
ML]N,V*?8L2#8M]F(V838I]F&VXP@V*?8L]BJV(P@V*?8L]F%(-BQV878LMF'
MV*<@V8;8J-BGVXS8KR#8J-N,V+0@V*?8LB`E9"#9AMF(VXS8L]F'(-BHV*?8
MM-BO(2(*"B,Z(&UA:6XN<&AP.C$V-PIM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@:7,@=&]O('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N9V5D(2(*;7-G
M<W1R("+8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-BTV878IR#8J-BQV*?;C"#8
MK=BOV+,@V++8K]F&(-BHV+/;C-BGV+$@V*+8L]BGV88@V87;C.*`C-BHV*?8
MM-BO(2#8I]BSV84@V+'9A=BR(-BJV+K;C-N,V+$@V8;;C-BGV8'8JB$B"@HC
M.B!M86EN+G!H<#HQ-3@*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&ES('1O
M;R!S:6UP;&4@=&\@9W5E<W,N($YO="!C:&%N9V5D(2(*;7-G<W1R("+8I]BS
MV84@V+'9A=BR(-BLV*_;C-BO(-BTV878IR#8J-BQV*?;C"#8K=BOV+,@V++8
MK]F&(-BHV+/;C-BGV+$@V*+8L]BGV88@V87;C.*`C-BHV*?8M-BO+B#8I]BS
MV84@V+'9A=BR(-BJV+K;C-N,V+$@V8;;C-BGV8'8JB$B"@HC.B!M86EN+G!H
M<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@;&]N9R$B"FUS9W-T<B`B
MV*?8L]F%(-BQV878LB#8K-BOVXS8KR#8M-F%V*<@V*C8I]N,V*\@V*W8K]BG
MV8+9A"`E9"#9AMF(VXS8L]F'(-BHV*?8M-BO(2(*"B,Z(&UA:6XN<&AP.C<V
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&1I9F9E<F5N="!F
M<F]M('EO=7(@8W5R<F5N="!P87-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9
MA=BR(-BLV*_;C-BO(-BTV878IR#8J-BGVXS8KR#8J-BG(-BGV+/9A2#8L=F%
MV+(@VJG9AMF(V8;;C"#8M-F%V*<@V878JMF!V*?9B-BJ(-BHV*?8M-BO(@H*
M(SH@;6%I;BYP:'`Z,3(X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W
M('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!A;'!H86)E=&EC
M(&-H87)A8W1E<G,N(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*S8K]N,V*\@
MV+39A=BG(-BMV*_8I]F"V80@V*C8I]N,V*\@V+38I]F%V80@)60@V8;9B-N,
MV+/9A]F4(-BGV839@=BHV*?;C-N,(-BHV*?8M-BO+B(*"B,Z(&UA:6XN<&AP
M.C$S,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A8W1E
M<G,N(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*S8K]N,V*\@V+39A=BG(-BM
MV*_8I]F"V80@V*C8I]N,V*\@V+38I]F%V80@)60@V8;9B-N,V+/9A]F4(-BG
MV839@=BHV*?;C-N,(-F((-BYV*_8K]N,(-BHV*?8M-BO+B(*"B,Z(&UA:6XN
M<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@9&EF9F5R96YT('1Y<&5S
M(&]F(&-H87)A8W1E<G,N("(*(E1H92!T>7!E<R!A<F4Z(&QO=V5R+"!U<'!E
M<BP@;G5M97)I8RP@86YD('-Y;6)O;',N(@IM<V=S='(@(B(*(MBGV+/9A2#8
ML=F%V+(@V*S8K]N,V*\@V+39A=BG(-BMV*_8I]F"V80@V*C8I]N,V*\@V+38
MI]F%V80@)60@V*?8LB#8I]F&V8C8I]BY(-F%V*K9@=BGV8C8JB#9AMF(VXS8
ML]F'(-BHV*?8M-BO+B#8I]F&V8C8I]BY(-BHV*_;C-F&("(*(MBUV8C8L=BJ
M(-F'V+/8JMF&V*\Z(-BMV+'9B-F!(-JIV8C:AMJIV(P@V*W8L=F(V8$@V*C8
MLMBQVJ_8C"#8N=BOV*_;C"#9B"#9AMBTV*?9AMF'XH",V8?8IRXB"@HC.B!M
M86EN+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&QO=V5R8V%S92!C:&%R
M86-T97)S+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-BTV878
MIR#8K=BOV*?9@MF$(-BHV*?;C-BO(-BTV*?9A=F$("5D(-F&V8C;C-BSV8<@
MV*C8IR#8K=BQV8C9@2#:J=F(VH;:J2#8J-BGV+38KRXB"@HC.B!M86EN+G!H
M<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M;75S="!C;VYT86EN(&%T(&QE87-T("5D(&YU;65R:6,@8VAA<F%C=&5R<RXB
M"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8K-BOVXS8KR#8M-F%V*<@V*W8K]BG
MV8+9A"#8J-BGVXS8KR#8M-BGV879A"`E9"#9AMF(VXS8L]F'(-BYV*_8K]N,
M(-BHV*?8M-BO+B(*"B,Z(&UA:6XN<&AP.C$Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@
M)60@=7!P97)C87-E(&-H87)A8W1E<G,N(@IM<V=S='(@(MBGV+/9A2#8L=F%
MV+(@V*S8K]N,V*\@V+39A=BG(-BMV*_8I]F"V80@V*C8I]N,V*\@V+38I]F%
MV80@)60@V8;9B-N,V+/9AR#8J-BG(-BMV+'9B-F!(-BHV++8L=JO(-BHV*?8
MM-BO+B(*"B,Z(&UA:6XN<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@;&5S<R!T:&%N("5D('=H
M:71E<W!A8V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8
MK-BOVXS8KR#8M-F%V*<@V*W8K]BGVJG8J]BQ(-BHV*?;C-BO(-BTV*?9A=F$
M("5D(-F&V8C;C-BSV8?9E"#8K-BGVXP@V*[8I]F$VXP@V*C8I]BTV*\N(@H*
M(SH@;6%I;BYP:'`Z,30V"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!M=7-T
M(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA<F%C=&5R<RXB"FUS9W-T<B`B
MV*?8L]F%(-BQV878LB#8K-BOVXS8KR#8M-F%V*<@V8;8J-BGVXS8KR#8M-BG
MV879A"#9AMF(VXS8L]F'V90@V*S8I]N,(-BNV*?9A-N,(-BHV*?8M-BO+B(*
M"B,Z(&UA:6XN<&AP.C<R"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9',@9&ED
M;B=T(&UA=&-H(@IM<V=S='(@(MBGV+/9A2#8L=F%V++9A]BGVXP@V*S8K]N,
MV*\@V+39A=BG(-BJV+?8I]BHV8(@V8;8K]BGV+'8KR(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z-S`@;&EB+T1R:79E<B]S;6)L9&%P+G!H<#HW,PIM<V=I
M9"`B;&1A<%]S=&%R=%]T;',@9F%I;&5D(@IM<V=S='(@(FQD87!?<W1A<G1?
M=&QS(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+W1H
M96UE<R\`````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,3<R,3$`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P87-S=V0O=&AE;65S+V=R87!H:6-S+P``````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S`#`R,3`Q
M,0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]T:&5M97,O9W)A<&AI
M8W,O9F%V:6-O;BYI8V\`````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-S8`
M,3`T,3<S-C(W-#,`,#(S,3,U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````0`!`!`0````````:`0``!8````H````$```
M`"`````!`"`````````$````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/\```#_````_P```/\```#_````_P``
M`/\```#_````_P```/\``````````````````````````````/]TJ-#_79;&
M_U"-OO]0C;[_2XFZ_TN)NO].C+W_3(J\_T>&NO\V<:3_````_P``````````
M``````````````#_GL+@_WFLU/]NILW_7HVO_UB'J_]8AZO_6(BK_TR!J/]&
MA[S_/GZT_P```/\`````````````````````````_YS"X?]PI,[_9(VM_XFR
MTO^#K,W_@ZS-_X.MSO][I\S_/H"X_S)SK?\```#_````````````````````
M`````/^@Q.'_=*;0_V2;Q_]5A*K_3GZD_TY^I/].?J3_1'>@_T*$NO\N<:S_
M````_P````````````````````````#_HL;C_WZNU?]?C;#_A++5_WRKS_]\
MJ\__>ZS/_W&DR_]&A[S_*V^J_P```/\`````````````````````````_Z'%
MXO^,M=C_:)_*_UB'K/]2@J?_4H*G_U."I_]+>Z/_28B\_RYQK/\```#_````
M`````````````````````/]VD:7_H,3@_Z/$W_^CQ-__FK[:_YJ^VO^:OMK_
ME+K6_W:FS?\K6H'_````_P``````````````````````````#A$3_Y27F_\<
M'2#_!PL+_P(#!/\"`P3_`P0%_R$I+_^>HZC_"Q,:_P``````````````````
M`````````````"LK*__`P,#_````_P`````````````````````6%A;_P,#!
M_P```/\````````````````````````````````M+2W_PL+"_PD)"?\`````
M````````````````+BXN_ZJJJO\```#_````````````````````````````
M`````````(2$A/^^OK[_.#@X_QP<'/\<'!S_34U-_[&QL?^$A(3_````````
M```````````````````````````````````>'A[_>GIZ_]+2TO_;V]O_V]O;
M_[R\O/]R<G+_"`@(_P``````````````````````````````````````````
M``````````````#_````_P```/\```#_````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/__``#@!P``P`,``,`#``#``P``P`,`
M`,`#``#``P``P`,``.`'``#CQP``X\<``/`/``#P#P``_#\``/__````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+W1H96UE<R]G<F%P:&EC<R]P87-S=V0N<&YG````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3,P-@`Q,#0Q-S,V,C<T,P`P,C,P,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3```!#E!,5$4````$`P(%!`,(
M"`@)"0D+"P<3$0X:$PL6%A8<'!P@'1P>'AXO*2$K*RLM+2TN+BXX.#A-34V!
M6BMR<G*J;RND<39Z>GJL<2ZM<S*@=T2C>TN$A(2D?DZH@4RT?CZG@E*G@E.X
M@#ZJA%6KAUBLAUBZA$*KB%BZAD>\AT:\B$FZB4NOC5ZMC62\BDRPC5^]C$ZE
MD7:^C5";EY3&EEW'FV2HHY[*GVBJJJK+I''.I'#-IF[-IG;0IG3,IWO0J'3/
MJWRQL;'/K'O-K(/.K8/4K'G5KG[2LHG5LH38M8R\O+R^OK[6NI3`P,#!P,#"
MPL+:OIK@PI[APIS@Q*#?Q*/AQ*#BQ:'CQJ+2TM+;V]L```![0$@>`````712
M3E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?4#!02+`1^#@'Y````C'1%6'1#;VUM96YT`$UE;G4M<VEZ960@:6-O
M;@H]/3T]/3T]/3T]"@HH8RD@,C`P,R!*86MU8B`G:FEM;6%C)R!3=&5I;F5R
M+"`*:'1T<#HO+VII;6UA8RYM=7-I8VAA;&PN8WH*"F-R96%T960@=VET:"!T
M:&4@1TE-4"P*:'1T<#HO+W=W=RYG:6UP+F]R9V>*QT<```"9241!5'C:8V#`
M#B*!`(G++18>$>$IS`P7D/82X.04=)"&\?G\6$`4OSE,%Z\/F,7A"Q-@,^)B
M961DXC%EA]I@$!0<[._O[VTM!%$2&>IAIB(OKR"E*0X5"'/5<[>W=[30$($*
MA-B8*,G(R$BJPE0$6NJX.3DYVRI*0`4"7*RTE9759#7DH`)VQH:&6EKZNNJB
MD0B?00`V?P,``.(=%XJG_UT`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&%S<W=D+W1E;7!L871E<R\`````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,3<W
M,C(`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O=&5M<&QA=&5S+VUA
M:6XO````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S0S`#`R,#8T-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A
M<W-W9"]T96UP;&%T97,O;6%I;B]M86EN+FEN8P``````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3$P-#4`,3`T,3<S-C(W-#,`,#(R,C8S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#QS8W)I<'0@='EP
M93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H*9G5N8W1I;VX@<W5B;6ET7V9O
M<FTH*0I["B`@("!I9B`H9&]C=6UE;G0N<&%S<W=D+F]L9'!A<W-W;W)D+G9A
M;'5E(#T]("(B*2!["B`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")0;&5A<V4@<')O=FED92!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0B
M*2D[(#\^)RD["B`@("`@("`@9&]C=6UE;G0N<&%S<W=D+F]L9'!A<W-W;W)D
M+F9O8W5S*"D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E(&EF
M("AD;V-U;65N="YP87-S=V0N;F5W<&%S<W=O<F0P+G9A;'5E(#T]("(B*2![
M"B`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;&5A
M<V4@<')O=FED92!A(&YE=R!P87-S=V]R9"(I*3L@/SXG*3L*("`@("`@("!D
M;V-U;65N="YP87-S=V0N;F5W<&%S<W=O<F0P+F9O8W5S*"D["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E(&EF("AD;V-U;65N="YP87-S=V0N
M;F5W<&%S<W=O<F0Q+G9A;'5E(#T]("(B*2!["B`@("`@("`@86QE<G0H)SP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;&5A<V4@=F5R:69Y('EO=7(@;F5W
M('!A<W-W;W)D(BDI.R`_/B<I.PH@("`@("`@(&1O8W5M96YT+G!A<W-W9"YN
M97=P87-S=V]R9#$N9F]C=7,H*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!](&5L<V4@:68@*&1O8W5M96YT+G!A<W-W9"YN97=P87-S=V]R9#`N=F%L
M=64@(3T@9&]C=6UE;G0N<&%S<W=D+FYE=W!A<W-W;W)D,2YV86QU92D@>PH@
M("`@("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U<B!P
M87-S=V]R9',@9&\@;F]T(&UA=&-H(BDI.R`_/B<I.PH@("`@("`@(&1O8W5M
M96YT+G!A<W-W9"YN97=P87-S=V]R9#`N=F%L=64@/2`G)SL*("`@("`@("!D
M;V-U;65N="YP87-S=V0N;F5W<&%S<W=O<F0Q+G9A;'5E(#T@)R<["B`@("`@
M("`@9&]C=6UE;G0N<&%S<W=D+FYE=W!A<W-W;W)D,"YF;V-U<R@I.PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T@96QS92!["B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"GT*"F9U;F-T:6]N('-E=$9O8W5S*"D*>PH@("`@:68@
M*&1O8W5M96YT+G!A<W-W9"YO;&1P87-S=V]R9"YV86QU92`]/2`B(BD@>PH@
M("`@("`@(&1O8W5M96YT+G!A<W-W9"YO;&1P87-S=V]R9"YF;V-U<R@I.PH@
M("`@?2!E;'-E(&EF("AD;V-U;65N="YP87-S=V0N;F5W<&%S<W=O<F0P+G9A
M;'5E(#T]("(B*2!["B`@("`@("`@9&]C=6UE;G0N<&%S<W=D+FYE=W!A<W-W
M;W)D,"YF;V-U<R@I.PH@("`@?2!E;'-E('L*("`@("`@("!D;V-U;65N="YP
M87-S=V0N;F5W<&%S<W=O<F0Q+F9O8W5S*"D["B`@("!]"GT*+R\M+3X*/"]S
M8W)I<'0^"@H\9&EV(&ED/2)M96YU(CX*/#]P:'`*<F5Q=6ER95]O;F-E("=(
M;W)D92]-96YU+G!H<"<["B1M96YU(#T@)FYE=R!-96YU*$A/4D1%7TU%3E5?
M34%32U]!3$P@)B!^2$]21$5?345.55]-05-+7U!21493*3L*96-H;R`D;65N
M=2T^<F5N9&5R*"D["B1I=&5M(#T@,3L*/SX*/"]D:78^"CP_<&AP("1N;W1I
M9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S
M)RDI(#\^"@H\9F]R;2!M971H;V0](G!O<W0B(&%C=&EO;CTB/#]P:'`@96-H
M;R!(;W)D93HZ=7)L*"=M86EN+G!H<"<L(&9A;'-E+"`M,2P@=')U92D@/SXB
M(&YA;64](G!A<W-W9"(^"CP_<&AP(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@
M/SX*/#]P:'`@:68@*"1C;VYF6R=B86-K96YD)UU;)V)A8VME;F1?;&ES="==
M(#T]("=H:61D96XG*3H@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M8F%C:V5N9"(@=F%L=64](CP_<&AP(&5C:&\@)&)A8VME;F1?:V5Y(#\^(B`O
M/@H\/W!H<"!E;F1I9CL@:68@*"1C;VYF6R=U<V5R)UU;)V-H86YG92==("$]
M/2!T<G5E*3H@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB=7-E<FED
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R:60I
M(#\^(B`O/@H\/W!H<"!E;F1I9CL@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB<F5T=7)N7W1O(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*%5T:6PZ.F=E=$9O<FU$871A*"=R971U<FY?=&\G*2D@/SXB("\^
M"@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(%\H(D-H86YG92!Y
M;W5R('!A<W-W;W)D(BD@/SX*/"]H,3X*"CQT86)L92!C96QL<W!A8VEN9STB
M,"(@=VED=&@](C$P,"4B/@H\/W!H<"!I9B`H)&-O;F9;)V)A8VME;F0G75LG
M8F%C:V5N9%]L:7-T)UT@/3T@)VAI9&1E;B<I.B`_/@H\='(@8VQA<W,](F-O
M;G1R;VPB/@H@/'1D(&-O;'-P86X](C,B(&-L87-S/2)C;VYT<F]L(&QE9G1!
M;&EG;B(^"B`@/#]P:'`@<')I;G1F*%\H(D-H86YG:6YG('!A<W-W;W)D(&]N
M("5S(BDL(&AT;6QS<&5C:6%L8VAA<G,H)&)A8VME;F1S6R1B86-K96YD7VME
M>5U;)VYA;64G72DI(#\^"B`\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*
M"CP_<&AP(&EF("@D8V]N9ELG=7-E<B==6R=C:&%N9V4G72`]/3T@=')U92DZ
M(#\^"CQT<B!C;&%S<STB:71E;3P_<&AP(&5C:&\@)&ET96TK*R`E(#(@/SXB
M/@H@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX*("`\<W1R;VYG/CP_<&AP(&5C
M:&\@7R@B57-E<FYA;64Z(BD@/SX\+W-T<F]N9SX*(#PO=&0^"B`\=&0@8VQA
M<W,](FQE9G1!;&EG;B(^"B`@/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G5S
M97)I9"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E
M<FED*2`_/B(@+SX*(#PO=&0^"B`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H@
M(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G<&%S<W=D)RP@)W!A<W-W9"UU<V5R
M;F%M92<I(#\^"B`\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*"CQT<B!C
M;&%S<STB:71E;3P_<&AP(&5C:&\@)&ET96TK*R`E(#(@/SXB/@H@/'1D('=I
M9'1H/2(Q-24B(&-L87-S/2)R:6=H=$%L:6=N(CX*("`\<W1R;VYG/CP_<&AP
M(&5C:&\@7R@B3VQD('!A<W-W;W)D.B(I(#\^/"]S=')O;F<^"B`\+W1D/@H@
M/'1D(&-L87-S/2)L969T06QI9VXB/@H@(#QI;G!U="!T>7!E/2)P87-S=V]R
M9"(@=&%B:6YD97@](C$B(&YA;64](F]L9'!A<W-W;W)D(B!S:7IE/2(S,B(@
M+SX*(#PO=&0^"B`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H@(#P_<&AP(&5C
M:&\@2&5L<#HZ;&EN:R@G<&%S<W=D)RP@)W!A<W-W9"UO;&0M<&%S<W=O<F0G
M*2`_/@H@/"]T9#X*/"]T<CX*"CQT<B!C;&%S<STB:71E;3P_<&AP(&5C:&\@
M)&ET96TK*R`E(#(@/SXB/@H@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX*("`\
M<W1R;VYG/CP_<&AP(&5C:&\@7R@B3F5W('!A<W-W;W)D.B(I(#\^/"]S=')O
M;F<^"B`\+W1D/@H@/'1D(&-L87-S/2)L969T06QI9VXB/@H@(#QI;G!U="!T
M>7!E/2)P87-S=V]R9"(@=&%B:6YD97@](C(B(&YA;64](FYE=W!A<W-W;W)D
M,"(@<VEZ93TB,S(B("\^"B`\+W1D/@H@/'1D(&-L87-S/2)R:6=H=$%L:6=N
M(CX*("`\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)W!A<W-W9"<L("=P87-S=V0M
M;F5W+7!A<W-W;W)D)RD@/SX*(#PO=&0^"CPO='(^"@H\='(@8VQA<W,](FET
M96T\/W!H<"!E8VAO("1I=&5M*RL@)2`R(#\^(CX*(#QT9"!C;&%S<STB<FEG
M:'1!;&EG;B(^"B`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D-O;F9I<FT@;F5W
M('!A<W-W;W)D.B(I(#\^/"]S=')O;F<^"B`\+W1D/@H@/'1D(&-L87-S/2)L
M969T06QI9VXB/@H@(#QI;G!U="!T>7!E/2)P87-S=V]R9"(@=&%B:6YD97@]
M(C,B(&YA;64](FYE=W!A<W-W;W)D,2(@<VEZ93TB,S(B("\^"B`\+W1D/@H@
M/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX*("`\/W!H<"!E8VAO($AE;'`Z.FQI
M;FLH)W!A<W-W9"<L("=P87-S=V0M8V]N9FER;2UP87-S=V]R9"<I(#\^"B`\
M+W1D/@H\+W1R/@H*/#]P:'`@:68@*"1C;VYF6R=B86-K96YD)UU;)V)A8VME
M;F1?;&ES="==(#T]("=S:&]W;B<I.B`_/@H\='(@8VQA<W,](FET96T\/W!H
M<"!E8VAO("1I=&5M*RL@)2`R(#\^(CX*(#QT9"!C;&%S<STB<FEG:'1!;&EG
M;B(^"B`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D-H86YG92!P87-S=V]R9"!O
M;CHB*2`_/CPO<W1R;VYG/@H@/"]T9#X*(#QT9"!C;&%S<STB;&5F=$%L:6=N
M(B!S='EL93TB9&ER96-T:6]N.B!L='(B/@H@(#QS96QE8W0@;F%M93TB8F%C
M:V5N9"(@=&%B:6YD97@](C0B/@H@("`\/W!H<"!E8VAO("1B86-K96YD<U]L
M:7-T(#\^"B`@/"]S96QE8W0^"B`\+W1D/@H@/'1D(&-L87-S/2)R:6=H=$%L
M:6=N(CX*("`@("`\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)W!A<W-W9"<L("=P
M87-S=V0M<V5R=F5R)RD@/SX*(#PO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_
M/@H*/'1R(&-L87-S/2)C;VYT<F]L(CX*(#QT9"!C;VQS<&%N/2(S(B!C;&%S
M<STB8V]N=')O;"!L969T06QI9VXB/@H@(#QI;G!U="!C;&%S<STB8G5T=&]N
M(B!T>7!E/2)S=6)M:70B(&YA;64](G-U8FUI="(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B0VAA;F=E(%!A<W-W;W)D(BD@/SXB(&]N8VQI8VL](G)E='5R;B!S
M=6)M:71?9F]R;2@I.R(@+SX*("`\:6YP=70@8VQA<W,](F)U='1O;B(@='EP
M93TB<F5S970B(&YA;64](G)E<V5T(B!V86QU93TB/#]P:'`@96-H;R!?*")2
M97-E="(I(#\^(B`O/@H@/"]T9#X*/"]T<CX*/"]T86)L93X*/"]F;W)M/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P87-S=V0O=&5M<&QA=&5S+RYH=&%C8V5S<P``````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#$V`#$P-#$W,S8R-S0S`#`R,34Q,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!$96YY
M(&9R;VT@86QL"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D
M+W1E;7!L871E<R]C;VUM;VXM:&5A9&5R+FEN8P``````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C(Q,0`Q,#0Q-S,V,C<T,P`P,C,Q,C0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*9VQO8F%L("1L
M86YG=6%G93L*:68@*&ES<V5T*"1L86YG=6%G92DI('L*("`@(&AE861E<B@G
M0V]N=&5N="UT>7!E.B!T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T
M0VAA<G-E="@I*3L*("`@(&AE861E<B@G5F%R>3H@06-C97!T+4QA;F=U86=E
M)RD["GT*/SX*/"%$3T-465!%(&AT;6P@4%5"3$E#("(M+R]7,T,O+T141"!8
M2%1-3"`Q+C`@5')A;G-I=&EO;F%L+R]%3B(@(D141"]X:'1M;#$M=')A;G-I
M=&EO;F%L+F1T9"(^"CPA+2T@("`@("`@("`@(%!A<W-W9#H@0V]P>7)I9VAT
M(#(P,#(M,C`P-2P@5&AE($AO<F1E(%!R;VIE8W0N("`@("`@("`@("`M+3X*
M/"$M+2!(;W)D92!0<F]J96-T.B!H='1P.B\O:&]R9&4N;W)G+R!\(%!A<W-W
M9#H@:'1T<#HO+VAO<F1E+F]R9R]P87-S=V0O("TM/@H\(2TM("`@("`@("`@
M("!(;W)D92!,:6-E;G-E<SH@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS
M97,O("`@("`@("`@("`@+2T^"CP_<&AP(&5C:&\@(65M<'1Y*"1L86YG=6%G
M92D@/R`G/&AT;6P@;&%N9STB)R`N('-T<G1R*"1L86YG=6%G92P@)U\G+"`G
M+2<I("X@)R(^)R`Z("<\:'1M;#XG(#\^"CQH96%D/@H\/W!H<`H*+RH@4')I
M;G0@=&AE('!A9V4@=&ET;&4N("HO"B1P86=E7W1I=&QE(#T@)')E9VES=')Y
M+3YG970H)VYA;64G*3L*:68@*"%E;7!T>2@D=&ET;&4I*2`D<&%G95]T:71L
M92`N/2`G(#HZ("<@+B`D=&ET;&4["FEF("@A96UP='DH)')E9G)E<VA?=&EM
M92D@)B8@*"1R969R97-H7W1I;64@/B`P*2`F)B`A96UP='DH)')E9G)E<VA?
M=7)L*2D@>PH@("`@96-H;R`B/&UE=&$@:'1T<"UE<75I=CU<(G)E9G)E<VA<
M(B!C;VYT96YT/5PB)')E9G)E<VA?=&EM93MU<FP])')E9G)E<VA?=7)L7"(^
M7&XB.PI]"@H_/@H\=&ET;&4^/#]P:'`@96-H;R`D<&%G95]T:71L92`_/CPO
M=&ET;&4^"CQL:6YK(&AR968](CP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E=$EM86=E1&ER*"D_/B]F879I8V]N+FEC;R(@<F5L/2)32$]2
M5$-55"!)0T].(B`O/@H\/W!H<"!E8VAO($AO<F1E.CIS='EL97-H965T3&EN
M:R@G:&]R9&4G*2`_/@H\+VAE860^"@H\8F]D>3P_<&AP(&EF("A5=&EL.CIN
M;VY);G!U=%9A<B@G8F]D>4-L87-S)RDI(&5C:&\@)R!C;&%S<STB)R`N("1B
M;V1Y0VQA<W,@+B`G(B<[(#\^/@H*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P87-S=V0O<V-R:7!T<R\`````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S0S`#`Q-S0Q,P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]S8W)I
M<'1S+RYH=&%C8V5S<P``````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,38`,3`T,3<S-C(W-#,`,#(Q,C`S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$1E;GD@9G)O;2!A;&P*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O<V-R:7!T<R]P87-S=V1?
M97AP96-T````````````````````````````````````````````````````
M`````````#`Q,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U-S4S`#$P
M-#$W,S8R-S0S`#`R,C(R,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C("1(;W)D93H@<&%S<W=D+W-C<FEP=',O<&%S<W=D
M7V5X<&5C="QV(#$N-R`R,#`U+S`Y+S$S(#(R.C$W.C0S(&IA;B!%>'`@)`HC
M"B,@5&AI<R!S8W)I<'1S(&-H86YG97,@82!P87-S=V]R9"!O;B!A(')E;6]T
M92!H;W-T+@HC($-O;FYE8W1I;VYS('1O('1H92!R96UO=&4@*'1H:7,@8V%N
M(&%L<V\@8F4@;&]C86QH;W-T*0HC(&%R92!M861E(&)Y('-S:"P@<G-H+"!T
M96QN970@;W(@<FQO9VEN+@H*(R!`875T:&]R("!'875D96YZ(%-T96EN;&EN
M(#QG875D96YZ+G-T96EN;&EN0&ED+G5N:6)E+F-H/@HC($!S:6YC92`@(%!A
M<W-W9"`R+C(*"B,@36]D:69I960@8GD@3&EO;F5L($5L:64@36%M86YE(#QL
M:6]N96Q`;6%M86YE+FQU/B!T;R!M86YA9V4@8V%S92!W:&5R90HC('!A<W-W
M9"!I<R!T:&4@;&]G:6X@<VAE;&PN"@HC($!S=&1I;B`@("`@("`@(%1H92!U
M<V5R;F%M92P@;VQD<&%S<W=O<F0L(&YE=W!A<W-W;W)D("AI;B!T:&ES(&]R
M9&5R*0HC("`@("`@("`@("`@("`@('=I;&P@8F4@=&%K96X@9G)O;2!S=&1I
M;@HC($!P87)A;2`M<')O;7!T("`@("`@<F5G97AP(&9O<B!T:&4@<VAE;&P@
M<')O;7!T"B,@0'!A<F%M("UP87-S=V]R9"`@("!R96=E>'`@<&%S<W=O<F0@
M<')O;7!T"B,@0'!A<F%M("UO;&1P87-S=V]R9"!R96=E>'`@9F]R('1H92!O
M;&0@<&%S<W=O<F0*(R!`<&%R86T@+6YE=W!A<W-W;W)D(')E9V5X<"!F;W(@
M=&AE(&YE=R!P87-S=V]R9`HC($!P87)A;2`M=F5R:69Y("`@("`@<F5G97AP
M(&9O<B!V97)I9GEI;F<@=&AE('!A<W-W;W)D"B,@0'!A<F%M("US=6-C97-S
M("`@("!R96=E>'`@9F]R('-U8V-E<W,@8VAA;F=I;F<@=&AE('!A<W-W;W)D
M"B,@0'!A<F%M("UL;V=I;B`@("`@("!R96=E>'`@9F]R('1H92!T96QN970@
M<')O;7!T(&9O<B!T:&4@;&]G:6YN86UE"B,@0'!A<F%M("UH;W-T("`@("`@
M("!H;W-T;F%M92!T;R!B92!C;VYN96-T960*(R!`<&%R86T@+71I;65O=70@
M("`@('1I;65O=70@9F]R(&5A8V@@<W1E<`HC($!P87)A;2`M;&]G("`@("`@
M("`@9FEL92!F;W(@=W)I=&EN9R!E<G)O<B!M97-S86=E<PHC($!P87)A;2`M
M;W5T<'5T("`@("`@9FEL92!F;W(@;&]G:6YG('1H92!O=71P=70*(R!`<&%R
M86T@+71E;&YE="`@("`@('5S92!T96QN970*(R!`<&%R86T@+7-S:"`@("`@
M("`@('5S92!S<V@@*&1E9F%U;'0I"B,@0'!A<F%M("UR;&]G:6X@("`@("!U
M<V4@<FQO9VEN"B,@0'!A<F%M("US;&]G:6X@("`@("!U<V4@<VQO9VEN"B,@
M0'!A<F%M("UP<F]G<F%M("`@("!C;VUM86YD(&9O<B!C:&%N9VEN9R!P87-S
M=V]R9',*(PHC($!R971U<FX@("`@("`@("`@("`@,"!O;B!S=6-C97-S+"`Q
M(&]N(&9A:6QU<F4*(PH*"B,@9&5F875L=',*<V5T(&AO<W0@(FQO8V%L:&]S
M="(*<V5T(&QO9VEN(")S<V@B"G-E="!P<F]G<F%M(")P87-S=V0B"G-E="!P
M<F]M<'1?<W1R:6YG("(H)7Q<7%PD?#XI(@IS970@9FEN9V5R<')I;G1?<W1R
M:6YG(")4:&4@875T:&5N=&EC:71Y(&]F(&AO<W0N*B!C86XG="!B92!E<W1A
M8FQI<VAE9"XJ7&Y24T$@:V5Y(&9I;F=E<G!R:6YT(&ES+BI<;D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU92!C;VYN96-T:6YG+BHB"G-E="!P
M87-S=V]R9%]S=')I;F<@(BA0?'`I87-S=V]R9"XJ(@IS970@;VQD<&%S<W=O
M<F1?<W1R:6YG("(H*$]\;REL9'QL;V=I;GQ<7%PH8W5R<F5N=%Q<7"D@54Y)
M6"D@*%!\<"EA<W-W;W)D+BHB"G-E="!N97=P87-S=V]R9%]S=')I;F<@(BA.
M?&XI97<N*B`H4'QP*6%S<W=O<F0N*B(*(W-E="!B861P87-S=V]R9%]S=')I
M;F<@(BAP87-S=V1\0D%$(%!!4U-73U)$*2XJ7B(*<V5T(&)A9'!A<W-W;W)D
M7W-T<FEN9R`B*'!A<W-W9'Q"860Z*2XJ7'(B"G-E="!V97)I9GE?<W1R:6YG
M("(H*%)\<BEE+2IE;G1E<BXJ*%!\<"EA<W-W;W)D?%)E='EP92!N97<H(%5.
M25@I/R!P87-S=V]R9'PH5GQV*65R:69I8V%T:6]N?"A6?'8I97)I9GE\*$%\
M82EG86EN*2XJ(@IS970@<W5C8V5S<U]S=')I;F<@(B@H4'QP*6%S<W=O<F0N
M*B!C:&%N9V5D?'-U8V-E<W-F=6QL>2DB"G-E="!L;V=I;E]S=')I;F<@(B@H
M*$Q\;"EO9VEN?"A5?'4I<V5R;F%M92DN*BDB"G-E="!T:6UE;W5T(#(P"G-E
M="!L;V<@(B]T;7`O<&%S<W=D+F]U="(*<V5T(&]U='!U="!F86QS90IS970@
M;W5T<'5T7V9I;&4@(B]T;7`O<&%S<W=D+FQO9R(*"B,@<F5A9"!I;G!U="!F
M<F]M('-T9&EN"@IG971S('-T9&EN('5S97(*9V5T<R!S=&1I;B!P87-S=V]R
M9"AO;&0I"F=E=',@<W1D:6X@<&%S<W=O<F0H;F5W*0H*"B,@<F5A9"!I;G!U
M="!F<F]M(&-O;6UA;F0@;&EN90HC:68@>R1A<F=C(#P@,WT@>PHC("`@('-E
M;F1?=7-E<B`B5&]O(&9E=R!A<F=U;65N=',Z(%5S86=E("1A<F=V,"!U<V5R
M;F%M92!O;&1P87-S(&YE=W!A<W,B"B,@("`@97AI="`Q"B-]"B-S970@=7-E
M<B!;;&EN9&5X("1A<F=V(#!="B-S970@<&%S<W=O<F0H;VQD*2!;;&EN9&5X
M("1A<F=V(#%="B-S970@<&%S<W=O<F0H;F5W*2!;;&EN9&5X("1A<F=V(#)=
M"@HC;F\@;W5T<'5T('1O('1H92!U<V5R"FQO9U]U<V5R(#`*"B,@<F5A9"!I
M;B!O=&AE<B!O<'1I;VYS"F9O<B![<V5T(&D@,'T@>R1I/"1A<F=C?2![:6YC
M<B!I?2!["B`@("!S970@87)G(%ML:6YD97@@)&%R9W8@)&E="B`@("!S=VET
M8V@@+2T@)&%R9R`B+7!R;VUP="(@>PH@("`@("`@(&EN8W(@:0H@("`@("`@
M('-E="!P<F]M<'1?<W1R:6YG(%ML:6YD97@@)&%R9W8@)&E="B`@("`@("`@
M8V]N=&EN=64*("`@('T@(BUP87-S=V]R9"(@>PH@("`@("`@(&EN8W(@:0H@
M("`@("`@('-E="!P87-S=V]R9%]S=')I;F<@6VQI;F1E>"`D87)G=B`D:5T*
M("`@("`@("!C;VYT:6YU90H@("`@?2`B+6]L9'!A<W-W;W)D(B!["B`@("`@
M("`@:6YC<B!I"B`@("`@("`@<V5T(&]L9'!A<W-W;W)D7W-T<FEN9R!;;&EN
M9&5X("1A<F=V("1I70H@("`@("`@(&-O;G1I;G5E"B`@("!]("(M;F5W<&%S
M<W=O<F0B('L*("`@("`@("!I;F-R(&D*("`@("`@("!S970@;F5W<&%S<W=O
M<F1?<W1R:6YG(%ML:6YD97@@)&%R9W8@)&E="B`@("`@("`@8V]N=&EN=64*
M("`@('T@(BUV97)I9GDB('L*("`@("`@("!I;F-R(&D*("`@("`@("!S970@
M=F5R:69Y7W-T<FEN9R!;;&EN9&5X("1A<F=V("1I70H@("`@("`@(&-O;G1I
M;G5E"B`@("!]("(M<W5C8V5S<R(@>PH@("`@("`@(&EN8W(@:0H@("`@("`@
M('-E="!S=6-C97-S7W-T<FEN9R!;;&EN9&5X("1A<F=V("1I70H@("`@("`@
M(&-O;G1I;G5E"B`@("!]("(M;&]G:6XB('L*("`@("`@("!I;F-R(&D*("`@
M("`@("!S970@;&]G:6Y?<W1R:6YG(%ML:6YD97@@)&%R9W8@)&E="B`@("`@
M("`@8V]N=&EN=64*("`@('T@(BUH;W-T(B!["B`@("`@("`@:6YC<B!I"B`@
M("`@("`@<V5T(&AO<W0@6VQI;F1E>"`D87)G=B`D:5T*("`@("`@("!C;VYT
M:6YU90H@("`@?2`B+71I;65O=70B('L*("`@("`@("!I;F-R(&D*("`@("`@
M("!S970@=&EM96]U="!;;&EN9&5X("1A<F=V("1I70H@("`@("`@(&-O;G1I
M;G5E"B`@("!]("(M;&]G(B!["B`@("`@("`@:6YC<B!I"B`@("`@("`@<V5T
M(&QO9R!;;&EN9&5X("1A<F=V("1I70H@("`@("`@(&-O;G1I;G5E"B`@("!]
M("(M;W5T<'5T(B!["B`@("`@("`@:6YC<B!I"B`@("`@("`@<V5T(&]U='!U
M=%]F:6QE(%ML:6YD97@@)&%R9W8@)&E="B`@("`@("`@<V5T(&]U='!U="!T
M<G5E"B`@("`@("`@8V]N=&EN=64*("`@('T@(BUT96QN970B('L*("`@("`@
M("!S970@;&]G:6X@(G1E;&YE="(*("`@("`@("!C;VYT:6YU90H@("`@?2`B
M+7-S:"(@>PH@("`@("`@('-E="!L;V=I;B`B<W-H(@H@("`@("`@(&-O;G1I
M;G5E"B`@("!]("(M<FQO9VEN(B!["B`@("`@("`@<V5T(&QO9VEN(")R;&]G
M:6XB"B`@("`@("`@8V]N=&EN=64*("`@('T@(BUS;&]G:6XB('L*("`@("`@
M("!S970@;&]G:6X@(G-L;V=I;B(*("`@("`@("!C;VYT:6YU90H@("`@?2`B
M+7!R;V=R86TB('L*("`@("`@("!I;F-R(&D*("`@("`@("!S970@<')O9W)A
M;2!;;&EN9&5X("1A<F=V("1I70H@("`@("`@(&-O;G1I;G5E"B`@("!]"GT*
M"B,@;&]G('-E<W-I;VX*:68@>R1O=71P=71]('L*("`@;&]G7V9I;&4@)&]U
M='!U=%]F:6QE"GT*"G-E="!E<G(@6V]P96X@)&QO9R`B=R(@(C`V,#`B70H*
M(R!S=&%R="!R96UO=&4@<V5S<VEO;@II9B![6W-T<FEN9R!M871C:"`D;&]G
M:6X@(G)L;V=I;B)=?2!["B`@('-E="!P:60@6W-P87=N(')L;V=I;B`D:&]S
M="`M;"`D=7-E<ET*?2!E;'-E:68@>UMS=')I;F<@;6%T8V@@)&QO9VEN(")S
M;&]G:6XB77T@>PH@("!S970@<&ED(%MS<&%W;B!S;&]G:6X@)&AO<W0@+6P@
M)'5S97)="GT@96QS96EF('M;<W1R:6YG(&UA=&-H("1L;V=I;B`B<W-H(EU]
M('L*("`@<V5T('!I9"!;<W!A=VX@<W-H("1H;W-T("UL("1U<V5R70I](&5L
M<V5I9B![6W-T<FEN9R!M871C:"`D;&]G:6X@(G1E;&YE=")=?2!["B`@('-E
M="!P:60@6W-P87=N('1E;&YE="`D:&]S=%T*("`@97AP96-T("UR92`D;&]G
M:6Y?<W1R:6YG('L*("`@("!S;&5E<"`N-0H@("`@('-E;F0@(B1U<V5R7'(B
M"B`@('T*?2!E;'-E('L*("`@<'5T<R`D97)R("));G9A;&ED(&QO9VEN(&UO
M9&4Z('9A;&ED(&UO9&5S.B!R;&]G:6XL('-L;V=I;BP@<W-H+"!T96QN971<
M;B(*("`@8VQO<V4@)&5R<@H@("!E>&ET(#$*?0H*(R!L;V<@:6X*97AP96-T
M('L*("`M<F4@)&9I;F=E<G!R:6YT7W-T<FEN9R![<VQE97`@+C4*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<V5N9"!Y97-<<GT*("`M<F4@)'!A<W-W
M;W)D7W-T<FEN9R`@("![<VQE97`@+C4*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<V5N9"`D<&%S<W=O<F0H;VQD*5QR?0H@('1I;65O=70@("`@("`@
M("`@("`@("`@('MP=71S("1E<G(@(D-O=6QD(&YO="!L;V=I;B!T;R!S>7-T
M96T@*&YO('!A<W-W;W)D('!R;VUP="E<;B(*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8VQO<V4@)&5R<@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!E>&ET(#%]"GT*"B,@<W1A<G0@<&%S<W=O<F0@8VAA;F=I;F<@<')O9W)A
M;0IS970@;VQD7W!A<W-W;W)D7VYO=&5N=&5R960@=')U90IE>'!E8W0@>PH@
M("UR92`D<')O;7!T7W-T<FEN9R`@("`@('MS;&5E<"`N-0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S96YD("1P<F]G<F%M7')]"B`@(R!4:&4@9F]L
M;&]W:6YG(&ES(&9O<B!W:&5N('!A<W-W9"!I<R!T:&4@;&]G:6X@<VAE;&P*
M("`M<F4@)&]L9'!A<W-W;W)D7W-T<FEN9R![<VQE97`@+C4*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<V5N9"`D<&%S<W=O<F0H;VQD*5QR"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-E="!O;&1?<&%S<W=O<F1?;F]T96YT
M97)E9"!F86QS97T*("!T:6UE;W5T("`@("`@("`@("`@("`@("![<'5T<R`D
M97)R("`B0V]U;&0@;F]T(&QO9VEN('1O('-Y<W1E;2`H8F%D(&]L9"!P87-S
M=V]R9#\I7&XB"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E("1E
M<G(*("`@("`@("`@("`@("`@("`@("`@("`@("`@97AI="`Q?0I]"@HC('-E
M;F0@;VQD('!A<W-W;W)D"FEF('LD;VQD7W!A<W-W;W)D7VYO=&5N=&5R961]
M('L*("!E>'!E8W0@>PH@("`@+7)E("1O;&1P87-S=V]R9%]S=')I;F<@>W-L
M965P("XU"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<V5N9"`D<&%S
M<W=O<F0H;VQD*5QR?0H@("`@=&EM96]U="`@("`@("`@("`@("`@("`@>W!U
M=',@)&5R<B`B0V]U;&0@;F]T('-T87)T('!A<W-W9"!P<F]G<F%M("AN;R!O
M;&0@<&%S<W=O<F0@<')O;7!T*5QN(@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-L;W-E("1E<G(*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!E>&ET(#%]"B`@?0I]"@HC('-E;F0@;F5W('!A<W-W;W)D"F5X<&5C="![
M"B`@+7)E("1N97=P87-S=V]R9%]S=')I;F<@>W-L965P("XU"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-E;F0@)'!A<W-W;W)D*&YE=RE<<GT*("!T
M:6UE;W5T("`@("`@("`@("`@("`@("![<'5T<R`B0V]U;&0@;F]T(&-H86YG
M92!P87-S=V]R9"`H8F%D(&]L9"!P87-S=V]R9#\I7&XB"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-L;W-E("1E<G(*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@97AI="`Q?0I]"@HC('-E;F0@;F5W('!A<W-W;W)D(&%G86EN
M"F5X<&5C="!["B`@+7)E("1B861P87-S=V]R9%]S=')I;F<@>W!U=',@)&5R
M<B`B)&5X<&5C=%]O=70H,"QS=')I;F<I(@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C;&]S92`D97)R"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-E;F0@7#`P,PH@("`@("`@("`@("`@("`@("`@("`@("`@("!S;&5E<"`N
M-0H@("`@("`@("`@("`@("`@("`@("`@("`@("!E>&ET(#%]"B`@+7)E("1V
M97)I9GE?<W1R:6YG("`@("`@>W-L965P("XU"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-E;F0@)'!A<W-W;W)D*&YE=RE<<GT*("!T:6UE;W5T("`@
M("`@("`@("`@("`@("![<'5T<R`D97)R(").97<@<&%S<W=O<F0@;F]T('9A
M;&ED("AT;V\@<VAO<G0L(&)A9"!P87-S=V]R9"P@=&]O('-I;6EL87(L("XN
M+BE<;B(*("`@("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4@)&5R<@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S96YD(%PP,#,*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<VQE97`@+C4*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@97AI="`Q?0I]"@HC(&-H96-K(')E<W!O;G-E"F5X<&5C="![
M"B`@+7)E("1S=6-C97-S7W-T<FEN9R![<VQE97`@+C4*("`@("`@("`@("`@
M("`@("`@("`@("!S96YD(&5X:71<<GT*("`M<F4@)&)A9'!A<W-W;W)D7W-T
M<FEN9R![<'5T<R`D97)R("(D97AP96-T7V]U="@P+'-T<FEN9RDB"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-L;W-E("1E<G(*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@97AI="`Q?0H@('1I;65O=70@("`@("`@("`@("`@
M>W!U=',@)&5R<B`B0V]U;&0@;F]T(&-H86YG92!P87-S=V]R9"Y<;B(*("`@
M("`@("`@("`@("`@("`@("`@("!C;&]S92`D97)R"B`@("`@("`@("`@("`@
M("`@("`@("`@97AI="`Q?0I]"@HC(&5X:70@<W5C8W-E<W-F=6QL>0IE>'!E
M8W0@>PH@(&5O9B![8VQO<V4@)&5R<@H@("`@("`@97AI="`P?0I]"F-L;W-E
M("1E<G(*````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P87-S=V0O<V-R:7!T<R]K<&%S<W=D7V5X<&5C=```````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S`U`#$P-#$W,S8R-S0S`#`R,C,V
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M("1(;W)D93H@<&%S<W=D+W-C<FEP=',O:W!A<W-W9%]E>'!E8W0L=B`Q+C(@
M,C`P-2\P,R\P,2`P.3HS,CHQ-"!J86X@17AP("0*(PHC(%1H92!F;VQL;W=I
M;F<@97AP96-T('-C<FEP="!E;F%B;&5S('1H92!P87-S=V]R9"!C:&%N9V4@
M;W9E<B!K97)B97)O<PHC(&MP87-S=V0N"B,*(R`@1&EL>6%N(%!A;&%U>F]V
M(#QD:61O<&%L875Z;W9`865G964N;W)G/BP@,C`P-0HC"F=E=',@<W1D:6X@
M=7-E<@IG971S('-T9&EN(&]L9'!W"F=E=',@<W1D:6X@;F5W<'<*<V5T(&QO
M9R!;;&EN9&5X("1A<F=V(#%="G-E="!E<G(@6V]P96X@)&QO9R`B=R(@(C`V
M,#`B70IS970@<&ED(%MS<&%W;B`O=7-R+V)I;B]K<&%S<W=D("1U<V5R70IS
M970@=&EM96]U="`Q"F5X<&5C="!["B`@("`B4&%S<W=O<F0@9F]R("HZ("(*
M("`@('L*("`@("`@("!S96YD("1O;&1P=UQR"B`@("!]"B`@("!E;V8@>PH@
M("`@("`@('!U=',@)&5R<B`D97AP96-T7V]U="AB=69F97(I"B`@("`@("`@
M8VQO<V4@)&5R<@H@("`@("`@(&5X:70@,0H@("`@?0I]"@IE>'!E8W0@>PH@
M("`@(D5N=&5R(&YE=R!P87-S=V]R9#H@.B`B"B`@("!["B`@("`@("`@<V5N
M9"`D;F5W<'=<<@H@("`@?0H@("`@96]F('L*("`@("`@("!P=71S("1E<G(@
M)&5X<&5C=%]O=70H8G5F9F5R*0H@("`@("`@(&-L;W-E("1E<G(*("`@("`@
M("!E>&ET(#$*("`@('T*?0IE>'!E8W0@>PH@("`@96]F('ME>&ET(#%]"B`@
M("`B16YT97(@:70@86=A:6XZ(#H@(@H@("`@>PH@("`@("`@('-E;F0@)&YE
M=W!W7'(*("`@('T*?0IE>'!E8W0@>PH@("`@96]F('L*("`@("`@("!P=71S
M("1E<G(@)&5X<&5C=%]O=70H8G5F9F5R*0H@("`@("`@(&-L;W-E(&5R<@H@
M("`@("`@(&5X:70@,0H@("`@?0H@("`@(E!A<W-W;W)D(&-H86YG960N(@H@
M("`@>PH@("`@("`@(&-L;W-E(&5R<@H@("`@("`@(&5X:70@,`H@("`@?0I]
M"@IC;&]S92!E<G(*97AI="`P"@``````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P87-S=V0O;&EB+P``````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S
M`#`Q-C0W,@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L:6(O1')I
M=F5R+P``````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#,`,#$W-S(U`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+VQI8B]$<FEV97(O;&1A<"YP:'``````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`R-#(T,@`Q,#0Q-S,V,C<T,P`P,C$S-3<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!,1$%0(&-L87-S(&%T=&5M<'1S('1O(&-H86YG92!A('5S
M97(G<R!P87-S=V]R9"!S=&]R960@:6X@86X@3$1!4`H@*B!D:7)E8W1O<GD@
M<V5R=FEC92X*("H*("H@)$AO<F1E.B!P87-S=V0O;&EB+T1R:79E<B]L9&%P
M+G!H<"QV(#$N-#$@,C`P-2\P.2\R,B`P.3HT.#HP-"!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#`M,C`P-2!(;W)D92!0<F]J96-T("AH='1P.B\O
M=W=W+FAO<F1E+F]R9R\I"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,
M24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H;W(@($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!A=71H
M;W(@(%1J965R9"!V86X@9&5R(%IE92`\861M:6Y`>&%R+FYL/@H@*B!`875T
M:&]R("!-871T:6%S(%=E8FKV<FX@17)I:W-S;VX@/&UA='1I87-`=V5B:F]R
M;BYO<F<^"B`J($!A=71H;W(@($5R:6,@2F]N(%)O<W1E='1E<B`\97)I8RYR
M;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@*B!`<&%C:V%G92!087-S
M=V0*("HO"F-L87-S(%!A<W-W9%]$<FEV97)?;&1A<"!E>'1E;F1S(%!A<W-W
M9%]$<FEV97(@>PH*("`@("\J*@H@("`@("H@3$1!4"!C;VYN96-T:6]N(&AA
M;F1L92X*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@
M('9A<B`D7V1S.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!0
M87-S=V1?1')I=F5R7VQD87`@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%!A<W-W9%]$<FEV
M97)?;&1A<"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI
M<RT^7W!A<F%M<R`](&%R<F%Y7VUE<F=E*&%R<F%Y*"=H;W-T)R`]/B`G;&]C
M86QH;W-T)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S<VQH;W-T)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=P;W)T)R`]/B`S.#DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G96YC<GEP=&EO
M;B<@/3X@)V-R>7!T)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S:&]W7V5N8W)Y<'1I;VXG(#T^("=T<G5E)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U:60G
M(#T^("=U:60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V)A<V5D;B<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G861M:6YD;B<@/3X@;G5L;"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A9&UI
M;G!W)R`]/B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E86QM)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T;',G(#T^(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB
M=71E)R`]/B`G=7-E<E!A<W-W;W)D)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=S:&%D;W=L87-T8VAA;F=E)R`]/B!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W-H861O=VUI;B<@/3X@;G5L;"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($1O97,@86X@3$1!4"!C;VYN96-T(&%N9"!B:6YD<R!A<R!T:&4@9W5E
M<W0@=7-E<B!O<B!A<R!T:&4@;W!T:6]N86P*("`@("`J('5S97)D;BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R9&X@("`@("`@5&AE(&1N
M('1O('5S92!W:&5N(&)I;F1I;F<@;F]N+6%N;VYY;6]U<VQY+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;VQD<&%S<W=O<F0@(%1H92!P87-S=V]R9"!F;W(@
M)'5S97)D;BX*("`@("`J($!P87)A;2!B;V]L96%N("1S<VP@("`@("`@("!4
M:&4@4U-,('1R:6=G97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&]R($9A;'-E(&)A<V5D(&]N('-U8V-E<W,@;V8@8V]N;F5C="!A
M;F0@8FEN9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H)'5S97)D
M;B`](&YU;&PL("1P87-S=V]R9"`](&YU;&PL("1S<VP@/2!F86QS92D*("`@
M('L*("`@("`@("!I9B`H)'-S;"`F)B!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M=&QS)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?9',@/2!L9&%P7V-O;FYE
M8W0H)VQD87!S.B\O)R`N("1T:&ES+3Y?<&%R86US6R=S<VQH;W-T)UTI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?9',@/2!L9&%P
M7V-O;FYE8W0H)'1H:7,M/E]P87)A;7-;)VAO<W0G72P@)'1H:7,M/E]P87)A
M;7-;)W!O<G0G72D["B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M/E]D
M<RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(I*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AL9&%P7W-E=%]O<'1I;VXH)'1H:7,M/E]D<RP@3$1!
M4%]/4%1?4%)/5$]#3TQ?5D524TE/3BP@,RD@)B8*("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1L<R==*2!["B`@("`@("`@("`@(&EF("@A;&1A<%]S
M=&%R=%]T;',H)'1H:7,M/E]D<RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(FQD87!?<W1A<G1?=&QS(&9A:6QE9"(I
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]
M(&9A;'-E.PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7W!A<F%M<ULG
M861M:6YD;B==*2D@>PH@("`@("`@("`@("`O+R!)9B!W92!H879E(&%N(&%D
M;6EN9&XL('1R>2!T;R!B:6YD(&%S(&%D;6EN+@H@("`@("`@("`@("`D<F5S
M=6QT(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S+"`D=&AI<RT^7W!A<F%M<ULG
M861M:6YD;B==+"`D=&AI<RT^7W!A<F%M<ULG861M:6YP=R==*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!4<GD@=&\@8FEN9"!A<R!T:&4@
M8W5R<F5N="!U<V5R9&X@=VET:"!P87-S=V]R9"X*("`@("`@("`@("`@:68@
M*"%I<U]N=6QL*"1U<V5R9&XI*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S+"`D=7-E<F1N+"`D<&%S<W=O<F0I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L
M="`]($!L9&%P7V)I;F0H)'1H:7,M/E]D<RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\O($EF(&YO;F4@;V8@=&AE(&)I;F0@871T96UP
M=',@<W5C8V5E9"P@<F5T=7)N(&5R<F]R+@H@("`@("`@(&EF("@A)')E<W5L
M="D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#
M;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]O
M:W,@=7`@86YD(')E='5R;G,@=&AE('5S97(G<R!D;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R("`@(%1H92!U<V5R;F%M92!O9B!T:&4@
M=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W("`@5&AE('!A<W-W
M;W)D(&]F('1H92!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5A;&T@
M("!4:&4@<F5A;&T@*&1O;6%I;BD@;F%M92!O9B!T:&4@=7-E<BX*("`@("`J
M($!P87)A;2!S=')I;F<@)&)A<V5D;B`@5&AE(&QD87`@8F%S961N+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=6ED("`@("!4:&4@;&1A<"!U:60N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L9&%P(&1N(&9O<B!T:&4@
M=7-E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO;VMU<&1N*"1U<V5R+"`D
M<&%S<W<I"B`@("!["B`@("`@("`@+R\@0V]N<W1R=6-T('5S97)N86UE0')E
M86QM('1O(&-O;FYE8W0@87,@:68@)W)E86QM)R!P87)A;65T97(@:7,@<V5T
M+@H@("`@("`@("1U<F5A;&T@/2`G)SL*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=R96%L;2==*2D@>PH@("`@("`@("`@("`D=7)E86QM
M(#T@)'5S97(@+B`G0"<@+B`D=&AI<RT^7W!A<F%M<ULG<F5A;&TG73L*("`@
M("`@("!]"@H@("`@("`@("\O($)I;F0@87,@8W5R<F5N="!U<V5R+B!?8V]N
M;F5C="!W:6QL('1R>2!A<R!G=65S="!I9B!N;R!U<V5R(')E86QM"B`@("`@
M("`@+R\@:7,@9F]U;F0@;W(@875T:"!E<G)O<BX*("`@("`@("`D=&AI<RT^
M7V-O;FYE8W0H)'5R96%L;2P@)'!A<W-W*3L*"B`@("`@("`@+R\@0V]N<W1R
M=6-T('-E87)C:"X*("`@("`@("`D<V5A<F-H(#T@)'1H:7,M/E]P87)A;7-;
M)W5I9"==("X@)STG("X@)'5S97(["@H@("`@("`@("\O($=E="!U<V5R9&XN
M"B`@("`@("`@)')E<W5L="`](&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T
M:&ES+3Y?<&%R86US6R=B87-E9&XG72P@)'-E87)C:"D["B`@("`@("`@)&5N
M=')Y(#T@;&1A<%]F:7)S=%]E;G1R>2@D=&AI<RT^7V1S+"`D<F5S=6QT*3L*
M("`@("`@("!I9B`H)&5N=')Y(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5<V5R(&YO="!F;W5N9"XB*2D[
M"B`@("`@("`@?0H*("`@("`@("`O+R!)9B!W92!U<V5D(&%D;6EN(&)I;F1I
M;F=S+"!W92!H879E('1O(&-H96-K('1H92!P87-S=V]R9"!H97)E+@H@("`@
M("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7W!A<F%M<ULG861M:6YD;B==*2D@
M>PH@("`@("`@("`@("`D;&1A<'!A<W-W9"`](&QD87!?9V5T7W9A;'5E<R@D
M=&AI<RT^7V1S+"`D96YT<GDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=A='1R:6)U=&4G72D[
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8V]M<&%R95!A<W-W;W)D
M<R@D;&1A<'!A<W-W9%LP72P@)'!A<W-W*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!L9&%P7V=E=%]D;B@D=&AI<RT^7V1S+"`D96YT<GDI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&9O<B!S:&%D;W=,87-T0VAA
M;F=E(&%N9"!S:&%D;W=-:6X@<W5P<&]R="!A;F0@<F5T=7)N<R!T:&5I<@H@
M("`@("H@=F%L=65S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S
M97(@("!4:&4@=7-E<FYA;64@;V8@=&AE('5S97(N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87-S=R`@5&AE('!A<W-W;W)D(&]F('1H92!U<V5R+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($AA<V@@=VET:"!K97ES(&)E:6YG
M(")S:&%D;W=L87-T8VAA;F=E(B!A;F0@(G-H861O=VUI;B(*("`@("`J("`@
M("`@("`@("`@("`@(&%N9"!C;VYT86EN:6YG('1H96ER(')E<W!E8W1I=F4@
M=F%L=65S(&]R(&9A;'-E(&9O<B!N;PH@("`@("H@("`@("`@("`@("`@("`@
M<W5P<&]R="X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO;VMU<%-H861O=R@D
M=7-E<BP@)'!A<W-W*0H@("`@>PH@("`@("`@("\O($EN:70@=&AE(')E='5R
M;B!A<G)A>0H@("`@("`@("1L;V]K=7!S:&%D;W<@/2!A<G)A>2@G<VAA9&]W
M;&%S=&-H86YG92<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S:&%D;W=M:6XG(#T^(&9A;'-E*3L*"B`@("`@("`@+R\@0V]N
M<W1R=6-T('5S97)N86UE0')E86QM('1O(&-O;FYE8W0@87,@:68@)W)E86QM
M)R!P87)A;65T97(@:7,@<V5T+@H@("`@("`@("1U<F5A;&T@/2`D=7-E<CL*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=R96%L;2==*2D@
M>PH@("`@("`@("`@("`D=7)E86QM("X]("=`)R`N("1T:&ES+3Y?<&%R86US
M6R=R96%L;2==.PH@("`@("`@('T*"B`@("`@("`@+R\@0FEN9"!A<R!C=7)R
M96YT('5S97(N(%]C;VYN96-T('=I;&P@=')Y(&%S(&=U97-T(&EF(&YO('5S
M97(@<F5A;&T*("`@("`@("`O+R!I<R!F;W5N9"!O<B!A=71H(&5R<F]R+@H@
M("`@("`@("1T:&ES+3Y?8V]N;F5C="@D=7)E86QM+"`D<&%S<W<I.PH*("`@
M("`@("`O+R!#;VYS=')U8W0@<V5A<F-H+@H@("`@("`@("1S96%R8V@@/2`D
M=&AI<RT^7W!A<F%M<ULG=6ED)UT@+B`G/2<@+B`D=7-E<CL*"B`@("`@("`@
M+R\@1V5T('5S97)D;BX*("`@("`@("`D<F5S=6QT(#T@;&1A<%]S96%R8V@H
M)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+"`D<V5A<F-H
M*3L*("`@("`@("`D96YT<GD@/2!L9&%P7V9I<G-T7V5N=')Y*"1T:&ES+3Y?
M9',L("1R97-U;'0I.PH@("`@("`@(&EF("@D96YT<GD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("1I;F9O<FUA=&EO;B`](&QD87!?9V5T7W9A;'5E<R@D
M=&AI<RT^7V1S+"`D96YT<GDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<VAA9&]W;&%S=&-H
M86YG92==*3L*("`@("`@("`@("`@:68@*"1I;F9O<FUA=&EO;BD@>PH@("`@
M("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W;&%S=&-H86YG92==
M(#T@)&EN9F]R;6%T:6]N6S!=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D:6YF;W)M871I;VX@/2!L9&%P7V=E=%]V86QU97,H)'1H:7,M/E]D<RP@
M)&5N=')Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W-H861O=VUI;B==*3L*("`@("`@("`@
M("`@:68@*"1I;F9O<FUA=&EO;BD@>PH@("`@("`@("`@("`@("`@)&QO;VMU
M<'-H861O=ULG<VAA9&]W;6EN)UT@/2`D:6YF;W)M871I;VY;,%T["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&]O:W5P<VAA
M9&]W.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B=S
M($1.+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@("`@("!4:&4@=7-E<B!F
M;W(@=VAI8V@@=&\@8VAA;F=E('1H92!P87-S=V]R9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&]L9%]P87-S=V]R9"`@5&AE(&]L9"`H8W5R<F5N="D@=7-E
M<B!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('5S97(G<R!$3B!O<B!A(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]U<V5R1$XH)'5S97)N86UE+"`D;VQD7W!A<W-W;W)D*0H@("`@>PH@
M("`@("`@(&EF("@D1TQ/0D%,4ULG8V]N9B==6R=H;V]K<R==6R=U<V5R9&XG
M72D@>PH@("`@("`@("`@("`D=7-E<F1N(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?
M<&%S<W=D7VAO;VM?=7-E<F1N)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2A!=71H.CIG971!=71H*"DI*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=7-E<F1N(#T@)'1H:7,M/E]L;V]K
M=7!D;B@D=7-E<FYA;64L("1O;&1?<&%S<W=O<F0I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D=7-E<F1N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'5S97)D;CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@0V]N<W1R=6-T('5S97)N86UE0')E86QM('1O(&-O;FYE
M8W0@:68@)W)E86QM)R!P87)A;65T97(@:7,@<V5T+@H@("`@("`@("\O($QO
M;VMS(&QI:V4@=&AE(%]P87-S=V1?:&]O:U]U<V5R;F%M92!H;V]K+"!B=70@
M:&5R92!W92!U<V4@80H@("`@("`@("\O(&-O;F9I9W5R86)L92!P87)A;65T
M97(@87,@<F5A;&TN("!4:&ES(&ES(&$@<V%F96=U87)D('1H870@:68*("`@
M("`@("`O+R!U;F%B;&4@=&\@;&]O:W5P('1H92!U<V5R)W,@1$X@=V4@<W1I
M;&P@:&%V92!A(&-H86YC92!T;PH@("`@("`@("\O(&%U=&AE;G1I8V%T92X*
M("`@("`@("!I9B`H96UP='DH)'5S97)D;BD@)B8@(65M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=R96%L;2==*2D@>PH@("`@("`@("`@("`D=7-E<F1N(#T@)'5S
M97)N86UE("X@)T`G("X@)'1H:7,M/E]P87)A;7-;)W)E86QM)UT["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'5S97)D;CL*("`@('T*"B`@("`O*BH*
M("`@("`J($-H86YG97,@=&AE('5S97(G<R!P87-S=V]R9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92`@("`@(%1H92!U<V5R(&9O
M<B!W:&EC:"!T;R!C:&%N9V4@=&AE('!A<W-W;W)D+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;VQD7W!A<W-W;W)D("!4:&4@;VQD("AC=7)R96YT*2!U<V5R
M('!A<W-W;W)D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W7W!A<W-W;W)D
M("!4:&4@;F5W('5S97(@<&%S<W=O<F0@=&\@<V5T+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O<B!014%27T5R<F]R(&)A<V5D(&]N
M('-U8V-E<W,@;V8@=&AE(&-H86YG92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VAA;F=E4&%S<W=O<F0H)'5S97)N86UE+"`D;VQD7W!A<W-W;W)D+"`D;F5W
M7W!A<W-W;W)D*0H@("`@>PH@("`@("`@("\O($=E="!T:&4@=7-E<B=S(&1N
M+@H@("`@("`@("1U<V5R9&X@/2`D=&AI<RT^7W5S97)$3B@D=7-E<FYA;64L
M("1O;&1?<&%S<W=O<F0I.PH@("`@("`@(&EF("AI<U]A*"1U<V5R9&XL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1U<V5R9&X["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]P87)A;7-;
M)W-H861O=VQA<W1C:&%N9V4G72DI('L*("`@("`@("`@("`@)&QO;VMU<'-H
M861O=R`]("1T:&ES+3Y?;&]O:W5P4VAA9&]W*"1U<V5R;F%M92P@)&]L9%]P
M87-S=V]R9"D["@H@("`@("`@("`@("`O+R!#:&5C:R!I9B!W92!M87D@8VAA
M;F=E('1H92!P87-S=V]R9`H@("`@("`@("`@("!I9B`H)&QO;VMU<'-H861O
M=ULG<VAA9&]W;&%S=&-H86YG92==("8F"B`@("`@("`@("`@("`@("`D;&]O
M:W5P<VAA9&]W6R=S:&%D;W=M:6XG72`F)@H@("`@("`@("`@("`@("`@*"1L
M;V]K=7!S:&%D;W=;)W-H861O=VQA<W1C:&%N9V4G72`K("1L;V]K=7!S:&%D
M;W=;)W-H861O=VUI;B==(#X@*'1I;64H*2`O(#@V-#`P*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DUI;FEM=6T@
M<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B*2D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-O;FYE8W0@87,@=&AE('5S
M97(N"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V]N;F5C="@D=7-E<F1N
M+"`D;VQD7W!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=S<VQH;W-T)UTI*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(&EF("@D<F5S=6QT+3YG971-97-S86=E*"D@/3T@7R@B0V]U;&0@
M;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YC;W)R96-T(%!A<W-W;W)D
M(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAA;F=E('1H92!U<V5R)W,@<&%S
M<W=O<F0@86YD('5P9&%T92!L87-T8VAA;F=E"B`@("`@("`@)&YE=U]D971A
M:6QS6R1T:&ES+3Y?<&%R86US6R=A='1R:6)U=&4G75T@/2`D=&AI<RT^96YC
M<GEP=%!A<W-W;W)D*"1N97=?<&%S<W=O<F0I.PH*("`@("`@("!I9B`H(6ES
M7VYU;&PH)'1H:7,M/E]P87)A;7-;)W-H861O=VQA<W1C:&%N9V4G72D@)B8*
M("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W;&%S=&-H86YG92==
M*2!["B`@("`@("`@("`@("1N97=?9&5T86EL<ULD=&AI<RT^7W!A<F%M<ULG
M<VAA9&]W;&%S=&-H86YG92==72`](&9L;V]R*'1I;64H*2`O(#@V-#`P*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A;&1A<%]M;V1?<F5P;&%C92@D=&AI
M<RT^7V1S+"`D=7-E<F1N+"`D;F5W7V1E=&%I;',I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*&QD87!?97)R;W(H)'1H:7,M/E]D
M<RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&EB+T1R:79E<B]E>'!E8W0N<&AP
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C,S`#$P-#$W,S8R
M-S0S`#`R,3<S,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE(%!A<W-W9%]E>'!E8W0@8VQA<W,@
M<')O=FED97,@86X@97AP96-T(&EM<&QE;65N=&%T:6]N(&]F('1H92!P87-S
M=V0*("H@<WES=&5M+@H@*@H@*B`D2&]R9&4Z('!A<W-W9"]L:6(O1')I=F5R
M+V5X<&5C="YP:'`L=B`Q+C(P(#(P,#4O,#@O,C,@,3$Z,34Z,#8@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#4@1V%U9&5N>B!3=&5I;FQI
M;B`\9V%U9&5N>D!S;WII;VQO9VEE+F-H/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`
M875T:&]R("!'875D96YZ(%-T96EN;&EN(#QG875D96YZ+G-T96EN;&EN0&ED
M+G5N:6)E+F-H/@H@*B!`<VEN8V4@("!087-S=V0@,BXR"B`J($!P86-K86=E
M(%!A<W-W9`H@*B\*8VQA<W,@4&%S<W=D7T1R:79E<E]E>'!E8W0@97AT96YD
M<R!087-S=V1?1')I=F5R('L*"B`@("`O*BH*("`@("`J($-H86YG92!T:&4@
M=7-E<G,@<&%S<W=O<F0@8GD@97AE8W5T:6YG(&%N(&5X<&5C="!S8W)I<'0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@("`@("!5
M<V5R($E$+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD7W!A<W-W;W)D("!/
M;&0@<&%S<W=O<F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=?<&%S<W=O
M<F0@($YE=R!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W(@97)R;W(@;65S<V%G92!O
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@8VAA;F=E4&%S<W=O<F0H
M)'5S97(L("1O;&1?<&%S<W=O<F0L("1N97=?<&%S<W=O<F0I"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`O+R!386YI='D@8VAE8VMS
M+@H@("`@("`@(&EF("@A0&ES7V5X96-U=&%B;&4H)'1H:7,M/E]P87)A;7-;
M)W!R;V=R86TG72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*"(E<R!D;V5S(&YO="!E>&ES="!O<B!I<R!N;W0@
M97AE8W5T86)L92XB*2P@)'1H:7,M/E]P87)A;7-;)W!R;V=R86TG72DI.PH@
M("`@("`@('T*"B`@("`@("`@+R\@5&5M<&]R87)Y(&QO9V9I;&4@9F]R(&5R
M<F]R(&UE<W-A9V5S+@H@("`@("`@("1L;V<@/2!T96UP;F%M*&EN:5]G970H
M)W5P;&]A9%]T;7!?9&ER)RD@/PH@("`@("`@("`@("`@("`@("`@("`@(&EN
M:5]G970H)W5P;&]A9%]T;7!?9&ER)RD@.@H@("`@("`@("`@("`@("`@("`@
M("`@("<O=&UP)RP*("`@("`@("`@("`@("`@("`@("`@("`G<&%S<W=D)RD[
M"@H@("`@("`@("\O($]P96X@97AP96-T('-C<FEP="!F;W(@=W)I=&EN9RX*
M("`@("`@("`D<')O9R`]("1T:&ES+3Y?<&%R86US6R=P<F]G<F%M)UT@+B`G
M("UF("<@+B`D=&AI<RT^7W!A<F%M<ULG<V-R:7!T)UT@+@H@("`@("`@("`@
M("`G("TM("<@+B`D=&AI<RT^7W!A<F%M<ULG<&%R86US)UT@+B`G("UL;V<@
M)R`N("1L;V<["@H@("`@("`@("1E>'`@/2!`<&]P96XH)'!R;V<L("=W)RD[
M"B`@("`@("`@0&9W<FET92@D97AP+"`B)'5S97)<;B(I.PH@("`@("`@($!F
M=W)I=&4H)&5X<"P@(B1O;&1?<&%S<W=O<F1<;B(I.PH@("`@("`@($!F=W)I
M=&4H)&5X<"P@(B1N97=?<&%S<W=O<F1<;B(I.PH@("`@("`@(&EF("A`<&-L
M;W-E*"1E>'`I*2!["B`@("`@("`@("`@("1E<G)O<FUS9R`](&EM<&QO9&4H
M)R`G+"!`9FEL92@D;&]G*2D["B`@("`@("`@("`@($!U;FQI;FLH)&QO9RD[
M"B`@("`@("`@("`@(')E='5R;B`D97)R;W)M<V<@/R!014%2.CIR86ES945R
M<F]R*"1E<G)O<FUS9RD@.B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&%S<W=D+VQI8B]$<FEV97(O8V]M<&]S:71E+G!H<```
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C4U-@`Q,#0Q-S,V,C<T,P`P
M,C(T-3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!C;VUP;W-I=&4@8VQA<W,@8VAA:6YS(&]T
M:&5R(&1R:79E<G,@=&]G971H97(@=&\@8VAA;F=E(&%N9"!A('5S97(G<PH@
M*B!P87-S=V]R9"!S=&]R960@;VX@=F%R:6]U<R!B86-K96YD<RX*("H*("H@
M)$AO<F1E.B!P87-S=V0O;&EB+T1R:79E<B]C;VUP;W-I=&4N<&AP+'8@,2XW
M(#(P,#4O,#@O,C,@,3$Z,34Z,#8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D92YO
M<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L
M:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!-87@@2V%L:6MA(#QM
M87A`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!087-S=V0@,RXP"B`J($!P86-K
M86=E(%!A<W-W9`H@*B\*8VQA<W,@4&%S<W=D7T1R:79E<E]C;VUP;W-I=&4@
M97AT96YD<R!087-S=V1?1')I=F5R('L*"B`@("`O*BH*("`@("`J($AA<V@@
M;V8@:6YS=&%N=&EA=&5D(&1R:79E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>2`*("`@("`J+PH@("`@=F%R("1?9')I=F5R<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!3=&%T92!O9B!T:&4@;&]A9&5D(&1R:79E<G,N"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VQO
M861E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!087-S=V1?1')I=F5R7V-O;7!O<VET92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-H
M86EN960@9')I=F5R<R!A;F0@=&AE:7(@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@4&%S<W=D7T1R:79E<E]C;VUP;W-I=&4H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=D
M<FEV97)S)UTI('Q\("%I<U]A<G)A>2@D<&%R86US6R=D<FEV97)S)UTI*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E)E<75I
M<F5D("=D<FEV97)S)R!I<R!M:7-C;VYF:6=U<F5D(&EN($-O;7!O<VET92!C
M;VYF:6=U<F%T:6]N+B(I*3L*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ
M4&%S<W=D7T1R:79E<B@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($EN<W1A;G1I871E(&-O;F9I9W5R960@9')I=F5R<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N("!B;V]L96%N("`@5')U92!O;B!S=6-C97-S(&]R(%!%05)?
M17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861$
M<FEV97)S*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]L;V%D960I('L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==(&%S("1K97D@/3X@
M)'-E='1I;F=S*2!["B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T
M<R@D:V5Y+"`D=&AI<RT^7V1R:79E<G,I*2!["@H@("`@("`@("`@("`@("`@
M)')E<R`]("9087-S=V1?1')I=F5R.CIF86-T;W)Y*"1S971T:6YG<ULG9')I
M=F5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-E='1I;F=S6R=P87)A;7,G72D["@H@("`@("`@("`@("`@
M("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M)7,Z('5N86)L92!T;R!L;V%D(&1R:79E<CH@)7,B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1K97DL
M("1R97,M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9')I=F5R<ULD:V5Y72`]("1R97,["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&]A9&5D
M(#T@=')U93L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($-H86YG92!T:&4@=7-E<B=S('!A<W-W;W)D+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("`@("`@5&AE('5S97(@9F]R
M('=H:6-H('1O(&-H86YG92!T:&4@<&%S<W=O<F0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1O;&1?<&%S<W=O<F0@(%1H92!O;&0@*&-U<G)E;G0I('5S97(@
M<&%S<W=O<F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=?<&%S<W=O<F0@
M(%1H92!N97<@=7-E<B!P87-S=V]R9"!T;R!S970N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]R(&9A;'-E(&)A<V5D(&]N('-U8V-E
M<W,@;V8@=&AE(&-H86YG92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAA;F=E
M4&%S<W=O<F0H)'5S97)N86UE+"`@)&]L9%]P87-S=V]R9"P@)&YE=U]P87-S
M=V]R9"D*("`@('L*("`@("`@("!G;&]B86P@)&YO=&EF:6-A=&EO;CL*"B`@
M("`@("`@)')E<R`]("1T:&ES+3Y?;&]A9$1R:79E<G,H*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]D<FEV97)S(&%S("1K97D@/3X@)&1R:79E<BD@>PH@("`@("`@("`@("`D
M<F5S(#T@)&1R:79E<BT^8VAA;F=E4&%S<W=O<F0H)'5S97)N86UE+"`D;VQD
M7W!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&YE=U]P87-S=V]R9"D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1R97,@
M/2!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1F%I;'5R92!I;B!C:&%N
M9VEN9R!P87-S=V]R9"!O;B`E<SH@)7,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)V1R:79E<G,G75LD:V5Y75LG;F%M92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S+3YG971-97-S86=E
M*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]P87)A;7-;)V1R:79E<G,G75LD:V5Y75LG<F5Q=6ER960G
M72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"@D<F5S+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!A<W-W9"]L:6(O1')I=F5R+W-M8G!A<W-W9"YP:'``
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<U,#$`,3`T,3<S-C(W-#,`
M,#(R-#0Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@<VUB<&%S<V0@8VQA<W,@871T96UP=',@
M=&\@8VAA;F=E(&$@=7-E<B=S('!A<W-W;W)D(&]N(&$@<V%M8F$@<V5R=F5R
M+@H@*@H@*B`D2&]R9&4Z('!A<W-W9"]L:6(O1')I=F5R+W-M8G!A<W-W9"YP
M:'`L=B`Q+C(R(#(P,#4O,#@O,C,@,3$Z,34Z,#8@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`P+3(P,#4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W
M=RYH;W)D92YO<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#
M14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!296YE
M($QU;F0@2F5N<V5N(#Q296YE0&QU;F1J96YS96XN;F5T/@H@*B!`<&%C:V%G
M92!087-S=V0*("HO"F-L87-S(%!A<W-W9%]$<FEV97)?<VUB<&%S<W=D(&5X
M=&5N9',@4&%S<W=D7T1R:79E<B!["@H@("`@+RHJ"B`@("`@*B!3;V-K970@
M8V]N;F5C=&EO;B!R97-O=7)C92X*("`@("`J"B`@("`@*B!`=F%R(')E<V]U
M<F-E"B`@("`@*B\*("`@('9A<B`D7V9P.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T<R!A(&YE=R!S;6)P87-S=V0@4&%S<W=D7T1R:79E<B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@4&%S<W=D7T1R:79E<E]S;6)P87-S=V0H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M
M97)G92AA<G)A>2@G:&]S="<@/3X@)VQO8V%L:&]S="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<')O9W)A;2<@/3X@
M)R]U<W(O8FEN+W-M8G!A<W-W9"<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYN96-T<R!A('!I<&4@=&\@=&AE('-A;6)A<V5R=F5R('5S:6YG('1H
M92!S;6)P87-S=V0@<')O9W)A;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R("`@("!4:&4@=7-E<B!T;R!C:&%N9V4@=&AE('!A<W-W;W)D
M(&9O<@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&UP9FEL92`@5&AE(&YA;64@
M;V8@82!T96UP;W)A<GD@9FEL92!I;B!W:&EC:"!T;R!W<FET90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@;W5T<'5T+@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&9A:6QU
M<F4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H)'5S97(L("1T;7!F
M:6QE*0H@("`@>PH@("`@("`@(&EF("@A:7-?97AE8W5T86)L92@D=&AI<RT^
M7W!A<F%M<ULG<')O9W)A;2==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")087-S=V0@:7,@;F]T('!R;W!E<FQY(&-O;F9I
M9W5R960N(BDI.PH@("`@("`@('T*"B`@("`@("`@)&-M9"`]('-P<FEN=&8H
M)R5S("UR("5S("US("U5("(E<R(@/B`E<R`R/B8Q)RP*("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<')O9W)A;2==+`H@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@)'5S97(L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'1M<&9I;&4I.PH@("`@("`@("1T:&ES+3Y?9G`@/2!`<&]P96XH)&-M
M9"P@)W<G*3L*("`@("`@("!I9B`H(21T:&ES+3Y?9G`I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&]P96X@
M<&EP92!T;R!S;6)P87-S=V0N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!T
M:&4@<&EP92!T;R!T:&4@<V%M8F%S97)V97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@("!`<&-L;W-E*"1T:&ES
M+3Y?9G`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@82!S=')I;F<@
M=&\@=&AE('=A:71I;F<@<V%M8F%S97)V97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8VUD("!4:&4@<W1R:6YG('1O('-E;F0@=&\@=&AE('-E
M<G9E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E;F1#;VUM86YD*"1C;60I
M"B`@("!["B`@("`@("`@:68@*&9P=71S*"1T:&ES+3Y?9G`L("1C;60@+B`B
M7&XB*2`]/2`M,2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+B(I*3L*
M("`@("`@("!]"B`@("`@("`@<VQE97`H,2D["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H92!U<V5R)W,@
M<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA
M;64@("`@("!4:&4@=7-E<B!F;W(@=VAI8V@@=&\@8VAA;F=E('1H92!P87-S
M=V]R9"X*("`@("`J($!P87)A;2!S=')I;F<@)&]L9%]P87-S=V]R9"`@5&AE
M(&]L9"`H8W5R<F5N="D@=7-E<B!P87-S=V]R9"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YE=U]P87-S=V]R9"`@5&AE(&YE=R!U<V5R('!A<W-W;W)D('1O
M('-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]R(%!%
M05)?17)R;W(@8F%S960@;VX@<W5C8V5S<R!O9B!T:&4@8VAA;F=E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C:&%N9V5087-S=V]R9"@D=7-E<FYA;64L("1O
M;&1?<&%S<W=O<F0L("1N97=?<&%S<W=O<F0I"B`@("!["B`@("`@("`@)')E
M<R`]('1R=64["@H@("`@("`@("\O($-L96%N('5P('5S97(@;F%M92!I;B!C
M87-E(&5V:6P@8VAA<F%C=&5R<R!A<F4@:6X@:70N"B`@("`@("`@)'5S97(@
M/2!E<V-A<&5S:&5L;&-M9"@D=7-E<FYA;64I.PH*("`@("`@("`D=&UP9FEL
M92`]($AO<F1E.CIG971496UP1FEL92@G<VUB<&%S<W=D)RD["B`@("`@("`@
M:68@*&ES7V$H)'1M<&9I;&4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T;7!F:6QE.PH@("`@("`@('T*"B`@("`@("`@)')E<R`]
M("1T:&ES+3Y?8V]N;F5C="@D=7-E<BP@)'1M<&9I;&4I.PH@("`@("`@(&EF
M("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@)'1H:7,M/E]S
M96YD0V]M;6%N9"@D;VQD7W!A<W-W;W)D*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@("`@('T*"B`@("`@("`@)')E<R`]("1T:&ES+3Y?<V5N9$-O;6UA
M;F0H)&YE=U]P87-S=V]R9"D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@
M("!]"@H@("`@("`@("1R97,@/2`D=&AI<RT^7W-E;F1#;VUM86YD*"1N97=?
M<&%S<W=O<F0I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7V1I<V-O;FYE8W0H*3L*"B`@("`@("`@)')E<R`](&9I
M;&4H)'1M<&9I;&4I.PH@("`@("`@(&EF("AS=')S='(H)')E<UMC;W5N="@D
M<F5S*2`M(#%=+"`G4&%S<W=O<F0@8VAA;F=E9"!F;W(@=7-E<B<I(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M=')R8VAR*'1R:6TH)')E<UMC;W5N="@D<F5S*2`M(#)=*2P@)SHG*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L:6(O1')I
M=F5R+W9M86EL;6=R+G!H<```````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#,P,S$`,3`T,3<S-C(W-#,`,#(R,C0V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@=FUA:6QM
M9W(@8VQA<W,@871T96UP=',@=&\@8VAA;F=E(&$@=7-E<B=S('!A<W-W;W)D
M(&]N(&$@;&]C86P@=FUA:6QM9W(*("H@9&%E;6]N"B`J"B`J("1(;W)D93H@
M<&%S<W=D+VQI8B]$<FEV97(O=FUA:6QM9W(N<&AP+'8@,2XQ,2`R,#`U+S`X
M+S(S(#$Q.C$U.C`V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`U($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R9&4N;W)G+RD*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$%33"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O
M87-L+G!H<"X*("H*("H@0&%U=&AO<B`@36%R8V\@2V%I<V5R(#QB871E0'!H
M<"YN970^"B`J($!S:6YC92`@(%!A<W-W9"`R+C(*("H@0'!A8VMA9V4@4&%S
M<W=D"B`J+PH@8VQA<W,@4&%S<W=D7T1R:79E<E]V;6%I;&UG<B!E>'1E;F1S
M(%!A<W-W9%]$<FEV97(@>PH*("`@("\J*@H@("`@("H@0VAA;F=E('1H92!U
M<V5R)W,@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=7-E<FYA;64@("`@("!4:&4@=7-E<B!F;W(@=VAI8V@@=&\@8VAA;F=E('1H
M92!P87-S=V]R9"X*("`@("`J($!P87)A;2!S=')I;F<@)&]L9%]P87-S=V]R
M9"`@5&AE(&]L9"`H8W5R<F5N="D@=7-E<B!P87-S=V]R9"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&YE=U]P87-S=V]R9"`@5&AE(&YE=R!P87-S=V]R9"!T
M;R!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]R
M(&9A;'-E(&)A<V5D(&]N('-U8V-E<W,@;V8@=&AE(&-H86YG92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8VAA;F=E4&%S<W=O<F0H)'5S97)N86UE+"`D;VQD
M7W!A<W-W;W)D+"`D;F5W7W!A<W-W;W)D*0H@("`@>PH@("`@("`@(&EF("AI
M<U]R96%D86)L92@D=&AI<RT^7W!A<F%M<ULG=FUA:6QI;F,G72D@)B8@:7-S
M970H)'1H:7,M/E]P87)A;7-;)W9M86EL:6YC)UTI*2!["B`@("`@("`@("`@
M($!I;F-L=61E*"1T:&ES+3Y?<&%R86US6R=V;6%I;&EN8R==*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G=FUA:6PN:6YC(&YO="!F;W5N9"`A("@G("X@)'1H:7,M/E]P87)A;7-;
M)W9M86EL:6YC)UT@+B`G*2<I.PH@("`@("`@('T*"B`@("`@("`@)%]S<&QI
M='1E9"`]('-P;&ET*"=`)RP@)'5S97)N86UE*3L*("`@("`@("`D7W5S97)N
M86UE(#T@)%]S<&QI='1E9%LP73L*("`@("`@("`D7V1O;6%I;B`]("1?<W!L
M:71T961;,5T["B`@("`@("`@)%]R971U<FY#:&%N9V4@/2!V8VAP87-S*"1?
M9&]M86EN+"`D;VQD7W!A<W-W;W)D+"`D7W5S97)N86UE+"`D;F5W7W!A<W-W
M;W)D*3L*"B`@("`@("`@:68@*"1?<F5T=7)N0VAA;F=E6S!=*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN8V]R<F5C="!0
M87-S=V]R9"(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&EB+T1R:79E<B]K
M;VQA8BYP:'``````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-3$T
M`#$P-#$W,S8R-S0S`#`R,34S,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($MO;&%B(&-L87-S
M(&%T=&5M<'1S('1O(&-H86YG92!A('5S97(G<R!P87-S=V]R9"!O;B!T:&4@
M9&5S:6=N871E9`H@*B!+;VQA8B!B86-K96YD+B!"87-E9"!O9F8@=&AE($Q$
M05`@<&%S<W=D(&-L87-S+@H@*@H@*B`D2&]R9&4Z('!A<W-W9"]L:6(O1')I
M=F5R+VMO;&%B+G!H<"QV(#$N,B`R,#`U+S`X+S(S(#$Q.C$U.C`V(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2!(;W)D92!0<F]J96-T("AH='1P
M.B\O=W=W+FAO<F1E+F]R9R\I"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H;W(@
M(%-T=6%R="!":6YGZR`\<VMB:6YG94!G;6%I;"YC;VT^"B`J($!S:6YC92`@
M(%!A<W-W9"`S+C`*("H@0'!A8VMA9V4@4&%S<W=D"B`J+PIC;&%S<R!087-S
M=V1?1')I=F5R7VMO;&%B(&5X=&5N9',@4&%S<W=D7T1R:79E<B!["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%!A<W-W9%]$<FEV97)?:V]L
M86(@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%!A<W-W9%]$<FEV97)?:V]L86(H)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+R\@5V4@9&]N)W0@;F5E9"!A
M;GD@8F%C:V5N9',N<&AP+6-O;F9I9W5R86)L92!P87)A;65T97)S"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H92!U<V5R)W,@<&%S<W=O<F0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@("`@("!4
M:&4@=7-E<B!F;W(@=VAI8V@@=&\@8VAA;F=E('1H92!P87-S=V]R9"X*("`@
M("`J($!P87)A;2!S=')I;F<@)&]L9%]P87-S=V]R9"`@5&AE(&]L9"`H8W5R
M<F5N="D@=7-E<B!P87-S=V]R9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE
M=U]P87-S=V]R9"`@5&AE(&YE=R!U<V5R('!A<W-W;W)D('1O('-E="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;W(@9F%L<V4@8F%S
M960@;VX@<W5C8V5S<R!O9B!T:&4@8VAA;F=E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C:&%N9V5087-S=V]R9"@D=7-E<FYA;64L("1O;&1?<&%S<W=O<F0L
M("1N97=?<&%S<W=O<F0I"B`@("!["B`@("`@("`@+R\@0V]N;F5C="!T;R!T
M:&4@3$1!4"!S97)V97(N"B`@("`@("`@)&1S(#T@;&1A<%]C;VYN96-T*`H@
M("`@("`@("`@("`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=L9&%P)UU;
M)W-E<G9E<B==+`H@("`@("`@("`@("`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA
M8B==6R=L9&%P)UU;)W!O<G0G70H@("`@("`@("D["B`@("`@("`@:68@*"$D
M9',I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B*2D["B`@("`@("`@
M?0H*("`@("`@("!L9&%P7W-E=%]O<'1I;VXH)&1S+"!,1$%07T]05%]04D]4
M3T-/3%]615)324].+"`S*3L*"B`@("`@("`@+R\@0FEN9"!A;F]N>6UO=7-L
M>2X*("`@("`@("`D<F5S=6QT(#T@0&QD87!?8FEN9"@D9',I.PH@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(I*3L*
M("`@("`@("!]"@H@("`@("`@("\O($UA:V4@<W5R92!W92=R92!U<VEN9R!T
M:&4@9G5L;"!U<V5R0&1O;6%I;B!F;W)M870N"B`@("`@("`@:68@*'-T<G-T
M<B@G0"<L("1U<V5R;F%M92D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1U
M<V5R;F%M92`N/2`G0"<@+B`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=I
M;6%P)UU;)VUA:6QD;VUA:6XG73L*("`@("`@("!]"@H@("`@("`@("\O($9I
M;F0@=&AE('5S97(G<R!$3BX*("`@("`@("`D<F5S=6QT(#T@;&1A<%]S96%R
M8V@H"B`@("`@("`@("`@("1D<RP*("`@("`@("`@("`@)$=,3T)!3%-;)V-O
M;F8G75LG:V]L86(G75LG;&1A<"==6R=B87-E9&XG72P*("`@("`@("`@("`@
M(FUA:6P])'5S97)N86UE(@H@("`@("`@("D["B`@("`@("`@)&5N=')Y(#T@
M;&1A<%]F:7)S=%]E;G1R>2@D9',L("1R97-U;'0I.PH@("`@("`@(&EF("@D
M96YT<GD@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5S97(@;F]T(&9O=6YD+B(I*3L*("`@("`@("!]"@H@
M("`@("`@("1U<V5R9&X@/2!L9&%P7V=E=%]D;B@D9',L("1E;G1R>2D["@H@
M("`@("`@("\O($-O;FYE8W0@87,@=&AE('5S97(N"B`@("`@("`@)')E<W5L
M="`]($!L9&%P7V)I;F0H)&1S+"`D=7-E<F1N+"`D;VQD7W!A<W-W;W)D*3L*
M("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B26YC;W)R96-T(%!A<W-W;W)D(BDI.PH@("`@
M("`@('T*"B`@("`@("`@+R\@06YD(&9I;F%L;'D@8VAA;F=E('1H92!P87-S
M=V]R9"X*("`@("`@("`D;F5W7V1E=&%I;'-;)W5S97)087-S=V]R9"==(#T@
M)WMS:&%])R`N"B`@("`@("`@("`@(&)A<V4V-%]E;F-O9&4H<&%C:R@G2"HG
M+"!S:&$Q*"1N97=?<&%S<W=O<F0I*2D["@H@("`@("`@(&EF("@A;&1A<%]M
M;V1?<F5P;&%C92@D9',L("1U<V5R9&XL("1N97=?9&5T86EL<RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H;&1A<%]E<G)O<B@D
M9',I*3L*("`@("`@("!]"@H@("`@("`@(&QD87!?=6YB:6YD*"1D<RD["@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!A<W-W9"]L:6(O1')I=F5R+W-Q;"YP:'``````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`Q,C,`,3`T,3<S-C(W-#,`,#(Q
M,C,P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@4U%,(&1R:79E<B!A='1E;7!T<R!T;R!C:&%N
M9V4@82!U<V5R)W,@<&%S<W=O<F0@<W1O<F5D(&EN(&%N(%-13`H@*B!D871A
M8G-E(&%N9"!I;7!L96UE;G1S('1H92!087-S=V1?1')I=F5R($%022X*("H*
M("H@)$AO<F1E.B!P87-S=V0O;&EB+T1R:79E<B]S<6PN<&AP+'8@,2XR-"`R
M,#`U+S`X+S(S(#$Q.C$U.C`V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,"TR,#`U($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R9&4N;W)G
M+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$%33"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC
M96YS97,O87-L+G!H<"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@26QY82!+<F5L
M(#QM86EL0&MR96PN;W)G/@H@*B!`875T:&]R("!4:F5E<F0@=F%N(&1E<B!:
M964@/&%D;6EN0'AA<BYN;#X*("H@0&%U=&AO<B`@36%T=&EA<R!796)J]G)N
M($5R:6MS<V]N(#QM871T:6%S0'=E8FIO<FXN;W)G/@H@*B!`875T:&]R("!%
M<FEC($IO;B!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E
M>&%S+F5D=3X*("H@0'!A8VMA9V4@4&%S<W=D"B`J+PIC;&%S<R!087-S=V1?
M1')I=F5R7W-Q;"!E>'1E;F1S(%!A<W-W9%]$<FEV97(@>PH*("`@("\J*@H@
M("`@("H@4U%,(&-O;FYE8W1I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!V
M87(@1$(*("`@("`J+PH@("`@=F%R("1?9&(["@H@("`@+RHJ"B`@("`@*B!3
M=&%T92!O9B!344P@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%!A<W-W9%]$<FEV97)?
M<W%L(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!087-S=V1?1')I=F5R7W-Q;"@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG
M<&AP='EP92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&AP
M='EP92==(#T@)'!A<F%M<ULG<&AP='EP92==.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E)E<75I
M<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%!A<W-W9"!344P@8V]N
M9FEG=7)A=&EO;BXB*2D["B`@("`@("`@?0H*("`@("`@("`O*B!5<V4@9&5F
M875L=',@9G)O;2!(;W)D92P@8G5T(&%L;&]W(&]V97)R:61I;F<@:6X@8F%C
M:V5N9',N<&AP+B`J+PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87E?
M;65R9V4H2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G)RP@)W-Q;"<I+"`D<&%R
M86US*3L*"B`@("`@("`@+RH@5&AE<V4@9&5F875L="!T;R!M871C:&EN9R!T
M:&4@075T:%]S<6P@9&5F875L=',N("HO"B`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@/2!I<W-E="@D<&%R86US6R=T86)L92==*2`_("1P87)A
M;7-;)W1A8FQE)UT@.B`G:&]R9&5?=7-E<G,G.PH@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=E;F-R>7!T:6]N)UT@/2!I<W-E="@D<&%R86US6R=E;F-R>7!T
M:6]N)UTI(#\@)'!A<F%M<ULG96YC<GEP=&EO;B==(#H@)VUD-2<["B`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W5S97)?8V]L)UT@/2!I<W-E="@D<&%R86US
M6R=U<V5R7V-O;"==*2`_("1P87)A;7-;)W5S97)?8V]L)UT@.B`G=7-E<E]U
M:60G.PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S7V-O;"==(#T@:7-S
M970H)'!A<F%M<ULG<&%S<U]C;VPG72D@/R`D<&%R86US6R=P87-S7V-O;"==
M(#H@)W5S97)?<&%S<R<["B`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?
M96YC<GEP=&EO;B==(#T@:7-S970H)'!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N
M)UTI(#\@)'!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UT@.B!F86QS93L*("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<75E<GE?;&]O:W5P)UT@/2!I<W-E="@D
M<&%R86US6R=Q=65R>5]L;V]K=7`G72D@/R`D<&%R86US6R=Q=65R>5]L;V]K
M=7`G72`Z(&9A;'-E.PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=Q=65R>5]M
M;V1I9GDG72`](&ES<V5T*"1P87)A;7-;)W%U97)Y7VUO9&EF>2==*2`_("1P
M87)A;7-;)W%U97)Y7VUO9&EF>2==(#H@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VYN96-T('1O('1H92!D871A8F%S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T
M*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?8V]N;F5C=&5D*2!["B`@
M("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V97(@=7-I;F<@
M=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@("`@("`@(&EN8VQU
M9&5?;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9$
M0CHZ8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(BDI.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL
M:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)
M5%E?15)23U)3*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@
M=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0@:7,@=F%L:60N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=7-E<DE$("`@("`@("!4:&4@=7-E<DE$('1O(&-H96-K+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;VQD7W!A<W-W;W)D("!!;B!O;&0@<&%S<W=O<F0@=&\@
M8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N
M('9A;&ED(&]R(%!%05)?17)R;W(@;VX@:6YV86QI9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7VQO;VMU<"@D=7-E<BP@)&]L9%]P87-S=V]R9"D*("`@('L*
M("`@("`@("`O*B!#;VYN96-T('1O('1H92!D871A8F%S92`J+PH@("`@("`@
M("1R97,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M
M<ULG<75E<GE?;&]O:W5P)UTI*2!["B`@("`@("`@("`@(&QI<W0H)'-Q;"P@
M)'9A;'5E<RD@/2`D=&AI<RT^7W!A<G-E475E<GDH)'1H:7,M/E]P87)A;7-;
M)W%U97)Y7VQO;VMU<"==+"`D=7-E<BP@)&]L9%]P87-S=V]R9"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R
M>2X@*B\*("`@("`@("`@("`@)'-Q;"`@/2`G4T5,14-4("<@+B`D=&AI<RT^
M7W!A<F%M<ULG<&%S<U]C;VPG72`N("<@1E)/32`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("<@5TA%4D4@)R`N
M("1T:&ES+3Y?<&%R86US6R=U<V5R7V-O;"==("X@)R`](#\G.PH@("`@("`@
M("`@("`D=F%L=65S(#T@87)R87DH)'5S97(I.PH@("`@("`@('T*("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y(%!A<W-W9%]$<FEV
M97)?<W%L.CI?;&]O:W5P*"DZ("<@+B`D<W%L+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@
M<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1S<6PL("1V86QU97,I.PH@("`@("`@(&EF("@A:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1R;W<@/2`D<F5S=6QT+3YF
M971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@("`@("`D<F5S
M=6QT+3YF<F5E*"D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F]W*2D@
M>PH@("`@("`@("`@("`@("`@+RH@1V5T('1H92!P87-S=V]R9"!F<F]M('1H
M92!D871A8F%S92X@*B\*("`@("`@("`@("`@("`@("1C=7)R96YT7W!A<W-W
M;W)D(#T@)')O=ULD=&AI<RT^7W!A<F%M<ULG<&%S<U]C;VPG75T["@H@("`@
M("`@("`@("`@("`@+RH@0VAE8VL@=&AE('!A<W-W;W)D<R!M871C:"X@*B\*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8V]M<&%R95!A<W-W;W)D
M<R@D8W5R<F5N=%]P87-S=V]R9"P@)&]L9%]P87-S=V]R9"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B57-E<B!N;W0@9F]U;F0B*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!-;V1I9GD@*'5P9&%T92D@82!M>7-Q;"!P87-S=V]R9"!R96-O<F0@9F]R
M(&$@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@
M("`@("`@(%1H92!U<V5R('=H;W-E(')E8V]R9"!W92!W:6QL('5D<&%T92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&YE=U]P87-S=V]R9"`@5&AE(&YE=R!P
M87-S=V]R9"!V86QU92!T;R!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]R($9A;'-E(&)A<V5D(&]N('-U8V-E<W,@;V8@=&AE
M(&UO9&EF>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7VUO9&EF>2@D=7-E<BP@
M)&YE=U]P87-S=V]R9"D*("`@('L*("`@("`@("`O*B!#;VYN96-T('1O('1H
M92!D871A8F%S92X@*B\*("`@("`@("`D<F5S(#T@)'1H:7,M/E]C;VYN96-T
M*"D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W%U97)Y7VUO9&EF>2==*2D@>PH@
M("`@("`@("`@("!L:7-T*"1S<6PL("1V86QU97,I(#T@)'1H:7,M/E]P87)S
M95%U97)Y*"1T:&ES+3Y?<&%R86US6R=Q=65R>5]M;V1I9GDG72P@)'5S97(L
M("1N97=?<&%S<W=O<F0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\J($5N8W)Y<'0@=&AE('!A<W-W;W)D+B`J+PH@("`@("`@("`@("`D;F5W
M7W!A<W-W;W)D(#T@)'1H:7,M/F5N8W)Y<'1087-S=V]R9"@D;F5W7W!A<W-W
M;W)D+"`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI.PH*("`@
M("`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`@
M("`@)'-Q;"`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==
M("X*("`@("`@("`@("`@("`@("`@("<@4T54("<@+B`D=&AI<RT^7W!A<F%M
M<ULG<&%S<U]C;VPG72`N("<@/2`_)R`N"B`@("`@("`@("`@("`@("`@("`G
M(%=(15)%("<@+B`D=&AI<RT^7W!A<F%M<ULG=7-E<E]C;VPG72`N("<@/2`_
M)SL*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1N97=?<&%S<W=O<F0L
M("1U<V5R*3L*("`@("`@("!]"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-13"!1=65R>2!B>2!087-S=V1?1')I=F5R7W-Q;#HZ7VUO9&EF>2@I.B`G
M("X@)'-Q;"P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"@H@("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<W%L+"`D=F%L=65S*3L*"B`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@=&AE('-T
M<FEN9R!A<R!A;B!344P@<75E<GD@<W5B<W1I='5T:6YG('!L86-E:&]L9&5R
M<R!F;W(*("`@("`J('1H96ER('9A;'5E<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S=')I;F<@("`@5&AE('-T<FEN9R!T;R!P<F]C97-S(&%S
M(&$@<75E<GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@5&AE
M('5S97(@=&\@=7-E(&9O<B!T:&4@)74@<&QA8V5H;VQD97(N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5&AE('!A<W-W;W)D('1O('5S92!F
M;W(@=&AE("5P(&%N9"`E92!P;&%C96AO;&1E<G,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!P<F]C97-S960@4U%,('%U97)Y+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<&%R<V51=65R>2@D<W1R:6YG+"`D=7-E<BP@
M)'!A<W-W;W)D*0H@("`@>PH@("`@("`@("1Q=65R>2`]("<G.PH@("`@("`@
M("1V86QU97,@/2!A<G)A>2@I.PH@("`@("`@("1L96YG=&@@/2!S=')L96XH
M)'-T<FEN9RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QE;F=T:#L@
M)&DK*RD@>PH@("`@("`@("`@("!I9B`H)'-T<FEN9ULD:5T@/3T@)R4G("8F
M("%E;7!T>2@D<W1R:6YG6R1I("L@,5TI*2!["B`@("`@("`@("`@("`@("!S
M=VET8V@@*"1S=')I;F=;*RLD:5TI('L*("`@("`@("`@("`@("`@(&-A<V4@
M)W4G.@H@("`@("`@("`@("`@("`@("`@("1Q=65R>2`N/2`G/R<["B`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'5S97(["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G<"<Z"B`@
M("`@("`@("`@("`@("`@("`@)'%U97)Y("X]("<_)SL*("`@("`@("`@("`@
M("`@("`@("`D=F%L=65S6UT@/2`D<&%S<W=O<F0["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G92<Z"B`@("`@
M("`@("`@("`@("`@("`@)'%U97)Y("X]("<_)SL*("`@("`@("`@("`@("`@
M("`@("`D=F%L=65S6UT@/2`D=&AI<RT^96YC<GEP=%!A<W-W;W)D*"1P87-S
M=V]R9"P@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E
M("<E)SH*("`@("`@("`@("`@("`@("`@("`D<75E<GD@+CT@)R4G.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("`@("`@)'%U97)Y("X]("<E)R`N("1S=')I
M;F=;)&E=.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'%U97)Y("X]("1S=')I;F=;)&E=.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@87)R87DH)'%U97)Y+"`D=F%L=65S*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H86YG92!T:&4@=7-E<B=S('!A<W-W;W)D
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("`@("`@
M5&AE('5S97(@9F]R('=H:6-H('1O(&-H86YG92!T:&4@<&%S<W=O<F0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1O;&1?<&%S<W=O<F0@(%1H92!O;&0@*&-U
M<G)E;G0I('5S97(@<&%S<W=O<F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M97=?<&%S<W=O<F0@(%1H92!N97<@=7-E<B!P87-S=V]R9"!T;R!S970N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]R(&9A;'-E(&)A
M<V5D(&]N('-U8V-E<W,@;V8@=&AE(&-H86YG92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VAA;F=E4&%S<W=O<F0H)'5S97)N86UE+"`@)&]L9%]P87-S=V]R
M9"P@)&YE=U]P87-S=V]R9"D*("`@('L*("`@("`@("`O*B!#:&5C:R!T:&4@
M8W5R<F5N="!P87-S=V]R9"X@*B\*("`@("`@("`D<F5S(#T@)'1H:7,M/E]L
M;V]K=7`H)'5S97)N86UE+"`D;VQD7W!A<W-W;W)D*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2`@>PH@("`@("`@("`@("!R971U
M<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VUO
M9&EF>2@D=7-E<FYA;64L("1N97=?<&%S<W=O<F0I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!A<W-W9"]L:6(O1')I=F5R+W!I;F4N<&AP````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,C$R-S(`,3`T,3<S-C(W-#,`,#(Q,S<R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M*BH*("H@3&]W97(@8F]U;F1A<GD@8VAA<F%C=&5R+@H@*B\*9&5F:6YE*"=&
M25)35$-()RP@,'@R,"D["@HO*BH*("H@57!P97(@8F]U;F1A<GD@8VAA<F%C
M=&5R+@H@*B\*9&5F:6YE*"=,05-40T@G+"`P>#=E*3L*"B\J*@H@*B!-961I
M86X@8VAA<F%C=&5R+@H@*B\*9&5F:6YE*"=404)36B<L($Q!4U1#2"`M($9)
M4E-40T@@*R`Q*3L*"B\J*@H@*B!4:&4@<&EN92!C;&%S<R!A='1E;7!T<R!T
M;R!C:&%N9V4@82!U<V5R)W,@<&%S<W=O<F0@;VX@82!I;B!A('!I;F4@<&%S
M<W=O<F0*("H@9FEL92X*("H*("H@)$AO<F1E.B!P87-S=V0O;&EB+T1R:79E
M<B]P:6YE+G!H<"QV(#$N.2`R,#`U+S`X+S(S(#$Q.C$U.C`V(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`U($AO<F1E(%!R;VIE8W0@*&AT
M='`Z+R]W=W<N:&]R9&4N;W)G+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*("H*("H@0&%U=&AO
M<B`@36%X($MA;&EK82`\;6%X0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@4&%S
M<W=D(#,N,`H@*B!`<&%C:V%G92!087-S=V0*("HO"F-L87-S(%!A<W-W9%]$
M<FEV97)?<&EN92!E>'1E;F1S(%!A<W-W9%]$<FEV97(@>PH*("`@("\J*@H@
M("`@("H@1E10(&-O;FYE8W1I;VX@:&%N9&QE+@H@("`@("H*("`@("`J($!V
M87(@5D93"B`@("`@*B\*("`@('9A<B`D7V9T<#L*"B`@("`O*BH*("`@("`J
M($)O;VQE86X@=VAI8V@@8V]N=&%I;G,@<W1A=&4@;V8@=&AE(&9T<"!C;VYN
M96-T:6]N+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]C;VYN96-T960@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-O
M;G1E;G1S(&%R<F%Y(&]F('1H92!P:6YE('!A<W-W;W)D(&9I;&4N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C;VYT96YT
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M('!I;F4@4&%S<W=D7T1R:79E<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("`D<&%R86US("`@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE
M8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@4&%S<W=D
M7T1R:79E<E]P:6YE*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M("\J(%=E('-E;&8M96YC<GEP="!H97)E+"!S;R!P;&%I;G1E>'0@:7,@;F5E
M9&5D+B`J+PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UT@
M/2`G<&QA:6XG.PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y
M<'1I;VXG72`](&9A;'-E.PH*("`@("`@("`O*B!396YS:6)L92!&5%`@<V5R
M=F5R('!A<F%M971E<G,N("HO"B`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO
M<W0G72`](&ES<V5T*"1P87)A;7-;)VAO<W0G72D@/R`D<&%R86US6R=H;W-T
M)UT@.B`G;&]C86QH;W-T)SL*("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R
M="==(#T@:7-S970H)'!A<F%M<ULG<&]R="==*2`_("1P87)A;7-;)W!O<G0G
M72`Z("<R,2<["B`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A=&@G72`](&ES
M<V5T*"1P87)A;7-;)W!A=&@G72D@/R`D<&%R86US6R=P871H)UT@.B`G)SL*
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9FEL92==(#T@:7-S970H)'!A<F%M
M<ULG9FEL92==*2`_("1P87)A;7-;)V9I;&4G72`Z("<N<&EN97!W)SL*"B`@
M("`@("`@+RH@0V]N;F5C="!T;R!&5%`@<V5R=F5R('5S:6YG(&IU<W0M<&%S
M<V5D+6EN(&-R961E;G1I86QS/PH@("`@("`@("`J($]N;'D@=7-E9G5L(&EF
M('5S:6YG('1H92!C;VUP;W-I=&4@9')I=F5R(&%N9"!C:&%N9VEN9PH@("`@
M("`@("`J('-Y<W1E;2`H1E10*2!P87-S=V]R9"!P<FEO<B!T;R!T:&ES(&]N
M92X@*B\*("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E7VYE=U]P87-S=V0G
M72`](&ES<V5T*"1P87)A;7-;)W5S95]N97=?<&%S<W=D)UTI(#\@)'!A<F%M
M<ULG=7-E7VYE=U]P87-S=V0G72`Z(&9A;'-E.PH*("`@("`@("`O*B!7:&%T
M(&AO<W0@=&\@;&]O:R!F;W(@;VX@96%C:"!L:6YE/R`J+PH@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=I;6%P:&]S="==(#T@:7-S970H)'!A<F%M<ULG:6UA
M<&AO<W0G72D@/R`D<&%R86US6R=I;6%P:&]S="==(#H@)VQO8V%L:&]S="<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!&5%`@<V5R
M=F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"1U<V5R+"`D<&%S<W=O<F0I"B`@
M("!["B`@("`@("`@:68@*"$D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!&5%`@<V5R=F5R('5S:6YG('1H92!S
M=7!P;&EE9`H@("`@("`@("`@("`@*B!P87)A;65T97)S+B`J+PH@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U9&4RYP:'`G.PH*("`@("`@("`@("`@)'!A
M<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D
M=7-E<BP*("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D
M+`H@("`@("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B`D=&AI<RT^7W!A<F%M
M<ULG:&]S="==+`H@("`@("`@("`@("`@("`@)W!O<G0G(#T^("1T:&ES+3Y?
M<&%R86US6R=P;W)T)UTL"B`@("`@("`@("`@("D["@H@("`@("`@("`@("`D
M<F5S(#T@)'1H:7,M/E]F='`@/2`F5D93.CIS:6YG;&5T;VXH)V9T<"<L("1P
M87)A;7,I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/E]F='`M/F-H96-K0W)E
M9&5N=&EA;',H*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C="!F<F]M('1H92!&5%`@<V5R
M=F5R(&%N9"!C;&5A;B!U<"!T:&4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C
M=&5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4[
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V9T<"T^9&ES8V]N;F5C="@I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$96-O9&5S(&$@4&EN92UE;F-O9&5D('!A<W-W;W)D('-T
M<FEN9RX@5&AE(&%L9V]R:71H;2!I<PH@("`@("H@8F]R<F]W960@9G)O;2!R
M96%D7W!A<W-F:6QE*"D@86YD('AL871E7V]U="@I(&9U;F-T:6]N<R!I;@H@
M("`@("H@<&EN92]I;6%P+F,@9FEL92!D:7-T<FEB=71E9"!I;B!T:&4@4&EN
M92!S;W5R8V4@87)C:&EV92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S=')I;F<@(%1H92!C;VYT96YT<R!O9B!A('!I;F4M96YC;V1E9"!P87-S
M=V]R9"!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($QI<W0@
M;V8@;&EN97,@;V8@9&5C;V1E9"!E;&5M96YT<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V1E8V]D92@D<W1R:6YG*0H@("`@>PH@("`@("`@("1L:7-T(#T@
M87)R87DH*3L*"B`@("`@("`@)&QI;F5S(#T@97AP;&]D92@B7&XB+"`D<W1R
M:6YG*3L*("`@("`@("!F;W(@*"1N(#T@,#L@)&X@/"!S:7IE;V8H)&QI;F5S
M*3L@)&XK*RD@>PH@("`@("`@("`@("`D:V5Y(#T@)&X["B`@("`@("`@("`@
M("1T;7`@/2`D;&EN97-;)&Y=.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!S=')L96XH)'1M<"D[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF
M("@H;W)D*"1T;7!;)&E=*2`^/2!&25)35$-(*2`F)B`H;W)D*"1T;7!;)&E=
M*2`\/2!,05-40T@I*2!["B`@("`@("`@("`@("`@("`@("`@)'AC:"`@/2!O
M<F0H)'1M<%LD:5TI("T@*"1D=&D@/2`D:V5Y*3L*("`@("`@("`@("`@("`@
M("1X8V@@*ST@*"1X8V@@/"!&25)35$-(("T@5$%"4UHI(#\@,B`J(%1!0E-:
M(#H@*"1X8V@@/"!&25)35$-(*2`_(%1!0E-:(#H@,#L*("`@("`@("`@("`@
M("`@("1D=&D@(#T@*"1X8V@@+2!&25)35$-(*2`K("1D=&D["B`@("`@("`@
M("`@("`@("`D9'1I("T]("@D9'1I(#X](#(@*B!404)36BD@/R`R("H@5$%"
M4UH@.B`H)&1T:2`^/2!404)36BD@/R!404)36B`Z(#`["B`@("`@("`@("`@
M("`@("`D:V5Y("`]("1D=&D["B`@("`@("`@("`@("`@("`D=&UP6R1I72`]
M(&-H<B@D>&-H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1I("8F("1T;7!;)&D@+2`Q72`]/2`B7&XB*2![
M"B`@("`@("`@("`@("`@("`D=&UP(#T@<W5B<W1R*"1T;7`L(#`L("TQ*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@B
M7'0B+"`D=&UP*3L*("`@("`@("`@("`@:68@*&-O=6YT*"1P87)T<RD@/CT@
M-"D@>PH@("`@("`@("`@("`@("`@)&QI<W1;72`]("1P87)T<SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@16YC;V1E<R!A;B!A<G)A>2!O9B!E;&5M96YT
M<R!I;G1O(&$@4&EN92UR96%D86)L92!P87-S=V]R9"!S=')I;F<N"B`@("`@
M*B!4:&4@86QG;W)I=&@@:7,@8F]R<F]W960@9G)O;2!W<FET95]P87-S9FEL
M92@I(&%N9"!X;&%T95]I;B@I(&9U;F-T:6]N<PH@("`@("H@:6X@<&EN92]I
M;6%P+F,@9FEL92!D:7-T<FEB=71E9"!I;B!T:&4@4&EN92!S;W5R8V4@87)C
M:&EV92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("1L:6YE<R`@3&ES
M="!O9B!L:6YE<R!O9B!D96-O9&5D(&5L96UE;G1S"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@0V]N=&5N=',@;V8@82!P:6YE+7)E861A8FQE('!A
M<W-W;W)D(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E;F-O9&4H)&QI
M;F5S*0H@("`@>PH@("`@("`@("1S=')I;F<@/2`G)SL*("`@("`@("!F;W(@
M*"1N(#T@,#L@)&X@/"!S:7IE;V8H)&QI;F5S*3L@)&XK*RD@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)&QI;F5S6R1N75LT72DI('L*("`@("`@("`@("`@
M("`@("1L:6YE<ULD;EU;-%T@/2`B7'0B("X@)&QI;F5S6R1N75LT73L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L:6YE<ULD;EU;
M-%T@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&ME>2`]("1N
M.PH@("`@("`@("`@("`D=&UP(#T@=G-P<FEN=&8H(B4N,3`P<UQT)2XQ,#!S
M7'0E+C$P,'-<="5D)7-<;B(L("1L:6YE<ULD;ETI.PH@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)'1M<"D[("1I*RLI('L*("`@("`@
M("`@("`@("`@("1E=&D@/2`D:V5Y.PH@("`@("`@("`@("`@("`@:68@*"AO
M<F0H)'1M<%LD:5TI(#X]($9)4E-40T@I("8F("AO<F0H)'1M<%LD:5TI(#P]
M($Q!4U1#2"DI('L*("`@("`@("`@("`@("`@("`@("`D971I("L](&]R9"@D
M=&UP6R1I72D@+2!&25)35$-(.PH@("`@("`@("`@("`@("`@("`@("1E=&D@
M+3T@*"1E=&D@/CT@,B`J(%1!0E-:*2`_(#(@*B!404)36B`Z("@D971I(#X]
M(%1!0E-:*2`_(%1!0E-:(#H@,#L*("`@("`@("`@("`@("`@("`@("`D:V5Y
M("`]("1E=&D["B`@("`@("`@("`@("`@("`@("`@)'1M<%LD:5T@/2!C:'(H
M)&5T:2`K($9)4E-40T@I.PH@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'-T<FEN9R`N/2`D=&UP.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1S=')I;F<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6YD(&]U="!I9B!A('5S97)N86UE(&%N9"!P87-S=V]R9"!I<R!V86QI
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@("`@
M5&AE('5S97))1"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!S=')I;F<@)&]L
M9%!A<W-W;W)D("!!;B!O;&0@<&%S<W=O<F0@=&\@8VAE8VLN"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7VQO;VMU<"@D=7-E<BP@)&]L9%!A<W-W;W)D*0H@("`@>PH@("`@("`@
M("1C;VYT96YT<R`]("1T:&ES+3Y?9G1P+3YR96%D*"1T:&ES+3Y?<&%R86US
M6R=P871H)UTL("1T:&ES+3Y?<&%R86US6R=F:6QE)UTI.PH@("`@("`@(&EF
M("AI<U]A*"1C;VYT96YT<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&-O;G1E;G1S.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]C;VYT96YT<R`]("1T:&ES+3Y?9&5C;V1E*"1C;VYT96YT<RD["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]C;VYT96YT<R!A<R`D;&EN92D@>PH@("`@
M("`@("`@("!I9B`H)&QI;F5;,5T@/3T@)'5S97(@)B8*("`@("`@("`@("`@
M("`@("@H)&QI;F5;,ET@/3T@)'1H:7,M/E]P87)A;7-;)VEM87!H;W-T)UTI
M('Q\"B`@("`@("`@("`@("`@("`@*"%E;7!T>2@D;&EN95LT72D@)B8@)&QI
M;F5;-%T@/3T@)'1H:7,M/E]P87)A;7-;)VEM87!H;W-T)UTI*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC;VUP87)E4&%S<W=O<F1S*"1L
M:6YE6S!=+"`D;VQD4&%S<W=O<F0I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5<V5R(&YO
M="!F;W5N9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;V1I9GD@*'5P
M9&%T92D@82!P:6YE('!A<W-W;W)D(')E8V]R9"!F;W(@82!U<V5R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("`@("!4:&4@=7-E
M<B!W:&]S92!R96-O<F0@=V4@=VEL;"!U9'!A=&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N97=087-S=V]R9"`@5&AE(&YE=R!P87-S=V]R9"!V86QU92!T
M;R!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7VUO9&EF>2@D=7-E<BP@)&YE=U!A<W-W;W)D
M*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI
M<RT^7V-O;G1E;G1S*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]C;VYT96YT<ULD:5U;,5T@/3T@)'5S97(@)B8*("`@("`@("`@("`@("`@
M("@H)'1H:7,M/E]C;VYT96YT<ULD:5U;,ET@/3T@)'1H:7,M/E]P87)A;7-;
M)VEM87!H;W-T)UTI('Q\"B`@("`@("`@("`@("`@("`@*"%E;7!T>2@D=&AI
M<RT^7V-O;G1E;G1S6R1I75LT72D@)B8*("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C;VYT96YT<ULD:5U;-%T@/3T@)'1H:7,M/E]P87)A;7-;)VEM87!H
M;W-T)UTI*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT<ULD
M:5U;,%T@/2`D;F5W4&%S<W=O<F0["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1S=')I;F<@/2`D=&AI<RT^7V5N8V]D92@D=&AI<RT^7V-O
M;G1E;G1S*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]F='`M/G=R:71E1&%T
M82@D=&AI<RT^7W!A<F%M<ULG<&%T:"==+"`D=&AI<RT^7W!A<F%M<ULG9FEL
M92==+"`D<W1R:6YG*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG92!T
M:&4@=7-E<B=S('!A<W-W;W)D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97)N86UE("`@("!4:&4@=7-E<B!F;W(@=VAI8V@@=&\@8VAA;F=E
M('1H92!P87-S=V]R9"X*("`@("`J($!P87)A;2!S=')I;F<@)&]L9%!A<W-W
M;W)D("!4:&4@;VQD("AC=7)R96YT*2!U<V5R('!A<W-W;W)D+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F5W4&%S<W=O<F0@(%1H92!N97<@=7-E<B!P87-S
M=V]R9"!T;R!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAA;F=E4&%S<W=O<F0H)'5S97)N
M86UE+"`@)&]L9%!A<W-W;W)D+"`D;F5W4&%S<W=O<F0I"B`@("!["B`@("`@
M("`@+RH@0V]N;F5C="!T;R!T:&4@9G1P('-E<G9E<BX@*B\*("`@("`@("`D
M<F5S(#T@)'1H:7,M/E]C;VYN96-T*"1U<V5R;F%M92P@)'1H:7,M/E]P87)A
M;7-;)W5S95]N97=?<&%S<W=D)UT@/R`D;F5W4&%S<W=O<F0@.B`D;VQD4&%S
M<W=O<F0I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@
M("`O*B!#:&5C:R!T:&4@8W5R<F5N="!P87-S=V]R9"X@*B\*("`@("`@("`D
M<F5S(#T@)'1H:7,M/E]L;V]K=7`H)'5S97)N86UE+"`D;VQD4&%S<W=O<F0I
M.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI("!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)')E
M<R`]("1T:&ES+3Y?;6]D:69Y*"1U<V5R;F%M92P@)&YE=U!A<W-W;W)D*3L*
M"B`@("`@("`@)'1H:7,M/E]D:7-C;VYN96-T*"D["@H@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&%S<W=D+VQI8B]$<FEV97(O<&]P<&%S<V0N<&AP````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C8T,P`Q,#0Q-S,V,C<T,P`P,C(R
M-S4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!P;W!P87-S9"!C;&%S<R!A='1E;7!T<R!T;R!C
M:&%N9V4@82!U<V5R)W,@<&%S<W=O<F0@=FEA(&$@<&]P<&%S<V0*("H@<V5R
M=F5R+@H@*@H@*B`D2&]R9&4Z('!A<W-W9"]L:6(O1')I=F5R+W!O<'!A<W-D
M+G!H<"QV(#$N,C0@,C`P-2\P."\R,R`Q,3HQ-3HP-B!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#`M,C`P-2!(;W)D92!0<F]J96-T("AH='1P.B\O
M=W=W+FAO<F1E+F]R9R\I"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,
M24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H;W(@($5R
M:6,@2F]N(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X
M87,N961U/@H@*B!`<&%C:V%G92!087-S=V0*("HO"F-L87-S(%!A<W-W9%]$
M<FEV97)?<&]P<&%S<V0@97AT96YD<R!087-S=V1?1')I=F5R('L*"B`@("`O
M*BH*("`@("`J(%-O8VME="!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!V
M87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?9G`["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1S(&$@;F5W('!O<'!A<W-D(%!A<W-W9%]$<FEV97(@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@)'!A<F%M<R`@
M("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%!A<W-W9%]$<FEV97)?<&]P<&%S<V0H)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)VAO<W0G72`](&%R<F%Y7VME>5]E>&ES=',H)VAO<W0G+"`D<&%R86US*2`_
M("1P87)A;7-;)VAO<W0G72`Z("=L;V-A;&AO<W0G.PH@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=P;W)T)UT@/2!A<G)A>5]K97E?97AI<W1S*"=P;W)T)RP@
M)'!A<F%M<RD@/R`D<&%R86US6R=P;W)T)UT@.B`Q,#8["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!S97)V97(*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9G`@
M/2!F<V]C:V]P96XH)'1H:7,M/E]P87)A;7-;)VAO<W0G72P@)'1H:7,M/E]P
M87)A;7-;)W!O<G0G72P@)&5R<FYO+"`D97)R<W1R+"`S,"D["B`@("`@("`@
M:68@*"$D=&AI<RT^7V9P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"1E<G)S='(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V=E=%!R;VUP="@I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@<V5R=F5R
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]F<"DI('L*("`@("`@("`@("`@9G!U
M=',H)'1H:7,M/E]F<"P@(G%U:71<;B(I.PH@("`@("`@("`@("!F8VQO<V4H
M)'1H:7,M/E]F<"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4&%R<V4@82!R97-P;VYS92!F<F]M('1H92!S97)V97(@=&\@<V5E('=H870@
M:70@=V%S"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9710<F]M<'0H*0H@("`@
M>PH@("`@("`@("1P<F]M<'0@/2!F9V5T<R@D=&AI<RT^7V9P+"`T,#DV*3L*
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UY;,2TU75LP+3E=6S`M.5TO)RP@
M)'!R;VUP="DI('L*("`@("`@("`@("`@)')C(#T@<W5B<W1R*"1P<F]M<'0L
M(#`L(#,I.PH@("`@("`@("`@("`O*B!4:&ES('-H;W5L9"!P<F]B86)L>2!B
M92!A(')E9V5X(&UA=&-H(&9O<B`R/S`@;W(@,S\P+"!N;S\@*B\*("`@("`@
M("`@("`@:68@*"1R8R`]/2`G,C`P)R!\?"`D<F,@/3T@)S(R,"<@?'P@)')C
M(#T]("<R-3`G('Q\("1R8R`]/2`G,S`P)R`I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'!R;VUP="D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD(&$@
M8V]M;6%N9"!T;R!T:&4@<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<V5N9$-O;6UA;F0H)&-M9"P@)&%R9RD*("`@('L*("`@("`@("`D;&EN92`]
M("1C;60@+B`G("<@+B`D87)G("X@(EQN(CL*("`@("`@("!F<'5T<R@D=&AI
M<RT^7V9P+"`D;&EN92D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T4')O
M;7!T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE('5S97(G
M<R!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M;F%M92`@("`@(%1H92!U<V5R(&9O<B!W:&EC:"!T;R!C:&%N9V4@=&AE('!A
M<W-W;W)D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD7W!A<W-W;W)D("!4
M:&4@;VQD("AC=7)R96YT*2!U<V5R('!A<W-W;W)D+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F5W7W!A<W-W;W)D("!4:&4@;F5W('5S97(@<&%S<W=O<F0@
M=&\@<V5T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@(%1R=64@
M;W(@9F%L<V4@8F%S960@;VX@<W5C8V5S<R!O9B!T:&4@8VAA;F=E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C:&%N9V5087-S=V]R9"@D=7-E<FYA;64L("1O
M;&1?<&%S<W=O<F0L("1N97=?<&%S<W=O<F0I"B`@("!["B`@("`@("`@)')E
M<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@
M("`@("`@?0H*("`@("`@("`D<F5S(#T@)'1H:7,M/E]S96YD0V]M;6%N9"@G
M=7-E<B<L("1U<V5R;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1I<V-O;FYE8W0H
M*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B57-E
M<B!N;W0@9F]U;F0B*2D["B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@)'1H
M:7,M/E]S96YD0V]M;6%N9"@G<&%S<R<L("1O;&1?<&%S<W=O<F0I.PH@("`@
M("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]D:7-C;VYN96-T*"D["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(DEN8V]R<F5C="!087-S=V]R9"(I*3L*("`@
M("`@("!]"@H@("`@("`@("1R97,@/2`D=&AI<RT^7W-E;F1#;VUM86YD*"=N
M97=P87-S)RP@)&YE=U]P87-S=V]R9"D["B`@("`@("`@)'1H:7,M/E]D:7-C
M;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!A<W-W9"]L:6(O1')I=F5R+W!R;V-O<&5N+G!H<```````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T-38`,3`T,3<S-C(W-#,`,#(R
M,C<Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@4&%S<W=D7W!R;V-O<&5N(&-L87-S('!R;W9I
M9&5S(&$@<')O8V]P96X@:6UP;&5M96YT871I;VX@;V8@=&AE('!A<W-W9`H@
M*B!S>7-T96TN"B`J"B`J($%N>2!S8W)I<'0@;W(@<')O9W)A;2!C86X@8F4@
M<W5P<&QI960@87,@=&AE("=P<F]G<F%M)R!A='1R:6)U=&4@=F%L=64@;V8*
M("H@=&AE('!A<F%M<R!A<F=U;65N="X@(%1H92!U<V5R;F%M92P@;VQD('!A
M<W-W;W)D(&%N9"!N97<@<&%S<W=O<F0@87)E"B`J('=R:71T96X@=&\@=&AE
M('-T9&EN(&]F('1H92!P<F]C97-S(&%N9"!T:&5N('1H92!S=&1O=70@86YD
M('-T9&5R<B!O9B!T:&4*("H@<')O8V5S<R!A<F4@<F5A9"!A;F0@8V]M8FEN
M960@=VET:"!T:&4@97AI="!S=&%T=7,@=F%L=64@86YD(')E='5R;F5D('1O
M"B`J('1H92!C86QL97(@:68@=&AE('-T871U<R!C;V1E(&ES(&YO="`P+@H@
M*@H@*B`D2&]R9&4Z('!A<W-W9"]L:6(O1')I=F5R+W!R;V-O<&5N+G!H<"QV
M(#$N-"`R,#`U+S`X+S(S(#$Q.C$U.C`V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`U($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R
M9&4N;W)G+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO
M<F<O;&EC96YS97,O87-L+G!H<"X*("H*("H@0&%U=&AO<B`@4V%M=65L($YI
M8V]L87)Y(#QS86U`;FEC;VQA<GDN;W)G/@H@*B!`<VEN8V4@("!087-S=V0@
M,RXP"B`J($!P86-K86=E(%!A<W-W9`H@*B\*8VQA<W,@4&%S<W=D7T1R:79E
M<E]P<F]C;W!E;B!E>'1E;F1S(%!A<W-W9%]$<FEV97(@>PH*("`@("\J*@H@
M("`@("H@0VAA;F=E('1H92!U<V5R)W,@<&%S<W=O<F0@8GD@97AE8W5T:6YG
M(&$@=7-E<B!S=7!P;&EE9"!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'5S97(@("`@(%5S97(@240N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1O;&1P87-S("!/;&0@<&%S<W=O<F0N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N97=P87-S("!.97<@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]R(&5R<F]R
M(&UE<W-A9V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H86YG
M95!A<W-W;W)D*"1U<V5R+"`D;VQD<&%S<RP@)&YE=W!A<W,I"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D9&5S8W)I<'1O<G-P96,@
M/2!A<G)A>2@*("`@("`@("`@("`@,"`]/B!A<G)A>2@G<&EP92<L("=R)RDL
M"B`@("`@("`@("`@(#$@/3X@87)R87DH)W!I<&4G+"`G=R<I+`H@("`@("`@
M("`@("`R(#T^(&%R<F%Y*"=P:7!E)RP@)V4G*2D["@H@("`@("`@("1O=71P
M=70@/2`G)SL*"B`@("`@("`@)'!R;V-E<W,@/2!`<')O8U]O<&5N*"1T:&ES
M+3Y?<&%R86US6R=P<F]G<F%M)UTL("1D97-C<FEP=&]R<W!E8RP@)'!I<&5S
M*3L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'!R;V-E<W,I*2!["B`@("`@
M("`@("`@(&9W<FET92@D<&EP97-;,%TL("(D=7-E<EQN(BD["B`@("`@("`@
M("`@(&9W<FET92@D<&EP97-;,%TL("(D;VQD<&%S<UQN(BD["B`@("`@("`@
M("`@(&9W<FET92@D<&EP97-;,%TL("(D;F5W<&%S<UQN(BD["B`@("`@("`@
M("`@(&9C;&]S92@D<&EP97-;,%TI.PH@("`@("`@("`@("!W:&EL92`H(69E
M;V8H)'!I<&5S6S%=*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2!F
M9V5T<R@D<&EP97-;,5TL(#$P,C0I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&9C;&]S92@D<&EP97-;,5TI.PH@("`@("`@("`@("!W:&EL92`H(69E
M;V8H)'!I<&5S6S)=*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2!F
M9V5T<R@D<&EP97-;,ETL(#$P,C0I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&9C;&]S92@D<&EP97-;,ETI.PH@("`@("`@("`@("`D<F5T=7)N7W9A
M;'5E(#T@<')O8U]C;&]S92@D<')O8V5S<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&]U='!U="`]("<G.PH@("`@("`@("`@("`D<F5T=7)N
M7W9A;'5E(#T@+3$["B`@("`@("`@?0H*("`@("`@("`D;W5T<'5T("X]("(@
M*$5X:70@4W1A='5S.B`D<F5T=7)N7W9A;'5E*2(["@H@("`@("`@(&EF("@D
M<F5T=7)N7W9A;'5E("$](#`I('L*("`@("`@("`@("`@<F5T=7)N("1O=71P
M=70@/R!014%2.CIR86ES945R<F]R*"1O=71P=70I(#H@9F%L<V4["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L:6(O1')I=F5R+W-E<G9U
M9G1P+G!H<```````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<Q,#4`,3`T
M,3<S-C(W-#,`,#(R,S$T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@<V5R=BUU(&9T<"!C;&%S
M<R!A='1E;7!T<R!T;R!C:&%N9V4@82!U<V5R)W,@<&%S<W=O<F0@=FEA('1H
M92!3251%(%!35T0*("H@8V]M;6%N9"!U<V5D(&)Y(%-E<G8M=2!F='!D(&9O
M<B!W:6YD;W=S+@H@*@H@*B`D2&]R9&4Z('!A<W-W9"]L:6(O1')I=F5R+W-E
M<G9U9G1P+G!H<"QV(#$N,30@,C`P-2\P."\R,R`Q,3HQ-3HP-B!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P-2!(;W)D92!0<F]J96-T("AH
M='1P.B\O=W=W+FAO<F1E+F]R9R\I"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H
M;W(@($QU8V%S($YE;&%N("AS8W)E96Y`8G)A:6YK<F%S:"YC;VTI"B`J($!P
M86-K86=E(%!A<W-W9`H@*B\*8VQA<W,@4&%S<W=D7T1R:79E<E]S97)V=69T
M<"!E>'1E;F1S(%!A<W-W9%]$<FEV97(@>PH*("`@('9A<B`D9G`["B`@("!V
M87(@)&9T<&1?8V]N;F5C=&5D("`@/2`G,C(P)SL*("`@('9A<B`D9G1P9%]G
M;V]D8GEE("`@("`]("<R,C$G.PH@("`@=F%R("1F='!D7W!A<W-W;W)D;VL@
M(#T@)S(S,"<["B`@("!V87(@)&9T<&1?=7-E<FYA;65O:R`@/2`G,S,Q)SL*
M("`@('9A<B`D9G1P9%]P87-S=V]R9&)A9"`]("<U,S`G.PH*("`@(&9U;F-T
M:6]N(&-O;FYE8W0H)'-E<G9E<BP@)'!O<G0L("1T:6UE;W5T(#T@,S`I"B`@
M("!["B`@("`@("`@)'1H:7,M/F9P(#T@9G-O8VMO<&5N*"1S97)V97(L("1P
M;W)T+"`D97)R;F\L("1E<G)S='(L("1T:6UE;W5T*3L*"B`@("`@("`@:68@
M*"$D=&AI<RT^9G`I('L*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<G-T<B`]
M("1E<G)S='(["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=%!R;VUP="@I
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YF<"D@>PH@("`@("`@("`@("!F
M<'5T<R@D=&AI<RT^9G`L(")Q=6ET7&XB*3L*("`@("`@("`@("`@9F-L;W-E
M*"1T:&ES+3YF<"D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%!R;VUP="@I"B`@("!["B`@("`@("`@)'!R;VUP="`](&9G971S*"1T:&ES
M+3YF<"P@-#`Y-BD["B`@("`@("`@)')E='5R;B`]("<G.PH*("`@("`@("!I
M9B`H<')E9U]M871C:"@G+UY;,2TU75LP+3E=6S`M.5TO)RP@)'!R;VUP="P@
M)')E<RDI('L*("`@("`@("`@("`@)')E='5R;B`]("1R97-;,5T["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E='5R;CL*("`@('T*"B`@("!F=6YC
M=&EO;B!S96YD0V]M;6%N9"@D8VUD+"`D87)G*0H@("`@>PH@("`@("`@("1L
M:6YE(#T@)&-M9"`N("<@)R`N("1A<F<@+B`B7')<;B(["B`@("`@("`@9G!U
M=',H)'1H:7,M/F9P+"`D;&EN92D["B`@("`@("`@<F5T=7)N("1T:&ES+3YG
M9710<F]M<'0H*3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%N9V5087-S=V]R
M9"@D=7-E<E]N86UE+"`D;VQD7W!A<W-W;W)D+"`D;F5W7W!A<W-W;W)D*0H@
M("`@>PH@("`@("`@("1S97)V97(@/2!I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M:&]S="==*2`_("1T:&ES+3Y?<&%R86US6R=H;W-T)UT@.B`G)SL*("`@("`@
M("`D<&]R="`](&ES<V5T*"1T:&ES+3Y?<&%R86US6R=P;W)T)UTI(#\@)'1H
M:7,M/E]P87)A;7-;)W!O<G0G72`Z("<G.PH@("`@("`@("1T:6UE;W5T(#T@
M:7-S970H)'1H:7,M/E]P87)A;7-;)W1I;65O=70G72D@/R`D=&AI<RT^7W!A
M<F%M<ULG=&EM96]U="==(#H@)R<["@H@("`@("`@(&EF("@D<V5R=F5R(#T]
M("<G('Q\("1P;W)T(#T]("<G*2!["B`@("`@("`@("`@("1T:&ES+3Y?97)R
M;W)S='(@/2!?*")087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O
M;F9I9W5R960B*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@)')E='5R;E]V86QU92`](&9A;'-E.PH@("`@("`@(&EF
M("@D=&AI<RT^8V]N;F5C="@D<V5R=F5R+"`D<&]R="P@)'1I;65O=70I(#T]
M("1T:&ES+3YF='!D7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/G-E;F1#;VUM86YD*"=U<V5R)RP@)'5S97)?;F%M92D@/3T@)'1H:7,M
M/F9T<&1?=7-E<FYA;65O:RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YS96YD0V]M;6%N9"@G<&%S<R<L("1O;&1?<&%S<W=O<F0I(#T]("1T:&ES
M+3YF='!D7W!A<W-W;W)D;VLI('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/G-E;F1#;VUM86YD*"=S:71E('!S=V0G+"`G(B<N)&]L9%]P87-S
M=V]R9"XG(B`B)RXD;F5W7W!A<W-W;W)D+B<B)RD@/3T@)'1H:7,M/F9T<&1?
M<&%S<W=O<F1O:RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N
M7W9A;'5E(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?
M9&ES8V]N;F5C="@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U
M<FY?=F%L=64["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VM087-S=V]R9"@D
M=7-E<E]N86UE+"`D=7-E<E]P87-S=V]R9"D*("`@('L*("`@("`@("`D<V5R
M=F5R(#T@:7-S970H)'1H:7,M/E]P87)A;7-;)VAO<W0G72D@/R`D=&AI<RT^
M7W!A<F%M<ULG:&]S="==(#H@)R<["B`@("`@("`@)'!O<G0@/2!I<W-E="@D
M=&AI<RT^7W!A<F%M<ULG<&]R="==*2`_("1T:&ES+3Y?<&%R86US6R=P;W)T
M)UT@.B`G)SL*("`@("`@("`D=&EM96]U="`](&ES<V5T*"1T:&ES+3Y?<&%R
M86US6R=T:6UE;W5T)UTI(#\@)'1H:7,M/E]P87)A;7-;)W1I;65O=70G72`Z
M("<G.PH*("`@("`@("!I9B`H)'-E<G9E<B`]/2`G)R!\?"`D<&]R="`]/2`G
M)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R<W1R(#T@7R@B4&%S<W=O
M<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+B(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5T
M=7)N7W9A;'5E(#T@9F%L<V4["@H@("`@("`@(&EF("@D=&AI<RT^8V]N;F5C
M="@D<V5R=F5R+"`D<&]R="P@)'1I;65O=70I(#T]("1T:&ES+3YF='!D7V-O
M;FYE8W1E9"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G-E;F1#;VUM86YD
M*"=U<V5R)RP@)'5S97)?;F%M92D@/3T@)'1H:7,M/F9T<&1?=7-E<FYA;65O
M:RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YS96YD0V]M;6%N9"@G
M<&%S<R<L("1U<V5R7W!A<W-W;W)D*2`]/2`D=&AI<RT^9G1P9%]P87-S=V]R
M9&]K*2!["B`@("`@("`@("`@("`@("`@("`@)')E='5R;E]V86QU92`]('1R
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&ES+3Y?9&ES8V]N;F5C="@I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\O($-A;FYO="!C;VYN96-T+@H@("`@("`@("`@("`D<F5T
M=7)N7W9A;'5E(#T@+3$["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E
M='5R;E]V86QU93L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W
M9"]L:6(O1')I=F5R+W!S<&%S<W=D+G!H<```````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3`Q-C8`,3`T,3<S-C(W-#,`,#(R,S`S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@4%-087-S=V0@8VQA<W,@8VAA;F=E<R!A('5S97(G<R!P87-S=V]R9"!O
M;B!A;GD@5VEN9&]W<R!-86-H:6YE"B`J("A.5"LI('5S:6YG('1H92!P<W!A
M<W-W9"!F<F5E('5T:6QI='D@879A:6QA8FQE(&%T(%-Y<VEN=&5R;F%L<PH@
M*B!W96)S:71E.B!H='1P.B\O=W=W+G-Y<VEN=&5R;F%L<RYC;VTO;G1W,FLO
M9G)E97=A<F4O<'-P87-S=V0N<VAT;6P*("H*("H@24U03U)404Y4(0H@*@H@
M*B!4:&ES(&1R:79E<B!S:&]U;&0@8F4@=7-E9"!O;FQY(&%S(&$@;&%S="!R
M97-O<G0@=VAE;B!T:&5R92=S(&YO"B`J('!O<W-I8FEL:71Y(&]F('5S:6YG
M('1H92!!1%-)(&]R($Q$05`@9')I=F5R<RP@=VAI8V@@87)E(&9A<B!M;W)E
M"B`J('-E8W5R92!A;F0@9F%S="X@5&AI<R!D<FEV97(@;F5E9',@861M:6YI
M<W1R871I=F4@8W)E9&5N=&EA;',*("H@97AP;W-E9"!O;B!T:&4@8F%C:V5N
M9',N<&AP(&9I;&4L('=H:6-H(&ES(')E<75I<F5D(&)Y('1H90H@*B!P<W!A
M<W-W9"YE>&4@=&]O;"X@270G<R!A;B!A;'1E<FYA=&EV92!D<FEV97(@=&AA
M="!S:&]U;&0@8F4*("H@879O:61E9"P@8G5T(&-O=6QD(&%L<V\@8F4@=&AE
M(&]N;'D@;W!T:6]N(&9O<B!A(&9E=R!S8V5N87)I;W,N"B`J("AE9SH@5VAE
M;B!Y;W4@9&]N)W0@:&%V92!!1%-)(&]R($Q$05`@<W5P<&]R="D*("H*("H@
M4V%M<&QE(&)A8VME;F0@8V]N9FEG=7)A=&EO;CH*("H@/&-O9&4^"B`J("1B
M86-K96YD<ULG<'-P87-S=V0G72`](&%R<F%Y*`H@*B`@("=N86UE)R`]/B`G
M4V%M<&QE('!S<&%S<W=D(&)A8VME;F0G+`H@*B`@("=P<F5F97)R960G(#T^
M("=L;V-A;&AO<W0G+`H@*B`@("=P87-S=V]R9"!P;VQI8WDG(#T^(&%R<F%Y
M*`H@*B`@("`@("`G;6EN3&5N9W1H)R`]/B`X+`H@*B`@("`@("`G;6%X3&5N
M9W1H)R`]/B`Q-`H@*B`@("DL"B`J("`@)V1R:79E<B<@/3X@)W!S<&%S<W=D
M)RP*("H@("`G<&%R86US)R`]/B!A<G)A>2@*("H)"2`G<V5R=F5R)R`]/B`G
M64]54E]315)615)?3D%-12<L"B`J"0D@)V)I;B<@/3X@)T12259%.EQ<1$E2
M7%QP<W!A<W-W9"YE>&4G+"`O+R!.;W1I8V4Z(")<7"(*("H)"2`G861M=7-R
M)R`]/B`G061M:6YI<W1R871O<B<L"B`J"2`@"2`G861M<'=D)R`]/B`G4&%S
M<W=O<F0G+`H@*B`@("`@("`G9&]M86EN)R`]/B`G64]54E]$3TU!24Y?3D%-
M12<*("H@("`I"B`J("D["B`J(#PO8V]D93X*("H*("H@0F%C:V5N9"!P87)A
M;65T97)S.CQP<F4^"B`J('-E<G9E<@D]($UA8VAI;F4@=VAE<F4@>6]U('=A
M;G0@=&\@8VAA;F=E('1H92!P87-S=V]R9"`H4F5Q=6ER960I"B`J(&)I;@D)
M/2!&=6QL('!A=&AN86UE(&]F('1H92!P<W!A<W-W9"YE>&4@<')O9W)A;2`H
M4F5Q=6ER960I"B`J(&%D;75S<@D](%5S97(@=VET:"!A9&UI;FES=')A=&EV
M92!P<FEV:6QE9V5S("A297%U:7)E9"D*("H@861M<'=D"3T@4&%S<W=O<F0@
M;V8@=&AE(&%D;6EN:7-T<F%T:79E('5S97(@*%)E<75I<F5D*0H@*B!D;VUA
M:6X)/2!7:6YD;W=S(&1O;6%I;B!N86UE("A/<'1I;VYA;"D*("H@/"]P<F4^
M"B`J"B`J($9O<B!E>&%M<&QE.B!087-S:6YG(&$@3E0T(%!$0R!S97)V97(@
M;F%M92!T;R!T:&4@<V5R=F5R('!A<F%M971E<@H@*B!M96%N<R!Y;W4@8V%N
M(&-H86YG92!T:&4@=7-E<B=S('!A<W-W;W)D(&]N('1H870@3E0T($1O;6%I
M;BX*("H*("H@4W!E8VEA;"!T:&%N:W,@=&\@36%R:R!2=7-S:6YO=FEC:"`H
M;6%R:T!S>7-I;G1E<FYA;',N8V]M*2!F;W(@=&AE"B`J('1O;VP@86YD(&AE
M;'!I;F<@;64@<V]L=F4@<V]M92!Q=65S=&EO;G,@86)O=70@:70N"B`J"B`J
M("1(;W)D93H@<&%S<W=D+VQI8B]$<FEV97(O<'-P87-S=V0N<&AP+'8@,2XR
M(#(P,#4O,#@O,C,@,3$Z,34Z,#8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`T+3(P,#4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D92YO
M<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L
M:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!,=6EZ(%(@36%L:&5I
M<F]S("AM86QH96ER;W-`9VUA:6PN8V]M*0H@*B!`<VEN8V4@("!087-S=V0@
M,RXP"B`J($!P86-K86=E(%!A<W-W9`H@*B\*8VQA<W,@4&%S<W=D7T1R:79E
M<E]P<W!A<W-W9"!E>'1E;F1S(%!A<W-W9%]$<FEV97(@>PH*("`@(&9U;F-T
M:6]N(&-H86YG95!A<W-W;W)D*"1U<V5R7VYA;64L("1O;&1?<&%S<W=O<F0L
M("1N97=?<&%S<W=O<F0I"B`@("!["B`@("`@("`@)'-E<G9E<B`](&ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=S97)V97(G72D@/R`D=&AI<RT^7W!A<F%M<ULG
M<V5R=F5R)UT@.B`G)SL*("`@("`@("`D8FEN(#T@:7-S970H)'1H:7,M/E]P
M87)A;7-;)V)I;B==*2`_("1T:&ES+3Y?<&%R86US6R=B:6XG72`Z("<G.PH@
M("`@("`@("1A9&UU<W(@/2!I<W-E="@D=&AI<RT^7W!A<F%M<ULG861M=7-R
M)UTI(#\@)'1H:7,M/E]P87)A;7-;)V%D;75S<B==(#H@)R<["B`@("`@("`@
M)&%D;7!W9"`](&ES<V5T*"1T:&ES+3Y?<&%R86US6R=A9&UP=V0G72D@/R`D
M=&AI<RT^7W!A<F%M<ULG861M<'=D)UT@.B`G)SL*("`@("`@("`D9&]M86EN
M(#T@:7-S970H)'1H:7,M/E]P87)A;7-;)V1O;6%I;B==*2`_("1T:&ES+3Y?
M<&%R86US6R=D;VUA:6XG72`Z("<G.PH*("`@("`@("!I9B`H)'-E<G9E<B`]
M/2`G)R!\?"`D8FEN(#T]("<G('Q\("1A9&UU<W(@/3T@)R<@?'P@)&%D;7!W
M9"`]/2`G)RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!R97%U:7)E9"!P87)A
M;65T97)S+B(I*3L*("`@("`@("!](&5L<V5I9B`H9FEL95]E>&ES=',H)&)I
M;BD@/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B4&%S<W=O<F0@;6]D=6QE(&-A;B=T(&9I;F0@=&AE('-U<'!L
M:65D(&)I;BXB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1O;6%I;B`A
M/2`G)RD@>PH@("`@("`@("`@("`D8VAP=V1?861M(#T@)&1O;6%I;B`N(")<
M7"(@+B`D861M=7-R.PH@("`@("`@("`@("`D8VAP=V1?=7-R(#T@)&1O;6%I
M;B`N(")<7"(@+B`D=7-E<E]N86UE.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1C:'!W9%]A9&T@/2`D861M=7-R.PH@("`@("`@("`@("`D8VAP
M=V1?=7-R(#T@)'5S97)?;F%M93L*("`@("`@("!]"@H@("`@("`@(&5X96,H
M)TY%5"!54T4@7%Q<7"<@+B`D<V5R=F5R("X@)UQ<25!#)"`O1"`^3E5,(#(^
M3E5,)RD["@H@("`@("`@("1C;61L:6YE(#T@)TY%5"!54T4@7%Q<7"<@+B`D
M<V5R=F5R("X@)UQ<25!#)"`B)R`N("1O;&1?<&%S<W=O<F0@+B`G(B`O55-%
M4CHG("X@)&-H<'=D7W5S<CL*"B`@("`@("`@97AE8R@D8VUD;&EN92P@)&-M
M9')E<&QY+"`D<F5T=F%L*3L*"B`@("`@("`@:68@*'-T<G!O<RAI;7!L;V1E
M*"<@)RP@)&-M9')E<&QY*2P@)U1H92!C;VUM86YD(&-O;7!L971E9"!S=6-C
M97-S9G5L;'DN)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(D9A:6QE9"!T;R!V97)I9GD@;VQD('!A<W-W
M;W)D+B(I*3L*("`@("`@("!]"@H@("`@("`@(&5X96,H)TY%5"!54T4@7%Q<
M7"<@+B`D<V5R=F5R("X@)UQ<25!#)"`O1"`^3E5,(#(^3E5,)RD["@H@("`@
M("`@("1C;61L:6YE(#T@)&)I;B`N("<@7%Q<7"<@+B`D<V5R=F5R("X@)R`M
M=2`G("X@)&-H<'=D7V%D;2`N("<@+7`@)R`N("1A9&UP=V0@+B`G("<@+B`D
M=7-E<E]N86UE("X@)R`G("X@)&YE=U]P87-S=V]R9#L*"B`@("`@("`@97AE
M8R@D8VUD;&EN92P@)&-M9')E<&QY+"`D<F5T=F%L*3L*"B`@("`@("`@97AE
M8R@G3D54(%5312!<7%Q<)R`N("1S97)V97(@+B`G7%Q)4$,D("]$(#Y.54P@
M,CY.54PG*3L*"B`@("`@("`@:68@*'-T<G!O<RAI;7!L;V1E*"<@)RP@)&-M
M9')E<&QY*2P@)U!A<W-W;W)D(&9O<B`G("X@)'-E<G9E<B`N("=<7"<@+B`D
M=7-E<E]N86UE("X@)R!S=6-C97-S9G5L;'D@8VAA;F=E9"XG*2`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M06-C97-S($1E;FEE9"XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQI8B]$<FEV
M97(O861S:2YP:'``````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#`U,0`Q,#0Q-S,V,C<T,P`P,C$S-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!!1%-)(&-L
M87-S(&-H86YG97,@82!U<V5R)W,@<&%S<W=O<F0@;VX@86YY(%=I;F1O=W,@
M36%C:&EN92].5"U$;VUA:6X*("H@=7-I;F<@=&AE($%$4TD@0T]-($EN=&5R
M9F%C92X*("H*("H@3D]415,Z"B`J"B`J("T@268@>6]U('!L86X@=&\@:6UP
M;&5M96YT('!A<W-W9"!O=F5R($%C=&EV92!$:7)E8V]R>2!Y;W4@;75S="!U
M<V4@=&AE"B`J("`@3$1!4"!D<FEV97(@86YD(&YO="!T:&ES(&]N92$@5&AI
M<R!D<FEV97(@:7,@9&5S:6=N960@9F]R('-T86YD86QO;F4*("H@("!M86-H
M:6YE<R!O<B!.5#0@9&]M86EN<RP@;VYL>2X*("H*("H@+2!4:&4@:&]S="!S
M97)V97(@;75S="!B92!7:6XS,B!W:71H($%$4TD@<W5P<&]R="X*("H*("H@
M4V%M<&QE(&)A8VME;F0@8V]N9FEG=7)A=&EO;CH*("H@/&-O9&4^"B`J("1B
M86-K96YD<ULG861S:2==(#T@87)R87DH"B`J("`@("=N86UE)R`]/B`G4V%M
M<&QE($%$4TD@8F%C:V5N9"<L"B`J("`@("=P<F5F97)R960G(#T^("=L;V-A
M;&AO<W0G+`H@*B`@("`G<&%S<W=O<F0@<&]L:6-Y)R`]/B!A<G)A>2@*("H@
M("`@("`@("=M:6Y,96YG=&@G(#T^(#@L"B`J("`@("`@("`G;6%X3&5N9W1H
M)R`]/B`Q-`H@*B`@("`I+`H@*B`@("`G9')I=F5R)R`]/B`G861S:2<L"B`J
M("`@("=P87)A;7,G(#T^(&%R<F%Y*`H@*B`@("`@("`@)W1A<F=E="<@/3X@
M)UE/55)?34%#2$E.12]$3TU!24Y?3D%-15](15)%)PH@*B`@("`I"B`J("D*
M("H@/"]C;V1E/@H@*@H@*B!"86-K96YD('!A<F%M971E<G,Z"B`J('1A<F=E
M="`](%1A<F=E="!7:6YD;W=S(&UA8VAI;F4O9&]M86EN(&YA;64@*%)E<75I
M<F5D*0H@*@H@*B`D2&]R9&4Z('!A<W-W9"]L:6(O1')I=F5R+V%D<VDN<&AP
M+'8@,2XT(#(P,#4O,#@O,C,@,3$Z,34Z,#8@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH
M;W)D92YO<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y3
M12!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E
M+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!,=6EZ(%(@
M36%L:&5I<F]S(#QM86QH96ER;W-`9VUA:6PN8V]M/@H@*B!`<VEN8V4@("!0
M87-S=V0@,RXP"B`J($!P86-K86=E(%!A<W-W9`H@*B\*8VQA<W,@4&%S<W=D
M7T1R:79E<E]A9'-I(&5X=&5N9',@4&%S<W=D7T1R:79E<B!["@H@("`@9G5N
M8W1I;VX@8VAA;F=E4&%S<W=O<F0H)'5S97)?;F%M92P@)&]L9%]P87-S=V]R
M9"P@)&YE=U]P87-S=V]R9"D*("`@('L*("`@("`@("`D=&%R9V5T(#T@:7-S
M970H)'1H:7,M/E]P87)A;7-;)W1A<F=E="==*2`_("1T:&ES+3Y?<&%R86US
M6R=T87)G970G72`Z("<G.PH*("`@("`@("!I9B`H96UP='DH)'1A<F=E="DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&%S
M<W=O<F0@;6]D=6QE(&ES(&UI<W-I;F<@=&%R9V5T('!A<F%M971E<BXB*2D[
M"B`@("`@("`@?0H*("`@("`@("`D<F]O="`]("9N97<@0T]-*"=7:6Y.5#HG
M*3L*"B`@("`@("`@:68@*"1A9'-I(#T@)')O;W0M/D]P96Y$4T]B:F5C="@G
M5VEN3E0Z+R\G("X@)'1A<F=E="`N("<O)R`N("1U<V5R7VYA;64@+B`G+'5S
M97(G+"`D=&%R9V5T("X@)UQ<)R`N("1U<V5R7VYA;64L("1O;&1?<&%S<W=O
M<F0L(#$I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D861S:2T^0VAA;F=E
M4&%S<W=O<F0H)&]L9%]P87-S=V]R9"P@)&YE=U]P87-S=V]R9"D["B`@("`@
M("`@("`@(&EF("@D<F5S=6QT(#T](#`I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")!1%-)(&5R
M<F]R("5S+B(I+"`D<F5S=6QT*2D["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")!8V-E<W,@1&5N:65D+B(I*3L*("`@("`@("!]"B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S
M<W=D+VQI8B]$<FEV97(O<VUB;&1A<"YP:'``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-S`Q,P`Q,#0Q-S,V,C<T,P`P,C(P-38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O;&1A<"YP:'`G.PH*+RHJ
M"B`J(%1H92!,1$%0(&-L87-S(&%T=&5M<'1S('1O(&-H86YG92!A('5S97(G
M<R!,1$%0('!A<W-W;W)D(&%N9"!386UB82!P87-S=V]R9`H@*B!S=&]R960@
M:6X@86X@3$1!4"!D:7)E8W1O<GD@<V5R=FEC92X*("H*("H@)$AO<F1E.B!P
M87-S=V0O;&EB+T1R:79E<B]S;6)L9&%P+G!H<"QV(#$N-R`R,#`U+S`X+S(T
M(#`V.C,Y.C4X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`U
M($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R9&4N;W)G+RD*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$%33"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O87-L
M+G!H<"X*("H*("H@0&%U=&AO<B`@4VAA;F4@0F]U;'1E<B`\<V)O=6QT97)`
M87)I87-O;'5T:6]N<RYC;VT^"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!A=71H;W(@(%1J965R9"!V
M86X@9&5R(%IE92`\861M:6Y`>&%R+FYL/@H@*B!`875T:&]R("!-871T:6%S
M(%=E8FKV<FX@17)I:W-S;VX@/&UA='1I87-`=V5B:F]R;BYO<F<^"B`J($!A
M=71H;W(@($5R:6,@2F]N(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY
M<VEC<RYU=&5X87,N961U/@H@*B!`<VEN8V4@("!087-S=V0@,RXP"B`J($!P
M86-K86=E(%!A<W-W9`H@*B\*8VQA<W,@4&%S<W=D7T1R:79E<E]S;6)L9&%P
M(&5X=&5N9',@4&%S<W=D7T1R:79E<E]L9&%P('L*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=',@82!N97<@4&%S<W=D7T1R:79E<E]S;6)L9&%P(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!087-S=V1?1')I=F5R7W-M8FQD87`H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*&%R
M<F%Y*"=L;5]A='1R:6)U=&4G(#T^("=S86UB84Q-4&%S<W=O<F0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;G1?871T<FEB=71E
M)R`]/B`G<V%M8F%.5%!A<W-W;W)D)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!W7W-E=%]A='1R:6)U=&4G(#T^("=S86UB85!W
M9$QA<W13970G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<'=?97AP:7)E7V%T=')I8G5T92<@/3X@)W-A;6)A4'=D375S=$-H86YG
M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P=U]E
M>'!I<F5?=&EM92<@/3X@,C$T-S0X,S8T-RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)A;7,I.PH@("`@("`@('!A<F5N=#HZ4&%S<W=D
M7T1R:79E<E]L9&%P*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAA;F=E('1H92!U<V5R)W,@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<FYA;64@("`@("!4:&4@=7-E<B!F;W(@=VAI8V@@
M=&\@8VAA;F=E('1H92!P87-S=V]R9"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&]L9%]P87-S=V]R9"`@5&AE(&]L9"`H8W5R<F5N="D@=7-E<B!P87-S=V]R
M9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=U]P87-S=V]R9"`@5&AE(&YE
M=R!U<V5R('!A<W-W;W)D('1O('-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;W(@9F%L<V4@8F%S960@;VX@<W5C8V5S<R!O9B!T
M:&4@8VAA;F=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&%N9V5087-S=V]R
M9"@D=7-E<FYA;64L("1O;&1?<&%S<W=O<F0L("1N97=?<&%S<W=O<F0I"B`@
M("!["B`@("`@("`@+R\@1V5T('1H92!U<V5R)W,@9&XN"B`@("`@("`@)'5S
M97)D;B`]("1T:&ES+3Y?=7-E<D1.*"1U<V5R;F%M92P@)&]L9%]P87-S=V]R
M9"D["B`@("`@("`@:68@*&ES7V$H)'5S97)D;BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'5S97)D;CL*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2!P87)E;G0Z.F-H86YG95!A<W-W;W)D*"1U<V5R;F%M
M92P@)&]L9%]P87-S=V]R9"P@)&YE=U]P87-S=V]R9"D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC
M92`G0W)Y<'0O0TA!4"YP:'`G.PH@("`@("`@("1H87-H(#T@)FYE=R!#<GEP
M=%]#2$%07TU3=C(H*3L*("`@("`@("`D:&%S:"T^<&%S<W=O<F0@/2`D;F5W
M7W!A<W-W;W)D.PH@("`@("`@("1L;7!A<W-W9"`]('-T<G1O=7!P97(H8FEN
M,FAE>"@D:&%S:"T^;&U087-S=V]R9$AA<V@H*2DI.PH@("`@("`@("1N='!A
M<W-W9"`]('-T<G1O=7!P97(H8FEN,FAE>"@D:&%S:"T^;G1087-S=V]R9$AA
M<V@H*2DI.PH@("`@("`@("1S971T:6UE(#T@=&EM92@I.PH@("`@("`@("\O
M(#(T(&AO=7)S+V1A>2`J(#8P(&UI;B]H;W5R("H@-C`@<V5C<R]M:6X@/2`X
M-C0P,"!S96-O;F1S+V1A>0H@("`@("`@("1E>'!I<F5T:6UE(#T@)'-E='1I
M;64@*R`H)'1H:7,M/E]P87)A;7-;)W!W7V5X<&ER95]T:6UE)UT@*B`X-C0P
M,"D["@H@("`@("`@("1N97=?;&U?<&%S<W=D6R1T:&ES+3Y?<&%R86US6R=L
M;5]A='1R:6)U=&4G75T@/2`D;&UP87-S=V0["B`@("`@("`@:68@*"%L9&%P
M7VUO9%]R97!L86-E*"1T:&ES+3Y?9',L("1U<V5R9&XL("1N97=?;&U?<&%S
M<W=D*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAL
M9&%P7V5R<F]R*"1T:&ES+3Y?9',I*3L*("`@("`@("!]"@H@("`@("`@("1N
M97=?;G1?<&%S<W=D6R1T:&ES+3Y?<&%R86US6R=N=%]A='1R:6)U=&4G75T@
M/2`D;G1P87-S=V0["B`@("`@("`@:68@*"%L9&%P7VUO9%]R97!L86-E*"1T
M:&ES+3Y?9',L("1U<V5R9&XL("1N97=?;G1?<&%S<W=D*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAL9&%P7V5R<F]R*"1T:&ES
M+3Y?9',I*3L*("`@("`@("!]"@H@("`@("`@("1N97=?<V5T7W1I;65;)'1H
M:7,M/E]P87)A;7-;)W!W7W-E=%]A='1R:6)U=&4G75T@/2`D<V5T=&EM93L*
M("`@("`@("!I9B`H(6QD87!?;6]D7W)E<&QA8V4H)'1H:7,M/E]D<RP@)'5S
M97)D;BP@)&YE=U]S971?=&EM92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H;&1A<%]E<G)O<B@D=&AI<RT^7V1S*2D["B`@("`@
M("`@?0H*("`@("`@("`D;F5W7W-E=%]T:6UE6R1T:&ES+3Y?<&%R86US6R=P
M=U]E>'!I<F5?871T<FEB=71E)UU=(#T@)&5X<&ER971I;64["B`@("`@("`@
M:68@*"%L9&%P7VUO9%]R97!L86-E*"1T:&ES+3Y?9',L("1U<V5R9&XL("1N
M97=?<V5T7W1I;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*&QD87!?97)R;W(H)'1H:7,M/E]D<RDI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQI8B]$<FEV97(O=G!O<&UA:6PN<&AP
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S<T-``Q,#0Q-S,V,C<T
M,P`P,C(R-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!V<&]P;6%I;"!C;&%S<R!A='1E;7!T
M<R!T;R!C:&%N9V4@82!U<V5R)W,@<&%S<W=O<F0@9F]R('9P;W!M86EL(&)A
M<V5D"B`J('-E<G9E<G,N("!)="!I<R!V97)Y('-I;6EL87(@=&\@=&AE(&UO
M<F4@9V5N97)I8R!S<6P@9')I=F5R+"!A;F0@=&AE('1W;PH@*B!S:&]U;&0@
M<')O8F%B;'D@8F4@;65R9V5D(&EN=&\@;VYE(&1R:79E<B!I9B!P;W-S:6)L
M92X*("H*("H@)$AO<F1E.B!P87-S=V0O;&EB+T1R:79E<B]V<&]P;6%I;"YP
M:'`L=B`Q+C$W(#(P,#4O,#@O,C,@,3$Z,34Z,#8@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W
M=RYH;W)D92YO<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#
M14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!!;G1O
M;B!.96MH;W)O<VAI:V@@/&%N=&]N0'9A;'5E:&]S="YR=3X*("H@0&%U=&AO
M<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@
M0&%U=&AO<B`@26QY82!+<F5L(#QM86EL0&MR96PN;W)G/@H@*B!`875T:&]R
M("!4:F5E<F0@=F%N(&1E<B!:964@/&%D;6EN0'AA<BYN;#X*("H@0&%U=&AO
M<B`@36%T=&EA<R!796)J]G)N($5R:6MS<V]N(#QM871T:6%S0'=E8FIO<FXN
M;W)G/@H@*B!`875T:&]R("!%<FEC($IO;B!2;W-T971T97(@/&5R:6,N<F]S
M=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@0'-I;F-E("`@4&%S<W=D
M(#(N,@H@*B!`<&%C:V%G92!087-S=V0*("HO"F-L87-S(%!A<W-W9%]$<FEV
M97)?=G!O<&UA:6P@97AT96YD<R!087-S=V1?1')I=F5R('L*"B`@("`O*BH*
M("`@("`J(%-13"!C;VYN96-T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M=F%R($1""B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@
M4W1A=&4@;V8@4U%,(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!087-S=V1?1')I=F5R
M7W9P;W!M86EL(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!087-S=V1?1')I=F5R7W9P;W!M
M86EL*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D<&%R86US6R=P:'!T>7!E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=P:'!T>7!E)UT@/2`D<&%R86US6R=P:'!T>7!E)UT["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@4U%,
M(&-O;F9I9W5R871I;VXN(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@57-E
M(&1E9F%U;'1S(&9R;VT@2&]R9&4N("HO"B`@("`@("`@)&1E9F%U;'1S(#T@
M2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G)RP@)W-Q;"<I.PH@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==("`@/2!I<W-E="@D<&%R86US6R=H
M;W-T<W!E8R==*2`@(#\@)'!A<F%M<ULG:&]S='-P96,G72`Z("1D969A=6QT
M<ULG:&]S='-P96,G73L*("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<')O=&]C
M;VPG72`@(#T@:7-S970H)'!A<F%M<ULG<')O=&]C;VPG72D@("`_("1P87)A
M;7-;)W!R;W1O8V]L)UT@.B`D9&5F875L='-;)W!R;W1O8V]L)UT["B`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@("`](&ES<V5T*"1P87)A
M;7-;)W5S97)N86UE)UTI("`@/R`D<&%R86US6R=U<V5R;F%M92==(#H@)&1E
M9F%U;'1S6R=U<V5R;F%M92==.PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=P
M87-S=V]R9"==("`@/2!I<W-E="@D<&%R86US6R=P87-S=V]R9"==*2`@(#\@
M)'!A<F%M<ULG<&%S<W=O<F0G72`Z("1D969A=6QT<ULG<&%S<W=O<F0G73L*
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72`@(#T@:7-S970H
M)'!A<F%M<ULG9&%T86)A<V4G72D@("`_("1P87)A;7-;)V1A=&%B87-E)UT@
M.B`D9&5F875L='-;)V1A=&%B87-E)UT["@H@("`@("`@("\J($1E9F%U;'1S
M('1O(&UA=&-H($%U=&@Z.G-Q;"!D969A=6QT+B`J+PH@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L92==("`@("`@/2!I<W-E="@D<&%R86US6R=T86)L
M92==*2`@("`@(#\@)'!A<F%M<ULG=&%B;&4G72`Z("=H;W)D95]U<V5R<R<[
M"B`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72`](&ES<V5T
M*"1P87)A;7-;)V5N8W)Y<'1I;VXG72D@/R`D<&%R86US6R=E;F-R>7!T:6]N
M)UT@.B`G8W)Y<'0G.PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=N86UE)UT@
M("`@("`@/2!I<W-E="@D<&%R86US6R=N86UE)UTI("`@("`@(#\@)'!A<F%M
M<ULG;F%M92==(#H@)W!W7VYA;64G.PH@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=D;VUA:6XG72`@("`@/2!I<W-E="@D<&%R86US6R=D;VUA:6XG72D@("`@
M(#\@)'!A<F%M<ULG9&]M86EN)UT@.B`G<'=?9&]M86EN)SL*("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=D)UT@("`@(#T@:7-S970H)'!A<F%M<ULG
M<&%S<W=D)UTI("`@("`_("1P87)A;7-;)W!A<W-W9"==(#H@)W!W7W!A<W-W
M9"<["B`@("`@("`@)'1H:7,M/E]P87)A;7-;)V-L96%R7W!A<W-W9"==(#T@
M:7-S970H)'!A<F%M<ULG8VQE87)?<&%S<W=D)UTI("`@("`_("1P87)A;7-;
M)V-L96%R7W!A<W-W9"==(#H@)W!W7V-L96%R7W!A<W-W9"<["B`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W5S95]C;&5A<E]P87-S=V0G72`](&ES<V5T*"1P
M87)A;7-;)W5S95]C;&5A<E]P87-S=V0G72D@("`@(#\@)'!A<F%M<ULG=7-E
M7V-L96%R7W!A<W-W9"==(#H@9F%L<V4["B`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W-H;W=?96YC<GEP=&EO;B==(#T@:7-S970H)'!A<F%M<ULG<VAO=U]E
M;F-R>7!T:6]N)UTI(#\@)'!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UT@.B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A
M=&%B87-E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@A)'1H
M:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@+RH@0V]N;F5C="!T;R!T
M:&4@4U%,('-E<G9E<B!U<VEN9R!T:&4@<W5P<&QI960@<&%R86UE=&5R<RX@
M*B\*("`@("`@("`@("`@:6YC;'5D95]O;F-E("=$0BYP:'`G.PH@("`@("`@
M("`@("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES+3Y?<&%R86US
M+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB
M*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E
M=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!
M4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYN96-T960@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A
M('5S97)N86UE(&%N9"!P87-S=V]R9"!I<R!V86QI9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92`@("`@(%1H92!U<V5R;F%M92!T
M;R!C:&5C:RX*("`@("`J($!P87)A;2!S=')I;F<@)&]L9%]P87-S=V]R9"`@
M06X@;VQD('!A<W-W;W)D('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@("`@("`@("`@("`@5')U92!O;B!V86QI9"!O<B!014%2
M7T5R<F]R(&]N(&EN=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L;V]K
M=7`H)'5S97)N86UE+"`D;VQD7W!A<W-W;W)D*0H@("`@>PH@("`@("`@("\J
M($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+B`J+PH@("`@("`@("1R97,@/2`D
M=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M('T*"B`@("`@("`@+RH@3VYL>2!S<&QI="!U<"!U<V5R;F%M92!I9B!D;VUA
M:6X@:7,@<V5T(&EN(&)A8VME;F0*("`@("`@("`@*B!C;VYF:6=U<F%T:6]N
M+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;B==*2D@>PH@("`@("`@("`@("!L:7-T*"1N86UE+"`D9&]M86EN*2`](&5X
M<&QO9&4H)T`G+"`D=7-E<FYA;64I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1N86UE(#T@)'5S97)N86UE.PH@("`@("`@('T*"B`@("`@("`@
M+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<W%L(#T@)U-%
M3$5#5"`G("X@)'1H:7,M/E]P87)A;7-;)W!A<W-W9"==("X*("`@("`@("`@
M("`@("`@)R!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@
M("`@("`@("`@("`@("<@5TA%4D4@)R`N("1T:&ES+3Y?<&%R86US6R=N86UE
M)UT@+B`G(#T@/R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1N86UE*3L*
M("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V1O;6%I;B==*2!["B`@("`@
M("`@("`@("1S<6P@+CT@)R!!3D0@)R`N("1T:&ES+3Y?<&%R86US6R=D;VUA
M:6XG72`N("<@/2`_)SL*("`@("`@("`@("`@)'9A;'5E<UM=(#T@)&1O;6%I
M;CL*("`@("`@("!]"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!087-S=V1?1')I=F5R7W9P;W!M86EL.CI?;&]O:W5P*"DZ("<@
M+B`D<W%L+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V86QU97,I.PH@("`@
M("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?
M05-33T,I.PH@("`@("`@("`@("`D<F5S=6QT+3YF<F5E*"D["B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D<F]W*2D@>PH@("`@("`@("`@("`@("`@+RH@
M1V5T('1H92!P87-S=V]R9"!F<F]M('1H92!D871A8F%S92X@*B\*("`@("`@
M("`@("`@("`@("1C=7)R96YT7W!A<W-W;W)D(#T@)')O=ULD=&AI<RT^7W!A
M<F%M<ULG<&%S<W=D)UU=.PH*("`@("`@("`@("`@("`@("\J(%-E92!I9B!T
M:&4@<&%S<W=O<F1S(&UA=&-H+B`J+PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YC;VUP87)E4&%S<W=O<F1S*"1C=7)R96YT7W!A<W-W;W)D+"`D
M;VQD7W!A<W-W;W)D*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B57-E<B!N;W0@9F]U;F0B
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;V1I9GD@*'5P9&%T92D@82!M
M>7-Q;"!P87-S=V]R9"!R96-O<F0@9F]R(&$@=7-E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92`@("`@(%1H92!U<V5R('=H;W-E
M(')E8V]R9"!W92!W:6QL('5D<&%T92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YE=U]P87-S=V]R9"`@5&AE(&YE=R!P87-S=V]R9"!V86QU92!T;R!S970N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]R($9A;'-E
M(&)A<V5D(&]N('-U8V-E<W,@;V8@=&AE(&UO9&EF>2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7VUO9&EF>2@D=7-E<FYA;64L("1N97=?<&%S<W=O<F0I"B`@
M("!["B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4N("HO"B`@
M("`@("`@)')E<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI
M<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97,["B`@("`@("`@?0H*("`@("`@("`O*B!/;FQY('-P;&ET('5P('5S
M97)N86UE(&EF(&1O;6%I;B!I<R!S970@:6X@8F%C:V5N9"X@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]P87)A;7-;)V1O;6%I;B==*2!["B`@("`@("`@("`@
M(&QI<W0H)&YA;64L("1D;VUA:6XI(#T@97AP;&]D92@G0"<L("1U<V5R;F%M
M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YA;64@/2`D=7-E
M<FYA;64["B`@("`@("`@?0H*("`@("`@("`O*B!%;F-R>7!T('1H92!P87-S
M=V]R9"X@*B\*("`@("`@("`D8VQE87)?<&%S<W=O<F0@/2`D;F5W7W!A<W-W
M;W)D.PH@("`@("`@("1N97=?<&%S<W=O<F0@/2`D=&AI<RT^96YC<GEP=%!A
M<W-W;W)D*"1N97=?<&%S<W=O<F0L("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N
M8W)Y<'1I;VXG72D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN
M("HO"B`@("`@("`@)'-Q;"`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US
M6R=T86)L92==("X*("`@("`@("`@("`@("`@)R!3150@)R`N("1T:&ES+3Y?
M<&%R86US6R=P87-S=V0G72`N("<@/2`_)SL*("`@("`@("`D=F%L=65S(#T@
M87)R87DH)&YE=U]P87-S=V]R9"D["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R
M86US6R=U<V5?8VQE87)?<&%S<W=D)UTI('L*("`@("`@("`@("`@)'-Q;"`N
M/2`G+"`G("X@)'1H:7,M/E]P87)A;7-;)V-L96%R7W!A<W-W9"==("X@)R`]
M(#\G.PH@("`@("`@("`@("`D=F%L=65S6UT@/2`D8VQE87)?<&%S<W=O<F0[
M"B`@("`@("`@?0H@("`@("`@("1S<6P@+CT@)R!72$5212`G("X@)'1H:7,M
M/E]P87)A;7-;)VYA;64G72`N("<@/2`_)SL*("`@("`@("`D=F%L=65S6UT@
M/2`D;F%M93L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V1O;6%I;B==
M*2!["B`@("`@("`@("`@("1S<6P@+CT@)R!!3D0@)R`N("1T:&ES+3Y?<&%R
M86US6R=D;VUA:6XG72`N("<@/2`_)SL*("`@("`@("`@("`@)'9A;'5E<UM=
M(#T@)&1O;6%I;CL*("`@("`@("!]"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U-13"!1=65R>2!B>2!087-S=V1?1')I=F5R7W9P;W!M86EL.CI?;6]D
M:69Y*"DZ("<@+B`D<W%L+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V86QU
M97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG
M92!T:&4@=7-E<B=S('!A<W-W;W)D+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97)N86UE("`@("`@5&AE('5S97(@9F]R('=H:6-H('1O(&-H
M86YG92!T:&4@<&%S<W=O<F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1?
M<&%S<W=O<F0@(%1H92!O;&0@*&-U<G)E;G0I('5S97(@<&%S<W=O<F0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N97=?<&%S<W=O<F0@(%1H92!N97<@=7-E
M<B!P87-S=V]R9"!T;R!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&]R(&9A;'-E(&)A<V5D(&]N('-U8V-E<W,@;V8@=&AE(&-H
M86YG92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAA;F=E4&%S<W=O<F0H)'5S
M97)N86UE+"`D;VQD7W!A<W-W;W)D+"`D;F5W7W!A<W-W;W)D*0H@("`@>PH@
M("`@("`@("\J($-H96-K('1H92!C=7)R96YT('!A<W-W;W)D+B`J+PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7VQO;VMU<"@D=7-E<FYA;64L("1O;&1?
M<&%S<W=O<F0I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI("!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]D:69Y*"1U<V5R;F%M92P@
M)&YE=U]P87-S=V]R9"D["B`@("!]"@I]"@``````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L:6(O
M+FAT86-C97-S````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,38`,3`T,3<S-C(W-#,`,#(P,C8R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$1E;GD@9G)O;2!A;&P*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&EB+W9E<G-I;VXN<&AP
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#4V`#$P
M-#$W,S8R-S0S`#`R,#8V-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<"!D969I;F4H)U!!4U-71%]615)324].)RP@
M)T@S("@S+C`I)RD@/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&%S<W=D+VQI8B]$<FEV97(N<&AP````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3<W,0`Q,#0Q-S,V,C<T,P`P
M,C`T-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%!A<W-W9%]$<FEV97(Z.B!D969I;F5S(&%N($%0
M22!F;W(@:6UP;&5M96YT:6YG('!A<W-W;W)D(&-H86YG92!S>7-T96US(&9O
M<@H@*B!087-S=V0N"B`J"B`J("1(;W)D93H@<&%S<W=D+VQI8B]$<FEV97(N
M<&AP+'8@,2XT-"`R,#`U+S`X+S(T(#`U.C0W.C4S('-E;'-K>2!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`U($AO<F1E(%!R;VIE8W0@*&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U
M=&AO<B`@17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N
M=71E>&%S+F5D=3X*("H@0'-I;F-E("`@4&%S<W=D(#(N,0H@*B!`<&%C:V%G
M92!087-S=V0*("HO"F-L87-S(%!A<W-W9%]$<FEV97(@>PH*("`@("\J*@H@
M("`@("H@2&%S:"!C;VYT86EN:6YG(&-O;F9I9W5R871I;VX@<&%R86UE=&5R
M<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!%<G)O<B!S=')I
M;F<@=&AA="!W:6QL(&)E(')E='5R;F5D('1O('1H92!U<V5R(&EF(&%N(&5R
M<F]R(&]C8W5R<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]E<G)O<G-T<CL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=',@82!N97<@97AP96-T(%!A<W-W9%]$<FEV97(@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI;F<@8V]N
M;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!087-S
M=V1?1')I=F5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($-O;7!A<F4@82!P;&%I;G1E>'0@<&%S<W=O<F0@=VET:"!A;B!E;F-R>7!T
M960@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&ES('1H97D@;6%T8V@L($9A;'-E(&EF('1H97D@9&EF9F5R"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;7!A<F5087-S=V]R9',H)&5N8W)Y<'1E9"P@
M)'!L86EN=&5X="D*("`@('L*("`@("`@("!R971U<FX@*"1E;F-R>7!T960@
M/3T@075T:#HZ9V5T0W)Y<'1E9%!A<W-W;W)D*"1P;&%I;G1E>'0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D96YC<GEP=&5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N
M8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N
M8W)Y<'1I;VXG72DI(#\*("`@("`@("`@("`@=')U92`Z"B`@("`@("`@("`@
M(%!%05(Z.G)A:7-E17)R;W(H7R@B26YC;W)R96-T(%!A<W-W;W)D(BDI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1F]R;6%T(&$@<&%S<W=O<F0@=7-I;F<@
M=&AE(&-U<G)E;G0@96YC<GEP=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P;&%I;G1E>'0@(%1H92!P;&%I;G1E>'0@<&%S<W=O<F0@=&\@
M96YC<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-R
M>7!T960@<&%S<W=O<F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'10
M87-S=V]R9"@D<&QA:6YT97AT*0H@("`@>PH@("`@("`@(')E='5R;B!!=71H
M.CIG971#<GEP=&5D4&%S<W=O<F0H)'!L86EN=&5X="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N
M8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE('5S97(G<R!P87-S=V]R
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92`@("`@
M5&AE('5S97(@9F]R('=H:6-H('1O(&-H86YG92!T:&4@<&%S<W=O<F0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1O;&1P87-S=V]R9"`@5&AE(&]L9"`H8W5R
M<F5N="D@=7-E<B!P87-S=V]R9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE
M=U]P87-S=V]R9"`@5&AE(&YE=R!U<V5R('!A<W-W;W)D('1O('-E="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;W(@9F%L<V4@8F%S
M960@;VX@<W5C8V5S<R!O9B!T:&4@8VAA;F=E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C:&%N9V5087-S=V]R9"@D=7-E<FYA;64L("1O;&1P87-S=V]R9"P@
M)&YE=U]P87-S=V]R9"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")"86-K96YD(&YO="!C;W)R96-T;'D@:6UP;&5M96YT960N
M(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@8V]N8W)E=&4@4&%S<W=D7T1R:79E<B!I;G-T86YC92!B87-E9"!O;@H@
M("`@("H@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E('!A<W-W9%]$<FEV97(@<W5B
M8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&\@<F5T=7)N
M+B!4:&4@:7,@8F%S960@;VX@=&AE('!A<W-W9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!D<FEV97(@*"1D<FEV97(I+B!4:&4@8V]D92!I<R!D
M>6YA;6EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;F-L
M=61E9"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@("AO
M<'1I;VYA;"D@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N9FEG=7)A=&EO;B!O<B!C
M;VYN96-T:6]N('!A<F%M971E<G,@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%!A<W-W
M9%]$<FEV97(*("`@("`J("`@("`@("`@("`@("`@(&EN<W1A;F-E+"!O<B!F
M86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH@("`@("`@(')E<75I<F5?
M;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O1')I=F5R+R<@+B`D9')I=F5R
M("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=087-S=V1?1')I=F5R7R<@
M+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E="`]("9N97<@)&-L87-S*"1P87)A
M;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO<F1E.CIF871A
M;"A014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B3F\@<W5C:"!B86-K96YD
M(%PB)7-<(B!F;W5N9"XB*2P@)&1R:79E<BDI+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E(%!A<W-W9%]$
M<FEV97(*("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I
M;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF(&YO(%!A
M<W-W9%]$<FEV97(@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S
M(&-U<G)E;G1L>0H@("`@("H@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@
M<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@<W1O<F%G92!S;W5R8V5S(&%R
M92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E
M(&EN=F]K960@87,Z("1V87(@/2`F4&%S<W=D7T1R:79E<CHZ<VEN9VQE=&]N
M*"D["B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@
M='EP92!O9B!C;VYC<F5T92!087-S=V1?1')I=F5R('-U8F-L87-S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@('1O(')E='5R;BX@(%1H92!I<R!B
M87-E9"!O;B!T:&4@<&%S<W=D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(&1R:79E<B`H)&1R:79E<BDN("!4:&4@8V]D92!I<R!D>6YA;6EC86QL
M>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@("AO<'1I;VYA;"D@
M02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N9FEG=7)A=&EO;B!O<B!C;VYN96-T:6]N
M('!A<F%M971E<G,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S
M=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1H92!C<F5A=&5D(&-O;F-R971E(%!A<W-W9%]$<FEV97(@:6YS=&%N
M8V4L(&]R(&9A;'-E"B`@("`@*B`@("`@("`@("`@("`@("!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E
M<R`](&%R<F%Y*"D["@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H
M87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A
M;F-E<ULD<VEG;F%T=7)E72`]("9087-S=V1?1')I=F5R.CIF86-T;W)Y*"1D
M<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I
M;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@`````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L:6(O4&%S<W=D+G!H<```````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4R,S<`,3`T,3<S
M-C(W-#,`,#(P-#4P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!087-S=V0@0F%S92!#;&%S<RX*("H*
M("H@)$AO<F1E.B!P87-S=V0O;&EB+U!A<W-W9"YP:'`L=B`Q+C$R(#(P,#4O
M,#@O,C,@,3$Z,34Z,#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`P
M+3(P,#4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D92YO<F<O*0H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E
M<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!P86-K86=E(%!A<W-W9`H@*B\*8VQA
M<W,@4&%S<W=D('L*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@=&AE
M(&=I=F5N(&)A8VME;F0@:7,@=&AE(")P<F5F97)R960B(&)A8VME;F0@9F]R
M"B`@("`@*B!T:&ES('=E8B!S97)V97(N("!4:&ES(&1E8VES:6]N(&ES(&)A
M<V5D(&]N('1H92!G;&]B86P*("`@("`J("=315)615)?3D%-12<@86YD("=(
M5%107TA/4U0G('-E<G9E<B!V87)I86)L97,@86YD('1H92!C;VYT96YT<PH@
M("`@("H@;V8@=&AE("=P<F5F97)R960G(&9I96QD(&EN('1H92!B86-K96YD
M)W,@9&5F:6YI=&EO;BX@(%1H90H@("`@("H@)W!R969E<G)E9"<@9FEE;&0@
M;6%Y('1A:V4@82!S:6YG;&4@=F%L=64@;W(@86X@87)R87D@;V8*("`@("`J
M(&UU;'1I<&QE('9A;'5E<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&)A8VME;F0@("`@($$@8V]M<&QE=&4@8F%C:V5N9"!E;G1R>2!F<F]M('1H
M92`D8F%C:V5N9',*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:&%S:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AI<R!E;G1R>2!I<R`B<')E9F5R<F5D(BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-0<F5F97)R961"86-K96YD*"1B86-K96YD*0H@("`@>PH@("`@("`@
M(&EF("@A96UP='DH)&)A8VME;F1;)W!R969E<G)E9"==*2D@>PH@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)&)A8VME;F1;)W!R969E<G)E9"==*2D@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&)A8VME;F1;)W!R969E<G)E9"==
M(&%S("1B86-K96YD*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1B86-K
M96YD(#T]("1?4T525D526R=315)615)?3D%-12==('Q\"B`@("`@("`@("`@
M("`@("`@("`@("`@("1B86-K96YD(#T]("1?4T525D526R=(5%107TA/4U0G
M72D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS96EF("@D8F%C:V5N9%LG<')E9F5R<F5D)UT@/3T@)%]315)6
M15);)U-%4E9%4E].04U%)UT@?'P*("`@("`@("`@("`@("`@("`@("`@("1B
M86-K96YD6R=P<F5F97)R960G72`]/2`D7U-%4E9%4ELG2%144%](3U-4)UTI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&%N9V4@=&AE($AO<F1E+TE-4"]-24U0(&-A8VAE9"!C
M<F5D96YT:6%L<RX@4VAO=6QD(&)E(&-A;&QE9`H@("`@("H@;VYL>2!A9G1E
M<B!A('-U8V-E<W-F=6P@8VAA;F=E(&]F('1H92!P87-S=V]R9"!I;B!T:&4@
M86-T=6%L"B`@("`@*B!B86-K96YD('-T;W)A9V4N(%1H:7,@<F]U=&EN92!I
M<R!T:&4@<V%M92!F;W(@86QL(&)A8VME;F1S(&%N9`H@("`@("H@<VAO=6QD
M(&YO="!B92!I;7!L96UE;G1E9"!I;B!T:&4@8F%C:V5N9"!C;&%S<V5S+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("`@("`@5&AE
M('5S97)N86UE('=E)W)E(&-H86YG:6YG+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;VQD<&%S<W=O<F0@("!4:&4@;VQD('5S97(@<&%S<W=O<F0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N97=?<&%S<W=O<F0@(%1H92!N97<@=7-E<B!P
M87-S=V]R9"!T;R!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T0W)E
M9&5N=&EA;',H)&]L9%]P87-S=V]R9"P@)&YE=U]P87-S=V]R9"D*("`@('L*
M("`@("`@("!I9B`H075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G*2`]
M/2`D;VQD7W!A<W-W;W)D*2!["B`@("`@("`@("`@($%U=&@Z.G-E=$-R961E
M;G1I86PH)W!A<W-W;W)D)RP@)&YE=U]P87-S=V]R9"D["B`@("`@("`@("`@
M(&EF("A!=71H.CIG9710<F]V:61E<B@I(#T]("=I;7`G*2!["B`@("`@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=P87-S)UT@/2!396-R970Z.G=R
M:71E*%-E8W)E=#HZ9V5T2V5Y*"=I;7`G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U]P
M87-S=V]R9"D["B`@("`@("`@("`@('T@96QS96EF("A!=71H.CIG9710<F]V
M:61E<B@I(#T]("=M:6UP)RD@>PH@("`@("`@("`@("`@("`@)%]315-324].
M6R=M:6UP)UU;)W!A<W,G72`](%-E8W)E=#HZ=W)I=&4H4V5C<F5T.CIG971+
M97DH)VUI;7`G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N97=?<&%S<W=O<F0I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+VQI8B]B87-E+G!H<```````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S$Q-P`Q,#0Q-S,V,C<T,P`P,C`Q,30`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%!A<W-W9"!B87-E(&EN8VQU<VEO;B!F:6QE+@H@*@H@*B!4:&ES
M(&9I;&4@8G)I;F=S(&EN(&%L;"!O9B!T:&4@9&5P96YD96YC:65S('1H870@
M979E<GD@4$%34U=$('-C<FEP="!W:6QL"B`J(&YE960L(&%N9"!S971S('5P
M(&]B:F5C=',@=&AA="!A;&P@<V-R:7!T<R!U<V4N"B`J"B`J("1(;W)D93H@
M<&%S<W=D+VQI8B]B87-E+G!H<"QV(#$N,S,@,C`P-2\P."\R,R`Q,3HQ-3HP
M-"!J86X@17AP("0*("H@"B`J($-O<'ER:6=H="`R,#`R+3(P,#4@17)I8R!*
M;VX@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE
M9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI
M8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H;W(@($5R:6,@4F]S=&5T=&5R
M(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^"B`J($!P86-K
M86=E(%!A<W-W9`H@*B\*"B\O($-H96-K(&9O<B!A('!R:6]R(&1E9FEN:71I
M;VX@;V8@2$]21$5?0D%312`H<&5R:&%P<R!B>2!A;@HO+R!A=71O7W!R97!E
M;F1?9FEL92!D969I;FET:6]N(&9O<B!S:71E(&-U<W1O;6EZ871I;VXI+@II
M9B`H(61E9FEN960H)TA/4D1%7T)!4T4G*2D@>PH@("`@0&1E9FEN92@G2$]2
M1$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PI]"@HO
M+R!,;V%D('1H92!(;W)D92!&<F%M97=O<FL@8V]R92P@86YD('-E="!U<"!I
M;F-L=7-I;VX@<&%T:',N"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8V]R92YP:'`G.PH*+R\@4F5G:7-T<GDN"B1R96=I<W1R>2`]("9296=I
M<W1R>3HZ<VEN9VQE=&]N*"D["FEF("AI<U]A*"@D<'5S:&5D(#T@)')E9VES
M=')Y+3YP=7-H07!P*"=P87-S=V0G+"`A9&5F:6YE9"@G05542%](04Y$3$52
M)RDI*2P@)U!%05)?17)R;W(G*2D@>PH@("`@:68@*"1P=7-H960M/F=E=$-O
M9&4H*2`]/2`G<&5R;6ES<VEO;E]D96YI960G*2!["B`@("`@("`@2&]R9&4Z
M.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D[(`H@("`@?0H@("`@
M2&]R9&4Z.F9A=&%L*"1P=7-H960L(%]?1DE,15]?+"!?7TQ)3D5?7RP@9F%L
M<V4I.PI]"B1C;VYF(#T@)B1'3$]"04Q36R=C;VYF)UT["D!D969I;F4H)U!!
M4U-71%]414U03$%415,G+"`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RDI
M.PH*+R\@3F]T:69I8V%T:6]N('-Y<W1E;2X*)&YO=&EF:6-A=&EO;B`]("9.
M;W1I9FEC871I;VXZ.G-I;F=L971O;B@I.PHD;F]T:69I8V%T:6]N+3YA='1A
M8V@H)W-T871U<R<I.PH*+R\@1FEN9"!T:&4@8F%S92!F:6QE('!A=&@@;V8@
M4&%S<W=D"D!D969I;F4H)U!!4U-71%]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN)RD["@HO+R!087-S=V0@8F%S92!L:6)R87)Y+@IR97%U:7)E
M7V]N8V4@4$%34U=$7T)!4T4@+B`G+VQI8B]087-S=V0N<&AP)SL*"B\O($AO
M<F1E(&QI8G)A<FEE<RX*<F5Q=6ER95]O;F-E("=(;W)D92](96QP+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O4V5C<F5T+G!H<"<["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A
M<W-W9"]D;V-S+P``````````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`,#$V-C4T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&%S<W=D+V1O8W,O3$E#14Y310``````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#(T-P`Q,#0Q-S,V,C<T
M,P`P,3<V-C4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````5F5R<VEO;B`Q+C`*"D-O<'ER:6=H="`H8RD@,C`P,BTR,#`U(%1H
M92!(;W)D92!0<F]J96-T+B!!;&P@<FEG:'1S(')E<V5R=F5D+@H*4F5D:7-T
M<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@
M=VET:"!O<B!W:71H;W5T"FUO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P
M<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R!A<F4*;65T
M.@H*,2X@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T
M86EN('1H92!A8F]V92!C;W!Y<FEG:'0*;F]T:6-E+"!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H*,BX@
M4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E
M('1H92!A8F]V92!C;W!Y<FEG:'0*;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H90ID
M;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@
M=VET:"!T:&4@9&ES=')I8G5T:6]N+@H*,RX@5&AE(&5N9"UU<V5R(&1O8W5M
M96YT871I;VX@:6YC;'5D960@=VET:"!T:&4@<F5D:7-T<FEB=71I;VXL(&EF
M"F%N>2P@;75S="!I;F-L=61E('1H92!F;VQL;W=I;F<@86-K;F]W;&5D9VUE
M;G0Z"@H@("`B5&AI<R!P<F]D=6-T(&EN8VQU9&5S('-O9G1W87)E(&1E=F5L
M;W!E9"!B>2!T:&4@2&]R9&4@4')O:F5C=`H@("`@*&AT='`Z+R]W=W<N:&]R
M9&4N;W)G+RDN(@H*06QT97)N871E;'DL('1H:7,@86-K;F]W;&5D9VUE;G0@
M;6%Y(&%P<&5A<B!I;B!T:&4@<V]F='=A<F4@:71S96QF+"!I9@IA;F0@=VAE
M<F5V97(@<W5C:"!T:&ER9"UP87)T>2!A8VMN;W=L961G;65N=',@;F]R;6%L
M;'D@87!P96%R+@H*-"X@5&AE(&YA;65S(")(;W)D92(L(")4:&4@2&]R9&4@
M4')O:F5C="(L(&%N9"`B4&%S<W=D(B!M=7-T(&YO="!B90IU<V5D('1O(&5N
M9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S
M;V9T=V%R92!W:71H;W5T"G!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX@1F]R
M('=R:71T96X@<&5R;6ES<VEO;BP@<&QE87-E(&-O;G1A8W0*8V]R94!H;W)D
M92YO<F<N"@HU+B!0<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R
M92!M87D@;F]T(&)E(&-A;&QE9"`B2&]R9&4B(&]R"B)087-S=V0B+"!N;W(@
M;6%Y(")(;W)D92(@;W(@(E!A<W-W9"(@87!P96%R(&EN('1H96ER(&YA;64L
M('=I=&AO=70*<')I;W(@=W)I='1E;B!P97)M:7-S:6]N(&]F('1H92!(;W)D
M92!0<F]J96-T+@H*5$A)4R!33T945T%212!)4R!04D]6241%1"`B05,@25,B
M($%.1"!!3ED@15A04D534T5$($]2($E-4$Q)140*5T%24D%.5$E%4RP@24Y#
M3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!
M3E1)15,@3T8*34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!
M4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X*24X@3D\@159%3E0@
M4TA!3$P@5$A%($A/4D1%(%!23TI%0U0@3U(@2513($-/3E1224)55$]24R!"
M12!,24%"3$4@1D]2"D%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,
M+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P*1$%-04=%
M4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4
M($]&(%-50E-425155$4@1T]/1%,*3U(@4T525DE#15,[($Q/4U,@3T8@55-%
M+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M"DA/5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E4
M62P@5TA%5$A%4B!)3B!#3TY44D%#5"P*4U1224-4($Q)04))3$E462P@3U(@
M5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE3
M24Y'"DE.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%2
M12P@159%3B!)1B!!1%9)4T5$($]&(%1(10I03U-324))3$E462!/1B!354-(
M($1!34%'12X*"E1H:7,@<V]F='=A<F4@8V]N<VES=',@;V8@=F]L=6YT87)Y
M(&-O;G1R:6)U=&EO;G,@;6%D92!B>2!M86YY"FEN9&EV:61U86QS(&]N(&)E
M:&%L9B!O9B!T:&4@2&]R9&4@4')O:F5C="X@1F]R(&UO<F4@:6YF;W)M871I
M;VX@;VX*=&AE($AO<F1E(%!R;VIE8W0L('!L96%S92!S964@/&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+SXN"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+V1O8W,O4D5!1$U%
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#,T
M,@`Q,#0Q-S,V,C<T,P`P,3<U,S0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````5VAA="!I<R!087-S=V0_"CT]/3T]/3T]/3T]
M/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`U+S`X+S(S(#$P.C`Y
M.C4V("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XU("0*.D-O;G1A
M8W0Z("`@("`@('-O<FM`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ
M($-O;G1E;G1S"BXN('-E8W1I;VXM;G5M8F5R:6YG.CH*"E!A<W-W9"!I<R!T
M:&4@2&]R9&4@<&%S<W=O<F0@8VAA;F=I;F<@87!P;&EC871I;VXN("!2:6=H
M="!N;W<L(%!A<W-W9"!P<F]V:61E<PIF86ER;'D@8V]M<&QE=&4@<W5P<&]R
M="!F;W(@8VAA;F=I;F<@<&%S<W=O<F1S('9I82!0;W!P87-S9"P@3$1!4"P@
M56YI>"!E>'!E8W0*<V-R:7!T<RP@=&AE(%5N:7@@<VUB<&%S<W=D(&-O;6UA
M;F0@9F]R(%--0B]#2493('!A<W-W;W)D<RP@2V]L86(L($%$4TDL(%!I;F4L
M"E-E<G8M52!&5%`L(%9-86EL36=R+"!V<&]P;6%I;"P@86YD(%-13"!P87-S
M=V]R9',N"@I4:&ES('-O9G1W87)E(&ES($]322!#97)T:69I960@3W!E;B!3
M;W5R8V4@4V]F='=A<F4N("!/4TD@0V5R=&EF:65D(&ES(&$*8V5R=&EF:6-A
M=&EO;B!M87)K(&]F('1H92!@3W!E;B!3;W5R8V4@26YI=&EA=&EV96!?+@H*
M+BX@7V!/<&5N(%-O=7)C92!);FET:6%T:79E8#H@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R\*"@I/8G1A:6YI;F<@4&%S<W=D"BTM+2TM+2TM+2TM+2TM
M+2TM+0H*1G5R=&AE<B!I;F9O<FUA=&EO;B!O;B!087-S=V0@86YD('1H92!L
M871E<W0@=F5R<VEO;B!C86X@8F4@;V)T86EN960@870*"B`@:'1T<#HO+W=W
M=RYH;W)D92YO<F<O<&%S<W=D+PH*"D1O8W5M96YT871I;VX*+2TM+2TM+2TM
M+2TM+0H*5&AE(&9O;&QO=VEN9R!D;V-U;65N=&%T:6]N(&ES(&%V86EL86)L
M92!I;B!T:&4@4&%S<W=D(&1I<W1R:6)U=&EO;CH*"CI214%$345?.B`@("`@
M("`@("`@(%1H:7,@9FEL90HZ3$E#14Y315\Z("`@("`@("`@("!#;W!Y<FEG
M:'0@86YD(&QI8V5N<V4@:6YF;W)M871I;VX*.F!D;V-S+T-(04Y'15-@7SH@
M("`@0VAA;F=E<R!B>2!R96QE87-E"CI@9&]C<R]#4D5$25138%\Z("`@(%!R
M;VIE8W0@9&5V96QO<&5R<PHZ8&1O8W,O24Y35$%,3&!?.B`@("!);G-T86QL
M871I;VX@:6YS=')U8W1I;VYS(&%N9"!N;W1E<PHZ8&1O8W,O5$]$3V!?.B`@
M("`@("!$979E;&]P;65N="!43T1/(&QI<W0*"@I);G-T86QL871I;VX*+2TM
M+2TM+2TM+2TM"@I);G-T<G5C=&EO;G,@9F]R(&EN<W1A;&QI;F<@4&%S<W=D
M(&-A;B!B92!F;W5N9"!I;B!T:&4@9FEL92!)3E-404Q,7R!I;B!T:&4*8&!D
M;V-S+V!@(&1I<F5C=&]R>2!O9B!T:&4@4&%S<W=D(&1I<W1R:6)U=&EO;BX*
M"@I!<W-I<W1A;F-E"BTM+2TM+2TM+2T*"DEF('EO=2!E;F-O=6YT97(@<')O
M8FQE;7,@=VET:"!087-S=V0L(&AE;'`@:7,@879A:6QA8FQE(2`*"E1H92!(
M;W)D92!&<F5Q=65N=&QY($%S:V5D(%%U97-T:6]N<R!,:7-T("A&05$I+"!A
M=F%I;&%B;&4@;VX@=&AE(%=E8B!A=`H@"B`@:'1T<#HO+W=W=RYH;W)D92YO
M<F<O9F%Q+PH*5&AE($AO<F1E(%!R;VIE8W0@<G5N<R!A(&YU;6)E<B!O9B!M
M86EL:6YG(&QI<W1S+"!F;W(@:6YD:79I9'5A;"!A<'!L:6-A=&EO;G,*86YD
M(&9O<B!I<W-U97,@<F5L871I;F<@=&\@=&AE('!R;VIE8W0@87,@82!W:&]L
M92X@($EN9F]R;6%T:6]N+"!A<F-H:79E<RP@86YD"G-U8G-C<FEP=&EO;B!I
M;F9O<FUA=&EO;B!C86X@8F4@9F]U;F0@870*"B`@:'1T<#HO+W=W=RYH;W)D
M92YO<F<O;6%I;"\*"DQA<W1L>2P@2&]R9&4@9&5V96QO<&5R<RP@8V]N=')I
M8G5T;W)S(&%N9"!U<V5R<R!A;'-O(&UA:V4@;V-C87-I;VYA;`IA<'!E87)A
M;F-E<R!O;B!)4D,L(&]N('1H92!C:&%N;F5L("-H;W)D92!O;B!T:&4@9G)E
M96YO9&4@3F5T=V]R:PHH:7)C+F9R965N;V1E+FYE="DN"@H*3&EC96YS:6YG
M"BTM+2TM+2TM+0H*1F]R(&QI8V5N<VEN9R!A;F0@8V]P>7)I9VAT(&EN9F]R
M;6%T:6]N+"!P;&5A<V4@<V5E('1H92!F:6QE($Q)0T5.4T5?(&EN('1H90I0
M87-S=V0@9&ES=')I8G5T:6]N+@H*5&AA;FMS+`H*5&AE(%-O<FL@=&5A;0H*
M"BXN(%]214%$344Z(#]F/5)%041-12YH=&UL"BXN(%],24-%3E-%.B!H='1P
M.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP"BXN(%]D;V-S+T-(
M04Y'15,Z(#]F/4-(04Y'15,N:'1M;`HN+B!?9&]C<R]#4D5$2513.B`_9CU#
M4D5$2513+FAT;6P*+BX@7TE.4U1!3$PZ"BXN(%]D;V-S+TE.4U1!3$PZ(#]F
M/4E.4U1!3$PN:'1M;`HN+B!?9&]C<R]43T1/.B`_9CU43T1/+FAT;6P*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D
M+V1O8W,O0TA!3D=%4P``````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q-#$T,P`Q,#0Q-S,V,C<T,P`P,3<V-#<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2TM+2TM+2T*=C,N,"UC
M=G,*+2TM+2TM+2T*"EMJ86Y=($%D9"!C;VYF:6=U<F%T:6]N(&]P=&EO;B!T
M;R!S=VET8V@@8F5T=V5E;B!U<VEN9R!U<V5R(&YA;65S('=I=&@@86YD"B`@
M("`@('=I=&AO=70@<F5A;&US+@I;:F%N72!!9&0@4VQO=F%K('1R86YS;&%T
M:6]N("A)=F%N($YO<FES(#QV:7A`=F%Z:V$N<VL^*2X*"@HM+2TM+2TM+0IV
M,RXP+5)#,0HM+2TM+2TM+0H*6VIA;ET@17AT96YD('1H92!E>'!E8W0@<V-R
M:7!T('1O(&%L;&]W('-E='5P<R!W:71H('!A<W-W9"!A<R!T:&4@;&]G:6X@
M<VAE;&P*("`@("`@*%)E<75E<W0@(S(U-3`L(&QM86UA;F5`9&5B:6%N+F]R
M9RDN"EMJ86Y=($1O;B=T(&)I;F0@=&\@3$1!4"!A;F]N>6UO=7-L>2!I9B!B
M:6YD:6YG('=I=&@@=7-E<F1N(&9A:6QS("A"=6<@(S(U,#(I+@I;8VIH72!&
M:7@@=7!D871I;F<@<VAA9&]W;&%S=&-H86YG92!A='1R:6)U=&4@:6X@;&1A
M<"!D<FEV97(@*%)O96P@1VQO=61E;6%N<PH@("`@("`\<F]E;$!G;&]U9&5M
M86YS+FEN9F\^*2X*6VIA;ET@17AT96YD('1H92!S;6)L9&%P(&1R:79E<B!F
M<F]M('1H92!L9&%P(&1R:79E<B!T;R!S=7!P;W)T(&%L;"!P87)A;65T97)S
M"B`@("`@(&]F('1H92!L9&%P(&1R:79E<B`H4F5Q=65S="`C,C0Y.2DN"@H*
M+2TM+2TM+2TM"G8S+C`M0D5400HM+2TM+2TM+2T*"EMC:FA=(%5S92!#<GEP
M=%]#2$%0('1O(&=E;F5R871E('-M8FQD87`@<&%S<W=O<F1S("A"=6<@(S$R
M,C,I+@I;<W1B72!!9&0@2V]L86(@9')I=F5R+@I;8VIH72!!;&QO=R!U<VEN
M9R!A9&UI;B!C<F5D96YT:6%L<R!I;B!T:&4@3$1!4"!D<FEV97(@*$)U9R`C
M,30P.2DN"EMC:FA=(%5S92!B:6YD('9A<FEA8FQE<R!I;B!344P@9')I=F5R
M<R`H<V5L<VMY0&-O;'5M8FEA+F5D=2P@0G5G(",Q-S$X*2X*6V-J:%T@06QL
M;W<@=&AE(&QI<W0@;V8@<F5F=7-E9"!U<V5R;F%M97,@=&\@8F4@96UP='D@
M*$)U9R`C,34T-"DN"EMC:FA=($EF("1C;VYF6R=U<V5R)UU;)V-H86YG92==
M(&ES(&9A;'-E+"!D;VXG="!T<G5S="!F;W)M(&EN<'5T(&9O<@H@("`@("!T
M:&4@=7-E<FED+@I;:F%N72!!9&0@0V%T86QA;B!T<F%N<VQA=&EO;B`H2F]A
M;B!*;W)B82!#86QS:6YA(#QJ;V%N+FIO<F)A0')U<V,N;F5T/BDN"EMC:FA=
M($%D9"!!1%-)(&%N9"!04U!!4U-71"!W:6YD;W=S('!A<W-W;W)D(&1R:79E
M<G,@*$Q230H@("`@("`\;')M0&EO;FQI;F4N8V]M+F)R/BDN"EMJ86Y=($%D
M9"!097)S:6%N("A797-T97)N*2!T<F%N<VQA=&EO;B`H5F%H:60@1VAA9F%R
M<&]U<@H@("`@("`\=F%H:61`9VAA9F%R<&]U<BYC;VT^*2X*6VIA;ET@061D
M('-H861O=TQA<W1#:&%N9V4@86YD('-H861O=TUI;B!C;VYF:6=U<F%T:6]N
M(&ET96US('1O($Q$05`@9')I=F5R"B`@("`@("A2;V5L($=L;W5D96UA;G,@
M/')O96Q`9VQO=61E;6%N<RYI;F9O/BDN"EMC:FA=($%D9"!P<F]C7V]P96XH
M*2!D<FEV97(@*%-A;75E;"!.:6-O;&%R>2`\<V%M0&YI8V]L87)Y+F]R9SXI
M+@I;8VIH72!!9&0@86X@4TU"($Q$05`@9')I=F5R("A3:&%N92!";W5L=&5R
M(#QS8F]U;'1E<D!A<FEA<V]L=71I;VYS+F-O;3XI+@I;8VIH72!!9&0@4U-,
M('-U<'!O<G0@=&\@=&AE($Q$05`@9')I=F5R("A,4DT@/&QR;4!I;VYL:6YE
M+F-O;2YB<CXI+@I;;6%X72!!9&0@;6EN4WEM8F]L<R!A;F0@;6EN0VQA<W-E
M<R!P87-S=V]R9"!P;VQI8VEE<RX@(%-E92!C;VUM96YT<R!I;@H@("`@("!C
M;VYF:6<O8F%C:V5N9',N<&AP+F1I<W0@9F]R(&UO<F4@:6YF;W)M871I;VXN
M"EMM87A=($%D9"!O<'1I;VYA;"`G<F5Q=6ER960G('!A<F%M971E<G,@=&\@
M8V]M<&]S:71E(&1R:79E<B=S('-U8F1R:79E<@H@("`@("!C;VYF:6=U<F%T
M:6]N<RX*6VUA>%T@061D(&]P=&EO;F%L('!A<F%M971E<B`G;F]?<F5S970G
M('1O('1H92!B86-K96YD(&-O;F9I9W,@=VAI8V@@<')E=F5N=',*("`@("`@
M<F5S971I;F<@=&AE(&%U=&AE;G1I8V%T960@=7-E<B=S(&-R961E;G1I86QS
M(&]N('!A<W-W;W)D(&-H86YG97,N"EMM87A=(%!R;W!E<FQY(')E<V5T(&%U
M=&AE;G1I8V%T960@=7-E<B=S(&-R961E;G1I86QS+@I;8VIH72!5<V4@<&%S
M<W=O<F0@96YC<GEP=&EO;B!T:&%T)W,@;F]W(&EM<&QE;65N=&5D(&EN('1H
M92!!=71H.CH@<&%C:V%G92X*6VUA>%T@061D('!I;F4@9')I=F5R('=H:6-H
M(&-H86YG97,@82!P:6YE+65N8V]D960@9FEL92!U<VEN9R!&5%`N"EMM87A=
M($9I>"!P87-S=V]R9"!C:&5C:VEN9R!W:&5N(&5N8W)Y<'1I;VX@<F5Q=6ER
M97,@82!R86YD;VT@<V%L="X*6VUA>%T@061D(&-O;7!O<VET92!D<FEV97(@
M=VAI8V@@=VEL;"!R97!L86-E(&%L;"!T:&4@9W)O=7!S('-T=69F+@I;;6%X
M72!!9&0@<W5P<&]R="!F;W(@8F%C:V5N9"!G<F]U<',@=&\@86QL;W<@<WEN
M8VEN9R!O9B!M=6QT:7!L92!B86-K96YD<RX*6VUA>%T@061D('%U97)Y7VQO
M;VMU<"!A;F0@<75E<GE?;6]D:69Y('!A<F%M971E<G,@=&\@=&AE('-Q;"!D
M<FEV97(N"EME:G)=($%D9"!T;',@<W5P<&]R="!F;W(@;&1A<"!D<FEV97(N
M"EME:G)=($9I>"!E<G)O<B!R97!O<G1I;F<@:6X@<&]P<&%S<V0@9')I=F5R
M+@I;96IR72!!9&0@8FEN9&1N(&AO;VL@<W5B;6ET=&5D(&)Y($%M:71H(%9A
M<F=H97-E(#QA;6ET:$!X86QA;BYC;VT^+@I;96IR72!M86ME('-U<F4@;VQD
M<&%S<W=O<F0@/3T@:&]R9&5?;&]G:6Y?<&%S<W=O<F0@8F5F;W)E(&-H86YG
M:6YG(&AO<F1E"B`@("`@(&-A8VAE9"!P87-S=V]R9"X*6V5J<ET@1FEX(&UD
M-2`H;60U+6AE>"!A;F0@;60U+6)A<V4V-"D@96YC<GEP=&EO;B!F;W(@;&1A
M<"]S<6P@*$%M:71H(%9A<F=H97-E"B`@("`@(#QA;6ET:$!X86QA;BYC;VT^
M*2X*6VUC72`@36]V92!T96UP;&%T97,@=&\@:&]R9&4@<W1Y;&4@9&ER96-T
M;W)Y(&QA>6]U="P@9V5T3F%M92@I("T^(&=E=%!A<F%M*"DN"EME:G)=($EM
M<&QE;65N=&5D(&YE=R!#5E,@2$5!1"!T:&5M97,N"EME:G)=(%5P9&%T960@
M=&\@;F5W($-64R!(14%$(&YO=&EF:6-A=&EO;B!S>7-T96TN"@H*+2TM+2TM
M"G8R+C(N,@HM+2TM+2T*"EMJ86Y=($-L;W-E(%A34R!W:&5N('-E='1I;F<@
M=&AE('!A<F5N="!F<F%M92=S('!A9V4@=&ET;&4@8GD@:F%V87-C<FEP="`H
M8VIH*2X*6V5J<ET@0V]N9FEG=7)A=&EO;B!I=&5M(&9O<B!S:&]W:6YG+V-H
M86YG:6YG('5S97)N86UE(&EN('1H92!F;W)M+@I;:F%N72!!;&QO=R!T;R!S
M970@=&AE('!R;W1O8V]L('9E<G-I;VX@:6X@=&AE($Q$05`@9')I=F5R("AB
M96Y`86QK86QO:60N;F5T*2X*6V-J:%T@061D(&-R>7!T+6)L;W=F:7-H(&%N
M9"!C<GEP="UM9#4@96YC<GEP=&EO;B!T>7!E<RX@06QS;R!A9&0@8W)Y<'0M
M9&5S"B`@("`@(&9O<B!C;VUP;&5T:6]N('=H:6-H(&ES(&IU<W0@86X@86QI
M87,@9F]R(&-R>7!T("AM87@I+@I;:F%N72!!9&0@17-T;VYI86X@=')A;G-L
M871I;VX@*%1O;VUA<R!!87,@/'1O;VUA<RYA87-`<F%A9"YT87)T=2YE93XI
M+@H*"BTM+2TM+0IV,BXR+C$*+2TM+2TM"EMJ86Y=($)U9R`C-#`Z($9I>"!S
M;6)P87-S=V0@9')I=F5R('=I=&@@;F]N+6)A<V@@<VAE;&QS("A#:')I<W1O
M<&AE<B!(=7EL97(*("`@("`@/&-H<FES0&AU>6QE<BYN970^*2X*6VIA;ET@
M061D(%-I;7!L:69I960@0VAI;F5S92!T<F%N<VQA=&EO;B`H6FAA;F<@0F\@
M/&)O;WIH86YG0'-D8BYA8RYC;CXI+@H*"BTM+2TM+2TM+2T*=C(N,BXQ+5)#
M,0HM+2TM+2TM+2TM"EMJ86Y=($%D9"!);F1O;F5S:6%N(&QA;F=U86=E("A3
M;&%M:6X@/'-L86UI;D!U;F5J+F%C+FED/BDN"EMJ86Y=($%D9"!'86QI8VEA
M;B!T<F%N<VQA=&EO;B`H4F%F865L(%9A<F5L82!0970@/'-R<F%F84!U<V,N
M97,^+"!'=6EL;&5R;6\*("`@("`@365N9&5Z(#QG=6EL;&5`=7-C+F5S/BDN
M"EMJ86Y=($%D9"!$86YI<V@@=')A;G-L871I;VX@*$%N9&5R<R!"<G5U;B!/
M;'-E;B`\86YD97)S0&)R=75N+6]L<V5N+FYE=#XI+@I;:F%N72!!9&0@07)A
M8FEC("A3>7)I82D@=')A;G-L871I;VX@*%!L871I;G5M($1E=F5L;W!M96YT
M(%1E86T*("`@("`@/&1E=G1E86U`<&QA=&EN=6TM<WDN;F5T/BDN"EMJ86Y=
M($%D9"!(=6YG87)I86X@=')A;G-L871I;VX@*%-Z86)O($=Y=6QA(#QG>75F
M:4!S>G1A:VDN:'4^*2X*6VIA;ET@061D(%)O;6%N:6%N('1R86YS;&%T:6]N
M("A%=6=E;B!(;V%N8V$@/&5U9V5N:$!U<F)A;BUG<F%F>"YR;SXL"B`@("`@
M($UA<FEU<R!$<F%G=6QE<V-U(#QM87)I=7-D0'5R8F%N+6=R869X+G)O/BDN
M"EMJ86Y=($%D9"!,:71H=6%N:6%N('1R86YS;&%T:6]N("A6:6QI=7,@4W5M
M<VMA<R`\=FEL:75S0&QN:RYL=#XI+@I;96IR72!&:7@@0D,@8G)E86MS(&EN
M('9P;W!M86EL(&%N9"!S<6P@9')I=F5R<RX*"@HM+2TM"G8R+C(*+2TM+0H*
M6V5J<ET@06QL;W<@8F,@9F]R('!H<"!V97)S:6]N<R!T:&%T(&1O;B=T(&AA
M=F4@=&AE(&-T>7!E(&5X=&5N<VEO;BX*"@HM+2TM+2TM+0IV,BXR+5)#,@HM
M+2TM+2TM+0H*6V5J<ET@1FEX(&UI<W-I;F<@<&%T:"!F;W(@97AP96-T(&)I
M;F%R>2X*6V5J<ET@061D(&UI<W-I;F<@<V-R:7!T<R\@9&ER96-T;W)Y(&%N
M9"!M:7-S:6YG(&5X<&5C="!S8W)I<'0N"EME:G)=($9I>"!E<G)O<B!R97!O
M<G1I;F<@:6X@97AP96-T(&1R:79E<B`H:BYH=6EN:6YK0'=A;F%D;V\N;FPI
M+@I;96IR72!296UO=F4@;VQD(')E86QM(&-O9&4@=&AA="!W87,@<')E=FEO
M=7-L>2!M:7-S960N"EME:G)=(%!O<G0@<V5R=G5F='`@9')I=F5R('1O(&YE
M=R!B86-K96YD<RYC;VYF(&9O<FUA="X*6V5J<ET@4F5T=7)N(&%C='5A;"!E
M<G)O<B!M97-S86=E('1E>'0@:6X@<&]P<&%S<V0@9')I=F5R("AS=6)M:71T
M960@8GD*("`@("`@3&5E;F$@2&5I;F\@/$QE96YA+DAE:6YO0'5T82YF:3XI
M+@I;96IR72!#:&%N9V4@:7-?82@J+"`G4$5!4E]%<G)O<B<I(&-A;&QS('1O
M(%!%05(Z.FES17)R;W(H*2!C86QL<R!F;W(@<&AP(&)C+@H*"BTM+2TM+2TM
M"G8R+C(M4D,Q"BTM+2TM+2TM"@I;96IR72!!9&0@=G!O<&UA:6P@9')I=F5R
M("A!;G1O;B!.96MH;W)O<VAI:V@@/&%N=&]N0'9A;'5E:&]S="YR=3XI+@I;
M;6%C72!!9&0@=FUA:6QM9W(@9')I=F5R("A-87)C;R!+86ES97(@/&)A=&5`
M<&AP+FYE=#XI+@I;96IR72!!9&0@97AP96-T('-C<FEP="`H1V%U9&5N>B!3
M=&5I;FQI;BDN"EME:G)=($-H86YG92!L9&%P(&-O9&4@=&\@9&\@<V5L9BUP
M87-S=V]R9"!C:&%N9V5S+"!A9&0@<&AP9&]C+@I;96IR72!5<&1A=&4@;&1A
M<"!D<FEV97(@*%1J965R9"!V86X@9&5R(%IE92DN"EME:G)=(%)E<V5T($AO
M<F1E+TE-4"!C86-H960@8W)E9&5N=&EA;',@=VAE;B!C:&%N9VEN9R!P87-S
M=V]R9"X*6V5J<ET@061D('5S97)N86UE(&AO;VMS("AM86,I+@I;96IR72!2
M97=R:71E(&1R:79E<B!S>7-T96TL(&%D9"!B86-K96YD<RYC;VYF('-Y<W1E
M;2`H;6,I+@I;:F%N72!!9&0@271A;&EA;B!T<F%N<VQA=&EO;B`H1FEC:&5R
M82!':6%N<FEC;R`\9VEA;G)I8V\N9FEC:&5R84!I=&5S>7,N:70^*2X*6V-J
M:%T@0VQO<V4@<V5V97)A;"!S;6%L;"!84U,@=G5L;F5R86)I;&ET:65S("A-
M:71J82!+;VQS96L*("`@("`@/&UI=&IA+FMO;'-E:T!A8W)O<RYS:3XI+@H*
M"BTM+2T*=C(N,0HM+2TM"@I;96IR72!!9&0@<V5R=G5F='`@:6YT97)F86-E
M+@I;96IR72!!9&0@97AI;2!S<6P@8F%C:V5N9"X*6V5J<ET@061D('-M8G!A
M<W-W9"!S=7!P;W)T+@I;96IR72!-;W9E('1O(&1R:79E<B!D<FEV96X@<WES
M=&5M+@I;;6-=("!!9&0@:F%V87-C<FEP="!C:&5C:W,@9F]R(&9O<FT@:6YP
M=70N"EMJ86Y=($%D9"!"=6QG87)I86X@=')A;G-L871I;VX@*$UI<F]S;&%V
M(%!E;F1E=B`\<&5N9&5V0&AO=&UA:6PN8V]M/BDN"@H*+2TM+0IV,BXP"BTM
M+2T*"EME:G)=($%D9&5D(&]P=&EO;F%L(&-H96-K<R!F;W(@<&%S<W=O<F0@
M;&5N9W1H<R!A;F0@<W1R96YG=&@@=&5S=&EN9RX*6V5J<ET@4F5M;W9E(&-H
M96-K(&9O<B!P<F5F<RYP:'`@:6X@;F]T8V]N9FEG=7)E9"YI;F,N"EME:G)=
M($-H86YG92!F<F]M('-H;W)T+71A9R`\/ST@=&\@;&]N9R!F;W)M870@/#]P
M:'`@96-H;RX*6V5J<ET@1FEX('-P86-I;F<@86YD(&QO;VL@;V8@4W5B;6ET
M(&)U='1O;BX*6V5J<ET@57!D871E(&-O;G1A8W0@:6YF;R!I;B!D;V-S+TE.
M4U1!3$P@9F]R(&UA:6QI;F<@;&ES="X*6V5J<ET@061D960@3F]R=V5G:6%N
M("AN;E].3RD@=')A;G-L871I;VXN"EME:G)=($%D9&5D(%-W961I<V@@*'-V
M7U-%*2!T<F%N<VQA=&EO;BX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!A<W-W9"]D;V-S+T-2141)5%,`````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<S,S,`,3`T,3<S-C(W-#,`,#$W-C<W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*(%!A<W-W9"!$979E;&]P;65N="!4
M96%M"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@
M("`D1&%T93H@,C`P-2\Q,"\P.2`Q-3HQ-SHU."`D"CI2979I<VEO;CH@("`@
M("`D4F5V:7-I;VXZ(#$N-#`@)`HZ0V]N=&%C=#H@("`@("`@<V]R:T!L:7-T
M<RYH;W)D92YO<F<*"@I#;W)E($1E=F5L;W!E<G,*/3T]/3T]/3T]/3T]/3T]
M"@HM($5R:6,@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T
M97AA<RYE9'4^"BT@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*"@I$
M<FEV97(@1&5V96QO<&5R<PH]/3T]/3T]/3T]/3T]/3T]/0H*+2!!;G1O;B!.
M96MH;W)O<VAI:V@@/&%N=&]N0'9A;'5E:&]S="YR=3X*+2!'875D96YZ(%-T
M96EN;&EN(#QG875D96YZ0'-O>FEO;&]G:64N8V@^"BT@26QY82!+<F5L(#QM
M86EL0&MR96PN;W)G/@HM($QU8V%S(#QS8W)E96Y`8G)A:6YK<F%S:"YC;VT^
M"BT@3'5I>B!2($UA;&AE:7)O<R`H;6%L:&5I<F]S0&=M86EL+F-O;2D*+2!-
M87)C;R!+86ES97(@/&)A=&5`<&AP+FYE=#X*+2!-871T:6%S(%=E8FKV<FX@
M17)I:W-S;VX@/&UA='1I87-`=V5B:F]R;BYO<F<^"BT@36%X($MA;&EK82`\
M;6%X0&AO<F1E+F]R9SX*+2!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@HM(%)E;ND@3'5N9"!*96YS96X@/&QU;F1E;6%N0'1B:V]L
M+F1K/@HM(%-A;75E;"!.:6-O;&%R>2`\<V%M0&YI8V]L87)Y+F]R9SX*+2!3
M:&%N92!";W5L=&5R(#QS8F]U;'1E<D!A<FEA<V]L=71I;VYS+F-O;3X*+2!3
M='5A<G0@0FEN9^L@/'-K8FEN9V5`9VUA:6PN8V]M/@HM(%1J965R9"!V86X@
M9&5R(%IE92`\861M:6Y`>&%R+FYL/@H*"DQO8V%L:7IA=&EO;@H]/3T]/3T]
M/3T]/3T*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I!<F%B
M:6%N("A3>7)I82D@("`@("`@("!0;&%T:6YU;2!$979E;&]P;65N="!496%M
M(#QD979T96%M0'!L871I;G5M+7-Y+FYE=#X*0G)A>FEL:6%N(%!O<G1U9W5E
M<V4@("`@1&%R8VD@06YT;VYI;R!487)T87)I(#QD=&%R=&%R:4!P;W)T;W)I
M;V=R86YD92YC;VTN8G(^"D)U;&=A<FEA;B`@("`@("`@("`@("`@($UI<F]S
M;&%V(%!E;F1E=B`\;6ER;T!C>6)E<G-H861E+G5S/@I#871A;&%N("`@("`@
M("`@("`@("`@("!*;V%N($IO<F)A($-A;'-I;F$@/&IO86XN:F]R8F%`<G5S
M8RYN970^"D-H:6YE<V4@*%1R861I=&EO;F%L*2`@($1A=FED($-H86YG(#QD
M879I9$!T;78N9V]V+G1W/@I#:&EN97-E("A3:6UP;&EF:65D*2`@("!796YZ
M:'5O(%IH86YG(#QW96YZ:'5O0'IH;6%I;"YC;VT^"D-Z96-H("`@("`@("`@
M("`@("`@("`@(%!A=F5L($-H>71I;"`\<&%V96Q`8VAY=&EL+G1K/@I$=71C
M:"`@("`@("`@("`@("`@("`@("!4:F5E<F0@=F%N(&1E<B!:964*("`@("`@
M("`@("`@("`@("`@("`@("`@4F5S86X@4V$M07)D;G5A;2`\:&]R9&5`<V$M
M87)D;G5A;2YN;#X*1&%N:7-H("`@("`@("`@("`@("`@("`@06YD97)S($)R
M=75N($]L<V5N(#QA;F1E<G-`8G)U=6XM;VQS96XN;F5T/@I%<W1O;FEA;B`@
M("`@("`@("`@("`@("!4;V]M87,@06%S(#QT;V]M87,N86%S0&UA:6PN964^
M"D9I;FYI<V@@("`@("`@("`@("`@("`@(%1E<F\@36%T:6YL87-S:2`\=&5R
M;VU`:6MI+F9I/@I&<F5N8V@@("`@("`@("`@("`@("`@("!$86YI96P@2'5H
M87)D96%U>"`\9&%N:65L+FAU:&%R9&5A=7A`=&]O=&%I+F-O;3X*("`@("`@
M("`@("`@("`@("`@("`@("`@0F5N;VET(%-T+4%N9'+I"B`@("`@("`@("`@
M("`@("`@("`@("`@(%!I97)R92!,86-H86YC92`\<&Q`<&EE<G)E;&%C:&%N
M8V4N;F5T/@I'86QI8VEA;B`@("`@("`@("`@("`@("!2869A96P@5F%R96QA
M(#QR869A96PN=F%R96QA0'5S8RYE<SX*("`@("`@("`@("`@("`@("`@("`@
M("`@1W5I;&QE<FUO($UE;F1E>B`\9W5I;&QE0'5S8RYE<SX*1V5R;6%N("`@
M("`@("`@("`@("`@("`@2F5N<R!!(%1K;W1Z(#QJ96YS+G1K;W1Z0&8R:#DN
M9&4^"B`@("`@("`@("`@("`@("`@("`@("`@($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"DAU;F=A<FEA;B`@("`@("`@("`@("`@(%)O8F5R="!3
M>F]K;W9A8W,*("`@("`@("`@("`@("`@("`@("`@("`@1WEU;&$@4WIA8F\@
M/&=Y=69I0'-Z=&%K:2YH=3X*26YD;VYE<VEA;B`@("`@("`@("`@("`@4VQA
M;6EN(#QS;&%M:6Y`=6YE:BYA8RYI9#X*271A;&EA;B`@("`@("`@("`@("`@
M("`@1VEA;G)I8V\@1FEC:&5R82`\9VEA;G)I8V\N9FEC:&5R84!I=&5S>7,N
M:70^"DQI=&AU86YI86X@("`@("`@("`@("`@($1A<FEU<R!-871U;&EA=7-K
M87,@/&1A<FEU<T!L;FLN;'0^"B`@("`@("`@("`@("`@("`@("`@("`@(%9I
M;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT/@I.;W)W96=I86X@3GEN;W)S
M:R`@("`@("!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^"E!E<G-I
M86X@("`@("`@("`@("`@("`@($UE=&%.150@06UI<FMA8FER(#QP97)S:6%N
M+6AO<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*4&]L:7-H("`@("`@("`@("`@
M("`@("`@36%R:75S>B!:>6YE;"`\;6%R:75S>D!S;VQA<FES+7@X-BYO<F<^
M"E!O<G1U9W5E<V4@("`@("`@("`@("`@($IOXV\@0^ES87(@36%R:6=O;F1A
M(#QJ;V%O0'=E8FYO=RYC;VTN8G(^"E)O;6%N:6%N("`@("`@("`@("`@("`@
M($UA<FEU<R!$<F%G=6QE<V-U(#QM87)I=7-D0'5R8F%N+6=R869X+G)O/@H@
M("`@("`@("`@("`@("`@("`@("`@("!%=6=E;B!(;V%N8V$@/&5U9V5N:$!U
M<F)A;BUG<F%F>"YR;SX*4G5S<VEA;B`@("`@("`@("`@("`@("`@26QL>6$@
M0F5L;W8@/&)E;&]V0&EO<"YI<FMP<RYR=3X*4VQO=F%K("`@("`@("`@("`@
M("`@("`@279A;B!.;W)I<R`\=FEX0'9A>FMA+G-K/@I3<&%N:7-H("`@("`@
M("`@("`@("`@("!-86YU96P@4&5R97H@07EA;&$@/&UA>6%L84!U;F5X+F5S
M/@I3=V5D:7-H("`@("`@("`@("`@("`@("!-871T:6%S(%=E8FKV<FX@17)I
M:W-S;VX@/&UA='1I87-`=V5B:F]R;CX*/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"@H*26YA8W1I=F4@1&5V96QO<&5R<PH]/3T]/3T]/3T]
M/3T]/3T]/3T]"@HM($UA=&AI974@0VQA8F%U=`H*"E-P96-I86P@=&AA;FMS
M"CT]/3T]/3T]/3T]/3T]"@HM(%1H86YK<R!T;R!*;VAN(%=E9&]F9BP@=VAO
M(&AE;'!E9"!D96)U9R!A('-E<W-I;VXO;&]G:6X@<')O8FQE;2X*+2!4:&%N
M:W,@=&\@3VQI=F5R(%-C:'5L='IE("A/4TPI(&9O<B!H96QP('=I=&@@8G5G
M(&9I>&5S+"!D;V-U;65N=&%T:6]N"B`@<W5G9V5S=&EO;G,L(&%N9"!M;W)A
M;"!S=7!P;W)T+@HM(%1H86YK<R!T;R!497)O(%1A<&%N:2!-871I;FQA<W-I
M(&9O<B!P;VEN=&EN9R!O=70@;7D@8F%D(&-O9&EN9R!W:&5N($D*("!R=7-H
M960@=&AE(')E86QM(&-H86YG97,@:6YT;R!E9F9E8W0L(&%N9"!E=F5N('!R
M;W9I9&EN9R!T:&4@<V]L=71I;VXA"BT@5&AA;FMS('1O(%1J965R9"!V86X@
M9&5R(%IE92!A;F0@36%T=&EA<R!796)J]G)N($5R:6MS<V]N(&9O<B!A;&P@
M=&AE:7(@:&5L<`H@(&%N9"!P871I96YC92!C;V1I;F<@=&AE($Q$05`@<W5P
M<&]R="X*+2!4:&%N:W,@=&\@06UI=&@@5F%R9VAE<V4@/&%M:71H0'AA;&%N
M+F-O;3X@9F]R('9A<FEO=7,@8V]N=')I8G5T:6]N<PH@(&EN8VQU9&EN9R!T
M:&4@3$1!4"!B:6YD9&X@:&]O:RX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]D;V-S+TE.4U1!3$P`
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C<W,C8`
M,3`T,3<S-C(W-#,`,#$W-S(P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!);G-T
M86QL:6YG(%!A<W-W9"`S+C`*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,
M87-T('5P9&%T93H@("`D1&%T93H@,C`P-2\P."\R-2`P-SHR.#HU,R`D"CI2
M979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N,S$@)`HZ0V]N=&%C=#H@("`@
M("`@<V]R:T!L:7-T<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N
M=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*5&AI<R!D;V-U;65N="!C;VYT
M86EN<R!I;G-T<G5C=&EO;G,@9F]R(&EN<W1A;&QI;F<@=&AE(%!A<W-W9"!0
M87-S=V]R9`I#:&%N9VEN9R!!<'!L:6-A=&EO;BX*"D9O<B!I;F9O<FUA=&EO
M;B!O;B!T:&4@8V%P86)I;&ET:65S(&%N9"!F96%T=7)E<R!O9B!087-S=V0L
M('-E92!T:&4@9FEL90I214%$345?(&EN('1H92!T;W`M;&5V96P@9&ER96-T
M;W)Y(&]F('1H92!087-S=V0@9&ES=')I8G5T:6]N+@H*"D]B=&%I;FEN9R!0
M87-S=V0*/3T]/3T]/3T]/3T]/3T]/3T]"@I087-S=V0@8V%N(&)E(&]B=&%I
M;F5D(&9R;VT@=&AE($AO<F1E('=E8G-I=&4@86YD($944"!S97)V97(L(&%T
M"@H@("!H='1P.B\O=W=W+FAO<F1E+F]R9R]P87-S=V0O"@H@("!F='`Z+R]F
M='`N:&]R9&4N;W)G+W!U8B]P87-S=V0O"@I/<B!U<V4@=&AE(&UI<G)O<B!C
M;&]S97-T('1O('EO=3H*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VUI<G)O
M<G,N<&AP"@I";&5E9&EN9RUE9&=E(&1E=F5L;W!M96YT('9E<G-I;VYS(&]F
M(%!A<W-W9"!A<F4@879A:6QA8FQE('9I82!#5E,[('-E92!T:&4*9FEL92!@
M:&]R9&4O9&]C<R](04-+24Y'8%\@:6X@=&AE($AO<F1E(&1I<W1R:6)U=&EO
M;BP@;W(@=&AE('=E8G-I=&4*:'1T<#HO+W=W=RYH;W)D92YO<F<O<V]U<F-E
M+RP@9F]R(&EN9F]R;6%T:6]N(&]N(&%C8V5S<VEN9R!T:&4@2&]R9&4@0U93
M"G)E<&]S:71O<GDN"@H*4')E<F5Q=6ES:71E<PH]/3T]/3T]/3T]/3T]"@I4
M;R!F=6YC=&EO;B!P<F]P97)L>2P@4&%S<W=D("HJ<F5Q=6ER97,J*B!T:&4@
M9F]L;&]W:6YG.@H*,2X@02!W;W)K:6YG($AO<F1E(&EN<W1A;&QA=&EO;BX*
M"B`@(%!A<W-W9"!R=6YS('=I=&AI;B!T:&4@8$AO<F1E($%P<&QI8V%T:6]N
M($9R86UE=V]R:V!?+"!A('-E="!O9B!C;VUM;VX*("`@=&]O;',@9F]R(%=E
M8B!A<'!L:6-A=&EO;G,@=W)I='1E;B!I;B!02%`N("!9;W4@;75S="!I;G-T
M86QL($AO<F1E(&)E9F]R90H@("!I;G-T86QL:6YG(%!A<W-W9"X*"B`@("XN
M($EM<&]R=&%N=#HZ(%!A<W-W9"`S+C`@<F5Q=6ER97,@=F5R<VEO;B`S+C`K
M(&]F('1H92!(;W)D92!&<F%M97=O<FL@+0H@("`@("`@("`@("`@("`@("!E
M87)L:65R('9E<G-I;VYS(&]F($AO<F1E('=I;&P@*BIN;W0J*B!W;W)K+@H*
M("`@+BX@7V!(;W)D92!!<'!L:6-A=&EO;B!&<F%M97=O<FM@.B!H='1P.B\O
M=W=W+FAO<F1E+F]R9R]H;W)D92\*"B`@(%1H92!(;W)D92!&<F%M97=O<FL@
M8V%N(&)E(&]B=&%I;F5D(&9R;VT@=&AE($AO<F1E('=E8G-I=&4@86YD($94
M4"!S97)V97(L"B`@(&%T"@H@("`@("!H='1P.B\O=W=W+FAO<F1E+F]R9R]H
M;W)D92\*"B`@("`@(&9T<#HO+V9T<"YH;W)D92YO<F<O<'5B+VAO<F1E+PH*
M("`@36%N>2!O9B!087-S=V0G<R!P<F5R97%U:7-I=&5S(&%R92!A;'-O($AO
M<F1E('!R97)E<75I<VET97,N"@H@("`N+B!);7!O<G1A;G0Z.B!"92!S=7)E
M('1O(&AA=F4@8V]M<&QE=&5D(&%L;"!O9B!T:&4@<W1E<',@:6X@=&AE"B`@
M("`@("`@("`@("`@("`@(&!H;W)D92]D;V-S+TE.4U1!3$Q@7R!F:6QE(&9O
M<B!T:&4@2&]R9&4@1G)A;65W;W)K(&)E9F]R90H@("`@("`@("`@("`@("`@
M("!I;G-T86QL:6YG(%!A<W-W9"X*"C(N(%1H92!F;VQL;W=I;F<@4$A0(&-A
M<&%B:6QI=&EE<RP@9&5P96YD:6YG(&]N('1H92!D<FEV97)S('EO=2!W86YT
M('5S93H*"B`@(&$N($Q$05`@<W5P<&]R="!@8"TM=VET:"UL9&%P8&`@6T]0
M5$E/3D%,70H*("`@("`@3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&9O<B!T
M:&4@:V]L86(L(&QD87`L(&%N9"!S;6)L9&%P(&1R:79E<G,N"@H@("!B+B!-
M:&%S:"!S=7!P;W)T(&!@+2UW:71H+6UH87-H8&`@6T]05$E/3D%,70H*("`@
M("`@36AA<V@@<W5P<&]R="!M:6=H="!B92!N96-E<W-A<GD@9F]R('1H92!,
M1$%0(&1R:79E<G,N("!3964@8$Q$05`*("`@("`@26UP;&5M96YT871I;VX@
M26YF;W)M871I;VY@7R!F;W(@9&5T86EL<RX*"C,N(%1H92!F;VQL;W=I;F<@
M4$5!4B!M;V1U;&5S.@H@("`H4V5E(&!H;W)D92]D;V-S+TE.4U1!3$Q@7R!F
M;W(@:6YS=')U8W1I;VYS(&]N(&EN<W1A;&QI;F<@4$5!4B!M;V1U;&5S*0H*
M("`@82X@0W)Y<'1?0TA!4"!;3U!424].04Q="B`@"B`@("`@(%!A<W-W9"!U
M<V5S('1H:7,@<&%C:V%G92!T;R!E;F-R>7!T('!A<W-W;W)D<R!F;W(@=&AE
M('-M8FQD87`@9')I=F5R+@H*5&AE(&9O;&QO=VEN9R!I=&5M<R!M:6=H="!B
M92!R97%U:7)E9"P@9&5P96YD:6YG(&]N('1H92!D<FEV97)S('EO=2!W86YT
M('1O"G5S93H*"C$N($$@<&]P<&%S<V0@<V5R=F5R(&EN<W1A;&QE9"P@<G5N
M;FEN9RP@86YD('=O<FMI;F<@;VX@82!S>7-T96TN"@HR+B!!;B!,1$%0('-E
M<G9E<B!I;G-T86QL960L(')U;FYI;F<L(&%N9"!W;W)K:6YG(&9O<B!A=71H
M96YT:6-A=&EO;BX*"C,N($$@=V]R:VEN9R!S;6)P87-S=V0@<')O9W)A;2!O
M;B!T:&4@=V5B('-E<G9E<BX@($ET(&-A;B!A8V-E<W,@82!R96UO=&4*("`@
M<V5R=F5R+"!B=70@=&AE('-M8G!A<W-W9"!B:6YA<GD@;75S="!B92!I;G-T
M86QL960@;VX@=&AE(&QO8V%L('-Y<W1E;2X*"C0N($$@=V]R:VEN9R!344P@
M875T:&5N=&EC871I;VX@<WES=&5M+@H*-2X@17AP96-T(&EN<W1A;&QE9"P@
M86YD(&%C8V5S<R!T;R!T96QN970@;W(@<W-H('1O('1H92!M86-H:6YE('=H
M97)E"B`@('!A<W-W;W)D<R!A<F4@<W1O<F5D+W-E="`H8V]U;&0@8F4@;&]C
M86QH;W-T*2X*"@I);G-T86QL:6YG(%!A<W-W9`H]/3T]/3T]/3T]/3T]/3T]
M/3T]"@I087-S=V0@:7,@=W)I='1E;B!I;B!02%`L(&%N9"!M=7-T(&)E(&EN
M<W1A;&QE9"!I;B!A('=E8BUA8V-E<W-I8FQE(&1I<F5C=&]R>2X*5&AE('!R
M96-I<V4@;&]C871I;VX@;V8@=&AI<R!D:7)E8W1O<GD@=VEL;"!D:69F97(@
M9G)O;2!S>7-T96T@=&\@<WES=&5M+@I#;VYV96YT:6]N86QL>2P@4&%S<W=D
M(&ES(&EN<W1A;&QE9"!D:7)E8W1L>2!U;F1E<FYE871H($AO<F1E(&EN('1H
M92!W96(*<V5R=F5R)W,@9&]C=6UE;G0@=')E92X*"E-I;F-E(%!A<W-W9"!I
M<R!W<FET=&5N(&EN(%!(4"P@=&AE<F4@:7,@;F\@8V]M<&EL871I;VX@;F5C
M97-S87)Y.R!S:6UP;'D*97AP86YD('1H92!D:7-T<FEB=71I;VX@=VAE<F4@
M>6]U('=A;G0@:70@=&\@<F5S:61E(&%N9"!R96YA;64@=&AE(')O;W0*9&ER
M96-T;W)Y(&]F('1H92!D:7-T<FEB=71I;VX@=&\@=VAA=&5V97(@>6]U('=I
M<V@@=&\@87!P96%R(&EN('1H92!54DPN("!&;W(*97AA;7!L92P@=VET:"!T
M:&4@07!A8VAE('=E8B!S97)V97(G<R!D969A=6QT(&1O8W5M96YT(')O;W0@
M;V8*8&`O=7-R+VQO8V%L+V%P86-H92]H=&1O8W-@8"P@>6]U('=O=6QD('1Y
M<&4Z.@H*("`@8V0@+W5S<B]L;V-A;"]A<&%C:&4O:'1D;V-S+VAO<F1E"B`@
M('1A<B!Z>'9F("]P871H+W1O+W!A<W-W9"UX+GDN>BYT87(N9WH*("`@;78@
M<&%S<W=D+7@N>2YZ('!A<W-W9`H*86YD('=O=6QD('1H96X@9FEN9"!087-S
M=V0@870@=&AE(%523#HZ"@H@("!H='1P.B\O>6]U<BUS97)V97(O:&]R9&4O
M<&%S<W=D+PH*"D-O;F9I9W5R:6YG(%!A<W-W9`H]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H*,2X@0V]N9FEG=7)I;F<@2&]R9&4@9F]R(%!A<W-W9`H*("`@82X@
M4F5G:7-T97(@=&AE(&%P<&QI8V%T:6]N"@H@("`@("!);B!@8&AO<F1E+V-O
M;F9I9R]R96=I<W1R>2YP:'!@8"P@9FEN9"!T:&4@8&!A<'!L:6-A=&EO;G-;
M)W!A<W-W9"==8&`*("`@("`@<W1A;GIA+B`@5&AE(&1E9F%U;'0@<V5T=&EN
M9W,@:&5R92!S:&]U;&0@8F4@;VMA>2P@8G5T('EO=2!C86X@8VAA;F=E"B`@
M("`@('1H96T@:68@9&5S:7)E9"X@($EF('EO=2!H879E(&-H86YG960@=&AE
M(&QO8V%T:6]N(&]F(%!A<W-W9"!R96QA=&EV92!T;PH@("`@("!(;W)D92P@
M96ET:&5R(&EN('1H92!54DPL(&EN('1H92!F:6QE<WES=&5M(&]R(&)O=&@L
M('EO=2!M=7-T('5P9&%T92!T:&4*("`@("`@8&!F:6QE<F]O=&!@(&%N9"!@
M8'=E8G)O;W1@8"!S971T:6YG<R!T;R!T:&5I<B!C;W)R96-T('9A;'5E<RX*
M"C(N($-O;F9I9W5R:6YG(%!A<W-W9`H*("`@5&\@8V]N9FEG=7)E(%!A<W-W
M9"P@8VAA;F=E('1O('1H92!@8&-O;F9I9R]@8"!D:7)E8W1O<GD@;V8@=&AE
M(&EN<W1A;&QE9`H@("!D:7-T<FEB=71I;VXL(&%N9"!M86ME(&-O<&EE<R!O
M9B!A;&P@;V8@=&AE(&-O;F9I9W5R871I;VX@8&!D:7-T8&`@9FEL97,*("`@
M=VET:&]U="!T:&4@8&!D:7-T8&`@<W5F9FEX.CH*"B`@("`@(&-D(&-O;F9I
M9R\*("`@("`@9F]R(&9O;R!I;B`J+F1I<W0[(&1O(&-P("1F;V\@8&)A<V5N
M86UE("1F;V\@+F1I<W1@.R!D;VYE"@H@("!/<B!O;B!7:6YD;W=S.CH*"B`@
M("`@(&-O<'D@*BYD:7-T("HN"@H@("!$;V-U;65N=&%T:6]N(&]N('1H92!F
M;W)M870@86YD('!U<G!O<V4@;V8@=&AO<V4@9FEL97,@8V%N(&)E(&9O=6YD
M(&EN(&5A8V@*("`@9FEL92X@(%EO=2!M87D@961I="!T:&5S92!F:6QE<R!I
M9B!Y;W4@=VES:"!T;R!C=7-T;VUI>F4@4&%S<W=D)W,*("`@87!P96%R86YC
M92!A;F0@8F5H879I;W(N("!7:71H(&]N92!E>&-E<'1I;VX@*&!@8F%C:V5N
M9',N<&AP8&`I('1H90H@("!D969A=6QT<R!W:6QL(&)E(&-O<G)E8W0@9F]R
M(&UO<W0@<VET97,N"@H@("!9;W4@;75S="!L;V=I;B!T;R!(;W)D92!A<R!A
M($AO<F1E($%D;6EN:7-T<F%T;W(@=&\@9FEN:7-H('1H90H@("!C;VYF:6=U
M<F%T:6]N(&]F(%!A<W-W9"X@(%5S92!T:&4@2&]R9&4@8&!!9&UI;FES=')A
M=&EO;F!@(&UE;G4@:71E;2!T;R!G970*("`@=&\@=&AE(&%D;6EN:7-T<F%T
M:6]N('!A9V4L(&%N9"!T:&5N(&-L:6-K(&]N('1H92!@8$-O;F9I9W5R871I
M;VY@8"!I8V]N('1O"B`@(&=E="!T:&4@8V]N9FEG=7)A=&EO;B!P86=E+B`@
M4V5L96-T(&!@4&%S<W=O<F1@8"!F<F]M('1H92!S96QE8W1I;VX@;&ES="!O
M9@H@("!A<'!L:6-A=&EO;G,N("!&:6QL(&EN(&]R(&-H86YG92!A;GD@8V]N
M9FEG=7)A=&EO;B!V86QU97,@87,@;F5E9&5D+B`@5VAE;@H@("!D;VYE(&-L
M:6-K(&]N(&!@1V5N97)A=&4@4&%S<W=O<F0@0V]N9FEG=7)A=&EO;F!@('1O
M(&=E;F5R871E('1H90H@("!@8&-O;F8N<&AP8&`@9FEL92X@($EF('EO=7(@
M=V5B('-E<G9E<B!D;V5S;B=T(&AA=F4@=W)I=&4@<&5R;6ES<VEO;G,@=&\*
M("`@=&AE(%!A<W-W9"!C;VYF:6=U<F%T:6]N(&1I<F5C=&]R>2!O<B!F:6QE
M+"!I="!W:6QL(&YO="!B92!A8FQE('1O('=R:71E"B`@('1H92!F:6QE+B`@
M26X@=&AI<R!C87-E+"!G;R!B86-K('1O(&!@0V]N9FEG=7)A=&EO;F!@(&%N
M9"!C:&]O<V4@;VYE(&]F('1H90H@("!O=&AE<B!M971H;V1S('1O(&-R96%T
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE(&!@<&%S<W=D+V-O;F9I9R]C;VYF
M+G!H<&!@+@H*("`@3F]T92!F;W(@:6YT97)N871I;VYA;"!U<V5R<SH@4&%S
M<W=D('5S97,@1TY5(&=E='1E>'0@=&\@<')O=FED92!L;V-A;`H@("!T<F%N
M<VQA=&EO;G,@;V8@=&5X="!D:7-P;&%Y960@8GD@87!P;&EC871I;VYS.R!T
M:&4@=')A;G-L871I;VYS(&%R92!F;W5N9`H@("!I;B!T:&4@8&!P;R]@8"!D
M:7)E8W1O<GDN("!)9B!A('1R86YS;&%T:6]N(&ES(&YO="!Y970@879A:6QA
M8FQE(&9O<B!Y;W5R"B`@(&QO8V%L92`H86YD('EO=2!W:7-H('1O(&-R96%T
M92!O;F4I+"!S964@=&AE(&!@:&]R9&4O<&\O4D5!1$U%8&`@9FEL92P@;W(*
M("`@:68@>6]U)W)E(&AA=FEN9R!T<F]U8FQE('5S:6YG(&$@<')O=FED960@
M=')A;G-L871I;VXL('!L96%S92!S964@=&AE"B`@(&!H;W)D92]D;V-S+U12
M04Y33$%424].4V!?(&9I;&4@9F]R(&EN<W1R=6-T:6]N<RX*"C,N(%1E<W1I
M;F<@4&%S<W=D"@H@("!/;F-E('EO=2!H879E(&-O;F9I9W5R960@4&%S<W=D
M+"!B<FEN9R!U<"!T:&4@:6YC;'5D960@=&5S="!P86=E(&EN('EO=7(*("`@
M5V5B(&)R;W=S97(@=&\@96YS=7)E('1H870@86QL(&YE8V5S<V%R>2!P<F5R
M97%U:7-I=&5S(&AA=F4@8F5E;B!M970N("!3964*("`@=&AE(&!H;W)D92]D
M;V-S+TE.4U1!3$Q@7R!D;V-U;65N="!F;W(@9G5R=&AE<B!D971A:6QS(&]N
M($AO<F1E('1E<W0*("`@<V-R:7!T<RX@($EF('EO=2!I;G-T86QL960@4&%S
M<W=D(&%S(&1E<V-R:6)E9"!A8F]V92P@=&AE(%523"!T;R!T:&4@=&5S=`H@
M("!P86=E('=O=6QD(&)E.CH*"B`@("`@(&AT='`Z+R]Y;W5R+7-E<G9E<B]H
M;W)D92]P87-S=V0O=&5S="YP:'`*"@I396-U<FET>2!C;VYS:61E<F%T:6]N
M<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*+BX@3F]T93HZ(%-O;64@9')I
M=F5R<R!L:6ME('!O<'!A<W-D(&%L=V%Y<R!U<V4@8VQE87(@=&5X="!P87-S
M=V]R9`H@("`@("`@("`@=')A;G-M:7-S:6]N<RX@($]T:&5R<R!M87D@86QS
M;R!U<V4@8VQE87(@=&5X="!P87-S=V]R9',@*&4N9RX@=&AE"B`@("`@("`@
M("!E>'!E8W0@<V-R:7!T(&1R:79E<B!U<VEN9R!T96QN970@<F%T:&5R('1H
M86X@<W-H*2X@(%1H:7,@8V%N(&)E"B`@("`@("`@("!C;VYS:61E<F5D('-O
M;65W:&%T('-A9F4@:68@=&AE('-E<G9E<B!I<R!O;B!T:&4@<V%M92!M86-H
M:6YE+"!T:&5R90H@("`@("`@("`@87)E(&YO('5S97(@:6YT97)A8W1I=F4@
M;&]G:6YS(&%L;&]W960@;VX@=&AA="!M86-H:6YE+"!A;F0@=&AE"B`@("`@
M("`@("!C;VYN96-T:6]N('5S97,@=&AE(&QO;W!B86-K("AL;V-A;&AO<W0I
M(&EN=&5R9F%C92X@($ET(&ES('5P('1O('1H90H@("`@("`@("`@861M:6YI
M<W1R871O<B!T;R!E=F%L=6%T92!T:&4@<V5C=7)I='D@:6UP;&EC871I;VYS
M(&]F('5S:6YG('1H:7,*("`@("`@("`@(&UO9'5L92P@86YD('1O('5N9&5R
M<W1A;F0@=&AE('-E8W5R:71Y(&EM<&QI8V%T:6]N<R!O9B!H;W<@=&AE:7(*
M("`@("`@("`@('-E<G9E<B!A;F0@=&AI<R!M;V1U;&4@:7,@8V]N9FEG=7)E
M9"X*"BXN($YO=&4Z.B!3971T:6YG('1H:7,@;6]D=6QE('1O(&%L;&]W(&=U
M97-T(&%C8V5S<R!M:6=H="!A;'-O(&)E(&-O;G-I9&5R960@80H@("`@("`@
M("`@<V5C=7)I='D@<FES:RX@($)Y(&1E9F%U;'0L(&=U97-T(&%C8V5S<R!I
M<R!D:7-A8FQE9"X@($ET(&ES('5P('1O"B`@("`@("`@("!T:&4@861M:6YI
M<W1R871O<B!T;R!E=F%L=6%T92!T:&4@<V5C=7)I='D@:6UP;&EC871I;VYS
M(&]F('5S:6YG"B`@("`@("`@("!T:&ES(&UO9'5L92!W:71H(&=U97-T(&%C
M8V5S<R!I9B!T:&5Y(&-H;V]S92!T;R!D;R!S;RX*"@H*4&]P<&%S<V0@4V5R
M=F5R(%-O9G1W87)E"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AE(&9O
M;&QO=VEN9R!A<F4@<V]M92!L:6YK<R!T:&%T('5S97)S(&AA=F4@<W5B;6ET
M=&5D+B`@3F\@=V%R<F5N='D@:7,@;6%D90IF;W(@=&AE(&9O;&QO=VEN9R!L
M:6YK<R!O<B!A;GD@<V]F='=A<F4@;V)T86EN960@9G)O;2!T:&5N+B`@5&AE
M<V4@87)E(&%L;`IU<V5R('-U8FUI='1E9"!L:6YK<RP@86YD(&AA=F4@;F]T
M(&)E96X@=&5S=&5D(&]R('9E<FEF:65D+B`@57-E('1H97-E(&QI;FMS"F%R
M92!Y;W5R(&]W;B!R:7-K(0H**B!H='1P.B\O=W=W+F-E=&DN8V]M+G!L+WYK
M<F%V:65T>B]P<F]G+FAT;6P**B!H='1P.B\O=W=W+G-A;65R82YN970O<G!M
M+PHJ(&AT='`Z+R]N971W:6YS:71E+F-O;2]P;W!P87-S9"\**B!H='1P.B\O
M96-H96QO;BYP;"]P=6)S+W!O<'!A<W-D+3$N."XQ+G1A<BYG>@H*"DQ$05`@
M26UP;&5M96YT871I;VX@26YF;W)M871I;VX*/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*5&AE(&UO9'5L92!I;F-L=61E<R!S=7!P;W)T(&9O
M<B!C:&%N9VEN9R!,1$%0('-T;W)E9"!P87-S=V]R9',N"@I,1$%0(&-A;B!S
M=&]R92!P87-S=V]R9',@:6X@;75L=&EP;&4@=V%Y<RP@;F%M96QY.@H*82X@
M4&QA:6X@=&5X="!P87-S=V]R9',*8BX@4TA!(&5N8W)Y<'1E9"!P87-S=V]R
M9',*8RX@4U-(02!E;F-R>7!T960@<&%S<W=O<F1S"F0N($-R>7!T(&5N8W)Y
M<'1E9"!P87-S=V]R9',*92X@340U(&5N8W)Y<'1E9"!P87-S=V]R9',@*'5S
M:6YG(&)A<V4V-"!E;F-O9&EN9R`M(&UD-2UB87-E-C0I"F8N(%--1#4@96YC
M<GEP=&5D('!A<W-W;W)D<PH*5&AE(%-(02P@4U-(02P@340U+"!A;F0@4TU$
M-2!E;F-R>7!T:6]N('1Y<&5S('=I;&P@<F5Q=6ER92!T:&4@<&AP(&UH87-H
M"F5X=&5N<VEO;B$@(%1O(&5N86)L92!T:&ES('EO=2!M=7-T(&-O;7!I;&4@
M<&AP('=I=&@@=&AE"F!@+2UW:71H+6UH87-H6SU$25)=8&`@<&%R86UE=&5R
M('1O(&5N86)L92!T:&ES(&5X=&5N<VEO;BX@8&!$25)@8"!I<R!T:&4*;6AA
M<V@@:6YS=&%L;"!D:7)E8W1O<GDN"@I#<GEP="!C86YN;W0@:&%N9&QE('!A
M<W-W;W)D<R!L;VYG97(@=&AA;B!E:6=H="!C:&%R86-T97)S("AI="!A8V-E
M<'1S('1H96T*8G5T('1R=6YC871E<R!T:&5M(&%T(#@@8VAA<F%C=&5R<RDN
M("!)9B!Y;W4@=V%N="!T;R!U<V4@;&]N9V5R('!A<W-W;W)D<RP@>6]U"FUA
M>2!U<V4@4TA!+@H*5&AE('5S97(@;75S="!B92!A8FQE('1O(&%U=&AE;G1I
M8V%T92!T;R!T:&4@3$1!4"!D:7)E8W1O<GD@86YD(&-H86YG92!H:7,@;W=N
M"G!A<W-W;W)D(&YO=R`H=V4@;F\@;&]N9V5R(&1O(')O;W0@86-C97-S('1O
M($Q$05`I+B`@5&AI<R!A<W-U;65S('1H870@=&AE"DQ$05`@861M:6YI<W1R
M871O<B!H87,@86QL;W=E9"!E=F5R>6]N92!T;R!W<FET92!T:&5I<B!O=VX@
M<&%S<W=O<F0L('-O;65T:&EN9PIL:6ME.CH*"B`@(&%C8V5S<R!T;R!A='1R
M:6)U=&4]=7-E<E!A<W-W;W)D"B`@("`@("`@("!B>2!S96QF('=R:71E"B`@
M("`@("`@("!B>2!A;F]N>6UO=7,@875T:`H@("`@("`@("`@8GD@*B!N;VYE
M"@H*4U%,($EM<&QE;65N=&%T:6]N($EN9F]R;6%T:6]N"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AE(&UO9'5L92!I;F-L=61E<R!S=7!P
M;W)T(&9O<B!C:&%N9VEN9R!P87-S=V]R9',@<W1O<F5D(&EN(&$@4U%,(&1A
M=&%B87-E+@I4:&4@4U%,(&1R:79E<B!I<R!S:6UI;&%R('1O('1H92!,1$%0
M(&1R:79E<B!E>&-E<'0@=&AA="!I="!A;'-O('-U<'!O<G1S($U$-0IE;F-R
M>7!T:6]N('5S:6YG(&AE>"!E;F-O9&EN9R`H;60U+6AE>"DN("!)9B!Y;W4@
M8W)E871E9"!Y;W5R('!A<W-W;W)D<R!U<VEN9PIT:&4@4$A0(&UD-2@I(&9U
M;F-T:6]N('1H96X@=7-E(&UD-2UH97@N"@H*4VUB<&%S<W=D($EM<&QE;65N
M=&%I;VX@26YF;W)M871I;VX*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"E1O('5S92!T:&ES(&UO9'5L92P@>6]U(&UU<W0@<&%S<R!T
M:&4@861D<F5S<R!O9B!Y;W5R(%-A;6)A(&1O;6%I;B!C;VYT<F]L;&5R"F]N
M('=H:6-H('1O(&-H86YG92!T:&4@<&%S<W=O<F0N("!4:&ES(&-A;B!B92`B
M;&]C86QH;W-T(B!F;W(@=&AE('-E<G9E<B!T:&%T"DAO<F1E(')U;G,@;VXN
M("!4:&4@<F5M;W1E('-Y<W1E;2!N86UE(&UA>2!B92!P87-S960@87,@=&AE
M($Y%5$))3U,@;F%M92P@=&AE"D1.4R!N86UE+"!O<B!T:&4@25`@861D<F5S
M<R!O9B!T:&4@4TU"+T-)1E,@<V5R=F5R('1O(&-O;FYE8W0@=&\N("!4:&4*
M=7-E<FYA;64@:7,@<G5N('1H<F]U9V@@8&!E<V-A<&5S:&5L;&-M9"@I8&`L
M('-O(&%N>2!U<V5R;F%M97,@=VET:"!S=')A;F=E"F-H87)A8W1E<G,@*"0L
M("8L(&5T8RD@;6%Y(&YO="!W;W)K+B`@22=M(&YO="!S=7)E(&EF(&%N>2!O
M9B!T:&5S92!A<F4@979E;@IV86QI9"!F;W(@4TU"+T-)1E,@875T:&5N=&EC
M871I;VXL(&)U="!I9B!S;RP@=&AE>2!M87D@;F]T('=O<FL@:6X@=&AI<PIM
M;V1U;&4N"@HN+B!.;W1E.CH@268@8VAA;F=I;F<@82!7:6YD;W=S($Y4($1O
M;6%I;B!P87-S=V]R9"!T:&4@<F5M;W1E(&UA8VAI;F4*("`@("`@("`@('-P
M96-I9FEE9"!M=7-T(&)E('1H92!0<FEM87)Y($1O;6%I;B!#;VYT<F]L;&5R
M(&9O<B!T:&4@9&]M86EN"B`@("`@("`@("`H0F%C:W5P($1O;6%I;B!#;VYT
M<F]L;&5R<R!O;FQY(&AA=F4@82!R96%D+6]N;'D@8V]P>2!O9B!T:&4@=7-E
M<@H@("`@("`@("`@86-C;W5N="!D871A8F%S92!A;F0@=VEL;"!N;W0@86QL
M;W<@=&AE('!A<W-W;W)D(&-H86YG92DN"@I3:6YC92!S;6)P87-S=V0@=V]R
M:W,@:6X@8VQI96YT+7-E<G9E<B!M;V1E(&-O;6UU;FEC871I;F<@=VET:"!A
M(&QO8V%L('-M8F0*9F]R(&$@;F]N+7)O;W0@=7-E<BP@=&AE('-M8F0@9&%E
M;6]N(&UU<W0@8F4@<G5N;FEN9R!F;W(@=&AI<R!T;R!W;W)K+B`@00IC;VUM
M;VX@<')O8FQE;2!I<R!T;R!A9&0@82!R97-T<FEC=&EO;B!T;R!T:&4@:&]S
M=',@=&AA="!M87D@86-C97-S('1H92!S;6)D"G)U;FYI;F<@;VX@=&AE(&QO
M8V%L(&UA8VAI;F4@8GD@<W!E8VEF>6EN9R!A(&%L;&]W(&AO<W1S(&]R(&1E
M;GD@:&]S=',@96YT<GD*:6X@=&AE(&!@<VUB+F-O;F9@8"!F:6QE(&%N9"!N
M96=L96-T:6YG('1O(&%L;&]W(")L;V-A;&AO<W0B(&%C8V5S<R!T;R!T:&4*
M<VUB9"X*"DEN(&%D9&ET:6]N+"!T:&4@<VUB<&%S<W=D(&-O;6UA;F0@:7,@
M;VYL>2!U<V5F=6P@:68@4V%M8F$@:&%S(&)E96X@<V5T('5P('1O"G5S92!E
M;F-R>7!T960@<&%S<W=O<F1S+@H*"D5X<&5C="!38W)I<'0@26YF;W)M871I
M;VX*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AI<R!C;V1E(&%L;&]W
M<R!U<V5R<R!T;R!C:&%N9V4@=&AE:7(@<&%S<W=O<F1S('9I82!A;B!E>'!E
M8W0@<V-R:7!T+B`@5&AE"FUO9'5L92!R97%U:7)E<R!T:&4@97AP96-T('!R
M;V=R86T@86YD(&$@=&5L;F5T(&]R('-S:"!P<F]G<F%M+B`@66]U(&UA>2!N
M965D"G1O(&-H86YG92!S;VUE(&]F('1H92!E>'!E8W0@<&%T=&5R;G,@:6X@
M8&!S8W)I<'1S+W!A<W-W9%]E>'!E8W1@8"!S=6-H(&%S('1H90I@8&)A9'!A
M<W-W;W)D7W-T<FEN9V!@(&]R(&!@<W5C8V5S<U]S=')I;F=@8"`H87,@;VYL
M>2!T=V\@97AA;7!L97,I+@H*1F]R('-E8W5R:71Y(')E87-O;G,L(&ET(&ES
M(&=E;F5R86QL>2!S=6=G97-T960@=&\@=7-E('-S:"!R871H97(@=&AA;B!T
M96QN970*9F]R('1H92!T<F%N<W!O<G0L(&EF('!O<W-I8FQE+@H*"D]B=&%I
M;FEN9R!3=7!P;W)T"CT]/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W4@96YC;W5N
M=&5R('!R;V)L96US('=I=&@@4&%S<W=D+"!H96QP(&ES(&%V86EL86)L92$*
M"E1H92!(;W)D92!&<F5Q=65N=&QY($%S:V5D(%%U97-T:6]N<R!,:7-T("A&
M05$I+"!A=F%I;&%B;&4@;VX@=&AE(%=E8B!A=`H*("!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]F87$O"@I4:&4@2&]R9&4@4')O:F5C="!R=6YS(&$@;G5M8F5R
M(&]F(&UA:6QI;F<@;&ES=',L(&9O<B!I;F1I=FED=6%L(&%P<&QI8V%T:6]N
M<PIA;F0@9F]R(&ES<W5E<R!R96QA=&EN9R!T;R!T:&4@<')O:F5C="!A<R!A
M('=H;VQE+B`@26YF;W)M871I;VXL(&%R8VAI=F5S+"!A;F0*<W5B<V-R:7!T
M:6]N(&EN9F]R;6%T:6]N(&-A;B!B92!F;W5N9"!A=`H*("!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]M86EL+PH*3&%S=&QY+"!(;W)D92!D979E;&]P97)S+"!C
M;VYT<FEB=71O<G,@86YD('5S97)S(&%L<V\@;6%K92!O8V-A<VEO;F%L"F%P
M<&5A<F%N8V5S(&]N($E20RP@;VX@=&AE(&-H86YN96P@(VAO<F1E(&]N('1H
M92!&<F5E;F]D92!.971W;W)K"BAI<F,N9G)E96YO9&4N;F5T*2X*"E!L96%S
M92!K965P(&EN(&UI;F0@=&AA="!087-S=V0@:7,@9G)E92!S;V9T=V%R92!W
M<FET=&5N(&)Y('9O;'5N=&5E<G,N("!&;W(*:6YF;W)M871I;VX@;VX@<F5A
M<V]N86)L92!S=7!P;W)T(&5X<&5C=&%T:6]N<RP@<&QE87-E(')E860*"B`@
M:'1T<#HO+W=W=RYH;W)D92YO<F<O<W5P<&]R="YP:'`*"E1H86YK<R!F;W(@
M=7-I;F<@4&%S<W=D(0H*5&AE(%!A<W-W9"!T96%M"@H*+BX@7U)%041-13H@
M/V8]4D5!1$U%+FAT;6P*+BX@7V!H;W)D92]D;V-S+TA!0TM)3D=@.B`N+B\N
M+B]H;W)D92]D;V-S+S]F/4A!0TM)3D<N:'1M;`HN+B!?8&AO<F1E+V1O8W,O
M24Y35$%,3&`Z("XN+RXN+VAO<F1E+V1O8W,O/V8]24Y35$%,3"YH=&UL"BXN
M(%]@:&]R9&4O9&]C<R]44D%.4TQ!5$E/3E-@.B`N+B\N+B]H;W)D92]D;V-S
M+S]F/51204Y33$%424].4RYH=&UL"@``````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&%S<W=D+V1O8W,O5$]$3P``````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C(T-``Q,#0Q-S,V,C<T,P`P,3<S-#,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!087-S=V0@1&5V96QO<&UE;G0@5$]$
M3R!,:7-T"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@
M=7!D871E.B`@("1$871E.B`R,#`U+S`Y+S$S(#(S.C(W.C`U("0*.E)E=FES
M:6]N.B`@("`@("12979I<VEO;CH@,2XQ,R`D"CI#;VYT86-T.B`@("`@("!S
M;W)K0&QI<W1S+FAO<F1E+F]R9PH*+2!4:&5R92!S:&]U;&0@8F4@;6]R92!E
M<G)O<B!C:&5C:VEN9R!F;W(@=F%R:6]U<R!T:&EN9W,L(&EN('!A<G1I8W5L
M87(@<V%N:71Y"B`@8VAE8VMI;F<@;V8@=&AE(&9O<FT@=F%R:6%B;&5S('!A
M<W-E9"!I;BX*"BT@1&]C=6UE;G0@:7-S=65S(&]F('!O<'!A<W-D+VQD87`O
M<VUB<&%S<W=D('!E<FAA<',@86QL;W=I;F<@=V5A:R!P87-S=V]R9',*("!O
M<B!O=&AE<G=I<V4@9V5T=&EN9R!A<F]U;F0@<&%S<W=D(')E<W1R:6-T:6]N
M<RX@($1O8W5M96YT('1H92!P87-S=V]R9`H@(&QE;F=T:"!A;F0@<W1R96YG
M=&@@=&5S=',L(&%N9"!H;W<@8F%D('1H97D@<F5A;&QY(&%R92X@(%=E(&-O
M=6QD"B`@:6YV97-T:6=A=&4@=7-I;F<@8W)A8VML:6(@8V%L;',L('-I;F-E
M(&ET(&ES('-U<'!O<G1E9"!B>2!P:'`L(&)U="!T:&%T"B`@=V]U;&0@<F5Q
M=6ER92!C<F%C:VQI8B!T;R!B92!I;G-T86QL960@;VX@=&AE('-Y<W1E;2!A
M;F0@:6X@4$A0+@H*+2!.965D('1O(&-L96%N('5P('1H92!L9&%P9"!C;V1E
M('-T:6QL+B`@02!W;W)K(&EN('!R;V=R97-S+B`@36%Y8F4@<&%S<R!T:&4*
M("!P87-S=V]R9"!F:65L9"`B=7-E<E!A<W-W;W)D(B!A<R!A(&-O;F9I9R!I
M=&5M('-O('!E;W!L92!C86X@;F%M92!I=`H@(&1I9F9E<F5N=&QY(&EF(&YE
M961E9#\*"BT@5&AE(&5X:6T@<W%L(&1R:79E<B!D969I;F5S(&$@;&]T(&]F
M('-T=69F(&EN(&-O;F8N<&AP('1H870@<VAO=6QD(&%L<F5A9'D*("!B92!D
M969I;F5D(&EN($AO<F1E+TE-4"=S(&-O;F9I9W,N("!792!S:&]U;&0@<')O
M8F%B;'D@<F5U<V4@=&AE($AO<F1E+TE-4`H@('-T=69F(')A=&AE<B!T:&%N
M(&1U<&QI8V%T:6YG('1H92!C;VYF:6=U<F%T:6]N/S\_"@HM($1I<W!L87D@
M=&AE('!A<W-W;W)D('!O;&EC>2!T;R!T:&4@=7-E<B!T:&%T(&AE(&MN;W=S
M(&AO=R!T:&4@<&%S<W=O<F0*("!S:&]U;&0@;&]O:R!L:6ME("A297%U97-T
M(",R,S`T*2X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+P``````````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S0T`#`Q-S$V-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W
M9"]L;V-A;&4O8F=?0D<O````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`,#(P,3(S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]B9U]"1R],0U]-15-304=%4R\`
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P
M,C$W,3``(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+V)G
M7T)'+TQ#7TU%4U-!1T53+W!A<W-W9"YM;P``````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,30W
M,C$P`#$P-#$W,S8R-S0S`#`R,S4U,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````#8"```<````S!$``/4"``!\
M(P```````%`O``!-````42\``+\```"?+P``9````%\P``"^````Q#```)``
M``"#,0``0P```!0R```\````6#(``"L```"5,@``+@```,$R```I````\#(`
M`"@````:,P``10```$,S``!*````B3,``$4```#4,P``2````!HT```Y````
M8S0``$8```"=-```1@```.0T``",````*S4``$@```"X-0``,`````$V``!&
M````,C8``#0```!Y-@``,@```*XV``!I````X38``#````!+-P``)0```'PW
M``"(````HC<``$`````K.```]@```&PX``!*````8SD``"P```"N.0``A0``
M`-LY``!(````83H```X```"J.@``"````+DZ```,````PCH``!$```#/.@``
M)0```.$Z```+````!SL``"@````3.P``"P```#P[```5````2#L```X```!>
M.P``+@```&T[```7````G#L``(````"T.P``#0```#4\```M````0SP``"0`
M``!Q/```*0```)8\```9````P#P``!0```#:/```&P```.\\```(````"ST`
M`"(````4/0``+````#<]```R````9#T``#@```"7/0``5````-`]``!1````
M)3X``#0```!W/@``.@```*P^``!8````YSX``%4```!`/P``!0```)8_```-
M````G#\``!(```"J/P``#0```+T_```2````RS\``!D```#>/P``'@```/@_
M```0````%T````\````H0```"P```#A````7````1$```!<```!<0```'P``
M`'1````9````E$````<```"N0```#````+9````.````PT````,```#20```
M!0```-9````*````W$````\```#G0```'P```/=````1````%T$```P````I
M00``.````#9!```]````;T$``#D```"M00``)P```.=!```L````#T(``"H`
M```\0@``"@```&="```5````<D(``"D```"(0@``$@```+)"```1````Q4(`
M`"(```#70@``%@```/I"```6````$4,```8````H0P``"````"]#```$````
M.$,```D````]0P``!0```$=#```$````34,``"8```!20P``&@```'E#```,
M````E$,```,```"A0P```P```*5#```#````J4,```@```"M0P``"@```+9#
M```@````P4,``!\```#B0P``+0````)$```&````,$0``"(````W1```"@``
M`%I$```(````940```\```!N1```%````'Y$```7````DT0``$0```"K1```
M"0```/!$```&````^D0``$$````!10``"@```$-%```1````3D4```P```!@
M10``!@```&U%```0````=$4```D```"%10``"P```(]%```'````FT4```T`
M``"C10``%0```+%%```0````QT4``"L```#810``(`````1&```9````)48`
M`!`````_1@``!````%!&```0````548``!X```!F1@``&P```(5&```@````
MH48``!T```#"1@``'0```.!&```@````_D8``!<````?1P``,````#='```;
M````:$<``!T```"$1P``,P```*)'```O````UD<``"D````&2```(0```#!(
M```#````4D@```(```!62```%@```%E(```%````<$@```0```!V2```%```
M`'M(```0````D$@``!,```"A2```!@```+5(```$````O$@``"\```#!2```
M"P```/%(```/````_4@```0````-20``&0```!))```J````+$D```4```!7
M20``#0```%U)```;````:TD```T```"'20``#````)5)``!`````HDD```4`
M``#C20``(````.E)```'````"DH``!`````22@``$````"-*```/````-$H`
M``L```!$2@``#P```%!*```,````8$H```\```!M2@``"@```'U*```6````
MB$H``!X```"?2@``(0```+Y*```@````X$H``!X````!2P```P```"!+```3
M````)$L``!0````X2P``#````$U+```)````6DL``!L```!D2P``!P```(!+
M```&````B$L```L```"/2P``%@```)M+```2````LDL``!$```#%2P``"0``
M`-=+```.````X4L```4```#P2P``!````/9+```4````^TL```8````03```
M$0```!=,```.````*4P``!X````X3```(0```%=,```)````>4P```0```"#
M3```H````(A,```$````*4T```P````N30``"@```#M-```%````1DT``!0`
M``!,30``(````&%-```;````@DT``"````">30``(````+]-```F````X$T`
M`"D````'3@``"@```#%.```/````/$X``"H```!,3@``+@```'=.```=````
MIDX``#H```#$3@``)0```/].```5````)4\``!(````[3P``$````$Y/```1
M````7T\``!0```!Q3P``&@```(9/```,````H4\``!<```"N3P``'````,9/
M```&````XT\```P```#J3P``#````/=/```-````!%```"@````24```*P``
M`#M0```(````9U````H```!P4```$````'M0```:````C%```!0```"G4```
M!@```+Q0```'````PU````8```#+4````@```-)0```E````U5````0```#[
M4```0`````!1```3````05$``!@```!540``$0```&Y1```/````@%$``!8`
M``"040``,@```*=1```'````VE$```H```#B40``+0```.U1```T````&U(`
M`"0```!04@``!P```'52``!2````?5(```8```#04@``&@```-=2```)````
M\E(```T```#\4@``!P````I3```/````$E,```P````B4P``!P```"]3```*
M````-U,```0```!"4P``!````$=3```'````3%,```4```!44P``%P```%I3
M```-````<E,```(```"`4P``,P```(-3```\````MU,``#H```#T4P``.P``
M`"]4```^````:U0``#8```"J5```,P```.%4```^````%54``#@```!450``
M.P```(U5```4````R54``"T```#>50``,0````Q6```M````/E8``"\```!L
M5@``+````)Q6```=````R58``!H```#G5@``"0````)7```<````#%<``"$`
M```I5P``)0```$M7``!)````<5<```4```"[5P``!@```,%7```C````R%<`
M``(```#L5P```P```.]7```-````\U<```(````!6```!P````18```(````
M#%@```8````56```#````!Q8```1````*5@``!$````[6```"0```$U8```9
M````5U@```@```!Q6```$0```'I8```C````C%@``"H```"P6```*P```-M8
M```)````!UD```H````160``&@```!Q9```5````-UD```4```!-60``*```
M`%-9```+````?%D``!H```"(60``!0```*-9```@````J5D``"0```#*60``
M40```.]9```O````05H```T```!Q6@``"````']:```R````B%H```4```"[
M6@``!````,%:```R````QEH``!4```#Y6@``*@````];```0````.EL```8`
M``!+6P``#@```%);```/````85L``!X```!Q6P``0````)!;```]````T5L`
M`$8````/7```0@```%9<```W````F5P``$(```#17```/@```!1=```_````
M4UT``#D```"370``0````,U=``!"````#EX``#<```!17@``0@```(E>```^
M````S%X``#\````+7P``.0```$M?``!"````A5\``#<```#(7P``0@````!@
M```^````0V```#\```""8```.0```,)@``!&````_&```#8```!#80``00``
M`'IA```V````O&$``$$```#S80``/0```#5B```^````<V(``#@```"R8@``
M,P```.MB```]````'V,``#H```!=8P``0@```)AC```W````VV,``$(````3
M9```/@```%9D```_````E60``#D```#59```-@````]E```$````1F4```D`
M``!+90```P```%5E```?````664``!T```!Y90``!@```)=E```5````GF4`
M`!(```"T90``#P```,=E```4````UV4``&@```#L90``&@```%5F```7````
M<&8``!<```"(9@``&P```*!F```9````O&8``!\```#69@``$0```/9F```&
M````"&<``"0````/9P``5P```#1G```.````C&<```0```";9P``!````*!G
M```*````I6<``#````"P9P``,P```.%G```,````%6@``!<````B:```!@``
M`#IH```'````06@``"8```!):```&@```'!H```J````BV@``!D```"V:```
M`P```-!H```%````U&@```D```#::```/@```.1H``!*````(VD``$P```!N
M:0``.````+MI```H````]&D``$@````=:@``.P```&9J``!)````HFH``(\`
M``#L:@``,````'QK``!I````K6L``"L````7;```+@```$-L```R````<FP`
M`"4```"E;```/0```,ML``!E````"6T``$T```!O;0``+P```+UM```N````
M[6T``(,````<;@``,@```*!N``!5````TVX``%@````I;P``+P```()O```L
M````LF\``!<```#?;P``)0```/=O```R````'7```"0```!0<```/@```'5P
M``#-````M'```)L```""<0``I@```!YR```E````Q7(``(D```#K<@``6P``
M`'5S```A````T7,``#````#S<P``'````"1T```-````070```4```!/=```
M`P```%5T```@````670``!H```!Z=```(@```)5T```E````N'0``"8```#>
M=```"0````5U```3````#W4```X````C=0``!@```#)U```)````.74```T`
M``!#=0``'0```%%U```&````;W4``!$```!V=0``%````(AU```3````G74`
M``X```"Q=0``#P```,!U```(````T'4``"4```#9=0``"0```/]U```*````
M"78```4````4=@``%````!IV```(````+W8``#\````X=@``!P```'AV```)
M````@'8```8```"*=@``#0```)%V```+````GW8``"\```"K=@``#````-MV
M```*````Z'8``"````#S=@```@```!1W```&````%W<```,````>=P``)0``
M`")W```H````2'<``",```!Q=P``'P```)5W```F````M7<``"4```#<=P``
M*`````)X```A````*W@``!,```!->```$````&%X```*````<G@``'(```!]
M>```<P```/!X``!1````9'D``#<```"V>0``-@```.YY```^````)7H``$$`
M``!D>@``0P```*9Z``!`````ZGH``#X````K>P``0````&I[``!%````JWL`
M`#D```#Q>P``'P```"M\```?````2WP``!0```!K?```#P```(!\```5````
MD'P```0```"F?```!@```*M\```$````LGP```0```"W?```"0```+Q\```1
M````QGP``#,```#8?```!P````Q]```%````%'T``"X!```:?0``40```$E^
M``"V````FWX``#T```!2?P``N````)!_``"$````28```&,```#.@```/```
M`#*!```R````;X$``#H```"B@0``-0```-V!```T````$X(``$(```!(@@``
M/````(N"```]````R((``$8````&@P``,0```$V#```Z````?X,``#T```"Z
M@P``B0```/B#``!`````@H0``#$```##A```1P```/6$```M````/84``#0`
M``!KA0``:@```*"%```P````"X8``"P````\A@``EP```&F&``!%`````8<`
M`/T```!'AP``00```$6(```U````AX@``'T```"]B```1P```#N)```/````
M@XD```<```"3B0``"````)N)```2````I(D``"$```"WB0``#@```-F)```E
M````Z(D```L````.B@``'````!J*```,````-XH``#````!$B@``&````'6*
M``!R````CHH```\````!BP``*````!&+```>````.HL``#H```!9BP``&0``
M`)2+```.````KHL``!L```"]BP``!P```-F+```;````X8L``#$```#]BP``
M-0```"^,```U````98P``%(```";C```3P```.Z,```W````/HT``$````!V
MC0``7@```+>-``!;````%HX```4```!RC@``%@```'B.```6````CXX``!4`
M``"FC@``$````+R.```?````S8X``!\```#MC@``#P````V/```6````'8\`
M``T````TCP``'````$*/```?````7X\``"D```!_CP``)@```*F/```%````
MT(\``!````#6CP``#@```.>/```'````]H\```D```#^CP``#`````B0```,
M````%9```",````BD```%P```$:0```-````7I```#T```!LD```/0```*J0
M```W````Z)```"T````@D0``+0```$Z1```O````?)$```@```"LD0``&```
M`+61```R````SI$```\````!D@``#P```!&2```A````(9(``!L```!#D@``
M)0```%^2```&````A9(```H```",D@``"0```)>2```'````H9(```4```"I
MD@``!@```*^2```H````MI(``"0```#?D@``#`````23```#````$9,```,`
M```5DP```P```!F3```(````'9,```H````FDP``)@```#&3```E````6),`
M`#H```!^DP``!@```+F3```K````P),```\```#LDP``"0```/R3```1````
M!I0``!0````8E```(P```"V4```T````490```D```"&E```!@```)"4```_
M````EY0```T```#7E```&````.64```0````_I0```<````/E0``#P```!>5
M```(````)Y4```H````PE0``"````#N5```,````1)4``!D```!1E0``$P``
M`&N5```I````?Y4``"0```"IE0``'````,Z5```2````ZY4```<```#^E0``
M%`````:6```E````&Y8``"4```!!E@``)P```&>6```G````CY8``"4```"W
ME@``)````-V6```C`````I<``#P````FEP``)P```&.7```I````BY<``"4`
M``"UEP``.@```-N7```U````%I@``"T```!,F```!@```'J8```"````@9@`
M`!@```"$F```"0```)V8```%````IY@``!4```"MF```&P```,.8```5````
MWY@```8```#UF```!P```/R8```N````!)D```@````SF0``#0```#R9```(
M````2ID``!L```!3F0``.P```&^9```%````JYD```L```"QF0``(@```+V9
M```0````X)D```P```#QF0``0P```/Z9```&````0IH``"L```!)F@``!@``
M`'6:```/````?)H``!````",F@``#@```)V:```-````K)H``!0```"ZF@``
M#````,^:```3````W)H```\```#PF@``$@````";```I````$YL``#(````]
MFP``)````'";```?````E9L```0```"UFP``%0```+J;```6````T)L```P`
M``#GFP``"P```/2;```F`````)P```8````GG```!@```"Z<```+````-9P`
M`!<```!!G```%````%F<```/````;IP```L```!^G```#P```(J<```%````
MFIP```0```"@G```%P```*6<```%````O9P```X```##G```#P```-*<```A
M````XIP``!4````$G0``"````!J=```%````(YT``(`````IG0``!@```*J=
M```-````L9T```\```"_G0``!0```,^=```4````U9T``"````#JG0``&@``
M``N>```O````)IX``"\```!6G@``/````(:>```F````PYX```H```#JG@``
M#0```/6>```O`````Y\``"\````SGP``)P```&.?```^````BY\``"L```#*
MGP``&0```/:?```4````$*```!,````EH```$0```#F@```=````2Z```!T`
M``!IH```$@```(>@```?````FJ```!P```"ZH```"0```->@```2````X:``
M`!$```#TH```$@````:A```J````&:$``"T```!$H0``!````'*A```*````
M=Z$```H```""H0``(0```(VA```<````KZ$```0```#,H0``!0```-&A```%
M````UZ$```(```#=H0``+0```."A```$````#J(``#`````3H@``&@```$2B
M```;````7Z(``!<```![H@``$````).B```=````I*(``#T```#"H@``!P``
M``"C```.````"*,``#`````7HP``,````$BC```D````>:,```4```">HP``
M3````*2C```%````\:,``!D```#WHP``"````!&D```1````&J0```<````L
MI```%@```#2D```5````2Z0```<```!AI```"@```&FD```#````=*0```0`
M``!XI```!0```'VD```&````@Z0``",```"*I```#````*ZD```"````NZ0`
M`"8```"^I```+P```.6D```R````%:4``#,```!(I0``,0```'RE```I````
MKJ4``"8```#8I0``-0```/^E```K````-:8``#````!AI@``&@```)*F```K
M````K:8``"\```#9I@``-@````FG```X````0*<``#4```!YIP``&0```*^G
M```9````R:<```X```#CIP``,````/*G```I````(Z@``"T```!-J```2@``
M`'NH```'````QJ@```D```#.J```&P```-BH```"````]*@```4```#WJ```
M#0```/VH```$````"ZD```4````0J0``!@```!:I```&````':D```\````D
MJ0``$````#2I```4````1:D```D```!:J0``&@```&2I```&````?ZD``!8`
M``"&J0``(P```)VI```L````P:D``"T```#NJ0``!P```!RJ```(````)*H`
M`!T````MJ@``$@```$NJ```&````7JH``#(```!EJ@``!0```)BJ```9````
MGJH```<```"XJ@``'@```,"J```C````WZH``&,````#JP``/@```&>K```+
M````IJL```@```"RJP``-P```+NK```*````\ZL```8```#^JP``0@````6L
M```7````2*P``"D```!@K```%````(JL```(````GZP```\```"HK```%P``
M`+BL```C````T*P``#0```#TK```,@```"FM```Z````7*T``$H```"7K0``
M0````.*M```W````(ZX``#0```!;K@``-@```)"N```_````QZX``$4````'
MKP``20```$VO```X````EZ\``$8```#0KP``,0```!>P```T````2;```#H`
M``!^L```20```+FP```[`````[$``#@````_L0``-````'BQ```V````K;$`
M`#L```#DL0``.0```""R```Z````6K(``$<```"5L@``.@```-VR```U````
M&+,``#$```!.LP``,P```("S```\````M+,``#<```#QLP``,0```"FT```M
M````6[0``$D```")M```.P```-.T```V````#[4``#4```!&M0``-````'RU
M```]````L;4``#H```#OM0``!````"JV```)````+[8```,````YM@``(```
M`#VV```G````7K8```8```"&M@``&@```(VV```@````J+8```\```#)M@``
M'0```-FV``!,````][8``!D```!$MP``&@```%ZW```8````>;<``!X```"2
MMP``(P```+&W```D````U;<``!````#ZMP``!@````NX```O````$K@``&@`
M``!"N```#@```*NX```)````NK@```8```#$N```#0```,NX```T````V;@`
M`#<````.N0``$@```$:Y```>````6;D```<```!XN0``!0```("Y```C````
MAKD``!0```"JN0``)````+^Y```:````Y+D```,```#_N0``!@````.Z```*
M````"KH``#L````5N@``1P```%&Z``!)````F;H``"L```#CN@``(`````^[
M``!)````,+L``#,```!ZNP``5P```*Z[``"A````!KP``"\```"HO```7P``
M`-B\```I````.+T``"H```!BO0``+0```(V]```B````N[T``#4```#>O0``
M80```!2^```_````=KX``#8```"VO@``)P```.V^``"&````%;\``"0```"<
MOP``80```,&_``!?````(\```!P```"#P```&P```*#````7````O,```"H`
M``#4P```,0```/_````F````,<$``$4```!8P0``U````)[!``"!````<\(`
M`*4```#UP@``(````)O#``"#````O,,``&<```!`Q```)````*C$```W````
MS<0``"`````%Q0``%0```";%```(````/,4```,```!%Q0``)````$G%```>
M````;L4``"L```"-Q0``)0```+G%```H````W\4```H````(Q@``%@```!/&
M```1````*L8```<````\Q@``"@```$3&```/````3\8``"(```!?Q@``#```
M`(+&```D````C\8``"````"TQ@``'P```-7&```5````]<8``!8````+QP``
M`P```"+'```H````)L<```0```!/QP``!0```%3'```+````6L<``!@```!F
MQP``"````'_'```]````B,<```@```#&QP``"@```,_'```(````VL<``!``
M``#CQP``#P```/3'```T````!,@```P````YR```#@```$;(```G````5<@`
M``(```!]R```!P```(#(```"````B,@``"X```"+R```(0```+K(```E````
MW,@``",````"R0``*P```";)```J````4LD``"T```!]R0``)P```*O)```2
M````T\D``!$```#FR0``"P```/C)``!E````!,H``&4```!JR@``4````-#*
M``!&````(<L``#,```!HRP``,0```)S+```S````SLL``$,````"S```00``
M`$;,```[````B,P``$(```#$S```/P````?-```P````1\T``"P```!XS0``
M*P```*7-```/````T<T``!````#AS0``%````/+-```)````!\X```D````1
MS@``!````!O.```$````(,X```\````ES@``%0```#7.```N````2\X```<`
M``!ZS@``!0```(+.```!````-@$```````":````/````)\```#U`0``9```
M`&X````Q`0``BP```&H!``#9`````````/4```!/`````````-`!```D`0``
MG0$``"8```!A`0``$@$```````!<````'P$``-L```#I`0``$`$``"L!``"?
M`0``;@$```````"!````K0$``#@````-`0``U0$``+(```#D`0```````#(`
M``"*`0```````+D!````````E0$``*````!,````]````.`!``!K````7@$`
M``````!3````_@$``-0!`````````````#$````N`@``60$```<"```^````
M<P$``*\````T`@``5P`````````R`0``1@```-H!``!;`0```````(<```!!
M`````````*8!```#`@``````````````````VP$```T"``"C`0``V`$``/P`
M``!B````8P````````#X`0``G0````L"``"C````%P$```````#4````6`$`
M`!D!``"6`0``>@$``!D"`````````````/T!````````)P(``.,!````````
M!`(``'P!``"#`0````````````"Q`0``W`$``#L```!Z````I`$`````````
M````T``````````Z`0``Y````$X!``#A````+0``````````````)P$``&<!
M````````2`$``-\!``"V`0``T0$``!,`````````=P````````"9`0``ZP``
M`)8```!'````N````$`!``!X````\`````````"J````^P$```````"7`0``
M&P`````````:````S0```)(!``!;`````````!,"```A`0``'@$``.T`````
M````U0`````````P`@``C````!8"``"M`````````#<```#,````7`$`````
M````````@`$``"`"``#J````>P$`````````````+0$``,T!````````5```
M`)@!```%``````````````#3````&`(```````"[````\@$``/$```!$`0``
M?P```*`!``"&`0``"0(``+P````+`0``7P$``-$```"B`0``R`````$!``"1
M`0``)@$``,\!``#(`0``'````*0```!$````;0$````````1`0``<`$```D!
M``"L`0``30$````````7`@``R@$``(D`````````````````````````````
M``````#``0``_P`````````X`0````````````"F````.0$``*@```"4`0``
M5`$``"P"``!I`0``W0```%X```"S````K@```.@```!A````DP```,4```!%
M`0``'@(``)X!````````````````````````50```.<!``"U`````````$8!
M``"%`0```````!8````;`0```@(``'4!```F`@``:0```"@`````````20$`
M`$H!````````&````(X```"E`0``;```````````````9@$```````#T`0``
M``````````!G````E0```"D"``!9````W@```+X!```T````[0$``'(`````
M````<0`````````O`@```````"D!```U`0``S@```/<!``!@`````````!$`
M````````@@```*$!``#_`0``^@$`````````````Y@$``&L!````````70$`
M````````````N0```!\"```*`0```@$``%$```#+`0``@`````@`````````
M`````&4``````````````-P``````````````,L```"[`0``N@```"L"```<
M`@``:`$```````````````````P!````````=@```!P!````````````````
M`````````````"(````+````)0(``(8```!S````*0```"X```#X````H0``
M`-\```#G````L`````\!```@`0``D````#0!``#W``````````\````5`0``
M!`$``+<```!6`0``M`````0`````````-P$``)P`````````=P$`````````
M````T@$``!$"``"I`0``*`(``#8"```#````C@$``)@```"E````*`$``/8`
M``#Y`0``B@```!H"```=`0``^P```+$```#H`0``!P$``%T```"N`0``5P$`
M````````````^0```!L"```R`@``+P$```T```#C````9`$``,8```"^````
M`````),!``!+`````````,4!````````\0$``"X!```]````,0(``!T"``"-
M````;P$``'P````E`0``B`$``#P!```*````+P```'0```!#````8`$``"H"
M``"4````J`$``+H!``#A`0``"@(``-<!``!O`````````.P!````````M@``
M``````"J`0``20```)$````4`@``P@```/`!`````````````,0!```&`0``
MCP```-8!```#`0``O0````(```!X`0``(P(``"0````U````5@`````````_
M````50$``#D```````````````````":`0``A`$`````````````!@(`````
M`````````````%$!``!:````6@$`````````````>P```,P!``!8````````
M`.X!`````````````/,```#3`0``````````````````````````````````
M^@```.8```!3`0``````````````````O0$``"T"``!H````LP$``.D`````
M`````0(``,D!``#9`0``$@(````````B`0``A````"<````&`````````#``
M``"'`0``9@```%\``````0```````'\!``"2````4@````````!L`0``Y0``
M``````!0`````````(D!``!*````*@$``#,!`````````````!`"````````
M3@```/P!``"O`0``%@$````````7````O`$``",!```Z````0@$`````````
M````PP$```````!P````P@$``%(!````````3P$``$P!``"G`0``B````$4`
M``!'`0``ZP$``+4!``"P`0```````-X!````````=0```+\````P`0``J0``
M`*P```#B````$````*<````5````]@$````````]`0``(0(``"P!``!+`0``
M8P$```X!````````90$```````!V`0```````!\```!T`0``:@````````#2
M````,P(```D``````````````-H```"R`0``0P$``,,```";`0``\@```$@`
M``"X`0``UP```-T!`````@``'@```(,```#)``````````@"````````````
M`/T`````````(@(``"0"````````[P```,0```````````````4!```@````
MC0$```````!]````_@```#L!``#```````````````!Y`0```````-8```!M
M````00$`````````````@0$``.(!``#L````R@```!4"``";````4`$`````
M```(`0```````/,!```^`0``>0````````#@````Z@$````````A````````
M`"H````4````SP```)P!``#O`0```````*L`````````&@$``)X```"+`0``
M`````)<````K````#P(```````"%````CP$``*(`````````@@$``'(!```2
M````&`$```````#!`0``MP$``#8```"9````0````,$```#'`0``!P``````
M``!-`````````"P`````````D`$```P```!Q`0``Y0$````````%`@``&0``
M`",`````````S@$``'T!```S````8@$``#4"``",`0``Q@$````````=````
MV````#\!```4`0``M`$``!,!``!^`0```````'X```"_`0``JP$```P"```.
M````[@```$(````E````QP`````````.`@```"`@+4TL("TM;65S<V%G93U-
M15-304=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H
M92!D969A=6QT(&]N97,N`"`@+6$L("TM861D/49)3$4@("`@("`@($%D9"!T
M:&ES(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T;PH@("`@
M("`@("`@("`@("`@("`@("`@("!I;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M
M(&$@9&EF9F5R96YT(&)R86YC:"!T;PH@("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@9V5N97)A=&5D(&-O;7!E;F1I=6TN`"`@+6(L("TM8F%S93TO4$%4
M2"`@1G5L;"!P871H('1O('1H92`H2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H
M870@<VAO=6QD(&)E"B`@("`@("`@("`@("`@("`@("`@=7-E9"X`("`M8RP@
M+2UC;VUP96YD:75M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@
M=&AI<R!C;VUP96YD:75M(&9I;&4*("`@("`@("`@("`@("`@("`@("`@("`@
M(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE("AC;VUP96YD:75M+G!O(&EN
M('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@9&ER96-T
M;W)Y+@`@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H:7,@8V]M<&5N
M9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U;'0*("`@("`@("`@("`@
M("`@("`@("`@("`@(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O
M<&\@9&ER96-T;W)Y*2X`("`M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R
M(&UE<W-A9V5S(&9R;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S+@`@("UD+"`M
M+61I<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M<&5N9&EU;2!I;B!T:&ES(&1I
M<F5C=&]R>2X`("`M:"P@+2UH96QP("`@("`@("!3:&]W('1H:7,@:&5L<"!M
M97-S86=E+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E(&]N;'D@=&AI
M<R!L;V-A;&4N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L
M;V-A;&4N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L
M92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($)U:6QD($U/(&9I;&5S(&]N
M;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/
M1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO
M<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!0
M3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M
M+6UO9'5L93U-3T153$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("!'96YE<F%T
M92!03U0@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UN
M+"`M+6YE=R`@("`@("`@("`@("`@5&AI<R!I<R!A(&YE=R!T<F%N<VQA=&EO
M;BP@8V]M;6ET(&%L<V\@0U)%1$E44RP*("`@("`@("`@("`@("`@("`@("`@
M("`@($-(04Y'15,@86YD(&QA;F<N<&AP+F1I<W0@;W(@;FQS+G!H<"YD:7-T
M+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@;65R9V4@;F5W('1R
M86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2X`("`M;BP@+2UN;RUC;VUP
M96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I=6TN`"`@+70L("TM=&5S
M="`@("`@("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T
M(')U;B!A;GET:&EN9RX`("!C;VUM:70@("`@("!#;VUM:70@=')A;G-L871I
M;VYS('1O('1H92!#5E,@<V5R=F5R+@`@(&-O;6UI="UH96QP($-O;6UI="!H
M96QP(&9I;&5S('1O('1H92!#5E,@<V5R=F5R+@`@(&-O;7!E;F1I=6T@(%)E
M8G5I;&0@=&AE(&-O;7!E;F1I=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R
M=W)I=&5S('1H90H@("`@("`@("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2X`
M("!E>'1R86-T("`@("!'96YE<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL
M97,N`"`@:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`("!I
M;FET("`@("`@("!#<F5A=&4@;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@
M;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI<PH@("`@("`@("`@("`@(&]V97)W
M<FET97,@=&AE(&5X:7-T:6YG(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+@`@
M(&UA:V4@("`@("`@($)U:6QD(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S
M<&5C:69I960@4$\@9FEL97,N`"`@;6%K92UH96QP("`@36%R:R!A;&P@96YT
M<FEE<R!I;B!T:&4@6$U,(&AE;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N
M9`H@("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I;&4@9F]R('1H92!N97AT
M(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U"B`@("`@("`@("`@("`@
M<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A
M;F0@<F5V:7-I;F<@=&AE"B`@("`@("`@("`@("`@:&5L<"!F:6QE+@`@(&UE
M<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT(%!/(&9I;&4@=VET:"!T:&4@
M8W5R<F5N="!03R!T96UP;&%T92!F:6QE+@`@('5P9&%T92`@("`@(%)U;B!E
M>'1R86-T(&%N9"!M97)G92!S97%U96YT+@`@('5P9&%T92UH96QP($5X=')A
M8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E;G1R:65S(&9R;VT@=&AE($5N9VQI
M<V@@6$U,(&AE;'`*("`@("`@("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M
M('=I=&@@=&AE(&5X:7-T:6YG(&]N97,N`"`F(S$U,3L@)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@*'1O9&%Y*0`@*'EE<W1E<F1A>2D`
M)60@8GET97,@=W)I='1E;BX`)60@;V8@)60@96YT<FEE<R!M87)K960@87,@
M=7`M=&\M9&%T90`E<R`M($YO=&EC90`E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%-T86YD87)D`"5S(%1E<FUS(&]F($%G
M<F5E;65N=``E<R!I<R!R97%U:7)E9``E<R!N;W0@9F]U;F0N(%)U;B`G=')A
M;G-L871I;VX@97AT<F%C="<@9FER<W0N`"5S)7,@1W5E<W0@4V5R=FEC97,\
M+V$^`"5S5V%R;FEN9SHE<R!4:&ES('!R;V=R86T@=V%S(&]N;'D@=&5S=&5D
M(&]N(&=E='1E>'0@,"XQ,2X@5&AE<F4@:7,@;F\*9W5A<F%N=&5E('1H870@
M:70@=VEL;"!W;W)K('=I=&@@>6]U<B!V97)S:6]N(&]F(&=E='1E>'0N`"5S
M9F]U;F0Z)7,@)7,`)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN`"<E<R<@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES
M=&5M+@`G)7,G('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+@`G)7,G('=A<R!N;W0@8W)E871E9#H@)7,N`"P@=')Y:6YG($,K*R!I;G-T
M96%D`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0`R-"!H;W5R<P`\8CY!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9#H\+V(^`#QB/E1H92!C86QE;F1A
M<B!D871A(&ES(&EN=F%L:60Z/&)R("\^)7,\+V(^`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2P@<')I=F%T92!334E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y+"!P<FEV871E(%--24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!32]030!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO
M;@!!9&0@4W5B+6=R;W5P`$%D9"!3=6(M<&5R;6ES<VEO;@!!9&0@82!C:&EL
M9"!G<F]U<"!T;R`G)7,G`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@)R5S
M)P!!9&0@82!N97<@;65M8F5R`$%D9"!A(&YE=R!U<V5R.@!!9&0@<W5M;6%R
M>0!!9&0@=&AI<R!T;R!M>2!C86QE;F1A<@!!9&0@=&\@;7D@861D<F5S<R!B
M;V]K.@!!9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI
M<W1R871I;VX`061S`$%L:6%S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07)C:&EV92!&:6QE
M(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D
M96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T<FEB=71E<P!!=71H96YT:6-A=&EO;B!F86EL960`075T
M:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`079A:6QA
M8FQE($-O;'5M;G,Z`$%V86EL86)L92!F:65L9',Z`$)A8VME;F0@;F]T(&-O
M<G)E8W1L>2!I;7!L96UE;G1E9"X`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"
M860@:V5R8F5R;W,@=7-E<FYA;64N`$)A<F)I90!":7)T:&1A>0!";VQD`$)O
M;VMM87)K<P!"<F]W;@!"=6=S`$)U:6QD:6YG($U/(&9I;&5S(&9O<B!M;V1U
M;&4@)7,E<R5S+BXN`$)U:6QD:6YG(&QO8V%L92`E<R5S)7,N+BX@`$)U<FYT
M($]R86YG90!#35,`0U)#`$-64P!#86QE;F1A<@!#86UO=69L86=E`$-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&-O;FYE8W0@=&\@
M4E!#('-E<G9E<CH@)7,`0V%N)W0@9V5T('-U;6UA<GD@;&ES="!F<F]M('1H
M92!S97)V97(@)7,Z("5S`$-A;F-E;`!#86YN;W0@<F5M;W9E.R!C:&EL9')E
M;B!E>&ES="`H)7,I`$-E;&P@4&AO;F4`0V5N=&5R960`0VAA;F=E(%!A<W-W
M;W)D`$-H86YG92!Y;W5R('!A<W-W;W)D`$-H86YG:6YG(%!A<W-W;W)D(&]N
M("5S`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A
M;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H96-K8F]O:P!#:&5R<GD`
M0VAO;W-E('1H92!O<F1E<B!O9B!T:&4@<W5M;6%R:65S('1O(&1I<W!L87D@
M:6X@=&AE('-U;6UA<GD@<&%G92X`0VQO<V4@2&5L<`!#;&]S92!(96QP(%=I
M;F1O=P!#;VQO<B!0:6-K97(`0V]M:6-S`$-O;6UA;F0@;W!T:6]N<SH`0V]M
M;6%N9',Z`$-O;6UI='1I;F<Z`$-O;7!A;GD`0V]N9FEG=7)A=&EO;@!#;VYF
M:7)M($YE=R!P87-S=V]R9#H`0V]N9FER;2!087-S=V]R9`!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M=&\@9G1P('-E<G9E<B!F86EL960N`$-O;G-O;&5?1V5T;W!T(&YO="!F;W5N
M9"X`0V]N=&5N=',@;V8@)R5S)P!#;W!Y`$-O<'EI;F<@)7,@=&\@)7,`0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG
M;B!M97-S86=E+@!#;W5L9"!N;W0@4TU)344@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@8FEN9"!T
M;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E
M<@!#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<P!#;W5L9"!N;W0@8W)E871E(&QO
M8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SH`0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%--24U%(&1A=&$N`$-O
M=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R
M97-S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#;W5L9"!N;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"X`0W5T`$1$
M`$1(5$U,(%)I8V@@5&5X="!%9&ET;W(`1&%I;'D`1&%T80!$96-R96%S92!)
M;F1E;G1A=&EO;@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO
M;G,`1&5L971E`$1E;GD`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&ES8W5S<VEO;G,`1&ES<&QA>2!/<'1I;VYS
M`$5D:70`161I="!P97)M:7-S:6]N<R!F;W(@)R5S)P!%9&ET(')E;6]T92!C
M;VYT96YT(&9O<B!T:&4@2&]R9&4@<W5M;6%R>2X`16UA:6P`16UA:6P@061D
M<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UP='D@<F5S=6QT
M+@!%;F0@=&AI<R!R;W<`16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A
M=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;@!%<G)O<@!%<G)O
M<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+@!%<G)O<CH@`$5V97)Y(#$U
M(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E
M<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE
M('9A;'5E<SH`17AE8W5T:6YG.@!%>'1R86-T:6YG(&9R;VT@)7,N+BX@`$9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E
M<G9E<BX`1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9#H@`$9A>`!&:6QE
M($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N
M86=E<@!&:6QE($YA;64`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I
M;'1E<G,`1F]R=6US`$9O<G=A<F1I;F=S`$9O=6YD(&%P<&QI8V%T:6]N<SH@
M)7,`1F]U;F0@9&ER96-T;W)I97,Z`$9U;&P@1&5S8W)I<'1I;VXZ`$9U;&P@
M3F%M90!'971O<'0@17)R;W(Z(`!'<F5E;@!'<F5Y`$=R;W5P($%D;6EN:7-T
M<F%T:6]N`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!'=65S="!397)V:6-E
M<P!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2%144%,@:7,@8W5R
M<F5N=&QY(&YO="!S=7!P;W)T960N`$AE861L:6YE<P!(96QP`$AE;'!E<B!A
M<'!L:6-A=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N
M<R!F;W(@=&AE($AO<F1E"F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N
M<RX*1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I
M;B!T:&ES(&1I<F5C=&]R>2X`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N
M90!(;W)D90!(;W)D92!!9&UI;FES=')A=&EO;@!(;W)D92!I<R!N;W0@<')O
M<&5R;'D@8V]N9FEG=7)E9`!(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(`
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T
M:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@
M0TE$4B!B;&]C:RX`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`26UP;W)T
M($5R<F]R.B!%>'!E8W1E9"`B0D5'24XB(&]N(&QI;F4@)60N`$EM<&]R="!%
M<G)O<CH@17AP96-T960@(D)%1TE.(B!O;B!T:&4@;&EN92`E9"X`26UP;W)T
M($5R<F]R.B!-86QF;W)M960@;&EN92X`26UP;W)T($5R<F]R.B!4>7!E(&UI
M<VUA=&-H+B!%>'!E8W1E9"`B14Y$.B5S(B!O;B!L:6YE("5D+@!);7!O<G0@
M17)R;W(Z(%5N97AP96-T960@96YD(&]F(&9I;&4N`$EM<&]R="!T;R!M>2!C
M86QE;F1A<@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!)
M;F-O<F5C="!087-S=V]R9`!);F-R96%S92!);F1E;G1A=&EO;@!);FET:6%L
M:7II;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@4G5L97(`26YV86QI9"!D871A
M('-U8FUI='1E9"X`26YV86QI9"!R97-P;VYS92!F<F]M('-E<G9E<@!)=&%L
M:6,`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$ME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!,86YG=6%G
M90!,:6=H="!";'5E`$QI<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]G(&EN`$QO9R!O
M=70`3&]G;W5T`$U-`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@
M9&%T82X`36%I;`!-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A
M;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA:VEN9R!D:7)E8W1O
M<GD@)7,`36%P($1A=&4@86YD(%1I;64@1FEE;&1S`$UA<"!);7!O<G0@1FEE
M;&1S`$UA=&-H:6YG(&9I96QD<P!-9&%E;6]N('!A=&@@;F]T(&9O=6YD`$UD
M865M;VX@=7-E<FQI<W0@9FEL92!N;W0@86-C97-S86)L92!O<B!N;W0@9F]U
M;F0N`$UE;6)E<G,`365N=2!M;V1E.@!-97)G:6YG(&%L;"`E<RYP;R!F:6QE
M<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!T:&4@4$\@9FEL92!F
M;W(@)7,E<R5S('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG('1R86YS
M;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BX`365S<V%G90!-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M9"!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE=&AO9`!-971H;V0@)R5S)R!I
M<R!N;W0@9&5F:6YE9`!-:6UE(%1Y<&4`36]D:69I960@1&%T90!-;VYT:&QY
M`$UO=F4@9&]W;B]R:6=H=`!-;W9E('5P+VQE9G0`36]Z:6QL80!->2!!8V-O
M=6YT`$YA;64`3F585`!.971W;W)K`$YE=F5R`$YE=R!5<V5R;F%M92`H;W!T
M:6]N86PI`$YE=R!P87-S=V]R9#H`3F\`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!,1$%0(%!R969E<F5N8V5S
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,($-A=&5G;W)I97,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@4')E9F5R96YC97,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@4V5S<VEO;DAA;F1L
M97(N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344P@5&]K96YS+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!A=71H96YT:6-A=&EO;BX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RX`3F\@96YT<GD@=VET:"!T:&4@:60@)R5S)R!E>&ES=',@:6X@=&AE
M(&]R:6=I;F%L(&AE;'`@9FEL92X`3F\@;&]C86QE('-P96-I9FEE9"X`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!2041)55,@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC
M871I;VXN`$YO('!R969E<F5N8V5S(&%R92!A=F%I;&%B;&4N`$YO('9A;&ED
M(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;W0@86)L92!T;R!C<F5A
M=&4@;&]C:R!F:6QE`$YO="!A8FQE('1O(&-R96%T92!S96UA<&AO<F4@9FEL
M90!.;W0@86)L92!T;R!R971R:65V92!C=7)R96YT(&1E=&%I;',N`$YO=&4Z
M(%EO=2!W:6QL(&YE960@=&\@;&]G;W5T(&%N9"!B86-K(&EN(&%F=&5R('EO
M=2!C:&%N9V4@>6]U<B!P87-S=V]R9"$`3F]T97,`3F]T:6-E`$YO=&EF:6-A
M=&EO;B!L:7-T96YE<B`E<R!N;W0@9F]U;F0N`$]+`$]F9@!/;&0@<&%S<W=O
M<F0Z`$]N`$]P=&EO;G,`3W!T:6]N<SH`3W)A;F=E`$]R9&5R960@3&ES=`!/
M=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!02%`@4VAE;&P`
M4$A0('-U<'!O<G0@:6X@>&=E='1E>'0Z(`!087-S=V]R9`!087-S=V]R9"!C
M:&%N9V5D+@!087-S=V]R9"!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9`!0
M87-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960`4&%S
M<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+@!087-S
M=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@8V%N;F]T(&)E(&)L86YK+@!0
M87-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N<P!097)M:7-S:6]N
M<R!!9&UI;FES=')A=&EO;@!0:&]N90!0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!M;VYT:"P@9&%Y+"!A;F0@>65A
M<BX`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S
M92!R97!O<G0@86YY(&)U9W,@=&\@:3$X;D!L:7-T<RYH;W)D92YO<F<N`%!R
M97-E;G1A=&EO;G,`4')O8FQE;3\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4F%T:6\`4F5A9`!296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2
M969R97-H(%-U;6UA<GD@5FEE=SH`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]T92!S=6UM87)I97,`4F5M;W9E`%)E
M;6]V92!S=6UM87)Y`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D.B``4F5Q=6ER960@)V)A<V5D;B<@;F]T('-P96-I9FEE
M9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M8F%S961N)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("=B9&-?:&]S='-P96,G(&YO="!S<&5C:69I960@
M:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A
M=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN(%-E<W-I;VY(86YD;&5R(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@
M<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I
M9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M9&%T86)A<V4G(&YO="!S<&5C:69I960@:6X@=&]K96X@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)V1O;6%I;B<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT
M:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO
M="!S<&5C:69I960@:6X@4V5S<VEO;DAA;F1L97(@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@
M:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)VAO
M<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN('!R
M969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=H;W-T<W!E8R<@
M;F]T('-P96-I9FEE9"!I;B!T;VME;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I960@:6X@4V5S<VEO;DAA;F1L97(@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF
M:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S<W=O<F0G
M(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G
M;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@
M<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!T;VME;B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G<&1C7VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D
M(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P
M:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%-13"!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!397-S:6]N2&%N
M9&QE<B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P
M96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y
M<&4G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@8V%T
M96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T
M('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!T;VME;B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G<&]R="<@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5I9"<@;F]T('-P96-I9FEE9"!I
M;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=6ED
M)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE9"!I;B!397-S:6]N
M2&%N9&QE<B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U
M<V5R;F%M92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@
M:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA
M;64G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN('1O:V5N
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=V9G-R;V]T)R!N;W0@<W!E8VEF
M:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!2;VQE`%-13"!3:&5L;`!34T@`
M4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<RXN+@!396%R8VAI;F<@9V5T
M=&5X="!B:6YA<FEE<RXN+@!396QE8W0`4V5L96-T(&$@9W)O=7`@=&\@861D
M`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@
M=7-E<B!T;R!A9&0`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.@!396QE8W1E9"!#;VQU;6YS.@!397)V97(`4V5T('EO=7(@<')E
M9F5R<F5D(&1I<W!L87D@;&%N9W5A9V4N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3:&]R="!3=6UM87)Y.@!3:&]W`%-I
M>F4`4VMI<'!E9"XN+@!3;VUE(&]F($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!F
M:6QE<R!A<F4@;6ES<VEN9SH`4V]M92!O9B!087-S=V]R9"=S(&-O;F9I9W5R
M871I;VX@9FEL97,@87)E(&UI<W-I;F<Z`%-P86U!<W-A<W-I;@!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3=6)M:70`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M861D960@)R5S)R!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E
M9"`G)7,G+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`G)7,G(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6X`5&%S:W,`5&5X
M="!/;FQY`%1H92`E<R!H96QP(&9I;&4@9F]R("5S(&1O97-N)W0@>65T(&5X
M:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N`%1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N`%1H92!D971A8VAE9"!334E-12!S:6=N871U<F4@8FQO8VL@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BX`5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\
M/WAM;`!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&]P96YS<VP@
M;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@0W)Y<'1?<VUI;64Z.B!C;&%S
M<RX`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<F5G:7-T<GD@
M:7,@:&]W($AO<F1E(&%P<&QI8V%T:6]N<R!F:6YD(&]U="!H;W<@=&\@=&%L
M:R!T;R!E86-H(&]T:&5R+B!9;W4@<VAO=6QD(&QI<W0@86YY(&EN<W1A;&QE
M9"!(;W)D92!A<'!L:6-A=&EO;G,@=&AA="!Y;W4@:&%V92!H97)E+@!4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`
M5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@
M66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N`%1H97)E(&1O97-N)W0@>65T(&5X:7-T(&$@:&5L
M<"!F:6QE(&9O<B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S
M)R!T;R!T:&4@<WES=&5M+@!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M("<E<R<@9G)O;2!T:&4@<WES=&5M+@!4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG("<E<R<Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G
M97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V%L96YD87(@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@
M=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E
M<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+@!4:&5R92!W87,@
M86X@=6YK;F]W;B!E<G)O<B!V97)I9GEI;F<@=&AI<R!M97-S86=E+@!4:&ES
M(&-A;&5N9&%R(&1A=&$@:&%S(&)E96X@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@<V-H961U;&4N($-L:6-K(&)E;&]W('1O('9I97<Z`%1H:7,@8V]N
M=&%C="!D871A(&AA<R!B965N('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RX@0VQI8VL@8F5L;W<@=&\@=FEE=SH`5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:6QE(&-O;G1R;VQS
M('1H92!G;&]B86P@<V5T(&]F($U)344@9')I=F5R<R!F;W(@=&AE($AO<F1E
M(&9R86UE=V]R:RP@86QL;W=I;F<@87!P;&EC871I;VYS('1O(&UA:V4@=7-E
M(&]F('!R;V=R86US('-U8V@@87,@96YS8W)I<'0@;W(@;7-W;W)D=FEE=R!T
M;R!R96YD97(@8V]N=&5N="!I;G1O($A434P@9F]R('9I97=I;F<@:6X@82!B
M<F]W<V5R+@!4:&ES(&9I;&4@8V]N=')O;',@=&AE('-T>6QE<VAE970@=&AA
M="!I<R!U<V5D('1O('-E="!C;VQO<G,@86YD(&9O;G1S(&9O<B!T:&4@2&]R
M9&4@9G)A;65W;W)K(&%N9"!A;&P@87!P;&EC871I;VYS('1H870@9&\@;F]T
M('!R;W9I9&4@=&AE:7(@;W=N('-E='1I;F=S+@!4:&ES(&9I;&4@;6%P<R!F
M:6QE(&5X=&5N<VEO;G,@=&\@;&]G:6-A;"!-24U%('1Y<&5S+"!E;F%B;&EN
M9R!(;W)D92!A<'!L:6-A=&EO;G,@=&\@9FEG=7)E(&]U="!H;W<@=&\@:&%N
M9&QE('-O;64@8V]N=&5N="!S=6-H(&%S(&5M86EL(&%T=&%C:&UE;G1S(&]R
M($-64R!C:&5C:V]U=',N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"X`5&AI<R!I<R!T:&4@;6%I;B!(;W)D92!C;VYF:6=U<F%T:6]N
M(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N9"!B87-I8R!I=&5M<R!T:&%T
M(&%P<&QY('1O('1H92!C;W)E(&9R86UE=V]R:R!A;F0@86QL($AO<F1E(&%P
M<&QI8V%T:6]N<RX`5&AI<R!I<R!T:&4@;6%I;B!087-S=V]R9"!C;VYF:6=U
M<F%T:6]N(&9I;&4N($ET(&-O;G1A:6YS(&]P=&EO;G,@9F]R(&%L;"!087-S
M=V]R9"!S8W)I<'1S+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@
M9FEL97,N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&EM92!4<F%C
M:VEN9P!4:71L90!54DP`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BX`56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RX`56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O
M8W5M96YT`%5N9&5R;&EN90!5;FMN;W=N(&-O;6UA;F0Z("5S`%5N;W)D97)E
M9"!,:7-T`%5P9&%T90!5<&1A=&4@)7,`57!D871E9"`G)7,G+@!5<&1A=&EN
M9R`E<R!H96QP(&9I;&4@9F]R("5S+@!5<V%G93H`57-E($1E9F%U;'0@5F%L
M=64`57-E<B`E<T`E<R!N;W0@9F]U;F0`57-E<B!!9&UI;FES=')A=&EO;@!5
M<V5R(&YO="!F;W5N9`!5<V5R(&YO="!F;W5N9"X`57-E<FYA;64`57-E<FYA
M;64@86YD+V]R('!A<W-W;W)D(&YO="!C;W)R96-T+@!5<V5R;F%M93H`57-E
M<FYA;64Z(`!5<V5R<P!5<V5R<R!I;B!T:&4@<WES=&5M.@!686-A=&EO;@!6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"X`5V%R;FEN9P!787)N:6YG.B``5V5E:VQY`%=E
M;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`5W)I=&EN9R!U<&1A=&5D(&AE;'`@9FEL92!T;R`E<RX`65D`665A
M<FQY`%EE<P!9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O<B!U<V5R("5S
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&UU<W0@9VEV92!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0`66]U(&UU<W0@9VEV
M92!Y;W5R(&YE=R!P87-S=V]R9`!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T
M92X`66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%EO=7(@16UA
M:6P@061D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($YA;64Z`%EO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!L;VYG.R!P87-S=V]R9',@;6%Y
M(&YO="!B92!M;W)E('1H86X@)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R(&YE
M=R!P87-S=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H86YG
M960A`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@870@;&5A<W0@)60@8VAA
M<F%C=&5R<R!L;VYG(0!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&1I9F9E
M<F5N="!F<F]M('EO=7(@8W5R<F5N="!P87-S=V]R9`!9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%B971I8R!C:&%R
M86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W
M;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!L;W=E<F-A<V4@8VAA<F%C
M=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T
M("5D(&YU;65R:6,@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S
M="!C;VYT86EN(&%T(&QE87-T("5D('5P<&5R8V%S92!C:&%R86-T97)S+@!9
M;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5S<R!T:&%N("5D
M('=H:71E<W!A8V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S
M="!N;W0@8V]N=&%I;B!W:&ET97-P86-E(&-H87)A8W1E<G,N`%EO=7(@;F5W
M('!A<W-W;W)D<R!D:61N)W0@;6%T8V@`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!;;&EN92`E<R!O9B`E
M<UT`86X@97)R;W(@:&%S(&]C8W5R960Z`&1O;F4`9F%I;&5D`&9I;&4`:3$X
M;@!N;W0@9F]U;F0`=&5M<&YA;2@I(&9A:6QE9"$`=&AE($AO<F1E(%!/(&9I
M;&4@9F]R('1H92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z`'5N;F%M960`
M=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!087-S=V0@,BXP+C$M8W9S"E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`R+3`Y+3$T(#`P.C,X+3`T,#`*4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,BTQ,2TQ.2`R,#HT-"TP-3`P"DQA<W0M5')A;G-L
M871O<CH@36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^"DQA
M;F=U86=E+51E86TZ($)'(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R
M<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#
M4#$R-3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`+4TL("TM
M;65S<V%G93U-15-304=%("#(Y^_NZ^?BX.D@\N[BX"#JX/+N(/'Z[N'YY>WH
MY2P@XNSE\?+N(._NY/#@Y^'H\.#Y[O+N("`@\>4N`"`@+6$L("TM861D/49)
M3$4@("`@("`@(,3NX>#BZ"#R[N?H(%!/(/3@Z>L@ZOKL(&-O;7!E;F1I=6TN
M(,_NZ^7G[>X@Y2#O\.@*("`@("`@("`@("`@("`@("`@("`@("`@Y.[AX.+_
M[>4@[>`@8V]M<&5N9&EU;2#N\B#PX.?KZ/?E[2#A\.#M^"#J^NP@[N'Y"B`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;7!E;F1I=6TN`"`@+6(L("TM8F%S
M93TO4$%42"`@S_KKY>T@[_KR(.3N(.'@Y^[BX/+@(.3H\.7J\N[PZ/\@[>`@
M2&]R9&4`("`M8RP@+2UC;VUP96YD:75M/49)3$4@(-'LY?'H(.WNXNCRY2#O
M\.7B[N3H(/$@\N[GZ"!C;VUP96YD:75M(/3@Z>L*+B`@("`@("`@("`@("`@
M("`@("`@("`@("#B[.7Q\NX@\2#O[N3PX.?AZ/#@^>C_\B#QY2`H8V]M<&5N
M9&EU;2YP;R#B"B`@("`@("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R#D
MZ/#EZO+N\.C_+@`@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@R.?O[NOGXN#I
M(/+NY^@@8V]M<&5N9&EU;2#TX.GK(.+L9?'R[B`*("`@("`@("`@("`@("`@
M("`@("`@("`@(._NY/#@Y^'H\.#YZ/_R(/'E(&-O;7!E;F1I=6TN<&\@XB!H
M;W)D92]P;RX`("`M9"P@+2UD96)U9R`@("`@(,_NZN#GXN#I(/'Z[N'YY>WH
M__+@(.?@(./PY?CJZ"#N\B#HY^_ZZ^WE[>CRY2`@("`@("`@("`@("`@("`@
M("`@("`@("`@(/3@Z>ONXN4N`"`@+60L("TM9&ER96-T;W)Y/41)4B`@(-'Z
MY^3@Z2!C;VUP96YD:75M(.(@\N#GZ"#DZ/#EZO+N\.C_+@`@("UH+"`M+6AE
M;'`@("`@("`@(,_NZN#FZ"#R[N+@(._N[.[Y[>X@\?KNX?GE[>CE+@`@("UL
M+"`M+6QO8V%L93UL;%]#0R`@("`@R.?O[NOGXN#I(/'@[.X@\N[BX"#K[NK@
MZ^CGZ/#@[>4N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("#(Y^_NZ^?BX.D@
M\N[BX"#K[NK@Z^CGZ/#@[>4N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@(,CG
M[^[KY^+@Z2#R[N+@(.ONZN#KZ.?H\.#MY2X`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@(,KN[._HZ^CPX.D@34\@].#IZ^[BY2#QX.SN(.?@(/+NY^@@[.[D
M\^LN`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("#(Y^_PX/+H(._PY>+NY.@@
M\>#L[B#GX"#R[N?H(.SNY//K+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@
MT>SE\>@@4$\@].#IZ^[BY2#QX.SN(.?@(/+NY^@@[.[D\^LN`"`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("#.[_#E\>WH(._N[.[Y[>CRY2#TX.GK[N+E(/'@
M[.X@Y^`@\N[GZ"#L[N3SZRX`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(,[O
M\.7Q[>@@\>#L[B#R[N?H(.SNY//K+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("#1^N?DX.D@4$\@].#IZR#QX.SN(.?@(/+NY^@@[.[D\^LN`"`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@P^7MY?#H\.#I(%!/5"#TX.GK(/'@[.X@Y^`@\N[G
MZ"#L[N3SZRX`("`M;BP@+2UN97<@("`@("`@("`@("`@("#2[N+@(.4@[>[B
M(._PY>+NY"P@Z.?O\.#RY?+E(/'Z^>X@0U)%1$E44RP@0TA!3D=%4PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("#H(&QA;F<N<&AP+F1I<W0@Z.OH(&YL
M<RYP:'`N9&ES="X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@(,WE(/'LY?'B
MX.D@[>[BZ"#O\.7B[N3H(.KZ["!C;VUP96YD:75M+@`@("UN+"`M+6YO+6-O
M;7!E;F1I=6T@("`@S>4@Z.?O[NOGXN#I(&-O;7!E;F1I=6TN`"`@+70L("TM
M=&5S="`@("`@("`@S^[JX.?BX.D@Z.?O^NOMY>WH\N4@ZN[LX.WDZ"P@[>X@
M[>4@Z.?O^NOM_^+@Z2#MZ/GN`"`@8V]M;6ET("`@("`@R.?O\.#RZ"#O\.7B
M[N3H\N4@XB!#5E,@\?KPXOKP+@`@(&-O;6UI="UH96QP(,CG[_#@\N@@[^[L
M[OGMZ/+E(/3@Z>ONXN4@XB!#5E,@\?KPXOKP`"`@8V]M<&5N9&EU;2`@R.?C
M\.#DZ"#MX.WNXNX@8V]M<&5N9&EU;2#TX.GKX"X@PNWH[.#MZ.4Z(/+NXN`@
M^>4@Y^#KZ/?H"B`@("`@("`@("`@("`@(/+EZO/YZ/\@8V]M<&5N9&EU;2X`
M("!E>'1R86-T("`@("##Y>WE\.CPX.D@4$\@^.#AZ^[MY>T@*"YP;W0I(/3@
MZ>LN`"`@:&5L<"`@("`@("`@S^[JX.;H(/+NXN`@[^[L[OGM[B#Q^N[A^>7M
MZ.4N`"`@:6YI="`@("`@("`@T?KGY.#I(.7DZ.T@Z.OH(._NXN7WY2!03R#T
MX.GKX"#GX"#M[N+@(.ONZN#KZ.?@]NC_+L+MZ.S@[>CE.@H@("`@("`@("`@
M("`@(/+NXN`@^>4@[^[J\.CE(/'Z^>7Q\N+SXN#YZ/+E(%!/(/3@Z>ONXN4@
MY^`@\N#GZ"#K[NK@Z^CGX/;H_RX`("!M86ME("`@("`@("#*[NSOZ.OH\.#I
M(.'H[>#P[>@@34\@].#IZ^[BY2#N\B#GX.3@Y.7MZ/+E(%!/(/3@Z>ONXN4N
M`"`@;6%K92UH96QP("`@S.#PZNCPX.D@XO'H]^KN(.(@6$U,(._N[.[Y[>C_
M\B#TX.GK(.K@\NX@[N_PY?'MY>WH(.@@"B`@("`@("`@("`@("`@[^[DX^[R
MXN@@].#IZ^`@Y^`@\>OEY.+@^>X@Z.?O^NOMY>WHY2#MX"!U<&1A=&4M:&5L
M<`H@("`@("`@("`@("`@(,WE[N'U[N3H[.X@Y2#DX"#Q\N#P\NCPX/+E(&UA
M:V4M:&5L<"#1P,S.(/'KY>0@=7!D871E+6AE;'`@Z`H@("`@("`@("`@("`@
M(.@@\.7DX.KRZ/#@[>4@[>`@:&5L<"#TX.GKX"X`("!M97)G92`@("`@("#1
M[.7QXN#MY2#MX"#RY>KS^2!03R#TX.GK(/$@\N7J\_D@4$\@^.#AZ^[MY>T@
M].#IZRX`("!U<&1A=&4@("`@("#(Y^_ZZ^WH(&5X=')A8W0@Z"!M97)G92#O
M[O'KY>3NXN#RY>OM[BX`('5P9&%T92UH96QP(,7J\?+PX.KR(.W@(.+QZ/?J
MZ"#M[N+H(.@@[_#N[.7MY>WH(/#EY.[BY2#N\B!%;F=L:7-H(%A-3"!H96QP
M"B`@("`@("`@("`@("`@].#IZR#H(./H(/'LY?'H(/'Z\2#Q^OGE\?+B\^+@
M^>CRY2X`("8C,34Q.R`E<R#E(./N\N[B(.?@(.CGXOKP^.+@[>4@[>`@Z.?A
M\.#MZ/+E(.[OY?#@]NCH(._N(.[A\>OSYN+@[>7R[BX`("@E<R#D[>@@[>#G
MX.0I`"`HY.WE\2D`("CB]^7PX"D`)60@Y^#OZ/'@[>@@X>#I\N`N`"5D(.[R
M("5D(.S@\.KH\.#MZ"#JX/+N(.[O\.7Q[>7MZ``E<R`M(,?@X>7KY>;JX``E
M<R#.X?'K\^;BX/GH(.[OY?#@]NCH("T@S^[RXOKPYN3E[>CE`"5S(-'RX.WD
MX/#R`"5S(-/QZ^[BZ/\@[^X@T>_N\.#G\^SE[>CE\NX`)7,@[>7NX?7NY.CL
M`"5S(.WE(.4@[>#LY?#E[2X@R.?O^NOMY?+E("=T<F%N<VQA=&EO;B!E>'1R
M86-T)P`E<R5S(-/QZ_/CZ"#GX"#C[O'RZ#POX#X`)7/"[>CLX.WHY3HE<R#2
MX.?H(._P[N/PX.S@(.4@\N7Q\N+@[>`@\>#L[B#Q(&=E='1E>'0@,"XQ,2X@
MS?_LX"#CX/#@[?;H_RP*]^4@^>4@\.#A[O+H(/$@XN#XX/+@(.+E\/'H_R#M
MX"!G971T97AT`"5S[>#LY?#E[3HE<R`E<P`G)7,G(.WE(.4@ZN[M].CC\_#H
M\.#M(.(@2&]R9&4@4F5G:7-T<GDN`"<E<R?AY?CE(.3NX>#BY>W@(.KZ["#C
M\//OZ/+E+@`G)7,G(.'E^.4@Y.[AX.+E[2#J^NP@\>CQ\N7LX/+@(.?@(._P
MX.+@(.W@(._N\O#EX>CRY>OH\N4N`"<E<R?MY2#AY?CE(/'ZY^3@Y.7M.B`E
M<RX`+"#N[^CR(/'Z\2!#*RL`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M`#(T(/?@\>``/&(^S>7O\.7NY.[KZ.S@(./PY?CJX#H\+V(^`#QB/L3@[>WH
M\N4@Y^`@ZN#KY>WDX/#@(/'@(.WEXN#KZ.3MZ#H\8G(@+SXE<SPO8CX`Q^`@
MY.`@ZO#H[_+H\.#RY2#OZ/'L[B#E(.WE[N'U[N3H["#O\^'KZ/?E[2!01U`@
MZNO^]RX`Q^`@Y.`@[_#NXN7PZ/+E(._NY._H\>#M[B#OZ/'L[B#E(.WE[N'U
M[N3H["!01U`@ZNO^]RX`Q^`@Y.`@Y.7J\.CO\NCPX/+E(._H\>SN(/'@(.WE
M[N'U[N3H[.@Z(._SX>OH]^7M(.KK_O<L(.OH]^7M(.KK_O<@Z"#JZ_[W[N+@
M(/3PX.?@+@#'X"#DX"#O[N3OZ/CE\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@
M[_/AZ^CWY>T@ZNO^]RP@Z^CWY>T@ZNO^]R#H(.KK_O?NXN`@]/#@Y^`N`,?@
M(.3@(.KPZ._RZ/#@\N4@[^CQ[.X@Y2#MY>[A]>[DZ.P@[_/AZ^CWY>T@4TU)
M344@ZNO^]RX`Q^`@Y.`@[_#NXN7PZ/+E(._NY._H\>#M[B#OZ/'L[B#E(.WE
M[N'U[N3H["#O\^'KZ/?E[2!334E-12#JZ_[W+@#'X"#DX"#DY>KPZ._RZ/#@
M\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@4TU)344@ZNO^]RP@
MZ^CWY>T@4TU)344@ZNO^]R#H(.KK_O?NXN`@]/#@Y^`N`,?@(.3@(._NY._H
M^.7RY2#OZ/'L[B#QX"#MY>[A]>[DZ.SH.B#O\^'KZ/?E[2!334E-12#JZ_[W
M+"#KZ/?E[2!334E-12#JZ_[W(.@@ZNO^]^[BX"#T\.#GX"X`04TO4$T`Q.[A
MX.+_[>4@[>`@[>[BX"#C\//OX`#$[N'@XO_MY2#MX"#M[N+H(._PX.+@`,3N
MX>#B_^WE(.W@(._NY"#C\//OX`#$[N'@XN@@[^[D+>_PX.+@`,3NX>#BZ"#M
MX/'KY>3E[>`@X_#S[^`@ZOKL("<E<R<`Q.[AX.+H(.W@\>OEY.7MZ"#O\.#B
MX"#J^NP@)R5S)P#$[N'@XN@@[>[B(/?KY>T`Q.[AX.+H(.WNXB#O[O+PY>'H
M\N7K.@#$[N'@XN@@\.7G_NSE`,3NX>#BZ"#R[N+@(.KZ["#L[O\@ZN#KY>WD
MX/``Q.[AX.+H(.KZ["#L[O_RX"#@Y/#E\>W@(.KMZ./@.@#$[N'@XO_MY2#M
MX"#M[N+H(/3@Z>ONXN4@ZOKL(/7PX.WHZ^CYY?+N.@#$[N'@XO_MY?+N(.W@
M(._N\O#EX>CRY>OH(.4@Y^#A\.#MY>WN+@#`Y/#E\0#`Y/#E\>7M(.'EZ^7F
M[>CJ`,#D[.CMZ/'R\.CPX.WE`,3NX>#BZN@`S_'EXN3N[>CL`,+QZ/?JZ"#C
M\//OZ`#"\>CWZN@@[_#@XN``POKBY>3E[>#RX"#Q\N[I[>[Q\B#MY2#E(.3N
M[_/Q\NCLX"X`T.#G[.7P(.W@(.#P]>CB[>C_(/3@Z>L`R.SE(.W@(.#P]>CB
MX`#1Z./S\.WH(.OH(/'RY2P@]^4@Z/'JX/+E(.3@(.CG\O#HY?+E("<E<R<@
MZ"#B\>CWZN@@[^[DX_#S[^@_`-'HX_/P[>@@Z^@@\?+E+"#WY2#H\>K@\N4@
MY.`@Z.?R\.CE\N4@)R5S)R#H(.+QZ/?JZ"#O[N3O\.#BX#\`Q.`@\>4@Z/'J
MX"#KZ"#O[O+B^O#FY.7MZ.4@[_#EY.@@[N'QZ_/FXN#YZ/+E(.[OY?#@]NCH
M/P##\.7XZN`@[_#H(.CG\O#HXN#MY2#MX"#MY?'Z^>7Q\N+SXN#YX"#C\//O
MX"X`P_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>4@[>7Q^OGE\?+B\^+@^>@@[_#@
MXN`N`,/PY?CJX"#O\.@@\.7DX.KRZ/#@[>4@[>`@[>7Q^OGE\?+B\^+@^>@@
M[_#@XN`N`,#R\.CA\_+H`,/PY?CJX"#O\.@@Z.3E[?+H].CJX/;H_P#(Y.7M
M\NCTZ.K@]NC_\N`@X>7XY2#N\O7B^O#KY>W@(.[R(%)!1$E54R#Q^O#B^O#@
M+@#-X.OH]^WH(.KNZ^[MZ#H`S>#KZ/?MZ"#O[NOE\N`Z`,+QY2#N^>4@[>4@
MY2#D[N'PY2#PX.?PX.'N\N7M[BXN+@#-Y>+@Z^CD[>`@:V5R8F5R;W,@(._@
M\.[KX"X`S>7BX.OHY.WN(&ME<F)E<F]S(._N\O#EX>CRY>OQZNX@Z.SE+@!"
M87)B:64`T.[FY.7M(.3E[0#3Y.7AY>OE[>@`SO+LY?+JZ`!"<F]W;@#!^N/N
MXN4`RN[L[^CKZ/#@Z2!-3R#TX.GK[N+E(.?@(.SNY//K("5S)7,E<RXN+@#*
M[NSOZ.OH\.#MY2#MX"#K[NK@Z^CGX/;H_R`E<R5S)7,N+BX`0G5R;G0@3W)A
M;F=E`$--4P!#4D,`0U93`,K@Z^7MY.#P`$-A;6]U9FQA9V4`P_#E^.K@(._P
MZ"#QXOKPY^+@[>4@\2#LY>GK(/'Z\.+Z\#H@)7,`P_#E^.K@(._PZ"#QXOKP
MY^+@[>4@\2!24$,@\?KPXOKP.B`E<P##\.7XZN`@[_#H(.CG\N7CZ__MY2#M
MX"#NX>[A^>7MZ/\@\>_H\?KJ(.[R(/'Z\.+Z\.`@)7,Z("5S`,[RZN#FZ`##
M\.7XZN`@[_#H(._PY>S@]>+@[>4[("@E<RD@XN7WY2#Q^OGE\?+B\^+@`,SN
MX>CKY>T@\N7KY?3N[0#6Y>WR\.CPX.T`T>S_[>`@[>`@[^#P[NO@\N``T>S_
M[>`@[>`@[^#P[NO@\N`@PN@`S_#NX>OE["#O\.@@\>S_[>`@[>`@[^#P[NO@
M\N`@[>`@)7,`R.?AY?#E\N4@[N_E\.#VZ.CRY2P@ZN[I\NX@Z/'JX/+E(.3@
M(.CGXOKP^.CRY2#QY>/@+@!#:&5C:V)O;VL`0VAE<G)Y`,CGX>7PY?+E(/#E
MY.`@[>`@[^[JX.?BX.WE(.W@(.CGXNOE]^7MZ/_RX"#B(/#EY_[LY2#Q\O#@
M[>CVX/+@+@#'X/+B[O#H(,_N[.[Y`,?@\N+N\.@@[_#NY^[PY?8@(L_N[.[Y
M(@#(Y^'H\.#MY2#MX"#VXO_R`,KN[.CJ\>@`RN[LX.WD[>@@[N_VZ.@Z`,KN
M[.#MY.@Z`,CG[_#@^>#MY3H`RN[L[^#MZ/\`RN[M].CC\_#@]NC_`,_N\N+Z
M\.3E\N4@[>[BX/+@(._@\.[KX#H`S^[RXOKPY.7RY2#OX/#NZ^#RX`#$[O'R
M^N_@(.3N(._SX>OH]^WH_R#Q^O#B^O`@X>7XY2#N\NK@Y^#M+@#"\/KGZN#R
MX"#Q^O$@1E10(/'Z\.+Z\.`@\>4@[_#NXN#KZ"X`0V]N<V]L95]'971O<'0@
M[>4@Y2#MX.SE\.7M+@#1^N3Z\.;@[>CE(.W@("<E<R<`RN[OZ/#@Z0#J[N_H
M\.#MY2#MX"`E<R#N\B`E<P##\.7XZN`@[_#H(%!'4"#J\.CO\NCPX.WE\NX@
M[>`@[^CQ[.XN`,/PY?CJX"#O\.@@4$=0(._NY._H\>+@[>7R[B#MX"#OZ/'L
M[BX`P_#E^.K@(._PZ"!334E-12#J\.CO\NCPX.WE\NX@[>`@[^CQ[.XN`,/P
MY?CJX"#O\.@@4TU)344@[^[D[^CQXN#MY?+N(.W@(._H\>SN+@#-Y>+ZY^SN
MYNWN\?(@Y^`@XO#ZY^K@(/$@3$1!4"#Q^O#B^O#@`,WEXOKG[.[F[>[Q\B#G
MX"#B\/KGZN`@\2!,1$%0(/'Z\.+Z\`#-Y>+ZY^SNYNWN\?(@Y.`@\>4@ZN[O
MZ/#@("5S(/+N("5S+@##\.7XZN`@[_#H(/'ZY^3@XN#MY2#MX"#K[NK@Z^W@
M(.3H\.7J\N[PZ/\@Y^`@Z^[JX.OHY^#VZ/\@)7,`P_#E^.K@(._PZ"#DY>KP
MZ._RZ/#@[>7R[B#MX"!01U`@Y.#M[>@N`,/PY?CJX"#O\.@@Y.7J\.CO\NCP
MX.WE\NX@[>`@4TU)344@Y.#M[>@N`,WEZN[PY>KRY>T@96UA:6P@X.3PY?$@
M[>`@[^[K\_?@\N7K_RX`P_#E^.K@(._PZ"#O[NOS]^#BX.WE\NX@[>`@[_/A
MZ^CW[>C_(.KK_O<@[O(@ZNO^]RWQ^O#B^O#@+@#-Y>+ZY^SNYNWN\?(@Y.`@
M\>4@[O+B[O#H(,[A\>OSYN+@^>A?Y^#DX/?H(.SNY//K("5S(`#-Y>+ZY^SN
MYNWN\?(@Y.`@\>4@[O+B[O#H(.K@[>#K(.3N('-M8G!A<W-W9"X`Z.?PY>;H
M`,3$`$1(5$U,(%)I8V@@5&5X="#PY>3@ZO+N\`#%YN7D[>7B[>X`Q.#M[>@`
MS>#LX.OH(//EY.W@ZN+_XN#MY?+N`,CDY>WRZ/?M[O'R(._N(._NY/#@Y^'H
M\.#MY0#/\.#BX"#O[B#O[N3PX.?AZ/#@[>4`R.?R\.CI`,?@X?#@[>@`Q.7R
MX.GKZ/+E(.'_]>`@\.7CZ/'R\.CPX.WH(.?@(.#D[.CMZ/'R\.#R[O#@+@#$
MZ/'J\_'HZ`#$Z/'OZ^7I(,[O]NCH`-#EY.#J]NC_`-#EY.#J]NC_(.W@(._P
MX.+@\N`@Y^`@)R5S)P#0Y>3@ZO;H_R#MX"#MY>ONZN#K[>[R[B#Q^N3Z\.;@
M[>CE(.?@(.[A[N'YY>WHY?+N(.W@($AO<F1E+@#/Z/'L[@#%;6%I;"#@Y/#E
M\0!%;6%I;"#@Y/#E\>CRY2#R\/_AXN`@Y.`@\?KB[^#DX/(N`,_PX.?E[2#P
MY>?SZ_+@\BX`RO#@Z2#MX"#PY>3@`-#EY.[BY3H@)60@[N'Y[BP@)60@[N_P
MY?'MY>WH+"`E9"#M[N+H+"`E9"#O\.[LY>WE[>@L("5D(.WEZ.?BY?'R[>@`
MP_#E^.K@`,/PY?CJX"#O\.@@Z.?O\.#YX.WE(.W@(.3@[>WH(.3N('-M8G!A
M<W-W9"X`P_#E^.K@`,+QY>KH(#$U(.SH[?/RZ`#"\>7JZ"`S,"#QY>KS[>3H
M`,+QY>KH(#4@[.CM\_+H`,+Q_^KN(.ONX^+@[>4`S>`@XO'EZN@@[^[K[N+H
M[2#WX/$`PO'_ZN`@[.CM\_+@`,_PZ.SE\.WH(/'R[NGM[O'RZ#H`R.?O^NOM
M_^+@[>4@[>`Z`,7J\?+PX.KR(.[R("5S("XN+@#-Y>+ZY^SNYNWN\?(@Y.`@
M\>4@Y^#PY>3_\B#O\.7TY?#E[?;HZ/+E+@#-Y>+ZY^SNYNWN\?(@Y.`@\>4@
M[O'Z^>7Q\N+H(.+P^N?JX"#Q($Q$05`@\?KPXOKP+@##\.7XZN`@[_#H(/'B
M^O#GXN#MY2#Q^O$@4TU"(/'Z\.+Z\"X`S_#NX>OE["#O\.@@\>S_[>`@[>`@
M[^#P[NO@\N`@.@#4X.KQ`,'P[ND@].#IZ^[BY3H@)7,@].#IZP#!\.[I(/3@
MZ>ONXN4Z("5S(/3@Z>O@`-3@Z>L@[.7MX.;E\`#([.4@[>`@].#IZP#(Y^_P
MX/G@[>7R[B#MX"#TX.GK[N+E(.WE(/'E(._NY.3Z\.;@+@#4Z.OR^O``U.[P
M\^SH`,_PY>_PX/G@[>C_`,W@[.7PY>WH(._PZ.ONYN7MZ/\Z("5S`,W@[.7P
MY>WH(.3H\.7J\N[PZ.@Z`,_ZZ^WN(.[OZ/'@[>CE.@#([.4@[>`@].#IZP!'
M971O<'0@X_#E^.K@.B``1W)E96X`1W)E>0#`Y.SH[>CQ\O#H\.#MY2#MX"#C
M\//OZ`##\//OZ`#/\.#BX"#GX"#C[O'RZ`#3\>OSX^@@Y^`@X^[Q\N@`2%14
M4"#HY.7M\NCTZ.K@]NC_(.WE(.4@[>#LY?#E[>`N`$A45%!3(.WE(/'E(._N
MY.3Z\.;@+@#'X./KX.+H_P#/[NSN^0#/[NSN^>WN(._PZ.ONYN7MZ.4@Y^`@
M\?KGY.#BX.WE(.W@(._PY>+NY.@@Y^`@2&]R9&4*Z"#Q^N_Z\O'RXN#YZ/+E
M(._PZ.ONYN7MZ/\N(,?@(.+ZXN7DY>WHY2#O\.[WY?+E\N4@4D5!1$U%(.(@
M\N#GZ"#DZ/#EZO+N\.C_+@#-X/?@Z^X`Q.[LX/CE[2#@Y/#E\0#$[NS@^.7M
M(/+EZ^7T[NT`2&]R9&4`2&]R9&4@P.3LZ.WH\?+PZ/#@[>4`2&]R9&4@[>4@
MY2#J[NWTZ./S\.CPX.T@ZN[PY>KR[>X`2&]R9&4@X^7MY?#@\N[P(.W@(._P
MY>+NY.@`P_#E^.K@(._PZ"#Q^N?DX.+@[>4@[>`@24U!4"#O[OGE[?'JX"#J
M\_+H_SH@)7,`P_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@24U!4"#O[OGE[?'J
MX"#J\_+H_SH@)7,`P_#E^.K@(._N\.#DZ"#JXN[RX"#O\.@@\?KGY.#BX.WE
M(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S`$E0(.#D\.7QX"#MY2#E(.(@
M[^[GXN[KY>WH_R!#2412(.'K[NHN`-'@[.X@Z.KN[>@`R.KN[>@@\2#RY>KQ
M\@##\.7XZN`@[_#H(.CL[^[P\CH@SO?@ZN+@(/'E(")"14=)3B(@[>`@\.7D
M("5D+@##\.7XZN`@[_#H(.CL[^[P\CH@SO?@ZN+@(/'E(")"14=)3B(@XB#P
MY>3@("5D+@##\.7XZN`@[_#H(.CL[^[P\CH@R^[X[B#T[O#LX/+H\.#M(/#E
MY"X`P_#E^.K@(._PZ"#H[._N\/(Z(,WEZN[PY>KRY>T@\NCO+B#.]^#JXN#M
M(")%3D0Z)7,B(.W@(/#EY"`E9"X`P_#E^.K@(._PZ"#H[._N\/(Z(,WE[O?@
MZN+@[2#J\.#I(.W@(/3@Z>O@+@#([._N\/+H\.#I(.(@[.[_(.K@Z^7MY.#P
M`,CL[^[P\NCPX.WN(._NZ^4Z("5S`,CL[^[P\NCPX.WH(._NZ^7RX#H`S>7J
M[O#EZO+MX"#OX/#NZ^``T^+EZ^CWX.+@[>4@[>`@\^7D[>#JXO_BX.WE\NX`
MR.WH]NC@Z^CGZ/#@[>4@[>`@[.[D\^L@)7,N+BX`PNSZZNWH(._NY/#@XNWH
M\N7K`,CG[_#@\N7MZ/+E(.3@[>WH(/'@(.WEXN#KZ.3MZ"X`S>7BX.OHY.7M
M(.[RX^[B[O`@[O(@\?KPXOKPX`#-X.KK[NWE[>@`[_KK[>X@[^[D\.#B[?_B
MX.WE`.O_XNX@[^[D\.#B[?_BX.WE`.3_\>WN(._NY/#@XNW_XN#MY0!+97)B
M97)O<R#Q^O#B^O#@(.[R]>+Z\.OH(.CDY>WRZ/3HZN#VZ/_RX"X`RNO^]^`@
MXN7WY2#Q^OGE\?+B\^+@(.(@[_/AZ^CW[>C_(.KK_O?Q^O#B^O`N`,7GZ.H`
M3&EG:'0@0FQU90#/[NSN^2#RY>SH`-'OZ/'ZZN`@\2#O[O+PY>'H\N7KZ"#E
M(.?@X?#@[>7M+@#GX/#EYN3@[>4@[>`@X>CAZ^CN\N7JZ/+E+BXN`,+U[N0`
MR.?U[N0`R.?U[N0`S,P`35,M5$Y%1B#O\.CJ\.7OY>WH__(@].#IZR#MY2#Q
M^N3Z\.;@^.4@Y.#M[>@N`,_N^>``T^+E\.7RY2#QY2P@]^4@Z.S@\N4@4$5!
M4B#H[?'RX.OH\.#M(.@@Y.[Q\OKOY>TN`-'ZY^3@XN#MY2#MX"#DZ/#EZO+N
M\.C_("5S`-'ZXN_@Y.#YZ"#$X/+@(.@@U^#Q(,_NZ^7RX`#1^N+OX.3@^>@@
MR.SO[O#R(,_NZ^7RX`#1^N+OX.3@^>@@[^[KY?+@`,_Z\O_R(.3N($UD865M
M;VX@[>4@Y2#MX.SE\.7M`$UD865M;VX@].#IZR#Q(._N\O#EX>CRY>OH(.WE
M(.4@Y.[Q\OKOY>T@Z.OH(.WE(.'E^.4@[>#LY?#E[2X`U^OE[>[BY0#"Z.0@
M[>`@[.7M_O+N.@#1[.7QXN#MY2#MX"#B\>CWZN@@)7,N<&\@].#IZ^[BY2#B
M(&-O;7!E;F1I=6TN+BX`T>SE\>+@[>4@[>`@4$\@].#IZ^[BY2#GX"`E<R5S
M)7,@XB!C;VUP96YD:75M+BXN`-'LY?'BX.WE(.W@(._PY>+NY.CRY2#GX"#L
M[N3SZR`E<RXN+@#/Z/'L[@#/Z/'L[O+N(.'E^.4@[_#NXN7PY>WN(//Q[^7X
M[>XL(.WN(/'E\/+H].CJX/+@(.W@(._NY._H\>`@[>4@X>7XY2#O[O+B^O#D
MY>TN`,SE\N[D`,SE\N[D("<E<R<@[>4@Y2#DY?3H[>CPX.T`36EM92#RZ.\`
MQ.#RX"#MX"#O\.[LY>W_[>4`S.7QY??M[@#O\.7LY?'RZ"#MX"#D[NOS+^3_
M\>WN`._PY>SE\?+H(.W@(./N\.4OZ__B[@!-;WII;&QA`,SN__+@(,_N^>``
MR.SE`$YE6'0`S/#EYN``S>CJ[N/@`,WNXNX@[^[R\.7AZ/+EZ_'J[B#H[.4@
M*.[O]NCN[>#K[>XI`,WNXN`@[^#P[NO@.@#-Y0#-_^S@(.?@Y.#DY>W@(.KN
M[?3HX_/PX/;H_R#GX"!&5%`@5D93+@#-_^S@(.?@Y.#DY>W@(.KN[?3HX_/P
MX/;H_R#GX"!,1$%0(._PY?3E\.7M]NCH+@#-_^S@(.KN[?3HX_/PX/;H[NWM
MX"#H[?3N\.S@]NC_(.?@(%-13"#JX/+EX^[PZ.CRY0#-_^S@(.KN[?3HX_/P
MX/;H[NWMX"#H[?3N\.S@]NC_(.?@(%-13"#O\.7TY?#E[?;HZ"X`S?_LX"#G
MX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,(%-E<W-I;VY(86YD;&5R+@#-
M_^S@(.?@Y.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!344P@5&]K96YS+@#-_^S@
M(.?@Y.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!344P@5D93+@#-_^S@(.KN[?3H
MX_/PX/;H[NWMX"#H[?3N\.S@]NC_(.?@(%-13"#HY.7M\NCTZ.K@]NC_+@#-
M_^S@(.?@Y.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!344PM1FEL92!61E,N`,W_
M[.`@\.7D(/$@\N[BX"!I9"`G)7,G(.(@[O#HX^CMX.OMZ/\@:&5L<"#TX.GK
M+@#-_^S@(.?@Y.#DY>W@(.ONZN#KZ.?@]NC_+@#-_^S@(.?@Y.#DY>W@(._@
M\.[KX"#GX"!)34%0(.CDY>WRZ/3HZN#VZ/\N`,W_[.`@Y^#DX.3E[>`@[^#P
M[NO@(.?@($ME<F)E<F]S(.CDY>WRZ/3HZN#VZ/\N`,W_[.`@ZN[M].CC\_#@
M]NCN[>W@(.CM].[P[.#VZ/\@Y^`@3$1!4"#HY.7M\NCTZ.K@]NC_+@#-_^S@
M(.KN[?3HX_/PX/;H[NWMX"#H[?3N\.S@]NC_(.?@(%)!1$E54R#HY.7M\NCT
MZ.K@]NC_+@#-_^S@(.KN[?3HX_/PX/;H[NWMX"#H[?3N\.S@]NC_(.?@(%--
M0B#HY.7M\NCTZ.K@]NC_+@#-_^S@(.W@Z^CW[>@@[_#E].7PY>WVZ.@N`,+Z
M\.W@\NCRY2#DX.WMZ"#MY2#QX"!834P`S?_LX"#Q\N[I[>[Q\N@`S>7B^N?L
M[N;M[O'R(.3@(/'E(/'ZY^3@Y.4@Y^#JZ_[WXN#Y("AL;V-K*2#TX.GK`,WE
MXOKG[.[F[>[Q\B#DX"#QY2#Q^N?DX.3E(/'E[.#T[O#E[2#TX.GK`,WEXOKG
M[.[F[>[Q\B#DX"#QY2#HY_+EX^O_\B#RY>KS^>CRY2#DY?+@Z>OH+@#-Y>[A
M]>[DZ.SN(.4@Y.`@Z.?KY>?E\N4@Z"#BZ^7GY?+E(.[R[>[B[B#Q(.WNXN#R
MX"#OX/#NZ^`L(/'KY>0@\>S_[>#RX"#I(0#!Y>OEYNKH`-'Z[N'YY>WHY0#1
MZ_/XX/+EZ__R("5S(.WE(.4@[>#LY?#E[2X`SLH`R.?JZRX`T?+@\.`@[^#P
M[NO@.@#"ZNLN`,[O]NCH`,[O]NCH.@!/<F%N9V4`S^[D\.7DY>T@\>_H\?KJ
M`,3P\^/@(.CM].[P[.#VZ/\`S_#@XN`@[>`@[_#H\N7FX/+EZ_\`4$=0(%-H
M96QL`%!(4"#O[N3D\/KFZN`@XB!X9V5T=&5X=#H@`,_@\.[KX`#/X/#NZ^#R
MX"#AY?CE(/'LY>WE[>`A`%!A<W-W;W)D(.WE(.4@ZN[M].CC\_#H\.#M(._P
MX.+HZ^WN`,SNY//K^O(@Y^`@[^#P[NOH(.WE(.4@ZN[M].CC\_#H\.#M(._P
MX.+HZ^WN`,SNY//K^O(@Y^`@[^#P[NOH(.WE(.4@ZN[M].CC\_#H\.#M(._P
MX.+HZ^WN+@#/X/#NZ^`Z`,_@\.[KX#H@`,_@\.[KX/+@(.WE(.SNYN4@Y.`@
MY2#O\.#G[>`N`,WEZN[PY>KR[>`@[^#P[NO@+@#"[/KJ[>@`Q.`@\>4@Z.?B
M^O#XXN#R(.OH(.[A\>OSYN+@^>CRY2#N[^7PX/;HZ"#O\.@@PO7NY#\`S_#@
MXN``P.3LZ.WH\?+PZ/#@[>4@[>`@[_#@XN#RX`#2Y>OE].[M`,SNZ_\L(.+Z
MXN7DY?+E(.SE\>7V(.@@X^[DZ.W@+@#,[NO_+"#B^N+EY.7RY2#LY?'E]BP@
MY.7M(.@@X^[DZ.W@+@#,[NO_+"#O\.[WY?+E\N4@\>OEY.WH__(@\N7J\?(N
M("#"Z.4@TM#?P<+`(.3@(/'E(/'ZX^O@\>CRY2#Q(//QZ^[BZ/_RX"#GX"#H
MY^_NZ^?BX.WE(.W@(/'H\?+E[.#RX"X`S.[K_RP@Z.?O\.#YX.GRY2#H[?3N
M\.S@]NC_\N`@Y^`@X?KC[N+E(.(@:3$X;D!L:7-T<RYH;W)D92YO<N,`S_#E
MY^7M\N#VZ.@`S_#NX>OE[#\`RNO^]^[BX"#DXN[IZN`@[_/AZ^CWY>TO]^#Q
M\N7M(.KK_O<@[>4@X>7XY2#CY>WE\.CPX.W@+@#*[N7TZ/;HY>WR`-?E\N7M
MY0#(\>K@\N4@Y.`@Z.?R\.CE\N4@)7,@Z^@_(-+@Y^@@[N_E\.#VZ/\@[>4@
M[.[FY2#DX"#QY2#B^O#MY2#MX.?@Y"X`SN_PY?'MZ"#0Y>?^[.4@Z.?CZ^7D
MX#H`P.3PY?$@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`
MS_#E[.#U[>@@[N'NX?GE[>C_\N``S_#E[.#U[>@`S_#E[.#U[>@@\.7G_NSE
M`,_PY>S@]>WH(._N\O#EX>CRY>LZ("5S`,W@(.?@[^CRXN#MY?+N(.WE(.'E
M^.4@[O+C[N+N\.7M[CH@`,WE[N'U[N3H[.C_("=B87-E9&XG(.WE(.4@Y^#D
MX.3E[2#B(.CDY>WRZ/3HZN#VZ.CRY2X`S>7NX?7NY.CLZ/\@)V)A<V5D;B<@
M[>4@Y2#GX.3@Y.7M(.(@[_#E].7PY>WVZ.CRY2X`S>7NX?7NY.CLZ/\@)V)D
M8U]H;W-T<W!E8R<@[>4@Y2#GX.3@Y.7M(.(@Z.3E[?+H].CJX/;HZ/+E+@#-
MY>[A]>[DZ.S@\N`@)V1A=&%B87-E)R#MY2#E(.?@Y.#DY>W@(.(@ZN[M].CC
M\_#@]NC_\N`@[>`@(%-E<W-I;VY(86YD;&5R+@#-Y>[A]>[DZ.S@\N`@)V1A
M=&%B87-E)R#MY2#E(.?@Y.#DY>W@(.+ZXB#J[NWTZ./S\.#VZ/_RX"#MX"!6
M1E,N`,WE[N'U[N3H[.#RX"`G9&%T86)A<V4G[>4@Y2#GX.3@Y.7MX"#B(.CD
MY>WRZ/3HZN#VZ.CRY2X`S>7NX?7NY.CLX/+@("=D871A8F%S92<@[>4@Y2#G
MX.3@Y.7MX"#B(.K@\N7C[O#HZ/+E+@#-Y>[A]>[DZ.S@\N`@)V1A=&%B87-E
M)R#MY2#E(.?@Y.#DY>W@(.(@[_#E].7PY>WVZ.CRY2X`S>7NX?7NY.CLX/+@
M("=D871A8F%S92<@[>4@Y2#GX.3@Y.7MX"#B^N(@=&]K96X@ZN[M].CC\_#@
M]NC_\N`N`,WE[N'U[N3H[.C_\B`G9&]M86EN)R#MY2#E(.?@Y.#DY>T@XB#J
M[NWTZ./S\.#VZ/_RX"#GX"#HY.7M\NCTZ.K@]NC_+@#-Y>[A]>[DZ.S@\N`@
M)VAO<W1S<&5C)R#MY2#E(.?@Y.#DY>W@(.(@ZN[M].CC\_#@]NC_\N`@[>`@
M4V5S<VEO;DAA;F1L97(N`,WE[N'U[N3H[.C_("=H;W-T<W!E8R<@[>4@Y2#S
MZN#GX.T@XB!61E,@ZN[M].CC\_#@]NC_\N`N`,WE[N'U[N3H[.C_("=H;W-T
M<W!E8R<@[>4@Y2#GX.3@Y.7M(.(@ZN[M].CC\_#@]NC_\N`@Y^`@Z.3E[?+H
M].CJX/;H_RX`S>7NX?7NY.CLZ/\@)VAO<W1S<&5C)R#MY2#E(.?@Y.#DY>T@
MXB#JX/+EX^[PZ.CRY0#-9>[A]>[DZ.SH_R`G:&]S='-P96,G(.WE(.4@Y^#D
MX.3E[2#B(._PY?3E[?#E]NCH\N4N`,WE[N'U[N3H[.C_("=H;W-T<W!E8R<@
M[>4@Y2#SZN#GX.T@XB!T;VME;B#J[NWTZ./S\.#VZ/_RX"X`S>7NX?7NY.CL
MX/+@("=P87-S=V]R9"<@[>4@Y2#GX.3@Y.7MX"#B(.KN[?3HX_/PX/;H__+@
M(.W@(%-E<W-I;VY(86YD;&5R+@#-Y>[A]>[DZ.S@\N`@)W!A<W-W;W)D)R#M
MY2#Q^OGE\?+B\^+@(.+ZXB!61E,@ZN[M].CC\_#@]NC_+@#-Y>[A]>[DZ.S@
M\N`@)W!A<W-W;W)D)R#MY2#E(.?@Y.#DY>W@(.(@Z.3E[?+H].CJX/;HZ/+E
M+@#-Y>[A]>[DZ.S@\N`@)W!A<W-W;W)D)R#MY2#E(.?@Y.#DY>W@(.(@ZN#R
MY>/N\.CH\N4N`,WE[N'U[N3H[.#RX"`G<&%S<W=O<F0G(.WE(.4@Y^#DX.3E
M[>`@XB#O\.7TY?#E[?;HZ/+E+@#-Y>[A]>[DZ.S@\N`@)W!A<W-W;W)D)R#M
MY2#Q^OGE\?+B\^+@(.(@=&]K96X@ZN[M].CC\_#@]NC_+@#-Y>[A]>[DZ.SH
M_R`G<&1C7VAO<W1S<&5C)^WE(.4@Y^#DX.3E[2#B(.CDY>WRZ/3HZN#VZ.CR
MY2X`S>7NX?7NY.CLZ/\@)W!H<'1Y<&4G(.WE(.4@Y^#DX.3E[2#B^N(@4U%,
M(.KN[?3HX_/PX/;H__+@+@#-Y>[A]>[DZ.SH__(@)W!H<'1Y<&4G(.WE(.4@
MY^#DX.3E[2#B(.KN[?3HX_/PX/;H__+@(.W@(%-E<W-I;VY(86YD;&5R+@#-
MY>[A]>[DZ.SH_R`G<&AP='EP92<@[>4@Y2#GX.3@Y.7M(.+ZXB!61E,@ZN[M
M].CC\_#@]NC_\N`N`,WE[N'U[N3H[.C_("=P:'!T>7!E)R#MY2#E(.?@Y.#D
MY>T@XB#HY.7M\NCTZ.K@]NCH\N4N`,WE[N'U[N3H[.C_("=P:'!T>7!E)R#M
MY2#E(.?@Y.#DY>T@XB#JX/+EX^[PZ.CRY2X`S>7NX?7NY.CLZ/\@)W!H<'1Y
M<&4G(.WE(.4@Y^#DX.3E[2#B(._PY?3E\.7M]NCH\N4N`,WE[N'U[N3H[.C_
M("=P:'!T>7!E)R#MY2#E(.?@Y.#DY>T@XOKB('1O:V5N(.KN[?3HX_/PX/;H
M__+@+@#-Y>[A]>[DZ.SH_R`G<&]R="<@[>4@Y2#GX.3@Y.7M(.+ZXB!61E,@
MZN[M].CC\_#@]NC_\N`N`,WE[N'U[N3H[.C_("=U:60G(.WE(.4@Y^#DX.3E
M[2#B(.CDY>WRZ/3HZN#VZ.CRY2X`S>7NX?7NY.CLZ/\@)W5I9"<@[>4@Y2#G
MX.3@Y.7M(._PY?3E\.7M]NCH\N4N`,WE[N'U[N3H[.[R[B`G=7-E<FYA;64G
M(.WE(.4@Y^#DX.3E[>X@XB#J[NWTZ./S\.#VZ/_RX"#MX"!397-S:6]N2&%N
M9&QE<BX`S>7NX?7NY.CL[O+N("=U<V5R;F%M92<@[>4@Y2#GX.3@Y.7M[B#B
M(%9&4R#J[NWTZ./S\.#VZ/_RX"X`S>7NX?7NY.CLZ/\@)W5S97)N86UE)R#M
MY2#E(.?@Y.#DY>T@XB#HY.7M\NCTZ.K@]NCH\N4N`,WE[N'U[N3H[.C_("=U
M<V5R;F%M92<@[>4@Y2#GX.3@Y.7M(.(@ZN[M].CC\_#@]NCH\N4N`,WE[N'U
M[N3H[.C_("=U<V5R;F%M92<@[>4@Y2#GX.3@Y.7M(.(@[_#E].7PY>WVZ.CR
MY2X`S>7NX?7NY.CL[O+N("=U<V5R;F%M92<@[>4@Y2#GX.3@Y.7M[B#B('1O
M:V5N(.KN[?3HX_/PX/;H__+@+@#-Y>[A]>[DZ.SH_R`G=F9S<F]O="<@[>4@
MY2#GX.3@Y.7M(.+ZXB!61E,@ZN[M].CC\_#@]NC_\N`N`-#NZ_\`4U%,(%-H
M96QL`%-32`#2^O#QY>WE(.W@($AO<F1E(._PZ.ONYN7MZ/_RX"XN+@#2^O#Q
MY>WE(.W@(&=E='1E>'0@Z.?O^NOMZ.SH(/3@Z>ONXN4N+BX`R.?AY?#H`,CG
MX>7PY?+E(./P\^_@(.?@(.3NX>#B_^WE`,CGX>7PY?+E(.WNXB#O\.CRY>;@
M\N7K(.W@(./P\^_@`,CGX>7PY?+E(/'Z\.+Z\`#(Y^'E\.@@[^[R\.7AZ/+E
MZR#GX"#D[N'@XO_MY0#(Y^'E\.7RY2#MY>[A]>[DZ.SH\N4@PN@@\>CLXN[K
MZ"X@T>OEY"#R[N+@(./H(.KN[^CPX.GRY2#N\B#RY>KQ\N[B[O+N(._NZ^4N
M`,CGX>7PY?+E(,3@\N`@\.#GY.7KZ/+EZSH`R.?AY?#E\N4@].[P[.#R(.?@
M(,3@\N#RX#H`R.?AY?#E\N4@].[P[.#R(.?@(-?@\>`Z`,CGX>7PY?+E(.3B
MY2#Q^N+OX.3@^>@@[^[KY?+@.@#(Y^'E\.7RY2#BX/C@\N`@\?7E[.`@Y^`@
M]N+E\N[BY?+E+@#(Y^'E\.7RY2#O\.7D[^[WZ/+@[>C_\B#N\B#"X/$@Y>?H
MZCH`R.?AY?#E\N4@ZN[K[NWH.@#1^O#B^O``R.?AY?#E\N4@[_#EY._N]^CR
MX.WH__(@[O(@PN#Q(.7GZ.H@Y^`@Y.CQ[^OE_RX`Q^#DX.GRY2#"X/CE\NX@
M[>#WX.OM[B#O\.CK[N;E[>CE+"#Q]>7LX"#GX"#VXN7R[N+E+"#N[_#E\>W_
MXN#MY2#MX"#Q\O#@[>CVX/+@(.@@Y/#SX^@@[N_VZ.@@Y^`@Y.CQ[^OE_RX`
MRO#@\NKN(/#EY_[LY3H`S^[JX.?BX.WE`-#@Y^SE\`#/\.7QZN[WY>WN+BXN
M`,W_ZN[H(.[R(.KN[?3HX_/PX/;H[NWMZ/+E(/3@Z>ONXN4@[>`@2&]R9&4@
MZ^CO\>+@\CH`S?_J[N@@[O(@ZN[M].CC\_#@]NCN[>WH\N4@].#IZ^[BY2#M
MX"!087-S=V]R9"#KZ._QXN#R.@#3[>CY[N;H\N7K(.W@(-'OX.P`POKBY>;D
MX.WE(.W@(/'OY?;HX.OMZ"#QZ.SB[NOH`,CG[_#@\N@`T_'OY?4`T_'OY?CM
M[B#D[N'@XN7M("<E<R<@ZOKL(/'H\?+E[.#RX"X`T_'OY?CM[B#HY_+PZ/(@
M)R5S)RX`T_'OY?CM[B#O\.7LX/7MX/(@)R5S)R#N\B#QZ/'RY>S@\N`N`-/Q
M[^7X[>X@X>7XY2#NX>WNXN7M("<E<R<N`%-U;@#'X.3@]^@`T>#L[B#RY>KQ
M\@`E<R!H96QP(/3@Z>L@Y^`@)7,@[>4@\?KYY?'RXO/BX"#B\>4@[OGE+B#1
M^N?DX.+@[>4@[>`@[>[B+@#/\.CJ\.7OY>WH__(@4$=0(._NY._H\2#E(.WE
M[N'U[N3H["#GX"#DX"#QY2#O\.[BY?#H(._NY._H\>#M[O+N(._H\>SN+@#/
M\.CJ\.7OY>WH__(@4TU)344@[^[D[^CQ(.4@[>7NX?7NY.CL(.?@(.3@(/'E
M(._P[N+E\.@@[^[D[^CQX.WN\NX@[^CQ[.XN`,KPZ._RZ/#@[>7R[B#HY^CQ
MZN+@(.KPZ._RZ/#@[>`@=V5B(.+P^N?JX"X`2&5L<"#TX.GKX"`E<R#MY2#G
MX._N]^+@(/$@/#]X;6P`S.7Q\N[O[NONYN7MZ.7R[B#MX"!';G501R#TX.GK
MX"#R\/_AXN`@Y.`@X?KDY2#DX.3E[6\@[>`@0W)Y<'1?<&=P.CH@8VQA<P#,
M[N3SZ_KR($]P96Y34TP@Y2#MY>[A]>[DZ.P@Y^`@0W)Y<'1?<VUI;64Z.B!C
M;&%S<RX`S_#NX_#@[.#RX"P@ZN[_\NX@\>OSYN@@Y^`@[^[JX.?BX.WE(.W@
M(/+NY^@@\NCO(.3@[>WH("@E<RD@[>4@X>7XY2#N\NKPZ/+@(.(@\>CQ\N7L
MX/+@`%1H92!296=I<W1R>2`HT.7CZ/'R\.#R\_#@\N`I(.4@[>#WZ.WZ\B#O
M[B#J[NGR[B!(;W)D92#O\.CK[N;E[>C_\N`@\.#GX>CPX/(@ZN#J(.3@(.KN
M[//MZ.KH\.#R(._N(.SEYN3S(/'H+B#!Z"#R\/_AXN#K[B#DX"#N[^CXY?+E
M(.CM\?+@Z^CPX.WH\N4@[_#HZ^[FY>WH_R#R\^HN`,W_[.`@Y.+NZ>KH+"#J
M[NCR[B#DX"#A^N3@\B#O[NK@Y^#MZ"#B(.OH[>C_\N`N`,CLX"#RXOKPY.4@
M[.WNX^X@\>CLXN[KZ"#B(/+NXN`@[^[KY2X@POKBY>OH(/'RY2`E<R#QZ.SB
M[NO@.R#R\/_AXN`@Y.`@XOKBY>3E\N4@[^XM[.#KZNX@[O(@)7,N`,WE(/'Z
M^>7Q\N+SXN`@:&5L<"#TX.GK(/$@\N[BX"#H[.4@Y^`@)7,N`,/PY?CJX"#O
M\.@@Y.[AX.+_[>4@[>`@)R5S)R#J^NP@\>CQ\N7LX/+@+@##\.7XZN`@[_#H
M(._PY>S@]>+@[>7R[B#MX"`G)7,G(.[R(/'H\?+E[.#RX"X`P_#E^.K@(._P
MZ"#N[_#E\>W_XN#MY2#MX"`G)7,G.B`E<P##\.7XZN`@[_#H(.CG[_#@^>#M
MY?+N(.W@(/3@Z>O@.B`E<R#MY2#AY?CE(.CG[_#@\N7M+@#([.#XY2#O\.[A
MZ^7L(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX"X@)7,@Y2#O[BWC[NO_["#N
M\B#LX.KQZ.S@Z^WN(.3N[_/Q\NCLZ/\@\.#G[.7P("@E9"#AX.GRX"DN`,/P
MY?CJX"#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`N("5S(.'E^.4@\>#L[B#N
M\O?@\?+H(.CG[_#@\N7M+@##\.7XZN`@[_#H(.CL[^[P\NCPX.WE(.W@(.CG
MX?#@[>CRY2#DX.WMZ"#GX"#JX.OE[>3@\"X`P_#E^.K@(._PZ"#H[._N\/(@
M[>`@Y.#M[>@@Y^`@ZN[M\N#J\N@N`,/PY?CJX"#O\.@@[O+BX/#_[>7R[B#M
MX"#TX.GK("5S+B#.[^CRX.GRY2#DX"#Q\N#P\NCPX/+E('1R86YS;&%T:6]N
M+G!H<"#Q(.[O]NC_("UD(.?@(.3@(.+HY.CRY2#Q^N[A^>7MZ&7R[B#GX"#C
M\.7XZN`@[O(@>&UL(._@\/'E\&$N`,/PY?CJX"#O\.@@[_#NXN7PZN#RX"#M
MX"#R[N+@(._H\>SN+@#2Y>?H(.3@[>WH(.?@(.K@Z^7MY.#PX"#A__7@(//Q
M[^7X[>X@Y.[AX.+E[>@@ZOKL(,+@^.#RX"#O\.[C\.#LX"X@RNOHZNWE\N4@
M[^XMY.[K\R#GX"#DX"#BZ.3H\N4Z`-+EY^@@Y.#M[>@@Y^`@ZN[M\N#J\B#A
M__7@(//Q[^7X[>X@Y.[AX.+E[>@@ZOKL(,+@^.#RX"#O\.[C\.#LX"X@RNOH
MZNWE\N4@[^XMY.[K\R#GX"#DX"#BZ.3H\N4Z`-+NXN`@[>4@Y2#BX.OHY.7M
M(')A<B#@\/7HXBX`TN[BX"#MY2#E(.+@Z^CDY>T@>FEP(/3@Z>LN`-+NXN`@
M[^[KY2#E(.WE[N'U[N3H[.XN`-+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KPYN`@
M\>#L[B#VY>OH(/?H\>O@+@#2[N+@(._NZ^4@[.[FY2#DX"#Q^N3Z\.;@(/'@
M[.X@]^CQZ^`@Z"#DXN[E\N[WZ.4N`-+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KP
MYN`@\>#L[B#M[NSE\.`N`-+NXN`@[^[KY2#R\/_AXN`@Y.`@Y2#GX._E\N#_
M(.CKZ"#H[?+E\.+@ZR#PX.?DY>OE[2#Q[^CQ^NH@[_#N[.7MZ^CBZ`#2[N?H
M(/3@Z>L@ZN[M\O#NZ^CPX"##Z^[AX.OMZ/+E(.W@\?+P[NGJZ"#GX"!-24U%
M(/+H[^[BY?+E(.?@($AO<F1E+"#J[N7R[B#E(.WE[N'U[N3H[.X@Y^`@Y.`@
M[.[CX/(@[_#NX_#@[.@@ZN#R[B!E;G-C<FEP="#HZ^@@;7-W;W)D=FEE=R#D
MX"#O[NK@Y^+@\B#Q^N3Z\.;@[>CE\NX@ZN#R[B!(5$U,(.+ZXB#BX/CH_R#A
M\.#SY^7P("A)12P@3F5T<V-A<&4@Z"#R+NTN*0#2[N?H(/3@Z>L@\?KD^O#F
MX"#Q\NCK[N+E\N4@[N_PY>3EZ__YZ"#VXN7R[N+E\N4@Z"#X\.CT\N[BY?+E
M(.?@($AO<F1E+"#JX.KR[B#H(.?@(.+QZ/?JZ"#O\.CK[N;E[>C_+"#J[NCR
M[B#M_^S@\B#QXN[H(.W@\?+P[NGJZ"X`TN[GZ"#TX.GK(/'Z[^[Q\N#B_R#T
MX.GK[N+H\N4@\.#G^.CPY>WH_R#MX"#K[N/H]^WH($U)344@\NCO[N+E(._N
MY^+NZ__BX.GJZ"#MX"!(;W)D92#DX"#N[_#EY.7KZ"#JX.H@Y.`@\>4@\>_P
MX.+H(/'Z\2#GX.K@]^7MZ"#J^NP@[^CQ[.[R[B#TX.GK[N+E(.CKZ"!#5E,@
M[_#NXN7PZN@N`-+@Y^@@].[P[.`@XN7WY2#AY?CE(.[A\.#A[O+E[>`N`-+N
MXN`@Y2#CZ^#B[>C_(.KN[?3HX_/PX/;H[NWE[2#TX.GK(.W@($AO<F1E+B#2
M[ND@\?KD^O#FX"#O^O+H^>`@Z"#N\>WNXNWH\N4@[>7YX"#JX.KR[B#GX"!(
M;W)D92#RX.K@(.@@Y^`@]N7KZ/_R(._@ZN7R(._PZ.ONYN7MZ/\N`-+NXN`@
MY2#CZ^#B[>C_(.KN[?3HX_/PX/;H[NWE[2#TX.GK(.W@(%!A<W-W;W)D+B#2
M[ND@\?KD^O#FX"#O^O+H^>`@Z"#N[_;HZ"#GX"#QZO#H[_+NXN7RY2#MX"!0
M87-S=V]R9"X`TN[BX"#WZ/'K[B#R\/_AXN`@Y.`@Y2#O[NWE(.7DZ.WH]N`N
M`-+NY^@@\?KPXOKP(.WE(.SNYN4@Y.`@Y.7J[NSO\.7QZ/#@('II<"#H(&=Z
M:7`@].#IZ^[BY2X`TN#GZ"#Q\N[I[>[Q\B#R\/_AXN`@Y.`@Y2#WZ/'K[BX`
MS_#N\>OEY/_BX.WE(.WE(.+PY>SE`,3K^N;M[O'R`%523`#-Y>+ZY^SNYNWN
M\?(@Y^`@XO#ZY^K@(/$@4U%,(/'Z\.+Z\"X`P_#E^.K@(._PZ"#HY_+PZ.+@
M[>4@)R5S)SH@)7,N`,/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO\.7Q
MZ/#@[2#@\/7HXBX`P_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@
M[^K@+@##\.7XZN`@[_#H(._PY>+NY.`@[>`@\N[GZ"!7;W)D(.3NZO/LY>WR
M`,_NY/?E\/+@[>@`S>7HY^+E\?+MX"#J[NS@[>3@.B`E<P#-Y>_NY/#EY.7M
M(/'OZ/'ZZ@#.[_#E\>WH`,[O\.7Q[>@@)7,`SN_PY?'MY>UA("<E<R<N`,[O
M\.7Q[?_BX.WE(.W@("5S(&AE;'`@].#IZR#GX"`E<RX`R.?O[NOGXN#MY3HZ
M`,CG[^[KY^+@Z2#O[N3PX.?AZ/#@^>#RX"#QY2#Q\N[I[>[Q\@#/[O+PY>'H
M\N7K("5S0"5S(.WE(.'E^.4@[>#LY?#E[0#`Y.SH[>CQ\O#H\.#MY2#MX"#O
M[O+PY>'H\N7KZ/+E`,W_[.`@\N#J^N(@[^[R\.7AZ/+EZP#-_^S@(/+@ZOKB
M(._N\O#EX>CRY>LN`,CLY0#-Y>KN\.7J\NW@(._@\.[KX"#HZ^@@[^[R\.7A
MZ/+EZ_'J[B#H[.4A`,CLY3H`R.SE.B``S^[R\.7AZ/+EZ^@`S^[R\.7AZ/+E
MZ^@@XB#QZ/'RY>S@\N`Z`,+@ZN#M]NC_`,/PY?CJX"#O\.@@[_#NXN7PZN#R
MX"`M(/+NXN`@[^CQ[.X@[.[FY2#DX"#E(.'HZ^X@[^[D[_#@XN7M[BX`PNWH
M[.#MZ.4`PNWH[.#MZ.4Z(`#1Y>3LZ/?M[@#$[N'PY2#$[OCKZ"#B("5S`,3N
MX?#E(.3N^.OH+"`E<P#(Y^'E\.7RY2#O\.CK[N;E[>CE\NXL(.KNY?+N("5S
M(.3@(._NZN#FY2#QZ^7D(.+U[N0N`,'HY^WE\2#@Y/#E\0#!Z.?MY?$@\N7K
MY?3N[0#'X._H\2#MX"#N[_#E\>WE[>C_\B#O[NSN^>7M(/3@Z>L@XB`E<RX`
MP\,`P^[DZ/CM[@#$X`#-Y2#L[N;E\N4@Y.`@\>SE[>CRY2#OX/#NZ^#RX"#M
MX"#O[O+PY>'H\N7K("5S`,WE(.+ZXN7D[O7RY2#BX.OHY.7M(&5M86EL(.#D
M\.7Q+@#2\/_AXN`@Y.`@XOKBY>3E\N4@\N7J\_G@\N`@PN@@[^#P[NO@`-+P
M_^'BX"#DX"#B^N+EY.7RY2#M[N+@\N`@PN@@[^#P[NO@`-+P_^'BX"#DX"#G
MX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2X`TO#_X>+@(.3@(.?@
MY.#DY?+E(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4N`-+P_^'BX"#DX"#GX.3@
MY.7RY2#O[O+PY>'H\N7K(.?@(.[O\.7Q[?_BX.WE+@#2\/_AXN`@Y.`@[^[R
MXOKPY.CRY2#"X/C@\N`@[>[BX"#OX/#NZ^``PN#XZ/\@16UA:6P@X.3PY?$Z
M`,CM].[P[.#VZ/\@Y^`@PN#Q`,+@^.7R[B#H[.4Z`,+@^.C_\B#HY.7M\NCT
MZ.K@]NCN[>7M(.3PX.GBY?`@[>4@[^[DY/KPYN`@Y.[AX.+_[>4@[>`@[^[R
M\.7AZ/+EZ^@L(.CKZ"#RX.?H(.+ZY^SNYNWN\?(@Y2#GX.'PX.WE[>`N`,+@
M^.C_\B#HY.7M\NCTZ.K@]NCN[>7M(.3PX.GBY?`@[>4@[^[DY/KPYN`@\>_H
M\?KJ(.W@(._N\O#EX>CRY>OH\N4L(.CKZ"#RX.?H(.+ZY^SNYNWN\?(@Y2#G
MX.'PX.WE[>`N`,WNXN#RX"#"Z"#OX/#NZ^`@Y2#RXOKPY.4@Y/KKX^`[(._@
M\.[KZ/+E(.WE(.SNX^#R(.3@(/'@(._N+>3ZZ^/H(.[R("5D(/'H[.+NZ^`A
M`,WNXN#RX"#"Z"#OX/#NZ^`@Y2#O\.7JX.OE[>X@Z^7Q[>`@Y^`@[O+CX/+B
MX.WE(2#-_^S@(.3@(.'ZY.4@\>SE[>7MX"$`S>[BX/+@(,+H(._@\.[KX"#R
M\/_AXN`@Y.`@Y2#D^NOCX"#O[NWE("5D(/'H[.+NZ^`A`,WNXN#RX"#"Z"#O
MX/#NZ^`@\O#_X>+@(.3@(.4@\.#GZ^CW[>`@[O(@\N7J\_G@\N``S>[BX/+@
M(,+H(._@\.[KX"#R\/_AXN`@Y.`@\?KD^O#FX"#O[NWE("5D(/'H[.+NZ^`A
M`,WNXN#RX"#"Z"#OX/#NZ^`@\O#_X>+@(.3@(/'ZY/KPYN`@[^[MY2`E9"#Q
MZ.SB[NO@("CA\^KBZ"#H(/;H]/#H*2X`S>[BX/+@(,+H(._@\.[KX"#R\/_A
MXN`@Y.`@\?KD^O#FX"#O[NWE("5D(/'H[.+NZ^`@*.S@Z^KH(.'SZN+H*2X`
MS>[BX/+@(,+H(._@\.[KX"#R\/_AXN`@Y.`@\?KD^O#FX"#O[NWE("5D(/'H
M[.+NZ^`@*/;H]/#H*2X`S>[BX/+@(,+H(._@\.[KX"#R\/_AXN`@Y.`@\?KD
M^O#FX"#O[NWE("5D(/'H[.+NZ^`@*./NZ^7LZ"#A\^KBZ"DN`,WNXN#RX"#"
MZ"#OX/#NZ^`@\O#_X>+@(.3@(/'ZY/KPYN`@[^[MY2`E9"#QZ.SB[NO@("CH
M[?+E\.+@Z^`I+@#-[N+@\N`@PN@@[^#P[NO@(/+P_^'BX"#DX"#MY2#Q^N3Z
M\.;@(.CM\N7PXN#KZ"X`S>[BX/+@(,+H(._@\.[KX"#MY2#AY?CE(._NXO+N
M\.7MX"#J[O#EZO+M[B$`PN#XZ/+E(.KN[?3HX_/PX/;H[NWMZ"#N[_;HZ"#A
M__7@(.[A[>[BY>WH+@#"X/CH\N4@\?KPXOKPZ#H`6^OH[>C_("5S(.[R("5S
M70#MY>_PY>[D[NOH[.`@X_#E^.K@.@#-X._PX.+E[>X`[_#NXN#KY>WN`/3@
MZ>L`:3$X;@#MY2#AY?CE(.W@[.7PY>T`X_#E^.K@(._PZ"!T96UP;F%M*"DA
M`$AO<F1E(%!/(/3@Z>L@Y^`@Z^[JX.OHY^#VZ/\@)7,@[>4@\?KYY?'RXO/B
MX#H`X>7G(.CLY0!V0V%R9```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+V%R7U-9+P``````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S
M`#`R,#(P,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O
M87)?4UDO3$-?34534T%'15,O````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#,`,#(Q-S8U`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+VQO8V%L92]A<E]362],0U]-15-304=%4R]P87-S=V0N;6\`
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`U-S`R,0`Q,#0Q-S,V,C<T,P`P,C,V,C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````WA($E0``
M```;`0``'````/0(``![`0``S!$```````"X%P``"````+D7```B````PA<`
M``4```#E%P``"````.L7```'````]!<```P```#\%P``'P````D8```Y````
M*1@``"D```!C&```$0```(T8```6````GQ@``!8```"V&```"````,T8```F
M````UA@``!H```#]&````P```!@9```(````'!D``!4````E&0``"@```#L9
M```4````1AD``$0```!;&0``"@```*`9```1````JQD```P```"]&0``!@``
M`,H9```)````T1D```L```#;&0``!P```.<9```5````[QD``"`````%&@``
M&0```"8:```0````0!H``!L```!1&@``$````&T:```U````?AH``#<```"T
M&@``%P```.P:```P````!!L``"D````U&P```@```%\;```%````8AL``!8`
M``!H&P``$````'\;```4````D!L``"\```"E&P``#P```-4;```F````Y1L`
M``4````,'```#0```!(<``!`````(!P```4```!A'```!P```&<<```0````
M;QP``!````"`'```#P```)$<```+````H1P```\```"M'```#````+T<```/
M````RAP```H```#:'```(````.4<```=````!AT``!8````D'0``'@```#L=
M```A````6AT``"````!\'0``'P```)T=```#````O1T``!8```#!'0``$@``
M`-@=```1````ZQT```X```#]'0``!`````P>``"@````$1X```0```"R'@``
M#````+<>```*````Q!X```4```#/'@``"P```-4>```,````X1X```X```#N
M'@``(````/T>```;````'A\```H````Z'P``#P```$4?```&````51\```X`
M``!<'P``$@```&L?```0````?A\``!H```"/'P``*````*H?```(````TQ\`
M`!````#<'P``%````.T?```&`````B````<````)(```7````!$@```&````
M;B````(```!U(```!````'@@``!`````?2```!,```"^(```&````-(@```1
M````ZR````\```#](```!0````TA```*````$R$``"T````>(0``-````$PA
M```D````@2$```<```"F(0``!P```*XA```*````MB$```0```#!(0``!0``
M`,8A```-````S"$```(```#:(0``,P```-TA```\````$2(``#H```!.(@``
M.P```(DB```^````Q2(``#,````$(P``/@```#@C```X````=R,``#L```"P
M(P``%````.PC```Q`````20``"T````S)```+P```&$D```L````D20``!T`
M``"^)```!0```-PD```&````XB0``",```#I)```)@````TE```"````-"4`
M``T````W)0``!P```$4E```(````324``!$```!6)0``&0```&@E```(````
M@B4``!$```"+)0``*@```)TE```>````R"4```4```#G)0``*````.TE```I
M````%B8``"\```!`)@``$P```'`F```(````A"8```L```"-)@``/````)DF
M``!`````UB8``#T````7)P``1@```%4G``!"````G"<``#<```#?)P``0@``
M`!<H```^````6B@``#\```"9*```0````-DH``!"````&BD``#<```!=*0``
M0@```)4I```^````V"D``#\````7*@``0@```%<J```W````FBH``$(```#2
M*@``/@```!4K```_````5"L``$8```"4*P``00```-LK```V````'2P``$$`
M``!4+```/0```)8L```^````U"P``#,````3+0``.P```$<M```\````@RT`
M`#T```#`+0``.@```/XM``!"````.2X``#<```!\+@``0@```+0N```^````
M]RX``#\````V+P``-@```'8O```1````K2\```0```"_+P``#````,0O```?
M````T2\``!T```#Q+P``:`````\P```:````>#```!<```"3,```%P```*LP
M```;````PS```!\```#?,```$P```/\P``!`````$S$``#0```!4,0``)```
M`(DQ```.````KC$``!````"],0``"@```,XQ```P````V3$``#H````*,@``
M%P```$4R```'````73(```4```!E,@``"0```&LR```H````=3(``$P```">
M,@``CP```.LR```K````>S,``(,```"G,P``=````"LT``#-````H#0``)L`
M``!N-0``<P````HV``"F````?C8``(D````E-P``<P```*\W```A````(S@`
M`!P```!%.```!0```&(X```.````:#@```,```!W.```+P```'LX```@````
MJS@``"4```#,.```*@```/(X```@````'3D``"8````^.0``#````&4Y```7
M````<CD``!,```"*.0``'0```)XY```&````O#D``!$```##.0``#````-4Y
M```(````XCD``"4```#K.0``"0```!$Z```'````&SH```D````C.@``!@``
M`"TZ```-````-#H```L```!".@``,@```$XZ```,````@3H```H```"..@``
M(````)DZ```"````NCH```8```"].@```P```,0Z```H````R#H``"4```#Q
M.@``/@```!<[``!%````5CL``!\```"<.P``'P```+P[```9````W#L``"$`
M``#V.P``,````!@\```3````23P``!````!=/```"@```&X\```?````>3P`
M`!\```"9/```$````+D\```/````RCP``!4```#:/```!````/`\```&````
M]3P```0```#\/```"0````$]```S````"ST```4````_/0``.P$``$4]```'
M````@3X```T```")/@``#````)<^```)````I#X```<```"N/@``"P```+8^
M```8````PCX``"8```#;/@``+0````(_```0````,#\``!\```!!/P``(0``
M`&$_```+````@S\``"(```"//P``'P```+(_```#````TC\```4```#6/P``
M%0```-P_```-````\C\``!$`````0```/````!)````.````3T```!0```!>
M0```#0```'-````&````@4````@```"(0```!0```)%````&````ET```!H`
M``">0```(P```+E````;````W4````P```#Y0```$P````9!```-````&D$`
M`#8````H00``,@```%]!```9````DD$``#<```"L00``*@```.1!```+````
M#T(```0````;0@``(````"!"```0````04(```L```!20@``'````%Y"```,
M````>T(``"D```"(0@``$0```+)"```-````Q$(``$@```#20@``!P```!M#
M```(````(T,```L````L0P``"P```#A#```*````1$,```<```!/0P``"P``
M`%=#```(````8T,``!````!L0P``!@```'U#```;````A$,``!L```"@0P``
M%@```+Q#```?````TT,``!\```#S0P``'@```!-$```8````,D0```0```!+
M1```%@```%!$```2````9T0```\```!Z1```#@```(I$```(````F40``#@`
M``"B1```!P```-M$```,````XT0```L```#P1```!0```/Q$```.`````D4`
M``H````110``#0```!Q%```<````*D4``!(```!'10``"P```%I%```/````
M9D4```<```!V10``$0```'Y%```4````D$4``!$```"E10``$P```+=%```E
M````RT4```4```#Q10``%0```/=%```1````#48```0````?1@``!````"1&
M``!1````*48```0```![1@``"P```(!&```&````C$8``"@```"31@``#P``
M`+Q&```:````S$8``!8```#G1@``#0```/Y&```&````#$<```T````31P``
M)0```"%'```G````1T<``!H```!O1P``!0```(I'```&````D$<```<```"7
M1P``!0```)]'```%````I4<``!0```"K1P```@```,!'```G````PT<``"``
M``#K1P``'P````Q(```?````+$@``"T```!,2```)P```'I(```K````HD@`
M`"D```#.2```-@```/A(```7````+TD``"````!'20``'0```&A)```?````
MADD``!P```"F20``$P```,-)```'````UTD```4```#?20``%P```.5)```6
M````_4D```4````42@``%````!I*```&````+TH```<````V2@``#````#Y*
M```4````2TH```L```!@2@``%0```&Q*```@````@DH``!0```"C2@``!```
M`+A*```<````O4H``"@```#:2@``0@````-+```+````1DL```8```!22P``
M#````%E+```O````9DL``#$```"62P``*@```,A+```W````\TL``#4````K
M3```*@```&%,```S````C$P``"P```#`3```+````.U,```Q````&DT``#4`
M``!,30``*@```()-```S````K4T``"P```#A30``+`````Y.```U````.TX`
M`"D```!Q3@``,P```)M.```M````STX``"T```#]3@``-P```"M/```T````
M8T\``"4```"83P``,@```+Y/```K````\4\``"L````=4```(@```$E0```S
M````;%```#,```"@4```+@```-10```G`````U$``#4````K40``)@```&%1
M```S````B%$``"P```"\40``+````.E1```E````%E(``!$````\4@``!0``
M`$Y2```,````5%(``!<```!A4@``(0```'E2``!&````FU(``!4```#B4@``
M$P```/A2```1````#%,``!0````>4P``$@```#-3```8````1E,``"$```!?
M4P``*````(%3```9````JE,``!$```#$4P``#````-93```(````XU,``"@`
M``#L4P``+````!54```/````0E0```X```!25```!P```&%4```&````:50`
M`"````!P5```20```)%4``!N````VU0``"0```!*50``:@```&]5``!J````
MVE4``'(```!%5@``G0```+A6``!/````5E<``+$```"F5P``@P```%A8``!5
M````W%@``",````R60``&P```%99```%````<ED```P```!X60``#P```(59
M```K````E5D``!T```#!60``'P```-]9```J````_UD``"X````J6@``(@``
M`%E:```2````?%H``!<```"/6@``$0```*=:```@````N5H```X```#:6@``
M%P```.E:```/`````5L```P````16P``(P```!Y;```-````0EL```4```!0
M6P``!@```%9;```(````75L```\```!F6P``#0```'9;```L````A%L```L`
M``"Q6P``"@```+U;```A````R%L```@```#J6P``!@```/-;```#````^EL`
M`"8```#^6P``)````"5<```T````2EP``"8```!_7```&0```*9<```=````
MP%P``!<```#>7```'0```/9<```M````%%T``!<```!"70``$0```%I=```%
M````;%T``"````!R70``$0```)-=```/````I5T``!````"U70``"````,9=
M```(````SUT```,```#870``!0```-Q=```)````XET``!X```#L70``!0``
M``M>```!````D0```'````#!````>@```%H`````````4````&@````"`0``
MA0````4```"T````P@```,@```#`````E0```!````![````*0````$!```V
M`````````!P```"#`````````%0```!7`````````.@```"[````(0```.8`
M``!W````DP```$L```"J````)P````````!;````$0````T````)`0``B0``
M``````#,``````````````#Q````]0```````````````````-P```"`````
M*````.X```"N````TP````````!B````A@```&P`````````,@````\!``!_
M````_`````0````'````X````-0```"S````]@``````````````&`$``!\`
M``!!````2@`````````9``````````````!/````PP```+<````.````9P``
M`-H```````````````P```#7````!0$```````"P````(P```!4!``!$````
M;0```"T````/`````````$(`````````"@$``%,`````````````````````
M````,````.L```!U`````````.<`````````E````-T```!F````M0``````
M```U````&0$``.D```"_````Q@`````````:`0``3@```!X```"9````````
M`*L`````````7P```+(````;````_@``````````````X@``````````````
M+P```-(````T````````````````````9```````````````4@````D```#>
M````I@```-D```""````I````+T````0`0``Q0````````!'````%@``````
M```S````60```)X`````````-P```-\``````````P$``#@`````````````
M`*D````````````````!``"$````30```"8````'`0``````````````````
M````````````````$0$``)````#_````K`````````#J``````````````"<
M````B@```*4```!R````L0```!L!``#X``````````L!``!6````*@```'X`
M``#*````/````)<```#]`````P```',```!A````^P```-@```!V````2```
M`/(`````````N@```#$````&`````````!4```"M````"````(P````-`0``
M$@```!0```!#```````````````L``````````8!``"6```````````````:
M````H````!8!``"=````\P````L```!Q``````````````"H````SP```,X`
M```Z````[P````````".`````````$4``````````````"(`````````^@``
M`!(!``!8`````````"X`````````CP```-L```"G````D@```+8````_````
MB````!T```#+`````````$8```#D````/@```'T````@````:0````````#-
M````!`$``!,````"````U0`````````*````````````````````"`$``%X`
M````````7`````````#L````/0`````````K````#@$``)\```"C````%`$`
M``````"^````$P$``'P`````````8P````````#0````;P```($```";````
M``````P!``!K````H0```(<```!N````40```+P`````````:@```.T```"X
M````=````$`````7`0``Y0```(T```!)````%P`````````Y````Q````,<`
M``":````>0```#L```!5````\````/0```#A````XP```+D```#Y````>```
M`-8``````````````/<```!@````F````*\```"B````)0```,D`````````
M3````"0`````````70```-$```"+````90`````````8`````#(T(&AO=7)S
M`#QB/D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D.CPO8CX`04TO4$T`061D
M('!A:7(`061D<F5S<P!!9&1R97-S($)O;VL`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BX`079A:6QA8FQE(&9I96QD<SH`0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)I
M<G1H9&%Y`$)U:6QD:6YG($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,E<R5S+BXN
M`$)U:6QD:6YG(&QO8V%L92`E<R5S)7,N+BX@`$-64P!#86QE;F1A<@!#86YC
M96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#:&%N9V4@>6]U<B!P87-S
M=V]R9`!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#;&]S92!(96QP`$-L;W-E
M($AE;'`@5VEN9&]W`$-L;W-E(%=I;F1O=P!#;VUI8W,`0V]M;6%N9',Z`$-O
M;6UI='1I;F<Z`$-O;7!A;GD`0V]N9FER;2!N97<@<&%S<W=O<F0Z`$-O;FYE
M8W1I;VX@=&\@9G1P('-E<G9E<B!F86EL960N`$-O;G-O;&5?1V5T;W!T(&YO
M="!F;W5N9"X`0V]N=&5N=',@;V8@)R5S)P!#;VYT96YT<R!O9B!T:&4@4D%2
M(&%R8VAI=F4`0V]P>6EN9R`E<R!T;R`E<P!#;W5L9"!N;W0@8V]N;F5C="!T
M;R!D871A8F%S92!F;W(@4U%,(%-E<W-I;VY(86YD;&5R+@!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!T86)L92`G)7,G(&9O<B!344P@4V5S<VEO;DAA;F1L97(N
M`$-O=6QD(&YO="!C;W!Y("5S('1O("5S`$-O=6QD(&YO="!C<F5A=&4@;&]C
M86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.@!#;W5L9"!N;W0@;W!E;B!-
M86EN=&5N86YC95]487-K(&UO9'5L92`E<P!$1`!$86EL>0!$871A8F%S92!Q
M=65R>2!F86EL960N`$1E9F%U;'0@261E;G1I='D`1&5S8W)I8F4@=&AE(%!R
M;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`16YT<FEE
M<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@8VAA;F=E
M9"P@)60@=6YK;F]W;@!%<G)O<@!%<G)O<CH@`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`
M179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`
M17AE8W5T:6YG.@!%>'!E8W1E9"`B0D5'24XB(&EN('1H92!L:6YE("5D+@!%
M>'!E8W1E9"`B14Y$.B5S(B!I;B!L:6YE("5D+@!%>'1R86-T:6YG(&9R;VT@
M)7,N+BX@`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@4TU"('-E<G9E<BX`1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"`Z
M(`!&87@`1F]U;F0@87!P;&EC871I;VYS.B`E<P!&;W5N9"!D:7)E8W1O<FEE
M<SH`1G5L;"!$97-C<FEP=&EO;CH`1V5T;W!T($5R<F]R.B``2&5L<`!(96QP
M97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA
M=&EO;G,@9F]R('1H92!(;W)D90IF<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A
M=&EO;G,N"D9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$
M344@:6X@=&AI<R!D:7)E8W1O<GDN`$AO;64`2&]M92!!9&1R97-S`$AO;64@
M4&AO;F4`2&]R9&4`2&]R9&4@3&]G:6X`2&]R9&4@4WES=&5M`$AO<F1E(%=I
M<F5L97-S`$AO<F1E(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D`$AO<F1E
M('1R86YS;&%T:6]N(&=E;F5R871O<@!)8V]N<R!/;FQY`$EC;VYS('=I=&@@
M=&5X=`!);7!O<G0`26UP;W)T($5R<F]R.B``26UP;W)T960@9FEE;&0Z("5S
M`$EM<&]R=&5D(&9I96QD<SH`26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN+B``
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!,86YG
M=6%G90!,:7-T($AE;'`@5&]P:6-S`$QO861I;F<@;&EB<F%R:65S+BXN`$QO
M9R!I;@!,;V<@;W5T`$QO9VEN(&9A:6QE9"!F;W(@<V]M92!R96%S;VXN($UO
M<W0@;&EK96QY('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN`$QO9V]U=`!-30!-86EL`$UA:V4@<W5R92!T:&%T
M('EO=2!H879E(%!%05(@:6YS=&%L;&5D(&%N9"!I;B!Y;W5R(&EN8VQU9&4@
M<&%T:"X`36%K:6YG(&1I<F5C=&]R>2`E<P!-87`@1&%T92!A;F0@5&EM92!&
M:65L9',`36%P($EM<&]R="!&:65L9',`36%T8VAI;F<@9FEE;&1S`$UE;6]S
M`$UE;G4@;6]D93H`365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O
M;7!E;F1I=6TN+BX@`$UE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S)7,E<R!T
M;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@
M;6]D=6QE("5S+BXN`$UE<W-A9V4`36]N=&AL>0!->2!3=6UM87)Y`$YA;64`
M3F5V97(`3F5W('!A<W-W;W)D.@!.;P!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($Q$05`@4')E9F5R96YC97,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@0V%T96=O<FEE<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!0<F5F97)E;F-E<RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!397-S:6]N2&%N9&QE
M<BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@875T:&5N=&EC871I;VXN`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&5N
M=')Y('=I=&@@=&AE(&ED("<E<R<@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H
M96QP(&9I;&4N`$YO(&QO8V%L92!S<&5C:69I960N`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!R
M969E<F5N8V5S(&%R92!A=F%I;&%B;&4N`$YO=&5S`$YO=&EC90!.;W1I9FEC
M871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+@!.=6UB97(@;V8@8V]L=6UN
M<R!I;B!T:&4@<W5M;6%R>2!V:65W.@!/2P!/;&0@<&%S<W=O<F0Z`$]P=&EO
M;G,`3W!T:6]N<SH`3W1H97(@26YF;W)M871I;VX`4$A0('-U<'!O<G0@:6X@
M>&=E='1E>'0Z(`!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D(0!087-S=V]R
M9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960`4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!H;VYE`%!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E<&]R="!A;GD@8G5G<R!T
M;R!I,3AN0&QI<W1S+FAO<F1E+F]R9RX`4')O8FQE;2!$97-C<FEP=&EO;@!0
M<F]B;&5M/P!296UO=F4@<&%I<@!297%U:7)E9"`G)7,G(&YO="!S<&5C:69I
M960@:6X@4V5S<VEO;DAA;F1L97(@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G8F%S961N)R!N;W0@<W!E8VEF:65D(&EN
M('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=B9&-?:&]S
M='-P96,G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN
M(%-E<W-I;VY(86YD;&5R(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D871A
M8F%S92<@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T
M:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P
M96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G9&]M86EN)R!N;W0@<W!E8VEF:65D(&EN
M(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=H;W-T
M<W!E8R<@;F]T('-P96-I9FEE9"!I;B!397-S:6]N2&%N9&QE<B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=H;W-T<W!E8R<@;F]T('-P
M96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I
M960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A
M<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(%-E<W-I;VY(86YD;&5R(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@
M<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I
M9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M<&1C7VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF
M:65D(&EN(%-E<W-I;VY(86YD;&5R(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT
M:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T
M('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("=P;W)T)R!N;W0@<W!E8VEF:65D(&EN
M(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B;&4G(&YO="!S<&5C
M:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M=&%B;&4G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W5I9"<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT
M:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=6ED)R!N;W0@<W!E
M8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=U<V5R;F%M92<@;F]T('-P96-I9FEE9"!I;B!397-S:6]N2&%N9&QE<B!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I
M960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U<V5R;F%M92<@
M;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@8V%T96=O
M<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S
M<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)W9F<W)O;W0G(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I
M;VXN`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E87)C
M:&EN9R!(;W)D92!A<'!L:6-A=&EO;G,N+BX`4V5A<F-H:6YG(&=E='1E>'0@
M8FEN87)I97,N+BX`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R
M=`!3970@=&AE(&QA;F=U86=E('1H870@;65N=2!I=&5M<RP@97AP;&%N871I
M;VYS+"!A;F0@:&5L<"!A<F4@:6XN`%-E="!Y;W5R('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T('EO=7(@<')E9F5R
M<F5D(&1I<W!L87D@;&%N9W5A9V4N`%-H;W)T(%-U;6UA<GDZ`%-K:7`@36%I
M;G1E;F%N8V4`4VMI<'!E9"XN+@!3;VUE(&]F($AO<F1E)W,@8V]N9FEG=7)A
M=&EO;B!F:6QE<R!A<F4@;6ES<VEN9SH`4V]M92!O9B!087-S=V]R9"!M;V1U
M;&4G<R!C;VYF:6=U<F%T:6]N(&9I;&5S(&%R92!M:7-S:6YG.@!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1A<VMS`%1E>'0@3VYL>0!4:&4@
M:&5L<"!F:6QE("5S(&1I9&XG="!S=&%R="!W:71H(#P_>&UL`%1H92!P<F]G
M<F%M('5S960@=&\@=FEE=R!T:&ES(&UE<W-A9V4@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')E9VES=')Y(&ES(&AO=R!(
M;W)D92!A<'!L:6-A=&EO;G,@9FEN9"!O=70@:&]W('1O('1A;&L@=&\@96%C
M:"!O=&AE<BX@66]U('-H;W5L9"!L:7-T(&%N>2!I;G-T86QL960@2&]R9&4@
M87!P;&EC871I;VYS('1H870@>6]U(&AA=F4@:&5R92X`5&AE<F4@9&]E<VXG
M="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+@!4:&5R92!W87,@86X@
M97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L
M871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M
M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+@!4:&ES(&9I;&4@8V]N=')O
M;',@=&AE(&1E9F%U;'0@<')E9F5R96YC97,@9F]R(%!A<W-W;W)D(&UO9'5L
M92P@86YD(&%L<V\@8V]N=')O;',@=VAI8V@@<')E9F5R96YC97,@=7-E<G,@
M8V%N(&%L=&5R+@!4:&ES(&9I;&4@8V]N=')O;',@=&AE(&=L;V)A;"!S970@
M;V8@34E-12!D<FEV97)S(&9O<B!T:&4@2&]R9&4@9G)A;65W;W)K+"!A;&QO
M=VEN9R!A<'!L:6-A=&EO;G,@=&\@;6%K92!U<V4@;V8@<')O9W)A;7,@<W5C
M:"!A<R!E;G-C<FEP="!O<B!M<W=O<F1V:65W('1O(')E;F1E<B!C;VYT96YT
M(&EN=&\@2%1-3"!F;W(@=FEE=VEN9R!I;B!A(&)R;W=S97(N`%1H:7,@9FEL
M92!C;VYT<F]L<R!T:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S960@=&\@<V5T
M(&-O;&]R<R!A;F0@9F]N=',@9F]R('1H92!(;W)D92!F<F%M97=O<FL@86YD
M(&%L;"!A<'!L:6-A=&EO;G,@=&AA="!D;R!N;W0@<')O=FED92!T:&5I<B!O
M=VX@<V5T=&EN9W,N`%1H:7,@9FEL92!C;VYT<F]L<R!T:&4@<W1Y;&5S:&5E
M="!T:&%T(&ES('5S960@=&\@<V5T(&-O;&]R<R!A;F0@9F]N=',@:6X@861D
M:71I;VX@=&\@;W(@;W9E<G)I9&EN9R!(;W)D92!D969A=6QT<RX`5&AI<R!F
M:6QE(&UA<',@9FEL92!E>'1E;G-I;VYS('1O(&QO9VEC86P@34E-12!T>7!E
M<RP@96YA8FQI;F<@2&]R9&4@87!P;&EC871I;VYS('1O(&9I9W5R92!O=70@
M:&]W('1O(&AA;F1L92!S;VUE(&-O;G1E;G0@<W5C:"!A<R!E;6%I;"!A='1A
M8VAM96YT<R!O<B!#5E,@8VAE8VMO=71S+@!4:&ES(&ES('1H92!M86EN($AO
M<F1E(&-O;F9I9W5R871I;VX@9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD
M(&)A<VEC(&ET96US('1H870@87!P;'D@=&\@=&AE(&-O<F4@9G)A;65W;W)K
M(&%N9"!A;&P@2&]R9&4@87!P;&EC871I;VYS+@!4:&ES(&ES('1H92!M86EN
M(%!A<W-W;W)D(&UO9'5L92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET(&-O;G1A
M:6YS('!A=&AS(&%N9"!O<'1I;VYS(&9O<B!A;&P@4&%S<W=O<F0@;6]D=6QE
M('-C<FEP=',N`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%1Y<&4@;6ES;6%T
M8V@N`%523`!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5
M;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T
M;R!R96=I<W1E<B!P<F5F97)E;F-E<R!I;B!S97-S:6]N+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`56YE>'!E8W1E9"!E;F0@
M;V8@9FEL92X`56YK;F]W;B!C;VUM86YD.B`E<P!5<&1A=&EN9R`E<R!H96QP
M(&9I;&4@9F]R("5S+@!5<V%G93H`57-E($1E9F%U;'0@5F%L=64`57-E<B!/
M<'1I;VYS`%5S97)N86UE`%5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!N;W0@
M8V]R<F5C="X`57-E<FYA;64Z`%=A<FYI;F<`5V%R;FEN9SH@`%=E96ML>0!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@87!P;&EC871I;VX@<VAO
M=6QD($AO<F1E(&1I<W!L87D@869T97(@;&]G:6X_`%=O<FL@061D<F5S<P!7
M;W)K(%!H;VYE`%=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@)7,N`%E9
M`%EE87)L>0!997,`66]U(&-A;B!N;W0@8VAA;F=E('!A<W-W9"!F;W(@;W1H
M97(@=7-E<@!9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O<B!U<V5R("5S
M`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X\8G(@+SY4:&%N:R!Y;W4@9F]R
M('5S:6YG('1H92!S>7-T96TN`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9
M;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D`%EO=2!M=7-T(&=I=F4@
M>6]U<B!O;&0@<&%S<W=O<F0`66]U(&UU<W0@9VEV92!Y;W5R('5S97)I9`!9
M;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA
M:6P@061D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($YA;64Z`%EO=7(@
M;F5W('!A<W-W;W)D<R!D:61N)W0@;6%T8V@`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S
M70!A;B!E<G)O<B!H87,@;V-C=7)E9#H`9&]N90!F86EL960`;F%M90!N;W0@
M9F]U;F0`=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H92!L;V-A;&4@)7,@9&]E
M<R!N;W0@97AI<W0Z`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@4&%S<W=D
M(`I03U0M0W)E871I;VXM1&%T93H@,C`P,RTP-"TS,"`Q,CHP,"LP,C`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#,M,#0M,S`@,3(Z,#`K,#(P,`I,87-T+51R
M86YS;&%T;W(Z("!0;&%T:6YU;2!$979E;&]P;65N="!496%M(#QD979T96%M
M0'!L871I;G5M+7-Y+F-O;3X*3&%N9W5A9V4M5&5A;3H@07)A8FEC(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U-@I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@`R-"#3Q]K)`#QB/B#-U>$@SMC#.B``Y.7'
MT<?P+^'MX<?P`,/6W2#+Y,?&[0#'X=KDYL?D`,_=RM$@VN3'YNWD`,KC(,K-
MS^W/(-[MX\D@V^W1(./>R.;AR0#*P]_MSR#'X=CAR"#>R.$@Q^'(S\$@R-KC
MX>W'RB#'X=7MQ^3)OP#*XR#1W=8@Q^'*S=[>(./D(,?AY>;MR2#CY"#>R.$@
MQ^'CSL_C(-''S^WFTRX`Q^'-WN;A(,?AX\KFW=').@#?X>/)(./1YM$@V\C1
M(./>R.;AR2`HW^W1R.W1YM,I`,?3XR#'X>/3RL[/XR#;R-$@X][(YN$@*-_M
MT<CMT>;3*0#MYN,@Q^'C[>''SP#%Y-3'P2#CX=W'RB!-3R#AX<C1[>/,Q\H@
M)7,E<R5S+BXN`,7DU,?!(,?AX^'=Q\H@Q^'CS>'MR2`E<R5S)7,N+BX`0U93
M`,/,Y,_)`,7AV\?!(,?AR.''VR#:Y"#CU-_AR0#'X>7'RMT@Q^',YL?A`,K;
M[>W1(-_AX\D@Q^'CT>;1`-;:(-KAQ^/)(-WM(./1R-H@Q^':X^'MR2`HQ^':
MX^'MQ\HI(,?ARNT@RM'MSR#*Y-WMT.7'(,W'X<?P+@#%V^''WB#'X>/3Q]K/
MR0#%V^''WB#DQ]W0R2#'X>/3Q]K/R0#%V^''WB#'X>3'W=#)`-'3YN/'R@#'
MX</FQ^/1.@#*Y-WMT`#'X=31W\D`RL/?[<\@W^'CR2#'X>/1YM$@Q^',S^W/
MR3H`S=7A(,[8PR#.X<?A(,?AQ<K5Q^$@R./.S^,@Q^'<($944"X`X>,@[=K+
MT2#:X>P@0V]N<V]L95]'971O<'0N`./-RN;MQ\H@)R5S)P#CS<KF[<?*(,?A
MP]'4[=T@4D%2`.33SB`E<R#%X>P@)7,`X>,@[<KC(,?AQ<K5Q^$@X]H@WL?:
MSR#'X<CMQ^3'RB#AW"!344P@4V5S<VEO;DAA;F1L97(N`.''(.W*XR#'X<7*
MU<?A(./:(,S/YN$@)R5S)R#=[2!344P@4V5S<VEO;DAA;F1L97(N`.''(,7C
MW\?D[<D@X>33SB`E<R#%X>P@)7,`X<?%X]_'Y.W)(.'%Y-3'P2#CS.'/(./-
MX>T@*&QO8V%L*2#CY"##S.$@X^'=(,?AX=O)("5S.@#AQ\7CW\?D[<D@X=W*
MS2!-86EN=&5N86YC95]487-K(.'AR-'MX\P@)7,`[>;C("T@T=[C[>0`[>;C
M[0#.V,,@W>T@Q^''RM7'X2#CVB#>Q]K/R2#'X<CMQ^3'R@#'X<K-WMX@Q^''
MW<K1Q];M`-31S2#'X>/4W^')`,KC(,W=V2#'X<K=Q]7MX2#AX\_MT2#'X>39
MQ^,`SNW'T<?*(,?AVM'6`.''(,K/SN$@X\C'U-')\"#%X>P@Q^'CX=T@;6%I
M;G1E;F%N8V4N<&AP`,?AR-'MSR#'X<7AW\K1YN3M`.''RN;,SR#DRL?&S"X`
MQ^'%S\['X<?*.B#'X>/,X^;:("5DH2#'X<W/[<O)("5DH2#'X<S/[<_)("5D
MH2#'X>/:S^')("5DH2#;[=$@X]K1YMW)("5D`,W5X2#.V,,`S=7A(,[8PSH`
MW^$@,34@S][MWLD`W^$@,S`@S][MWLD`W^$@-2#/WNW>R0#?X2#/SN;A`-_A
M(.35W2#3Q]K)`-_A(,_>[=[)`,/CR^')(-KA["#'X=[MXSH`RN3=[=`Z`.3*
MYM[:(")"14=)3B(@(-WM(,?AT]C1("5D+@#DRN;>VB`B14Y$.B5S(B#=[2#'
MX=/8T2`E9"X`[<KC(,?AQ]/*SN''U2#CY"`E<RXN+@#AQ\7CW\?D[<D@X>':
MR^;1(-KA["#'X<K=UNWAQ\HN`.''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@
M3$1!4"X`X<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!334(N`,[8PR#=[2#*
MV^WMT2#?X>/)(,?AX]'FT0#=Q]_3`,?ARMC([=['RB#'X>/FS.;/R3H@)7,`
MQ^'CS.'/Q\H@Q^'CYLSFS\DZ`,?AU-'-(,?ARMW5[>'M.@#.V,,@W>T@1V5T
M;W!T.@#'X>/3Q]K/R0#CY"##S.$@X>/-R2#:Q^/)H2#'X=',Q\$@WM''P<D@
MX^'=(%)E861M92#=[2#ET,<@Q^'CS.'/+@#'X<C/Q^W)`-KDYL?D(,?AX^32
MX0#EQ\K=(,?AX^32X0#EYM'/[0#/SN;A(,7A["#EYM'/[0#DV<?C(.7FT<_M
M`.7FT<_M(.'AQ]/AW^T`X>,@[<KC(,7:S\?/(.7FT<_M(,C4W^$@U<WMS0#C
MYN'/(.7FT<_M(,?'RM',X\D`P^W>YN3'RB#=WM@`P^W>YN3'RB#CVB#DU>;5
M`,?3RNW1Q\\`SMC#(-WM(,?AQ]/*[=''SSH`Q^'-WN;A(,?AX]/*YM'/R3H@
M)7,`Q^'-WN;A(,?AX]/*YM'/R3H`RLSE[=(@Q^'(T>WCS"`E<RXN+@#'X>/.
MS^,@W^W1R.W1YM,@T=W6(,?ARLW>WB#CY"#'X>7F[<DN`,?AX=O)`-['QN/)
M(-KDQ^;MY"#'X>/3Q]K/R0#*S>/MX2#'X>/?RLC'RBXN+@#/SN;A`,[1YLP`
MS=7A(,[8PR#AT\C((./'(,/+Y,?!(,?AS\[FX2X@VN'L(,?AP]',S2##Y"#'
MT^,@Q^'CT\K.S^,@P^8@W^'CR2#'X>/1YM'A[=/*(-7-[<W)`,[1YLP`U.71
M("T@T=[C[>0`Q^'(T>W/`,K#W\\@X^0@P^0@4$5!4B#CT=_(R2#FX]K1W<D@
MUN/D(,?AX]/'T2X`Q>34Q\$@Q^'CS.'/("5S`,7/T<?,(,W>YN$@Q^'*Q]'M
MSB#FQ^'FWLHN`,7/T<?,(,?AS=[FX2#'X>/3RN;1S\D`X]C'R-[)(,?AS=[F
MX0#CT-_1Q\H`YM;:(,?AX]#?T<?*.@#/X\P@S./MVB#'X>/AW<?*("5S+G!O
M(,7A["#'X<[AQ]7)+BXN`,_CS"#CX=T@4$\@X^0@P\SA("5S)7,E<R#%X>P@
MQ^'.X<?5R2XN+@#/X\P@Q^'*X=',X\D@X>'(T>WCS"`E<RXN+@#1T\?AR0#4
MY='MQ_``Q^'.X<?5R0#'X<?3XP##R,_'\`#?X>/)(,?AX]'FT2#'X<S/[<_)
M.@#AQP#AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#'X=P@1E10(%9&4RX`
MX<?*YLS/(./:X>;CQ\H@S>;A(,K=UNWAQ\H@3$1!4"X`X<?*YLS/(./:X>;C
MQ\H@S>;A(,K5Y.W=Q\H@4U%,+@#AQ\KFS,\@X]KAYN/'RB#-YN$@Y-W6[>''
MRB!344PN`.''RN;,SR#CVN'FX\?*(,WFX2!397-S:6]N2&%N9&QE<B#CY"##
MS.$@4U%,+@#AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#'X=P@4U%,(%9&
M4RX`X<?*YLS/(./:X>;CQ\H@S>;A(,?ARLW>WB#CY"#'X>7F[<D@X=P@4U%,
M+@#AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#CX=W'RB!344P@5D93+@#A
MQ\KFS,\@R.W'Y,?*(,K-RB#'X>/:T=T@)R5S)R#=[2#CX=T@Q^'CT\?:S\D@
MQ^'#T\?3[2X`X>,@[<KC(,K-S^W/(.';R2#CS>'MR2X`X<?*YLS/(-_AX\D@
MX]'FT2#AX<K-WMX@W^W1R.W1YM,`X<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@
M3$1!4"X`X<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@T<?/[>;3+@#AQ\KFS,\@
MW^'CR2#CT>;1(.'ARLW>WB!334(^`.''RN;,SR##[<D@RMW6[>''RBX`X^''
MS=G'R@#*Y,CMY0#AXR#MVLO1(-KA["#'X>/3RN/:("5S+@#:S\\@Q^'#VN//
MR2#=[2#'X>/ASM4Z`./FQ]W>`-_AX\D@Q^'CT>;1(,?AWL_MX\DZ`,[MQ]''
MR@#.[<?1Q\HZ`./:X>;CQ\H@PL[1[`#/VN,@4$A0(-WM('AG971T97AT.@#?
MX>/)(,?AX]'FT0#*XR#*V^WMT2#?X>/)(,?AX]'FT2$`SMC#(-WM(,7:S\?/
MQ\H@R-'MX\P@W^'CR2#'X>/1YM$`RN3=[=`@VN/A[<?*(,?AU>W'Y,D`Y<?*
MW0#'X=',Q\$@RM+F[<_DQR#CX<[5(,?AX]3?X<DN`,?AT<S'P2#*TN;MS^3'
M(,C'T^,@Q^'CT\K.S^,@YM_AX\D@Q^'3T2X`Q^'1S,?!(,71T\?A(,/M(./4
MW^')(,/F(,[8PR#=[2#'X<C1Y,?CS"#%X>P@:3$X;D!L:7-T<RYH;W)D92YO
M<F<N`-31S2#'X>/4W^')`./4W^')OP#%TN')(,?AR^3'QNT`X>,@[=K+T2#:
MX>P@)R5S)R#=[2#%VL_'S\?*(,?AW"!397-S:6]N2&%N9&QE<BX`X>,@[=K+
MT2#:X>P@)V)A<V5D;B<@W>T@Q=K/Q\_'RB#'X<K-WMX@X^0@Q^'EYNW)+@#A
MXR#MVLO1(-KA["`G8F%S961N)R#=[2#%VL_'S\?*(,?ARMW6[>''RBX`X>,@
M[=K+T2#:X>P@)V)D8U]H;W-T<W!E8R<@W>T@Q=K/Q\_'RB#'X<K-WMX@X^0@
MQ^'EYNW)+@#AXR#MVLO1(-KA["`G9&%T86)A<V4G(-WM(,7:S\?/Q\H@Q^'<
M(%-E<W-I;VY(86YD;&5R+@#AXR#MVLO1(-KA["`G9&%T86)A<V4G(-WM(,7:
MS\?/Q\H@Q^'<(%9&4RX`X>,@[=K+T2#:X>P@)V1A=&%B87-E)R#=[2#%VL_'
MS\?*(,?ARLW>WB#CY"#'X>7F[<DN`.'C(.W:R]$@VN'L("=D871A8F%S92<@
MW>T@Q=K/Q\_'RB#'X<K5Y.W=Q\HN`.'C(.W:R]$@VN'L("=D871A8F%S92<@
MW>T@Q=K/Q\_'RB#'X<K=UNWAQ\HN`.'C(.W:R]$@VN'L("=D;VUA:6XG(-WM
M(,7:S\?/Q\H@Q^'*S=[>(./D(,?AY>;MR2X`X>,@[=K+T2#:X>P@)VAO<W1S
M<&5C)R#=[2#%VL_'S\?*(,?AW"!397-S:6]N2&%N9&QE<BX`X>,@[=K+T2#:
MX>P@)VAO<W1S<&5C)R#=[2#%VL_'S\?*(,?AW"!61E,N`.'C(.W:R]$@VN'L
M("=H;W-T<W!E8R<@W>T@Q=K/Q\_'RB#'X<K-WMX@X^0@Q^'EYNW)+@#AXR#M
MVLO1(-KA["`G:&]S='-P96,G(-WM(,7:S\?/Q\H@Q^'*U>3MW<?*+@#AXR#M
MVLO1(-KA["`G:&]S='-P96,G(-WM(,7:S\?/Q\H@Q^'*W=;MX<?*+@#AXR#M
MVLO1(-KA["`G<&%S<W=O<F0G(-WM(,7:S\?/Q\H@Q^'<(%-E<W-I;VY(86YD
M;&5R+@#AXR#MVLO1(-KA["=P87-S=V]R9"<@W>T@Q=K/Q\_'RB#'X=P@5D93
M+@#AXR#MVLO1(-KA["`G<&%S<W=O<F0G(-WM(,7:S\?/Q\H@Q^'*S=[>(./D
M(,?AY>;MR2X`X>,@[=K+T2#:X>P@)W!A<W-W;W)D)R<@W>T@Q=K/Q\_'RB#'
MX<K5Y.W=Q\HN`.'C(.W:R]$@VN'L("=P87-S=V]R9"<G(-WM(,7:S\?/Q\H@
MQ^'*W=;MX<?*+@#AXR#MVLO1(-KA["`G<&1C7VAO<W1S<&5C)R#=[2#%VL_'
MS\?*(,?ARLW>WB#CY"#'X>7F[<DN`.'C(.W:R]$@VN'L("=P:'!T>7!E)R#=
M[2#%VL_'S\?*(,?AW"!397-S:6]N2&%N9&QE<BX`X>,@[=K+T2#:X>P@)W!H
M<'1Y<&4G(-WM(,7:S\?/Q\H@5D93+@#AXR#MVLO1(-KA["`G<&AP='EP92<@
MW>T@Q=K/Q\_'RB#'X<K-WMX@X^0@Q^'EYNW)+@#AXR#MVLO1(-KA["`G<&AP
M='EP92<@W>T@Q=K/Q\_'RB#'X<K5Y.W=Q\HN`.'C(.W:R]$@VN'L("`G<&AP
M='EP92<@W>T@Q=K/Q\_'RB#'X<K=UNWAQ\H`X>,@[=K+T2#:X>P@)W!O<G0G
M(-WM(,7:S\?/Q\H@5D93+@#AXR#MVLO1(-KA["`G:&]S='-P96,G(-WM(,7:
MS\?/Q\H@Q^'*S=[>(./D(,?AY>;MR2X`X>,@[=K+T2#:X>P@)VAO<W1S<&5C
M)R#=[2#%VL_'S\?*(,?ARLW>WB#CY"#'X>7F[<DN`.'C(.W:R]$@VN'L("=U
M:60G(-WM(,7:S\?/Q\H@Q^'*S=[>(./D(,?AY>;MR2X`X>,@[=K+T2#:X>P@
M)W5I9"<@W>T@Q=K/Q\_'RB#'X<K=UNWAQ\HN`.'C(.W:R]$@VN'L("=U<V5R
M;F%M92<@W>T@Q=K/Q\_'RB#'X=P@4V5S<VEO;DAA;F1L97(N`.'C(.W:R]$@
MVN'L("=U<V5R;F%M92<@W>T@Q=K/Q\_'RB!61E,N`.'C(.W:R]$@VN'L("=U
M<V5R;F%M92<@W>T@Q=K/Q\_'RB#'X<K-WMX@X^0@Q^'EYNW)+@#AXR#MVLO1
M(-KA["`G=7-E<FYA;64G(-WM(,7:S\?/Q\H@Q^'*U>3MW<?*+@#AXR#MVLO1
M(-KA["`G=7-E<FYA;64G(-WM(,7:S\?/Q\H@Q^'*W=;MX<?*+@#AXR#MVLO1
M(-KA["`G=F9S<F]O="<@W>T@Q=K/Q\_'RB!61E,N`-KFS\D@Q>'L(,?ASNW'
MT<?*`,?AS^;1`,W=V2#'X<[MQ]''R@#(S<L@VN0@RMC([=['RB#EYM'/[2XN
M+@#(S<L@VN0@Q^'*T>/MTB#'X<ODQ\;M(.'<(&=E='1E>'0`S<_/(,?AS='F
MW2_'X='CYM(@Q^'*[2#*T>W/Y<<@P\_DQ^4N(.;CY"#+XR#MX]_D(.33SN7'
MYN'5WN7'(-;CY"#'X>35+@#'SLK1(,?AW>;'U>$@X>'*Q]'MSCH`Q\[*T2#*
MY-/MWB#'X<K'T>W..@#'SLK1(,KDT^W>(,?AYM[*.@#%SLK1(,W>X>WD(./*
MX\?+X>WD+@#'SLK1(.';RM\@Q^'CW=;AR3H`P]'3X2#*WM'MT<?P(,CCU-_A
MR2#-U>'*`,W/SR#AV\D@Q^'#YL?CT:$@Q^'4T<T@YL?AX]/'VL_)+@#'SLK1
M(,K-S^W+(,?AU=W-R2#FSNW'T<?*(,?AU,?4R2#'X</.T>PN`,?.RM$@X=O*
MWR#'X>/=UN')(.'AQ=GEQ]$`Q^'DRNW,R2#'X>/.RM71R3H`Q>7CX2#'X=7M
MQ^3)`,7EX\?A+BXN`,C:UB#CX=W'RB#'X<7:S\?/Q\H@Q^'.U<D@R.7FT<_M
M(./=WN;/R2X`R-K6(./AW<?*(,7:S\?/Q\H@R-'MX\S'RB#?X>/)(,?AX]'F
MT2#CW=[FS\D`Q<_.Q]$@S='FW2#.Q]7)`,KC(,?AP^/1(,CDS,?-`,?AX^7C
MQ\H`Y-4@W=[8`./AW2#'X>/3Q]K/R2`E<R#AQR#MR,_#(,C<(#P_>&UL`.'C
M(.W*XR#'X=K+YM$@VN'L(,?AR-'DQ^/,(,?AX]/*SL_C(.'%V>7'T2#'X='3
MQ\;A(./D(.3FVB`H)7,I(-;CY"#DV<?CWRX`Q^'*T\SMX2#MVN3M(-C1[=[)
M(,?ARL['V,@@R.WD(,?AR-''X\P@Q^'CW^;DR2#AY-G'XR#EYM'/[>W,R"#%
MS]''S"##[2#(T>3'X\P@[=KCX2#CVB#EYM'/[2#>SR#*XR#*T=_MR.4@VN3?
MXRX`X<<@[>;,SR#-Q^'MQ_`@X^'=(./3Q]K/R2#CY"##S.$@)7,N`,W5X2#.
MV,,@SN''X2#=RLT@X^'=(,?ARM',X\D@)7,N(,W'YN$@RM3;[>$@=')A;G-L
M871I;VXN<&AP(./:*&9L86<@+60I(.':T=8@T=/'X<D@Q^'.V,,@X^0@X]K'
MX<P@Q^'<('AM;"X`[<K-W^,@Y=#'(,?AX^'=(,C'X<7:S\?/Q\H@Q^''W<K1
MQ];MR2#AR-'MX\S'RB#?X>/)(,?AX]'FT:$@W^/'(.W-S\\@Q^'%VL_'S\?*
M(,?ARNT@[>/?Y"#AX>/3RL[/XR#*VL_MX>7'+@#MRLW?XR#ET,<@Q^'CX=T@
MR,?AQ=K/Q\_'RB#'X=K'X\D@X<C1Q^/,(,?AWNW'S\D@X>'<($U)344@X>'E
MYM'/[>'%V>7'T2#'X>/AW<?*(,?AX]'=WLD@UN/D(-7=S<D@Q^'F[<@@W>T@
MQ^'CRM7=S2X`[<K-W^,@Y=#'(,?AX^'=(-WM(-31[<W)("#'X=/CQ\H@Q^'*
M[2#*T\K.S^,@X=;(V"#'X</AYL?D(.;'X<[8YMCAX<78Q]$@Q^':Q^,@X>7F
MT<_M(,/F(,?AR-''X\P@Q^':Q^/AR2#6X^3E(,?ARNT@X<<@RN/AWR#CX=WE
MQR#'X<['U>'ET,<@Q^'DYMH@X^0@Q^'%VL_'S\?*+@#MRLW?XR#ET,<@Q^'C
MX=T@R.'FQ\;-(,?AP^'FQ^0@YL?ASMCFV"#%UL?=R2##YB#(S^''\"#CY"#%
MVL_'S\?*(.7FT<_M("=(;W)D92<N`.W-RN;M(.70QR#'X>/AW2#:X>P@X\[8
MV"#'X<7CRL_'S\?*(.'AP^3FQ]H@Q^'CY-C>[<D@X>'CX=W'RB#'X<KM(,K,
MVN$@R-''X\SEYM'/[2#>Q\_1R2#:X>P@Q^'*VL?CX2#CVB#(VM8@Q^'#Y.;'
MVB#CY"#'X>/-RN;MQ\H@X>'(T>W/X\OA(,C:UB#CT=W>Q\H@Q^'1T\?&X2##
MYB#CX=W'RB#CY"#DYMH@0U93+@#ET,<@Q^'CX=T@[<WF[2#'X<7:S\?/Q\H@
MQ^'1QNW3[<D@X>7FT<_M+B#MS<KF[2#:X>P@Q^'CT\?1Q\H@YL?AX]_FY,?*
M(,?AP]/'T^W)X>'%V,?1(,?AVL?C(.;,X^W:(,?AR-''X\P@Q^'*[2#*VN/A
M(-;CY"#%V,?1(.7FT<_M+@#ET,<@X^'=(,?AQ=K/Q\_'RB#'X='&[=/M(.'?
MX>/)(,?AX]'FT2#F[<WF[2#CT\?1Q\H@YB#.[<?1Q\H@S./MVB#([='CS,?*
M(-_AX\D@Q^'CT>;1`.W,R"##Y"#MW^;D(.70QR#'X='>XR##W\C1(./D(,?A
MU=W1`.W,R"##Y"#*W^;D(.70Y2#'X=[MX\D@T=[C+@#'X>'>R`#.V,,@W>T@
MQ^'DYMH`VN3FQ^0@Q^'%Y,K1Y.W*`.''(,7CW\?D[<D@X<K;[>W1(,?AT^/'
MS>W'RB#AX^'=(%9&4R`E<R\E<RX`X<<@Q>/?Q^3MR2#AX<7*U<?A(,CCSL_C
M(%-13"X`X<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+@#AQR#%X]_'
MY.W)(.'*T\SMX2#'X<CMQ^3'RB#=[2#ET,<@Q^''RM7'X2X`X<<@RN;,SR#%
MX]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+@#;[=$@WL?/
MT2#:X>P@RM',X\D@X]/*Y,\@Q^'FT<\@Y=#'`,K1Q\S:(-KD(,?ARMOM[=''
MR@#DY<?MR2#;[=$@X][(YN')(.'AX^'=+@##X]$@V^W1(./:T>;=("5S.@#*
MS<_MRR#CX=T@Q^'CT\?:S\D@)7,@X^0@P\SA("5S+@#-S.,@Q^''T\K.S\?C
M.@#'T\K.S^,@Q^'>[>,@Q^'%W<K1Q];MR0#.[<?1Q\H@Q^'CT\K.S^,`Q]/C
M(,?AX]/*SL_C`,[8PR#=[2#'T^,@Q^'CT\K.S^,@YB_#YB#?X>/)(,?AT]$N
M`,?3XR#'X>/3RL[/XSH`RN3([>4`RN3([>4Z`,/3R.;:[<?P`,/EX<<@R-_C
M(,7A["`E<P##Y>''(.;3Y>''("5S`./'(,?AR-'DQ^/,(,?AX\K1UB#:T=;E
M(./D(.7FT<_M(,C:SR#'X<_.YN&_`-KDYL?D(,?AVN/A`.7'RMT@Q^':X^$`
MW\K'R,D@X^'=(,?AX]/'VL_)(,?AX]K/X2#%X>P@)7,N`-/DR2`M(-?7`-/D
MYNW'\`#DVN,`X<?MX]_D(,K;[>W1(-_AX\D@Q^'CT>;1(.'CT\K.S^,@X<+.
MT2X`X<?MX]_D(,K;[>W1(-_AX\D@Q^'CT>;1(.'AX]/*SL_C("5S`,KC(,?A
MSM'FS"#(Y,S'S2X@/&)R("\^(-3?T<?P(.''T\K.S\?CW^,@Y=#'(,?AY-G'
MXRX`[<S((-31S2#'X>/4W^')(-[(X2#'T=/'X2#*WM'MT<?P(,CEQRX`[<S(
M(,7/SL?A(-_AX\D@X]'FT2#,S^W/R0#MS,@@Q<_.Q^$@W^'CR2#'X>/1YM$@
MQ^'>S^WCR0#MS,@@Q<_.Q^$@X]K1W2#'X>/3RL[/XP#MS,@@RL/?[<\@W^'C
MR2#'X>/1YM$@Q^',S^W/R0#'Y,KERB#5X<?-[<D@Q^''RM7'X2`E<RX@Q^'1
MS,?!(,7:Q\_)(,?AS\[FX2X`VN3FQ^0@R-'MS]\@Q^'%X=_*T>;D[3H`Q^'C
MVN'FX\?*(,?AU,[5[<D`Q]/CWSH`VL_C(,K8Q\C>(-WM(-_AX\D@Q^'CT>;1
M(,?AS,_MS\D`RN,@RLW/[<L@Q^'.[<?1Q\H`6\K>T>W1(,?AX]3?X<E=`%O'
MX=/8T2`E<R#CY"`E<UT`S=7A(,[8PSH`RN,@R.3,Q\T`W=3A`,?AQ]/C`-OM
MT2#CYLSFSP#%Y"#CX=W'RB!03R#AX=O)("5S(-OMT2#CYLSFS\D`=D-A<F0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+V-A7T53
M+P``````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S0S`#`R,#$S-0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A
M<W-W9"]L;V-A;&4O8V%?15,O3$-?34534T%'15,O````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`,#(Q-S(R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]C85]%4R],0U]-15-304=%
M4R]P87-S=V0N;6\````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-38U,P`Q,#0Q-S,V,C<T
M,P`P,C,U-S(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````#.````'````(P&```5`0``_`P```````!0$0``*```
M`%$1``!`````>A$``"T```"[$0``"````.D1```B````\A$```4````5$@``
M"````!L2```'````)!(```L````L$@``!0```#@2```?````/A(``!$```!>
M$@``+P```'`2```(````H!(```,```"I$@``"````*T2```5````MA(```H`
M``#,$@``%````-<2``!$````[!(```H````Q$P``$0```#P3```,````3A,`
M``<```!;$P``%0```&,3```0````>1,``!L```"*$P``*0```*83```"````
MT!,```4```#3$P``%@```-D3```0````\!,``!0````!%```+P```!84```/
M````1A0``"8```!6%```!0```'T4```-````@Q0```4```"1%```$````)<4
M```0````J!0```\```"Y%```"P```,D4```/````U10```P```#E%```#P``
M`/(4```@`````A4``!T````C%0``'@```$$5```<````8!4``"T```!]%0``
M(0```*L5```H````S14``"4```#V%0``'P```!P6```#````/!8``!$```!`
M%@``!````%(6```,````5Q8```H```!D%@``!0```&\6```+````=18```P`
M``"!%@``#@```(X6```@````G18```8```"^%@``#@```,46```2````U!8`
M`!````#G%@``"````/@6```0`````1<```8````2%P``!P```!D7``!<````
M(1<```8```!^%P```@```(47```$````B!<``!@```"-%P``$0```*87```/
M````N!<```4```#(%P``!P```,X7```'````UA<```H```#>%P``!````.D7
M```%````[A<```T```#T%P``/`````(8```Z````/Q@``#L```!Z&```/@``
M`+88```=````]1@``!X````3&0``!0```#(9```C````.!D```T```!<&0``
M!P```&H9```1````<AD```@```"$&0``$0```(T9```J````GQD``!X```#*
M&0``!0```.D9```H````[QD``"D````8&@``$P```$(:```(````5AH``#$`
M``!?&@``0@```)$:```5````U!H```L```#J&@``0````/8:```]````-QL`
M`$(```!U&P``/@```+@;```_````]QL``$(````W'```/@```'H<```_````
MN1P``$(```#Y'```/@```#P=```_````>QT``$$```"['0``/0```/T=```^
M````.QX``#\```!Z'@``.P```+H>```\````]AX``$0````S'P``/0```'@?
M```Z````MA\``$(```#Q'P``/@```#0@```_````<R````4```"S(```$0``
M`+D@```$````RR````P```#0(```:````-T@```:````1B$``!<```!A(0``
M%P```'DA```;````D2$``!\```"M(0``$P```,TA```?````X2$``$`````!
M(@``-````$(B```D````=R(```X```"<(@``$````*LB```P````O"(``#H`
M``#M(@``%P```"@C```'````0",```4```!((P``CP```$XC``!T````WB,`
M`,T```!3)```FP```"$E``!S````O24``*8````Q)@``B0```-@F``!S````
M8B<``"$```#6)P``'````/@G```%````%2@```X````;*````P```"HH```@
M````+B@``"4```!/*```*@```'4H```F````H"@```P```#'*```%P```-0H
M```1````["@```P```#^*```"`````LI```)````%"D```<````>*0``"```
M`"8I```&````+RD```T````V*0``"P```$0I```,````4"D```H```!=*0``
M`@```&@I```&````:RD``"@```!R*0``)0```)LI```^````P2D``$4`````
M*@``'P```$8J```?````9BH``!D```"&*@``(0```*`J```P````PBH``!,`
M``#S*@``$`````<K```*````&"L``!\````C*P``'P```$,K```0````8RL`
M``\```!T*P``!0```(0K```S`0``BBL``"H```"^+```20```.DL```P````
M,RT```@```!D+0``(@```&TM```%````D"T```T```"6+0``!@```*0M```2
M````JRT```4```"^+0``(P```,0M```2````Z"T``#4```#[+0``"@```#$N
M```#````/"X```D```!`+@``$@```$HN```1````72X``!4```!O+@``80``
M`(4N```,````YRX``!<```#T+@``#P````PO```)````'"\``!T````F+P``
M$0```$0O```6````5B\``#````!M+P```@```)XO```*````H2\``"8```"L
M+P``&````-,O```7````["\``#<````$,```%P```#PP```H````5#````4`
M``!],```#@```(,P```%````DC````X```"8,```#@```*<P```-````MC``
M`!0```#$,```#P```-DP```*````Z3```!(```#T,```(0````<Q```D````
M*3$``"4```!.,0``*P```'0Q``!#````H#$``"D```#D,0``,`````XR```J
M````/S(``!X```!J,@```P```(DR```4````C3(```4```"B,@``$0```*@R
M```2````NC(```4```#-,@``"P```-,R```-````WS(``!````#M,@``)@``
M`/XR```(````)3,``!4````N,P``$0```$0S```0````5C,```H```!G,P``
M%0```'(S```&````B#,``!````"/,P``B````*`S```1````*30```(````[
M-```!@```#XT```<````130``!@```!B-```$P```'LT```+````CS0```@`
M``";-```"P```*0T```,````L#0```,```"]-````P```,$T```0````Q30`
M`#L```#6-```.P```!(U```]````3C4``#\```",-0``(@```,PU```J````
M[S4```4````:-@``)P```"`V```2````2#8```<```!;-@``$````&,V```+
M````=#8``!0```"`-@``,0```)4V```C````QS8```<```#K-@``+P```/,V
M```]````(S<``!<```!A-P``"@```'DW```W````A#<``%P```"\-P``&@``
M`!DX```-````-#@``$4```!".```1P```(@X``!'````T#@``$<````8.0``
M20```&`Y``!&````JCD``$<```#Q.0``20```#DZ``!'````@SH``$<```#+
M.@``20```!,[``!&````73L``$8```"D.P``2````.L[``!$````-#P``$0`
M``!Y/```1@```+X\``!-````!3T``$(```!3/0``1````)8]``!'````VST`
M`$<````C/@``20```&L^```)````M3X``!````"_/@``!@```-`^```-````
MUSX``'0```#E/@``)@```%H_```A````@3\``"````"C/P``)P```,0_```E
M````[#\```X````20```+0```"%```!*````3T```$$```":0```-0```-Q`
M```+````$D$``!(````>00``+@```#%!``!*````8$$``!X```"K00``!```
M`,I!```&````ST$``)(```#600``K0```&E"``#Q````%T,``+P````)1```
M>P```,9$``#)````0D4``*`````,1@``G0```*U&```I````2T<``"$```!U
M1P``!0```)='```7````G4<```,```"U1P``*@```+E'```N````Y$<``#``
M```32```+@```$1(```-````<T@``!@```"!2```&P```)I(```0````MD@`
M``8```#'2```!P```,Y(```+````UD@```8```#B2```#````.E(```/````
M]D@```T````&20``$@```!1)```3````)TD```(````[20``"0```#Y)```I
M````2$D``"H```!R20``-P```)U)``!#````U4D``"<````92@``)0```$%*
M```<````9TH``"D```"$2@``1P```*Y*```2````]DH``!(````)2P``#@``
M`!Q+```L````*TL``"0```!82P``%@```'U+```0````E$L```4```"E2P``
M`0````````!'`````````#H```",````-P```"````!;````<0`````````M
M`````````&4````J````60```",`````````00`````````:````Q@```!D`
M``")````80```+D````&````*P```(,````=````NP```,T```"G````````
M``X```"%````+P````````"2````;@```)D`````````OP```)8`````````
M`````!8````,````'@```%0````7````O@```!````````````````````##
M`````````#T```"3`````````(T````/````G@````````#%````;P```"0`
M```Q````E`````````!0`````P```$4````G````0````+$```#!````````
M```````5`````````'\````-`````````$(`````````'P```,X`````````
M6@```%,```"<````EP````````#"`````````$8```"C````:0```'H```"Z
M`````````'D```!V````QP```'<````3`````````',``````````````#P`
M```%````&P````D````'````F````!(`````````R@```(L`````````````
M`*T```"'``````````````"F````3P````````#$````-`````@````^````
M``````````!5````J````)4`````````KP```$@```!-````/P```"4```!^
M````FP```(8````+````%`````````!P````I0```"(``````````````*H`
M``"(````MP```&,```!@````CP``````````````I`````````"B````7@``
M`,P```"?````)@````````![````9P````````"A````4@``````````````
M.P```&8```"U````:@```*````!H``````````````!M`````````+(```!L
M````5@````````!.````*0````````"L``````````````"*````"@```#D`
M``"X````$0```(0```"T````.````"@```!1````20```'P```!X````,@``
M`&L`````````8@```!P````P````0P```'T```!D`````````+``````````
MR0```#8`````````-0````````!R````J0```)$```"]````5P```$0```":
M````3````((```#+````@````%T```````````````````!U`````````)``
M```$``````````````".````LP```#,```!T````7P```*L````8````````
M`*X`````````+@```,@```"=````2P```%@````"````O````"$`````````
M@0```,````!*````7````+8````L```````````E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(&ES(')E861Y('1O('!E<F9O
M<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX`
M)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN
M`#(T(&AO=7)S`#QB/D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D.CPO8CX`
M04TO4$T`061D('!A:7(`061D<F5S<P!!9&1R97-S8F]O:P!!;&EA<P!!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%V86EL86)L92!F:65L9',Z
M`$)I;F0@=&\@<V5R=F5R("5S.B5D('=I=&@@1$X@)7,@9F%I;&5D.B!;)61=
M("5S`$)I<G1H9&%Y`$-64P!#86QE;F1A<@!#86YC96P@4')O8FQE;2!297!O
M<G0`0V5L;"!0:&]N90!#:&%N9V4@>6]U<B!P87-S=V]R9`!#:&5C:R!T:&4@
M8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@
M870@=&AI<R!T:6UE+@!#;&]S92!(96QP`$-L;W-E($AE;'`@5VEN9&]W`$-L
M;W-E(%=I;F1O=P!#;VUP86YY`$-O;F9I<FT@;F5W('!A<W-W;W)D.@!#;VYT
M96YT<R!O9B`G)7,G`$-O;G1E;G1S(&]F('1H92!205(@87)C:&EV90!#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!$1`!$86EL
M>0!$871A8F%S92!Q=65R>2!F86EL960N`$1E9F%U;'0@261E;G1I='D`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E
M<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S
M`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>'!E8W1E9"`B0D5'24XB
M(&EN('1H92!L:6YE("5D+@!%>'!E8W1E9"`B14Y$.B5S(B!I;B!L:6YE("5D
M+@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D(')E=')I
M979I;F<@<')E9G,@9F]R(`!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('!R
M969E<F5N8V5S('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A:6QE9"!T;R!O<&5N(&%N($Q$05`@8V]N;F5C=&EO;B!T;R`E
M<RX`1F%I;&5D('1O(')E=')I979E('5S97(G<R!$3CH@6R5D72`E<P!&86EL
M=7)E(&EN(&-H86YG:6YG('!A<W-W;W)D(#H@`$9A>`!&=6QL($1E<V-R:7!T
M:6]N.@!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO<F1E
M($QO9VEN`$AO<F1E(%-Y<W1E;0!(;W)D92!7:7)E;&5S<P!(;W)D92!I<R!N
M;W0@<')O<&5R;'D@8V]N9FEG=7)E9`!);7!O<G0`26UP;W)T($5R<F]R.B``
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N9W5A9V4`
M3&ES="!(96QP(%1O<&EC<P!,;V<@:6X`3&]G(&]U=`!,;V=I;B!F86EL960@
M9F]R('-O;64@<F5A<V]N+B!-;W-T(&QI:V5L>2!Y;W5R('5S97)N86UE(&]R
M('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=O=70`34T`
M36%I;`!-87`@1&%T92!A;F0@5&EM92!&:65L9',`36%P($EM<&]R="!&:65L
M9',`36%T8VAI;F<@9FEE;&1S`$UE;6]S`$UE<W-A9V4`36]N=&AL>0!->2!3
M=6UM87)Y`$YA;64`3F5V97(`3F5W('!A<W-W;W)D.@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@3$1!4"!0<F5F97)E;F-E
M<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!#871E9V]R:65S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%!R969E<F5N8V5S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P<F5F97)E;F-E<R!A<F4@879A:6QA8FQE+@!.;R!P<F5F97)E
M;F-E<R!W97)E(')E=')I979E9"X`3F]T97,`3F]T:69I8V%T:6]N(&QI<W1E
M;F5R("5S(&YO="!F;W5N9"X`3VQD('!A<W-W;W)D.@!/<'1I;VYS`$]T:&5R
M($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960A`%!A<W-W
M;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9`!097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%!R
M;V)L96T_`%)E8FEN9"!T;R!S97)V97(@)7,Z)60@=VET:"!$3B`E<R!F86EL
M960Z(%LE9%T@)7,`4F5F97)R86P@=&%R9V5T("5S(&9O<B!$3B`E<R!I<R!N
M;W0@:6X@=&AE(&%U=&AO<FEZ960@<V5R=F5R(&QI<W0A`%)E9G)E<V@@4W5M
M;6%R>2!6:65W.@!296UO=F4@<&%I<@!297%U:7)E9"`G8F%S961N)R!N;W0@
M<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=B87-E9&XG(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF
M:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I
M;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P
M96,G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(&-A
M=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)VAO<W1S<&5C)R!N
M;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A
M=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S<W=O<F0G(&YO="!S
M<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@
M:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H
M<'1Y<&4G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!P<F5F
M97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B;&4G(&YO="!S
M<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN
M('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=T86)L95)E
M;&%T:6]N<R<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("=U:60G(&YO="!S<&5C:69I960@:6X@875T:&5N
M=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5I9"<@;F]T('-P
M96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF
M:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S
M97)N86UE)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R
M871I;VXN`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I
M;VYS`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X=&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M
M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5T(')E
M8FEN9"!P<F]C(&9A:6QE9#H@6R5D72`E<P!3970@=&AE(&QA;F=U86=E('1H
M870@;65N=2!I=&5M<RP@97AP;&%N871I;VYS+"!A;F0@:&5L<"!A<F4@:6XN
M`%-E="!Y;W5R('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@
M;W!T:6]N<RX`4V5T('EO=7(@<')E9F5R<F5D(&1I<W!L87D@;&%N9W5A9V4N
M`%-H;W)T(%-U;6UA<GDZ`%-K:7`@36%I;G1E;F%N8V4`4V]M92!O9B!(;W)D
M92=S(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I;F<Z`%-O;64@;V8@
M4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@;6ES
M<VEN9SH`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5C8V5S<P!487-K<P!4
M:&4@<F5G:7-T<GD@:7,@:&]W($AO<F1E(&%P<&QI8V%T:6]N<R!F:6YD(&]U
M="!H;W<@=&\@=&%L:R!T;R!E86-H(&]T:&5R+B!9;W4@<VAO=6QD(&QI<W0@
M86YY(&EN<W1A;&QE9"!(;W)D92!A<'!L:6-A=&EO;G,@=&AA="!Y;W4@:&%V
M92!H97)E+@!4:&ES(&9I;&4@8V]N=')O;',@=&AE(&1E9F%U;'0@<')E9F5R
M96YC97,@9F]R(%!A<W-W;W)D(&UO9'5L92P@86YD(&%L<V\@8V]N=')O;',@
M=VAI8V@@<')E9F5R96YC97,@=7-E<G,@8V%N(&%L=&5R+@!4:&ES(&9I;&4@
M8V]N=')O;',@=&AE(&=L;V)A;"!S970@;V8@34E-12!D<FEV97)S(&9O<B!T
M:&4@2&]R9&4@9G)A;65W;W)K+"!A;&QO=VEN9R!A<'!L:6-A=&EO;G,@=&\@
M;6%K92!U<V4@;V8@<')O9W)A;7,@<W5C:"!A<R!E;G-C<FEP="!O<B!M<W=O
M<F1V:65W('1O(')E;F1E<B!C;VYT96YT(&EN=&\@2%1-3"!F;W(@=FEE=VEN
M9R!I;B!A(&)R;W=S97(N`%1H:7,@9FEL92!C;VYT<F]L<R!T:&4@<W1Y;&5S
M:&5E="!T:&%T(&ES('5S960@=&\@<V5T(&-O;&]R<R!A;F0@9F]N=',@9F]R
M('1H92!(;W)D92!F<F%M97=O<FL@86YD(&%L;"!A<'!L:6-A=&EO;G,@=&AA
M="!D;R!N;W0@<')O=FED92!T:&5I<B!O=VX@<V5T=&EN9W,N`%1H:7,@9FEL
M92!C;VYT<F]L<R!T:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S960@=&\@<V5T
M(&-O;&]R<R!A;F0@9F]N=',@:6X@861D:71I;VX@=&\@;W(@;W9E<G)I9&EN
M9R!(;W)D92!D969A=6QT<RX`5&AI<R!F:6QE(&UA<',@9FEL92!E>'1E;G-I
M;VYS('1O(&QO9VEC86P@34E-12!T>7!E<RP@96YA8FQI;F<@2&]R9&4@87!P
M;&EC871I;VYS('1O(&9I9W5R92!O=70@:&]W('1O(&AA;F1L92!S;VUE(&-O
M;G1E;G0@<W5C:"!A<R!E;6%I;"!A='1A8VAM96YT<R!O<B!#5E,@8VAE8VMO
M=71S+@!4:&ES(&ES('1H92!M86EN($AO<F1E(&-O;F9I9W5R871I;VX@9FEL
M92X@270@8V]N=&%I;G,@<&%T:',@86YD(&)A<VEC(&ET96US('1H870@87!P
M;'D@=&\@=&AE(&-O<F4@9G)A;65W;W)K(&%N9"!A;&P@2&]R9&4@87!P;&EC
M871I;VYS+@!4:&ES(&ES('1H92!M86EN(%!A<W-W;W)D(&UO9'5L92!C;VYF
M:6=U<F%T:6]N(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N9"!O<'1I;VYS
M(&9O<B!A;&P@4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N`%1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N
M=6UB97(N`%1I=&QE`%1Y<&4@;6ES;6%T8V@N`%523`!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;6]D:69Y('!R969E<F5N
M8V5S.B!;)61=("5S`%5N86)L92!T;R!R96=I<W1E<B!P<F5F97)E;F-E<R!I
M;B!S97-S:6]N+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N=`!5;F1O($-H86YG97,`56YE>'!E8W1E9"!E;F0@;V8@9FEL92X`57-E
M($1E9F%U;'0@5F%L=64`57-E<B!/<'1I;VYS`%5S97)N86UE`%5S97)N86UE
M.@!787)N:6YG`%=A<FYI;F<A`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9;W4@
M8V%N(&YO="!C:&%N9V4@<&%S<W=D(&9O<B!O=&AE<B!U<V5R`%EO=2!C86XG
M="!C:&%N9V4@<&%S<W=O<F0@9F]R('5S97(@)7,`66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+CQB<B`O/E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E
M;2X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&=I=F4@>6]U
M<B!N97<@<&%S<W=O<F0`66]U(&UU<W0@9VEV92!Y;W5R(&]L9"!P87-S=V]R
M9`!9;W4@;75S="!G:79E('EO=7(@=7-E<FED`%EO=2!M=7-T('9E<FEF>2!Y
M;W5R(&YE=R!P87-S=V]R9`!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S.@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@3F%M93H`66]U<B!N97<@<&%S<W=O<F1S(&1I
M9&XG="!M871C:`!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0
M<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M
M260M5F5R<VEO;CH@<&%S<W=D"E!/5"U#<F5A=&EO;BU$871E.B`R,#`T+3$Q
M+3(Y(#(S.C`Y+3`V,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,2TR.2`R
M,SHR-"!'350K-0I,87-T+51R86YS;&%T;W(Z($IO86X@2F]R8F$@0V%L<VEN
M82`\:F]A;BYJ;W)B84!R=7-C+FYE=#X*3&%N9W5A9V4M5&5A;3H@0V%T86QA
M(&-A7T53(#QI;F9O0')U<V,N;F5T/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`3W!E<F%C:6]N<R!D92!-
M86YT96YI;65N="`E<R`M($-O;F9I<FUA8VGS`"5S(.ES(&$@<'5N="!D)V5F
M96-T=6%R(&QE<R!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96UT(&UA<F-A9&5S
M(&WI<R!A8F%I>"X`)R5S)R!N;R!E<W3@(&-O;F9I9W5R870@96X@96P@4F5G
M:7-T<F4@9&4@2&]R9&4N`#(T(&AO<F5S`#QB/DAA('-U8V-E[W0@=6X@97)R
M;W(@9F%T86PZ(#PO8CX`04TO4$T`069E9VER('!A<F5L;`!!9')EYV$`3&QI
M8G)E=&$@9"=A9')E8V5S`$%L:65S`%,G:&$@97-P96-I9FEC870@=6X@=F%L
M;W(@:6RW;&5G86PN`$-A;7!S(&1I<W!O;FEB;&5S.@!%;FQL8><@86P@<V5R
M=FED;W(@)7,Z)60@86UB($1.("5S(&AA(&9A;&QA=#H@6R5D72`E<P!!;FEV
M97)S87)I`$-64P!#86QE;F1A<FD`0V%N8V5LMVQA<B!);F9O<FUE`%1E;.AF
M;VX@0V5LMVQU;&%R`$-A;G9I82!L82!C;VYT<F%S96YY80!-87)Q=65U(&$@
M;&$@8V%S96QL82!D92!S96QE8V-I\R!L)V]P97)A8VGS(&\@;W!E<F%C:6]N
M<R!Q=64@9&5S:71J974@97AE8W5T87(@96X@87%U97-T82!O8V%S:?,N`%1A
M;F-A<B!!:G5D80!486YC87(@1FEN97-T<F$@9"=!:G5D80!486YC87(@1FEN
M97-T<F$`0V]M<&%N>6EA`$-O;F9I<FUA(&QA(&YO=F$@8V]N=')A<V5N>6$Z
M`$-O;G1I;F=U="!D92`G)7,G`$-O;G1I:6YG=70@9"=A<GAI=2!205(`3F\@
M<R=H82!P;V=U="!O8G)I<B!E;"!M\F1U;"`E<R!-86EN=&5N86YC95]487-K
M`$1$`$1IX')I86UE;G0`0V]N<W5L=&$@82!L82!B87-E(&1E(&1A9&5S(&AA
M(&9A;&QA="X`261E;G1I=&%T(%!R961E=&5R;6EN861A`$1E<V-R:7!C:?,@
M9&5L(%!R;V)L96UA`$5L<R!D971A;&QS(&AA;B!E<W1A="!R96=I<W1R871S
M('!E<B!A(&PG861M:6YI<W1R861O<BX`3W!C:6]N<R!D92!6:7-U86QI>F%C
M:?,`3F\@86-C961I=2!D:7)E8W1A;65N="!A(&UA:6YT96YA;F-E+G!H<`!%
M;6%I;`!297-U;'1A="!B=6ET+@!%<G)O<@!#861A(#$U(&UI;G5T<P!#861A
M(#,P('-E9V]N<P!#861A(#4@;6EN=71S`$-A9&$@26YI8VD@9&4@4V5S<VGS
M`$-A9&$@;6ET:F$@:&]R80!#861A(&UI;G5T`$5X96UP;&4@9&4@=F%L;W)S
M.@!3)V5S<&5R879A(")"14=)3B(@82!L82!L[6YI82`E9"X`4R=E<W!E<F%R
M879A(")%3D0Z)7,B(&$@;&$@;.UN:6$@)60N`$5R<F%D82!A;"!R96-U<&5R
M87(@;&5S('!R969E<NAN8VEE<RX`17)R861A(&%L(')E8W5P97)A<B!L97,@
M<')E9F5RZ&YC:65S('!E<B!A(`!%<G)A9&$@82!L)VEN=&5N=&%R(&-O;FYE
M8W1A<B!A;6(@96P@<V5R=FED;W(@9&4@<')E9F5R96YC:65S($Q$05`N`$5R
M<F%D82!A;"!C;VYN96-T87(@86UB(&5L('-E<G9I9&]R($Q$05`N`$5R<F%D
M82!A(&PG:6YT96YT87(@;V)R:7(@;&$@8V]N;F5X:?,@3$1!4"!A("5S+@!%
M<G)A9&$@86QR96-U<&5R87(@1$X@9&4@;"=U<W5A<FDZ(%LE9%T@)7,`1F%L
M;&ET(&5L(&-A;G9I(&1E(&-O;G1R87-E;GEA`$9A>`!$97-C<FEP8VGS($-O
M;7!L971A.@!!:G5D80!!9')EYV$@4&%R=&EC=6QA<@!496SH9F]N(%!A<G1I
M8W5L87(`2&]R9&4`2&]R9&4@3&]G:6X`4VES=&5M82!(;W)D90!(;W)D92!)
M;F%LX&UB<FEC`$AO<F1E(&YO(&5S=.`@8V]N9FEG=7)A="!C;W)R96-T86UE
M;G0N`$EM<&]R=&%R`$5R<F%D82!D)TEM<&]R=&%C:?,Z(`!#86UP(&EM<&]R
M=&%T.B`E<P!#86UP<R!I;7!O<G1A=',Z`$QL96YG=6%T9V4`3&QI<W1A<B!4
M96UE<R!D)T%J=61A`$5N=')A<@!3;W)T:7(@9&4@<V5S<VGS`%!E<B!A;&=U
M;F$@<F'S(&YO(',G:&$@86-O;G-E9W5I="!O8G)I<B!L82!S97-S:?,N(%!R
M;V)A8FQE;65N="!E;"!V;W-T<F4@;F]M(&0G=7-U<V%R:2!O(&-O;G1R87-E
M;GEA(&AA(&5S=&%T(&EN=')O9'7O="!I;F-O<G)E8W1A;65N="X`1FEN86QI
M='IA<B!397-S:?,`34T`0V]R<F5U`$UA<&5J87(@0V%M<',@9&4@1&%T82!I
M($AO<F$`36%P96IA<B!#86UP<R!A($EM<&]R=&%R`$-A;7!S($-O<G)E<W!O
M;F5N=',`365M;W+@;F1U;7,`36ES<V%T9V4`365N<W5A;&UE;G0`16P@;65U
M(%)E<W5M`$YO;0!-86D`3F]V82!#;VYT<F%S96YY80!.;R!S)VAA(&5S<&5C
M:69I8V%T(&EN9F]R;6%C:?,@<&5R(&$@;&5S(%!R969E<NAN8VEE<R!,1$%0
M+@!.;R!S)VAA(&5S<&5C:69I8V%T(&QA(&EN9F]R;6%C:?,@<&5R(&$@;&5S
M($-A=&5G;W)I97,@4U%,+@!.;R!S)VAA(&5S<&5C:69I8V%T(&QA(&EN9F]R
M;6%C:?,@<&5R(&$@;&5S(%!R969E<NAN8VEE<R!344PN`$YO(',G:&$@97-P
M96-I9FEC870@;&$@:6YF;W)M86-I\R!P97(@82!L)V%U=&5N=&EC86-I\R!P
M97(@4U%,+@!.;R!H:2!H82!P<F5F97+H;F-I97,@9&ES<&]N:6)L97,N`$YO
M(',G:&$@<F5C=7!E<F%T(&-A<"!D92!L97,@<')E9F5RZ&YC:65S+@!.;W1E
M<P!.;R!S)VAA('1R;V)A="!A9V5N="!D92!N;W1I9FEC86-I\R`E<RX`06YT
M:6=A($-O;G1R87-E;GEA`$]P8VEO;G,`06QT<F$@26YF;W)M86-I\P!#;VYT
M<F%S96YY80!#;VYT<F%S96YY82!#86YV:6%D80!-\F1U;"!D92!C86YV:2!D
M92!#;&%U(&YO(&-O;F9I9W5R870@861E8W5A9&%M96YT`%)E86QI='IA<B!/
M<&5R86-I;VYS(&1E($UA;G1E;FEM96YT`%1E;.AF;VX`4VD@=7,@<&QA=2P@
M<')O<&]R8VEO;F5U('5N(')E<W5M(&1E;"!P<F]B;&5M82X`4VD@=7,@<&QA
M=2P@<')O<&]R8VEO;F5U(&5L('9O<W1R92!N;VT@9"=U<W5A<FD@:2!C;VYT
M<F%S96YY80!$97-C<FEP8VGS(&1E;"!0<F]B;&5M80"_4')O8FQE;6$_`%)E
M96YL;&'G(&%L('-E<G9I9&]R("5S.B5D(&%M8B!$3B`E<R!H82!F86QL870Z
M(%LE9%T@)7,`H45L(&)L86YC(&1E(')E9F5RZ&YC:6$@)7,@<&5R(&%L($1.
M("5S(&YO(&5S=.`@9&5F:6YI="!A(&QA(&QL:7-T82!D92!S97)V:61O<G,@
M875T;W)I>F%T<R$`4F5F<F5S8V%R(%9I<W1A(&1E;"!297-U;3H`5')E=7)E
M('!A<F5L;``G8F%S961N)R!R97%U97)I="!N;R!E<W!E8VEF:6-A="!A(&QA
M(&-O;F9I9W5R86-I\R!D92!L)V%U=&5N=&EC86-I\RX`)V)A<V5D;B<@<F5Q
M=65R:70@;F\@97-P96-I9FEC870@82!L82!C;VYF:6=U<F%C:?,@9&4@;&5S
M('!R969E<NAN8VEE<RX`)V1A=&%B87-E)R!R97%U97)I="!N;R!E<W!E8VEF
M:6-A="!A(&QA(&-O;F9I9W5R86-I\R!D92!L)V%U=&5N=&EC86-I\RX`)V1A
M=&%B87-E)R!R97%U97)I="!N;R!E<W!E8VEF:6-A="!A(&QA(&-O;F9I9W5R
M86-I\R!D92!L97,@8V%T96=O<FEE<RX`)V1A=&%B87-E)R!R97%U97)I="!N
M;R!E<W!E8VEF:6-A="!A(&QA(&-O;F9I9W5R86-I\R!D92!L97,@<')E9F5R
MZ&YC:65S+@`G:&]S='-P96,G(')E<75E<FET(&YO(&5S<&5C:69I8V%T(&$@
M;&$@8V]N9FEG=7)A8VGS(&1E(&PG875T96YT:6-A8VGS`"=H;W-T<W!E8R<@
M<F5Q=65R:70@;F\@97-P96-I9FEC870@82!L82!C;VYF:6=U<F%C:?,@9&4@
M;&5S(&-A=&5G;W)I97,N`"=H;W-T<W!E8R<@<F5Q=65R:70@;F\@97-P96-I
M9FEC870@82!L82!C;VYF:6=U<F%C:?,@9&4@;&5S('!R969E<NAN8VEE<RX`
M)W!A<W-W;W)D)R!R97%U97)I="!N;R!E<W!E8VEF:6-A="!A(&QA(&-O;F9I
M9W5R86-I\R!D92!L)V%U=&5N=&EC86-I\RX`)W!A<W-W;W)D)R!R97%U97)I
M="!N;R!E<W!E8VEF:6-A="!A(&QA(&-O;F9I9W5R86-I\R!D92!L97,@8V%T
M96=O<FEE<RX`)W!A<W-W;W)D)R!R97%U97)I="!N;R!E<W!E8VEF:6-A="!A
M(&QA(&-O;F9I9W5R86-I\R!D92!L97,@<')E9F5RZ&YC:65S+@`G<&AP='EP
M92<@<F5Q=65R:70@;F\@97-P96-I9FEC870@82!L82!C;VYF:6=U<F%C:?,@
M9&4@;"=A=71E;G1I8V%C:?,N`"=P:'!T>7!E)R!R97%U97)I="!N;R!E<W!E
M8VEF:6-A="!A(&QA(&-O;F9I9W5R86-I\R!D92!L97,@8V%T96=O<FEE<RX`
M)W!H<'1Y<&4G(')E<75E<FET(&YO(&5S<&5C:69I8V%T(&$@;&$@8V]N9FEG
M=7)A8VGS(&1E(&QE<R!P<F5F97+H;F-I97,N`"=T86)L92<@<F5Q=65R:70@
M;F\@97-P96-I9FEC870@82!L82!C;VYF:6=U<F%C:?,@9&4@;"=A=71E;G1I
M8V%C:?,N`"=T86)L92<@<F5Q=65R:70@;F\@97-P96-I9FEC870@82!L82!C
M;VYF:6=U<F%C:?,@9&4@;&5S(&-A=&5G;W)I97,N`"=T86)L92<@<F5Q=65R
M:70@;F\@97-P96-I9FEC870@82!L82!C;VYF:6=U<F%C:?,@9&4@;&5S('!R
M969E<NAN8VEE<RX`)W1A8FQE4F5L871I;VYS)R!R97%U97)I="!N;R!E<W!E
M8VEF:6-A="!A(&QA(&-O;F9I9W5R86-I\R!D92!L97,@8V%T96=O<FEE<RX`
M)W5I9"<@<F5Q=65R:70@;F\@97-P96-I9FEC870@82!L82!C;VYF:6=U<F%C
M:?,@9&4@;"=A=71E;G1I8V%C:?,N`"=U:60G(')E<75E<FET(&YO(&5S<&5C
M:69I8V%T(&$@;&$@8V]N9FEG=7)A8VGS(&1E(&QA<R!P<F5F97+H;F-I97,N
M`"=U<V5R;F%M92<@<F5Q=65R:70@;F\@97-P96-I9FEC870@82!L82!C;VYF
M:6=U<F%C:?,@9&4@;"=A=71E;G1I8V%C:?,N`"=U<V5R;F%M92<@<F5Q=65R
M:70@;F\@97-P96-I9FEC870@82!L82!C;VYF:6=U<F%C:?,@9&4@;&5S(&-A
M=&5G;W)I97,N`"=U<V5R;F%M92<@<F5Q=65R:70@;F\@97-P96-I9FEC870@
M82!L82!C;VYF:6=U<F%C:?,@9&4@;&5S('!R969E<NAN8VEE<RX`4F5I;FEC
M:6%R`%1O<FYA<B!A($]P8VEO;G,`1G5N8VGS`$1E<V%R($]P8VEO;G,`4V5L
M96-C:6]N974@96QS(&-A<N!C=&5R<R!Q=64@;F5C97-S:71E=2!D92!L97,@
M8V%S96QL97,@9&4@<V]T82X@4&]D974@8V]P:6%R+6QO<R!I(&5N9V%N>&%R
M+6QO<R!D92!L)^!R96$@9&4@=&5X="X`4V5L96-C:6]N974@96P@9&5L:6UI
M=&%D;W(@9&4@;&$@9&%T83H`4V5L96-C:6]N974@96P@9F]R;6%T(&1E(&QA
M(&1A=&$Z`%-E;&5C8VEO;F5U(&5L(&9O<FUA="!D92!L)VAO<F$Z`%-E;&5C
M8VEO;F5U(&1O<R!C86UP<R!Q=64@8V]I;F-I9&5I>&EN+@!396QE8V-I;VYI
M(&5L('-E=2!L;&5N9W5A=&=E('!R969E<FET`$5N=FEA<B!);F9O<FUE`$5R
M<F%D82!A;"!F:7AA<B!E;"!P<F]C(&1E;"!R965N;&QAYSH@6R5D72`E<P!%
M<W1A8FQE:7@@96P@;&QE;F=U871G92!E;B!E;"!Q=64@97-T86X@96QS(&UE
M;G5S+"!E>'!L:6-A8VEO;G,@:2!L82!A:G5D80!%<W1A8FQE:7@@96P@<F5F
M<F5S8R!D92!PX&=I;F$@:2!A;'1R97,@;W!C:6]N<R!D92!V:7-U86QI='IA
M8VGS+@!%<W1A8FQE:7@@96P@=F]S=')E(&ED:6]M82!P<F5F97)I="!D92!V
M:7-U86QI='IA8VGS+@!"<F5U(%)E<W5M.@!/;6ET:7(@36%N=&5N:6UE;G0`
M1F%L=&5N(&%L9W5N<R!A<GAI=7,@9&4@8V]N9FEG=7)A8VGS(&1E($AO<F1E
M.@!!;&=U;G,@9&5L<R!A<GAI=7,@9&4@;?)D=6P@9&4@8V]N9FEG=7)A8VGS
M(&1E(&-A;G9I(&1E(&-L874@;F\@97,@=')O8F5N.@!%;G1R861A(&1E($-A
M<N!C=&5R<R!%<W!E8VEA;',`R'AI=`!&96EN97,`16P@<F5G:7-T<F4@Z7,@
M8V]M(&QE<R!A<&QI8V%C:6]N<R!D92!(;W)D92!D971E<FUI;F5N(&-O;75N
M:6-A<BUS92!E;G1R92!E;&QE<R!M871E:7AE<RX@2&5U(&1E(&QL:7-T87(@
M8V%D82!A<&QI8V%C:?,@9&4@2&]R9&4@<75E('1I;F=U974@87%U[2X`07%U
M97-T(&%R>&EU(&-O;G1R;VQA(&QE<R!P<F5F97)E;F-I97,@<&5R(&1E9F5C
M=&4@9&5L(&WR9'5L(&1E(&-A;G9I(&1E(&-O;G1R87-E;GEA(&D@82!M97,@
M82!M97,@8V]N=')O;&$@<75I;F5S('-O;B!L97,@<')E9F5R96YC:65S('%U
M92!P;V1E;B!S97(@86QT97)A9&5S('!E;',@=7-U87)I<RX`07%U97-T(&%R
M>&EU(&-O;G1R;VQA(&5L(&-O;FIU;G0@9VQO8F%L(&1E(&-O;G1R;VQA9&]R
M<R!-24U%('!E<B!A(&QA(&5S=')U8W1U<F$@2&]R9&4L('!E<FUE=&5N="!A
M(&QE<R!A<&QI8V%C:6]N<R!F97(@^G,@9&4@<')O9W)A;65S('1A;',@8V]M
M;R!E;G-C<FEP="!O(&US=V]R9'9I97<@<75E('1R861U96EX96X@96P@8V]N
M=&EN9W5T(&5N($A434P@<&5R(&$@=FES=6%L:71Z87(M;&\@96X@=6X@;F%V
M96=A9&]R+@!!<75E<W0@87)X:74@8V]N=')O;&$@96P@9G5L;"!D)V5S=&EL
M('%U92!S)W5T:6QI='IA('!E<B!F:7AA<B!C;VQO<G,@:2!T:7!U<R!D92!L
M;&5T<F$@<&5R(&$@;"=E<W1R=6-T=7)A($AO<F1E(&D@=&]T97,@;&5S(&%P
M;&EC86-I;VYS('%U92!N;R!P<F]V965I>&EN(&QE<R!S979E<R!P<O)P:65S
M(&-O;F9I9W5R86-I;VYS+@!!<75E<W0@87)X:74@8V]N=')O;&$@96QS(&5S
M=&EL<R!Q=64@<V]N('5S871S('!E<B!E<W1A8FQI<B!C;VQO<G,@:2!F;VYT
M<R#S('-O8G)E97-C<FEU<F4@96QS('9A;&]R<R!P97(@9&5F96-T92!D92!(
M;W)D92X`07%U97-T(&%R>&EU(&UA<&5J82!L97,@97AT96YS:6]N<R!D)V%R
M>&EU(&$@=&EP=7,@34E-12!L\F=I8W,L('!E<FUE=&5N="!A(&QE<R!A<&QI
M8V%C:6]N<R!(;W)D92!C;VUP<F5N9')E(&-O;2!F97(@=71I;&ET>F%R(&%L
M9W5N<R!C;VYT:6YG=71S=&%L<R!C;VT@87)X:75S(&%D:G5N=',@96X@96P@
M8V]R<F5U(&\@:6YS<&5C8VEO;G,@82!#5E,N`$%Q=65S="#I<R!L)V%R>&EU
M('!R:6YC:7!A;"!D92!C;VYF:6=U<F%C:?,@9&4@+B!#;VYTZ2!R=71E<R!A
M82!A<GAI=7,@:2!E;&5M96YT<R!BX'-I8W,@<75E(&%P;&EQ=65N(&5L(&YU
M8VQI(&1E(&PG97-T<G5C='5R82!I('1O=&5S(&QE<R!A<&QI8V%C:6]N<R!D
M92!(;W)D92X`07%U97-T(&5S(&5L(&%R>&EU('!R:6YC:7!A;"!D92!C;VYF
M:6=U<F%C:?,@9&5L(&WR9'5L(&1E(&-A;G9I;R!D92!C;VYT<F%S96YY82X@
M0V]N=.D@<G5T97,@:2!O<&-I;VYS('!E<B!T;W1S(&5L<R!G=6EO;G,@9&5L
M(&WR9'5O(&1E(&-A;G9I(&1E(&-O;G1R87-E;GEA+@!!<75E<W0@;OIM97)O
M(&AA(&1E('-E<B!C;VT@82!M[6YI;2!U;B`Q+@!!<75E<W0@=F%L;W(@:&$@
M9&4@<V5R('5N(&[Z;65R;RX`5.UT;VP`16P@=&EP=7,@;F\@8V]I;F-I9&5I
M>"X`55),`$EN8V%P8><@9&4@8V]N;F5C=&%R<V4@86P@<V5R=FED;W(@9&4@
M4U%,+@!);F-A<&'G(&1E(&UO9&EF:6-A<B!L97,@<')E9F5RZ&YC:65S.B!;
M)61=("5S`$EN8V%P8><@9"=E;G)E9VES=')A<B!P<F5F97+H;F-I97,@96X@
M;&$@<V5S<VGS+@!.;R#I<R!P;W-S:6)L92!T<F%D=6ER(&%Q=65S="!D;V-U
M;65N="!D92!7;W)D`$1E<V9E<B!#86YV:7,`1FEN86P@9"=A<GAI=2!I;F5S
M<&5R870N`%5T:6QI='IA<B!686QO<B!P97(@1&5F96-T90!/<&-I;VYS(&0G
M57-U87)I`%5S=6%R:0!5<W5A<FDZ`$%D=F5R=.AN8VEA`*%!=NUS(0!3971M
M86YA;&UE;G0`0F5N=FEN9W5T<R!A("5S`$)E;G9I;F=U="P@)7,`061R9>=A
M(&1E(&QA($9E:6YA`%1E;.AF;VX@9&4@;&$@1F5I;F$`04$`06YU86QM96YT
M`$YO('!O=',@8V%N=FEA<B!L82!C;&%U(&$@=6X@86QT<F4@=7-U87)I`%9O
M<W3H(&YO('!O="!C86YV:6%R(&QA(&-L874@<&5L('5S=6%R:2`E<P!(974@
M=&%N8V%T(&QA('-E<W-I\RX@1W+@8VEE('-P97(@=71I;&ET>F%R(&5L('-I
M<W1E;6$N`$AE=2!D92!D97-C<FEU<F4@96P@<')O8FQE;6$@86)A;G,@9"=E
M;G9I87(@;"=I;F9O<FUE(&1E;"!P<F]B;&5M82X`2&%S(&0G97-C<FEU<F4@
M;&$@=&5V82!N;W9A(&-O;G1R87-E;GEA`$AA<R!D92!E<V-R:75R92!L82!A
M;G1I9V$@8V]N=')A<V5N>6$`2&%S(&0G97-C<FEU<F4@96P@=&5U('5S=6%R
M:0!(87,@9&4@=F5R:69I8V%R(&QA('1E=F$@;F]V82!C;VYT<F%S96YY80!,
M82!V;W-T<F$@<V5S<VGS(&5N("5S(&AA(&5X<&ER870N(%-I('5S('!L874L
M(&EN:6-I974@=6YA(&YO=F$@<V5S<VGS+@!#;W)R974@16QE8W1R\FYI8SH`
M3&$@<V5V82!);F9O<FUA8VGS`$5L('9O<W1R92!.;VTZ`$QA(&-O;G1R87-E
M;GEA(&YO=F$@:2!L82!A;G1I9V$@;F\@8V]N8V]R9&5N`$QE<R!O<&-I;VYS
M(&AA;B!E<W1A="!A8W1U86QI='IA9&5S+@!;26YF;W)M92!D96P@4')O8FQE
M;6%=`%ML[6YI82`E<R!D92`E<UT`=D-A<F0`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+VQO8V%L92]D85]$2R\`````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,C`Q,C4`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+V1A7T1++TQ#7TU%
M4U-!1T53+P``````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8R-S0S`#`R,3<Q,@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L
M;V-A;&4O9&%?1$LO3$-?34534T%'15,O<&%S<W=D+FUO````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-#8V-C``,3`T,3<S-C(W-#,`,#(S-38Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-X2!)4`````W````!P```#\
M!@``)0$``-P-````````<!(``"@```!Q$@``0````)H2```(````VQ(```4`
M``#D$@``#P```.H2```(````^A(```@````#$P``&0````P3```'````)A,`
M``L````N$P``#@```#H3```%````21,``"X```!/$P``*P```'X3```1````
MJA,``"(```"\$P``+@```-\3```(````#A0```0````7%````P```!P4```(
M````(!0``!4````I%```"@```#\4```/````2A0``!0```!:%```%P```&\4
M``!$````AQ0```H```#,%```$0```-<4```,````Z10```<```#V%```$```
M`/X4```5````#Q4``!\````E%0``&P```$45```8````814``!T```!Z%0``
M(````)@5```I````N14``"$```#C%0```@````46```%````"!8``!8````.
M%@``$````"46```&````-A8``!0````]%@``"P```%(6```F````7A8```4`
M``"%%@``#0```(L6```%````F18``"````"?%@``"P```,`6```/````S!8`
M`"````#<%@``'0```/T6```#````&Q<``"T````?%P``(0```$T7```H````
M;Q<``!\```"8%P```P```+@7```,````O!<``!$```#)%P``"0```-L7```$
M````Y1<```P```#J%P``"@```/<7```%`````A@```L````(&```#````!08
M```9````(1@```X````[&```(````$H8```&````:Q@```X```!R&```$@``
M`($8```0````E!@``!$```"E&```$````+<8```:````R!@```8```#C&```
M!P```.H8```&````\A@```(```#Y&```!````/P8```8`````1D``!$````:
M&0``#P```"P9```'````/!D```<```!$&0``!````$P9```'````41D```T`
M``!9&0``!````&<9```\````;!D``#H```"I&0``.P```.09```^````(!H`
M`!8```!?&@``'0```'8:```>````E!H```4```"S&@``#0```+D:```(````
MQQH``!$```#0&@``*@```.(:```:````#1L``!4````H&P``'@```#X;```%
M````71L```T```!C&P``*````'$;```I````FAL```T```#$&P``$P```-(;
M```(````YAL```L```#O&P``0````/L;```]````/!P``$(```!Z'```/@``
M`+T<```_````_!P``$(````\'0``/@```'\=```_````OAT``$(```#^'0``
M/@```$$>```_````@!X``#8```#`'@``00```/<>```]````.1\``#X```!W
M'P``/P```+8?```[````]A\``#P````R(```1````&\@```]````M"```#H`
M``#R(```0@```"TA```^````<"$``#\```"O(0``!0```.\A```1````]2$`
M``0````'(@``#`````PB``!H````&2(``!H```""(@``%P```)TB```7````
MM2(``!L```#-(@``$P```.DB```&````_2(```X````$(P``$````!,C```P
M````)",``#H```!5(P``%P```)`C```'````J",``"8```"P(P``*@```-<C
M```%`````B0``(\````()```+@```)@D```R````QR0``%4```#Z)```S0``
M`%`E``"<````'B8``*8```"[)@``B0```&(G``!S````["<```4```!@*```
M#@```&8H```#````=2@``"````!Y*```'P```)HH```J````NB@``"8```#E
M*```#`````PI```7````&2D``!$````Q*0``#@```$,I```/````4BD```@`
M``!B*0``"0```&LI```4````=2D```<```"**0``"````)(I```&````FRD`
M``L```"B*0``#````*XI```*````NRD```(```#&*0``!@```,DI```E````
MT"D``$4```#V*0``'P```#PJ```?````7"H``"8```!\*@``)0```*,J```A
M````R2H``!,```#K*@``"@```/\J``!R````"BL``',```!]*P``40```/$K
M```W````0RP``#8```![+```/@```+(L``!!````\2P``$,````S+0``0```
M`'<M```^````N"T``$````#W+0``10```#@N```Y````?BX``!\```"X+@``
M$````-@N```1````Z2X``#4!``#[+@``(````#$P```X````4C````@```"+
M,```!0```)0P```5````FC````D```"P,```#````+HP```B````QS````<`
M``#J,```#P```/(P```.`````C$```D````1,0``,P```!LQ```C````3S$`
M`!0```!S,0``)@```(@Q```\````KS$```H```#L,0``!````/<Q```#````
M_#$```@`````,@``'0````DR```%````)S(```T````M,@``$0```#LR```3
M````33(``"P```!A,@``%````(XR```7````HS(```H```"[,@``!0```,8R
M```/````S#(``!0```#<,@``&````/$R```8````"C,``!@````C,P``+```
M`#PS```M````:3,``"P```"7,P``*@```,0S```"````[S,```8```#R,P``
M%P```/DS```2````$30```0````D-```$0```"DT```,````.S0``"@```!(
M-```!0```'$T```/````=S0```0```"'-```)@```(PT```/````LS0``!``
M``##-```'@```-0T```?````\S0```,````3-0``/````!<U```L````5#4`
M`"\```"!-0``*0```+$U```#````VS4```T```#?-0``$0```.TU```.````
M_S4```4````.-@``#@```!0V```.````(S8```4````R-@``"P```#@V```,
M````1#8``!L```!1-@``#0```&TV```B````>S8```8```">-@``$P```*4V
M```6````N38``!,```#0-@``#P```.0V```9````]#8``"`````.-P``!P``
M`"\W```&````-S<```8````^-P```@```$4W```$````2#<``!P```!--P``
M%P```&HW```6````@C<```8```"9-P``"````*`W```$````J3<```<```"N
M-P``#````+8W```'````PS<``#H```#+-P``.`````8X```Y````/S@``#D`
M``!Y.```&0```+,X```H````S3@``"D```#V.```!0```"`Y```0````)CD`
M``<````W.0``%@```#\Y```D````5CD``!8```![.0``&0```)(Y```5````
MK#D```<```#".0``$0```,HY```Z````W#D``"8````7.@``#@```#XZ```2
M````33H```@```!@.@``"````&DZ``!#````<CH``#@```"V.@``10```.\Z
M```_````-3L``#H```!U.P``1````+`[```_````]3L``#H````U/```1```
M`'`\```_````M3P``#H```#U/```-P```#`]``!#````:#T``#X```"L/0``
M.0```.L]``!!````)3X``#P```!G/@``-P```*0^``!%````W#X``#\````B
M/P``-0```&(_``!$````F#\``#\```#=/P``.@```!U````'````6$```!L`
M``!@0```!0```'Q````3````@D```&$```"60```%@```/A````0````#T$`
M`!`````@00``*````#%!```7````6D$```8```!R00``$0```'E!```;````
MBT$``"D```"G00``,0```-%!```?`````T(```<````C0@``'@```"M"```=
M````2D(```<```!H0@``BP```'!"```]````_$(``#@````Z0P``3P```'-#
M``#-````PT,``(4```"11```GP```!=%``"2````MT4``'H```!*1@``!0``
M`,5&```+````RT8```,```#71@``+0```-M&```A````"4<``#T````K1P``
M*````&E'```1````DD<``!<```"D1P``$@```+Q'```6````ST<``!<```#F
M1P``"@```/Y'```+````"4@``!,````52```"````"E(```)````,D@```@`
M```\2```#0```$5(```1````4T@``!$```!E2````@```'=(```%````>D@`
M`"H```"`2```2@```*M(```=````]D@``"`````420``+P```#5)```P````
M94D``"````"620``$@```+=)```)````RDD``((```#420``@P```%=*``!*
M````VTH``$4````F2P``+P```&Q+```_````G$L``#,```#<2P``/````!!,
M```W````34P``"T```"%3```.0```+-,```]````[4P``#$````K30``*@``
M`%U-```4````B$T``!(```"=30```0```*\```"+````4````#(````$````
M.@```&\```#2````R@```+L```"S````,0````````!-````0P```*4```!$
M````6``````````B````0````$$```"A````+0````,```!A````D@``````
M```K``````````````!Z````-````+H````;````=P``````````````#```
M`"@```!S````+@```#@``````````@``````````````'`````````"D````
M4P`````````Y````S````,0```">```````````````(````HP```$X```"X
M`````````)H``````````````*````!/````.P`````````'````9````)<`
M````````K````"D````:````U0```,,```#:````5P```&(```"R````"P``
M`'X```#7`````````(0```!N````V````,$```!Y````?````+$`````````
MC```````````````CP````````#1````C@```#X```!G````@0```$@```!+
M````U````'\`````````M0```(H`````````RP```(8```!I`````````!T`
M``#'````#P```"4````@````7P```$(```"G````:`````X````C````OP``
M`'8```")````70```)``````````)````!<```!6`````````)@```"`````
MO````!(`````````$````(T```#-````-0````D```!T````L````'4````5
M``````````````#9````VP````````!@````O0```$8````\````T````'$`
M``"9````SP```"<```!;````$P````````!9````,P````````#3````````
M``````![````40`````````>````4@```-8`````````N0````````"6````
M`````+8```!C````O@``````````````/0```$<`````````P````*X`````
M````K0````````!>````FP```,8`````````@@```!\`````````````````
M``"1`````````$D```"=`````````*H`````````J````)0```!]````10``
M`(@```#(````&0`````````O````P@```!@`````````%@```-P````&````
MR0```(,`````````7```````````````6@```%0`````````:@````4`````
M````````````````````2@```&L````1`````````,X````L````90``````
M```_````DP```%4```!R````;0```*L```#%````%`````````"I````G```
M`(<```!,````,````#<```!X````#0`````````*````9@```&P`````````
MA0```"H```"T````GP```"8``````````````+<````A````H@``````````
M````E0`````````V````<````*8`````)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`#(T(&AO
M=7)S`$%-+U!-`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E<@!!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<V)O;VL`
M061M:6YI<W1R871I;VX`06QI87,`071T96UP="!T;R!B:6YD(&9A:6QE9#H@
M;F\@96YT<GD@9F]U;F0@9F]R("5S+@!!='1E;7!T('1O(&)I;F0@=VET:&]U
M="!A('9A;&ED(&-O;FYE8W1I;VXN`$%V86EL86)L92!F:65L9',Z`$)A8VME
M;F0@;F]T(&-O<G)E8W1L>2!I;7!L96UE;G1E9"X`0FEN9"!T;R!S97)V97(@
M)7,L(&1N("5S(&%S("5S(&9A:6QE9#H@6R5D72`E<P!":7)T:&1A>0!"=6=S
M`$-64P!#86QE;F1A<@!#86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N
M90!#:&%N9V4@4&%S<W=O<F0`0VAA;F=E('EO=7(@<&%S<W=O<F0`0VAA;F=I
M;F<@4&%S<W=O<F0@;VX@)7,`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A
M=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VQO
M<V4@2&5L<`!#;&]S92!(96QP(%=I;F1O=P!#;&]S92!7:6YD;W<`0V]M<&%N
M>0!#;VYF:7)M(%!A<W-W;W)D`$-O;F9I<FT@;F5W('!A<W-W;W)D.@!#;VYT
M96YT<R!O9B!T:&4@1UII<'!E9"!487)B86QL`$-O;G1E;G1S(&]F('1H92!2
M05(@87)C:&EV90!#;VYT96YT<R!O9B!T:&4@6FEP(&9I;&4`0V]U;&0@;F]T
M(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A
M<"!S97)V97(`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N`$1$`$1A
M:6QY`$1A=&%B87-E('%U97)Y(&9A:6QE9"X`1&5F875L="!)9&5N=&ET>0!$
M96QE=&4`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&ES8W5S<VEO;G,`1&\@;F]T
M(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``16UA:6P`16UP='D@
M<F5S=6QT+@!%<G)O<@!%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D
M+@!%=F5R>2!,;V=I;@!%>&%M<&QE('9A;'5E<SH`17AP96-T960@(D)%1TE.
M(B!I;B!T:&4@;&EN92`E9"X`17AP96-T960@(D5.1#HE<R(@:6X@;&EN92`E
M9"X`1E10`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<')E9F5R96YC97,@
M<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I
M;&5D('1O(&]P96X@86X@3$1!4"!C;VYN96-T:6]N('1O("5S+@!&86EL=7)E
M(&EN(&-H86YG:6YG('!A<W-W;W)D(#H@`$9A>`!&:6QE($UA;F%G97(`1G5L
M;"!$97-C<FEP=&EO;CH`2&5A9&QI;F5S`$AE;'``2&]M92!!9&1R97-S`$AO
M;64@4&AO;F4`2&]R9&4`2&]R9&4@3&]G:6X`2&]R9&4@4WES=&5M`$AO<F1E
M(%5S97(@061M:6YI<W1R871I;VX`2&]R9&4@5VER96QE<W,`2&]R9&4@:7,@
M;F]T('!R;W!E<FQY(&-O;F9I9W5R960`26UP;W)T`$EM<&]R="!%<G)O<CH@
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN8V]R96-T
M(%!A<W-W;W)D`$QI<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&]G(&EN`$QO9R!O=70`3&]G;W5T`$U-`$UA:6P`36%P($1A
M=&4@86YD(%1I;64@1FEE;&1S`$UA<"!);7!O<G0@1FEE;&1S`$UA=&-H:6YG
M(&9I96QD<P!-97-S86=E`$UO;G1H;'D`3F%M90!.971W;W)K`$YE=R!P87-S
M=V]R9#H`3F5W<P!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@3$1!4"!0<F5F97)E;F-E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!#871E9V]R:65S+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%!R
M969E<F5N8V5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(&%U=&AE;G1I8V%T:6]N+@!.;R!E;G1R>2!F;W5N9"!F
M;W(@)7,N`$YO('!R969E<F5N8V5S(&%R92!A=F%I;&%B;&4N`$YO('!R969E
M<F5N8V5S('=E<F4@<F5T<FEE=F5D+@!.;W1E<P!/;&0@<&%S<W=O<F0Z`%!A
M<W-W;W)D`%!A<W-W;W)D(&-H86YG960A`%!A<W-W;W)D(&UO9'5L92!I<R!N
M;W0@<')O<&5R;'D@8V]N9FEG=7)E9`!087-S=V]R9',@8V%N;F]T(&)E(&)L
M86YK+@!087-S=V]R9',@;75S="!M871C:"X`4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS`%!H;VYE`%!L96%S92!L;V<@:6X`4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0<F5S96YT871I;VYS`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4')O8FQE;3\`4F5M;W9E('!A:7(`4F5Q=6ER960@
M)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G8F%S961N)R!N;W0@<W!E8VEF:65D(&EN
M('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D871A8F%S
M92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`G9&%T86)A<V4G(&YO="!S<&5C:69I960@:6X@8V%T
M96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G9&%T86)A<V4G(&YO
M="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T
M:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=H;W-T<W!E8R<@;F]T('-P
M96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=H;W-T<W!E8R<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I960@
M:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A
M<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN('!R
M969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N
M;W0@<W!E8VEF:65D(&EN(%-13"!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I
M;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E
M)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A
M=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B;&4G(&YO="!S<&5C
M:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M=&%B;&4G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W1A8FQE4F5L871I;VYS)R!N;W0@<W!E8VEF:65D
M(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5I9"<@
M;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`G=6ED)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I
M9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@
M:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5S970`4F5T=7)N('1O
M($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT87)E82X`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N`%-E;F0@4')O8FQE;2!297!O<G0`4V5R=F5R`%-H;W)T(%-U
M;6UA<GDZ`%-K:7`@36%I;G1E;F%N8V4`4V]M92!O9B!(;W)D92=S(&-O;F9I
M9W5R871I;VX@9FEL97,@87)E(&UI<W-I;F<Z`%-O;64@;V8@4&%S<W=O<F0@
M;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@;6ES<VEN9SH`4W!E
M8VEA;"!#:&%R86-T97(@26YP=70`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D
M960@)R5S)R!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`G
M)7,G(&9R;VT@=&AE('-Y<W1E;2X`5&%S:W,`5&AE(')E9VES=')Y(&ES(&AO
M=R!(;W)D92!A<'!L:6-A=&EO;G,@9FEN9"!O=70@:&]W('1O('1A;&L@=&\@
M96%C:"!O=&AE<BX@66]U('-H;W5L9"!L:7-T(&%N>2!I;G-T86QL960@2&]R
M9&4@87!P;&EC871I;VYS('1H870@>6]U(&AA=F4@:&5R92X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+@!4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M+@!4
M:&ES(&9I;&4@8V]N=&%I;G,@8F%C:V5N9"!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N(&9O<B!T:&4@4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N`%1H:7,@
M9FEL92!C;VYT<F]L<R!T:&4@9VQO8F%L('-E="!O9B!-24U%(&1R:79E<G,@
M9F]R('1H92!(;W)D92!F<F%M97=O<FLL(&%L;&]W:6YG(&%P<&QI8V%T:6]N
M<R!T;R!M86ME('5S92!O9B!P<F]G<F%M<R!S=6-H(&%S(&5N<V-R:7!T(&]R
M(&US=V]R9'9I97<@=&\@<F5N9&5R(&-O;G1E;G0@:6YT;R!(5$U,(&9O<B!V
M:65W:6YG(&EN(&$@8G)O=W-E<BX`5&AI<R!F:6QE(&-O;G1R;VQS('1H92!S
M='EL97-H965T('1H870@:7,@=7-E9"!T;R!S970@8V]L;W)S(&%N9"!F;VYT
M<R!F;W(@=&AE($AO<F1E(&9R86UE=V]R:R!A;F0@86QL(&%P<&QI8V%T:6]N
M<R!T:&%T(&1O(&YO="!P<F]V:61E('1H96ER(&]W;B!S971T:6YG<RXN`%1H
M:7,@9FEL92!M87!S(&9I;&4@97AT96YS:6]N<R!T;R!L;V=I8V%L($U)344@
M='EP97,L(&5N86)L:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!T;R!F:6=U<F4@
M;W5T(&AO=R!T;R!H86YD;&4@<V]M92!C;VYT96YT('-U8V@@87,@96UA:6P@
M871T86-H;65N=',@;W(@0U93(&-H96-K;W5T<RX`5&AI<R!I<R!T:&4@;6%I
M;B!(;W)D92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS
M(&%N9"!B87-I8R!I=&5M<R!T:&%T(&%P<&QY('1O('1H92!C;W)E(&9R86UE
M=V]R:R!A;F0@86QL($AO<F1E(&%P<&QI8V%T:6]N<RX`5&AI<R!I<R!T:&4@
M;6%I;B!087-S=V]R9"!M;V1U;&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C
M;VYT86EN<R!P871H<R!A;F0@;W!T:6]N<R!F;W(@86QL(%!A<W-W;W)D(&UO
M9'5L92!S8W)I<'1S+@!4:71L90!4>7!E(&UI<VUA=&-H+@!54DP`56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&UO9&EF:65D
M('!R969E<F5N8V5S+@!5;F%B;&4@=&\@<F5G:7-T97(@<')E9F5R96YC97,@
M:6X@<V5S<VEO;BX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0`56YD;R!#:&%N9V5S`%5N97AP96-T960@96YD(&]F(&9I;&4N`%5S
M92!$969A=6QT(%9A;'5E`%5S97(@;F]T(&9O=6YD`%5S97(@;F]T(&9O=6YD
M+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<G,@:6X@=&AE('-Y<W1E;3H`5V%R
M;FEN9P!787)N:6YG(0!7965K;'D`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`65D`665A<FQY`%EO=2!C86XG="!C:&%N9V4@<&%S<W=O
M<F0@9F]R('5S97(@)7,`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M
M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O<F0`66]U(&UU<W0@9VEV92!Y;W5R
M(&]L9"!P87-S=V]R9`!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M`%EO=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9`!9;W5R($5M86EL
M($%D9')E<W,Z`%EO=7(@3F%M93H`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!N97<@<&%S<W=O<F0@
M:7,@=&]O(&QO;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E(&UO<F4@=&AA;B`E
M9"!C:&%R86-T97)S(&QO;F<A`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S
M:6UP;&4@=&\@9W5E<W,A("!.;W0@8VAA;F=E9"$`66]U<B!N97<@<&%S<W=O
M<F0@;75S="!B92!A="!L96%S="`E9"!C:&%R86-T97)S(&QO;F<A`%EO=7(@
M;F5W('!A<W-W;W)D(&UU<W0@8F4@9&EF9F5R96YT(&9R;VT@>6]U<B!C=7)R
M96YT('!A<W-W;W)D`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A
M="!L96%S="`E9"!A;'!H86)E=&EC(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!A;'!H86YU;65R:6,@
M8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T
M(&QE87-T("5D(&QO=V5R8V%S92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;G5M97)I8R!C:&%R86-T
M97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@
M)60@=7!P97)C87-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T
M97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&YO="!C;VYT86EN('=H:71E
M<W!A8V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M
M871C:`!;4')O8FQE;2!297!O<G1=`'1E;7!N86TH*2!F86EL960A`%!R;VIE
M8W0M260M5F5R<VEO;CH@<&%S<W=D"E!/5"U#<F5A=&EO;BU$871E.B`R,#`S
M+3`W+3$R(#`S.C,Y*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP-RTQ
M,B`P-#HP,"LP,C`P"DQA<W0M5')A;G-L871O<CH@06YD97)S($)R=75N($]L
M<V5N(#QA;F1E<G-`8G)U=6XM;VQS96XN;F5T/@I,86YG=6%G92U496%M.B!$
M86YI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM
M,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`E<R!6961L:6=E
M:&]L9&5L<V4@+2!"96MRYF9T96QS90`E<R!S:V%L('1I;"!A="!U9&;X<F4@
M9&4@=F%L9W1E('9E9&QI9V5H;VQD96QS97-O<&=A=F5R+@`R-"!T:6UE<@!!
M32]030!/<')E='1E(&5N(&YY(&)R=6=E<CH`3W!R970@<&%R`$]P<F5T(&)R
M=6=E<@!/<')E='1E;'-E(&%F(&)R=6=E<F4@97(@<VSE970@9G)A`$%D<F5S
M<V4`061R97-S96MA<G1O=&5K`$%D;6EN:7-T<F%T:6]N`$MA;&1E;F%V;@!&
M;W)B:6YD96QS92!M:7-L>6MK961E<SH@:6YG96X@96UN97(@9F]R("5S(&9U
M;F1E="X`26YG96X@9WEL9&EG(&9O<F)I;F1E;'-E(&9O<FCE;F1E;BX`1F5L
M=&5R('1I;"!RY61I9VAE9#H`0F%C:V5N9"!E<B!I:VME(&MO<G)E:W0@:6UP
M;&5M96YT97)E="X`1F]R8FEN9&5L<V4@=&EL('-E<G9E<B`E<RP@9&X@)7,@
M<V]M("5S(&UI<VQY:VME9&5S.B!;)61=("5S`$;X9'-E;'-D86<`1F5J;`!#
M5E,`2V%L96YD97(`069B<GED(')E<&]R=&5R:6YG(&%F('!R;V)L96T`36]B
M:6P`4VMI9G0@:V]D96]R9`!3:VEF="!D:70@:V]D96]R9`!3:VEF="!K;V1E
M;W)D('#E("5S`%5D=N9L9R!D92!T:6YG+"!S;VT@<VMA;"!U9&;X<F5S(&1E
M;FYE(&=A;F<N`$QU:R!H:N9L<&5F=6YK=&EO;F5N`$QU:R!V:6YD=65T(&UE
M9"!H:N9L<&5N`$QU:R!V:6YD=64`1FER;6$`0F5K<N9F="!K;V1E;W)D`$)E
M:W+F9G0@;GET(&MO9&5O<F0Z`$EN9&AO;&1E="!A9B!T9WH@87)K:79E=`!)
M;F1H;VQD970@868@4D%2(&%R:VEV970`26YD:&]L9&5T(&%F(%I)4"!A<FMI
M=F5T`$MU;FYE(&EK:V4@;&%V92!E;B!B:6YD:6YG('1I;"!L9&%P('-E<G9E
M<F5N`$MU;FYE(&EK:V4@;W!NY2!F;W)B:6YD96QS92!T:6P@;&1A<"!S97)V
M97)E;@!+=6YN92!I:VME(.5B;F4@;6]D=6P@=&EL('9E9&QI9V5H;VQD96QS
M92`E<P!+=6YN92!I:VME(.5B;F4@9F]R8FEN9&5L<V4@=&EL('-M8G!A<W-W
M9"X`1$0`1&%G;&EG`$1A=&%B87-E;W!S;&%G(&9E:FQE9&4N`%-T86YD87)D
M+6ED96YT:71E=`!3;&5T`$)E<VMR:78@<')O8FQE;65T`$1I<VMU<W-I;VYE
M<@!$=2!MY2!I:VME(&MA;&1E(&UA:6YT96YA;F-E+G!H<"!D:7)E:W1E`&5-
M86EL`$EN=&5T(')E<W5L=&%T+@!&96IL`$9E:FP@=F5D(&1A=&%O=F5R9OAR
M<V5L('1I;"!S;6)P87-S=V0N`$%L=&ED('9E9"!L;V=I;@!%:W-E;7!E;';F
M<F1I97(Z`$9O<G9E;G1E9&4@(D)%1TE.(B!I(&QI;FEE("5D+@!&;W)V96YT
M961E(")%3D0Z)7,B(&D@;&EN:64@)60N`$944`!+=6YN92!I:VME(&;E(&9O
M<F)I;F1E;'-E('1I;"!,1$%0('-E<G9E<F5N(&UE9"!O<'/F=&YI;F=E;BX`
M2W5N;F4@:6MK92!FY2!F;W)B:6YD96QS92!T:6P@3$1!4"!S97)V97)E;BX`
M2W5N;F4@:6MK92!E=&%B;&5R92!E;B!,1$%0(&9O<F)I;F1E;'-E('1I;"`E
M<RX`1&5R('-K971E(&5N(&9E:FP@=F5D(.9N9')I;F<@868@:V]D96]R9#H`
M1F%X`$9I;&CE;F1T97)I;F<`1G5L9"!B97-K<FEV96QS93H`3W9E<G-K<FEF
M=&5R;F4`2&KF;'``061R97-S92`H:&IE;2D`5&5L969O;B`H:&IE;2D`2&]R
M9&4`2&]R9&4@3&]G:6X`2&]R9&4@4WES=&5M`$AO<F1E($)R=6=E<B!!9&UI
M;FES=')A=&EO;@!(;W)D92!4<N5D;/AS`$AO<F1E(&5R(&EK:V4@:V]N9FEG
M=7)E<F5T(&MO<G)E:W0`26UP;W)T`$9E:FP@=6YD97(@:6UP;W)T.B``26UP
M;W)T97)E9&4@9F5L=&5R.B`E<P!);7!O<G1E<F5D92!F96QT97(Z`$9O<FME
M<G0@:V]D96]R9`!/<&QI<W1N:6YG(&%F(&AJYFQP965M;F5R`%9I<VYI;F<@
M868@8G)U9V5R92!E<B!S;.5E="!F<F$N`$QO9R!I;F0`3&]G('5D`$QO9R!U
M9`!-30!-86EL`%-A;6UE;FOF9"!D871O(&]G('1I9"!F96QT97(`4V%M;65N
M:^9D(&EM<&]R="!F96QT97(`3W9E<F5N<W!A<W-E;F1E(&9E;'1E<@!"97-K
M960`3>5N961L:6<`3F%V;@!.971VYG)K`$YY="!K;V1E;W)D.@!.>6AE9&5R
M`$1E<B!E<B!I;F=E;B!O<'/F=&YI;F<@9F]R(&)R=6<@868@3$1!4"!T:6P@
M:6YD<W1I;&QI;F=E<BX`1&5R(&5R(&EN9V5N(&]P<^9T;FEN9R!F;W(@8G)U
M9R!A9B!344P@=&EL(&MA=&5G;W)I97)N92X`1&5R(&5R(&EN9V5N(&]P<^9T
M;FEN9R!F;W(@8G)U9R!A9B!344P@=&EL(&EN9'-T:6QL:6YG97(N`$1E<B!E
M<B!I;F=E;B!O<'/F=&YI;F<@9F]R(&)R=6<@868@4U%,('1I;"!A=71O<FES
M=&%T:6]N+@!);F=E;B!E;6YE(&9O<B`E<R!F=6YD970N`$1E<B!E<B!I;F=E
M;B!I;F1S=&EL;&EN9V5R('1I;"!RY61I9VAE9"X`1&5R(&)L978@:6MK92!H
M96YT970@;F]G96X@:6YD<W1I;&QI;F=E<BX`3F]T97(`1V%M;65L="!K;V1E
M;W)D.@!+;V1E;W)D`$MO9&5O<F0@97(@;G4@<VMI9G1E="$`4&%S<W=D(&UO
M9'5L970@97(@:6MK92!K;W)R96MT(&]P<V%T`$MO9&5O<F0@:V%N(';F<F4@
M=&]M="X`2V]D96]R9&5N92!S:V%L(';F<F4@96YS+@!59&;X<B!V961L:6=E
M:&]L9&5L<V4`5&5L969O;@!,;V<@=F5N9&QI9W-T(&EN9`!3:W)I=B!V96YL
M:6=S="P@:'9A9"!P<F]B;&5M970@9^5R('5D('#E(&]G(&AV860@9&5R('-K
M97(N`$EN9'1A<W0@=F5N;&EG<W0@8G)U9V5R;F%V;B!O9R!K;V1E;W)D`%!R
MYG-E;G1A=&EO;F5R`%!R;V)L96UB97-K<FEV96QS90!0<F]B;&5M/P!3;&5T
M('!A<@!$96X@9F]R;OAD;F4@)V)A<V5D;B<@97(@:6MK92!A;F=I=F5T(&D@
M875T;W)I<W1A=&EO;G,M;W!SYG1N:6YG96XN`$1E;B!F;W)N^&1N92`G8F%S
M961N)R!E<B!I:VME(&%N9VEV970@:2!I;F1S=&EL;&EN9V5R;F4N`$1E;B!F
M;W)N^&1N92`G9&%T86)A<V4G(&5R(&EK:V4@86YG:79E="!I(&%U=&]R:7-T
M871I;VYS+6]P<^9T;FEN9V5N+@!$96X@9F]R;OAD;F4@)V1A=&%B87-E)R!E
M<B!I:VME(&%N9VEV970@:2!K871E9V]R:2UO<'/F=&YI;F=E;BX`1&5N(&9O
M<F[X9&YE("=D871A8F%S92<@97(@:6MK92!A;F=I=F5T(&D@:6YD<W1I;&QI
M;F=E<FYE+@!$96X@9F]R;OAD;F4@)VAO<W1S<&5C)R!E<B!I:VME(&%N9VEV
M970@:2!A=71O<FES871I;VYS+6]P<^9T;FEN9V5N+@!$96X@9F]R;OAD;F4@
M)VAO<W1S<&5C)R!E<B!I:VME(&%N9VEV970@:2!K871E9V]R:2UO<'/F=&YI
M;F=E;BX`1&5N(&9O<F[X9&YE("=H;W-T<W!E8R<@97(@:6MK92!A;F=I=F5T
M(&D@:6YD<W1I;&QI;F=E<FYE+@!$970@9F]R;OAD;F4@)W!A<W-W;W)D)R!E
M<B!I:VME(&%N9VEV970@:2!A=71O<FES871I;VYS+6]P<^9T;FEN9V5N+@!$
M970@9F]R;OAD;F4@)W!A<W-W;W)D)R!E<B!I:VME(&%N9VEV970@:2!K871E
M9V]R:2UO<'/F=&YI;F=E;BX`1&5T(&9O<F[X9&YE("=P87-S=V]R9"<@97(@
M:6MK92!A;F=I=F5T(&D@:6YD<W1I;&QI;F=E<FYE+@!0Y6MRYG9E="`G<&AP
M='EP92<@97(@:6MK92!S<&5C:69I8V5R970@:2!344P@;W!SYG1N:6YG`$1E
M;B!F;W)N^&1N92`G<&AP='EP92<@97(@:6MK92!A;F=I=F5T(&D@875T;W)I
M<V%T:6]N<RUO<'/F=&YI;F=E;BX`1&5N(&9O<F[X9&YE("=P:'!T>7!E)R!E
M<B!I:VME(&%N9VEV970@:2!K871E9V]R:2UO<'/F=&YI;F=E;BX`1&5N(&9O
M<F[X9&YE("=P:'!T>7!E)R!E<B!I:VME(&%N9VEV970@:2!I;F1S=&EL;&EN
M9V5R;F4N`$1E;B!F;W)N^&1N92`G=&%B;&4G(&5R(&EK:V4@86YG:79E="!I
M(&%U=&]R:7-A=&EO;G,M;W!SYG1N:6YG96XN`$1E;B!F;W)N^&1N92`G=&%B
M;&4G(&5R(&EK:V4@86YG:79E="!I(&MA=&5G;W)I+6]P<^9T;FEN9V5N+@!$
M96X@9F]R;OAD;F4@)W1A8FQE)R!E<B!I:VME(&%N9VEV970@:2!I;F1S=&EL
M;&EN9V5R;F4N`$1E;B!F;W)N^&1N92`G=&%B;&5296QA=&EO;G,G(&5R(&EK
M:V4@86YG:79E="!I(&MA=&5G;W)I+6]P<^9T;FEN9V5N+@!$96X@9F]R;OAD
M;F4@)W5I9"<@97(@:6MK92!A;F=I=F5T(&D@875T;W)I<V%T:6]N<RUO<'/F
M=&YI;F=E;BX`1&5N(&9O<F[X9&YE("=U:60G(&5R(&EK:V4@86YG:79E="!I
M(&EN9'-T:6QL:6YG97)N92X`1&5T(&9O<F[X9&YE("=U<V5R;F%M92<@97(@
M:6MK92!A;F=I=F5T(&D@875T;W)I<V%T:6]N<RUO<'/F=&YI;F=E;BX`1&5T
M(&9O<F[X9&YE("=U<V5R;F%M92<@97(@:6MK92!A;F=I=F5T(&D@:V%T96=O
M<FDM;W!SYG1N:6YG96XN`$1E;B!F;W)N^&1N92`G=7-E<FYA;64G(&5R(&EK
M:V4@86YG:79E="!I(&EN9'-T:6QL:6YG97)N92X`3G5L<W1I;`!4:6QB86=E
M('1I;"!I;F1S=&EL;&EN9V5R;F4`4F5G96P`1V5M;64@26YD<W1I;&QI;F=E
M<@!6YFQG(&1E('1E9VX@9'4@:&%R(&)R=6<@9F]R(&9R82!K87-S97)N92!F
M;W)N961E;BX@1&4@:V%N('/E(&ML:7!P97,@;V<@:V]P:65R97,@9G)A('1E
M>'1F96QT970N`%;F;&<@9&%T;RUA9'-K:6QL97)E;CH`5N9L9R!D871O9F]R
M;6%T.@!6YFQG('1I9'-F;W)M870Z`%;F;&<@=&\@9F5L=&5R+"!D97(@<W9A
M<F5R('1I;"!H:6YA;F1E;BX`4V5N9"!P<F]B;&5M8F5S:W)I=F5L<V4`4V5R
M=F5R`$MO<G0@;W!S=6UM97)I;F<Z`%-P<FEN9R!V961L:6=E:&]L9&5L<V4@
M;W9E<@!.;V=L92!A9B!(;W)D92=S(&]P<^9T;FEN9W-F:6QE<B!M86YG;&5R
M.@!.;V=L92!A9B!087-S=V0@;6]D=6QE=',@;W!SYG1N:6YG<V9I;&5R(&UA
M;F=L97(Z`$EN9'1A<W1N:6YG(&9O<B!S<&5C:6%L:V%R86MT97(`4W5C8V5S
M<P`G)7,G(&)L978@=&EL9OAJ970@:2!S>7-T96UE="X`)R5S)R!B;&5V('-L
M971T970@:2!S>7-T96UE="X`3W!G879E<@!296=I<W1R97)I;F=S9&%T86)A
M<V5N('/X<F=E<B!F;W(L(&%T(&1E(&9O<G-K96QL:6=E($AO<F1E+6UO9'5L
M97(@:V%N('1A;&4@;65D(&AI;F%N9&5N+B!!;&QE($AO<F1E+6UO9'5L97(@
M9'4@8G)U9V5R+"!B^'(@=N9R92!NYG9N="!H97(N`$1E<B!O<'-T;V0@970@
M<')O8FQE;2!U;F1E<B!T:6QF^&IE;'-E;B!A9B`G)7,G('1I;"!S>7-T96UE
M="X`1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R('-L971N:6YG(&%F("<E
M<R<@:2!S>7-T96UE="X`1&5N;F4@9FEL(&EN9&5H;VQD97(@8F%C:V5N9"!O
M<'/F=&YI;F=S:6YF;W)M871I;VX@=&EL(%!A<W-W9"!M;V1U;&5T<R!S8W)I
M<'1S+@!$96YN92!F:6P@:.5N9'1E<F5R(&5T(&=L;V)A;"!SYG0@868@34E-
M12!D<FEV97)E+"!S;VT@8G)U9V5S(&%F($AO<F1E+B!$:7-S92!D<FEV97)E
M('1I;&QA9&5R(&UO9'5L97(@870@8G)U9V4@<')O9W)A;6UE<B!S;VT@96YS
M8W)I<'0@;V<@;7-W;W)D=FEE=RP@<^4@9&4@:V%N(&MO;G9E<G1E<F5S(&9O
M<B!V:7-N:6YG96X@:2!E;B!(5$U,(&)R;W=S97(N`$1E;FYE(&9I;"!I;F1E
M:&]L9&5R(&1E="!S='EL97-H965T+"!D97(@8F5S=&5M;65R(&9A<G9E<B!O
M9R!F;VYT92!F;W(@2&]R9&4@;V<@86QL92!M;V1U;&5R+"!D97(@:6MK92!H
M87(@9&5R97,@96=N92!I;F1S=&EL;&EN9V5R+BX`1&5N;F4@9FEL('-A;6UE
M;F)I;F1E<B!F:6QT>7!E<B!M960@34E-12!T>7!E<BP@:'9I;&ME="!G^'(L
M(&%T($AO<F1E(&UO9'5L97(@:V%N(&9I;F1E('5D(&%F(&AV;W)D86X@9BYE
M:W,N(&5M86EL=F5D:.9F=&5L<V5R(&]G($-64R!C:&5C:V]U=',@<VMA;"!H
MY6YD=&5R97,N`$1E='1E(&5R($AO<F1E)W,@:&]V961K;VYF:6=U<F%T:6]N
M<V9I;"X@1&5N(&EN9&AO;&1E<B!S=&EE<B!O9R!D96X@9W)U;F1LYF=G96YD
M92!O<'/F=&YI;F<L(&1E<B!E<B!GYFQD96YD92!F;W(@2&]R9&4@;V<@9&4@
M:6YS=&%L;&5R961E(&UO9'5L97(N`$1E='1E(&5R(&AO=F5D;W!SYG1N:6YG
M<V9I;&5N(&9O<B!087-S=V0@;6]D=6QE="X@1&5N(&EN9&5H;VQD97(@<W1I
M97(@;V<@;W!SYG1N:6YG<W9A;&<@=&EL(&%L;&4@4&%S<W=D(&UO9'5L971S
M('-C<FEP=',N`%1I=&5L`%-K<FEV969E:FPN`%523`!+=6YN92!I:VME(&]P
M;N4@9F]R8FEN9&5L<V4@=&EL(%-13"!S97)V97)E;BX`2W5N;F4@:6MK92#F
M;F1R92!I;F1S=&EL;&EN9V5R;F4N`$MU;FYE(&EK:V4@<F5G:7-T<F5R92!I
M;F1S=&EL;&EN9V5R;F4@:2!D96X@86MT=65L;&4@<V5S<VEO;BX`2W5N;F4@
M:6MK92!O=F5R<^9T=&4@9&5T=&4@5V]R9"!D;VMU;65N=`!&;W)T<GED(.9N
M9')I;F=E<@!59F]R=F5N=&5T('-L=70@868@9FEL+@!"<G5G('-T86YD87)D
M=N9R9&D`0G)U9V5R;F%V;B!I:VME(&9U;F1E=`!"<G5G97)N879N(&EK:V4@
M9G5N9&5T+@!"<G5G97)N879N`$)R=6=E<FYA=FXZ`$)R=6=E<F4@:2!S>7-T
M96UE=#H`061V87)S96P`061V87)S96PA`%5G96YT;&EG`%9E;&MO;6UE;BP@
M)7,`061R97-S92`H87)B96ID92D`5&5L969O;B`H87)B96ID92D`Q<4`Q7)L
M:6<`1'4@:V%N(&EK:V4@<VMI9G1E(&MO9&5O<F0@9F]R(&)R=6=E<F5N("5S
M`$1U(&)L:79E<B!N^&0@=&EL(&%T(&QA=F4@96X@<')O8FQE;6)E<VMR:79E
M;'-E+"!F^'(@9'4@:V%N('-E;F1E(&1E;B!I;F0N`$1U('-K86P@86YG:79E
M(&5T(&YY="!K;V1E;W)D`$1U('-K86P@86YG:79E(&1I="!G86UL92!K;V1E
M;W)D`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!F
M:F5R;F4N`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I
M;"!T:6QF^&IE+@!$=2!S:V%L(&)E:W+F9G1E(&1I="!N>64@:V]D96]R9`!$
M:6X@94UA:6PM861R97-S93H`1&ET(&YA=FXZ`$1I;B!A=71O<FES871I;VYS
M+6)A8VME;F0@=6YD97)S=/AT=&5R(&EK:V4@=&EL9OAJ96QS96X@868@8G)U
M9V5R92!E;&QE<B!E<B!D96X@9G5N:W1I;VX@868@96X@96QL97(@86YD96X@
M9W)U;F0@8FQE=F5T('-LY65T(&9R82X`1&EN(&%U=&]R:7-A=&EO;G,M8F%C
M:V5N9"!U;F1E<G-T^'1T97(@:6MK92!O<&QI<W1N:6YG96X@868@8G)U9V5R
M92!E;&QE<B!E<B!D96X@9G5N:W1I;VX@868@96X@96QL97(@86YD96X@9W)U
M;F0@8FQE=F5T('-LY65T(&9R82X`1&ET(&YY92!K;V1E;W)D(&5R(&9O<B!L
M86YG="X@2V]D96]R9"!MY2!I:VME(';F<F4@;65R92!E;F0@)60@=&5G;B!L
M86YG92$`1&ET(&YY92!K;V1E;W)D(&5R(&9O<B!S:6UP96QT(&%T(&?F='1E
M(2`@1&5T(&5R(&EK:V4@8FQE=F5T('-K:69T970A`$1I="!N>64@:V]D96]R
M9"!S:V%L(';F<F4@;6EN9'-T("5D('1E9VX@;&%N9W0A`$1I="!N>64@:V]D
M96]R9"!S:V%L(';F<F4@9F]R<VME;&QI9W0@9G)A(&1I="!N=7;F<F5N9&4@
M:V]D96]R9`!$:70@;GEE(&MO9&5O<F0@<VMA;"!I;F1E:&]L9&4@;6EN9'-T
M("5D(&)O9W-T879E<BX`1&ET(&YY92!K;V1E;W)D('-K86P@:6YD96AO;&1E
M(&UI;F1S="`E9"!A;&9A;G5M97)I<VME('1E9VXN`$1I="!N>64@:V]D96]R
M9"!S:V%L(&EN9&5H;VQD92!M:6YD<W0@)60@<VWE(&)O9W-T879E<BX`1&ET
M(&YY92!K;V1E;W)D('-K86P@:6YD96AO;&1E(&UI;F1S="`E9"!T86PN`$1I
M="!N>64@:V]D96]R9"!S:V%L(&EN9&5H;VQD92!M:6YD<W0@)60@<W1O<F4@
M8F]G<W1A=F5R+@!$:70@;GEE(&MO9&5O<F0@;>4@:6MK92!I;F1E:&]L9&4@
M;65R92!E;F0@)60@;65L;&5M<G5M<W1E9VXN`$1I="!N>64@:V]D96]R9"!M
MY2!I:VME(&EN9&5H;VQD92!M96QL96UR=6US=&5G;BX`1&ET(&YY92!K;V1E
M;W)D(&5R(&EK:V4@96YS(&D@8F5G9V4@9F5L=&5R`%M0<F]B;&5M8F5S:W)I
M=F5L<V5=`'1E;7!N86TH*2!F96IL961E(0``````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S
M<W=D+VQO8V%L92]D95]$12\`````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,C`Q,C,`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+V1E7T1%+TQ#7TU%4U-!1T53
M+P```````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S
M`#`R,3<Q,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O
M9&5?1$4O3$-?34534T%'15,O<&%S<W=D+FUO````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T
M-3<R,#(`,3`T,3<S-C(W-#,`,#(S-34U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-X2!)4`````ZP<``!P```!T/P``DPH`
M`,Q^````````&*D``$T````9J0``OP```&>I``!D````)ZH``+X```",J@``
MD````$NK``!#````W*L``#P````@K```*P```%VL```N````B:P``"D```"X
MK```*````.*L``!%````"ZT``$<```!1K0``2@```)FM``!'````Y*T``$4`
M```LK@``2````'*N```Y````NZX``$8```#UK@``2````#RO```P````A:\`
M`$4```"VKP``1@```/RO``!,````0[```#0```"0L```,@```,6P``!I````
M^+```#````!BL0``)0```).Q``"(````N;$``$````!"L@``]@```(.R``!*
M````>K,``"P```#%LP``A0```/*S``!(````>+0```X```#!M```#P```-"T
M```-````X+0```@```#NM```"P```/>T```,`````[4```0````0M0``&P``
M`!6U```M````,;4``!T```!?M0``)````'VU```I````HK4``!D```#,M0``
M#````.:U```1````\[4``"4````%M@``#P```"NV```+````.[8``!$```!'
MM@``#@```%FV```%````:+8``"@```!NM@``"````)>V```*````H+8``!4`
M``"KM@``$@```,&V```+````U+8``"<```#@M@``%`````BW```F````';<`
M`"<```!$MP``)@```&RW```3````D[<```X```"GMP``"@```+:W```-````
MP;<``"X```#/MP``)P```/ZW```@````)K@```X```!'N```%P```%:X```B
M````;K@``#4```"1N```$0```,>X```-````V;@```P```#GN```#0```/2X
M```&`````KD``!T````)N0``#P```">Y```8````-[D```P```!0N0``&P``
M`%VY```.````>;D```X```"(N0``"````)>Y```)````H+D``$(```"JN0``
M+@```.VY```:````'+H``#(````WN@``.````&JZ``!4````H[H``%$```#X
MN@``6@```$J[``!7````I;L``#0```#]NP``#@```#*\```)````0;P```T`
M``!+O```!P```%F\```*````8;P```\```!LO```!0```'R\```&````@KP`
M`!$```")O```"````)N\```)````I+P```D```"NO```#@```+B\```(````
MQ[P```X```#0O```)0```-^\```@````!;T``!`````FO0``#P```#>]```*
M````1[T```<```!2O0```P```%J]```/````7KT``!0```!NO0``"0```(.]
M```-````C;T``!(```";O0``&0```*Z]```>````R+T```\```#GO0``"@``
M`/>]```/`````KX```@````2O@``)````!N^```7````0+X``!0```!8O@``
M%@```&V^```(````A+X``$X```"-O@``+0```-R^```?````"K\``!D````J
MOP``!P```$2_```,````3+\``"P```!9OP``#@```(:_```#````E;\```L`
M``"9OP``!P```*6_```'````K;\```4```"UOP``!0```+N_```*````P;\`
M``,```#,OP``%P```-"_```*````Z+\```\```#SOP``#@````/````8````
M$L```",````KP```#@```$_````4````7L```!<```!SP```%P```(O````7
M````H\```!,```"[P```#P```,_````.````W\```!\```#NP```'0````[!
M```'````+,$```8````TP0``"````#O!```/````1,$```8```!4P0``"@``
M`%O!```3````9L$```L```!ZP0``$````(;!```5````E\$``!4```"MP0``
M!P```,/!```0````R\$```4```#<P0``%0```.+!```1````^,$```P````*
MP@``.P```!?"```X````4\(```D```",P@``!P```);"```4````GL(```,`
M``"SP@``!0```+?"```0````O<(```D```#.P@``$P```-C"```Y````[,(`
M`!(````FPP``.0```#G#```G````<\,``"P```";PP``*@```,C#```E````
M\\,```D````9Q```"@```"/$```&````+L0```D````UQ```!P```#_$```O
M````1\0``#<```!WQ```+@```*_$``!5````WL0``"T````TQ0``+0```&+%
M```M````D,4``$````"^Q0``(P```/_%```C````(\8``"T```!'Q@``,P``
M`'7&```5````J<8``!D```"_Q@``*0```-G&```D`````\<``!$````HQP``
M$0```#K'```*````3,<```P```!7QP``(@```&3'```*````A\<``!````"2
MQP``%@```*/'```6````NL<```<```#1QP``!P```-G'```4````X<<```H`
M``#VQP``"`````'(```G````"L@```@````RR```!P```#O(```'````0\@`
M``8```!+R```!0```%+(```'````6,@```8```!@R```"````&?(```I````
M<,@```X```":R```"@```*G(```$````M,@```<```"YR```"0```,'(```&
M````R\@``!$```#2R```!P```.3(```6````[,@```0````#R0``"`````C)
M```&````$<D```T````8R0``!@```";)```>````+<D``!$```!,R0``(@``
M`%[)```6````@<D```@```"8R0``#0```*')```,````K\D```<```"\R0``
M`P```,3)```#````R,D``!<```#,R0``$P```.3)```=````^,D```@````6
MR@``!````!_*```(````),H```@````MR@``00```#;*```@````>,H```8`
M``"9R@``!@```*#*```5````I\H``!@```"]R@``(@```-;*```N````^<H`
M`!T````HRP``(0```$;+``!4````:,L``"D```"]RP``"@```.?+```'````
M\LL``!4```#ZRP``#@```!#,```*````'\P```\````JS```#0```#K,```/
M````2,P```T```!8S```"0```&;,```4````<,P```8```"%S```&````(S,
M```=````I<P``!,```##S```$0```-?,```4````Z<P```0```#^S```#```
M``/-```&````$,T```\````7S0``$P```"?-``!4````.\T``!0```"0S0``
M%P```*7-```$````O<T```X```#"S0``1````-'-```%````%LX```4````<
MS@``&P```"+.```:````/LX``!$```!9S@``$0```&O.```1````?<X``!P`
M``"/S@``*@```*S.```0````U\X``"$```#HS@``)0````K/```9````,,\`
M``4```!*SP``$P```%#/```2````9,\```H```!WSP``#P```(+/```-````
MDL\``!$```"@SP``$P```++/```,````QL\```8```#3SP``#````-K/```&
M````Y\\``!<```#NSP``$`````;0```1````%]````@````IT```!0```#+0
M```,````.-```!````!%T```!0```%;0```-````7-````8```!JT```!P``
M`''0```-````>=```!````"'T```"0```)C0```'````HM````L```"JT```
M"P```+;0```'````PM````<```#*T```"0```-+0```4````W-````D```#Q
MT```"@```/O0```9````!M$``!T````@T0``#````#[1```0````2]$``!4`
M``!<T0``!0```'+1```E````>-$``!(```">T0``$P```+'1```K````Q=$`
M`#L```#QT0``(````"W2```V````3M(``!````"%T@``"````);2```,````
MG](```8```"LT@``!````+/2```.````N-(``!````#'T@``"@```-C2```-
M````X](``!X```#QT@``&P```!#3```A````+-,``!X```!.TP``&0```&W3
M```>````A],``!T```"FTP``&P```,33```@````X-,``"X````!U```%P``
M`##4```F````2-0``#````!OU```&P```*#4```>````O-0``!P```#;U```
M)@```/C4```K````']4``#,```!+U0``)@```'_5```K````IM4``#@```#2
MU0``'0````O6```5````*=8``"\````_U@``(````&_6```2````D-8``"D`
M``"CU@``'@```,W6```A````[-8``!(````.UP``H@```"'7```6````Q-<`
M`",```#;UP``*````/_7```I````*-@``"@```!2V```'P```'O8```5````
MF]@``"````"QV```)0```-+8```H````^-@``"T````AV0``,````$_9``"2
M````@-D``"$````3V@``%@```#7:```<````3-H``"8```!IV@``*@```)#:
M``!!````N]H``$0```#]V@``#````$+;```'````3]L```<```!7VP``!@``
M`%_;```-````9ML``!````!TVP``$@```(7;```3````F-L``!(```"LVP``
M!P```+_;```$````Q]L``!````#,VP``#````-W;```.````ZML```\```#Y
MVP``$P````G<```-````'=P``"@````KW````P```%3<```-````6-P```8`
M``!FW```$0```&W<```7````?]P``!L```"7W```#@```+/<```"````PMP`
M``4```#%W```$````,O<```$````W-P```T```#AW```#@```._<```#````
M_MP```X````"W0``"````!'=```/````&MT```@````JW0``#P```#/=```'
M````0]T```T```!+W0``$````%G=```3````:MT``!,```!^W0``"P```)+=
M```1````GMT```D```"PW0``!@```+K=```,````P=T``!$```#.W0``&0``
M`.#=```+````^MT```T````&W@``(@```!3>```;````-]X``#0```!3W@``
M"@```(C>```8````D]X``!D```"LW@``%@```,;>```O````W=X``"(````-
MWP``#0```##?```'````/M\```P```!&WP``)@```%/?```4````>M\```L`
M``"/WP``(@```)O?```O````OM\```L```#NWP``"0```/K?```9````!.``
M``L````>X```%P```"K@```7````0N````D```!:X```%@```&3@```/````
M>^```!8```"+X```#@```*+@```8````L>````@```#*X```#0```-/@```F
M````X>```$,````(X0``"````$SA```2````5>$```@```!HX0``"P```''A
M```O````?>$```X```"MX0``!0```+SA```&````PN$```,```#)X0``!P``
M`,WA```$````U>$```H```#:X0``"@```.7A```/````\.$``!``````X@``
M%P```!'B```1````*>(``!D````[X@``%P```%7B```)````;>(```4```!W
MX@``"P```'WB```*````B>(```(```"4X@``!0```)?B```-````G>(``!L`
M``"KX@``%P```,?B```)````W^(```X```#IX@``#0```/CB```2````!N,`
M`#@````9XP``(````%+C```#````<^,```@```!WXP``#@```(#C``![````
MC^,``!@````+Y```0````"3D```1````9>0```<```!WY```!0```'_D```@
M````A>0``!@```"FY```&0```+_D```3````V>0```<```#MY```!P```/7D
M```(````_>0```8````&Y0``!@````WE```0````%.4```\````EY0``$```
M`#7E```/````1N4```L```!6Y0``#P```&+E```,````<N4```\```!_Y0``
M!P```(_E```*````E^4```8```"BY0``#@```*GE```,````N.4``"@```#%
MY0``#P```.[E```(````_N4``!8````'Y@``"````![F```3````)^8``!X`
M```[Y@``(0```%KF```@````?.8``!D```"=Y@``%P```+?F```E````S^8`
M`!<```#UY@``'@````WG```F````+.<```0```!3YP``&P```%CG```-````
M=.<```P```""YP```P```(_G```(````D^<```H```"<YP``#````*?G```+
M````M.<``!````#`YP``#````-'G```$````WN<``!,```#CYP``%````/?G
M```,````#.@```D````9Z```#@```"/H```+````,N@``!L````^Z```!P``
M`%KH```'````8N@```H```!JZ```#0```'7H```)````@^@```0```"-Z```
M!0```)+H```#````F.@``!@```"<Z```"@```+7H```$````P.@``"8```#%
MZ```#@```.SH``!\````^^@``!4```!XZ0``!0```([I```'````E.D```P`
M``"<Z0``"````*GI```*````LND```8```"]Z0``"````,3I```6````S>D`
M`!(```#DZ0```@```/?I```&````^ND```8````!Z@``%`````CJ```5````
M'>H```\````SZ@``$0```$/J```:````5>H```T```!PZ@``$````'[J```;
M````C^H```0```"KZ@``"0```+#J```0````NNH```D```#+Z@``"0```-7J
M```%````W^H```4```#EZ@``&@```.OJ```(````!NL```8````/ZP``&0``
M`!;K```.````,.L``"(````_ZP``!P```&+K```'````:NL```X```!RZP``
M!0```('K```)````A^L```H```"1ZP```@```)SK```&````G^L```T```"F
MZP``"0```+3K```&````ONL``!(```#%ZP``"0```-CK```'````XNL``!0`
M``#JZP``'0```/_K```1````'>P```8````O[```"@```#;L```$````0>P`
M``D```!&[```"````%#L```1````6>P``!$```!K[```"0```'WL```&````
MA^P```T```".[```!@```)SL```$````H^P``#D```"H[```/0```.+L```Z
M````(.T``!X```!;[0``!0```'KM```.````@.T```0```"/[0``!@```)3M
M```A````F^T```T```"][0``%0```,OM```&````X>T```0```#H[0``$0``
M`.WM```&````_^T``*`````&[@``"@```*?N```B````LNX```0```#5[@``
M)0```-KN```%`````.\``!T````&[P``!````"3O```,````*>\```H````V
M[P``"````$'O```)````2N\```4```!4[P``&P```%KO```Z````=N\``#``
M``"Q[P``-0```.+O```I````&/```"X```!"\```1P```''P```X````N?``
M`"D```#R\```/P```!SQ```N````7/$``"T```"+\0``'P```+GQ```/````
MV?$``!(```#I\0``"P```/SQ```F````"/(``"D````O\@``)````%GR```F
M````?O(```@```"E\@``"@```*[R```)````N?(```<```##\@``(````,OR
M```@````[/(``"8````-\P``"@```#3S```9````/_,``"D```!9\P``%@``
M`(/S```2````FO,```<```"M\P``"@```+7S```,````P/,```\```#-\P``
M$````-WS``!`````[O,``'`````O]```9@```*#T```.````!_4```D````6
M]0``"@```"#U```2````*_4``!,````^]0``#````%+U```&````7_4```\`
M``!F]0``$@```';U```0````B?4```H```":]0``$0```*7U```2````M_4`
M`!P```#*]0``(P```.?U``!J````"_8```\```!V]@``!0```(;V```0````
MC/8```D```"=]@``!````*?V```+````K/8``!H```"X]@``%````-/V```,
M````Z/8```P```#U]@``#P````+W```5````$O<``"D````H]P``*@```%+W
M```F````??<``"<```"D]P``*0```,SW```J````]O<``!D````A^```0@``
M`#OX```1````?O@``!(```"0^```$P```*/X```4````M_@```\```#,^```
M%@```-SX```7````\_@``!`````+^0``$0```!SY```T````+OD``!,```!C
M^0``$@```'?Y```U````BOD``!0```#`^0``!P```-7Y```,````W?D``"L`
M``#J^0``(````!;Z```4````-_H``!$```!,^@``%P```%[Z```<````=OH`
M`!,```"3^@``%````*?Z```:````O/H``!$```#7^@``&@```.GZ```>````
M!/L``!H````C^P``$P```#[[```5````4OL``!$```!H^P``%P```'K[```4
M````DOL``!<```"G^P``%0```+_[```)````U?L``!D```#?^P``!````/G[
M```'````_OL```L````&_```$0```!+\```&````)/P```8````K_```!@``
M`#+\```%````.?P```<````__```!P```$?\```%````3_P``!8```!5_```
M!@```&S\```&````<_P```0```!Z_```!````'_\```'````A/P```X```",
M_```#````)O\```,````J/P```T```"U_```"@```,/\```.````SOP```4`
M``#=_```*````./\```.````#/T```P````;_0``#P```"C]```*````./T`
M``@```!#_0``"0```$S]```K````5OT```0```""_0``"````(?]```F````
MD/T``!(```"W_0``#P```,K]```&````VOT```H```#A_0``!P```.S]```(
M````]/T``"````#]_0``"0```![^```,````*/X```T````U_@``#@```$/^
M```6````4OX``!$```!I_@``!@```'O^```#````@OX```8```"&_@``&0``
M`(W^```'````I_X```0```"O_@``"P```+3^```+````P/X```<```#,_@``
M!P```-3^```6````W/X```T```#S_@``#0````'_```*````#_\``!`````:
M_P``#P```"O_```1````._\``!<```!-_P``"@```&7_```1````</\```@`
M``""_P``!````(O_```/````D/\``#H```"@_P``!0```-O_```,````X?\`
M`!X```#N_P``#@````T``0`0````'``!``L````M``$`#````#D``0`)````
M1@`!``<```!0``$`"@```%@``0`)````8P`!``X```!M``$`$````'P``0`:
M````C0`!``H```"H``$`"0```+,``0`4````O0`!``H```#2``$`#````-T`
M`0`/````Z@`!``@```#Z``$`!@````,!`0`'````"@$!``L````2`0$`1P``
M`!X!`0`-````9@$!``D```!T`0$`!````'X!`0`#````@P$!`!,```"'`0$`
M$P```)L!`0`3````KP$!``H```##`0$``@```,X!`0`$````T0$!`"4```#6
M`0$``P```/P!`0`%``````(!`"H````&`@$`"@```#$"`0`%````/`(!``0`
M``!"`@$`"@```$<"`0`-````4@(!`$````!@`@$`$P```*$"`0`&````M0(!
M``@```"\`@$`"````,4"`0`$````S@(!``4```#3`@$`:````-D"`0`)````
M0@,!``P```!,`P$`!0```%D#`0`&````7P,!`!L```!F`P$`+P```((#`0`0
M````L@,!``H```##`P$`#P```,X#`0`*````W@,!``D```#I`P$`$P```/,#
M`0`;````!P0!`!@````C!`$`%P```#P$`0`.````5`0!``,```!C!`$`!P``
M`&<$`0`(````;P0!`!0```!X!`$`$P```(T$`0`0````H00!``T```"R!`$`
M#@```,`$`0`6````SP0!``<```#F!`$`"@```.X$`0`+````^00!`"T````%
M!0$`%0```#,%`0`P````204!`"0```!Z!0$`!P```)\%`0!1````IP4!`!``
M``#Y!0$`#`````H&`0`-````%P8!`!H````E!@$`2@```$`&`0`9````BP8!
M``8```"E!@$`&@```*P&`0`&````QP8!``8```#.!@$`'P```-4&`0`&````
M]08!``D```#\!@$`&`````8'`0`7````'P<!`"@````W!P$`!@```&`'`0`-
M````9P<!`"(```!U!P$`5P```)@'`0`3````\`<!`",````$"`$`$P```"@(
M`0`"````/`@!``L````_"`$`"````$L(`0`-````5`@!``H```!B"`$`!@``
M`&T(`0`'````=`@!`!0```!\"`$`!@```)$(`0`(````F`@!``X```"A"`$`
M!P```+`(`0`*````N`@!``L```##"`$`!P```,\(`0`,````UP@!``T```#D
M"`$`#````/((`0`)````_P@!``D````)"0$`"@```!,)`0`'````'@D!``D`
M```F"0$`!P```#`)`0`*````.`D!`!L```!#"0$`$@```%\)`0`*````<@D!
M``D```!]"0$`$````(<)`0`'````F`D!`!(```"@"0$`!````+,)`0`'````
MN`D!``4```#`"0$`#````,8)`0`%````TPD!``L```#9"0$`%````.4)`0`1
M````^@D!`!H````,"@$`%@```"<*`0`4````/@H!`!<```!3"@$`&````&L*
M`0`<````A`H!`!D```"A"@$`!P```+L*`0`%````PPH!``T```#)"@$`#```
M`-<*`0`(````Y`H!`!<```#M"@$`"P````4+`0`-````$0L!`!,````?"P$`
M!````#,+`0`*````.`L!``0```!#"P$`#0```$@+`0`,````5@L!``4```!C
M"P$`"0```&D+`0`%````<PL!``<```!Y"P$`!0```($+`0`$````APL!``(`
M``","P$`.````(\+`0`L````R`L!`!(```#U"P$`*0````@,`0`R````,@P!
M``H```!E#`$`-@```'`,`0`L````IPP!`!4```#4#`$`+@```.H,`0`S````
M&0T!`#,```!-#0$`.````($-`0`/````N@T!`!@```#*#0$`.P```.,-`0`0
M````'PX!``\````P#@$`%````$`.`0`3````50X!`!4```!I#@$`%````'\.
M`0`2````E`X!`!0```"G#@$`%0```+P.`0`M````T@X!`"T`````#P$`,0``
M`"X/`0`M````8`\!`"X```".#P$`+P```+T/`0`L````[0\!`&(````:$`$`
M$P```'T0`0`(````D1`!``@```":$`$`&P```*,0`0`K````OQ`!`"$```#K
M$`$`&@````T1`0`)````*!$!`$4````R$0$`00```'@1`0`/````NA$!``0`
M``#*$0$`$P```,\1`0`4````XQ$!``X```#X$0$`$P````<2`0`8````&Q(!
M``8````T$@$`"0```#L2`0`*````11(!``\```!0$@$`$````&`2`0`'````
M<1(!``X```!Y$@$`!0```(@2`0`;````CA(!``8```"J$@$`"````+$2`0`&
M````NA(!`!0```#!$@$`$0```-82`0`.````Z!(!`#@```#W$@$``@```#`3
M`0`&````,Q,!``X````Z$P$`&@```$D3`0`%````9!,!``<```!J$P$`#@``
M`'(3`0`&````@1,!``T```"($P$`!````)83`0`I````FQ,!`!<```#%$P$`
M'P```-T3`0!<````_1,!`!0```!:%`$`/@```&\4`0`?````KA0!`!````#.
M%`$`%````-\4`0`'````]!0!``X```#\%`$`"`````L5`0`,````%!4!``P`
M```A%0$`$P```"X5`0`*````0A4!`!T```!-%0$`&0```&L5`0`%````A14!
M`!$```"+%0$`$0```)T5`0`D````KQ4!`!4```#4%0$`$@```.H5`0`.````
M_14!`!D````,%@$`"````"86`0`)````+Q8!``T````Y%@$`"@```$<6`0`'
M````4A8!``\```!:%@$`!@```&H6`0`+````<18!``H```!]%@$`!P```(@6
M`0`(````D!8!``4```"9%@$`'P```)\6`0`&````OQ8!`!````#&%@$`"```
M`-<6`0`-````X!8!`"(```#N%@$`"````!$7`0`7````&A<!`!(````R%P$`
M+````$47`0`O````<A<!`"P```"B%P$`*@```,\7`0`K````^A<!`"P````F
M&`$`&@```%,8`0`)````;A@!``H```!X&`$`%0```(,8`0`%````F1@!`!0`
M``"?&`$`!````+08`0`0````N1@!``8```#*&`$`!P```-$8`0`>````V1@!
M`"@```#X&`$`"@```"$9`0`<````+!D!`!H```!)&0$`#P```&09`0`4````
M=!D!``0```")&0$`!````(X9`0`+````DQD!``4```"?&0$`!@```*49`0`(
M````K!D!``8```"U&0$`"@```+P9`0`;````QQD!`#0```#C&0$`-````!@:
M`0`@````31H!`"D```!N&@$`(````)@:`0!!````N1H!`!H```#[&@$`'0``
M`!8;`0`H````-!L!`"0```!=&P$`*0```((;`0!1````K!L!`"\```#^&P$`
M5P```"X<`0`L````AAP!`"(```"S'`$`'P```-8<`0`&````]AP!``@```#]
M'`$`!0````8=`0`(````#!T!`!D````5'0$`&0```"\=`0`J````21T!`",`
M``!T'0$`+@```)@=`0`T````QQT!``@```#\'0$`%P````4>`0`*````'1X!
M``<````H'@$`(0```#`>`0`0````4AX!``X```!C'@$`"P```'(>`0`'````
M?AX!`!,```"&'@$`"````)H>`0`+````HQX!``H```"O'@$`%````+H>`0`/
M````SQX!`#(```#?'@$`"P```!(?`0`%````'A\!``4````D'P$`%P```"H?
M`0`/````0A\!``0```!2'P$`"@```%<?`0`)````8A\!``L```!L'P$`#0``
M`'@?`0`,````AA\!``X```"3'P$`!0```*(?`0`$````J!\!``T```"M'P$`
M,@```+L?`0!%````[A\!`!<````T(`$`'@```$P@`0`4````:R`!``4```"`
M(`$`%````(8@`0`'````FR`!`",```"C(`$`#@```,<@`0`J````UB`!``8`
M```!(0$`#`````@A`0`-````%2$!`!$````C(0$`%P```#4A`0`+````32$!
M`#8```!9(0$`"@```)`A`0`B````FR$!``L```"^(0$`#P```,HA`0`+````
MVB$!`"````#F(0$`)P````<B`0`K````+R(!``D```!;(@$`,@```&4B`0`E
M````F"(!`#````"^(@$`,0```.\B`0`M````(2,!`#\```!/(P$`/0```(\C
M`0`V````S2,!``X````$)`$`%````!,D`0`%````*"0!``X````N)`$`$P``
M`#TD`0`'````420!`!H```!9)`$`"````'0D`0`1````?20!``<```"/)`$`
M%````)<D`0`8````K"0!``<```#%)`$`!0```,TD`0`,````TR0!``P```#@
M)`$`$@```.TD`0`$`````"4!``<````%)0$`"@````TE`0`+````&"4!``P`
M```D)0$`#@```#$E`0`.````0"4!``4```!/)0$`!0```%4E`0`N````6R4!
M`"8```"*)0$`(P```+$E`0`#````U24!`!(```#9)0$`!@```.PE`0`>````
M\R4!`!@````2)@$`)0```"LF`0`-````428!``D```!?)@$``P```&DF`0`'
M````;28!``H```!U)@$``@```(`F`0`,````@R8!`!4```"0)@$`"P```*8F
M`0`9````LB8!`"````#,)@$`$@```.TF`0`%`````"<!``H````&)P$`%0``
M`!$G`0`2````)R<!``P````Z)P$`!````$<G`0`'````3"<!``D```!4)P$`
M#````%XG`0!2````:R<!`!<```"^)P$`)````-8G`0`2````^R<!``<````.
M*`$`!@```!8H`0`.````'2@!`"(````L*`$`'0```$\H`0`,````;2@!``T`
M``!Z*`$`%0```(@H`0`2````GB@!``\```"Q*`$`%````,$H`0`;````UB@!
M`!````#R*`$`:0````,I`0`:````;2D!`!<```"(*0$`)P```*`I`0`:````
MR"D!`!<```#C*0$`&P```/LI`0`9````%RH!`!\````Q*@$`%P```%$J`0`3
M````:2H!``@```!]*@$`!P```(8J`0`(````CBH!``D```"7*@$`%0```*$J
M`0`-````MRH!`",```#%*@$`$P```.DJ`0`#````_2H!`$8````!*P$`/P``
M`$@K`0`W````B"L!`%<```#`*P$`!0```!@L`0`?````'BP!`"\````^+`$`
M"@```&XL`0`(````>2P!``T```""+`$`+0```)`L`0`$````OBP!`$\```##
M+`$`)0```!,M`0`<````.2T!``L```!6+0$`'P```&(M`0`=````@BT!`"4`
M``"@+0$`(````,8M`0`D````YRT!`"`````,+@$`"P```"TN`0`'````.2X!
M``T```!!+@$`#````$\N`0`7````7"X!``8```!T+@$`.0```'LN`0`,````
MM2X!``<```#"+@$`&0```,HN`0`)````Y"X!`!,```#N+@$`"0````(O`0`$
M````#"\!`!`````1+P$`"@```"(O`0`(````+2\!``@````V+P$`!````#\O
M`0`+````1"\!``P```!0+P$`$@```%TO`0`1````<"\!``P```""+P$`&@``
M`(\O`0`/````JB\!``<```"Z+P$`#0```,(O`0`4````T"\!``X```#E+P$`
M#````/0O`0`;`````3`!`"P````=,`$`$P```$HP`0`<````7C`!`"@```![
M,`$`!@```*0P`0`'````JS`!`!,```"S,`$`!0```,<P`0`$````S3`!`!<`
M``#2,`$`"@```.HP`0`,````]3`!``D````",0$`!@````PQ`0`)````$S$!
M``@````=,0$`"0```"8Q`0`%````,#$!``H````V,0$`$0```$$Q`0`&````
M4S$!`!@```!:,0$`#@```',Q`0`.````@C$!``T```"1,0$`"P```)\Q`0`=
M````JS$!``L```#),0$``@```-4Q`0`<````V#$!``<```#U,0$`!@```/TQ
M`0!E````!#(!``D```!J,@$`!P```'0R`0`F````?#(!`#@```"C,@$`&@``
M`-PR`0`J````]S(!`#L````B,P$`*````%XS`0`T````AS,!`!D```"\,P$`
M%0```-8S`0`%````[#,!``<```#R,P$`"````/HS`0`'`````S0!``4````+
M-`$`!P```!$T`0`.````&30!``D````H-`$`!@```#(T`0`(````.30!``L`
M``!"-`$`!P```$XT`0`(````5C0!``<```!?-`$`%@```&<T`0`)````?C0!
M``8```"(-`$`"P```(\T`0`<````FS0!`!0```"X-`$`!P```,TT`0`1````
MU30!``@```#G-`$`#@```/`T`0`(````_S0!``4````(-0$`$`````XU`0`0
M````'S4!``8````P-0$`&0```#<U`0`*````434!`!P```!<-0$`!P```'DU
M`0`%````@34!`!````"'-0$`%````)@U`0`+````K34!``T```"Y-0$`&```
M`,<U`0`7````X#4!`!H```#X-0$`%````!,V`0`$````*#8!``D````M-@$`
M"@```#<V`0`'````0C8!``(```!*-@$`#@```$TV`0`(````7#8!`!\```!E
M-@$`/@```(4V`0`C````Q#8!`#@```#H-@$`,0```"$W`0`G````4S<!`&0`
M``![-P$`%````.`W`0`<````]3<!`%4````2.`$`.````&@X`0!*````H3@!
M`%L```#L.`$`*````$@Y`0`X````<3D!`"H```"J.0$`*````-4Y`0`L````
M_CD!`"<````K.@$`&P```%,Z`0`^````;SH!`*D!``"N.@$`*````%@\`0`C
M````@3P!`!<```"E/`$`2````+T\`0"%````!CT!`#````",/0$`00```+T]
M`0!;````_ST!`$D```!;/@$`'0```*4^`0`8````PSX!`"$```#</@$`'P``
M`/X^`0`K````'C\!`"$```!*/P$`*0```&P_`0`G````EC\!`!T```"^/P$`
M$0```-P_`0`S````[C\!`"4````B0`$`.````$A``0`G````@4`!`"````"I
M0`$`'P```,I``0`P````ZD`!`&D````;00$`*P```(5!`0`Q````L4$!`$$`
M``#C00$`,P```"5"`0`E````64(!`#T```!_0@$`90```+U"`0!-````(T,!
M`"\```!Q0P$`+@```*%#`0`K````T$,!`#````#\0P$`*@```"U$`0`^````
M6$0!`%0```"71`$`@P```.Q$`0!:````<$4!`$@```#+10$`2@```!1&`0`R
M````7T8!`!T```"21@$`(P```+!&`0`O````U$8!`"P````$1P$`+0```#%'
M`0!Q````7T<!`&\```#11P$`LP```$%(`0`7````]4@!`"4````-20$`,@``
M`#-)`0`I````9DD!`#X```"020$`(@```,])`0!2````\DD!`"4```!%2@$`
M"P```&M*`0"Q````=TH!`$4````I2P$`(0```&]+`0`N````D4L!`#````#`
M2P$`)0```/%+`0`<````%TP!`#$````T3`$`!P```&9,`0`'````;DP!``0`
M``!V3`$`#0```'M,`0`+````B4P!``X```"53`$`"P```*1,`0`%````L$P!
M`!````"V3`$``@```,=,`0!9````RDP!``4````D30$`$@```"I-`0`$````
M/4T!``<```!"30$`"````$I-`0`%````4TT!``,```!930$`$````%U-`0`*
M````;DT!``P```!Y30$`$P```(9-`0`-````FDT!``(```"H30$`!P```*M-
M`0`&````LTT!`!0```"Z30$`#````,]-`0`8````W$T!``8```#U30$`$@``
M`/Q-`0`,````#TX!``,````<3@$`*@```"!.`0`$````2TX!``8```!03@$`
M!P```%=.`0`?````7TX!`#4```!_3@$`+@```+5.`0`O````Y$X!`!<````4
M3P$`(````"Q/`0`;````34\!`!@```!I3P$`)````()/`0`?````IT\!`!H`
M``#'3P$`(````.)/`0`:`````U`!`#(````>4`$`&@```%%0`0`O````;%`!
M`"L```"<4`$`'P```,A0`0`C````Z%`!`!\````,40$`&@```"Q1`0`E````
M1U$!`"8```!M40$`)0```)11`0`D````NE$!`!@```#?40$`'0```/A1`0`D
M````%E(!`!@````[4@$`(@```%12`0`5````=U(!`"4```"-4@$`/````+-2
M`0`?````\%(!`",````04P$`'P```#13`0`@````5%,!`!H```!U4P$`&```
M`)!3`0`F````J5,!`!X```#04P$`*0```.]3`0`>````&50!``D````X5`$`
M#````$)4`0`7````3U0!`"\```!G5`$`)````)=4`0`'````O%0!`!\```#$
M5`$`#P```.14`0`4````]%0!``X````)50$`#0```!A5`0`D````)E4!``4`
M``!+50$`!P```%%5`0`B````654!`"4```!\50$`$P```*)5`0`:````ME4!
M`!T```#150$`&@```.]5`0`'````"E8!`,<````25@$`"P```-I6`0`5````
MYE8!``P```#\5@$`!@````E7`0`)````$%<!`!@````:5P$`"P```#-7`0`-
M````/U<!`!T```!-5P$`%P```&M7`0`&````@U<!`#,```"*5P$`$P```+Y7
M`0`3````TE<!``<```#F5P$`!@```.Y7`0`/````]5<!``<````%6`$`,@``
M``U8`0`A````0%@!`!,```!B6`$`#````'98`0`1````@U@!`#(```"56`$`
M#@```,A8`0`/````UU@!`!````#G6`$`"````/A8`0`=`````5D!``D````?
M60$`"@```"E9`0`%````-%D!`!0````Z60$`"@```$]9`0`=````6ED!``@`
M``!X60$`'P```(%9`0`(````H5D!`!H```"J60$`)P```,59`0`&````[5D!
M`!4```#T60$`!P````I:`0`(````$EH!``D````;6@$`/P```"5:`0`'````
M95H!``\```!M6@$`#@```'U:`0`0````C%H!``D```"=6@$`"0```*=:`0`(
M````L5H!`!,```"Z6@$`!P```,Y:`0`9````UEH!``H```#P6@$`"@```/M:
M`0`)````!EL!`!<````06P$`%````"A;`0`*````/5L!``P```!(6P$`%P``
M`%5;`0`$````;5L!`"H```!R6P$`$0```)U;`0`'````KUL!``D```"W6P$`
M`@```,%;`0`0````Q%L!`!@```#56P$`"P```.Y;`0`#````^EL!``@```#^
M6P$`!@````=<`0`'````#EP!``T````67`$`"P```"1<`0`4````,%P!`!4`
M``!%7`$`#@```%M<`0`O````:EP!`"````":7`$`'````+M<`0`,````V%P!
M`#$```#E7`$`!0```!==`0`2````'5T!`#\````P70$`$@```'!=`0`*````
M@UT!``8```".70$`!````)5=`0`$````FET!``H```"?70$`$P```*I=`0`%
M````OET!``8```#$70$`!@```,M=`0`)````TET!``0```#<70$`#````.%=
M`0`*````[ET!`"````#Y70$`!0```!I>`0`8````(%X!`!D````Y7@$`'P``
M`%->`0`=````<UX!`!$```"17@$``@```*->`0`$````IEX!``H```"K7@$`
M!@```+9>`0`%````O5X!``,```##7@$`#````,=>`0!%````U%X!`!H````:
M7P$`-0```#5?`0`E````:U\!`"@```"17P$`4P```+I?`0`9````#F`!`'(`
M```H8`$`(````)M@`0`U````O&`!`"$```#R8`$`10```!1A`0`P````6F$!
M`",```"+80$`'P```*]A`0`H````SV$!`"D```#X80$`)@```")B`0`E````
M26(!`"@```!O8@$`*````)AB`0`B````P6(!`"$```#D8@$`*P````9C`0`P
M````,F,!`!(```!C8P$`$P```'9C`0`0````BF,!`'D```";8P$`"0```!5D
M`0!R````'V0!`',```"29`$`?`````9E`0`K````@V4!`%0```"O90$`%P``
M``1F`0`6````'&8!``\````S9@$`90```$-F`0`?````J68!`%$```#)9@$`
M-P```!MG`0`V````4V<!`#8```"*9P$`/@```,%G`0!!`````&@!`$,```!"
M:`$`?````(9H`0!``````VD!`#X```!$:0$`0````(-I`0!"````Q&D!`#D`
M```':@$`'P```$%J`0!`````86H!`!\```"B:@$`'````,)J`0!1````WVH!
M`!L````Q:P$`%````$UK`0`*````8FL!``4```!M:P$`!@```'-K`0`(````
M>FL!``4```"#:P$`$@```(EK`0`0````G&L!`!,```"M:P$`'0```,%K`0`/
M````WVL!``\```#O:P$`!````/]K`0`)````!&P!``L````.;`$`!P```!IL
M`0`%````(FP!`!0````H;`$`!P```#UL`0`(````16P!``\```!.;`$`"```
M`%YL`0`,````9VP!``\```!T;`$`!@```(1L`0`4````BVP!``8```"@;`$`
M#````*=L`0`5````M&P!``@```#*;`$`!````--L`0`*````V&P!``0```#C
M;`$`!@```.AL`0`'````[VP!``0```#W;`$`!P```/QL`0`9````!&T!``(`
M```>;0$``@```"%M`0`)````)&T!``8````N;0$`%0```#5M`0`&````2VT!
M`"<```!2;0$``@```'IM`0`$````?6T!``L```"";0$`"0```(YM`0`/````
MF&T!`!,```"H;0$`!P```+QM`0`'````Q&T!``8```#,;0$`!@```--M`0`0
M````VFT!`!(```#K;0$``@```/YM`0`&`````6X!``D````(;@$`,P```!)N
M`0`B````1FX!``<```!I;@$`!P```'%N`0`'````>6X!``L```"!;@$`!0``
M`(UN`0`"````DVX!``L```"6;@$`4@$``*)N`0!K````]6\!`,\```!A<`$`
M<````#%Q`0#&````HG$!`(X```!I<@$`2````/AR`0!"````07,!`"D```"$
M<P$`-0```*YS`0`Q````Y',!`#`````6=`$`2P```$=T`0!E````DW0!`&D`
M``#Y=`$`2P```&-U`0!J````KW4!`%,````:=@$`00```&YV`0!-````L'8!
M`$X```#^=@$`,P```$UW`0!,````@7<!`$T```#.=P$`:0```!QX`0`Z````
MAG@!`#D```#!>`$`<````/MX`0`R````;'D!`",```"?>0$`L0```,-Y`0!-
M````=7H!`!(!``##>@$`3````-9[`0`W````(WP!`*D```!;?`$`2@````5]
M`0`/````4'T!`!,```!@?0$`#@```'1]`0`(````@WT!``D```",?0$`"@``
M`)9]`0`%````H7T!`!\```"G?0$`,@```,=]`0`P````^GT!`"D````K?@$`
M*````%5^`0`>````?GX!``P```"=?@$`%0```*I^`0`H````P'X!`!(```#I
M?@$`#````/Q^`0`1````"7\!`!`````;?P$`!0```"Q_`0`A````,G\!`!``
M``!4?P$`$````&5_`0`6````=G\!`!4```"-?P$`#````*-_`0`M````L'\!
M`!,```#>?P$`,0```/)_`0`K````)(`!`#(```!0@`$`&0```(.``0`0````
MG8`!``H```"N@`$`$@```+F``0`]````S(`!`"T````*@0$`)0```#B!`0`0
M````7H$!`!L```!O@0$`)P```(N!`0`V````LX$!``X```#J@0$`#````/F!
M`0`.````!H(!`!$````5@@$`!@```">"`0`K````+H(!``L```!:@@$`&@``
M`&:"`0`/````@8(!`!L```"1@@$`$0```*V"`0`1````OX(!``H```#1@@$`
M!P```-R"`0!6````Y((!`"P````[@P$`)````&B#`0!5````C8,!`&$```#C
M@P$`>0```$6$`0!X````OX0!`'P````XA0$`>P```+6%`0!8````,88!``\`
M``"*A@$`$0```)J&`0`9````K(8!`!````#&A@$`$@```->&`0`8````ZH8!
M``4````#AP$`!@````F'`0`2````$(<!``<````CAP$`#0```"N'`0`-````
M.8<!`!,```!'AP$`"@```%N'`0`3````9H<!`#<```!ZAP$`+@```+*'`0`-
M````X8<!`!(```#OAP$`"P````*(`0`(````#H@!``H````7B`$`&P```"*(
M`0`;````/H@!`!````!:B`$`%@```&N(`0`6````@H@!`!X```"9B`$`'@``
M`+B(`0`E````UX@!`!$```#]B`$`&@````^)`0`/````*HD!`"H````ZB0$`
M'0```&6)`0`:````@XD!`!\```">B0$`$P```+Z)`0!S````THD!`$(```!&
MB@$`+P```(F*`0`O````N8H!``<```#IB@$`"@```/&*`0`P````_(H!``X`
M```MBP$`!P```#R+`0`+````1(L!``@```!0BP$`"````%F+`0`)````8HL!
M``L```!LBP$`#````'B+`0`$````A8L!`!0```"*BP$`#````)^+`0`+````
MK(L!`!````"XBP$`&0```,F+`0`F````XXL!`!$````*C`$`&@```!R,`0`:
M````-XP!`!X```!2C`$`&````'&,`0`4````BHP!`!(```"?C`$`$@```+*,
M`0`G````Q8P!`"<```#MC`$`!P```!6-`0`&````'8T!``@````DC0$`#@``
M`"V-`0`'````/(T!``D```!$C0$`$P```$Z-`0`)````8HT!``\```!LC0$`
M%0```'R-`0`8````DHT!``H```"KC0$`#P```+:-`0`%````QHT!`!<```#,
MC0$`"P```.2-`0`*````\(T!`$L```#[C0$`10```$>.`0`+````C8X!``@`
M``"9C@$`%0```**.`0`%````N(X!``4```"^C@$`$````,2.`0`+````U8X!
M`!<```#AC@$`+@```/F.`0`0````*(\!`%X````YCP$`/0```)B/`0`\````
MUH\!`#\````3D`$`/P```%.0`0`*````DY`!``D```">D`$`!@```*B0`0`*
M````KY`!``H```"ZD`$`00```,60`0`]````!Y$!`$````!%D0$`<0```(:1
M`0`_````^)$!`$,````XD@$`/P```'R2`0!1````O)(!`#,````.DP$`-P``
M`$*3`0`_````>I,!`$,```"ZDP$`(````/Z3`0`<````'Y0!`#T````\E`$`
M*0```'J4`0`2````I)0!`!,```"WE`$`#0```,N4`0`-````V90!`"X```#G
ME`$`"P```!:5`0`0````(I4!`!L````SE0$`'P```$^5`0`'````;Y4!``<`
M``!WE0$`%@```'^5`0`+````EI4!``@```"BE0$`+0```*N5`0`*````V94!
M``H```#DE0$`!P```.^5`0`&````]Y4!``4```#^E0$`"`````26`0`&````
M#98!``H````4E@$`+0```!^6`0`2````398!``@```!@E@$`!````&F6`0`(
M````;I8!``L```!WE@$`!````(.6`0`,````B)8!``8```"5E@$`$P```)R6
M`0`&````L)8!``@```"WE@$`!0```,"6`0`+````QI8!``D```#2E@$`*0``
M`-R6`0`1````!I<!`"X````8EP$`&P```$>7`0`)````8Y<!`!,```!MEP$`
M#````(&7`0`'````CI<!``,```"6EP$``P```)J7`0`7````GI<!`!<```"V
MEP$`-P```,Z7`0`(````!I@!``D````/F`$`"@```!F8`0`'````))@!`&,`
M```LF`$`/````)"8`0`&````S9@!``D```#4F`$`&````-Z8`0`L````]Y@!
M`"4````DF0$`-@```$J9`0`R````@9D!`#,```"TF0$`D0```.B9`0!(````
M>IH!``D```##F@$`"P```,V:`0`=````V9H!``T```#WF@$`#`````6;`0`3
M````$IL!``T````FFP$`$P```#2;`0`.````2)L!``P```!7FP$`%@```&2;
M`0`)````>YL!`!P```"%FP$`'0```**;`0`1````P)L!`!(```#2FP$`%0``
M`.6;`0`&````^YL!`!(````"G`$`!@```!6<`0`/````')P!`!0````LG`$`
MA````$&<`0`7````QIP!`!8```#>G`$`!P```/6<`0`3````_9P!`$(````1
MG0$`!0```%2=`0`%````6IT!`!\```!@G0$`'@```("=`0`7````GYT!`!X`
M``"WG0$`$0```-:=`0`T````Z)T!`"\````=G@$`#P```$V>`0`H````79X!
M`#````"&G@$`'0```+>>`0`&````U9X!`!@```#<G@$`&0```/6>`0`5````
M#Y\!`!4````EGP$`$0```#N?`0`*````39\!`!,```!8GP$`$0```&R?`0`&
M````?I\!``L```"%GP$`!P```)&?`0`+````F9\!``X```"EGP$`%P```+2?
M`0`)````S)\!``4```#6GP$`"P```-R?`0`(````Z)\!``@```#QGP$`%```
M`/J?`0`&````#Z`!``8````6H`$`#````!V@`0`/````*J`!``@````ZH`$`
M"0```$.@`0`+````3:`!`!````!9H`$`!P```&J@`0`%````<J`!``@```!X
MH`$`$P```(&@`0`(````E:`!``L```">H`$`&@```*J@`0`K````Q:`!`!``
M``#QH`$`$P````*A`0`:````%J$!``4````QH0$`'````#>A`0`:````5*$!
M`!L```!OH0$`/0```(NA`0!,````R:$!`"@````6H@$`/0```#^B`0`/````
M?:(!``8```"-H@$`"P```)2B`0`&````H*(!``@```"GH@$`$````+"B`0`2
M````P:(!``H```#4H@$`#@```-^B`0`X````[J(!`#@````GHP$`.P```&"C
M`0`[````G*,!`"L```#8HP$`*@````2D`0`I````+Z0!`"P```!9I`$`*0``
M`(:D`0!"````L*0!`"````#SI`$`+P```!2E`0!&````1*4!`"T```"+I0$`
M,````+FE`0`H````ZJ4!`"\````3I@$`/````$.F`0`^````@*8!`#0```"_
MI@$`,0```/2F`0`Y````)J<!`"\```!@IP$`,@```)"G`0!&````PZ<!`#``
M```*J`$`'P```#NH`0`Z````6Z@!`"X```"6J`$`.````,6H`0`?````_J@!
M`-P````>J0$`'P```/NI`0`N````&ZH!`#$```!*J@$`,@```'RJ`0`U````
MKZH!`#````#EJ@$`+@```!:K`0`Q````1:L!`#D```!WJP$`/````+&K`0!$
M````[JL!`#P````SK`$`Q0```'"L`0`O````-JT!`"(```!FK0$`+P```(FM
M`0`S````N:T!`#X```#MK0$`9````"RN`0!=````D:X!``X```#OK@$`!```
M`/ZN`0`%`````Z\!``D````)KP$`#@```!.O`0`6````(J\!`!4````YKP$`
M#P```$^O`0`2````7Z\!``@```!RKP$`!````'NO`0`1````@*\!``T```"2
MKP$`$````*"O`0`0````L:\!`!@```#"KP$`#@```-NO`0!1````ZJ\!``P`
M```\L`$`%````$FP`0`&````7K`!`!,```!EL`$`&0```'FP`0`>````D[`!
M`!4```"RL`$``@```,BP`0`'````R[`!`!````#3L`$`!0```.2P`0`-````
MZK`!``T```#XL`$``P````:Q`0`/````"K$!``@````:L0$`!@```".Q`0`)
M````*K$!`!$````TL0$`"````$:Q`0`-````3[$!`!$```!=L0$`#@```&^Q
M`0`.````?K$!``P```"-L0$`"@```)JQ`0`)````I;$!``<```"OL0$`#@``
M`+>Q`0`.````QK$!`"$```#5L0$`#0```/>Q`0`.````!;(!`"8````4L@$`
M%P```#NR`0`M````4[(!``T```"!L@$`'0```(^R`0`;````K;(!`!H```#)
ML@$`*@```.2R`0`N````#[,!`!$````^LP$`"````%"S`0`0````6;,!`"\`
M``!JLP$`&P```)JS`0`,````MK,!`"(```##LP$`,````.:S`0`+````%[0!
M``@````CM`$`'0```"RT`0`*````2K0!`!4```!5M`$`%0```&NT`0`+````
M@;0!`",```"-M`$`%0```+&T`0`9````Q[0!``T```#AM`$`$P```.^T`0`)
M`````[4!``T````-M0$`+P```!NU`0!1````2[4!``@```"=M0$`%P```*:U
M`0`-````OK4!`!````#,M0$`-````-VU`0`,````$K8!``8````?M@$`!0``
M`":V`0`&````++8!``<````SM@$`"@```#NV`0`0````1K8!`!$```!7M@$`
M$0```&FV`0`1````>[8!`!H```"-M@$`'0```*BV`0`:````QK8!`!@```#A
MM@$`!P```/JV`0`'`````K<!``L````*MP$`"@```!:W`0`"````(;<!``4`
M```DMP$`#````"JW`0`E````-[<!`!4```!=MP$`!P```'.W`0`0````>[<!
M`!````",MP$`%````)VW`0`\````LK<!`"<```#OMP$`!````!>X`0`'````
M'+@!`!$````DN`$`EP```#:X`0`9````SK@!`$D```#HN`$`$0```#*Y`0`'
M````1+D!``8```!,N0$`00```%.Y`0`E````E;D!`!T```"[N0$`'P```-FY
M`0`(````^;D!``<````"N@$`"0````JZ`0`)````%+H!``8````>N@$`#P``
M`"6Z`0`.````-;H!`!````!$N@$`#@```%6Z`0`3````9+H!`!$```!XN@$`
M$````(JZ`0`.````F[H!``D```"JN@$`"@```+2Z`0`*````O[H!``X```#*
MN@$`#````-FZ`0`]````YKH!``T````DNP$`"````#*[`0`6````.[L!`!``
M``!2NP$`(P```&.[`0`S````A[L!`"<```"[NP$`)@```..[`0`O````"KP!
M`"D````ZO`$`-@```&2\`0`L````F[P!`#````#(O`$`*P```/F\`0`&````
M);T!``X````LO0$`!@```#N]`0`0````0KT!``,```!3O0$`!P```%>]`0`3
M````7[T!`!4```!SO0$`$P```(F]`0`9````G;T!``H```"WO0$`!P```,*]
M`0`0````RKT!`!(```#;O0$`#````.Z]`0`)````^[T!``P````%O@$`#P``
M`!*^`0`Q````(KX!``8```!4O@$`"````%N^`0`,````9+X!``X```!QO@$`
M%P```("^`0`(````F+X!``@```"AO@$`!0```*J^`0`B````L+X!``P```#3
MO@$`!0```."^`0`J````YKX!`!`````1OP$`<0```"*_`0`3````E+\!``D`
M``"HOP$`"@```+*_`0`-````O;\!``L```#+OP$`#0```->_`0`%````Y;\!
M``T```#KOP$`&````/F_`0`9````$L`!``(````LP`$`!@```"_``0`*````
M-L`!`!<```!!P`$`&@```%G``0`4````=,`!`!0```")P`$`(````)[``0`3
M````O\`!`!8```#3P`$`,0```.K``0`#````',$!``0````@P0$`&0```"7!
M`0`(````/\$!`!(```!(P0$`!P```%O!`0`%````8\$!`!H```!IP0$`"0``
M`(3!`0`&````CL$!`!D```"5P0$`#@```*_!`0`I````OL$!``@```#HP0$`
M"P```/'!`0`/````_<$!``4````-P@$`"0```!/"`0`'````'<(!``,````E
MP@$`!@```"G"`0`,````,,(!``H````]P@$`#````$C"`0`7````5<(!``@`
M``!MP@$`!P```';"`0`1````?L(!`",```"0P@$`#0```+3"`0`'````PL(!
M``H```#*P@$`!````-7"`0`)````VL(!``@```#DP@$`"@```.W"`0`*````
M^,(!``D````#PP$`!@````W#`0`-````%,,!``8````BPP$`!````"G#`0`[
M````+L,!`#X```!JPP$`/0```*G#`0`F````Y\,!``4````.Q`$`$````!3$
M`0`&````)<0!``L````LQ`$`&0```#C$`0`0````4L0!`!@```!CQ`$`!```
M`'S$`0`%````@<0!``L```"'Q`$`!0```)/$`0"Y````F<0!``H```!3Q0$`
M'@```%[%`0`$````?<4!`"0```""Q0$`"P```*?%`0`,````L\4!``H```#`
MQ0$`#@```,O%`0`.````VL4!``@```#IQ0$`"0```/+%`0`%````_,4!`!L`
M```"Q@$`,P```![&`0`S````4L8!`#P```"&Q@$`+P```,/&`0`U````\\8!
M`$X````IQP$`2````'C'`0`U````P<<!`%8```#WQP$`.P```$[(`0!,````
MBL@!`#````#7R`$`$0````C)`0`9````&LD!``L````TR0$`0P```$#)`0`O
M````A,D!`"(```"TR0$`+@```-?)`0`0````!LH!`!(````7R@$`!P```"K*
M`0`&````,LH!`#$````YR@$`,0```&O*`0`X````G<H!``H```#6R@$`&P``
M`.'*`0`I````_<H!`!\````GRP$`$P```$?+`0`&````6\L!``H```!BRP$`
M#````&W+`0`/````>LL!`!D```"*RP$`7P```*3+`0!]````!,P!`'H```""
MS`$`#0```/W,`0`(````"\T!``D````4S0$`$0```![-`0`2````,,T!``X`
M``!#S0$`!@```%+-`0`7````6<T!`!4```!QS0$`$P```(?-`0`.````F\T!
M`!0```"JS0$`$0```+_-`0`;````T<T!`"H```#MS0$`E0```!C.`0`1````
MKLX!``8```#`S@$`$0```,?.`0`*````V<X!``L```#DS@$`#0```/#.`0`:
M````_LX!`!8````9SP$`#P```##/`0`0````0,\!``T```!1SP$`%P```%_/
M`0`L````=\\!`"L```"DSP$`*P```-#/`0`J````_,\!`#8````GT`$`-0``
M`%[0`0`<````E-`!`$\```"QT`$`%0````'1`0`4````%]$!`!8````LT0$`
M%0```$/1`0`6````6=$!`!8```!PT0$`%0```(?1`0`5````G=$!`!0```"S
MT0$`,P```,C1`0`8````_-$!`!@````5T@$`.P```"[2`0`2````:M(!``@`
M``!]T@$`%````(;2`0`Q````F](!`",```#-T@$`%````/'2`0`3````!M,!
M`!D````:TP$`%@```#33`0`6````2],!`!L```!BTP$`&0```'[3`0`4````
MF-,!`!\```"MTP$`(@```,W3`0`5````\-,!`!4````&U`$`%P```!S4`0`5
M````--0!`!H```!*U`$`'0```&74`0`;````@]0!`!@```"?U`$`"````+C4
M`0`8````P=0!``0```#:U`$`!@```-_4`0`+````YM0!`!0```#RU`$`!@``
M``?5`0`*````#M4!``8````9U0$`!P```"#5`0`'````*-4!``8````PU0$`
M!0```#?5`0`7````/=4!``8```!5U0$`"0```%S5`0`$````9M4!``0```!K
MU0$`"0```'#5`0`*````>M4!``D```"%U0$`$````(_5`0`1````H-4!``H`
M``"RU0$`%0```+W5`0`%````T]4!`#4```#9U0$`#P````_6`0`2````']8!
M`!P````RU@$`#@```$_6`0`,````7M8!``X```!KU@$`20```'K6`0`&````
MQ-8!``@```#+U@$`(0```-36`0`.````]M8!`!,````%UP$`!@```!G7`0`+
M````(-<!``D````LUP$`!P```#;7`0`$````/M<!``T```!#UP$`#P```%'7
M`0`6````8=<!`!0```!XUP$`&P```(W7`0`:````J=<!``@```#$UP$`!@``
M`,W7`0`&````U-<!`!T```#;UP$`!P```/G7`0`%`````=@!`!$````'V`$`
M"P```!G8`0`'````)=@!``<````MV`$`!@```#78`0`-````/-@!``H```!*
MV`$`#@```%78`0`3````9-@!`!4```!XV`$`%````([8`0`;````H]@!`!,`
M``"_V`$`%0```-/8`0`(````Z=@!``0```#RV`$`$@```/?8`0`7````"MD!
M``4````BV0$`$0```"C9`0`E````.MD!`!0```!@V0$`%@```'79`0`1````
MC-D!``T```">V0$`#````*S9`0`)````N=D!``\```##V0$`#@```-/9`0`0
M````XMD!`!````#SV0$`+`````3:`0`)````,=H!``<````[V@$`%````$/:
M`0`'````6-H!`!````!@V@$`$````'':`0`#````@MH!``@```"&V@$`"```
M`(_:`0`/````F-H!`&D```"HV@$`&0```!+;`0`+````+-L!``4````XVP$`
M!P```#[;`0`:````1ML!`!H```!AVP$`$P```'S;`0`)````D-L!``(```":
MVP$`!````)W;`0`D````HML!``<```#'VP$`!0```,_;`0`O````U=L!``H`
M```%W`$`!0```!#<`0`'````%MP!`!0````>W`$`$````#/<`0!(````1-P!
M`!<```"-W`$`!@```*7<`0`(````K-P!``D```"UW`$`!````+_<`0`%````
MQ-P!`'0```#*W`$`"P```#_=`0`.````2]T!``0```!:W0$`#````%_=`0`F
M````;-T!`#4```"3W0$`#@```,G=`0`*````V-T!`!(```#CW0$`"P```/;=
M`0`)`````MX!`!D````,W@$`*````";>`0`I````3]X!`"@```!YW@$`#@``
M`*+>`0`#````L=X!``X```"UW@$`!P```,3>`0`2````S-X!`!H```#?W@$`
M%0```/K>`0`3````$-\!`!H````DWP$`)@```#_?`0`*````9M\!``H```!Q
MWP$`%````'S?`0`O````D=\!`!P```#!WP$`,P```-[?`0`P````$N`!``D`
M``!#X`$`6@```$W@`0`<````J.`!``X```#%X`$`#````-3@`0`;````X>`!
M`$P```#]X`$`'0```$KA`0`'````:.$!`"0```!PX0$`"````)7A`0`&````
MGN$!`"(```"EX0$`!0```,CA`0`'````SN$!`"D```#6X0$`*`````#B`0`T
M````*>(!``@```!>X@$`#0```&?B`0`>````=>(!`&(```"4X@$`&````/?B
M`0`6````$.,!`!4````GXP$``@```#WC`0`+````0.,!``4```!,XP$`#@``
M`%+C`0`.````8>,!``8```!PXP$`!P```'?C`0`/````?^,!``8```"/XP$`
M"````);C`0`.````G^,!``D```"NXP$`"@```+CC`0`*````P^,!``<```#.
MXP$`$@```-;C`0`3````Z>,!`!(```#]XP$`"@```!#D`0`*````&^0!``L`
M```FY`$`"0```#+D`0`*````/.0!``D```!'Y`$`"````%'D`0`?````6N0!
M``\```!ZY`$`"@```(KD`0`+````E>0!`!$```"AY`$`!0```+/D`0`9````
MN>0!``0```#3Y`$`!P```-CD`0`%````X.0!``\```#FY`$`!0```/;D`0`+
M````_.0!`!@````(Y0$`$@```"'E`0`9````-.4!`!L```!.Y0$`(@```&KE
M`0`6````C>4!`!<```"DY0$`$@```+SE`0`6````S^4!``@```#FY0$``P``
M`._E`0`-````\^4!``X````!Y@$`!P```!#F`0`=````&.8!``H````VY@$`
M#P```$'F`0`6````4>8!``L```!HY@$`"P```'3F`0`&````@.8!`!````"'
MY@$`%0```)CF`0`'````KN8!``D```"VY@$`!0```,#F`0`'````QN8!``8`
M``#.Y@$`!````-7F`0`$````VN8!`$````#?Y@$`.@```"#G`0`4````6^<!
M`#,```!PYP$`.P```*3G`0`1````X.<!`$P```#RYP$`3````#_H`0`6````
MC.@!`#H```"CZ`$`2P```-[H`0!+````*ND!`%$```!VZ0$`%P```,CI`0`9
M````X.D!`$L```#ZZ0$`%P```$;J`0`5````7NH!`!8```!TZ@$`'0```(OJ
M`0`3````J>H!`!H```"]Z@$`%````-CJ`0`7````[>H!`!P````%ZP$`-P``
M`"+K`0`W````6NL!`#L```"2ZP$`-P```,[K`0`X````!NP!`#D````_[`$`
M-@```'GL`0!U````L.P!`",````F[0$`#````$KM`0`,````5^T!`#4```!D
M[0$`-````)KM`0`L````S^T!`#````#\[0$`"P```"WN`0!<````.>X!`%8`
M``"6[@$`#P```.WN`0`&````_>X!`!D````$[P$`%@```![O`0`,````->\!
M`!0```!"[P$`$@```%?O`0`(````:N\!``H```!S[P$`"0```'[O`0`0````
MB.\!`!0```"9[P$`$````*[O`0`2````O^\!``<```#2[P$`)0```-KO`0`'
M`````/`!``@````(\`$`!````!'P`0`2````%O`!`!(````I\`$`$0```#SP
M`0`O````3O`!``(```!^\`$`!@```('P`0`/````B/`!`!4```"8\`$`"0``
M`*[P`0`'````N/`!`!P```#`\`$`!````-WP`0`/````XO`!``0```#R\`$`
M+P```/?P`0`9````)_$!`!\```!!\0$`7@```&'Q`0`7````P/$!`$<```#8
M\0$`*0```"#R`0`-````2O(!`!4```!8\@$`#0```&[R`0`4````?/(!``D`
M``"1\@$`$0```)OR`0`,````K?(!`!8```"Z\@$`#0```-'R`0`=````W_(!
M`!8```#]\@$`"````!3S`0`4````'?,!``X````R\P$`*@```$'S`0`9````
M;/,!`!@```"&\P$`&@```)_S`0`K````NO,!``@```#F\P$`"0```._S`0`9
M````^?,!`!,````3]`$`$@```"?T`0`9````.O0!`!$```!4]`$`%````&;T
M`0`*````>_0!``P```"&]`$`"````)/T`0`%````G/0!`"$```"B]`$`!@``
M`,3T`0`/````R_0!``@```#;]`$`$0```.3T`0`J````]O0!``@````A]0$`
M&0```"KU`0`1````1/4!`#$```!6]0$`(@```(CU`0`B````J_4!`"D```#.
M]0$`*@```/CU`0`Y````(_8!`!@```!=]@$`"0```';V`0`*````@/8!`"(`
M``"+]@$`"````*[V`0`?````M_8!``0```#7]@$`'````-SV`0`(````^?8!
M``<````"]P$`'`````KW`0`P````)_<!``8```!8]P$`(````%_W`0`0````
M@/<!``H```"1]P$`&0```)SW`0`$````MO<!``D```"[]P$`"P```,7W`0`'
M````T?<!``4```#9]P$`"````-_W`0`%````Z/<!``L```#N]P$`'P```/KW
M`0`^````&O@!`$P```!9^`$`)P```*;X`0`V````SO@!`"<````%^0$`50``
M`"WY`0`G````@_D!`"4```"K^0$`-P```-'Y`0`I````"?H!`#<````S^@$`
M@````&OZ`0`Q````[/H!`&X````>^P$`+@```(W[`0`H````O/L!`"<```#E
M^P$`!0````W\`0`'````$_P!``@````;_`$`"````"3\`0`;````+?P!`!T`
M``!)_`$`*@```&?\`0`J````DOP!`$````"]_`$`1@```/[\`0`)````1?T!
M`!<```!/_0$`"P```&?]`0`(````<_T!`#@```!\_0$`%@```+7]`0`0````
MS/T!`!(```#=_0$`"````/#]`0`3````^?T!``@````-_@$`#0```!;^`0`6
M````)/X!`"<````[_@$`*````&/^`0!#````C/X!``L```#0_@$`!0```-S^
M`0`'````XOX!`",```#J_@$`#`````[_`0`%````&_\!``H````A_P$`#```
M`"S_`0`,````.?\!``L```!&_P$`&@```%+_`0`*````;?\!``H```!X_P$`
M!0```(/_`0`1````B?\!`$D```";_P$`70```.7_`0`>````0P`"`"8```!B
M``(`'````(D``@`2````I@`"`!,```"Y``(`"P```,T``@`B````V0`"`!``
M``#\``(`+0````T!`@`)````.P$"``T```!%`0(`#@```%,!`@`6````8@$"
M`!T```!Y`0(`#````)<!`@`^````I`$"``@```#C`0(`*0```.P!`@`0````
M%@("`!0````G`@(`$@```#P"`@`L````3P("`$8```!\`@(`,P```,,"`@`+
M````]P("`$4````#`P(`,P```$D#`@`W````?0,"`#0```"U`P(`,````.H#
M`@!%````&P0"`#D```!A!`(`.0```)L$`@`0````U00"`!D```#F!`(`#```
M```%`@`5````#04"`!X````C!0(`"@```$(%`@`9````304"``L```!G!0(`
M%P```',%`@`'````BP4"`!H```"3!0(`'````*X%`@`&````RP4"``8```#2
M!0(`$@```-D%`@`,````[`4"`!<```#Y!0(`!0```!$&`@`(````%P8"``X`
M```@!@(`$0```"\&`@`2````008"`!,```!4!@(`$P```&@&`@`'````?`8"
M``8```"$!@(`*````(L&`@`;````M`8"`!H```#0!@(`!P```.L&`@`5````
M\P8"``8````)!P(`(P```!`'`@`C````-`<"`"L```!8!P(`"P```(0'`@`)
M````D`<"``,```":!P(`!@```)X'`@`*````I0<"``(```"P!P(`#````+,'
M`@`5````P`<"``L```#6!P(`&0```.('`@`@````_`<"`!<````="`(`!0``
M`#4(`@`*````.P@"`!4```!&"`(`$@```%P(`@`-````;P@"``D```!]"`(`
M#````(<(`@`.````E`@"`!<```"C"`(`6````+L(`@`=````%`D"`#0````R
M"0(`%````&<)`@`,````?`D"``4```")"0(`#0```(\)`@`@````G0D"`!H`
M``"^"0(`$0```-D)`@`/````ZPD"`"````#["0(`&````!P*`@`0````-0H"
M`"(```!&"@(`)@```&D*`@`0````D`H"`)$```"A"@(`(@```#,+`@`<````
M5@L"`#$```!S"P(`(````*4+`@`:````Q@L"`"P```#A"P(`&@````X,`@`C
M````*0P"`"````!-#`(`&0```&X,`@`/````B`P"``<```"8#`(`"````*`,
M`@`)````J0P"`!8```"S#`(`#````,H,`@`J````UPP"`!8````"#0(`#```
M`!D-`@![````)@T"`%0```"B#0(`10```/<-`@!P````/0X"``T```"N#@(`
M)0```+P.`@`L````X@X"``H````/#P(`!P```!H/`@`5````(@\"`$(````X
M#P(`!@```'L/`@!4````@@\"`#````#7#P(`(@````@0`@`2````*Q`"`"4`
M```^$`(`*@```&00`@`O````CQ`"`"D```"_$`(`+P```.D0`@`E````&1$"
M`!4````_$0(`!P```%41`@`,````71$"``X```!J$0(`%P```'D1`@`+````
MD1$"`#T```"=$0(`#````-L1`@`,````Z!$"`"0```#U$0(`"````!H2`@`3
M````(Q("``@````W$@(`!0```$`2`@`=````1A("``\```!D$@(`"````'02
M`@`)````?1("``8```"'$@(`#0```(X2`@`-````G!("`!(```"J$@(`%```
M`+T2`@`,````TA("`!@```#?$@(`#0```/@2`@`(````!A,"`!$````/$P(`
M'@```"$3`@`0````0!,"``D```!1$P(`&@```%L3`@`L````=A,"`!,```"C
M$P(`+0```+<3`@`M````Y1,"``T````3%`(`!P```"$4`@`(````*10"``<`
M```R%`(`!````#H4`@`5````/Q0"``P```!5%`(`#0```&(4`@`,````<!0"
M``4```!]%`(`"0```(,4`@`(````C10"``D```"6%`(`!@```*`4`@`)````
MIQ0"`!@```"Q%`(`!@```,H4`@`8````T10"``X```#J%`(`!@```/D4`@`/
M`````!4"``P````0%0(`(````!T5`@`*````/A4"``(```!)%0(`)0```$P5
M`@`'````<A4"``H```!Z%0(`AP```(45`@`,````#18"``8````:%@(`(P``
M`"$6`@`T````118"`"````!Z%@(`(````)L6`@!7````O!8"`#$````4%P(`
M-````$87`@`C````>Q<"`"````"?%P(`!0```,`7`@`/````QA<"``T```#6
M%P(`#P```.07`@`&````]!<"``T```#[%P(`$P````D8`@`/````'1@"``\`
M```M&`(`$0```#T8`@`,````3Q@"``<```!<&`(`!P```&08`@`(````;!@"
M`!8```!U&`(`"0```(P8`@`(````EA@"``<```"?&`(`'0```*<8`@`9````
MQ1@"``@```#?&`(`$P```.@8`@`(````_!@"``T````%&0(`"0```!,9`@`'
M````'1D"`!4````E&0(`%0```#L9`@`&````41D"`!L```!8&0(`#0```'09
M`@`<````@AD"``4```"?&0(`"````*49`@`-````KAD"`!\```"\&0(`"@``
M`-P9`@`,````YQD"`!P```#T&0(`$@```!$:`@`:````)!H"`!0````_&@(`
M!````%0:`@`(````61H"``L```!B&@(`"0```&X:`@`"````>!H"`!8```![
M&@(`"````)(:`@`G````FQH"`$(```##&@(`)@````8;`@`^````+1L"`#0`
M``!L&P(`.@```*$;`@!O````W!L"``D```!,'`(`'P```%8<`@!L````=AP"
M`#L```#C'`(`4P```!\=`@!R````<QT"`"D```#F'0(`1P```!`>`@`L````
M6!X"`"\```"%'@(`,0```+4>`@`T````YQX"`!\````<'P(`/@```#P?`@#H
M`0``>Q\"`"D```!D(0(`(@```(XA`@`)````L2$"`$D```"[(0(`J`````4B
M`@`K````KB("`$,```#:(@(`=@```!XC`@!(````E2,"`!0```#>(P(`"@``
M`/,C`@`?````_B,"`"(````>)`(`,````$$D`@`E````<B0"`#4```"8)`(`
M*0```,XD`@`2````^"0"``@````+)0(`2````!0E`@`W````724"`$D```"5
M)0(`*@```-\E`@`G````"B8"`"8````R)@(`*P```%DF`@!H````A28"`"H`
M``#N)@(`0P```!DG`@!&````72<"`$(```"D)P(`.P```.<G`@!0````(R@"
M`&T```!T*`(`6````.(H`@!!````.RD"`#T```!]*0(`/````+LI`@!`````
M^"D"`#P````Y*@(`3P```'8J`@!F````QBH"`*<````M*P(`>````-4K`@!P
M````3BP"`'````"_+`(`.````#`M`@`D````:2T"`"H```".+0(`+@```+DM
M`@`N````Z"T"`#`````7+@(`@P```$@N`@!_````S"X"`-,```!,+P(`&@``
M`"`P`@`L````.S`"`#8```!H,`(`*P```)\P`@!8````RS`"`"T````D,0(`
M5P```%(Q`@`J````JC$"``P```#5,0(`O@```.(Q`@!=````H3("`",```#_
M,@(`.P```",S`@`X````7S,"`"<```"8,P(`(````,`S`@!#````X3,"``8`
M```E-`(`!P```"PT`@`$````-#0"``T````Y-`(`"@```$<T`@`+````4C0"
M``L```!>-`(`!0```&HT`@`0````<#0"``(```"!-`(`7P```(0T`@`%````
MY#0"`!P```#J-`(`!`````<U`@`'````##4"``8````4-0(`!0```!LU`@`$
M````(34"`!<````F-0(`"0```#XU`@`-````2#4"`!,```!6-0(`$````&HU
M`@`"````>S4"``@```!^-0(`!@```(<U`@`5````CC4"``P```"D-0(`%P``
M`+$U`@`&````R34"``X```#0-0(`"@```-\U`@`(````ZC4"`"X```#S-0(`
M"````"(V`@`&````*S8"``<````R-@(`.````#HV`@!<````<S8"`$@```#0
M-@(`20```!DW`@`R````8S<"`#@```"6-P(`+P```,\W`@`J````_S<"`#8`
M```J.`(`,0```&$X`@`K````DS@"`"T```"_.`(`+0```.TX`@!"````&SD"
M`"0```!>.0(`/P```(,Y`@`Z````PSD"`#$```#^.0(`-0```#`Z`@`P````
M9CH"`"L```"7.@(`,@```,,Z`@`V````]CH"`#4````M.P(`*P```&,[`@`M
M````CSL"`#````"].P(`.P```.X[`@`K````*CP"`"@```!6/`(`)P```'\\
M`@`T````ISP"`$\```#</`(`,@```"P]`@`V````7ST"`#$```"6/0(`,@``
M`,@]`@`L````^ST"`"D````H/@(`+@```%(^`@`S````@3X"`$8```"U/@(`
M+P```/P^`@`-````+#\"`!P````Z/P(`(@```%<_`@!!````>C\"`"4```"\
M/P(`$````.(_`@`J````\S\"``\````>0`(`'````"Y``@`6````2T`"`!(`
M``!B0`(`)````'5``@`)````FD`"``D```"D0`(`)0```*Y``@`H````U$`"
M`!8```#]0`(`)P```!1!`@`G````/$$"`"0```!D00(`"0```(E!`@`#`0``
MDT$"`!(```"70@(`'0```*I"`@`+````R$("``X```#40@(`$````.-"`@`C
M````]$("`!8````80P(`&````"]#`@`B````2$,"`!\```!K0P(`"0```(M#
M`@!.````E4,"`!H```#D0P(`$P```/]#`@`'````$T0"``<````;1`(`%0``
M`"-$`@`,````.40"`%D```!&1`(`*0```*!$`@`2````RD0"`!4```#=1`(`
M%0```/-$`@`^````"44"`!<```!(10(`&````&!%`@`.````>44"``P```"(
M10(`*````)5%`@`-````OD4"``X```#,10(`"````-M%`@`5````Y$4"``H`
M``#Z10(`)`````5&`@`+````*D8"`!D````V1@(`"@```%!&`@`=````6T8"
M`"T```!Y1@(`!0```*=&`@`G````K48"``<```#51@(`!P```-U&`@`)````
MY48"`$P```#O1@(`!P```#Q'`@`1````1$<"``L```!61P(`%P```&)'`@`)
M````>D<"``D```"$1P(`!P```(Y'`@`6````ED<"``L```"M1P(`'@```+E'
M`@`/````V$<"``\```#H1P(`$````/A'`@`8````"4@"`!P````B2`(`!0``
M`#](`@`'````14@"`!D```!-2`(`!P```&=(`@`Q````;T@"`!$```"A2`(`
M!P```+-(`@`)````NT@"``(```#%2`(`$````,A(`@`/````V4@"``L```#I
M2`(``P```/5(`@`'````^4@"``L````!20(`"@````U)`@`1````&$D"``X`
M```J20(`&P```#E)`@`<````54D"``H```!R20(`-@```'U)`@`D````M$D"
M`"H```#920(`#0````1*`@`^````$DH"``8```!12@(`%P```%A*`@!`````
M<$H"``X```"Q2@(`!P```,!*`@`'````R$H"``0```#02@(`!````-5*`@`)
M````VDH"`!X```#D2@(`!0````-+`@`&````"4L"``@````02P(`#````!E+
M`@`&````)DL"`!0````M2P(`%````$)+`@`J````5TL"``P```""2P(`'@``
M`(]+`@`A````KDL"`"\```#02P(`*0````!,`@`4````*DP"``(````_3`(`
M!````$),`@`,````1TP"``@```!43`(`!0```%U,`@`"````8TP"`!$```!F
M3`(`80```'A,`@`:````VDP"`#H```#U3`(`-````#!-`@`O````94T"`%X`
M``"530(`%@```/1-`@!]````"TX"`"D```")3@(`1P```+-.`@`I````^TX"
M`$`````E3P(`/@```&9/`@`E````I4\"`"4```#+3P(`-0```/%/`@!,````
M)U`"`#4```!T4`(`-P```*I0`@`Y````XE`"`!\````<40(`+@```#Q1`@`H
M````:U$"`#(```"440(`0````,=1`@`2````"%("`!(````;4@(`#````"Y2
M`@")````.U("``@```#%4@(`=0```,Y2`@!Q````1%,"`(L```"V4P(`+0``
M`$)4`@!E````<%0"`!<```#65`(`%P```.Y4`@`7````!E4"`&T````>50(`
M)````(Q5`@!3````L54"`#P````%5@(`/````$)6`@`X````?U8"`#H```"X
M5@(`.P```/-6`@!'````+U<"`)$```!W5P(`0`````E8`@`W````2E@"`#\`
M``""6`(`0````,)8`@`T`````UD"`"L````X60(`0P```&19`@`F````J%D"
M`"````#/60(`:P```/!9`@`E````7%H"``P```""6@(`"P```(]:`@`%````
MFUH"``8```"A6@(`"````*A:`@`%````L5H"`!8```"W6@(`$````,Y:`@`5
M````WUH"`"````#U6@(`$0```!9;`@`/````*%L"``T````X6P(`"0```$9;
M`@`.````4%L"``@```!?6P(`!@```&A;`@`5````;UL"``D```"%6P(`"0``
M`(];`@`3````F5L"``X```"M6P(`!P```+Q;`@`2````Q%L"``X```#76P(`
M&0```.9;`@`)`````%P"``H````*7`(`&P```!5<`@`(````,5P"``D````Z
M7`(`$````$1<`@`&````55P"``X```!<7`(`!P```&M<`@`%````<UP"``H`
M``!Y7`(`%0```(1<`@`"````FEP"``(```"=7`(`!@```*!<`@`&````IUP"
M`!T```"N7`(`!P```,Q<`@`Z````U%P"``(````/70(`!````!)=`@`.````
M%UT"``X````F70(`$P```#5=`@`8````25T"``H```!B70(`!P```&U=`@`%
M````=5T"``@```![70(`%0```(1=`@`3````FET"``(```"N70(`#@```+%=
M`@`-````P%T"`#(```#.70(`.@````%>`@`'````/%X"``D```!$7@(`#```
M`$Y>`@`1````6UX"``4```!M7@(``@```'->`@`+````=EX"``$```",`P``
M`````#4'````````B@<``-,'``#H!```?P<``#T&``!>!P```````#\%``")
M!```7`8``*\"``"7!P``MP<```8`````````XP$``%P!`````````@$``%``
M``#R!0``:@,``.X!``!S`````````$T"``"I!@````````````"5!```U`0`
M`"H#``!>!@```````(D"``!Y`P```````-(!``!D!```N00``.4&``#[````
M.`8```````#M`@``C@0```````````````````````#%`P``<`0```X```#X
M!0``U`8```0````E`P``PP0``%<```!H!0``X`0``%<&``#?`0``.````"H`
M````````E0```)D'```5!@```````$4!````````O0```-,"``"5`0```@4`
M`(0"``"X!P``W@8```````!P!0``````````````````8`4``$8```"T!P``
M)@4``+X&```4`@``KP,``%\$````````6`0```````"R!```^`0```````"=
M``````````X$``"W`@```````+,!```;`@``<@(`````````````S04``,,&
M``!5!0``````````````````-@$``.@'````````2@8``'\#``!U!P``W@4`
M`+,"``#>`@``2`(`````````````5P0``-X!``#$!0```````!4"````````
MJ````,\'```K!0``4P```,$&``#3!@```````%P%````````60````````"6
M!```"0$````````G````0P<```````#H!0``T@(``,`'``#P`@``R0$``.H%
M``#T`P```````%<#```=`0````````````#$!@``-`,```````!'!P``^P$`
M`&$%``"2!0``%@0``.8&```>````````````````````)@<``"P!``#/!@``
MCP0```````#Q!0```````.T$````````/@```#`$``":!```T0$``$<#``#E
M!0``L`0``/D&```Y`@````````````#)!@``&0<``"<%``#+!````````/H`
M``!0`0``<08``+L%``"P!0``G0,``.0%````````FP<``*L!``!S`P``````
M`"$$``#B`0``'P,``&\!``"3!0``3P,``*<'````````SP$``"4&``#3!0``
M&04``#<'````````(@8``#P#``!A````&@4``$P$```'`0``3@<``(T&``!8
M!0``XP4``+4$``".!@```````*@!``#,`P`````````````$`@``908``#(%
M``"Y`0``FP(``(L#````````@@```,,"``!O````;P4``.T#``!-!```&`$`
M`$,%```#`@``,P(```````!C!@``QP8``!<"`````````````$L%```'!@``
M#0,```<"``#\`@```````!L'````````L0````````"4````2P0``$\!```L
M`P```````*$%``",````R@(``#T%````````#`4``-\&``#(````@`(``#0%
M```V!P``N0(````````\!```>@```,0```"%`@```````"D!``"H`P``````
M`%8"````````/0$``,8&````````A@(```T"``!G`P```````%H%``"J````
M.P0``*L%``"<!@``90<``'<!````````M`(``````````````0,``#<"```*
M!@``4`8``/H$````````[P8``!,```#`!```J@4``$$%```S`0``LP```%4#
M`````````````!P```````````````('````````G@0``&@'``!+`@``K`8`
M`!D$`````````````````````````````/L&``#A!```M04```````#L`@``
M&P4``%4"``"C!P``?@<``%`%``!W`@``DP8``/\```!X!````````*`$````
M````Y0,```````"E!P``"`8``.("```W````@`0``&0'``!U`0``N@8``*X$
M````````#`8``"8```"?!P``H0``````````````=@,``$8#```H!P``F@``
M````````````5P<``"L````"`@``Q`(`````````````+P(```````#^`P``
M?@(``!H'``"8`0``:0(``.8```!,`@```````*````!=````NP<``,H```!F
M`P``'08```````!L!P````````````!1`@``"08``#4````````````````!
M````````7`(``"X'````````,`,``/$#``!V````)@(``+D`````````KP<`
M`(,&```Y!0````````````#H`@``$@8``&D#```E!P``4@,``"4!```*`@``
M`````#L%```(!0``UP8```````#/!0``808``-H#``##``````````````"C
M`@``KP$```````#Q`@`````````````?`@``B`$``(H```#L`0``"`0`````
M``!3`0``#P``````````````#@8`````````````-`$``$T&``#0`@``Y0(`
M``````"(!0```````#('``!1!@``@0(`````````!0``:@<`````````````
M3@0```````!``@``;`(```L#```Q!P``&P```.D&``#G!P```````$,```#.
M`@``UP$``'`&``"<!0``,`4```````"6!0``V0<``+\!``#M`0``R04``'4#
M``!;!0``A`<``-(`````````T0<``(8#``"/!P``+P,``+P$````````*P$`
M``(#```%`@``TP,``!P!```H````F@,``.8'``"!````(`8``+D#````````
MYP(``"\!``#'`0``1P```%(``````````````&L$``!M`P``Z@0``)0&```+
M!0``R@<```````"V!@``WP<``'P%````````C`4``+H!``!\````A0<`````
M``"2`````````/````"!!P``G@,``&,'``"*`0```````.,'``"1`@``$@``
M`),````B`0```````-`%`````````````/H"``"(`P```````!\%``"F````
M``````````!\`@````````````!\`0``%`4``$4%````````C@````````#R
M!@``)0```)0$``!Z!P``!@$``*$'````````9`$`````````````````````
M```L!0``[`,````````:!```O00```````"%!`````````````"T`P``.0<`
M```````I!0```````!H!``!4`0``RP````````!Q!````````/\!```2`@``
M>`8``*D``````````````+P"````````F@$```````"3`P``$P$``!T%``!G
M`@``4@4``,P&``#I````#@,``)@#```(`P``[@8``,````"[````W0$`````
M``!3!P``A04``'D&``#W!@```P4``+H$``#-`P``/`8``&,!``!\`P``!P,`
M``````!/`@```````$X&``"F`@``0P0``'H"``"=!@``6P$``(<$``#5`0``
M`````/\"``"S!0``70$`````````````#P,``#4%``#G!```K@(``.P%````
M!P```````#T$````````$@0`````````````\P0```````"7`@``.0```(`'
M``"7!@````````````#=`@``G04````````\````NP0``$L!```^!P``!`$`
M`+T&`````````````!`'```7!P```````.,#``!6!P``.@```.\"```P````
MB0```!X'``"*!0``'`(`````````````W@<``.4'```Q!@``=P0``#P%``!=
M`@``%P```!X$````````J@(``'0!``!Y!`````````````!M!```BP<`````
M```]`@``=@(``"T#``#F!0``P@4``,L!``"/!0```````#L'````````Y0``
M`%("``!W`P``2P8``"X```!F!0```````+`"``#@`P``C04``-T&```T`@``
MW````!D&```#````\@$``-P&``"R`P``NP,```````!V!0``40<```````""
M`@``P@<``#$```#K`0``0@(``+X'``"C!```]P0``"P`````````7@,``#P"
M```N!@``WP,``!,&``!9!P``[@0````````2`P``E`4```````",`@``&@``
M`%4'``"Q`0````````````!-!P``T04``$D'``"'!@``:P```.\!``!?`0``
M`````!(%````````&@8``&4$````````V`0``"X%``!S!@``,@,``","``#,
M`0``$`$```````#%`@```P,``-8#````````TP$`````````````-P8``#$!
M```G!@``<@,``"H$``!!!````````.8!``!Q`0``ZP8``"T!``#5!@``5`4`
M``````![`0````````````!]`@``X`$```````#W`0```````#,$```3`P``
M``````````!N`0``W`0```````!W!@``@04``$T!````````UP,``#X$``"`
M`0``Q04``,\````P`@```````'L```"H!@``F`8```````!'!@``^P4``'$#
M``#*!````````'0&````````P0,```````"2`0``^04``&$!```E`@``W00`
M`(0`````````-0,``"8#``!@`0``V`<````````^`@```````(D!````````
MSP,```````"I!0``P0$``-\$``#9`@```````(X%``#K`P``V`,```````"*
M!@``$`````````"M!0```````*H#````!@``&0$````````=````#@$`````
M````````#P$```````"@`0``#`,``/`!```B!0``\P4``,@"``!S`@``XP``
M`*H'``"N````J@$```````!4!P``.00``-8$````````[`````````"8````
M7@(```````#&!````````(4```"_````C@<````````&!@``C00``!$%``"P
M`````````*4!``#S````/P(````````*!```,P```%H!````````700``*0"
M````````*P0```````"'`0``^`8``,H#``"+!````````(0&```?!```T@4`
M`/@"````````3@4``)`#``":!P``!P4```````#<`@``G00``.0'```]````
M]@(``-8````0`P``#P8``&P%``"!!@``K0<``*P%``"-`@``\00```($``!1
M!0``Q0$``,("`````````````*0#``"I!P``X0(``/D#````````MP4``$0#
M``!<!```7@4``/`$``#K`@```````,D````H`0```````/X$``#G!@``I0``
M`*`#``"W`P``E@<``!0`````````PP,``!X&```K`P``6@,``/P%``!A!P``
M``````````"1````6P8````````P!P``7`<``%X$```X!P`````````````4
M!```4`(``,@#```:`P````0`````````````?`8``-0"```M!0```````(T'
M``!F!P``]`0``+\%``"C`0``I00`````````````)`<```0$````````50``
M`.8"``"C`````````$0!````````L`$``&0#```P`0```````-L%``!N!0``
M&0```#(!```#!P``OP,```````"S!```#P<``'(%``!'!0```````%H&````
M````*@8````````S`P``*P8``+H"````````%P4``(T```#3````Y`0``.@#
M``#'`P``M@,``%`#```Z`P``"@4`````````````%@,``'L#``"]!0``10(`
M`"0%``#@`@```0$``&4%```$!P```````%X```#:````30,``.($``#H!@``
M)P0``&`$````````10<`````````````[08``*P$``"U!@````````````#(
M!0``7````,$%````````*@$```````"'`@``_@4```````#-!```2@,`````
M``!I````PP<``*<#````````GP,```````#8`0```````.$'``"(!P``(P$`
M`-H"``"\!0`````````````U`@`````````"```V`````````$P```#:!@``
M>P4```````!W!P``H@$``(L%``"I`P``]@```&@!```1!```>``````````-
M!0``*00``+8!``!3!````````&H```#/`@````````````#&!0``````````
M``"*`P````````````!^!@``=P```'4%````````G@(``$(#``#S!@``+`(`
M`#,&````````[P4``-T````(`0```````)8"```J`@``I@4```````"0!```
M0@8``.H'``!_````F`(``&D!``#[!```#`0``"L"``!P!P``+@,```````#D
M`@``Z0$``%0```!R!```G@8``&L#``".`@``:08``+D%``!J!```@@8```D#
M``!(!````P$``&P$```_!```K00``/X```!G!P``0@```$`%````````]0(`
M``````"O````8@(``.$!``!]````H@,```````!Z`0``H0$``.D%```/!```
M-@8``-L'```+`0``U@4``"\$``!O!````````'D"```*`P```````'4$``!-
M!0``:@$``!<$````````+08``.0&``#'`@``5P$``.D"``"]`0``VP,`````
M```,`0``B04``&\&```)`@``VP8``"<"````````T@,``($$``"H!P``````
M`/P#```9`@```````/8!````````Y````&,```"$!0```````!8%``!1````
M`````,<%``"Z`P``4P,``$@#``!G!0``(`````````!B!P```````'L$``"B
M````O`<`````````````)00```````!_`0``I@$``(,!``#V!```=`,``-``
M```D`0``_0(``%8```!E`@``F`0``/T!``"C!0``$@<``!P#``",!```A`0`
M``````"<`@``!@0``#8$`````````````.P$``!7`@```````)P'````````
M`````(P'```H!0```````'L'``!#`P``]`$``$D$``")`P``-````-8&``#&
M!P``&P,``)P#````````6P,``*8#``#>!`````````````!]`0```````%D%
M``"0!@``2`4``%L"```+`````````+0```!4`P``N@<``'8$````````H@0`
M`/\#``"+`@``DP0``&X"`````````````,@'``"T!`````````````"K`P``
M`````&@$``#]`P``K@<``"4%```]`P```````'D``````````````+P#``!?
M!P``O0(``'P$``#5`@``)````/H&``"K!P```````#0$``"K````[`8`````
M```I!@``QP```!T"``!K`@``'0<``&H%```N!````````(\&``#C`@``````
M`'0$```:`@```````!\!```X!```H00``#@!``!-````%`<```````"G````
M.08``,L%```1````2@```*4&``!/!@``+P8``.<```#(`0``@@4```````"3
M`@``V@$``)D&```1!@``6@```/`&``#C!@``Z0,``*<&``!&!@``*0,``.X"
M````````O@`````````@!0``B@(``+X"``"L````IP4``&````"^`0``7P(`
M`'('```5!```$`(``,T!````````7P8```4&```W`0``$`4```````"\````
M`````'D'````````E`$``$<"```,`@``F@8``/4$``"&!P``Q00````````!
M!P```````*P#`````````````$X"````````;04`````````````400``#4$
M````````*`8````````R`@```````-$"``"#`@``>`$``(,'````````AP``
M````````````9`(``#0&``!,`0``]@,``'T#``"X````9P8``"('``!L`P``
M"`<``%@'``!]!@```````(('``#/!```J@8```4#``!9`P```````*("````
M````W0<``.D$``#>`P``D0<``*T"```A`````````"X"``#+`@``(P8``,X'
M````````P@$``(($``#5````;0$``+$%```\`0``.`(``#L````.!0``````
M`)0'``#B`P``EP$``%H'``!``P```````-4'``#+`P``T@<``-4%```S!0``
MA@$``#`&``!(`0```````*$&``#C!````````+8"````````00(``/@````Q
M`P``D@(``'0"``!E`P```````)T'````````1`<``!P&```S!P``N`,`````
M``!`!```EP0```````#)!P```````$X`````````P00```````#^!@``O@0`
M````````````;P<``-<```!3!0``%P8```````!(!@```````*\&``#]!0``
M*@<``.L'``"F!P``.`,``)L``````````````+$&```G!P```````%0&``!'
M`0```````&D'````````A`$`````````````!0$``````````````````+L&
M````````<@```!,'```'!P``\@(``!P%```;`0```````/0`````````````
M`*\$``"=`@``Z`$``/L"``!+!P``C0,``#8"``#N`P``X@4```````!%`P``
M!`4``)8#``#.!0``7@$``(\!````````00```#4&``!<`P``.P(``/0&````
M````V`4``(0#``#,!````````+8'``"%`P``T`$```T$``#O````K@4```4$
M```0!```3`<```4'````````5@8``!@&``!)!0````````````#&`@``````
M`!\```#5`P``?@0``+P!``#E!```5`0``-8!```W!````````*4"```&`@``
M``````\%`````````````#$%``"<````T@0``+$#``!D````L0(``*D"``"O
M!0``#0```&`&````````Z@$``-L````'````70,```(&````````00<``*0&
M``#0!@``&P0``%(!`````````````'X!``#T`@``(@```+L!``!M`@``OP0`
M``````"/`@``0`<``"H%```8!P``#P(``"D"```W!0``80(```T'```5!P``
M'P8``,(```"X`0``Q0<```````!W!0``M0```.T```#4!0``EP,``*P'``#9
M`0``V`8``)`'````````P@,```````#B!@``GP(``)L&````````4P(``,@&
M``!C!0``]P,``%0"``!X`P``4P8``"`"``!L!@``608``,H!```M`@``*P<`
M`*,#``!X`@``VP(`````````````5@$``#@%````````ZP0``!@````B`P``
M`````)D```#7!P``````````````````/0<``'H#````````C@$````#````
M````;P(``)\$```5`P``%@(``)X'``"J!```!`,``'@'``![`@```````,,%
M````````3P<```````"7!0``I04``!X%``"D`0```````'8&````````(0$`
M`-\```!M`````````!,%``"8!P``"@<``#\```!$!0````````8#``!=!P``
MU`````````#W`@``K0,`````````````U`<``"8&````````N`(```````!N
M!P``.@0``&L%``"@`@``R0,```D$``#Y`@```````)4&``"4`@``?@,``$4`
M````````]0```.$&``"?`0``P`4```8'```Z!0``````````````````````
M`%@#``#J`P``J`0``%D$``!`````X`4``$,&````````\`,``*0'```5````
MU@(``!$'````````2@4```````!A`P````````````#,!0``(`<``','``#.
M`P``E0,``&D$``!!!@```````.<#``";!0```````(L!````````6@(`````
M``!J!@``]P```"T'``"9!0``>@0`````````````'P<``&(#``!K`0``WP(`
M`&<!``"K!```GP4``"<#```@!````````*@%`````````````#D!```W`P``
M1@0``+,#````````20$```````#:!```;@```%\#``!+`P``W`4`````````
M````;@,``",```"9`0```````',!``"R!@``A@8``&`#``"0`@```````&X$
M``#A!0``D@0``%<%``#Y!````````'4"```Z!P````````````#S`P``%@<`
M`(`%``#'!P``(`$``/\$``#D`P``(0<```````"]!P``_`8``(\`````````
M`````!P'``!_!0``S@8``````````````````)\`````````M@0``-P'```)
M!P``"````/D````^!@``IP(```X'``#N````V04``#($```F`0``3`,`````
M``"W!@``2@<```@"``"``P```````,X!```T!P``9@0``*(&````````0@<`
M````````````7P```)`%```#!@``Q@$``&,$``"*!````````/4#````````
MS@````````"4`P``800``,H&``"D`````````,$````.`@``0P$``,H%``"T
M`0```````,0'``!C`@``B08``&D%````````5@0```````#0`P``\P$``.D'
M``#]!@```````)L$``!)`P```````+0%``!)!@``<@8``$`!```%!0``60(`
M`$8!```````````````````R`````````)\&``#Z!0``^0$```````!;!P``
MF`4``,`&``"M`0``V0,``%$!```I!P``$`8``$4$``!/````H`<``'\"``#`
M`0``M0$``$($``"+!@```````/($````````!0```*0$`````````````/0%
M```A`@``?00``*L"``!^````"@$``,(&`````````````'@%````````LP8`
M`$\%```Z!@````````````!8`@``1`````````"7````L`8``(X#````````
M6`8``((!```V`P``%@``````````````N`0```````"6!@``=`<``%H$```!
M!0``:`(``````````````````-L!``"N!@``K`$``!0#```&!0``U@<`````
M``#$!````````-$`````````L@(``-`'``#@````H0(``-@```#=!0``L@4`
M````````````%`8``'\&``"+````40,``,,!```8`@``/@,``&@````1`P``
MO0,``,P"``"B!0``1`(``+(!`````````````%($``#Q`0``J0$``$$#```;
M!@``UP4``"`#```C!0```````((#``!'!```N0<```````"I!```S@0`````
M``#'!```S08```````!"!0``^P,``(8`````````R00``'`"````````$P0`
M``$&````````.0,``"0&``#E`0```````,8```!5!@``````````````````
M'`0``$@```#W!0``)`,`````````````X0,``!@%````````S0<```````#%
M!@``;`$``&`"``"#`P``$@$``*('````````%`$``&P`````````````````
M````````.@$```,$``"_`@``G@```*4#```D!```(@0``.H````3`@``````
M`-D```#X`P``D@,```````!"`0``'@$``/P````=!`````````T!``!,!@``
M\08``!D#````````L`,``'(!``":!0``D00``$@'````````.P8```````#F
M!````````*T```!$!@``)`(``)('``#1!@```````($#``#)`@```````",$
M``!)````%P$``'L&`````````````$8%```Q!```DP<```````#4`P``704`
M`.\$````````*0```!4!``#R````_@$``"T`````````.P,```````#``P``
M"P0``!T#``"6````)@0```````#0!```L`<```<$``!B!@``(P<```L'``"(
M!```3@,``$L``````````````$$!```A`P``\P(```````"F!@``NP(``#(&
M``!B````````````````````P0(``$H!``",!@``K@$````````>`P``T0,`
M`!8!``!C`P``@P4``/P!``"F!```M0(``+<!``#%`````````'H&````````
ML@<``&T&```_!P``6````#\!``!.`0``X@```````````````````+$'````
M``````````````!T!0``/P8``'`#````````H`4``"$&````````P0<``!@#
M``#H````R`0````````8!```8`<``,0#``!F````:P8``*<$````````F0(`
M``H```#7`@``D`$``*0%``"_!P```````(\#``#?!0``````````````````
M`````,P`````````=0```)L#````````$0$``/(#``!Z!0``<P4``.0!``!U
M!@``"P(```````!B!```M0,`````````````````````````````1@(``.`'
M````````]08``,T`````````ZP4``)````"K!@``H`8``"@#````````P`(`
M`&@#````````20(````````M!```-@4``&0&``"5!0``(@(``+<$``#G`0``
MM`8````````"````[04``-T#``"_!@``%@8```````"9`P``/`<``)4'``"5
M`@````````D%````````:`8``(@```!Y!0``LP<``+X#````````?P0`````
M````````V@4``&\#````````M0<``%T&```Z`@``HP8``!4%````````````
M``P`````````8@4```````!F`@````````D````$!@``W@```"@"``#:!P``
M``````````",`0```````/T````^!0``VP0```````">`0``A@4``',$``!6
M`P``[@4````````H!```A@0``/8&````````K`(```````#4`0``?0<``&8!
M``!*!```E@$``/8%````````_00```````!B`0``"P8``%D!````````````
M`/@!````````N@```&4!``#&`P``4`<```$"``"!`0```````/`%``!Y`0``
M@P0``-4$`````````````.H&``#<`P``<0<```````"V!0```````!<#``"G
M`0```````-<$``"1`P``Z@(``+P&````````;0<`````````````S`<`````
M``"Z!0``_P8```````#-`@``ZP```&<``````````````-D$``#O`P``50$`
M`-(&````````_@(``+8```!P````9`4``,($``!8`0``-0$``"P$``!^!0``
MO@4```````!T````+`8````````_`P``V08``%4$``!/!```V`(``,0!``"9
M!```2@(```````#U!0``N`4````````1`@``F@(``+@&````````RP8``$`&
M```-!@``A0$```````#U`0``D04``*T&`````````````(T!``!Q````108`
M`&H"`````````````(`&```>`@```````(@&```[`0````````$$``!N!@``
M`````.`&``"`````X@<````````Q`@``N08````````C`P```````.$```"W
M````@P```%`$````````=@<``,L'``"2!@``/@$``%('``!$!```AP<`````
M````````````````````````\0```)X%``"H`@```````(4&``!2!@``^@$`
M`'$%``"N`P``W`$``"X!``!F!@````````````!?!0```````(@"``";`0``
MG`$``/H#``!&!P``<`$``)$!````````6P```"\```"'!0``B0<```````!6
M!0``?04``%L$`````````````&L'````````G0$``'P'``"1!@``0P(`````
M``#1!```AP,``'$"````````3`4``*$#``!E````+`<```````#3!```(04`
M`"\%``#G!0``)P$``+$$``"R````DP$``/P$``#F`P```````/\%````````
M9P0``)P$```,!P``+P<``'8!````("`M32P@+2UM97-S86=E/4U%4U-!1T4@
M(%5S92!T:&ES(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0@;VYE<RX`("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@
M9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F
M97)E;G0@8G)A;F-H('1O"B`@("`@("`@("`@("`@("`@("`@("`@('1H92!G
M96YE<F%T960@8V]M<&5N9&EU;2X`("`M8BP@+2UB87-E/2]0051(("!&=6QL
M('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U
M;&0@8F4*("`@("`@("`@("`@("`@("`@("!U<V5D+@`@("UC+"`M+6-O;7!E
M;F1I=6T]1DE,12`@365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O
M;7!E;F1I=6T@9FEL90H@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A
M9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE"B`@
M("`@("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E8W1O<GDN`"`@
M+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I
M;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L=`H@("`@("`@("`@("`@("`@("`@
M("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E
M8W1O<GDI+@`@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G
M97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I97,N`"`@+60L("TM9&ER96-T
M;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y
M+@`@("UH+"`M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N
M`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L
M92X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92X`
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+@`@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO
M;G,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U
M;&4]34]$54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E
M(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM
M;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N
M)W0@;65R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2X`
M("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I
M=6TN`"`@+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N
M('-T871I<W1I8W,@:6X@82!L;V-A;"!F:6QE+@`@("UT+"`M+71E<W0@("`@
M("`@(%-H;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@
M86YY=&AI;F<N`"`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U
M<"!F<F]M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RX`("!C
M;VUM:70@("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R
M=F5R+@`@(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#
M5E,@<V5R=F5R+@`@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I
M=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H90H@("`@("`@
M("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2X`("!E>'1R86-T("`@("!'96YE
M<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N`"`@:&5L<"`@("`@("`@
M4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`("!I;FET("`@("`@("!#<F5A=&4@
M;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN
M9SH@5&AI<PH@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG
M(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+@`@(&UA:V4@("`@("`@($)U:6QD
M(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N
M`"`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE
M;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9`H@("`@("`@("`@("`@('!R
M97!A<F4@=&AE(&9I;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A
M=&4M:&5L<"X@66]U"B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA
M:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE"B`@
M("`@("`@("`@("`@:&5L<"!F:6QE+@`@(&UE<F=E("`@("`@($UE<F=E('1H
M92!C=7)R96YT(%!/(&9I;&4@=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T
M92!F:6QE+@`@('5P9&%T92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S
M97%U96YT+@`@('5P9&%T92UH96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA
M;F=E9"!E;G1R:65S(&9R;VT@=&AE($5N9VQI<V@@6$U,(&AE;'`*("`@("`@
M("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG
M(&]N97,N`"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@
M*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A('9A
M;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@
M8W)E871E9#H@)7,N`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E
M9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F
M;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!D;V5S
M(&YO="!E>&ES="!O<B!I<R!N;W0@97AE8W5T86)L92X`)7,@:&%S(&-A;F-E
M;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S
M="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N`"5S
M(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(&ES(&YO
M="!W<FET86)L92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@
M9F]U;F0N`"5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T
M)R!F:7)S="X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('1O("5S
M(&]F("5S`"5S('=I<VAE<R!T;R!A9&0@=&\@)7,N`"5S('=I<VAE<R!T;R!M
M86ME('EO=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE
M(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S($)O
M;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E
M<SH@)7,`)7,Z('5N86)L92!T;R!L;V%D(&1R:79E<CH@)7,`+"!G=7-T:6YG
M("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`#$R($AO=7(@1F]R;6%T`#(T
M($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P`\9V5T=&5X=#X@=&%G
M(&YO="!C;&]S960@:6X@9FEL92`E<RX*3W!E;FEN9R!T86<@9F]U;F0@:6X@
M;&EN92`E9"X`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T
M:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+@!!1%-)(&5R<F]R("5S+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!
M32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)
M1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED
M9&QE`$%C8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5S<R!$96YI960N`$%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O
M=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@0VAI;&0@
M1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@
M1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O
M("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1H:7,@
M=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY
M(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N`$%D9&EN9R!N97<@9FEL97,@=&\@<F5P;W-I=&]R>3H`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E
M<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A
M=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R
M('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA
M=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA
M=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E
M<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO
M80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@
M97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N
M;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"
M87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I
M;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P
M<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R
M8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S
M=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)
M22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I
M82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@
M9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU
M;6YS`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY('1O(&$@
M<F5Q=65S="!Y;W4@<V5N=`!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92X`071T96YD965S`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T
M<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F
M86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07=A:71I
M;F<@4F5S<&]N<V4`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V5N9"!N
M;W0@8V]R<F5C=&QY(&EM<&QE;65N=&5D+@!"86-K9W)O=6YD`$)A8VMG<F]U
M;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@
M=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S
M*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y
M("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L
M:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@
M;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S
M`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R
M9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA
M`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA
M;0!"=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN`$)U:6QD:6YG
M(&QO8V%L92`E<RXN+B``0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA
M($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L
M971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@
M9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A=&5G
M;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E
M;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#
M96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#
M96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A
M=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%I<B!097)S
M;VX`0VAA;F=E`$-H86YG92!087-S=V]R9`!#:&%N9V4@<&%S<W=O<F0@;VXZ
M`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N
M9V4@>6]U<B!P87-S=V]R9`!#:&%N9VEN9R!P87-S=V]R9"!O;B`E<P!#:&%R
M`$-H96-?:R!,:6YK+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE
M`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U
M<V5R;F%M90!#:&]O<V4@86X@86-T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D
M(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+@!#;&5A;FEN9R!U<"!03R!F:6QE<R!F;W(@;6]D=6QE
M("5S+BXN`$-L96%N:6YG('5P(&QO8V%L92`E<RXN+B``0VQE87(`0VQE87(@
M35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#
M;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU
M90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO
M=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL
M87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R
M`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T
M:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM86YD(&]P
M=&EO;G,Z`$-O;6UA;F1S.@!#;VUM96YT`$-O;6UI='1I;F<Z`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!-97-S86=E
M("@E<RD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U
M<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&YE=R!P87-S=V]R9#H`
M0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#
M;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+@!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#
M;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W!Y:6YG("5S('1O("5S`$-O
M<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&)I;F0@=&\@;&1A
M<"!S97)V97(`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO
M="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C;VYN96-T('1O
M('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-O<'D@)7,@
M=&\@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER96-T;W)Y(&9O<B!L;V-A;&4@
M)7,Z`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD
M(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@
M;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO
M="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET
M:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M("(E<R(N`$-O=6QD(&YO="!O<&5N('!I<&4@=&\@<VUB<&%S<W=D+@!#;W5L
M9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O
M=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S
M`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M
M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@
M=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E
M871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M
M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E
M;G0@-"!0:&%S97,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E
M;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`
M0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T
M90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O
M;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A
M<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT
M:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M:7-S:6]N<P!$
M969I;FET:6]N<P!$96QE9V%T92!P;W-I=&EO;@!$96QE9V%T960`1&5L971E
M`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T
M:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5N>2!R97%U97-T`$1E
M;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y
M`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@
M<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H
M:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`
M1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$52
M4@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R
M;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E
M<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L
M(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M
M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`
M16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N9`!%;F0@>65A<@!%;FQA<F=E($5D:71O
M<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E
M(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE
M(&EM86=E(%523"!H97)E`$5N=')I97,Z("5D('1O=&%L+"`E9"!U<"UT;RUD
M871E+"`E9"!N97<L("5D(&-H86YG960L("5D('5N:VYO=VX`17%U871O<FEA
M;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!S96YD:6YG(&1A=&$@=&\@
M<VUB<&%S<W=D+@!%<G)O<B!S96YD:6YG(')E<&QY.B`E<RX`17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5R<F]R.B``
M17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M
M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU
M=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AE8W5T:6YG.@!%>'!A;F0`
M17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R
M9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N
M96YT`$5X=')A8W1I;F<@9G)O;2`E<RXN+B``1D<@0V]L;W(`1E10('5P;&]A
M9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`
M1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL
M960@=&\@=F5R:69Y(&]L9"!P87-S=V]R9"X`1F%I;'5R92!I;B!C:&%N9VEN
M9R!P87-S=V]R9"!O;B`E<SH@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-
M86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9E8G)U
M87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3
M;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL92!#;W5N=#H@)7,@
M9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.
M86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S
M="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O
M<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9O=6YD(&%P<&QI8V%T:6]N<SH@
M)7,`1F]U;F0@9&ER96-T;W)I97,Z`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E
M+"!-971R;W!O;&ET86X`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O0G5S
M>2!297!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S="!2
M97-P;VYS90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S
M8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=7IZ>0!'86)O;@!'86QL
M97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A
M=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96YE<F%T:6YG
M('-T871U<R!F;W(@;6]D=6QE("5S+BXN`$=E;W)G:6$`1V5R;6%N>0!'971O
M<'0@17)R;W(Z(`!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D
M96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M
M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO
M;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<"!P97)M:7-S
M:6]N<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!'=65S="!097)M:7-S:6]N<P!'=65S="!P97)M:7-S:6]N<P!'=65S=&)O
M;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R
M;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z
M90!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE
M879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP
M`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96QP97(@87!P;&EC871I;VX@
M=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(
M;W)D90IF<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N"D9O<B!A;B!I
M;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI<R!D:7)E
M8W1O<GDN`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.@!(:6=H`$AI<W1O<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM
M96UP='D`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4@=')A;G-L871I;VX@9V5N97)A=&]R`$AO<F1E+TMO;&%B
M.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M
M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR
M;VYI<V5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E
M;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$
M(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN
M;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D
M9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I
M='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N
M<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG
M<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@
M86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE
M960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!)
M;6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE
M<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R
M=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?
M<V5R="!2;W<@069T97(`26YC;W)R96-T(%!A<W-W;W)D`$EN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD
M:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO
M;@!);FET:6%L:7II;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O
M;7!O;F5N="X`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D
M871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!)
M;G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L
M:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A
M<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B
M:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@
M9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A
M<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E
M;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*
M87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE
M`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@
M3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`
M2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT
M`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+
M;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@
M4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N
M`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA
M<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I
M;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`
M3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT
M96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%
M87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E
M<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F
M;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A
M8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE
M<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI
M80!,;V%D:6YG(&QI8G)A<FEE<RXN+@!,;V%D:6YG+BXN`$QO8V%L('1I;64Z
M(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G
M:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I
M;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,
M;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB
M;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@
M9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI
M;@!-86ME(&QI;E]K+BXN`$UA:V4@<W5R92!T:&%T('EO=2!H879E(%!%05(@
M:6YS=&%L;&5D(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"X`36%K:6YG(&1I
M<F5C=&]R>2`E<P!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT
M80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<F-H
M`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA
M;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A
M;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E
M('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X
M('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T
M=&4`365D:6-I;F4`365E=&EN9R!#86YC96QL871I;VX`365E=&EN9R!);F9O
M<FUA=&EO;@!-965T:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P;'D`365E=&EN
M9R!5<&1A=&4`365E=&EN9R!5<&1A=&4@4F5Q=65S=`!-96UB97)S`$UE;G4@
M;6]D93H`365R9V4@8V5L;',`365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@
M=&AE(&-O;7!E;F1I=6TN+BX@`$UE<F=I;F<@;&]C86QE("5S+BXN(`!-97)G
M:6YG('1H92!03R!F:6QE(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``
M365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`
M365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G
M<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@
M97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E
M<R(@:7,@;F]T(&1E9FEN960`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&
M961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM
M=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI
M<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`
M36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C
M:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL
M`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;&4`36]D
M=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N
M=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO
M<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@
M9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N
M(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A
M;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E
M`$YA;64`3F%M:6)I80!.875R=0!.965D<R!!8W1I;VX`3F5P86P`3F5T:&5R
M;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`
M3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N
M(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O
M<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`
M3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W
M;W)D.@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT
M`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.
M:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I
M9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T
M8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D
M('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&0@<&5R;6ES<VEO
M;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN`$YO(&-H:6QD
M<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;6UA
M;F0@<W!E8VEF:65D+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@
M8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!E;G1R
M>2!W:71H('1H92!I9"`B)7,B(&5X:7-T<R!I;B!T:&4@;W)I9VEN86P@:&5L
M<"!F:6QE+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L
M;V-A;&4@<W!E8VEF:65D+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T
M:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P
M96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O
M<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3$1!4"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO(')U;&5S`$YO('-I9&5S`$YO('-U8V@@8F%C:V5N9"`B)7,B(&9O
M=6YD+@!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!087)T:6-I<&%N
M=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R
M;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E
M`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T
M('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M`$YO=&EC90!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`
M3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`
M3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]B:F5C="!C<F5A=&]R('!E<FUI
M<W-I;VYS`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L
M9"!P87-S=V]R9#H`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H
M87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN
M9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA;"!087)T:6-I<&%N
M=`!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]P=&EO;G,Z`$]R9&5R960@3&ES
M=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG
M`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R
M;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0
M(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D
M90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`
M4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!07TA0(%-H96QL
M`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y
M+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!0
M87)T;'D@0VQO=61Y`%!A<W-W9"!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E
M9"X`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!O;B`E<RX`4&%S<W=O<F0@
M:6YC;W)R96-T`%!A<W-W;W)D(&UO9'5L92!C86XG="!F:6YD('1H92!S=7!P
M;&EE9"!B:6XN`%!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG(')E<75I<F5D
M('!A<F%M971E<G,N`%!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG('1A<F=E
M="!P87)A;65T97(N`%!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@
M8V]N9FEG=7)E9`!087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O
M;F9I9W5R960N`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N
M=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D
M.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T
M92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE
M`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO
M;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS($%D
M;6EN:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A
M:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE
M87-E('!R;W9I9&4@82!N97<@<&%S<W=O<F0`4&QE87-E('!R;W9I9&4@82!S
M=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R(&-U
M<G)E;G0@<&%S<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T
M96TN`%!L96%S92!R97!O<G0@86YY(&)U9W,@=&\@:3$X;D!L:7-T<RYH;W)D
M92YO<F<N`%!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO
M;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E
M;&]W+@!0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E
M;&]W+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!L96%S
M92!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0`4&]L86YD`%!O;&ET:6-S`%!O
M;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H
M;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L
M979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I
M;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N
M=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O
M:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R
M:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`
M475E<GD`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N
M`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A
M;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A
M9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A
M(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I
M;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UE;6)E<B!T:&4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C
M:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M
M(&UY(&-A;&5N9&%R`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE
M`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S
M97(`4F5M;W9E('5S97(Z("5S`%)E<&QY(%-E;G0N`%)E<&QY('=I=&@@3F]T
M(%-U<'!O<G1E9"!-97-S86=E`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N
M97AT(#(@;6]N=&AS+@!297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN`%)E<&QY.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC
M92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I
M9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S
M<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G9')I
M=F5R<R<@:7,@;6ES8V]N9FEG=7)E9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@4&%S
M<W=D(%-13"!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T
M('-P96-I9FEE9"!I;B!344P@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE
M;&0`4F5Q=6ER960@4&%R=&EC:7!A;G0`4F5S970`4F5S970@4&%S<W=O<F0`
M4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E<W5L=',@*&EN8VQU9&EN
M9R!(;W)D92DZ`%)E<W5L=',Z`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`
M4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W
M(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E
M($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T
M:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S
M86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/<'1I
M;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C
M:`!396%R8V@@16YG:6YE<P!396%R8VAI;F<@2&]R9&4@87!P;&EC871I;VYS
M(&EN("5S`%-E87)C:&EN9R!G971T97AT(&)I;F%R:65S+BXN`%-E;&5C="!&
M:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE
M8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@
M=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@
M;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H
M92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD($QA=&5S="!);F9O<FUA
M=&EO;@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N
M<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@
M3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E
M<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO
M=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I
M="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P
M9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S
M<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN
M9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D
M(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E
M;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG
M(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R
M`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3
M:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I
M;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P
M`%-I9VX@=7`@:68@;F]T(')E9VES=&5R960`4VEG;F%T=7)E`%-I9VYA='5R
M92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3
M:VEP<&5D+BXN`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`
M4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@
M3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``
M4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R
M9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I
M;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S
M`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0`4W1A<G0@>65A
M<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1A='5S(&9O<B!L;V-A;&4@
M)7,N+BX@`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H
M<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E
M<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD
M+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U
M<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S
M<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E
M<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY
M('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN
M>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N
M<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V
M86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R
M;&%N9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B
M(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`
M5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE
M<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S
M="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92`B
M)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5N=&%T
M:79E;'D@06-C97!T(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5X
M=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV
M,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`
M5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VXG="!Y970@97AI<W0N($-R
M96%T:6YG(&$@;F5W(&]N92X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@
M:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I
M9&4@;VYL>0!4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED`%1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E
M=F5N="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A
M;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N
M(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE
M="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD
M+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I
M<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T
M(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/
M2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D
M:71O<BX`5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\/WAM
M;`!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F
M="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S
M(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H
M870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4
M:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A
M9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O
M('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R
M:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S
M<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&%S:R!H87,@8F5E
M;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@
M(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S
M(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('5S97(G<R!F<F5E+V)U<WD@
M:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE('=E871H
M97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O
M<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL
M86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!D;V5S;B=T('EE="!E
M>&ES="!A(&AE;'`@9FEL92!F;W(@)7,N`%1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES
M=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S
M(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+@!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S
M+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN
M:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H92!F;&%G("UD('1O('-E92!A
M;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4
M:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D
M869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W
M:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N
M=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I
M;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4
M:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S8W)I<'0@
M;75S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE+@!4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R
M;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM
M92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,
M97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(
M5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O
M<"!F<F%M92`H7W1O<"D`5')A;G-L871E9`!4<F%N<VQA=&EO;G,`5')I;FED
M860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y
M`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N
M(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E
M<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN
M9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA
M;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5
M;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93
M(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A
M=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@
M(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D
M96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E
M<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@
M;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5
M;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T
M:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N
M9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL
M960`56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<P!5;FEC;V1E("A5
M5$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI
M=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`
M56YK;F]W;B!C;VUM86YD.B`E<P!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D
M+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A
M;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O
M<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI
M8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T
M;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS
M970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5N=')A;G-L871E9`!5
M<&1A=&4`57!D871E("5S`%5P9&%T92!R97-P;VYD96YT('-T871U<P!5<&1A
M=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9&%T:6YG("5S(&AE;'`@9FEL92!F
M;W(@)7,N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`
M57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U
M87D`57-A9V4Z`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE
M+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T
M:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R
M(&YO="!F;W5N9`!5<V5R(&YO="!F;W5N9"X`57-E<B!P97)M:7-S:6]N<P!5
M<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M
M93H`57-E<FYA;64Z(`!5<V5R<P!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E
M:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N
M`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L
M=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X
M:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R
M;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E
M<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6
M:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G90!6:65W(&%S("5S`%9I97<@979E;G0`5FEE=R!T87-K`%9I<F=I
M;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB
M:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!
M4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N
M`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V%R;FEN9SH@`%=E`%=E871H
M97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N
M8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S
M`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N
M:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@
M:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K
M($%D9')E<W,`5V]R:R!0:&]N90!7<FET:6YG('5P9&%T960@:&5L<"!F:6QE
M('1O("5S+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E
M>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S
M`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R
M92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG
M(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A;B=T(&-H86YG
M92!P87-S=V]R9"!F;W(@=7-E<B`E<P!9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T(&=I
M=F4@>6]U<B!C=7)R96YT('!A<W-W;W)D`%EO=2!M=7-T(&=I=F4@>6]U<B!N
M97<@<&%S<W=O<F0`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@
M;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P
M87-S=V]R9`!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R
M97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T
M;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT
M(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!G971T97AT('9E<G-I
M;VX@:7,@=&]O(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T:79E
M;'DN"DYO="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A8W1E9"X`66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&YE=R!P87-S=V]R9"!I
M<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@8F4@;6]R92!T:&%N("5D
M(&-H87)A8W1E<G,@;&]N9R$`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I
M;7!L92!T;R!G=65S<R$@($YO="!C:&%N9V5D(0!9;W5R(&YE=R!P87-S=V]R
M9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S+B!.;W0@8VAA;F=E9"$`66]U<B!N
M97<@<&%S<W=O<F0@;75S="!B92!A="!L96%S="`E9"!C:&%R86-T97)S(&QO
M;F<A`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@9&EF9F5R96YT(&9R;VT@
M>6]U<B!C=7)R96YT('!A<W-W;W)D`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@
M8V]N=&%I;B!A="!L96%S="`E9"!A;'!H86)E=&EC(&-H87)A8W1E<G,N`%EO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!A;'!H
M86YU;65R:6,@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C
M;VYT86EN(&%T(&QE87-T("5D(&1I9F9E<F5N="!T>7!E<R!O9B!C:&%R86-T
M97)S+B!4:&4@='EP97,@87)E.B!L;W=E<BP@=7!P97(L(&YU;65R:6,L(&%N
M9"!S>6UB;VQS+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@
M;&5A<W0@)60@;&]W97)C87-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W
M;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!N=6UE<FEC(&-H87)A8W1E
M<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E
M9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S
M="!C;VYT86EN(&QE<W,@=&AA;B`E9"!W:&ET97-P86-E(&-H87)A8W1E<G,N
M`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C
M92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9',@9&ED;B=T(&UA=&-H
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T
M:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO
M9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D<R!D
M;R!N;W0@;6%T8V@`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:
M86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=
M`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN
M:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`
M7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?
M36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@
M3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D
M9')E<W,@8F]O:P!A;B!E<G)O<B!H87,@;V-C=7)E9#H`8V%L96YD87(`8V%L
M;0!C;&EC:R!H97)E`&1O;F4`9F%I;&5D`&9A;&QI;F<`9FEL90!F;W5N9#H@
M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`:&@`:6UM961I871E`&EN
M;&EN90!L9&%P7W-T87)T7W1L<R!F86EL960`;&EN97-=`&UK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!C:&%N
M9V5D`&YO="!F;W5N9`!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE
M;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E
M<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`=&%S:R!L:7-T
M`'1H92!(;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T
M(&5X:7-T.@!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N
M:69I960`=6YN86UE9`!U<&1A=&5D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E
M871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@<&%S<W=D"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3`Y(#$V.C4Q*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-2TQ,"TP.2`Q-SHP-RLP,C`P"DQA<W0M5')A;G-L871O<CH@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*3&%N9W5A9V4M5&5A;3H@1V5R
M;6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"`@+4TL("TM;65S
M<V%G93U-15-304=%("!$:65S92!.86-H<FEC:'0@86YS=&5L;&4@9&5R(%-T
M86YD87)D;F%C:')I8VAT"B`@("`@("`@("`@("`@("`@("`@("`@("!V97)W
M96YD96XN`"`@+6$L("TM861D/49)3$4@("`@("`@($1I97-E(%!/+41A=&5I
M('IU;2!+;VUP96YD:75M(&AI;GIU9OQG96XN($[\='IL:6-H+`H@("`@("`@
M("`@("`@("`@("`@("`@("!U;2!E:6X@2V]M<&5N9&EU;2!A=7,@96EN96T@
M86YD97)E;B!"<F%N8V@@:6X@9&%S"B`@("`@("`@("`@("`@("`@("`@("`@
M(&=E;F5R:65R=&4@2V]M<&5N9&EU;2!E:6YZ=6;\9V5N+@`@("UB+"`M+6)A
M<V4]+U!!5$@@(%9O;&QS=.1N9&EG97(@4&9A9"!Z=2!D96T@*$AO<F1E+2D@
M5F5R>F5I8VAN:7,L(&1A<PH@("`@("`@("`@("`@("`@("`@(&)E;G5T>G0@
M=V5R9&5N('-O;&PN`"`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!.975E(-QB
M97)S971Z=6YG96X@:6X@9&EE<V5S($MO;7!E;F1I=6T@96EN9OQG96X*("`@
M("`@("`@("`@("`@("`@("`@("`@(&%N<W1A='0@:6X@9&%S(%-T86YD87)D
M+4MO;7!E;F1I=6T@*&-O;7!E;F1I=6TN<&\*("`@("`@("`@("`@("`@("`@
M("`@("`@(&EM(&AO<F1E+W!O(%9E<GIE:6-H;FES+@`@("UC+"`M+6-O;7!E
M;F1I=6T]1DE,12`@1&EE<V5S(&%N(%-T96QL92!D97,@4W1A;F1A<F0M2V]M
M<&5N9&EU;7,*("`@("`@("`@("`@("`@("`@("`@("`@("AC;VUP96YD:75M
M+G!O(&EM(&AO<F1E+W!O(%9E<GIE:6-H;FES*2!V97)W96YD96XN`"`@+60L
M("TM9&5B=6<@("`@("`@1F5H;&5R;65L9'5N9V5N(&1E<B!A=7-G96;\:')T
M96X@4')O9W)A;6UE(&%N>F5I9V5N+@`@("UD+"`M+61I<F5C=&]R>3U$25(@
M("!+;VUP96YD:75M(&EN(&1I97-E;2!697)Z96EC:&YI<R!E<GIE=6=E;BX`
M("`M:"P@+2UH96QP("`@("`@("!$:65S92!(:6QF92!A;GIE:6=E;BX`("`M
M;"P@+2UL;V-A;&4];&Q?0T,@("`@($YU<B!D:65S97,@3&]C86QE('9E<G=E
M;F1E;BX`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@($1I97-E<R!,;V-A;&4@
M=F5R=V5N9&5N+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!$:65S97,@3&]C
M86QE('9E<G=E;F1E;BX`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($YU<B!-
M3RU$871E:65N(&;\<B!D:65S97,@*$AO<F1E+2D@36]D=6P@97)Z975G96XN
M`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!03RU$871E:65N(&YU<B!F_'(@
M9&EE<V5S("A(;W)D92TI($UO9'5L"B`@("`@("`@("`@("`@("`@("`@("`@
M("!A=69RY'5M96XN`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!.=7(@W&)E
M<G-E='IU;F=E;B!F_'(@9&EE<V5S("A(;W)D92TI($UO9'5L"B`@("`@("`@
M("`@("`@("`@("`@("`@("!E:6YC:&5C:V5N+@`@("UM+"`M+6UO9'5L93U-
M3T153$4@("`@3G5R(%!/+41A=&5I96X@9OQR(&1I97-E<R`H2&]R9&4M*2!-
M;V1U;"!E<GIE=6=E;BX`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%!/+41A
M=&5I96X@;G5R(&;\<B!D:65S97,@*$AO<F1E+2D@36]D=6P*("`@("`@("`@
M("`@("`@("`@("`@("`@('IU<V%M;65N9OQH<F5N+@`@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@3G5R($AI;&9E+41A=&5I96X@9OQR(&1I97-E<R`H2&]R
M9&4M*2!-;V1U;"!A:W1U86QI<VEE<F5N+@`@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@3G5R(&1I97-E<R`H2&]R9&4M*2!-;V1U;"!A:W1U86QI<VEE<F5N
M+@`@("UM+"`M+6UO9'5L93U-3T153$4@($YU<B!E:6YE(%!/5"U$871E:2!F
M_'(@9&EE<V5S("A(;W)D92TI($UO9'5L(&5R>F5U9V5N+@`@("UN+"`M+6YO
M+6-O;7!E;F1I=6T@("`@2V5I;F4@;F5U96X@W&)E<G-E='IU;F=E;B!I;B!D
M87,@2V]M<&5N9&EU;2!E:6YF_&=E;BX`("`M;BP@+2UN;RUC;VUP96YD:75M
M("`@($ME:6X@2V]M<&5N9&EU;2!V97)W96YD96XN`"`@+7,L("TM<W1A=&ES
M=&EC<R`@("`@("#<8F5R<V5T>G5N9W-S=&%T:7-T:6ME;B!I;B!L;VMA;&5R
M($1A=&5I('-P96EC:&5R;BX`("`M="P@+2UT97-T("`@("`@("!$:64@875S
M>G5F_&AR96YD96X@0F5F96AL92!A;GIE:6=E;B!A8F5R(&YI8VAT(&%U<V;\
M:')E;BX`("!C;&5A;G5P("`@("!3Y'5B97)T(&1I92!03RU$871E:65N('9O
M;B!U;OQB97)S971Z=&5N('5N9"!N:6-H="!M96AR"B`@("`@("`@("`@("`@
M8F5N]G1I9W1E;B!%:6YT<N1G96XN`"`@8V]M;6ET("`@("`@W&)E<G-E='IU
M;F=E;B!A=68@9&5M($-64RU397)V97(@96EN8VAE8VME;BX`("!C;VUM:70M
M:&5L<"!(:6QF961A=&5I96X@875F(&1E;2!#5E,M4V5R=F5R(&5I;F-H96-K
M96XN`"`@8V]M<&5N9&EU;2`@2V]M<&5N9&EU;2!N974@97)S=&5L;&5N+B!7
M87)N=6YG.B!$86UI="!W:7)D(&1A<R!A:W1U96QL90H@("`@("`@("`@("`@
M($MO;7!E;F1I=6T@_&)E<G-C:')I96)E;BX`("!E>'1R86-T("`@("!03R!6
M;W)L86=E;B`H+G!O="!$871E:65N*2!E<GIE=6=E;BX`("!H96QP("`@("`@
M("!$:65S92!(:6QF92!A;GIE:6=E;BX`("!I;FET("`@("`@("!%:6X@;V1E
M<B!M96AR97)E(%!/+41A=&5I96X@9OQR(&5I;B!N975E<R!,;V-A;&4@97)Z
M975G96XN"B`@("`@("`@("`@("`@5V%R;G5N9SH@1&%M:70@=V5R9&5N(&)E
M<W1E:&5N9&4@4$\M1&%T96EE;B!F_'(@9&EE<V5S($QO8V%L90H@("`@("`@
M("`@("`@(/QB97)S8VAR:65B96XN`"`@;6%K92`@("`@("`@2V]M<&EL:65R
M=&4@34\M1&%T96EE;B!A=7,@9&5N(&%N9V5G96)E;F5N(%!/+41A=&5I96X@
M97)Z975G96XN`"`@;6%K92UH96QP("`@06QL92!%:6YT<N1G92!I;B!D97(@
M6$U,+4AI;&9E9&%T96D@86QS(&%K='5E;&P@;6%R:VEE<F5N('5N9`H@("`@
M("`@("`@("`@(&1I92!$871E:2!F_'(@9&EE(&[D8VAS=&4@075S9OQH<G5N
M9R!V;VX@=7!D871E+6AE;'`*("`@("`@("`@("`@("!V;W)B97)E:71E;BX@
M4VEE('-O;&QT96X@;6%K92UH96QP(&YU<B!.04-(('5P9&%T92UH96QP('5N
M9"!D97(*("`@("`@("`@("`@("#<8F5R87)B96ET=6YG(&1E<B!(:6QF961A
M=&5I(&%U<V;\:')E;BX`("!M97)G92`@("`@("!!:W1U96QL92!03RU$871E
M:2!M:70@9&5R(&%K='5E;&QE;B!03RU6;W)L86=E('IU<V%M;65N9OQH<F5N
M+@`@('5P9&%T92`@("`@(&5X=')A8W0@=6YD(&UE<F=E(&YA8VAE:6YA;F1E
M<B!A=7-F_&AR96XN`"`@=7!D871E+6AE;'`@06QL92!N975E;B!U;F0@9V7D
M;F1E<G1E;B!%:6YT<N1G92!A=7,@9&5R(&5N9VQI<V-H96X@6$U,+0H@("`@
M("`@("`@("`@($AI;&9E9&%T96D@97AT<F%H:65R96X@=6YD(&UI="!D97(@
M8F5S=&5H96YD96X@1&%T96D*("`@("`@("`@("`@("!Z=7-A;6UE;F;\:')E
M;BX`("8C,34Q.R`E<R!W:7)D(&1I92!787)T=6YG<V%R8F5I=&5N(&1U<F-H
M9OQH<F5N+"!D:64@=6YT96X@;6%R:VEE<G0@<VEN9"X`("AV;W(@)7,@5&%G
M96XI`"`H6G5G<FEF9G-T87-T92`E<RD`("AI;B`E<R!486=E;BD`("AH975T
M92D`("AM;W)G96XI`"`H9V5S=&5R;BD`(&UI="``(B5S(B!I<W0@:V5I;F4@
M9_QL=&EG92!!=7-W86AL+@`B)7,B(&ES="!I;B!D97(@2&]R9&4@4F5G:7-T
M<GD@;FEC:'0@:V]N9FEG=7)I97)T+@!$97(@0F%U;2U296YD97)E<B!F_'(@
M(B5S(B!W=7)D92!N:6-H="!G969U;F1E;BX`(B5S(B!W=7)D92!Z=6T@1W)U
M<'!E;G-Y<W1E;2!H:6YZ=6=E9OQG="X`(B5S(B!W=7)D92!Z=6T@4F5C:'1E
M<WES=&5M(&AI;GIU9V5F_&=T+@`B)7,B('=U<F1E(&YI8VAT(&5R<W1E;&QT
M.B`E<RX`)60@)7,@=6YD("5S`"5D($)Y=&5S(&=E<V-H<FEE8F5N+@`E9"!V
M;VX@)60@16EN='+D9V5N(&%L<R!A:W1U96QL(&UA<FMI97)T`"5D+51A9V4M
M5F]R:&5R<V%G90`E<R`M($AI;G=E:7,`)7,M061M:6YI<W1R871I;VX`)7,@
M1FEN9V5R86)D<G5C:P`E<R!+0@`E<R!787)T=6YG<V%R8F5I=&5N("T@0F5S
M=.1T:6=U;F<`)7,M2V]N9FEG=7)A=&EO;@`E<R!296=I<W1R:65R=6YG`"5S
M($YU='IU;F=S8F5D:6YG=6YG96X`)7,@97AI<W1I97)T(&)E<F5I=',N`"5S
M(&UI="`E<R`E<P`E<R!E>&ES=&EE<G0@;FEC:'0@;V1E<B!I<W0@;FEC:'0@
M875S9OQH<F)A<BX`)7,@:&%T("5S(&%B9V5S86=T+@`E<R!H870@875F(&5I
M;F4@1G)E:2]'96)U8VAT+4%N9G)A9V4@9V5A;G1W;W)T970N`"5S(&AA="!A
M=68@9&EE($5I;FQA9'5N9R!Z=2`E<R!G96%N='=O<G1E="X`)7,@:&%T($EH
M;F5N($9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N(&=E<V-H:6-K="X`)7,@
M:7-T(&YI8VAT(&)E<V-H<F5I8F%R+@`E<R!I<W0@;F]T=V5N9&EG`"5S($UI
M;G5T96X`)7,@;FEC:'0@9V5F=6YD96XN`"5S(&YI8VAT(&=E9G5N9&5N+B!&
M_&AR96X@4VEE(&5R<W0@)W1R86YS;&%T:6]N(&5X=')A8W0G(&%U<RX`)7,@
M8FET=&5T('5M($EH<F4@1G)E:2]'96)U8VAT+4EN9F]R;6%T:6]N96XN`"5S
M(&)I='1E="!U;2!):')E($%N=V5S96YH96ET(&)E:2`E<RX`)7,@8FES("5S
M('9O;B`E<P`E<R!M]F-H=&4@>G4@)7,@:&EN>G5F_&=E;BX`)7,@;?9C:'1E
M(%-I92!A=68@)7,@875F;65R:W-A;2!M86-H96XN`"5S(&WV8VAT92!D:64@
M;F5U97-T96X@26YF;W)M871I;VYE;B#\8F5R("5S(&5R:&%L=&5N+@`E<W,@
M061R97-S8G5C:``E<W,@2V%L96YD97(`)7-S($YO=&EZ8FQO8VL`)7-S($%U
M9F=A8F5N;&ES=&4`)7,Z("5S`"5S.B!4<F5I8F5R(&MO;FYT92!N:6-H="!G
M96QA9&5N('=E<F1E;CH@)7,`+"!B:6<@)7,@)7,`+"!S8VAW86YK96YD('9O
M;B`E<R!B:7,@)7,`+2T@075S=^1H;&5N("TM`"TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0`Q,BU3='5N9&5N+49O<FUA=``R-"U3='5N9&5N+49O<FUA
M=``R-"!3='5N9&5N`#Q:=7+\8VL`/&=E='1E>'0^(%1A9R!I;B!$871E:2`E
M<R!W=7)D92!N:6-H="!G97-C:&QO<W-E;BX*UF9F;F5N9&5R(%1A9R!I;B!:
M96EL92`E9"!G969U;F1E;BX`1G(@9&EE<V5N($)L;V-K('=I<F0@96EN92!$
M871E;F)A;FL@8F5N=&EG="X`16EN('-C:'=E<F5R($9E:&QE<B!I<W0@875F
M9V5T<F5T96XZ`$5I;B#V9F9E;G1L:6-H97(@4$=0+5-C:&S\<W-E;"!W:7)D
M(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B96[V
M=&EG="X`16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L('=I<F0@9OQR
M(&1I92#<8F5R<'+\9G5N9R!E:6YE<B!U;G1E<GIE:6-H;F5T96X@3F%C:')I
M8VAT(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R('5N9"!E:6X@<')I=F%T
M97(@4$=0+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O<G0@=VER9"!F_'(@
M9&EE($5N='-C:&S\<W-E;'5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N
M`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!01U`M4V-H;/QS
M<V5L('-O=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D:64@56YT97)Z96EC
M:&YU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC
M:&5R('5N9"!E:6X@<')I=F%T97(@4R]-24U%+5-C:&S\<W-E;"!S;W=I92!E
M:6X@4&%S<W=O<G0@=VER9"!F_'(@9&EE($5N='-C:&S\<W-E;'5N9R!E:6YE
M<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I
M;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R
M="!W:7)D(&;\<B!D:64@56YT97)Z96EC:&YU;F<@96EN97(@3F%C:')I8VAT
M(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R(%,O34E-12U38VAL_'-S96P@
M=VER9"!F_'(@9&EE(%9E<G-C:&S\<W-E;'5N9R!E:6YE<B!.86-H<FEC:'0@
M8F5N]G1I9W0N`$%$4TD@1F5H;&5R("5S+@!6;W)M:71T86=S(%=O;&ME;@!6
M;W)M:71T86=S(&QE:6-H=&5R(%)E9V5N`%9O<FUI='1A9W,@4F5G96X`5F]R
M;6ET=&%G<R!38VAA=65R`%9O<FUI='1A9W,@4V-H;F5E<V-H875E<@!!32]0
M30!!4$D@240`W&)E<B!D:65S96X@161I=&]R`$EN9F\N+BX`06)S;VQU="!5
M;G1E;@!!8G-O;'5T($UI='1E`$%N9G)A9V4@86MZ97!T:65R96X`06YG96YO
M;6UE;@!:=6=R:69F('9E<G=E:6=E<G0N`%IU9W)I9F8@=F5R=V5I9V5R="!B
M96EM($%N;&5G96X@9&5S(%9&4RU697)Z96EC:&YI<W-E<RX`6G5G<FEF9B!V
M97)W96EG97)T(&)E:6T@06YL96=E;B!D97(@5D93+41A=&5I+@!+;VYT;W!A
M<W-W;W)T`$MO;G1O(&5I;F=E9G)O<F5N+@!"=6-H:&%L='5N9P!!:W1I;VYE
M;@!(:6YZ=6;\9V5N`$YE=64@56YT97)G<G5P<&4@:&EN>G5F_&=E;@!.975E
M(%5N=&5R<F5C:'1E(&AI;GIU9OQG96X`2&EE<B!H:6YZ=6;\9V5N.@!.975E
M($=R=7!P92!H:6YZ=6;\9V5N`$YE=64@4F5C:'1E(&AI;GIU9OQG96X`56YT
M97)G<G5P<&4@>G4@(B5S(B!H:6YZ=6;\9V5N`%5N=&5R<F5C:'1E('IU("(E
M<R(@:&EN>G5F_&=E;@!&_&=E;B!3:64@96EN96X@;F5U96X@0F5N=71Z97(@
M:&EN>G4Z`%-P86QT92!H:6YZ=6;\9V5N`$YE=64@36ET9VQI961E<B!H:6YZ
M=6;\9V5N`%!A87(@:&EN>G5F_&=E;@!$87,@)7,M365N_"!Z=7(@36]Z:6QL
M82!3:61E8F%R(&AI;GIU9OQG96X`6G4@;65I;F5M($MA;&5N9&5R(&AI;GIU
M9OQG96X`6G5M($%D<F5S<V)U8V@@:&EN>G5F_&=E;CH`6G4@;65I;F5M($%D
M<F5S<V)U8V@@:&EN>G5F_&=E;@!"96YU='IE<B!H:6YZ=6;\9V5N`"(E<R(@
M=W5R9&4@>G5M(%-Y<W1E;2!H:6YZ=6=E9OQG="P@86)E<B!D:64@>G5SY'1Z
M;&EC:&5N($%N;65L9&5I;F9O<FUA=&EO;F5N(&MO;FYT96X@;FEC:'0@9V5S
M<&5I8VAE<G0@=V5R9&5N.B`E<RX`(B5S(B!W=7)D92!Z=6T@4WES=&5M(&AI
M;GIU9V5F_&=T+B!3:64@:_9N;F5N('-I8V@@:F5T>G0@86YM96QD96XN`$YE
M=64@1&%T96EE;B!W97)D96X@>G5M(%)E<&]S:71O<GD@:&EN>G5G96;\9W0Z
M`$1A<R!(:6YZ=6;\9V5N('9O;B!"96YU='IE<FX@:7-T(&YI8VAT(&WV9VQI
M8V@N`$%D<F5S<V4`061R97-S8G5C:`!697)W86QT96X@+2!296-H=&4@9OQR
M(&%N9&5R92!"96YU='IE<B!F97-T;&5G96X`061M:6YI<W1R871I;VX`5V5R
M8G5N9P!!9F=H86YI<W1A;@!!;&)A;FEE;@!!;&=E<FEE;@!3<&ET>FYA;64`
M075S<FEC:'1U;F<`075S<FEC:'1U;F<Z`$%L;&4`06YG96UE;&1E=&4@0F5N
M=71Z97(`06QL92!'<G5P<&5N`$%L;&4@4F5C:'1E`$%L;&4@=FEE<B!396ET
M96X`365H<F5R92!!9')E<W-E;B!E<FQA=6)E;@!&;W)M870@=F]N(&YU;6UE
M<FEE<G1E;B!,:7-T96X@Y&YD97)N/P!%>&ES=&EE<G0@8F5R96ET<P!!;'1E
M<FYA=&EV92!)35-0+4%N;65L9'5N9P!!;'1E<FYA=&EV97,@24U34"U087-S
M=V]R=`!!;'1E<FYA=&EV97(@24U34"U"96YU='IE<FYA;64`06QT97)N871I
M=F4@16UA:6QA9')E<W-E`$%L=&5R;F%T:79E(%9O<FQA9V5N`$%L=&5R;F%T
M:79E<B!497AT.@!!;65R:6MA;FES8V@M4V%M;V$`17,@=W5R9&4@96EN('5N
M9_QL=&EG97(@5V5R="!A;F=E9V5B96XN`$5I;B!U;F)E:V%N;G1E<B!&96AL
M97(@:7-T(&%U9F=E=')E=&5N+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!
M;F]N>6UE<B!0<F]X>0!!;G1W;W)T`$%N=&%R:W1I<P!!;G1I9W5A('5N9"!"
M87)B=61A`$%N=V5N9'5N9P!!;G=E;F1U;F=S;&ES=&4`06YW96YD=6YG(&ES
M="!B97)E:70N`$%U9B!5;G1E<G)E8VAT92!A;G=E;F1E;@!"97-TY'1I9V5N
M`%5N9V5FY&AR92!'<O;?90!!<')I;`!!<F%B:7-C:"`H5VEN9&]W<RTQ,C4V
M*0!!<F-H:79G<O;?90!!<F-H:79N86UE`%-I;F0@4VEE('-I8VAE<BP@9&%S
M<R!3:64@9&EE(%)E9VES=')I97)U;F=S86YF<F%G92!V;VX@)7,@;/9S8VAE
M;B!M]F-H=&5N/P!3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE("(E<R(@=6YD
M(&%L;&4@56YT97)G<G5P<&5N(&SV<V-H96X@;?9C:'1E;C\`07)G96YT:6YI
M96X`07)M96YI96X`07)M96YI<V-H("A!4DU30TE)+3@I`$MU;G-T`$%R=6)A
M`$%S8V5N<VEO;BU);G-E;&X`05-#24DM2W5N<W0`07-I96XO4&%Z:69I<V-H
M92!296=I;VX`06YS=&5H96YD92!787)T=6YG<V%R8F5I=&5N(&)E<W3D=&EG
M96X@;&%S<V5N/P!:=6]R9&YU;F=S9F5L9&5R`$EM($%N:&%N9R!F:6YD96X@
M4VEE(&5I;F4@:4-A;&5N9&%R+41A=&5I(&%L<R!!;G=O<G0@875F(&5I;F4@
M06YF<F%G92P@9&EE(%-I92!G97-T96QL="!H86)E;BX`17,@=W5R9&4@=F5R
M<W5C:'0L(&5I;F4@;FEC:'0@97AI<W1I97)E;F1E($=R=7!P92!Z=2!L]G-C
M:&5N+@!%<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T:65R96YD
M97,@4F5C:'0@>G4@;/9S8VAE;BX`17,@=W5R9&4@=F5R<W5C:'0L(&5I;B!N
M:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E87)B96ET96XN`$5S('=U
M<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI<W1I97)E;F1E<R!296-H="!Z
M=2!B96%R8F5I=&5N+@!496EL;F5H;65R`$%T=')I8G5T90!!=6=U<W0`075S
M=')A;&EE;@#6<W1E<G)E:6-H`$%U=&A?8WER<W%L.B!$:64@8F5N]G1I9W1E
M($E-05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?
M8WER=7,Z($1A<R!"86-K96YD(&AA="!N:6-H="!D:64@8F5N]G1I9W1E;B!&
MY&AI9VME:71E;BX`075T:%]C>7)U<SH@1&EE(&)E;O9T:6=T92!)34%0+45R
M=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7V9T<#H@1&EE
M(&)E;O9T:6=T92!&5%`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD
M96XN($MO;7!I;&EE<F5N(%-I92!02%`@;6ET(&1E;2`M+65N86)L92UF='`@
M4&%R86UE=&5R+@!!=71H7VEM87`Z($1I92!B96[V=&EG=&4@24U!4"U%<G=E
M:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]K<F(U.B!$:64@
M8F5N]G1I9W1E($ME<F)E<F]S+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E
M9G5N9&5N+@!!=71H7VQD87`Z($1I92!B96[V=&EG=&4@3$1!4"U%<G=E:71E
M<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]L9&%P.B!$97(@0F5N
M=71Z97(@)7,@:V]N;G1E(&YI8VAT(&AI;GIU9V5F_&=T('=E<F1E;BX@365L
M9'5N9R!D97,@4V5R=F5R<SH@`$%U=&A?;&1A<#H@0F5N=71Z97(@)7,@:V]N
M;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;@!!=71H7VQD87`Z($)E;G5T>F5R
M("5S(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N`$%U=&A?;6-A
M;#H@1&EE(&)E;O9T:6=T92!-0T%,+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT
M(&=E9G5N9&5N+@!!=71H7W-M8F%U=&@Z($1I92!B96[V=&EG=&4@4V%M8F$M
M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&AE;G1I9FEZ
M:65R=6YG(&9E:&QG97-C:&QA9V5N`$%N;65L9'5N9R!F96AL9V5S8VAL86=E
M;BX@)7,`1&EE($%U=&AE;G1I9FEZ:65R=6YG('=U<F1E('9O;2!2041)55,M
M4V5R=F5R('IU<OQC:V=E=VEE<V5N+@!!;FUE;&1U;F<@8F5I;2!&5%`M4V5R
M=F5R(&9E:&QG97-C:&QA9V5N+@!697)F_&=B87)E($9E;&1E<CH`075F($%N
M='=O<G0@=V%R=&5N9`!!<V5R8F%I9'-C:&%N`$)/1D@M075S<F5D96X`1&%S
M($)A8VME;F0@=W5R9&4@;FEC:'0@:V]R<F5K="!I;7!L96UE;G1I97)T+@!(
M:6YT97)G<G5N9`!(:6YT97)G<G5N9&9A<F)E`$9A;'-C:&5S($ME<F)E<F]S
M+5!A<W-W;W)T+@!&86QS8VAE<B!+97)B97)O<RU"96YU='IE<FYA;64N`$)A
M:&%M87,`0F%H<F5I;@!"86QT:7-C:"`H25-/+3@X-3DM,3,I`$)A;F=L861E
M<V-H`$)A<F)A9&]S`$)A<VES+4)I;&1E<BU697)Z96EC:&YI<R`B)7,B(&YI
M8VAT(&=E9G5N9&5N+@!'<G5N9&QI;FEE`%=E:=]R=6QA;F0`0F5L9VEE;@!"
M96QI>F4`0F5N:6X`0F5R;75D87,`0FAU=&%N`$=E8G5R='-T86<`0FQO8VL@
M(B5S(B!D97(@06YW96YD=6YG("(E<R(@;FEC:'0@9V5F=6YD96XN`$)L;V-K
M96EN<W1E;&QU;F=E;@!";&]C:W1Y<`!&971T`$)O;&EV:65N`$QE<V5Z96EC
M:&5N`%)A;F0`4F%H;65N9&EC:V4Z`%+D;F1E<@!";W-N:65N+4AE<GIE9V]W
M:6YA`$)E:61E<P!";W1S=V%N80!5;G1E;@!";W5V971I;G-E;`!"<F%S:6QI
M96X`0G)I=&ES8VAE<R!497)R:71O<FEU;2!I;2!);F1I<V-H96X@3WIE86X`
M0G)U;F5I($1A<G5S<V%L86T`34\M1&%T96EE;B!F_'(@9&%S("5S($UO9'5L
M('=E<F1E;B!E<G-T96QL="XN+@!,;V-A;&4@)7,@=VER9"!E<G-T96QL="XN
M+B``0G5L9V%R:65N`%5N;G5M;65R:65R=&4@3&ES=&4`0G5R:VEN82!&87-O
M`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N<W-T96QL90!?6F5L
M;&5N96EG96YS8VAA9G1E;BXN+@!$97(@6G=I<V-H96YS<&5I8VAE<B!K;VYN
M=&4@;FEC:'0@:6YI=&EA;&ES:65R="!W97)D96XN`$MA;&5N9&5R`%=I;F1S
M=&EL;`!+86UB;V1S8VAA`$MA;65R=6X`4&%S<W=O<G0@:V%N;B!N:6-H="!A
M=71O;6%T:7-C:"!Z=7+\8VMG97-E='IT('=E<F1E;BP@8FET=&4@=V5N9&5N
M(%-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T<F%T;W(N`%9E<F)I;F1U;F<@
M>G5M($E-05`M4V5R=F5R(&MA;FX@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N
M.B`E<P!+86YA9&$`06)B<F5C:&5N`%!R;V)L96UB97)I8VAT(&%B8G)E8VAE
M;@!$:64@1&%T96D@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M+@!+96EN('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9V5F=6YD96XN`$9O<G1S
M971Z=6YG(&]H;F4@(G1A<F=E=$9I;&4B+5!A<F%M971E<B!N:6-H="!M]F=L
M:6-H+@!$87,@5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@96YT9F5R
M;G0@=V5R9&5N+@!+;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N+"`E9"!+
M:6YD97(@97AI<W1I97)E;BX`56US;W)T:65R96X@;FEC:'0@;?9G;&EC:"X@
M1&EE($%N>F%H;"!D97(@16EN='+D9V4L(&1I92!U;7-O<G1I97)T('=E<F1E
M;B!S;VQL96XL('-T:6UM="!N:6-H="!M:70@9&5R($%N>F%H;"!D97(@9V5S
M<&5I8VAE<G1E;B!%:6YT<N1G92#\8F5R96EN+@!$:64@3F%C:')I8VAT(&MO
M;FYT92!N:6-H="!A;B!D:64@86YG96=E8F4@3G5M;65R('=E:71E<F=E;&5I
M=&5T('=E<F1E;BX`2V%P(%9E<F1E`-QB97)S8VAR:69T`$MA=&5G;W)I96X@
M=6YD($)E<V-H<FEF='5N9V5N`$-A>6UA;BU);G-E;&X`36]B:6QT96QE9F]N
M`%IE;&QE;F5I9V5N<V-H869T96X`26YN96YA8G-T86YD.@!:96QL96YE:6=E
M;G-C:&%F=&5N`%IE;&QE;F%B<W1A;F0Z`$UO8FEL=&5L969O;@!+96QT:7-C
M:"`H25-/+3@X-3DM,30I`%IE;G1R:65R=`!:96YT<F%L869R:6MA;FES8VAE
M(%)E<'5B;&EK`$UI='1E;&5U<F]PY&ES8V@@*$E33RTX.#4Y+3(I`%IE<G1I
M9FEK871D971A:6QS`%IE<G1I9FEK871B97-I='IE<@!:97)T:69I:V%T<FEC
M:'1L:6YI96X`5'-C:&%D`$)E<W!R96-H=6YG<VQE:71E<@#$;F1E<FX`4&%S
M<W=O<G0@Y&YD97)N`%!A<W-W;W)T(.1N9&5R;B!A=68Z`,1N9&5R;B!3:64@
M9&5N($YA;65N(&]D97(@9&EE($5M86EL861R97-S92P@9&EE(&1I92!%;7!F
MY&YG97(@26AR97(@16UA:6QS('-E:&5N+"!W96YN(&1I97-E($EH<F4@16UA
M:6QS(&QE<V5N(&]D97(@9&%R875F(&%N=V]R=&5N+@#$;F1E<FX@4VEE($EH
M<B!087-S=V]R=`!087-S=V]R="!A=68@)7,@Y&YD97)N`%IE:6-H96X`3&EN
M:R#\8F5R7W!R_&9E;BXN+@!-87)K:65R96X@4VEE(&%L;&4@075F9V%B96XL
M(&1I92!J971Z="!D=7)C:&=E9OQH<G0@=V5R9&5N('-O;&QE;BX`0VAI;&4`
M0VAI;F$`0VAI;F5S:7-C:"!V97)E:6YF86-H="`H1T(R,S$R*0!#:&EN97-I
M<V-H('1R861I=&EO;F5L;"`H0FEG-2D`5^1H;&5N(%-I92!E:6X@4&%S<W=O
M<G0`5^1H;&5N(%-I92!E:6YE;B!"96YU='IE<FYA;65N`$%K=&EO;B!A=7-W
MY&AL96XZ`$QE9V5N(%-I92!F97-T+"!W:64@9&%S($1A='5M(&%N9V5Z96EG
M="!W97)D96X@<V]L;#H`3&ES=&5N9F]R;6%T(&%U<W?D:&QE;B`H9OQR(&YU
M;6UE<FEE<G1E($QI<W1E;BD`5V5I:&YA8VAT<VEN<V5L`$ML87-S96YD969I
M;FET:6]N(&;\<B`E<R!N:6-H="!G969U;F1E;BX`4$\M1&%T96EE;B!F_'(@
M9&%S("5S($UO9'5L('=E<F1E;B!A=69G97+D=6UT+BXN`$QO8V%L92`E<R!W
M:7)D(&%U9F=E<N1U;70N+BX@`$AE:71E<@!-4RU/9F9I8V4M5&%G<R!E;G1F
M97)N96X`0F5N=71Z97)D871E;B!L]G-C:&5N.B`E<P!"96YU='IE<F1A=&5N
M(&SV<V-H96X`0F5N=71Z97)D871E;B!L]G-C:&5N`%-PY'1E<B!!=69K;&%R
M96YD`$9O<G1F86AR96X`0VQI8VMA=&5L;"!P97(@2%144`!&96YS=&5R('-C
M:&QI9=]E;@!7;VQK96X`1G+\:"!7;VQK96X`0F5W]FQK=`!+;VMO<VEN<V5L
M;@!-96[\(&5I;F9A:')E;@!:=7-A;6UE;FCD;F=E;F1E(%)A:&UE;@!+;VQU
M;6)I96X`1F%R8F4`1F%R8F%U<W=A:&P`1F%R8G=A:&P`4W!A;'1E;CH`4W!A
M;'1E;OQB97)S8VAR:69T96X`0V]M:6-S`$)E9F5H;`!"969E:&QS>F5I;&4`
M0F5F96AL<V]P=&EO;F5N`$)E9F5H;&4Z`$MO;6UE;G1A<@!#:&5C:V4@96EN
M.@!%:6YD975T:6=E<B!.86UE`$MO;6]R96X`1FER;6$`17)L961I9W0`3F5U
M92!.86-H<FEC:'0@*"5S*0!#;VUP=71E<@!"961I;F=U;F=E;@!+;VYF:6=U
M<F%T:6]N<W5N=&5R<V-H:65D90!$:64@2V]N9FEG=7)A=&EO;B!M=7-S(&%K
M='5A;&ES:65R="!W97)D96XN`"5S(&MO;F9I9W5R:65R96X`4&%S<W=O<G0@
M8F5S=.1T:6=E;@!.975E<R!087-S=V]R="!B97-TY'1I9V5N.@!+;VYG;P!$
M96UO:W)A=&ES8VAE(%)E<'5B;&EC($MO;F=O`%9E<F)I;F1U;F<@9F5H;&=E
M<V-H;&%G96XN`%9E<F)I;F1U;F<@9F5H;&=E<V-H;&%G96XZ(`!697)B:6YD
M=6YG('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E(&%B
M9V5W:65S96XN`%9E<F)I;F1U;F<@>G5M(/9F9F5N=&QI8VAE;B!38VAL_'-S
M96QS97)V97(@=W5R9&4@86)G97=I97-E;BX@1W)U;F0Z("5S("@E<RD`5F5R
M8FEN9'5N9R!Z=6T@1E10+5-E<G9E<B!F96AL9V5S8VAL86=E;@!$:64@2V]N
M=&%K=&4@=W5R9&5N(&5R9F]L9W)E:6-H($EH<F5M($%D<F5S<V)U8V@@:&EN
M>G5G96;\9W0N`$EN:&%L="!V;VX@(B5S(@!796ET97(`0V]O:RU);G-E;&X`
M0V]O:VEE`$MO<&EE<F5N`$%U<W=A:&P@:V]P:65R96X`2V]P:65R92`E<R!N
M86-H("5S`$-O<W1A(%)I8V$`16QF96YB96EN:_QS=&4`1&EE($YA8VAR:6-H
M="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!V97)S8VAL_'-S96QT('=E<F1E;BX`
M1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!U;G1E<GIE:6-H
M;F5T('=E<F1E;BX`1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%,O
M34E-12!V97)S8VAL_'-S96QT('=E<F1E;BX`1&EE($YA8VAR:6-H="!K;VYN
M=&4@;FEC:'0@;6ET(%,O34E-12!U;G1E<GIE:6-H;F5T('=E<F1E;BX`2V]N
M=&%K="!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B`E<P!697)B
M:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`5F5R8FEN
M9'5N9R!Z=6T@3$1!4"U397)V97(@9F5H;&=E<V-H;&%G96X`2V]N=&]S=&%N
M9"!K;VYN=&4@;FEC:'0@_&)E<G!R_&9T('=E<F1E;BX@)7,`5F5R8FEN9'5N
M9R!Z=6T@3$1!4"U397)V97(@9F5H;&=E<V-H;&%G96X`1E10+59E<F)I;F1U
M;F<@>G5M(%-E<G9E<B`B)7,B(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W
M97)D96XZ("5S`$MO;FYT92`E<R!N:6-H="!N86-H("5S(&MO<&EE<F5N`%9E
M<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96XN("5S
M`$1A<R!L;V-A;&4@5F5R>F5I8VAN:7,@9OQR(&1A<R!,;V-A;&4@)7,@:V]N
M;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E;CH`4$=0+41A=&5N(&MO;FYT96X@
M;FEC:'0@96YT<V-H;/QS<V5L="!W97)D96XN`%,O34E-12U$871E;B!K;VYN
M=&5N(&YI8VAT(&5N='-C:&S\<W-E;'0@=V5R9&5N+@!+;VYT86MT(&MO;FYT
M92!N:6-H="!G96SV<V-H="!W97)D96XN("5S`%9E<G1E:6QE<FQI<W1E(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN("5S`$1A<R!!:W1U86QI<VEE
M<G5N9W-S:W)I<'0@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M+@!$:64@16UA:6QA9')E<W-E(&1E<R!%;7!FY&YG97)S(&MO;FYT92!N:6-H
M="!E<FUI='1E;'0@=V5R9&5N+@!$87,@061R97-S8G5C:"!K;VYN=&4@;FEC
M:'0@:V]M<&QE='0@9V5L97-E;B!W97)D96XN`%9E<G1E:6QE<FQI<W1E(&MO
M;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`3&ES=&4@9&5R(%9E
M<G1E:6QE<FQI<W1E;B!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN
M`$1I92!3=')A=&5G:64@(B5S(B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D
M96XN`$1A<R!697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!A;F=E;&5G
M="!W97)D96XN`-9F9F5N=&QI8VAE<B!38VAL_'-S96P@:V]N;G1E(&YI8VAT
M('9O;2!38VAL_'-S96QS97)V97(@9V5H;VQT('=E<F1E;BX`(B5S(B!K;VYN
M=&4@;FEC:'0@>G5M(%-C:')E:6)E;B!G9?9F9FYE="!W97)D96XN`"5S(&MO
M;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX`1&%S($UA:6YT96YA;F-E7U1A
M<VL@36]D=6P@)7,@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;@!697)Z
M96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN`%9E
M<F)I;F1U;F<@>G4@<VUB<&%S<W=D(&MO;FYT92!N:6-H="!H97)G97-T96QL
M="!W97)D96XN`"5S(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX`1&%S
M(%!A<W-W;W)T(&;\<B!D96X@86YG96=E8F5N96X@0F5N=71Z97(@:V]N;G1E
M(&YI8VAT('IU<OQC:V=E<V5T>G0@=V5R9&5N+"!W96EL(&5I;FEG92!!;F=A
M8F5N(&YI8VAT(')I8VAT:6<@=V%R96XN(%9E<G-U8VAE;B!3:64@97,@97)N
M975T(&]D97(@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T<F%T
M;W(L('=E;FX@4VEE('=E:71E<F4@2&EL9F4@8F5N]G1I9V5N+@!!0TP@:V]N
M;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N`$1A<R!!9')E<W-B=6-H(&MO;FYT
M92!N:6-H="!G96QE<V5N('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@:V]N
M;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<P!697)T96EL97)L:7-T
M96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<P!$:64@4V5R
M=F5R9N1H:6=K96ET96X@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N('=E<F1E
M;@!+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!Z=7+\8VMG97-E='IT('=E
M<F1E;BX`5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@
M=V5R9&5N+@`E<RU+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P96EC
M:&5R="!W97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B!K;VYN=&4@
M;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!"86-K=7`@9&5R($MO;F9I9W5R
M871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;CH@)7,`1&%S
M($%K='5A;&ES:65R=6YG<W-K<FEP="!K;VYN=&4@;FEC:'0@;F%C:"`B)7,B
M(&=E<W!E:6-H97)T('=E<F1E;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N
M("5S(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN`$1I92!+;VYF
M:6=U<F%T:6]N("5S(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN
M(%-I92!K]FYN96X@96YT=V5D97(@96EN92!D97(@3?9G;&EC:&ME:71E;B!U
M;G1E<B`E<R!V97)W96YD96XL('5M(&1E;B!#;V1E('IU('-P96EC:&5R;BP@
M;V1E<B!D96X@=6YT96YS=&5H96YD96X@0V]D92!M86YU96QL(&YA8V@@)7,@
M:V]P:65R96XN`$1E<B!,1$%0+5-E<G9E<B!K;VYN=&4@;FEC:'0@9'5R8VAS
M=6-H="!W97)D96XN`"(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E
M;BX`1&5R($MO;G1A:W0@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E
M;BX@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&%K='5A;&ES:65R
M="!W97)D96XN("5S`$1I92!+;VYF:6=U<F%T:6]N(&;\<B`B)7,B(&MO;FYT
M92!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S`$1I92!-;WII;&QA(%-I
M9&5B87(@:V]N;G1E(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX@4W1E;&QE;B!3
M:64@<VEC:&5R+"!D87-S(&1I92!3:61E8F%R(&=E]F9F;F5T(&ES="X`1&5M
M($)E;G5T>F5R("(E<R(@:V]N;G1E;B!D:64@9F]L9V5N9&4@4F5C:'1E(&;\
M<B!D96X@3W)D;F5R("(E<R(@;FEC:'0@>G5G97=I97-E;B!W97)D96XZ("5S
M`$=E>N1H;'1E<B!497AT`$QA;F0`2W5R<V4`17)S=&5L;&5N`$QI;FL@97)S
M=&5L;&5N`$YE=64@261E;G1I=.1T(&%N;&5G96X`56YT97)O<F1N97(@97)S
M=&5L;&5N`$5R<W1E;&QE<G)E8VAT90!+<F5D:71K87)T96YN=6UM97(`2W)O
M871I96X`2W5B80!!:W1U96QL92`T(%!H87-E;@!!:W1U96QL92!:96ET`$%K
M='5E;&QE(%523"!I<W0`06MT=65L;&5S(%=E='1E<@!$97)Z96ET:6=E($)E
M9&EN9W5N9V5N.B``06MT=65L;&5R(%-T:6P`3&5G96X@4VEE(&9E<W0L('=E
M;&-H92!!=69G86)E;B!N86-H(&1E<B!!;FUE;&1U;F<@8F5I("5S(&5R;&5D
M:6=T('=E<F1E;B!S;VQL96XN`$%U<W-C:&YE:61E;@!!=7-W86AL(&%U<W-C
M:&YE:61E;@!:>7!E<FX`2WER:6QL:7-C:"`H2T])."U2*0!+>7)I;&QI<V-H
M("A7:6YD;W=S+3$R-3$I`$MY<FEL;&ES8V@O56MR86EN:7-C:"`H2T])."U5
M*0!4<V-H96-H:7-C:&4@4F5P=6)L:6L`5%0`5.1G;&EC:`!$871A5')E92!"
M<F]W<V5R`$1A='5M`$5M<&9A;F=S9&%T=6T`1&%T=6US875S=V%H;`!486<`
M4W!A;'1E(%]L]G-C:&5N`$1E>F5M8F5R`%IA:&QE;@!!8F=E;&5H;G0`16EN
M>G5G('9E<G)I;F=E<FX`4W1A;F1A<F0`4W1A;F1A<F1F87)B90!3=&%N9&%R
M9&ED96YT:73D=`!3=&%N9&%R9')E8VAT90!3=&%N9&%R9')E8VAT90!$969I
M;FET:6]N96X`1&5L96=I97)E;@!$96QE9VEE<G0`3/9S8VAE;@!'<G5P<&4@
M;/9S8VAE;@!296-H=&4@;/9S8VAE;@!.86-H<FEC:'1E;B!L]G-C:&5N('5N
M9"!E;G1F97)N96X`6F5L;&4@;/9S8VAE;@!3<&%L=&4@;/9S8VAE;@!"97-T
M96AE;F1E(&%L=&5R;F%T:79E(%9O<FQA9V4@;/9S8VAE;@!296-H=&4@9OQR
M("(E<R(@;/9S8VAE;@!296-H=&4@9OQR("<E<R<@=6YD(&%L;&4@56YT97)R
M96-H=&4@;/9S8VAE;C\`6F5I;&4@;/9S8VAE;@!!=7-G97?D:&QT92!)9&5N
M=&ETY'0@;/9S8VAE;@!$:64@86MT=65L;&4@4W!A;'1E(&SV<V-H96X`1&EE
M(&%K='5E;&QE(%IE:6QE(&SV<V-H96X`1&EE<V5S(%)E8VAT('5N9"!A;&QE
M(%5N=&5R<F5C:'1E(&SV<V-H96X_`$1A<R!!:W1U86QI<VEE<G5N9W-S:W)I
M<'0@(B5S(B!W=7)D92!G96SV<V-H="X`075S;&EE9F5R=6YG<WIE:70`1.1N
M96UA<FL`06YF<F%G92!A8FQE:&YE;@!!;F9R86=E(&;\<B!&<F5I+T=E8G5C
M:'0M26YF;W)M871I;VYE;B!A8FQE:&YE;@!"97-C:')E:6)E;B!3:64@9&%S
M(%!R;V)L96T`0F5S8VAR96EB=6YG`$1E=&%I;',@*&%U8V@@:6X@2&]R9&5S
M($QO9V1A=&5I*3H`1&5T86EL<R!W=7)D96X@9OQR(&1E;B!!9&UI;FES=')A
M=&]R(&UI=&=E;&]G9W0N`$5N='=I8VML=6YG`%1A=7!U;FMT`%1A=7!U;FMT
M(&1E<B!L971Z=&5N(%-T=6YD93H@`%1A=7!U;FMT.B``5F]N(&QI;FMS(&YA
M8V@@<F5C:'1S`%9O;B!R96-H=',@;F%C:"!L:6YK<P!697)Z96EC:&YI<P!:
M96ET(&EM(#(T+5-T=6YD96XM1F]R;6%T(&%N>F5I9V5N/P!!;GIE:6=E+45I
M;G-T96QL=6YG96X`5F]R:&5R<V%G92`H5$%&*2!A;GIE:6=E;@!!;GIE:6=E
M9F]R;6%T`$5M<&9A;F=S8F5S=.1T:6=U;F<`1'-C:&EB=71I`$YI8VAT(&SV
M<V-H96X`1W)E:69E;B!3:64@;FEC:'0@9&ER96MT(&%U9B!M86EN=&5N86YC
M92YP:'`@>G4`16YT:.1L="!D:64@97)S=&4@6F5I;&4@9&EE($9E;&1N86UE
M;C\@5V5N;B!J82P@9&EE<V5S($%U<W=A:&QKY'-T8VAE;B!M87)K:65R96XZ
M`$1O;6EN:6-A`$1O;6EN:6MA;FES8VAE(%)E<'5B;&EK`$AE<G5N=&5R;&%D
M96X`)7,@2&5R=6YT97)L861E;@!%<GIE=6=T92!+;VYF:6=U<F%T:6]N(&%L
M<R!02%`M4VMR:7!T(&AE<G5N=&5R;&%D96XN`$%U<W=A:&QL:7-T90!$<F]G
M96X`16UA:6P`1D5(3$52`$5C=6%D;W(`0F5A<F)E:71E;@!";&]C:R!B96%R
M8F5I=&5N`$=R=7!P92!B96%R8F5I=&5N`%)E8VAT92!B96%R8F5I=&5N`%)E
M8VAT92!B96%R8F5I=&5N`%)E8VAT92!F_'(@)R5S)R!B96%R8F5I=&5N`$5I
M;G-T96QL=6YG96X@8F5A<F)E:71E;B!F_'(Z`%)E8VAT92!F_'(@(B5S(B!B
M96%R8F5I=&5N`%)E8VAT92!F_'(@)7,@8F5A<F)E:71E;@!":6QD=6YG`,1G
M>7!T96X`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;&%D
M<F5S<V4`1&EE($5M86EL861R97-S96X@;?QS<V5N(&=L96EC:"!S96EN+@!%
M;6%I;"!M:70@0F5S=.1T:6=U;F<`4VUI;&5Y<P!,965R92!.86-H<FEC:'0N
M`$QE97)E<R!%<F=E8FYI<RX`4W5C:&)E9W)I9F9E(&SV<V-H96X`16EN9OQG
M96X@=F]N($)I;&1E<FX@875S($9O=&]G86QL97)I96X@:6X@9&5N(%1E>'0@
M97)L875B96X_`$MO;G1E>'1M96[\(&)E:2!296-H='-K;&EC:R!A:W1I=FEE
M<F5N/P!%;F1E`$5N9&IA:'(`161I=&]R('9E<F=R]M]E<FX`1V5B96X@4VEE
M(&5I;F4@4VEC:&5R:&5I='-F<F%G92!E:6XL(&1I92!):&YE;B!G97-T96QL
M="!W:7)D+"!W96YN(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K<V5T>F5N(&WV
M8VAT96XL('HN($(N(")7:64@;&%U=&5T(&1E<B!.86UE($EH<F5S($AA=7-T
M:65R<S\B.@!(:65R(&1I92!":6QD+5523"!A;F=E8F5N`$5I;G1RY&=E.B`E
M9"!I;G-G97-A;70L("5D(&%K='5E;&QE+"`E9"!N975E+"`E9"!G9>1N9&5R
M=&4L("5D('5N8F5K86YN=&4`Q'%U871O<FEA;"U'=6EN96$`17)I=')E80!&
M96AL97(`0F5I;2!697)S96YD96X@=F]N($1A=&5N('IU('-M8G!A<W-W9"!I
M<W0@96EN($9E:&QE<B!A=69G971R971E;BX`1F5H;&5R(&)E:6T@5F5R<V5N
M9&5N(&1E<B!!;G1W;W)T.B`E<P!&96AL97(@:6X@9&5R($5M86EL;F%C:')I
M8VAT+@!&96AL97(@8F5I;2!38VAR96EB96X@=F]N("(E<R(N`$9E:&QE<CH@
M`$5S=&QA;F0`Q'1H:6]P:65N`$5T;FES8VAE<P!%=7)O<&$`06QL92`Q-2!-
M:6YU=&5N`$%L;&4@,B!-:6YU=&5N`$%L;&4@,S`@4V5K=6YD96X`06QL92`U
M($UI;G5T96X`0F5I(&IE9&5R($%N;65L9'5N9P!!;&QE(&AA;&)E(%-T=6YD
M90!!;&QE(#8P(%-E:W5N9&5N`$)E:7-P:65L=V5R=&4Z`$%U<V;\:')E;@!&
M_&AR92!A=7,Z`%9E<F=R]M]E<FX`365N_"!A=7-F86AR96X`)RDG(&5R=V%R
M=&5T`$5I;GIE;&YE<R!7;W)T(&]D97(@4W5C:&)E9W)I9F8@:6X@06YF_&AR
M=6YG<WIE:6-H96X@97)W87)T970`5F5R9F%L;'-D871U;0!%>'!O;F5N=`!!
M=7,@)7,@97AT<F%H:65R96XN+BX@`%9O<F1E<F=R=6YD9F%R8F4`2&]C:&QA
M9&5N(&1E<B!+;VYF:6=U<F%T:6]N('!E<B!&5%``0F5N=71Z97)E:6YS=&5L
M;'5N9V5N(&MO;FYT96X@;FEC:'0@9V5L861E;B!W97)D96XN`%9E<F)I;F1U
M;F<@>G5M($Q$05`@4V5R=F5R(&=E<V-H96ET97)T+@!697)B:6YD=6YG('IU
M;2!334(M4V5R=F5R(&=E<V-H96ET97)T+@!%<R!K;VYN=&4@:V5I;F4@2V]P
M:64@=F]N("(E<R(@97)S=&5L;'0@=V5R9&5N+@!%<R!K;VYN=&4@;FEC:'0@
M;F%C:"`B)7,B(&MO<&EE<G0@=V5R9&5N+@!!=69B874@96EN96X@;F5U96X@
M4T%33"U697)B:6YD=6YG(&ES="!F96AL9V5S8VAL86=E;BX`17,@:V]N;G1E
M(&YI8VAT(&YA8V@@(B5S(B!V97)S8VAO8F5N('=E<F1E;BX`1&%S(&%L=&4@
M4&%S<W=O<G0@:V]N;G1E(&YI8VAT(&)E<W3D=&EG="!W97)D96XN`$9E:&QE
M<B!B96EM(,1N9&5R;B!D97,@4&%S<W=O<G1S(&%U9B`E<SH@)7,`2&5I=&5R
M`$9A;&ML86YD:6YS96QN`$9A<O9E<@!38VAW97)E<B!&96AL97(Z`$9A>`!&
M96)R=6%R`$=E9OQH;'1E(%1E;7!E<F%T=7(`1V5F_&AL=&4@5&5M<&5R871U
M<CH@`%9E<F5I;GIE;'1E(%-C:&%U97(`5F5R96EN>F5L=&4@4V-H;F5E<V-H
M875E<@!&96QD;6%T<FEX`$9I9'-C:&D`06YZ86AL.B`E<R!$871E:0!!;GIA
M:&PZ("5S($1A=&5I96X`1&%T96EM86YA9V5R`$1A=&5I;F%M90!$871E:6%U
M<W=A:&P`1&%T96DM2&]C:&QA9&5N`$1A<R!(;V-H;&%D96X@=F]N($1A=&5I
M96X@=VER9"!N:6-H="!U;G1E<G-T_'1Z="X`1FEL=&5R`$9I;FYL86YD`$5R
M<W1E($CD;&9T90!%<G-T97,@5FEE<G1E;`!697)HY&QT;FES('IU<OQC:W-E
M='IE;@!5;61R96AE;@!497AT9FQUWP!.96)E;`!$87,@5F5R>F5I8VAN:7,@
M)7,@97AI<W1I97)T(&YI8VAT`%-C:')I9G1F87)B90!%<W-E;@!&_'(@0G)O
M=W-E<BP@9&EE(&ME:6YE($)I;&1E<B!U;G1E<G-T_'1Z96X`5F]R:&5R<V%G
M92`H5$%&*0!6;W)H97)G97-A9W1E(%1A9V4@*%9O<FAE<G-A9V5N(&5N=&AA
M;'1E;B!486=E('5N9"!.Y&-H=&4L(&5I;B!H;VAE<B!797)T(&MA;FX@>G4@
M96EN96T@<V5H<B!G<F_?96X@0FQO8VL@9OQH<F5N*0!087-S=V]R="!V97)G
M97-S96X_`$9O<FUU;&%R90!';/QC:W-K96MS`$=L_&-K<VME:W-T>7``1VS\
M8VMS:V5K<V4`1VS\8VMS:V5K<V4@,@!&;W)E;@!796ET97)L96ET=6YG`$%N
M=V5N9'5N9V5N(&=E9G5N9&5N.B`E<P!'969U;F1E;F4@5F5R>F5I8VAN:7-S
M93H@`$9R`%)A:&UE;@!&<F%N:W)E:6-H`$5U<F]PY&ES8VAE<R!&<F%N:W)E
M:6-H`$9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N`$9R96DO1V5B=6-H="U!
M;G1W;W)T`$9R96DO1V5B=6-H="U!;F9R86=E`$%N='=O<G0@875F($9R96DO
M1V5B=6-H="U!;F9R86=E`$9R86YZ]G-I<V-H+4=U87EA;F$`1G)A;GKV<VES
M8V@M4&]L>6YE<VEE;@!&<F%N>O9S:7-C:&4@1V5B:65T92!I;2!S_&1L:6-H
M96X@26YD:7-C:&5N($]Z96%N`%9O;@!!=7,@`%9O;&QS=.1N9&EG92!"97-C
M:')E:6)U;F<`5F]L;&UO;F0`5F]L;'-TY&YD:6=E<B!.86UE`%5N9V5N874`
M1V%B=6X`0FEL9&5R(&%U<R!D:65S97(@1V%L;&5R:64`1V%L;&5R:64Z`$=A
M;6)I80`E<RU+;VYF:6=U<F%T:6]N(&5R>F5U9V5N`$5R>F5U9W1E<B!#;V1E
M`%-T871U<R!F_'(@9&%S("5S+4UO9'5L('=I<F0@9V5N97)I97)T+BXN`$=E
M;W)G:65N`$1E=71S8VAL86YD`$=E=&]P="!&96AL97(Z(`!':&%N80!':6)R
M86QT87(`5F]R;F%M90!,;W,`1V]E9&5L`$=O;V=L92!3=6-H90!'<F%U<W1U
M9F5N`$=R:65C:&5N;&%N9`!'<FEE8VAI<V-H("A)4T\M.#@U.2TW*0!'<O9N
M;&%N9`!'<F5N861A`$=R=7!P96YV97)W86QT=6YG`$=R=7!P96YN86UE;B!D
M_')F96X@;FEC:'0@;&5E<B!S96EN`$=R=7!P96YR96-H=&4`1W)U<'!E;@!'
M=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=A<W1R96-H=&4`
M1V%S=')E8VAT90!'Y'-T96)U8V@`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y
M86YA`$A434P`1&5R($5D:71O<B!K86YN(&1I92!L971Z=&4@6F5L;&4@96EN
M97(@6F5I;&4@;FEC:'0@;/9S8VAE;BX`1&5R($5D:71O<B!K86YN(&1I92!L
M971Z=&4@4W!A;'1E(&5I;F5R(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BX`1&5R
M($5D:71O<B!K86YN(&1I92!L971Z=&4@6F5I;&4@96EN97(@5&%B96QL92!N
M:6-H="!L]G-C:&5N+@!(5%10+4%U=&AE;G1I9FEZ:65R=6YG(&YI8VAT(&=E
M9G5N9&5N+@!(86ET:0!(87-H+4%L9V]R:71H;75S`$1I97-I9P#<8F5R<V-H
M<FEF=`!(96%R9"T@=6YD($UC1&]N86QD:6YS96QN`%-C:'=E<F4@1V5W:71T
M97(`2&5B<N1I<V-H("A)4T\M.#@U.2TX+4DI`$CV:&4`2&EL9F4`161I=&]R
M:&EL9F4`2&EL9F4`2&EL9G-P<F]G<F%M;2!F_'(@9&EE($5R<W1E;&QU;F<@
M=6YD(%=A<G1U;F<@=F]N(-QB97)S971Z=6YG96X@9OQR(&1A<PI(;W)D92!&
M<F%M97=O<FL@=6YD('-E:6YE($%N=V5N9'5N9V5N+@I&_'(@96EN92!%:6YF
M_&AR=6YG(&QE<V5N(%-I92!B:71T92!D:64@4D5!1$U%+41A=&5I(&EN(&1I
M97-E;2!697)Z96EC:&YI<RX`2&5M:7-P:&5R90!$:65S(&ES="!D97(@0F5G
M:6YN(&1E<B!$871E:3H`2&]C:`!697)L875F<VYA;65N(&3\<F9E;B!N:6-H
M="!L965R('-E:6X`7U-T87)T<V5I=&4`5F%T:6MA;G-T861T`%-T87)T<V5I
M=&4`061R97-S92!P<FEV870`5&5L969O;B!P<FEV870`2&]N9'5R87,`2&]N
M9R!+;VYG`$AO<F1E`$AO<F1E(-QB97)S971Z=6YG<V=E;F5R871O<@!(;W)D
M92]+;VQA8CH@56YG_&QT:6=E("5S+5A-3"U$871E;B!I;B!.86-H<FEC:'0@
M)7,`2&]R9&4O2V]L86(Z($5S('!A<W-T(&ME:6YE($YA8VAR:6-H="!Z=6T@
M3V)J96MT("5S`$AO<F1E+TMO;&%B.B!+96EN($]B:F5K="!V;VT@5'EP("5S
M(&EN($YA8VAR:6-H="`E<R!G969U;F1E;@!(;W)D92]+;VQA8CH@)7,@(B5S
M(B!W=7)D92!E<F9O;&=R96EC:"!E;G1F97)N=`!(;W)D92]+;VQA8CH@)7,@
M(B5S(B!W=7)D92!E<F9O;&=R96EC:"!S>6YC:')O;FES:65R=`!(;W)D92]+
M;VQA8CH@1&EE($EN=&5G<F%T:6]N<V9U;FMT:6]N96X@8F5N]G1I9V5N(&1I
M92`B9&]M>&UL(B!02%`M17)W96ET97)U;F<`2&]R9&4O2V]L86(Z($;\<B!D
M87,@3V)J96MT("5S(&MO;FYT92!K96EN(&YE=65R(%A-3"U"875M(&5R>F5U
M9W0@=V5R9&5N`$AO<F1E+TMO;&%B.B`E<R`B)7,B(&MO;FYT92!N:6-H="!E
M;G1F97)N="!W97)D96XZ("5S`$AO<F1E+TMO;&%B.B!$:64@34E-12U)1"!D
M97,@06)S8VAN:71T<R!V;VT@5'EP("5S(&MO;FYT92!N:6-H="!H97)A=7-G
M969U;F1E;B!W97)D96XN`$AO<F1E+TMO;&%B.B`E<R`B)7,B(&MO;FYT92!N
M:6-H="!S>6YC:')O;FES:65R="!W97)D96XZ("5S`$AO<F1E+TMO;&%B.B!$
M:64@9V5M96EN<V%M96X@3V)J96MT92!K;VYN=&5N(&YI8VAT('-Y;F-H<F]N
M:7-I97)T('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z(%5N8F5K86YN=&5S(&=E
M;65I;G-A;65S($]B:F5K="`B)7,B`$AO<FEZ;VYT86QE($QI;FEE`$AO<FEZ
M;VYT86QE<B!);FYE;F%B<W1A;F0`2&]R:7IO;G1A;#H`5VEE('-I;F0@4VEE
M(&AI97)H97)G96QA;F=T/R!":71T92!A;B!D:64@16YT=VEC:VQE<B!Z=7+\
M8VMM96QD96XA*0!7:64@=FEE;&4@4W!A;'1E;B!S;VQL96X@>G5S86UM96YG
M96;\9W0@=V5R9&5N/P!7:65V:65L92!&96QD97(@*%-P86QT96XI(&=I8G0@
M97,_`%=I92!V:65L92!:96EL96X@<V]L;&5N('IU<V%M;65N9V5F_&=T('=E
M<F1E;C\`3'5F=&9E=6-H=&EG:V5I=`!,=69T9F5U8VAT:6=K96ET.B``2V]M
M:6ME<@!5;F=A<FX`06YL96=E;B!D97,@24U!4"U0;W-T9F%C:',@:7-T(&9E
M:&QG97-C:&QA9V5N.B`E<P!,]G-C:&5N(&1E<R!)34%0+5!O<W1F86-H<R!I
M<W0@9F5H;&=E<V-H;&%G96XZ("5S`$9E<W1L96=E;B!D97(@24U!4"U0;W-T
M9F%C:"U1=6]T82!I<W0@9F5H;&=E<V-H;&%G96XZ("5S`$E0+4%D<F5S<V4`
M25`M061R97-S92!N:6-H="!V97)F_&=B87(N`$E0+4%D<F5S<V4@;FEC:'0@
M:6T@97)L875B=&5N($-)1%(M0FQO8VLN`%9E<FQE='IU;F<@9&5R(&9E<W1G
M96QE9W1E;B!)4"X`6F5I;&4@96EN9OQG96X@7W9O<@!)<VQA;F0`3G5R($)I
M;&1E<@!)8V]N<R!F_'(@)7,`0FEL9&5R('5N9"!497AT`$)E>F5I8VAN=6YG
M(&1E<B!)9&5N=&ETY'0`5V5N;B!S:64@;FEC:'0@:V]R<F5K="!A;F=E>F5I
M9W0@=VER9"P@)7,L('5M('-I92!I;B!E:6YE;2!N975E;B!&96YS=&5R(&%N
M9V5Z96EG="!Z=2!B96MO;6UE;BX`5V5N;B!3:64@;6ET(&1E;2!);G1E<FYE
M="!%>'!L;W)E<B!K96EN92!3>6UB;VQE('-E:&5N+"!M_'-S96X@4VEE(&1I
M97-E<R!+Y'-T8VAE;B!M87)K:65R96XL('5M(%!.1RU4<F%N<&%R96YZ(&%U
M<WIU<W1E;&QE;BX`5V5N;B!3:64@9&EE<V4@3F%C:')I8VAT(&%N(%-T96QL
M92!E:6YE($)I;&1E<R!S96AE;BP@:V%N;B!):'(@0G)O=W-E<B!D87,@0FEL
M9"P@9&%S(%-I92!H;V-H;&%D96X@;?9C:'1E;B!N:6-H="!A;GIE:6=E;BX`
M0FEL9'9O<G-C:&%U.@!":6QD+5523`!":6QD+5523#H`0FEL9"!V;VX@1V%L
M;&5R:64`0FEL9"!V;VX@1V%L;&5R:64Z`$)I;&0M2&]C:&QA9&5N`$)I;&1E
M<@!);7!O<G1I97)E;BP@4V-H<FET="`E9`!);7!O<G1I97)T97,@1F5L9#H@
M)7,`26UP;W)T:65R=&4@1F5L9&5R.@!);B!"96%R8F5I='5N9P!:96EL92!E
M:6YF_&=E;B!?;F%C:`!&86QS8VAE<R!087-S=V]R=`!5;F?\;'1I9V4@06MT
M:6]N(&%N9V5G96)E;BX`56YG_&QT:6=E<B!"96YU='IE<FYA;64@=6YD+V]D
M97(@4&%S<W=O<G0N`$9A;'-C:&5R($)E;G5T>F5R;F%M92!O9&5R($5M86EL
M861R97-S92X@5F5R<W5C:&5N(%-I92!E<R!E<FYE=70@;V1E<B!W96YD96X@
M4VEE('-I8V@@86X@26AR96X@4WES=&5M861M:6YI<W1R871O<BP@=V5N;B!3
M:64@=V5I=&5R92!(:6QF92!B96[V=&EG96XN`$5I;GIU9R!V97)G<O;?97)N
M`$EN9&EE;@!%:6YZ96QN92!"96YU='IE<@!);F1O;F5S:65N`$EN9F]R;6%T
M:6]N`$EN9F]R;6%T:6]N96X`26YI=&EA;&ES:65R92!-;V1U;"`E<RXN+B``
M7U-P86QT92!D879O<B!E:6YF_&=E;@!":6QD(&AI;GIU9OQG96X`5&%B96QL
M92!E:6YF_&=E;@!,:6YK(&5I;F;\9V5N`%-?<&%L=&4@9&%N86-H(&5I;F;\
M9V5N`$5I;F4@;F5U92!3<&%L=&4@;F%C:"!D97(@86MT=65L;&5N(&5I;F;\
M9V5N`$5I;F4@;F5U92!3<&%L=&4@=F]R(&1E<B!A:W1U96QL96X@96EN9OQG
M96X`16EN92!N975E(%IE:6QE(&YA8V@@9&5R(&%K='5E;&QE;B!E:6YF_&=E
M;@!%:6YE(&YE=64@6F5I;&4@=F]R(&1E<B!A:W1U96QL96X@96EN9OQG96X`
M16EN96X@;F5U96X@06)S871Z(&YA8V@@9&5M(&%K='5E;&QE;B!%;&5M96YT
M(&5I;F;\9V5N`$5I;F5N(&YE=65N($%B<V%T>B!V;W(@9&5M(&%K='5E;&QE
M;B!%;&5M96YT(&5I;F;\9V5N`$%L=&5R;F%T:79E(%9O<FQA9V4@96EN9OQG
M96X`1V5B96X@4VEE(&5I;F4@16UA:6QA9')E<W-E(&%N+"!A;B!D:64@9&%S
M(&YE=64@4&%S<W=O<G0@9V5S8VAI8VMT('=E<F1E;B!S;VQL.@!:96QL92!D
M86YA8V@@96EN9OQG96X`6F5L;&4@9&%V;W(@96EN9OQG96X`4W!A;'1E(&1A
M;F%C:"!E:6YF_&=E;@!3<&%L=&4@9&%V;W(@96EN9OQG96X`3F%C:')I8VAT
M96X@:&EN>G5F_&=E;@!!8G-A='H@9&%N86-H(&5I;F;\9V5N`$%B<V%T>B!D
M879O<B!E:6YF_&=E;@!:96EL92!D86YA8V@@96EN9OQG96X`6F5I;&4@9&%V
M;W(@96EN9OQG96X`1V5B96X@4VEE(&1I92!!;G1W;W)T(&%U9B!D:64@4VEC
M:&5R:&5I='-F<F%G92!E:6XZ`$)I;&0@96EN9OQG96XO8F5A<F)E:71E;@!,
M:6YK(&5I;F;\9V5N+V)E87)B96ET96X`6G4@=V5N:6<@1W5T:&%B96XL('5M
M(&%N(&1I92!697)T96EL97)L:7-T92!Z=2!V97)S8VAI8VME;BX`6G4@=V5N
M:6<@1W5T:&%B96XN`$=A;GIZ86AL`$QI<W1E('9O;B!'86YZ>F%H;&5N`%5N
M9_QL=&EG92!!:W1I;VX@9OQR(&1I97-E($MO;7!O;F5N=&4@875S9V5WY&AL
M="X`56YG_&QT:6=E<B!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`56YG_&QT
M:6=E($%N=V5N9'5N9RX`56YG_&QT:6=E($)A=&-H+4E$+@!5;F?\;'1I9V4@
M1&%T96X@96EN9V5B96XN`%5N9_QL=&EG92!::65L861R97-S92X`56YG_&QT
M:6=E<R!$871E:69O<FUA=`!5;F?\;'1I9V5R($QI>F5N>G-C:&S\<W-E;"X`
M56YG_&QT:6=E<B!/<G0@86YG96=E8F5N+@!5;F?\;'1I9V5R(&US9U]T>7!E
M+@!5;F?\;'1I9V4@;V1E<B!F96AL96YD92!A<&E?:60N`%5N9_QL=&EG92!O
M9&5R(&9E:&QE;F1E(%!A<F%M971E<BX`56YG_&QT:6=E<R#<8F5R<F5C:'0N
M`%5N9_QL=&EG92!087)T;F5R+4E$+@!5;F?\;'1I9V5R(%!R;V1U:W1C;V1E
M+@!5;F?\;'1I9V5S(%!R;W1O:V]L;"X`56YG_&QT:6=E<B!%;7!FY&YG97(Z
M("(E<R(`56YG_&QT:6=E<R!G96UE:6YS86UE<R!/8FIE:W0`56YG_&QT:6=E
M(%5R<W!R=6YG<V%D<F5S<V4N`%5N9_QL=&EG92!5;FEC;V1E+41A=&5N+@!)
M;G9E;G1A<@!)<VQA;6ES8VAE(%)E<'5B;&EK($ER86X`27)A:P!)<FQA;F0`
M27-L92!O9B!-86X`5F5R96EN>F5L=&4@1V5W:71T97(`27-R865L`$%U<W-T
M96QL97(`2W5R<VEV`$ET86QI96X`2F%M86EK80!*86YU87(`2F%P86X`2F%P
M86YI<V-H("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE;@!*=6QI`$IU
M;FD`0FQO8VMS871Z`%IE;G1R:65R96X`0FQO8VMS871Z`$QI;FMS(&%U<W)I
M8VAT96X`4F5C:'1S(&%U<W)I8VAT96X`2V%S86-H<W1A;@!/<FEG:6YA;"!B
M96EB96AA;'1E;C\`2V5N:6$`2V5R8F5R;W,M4V5R=F5R(&AA="!!=71H96YT
M:69I>FEE<G5N9R!Z=7+\8VMG97=I97-E;BX`2V5R;F5L+4YE=6QI;F=E`%-C
M:&S\<W-E;&5R>F5U9W5N9P!&:6YG97)A8F1R=6-K(&1E<R!38VAL_'-S96QS
M`%-C:&S\<W-E;&SD;F=E`%-C:&S\<W-E;'1Y<`!38VAL_'-S96QZ=V5C:P!$
M97(@4V-H;/QS<V5L(&)E9FEN9&5T('-I8V@@8F5R96ET<R!A=68@9&5M(/9F
M9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(N`$MI;F1E<@!+:7)I8F%T:0!$
M96UO:W)A=&ES8VAE(%9O;&MS<F5P=6)L:6,@2V]R96$`4F5P=6)L:6L@2V]R
M96$`2V]R96%N:7-C:"`H155#+4M2*0!+=7=A:70`2VER9VES:7-T86X`06Y?
M<&%S<V5N`%-P<F%C:&4`3&%O<P!,971Z=&4@2.1L9G1E`$QE='IT97,@5FEE
M<G1E;`!,971Z=&4@06MT=6%L:7-I97)U;F<Z`$QE='IT92!!;FUE;&1U;F<Z
M("5S`$QE='IT92!!;FUE;&1U;F<Z("5S('9O;B`E<P!,971Z=&4@06YM96QD
M=6YG.B!.;V-H(&YI90!,971T;&%N9`!'97-E='H`1F]R;6%T`$QE97(@;&%S
M<V5N(&;\<B!K96EN96X@4F%H;65N`$QI8F%N;VX`3&EN:W,`3&EN:V4@W&)E
M<G-C:')I9G0`3&EN:V4@5V5R=&4`3&5S;W1H;P!,:6)E<FEA`$QI8GEE;@!,
M:65C:'1E;G-T96EN`%-P<OQH<F5G96X`3&5I8VAT97(@4F5G96X`1G+\:"!L
M96EC:'1E<B!296=E;@!3<.1T97(@3&5I8VAT97(@4F5G96X`3&5I8VAT92!2
M96=E;G-C:&%U97(`3&5I8VAT97(@4F5G96X@;6ET($=E=VET=&5R`$QE:6-H
M=&5R(%-C:&YE969A;&P`3&5I8VAT92!38VAN965S8VAA=65R`$QI;65R:6-K
M`$QI;FL`3&EN:R!V97)W96ES="!A=68Z`$5M86EL861R97-S92!V97)L:6YK
M96X_`$QI;FMS`$QI;G5X+4=L_&-K<VME:W-E`$QI<W0@+2!"96YU='IE<B!K
M86YN(&1E;B!/<F1N97(@<V5H96X`1&%T96YB86YK96X@86YZ96EG96X`2&EL
M9F5E:6YT<N1G92!A;GIE:6=E;@!486)E;&QE;B!A;GIE:6=E;@!,:7-T96XM
M07)C:&EV`$QI<W1E;BU(:6QF90!,:7-T96XM260`3&ES=&5N+4)E<VET>F5R
M`$QI<W1E;BU!9')E<W-E`$QI<W1E;BU!;FUE;&1U;F<`3&ES=&5N+4%B;65L
M9'5N9P!$87,@06YZ96EG96X@9&5R($)E;G5T>F5R(&ES="!N:6-H="!M]F=L
M:6-H+@!,:71E<F%T=7(`3&ET875E;@!,861E($)I8FQI;W1H96ME;BXN+@!,
M861E+BXN`$QO:V%L92!5:')Z96ET.B``4W!R86-H92!U;F0@6F5I=`!/<G0`
M06YM96QD96X`06)M96QD96X`06YM96QD96%U9F=A8F5N`$1I92!!;FUE;&1U
M;F<@:7-T(&9E:&QG97-C:&QA9V5N+"!W96EL(%-I92!):')E;B!"96YU='IE
M<FYA;65N(&]D97(@26AR(%!A<W-W;W)T(&9A;'-C:"!E:6YG96=E8F5N(&AA
M8F5N+@!!;FUE;&1U;F<@9F5H;&=E<V-H;&%G96XN`$QA;F=E<B!497AT`$QI
M96)E`$YI961R:6<`2VPN(&=R:65C:&ES8VAE($)U8VAS=&%B96X`2VPN(&QA
M=&5I;FES8VAE($)U8VAS=&%B96X`2VPN('+V;6ES8VAE(%IA:&QE;@!,=7AE
M;6)U<F<`34T`34]41`!-4RU43D5&+4%N:&%N9R!E;G1H:65L="!K96EN92!$
M871E;BX`2$E.5T5)4P!-86-A;P!$:64@96AE;6%L:6=E($IU9V]S;&%W:7-C
M:&4@4F5P=6)L:6L@36%Z961O;FEE;@!-861A9V%S:V%R`$UA9VEE`%=E8FUA
M:6P`16UA:6P@061M:6YI<W1R871I;VX`3&EN:R!?86YL96=E;BXN+@!3=&5L
M;&5N(%-I92!S:6-H97(L(&1A<W,@4$5!4B!I;G-T86QL:65R="!I<W0@=6YD
M('-I8V@@:6T@4&9A9"!B969I;F1E="X`17)S=&5L;&4@5F5R>F5I8VAN:7,@
M)7,`36%L87=I`$UA;&%Y<VEA`$UA;&ED:79E;@!-86QI`$UA;'1A`%9E<G=A
M;'1E;B!3:64@9&EE($MA=&5G;W)I96XL(&UI="!D96YE;B!3:64@16QE;65N
M=&4@=6YD($5I;G1RY&=E(&ME;FYZ96EC:&YE;B!K]FYN96XL('-O=VEE(&1I
M92!Z=6=E:/9R:6=E;B!&87)B96XN`$UA<#(T+4MA<G1E`$UA<%%U97-T+4MA
M<G1E`$WD<GH`077?96YA8G-T86YD`$UI="!'96QE<V5N+2]5;F=E;&5S96XM
M4W1A='5S('9E<G-E:&5N`$UI="!A;F1E<F5M(%-T871U<R!V97)S96AE;B`H
M>BY"+B!7:6-H=&EG+T)E86YW;W)T970I`$UA<G-H86QL:6YS96QN`$UA<G1I
M;FEQ=64`6G5G96]R9&YE=&4@1F5L9&5R`$UA=7)E=&%N:65N`$UA=7)I=&EU
M<P!-87AI;6%L(&5R;&%U8G1E<B!+<F5D:70N`$UA>&EM86QE($YA8VAT:6-H
M=&5N=&5I;&4@_&)E<G-C:')I='1E;BX`2/9C:'-T=&5M<&5R871U<B!D97(@
M;&5T>G1E;B`R-"!3='5N9&5N.B``2/9C:'-T=&5M<&5R871U<B!D97(@;&5T
M>G1E;B`V(%-T=6YD96XZ(`!-87AI;6%L92!,Y&YG90!-86D`36%Y;W1T92!)
M<VQA;F0`365D:7II;@!"97-P<F5C:'5N9W-A8G-A9V4`0F5S<')E8VAU;F=S
M+4EN9F]R;6%T:6]N96X`0F5S<')E8VAU;F=S=F]R<V-H;&%G`$)E<W!R96-H
M=6YG<V%N='=O<G0`0F5S<')E8VAU;F=S86MT=6%L:7-I97)U;F<`06YF<F%G
M92!F_'(@0F5S<')E8VAU;F=S86MT=6%L:7-I97)U;F<`36ET9VQI961E<@!-
M96[\;6]D=7,Z`%IE;&QE;B!Z=7-A;6UE;F;\9V5N`$;\9V4@86QL92`E<RYP
M;R!$871E:65N('IU;2!+;VUP96YD:75M(&AI;GIU+BXN`$;\:')E($QO8V%L
M92`E<R!Z=7-A;6UE;BXN+B``1OQG92!D:64@4$\M1&%T96D@9OQR("5S('IU
M(&1E;2!+;VUP96YD:75M(&AI;GIU+BXN`$;\:')E(-QB97)S971Z=6YG96X@
M9OQR(&1A<R`E<RU-;V1U;"!Z=7-A;6UE;BXN+@!.86-H<FEC:'0`1&EE($YA
M8VAR:6-H="!K;VYN=&4@97)F;VQG<F5I8V@@_&)E<G!R_&9T('=E<F1E;B!A
M8F5R(&YI8VAT(&1A<R!:97)T:69I:V%T(&1E<R!!8G-E;F1E<G,N`$YA8VAR
M:6-H="!N:6-H="!M96AR(&?\;'1I9RX`3F%C:')I8VAT96YT>7``365T87(@
M5V5T=&5R`$UE=&%R8FQO8VL@;FEC:'0@=F5R9OQG8F%R+@!-971A<F)L;V-K
M(&YI8VAT('9E<F;\9V)A<BX@1&5T86EL<R!W=7)D96X@9OQR(&1E;B!!9&UI
M;FES=')A=&]R(&UI=&=E;&]G9W0N`$ME:6YE(%9E<F)I;F1U;F<@>G5R($UE
M=&%R1$(N`$UE=&AO9&4`1&EE($UE=&AO9&4@(B5S(B!I<W0@;FEC:'0@9&5F
M:6YI97)T`$UE=')I<V-H`$UE>&EK;P!&]F1E<FEE<G1E(%-T86%T96X@=F]N
M($UI:W)O;F5S:65N`$UI='1E`$UI;65T>7``5&EE9G-T=&5M<&5R871U<B!D
M97(@;&5T>G1E;B`R-"!3='5N9&5N.B``5&EE9G-T=&5M<&5R871U<B!D97(@
M;&5T>G1E;B`V(%-T=6YD96XZ(`!$87,@;6EN:6UA;&4@4&%S<W=O<G1A;'1E
M<B!I<W0@;F]C:"!N:6-H="!A8F=E;&%U9F5N`%-P:65G96QN`%9E<G-C:&EE
M9&5N97,`4$5!4BU086ME="!(5%107U)E<75E<W0@9F5H;'0N`$9E:&QE;F1E
M($MO;F9I9W5R871I;VXN(%-I92!M_'-S96X@9&EE<V4@:F5T>G0@97)Z975G
M96XL('=E;FX@4VEE(&1I92!!;G=E;F1U;F<@=F5R=V5N9&5N(&WV8VAT96XN
M`$9E:&QE;F1E($YA8VAR:6-H=&5N+4E$+@!014%2+5!A:V5T($UA:6P@9F5H
M;'0N`$9E:&QE;F1E(%-I='IU;F=S+4E$+@!-;P!%;6%I;"!-;V)I;`!-Y-]I
M9P#$;F1E<G5N9W-D871U;0!54DP@8F5A<F)E:71E;@!-;V1U;&4`36]D=6QU
M<P!297!U8FQI:R!-;VQD874`36]N86-O`$UO;F=O;&5I`$UO;F%T('5N9"!*
M86AR`$UO;F%T;&EC:`!-;VYT<V5R<F%T`$UO;F1P:&%S96X`36%R;VMK;P#<
M8F5R=VEE9V5N9"!H96ET97(`W&)E<G=I96=E;F0@0F5W]FQK=`#<8F5R=VEE
M9V5N9"!3;VYN:6<`3F%C:"!U;G1E;@!.86-H(&QI;FMS`$YA8V@@<F5C:'1S
M`$YA8V@@;V)E;@!.86-H('5N=&5N`$YA8V@@;V)E;@!-;W-A;6)I:P!!=7-W
M86AL;&ES=&4@:6X@;65H<F5R96X@16)E;F5N`$UE:')F86-H875S=V%H;`!-
M96EN($MO;G1O`$UE:6X@4&]R=&%L`$UE:6X@4&]R=&%L;&%Y;W5T`$)U<FUA
M`$Y%24XL(&EC:"!S=&EM;64@3DE#2%0@>G4`3F%M90!.86UI8FEA`$YA=7)U
M`$%K=&EO;B!B96[V=&EG=`!.97!A;`!.:65D97)L86YD90!.:65D97)LY&YD
M:7-C:&4@06YT:6QL96X`3F5T<V-A<&4M0F%S:7,M55),`$YE='-C87!E+4-!
M+5-P97)R=6YG<RU54DP`3F5T<V-A<&4M0T$M4FEC:'1L:6YI96XM55),`$YE
M='-C87!E+5IE=&EF:6MA='-E<FYE=65R=6YG<RU54DP`3F5T<V-A<&4M4W!E
M<G)U;F=S+5523`!.971S8V%P92U34TPM4V5R=F5R;F%M90!.971S8V%P92U+
M;VUM96YT87(`3F5T<V-A<&4M6F5R=&EF:6MA='1Y<`!.971Z=V5R:P!.:64`
M3F5U:V%L961O;FEE;@!.975E($MA=&5G;W)I90!.975M;VYD`$YE=65R($)E
M;G5T>F5R;F%M92`H;W!T:6]N86PI`$YE=7-E96QA;F0`3F5U97,@4&%S<W=O
M<G0Z`$YE=65S($9E;G-T97(@*%]B;&%N:RD`3F%C:')I8VAT96X`3F5W<V=R
M=7!P96X`5V5I=&5R`$[D8VAS=&4@-"!0:&%S96X`3N1C:'-T92!%:6YS=&5L
M;'5N9V5N`%=E:71E<CX`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3F%C:'1S
M`$YI=64`3F5I;@!+96EN92!+;VYF:6=U<F%T:6]N<V1A=&5N('9E<F;\9V)A
M<BP@=6T@56YT97)S8VAI961E(&%N>G5Z96EG96XN`$ME:6YE(%-T<F%T96=I
M92!Z=6T@17)S=&5L;&5N('9O;B!)4T\M06)B:6QD97)N('9E<F;\9V)A<BX`
M2V5I;F4@0F%T8V@M5F]R;&%G92X`17,@97AI<W1I97)T(&ME:6X@0FQO8VL@
M86X@9&5R(&%N9V5G96)E;F5N(%!O<VET:6]N`$ME:6X@2V%L96YD97)N86UE
M(&;\<B!D:64@34-!3"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME
M:6YE(,1N9&5R=6YG96XN`%5N=&5R:&%L8B!D:65S97(@16)E;F4@:_9N;F5N
M(&ME:6YE('=E:71E<F5N(%5N=&5R<F5C:'1E(&AI;GIU9V5F_&=T('=E<F1E
M;BX`56YT97)H86QB(&1I97-E<B!%8F5N92!K]FYN96X@:V5I;F4@=V5I=&5R
M96X@56YT97)R96-H=&4@:&EN>G5G96;\9W0@=V5R9&5N+@!+96EN($)E9F5H
M;"!A;F=E9V5B96XN`$;\<B`E<R!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO
M;G-I;F9O<FUA=&EO;F5N(&%N9V5G96)E;BX`1OQR(&1E;B!&5%`M5D93+51R
M96EB97(@=W5R9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE
M;B!A;F=E9V5B96XN`$;\<B!D96X@4U%,+59&4RU4<F5I8F5R('=U<F1E;B!K
M96EN92!+;VYF:6=U<F%T:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+@!&
M_'(@9&5N(%-13"U$871E:2U61E,M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N
M9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N(&%N9V5G96)E;BX`2V5I;B!+<F5D
M:70@;65H<B#\8G)I9RX`2V5I;B!%;7!FY&YG97(@86YG96=E8F5N+@!%<R!E
M>&ES=&EE<G0@:V5I;B!%:6YT<F%G(&UI="!D97(@240@(B5S(B!I;B!D97(@
M=7)S<'+\;F=L:6-H96X@2&EL9F5D871E:2X`2V5I;F4@1&%T96D@:&]C:&=E
M;&%D96X`2V5I;F4@26-O;G,@9V5F=6YD96XN`$ME:6X@;&]C86QE(&%N9V5G
M96)E;BX`17,@=W5R9&4@:V5I;B!/<G0@9F5S=&=E;&5G="X`2V5I;B!/<G0@
M86YG96=E8F5N+@!+96EN92!.86-H<FEC:'0@86YG96=E8F5N+@!+96EN($YA
M;64@86YG96=E8F5N+@!+96EN92!.=6UM97(@86YG96=E8F5N+@!+96EN92!A
M;G-T]M]I9V5N($=L_&-K<VME:W-E`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!(
M5%10+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R
M="!F_'(@9&EE($E-05`M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+
M96EN(%!A<W-W;W)T(&;\<B!D:64@2V5R8F5R;W,M075T:&5N=&EF:7II97)U
M;F<@86YG96=E8F5N+@!+96EN(%!A<W-W;W)T(&;\<B!D:64@3$1!4"U!=71H
M96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR(&1I
M92!,;V=I;BU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S
M<W=O<G0@9OQR(&1I92!005-35T0M075T:&5N=&EF:7II97)U;F<@86YG96=E
M8F5N+@!+96EN(%!A<W-W;W)T(&;\<B!D:64@4TU"+4%U=&AE;G1I9FEZ:65R
M=6YG(&%N9V5G96)E;BX`2V5I;B!09F%D('IU;2!/<&5N4U-,+5!R;V=R86UM
M(&%N9V5G96)E;BX@1&%S($]P96Y34TPM4')O9W)A;6T@=VER9"!B96[V=&EG
M="P@=6T@4$M#4RTQ,BU$871E;B!V97)A<F)E:71E;B!Z=2!K]FYN96XN`$ME
M:6YE(&%U<W-T96AE;F1E;B!296=I<W1R:65R=6YG96XN`$ME:6YE(%)A:&UE
M;@!+96EN92!396ET96X`16EN($)A8VME;F0@;F%M96YS("(E<R(@:V]N;G1E
M(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`2V5I;F4@=&5M<&]RY')E<R!697)Z
M96EC:&YI<R!F_'(@9&5N($-A8VAE(&=E9G5N9&5N+@!+96EN($)E;G5T>F5R
M;F%M92!U;F0O;V1E<B!087-S=V]R="!A;F=E8F5N+@!%<R!W=7)D96X@:V5I
M;F4@9_QL=&EG96X@6$U,+41A=&5N('IU<OQC:V=E9V5B96X`2V5I;F4@5V5R
M=&4`2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@9&5R($]R:6=I;F%L:V]N9FEG
M=7)A=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE($EH<F4@2V]N9FEG=7)A
M=&EO;BX`2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@26AR97(@2V]N9FEG=7)A
M=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE($EH<F4@2V]N9FEG=7)A=&EO
M;BX`2V5I;B!496EL;F5H;65R`$ME:6YE<@!+96EN<R`H4W1A;F1A<F0@8F5N
M=71Z96XI`$YO<F1I<V-H("A)4T\M.#@U.2TQ,"D`3F]R9F]L:VEN<V5L`$[V
M<F1L:6-H92!(96UI<W!H97)E`$[V<F1L:6-H92!-87)I86YE;@!.;W)W96=E
M;@!'_&QT:6<@8FES`$?\;'1I9R!A8@!+96EN(%9E<GIE:6-H;FES`$YI8VAT
M(&EM<&QE;65N=&EE<G0N`$YI8VAT(&9E<W1G96QE9W0`3FEC:'0@=6YT97)S
M=/QT>G0N`$YO=&EZ96X`3FEC:'1S(&%N>G5Z96EG96XL(&)I='1E('IU<OQC
M:V=E:&5N+@!(:6YW96ES`$YO=F5M8F5R`%IA:&P`06YZ86AL(&1E<B!:96EC
M:&5N`$%N>F%H;"!D97(@4W!A;'1E;@!!;GIA:&P@9&5R(%IE:6QE;@!+96EN
M92!.=6UM97)N(&;\<B!D:64@5F5R=&5I;&5R;&ES=&4@86YG96=E8F5N+@!/
M2P!/8FIE:W0`3V)J96MT97)S=&5L;&5R`$]B:F5K=&5R<W1E;&QE<G)E8VAT
M90!/:W1A;'IA:&P`3VMT;V)E<@!&:6QT97(@9OQR(&%N<W3VWVEG92!);FAA
M;'1E`$+\<F\`06QT97,@4&%S<W=O<G0Z`$]M86X`3G5R($E-05`M4V5R=F5R
M('5N=&5R<W3\='IE;B!G96UE:6YS86UE($]R9&YE<BX`3G5R(&%N<W3VWVEG
M92!';/QC:W-K96MS90!.=7(@96EN92!%;6%I;"U!9')E<W-E(&5R;&%U8G0N
M`$YU<B!D97(@0F5S:71Z97(@;V1E<B!D97(@4WES=&5M861M:6YI<W1R871O
M<B!K86YN(&1E;B!"97-I='IE<B!O9&5R(&1I92!"97-I='IE<G)E8VAT92#D
M;F1E<FX`26X@;F5U96T@1F5N<W1E<B#V9F9N96X`3W!E;E-33"U&96AL97(Z
M(%-I9VYI97)T92!3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E>'1R86AI
M97)T('=E<F1E;BX`1&EE<V5N($QI;FL@:6X@96EN96T@;F5U96T@1F5N<W1E
M<B#V9F9N96X`0F5T<FEE8G-Y<W1E;0!/<'1I;VYA;&5R(%1E:6QN96AM97(`
M16EN<W1E;&QU;F=E;@!%:6YS=&5L;'5N9V5N(&;\<B`E<P!/<'1I;VYE;CH`
M3G5M;65R:65R=&4@3&ES=&4`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;G-A
M8G1E:6QU;F<`3W)G86YI<VEE<G5N9P!/<FEG:6YA;'9O<FQA9V4@9&5R($%N
M=V5N9'5N9P!/<FEG:6YA;'9O<FQA9V4@:6X@)7,Z`%-O;G-T:6=E`$%N9&5R
M92!);F9O<FUA=&EO;F5N`$)E<VET>F5R<F5C:'1E`%!!32U!=71H96YT:69I
M>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!$:6=I=&%L92!01U`M56YT
M97)S8VAR:69T`%!'4"UV97)S8VAL_'-S96QT92!$871E;@#69F9E;G1L:6-H
M97(@4$=0+5-C:&S\<W-E;`!-:70@4$=0('5N=&5R>F5I8VAN971E+W9E<G-C
M:&S\<W-E;'1E($1A=&5N`%!(4"!#;V1E`%!(4"!3:&5L;`!6;W)M:71T86=S
M(&QE:6-H=&5R(%)E9V5N`$YA8VAM:71T86=S(%-C:&%U97(`3F%C:&UI='1A
M9W,@4V-H;F5E`$YA8VAM:71T86=S(%-C:&YE97-C:&%U97(`3F%C:&UI='1A
M9W,@4V]N;F4`3F%C:&UI='1A9W,@1V5W:71T97(`7U!(4"!3:&5L;`!);FYE
M;F%B<W1A;F0`4&%K:7-T86X`4&%L874`0F5S971Z=&4@4&%LY'-T:6YE;G-I
M<V-H92!'96)I971E`%!A;F%M80!087!U82U.975G=6EN96$`4&%R86=U87D`
M5&5I;'=E:7-E($)E=_9L:W0`4&%S<W=D(&ES="!N:6-H="!V;VQL<W3D;F1I
M9R!K;VYF:6=U<FEE<G0N`%!A<W-W;W)T`%!A<W-W;W)T(&%U9B`E<R!G9>1N
M9&5R="X`1F%L<V-H97,@4&%S<W=O<G0`4&%S<W=D(&MA;FX@9&%S(&%N9V5G
M96)E;F4@4')O9W)A;6T@;FEC:'0@9FEN9&5N+@!087-S=V0@9F5H;&5N(&)E
M;O9T:6=T92!087)A;65T97(N`%!A<W-W9"!F96AL="!D97(@(EII96PB+5!A
M<F%M971E<BX`4&%S<W=D(&ES="!N:6-H="!V;VQL<W3D;F1I9R!K;VYF:6=U
M<FEE<G0`4&%S<W=D(&ES="!N:6-H="!V;VQL<W3D;F1I9R!K;VYF:6=U<FEE
M<G0N`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!2041)55,M075T:&5N=&EF:7II
M97)U;F<@86YG96=E8F5N+@!087-S=V]R="!M:70@0F5S=.1T:6=U;F<`4&%S
M<W=O<G0Z`%!A<W-W;W)T.B``1&EE(%!A<W-W]G)T97(@;?QS<V5N(&=L96EC
M:"!S96EN+@!%:6YF_&=E;@!6;VX@9&5R(%IW:7-C:&5N86)L86=E(&5I;F;\
M9V5N`%!F860`075S<W1E:&5N9&4@4F5G:7-T<FEE<G5N9V5N.@!097)S;VYE
M;@!0<F]Z96YT`%=A<G1U;F=S87)B96ET96X@9'5R8VAF_&AR96X`5V%R='5N
M9W-A<F)E:71E;B!N86-H(&1E<B!!;FUE;&1U;F<@9'5R8VAF_&AR96X_`%)E
M8VAT90!296-H="`B)7,B('=U<F1E(&YI8VAT(&=E;/9S8VAT+@!296-H=&5V
M97)W86QT=6YG`%)E8VAT92!F_'(`4&5R<_9N;&EC:&4@26YF;W)M871I;VYE
M;@!097)U`$AA=7-T:65R90!0:&EL:7!P:6YE;@!496QE9F]N`$9O=&]S`%!I
M=&-A:7)N`%!I>&5L`%!L871T:&5I=&5N`$)I='1E(&ML:6-K96X@4VEE(&EN
M(&5I;F4@6F5L;&4`0FET=&4@8F5S=.1T:6=E;B!3:64L(&1A<W,@4VEE(&1I
M97-E<R!%;&5M96YT(&SV<V-H96X@;?9C:'1E;CH`0FET=&4@8F5TY'1I9V5N
M(%-I92P@9&%S<R!3:64@9&5N($QI;FL@=F]N(&1I97-E;2!%;&5M96YT(&5N
M=&9E<FYE;B!M]F-H=&5N+@!":71T92!E:6YE;B!-;VYA="!U;F0@96EN($IA
M:'(@86YG96)E;BX`0FET=&4@9V5B96X@4VEE(&5I;F5N($YA;65N(&;\<B!D
M:64@;F5U92!+871E9V]R:64@86XZ`$)I='1E(&5I;F4@9_QL=&EG92!)4"U!
M9')E<W-E(&5I;F=E8F5N+@!":71T92!G96)E;B!3:64@96EN(&?\;'1I9V5S
M($1A='5M(&%N.R#\8F5R<'+\9F5N(%-I92!D:64@6F%H;"!D97(@5&%G92!I
M;B!D96T@36]N870N`$)I='1E(&5I;F5N(&?\;'1I9V5N(%IE:71W97)T(&5I
M;F=E8F5N+@!":71T92!G96)E;B!3:64@96EN(&YE=65S(%!A<W-W;W)T(&%N
M`$)I='1E(&=E8F5N(%-I92!E:6YE(%IU<V%M;65N9F%S<W5N9R!):')E<R!0
M<F]B;&5M<R!A;BX`0FET=&4@9V5B96X@4VEE($EH<B!A:W1U96QL97,@4&%S
M<W=O<G0@86X`0FET=&4@9V5B96X@4VEE($EH<F5N($)E;G5T>F5R;F%M96X@
M=6YD($EH<B!087-S=V]R="!A;@!":71T92!L97-E;B!3:64@<VEC:"!D96X@
M9F]L9V5N9&5N(%1E>'0@<V]R9V;D;'1I9R!D=7)C:"X@4VEE($W<4U-%3B!D
M:65S96X@0F5D:6YG=6YG96X@>G5S=&EM;65N+"!U;2!D:65S92!$:65N<W1E
M('IU(&)E;G5T>F5N+@!":71T92!A;&QE($9E:&QE<B!A;B!I,3AN0&QI<W1S
M+FAO<F1E+F]R9R!M96QD96XN`$)I='1E(/QB97)P<OQF96X@4VEE(&1I92!F
M;VQG96YD96X@26YF;W)M871I;VYE;B!U;F0@=^1H;&5N(%-I92!A;G-C:&QI
M9=]E;F0@96EN92!!:W1I;VX@875S(&1E;2!U;G1E<F5N($UE;OPN`$)I='1E
M('?D:&QE;B!3:64@96EN92!!:W1I;VX@875S(&1E;2!-96[\(&%U<RX`0FET
M=&4@9&5N(&YE=65N($MA=&5G;W)I96YA;65N(&5I;F=E8F5N.@!":71T92!B
M97-TY'1I9V5N(%-I92!):'(@;F5U97,@4&%S<W=O<G0`4&]L96X`4&]L:71I
M:P!5;69R86=E;@!0;W)T=6=A;`!0;W-I=&EO;FEE<G5N9R!D:65S92!":6QD
M97,`4&]S:71I;VYI97)U;F<@9&EE<V5R(%1A8F5L;&4`4V5N9&5N(&%N(&1I
M97-E;B!/<F1N97(@*&YI8VAT(&1U<F-H($E-05`I`$YI961E<G-C:&QA9R!I
M;B!D96X@;&5T>G1E;B`E<R!3='5N9&4H;BDZ(`!0<F5F<U]L9&%P.B!$:64@
M8F5N]G1I9W1E($Q$05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD
M96XN`%!R969S7W-E<W-I;VXZ($1I92!B96[V=&EG=&4@4V5S<VEO;BU%<G=E
M:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`3'5F=&1R=6-K`$QU9G1D
M<G5C:R!A=68@4V5E:/9H93H@`$QU9G1D<G5C:SH@`%9O<G-C:&%U`$5I;F4@
M5F]R<V-H874@9&5S($)I;&1E<R!I;B!E:6YE;2!N975E;2!&96YS=&5R(&%N
M>F5I9V5N`%9O:&5R:6=E($5I;G-T96QL=6YG96X`1&]K=6UE;G0@9')U8VME
M;@!0<FEV871E<B!38VAL_'-S96P`4')O8FQE;64`4')O8FQE;6)E<V-H<F5I
M8G5N9P!0<F]J96MT90!.86-H9G)A9V5T97AT`-9F9F5N=&QI8VAE<B!38VAL
M_'-S96P`06QG;W)I=&AM=7,@9&5S(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS
M`$EN9F]R;6%T:6]N96X@>G5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96P`1&%S
M(/9F9F5N=&QI8VAE+W!R:79A=&4@4V-H;/QS<V5L<&%A<B!K;VYN=&4@;FEC
M:'0@97)S=&5L;'0@=V5R9&5N+@!0=65R=&\@4FEC;P!+871A<@!!8F9R86=E
M`-9F9F5N=&QI8VAE<B!24T$@4V-H;/QS<V5L("@E9"!":70I`$%U<W=A:&QK
M;F]P9@!296=E;@!&<OQH(%)E9V5N`%-PY'1E<B!296=E;@!296=E;G-C:&%U
M97(`4V-H;F5E<F5G96X`4F5G96X@:6X@4V-H;F5E(/QB97)G96AE;F0`1VS\
M8VMS:V5K<P!697)HY&QT;FES`$QE<V5N`$YA8VAR:6-H=&5N(&QE<V5N`"5S
M('=I<FML:6-H(&SV<V-H96X_($1I97-E<B!6;W)G86YG(&MA;FX@;FEC:'0@
M<OQC:V?D;F=I9R!G96UA8VAT('=E<F1E;BX`1&%T96X@9&5S($)E;G5T>F5R
M<R`E<R!W:7)K;&EC:"!L]G-C:&5N/R!$:65S97(@5F]R9V%N9R!K86YN(&YI
M8VAT('+\8VMGY&YG:6<@9V5M86-H="!W97)D96XN`$;\:')T(&QE='IT92!!
M:W1I;VX@97)N975T(&%U<P!$>6YA;6ES8VAE($UE;OQE;&5M96YT92!A:W1U
M86QI<VEE<F5N.@!0;W)T86QA;G-I8VAT(&%K='5A;&ES:65R96XZ`%)E9W5L
MY')E<B!!=7-D<G5C:P!697)B:6YD=6YG<RU"<F]W<V5R`$)E;65R:W5N9V5N
M`$9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N(&UE<FME;BX`16YT9F5R;G1E
M(%-E<G9E<@!397)V97)A9')E<W-E("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3H`16YT9F5R;F5N`$)L;V-K(&SV<V-H96X`4W!A;'1E(&SV<V-H
M96X`1F]R;6%T:65R=6YG(&5N=&9E<FYE;@!!=7,@;65I;F5M($MA;&5N9&5R
M(&5N=&9E<FYE;@!086%R(&SV<V-H96X`1V5S<&5I8VAE<G1E<R!3:W)I<'0@
M875S(&1E;2!T96UP;W+D<F5N(%9E<GIE:6-H;FES(&5N=&9E<FYE;BX`16YT
M9F5R;F4`1&EE<V5S($5L96UE;G0@875S(&1E;2!$;VMU;65N="!E;G1F97)N
M96X`0F5N=71Z97(@;/9S8VAE;@!"96YU='IE<B!L]G-C:&5N.B`E<P!!;G1W
M;W)T('9E<G-E;F1E="X`36ET(").:6-H="!U;G1E<G-T_'1Z="(M3F%C:')I
M8VAT(&%N='=O<G1E;BX`36ET($9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N
M(&;\<B!D:64@;N1C:'-T96X@>G=E:2!-;VYA=&4@86YT=V]R=&5N+@!-:70@
M97)F<F%G=&5N($9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N(&%N='=O<G1E
M;BX`06YT=V]R=#H@)7,`06YF<F%G92!K;VYN=&4@;FEC:'0@8F5A;G1W;W)T
M970@=V5R9&5N+B!:=7+\8VMG96=E8F5N97(@1F5H;&5R8V]D93H@`$1E<B!G
M97?\;G-C:'1E($1I96YS="!K;VYN=&4@;FEC:'0@9V5F=6YD96X@=V5R9&5N
M+@`B)7,B('=U<F1E(&EN(&1E<B!+;VYF:6=U<F%T:6]N(&;\<B`E<R!N:6-H
M="!A;F=E9V5B96XN`"(E<R(@=W5R9&4@:6X@9&5R(%9&4RU+;VYF:6=U<F%T
M:6]N(&YI8VAT(&%N9V5G96)E;BX`(B5S(B!W=7)D92!I;B!D97(@2V]N9FEG
M=7)A=&EO;B!N:6-H="!A;F=E9V5B96XN`"=D<FEV97)S)R!I<W0@:6X@9&5R
M($-O;7!O<VET92U+;VYF:6=U<F%T:6]N(&9E:&QE<FAA9G0@:V]N9FEG=7)I
M97)T+@`G<&AP='EP92<@=W5R9&4@:6X@9&5R(%-13"U+;VYF:6=U<F%T:6]N
M(&YI8VAT(&%N9V5G96)E;BX`)W!H<'1Y<&4G('=U<F1E(&EN(&1E<B!344PM
M2V]N9FEG=7)A=&EO;B!N:6-H="!A;F=E9V5B96XN`$YO='=E;F1I9V5S($9E
M;&0`17)F;W)D97)L:6-H97(@5&5I;&YE:&UE<@!:=7+\8VMS971Z96X`4&%S
M<W=O<G0@>G5R_&-K<V5T>F5N`%-E='IE;B!3:64@26AR(%!A<W-W;W)T('IU
M<OQC:P!%<F=E8FYI<W-E`$5R9V5B;FES<V4@*&EN:VPN($AO<F1E*3H`17)G
M96)N:7-S93H`6G5R_&-K('IU($5I;G-T96QL=6YG96X`4NEU;FEO;@!+;VYF
M:6=U<F%T:6]N('IU<OQC:W-E='IE;@!765-)5UE'+45D:71O<B!%:6YS=&5L
M;'5N9V5N`%+D='-E;`!296-H=',`4F5C:'1E(-QB97)S8VAR:69T`%)E8VAT
M92!797)T90!?6F5I;&5N96EG96YS8VAA9G1E;BXN+@!2;VQL90!2=6WD;FEE
M;@!5;2`Q.#"P(&1R96AE;@!.86-H(&QI;FMS(&1R96AE;@!.86-H(')E8VAT
M<R!D<F5H96X`6F5I;&5N96EG96YS8VAA9G1E;@!:96EL96YE:6=E;G-C:&%F
M=&5N`%IE:6QE;CH`4F5G96QN`%)A:&UE;B!Z=VES8VAE;B!A;&QE;B!:96EL
M96X@=6YD(%-P86QT96X`4F%H;65N(&YU<B!Z=VES8VAE;B!3<&%L=&5N`%)A
M:&UE;B!N=7(@>G=I<V-H96X@6F5I;&5N`%-T87)T96X`4G5S<VES8VAE($;V
M<F1E<F%T:6]N`%)U86YD80!3+TU)344@:W)Y=&]G<F%P:&ES8VAE(%5N=&5R
M<V-H<FEF=`!-:70@4R]-24U%('9E<G-C:&S\<W-E;'1E($YA8VAR:6-H=`!3
M05-,+4%U=&AE;G1I9FEZ:65R=6YG(&ES="!N:6-H="!V97)F_&=B87(N`%--
M4RU697)S86YD`%-13"!3:&5L;`!34T@`15)&3TQ'`%-?44P@4VAE;&P`4V$`
M4V%I;G0@2&5L96YA`%-A:6YT($MI='1S('5N9"!.979I<P!386EN="!,=6-I
M80!386EN="!0:65R<F4@=6YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@=6YD
M(&1I92!'<F5N861I;F5N`$=L96EC:&5R(%)A:&UE;B`H7W-E;&8I`%-A;6]A
M`%-A;B!-87)I;F\`4V%O(%1O;64@=6YD(%!R:6YC:7!E`%-A=&5L;&ET96YP
M<F]V:61E<@!3875D:2U!<F%B:65N`%-P96EC:&5R;@`E<R!S<&5I8VAE<FX`
M)R5S)R!S<&5I8VAE<FX`16EN<W1E;&QU;F=E;B!S<&5I8VAE<FX`17)Z975G
M=&4@2V]N9FEG=7)A=&EO;B!A;',@4$A0+5-K<FEP="!I;2!T96UP;W+D<F5N
M(%9E<GIE:6-H;FES($EH<F5S(%-E<G9E<G,@<W!E:6-H97)N+@`E<RU+;VYF
M:6=U<F%T:6]N(&=E<W!E:6-H97)T+@!$87,@06MT=6%L:7-I97)U;F=S<VMR
M:7!T('=U<F1E(&EN("(E<R(@9V5S<&5I8VAE<G0N`%9E<F5I;GIE;'1E($=E
M=VET=&5R`%=I<W-E;G-C:&%F=`!3=6-H90!3=6-H;6%S8VAI;F5N`%-U8VAE
M($AO<F1E+4%N=V5N9'5N9V5N(&EN("5S+BXN`%-U8VAE(&=E='1E>'0@4')O
M9W)A;6UE+BXN`$1A=&5I96X@875S=^1H;&5N`$1A='5M(&%U<W?D:&QE;@!(
M:6YZ=7IU9OQG96YD92!'<G5P<&5N(&%U<W?D:&QE;@!.975E;B!"97-I='IE
M<B!A=7-WY&AL96X`4V5R=F5R(&%U<W?D:&QE;@!(:6YZ=7IU9OQG96YD96X@
M0F5N=71Z97(@875S=^1H;&5N`$QE9V5N(%-I92!A;&QE($1A='5M<VMO;7!O
M;F5N=&5N(&9E<W0N`$]B:F5K="!A=7-WY&AL96X`5^1H;&5N(%-I92!D:64@
M8F5N]G1I9W1E;B!:96EC:&5N(&%U<R!D96X@:F5W96EL:6=E;B!&96QD97)N
M(&%U<RX@1&%N;B!K]FYN96X@4VEE(&1I97-E(&%U<R!D96T@5&5X=&9E;&0@
M:V]P:65R96X@=6YD(&EN($EH<F4@3F%C:')I8VAT(&5I;F;\9V5N+@!7Y&AL
M96X@4VEE(&1A<R!$871U;7-T<F5N;GIE:6-H96XZ`%?D:&QE;B!3:64@9&%S
M($1A='5M<V9O<FUA=#H`5^1H;&5N(%-I92!D:64@261E;G1I=.1T+"!D:64@
M4VEE(.1N9&5R;B!M]F-H=&5N.@!7Y&AL96X@4VEE(&1A<R!:96ET=')E;FYZ
M96EC:&5N.@!7Y&AL96X@4VEE(&1A<R!:96ET9F]R;6%T.@!7Y&AL96X@4VEE
M('IW96D@>G5S86UM96YG96CV<FEG92!&96QD97(@875S+@!7Y&AL96X@4VEE
M(&5I;B!&87)B<V-H96UA+@!7Y&AL96X@4VEE($EH<F4@8F5V;W)Z=6=T92!3
M<')A8VAE.@!!:W1U96QL92!);F9O<FUA=&EO;F5N('9E<G-E;F1E;@!0<F]B
M;&5M8F5R:6-H="!A8G-C:&EC:V5N`%--4R!V97)S8VAI8VME;@!396YE9V%L
M`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:65N('5N9"!-;VYT96YE9W)O`%-E
M<FEE;FYU;6UE<@!397)V97)D871E;B!U;F?\;'1I9R!O9&5R(&YI8VAT('9E
M<F;\9V)A<BX`4V5S<VEO;BU)1"!A8F=E;&%U9F5N+@!!=7-W86AL+5-A='H`
M3&5G96X@4VEE(&1I92!%:6YS=&5L;'5N9V5N(&9E<W0L(&1I92!E<R!):&YE
M;B!E<FQA=6)E;B!):'(@4&%S<W=O<G0@>G5R_&-K>G5S971Z96XL(&9A;&QS
M('-I92!E<R!E:6YM86P@=F5R9V5S<V5N('-O;&QT96XN`$QE9V5N(%-I92!E
M;G1F97)N=&4@4V5R=F5R(&9E<W0L(&%U9B!D:64@4VEE('9O;B!):')E;2!0
M;W)T86P@875S('IU9W)E:69E;B!M]F-H=&5N+@!7Y&AL96X@4VEE($EH<F4@
M8F5V;W)Z=6=T92!3<')A8VAE+"!:96ET>F]N92!U;F0@1&%T=6US96EN<W1E
M;&QU;F=E;BX`3&5G96X@4VEE(&1A<R!D:64@4W1A<G1A;G=E;F1U;F<L(&1A
M<R!&87)B<V-H96UA+"!D:64@4V5I=&5N86MT=6%L:7-I97)U;F<@=6YD(&%N
M9&5R92!!;GIE:6=E96EN<W1E;&QU;F=E;B!F97-T+@!+;VYF:6=U<F%T:6]N
M`$%K='5A;&ES:65R=6YG<W-K<FEP=&4@<VEN9"!V97)F_&=B87(`365H<F5R
M92!P87-S96YD92!/<G1E(&UI="!D:65S96T@4&%R86UE=&5R.B``4V5Y8VAE
M;&QE;@!%:6YK875F`$MU<GIE(%IU<V%M;65N9F%S<W5N9P!3;VQL96X@5&%S
M=&5N:V]M8FEN871I;VYE;B!F_'(@9&EE(&UE:7-T96X@3&EN:W,@86MT:79I
M97)T('=E<F1E;C\`6F5I9V5N`%5N=&5R<V-H:65D92!Z=VES8VAE;B!D97(@
M86MT=65L;&5N('5N9"!D97(@9V5R861E(&5R>F5U9W1E;B!+;VYF:6=U<F%T
M:6]N(&%N>F5I9V5N+@!!;GIE:6=E;BP@=V%N;B!D:64@;&5T>G1E($%N;65L
M9'5N9R!E<F9O;&=T(&ES=#\`17)H86QT96X@9&5S($]R:6=I;F%L<R!E<FWV
M9VQI8VAE;@!!=7-WY&AL97(@86YZ96EG96X`5V5R:WIE=6=L96ES=&4@9OQR
M(%1A8F5L;&5N(&%N>F5I9V5N/P!$87,@)7,M365N_"!A=68@9&5R(&QI;FME
M;B!396ET92!A;GIE:6=E;C\`1&EA;&]G(&;\<B!486)E;&QE;GIE;&QE;F5I
M9V5N<V-H869T96X@86YZ96EG96X`1&EA;&]G(&;\<B!486)E;&QE;F5I9V5N
M<V-H869T96X@86YZ96EG96X`1&EA;&]G(&;\<B!486)E;&QE;GIE:6QE;F5I
M9V5N<V-H869T96X@86YZ96EG96X`1&EA;&]G(&;\<B!":6QD96EG96YS8VAA
M9G1E;B!A;GIE:6=E;@!(;V-H;&%D96X@97)M]F=L:6-H96X`4V-H875E<@!&
M<OQH(%-C:&%U97(`4W#D=&5R(%-C:&%U97(`4V-H875E<B!I;B!D97(@56UG
M96)U;F<`5F5R:VQE:6YE<FX`5F5R:VQE:6YE<FX@;V1E<B!V97)S8VAI96)E
M;B!3:64@97)S="!D:64@8F5N86-H8F%R=&5N($)L]F-K90!3:65R<F$@3&5O
M;F4`4F5G:7-T<FEE<F5N`$YO8V@@:V5I;B!:=6=A;F<_($AI97(@<F5G:7-T
M<FEE<F5N+@!3:6=N871U<@!3:6=N871U<F%L9V]R:71H;75S`%-I;F=A<'5R
M`$=R]M]E`%=A<G1U;F=S87)B96ET96X@_&)E<G-P<FEN9V5N`-QB97)S<')U
M;F=E;BXN+@!3;&]W86ME:0!3;&]W96YI96X`4V-H;F5E`%-C:&YE97-C:&%U
M97(`4V-H;F5E<V-H875E<@!&<OQH(%-C:&YE97-C:&%U97(`4W#D=&5R(%-C
M:&YE97-C:&%U97(`4V-H;F5E:/9H93H@`%-C:&YE96UE;F=E(&%L<R!787-S
M97(Z(`!3;VQO;6]N:6YS96QN`%-O;6%L:65N`$QI961E<B`F($=E9&EC:'1E
M`$%U<W=A:&P@9&5R(%-O<G1I97)R96EH96YF;VQG90!5<G-P<G5N9W-A9')E
M<W-E`%/\9&%F<FEK80!3_&1E=7)O<.1I<V-H("A)4T\M.#@U.2TS*0!3_&1G
M96]R9VEE;B!U;F0@9&EE(%/\9&QI8VAE;B!386YD=VEC:&EN<V5L;@!3_&1L
M:6-H92!(96UI<W!H97)E`$%B<W1A;F0@>G=I<V-H96X@875F96EN86YD97(@
M9F]L9V5N9&5N(%IE;&QE;@!!8G-T86YD('IW:7-C:&5N($EN:&%L="!U;F0@
M4F%H;65N('9O;B!:96QL96X`06)S=&%N9&AA;'1E<@!!8G-T86YD`$%B<W3D
M;F1E`%-P86YI96X`4W!A;0!3;VYD97)Z96EC:&5N+45I;F=A8F4`6F5L;&4@
M=&5I;&5N`%-P86QT92!T96EL96X`6F5I;&4@=&5I;&5N`%-P;W)T`%-R:2!,
M86YK80!3=&%N9&%R9`!3=&%R(%1R96L`0F5G:6YN`%-T87)T:F%H<@!"=6YD
M97-S=&%A="!O9&5R(%!R;W9I;GH`4W1A='5S`%-T871U<R!F_'(@3&]C86QE
M("5S+BXN(`!3<&5I8VAE<F9O<FUA=`!3=')AWV4`1'5R8VAG97-T<FEC:&5N
M`%IE:6-H96YL:7-T90!$;VUA:6X@875S(&1E<B!!9')E<W-E(&5N=&9E<FYE
M;@!3=&EL(%M#4U-=`%-O`%5N=&5R=F5R>F5I8VAN:7,@(B5S(B!N:6-H="!G
M969U;F1E;BX`0F5T<F5F9@!!8G-C:&EC:V5N`$1I92!!;F9R86=E("(E<R(@
M>G5M(%-Y<W1E;2!H:6YZ=7IU9OQG96X@=W5R9&4@86)G97-C:&EC:W0N(%-I
M92!K]FYN96X@<VEC:"!N;V-H(&YI8VAT(&%N;65L9&5N+"!B:7,@26AR92!!
M;F9R86=E(&)E<W3D=&EG="!W;W)D96X@:7-T+@!4:65F9V5S=&5L;'0`17)F
M;VQG`"(E<R(@=W5R9&4@97)F;VQG<F5I8V@@:&EN>G5G96;\9W0N`$1A=&5N
M(&1E<R!"96YU='IE<G,@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H
M="X`(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="X`(B5S(B!W=7)D
M92!E<F9O;&=R96EC:"!G96SV<V-H="X`2V]N9FEG=7)A=&EO;B!E<F9O;&=R
M96EC:"!Z=7+\8VMG97-E='IT+B!396ET92!N974@;&%D96XL('5M(&1I92#$
M;F1E<G5N9V5N(&%N>G5Z96EG96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO
M;B!E<F9O;&=R96EC:"!G97-P96EC:&5R="X`0F%C:W5P(&1E<B!+;VYF:6=U
M<F%T:6]N("5S(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+@`B)7,B('=U<F1E
M(&5R9F]L9W)E:6-H(&%K='5A;&ES:65R=``E<R!W=7)D92!E<F9O;&=R96EC
M:"!G97-P96EC:&5R=`!3=61A;@!:=7-A;6UE;F9A<W-U;F<`4V]N;F5N875F
M9V%N9P!3;VYN96YU;G1E<F=A;F<`4V]N;FEG`%-O;FYE;F%U9F=A;F<`4V]N
M;F5N875F+W5N=&5R9V%N9P!3;VYN96YA=69G86YG.B``4V]N;F5N=6YT97)G
M86YG`%-O;FYE;G5N=&5R9V%N9SH@`$AO8VAG97-T96QL=`!3=7!P;W)T`%-U
M<FEN86T`3F%C:&YA;64`4W9A;&)A<F0@=6YD($IA;B!-87EE;@!3=V%S:6QA
M;F0`4V-H=V5D96X`4V-H=V5I>@!&;W)M871F96AL97(@:6X@4W5C:&)E9W)I
M9F9E;@!!<F%B:7-C:&4@4F5P=6)L:6L@4WER:65N`$=E=VET=&5R`$=E=VET
M=&5R('5N9"!7:6YD:6<`1V5W:71T97(`1G+\:"!'97=I='1E<@!44U8M1&%T
M96D`5&%B96QL90!486)E;&QE;F5I9V5N<V-H869T96X`5&%B96QL96YE:6=E
M;G-C:&%F=&5N`%1A:7=A;@!486EW86XL(&-H:6YE<VES8VAE(%!R;W9I;GH`
M5&%D<V-H:6MI<W1A;@!697)E:6YI9W1E(%)E<'5B;&EK(%1A;G-A;FEA`%II
M96PZ`$%U9F=A8F5N`%1E;&5F;VYN=6UM97(`5&5M<&5R871U<B!D97(@;&5T
M>G1E;B!3='5N9&4Z(`!496UP97)A='5R`%1E;7!E<F%T=7(Z(`!6;W)L86=E
M("(E<R(@;FEC:'0@9V5F=6YD96XN`%9O<FQA9V5N=F5R=V%L='5N9P!!;F9R
M86=E('9O<FSD=69I9R!A;FYE:&UE;@!6;W)LY'5F:6<@86YG96YO;6UE;@!4
M97AT`$YU<B!497AT`$%U<W)I8VAT=6YG`%1E>'0@3V)E;@!$;P!4:&%I;.1N
M9&ES8V@@*%1)4RTV,C`I`%1H86EL86YD`$1A;FME(&;\<B!D:64@0F5N=71Z
M=6YG(&1I97-E<R!3>7-T96US+@!$:64@)7,@2&EL9F5D871E:2!F_'(@)7,@
M97AI<W1I97)T(&YO8V@@;FEC:'0N($5R<W1E;&QE(&5I;F4@;F5U92X`1&EE
M($944"U%>'1E;G-I;VX@:7-T(&YI8VAT('9E<F;\9V)A<BX`1&EE($AO<F1E
M+TMO;&%B($EN=&5G<F%T:6]N<V9U;FMT:6]N96X@=6YT97)S=/QT>F5N("(E
M<R(@;FEC:'0`1&EE($UA:6YT96YA;F-E.CH@2VQA<W-E(&MO;FYT92!N:6-H
M="!G96QA9&5N('=E<F1E;@!$87,@16EN<W1E;&QU;F=E;BU&96YS=&5R(&ES
M="!G97-C:&QO<W-E;B!W;W)D96XN($%B8G)U8V@N`$1E<B!!9&UI;FES=')A
M=&]R(&UU<W,@96EN('!E<FUA;F5N=&5S(%)E8VAT92U"86-K96YD(&5I;G)I
M8VAT96XL('=E;FX@4VEE(&1I92!296-H=&5V97)W86QT=6YG(&YU='IE;B!M
M]F-H=&5N+@!.=7(@=6YT96X`1&EE($MA;&5N9&5R9&%T96X@<VEN9"!U;F?\
M;'1I9P!$:64@240M3G5M;65R(&1E<R!+;VYT86MT<R!W=7)D92!N:6-H="!A
M;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92!I;B!D97(@1&%T96YB86YK
M(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`1&5R($MO;G1A:W0@=W5R9&4@97)F
M;VQG<F5I8V@@26AR96T@061R97-S8G5C:"!H:6YZ=6=E9OQG="X`1&5R(%!'
M4"U3:6=N871U<F)L;V-K('=I<F0@8F5N]G1I9W0L('5M(&1I92!U;G1E<GIE
M:6-H;F5T92!.86-H<FEC:'0@>G4@_&)E<G!R_&9E;BX`1&EE($E$+4YU;6UE
M<B!D97(@5F5R=&5I;&5R;&ES=&4@=W5R9&4@;FEC:'0@86YG96)E;BP@=V%R
M(&QE97(@;V1E<B!K;VYN=&4@:6X@9&5R($1A=&5N8F%N:R!N:6-H="!G969U
M;F1E;B!W97)D96XN`$1I92!697)T96EL97)L:7-T92!W=7)D92!N:6-H="!A
M;F=E9V5B96XN`$1I92!697)S8VAL_'-S96QU;F=S9G5N:W1I;VYE;B!B96[V
M=&EG96X@96EN92!S:6-H97)E(%-E<G9E<G9E<F)I;F1U;F<N`$1E<B!497)M
M:6X@=W5R9&4@26AR96T@2V%L96YD97(@:&EN>G5G96;\9W0N`$1I92!$871E
M:2`E<R!S;VQL=&4@96EN96X@)7,@16EN=')A9R!E;G1H86QT96XN`$1I92!$
M871E:2`E<R!S;VQL=&4@96EN:6=E("5S($5I;G1RY&=E(&5N=&AA;'1E;BX`
M1&EE($1A=&5I(&MA;FX@;FEC:'0@875F('-I8V@@<V5L8G-T(&MO<&EE<G0@
M=V5R9&5N+@!$:64@1&%T96D@96YT:&EE;'0@:V5I;F4@1&%T96XN`$AI97(@
M<VEN9"!D:64@2V]P9F5I;G1RY&=E(&;\<B!D:65S92!M97-S86=E+W)F8S@R
M,B!.86-H<FEC:'0N`$1E<B!6;VQL8FEL9&UO9'5S('9E<G5R<V%C:'0@875F
M($=R=6YD('9O;B!&96AL97)N(&EM($EN=&5R;F5T($5X<&QO<F5R(&)E:V%N
M;G1E<FUAWV5N(%!R;V)L96UE(&UI="!D:65S96T@0G)O=W-E<BP@9&EE('=I
M<B!N:6-H="!U;6=E:&5N(&OV;FYE;BX@56YT97(@56US=.1N9&5N(&5R:&%L
M=&5N(%-I92!E:6YE(&9E:&QE<FAA9G1E($%N>F5I9V4L(&9E:&QE;B!%9&ET
M;W)F=6YK=&EO;F5N+"!O9&5R(&1E<B!"<F]W<V5R('-T_')Z="!A8BX@075F
M(&5I;F5M(%=I;F1O=R`Y>"!3>7-T96T@=V5R9&5N(%-I92!V97)M=71L:6-H
M(&5I;F4@)T%L;&=E;65I;F4@4V-H=71Z=F5R;&5T>G5N9R<@97)H86QT96X@
M=6YD(&W\<W-E;B!D96X@4F5C:&YE<B!N974@<W1A<G1E;BY<;EQN4VEE('=U
M<F1E;B!G97=A<FYT+B!":71T92!D<OQC:V5N(%-I92!A=68@3TLL('=E;FX@
M4VEE(&YO8V@@:6UM97(@9&5N(%9O;&QB:6QD;6]D=7,@=F5R=V5N9&5N(&WV
M8VAT96XN`$1I92!(:6QF961A=&5I("5S(&)E9VEN;G0@;FEC:'0@;6ET(#P_
M>&UL`$1I92!)9&5N=&ETY'0@(B5S(B!W=7)D92!G96SV<V-H="X`3G5R(&QI
M;FMS`$1E<B!/<G0@9&5S($=N=5!'+5!R;V=R86UM<R!M=7-S(&1E<B!#<GEP
M=%]P9W`Z.B!+;&%S<V4@_&)E<F=E8F5N('=E<F1E;BX`1&EE($YA8VAR:6-H
M="!M:70@9&5M($)E=')E9F8@(B4S)',B+"!D:64@86T@)3$D<R!A;B`E,B1S
M(&=E<V-H:6-K="!W=7)D92P@:7-T(&%N9V5Z96EG="!W;W)D96XN"D1A<R!H
M96G?="!N:6-H="P@9&%S<R!D:64@3F%C:')I8VAT(&%U8V@@9V5L97-E;B!O
M9&5R('9E<G-T86YD96X@=W5R9&4N`$YA;64@9OQR(&1E;B!,:6YK('IU<B!.
M86-H<FEC:'1E;F5R<W1E;&QU;F<`1&%S($]P96Y34TPM36]D=6P@=VER9"!F
M_'(@9&EE($AO<F1E7T-R>7!T7W-M:6UE.CH@2VQA<W-E(&)E;O9T:6=T+@!$
M:64@0F5N=71Z97)E:6YS=&5L;'5N9R`B)7,B(&MO;FYT92!N:6-H="!G97-P
M96EC:&5R="!W97)D96XL('=E:6P@:6AR92!$871E;B!D:64@;6%X:6UA;"!E
M<FQA=6)T92!'<O;?92#\8F5R<V-H<F5I=&5N`$1A<R!0<F]G<F%M;2!F_'(@
M9&EE($%N>F5I9V4@9&EE<V5S($1A=&5I='EP<R`H)7,I('=U<F1E(&YI8VAT
M(&=E9G5N9&5N+@!.=7(@;&EN:W,@=6YD(')E8VAT<P!.=7(@<F5C:'1S`$1E
M<B!397)V97(@(B5S(B!W=7)D92!E;G1F97)N="X`1&5R(%-E<G9E<B`B)7,B
M('=U<F1E(&=E<W!E:6-H97)T+@!$:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E
M('9O;B`E<R!W=7)D92!E;G1F97)N="X`1&EE(&%N9V5G96)E;F4@6F5I;&4@
M97AI<W1I97)T(&YI8VAT+@!$:64@075F9V%B92!W=7)D92!Z=2!):')E<B!!
M=69G86)E;FQI<W1E(&AI;GIU9V5F_&=T+@!$:64@=&5M<&]RY')E($1A=&5I
M("(E<R(@97AI<W1I97)T(&YI8VAT+@!.=7(@;V)E;B!U;F0@=6YT96X`3G5R
M(&]B96X`1&EE(&AO8VAG96QA9&5N96X@1&%T96X@<VEN9"!N86-H(&1E;2!L
M971Z=&5N(%-C:')I='0@=F5R;&]R96X@9V5G86YG96XN`$1I92!H;V-H9V5L
M861E;F4@1&%T96D@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`
M1&EE($9R96DO1V5B=6-H="U);F9O<FUA=&EO;B!D97,@0F5N=71Z97)S('=U
M<F1E(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+@!$97(@=V5A=&AE<BYC;VT@
M0FQO8VL@:7-T(&YI8VAT('9E<F;\9V)A<BX`5&AE;65N+59E<GIE:6-H;FES
M("(E<R(@;FEC:'0@9V5F=6YD96XN`$5S('-I;F0@:V5I;F4@16EN<W1E;&QU
M;F=E;B!V97)F_&=B87(N`$5S(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@3F%C
M:')I8VAT96YT96EL92X`1&EE<V5S($9E;&0@96YT:.1L="!Z=2!V:65L92!:
M96EC:&5N+B!3:64@:&%B96X@)7,@6F5I8VAE;B!A;F=E9V5B96X[(%-I92!M
M_'-S96X@=V5N:6=E<B!A;',@)7,@86YG96)E;BX`17,@97AI<W1I97)T(&YO
M8V@@:V5I;F4@2&EL9F5D871E:2!F_'(@)7,N`$)E:6T@2&EN>G5F_&=E;B!V
M;VX@(B5S(B!Z=6T@4WES=&5M(&ES="!E:6X@4')O8FQE;2!A=69G971R971E
M;CH@)7,`0F5I;2!,]G-C:&5N(&1E<B!$871E;B!V;VX@0F5N=71Z97(@(B5S
M(B!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ(`!"96EM($SV<V-H96X@
M=F]N("(E<R(@875S(&1E;2!3>7-T96T@:7-T(&5I;B!0<F]B;&5M(&%U9F=E
M=')E=&5N.B``0F5I;2!!:W1U86QI<VEE<F5N('9O;B`B)7,B(&ES="!E:6X@
M4')O8FQE;2!A=69G971R971E;CH@)7,`0F5I;2!(;V-H;&%D96X@9&5R($1A
M=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W=7)D92!N:6-H
M="!H;V-H9V5L861E;BX`0F5I;2!(;V-H;&%D96X@9&5R($1A=&5I(&ES="!E
M:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W87(@9W+VWV5R(&%L<R!D:64@
M;6%X:6UA;"!E<FQA=6)T92!'<O;?92`H)60@0GET97,I+@!"96EM($AO8VAL
M861E;B!D97(@1&%T96D@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN("5S
M('=U<F1E(&YU<B!T96EL=V5I<V4@:&]C:&=E;&%D96XN`$)E:6T@06YZ96EG
M96X@9&EE<V5S($YA8VAR:6-H=&5N=&5I;',@:7-T(&5I;B!&96AL97(@875F
M9V5T<F5T96XN`$)E:6T@26UP;W)T:65R96X@9&5R($MO;G1A:W1D871E;B!I
M<W0@96EN($9E:&QE<B!A=69G971R971E;BX`0F5I;2!);7!O<G1I97)E;B!D
M97,@5&5R;6EN<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;CH@)7,N`$)E
M:6T@26UP;W)T:65R96X@9&5R(&E#86QE;F1A<B!$871E;B!I<W0@96EN($9E
M:&QE<B!A=69G971R971E;BX`0F5I;2!);7!O<G1I97)E;B!D97(@075F9V%B
M92!I<W0@96EN($9E:&QE<B!A=69G971R971E;CH@)7,N`$)E:6T@26UP;W)T
M:65R96X@9&5R($9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N(&ES="!E:6X@
M1F5H;&5R(&%U9F=E=')E=&5N.B`E<RX`1&%S($MO;F9I9W5R871I;VYS+49O
M<FUU;&%R(&5N=&AI96QT(&5I;F5N($9E:&QE<BX@5FEE;&QE:6-H="!H86)E
M;B!3:64@96EN(%!F;&EC:'1F96QD(&QE97(@9V5L87-S96XN`$)E:6T@UF9F
M;F5N(&1E<B!$871E:2`E<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@
M5F5R<W5C:&5N(%-I92P@=')A;G-L871I;VXN<&AP(&UI="!D96T@+60@4V-H
M86QT97(@875S>G5F_&AR96X@=6YD(&%C:'1E;B!3:64@875F($9E:&QE<FUE
M;&1U;F=E;B!D97,@6$U,+5!A<G-E<G,N`$)E:6T@075S9OQH<F5N(&1E<B!A
M;F=E9V5B96YE;B!!9')E<W-B=6-H9G5N:W1I;VX@:7-T(&5I;B!&96AL97(@
M875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO
M8V@@96EN;6%L+@!"96D@9&5R($%K='5A;&ES:65R=6YG(&1E<B!+;VYT86MT
M9&5T86EL<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET=&4@=F5R
M<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`$)E:2!D97(@06MT
M=6%L:7-I97)U;F<@9&5R(%9E<G1E:6QE<FQI<W1E(&ES="!E:6X@1F5H;&5R
M(&%U9F=E=')E=&5N+B!":71T92!V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N
M;V-H(&5I;FUA;"X`1&EE<V5R($E-05`M4V5R=F5R('5N=&5R<W3\='IT(&ME
M:6YE(&=E;65I;G-A;65N($]R9&YE<BX`1&EE<V4@06MT:6]N('=I<F0@;FEC
M:'0@=6YT97)S=/QT>G0N`$1I97-E($%K=&EO;B!I<W0@;F]C:"!N:6-H="!I
M;7!L96UE;G1I97)T+@!$:65S('-C:&5I;G0@:V5I;B!G_&QT:6=E<R!205(M
M07)C:&EV('IU('-E:6XN`$1I97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%I)
M4"U!<F-H:78@>G4@<V5I;BX`1&EE<R!S8VAE:6YT(&ME:6YE(&?\;'1I9V4@
M2V%R=&5N;G5M;65R('IU('-E:6XN`$1I97-E<B!4<F5I8F5R(&5R;&%U8G0@
M9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D96X@0VQI
M8VMA=&5L;"U'871E=V%Y("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&UI="!(
M:6QF92!D97(@2%144"U!4$DN`$1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S
M(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D96X@<VUS,FUA
M:6PM1V%T97=A>2`H:'1T<#HO+W-M<S)M86EL+F-O;2D@;6ET($AI;&9E(&1E
M<B!(5%10+4%022X`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H
M:6-K96X@=F]N($YA8VAR:6-H=&5N('!E<B!33510(&1U<F-H(&1E;B!6;V1A
M9F]N92U)=&%L:65N+4=A=&5W87D@875S<V-H;&EEWVQI8V@@86X@5F]D869O
M;F4M3G5M;65R;BX@1&%F_'(@=VER9"!E:6X@16UA:6QK;VYT;R!B96D@5F]D
M869O;F4@271A;&EE;B`H:'1T<#HO+W=W=RXQ.3`N:70I(&)E;O9T:6=T+@!$
M:65S97,@1F5L9"!I<W0@;F]T=V5N9&EG+@!$:65S97,@1F5L9"!D87)F(&YU
M<B!G86YZ92!:86AL96X@96YT:&%L=&5N+@!$:65S97,@1F5L9"!D87)F(&YU
M<B!:86AL96X@=6YD(&5I;F5N(%!U;FMT(&5N=&AA;'1E;BX`1&EE<V5S($9E
M;&0@9&%R9B!N=7(@3VMT86QZ86AL96X@96YT:&%L=&5N+@!$:65S97,@1F5L
M9"!M=7-S(&5I;F4@:V]M;6$M(&]D97(@;&5E<GIE:6-H96YG971R96YN=&4@
M3&ES=&4@=F]N(&=A;GIE;B!:86AL96X@96YT:&%L=&5N`$1I97-E<R!&96QD
M(&UU<W,@96EN92!G_&QT:6=E(%IA:&P@96YT:&%L=&5N+@!$:65S97,@1F5L
M9"!M=7-S(&5I;F5N($9A<F)W97)T(&EM(&AE>&%D97II;6%L96X@4D="+49O
M<FUA="!E;G1H86QT96XL('HN($(N("<C,3(S-&%F)RX`1&EE<V5S($9O<FUU
M;&%R('=U<F1E(&)E<F5I=',@=F5R87)B96ET970N`$1I97,@:7-T("5S+@!$
M:64@:7-T(&5I;B!+;VQA8BU'<F]U<'=A<F4M3V)J96MT+B!5;2!D:65S97,@
M3V)J96MT(&%N>G5Z96EG96XL(&)E;O9T:6=E;B!3:64@96EN($5M86EL<')O
M9W)A;6TL(&1A<R!D87,@2V]L86(M1W)O=7!W87)E+49O<FUA="!U;G1E<G-T
M_'1Z="X@16EN92!,:7-T92!S;VQC:&5R(%!R;V=R86UM92!F:6YD96X@4VEE
M('5N=&5R("5S`$1I97-E($YA8VAR:6-H="!W=7)D92!I;B!E:6YE;2!:96EC
M:&5N<V%T>B`H)7,I(&5R<W1E;&QT+"!D97(@;FEC:'0@26AR96T@96EG96YE
M;B!E;G1S<')I8VAT+@!$:65S92!:86AL(&UU<W,@,2!O9&5R(&=R]M]E<B!S
M96EN+@!$:65S97,@4VMR:7!T(&UU<W,@=F]N(&1E<B!+;VUM86YD;WIE:6QE
M(&%U<V=E9OQH<G0@=V5R9&5N+@!$:65S97(@4V5R=F5R(&MA;FX@6DE0+2!U
M;F0@1UI)4"U$871E:6X@;FEC:'0@96YT<&%C:V5N+@!$:65S97,@4WES=&5M
M(&ES="!Z=7(@6F5I="!D96%K=&EV:65R="X`1&EE<V5R(%=E<G0@;75S<R!E
M:6YE(%IA:&P@<V5I;BX`1&EE<V5S($9E;G-T97(@;75S<R!V;VX@96EN96T@
M16EN<W1E;&QU;F=E;BU&96YS=&5R(&=E]F9F;F5T('=E<F1E;@!$;VYN97(`
M5&EC:V5T<P!:96ET`%IE:71E<F9A<W-U;F<`6F5I=&9O<FUA=`!:96ET875S
M=V%H;`!4:6UO<BU,97-T90!4:71E;`!4:71E;"`H5&]O;'1I<"DZ`$%N`$AA
M;'1E;B!3:64@8F5I;2!+;&EC:V5N(%-T<F<@8GIW+B`H4$,I($-O;6UA;F0@
M*$UA8RD@9V5D<OQC:W0L('5M(&UE:')E<F4@16EN='+D9V4@875S>G5WY&AL
M96XN`$AE=71E`%IU($A434PM475E;&QC;V1E('5M<V-H86QT96X`5&]G;P!4
M;VME;&%U`$UO<F=E;@!4;VYG80!/8F5N`,1UWV5R<W1E<B!286AM96X@*%]T
M;W`I`-QB97)S971Z=`#<8F5R<V5T>G5N9V5N`%1R:6YI9&%D('5N9"!4;V)A
M9V\`5V%H<B!O9&5R(&9A;'-C:`!$:0!4=6YE<VEE;@!4_')K96D`5/QR:VES
M8V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<RT@=6YD($-A:6-O
M<VEN<V5L;@!4=79A;'4`26AR92!!=7-W86AL.B``558M26YD97@Z(`!(;VUE
M<&%G90!54DP@26AR97,@4VMR:7!T<R!F_'(@9&5N(%9E<G-A;F1S=&%T=7-B
M97)I8VAT`$%D<F5S<V4Z`%5G86YD80!5:W)A:6YE`$%U9B!D87,@5D93+59E
M<GIE:6-H;FES(&MO;FYT92!N:6-H="!Z=6=E9W)I9F9E;B!W97)D96XN`$1I
M92!Z=7/D='IL:6-H96X@0F5N=71Z97)I;F9O<FUA=&EO;F5N(&MO;FYT96X@
M8F5I(&1E<B!296=I<W1R:65R=6YG(&YI8VAT(&AI;GIU9OQG="!W97)D96XN
M`$1I92!:=6=R:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`B)7,B(&MO
M;FYT96X@;FEC:'0@9V7D;F1E<G0@=V5R9&5N+@!$:64@6G5G<FEF9G-R96-H
M=&4@9OQR(&1I92!61E,M1&%T96D@)7,O)7,@:V]N;G1E;B!N:6-H="!G9>1N
M9&5R="!W97)D96XN`$5S(&MA;FX@;FEC:'0@:6X@5F5R>F5I8VAN:7,@)7,@
M9V5W96-H<V5L="!W97)D96XN`%9E<F)I;F1U;F<@>G5M(%-13"!397)V97(@
M:V%N;B!N:6-H="!H97)G97-T96QL="!W97)D96XN`%-33"U697)B:6YD=6YG
M(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W97)D96XN`$1I92!61E,M1&%T
M96D@:V]N;G1E(&YI8VAT(&MO<&EE<G0@=V5R9&5N+@!$87,@5D93+59E<GIE
M:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`1&%S
M(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N
M+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN
M`$QE97)E(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N
M+@!$:64@1&%T96X@:V]N;G1E;B!N:6-H="!D96MO;7!R:6UI97)T('=E<F1E
M;BX`(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+"!D87,@5F5R
M>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(N`"(E<R(@:V%N;B!N:6-H="!G96SV
M<V-H="!W97)D96XZ("5S+@`E<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N+"!D87,@5F5R>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(`1&%S(%9&4RU6
M97)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@<F5K=7)S:78@9V5L]G-C:'0@=V5R
M9&5N+@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96SV<V-H
M="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E
M;/9S8VAT('=E<F1E;CH@)7,N`$1I92!61E,M1&%T96D@(B5S(B!K;VYN=&4@
M;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N
M:6-H="!G96SV<V-H="!W97)D96XN`$1A<R!61E,@:V]N;G1E(&YI8VAT(')E
M:W5R<VEV(&=E;/9S8VAT('=E<F1E;CH@)7,N`$1A<R!A:W1U96QL92!697)Z
M96EC:&YI<R!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!$:64@6F5R
M=&EF:6MA=&1E=&%I;',@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N('=E<F1E
M;@!$97(@)7,M5')E:6)E<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96XN
M`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N
M+@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E
M<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@>G5M($)E<V-H<F5I
M8F5N(&=E]F9F;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V7V9F9N970@=V5R9&5N+@!$87,@07)C:&EV(&MO;FYT92!N:6-H="!G
M9?9F9FYE="!W97)D96XN`$1I92!$871E:2!K;VYN=&4@;FEC:'0@9V5L97-E
M;B!W97)D96XZ(`!$87,@=F9S<F]O="U697)Z96EC:&YI<R!K;VYN=&4@;FEC
M:'0@9V5L97-E;B!W97)D96XN`"5S(&MO;FYT92!N:6-H="!N86-H("5S('5M
M8F5N86YN="!W97)D96XZ($1A<R!::65L=F5R>F5I8VAN:7,@97AI<W1I97)T
M(&)E<F5I=',`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@=6UB
M96YA;FYT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC
M:'0@=6UB96YA;FYT('=E<F1E;CH@)7,N`$1I92!61E,M1&%T96D@(B5S(B!K
M;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&EE(%9&4RU$871E:2`E
M<R\E<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&EE(%9&4RU$
M871E:2!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`(FUK:7-O9G,B
M(&MO;FYT92!N:6-H="!A=7-G96;\:')T('=E<F1E;BX`1&EE<V5S(%=O<F0M
M1&]K=6UE;G0@;.1S<W0@<VEC:"!N:6-H="!A;GIE:6=E;@!$:64@5D93+41A
M=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`1&EE
M(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V5S8VAR:65B96X@=V5R9&5N("AC
M;W!Y*"D@9F5H;&=E<V-H;&%G96XI+@!$:64@5D93+41A=&5N(&MO;FYT96X@
M;FEC:'0@9V5S8VAR:65B96X@=V5R9&5N+@!5;G1E<G-T<FEC:&5N`,1N9&5R
M=6YG96X@<OQC:V?D;F=I9R!M86-H96X`36%C:'0@9&EE(&QE='IT92!!:W1I
M;VX@<OQC:V?D;F=I9P!5;F?\;'1I9V4@4OQC:VUE;&1U;F<@=F]M(%-E<G9E
M<B!B96EM($AE<G-T96QL96X@9&5R(%9E<F)I;F1U;F<Z(`!5;F5R=V%R=&5T
M92!!;G1W;W)T(&1E<R!397)V97)S(&%U9CH@`$YI8VAT('IU9V5O<F1N970`
M3FEC:'0@=F5R87)B96ET971E($MO;7!O;F5N=&4@9&5S(%1Y<',Z("5S`%5N
M:6-O9&4@*%541BTX*0!697)E:6YI9W1E($%R86)I<V-H92!%;6ER871E`%9E
M<F5I;FEG=&5S($OV;FEG<F5I8V@`5F5R96EN:6=T92!3=&%A=&5N`$ML96EN
M97)E($%M97)I:V%N:7-C:&4@W&)E<G-E96EN<V5L;@!%:6YH96ET96X`56YB
M96MA;FYT`%5N8F5K86YN=&4@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`
M56YB96MA;FYT92!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;F)E
M:V%N;G1E<B!"969E:&PZ("5S`$5S('=U<F1E(&5I;B!U;F)E:V%N;G1E<B!/
M<G0@86YG96=E8F5N+@!5;F)E:V%N;G1E<B!"96YU='IE<FYA;64@;V1E<B!0
M87-S=V]R="X`3&EN:R!V;VT@86MT=65L;&5N($5L96UE;G0@96YT9F5R;F5N
M`%5N8F5N86YN=`!!=7,@4VEC:&5R:&5I='-G<OQN9&5N(&3\<F9E;B!U;F%U
M=&]R:7-I97)T92!3:W)I<'1E(&YI8VAT(&%U<V-H;F5I9&5N+"!K;W!I97)E
M;B!U;F0@96EN9OQG96XN($ML:6-K96X@4VEE(&%U9B!/2RP@=6T@96EN96X@
M2&EN=V5I<R!A=68@;6]Z:6QL82YO<F<@86YG97IE:6=T('IU(&)E:V]M;65N
M+"!D97(@8F5S8VAR96EB="P@=VEE(%-I92!E:6YE;2!3:W)I<'0@9&5N(%IU
M9W)I9F8@875F(&1I92!:=VES8VAE;F%B;&%G92!E<FQA=6)E;B!K]FYN96XN
M`$9A<F)E('IU<OQC:W-E='IE;@!%<G=E:71E<G5N9R!N:6-H="!U;G1E<G-T
M_'1Z=`!5;OQB97)S971Z=`!!:W1U86QI<VEE<G5N9P`E<R!A:W1U86QI<VEE
M<F5N`%-T871U<R!D97(@5&5I;&YE:&UE<B!A:W1U86QI<VEE<F5N`$)E;G5T
M>F5R(&%K='5A;&ES:65R96X`(B5S(B!W=7)D92!A:W1U86QI<VEE<G0N`$%K
M='5A;&ES:65R92`E<R!(:6QF961A=&5I(&;\<B`E<RX`06MT=6%L:7-I97)U
M;F=S<VMR:7!T(&=E;/9S8VAT+@!(;V-H;&%D96X`1&EE($MO;F9I9W5R871I
M;VYS9&%T96EE;B!A;&QE<B!!;G=E;F1U;F=E;B!W=7)D96X@875F(&1E;B!3
M97)V97(@:&]C:&=E;&%D96XN`$=R+B!L871E:6YI<V-H92!"=6-H<W1A8F5N
M`$=R+B!R]FUI<V-H92!:86AL96X`57)U9W5A>0!!=69R=68Z`$%K='5E;&QE
M(&)E;G5T>F5N.B`E<P!34TP@8F5N=71Z96X`0FET=&4@875S9OQL;&5N+"!W
M96YN(%-I92!E:6YE;B!A;F1E<F5N($)E;G5T>F5R;F%M96XO4&%S<W=O<G0@
M9OQR(&1E;B!)35-0+5-E<G9E<B!H86)E;BX`0F5N=71Z97(@)7,@:7-T(&;\
M<B`E<R!N:6-H="!A=71O<FES:65R="X`0F5N=71Z97)V97)W86QT=6YG`$)E
M;G5T>F5R96EN<W1E;&QU;F=E;@!"96YU='IE<G)E9VES=')I97)U;F<`1&EE
M($)E;G5T>F5R<F5G:7-T<FEE<G5N9R!W=7)D92!A=68@9&EE<V5M(%-Y<W1E
M;2!D96%K=&EV:65R="X`0F5N=71Z97(@;FEC:'0@9V5F=6YD96X`0F5N=71Z
M97(@;FEC:'0@9V5F=6YD96XN`$)E;G5T>F5R<F5C:'1E`$)E;G5T>F5R;F%M
M90!$97(@0F5N=71Z97)N86UE("(E<R(@97AI<W1I97)T(&)E<F5I=',N`$)E
M;G5T>F5R;F%M93H`0F5N=71Z97)N86UE.B``0F5N=71Z97(`0F5N=71Z97(@
M9&5S(%-Y<W1E;7,Z`%5S8F5K:7-T86X`1&%S(%9&4RU697)Z96EC:&YI<R!E
M>&ES=&EE<G0@;FEC:'0N`$%B=V5S96YH96ET`%!A<W-E;F1E(&=E9G5N9&5N
M92!/<G1E.B``1_QL=&EG:V5I=`!797)T(&EN($UI;G5T96X@=F]N(&IE='IT
M(&%N+@!$97(@5V5R="!I<W0@_&)E<B!D97(@;6%X:6UA;&5N($SD;F=E('9O
M;B`E<RX`5V5R=&4`5V5R=&4L(&%U<R!D96YE;B!A=7-G97?D:&QT('=E<F1E
M;B!K86YN`%9A;G5A='4`1')E:&5N9`!696YE>G5E;&$`W&)E<G!R_&9U;F<@
M9F5H;&=E<V-H;&%G96X@+2!D:65S92!.86-H<FEC:'0@:_9N;G1E(&UA;FEP
M=6QI97)T('=O<F1E;B!S96EN+@!697)S:6]N`%9E<G-I;VYS:V]N=')O;&QE
M`$%U<W)I8VAT=6YG`%9E<G1I:V%L97(@26YN96YA8G-T86YD`%9E<G1I:V%L
M.@!396AR($AO8V@`5FEE=&YA;0!6:65T;F%M97-I<V-H("A625-#24DI`"5S
M(&%N>F5I9V5N`$5I;F4@97AT97)N92!796)S96ET92!A;GIE:6=E;@!!;GIE
M:6=E;B!A;',@)7,`5&5R;6EN(&%N>F5I9V5N`$%U9F=A8F4@86YZ96EG96X`
M0G)I=&ES8VAE($IU;F=F97)N:6YS96QN`$%M97)I:V%N:7-C:&4@2G5N9V9E
M<FYI;G-E;&X`4VEC:'0`4VEC:'0Z(`!6;V1A9F]N92!)=&%L:65N('!E<B!3
M3510`%=!4DY53D<`5T%23E5.1R$A(2!,UE-#2$5.(%-)12!$05,@4TM225!4
M($U!3E5%3$P@0553("5S+@!786QL:7,@=6YD($9U='5N80!787)N=6YG`%=A
M<FYU;F<Z(`!-:0!7971T97)V;W)H97)S86=E`%=E='1E<F1A=&5N('9O;@!7
M96%T:&5R+F-O;0!796(`5V5B<VET90!7]F-H96YT;&EC:`!7:6QL:V]M;65N
M`%=I;&QK;VUM96X@8F5I("5S`%=I;&QK;VUM96XL("5S`%=E<W1E=7)O<.1I
M<V-H("A)4T\M.#@U.2TQ*0!797-T975R;W#D:7-C:"`H25-/+3@X-3DM,34I
M`%=E<W1S86AA<F$`5V5L8VAE($%N=V5N9'5N9R!S;VQL("5S(&YA8V@@9&5M
M($%N;65L9&5N(&%N9V5Z96EG96X_`%=E;&-H97,@5')E;FYZ96EC:&5N('=I
M<F0@=F5R=V5N9&5T/P!796QC:&4@06YF_&AR=6YG<WIE:6-H96X@=V5R9&5N
M('9E<G=E;F1E=#\`5V5L8VAE(%!H87-E;@!796QC:&4@4&QU9VEN<R!F_'(@
M9&5N(%=94TE764<M161I=&]R('-O;&QE;B!A:W1I=FEE<G0@=V5R9&5N/P!"
M<F5I=&4`0G)E:71E(&EN($-34RU%:6YH96ET96X`0G)E:71E(&1E<R`E<RU-
M96[\<R!L:6YK<R`H=VER:W-A;2!N86-H(&1E<B!NY&-H<W1E;B!!;FUE;&1U
M;F<I.@!486)E;&QE;F)R96ET90!%:6YH96ET`$)R96ET93H`5VEK:0!7:6YD
M`$9R_&@@5VEN9`!7:6YD9V5S8VAW:6YD:6=T:V5I="!I;B!+;F]T96X`5VEN
M9#H`5VEN9#H@`%=E:7-H96ET`%=U;G-C:'IE='1E;`!!<F)E:70`061R97-S
M92!G97-C:.1F=&QI8V@`5&5L969O;B!G97-C:.1F=&QI8V@`4V-H<F5I8F4@
M86MT=6%L:7-I97)T92!(:6QF961A=&5I(&YA8V@@)7,N`%%U97)V97)W96ES
M90!8-3`Y=C,@1V5N97)E;&QE($5I;G-C:'+D;FMU;F<`6#4P.78S($5R=V5I
M=&5R=&5R(%-C:&S\<W-E;'IW96-K`%@U,#EV,R!!;'1E<FYA=&EV97(@3F%M
M92!D97,@6F5R=&EF:6MA=&EN:&%B97)S`%@U,#EV,R!)9&5N=&ETY'0@9&5S
M(%IE<G1I9FEK871S8VAL_'-S96QS`%@U,#EV,R!%<G=E:71E<G5N9V5N`$I*
M`$I*2DH`66%H;V\A($MA<G1E`$KD:')L:6-H`$IE;65N`$IA`$IA+"!I8V@@
M<W1I;6UE('IU`%-I92!B969I;F1E;B!S:6-H(&EM(%1E>'1M;V1U<RX@0F5N
M=71Z96X@4VEE(&1E;B!;/#Y=($MN;W!F+"!U;2!I;B!D96X@5UE325=)1RU-
M;V1U<R!Z=2!W96-H<V5L;BX`4VEE('-I;F0@;FEC:'0@86YG96UE;&1E="X`
M4VEE(&3\<F9E;B!D87,@)UPG+5IE:6-H96X@;FEC:'0@:6X@26AR96T@3F%M
M96X@=F5R=V5N9&5N+@!3:64@:_9N;F5N(&1A<R!087-S=V]R="!V;VX@0F5N
M=71Z97(@)7,@;FEC:'0@Y&YD97)N`%-I92!H86)E;B!K96EN92!G_&QT:6=E
M($5M86EL861R97-S92!A;F=E9V5B96XN`%-I92!H86)E;B!K96EN92!&96QD
M97(@875S(&1E;B!I;7!O<G1I97)T96X@1&%T96X@9&5N(&5N='-P<F5C:&5N
M9&5N($9E;&1E<FX@:6X@)7,@>G5G96]R9&YE="X`4VEE('=U<F1E;B!A8F=E
M;65L9&5T+@!3:64@;?QS<V5N(&5I;F4@9_QL=&EG92!-;V)I;'1E;&5F;VYN
M=6UM97(@86YG96)E;BP@;G5R(&%U<R!:86AL96X@=6YD(&=G9BX@96EN96T@
M(BLB(&;\<B!I;G1E<FYA=&EO;F%L92!6;W)W86AL96X@8F5S=&5H96YD+@!3
M:64@;?QS<V5N(&5I;F5N(&?\;'1I9V5N(%=E<G0@86YG96=E8F5N+@!3:64@
M;?QS<V5N(&5I;B!$871A5')E92U"86-K96YD(&MO;F9I9W5R:65R96XL('5M
M(%-I9VYU<',@>G4@=F5R=V5N9&5N+@!3:64@;?QS<V5N(&5I;B!61E,M0F%C
M:V5N9"!K;VYF:6=U<FEE<F5N+@!3:64@;?QS<V5N(&1A<R!0<F]B;&5M(&)E
M<V-H<F5I8F5N+"!U;2!D96X@0F5R:6-H="!A8GIU<V-H:6-K96XN`%-I92!M
M_'-S96X@9&EE(%523"!A;F=E8F5N+"!A=68@9&EE(&1I97-E<B!,:6YK('9E
M<G=E:7-E;B!S;VQL`%-I92!M_'-S96X@26AR(&%L=&5S(%!A<W-W;W)T(&%N
M9V5B96X`4VEE(&W\<W-E;B!):'(@;F5U97,@4&%S<W=O<G0@86YG96)E;@!3
M:64@;?QS<V5N(&5R<W0@9&5N('IU(&5N=&9E<FYE;F1E;B!397)V97(@875S
M=^1H;&5N+@!3:64@;?QS<V5N(&5I;F5N($)E;G5T>F5R;F%M96X@86YG96)E
M;BP@9&5S<V5N($1A=&5N(&=E;/9S8VAT('=E<F1E;B!S;VQL96XN`%-I92!M
M_'-S96X@96EN96X@>G4@;/9S8VAE;F1E;B!"96YU='IE<FYA;65N(&%N9V5B
M96XN`%-I92!M_'-S96X@96EN96X@:&EN>G5Z=6;\9V5N9&5N($)E;G5T>F5R
M;F%M96X@86YG96)E;BX`4VEE(&W\<W-E;B!D96X@>G4@86MT=6%L:7-I97)E
M;F1E;B!"96YU='IE<FYA;65N(&%N9V5B96XN`%-I92!M_'-S96X@96EN92!!
M:W1I;VX@86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE;B!N975E;B!+871E9V]R
M:65N86UE;B!A;F=E8F5N+@!3:64@;?QS<V5N($EH<B!N975E<R!087-S=V]R
M="!B97-TY'1I9V5N`%-I92!M_'-S96X@96EN92!)=&%L:65N:7-C:&4@5&5L
M969O;FYU;6UE<B!A;F=E8F5N`$EH<F4@)7,M4V5S<VEO;B!I<W0@86)G96QA
M=69E;BX@0FET=&4@;65L9&5N(%-I92!S:6-H(&5R;F5U="!A;BX`26AR92!%
M;6%I;"U!9')E<W-E`$EH<F4@5F]N.B!!9')E<W-E.@!):')E($%N9V%B96X`
M26AR92!);G1E<FYE=&%D<F5S<V4@:&%T('-I8V@@9V7D;F1E<G0L('-E:70@
M4VEE(&1I92`E<RU3:71Z=6YG(&)E9V]N;F5N(&AA8F5N+B!:=6T@4V-H=71Z
M($EH<F5R(%-I8VAE<FAE:70@;?QS<V5N(%-I92!S:6-H(&YE=2!A;FUE;&1E
M;BX`26AR($YA;64`26AR($%U=&AE;G1I9FEZ:65R=6YG<W-Y<W1E;2!E<FQA
M=6)T(&ME:6X@2&EN>G5F_&=E;B!V;VX@;F5U96X@0F5N=71Z97)N+"!O9&5R
M(&1I97-E($WV9VQI8VAK96ET('=U<F1E(&%U<V=E<V-H86QT970N`$EH<B!!
M=71H96YT:69I>FEE<G5N9W-S>7-T96T@97)L875B="!D87,@06YZ96EG96X@
M9&5R($)E;G5T>F5R(&YI8VAT+"!O9&5R(&1I97-E($WV9VQI8VAK96ET('=U
M<F1E(&%U<V=E<V-H86QT970N`$EH<B!"<F]W<V5R(&AA="!S:6-H(&%N<V-H
M96EN96YD(&=EY&YD97)T('-E:70@4VEE(&1I92`E<RU3:71Z=6YG(&)E9V]N
M;F5N(&AA8F5N+B!:=6T@4V-H=71Z($EH<F5R(%-I8VAE<FAE:70@;?QS<V5N
M(%-I92!S:6-H(&YE=2!A;FUE;&1E;BX`26AR($)R;W=S97(@=6YT97)S=/QT
M>G0@9&EE<V4@1G5N:W1I;VX@;FEC:'0N`$EH<B!"<F]W<V5R('5N=&5R<W3\
M='IT(&1I97-E($1R=6-K9G5N:W1I;VX@;FEC:'0N($)I='1E(&1R_&-K96X@
M4VEE(%-T<F<O2V]M;6%N9&\@*R!0('5M('IU(&1R=6-K96XN`$EH<F4@86MT
M=65L;&4@6F5I='IO;F4Z`$EH<F4@4W1A;F1A<F1I9&5N=&ETY'0Z`$EH<B!V
M;VQL<W3D;F1I9V5R($YA;64Z`$EH<F4@9V5T=&5X="!697)S:6]N(&ES="!Z
M=2!A;'0@=6YD('5N=&5R<W3\='IT(%!(4"!N:6-H="!D:7)E:W0N"DYI8VAT
M(&%L;&4@5&5X=&4@=V5R9&5N(&MO<G)E:W0@97AT<F%H:65R="X`26AR(&YE
M=65S(%!A<W-W;W)T(&;\<B`E<R!L875T970Z("5S`$EH<B!N975E<R!087-S
M=V]R="!I<W0@>G4@;&%N9RP@9&%S(%!A<W-W;W)T(&1A<F8@;FEC:'0@;.1N
M9V5R(&%L<R`E9"!:96EC:&5N('-E:6XA`$EH<B!N975E<R!087-S=V]R="!I
M<W0@>G4@;&5I8VAT('IU(&5R<F%T96XA($YI8VAT(&=EY&YD97)T(0!):'(@
M;F5U97,@4&%S<W=O<G0@:7-T('IU(&QE:6-H="!Z=2!E<G)A=&5N+B!.:6-H
M="!G9>1N9&5R="$`26AR(&YE=65S(%!A<W-W;W)T(&UU<W,@;6EN9&5S=&5N
M<R`E9"!:96EC:&5N(&QA;F<@<V5I;B$`26AR(&YE=65S(%!A<W-W;W)T(&UU
M<W,@<VEC:"!V;VX@26AR96T@86QT96X@=6YT97)S8VAE:61E;@!):'(@;F5U
M97,@4&%S<W=O<G0@;75S<R!M:6YD97-T96YS("5D($)U8VAS=&%B96X@96YT
M:&%L=&5N+@!):'(@;F5U97,@4&%S<W=O<G0@;75S<R!M:6YD97-T96YS("5D
M($)U8VAS=&%B96X@;V1E<B!:86AL96X@96YT:&%L=&5N+@!):'(@;F5U97,@
M4&%S<W=O<G0@;75S<R!M:6YD97-T96YS("5D('9E<G-C:&EE9&5N96X@6F5I
M8VAE;G1Y<&5N(&5N:&%L=&5N+B!4>7!E;B!S:6YD.B!+;&5I;F)U8VAS=&%B
M96XL($=R;]]B=6-H<W1A8F5N+"!:86AL96X@=6YD(%-O;F1E<GIE:6-H96XN
M`$EH<B!N975E<R!087-S=V]R="!M=7-S(&UI;F1E<W1E;G,@)60@2VQE:6YB
M=6-H<W1A8F5N(&5N=&AA;'1E;BX`26AR(&YE=65S(%!A<W-W;W)T(&UU<W,@
M;6EN9&5S=&5N<R`E9"!:86AL96X@96YT:&%L=&5N+@!):'(@;F5U97,@4&%S
M<W=O<G0@;75S<R!M:6YD97-T96YS("5D($=R;]]B=6-H<W1A8F5N(&5N=&AA
M;'1E;BX`26AR(&YE=65S(%!A<W-W;W)T(&1A<F8@;FEC:'0@;65H<B!A;',@
M)60@3&5E<GIE:6-H96X@96YT:&%L=&5N+@!):'(@;F5U97,@4&%S<W=O<G0@
M9&%R9B!K96EN92!,965R>F5I8VAE;B!E;G1H86QT96XN`$EH<F4@;F5U96X@
M4&%S<W?V<G1E<B!S=&EM;65N(&YI8VAT(/QB97)E:6X`26AR92!%:6YS=&5L
M;'5N9V5N('=U<F1E;B!F_'(@9&EE($1A=65R(&1I97-E<B!3:71Z=6YG(&=E
M<W!E:6-H97)T+@!):')E($5I;G-T96QL=6YG96X@=W5R9&5N(&=E<W!E:6-H
M97)T+@!):'(@4&%S<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z=`!):'(@4&%S
M<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z="X@4G5F96X@4VEE($EH<F4@16UA
M:6QS(&%B('5N9"!M96QD96X@4VEE('-I8V@@;6ET($EH<F5M(&YE=65N(%!A
M<W-W;W)T(&%N+@!):')E(%!A<W-W]G)T97(@<W1I;6UE;B!N:6-H="#\8F5R
M96EN`$EH<F4@4V5R=F5R.@!*=6=O<VQA=VEE;@!:86ER90!386UB:6$`4VEM
M8F%B=V4`6FEP<'D`6UII=&%T=&5X="!V97)S=&5C:V5N70!;4')O8FQE;6)E
M<FEC:'1=`%M::71A='1E>'0@86YZ96EG96X@+0!;6FET871T97AT(&%N>F5I
M9V5N("T@)7,@6F5I;&5N70!;6F5I;&4@)7,@=F]N("5S70!?061M:6YI<W1R
M871I;VX`0F5?9F5H;'-Z96EL90!?1&%T851R964`6F5I;&4@7VSV<V-H96X`
M7T=R=7!P96X`7TAI;&9E`%]":6QD96EG96YS8VAA9G1E;BXN+@!!;E]M96QD
M96X`06)?;65L9&5N`$QI;FL@7V)E87)B96ET96XN+BX`7T5I;G-T96QL=6YG
M96X`7U)E8VAT90!,:6YK(%]E;G1F97)N96XN+BX`7TMO;F9I9W5R871I;VX`
M7U1A8F5L;&5N96EG96YS8VAA9G1E;BXN+@!?0F5N=71Z97(`061R97-S8G5C
M:`!E:6X@1F5H;&5R(&ES="!A=69G971R971E;CH`2V%L96YD97(`=VEN9'-T
M:6QL`&ML:6-K96X@4VEE(&AI97(`9F5R=&EG`&9E:&QG97-C:&QA9V5N`&9A
M;&QE;F0`1&%T96D`9V5F=6YD96XZ(`!A=7,@)7,@*"5S*2!M:70@)7,@)7,`
M:#H`:&@`<V]F;W)T`$EN;&EN90!L9&%P7W-T87)T7W1L<R!F96AL9V5S8VAL
M86=E;@!:96EL96Y=`&UK:7-O9G,M1F5H;&5R8V]D92`E9"!B96D@9&5R($5R
M<W1E;&QU;F<@9&5S($E33RU!8F)I;&1E<RX`;6T`3F%M90!N:6-H="!G9>1N
M9&5R=`!N:6-H="!G969U;F1E;@!N:6-H="!I;7!L96UE;G1I97)T`$YO8V@@
M;FEC:'0@:6UP;&5M96YT:65R=`!.;W1I>F)L;V-K`%!R;WIE;G0`4&EX96P`
M<W1E:6=E;F0`56YT97)S8VAI961E(&%N>F5I9V5N`'-M<S)E;6%I;"#\8F5R
M($A45%``<W,`9VQE:6-H8FQE:6)E;F0`075F9V%B96YL:7-T90!(;W)D97,@
M4$\M1&%T96D@9OQR(&1A<R!,;V-A;&4@)7,@97AI<W1I97)T(&YI8VAT.@!G
M96)E;B!3:64@9&%S(%!A<W-W;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@0F5S
M=.1T:6=U;F<@96EN`'5N:69I960`=6YB96YA;FYT`&%K='5A;&ES:65R=`!B
M96YU='IE<F1E9FEN:65R=`!V0V%R9`!B.@!W96%T:&5R+F-O;0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S
M=V0O;&]C86QE+V1E7T1%+VAE;'`N>&UL````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`T-C`W`#$P-#$W,S8R-S0S`#`R,38P,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA+2T@)$AO<F1E.B!P
M87-S=V0O;&]C86QE+V1E7T1%+VAE;'`N>&UL+'8@,2XQ(#(P,#4O,3`O,#D@
M,34Z,3,Z,#`@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G!A
M<W-W9"UU<V5R;F%M92(@;60U/2(R.#DP83DX,3)D-S8P-S1F9F(S93,U.34W
M965A.38W9"(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y"96YU='IE
M<FYA;64\+W1I=&QE/@H@("`@/'!A<F$^1V5B96X@4VEE(&AI97(@26AR96X@
M0F5N=71Z97)N86UE;B!A;BP@9F%L;',@97(@;FEC:'0@8F5R96ET<PH@("`@
M96EN9V5T<F%G96X@:7-T+B!$:65S97,@1F5L9"!S=&5H="!N:6-H="!A=68@
M86QL96X@4WES=&5M96X@>G5R"B`@("!697)F_&=U;F<N/"]P87)A/@H@(#PO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P87-S=V0M;VQD+7!A<W-W;W)D(B!M9#4]
M(F5C,30R.3DX-V8X.&-B9#0P-&0P969B,F9D-3=D9C)C(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/D%L=&5S(%!A<W-W;W)T/"]T:71L93X*("`@
M(#QP87)A/D=E8F5N(%-I92!H:65R($EH<B!A:W1U96QL97,L(&9U;FMT:6]N
M:65R96YD97,@4&%S<W=O<G0@86XN(%-I90H@("`@;?QS<V5N($EH<B!087-S
M=V]R="!K;W)R96MT(&%N9V5B96XL('5M(&5S(.1N9&5R;B!Z=2!K]FYN96XN
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P87-S=V0M;F5W+7!A
M<W-W;W)D(B!M9#4](CAF939F,C(U-&$Y9#$P.3@T9F$X8F$X-S9F,30X8C4S
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DYE=65S(%!A<W-W;W)T
M/"]T:71L93X*("`@(#QP87)A/D=E8F5N(%-I92!H:65R($EH<B!N975E<R!0
M87-S=V]R="!A;BP@86QS;R!D96X@5V5R="P@:6X@9&5N(%-I92!):'(*("`@
M(%!A<W-W;W)T(.1N9&5R;B!M]F-H=&5N+B!"96%C:'1E;B!3:64L(&1A<W,@
M26AR(%!A<W-W;W)T(&UI;FEM86QE;@H@("`@5F]R875S<V5T>G5N9V5N(&5N
M='-P<F5C:&5N(&UU<W,L('HN0BX@9V5N_&=E;F0@;&%N9R!S96EN(&UU<W,L
M(&%U<PH@("`@2V]M8FEN871I;VYE;B!V;VX@0G5C:'-T86)E;B!U;F0@86YD
M97)E;B!:96EC:&5N(&)E<W1E:&5N(&UU<W,L(&YI8VAT"B`@("!):')E;2!"
M96YU='IE<FYA;65N(&5N='-P<F5C:&5N(&1A<F8@=7-W+B!!;F1E<F5N9F%L
M;',@97)H86QT96X@4VEE(&5I;F4*("`@($9E:&QE<FUE;&1U;F<N/"]P87)A
M/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P87-S=V0M8V]N9FER;2UP87-S
M=V]R9"(@;60U/2(S.&-A864T8C<W-6-C961A-C!B8F,S8S$X,V$W.&9C8B(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y.975E<R!087-S=V]R="!B
M973D=&EG96X\+W1I=&QE/@H@("`@/'!A<F$^1V5B96X@4VEE(&AI97(@26AR
M(&YE=64@4&%S<W=O<G0@96EN('IW96ET97,@36%L(&%N+B!$86UI="!W:7)D
M"B`@("!V97)H:6YD97)T+"!D87-S(%-I92!S:6-H('9E<G1I<'!E;B!U;F0@
M9&%D=7)C:"!S96QB<W0@=F]N($EH<F5M($MO;G1O"B`@("!A=7-S8VAL:67?
M96XN/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P87-S=V0M<V5R
M=F5R(B!M9#4](C$V-&5D8C@X,&1B-S(Y-V5B,C4Y.#$V96$T,F,P9CAF(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!A<W-W;W)T(.1N9&5R;B!A
M=68\+W1I=&QE/@H@("`@/'!A<F$^5^1H;&5N(%-I92!D96X@4V5R=F5R(&]D
M97(@9&EE($%N=V5N9'5N9R!A=7,L(&;\<B!D:64@4VEE($EH<@H@("`@4&%S
M<W=O<G0@Y&YD97)N(&WV8VAT96XN($1I97-E<R!&96QD('-T96AT(&YI8VAT
M(&%U9B!A;&QE;B!3>7-T96UE;B!Z=7(*("`@(%9E<F;\9W5N9RX\+W!A<F$^
M"B`@/"]E;G1R>3X*("`\96YT<GD@:60](D-H86YG92UY;W5R+7!A<W-W;W)D
M(B!M9#4](C$X-CDY,V$S-#=A.6%D-&0Y8V0R8V)E96%D-V8V931E(B!S=&%T
M93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!A<W-W;W)T(.1N9&5R;CPO=&ET
M;&4^"B`@("`\<&%R83Y$<OQC:V5N(%-I92!D96X@(E!A<W-W;W)T(.1N9&5R
M;B(M2VYO<&8@86T@16YD92!D97,@1F]R;75L87)S+"!U;0H@("`@9&%S(%!A
M<W-W;W)T('=I92!A;F=E9V5B96X@>G4@Y&YD97)N+CPO<&%R83X*("`\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<F5S970B(&UD-3TB.#<S,#)F8F,X.6(X.3=C
M.&0W.#0T-65B,V4V,C1D-64B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET
M;&4^6G5R_&-K<V5T>F5N/"]T:71L93X*("`@(#QP87)A/D1R_&-K96X@4VEE
M(&1E;B`B6G5R_&-K<V5T>F5N(BU+;F]P9B!A;2!%;F1E(&1E<R!&;W)M=6QA
M<G,L('5M(&%L;&4*("`@($9O<FUU;&%R9&%T96XL(&1I92!3:64@8FES:&5R
M(&5I;F=E9V5B96X@:&%B96X@>G4@;/9S8VAE;B!U;F0@=F]N('9O<FYE('IU
M"B`@("!B96=I;FYE;BX\+W!A<F$^"B`@/"]E;G1R>3X*/"]H96QP/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P87-S=V0O;&]C86QE+V-S7T-:+P``````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S`#`R,#$V
M-``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O8W-?0UHO
M3$-?34534T%'15,O````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-#,`,#(Q-S4Q`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S
M<W=D+VQO8V%L92]C<U]#6B],0U]-15-304=%4R]P87-S=V0N;6\`````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#0S,3$W,0`Q,#0Q-S,V,C<T,P`P,C,V,3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````WA($E0````#!!P``
M'````"0^``!7"@``+'P```````"(I0``30```(FE``"_````UZ4``&0```"7
MI@``O@```/RF``"0````NZ<``$,```!,J```/````)"H```K````S:@``"X`
M``#YJ```*0```"BI```H````4JD``$4```![J0``1P```,&I``!*````":H`
M`$<```!4J@``10```)RJ``!(````XJH``#D````KJP``1@```&6K``!(````
MK*L``#````#UJP``10```":L``!&````;*P``$P```"SK```-`````"M```R
M````-:T``&D```!HK0``,````-*M```E`````ZX``(@````IK@``0````+*N
M``#V````\ZX``$H```#JKP``+````#6P``"%````8K```$@```#HL```#@``
M`#&Q```/````0+$```@```!0L0``#````%FQ```$````9K$```P```!KL0``
M$0```'BQ```E````BK$```\```"PL0``"P```,"Q```1````S+$``!````#>
ML0``#@```.^Q```%````_K$``"@````$L@``"@```"VR```5````.+(``!(`
M``!.L@``"P```&&R```4````;;(``"8```""L@``)P```*FR```F````T;(`
M`!,```#XL@``#@````RS```*````&[,```T````FLP``+@```#2S```G````
M8[,``"````"+LP``#@```*RS```7````N[,``"(```#3LP``-0```/:S```1
M````++0```T````^M```#````$RT```-````6;0```8```!GM```'0```&ZT
M```;````C+0``"T```"HM```'0```-:T```D````]+0``"D````9M0``&0``
M`$.U```/````7;4``!@```!MM0``#````(:U```;````D[4```X```"OM0``
M#@```+ZU```(````S;4``$(```#6M0``+@```!FV```:````2+8``#(```!C
MM@``.````):V``!4````S[8``%$````DMP``6@```':W``!7````T;<``#0`
M```IN```#@```%ZX```*````;;@```4```!XN```!@```'ZX```1````A;@`
M``@```"7N```"0```*"X```)````JK@```X```"TN```"````,.X```.````
MS+@``"4```#;N```(`````&Y```0````(KD```\````SN0``"@```$.Y```'
M````3KD```,```!6N0``#P```%JY```4````:KD```D```!_N0``#0```(FY
M```2````E[D``!D```"JN0``'@```,2Y```/````X[D```H```#SN0``#P``
M`/ZY```(````#KH``"0````7N@``%P```#RZ```4````5+H``!8```!IN@``
M"````("Z``!.````B;H``"T```#8N@``'P````:[```9````)KL```<```!`
MNP``#````$B[```L````5;L```X```""NP```P```)&[```+````E;L```<`
M``"ANP``!P```*F[```%````L;L```4```"WNP``"@```+V[```#````R+L`
M`!<```#,NP``"@```.2[```/````[[L```X```#_NP``&`````Z\```C````
M)[P```X```!+O```%````%J\```7````;[P``!<```"'O```%P```)^\```3
M````M[P```\```#+O```#@```-N\```?````ZKP```<````*O0``!@```!*]
M```(````&;T```\````BO0``!@```#*]```*````.;T``!,```!$O0``"P``
M`%B]```0````9+T``!4```!UO0``%0```(N]```'````H;T```4```"IO0``
M%0```*^]```1````Q;T```P```#7O0``.P```.2]```X````(+X```D```!9
MO@``!P```&.^```4````:[X```,```"`O@``!0```(2^```0````BKX```D`
M``";O@``$P```*6^```Y````N;X``!(```#SO@``.0````:_```G````0+\`
M`"P```!HOP``*@```)6_```E````P+\```D```#FOP``"@```/"_```&````
M^[\```D````"P```!P````S````O````%,```#<```!$P```+@```'S```!5
M````J\```"T````!P0``+0```"_!```M````7<$``$````"+P0``(P```,S!
M```C````\,$``"T````4P@``,P```$+"```5````=L(``!D```",P@``*0``
M`*;"```D````T,(``!$```#UP@``$0````?#```*````&<,```P````DPP``
M(@```#'#```*````5,,``!````!?PP``%@```'##```6````A\,```<```">
MPP``!P```*;#```4````KL,```H```##PP``"````,[#```$````U\,``"<`
M``#<PP``"`````3$```'````#<0```<````5Q```!@```!W$```%````),0`
M``<````JQ```!@```#+$```(````.<0``"D```!"Q```#@```&S$```*````
M>\0```\```"&Q```!````);$```'````F\0```D```"CQ```!@```*W$```1
M````M,0```<```#&Q```%@```,[$```$````Y<0```@```#JQ```!@```//$
M```-````^L0```8````(Q0``'@````_%```1````+L4``"(```!`Q0``%@``
M`&/%```(````>L4```T```"#Q0``#````)'%```'````GL4```,```"FQ0``
M`P```*K%```7````KL4``!,```#&Q0``"````-K%```$````X\4```@```#H
MQ0``"````/'%``!!````^L4``"`````\Q@``!@```%W&```&````9,8``!4`
M``!KQ@``&````('&```B````FL8``"X```"]Q@``'0```.S&```A````"L<`
M`%0````LQP``*0```(''```*````J\<```<```"VQP``%0```+['```.````
MU,<```H```#CQP``#P```.['```-````_L<```\````,R```#0```!S(```)
M````*L@``!0````TR```!@```$G(```8````4,@``!T```!IR```$P```(?(
M```4````F\@```0```"PR```#````+7(```&````PL@```\```#)R```$P``
M`-G(``!4````[<@``!0```!"R0``%P```%?)```$````;\D```X```!TR0``
M1````(/)```%````R,D```4```#.R0``&P```-3)```:````\,D``!$````+
MR@``$0```!W*```1````+\H``!P```!!R@``*@```%[*```0````B<H``"$`
M``":R@``)0```+S*```9````XLH```4```#\R@``$P````++```2````%LL`
M``H````IRP``#P```#3+```1````1,L``!,```!6RP``#````&K+```&````
M=\L```8```!^RP``%P```(7+```0````G<L``!$```"NRP``"````,#+```%
M````R<L```P```#/RP``$````-S+```%````[<L```T```#SRP``!@````',
M```'````",P```T````0S```$````![,```)````+\P```<````YS```"P``
M`$',```+````3<P```<```!9S```!P```&',```)````:<P``!0```!SS```
M"0```(C,```*````DLP``!D```"=S```'0```+?,```,````U<P``!````#B
MS```%0```//,```%````"<T``"4````/S0``$@```#7-```3````2,T``"L`
M``!<S0``.P```(C-```@````Q,T``#8```#ES0``$````!S.```(````+<X`
M``P````VS@``!@```$/.```$````2LX```X```!/S@``$````%[.```*````
M;\X```T```!ZS@``'@```(C.```;````I\X``"$```##S@``'@```.7.```9
M````!,\``!X````>SP``'0```#W/```M````6\\``!L```")SP``(````*7/
M```N````QL\``!<```#USP``)@````W0```P````--```!L```!ET```'@``
M`('0```<````H-```"8```"]T```*P```.30```S````$-$``"8```!$T0``
M*P```&O1```X````E]$``!T```#0T0``%0```.[1```O````!-(``!(````T
MT@``(````$?2```I````:-(``!X```"2T@``(0```+'2```2````T](``*(`
M``#FT@``%@```(G3```C````H-,``"@```#$TP``*0```.W3```H````%]0`
M`!\```!`U```%0```&#4```@````=M0``"4```"7U```*0```+W4```M````
MY]0``"$````5U0``%@```#?5```<````3M4``"8```!KU0``*@```)+5``!!
M````O=4``$0```#_U0``#````$36```'````4=8```<```!9U@``!@```&'6
M```-````:-8``!````!VU@``$@```(?6```3````FM8``!(```"NU@``!P``
M`,'6```$````R=8```T```#.U@``#````-S6```.````Z=8```\```#XU@``
M$P````C7```-````'-<``"@````JUP```P```%/7```-````5]<```8```!E
MUP``$0```&S7```7````?M<``!L```"6UP``#@```++7```"````P=<```4`
M``#$UP``!````,K7```0````S]<```0```#@UP``#0```.77```.````\]<`
M``,````"V```#@````;8```(````%=@```\````>V```"````"[8```/````
M-]@```T```!'V```$````%78```3````9M@``!,```!ZV```"P```([8```1
M````FM@```D```"LV```!@```+;8```,````O=@``!$```#*V```&0```-S8
M```+````]M@```T````"V0``(@```!#9```;````,]D``#0```!/V0``"@``
M`(39```8````C]D``!D```"HV0``%@```,+9```O````V=D``"(````)V@``
M#0```"S:```'````.MH```P```!"V@``)@```$_:```4````=MH```L```"+
MV@``(@```)?:```O````NMH```L```#JV@``"0```/;:```9`````-L```L`
M```:VP``%P```";;```7````/ML```D```!6VP``%@```&#;```/````=]L`
M`!8```"'VP``#@```)[;```8````K=L```@```#&VP``#0```,_;```F````
MW=L``$,````$W```"````$C<```2````4=P```@```!DW```"P```&W<```O
M````>=P```X```"IW```!0```+C<```&````OMP```,```#%W```!P```,G<
M```$````T=P```H```#6W```"@```.'<```/````[-P``!````#\W```%P``
M``W=```1````)=T``!<````WW0``&0```$_=```)````:=T```4```!SW0``
M"P```'G=```*````A=T```(```"0W0``!0```)/=```-````F=T``!L```"G
MW0``%P```,/=```)````V]T```X```#EW0``#0```/3=```2`````MX``#@`
M```5W@``(````$[>```#````;]X```@```!SW@``#@```'S>``![````B]X`
M`!@````'WP``0````"#?```1````8=\```<```!SWP``!0```'O?```@````
M@=\``!@```"BWP``&0```+O?```3````U=\```<```#IWP``!P```/'?```(
M````^=\```8````"X```!@````G@```0````$.````\````AX```$````#'@
M```/````0N````L```!2X```#P```%[@```,````;N````\```![X```!P``
M`(O@```*````D^````8```">X```#@```*7@```,````M.```"@```#!X```
M#P```.K@```(````^N```!8````#X0``"````!KA```3````(^$``!X````W
MX0``(0```%;A```@````>.$``!D```"9X0``%P```+/A```E````R^$``!<`
M``#QX0``'@````GB```F````*.(```0```!/X@``&P```%3B```-````<.(`
M``P```!^X@```P```(OB```(````C^(```H```"8X@``#````*/B```+````
ML.(```0```"\X@``$P```,'B```4````U>(```P```#JX@``"0```/?B```.
M`````>,```L````0XP``&P```!SC```'````..,```<```!`XP``"@```$CC
M```-````4^,```D```!AXP``!````&OC```%````<.,```,```!VXP``&```
M`'KC```*````D^,```0```">XP``)@```*/C```.````RN,``'P```#9XP``
M%0```%;D```%````;.0```<```!RY```#````'KD```(````A^0```H```"0
MY```!@```)OD```(````HN0``!8```"KY```$@```,+D```"````U>0```8`
M``#8Y```!@```-_D```4````YN0``!4```#[Y```#P```!'E```1````(>4`
M`!H````SY0``#0```$[E```0````7.4``!L```!MY0``!````(GE```)````
MCN4``!````"8Y0``"0```*GE```)````L^4```4```"]Y0``!0```,/E```:
M````R>4```@```#DY0``!@```.WE```9````].4```X````.Y@``(@```!WF
M```'````0.8```<```!(Y@``#@```%#F```%````7^8```D```!EY@``"@``
M`&_F```"````>N8```8```!]Y@``#0```(3F```)````DN8```8```"<Y@``
M$@```*/F```)````MN8```<```#`Y@``%````,CF```=````W>8``!$```#[
MY@``!@````WG```*````%.<```0````?YP``"0```"3G```(````+N<``!$`
M```WYP``$0```$GG```)````6^<```8```!EYP``#0```&SG```&````>N<`
M``(```"!YP``!````(3G```Y````B><``#T```##YP``.@````'H```>````
M/.@```4```!;Z```#@```&'H```$````<.@```8```!UZ```(0```'SH```5
M````GN@```8```"TZ```!````+OH```1````P.@```8```#2Z```H````-GH
M```*````>ND``"(```"%Z0``!````*CI```E````K>D```4```#3Z0``'0``
M`-GI```$````]^D```P```#\Z0``"@````GJ```(````%.H```D````=Z@``
M!0```"?J```;````+>H``#H```!)Z@``,````(3J```U````M>H``"D```#K
MZ@``+@```!7K``!'````1.L``#@```",ZP``*0```,7K```_````[^L``"X`
M```O[```+0```%[L```?````C.P```\```"L[```$@```+SL```+````S^P`
M`"8```#;[```*0````+M```D````+.T``"8```!1[0``"````'CM```*````
M@>T```D```",[0``!P```);M```@````GNT``"````"_[0``)@```.#M```*
M````!^X``!D````2[@``*0```"SN```6````5NX``!(```!M[@``!P```(#N
M```*````B.X```P```"3[@``#P```*#N```0````L.X``$````#![@``<```
M``+O``!F````<^\```X```#:[P``"0```.GO```*````\^\``!(```#^[P``
M$P```!'P```,````)?````8````R\```#P```#GP```2````2?```!````!<
M\```"@```&WP```1````>/```!(```"*\```'````)WP```C````NO```&H`
M``#>\```#P```$GQ```%````6?$``!````!?\0``"0```'#Q```$````>O$`
M``L```!_\0``&@```(OQ```4````IO$```P```"[\0``#````,CQ```/````
MU?$``!4```#E\0``*0```/OQ```J````)?(``"8```!0\@``)P```'?R```I
M````G_(``"H```#)\@``&0```/3R``!"````#O,``!$```!1\P``$@```&/S
M```3````=O,``!0```"*\P``#P```)_S```6````K_,``!<```#&\P``$```
M`-[S```1````[_,``#0````!]```$P```#;T```2````2O0``#4```!=]```
M%````)/T```'````J/0```P```"P]```*P```+WT```@````Z?0``!0````*
M]0``$0```!_U```7````,?4``!P```!)]0``$P```&;U```1````>O4``!H`
M``",]0``'@```*?U```:````QO4``!$```#A]0``%P```//U```4````"_8`
M`!<````@]@``%0```#CV```)````3O8``!D```!8]@``!````'+V```'````
M=_8```L```!_]@``$0```(OV```&````G?8```8```"D]@``!@```*OV```%
M````LO8```<```"X]@``!P```,#V```%````R/8``!8```#.]@``!@```.7V
M```&````[/8```0```#S]@``!````/CV```'````_?8```X````%]P``#```
M`!3W```,````(?<```T````N]P``"@```#SW```.````1_<```4```!6]P``
M*````%SW```.````A?<```P```"4]P``#P```*'W```*````L?<```@```"\
M]P``"0```,7W```K````S_<```0```#[]P``"`````#X```F````"?@``!(`
M```P^```#P```$/X```&````4_@```H```!:^```!P```&7X```(````;?@`
M`"````!V^```"0```)?X```,````H?@```T```"N^```#@```+SX```6````
MR_@``!$```#B^```!@```/3X```#````^_@```8```#_^```&0````;Y```'
M````(/D```0````H^0``"P```"WY```+````.?D```<```!%^0``!P```$WY
M```6````5?D```T```!L^0``#0```'KY```*````B/D``!````"3^0``#P``
M`*3Y```1````M/D``!<```#&^0``"@```-[Y```1````Z?D```@```#[^0``
M!`````3Z```/````"?H``#H````9^@``!0```%3Z```,````6OH``!X```!G
M^@``#@```(;Z```0````E?H```L```"F^@``#````++Z```)````O_H```<`
M``#)^@``"@```-'Z```)````W/H```X```#F^@``$````/7Z```:````!OL`
M``H````A^P``"0```"S[```4````-OL```H```!+^P``#````%;[```/````
M8_L```@```!S^P``!@```'S[```'````@_L```L```"+^P``1P```)?[```-
M````W_L```D```#M^P``!````/?[```#````_/L``!,`````_```$P```!3\
M```3````*/P```H````\_````@```$?\```$````2OP``"4```!/_````P``
M`'7\```%````>?P``"H```!__```"@```*K\```%````M?P```0```"[_```
M"@```,#\```-````R_P``$````#9_```$P```!K]```&````+OT```@````U
M_0``"````#[]```$````1_T```4```!,_0``:````%+]```)````N_T```P`
M``#%_0``!0```-+]```&````V/T``!L```#?_0``+P```/O]```0````*_X`
M``H````\_@``#P```$?^```*````5_X```D```!B_@``$P```&S^```;````
M@/X``!@```"<_@``%P```+7^```.````S?X```,```#<_@``!P```.#^```(
M````Z/X``!0```#Q_@``$P````;_```0````&O\```T````K_P``#@```#G_
M```6````2/\```<```!?_P``"@```&?_```+````<O\``"T```!^_P``%0``
M`*S_```P````PO\``"0```#S_P``!P```!@``0!1````(``!`!````!R``$`
M#````(,``0`-````D``!`!H```">``$`2@```+D``0`&````!`$!`!H````+
M`0$`!@```"8!`0`&````+0$!`!\````T`0$`!@```%0!`0`)````6P$!`!@`
M``!E`0$`%P```'X!`0`H````E@$!``8```"_`0$`#0```,8!`0`B````U`$!
M`%<```#W`0$`$P```$\"`0`C````8P(!`!,```"'`@$``@```)L"`0`+````
MG@(!``@```"J`@$`#0```+,"`0`*````P0(!``8```#,`@$`!P```-,"`0`4
M````VP(!``8```#P`@$`"````/<"`0`.``````,!``<````/`P$`"@```!<#
M`0`+````(@,!``<````N`P$`#````#8#`0`-````0P,!``P```!1`P$`"0``
M`%X#`0`)````:`,!``H```!R`P$`!P```'T#`0`)````A0,!``<```"/`P$`
M"@```)<#`0`;````H@,!`!(```"^`P$`"@```-$#`0`)````W`,!`!````#F
M`P$`!P```/<#`0`2````_P,!``0````2!`$`!P```!<$`0`%````'P0!``P`
M```E!`$`!0```#($`0`+````.`0!`!0```!$!`$`$0```%D$`0`:````:P0!
M`!8```"&!`$`%````)T$`0`7````L@0!`!@```#*!`$`'````.,$`0`9````
M``4!``<````:!0$`!0```"(%`0`-````*`4!``P````V!0$`"````$,%`0`7
M````3`4!``L```!D!0$`#0```'`%`0`3````?@4!``0```"2!0$`"@```)<%
M`0`$````H@4!``D```"G!0$`"@```+$%`0`,````O`4!``D```#)!0$`!0``
M`-,%`0`'````V04!``4```#A!0$`!````.<%`0`"````[`4!`#@```#O!0$`
M+````"@&`0`2````508!`"D```!H!@$`,@```)(&`0`*````Q08!`#8```#0
M!@$`+`````<'`0`5````-`<!`"X```!*!P$`,P```'D'`0`S````K0<!`#@`
M``#A!P$`#P```!H(`0`8````*@@!`#L```!#"`$`$````'\(`0`/````D`@!
M`!0```"@"`$`$P```+4(`0`4````R0@!`!(```#>"`$`%````/$(`0`5````
M!@D!`"T````<"0$`+0```$H)`0`Q````>`D!`"T```"J"0$`+@```-@)`0`O
M````!PH!`"P````W"@$`8@```&0*`0`3````QPH!``@```#;"@$`"````.0*
M`0`;````[0H!`"L````)"P$`(0```#4+`0`:````5PL!``D```!R"P$`10``
M`'P+`0!!````P@L!``\````$#`$`!````!0,`0`3````&0P!`!0````M#`$`
M#@```$(,`0`3````40P!`!@```!E#`$`!@```'X,`0`)````A0P!``H```"/
M#`$`#P```)H,`0`0````J@P!``<```"[#`$`#@```,,,`0`%````T@P!`!L`
M``#8#`$`!@```/0,`0`(````^PP!``8````$#0$`%`````L-`0`1````(`T!
M``X````R#0$`.````$$-`0`"````>@T!``8```!]#0$`#@```(0-`0`:````
MDPT!``4```"N#0$`!P```+0-`0`.````O`T!``8```#+#0$`#0```-(-`0`$
M````X`T!`"D```#E#0$`%P````\.`0`?````)PX!`%P```!'#@$`%````*0.
M`0`^````N0X!`!\```#X#@$`$````!@/`0`4````*0\!``<````^#P$`#@``
M`$8/`0`(````50\!``P```!>#P$`#````&L/`0`3````>`\!``H```",#P$`
M'0```)</`0`9````M0\!``4```#/#P$`$0```-4/`0`1````YP\!`"0```#Y
M#P$`%0```!X0`0`2````-!`!``X```!'$`$`&0```%80`0`(````<!`!``D`
M``!Y$`$`#0```(,0`0`*````D1`!``L```"<$`$`"@```*@0`0`'````LQ`!
M``@```"[$`$`!0```,00`0`?````RA`!``8```#J$`$`$````/$0`0`(````
M`A$!``T````+$0$`(@```!D1`0`(````/!$!`!<```!%$0$`$@```%T1`0`L
M````<!$!`"\```"=$0$`+````,T1`0`J````^A$!`"L````E$@$`+````%$2
M`0`:````?A(!``D```"9$@$`"@```*,2`0`5````KA(!``4```#$$@$`%```
M`,H2`0`$````WQ(!`!````#D$@$`!@```/42`0`'````_!(!`!X````$$P$`
M*````",3`0`*````3!,!`!P```!7$P$`&@```'03`0`/````CQ,!`!0```"?
M$P$`!````+03`0`$````N1,!``L```"^$P$`!0```,H3`0`&````T!,!``@`
M``#7$P$`!@```.`3`0`*````YQ,!`!L```#R$P$`-`````X4`0`T````0Q0!
M`"````!X%`$`*0```)D4`0`@````PQ0!`$$```#D%`$`&@```"85`0`H````
M014!`"D```!J%0$`40```)05`0`O````YA4!`%<````6%@$`+````&X6`0`B
M````FQ8!``8```"^%@$`"````,46`0`%````SA8!``@```#4%@$`&0```-T6
M`0`9````]Q8!`"H````1%P$`(P```#P7`0`N````8!<!`#0```"/%P$`#0``
M`,07`0`(````TA<!`!<```#;%P$`"@```/,7`0`'````_A<!`"$````&&`$`
M#0```"@8`0`0````-A@!``X```!'&`$`"P```%88`0`'````8A@!`!,```!J
M&`$`"````'X8`0`+````AQ@!``H```"3&`$`%````)X8`0`R````LQ@!``L`
M``#F&`$`!0```/(8`0`%````^!@!`!<```#^&`$`#P```!89`0`$````)AD!
M``H````K&0$`"0```#89`0`+````0!D!``X```!,&0$`!0```%L9`0`$````
M81D!``T```!F&0$`,@```'09`0!%````IQD!`!<```#M&0$`'@````4:`0`4
M````)!H!``\````Y&@$`!0```$D:`0`4````3QH!``<```!D&@$`(P```&P:
M`0`.````D!H!`"H```"?&@$`!@```,H:`0`,````T1H!``T```#>&@$`$0``
M`.P:`0`7````_AH!``L````6&P$`-@```"(;`0`*````61L!`"(```!D&P$`
M"P```(<;`0`/````DQL!``L```"C&P$`(````*\;`0`G````T!L!`"L```#X
M&P$`"0```"0<`0`R````+AP!`#````!A'`$`,0```)(<`0`M````Q!P!`#\`
M``#R'`$`/0```#(=`0`V````<!T!`!0```"G'0$`!0```+P=`0`.````PAT!
M`!,```#1'0$`!P```.4=`0`:````[1T!``@````('@$`$0```!$>`0`'````
M(QX!`!0````K'@$`&````$`>`0`'````61X!``4```!A'@$`#````&<>`0`,
M````=!X!`!(```"!'@$`!````)0>`0`'````F1X!``H```"A'@$`"P```*P>
M`0`,````N!X!``X```#%'@$`#@```-0>`0`%````XQX!``4```#I'@$`+@``
M`.\>`0`F````'A\!`",```!%'P$``P```&D?`0`2````;1\!``8```"`'P$`
M'@```(<?`0`8````IA\!`"4```"_'P$`#0```.4?`0`)````\Q\!``(```#]
M'P$``P`````@`0`'````!"`!``H````,(`$``@```!<@`0`,````&B`!`!4`
M```G(`$`"P```#T@`0`9````22`!`"````!C(`$`$@```(0@`0`%````ER`!
M``H```"=(`$`%0```*@@`0`2````OB`!``P```#1(`$`!````-X@`0`'````
MXR`!``D```#K(`$`#````/4@`0!2`````B$!`!<```!5(0$`)````&TA`0`'
M````DB$!``8```":(0$`#@```*$A`0`B````L"$!`!T```#3(0$`#````/$A
M`0`-````_B$!`!4````,(@$`$@```"(B`0`/````-2(!`!0```!%(@$`&P``
M`%HB`0`0````=B(!`&D```"'(@$`&@```/$B`0`7````#",!`"<````D(P$`
M&@```$PC`0`7````9R,!`!L```!_(P$`&0```)LC`0`?````M2,!`!<```#5
M(P$`$P```.TC`0`(`````20!``<````*)`$`"````!(D`0`)````&R0!`!4`
M```E)`$`#0```#LD`0`3````220!``,```!=)`$`1@```&$D`0`_````J"0!
M`#<```#H)`$`5P```"`E`0`?````>"4!`"\```"8)0$`"@```,@E`0`(````
MTR4!``T```#<)0$`+0```.HE`0`$````&"8!`$\````=)@$`)0```&TF`0`<
M````DR8!``L```"P)@$`'P```+PF`0`=````W"8!`"4```#Z)@$`(````"`G
M`0`D````02<!`"````!F)P$`"P```(<G`0`'````DR<!``T```";)P$`#```
M`*DG`0`&````MB<!`#D```"])P$`#````/<G`0`'````!"@!`!D````,*`$`
M"0```"8H`0`3````,"@!``D```!$*`$`!````$XH`0`0````4R@!``H```!D
M*`$`"````&\H`0`(````>"@!``0```"!*`$`"P```(8H`0`,````DB@!`!$`
M``"?*`$`#````+$H`0`:````OB@!``\```#9*`$`!P```.DH`0`-````\2@!
M`!0```#_*`$`#@```!0I`0`,````(RD!`!L````P*0$`+````$PI`0`3````
M>2D!`!P```"-*0$`*````*HI`0`&````TRD!``<```#:*0$`$P```.(I`0`%
M````]BD!``0```#\*0$`%P````$J`0`*````&2H!``P````D*@$`"0```#$J
M`0`&````.RH!``D```!"*@$`"````$PJ`0`)````52H!``4```!?*@$`"@``
M`&4J`0`1````<"H!``8```""*@$`&````(DJ`0`.````HBH!``X```"Q*@$`
M#0```,`J`0`+````SBH!`!T```#:*@$`"P```/@J`0`"````!"L!`!P````'
M*P$`!P```"0K`0`7````+"L!``8```!$*P$`90```$LK`0`)````L2L!``<`
M``"[*P$`)@```,,K`0`X````ZBL!`!H````C+`$`*@```#XL`0`[````:2P!
M`"L```"E+`$`*````-$L`0`9````^BP!`!4````4+0$`!0```"HM`0`'````
M,"T!``@````X+0$`!P```$$M`0`%````22T!``<```!/+0$`#@```%<M`0`)
M````9BT!``8```!P+0$`"````'<M`0`+````@"T!``<```",+0$`"````)0M
M`0`'````G2T!`!8```"E+0$`"0```+PM`0`&````QBT!``L```#-+0$`'```
M`-DM`0`4````]BT!``<````++@$`"````!,N`0`(````'"X!``4````E+@$`
M$````"LN`0`0````/"X!``8```!-+@$`&0```%0N`0`*````;BX!`!P```!Y
M+@$`!P```)8N`0`%````GBX!`!````"D+@$`%````+4N`0`+````RBX!``T`
M``#6+@$`&````.0N`0`7````_2X!`!H````5+P$`%````#`O`0`$````12\!
M``D```!*+P$`"@```%0O`0`'````7R\!``(```!G+P$`#@```&HO`0`(````
M>2\!`!\```""+P$`/@```*(O`0`C````X2\!`#@````%,`$`,0```#XP`0`G
M````<#`!`&0```"8,`$`%````/TP`0`<````$C$!`%4````O,0$`.````(4Q
M`0!*````OC$!`%L````),@$`*````&4R`0`X````CC(!`"H```#',@$`*```
M`/(R`0`L````&S,!`"<```!(,P$`&P```'`S`0`^````C#,!`*D!``#+,P$`
M*````'4U`0`C````GC4!`!<```#"-0$`2````-HU`0"%````(S8!`#````"I
M-@$`00```-HV`0!;````'#<!`$D```!X-P$`'0```,(W`0`8````X#<!`"$`
M``#Y-P$`'P```!LX`0`K````.S@!`"$```!G.`$`*0```(DX`0`=````LS@!
M`!$```#1.`$`,P```.,X`0`E````%SD!`#@````].0$`)P```'8Y`0`@````
MGCD!`!\```"_.0$`,````-\Y`0!I````$#H!`"L```!Z.@$`,@```*8Z`0`Q
M````V3H!`$$````+.P$`,P```$T[`0`E````@3L!`#T```"G.P$`90```.4[
M`0!-````2SP!`"\```"9/`$`+@```,D\`0`K````^#P!`#`````D/0$`*@``
M`%4]`0`^````@#T!`%0```"_/0$`@P```!0^`0!:````F#X!`$@```#S/@$`
M2@```#P_`0`R````AS\!`!T```"Z/P$`(P```-@_`0`O````_#\!`"P````L
M0`$`+0```%E``0!Q````AT`!`&\```#Y0`$`LP```&E!`0`7````'4(!`"4`
M```U0@$`,@```%M"`0`I````CD(!`#X```"X0@$`(@```/="`0!2````&D,!
M`"4```!M0P$`"P```)-#`0"Q````GT,!`$4```!11`$`(0```)=$`0`N````
MN40!`#````#H1`$`)0```!E%`0`<````/T4!`#$```!<10$`!P```(Y%`0`'
M````ED4!``0```">10$`#0```*-%`0`+````L44!``X```"]10$`"P```,Q%
M`0`%````V$4!`!````#>10$``@```.]%`0!9````\D4!``4```!,1@$`$@``
M`%)&`0`$````948!``<```!J1@$`"````')&`0`%````>T8!``,```"!1@$`
M$````(5&`0`*````ED8!``P```"A1@$`$P```*Y&`0`-````PD8!``(```#0
M1@$`!P```--&`0`&````VT8!`!0```#B1@$`#````/=&`0`8````!$<!``8`
M```=1P$`$@```"1'`0`,````-T<!``,```!$1P$`*@```$A'`0`$````<T<!
M``8```!X1P$`!P```']'`0`?````AT<!`#4```"G1P$`+@```-U'`0`O````
M#$@!`!<````\2`$`(````%1(`0`;````=4@!`!@```"12`$`)````*I(`0`?
M````ST@!`!H```#O2`$`(`````I)`0`:````*TD!`#(```!&20$`+P```'E)
M`0`:````J4D!`"L```#$20$`'P```/!)`0`C````$$H!`!\````T2@$`&@``
M`%1*`0`E````;TH!`"8```"52@$`)0```+Q*`0`D````XDH!`!@````'2P$`
M'0```"!+`0`D````/DL!`!@```!C2P$`(@```'Q+`0`E````GTL!`#P```#%
M2P$`'P````),`0`C````(DP!`!\```!&3`$`(````&9,`0`:````ATP!`!@`
M``"B3`$`)@```+M,`0`>````XDP!`"D````!30$`'@```"M-`0`)````2DT!
M``P```!430$`%P```&%-`0`O````>4T!`"0```"I30$`!P```,Y-`0`?````
MUDT!``\```#V30$`%`````9.`0`.````&TX!``T````J3@$`)````#A.`0`%
M````74X!``<```!C3@$`(@```&M.`0`E````CDX!`!,```"T3@$`'0```,A.
M`0`:````YDX!``<````!3P$`QP````E/`0`+````T4\!`!4```#=3P$`#```
M`/-/`0`&`````%`!``D````'4`$`&````!%0`0`+````*E`!``T````V4`$`
M'0```$10`0`7````8E`!``8```!Z4`$`,P```(%0`0`3````M5`!`!,```#)
M4`$`!P```-U0`0`&````Y5`!``\```#L4`$`!P```/Q0`0`R````!%$!`"$`
M```W40$`$P```%E1`0`,````;5$!`!$```!Z40$`,@```(Q1`0`.````OU$!
M``\```#.40$`$````-Y1`0`(````[U$!`!T```#X40$`"0```!92`0`*````
M(%(!``4````K4@$`%````#%2`0`*````1E(!`!T```!14@$`"````&]2`0`?
M````>%(!``@```"84@$`&@```*%2`0`&````O%(!`!4```##4@$`!P```-E2
M`0`(````X5(!``D```#J4@$`/P```/12`0`'````-%,!``\````\4P$`#@``
M`$Q3`0`0````6U,!``D```!L4P$`"0```'93`0`(````@%,!`!,```")4P$`
M!P```)U3`0`9````I5,!``H```"_4P$`"@```,I3`0`)````U5,!`!<```#?
M4P$`%````/=3`0`*````#%0!``P````75`$`%P```"14`0`$````/%0!`"H`
M``!!5`$`$0```&Q4`0`'````?E0!``D```"&5`$``@```)!4`0`0````DU0!
M`!@```"D5`$`"P```+U4`0`#````R50!``@```#-5`$`!@```-94`0`'````
MW50!``T```#E5`$`"P```/-4`0`4````_U0!`!4````450$`#@```"I5`0`O
M````.54!`"````!I50$`'````(I5`0`,````IU4!`#$```"T50$`!0```.95
M`0`2````[%4!`#\```#_50$`$@```#]6`0`*````4E8!``8```!=5@$`!```
M`&16`0`$````:58!`!,```!N5@$`!0```()6`0`&````B%8!``8```"/5@$`
M"0```)96`0`$````H%8!``P```"E5@$`"@```+)6`0!L````O58!`"`````J
M5P$`!0```$M7`0`8````45<!`!D```!J5P$`'P```(17`0`=````I%<!`!$`
M``#"5P$``@```-17`0`$````UU<!``H```#<5P$`!@```.=7`0`%````[E<!
M``,```#T5P$`#````/A7`0!%````!5@!`!H```!+6`$`-0```&98`0`E````
MG%@!`"@```#"6`$`4P```.M8`0`9````/UD!`'(```!960$`(````,Q9`0`U
M````[5D!`"$````C6@$`10```$5:`0`P````BUH!`",```"\6@$`'P```.!:
M`0`H`````%L!`"D````I6P$`)@```%-;`0`E````>EL!`"@```"@6P$`*```
M`,E;`0`B````\EL!`"$````57`$`,````#=<`0`2````:%P!`!,```![7`$`
M$````(]<`0!Y````H%P!``D````:70$`<@```"1=`0!S````EUT!`'P````+
M7@$`*P```(A>`0!3````M%X!`!<````(7P$`%@```"!?`0`/````-U\!`&4`
M``!'7P$`'P```*U?`0!1````S5\!`#<````?8`$`-@```%=@`0`V````CF`!
M`#X```#%8`$`00````1A`0!#````1F$!`'P```"*80$`0`````=B`0`^````
M2&(!`$````"'8@$`0@```,AB`0`Y````"V,!`!\```!%8P$`'P```&5C`0`<
M````A6,!`%$```"B8P$`%````/1C`0`*````"60!``4````49`$`!@```!ID
M`0`(````(60!``4````J9`$`$@```#!D`0`0````0V0!`!,```!49`$`'0``
M`&AD`0`/````AF0!``\```"69`$`!````*9D`0`)````JV0!``L```"U9`$`
M!P```,%D`0`%````R60!`!0```#/9`$`!P```.1D`0`(````[&0!``\```#U
M9`$`"`````5E`0`,````#F4!``\````;90$`!@```"ME`0`4````,F4!``8`
M``!'90$`#````$YE`0`5````6V4!``@```!Q90$`!````'IE`0`*````?V4!
M``0```"*90$`!@```(]E`0`'````EF4!``0```">90$`!P```*-E`0`9````
MJV4!``(```#%90$`!````,AE`0`)````S64!``8```#790$`%0```-YE`0`&
M````]&4!`"<```#[90$`!````"-F`0`+````*&8!``D````T9@$`#P```#YF
M`0`3````3F8!``<```!B9@$`!P```&IF`0`&````<F8!``8```!Y9@$`$```
M`(!F`0`2````D68!``8```"D9@$`"0```*MF`0`S````M68!`"(```#I9@$`
M!P````QG`0`'````%&<!``<````<9P$`"P```"1G`0`%````,&<!``(````V
M9P$`"P```#EG`0#&`0``16<!`$8````,:0$`K0```%-I`0!?`````6H!`+0`
M``!A:@$`B````!9K`0!.````GVL!`$$```#N:P$`*P```#!L`0`S````7&P!
M`"T```"0;`$`*````+YL`0!,````YVP!`$L````T;0$`10```(!M`0!(````
MQFT!`$L````/;@$`60```%MN`0!!````M6X!`$P```#W;@$`/````$1O`0`L
M````@6\!`$8```"N;P$`/````/5O`0!$````,G`!`"@```!W<`$`.````*!P
M`0!B````V7`!`"X````\<0$`'0```&MQ`0"#````B7$!`#T````-<@$`"P$`
M`$MR`0`\````5W,!`#0```"4<P$`@P```,ES`0`]````370!``X```"+=`$`
M%0```)IT`0`'````L'0!``@```"X=`$`"@```,%T`0`*````S'0!`!````#7
M=`$`+````.AT`0`2````%74!``T````H=0$`#P```#9U`0`,````1G4!``@`
M``!3=0$`!0```%QU`0`=````8G4!``T```"`=0$`%0```(YU`0`0````I'4!
M``L```"U=0$`#@```,%U`0`D````T'4!`"(```#U=0$`(P```!AV`0`9````
M/'8!`!````!6=@$`"````&=V`0`3````<'8!`$$```"$=@$`(@```,9V`0`=
M````Z78!``T````'=P$`(````!5W`0`@````-G<!`"P```!7=P$`"P```(1W
M`0`+````D'<!``L```"<=P$`#P```*AW`0`&````N'<!`!P```"_=P$`$```
M`-QW`0`T````[7<!`!T````B>`$`(0```$!X`0`L````8G@!`!@```"/>`$`
M$````*AX`0`6````N7@!``L```#0>`$`&P```-QX`0`2````^'@!`!(````+
M>0$`"````!YY`0!4````)WD!`"X```!\>0$`&0```*MY`0`W````Q7D!`$``
M``#]>0$`4@```#YZ`0!0````D7H!`%@```#B>@$`5@```#M[`0`Y````DGL!
M``X```#,>P$`#@```-M[`0`%````ZGL!``8```#P>P$`&0```/=[`0`,````
M$7P!`!8````>?`$`&````#5\`0`2````3GP!``@```!A?`$`$0```&I\`0`G
M````?'P!`"8```"D?`$`$0```,M\`0`?````W7P!``\```#]?`$`!`````U]
M`0`$````$GT!`!$````7?0$`$````"E]`0`'````.GT!`!0```!"?0$`$0``
M`%=]`0`9````:7T!`!<```"#?0$`&````)M]`0`.````M'T!`!$```##?0$`
M"@```-5]`0`I````X'T!`"0````*?@$`$P```"]^`0`:````0WX!`!````!>
M?@$`2````&]^`0!!````N'X!`",```#Z?@$`(P```!Y_`0`&````0G\!``@`
M``!)?P$`2@```%)_`0`,````G7\!``@```"J?P$`"@```+-_`0`'````OG\!
M``@```#&?P$`#P```,]_`0`(````WW\!``H```#H?P$``P```/-_`0`9````
M]W\!``\````1@`$`&0```"&``0`4````.X`!`!(```!0@`$`*````&.``0`,
M````C(`!`"8```"9@`$`%@```,"``0`B````UX`!`!P```#Z@`$`$0```!>!
M`0`1````*8$!``X````[@0$`'P```$J!`0`&````:H$!``8```!Q@0$`"```
M`'B!`0`.````@8$!``<```"0@0$`"@```)B!`0`3````HX$!``@```"W@0$`
M#P```,"!`0`6````T($!`!<```#G@0$`"````/^!`0`%````"((!`!8````.
M@@$`'@```"6"`0`-````1((!`#````!2@@$`,@```(."`0`)````MH(!``<`
M``#`@@$`%````,B"`0`%````W8(!``4```#C@@$`$````.F"`0`+````^H(!
M`!H````&@P$`,P```"&#`0`/````58,!`#8```!E@P$`)@```)R#`0`S````
MPX,!`#(```#W@P$`,0```"J$`0`)````7(0!``@```!FA`$`!0```&^$`0`)
M````=80!``@```!_A`$`.0```(B$`0`M````PH0!`#@```#PA`$`4P```"F%
M`0`W````?84!`#<```"UA0$`-@```.V%`0`Y````)(8!`"4```!>A@$`*@``
M`(2&`0`W````KX8!`#T```#GA@$`#P```"6'`0`3````-8<!`"<```!)AP$`
M(````'&'`0`.````DH<!`!$```"AAP$`"P```+.'`0`,````OX<!`",```#,
MAP$`!@```/"'`0`,````]X<!`!H````$B`$`)@```!^(`0`&````1H@!``<`
M``!-B`$`%@```%6(`0`)````;(@!``@```!VB`$`!P```'^(`0`G````AX@!
M``8```"OB`$`"0```+:(`0`&````P(@!``4```#'B`$`!0```,V(`0`'````
MTX@!``8```#;B`$`"@```.*(`0`E````[8@!``\````3B0$`"0```".)`0`+
M````+8D!``4````YB0$`!P```#^)`0`'````1XD!``<```!/B0$`#@```%>)
M`0`'````9HD!`!,```!NB0$``P```(*)`0`(````AHD!``H```"/B0$`#0``
M`)J)`0`(````J(D!`",```"QB0$`$0```-6)`0`N````YXD!`"4````6B@$`
M"0```#R*`0`/````1HH!``P```!6B@$`!P```&.*`0`#````:XH!``,```!O
MB@$`%````'.*`0`4````B(H!``@```"=B@$`"````*:*`0`(````KXH!``<`
M``"XB@$`5P```,"*`0`D````&(L!``8````]BP$`!@```$2+`0`7````2XL!
M`!H```!CBP$`'````'Z+`0`M````FXL!`!L```#)BP$`+@```.6+`0!M````
M%(P!`"D```""C`$`"@```*R,`0`'````MXP!`!(```"_C`$`$0```-*,`0`/
M````Y(P!``X```#TC`$`%0````.-`0`0````&8T!`!0````JC0$`#P```#^-
M`0`5````3XT!``4```!EC0$`&0```&N-`0`;````A8T!`!,```"AC0$`%```
M`+6-`0`#````RHT!``P```#.C0$`!@```-N-`0`,````XHT!``\```#OC0$`
M8P```/^-`0`1````8XX!`!$```!UC@$`!````(>.`0`6````C(X!`#4```"C
MC@$`!0```-F.`0`$````WXX!`!X```#DC@$`&`````./`0`,````'(\!`!@`
M```ICP$`#````$*/`0`8````3X\!`"X```!HCP$`#@```)>/`0`B````IH\!
M`"H```#)CP$`'0```/2/`0`(````$I`!`!H````;D`$`&````#:0`0`3````
M3Y`!`!P```!CD`$`&````("0`0`4````F9`!``L```"ND`$`"````+J0`0`'
M````PY`!`!````#+D`$`%0```-R0`0`1````\I`!``@````$D0$`!0````V1
M`0`+````$Y$!``P````?D0$`"````"R1`0`-````-9$!``<```!#D0$`!@``
M`$N1`0`1````4I$!`!$```!DD0$`!P```':1`0`(````?I$!``L```"'D0$`
M#````).1`0`'````H)$!``4```"HD0$`"0```*Z1`0`4````N)$!``@```#-
MD0$`"````-:1`0`3````WY$!`"````#SD0$`"P```!22`0`.````()(!`!0`
M```OD@$`!0```$22`0`=````2I(!`!````!HD@$`$0```'F2`0`T````BY(!
M`$0```#`D@$`'P````63`0`J````)9,!``P```!0DP$`"@```%V3`0`/````
M:),!``<```!XDP$`"0```("3`0`/````BI,!`!(```":DP$`"@```*V3`0`1
M````N),!`"````#*DP$`(````.N3`0`C````#)0!`"0````PE`$`&````%64
M`0`A````;I0!`"$```"0E`$`)@```+*4`0`;````V90!`"````#UE`$`+P``
M`!:5`0`8````1I4!`"8```!?E0$`+````(:5`0`9````LY4!`!P```#-E0$`
M&````.J5`0`C`````Y8!`#4````GE@$`*0```%V6`0`F````AY8!`"8```"N
ME@$`,````-66`0`=````!I<!`!,````DEP$`+P```#B7`0`1````:)<!`!P`
M``!ZEP$`*0```)>7`0`;````P9<!`"$```#=EP$`#@```/^7`0"M````#I@!
M`!$```"\F`$`)````,Z8`0`D````\Y@!`"4````8F0$`(0```#Z9`0`;````
M8)D!`!0```!\F0$`(````)&9`0`A````LID!`"0```#4F0$`*@```/F9`0`<
M````))H!`!,```!!F@$`'@```%6:`0`I````=)H!`"4```">F@$`20```,2:
M`0!'````#IL!``\```!6FP$`!````&:;`0`2````:YL!``@```!^FP$`#@``
M`(>;`0`.````EIL!`!,```"EFP$`#0```+F;`0`4````QYL!``H```#<FP$`
M!````.>;`0`-````[)L!``P```#ZFP$`#P````><`0`/````%YP!`!,````G
MG`$`#````#N<`0`^````2)P!``L```"'G`$`$P```).<`0`$````IYP!``\`
M``"LG`$`%0```+R<`0`8````TIP!``\```#KG`$``@```/N<`0`%````_IP!
M``0````$G0$`$@````F=`0`%````')T!``L````BG0$`#````"Z=`0`#````
M.YT!``\````_G0$`"````$^=`0`8````6)T!``@```!QG0$`$````'J=`0`0
M````BYT!`!,```"<G0$`$````+"=`0`0````P9T!``@```#2G0$`#P```-N=
M`0`)````ZYT!``8```#UG0$`#@```/R=`0`,````"YX!`!@````8G@$`#```
M`#&>`0`.````/IX!`",```!-G@$`%0```'&>`0`A````AYX!``P```"IG@$`
M'@```+:>`0`7````U9X!`!4```#MG@$`'0````.?`0`D````(9\!``P```!&
MGP$`!@```%.?`0`3````6I\!`"P```!NGP$`#@```)N?`0`%````JI\!`",`
M``"PGP$`.P```-2?`0`%````$*`!``D````6H`$`'@```""@`0`+````/Z`!
M`!0```!+H`$`%````&"@`0`'````=:`!`!D```!]H`$`$@```)>@`0`8````
MJJ`!`!````##H`$`%0```-2@`0`(````ZJ`!``@```#SH`$`)@```/R@`0!'
M````(Z$!``@```!KH0$`%@```'2A`0`(````BZ$!``L```"4H0$`,````*"A
M`0`/````T:$!``4```#AH0$`!@```.>A`0`#````[J$!``<```#RH0$`!P``
M`/JA`0`,`````J(!``\````/H@$`#0```!^B`0`-````+:(!`!8````[H@$`
M%0```%*B`0`6````:*(!`!8```!_H@$`!0```):B`0`%````G*(!``L```"B
MH@$`"@```*ZB`0`"````N:(!``4```"\H@$`#P```,*B`0`A````TJ(!`!(`
M``#TH@$`$`````>C`0`/````&*,!`!$````HHP$`'@```#JC`0`Q````6:,!
M`"L```"+HP$`!0```+>C`0`*````O:,!``X```#(HP$`B0```->C`0`6````
M8:0!`$@```!XI`$`$````,&D`0`'````TJ0!``4```#:I`$`+````."D`0`H
M````#:4!`"(````VI0$`%@```%FE`0`'````<*4!``@```!XI0$`!P```(&E
M`0`'````B:4!``8```"1I0$`$````)BE`0`.````J:4!`!$```"XI0$`#P``
M`,JE`0`;````VJ4!`!$```#VI0$`#0````BF`0`7````%J8!``<````NI@$`
M#````#:F`0`)````0Z8!`!0```!-I@$`#0```&*F`0`[````<*8!`!D```"L
MI@$`"````,:F`0`3````SZ8!``@```#CI@$`'0```.RF`0`:````"J<!`"$`
M```EIP$`(````$>G`0`:````:*<!`!L```"#IP$`)P```)^G`0`:````QZ<!
M`"$```#BIP$`'@````2H`0`%````(Z@!`!X````IJ`$`$````$BH`0`.````
M6:@!``,```!HJ`$`!````&RH`0`)````<:@!``H```![J`$`#P```(:H`0`$
M````EJ@!`!@```";J`$`&0```+2H`0`/````SJ@!``T```#>J`$`#0```.RH
M`0`.````^J@!`!\````)J0$`!@```"FI`0`&````,*D!``L````WJ0$`#0``
M`$.I`0`-````4:D!``@```!?J0$`"````&BI`0`$````<:D!`!8```!VJ0$`
M"P```(VI`0`%````F:D!`"P```"?J0$`#P```,RI`0!S````W*D!`!D```!0
MJ@$`"0```&JJ`0`&````=*H!``H```![J@$`!@```(:J`0`(````C:H!``0`
M``"6J@$`"@```)NJ`0`5````IJH!`!(```"\J@$``@```,^J`0`$````TJH!
M``<```#7J@$`%0```-^J`0`5````]:H!`!$````+JP$`$````!VK`0`;````
M+JL!`!$```!*JP$`%````%RK`0`:````<:L!``(```",JP$``@```(^K`0`.
M````DJL!``8```"AJP$`"@```*BK`0`(````LZL!``4```"\JP$`&0```,*K
M`0`(````W*L!``8```#EJP$`%P```.RK`0`0````!*P!`"H````5K`$`"0``
M`$"L`0`'````2JP!``X```!2K`$`!0```&&L`0`)````9ZP!``T```!QK`$`
M!@```'^L`0`&````AJP!`!D```"-K`$`"P```*>L`0`%````LZP!`!(```"Y
MK`$`!P```,RL`0`'````U*P!`!@```#<K`$`'0```/6L`0`1````$ZT!``<`
M```EK0$`"@```"VM`0`$````.*T!``D````]K0$`"````$>M`0`+````4*T!
M``L```!<K0$`"P```&BM`0`&````=*T!``T```![K0$`!@```(FM`0`"````
MD*T!``0```"3K0$`.0```)BM`0!#````TJT!`#H````6K@$`,````%&N`0`%
M````@JX!``\```"(K@$`!@```)BN`0`(````GZX!`"$```"HK@$`&@```,JN
M`0`%````Y:X!``@```#KK@$`$P```/2N`0`(````"*\!`*8````1KP$`"0``
M`+BO`0`7````PJ\!``8```#:KP$`)````.&O`0`&````!K`!`!4````-L`$`
M!0```".P`0`+````*;`!``P````UL`$`"````$*P`0`)````2[`!``4```!5
ML`$`'````%NP`0`N````>+`!`#0```"GL`$`/````-RP`0`G````&;$!`"H`
M``!!L0$`/@```&RQ`0`X````J[$!`"@```#DL0$`,@````VR`0`M````0+(!
M`#4```!NL@$`*````*2R`0`2````S;(!`!,```#@L@$`#0```/2R`0`Q````
M`K,!`!P````TLP$`'````%&S`0`:````;K,!``<```")LP$`"````)&S`0`'
M````FK,!``@```"BLP$`)@```*NS`0`D````TK,!`#$```#WLP$`"0```"FT
M`0`8````,[0!`"@```!,M`$`%@```'6T`0`2````C+0!``8```"?M`$`#```
M`*:T`0`-````L[0!``\```#!M`$`#@```-&T`0`X````X+0!`(@````9M0$`
M6````**U`0`/````^[4!``L````+M@$`#````!>V`0`1````)+8!`!(````V
MM@$`#P```$FV`0`'````6;8!``\```!AM@$`%````'&V`0`1````AK8!``D`
M``"8M@$`"0```**V`0`.````K+8!`!X```"[M@$`+P```-JV`0!]````"K<!
M`!````"(MP$`!0```)FW`0`4````G[<!``D```"TMP$`"0```+ZW`0`)````
MR+<!`!D```#2MP$`$@```.RW`0`.````_[<!``X````.N`$`%````!VX`0`5
M````,K@!`!\```!(N`$`(0```&BX`0`=````BK@!`!\```"HN`$`(````,BX
M`0`B````Z;@!`!@````,N0$`-P```"6Y`0`/````7;D!`!$```!MN0$`$0``
M`'^Y`0`3````D;D!``T```"EN0$`$@```+.Y`0`4````QKD!``\```#;N0$`
M$0```.NY`0`R````_;D!`!H````PN@$`&````$NZ`0`[````9+H!`!,```"@
MN@$`"@```+2Z`0`3````O[H!`#````#3N@$`(@````2[`0`2````)[L!`"@`
M```ZNP$`&0```&.[`0`9````?;L!`!<```"7NP$`$@```*^[`0`=````PKL!
M`"````#@NP$`&@````&\`0`2````'+P!`!<````OO`$`%P```$>\`0`<````
M7[P!`!8```!\O`$`"````).\`0`8````G+P!``0```"UO`$`!0```+J\`0`+
M````P+P!`!````#,O`$`!@```-V\`0`,````Y+P!``<```#QO`$`!@```/F\
M`0`'`````+T!``4````(O0$`"`````Z]`0`8````%[T!``8````PO0$`!@``
M`#>]`0`(````/KT!``8```!'O0$`"````$Z]`0`2````5[T!`!D```!JO0$`
M$````(2]`0`1````E;T!``H```"GO0$`$0```+*]`0`$````Q+T!`"$```#)
MO0$`#P```.N]`0`/````^[T!`!8````+O@$`"P```"*^`0`)````+KX!``L`
M```XO@$`+P```$2^`0`$````=+X!``@```!YO@$`)````(*^`0`0````I[X!
M`!$```"XO@$`!@```,J^`0`)````T;X!``H```#;O@$`!0```.:^`0`C````
M[+X!``X````0OP$`$````!^_`0`5````,+\!`!<```!&OP$`'````%Z_`0`:
M````>[\!``4```"6OP$`!0```)R_`0`)````HK\!`!H```"LOP$`!P```,>_
M`0`&````S[\!``T```#6OP$`#@```.2_`0`'````\[\!``<```#[OP$`!0``
M``/``0`-````"<`!``X````7P`$`"@```";``0`0````,<`!`!(```!"P`$`
M%````%7``0`4````:L`!``T```!_P`$`%0```(W``0`(````H\`!``4```"L
MP`$`$0```++``0!"````Q,`!``4````'P0$`$@````W!`0`D````(,$!``\`
M``!%P0$`%0```%7!`0`.````:\$!``T```!ZP0$`#P```(C!`0`)````F,$!
M``\```"BP0$`#P```++!`0`1````PL$!`!````#4P0$`'@```.7!`0`*````
M!,(!``@````/P@$`%P```!C"`0`*````,,(!``P````[P@$`#````$C"`0`%
M````5<(!``P```!;P@$`"0```&C"`0`>````<L(!`&D```"1P@$`$P```/O"
M`0`+````#\,!``4````;PP$`!0```"'#`0`2````)\,!`!0````ZPP$`$P``
M`$_#`0`+````8\,!``(```!OPP$`"@```'+#`0`O````?<,!``,```"MPP$`
M!0```+'#`0`F````M\,!``H```#>PP$`!0```.G#`0`%````[\,!`!<```#U
MPP$`$@````W$`0`Z````(,0!`!4```!;Q`$`!@```''$`0`(````>,0!``@`
M``"!Q`$`!````(K$`0`%````C\0!`&X```"5Q`$`"@````3%`0`.````#\4!
M``8````>Q0$`!0```"7%`0`I````*\4!`#(```!5Q0$`$0```(C%`0`*````
MFL4!`!$```"EQ0$`"@```+?%`0`)````PL4!`!D```#,Q0$`)P```.;%`0`I
M````#L8!`"@````XQ@$`#P```&'&`0`&````<<8!``<```!XQ@$`"````(#&
M`0`.````B<8!`!(```"8Q@$`#P```*O&`0`1````N\8!`!(```#-Q@$`'P``
M`.#&`0`'`````,<!``X````(QP$`#````!?'`0`V````),<!`!\```!;QP$`
M-````'O'`0`?````L,<!``8```#0QP$`20```-?'`0`0````(<@!``H````R
MR`$`!@```#W(`0`=````1,@!`%8```!BR`$`!@```+G(`0`;````P,@!``@`
M``#<R`$`!@```.7(`0`4````[,@!``D````!R0$`"`````O)`0`I````%,D!
M`"@````^R0$`+P```&?)`0`)````E\D!``4```"AR0$`*P```*?)`0!E````
MT\D!`"D````YR@$`+@```&/*`0`8````DLH!``(```"KR@$`#0```*[*`0`%
M````O,H!`!0```#"R@$`"@```-?*`0`%````XLH!``4```#HR@$`"````.[*
M`0`&````]\H!``D```#^R@$`"P````C+`0`'````%,L!``@````<RP$`"P``
M`"7+`0`&````,<L!``X````XRP$`$````$?+`0`1````6,L!``T```!JRP$`
M#P```'C+`0`0````B,L!``\```"9RP$`#0```*G+`0`/````M\L!``@```#'
MRP$`'@```-#+`0`3````[\L!``@````#S`$`"@````S,`0`6````%\P!``<`
M```NS`$`#P```#;,`0`%````1LP!``<```!,S`$`!0```%3,`0`0````6LP!
M``4```!KS`$`"````'',`0`1````>LP!`!$```",S`$`&@```)[,`0`6````
MN<P!`!0```#0S`$`%P```.7,`0`:````_<P!`!\````8S0$`&0```#C-`0`#
M````4LT!``4```!6S0$`#@```%S-`0`.````:\T!`!0```!ZS0$`(@```(_-
M`0`+````LLT!``L```"^S0$`%````,K-`0`'````W\T!``H```#GS0$`!0``
M`/+-`0`-````^,T!``H````&S@$`#@```!'.`0`)````(,X!``4````JS@$`
M!P```##.`0`#````.,X!``0````\S@$``@```$'.`0`^````1,X!`#0```"#
MS@$`%````+C.`0`J````S<X!`$$```#XS@$`"@```#K/`0`M````1<\!`"P`
M``!SSP$`&@```*#/`0`S````N\\!`#<```#OSP$`-P```"?0`0`\````7]`!
M`!0```"<T`$`&@```+'0`0!*````S-`!`!D````7T0$`'0```#'1`0`9````
M3]$!`!L```!IT0$`'P```(71`0`>````I=$!`!L```#$T0$`#@```.#1`0`T
M````[]$!`#0````DT@$`.````%G2`0`T````DM(!`#T```#'T@$`-@````73
M`0`S````/-,!`'(```!PTP$`)@```./3`0`,````"M0!``H````7U`$`&P``
M`"+4`0`S````/M0!`#0```!RU`$`)P```*?4`0`-````S]0!`$0```#=U`$`
M/P```"+5`0`/````8M4!``4```!RU0$`&P```'C5`0`6````E-4!`!(```"K
MU0$`$0```+[5`0`9````T-4!``8```#JU0$`!P```/'5`0`)````^=4!``X`
M```#U@$`%````!+6`0`.````)]8!`!$````VU@$`"````$C6`0`>````4=8!
M``H```!PU@$`"````'O6`0`%````A-8!``L```"*U@$`#0```);6`0`+````
MI-8!`#H```"PU@$``@```.O6`0`&````[M8!`!````#UU@$`&@````;7`0`)
M````(=<!``4````KUP$`$P```#'7`0`(````1=<!``P```!.UP$`!````%O7
M`0`S````8-<!``X```"4UP$`*0```*/7`0!1````S=<!`!4````?V`$`.0``
M`#78`0`:````;]@!``\```"*V`$`#P```)K8`0`(````JM@!``\```"SV`$`
M"0```,/8`0`/````S=@!``H```#=V`$`%````.C8`0`,````_=@!`!H````*
MV0$`%0```"79`0`'````.]D!`!$```!#V0$`$0```%79`0`:````9]D!`!<`
M``""V0$`$0```)K9`0`0````K-D!`"$```"]V0$`!P```-_9`0`+````Y]D!
M`!0```#SV0$`$@````C:`0`0````&]H!``P````LV@$`!P```#G:`0`(````
M0=H!``4```!*V@$`(0```%#:`0`&````<MH!`!$```!YV@$`"````(O:`0`.
M````E-H!`",```"CV@$`!0```,?:`0`3````S=H!``\```#AV@$`+0```/':
M`0`N````']L!`"D```!.VP$`*````'C;`0`I````H=L!`"\```#+VP$`$@``
M`/O;`0`&````#MP!``<````5W`$`%P```!W<`0`&````-=P!`!(````\W`$`
M!0```$_<`0`5````5=P!``0```!KW`$`!P```'#<`0`6````>-P!`#$```"/
MW`$`!0```,'<`0`:````Q]P!`!,```#BW`$`"0```/;<`0`0`````-T!``0`
M```1W0$`#@```!;=`0`(````)=T!``<````NW0$`!0```#;=`0`(````/-T!
M``8```!%W0$`!0```$S=`0`@````4MT!`#<```!SW0$`-P```*O=`0`;````
MX]T!`"0```#_W0$`(P```"3>`0`_````2-X!`!L```"(W@$`)@```*3>`0`M
M````R]X!`%4```#YW@$`1P```$_?`0!3````E]\!`"H```#KWP$`)````!;@
M`0`&````.^`!``@```!"X`$`"0```$O@`0`+````5>`!`!<```!AX`$`$```
M`'G@`0`Q````BN`!`"0```"\X`$`-````.'@`0`X````%N$!``H```!/X0$`
M$0```%KA`0`B````;.$!`!(```"/X0$`!@```*+A`0`;````J>$!`!````#%
MX0$`$@```-;A`0`1````Z>$!``L```#[X0$`!P````?B`0`.````#^(!``@`
M```>X@$`"P```"?B`0`,````,^(!`!L```!`X@$`,@```%SB`0`*````C^(!
M``4```":X@$`"0```*#B`0`9````JN(!`!$```#$X@$`!````-;B`0`*````
MV^(!``L```#FX@$`$````/+B`0`6`````^,!``4````:XP$`!0```"#C`0`0
M````)N,!`"P````WXP$`2P```&3C`0`6````L.,!`"````#'XP$`&@```.CC
M`0`3`````^0!``4````7Y`$`$````!WD`0`'````+N0!`"4````VY`$`$0``
M`%SD`0`K````;N0!``D```":Y`$`#@```*3D`0`1````L^0!`!4```#%Y`$`
M&@```-OD`0`-````]N0!`#D````$Y0$`"0```#[E`0`=````2.4!`!,```!F
MY0$`%P```'KE`0`5````DN4!`!X```"HY0$`*@```,?E`0`L````\N4!``L`
M```?Y@$`+P```"OF`0`T````6^8!`#4```"0Y@$`+0```,;F`0!+````].8!
M`#H```!`YP$`,P```'OG`0`4````K^<!``8```#$YP$`#0```,OG`0`2````
MV><!``@```#LYP$`'````/7G`0`)````$N@!`!(````<Z`$`!P```"_H`0`4
M````-^@!`!H```!,Z`$`!P```&?H`0`'````;^@!`!````!WZ`$`#P```(CH
M`0`1````F.@!``4```"JZ`$`"````+#H`0`-````N>@!``T```#'Z`$`#@``
M`-7H`0`0````Y.@!`!````#UZ`$`!@````;I`0`(````#>D!`"X````6Z0$`
M)@```$7I`0`D````;.D!``<```"1Z0$`#@```)GI`0`&````J.D!`!T```"O
MZ0$`%@```,WI`0`;````Y.D!``H`````Z@$`"P````OJ`0`"````%^H!``,`
M```:Z@$`!@```![J`0`,````)>H!``(````RZ@$`#````#7J`0`3````0NH!
M``L```!6Z@$`&0```&+J`0`@````?.H!`!(```"=Z@$`!0```+#J`0`*````
MMNH!`!4```#!Z@$`$0```-?J`0`.````Z>H!``8```#XZ@$`"0```/_J`0`+
M````">L!`!`````5ZP$`20```";K`0`7````<.L!`#4```"(ZP$`!````+[K
M`0`(````P^L!``X```#,ZP$`)P```-OK`0`T`````^P!``X````X[`$`#```
M`$?L`0`B````5.P!`!<```!W[`$`#0```(_L`0`C````G>P!`!P```#![`$`
M#0```-[L`0!B````[.P!`"(```!/[0$`%@```'+M`0`K````B>T!`"````"U
M[0$`%````-;M`0`>````Z^T!`!8````*[@$`'P```"'N`0`?````0>X!`!@`
M``!A[@$`"@```'KN`0`'````A>X!``<```"-[@$`!````)7N`0`3````FNX!
M``T```"N[@$`$0```+SN`0`(````SNX!`%$```#7[@$`.P```"GO`0`[````
M9>\!`%D```"A[P$`+P```/OO`0`P````*_`!``H```!<\`$`"@```&?P`0`.
M````<O`!`#H```"!\`$`!@```+SP`0`[````P_`!`"X```#_\`$`(@```"[Q
M`0`/````4?$!`"T```!A\0$`&````(_Q`0`P````J/$!`"8```#9\0$`*```
M``#R`0`B````*?(!``\```!,\@$`"````%SR`0`.````9?(!``\```!T\@$`
M!P```(3R`0`]````C/(!``P```#*\@$`#@```-?R`0`Q````YO(!``@````8
M\P$`%P```"'S`0`(````.?,!``@```!"\P$`#P```$OS`0`,````6_,!``D`
M``!H\P$`"0```'+S`0`'````?/,!`!````"$\P$`$````)7S`0`7````IO,!
M``\```"^\P$`&P```,[S`0`3````ZO,!``@```#^\P$`#0````?T`0`,````
M%?0!``\````B]`$`#````#+T`0`9````/_0!`"P```!9]`$`#P```(;T`0`?
M````EO0!`"@```"V]`$`"````-_T`0`&````Z/0!`!````#O]`$`"0````#U
M`0`$````"O4!`!@````/]0$`#@```"CU`0`0````-_4!``X```!(]0$`!0``
M`%?U`0`)````7?4!``@```!G]0$`"0```'#U`0`'````>O4!``L```""]0$`
M$0```([U`0`$````H/4!`!4```"E]0$`#@```+OU`0`%````RO4!``L```#0
M]0$`#@```-SU`0`B````Z_4!``H````.]@$``@```!GV`0`>````'/8!``<`
M```[]@$`(````$/V`0`%````9/8!`'4```!J]@$`"P```.#V`0`'````[/8!
M`"D```#T]@$`-````![W`0`8````4_<!`"4```!L]P$`,@```)+W`0`G````
MQ?<!`"0```#M]P$`'````!+X`0`7````+_@!``4```!'^`$`!P```$WX`0`'
M````5?@!``P```!=^`$`"````&KX`0`-````<_@!`!,```"!^`$`#@```)7X
M`0`,````I/@!``X```"Q^`$`"P```,#X`0`'````S/@!``@```#4^`$`"```
M`-WX`0`6````YO@!``D```#]^`$`!P````?Y`0`)````#_D!`"`````9^0$`
M!0```#KY`0`&````0/D!``8```!'^0$`"@```$[Y`0`'````6?D!`!(```!A
M^0$`$@```'3Y`0`&````A_D!`!8```".^0$`"P```*7Y`0`;````L?D!``0`
M``#-^0$`!0```-+Y`0`/````V/D!`!P```#H^0$`!P````7Z`0`)````#?H!
M`!@````7^@$`%0```##Z`0`;````1OH!`!0```!B^@$`!````'?Z`0`*````
M?/H!``\```"'^@$`"@```)?Z`0`"````HOH!`!$```"E^@$`!P```+?Z`0`>
M````O_H!`$8```#>^@$`'@```"7[`0`S````1/L!`"4```!X^P$`*0```)[[
M`0!=````R/L!`!,````F_`$`'@```#K\`0!1````6?P!`"X```"K_`$`10``
M`-K\`0!<````(/T!`"````!]_0$`2````)[]`0`E````Y_T!`"@````-_@$`
M,@```#;^`0`C````:?X!`!T```"-_@$`+````*O^`0#V`0``V/X!`"8```#/
M``(`&P```/8``@`4````$@$"`$4````G`0(`A0```&T!`@!#````\P$"`#$`
M```W`@(`2@```&D"`@`X````M`("`!P```#M`@(`%0````H#`@`8````(`,"
M`!<````Y`P(`*P```%$#`@`<````?0,"`"@```":`P(`$P```,,#`@`,````
MUP,"`#````#D`P(`'0```!4$`@`W````,P0"`"(```!K!`(`)````(X$`@`A
M````LP0"`$(```#5!`(`4````!@%`@`D````:04"`#````".!0(`+P```+\%
M`@!"````[P4"`#`````R!@(`)@```&,&`@`Z````B@8"`&8```#%!@(`30``
M`"P'`@`O````>@<"`"<```"J!P(`*P```-('`@`L````_@<"`"@````K"`(`
M1````%0(`@!'````F0@"`)````#A"`(`4````'()`@!!````PPD"`$X````%
M"@(`+0```%0*`@`6````@@H"`"8```"9"@(`)0```,`*`@`E````Y@H"`"8`
M```,"P(`:````#,+`@!F````G`L"`*X````##`(`&P```+(,`@`J````S@P"
M`#8```#Y#`(`+P```#`-`@!%````8`T"`"````"F#0(`2@```,<-`@`A````
M$@X"``L````T#@(`MP```$`.`@`\````^`X"`"(````U#P(`,@```%@/`@`J
M````BP\"`!T```"V#P(`'````-0/`@`O````\0\"``8````A$`(`!P```"@0
M`@`#````,!`"``X````T$`(`"P```$,0`@`*````3Q`"``L```!:$`(`!0``
M`&80`@`+````;!`"``0```!X$`(`;@```'T0`@`$````[!`"`!8```#Q$`(`
M!`````@1`@`'````#1$"``4````5$0(`!0```!L1`@`$````(1$"`!`````F
M$0(`"0```#<1`@`(````01$"`!$```!*$0(`$P```%P1`@`"````<!$"``<`
M``!S$0(`!P```'L1`@`4````@Q$"``P```"8$0(`%@```*41`@`&````O!$"
M`!0```##$0(`#````-@1`@`#````Y1$"`"<```#I$0(`!````!$2`@`&````
M%A("``@````=$@(`&P```"82`@`T````0A("`"@```!W$@(`*````*`2`@`3
M````R1("`"````#=$@(`'0```/X2`@`;````'!,"`"`````X$P(`&P```%D3
M`@`:````=1,"`"(```"0$P(`%````+,3`@`Q````R!,"`"\```#Z$P(`%P``
M`"H4`@`F````0A0"`!H```!I%`(`'@```(04`@`>````HQ0"`!D```#"%`(`
M(P```-P4`@`?`````!4"`"(````@%0(`&@```$,5`@`;````7A4"`"````!Z
M%0(`(@```)L5`@`9````OA4"`"$```#8%0(`'@```/H5`@`X````&18"`!X`
M``!2%@(`(@```'$6`@`B````E!8"`",```"W%@(`'0```-L6`@`8````^18"
M`"(````2%P(`(0```#47`@`R````5Q<"`"````"*%P(`"@```*L7`@`,````
MMA<"`!8```##%P(`+@```-H7`@`@````"1@"``H````J&`(`'0```#48`@`/
M````4Q@"`!<```!C&`(`#@```'L8`@`6````BA@"`"$```"A&`(`"````,,8
M`@`'````S!@"`"(```#4&`(`)0```/<8`@`2````'1D"`"4````P&0(`&```
M`%89`@`)````;QD"`.(```!Y&0(`$0```%P:`@`5````;AH"``L```"$&@(`
M#````)`:`@`/````G1H"`"````"M&@(`%@```,X:`@`3````Y1H"`#(```#Y
M&@(`'P```"P;`@`*````3!L"`#8```!7&P(`%0```(X;`@`4````I!L"``<`
M``"Y&P(`"````,$;`@`3````RAL"``H```#>&P(`-P```.D;`@`I````(1P"
M`!8```!+'`(`%````&(<`@`4````=QP"`#````",'`(`%@```+T<`@`7````
MU!P"`!(```#L'`(`$0```/\<`@`D````$1T"`!(````V'0(`$P```$D=`@`)
M````71T"`!$```!G'0(`"@```'D=`@`7````A!T"``@```"<'0(`(````*4=
M`@`(````QAT"`!,```#/'0(`!P```.,=`@`1````ZQT"``<```#]'0(`"```
M``4>`@`)````#AX"`#8````8'@(`!0```$\>`@`/````51X"`!0```!E'@(`
M$0```'H>`@`+````C!X"``P```"8'@(`!P```*4>`@`3````K1X"``L```#!
M'@(`&P```,T>`@`0````Z1X"`!````#Z'@(`#0````L?`@`:````&1\"`!<`
M```T'P(`"P```$P?`@`,````6!\"`!@```!E'P(`"0```'X?`@`J````B!\"
M`!$```"S'P(`"@```,4?`@`,````T!\"``(```#='P(`$````.`?`@`7````
M\1\"``L````)(`(``P```!4@`@`*````&2`"``4````D(`(`!P```"H@`@`,
M````,B`"``L````_(`(`%````$L@`@`5````8"`"``X```!V(`(`.````(4@
M`@`8````OB`"`!@```#7(`(`"@```/`@`@`M````^R`"``4````I(0(`%@``
M`"\A`@`_````1B$"``T```"&(0(`#@```)0A`@`&````HR$"``0```"J(0(`
M!````*\A`@`7````M"$"``4```#,(0(`!@```-(A`@`(````V2$"``P```#B
M(0(`!0```.\A`@`/````]2$"`!`````%(@(`7````!8B`@`J````<R("``4`
M``">(@(`%P```*0B`@`>````O"("`!\```#;(@(`(@```/LB`@`.````'B,"
M``(````M(P(`!````#`C`@`+````-2,"``4```!!(P(`!0```$<C`@`#````
M32,"``X```!1(P(`3````&`C`@`<````K2,"`"H```#*(P(`*````/4C`@`E
M````'B0"`$\```!$)`(`'P```)0D`@!9````M"0"`!T````.)0(`1P```"PE
M`@`@````="4"`#,```"5)0(`,P```,DE`@`B````_24"`!X````@)@(`*```
M`#\F`@`T````:"8"`#4```"=)@(`-````-,F`@`P````""<"`"8````Y)P(`
M(@```&`G`@`B````@R<"`#@```"F)P(`%````-\G`@`4````]"<"``X````)
M*`(`8P```!@H`@`*````?"@"`&<```"'*`(`8P```.\H`@!<````4RD"`"<`
M``"P*0(`80```-@I`@`;````.BH"`!@```!6*@(`$0```&\J`@!?````@2H"
M`!T```#A*@(`10```/\J`@!'````12L"`$8```"-*P(`,0```-0K`@`R````
M!BP"`#$````Y+`(`0````&LL`@!T````K"P"`#@````A+0(`,0```%HM`@`Y
M````C"T"`#````#&+0(`)P```/<M`@`<````'RX"`"(````\+@(`&P```%\N
M`@!6````>RX"`!8```#2+@(`"@```.DN`@`$````]"X"``8```#Y+@(`"```
M```O`@`%````"2\"`!4````/+P(`$@```"4O`@`9````."\"`",```!2+P(`
M#P```'8O`@`-````AB\"``0```"4+P(`"0```)DO`@`-````HR\"``@```"Q
M+P(`"0```+HO`@`6````Q"\"``L```#;+P(`"@```.<O`@`5````\B\"``D`
M```(,`(`!@```!(P`@`3````&3`"``H````M,`(`%@```#@P`@`*````3S`"
M``@```!:,`(`#@```&,P`@`(````<C`"``@```![,`(`#````(0P`@`)````
MD3`"``<```";,`(`!@```*,P`@`&````JC`"``H```"Q,`(`&0```+PP`@`"
M````UC`"``0```#9,`(`"````-XP`@`&````YS`"`!4```#N,`(`!@````0Q
M`@`I````"S$"``4````U,0(`"0```#LQ`@`*````13$"`!,```!0,0(`&0``
M`&0Q`@`(````?C$"``<```"',0(`!@```(\Q`@`*````EC$"`!````"A,0(`
M&0```+(Q`@`(````S#$"``P```#5,0(`*0```.(Q`@`C````##("``H````P
M,@(`"0```#LR`@`-````13("`!````!3,@(`!0```&0R`@`"````:C("``L`
M``!M,@(``0`````````-`0``:`0``#8!`````````````````````````@4`
M``````!I!```QP(``/\&``!>`@```````$(&````````DP<``!0!``#<`@``
M`````"8&```*`P``O`0``+L'``#[``````````````"^!0``C`$```````!W
M!`````````````#D``````````````!4`0``NP8``/(#``#6`P```````%@"
M``````````````8"``!_`0``P`0````````"!P``NP````````!O`0``]@,`
M``````#$!@``I`4``%\#`````````````#L%``#[`P``=`4``(,#``"*`0``
M`````"P```!S`0````````````"2`@``-00``-@&````````3`4```````#M
M`P``N@,``&,!``!P`````````(8`````````M`(``"<'``"J!```?`$``!P%
M```F`@``/08````````6`0``KP0``!D#``#4!0````````````!7!P``[`0`
M`)`&`````````````!`$```.!@``:`<``,<!`````````````,H&``"8!@``
M`@$``$`%```G!@``=`$``&T$``#-`P``000``"`#``````````````````#7
M!```>````.8&``!;`0```04``/<%``"'!0``X0$```````#/`@``L00``$X'
M`````````````!T%```1`P``PP(``#\!````````:@<```````"=!P``/@``
M``````!_!@````4```8$```O````QP0````````)`@``H04````````R!P``
M&@,``!`#``"K!P``*`,``*4%````````K`0``!H'``"R`P``00$`````````
M`````````"X$``#M`0``Y`8``#4&``#T!0```````*(#```K`@``1`8``$P$
M```>`@``X`$``.T`````````0P4```````"5!```I08``)``````````Y@``
M``````"4!@``]`$````````N```````````````@````+P<````````#!```
M`````'8'``#8!```^@8``%0%``!M!P```````!,"``#*`P``<`$``+H`````
M````5````````````````````'(```#J`P```````/X%`````````````$L#
M````````J0<``!D%``"R!P``X00```````!2`0``2`<``"<$````````M`0`
M``````!$````Q@$``*$#````````A`0``/,%```&!P``F`4``-`%````````
M?P4``&H```![`P``P@8```T&``#F!```M08``)H%``#X`@```````#0```##
M`P``N@0```````"]!@``8P<```<$```Y`@```````%\$``#[`@``B`,``(<#
M``!;!P```````%X!````````5@<``'4"````````N@8``%,'````````````
M`#P"``#Z!```N04```````````````````````#N`@```````!4'````````
M508```4'```)!0```````*D&``#I`@``N`8```````"S!@``10$``'<#```D
M!0``!P$```````````````````@!`````````````"4#``!=!```IP0``'$%
M``#$!0``L08``"0"```W!`````````````!B`P``'0``````````````(00`
M``````!\````/00``.L%````````2@0``&8`````````C0$``"T"``!D!P``
M&0<``",&``"1!```6@$````````R!````P$``(<'```B!@``^0```!\&``#<
M!@```````,D```#,`@````````````"^!@``!0(``"8!``!Z`0``%0,``",`
M``"8!```;`0``&$$```W`0``L0<```\'``"Y````V`$``%,%``#I````````
M``````#3`P``(`$``+@'``!%`@```````)\$````````600```\#``!@`P``
M#04``(X````````````````````)!@``$P```%@'``"$!@``7P8``-H%``"2
M````,@,``&@```"@`P``&@(``(('``!<`P``\0,``%L```">!0``V@,`````
M``#U!@``J`$``(L%``!*`P``7P(``&H"``#-!```/`<```````"7!@``H`8`
M``````!]`0``,@8``-8&``"7`0``9``````'``!1!P```````+\&``!S`P``
MZ04``,D$``!W`@``]0,``-X%```T`@`````````````S!@``DP(```````!D
M`P````````````````````````````!'````SP,```````"K!0```````'4$
M``"N````Y@(``-L!````````/`4``%4$````````U`0``#\$```S`0``````
M`+P#````````YP4``+("`````````````"H!``#M!0``2@$``,X````]`P``
MQP,``"$#```@!```1@<``(P%``#.`0``O@<```````#"!0``J`4``*`'``#2
M`P``F0````````"!`@``M@,`````````````F0<``#@$````````<@<``+X!
M``"6`P``KP<``-D$``#_`P```````#\#``!``@```````$T'``#<`0``*0$`
M`,L$``!?!0``BP$``*<```";`0``:P,``$P"```]!0````````(&``#.`@``
M80,````````O`P``PP$``)@'``!=`0```````'@&````````0P,``+T$``!#
M````Y0,```X"````````GP(```````!Y`0``W0(``*$&``")````````````
M``"*`@```````(\#```M````JP8``-````",!@``````````````````5P,`
M`!@#```*`0``T@$```````!(!```4P,`````````````-@````("```Q`@``
M=0,``$0!``!R`0```````%T%``"3````6@````````"]`P``3@8``+X$``#<
M`P``G04``+H"``"0`P``>0```-@%````````%`0```````!.`@``G`,``(\$
M````````P0$``'`$``"_`P``30(``!,$``"2!```SP4``#D%````````MP,`
M``````!5````<`4``)$"````````_`$``&T#```H!@``A@4``.,`````````
M*@0``&($``"!`P``T0(``,8"``#$`0``'`8``!\'``"+!```)@0``$X$```W
M`P```````&L```"-!```$`8``/X#```L!```(@(``*8!``#1!@``````````
M``#J`````````!<!``"*!`````````````!C`@``P@$``)D$``#P`@``@@$`
M`#$'```>!P``_@$``+`'```(`````````$`!````````_````"$!``#T````
MA00``*X$``"2!P``HP<``-T```!0!P``E````+P&````````MP8``&<'````
M`````P8`````````````1`,``'<%```Y!P``3P```'H$``!G!0```````+X`
M``"!!P``>@8```4#````````UP8``&D%````````/P8``(@$```,`P``````
M`/P#``!E!````````%\```!A````/`,``$4$``!%!P``?`4``*X%````````
M`````$\"```Q!````````&8&``"3!@```````%D#``!H`@``R`(``+,%````
M````M@<`````````````]`8```L`````````)P4``(@```!Q!P``8P,``/,!
M`````````````.P`````````00(``"@!```E!0```````)P```".`@``G@8`
M`+X"``!0!0```````/`&``!_!````````!H````<`P```````%P!``!5!P``
M/0```%L$``!)`0``<@0````````0!0``,@4``#,$``"P`@``F0,``$0%```U
M`@``QP4``'D#``#1!```Q0```%4%````````?`0``,@%``!`!P``````````
M``#\!```7P<````````U!P````````<%```\````S0```%<$````````"00`
M`%`&````````H0```%$#``#$!```4P8``/H%```4`P``&0```#0$``";!P``
M`````````````````````(4"``#*`0``WP,``(<!``#C!@``0P8``(P```#&
M!````````$8%````````:@8``/T%````````:@0``.L"``#%!@``4P(``&8"
M``#%!```,0$``#\"````````'@4```````#?!0``C`0``(,&``#6!```90,`
M`%,````F`P``20(``)L%``#C`0``1@0``&D"``"2`P``K@(``%<"````````
M-@4``````````````````!,!``#D!0```````/4$``#%`P``6`4``(`````U
M`0``*04``*P&``!Q!@``L@```'@#```Z`P``?P<``,L"``!^!0``5@8`````
M```>!@``J`8```L!````````;P0``*@#```P!0``K0<``,D!``#Q!0``````
M`$X````M`P``4P$``$4&`````````````'`'``"?`0```````$<!``#6!0``
MNP4``!`"````````-`<``+4%```M!@```````(,%````````2`8`````````
M`````````.$%`````````@```)P'```*`@``^@,``'<!``"(`@``_@8`````
M``"E`````````$D'``!G`P```````(($``"5`0``E`4```````#-`0``"@0`
M`$@!``#J`0``SP$```````"'!@``'P0``,P%```<````L`4`````````````
M%P(``+<!``!-`````````%P$```/````.@8````````^!0````````````#9
M`0``B@8``$8```"V`0```````+4$````````10``````````````6`$`````
M``#X!0```````"\&``#M!@``I`8``)(%```P`0``%P,``'D"``#9!0``````
M`"X%```M!P``RP,````````I!P```````&,$`````````````!<```"Q`P``
M0@4``"$'``"B!0``;`4``%$&````````]P````4```!<!0``N08`````````
M````@`4``&(```#,!@```````*H!````````B@4``.D!``#T`@``M0(``(@&
M``"$`0``608```\&``#1`P``&`4````````H`@``;P4``,8#``!(!0``!@$`
M`%8"`````````````)8'```W!@``6@0``$8!``!Z!0``B@<```````##!```
MI`<``'L&``!?`0``U`$``"<```"F!@``H@(````````$`@``ZP,``)8&``!I
M!P``T@4``"@$```!!```"@```&P#```!!@``>00``"X#``"O!@``P08`````
M``#L`P``:`4```````#S`@``"0```"0!``#(!@``]P0``$("````````````
M`.4$````````/@0``.T"```H!0```````(4#``#!!P``+@8```````#.`P``
MK@$``%8#``#%`0``;`$``"4!````````$@0``%H"```6`````````&X`````
M````Z`,``.,#````````G`4`````````````$P,```````!>!```S@0``#P&
M```5!```C04``(X%``#Q!```YP$``-L$````````_0```$@"``#@!```````
M`&(&````````BP(``$X#``!<````LP,````````O!````````!0`````````
M]0``````````````A@(``',$``#Q````W@,``)D!``!2`````````&,`````
M````G@```"L#``"J!0``)0<`````````````+`,``+8&```$!````````-0"
M````````Y`0``%<!````````*@<````````4!P``=P`````````8`@``#P0`
M`&`%``"#````0@```#L#``"B!@``>@,``(,$``#7`@``L0```)H!```S!P``
MM`,``)P&````````/P<``-$%````````_P(``(D"``!^!```$0<``,L!``!G
M!@``C`,``/D!``!,````<P(``,D%``!#`@``_@(``!L"``"6`@``-@(``-X"
M``!/!P``#P$``-H$``!2`@``-P<```````"?`````````*4!````````L0$`
M`($&``"[`0``'P,``-\$``"`!````````&$'``#5!0``804``$($````````
MT@8``%$$``!0`P````````````")!0``8P8``-,%``#K````O0<``/D#````
M```````````````K!P``T0$``)`'```'!@```````'(&``!U!P```````!T"
M```T`0````````````!L!P``A@,``)(!``!-!@``Z`(``%T'```D`P``LP(`
M`(0"``!K`0```0,``/\%````````<P4```````!0````WP8``'\"``!^````
MJ0,``*T%``"=`````````#L&``!_`P``,P,``-T#````````AP(```4%``"=
M`@```````-($```;`P```````)L$``#A`P```````&T&`````````````-0`
M``"(`0``9P0``"8'``````````````````"D`P``.@$````````8!```!@8`
M`&X"`````````````-4!``#N!0```````*<&``"G`@``=P<``%L"``#B`0``
MW08``*<#``"I!`````````,```#@````T`,``%@```#]`0``,`(````````^
M!@``!`8``!X```#J`@``U08```````!Y!P``=````-L#``#R!```7`8``!L`
M````````UP$``+(&``#``0```````-`"````````$@8``"D&``"#`0``C@8`
M`'X!````````K`,``"L$``#6````J@```"0'``"C````$0(``$X!``""!0``
M,08``&@!``"<`@```````(("``!!!0````````0%``":!```30$``(,"```V
M!```,@$``)@"```%`0```````.H$``#C`@```````)<"``!O!P``!00`````
M````````B0$`````````````"`(``.`"````````?P```*\#``"^`P``&P0`
M`%H&``#/!@``=@8``$\!```.!```HP8``',```!F!`````````4&``!G````
M&@4`````````````K@8```````!3!```?@,``!H&```Q!0``UP4``)<```#;
M`@``40```)L"`````````````%L#``!'!0``4@,`````````````Y08``&@#
M```O`@``[@$``&X&```?!0```P4``.X```#;``````````````!*!@``$`$`
M`````````````0<``%X&`````````````+4````+!P``M0$```````#0!```
MM@0```H%``!\!P``H`0```````#,`0``-`8``.4%````````3@4``-<```#9
M`P``]@0``/H````.`0``,P(```````"-!@``E`$``+H'``")!@``.@(``(\&
M``#Z`0``7@4````````P`P```````$L&``#`!0``)P,``/,#``#I!```&P<`
M`#(```!D!0``!`````@&````````=P8``+$"`````````````"L%``"X!```
MA08``)$#``"$!P``90```%T"``!5`@``2@```(0#``#X````LP0``)X$``!+
M!0``N````-H&`````````````$````!9`@``K@,``"H"````````````````
M``"&!@```````#<"```M!```"P(```````#Z`@``304````````6!P``N0,`
M``````!D!@``4@0``%('`````````````*@`````````6@4``(@%````````
M`````.P!````````/@<``+L"```8!@```````-8"`````````````((```#8
M`P````````````"K`0```````)X!```[`0``%`8``#H```!M`0``T@(``,4%
M````````"0$``*($``">`@```````)P$``"%!P``KP4``&`$```1!```?@<`
M``````"0`0``5@0``!8&``#>!```?0,``$<&```8`0``,`<``"0$```.!0``
M``````````#,!```604``&T"``"M`@``.08``.`#``!!````Y@4``%4#``#*
M!0```````,@$````````W00``'8"`````````````&<"```S````1P0`````
M``!:`P```````,D&``!#`0````````````#?`0``I@<```````!`!```]`,`
M`+(!``!Y!0``I0(``$H%````````\08``-`!``#O`@``7@<```````!+````
MB0,``$('`````````````&H#``#_`````````!4!``"Y`0``+`$`````````
M````*@,``!L%```@`@``^P4``/@!``````````````````"7`P``:@4`````
M```J`````````-$`````````/`$``#@``````````````$`&````````/@,`
M`$@````2!0`````````````,!P```````-4```"V!0``;P(``"T%```I`P``
MX08```@$```?`0``O`$``-0#```1````$P4``+\%```I`@``(P0```````"H
M`@``W@8```````!A`0``-0```.,%``!6!0``/0<``(`#````````.`<`````
M``!&!@``?`8``#\```!4`P``'P(``!P$``"W!P``OP(``.\$```3!P``````
M````````!@``C0,```````!]!@``HP4``)8$````````(P4``)P!``"L`0``
M`````"($```U`P```````&@&``#]!```FP8``+`````!`@````````````!7
M````[`8``'@$````````DP$``*T&````````H0<`````````````-@8``"P'
M```B!0``;04``%P"````````P0,```````"W!````````(`"```0````````
M````````````I0<``,T&``#V``````````````#Y`@``)`8```````!K!```
M4@4``,0#````````^`,````````&````8@$`````````````4`0``(X!``"\
M````3P0`````````````DP4``.<"`````````````)@```!+!P``_0(``!L&
M``!'!P```````&('``![`0``G0$``+`!```I!```]0$``,@#```(`P``=`<`
M`"P%``#L!0``$04``'8!``!)!@``I00`````````````!`<```````#P````
MP0(``'0&````````8`$`````````````#0,``(`'```)!P```````(X$``#H
M!0``R0(``````````````````$$&``"0!0``C@,``#\%``!Z````=04``"<"
M``!#!P```````.@!``#Y!0``AP```$T$``"B!P``+@$```````#P`0``````
M`*P%``"I````/@$``+\`````````(0`````````/!0```````&X%````````
MM`4``!T$```+!`````````````"L`@``DP,```@%```-!P``Y`,```````!I
M`0``K@<``(@'````````>P(``/8"```J!@``2`,````````9!@``A04```H&
M``"%`0``N0(``````````````````&D#``!F!P``V````-T%``#+````[@,`
M`/\$``"V````,P4``"H%``"H!`````0``+`&``"X!0```````+0&```W````
M*P```)0$```E````C0```.0!``!]!0``)@```%@$``!B`@``N@$``'4`````
M````[@8``'8$```E`@```0$``#4%``#Y!@``#@,``*\!```5`@```````"`'
M``"K`P``&@0``$(#``"I`@``$@<``#0#````````Z@4``*8"````````P`,`
M`#8#```:`0``_`(```````#-!0``E0```,`````F!0``.`4``!`'``#+!0``
M'08``#L$``"@`0``>@<``'X"``#[`0``I@````@'```=!P``8`<``",!````
M`````````#@"``#.!0``8P4```````!1!0``2P0```<"``"O`@``-P4`````
M``"=`P``CP(``$8#``"Z!0```````/\!``!I!@```````/P&``#'!@``X@4`
M```#``#B````G00``)H`````````L`,``+@!```9!````````'4&``"-`@``
MWP(``'@%````````90$```````"]`0``P`<``*L$``#;!@```````(`!````
M````*P8``%(&```'!P``<0,``.\``````````````!D"``#I!@``BP```*<'
M```D````/0(``#0%````````$08``)`"```'`P``%@(``%D!```#!P``>@(`
M`!$!`````````````,,`````````>P<```````"1`0``>`<``$\%```\!```
M904`````````````:P8``-P```!P`P``[`(``$P#``#*`````````-,&````
M````F08``$\#``!%!0``TP(``%T`````````<0(``)\%`````````````$<#
M``!A!@```````'$!``#&````GP8``$D$``"7!0```````"4$````````````
M``````!^!@``X@0`````````````+@<```````"1!0```````$T#````````
M`````$D%```>!```1P(````"````````H`(````````A`@``\`,```````"T
M`0``A0```/8%``![````D0````````!T!```]0(``*$$````````'@$``+`$
M```A!@``X@,``!4```!F`0``6P4``$`#```^`@``R@(``)0'````````90<`
M`"(!``!]`@````````````#G!@``^`8``'D&`````````````,`&``"G!0``
MGP<``,X&````````E0(``%T#````````Q0(``#D#`````````````&(%``#?
M````X`8``,@!``#V`0``;`8``$P'``"$`````````#`$```[!P``/0$`````
M````````.`,``/<"``#T!```G@,``)4%``#R`0``P00``%0&```<`@``_@``
M`.,$````````8`8``"4&``"R!```\`4``#L```".!P``;@0```````#J!@``
M`````,H$``"K````*``````````2`P``J@(``)L#``">!P``V0(```````"4
M`@```````"X"```O`0``D0<``%X#``"S`0```````'0"``"&!P``.`$``!<'
M``"M!```V@(``%@#``"6!0``^00``&\&``!\`P```@,``.`%``!+`0``````
M`)4#``"S````8`````L%``#5`@``;P```*,!``"6`0``0P0`````````````
M%P8``'$```",`@``#`0``*T`````````N`(```,"``!@`@```````,L&```9
M`0``2@<``'`"``"\!P```````)H'```L`@``#P(``%X```#R!@``HP,``.T$
M```-`@```````%@&```7!```(P<``'`&`````````````/P%``#S!@``+`8`
M``````!)````B@```"(#``"#!P``V@```)H&``````````````````#E`0``
M_0,``+4'``#O!@```````,("````````MP4``&$"``#F`P```````$(!``!=
M!@```````%$"``"$!0``>`$```````#W!@````````````!T`P``00,`````
M````````<@,``!8%``#S`````````+\!``"!````TP0`````````````@00`
M``````!D!```+P4``,0`````````OP0``,@`````````$@(```````!N!P``
M```````````Q`P``M@(``.\#``#"!```BP,``/$!``#6`0``'0,``(T'``"C
M!`````````X````P!@``\@```*8%````````\P0```````!$!```B00`````
M`````````````)D%``!0`0``K0$``,8&``#-`@``N0<``/T&``!1`0``+0$`
M``````!4!P``G08``&L%``!R!0```````*P'``"/````F@(``*8$````````
M`````%<&`````````````(8!``#``@``6P8``*<!``!\`@``I@,``%H'``#O
M!0```````&P```#0!@``H0$``/("``#>````PP4````!```3!@``?0```","
M````````5P4``````````````````'4!````````ZP8``%D'``":`P``J@<`
M`"@'``!6`0```````-,```"@````ZP$```T$``#B!@````````````!N`0``
MK0,``(8$``"_!P``60````````"B`````````%`"``!S!@``V@$```````";
M````T@```&D````Q````CP$``(P'``"\!0``00<``((&```;`0``K````*0$
M``"]````I0,``!@`````````>`(``$\&```B!P``L04``),$``!,`0``@04`
M`+L$```<!P``CP4``/(%`````````````&T`````````.@0``*0```"9`@``
MP04``'$$````````B@,``%P'````````$@```*@'```$`0```````-X!``!S
M!P``9P$``$0"````````N00`````````````D08```````"B`0```````.@`
M```G`0``%@0``)0#```6`P``*P$``)@#``#9!@```````.<$````````P@``
M`+0``````````````+<"```Z!0``9`(``(<$````````&`<``.4"``!E`@``
M"P,````````,`````````.$"``#E````(`8``'8```#5`P``9`$``!X#```'
M``````````0#```#`P``NP,``+0'```=`0```````'T'``#)`P``JP(``#``
M``#B`@``BP<```D#```Y`0``W`0``*$"``!E!@``%`(``+4#``#O`0``````
M`&L"``#=`0``VP4``)(&````````2@(``$P&``#"`P``Z0,````````Y!```
MO`(``(\'``"I`0``TP$``,\$```B````^P0``+(%``#V!@``KP```/L&``"S
M!P``P0```/4%``#F`0``UP,```````#8`@`````````````[`@``N`,```($
M````````,@(```````!J`0``\0(````````.!P```````!0%``"]`@``````
M`/X$``"0!```(`4``$4#````````I`$``*0"```X!@````````````"5!P``
M9@4``'8#```Y````@0$```````!N`P``(04`````````````J@8```````#D
M`@``!@,``.<`````````]P,`````````````Q`(```````!R`@```````$D#
M``![!```EP<``!(!``")!P``'`$``"D````,`@``HP(``.@&``!L`@``````
M`$L"``!F`P``:P<``,P`````````%04```8%``"J`P``EP0````````,`0``
M5`(``%8`````````(P,``'8%``#&!0``'P```(L&``"6````QP```-D```!4
M!```;P,```````#5!```%08```P&``#W`0``#0````P%````````1@(`````
M``#H!```[@0```````!]!```@@,``-P%````````H`4````````+!@``F`$`
M`)\#````````U`8``'L%``#,`P``J04```````#G`P```````!<%``"5!@``
M"@<``.$````V!P```````+<```##!@``^`0``/`$```Z!P``1`<```````"`
M!@``O04``%4!``#/````ZP0````@("U-+"`M+6UE<W-A9V4]34534T%'12`@
M57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F875L
M="!O;F5S+@`@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F
M:6QE('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&\*("`@("`@("`@("`@
M("`@("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A(&1I9F9E
M<F5N="!B<F%N8V@@=&\*("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E
M;F5R871E9"!C;VUP96YD:75M+@`@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@
M<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L
M9"!B90H@("`@("`@("`@("`@("`@("`@('5S960N`"`@+6,L("TM8V]M<&5N
M9&EU;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M
M<&5N9&EU;2!F:6QE"B`@("`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D
M(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4*("`@
M("`@("`@("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2X`("`M
M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL
M92!I;G-T96%D(&]F('1H92!D969A=6QT"B`@("`@("`@("`@("`@("`@("`@
M("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C
M=&]R>2DN`"`@+60L("TM9&5B=6<@("`@("`@4VAO=R!E<G)O<B!M97-S86=E
M<R!F<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RX`("`M9"P@+2UD:7)E8W1O
M<GD]1$E2("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN
M`"`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY('1H:7,@;&]C86QE
M+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+@`@
M("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T
M:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@
M0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE
M+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R86YS;&%T:6]N
M<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@
M4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@
M+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S(&]N;'D@9F]R
M('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M("!5<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO
M9'5L93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@
M*$AO<F1E*2!M;V1U;&4N`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG
M="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP96YD:75M+@`@
M("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU
M;2X`("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A;G-L871I;VX@
M<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N`"`@+70L("TM=&5S="`@("`@
M("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U;B!A
M;GET:&EN9RX`("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P
M(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+@`@(&-O
M;6UI="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V
M97(N`"`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE($-6
M4R!S97)V97(N`"`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU
M;2!F:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE"B`@("`@("`@
M("`@("`@8W5R<F5N="!C;VUP96YD:75M+@`@(&5X=')A8W0@("`@($=E;F5R
M871E(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RX`("!H96QP("`@("`@("!3
M:&]W('1H:7,@:&5L<"!M97-S86=E+@`@(&EN:70@("`@("`@($-R96%T92!O
M;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG
M.B!4:&ES"B`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@
M4$\@9FEL97,@;V8@=&AI<R!L;V-A;&4N`"`@;6%K92`@("`@("`@0G5I;&0@
M8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!03R!F:6QE<RX`
M("!M86ME+6AE;'`@("!-87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L
M<"!F:6QE(&)E:6YG('5P+71O+61A=&4@86YD"B`@("`@("`@("`@("`@<')E
M<&%R92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T
M92UH96QP+B!9;W4*("`@("`@("`@("`@("!S:&]U;&0@;VYL>2!R=6X@;6%K
M92UH96QP($%&5$52('5P9&%T92UH96QP(&%N9"!R979I<VEN9R!T:&4*("`@
M("`@("`@("`@("!H96QP(&9I;&4N`"`@;65R9V4@("`@("`@365R9V4@=&AE
M(&-U<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E
M(&9I;&4N`"`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E
M<75E;G0N`"`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N
M9V5D(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<`H@("`@("`@
M("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@
M;VYE<RX`("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN
M=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A
M9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@*'EE<W1E<F1A>2D`(&%T
M(``E9"`E<R!A;F0@)7,`)60@8GET97,@=W)I='1E;BX`)60@;V8@)60@96YT
M<FEE<R!M87)K960@87,@=7`M=&\M9&%T90`E9"UD87D@9F]R96-A<W0`)7,@
M+2!.;W1I8V4`)7,@061M:6YI<W1R871I;VX`)7,@0V]N9FEG=7)A=&EO;@`E
M<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!H87,@8V%N
M8V5L;&5D("5S+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U
M97-T+@`E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`
M)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:7,@
M;F]T('=R:71A8FQE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO
M="!F;W5N9"X`)7,@;F]T(&9O=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X=')A
M8W0G(&9I<G-T+@`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RX`)7,@=&\@
M)7,@;V8@)7,`)7,@=VES:&5S('1O(&%D9"!T;R`E<RX`)7,@=VES:&5S('1O
M(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E<R!W:7-H97,@=&\@<F5C96EV92!T
M:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+@`E<R=S($%D9')E<W,@
M0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T
M`"5S.B`E<P`E<SH@=6YA8FQE('1O(&QO860@9')I=F5R.B`E<P`G)7,G(&ES
M(&YO="!A('9A;&ED(&-H;VEC92X`)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"<E<R<@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N`"<E<R<@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`G
M)7,G('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G
M('=A<R!N;W0@8W)E871E9#H@)7,N`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA
M8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R
M-"!H;W5R<P`\9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RX*
M3W!E;FEN9R!T86<@9F]U;F0@:6X@;&EN92`E9"X`02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!1%-)(&5R<F]R("5S+@!!32!3
M:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN
M+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P="!R97%U97-T`$%C8V5P=&5D
M`$%C8V5S<R!$96YI960N`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I
M<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C
M;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I
M;VYS`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`
M061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D
M9"!A(&-H:6QD(&=R;W5P('1O("<E<R<`061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R`G)7,G`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@
M;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(`061D('1H:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E
M<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E
M9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET
M:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@)R5S)R!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!N97<@9FEL
M97,@=&\@<F5P;W-I=&]R>3H`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!
M9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N
M:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`
M06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E
M<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E
M<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E
M861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U3
M4"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@
M96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T
M97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X
M>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI
M8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN
M`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<FEL`$%R86)I8R`H
M5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`
M07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T
M92`G)7,G(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`
M07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA
M;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF
M:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_
M`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@
M9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1R:6)U=&5S`$%U9W5S
M=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S
M`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A
M;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL86)L
M92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`0D]&2"!%
M>&-U<V5S`$)A8VME;F0@;F]T(&-O<G)E8W1L>2!I;7!L96UE;G1E9"X`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L
M=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87)E`$)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!"87-E;&EN
M90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N
M`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@
M9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQO8VL@<V5L96-T
M:6]N`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC
M:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O
M='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN
M9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5I;&1I
M;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!"=6EL9&EN9R!L;V-A;&4@
M)7,N+BX@`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U
M<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0
M<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`
M0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`
M0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B
M+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO
M;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0
M:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E
M<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U
M.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L
M($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E
M<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#
M:&%N9V4@4&%S<W=O<F0`0VAA;F=E('!A<W-W;W)D(&]N.@!#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@<&%S
M<W=O<F0`0VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,`0VAA<@!#:&5C7VL@3&EN
M:RXN+@!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO
M;W-E(&%N(&%C=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR
M:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N
M9"X`0VQE86YI;F<@=7`@4$\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!#;&5A
M;FEN9R!U<"!L;V-A;&4@)7,N+BX@`$-L96%R`$-L96%R($U33V9F:6-E('1A
M9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D
M871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO
M<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I
M80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#
M;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M
M;6%N9"!O<'1I;VYS.@!#;VUM86YD<SH`0V]M;65N=`!#;VUM:71T:6YG.@!#
M;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&QE=&5D`$-O;7!O<V4@
M365S<V%G92`H)7,I`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!N965D<R!U<&1A=&EN9RX`
M0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9FER;2!N97<@<&%S
M<W=O<F0Z`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O
M9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RX`0V]N=&5N=',@;V8@)R5S)P!#;VYT:6YU90!#;V]K($ES
M;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]P>6EN9R`E<R!T
M;R`E<P!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!B:6YD
M('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C86QL(&9U;F-T:6]N("5S(&EN
M(&%P<&QI8V%T:6]N("5S+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@<V5R=F5R("<E<R<@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@
M8V]P>2`E<R!T;R`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R
M(&QO8V%L92`E<SH`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD
M(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S
M)RX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL
M(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R
M:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S)RX`
M0V]U;&0@;F]T(&UK9&ER("<E<R<N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC
M(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#
M;W5L9"!N;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E
M;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D
M:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S
M=V0N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L
M9"!N;W0@<FUD:7(@)R5S)RX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U<F%T:6]N("5S+@!#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`0V]U
M;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI
M;FL@)R5S)RX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I
M=&4@8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@)7,`0V]U;&1N)W0@9FEN9"!T
M:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@
M;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R
M:6=H=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,`0V]U;G1E9"!T97AT`$-O
M=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N
M97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS
M`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!0:&%S
M90!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P
M=6)L:6,`1$0`1&%I;'D`1&%T80!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T
M92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`
M1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN
M9&5N=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!0
M97)M:7-S:6]N<P!$969A=6QT('!E<FUI<W-I;VYS`$1E9FEN:71I;VYS`$1E
M;&5G871E('!O<VET:6]N`$1E;&5G871E9`!$96QE=&4`1&5L971E($=R;W5P
M`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)P!$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E
M;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O
M=P!$96QE=&4@=&AI<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N`$1E;&EV
M97)Y('1I;64`1&5N;6%R:P!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O
M<B!F<F5E+V)U<WD@:6YF;W)M871I;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`
M1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN
M:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I
M=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@
M4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I
M;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!P97)M:7-S
M:6]N<R!F;W(@)R5S)P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE
M;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O
M;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@
M=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'
M86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@
M;65N=3\`16YD`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C
M=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U
M(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T
M:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE
M<F4`16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@
M)60@8VAA;F=E9"P@)60@=6YK;F]W;@!%<75A=&]R:6%L($=U:6YE80!%<FET
M<F5A`$5R<F]R`$5R<F]R('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N`$5R
M<F]R('-E;F1I;F<@<F5P;'DZ("5S+@!%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N`$5R<F]R('=R:71I;F<@)R5S)RX`17)R;W(Z(`!%<W1O;FEA`$5T:&EO
M<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AE8W5T90!%>&5C=71I;F<Z`$5X<&%N9`!%>'!A;F0@4VED96)A
M<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AT<F%C=&EN
M9R!F<F]M("5S+BXN(`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E
M<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P
M>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I
M;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!V97)I9GD@
M;VQD('!A<W-W;W)D+@!&86EL=7)E(&EN(&-H86YG:6YG('!A<W-W;W)D(&]N
M("5S.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O
M92!)<VQA;F1S`$9A=&%L($5R<F]R(0!&87@`1F5B<G5A<GD`1F5E;',@3&EK
M90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1FEJ:0!&:6QE($-O=6YT.B`E
M<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE
M($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S
M(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I
M<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E
M<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P
M87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`
M1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1F]U;F0@87!P;&EC871I;VYS
M.B`E<P!&;W5N9"!D:7)E8W1O<FEE<SH`1G(`1G)A;65S`$9R86YC90!&<F%N
M8V4L($UE=')O<&]L:71A;@!&<F5E+T)U<WD@26YF;W)M871I;VX`1G)E92]"
M=7-Y(%)E<&QY`$9R964O0G5S>2!297%U97-T`$9R964O0G5S>2!297%U97-T
M(%)E<W!O;G-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$
M97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9U>GIY`$=A8F]N`$=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;F5R871I
M;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BX`1V5O<F=I80!'97)M86YY`$=E
M=&]P="!%<G)O<CH@`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O
M961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E3
M3RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T
M:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI
M<W-I;VYS`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T
M8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2$@`2%1-3`!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL
M(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H
M;0!(87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I
M;F<@961I=&]R`$AE;'!E<@!(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E
M(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D90IF<F%M
M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N"D9O<B!A;B!I;G1R;V1U8W1I
M;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O<GDN`$AE
M;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(
M:6=H`$AI<W1O<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM96UP='D`2&]?
M;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D
M9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R
M9&4@=')A;G-L871I;VX@9V5N97)A=&]R`$AO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S
M("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E
M("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I
M>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(
M;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I
M='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R
M97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@
M=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T
M:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC
M;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS
M('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE
M8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@
M>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@
M>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ
M`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E
M('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD
M.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@
M069T97(`26YC;W)R96-T(%!A<W-W;W)D`$EN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I
M9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);FET:6%L
M:7II;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E
M<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@
M7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T
M(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS
M97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU
M;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S
M`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O
M<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@
M=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ
M`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T
M`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI
M='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A
M;&ED(')E8VEP:65N=#H@)R5S)P!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A
M;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV
M96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD
M`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`
M271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H
M25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`
M2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T
M:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@
M3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG
M=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@
M;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`
M3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S
M="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ
M("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`
M3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,
M96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,
M:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,
M:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H
M="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC
M:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S
M('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI
M;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES
M="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T
M+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O
M<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG
M(&QI8G)A<FEE<RXN+@!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@
M86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG
M('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I
M;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-
M3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'
M`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI
M;E]K+BXN`$UA:V4@<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS=&%L;&5D
M(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"X`36%K:6YG(&1I<F5C=&]R>2`E
M<P!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L
M86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD
M<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I
M=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X
M8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S
M="`V(&AO=7)S.B``36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I
M;F4`365E=&EN9R!#86YC96QL871I;VX`365E=&EN9R!);F9O<FUA=&EO;@!-
M965T:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P;'D`365E=&EN9R!5<&1A=&4`
M365E=&EN9R!5<&1A=&4@4F5Q=65S=`!-96UB97)S`$UE;G4@;6]D93H`365R
M9V4@8V5L;',`365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E
M;F1I=6TN+BX@`$UE<F=I;F<@;&]C86QE("5S+BXN(`!-97)G:6YG('1H92!0
M3R!F:6QE(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!T
M<F%N<VQA=&EO;B!F;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`
M365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D
M`$UE=&AO9"`G)7,G(&ES(&YO="!D969I;F5D`$UE=')I8P!-97AI8V\`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E
M`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D
M`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P
M;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-
M;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`
M36]D=6QE`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO
M;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N
M(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO
M<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V
M92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N
M=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O
M($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5E9',@06-T:6]N`$YE
M<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E
M($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E
M($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C
M87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y
M`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD
M`$YE=R!P87-S=V]R9#H`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G
M<F]U<',`3F5X=`!.97AT(%!A9V4`3F5X="!0:&%S90!.97AT(&]P=&EO;G,`
M3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I
M;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@
M9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA
M9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H
M92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E
M9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL
M9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E
M;"X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO
M;BX`3F\@8V]M;6%N9"!S<&5C:69I960N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N`$YO(&5N=')Y('=I=&@@=&AE(&ED("<E<R<@97AI<W1S(&EN('1H92!O
M<FEG:6YA;"!H96QP(&9I;&4N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@
M9F]U;F0N`$YO(&QO8V%L92!S<&5C:69I960N`$YO(&QO8V%T:6]N(&ES('-E
M="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO
M(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W
M:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE
M<P!.;R!S:61E<P!.;R!S=6-H(&)A8VME;F0@)R5S)R!F;W5N9"X`3F\@=&5M
M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.
M;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`3F]N90!.;VYE
M("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@
M27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)
M<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E
M8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N
M`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I8V4`3F]V
M96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C
M;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/
M8FIE8W0@0W)E871O<@!/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<P!/8W1A
M;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@<&%S<W=O<F0Z
M`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S
M:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,
M(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O
M34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P
M97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/
M<'1I;VYS(&9O<B`E<P!/<'1I;VYS.@!/<F1E<F5D($QI<W0`3W)G86YI<V%T
M:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A
M;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y
M`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL
M`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H
M96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W9"!I<R!N;W0@<')O<&5R;'D@8V]N9FEG
M=7)E9"X`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!O;B`E<RX`4&%S<W=O
M<F0@:6YC;W)R96-T`%!A<W-W;W)D(&UO9'5L92!C86XG="!F:6YD('1H92!S
M=7!P;&EE9"!B:6XN`%!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG(')E<75I
M<F5D('!A<F%M971E<G,N`%!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG('1A
M<F=E="!P87)A;65T97(N`%!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R
M;'D@8V]N9FEG=7)E9`!087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY
M(&-O;F9I9W5R960N`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W
M;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!0
M87-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O
M<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N("<E<R<@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS
M($%D;6EN:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O
M<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I
M=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O
M;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C
M871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE
M87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D
M87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`
M4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H
M('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E<&]R="!A
M;GD@8G5G<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R9RX`4&QE87-E(')E=FEE
M=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@
M86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@
M86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O
M<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R97-E;G1A=&EO;G,`4')E<W-U<F4`4')E<W-U<F4@
M870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!086=E`%!R979I;W5S
M(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0
M<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI
M8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`
M46%T87(`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L
M96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`
M4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL
M>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C
M=&EO;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0
M;W)T86P@5FEE=SH`4F5F<F5S:"!3:61E8F%R`%)E9V5X`%)E;&%T:6]N<VAI
M<"!"<F]W<V5R`%)E;6%R:W,`4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BX`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M
M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@9G)O;2!M>2!C
M86QE;F1A<@!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E
M;6]V92!U<V5R.B`E<P!297!L>2!396YT+@!297!L>2!W:71H($YO="!3=7!P
M;W)T960@365S<V%G90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R
M(&UO;G1H<RX`4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+@!297!L>3H@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E
M9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=6ER960@)R5S)R!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("<E<R<@;F]T
M('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)R5S
M)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D
M<FEV97)S)R!I<R!M:7-C;VYF:6=U<F5D(&EN($-O;7!O<VET92!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!0
M87-S=V0@4U%,(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N
M;W0@<W!E8VEF:65D(&EN(%-13"!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!0
M87)T:6-I<&%N=`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<W5L=',`4F5S=6QT<R`H:6YC;'5D:6YG($AO<F1E*3H`4F5S
M=6QT<SH`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG
M=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H
M=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN
M+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@
M4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L
M97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA
M;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE
M;&P`4U,`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`
M4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O
M;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B
M:6$`4V%V90!3879E("5S`%-A=F4@)R5S)P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S
M)RX`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H:6YG($AO
M<F1E(&%P<&QI8V%T:6]N<R!I;B`E<P!396%R8VAI;F<@9V5T=&5X="!B:6YA
M<FEE<RXN+@!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G
M<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E
M<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N
M96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N
M9"!,871E<W0@26YF;W)M871I;VX`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD
M(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E
M=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA
M>2!O<'1I;VYS+@!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C
M97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N
M=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE
M(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@
M4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`
M4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N
M('5P(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG
M;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VMI<'!E
M9"XN+@!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@
M4VAO=V5R<P!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`
M4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D
M<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A
M;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O
M;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R
M(%1R96L`4W1A<G0`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T
M=7,`4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@`%-T;W)A9V4@9F]R;6%T`%-T
M<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@
M9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER
M96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FIE8W0@4'5B;&EC
M($ME>2!);F9O`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@)R5S
M)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U
M<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S
M<P!3=6-C97-S9G5L;'D@861D960@)R5S)R!T;R!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+@!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`G)7,G(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E
M<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N("5S
M+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U
M8V-E<W-F=6QL>2!U<&1A=&5D("<E<R<`4W5C8V5S<V9U;&QY('=R;W1E("5S
M`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E
M`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P
M97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N
M9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC
M`%0M4W1O<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R
M=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@
M;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T
M92`G)7,G(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5N
M=&%T:79E;'D@06-C97!T(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`
M5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)
M4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E
M;2X`5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VXG="!Y970@97AI<W0N
M($-R96%T:6YG(&$@;F5W(&]N92X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($UA:6YT96YA;F-E.CH@8VQA
M<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD
M;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E
M9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME
M;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M
M('-I9&4@;VYL>0!4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED`%1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N
M(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H
M92!E=F5N="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+@!4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE
M(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E
M<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N
M8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BX`5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\
M/WAM;`!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H
M92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&%S:R!H87,@
M8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=&]P(&%N9"!B;W1T
M;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R
M964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S
M(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO
M;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@
M9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E(&1O97-N
M)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RX`5&AE<F4@=V%S(&$@
M<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+B`E<RX`5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@)R5S
M)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V
M:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R`G)7,G.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I
M<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL
M92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L
M86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@
M<&%R<V5R+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E
M8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@86-T:6]N(&ES(&YO
M="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT
M960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A
M>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E
M;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A
M;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S
M('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U
M8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI
M;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N
M`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I
M8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L
M96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`
M5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O
M=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&5D`%1R86YS
M;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`
M5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R
M(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP
M="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='D`56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RX`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@
M8V]M;6%N9#H@)7,`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL
M:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@
M<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA
M=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5;G1R
M86YS;&%T960`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N9&5N="!S
M=&%T=7,`57!D871E('5S97(`57!D871E9"`G)7,G+@!5<&1A=&EN9R`E<R!H
M96QP(&9I;&4@9F]R("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO
M860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M
M8F5R<P!5<G5G=6%Y`%5S86=E.@!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!
M9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92X`57-E<B!N;W0@9F]U;F0`57-E<B!N;W0@9F]U;F0N`%5S97(@<&5R
M;6ES<VEO;G,`57-E<FYA;64`57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T
M<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,`57-E<G,@:6X@=&AE('-Y
M<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A
M;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU
M97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E
M<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@
M2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I97<@979E;G0`
M5FEE=R!T87-K`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V%R
M;FEN9SH@`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I
M9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M
M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y
M+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T
M(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q
M=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H
M(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F
M="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE
M('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD('-P965D
M(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W1S`%=O<FL`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)I=&EN9R!N;W0@<&]S<VEB;&4N
M(%EO=2!C86X@96ET:&5R('5S92!T:&4@879A:6QA8FQE('5P9W)A9&4@<V-R
M:7!T(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`%=R
M:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@)7,N`%@M4F5F`%@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U
M,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO
M;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9
M;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+@!9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O<B!U<V5R("5S
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E
M;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@
M)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG
M=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E
M('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@
M<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\`66]U(&UU<W0@9VEV92!Y;W5R(&-U<G)E;G0@<&%S<W=O
M<F0`66]U(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9`!9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U
M(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%EO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL
M($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N
M`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D
M9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]/<'1I;VX@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N
M86UE.@!9;W5R(&=E='1E>'0@=F5R<VEO;B!I<R!T;V\@;VQD(&%N9"!D;V5S
M(&YO="!S=7!P;W)T(%!(4"!N871I=F5L>2X*3F]T(&%L;"!S=')I;F=S('=I
M;&P@8F4@97AT<F%C=&5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!L;VYG.R!P87-S=V]R9',@
M;6%Y(&YO="!B92!M;W)E('1H86X@)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R
M(&YE=R!P87-S=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H
M86YG960A`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E
M<W,N($YO="!C:&%N9V5D(0!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T
M(&QE87-T("5D(&-H87)A8W1E<G,@;&]N9R$`66]U<B!N97<@<&%S<W=O<F0@
M;75S="!B92!D:69F97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0`
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L
M<&AA8F5T:6,@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C
M;VYT86EN(&%T(&QE87-T("5D(&%L<&AA;G5M97)I8R!C:&%R86-T97)S+@!9
M;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@9&EF
M9F5R96YT('1Y<&5S(&]F(&-H87)A8W1E<G,N(%1H92!T>7!E<R!A<F4Z(&QO
M=V5R+"!U<'!E<BP@;G5M97)I8RP@86YD('-Y;6)O;',N`%EO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!L;W=E<F-A<V4@8VAA
M<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE
M87-T("5D(&YU;65R:6,@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@
M;75S="!C;VYT86EN(&%T(&QE87-T("5D('5P<&5R8V%S92!C:&%R86-T97)S
M+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@;&5S<R!T:&%N("5D
M('=H:71E<W!A8V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S
M="!N;W0@8V]N=&%I;B!W:&ET97-P86-E(&-H87)A8W1E<G,N`%EO=7(@;F5W
M('!A<W-W;W)D<R!D:61N)W0@;6%T8V@`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T92!S
M97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P
M>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1
M=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML
M:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851R964`
M7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN
M+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?
M4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O
M<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%N(&5R<F]R(&AA<R!O
M8V-U<F5D.@!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`9&]N90!F86EL960`
M9F%L;&EN9P!F:6QE`&9O=6YD.B``9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<P!H.@!I,3AN`&EM;65D:6%T90!I;FQI;F4`;&1A<%]S=&%R=%]T;',@9F%I
M;&5D`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RX`;F%M90!N;W0@8VAA;F=E9`!N;W0@9F]U;F0`;F]T(&EM<&QE;65N
M=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L
M<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``
M<W1E861Y`'1A<VL@;&ES=`!T:&4@2&]R9&4@4$\@9FEL92!F;W(@=&AE(&QO
M8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7!D871E9`!U<V5R('-E
M;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ
M(%!A<W-W9`I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-"TQ,2TR-2`P.3HQ.2TP.#`P
M"E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,3$M,C4@,#DZ,3DM,#@P,`I,87-T
M+51R86YS;&%T;W(Z(%!A=F5L($-H>71I;"`\<&%V96Q`8VAY=&EL+G1K/@I,
M86YG=6%G92U496%M.B!#>F5C:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]/3$@
M)B8@;B4Q,#`A/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@;B4Q,#P]-"`F)B`H;B4Q
M,#`\,3`@?'P@;B4Q,#`^/3(P*2`_(#$@.B`R*3L*`"`@+4TL("TM;65S<V%G
M93U:4%+!5D$@(%!O=;[M="!T=71O(%I04L%652!N82!M[7-T;R!I;7!L:6-I
M=&[M('IP<N%V>2X`("`M82P@+2UA9&0]4T]50D]2("`@("`@4/AI9&%T('1E
M;G1O(%!/('-O=6)O<B!D;R!K;VUP96YD:6$@*'#X96AL961U*2X)"0D@5;YI
M=&7H;ND@<')O('IA:')N=73M(&MO;7!E;F1I[2!Z(&II;OUC:"!M;V1U;/D*
M("`@("`@("`@("`@("`@("`@("`@("`@9&\@9V5N97)O=F%NZ6AO(&MO;7!E
M;F1I82X`("`M8BP@+2UB87-E/2]#15-402`)(-IP;&[A($-%4U1!(&L@>N%K
M;&%D;NUM=2!A9')E<^'X:2`H2&]R9&4I+"!K=&5RX2!B>0H)"0D@;>QL82!B
M_70@<&]UOFET82X`("`M8RP@+2UC;VUP96YD:75M/5-/54)/4B`@4VQO=>AI
M="!N;W;I('#X96ML861Y(&1O('1O:&]T;R!K;VUP96YD:6$*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:6X@;>US=&\@:6UP;&EC:71N[6AO("AC;VUP
M96YD:75M+G!O('8*("`@("`@("`@("`@("`@("`@("`@("`@("`@861R97/A
M^&D@:&]R9&4O<&\N`"`@+6,L("TM8V]M<&5N9&EU;3U33U5"3U(@(%!O=;[M
M="!T;VAO=&\@:V]M<&5N9&EA(&YA(&WM<W1O(&EM<&QI8VET;NUH;PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`H8V]M<&5N9&EU;2YP;R!V(&%D<F5S
MX?AI(&AO<F1E+W!O*2X`("`M9"P@+2UD96)U9R`@("`@("!:;V)R87II="!C
M:'EB;W;A(&ALX;EE;NT@>F4@<W!O=;ET[&[]8V@@8FENX7)N[6-H('-O=6)O
M<ODN`"`@+60L("TM9&ER96-T;W)Y/4%$4D53P=@@("!6>71V;_AI="!K;VUP
M96YD:75M('8@=&]M=&\@041215/!V$DN`"`@+6@L("TM:&5L<"`@("`@("`@
M6F]B<F%Z:70@='5T;R!NX7!O=NQD=2X`("`M;"P@+2UL;V-A;&4];&Q?0T,@
M("`@(%!O=;[M="!P;W5Z92!T96YT;R!L;V-A;&4N`"`@+6PL("TM;&]C86QE
M/6QL7T-#("`@("!0;W6^[70@=&5N=&\@;&]C86QE+@`@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6TL("TM;6]D=6QE/4U/
M1%5,("`@(%9Y='9O^&ET($U/('-O=6)O<GD@<&]U>F4@<')O('1E;G1O(&UO
M9'5L("AV($AO<F1E*2X`("`M;2P@+2UM;V1U;&4]34]$54P@("`@5GEM87IA
M="!03R!S;W5B;W)Y('!O=7IE('!R;R!T96YT;R!M;V1U;"`H=B!(;W)D92DN
M`"`@+6TL("TM;6]D=6QE/4U/1%5,"5IA<'-A="!P^&5K;&%D>2!P;W5Z92!P
M<F\@=&5N=&\@;6]D=6P@*'8@2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-3T15
M3`E6>71V;_AI="!03R!S;W5B;W(@<&]U>F4@<')O('1E;G1O(&UO9'5L("AV
M($AO<F1E*2X`("`M;2P@+2UM;V1U;&4]34]$54P@("`@4VQO=>AI="!03R!S
M;W5B;W)Y('!O=7IE('!R;R!T96YT;R!M;V1U;"`H=B!(;W)D92DN`"`@+6TL
M("TM;6]D=6QE/4U/1%5,("`@($%K='5A;&EZ;W9A="!S;W5B;W)Y('!R;R!N
MX7!O=NQD=2!P;W5Z92!V('1O;71O(&UO9'5L=2`H=B!(;W)D92DN`"`@+6TL
M("TM;6]D=6QE/4U/1%5,("`@($%K='5A;&EZ;W9A="!P;W5Z92!T96YT;R!M
M;V1U;"`H=B!(;W)D92DN`"`@+6TL("TM;6]D=6QE/4U/1%5,"59Y9V5N97)O
M=F%T(%!/5"!S;W5B;W(@<&]U>F4@<')O('1E;G1O(&UO9'5L("AV($AO<F1E
M*2X`("`M;BP@+2UN;RUC;VUP96YD:75M"4YE<VQUZ&]V870@;F]VZ2!P^&5K
M;&%D>2!S(&MO;7!E;F1I96TN`"`@+6XL("TM;F\M8V]M<&5N9&EU;0E.97!O
M=;[M=F%T(&MO;7!E;F1I=6TN`"`@+7,L("TM<W1A=&ES=&EC<PE5;&^^:70@
M<W1A=&ES=&EK>2!P<F\@</AE:VQA9'D@9&\@;>US=&[M:&\@<V]U8F]R=2X`
M("`M="P@+2UT97-T"2`@(%IO8G)A>FET('!O=;YI=/T@</CM:V%Z+"!A;&4@
M;FEC(&YE<')O=N%D['0N`"`@8VQE86YU<`E6>>AI<W1I="!03R!S;W5B;W)Y
M(&]D(&YE<&]UOFET_6-H(&$@>F%S=&%R86S]8V@@</AE:VQA9/DN`"`@8V]M
M;6ET(`E5;&^^:70@</AE:VQA9"!D;R!#5E,@<V5R=F5R=2X`("!C;VUM:70M
M:&5L<`E5;&^^:70@<V]U8F]R>2!S(&[A<&]V[&1O=2!D;R!#5E,@<V5R=F5R
M=2X`("!C;VUP96YD:75M"5#X96)U9&]V870@<V]U8F]R(',@:V]M<&5N9&EE
M;2X@5F%R;W;A;NTZ(%1A=&\@;W!E<F%C92!P^&5P[;EE"@D)<V]U8F]R(',@
M:V]M<&5N9&EE;2X`("!E>'1R86-T"4=E;F5R;W9A="!03R!V>F]R;W;I("@N
M<&]T*2!S;W5B;W)Y+@`@(&AE;'`)"5IO8G)A>FET('1U=&\@<W!RX79U+@`@
M(&EN:70)"59Y='9O^&ET(&IE9&5N(.AI(';M8V4@4$\@<V]U8F]R^2!P<F\@
M;F]V_2!L;V-A;&4N(%9A<F]VX6[M.B`*"0E4871O(&]P97)A8V4@</AE<.VY
M92!D;W-A=F%D;NT@4$\@<V]U8F]R>2!P<F\@=&5N=&\@;&]C86QE+@`@(&UA
M:V4)"59Y='9O^&ET(&)I;N%R;NT@34\@<V]U8F]R('!R;R!S<&5C:69I8VOI
M(%!/('-O=6)O<GDN`"`@;6%K92UH96QP"4]Z;F'H:70@=KEE8VAN>2!P;VQO
MOFMY(%A-3"!S;W5B;W)U(',@;N%P;W;L9&]U(&IA:V\@86MT=6%L;NT*"0EA
M('#X:7!R879I="!D86YN_2!S;W5B;W(@<')O(&1A;+GM(&%K='5A;&EZ86-I
M('!O;6]C[2!P^.UK87IU"@D)=7!D871E+6AE;'`N(%#X[6MA>B!M86ME+6AE
M;'`@8GD@<V4@;>QL('-P;W6Y=.QT('!O=7IE('!O('-P=;ET[&[M"@D)</CM
M:V%Z=2!U<&1A=&4M:&5L<"!A('#X[7!A9&[I(')E=FEZ:2!S;W5B;W)U(',@
M;N%P;W;L9&]U+@`@(&UE<F=E"5-L;W7H:70@9&]S879A9&[M(%!/('-O=6)O
M<B!S92!V>F]R;W;];2!03R!S;W5B;W)E;2X`("!U<&1A=&4)4')O=NES="!P
M^.UK87IY(&5X=')A8W0@82!M97)G92!NX7-L961O=F[L+@`@('5P9&%T92UH
M96QP"45X=')A:W1O=F%T(':Y96-H;GD@;F]VZ2!A('IM[&[L;ND@<&]L;[YK
M>2!Z($%N9VQI8VOI:&\@6$U,"@D)<V]U8F]R=2!S(&[A<&]V[&1O=2!A('-P
M;VII="!J92!S(&5X:7-T=6KM8VEM:2!S;W5B;W)Y+@`@)B,Q-3$[("5S(&IE
M('#X:7!R879E;B!P<F]VZ7-T(&[MOF4@;WIN8>AE;ND@;W!E<F%C92#Z9'*^
M8GDN`"`H</AE9"`E<R!D;GDI`"`H4/CM<W1U<&]V_2!+;.WH("5S*0`@*&1N
M97,I`"`H=NAE<F$I`"!R>6-H;&]S="``)60@)7,@82`E<P`E9"!B>73Y('IA
M<'/A;F\N`"5D('H@)60@<&]L;[YE:R!B>6QO(&]Z;F'H96YO(&IA:V\@86MT
M=6%L;NTN`"5D+61E;F[M('#X961P;W;L[P`E<R`M($]Z;N%M96[M`"5S($%D
M;6EN:7-T<F%C90`E<R!.87-T879E;NT`)7,@3W1I<VL`)7,@2T(`)7,@3W!E
M<F%C92#:9'*^8GD@+2!0;W1V<GIE;NT`)7,@4F5G:7-T<F%C90`E<R!0;V1M
M[6YK>2!0;W6^[7;A;NT`)7,@:FF^(&5X:7-T=6IE+@`E<R!N82`E<R`E<P`E
M<R!Z<G6Y:6QO("5S+@`E<R!O9'!O=NQD[&PH82D@;F$@9G)E92]B=7-Y(+[A
M9&]S="X`)7,@;V1P;W;L9.QL*&$I(&YA('!O>G;A;FMU(&YA("5S+@`E<R!Z
M87-L86PH82D@:6YF;W)M86-I(&\@9G)E92]B=7-Y+@`E<R!N96QZ92!P;W6^
M[70@:R!ZX7!I<W4N`"5S(&IE('!OOF%D;W;A;F\`)7,@;6EN=70`)7,@;F5B
M>6QO(&YA;&5Z96YO+@`E<R!N96)Y;&\@;F%L97IE;F\N("=T<F%N<VQA=&EO
M;B!E>'1R86-T)R!M=7/M(&+]="!S<'6Y=.QN('!R=F[M+@`E<R!V>;YA9'5J
M92!I;F9O<FUA8VD@;R!F<F5E+V)U<WDN`"5S('9YOF%D=6IE(%9AN6D@^NAA
M<W0@;F$@)7,N`"5S(&&^("5S('H@)7,`)7,@<VD@</AE:F4@8OUT('#X:63A
M;BAA*2!D;R`E<RX`)7,@<VD@</AE:F4@5N%S('5P;WIO<FYI="!N82`E<RX`
M)7,@<VD@</AE:F4@;V)D<KYE="!A:W1U86QN[2!I;F9O<FUA8V4@;R`E<RX`
M)7,@2V]N=&%K='D`)7,@2V%L96YDX?@`)7,@6N%P:7-N[6L`)7,@4V5Z;F%M
M(-IK;VSY`"5S.B`E<P`E<SH@;F5L>F4@<&]UONUT(&1R:79E<B`Z("5S`"5S
M(&YE;'IE('IV;VQI="X`)R5S)R!N96[M(&YA:V]N9FEG=7)O=N%N('8@4F5G
M:7-T<F5C:"!(;W)D92!S>7-TZ6UU+@`G)7,G('#X96ML861AZ"!N96)Y;"!N
M86QE>F5N+@`E<R<@8GEL('#X:63A;B!D;R!S>7-TZ6UU('-K=7!I;BX`)R5S
M)V)Y;"!P^&EDX6X@9&\@<WES=.EM=2!P^.US='5P;W;]8V@@<'+A=BX`)R5S
M)R!N96)Y;"!V>71V;_AE;CH@)7,N`"P@;N%R87IO=OT@)7,@)7,`+"!P<F]M
M[&YNX2!O9B`E<R!D;R`E<P`M+2!V_6+L<B`M+0`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T`,3(@2&]D:6YO=OT@1F]R;>%T`.SH($AO9&EN;W;]($9O
M<FWA=``R-"!H;V1I;@!6('-O=6)O<G4@)7,@<V4@;F%C:.%Z:2!N975Z87;X
M96[A('9Y<V'H:V$@/&=E='1E>'0^+@I0;^CA=&7H;NT@=GES8>AK82!N82#X
MX61K=2`E9"X`4')O('1E;G1O(&)L;V-K(&IE('9YOF%D;W;A;B!D871A8N%Z
M;W;]('ID<F]J+@!6>7-K>71L82!S92!ZX79AOF[A(&-H>6)A`%!R;R!Z86OS
M9&]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSM
MZ"X`4')O('9E<FEF:6MA8VD@;WIN8>AE;ND@>G!RX79Y(&IE(&YU=&YO('!O
M=;[M="!V9?AE:F[](%!'4"!K;.WH+@!0<F\@9&5K\V1O=N%N[2!Z<'+A=GD@
M:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'
M4"!K;.WH(&$@:&5S;&\N`%!R;R!O>FYAZ&5N[2!Z<'+A=GD@:F4@;G5T;F\@
M<&]UONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'4"!K;.WH(&$@
M:&5S;&\N`%!R;R!D96OS9&]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@
M=F7X96IN_2!3+TU)344@:VSMZ"P@<')I=N%T;NT@4R]-24U%(&ML[>@@82!H
M97-L;RX`4')O(&]Z;F'H96[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X
M96IN_2!3+TU)344@:VSMZ"P@<')I=N%T;NT@4R]-24U%(&ML[>@@82!H97-L
M;RX`4')O('IA:_-D;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE
M:F[](%--24U%(&ML[>@N`$%$4TD@8VAY8F$@)7,N`%)A;F[M(%#X96CA\FMY
M`$%-+U!-`$%022!)1`!);F9O<FUA8V4@;R!T;VUT;R!E9&ET;W)U`$EN9F]R
M;6%C92XN+@!497AT(&YA('-P;V1E:R!O8G+A>FMU`%1E>'0@9&\@<')O<W3X
M960@;V)RX7IK=0!0^&EJ;6]U="!P;[YA9&%V96L`4/AI:FUU=&\`4/CM<W1U
M<"!:86WM=&YU="X`5GET=F_X96[M(%9&4R!A9')A<^'X92!N96)Y;&\@<&]V
M;VQE;F\N`%9Y='9O^&5N[2!61E,@<V]U8F]R=2!N96)Y;&\@<&]V;VQE;F\N
M`%6^:79A=&5L<VOI($AE<VQO`%6^:79A=&5L:_T@^NAE="!B>6P@>F%B;&]K
M;W;A;BX`5;YI=F%T96QKZ2#:Z'1Y`$%K8V4`5FQOO@!0^&ED870@4&]D<VMU
M<&EN=0!0^&ED870@4&]D(%!RX79A`%#X:61A=#H`4/AI9&%T($YO=F]U(%-K
M=7!I;G4`4/AI9&%T($YO=N$@4'+A=F$`4/AI9&%T('!O9'-K=7!I;G4@9&\@
M)R5S)P!0^&ED870@<&]D<'+A=F$@9&\@)R5S)P!0^&ED870@;F]VZ6AO('6^
M:79A=&5L93H`4/AI9&%T('-L;W5P96,`4/AI9&%T(&YO=ND@Z&QE;GD`4/AI
M9&%T('#A<@!0^&ED870@)7,@365N=2!J86MO(&)OZ&YI('-L;W5P96,@36]Z
M:6QL>0!0^&ED870@='5T('!O;&^^:W4@9&\@;>EH;R!K86QE;F3A^&4`4/AI
M9&%T(&1O(&MO;G1A:W3Y.@!0^&ED870@9&\@;6]J:6-H(&MO;G1A:W3Y.@!0
M^&ED870@=;YI=F%T96QE`"<E<R<@8GEL('#X:63A;F\@9&\@<WES=.EM=2P@
M86QE(&YE;'IE('#X:61A="!NX7-L961U:NUC[2!I;F9O<FUA8V4Z("5S+@`G
M)7,G(&)Y;"!P^&EDX6YO(&1O('-Y<W3I;74N($WYOF5T92!S92!N>6[M('#X
M:6ALX7-I="!D;R!S>7-TZ6UU+@!0^&ED[7;M;NT@;F]V_6-H('-O=6)O<OD@
M9&\@>F1R;VIE.@!0^&EDX7;A;NT@=;YI=F%T96SY(&IE('IA8FQO:V]VX6YO
M+@!!9')E<V$`2V]N=&%K='D`5GEK;V[A=F%T($%D;6EN:7-T<F%C:2`M(&YA
M<W1A=F5N[2!P^.US='5P;W;]8V@@<'+A=B!P<F\@;W-T871N[2!UOFEV871E
M;&4`061M:6YI<W1R86-E`$EN>F5RX71Y`$%F9^%N:7-TX6X`06QBX6YI90!!
M;+[M<G-K;P!0^&5Z9.UV:V$O06QI87,`6F%R;W9N870`6F%R;W9NX6[M.@!6
MN64`5KEI8VAN:2!/=NSX96[M(%6^:79A=&5LZ0!6N65C:&YY(%-K=7!I;GD`
M5KEE8VAN>2!5OFEV871E;'-KZ2!0<N%V80!6N65C:&YY(.AT>?AI('-T<F%N
M>0!0;W9O;&ET(';M8V4@861R97,`4&]V;VQI="!N87-T879E;NT@='EP=2!S
M973X[63L;OT@<V5Z;F%M/P!*:;X@97AI<W1U:F4`06QT96YA=&EV;NT@24U3
M4"!0^&EH;&&Y96[M(&1O(%-Y<W3I;74`06QT96YA=&EV;NT@24U34"!(97-L
M;P!!;'1E;F%T:79N[2!)35-0(%6^:79A=&5L<VOI($IMZ6YO`$%L=&5N871I
M=F[M(&4M;6%I;&]VX2!A9')E<V$`06QT96YA=&EV;NT@=GIO<GD`06QT96YA
M=&EV;NT@=&5X=#H`06UE<FEC:^$@4V%M;V$`0GEL82!Z863A;F$@;F5P;W9O
M;&5NX2!H;V1N;W1A+@!!;F1O<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6[M
M(%!R;WAY`$]D<&]V[.\`06YT87)K=&EK80!!;G1I9W5A(&%N9"!"87)B=61A
M`$%P;&EK86-E`%-E>FYA;2!!<&QI:V%C[0!!<&QI:V%C92!J92!P^&EP<F%V
M96[A`%!O=;[M="!P<F\@0VAI;&0@4VAA<F5S`%-C:';A;&ET`$1U8F5N`$%R
M86)S:WD@*%=I;F1O=W,M,3(U-BD`5F5L:6MO<W0@07)C:&EV;W9A;NEH;R!3
M;W5B;W)U`$IMZ6YO($%R8VCM=G4`57+H:73L(&-H8V5T92!V>6UA>F%T(+[A
M9&]S="!O('#X:6ALX;EE;NT@;V0@)7,_`%5RZ&ET["!C:&-E=&4@<VD@</AE
M:F5T92!V>6UA>F%T("<E<R<@82!P;W-K=7!I;GD_`$%R9V5N=&EN80!!<FWI
M;FEE`$%R;>EN<VO]("A!4DU30TE)+3@I`%5M[&[M`$%R=6)A`$%S8V5N<VEO
M;B!/<W1R;W8`07-C:6D@56WL;NT`07-I92]296=I;VX@5&EC:.EH;R!O8V7A
M;G4`4&^^X61A="!O('!O='9R>F5N[2!P^&5D('!R;W9E9&5N[6T@;W!E<F%C
M[2#Z9'*^8GD_`%-L;W5P8V4@<R#::V]L>0!0^&EL;[YE;B!J92!S;W5B;W(@
M:4-A;&5N9&%R(',@;V1P;W;L9.T@;F$@5F&Y:2!O=.%Z:W4`4&]K=7,@;R!V
M>6UA>N%N[2!N965X:7-T=6KM8^T@<VMU<&EN>2X`4&]K=7,@;R!V>6UA>N%N
M[2!N965X:7-T=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N`%!O:W5S(&\@
M961I=&%C:2!N965X:7-T=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N`%!O
M:W5S(&\@961I=&%C:2!N965X:7-T=6KM8^UH;R!S9.UL96[I:&\@;V)J96MT
M=2X`VNAA<W1N[6-I`$%T<FEB=71Y`%-R<&5N`$%U<W1RX6QI90!286MO=7-K
M;P!!=71H7V-Y<G-Q;#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM
M<&]N82!P<F\@:6UA<"X`075T:%]C>7)U<SH@6F1R;VH@;F5MX2!P;[YA9&]V
M86[I('-C:&]P;F]S=&DN`$%U=&A?8WER=7,Z($YE8GEL82!N86QE>F5N82!P
M;[YA9&]V86[A('#X[7!O;F$@<')O(&EM87`N`$%U=&A?9G1P.B!.96)Y;&$@
M;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!F='`N($MO;7!I;'5J
M=&4@4$A0(',@+2UE;F%B;&4M9G1P`$%U=&A?:6UA<#H@3F5B>6QA(&YA;&5Z
M96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@24U!4"X`075T:%]K<F(U.B!.
M96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!K<F(U+@!!
M=71H7VQD87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@
M<')O($Q$05``075T:%]L9&%P.B!.96IZ92!P^&ED870@=;YI=F%T96QE("5S
M+B!:<'+A=F$@>F4@<V5R=F5R=3H@`$%U=&A?;&1A<#H@3F5L>F4@=GEM87IA
M="!UOFEV871E;&4@)7,`075T:%]L9&%P.B!.96QZ92!A8W1U86QI>F]V870@
M=;YI=F%T96QE("5S`$%U=&A?;6-A;#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D
M;W9A;N$@</CM<&]N82!P<F\@34-!3"X`075T:%]S;6)A=71H.B!.96)Y;&$@
M;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!S;6)A=71H+@!/=NSX
M96[M('-E;&AA;&\`3W;L^&5N[2!S96QH86QO+B`E<P!/=NSX96[M(&)Y;&\@
M>F%M:71N=71O(%)!1$E54R!S97)V97)E;2X`4V5L:&%L;R!O=NSX96[M('!R
M;R!&5%`@<V5V97)E;2X`1&]S='5P;ND@<&]L93H`3^AE:^%V86[A($]D<&]V
M[.\`07IE<F)A:F2^X6X`0D]&2"!6_6UL=79Y`$)A8VME;F0@;F5N[2!S<'+A
M=F[L(&EM<&QE;65N=&]VX6XN`%!O>F%D[0!"87)V82!0;WIA9.T`J7!A=&[I
M(&AE<VQO('!R;R!K97)B97)O<RX`J7!A=&[I('6^:79A=&5L<VOI(&IMZ6YO
M('!R;R!K97)B97)O<RX`0F%H86UY`$)A:')A:6X`0F%L=&EC:^D@*$E33RTX
M.#4Y+3$S*0!"86YG;&%DZ;D`0F%R8F%D;W,`4'+A>F1NZ0!.96)Y;"!N86QE
M>F5N(&%D<F5SX?@@)R5S)R!S(&=R869I:V%M:2X`6N%K;&%D`$+L;&]R=7-K
M;P!"96QG:64`0F5L:7H`0F5N:6X`0F5R;75D>0!":/ITX6X`3F%R;WIE;FEN
M>0!.96QZ92!N86SI<W0@Z.%S="`B)7,B(&%P;&EK86-E("(E<R(N`$YA<W1A
M=F5N[2!";&]K=0!4>7`@0FQO:W4`5OUB['(@0FQO:W4`5'7H;NP`0F]L[79I
M90!:X6QOOFMY`$AR86YI8V4`J>WX:V$@:')A;FEC93H`2')A;FEC90!";W-N
M82!A($AE<F-E9V]V:6YA`$]B80!";W1S=V%N80!$;VQN[2#(X7-T`$)O=79E
M="!)<VQA;F0`0G)A>NUL:64`0G)I='-KX2!497)I<F]R:6$@=B!);F1I8VOI
M;2!/8V7A;NP`0G)U;F5I($1A<G5S<V%L86T`4')O8NUHX2!S97-T879O=N%N
M[2!-3R!S;W5B;W+Y('!R;R!M;V1U;"`E<RXN+@!0<F]B[6CA('-E<W1A=F]V
MX6[M(&QO8V%L92!P<F\@)7,N+BX@`$)U;&AA<G-K;P!397IN86T@<R!/9'1R
M:'D`0G5R:VEN82!&87-O`$)U<G5N9&$`0TU3`$-20P!#4DP@1&ES=')I8G7H
M;NT@0F]D>0!6;&%S=&YO<W1I($)?=?)K>2XN+@!+86QE;F3A^`!"97IV['3X
M[0!+86UB;V2^80!+86UE<G5N`$AE;'-O(&YE;'IE(&YA<W1A=FET(&%U=&]M
M871I8VMY+"!P<F]S[6T@:V]N=&%K='5J=&4@5F&Y96AO('-Y<W3I;6]VZ6AO
M(&%D;6EN:7-T<N%T;W)A+@!.96QZ92!S92!P^&EP;VII="!K($E-05`@4V5R
M=F5R=3H@)7,`2V%N861A`%-T;W)N;P!3=&]R;F\@2&SAN65N[2!0<F]B;.EM
M=0!.96QZ92!V>6UA>F%T('-O=6)O<B`B)7,B+@!.96QZ92!N86KM="!D;^AA
M<V[](&%D<F5SX?@N`$YE;'IE('!O:W)AZ&]V870@8F5Z('!A<F%M96YT<G4@
M)W1A<F=E=$9I;&4G+@!.96QZ92!V>6UA>F%T(&%D<F5SX?@@(B5S(BX`3F5L
M>F4@=GEM87IA="P@:F5L:6MOOB!E>&ES='5J[2!P;V1S:W5P:6YY("5D+@!.
M96QZ92!P<F]VZ7-T('#X975S<&_XX63A;NTL('!OZ&5T('!O<VMY=&YU=/UC
M:"!P;VQOOF5K('!R;R!P^&5U<W!O^.%DX6[M(&YE;V1P;W;M9.$@<&_H='4@
M=6QOOF5N_6-H('!O;&^^96LN`$YE;'IE('IA<VQA="!Z<'+A=G4@;F$@<&]S
M:WET;G5TZ2#H[7-L;RX@`$-A<&4@5F5R9&4`5&ET=6QK>0!+871E9V]R:64@
M82!:;F'H:WD`2V%J;6%N<VOI($]S=')O=GD`36]B:6QN[2!496QE9F]N`$UO
MOFYO<W1I($)U\FMY`$]D<W1U<'D@;65Z:2!B=?)K86UI.@!6;&%S=&YO<W1I
M(&)U\FMY`$UE>F5R>2!M97II(&)U\FMA;6DZ`$UO8FEL;NT@5&5L969O;@!+
M96QT<VO]("A)4T\M.#@U.2TQ-"D`4W3X960`4W3X961N[2!!9G)I8VOA(%)E
M<'5B;&EK80!3=/AE9&]E=G)O<'-K_2`H25-/+3@X-3DM,BD`1&5T86EL>2!#
M97)T:69I:^%T=0!0;V1M[6YK>2!#97)T:69I:^%T=0#(860`4/AE9'-E9&%J
M[6/M`%IM[&YI=`!:;>QN:70@2&5S;&\`6FWL;FET(&AE<VQO('8Z`%IM[&YI
M="!J;>EN;RP@96UA:6QO=F]U(&%D<F5S=2X@5'ET;R!P;VQOOFMY(&QI9.D@
M=79I9.TL(&MD>;X@<VD@Z'1O=2!N96)O(&]D<&]V[61A:NT@;F$@5N&Y(&5M
M86EL+@!:;>QN:70@5F&Y92!H97-L;P!:;>QN:70@:&5S;&\@=B`E<P!:;F%K
M`%IK;VYT7W)O;&]V870@3&EN:W4N+BX`3WIN8>AI="!RX6UEZ&5K('!O:W5D
M('-I('1E[R!P^&5J971E('!R;W;I<W0@;W!E<F%C92X`0VAI;&4`R.UN80#(
M[6ZY=&EN82!::F5D;F]D=;EE;N$@*$=",C,Q,BD`5')A9&GH;NT@R.UNN71I
M;F$@*$)I9S4I`%IV;VQT92!H97-L;P!:=F]L=&4@=;YI=F%T96QS:^D@:FWI
M;F\`5GEB<N%T(&%K8VDZ`%9Y8G)A="!Z;V)R87IE;NT@9&%T=6UU.@!6>6)R
M870@='EP('-T>6QU('-E>FYM=2`H<')O('-E^&%Z96[I('-E>FYA;7DI`%;A
M;F_H;NT@3W-T<F]V`$YE8GEL82!N86QE>F5N82!D969I;FEC92!T^.UD>2`E
M<RX`4')O8NUHX2#H:;ET[&[M(%!/('-O=6)O<OD@<')O(&UO9'5L("5S+BXN
M`%!R;V+M:.$@Z&FY=.QN[2!L;V-A;&4@)7,N+BX@`%9YZ&ES=&ET`%9YZ&ES
M=&ET('IN8>AK>2!Z($U33V9F:6-E`$]D<W1R86[L;NT@=;YI=F%T96QE.B`E
M<P!/9'-T<F%N:70@=;YI=F%T96QE`$]D<W1R86[L;NT@^F1A:OD@;R!UOFEV
M871E;&D`<')O(%!O:W)AZ&]VX6[M($ML:6MN['1E`$-L:6-K871E;&P@</AE
M<R!(5%10`%IA=OCM="!/:VYO`%IA=&&^96YO`$]B;&'H;F\`2V]K;W-O=ND@
M3W-T<F]V>0!3:VQA<&YO=70@0F_H;NT@3&FY='4`4VML87!N;W5T($AR86YI
M8V4`2V]L=6UB:64`0F%R=F$`5OUB['(@0F%R978`4&%L971A(&)A<F5V`%-L
M;W5P8V4Z`$[A>G9Y('-L;W5P8V4`2V]M:6MS>0!0^.UK87H`4/CM:V%Z;W;A
M($MO;GIO;&$`36^^;F]S=&D@4/CM:V%Z=3H`4/CM:V%Z>0!0;WINX6UK80!5
M:VSA9&%J[6/M.@!/8F5C;ND@2FWI;F\`2V]M;W)O<P!&:7)M80!$;VMO;NAE
M;F\`5GET=F_X:70@6G!RX79U("@E<RD`4&_H[71AZ&4`4&]D;>UN:WD`4F]Z
M9.UL>2!V($YA<W1A=F5N[0!*92!N=71N;R!A:W1U86QI>F]V870@;F%S=&%V
M96[M+@!.87-T879I="`E<P!0;W1V<F1I="!(97-L;P!0;W1V<F1I="!N;W;I
M(&AE<VQO.@!+;VYG;P!+;VYG;RP@1&5M;VMR871I8VOA(%)E<'5B;&EK80!3
M<&]J96[M('-E;&AA;&\N`%-P;VIE;NT@<V5L:&%L;SH@`$)Y;&\@>F%M[71N
M=71O('-P;VIE;NT@<R!V9?AE:F[];2!K;.WH;W;];2!S97)V97)E;2X`0GEL
M;R!Z86WM=&YU=&\@<W!O:F5N[2!S('9E^&5J;OUM(&ML[>AO=OUM('-E<G9E
M<F5M+B!$^79O9"`Z("5S("@E<RD`4V5L:&%L;R!S<&]J96[M(',@1E10(%-E
M<G9E<F5M+@!+;VYT86MT>2!B>6QY(/IS<.RY;NP@</AI9.%N>2!D;R!+;VYT
M86MT^2X`3V)S86@@=B`G)7,G`%!O:W)AZ&]V870`0V]O:V]V:2!/<W1R;W9Y
M`$MO;.'H96L`2V]P[7)O=F%T`$MO<.UR;W9A="!V_6+L<@!+;W#M<F]V870@
M)7,@9&\@)7,`2V]S=&$@4FEK80!0;V+X9;[M(%-L;VYO=FEN>0!.96QZ92!K
M\V1O=F%T('IP<N%V=2!P;VUO8^T@4$=0+@!.96QZ92!P;V1E<'-A="!Z<'+A
M=G4@<&]M;V/M(%!'4`!.96QZ92!K\V1O=F%T('IP<N%V=2!P;VUO8^T@4R]-
M24U%+@!.96QZ92!P;V1E<'-A="!Z<'+A=G4@<&]M;V/M(%,O34E-12X`3F5L
M>F4@</AI9&%T(&MO;G1A:W0N("5S`$YE;'IE('-E('#X:7!O:FET(&YA($Q$
M05`@<V5R=F5R+@!.96QZ92!S92!D;VUL=79I="!S(&QD87`@<V5R=F5R96T`
M3F5L>F4@>F%V;VQA="!F:6YK8VD@)7,@=B!A<&QI:V%C:2`E<RX`3F5L>F4@
M>FMO;G1R;VQO=F%T(/KH970N("5S`$YE;'IE('-E('#X:7!O:FET(&YA(&QD
M87`@<V5R=F5R`$YE;'IE('-E('#X:7!O:FET('!O;6]C[2!&5%`@;F$@)R5S
M)R!S97)V97(Z("5S`$YE;'IE(&MO<.UR;W9A="`E<R!D;R`E<P!.96QZ92!V
M>7)T=F_X:70@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!V>71V;_AI
M="!L;V-A;&4@861R97/A^"!P<F\@;&]C86QE("5S.@!.96QZ92!D96OS9&]V
M870@4$=0(&1A=&$N`$YE;'IE(&1E:_-D;W9A="!3+TU)344@9&%T82X`3F5L
M>F4@<VUA>F%T(&MO;G1A:W0N("5S`$YE;'IE('-M87IA="!D:7-T<FEB=>AN
M[2!S97IN86TN("5S`$YE;'IE('-M87IA="!N87-T879O=F%C[2!S:W)I<'0@
M<')O(&%K='5A;&EZ86-I("<E<R<N`$YE;'IE('IJ:7-T:70@92UM86EL;W9O
M=2!A9')E<W4@</CM:F5M8V4N`$YE;'IE(&YA;.ES="#Z<&QN_2!!9')E<^'X
M(',@2V]N=&%K='DN`$YE;'IE(&YA;.ES="#Z<&QN_2!D:7-T<FEB=>AN[2!S
M97IN86TN`$YE;'IE(&YA;.ES="#Z<&QN_2!S97IN86T@9&ES=')I8G7H;NUC
M:"!S97IN86WY+@!3=')A=&5G:64@)R5S)R!J92!N961O<W1U<&[A+@!.96QZ
M92!Z86QOOFET("<E<R<N`$YE;'IE(&]B9'*^970@=F7X96IN_2!K;.WH('H@
M:VSMZ&]VZ6AO('-E<G9E<G4N`$YE;'IE(&]T97;X[70@)7,N`$YE;'IE(&]T
M97;X[70@)R5S)R!K('KA<&ES=2X`3F5L>F4@<')O=NES="!/<&5R86-E(-ID
M<KYB>2!P<F\@;6]D=6P@)7,`3F5L>F4@;W1E=OCM="!A9')E<^'X("<E<R<N
M`$YE;'IE(&]T97;X[70@;&EN:W4@;F$@<VUB<&%S<W=D+@!.96QZ92#H[7-T
M("5S+@!.96QZ92!R97-E=&]V870@:&5S;&\@<')O(&1A;F[I:&\@=;YI=F%T
M96QE+B!6N65C:&YY(&YE8F\@;NQK=&5RZ2!Z(&1E=&%I;/D@;F5B>6QI('-P
M<N%V;NP@>F%DX6YY+B!::W5S=&4@=&\@>FYO=G4L(&YE8F\@<&]K=60@<&]T
M^&5B=6IE=&4@<&]M;V,@:V]N=&%K='5J=&4@<W!RX79C92!S>7-TZ6WY+@!.
M96QZ92!O8F1ROF5T($%#3`!.96QZ92!O8F1ROF5T($%D<F5SX?@@<R!+;VYT
M86MT>2X@)7,`3F5L>F4@;V)D<KYE="!D:7-T<FEB=>AN[2!S97IN86TN("5S
M`$YE;'IE(&]B9'*^970@9&ES=')I8G7H;NT@<V5Z;F%M>2X@)7,`3F5L>F4@
M;V)D<KYE="!S8VAO<&YO<W1I('-E<G9E<G4N`$YE;'IE('#X97!N;W5T(&MO
M;F9I9W5R86-I+@!.96QZ92!O9'-T<F%N="`G)7,G+@!.96QZ92!U;&^^:70@
M:V]N9FEG=7)A8VD@<')O("5S+@!.96QZ92!U;&^^:70@>N%L;[YN[2!K;VYF
M:6=U<F%C:2X`3F5L>F4@=6QOOFET('KA;&^^;NT@:V]N9FEG=7)A8VD@)7,N
M`$YE;'IE('5L;[YI="!K;VYF:6=U<F'H;NT@<V-R:7!T(&1O.B`G)7,G+@!.
M96QZ92!H;&5D870@=B!,1$%0('-E<G9E<G4N`$YE;'IE(&]D<&]J:70@)R5S
M)RX`3F5L>F4@86MT=6%L:7IO=F%T(&MO;G1A:W0N("5S`$YE;'IE(&%K='5A
M;&EZ;W9A="!D:7-T<FEB=>AN[2!S97IN86TN("5S`$YE;'IE('5L;[YI="!K
M;VYF:6=U<F%C:2!P<F\@)R5S)SH@)7,`3F5L>F4@;F%LZ7-T(&)OZ&[M(&QI
MN71U('!R;R!-;WII;&QU+B!0<F]S[6T@</AE<W;L9.AT97-E(+YE(&IE(&]T
M97;X96[A+@!.96QZ92!P;W-K>71N;W5T(&[A<VQE9'5J[6/M('!RX79A('!R
M;R!UOFEV871E;&4@)7,@=B!A9')E<^'X:2`G)7,G.B`E<P!/9'!OZ.UT86[]
M('1E>'0`6F5M[`!6>77H;W9A8^T@4/AE9&WL='D`5GET=F_X:70`5GET=F_X
M:70@;&EN:W4`5GET=F_X:70@;F]V;W4`5G5T=F_X:70@<&]D861R97/A^`!6
M>71VX?AEZ"!P<N%V`,CM<VQO(&MR961I=&[M(&MA<G1Y`$-H;W)V871S:V\`
M2W5B80!!:W1UX6QN[2!&X7IE`$%K='7A;&[M(,AA<P!!:W1UX6QN[2!54DP@
M:F4`06MT=>%L;NT@4&_H87/M`$%K='7A;&[M(%!O9&WM;FMY.B``3GEN[&JY
M[2!S='EL`$YA<W1A=FET(/IK;VQY+"!K=&5RZ2!S92!M86KM('!R;W;I<W0@
M</AI('#X:6ALX;EE;NT@<V4@9&\@)7,N`%9Y<W3X:6AN;W5T`%9Y<W3X:6AN
M;W5T('-E;&5K8VD`2WEP<@!!>F)U:V$@*$M/23@M4BD`07IB=6MA("A7:6YD
M;W=S+3$R-3$I`$%Z8G5K82]5:W)A:FEN82`H2T])."U5*0#(97-KX2!297!U
M8FQI:V$`1$0`1&5N;NP`1&%T80!$871A5')E92!0<F]H;.V^9>@`1&%T=6T`
M4/AI:F%T;R!$;F4`5OUB['(@1&%T=6UU`$1E;@!3;6%?>F%T(%-L;W5P96,`
M4')O<VEN96,`R.US;&$@9&5S[71K;W;I('-O=7-T879Y`%IA;>UT;G5T`%IM
M96ZY:70@3V1S87IE;NT`26UP;&EC:71N[2!"87)V80!);7!L:6-I=&[M($ED
M96YT:71A`$EM<&QI8VET;NT@4'+A=F$`26UP;&EC:71N[2!P<N%V80!$969I
M;FEC90!0^&ED[&QI="!P;WII8VD`4/AI9.QL96YO`%-M87IA=`!3;6%Z870@
M4VMU<&EN=0!3;6%Z870@4'+A=F$`4VUA>F%T(&$@=GGH:7-T:70@>G!RX79Y
M`%-M87IA="!B=?)K=0!3;6%Z870@<VQO=7!E8P!3;6%Z870@97AI<W1U:NUC
M[2!A;'1E<FYA=&EV;NT@=GIO<@!3;6%Z870@<'+A=F$@<')O("<E<R<`4VUA
M>F%T('!RX79A(&$@<&]D<'+A=F$@<')O("<E<R<_`%-M87IA="#XX61E:P!3
M;6%Z870@=GEB<F%N;W4HZ2D@:61E;G1I='4H>2D`4VUA>F%T('-O=>AA<V[]
M('-L;W5P96,`4VUA>F%T('-O=>AA<V[](/CA9&5K`%-M87IA="!T>71O('!R
MX79A(&$@<&]D<'+A=F$_`$MO;F9I9W5RX>AN[2!S8W)I<'0@)R5S)R!B>6P@
M<VUA>N%N+@#(87,@9&]R=>AE;NT`1.%N<VMO`%IA;>UT;F]U="!P;[YA9&%V
M96L`6F%M[71N;W5T('!OOF%D879E:R!N82!I;F9O<FUA8VD@;R!F<F5E+V)U
M<WD`4&]P<V%T(%!R;V)LZ6T`4&]P:7,`1&5T86EL>2`H=&%KZ2!V(&QO9R!S
M;W5B;W)U($AO<F1E*3H`1&5T86EL>2!B>6QY('IA>FYA;65NX6YY(&1O(&QO
M9R!S;W5B;W)U('!R;R!A9&UI;FES='+A=&]R82X`5OUV;VH`4F]S;OT@0F]D
M`%)O<V[]($)O9"!Z82!P;W-L961N[2!H;V1I;G4Z(`!2;W-N_2!B;V0Z(`!3
M;>QR('H@;&5V82!D;R!P<F%V80!3;>QR('H@<')A=F$@9&\@;&5V80!!9')E
M<^'X`%IO8G)A>FET(#(T+6AO9&EN;W;](.AA<S\`36^^;F]S=&D@6F]B<F%Z
M96[M`%IO8G)A>FET(%#X961P;W;L[R`H5$%&*0!&;W)MX70@>F]B<F%Z96[M
M`$1I<W!O>FGH;NT@57!O>F]R;NQN[0!$:FEB;W5T:0!.97-M87IA=`!.97#X
M:7-T=7!O=F%T('#X[6UO(&1O(&UA:6YT96YA;F-E+G!H<`!/8G-A:'5J92!P
M<G9N[2#XX61E:R!NX7IE=B!S;&]U<&/Y/R!0;VMU9"!A;F\L('IA=')H;NQT
M92!T96YT;R!RX6UEZ&5K.@!$;VUI;FEK80!$;VUI;FEKX6YS:^$@4F5P=6)L
M:6MA`$1O=VYL;V%D`$1O=VYL;V%D("5S`$YAZ.US="!G96YE<F]V86YO=70@
M:V]N9FEG=7)A8VD@:F%K;R!02%`@<VMR:7!T+@!2;VQE=&]V_2!S97IN86T`
M1')O9WD`12UM86EL`$524@!%:W;A9&]R`%5P<F%V:70`57!R879I="!";&]K
M`%5P<F%V:70@4VMU<&EN=0!5<')A=FET(%!RX79O`%5P<F%V:70@4'+A=F$`
M57!R879I="!0<N%V82!P<F\@)R5S)P!5<')A=FET(&UOOFYO<W1I('!R;SH`
M57!R879I="!P<N%V82!P<F\@)R5S)P!5<')A=FET('!RX79A('!R;R`G)7,G
M`%;]=6MA`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`
M16UA:6QO=N$@061R97-A`$5M86EL;W;I($%D<F5S>2!S92!M=7/M('-H;V1O
M=F%T+@!%;6%I;"!S('!O='9R>F5N[6T`26MO;FMY(',@16UO8V5M:0!0<N%Z
M9&[A('IP<N%V82X`4'+A>F1N_2!V_7-L961E:RX`4'+A>F1N_2!T97)M[6X@
M<')O('9Y:&QE9.%VX6[M`%!O=F]L:70@=FMLX63A;NT@;V)R87IK^2!Z($9O
M=&\@1V%L97)I[2!D;R!T97AT=3\`06MT:79O=F%T('!R87;I(&ML:6MN=73M
M('!R;R!M96YU(&MO;G1E>'1U/P!+;VYE8P!+;VYE8R!R;VMU`%IV['2Y:70@
M161I=&]R`%IA9&5J=&4@8F5Z<&7H;F]S=&[M(&]TX7IK=2P@;F$@:W1E<F]U
M(&)U9&5T92!M=7-E="!O9'!O=NQD['0@<&]K=60@<VD@8G5D92!P^.%T(')E
M<V5T;W9A="!68;EE(&AE<VQO+"!N87#X+B`G2F%KZ2!J92!J;>EN;R!68;EE
M:&\@<'-A/R<Z`%ID92!V;&^^:70@55),(&]B<N%Z:W4`4&]L;[YK>3H@)60@
M8V5L:V5M+"`E9"!A:W1UX6QN[6-H+"`E9"!N;W;]8V@L("5D('IM[&[L;OUC
M:"P@)60@;F5Z;N%M_6-H`%)O=F[M:V]VX2!'=6EN96$`17)I=')E80!#:'EB
M80!.87-T86QA(&-H>6)A('#X:2!Z87/M;.%N[2!D870@9&\@<VUB<&%S<W=D
M+@!.87-T86QA(&-H>6)A('#X:2!Z87/M;.%N[2!O9'!O=NQD:3H@)7,N`$YA
M<W1A;&$@8VAY8F$@<')O(&5M86QO=F]U('IP<N%V=2X`0VAY8F$@</AI('KA
M<&ES=2`G)7,G+@!#:'EB83H@`$5S=/-N<VMO`$5T:6]P:64`171N:6-KZ0!%
M=G)O<&$`2V&^9/UC:"`Q-2!M:6YU=`!+8;YDZ2`R(&UI;G5T>0!+8;YD_6-H
M(#,P('-E:W5N9`!+8;YD_6-H(#4@;6EN=70`2V&^9.D@</AI:&SAN65N[2!D
M;R!S>7-TZ6UU`$MAOF1O=2!P^6P@:&]D:6YU`$MAOF1O=2!M:6YU='4`5GIO
M<F]V_2!P^.UK;&%D(&AO9&YO=#H`4')O=NES=`!0<F]VX63L:NUC[3H`4F]Z
M=FEN;W5T`%)O>F)A;&ET($)OZ&[M($QIN71U`$_H96OA=N%N;R`G*2<`3^AE
M:^%VX6YO('-A;6]S=&%T;ND@<VQO=F\@;F5B;R!H;&5D86[]('1E<FWM;B!V
M(/IV;WIO=FOA8V@`1&%T=6T@<')O($MO;F5C(%!L871N;W-T:0!%>'!O;F5N
M=`!6>6KM;6%J[6/M('H@)7,N+BX@`$9'($)A<G9A`%#X96YO<R!K;VYF:6=U
M<F%C92!P;VUO8^T@1E10`%-E;&AA;&\@;V)D<KYE;NT@;6^^;F]S=.TN`$YE
M;'IE('-E('#X:7!O:FET(&YA($Q$05`@<V5R=F5R+@!.96QZ92!S92!P^&EP
M;VII="!N82!334(@<V5R=F5R+@!396QH86QO(&MO<.%R;W;A;NT@>B`B)7,B
M+@!396QH86QO(&MO<.%R;W;A;NT@9&\@(B5S(BX`4V5L:&%L;R!N;W;I('IA
M;&^^96[M('!R;R!305-,('-P;VIE;NTN`%-E;&AA;&\@</AE<W5N=73M(&1O
M("(E<R(N`%-E;&AA;&$@=F5R:69I:V%C92!S=&%RZ6AO(&AE<VQA+@!:;>QN
M82!H97-L82!S96QH86QA('!R;R`E<SH@)7,`1&]B<ND`1F%L:VQA;F1S:^D@
M3W-T<F]V>2`H36%L=FEN87,I`$9A<FEJ<VOI($]S=')O=GD`6N%V8;YNX2!#
M:'EB82$`1F%X`-IN;W(`0^UT:70@2F%K`$/M=&ET(&IA:SH`1')O8F[I(%#X
M96CA\FMY`$9I:FD`4&_H970@4V]U8F]R^3H@)7,@<V]U8F]R`%!OZ&5T(%-O
M=6)O<ODZ("5S('-O=6)O<OD`4W!RX79C92!3;W5B;W+Y`$[A>F5V(%-O=6)O
M<G4`5OUB['(@<V]U8F]R=0!0^&5NZ7-T('-O=6)O<@!0^&5N;W,@<V]U8F]R
M^2!N96[M('!O9'!O<F]VX6XN`$9I;'1R>0!&:6YS:V\`4')V;NT@4/EL:V$`
M4')V;NT@R'1V<G1K80!0979N[2!M[/CM=&MO`%#X96AO9&ET`%!L;W9O=6/M
M`$UL:&$`061R97/A^"`E<R!N965X:7-T=6IE+@!"87)V82!0[7-M80!*[61L
M;P!6X;D@<')O:&SMOF7H(&YE<&]D<&]R=6IE('IO8G)A>F5N[2!O8G+A>FOY
M+@!0^&5D<&]V[.\@*%1!1BD`4/AE9'!O=NSO(%!OZ&%S[2!P<F\@1&YY("AP
M;WINX6UK83H@</AE9'!O=NSO(&YA=G)A8^T@;V)O:NT@9&YY(&$@;F]C:3L@
M=&]T;R!M^;YE('9Y='9O^&ET('!O;>QR;NP@;V+A<^%H;.T@<V5Z;F%M+@!:
M87!O;>QL:2!J<W1E(%9AN64@:&5S;&\_`$9O<FUU;.'X90"I=.QS=.T`='EP
M(*ET['-T[0"I=.QS=.T`J73L<W3M(#(`1O-R80!0^&5P;W-LX6[M`$YA;&5Z
M96[I(&%P;&EK86-E.B`E<P!.86QE>F5NZ2!A9')E<^'X93H`4.$`4N%M>0!&
M<F%N8VEE`$9R86YC:64L($UE=')O<&]L:71N[0!);F9O<FUA8V4@;R!&<F5E
M+T)U<WD`1G)E92]"=7-Y($]D<&]V[.\`1G)E92]"=7-Y(*[A9&]S=`!&<F5E
M+T)U<WD@3V1P;W;L[R!N82"NX61O<W0`1G)A;F-O=7-KX2!'=6GA;F$`1G)A
M;F-O=7-KX2!0;VQY;NES:64`1G)A;F-O=7-KZ2!*:;YN[2!497)I=&]R:64`
M3V0`3V0`1&5T86EL;NT@4&]P:7,`VG!L;NQK`$-E;.D@2FWI;F\`3F5U<NAI
M=/T`1V%B;VX`1V%L97)I92!P<F\@=OUB['(@;V)RX7IK^0!'86QE<FEE.@!'
M86UB:64`5GET=F_X:70@)7,@2V]N9FEG=7)A8VD`5GEG96YE<F]V86[]($OS
M9`!0<F]B[6CA(&=E;F5R;W;A;NT@<W1A='5S=2!P<F\@;6]D=6P@)7,N+BX`
M1W)U>NUN<VMO`$[L;65C:V\`0VAY8F$@1V5T;W!T.B``1VAA;F$`1VEB<F%L
M=&%R`$OX97-T;NT@2FWI;F\`2F1I(&YA`$=O961E;`!6>6AL963A=N%N[2!0
M;VUO8^T@1V]O9VQU`%-T=7!N[""I961I`-AE8VMO`-AE8VOI("A)4T\M.#@U
M.2TW*0!'<O-N<VMO`$=R96YA9&$`061M:6YI<W1R86-E('!R;R!3:W5P:6YY
M`$UU<^T@8OUT('IA9.%N;R!J;>EN;R!S:W5P:6YY`%!RX79A('!R;R!S:W5P
M:6YU`%-K=7!I;GD`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!0<N%V82!(;W-T^0!0<N%V82!H;W-T^0!+;FEH82!(;W-T^0!'=6EN96$`
M1W5I;F5A+4)I<W-A=0!'=7EA;F$`2$@`2%1-3`!(5$U,3V)L87-T('IB86+L
M;&4@;V1M[73A('-M87IA="!P;W-L961N[2!B=?)K=2!N82#XX61K=2X`2%1-
M3$]B;&%S="!Z8F%B[&QE(&]D;>UTX2!S;6%Z870@<&]S;&5D;NT@8G7R:W4@
M=F4@<VQO=7!C:2!T86)U;&MY+@!(5$U,3V)L87-T('IB86+L;&4@;V1M[73A
M('-M87IA="!P;W-L961N[2#XX61E:R!V('1A8G5L8V4N`$YE8GEL;R!N86QE
M>F5N;R!P<F]K87IO=N%N[2!I9&5N=&ET>2!P;VUO8^T@2%144`!(86ET:0!(
M87-H+4%L9V]R:71M=7,`36QH879O`$AL879IZ&MA`$AE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<P!(96)R96JY=&EN82`H25-/+3@X-3DM."U)
M*0!6_;EK80!.X7!O=NQD80!.X7!O=NQD82!P<F\@961I=&]R`%!O;6]C;NUK
M`%!O;6]C;NUK(&IE(&%P;&EK86-E(&MT97+A(&YA<&]MX6CA('9Y=';A^&5N
M[2!P^&5K;&%D^2!P<F\@2&]R9&4*82!J96AO(&%P;&EK86-E+@I0;VMU9"!P
M;W3X96)U:F5T92!V[6-E(&EN9F]R;6%C[2!J86L@=GET=N'X970@</AE:VQA
M9'DL(&YA:F1E=&4@:F4@=B!S;W5B;W)U(%)%041-12X`2&5M:7-FZ7)A`%ID
M92!J92!Z8>CA=&5K('-O=6)O<G4Z`%9Y<V]KX0!0;VQOOFMY('8@:&ES=&]R
M:6D@;F5S;>T@8OUT('!RX7ID;ND`7TAO<F1E`%-V873I($WL<W1O("A6871I
M:^%N*0!(;W)D90!!9')E<V$@1&]M^0!496QE9F]N($1O;?D`2&]N9'5R87,`
M2&]N9R!+;VYG`$AO<F1E`$=E;F5RX71O<B!P^&5K;&%D=2!P<F\@2&]R9&4`
M2&]R9&4O2V]L86(Z($YE<&QA=&[I("5S(%A-3"!D871A('9E('IP<N%V["`E
M<P!(;W)D92]+;VQA8CH@KN%D;N$@>G!RX79A('-E(&YE<VAO9'5J92!S(&]B
M:F5K=&5M("5S`$AO<F1E+TMO;&%B.B!.96)Y;"!N86QE>F5N(+[A9&[](&]B
M:F5K="!T>7!U("5S('9E('IP<N%V["`E<P!(;W)D92]+;VQA8CH@VG-P[+EN
MZ2!O9'-T<F%N[&[M("5S("(E<R(`2&]R9&4O2V]L86(Z(-IS<.RY;N$@<WEN
M8VAR;VYI>F%C92`E<R`B)7,B`$AO<F1E+TMO;&%B.B!);G1E9W)AZ&[M(&[A
M<W1R;VH@<&]T^&5B=6IE(%!(4"!P^.UP;VYU("=D;VUX;6PG`$AO<F1E+TMO
M;&%B.B!.96QZ92!V>71V;_AI="!N;W;]('-T<F]M(%A-3"!P<F\@;V)J96MT
M("5S`$AO<F1E+TMO;&%B.B!.96QZ92!O9'-T<F%N:70@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z($YE;'IE(&]B<KYE="!-24U%($E$('!R;R#HX7-T('1Y
M<&4@)7,`2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO=F%T("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!.96QZ92!S>6YC:')O;FEZ;W9A="!S9.UL
M96[I(&]B:F5K='DZ("5S`$AO<F1E+TMO;&%B.B!.97INX6W]('-D[6QE;OT@
M;V)J96MT("(E<R(`5F]D;W)O=F[I(%!R87;M=&MO`$AO<FEZ;VYTX6QN[2!O
M9'-T=7``2&]R:7IO;G3A;&[M.@!*86L@:G-T92!S92!S96T@9&]S=&%L:3\@
M*%IAN6QE=&4@<')O<^UM('IP<N%V=2$I`$MO;&EK('-L;W5P8_D@8VAC971E
M('-P;VII=#\`2V]L:6L@:F4@=&%M('!O;.T@*'-L;W5P8_DI/P!+;VQI:R#X
MX61K^2!C:&-E=&4@<W!O:FET/P!6;&AK;W-T`%9L:&MO<W0Z`$AU;6]R;ND`
M36'O87)S:V\`4V5L:&%L;R!V>71V;_AE;NT@24U!4&]VZ2!S8VARX6YK>3H@
M)7,`4V5L:&%L;R!S;6%ZX6[M($E-05!O=ND@<V-H<N%N:WDZ("5S`%-E;&AA
M;&\@;F%S=&%V96[M(&MV\W1Y('!R;R!)34%0;W9O=2!S8VARX6YK=3H@)7,`
M25`@061R97-A`$E0(&%D<F5S82!N96[M(&1O<W1U<&[A+@!)4"!A9')E<V$@
M;F5N[2!V('!O=F]L96[I;2!#2412(')E9VEO;G4N`%!O<G6Y96[M(&EN=&5G
M<FET>2!)4"X`5E]L;[YT92#8X61E:R!0^&5D`$ES;&%N9`!0;W5Z92!):V]N
M:WD`26MO;FMY('!R;R`E<P!):V]N:WD@<R!T97AT96T`3N%Z978@261E;G1I
M='D`4&]K=60@>F]B<F%Z96[M(&YE;NT@=B!P;_CA9&MU+"`E<R!O=&5V^&ET
M('8@;F]VZ6T@;VMN["X`4&]K=60@<&]UONUVX71E($EN=&5R;F5T($5X<&QO
M<F5R(&$@;F5V:63M=&4@ON%D;ND@:6MO;FMY+"!Z^&5J;>P@<&]T^&5B=6IE
M(&]Z;F'H:70@=&5N=&\@<N%M9>AE:RP@86)Y('-E(&1E86MT:79O=F%L82!0
M3D<@=')A;G-P87)E;F-E+@!0;VMU9"!V:61I=&4@='5T;R!Z<'+A=G4@;6ES
M=&\@;V)RX7IK=2P@;V)RX7IE:R!N96QZ92!Z;V)R87II="!P;VUO8^T@5F&Y
M96AO('!R;VAL[;YEZ&4N`%5KX7IK82!/8G+A>FMU.@!54DP@3V)RX7IK=0!5
M4DP@3V)RX7IK=3H`3V)RX7IE:R!Z(&=A;&5R:64`3V)RX7IE:R!Z(&=A;&5R
M:64Z`$YA:'+A;NT@;V)RX7IK=0!/8G+A>FMY`$EM<&]R="P@2W)O:R`E9`!)
M;7!O<G1O=F%NZ2!0;VQE.B`E<P!);7!O<G1O=F%NX2!P;VQE.@!6(%!R;V-E
M<W4`5FQOOB!.96[M`$YE<&QA=&[I($AE<VQO`$)Y;"!Z863A;B!N97-P<N%V
M;OT@86OH;NT@:_-D+@!.97-P<N%V;NP@>F%D86[I('6^:79A=&5L<VOI(&IM
MZ6YO(&$O;F5B;R!H97-L;P!.97-P<N%V;ND@=;YI=F%T96QS:^D@:FWI;F\@
M;F5B;R!A;'1E<FYA=&EV;NT@861R97-A+B!::W5S=&4@:NRY=.P@:F5D;F]U
M(&YE8F\@:V]N=&%K='5J=&4@5F&Y96AO('-Y<W3I;6]VZ6AO(&%D;6EN:7-T
M<N%T;W)A+@!:=NQTN6ET($]D<V%Z96[M`$EN9&EE`$IE9&YO=&QI=OT@5;YI
M=F%T96SI`$EN9&]NZ7-I90!);F9O<FUA8V4`26YF;W)M86-E`%#X:7!R879U
M:NUC[2!M;V1U;"`E<RXN+B``5FQOOFET(%-?;&]U<&5C(%!O`%9L;[YI="!/
M8G+A>F5K`%9L;[YI="!486)U;&MU`%9L;[YI="!796)O=F]U($QI;FMU`%9L
M;[YI="!?4VQO=7!E8R!0^&5D(`!6;&^^:70@;F]V_2!S;&]U<&5C('IA('-O
M=>AA<V[]`%9L;[YI="!N;W;]('-L;W5P96,@</AE9"!S;W7H87-N_0!6;&^^
M:70@;F]V_2#XX61E:R!Z82!S;W7H87-N_0!6;&^^:70@;F]V_2#XX61E:R!P
M^&5D('-O=>AA<V[]`%9L;[YI="!P87)A9W)A9B!Z82!S;W7H87-N_2!U>F5L
M`%9L;[YI="!P87)A9W)A9B!P^&5D('-O=>AA<V[]('5Z96P`5FQOOFET(&%L
M=&5R;F%T:79N[2!V>F]R`%9L;[YT92!E;6%I;&]V;W4@861R97-U+"!N82!K
M=&5R;W4@;V)D<K[M=&4@;F]VZ2!H97-L;SH`5FQOOFET(&)U\FMU('IA`%9L
M;[YI="!B=?)K=2!P^&5D`%9L;[YI="!S;&]U<&5C('IA`%9L;[YI="!S;&]U
M<&5C('#X960`5FQOOFET('IP<N%V>0!6;&^^:70@<&%R86=R868@<&\`5FQO
MOFET('!A<F%G<F%F('#X960`5FQOOFET(/CA9&5K('!O`%9L;[YI="#XX61E
M:R!P^&5D`%9L;[YT92!P;[YA9&]V86YO=2!O9'!O=NSO(&YA(&)E>G!EZ&YO
M<W1N[2!O=.%Z:W4Z`%9L;[YI="]-;V1I9FEK;W9A="!/8G+M>F5K`%9L;[YI
M="]-;V1I9FEK;W9A="!,:6YK=0!.961O<W1A=&7H;OT@:W)E9&ET(&L@>F%S
M;.%N[2!Z<'+A=GD@;F$@9&ES=')I8G7H;NT@<V5Z;F%M+@!E9&]S=&%T9>AN
M_2!K<F5D:70N`$-E;.D@R.US;&\`4V5Z;F%M($-E;/UC:"#([7-E;`!">6QA
M('9Y8G+A;F$@;F5S<'+A=F[A(&%K8V4@<')O('1E;G1O(&MO;7!O;F5N="X`
M3F5S<'+A=F[I(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!.97!L871NX2!A
M<&QI:V%C92X`3F5P;&%T;ND@:61E;G1I9FEK8>AN[2#H[7-L;R`H240I(&1A
M=FMY+@!">6QY('IA9.%N>2!N97!L871NZ2!D871A`$YE<&QA=&[A(&%D<F5S
M82!P^.UJ96UC92X`3F5P;&%T;OT@9F]R;>%T('-O=6)O<G4`3F5P;&%T;OT@
M;7-G7W1Y<&4N`$YE<&QA=&[I(.AI(&-H>6+L:NUC[2!A<&E?:60N`$YE<&QA
M=&[I(.AI(&-H>6+L:NUC[2!P87)A;65T<GDN`$YE<&QA=&[I('9L87-T;FEC
M:^D@<'+A=F$N`$YE<&QA=&[]('!R;W1O:V]L+@!.97!L871N_2!P^.UJ96UC
M93H@)R5S)P!.97!L871N_2!S9.UL96[](&]B:F5K=`!.97!L871NX2!A9')E
M<V$@;V1E<VEL871E;&4N`$YE<&QA=&[I(&1A=&$@=6YI:_-D=2X`26YV96YT
MX?@`S7+A;BP@27-LX6US:^$@4F5P=6)L:6MA`$ERX6L`27)S:V\`3W-T<F]V
M($UUOF4`3VIE9&EN[&SI($)O=?AK>0!)<W)A96P`4&]S:WET;W9A=&5L`$MU
M<GKM=F$`273A;&EE`$IA;6%J:V$`3&5D96X`2F%P;VYS:V\`2F%P;VZY=&EN
M82`H25-/+3(P,C(M2E`I`%1R:6MO=`!*;W)DX6X`R&5R=F5N96,`R&5R=F5N
M`%IA<F]V;F%T`%IA<F]V;F%T(&ME(%-T^&5D=0!:87)O=FYA="!N82!/8F]U
M(%-T<F%NX6-H`%IA<F]V;F%T(&1O($QE=F$`6F%R;W9N870@9&\@4')A=F$`
M2V%Z86-H<W3A;@!58VAO=F%T(&]R:6=I;N%L/P!+9?)A`$ME<F)E<F]S('-E
M<G9E<B!Z86UI=&YU;"!O=NSX96[M+@!.;W;AZ&-I($ME<FYE;'4`5GET=F_X
M96[M($ML[>AE`%9Y='9O^&5N[2!/=&ES:W4@2VSMZ&4`1.EL:V$@2VSMZ&4`
M5'EP($ML[>AE`%6^:73M($ML[>AE`$ML[>@@:FF^(&5X:7-T=6IE('9E('9E
M^&5J;NEM(&ML[>AO=NEM('-E<G9E<G4N`$3L=&D`2VER:6)A=&D`2V]R96$L
M($QI9&]V["!$96UO:W)A=&EC:^$@4F5P=6)L:6MA`$MO<F5A+"!297!U8FQI
M:V$`2V]R96IS:WD@*$550RU+4BD`2W5V86IT`$MY<F=I<W3A;@!?4F]Z;&^^
M96[M`$IA>GEK`$QA;W,L($QI9&]V["!$96UO:W)A=&EC:V$@4F5P=6)L:6MA
M`$1R=6CA(%!O;&]V:6YA`%!O<VQE9&[M(,AT=G)T:V$`4&]S;&5D;NT@06MT
M=6%L:7IA8V4Z`%!O<VQE9&[M('#X:6ALX;EE;NTZ("5S`%!O<VQE9&[M('#X
M:6ALX;EE;NTZ("5S('H@)7,`4&]S;&5D;NT@</AI:&SAN65N[3H@3FEK9'D`
M3&ET=F$`4'+A=F\`4F]Z;&^^96[M`$YE8VAA="!P<N%Z9&[I(&)E>B!H<F%N
M:6-E`$QI8F%N;VX`1&]L979A`$QE=N$@:&QA=FGH:V$`2&]D;F]T>2!N86QE
M=F\`3&5S;W1H;P!,:6+I<FEE`$QI8FEE`$QI8VANN71E:FYS:V\`3&5H:^D@
M37)H;VQE;NT`3&5H:_T@1.FYNP!"<GIK_2!,96AK_2!$Z;F[`%!O>F3L:FD@
M3&5H:_T@1.FYNP!,96AK_2!$Z;F[;W;I(%-RX;YK>0!,96AK_2!$Z;F[(',@
M2/AM[&[M;0!,96AKZ2!3;NR^96[M`$QE:&OI(%-N[+YNZ2!0^&5HX?)K>0!,
M:6UE<FEC:P!,:6YK80!,:6YK>2!U>F%Z=6KM(&YA.@!.86QI;FMO=F%T(&5M
M86EL;W;I(&%D<F5S>2!P^&D@>F]B<F%Z;W;A;NT@<W1RX6YK>2!P<F\@<'-A
M;NT@>G!RX78`3&EN:WD`3&EN=7AO=ND@4VQA9&MO<W1I`%-E>FYA;2`M('6^
M:79A=&5L(&WYOF4@=FED['0@861R97/A^`!397IN86T@1&%T86+A>NT`4V5Z
M;F%M(%3I;6%T($[A<&]V[&1Y`%-E>FYA;2!486)U;&5K`%-E>FYA;2U!<F-H
M[78`4V5Z;F%M+4[A<&]V[&1A`%-E>FYA;2U)9`!397IN86TM5FQA<W1N[6L`
M4V5Z;F%M+4]D97-LX6[M`%-E>FYA;2U0^&EH;.&Y96[M`%-E>FYA;2U/9&AL
MX;EE;NT`5OUP:7,@=;YI=F%T96SY(&YE;NT@9&]S='5P;OTN`$QI=&5R871U
M<F$`3&]T>;ES:V\`3N%H<N%V86KM8^T@:VYI:&]V;GDN+BX`4W1A:'5J:2XN
M+@!-[7-T;NT@Z&%S.B``3&]C86QE(&$@R&%S`$WM<W1O`%#X:6ALX7-I="!S
M90!/9&ALX;EE;NT`VFMO;'D@<')O=N%D[&[I('#X:2!P^&EH;.&Y96[M`%-E
M;&AA;&\@</AI:&SAN65N[2!D;R!S>71SZ6UU+B!0<F%V9.QP;V1O8F[L(%9A
MN64@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO(&YE8GEL;R!N97-P
M<N%V;NP@>F%DX6YO+@!0^&EH;.&Y96[M(%-E;&AA;&\N`$1L;W5H_2!T97AT
M`$SA<VMA`$YI>FOA`&UA;.$@^&5C:^$@<.US;65N80!M86SA('1I<VMA8^T@
M<.US;65N80!-86SI(/CM;7-KZ2#H[7-L:6-E`$QU8V5M8G5R<VMO`$U-`%IP
M<N%V82!$;F4`4/AI<&]J96[]('-O=6)O<B!-4RU.5$5&(&YE;V)S86AU:F4@
MON%D;ND@9&%T82X`35-'`$UA:V%O`$UA:V5D;VYI92P@8OUV86SA(%)E<'5B
M;&EK82!*=6=O<VSA=FEE`$UA9&%G87-K87(`36%G:64`4&^Y=&$`061M:6YI
M<W1R[71O<B!P<F\@4&^Y='4`5GET=F_X:70@;&EN7VMU+BXN`$]V[/AT92!Z
M9&$M;&D@4$5!4B!J92!I;G-T86QO=N%N(&$@>F%H<FYU="!V(&EN8VQU9&4@
M<&%T:"X`5GET=N'X[2!V(&%D<F5SX?AI("5S`$UA;&%W:0!-86QA:G-I90!-
M86QD=FEN>0!-86QI`$UA;'1A`%!R;R!U;6^^;NQN[2!O=FSA9.%N[2!K871E
M9V]R:>T@:F4@>F%P;W3X96+M(&]Z;F'H:70@<&]L;[YK>2!B87)V86UI+"!K
M=&5RZ2!J<V]U('#X:?AA>F5N>2!K('3L;71O(&MA=&5G;W)I[6TN`$UA<#(T
M($UA<&$`36%P82!-87!1=65S='4`0OAE>F5N`$]K<F%J`$]Z;F'H:70@>FYA
MZ&MO=2!0<F]H;.UD;G5T;R].97!R;VAL[61N=71O`$]Z;F'H:70@:FEN_6UI
M('IN8>AK86UI("AJ86MO($3Y;&6^:73I+T]D<&]V['IE;NDI`$UA<KEA;'-K
MZ2!/<W1R;W9Y`$UA<G1I;FEQ=64`4VAO9'5J[6/M('-E('!O;&4`36%U<F5T
MX6YI90!-875R:6-I=7,`36%X:6UA;&[M(&1O=F]L96[](&MR961I=`!">6QA
M('#X96MR;^AE;F$@;6%X:6UA;&[M(&3I;&MA('IP<N%V>2X`3F5J=GF^N>T@
M=&5P;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``3F5J=GF^N>T@=&5P
M;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!-87AI;6%L;NT@9.EL:V$`
M2W;L=&5N`$UA>6]T=&4`365D:6/M;F$`6G)UN65N[2!38VCY>F4`26YF;W)M
M86-E(&\@4V-H^7II`$YA=G)H(&YA(%-C:/EZ:0!/9'!O=NSO(&YA(%-C:/EZ
M:0!!:W1U86QI>F%C92!38VCY>F4`4&^^861A=F5K(&YA($%K='5A;&EZ86-I
M(%-C:/EZ90#(;&5N;W;I`$WS9'D@<')O($UE;G4Z`%-P;VII="!B=?)K>0!0
M<F]B[6CA('-P;VIO=N%N[2!VN65C:"`E<RYP;R!S;W5B;W+Y(&1O(&MO;7!E
M;F1I82XN+B``4')O8NUHX2!S<&]J;W;A;NT@;&]C86QE("5S+BXN(`!0<F]B
M[6CA('-P;VIO=N%N[2!03R!S;W5B;W)U('!R;R`E<R!D;R!K;VUP96YD:6$N
M+BX@`%!R;V+M:.$@</AE:VQA9"!P<F\@;6]D=6P@)7,N+BX`6G!RX79A`%IP
M<N%V82!B>6QA(&]V[/AE;F$@=B!P;_CA9&MU+"!B;VAUOF5L(&YE;'IE(&]V
M[/AI="!P;V1P:7-O=OT@8V5R=&EF:6OA="X`6G!RX79A('!R;W!A9&QA+@!4
M>7`@6G!RX79Y`%!OZ&%S[0!";&]C:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]
M+@!";&]C:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]+B!$971A:6QY(&)Y;'D@
M>F%Z;F%M96[A;GD@<')O('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T;W)A+@!-
M971O9&$`365T;V1A("<E<R<@;F5N[2!D969I;F]VX6YA`$UE=')I8VO]`$UE
M>&EK;P!-:6MR;V[I<VEE+"!&961E<F%C90!5<')O<W3X960`36EM92!4>7``
M3F5J;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``3F5J
M;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!-:6YI;>%L
M;NT@9&]B82!P;&%T;F]S=&D@:&5S;&$@:F6Y=.P@;F5V>7!RN65L80!:<F-A
M9&QO=NP`4OEZ;ND`4')O9W)A;6]V_2!B86SM:R!(5%107U)E<75E<W0@8VAY
M8NT@=B!014%2+@!#:'EB[&KM8^T@:V]N9FEG=7)A8V4N(%!O:W5D('-I('#X
M96IE=&4@<&]UONUV870@='5T;R!A<&QI:V%C:2P@;75S[71E(&=E;F5R;W9A
M="!K;VYF:6=U<F'H;NT@<V]U8F]R+@!#:'EB[&KM8^T@240@>G!RX79Y("AI
M9&5N=&EF:6MAZ&[M(.CM<VQO*0!0;[YA9&]V86[]('!R;V=R86UO=OT@8F%L
M[6L@36%I;"!C:'EB[2!V(%!%05(N`$-H>6+L:NUC[2!)1"!P<F\@<F5L86-I
M+@!0;P!-;V)I;&[M(%!ON71A`$WM<F[]`$1A='5M(%!O<VQE9&[M(%IM[&YY
M`%IM[/)I="!54DP`36]D=6P`36]D=6P`36]L9.%V:64`36]N86MO`$UO;F=O
M;'-K;P!-['/M8R!A(')O:P!-['/MZ&[L`$UO;G-E<F%T`$;A>F4@3>QS[6-E
M`$UA<F]K;P!0^&5VX;YN["!*87-N;P!0^&5VX;YN["!/8FQAZ&YO`%#X97;A
MOF[L(%-L=6YEZ&YO`%!O<W5N;W5T($1O;/D`4&]S=6YO=70@1&]L979A`%!O
M<W5N;W5T($1O<')A=F$`4&]S=6YO=70@3F%H;W)U`%!O<W5N;W5T(&1O;/D`
M4&]S=6YO=70@;F%H;W)U`$UO<V%M8FEK`%;M8V4M^G)O=O)O=ND@<F]L971O
M=ND@<V5Z;F%M>0!6[6-E;N%S;V)NX2!S96QE:V-E`$WY:B#:Z&5T`$WY:B!0
M;W)TX6P`36]J92!2;WIL;[YE;NT@4&]R=.%L=0!->6%N;6%R`$Y%+"!.15-/
M54A,05/-30!*;>EN;P!.86WM8FEE`$YA=7)U`%!O=/AE8G5J92!:X6MR;VL`
M3F5PX6P`3FEZ;WIE;>T`3FEZ;WIE;7-KZ2!!;G1I;'D`3F5T<V-A<&4@0F%S
M92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@
M<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O
M8V%T:6]N(%523`!*;>EN;R!.971S8V%P92!34TP@<V5R=F5R=0!0;WINX6UK
M82!K(&-E<G1I9FEKX71U($YE='-C87!U`%1Y<&4@8V5R=&EF:6OA='4@3F5T
M<V-A<'4`4^V[`$YI:V1Y`$YO=N$@2V%L961O;FEE`$YO=N$@2V%T96=O<FEE
M`$WL<^UC('8@4')V;NT@R'1V<G1I`$YO=ND@5;YI=F%T96QS:^D@2FWI;F\@
M*&YE<&]V:6YNZ2D`3F]V_2!:Z6QA;F0`3F]VZ2!H97-L;SH`3F]VZ2!O:VYO
M("A?<'+A>F1NZ2D`3F]V:6YK>0!.97=S9W)O=7!S`$1A;+GM`$1A;+GM(%-T
M<N%N:V$`1&%LN>T@1N%Z90!$86RY[2!M;[YN;W-T:0!.:6MA<F%G=6$`3FEG
M97(`3FEGZ7)I90!.;V,`3FEU90!.90"N861NZ2!K;VYF:6=U<F'H;NT@9&%T
M82!N96IS;W4@9&]S='5P;ND@<')O('IO8G)A>F5N[2!R;WID[6SY+@!.96[M
M(&1O<W1U<&[A(+[A9&[A('-T<F%T96=I92!P<F\@='9O<F)U($E33R!O8G)A
M>ODN`$)E>B!DX79K;W;I:&\@=GIO<G4N`$YA('!OOF%D;W9A;ND@<&]Z:6-I
M(&YE97AI<W1U:F4@ON%D;OT@8FQO:P!.96)Y;&\@<&]S:WET;G5T;R"^X61N
MZ2!J;>EN;R!P<F\@:V%L96YDX?@@</AI(&]V[/AO=N%NZ2!P<F\@34-!3`!"
M97H@>FWL;GDN`$YE;'IE('#X:61A=""^X61NZ2!P;V0@<'+A=F$@<&]D('1U
M=&\@^G)O=F7R+@!.96QZ92!P^&ED870@ON%D;ND@<&]D('!RX79A(&L@=.QM
M=&\@<'+A=OEM+@!.96)Y;"!U=F5D96X@ON%D;OT@</CM:V%Z+@!.96)Y;'D@
M=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R`E<RX`
M3F5B>6QY('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P
M<F\@1E10(%9&4P!.96)Y;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@
M:6YF;W)M86-E('!R;R!344P@5D93`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO
M;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O(%-13"U&:6QE(%9&4P!.96WA=&4@
MON%D;OT@:W)E=&ET+@!.96)Y;"!P;W-K>71N=70@ON%D;OT@8^UL+@"NX61N
MX2!P;VQOOFMA(&1A;NEH;R!I9"`G)7,G(&YE97AI<W1U:F4@=B!O<FEG:6[A
M;&[M;2!S;W5B;W)U(',@;N%P;W;L9&]U+@"NX61N_2!S;W5B;W(@;F5B>6P@
M;F'H=&5N`$YE8GEL>2!N86QE>F5N>2"^X61NZ2!I:V]N:WDN`$YE8GEL('5V
M961E;B"^X61N_2!L;V-A;&4`3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US=&\N
M`$YE8GEL>2!P;W-K>71N=71Y(+[A9&[I('IP<N%V>2X`3F5B>6QO('!O<VMY
M=&YU=&\@ON%D;ND@:FWI;F\N`$YE8GEL;R!U=F5D96YO(+[A9&[I(.CM<VQO
M+@!"97H@;F5S;'6Y;OUC:`!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@
M;W;L^&5N[2!Z82!P;W6^:73M($A45%`N`$YE8GEL;R!P;W-K>71N=71O(&AE
M<VQO('!R;R!O=NSX96[M('IA('!O=;YI=.T@24U!4"X`3F5B>6QO('!O<VMY
M=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@>F$@<&]UOFET[2!+97)B97)O<RX`
M3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@>F$@<&]UOFET
M[2!,1$%0+@!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P
M^&EH;.&Y96[M('-E(&1O('-Y<W3I;74N`$YE8GEL;R!P;W-K>71N=71O(&AE
M<VQO('!R;R!O=NSX96[M('IA('!O=;YI=.T@4$%34U=$+@!.96)Y;&\@<&]S
M:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!Z82!P;W6^:73M(%--0BX`3F5B
M>6QA('!O<VMY=&YU=&$@8V5S=&$@:R!B:6[A<F[M;74@<V]U8F]R=2!/<&5N
M4U-,+B!":6[A<F[M('-O=6)O<B!/<&5N4U-,(&IE('IA<&]T^&5B[2!P<F\@
M<'+A8VD@<R!02T-3(#$R(&1A='DN`*[A9&[I(&YE=GGX[7IE;NT@ON%D;W-T
M:2!O('#X:6ALX;EE;NTN`$)E>B!P<F%V:61E;`!"97H@;VMR86KY`"<E<R<@
M8F%C:V5N9"!N96)Y;"!N86QE>F5N+@"NX61N_2!Z(&1OZ&%S;OUC:"!A9')E
M<^'X^2!N96[M(&1O<W1U<&[]('!R;R!C86-H92X`3F5B>6QO('IA<VSA;F\@
MON%D;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+@!.96)Y;'D@
M;F%V<N%C96YY(+[A9&[I('!L871NZ2!834P@9&%T82X`KN%D;ND@2&]D;F]T
M>0!6(&]R:6=I;N%L;NT@:V]N9FEG=7)A8VD@;F5B>6QA(&YA;&5Z96YA('9E
M<GIE+B!/8FYO=G1E(&MO;F9I9W5R86-I+@!692!68;GM(&MO;F9I9W5R86-I
M(&YE8GEL82!N86QE>F5N82!V97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C:2X`
M3F5N[2#:Z&%S=&[M:V5M`*[A9&[]`*[A9&[]("AP;W6^:6IT92!I;7!L:6-I
M=&[M*0!3979E<G-K_2`H25-/+3@X-3DM,3`I`$YO<F9O;&MS:^D@3W-T<F]V
M>0!3979E<F[M(%!O;&]K;W5L90!3979E<F[M($UA<FGA;G-KZ2!/<W1R;W9Y
M`$YO<G-K;P!.96[M(%!O`$YE;NT@4/AE9`!.96[M(&%D<F5SX?AE;0!.96[M
M(&EM<&QE;65N=&]VX6YO+@!.96[M(&YA<W1A=F5N;P!.96[M('!O9'!O<F]V
MX6YO+@!0;WINX6UK80!.:6,@:R!P<F]H;.ED;G5T[2P@8NR^=&4@>G#L="X`
M57!O>F]R;NQN[0!,:7-T;W!A9`#([7-L;P!0;^AE="!Z;F%K^0!0;^AE="!S
M;&]U<&/Y`%!OZ&5T(/CA9&OY`$YE8GEL>2!Z863A;GD@Z.US;&$@<')O(&%K
M='5A;&EZ86-I(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2X`3TL`3V)J96MT`%9Y
M=';A^&7H($]B:F5K=/D`4'+A=F$@<')O('9Y=';A^&7H(&]B:F5K=/D`3W-M
M:>AK;W;]`-CM:F5N`$9I;'1E<F]V870@;F5S;'6Y;ND`2V%N8V5LX?@`4W1A
M<ND@:&5S;&\Z`$]MX6X`4V3M;&5NZ2!S;&^^:WD@:G-O=2!P;W-K>71O=N%N
M>2!P;W5Z92!)34%0('-E<G9E<GDN`%!O=7IE(&YE<VQUN6[I`$IE('!O=F]L
M96YA('!O=7IE(&IE9&YA(&4M;6%I;&]VX2!A9')E<V$N`%!O=7IE('9L87-T
M;NUK(&YE8F\@<WES=.EM;W;](&%D;6EN:7-T<N%T;W(@;?F^92!Z;>QN:70@
M<'+A=F$@<')O('-D[6QE;OT@;V)J96MT+@!/=&5V^&ET('8@;F]VZ6T@;VMN
M["X`0TAY8F$@3W!E;E-33#H@3F5L>F4@>NUS:V%T(&1A=&$@>B#HX7-T:2!O
M>FYAZ&5NZ2!3+TU)3D4N`$]T97;X:70@;&EN:W4@=B!N;W;I;2!O:V[L`$]P
M97)AZ&[M(%-Y<W3I;0!-;[YN[2#:Z&%S=&[M8VD`36^^;F]S=&D`36^^;F]S
M=&D@<')O("5S`$UOOFYO<W1I.@!39?AA>F5N_2!397IN86T`3W)G86YI>F%C
M90!/<F=A;FEZ8>AN[2!*961N;W1K80!/<F=A;FEZ;W;A;NT`3W)I9VENX6QN
M[2!V>F]R('!R;R"^X61O<W0`3W)I9VENX6QN[2!V>F]R('8@)7,Z`$]S=&%T
M;NT`3W-T871N[2!);F9O<FUA8V4`5;YI=F%T96QS:^$@4'+A=F$`3W;L^&5N
M[2!004T@;F5N[2!D;W-T=7!NZ2X`4$=0($1I9VETX6QN[2!3:6=N871U<F$`
M4$=0($OS9&]V86[I($1A=&$`5F7X96IN_2!01U`@2VSMZ`!$871A($]Z;F'H
M96[A+TOS9&]V86[A(%!O;6]C[2!01U``4$A0($OS9`!02%`@:V]N<V]L80!/
M9'!O;&5D;NT@3&5H:_T@1.FYNP!/9'!O;&5D;NT@4/AE:.'R:WD`3V1P;VQE
M9&[M($)O=?AK>0!07TA0($MO;G-O;&$`3V1S='5P>0!086MI<W3A;@!086QA
M=0!086QE<W1I;G-KZ2!497)I=&]R:75M+"!/:W5P;W9A;ND`4&%N86UA`%!A
M<'5A($YO=N$@1W5I;F5A`%!A<F%G=6%Y`$WM<W1Y(%IA=&&^96YO`%!A<W-W
M9"!N96[M('-P<N%V;NP@;F%K;VYF:6=U<F]VX6XN`$AE<VQO`$AE<VQO('IM
M[&[L;F\@=B`E<RX`3F5S<'+A=F[I(&AE<VQO`%!A<W-W;W)D(&UO9'5L(&YE
M;F%L97IL('!O<VMY=&YU=&]U('-C:'+A;FMU+@!#:'EB[2!P;[YA9&]V86[I
M('!A<F%M971R>2!P<F\@;6]D=6P@4&%S<W=O<F0N`$-H>6+M(&/M;&]V_2!P
M87)A;65T<B!P<F\@;6]D=6P@4&%S<W=O<F0N`$UO9'5L(%!A<W-W;W)D(&YE
M;NT@<W!RX79N["!K;VYF:6=U<F]VX6X`36]D=6P@4&%S<W=O<F0@;F5N[2!S
M<'+A=F[L(&MO;F9I9W5R;W;A;BX`4')O(&]V[/AE;NT@<&]M;V/M(%)!1%5)
M4R!J92!N=71N;R!Z861A="!H97-L;RX`2&5S;&\@<R!P;W1V<GIE;NUM`$AE
M<VQO.@!(97-L;SH@`$AE<VQA('-E(&UU<^T@<VAO9&]V870N`%9L;[YI=`!6
M;&^^:70@>F4@<V-H<N%N:WD`0V5S=&$`KN%D;W-T:2!O(%#X:6ALX;EE;NTZ
M`$QI9.D`4')O8V5N=`!0<F]VZ7-T($]P97)A8V4@VF1ROF)Y`%!R;W;I<W0@
M;W!E<F%C92#Z9'*^8GD@</AI('#X:6ALX;EE;NT@9&\@<WES=.EM=3\`4'+A
M=F$`4'+A=F\@)R5S)R!N96)Y;&\@<VUA>N%N;RX`061M:6YI<W1R8>AN[2!0
M<N%V80!0<N%V82!P<F\`3W-O8F[M($EN9F]R;6%C90!097)U`$1O;>%C[2!:
M=NWX871A`$9I;&EP[6YY`%1E;&5F;VX`1F]T:WD`4&ET8V%I<FX`4&EX96SY
M`$9RX7IE`%!R;W/M;2!K;&EK;NQT92!N82!N[&IA:V]U(&)U\FMU`%!R;W/M
M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N=&\@96QE
M;65N=#H`4')O<^UM('!O='9R[W1E+""^92!S:2!P^&5J971E(&]D<W1R86YI
M="!T96YT;R!E;&5M96YT+@!0<F]S[6T@>F%D96IT92!M['/M8R!A(')O:RX`
M4')O<^UM('IA9&5J=&4@;N%Z978@;F]VZ2!K871E9V]R:64Z`%!R;W/M;2!Z
M861E:G1E('-P<N%V;F]U($E0(&%D<F5S=2XN`%!R;W/M;2!Z861E:G1E('-P
M<N%V;OT@9&%T=6T@82!Z:V]N=')O;'5J=&4@<&_H970@9&[M('8@;>QS[6-I
M+@!0<F]S[6T@>F%D96IT92!S<'+A=F[](.AA<RX`4')O<^UM('5V9>]T92!S
M:')N=73M(%9AN65H;R!P<F]B;.EM=2X`4')O<^UM('IA9&5J=&4@5F&Y92!U
MOFEV871E;'-KZ2!J;>EN;R!A(&AE<VQO`%!R;W/M;2!P^&7H=.QT92!S:2!N
MX7-L961U:NUC[2!T97AT+B!-55/-5$4@<V]U:&QA<VET(',@<&]D;>UN:V%M
M:2!P;W6^[7;A;NT@<WES=.EM=2X`4')O<^UM(&YA:&QAN71E(&YA;&5Z96[I
M(&-H>6)Y(&YA(&5M86EL;W;I(&%D<F5S92!I,3AN0&QI<W1S+FAO<F1E+F]R
M9RX`4')O<^UM('IK;VYT<F]L=6IT92!NX7-L961U:NUC[2!I;F9O<FUA8V4@
M82!P86L@=GEB97)T92#Z:V]N('H@;NV^92!U=F5D96[I:&\@;65N=2X`4')O
M<^UM('9Y8F5R=&4@^FMO;B!Z(&[MOF4@=79E9&5NZ6AO(&UE;G4N`%!R;W/M
M;2!Z861E:G1E(&YO=OT@;N%Z978@:V%T96=O<FEE.@!0;VQS:V\`4&]L:71I
M:V$`2&QA<V]VX6[M`%!O<G1U9V%L<VMO`%5M[7-T[&[M('1O:&]T;R!O8G+A
M>FMU`%5M[7-T[&[M('1A8G5L:WD`6F%S;&%T(&1O('3I=&\@<V-H<N%N:VQY
M("AN96[M('!O<VMY=&YU=&\@24U!4&5M*0!3<N&^:WD@>F$@<&]S;&5D;NTH
M8V@I("5S(&AO9&EN*'4I.B``4')E9G-?;&1A<#H@3F5B>6QA(&YA;&5Z96YA
M('!OOF%D;W9A;N$@</CM<&]N82!,1$%0+@!0<F5F<U]S97-S:6]N.B!.96)Y
M;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('-E:V-E+@!0<F5Z96YT
M86-E`$)A<F]M971R:6-K_2!4;&%K`$)A<F]M971R:6-K_2!4;&%K(&YA(/IR
M;W9N:2!M;_AE.B``0F%R;VUE=')I8VO](%1L86LZ`%5KX7IK80!5:^%Z:V$@
M;V)RX7IK=2!V(&YO=NEM(&]K;NP`4/AE9&-H;WKM(%-T<F%N80!0^&5D8VAO
M>NT@;6^^;F]S=&D`5&ES:VYO=70@1&]K=6UE;G0`3W-O8F[M($ML[>@`4')O
M8FSI;0!0;W!I<R!0<F]B;.EM=0!0<F]J96MT>0!0<F]M<'0@=&5X=`!69?AE
M:F[]($ML[>@`06QG;W)I=&UU<R!P<F\@5F7X96IN_2!+;.WH`$]S;V)N[2]6
M9?AE:F[](&ML[>AO=OT@<.%R(&YE8GEL(/IS<.RY;NP@=GET=F_X96XN`%!O
M<G1O(%)I:V\`2V%T87(`5GEH;&5DX6[M`%)302!69?AE:F[]($ML[>@@*"5D
M(&)I=/D`4W#X8;YE;ND@=&QAZ.UT:V\`1.FYNP!"<GIK_2!$Z;F[`%!O>F1N
M[2!$Z;F[`$1EN;MT;ND@4/AE:.'R:WD`3N%H;V1N["!V>6)R86[I(*ET['-T
M[0!0;VWL<@#(=&5C[0!0<F]H;.ED;.D@6G!RX79Y`$]P<F%V9'4@<VUA>F%T
M("5S/R!4871O(&]P97)A8V4@:F4@;F5V<F%T;N$N`$]P<F%V9'4@<VUA>F%T
M('6^:79A=&5L<VOA(&1A=&$@<')O('6^:79A=&5L92`E<S\@5&%T;R!O<&5R
M86-E(&IE(&YE=G)A=&[A+@!/<&%K;W9A="!P;W-L961N[2#Z:V]N`$]B;F]V
M:70@1'EN86UI8VOI($5L96UE;G1Y($UE;G4Z`$]B;F]V82!:;V)R87IE;NT@
M4&]R=.%L=3H@`$]B;F]V:70@0F_H;NT@3&FY='4`4F5G97@`4')O:&SMOF7H
M(%9Z=&%H^0!(;V1N;W1Y`%IA<&%M871O=F%T('-I(&EN9F]R;6%C:2!O(&9R
M964O8G5S>2X`5GIDX6QE;ND@4V5R=F5R>2X`5GKA;&5NX2!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!/9'-T<F%N:70`3V1S=')A;FET
M($)L;VL`3V1S=')A;FET(%-L;W5P96,`3V1S=')A;FET(&9O<FWM=&]VX6[M
M`$]D<W1R86YI="!Z(&WI:&\@:V%L96YDX?AE`$]D<W1R86YI="!PX7(`3V1S
M=')A=&ET('5L;[YE;OT@<VMR:7!T('H@9&_H87-NZ6AO(&%D<F5SX?AE(&YA
M('-E<G9E<G4N`$]D<W1R86YI=`!/9'-T<F%N:70@='5T;R#HX7-T(&1O:W5M
M96YT=0!/9'-T<F%N:70@=;YI=F%T96QE`$]D<W1R86YI="!UOFEV871E;&4Z
M("5S`$]D<&]V[.\@0GEL82!:87-LX6YA+@!/9'!O=NSO(',@3F5S=&%N9&%R
M9&[M(%IP<N%V;W4`3V1P;W;L9.QT(&YA(&9R964O8G5S>2!N82!P^.VY=.T@
M,B!M['/M8V4N`$]D<&]V[&3L="!S('!OOF%D;W9A;F]U(&EN9F]R;6%C[2!F
M<F5E+V)U<WDN`$]D<&]V[.\Z("5S`$YE;'IE(&]D<&]V[&3L="!N82!P;[YA
M9&%V96LN($-H>6)O=ND@:&SAN65N[3H@`%!OOF%D;W9A;ND@)R5S)R!N96)Y
M;&\@=79E9&5N;R!V(&MO;F9I9W5R86-I('!R;R`E<RX`4&^^861O=F%NZ2`G
M)7,G(&YE8GEL;R!U=F5D96YO('8@:V]N9FEG=7)A8VD@<')O(%9&4RX`4&^^
M861O=F%NZ2`G)7,G(&YE8GEL;R!U=F5D96YO('8@:V]N9FEG=7)A8VDN`%!O
MOF%D;W9A;ND@)V1R:79E<GDG(&IS;W4@;F5S<'+A=F[L(&MO;F9I9W5R;W;A
M;GD@=B!+;VUP;WIIZ&[M(&MO;F9I9W5R86-I+@!.96)Y;"!Z863A;B!P;[YA
M9&]V86[]("=P:'!T>7!E)R!V(&MO;F9I9W5R86-I(%!A<W-W9"!344PN`$YE
M8GEL('IA9.%N('!OOF%D;W9A;OT@)W!H<'1Y<&4G('8@:V]N9FEG=7)A8VD@
M4U%,+@!0;[YA9&]V86[M(-KH87-T;NUC:0!3;6%Z870`5GEM87IA="!(97-L
M;P!6>6UA>F%T(%9AN64@2&5S;&\`5OUS;&5D:WD`5OUS;&5D:WD@*'IA:')N
M=6KM8^T@2&]R9&4I.@!6_7-L961K>3H`3N%V<F%T(&L@36^^;F]S=&5M`%)E
M=6YI;VX`4/AE<&YO=70@2V]N9FEG=7)A8VD`36^^;F]S=&D@4FEC:"!497AT
M($5D:71O<G4`2.%D86YK>0!$;W!R879A`$AL879IZ&MA(&YA<')A=F\`2&]D
M;F]T>2!N87!R879O`%9L87-T;F]S=&D@V.%?9&MU`-IL;VAA`%)U;75N<VMO
M`$]T;^AI="!O(#$X,+``3W1OZ&ET(&1O;&5V80!/=&_H:70@9&]P<F%V80!6
M;&%S=&YO<W1I(-CA9&MU`%9L87-T;F]S=&D@^.%D:W4`V.%D:WDZ`%!R879I
M9&QA`%!R879I9&QA('-E('5P;&%T;NT@;65Z:2!VN65M:2#XX61K>2!A('-L
M;W5P8WD`4')A=FED;&$@<V4@=7!L871N[2!P;W5Z92!M97II('-L;W5P8WD`
M4')A=FED;&$@<V4@=7!L871N[2!P;W5Z92!M97II(/CA9&MY`%!R;W;I<W0`
M4G5S:^$@1F5D97)A8V4`4G=A;F1A`%,O34E-12!+<GEP=&]G<F9I8VOI($]Z
M;F'H96[M`%,O34E-12!+\V1O=F%NX2!:<'+A=F$`4T%33"!O=NSX96[M(&YE
M;NT@9&]S='5P;NDN`%--4R!Z<'+A=GD`4U%,($MO;GIO;&$`4U,`4U-(`-I3
M4,Q#2`!37U%,($MO;GIO;&$`4V\`4W9A=.$@2&5L96YA`%-V873]($MI='1S
M(&$@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!3=&5J;OT@<N%M
M("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I
M<&4`5FQA<W1N[6L@4V%T96QI='4`4V%U9'-KX2!!<N%B:64`56QOOFET`%5L
M;[YI="`E<P!5;&^^:70@)R5S)P!-;[YN;W-T:2!5;&^^96[M`%5L;[YI="!V
M>79O^&5N_2!K;VYF:6=U<F'H;NT@4$A0('-K<FEP="!D;R!D;^AA<V[I:&\@
M861R97/A^&4@;F$@<V5R=F5R=2X`4&]T=G)Z96[M(&\@56QOOF5N[2`E<RX`
M06MT=6%L:7IAZ&[L(&MO;F9I9W5R8>AN[2!S:W)I<'0@8GEL('5L;[YE;B!D
M;SH@)R5S)RX`5NQD80!6>6AL961A=`!396%R8V@@16YG:6YE<P!0<F]B[6CA
M('9Y:&QE9.%VX6[M(&%P;&EK86/M($AO<F1E('8@)7,`4')O8NUHX2!V>6AL
M963A=N%N[2!B:6[A<F[M8V@@<V]U8F]R=2!P<F\@9V5T=&5X="XN+@!6>6)R
M870@4V]U8F]R>0!6>6)R870@9&%T=6T`5GEB<F%T('-K=7!I;G4L(&MT97+A
M(&)U9&4@</AI9.%N80!6>6)R870@;F]VZ6AO('9L87-T;NUK80!6>6)R870@
M<V5R=F5R`%9Y8G)A="!UOFEV871E;&4L(&MT97+](&)U9&4@</AI9.%N`%9Y
M8G)A="!VN65C:&YY(.CA<W1I(&1A='5M=2X`5GEB<F%T(&]B:F5K=`!6>6)E
M<G1E('!O=/AE8F[I('IN86MY+"!Z(&[MOF4@=79E9&5N_6-H(&)O>/DN(%!A
M:R!J92!M^;YE=&4@:V]P[7)O=F%T(&$@=FQOOFET(',@=&5X=&]VZ2!O8FQA
M<W1I+@!6>6)E<G1E(&]D9.QL;W9A8^T@>FYA:R!P<F\@9&%T=6TZ`%9Y8F5R
M=&4@9F]R;>%T(&1A='5M=3H`5GEB97)T92!I9&5N=&ET=2P@:W1E<F]U('-I
M('#X96IE=&4@>FWL;FET.@!6>6)E<G1E(&]D9.QL;W9A8^T@>FYA:R!P<F\@
MZ&%S.@!6>6)E<G1E(&9O<FWA="#H87-U.@!6>6)E<G1E(&1V["!O9'!O=NUD
M86KM8^T@<&]L92X`5GEB97)T92!B87)E=F[](&UO=&EV+@!6>6)E<G1E(%;A
M;6D@<')E9F5R;W9A;OT@:F%Z>6LZ`%!O<VQA="!.96IA:W1UX6QN[&JY[2!)
M;F9O<FUA8V4`4&]S;&%T(%IP<N%V=2!O(%!R;V)LZ6UU`%!O<VQA="!335,`
M4V5N96=A;`!396YS;W(Z`%KA^.T`4W)B<VMO(&$@R&5R;N$@2&]R80!3Z7)I
M;W;I(,CM<VQO`$E$('-E:V-E('IA;FEK;&\N`$YA<W1A=FET`$YA<W1A=FET
M(&UOOFYO<W1I('1A:RP@OF4@5N%M(&)U9&4@9&]V;VQE;F\@<F5S971O=F%T
M(&AE<VQO+"!P;VMU9"!H;R!Z87!O;65N971E+@!.87-T879I="!V>F3A;&5N
MZ2!S97)V<GD@=&%K+""^92!B=61O=2!P^.US='5P;ND@>B!P;W)TX6QU+@!.
M87-T879T92!6X6UI('!R969E<F]V86[](&IA>GEK+"#H87-O=ND@<.%S;6\@
M82!T>7`@9&%T=6UU+@!.87-T879I="!P;^CA=&7H;NT@87!L:6MA8VDL(&)A
M<F5V;OT@;6]T:78L(&]B;F]V=2!S='+A;F5K+"!A(&1A;+GM('IO8G)A>F]V
M86/M(&UOOFYO<W1I+@!!:W1U86QI>F'H;NP@:V]N9FEG=7)AZ&[M('-K<FEP
M='D@:G-O=2!D;W-T=7!NZ0!.[&MT97+I(&WM<W1A(&QZ92!N87-T879I="!S
M('3M;71O('!A<F%M96YT<F5M.B``4V5Y8VAE;&QE<P!.86MU<&]VX6[M`$MR
MX71KZ2!3:')N=73M`$WL;&D@8GD@8OUT('#X[7-T=7!O=ND@:VSMZ&4@9&5F
M:6YO=N%N>2!P<F\@=NQTN6EN=2!L:6YE:S\`56OA>F%T`%IO8G)A>FET(&]D
M;&FY;F]S=&D@;65Z:2!S;W7H87-N;W4@82!P^&5D8VAO>NT@:V]N9FEG=7)A
M8^TN`%IO8G)A>FET(.AA<R!P;W-L961N[6AO('#X:6AL8;EE;NT@9&\@<WES
M=.EM=3\`6F]B<F%Z:70@;6^^;F]S="!U9'*^96[M(&]R:6=I;N%L=0!:;V)R
M87II="!S8NQR8>@`6F]B<F%Z:70@;W!E<F'H;NT@;&FY='4@<')O(&UE;G4@
M<')O('1A8G5L:WD_`%IO8G)A>FET("5S($UE;G4@;F%L979O/P!:;V)R87II
M="!$:6%L;V<@<')O(%9L87-T;F]S=&D@0G5N[&L@=B!486)U;&OA8V@`6F]B
M<F%Z:70@9&EA;&]G(%1A8G5L:V]V_6-H(%9L87-T;F]S=.T`6F]B<F%Z:70@
M9&EA;&]G(%9L87-T;F]S=.T@V.%D:_D@5&%B=6QE:P!:;V)R87II="!D:6%L
M;V<@=FQA<W1N;W-T[2!O8G+A>FOY`%IO8G)A>FET('#X96YO<P!0^&5HX?)K
M>0!"<GIKZ2!0^&5HX?)K>0!0;WID;NT@4/AE:.'R:WD`6FUE;KEI=`!:;65N
MN6ET(&YE8F\@<&]S=6YO=70@9&\@<V]U<V5D;NUH;R!B;&]K=2CY*2P@>B!C
M97-T>2!P<G9N[6UU`%-I97)R82!,96]N90!296=I<W1R;W9A="!S90!296=I
M<W1R;W9A="!S92!P;VMU9"!J<W1E('-E(&IEN73L(&YE<F5G:7-T<F]V86QI
M`$]Z;F'H96[M`$%L9V]R:71M=7,@<')O($]Z;F'H96[M`%-I;F=A<'5R`%9E
M;&EK;W-T`%9Y;F5C:&%T(-ID<KYB=0!6>6YE8VCA;F\N+BX`4VQO=F5N<VMO
M`%-L;W9I;G-K;P!3;NR^96[M`%-N[&AO=ND@4/AE:.'R:WD`4V[L:&]VZ2!0
M^&5HX?)K>0!0;WID;NT@4V[L:&]VZ2!0^&5HX?)K>0!3;NQH;W;]('!O:W)Y
M=CH`5F]D;NT@96MV:79A;&5N="!P<F\@<V[M:#H@`*EA;&%M;W5N;W9Y($]S
M=')O=GD`4V]MX6QS:V\`4.US;NP@82!"X7-N[`!3;>QR(%3X[63L;NT`6F1R
M;VIO=N$@861R97-A`$IIOF[M($%F<FEK80!*:6AO979R;W!S:_T@*$E33RTX
M.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)
M<VQA;F1S`$IIOF[M(%!O;&]K;W5L90!0<F]S=&]R(&UE>FD@<V]U<V5D;NUM
M82!B=?)K86UA`%!R;W-T;W(@;65Z:2!O8G-A:&5M(&$@:')A;FEC96UI('8@
M8G7R8V4`365Z97)N[6L`365Z97)Y`$]D<W1U<'D@82!-97IE<GD`J7!A;NQL
M<VMO`%-P86T`5G-T=7`@<')O(%IV;.&Y=&[M(%IN86MY`%)O>F3L;&ET(&)U
M\FMU`%)O>F3L;&ET('-L;W5P96,`4F]Z9.QL:70@V.%D96L`4W!O<G0`4W+]
M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!:8>CA=&5K`%)O:R!:8>CA=&MU
M`%-TX70@Z&D@4')O=FEN8VEE`%-T878`4W1A=B!P<F\@;&]C86QE("5S+BXN
M`$9O<FWA="!U;&^^96[M`%5L:6-E`%#X9;EK<G1N=73]`%-E>FYA;2#X973L
M>F-E`$]D<W1R86YI="!D;VWI;F]VZ2!J;>EN;R!O9"!A9')E<WD`4W1Y;"!;
M0U-370!.90!0;V1A9')E<^'X("<E<R<@;F5B>6P@;F%L97IE;BX`4/AE9&WL
M=`!);F9O<FUA8V4@;R!69?AE:F[I;2!+;.WH:2!/<V]B>0!0;V1A=`!">6QA
M('!O9.%N82"^X61O<W0@;R!P^&EDX6[M("<E<R<@9&\@<WES=.EM=2X@0G5D
M971E('-E(&UO8R!P^&EH;.%S:70@9&\@<WES=.EM=2!A>B!B=61E(%9AN64@
MON%D;W-T(&ML861N["!V>?CM>F5N82X`1&]L;NT@26YD97@`VG-P[+EN[``G
M)7,G(&)Y;"AA*2#Z<W#LN6[L('#X:63A;BAA*2!D;R!S>7-TZ6UU+@!$871A
M('!R;R!UOFEV871E;&4@)7,@^G-P[+EN["!O9'-T<F%N[&YA('IE('-Y<W3I
M;74N`-IS<.RY;NP@;V1S=')A;NQN82`G)7,G+@`G)7,G(/IS<.RY;NP@;V1S
M=')A;NQN*&$I('IE('-Y<W3I;74N`$MO;F9I9W5R86-E(&)Y;&$@^G-P[+EN
M["!Z;>QN[&YA+B!/8FYO=G1E('-T<N%N:W4N`-IS<.RY;ND@=6QOOF5N[2!Z
MX6QOOF[M(&MO;F9I9W5R86-E("5S+@#:<W#LN6[I('5L;[YE;NT@>N%L;[YN
M[2!K;VYF:6=U<F%C92X`VG-P[+ENX2!A:W1U86QI>F%C92!P<F\@)R5S)P`E
M<R!B>6QO(/IS<.RY;NP@>F%P<^%N;P!3=63A;@!3:')N=73M`%-V[73A;NT`
M6N%P860@4VQU;F-E`%-L=6YEZ&YO`%;]8VAO9"!3;'5N8V4`5OUC:&]D+UKA
M<&%D(%-L=6YC90!6_6-H;V0@4VQU;F-E.@!:X7!A9"!3;'5N8V4`6N%P860@
M4VQU;F-E.B``2&]R;NT@26YD97@`4&]D<&]R80!3=7)I;F%M90!0^.UJ;65N
M[0!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;'-K;P"I=NED<VMO`*EV
M_6-A<G-K;P!3>6YT87AO=N$@8VAY8F$@=B!H;&5D86[I;2!T97AT=0!3_7)I
M90!";W7X:V$`0F]U^&MY`%135B!S;W5B;W(`5&%B=6QK80!6;&%S=&YO<W1I
M(%1A8G5L:WD`5FQA<W1N;W-T:2!T86)U;&MY`%1A:7=A;@!486EW86XL(%!R
M;W9I;F-I92#([6YY`%1A9+YI:VES=.%N`%1A;GKA;FEE+"!3<&]J96[A(%)E
M<'5B;&EK80!#[6PZ`-IK;VQY`%1E;&5F;VYN[2#([7-L;P!497!L;W1A('IA
M('!O<VQE9&[M(&AO9&EN=3H@`%1E<&QO=&$`5&5P;&]T83H@`%9Z;W(@)R5S
M)R!N96)Y;"!N86QE>F5N+@!6>F]R('!R;R!!9&UI;FES=')A8VD`4')O>F%T
M[6UN["!38VAVX6QE;N$@ON%D;W-T`%!R;WIA=.UM;NP@4V-H=N%L96YO`%1E
M>'0`4&]U>F4@5&5X=`!:87)O=F[A;NT@5&5X='4`5G)C:"!497AT=0#(=`!4
M:&%J<VMY("A425,M-C(P*0!4:&%J<VMO`$3L:W5J96UE('IA('!O=;[M=N%N
M[2!S>7-TZ6UU+@!3;W5B;W(@)7,@<R!NX7!O=NQD;W4@<')O("5S(&KLN73L
M(&YE97AI<W1U:F4N(%IA:VSA9.%M('1E;G1O('-O=6)O<BX@`%#X[7!O;F$@
M<')O($944"!N96[M(&1O<W1U<&[A+@!);G1E9W)AZ&[M(&%L9V]R:71M>2!V
M($AO<F1E+TMO;&%B(&YE<&]T<&]R=6KM("(E<R(`3F7Z<W#LN6[I(&YAZ'1E
M;NT@=/CM9'D@36%I;G1E;F%N8V4Z.@!"=6QO('5Z87;X96YO(&]K;F\@<R!M
M;[YN;W-T;7DN(%5K;V[H96YO+@!!9&UI;FES='+M=&]R('!O=/AE8G5J92!N
M86MO;F9I9W5R;W9A="!T<G9A;.D@4'+A=F$@=B!S>7-TZ6UU+"!P;VMU9"!S
M:2!P^&5J971E('!O=;[M="!0<N%V82X`4&]U>F4@<W!O9&[M('-T<F%N80!$
M871A('8@:V%L96YDX?AI(&IS;W4@;F5P;&%T;N$`3F5B>6QO('5V961E;F\@
M240@<')O(&MO;G1A:W0L(&YE8GEL;R!N86QE>F5N;R!V(&1A=&%BX7II(.AI
M(&)Y;&\@^G!L;NQV>6YE8VCA;F\N`$MO;G1A:W0@8GEL(/IS<.RY;NP@</AI
M9.%N(&1O(%9AN6EC:"!+;VYT86MT^2X`2R!O=NSX96[M(&]Z;F'H96[I('IP
M<N%V>2!J92!Z87!O=/AE8NT@;V1D[&QE;OT@8FQO:R!S(%!'4"!O>FYAZ&5N
M[6TN`$YE8GEL;R!U=F5D96YO($E$(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2P@
M;F5B>6QO(&YA;&5Z96YO('8@9&%T86+A>FD@Z&D@8GEL;R#Z<&QN["!V>6YE
M8VCA;F\N`$YE8GEL('5V961E;B!D:7-T<FEB=>AN[2!S97IN86TN`$OS9&]V
M86/M(&UOOFYO<W1I(&QZ92!V>76^[70@<&]U>F4@<R!B97IP9>AN_6T@<W!O
M:F5N[6T@<R!W96)E;2`H:'1T<',I+@!59.%L;W-T(&)Y;&$@</AI9.%N82!N
M82!6X;D@:V%L96YDX?@N`%-O=6)O<B`E<R!B>2!M[&P@;V)S86AO=F%T(&YA
M<W1A=F5N[2`E<RX`4V]U8F]R("5S(&)Y(&WL;"!O8G-A:&]V870@;NQK=&5R
MZ2!Z(&YA<W1A=F5N[2`E<RX`4V]U8F]R(&YE;'IE(&MO<.UR;W9A="!SX6T@
M9&\@<V5B92X`4V]U8F]R(&YE;V)S86AU:F4@ON%D;ND@9&%T82X`3N%S;&5D
M=6KM(&AL879IZ&MY('!R;R!M97-S86=E+W)F8S@R,B!Z<'+A=G4`2F4@>F[A
M;>DL(+YE(&WS9"!P^&5S(&-E;&]U(&]B<F%Z;W9K=2!V($EN=&5R;F5T($5X
M<&QO<F5R=2!P^7-O8NT@<')O8FSI;7DL(&IE;&EK;[X@<V4@=B!P<F]G<F%M
M=2!V>7-K>71U:F4@8VAY8F$L(&MT97+I('-E(&YE;'IE('9Y:&YO=70N($IA
M:V\@;N%S;&5D96L@;?F^92!B_70@;N%H;V1NZ2!Z:')O=6-E;NT@=&]H;W1O
M('!R;V=R86UU+"!N96)O(&-H>6)E:NUC[2!F=6YK8V4@961I=&]R=2#H:2!N
M97-P<N%V;ND@>F]B<F%Z;W;A;NTN(%!O:W5D(&IE(%;AN2!S>7-T96WI;2!7
M:6YO9'=S(#EX+"!J92!V96QM:2!P<F%V9.QP;V1O8F[I+""^92!S92!O8FIE
M=NT@8VAY8F]VZ2!H;.&Y96[M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G
M(&$@8G5D971E(&UU<V5T(')E<W1A<G1O=F%T('!OZ.UT8>@N7&Y<;D)Y;&D@
M:G-T92!V87)O=N%N:2X@4')O<^UM('-T:7-K;NQT92!/2R!P;VMU9"!S:2!P
M^&5J971E('!O:W)AZ&]V870@=FT];V1U('#X97,@8V5L;W4@;V)R87IO=FMU
M+@!3;W5B;W(@<R!NX7!O=NQD;W4@)7,@;F5Z8>CM;N$@<R`\/WAM;`!)9&5N
M=&ET82`B)7,B(&)Y;&$@<VUA>N%N82X`4&]U>F4@;F$@;&5VZ2!S=')A;NP`
M5/CM9&$@0W)Y<'1?<&=P.CH@;75S[2!O8F1ROF5T(&WM<W1O('5L;[YE;NT@
M8FENX7)N[6AO('-O=6)O<G4@1VYU4$<N`%IP<N%V82!Z87-L86[A('8@)7,@
M:R`E<R!S('#X961M['1E;2`B)7,B(&)Y;&$@>F]B<F%Z96YA+@I4;W1O(&YE
M>F%R=>AU:F4L(+YE('IP<N%V82!B>6QA('#X9>AT96YA(&YE8F\@OF4@:NT@
M861R97/A="AK82D@<F]Z=6WL;"AA*2X`3N%Z978L(&MT97+](&)U9&4@<&]U
MOFET('#X:2!L:6YK;W;A;NT@9&\@<W1RX6YK>2!P<F\@='9O<F)U(&5M86EL
M^0!4^.UD82!(;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P
M96YS<VPN`$YE;'IE('5L;[YI="!N87-T879E;NT@(B5S(B!J96QI:V^^(&IE
M:&\@=F5L:6MO<W0@</AE<^%H;&$@<&]V;VQE;OT@;&EM:70N`$YE8GEL82!N
M86QE>F5N82!A<&QI:V%C92!P<F\@Z'1E;NT@=&]H;W1O('1Y<'4@9&%T("@E
M<RDN`%!O=7IE(&YA('!R87;I(&$@;&5VZ2!S=')A;NP`4&]U>F4@;F$@<')A
M=ND@<W1R86[L`%-E<G9E<B`B)7,B(&)Y;"!V>6UA>N%N+@!397)V97(@(B5S
M(B!B>6P@=6QOOF5N+@!">6QA(&]D<W1R86[L;F$@ON%D;W-T(&\@</AI:&SA
MN65N[2!P<F\@)7,N`%!OOF%D;W9A;OT@^.%D96L@;F5E>&ES='5J92X`VFMO
M;"!B>6P@</AI9.%N(&1O(%9AN65H;R!S97IN86UU(/IK;VSY+@!0;W5Z92!N
M86AO^&4@82!D;VQE`%!O=7IE(&YA:&_X90!:=')A=&EL>2!S92!P;W-K>71N
M=73I(&1A=&$@>B!P^&5D8VAO>NUH;R!K<F]K=2X`3F5L>F4@=6QOOFET('!O
M<VMY=&YU=.D@9&%T82X`5;YI=F%T96QO=F$@:6YF;W)M86-E(&\@9G)E92]B
M=7-Y(&)Y;&$@^G-P[+EN["!U;&^^96YA+@!";&]C:R!S('=E871H97(N8V]M
M(&YE;NT@9&]S='5P;OTN`$YE8GEL(&YA;&5Z96X@861R97/A^"!S('3I;6%T
M>2`G)7,G+@"NX61NZ2!Z(&UOOFYO<W3M(&YE:G-O=2!D;W-T=7!NZ2X`3F5B
M>6QI(&YA;&5Z96YY(+[A9&[I(.CA<W1I+"!K=&5RZ2!B>2!B>6QO(&UOOFYO
M('IO8G)A>FET('8@^.%D:W4N`%#X[6QIN2!M;F]H;R!Z;F%K^2!V('!O;&DN
M(%IA9&%L:2!J<W1E("5S('IN86OY.R!M=7/M=&4@>F%D870@;>EN["!N9;X@
M)7,@>FYA:_DN`%-O=6)O<B!S(&[A<&]V[&1O=2!P<F\@)7,@;F5X:7-T=6IE
M+@!.87-T86QA(&-H>6)A('#X:2!P^&EDX7;A;NT@)R5S)R!D;R!S>7-TZ6UU
M+B`E<RX`3F%S=&%L82!C:'EB82!P^&D@</AI9.%VX6[M("<E<R<@9&\@<WES
M=.EM=3H@)7,`3F%S=&%L82!C:'EB82!P^&D@;V1S=')A\F]VX6[M('6^:79A
M=&5L<VO]8V@@9&%T("<E<R<@>F4@<WES=.EM=3H@`$YA<W1A;&$@8VAY8F$@
M</AI(&]D<W1R8?)O=N%N[2`G)7,G('IE('-Y<W3I;74Z(`!.87-T86QA(&-H
M>6)A('#X:2!A:W1U86QI>F%C:2`G)7,G.B`E<P!.87-T86QA(&-H>6)A('#X
M:2!P;W-K>71O=N%N[2!S;W5B;W)U.B`E<R!N96)Y;"!P;W-K>71N=70N`$YA
M<W1A;"!P<F]B;&5M('#X:2!P;W-K>71O=N%N[2!S;W5B;W)U+B`E<R!N96WY
MOF4@8OUT(';L=+GM(&YEOB!M87AI;>%L;NT@<&]V;VQE;N$@=F5L:6MO<W0@
M*"5D(&)Y=/DI+@!.87-T86QA(&-H>6)A('#X:2!P;W-K>71O=N%N[2!S;W5B
M;W)U.B!P;W5Z92#HX7-T('-O=6)O<G4@)7,@8GEL82!P;W-K>71N=71A+@!$
M;[EL;R!K(&-H>6+L('#X:2!Z;V)R87IO=N%N[2!TZ71O(.CA<W1I('IP<N%V
M>0!.87-T86QA(&-H>6)A('#X:2!I;7!O<G1O=N%N[2!K;VYT86MT=2X`3F%S
M=&%L82!C:'EB82!P^&D@:6UP;W)T;W;A;NT@=63A;&]S=&DZ("5S+@!0^&D@
M:6UP;W)T;W;A;NT@:4-A;&5N9&%R(&1A="!D;[EL;R!K(&-H>6+L+@!.87-T
M86QA(&-H>6)A('#X:2!I;7!O<G1O=N%N[2#Z:V]L=3H@)7,N`$YA<W1A;&$@
M8VAY8F$@</AI(&EM<&]R=&]VX6[M('6^:79A=&5L;W9Y(&EN9F]R;6%C92!O
M(&9R964O8G5S>3H@)7,N`$-H>6)A('8@:V]N9FEG=7)AZ&[M;2!F;W)M=6SA
M^&DN(%KX96IM["!J<W1E('9Y;F5C:&%L:2!P;[YA9&]V86[I('!O;&4N`$YA
M<W1A;&$@8VAY8F$@</AI(&]T=NURX6[M('-O=6)O<G4@)7,N(%!R;R!D971A
M:6QN[2!P;W!I<R!C:'EB;W;I:&\@:&SAN65N[2!P<F]G<F%M=2!K;VYT<F]L
M=6KM8^UH;R!X;6PL('-P=;MT92!T<F%N<VQA=&EO;BYP:'`@<R!P^&5P[6YA
MZ&5M("UD+@!.87-T86QA(&-H>6)A('#X:2!P<F]VX63L;NT@>F%D86[I(&]P
M97)A8V4@=B!A9')E<^'X:2X@4')O<^UM('IK=7-T92!T;R!P;WID[&II+@!.
M87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!K;VYT86MT=2X@4')O<^UM
M('IK=7-T92!T;R!P;WID[&II+@!.87-T86QA(&-H>6)A('#X:2!A:W1U86QI
M>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA;74N(%!R;W/M;2!Z:W5S=&4@=&\@
M<&]Z9.QJ:2X`5&5N=&\@24U!4"!S97)V97(@;F5P;V1P;W)U:F4@<V3M;&5N
M[2!S;&^^96LN`%1E;G1O(/IK;VX@;F5N[2!M;[YN_2X`5&5N=&\@^FMO;B!N
M96[M(&IEN73L(&EM<&QE;65N=&]VX6XN+BX`5&]T;R!N979Y<&%DX2!J86MO
M('!L871N_2!R87(@87)C:.UV+@!4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[]
M('II<"!S;W5B;W(N`%1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T;ND@Z.US;&\@
M:V%R='DN`%1E;G1O(&]V;&%D8>@@=6UOOO)U:F4@>F%S[6SA;NT@>G!RX78@
M<&]M;V/M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@8G+A
M;GD@>F%P;W6^:73M($A45%`@05!)`%1E;G1O(&]V;&%D8>@@=6UOOO)U:F4@
M>F%S[6SA;NT@>G!RX78@<&]M;V/M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E
M;6%I;"YC;VTI(&)RX6YY('IA<&]UOFET[2!(5%10($%020!496YT;R!O=FQA
M9&'H('5M;[[R=6IE('IA<^ULX6[M('IP<N%V('!O;6]C[2!33510(&1O(%9O
M9&%F;VYE($ET86QY(&)RX6YY('!O=7IE('!R;R#H[7-L82!P;W-K>71N=73I
M(%9O9&%F;VYE;2X@375S[71E(&WM="!E;6%I;&]V_2#ZZ&5T('4@5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&]T;R!P;VQE(&IE(&YU
M=&[I('9Y<&QN:70N`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!C
M96SA(.CM<VQA+@!4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5L
MX2#H[7-L82!A(&1V;VIT9>AK=2X`5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T
M('!O=7IE(&]S;6GH:V]VZ2#H[7-L82X`5&]T;R!P;VQE(&UU<^T@8OUT('-E
M>FYA;2!C96S]8V@@Z.US96P@;V1D[&QE;OUC:"#HX7)K;W4@;F5B;R!M97IE
M<F]U`%1O=&\@<&]L92!M=7/M(&+]="!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L
M92!M=7/M(&+]="!B87)E=F[](&OS9"!V92!T=F%R=2"Y97-T;N%C:V]VZ6T@
M4D="+"!N87#X+B`G(S$R,S1A9B<N`%1E;G1O(&9O<FUU;.'X(&IIOB!B>6P@
M>G!R86-O=N%N+@!4;W1O(&IE("5S+@!4;W1O(&IE(&]B:F5K="!+;VQA8B!'
M<F]U<'=A<G4N($L@=GIH;.ED;G5T[2!T;VAO=&\@;V)J96MT=2!J92!Z87!O
M=/AE8NT@;>UT(&5M86EL;W;I:&\@:VQI96YT82P@:W1E<OT@<F]Z=6WM(&9O
M<FWA='4@2V]L86(@1W)O=7!W87)U+B!0<F\@<V5Z;F%M('1A:V]V_6-H(&ML
M:65N=/D@<')O<^UM('9Z:&SI9&[L=&4@)7,`5&%T;R!Z<'+A=F$@8GEL82!N
M87!SX6YA('8@:FENZ2!Z;F%K;W;M('-A9.P@*"5S*2!N9;X@5F&Y[2X@`%1O
M=&\@Z.US;&\@;75S[2!B_70@;F5J;>EN["!J961N82X`5&5N=&\@<VMR:7!T
M(&UU<^T@8OUT('-P=;ET[&X@>B!P^.UK87IO=NEH;R#XX61K=2X`4V5R=F5R
M(&YE;?F^92!R;WIB86QI="!Z:7`@82!G>FEP('-O=6)O<GDN`%1E;G1O('-Y
M<W3I;2!J92!D96%K=&EV;W9A;OTN`%1A=&\@:&]D;F]T82!M=7/M(&+]="#H
M[7-L;RX`5&]T;R!O:VYO(&UUOF4@8OUT('9O;.%N;R!P;W5Z92!Z(&]K;F$@
M36^^;F]S=.T`2/AM[&[M`%1I8VME=',`R&%S`%-L961O=N%N[2#(87-U`$9O
M<FWA="#H87-U`%;]8NQR(.AA<W4`5&EM;W(M3&5S=&4`5&ET=6P`5&ET=6P@
M*'1I<"D`2V]M=0!0;VMU9"!S:2!P^&5J971E('9Y8G)A="!V[6-E('!O;&^^
M96LL('IMX>AK;NQT92!K;.%V97-U($-O;G1R;VP@*%!#*2!N96)O($-O;6UA
M;F0@*$UA8RD@82!K;&EK;NQT92!N82!P;VQOOFMU+@!$;F5S`%#X97!N;W5T
M(&YA($A434P@6F1R;VH`5&]G;P!4;VME;&%U`%KM=')A`%1O;F=A`%9R8V@`
M2&]R;NT@<N%M("A?=&]P*0!0^&5L;[YE;F\`4/AE:VQA9'D`5')I;FED860@
M82!4;V)A9V\`4W!RX79N["!N96)O(*EP871N[`#:=`!4=6YI<VMO`%1U<F5C
M:V\`5'5R96-K>2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=.%N`%1U<FMS(&$@
M0V%I8V]S($]S=')O=GD`5'5V86QU`$YA<&FY=&4@5F&Y:2!V;VQB=3H@`%4N
M5BX@:6YD97@Z(`!54DP`55),('!R;R!Z<'+A=G4@;R!S=&%V('IA<VSA;NEH
M;R!S:W)I<'1U`%523#H`56=A;F1A`%5K<F%J:6YA`%9&4R!A9')E<^'X(&IE
M(&YE</CM<W1U<&[]+@!.96QZ92!P^&ED870@97AT<F$@=;YI=F%T96QS:^D@
M^F1A:F4@</AI(')E9VES=')A8VDN`$YE;'IE('IM[&YI="!P<N%V82!P<F\@
M5D93('-O=6)O<B`B)7,B+BX`3F5L>F4@>FWL;FET('!RX79A('!R;R!61E,@
M<V]U8F]R("5S+R5S+@!.96QZ92!Z;>QN:70@;F$@)7,N`$YE;'IE('-E('#X
M:7!O:FET(&YA(%-13"!S97)V97(N`$YE;'IE('-E('#X:7!O:FET('!O;6]C
M[2!34TPN`$YE;'IE(&MO<.%R;W9A="!61E,@<V]U8F]R+@!.96QZ92!V>71V
M;_AI="!61E,@861R97/A^"`B)7,B+@!.96QZ92!V>71V;_AI="!61E,@861R
M97/A^"X`3F5L>F4@=GET=F_X:70@5D93('-O=6)O<BX`3F5L>F4@=GET=F_X
M:70@<'+A>F1N_2!61E,@<V]U8F]R+@!.96QZ92!R;WIB86QI="!D871A+@!.
M96QZ92!V>6UA>F%T("(E<R(L(&IE;&EK;[X@861R97/A^"!N96[M('!RX7ID
M;OTN`$YE;'IE('9Y;6%Z870@)7,L(&IE;&EK;[X@861R97/A^"!N96[M('!R
MX7ID;OTN`$YE;'IE('9Y;6%Z870@)R5S)SH@)7,N`$YE;'IE(')E:W5R>FEV
M["!O9'-T<F%N:70@5D93(&%D<F5SX?@N`$YE;'IE('9Y;6%Z870@5D93(&%D
M<F5SX?@N`$YE;'IE('9Y;6%Z870@5D93(&%D<F5SX?@Z("5S+@!.96QZ92!V
M>6UA>F%T(%9&4R!S;W5B;W(@(B5S(BX`3F5L>F4@=GEM87IA="!61E,@<V]U
M8F]R+@!.96QZ92!R96MU<G-I=F[L(&]D<W1R86YI="!61E,Z("5S+@!.96QZ
M92!Z:FES=&ET(&%K='7A;&[M(&%D<F5SX?@N`$YE;'IE('IJ:7-T:2!D971I
M;'D@;R!C97)T:69I:^%T=2X`1&5F:6YI8V4@)7,@;F5N[2!D;W-T=7!NX2X`
M3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(N`$YE;'IE('#X97-U;F]U="!6
M1E,@<V]U8F]R("(E<R(N`%9&4R!S;W5B;W(@;F5L>F4@;W1E=OCM="!K('KA
M<&ES=2X`3F5L>F4@;W1E=OCM="!61E,@<V]U8F]R+@!.96QZ92!O=&5V^.UT
M(&%R8VAI=F]V86[]('-O=6)O<BX`3F5L>F4@Z.US="!Z('9F<W)O;W0@861R
M97/A^&4N`$YE;'IE('#X96IM96YO=F%T("5S(&YA("5S.B!C[6QO=N$@<V-H
M<N%N:V$@:FF^(&5X:7-T=6IE`%9&4R!A9')E<^'X(&YE;'IE('#X96IM96YO
M=F%T+@!61E,@861R97/A^"!N96QZ92!P^&5J;65N;W9A=#H@)7,N`$YE;'IE
M('#X96IM96YO=F%T(%9&4R!S;W5B;W(@(B5S(BX`3F5L>F4@</AE:FUE;F]V
M870@5D93('-O=6)O<B`E<R\E<RX`3F5L>F4@</AE:FUE;F]V870@5D93('-O
M=6)O<BX`3F5L>F4@<')O=NES="`G;6MI<V]F<R<N`%1E;G1O(%=O<F0@9&]K
M=6UE;G0@;F5L>F4@</AE;&^^:70`3F5L>F4@>F%P<V%T(&1O(%9&4R!S;W5B
M;W)U("(E<R(N`$YE;'IE('IA<'-A="!D871A(&1O(%9&4R!S;W5B;W)U("AS
M96QH86QO(&-O<'DH*2DN`$YE;'IE('IA<'-A="!D871A(&1O(%9&4R!S;W5B
M;W)U`%!O9'1R:&YU=.D`4W1O<FYO(%IM[&YY`%-T;W)N;W9A="!P;W-L96[M
M(/IK;VX`3F5OZ&5KX79A;N$@;V1P;W;L[R!Z92!S97)V97)U('#X:7!O:F5N
MZ6T@;F$Z(`!.96_H96OA=F%NX2!O9'!O=NSO('IE('-E<G9E<G4Z(`!.979Y
M<&QN[&YO`$YE;W9LX63A;OT@:V]M<&]N96YT('1Y<'4Z("5S`%5N:6-O9&4@
M*%541BTX*0!3<&]J96[I($%R86)S:^D@16UI<N%T>0!696QKX2!"<FETX6YI
M90!3<&]J96[I(%-TX71Y($%M97)I8VOI`%-P;VIE;ND@4W3A='D@365NN6EN
M;W;]8V@@3W-T<F]V^0!*961N;W1K>0!.97INX6WM`$YE>F[A;>D@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2X`3F5Z;N%MZ2!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+@!.97INX6WM('#X[6MA>CH@)7,`3F5Z;N%MZ2!UOFEV
M871E;'-KZ2!J;>EN;R!N96)O(&AE<VQO+@!/9'!O:FET('-O=>AA<V[](&5L
M96UE;G0`0F5Z(&IMZ6YA`$YE<')I=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6]H
M;W4@=GEUONUV870@9G5N:V-A(%9Y:FUO=70O2V]P[7)O=F%T+U9L;[X@>B!B
M97IP9>AN;W-T;NUC:"!D^79O9/DN($ML:6MN['1E(&YA($]+(&%B>6IS=&4@
M=GIH;.ED;&D@=&5C:&YI8VMO=2!Z<'+A=G4@>B!M;WII;&QA+F]R9RP@:W1E
M<N$@=GES=NQT;'5J92!J86L@;F%S=&%V:70@<VMR:7!T(&%B>2!M[&P@</CM
M<W1U<"!K92!S8VARX6YC92X`3F5N87-T879E;N$@8F%R=F$`3F5P;V1P;W)O
M=F%NX2!0^.UP;VYA`$YE</AE;&^^96[I`$%K='5A;&EZ;W9A=`!!:W1U86QI
M>F]V870@)7,`06MT=6%L:7IO=F%T('-T878@;V1P;W;M9&%J[6/M:&\`06MT
M=6%L:7IO=F%T('6^:79A=&5L90!!:W1U86QI>F]VX6YY("<E<R<N`%!R;V+M
M:.$@86MT=6%L:7IA8V4@<V]U8F]R=2!S(&[A<&]V[&1O=2`E<R!P<F\@)7,N
M`%-K<FEP="!P<F\@=7!G<F%D92!B>6P@=GEM87KA;BX`4&]S:WET;G5T[0!6
MN65C:&YY('-O=6)O<GD@<')O(&YA<W1A=F5N[2!B>6QY('5L;[YE;GD@;F$@
M<V5R=F5R=2X`5F5L:^$@=&ES:V%C[2!P[7-M96YA`%9E;&OI(/CM;7-KZ2#H
M[7-L:6-E`%5R=6=V86H`5GEUOFET[3H`4&]UONUT($%K='5A;&[M.B`E<P!0
M;W6^[70@4U-,`%!O=;[M="!P;VMU9"!J;>EN;R]H97-L;R!J<V]U(&II;ND@
M;F6^(&YA($E-4U`@<V5R=F5R=2X`5;YI=F%T96P@)7,@;F5N[2!O<'+A=F[L
M;B!K('!O=;YI=N%N[2`E<RX`061M:6YI<W1R86-E(%6^:79A=&5L^0!5OFEV
M871E;'-KZ2!-;[YN;W-T:0!296=I<W1R86-E(%6^:79A=&5L^0!.82!TZ71O
M('-T<N%N8V4@;F5N[2!M;[YNX2!R96=I<W1R86-E('6^:79A=&5L^2X`5;YI
M=F%T96P@;F5B>6P@;F%L97IE;@!5OFEV871E;"!N96)Y;"!N86QE>F5N+@!5
MOFEV871E;'-KX2!P<N%V82X`5;YI=F%T96QS:^D@2FWI;F\`5;YI=F%T96QS
M:^D@2FWI;F\@)R5S)R!J:;X@97AI<W1U:F4N`%6^:79A=&5L<VOI($IMZ6YO
M.@!5OFEV871E;'-KZ2!*;>EN;SH@`%6^:79A=&5LZ0!397IN86T@5;YI=F%T
M96SY.@!5>F)E:VES=.%N`%9&4R!A9')E<^'X(&YE97AI<W1U:F4N`$1O=F]L
M96[A`$YA;&5Z96[I('!L871NZ2!M[7-T82!Z86AR;G5J[3H@`%!L871N;W-T
M`$AO9&YO=&$@=B!M:6YU=.%C:"X`2&]D;F]T>0!6>6)R86[I(&AO9&YO='D@
M>@!686YU871U`%!R;VWL;F[I`%9E;F5Z=65L80!396QH86QA('9E<FEF:6MA
M8V4@+2!T871O('IP<N%V82!M;VAL82!B_70@>F9A;+EO=N%N82X`5F5R>F4`
M5F5R<VEO;B!#;VYT<F]L`%9E<G1I:^%L;NT@>F%R;W9NX6[M`%9E<G1I:^%L
M;NT@;V1S='5P`%9E<G1I:^%L;NTZ`%9E;&UI(%9Y<V]KX0!6:65T;F%M`%9I
M971N86US:WD@*%9)4T-)22D`6F]B<F%Z:70@)7,`6F]B<F%Z:70@97AT97)N
M[2!W96)S='+A;FMU`%IO8G)A>FET(&IA:V\@)7,`6F]B<F%Z:70@=63A;&]S
M=`!:;V)R87II="#Z:V]L`%!A;FYE;G-KZ2!/<W1R;W9Y+"!"<FET<VOI`%!A
M;FYE;G-KZ2!/<W1R;W9Y+"!5+E,N`%9I9&ET96QN;W-T`%9I9&ET96QN;W-T
M.@!6;V1A9F]N92!)=&%L>2!P^&5S(%--5%``55!/6D]23DE4`%503UI/4D[,
M3LTA(2$@3T135%)!TE1%(%-+4DE05"!25<A.S"!:("5S+@!786QL:7,@86YD
M($9U='5N80!5<&]Z;W)N[&[M`%5P;WIO<F[L;NTZ(`!3=`!0^&5D<&]V[.\@
M4&_H87/M`$1A=&$@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H97(N8V]M`%/M
MNP!796)S='+A;FMA`%3]9&[L`%9I=&5J=&4`5NUT96IT92!V("5S`%;M=&5J
M=&4L("5S`%KA<&%D;NT@*$E33RTX.#4Y+3$I`%KA<&%D;NT@*$E33RTX.#4Y
M+3$U*0!:X7!A9&[M(%-A:&%R80!+=&5R;W4@87!L:6MA8VD@;>$@)7,@>F]B
M<F%Z:70@<&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!*86O](&IE(&]D9.QL
M;W9A8^T@>FYA:S\`2F%K_2!J92!Z;F%K('!R;R!C:71A8VD_`$MT97+I(&;A
M>F4`2W1E<ND@</CM<&]N>2!A:W1I=F]V870@<')O(%)I8V@@5&5X="!E9&ET
M;W(N`*GM^&MA`*GM^&MA('8@0U-3(&IE9&YO=&OA8V@`J>WX:V$@)7,@;65N
M=2!V;&5V;R`H>FWL;F$@<V4@;V)J97;M('#X:2!D86RY[6T@</AI:&SAN65N
M[2!S92DZ`*GM^&MA('1A8G5L:WD`2F5D;F]T:V$@N>WX:WD`J>WX:V$Z`%=I
M:VD`5NUT<@!2>6-H;&]S="!V['1R=2!V('5Z;&5C:`!6[71R.@!6[71R.B``
M36]U9')O<W0`4V5Z;F%M(%#XX6[M`%!RX6-E`%!R86-O=F[M($%D<F5S80!4
M96QE9F]N(&1O(%!RX6-E`$YE;'IE('IA<'-A="X@3?F^971E('!O=;[M="!S
M:W)I<'0@<')O('5P9W)A9&4@;F5B;R!R=>AN["!Z:V]P[7)O=F%T(&[MOF4@
M=79E9&5N_2!K\V0@9&\@)7,N`%!R;V+M:.$@>F%P:7-O=N%N[2!S;W5B;W)U
M(&[A<&]V[&1Y(&1O("5S+@!8+5)E9@!8-3`Y=C,@6N%K;&%D;NT@3VUE>F5N
M[0!8-3`Y=C,@4F]ZN>WX96[I(%!O=;YI=.T@2VSMZ&4`6#4P.78S($%L=&5R
M;F%T:79N[2!*;>EN;R!/<V]B>0!8-3`Y=C,@2VSMZ&]V_2!)9&5N=&EF:6OA
M=&]R($]S;V)Y`%@U,#EV,R!P^.UP;VYY`%)2`%)24E(`66%H;V\A(&UA<&$`
M4F_H;NP`2F5M96X`06YO`$%N;RP@4V]U:&QA<^UM`$IS=&4@=B!415A43U;)
M32!-TT15+B!0;W6^:6IT92!;/#Y=('1L8>CM=&MA(&L@>G#L=&[I;74@</AE
M<&YU=.T@9&\@5UE325=91RX`3F5B>6QI(&IS=&4@<W!RX79N["!O=NSX96YI
M+@!:;F%K("=<)R!N96WYOF4@8OUT('-O=>CA<W3M(%9AN65H;R!J;>EN82X`
M3F5L>F4@;6]D:69I:V]V870@:&5S;&\@<')O('6^:79A=&5L92`E<P!">6QA
M('IA9.%N82!N97!L871NX2!E+6UA:6QO=N$@861R97-A`$YE;6%P;W9A;&D@
M:G-T92"^X61NX2!P;VQE('H@:6UP;W)T;W9A;NEH;R!S;W5B;W)U(&L@;V1P
M;W;M9&%J[6/M;2!P;VSM;2!V("5S+B``0GEL:2!J<W1E(&]D:&SAN65N:2!Z
M92!S>7-TZ6UU+@!6;&^^=&4@Z.US;&\@;6]B:6QN[6AO('1E;&5F;VYU+"!P
M;W6^:6IT92#H[7-L:6,@;F5B;R!P^.UP861N["`G*R<@<')O(&UE>FENX7)O
M9&[M(.AI<VQA+@!-=7/M=&4@>F%DX70@<&QA=&YO=2!H;V1N;W1U+@!-=7/M
M=&4@:V]N9FEG=7)O=F%T(&1A=&%BX7II(&1A="P@<&]K=60@<VD@</AE:F5T
M92!P;W6^[79A="!296=I<W1R86-E+@!-=7/M=&4@:V]N9FEG=7)O=F%T(%9&
M4R!B86-K96YD+@!-=7/M=&4@;F5J9/CM=F4@<&]P<V%T('!R;V)LZ6T@82!P
M86L@:&\@;'IE('!O<VQA="X`375S[71E('IA9.%T(%523"!K92!K=&5RZ6UU
M(&)U9&4@=&%T;R!L:6YK82!S<&]J96YA`%!R;W/M;2!Z861E:G1E(%9AN64@
M<V]UZ&%S;ND@:&5S;&\`4')O<^UM('IA9&5J=&4@5F&Y92!N;W;I(&AE<VQO
M`$UU<^UT92!V>6)R870@<V5R=F5R+"!K=&5R_2!B=61E('-M87KA;BX`375S
M[71E('9Y8G)A="!UOFEV871E;'-KZ2!J;>EN;RP@:W1E<ND@8G5D92!S;6%Z
MX6YO+@!-=7/M=&4@=61A="!UOFEV871E;'-KZ2!J;>EN;RP@:W1E<ND@8G5D
M92!O9'-T<F%N[&YO+@!.975V961L:2!J<W1E('6^:79A=&5L<VOI(&IMZ6YO
M+"!K=&5RZ2!B=61E('#X:63A;F\N`$YE=79E9&QI(&IS=&4@=;YI=F%T96QS
M:^D@:FWI;F\@<')O(&%K='5A;&EZ86-I+@!-=7/M=&4@=61A="#Z:V]N+"!K
M=&5R_2!B=61E('!R;W9E9&5N+@!-=7/M=&4@>F%D870@:FWI;F\@;F]VZ2!K
M871E9V]R:64N`$UU<^UT92!V97)I9FEK;W9A="!68;EE(&YO=ND@:&5S;&\`
M5F&Y92`E<R!R96QA8V4@8GEL82!U:V]NZ&5N82X@3W#L="!S92!P^&EH;&&Y
M=&4L('!R;W/M;2X`5F&Y92!%;6%I;&]VX2!!9')E<V$`5F&Y92!/9&MO:&\Z
M(&%D<F5S83H`5F&Y92!);F9O<FUA8V4`5B!R96QA8VD@)7,@<V4@>FWL;FEL
M82!68;EE(&EN=&5R;F5T;W;A(&%D<F5S82X@6B!B97IP9>AN;W-T;NUH;R!H
M;&5D:7-K82!S92!M=7/M=&4@;W#L="!P^&EH;.%S:70N`%9AN64@2FWI;F\`
M5N&Y(&]V[/AO=F%C[2!S>7-TZ6T@;F5P;V1P;W)U:F4@</AI9.%VX6[M('6^
M:79A=&5L^2P@;F5B;R!T871O(&UOOFYO<W0@;F5N[2!P^.US='5P;N$@>B!J
M:6[]8V@@9/EV;V3Y+@!6X;D@;W;L^&]V86/M('-Y<W3I;2!N97!O9'!O<G5J
M92!V_7!I<R!UOFEV871E;/DL(&YE8F\@=&%T;R!M;[YN;W-T(&YE;NT@</CM
M<W1U<&[A('H@:FEN_6-H(&3Y=F]D^2X`5B!P<OEB[&AU(')E;&%C92`E<R!S
M92!Z;>QN:6P@<')O:&SMOF7H+B!:(&)E>G!EZ&YO<W1N[6AO(&AL961I<VMA
M('-E(&UU<^UT92!O<.QT('#X:6ALX7-I="X`5N&Y('!R;VAL[;YEZ"!N97!O
M9'!O<G5J92!T=71O(&UOOFYO<W0N`%;AN2!P<F]H;.V^9>@@;F5U;6^^\G5J
M92!T:7-K('3M;71O('IP^7-O8F5M+B!0<F]V961E;NUM('-T:7-K;G5T[2!#
M=')L+T]P=&EO;B`K(%`@<W!U<W3M=&4@=&ES:RX`5F&Y92!S;W7H87-NZ2#H
M87-O=ND@<.%S;6\Z`%9AN64@:6UP;&EC:71N[2!I9&5N=&ET80!68;EE(/IP
M;&[I(&IMZ6YO.@!697)Z92!G971T97AT(&IE('#X[6QIN2!Z87-T87)A;.$@
M82!N97!O9'!O<G5J92!P^&ER;WIE;NP@4$A0+@I.92!VN65C:&YY('IN86MY
M(&)U9&]U(&YA;&5Z96YY+@!68;EE(&YO=ND@:&5S;&\@<')O("5S(&IE.B`E
M<P!68;EE(&YO=ND@:&5S;&\@:F4@</CM;&FY(&1L;W5HZ3L@:&5S;&\@;F5S
M;>T@8OUT(&1E;+GM(&YEOB`E9"!Z;F%K^2$`5F&Y92!N;W;I(&AE<VQO(&IE
M('#X[6QIN2!J961N;V1U8VCI(&L@=6CA9&YU=.TA("!(97-L;R!N96)Y;&\@
M>FWL;NQN;R$`5F&Y92!N;W;I(&AE<VQO(&IE('#X[6QIN2!J961N;V1U8VCI
M(&L@=6CA9&YU=.TN($AE<VQO(&YE8GEL;R!Z;>QN[&YO(0!68;EE(&YO=ND@
M:&5S;&\@;75S[2!B_70@86QE<W!O\B`E9"!Z;F%K^2!D;&]U:.DA`%9AN64@
M;F]VZ2!H97-L;R!M=7/M(&+]="!J:6[I(&YEOB!68;EE('-T87+I(&AE<VQO
M`%9AN64@;F]VZ2!H97-L;R!M=7/M(&]B<V%H;W9A="!A;&5S<&_R("5D('!I
M<VUE;BX`5F&Y92!N;W;I(&AE<VQO(&UU<^T@;V)S86AO=F%T(&%L97-P;_(@
M)60@86QF86YU;65R:6-K_6-H('IN86OY+@!68;EE(&YO=ND@:&5S;&\@;75S
M[2!O8G-A:&]V870@86QE<W!O\B`E9"!R^7IN_6-H('1Y</D@>FYA:_DN(%1Y
M<'D@:G-O=3H@;6%LZ2P@=F5L:^D@<.US;65N82P@Z.US;&EC92!A('+Y>F[I
M('IN86MY+@!68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V870@86QE<W!O
M\B`E9"!M86S]8V@@<.US;65N+@!68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A
M:&]V870@86QE<W!O\B`E9"#H[7-L:6,N`%9AN64@;F]VZ2!H97-L;R!M=7/M
M(&]B<V%H;W9A="!A;&5S<&_R("5D('9E;&O]8V@@<.US;65N+@!68;EE(&YO
M=ND@:&5S;&\@;75S[2!O8G-A:&]V870@86QE<W!O\B`E9"!M97IE<BX`5F&Y
M92!N;W;I(&AE<VQO(&YE<VWM(&]B<V%H;W9A="!M97IE<GDN`%9AN64@;F]V
MZ2!H97-L82!S92!N97-H;V1U:NT`5F&Y92!N87-T879E;NT@8GEL;R!A:W1U
M86QI>F]VX6YO+@!68;EE(&AE<VQO(&)Y;&\@<F5S971O=N%N;RX`5F&Y92!H
M97-L;R!B>6QO(')E<V5T;W;A;F\L('IK;VYT<F]L=6IT92!S:2!E;6%I;"!A
M('#X:6AL8;ET92!S92!S(%9AN>UM(&YO=OUM(&AE<VQE;2X`5N&Y92!V>F3A
M;&5NZ2!S97)V97)Y.@!*=6=O<VSA=FEE`%IA:7(`6F%M8FEE`%II;6)A8G9E
M`%II<'!Y`%M5:W+]="!#:71O=F%N_2!497AT70!;2&SAN65N[2!0<F]B;.EM
M=5T`6UIO8G)A>FET($-I=&]V86[](%1E>'0@+0!;6F]B<F%Z:70@0VET;W9A
M;OT@5&5X="`M("5S(/CA9&OY70!;^.%D96L@)7,@>B`E<UT`7T%D;6EN:7-T
M<F%C90!?0TQ)`%]$871A5')E90!?4VUA>F%T(-CA9&5K`%]3:W5P:6YY`%].
MX7!O=NQD80!?5FQA<W1N;W-T:2!/8G+A>FMU+BXN`%]0^&EH;.&Y96[M`%]/
M9&ALX;EE;NT`7TUO9&EF:6MO=F%T($QI;FMU+BXN`%]-;[YN;W-T:0!?4'+A
M=F$`7T]D<W1R86YI="!,:6YK=2XN+@!?3F%S=&%V96[M`%]6;&%S=&YO<W1I
M(%1A8G5L:WDN+BX`7U6^:79A=&5LZ0!K;VYT86MT>0!N87-T86QA(&-H>6)A
M.@!K86QE;F3A^`!B97IV['3X[0!K;&EK;F]U="!Z9&4`<')O=F5D96YO`'-E
M;&AA;&\`<W+AOFMY`'-O=6)O<@!N86QE>F5N;SH@`'H@)7,@*"5S*2!R>6-H
M;&]S=.T@)7,@)7,`:#H`:3$X;@!O:V%MOFET[`!V(/AA9.P`;&1A<%]S=&%R
M=%]T;',@<V5L:&%L`/CA9&OY70!C:'EB;W;](&OS9"!M:VES;V9S("5D('#X
M:2!V>71VX?AE;NT@25-/+@!J;>EN;P!N97IM[&[L;F\`;F5N86QE>F5N;P!N
M96[M(&EM<&QE;65N=&]VX6YO`&YE;NT@:F6Y=.P@:6UP;&5M96YT;W;A;F\`
M>N%P:7-N[6L`<')O8V5N=`!P:7AE;/D`<W1O=7!A:NUC[0!Z;V)R87II="!R
M;WID[6QY`'-M<S)E;6%I;"!Z82!P;W6^:73M($A45%``=GET<G9A;.D`<V5Z
M;F%M(/IK;VSY`$AO<F1E(%!/('-O=6)O<B!P<F\@;&]C86QE("5S(&YE97AI
M<W1U:F4Z`'!R;R!P;W1V<GIE;NT@;F%P:;ET92!H97-L;R!D=F%K<N%T`'-J
M961N;V-E;OT`8F5Z(&[A>G9U`&%K='5A;&EZ;W;A;F\`=GEB<F%T('6^:79A
M=&5L90!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O
M;&]C86QE+V9A7TE2+P``````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S`#`R,#$T,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O9F%?25(O3$-?34534T%'15,O````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`,#(Q
M-S,P`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]F85])
M4B],0U]-15-304=%4R]P87-S=V0N;6\`````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0S,#0U
M-``Q,#0Q-S,V,C<T,P`P,C,U-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````WA($E0````!?!@``'````!0S``"#"```#&8`
M```````8B```#@```!F(```/````*(@```T````XB```"````$:(```+````
M3X@```P```!;B```!````&B(```,````;8@``!$```!ZB```)0```(R(```/
M````LH@```L```#"B```$0```,Z(```.````X(@```4```#OB```*````/6(
M```(````'HD```H````GB0``%0```#*)```2````2(D```L```!;B0``)P``
M`&>)```4````CXD``"8```"DB0``)P```,N)```F````\XD``!,````:B@``
M#@```"Z*```*````/8H```T```!(B@``+@```%:*```G````A8H``"````"M
MB@``#@```,Z*```7````W8H``"(```#UB@``-0```!B+```1````3HL```T`
M``!@BP``#````&Z+```-````>XL```8```")BP``'0```)"+```;````KHL`
M`"T```#*BP``'0```/B+```D````%HP``"D````[C```&0```&6,```/````
M?XP``!@```"/C```#````*B,```;````M8P```X```#1C```#@```.",```(
M````[XP``"X```#XC```&@```">-```R````0HT``#@```!UC0``#@```*Z-
M```'````O8T```H```#%C0``#P```-"-```%````X(T``!$```#FC0``"```
M`/B-```)`````8X```D````+C@``#@```!6.```(````)(X```X````MC@``
M)0```#R.```@````8HX``!````"#C@``"@```)2.```'````GXX```,```"G
MC@``#P```*N.```4````NXX```D```#0C@``#0```-J.```2````Z(X``!D`
M``#[C@``'@```!6/```/````-(\```H```!$CP``#P```$^/```(````7X\`
M`"0```!HCP``%P```(V/```4````I8\``!8```"ZCP``"````-&/``!.````
MVH\``"T````ID```'P```%>0```9````=Y````<```"1D```#````)F0```L
M````II````X```#3D````P```.*0```%````YI````4```#LD```"@```/*0
M```#````_9```!<````!D0``"@```!F1```/````))$```X````TD0``&```
M`$.1```C````7)$```X```"`D0``%````(^1```7````I)$``!<```"\D0``
M%P```-21```3````[)$```\`````D@``'P```!"2```&````,)(```L````W
MD@``$````$.2```5````5)(``!4```!JD@``!P```("2```%````B)(``!4`
M``".D@``$0```*22```,````MI(``#L```##D@``.````/^2```4````.),`
M``,```!-DP``.0```%&3```2````BY,``#D```">DP``)P```-B3```L````
M`)0``"H````ME```)0```%B4```)````?I0```H```"(E```!@```).4```O
M````FI0``#<```#*E```+@````*5``!5````,94``"T```"'E0``+0```+65
M```M````XY4``$`````1E@``(P```%*6```C````=I8``"T```":E@``,P``
M`,B6```5````_)8``!D````2EP``*0```"R7```D````5I<``!$```![EP``
M$0```(V7```B````GY<```H```#"EP``$````,V7```6````WI<``!8```#U
MEP``%`````R8```$````(9@``"<````FF```"````$Z8```I````5Y@```X`
M``"!F```"@```)"8```/````FY@```0```"KF```"0```+"8```&````NI@`
M`!$```#!F```!P```-.8```$````VY@```8```#@F```(@```.>8```6````
M"ID```T````AF0```P```"^9```#````,YD``!<````WF0``$P```$^9```(
M````8YD```0```!LF0``00```'&9```@````LYD```8```#4F0``%0```-N9
M```8````\9D``"(````*F@``+@```"V:```=````7)H``"$```!ZF@``5```
M`)R:```I````\9H```<````;FP``%0```".;```*````.9L```\```!$FP``
M#0```%2;```/````8IL```T```!RFP``"0```(";```4````BIL```8```"?
MFP``'0```*:;```3````Q)L``!0```#8FP``#````.V;```&````^IL```\`
M```!G```$P```!&<``!4````)9P``!0```!ZG```%P```(^<```$````IYP`
M``X```"LG```1````+N<```;`````)T``!H````<G0``$0```#>=```1````
M29T``!$```!;G0``'````&V=```J````BIT``"$```"UG0``)0```->=```9
M````_9T```4````7G@``$P```!V>```2````,9X```H```!$G@``#P```$^>
M```1````7YX``!,```!QG@``#````(6>```&````DIX```8```"9G@``$```
M`*">```1````L9X```4```##G@``#````,F>```0````UIX```4```#GG@``
M#0```.V>```&````^YX```<````"GP``#0````J?```0````&)\```D````I
MGP``!P```#.?```+````.Y\```L```!'GP``!P```%.?```)````6Y\``!0`
M``!EGP``"0```'J?```*````A)\``!D```"/GP``'0```*F?```,````QY\`
M`!````#4GP``%0```.6?```2````^Y\``!,````.H```*P```"*@```[````
M3J```"````"*H```-@```*N@```0````XJ````@```#SH```!@```/R@```$
M`````Z$```X````(H0``$````!>A```>````**$``!L```!'H0``(0```&.A
M```>````A:$``!D```"DH0``'@```+ZA```=````W:$``!L```#[H0``(```
M`!>B```N````.*(``!<```!GH@``)@```'^B```P````IJ(``!L```#7H@``
M'@```/.B```<````$J,``"8````OHP``*P```%:C```S````@J,``"8```"V
MHP``*P```-VC```X````":0``!T```!"I```%0```&"D```O````=J0``!(`
M``"FI```(````+FD```I````VJ0``!X````$I0``(0```".E```2````1:4`
M`*(```!8I0``%@```/NE```C````$J8``"@````VI@``*0```%^F```H````
MB:8``!\```"RI@``%0```-*F```@````Z*8``"4````)IP``*````"^G```M
M````6*<``#````"&IP``D@```+>G```A````2J@``!P```!LJ```)@```(FH
M```J````L*@``$$```#;J```1````!VI```,````8JD```<```!OJ0``!P``
M`'>I```&````?ZD```T```"&J0``$````)2I```2````I:D``!,```"XJ0``
M$@```,RI```-````WZD```P```#MJ0``#@```/JI```/````":H``!,````9
MJ@``#0```"VJ```H````.ZH```,```!DJ@``#0```&BJ```1````=JH``!<`
M``"(J@``&P```*"J```"````O*H```4```"_J@``!````,6J```0````RJH`
M``0```#;J@``#0```."J```.````[JH```,```#]J@``#@````&K```(````
M$*L```\````9JP``"````"FK```/````,JL```T```!"JP``$````%"K```3
M````8:L``!,```!UJP``"P```(FK```1````E:L```D```"GJP``!@```+&K
M```,````N*L``!$```#%JP``&0```->K```+````\:L```T```#]JP``(@``
M``NL```;````+JP``#0```!*K```"@```'^L```8````BJP``!D```"CK```
M%@```+VL```O````U*P``"(````$K0``#0```">M```,````-:T``"8```!"
MK0``%````&FM```+````?JT``"(```"*K0``+P```*VM```+````W:T```D`
M``#IK0``&0```/.M```+````#:X``!<````9K@``%P```#&N```)````2:X`
M`!8```!3K@``#P```&JN```6````>JX```X```"1K@``&````*"N```-````
MN:X``"8```#'K@``0P```.ZN```(````,J\```L````[KP``+P```$>O```.
M````=Z\```4```"&KP``!@```(RO```#````DZ\```0```"7KP``"@```)RO
M```*````IZ\```\```"RKP``$````,*O```7````TZ\``!$```#KKP``%P``
M`/VO```9````%;````D````OL```"@```#FP```"````1+````4```!'L```
M#0```$VP```;````6[```!<```!WL```"0```(^P```.````F;````T```"H
ML```$@```+:P```X````R;```"`````"L0```P```".Q```(````)[$```X`
M```PL0``>P```#^Q```8````N[$``$````#4L0``!0```!6R```@````&[(`
M`!@````\L@``&0```%6R```3````;[(```<```"#L@``!@```(NR```&````
MDK(``!````"9L@``#P```*JR```0````NK(```\```#+L@``"P```-NR```/
M````Y[(```P```#WL@``#P````2S```'````%+,```H````<LP``!@```">S
M```.````+K,```P````]LP``#P```$JS```6````6K,```@```!QLP``$P``
M`'JS```>````CK,``"$```"MLP``(````,^S```9````\+,``!<````*M```
M)0```"*T```7````2+0``!X```!@M```)@```'^T```$````IK0```P```"K
MM````P```+BT```(````O+0```L```#%M```$````-&T```3````XK0``!0`
M``#VM```#`````NU```)````&+4```X````BM0``"P```#&U```;````/;4`
M``<```!9M0``"@```&&U```-````;+4```D```!ZM0``!0```(2U```#````
MBK4``!@```".M0``"@```*>U```$````LK4``"8```"WM0``#@```-ZU```5
M````[;4```4````#M@``!P````FV```,````$;8```@````>M@``"@```">V
M```&````,K8```@````YM@``%@```$*V```2````6;8```(```!LM@``!@``
M`&^V```5````=K8```\```",M@``$0```)RV```:````KK8```0```#)M@``
M"0```,ZV```0````V+8```D```#IM@``"0```/.V```%````_;8``!H````#
MMP``"````!ZW```9````)[<```X```!!MP``(@```%"W```.````<[<```H`
M``""MP```@```(VW```-````D+<```D```">MP``$@```*BW```4````N[<`
M`!T```#0MP``$0```.ZW```&`````+@``!$````'N```$0```!FX```)````
M*[@```(````UN```!````#BX```Y````/;@``#T```!WN```.@```+6X```>
M````\+@```X````/N0``!````!ZY```&````([D``!4````JN0``!@```$"Y
M```$````1[D``!$```!,N0``!@```%ZY``"@````9;D```H````&N@``(@``
M`!&Z```$````-+H``"4````YN@``!0```%^Z```$````9;H```P```!JN@``
M"@```'>Z```%````@KH``!L```"(N@``.@```*2Z```P````W[H``#4````0
MNP``*0```$:[```N````<+L``#@```"?NP``*0```-B[```N`````KP``!\`
M```QO```#P```%&\```2````8;P```L```!TO```)@```("\```I````I[P`
M`"0```#1O```)@```/:\```(````';T```H````FO0``(````#&]```@````
M4KT``"8```!SO0``"@```)J]```9````I;T``!(```"_O0``"@```-*]```,
M````W;T```\```#JO0``$````/J]``!`````"[X``'````!,O@``9@```+V^
M```.````)+\```D````SOP``"@```#V_```2````2+\``!,```!;OP``#```
M`&^_```&````?+\```\```"#OP``$@```)._```0````IK\```H```"WOP``
M$0```,*_```2````U+\``!P```#GOP``(P````3```!J````*,````\```"3
MP```$````*/````$````M,````L```"YP```&@```,7````4````X,````P`
M``#UP```#`````+!```/````#\$``!4````?P0``*0```#7!```J````7\$`
M`"8```"*P0``)P```+'!```I````V<$``"H````#P@``&0```"["``!"````
M2,(``!$```"+P@``$@```)W"```3````L,(``!0```#$P@``#P```-G"```6
M````Z<(``!<`````PP``$````!C#```1````*<,``#0````[PP``$P```'##
M```2````A,,``#4```"7PP``%````,W#```'````XL,```P```#JPP``*P``
M`/?#```@````(\0``!0```!$Q```%P```%G$```<````<<0``!,```".Q```
M$0```*+$```:````M,0``!X```#/Q```&@```.[$```1````"<4``!<````;
MQ0``%````#/%```7````2,4``!4```!@Q0``"0```';%```1````@,4```8`
M``"2Q0``!@```)G%```'````H,4``!8```"HQ0``!@```+_%```$````QL4`
M``0```#+Q0``!P```-#%```.````V,4```P```#GQ0``#````/3%```-````
M`<8```X````/Q@``*````![&```,````1\8```\```!4Q@``"@```&3&```(
M````;\8```D```!XQ@``*P```(+&```$````KL8```\```"SQ@``!P```,/&
M```(````R\8```D```#4Q@``#````-[&```-````Z\8```X```#YQ@``%@``
M``C'```1````'\<```,````QQP``!@```#7'```$````/,<```L```!!QP``
M"P```$W'```-````6<<```H```!GQP``$````'+'```/````@\<``!$```"3
MQP``%P```*7'```*````O<<``!$```#(QP``!````-K'```/````W\<``#H`
M``#OQP``!0```"K(```,````,,@``!X````]R```#@```%S(```0````:\@`
M``L```!\R```#````(C(```)````E<@```<```"?R```"@```*?(```)````
MLL@```X```"\R```$````,O(```:````W,@```H```#WR```%`````+)```*
M````%\D```P````BR0``#P```"_)```(````/\D```8```!(R0``!P```$_)
M```+````5\D``$<```!CR0``#0```*O)```)````N<D```0```##R0```P``
M`,C)```3````S,D``!,```#@R0``$P```/3)```"````",H```0````+R@``
M)0```!#*```#````-LH```4````ZR@``!````$#*```*````1<H```T```!0
MR@``0````%[*```3````G\H``&@```"SR@``"0```!S+```,````)LL```4`
M```SRP``!@```#G+```;````0,L``"\```!<RP``#P```(S+```3````G,L`
M`!L```"PRP``&````,S+```7````Y<L```X```#]RP```P````S,```(````
M$,P``!0````9S```$P```"[,```0````0LP```T```!3S```#@```&',```6
M````<,P```<```"'S```"@```(_,```+````FLP``"T```"FS```%0```-3,
M```P````ZLP``"0````;S0``!P```$#-``!1````2,T``!````":S0``#```
M`*O-```-````N,T``!H```#&S0``2@```.'-```&````+,X``!H````SS@``
M!@```$[.```&````5<X```D```!<S@``&````&;.```7````?\X``"@```"7
MS@``!@```,#.```-````Q\X``%<```#5S@``$P```"W/```"````0<\```L`
M``!$SP``"````%#/```-````6<\```H```!GSP``!@```'+/```.````><\`
M``<```"(SP``"P```)#/```,````G,\```T```"ISP``#````+?/```)````
MQ,\```D```#.SP``"@```-C/```'````X\\```D```#KSP``!P```/7/```;
M````_<\``!(````9T```"@```"S0```)````-]```!````!!T```$@```%+0
M```$````9=````P```!JT```$0```'?0```:````B=```!8```"DT```%```
M`+O0```7````T-````<```#HT```!0```/#0```,````]M````@````#T0``
M%P````S1```-````)-$``!,````RT0``!````$;1```*````2]$```0```!6
MT0``"0```%O1```*````9=$```P```!PT0``!0```'W1```"````@]$``#@`
M``"&T0``+````+_1```I````[-$``#(````6T@``"@```$G2```V````5-(`
M`"P```"+T@``%0```+C2```N````SM(``#,```#]T@``,P```#'3```X````
M9=,```\```">TP``&````*[3```[````Q],``!`````#U```#P```!34```4
M````)-0``!,````YU```%````$W4```2````8M0``!0```!UU```%0```(K4
M```M````H-0``"T```#.U```,0```/S4```M````+M4``"X```!<U0``+P``
M`(O5```L````N]4```@```#HU0``"````/'5```;````^M4``"L````6U@``
M(0```$+6```:````9-8```D```!_U@``10```(G6``!!````S]8```\````1
MUP``!````"'7```3````)M<``!0````ZUP``$P```$_7```)````8]<```H`
M``!MUP``#P```'C7```0````B-<```<```"9UP``#@```*'7```%````L-<`
M`!L```"VUP``!@```-+7```(````V=<```8```#BUP``%````.G7```1````
M_M<```X````0V```.````!_8```"````6-@```8```!;V```#@```&+8```:
M````<=@```4```",V```!P```)+8```.````FM@```8```"IV```#0```+#8
M```I````OM@``!\```#HV```7`````C9```4````9=D``!\```!ZV0``$```
M`)K9```4````J]D```<```#`V0``#@```,C9```(````U]D```P```#@V0``
M#````.W9```3````^MD```H````.V@``'0```!G:```9````-]H```4```!1
MV@``$0```%?:```1````:=H``"0```![V@``%0```*#:```2````MMH```X`
M``#)V@``&0```-C:```(````\MH```D```#[V@``#0````7;```*````$]L`
M``<````>VP``#P```";;```+````-ML```H```!"VP``!P```$W;```-````
M5=L``"(```!CVP``"````(;;```7````C]L``!(```"GVP``+````+K;```O
M````Y]L``"P````7W```*@```$3<```K````;]P``"P```";W```&@```,C<
M```)````X]P```H```#MW```%0```/C<```%````#MT``!0````4W0``!```
M`"G=```&````+MT```<````UW0``'@```#W=```H````7-T```H```"%W0``
M'````)#=```:````K=T```\```#(W0``%````-C=```$````[=T```4```#R
MW0``!@```/C=```&````_]T``!L````&W@``-````"+>```T````5]X``"``
M``",W@``*0```*W>```@````U]X``$$```#XW@``&@```#K?```H````5=\`
M`"D```!^WP``40```*C?```O````^M\``%<````JX```+````(+@```B````
MK^````@```#2X```!0```-O@```9````X>```!D```#[X```*@```!7A```C
M````0.$``"X```!DX0``-````)/A```-````R.$```@```#6X0``%P```-_A
M```*````]^$```<````"X@``(0````KB```-````+.(``!`````ZX@``#@``
M`$OB```+````6N(```<```!FX@``$P```&[B```(````@N(```L```"+X@``
M"@```)?B```4````HN(``#(```"WX@``!0```.KB```7````\.(```\````(
MXP``!````!CC```*````'>,```D````HXP``"P```#+C```-````/N,```P`
M``!,XP``#@```%GC```$````:.,```T```!MXP``,@```'OC``!%````KN,`
M`!<```#TXP``'@````SD```4````*^0``!0```!`Y```!P```%7D```C````
M7>0```X```"!Y```*@```)#D```&````N^0```P```#"Y```#0```,_D```1
M````W>0``!<```#OY```"P````?E```V````$^4```H```!*Y0``(@```%7E
M```+````>.4```\```"$Y0``"P```)3E```@````H.4``"<```#!Y0``*P``
M`.GE```)````%>8``#(````?Y@``,````%+F```Q````@^8``"T```"UY@``
M/P```./F```]````(^<``#8```!AYP``#@```)CG```4````I^<```4```"\
MYP``#@```,+G```3````T><```<```#EYP``&@```.WG```(````".@``!$`
M```1Z```!P```"/H```4````*^@``!@```!`Z```!P```%GH```%````8>@`
M``P```!GZ```#````'3H```2````@>@```0```"4Z```"@```)GH```+````
MI.@```P```"PZ```#@```+WH```.````S.@```4```#;Z```!0```.'H```N
M````Y^@``"8````6Z0``(P```#WI```#````8>D``!@```!EZ0``)0```'[I
M```-````I.D```D```"RZ0```@```+SI```#````O^D```<```##Z0``"@``
M`,OI```"````UND``!(```#9Z0``!````.SI```'````\>D```D```#YZ0``
M#`````/J``!2````$.H``!<```!CZ@``)````'OJ```'````H.H```8```"H
MZ@``#@```*_J```B````ONH``!T```#AZ@``#````/_J```-````#.L``!4`
M```:ZP``$@```##K```/````0^L``!0```!3ZP``&P```&CK```0````A.L`
M`&D```"5ZP``&@```/_K```7````&NP``"<````R[```&@```%KL```7````
M=>P``!L```"-[```&0```*GL```?````P^P``!<```#C[```$P```/OL```(
M````#^T```@````8[0``"0```"'M```-````*^T``!,````Y[0```P```$WM
M``!&````4>T``#\```"8[0``-P```-CM``!7````$.X```4```!H[@``'P``
M`&[N```O````CNX```@```"^[@``#0```,?N```M````U>X```0````#[P``
M3P````CO```E````6.\``!P```!^[P``"P```)OO```?````I^\``!T```#'
M[P``)0```.7O```@````"_```"0````L\```(````%'P```+````<O````<`
M``!^\```#0```(;P```,````E/````8```"A\```!P```*CP```9````L/``
M``D```#*\```$P```-3P```$````Z/```!````#M\```"@```/[P```$````
M"?$```L````.\0``#````!KQ```1````)_$```P````Y\0``&@```$;Q```-
M````8?$``!0```!O\0``#@```(3Q```;````D_$``!,```"O\0``'````,/Q
M```H````X/$```8````)\@``!P```!#R```3````&/(```0````L\@``%P``
M`#'R```*````2?(```P```!4\@``"0```&'R```&````:_(```@```!R\@``
M!0```'OR```*````@?(``!$```",\@``!@```)[R```8````I?(```X```"^
M\@``#@```,WR```+````W/(```L```#H\@```@```/3R```<````]_(```<`
M```4\P``%P```!SS```&````-/,``&4````[\P``"0```*'S```'````J_,`
M`"8```"S\P``.````-KS```:````$_0``"H````N]```.P```%GT```H````
ME?0``#0```"^]```&0```//T```5````#?4```<````C]0``"````"OU```'
M````-/4```4````\]0``!P```$+U```.````2O4```D```!9]0``!@```&/U
M```(````:O4```L```!S]0``!P```'_U```'````A_4``!P```"/]0``!P``
M`*SU```(````M/4```@```"]]0``!0```,;U```0````S/4``!````#=]0``
M!P```.[U```%````]O4``!````#\]0``%`````WV```+````(O8```T````N
M]@``&````#SV```7````5?8``!H```!M]@``%````(CV```$````G?8```D`
M``"B]@``"@```*SV```'````M_8```(```"_]@``#@```,+V```?````T?8`
M`"````#Q]@``/@```!+W```Q````4?<``"<```"#]P``%````*OW```<````
MP/<``%4```#=]P``.````#/X``!;````;/@``"@```#(^```.````/'X```J
M````*OD``"@```!5^0``+````'[Y```G````J_D``!L```#3^0``J0$``._Y
M```H````F?L``",```#"^P``%P```.;[``"%````_OL``#````"$_```6P``
M`+7\``!)````$?T``!T```!;_0``&````'G]```A````DOT``!\```"T_0``
M*P```-3]```A`````/X``"D````B_@``)P```$S^```=````=/X``!$```"2
M_@``,P```*3^```E````V/X``#@```#^_@``)P```#?_```@````7_\``!\`
M``"`_P``,````*#_``!I````T?\``"L````[``$`,@```&<``0`Q````F@`!
M`$$```#,``$`,P````X!`0`E````0@$!`#T```!H`0$`90```*8!`0!-````
M#`(!`"\```!:`@$`+@```(H"`0`K````N0(!`#````#E`@$`*@```!8#`0`^
M````00,!`%0```"``P$`@P```-4#`0!:````600!`$@```"T!`$`2@```/T$
M`0`R````2`4!`!T```![!0$`(P```)D%`0`O````O04!`"P```#M!0$`+0``
M`!H&`0`7````2`8!`"4```!@!@$`,@```(8&`0`I````N08!`#X```#C!@$`
M(@```"('`0`+````10<!`$4```!1!P$`(0```)<'`0`N````N0<!`#````#H
M!P$`)0```!D(`0`<````/P@!`#$```!<"`$`!P```(X(`0`'````E@@!``0`
M``">"`$`#0```*,(`0`+````L0@!``X```"]"`$`!0```,P(`0`0````T@@!
M``(```#C"`$`60```.8(`0`%````0`D!``@```!&"0$``P```$\)`0`0````
M4PD!``H```!D"0$`#````&\)`0`-````?`D!``(```"*"0$`%````(T)`0`2
M````H@D!``P```"U"0$``P```,()`0`$````Q@D!`!\```#+"0$`-0```.L)
M`0`N````(0H!`"\```!0"@$`%P```(`*`0`@````F`H!`!L```"Y"@$`&```
M`-4*`0`D````[@H!`!\````3"P$`&@```#,+`0`@````3@L!`!H```!O"P$`
M,@```(H+`0`O````O0L!`!H```#M"P$`*P````@,`0`?````-`P!`",```!4
M#`$`'P```'@,`0`:````F`P!`"4```"S#`$`)@```-D,`0`E``````T!`"0`
M```F#0$`&````$L-`0`=````9`T!`"0```""#0$`&````*<-`0`B````P`T!
M`"4```#C#0$`/`````D.`0`?````1@X!`",```!F#@$`'P```(H.`0`@````
MJ@X!`!H```#+#@$`&````.8.`0`F````_PX!`!X````F#P$`*0```$4/`0`>
M````;P\!``D```".#P$`#````)@/`0`7````I0\!`"\```"]#P$`)````.T/
M`0`'````$A`!``\````:$`$`!0```"H0`0`'````,!`!`!,````X$`$`'0``
M`$P0`0`:````:A`!``<```"%$`$`QP```(T0`0`+````51$!`!4```!A$0$`
M#````'<1`0`&````A!$!``D```"+$0$`&````)41`0`+````KA$!``T```"Z
M$0$`'0```,@1`0`7````YA$!``8```#^$0$`,P````42`0`3````.1(!`!,`
M``!-$@$`!@```&$2`0`/````:!(!``<```!X$@$`,@```(`2`0`A````LQ(!
M`!,```#5$@$`#````.D2`0`1````]A(!`#(````($P$`#@```#L3`0`/````
M2A,!`!````!:$P$`"````&L3`0`=````=!,!``D```"2$P$`"@```)P3`0`%
M````IQ,!`!0```"M$P$`'0```,(3`0`(````X!,!`!\```#I$P$`"`````D4
M`0`:````$A0!``8````M%`$`%0```#04`0`(````2A0!``<```!3%`$`#P``
M`%L4`0`.````:Q0!`!````!Z%`$`"0```(L4`0`)````E10!`!,```"?%`$`
M!P```+,4`0`9````NQ0!``H```#5%`$`"@```.`4`0`)````ZQ0!``H```#U
M%`$`#``````5`0`J````#14!``<````X%0$`"0```$`5`0`"````2A4!`!``
M``!-%0$`&````%X5`0`+````=Q4!``,```"#%0$`"````(<5`0`&````D!4!
M``<```"7%0$`#0```)\5`0`+````K14!`!0```"Y%0$`%0```,X5`0`O````
MY!4!`"`````4%@$`'````#46`0`,````4A8!`#$```!?%@$`!0```)$6`0`2
M````EQ8!`#\```"J%@$`$@```.H6`0`*````_18!``8````(%P$`!`````\7
M`0`$````%!<!``H````9%P$`$P```"07`0`%````.!<!``8````^%P$`!@``
M`$47`0`)````3!<!``0```!6%P$`#````%L7`0`*````:!<!`"````!S%P$`
M`@```)07`0`$````EQ<!``8```"<%P$``P```*,7`0`,````IQ<!`$4```"T
M%P$`&@```/H7`0`U````%1@!`"4```!+&`$`*````'$8`0!3````FA@!`!D`
M``#N&`$`<@````@9`0`@````>QD!`"$```"<&0$`10```+X9`0`P````!!H!
M`",````U&@$`'P```%D:`0`H````>1H!`"D```"B&@$`)@```,P:`0`E````
M\QH!`"@````9&P$`*````$(;`0`B````:QL!`"$```".&P$`,````+`;`0`2
M````X1L!`!,```#T&P$`$`````@<`0!Y````&1P!``D```"3'`$`<@```)T<
M`0!S````$!T!`'P```"$'0$`*P````$>`0!3````+1X!`!<```"!'@$`%@``
M`)D>`0`/````L!X!`&4```#`'@$`'P```"8?`0!1````1A\!`#<```"8'P$`
M-@```-`?`0`V````!R`!`#X````^(`$`00```'T@`0!#````OR`!`'P````#
M(0$`0````(`A`0`^````P2$!`$``````(@$`0@```$$B`0`Y````A"(!`!\`
M``"^(@$`'P```-XB`0`<````_B(!`%$````;(P$`%````&TC`0`2````@B,!
M`!````"5(P$`$P```*8C`0`=````NB,!``\```#8(P$`#P```.@C`0`$````
M^",!``D```#](P$`"P````<D`0`'````$R0!``4````;)`$`%````"$D`0`'
M````-B0!``@````^)`$`#P```$<D`0`(````5R0!``P```!@)`$`#P```&TD
M`0`&````?20!`!0```"$)`$`!@```)DD`0`,````H"0!`!4```"M)`$`"```
M`,,D`0`$````S"0!``H```#1)`$`!````-PD`0`&````X20!``0```#H)`$`
M!P```.TD`0`9````]20!``(````/)0$`!````!(E`0`)````%R4!``8````A
M)0$`%0```"@E`0`&````/B4!``0```!%)0$`"P```$HE`0`)````5B4!``\`
M``!@)0$`$P```'`E`0`'````A"4!``<```",)0$`!@```)0E`0`&````FR4!
M`!````"B)0$`!@```+,E`0`)````NB4!`#,```#$)0$`(@```/@E`0`'````
M&R8!``<````C)@$`!P```"LF`0`+````,R8!``(````_)@$`"P```$(F`0!X
M`0``3B8!`!,```#')P$`&@```-LG`0`0````]B<!``T````'*`$`"P```!4H
M`0`-````(2@!``8````O*`$`"P```#8H`0`D````0B@!`%L```!G*`$`&P``
M`,,H`0`-````WR@!``\```#M*`$`%````/TH`0`4````$BD!`"L````G*0$`
M$P```%,I`0`+````9RD!`!8```!S*0$`)````(HI`0`-````KRD!`#D```"]
M*0$`&@```/<I`0`^````$BH!`"P```!1*@$`0@```'XJ`0`?````P2H!`!L`
M``#A*@$`#0```/TJ`0`2````"RL!`$`````>*P$`/P```%\K`0`U````GRL!
M`!(```#5*P$`/````.@K`0`X````)2P!`%8```!>+`$`&````+4L`0`-````
MSBP!`!,```#<+`$`&````/`L`0`&````"2T!`#\````0+0$`)P```%`M`0`S
M````>"T!`#,```"L+0$`-@```.`M`0`\````%RX!`!L```!4+@$`#P```'`N
M`0`?````@"X!``X```"@+@$`&P```*\N`0`6````RRX!`!8```#B+@$`#P``
M`/DN`0!(````"2\!`"D```!2+P$`70```'PO`0!K````VB\!`!$```!&,`$`
M&0```%@P`0`9````<C`!`!<```",,`$`#0```*0P`0`D````LC`!``\```#7
M,`$`$P```.<P`0`/````^S`!`!T````+,0$`$P```"DQ`0`A````/3$!`#8`
M``!?,0$`/````)8Q`0`7````TS$!`!````#K,0$`#````/PQ`0`3````"3(!
M`"4````=,@$`-P```$,R`0`;````>S(!`"4```"7,@$`-````+TR`0`T````
M\C(!`$,````G,P$`+0```&LS`0`<````F3,!`"<```"V,P$`'0```-XS`0!%
M````_#,!`"\```!"-`$`+P```'(T`0`S````HC0!`!X```#6-`$`;0```/4T
M`0!;````8S4!`$$```"_-0$`-`````$V`0`(````-C8!`!8````_-@$`80``
M`%8V`0`7````N#8!``X```#0-@$`"@```-\V`0`1````ZC8!``D```#\-@$`
M!@````8W`0`X````#3<!`!8```!&-P$`)P```%TW`0`:````A3<!`!P```"@
M-P$`20```+TW`0`=````!S@!`!P````E.`$`(P```$(X`0`G````9C@!`#,`
M``"..`$`(````,(X`0`6````XS@!`#4```#Z.`$`"````#`Y`0`D````.3D!
M`"8```!>.0$`'@```(4Y`0`U````I#D!``H```#:.0$`"@```.4Y`0`5````
M\#D!`"0````&.@$`$0```"LZ`0!O````/3H!`'$```"M.@$`%````!\[`0`&
M````-#L!`%P````[.P$`%0```)@[`0!C````KCL!`#T````2/`$`3P```%`\
M`0!5````H#P!`$P```#V/`$`%P```$,]`0`4````6ST!``H```!P/0$`.@``
M`'L]`0!6````MCT!`#8````-/@$`-@```$0^`0`W````>SX!`#@```"S/@$`
M.````.P^`0!\````)3\!`#,```"B/P$`0````-8_`0`X````%T`!`#X```!0
M0`$`)P```(]``0`K````MT`!`$@```#C0`$`-@```"Q!`0`E````8T$!`!,`
M``")00$`1P```)U!`0`/````Y4$!`!8```#U00$`)0````Q"`0`I````,D(!
M`!0```!<0@$`"@```'%"`0`X````?$(!``T```"U0@$`0P```,-"`0`7````
M!T,!``\````?0P$`%0```"]#`0`(````14,!``T```!.0P$`!@```%Q#`0`2
M````8T,!``T```!V0P$`"0```(1#`0`*````CD,!`#P```"90P$`&P```-9#
M`0`8````\D,!``,````+1`$``P````]$`0`7````$T0!`!\````K1`$`"@``
M`$M$`0`(````5D0!`)X```!?1`$`20```/Y$`0`,````2$4!`"<```!510$`
M.````'U%`0`V````MD4!`%,```#M10$`,0```$%&`0!#````<T8!`+,```"W
M1@$`50```&M'`0`*````P4<!`"0```#,1P$`#````/%'`0`9````_D<!`!,`
M```82`$`&0```"Q(`0`3````1D@!``P```!:2`$`%````&=(`0`(````?$@!
M`!T```"%2`$`%P```*-(`0`;````NT@!``@```#72`$`"P```.!(`0`8````
M[$@!`"4````%20$`C0```"M)`0`M````N4D!`"<```#G20$`"@````]*`0`8
M````&DH!`'(````S2@$`&P```*9*`0`:````PDH!`"$```#=2@$`)0```/]*
M`0`?````)4L!`#````!%2P$`30```'9+`0`V````Q$L!`#X```#[2P$`%P``
M`#I,`0`'````4DP!`"8```!:3`$`(@```(%,`0`:````I$P!`",```"_3`$`
M)P```.-,`0`=````"TT!`!,````I30$`"@```#U-`0`(````2$T!`"$```!1
M30$`&P```'--`0`&````CTT!`!X```"630$`$P```+5-`0`-````R4T!`!,`
M``#730$`"````.M-`0`4````]$T!``\````)3@$`*0```!E.`0`<````0TX!
M``H```!@3@$`%````&M.`0`1````@$X!``@```"23@$`#0```)M.`0`:````
MJ4X!`!,```#$3@$`"@```-A.`0`D````XTX!`#H````(3P$`$P```$-/`0`:
M````5T\!`"(```!R3P$`*@```)5/`0`J````P$\!`#X```#K3P$`40```"I0
M`0`M````?%`!`$4```"J4`$`$@```/!0`0`3`````U$!``@````740$`%0``
M`"!1`0`N````-E$!`!H```!E40$`-0```(!1`0`W````ME$!`$,```#N40$`
M.@```#)2`0`Z````;5(!`#````"H4@$`,P```-E2`0`R````#5,!`#8```!`
M4P$`4````'=3`0`O````R%,!`#P```#X4P$`3P```#54`0`^````A50!`$$`
M``#$5`$`-0````95`0!"````/%4!`&@```!_50$`80```.A5`0!%````2E8!
M`$<```"05@$`5@```-A6`0`Z````+U<!`"\```!J5P$`5P```)I7`0`G````
M\E<!`#X````:6`$`3@```%E8`0`R````J%@!`#@```#;6`$`+P```!19`0!!
M`0``1%D!`#D```"&6@$`3P```,!:`0!1````$%L!`%$```!B6P$`40```+1;
M`0`Z````!EP!`#,```!!7`$`/````'5<`0!*````LEP!`$\```#]7`$`9@``
M`$U=`0!+````M%T!`!L!````7@$`-0```!Q?`0`X````4E\!`$4```"+7P$`
M0@```-%?`0"#````%&`!`&4```"88`$`(0```/Y@`0`(````(&$!``\````I
M80$`"@```#EA`0`:````1&$!`!H```!?80$`(0```'IA`0`V````G&$!`"(`
M``#380$`$0```/9A`0`3````"&(!`!4````<8@$`&P```#)B`0`7````3F(!
M`!,```!F8@$`4P```'IB`0`*````SF(!`!<```#98@$`$0```/%B`0`7````
M`V,!`!L````;8P$``@```#=C`0`,````.F,!``@```!'8P$`'@```%!C`0`*
M````;V,!`!<```!Z8P$`%P```))C`0`&````JF,!``\```"Q8P$`#````,%C
M`0`5````SF,!``H```#D8P$`'````.]C`0`4````#&0!`!8````A9`$`+@``
M`#AD`0`N````9V0!``P```"69`$`%P```*-D`0`1````NV0!``8```#-9`$`
M#P```-1D`0`G````Y&0!`"L````,90$`#P```#AE`0`/````2&4!`"L```!8
M90$`-0```(1E`0!L````NF4!``T````G9@$`(P```#5F`0`:````668!`!@`
M``!T9@$`7````(UF`0!/````ZF8!`!,````Z9P$`#P```$YG`0!&````7F<!
M``\```"E9P$`"@```+5G`0`/````P&<!`$4```#09P$`"@```!9H`0`1````
M(6@!`#`````S:`$`$P```&1H`0`>````>&@!`!X```"7:`$`!@```+9H`0`Z
M````O6@!`!X```#X:`$`(0```!=I`0`3````.6D!`!,```!-:0$`#P```&%I
M`0!`````<6D!`(0```"R:0$`#````#=J`0`/````1&H!`$D```!4:@$`"P``
M`)YJ`0`,````JFH!`!T```"W:@$``P```-5J`0`,````V6H!`!4```#F:@$`
M%0```/QJ`0`M````$FL!`"T```!`:P$`.0```&YK`0`J````J&L!`#D```#3
M:P$`.P````UL`0`.````26P!``L```!8;`$``@```&1L`0`=````9VP!`"8`
M``"%;`$`4@```*QL`0`M````_VP!``X````M;0$`$P```#QM`0`<````4&T!
M`"<```!M;0$`90```)5M`0!`````^VT!``H````\;@$`$P```$=N`0`B````
M6VX!`,(```!^;@$`,````$%O`0!M````<F\!``8```#@;P$`+P```.=O`0`H
M````%W`!`#0```!`<`$`&0```'5P`0`(````CW`!``H```"8<`$`"@```*-P
M`0`<````KG`!`!0```#+<`$`%````.!P`0`6````]7`!`!(````,<0$`%```
M`!]Q`0`/````-'$!`!@```!$<0$`"````%UQ`0`)````9G$!``\```!P<0$`
M(@```(!Q`0`9````HW$!`!<```"]<0$`(@```-5Q`0`8````^'$!`!,````1
M<@$`,@```"5R`0`O````6'(!`"\```"(<@$`*P```+AR`0`O````Y'(!`$$`
M```4<P$`,@```%9S`0`^````B7,!`$(```#(<P$`"`````MT`0`(````%'0!
M``8````==`$`"@```"1T`0`3````+W0!``\```!#=`$`*````%-T`0`O````
M?'0!`!4```"L=`$`$P```,)T`0`9````UG0!`!<```#P=`$`.@````AU`0`.
M````0W4!``\```!2=0$`#0```&)U`0`1````<'4!``P```""=0$`#0```(]U
M`0`@````G74!``T```"^=0$`!@```,QU`0!5````TW4!``\````I=@$`/```
M`#EV`0`-````=G8!``@```"$=@$`#P```(UV`0`/````G78!`!$```"M=@$`
M$0```+]V`0`0````T78!`#H```#B=@$`(````!UW`0`(````/G<!`!````!'
M=P$`&````%AW`0`2````<7<!`!@```"$=P$`(0```)UW`0`$````OW<!``4`
M``#$=P$`#P```,IW`0`/````VG<!``\```#J=P$`"````/IW`0`L`````W@!
M``L````P>`$`'@```#QX`0`6````6W@!`#(```!R>`$`$0```*5X`0`6````
MMW@!``8```#.>`$`%0```-5X`0`.````ZW@!`!(```#Z>`$`%0````UY`0`L
M````(WD!`"D```!0>0$`#P```'IY`0`M````BGD!`"T```"X>0$`&0```.9Y
M`0`"`````'H!``0````#>@$`20````AZ`0!)````4GH!`$D```"<>@$`*@``
M`.9Z`0`5````$7L!``T````G>P$`"@```#5[`0`5````0'L!``H```!6>P$`
M#````&%[`0`P````;GL!`!$```"?>P$`%@$``+%[`0`-````R'P!`#@```#6
M?`$`"`````]]`0`[````&'T!``@```!4?0$`"````%U]`0`1````9GT!`!P`
M``!X?0$`"````)5]`0`:````GGT!`%4```"Y?0$`1P````]^`0!,````5WX!
M`#(```"D?@$`.````-=^`0!=````$'\!`#````!N?P$`10```)]_`0`O````
MY7\!``T````5@`$`(````".``0`)````1(`!`%````!.@`$`/@```)^``0`N
M````WH`!`#P````-@0$`"@```$J!`0`,````58$!`#4```!B@0$`,0```)B!
M`0`[````RH$!``L````&@@$`*@```!*"`0`I````/8(!`!@```!G@@$`%```
M`(""`0`L````E8(!`!L```#"@@$`>@```-Z"`0"+````68,!`.$```#E@P$`
M'0```,>$`0`.````Y80!``\```#TA`$`&@````2%`0`;````'X4!`!4````[
MA0$`#````%&%`0`=````7H4!`!P```!\A0$`(@```)F%`0`6````O(4!`"D`
M``#3A0$`&@```/V%`0`U````&(8!`#X```!.A@$`U0```(V&`0`;````8X<!
M`!4```!_AP$`#@```)6'`0`.````I(<!`"0```"SAP$`*````-B'`0`>````
M`8@!`!H````@B`$`*0```#N(`0`J````98@!`$@```"0B`$`2````-F(`0!$
M````(HD!`$0```!GB0$`10```*R)`0!%````\HD!`"T````XB@$`D````&:*
M`0`H````]XH!`"@````@BP$`*````$F+`0`H````<HL!`!X```";BP$`,```
M`+J+`0`P````ZXL!`"8````<C`$`)@```$.,`0!3````:HP!`#````"^C`$`
M,````.^,`0!:````((T!`"D```![C0$`#P```*6-`0`:````M8T!`%````#0
MC0$`$````"&.`0`H````,HX!`"X```!;C@$`'@```(J.`0`G````J8X!`"4`
M``#1C@$`0````/>.`0`V````.(\!`"T```!OCP$`'@```)V/`0`D````O(\!
M`#L```#ACP$`(P```!V0`0`I````09`!``P```!KD`$`"````'B0`0`3````
M@9`!``T```"5D`$`#````*.0`0`6````L)`!`!4```#'D`$`"@```-V0`0`(
M````Z)`!``P```#QD`$`#0```/Z0`0`/````#)$!``L````<D0$`#P```"B1
M`0`C````.)$!`#<```!<D0$`$P```)21`0`(````J)$!``\```"QD0$`#P``
M`,&1`0`5````T9$!`$<```#GD0$`$````"^2`0`/````0)(!``\```!0D@$`
M"````&"2`0`/````:9(!``T```!YD@$`'0```(>2`0`7````I9(!`"````"]
MD@$`'0```-Z2`0`(````_)(!``\````%DP$`!````!63`0`/````&I,!`!$`
M```JDP$`%````#R3`0`5````49,!`"$```!GDP$`(@```(F3`0`C````K),!
M`"@```#0DP$`#0```/F3`0`;````!Y0!``H````CE`$`&0```"Z4`0"`````
M2)0!`!$```#)E`$`'@```-N4`0!"````^I0!`"P````]E0$`)````&J5`0`5
M````CY4!`!4```"EE0$`%P```+N5`0`-````TY4!`!<```#AE0$`$P```/F5
M`0`5````#98!`",````CE@$`-````$>6`0`,````?)8!`"D```")E@$`$0``
M`+.6`0`3````Q98!`!8```#9E@$`#````/"6`0`(````_98!``@````&EP$`
M$P````^7`0"0````(Y<!`!H```"TEP$`#P```,^7`0`&````WY<!``H```#F
MEP$`'@```/&7`0`<````$)@!`"`````MF`$``@```$Z8`0`1````49@!`#T`
M``!CF`$``P```*&8`0`(````I9@!`!T```"NF`$`)@```,R8`0`8````\Y@!
M`&L````,F0$`(````'B9`0"`````F9D!``D````:F@$`#````"2:`0`(````
M,9H!``H````ZF@$`3@```$6:`0`N````E)H!`!P```##F@$`-@```.":`0!!
M````%YL!`#,```!9FP$`,@```(V;`0`5````P)L!``0```#6FP$`"@```-N;
M`0`E````YIL!`!L````,G`$`)````"B<`0`5````39P!`"````!CG`$`+P``
M`(2<`0`*````M)P!`!0```"_G`$`%P```-2<`0!'````[)P!`!P````TG0$`
M0P```%&=`0`M````E9T!``H```##G0$`>@```,Z=`0`C````29X!`!$```!M
MG@$`&P```'^>`0`M````FYX!`&T```#)G@$`!@```#>?`0`F````/I\!`!,`
M``!EGP$`!@```'F?`0`+````@)\!`"(```",GP$`(0```*^?`0!%````T9\!
M``@````7H`$`#````""@`0"M````+:`!`!8```#;H`$`#````/*@`0`8````
M_Z`!``H````8H0$`'@```".A`0`.````0J$!``@```!1H0$`$````%JA`0`,
M````:Z$!`!,```!XH0$`$0```(RA`0`3````GJ$!`!<```"RH0$`'@```,JA
M`0`<````Z:$!`!P````&H@$`'````".B`0`>````0*(!`!P```!?H@$`,P``
M`'RB`0`5````L*(!``T```#&H@$`#P```-2B`0`D````Y*(!`"$````)HP$`
M!@```"NC`0`4````,J,!`!4```!'HP$`&@```%VC`0`6````>*,!`!0```"/
MHP$`%P```*2C`0`(````O*,!``@```#%HP$`$0```,ZC`0`+````X*,!`"T`
M``#LHP$`%P```!JD`0`>````,J0!``H```!1I`$`&@```%RD`0`(````=Z0!
M`!$```"`I`$`#P```)*D`0`<````HJ0!``0```"_I`$`!````,2D`0!7````
MR:0!`$\````AI0$`1@```'&E`0!7````N*4!`!,````0I@$`7````"2F`0!K
M````@:8!`"4```#MI@$`2P```!.G`0!0````7Z<!`%````"PIP$`50````&H
M`0`R````5Z@!`"P```"*J`$`90```+>H`0`N````':D!`"H```!,J0$`+```
M`'>I`0`G````I*D!`"X```#,J0$`*````/NI`0`S````)*H!`"0```!8J@$`
M3@```'VJ`0!.````S*H!`%(````;JP$`3@```&ZK`0!2````O:L!`%`````0
MK`$`30```&&L`0`3````KZP!`!$```##K`$`(P```-6L`0`Y````^:P!`$\`
M```SK0$`10```(.M`0`3````R:T!`'8```#=K0$`?0```%2N`0`<````TJX!
M``X```#OK@$`,0```/ZN`0`4````,*\!`!@```!%KP$`"P```%ZO`0`+````
M:J\!``\```!VKP$`)0```(:O`0`3````K*\!`"(```#`KP$`$@```..O`0`\
M````]J\!``H````SL`$`#````#ZP`0`&````2[`!`!T```!2L`$`%P```'"P
M`0`5````B+`!`%T```">L`$`#P```/RP`0`&````#+$!`!P````3L0$`/0``
M`#"Q`0`,````;K$!``H```![L0$`'````(:Q`0`/````H[$!`!D```"SL0$`
M5P```,VQ`0!4````);(!`*X```!ZL@$`*P```"FS`0`]````5;,!`!,```"3
MLP$`%P```*>S`0`1````O[,!`!8```#1LP$`$@```.BS`0`8````^[,!``P`
M```4M`$`%P```"&T`0`2````.;0!`"\```!,M`$`(````'RT`0`(````G;0!
M`!<```"FM`$`*0```+ZT`0`V````Z+0!`"(````?M0$`)@```$*U`0`8````
M:;4!`#@```""M0$`"````+NU`0`.````Q+4!`"0```#3M0$`&0```/BU`0`5
M````$K8!`!<````HM@$`"````$"V`0`.````2;8!`!,```!8M@$`$P```&RV
M`0`]````@+8!``\```"^M@$`*@```,ZV`0`C````^;8!`%H````=MP$`30``
M`'BW`0!%````QK<!`$X````,N`$`30```%NX`0!!````J;@!`!\```#KN`$`
M$`````NY`0`1````'+D!`#,````NN0$`#@```&*Y`0`C````<;D!``@```"5
MN0$`"@```)ZY`0`(````J;D!`"8```"RN0$`1@```-FY`0`7````(+H!`#,`
M```XN@$`+0```&RZ`0`I````FKH!`!<```#$N@$`&0```-RZ`0`(````]KH!
M``T```#_N@$`"@````V[`0`^````&+L!`%T```!7NP$`:@```+6[`0`S````
M(+P!`$$```!4O`$`,P```):\`0!T````RKP!`#4````_O0$`0````'6]`0!/
M````MKT!`(H````&O@$`3@```)&^`0"-````X+X!`%0```!NOP$`.P```,._
M`0`1````_[\!``@````1P`$`*P```!K``0`I````1L`!`!L```!PP`$`+```
M`(S``0`Y````N<`!`#\```#SP`$`$0```#/!`0`(````1<$!`!\```!.P0$`
M"@```&[!`0`1````><$!`#L```"+P0$`$0```,?!`0`<````V<$!``T```#V
MP0$`$0````3"`0`(````%L(!`!,````?P@$`$0```#/"`0`1````1<(!`!,`
M``!7P@$`)````&O"`0!6````D,(!``X```#GP@$`)````/;"`0`7````&\,!
M``H````SPP$`'0```#[#`0`9````7,,!`!@```!VPP$`%````(_#`0`4````
MI,,!`!4```"YPP$`#````,_#`0`?````W,,!`$@```#\PP$`?````$7$`0`^
M````PL0!`#X````!Q0$`(0```$#%`0`@````8L4!``X```"#Q0$`+@```)+%
M`0`<````P<4!`",```#>Q0$`!@````+&`0`/````"<8!``\````9Q@$`(```
M`"G&`0`B````2L8!``\```!MQ@$`3@```'W&`0`&````S,8!`"````#3Q@$`
M$0```/3&`0`5````!L<!`!P````<QP$`,@```#G'`0`]````;,<!`$,```"J
MQP$`#````.['`0!=````^\<!`$@```!9R`$`20```*+(`0!%````[,@!`%$`
M```RR0$`4P```(3)`0!&````V,D!`"`````?R@$`$0```$#*`0`0````4LH!
M`#$```!CR@$`.````)7*`0`*````SLH!`!\```#9R@$`"P```/G*`0`C````
M!<L!`!`````IRP$`)0```#K+`0`K````8,L!`!$```",RP$`"````)[+`0`3
M````I\L!`!4```"[RP$`&@```-'+`0`&````[,L!`!4```#SRP$`$@````G,
M`0`6````',P!`!<````SS`$`%P```$O,`0`+````8\P!``H```!OS`$`4@``
M`'K,`0!$````S<P!`$(````2S0$`"````%7-`0`B````7LT!`#<```"!S0$`
M#@```+G-`0`.````R,T!``(```#7S0$``P```-K-`0`,````WLT!``X```#K
MS0$`"````/K-`0`@`````\X!``H````DS@$`#0```"_.`0`/````/<X!`!P`
M``!-S@$`<P```&K.`0`C````WLX!`$D````"SP$`"````$S/`0`*````5<\!
M`!L```!@SP$`0@```'S/`0`K````O\\!`"````#KSP$`'`````S0`0`W````
M*=`!`",```!AT`$`&@```(70`0`Y````H-`!`"L```#:T`$`%@````;1`0#*
M````'=$!`"4```#HT0$`(0````[2`0!%````,-(!`",```!VT@$`'P```)K2
M`0`E````NM(!`"$```#@T@$`+0````+3`0`D````,-,!`!4```!5TP$`#@``
M`&O3`0`*````>M,!``X```"%TP$`%P```)33`0`D````K-,!``H```#1TP$`
MIP```-S3`0"-````A-0!`%(````2U0$`@````&75`0`.````YM4!`$4```#U
MU0$`/@```#O6`0`(````>M8!`!4```"#U@$`9````)G6`0`*````_M8!`&\`
M```)UP$`5P```'G7`0`_````T=<!`"(````1V`$`0````#38`0`W````==@!
M`#@```"MV`$`+P```.;8`0`V````%MD!`"T```!-V0$`%0```'O9`0`(````
MD=D!`!L```":V0$`&P```+;9`0`/````TMD!``T```#BV0$`-````/#9`0`*
M````)=H!`!L````PV@$`#````$S:`0`@````6=H!`!0```!ZV@$`!@```(_:
M`0`(````EMH!``@```"?V@$`&P```*C:`0`/````Q-H!`!T```#4V@$`$@``
M`/+:`0`L````!=L!`!$````RVP$`&P```$3;`0`8````8-L!`"X```!YVP$`
M-````*C;`0`*````W=L!``H```#HVP$`*P```//;`0`/````']P!`",````O
MW`$`$P```%/<`0`3````9]P!`!$```![W`$`"@```(W<`0`2````F-P!``@`
M``"KW`$`#P```+3<`0`:````Q-P!``T```#?W`$`)````.W<`0`<````$MT!
M`!4````OW0$`$P```$7=`0`.````6=T!``P```!HW0$`)````'7=`0`*````
MFMT!`"4```"EW0$`"@```,O=`0#&````UMT!``\```"=W@$`#````*W>`0`V
M````NMX!`$8```#QW@$`(@```#C?`0`R````6]\!`(H```".WP$`/P```!G@
M`0!/````6>`!`"<```"IX`$`)````-'@`0`*````]N`!`!,````!X0$`$P``
M`!7A`0`,````*>$!``@````VX0$`$0```#_A`0`*````4>$!``@```!<X0$`
M"@```&7A`0`1````<.$!`!````""X0$`%P```)/A`0`L````J^$!``@```#8
MX0$`"````.'A`0`0````ZN$!``@```#[X0$`'`````3B`0`<````(>(!``<`
M```^X@$`"@```$;B`0`3````4>(!`!X```!EX@$`$P```(3B`0`5````F.(!
M`!\```"NX@$`%P```,[B`0`Z````YN(!`"T````AXP$`!@```$_C`0`-````
M5N,!``\```!DXP$`$0```'3C`0`.````AN,!``X```"5XP$`1P```*3C`0`I
M````[.,!`(L````6Y`$`.0```*+D`0`T````W.0!`!,````1Y0$`*0```"7E
M`0!N````3^4!`$D```"^Y0$`:@````CF`0`P````<^8!`&$```"DY@$`,P``
M``;G`0`Z````.N<!`#P```!UYP$`0P```++G`0`Q````]N<!``T!```HZ`$`
M1@```#;I`0`B````?>D!`!0```"@Z0$`O````+7I`0!K````<NH!`(````#>
MZ@$`K@```%_K`0`9````#NP!`!@````H[`$`(@```$'L`0`F````9.P!`#P`
M``"+[`$`+````,CL`0!1````]>P!`#````!'[0$`'P```'CM`0`<````F.T!
M`%<```"U[0$`1`````WN`0!-````4NX!`#,```"@[@$`(````-3N`0`O````
M]>X!`%(````E[P$`QP```'CO`0!)````0/`!`%$```"*\`$`40```-SP`0!-
M````+O$!`$(```!\\0$`0@```+_Q`0!2`````O(!`)$```!5\@$`@````.?R
M`0!(````:/,!`$@```"Q\P$`2````/KS`0!*````0_0!`$(```".]`$`8P``
M`-'T`0"%````-?4!`-0```"[]0$`@@```)#V`0!X````$_<!`'H```",]P$`
M4`````?X`0`N````6/@!`"\```"'^`$`1@```+?X`0!(````_O@!`$H```!'
M^0$`*````)+Y`0!%````N_D!`$P````!^@$`/````$[Z`0"(````B_H!`#@`
M```4^P$`&0```$W[`0"/````9_L!`"8```#W^P$`0P```![\`0!-````8OP!
M`#T```"P_`$`*@```.[\`0!7````&?T!``8```!Q_0$`#P```'C]`0`(````
MB/T!`!<```"1_0$`$P```*G]`0`9````O?T!``H```#7_0$`%0```.+]`0`$
M````^/T!`(\```#]_0$`"@```(W^`0`(````F/X!``@```"A_@$`(````*K^
M`0`1````R_X!`!$```#=_@$`&````._^`0`-````"/\!`!0````6_P$`*0``
M`"O_`0`0````5?\!``,```!F_P$`!````&K_`0`P````;_\!`&4```"@_P$`
M50````8``@!;````7``"`"0```"X``(`/@```-T``@`[````'`$"`#<```!8
M`0(`.@```)`!`@`U````RP$"`#L````!`@(`0````#T"`@`X````?@("`#H`
M``"W`@(`.````/("`@`N````*P,"`$X```!:`P(`,0```*D#`@`V````VP,"
M`#P````2!`(`-P```$\$`@!,````AP0"`#@```#4!`(`/@````T%`@`U````
M3`4"`$````""!0(`/````,,%`@!)``````8"`#<```!*!@(`00```((&`@`P
M````Q`8"`&T```#U!@(`.@```&,'`@`_````G@<"`$4```#>!P(`1@```"0(
M`@!`````:P@"`#,```"L"`(`/0```.`(`@`W````'@D"`#(```!6"0(`.0``
M`(D)`@`1````PPD"`"````#5"0(`*@```/8)`@!$````(0H"`#````!F"@(`
M!P```)<*`@`/````GPH"``P```"O"@(`&0```+P*`@`;````U@H"`#P```#R
M"@(`(@```"\+`@`+````4@L"`'8!``!>"P(`&@```-4,`@`F````\`P"`!,`
M```7#0(`$P```"L-`@`7````/PT"`"P```!7#0(`'P```(0-`@`>````I`T"
M`$,```###0(`*`````<.`@`.````,`X"`'0````_#@(`'````+0.`@`@````
MT0X"``T```#R#@(`'``````/`@`7````'0\"`&$````U#P(`0@```)</`@`7
M````V@\"`!X```#R#P(`&````!$0`@!/````*A`"`!H```!Z$`(`&P```)40
M`@`K````L1`"`!$```#=$`(`-@```.\0`@`2````)A$"`!,````Y$0(`#@``
M`$T1`@`:````7!$"`!X```!W$0(`#@```)81`@!$````I1$"`!@```#J$0(`
M*`````,2`@`,````+!("`"<````Y$@(`#````&$2`@`(````;A("`!,```!W
M$@(`$P```(L2`@`@````GQ("``L```#`$@(`$0```,P2`@`3````WA("``T`
M``#R$@(`,@`````3`@`>````,Q,"`!<```!2$P(`%0```&H3`@`1````@!,"
M`!,```"2$P(`0P```*83`@`,````ZA,"``P```#W$P(`$`````04`@`6````
M%10"`#T````L%`(`"P```&H4`@`,````=A0"`!,```"#%`(`"@```)<4`@`1
M````HA0"`!D```"T%`(`%@```,X4`@`4````Y10"`!4```#Z%`(`6````!`5
M`@`C````:14"`"@```"-%0(`#P```+85`@!+````QA4"``8````2%@(`'```
M`!D6`@!1````-A8"`!,```"(%@(`$0```)P6`@`)````KA8"``0```"X%@(`
M!P```+T6`@`9````Q18"`"\```#?%@(`!P````\7`@`(````%Q<"``8````@
M%P(`&0```"<7`@`&````01<"`!8```!(%P(`%@```%\7`@!%````=A<"``4`
M``"\%P(`!````,(7`@`,````QQ<"``8```#4%P(`%0```-L7`@!T````\1<"
M`"D```!F&`(`8@```)`8`@!1````\Q@"`%,```!%&0(`<P```)D9`@`8````
M#1H"`+$````F&@(`20```-@:`@`Z````(AL"`$H```!=&P(`:````*@;`@`_
M````$1P"`#X```!1'`(`2@```)`<`@!:````VQP"`%H````V'0(`60```)$=
M`@!<````ZQT"`%$```!('@(`1P```)H>`@!*````XAX"`%8````M'P(`)```
M`(0?`@`@````J1\"`!4```#*'P(`O0```.`?`@`-````GB`"`,0```"L(`(`
MP@```'$A`@"Y````-"("`$P```#N(@(`D````#LC`@`Y````S","`!X````&
M)`(`%P```"4D`@"2````/20"`#8```#0)`(`?P````<E`@!^````AR4"`'X`
M```&)@(`20```(4F`@!A````SR8"`&,````Q)P(`;P```)4G`@#?````!2@"
M`&D```#E*`(`6P```$\I`@!I````JRD"`&8````5*@(`6````'PJ`@`Y````
MU2H"`#0````/*P(`/@```$0K`@"U````@RL"`"`````Y+`(`,0```%HL`@`6
M````C"P"`"D```"C+`(`,@```,TL`@`3`````"T"``P````4+0(``P```"$M
M`@`1````)2T"``T````W+0(`#P```$4M`@`,````52T"`!X```!B+0(`"```
M`($M`@`(````BBT"`"````"3+0(`$0```+0M`@`@````QBT"`!P```#G+0(`
M#@````0N`@`<````$RX"``X````P+@(`%@```#\N`@`@````5BX"``H```!W
M+@(`"````((N`@`A````BRX"`!$```"M+@(`$P```+\N`@`,````TRX"`!$`
M``#@+@(`%P```/(N`@`"````"B\"``0````-+P(`"@```!(O`@`(````'2\"
M`"0````F+P(`#````$LO`@`&````6"\"`!P```!?+P(`&````'PO`@`C````
ME2\"`"P```"Y+P(`!P```.8O`@`(````[B\"``H```#W+P(`"`````(P`@`9
M````"S`"``X````E,`(`%0```#0P`@!#````2C`"`$4```".,`(`$0```-0P
M`@`+````YC`"`!(```#R,`(`%P````4Q`@`"````'3$"``L````@,0(``0``
M`/T#````````\0$`````````````4`(```$&```M!0``1P4``+<```#2````
M9@,```````!A!0``V@````````#+!0``.@8```````!*!0``)@````0%``#*
M````H0$``$<"````````&`8`````````````>`$```````#-!0``LP(``'X#
M```R`0``O0```.,$``"O`@``U0$``(0#``!W`````04``'$`````````B@(`
M`"X!``!_`0``Z`,``#$#````````G0,``-D#``#>!```^0(``/8%```%`0``
MHP4``.@`````````=`4``*(!`````````````-,!```@!@``P`$``(\%``#$
M`@``CP$```````!)!````````-$"``#M!0```````%L!``!-`0```````&(#
M```\`0``0P```'T"``!?`````````!`$`````````````/`$````````*0,`
M`'<$````````004```````"#````W`(```````"%`P``-P0``/@%````````
M`````(T````Y`@``V````"\"``#;`P``Q0(``&4#``!\`P``WP(``.P%```2
M!``````````````N`@``"0$``(\"``#)`@```````'\```!,`0``3@,`````
M````````P`,`````````````408``'L"``"I`@````````````!E`0``````
M``````"A!````````%0!```>`0``JP0```````#P`0````````````!I````
M&@4``&L```"G`0``:@,``*X$``!&`P````````````#Z`P``"@(``,8#``">
M!```#0,``&<$``!K!0``2P0``!@!```'`@``;`,`````````````````````
M``#%!```X@(``+L$```B`P``*@,``$P%``#V````:`(``&L!```E!0``,0$`
M`*8#``!-````N0$```````"R`P``W00``($#``#U`0``.P0``#$`````````
M6`(``&D$``!X!```B`0``#H%``"L`P``&@```)D%``#O`0``:`$``$("```9
M!@``6@8``&X`````````70(``.8%````````^0```&0`````````(@0``'\"
M``"L`0``HP0``'(`````````=P$``)P%```,`@``R@$``)\%```F!```!`0`
M`$0!``"$!0```````+("``!"!@``=@4```````"K`P``K0$```````"!!```
M:@````````!4`P``-P$``````````````````&\$````!```?@0``"\$``!<
M`@``I`4`````````````B@0``&<!````````:`4``#T!``!I`0``9`$``%L`
M``!6`P```````,D```"N`0````````````!#`P``>@(``&<%```#`P``F0$`
M`+L````_``````````````#M````P0,````````D!0``BP(``.@$````````
M<0,```````#W`P``V04``!$%````````)P,``/\```#[`0``T0````````"Z
M`@``;0,``"\%``!A```````````````E!```;@$``&,"``"'!```3P0``/("
M``!O````7P$```L%``"I`````````/(!``!J`0``;@(``",%````````WP,`
M`%<#``!3`@``100``#8"``!#!0``P@$``&D#```V`P``*0(``!P$```B!0``
MR04```T"```0!0``T@,```````#.`0``BP```/0!``!8````K@```$4&````
M````008``!P```!Y`P``'@,``%D```#+`P``+0$```````"J`0``````````
M``#@!```V`0``!<&``"O````)`$``*\$````````5`(``*T````9`0``````
M`(,"``#I`0``-`0``#$%``!Z````2P8`````````````QP0``.0$```&!0``
M```````````Y!`````````@#``!)`P``&04``&H"``!H`P``_@,``!$$```]
M!@``RP0``,<!``#`!0``X`,``#H#``#,!0``1P```"(```!Z`P```````'4#
M``#T`@```````!T%```C!```P0````````!``0``800``%8"``#_!```*`,`
M``@&````````-00`````````````P@```&(%```G`0``/`````````#I`@``
M7P(````````L````,`4``$,"`````````````"8&``"X!0``+`,``#P$``!Q
M!```_@(```````"B!```Z@`````````E````70```,\!````````U@0``/X$
M``!R!```[P,``#$"``#&!``````````````^!```E@,``.L#``"5!```NP4`
M`````````````````"$"``"?`P``>04```X$``!+`0````,``!8%```4!0``
M$@,``*L!``!B`@``$0,`````````````J`$`````````````U04``.`%````
M````6`4``-(%````````X0(```D&```X!@``R`$````````#!@```````,(%
M``#U`@``D`(```````#=`@````$``+4#`````````````#H!``!L!```.`$`
M`.H"``#N!```N@4```X#``"-`P``Q`$``#<"``#:!```W`$``)\!````````
M_`$```````!-`P``Y`4``,\#``#L`0``-`4``"4!````````V@(``&8%``"'
M`@``@`4```````!^`@``"0```.L!``"1`0``"P````````#(!```KP$``#,!
M``#T!```F`$``*\%``!\`0``M`,``-$!``"<`P``G0$``"$```!@`@``````
M`'4!```0`@``YP$``!H$``!S`@``?@4``$$$````````W`0``,0````"!@``
MCP,``$T%``![!0```````(@%``#6!0``?0```(L$```7`P```````-L!``!.
M````E@(```P&``#Y!```B@$``'P"````````)`0```````"^`0``!`,``/T$
M```3!@``E`$```````#U````,`,```````#9!````````%@$``"`!```````
M````````````+00``/$$``##````,`$``,H"```<!@``_@$``+\%````````
MU00```````#/!```OP$```````"E`0``.@0````````W!@``?0$``/(#```)
M`P``C04``````````````````%0`````````Y@,```````#(`@``#@8`````
M```U`P``Q0,``'4```"G`P``)@,``!\&```F!0``J00``%(!``"*!0``10$`
M`.`"````````4P```*P%`````````````)D`````````L`,``%X"````````
M`````(@#``#I````Z`4``/8!``##`0``$P4``',#``"I`0``U0(`````````
M````2````,D#``!V````/P,``$@&``#=!0``7@4```P%```&!@``%`$``-8#
M````````O0$``/0#``!9`P``$`,``)X!````````.P,``+`%``#'````B@``
M`$8$````````%08``.8!````````.@(``*<"``#Z```````````&``!?`P``
M`P````````!*!@``!@$``.(`````````5`8```````!:!0``%@(``(8$````
M````=`,```````!@`P``U`4``#<```!<!0``BP,``#H```!#`0``8`0``)L!
M``"E````5P8``'0$``"&`@``8P0``*````"?!```4@0``-`$``!Z!0``@P$`
M``````#!!```$````$@#``"G!```ZP````````!I`@```````#@````_!@``
MT@0``/(%````````\0(```````!^`````````#4&``!1!```#P4``#P&```>
M!```4`4``+0!``!C`P``<0(``!D#``"K````'0,```````"5`@```0,``)`#
M``"V!0``+0```+X```".`````````,8%``"0!```1@$``-@!``"5`P``R```
M``L!```4````)P4``"\!``!X``````````````",`````````'H$``#;!0``
MZ04``(8%``#&`@``>`,``'D!`````````````"@!````````<@,``.T#```V
M!`````````````"4!```$08```````!!`0```````/D#``#\!0``G00``#,&
M``"Q`0````````````!:!```X00```4```"@`P``+`0``/@"``#7!0``TP,`
M`,X``````````````$<&```M`P``#P```'0```!U`@``+`4``)$#``!M!0``
M`````$0$``"@`@```````#<%``!1````C0(```````"Q````[00`````````
M````5@4```````#!`@```````"L&`````````````.T"```-!```]`4``!P%
M```>``````````````#_`0``>P$``#,#``!)````?@$``(0"``!O!0``!`8`
M`/<"``"7`@``300```<#``"F`0``RP$``,\"````````^P```#<#```.````
MPP0```,!``"1`@```````'@"``"\`@```````)(````]!```^`,``&P"``##
M!0``!@```-`"```C!@```````"X&``"H`@``!@,``)<%``#-````'`$`````
M```9`@``A`$``"X#```7!0``=`(``%("```[`0``2P``````````````R00`
M`"D!``!*`P``1P0```@```````````````````!/````DP,````````T`P``
M`````!L#````````U@$```D%``#J`0``K````$P#```P`@``,`0``'`$``!H
M````'@4``-(!```)!```F`4```````!J!0``@@4``,<#``#&````/@``````
M````````,P(```````#(!0``O0(``)0#```R`@```````*P"``!B`0``````
M``H```````````````````"X`0``9P(``+<$```I!@````````4&``!`````
M@04``(D!```*!```50````````!M````&P(```````!6!`````````````!5
M`@```````!\!``"3`@``<@4`````````````7@`````````?`P``#P$``.L%
M``"X`````````'8"``"D!```!@0``#0!``!,!@``%P$``(4````[````````
M`&,%``!$`P``J@(````````U````4P,``'T%``!@````L0(``%T$``";`P``
M`````.<%``"P````%0```&8!````````V0(``)H#``#>`@````````P$````
M````7P0```````#:`0``(0$``&8```!@!0``6P0``.H#```"`@``_P(``*X#
M``"B`P``*P(``-L"``"<!````````*D#```=`@``-``````````B`@``O```
M`#D&``#[!```D04````````N!0```````),$```*!@``;````!0"````````
MC`0``$L#``!"`P``A04``/4%```T`@``$0$``%P```!Y`@``2`$``/@!``#W
M`0``5P`````````L!@``!`````````"=`@``<`4```````"9!```;P(``"$#
M``"C`0``-0(``(<````4!```Y`(`````````````H@(``.$%``!]!```````
M`.8````1`@``?0,``)L$```Q!@``!P````````!Y!````````&H$````````
M50,``%,!``#<!0``J@0```````!W!0``DP```+,```""`0```````+`$``"F
M````6@$``-0```!F`@``!0,``$,&```'!0``EP``````````````$P$`````
M```O````S00```````#"!```V0```*4"``!O`P``"`(````````6````80(`
M``````#4`0``````````````````@0$``!X&``"<`````````#4!``#R!```
M70,```````!7!```N@0``-,$``"Z`0```````#($``!"!0````````````"(
M`````````"T&````````]0,``(X$``#1!0``O@(``/X```"+!0```````*,`
M``!M!````````&0#```2`0``EP,``$8&``#.!````````-`#```J!```<`(`
M``````"$!```G04`````````````.`0``.4"`````````````,\```!B````
M`````,L```"O`P``>`4``,``````````I`(``)4```"3`0```````"$$``#O
M`@```````,\%````````1P$``"4&``#7`0``N04``#X"``":!0```````,L"
M`````````````$0```"G!0``````````````````>P```+`!``#6````B0,`
M`"4#```%!`````````````!;`@``&P$``-L$```J!@``(P(``/8$``"_`@``
M`````(T$``#A`0``T`$``,H%```5!`````````4"``""`P``*``````````V
M!@```@0``$D%``">`@`````````````G!@``AP4``/$#```8`@``Z`(``$$`
M````````_`0````````]`@``O0,```````",`P``#0````````!H!```]@(`
M`*0#``#!!0``3@8``+<#```S````R@,``$\!````````@`,```````#=`0``
M#P8``*<`````````.`,``.(!```<`P``0`0``)@"````````D@4``/X%````
M````^@4```H!````````8P$``$D!``!,!```'@(```````"9`@``0`8``$X%
M``"S!```@0(``#(&``!2!@``>0```&($``!:`@``/`(``((`````````````
M``@$`````````````.L"```;!0``.0```/T%````````7@8`````````````
M`0$``%,%```6!@``YP(``(P!``"A````'00```````#\`@```````$L"````
M````P@(```````#&`0``(@8``"L%````````;0$```````"]!0``'08``+<!
M`````@``4`$````````D`P``U`,``!4"````````5@````X"``"W`@``WP4`
M``````#4`@``50$``/T!````````B`(``(X!``#P`P``40,``&0%``!_!0``
M508```````"V!````````%`&```%!0```````)8``````````````#,$````
M````#0$``'$%`````````P(``&X$``!2!0```````!8!``#C````M`4`````
M`````````````,X#``#%!0``Y````#8``````````````"`"````````#08`
M`/,#``!%`@``*`0```````!*````7`8```````!E!```\````$@%```_`0``
MD@(``!4!``#N`0``&`0``)H!```'!@``$P```%,$``"H`P``A00``$T&```0
M`0``<P```&$!``!!`@``VP```*T$````````4`0``(4"````````O`4``-$$
M`````````````&$#``#7`P``<0$``-,"``"?`@``V@4``)4%``".`P``P`0`
M``````!#!```)@(``"8!``!,`@``\P$``.,"``#J!```'`(``(D%```E`@``
M.`(```L#``!$!@``500`````````````4P8``!H#```5`P``2`0``.P"```!
M`@````````````!:````\P0``#\%```^!@``_````*T#````````L@4``,@#
M``"Z`P```````*4#``#B`P``D`````````##`P``*P0````````J`@``M@$`
M`!@#``#X!```A@````````"#!```Q`0```@%``#'!0``0`4``"`$````````
M^P(``%@!````````[@(``-\```!$!0``_0```!\$```L`@``S`0```````#Z
M!```A@,```````"7!```I@(``,4!``##`@``B`$``!T!``!<!```HP(``/<$
M``#Z`0````````````"!``````````````#F!```F@(``/D!```$`0``,@``
M``````"Q!```ZP0```````"K`@```````#0&``````````````````"<`@``
MF@0``%H#```A!0``/0,```````#B!```%P0``#P%``"T!```7@,``%<%```.
M`0````````````!W`P``*04````````'!````````!`&```J````5P$``'L$
M````````J@4``)@#``!9!0``/@,```````#C!0``M@(```````!(`@``````
M`#\$``#N!0``@@0``%\%```````````````````2!0``-@4``'H!``!/`@``
M#04``"L#```H!0````````````!_`P````````````!R`@``F@```/D%````
M````````````````````2P4``!8#```#!0```````"0```"Z````K@(``$<#
M``!8`P``M``````````2!@``[`,``.4#```[`@``]@,````````?````$P,`
M`),%````````N0,````````V`0``I`$``",````?`@``\0```+$%```Y`0``
M[@```&P%``"V`````````&0"````````&P8``$($``!?!@``600``!,"``"=
M`````````#\"```1````[`0```````!L`0```````#$$````````'0```&4%
M``!_!````````#4%````````D00```0"````````P`(``%8&````````````
M`)8!``#O`````````````````````````#X!``"-`0```````$4#``!V!```
M@````+,%``#E````&````!L$`````````````%X$``!P`P```````'8#``!E
M````H04``#````#M`0``NP(``%(`````````T`4``"\&``#J!0``O`,``*$"
M``"U!```B00``(<!````!0``F`0`````````````XP,``&`!````````````
M```````4`P``Q`4``.D$``!.`0``70$`````````````Y`,```````"'`P``
M#`$```````#,`P``#P0``````````````````/L%``!/`P``W@```-4#````
M````YP,``%T&``#8`@``208``#D#``"_`P``5@$`````````````2@$``%X!
M``!U!0``9@0``&4"``!;!0``XP$``)`!``"4```````````````J!0``````
M``````#\`P``F0,`````````````L`(```L&`````````````,$!``!T`0``
MLP,````````D`@``#````(0````)`@``S0(```(#``"^`P``FP```.8"``!1
M`0``P@,``)X#``"4`@``&P```%`#``!I!0``J`4``$`"`````````````+D"
M``#U!```YP```+4%````````00,`````````````````````````````J@,`
M``````#B!0``````````````````LP$```````!,````"`$`````````````
M\P```(X"````````^P,``+D$`````````````&\!`````````````+X$``"&
M`0``D@$``-D!``!"`````````(D````]!0``@P,``!<"```@!0``H`4```L"
M`````````````(`!``"T`@``Y00``+X%``#O!0```````+P!````````````
M`+4!```````````````````J`0``*P$``$H$``````````````````"%`0``
M`````-````"N!0``%@0``#X%```R!0``W0````\"```O`P``V@,``*D%``!<
M`P``:P0``'(!````````;@,``*,#``""`@``NP,``,X%``"Y`````@4``$\&
M```:`0``OP`````````\`P```````)<!````````E@0``!<```"2!```\@``
M````````````]P```$8`````````H@```-@#``#@`0``G`$``+<%``!=!0``
M6`8```<!```,`P``&`4``"T"```L`0``I`````````!S!0``40(``'<"````
M`````````(L!``"*`P``30(``+(!````````H`$``'L#``!&!0``=@$``$0"
M``"R!`````````````"8````10`````````"````W@$``,4```!P````60(`
M`.D#``!4!0``*`(``*T%```!!````````#@%``#6`@``<P$``)X%``"?````
M[`````L$``"E!```H`0``$D"```:`@``'P4``%<"``````````````````#8
M!0```````*(%``"K!0``K0(``*$#```H!@```````,<"`````````````)0%
M```Y!0``<P0```````"U````G@````````"J````$@```&<```")`@``3P4`
M`"<```"X`@``6P8````````N!```U0```.@!```G!```/0```#,%``#-`P``
M``````````#_!0```````,0#````````)`8``,H$````````Y`$``*4%````
M`````````&<#``#?`0``O00``%P!``".!0``404``,P````9!````````(,%
M``",!0```````!("``!2`P``S`(``.$```!\!0``NP$```````#S`@``O`0`
M`-,`````````@`(`````````````&0``````````````I@4````````@`0``
M`````-X%``!\``````````````"0!0```````$H"``"X`P````````````#T
M````[@,``*@$``````````````````#.`@``3@(``"(!``"R`````````/@`
M```&`@``;0(``/\#```@````&@8``!4%``#?!```"@,````````G`@``#@4`
M`-,%``#W!0``````````````````60$``-$#``!.!````````'`!```P!@``
M(08````````N````9`0``/,%```[!@``\`(``*8$``!9!@```````",!````
M````0`,``,D!``";`@``````````````````#P,``%````!K`@```````'4$
M````````C`(``+$#``!&`@``T@(```(!```#!```(`,``-<"``#@````*P``
M`-P````*!0``(P,``.\$``!C````?`0``&X%````````CP0``,T!``";!0``
MUP````````#>`P``:P,``"D````I!```UP0```````"_!```X0,``%L#````
M`````````%0$``"/````U`0``)$```"5`0``S`$``-P#````````Y04`````
M``#Z`@``M0(``*@````[!0``YP0``/$%``"6!0```````+@$````````Y0$`
M`-T#`````````````)(#```3!`````````````!"`0``%`8``/T"``"L!```
M,@,``+8#````````504``/`%``!%!0`````````@*"5S(&1A>7,@86=O*0`@
M*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R
M<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60@8GET97,@
M=W)I='1E;BX`)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M=&\M9&%T
M90`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@061M:6YI<W1R871I
M;VX`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@9&]E<R!N;W0@97AI<W0@;W(@:7,@;F]T(&5X96-U=&%B;&4N`"5S
M(&AA<R!C86YC96QL960@)7,N`"5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B
M=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N
M('1O("5S+@`E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M+@`E<R!I<R!N;W0@=W)I=&%B;&4N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L871I
M;VX@97AT<F%C="<@9FER<W0N`"5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S
M+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@=&\@861D('1O("5S+@`E<R!W
M:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N`"5S('=I<VAE<R!T;R!R
M96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N`"5S)W,@
M061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@
M5&%S:VQI<W0`)7,Z("5S`"5S.B!U;F%B;&4@=&\@;&]A9"!D<FEV97(Z("5S
M`"<E<R<@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`G)7,G(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`)R5S)R!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"X`)R5S)R!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN`"<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN`"<E<R<@=V%S(&YO="!C<F5A=&5D.B`E<RX`+"!G=7-T:6YG("5S("5S
M`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@
M1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M82!S:6=N960@;65S<V%G92X`041322!E<G)O<B`E<RX`04T@4F%I;@!!32!3
M:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!8F]U="!T:&ES(&5D:71O
M<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P="!R97%U97-T
M`$%C8V5P=&5D`$%C8V5S<R!$96YI960N`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT:6YG`$%C=&EO;G,`061D
M`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R
M93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI
M;&0@9W)O=7`@=&\@)R5S)P!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("<E
M<R<`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S
M`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A
M<@!!9&0@=&AI<R!T;R!M>2!C86QE;F1A<@!!9&0@=&\@861D<F5S<R!B;V]K
M.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("<E<R<@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`G)7,G('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG(&YE=R!F:6QE<R!T;R!R
M97!O<VET;W)Y.@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`
M061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!;&EA<P!!;&EG;@!!
M;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O
M=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT
M:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT
M97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`
M06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!
M;'1E<FYA=&4@=&5X=#H`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D
M+@!!;G-W97(`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A
M=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`
M07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE
M`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E("<E<R<@86YD(&%N>2!S=6(M9W)O=7!S/P!!<FUE
M;FEA;B`H05)-4T-)22TX*0!!<G0`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@
M8V]L=6UN<P!!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!R97!L>2!T
M;R!A(')E<75E<W0@>6]U('-E;G0`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<VAA<F4N`$%T=&5N9&5E<P!!='1R:6)U=&5S`$%U9W5S=`!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$)A
M8VME;F0@;F]T(&-O<G)E8W1L>2!I;7!L96UE;G1E9"X`0F%C:V=R;W5N9`!"
M86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME
M<F)E<F]S('5S97)N86UE+@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"87)E`$)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!"87-E;&EN
M90!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!"
M;&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)L;V-K('-E;&5C=&EO;@!";VQD
M`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!"
M;W1H`$)O='1O;0!"=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN
M`$)U:6QD:6YG(&QO8V%L92`E<RXN+B``0G5L;&5T960@3&ES=`!#35,`0U)#
M`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`
M0V%L96YD87(`0V%L;0!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!T:6]N`$-A
M=&5G;W)I97,@86YD($QA8F5L<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE
M<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z
M`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!0;VQI8VEE<P!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG
M92!087-S=V]R9`!#:&%N9V4@<&%S<W=O<F0@;VXZ`$-H86YG92!T:&4@;F%M
M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@
M86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V4@>6]U<B!P87-S=V]R
M9`!#:&%N9VEN9R!P87-S=V]R9"!O;B`E<P!#:&%R`$-H96-?:R!,:6YK+BXN
M`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P
M87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@86-T:6]N.@!#
M:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"X`0VQE86YI;F<@=7`@4$\@9FEL97,@9F]R(&UO9'5L
M92`E<RXN+@!#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@`$-L96%R`$-L96%R
M($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`
M0VQE87(@=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@
M=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO<@!#;VQO<B!0:6-K97(`
M0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#
M;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;6%N9"!O<'1I;VYS.@!#;VUM86YD
M<SH`0V]M;65N=`!#;VUM:71T:6YG.@!#;VUM;VX@3F%M90!#;VUP86YY`$-O
M;7!L971E9`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET
M:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@
M;F5E9',@=7!D871I;F<N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F9I<FT@;F5W('!A<W-W;W)D.@!#;VYN96-T:6]N(&9A:6QE9"X`0V]N
M;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`G)7,G
M`$-O;G1I;G5E`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'EI;F<@
M)7,@=&\@)7,`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L
M9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@)R5S)R!U
M<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C;W!Y("5S('1O("5S`$-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!C<F5A
M=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.@!#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S
M971U<"!U<&=R861E('-C<FEP="`G)7,G+@!#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2`G)7,G+@!#;W5L9"!N;W0@;6MD:7(@)R5S)RX`
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@9F]R
M('=R:71I;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+@!#;W5L9"!N
M;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"X`0V]U;&0@;F]T(')E860@)7,N
M`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`G)7,G+@!#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z("<E<R<N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@)7,`
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@
M=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,`
M0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@
M;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A
M=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#=7)R96YT(%!H
M87-E`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H
M97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE
M8W1I;VX`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A:6QY`$1A=&$`
M1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE
M8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M
M8F5R<P!$96-L:6YE9`!$96-R96%S92!);F1E;G0`1&5F875L="!#;VQO<@!$
M969A=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P
M97)M:7-S:6]N<P!$969I;FET:6]N<P!$96QE9V%T92!P;W-I=&EO;@!$96QE
M9V%T960`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES
M<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S971U<"!U
M<&=R861E('-C<FEP="`G)7,G+@!$96QI=F5R>2!T:6UE`$1E;GD@<F5Q=65S
M=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;@!$97-C
M<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO
M;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C
M=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$
M:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;@!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C
M;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O
M>#H`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U
M9W,`12U-86EL`$524@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET
M(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS
M(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O
M<B`E<P!%9&ET('!E<FUI<W-I;VYS(&9O<B`G)7,G`$5D=6-A=&EO;@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H
M92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R
M90!%;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E
M9"!C:&%N9V5D+"`E9"!U;FMN;W=N`$5R<F]R`$5R<F]R('-E;F1I;F<@9&%T
M82!T;R!S;6)P87-S=V0N`$5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+@!%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@)R5S)RX`17)R
M;W(Z(`!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M
M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y
M($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V
M86QU97,Z`$5X96-U=&4`17AE8W5T:6YG.@!%>'!A;F0`17AP86YD(%-I9&5B
M87(`17AP96-T960@)RDG`$5X<&ER871I;VX@1&%T90!%>'1R86-T:6YG(&9R
M;VT@)7,N+BX@`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O
M("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`
M1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O('9E<FEF>2!O;&0@
M<&%S<W=O<F0N`$9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,Z
M("5S`$9A:7(`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&97<@4VAO=V5R
M<P!&97<@4VYO=R!3:&]W97)S`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#
M;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E
M;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"X`1FEL=&5R<P!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO
M`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO
M<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M`$9O<F5C87-T("A4048I`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C
M=&]R:65S.@!&<@!&<F%M97,`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O
M0G5S>2!297!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S
M="!297-P;VYS90!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U
M;&P@36]O;@!&=6QL($YA;64`1G5Z>GD`1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VT`1V%L;&5R>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE
M<F%T960@0V]D90!'96YE<F%T:6YG('-T871U<R!F;W(@;6]D=6QE("5S+BXN
M`$=E=&]P="!%<G)O<CH@`$=I=F5N($YA;64`1V\`1V]O9VQE(%-E87)C:`!'
M<F%Y<V-A;&4`1W)E96L@*$E33RTX.#4Y+3<I`$=R;W5P($%D;6EN:7-T<F%T
M:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI
M<W-I;VYS`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!'=65S="!P97)M:7-S
M:6]N<P!'=65S=&)O;VL`2$@`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T
M(&9O=6YD+@!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96)R97<@*$E3
M3RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L
M<&5R`$AE;'!E<B!A<'!L:6-A=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN
M('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E"F9R86UE=V]R:R!A;F0@:71S
M(&%P<&QI8V%T:6]N<RX*1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H92!F
M:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R>2X`2&5M:7-P:&5R90!(97)E
M(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&ES=&]R>2!E
M;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!(;U]M90!(;VUE`$AO;64@
M061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO<F1E('1R86YS;&%T:6]N(&=E
M;F5R871O<@!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O
M=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY('-Y;F-H<F]N:7-E9"`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U
M;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U
M(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$E-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL
M960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S
M`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)7VYS97)T
M(%)O=R!"969O<F4`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET
M:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE
M9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)
M9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L
M;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V
M:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`
M26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R
M="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!087-S
M=V]R9`!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC
M<F5A<V4@26YD96YT`$EN9&EV:61U86P@57-E<G,`26YF;P!);F9O<FUA=&EO
M;@!);FET:6%L:7II;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O
M;7!O;F5N="X`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV
M86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T
M`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP
M:65N=#H@)R5S)P!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C
M92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ES
M;VQA=&5D(%0M4W1O<FUS`$ES<W5E<@!)=&%L:6,`2F%N=6%R>0!*87!A;F5S
M92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T
M:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@
M4FEG:'0`2V5E<"!O<FEG:6YA;#\`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D
M(&%U=&AE;G1I8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT
M`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+;W)E86X@*$55
M0RU+4BD`3&%?>6]U=`!,86YG=6%G90!,87-T($AA;&8`3&%S="!1=6%R=&5R
M`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87<`3&%Y;W5T`$QE9G0`3&5F
M="!H96%D97(`3&5F="!V86QU97,`3&EG:'0@1')I>GIL90!,:6=H="!286EN
M`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@
M4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG
M:'0@4VYO=R!3:&]W97(`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES
M="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M
M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I
M8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,;V%D
M:6YG(&QI8G)A<FEE<RXN+@!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A
M;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S
M:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,
M;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L
M871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`34T`34]41`!-4RU4
M3D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86=I8P!-
M86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86ME('-U<F4@=&AA="!Y
M;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A
M=&@N`$UA:VEN9R!D:7)E8W1O<GD@)7,`36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@
M;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I`$UA=&-H:6YG(&9I96QD<P!-87@@86QL;W=E9"!C
M<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU
M;2!L96YG=&@`36%Y`$UE9&EC:6YE`$UE971I;F<@0V%N8V5L;&%T:6]N`$UE
M971I;F<@26YF;W)M871I;VX`365E=&EN9R!0<F]P;W-A;`!-965T:6YG(%)E
M<&QY`$UE971I;F<@57!D871E`$UE971I;F<@57!D871E(%)E<75E<W0`365M
M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<F=I;F<@86QL("5S+G!O
M(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG(&QO8V%L92`E
M<RXN+B``365R9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E
M;F1I=6TN+BX@`$UE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO9'5L92`E<RXN
M+@!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D
M+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$UE=&AO9`!-971H;V0@)R5S)R!I<R!N;W0@9&5F:6YE
M9`!-971R:6,`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO
M=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R
M9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U
M<P!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`
M36ES<VEN9R!M97-S86=E($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-
M;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QE`$UO;G1H(&%N9"!Y96%R
M`$UO;G1H;'D`36]O;B!0:&%S97,`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U
M9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H
M=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0
M;W)T86P`37D@4&]R=&%L($QA>6]U=`!.3RP@22!$;R!.3U0@06=R964`3F%M
M90!.965D<R!!8W1I;VX`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P
M92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971W;W)K
M`$YE=F5R`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P
M=&EO;F%L*0!.97<@<&%S<W=O<F0Z`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="!086=E`$YE>'0@4&AA<V4`3F5X="!O
M<'1I;VYS`$YI9VAT`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@
M8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@
M;&5V96PN`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN`$YO(&-O;6UA;F0@<W!E8VEF:65D+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U
M<'!L:65D+@!.;R!E;G1R>2!W:71H('1H92!I9"`G)7,G(&5X:7-T<R!I;B!T
M:&4@;W)I9VEN86P@:&5L<"!F:6QE+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC
M;VYS(&9O=6YD+@!.;R!L;V-A;&4@<W!E8VEF:65D+@!.;R!L;V-A=&EO;B!I
M<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D
M+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO(')U;&5S`$YO('-I9&5S`$YO('-U8V@@8F%C:V5N
M9"`G)7,G(&9O=6YD+@!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!0
M87)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)
M4T\M.#@U.2TQ,"D`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W0@069T97(`3F]T
M($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@
M<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G
M;R!B86-K+@!.;W1I8V4`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R
M86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E
M<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N
M(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8FIE8W0@8W)E871O
M<B!P97)M:7-S:6]N<P!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F
M9FEC90!/;&0@<&%S<W=O<F0Z`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;F%L(%!A<G1I
M8VEP86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W!T:6]N<SH`3W)D97)E
M9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N
M:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@
M4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@5"U3=&]R;7,`4%](4"!3:&5L;`!0
M861D:6YG`%!A<G1L>2!#;&]U9'D`4&%S<W=D(&ES(&YO="!P<F]P97)L>2!C
M;VYF:6=U<F5D+@!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D(&]N("5S+@!0
M87-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@;6]D=6QE(&-A;B=T(&9I;F0@
M=&AE('-U<'!L:65D(&)I;BX`4&%S<W=O<F0@;6]D=6QE(&ES(&UI<W-I;F<@
M<F5Q=6ER960@<&%R86UE=&5R<RX`4&%S<W=O<F0@;6]D=6QE(&ES(&UI<W-I
M;F<@=&%R9V5T('!A<F%M971E<BX`4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P
M<F]P97)L>2!C;VYF:6=U<F5D`%!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O
M<&5R;'D@8V]N9FEG=7)E9"X`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E5
M4R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`
M4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A
M<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N("<E<R<@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N`%!E<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O<FUA=&EO;@!0971S
M`%!H;VYE`%!H;W1O<P!0:7AE;',`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C
M96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D
M('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5P;W)T(&%N>2!B
M=6=S('1O(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!0;&5A<V4@<F5V:65W('1H
M92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A
M8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('-E;&5C="!A;B!A
M8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.@!0;VQI=&EC<P!0;VQL<P!0;W-I=&EO;FEN9R!O
M9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T
M;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET
M871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S96YT
M871I;VYS`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S
M=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<`4')E=FEO=7,@4&%G90!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M
M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0
M<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG
M;W)I=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A
M9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@
M4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T
M=6YE`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;&%T
M:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M96UB97(@=&AE(&9R964O8G5S
M>2!I;F9O<FUA=&EO;BX`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO
M8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@9G)O
M;2!M>2!C86QE;F1A<@!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H
M90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U
M<V5R`%)E;6]V92!U<V5R.B`E<P!297!L>2!396YT+@!297!L>2!W:71H($YO
M="!3=7!P;W)T960@365S<V%G90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@
M;F5X="`R(&UO;G1H<RX`4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+@!297!L>3H@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A
M;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=6ER960@)R5S)R!N
M;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("<E
M<R<@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("=D<FEV97)S)R!I<R!M:7-C;VYF:6=U<F5D(&EN($-O;7!O<VET92!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE
M9"!I;B!087-S=V0@4U%,(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T
M>7!E)R!N;W0@<W!E8VEF:65D(&EN(%-13"!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"!&:65L9`!297%U:7)E9"!087)T:6-I<&%N=`!297-E=`!297-E="!0
M87-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5S=6QT<R`H
M:6YC;'5D:6YG($AO<F1E*3H`4F5S=6QT<SH`4F5T=7)N('1O($]P=&EO;G,`
M4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L
M=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O=&%T92`Q.#``4F]T871E
M($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T
M:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'D`4G5N`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H
M96QL`%-3`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%M92!F<F%M92`H
M7W-E;&8I`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/<'1I;VYS`%-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M("<E<R<N`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:&EN
M9R!(;W)D92!A<'!L:6-A=&EO;G,@:6X@)7,`4V5A<F-H:6YG(&=E='1E>'0@
M8FEN87)I97,N+BX`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T
M(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S
M97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M
M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!3
M96QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R
M;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z
M`%-E;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E;F0@4')O8FQE;2!297!O<G0`
M4V5N9"!335,`4V5N<V]R.B``4V5P=&5M8F5R`%-E<FEA;"!.=6UB97(`4V5S
M<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S
M:6)L92!W:71H('1H92!P87)A;65T97(Z(`!3:&]P<&EN9P!3:&]R="!3=6UM
M87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY
M`%-H;W=E<G,@3&%T90!3:')I;FL`4VEG;B!U<`!3:6=N('5P(&EF(&YO="!R
M96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I>F4`
M4VMI<"!-86EN=&5N86YC90!3:VEP<&5D+BXN`%-N;W<`4VYO=R!3:&]W97(`
M4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VYG<R`F(%!O96US`%-O<G0@
M;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($5U<F]P96%N
M("A)4T\M.#@U.2TS*0!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E
M96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D
M:6YG`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3
M<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3=&%N9&%R9`!3=&%R=`!3
M=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&%T=7,@9F]R
M(&QO8V%L92`E<RXN+B``4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`
M4W1R:6YG(&QI<W0`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("<E<R<@
M;F]T(&9O=6YD+@!3=6)J96-T`%-U8FIE8W0@4'5B;&EC($ME>2!);F9O`%-U
M8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@)R5S)R!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA
M<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@861D960@)R5S)R!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`G)7,G+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`G
M)7,G(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!U<&1A=&5D("<E<R<`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O
M4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`
M4W5P<&]R=`!3=7)N86UE`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`
M5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%R9V5T.@!487-K<P!496QE<&AO;F4@
M3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E
M<F%T=7)E.B``5&5M<&QA=&4@)R5S)R!N;W0@9F]U;F0N`%1E;7!L871E($%D
M;6EN:7-T<F%T:6]N`%1E;G1A=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A
M=&EV96QY($%C8V5P=&5D`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X
M='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%N:R!Y;W4@9F]R('5S:6YG('1H
M92!S>7-T96TN`%1H92`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H
M92`E<R!H96QP(&9I;&4@9F]R("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A
M=&EN9R!A(&YE=R!O;F4N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C86QE
M;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I
M;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&5V
M96YT(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N
M(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C
M875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@
M8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U
M;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V
M97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T
M:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E
M96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:&5L<"!F:6QE
M("5S(&1I9&XG="!S=&%R="!W:71H(#P_>&UL`%1H92!I9&5N=&ET>2`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@
M:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE
M(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E
M`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I
M>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE
M('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H
M87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E
M>&ES="X`5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES
M="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY
M`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U
M<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M`%1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F
M=6QL>2!S=&]R960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O
M(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E
M<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E
M<RX`5&AE<F4@9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S
M+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T
M96TN("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H
M92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG("<E<R<Z("5S`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N
M=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E
M=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!O
M<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP
M:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S
M(&9R;VT@=&AE('AM;"!P87)S97(N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI
M<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I;VX@:7,@;F]T
M('EE="!I;7!L96UE;G1E9"X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&ES("5S+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V-R:7!T(&UU
M<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN92X`5&AI<R!S97)V97(@
M8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES
M=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@
M5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&ET;&4`5&ET
M;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;VUO<G)O=P!4;W``5&]P(&9R86UE
M("A?=&]P*0!4<F%N<VQA=&5D`%1R86YS;&%T:6]N<P!4<G5E(&]R(&9A;'-E
M`%1U`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5
M+E8N(&EN9&5X.B``55),`%523#H`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92`G
M)7,G.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@
M=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET<P!5;FMN;W=N
M`%5N:VYO=VX@8V]M;6%N9#H@)7,`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R
M:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E
M('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N
M<VEO;@!5;G1R86YS;&%T960`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S
M<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`G)7,G+@!5<&1A
M=&EN9R`E<R!H96QP(&9I;&4@9F]R("5S+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<V%G93H`57-E($-U<G)E;G0Z("5S`%5S92!34TP`
M57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E
M<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97(@;F]T(&9O=6YD`%5S97(@;F]T(&9O=6YD+@!5<V5R('!E
M<FUI<W-I;VYS`%5S97)N86UE`%5S97)N86UE("<E<R<@86QR96%D>2!E>&ES
M=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S`%5S97)S(&EN('1H92!S
M>7-T96TZ`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N
M`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L
M=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S96QE
M8W0@9G)O;0!687)I86)L90!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T
M:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI
M9V@`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N
M86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W(&5V96YT`%9I97<@=&%S:P!6
M:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!705).24Y'(2$A(%)%34]612!30U))
M4%0@34%.54%,3%D@1E)/32`E<RX`5V%R;FEN9P!787)N:6YG.B``5V4`5V5A
M=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE
M<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H
M25-/+3@X-3DM,34I`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK
M:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7
M:6YD.B``5VES9&]M`%=I<VAL:7-T<P!7;W)K`%=O<FL@061D<F5S<P!7;W)K
M(%!H;VYE`%=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@)7,N`%E9`%E9
M65D`665A<FQY`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T
M(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO
M=2!C86XG="!C:&%N9V4@<&%S<W=O<F0@9F]R('5S97(@)7,`66]U(&1I9"!N
M;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA
M<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O
M<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@
M8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S
M="!G:79E('EO=7(@8W5R<F5N="!P87-S=V]R9`!9;W4@;75S="!G:79E('EO
M=7(@;F5W('!A<W-W;W)D`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@
M8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L
M96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP
M92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;75S="!V97)I9GD@>6]U<B!N
M97<@<&%S<W=O<F0`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ
M(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P
M<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO;B`K
M(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V
M97)S:6]N(&ES('1O;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA
M=&EV96QY+@I.;W0@86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!N97<@<&%S<W=O
M<F0@:7,@=&]O(&QO;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E(&UO<F4@=&AA
M;B`E9"!C:&%R86-T97)S(&QO;F<A`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O
M;R!S:6UP;&4@=&\@9W5E<W,A("!.;W0@8VAA;F=E9"$`66]U<B!N97<@<&%S
M<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G=65S<RX@3F]T(&-H86YG960A`%EO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@870@;&5A<W0@)60@8VAA<F%C=&5R
M<R!L;VYG(0!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&1I9F9E<F5N="!F
M<F]M('EO=7(@8W5R<F5N="!P87-S=V]R9`!9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%B971I8R!C:&%R86-T97)S
M+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@
M86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!D:69F97)E;G0@='EP97,@;V8@8VAA
M<F%C=&5R<RX@5&AE('1Y<&5S(&%R93H@;&]W97(L('5P<&5R+"!N=6UE<FEC
M+"!A;F0@<WEM8F]L<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN
M(&%T(&QE87-T("5D(&QO=V5R8V%S92!C:&%R86-T97)S+@!9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;G5M97)I8R!C:&%R
M86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@=7!P97)C87-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D
M(&UU<W0@8V]N=&%I;B!L97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T
M97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&YO="!C;VYT86EN('=H:71E
M<W!A8V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M
M871C:`!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M(:61E(%%U;W1E
M9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`
M6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=
M`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?
M1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO
M9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?
M4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5
M<V5R<P!A9&1R97-S(&)O;VL`86X@97)R;W(@:&%S(&]C8W5R960Z`&-A;&5N
M9&%R`&-A;&T`8VQI8VL@:&5R90!D;VYE`&9A:6QE9`!F:6QE`&9O=6YD.B``
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I,3AN`&EM;65D:6%T90!I
M;FQI;F4`;&1A<%]S=&%R=%]T;',@9F%I;&5D`&QI;F5S70!N86UE`&YO="!C
M:&%N9V5D`&YO="!F;W5N9`!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L
M96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I
M9F9E<F5N8V5S`'-T96%D>0!T87-K(&QI<W0`=&AE($AO<F1E(%!/(&9I;&4@
M9F]R('1H92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z`'1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5P9&%T
M960`=7-E<B!S96QE8W0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!087-S=V0@,R!!3%!(00I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TP-RTQ
M-"`Q,3HT."LP-#,P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#<M,#@@,3(Z
M-#4K,#0S,`I,87-T+51R86YS;&%T;W(Z($%M:7)K86)I<B!-971A;F5T=V]R
M:VEN9R!L=&0N(#QP97)S:6%N+6AO<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*
M3&%N9W5A9V4M5&5A;3H@4&5R<VEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U55$8M.`I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M"@`@*-BQV8C8LB#9@MBHV80@)7,I`"C:J=F$V8K8KR#8K]BSV*K8L=BSVXP@
M)7,I`"C8K]BQ("5S(-BQV8C8LBD`("C8I]F%V+'9B-BR*0`@*-F!V+'8K]BG
M*0`@*-BOV8K8L=F(V+(I`"#8K]BQ(``E9"`E<R#9B"`E<P`E9"#8J-BGV8K8
MJB#9AMF(V+38JMF'(-BTV*_9AR#8I]BSV*H`)60@V*?8LB`E9"#9B-BQV8C8
MK]N,(-BHV+G9AMF(V*?9AB#8J-F'(-BQV8C8LB#8M-BOV8<@V+G9A-BGV878
MJB#:K]BPV*?8L=N,(-BTV*_9A^*`C-BGV8;8KP#9OMF*V+0@V*C9BMF&VXP@
M)60MV+'9B-BRV8<`)7,@+2#8JMF(V*S9AP#9A=BOV8K8L=F*V*H@)7,`V*?8
MJ]BQ(-BGV8;:K]BTV*H@)7,`)7,@VJG9BMF$V8@@V*C8I]F*V*H`)7,@V+G9
MA=F$V8K8I]BJ(-F&VJ_9A]BOV*?8L=N,("T@V*K8H]F*V8K8KP`@V*K9AMBX
MV8K9A=BGV*H@)7,@`"5S(-F(V+'9B-BO`-BTV+'9B-BW(-BJV8C8I]F!V8(@
M)7,`)7,@V8?9A2#8I]JIV8;9B-F&(-F%V8C8K-F(V*\@V*?8L]BJ`"5S(-BO
MV+$@)7,@)7,`)7,@V879B-BLV8C8KR#9AMN,V+/8JB#9B"#;C-BG(-F"V*?8
MJ-F$(-BGV*S8L=BG(-F&VXS8L]BJ`"5S("5S(-BQV*<@V*C8I]BWV80@VJG8
ML=BO`"5S(-BHV8<@V8K:J2#8K]BQV*[9B-BGV+/8JB!F<F5E+V)U<WD@V;[8
MI]BSV*X@V*_8I]BOV8<@V*?8L]BJ`"5S(-BHV8<@V*_8N=F(V*H@)7,@V;[8
MI]BSV*X@V*_8I]BOV8<@V*?8L]BJ`"5S(-BGV+?9A-BGV+G8I]BJ(&9R964O
M8G5S>2#8L=BG(-BHV8<@V+39A=BG(-F!V+'8L]BJV*?8K]F'(-BGV+/8J@`E
M<R#9@MBGV*C9A"#9AMF(V+38JMF&(-F&V8K8L]BJ`"5S(-F%V8C8L=BO(-F&
MV8K8I]BR(-BGV+/8J@`E<R#8K]F"V8K9@MF'`"5S(-F^V8K8K]BG(-F&V+38
MKP`E<R#9OMF*V*_8IR#9AMBTV*\N)W1R86YS;&%T:6]N(&5X=')A8W0G(-BQ
MV*<@V*?8K-BQV*<@VJG9AMF*V*\@`"5S(-BGV+?9A-BGV+G8I]BJ(&9R964O
M8G5S>2#8M-F%V*<@V+'8IR#8K]BQV*[9B-BGV+/8JB#8K]BGV+'8KP`E<R#8
MK=BVV8C8L2#8M-F%V*<@V+'8IR#8K]BQ("5S(-BNV8C8I]BSV*K8I]BQ(-BG
MV+/8J@`E<R#8J-F'("5S(-BGV+(@)7,`)7,@V878I]F*V80@V*?8L]BJ(-BT
MV878IR#8L=BG(-BHV8<@)7,@V*?8MMBGV8'9AR#9AMF%V*?9BMBO`"5S(-F%
MV*?9BMF$(-BGV+/8JB#8M-F%V*<@V+'8IR#8I]BR("5S(-BBVJ_8I]F'(-BS
MV*?8LMBO`"5S(-F%V*?9BMF$(-BGV+/8JB#8HMBNV+'9BMF&(-BGV+?9A-BG
MV+G8I]BJ(-BQV*?8K-BY(-BHV8<@)7,@V+'8IR#8K]BQV8K8I]F!V*H@VJG9
MAMBO`-JIV*K8I]BHVH;9AR#8HMBOV+'8LR`E<P#8JMF"V8C9BMF%("5S`-F(
MV8K8L=BGV8K8M-JOV+$@)7,`V8'9A]BQV+/8JB#9B-BXV*?9BMF!("5S`"5S
M.B`E<P`E<SH@V8;9A=N,XH",V*K9B-BGV88@V+'8I]F'XH",V*?9AMBOV*?8
MLB#8L=BG(-BHV*?8L=JIV+'8KSH@)7,`)R5S)R#8I]F&V*K8KMBGV*@@V878
MN=BJV*C8L=N,(-F&V8K8L]BJ`"<E<R<@V*_8L2#9A]F(V+'8KR#9OMF*VJG8
ML=BHV8;8K]N,(-F&V+38K]F'(-BGV+/8J@`G)7,G(-F&V878I]F*V+0@V*_9
MA]F&V*_9AR#8K]BQV*[8JB#9OMF*V*_8IR#9AMBTV*\`)R5S)R#8J-F'(-JO
MV+'9B-F'XH",V8?8I]N,(-BSV8K8L]BJV84@V*?8MMBGV8'9AR#8M-BO`"<E
M<R<@V*C9AR#8L]F*V+/8JMF%(-BGV*S8I]BRV8<@V*_8L]BJV+'8L]N,(-BG
MV+;8I]F!V8<@V+38KP`G)7,G(-BGV8K8K-BGV*\@V8;8M-BO.B`E<RX`V(P@
MV*C8I]BO("5S("5S`-B,(-F%V*K8NMF*V8K8L2#8I]BR("5S(-BHV8<@)7,`
M(-BGV8;8JMBNV*?8J"``+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`-F"
MV*?9A-BH(#$R(-BSV*?8N=BJVXP`V8+8I]F$V*@@,C0@V+/8I]BYV*K;C`#;
MLMNT(-BSV*?8N=BJV8<`V8K:J2#8J-BGV8;:J2#8K]BGV*_9AR#8J-BQV*?;
MC"#8I]F*V88@V*C9A-BGVJD@V879B-BQV*\@V8;9BMBGV+(@V*?8L]BJ`-F*
MVJD@V*[8M]BGVXP@V879A]F%(-BQV*X@V*_8I]BOV8<@V*?8L]BJ`-F*VJD@
MVJG9A-F*V*\@V+G9A=F(V87;C"!01U`@V*C8L=BGVXP@V+'9A=BRVJG8L=BO
MV88@V8K:J2#9OMF*V+K8I]F%(-F%V8C8L=BO(-F&V8K8I]BR(-BGV+/8J@#9
MBMJI(-JIV839BMBO(-BYV879B-F%VXP@4$=0(-BHV+'8I]N,(-F(V*?8L=BS
MVXP@V8K:J2#9OMF*V+K8I]F%(-BGV878MMBGV*$@V+38K]F'(-F%V8C8L=BO
M(-F&V8K8I]BR(-BGV+/8J@#8KMBWV*?;C"!!1%-)("5S+@#8J-BGV+'8I]F&
M(-BUV*C8K=JOV*?9A]N,`-BQVJ_8J-BGV+$@V+78J-BMVJ_8I]F'VXP`V*K:
MK]BQVJ\@V+78J-BMVJ_8I]F'VXP`V+78J-BM+]BYV+78L0#8K]BQV*C8I]BQ
MV8<@V*?9BMF&(-F(V8K8L=BGV+/8JMBGV+$`V*_8L=BHV*?8L=F'+BXN`-F^
MV*?9BMF*V88@V878M]F$V8(`V8C8L]BW(-F%V+?9A-F"`-F^V+#9BMBQV8'8
MJMF&(-BOV+'8KMF(V*?8L]BJ`-F^V+#9BMBQV8'8JMF'(-BTV*\`V+G8K]F%
M(-BGV*S8I]BRV8?9E"#8K]BSV*K8L=BSVXPN`-BGV8K8K-BGV*\@VJG8M-F(
M(%9&4R#9A=BLV8C8LB#8K]BSV*K8L=BSVXP@V8;8K]BGV+'8KP#8I]F*V*S8
MI]BO(-F^V+'9B-F&V*_9AR!61E,@V878K-F(V+(@V*_8L]BJV+'8L]N,(-F&
MV*_8I]BQV*\`V+'9A=BRV+G8J-F(V+$@V*W8L]BGV*@`V*W8L]BGV*C8K]BG
MV+';C`#8N=F%V839BMBGV*H`V*?8MMBGV8'9AR#:J=BQV*_9A@#8I]BVV*?9
M@=F'(-JIV+'8K]F&(-JOV+'9B-F'(-F!V+'8N=N,`-BGV+;8I]F!V8<@VJG8
ML=BOV88@V*?8K-BGV++9AR#8K]BSV*K8L=BSVXP@V8'8L=BYVXSB@(P`V*?9
MBMF&V*S8IR#8I]BVV*?9@=F'(-JIV88Z`-BGV+;8I]F!V8<@VJG8L=BOV88@
MVJ_8L=F(V8<@V*S8K]F*V*\`V*?8MMBGV8'9AR#:J=BQV*_9AB#8I]BLV*?8
MLMF'(-BOV+/8JMBQV+/;C"#8K-BOV8K8KP#8I]BVV*?9@=F'(-JIV+'8K]F&
M(-F*VJD@VJ_8L=F(V8<@V8'8L=BYVXP@V*C9AR`G)7,G`-BGV+;8I]F!V8<@
MVJG8L=BOV88@V8K:J2#8I]BLV*?8LMF'(-BOV+/8JMBQV+/;C"#9@=BQV+G;
MC"#8J-F'("<E<R<`V*?8MMBGV8'9AR#:J=BQV*_9AB#9BMJI(-JIV*?8L=BH
MV+$@V*S8K]F*V*\Z`-BGV+;8I]F!V8<@VJG8L=BOV88@V+/8JMF(V88`V*?8
MMMBGV8'9AR#:J=BQV*_9AB#8I]BYV+;8I]N,(-BLV*_9BMBO`-BGV+;8I]F!
MV8<@VJG8L=BOV88@V8?8L2#8K]F(`"#8I]BVV*?9@=F'(-JIV+'8K]F&("5S
M(-BHV+G9AMF(V*?9AB#9AMF(V*?8L2#8K-BGV8;8J-N,(-F%V8C8LMF*V838
MIP#8I]BVV*?9@=F'(-JIV+'8K]F&(-BGV8K9AB#8J-F'(-BJV8+9B-F*V84@
MV879A@#8I]BVV*?9@=F'(-JIV+'8K]F&(-BHV8<@VJG8JMBGV*C:AMF'(-BB
MV*_8L=BS.@#8I]BVV*?9@=F'(-JIV+'8K]F&(-BHV8<@VJG8JMBGV*C:AMF'
M(-BBV*_8L=BS(-F%V88`V*?8MMBGV8'9AR#9@]BQV*_9AB#:J=BGV+'8J-BQ
M`"<E<R<@V*C9AR#8L]F*V+/8JMF%(-BGV+;8I]F!V8<@V+38K]B,(-BGV878
MIR#8I]BWV838I]BYV*?8JB#8K]F*VJ_8L2#8I]F!V*K8JMBGV*T@V*W8L]BG
MV*@@V*?8MMBGV8'9AR#9AMBTV*\`)R5S)R#8J-F'(-BSV8K8L]BJV84@V*?8
MMMBGV8'9AR#8M-BO+B#8M-F%V*<@V87;C.*`C-BJV8C8I]F&V8K8KR#8I]F$
MV*?9AB#9B-BGV+'8KR#8M-F(V8K8KP#8I]BVV*?9@=F'(-JIV+'8K]F&(-F^
MV+'9B-F&V*_9A^*`C-F'V*?;C"#8K-BOV8K8KR#8J-F'(-F%V*[8LMF&.@#8
MI]BVV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-F!V+G8I]F$(-F&
MV8K8L]BJ`-BBV*_8L=BS`-JIV*K8I]BHVH;9AR#8HMBOV+'8LR``V878K]F*
MV+$@V+/9BMBSV*K9A2T@V*K8N=F*V8K9AB#8I]BLV*?8LMF'XH",V8?8I]N,
M(-BOV+/8JMBQV+/;C"#8J-BQV*?;C"#:J=BGV+'8J-BQV*?9AB#8K]F*VJ_8
ML0#9A=BOV8K8L=F*V*H@V+/9BMBSV*K9A0#8JMBHV839BMBZV*?8J@#9A=BY
MV*?8K]F$`-BJV+'8I]BR(-JIV+'8K]F&`-BJV+'8I]BR.@#9A]F%V8<`V*K9
MA=BGV87;C"#:J=BGV+'8J-BQV*?9AB#8JMBCV8K9BMBO(-BUV838I]BMV8K8
MJB#8M-BOV8<`V8?9A=F'(-JOV+'9B-F'XH",V8?8IP#9A]F%V8<@V*?8K-BG
MV++9A^*`C-F'V*?;C"#8K]BSV*K8L=BSVXP`V*K9A=BGV879BB#:AMF'V*?8
ML2#8M]BQV8$`V*?8K-BGV++9AR#:AMF&V*\@V*+8K]BQV+/;C`#8HMF*V*<@
MV*?8K-BGV++9AR#8JMF&V+C9BMF%(-F&V8C8N2#9@=F'V+'8L]BJ(-F%V+'8
MJMBH(-BOV*?8K]F'(-BTV8C8K]B?`-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@
MV*?8L]BJ`-F(V+'9B-BO($E-4U`@V*S8I]F*VJ_8LMF*V88`V+'9A=BR(-BY
MV*C9B-BQ($E-4U`@V*S8I]F*VJ_8LMF*V88`V8;8I]F%(-JIV*?8L=BHV+';
MC"!)35-0(-BLV*?9BMJOV++9BMF&`-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8
MJMBQV8C9AMF*VJG;C"#8K-BGV8K:K]BRV8K9A@#8I]F$VJ_9B.*`C-F'V*?;
MC"#8K-BGV8K:K]BRV8K9A@#9A=BJV88@V*S8I]F*VJ_8LMF*V88Z`-F*VJD@
MV879@MBOV*?8L2#9AMBGV*_8L=BSV*H@V*K8N=F*V8K9AB#8M-BOV8<@V*C9
MB-BO`-F^V*?8L]BN`-BHV+'9AMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQ
MV*_;C`#9@=F'V+'8L]BJ(-BHV+'9AMBGV879AR#:J=BGV+'8J-BQV*_;C`#8
MJ-BQV8;8I]F%V8<@V*+9A=BGV*_9AR#8I]BSV*H`V*?8N=F%V*?9A"#8J-BQ
M(-BQV8C;C"#8I]BTV*K8L=BGVJGB@(S9A]BGVXP@V8'8L=BYVXP`V*K8M=F(
MV8K8J`#8HMF(V+'9BMF$`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0#8I]F&V*_8
MI]BRV8<@V;[8L=F(V8;8K]F'(-BBV+'8M-F*V8@`V8;8I]F%(-BBV+'8M-F*
MV8@`V*+9BMBG(-F%V+?9A=BFV8;9BMBO(-JIV8<@V87;C.*`C-BNV8C8I]F'
MV8K8KR#8I]BWV838I]BYV*?8JB#8K]BQV*[9B-BGV+/8JB#8K=BSV*?8J"`E
M<R#8L=BG(-F^V*?:J2#:J=F&V8K8K]B?`-BBV8K8IR#9A=BWV878IMF&V8K8
MKR#:J=F'(-F%VXSB@(S8KMF(V*?9A]F*V*\@)R5S)R#9B"#8JMF%V*?9A2#8
MLMF*V+$@VJ_8L=F(V8?B@(S9A]BGV8K8M"#8L=BG(-BMV+#9@2#:J=F&V8K8
MK]B?`$%R;65N:6%N("A!4DU30TE)+3@I`-F'V8;8L0#8HMF*V*<@V8+8J-F$
M(-BGV+(@V+G9A=F$V8K8I]BJ(-F&VJ_9A]BOV*?8L=N,(-BHV+'8I]N,(-BJ
MV*?9BMF*V*\@V*+9AB#8L]BFV8C8I]F$(-BTV8C8K]B?(`#8I]F&V*K8L]BG
MV*@@V+/8JMF(V88`V+;9A=F*V879A]B,(-F^V*?8L]BN(-BHV8<@V*_8L=BN
MV8C8I]BSV*H@V*K9@MF(V8K9A=N,(-BGV+/8JB#:J=F'(-BTV878IR#9@=BQ
MV+/8JMBGV*_9AR#8J-F(V*_9BMBO`-BSV+G;C"#8K]BQ(-BMV+#9@2#:K]BQ
MV8C9A]N,(-BTV*_9AR#:J=F'(-F%V8C8K-F(V*\@V8;9BMBSV*H`V+/8N=N,
M(-BOV+$@V*W8L-F!(-F*VJD@V*?8K-BGV++9AR#8K]BSV*K8L=BSVXP@V+38
MK]F'(-JIV8<@V879B-BLV8C8KR#9AMF*V+/8J@#8L]BYVXP@V*_8L2#9B-F*
MV+'8I]F*V+0@V8K:J2#8I]BLV*?8LMF'(-BOV+/8JMBQV+/;C"#8M-BOV8<@
MVJG9AR#9A=F(V*S9B-BO(-F&V8K8L]BJ`-BSV+G;C"#8K]BQ(-F(V8K8L=BG
MV8K8M"#9BMJI(-BGV+38JMBQV*?:J=N,(-BTV*_9AR#:J=F'(-F%V8C8K-F(
MV*\@V8;9BMBSV*H`V+38L=JIV*H@VJG9AMF&V*_:K]BGV88`XH",V8C9BMJ8
MVJ_;C.*`C-F'V*<`V*+:K]F(V+/8J@!!=71H7V-Y<G-Q;#H@V*C8L]BW(-F%
MV8C8L=BO(-F&V8K8I]BR($E-05`@V;[9BMBOV*<@V8;8M-BO`$%U=&A?8WER
M<W%L.B#9OMBS(-BRV879BMF&V8<@V*K9B-BGV8;8I]F*VXSB@(S9A]BGVXP@
MV879B-BQV*\@V8;9BMBGV+(@V+'8IR#9AMBOV*?8L=BO`$%U=&AI;7`Z(-BH
MV+/8MR#9A=F(V+'8KR#9AMF*V*?8LB!)34%0(-F^V8K8K]BG(-F&V+38KP!!
M=71H7V9T<#H@V*C8L]BW(-F%V8C8L=BO(-F&V8K8I]BR($944"#9OMF*V*_8
MIR#9AMBTV*\`075T:%]I;7`Z(-BHV+/8MR#9A=F(V+'8KR#9AMF*V*?8LB!)
M34%0(-F^V8K8K]BG(-F&V+38KP!!=71H7VMR8C4Z(-BHV+/8MR#9A=F(V+'8
MKR#9AMF*V*?8LB!K<F(U(-F^V8K8K]BG(-F&V+38KP!!=71H7VQD87`Z(-BH
MV+/8MR#9A=F(V+'8KR#9AMF*V*?8LB!,1$%0(-F^V8K8K]BG(-F&V+38KP!!
M=71H7VQD87`ZV*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQ("#8J-F'
M("5S(-F%V8+8K]F(V+$@V8;9BMBSV*H@+B#8I]F*V88@VH;9BMBRVXP@V*?8
ML]BJ(-JIV8<@V+/8L=F(V+$@VJ_9@=BJV8<@V*?8L]BJ`$%U=&A?;&1A<#K8
MK=BPV8$@VJG8I]BQV*C8L2`E<R#9A=F"V*_9B-BQ(-F&V8K8L]BJ(`!!=71H
M7VQD87`ZV*C9AR#8L=F(V+(@V*+9B-BQVXP@VJG8I]BQV*C8L2`E<R#9A=F"
MV*_9B-BQ(-F&V8K8L]BJ`$%U=&A?;6-A;#H@V*C8L]BW(-F%V8C8L=BO(-F&
MV8K8I]BR($U#04P@V;[9BMBOV*<@V8;8M-BO`$%U=&A?<VUB875T:#H@V*C8
ML]BW(-F%V8C8L=BO(-F&V8K8I]BR('-M8F%U=&@@V;[9BMBOV*<@V8;8M-BO
M`-BGV*W8L=BGV+(@V8?9B-F*V*H@V+79B-BQV*H@V8;:K]BQV8'8J@#8I]BM
MV+'8I]BR(-F'V8C9BMBJ(-BUV8C8L=BJ(-F&VJ_8L=F!V*HN("5S`-BGV*W8
ML=BGV+(@V8?9B-F*V*H@V*?8LB#8M]BQV8$@V+/8L=F(V+$@4D%$2553(-BH
MV+':K]BTV*H@V*_8I]BOV8<@V+38KP#8I]BMV+'8I]BR(-F'V8C9BMBJ(-BO
MV+$@V+/8L=F(V+$@1E10V*?9AMBLV*?9A2#9AMBTV*\`V8'9BMF$V*_9A]BG
MVXP@V8+8I]BHV80@V*_8L]BJV+'8L]N,.@#9A=F&V*K8N-BQ(-F^V*?8L]BN
M`-F^V+38JMN,V*C8I]F&(-BHV8<@V*_8L=BSV*K;C"#9OMN,V*?8K]F'XH",
MV+/8I]BRVXP@V8;8M-BOV8?B@(S8I]BSV*HN`-F^V+,@V++9A=F*V8;9AP#8
ML=F&VJ\@V;[8LR#8LMF%V8K9AMF'`-BQV878LB#8N=BHV8C8L2#9AMBGV*_8
ML=BSV*H@:V5R8F5R;W,`V8;8I]F%(-JIV*?8L=BHV+';C"#9AMBGV*_8L=BS
MV*H@:V5R8F5R;W,`0F%L=&EC("A)4T\M.#@U.2TQ,RD`V*C8L=F'V8;9AP#8
MJ-BQ(-BGV+/8I]BS(-JIV+39B"#:K]BQV*?9@=F*VJG;C"`G)7,G(-F*V*?9
M@=BJ(-F&V+38KP#8KMBW(-BTV+'9B-BY`-BHV839B-JI("(E<R(@V*?8LB#8
MJ-BQV8;8I]F%V8<@VJG8I]BQV*C8L=BOVXP@(B5S(B#9BMBGV8'8JB#9AMBT
MV*\`V*K9AMBXV8K9A=BGV*H@V*C9A-F(VJD`V8;9B-BY(-BHV839B-JI`-BG
MV8;8JMBNV*?8J"#8J-F$V8C:J0#8L]F*V*?9AP#:AMF(V*@@V*?9A-F!`-F$
MV*C9AP#9OMF'V8;8I]N,(-F$V*C9ASH`V838J-F'XH",V8?8IP#9A]BQ(-BO
MV8@`V;[8I]F*V8K9A@#8L]BGV*[8JMF&(-F^V+'9B-F&V*_9A^*`C-F'V*?;
MC"!-3R#8J-BQV*?;C"#9@MBSV878JB`E<RXN+B``V+/8I]BNV*K9AB#9A=BM
MV839BMBJ("5S+BXN`-F$V8K8L]BJ(-BHV8C9A-BJ(-BOV*?8L0!#35,`0U)#
M`-F&V8+8I]BW(-BJV8C8LMF*V+D@0U),`-F(V8K:F-F'(-JOV8K9A]BGVXP@
MV+/9A-F(V80N+BX`V*K9@MF(V8K9A0#8HMBQV*?9A0#9AMF%VXSB@(S8JMF(
MV*?9AB#8L=F%V+(@V+G8J-F(V+$@V+'8IR#8J-BWV8C8L2#8KMF(V*_:J=BG
MV+$@V*_9B-BHV*?8L=F'(-BQV*?9A^*`C-BGV8;8K]BGV++;C"#:J=BQV*_8
MC"#8J-BG(-F%V*_9BMBQ(-BSV8K8L]BJV84@V*[9B-BO(-BJV878I]BS(-BH
MVJ_9BMBQV8K8KP#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-BSV+'9B-BQ(-F^
MV+/8JB#8I]F$VJG8JMBQV8C9AMF*VJD@V8C8M=F$(-BTV*\Z("5S`-BGV8;8
MM=BQV*?9@0#8I]F&V+78L=BGV8$@V*?8LB#8I]BQV+/8I]F$(-JOV++8I]BQ
MV+0`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(-BQV*<@V*W8L-F!
M(-JIV+'8KR`B)7,B("X`V8;9A=N,XH",V*K9B-BGV88@V8K:J2#:J=BTV8@@
MV879B-F"V*H@V;[9BMBOV*<@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-BH
MV*_9B-F&(-F^V*?8L=BGV878JMBQ("?9OMBQV8C9AMBOV8<@V879@MBUV*\G
M(-BGV*_8I]F%V8<@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-JIV+39B"#8
ML=BG(-BMV+#9@2#:J=BQV*\@(B5S(BX`V8;9A=N,XH",V*K9B-BGV88@V*W8
ML-F!(-F&V879B-BOV(P@)60@V8'8L=BRV8;8KR#9A=F(V*S9B-BO(-BGV+/8
MJ@#9AMF%VXSB@(S8JMF(V*?9AB#8K]F(V*C8I]BQV8<@V878L=BJV*@@V8;9
MA=F(V*\@V(P@V*C8L=BNVXP@V*?8LB#9B-BQV8C8K]N,XH",V8?8I]N,(-F!
MV+'8I]F'V84@V+38K]F'(-BHV+'8I]N,(-F%V+'8JMBH(-BSV*?8LMN,(-BH
MV*<@V+39A=BGV+'9A^*`C-F'V*<@V+/8I]BRVJ_8I]BQ(-F&V8K8L]BJV8;8
MKP#9AMF%VXSB@(S8JMF(V*?9AB#9OMF*V+K8I]F%(-BQV*<@V*C9AR#8M-F%
MV*?8L=F'(-BJV+G9BMF*V88@V+38K]F'(-BGV+'8L]BGV80@VJG8L=BO`-BY
MV8;9B-BGV88`V*_8L]BJV8?B@(S9A]BG(-F((-BHV+':AMBSV*CB@(S9A]BG
M`-F%V8C8J-BGV8K9A`#9B-F*VIC:K]F*V8?8I]N,(-BSV839B-F$`-F!V*?8
MM=F$V8<@V+/9A-F(V80`V8C9BMJ8VJ_9BMF'V*?;C"#8L]F$V8C9A`#9@=BG
MV+79A-F'(-BSV839B-F$`-F%V8C8J-BGV8K9A`!#96QT:6,@*$E33RTX.#4Y
M+3$T*0#9A=BQVJG8L@!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0#8
MJMBUV*_9BMF"(-BLV++8IMF*V*?8J@#8L]F*V*?8L]BJV8?8I]N,(-BJV+78
MK]F*V8(`V878K]F*V+$`V*K8NMF*V8K8L2``V*K8NMN,VXS8L2#8I]BSV84@
MV+'9A=BR`-BJV+K;C-N,V+$@V*?8L]F%(-BQV878LB#8J-BQ(-BQV8C;C#H`
MV*K8NMF*V8K8L=BOV*?8K]F&(-F&V*?9A2#9B"#8HMBOV+'8L]N,(-JIV8<@
MV*?9@=BQV*?8KR#9A]F&VJ_8I]F%(-BNV8C8I]F&V*_9AB#9B"#9OMBGV+/8
MKB#8K]BGV*_9AB#8J-F'(-F&V*?9A=F'(-BTV878IR#8KMF(V*?9A]F&V*\@
MV*_9BMBO`-BGV+/9A2#8L=F%V+(@V*[9B-BO(-BQV*<@V*K8NMN,VXS8L2#8
MK]F'VXS8KP#8JMBZVXS;C-BQ(-BGV+/9A2#8L=F%V+(@V*C8L2#8L=F(VXP@
M)7,`V8;9B-F*V+/9AP#8J-BQV+'8L]N,(-F^V8K9B-F&V*\N+BX`V*S8N=BH
MV8<@V8?8L2#8N=F%V839BMBGV*K;C"#8L=BG(-JIV8<@V8?9A2#8I]JIV8;9
MB-F&(-F%V8KB@(S8KMF(V*?9A]F*V*\@V*?8K-BQV*<@VJG9AMF*V*\@V+G9
MA-BGV878JB#8J-BRV8;9BMBO`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0#8I]F&V*K8KMBGV*@@V8K:
MJ2#8L=F%V+(@V+G8J-F(V+$`V*?9AMBJV*[8I]BH(-F*VJD@V8;8I]F%(-JI
MV*?8L=BHV+';C`#8I]F&V*K8KMBGV*@@V8K:J2#9@=BYV*?9A-F*V*HZ`-BG
MV8;8JMBNV*?8J"#:AMJOV8C9AMJOVXP@V8;9A=BGV8K8M"#8JMBGV+'9BMBN
M.@#8I]F&V*K8KMBGV*@@V8;9B-BY(-BSV*C:J2#9@=F'V+'8L]BJ("C8J-BQ
MV*?;C"#9@=F'V+'8L]BJXH",V8?8I]N,(-F%V+'8JMBH*0#:J=F$V*?8LR#8
MJMBYV+'9BMF!(-BTV*_9AR#8J-BQV*?;C"`E<R#9BMBGV8'8JB#9AMBTV*\`
MV++8K]F(V*_9AB#9OMBQV8C9AMBOV8?B@(SB@(S9A]BGVXP@4$\@V*C8L=BG
MVXP@V8+8L]F%V*H@)7,N+BX`V++8K]F(V*_9AB#9A=BMV80@)7,N+BX`V;[8
MI]JI(`#9OMBGVJD@VJG8L=BOV88@V*K:K^*`C-F'V*?;C"!-4T]F9FEC90#8
MK=BPV8$@VJG8I]BQV*C8L2#8J-F*V+'9B-F&VXPZ("5S`-F^V*?:J2#:J=BQ
MV*_9AB#:J=BGV+'8J-BQ`-F^V*?:J2#:J=BQV*_9AB#8K]BGV*_9AR#:J=BG
MV+'8J-BQ`-BHV+'8I]N,(-BGV*_8I]F%V8?8C"#:J=F$V8K:J2#:J=F&V8K8
MKP!#;&EC:V%T96QL(-BGV+(@V+?8L=F*V8(@2%144`#8J-BSV*K9AB#9OMF&
MV*S8L=F'`-BGV*C8L=F'V*<`V*?8J-BQVXP`V*S9A=BY(-BTV*_9AB#9AMF(
MV*?8L2#:J=F&V*?8L=N,`-J&V878N2#8M-BOV88@V838J-F'XH",V8?8IP#8
ML=F&VJ\`V*?9AMBJV*[8I]BH(-JIV8;9AMBOV8<@V+'9AMJO`-BGV8;8JMBN
MV*?8J"#8L=F&VJ\`V+/8JMF(V8;9A]BG.@#8N=F&V8C8I]F&(-BSV*K9B-F&
M`-F%V+;8K=JI`-BOV+/8JMF(V+'8I]F$V+G9A=F$`-BNV+<@V*_8L]BJV8C8
ML0#:K]BRV8K9AMF'XH",V8?8I]N,(-BOV+/8JMF(V+'8I]F$V+G9A=F$.@`Z
MV*_8L]BJV8C8L=BGV838N=F%V83B@(S9A]BG`-BJV8C8MMF*V*T`V*K8H]F*
MV8K8KR#:J=BQV*_9ACH`V8;8I]F%(-BYV879B-F%VXP`V+38L=JIV*H`VJG8
MI]F%V80@V+38KP#8I]F*V*S8I]BO(-F^V8K8NMBGV84@*"5S*0#8L=BGV8K8
MI]F&V8?B@(S9A]BG`-BTV+'8I]F*V+<`V*K9@=BGV8C8JN*`C-F'V*?;C"#9
MOMF*VJG8L=BHV8;8K]N,`-F^V8K:J=BQV*C9AMBOVXP@V*C9AR#8J-F'(-BQ
MV8C8LB#8M-BOV88@V8;9BMBGV+(@V*_8I]BQV*\`V;[9BMJIV+'8J-F&V*_;
MC"`E<P#8JMBCV8K9BMBO(-BQV878LB#8N=BHV8C8L0#8JMBCVXS;C-BO(-BG
MV+/9A2#8L=F%V+(@V*S8K]N,V*\Z`-BGV*K8M=BGV80@V*C9AR#8L]BQV8C8
ML2#8I]F&V*S8I]F%(-F&V+38KP#8I]BJV+78I]F$(-BHV8<@V+/8L=F(V+$@
MV*?9AMBLV*?9A2#9AMBTV*\`V*?8L=BJV*C8I]BW(-BHV*<@V+/8L=F(V+$@
MVJG9A-F*V*\@V+G9A=F(V87;C"#9A=F*V+/8L2#9AMBTV*\`V*?8L=BJV*C8
MI]BW(-BHV*<@V+/8L=F(V+$@VJG9A-F*V*\@V+G9A=F(V87;C"#9A=F*V+/8
ML2#9AMBTV*\N(-BOV839BMF$.B`E<R`H)7,I`-BGV*K8M=BGV80@V*C9AR#8
ML]BQV8C8L2!&5%#8I]F&V*S8I]F%(-F&V+38KP#8JMF%V*?8LR#8J-BG(-F%
MV8C9@=F"V8K8JB#8J-F'(-JIV*K8I]BHVH;9AR#8HMBOV+'8LR#8I]BVV*?9
M@=F'(-BTV*\`V878K=BJV8C8I]N,("<E<R<@`-BGV*_8I]F%V8<@V*_8I]BO
MV88`VJG9B-JIVXP`V*K9A]F*V8<@V+'9B-F&V8C8M-BJ`-BJV8?9BMF'(-BQ
MV8C9AMF(V+38JB#8I]BR(-BGV8;8JMBNV*?8J.*`C-F'V*<`VJG9OMN,(-JI
MV+'8K]F&("5S(-BOV+$@)7,`V8;9A=N,XH",V*K9B-BGV8;8KR#9OMF*V+K8
MI]F%(-BQV*<@V+'9A=BR(-JIV8;8KR!01U``V8;9A=N,XH",V*K9B-BGV8;8
MKR#9OMF*V+K8I]F%(-BQV*<@V*?9A=BVV*<@VJG9AMBO(%!'4`#9AMF%VXSB
M@(S8JMF(V*?9AMBO(-F^V8K8NMBGV84@V+'8IR#8L=F%V+(@VJ_8M-BGV8K;
MC"#:J=F&V*\@4R]-24U%`-F&V87;C.*`C-BJV8C8I]F&V*\@V;[9BMBZV*?9
MA2#8L=BG(-BGV878MMBG(-JIV8;8KR!3+TU)344`V8;9A=N,XH",V*K9B-BG
MV88@V*?8JMBUV*?9A-BGV*H@V+'8IR#8I]BVV*?9@=F'(-JIV+'8KR`E<P#9
MAMF%VXSB@(S8JMF(V*?9AB#8J-F'(-BSV+'9B-BQ($Q$05`@V;[9BMF(V+/8
MJB``V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@;&1A<"#9
MOMN,V8C8L]BJ`-F&V87;C.*`C-BJV8C8I]F&(-BHV*?9A-BGV8;8LR#8L=BG
M(-J&VJD@VJG8L=BO("5S`-F&V87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQ
MV+/8I]BR(&QD87`@V878JMBUV80@V+38KP#9AMF%VXSB@(S8JMF(V*?9AB#8
MJ-BG(-BGV+/8JMF!V*?8K]F'(-BGV+(@1E10V*C9AR#8L]BQV8C8L2`G)7,G
M(-F(V+79A"#8M-BO.B`E<P#9AMF%VXSB@(S8JMF(V*?9AB`E<R#8L=BG(-BO
MV+$@)7,@VJG9OMN,(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8
ML]BJ(-BJV8C8LMF*V+G;C"#8I]F*V*S8I]BO(-JIV+'8KSH`V8;9A=N,XH",
MV*K9B-BGV88@VJG8M-F(VXP@V878K=F$V8K8JB#8J-BQV*?;C"#9A=BMV839
MBMBJ("5S(-BGV8K8K-BGV*\@VJG8L=BO.@#9AMF%VXSB@(S8JMF(V*?9AB#8
MK]BGV*_9AR!01U`@V+'8IR#8L=F%V++:K]BTV*?9BMN,(-F&V879B-BO(`#9
MAMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR!3+TU)344@V+'8IR#8L=F%V++:
MK]BTV*?9BMN,(-F&V879B-BO(`#9AMF%VXSB@(S8JMF(V*?9AB#8I]BJV+78
MI]F$(-BQV*<@V*W8L-F!(-F&V879B-BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9
MAB#9@=F'V+'8L]BJ(-BJV8C8LMF*V+G;C"#8L=BG(-BMV+#9@2#9AMF%V8C8
MKRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V*?8L]JIV+'9BMF^V*H@V*C9AR#8
ML=F(V+(@V+'8L]BGV8;;C"#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@V+'8IR#8
MK=BPV8$@V8;9A=F(V*\@)R5S)RX`V8;9A=N,XH",V*K9B-BGV88@V*+8K]BQ
MV+,@V8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;9BMJIVXP@V8K8I]F!V*K9AR#8
MM-BOV8<@V+'8IR#8JMBTV*[9BMBU(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9
MAB#:J=F$(-JIV*K8I]BHVH;9AR#8HMBOV+'8LR#8L=BG(-F(V*?:J=BTVXP@
MV8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@VJG9A"#9@=F'V+'8L]BJ(-BJ
MV8C8LMF*V+G;C"#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\`V8;9A=N,XH",
MV*K9B-BGV88@V8'9A]BQV+/8JB#:J=BGV879A"#9@=F'V+'8L]BJ(-BJV8C8
MLMF*V+G;C"#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\`V8;9A=N,XH",V*K9
MB-BGV88@V*?8L]BJV+'8I]BJVIC;C"#8L=BG(-BHV*?8L2#:J=BQV*\@)R5S
M)P#9AMF%VXSB@(S8JMF(V*?9AB#:J=BTV8@@V*?9BMBLV*?8KR#:J=BQV*\@
M)R5S)P#9AMF%VXSB@(S8JMF(V*?9AB#:J=F$V8K8KR#8N=F%V8C9A=N,(-BQ
MV*<@V*?8LB#8L]BQV8C8L2#:J=F$V8K8KR#8K]BQV8K8I]F!V*H@V8;9A=F(
MV*\`V8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8J-BGV+(@VJG8L=BO`-F&
MV87;C.*`C-BJV8C8I]F&("<E<R<@V+'8IR#8J-BQV*?;C"#9AMF(V+38JMF&
M(-BHV*?8LB#:J=BQV*\@`-F&V87;C.*`C-BJV8C8I]F&(-F%V*_9B-F$(-BY
MV879A-F*V*?8JB#9AMJOV8?8K]BGV+';C"`E<R#8L=BG(-BHV*?8LB#9AMF%
MV8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=BTV8@@)R5S)R#8L=BG(-BHV*?8
MLB#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8L=BGV8?;C"#8J-F'('-M
M8G!A<W-W9"#8J-BGV+(@VJG8L=BO+@#9AMF%VXSB@(S8JMF(V*?9AB`E<R#8
ML=BG(-BOV+$@)7,@VJG9OMN,(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#8
ML=F%V++8N=BHV8C8L2#8L=BG(-BHV+'8I]N,(-JIV*?8L=BHV+$@V879B-BQ
MV*\@V8;8N-BQ(-F%V*S8K]BOV*?9BR#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@
MVJG8L=BO+B#8J-BYV+;;C"#9BMBG(-F'V879AR#8K-BRV*;9BMBGV*H@V878
ML=BHV8C8MR#8J-F'(-BBV88@V8;8I]BOV+'8L]BJ(-F%VXSB@(S8J-BGV+38
MKR[8K]F(V*C8I]BQV8<@V*+8LMF%V*?9BMBT(-JIV8;9BMBO(-F*V*<@V*C8
ML=BGVXP@VJG9A=JI(-BHV8K8M-BJV+$@V*C8IR#9A=BOV8K8L2#8L]F*V+/8
MJMF%(-BNV8C8KR#8JMF%V*?8LR#8J-JOV8K8L=F*V*\`V8;9A=N,XH",V*K9
MB-BGV88@04-,(-BQV*<@V878K-BOV*_8I]F+(-BHV*_8L]BJ(-BBV8C8L=BO
M`-F&V87;C.*`C-BJV8C8I]F&(-JIV*K8I]BHVH;9AR#8HMBOV+'8LR#8L=BG
M(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,`V8;9A=N,XH",
MV*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++9BMBYVXP@V+'8IR#8K]F(V*C8
MI]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&
M(-F!V8?8L=BSV*H@V*K9B-BRV8K8N=N,(-BQV*<@V*_9B-BHV*?8L=F'(-BH
MV*_8L]BJ(-BBV8C8L=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9@MBGV*C9
MA-F*V*K9A]BGVXP@V+/8L=F(V+$@V+'8IR#8K]F(V*C8I]BQV8<@V*C8K]BS
MV*H@V*+9B-BQV*\`V8;9A=N,XH",V*K9B-BGV88@V;[9BMJIV+'8J-F&V*_;
MC"#8L=BG(-BHV*?8LMJOV+'8K]BGV8;8KP#9AMF%VXSB@(S8JMF(V*?9AB#:
MJ=BTV8@@V+'8IR#8K=BPV8$@V8;9A=F(V*\G)7,G("X`V8;9A=N,XH",V*K9
MB-BGV88@V;[9BMJIV+'8J-F&V*_;C"`E<R#8L=BG(-BOV*[9BMBQV8<@VJG8
ML=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+38JMF*V*C8I]F&VXP@V*?8LB#9
MOMF*VJG8L=BHV8;8K]N,(-BPV*[9BMBQV8<@VJG8L=BO`-F&V87;C.*`C-BJ
MV8C8I]F&(-F^V+38JMF*V*C8I]F&VXP@V*?8LB#9OMF*VJG8L=BHV8;8K]N,
M(-BPV*[9BMBQV8<@VJG8L=BO.B`E<R``V8;9A=N,XH",V*K9B-BGV88@V*?8
ML]JIV+'9BMF^V*H@V*C9AR#8L=F(V+(@V+'8L]BGV8;;C"#8JMF&V+C9BMF%
MV*?8JB#8L=BG(-BPV*[9BMBQV8<@V8;9A=F(V*\Z("<E<R<N`-F&V87;C.*`
MC-BJV8C8I]F&(-BJV8;8N-F*V878I]BJ(-F^V+38JMF*V*C8I]F&VXP@)7,@
MV+'8IR#8L-BNV8K8L=F'(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQ
MV8C9AMBOV8<@V;[9BMJIV+'8J-F&V*_;C"`E<R#8L=BG(-BPV*[9BMBQV8<@
MV8;9A=F(V*\N(-BTV878IR#9A=N,(-BJV8C8I]F&V8K8KR#8I]BR(-F*VJG;
MC"#8I]BR(-JOV++9BMF&V8?B@(S9A]BG(-BHV+'8I]N,(-BPV*[9BMBQV8<@
MVJG8KR#8J-BQ(-BQV8C;C"`E<R#8I]BSV*K9@=BGV*_9AR#9AMF%V*?9BMF*
MV*\@V8@@V8K8IR#8I]F*V8;:J=F'(-JIV*\@V+'8IR#8J-F'(-BUV8C8L=BJ
M(-BOV+/8JMN,(-BOV+$E<R#:J=F^VXP@V8;9A=BGV8K9BMBO`-F&V87;C.*`
MC-BJV8C8I]F&(-BSV+'9B-BQ3$1!4"#8L=BG(-BLV+/8JMBLV8@@VJG8L=BO
M`-F&V87;C.*`C-BJV8C8I]F&(-BGV*K8M=BGV80@V+'8IR#8J-F'(-BQV8C8
MLB#:J=BQV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9
MB-BRV8K8N=N,(-BQV*<@V*C9AR#8L=F(V+(@VJG8L=BO+B`E<P#9AMF%VXSB
M@(S8JMF(V*?9AB#9OMF*VJG8L=BHV8;8K]N,(-BQV*<@V*C8L=BGVXP@)R5S
M)R#9AMF(V+38JCH@)7,`V8;9A=N,XH",V*K9B-BGV88@V8;9B-BGV+$@V*S8
MI]F&V*C;C"#9A=F(V++9BMF$V*<@V+'8IR#9OMF*V*_8IR#:J=BQV*\N(-F%
MV+?9A=BFV88@V+39B-F*V*\@VJG9AR#9AMF(V*?8L2#8K-BGV8;8J-N,(-BH
MV*?8LB#8I]BSV*H`V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8J-BQ
M("<E<R<@V*_8L]BJV+'8L]N,XH",V8?8I]N,(-BRV8K8L2#8J-BQV*?;C"#9
MOMF(V+39AR`G)7,G(-BOV*?8KSH@)7,`V878JMF&XH",V8?8I]N,(-BTV878
MI]BQV+0@V+38K]F'`-JIV+39B-BQ`-BOV8C8L=F'XH",V8?8IP#8I]F*V*S8
MI]BO`-BGV8K8K-BGV*\@V8K:J2#9OMF*V8C9AMBO`-BGV8K8K-BGV*\@V8K:
MJ=N,(-BLV*_9BMBO`-BGV8K8K-BGV*\@V++9BMBQ(-F^V8C8M-F'XH",V8?8
MIP#8I]F*V*S8I]BO(-JIV8;9AMBOV8<@V*?8K-BGV++9A^*`C-F'V*?;C"#8
MK]BSV*K8L=BSVXP`V+39A=BGV+'9AR#:J=BGV+'8JB#8I]BYV*K8J-BGV+';
MC`#9@=BGV+(@VJG9AMF(V8;;C`#8L]BGV+G8JB#:J=F&V8C9AMN,`%523"#:
MJ=F&V8C9AMN,(-F'V+/8J@#8HMBH(-F((-F'V8C8I]N,(-JIV8;9B-F&VXP`
MV+38L=BGV8K8MR#:J=F&V8C9AMN,.B``V8+8I]F$V*@@VJG9AMF(V8;;C`#8
ML]F!V*?8L=BTVXP@VJG8L=BOV88@V8C8N-BGV8K9@2#8J-BQV*?;C"#8I]BL
MV+'8IR#8J-F'(-F'V8;:K]BGV84@V8C8L=F(V*\@V*C9AR`E<P#8J-BQV8K8
MK]F&`-BHV+'9BMBOV88@V*?9AMBJV*[8I]BH`$-Y<FEL;&EC("A+3TDX+5(I
M`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*0!$1`#8L=F(V++8I]F&V8<`V*_8I]BOV8<`V878L=F(V+':K]BQ
M(-BOV+'8KMBJ(-BOV*?8K]F'`-BJV*?8L=F*V*X`V*K8I]BQV8K8KB#8K]BQ
MV8K8I]F!V*H`V*K8I]BQV8K8KB#8I]F&V*K8KMBGV*@`V+'9B-BR`-BMV+#9
M@2#8L]BJV8C9A@#8K]BSV*?9A=BHV+$`V*?8N=BOV*?8KR#8K]F'V*_9A]N,
M`-BQV*_8M-BOV8<`VJG9A2#:J=BQV*_9AB#8JMF(V+'9@=BJVJ_;C`#8L=F&
MVJ\@V;[9BMBT(-F!V+'8M@#9A]F(V8K8JB#9OMF*V+0@V8'8L=BV`-BGV*S8
MI]BRV8?B@(S9A]BGVXP@V*_8L]BJV+'8L]N,(-F^V8K8M"#9@=BQV+8`V*?8
MK-BGV++9A^*`C-F'V*?;C"#8K]BSV*K8L=BSVXP@V;[9BMBT(-F!V+'8M@#8
MJMBYV*?8L=F*V8$`V878H]F%V8C8L2#9A=F(V8+8N=F*V*H`V878H]F%V8C8
ML2#8M-BOV8<`V*W8L-F!`-BMV+#9@2#:K]BQV8C9AP#8K=BPV8$@V*?8K-BG
MV++9A^*`C-F'V*?;C"#8K]BSV*K8L=BSVXP`V*W8L-F!(-F((-F^V*?:J2#:
MJ=BQV*_9AB#9OMF*V+K8I]F%XH",V8?8IP#8K=BPV8$@V+/9A-F(V80`V*W8
ML-F!(-BSV*K9B-F&`-BMV+#9@2#8I]F$VJ_9B-N,(-BLV*?9BMJOV++9BMF&
M(-F%V8C8K-F(V*\`V*W8L-F!(-BGV*S8I]BRV8?B@(S9A]BGVXP@V*_8L]BJ
MV+'8L]N,(-BHV+'8I]N,("<E<R<`V*?8K-BGV++9A^*`C-F'V*?;C"#8K]BS
MV*K8L=BSVXP@V*C8L=BGVXP@)R5S)R#9B"#8JMF%V*?9A=N,(-BRV8K8L2#:
MK]BQV8C9A^*`C-F'V*?;C"#8HMF&(-BMV+#9@2#8M-F(V8;8K]B?`-BMV+#9
M@2#8L]BWV+$`V*W8L-F!(-F'V8C9BMBJ(-BGV8;8JMBNV*?8J"#8M-BOV8<`
MV*W8L-F!(-BSV*K9B-F&(-JIV8;9B-F&VXP`V*W8L-F!(-BSV+?8L2#:J=F&
MV8C9AMN,`-BGV8K9AB#8I]BLV*?8LMF'(-BOV+/8JMBQV+/;C"#9B"#8JMF%
MV*?9A=N,(-BRV8K8L2#:K]BQV8C9A^*`C-F'V*?;C"#8HMF&(-BMV+#9@2#8
MM-F(V8;8K]B?`-BGV+/:J=BQV8K9OMBJ(-BHV8<@V+'9B-BR(-BQV+/8I]F&
MVXP@V*K9AMBXV8K9A=BGV*H@V*W8L-F!(-BTV*_9AR#8I]BSV*H@)R5S)RX`
MV++9A=BGV88@V*?8L=BSV*?9A`#8L=BO(-BJV8+8I]BVV*<`V*_8L=BNV8C8
MI]BSV*H@V*C8L=BGVXP@V*?8M]F$V*?8N=BGV*H@9G)E92]B=7-Y(-F^V+#9
MBMBQV8'8JMF'(-F&V+38KP#8M-BQV*T@V878M-JIV80`V*K9B-BVV8K8K0#8
MK-BRV9#8IMF*V*?8JCH`(-BLV++8IMF*V*?8JB#8J-BQV*?;C"#9A=BSV*;9
MB-F$(-BSV8K8L]BJV84@VJ_8LMBGV+'8M"#8M-BOV8<@V*?8L]BJ`-JOV+/8
MJMBQV+0`V8;9@MBWV8<@V+38J-F&V84`V8;9@MBWV8<@V+38J-F&V84@V*C8
ML=BGVXP@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@`-F&V8+8M]F'(-BTV*C9AMF%
M.B``V*S9A]BJ(-BGV+(@VH;9OB#8J-F'(-BQV*?8L]BJ`-BLV8?8JB#8I]BR
M(-BQV*?8L]BJ(-BHV8<@VH;9O@#:J=BTV8@`V*+9BMBG(-BRV878I]F&(#(T
M(-BSV*?8N=BJV8<@V8;9A=BGV8K8M"#8K]BGV*_9AR#8M-F(V*_8GP#:K]BR
MV8K9AMF'XH",V8?8I]N,(-F&V878I]F*V+0`V8;8M-BGV88@V*_8I]BOV88@
MV;[9BMBT(-BHV8K9AMN,`-F&V878I]F*V+0@V8+8I]F$V*@`V*K8L-JIV+$@
MV*K8L=BJV8K8J`#8K=BPV8$@V8;8M-F(V*\`V*_8L]BJV+'8L]N,(-F%V+/8
MJMF"V8K9A2#8J-F'(&UA:6YT96YA;F-E+G!H<"#9A=F%VJG9AB#9AMF*V+/8
MJ@#8HMF*V*<@V+/8M]BQ(-BGV8C9A"#8M-BGV879A"#9@=F*V838KR#9AMBG
MV84@V87;C.*`C-BHV*?8M-BOV)\@V*?:K]BQ(-J&V8;9BMF&(-BGV+/8JMB,
M(-BGV8K9AB#8K-BYV*C9AR#8L=BG(-BYV838I]F%V*H@V*C8LMF&V8K8KSH`
MV*_8L=F*V*?9@=BJ`-BOV+'9BMBGV8'8JB`E<P#8J-BGV+':J=BQV*_9AB#9
MOMF*VJG8L=BHV8;8K]N,(-BJV8C9A-F*V*\@V+38K]F'(-BHV+G9AMF(V*?9
MAB#9A=BJV88@4$A0`-F!V8?8L=BSV*H@`-BOV*?8L=F(V8?8IP#9AMBGV879
MAR#8I]F$VJG8JMBQV8C9AMF*VJG;C`!%4E(`V8C9BMBQV*?9BMBT`-F(V8K8
ML=BGV8K8M"#8J-F$V8C:J0#9B-F*V+'8I]F*V+0@VJ_8L=F(V8<`V8C9BMBQ
MV*?9BMBT(-BGV*S8I]BRV8?B@(S9A]BGVXP@V*_8L]BJV+'8L]N,`-F(V8K8
ML=BGV8K8M"#8I]BLV*?8LMF'XH",V8?8I]N,(-BOV+/8JMBQV+/;C`#9B-F*
MV+'8I]F*V+0@V*?8K-BGV++9A^*`C-F'V*?;C"#8K]BSV*K8L=BSVXP@V*C8
ML=BGVXP@)7,`VJ_8LMF*V8;9A^*`C-F'V*?;C"#9B-F*V+'8I]F*V+0@V*C8
ML=BGVXPZ`-F(V8K8L=BGV8K8M"#8I]BLV*?8LMF'XH",V8?8I]N,(-BOV+/8
MJMBQV+/;C"#8J-BQV*?;C"`E<P#9B-F*V+'8I]F*V+0@V*?8K-BGV++9A^*`
MC-F'V*?;C"#8K]BSV*K8L=BSVXP@V*C8L=BGVXP@)R5S)P#8JMBMV+79BMF$
MV*?8J@#8N=F&V+78L2XN+@!%;0#9AMBGV879AR#8I]F$VJG8JMBQV8C9AMF*
MVJG;C`#8HMBOV+'8LR#9AMBGV879AR#8I]F$VJG8JMBQV8C9AMF*VJG;C`#8
MHMBOV+'8L]F'V*?;C"#9AMBGV879A^*`C-F'V*?;C"#8I]F$VJG8JMBQV8C9
MAMF*VJG;C"#8J-BGV8K8KR#9A=F&V+?8J-F"(-BHV*?8M-BO`-F&V*?9A=F'
M(-BGV83:J=BJV+'9B-F&V8K:J=N,(-BHV*<@V*K8H]F*V8K8KP#8I]BMV+/8
MI]BSV*?8J@#9OMF*V+K8I]F%(-BNV*?9A-N,`-BNV*?9A-N,(-JIV+'8K]F&
M(-F&V*K9BMBLV8<`V*[8I]F$VXP@VJG8L=BOV88@V879B-BGV+'8KR#8K-BS
MV*K8K-F(`-BBV8K8IR#8I]BVV*?9@=F'(-JIV+'8K]F&(-BJV+78I]F(V8K8
ML2#8I]BR(-JOV*?9A-BQVXSB@(S9A]BGVXP@V+G:J=BS(-BOV+$@V878JMF&
M(-F!V+G8I]F$(-BTV8C8K]B?`-BBV8K8IR#9A=F&V8@@8V]N=&5X="#8L=F(
MVXP@VJG9A-F*VJD@V+'8I]BSV*H@V8'8N=BGV80@V+39B-BOV)\`V*?9AMBJ
MV8?8IP#8I]F&V*K9A]BGVXP@V+/8I]F$`-BHV++8L=JO(-JIV+'8K]F&(-F(
MV8K8L=BGV+/8JMBGV+$`V8K:J2#8L]BFV8C8I]F$(-BGV879AMF*V*K;C"#8
ML=BG(-BHV+'8I]N,(-F^V+'8L]BT(-BHV8<@V8?9AMJOV*?9A2#8L=BGV8?B
M@(S8I]F&V*_8I]BRVXP@V*_9B-BHV*?8L=F'(-BQV878LB#8N=BHV8C8L2#9
MB-BGV+'8KR#:J=F&V8K8K]B,(-F%V*O9A"`GV8;8I]F%(-BMV8K9B-BGV88@
MV*[8I]F&VJ_;C"#8M-F%V*<@VH;9BMBSV*K8GR<`55),(-BJV+79B-F*V+$@
MV+'8IR#8I]F*V8;8K-BG(-F(V*?8L=BO(-JIV8;9BMBO`-F(V+'9B-BOVXP@
M.B#8K-F%V+G8I]F+("5DV(P@)60@V*C9AR#8L=F(V+(@V+38K]F'V(P@)60@
MV*S8K]F*V*_8C"`E9"#8JMBZV8K9BMBQ(-F*V*?9@=BJV8?8C"`E9"#9AMBG
MV+39AMBGV+,`V*[8M]BG`-BNV+?8IR#8K]BQ(-BGV+'8L]BGV80@V*_8I]BO
MV8<@V*C9AR!S;6)P87-S=V0N`-BNV+?8IR#8K]BQ(-F!V+'8L]BJV*?8K]F&
M(-F^V*?8L]BN.B`E<RX`V*[8M]BG(-BOV+$@V;[9BMBZV*?9A2#9AMBGV879
MAR#8I]F$VJG8JMBQV8C9AMF*VJG;C`#8KMBWV*?;C"#9AMF(V+38JMF&("<E
M<R<@`-BNV+?8ISH@`-BYV*K9BMF"V8<`V*?8L=F(V;[8IP#9A]BQ(-F^V*?9
MAMBRV*_9AR#8K]F"V8K9@MF'`-F'V+$@V*_9B"#8K]F"V8K9@MF'`-F'V+$@
MV+/;C"#8K]F"V8K9@MF'`-F'V+$@V;[9AMBL(-BOV8+9BMF"V8<`V*_8L2#9
MA]BQ(-F(V+'9B-BO`-F'V+$@V8;9BMF%(-BSV*?8N=BJ`-F'V+$@V*_9@MF*
MV8+9AP#9A=F"V*?8K]F*V+$@V878J]BGV83;C#H`V*?8K-BQV*<`V*?8K-BQ
MV*<Z`-BHV*?8LB#:J=BQV*_9A@#8J-BGV++:J=BQV*_9AB#9AMF(V*?8L2#:
MJ=F&V*?8L=N,`-BGV8;8JMBXV*?8L2#8J-BQV*?;C"`G*"<`V*K8I]BQV8K8
MKB#8I]F&V8+8MMBGV*$`V*?8L]BJV*[8L=BGV*P@V+38K]F'(-BGV+(@)7,N
M+BX@(`#8L=F&VJ\@V;[9BMBT(-BRV879BMF&V8<`1E10('5P;&]A9"!O9B!S
M971U<`#8J-BGV++9BMBGV*C;C"#8I]F(V839B-F*V*KB@(S9A]BG(-F%V8K8
ML]BQ(-F&V+38KP#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-BSV+'9B-BQ($Q$
M05#9B-BUV80@V+38KP#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-BSV+'9B-BQ
M(%--0B#9B-BUV80@V+38KP#9AMF%VXSB@(S8JMF(V*?9AB#8I]BR("(E<R(@
MVJG9OMN,(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*_8
ML2`E<R#:J=F^VXP@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F*VJD@V*?8
MJMBUV*?9A"#8K-BOV8K8KR!305-,(-BGV8K8K-BGV*\@VJG8L=BO`-F&V87;
MC.*`C-BJV8C8I]F&(-BHV8<@(B5S(B#9AMF"V80@V87:J=BGV88@VJG8L=BO
M`-BHV*?8LMBHVXS9AMN,(-BGV+/9A2#8L=F%V+(@V8+8K]N,V87;C"#9AMBG
MV879B-F!V9'9@B#8J-F(V*\N`-BYV*_9A2#9A=F(V8'9D=F"VXS9D=BJ(-BO
MV+$@V*K8NMN,VXS8L2#8I]BSV84@V+'9A=BR(-BHV+$@)7,@.B`E<P#9A-BW
MV8K9@0#8KMBWV*<Z(`#9@=JIV+,`V8'9B-BQV8K9AP#8L=JOV*C8I]BQ(-BN
MV8'9BMF!`-JIV87;C"#8JMJOV+':KP#8JMBYV*_8I]BO(-F^V+'9B-F&V*_9
MASH@)7,@V;[8L=F(V8;8K]F'`-BJV+G8K]BGV*\@V;[8L=F(V8;8K]F'XH",
MV8?8ISH@)7,@V;[8L=F(V8;8K]F'`-F%V*_9BMBQ(-F^V+'9B-F&V*_9AP#9
MAMBGV84@V;[8L=F(V8;8K]F'`-BGV8;8JMBNV*?8J"#9OMBQV8C9AMBOV8<`
MV*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<`V*?8L=BSV*?9A"#9OMBQV8C9AMBO
MV8<@V;[8M-BJV8K8J-BGV8;;C"#9AMF%VXSB@(S8M-F(V*\N+@#9@=F*V838
MJMBQV8?8IP#9AMF*V879AR#8I]F(V80`V+'8J-BY(-BGV8C9A`#9AMBSV*C8
MJB#8J]BGV*C8J@#8I]BYV+38I]BQVXP`V879AR#8HMF$V8C8KP#9OMF(V+39
MAR`E<R#9A=F(V*S9B-BO(-F&V8K8L]BJ(`#8L=F&VJ\@V8+9A-F%`-BZV+#8
MIP#8J-BQV*?;C"#9A=BQV8C8L=JOV+'9A]BGV8K;C"#:J=F'(-BJV+78I]F(
MV8K8L2#8L=BG(-F^V+38JMF*V*C8I]F&VXP@V8;9A=N,XH",VJG9AMBO`-F^
MV8K8M"#8J-F*V8;;C`#8L=F%V+(@V+G8J-F(V+$@V*[9B-BO(-BQV*<@V8'8
ML=BGV879B-BT(-JIV+'8K]F'XH",V*?9BMBOV)\`V8'8L=F%XH",V8?8IP#8
MM]BGV838N0#9AMF(V+D@V+?8I]F$V+D`V+?8I]F$V+GB@(S9A]BG`-BWV*?9
MA-BYXH",V8?8IR`R`-BGV8;8K-F%V8;B@(S9A]BG`-F^V8K8M-BHV+'8K]F'
MV*<`V;[9BMBOV*<@VJG8L=BOV88@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-JI
MV*?8L=BHV+'8K]N,.B`E<P#9OMF*V*_8IR#:J=BQV*_9AB#:J=BTV8CB@(S9
MA]BG.@#8K-F%V+G9AP#:AMBGV+':AMF(V*C9A]BG`-BGV+?9A-BGV+G8I]BJ
M($9R964O0G5S>0#9OMBGV+/8KB!&<F5E+T)U<WD`V*_8L=BNV8C8I]BSV*H@
M1G)E92]"=7-Y`-F^V*?8L]BN(-BOV+'8KMF(V*?8L]BJ($9R964O0G5S>0#8
MI]BR`-BGV+(@`-BTV+'8K2#:J=BGV879A`#9A=BGV8<@VJG8I]F%V80`V8;8
MI]F%(-JIV*?9A=F$`-F!V*?8LMN,`-JOV*?9A-BQVXP@V*C8L=BGVXP@V*_8
ML=F*V*?9@=BJ(-BJV+79B-F*V+$@`-JOV*?9A-BQVXPZ`-BJV8C9A-F*V*\@
MV;[9BMJIV+'8J-F&V*_;C"`E<P#:J=BO(-BJV8C9A-F*V*\@V+38K]F'`-BJ
MV8C9A-F*V*\@V*W8I]F$V*KB@(S9A]BG(-BHV+'8I]N,(-F"V+/9A=BJ("5S
M+BXN`-BNV+?8I]N,($=E=&]P=#H@`-F&V*?9A2#8K]BGV*_9AR#8M-BOV8<`
MV*C8L=F(`-BLV+/9AMBLV8C;C"#:K]F(VJ_9A`#8KMBGVJG8L]BJV+';C`!'
M<F5E:R`H25-/+3@X-3DM-RD`V878K]F*V+'9BMBJ(-JOV+'9B-F'`-F&V*?9
MA2#:K]BQV8C9AR#9AMBHV*?9BMBO(-BNV*?9A-N,(-BHV*?8M-BO`-BGV*S8
MI]BRV8?B@(S9A]BGVXP@V*_8L]BJV+'8L]N,(-JOV+'9B-F'`-JOV+'9B-F'
MXH",V8?8IP#8I]BLV*?8LMF'XH",V8?8I]N,(-BOV+/8JMBQV+/;C"#9A=F*
MV8?9A=BGV88`V*?8K-BGV++9A^*`C-F'V*?;C"#8K]BSV*K8L=BSVXP@V879
MBMF'V878I]F&`-JIV*K8I]BHVH;9AR#9BMBGV*_8J-F(V*\`2$@`2%1-3`!(
M5$U,07)E82#8K=BPV8$@V*+8KMBQV8K9AB#8L]F$V8C9A"#8L=BG(-BOV+$@
MV+'8K]F*V8$@V+'8KR#9A=N,XH",VJG9AMBO`$A434Q!<F5A(-BMV+#9@2#8
MHMBNV+'9BMF&(-BSV*K9B-F&(-BQV*<@V*_8L2#8K-BOV8C9A"#8L=BO(-F%
MVXSB@(S:J=F&V*\`2%1-3$%R96$@V*W8L-F!(-BBV*[8L=F*V88@V+'8K]F*
MV8$@V+'8IR#8K]BQ(-BLV*_9B-F$(-BQV*\@V87;C.*`C-JIV8;8KP#8I]BM
MV+'8I]BR(-F'V8C9BMBJ($A45%`@V8K8I]F!V*K9AR#9AMBTV*\`V*?9A-JO
MV8C8L=F*V*K9A2!(87-H`-F%V8<@V*+9A-F(V*\`V+/8L=BBV878KP!(96)R
M97<@*$E33RTX.#4Y+3@M22D`V*C9A-F&V*_;C`#8L=BGV8?9AMF%V*<`VJG9
MA=JI(-BHV*<@V*?8L]BJV8'8I]BOV8<@V*?8LB#9B-F*V+'8I]F*V+3:K]BQ
M`-JIV87:J2#:J=F&V8;8K]F'`-BHV+'9AMBGV879A^*`C-F'V*?;C"#:J=BG
MV+'8J-BQV*_;C"#8L=BGV8?9AMF%V*?9BMN,(-JIV8;9AMBOV8<@V*C8L=BG
MVXP@V*?9BMBLV*?8KR#9B"#9AMJOV8?8K]BGV+';C.*`C"#8JMBQV*S9A=F'
MXH",V8?8I]N,(-F'V8C8L=BO(`H@V8@@VH;8I]BQVH;9B-BH(-F((-BHV+'9
MAMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C"`*(-BHV+'8I]N,(-BB
MV+39AMBGV8K;C"#9OMBQV8C9AMBOV8?B@(P@4D5!1$U%(-BQV*<@V*_8L2#8
MI]F*V88@VJG8M-F((-BHV*[9B-BGV8;9BMBO`-F&V8K9A2#:J=BQV8<`V*?9
MBMF&V*S8IR#8I]BHV*K8K]BGVXP@V;[8L=F(V8;8K]F'XH",(-F%VXSB@(S8
MJ-BGV+38KSH`V*C8I]F$V*<`V8;8I]F%(-F(V+'9B-BOVXP@V*K8I]BQV8K8
MKMN,(-F&V*C8I]F*V*\@V*[8I]F$VXP@V*C8I]BTV*\`V*[8I]F&V8<`V*[8
MI]F&V8<`V*+8K]BQV+,@V*[8I]F&V8<`V+39A=BGV+'9AR#8JMF$V8'9AB#8
MKMBGV8;9AP#9A]F(V+'8KP#8JMBQV*S9A=F'XH",VJ_8L2#9A]F(V+'8KP!(
M;W)D92]+;VQA8CH@)7,@V*_8I]BOV8<@V8;8I]BOV+'8L]BJ(%A-3"#8K]BQ
M(-F^V8K8NMBGV84@)7,@V+39A=BQV*_9AR#8M-BOV8<@V*?8L]BJ`$AO<F1E
M+TMO;&%B.B#9A]F*VH8@V;[9BMBZV*?9A=N,(-F%V+?8I]BHV8+8JB#8J-BG
M(-BTVXS8H2`E<R#9AMBOV*?8L=BO`$AO<F1E+TMO;&%B.B#9A]F*VH8@V+3;
MC-BA(-BGV+(@V8;9B-BY("5S(-BOV+$@V;[9BMBZV*?9A2`E<R#9BMBGV8'8
MJB#9AMBTV*\`2&]R9&4O2V]L86(Z(-BHV*<@V879B-F!V8+9BMBJ("5S("(E
M<R(@V*W8L-F!(-BTV*\`2&]R9&4O2V]L86(Z(-BHV*<@V879B-F!V8+9BMBJ
M("5S("(E<R(@V+/9AMJIV+'9B-F&(-BTV*\`2&]R9&4O2V]L86(Z(-F"V*?8
MK]BQ(-BHV8<@V*K9B-F$V8K8KR#9BMJI(-BOV+'8KMBJ(-BLV*_9BMBO(%A-
M3"#8J-BQV*?;C"#8M-N,V*$@)7,@V8;9BMBSV*H@`$AO<F1E+TMO;&%B.B#8
MK=BPV8$@)7,@(B5S(CHE<R#9A=F%VJG9AB#9AMF*V+/8J@!(;W)D92]+;VQA
M8CH@V8+8I]BOV+$@V*C9AR#8L]F&VJG8L=F(V88@VJG8L=BOV88@)7,@(B5S
M(CH@)7,@V8;9BMBSV*H`2&]R9&4O2V]L86(Z(-BGV+38JMBQV*?:J2#9AMBG
MV+39AMBGV*[8JMF'("(E<R(`V*[8MR#8I]F!V8+9B@#9@=BGV+79A-F'XH",
MVJ_8L-BGV+';C"#8I]F!V8+;C``ZV*?9@=F"VXP`VH;:K]F(V8;9AR#8J-BG
M(-BGV8K9AMBLV*<@V*+8M-F&V*<@V+38K]F*V*_8GR`HV838M]F!V*?9BR#8
MJMF(V+;9BMBM(-BOV8?9BMBO*2$`VH;9AMBO(-BSV*K9B-F&(-BQV*<@V87;
MC.*`C-BNV8C8I]F'V8K8KR#8I]BOV+K8I]F%(-JIV8;9BMBOV)\`VH;9AMBO
M(-F!V8K9A-BO("C8L]BJV8C9ABD@V8C8K-F(V*\@V*_8I]BQV*_8GP#:AMF&
MV*\@V+/8M]BQ(-BQV*<@V87;C.*`C-BNV8C8I]F'V8K8KR#8I]BOV+K8I]F%
M(-JIV8;9BMBOV)\`V+'8M]F(V*C8J@#8L=BWV8C8J-BJ.B``V*K9B-F$V8K8
MKR#8K-BYV*C9AR#9OMBSV*K;C"!)34%0(-F%V8K8L]BQ(-F&V+38KSH@)7,`
MV*W8L-F!(-BLV+G8J-F'(-F^V+/8JMN,($E-05`@V879BMBSV+$@V8;8M-BO
M.B`E<P#8JMF(V839BMBO('%U;W1A(-BLV+G8J-F'(-F^V+/8JMN,($E-05`@
MV879BMBSV+$@V8;8M-BO.B`E<P#8HMBOV+'8LR!)4`#8HMBOV+'8LR!)4"#9
M@MBGV*C9A"#8K]BSV*K8L=BSV8H@V8;9BMBSV*H`7]F"V*C9A-BGV8L@V+/8
MM]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMF*V*\`V8'9@MBW(-BBV8K:J=F(V8;B
M@(S9A]BG`-BBV8K:J=F(V8;B@(S9A]BG("5S`-BBV8K:J=F(V8;B@(S9A]BG
M(-F'V878L=BGV8<@V*C8IR#9AMF(V+38JMF'`-F&V*?9A2#9A=BTV*[8M=F'
M(-F'V8C9BMBJ.@#8I]JOV+$@V*+9AB#8J-F'(-BOV+'8L]BJV8H@V8;9A=BG
MV8K8M"#8K]BGV*_9AR#9AMBTV8C8K]B,("5S("#8J-BQV*?;C"#8J-BGV+(@
MVJG8L=BOV88@V*+9AB#8K]BQ(-F*VJD@V;[9AMBLV+'9AR#8K-BOV8K8KP#8
MI]JOV+$@V+39A=BG(-F'V8K:AB!I8V]N(-BOV+$@V878L=F(V+':K]BQ(-F&
MV*C9BMF&V8K8K]B,(-F%V87:J=F&(-BGV+/8JB#9A-BGV++9A2#8J-BGV+38
MKR#:J=F'(%!.1R!4<F%N<W!A<F5N8WD@V+'8IR#8KMBGV879B-BT(-JIV8;9
MBMBO`-BGVJ_8L2#8M-F%V*<@V*?9BMF&(-F^V8K8NMBGV84@V+'8IR#9A=BT
MV*?9A]BOV8<@VJG9AMF*V*\@V*?9A=BG(-BJV+79B-F*V+';C"#8L=BG(-F%
MV+38I]F'V*_9AR#9AMJIV8;9BMBO(-B,(-BGV8K9AB#8J-F'(-BGV8K9AB#8
MN=F$V*H@V*[9B-BGV8?8KR#8J-F(V*\@VJG9AR#9A=BQV8C8L=JOV+$@V+39
MA=BG(-F!V*?8K]BQ(-BHV8<@V8;9A=BGV8K8M"#8JMBUV8C9BMBQ(-F&V8K8
ML]BJ(`#9OMF*V+0@V8;9A=BGV8K8M"#8JMBUV8C9BMBQ.@!54DP@V*K8M=F(
MV8K8L0!54DP@V*K8M=F(V8K8L3H`V*K8M=F(V8K8L2#8I]BR(-JOV*?9A-BQ
MVXP`V*K8M=F(V8K8L2#8I]BR(-JOV*?9A-BQVXPZ`-BGV+'8L]BGV80@V*K8
MM=F(V8K8L0#8JMBUV*?9B-F*V+$`V8C8I]BQV*\@VJG8L=BOV8;8C"#:K]BG
MV84@)60`V8'9BMF$V*\@V8C8I]BQV*\@V+38K]F'.B`E<P#9@=F*V838K^*`
MC-F'V*?;C"#9B-BGV+'8KR#8M-BOV8<Z`-BOV+$@V*W8I]F$(-BGV8;8K-BG
MV84`7]BHV+G8K]BGV8L@V+/8M]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMF*V*\`
MV*?8L]F%(-BQV878LB#9AMBGV*_8L=BSV*H`VJG8KR#8N=F%V83:J=BQV*\@
MV8;8I]BOV+'8L]BJ(-BOV*?8K]F'(-BTV*_9AR#8I]BSV*H`(-F&V*?9A2#:
MJ=BGV+'8J-BQ(-F((-F*V*<@V+'9A=BR(-BYV*C9B-BQ(-F&V*?8K]BQV+/8
MJB#8I]BSV*H`V8;8I]F%(-JIV*?8L=BHV+$@V8K8IR#8HMBOV+'8LR#8K-BG
MV8K:K]BRV8K9AB#9AMBGV*_8L=BSV*H@V87;C.*`C-BHV*?8M-BO+B#9A-BW
MV8'8IR#9A=BLV*_8K]BG(-BSV+G;C"#:J=F&V8K8KR#9B"#9BMBG(-BOV+$@
MV+79B-BQV*H@V8;9BMBGV+(@V*C9AR#:J=F%VJD@V*C9BMBTV*K8L2#8J-BG
M(-F%V*_9BMBQ(-BSV8K8L]BJV84@V*K9A=BGV+,@V*C:K]F*V+'9BMBO`-BG
MV8'8LMBGV8K8M"#8JMF(V+'9@=BJVJ_;C`#:J=BGV+'8J-BQV*?9AB#8KMBG
MV+4`V*?8M]F$V*?8N=BGV*H`V*?8M]F$V*?8N=BGV*H`V*K9AMBXV8K9A2#8
MI]F(V839BMF'(-F%V*_9B-F$("5S+BXN`-BGV+;8I]F!V8<@VJG8L=BOV88@
MV+/8JMF(V88@V*C8N=BO(-BGV+(`V*?8MMBGV8'9AR#:J=BQV*_9AB#8JMBU
MV8C9BMBQ`-F(V*?8L=BO(-JIV+'8K]F&(-BLV*_9B-F$`-F(V*?8L=BO(-JI
MV+'8K]F&(-F^V8K9B-F&V*\@V*K8I]BQV8;9A=BG`-F"V*C9A-BGV8L@V+/8
MJMF(V88@V+'8IR#9B-BGV+'8KR#:J=F&V8K8KP#9BMJI(-BSV*K9B-F&(-BL
MV*_9BMBO(-BHV+G8KR#8I]BR(-BSV*K9B-F&(-JIV8;9B-F&VXP@V8C8I]BQ
MV*\@VJG9AMF*V*\`V8K:J2#8L]BJV8C9AB#8K-BOV8K8KR#9@MBHV80@V*?8
MLB#8L]BJV8C9AB#:J=F&V8C9AMN,(-F(V*?8L=BO(-JIV8;9BMBO`-F*VJD@
MV+/8M]BQ(-BLV*_9BMBO(-BHV+G8KR#8I]BR(-BSV+?8L2#:J=F&V8C9AMN,
M(-F(V*?8L=BO(-JIV8;9BMBO`-F*VJD@V+/8M]BQ(-BLV*_9BMBO(-F"V*C9
MA"#8I]BR(-BSV+?8L2#:J=F&V8C9AMN,(-F(V*?8L=BO(-JIV8;9BMBO`-F*
MVJD@V;[8I]BQV*?:K]BQV*?9@2#8J-BYV*\@V*?8LB#:K]BQV8<@VJG9AMF(
MV8;;C"#9B-BGV+'8KR#:J=F&V8K8KP#9BMJI(-F^V*?8L=BGVJ_8L=BGV8$@
MV8+8J-F$(-BGV+(@VJ_8L=F'(-JIV8;9B-F&VXP@V8C8I]BQV*\@VJG9AMF*
MV*\`V*?8MMBGV8'9AR#:J=BQV*_9AB#8I]F$VJ_9B-N,(-BLV*?9BMJOV++9
MBMF&`-F*VJD@V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&V8K:J2#:
MJ=F'(-BGV+(@V*+9AB#9A=N,XH",V*K9B-BGV8;9BMBO(-BQV878LB#8N=BH
MV8C8L2#8K-BOV8K8KR#8L=BG(-BOV+'9BMBGV8'8JB#:J=F&V8K8KR#9B-BG
MV+'8KR#:J=F&V8K8KP#8I]BVV*?9@=F'(-JIV+'8K]F&(-BSV839B-F$(-BH
MV+G8KR#8I]BR`-BGV+;8I]F!V8<@VJG8L=BOV88@V+/9A-F(V80@V8+8J-F$
M(-BGV+(`V*?8MMBGV8'9AR#:J=BQV*_9AB#8L]BJV8C9AB#8J-BYV*\@V*?8
ML@#8I]BVV*?9@=F'(-JIV+'8K]F&(-BSV*K9B-F&(-F"V*C9A"#8I]BR`-BG
MV+;8I]F!V8<@VJG8L=BOV88@V;[9BMBZV*?9A0#8I]BVV*?9@=F'(-JIV+'8
MK]F&(-F^V*?8L=BGVJ_8L=BGV8$@V*C8N=BO(-BGV+(`V*?8MMBGV8'9AR#:
MJ=BQV*_9AB#9OMBGV+'8I]JOV+'8I]F!(-F"V*C9A"#8I]BR`-BGV+;8I]F!
MV8<@VJG8L=BOV88@V+/8M]BQ(-BHV+G8KR#8I]BR`-BGV+;8I]F!V8<@VJG8
ML=BOV88@V+/8M]BQ(-F"V*C9A"#8I]BR`-F^V*?8L]BN(-F%V8C8L=BO(-F&
MV8K8I]BR(-BQV*<@V*C8L=BGVXP@V+/8IMF(V*?9A"#8I]F%V8;9BMBJVXP@
MV8C8I]BQV*\@VJG9AMF*V*\Z`-F(V*?8L=BO(-JIV+'8K]F&+]BJV+K9BMF*
MV+$@V*_8I]BOV88@V*K8M=F(V8K8L0#9B-BGV+'8KR#:J=BQV*_9AB_8JMBZ
MV8K9BMBQ(-BOV*?8K]F&(-F^V8K9B-F&V*\`V*?8N=BJV*C8I]BQ(-JIV*?9
M@=N,(-BHV+'8I]N,(-BGV+'8L]BGV80@V*C9AR#9@=F'V+'8L]BJ(-BJV8C8
MLMF*V+G;C"#9B-BLV8C8KR#9AMBOV*?8L=BO`-BGV+G8JMBHV*?8L2#:J=BG
MV8';C"#9B-BLV8C8KR#9AMBOV*?8L=BO`-BYV*_8KR#8M=BMV8K8K0#9@=F'
MV+'8L]BJ(-BYV*_8KR#8M=BMV8K8K0#8N=F%V80@V+K9BMBQ(-F%V+G8JMBH
MV+';C"#8J-BQV*?;C"#8I]F*V88@V879B-F$V8'9AR#8I]F&V*K8KMBGV*@@
MV+38K]F'(-BGV+/8J@!51$@@V8;8I]BOV+'8L]BJ`-BHV+'9AMBGV879AR#:
MJ=BGV+'8J-BQV*_;C"#9AMBGV*_8L=BSV*H`V*_8I]BOV8<@V8;8I]BOV+'8
ML]BJ(-BGV+'8L]BGV80@V+38K]F'(-BGV+/8J@#8HMBOV+'8LR#9A=F"V+78
MKR#9AMBGV*_8L=BSV*H`V8+8I]F$V*@@V;[8L=F(V8;8K]F'(-BZV8K8L2#9
MA=BYV*K8J-BQ`-F&V8C8N2#9OMF*V+K8I]F%(-F&V*?8K]BQV+/8JB#8I]BS
MV*H`87!I7VED(-BZV8K8L2#9A=BYV*K8J-BQ(-BGV+/8JB#9B"#9BMBG(-F(
MV*?8L=BO(-F&V+38K]F'(-BGV+/8J@#9OMBGV+'8I]F%V*K8L2#8NMF*V+$@
MV878N=BJV*C8L2#9B"#9BMBG(-BMV+#9@2#8M-BOV8<`V*?8K-BGV++9AR#8
MK]BSV*K8L=BSVXP@V;[8K]BQ(-F&V*?9A=BYV*K8J-BQ`-F^V+'9B-BJVJG9
MA"#8NMF*V+$@V878N=BJV*C8L0#:K]F*V+'9AMBOV8<@V+K9BMBQ(-F%V+G8
MJMBHV+$Z("<E<R<`V+3;C-BA(-BHV8<@V*?8M-BJV+'8I]JI(-JOV+#8I]BT
MV*K9AR#8M-BOV8<@V8;8I]F%V+G8JMBHV+$`V*+8K]BQV+,@V878J-BOV*,@
MV+K9BMBQ(-F%V+G8JMBHV+$`V*_8I]BOV8<@V8K9B-F&VXP@VJG8KR#8NMF*
MV+$@V878N=BJV*C8L2``V879B-BLV8C8K]N,`%0M4W1O<FUS`-BUV*?8K]BQ
M(-JIV8;9AMBOV8<`V*W8L=F(V8$@VJG8K`#:F-BGV8;9B-F*V8<`2F%P86YE
M<V4@*$E33RTR,#(R+4I0*0#8LMF*V+$@V;[9BMBQV*?9A]F&VXP`VIC9B-BF
MV8K9AP#:F-F(V*;9A@#:AMF*V*_9A=BGV88`V8C8L]BW(-J&V8K9A@#8JMF%
MV*?9A2#:AMF*V88`VH;9OB#:AMF*V88`V+'8I]BSV*H@VH;9BMF&`-BGV+79
MA-N,(-F&VJ_9AR#8K]BGV+38JMF'(-BTV8C8K]B?`-BSV+'9B-BQ(&ME<F)E
M<F]S92#8I]BMV+'8I]BR(-F'V8C9BMBJ(-BQV*<@V+'8KR#:J=BQV*\`V*K9
MB-F$V8K8KR#:J=F$V8K8KP#:J=F$V8K8KP#8M]F(V80@VJG9A-F*V*\`V8;9
MB-BY(-JIV839BMBO`-JIV*?8L=BHV+'8KR#:J=F$V8K8KP#:J=F$V8K8KR#9
M@MBHV838I]F+(-BOV+$@V+/8L=F(V+$@V+G9A=F(V87;C"#:J=F$V8K8KR#9
MA=F(V*S9B-BO(-BGV+/8J@#B@(S8J-J&V8?B@(S9A]BG`$MO<F5A;B`H155#
M+4M2*0#8M]BQV*T@V*C9AMBOVXP`V++8J-BGV88`V8;9BMF%V8<@V*+8KMBQ
M`-BQV*C8N2#8HMBNV+$`V*+8KMBQV8K9AB#8J-F'(-BQV8C8LMBTV*_9ASH`
MV*+8KMBQV8K9AB#9B-BQV8C8KSH@)7,`V*+8KMBQV8K9AB#9B-BQV8C8KR`Z
M("5S(-BGV+(@)7,`V*+8KMBQV8K9AB#9B-BQV8C8KSH@V8?8L=JOV+(`V*W9
M@MF(V8(`V+?8L=BM(-BHV8;8K]N,`-J&V;X`V+/8L=BBV878KR#:AMF^`-F%
MV8+8I]BOV8K8L2#:AMF^`-F&V84@V8;9A2#8J-BGV+'8I]F&`-BHV*?8L=F&
MV*_:K]N,(-BSV*C:J0#8J-BGV+'9AMBOVJ_;C"#8L]BHVJD@V8@@V+/8L=F*
MV+D`V*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BOV8K8L=F(V8+8J@#8J-BGV+'9
MAMBOVJ_;C"#9B"#8L=JOV*C8I]BQ(-BSV*C:J0#8J-BGV+'8I]F&(-BSV*C:
MJ2#8J-F'(-F'V878L=BGV8<@V+'8N=BO`-BHV+'9@2#8L]BHVJD`V*C8L=F!
M(-F((-BQVJ_8J-BGV+$@V+/8J-JI`-F^V8K9B-F&V*\`V8;9@MBWV8<@V;[9
MBMF(V8;8KR#8J-F'.@#8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;9
MBMJI(-BQV*<@V*C9AR#8M=F!V*W9AR#8I]F*V*S8I]BO(-F^V8K8NMBGV878
MC"#8J-F'(-F'V8;:K]BGV84@V878M-BGV8?8K]F'V(P@V;[9BMF(V8;8KR#8
MK]F'V8K8KP#9OMF*V8C9AMBOXH",V8?8IP#:J=F(VJG;C.*`C-F'V*?;C"#9
MA-F*V8;9B-JIV+,`V8'9A]BQV+/8JB`M(-JIV*?8L=BHV+$@V87;C.*`C-BJ
MV8C8I]F&V*\@V;[9B-BTV8<@V+'8IR#8J-BHV8K9AMBO`-F!V8?8L=BSV*H@
MV;[8I]F*VJ_8I]F'XH",V8?8I]N,(-BOV*?8K]F'XH",`-F!V8?8L=BSV*H@
MV+G9AMBGV8C9BMF&(-BQV*?9A]F&V878IP#9@=F'V+'8L]BJ(-BLV*_8I]F(
MV80`V8'9A]BQV+/8JB#8HMBQV+39BMF(`-F!V8?8L=BSV*H@V+'8I]F'V8;9
MA=BG`-F!V8?8L=BSV*H@260`V8'9A]BQV+/8JB#8M=BGV*W8J-BGV88`V8'9
MA]BQV+/8JB#9OMBSV*K;C`#9@=F'V+'8L]BJ(-BGV+G8MMBGV*$`V8'9A]BQ
MV+/8JB#8I]F!V+'8I]BO(-BZV8K8L2#8N=BVV8@`V8'9A]BQV+/8JB#:J=BG
MV+'8J-BQV*?9AB#9@=BYV*?9A"#9AMF%VXSB@(S8J-BGV+38KP#8I]BOV*C9
MBMBGV*H`V*C8I]BQVJG8L=BOV88@VJG8JMBGV*C8KMBGV8;9A^*`C-F'V*<N
M+BX`V*C8I]BQVJG8L=BOV88N+BX`V+/8I]BYV*H@V878K=F$VXPZ(`#9A=BM
MV839BMBJ(-F((-BSV*?8N=BJ`-F%V8C9@MBYV8K8J@#9B-BQV8C8KP#8KMBQ
MV8C8K`#9B-BXV*?9BMF!(-F(V+'9B-BO`-F(V+'9B-BO(-F%V8C9@=F"V8K8
MJB#8HMF%V8K8LB#9AMBHV8C8K]F'(-BGV+/8JB#8LMF*V+'8IR#9AMBGV84@
MVJG8I]BQV*C8L=N,(-F((-F*V*<@V+'9A=BR(-BYV*C9B-BQ(-F(V*?8L=BO
M(-BTV*_9AR#8M=BMV8K8K2#9AMBHV8C8K]F'(-BGV+/8J@#9B-BQV8C8KR#9
MA=F*V+/8L=F&V8K8L]BJ+@#9A=BJV88@V*C9A-F&V*\`V+G8M-F"`-F^V*?9
MBMF*V88`V*W8L=F(V8$@VJG9B-J&VJD@V8K9B-F&V*?9AMN,`-BMV+'9B-F!
M(-JIV8C:AMJI(-F$V*?8JMF*V88`V*?8N=BOV*?8KR#:J=F(VH;:J2#9BMF(
MV8;8I]F&VXP`34T`V;[9BMBZV*?9A2#8L=F(V+(`V+;9A=F*V879AR!-4RU4
M3D5&(-BTV*?9A=F$(-F'V8K:AB#8K]BGV*_9A^*`C-BGV8K;C"#9AMF*V+/8
MJ@!-4T<`V*S8I]BOV8@`V8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;9BMJIVXP`
MV878K]F*V+$@V8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;9BMJIVXP`V+/8I]BN
MV*K9AB#9OMF*V8C9AMBO+BXN`-F%V+?9A=BFV88@V+39B-F*V*\@VJG9AR!0
M14%2(-BQV*<@V8;8M=BH(-JIV+'8K]F'XH",V*?9BMBO(-F((-BOV+$@V878
ML]F*V+$@V+39A=BG*'!A=&@I(-F"V+'8I]BQ(-BOV*?8L=BO`-BSV*?8KMBJ
MV88@V*_8I]F*V+':J=BJV8C8L=N,("5S`-F%V*_9BMBQV8K8JB#9B"#8JMBY
MV8K9BMF&(-BQV8;:KR#8K]BSV*K9A^*`C-F'V*?9BMF*(-JIV8<@V+39A=BG
M(-F%V8C8I]BQV*\@V+'8IR#8J-BG(-BBV8;9A]BG(-F&V*?9A=JOV+#8I]BQ
MVXP@V87;C.*`C-JIV8;9BMBO`$UA<#(T(&UA<`!-87!1=65S="!M87``V878
MI]BQV+,`V*W8I]BTV8K9AP#8N=F$V*?9A=BJ(-JOV+#8I]BQVXP@V*C8IR#9
MOMBQVH;9A2#9A=BTV*?9A]BOV8<@V+38K]F'+R#9A=BTV*?9A]BOV8<@V8;8
MM-BOV8<`V+G9A-BGV878JB#:K]BPV*?8L=N,(-BHV*<@V+G9A-BGV*;9A2#8
MK]F*VJ_8L0#9@=F*V838K^*`C-F'V*?;C"#9A=F&V+?8J-F"`-F%V*?:J=BR
MV8K9A=F%(-BGV+G8JMBHV*?8L2#8I]BLV*?8LMF'(-BOV*?8K]F'(-BTV*_9
MAP#9@=BQV*?8JMBQ(-BQV8'8JMF&(-BGV+(@V878I]JIV++9BMF%V84@V8+8
ML]F%V*K9A]BGVXP@V;[9BMBZV*?9A0#8J-F*V+38JMBQV8K9AB#8K]F%V*<@
MV*_8L2`R-"#8L]BGV+G8JB#:K]BPV+38JMF'.B``V*C9BMBTV*K8L=F*V88@
MV*_9A=BG(-BOV+$@-B#8L]BGV+G8JB#:K]BPV+38JMF'.B``V878I]JIV++9
MBMF%V84@V+?9B-F$`-F%VXP`V;[8LMBTVJG;C`#9A=F$V+K;C"#8M-BOV88@
MV8+8L=BGV+$@V879A-BGV8+8I]BJ`-BGV+?9A-BGV+G8I]BJ(-F%V838I]F"
MV*?8J@#8M]BQV*T@V;[9BMBTV8;9A]BGV*_;C"#9A=F$V*?9@MBGV*H`V;[8
MI]BSV*X@V879A-BGV8+8I]BJ`-BHV8<@V+'9B-BRVJG8L=BOV88@V879A-BG
MV8+8I]BJ`-BOV+'8KMF(V*?8L]BJ(-BHV8<@V+'9B-BRVJG8L=BOV88@V879
MA-BGV8+8I]BJ`-BGV+G8MMBGV*$`V*W8I]F$V*H@V879AMF(V8K;C#H`V*?8
MK]BZV*?9A2#8L]F$V8C9A-F'V*<`V*?8K]BZV*?9A2#9A]F%V8<@V;[8L=F(
MV8;8K]F'XH",V8?8I]N,("`E<RYP;R#8J-BUV8C8L=BJ(-BNV838I]BUV8<N
M+BX`V*?8K]BZV*?9A2#9A=BMV83;C-BJ("5S+BXN(`#8I]BOV+K8I]F%(-F^
MV+'9B-F&V*_9A^*`C"!03R#8J-BQV*?;C"`E<R#8J-F'(-BWV8C8L2#8KMF$
MV*?8M=F'+BXN`-BJV+':J=F*V*@@V*K8L=BLV879AR#8J-BQV*?;C"#9@MBW
MV+G9AR`E<RXN+@#9OMF*V+K8I]F%`-F^V8K8NMBGV84@V*C8IR#9A=F(V8'9
M@MF*V*H@V*K8M=BOV8K9@B#8M-BO(-BGV878IR#:K]F(V*?9A]N,(-BGV878
MMMBGV*$@VJG9AMF&V*_9AR#9AMF%VXSB@(S8JMF(V*?9AMBO(-BJV+78K]F*
MV8(@V+39B-BO`-F^V8K8NMBGV84@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ
M`-F&V8C8N2#9OMF*V+K8I]F%`-BBV*@@V8@@V8?9B-BGVXP@VJG9AMF(V8;;
MC`#8J-F$V8C:J2!-971A<B#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@V8;9BMBS
MV*H`V*C9A-F(VJD@365T87(@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&V8K8
ML]BJ+B#8K-BRV*;9BMBGV*H@V*C8L=BGVXP@V878K]F*V+$@V+/9BMBSV*K9
MA2#8J]BHV*H@V+38K]F'(-BGV+/8J@#8L=F(V+0`V+'9B-BT("<E<R<@V*K8
MN=BQV8K9@2#9AMBTV*_9AR#8I]BSV*H`V*?9AMBOV*?8LMF'XH",V*?;C`#9
MB-BSV+<`V8;9B-BY($UI;64`(-BOV878I]N,(#(T(-BSV*?8N=BJ(-JOV+#8
MM-BJV8<Z(``@V*_9A=BGVXP@-B#8L]BGV+G8JB#:K]BPV+38JMF'.B``V*W8
MK]BGV8+9A"#8N=F%V+$@V*?8L]F%(-BQV878LB#9A]F&V8C8LB#9A=F&V8+8
MMMN,(-F&V+38K]F'XH",V*?8L]BJ`-BBV8K9AMF'`-F%V*K9@=BQV8+9AP#9
MOMF*VJG8L=BHV8;8K]N,(-F%V8C8K-F(V*\@V8;9BMBSV*HN(-BTV878IR#8
MI]JOV+$@V87;C.*`C-BNV8C8I]F'V8K8KR#8I]F*V88@V*C8L=F&V*?9A=F'
M(-JIV*?8L=BHV+'8K]N,(-BQV*<@V*?8L]BJV8'8I]BOV8<@VJG9AMF*V*\@
MV*C8I]F*V*\@V*+9AMBQV*<@V*K9B-F$V8K8KR#:J=F&V8K8KP!)1"#9OMF*
MV+K8I]F%(-F&V8K8L]BJ`-BOV8C8M-F&V*C9AP#8HMBOV+'8LR#9OMBSV*H@
MV+/9BMBGV+$`V878N=BJV*_9A`#8JMBGV+'9BMBN(-BJV+K9BMF*V+$@VJG8
ML=BOV8<`V*K8NMF*V8K8L2!54DP`V8+8M]BYV8<`V878I]F'(-F((-BSV*?9
MA`#9A=BGV8?8I]F&V8<`V8'8I]BRV8?8I]N,(-F%V*?9AP#8J-F*V+38JMBQ
M(-BUV*?9@0#8J-F*V+38JMBQ(-BGV*C8L=N,`-BHV8K8M-BJV+$@V*+9@=BJ
MV*?8J-N,`-BLV*?8J-BLV*?9BMN,(-BHV8<@V;[8I]F*V8K9A@#8K-BGV*C8
MK-BGV8K;C"#8J-F'(-BHV*?9A-BG`-BLV*?8J-BLV*?9BMN,(-BHV8<@V+'8
MI]BSV*H`V*S8I]BHV*S8I]F*VXP@V*C9AR#8J-BGV838IP#8K-BGV*C8K-BG
MV8K;C"#8J-F'(-F^V*?9BMF*V88`V*S8I]BHV*S8I]F*VXP@V*C9AR#8J-BG
MV838IP#9@=F'V+'8L]BJ(-BHV*?9A-BG(-BHV8<@V;[8I]F*V8K9AB#:AMF&
MV*\@V838I]F*V8<`VH;9AMBO(-BGV8;8JMBNV*?8J-N,`-BMV+/8I]BH(-F%
MV88`V;[8L=BJV*?9A"#9A=F&`-BWV+'8K2#8J-F&V*_;C"#9A=BMV80@V8C8
ML=F(V*\@V879A@#9AMF'V(P@V879AB#9A=F(V*?9@=F"(-F&V8K8L]BJV84`
MV8;8I]F%`-F&V8K8I]BR(-BHV8<@V+G9A=F$`%523"#9OMBGV8K9AR!.971S
M8V%P90!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P
M;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C
M871I;VX@55),`-BTV*C:J=F'`-F'V+':K]BR`-JOV+'9B-F'(-BLV*_9BMBO
M`-F%V*?9AR#9AMF(`-F&V*?9A2#:J=BGV+'8J-BQVXP@V*S8K]F*V*\@*-BG
MV*[8JMF*V*?8L=N,*0#8I]BSV84@V+'9A=BR(-BLV*_;C-BO.@#9OMF&V*S8
ML=F'(-BLV*_9BMBO("C8KMBGV83;C"D`V*?8KMBHV*?8L0#:K]BQV8C9A^*`
MC-F'V*?;C"#8KMBHV+';C`#8J-BYV*_;C`#8M=F!V*W9AR#8J-BYV*_;C`#9
M@=BGV+(@V*C8N=BOVXP`VJ_8LMF*V8;9A^*`C-F'V*?;C"#8J-BYV*_;C`#8
MM-BH`-F&V8<`V*_8I]BOV8<@V;[9BMJIV+'8J-F&V*_;C"#8J-BQV*?;C"#9
MAMBTV*?9AB#8K]BGV*_9AB#8JMF!V*?9B-BJV8?8IR#9B-BLV8C8KR#9AMBO
MV*?8L=BO`$E33R#9AMF*V+/8JB#8I]BSV*K8L=BGV*K:F-N,(-BOV+$@V*_8
ML]BJV+'8L]N,(-BHV+'8I]N,(-BSV*?8KMBJV88@V*K8M=F(V8K8L2``V*C9
MA-BGVJG9BB#8K]BQ(-F%V8C9@MBYV8K8JB#8K]BQV*[9B-BGV+/8JB#8M-BO
MV8<@V879B-BLV8C8KR#9AMF*V+/8J@#9A]F*VH8@V8;8I]F%(-BJV8+9B-F*
MV87;C"#8J-BQV*?;C"#8JMBUV*_9BMF"(-F'V8C9BMBJ($U#04P@V8'8L=BG
MV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8K]F(V88@V*K8NMF*V8K8L0#9A]F*
MVH8@V*?8K-BGV++9AR#8K]BSV*K8L=BSVXP@V8'8L=BYVXP@V*C9AR#8LMF*
MV+$@V*?9BMF&(-F$V8K9AR#8I]BVV*?9@=F'(-F&V+38K]F'(-BGV+/8J@#9
MA]F*VH8@V*?8K-BGV++9AR#9@=BQV+G;C.*`C-BGVXP@V8;9A=N,XH",V*K9
MB-BGV8;8KR#8J-F'(-BGV8K9AB#8I]BLV*?8LMF'(-BOV+/8JMBQV+/;C"#8
MI]BVV*?9@=F'(-BTV8C8KP#9@=BQV878I]F&VXP@V878M-BNV+4@V8;8M-BO
MV8<@V*?8L]BJ`-F'V8K:AB#8I]BWV838I]BYV*?8JB#9OMF*VJG8L=BHV8;8
MK]N,(-BHV+'8I]N,("5S(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8J@#9A]F*
MVH8@V*?8M]F$V*?8N=BGV*H@V;[9BMJIV+'8J-F&V*_;C"#8J-BQV*?;C"!&
M5%`@5D93(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8J@#9A]F*VH8@V*?8M]F$
MV*?8N=BGV*H@V;[9BMJIV+'8J-F&V*_;C"#8J-BQV*?;C"!344P@5D93(-F%
MV+38KMBU(-F&V+38K]F'(-BGV+/8J@#9A]F*VH8@V*?8M]F$V*?8N=BGV*H@
MV;[9BMJIV+'8J-F&V*_;C"#8J-BQV*?;C"!344PM1FEL92!61E,@V878M-BN
MV+4@V8;8M-BOV8<@V*?8L]BJ`-F'V8K:AB#8I]BYV*K8J-BGV+';C"#8J-BG
MV8+;C"#9AMF%V*?9AMBOV8<@V*?8L]BJ`-F'V8K:AB#9A=F"V+78K]N,(-F!
MV+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-F'V8K:AB#9B-BQV8C8K]N,(-BH
MV*<@V878M-BNV+79AR`G)7,G(-BOV+$@V;[8L=F(V8;8K]F'XH",(-BGV+79
MA-N,(-BQV*?9A]F&V878IR#9B-BLV8C8KR#9AMBOV*?8L=BO`-F'V8K:AB#9
MOMBQV8C9AMBOV8?B@(S8I]F*VXP@V*?8L=BSV*?9A"#9AMBTV*\`V8?9BMJ&
M(-BBV8K:J=F(V8;;C.*`C-BGVXP@V;[9BMBOV*<@V8;8M-BO`-F'V8K:AB#9
MA=BMV839BMBJVXP@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ`-F%V*W9A-F*
MV*K;C"#8JMF&V+C9BMF%(-F&V+38K]F'(-BGV+/8J@#9A]F*VH8@V;[9BMBZ
MV*?9A=N,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-F'V8K:AB#9AMBG
MV87;C"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*H`V8?9BMJ&(-BTV878I]BQ
MV8?B@(S8I]F*VXP@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ`-BBV8K9AMBO
MV8<@V8;8I]F%V+?8J-F(V+G;C"#9AMF*V+/8J@#8J-BQV*?;C"#8JMBUV*_9
MBMF"(-F'V8C9BMBJ($A45%`@V+'9A=BR(-BYV*C9B-BQVXP@V8'8L=BGV8?9
MA2#9AMBTV*_9AR#8I]BSV*H`V*C8L=BGVXP@V*K8M=BOV8K9@B#9A]F(V8K8
MJB!)34%0(-BQV878LB#8N=BHV8C8L=N,(-F!V+'8I]F'V84@V8;8M-BOV8<@
MV*?8L]BJ`-BHV+'8I]N,(-BJV+78K]F*V8(@V8?9B-F*V*H@2V5R8F5R;W,@
MV+'9A=BR(-BYV*C9B-BQVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`
MV*C8L=BGVXP@V*K8M=BOV8K9@B#9A]F(V8K8JB!,1$%0(-BQV878LB#8N=BH
MV8C8L=N,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8I]N,(-BJ
MV+78K]F*V8(@V8?9B-F*V*H@V8C8L=F(V*\@V+'9A=BR(-BYV*C9B-BQVXP@
MV8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8L=BGVXP@V*K8M=BOV8K9
M@B#9A]F(V8K8JB!005-35T0@V+'9A=BR(-BYV*C9B-BQVXP@V8'8L=BGV8?9
MA2#9AMBTV*_9AR#8I]BSV*H`V*C8L=BGVXP@V*K8M=BOV8K9@B#9A]F(V8K8
MJB!334(@V+'9A=BR(-BYV*C9B-BQVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8
MI]BSV*H`V*C8K]F(V88@V8+9B-BGV+G8KP#8J-BOV8C9AB#9OMF'V839B`#9
MOMBTV*K;C-BHV*?9AB`G)7,G(-F^VXS8K]BGV8;8M-BO+@#:J=BTV8@@V879
MB-F"V*K;C"#8J-BQV*?;C"#8K=BGV8'8N-F'(-F%V8C8K-F(V*\@V8;9BMBS
MV*H`V8?9BMJ&(-F&V*?9A2#:J=BGV+'8J-BQVXP@V8@@V8K8IR#8L=F%V+(@
MV+G8J-F(V+';C"#8I]BQV+/8I]F$(-F&V+38K]F'(-BGV+/8J@#9A]F*VH8@
MV*_8I]BOV8<@6$U,(-F%V+G8JMBHV+';C"#8J-BGV++:K]BQV*_8I]F&V*_9
MAR#9AMBTV*_9AR#8I]BSV*H`V*C8K]F(V88@V879@MBOV*?8L0#9AMBSV*[9
MA^*`C-BGVXP@V*_8L2#9OMF*VJG8L=BHV8;8K]N,(-BGV+79A-N,(-F^V8K8
MK]BG(-F&V+38KRX@V;[9BMJIV+'8J-F&V*_;C"#8L=BG(-BOV8C8J-BGV+'9
MAR#8JMF(V839BMBO(-JIV8;9BMBO`-F&V+/8KMF'XH",V*?;C"#8K]BQ(-F^
MV8K:J=BQV*C9AMBOVXP@V+39A=BG(-F^V8K8K]BG(-F&V+38K]F'(-BGV+/8
MJBX@V;[9BMJIV+'8J-F&V*_;C"#8L=BG(-BOV8C8J-BGV+'9AR#8JMF(V839
MBMBO(-JIV8;9BMBO`-BHV*_9B-F&(-BTV+':J=BJ(-JIV8;9AMBOV8<`V8?9
MBMJ&VJG8K]BGV84`V8?9BMJ&VJG8K]BGV84@*-BVV879AMN,(-BGV+/8JMF!
MV*?8K]F'(-JIV8;9BMBO*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0#9AMF*V84@
MVJG8L=F'(-BTV878I]F$VXP`V8;9AR#8J-BYV*\`V8;9AR#9@MBHV80`VJG8
MM-F((-F&V8K8L]BJ`-F^V8K8I]BOV8?B@(S8L]BGV++;C"#9AMBTV*_9AR#8
MI]BSV*H`V*K9AMBXV8K9A2#9AMBTV*_9AP`@V;[8M-BJV8K8J-BGV8;;C"#9
MAMF%V8KB@(S8M-F(V*\@`-F*V*?8K]BOV*?8M-BJV8?8IP#:AMF*V++;C"#8
MJ-BQV*?;C"#9A=BQV8C8L2#9AMF*V+/8JMB,(-BHV8<@V+G9@MBH(-BHV+':
MK]BQV*\`V*?8KMBWV*?8L0#9AMF(V*?9A=BHV+$`V+G8K]BO`-BJV+G8K]BG
MV*\@VJG8I]BQV*?:J=BJV+'9A]BG`-BJV+G8K]BGV*\@V+/8JMF(V8;9A]BG
M`-BJV+G8K]BGV*\@V+/8M]BQV8?8IP#8I]BYV*_8I]BOVXP@V*C8L=BGVXP@
MV*C9AR#8L=F(V+(@V8;9A=F(V*_9AB#9@=F'V+'8L]BJ(-BJV8C8LMF*V+G;
MC"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*H`V+78K=F*V*T@V*?8L]BJ`-BT
MVXS8H0#8I]F*V*S8I]BO(-JIV8;9AMBOV8<@V+3;C-BA`-BGV*S8I]BRV8?B
M@(S9A]BGVXP@V*_8L]BJV+'8L]N,(-BJV8C9A-F*V*\@VJG9AMF&V*_9AR#8
MM-N,V*$`V8?8M-BJV*?9BMF*`-BGVJG8JMBHV+$`V8'9BMF$V*K8L2#8J-F*
MXH",V*W8L=F%V*K9B@#8K]F!V*K8L2#:J=BGV+$`V*?8L]F%(-BQV878LB#9
M@MBOVXS9A=N,.@#8JMF&V8?8IR#8L]BQV8C8L2!)34%0V;[9B-BTV8?B@(S9
MA]BGVXP@V878M-BJV+':J2#8L=BG(-F^V+38JMF*V*C8I]F&VXP@V87;C.*`
MC-JIV8;8KR``V*K9AMF'V*<@V8K:J2#8HMBOV+'8LR#9OMBSV*H@V*?9A-JI
MV*K8L=F(V8;9BMJIVXP@V*?8K-BGV++9AR#8K]BGV*_9AR#9A=N,XH",V+39
MB-BO`-BJV8;9A]BG(-BUV*?8K=BH(-F*V*<@V878K]F*V+'9BMBJ(-BSV8K8
ML]BJV84@V87;C.*`C-BJV8C8I]F&V*\@V878I]F$VJG9BMBJ(-F*V*<@V*?8
MK-BGV++9A^*`C-F'V*?;C"#8K]BSV*K8L=BSVXP@V+78I]BMV*@@V+'8IR#8
MJ-BQV*?;C"#9BMJI(-BGV+38JMBQV*?:J2#8JMBZV8K9BMBQ(-BOV8?8KP#8
MK]BQ(-F*VJD@V;[9AMBLV+'9AR#8K-BOV8K8KR#8J-BGV+(@V+39B-BO`-BG
MV8K9AB#9OMF*V8C9AMBO(-BOV+$@V8K:J2#9OMF&V*S8L=F'(-BLV*_9BMBO
M(-BHV*?8LB#8M-F(V*\`V+/9BMBSV*K9A2#8N=BGV879A`#8M-BQV8K:J2#8
MI]F&V*K8KMBGV*C;C`#:K]BRV8K9AMF'XH",V8?8IP#:K]BRV8K9AMF'XH",
MV8?8I]N,("5S`-JOV++9BMF&V8?B@(S9A]BG.@#9A-F*V+/8JB#9A=BQV*K8
MJ"#8M-BOV8<`V+/8I]BRV878I]F&`-F(V*?8K=BO(-BSV*?8LMF%V*?9AMN,
M`-BSV*?8LMF%V*?9AMBOV8?;C`#8I]F$VJ_9B-N,(-BGV+79A-N,(-BHV+'9
MAMBGV879AR#:J=BGV+'8J-BQV*_;C`#8I]F$VJ_9B-F'V*?;C"#8I]BUV83;
MC"#8K]BQ("5S.@#8K]F*VJ_8L0#8I]BWV838I]BYV*?8JB#8K]F*VJ_8L0#8
MI]BLV*?8LMF'XH",V8?8I]N,(-BOV+/8JMBQV+/;C"#9A=BGV83:J0#8JMBU
MV*_9BMF"(-F'V8C9BMBJ(%!!32#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@V8;9
MBMBSV*H`(%!'4-BGV878MMBGV*'B@(S8K]F*V*S9BMBJV*?9A-N,(`#9OMF*
MV+K8I]F%(-BQV878LMF&VJ_8I]BQVXP@V+38K]F'(%!'4``@VJG9A-F*V*\@
MV+G9A=F(V87;C"!01U``V;[9BMBZV*?9A2#8L=F%V++9AMJOV*?8L=N,(-BT
MV*_9AR_8I]F%V+;8I]BA(-BTV*_9AR!01U``VJG8KR!02%``V;[9B-BSV*K9
MAR!02%``V*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BYV+78L=JOV*?9A]N,`-BQ
MVJ_8J-BGV+$@V+G8M=BQVJ_8I]F'VXP`V*C8L=F!(-BYV+78L=JOV*?9A]N,
M`-BJVJ_8L=JO(-BYV+78L=JOV*?9A]N,`%0M4W1O<FUS`-F^V8C8L]BJV8<@
M4$A0`-BHV*?8LB#:J=BQV*_9ABXN+B``V8+8L]F%V*K;C"#8I]BHV+';C`!0
M87-S=V0@V*C9AR#8M]F(V+$@VJG8I]F%V80@V;[;C-JIV+'8J-F&V*_;C"#9
MAMBTV*_9AR#8I]BSV*HN`-BQV878LB#8N=BHV8C8L0#8I]BSV84@V+'9A=BR
M(-BHV+$@)7,@V*K8NMN,VXS8L2#;C-BGV8'8JBX`V+'9A=BR(-BYV*C9B-BQ
M(-F&V*?8K]BQV+/8JB#8I]BSV*H`V878K]F(V80@V*?8L]F%(-BQV878LB#8
MJ-BGVXS9AMBQVXP@V879B-BQV*\@V8;;C-BGV+(@V+'8IR#9AMBJV8C8I]F&
MV+/8JB#9OMN,V*_8IR#:J=F&V*\N`-F%V*_9B-F$(-BGV+/9A2#8L=F%V+(@
MV;[8I]BQV*?9A=BJV+'9A]BGVXP@V879B-BQV*_9AMN,V*?8LB#8L=BG(-F&
MV*_8I]BQV*\N`-F%V*_9B-F$(-BGV+/9A2#8L=F%V+(@V;[8I]BQV*?9A=BJ
MV+'9A]BGVXP@V879@MBUV*\@V+'8IR#9AMBOV*?8L=BO+@#9A=BOV8C9A"#8
MI]BSV84@V+'9A=BR(-BHV8<@V+?9B-BQ(-F%V8;8I]BSV*@@V;[;C-JIV+'8
MJ-F&V*_;C"#9AMBTV*_9AR#8I]BSV*H`V878K]F(V80@V*?8L]F%(-BQV878
MLB#8J-F'(-BWV8C8L2#:J=BGV879A"#9OMN,VJG8L=BHV8;8K]N,(-F&V+38
MK]F'(-BGV+/8JBX`V+'9A=BR(-BYV*C9B-BQ(-BHV8<@V*K8M=BOV8K9@B#9
MA]F(V8K8JB!2041)55,@V8;9BMBGV+(@V*_8I]BQV*\`V+'9A=BR(-BYV*C9
MB-BQ(-BHV*<@V*K8H]F*V8K8KP#8L=F%V+(@V+G8J-F(V+$Z`-BQV878LB#8
MN=BHV8C8L3H@`-BQV878LB#8N=BHV8C8L>*`C-F'V*<@V*C8I]F*V*\@V879
MAMBWV*C9@B#8J-BGV+38KP#:AMBSV*C8I]F&V*_9A@#:AMBSV*C8I]F&V*_9
MAB#8I]BR(-BJV*[8JMF'(-BQV+/9A0#9A=BSV8K8L0#8I]F!V+'8I]BO`-BO
MV+'8M=BO`-BGV*S8L=BGVXP@V+G9A=F$V8K8I]BJ(-F&VJ_9A]BOV*?8L=N,
M`-BBV8K8IR#8N=F%V839BMBGV*H@V8;:K]F'V*_8I]BQVXP@V838K=BXV8<@
MV8C8L=F(V*\@V*?8K-BQV*<@V+39B-BOV)\`V*?8K-BGV++9AR#8K]BSV*K8
ML=BSVXP`V*?8K-BGV++9AR#8K]BSV*K8L=BSVXP@)R5S)R#8K=BPV8$@V8;8
MM-BOV8<@V*?8L]BJ`-F%V*_9BMBQV8K8JB#8I]BLV*?8LMF'XH",V8?8I]N,
M(-BOV+/8JMBQV+/;C`#8I]BLV*?8LMF'XH",V8?8I]N,(-BOV+/8JMBQV+/;
MC"#8J-BQV*?;C`#8I]BWV838I]BYV*?8JB#8M-BNV+7;C`#8K=F*V8C8I]F&
MV*?8JB#8KMBGV8;:K]N,`-BJV839@=F&`-BYVJG8L^*`C-F'V*<`V;[9BMJI
MV+/9A`#9A-BWV8'8I]F+(-BOV*?8KMF$(-F*VJG;C"#8I]BR(-BSV839B-F$
MV8?8IR#:J=F$V8K:J2#:J=F&V8K8KP#9A-BWV8'8I]F+(-BJV*/9BMF*V*\@
MVJG9AMF*V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?9BMBO(-BGV8K9AB#8N=F&
MV+78L2#8L=BG(-BMV+#9@2#:J=F&V8K8KSH`V838M]F!V*?9BR#8JMBCV8K9
MBMBO(-JIV8;9BMBO(-JIV8<@V87;C.*`C-BNV8C8I]F'V8K8KR#8I]F*V88@
MV+G9AMBUV+'9A]BG(-BQV*<@V*?8LB#9A]F%(-BLV*_8IR#:J=F&V8K8KP#9
MA-BWV8'8I]F+(-F*VJD@V878I]F'(-F((-BSV*?9A"#9B-BGV+'8KR#:J=F&
MV8K8KRX`V838M]F!V*?9BR#9AMBGV87;C"#8J-BQV*?;C"#:K]BQV8C9AR#8
MK-BOV8K8KR#9B-BGV+'8KR#:J=F&V8K8KSH`V838M]F!V*?9BR#8HMBOV+'8
MLR!)4"#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;9BMBO`-F$V+?9@=BGV8L@
MV8K:J2#8JMBGV+'9BMBN(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMF*V*_8
MC"#8JMBYV*_8I]BO(-BQV8C8LMF'V*<@V*_8L2#9A=BGV8<@V+'8IR#:J=F&
MV*K8L=F$(-JIV8;9BMBO`-F$V+?9@=BGV8L@V8K:J2#8LMF%V*?9AB#9A=BY
MV*K8J-BQ(-F(V*?8L=BO(-JIV8;9BMBO`-F$V+?9@=BGV8L@V*[9A-BGV+79
MA^*`C-BGV8K;C"#8I]BR(-F%V+3:J=F$(-BQV*<@V*C9AMF(V8K8L]F*V*\`
MV838M]F!V*?9BR#9AMBGV84@VJG8I]BQV*C8L2#9B"#8L=F%V+(@V+G8J-F(
MV+$@V*[9B-BO(-BQV*<@V*+9A=BGV*_9AR#:J=F&V8K8KP#9A-BWV8'8I]F+
M(-F%V*K9AB#8LMF*V+$@V+'8IR#8J-BNV8C8I]F&V8K8KRX@V+39A=BG(-BH
MV+'8I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V+/9BMBSV*K9A2#8J-BGV8K8
MKR#8M-BQV+?B@(S9A]BG(-BQV*<@V8+8J-F(V80@VJG9AMF*V*\`V838M]F!
MV*?9BR#9A]BQ(-BGV+3:J=BGV83;C"#8L=BGV*C9AR!I,3AN0&QI<W1S+FAO
M<F1E+F]R9R#:K]BRV*?8L=BT(-BOV8?9BMBO`-F$V+?9@=BGV8L@V*?8M]F$
MV*?8N=BGV*H@V++9BMBQ(-BQV*<@V878L=F(V+$@VJG8L=BOV8?8C"#9B"#8
ML]F^V+,@V8K:J2#9@=BYV*?9A-F*V*H@V*?8LB#9A-F*V+/8JB#8I]F&V*K8
MKMBGV*@@V++9BMBQ(-BQV*<@V*C8L=JOV++9BMF&V8K8KP#9A-BWV8'8I]F+
M(-F*VJD@V8'8N=BGV839BMBJ(-BGV+(@V839BMBSV*H@V*?9AMBJV*[8I]BH
M(-BRV8K8L2#8L=BG(-BHV+':K]BRV8K9AMF*V*\`V838M]F!V*?9BR#9AMBG
MV84@VJ_8L=F(V8<@V*S8K]F*V*\@V+'8IR#9B-BGV+'8KR#:J=F&V8K8KSH`
MV+/9BMBGV+/8JN*`C-F'V*<`V*+8L=BGV*$`V878K=F$(-F"V+'8I]BQVJ_8
ML=F!V*K9AB#8I]F*V88@V*K8M=F(V8K8L0#9A=BMV80@V8+8L=BGV+':K]BQ
MV8'8JMF&(-BGV8K9AB#8K-BOV8C9A`#9OMBSV*H@V*C9AR#8I]F*V88@V;[9
MB-BTV8<`V*_8L=BUV*\@V+'8M]F(V*C8JB#8K]BQ("5S(-BSV*?8N=BJ(-F"
MV*C9A#H`4')E9G-?;&1A<#H@V*C8L]BW(-F%V8C8L=BO(-F&V8K8I]BR($Q$
M05`@V;[9BMBOV*<@V8;8M-BO`%!R969S7W-E<W-I;VXZ(-BHV+/8MR#9A=F(
MV+'8KR#9AMF*V*?8LB!S97-S:6]N(-F^V8K8K]BG(-F&V+38KP#8I]BQV*?8
MIMF'XH",V8?8IP#9@=BTV*?8L0#9@=BTV*?8L2#8K]BQ(-BSV+?8K2#8K]BQ
MV8K8ISH@`-F!V+38I]BQ.B``V;[9BMBT(-F&V878I]F*V+0`V;[9BMBT(-F&
MV878I]F*V+0@V*K8M=F(V8K8L2#8K]BQ(-F*VJD@V;[9AMBLV+'9AR#8K-BO
MV8K8KR``V+79@=BMV8<@V8+8J-F$VXP`VJ_8LMF*V8;9A^*`C-F'V*?;C"#9
M@MBHV83;C`#:AMBGV;X@V+/9AMBO`-JIV839BMBO(-BTV*[8M=N,`-F%V+3:
MJ=F$`-BJV8C8MMF*V*T@V878M-JIV80`V;[8L=F(VIC9A^*`C-F'V*<`V878
MJMF&(-BBV878I]BOV8<`VJG9A-F*V*\@V+G9A=F(V87;C`#8I]F$VJ_9B-BQ
MV8K8JMF%(-JIV839BMBO(-BYV879B-F%VXP`V*S9@=BJ(-JIV839BMBO(-BY
MV879B-F%VXPOV*[8M=F(V+7;C"#8J-BWV8C8L2#9A=F(V8'9@MF*V*H@V*+9
MA=F*V+(@V*K9B-F$V8K8KR#9AMBTV*\`V;[8L=BS(-F((-BLV8@`(-JIV839
MBMBO(-BYV879B-F%VXP@4E-!("@E9"#8J-F*V*HI`-BGV8;8JMBNV*?8J"#8
ML=BGV*_9BMF(`-BHV*?8L=BGV88`V*C8I]BQV8;8K]JOVXP@V+78K=BQVJ_8
MI]F'VXP`V*C8I]BQV*?9AB#8K]F*V+':K]BGV8?;C`#8J-BGV+'8I]F&(-F(
M(-BQVJ_8J-BGV+$`V*C8I]BQV*?9AB#9B"#8J-BQV8$`V*C8I]BQV*?9AB#9
MB"#8J-BQV8$`V+?8I]F$V+D@V*K8M=BGV*_9@=N,`-BNV8C8I]F&V*_9A@#8
MKMF(V*?9AMBOV88@V;[9BMBZV*?9A>*`C-F'V*<@`-F(V*?9@MBYV*,@)7,@
MV*W8L-F!(-BTV8C8K]B?(-BGV8K9AB#8N=F%V80@V8+8I]BHV80@V*C8L=JO
MV+38JB#9AMF*V+/8J@#9B-BGV8+8N=BGV8L@V*_8I]BOV8<@VJG8I]BQV*C8
ML=N,(-BHV+'8I]N,(-JIV*?8L=BHV+$@)7,@V*C8L=BOV*?8M-BJV8<@V+39
MB-BOV)\@V*?9BMF&(-BYV879A"#9@MBGV*C9A"#8J-BQVJ_8M-BJ(-F&V8K8
ML]BJ`-BBV*[8L=F*V88@V+G9A=F$(-BNV8C8KR#8L=BG(-BOV8C8J-BGV+'9
MAR#8I]F&V*S8I]F%(-BOV8?9BMBO`-BYV8;8I]BUV+$@V879AMF((-BOV8K9
MAMBGV879BMJIVXP@V+'8IR#9AMF(V+/8I]BRVXP@VJG9AMF*V*\Z`-F&V8C8
ML]BGV++;C"#9AMF%V*?;C"#9OMBQV*K8I]F$.@#9A=BQV8C8L=JOV+$@V+'8
MI]BHV+?9A^*`C-BGV8K;C`#8JMF(V+;9BMBMV*?8J@#8J-F'(-F*V*?8K]BO
MV*?8M-BJV88@V*?8M]F$V*?8N=BGV*H@9G)E92]B=7-Y`-BSV+'9B-BQV8?8
MI]N,(-BQV*?9AR#8K]F(V+$`55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3H`V*W8L-F!`-BMV+#9@2#8J-F$V8C:J0#8K=BPV8$@V+/8JMF(
MV88`V*C8L=BOV*?8M-BJV88@V8+8I]F$V*@@V*C9AMBOVXP`V*?8LB#8JMF"
MV8C9BMF%(-F%V88@V;[8I]JI(-BTV8C8KP#8K=BPV8$@V8?8L=BOV8@`V*W8
ML-F!(-BGV+/:J=BQV8K9OMBJXH",V8?8I]N,(-BPV*[9BMBQV8<@V+38K]F'
M(-BOV+$@VJG8M-F((-F%V8C9@MBJ(-BSV+'9B-BQ`-BMV+#9@0#8K=BPV8$@
MV*?9BMF&(-JOV+'9AR#8I]BR(-BSV8;8KP#8K=BPV8$@VJG8I]BQV*C8L0#8
MK=BPV8$@VJG8I]BQV*C8L3H@)7,`V;[8I]BSV*X@V8'8L=BSV*K8I]BOV8<@
MV+38KP#9OMBGV+/8KB#8J-BG(-F^V8K8NMBGV84@V;[8M-BJV8K8J-BGV8;;
MC"#9AMBTV*_9AP#9OMBGV+/8KB#8K]BGV*_9AB#8J-BG(&9R964O8G5S>2#8
MJ-BQV*?;C"`R(-F%V*?9AR#8HMF*V8;8K]F'`-F^V*?8L]BN(-BOV*?8K]F&
M(-BHV*<@V*?8M]F$V*?8N=BGV*H@9G)E92]B=7-Y(-BNV8C8I]BSV*K9AR#8
MM-BOV8<`V;[8I]BSV*XZ("5S`-BJV8+8I]BVV*<@V8+8I]BHV80@V;[8I]BS
MV*[:K]F(V8K;C"#9AMF*V+/8JBX@V+39A=BGV+'9AR#8KMBWV*?;C"#8J-BQ
MVJ_8L=BOV*?9AMBOV8<@V+38K]F'.@`G)7,G(-F%V8C8L=BO(-F&V8K8I]BR
M(-BOV+$@V;[9BMJIV+'8J-F&V*_;C"`E<R#9A=BTV*[8M2#9AMBTV*_9AR#8
MI]BSV*H`)R5S)R#9A=F(V+'8KR#9AMF*V*?8LB#8K]BQ(-F^V8K:J=BQV*C9
MAMBOVXP@5D93(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8J@`G)7,G(-F%V8C8
ML=BO(-F&V8K8I]BR(-BOV+$@V;[9BMJIV+'8J-F&V*_;C"#9A=BTV*[8M2#9
MAMBTV*_9AR#8I]BSV*H`V8';C-F$V*\@)V1R:79E<G,G(-BOV+$@V;[;C-JI
MV+'8J-F&V*_;C-B,(-BZV838MR#9OMN,VJG8L=BHV8;8K]N,(-BTV*_9AR#8
MI]BSV*HN`-F!VXS9A-BO("=P:'!T>7!E)R#8K]BQ(-F^VXS:J=BQV*C9AMBO
MVXP@V878K]F(V80@<&%S<W=D("#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*HN
M`-F!VXS9A-BO("=P:'!T>7!E)R#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@4U%,
M(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JBX`V8'9BMF$V*_9A]BGVXP@V879
MB-BQV*\@V8;9BMBGV+(`V8;9BMBGV+(@V+38L=F*VJD`V*C8I]BRV8;8M-BG
MV8;;C`#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@V*_9B-BHV*?8L=F'(-BQV878
MLMBYV*C9B-BQ`-BQV*?9A^*`C-BGV8;8K]BGV++;C"#8K]F(V*C8I]BQV8<@
MV+'9A=BRV+G8J-F(V+$@V+39A=BG`-F&V*K8I]F*V*P`V8;8JMBGV8K8K"`H
MV+38I]F%V80@V8?9B-BQV*\I.@#9AMBJV*?9BMBL.@#8J-BGV++:K]BTV*H@
MV*C9AR#:K]BRV8K9AMF'XH",V8?8IP#:K]BQV*_9A]F%V*?9BMN,`-BHV*?8
MLMJOV+'8K]BGV8;8K]F&(-F^V8K:J=BQV*C9AMBOVXP`VJ_8LMF*V8;9A^*`
MC-F'V*?;C"#9B-F*V+'8I]F*V+3:K]BQ(-F%V*K9A@#8NMBQV*C8I]F$XH",
MV8?8IP#8L=BGV+/8J@#8L]BQV*+9A=BO(-BQV*?8L]BJ`-F%V8+8I]BOV8K8
ML2#8L=BGV+/8J@#9B-F*VIC:K]F*V8?8I]N,(-BSV+?8L2XN+@#9AMF"V+0`
MVH;8L=BNV+0@,3@P(-BOV+'8K-F'`-J&V+'8KMBT(-BHV8<@VH;9O@#:AMBQ
MV*[8M"#8J-F'(-BQV*?8L]BJ`-F(V8K:F-JOV8K9A]BGVXP@V+/8M]BQ`-F(
MV8K:F-JOV8K9A]BGVXP@V+/8M]BQ`-BSV+?8L=F'V*<Z`-F"V8C8I]BYV*\`
MV8+9B-BGV+G8KR#9A=F*V*?9AB#8JMF%V*?9A2#8L]BWV+'9A]BG(-F((-BS
MV*K9B-F&V8?8IR#8I]BYV878I]F$(-BNV8C8I]F'V*\@V+38KP#9@MF(V*?8
MN=BO(-F%V8K8I]F&(-BJV878I]F%(-BSV*K9B-F&V8?8IR#8I]BYV878I]F$
M(-BNV8C8I]F'V*\@V+38KP#9@MF(V*?8N=BO(-F%V8K8I]F&(-BJV878I]F%
M(-BSV+?8L=F'V*<@V*?8N=F%V*?9A"#8KMF(V*?9A]BO(-BTV*\`V*?8K-BQ
MV*<`V+'9A=BRV8;:K]BGV+';C"!3+TU)344@V;[9BMBZV*?9A0#8JMBUV*_9
MBMF"(-F'V8C9BMBJ(%-!4TP@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&V8K8
ML]BJ`-F^V8K8NMBGV84@4TU3`-F^V8C8L]BJV8<@4U%,`%-3`%-32`#9A=F(
MV8'9@MF*V*H`V;[9B-BSV*K9AR!344P`V+39AMBHV8<`V8?9A=BGV88@VH;8
MI]BQVH;9B-BH("C8KMF(V*_8M"D`V+#8KMF*V+'9AP#8L-BNV8K8L=F'("5S
M`-BPV*[9BMBQV8<@)R5S)P#8L-BNV8K8L=F'(-JOV++9BMF&V8?B@(S9A]BG
M`-F^V8K:J=BQV*C9AMBOVXP@V*K9B-F$V8K8KR#8M-BOV8<@V*C8N=F&V8C8
MI]F&(-F%V*K9AB!02%`@V*_8L2#:J=BTV8C;C"#9A=F(V8+8JB#8L]BQV8C8
ML2#8M-F%V*<@V+#8KMF*V+'9AR#8M-F(V*\`V;[9BMJIV+'8J-F&V*_;C"`E
M<R#8L-BNV8K8L=F'(-BTV*\`V+'9B-BGV80@V*C9AR#8L=F(V+(@VJG8L=BO
MV88@V*K9AMBXV8K9A=BGV*H@V+#8KMF*V+'9AR#8M-BO(-BOV+$@.B<E<R<@
M+@#8N=F$V8C9A0#8K-BSV*K8K-F(`-F%V8C8JMF(V+'9A]BGVXP@V*S8L]BJ
MV*S9B`#8K-BSV*K8K-F(VXP@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-JIV*?8
ML=BHV+'8K]N,(-F'V8C8L=BO(-BOV+$@)7,`V*S8L]BJV*S9B"#8J-BGV8K9
MAMBQVXSB@(S9A]BGVXP@9V5T=&5X="XN+@#8I]F&V*K8KMBGV*@@V;[8L=F(
MV8;8K]F'XH",V8?8IP#8I]F&V*K8KMBGV*@@V8K:J2#8JMBGV+'9BMBN`-BG
MV8;8JMBNV*?8J"#9BMJI(-JOV+'9B-F'(-BHV+'8I]N,(-BGV+;8I]F!V8<@
MVJG8L=BOV88`V*?9AMBJV*[8I]BH(-F*VJD@V878I]F$VJD@V*S8K]F*V*\`
MV*?9AMBJV*[8I]BH(-F*VJD@V+/8L=F(V+$`V*?9AMBJV*[8I]BH(-F*VJD@
MVJG8I]BQV*C8L2#8J-BQV*?;C"#8I]BVV*?9@=F'(-JIV+'8K]F&`-BGV8;8
MJMBNV*?8J"#8JMF%V*?9A2#8I]BLV++8I]BA(-BJV*?8L=F*V*X`V*?9AMBJ
MV*[8I]BH(-F*VJD@V+38I@#9AMF(V8K8L]F'XH",V8?8I]F*VXP@VJG9AR#9
MA-BGV++9A2#8K]BGV+'9BMBO(-BQV*<@V*?8LB#8K-BYV*C9AR#8LMF*V+$@
MV*?9AMBJV*[8I]BH(-JIV8;9BMBO+B#8L]F^V+,@V+39A=BG(-F%VXSB@(S8
MJMF(V*?9AMF*V*\@V*+9AMF'V*<@V+'8IR#8I]BR(-F%V8;8M]F"V8<@V878
MJMF&(-JIV;[;C"#:J=BQV*_9AR#9B"#8J-J&V+/8J-BGV8;9BMBO`-BGV8;8
MJMBNV*?8J"#9A=BMV*_9B-BOV8<@V*K8I]BQV8K8KCH`V*?9AMBJV*[8I]BH
M(-F"V*?9A-BH(-BJV*?8L=F*V*XZ`-BGV8;8JMBNV*?8J"#9A]F(V8K8JMN,
M(-JIV8<@V87;C.*`C-BNV8C8I]F'V8K8KR#8JMBZV8K9BMBQ(-BOV8?9BMBO
M.@#8I]F&V*K8KMBGV*@@V878K=BOV8C8K]F'(-BRV878I]F&.@#8I]F&V*K8
MKMBGV*@@V8+8I]F$V*@@V++9A=BGV88Z`-BGV8;8JMBNV*?8J"#8K]F((-F!
MV8K9A-BO(-F%V8;8M]BHV8(`V*?9AMBJV*[8I]BH(-BWV+'8K2#8L=F&VJ\@
MV+39A=BG`-BGV8;8JMBNV*?8J"#8LMBHV*?9AB#9A=F(V+'8KR#9AMBXV+$@
MV+39A=BG.@#8I]BQV+/8I]F$(-BBV*[8L=F*V88@V*?8M]F$V*?8N=BGV*H`
MV*?8L=BSV*?9A"#:K]BRV*?8L=BT`-BGV+'8L]BGV80@4TU3`-BMV+/:K]BQ
M.B``V+/9OMBJV*?9A=BHV+$`V*?8N=BOV*?8KR#8JMBQV*K9BMBHVXP`240@
MV8;8M-BSV*H@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ`-BJV8;8N-F*V84`
MV*?9AMBJV*[8I]BH(-JOV++9BMF&V8?B@(S9A]BG(-BHV+'8I]N,(-BGV*S8
MI]BRV8<@V*_8I]BOV88@V*C9AR#8M-F%V*<@V*C8L=BGVXP@V+'8I]F'XH",
MV*?9AMBOV*?8LMN,(-BOV8C8J-BGV+'9AR#8L=F%V+(@V+G8J-F(V+'8J-F'
M(-F'V8;:K]BGV84@V8'8L=BGV879B-BTVXP@V*+9AB``V*K9AMBXV8K9A2#8
ML]BQV8C8L=F'V*?;C"#8L=BGV8<@V*_9B-BQVXP@VJG9AR#8M-F%V*<@V87;
MC.*`C-BNV8C8I]F'V8K8KR#8I]BR(-F^V+'8JMBGV80@V*[9B-BO(-BHV8<@
MV*+9AB#8K]BSV*K8L=BSVXP@V*_8I]BTV*K9AR#8J-BGV+39BMBO`-BGV8;8
MJMBNV*?8J"#8LMBHV*?9AB#9A=F(V+'8KR#9AMBXV+'8C"#8L]BGV+G8JB#9
MB"#:K]BRV8K9AMF'XH",V8?8I]N,(-BJV*?8L=F*V*X`V*?9AMBJV*[8I]BH
M(-BHV+'9AMBGV879AR#8LMF%V*?9AB#8M-BQV8C8N=B,(-BQV8;:KR#8J-F&
MV*_;C-B,(-F&V8C8L]BGV++;C"#8M=F!V*W9AR#9B"#8J-F"V8K9AR#:K]BR
MV8K9AMF'XH",V8?8I]N,(-F&V878I]F*V+0`V*K9AMBXV8K9A=BGV*H`V+'9
MB-BGV80@V*C9AR#8L=F(V+(@V+'8L]BGV8;;C"#8JMF&V+C9BMF%V*?8JB#8
MK]BQ(-BOV+/8JMBQV+,@V*?8L]BJ`-J&V8;8K]F*V88@V879B-F"V+G9BMBJ
M(-BHV*<@V;[8I]BQV*?9A=BJV+$@V879B-BLV8C8KR#8I]BSV*HZ`-BNV+'9
MBMBO`-BNV838I]BUV8<@VJG9B-BJV*?9AP#8HMF*V*<@VJG9A-F*V*_9A]BG
MVXP@V*_8L]BJV+'8L]N,(-BHV*?9BMBO(-BHV+'8I]N,(-BHV8K8M-BJV+$@
MV;[9BMF(V8;8K]F'V*<@V*K8N=BQV8K9@2#8M-F(V8;8K]B?`-F&V878I]F*
MV+0`(-F&V878I]F*V+0@V*K9@=BGV8C8JMF'V*?;C"#9A=F*V*?9AB#9OMF*
MVJG8L=BHV8;8K]N,(-BPV*[9BMBQV8<@V+38K]F'(-F!V+G9A-N,(-F((-BJ
MV8C9A-F*V*\@V+38K]F'(-BLV*_9BMBO`-BBV8K8IR#8LMF%V*?9AB#8HMBN
MV+'9BMF&(-F(V+'9B-BO(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#9AMBT
MV*?9AB#8K]BGV*_9AR#8M-F(V*_8GP#9AMF%V*?9BMBT(-JOV++9BMF&V8?B
M@(S9A]BG(-BHV+'8I]N,(-F&VJ_9A]BOV*?8L=N,(-BGV+79A-F*V*H`V*?9
MAMBJV*[8I]BH(-F#V8;9AMBOV8<@V8;9A=BGV8K8M`#9A=F*V839AR#8N=F%
MV839BMBGV*H@V*S8K]BGV8C9A.*`C"#9AMF%V*?9BMBT(-BOV*?8K]F'(-BT
MV8C8K]B?`-BBV8K8IR#9A=F&V8@@)7,@V+/9A=BJ(-J&V;X@V8;8M-BGV88@
MV*_8I]BOV8<@V+39B-BOV)\`V8;9A=BGV8K8M"#8K]F*V*?9A-F(VJ\@V*[8
MM=F(V+79BMBGV*H@V+/9A-F(V80@V*S8K]F(V80`V8;9A=BGV8K8M"#8K]F*
MV*?9A-F(VJ\@V*[8M=F(V+79BMBGV*H@V*S8K]F(V80`V8;9A=BGV8K8M"#8
MK]F*V*?9A-F(VJ\@V*[8M=F(V+79BMBGV*H@V+/8M]BQ(-BLV*_9B-F$`-F&
MV878I]F*V+0@V*_9BMBGV839B-JO(-BNV+79B-BUV8K8I]BJ(-BYVJG8LP#9
MAMF%V*?9BMBT(-BGV+'8L]BGV80`V*K:K]BQVJ\`V+':K]BHV*?8L2#8LMF(
MV*_9A]F&VJ_8I]F%`-BQVJ_8J-BGV+$@V*_9BMBQV8?9AMJOV*?9A0#:AMBQ
MV8C:J2#8M-BOV88`V+G8MMF((-BTV*_9A@#8N=BVV8@@V+38K]F&(-BOV+$@
MV+79B-BQV*H@V*O8J-BJ(-F&V+38K]F'(-BHV8C8K]F&`-BGV878MMBGV*$`
MV*?9A-JOV8C8L=F*V*K9A2#8I]F%V+;8I]BA`-BGV8;8K]BGV++9AP#8M=BQ
MV8'9AMBXV+$@V*?8LB#9AMJOV8?8K]BGV+';C`#8M=BQV8'9AMBXV+$@V+38
MKRXN+@#8J-BQV8$`V*K:K]BQVJ\`V*K:K]BQVJ\`V+':K]BHV*?8L2#8K]F*
MV+'9A]F&VJ_8I]F%`-BYV879@B#8J-BQV8$Z(`#9A=BYV*?8K]F$(-BHV+'9
M@2#8K]BQ(-BBV*@Z(`#8M-BYV+$@V8@@V*+9B-BGV+(`V878L=BJV*@@V+/8
MI]BRVXP@V*?9AMBJV*[8I]BH(-BLV8?8JN*`C-F'V*<`V*+8K]BQV+,@V879
MAMBHV+D`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`-F&V8K9A2#:J=BQ
MV8<@V*S9AMF(V*C;C`#9@=BGV+79A-F'(-BHV8K9AB#8L]F$V8C9A.*`C-F'
MV*?;C"#9A=BLV*?9B-BQ`-F!V*?8M=F$V8<@V*C9BMF&(-F%V*W8JMF(V*<@
MV8@@V838J-F'(-BOV+$@V+/9A-F(V80`V8'8I]BUV839AP#9@=BGV+79A-F'
M`-F!V*?8M=F$V8?B@(S:K]BPV*?8L=N,(-F((-BOV+'8LMJOV+#8I]BQVXP`
MV8?8L=BR(-F&V*?9A=F'`-JIV*?8L=BGVJG8JMBQ(-BNV*?8M2#9B-BGV+'8
MKR#8M-BO`-BJV8+8L]F*V84@V+/9A-F(V80`V*K9@MBSV8K9A2#8L]BJV8C9
MA@#8JMF"V+/9BMF%(-BSV+?8L0#9B-BQV++8M-N,`-BGV+/8JMBGV8;8K]BG
MV+'8KP#8M-BQV8C8N0#8L]BGV80@V+38L=F(V+D`V8C8MMBYV8K8JB#8K=F(
MV++9A^*`C-F'V*<`V8C8MMBYV8K8JN*`C`#9B-BVV+G9BMBJ(-BHV+'8I]N,
M(-F%V*W9A-F*V*H@)7,N+BX`V8+8I]F$V*@@V+#8KMF*V+'9AR#8L]BGV++;
MC`#8HMBOV+'8LR#8KMF*V*?8J-BGV88`V8'9A]BQV+/8JB#8L=BTV*K9AP#8
MM-F*V8C9AR!;0U-370#9BMJIV+39AMBHV8<`(-BRV8K8L2#8M-BGV*[9AR`E
M<R#9OMF*V*_8IR#9AMBTV*\N`-BYV8;9B-BGV88`V879B-BVV8C8N2#:J=F$
MV8K8KR#8N=F%V8C9A=N,(-BTV878IP#8I]BQV+/8I]F$`-BJV8+8I]BVV*?;
MC"#8I]BVV*?9@=F'(-BTV*_9AB`G)7,G(-BHV8<@V+/9BMBSV*K9A2#8L=BG
M(-BGV+'8L]BGV80@VJG9AMF*V*\N(-BJV*<@V8?9AMJOV*?9A=N,(-JIV8<@
MV*K9@MBGV+;8I]N,(-BTV878IR#8JMBCV8K9BMBO(-F&VJ_8L=BOV*\@V8;9
MA=N,XH",V*K9B-BGV8;9BMBO(-BHV8<@V+/9BMBSV*K9A2#9B-BGV+'8KR#8
MM-F(V8K8KP#8LMF*V+$@V8;9B-F*V+,`V879B-F!V8+9BMBJ`"<E<R<@V*C8
MIR#9A=F(V8'9@MF*V*H@V*C9AR#8L]F*V+/8JMF%(-BGV+;8I]F!V8<@V+38
MKP`@V*_8I]BOV8<@VJG8I]BQV*C8L2`G)7,GV*C8IR#9A=F(V8'9@MF*V*H@
MV*?8LB#8L]F*V+/8JMF%(-F^V*?:J2#8M-BO`"<E<R<@V*C8IR#9A=F(V8'9
M@MF*V*H@V*W8L-F!(-BTV*\`)R5S)R#8J-BG(-F%V8C9@=F"V8K8JB#8I]BR
M(-BSV8K8L]BJV84@V;[8I]JI(-BTV*\`V;[9BMJIV+'8J-F&V*_;C"#8J-BG
M(-F%V8C9@=F"V8K8JB#8J-BQVJ_8M-BJ(-F^V+#9BMBQV8'8JBX@V*C8L=BG
MVXP@V878M-BGV8?8K]F'(-BJV+K9BMF*V+'8I]BJ(-F%V*S8K]BOV*?9BR#8
MHMF&V+'8IR#8J-BGV+$@V8;9A=BGV8K9BMBO`-F^V+38JMF*V*C8I]F&(-BJ
MV8;8N-F*V878I]BJ(-BHV*<@V879B-F!V8+9BMBJ(-BPV*[9BMBQV8<@V+38
MKP#9OMBQV8C9AMBOV8<@V;[8M-BJV8K8J-BGV88@V*K9AMBXV8K9A=BGV*H@
M)7,@V*C8IR#9A=F(V8'9@MF*V*H@V+#8KMF*V+'9AR#8M-BO`"<E<R<@V*C8
MIR#9A=F(V8'9@MF*V*H@V*C9AR#8L=F(V+(@V+38KP`E<R#8J-BG(-F%V8C9
M@=F"V8K8JB#9AMF(V+38JMF'(-BTV*\`V*[9A-BGV+79AP#8M]F$V8C8N2#8
MHMF!V*K8I]BH`-BZV+'9B-BH(-BBV8'8JMBGV*@`V*+9@=BJV*?8J-N,`-BW
MV839B-BY`-BWV839B-BY+]BZV+'9B-BH`-BWV839B-BY.B``V+K8L=F(V*@`
MV+K8L=F(V*@Z(`#8J-BGV838IR#9AMF(V8K8LP#9OMBTV*K9BMBHV*?9AMN,
M`-F&V*?9A2#8KMBGV8;9B-BGV*_:K]N,`-BNV+?8I]N,(-F&V*W9B-N,(-BO
MV+$@V879B-BGV+'8KR#8K-BSV*K8K-F(`%0M4W1O<FUS`%0M4W1O<FUS`-F^
MV+'9B-F&V*_9AR!44U8`V*S8K]F(V80`V8C9BMJ8VJ_9BN*`C-F'V*?;C"#8
MK-BOV8C9A`#9B-F*VIC:K]F*XH",V8?8I]N,(-BLV*_9B-F$`-F'V*_9@3H`
MV8C8N-BGV8K9@0#8M-F%V*?8L=F'(-BJV839@=F&`-BOV878I]N,(-BSV*?8
MN=BJ(-JOV+#8M-BJV8<Z(`#8K]BQV*S9AR#8K=BQV*?8L=BJ`-BOV+'8K-F'
M(-BMV+'8I]BQV*HZ(``@V*?9A-JOV8C;C"`G)7,GV;[9BMBOV*<@V8;8M-BO
M`-BGV83:K]F(VXP@V878K]F*V+'9BMBJ`-BOV+'8KMF(V*?8L]BJ(-BHV+?9
MB-BQ(-BBV++9A=BGV8K8M-N,(-F^V+#9BMBQV8'8JMF'(-BTV*\`V*C8M]F(
MV+$@V*+8LMF%V*?9BMBTVXP@V;[8L-F*V+'9@=BJV8<@V+38K]F'`-F%V*K9
MA@#9@=F"V+<@V878JMF&`-BJV+'8I]BR(-F%V*K9A@#8J-BGV838I]N,(-F%
MV*K9A@#9OMF&V*S8M-F&V*C9AP!4:&%I("A425,M-C(P*0#8I]BR(-BTV878
MIR#8J-F'(-BNV*?8M]BQ(-BGV+/8JMF!V*?8K]F'(-BGV+(@V+/9BMBSV*K9
MA2#9A=BJV+3:J=BQV8K9A0#8J-BSV+<@1E10(-F"V*?8J-F$(-BOV+/8JMBQ
MV+/;C"#9AMF*V+/8J@#9OMBQV8C9AMBOV8?B@(P@V+'8I]F'V8;9A=BGVXP@
M)7,@V*C8L=BGVXP@)7,@V8?9AMF(V+(@V879B-BLV8C8KR#9AMF*V+/8JBX@
MV8K:J2#9OMBQV8C9AMBOV8?B@(P@V*S8K]F*V*\@V*C8L=BGVXP@V*+9AB#8
MI]F*V*S8I]BO(-JIV8;9BMBO`-F&VJ_9A]BOV*?8L=N,.CH@VJG9A-BGV+,@
MV*C8IR#9A=F(V8'9@MF*V*H@V*C8I]BQ(-F&V+38KP#9OMF&V*S8L=F'(-JO
MV++9BMF&V8?B@(S9A]BG(-BHV+/8JMF'(-BTV*\N(-BNV+'9B-BL`-BJV8;9
MA]BG(-F^V*?9BMF*V88`(-BOV*?8K]F'(-BJV8+9B-F*V84@V878N=BJV*C8
ML2#9AMF*V+/8JB``V+39A=BGV+'9AR!)1"#8JMF%V*?8LR#9A=BTV*[8M2#9
MAMBTV*_9AR#8I]BSV*K8C"#8I]F*V88@V+39A=BGV+'9AR#8K]BQ(-F^V*?9
MBMJOV*?9AR#8K]BGV*_9AR#9BMBGV8'8JB#9AMBTV*\`V*K9A=BGV+,@("5S
M(-BHV*<@V879B-F!V8+9BMBJ(-BHV8<@VJG8JMBGV*C:AMF'(-BBV*_8L=BS
M(-BGV+;8I]F!V8<@V+38KP!)1"#9@=F'V+'8L]BJ(-BJV8C8LMF*V+G;C"#9
MA=BTV*[8M2#9AMBTV*_9AR#8I]BSV*H@V8@@V8K8IR#8K]BQ(-F^V*?9BMJO
MV*?9AR#8K]BGV*_9AR#9A=F(V*S9B-BO(-F&V8K8L]BJ`-F!V8?8L=BSV*H@
MV*K9B-BRV8K8N=N,(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8J@#9A=BTV*[8
MM=F'XH",V8?8I]N,(-BQV878LMF&VJ_8I]BQVXP@V8;9BMBGV++9A=F&V*\@
MV8K:J2#8I]BQV*K9BMBGV+<@V*?9A=F&(-F(V*@@V87;C.*`C-BHV*?8M-BO
M`-BQV8C9BMBOV*?8KR#8J-F'(-BJV8+9B-F*V84@V+39A=BG(-BGV+;8I]F!
MV8<@V+38KP#9OMBQV8C9AMBOV8<@)7,@V*C8I]F*V*\@V*_8I]BQV*?;C"#8
MJMF&V+C9BMF%("5S(-BHV*?8M-BO`-F^V+'9B-F&V*_9AR`E<R#8J-BGV8K8
MKR#8K=BGV8C;C"#8JMF&V+C9BMF%V*?8JB`E<R#8J-BGV+38KP#9OMBQV8C9
MAMBOV8<@V*C8L2#8L=F(VXP@V*[9B-BOV+0@V8;9A=N,XH",V*K9B-BGV8;8
MKR#:J=F^VXP@V+39B-BO`-F^V+'9B-F&V*_9AR#8K=BGV8C;C"#8K]BGV*_9
MA^*`C-BGV8K;C"#9AMF*V+/8JB``V878KR#8JMF%V*?9A2#8M=F!V*W9AR#8
MJ-BG($E%(-F%V+3:J=F$(-BOV*?8L=BO(-F((-BGV8K9AB#8I]BR(-F%V+3:
MJ=F$V*?8JB#9A=BQV8C8L=JOV+$@V87;C.*`C-BHV*?8M-BO+B#8I]JOV+$@
MV8?9AMF(V+(@V87;C.*`C-BNV8C8I]F'V8K8KR#8K=BGV838JB#9B-F*V+'8
MI]F*V+3:K]BQV*K9A=BGV84@V+79@=BMV8<@V+'8IR#8I]F%V*K8K=BGV88@
MVJG9AMF*V*_8C"#9A-BWV8'8I]F+(-JIV839BMBO(-BJV*/9BMF*V*\@V+'8
MIR#9@=BTV*?8L2#8K]F'V8K8KR``V;[8L=F(V8;8K]F'XH",(-BQV*?9A]F&
MV878I]N,("`E<R#8J-BG(#P_>&UL(-BTV+'9B-BY(-F&V+38K]F'(-BGV+/8
MJ@#9A]F(V8K8JB`B)7,B(-BMV+#9@2#8M-BOV8<@V*?8L]BJ`-BJV8;9A]BG
M(-BOV+/8JB#:AMF^`-F^V8K8NMBGV84@V8'8L=BSV*K8I]BOV8<@V+38K]F'
M(-BQV8C;C"`E<R#8J-F'("5S(-BHV*<@V879B-BVV8C8N2`B)7,B(-F&V878
MI]F*V+0@V*_8I]BOV8<@V+38K]F'(-BGV+/8JBX*V*K8MMF%V8K9AMN,(-BH
MV+'8I]N,(-BNV8C8I]F&V*_9AR#8M-BOV88@V8@@V8K8IR#8K]BQVJD@V*+9
MAB#9B-BLV8C8KR#9AMBOV*?8L=BO`-F&V*?9A=N,(-JIV8<@V*C8L=BGVXP@
MV;[9BMF(V8;8KR#8KMF(V+'8K]F&(-BHV8<@V+79@=BMV8<@V*K9B-F$V8K8
MKR#9AMBGV879AR#8I]BSV*K9@=BGV*_9AR#9A=N,XH",V+39B-BO`-BGV8C9
MA-F(V8K8JB`B)7,B(-F&V87;C.*`C-BJV8C8I]F&V*\@V+#8KMF*V+'9AR#:
MK]BQV*_8KR#8LMF*V+'8IR#9A=F"V*_8I]BQ(-BOV*?8K]F'(-BBV88@V*?8
MLB#8K=BO(-F%V*S8I]BR(-BHV8K8M-BJV+$@V*?8L]BJ`-BHV+'9AMBGV879
MA^*`C-BGV8K;C"#:J=F'(-BHV+'8I]N,(-F%V+38I]F'V*_9AR#8I]F*V88@
MV8;9B-BY(-BOV*?8K]F'("@E<RD@V8+8J-F$V*?9BR#9A=F(V+'8KR#8I]BS
MV*K9@=BGV*_9AR#9@MBQV*?8L2#9A=N,XH",VJ_8L=F!V*K8C"#8K]BQ(-BS
MV8K8L]BJV84@V879B-BLV8C8KR#9AMF*V+/8J@#8JMF&V8?8IR#8L=BGV+/8
MJB#9B"#:AMF^`-BJV8;9A]BG(-BOV+/8JB#8L=BGV+/8J@#8L]BQV8C8L2`B
M)7,B(-BMV+#9@2#8M-BOV8<@V*?8L]BJ`-BSV+'9B-BQ("(E<R(@V+#8KMF*
MV+'9AR#8M-BOV8<@V*?8L]BJ`-BOV+'8KMF(V*?8L]BJ(-BGV8'8JMBJV*?8
MK2#8K=BSV*?8J"#8J-BQV*?;C"`E<R#9OMBGVJD@V+38KP#8L=BOV8K9@2#9
MA=BTV*[8M2#8M-BOV8<@V8C8K-F(V*\@V8;8K]BGV+'8KP#:J=BGV+$@V879
MB-BQV*\@V8;8N-BQ(-BHV8<@V839BMBSV*H@VJG8I]BQV8?8I]N,(-BTV878
MIR#8I]BVV*?9@=F'(-BTV*_9AR#8I]BSV*H`V;[8L=F(V8;8K]F'(-F%V8C9
M@MBJVXP@("(E<R+9A=F(V*S9B-BO(-F&V8K8L]BJ`-BJV8;9A]BG(-BHV*?9
MA-BG(-F((-F^V*?9BMF*V88`V*K9AMF'V*<@V+/9A=BJ(-BHV*?9A-BGV8K;
MC`#8K]BGV*_9AR#8I]BQV+/8I]F$(-BTV*_9AR#8I]BR(-JOV*?9A2#9@MBH
MV83;C"#8J-F'(-BHV+G8KR#8I]BR(-BOV+/8JB#8L=F!V*K9AR#8I]BSV*H`
MV;[8L=F(V8;8K]F'(-BGV+'8L]BGV80@V+38K]F'(-F&V87;C.*`C-BJV8C8
MI]F&V*\@V+#8KMF*V+'9AR#8M-F(V*\`VJG8I]BQV*C8L=BGV88@V*?8M]F$
MV*?8N=BGV*H@9G)E92]B=7-Y(-BHV*<@V879B-F!V8+9BMBJ(-BPV*[9BMBQ
MV8<@V+38K]F&V*\`V*C9A-F(VJD@=V5A=&AE<BYC;VT@V8+8I]BHV80@V*_8
ML]BJV+'8L]N,(-F&V8K8L]BJ`-JIV+39B"#8JMF%("<E<R<@V8K8I]F!V*H@
MV8;8M-BO`-JOV++9BMF&V8?B@(SB@(S8I]F*VXP@V*_8L2#8K]BSV*K8L=BS
M(-F&V8K8L]BJ`-BHV*[8M-N,(-JIV8<@V*C8JMF(V*?9AMBO(-BOV+'8KMBW
M(-F&V878I]F*V+0@V*_8I]BOV8<@V+39B-BO(-F%V8C8K-F(V*\@V8;9BMBS
MV*H`V8;9B-F*V+/9A^*`C-F'V*?;C"#8LMF*V*?8K]N,(-BOV+$@V*?9BMF&
M(-F!V8K9A-BO(-F"V+'8I]BQ(-BOV*?8L=BO+B#8M-F%V*<@)7,@V8;9B-F*
MV+/9AR#9B-BGV+'8KR#:J=BQV*_9A^*`C-BGV8K8KR#8K]BQ(-BMV*?9A-N,
M(-JIV8<@V+39A=BG(-BHV*?9BMBO(-JIV878JMBQ(-BGV+(@)7,@V8;9B-F*
MV+/9AR#9B-BGV+'8KR#:J=F&V8K8KP#9A]F&V8C8LB#9OMBQV8C9AMBOV8?B
M@(P@V+'8I]F'V8;9A=BGV8K;C"#8J-BQV*?;C"`E<R#9B-BLV8C8KR#9AMBO
MV*?8L=BO`-F%V+3:J=F$VXP@V*_8L2#8I]BVV*?9@=F'(-JIV+'8K]F&("<E
M<R<@V*C9AR#8L]F*V+/8JMF%(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B`E<P#9
MA=BTVJG9A-N,(-BOV+$@V*?8MMBGV8'9AR#:J=BQV*_9AB`G)7,G(-BHV8<@
MV+/9BMBSV*K9A2#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,`V878M-JIV83;
MC"#8K]BQ(-BMV+#9@2#:J=BGV+'8J-BQ("<E<R<@V*?8LB#8L]F*V+/8JMF%
M(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B``V878M-JIV83;C"#8K]BQ(-BMV+#9
M@2`G)7,G(-BGV+(@V+/9BMBSV*K9A2#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@
M`-F%V+3:J=F$VXP@V*_8L2#8J-F'(-BQV8C8LB#:J=BQV*_9AB`G)7,G(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<P#9A=BTVJG9A-N,(-BOV+$@V*?8L=BS
MV*?9A"#9OMBQV8C9AMBOV8<@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ("5S(-BG
MV+'8L]BGV80@V8;8M-BO`-F%V+3:J=F$VXP@V*_8L2#8I]BQV+/8I]F$(-F^
MV+'9B-F&V*_9AR#9B-BLV8C8KR#8K]BGV+38JMF'(-BGV+/8JCH@V*?9AMBO
MV*?8LMF'("5S(-BHV8K8M-BJV+$@V*?8LB#8K=BO(-F%V*S8I]BR(-BHV8C8
MK]F'(-BGV+/8JB`H("5D(-BHV*?9BMBJ*2X`V878M-JIV83;C"#8K]BQ(-BG
MV+'8L]BGV80@V;[8L=F(V8;8K]F'(-F(V*S9B-BO(-BOV*?8M-BJV8<@V*?8
ML]BJ.B`@)7,@V*C9AR#8M=F(V+'8JB#8JMJIV8?B@(S8I]F*VXP@V*C9AR#8
ML=F(V+(@V+38K]F'(-BGV+/8JB``V*[8M]BGV8K;C"#8K]BQ(-F&V878I]F*
MV+0@V*?9BMF&(-BHV*[8M"#9OMF*V+K8I]F%(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJ`-BNV+?8I]F*VXP@V*_8L2#9B-BGV+'8KR#:J=BQV*_9AB#8K]BGV*_9
MAR#8JMF%V*?8LR#8L=BN(-BOV*?8K]F'(-BGV+/8J@#8KMBWV*?9BMN,(-BO
MV+$@V8C8I]BQV*\@VJG8L=BOV88@V+'9B-F*V*_8I]BO(-BQV*X@V*_8I]BO
MV8<@V*?8L]BJ.B`E<RX`V*[8M]BGV8K;C"#8K]BQ(-F(V*?8L=BO(-JIV+'8
MK]F&(-BOV*?8K]F'(-BJV8+9B-F*V84@V+'8KB#8K]BGV*_9AR#8I]BSV*H`
MV*[8M]BGV8K;C"#8K]BQ(-F(V*?8L=BO(-JIV+'8K]F&(-JIV*?8L2#8L=BN
M(-BOV*?8K]F'(-BGV+/8JCH@)7,N`-BNV+?8I]F*VXP@V*_8L2#9B-BGV+'8
MKR#:J=BQV*_9AB#8I]BWV838I]BYV*?8JB#:J=BGV+'8J-BQV*?9AB!F<F5E
M+V)U<WD@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ("5S+@#8KMBWV*?9BMN,(-BO
MV+$@V;[9BMJIV+'8J-F&V*_;C"#9@=BQV84@V+'8KB#8K]BGV*_9AR#8I]BS
MV*HN(-BTV*?9BMBO(-F!V8K9A-BO(-F%V8C8L=BO(-F&V8K8I]BRVXP@V+'8
MIR#8K-BG(-BGV8;8K]BGV*[8JMF'XH",V*?9BMBO`-BGV+3:J=BGV83;C"#8
MK]BQ(-BHV*?8LMJIV+'8K]F&(-F^V+'9B-F&V*_9A^*`C"`E<R#9OMF*V+0@
MV*+9A=BO+B!T<F%N<VQA=&EO;BYP:'`@V+'8IR#8J-BG(-BYV838I]F%V*H@
M+60@V*?8K-BQV*<@VJG9AMF*V*\@V*K8IR#9A]F%V8<@V;[9BMBZV*?9A>*`
MC-F'V*?;C"#8KMBWV*<@V*?8LB#8JMBLV++9BMF'(-JIV8;9AMBOV8<@>&UL
M(-BQV*<@V*C8J-F*V8;9BMBO`-BNV+?8I]F*VXP@V*_8L2#8I]BLV+'8IR#:
MJ=BQV*_9AB#8N=F%V839BMBGV*H@VJG8JMBGV*C:AMF'(-BBV*_8L=BS(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#8
ML]BYVXP@VJG9AMF*V*\`V*[8M]BGV8K;C"#8K]BQ(-BHV8<@V+'9B-BR(-JI
MV+'8K]F&(-BLV++8IMF*V*?8JB#8JMF%V*?8LR#8L=BN(-BOV*?8K]F'(-BG
MV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;9BMBO
M`-BNV+?8I]F*VXP@V*_8L2#8J-F'(-BQV8C8LB#:J=BQV*_9AB#9@=F'V+'8
ML]BJ(-BJV8C8LMF*V+G;C"#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V838M]F!
MV*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;9BMBO`"#8L]BQV8C8L2!)
M34%0V;[9B-BTV8?B@(S9A]BGVXP@V878M-BJV+':J2#8L=BG(-F^V+38JMF*
MV*C8I]F&VXP@V8;9A=N,XH",VJG9AMBO`-BGV8K9AB#8N=F%V80@V;[8M-BJ
MV8K8J-BGV8;;C"#9AMF%VXSB@(S8M-F(V*\`V*?9BMF&(-BYV879A"#9A]F&
MV8C8LB#8I]BLV+'8IR#9AMBTV*_9AR#8I]BSV*H`(-BHV8<@V8;8N-BQ(-F&
MV87;C.*`C-BQV+/8KR#:J=F'(-BBV+'8M-F*V8@@<F%R(-F%V+G8JMBHV+';
MC"#8J-BGV+38KP`@V*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@
MV;[8L=F(V8;8K]F'('II<"#9A=BYV*K8J-BQVXP@V*C8I]BTV*\`V*C9AR#9
MAMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V+39A=BGV+'9AR#:J=BGV+'8
MJB#9A=BYV*K8J-BQVXP@V*C8I]BTV*\`V*?9BMF&(-F!V8K9A-BO(-F%V8C8
ML=BO(-F&V8K8I]BR(-BGV+/8J@#8I]F*V88@V8'9BMF$V*\@V879A=JIV88@
MV*?8L]BJ(-BTV*?9A=F$(-BGV+G8K]BGV*\@V+78K=F*V*T@V*C8I]BTV*\`
MV*?9BMF&(-F!V8K9A-BO(-F%V87:J=F&(-BGV+/8JB#8M-BGV879A"#8I]BY
MV*_8I]BO(-F((-F(V8K8L=JOV8C9A"#8J-BGV+38KP#8I]F*V88@V8'9BMF$
MV*\@V+38I]F%V80@V879@MBGV*_9BMBQ(-F'V+38JB#9A]BTV*K;C"#8I]BS
MV*H`V*?9BMF&(-F!V8K9A-BO(-BHV*?9BMBO(-BMV*?9B-N,(-JIV*?9A=BG
M(-F((-F*V*<@V8'9A]BQV+/8JMN,(-BGV+(@V*?8N=BOV*?8KR#8M=BMV8K8
MK2#8K-BOV*<@V+38K]F'(-BHV*<@V8;9B-F*V+/9AR#8KMBGV83;C"#8J-BG
MV+38KP#8I]F*V88@V8'9BMF$V*\@V*C8I]F*V*\@V8K:J2#8N=BOV*\@V878
MN=BJV*C8L2#8J-BGV+38KP#8I]F*V88@)7,@V87;C.*`C-BHV*?8M-BO`-BG
MV8K9AB#9OMF*V+K8I]F%(-BHV*<@V878K-F%V8C8N=F'(-JIV*?8L=BGVJG8
MJMBQ("5S(-F&V8C8M-BJV8<@V+38K]F'(-BGV+/8JB#:J=F'(-BHV*<@V878
MK-F%V8C8N=F'(-JIV*?8L=BGVJG8JMBQ(-BTV878IR#9A=BJV8'8I]F(V*H@
MV*?8L]BJ`-BGV8K9AB#8N=BOV*\@(-BHV*?9BMBO(-F*VJD@V*C8I]BTV*\N
M`-BGV8K9AB#8I]BSVJG8L=F*V;[8JB#8J-BGV8K8KR#8K]BQ(-BNV+<@V*_8
ML]BJV8C8L2#8I]BLV+'8IR#8M-F(V*\`V*?9BMF&(-BSV+'9B-BQ(-F^V+'9
MB-F&V*_9A^*`C-F'V*?;C"!Z:7`@V8@@9WII<"#8L=BG(-BHV*?8LB#9AMF%
MVXSB@(S:J=F&V*\`V*?9BMF&(-BSV8K8L]BJV84@V*_8L2#8K=BGV80@V*W8
MI]BVV+$@V+K9BMBQ(-F!V+G8I]F$(-BGV+/8J@#8I]F*V88@V879@MBOV*?8
ML2#8J-BGV8K8KR#8N=BOV*\@V*C8I]BTV*\`V*?9BMF&(-F^V8;8K-BQV8<@
MV*C8I]F*V*\@V*?8LB#9OMF&V*S8L=F'(-JOV++9BMF&V8?B@(SB@(S9A]BG
M(-F!V+'8I]BNV8C8I]F&VXP@V+39B-BO`-BQV+G8KP#8J-F$V8K8M^*`C-F'
MV*<`V++9A=BGV88`V;[9BMJOV8K8L=N,(-BRV878I]F&VXP`V8+8I]F$V*@@
MV++9A=BGV8;;C``@V*?9AMBJV*[8I]BH(-BRV878I]F&VXP@`-BYV8;9B-BG
MV88`V+G9AMF(V*?9AB`H=&]O;'1I<"DZ`-BHV8<`V*C8L=BGVXP@V*?9AMBJ
MV*[8I]BH(-J&V8;8KR#9@=F*V838K]B,(-BOVJG9A=F'($-T<FP@V+'9B-N,
M("A00RD@V8K8IR!#;VUM86YD(-BQV8C;C"`H36%C*2#8L=BG(-BOV+$@V878
MK]BJ(-JIV839BMJI(-JIV+'8K]F&(-F&VJ_9A]BOV*?8L=F*V*\`V*?9A=BQ
MV8C8L@#9@=BQV*_8IP#8J-BGV838IP#:AMBGV+':AMF(V*@@V*C8I]F$V*<@
M*-BHV*?9A-BG*0#8JMBQV*S9A=F'(-BTV*_9AP#8JMBQV*S9A=F'XH",V8?8
MIP#8K]BQV+/8JB#9B"#9AMBGV*_8L=BSV*H`V+/9AR#8M-F&V*C9AP!4=7)K
M:7-H("A)4T\M.#@U.2TY*0#8I]F&V*K8KMBGV*@@V*[9B-BO(-BQV*<@V*_8
ML=BL(-JIV8;9BMBO.@#8M-BGV*[8M2!5+E8N(#H@`%523`!54DPZ`-BGV87:
MJ=BGV88@V*_8L]BJV+'8L]N,(-BHV8<@VJG8M-F((%9&4R#9AMF*V+/8J@#8
MI]F%VJG8I]F&(-BGV+;8I]F!V8<@VJG8L=BOV88@V*?8M]F$V*?8N=BGV*H@
MV*?8MMBGV8';C"#:J=BGV+'8J-BQ(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8
MKR#9AMF*V+/8J@#8JMBZV8K9BMBQ(-F%V*S9B-BRV8?8I]N,(-BOV+/8JMBQ
MV+/;C"#8J-BQV*?;C"#9OMBQV8C9AMBOV8<@(B5S(B#9A=F"V*_9B-BQ(-F&
MV8K8L]BJ`-BJV+K9BMF*V+$@V878K-F(V++9A]BGVXP@V*_8L]BJV+'8L]N,
M(-BHV+'8I]N,(-F^V+'9B-F&V*_9AR`E<R\E<R!61E,@(-F%V8+8K]F(V+$@
MV8;9BMBSV*H`V*K8NMF*V8K8L2#8K]BQ("5S(-F%V*S8I]BR(-F&V8K8L]BJ
M`-BGV87:J=BGV88@V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB!346P@
MV8;9A=N,XH",V*C8I]BTV*\N`-F&V87;C.*`C-BJV8C8I]F&(-BHV*<@4U-,
M(-BGV+'8JMBHV*?8MR#8J-BQV8+8L=BGV+$@VJG8L=BO`-F&V87;C.*`C-BJ
MV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#:J=F^VXP@V8;9A=F(V*\`
MV8;9A=N,XH",V*K9B-BGV88@VJG8M-F((%9&4R`B)7,B(-BQV*<@V*?9BMBL
MV*?8KR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=BTV8@@5D93(-BQ
MV*<@V*?9BMBLV*?8KR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQ
MV8C9AMBOV8<@5D93(-BQV*<@V*?9BMBLV*?8KR#9AMF%V8C8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@V*[8I]F$VXP@5D93("#8I]F*V*S8
MI]BO(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BOV*?8K]F'(-BQV*<@
MV+'9A=BRVJ_8M-BGV8K;C"#:J=BQV*\@`-BMV+#9@2`B)7,B(-F%V8+8K]F(
MV+$@V8;9BMBSV*K8C"#:J=BTV8@@V*[8I]F$VXP@V8;9BMBSV*H`V*W8L-F!
M("5S(-F%V8+8K]F(V+$@V8;9BMBSV*K8C"#:J=BTV8@@V*[8I]F$VXP@V8;9
MBMBSV*H`V8;9A=N,XH",V*K9B-BGV88@)R5S)R#8L=BG(-BMV+#9@2#:J=BQ
MV*\Z("5S+@#9AMF%VXSB@(S8JMF(V*?9AB#:J=BTV8@@5D93(-BQV*<@V*C9
MAR#8M=F(V+'8JB#8JMF((-BOV+$@V*K9B"#8K=BPV8$@V8;9A=F(V*\`V8;9
MA=N,XH",V*K9B-BGV88@VJG8M-F((%9&4R#8L=BG(-BMV+#9@2#9AMF%V8C8
MKP#9AMF%VXSB@(S8JMF(V*?9AB#:J=BTV8@@5D93(-BQV*<@V*W8L-F!(-F&
MV879B-BO.B`E<RX`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&
M4R`B)7,B(-BQV*<@V*W8L-F!(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&
M(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8K=BPV8$@V8;9A=F(V*\`V8;9A=N,
MXH",V*K9B-BGV88@5D93(-BQV*<@V*C9AR#8M=F(V+'8JB#8JMF((-BOV+$@
MV*K9B"#8K=BPV8$@V8;9A=F(V*\Z("5S+@#9AMF%VXSB@(S8JMF(V*?9AB#:
MJ=BTV8@@V*S8I]BQVXP@V+'8IR#8JMBTV*[9BMBU(-BOV*?8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#8K-BRV*;9BMBGV*H@VJ_9B-BGV8?;C"#8L=BG(-BHV+/8
MMR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8JMBYV+'9BMF!("5S("#8
ML=BG(-BHV*?8L2#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9
MAMBOV8<@5D93(-BQV*<@V*S8I]BHV8?B@(S8K-BG(-F&V879B-BO`-F&V87;
MC.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@(B5S(B#8L=BG(-BHV*?8
MLB#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93
M(-BQV*<@V*C8L=BGVXP@V8;9B-BTV*K9AB#8J-BGV+(@VJG8L=BO`-F&V87;
MC.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8J-BGV+(@V8;9
MA=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V*+8L=BTV8K9B"#9@=BTV+'8K]F'
M(-BTV*_9AR#8L=BG(-BHV*?8LB#:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@
MVJG8M-F(('9F<W)O;W0@V+'8IR#8KMF(V*?9AMBO`-F&V87;C.*`C-BJV8C8
MI]F&("5S("#8L=BG(-BHV8<@)7,@(-BJV+K9BMF*V+$@V8;8I]F%(-BOV*?8
MKSH@V;[9B-BTV8<@V879@MBUV*\@V*?8LB#9@MBHV80@V879B-BLV8C8KR#8
MI]BSV*H`V8;9A=N,XH",V*K9B-BGV88@VJG8M-F((%9&4R#8L=BG(-BJV+K9
MBMF*V+$@V8;8I]F%(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=BTV8@@
M5D93(-BQV*<@V*K8NMF*V8K8L2#9AMBGV84@V*_8I]BO.B`E<RX`V8;9A=N,
MXH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`B)7,B(-BQV*<@V*K8NMF*
MV8K8L2#9AMBGV84@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&
MV*_9AR!61E,@)7,O)7,@V+'8IR#8JMBZV8K9BMBQ(-F&V*?9A2#8K]BGV*\`
MV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BJV+K9
MBMF*V+$@V8;8I]F%(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB`G;6MI<V]F
M<R<@V+'8IR#8I]BLV+'8IR#9AMF%V8C8KRX`V8;9A=N,XH",V*K9B-BGV88@
MV*?9BMF&(-BSV8;8KR!7;W)D(-BQV*<@V*K8L=BLV879AR#9AMF%V8C8KP`@
MV8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@(B5S(B!61E,@
M(-F&V8C8M-BJ`"#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9
MAR!61E,@V8;9B-BTV*HN`-BOV*?8K]F'(-F&V87;C.*`C-BJV8C8I]F&(-BO
MV+$@V;[8L=F(V8;8K]F'(%9&4R#9AMF(V+38J@#8LMF*V+'8KMBW(-BOV*?8
ML0#8KMF&V*O;C"#8L]BGV++;C"#8JMBZV8K9BMBQV*?8J@#8KMF&V*O;C"#8
ML]BGV++;C"#8HMBNV+'9BMF&(-BYV879A"#8M-F%V*<`V;[8I]BSV*X@V+K9
MBMBQ(-F%V8;8JMBXV+'9AR#8I]BR(-BSV+'9B-BQ(-BHV+$@V+'9B-N,(-BG
MV+'8JMBHV*?8MSH`V;[8I]BSV*X@V+K9BMBQ(-F%V8;8JMBXV+'9AR#8I]BR
M(-BSV+'9B-BQ(-BHV8<Z`%5N9FEL960`56YI8V]D92`H551&+3@I`-F(V*?8
MK=BOV8?8IP#8K]BGV*_9AR#9AMBGV+39AMBGV*[8JMF'`-BOV+/8JMF(V+$@
MV8;8I]BTV8;8I]BS.B`E<P#9AMBGV84@VJG8I]BQV*C8L=N,(-F((-F*V*<@
MVJG9A-F%V8<@V+'9A=BR(-F&V*?8M-F&V*?8KMBJV8<`V*S8K]BGVJG8L=BO
MV88@V+G9AMBUV+$@VJG9AMF(V8;;C`#8J-N,(-F&V*?9A0#8L=F(V*?9A-F'
MV*?;C"#8J-BOV8C9AB#8I]F(V839B-F*V*H@V*C9AR#8K]F$V8K9A"#8I]F%
MV8;9BMBJVXP@V8;9A=N,XH",V*K9B-BGV8;9AMBO(-BGV+(@V+?8L=F*V8(@
MV*C8L=F&V*?9A=F'(-F&V8C9BMBSVXP@V*C8L=F*V*_9AR_:J=F^VXP@V+38
MK]F'(-F((-F*V*<@VH;8L]BHV8K8K]F'(-BTV8C9AMBO+B#:J=F$V8K8KR#8
MJMBCV8K9BMBO(-BQV*<@V8'8M-BGV+$@V*_9A]F*V*\@V*K8IR#9A=BJV88@
MV8'9AMN,XH",V*?9BMN,(-BQV*<@V*_8L2!M;WII;&QA+F]R9R#8J-BG(-BY
MV8;9B-BGV88@VH;:K]F(V8;:K]N,(-BOV+/8JMBQV+/;C"#8L=F(V*?9A-F'
MV*<@V*C9AR#8K=BGV8'8N-F'(-F%V8C9@MBJ(-F%V+38I]F'V*_9AR#:J=F&
MV8K8KP#8L=F&VJ\@V*K9AMBXV8K9A2#9AMBTV*_9AP#8I]F&V+38N=BGV*@@
MV*C8K]F(V88@V;[8M-BJV8K8J-BGV8;;C`#8JMBQV*S9A=F'(-F&V+38K]F'
M`-BHV8<@V+'9B-BRVJG8L=BOV88`V*C9AR#8L=F(V+(@VJG8L=BOV88@)7,`
MV*C9AR#8L=F(V+(@VJG8L=BOV88@V*W8I]F$V*?8JB#9OMBGV+/8KMJOV8@`
MV*C9AR#8L=F(V+(@VJG8L=BOV88@VJG8I]BQV*C8L0`G)7,G(-BHV8<@V+'9
MB-BR(-BTV*_9AR#8I]BSV*H`V*C9AR#8L=F(V+(@VJG8L=BOV88@V;[8L=F(
MV8;8K]F'XH",(-BQV*?9A]F&V878I]N,("5S(-BHV+'8I]N,("5S+@#8L=F(
MV*?9A"#8J-F'V8K9AMF'(-BSV*?8LMN,(-BMV+#9@2#8M-BO`-F!V+'8L]BJ
MV*?8K]F&`-BJV878I]F%(-F^V+'9B-F&V*_9A^*`C.*`C-F'V*?;C"#8JMF&
MV+C9BMF%(-BHV+'9AMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C"#8
MJ-F'(-BSV+'9B-BQ(-BHV*?8L2#8M-BOV8<@V*?8L]BJ`-BMV+'9B-F!(-BH
MV++8L=JO(-F$V*?8JMF*V88`V*?8N=BOV*?8KR#9BMF(V8;8I]F&VXP@V*C8
MLMBQVJ\`VJG8I]BQV*C8L=BO.@`@V*?8L]BJV8'8I]BOV8<@V*S8I]BQVXPZ
M("5S`-BGV+/8JMF!V*?8K]F'(-BGV+(@4U-,`-BGVJ_8L2#9AMBGV84OV+'9
MA=BRV+G8J-F(V+$@V*C8L=BGVXP@V+/8L=F(V+$@24U34"#9A=BJV8'8I]F(
MV*H@V*?8L]BJV(P@V*?8L]BJV8'8I]BOV8<@VJG9AMF*V*\`VJG8I]BQV*C8
ML2`E<R`@V*C8L=BGVXP@)7,@V*K8H]F*V8K8KR#8M=F$V*?8K=F*V*H@V8;8
MM-BOV8<@V*?8L]BJ`-F%V*_9BMBQV8K8JB#:J=BGV+'8J-BQ`-JOV++9BMF&
MV8?B@(S9A]BGVXP@VJG8I]BQV*C8L0#8J]BHV*H@V8;8I]F%(-JIV*?8L=BH
MV+$`V*O8J-BJ(-F&V*?9A2#:J=BGV+'8J-BQ(-BHV+'8I]N,(-BGV8K9AB#8
ML]BGV8K8JB#8NMF*V+$@V8'8N=BGV80@V+38K]F'(-BGV+/8J@#:J=BGV+'8
MJ-BQ(-F^VXS8K]BG(-F&V+38KP#:J=BGV+'8J-BQ(-F^VXS8K]BG(-F&V+38
MKRX`V*?8K-BGV++9A^*`C-F'V*?;C"#8K]BSV*K8L=BSVXP@VJG8I]BQV*C8
ML0#9AMBGV84@VJG8I]BQV*C8L0#9AMBGV84@VJG8I]BQV*C8L=N,("<E<R<@
MV*?8LB#9@MBHV80@V879B-BLV8C8KR#8I]BSV*H`V8;8I]F%(-JIV*?8L=BH
MV+$Z`-F&V*?9A2#:J=BGV+'8J-BQ.B``VJG8I]BQV*C8L=BGV88`VJG8I]BQ
MV*C8L=BGV88@V+/9BMBSV*K9A3H`VJG8M-F((%9&4R#9B-BLV8C8KR#9AMBO
MV*?8L=BO`-BJV+G8M]F*V838I]BJ`-F%V8C9@MBYV8K8JMF'V*?;C"#9A=BY
MV*K8J-BQ(-F*V*?9@=BJV8<@V+38K]F'(-BYV*C8I]BQV*K9AMBO(-BGV+(Z
M`-BOV+$@V*_8L]BJV+'8LR#8J-F(V*_9A@#9A=F"V*_8I]BQ(-BHV8<@V*_9
M@MF*V8+9AR#8I]BR(-BMV*?9A-BG`-F%V8+8I]BOV8K8L0#9A=F"V*?8K]F*
MV+$@V*C8L=BGVXP@V*?9AMBJV*[8I]BH(-BGV+(`V878JMBZV8K9BMBQ`-F&
MV+/8KMF'`-JIV8;8JMBQV80@V8;8L]BNV8<`V*K8L=BGV+(@V+G9A=F(V*_;
MC`#9@=BGV+79A-F'(-JOV+#8I]BQVXP@V+G9A=F(V*_;C`#8N=F%V8C8K]N,
M.@#8KMF*V83;C"#8J-BGV838IP!6:65T;F%M97-E("A625-#24DI`-F&V878
MI]F*V+0@)7,`V8;9A=BGV8K8M"#9BMJI(-BUV8'8K=F'(-BJV*?8L=F&V878
MI]N,(-BNV*?8L=BLVXP`(-F&V878I]F*V+0@V*C9AR#8N=F&V8C8I]F&("5S
M`-F&V878I]F*V+0@V+'9B-F*V*_8I]BO`-F&V878I]F*V+0@V8C8N-F*V8'9
MAP#9A=F*V*_8I]F&(-BOV8K8KP#9A=F*V*_8I]F&(-BOV8K8KSH@`-F'V+38
MK]BGV+$A(2$@V878JMF&(-BQV*<@V*C8M]F(V+$@V*_8L]BJVXP@V*?8LB`E
M<R#8K=BPV8$@VJG9AMF*V*\`V*?8KMBWV*?8L3H@`-BGV*[8M]BGV+$Z(`#:
MAMF'V*?8L=BTV8;8J-F'`-F^V8K8M"#8J-F*V8;;C"#9A]F(V*<`V*_8I]BO
MV8<@V*+8J"#9B"#9A]F(V*?9BMN,(-F!V+'8I]F'V84@V+38K]F'(-BHV8<@
MV8C8L]F*V839AP!W96%T:&5R+F-O;0#8JMBGV+'9AMF%V*<`V878K=F$(-BJ
MV*?8L=F&V878IP#9A]F!V*K:K]N,`-BNV8C8M"#8HMF%V*_9BMBO`-BHV8<@
M)7,@V*[9B-BT(-BBV878K]F*V*\`)7/8C"#8KMF(V+0@V*+9A=BOV8K8KP!7
M97-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`VH;9
MAR#8J-BQV8;8I]F%V8<@VJG8I]BQV*C8L=BOVXP@V+'8IR`E<R#8J-BGV8K8
MKR#8J-BYV*\@V*?8LB#9B-BQV8C8KR#9AMBTV*?9AB#8K]F'V*_8GP#9AMF(
MV8K8L]F'XH",VXP@V*W8I]BFV80@VH;9BMBSV*K8GP#9AMF(V8K8L]F'XH",
MVXP@V8;9@MF$(-F"V8C9A"#:AMF*V+/8JMB?`-JIV*_8I]F%(-F!V*?8L@#:
MJ=BOV*?9A2!P;'5G:6[B@(S9A]BG(-BHV+'8I]N,(-F(V8K8L=BGV8K8M-JO
MV+$@V878JMF&(-F!V+G8I]F$(-BHV*?8M-F&V*\`V+G8L=BV`"#9OMF'V8;8
MIR#8K]BQ(-F(V*?8K=BO($-34R``V;[9A]F&V*?;C"#9A=F&V8@@)7,@V*_8
ML2#:AMF^("C8K]BQ(-F(V+'9B-BO(-BHV+G8K]N,(-F%V8C8J]BQ(-F%VXSB
M@(S:K]BQV*_8KRDZ`-F^V8?9AMBGVXP@V*S8K]F(V80`V8C8I]BMV*\@V;[9
MA]F&V*<`V;[9A]F&V*<Z`%=I:VD`V*C8I]BO.@#8J-BGV*\@V++9B-BOV8?9
MAMJOV*?9A3H@`-BSV+'8N=BJ(-BHV*?8KR#8J-BQV*W8L]BH(-F!V8C8JB#8
MJ-BQ(-BSV*?8N=BJ`-BHV*?8KSH`V*C8I]BO.B``V+G9@MF$`-F$V8K8L]BJ
M(-BYV838I]F"V879AMBOVXP`VJG8I]BQ`-BBV*_8L=BS(-F%V*W9A"#:J=BG
MV+$`V*K9A-F!V88@V878K=F$(-JIV*?8L0#9AMF(V+38JMF&(-F^V+'9B-F&
MV*_9A^*`C"#8L=BGV8?9AMF%V*?;C"#8J-F'(-BQV8C8LB#8M-BOV8<@V*_8
ML2`E<RX`XH",65D`65E960#8L]BGV838I]F&V8<`V*+8L=N,`-BHV839A]B,
M(-F%V8C8I]F!V8+9A0#8M-F%V*<@V*_8L2#8L]BHVJD@V878JMF&(-F'V+/8
MJMF*V*\N(-BGV+(@V*_:J=F%V8<@(%L\/ET@V*C8L=BGVXP@V*C8L=JOV+38
MJMF&(-BHV8<@5UE325=91R#8I]BSV*K9@=BGV*_9AR#:J=F&V8K8KP#8M-F%
MV*<@V*K8H]F*V8K8KR#8M=F$V*?8K=F*V*H@V8;8M-BOV8K8KP#8M-F%V*<@
MV8;9A=N,XH",V*K9B-BGV8;9BMBO(-F&V8C9BMBSV8<@)UPG(-BQV*<@V*_8
ML2#9AMBGV84@VJG8I]F%V80@V*[9B-BO(-BOV*?8M-BJV8<@V*C8I]BTV8K8
MKP#8M-F%V*<@V8;9A=N,XH",V*K9B-BGV8;;C-BO(-BGV+/9A2#8L=F%V+(@
MVJG8I]BQV*C8L2`E<R#8L=BG(-BJV+K;C-N,V+$@V*_9A]N,V*\`V+39A=BG
M(-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMF*VJD@V878N=BJV*C8
ML=N,(-F(V*?8L=BO(-F&VJG8L=BOV8?B@(S8I]F*V*\`V8?9BMJ&(-F!V8K9
MA-BOVXP@V+'8IR#8K]BQ(-F^V+'9B-F&V*_9AR#9B-BGV+'8K]F'(-BHV8<@
MV8'9BMF$V*\@V878JMF"V*?8J-F$VXP@V*_8L2`E<R#9AMJOV*?8M-BJ(-F&
MV+38K]F'(-BGV+/8J@#8M-F%V*<@V*[8I]BQV*P@V+38K]F*V*\`V+39A=BG
M(-F%V*S8J-F(V+$@V8?8L]BJV8K8KR#9BMJI(-BTV878I]BQV8<@V*K9A-F!
MV88@V878N=BJV*C8L2#9B-BGV+'8KR#:J=F&V8K8K]B,(-BGV+(@V+G9A-BG
MV878JB`G*R<@V*C8L=BGVXP@V+39A=BGV+'9A^*`C-F'V*?;C"#8J-F*V88@
MV*?9A-F%V839A-N,(-BGV+/8JMF!V*?8K]F'(-JIV8;9BMBO`-BTV878IR#9
MA=BLV*C9B-BQ(-F'V+/8JMF*V*\@V8K:J2#9A=F"V*_8I]BQ(-F%V+G8JMBH
MV+$@V8C8I]BQV*\@VJG9AMF*V*\`V+39A=BG(-BHV*?9BMBO(-F*VJD@5D93
M(&)A8VME;F0@V;[9BMJIV+'8J-F&V*_;C"#:J=F&V8K8KP#9@MBHV80@V*?8
MLB#8I]BQV+/8I]F$(-JOV++8I]BQV+38C"#8J-BGV8K8KR#9A=BTVJG9A"#8
ML=BG(-BTV+'8K2#8K]F'V8K8KP#8M-F%V*<@V*C8I]F*V*\@55),V*?;C"#:
MJ=F'(-BGV8K9AB#9OMF*V8C9AMBO(-BHV8<@V*+9AB#8I]BTV*?8L=F'(-F%
MVXSB@(S:J=F&V*\@V+'8IR#9B-BGV+'8KR#:J=F&V8K8KP#8M-F%V*<@V*C8
MI]N,V*\@V*?8L]F%(-BQV878LB#:J=F&V8C9AMN,(-BNV8C8KR#8L=BG(-BH
MV*_9A]N,V*\`V+39A=BG(-BHV*?;C-BO(-BGV+/9A2#8L=F%V+(@V*S8K]N,
MV*\@V*[9B-BO(-BQV*<@V*C8K]F'VXS8KR``V+39A=BG(-BHV*?9BMBO(-F*
MVJD@V+/8L=F(V+$@V*C8L=BGVXP@V*W8L-F!(-BTV*_9AB#8I]F&V*K8KMBG
MV*@@VJG9AMF*V*\`V+39A=BG(-BHV*?9BMBO(-F*VJD@V+39AMBGV+/9AR#:
MJ=BGV+'8J-BQ(-BQV*<@V*C8L=BGVXP@V*W8L-F!(-JIV+'8K]F&(-F%V+38
MKMBU(-JIV8;9BMBO`-BTV878IR#8J-BGV8K8KR#9BMJI(-BTV8;8I]BSV8<@
MVJG8I]BQV*C8L2#8L=BG(-BHV+'8I]N,(-BMV+#9@2#:J=BQV*_9AB#9A=BT
MV*[8M2#:J=F&V8K8KP#8M-F%V*<@V*C8I]F*V*\@V8K:J2#8M-F&V*?8L]F'
M(-JIV*?8L=BHV+$@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BT
MV*[8M2#:J=F&V8K8KP#8M-F%V*<@V*C8I]F*V*\@V8K:J2#8M-F&V*?8L]F'
M(-JIV*?8L=BHV+$@V*C8L=BGVXP@V*C9AR#8L=F(V+(@V+38K]F&(-BGV8;8
MJMBNV*?8J"#:J=F&V8K8KP#8M-F%V*<@V*C8I]F*V*\@V878M-BNV+4@VJG9
MAMF*V*\@VJG9AR#:AMF'(-BYV879A-N,(-BHV*?9BMBO(-BGV8;8K-BGV84@
MVJ_9BMBQV*\`V+39A=BG(-BHV*?9BMBO(-F*VJD@V8;8I]F%(-F*VJD@V*_8
ML]BJV8<@V*S8K]F*V*\@V+'8IR#8K]BQV*P@VJG9AMF*V*\`V+39A=BG(-BH
MV*?;C-BO(-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\@V*[9B-BO(-BQV*<@V*C8
MI]BRV*C;C-F&VXP@VJG9AMN,V*\`V8;8M-BSV*H@)7,@V+39A=BG(-F%V8;9
M@MBVVXP@V+38K]F'(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@
MV8C8I]BQV*\@V+39B-F*V*\`V*+8K]BQV+,@V*?9A-JIV*K8L=F(V8;9BMJI
MVXP@V+39A=BG`-BBV*_8L=BS(-F!V+'8L]BJV8;8K]F'.B#8M-F%V*<Z`-BG
MV+?9A-BGV+G8I]BJ(-BTV878IP#8HMBOV+'8LR#8I]F*V8;8JMBQV8;8JMN,
M(-BTV878IR#9AMBSV*C8JB#8J-F'(-BGV*C8JMBOV*?;C"#9AMBTV+/8JB`E
M<R#8M-F%V*<@V*K8NMF*V8K8L2#:J=BQV*_9AR#8I]BSV*HNV*C8L=BGVXP@
MV+'8N=BGV8K8JB#9A=BSV*?8IMF$(-BGV879AMF*V*K;C"#8J-BGV8K8KR#8
MK]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39B-F*V*\`V8;8I]F%(-BTV878IP#:
MK]F(V*?9A]N,(-F^V+38JMF*V*C8I]F&(-BTV878IR#8I]BVV*?9@=F'(-JI
MV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-BQV*<@V;[8M-BJV8K8J-BGV8;;C"#9
MAMF%VXSB@(S:J=F&V*_8C"#9BMBG(-BTV*?9BMBO(-BHV8;8IR#8J-F'(-BO
MV838I]F*V80@V*_9BMJOV+';C"#8I]F*V88@VJG8I]BQ(-BGV8;8K-BGV84@
MV8;9A=N,XH",V+39B-BO`-JOV8C8I]F'VXP@V;[8M-BJV8K8J-BGV88@V+39
MA=BG(-F$V8K8L]BJ(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-BQV*<@V;[8
MM-BJV8K8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V*_8C"#9BMBG(-BTV*?9BMBO
M(-BHV8;8IR#8J-F'(-BOV838I]F*V80@V*_9BMJOV+';C"#8I]F*V88@VJG8
MI]BQ(-BGV8;8K-BGV84@V8;9A=N,XH",V+39B-BO`-BXV*?9A]BQ(-F%V+'9
MB-BQVJ_8L2#8M-F%V*<@V8;8L]BHV*H@V*C9AR#8I]BHV*K8K]BGVXP@V8;8
MM-BSV*H@)7,@V+39A=BG(-BJV+K9BMF*V+$@VJG8L=BOV8<@V*?8L]BJ+MBH
MV+'8I]N,(-BQV+G8I]F*V*H@V878L]BGV*;9A"#8I]F%V8;9BMBJVXP@V*C8
MI]F*V*\@V*_9B-BHV*?8L=F'(-F(V*?8L=BO(-BTV8C9BMBO`-F%V+'9B-BQ
MVJ_8L2#8M-F%V*<@V*?9BMF&(-BNV+79BMBUV8<@V+'8IR#9OMBTV*K9BMBH
MV*?9AMN,(-F&V87;C.*`C-JIV8;8KRX`V878L=F(V+':K]BQ(-BTV878IR#8
MI]F*V88@VJ_8LMF*V8;9A^*`C"#:AMBGV;X@V+'8IR#9OMBTV*K9BMBHV*?9
MAMN,(-F&V87;C.*`C-JIV8;8KRX@0V]N=')O;"]/<'1I;VX@*R!0(-BQV*<@
MV*C8L=BGVXP@VH;8I]F^(-F!V+38I]BQ(-BOV8?9BMBO`-BRV878I]F&(-JI
MV8;9B-F&VXP@V879AMBWV8+9AR#8K-BZV+'8I]F!V8K8I]F*VXP@V+39A=BG
M.@#9A]F(V8K8JB#9OMF*V+0@V8'8L=BV(-BTV878ISH`V8;8I]F%(-JIV*?9
MA=F$(-BTV878ISH`V8;8L]BNV8<@9V5T=&5X="#8M-F%V*<@V8+8K]F*V87;
MC"#8I]BSV*H@V8@@4$A0(-BQV*<@V;[8M-BJV8K8J-BGV8;;C"#9AMF%VXSB
M@(S:J=F&V*\@V8@@V*K9A=BGV84@V+'8M-BJV8?B@(S9A]BG(-F"V*?8J-F$
M(-BHV*?8LB#8M-BOV88@V8;9BMBSV*H`V+'9A=BR(-BYV*C9B-BQ(-BLV*_9
MBMBO(-BTV878IR#8J-BQV*?;C"`E<R#9A]BSV*HZ("5S`-BGV+/9A2#8L=F%
MV+(@V*S8K]N,V*\@V+39A=BG(-BHV+/;C-BGV+$@V+?9B-F$V*?9AMN,(-BG
MV+/8JMB,(-BGV+/9A2#8L=F%V++9A]BG(-F&V*C8I]N,V*\@V*C;C-BT(-BG
MV+(@)60@V8;9B-N,V+/9AR#8J-BGV+38KR$`V*?8L]F%(-BQV878LB#8K-BO
MVXS8KR#8M-F%V*<@V*C8L=BGVXP@V*W8K]BS(-BRV*_9AB#8J-BSVXS8I]BQ
M(-BBV+/8I]F&(-F%VXSB@(S8J-BGV+38KR$@V*?8L]F%(-BQV878LB#8JMBZ
MVXS;C-BQ(-F&VXS8I]F!V*HA`-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\@V+39
MA=BG(-BHV+'8I]N,(-BMV*_8LR#8LMBOV88@V*C8L]N,V*?8L2#8HMBSV*?9
MAB#9A=N,XH",V*C8I]BTV*\N(-BGV+/9A2#8L=F%V+(@V*K8NMN,VXS8L2#9
MAMN,V*?9@=BJ(0#8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-BTV878IR#8J-BG
MVXS8KR#8K=BOV*?9@MF$("5D(-F&V8C;C-BSV8<@V*C8I]BTV*\A`-BGV+/9
MA2#8L=F%V+(@V*S8K]N,V*\@V+39A=BG(-BHV*?;C-BO(-BHV*<@V*?8L]F%
M(-BQV878LB#:J=F&V8C9AMN,(-BTV878IR#9A=BJV8'8I]F(V*H@V*C8I]BT
MV*\`V*?8L]F%(-BQV878LB#8K-BOVXS8KR#8M-F%V*<@V*W8K]BGV8+9A"#8
MJ-BGVXS8KR#8M-BGV879A"`E9"#9AMF(VXS8L]F'V90@V*?9A-F!V*C8I]N,
MVXP@V*C8I]BTV*\N`-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\@V+39A=BG(-BM
MV*_8I]F"V80@V*C8I]N,V*\@V+38I]F%V80@)60@V8;9B-N,V+/9A]F4(-BG
MV839@=BHV*?;C-N,(-F((-BYV*_8K]N,(-BHV*?8M-BO+@#8I]BSV84@V+'9
MA=BR(-BLV*_;C-BO(-BTV878IR#8K=BOV*?9@MF$(-BHV*?;C-BO(-BTV*?9
MA=F$("5D(-BGV+(@V*?9AMF(V*?8N2#9A=BJV8'8I]F(V*H@V8;9B-N,V+/9
MAR#8J-BGV+38KRX@V*?9AMF(V*?8N2#8J-BOVXS9AB#8M=F(V+'8JB#9A]BS
MV*K9AMBO.B#8K=BQV8C9@2#:J=F(VH;:J=B,(-BMV+'9B-F!(-BHV++8L=JO
MV(P@V+G8K]BOVXP@V8@@V8;8M-BGV8;9A^*`C-F'V*<N`-BGV+/9A2#8L=F%
MV+(@V*S8K]N,V*\@V+39A=BG(-BMV*_8I]F"V80@V*C8I]N,V*\@V+38I]F%
MV80@)60@V8;9B-N,V+/9AR#8J-BG(-BMV+'9B-F!(-JIV8C:AMJI(-BHV*?8
MM-BO+@#8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-BTV878IR#8K=BOV*?9@MF$
M(-BHV*?;C-BO(-BTV*?9A=F$("5D(-F&V8C;C-BSV8<@V+G8K]BOVXP@V*C8
MI]BTV*\N`-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\@V+39A=BG(-BMV*_8I]F"
MV80@V*C8I]N,V*\@V+38I]F%V80@)60@V8;9B-N,V+/9AR#8J-BG(-BMV+'9
MB-F!(-BHV++8L=JO(-BHV*?8M-BO+@#8I]BSV84@V+'9A=BR(-BLV*_;C-BO
M(-BTV878IR#8K=BOV*?:J=BKV+$@V*C8I]N,V*\@V+38I]F%V80@)60@V8;9
MB-N,V+/9A]F4(-BLV*?;C"#8KMBGV83;C"#8J-BGV+38KRX`V*?8L]F%(-BQ
MV878LB#8K-BOVXS8KR#8M-F%V*<@V8;8J-BGVXS8KR#8M-BGV879A"#9AMF(
MVXS8L]F'V90@V*S8I]N,(-BNV*?9A-N,(-BHV*?8M-BO+@#8I]BSV84@V+'9
MA=BRV8?8I]N,(-BLV*_;C-BO(-BTV878IR#8JMBWV*?8J-F"(-F&V*_8I]BQ
MV*\`VJ_8LMF*V8;9A^*`C-F'V*?;C"#8M-F%V*<@V*C9AR#8L=F(V+(@V+38
MK]F'(-BGV+/8J@#8L=F%V+(@V+G8J-F(V+$@V+39A=BG(-BOV8C8J-BGV+'9
MAR#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@V+38KP#8L=F%V++8N=BHV8C8L2#8
MM-F%V*<@V*_9B-BHV*?8L=F'(-BQV*?9A^*`C-BGV8;8K]BGV++;C"#8M-BO
MV8<@V*?8L]BJV(P@V;[8L]BJ(-BGV83:J=BJV+'9B-F&V8K:J2#8KMF(V*\@
MV+'8IR#:AMJI(-JIV8;9BMBO(-F((-BHV*<@V+'9A=BRV+G8J-F(V+$@V*S8
MK]F*V*\@V*[9B-BO(-F(V*?8L=BO(-BTV8C9BMBO`-BSV+'9B-BQXH",V8?8
MI]N,(-BOV8C8L2#8M-F%V*<Z`%O9OMF&V8?8I]F&(-JIV+'8K]F&(-F%V*K9
MAB#9AMF"V80@V8+9B-F$(-BTV*_9AUT`6]JOV++8I]BQV+0@V878M-JIV81=
M(`!;V8;9A=BGV8K8M"#9A=BJV88@V8;9@MF$(-F"V8C9A"#8M-BOV8<@+0#9
MAMF%V*?9BMBT(-F%V*K9AB#9AMF"V80@V8+9B-F$(-BTV*_9AUL@+2`E<R#8
MKMBW70!;V*[8MR`E<R#8I]BR("5S(%T@`-F%V*_9BMBQV8K8J@!#3$D`V*_8
ML=BNV*H@V*_8I]BOV8<`V*W8L-F!(-BSV+?8L0#:K]BQV8C9A^*`C-F'V*<`
MV+'8I]F'V8;9A=BG`-F(V8K:F-JOV8K9A]BGVXP@V*K8M=F(V8K8L2XN+@#9
MB-BQV8C8KP#8KMBQV8C8K`#8JMBZV8K9BMBQV*_8I]BOV88@V;[9BMF(V8;8
MKRXN+@#:K]BRV8K9AMF'XH",V8?8IP#8I]BLV*?8LMF'XH",V8?8I]N,(-BO
MV+/8JMBQV+/;C`#8J-BQV*_8I]BTV*K9AB#9OMF*V8C9AMBO+BXN`-BJV8;8
MN-F*V878I]BJ`-F(V8K:F-JOV8K9A]BGVXP@V*S8K]F(V80N+BX`VJG8I]BQ
MV*C8L=BGV88`VJG8JMBGV*C:AMF'(-BBV*_8L=BS(`#8KMBWV*?9BMN,(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ.@#8JMF"V8C9BMF%`-BBV+'8I]F%`-BGV8K9
MAMBLV*<@V+'8IR#9@=BTV*?8L2#8K]F'V8K8KP#8I]F&V*S8I]F%(-BTV*_9
MAP#8I]F&V*S8I]F%(-F&V+38K]F'`-F^V+'9B-F&V*_9AP#9OMF*V*_8IR#8
MM-BOV8<Z(`#8I]BR("5S("@E<RD@V*_8L2`E<R`E<P!H.@!I,3AN`-F!V8C8
ML=BGV8L`V*_8L=BNV+<`;&1A<%]S=&%R=%]T;',@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO`-BNV+?B@(S9A]BG70#9AMBGV84`V*K8NMF*V8K8L2#9AMJIV+'8
MK]F'(-BGV+/8J@#9OMF*V*_8IR#9AMBTV*_9AR#8I]BSV*H`V;[9BMBGV*_9
MAR#8L]BGV++;C"#9AMBTV*_9AR#8I]BSV*H`V8?9AMF(V+(@V;[9BMBGV*_9
MAR#8L]BGV++;C"#9AMBTV*_9AR#8I]BSV*H`;F]T97!A9`#8K]BQV+78KP#9
MOMF*VJG8L]F$`-BWV839B-BY`-F&V878I]F*V+0@V*K9@=BGV8C8JMF'V*<`
MV;[;C"#8K]BQ(-F^VXP`V8'9A]BQV+/8JB#9B-BXV*?9BMF!`-F^V+'9B-F&
MV*_9A^*`C"!03R#9A]F(V+'8KR#8J-BQV*?;C"#9A=BMV80@)7,@V879B-BL
MV8C8KR#9AMF*V+/8JCH`V+'9A=BR(-BYV*C9B-BQ(-BQV*<@V*C8L=BGVXP@
MV*K8H]F*V8K8KR#8K]F(V*C8I]BQ(-F(V*?8L=BO(-JIV8;9BMBO`-F*VJ_8
MI]F&V8<@V+38K]F'`-BHVXP@V8;8I]F%`-BHV8<@V+'9B-BR(-BTV*_9AP#8
MI]F&V*K8KMBGV*@@VJG8I]BQV*C8L0!W.@!W96%T:&5R+F-O;0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&%S<W=D+VQO8V%L92]F85])4B]H96QP+GAM;```````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#,T,P`Q,#0Q-S,V,C<T,P`P,C$V,38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTG,2XP)S\^#0H\(2TM("1(;W)D93H@<&%S<W=D+VQO8V%L
M92]F85])4B]H96QP+GAM;"QV(#$N,2`R,#`U+S`T+S(Q(#`Q.C,X.C0P('!E
M<G-I86XM:&]R9&4@:6X@365T84Y%5"`M+3X-"CQH96QP/@T*#0H\96YT<GD@
M:60](G!A<W-W9"UU<V5R;F%M92(^#0H@("`@/'1I=&QE/MF&V*?9A2#:J=BG
MV+'8J-BQ/"]T:71L93X-"B`@("`\:&5A9&EN9S[9AMBGV84@VJG8I]BQV*C8
ML=N,(-BTV878ISPO:&5A9&EN9SX-"B`@("`\<&%R83X-"B`@("#9AMBGV84@
MVJG8I]BQV*C8L=N,(-BNV8C8KR#8L=BG(-BOV+$@V*?9BMF&(-F"V+/9A=BJ
M(-F(V*?8L=BO(-F&V878I]F*V8K8KRX@("`@#0H@("`@/"]P87)A/@T*/"]E
M;G1R>3X-"@T*#0H\96YT<GD@:60](G!A<W-W9"UO;&0M<&%S<W=O<F0B/@T*
M("`@(#QT:71L93[8I]BSV84@V+'9A=BR(-F"V*C9A-N,/"]T:71L93X-"B`@
M("`\:&5A9&EN9S[8I]BSV84@V+'9A=BR(-F"V*C9A-N,/"]H96%D:6YG/@T*
M("`@(#QP87)A/@T*("`@(-BGV+/9A2#8L=F%V+(@V8'8N=F$VXP@V*[9B-BO
M(-BQV*<@V*_8L2#8I]F*V88@V8+8L]F%V*H@V8C8I]BQV*\@V8;9A=BGV8K9
MBMBO+B#8I]JOV+$@V*?8L]F%(-BQV878LB#9@=BYV83;C"#8KMF(V*\@V+'8
MIR#8J-F'(-BOV+'8L]BJVXP@V8C8I]BQV*\@V8;9AMF%V*?8IMF*V*\@V*K8
MNMF*V8K8L2#8I]BSV84@V+'9A=BR(-BYV*C9B-BQ(-F%V87:J=F&(-F&V*[9
MB-BGV8?8KR#8J-F(V*\N(`T*("`@(#PO<&%R83X-"CPO96YT<GD^#0H-"CQE
M;G1R>2!I9#TB<&%S<W=D+6YE=RUP87-S=V]R9"(^#0H@("`@/'1I=&QE/MBG
MV+/9A2#8L=F%V+(@V*S8K]F*V*\\+W1I=&QE/@T*("`@(#QH96%D:6YG/MBG
MV+/9A2#8L=F%V+(@V*S8K]F*V*\\+VAE861I;F<^#0H@("`@/'!A<F$^#0H@
M("`@V*?8L]F%(-BQV878LB#8K-BOV8K8KR#8KMF(V*\@V+'8IR#9B-BGV+'8
MKR#9AMF%V*?8IMF*V*\N(-BJV8C8K-F'(-BOV*?8M-BJV8<@V*C8I]BTV8K8
MKR#:J=F'(-BGV+/9A2#8L=F%V+(@V*S8K]F*V*\@V+39A=BG(-BHV*?9BMBO
M(-BHV+'8KMN,(-BGV+(@V*?8L]BJV*?9AMBOV*?8L=BOV8?8I]N,(-BSV*?8
MK]F'(-J&V8C9AB`@(`T*("`@(-BMV*_8I]F"V80@V+?9B-F$(-F%V*S8I]BR
MV(P@V+G8K]F%(-F*VJG8L]BGV88@V*C9B-BOV88@V*C8IR#9AMBGV84@VJG8
MI]BQV*C8L=N,(-BTV878I]B,(-F(V*S9B-BO(-BJV+':J=F*V*C;C"#8I]BR
M(-BMV+'9B-F!(-BGV839@=BHV*?9BMF*(-F((-BYV*_8K]N,(-BOV+$@V*+9
MAB#9B"`N+BX@V+'8IR#8L=BYV*?9BMBJ(-F&V878I]F*V*\N("`-"B`@("`\
M+W!A<F$^#0H\+V5N=')Y/@T*#0H\96YT<GD@:60](G!A<W-W9"UC;VYF:7)M
M+7!A<W-W;W)D(CX-"B`@("`\=&ET;&4^V*K8H]F*V8K8KR#8I]BSV84@V+'9
MA=BR(-BLV*_9BMBO(#PO=&ET;&4^#0H@("`@/&AE861I;F<^V*K8H]F*V8K8
MKR#8I]BSV84@V+'9A=BR(-BLV*_9BMBO/"]H96%D:6YG/@T*("`@(#QP87)A
M/@T*("`@(-BGV+/9A2#8L=F%V+(@V*S8K]F*V*\@V*[9B-BO(-BQV*<@V*_9
MB-BHV*?8L=F'(-F(V*?8L=BO(-F&V878I]F*V8K8KRX@V*?9BMF&(-BYV879
MA"#8J-BQV*?;C"#8I]BWV879BMF&V*?9AB#8I]BR(-BUV*W8JB#9B-BQV8C8
MKR#8I]BSV84@V+'9A=BR(-BLV*_9BMBO(-BTV878IR#8M=F(V+'8JB#9A=N,
MXH",V;[8L-F*V+'8KRX-"B`@("`\+W!A<F$^#0H\+V5N=')Y/@T*#0H\96YT
M<GD@:60](D-H86YG92UY;W5R+7!A<W-W;W)D(CX-"B`@("`\=&ET;&4^V*K8
MNMF*V8K8L2#8I]BSV84@V+'9A=BR(-BTV878ISPO=&ET;&4^#0H@("`@/&AE
M861I;F<^V*K8NMF*V8K8L2#8I]BSV84@V+'9A=BR(-BTV878ISPO:&5A9&EN
M9SX-"B`@("`\<&%R83X-"B`@("#:J=F$V8K8KR#8JMBZV8K9BMBQ(-BGV+/9
MA2#8L=F%V+(@V+'8IR#8J-F'(-F%V8;8N-F(V+$@V*K8NMF*V8K8L2#8I]BS
MV84@V+'9A=BR(-BNV8C8KR#8J-F!V+38I]BQV8K8KR`-"B`@("`\+W!A<F$^
M#0H\+V5N=')Y/@T*#0H\96YT<GD@:60](G)E<V5T(CX-"B`@("`\=&ET;&4^
MV*C8I]BR(-F&V+38I]F&VXP\+W1I=&QE/@T*("`@(#QH96%D:6YG/MBHV*?8
MLB#9AMBTV*?9AMN,/"]H96%D:6YG/@T*("`@(#QP87)A/@T*("`@(-BGV8K9
MAB#:J=F$V8K8KR#8L=BG(-BHV+'8I]N,(-BBV+K8I]BR(-F%V*S8K]BO(-F(
M(-F^V*?:J2#:J=BQV*_9AB#:J=F$V8K9AR#8I]BWV838I]BYV*?8JB#9B-BG
MV+'8K]F'(-F"V*C9A-N,(-BHV8'8M-BGV+'9BMBO+@T*("`@(#PO<&%R83X-
M"CPO96YT<GD^#0H-"CPO:&5L<#X-"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]E;E]54R\`````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<T,P`P,C`Q-S0`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C
M86QE+V5N7U53+VAE;'`N>&UL````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`S-3,W`#$P-#$W,S8R-S0S`#`R,38U,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/WAM;"!V97)S:6]N/2<Q+C`G
M/SX*/"$M+2`D2&]R9&4Z('!A<W-W9"]L;V-A;&4O96Y?55,O:&5L<"YX;6PL
M=B`Q+C<@,C`P-2\Q,"\P.2`Q-#HU.3HR,2!J86X@17AP("0@+2T^"CQH96QP
M/@H@(#QE;G1R>2!I9#TB<&%S<W=D+75S97)N86UE(CX*("`@(#QT:71L93Y5
M<V5R;F%M93PO=&ET;&4^"B`@("`\<&%R83Y%;G1E<B!Y;W5R('5S97)N86UE
M(&AE<F4@*&EF(&ET(&ES(&YO="!A;')E861Y('!R969I;&QE9"DN($YO="!A
M;&P*("`@(&EN<W1A;&QA=&EO;G,@<W5P<&]R="!T:&ES+CPO<&%R83X*("`\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&%S<W=D+6]L9"UP87-S=V]R9"(^"B`@
M("`\=&ET;&4^3VQD('!A<W-W;W)D/"]T:71L93X*("`@(#QP87)A/D5N=&5R
M('EO=7(@8W5R<F5N="P@=V]R:VEN9R!L;V=I;B!P87-S=V]R9"!H97)E+B!9
M;W4@;75S="!C;W)R96-T;'D*("`@(&5N=&5R('EO=7(@8W5R<F5N="!L;V=I
M;B!P87-S=V]R9"P@;W(@>6]U(&-A;B!N;W0@8VAA;F=E('EO=7(*("`@('!A
M<W-W;W)D+CPO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&%S<W=D
M+6YE=RUP87-S=V]R9"(^"B`@("`\=&ET;&4^3F5W('!A<W-W;W)D/"]T:71L
M93X*("`@(#QP87)A/D5N=&5R('1H92!N97<@<&%S<W=O<F0L('1H870@:7,@
M=VAA="!Y;W4@=V%N="!T;R!C:&%N9V4@>6]U<@H@("`@<&%S<W=O<F0@=&\N
M($YO=&4@=&AA="!T:&4@<&%S<W=O<F0@96YT97)E9"!M=7-T(&UE970@<V]M
M92!M:6YI;75M"B`@("!S=&%N9&%R9',@*'-U9F9I8VEE;G0@;&5N9W1H+"!N
M;W0@;6%T8V@@>6]U<B!U<V5R;F%M92P@:&%V92!A(&-O;6)I;F%T:6]N"B`@
M("!O9B!L971T97)S(&%N9"!O=&AE<B!C:&%R86-T97)S+"!E=&,I(&]R('EO
M=2!W:6QL(&=E="!A;B!E<G)O<BX\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT
M<GD@:60](G!A<W-W9"UC;VYF:7)M+7!A<W-W;W)D(CX*("`@(#QT:71L93Y#
M;VYF:7)M(&YE=R!P87-S=V]R9#PO=&ET;&4^"B`@("`\<&%R83Y%;G1E<B!T
M:&4@;F5W('!A<W-W;W)D(&$@<V5C;VYD('1I;64@:6X@=&AE($-O;F9I<FT@
M3F5W(%!A<W-W;W)D"B`@("!A<F5A+B!4:&ES(&ES('1O(&UA:V4@<W5R92!Y
M;W4@9&]N)W0@;6%K92!A('1Y<&\@;W(@;W1H97(@;6ES=&%K92!A;F0*("`@
M(&QO8VL@>6]U(&]U="!O9B!Y;W5R(&%C8V]U;G0N/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P87-S=V0M<V5R=F5R(CX*("`@(#QT:71L93Y#
M:&%N9V4@<&%S<W=O<F0@;VX\+W1I=&QE/@H@("`@/'!A<F$^4V5L96-T('1H
M92!S97)V97(@;W(@87!P;&EC871I;VX@:6X@=VAI8V@@>6]U('=A;G0@=&\@
M8VAA;F=E('1H90H@("`@<&%S<W=O<F0N($YO="!A;&P@:6YS=&%L;&%T:6]N
M<R!S=7!P;W)T('1H:7,N/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)#:&%N9V4M>6]U<BUP87-S=V]R9"(^"B`@("`\=&ET;&4^0VAA;F=E('!A
M<W-W;W)D/"]T:71L93X*("`@(#QP87)A/E!R97-S('1H92`B0VAA;F=E('EO
M=7(@<&%S<W=O<F0B(&)U='1O;B!A="!T:&4@8F]T=&]M(&]F('1H92!F;W)M
M"B`@("!T;R!S=6)M:70@>6]U<B!P87-S=V]R9"!R97%U97-T(&-H86YG92!T
M;R!T:&4@<WES=&5M+B!4:&ES(&)U='1O;B!T96QL<PH@("`@=&AE('-Y<W1E
M;2!T;R!A8W1U86QL>2!C:&%N9V4@>6]U<B!P87-S=V]R9"X\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](G)E<V5T(CX*("`@(#QT:71L93Y297-E
M=#PO=&ET;&4^"B`@("`\<&%R83Y5<V4@=&AE(%)E<V5T(&)U='1O;B!A="!T
M:&4@8F]T=&]M(&]F('1H92!F;W)M('1O(&-L96%R(&%N>2!F;W)M"B`@("!D
M871A('1H870@>6]U(&AA=F4@96YT97)E9"!A;F0@<W1A<G0@;W9E<BX\+W!A
M<F$^"B`@/"]E;G1R>3X*/"]H96QP/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]E
M<U]%4R\`````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<T,P`P,C`Q-C$`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P87-S=V0O;&]C86QE+V5S7T53+TQ#7TU%4U-!1T53+P``````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S`#`R,3<T-@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O97-?15,O3$-?3453
M4T%'15,O<&%S<W=D+FUO````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-#<R,3(`,3`T,3<S
M-C(W-#,`,#(S-C$S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````U@<``!P```#,/@``=0H``'Q]````````4*<`
M`$T```!1IP``OP```)^G``!D````7Z@``+X```#$J```D````(.I``!#````
M%*H``#P```!8J@``*P```)6J```N````P:H``"D```#PJ@``*````!JK``!%
M````0ZL``$<```")JP``2@```-&K``!'````'*P``$4```!DK```2````*JL
M```Y````\ZP``$8````MK0``2````'2M```P````O:T``$4```#NK0``1@``
M`#2N``!,````>ZX``#0```#(K@``,@```/VN``!I````,*\``#````":KP``
M)0```,NO``"(````\:\``$````!ZL```]@```+NP``!*````LK$``"P```#]
ML0``A0```"JR``!(````L+(```X```#YL@``#P````BS```,````&+,```@`
M```ELP``#````"ZS```$````.[,```P```!`LP``$0```$VS```E````7[,`
M``\```"%LP``"P```)6S```1````H;,``!````"SLP``#@```,2S```%````
MT[,``"@```#9LP``"@````*T```+````#;0``!4````9M```$@```"^T```+
M````0K0``!0```!.M```)@```&.T```G````BK0``"8```"RM```#@```-FT
M```*````Z+0```T```#SM```+@````&U```G````,+4``"````!8M0``#@``
M`'FU```7````B+4``"(```"@M0``-0```,.U```1````^;4```T````+M@``
M#````!FV```-````)K8```8````TM@``'0```#NV```;````6;8``"T```!U
MM@``'0```*.V```D````P;8``"D```#FM@``&0```!"W```/````*K<``!@`
M```ZMP``#````%.W```;````8+<```X```!\MP``#@```(NW```(````FK<`
M`$(```"CMP``+@```.:W```:````%;@``#T````PN```,@```&ZX```X````
MH;@``%0```#:N```40```"^Y``!:````@;D``%<```#<N0``-````#2Z```*
M````:;H```4```!TN@``!@```'JZ```1````@;H```@```"3N@``"0```)RZ
M```)````IKH```X```"PN@``"````+^Z```E````R+H``"````#NN@``$```
M``^[```/````(+L```H````PNP``!P```#N[```#````0[L```8```!'NP``
M#P```$Z[```4````7KL```D```!SNP``#0```'V[```2````B[L``!D```">
MNP``'@```+B[```/````U[L```H```#GNP``#P```/*[```(`````KP``"0`
M```+O```%P```#"\```4````2+P``!8```!=O```"````'2\``!.````?;P`
M`"T```#,O```'P```/J\```9````&KT```<````TO0``#````#R]```L````
M2;T```X```!VO0```P```(6]```+````B;T```<```"5O0``!P```)V]```%
M````I;T```4```"KO0``"@```+&]```#````O+T``!<```#`O0``"@```-B]
M```/````X[T```X```#SO0``&`````*^```C````&[X```X````_O@``%```
M`$Z^```7````8[X``!<```![O@``%P```).^```3````J[X```\```"_O@``
M#@```,^^```?````WKX```<```#^O@``!@````:_```(````#;\```\````6
MOP``!@```":_```*````+;\``!,````XOP``"P```$R_```5````6+\``!4`
M``!NOP``!P```(2_```%````C+\``!4```"2OP``$0```*B_```,````NK\`
M`#L```#'OP``.`````/````)````/,````<```!&P```%````$[````#````
M8\````4```!GP```$````&W````)````?L```!,```"(P```.0```)S````2
M````UL```#D```#IP```)P```"/!```L````2\$``"H```!XP0``)0```*/!
M```)````R<$```H```#3P0``!@```-[!```)````Y<$```<```#OP0``+P``
M`/?!```W````)\(``"X```!?P@``50```(["```M````Y,(``"T````2PP``
M+0```$##``!`````;L,``",```"OPP``(P```-/#```M````]\,``#,````E
MQ```%0```%G$```9````;\0``"D```")Q```)````+/$```1````V,0``!$`
M``#JQ```"@```/S$```$````!\4```P````,Q0``(@```!G%```*````/,4`
M`!````!'Q0``%@```%C%```6````;\4```<```"&Q0``!P```([%```4````
MEL4```H```"KQ0``"````+;%```&````O\4```0```#&Q0``"````,O%```'
M````U,4```<```#<Q0``!@```.3%```%````Z\4```<```#QQ0``!@```/G%
M```(`````,8``"D````)Q@``#@```#/&```*````0L8```\```!-Q@``#@``
M`%W&```$````;,8```<```!QQ@``"0```'G&```&````@\8``!$```"*Q@``
M!P```)S&```6````I,8```0```"[Q@``"````,#&```&````R<8```T```#0
MQ@``!@```-[&```>````Y<8```4````$QP``$0````K'```B````',<``!8`
M```_QP``"````%;'```-````7\<```P```!MQP``#````'K'```'````A\<`
M``,```"/QP```P```)/'```7````E\<``!,```"OQP``"````,/'```$````
MS,<```@```#1QP``"````-K'```*````X\<``$$```#NQP``(````##(```&
M````4<@```8```!8R```%0```%_(```8````=<@``"(```".R```+@```+'(
M```=````X,@``"$```#^R```5````"#)```I````=<D```H```"?R0``!P``
M`*K)```5````LLD```X```#(R0``"@```-?)```/````XLD```T```#RR0``
M#P````#*```-````$,H```D````>R@``%````"C*```&````/<H``!@```!$
MR@``'0```%W*```3````>\H``!0```"/R@``!````*3*```,````J<H```8`
M``"VR@``#P```+W*```3````S<H``%0```#AR@``%````#;+```7````2\L`
M``0```!CRP``#@```&C+``!$````=\L```4```"\RP``!0```,++```;````
MR,L``!H```#DRP``$0```/_+```1````$<P``!$````CS```'````#7,```J
M````4LP``!````!]S```(0```([,```E````L,P``!D```#6S```!0```/#,
M```3````]LP``!(````*S0``"@```!W-```/````*,T``!$````XS0``$P``
M`$K-```,````7LT```8```!KS0``!@```'+-```7````><T``!$```"1S0``
M"````*/-```%````K,T```P```"RS0``$````+_-```%````T,T```T```#6
MS0``!@```.3-```'````Z\T```T```#SS0``$`````'.```)````$LX```<`
M```<S@``"P```"3.```+````,,X```<````\S@``!P```$3.```)````3,X`
M`!0```!6S@``"0```&O.```*````=<X``!D```"`S@``'0```)K.```,````
MN,X``!````#%S@``%0```-;.```%````[,X``"4```#RS@``$@```!C/```3
M````*\\``"L````_SP``.P```&O/```@````I\\```@```#(SP``-@```-'/
M```0````"-````@````9T```#````"+0```&````+]````0````VT```#@``
M`#O0```0````2M````H```!;T```"@```&;0```-````<=```!X```!_T```
M&P```)[0```A````NM```!X```#<T```&0```/O0```>````%=$``!T````T
MT0``+0```%+1```;````@-$``"````"<T0``+@```+W1```7````[-$``"8`
M```$T@``,````"O2```;````7-(``!X```!XT@``'````)?2```F````M-(`
M`"L```#;T@``,P````?3```F````.],``"L```!BTP``.````([3```=````
MQ],``!4```#ETP``+P```/O3```2````*]0``"`````^U```*0```%_4```>
M````B=0``"$```"HU```$@```,K4``"B````W=0``!8```"`U0``(P```)?5
M```H````N]4``"D```#DU0``*`````[6```?````-]8``!4```!7U@``(```
M`&W6```E````CM8``"D```"TU@``+0```-[6```A````#-<``!8````NUP``
M'````$77```F````8M<``"H```")UP``00```+37``!$````]M<```P````[
MV```!P```$C8```'````4-@```8```!8V```#0```%_8```0````;=@``!(`
M``!^V```$P```)'8```2````I=@```<```"XV```!````,#8```-````Q=@`
M``P```#3V```#@```.#8```/````[]@``!,```#_V```#0```!/9```H````
M(=D```,```!*V0``#0```$[9```&````7-D``!$```!CV0``%P```'79```;
M````C=D```X```"IV0```@```+C9```%````N]D```0```#!V0``$````,;9
M```$````U]D```T```#<V0``#@```.K9```#````^=D```X```#]V0``"```
M``S:```/````%=H```@````EV@``#P```"[:```-````/MH``!````!,V@``
M$P```%W:```3````<=H```L```"%V@``$0```)':```)````H]H```8```"M
MV@``#````+3:```1````P=H``!D```#3V@``"P```.W:```-````^=H``"(`
M```'VP``&P```"K;```T````1ML```H```![VP``&````(;;```9````G]L`
M`!8```"YVP``+P```-#;```B`````-P```T````CW```!P```#'<```,````
M.=P``"8```!&W```%````&W<```+````@MP``"(```".W```+P```+'<```+
M````X=P```D```#MW```&0```/?<```+````$=T``!<````=W0``%P```#7=
M```)````3=T``!8```!7W0``#P```&[=```6````?MT```X```"5W0``&```
M`*3=```(````O=T```T```#&W0``)@```-3=``!#````^]T```@````_W@``
M$@```$C>```(````6]X```L```!DW@``+P```'#>```.````H-X```4```"O
MW@``!@```+7>```#````O-X```<```#`W@``!````,C>```*````S=X```H`
M``#8W@``#P```./>```0````\]X``!<````$WP``$0```!S?```7````+M\`
M`!D```!&WP``"0```&#?```%````:M\```L```!PWP``"@```'S?```"````
MA]\```4```"*WP``#0```)#?```;````GM\``!<```"ZWP``"0```-+?```.
M````W-\```T```#KWP``$@```/G?```X````#.```"````!%X````P```&;@
M```(````:N````X```!SX```>P```(+@```8````_N```$`````7X0``$0``
M`%CA```'````:N$```4```!RX0``(````'CA```8````F>$``!D```"RX0``
M$P```,SA```'````X.$```<```#HX0``"````/#A```&````^>$```8`````
MX@``$`````?B```/````&.(``!`````HX@``#P```#GB```+````2>(```\`
M``!5X@``#````&7B```/````<N(```<```""X@``"@```(KB```&````E>(`
M``P```"<X@``*````*GB```/````TN(```@```#BX@``%@```.OB```(````
M`N,``!,````+XP``'@```!_C```A````/N,``"````!@XP``&0```('C```7
M````F^,``"4```"SXP``%P```-GC```F````\>,```0````8Y```&P```!WD
M```-````.>0```P```!'Y````P```%3D```(````6.0```H```!AY```#```
M`&SD```+````>>0```0```"%Y```$P```(KD```4````GN0```P```"SY```
M"0```,#D```.````RN0```L```#9Y```&P```.7D```'`````>4```<````)
MY0``"@```!'E```-````'.4```D````JY0``!````#3E```%````.>4```,`
M```_Y0``&````$/E```*````7.4```0```!GY0``)@```&SE```.````D^4`
M`'P```"BY0``%0```!_F```%````->8```<````[Y@``#````$/F```(````
M4.8```H```!9Y@``!@```&3F```(````:^8``!8```!TY@``$@```(OF```"
M````GN8```8```"AY@``!@```*CF```4````K^8``!4```#$Y@``#P```-KF
M```1````ZN8``!H```#\Y@``#0```!?G```0````)><``!L````VYP``!```
M`%+G```)````5^<``!````!AYP``"0```'+G```)````?.<```4```"&YP``
M!0```(SG```:````DN<```@```"MYP``!@```+;G```9````O><```X```#7
MYP``(@```.;G```'````">@```<````1Z```#@```!GH```%````*.@```D`
M```NZ```"@```#CH```"````0^@```8```!&Z```#0```$WH```)````6^@`
M``8```!EZ```$@```&SH```%````?^@```D```"%Z```!P```(_H```$````
ME^@``!0```"<Z```'0```+'H```1````S^@```8```#AZ```"@```.CH```$
M````\^@```D```#XZ```"`````+I```1````"^D```X````=Z0``$0```"SI
M```)````/ND```8```!(Z0``#0```$_I```&````7>D```(```!DZ0``!```
M`&?I```Y````;.D``#T```"FZ0``.@```.3I```>````'^H```4````^Z@``
M#@```$3J```$````4^H```8```!8Z@``(0```%_J```5````@>H```8```"7
MZ@``!````)[J```1````H^H```8```"UZ@``H````+SJ```*````7>L``"(`
M``!HZP``!````(OK```E````D.L```4```"VZP``'0```+SK```$````VNL`
M``P```#?ZP``"@```.SK```(````]^L```D`````[```!0````KL```;````
M$.P``#H````L[```,````&?L```U````F.P``"D```#.[```+@```/CL``!'
M````)^T``#@```!O[0``*0```*CM```_````TNT``"X````2[@``+0```$'N
M```?````;^X```\```"/[@``$@```)_N```+````LNX``"8```"^[@``*0``
M`.7N```D````#^\``"8````T[P``"````%OO```*````9.\```D```!O[P``
M!P```'GO```@````@>\``"````"B[P``)@```,/O```*````ZN\``!D```#U
M[P``*0````_P```6````.?```!(```!0\```!P```&/P```*````:_````\`
M``!V\```$````(;P``!`````E_```'````#8\```9@```$GQ```.````L/$`
M``D```"_\0``"@```,GQ```2````U/$``!,```#G\0``#````/OQ```&````
M"/(```\````/\@``$@```!_R```0````,O(```H```!#\@``$0```$[R```2
M````8/(``!P```!S\@``(P```)#R``!J````M/(```\````?\P``!0```"_S
M```0````-?,```D```!&\P``!````%#S```+````5?,``!H```!A\P``%```
M`'SS```,````D?,```P```">\P``#P```*OS```5````N_,``"D```#1\P``
M*@```/OS```F````)O0``"<```!-]```*0```'7T```J````G_0``!D```#*
M]```0@```.3T```1````)_4``!(````Y]0``$P```$SU```4````8/4```\`
M``!U]0``%@```(7U```7````G/4``!````"T]0``$0```,7U```T````U_4`
M`!,````,]@``$@```"#V```U````,_8``!0```!I]@``!P```'[V```,````
MAO8``"L```"3]@``(````+_V```4````X/8``!$```#U]@``%P````?W```<
M````'_<``!,````\]P``$0```%#W```:````8O<``!X```!]]P``&@```)SW
M```1````M_<``!<```#)]P``%````.'W```7````]O<``!4````.^```"0``
M`"3X```9````+O@```0```!(^```!P```$WX```+````5?@``!$```!A^```
M!@```'/X```&````>O@```8```"!^```!0```(CX```'````CO@```<```"6
M^```!0```)[X```6````I/@```8```"[^```!@```,+X```$````R?@```0`
M``#.^```!P```-/X```.````V_@```P```#J^```#````/?X```-````!/D`
M``H````2^0``#@```!WY```%````+/D``"@````R^0``#@```%OY```,````
M:OD```\```!W^0``"@```(?Y```(````DOD```D```";^0``*P```*7Y```$
M````T?D```@```#6^0``!0```-_Y```F````Y?D``!(````,^@``#P```!_Z
M```&````+_H```H````V^@``!P```$'Z```(````2?H``"````!2^@``"0``
M`'/Z```,````??H```T```"*^@``#@```)CZ```6````I_H``!$```"^^@``
M!@```-#Z```(````U_H```,```#@^@``!@```.3Z```9````Z_H```<````%
M^P``!`````W[```+````$OL```L````>^P``!P```"K[```'````,OL``!8`
M```Z^P``#0```%'[```*````7_L```T```!J^P``"@```'C[```1````@_L`
M`!````"5^P``#P```*;[```1````MOL``!<```#(^P``"@```.#[```1````
MZ_L```@```#]^P``!`````;\```/````"_P``#H````;_```!0```%;\```,
M````7/P``!X```!I_```#@```(C\```0````E_P```L```"H_```#````+3\
M```)````P?P```<```#+_```"@```-/\```)````WOP```X```#H_```$```
M`/?\```:````"/T```H````C_0``"0```"[]```4````./T```H```!-_0``
M#````%C]```/````9?T```@```!U_0``!@```'[]```,````A?T```<```"2
M_0``#0```)K]```%````J/T```L```"N_0``1P```+K]```-`````OX```8`
M```0_@``"0```!?^```$````(?X```,````F_@``$P```"K^```3````/OX`
M`!,```!2_@``!@```&;^```+````;?X```H```!Y_@```@```(3^```$````
MA_X``"4```",_@```P```++^```%````MOX``"H```"\_@``"@```.?^```%
M````\OX```0```#X_@``"@```/W^```-````"/\``$`````6_P``$P```%?_
M```&````:_\```@```!R_P``"````'O_```$````A/\```4```")_P``:```
M`(__```)````^/\```P````"``$`!0````\``0`&````%0`!`!L````<``$`
M+P```#@``0`0````:``!``H```!Y``$`#P```(0``0`*````E``!``D```"?
M``$`$P```*D``0`;````O0`!`!@```#9``$`%P```/(``0`.````"@$!``,`
M```9`0$`!P```!T!`0`(````)0$!`!0````N`0$`$P```$,!`0`0````5P$!
M``T```!H`0$`#@```'8!`0`6````A0$!``<```"<`0$`"@```*0!`0`+````
MKP$!`"T```"[`0$`%0```.D!`0`P````_P$!`"0````P`@$`!P```%4"`0!1
M````70(!`!````"O`@$`#````,`"`0`-````S0(!`!H```#;`@$`2@```/8"
M`0`&````00,!`!H```!(`P$`!@```&,#`0`&````:@,!`!\```!Q`P$`!@``
M`)$#`0`)````F`,!`!@```"B`P$`%P```+L#`0`&````TP,!``T```#:`P$`
M(@```.@#`0!7````"P0!`!,```!C!`$`(P```'<$`0`3````FP0!``(```"O
M!`$`"P```+($`0`(````O@0!``T```#'!`$`"@```-4$`0`&````X`0!``<`
M``#G!`$`%````.\$`0`&````!`4!``@````+!0$`#@```!0%`0`'````(P4!
M``H````K!0$`"P```#8%`0`'````0@4!``P```!*!0$`#0```%<%`0`,````
M904!``D```!R!0$`"0```'P%`0`*````A@4!``<```"1!0$`"0```)D%`0`'
M````HP4!``H```"K!0$`!P```+8%`0`;````O@4!`!(```#:!0$`"@```.T%
M`0`)````^`4!`!`````"!@$`!P```!,&`0`2````&P8!``0````N!@$`!P``
M`#,&`0`%````.P8!``0```!!!@$`#````$8&`0`%````4P8!``L```!9!@$`
M%````&4&`0`1````>@8!`!H```",!@$`%@```*<&`0`4````O@8!`!<```#3
M!@$`&````.L&`0`<````!`<!`!D````A!P$`!P```#L'`0`%````0P<!``T`
M``!)!P$`#````%<'`0`(````9`<!`!<```!M!P$`"P```(4'`0`-````D0<!
M`!,```"?!P$`!````+,'`0`*````N`<!``0```##!P$`"0```,@'`0`*````
MT@<!``P```#=!P$`"0```.H'`0`%````]`<!``<```#Z!P$`!0````((`0`$
M````"`@!``(````-"`$`.````!`(`0`L````20@!`!(```!V"`$`*0```(D(
M`0`R````LP@!``H```#F"`$`-@```/$(`0`L````*`D!`!4```!5"0$`+@``
M`&L)`0`S````F@D!`#,```#."0$`.`````(*`0`/````.PH!`!@```!+"@$`
M.P```&0*`0`0````H`H!`!0```"Q"@$`$P```,8*`0`4````V@H!`!(```#O
M"@$`%`````(+`0`5````%PL!`"T````M"P$`+0```%L+`0`Q````B0L!`"T`
M``"["P$`+@```.D+`0`O````&`P!`"P```!(#`$`8@```'4,`0`3````V`P!
M``@```#L#`$`"````/4,`0`;````_@P!`"L````:#0$`(0```$8-`0`:````
M:`T!``D```"##0$`10```(T-`0!!````TPT!``\````5#@$`!````"4.`0`3
M````*@X!`!0````^#@$`#@```%,.`0`3````8@X!`!@```!V#@$`!@```(\.
M`0`)````E@X!``H```"@#@$`#P```*L.`0`0````NPX!``<```#,#@$`#@``
M`-0.`0`%````XPX!`!L```#I#@$`!@````4/`0`(````#`\!``8````5#P$`
M%````!P/`0`1````,0\!``X```!##P$`.````%(/`0`"````BP\!``8```".
M#P$`#@```)4/`0`:````I`\!``4```"_#P$`!P```,4/`0`.````S0\!``8`
M``#<#P$`#0```.,/`0`$````\0\!`"D```#V#P$`%P```"`0`0`?````.!`!
M`%P```!8$`$`%````+40`0`^````RA`!`!\````)$0$`$````"D1`0`4````
M.A$!``<```!/$0$`#@```%<1`0`(````9A$!``P```!O$0$`#````'P1`0`3
M````B1$!``H```"=$0$`'0```*@1`0`9````QA$!``4```#@$0$`$0```.81
M`0`1````^!$!`"0````*$@$`%0```"\2`0`2````11(!``X```!8$@$`&0``
M`&<2`0`(````@1(!``D```"*$@$`#0```)02`0`*````HA(!``L```"M$@$`
M"@```+D2`0`'````Q!(!``@```#,$@$`!0```-42`0`?````VQ(!``8```#[
M$@$`$`````(3`0`(````$Q,!``T````<$P$`(@```"H3`0`(````31,!`!<`
M``!6$P$`$@```&X3`0`J````@1,!`"L```"L$P$`+````-@3`0`:````!10!
M``D````@%`$`"@```"H4`0`5````-10!``4```!+%`$`%````%$4`0`$````
M9A0!`!````!K%`$`!@```'P4`0`'````@Q0!`!X```"+%`$`*````*H4`0`*
M````TQ0!`!P```#>%`$`&@```/L4`0`/````%A4!`!0````F%0$`!````#L5
M`0`$````0!4!``L```!%%0$`!0```%$5`0`&````5Q4!``@```!>%0$`!@``
M`&<5`0`*````;A4!`!L```!Y%0$`-````)45`0`T````RA4!`"````#_%0$`
M*0```"`6`0`@````2A8!`$$```!K%@$`&@```*T6`0`H````R!8!`"D```#Q
M%@$`40```!L7`0`O````;1<!`%<```"=%P$`+````/47`0`B````(A@!``8`
M``!%&`$`"````$P8`0`%````51@!``@```!;&`$`&0```&08`0`9````?A@!
M`"H```"8&`$`"````,,8`0`C````S!@!`"X```#P&`$`-````!\9`0`-````
M5!D!``@```!B&0$`%P```&L9`0`*````@QD!``<```".&0$`(0```)89`0`-
M````N!D!`!````#&&0$`#@```-<9`0`+````YAD!``<```#R&0$`$P```/H9
M`0`(````#AH!``L````7&@$`"@```",:`0`4````+AH!`#(```!#&@$`"P``
M`'8:`0`%````@AH!``4```"(&@$`%P```(X:`0`/````IAH!``0```"V&@$`
M"P```+L:`0`3````QQH!``H```#;&@$`"0```.8:`0`+````\!H!``X```#\
M&@$`!0````L;`0`$````$1L!``T````6&P$`,@```"0;`0!%````5QL!`!<`
M``"=&P$`'@```+4;`0`4````U!L!``4```#I&P$`%````.\;`0`'````!!P!
M`",````,'`$`#@```#`<`0`J````/QP!``8```!J'`$`#````'$<`0`-````
M?AP!`!$```",'`$`%P```)X<`0`+````MAP!`#8```#"'`$`"@```/D<`0`B
M````!!T!``L````G'0$`#P```#,=`0`+````0QT!`"````!/'0$`)P```'`=
M`0`K````F!T!``D```#$'0$`,@```,X=`0`P`````1X!`#$````R'@$`+0``
M`&0>`0`_````DAX!`#T```#2'@$`-@```!`?`0`4````1Q\!``4```!<'P$`
M#@```&(?`0`3````<1\!``<```"%'P$`&@```(T?`0`(````J!\!`!$```"Q
M'P$`!P```,,?`0`4````RQ\!`!@```#@'P$`!P```/D?`0`%`````2`!``P`
M```'(`$`#````!0@`0`2````(2`!``0````T(`$`!P```#D@`0`*````02`!
M``L```!,(`$`#````%@@`0`.````92`!``X```!T(`$`!0```(,@`0`%````
MB2`!`"X```"/(`$`)@```+X@`0`C````Y2`!``,````)(0$`$@````TA`0`&
M````("$!`!X````G(0$`&````$8A`0`<````7R$!`"4```!\(0$`#0```*(A
M`0`)````L"$!``(```"Z(0$``P```+TA`0`'````P2$!``H```#)(0$``@``
M`-0A`0`,````UR$!`!4```#D(0$`"P```/HA`0`9````!B(!`"`````@(@$`
M$@```$$B`0`%````5"(!``H```!:(@$`%0```&4B`0`2````>R(!``P```".
M(@$`!````)LB`0`'````H"(!``D```"H(@$`#````+(B`0!2````OR(!`!<`
M```2(P$`)````"HC`0`'````3R,!``8```!7(P$`#@```%XC`0`B````;2,!
M`!T```"0(P$`#````*XC`0`-````NR,!`!4```#)(P$`$@```-\C`0`/````
M\B,!`!0````")`$`&P```!<D`0`0````,R0!`&D```!$)`$`&@```*XD`0`7
M````R20!`"<```#A)`$`&@````DE`0`7````)"4!`!L````\)0$`&0```%@E
M`0`?````<B4!`!<```"2)0$`$P```*HE`0`(````OB4!``<```#')0$`"```
M`,\E`0`)````V"4!`!4```#B)0$`#0```/@E`0`3````!B8!``,````:)@$`
M1@```!XF`0`_````928!`#<```"E)@$`5P```-TF`0`?````-2<!`"\```!5
M)P$`"@```(4G`0`(````D"<!``T```"9)P$`+0```*<G`0`$````U2<!`$\`
M``#:)P$`)0```"HH`0`<````4"@!``L```!M*`$`'P```'DH`0`=````F2@!
M`"4```"W*`$`(````-TH`0`D````_B@!`"`````C*0$`"P```$0I`0`'````
M4"D!``X```!8*0$`#0```&<I`0`,````=2D!``8```""*0$`.0```(DI`0`,
M````PRD!``<```#0*0$`&0```-@I`0`)````\BD!`!,```#\*0$`!P```!`J
M`0`)````&"H!``0````B*@$`$````"<J`0`*````."H!``@```!#*@$`"```
M`$PJ`0`$````52H!``L```!:*@$`#````&8J`0`1````<RH!``P```"%*@$`
M&@```)(J`0`/````K2H!``<```"]*@$`#0```,4J`0`4````TRH!``X```#H
M*@$`#````/<J`0`;````!"L!`"P````@*P$`$P```$TK`0`<````82L!`"@`
M``!^*P$`!@```*<K`0`'````KBL!`!,```"V*P$`!0```,HK`0`$````T"L!
M`!<```#5*P$`"@```.TK`0`,````^"L!``D````%+`$`!@````\L`0`)````
M%BP!``@````@+`$`"0```"DL`0`%````,RP!``H````Y+`$`$0```$0L`0`&
M````5BP!`!@```!=+`$`#@```'8L`0`.````A2P!``T```"4+`$`"P```*(L
M`0`=````KBP!``L```#,+`$``@```-@L`0`'````VRP!`!<```#C+`$`!@``
M`/LL`0!E`````BT!``D```!H+0$`!P```'(M`0`F````>BT!`#@```"A+0$`
M&@```-HM`0`J````]2T!`#L````@+@$`*P```%PN`0`H````B"X!`!D```"Q
M+@$`%0```,LN`0`%````X2X!``<```#G+@$`"````.\N`0`'````^"X!``4`
M````+P$`!P````8O`0`.````#B\!``D````=+P$`!@```"<O`0`(````+B\!
M``L````W+P$`!P```$,O`0`(````2R\!``<```!4+P$`%@```%PO`0`)````
M<R\!``8```!]+P$`"P```(0O`0`<````D"\!`!0```"M+P$`!P```,(O`0`(
M````RB\!``@```#3+P$`!0```-PO`0`0````XB\!`!````#S+P$`!@````0P
M`0`9````"S`!``H````E,`$`'````#`P`0`'````33`!``4```!5,`$`!```
M`%LP`0`0````8#`!`!0```!Q,`$`"P```(8P`0`-````DC`!`!@```"@,`$`
M%P```+DP`0`:````T3`!`!0```#L,`$`!`````$Q`0`)````!C$!``H````0
M,0$`!P```!LQ`0`"````(S$!``X````F,0$`"````#4Q`0`?````/C$!`#X`
M``!>,0$`(P```)TQ`0`C````P3$!`#@```#E,0$`,0```!XR`0`G````4#(!
M`&0```!X,@$`%````-TR`0`<````\C(!`%4````/,P$`.````&4S`0!*````
MGC,!`%L```#I,P$`*````$4T`0`X````;C0!`"H```"G-`$`*````-(T`0`L
M````^S0!`"<````H-0$`&P```%`U`0`^````;#4!`*D!``"K-0$`*````%4W
M`0`C````?C<!`!<```"B-P$`&0```+HW`0!(````U#<!`(4````=.`$`,```
M`*,X`0!!````U#@!`%L````6.0$`20```'(Y`0`=````O#D!`!@```#:.0$`
M(0```/,Y`0`?````%3H!`"L````U.@$`(0```&$Z`0`I````@SH!`!T```"M
M.@$`$0```,LZ`0`S````W3H!`"4````1.P$`.````#<[`0`G````<#L!`!\`
M``"8.P$`,````+@[`0!I````Z3L!`"L```!3/`$`,@```'\\`0`Q````LCP!
M`$$```#D/`$`,P```"8]`0`E````6CT!`#T```"`/0$`90```+X]`0!-````
M)#X!`"\```!R/@$`+@```*(^`0`K````T3X!`#````#]/@$`*@```"X_`0`^
M````63\!`%0```"8/P$`@P```.T_`0!:````<4`!`$@```#,0`$`2@```!5!
M`0`R````8$$!`#(```"300$`'0```,9!`0`C````Y$$!`"\````(0@$`+```
M`#A"`0`M````94(!`'$```"30@$`;P````5#`0"S````=4,!`!<````I1`$`
M)0```$%$`0`R````9T0!`"D```":1`$`/@```,1$`0`B`````T4!`%(````F
M10$`)0```'E%`0`+````GT4!`+$```"K10$`10```%U&`0`A````HT8!`"X`
M``#%1@$`,````/1&`0`E````)4<!`!P```!+1P$`,0```&A'`0`'````FD<!
M``<```"B1P$`!````*I'`0`-````KT<!``L```"]1P$`#@```,E'`0`+````
MV$<!``4```#D1P$`$````.I'`0`"````^T<!`%D```#^1P$`!0```%A(`0`2
M````7D@!``0```!Q2`$`!P```'9(`0`(````?D@!``4```"'2`$``P```(U(
M`0`0````D4@!``H```"B2`$`#````*U(`0`3````ND@!``T```#.2`$``@``
M`-Q(`0`'````WT@!``8```#G2`$`%````.Y(`0`,`````TD!`!@````020$`
M!@```"E)`0`2````,$D!``P```!#20$``P```%!)`0`J````5$D!``0```!_
M20$`!@```(1)`0`'````BTD!`!\```"320$`-0```+-)`0`N````Z4D!`"\`
M```82@$`%P```$A*`0`@````8$H!`!L```"!2@$`&````)U*`0`D````MDH!
M`!\```#;2@$`&@```/M*`0`@````%DL!`!H````W2P$`,@```%)+`0`O````
MA4L!`!H```"U2P$`*P```-!+`0`?````_$L!`",````<3`$`'P```$!,`0`:
M````8$P!`"4```![3`$`)@```*%,`0`E````R$P!`"0```#N3`$`&````!--
M`0`=````+$T!`"0```!*30$`&````&]-`0`B````B$T!`"4```"K30$`/```
M`-%-`0`?````#DX!`",````N3@$`'P```%).`0`@````<DX!`!H```"33@$`
M&````*Y.`0`F````QTX!`!X```#N3@$`*0````U/`0`>````-T\!``D```!6
M3P$`#````&!/`0`7````;4\!`"\```"%3P$`)````+5/`0`'````VD\!`!\`
M``#B3P$`#P````)0`0`4````$E`!``X````G4`$`#0```#90`0`D````1%`!
M``4```!I4`$`!P```&]0`0`B````=U`!`"4```":4`$`$P```,!0`0`=````
MU%`!`!H```#R4`$`!P````U1`0#'````%5$!``L```#=40$`%0```.E1`0`,
M````_U$!``8````,4@$`"0```!-2`0`8````'5(!``L````V4@$`#0```$)2
M`0`=````4%(!`!<```!N4@$`!@```(92`0`S````C5(!`!,```#!4@$`$P``
M`-52`0`'````Z5(!``8```#Q4@$`#P```/A2`0`1````"%,!``<````:4P$`
M,@```")3`0`A````55,!`!,```!W4P$`#````(M3`0`1````F%,!`#(```"J
M4P$`#@```-U3`0`/````[%,!`!````#\4P$`"`````U4`0`=````%E0!``D`
M```T5`$`"@```#Y4`0`%````250!`!0```!/5`$`"@```&14`0`=````;U0!
M``@```"-5`$`'P```)94`0`(````ME0!`!H```"_5`$`!@```-I4`0`5````
MX50!``<```#W5`$`"````/]4`0`)````"%4!`#\````250$`!P```%)5`0`/
M````6E4!``X```!J50$`$````'E5`0`)````BE4!``D```"450$`"````)Y5
M`0`3````IU4!``<```"[50$`&0```,-5`0`*````W54!``H```#H50$`"0``
M`/-5`0`7````_54!`!0````55@$`"@```"I6`0`,````-58!`!<```!"5@$`
M!````%I6`0`J````7U8!`!$```"*5@$`!P```)Q6`0`)````I%8!``(```"N
M5@$`$````+%6`0`8````PE8!``L```#;5@$``P```.=6`0`(````ZU8!``8`
M``#T5@$`!P```/M6`0`-`````U<!``L````15P$`%````!U7`0`5````,E<!
M``X```!(5P$`+P```%=7`0`@````AU<!`!P```"H5P$`#````,57`0`Q````
MTE<!``4````$6`$`$@````I8`0`_````'5@!`!(```!=6`$`"@```'!8`0`&
M````>U@!``0```""6`$`!````(=8`0`3````C%@!``4```"@6`$`!@```*98
M`0`&````K5@!``D```"T6`$`!````+Y8`0`,````PU@!``H```#06`$`;```
M`-M8`0`@````2%D!``4```!I60$`&````&]9`0`9````B%D!`!\```"B60$`
M'0```,)9`0`1````X%D!``(```#R60$`!````/59`0`*````^ED!``8````%
M6@$`!0````Q:`0`#````$EH!``P````66@$`10```"-:`0`:````:5H!`"$`
M``"$6@$`-0```*9:`0`E````W%H!`"@````"6P$`4P```"M;`0`9````?UL!
M`'(```"96P$`(`````Q<`0`U````+5P!`$4```!C7`$`,````*E<`0`C````
MVEP!`!\```#^7`$`*````!Y=`0`I````1UT!`"8```!Q70$`)0```)A=`0`H
M````OET!`"@```#G70$`(@```!!>`0`A````,UX!`#````!57@$`$@```(9>
M`0`3````F5X!`!````"M7@$`>0```+Y>`0`)````.%\!`'(```!"7P$`<P``
M`+5?`0!\````*6`!`"L```"F8`$`4P```-)@`0`7````)F$!`!8````^80$`
M#P```%5A`0!E````96$!`!\```#+80$`40```.MA`0`W````/6(!`#8```!U
M8@$`-@```*QB`0`^````XV(!`$$````B8P$`0P```&1C`0!\````J&,!`$``
M```E9`$`/@```&9D`0!`````I60!`$(```#F9`$`.0```"EE`0`?````8V4!
M`!\```"#90$`'````*-E`0!1````P&4!`!0````29@$`"@```"=F`0`%````
M,F8!``8````X9@$`"````#]F`0`%````2&8!`!(```!.9@$`$````&%F`0`3
M````<F8!`!T```"&9@$`#P```*1F`0`/````M&8!``0```#$9@$`"0```,EF
M`0`+````TV8!``<```#?9@$`!0```.=F`0`4````[68!``<````"9P$`"```
M``IG`0`/````$V<!``@````C9P$`#````"QG`0`/````.6<!``8```!)9P$`
M%````%!G`0`&````96<!``P```!L9P$`%0```'EG`0`(````CV<!``0```"8
M9P$`"@```)UG`0`$````J&<!``8```"M9P$`!P```+1G`0`$````O&<!``<`
M``#!9P$`&0```,EG`0`"````XV<!``0```#F9P$`"0```.MG`0`&````]6<!
M`!4```#\9P$`!@```!)H`0`G````&6@!``0```!!:`$`"P```$9H`0`)````
M4F@!``\```!<:`$`$P```&QH`0`'````@&@!``<```"(:`$`!@```)!H`0`&
M````EV@!`!````">:`$`$@```*]H`0`&````PF@!``D```#):`$`,P```--H
M`0`B````!VD!``<````J:0$`!P```#)I`0`'````.FD!``L```!":0$`!0``
M`$YI`0`"````5&D!``L```!7:0$`?@$``&-I`0!Y````XFH!`+8```!<:P$`
M<@```!-L`0#:````AFP!`+P```!A;0$`30```!YN`0`]````;&X!`#(```"J
M;@$`+@```-UN`0`I````#&\!`"@````V;P$`3````%]O`0!(````K&\!`$P`
M``#U;P$`20```$)P`0!*````C'`!`&L```#7<`$`/0```$-Q`0!*````@7$!
M`$P```#,<0$`,0```!ER`0!O````2W(!`#L```"[<@$`2P```/=R`0`\````
M0W,!`$$```"`<P$`=````,)S`0`U````-W0!`"P```!M=`$`E0```)IT`0!H
M````,'4!`!(!``"9=0$`2@```*QV`0`S````]W8!`(P````K=P$`4P```+AW
M`0`/````#'@!`!(````<>`$`$````"]X`0`&````0'@!``<```!'>`$``P``
M`$]X`0`*````4W@!`!(```!>>`$`+````'%X`0`6````GG@!``H```"U>`$`
M$P```,!X`0`3````U'@!`!0```#H>`$`!0```/UX`0`N`````WD!``L````R
M>0$`#@```#YY`0`:````37D!``T```!H>0$`#@```'9Y`0`3````A7D!`#4`
M``"9>0$`*0```,]Y`0`N````^7D!``T````H>@$`"@```#9Z`0`7````07H!
M`#X```!9>@$`)@```)AZ`0`?````OWH!``X```#?>@$`%P```.YZ`0`C````
M!GL!`#(````J>P$`$0```%U[`0`,````;WL!`!8```!\>P$`#````)-[`0`&
M````H'L!`"D```"G>P$`'P```-%[`0`R````\7L!`"\````D?`$`*````%1\
M`0`M````?7P!`!D```"K?`$`#P```,5\`0`5````U7P!`!$```#K?`$`&P``
M`/U\`0`3````&7T!`!,````M?0$`"````$%]`0!I````2GT!`#8```"T?0$`
M)````.M]`0!`````$'X!`#@```!1?@$`0P```(I^`0!E````SGX!`&(````T
M?P$`:P```)=_`0!H`````X`!`#H```!L@`$`$P```*>``0`%````NX`!``D`
M``#!@`$`$0```,N``0`,````W8`!``T```#J@`$`#0```/B``0`0````!H$!
M``@````7@0$`-````""!`0`Q````58$!`!0```"'@0$`%````)R!`0`,````
ML8$!``@```"^@0$`!@```,>!`0`)````SH$!`!D```#8@0$`'@```/*!`0`,
M````$8(!``P````>@@$`$0```"N"`0`C````/8(!`"@```!A@@$`$@```(J"
M`0`.````G8(!``\```"L@@$`"@```+R"`0`O````QX(!`!(```#W@@$`&0``
M``J#`0`9````)(,!``X````^@P$`7````$V#`0`Z````JH,!`"8```#E@P$`
M*@````R$`0`)````-X0!``L```!!A`$`-````$V$`0`.````@H0!``@```"1
MA`$`"@```)J$`0`'````I80!``<```"MA`$`!0```+6$`0`'````NX0!``L`
M``##A`$`!0```,^$`0`A````U80!`!````#WA`$`%0````B%`0`/````'H4!
M`!L````NA0$`-````$J%`0`)````?X4!`!<```")A0$`%@```*&%`0`8````
MN(4!`"$```#1A0$`%P```/.%`0`1````"X8!``\````=A@$`'P```"V&`0`'
M````388!``8```!5A@$`!P```%R&`0`-````9(8!``D```!RA@$`"0```'R&
M`0`2````AH8!``H```"9A@$`&0```*2&`0`L````OH8!``<```#KA@$`!0``
M`/.&`0`6````^88!`!(````0AP$`$@```".'`0`^````-H<!`#T```!UAP$`
M"0```+.'`0`'````O8<!`!,```#%AP$`!````-F'`0`%````WH<!``X```#D
MAP$`#@```/.'`0`7`````H@!`$<````:B`$`%@```&*(`0!1````>8@!`"8`
M``#+B`$`*P```/*(`0`L````'HD!`#0```!+B0$`"@```(")`0`)````BXD!
M``8```"5B0$`"0```)R)`0`'````IHD!`#@```"NB0$`.@```.>)`0`W````
M(HH!`%P```!:B@$`-@```+>*`0`V````[HH!`#8````EBP$`3@```%R+`0`L
M````JXL!`"X```#8BP$`-@````>,`0`\````/HP!`!@```![C`$`'````)2,
M`0`S````L8P!`"T```#EC`$`$P```!.-`0`3````)XT!``H````[C0$`#```
M`$:-`0`,````4XT!`"T```!@C0$`!0```(Z-`0`.````E(T!`!\```"CC0$`
M)@```,.-`0`'````ZHT!``<```#RC0$`%0```/J-`0`*````$(X!``@````;
MC@$`!@```"2.`0`+````*XX!``H````WC@$`!P```$*.`0`'````2HX!``8`
M``!2C@$`!0```%F.`0`(````7XX!``8```!HC@$`"@```&^.`0`T````>HX!
M`!(```"OC@$`#@```,*.`0`3````T8X!``T```#EC@$`!P```/..`0`'````
M^XX!``H````#CP$`!0````Z/`0`1````%(\!``8````FCP$`$@```"V/`0`%
M````0(\!``@```!&CP$`"````$^/`0`.````6(\!``8```!GCP$`*0```&Z/
M`0`&````F(\!`!$```"?CP$`*0```+&/`0`:````VX\!``@```#VCP$`$0``
M`/^/`0`,````$9`!``\````>D`$`!P```"Z0`0`#````-I`!``,````ZD`$`
M&@```#Z0`0`8````69`!``8```!RD`$`!0```'F0`0`'````?Y`!``<```"'
MD`$`"0```(^0`0!E````F9`!`"D```#_D`$`!@```"F1`0`(````,)$!`!T`
M```YD0$`)0```%>1`0`G````?9$!`#0```"ED0$`*````-J1`0`M`````Y(!
M`&(````QD@$`-@```)22`0`*````RY(!``D```#6D@$`%@```."2`0`,````
M]Y(!``X````$DP$`%````!.3`0`0````*),!`!0````YDP$`$P```$Z3`0`.
M````8I,!`!4```!QDP$`!P```(>3`0`8````CY,!`!L```"HDP$`&````,23
M`0`9````W9,!``0```#WDP$`"````/R3`0`'````!90!`!4````-E`$`%@``
M`".4`0!8````.I0!`!4```"3E`$`'0```*F4`0`'````QY0!`!4```#/E`$`
M1````.64`0`%````*I4!``4````PE0$`&P```#:5`0`8````4I4!`!0```!K
ME0$`&@```("5`0`1````FY4!`!X```"ME0$`.P```,R5`0`.````")8!`"P`
M```7E@$`*@```$26`0`9````;Y8!``<```")E@$`&P```)&6`0`2````K98!
M``X```#`E@$`&````,^6`0`6````Z)8!`!,```#_E@$`#@```!.7`0`%````
M(I<!``8````HEP$`&````"^7`0`/````2)<!``@```!8EP$`!0```&&7`0`1
M````9Y<!`!(```!YEP$`"0```(R7`0`7````EI<!``8```"NEP$`!P```+67
M`0`1````O9<!`!4```#/EP$`"0```.67`0`*````[Y<!``T```#ZEP$`#```
M``B8`0`'````%9@!``@````=F`$`"0```":8`0`5````,)@!``L```!&F`$`
M"P```%*8`0`?````7I@!`"0```!^F`$`#0```*.8`0`4````L9@!`!X```#&
MF`$`!0```.68`0`@````ZY@!`!(````,F0$`$P```!^9`0`Z````,YD!`$H`
M``!NF0$`)P```+F9`0`)````X9D!`#P```#KF0$`$0```"B:`0`)````.IH!
M``H```!$F@$`!@```$^:`0`&````5IH!`!````!=F@$`$0```&Z:`0`'````
M@)H!``H```"(F@$`#P```).:`0`K````HYH!`"L```#/F@$`+0```/N:`0`N
M````*9L!`"(```!8FP$`)0```'N;`0`D````H9L!`#4```#&FP$`(@```/R;
M`0`E````'YP!`#8```!%G`$`&@```'R<`0`N````EYP!`#@```#&G`$`)0``
M`/^<`0`H````)9T!`"0```!.G0$`,0```'.=`0!%````I9T!`$````#KG0$`
M-0```"R>`0`T````8IX!`#X```"7G@$`)@```-:>`0`E````_9X!`#P````C
MGP$`%0```&"?`0`E````=I\!`#D```"<GP$`)0```-:?`0`O````_)\!`!0`
M```LH`$`R@```$&@`0`;````#*$!`#$````HH0$`,````%JA`0`S````BZ$!
M`#$```"_H0$`)P```/&A`0`H````&:(!`"L```!"H@$`,@```&ZB`0`T````
MH:(!`$L```#6H@$`)P```"*C`0`=````2J,!`"8```!HHP$`,P```(^C`0`Q
M````PZ,!`$X```#UHP$`50```$2D`0`-````FJ0!``0```"HI`$`!@```*VD
M`0`%````M*0!``\```"ZI`$`!0```,JD`0`1````T*0!`!8```#BI`$`'```
M`/FD`0`'````%J4!``0````>I0$`"P```".E`0`+````+Z4!``H````[I0$`
M#0```$:E`0`2````5*4!``T```!GI0$`.@```'6E`0`&````L*4!`!````"W
MI0$`!@```,BE`0`1````SZ4!`!<```#AI0$`&P```/FE`0`/````%:8!``(`
M```EI@$`"P```"BF`0`%````-*8!``P````ZI@$`!0```$>F`0`7````3:8!
M`!(```!EI@$``P```'BF`0`1````?*8!``D```".I@$`$0```)BF`0`)````
MJJ8!`!````"TI@$`$0```,6F`0`5````UZ8!`!<```#MI@$`%P````6G`0`,
M````':<!`!$````JIP$`"````#RG`0`4````1:<!``X```!:IP$`$P```&FG
M`0`:````?:<!``X```"8IP$`$````*>G`0`K````N*<!`!P```#DIP$`1```
M``&H`0`-````1J@!`!\```!4J`$`&0```'2H`0`6````CJ@!`#X```"EJ`$`
M0P```.2H`0`0````**D!``D````YJ0$`$P```$.I`0`W````5ZD!`!0```"/
MJ0$`"P```*2I`0`V````L*D!`#4```#GJ0$`"@```!VJ`0`5````**H!`"D`
M```^J@$`%P```&BJ`0`6````@*H!`!8```"7J@$`"@```*ZJ`0`@````N:H!
M`!D```#:J@$`&````/2J`0`9````#:L!`!@````GJP$`"````$"K`0`+````
M2:L!`"D```!5JP$`6````'^K`0`(````V*L!`!0```#AJP$`"0```/:K`0`,
M`````*P!`#8````-K`$`$0```$2L`0`&````5JP!``8```!=K`$``P```&2L
M`0`'````:*P!`!4```!PK`$`$````(:L`0`/````EZP!`!0```"GK`$`%0``
M`+RL`0`;````TJP!`!8```#NK`$`&P````6M`0`=````(:T!``D````_K0$`
M!@```$FM`0`+````4*T!``L```!<K0$``@```&BM`0`&````:ZT!`!,```!R
MK0$`+P```(:M`0`7````MJT!``H```#.K0$`$0```-FM`0`4````ZZT!`!P`
M````K@$`.0```!VN`0`W````5ZX!``4```"/K@$`$@```)6N`0`/````J*X!
M`(8```"XK@$`(P```#^O`0!-````8Z\!`!$```"QKP$`!P```,.O`0`%````
MRZ\!`"8```#1KP$`(0```/BO`0`?````&K`!`!<````ZL`$`!P```%*P`0`'
M````6K`!``<```!BL`$`!@```&JP`0`&````<;`!``\```!XL`$`#@```(BP
M`0`0````E[`!``X```"HL`$`%0```+>P`0`/````S;`!``L```#=L`$`$P``
M`.FP`0`(````_;`!``L````&L0$`"````!*Q`0`/````&[$!`$4````KL0$`
M%````'&Q`0`)````AK$!`!0```"0L0$`#@```*6Q`0`?````M+$!`"````#4
ML0$`)P```/6Q`0`F````';(!`!@```!$L@$`%P```%VR`0`@````=;(!`!@`
M``"6L@$`*````*^R`0`)````V+(!`!D```#BL@$`"P```/RR`0`5````"+,!
M``,````>LP$`!P```"*S`0`.````*K,!`!`````YLP$`#0```$JS`0`$````
M6+,!`!H```!=LP$`&P```'BS`0`(````E+,!`!$```"=LP$`%````*^S`0`.
M````Q+,!`"<```#3LP$`!P```/NS`0`)`````[0!`!`````-M`$`$````!ZT
M`0`*````+[0!``<````ZM`$`"P```$*T`0`&````3K0!`!@```!5M`$`#@``
M`&ZT`0`&````?;0!`"@```"$M`$`$````*VT`0";````OK0!`!L```!:M0$`
M"P```':U`0`'````@K4!``\```"*M0$`"````)JU`0`*````H[4!``4```"N
MM0$`"````+2U`0`B````O;4!`!X```#@M0$``P```/^U`0`&`````[8!``<`
M```*M@$`%@```!*V`0`@````*;8!`!X```!*M@$`'0```&FV`0`I````A[8!
M`!````"QM@$`$@```,*V`0`=````U;8!``(```#SM@$`!````/:V`0`4````
M^[8!``H````0MP$`#P```!NW`0`'````*[<!``4````SMP$`(P```#FW`0`(
M````7;<!``8```!FMP$`&P```&VW`0`/````B;<!`"$```"9MP$`!P```+NW
M`0`(````P[<!`!$```#,MP$`!0```-ZW`0`)````Y+<!``\```#NMP$``@``
M`/ZW`0`&`````;@!`!(````(N`$`$````!NX`0`&````++@!`!,````SN`$`
M!0```$>X`0`+````3;@!``<```!9N`$`!````&&X`0`8````9K@!`#````!_
MN`$`%````+"X`0`&````Q;@!``D```#,N`$`!````-:X`0`)````V[@!``D`
M``#EN`$`%P```.^X`0`5````![D!`!<````=N0$`#````#6Y`0`&````0KD!
M``T```!)N0$`!P```%>Y`0`"````7[D!``0```!BN0$`00```&>Y`0!(````
MJ;D!`$$```#RN0$`)P```#2Z`0`%````7+H!``T```!BN@$`!P```'"Z`0`(
M````>+H!`!L```"!N@$`%0```)VZ`0`&````L[H!``4```"ZN@$`$````,"Z
M`0`(````T;H!`)@```#:N@$`"@```'.[`0`C````?KL!``0```"BNP$`0P``
M`*>[`0`'````Z[L!`"<```#SNP$`!@```!N\`0`)````(KP!`!,````LO`$`
M"````$"\`0`)````2;P!``4```!3O`$`(@```%F\`0!'````?+P!`#0```#$
MO`$`00```/F\`0`R````.[T!`#4```!NO0$`20```*2]`0`[````[KT!`"P`
M```JO@$`/@```%>^`0`O````EKX!`#T```#&O@$`,0````2_`0`0````-K\!
M`!$```!'OP$`"P```%F_`0`R````9;\!`"$```"8OP$`'P```+J_`0`>````
MVK\!``<```#YOP$`"0````'``0`*````"\`!``<````6P`$`*0```![``0`L
M````2,`!`#T```!UP`$`#````+/``0`C````P,`!`#8```#DP`$`%@```!O!
M`0`5````,L$!``@```!(P0$`"P```%'!`0`0````7<$!`!<```!NP0$`10``
M`(;!`0!\````S,$!`&<```!)P@$`#0```+'"`0`0````O\(!`!$```#0P@$`
M%````.+"`0`5````]\(!`!<````-PP$`"````"7#`0`1````+L,!`!,```!`
MPP$`$@```%3#`0`*````9\,!`!4```!RPP$`%0```(C#`0`N````GL,!`"T`
M``#-PP$`EP```/O#`0`1````D\0!``4```"EQ`$`%0```*O$`0`)````P<0!
M``L```#+Q`$`"P```-?$`0`>````X\0!`!@````"Q0$`#P```!O%`0`.````
M*\4!`!0````ZQ0$`&0```$_%`0`M````:<4!`"X```"7Q0$`*@```,;%`0`J
M````\<4!`"8````<Q@$`*````$/&`0`>````;,8!`$$```"+Q@$`%0```,W&
M`0`4````X\8!`!<```#XQ@$`%@```!#'`0`1````)\<!`!<````YQP$`%@``
M`%''`0`4````:,<!`!0```!]QP$`.P```)+'`0`9````SL<!`!H```#HQP$`
M.@````/(`0`3````/L@!``8```!2R`$`$````%G(`0`]````:L@!`"T```"H
MR`$`%0```-;(`0`5````[,@!`"`````"R0$`'@```"/)`0`<````0LD!`!,`
M``!?R0$`(````'/)`0`F````E,D!`"````"[R0$`%````-S)`0`=````\<D!
M`!P````/R@$`(0```"S*`0`9````3LH!``H```!HR@$`&P```'/*`0`$````
MC\H!``<```"4R@$`"P```)S*`0`2````J,H!``8```"[R@$`!@```,+*`0`'
M````R<H!``8```#1R@$`!P```-C*`0`%````X,H!``4```#FR@$`%0```.S*
M`0`&`````LL!``8````)RP$`!0```!#+`0`%````%LL!``H````<RP$`$0``
M`"?+`0`*````.<L!`!8```!$RP$`%````%O+`0`*````<,L!`!<```![RP$`
M!0```)/+`0`U````F<L!`!(```#/RP$`$0```.++`0`:````],L!``\````/
MS`$`#0```!_,`0`0````+<P!`#0````^S`$`!0```'/,`0`(````><P!``4`
M``""S`$`)P```(C,`0`3````L,P!`!````#$S`$`!@```-7,`0`*````W,P!
M``T```#GS`$`!@```/7,`0`B````_,P!`!`````?S0$`$````##-`0`5````
M0<T!`!$```!7S0$`&@```&G-`0`4````A,T!``8```"9S0$`!P```*#-`0`%
M````J,T!``P```"NS0$`)@```+O-`0`'````XLT!``D```#JS0$`$@```/3-
M`0`7````!\X!``<````?S@$`!P```"?.`0`6````+\X!``T```!&S@$`"@``
M`%3.`0`/````7\X!``T```!OS@$`%P```'W.`0`6````E<X!`!@```"LS@$`
M#P```,7.`0`1````U<X!``P```#GS@$`&````/3.`0`,````#<\!``<````:
MSP$`%````"+/`0!"````-\\!``@```!ZSP$`#````(//`0`M````D,\!`!4`
M``"^SP$`%0```-3/`0`-````ZL\!``P```#XSP$`"0````70`0`'````#]`!
M``H````7T`$`"0```"+0`0`.````+-`!`!`````[T`$`*@```$S0`0`*````
M=]`!``@```""T`$`%````(O0`0`*````H-`!``P```"KT`$`#0```+C0`0`)
M````QM`!``X```#0T`$`%````-_0`0`%````]-`!``L```#ZT`$`#@````;1
M`0`:````%=$!`%T````PT0$`&@```([1`0`%````J=$!``X```"OT0$`!```
M`+[1`0`$````P]$!`!H```#(T0$`&@```./1`0`:````_M$!``8````9T@$`
M"P```"#2`0`*````+-(!``(````WT@$`!````#K2`0`E````/](!``,```!E
MT@$`!0```&G2`0`I````;](!``H```"9T@$`!0```*32`0`&````JM(!``L`
M``"QT@$`$0```+W2`0!1````S](!`!4````ATP$`!@```#?3`0`'````/M,!
M``@```!&TP$`!````$_3`0`%````5-,!`&L```!:TP$`"@```,;3`0`-````
MT=,!``4```#?TP$`!@```.73`0`I````[-,!`#8````6U`$`#@```$W4`0`)
M````7-0!`!,```!FU`$`"@```'K4`0`(````A=0!`!<```".U`$`.````*;4
M`0`?````W]0!`!X```#_U`$`#P```![5`0`$````+M4!``<````SU0$`"```
M`#O5`0`4````1-4!`!8```!9U0$`%````'#5`0`3````A=4!`!@```"9U0$`
M)0```++5`0`(````V-4!`!$```#AU0$`#P```//5`0`W`````]8!`!@````[
MU@$`,@```%36`0`F````A]8!``<```"NU@$`80```+;6`0`1````&-<!``\`
M```JUP$`#P```#K7`0`;````2M<!`%$```!FUP$`!@```+C7`0`?````O]<!
M``<```#?UP$`!@```.?7`0`@````[M<!``@````/V`$`"0```!C8`0`A````
M(M@!`"````!$V`$`"````&78`0`*````;M@!`"<```!YV`$`5````*'8`0`;
M````]M@!`!\````2V0$`&@```#+9`0`#````3=D!``P```!1V0$`"````%[9
M`0`9````9]D!``T```"!V0$`!@```(_9`0`&````EMD!`!8```"=V0$`!@``
M`+39`0`(````N]D!``D```#$V0$`#````,[9`0`*````V]D!`!````#FV0$`
M"0```/?9`0`:`````=H!`!<````<V@$`&````#3:`0`5````3=H!`!@```!C
MV@$`%@```'S:`0`6````D]H!`!4```"JV@$`%@```,#:`0`*````U]H!``<`
M``#BV@$`'P```.K:`0`2````"ML!``D````=VP$`"0```"?;`0`9````,=L!
M``<```!+VP$`%P```%/;`0`&````:]L!``<```!RVP$`!0```'K;`0`$````
M@-L!`!8```"%VP$`!0```)S;`0`'````HML!`!,```"JVP$`%````+[;`0`B
M````T]L!`"(```#VVP$`'0```!G<`0`<````-]P!`"(```!4W`$`)@```'?<
M`0`?````GMP!``,```"^W`$`!0```,+<`0`/````R-P!``\```#8W`$`"@``
M`.C<`0`B````\]P!``T````6W0$`$0```"3=`0`6````-MT!``@```!-W0$`
M#@```%;=`0`)````9=T!``X```!OW0$`#````'[=`0`3````B]T!``D```"?
MW0$`!0```*G=`0`'````K]T!``4```"WW0$`!````+W=`0`"````PMT!`#<`
M``#%W0$`.P```/W=`0`9````.=X!`"8```!3W@$`1@```'K>`0`,````P=X!
M`$<```#.W@$`-````!;?`0`A````2]\!`#L```!MWP$`1````*G?`0!$````
M[M\!`$P````SX`$`#P```(#@`0`@````D.`!`$D```"QX`$`'P```/O@`0`@
M````&^$!`!\````\X0$`(````%SA`0`@````?>$!`"````">X0$`#````+_A
M`0!!````S.$!`$$````.X@$`10```%#B`0!!````EN(!`$8```#8X@$`0P``
M`!_C`0!`````8^,!`'D```"DXP$`%0```![D`0`)````-.0!``<````^Y`$`
M'0```$;D`0`Z````9.0!`#@```"?Y`$`)````-CD`0`+````_>0!`%,````)
MY0$`2@```%WE`0`1````J.4!``<```"ZY0$`%P```,+E`0`5````VN4!``\`
M``#PY0$`$`````#F`0`8````$>8!``<````JY@$`"@```#+F`0`(````/>8!
M`!,```!&Y@$`$````%KF`0`.````:^8!`!(```!ZY@$`!0```(WF`0`D````
MD^8!``4```"XY@$`"0```+[F`0`&````R.8!`!0```#/Y@$`$@```.3F`0`/
M````]^8!`$@````'YP$`!P```%#G`0`&````6.<!`!(```!?YP$`(````'+G
M`0`%````D^<!``<```"9YP$`#P```*'G`0`'````L><!`!,```"YYP$`!```
M`,WG`0`[````TN<!``X````.Z`$`*````!WH`0"'````1N@!`!H```#.Z`$`
M10```.GH`0`G````+^D!`!$```!7Z0$`%0```&GI`0`(````?^D!``X```"(
MZ0$`"0```)?I`0`.````H>D!``P```"PZ0$`$P```+WI`0`,````T>D!`"``
M``#>Z0$`'````/_I`0`$````'.H!`!`````AZ@$`&P```#+J`0`J````3NH!
M`!$```!YZ@$`%@```(OJ`0`1````HNH!`!\```"TZ@$`"@```-3J`0`,````
MW^H!`!8```#LZ@$`%`````/K`0`2````&.L!``T````KZP$`!@```#GK`0`(
M````0.L!``4```!)ZP$`(````$_K`0`&````<.L!`!(```!WZP$`"````(KK
M`0`3````D^L!`"````"GZP$`"@```,CK`0`C````T^L!`!4```#WZP$`,0``
M``WL`0`R````/^P!`$$```!R[`$`&P```+3L`0`+````T.P!``P```#<[`$`
M)0```.GL`0`%````#^T!`!8````5[0$``P```"SM`0`1````,.T!``4```!"
M[0$`"@```$CM`0`E````4^T!`#D```!Y[0$`"@```+/M`0`F````ONT!`!T`
M``#E[0$`"P````/N`0`4````#^X!``0````D[@$`"````"GN`0`)````,NX!
M``@````\[@$`"P```$7N`0`(````4>X!``<```!:[@$`!P```&+N`0`2````
M:NX!`"H```!][@$`-P```*CN`0`;````X.X!`"L```#\[@$`(P```"CO`0!!
M````3.\!`!L```".[P$`)````*KO`0`M````S^\!`$P```#][P$`,@```$KP
M`0!5````??`!`"D```#3\`$`*````/WP`0`'````)O$!``@````N\0$`"0``
M`#?Q`0`(````0?$!`!4```!*\0$`%````&#Q`0`L````=?$!``@```"B\0$`
M+P```*OQ`0`W````V_$!`#\````3\@$`"@```%/R`0`'````7O(!`!H```!F
M\@$`"0```('R`0`,````B_(!`"X```"8\@$`#P```,?R`0`3````U_(!`!(`
M``#K\@$`#0```/[R`0`+````#/,!`!@````8\P$`"0```#'S`0`2````._,!
M`!$```!.\P$`&@```&#S`0`Y````>_,!``L```"U\P$`!0```,'S`0`(````
MQ_,!`!H```#0\P$`#P```.OS`0`&````^_,!``X````"]`$`%````!'T`0`/
M````)O0!`!$````V]`$`"````$CT`0`3````4?0!``4```!E]`$`$````&OT
M`0`-````?/0!`#P```"*]`$`4@```,?T`0`B````&O4!`"8````]]0$`&P``
M`&3U`0`%````@/4!`!<```"&]0$`#0```)[U`0`M````K/4!`!(```#:]0$`
M*@```.WU`0`&````&/8!``T````?]@$`#@```"WV`0`0````//8!`!,```!-
M]@$`"@```&'V`0`]````;/8!``D```"J]@$`(````+3V`0`0````U?8!`!0`
M``#F]@$`$@```/OV`0`E````#O<!`$`````T]P$`.0```'7W`0`-````K_<!
M`$````"]]P$`0@```/[W`0!#````0?@!`#P```"%^`$`5@```,+X`0!/````
M&?D!`$@```!I^0$`%@```++Y`0`'````R?D!`!(```#1^0$`$@```.3Y`0`*
M````]_D!`!P````"^@$`"P```!_Z`0`3````*_H!``<````_^@$`%P```$?Z
M`0`H````7_H!``8```"(^@$`!P```(_Z`0`0````E_H!`!4```"H^@$`%P``
M`+[Z`0`'````UOH!``<```#>^@$`"0```.;Z`0`4````\/H!`!(````%^P$`
M$P```!C[`0`3````+/L!``8```!`^P$`!0```$?[`0`Q````3?L!`"@```!_
M^P$`)0```*C[`0`(````SOL!``\```#7^P$`!@```.?[`0`:````[OL!`!D`
M```)_`$`(@```"/\`0`K````1OP!``D```!R_`$`#````'S\`0`"````B?P!
M``,```",_`$`!0```)#\`0`-````EOP!``,```"D_`$`#````*C\`0`3````
MM?P!``L```#)_`$`%P```-7\`0`8````[?P!`!,````&_0$`!0```!K]`0`*
M````(/T!`!8````K_0$`%0```$+]`0`.````6/T!``<```!G_0$`"@```&_]
M`0`,````>OT!`!````"'_0$`70```)C]`0`F````]OT!`#P````=_@$`!P``
M`%K^`0`&````8OX!``L```!I_@$`)````'7^`0`<````FOX!`!0```"W_@$`
M%````,S^`0`<````X?X!`!\```#^_@$`%@```![_`0`>````-?\!`"T```!4
M_P$`%0```(+_`0!N````F/\!`"0````'``(`(````"P``@`K````30`"`",`
M``!Y``(`'P```)T``@`C````O0`"`"4```#A``(`'P````<!`@`>````)P$"
M`!L```!&`0(`"@```&(!`@`'````;0$"``@```!U`0(`"@```'X!`@`3````
MB0$"``\```"=`0(`'````*T!`@`*````R@$"`%(```#5`0(`10```"@"`@!`
M````;@("`'@```"O`@(`,````"@#`@`Q````60,"``H```"+`P(`!P```)8#
M`@`-````G@,"`#H```"L`P(`$P```.<#`@!$````^P,"`"T```!`!`(`)P``
M`&X$`@`0````E@0"`#(```"G!`(`(P```-H$`@`S````_@0"`"H````R!0(`
M,@```%T%`@`K````D`4"``T```"\!0(`"0```,H%`@`2````U`4"`!$```#G
M!0(`$P```/D%`@`'````#08"`#<````5!@(`#````$T&`@`$````6@8"`"0`
M``!?!@(`!0```(0&`@`2````B@8"``<```"=!@(`"````*4&`@`&````K@8"
M`!0```"U!@(`"@```,H&`@`*````U08"``D```#@!@(`!0```.H&`@`1````
M\`8"`!$````"!P(`'````!0'`@`5````,0<"`"$```!'!P(`#0```&D'`@`'
M````=P<"`!(```!_!P(`*0```)('`@`)````O`<"``D```#&!P(`&P```-`'
M`@`H````[`<"``X````5"`(`(0```"0(`@`T````1@@"``D```!["`(`"0``
M`(4(`@`2````CP@"``8```"B"`(`!````*D(`@`B````K@@"``T```#1"`(`
M#P```-\(`@`,````[P@"``@```#\"`(`"0````4)`@`(````#PD"``D````8
M"0(`!P```"()`@`-````*@D"`!(````X"0(`!@```$L)`@`8````4@D"`!D`
M``!K"0(`%0```(4)`@`'````FPD"`!````"C"0(`(````+0)`@`,````U0D"
M``,```#B"0(`!@```.8)`@`G````[0D"``8````5"@(`>P```!P*`@`)````
MF`H"``4```"B"@(`+````*@*`@!&````U0H"`",````<"P(`+P```$`+`@!0
M````<`L"`#T```#!"P(`.@```/\+`@`D````.@P"`"````!?#`(`!0```(`,
M`@`'````A@P"``@```".#`(`"0```)<,`@`'````H0P"``@```"I#`(`$@``
M`+(,`@`*````Q0P"``D```#0#`(`"P```-H,`@`+````Y@P"``<```#R#`(`
M!P```/H,`@`(`````@T"`!0````+#0(`"P```"`-`@`&````+`T"``4````S
M#0(`+0```#D-`@`8````9PT"``@```"`#0(`"0```(D-`@`+````DPT"``4`
M``"?#0(`%````*4-`@`4````N@T"``8```#/#0(`&@```-8-`@`*````\0T"
M`!P```#\#0(`"````!D.`@`&````(@X"``0````I#@(`$@```"X.`@`D````
M00X"``L```!F#@(`#0```'(.`@`A````@`X"`!P```"B#@(`(0```+\.`@`9
M````X0X"``4```#[#@(`"@````$/`@`3````#`\"`!@````@#P(``P```#D/
M`@`3````/0\"``D```!1#P(`(````%L/`@`^````?`\"`"(```"[#P(`)```
M`-X/`@`S`````Q`"`#4````W$`(`+P```&T0`@!D````G1`"`!8````"$0(`
M)0```!D1`@!<````/Q$"`#H```"<$0(`20```-<1`@!K````(1("`"H```"-
M$@(`00```+@2`@`L````^A("`#$````G$P(`-P```%D3`@`M````D1,"`!T`
M``"_$P(`0@```-T3`@#3`0``(!0"`"L```#T%0(`(@```"`6`@`7````0Q8"
M`!H```!;%@(`3````'86`@"`````PQ8"`#<```!$%P(`/P```'P7`@!>````
MO!<"`$H````;&`(`(@```&88`@`4````B1@"`"$```">&`(`(````,`8`@`K
M````X1@"`!\````-&0(`+````"T9`@`B````6AD"`!4```!]&0(`-P```),9
M`@`F````RQD"`$H```#R&0(`+````#T:`@`:````:AH"`"T```"%&@(`:0``
M`+,:`@`H````'1L"`#<```!&&P(`-@```'X;`@!)````M1L"`#<```#_&P(`
M+0```#<<`@!`````91P"`'````"F'`(`4@```!<=`@`U````:AT"`#<```"@
M'0(`-@```-@=`@`T````#QX"`"T```!$'@(`5````'(>`@!K````QQX"`)$`
M```S'P(`<P```,4?`@!:````.2`"`%D```"4(`(`.@```.X@`@`W````*2$"
M`!X```!A(0(`*0```(`A`@`I````JB$"`"D```#4(0(`+P```/XA`@!Y````
M+B("`'<```"H(@(`Q````"`C`@`6````Y2,"`"<```#\(P(`.````"0D`@`O
M````720"`$T```"-)`(`*@```-LD`@!C````!B4"`",```!J)0(`"P```(XE
M`@"H````FB4"`$H```!#)@(`*0```(XF`@`Y````N"8"`#@```#R)@(`*@``
M`"LG`@`C````5B<"`#T```!Z)P(`!@```+@G`@`+````OR<"``0```#+)P(`
M"@```-`G`@`/````VR<"`!$```#K)P(`"P```/TG`@`&````"2@"`!$````0
M*`(`!````"(H`@!F````)R@"``,```".*`(`%````)(H`@`$````IR@"``<`
M``"L*`(`!@```+0H`@`%````NR@"``@```#!*`(`%0```,HH`@`)````X"@"
M``P```#J*`(`$0```/<H`@`1````"2D"``,````;*0(`!0```!\I`@`'````
M)2D"`!(````M*0(`#````$`I`@`4````32D"``8```!B*0(`%0```&DI`@`-
M````?RD"``,```"-*0(`+@```)$I`@`$````P"D"``8```#%*0(`!P```,PI
M`@`E````U"D"`$<```#Z*0(`.````$(J`@`Y````>RH"`!@```"U*@(`)@``
M`,XJ`@`<````]2H"`"$````2*P(`*````#0K`@`C````72L"`"````"!*P(`
M)@```*(K`@`B````R2L"`#8```#L*P(`,P```",L`@`=````5RP"`#D```!U
M+`(`)@```*\L`@`J````UBP"`"@````!+0(`(P```"HM`@`R````3BT"`"L`
M``"!+0(`,````*TM`@`F````WBT"`"0````%+@(`)0```"HN`@`N````4"X"
M`"````!_+@(`)P```*`N`@`F````R"X"`#T```#O+@(`)P```"TO`@`K````
M52\"`"@```"!+P(`*@```*HO`@`D````U2\"`!X```#Z+P(`)P```!DP`@`H
M````03`"`#<```!J,`(`+@```*(P`@`)````T3`"`!````#;,`(`&````.PP
M`@`R````!3$"`"4````X,0(`#0```%XQ`@`C````;#$"``\```"0,0(`%@``
M`*`Q`@`*````MS$"``X```#",0(`*@```-$Q`@`(````_#$"``L````%,@(`
M+P```!$R`@`Q````03("`!<```!S,@(`(@```(LR`@`D````KC("``H```#3
M,@(`[````-XR`@`,````RS,"`!8```#8,P(`#````.\S`@`*````_#,"``T`
M```'-`(`'@```!4T`@`2````-#0"`!<```!'-`(`*@```%\T`@`J````BC0"
M``8```"U-`(`4@```+PT`@`:````#S4"`!H````J-0(`!P```$4U`@`$````
M334"``\```!2-0(`%@```&(U`@`(````>34"`$(```""-0(`+0```,4U`@`:
M````\S4"`!,````.-@(`%````"(V`@`T````-S8"`!D```!L-@(`&@```(8V
M`@`6````H38"``<```"X-@(`)````,`V`@`(````Y38"``D```#N-@(`"```
M`/@V`@`7`````3<"``H````9-P(`'````"0W`@`(````03<"`"X```!*-P(`
M!P```'DW`@`C````@3<"``<```"E-P(`%0```*TW`@`'````PS<"``@```#+
M-P(`"0```-0W`@!`````WC<"``<````?.`(`#````"<X`@`3````-#@"``\`
M``!(.`(`"0```%@X`@`(````8C@"``<```!K.`(`$P```',X`@`&````AS@"
M`!H```"..`(`"P```*DX`@`2````M3@"``D```#(.`(`&@```-(X`@`4````
M[3@"``L````".0(`#0````XY`@`@````'#D"``4````].0(`-0```$,Y`@`/
M````>3D"``L```").0(`#0```)4Y`@`#````HSD"`!0```"G.0(`(@```+PY
M`@`+````WSD"``,```#K.0(`"````.\Y`@`,````^#D"``H````%.@(`$```
M`!`Z`@`.````(3H"`!(````P.@(`$P```$,Z`@`1````5SH"`#@```!I.@(`
M(0```*(Z`@`?````Q#H"``D```#D.@(`-````.XZ`@`'````(SL"`!<````K
M.P(`0````$,[`@`3````A#L"`!,```"8.P(`"````*P[`@`$````M3L"``8`
M``"Z.P(`'0```,$[`@`'````WSL"``@```#G.P(`"0```/`[`@`&````^CL"
M``8````!/`(`%0````@\`@`4````'CP"`'@````S/`(`+P```*P\`@`%````
MW#P"`!L```#B/`(`'0```/X\`@`C````'#T"`"<```!`/0(`$@```&@]`@`"
M````>ST"``0```!^/0(`#P```(,]`@`*````DST"``4```">/0(``@```*0]
M`@`-````IST"`$@```"U/0(`%@```/X]`@`A````%3X"`#<````W/@(`*```
M`&\^`@`L````F#X"`%H```#%/@(`%P```"`_`@"#````.#\"`"4```"\/P(`
M.@```.(_`@`V````'4`"`#@```!40`(`*0```(U``@`H````MT`"`"T```#@
M0`(`+`````Y!`@`L````.T$"`"H```!H00(`+@```)-!`@`N````PD$"`#(`
M``#Q00(`)P```"1"`@`R````3$("`!8```!_0@(`#0```)9"`@`.````I$("
M`(8```"S0@(`"0```#I#`@!Q````1$,"`'$```"V0P(`A0```"A$`@`K````
MKD0"`%L```#:1`(`%````#9%`@`6````2T4"`!````!B10(`;P```'-%`@`B
M````XT4"`%X````&1@(`2````&5&`@!(````KD8"`#P```#W1@(`-P```#1'
M`@!*````;$<"`$P```"W1P(`C`````1(`@!,````D4@"`$@```#>2`(`3```
M`"=)`@`\````=$D"`"\```"Q20(`+@```.%)`@`@````$$H"`!X````Q2@(`
M7````%!*`@`3````K4H"``H```#!2@(`!0```,Q*`@`&````TDH"``@```#9
M2@(`!0```.)*`@`6````Z$H"`!4```#_2@(`%P```!5+`@`B````+4L"`!``
M``!02P(`#P```&%+`@`$````<4L"``P```!V2P(`#@```(-+`@`'````DDL"
M``8```":2P(`&0```*%+`@`/````NTL"``8```#+2P(`%0```-)+`@`)````
MZ$L"``P```#R2P(`%````/]+`@`,````%$P"`!@````A3`(`"0```#I,`@`+
M````1$P"`!D```!03`(`!@```&I,`@`%````<4P"``H```!W3`(`"0```(),
M`@`'````C$P"``@```"43`(`!P```)U,`@`-````I4P"`!<```"S3`(``@``
M`,M,`@`$````SDP"``X```#33`(`"````.),`@`9````ZTP"``<````%30(`
M*P````U-`@`&````.4T"``L```!`30(`#0```$Q-`@`/````6DT"`!D```!J
M30(`!0```(1-`@`*````BDT"``<```"530(`"@```)U-`@`3````J$T"`!(`
M``"\30(`!P```,]-`@`&````UTT"`"\```#>30(`,`````Y.`@`)````/TX"
M``H```!)3@(`"P```%1.`@`4````8$X"``4```!U3@(``@```'M.`@`+````
M?DX"``$```!Z`0```````/(#```4`0``HP4``)T$``!E````5`4``$('``!?
M````%`4``#\$````````:P,``,X$``"2`P``O@,``,P!``"G!0```````&T#
M``#L!@``:@```"<#````````+@4``*0!``#I`P````````````"M`@``(0(`
M`!@```!D!P```````'<'````````;@$```````"Q````````````````````
M<@0``-8"````````RP(``#4"```Z`P``808``````````````````"`$````
M```````````````Z!P``@`0``#L%``"^!@``A0<```````"-`P```````-T%
M``#F!0``#`<``+X"``#F`P``*@<``%0&``!7`P```````(8!``"F`@``F0<`
M````````````Z@```-<```#)`P```````*\%``#%!0``<`$``#4%````````
MK`4```\```";`@````$```8'``#&`@``;P$```````!+`0``2@(```````##
M`P```````+$&```N!P``E04``(T````F`@``60,``$X"````````@@4``*8!
M``"E!```B0,``,L$``#L`````P$``(T'```&!```+00```````";!P``````
M`#0%````````@P<``*X%```G!P```````&X'```;!0``Y`4``,H'``#-!0``
M=0```-,!```^`@``.`$```````#5`0````````8`````````EP(``$<"``#]
M`@```P<``*8&````````3@$``&`$``"A`0```@,`````````````"@,`````
M``!6!P``N`````````!?`0````````````"O!P``?P4``%L&````````<P$`
M`%`"````````&`(``($$````````>P<``!X&`````````````*P"``"L`P``
MVP8````````]`P```````,`&``#T`@``EP<``)@#``#_!`````````````!4
M``````````0!``!>`0``(@(``%,&```?````(`<``-`$``"K`@``]`$```\!
M````!0````````0&``#D!@``Q`0``#4!```I`0``"`4``*,'``"4!P``&`0`
M``L"```,`P``.@8``%,````H!@````````<%``!L````/0$```````!4!P``
M,@,```````!\!@``8@,``-\!``#/!```P0<``"4```!(!0```````%L$``!`
M`0``J`4``-8%``!I`````````-(#``"6````&P<``&@``````````````)D&
M````````8P4``%\%``!Q`````````%D$``"\!P``P@<```````#2`0``1@,`
M``````!T!P``H@0``,T&````````00$```````!P!0````````$"````````
M[@4``+($``!S`P``_P```+`&``!P`@``'0```#8!``#\!0``>`<```4%``!2
M`P``^P4``-$'``#5````?@0``+$%``````````````````!:`0```@(``&("
M``!:````'0$``'\"````````0P$``%T!`````````````,<"```T`P``````
M`"L"``!Z`@```````'L%``#E````@0$``+,'```K!P```P8``"L#````````
M``````````!;`````````%H$```4`@``,0,``'('`````````````,<'````
M````-@````````#]````7@8``/X%```)`@``0@```,P%``!+!```?`,``-8$
M```6!0```````-0```!]!````````-@!``#)!```\P8``(P#````````_04`
M``T%``#9`@``!`0``%H#````!@``^`8``-`"``!J!0```````'X"``#4`P``
M`````-,"``!+!0``M0$``'L$``"F`P````(```````"A!```:@0``'T&``!`
M`P``X0$``),"``#=`@``F`$```````!N`P```````+\&`````````````+,"
M`````````````'8'`````````````$H%````````$0```*D'````````,0(`
M`/,"``"J!P```````($#``#*`@``<@8```````"*````R@$`````````````
M`````/($``#7!@``UP0``$0#```=`P``0P(````````'!@``4@8``#8%```H
M`P```````.4$``#$!0``=@,``"D"``!6!@``&@8``/4#``"N`@```````-<"
M``"O!``````````````/!@```````#X#``##`0``F`<``,T```#^!@``````
M`.$```!L!@``G0```,$#``!Q`@``Y@(``$8"``!2`@``?`(``$4```!U`P``
M(`,```````"2`0``\P$``)H!```8!P``?`4````'````````NP$``#\'``"`
M!@`````````````]!0``^`(```````"+`P``H@4``#D#``"T`@``)`8``-X`
M``#W`P```````*4!``!@`0``DP4``$X#```+!`````````````"`!0``$@``
M`%8#``"6!0``508```````!&`0``,00````````%`````````&P!````````
M>`8``*$'``"4````J@(``"$%```/`@``%P,```````!*`P``@04``.(!````
M````/0```$P```!K`@``6@(``,D````D````Z@,``$4#````````2P8`````
M``#Z!0``W`8``````````````````!T%``".!P``H0,``+P$````````````
M``````"_!0````````````"_!P```````'<%``"H````+`0``+@$```7````
M%00``&`&````````L`<``$$#````````.`4``&P'``"0`P``J04``.0!``""
M!P``;P(````````U!```!0(``(<"````````P@(``(0"```O````*@4``*4&
M```[````WP(``!$'``!T`0``L@```+P&`````````````!P&``!8!```"@$`
M`,`$``#K`````````,T#`````````````)H#```_`@``RP````````"Z!P``
MQP8``,L'``"J`0``E0```"4$````````KP````````"4!0``[P```(,!``"U
M!P``*04``-("```4`P````````````#T!@``V00``*0```!L`P``=`,`````
M``#E!@``70(```````""`@``^P8``,L%```+!@``J08````````(````````
M``````!-`````````,`````B!0``?P```/<&``!0!```?@8``.H!``"<!```
M*````"P``````````````'X%``#X!````````+H`````````'0(``$P"``"/
M!0``,P<```````"F````?0,```````#0!P```````"<````S`P```````/X#
M``!Z`````````$,```"E`@```````"X```!,`P``E`8``!$$``""`P``D@<`
M`$(!```U````Z`$``$$"``"<!P``&@$``"(```!R`0``O0,``+4%```O!@``
MVP0```````!S!````````&D'``#/`@``>P8`````````````OP(`````````
M````A`8``$H!````````\04``)X"``"B`0``U@<``"4!``!R!0``!@,`````
M``#G!0```````(0```!U!@``[P4```````!?!@``=@0``!D$````````````
M`%P!``#%`0``<P(````````2`0```````(X#```R!P``&0<``)D#``#Y!```
M/`<``(8'``#_!@``$04``-X!```.`````````"$'````````'P<````````7
M`0``*`<`````````````K00```D'``!O`P``$P```%L"``":!P``````````
M``")```````````````Z`0``[00``#`$``#J!0``408`````````````"P``
M``````"9!````````/H````9!@``\`8``)`"````````B`<````````U`P``
M`````*,"`````````````(4"``!%`0``.04``)<$``!8!P``W0$```````#J
M!````````*L````C````MP8``&4$``"[!```G`(`````````````-````-X&
M``"?!P``#`(``,8```!P`P```````*T'``#1`0``<````'4%````````````
M`%0$````````6P,``#\#``#P!0``MP4``)(````P!0```````(<'``#*`P``
M]00```````"^````B@<````````'!P``X`0````````[`0``$P,``*H$````
M````M@<``,$"``"F!````````&(````-````J@```%(!````````-@,``-P!
M```+`0``TP4``!P'``!3`P```````,\#`````````````!D```#Z`P``*@0`
M`(````"D!P``WP,``/D#```:!P``:`,``+0'``!@`P```````"8!``!>`@``
MG@$``&T"````````7P,``!@#``!D`````````#\%````````6@<``",!``"(
M`P``!`,``+T%```[!@``)`$```````#"`0``Q`$``%`#``"*`P``+0,``/D&
M````````3`8``.X#``!#!0``=00``$$`````````\@```-H```#*````&@4`
M``$!`````````````&<#``"%`0``(P,```````!7!P```````/<%````````
M``````X%``#,`@``^````&4#``!G!P```````/\%``#=`````08```````"/
M!````````)$````[`P``N@8``+X%``!_!@````````D```!A`````````$<&
M````````8P```$T$``````````````<```"L!@``;@```$<$``#P!```H08`
M`$<%``#(!@``G@<``+T$``"Z`0``B````.8!``"4`P``+`,``,@```!W`@``
M``````````!?!`````````````"@!0```````!@!`````````````#D&````
M````F````#L'``"\`@``_`0``!8&```V!@``````````````````DP,``-D%
M``#]!@``104``-$%``!!!``````````````;````#`0``(8&``"[!0``````
M``````#*!0``ZP0```````!/!P````````````#/````;0<``#L"``#N!@``
M$`(```````#%````E@$``*\"``"&!0````````````!E!@``/@4``#X&``#:
M!```Z04````````&!0``[`(``,L#``"]`0``S0<`````````````%08`````
M```'`@``308``(\`````````[0,``*0#``!%`@``_`8`````````````(P4`
M``D$``#[````>0$```````#&!@```````%T```"\`0``````````````````
MTP0```````!&!0``9@```-H"``````````````````#5!@``[P$```H```!Y
M!`````````````"5`0``B0<``)8"```<````\@$``)\"```6`P``%04``-4#
M``#H````$`0```````!R`@``)P0``*T&``!,!0``.0$``)($```^!```4`4`
M`)L`````````+`(``',&```<!```;0$``/X```"@!P``1P```(P!``"+````
M`````!X$``#Z`@``3P0``+P#```W`0``-`$``/<$``"Q!```1@<```````!5
M`0``(08```(%``#S`P``A@,```````!6`0``:`(``)$$``!X`@```````*\!
M``":!0``7@<```````````````````4$``#&!```>@0`````````````Q```
M`'P$``!W!@``>`````````!I!````````&H&``"V!```BP(``#`!```D!P``
M`````*@!``!U`@``[P0```````"M`P```````,$$````````UP4``/@%````
M````-08``)$'```B`P``:@(``)4"``#C!@``60<``,(#````````6P$``"P%
M```+`P```````&L!````````,@0``)P#```P`P`````````````Z````K0``
M````````````4P$```````#/`0``V`4``*T!```7!@``K@```/L#``"K!P``
M`````&0#````````A`4```````#3!@``400``$H&``#6!@``\P4``"@$``"9
M`@``_`````````#\`@```````%$```!,!`````````````"P`@``]P(`````
M``!I!0``.````+<$``!K!0``200```<!``"B!P``<@,``-0'````````.0``
M`,P``````````````!H#``#G````S@<``*,!```7!P``2@<``)\&``"Y`0``
MP`<```P&``#1!```Z00```````"W!P``"0$``'<!```S`0``V0$``+H"```)
M!0``>0,```0'````````6`(````````?!```6P4``&8"``"#`@``T`$``(4#
M``!3!0```````&`"````````G0$````````@!@``A@(``$(%``!-!P``H0(`
M``````#H`@``8P8``,D"``!E!P``DP0``/`!```*!```T0(`````````````
MC00``%D%``!C`P``'@,``-$#````````@P````````"9`0``J00```````!E
M!0``````````````````YP8``-`%````````%0$```````!A!P``Y0,```L%
M```X`@``E@<``#0'``#Q````>P$``)\!````````/08```````!7!@``````
M``````!5`@```````!<$```8!@``PP<``,4&``"/`@```````,P'``#/!P``
MQP$```@#```C!```8@$``!@%``##`@``T@```*\&``!$!0``D0$````````2
M!````````-````"X`0``W@0``*L#````````-P0``-8`````````L@(``*H&
M``#@````^P$````````-`0``E00```````"#`P``,0````T#``#Y`@``8```
M``````"'!````````#4'```T!@```00```````#I`0```````%\"``"E!0``
M,@```(\&``"V`P``.`8``,0"``!N!0``+P0``#8"``#"!````````$8$```F
M!0``_@(``(0!``!M!```F@8``$8&``#1!@``R`$``*X!```H`0``G@,``!$&
M``"\````A`0```````#J!@``@0`````````D`P``'@<```0%````````\0,`
M``````#2!@``N@0``$D#``#)!0```````,P&```G!@```````+P%``!F`0``
M`````$D`````````XP````````"C`````````````````````````-0&``!Y
M````T0``````````````RP$``)D```!:!0``9@4``)T&``#$!P``^0$``-4$
M```E`P```````'0```#A`@```````*P```#V`P``\00``%X%``""!```````
M`#P#```"!P```````*,&``"1!0``304``-`#``!(!P``_@0``#(!````````
M``````````#?!0``R`(``.4%```E!P``9P4``*L!````````'P8`````````
M````P`$``)$#``!I`0``40<``(L&`````````````"H#``#M!@``/`0``$X`
M````````0`(``,@%``!H!P``6`4``.@$````````S@```"`"``!.!0``-P<`
M`"H```#A!0```````"8#```C!P``0````,\%``"[`P```P,``!0$``!(!```
M_0$``(T&``!P!@```````*4`````````Z08```````#D`P``!@$``%P#```*
M!0```````+('``!=`P``+@,``.`&``#"````BP4``"\#``"[!P``W`(``-X"
M```R!@```````$\%``"G``````````````!5!P``Q@,``&0!````````M@4`
M`*X&````````S@$``%<!````````*@(``.H"```]`@``B`8``((!``!B!@``
M`````&<`````````&@0``,@#``#;````/`$```````#:!0``'`(`````````
M````:`0``-,'```1`@``2@0```````#3````2P,``+0#```3!P``````````
M``!(`0``7`````H"```Q!@``D@4```````!1!0``L0$``*X$````````'P4`
M`+(&```3`@``Y`0``"4%`````````````&(%```.`P``GP4`````````````
M`````+,&``!)`0``6````&$#```(!@``W0,``$X'``"V!@``6@8``,4'```N
M`@``TP,```0"``!"`P``]@8``),!``!Z`P``#P<````````-`@```````$,$
M````````>P,``!X"``",!```C@`````````6`@``,`(```````"5`P``[@(`
M`.L"```F`````````/H$``#2!0````````````"^!P``$P0``%@!````````
MZ`8``(P&````````$@<```````!W!```1P<``"@"```:````C@$````````D
M!0``O@$````````^`0``M`8``,4$``````````````````!]````M@$`````
M```[!```'08``/8"```I!```I`0``$D%``!'`P``00<`````````````+@$`
M`*P$``",`@``W@,```````#5`@``J`0``(0'``#B!0``2P<``!(&``#8`@``
M>@4``(<!```K!0``J0(```````"/`0```````*@'``!<!```X`4``$$%````
M````/00``(D"`````````````%(```!T!@``J`8``)8#```F!P``>04``/\"
M```_`0````````````#Q`0``K`<``!`%``"B````]0````````"?````>`,`
M```````;!```FP8``%@&````````^0```/0#``!S`````````&<$````````
M3`$``$0!```V!P``2``````````;`P``\P0``)<&``!I`P``X08``&D&``#<
M!0```````*\#```3!@``@@8``&($``"%````2`,``(H$``#!!0``,P``````
M``"B!@````````($``"R!0``,04``)@%``!(`@``>P```*`!``"*`0``````
M`%$!``#U!0``<`0``'P'````````W08```````"4`@``\08``&4"``"K!0``
M@P4``$("``"C`P``4`8```````!M!0``#P,`````````````208``+H%``#!
M`0```````/@#````````U`(``'@%``!=!```30,```````"=!0``9@8``'8&
M```T!```$@4``*(#``"2`@``&P$``+@"``!N!@``"`<``)\$``"G!P``L`0`
M`!,!``"7!0````````````#*!```R`<```````!V`0````````````"Q`P``
M`````"D&``"G`P``B`(``&,$````````!P,``-P$``"=!P``7`(``$(&``";
M`P``VP4```$#``"<!0``:P0``"H&``"A!0``E@8```````"W`@``R`0```4!
M```9!0``:@,``,<$``"1`@``#@$``%$#``"^!````````'X````+!P``+0(`
M``X'``"P`0```````$D'``!=!@``NP(``*`"````````80$```````!4`P``
M80(``/D%`````````````&\$``#H`P``4@0``!4'``"0!@``'P$``,P$``!D
M!@``AP,``/X!```#!0``G@8``#H$``#U`@``DP<``'@!```K!@````````$%
M``"Y!@`````````````_!@```````)X%````````T@0``$0"``"7`0``L`4`
M`*<$``!P!P``U`$``(`#``!/`P``Q`,``!0```#M````(`4``-<#``!J!P``
M`````!X```"+!P``Z`4```8"``#E`0``^`$``#X```"5!P``'`4``-H!````
M````2@```+0%``".`@``M`0``%('````````B@8``(\#``#8!@``````````
M```^!P``3`<``&8'``"K!@``E`$``&\`````````D@8`````````````'@$`
M`"($``![`@``#`4``&T```#C`0``H@(``&('```0!P```````'P`````````
M`````/0%````````R@8``"\!````````;P<``*X'``!]!P``8P$``(8$``!`
M!0```````````````````````````````````````+0```!$!P```````+\`
M```"!@``[`,```T'``")!0```````-4'````````````````````````:P``
M`(L$``#9`P```````#P%````````L@,``&<&``!%!P``DP8```````!^`P``
M]@$```````"Y`P``PP8````````*!P``DP````4#``#@`0``F@(``&$%```"
M````H`,``'(```"S!```_`,``*`$``!1`@``M0(``+\$````````+0``````
M``!6!0``5P(``',%``#C`@```````````````````````.P!````````````
M``$'````````6P<``.D```"#!@``$`8``$L```#&`0``B`4````````L!@``
M``````````"<!@``S@4```@"``"M!0``&@(``&H!````````OP,``"8$```'
M!```QP```/<!``"!`@``60```$,&```1`P``7`4`````````````5`$`````
M``!-`0```````)`%``"C!`````````````"``0``/P```/P!````````\```
M`!8'```7`@``-`(``"('````````G@```"L$```N!```X@0```````!K!P``
M`````'\!``!9`0``=`4``&0%``!H!0``K@,``&@!``!(!@``QP,```````"]
M!P````````D#````````S00``)H$````````[P8``(L!````````MP```"$`
M```W!0``\`,``'$'`````````````#$'````````,````*@#``"7`P``M@``
M``````!?!P```````,L&``!%!````````(@$````````>@8``*<&```B`0``
M=P,``,8'```/!````````"T%```9`@```````'0$```R!0``I0,````````I
M!P``Y@0``.,#``!D!```M00```T&``#A!````````+\!```P!@```````$\!
M``#/!@```````(`'``#0!@``\@8``,X"```-!```5@0``.`#````````9@0`
M`,D!``#:!@``!````%P'``!V`@```````)@"``#K!0```````,D'````````
M\`(``)X$````````W````.$#`````````P(``.X$`````````````+(!``!D
M`@``M0,``,T"``#T!`````````````#2!P``^@8``$X$``"%!````````#<"
M``!I`@```````!8!``"=`P```````)D%``!L!0``LP$``$$&``!U`0``8P(`
M``4'``!.!@``C@8``'0"``!Y!P```````%D"``"?`P``N0<``#<#``!Q`0``
M4`<```````#"!0```````&`'```?`P``^P0``'<`````````*P$````````Z
M`@``<08``*8%``!Q`P``H0````````#G`@```````(\'``!N`@```````,`%
M``!5````P`(``(0#````````P`,``````````````````-4%``")!```````
M`$,'``"J!0```````)@$``"W`0``6`,``-D&````````AP8``,,`````````
M,P4``"$!````````F@```#@$``"Q`@``4P0``)T"```4!P``[0(```````!$
M````XP0``"4&````````]@4``#P````3!0``Q@4``#$!`````````````)`'
M``#6`P``?P,``/,`````````ZP8``*0&``!V````YP,``+T&``#8````'0<`
M`+4&``#Z`0``H````'$%``!O!@``*`4``````````````````.X```"0````
M-P8```````!6`@``=0<``.\"````````)`0``"T&````````XP4``&4!``#%
M`P``P0```````````````````*`&``#?````5@```/0```"U````O0```,,$
M```2`P``+`$````````<`0```@$``&8#``#M`0``U`4````$``!`!@``$```
M`((```"-`@``3P```*P!```Y!P``5P```$($````````30(```H&````````
M``````\%``!L!```9P$```P!````````N04``.4"``!0`0``%P4```````!=
M!P``ZP,``.P$``!O!0```````/T$``")!@``\0(```X&```N!@``#```````
M``````````````X$``#9````A04``/T#``#?!@``UP$``$`$``"4!```N@,`
M`*D!```@`0``"08````````6!`````````````"X`P``(0,```8&````````
M`````+T"``!<!@``W00``*<"``#L!0```````+D$``"1!@``Z0(``+0!``#D
M`@``%@```(P'`````````````!T$```;`@```````"4"``!>`P``$`$``#`'
M```(`0``E@0``*@"``!5!```WP0``%X`````````EP```+D```!/!@``QP4`
M`*0"```J`0``!08``#,"``!M!@``FP4``(T!```X`P``X`(``","``!V!0``
M20(``"T!``"!!@``@P0```````#$!@```````"````!3!P``5P0``'P!``"E
M!P``G`$``&P"``!S!P``````````````````S@8``'\'``!Q!```U@$``$\"
M```Y`@``P@8````````Y!```L0<``"(&``##!0``W@4``'X!``"-!0``L`,`
M`"0"``!X!```B@(``-@$````````]0$``!$!``"I`P``+0<```````#B`P``
M`````'X'````````Y````+,%``!G`@``JP0``"P'```5`@``2P(``)@&``#4
M!````P```$,#``"*!0```````)L!``!9!@``(00``'H'``#V`````````*8'
M````````\@4`````````````]08``(<```!7!0```````'T!``")`0``1P$`
M```#````````/0<``+@&```0`P``IP$``)`$``#;`P``%`8``)P```"[````
MLP,``%T%```F!@``C````#H%``#<`P```P0``"L```!C!P```````($'``#8
M`P```````'\$````````+P(``+L&``!H!@```````/L"``"D!0``YP0``.(`
M```9`0```````!4#````````50,````````\`@``S0$``"D#```W````````
M````````````>08```````#_`0``C@4````````>!0``ZP$``%````!$!```
MC`4`````````````N`<`````````````+P<``"D```!&`````````+@%````
M````A@```#@'``!@!0``#@(``%(%``#B!@``504``#8$```O!0``)P4``%0"
M``#N`0````````````#_`P``M@(``'T"``#;`0``C@0``&$$``#B`@``]@0`
M````````````N0(`````````````:P8`````````````Q0(``%X$````````
M>0(``(<%````````)P$``#,&```\!@``````````````````0`<``+<#``!3
M`@```````-L"``#F````S@,`````````````D`$``(@!````````(P8``+,`
M````````P08```````"I`````````)L$``#F!@````````````"%!@``'`,`
M`$0&``"``@``?04``-H#`````````````#("``!%!@``E08``/<````G`@``
M[04`````````````$@(````````(!```R08``.<!```;!@```````+``````
M`````````#,$``#,`P``&0,```````#R`@``;@0``!\"```5````J@,``.\#
M````("`M32P@+2UM97-S86=E/4U%4U-!1T4@(%5S92!T:&ES(&-O;6UI="!M
M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE<RX`("`M82P@+2UA
M9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@9FEL92!T;R!T:&4@8V]M<&5N
M9&EU;2X@57-E9G5L('1O"B`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU
M9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F97)E;G0@8G)A;F-H('1O"B`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!G96YE<F%T960@8V]M<&5N9&EU
M;2X`("`M8BP@+2UB87-E/2]0051(("!&=6QL('!A=&@@=&\@=&AE("A(;W)D
M92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U;&0@8F4*("`@("`@("`@("`@
M("`@("`@("!U<V5D+@`@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@365R9V4@
M;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@9FEL90H@("`@
M("`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O
M;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE"B`@("`@("`@("`@("`@("`@("`@
M("`@("!H;W)D92]P;R!D:7)E8W1O<GDN`"`@+6,L("TM8V]M<&5N9&EU;3U&
M24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T:&4@
M9&5F875L=`H@("`@("`@("`@("`@("`@("`@("`@("`@;VYE("AC;VUP96YD
M:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+@`@("UD+"`M+61E
M8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@97AE8W5T
M960@8FEN87)I97,N`"`@+60L("TM9&ER96-T;W)Y/41)4B`@($-R96%T92!C
M;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y+@`@("UH+"`M+6AE;'`@("`@
M("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N`"`@+6PL("TM;&]C86QE/6QL
M7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92X`("`M;"P@+2UL;V-A;&4]
M;&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92X`("`M;"P@+2UL;V-A;&4];&Q?
M0T,@("`@57-E('1H:7,@;&]C86QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-L96%N=7`@4$\@9FEL97,@
M;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO;G,@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-R96%T
M92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E(%!/(&9I;&5S(&]N;'D@9F]R
M('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D
M=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&]N;'D@=&AI
M<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("!'96YE
M<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@
M("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@;65R9V4@;F5W('1R86YS
M;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2X`("`M;BP@+2UN;RUC;VUP96YD
M:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I=6TN`"`@+7,L("TM<W1A=&ES
M=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T871I<W1I8W,@:6X@82!L
M;V-A;"!F:6QE+@`@("UT+"`M+71E<W0@("`@("`@(%-H;W<@=&AE(&5X96-U
M=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@86YY=&AI;F<N`"`@8VQE86YU
M<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U<"!F<F]M('5N=')A;G-L871E
M9"!A;F0@;V)S;VQE=&4@96YT<FEE<RX`("!C;VUM:70@("`@("!#;VUM:70@
M=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R=F5R+@`@(&-O;6UI="UH96QP
M($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#5E,@<V5R=F5R+@`@(&-O;7!E
M;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I=6T@9FEL92X@5V%R;FEN9SH@
M5&AI<R!O=F5R=W)I=&5S('1H90H@("`@("`@("`@("`@(&-U<G)E;G0@8V]M
M<&5N9&EU;2X`("!E>'1R86-T("`@("!'96YE<F%T92!03R!T96UP;&%T92`H
M+G!O="D@9FEL97,N`"`@:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S
M<V%G92X`("!I;FET("`@("`@("!#<F5A=&4@;VYE(&]R(&UO<F4@4$\@9FEL
M97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI<PH@("`@("`@("`@
M("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG(%!/(&9I;&5S(&]F('1H:7,@
M;&]C86QE+@`@(&UA:V4@("`@("`@($)U:6QD(&)I;F%R>2!-3R!F:6QE<R!F
M<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N`"`@;6%K92UH96QP("`@36%R
M:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE;'`@9FEL92!B96EN9R!U<"UT
M;RUD871E(&%N9`H@("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I;&4@9F]R
M('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U"B`@("`@
M("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L<"!!1E1%4B!U<&1A
M=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE"B`@("`@("`@("`@("`@:&5L<"!F
M:6QE+@`@(&UE<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT(%!/(&9I;&4@
M=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T92!F:6QE+@`@('5P9&%T92`@
M("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S97%U96YT+@`@('5P9&%T92UH
M96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E;G1R:65S(&9R;VT@
M=&AE($5N9VQI<V@@6$U,(&AE;'`*("`@("`@("`@("`@("!F:6QE(&%N9"!M
M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG(&]N97,N`"`F(S$U,3L@)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E
M<RD`("A296%D(&]N;'DI`"`H=&]D87DI`"`H>65S=&5R9&%Y*0`@870@`"5D
M("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E9"!O9B`E9"!E;G1R:65S
M(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F;W)E8V%S=``E<R`M($YO
M=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!#;VYF:6=U<F%T:6]N`"5S($9I
M;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!3=&%N9&%R9``E<R!497)M<R!O
M9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S
M(&AA<R!C86YC96QL960@)7,N`"5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B
M=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N
M('1O("5S+@`E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@
M;F]T(&9O=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I<G-T+@`E
M<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@<F5Q
M=65S=',@>6]U<B!P<F5S96YC92!A="`E<RX`)7,@=&\@)7,@;V8@)7,`)7,@
M=VES:&5S('1O(&%D9"!T;R`E<RX`)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W
M87)E(&]F("5S+@`E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN
M9F]R;6%T:6]N(&%B;W5T("5S+@`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A
M;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@
M=6YA8FQE('1O(&QO860@9')I=F5R.B`E<P`G)7,G(&ES(&YO="!A('9A;&ED
M(&-H;VEC92X`)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN`"<E<R<@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"<E<R<@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A9&1E
M9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E
M871E9#H@)7,N`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,`+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\9V5T
M=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RX*3W!E;FEN9R!T86<@
M9F]U;F0@:6X@;&EN92`E9"X`02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E
M9`!!(&YE=R!S:6=N=7`@:&%S(&)E96X@<F5C96EV960@86YD(&ES(&%W86ET
M:6YG('EO=7(@87!P<F]V86PN`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-(%-H;W=E<G,`04TO
M4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O
M;0!!8G-M:61D;&4`06-C97!T(')E<75E<W0`06-C97!T960`06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O
M>F5N+@!!8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"`E<P!!9&0@0VAI;&0@
M1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@
M1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O
M("<E<R<`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1H:7,@
M=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY
M(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`G)7,G('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`E<RX`061D960@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N`$%D9&EN9R!N97<@9FEL97,@=&\@<F5P;W-I=&]R>3H`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E
M<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A
M=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R
M('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA
M=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA
M=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E
M<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO
M80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC
M80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N
M(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I
M;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C
M:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!D96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN
M80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E
M;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T86-H960@:7,@86X@
M:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S96YT`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E;F1E97,`071T<FEB
M=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@
M0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!
M=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO
M;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!!=F%I;&%B;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!!>F5R8F%I
M:F%N`$%Z=7(`0D]&2"!%>&-U<V5S`$)A8VME;F0@;F]T(&-O<G)E8W1L>2!I
M;7!L96UE;G1E9"X`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K
M97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA
M;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"
M87)B861O<P!"87)B:64`0F%R90!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E
M<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I
M;F=S`$)L;V-K(%1Y<&4`0FQO8VL@<V5L96-T:6]N`$)L=64@86YD(%=H:71E
M`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE
M<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W
M86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GD`0G)O=VX`0G)U;F5I($1A<G5S<V%L86T`0G5I
M;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!"=6EL9&EN9R!L;V-A
M;&4@)7,N+BX@`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O
M`$)U<FYT($]R86YG90!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO
M;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A
M;6)O9&EA`$-A;65R;V]N`$-A;6]U9FQA9V4`0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A
M;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE
M("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#
M86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E
M9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,
M86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I
M97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG
M.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R
M86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S
M`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@4&%S<W=O<F0`0VAA
M;F=E('!A<W-W;W)D(&]N.@!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@<&%S<W=O<F0`0VAA;F=I;F<@<&%S
M<W=O<F0@;VX@)7,`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE86YI;F<@=7`@4$\@
M9FEL97,@9F]R(&UO9'5L92`E<RXN+@!#;&5A;FEN9R!U<"!L;V-A;&4@)7,N
M+BX@`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z
M("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O($-O;G1I
M;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#
M;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V5D(&)O<F1E
M<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I
M;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD
M(%-H96QL`$-O;6UA;F0@;W!T:6]N<SH`0V]M;6%N9',Z`$-O;6UE;G0`0V]M
M;6ET=&EN9SH`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!L971E
M9`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#
M;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@;F5E9',@
M=7!D871I;F<N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F9I
M<FT@;F5W('!A<W-W;W)D.@!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N
M(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G1S(&]F("<E
M<R<`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L
M96-T:6]N`$-O<'EI;F<@)7,@=&\@)7,`0V]R;F9L;W=E<@!#;W-T82!2:6-A
M`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R
M`$-O=6QD(&YO="!C86QL(&9U;F-T:6]N("5S(&EN(&%P<&QI8V%T:6]N("5S
M+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M("<E<R<@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<P!#
M;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SH`0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E
M=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S)RX`0V]U;&0@;F]T(&UK9&ER
M("<E<R<N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B`G
M)7,G(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RX`
M0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N`$-O=6QD(&YO="!R
M96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@
M<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T
M(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@)R5S
M)RX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N("5S+@!#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@)R5S)RX`0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@)R5S)SH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@
M9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F
M;VQD97(@)R5S)SH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#
M<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S
M=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!0:&%S90!#=7)R96YT(%1I;64`
M0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET
M:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I
M;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI
M8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`
M1&%T80!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E
M('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA
M;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN9&5N=`!$969A=6QT($-O
M;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!097)M:7-S:6]N<P!$969A
M=6QT('!E<FUI<W-I;VYS`$1E9FEN:71I;VYS`$1E;&5G871E('!O<VET:6]N
M`$1E;&5G871E9`!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S
M:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L
M971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)P!$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R
M;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!P
M97)M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&5D('-E
M='5P('5P9W)A9&4@<V-R:7!T("<E<R<N`$1E;&EV97)Y('1I;64`1&5N;6%R
M:P!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF
M;W)M871I;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N
M=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I
M;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P
M;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O
M<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T
M(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!2
M97!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES
M=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D
M:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@)7,`161I="!P97)M:7-S:6]N<R!F;W(@)R5S)P!%
M9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G
M92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD`$5N9"!Y
M96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@
M=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT<FEE<SH@)60@
M=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@
M=6YK;F]W;@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R
M('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N`$5R<F]R('-E;F1I;F<@<F5P
M;'DZ("5S+@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I
M;F<@)R5S)RX`17)R;W(Z(`!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O
M<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@
M<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L
M9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%
M>&5C=71I;F<Z`$5X<&%N9`!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W
M;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP
M;VYE;G0`17AT<F%C=&EN9R!F<F]M("5S+BXN(`!&1R!#;VQO<@!&5%`@=7!L
M;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B
M+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE
M=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A
M:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,Z("5S`$9A:7(`1F%L
M:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@
M17)R;W(A`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&
M97<@4VAO=V5R<P!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C
M=&]R:65S.@!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N
M`$9R964O0G5S>2!);F9O<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"
M=7-Y(%)E<75E<W0`1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H
M($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@
M36]O;@!&=6QL($YA;64`1G5Z>GD`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R
M871I;VX`1V5N97)A=&5D($-O9&4`1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO
M9'5L92`E<RXN+@!'96]R9VEA`$=E<FUA;GD`1V5T;W!T($5R<F]R.B``1VAA
M;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R
M8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96X`
M1W)E96YL86YD`$=R96YA9&$`1W)E>0!'<F]U<"!!9&UI;FES=')A=&EO;@!'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<"!P97)M:7-S:6]N
M<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'
M=65S="!097)M:7-S:6]N<P!'=65S="!397)V:6-E<P!'=65S="!P97)M:7-S
M:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A(
M`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A
M8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S
M:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O
M;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L
M<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5L<&5R(&%P<&QI8V%T:6]N
M('1O(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@
M2&]R9&4*9G)A;65W;W)K(&%N9"!I=',@87!P;&EC871I;VYS+@I&;W(@86X@
M:6YT<F]D=6-T:6]N(')E860@=&AE(&9I;&4@4D5!1$U%(&EN('1H:7,@9&ER
M96-T;W)Y+@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T
M:&4@9FEL93H`2&EG:`!(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO
M;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<F1E('1R86YS;&%T:6]N(&=E;F5R871O<@!(;W)D92]+;VQA
M8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E
M("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY('-Y;F-H
M<F]N:7-E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@
M;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK
M;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A
M9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A
M<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_
M`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED
M:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X
M(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D
M9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD
M;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O
M;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM
M86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P
M;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T
M97(`26YC;W)R96-T(%!A<W-W;W)D`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A
M;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);FET:6%L:7II
M;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E
M9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@
M9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A
M<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED
M(')E8VEP:65N=#H@)R5S)P!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED
M('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT
M;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES
M;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A
M;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/
M+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S
M=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y
M(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W
M8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`
M2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;VQA8@!+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L
M:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO
M=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`
M3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G
M:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V
M97(`3&%T=FEA`$QA=F5N9&5R`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU
M97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE
M8VAT96YS=&5I;@!,:6=H="!";'5E`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I
M;@!,:6=H="!286EN("\@5VEN9`!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A
M:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU
M;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI
M;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@
M0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A
M=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C
M:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,
M:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<@;&EB
M<F%R:65S+BXN`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@
M5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G
M(&]U="!O9B`E<P!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C
M875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN
M8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO9V]U=`!,;VYG('1E>'0`3&]V
M90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S
M`$QO=V5R(')O;6%N(&YU;6)E<G,`3&]Y;VQA`$QO>6]L82!";'5E`$QU>&5M
M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L
M878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M
M:6X`36%K92!L:6Y?:RXN+@!-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2
M(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA:VEN9R!D
M:7)E8W1O<GD@)7,`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L
M=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@
M;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@
M=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C
M:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET
M:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H
M86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET
M86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO
M='1E`$UE9&EC:6YE`$UE971I;F<@0V%N8V5L;&%T:6]N`$UE971I;F<@26YF
M;W)M871I;VX`365E=&EN9R!0<F]P;W-A;`!-965T:6YG(%)E<&QY`$UE971I
M;F<@57!D871E`$UE971I;F<@57!D871E(%)E<75E<W0`365M8F5R<P!-96YU
M(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<F=I;F<@86QL("5S+G!O(&9I;&5S('1O
M('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG(&QO8V%L92`E<RXN+B``365R
M9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@
M`$UE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO9'5L92`E<RXN+@!-97-S86=E
M`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R
M)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E
M(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$UE=&AO9`!-971H;V0@)R5S)R!I<R!N;W0@9&5F:6YE9`!-971R:6,`
M365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE
M`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@
M;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-
M:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E
M<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A
M=&4`36]D:69Y(%523`!-;V1U;&4`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI
M8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-
M;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`36]S=&QY($-L96%R`$UO
M<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`
M36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ
M=64`36]Z:6QL80!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP
M;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,
M87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA
M`$YA=7)U`$YE6%0`3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE
M=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E
M($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T
M<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R
M`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R
M;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9#H`3F5W
M('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(%!A
M9V4`3F5X="!0:&%S90!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP
M;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@
M=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]M;6%N9"!S<&5C
M:69I960N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@
M;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&5N=')Y('=I=&@@
M=&AE(&ED("<E<R<@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N
M`$YO(&9I;&4@=7!L;V%D960`3F\@;&]C86QE('-P96-I9FEE9"X`3F\@;&]C
M871I;VX@:7,@<V5T+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P
M96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O
M<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3$1!4"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO(')U;&5S`$YO('-I9&5S`$YO('-U8V@@8F%C:V5N9"`G)7,G(&9O
M=6YD+@!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!087)T:6-I<&%N
M=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R
M;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E
M`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T
M('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M`$YO=&EC90!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`
M3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`
M3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]B:F5C="!C<F5A=&]R('!E<FUI
M<W-I;VYS`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L
M9"!P87-S=V]R9#H`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H
M87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN
M9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA;"!087)T:6-I<&%N
M=`!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]P=&EO;G,Z`$]R9&5R960@3&ES
M=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG
M`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R
M;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0
M(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D
M90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%0M4W1O
M<FUS`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I
M;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=D(&ES(&YO="!P<F]P
M97)L>2!C;VYF:6=U<F5D+@!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D(&]N
M("5S+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@;6]D=6QE(&ES(&YO
M="!P<F]P97)L>2!C;VYF:6=U<F5D`%!A<W-W;W)D(&UO9'5L92!I<R!N;W0@
M<')O<&5R;'D@8V]N9FEG=7)E9"X`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N
M=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A
M=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@)R5S)R!N;W0@9&5L971E9"X`4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R;6ES<VEO;G,@9F]R`%!E<G-O
M;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0
M:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@
M82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@
M<F5P;W)T(&%N>2!B=6=S('1O(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!0;&5A
M<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N
M('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E
M('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`
M4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*0!0;W-T;G5K90!0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D
M('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<V5N=&%T:6]N<P!0
M<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R
M979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I
M;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV
M871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`
M4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H
M)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN("\@4VYO=P!286EN
M("\@4VYO=R!3:&]W97)S`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO
M=V5R`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E
M<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E
M;6%R:W,`4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M
M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!2
M96UO=F4@9F]R;6%T=&EN9P!296UO=F4@9G)O;2!M>2!C86QE;F1A<@!296UO
M=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297!L>2!396YT+@!297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G
M90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P
M;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L
M>3H@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B``4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN("5S
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D<FEV97)S)R!I<R!M
M:7-C;VYF:6=U<F5D(&EN($-O;7!O<VET92!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!087-S=V0@4U%,(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D
M(&EN(%-13"!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!087)T:6-I<&%N=`!2
M97-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L
M=',`4F5S=6QT<R`H:6YC;'5D:6YG($AO<F1E*3H`4F5S=6QT<SH`4F5T=7)N
M('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D
M97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N
M:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R
M;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N
M`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%
M($5N8W)Y<'1E9"!-97-S86=E`%,O34E-12!3:6=N960O16YC<GEP=&5D($1A
M=&$`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@
M365S<V%G:6YG`%-13"!3:&5L;`!34P!34T@`4U5#0T534P!37U%,(%-H96QL
M`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@
M3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`
M4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R
M;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@)7,`4V%V92`G)7,G`%-A
M=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`G)7,G+@!38VEE;F-E`%-E87)C:`!396%R8V@@16YG
M:6YE<P!396%R8VAI;F<@2&]R9&4@87!P;&EC871I;VYS(&EN("5S`%-E87)C
M:&EN9R!G971T97AT(&)I;F%R:65S+BXN`%-E;&5C="!&:6QE<P!396QE8W0@
M82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N
M97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.@!396YD($QA=&5S="!);F9O<FUA=&EO;@!396YD(%!R
M;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I
M;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P('5P9W)A9&4@<V-R
M:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET
M:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3
M=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S("\@
M5VEN9`!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:')I;FL`4VAR:6YK
M(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y
M(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VX@=7`@:68@;F]T(')E
M9VES=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEM<&QE
M>`!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-K:7!P960N+BX`
M4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E
M<G,`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S
M("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`
M4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T
M:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T
M:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`
M4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C
M97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E
M8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`
M4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K
M`%-T87)T`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T
M871U<R!F;W(@;&]C86QE("5S+BXN(`!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B
M:F5C="!0=6)L:6,@2V5Y($EN9F\`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C
M<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@)R5S
M)R!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("<E<R<N
M`%-U8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O
M('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VX@)7,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BX`4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6-C97-S9G5L
M;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z
M97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R
M86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!4
M86)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5A;`!496QE<&AO;F4@
M3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E
M<F%T=7)E.B``5&5M<&QA=&4@)R5S)R!N;W0@9F]U;F0N`%1E;7!L871E($%D
M;6EN:7-T<F%T:6]N`%1E;G1A=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A
M=&EV96QY($%C8V5P=&5D`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X
M='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R
M('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H96QP(&9I;&4@9F]R("5S(&1O
M97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N`%1H92`E<R!L
M:6YK('1O("5S(&AA<R!B965N(')E;6]V960N`%1H92!&5%`@97AT96YS:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC
M93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A
M=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N
M<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE
M(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI
M9`!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H
M92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES
M(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D
M:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC
M<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T
M:6]N+@!4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U<B!C86QE;F1A
M<BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N`%1H92!H96QP(&9I;&4@)7,@9&ED;B=T('-T87)T
M('=I=&@@/#]X;6P`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QI;FL@:&%S(&)E96X@
M<F5M;W9E9`!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E
M;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD
M('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T
M;R!Y;W5R('1A<VML:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@
M8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@=V5A=&AE<BYC
M;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&]P=&EO
M;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@
M9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E(&1O97-N
M)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RX`5&AE<F4@=V%S(&$@
M<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+B`E<RX`5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@)R5S
M)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V
M:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R`G)7,G.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I
M<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL
M92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L
M86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@
M<&%R<V5R+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E
M8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!U;FMN;W=N(&5R
M<F]R('9E<FEF>6EN9R!T:&ES(&UE<W-A9V4N`%1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@86-T:6]N
M(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP
M;&5M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E
M<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM
M86YD(&QI;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N
M9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD
M;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N
M9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I
M;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP
M*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC
M:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4
M;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&5D
M`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L
M<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R
M:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP
M92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R
M('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K
M<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RX`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S
M+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R
M86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I
M(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E
M<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D
M`%5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&
M+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E
M9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@
M240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N
M:VYO=VX@8V]M;6%N9#H@)7,`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R
M9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+
M('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H
M('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H
M92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO
M;@!5;G1R86YS;&%T960`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N
M9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`G)7,G+@!5<&1A=&EN
M9R`E<R!H96QP(&9I;&4@9F]R("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D
M+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M
M86X@;G5M8F5R<P!5<G5G=6%Y`%5S86=E.@!5<V4@0W5R<F5N=#H@)7,`57-E
M($1E9F%U;'0@5F%L=64`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P
M=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S
M(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!N;W0@9F]U;F0`
M57-E<B!N;W0@9F]U;F0N`%5S97(@<&5R;6ES<VEO;G,`57-E<FYA;64`57-E
M<FYA;64@)R5S)R!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE
M.B``57-E<G,`57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T
M97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N
M=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M
M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E
M<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L
M('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M
M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M90!6:65W(&%S("5S`%9I97<@979E;G0`5FEE=R!T87-K`%9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`
M5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V%R;FEN9SH@`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E
M8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H
M('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED
M=&@Z`%=I:VD`5VEN9`!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z
M(`!7:7-D;VT`5VES:&QI<W1S`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO
M;F4`5W)I=&EN9R!N;W0@<&]S<VEB;&4N(%EO=2!C86X@96ET:&5R('5S92!T
M:&4@879A:6QA8FQE('5P9W)A9&4@<V-R:7!T(&]R(&-O<'D@;6%N=6%L;'D@
M=&AE(&-O9&4@8F5L;W<@=&\@)7,N`%=R:71I;F<@=7!D871E9"!H96QP(&9I
M;&4@=&\@)7,N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S
M(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!9
M97,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@
M87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&%P<')O=F4@=&AI<R!S
M:6=N=7`@870@)7,`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A;B=T(&-H86YG92!P87-S=V]R
M9"!F;W(@=7-E<B`E<P!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@
M)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@
M9VEV92!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0`66]U(&UU<W0@9VEV92!Y;W5R
M(&YE=R!P87-S=V]R9`!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W
M('!A<W-W;W)D`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A
M9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/<'1I;VX@*R!0
M('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&=E='1E>'0@=F5R
M<VEO;B!I<R!T;V\@;VQD(&%N9"!D;V5S(&YO="!S=7!P;W)T(%!(4"!N871I
M=F5L>2X*3F]T(&%L;"!S=')I;F=S('=I;&P@8F4@97AT<F%C=&5D+@!9;W5R
M(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;F5W('!A<W-W;W)D
M(&ES('1O;R!L;VYG.R!P87-S=V]R9',@;6%Y(&YO="!B92!M;W)E('1H86X@
M)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@
M<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H86YG960A`%EO=7(@;F5W('!A<W-W
M;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,N($YO="!C:&%N9V5D(0!9;W5R
M(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@
M;&]N9R$`66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F97)E;G0@9G)O
M;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0`66]U<B!N97<@<&%S<W=O<F0@;75S
M="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA<F%C=&5R<RX`
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L
M<&AA;G5M97)I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T
M(&-O;G1A:6X@870@;&5A<W0@)60@9&EF9F5R96YT('1Y<&5S(&]F(&-H87)A
M8W1E<G,N(%1H92!T>7!E<R!A<F4Z(&QO=V5R+"!U<'!E<BP@;G5M97)I8RP@
M86YD('-Y;6)O;',N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A
M="!L96%S="`E9"!L;W=E<F-A<V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&YU;65R:6,@8VAA<F%C
M=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T
M("5D('5P<&5R8V%S92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@;&5S<R!T:&%N("5D('=H:71E<W!A8V4@8VAA<F%C=&5R
M<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!N;W0@8V]N=&%I;B!W:&ET97-P
M86-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D<R!D:61N)W0@;6%T
M8V@`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M('!A<W-W;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA
M:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`
M6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U
M;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI
M<W1R871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?
M2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-
M;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,
M:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D
M<F5S<R!B;V]K`&%N(&5R<F]R(&AA<R!O8V-U<F5D.@!C86QE;F1A<@!C86QM
M`&-L:6-K(&AE<F4`9&]N90!F86EL960`9F%L;&EN9P!F:6QE`&9O=6YD.B``
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I,3AN`&EM;65D:6%T90!I
M;FQI;F4`;&1A<%]S=&%R=%]T;',@9F%I;&5D`&QI;F5S70!M:VES;V9S(&5R
M<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M90!N;W0@8VAA;F=E
M9`!N;W0@9F]U;F0`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT
M960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E
M;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W1E861Y`'1A<VL@;&ES=`!T:&4@
M2&]R9&4@4$\@9FEL92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES
M=#H`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5N;F%M960`=7!D871E9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R
M+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(%!A<W-W9"`S+C`M8W9S"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`T+3`V+3(R(#$X.C,P*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-"TP-BTR,B`Q.#HS,"LP,C`P"DQA<W0M5')A;G-L871O<CH@
M36%N=65L(%`N($%Y86QA(#QM87EA;&%`=6YE>"YE<SX*3&%N9W5A9V4M5&5A
M;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP
M;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3L*`"`@+4TL("TM;65S<V%G93U-
M14Y304I%("!5=&EL:7IA(&5S=&4@;65N<V%J92!D92!A8W1U86QI>F%C:?-N
M(&5N(&QU9V%R(&1E;`H@("`@("`@("`@("`@("`@("`@("`@("`@;65N<V%J
M92!P;W(@;VUI<VGS;BX`("`M82P@+2UA9&0]05)#2$E63R`@("`@0?%A9&4@
M97-T92!A<F-H:79O(%!/(&%L(&-O;7!E;F1I;RX@VG1I;"!P87)A"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EN8VQU:7(@=6X@8V]M<&5N9&EO(&1E('5N
M82!R86UA(&1I<W1I;G1A(&%L"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;7!E;F1I;R!G96YE<F%D;RX`("`M8BP@+2UB87-E/2]6S4$@("!6[6$@9&4@
M86-C97-O(&-O;7!L971A(&%L(&1I<F5C=&]R:6\@8F%S92!D92!(;W)D92!Q
M=64*("`@("`@("`@("`@("`@("`@("!D96)E<NUA('5T:6QI>F%R<V4N`"`@
M+6,L("TM8V]M<&5N9&EU;3U!4D-(259/($EN8V]R<&]R82!L87,@=')A9'5C
M8VEO;F5S(&YU979A<R!A(&5S=&4@87)C:&EV;PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("!D92!C;VUP96YD:6\@96X@=F5Z(&1E(&%L(&%R8VAI=F\@
M<&]R(&]M:7-I\VX*("`@("`@("`@("`@("`@("`@("`@("`@("`@*&-O;7!E
M;F1I=6TN<&\@96X@96P@9&ER96-T;W)I;R!H;W)D92]P;RDN`"`@+6,L("TM
M8V]M<&5N9&EU;3U!4D-(259/(%5T:6QI>F$@97-T92!A<F-H:79O(&1E(&-O
M;7!E;F1I;R!E;B!V97H@9&5L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R8VAI=F\@<&]R(&]M:7-I\VX@*&-O;7!E;F1I=6TN<&\@96X@96P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9&ER96-T;W)I;R!H;W)D92]P;RDN
M`"`@+60L("TM9&5B=6<@("`@("`@375E<W1R82!L;W,@;65N<V%J97,@9&4@
M97)R;W(@9&4@;&]S(&)I;F%R:6]S(&5J96-U=&%D;W,N`"`@+60L("TM9&ER
M96-T;W)Y/41)4B`@($-R96$@96P@8V]M<&5N9&EO(&5N(&5S=&4@9&ER96-T
M;W)I;RX`("`M:"P@+2UH96QP("`@("`@("!-=65S=')A(&5S=&4@;65N<V%J
M92!D92!A>75D82X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S82!S\VQO
M(&5S=&4@:61I;VUA+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-A(&5S
M=&4@:61I;VUA+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V$@97-T92!I
M9&EO;6$N`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#;VYS=')U>64@87)C
M:&EV;W,@34\@<_-L;R!D92!E<W1E(&WS9'5L;R!D92!(;W)D92X`("`M;2P@
M+2UM;V1U;&4]3=-$54Q/("`@(%-A;F5A(&%R8VAI=F]S(%!/('/S;&\@9&4@
M97-T92!M\V1U;&\@9&4@2&]R9&4N`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@
M($%C='5A;&EZ82!T<F%D=6-C:6]N97,@<_-L;R!D92!E<W1E(&WS9'5L;R!D
M92!(;W)D92X`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-R96$@=6X@87)C
M:&EV;R!03R!S\VQO(&1E(&5S=&4@;?-D=6QO(&1E($AO<F1E+@`@("UM+"`M
M+6UO9'5L93U-TT153$\@("`@0V]M8FEN82!A<F-H:79O<R!03R!S\VQO(&1E
M(&5S=&4@;?-D=6QO(&1E($AO<F1E+@`@("UM+"`M+6UO9'5L93U-TT153$\@
M("`@06-T=6%L:7IA(&%R8VAI=F]S(&1E(&%Y=61A('/S;&\@9&4@97-T92!M
M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@(&1E($AO<F1E+@`@("UM
M+"`M+6UO9'5L93U-TT153$\@("`@06-T=6%L:7IA('/S;&\@97-T92!M\V1U
M;&\@9&4@2&]R9&4N`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@1V5N97)A(&5L
M(&%R8VAI=F\@4$]4('/S;&\@9&4@97-T92!M\V1U;&\@9&4@2&]R9&4N`"`@
M+6XL("TM;F\M8V]M<&5N9&EU;2`@("!.;R!C;VUB:6YA(&QA<R!T<F%D=6-C
M:6]N97,@;G5E=F%S(&5N(&5L(&-O;7!E;F1I;RX`("`M;BP@+2UN;RUC;VUP
M96YD:75M("`@($YO('5T:6QI>F$@=6X@8V]M<&5N9&EO+@`@("US+"`M+7-T
M871I<W1I8W,@("`@("`@1W5A<F1A(&QA<R!E<W1A9.US=&EC87,@9&4@;&$@
M=')A9'5C8VGS;B!E;B!U;@H@("`@("`@("`@("`@("`@("`@("`@("`@87)C
M:&EV;R!L;V-A;"X`("`M="P@+2UT97-T("`@("`@("!-=65S=')A(&QO<R!C
M;VUA;F1O<R!S:6X@96IE8W5T87(@;F%D82X`("!C;&5A;G5P("`@("!386YE
M82!L;W,@87)C:&EV;W,@4$\@9&4@96YT<F%D87,@;V)S;VQE=&%S(&\@<VEN
M('1R861U8V-I\VXN`"`@8V]M;6ET("`@("`@06-T=6%L:7IA(&QA<R!T<F%D
M=6-C:6]N97,@96X@96P@<V5R=FED;W(@0U93+@`@(&-O;6UI="UH96QP($%C
M='5A;&EZ82!L;W,@87)C:&EV;W,@9&4@87EU9&$@96X@96P@<V5R=FED;W(@
M0U93+@`@(&-O;7!E;F1I=6T@(%)E8V]N<W1R=7EE(&5L(&%R8VAI=F\@9&4@
M8V]M<&5N9&EO+B!!9'9E<G1E;F-I83H@R7-T;PH@("`@("`@("`@("`@('-O
M8G)E97-C<FEB92!E;"!C;VUP96YD:6\@86-T=6%L+@`@(&5X=')A8W0@("`@
M($=E;F5R82!A<F-H:79O<R!03R!D92!P;&%N=&EL;&$@*"YP;W0I+@`@(&AE
M;'`@("`@("`@($UU97-T<F$@97-T92!M96YS86IE(&1E(&%Y=61A+@`@(&EN
M:70@("`@("`@($-R96$@=6YO(&\@;>%S(&%R8VAI=F]S(%!/('!A<F$@=6X@
M;G5E=F\@:61I;VUA+B!!9'9E<G1E;F-I83H*("`@("`@("`@("`@("#)<W1O
M('-O8G)E97-C<FEB92!L;W,@87)C:&EV;W,@4$\@97AI<W1E;G1E<R!D92!E
M<V4@:61I;VUA+@`@(&UA:V4@("`@("`@($-O;G-T<G5Y92!L;W,@87)C:&EV
M;R!-3R!B:6YA<FEO<R!A('!A<G1I<B!D92!L;W,@87)C:&EV;W,@4$\*("`@
M("`@("`@("`@("!E<W!E8VEF:6-A9&]S+@`@(&UA:V4M:&5L<"`@(%-E\6%L
M82!T;V1A<R!L87,@96YT<F%D87,@9&5L(&%R8VAI=F\@9&4@87EU9&$@6$U,
M(&-O;6\*("`@("`@("`@("`@("!A8W1U86QI>F%D87,@>2!P<F5P87)A(&5L
M(&%R8VAI=F\@<&%R82!L82!P<O-X:6UA(&5J96-U8VGS;@H@("`@("`@("`@
M("`@(&1E('5P9&%T92UH96QP+B!3\VQO(&1E8F5R[6$@96IE8W5T87(@;6%K
M92UH96QP(%1205,*("`@("`@("`@("`@("!U<&1A=&4M:&5L<"!Y(&AA8F5R
M(')E=FES861O(&5L(&%R8VAI=F\@9&4@87EU9&$N`"`@;65R9V4@("`@("`@
M0V]M8FEN82!E;"!A<F-H:79O(%!/(&%C='5A;"!C;VX@96P@87)C:&EV;R!D
M92!P;&%N=&EL;&$@4$\N`"`@=7!D871E("`@("`@16IE8W5T82!E>'1R86-T
M('D@;65R9V4@96X@<V5C=65N8VEA+@`@('5P9&%T92UH96QP($5X=')A92!T
M;V1A<R!L87,@96YT<F%D87,@;G5E=F%S(&\@;6]D:69I8V%D87,@9&5L(&%R
M8VAI=F\@9&4*("`@("`@("`@("`@("!A>75D82!834P@26YG;.ES('D@;&%S
M(&-O;6)I;F$@8V]N(&QA<R!E>&ES=&5N=&5S+@`@)B,Q-3$[("5S('9A(&$@
M969E8W1U87(@;&%S(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\@:6YD
M:6-A9&%S(&$@8V]N=&EN=6%C:?-N+@`@*&AA8V4@)7,@9.UA<RD`("A!8V-E
M9&EE;F1O(&$@)7,I`"`H4_-L;R!L96-T=7)A*2D`("AH;WDI`"`H87EE<BD`
M96X@`"5D("5S('D@)7,`17-C<FET;W,@)60@8GET97,N`$UA<F-A9&%S(&-O
M;6\@86-T=6%L:7IA9&%S("5D(&1E("5D(&5N=')A9&%S`"5D('!R;V[S<W1I
M8V]S(&1I87)I;W,`)7,@+2!!=FES;P!!9&UI;FES=')A9&]R(&1E("5S`$-O
M;F9I9W5R86-I\VX@9&4@)7,`2'5E;&QA(&1I9VET86P@9&4@)7,`)7,@2T(`
M)7,@;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;R`M($-O;F9I<FUA8VGS
M;@!&:7)M82!D92`E<P!%<W3A;F1A<B!D92`E<P!!8W5E<F1O<R!D92!L:6-E
M;F-I82!D92`E<P!982!E>&ES=&4@)7,N`"5S(&$@;&%S("5S("5S`"5S(&AA
M(&-A;F-E;&%D;R`E<RX`)7,@:&$@<F5S<&]N9&ED;R!A('5N82!C;VYS=6QT
M82!D92!T:65M<&\@9&ES<&]N:6)L92X`)7,@:&$@<F5S<&]N9&ED;R!A(&QA
M(&EN=FET86-I\VX@<&%R82`E<RX`)7,@;&4@:&$@:6YF;W)M861O('-O8G)E
M('-U('1I96UP;R!D:7-P;VYI8FQE+@!(86-E(&9A;'1A("5S`"5S(&UI;G5T
M;W,`3F\@<V4@:&$@96YC;VYT<F%D;R`E<RX`3F\@<V4@:&$@96YC;VYT<F%D
M;R`E<RX@16IE8W5T92!P<FEM97)O("=T<F%N<VQA=&EO;B!E>'1R86-T)RX`
M)7,@9&5S96$@8V]N;V-E<B!S=2!T:65M<&\@9&ES<&]N:6)L92X`)7,@<V]L
M:6-I=&$@<W4@87-I<W1E;F-I82!A("5S+@`E<R!A;"`E<R!D92`E<P`E<R!D
M97-E82!A\6%D:7)S92!A("5S+@`E<R!D97-E82!P;VYE<FQE(&%L('1A;G1O
M('-O8G)E("5S+@`E<R!D97-E82!R96-I8FER(&EN9F]R;6%C:?-N(&%C='5A
M;&EZ861A('-O8G)E("5S+@!$:7)E8V-I;VYE<R!D92`E<P!!9V5N9&$@9&4@
M)7,`3&EB<F5T82!D92!N;W1A<R!D92`E<P!487)E87,@9&4@)7,`)7,Z("5S
M`"5S.B!N;R!S92!P=65D92!C87)G87(@96P@8V]N=')O;&%D;W(Z("5S`"<E
M<R<@;F\@97,@=6YA(&5L96-C:?-N(';A;&ED82X`3F\@<V4@:&$@8V]N9FEG
M=7)A9&\@)R5S)R!E;B!E;"!R96=I<W1R;R!D92!(;W)D92X`3F\@<V4@96YC
M;VYT<O,@96P@9V5N97)A9&]R(&1E(.%R8F]L97,@9&4@)R5S)RX`4V4@:&$@
M8?%A9&ED;R`G)7,G(&%L('-I<W1E;6$@9&4@9W)U<&]S+@!392!H82!A\6%D
M:61O("<E<R<@86P@<VES=&5M82!D92!P<FEV:6QE9VEO<RX`3F\@<V4@:&$@
M8W)E861O("<E<R<Z("5S+@`L('9E;G1O<V\@)7,@)7,`+"!V87)I86)L92!D
M92`E<R!A("5S`"TM('-E;&5C8VEO;F%R("TM`"TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0!&;W)M871O(&1E(#$R(&AO<F%S`$9O<FUA=&\@9&4@,C0@
M:&]R87,`,C0@:&]R87,`171I<75E=&$@/&=E='1E>'0^('-I;B!C97)R87(@
M96X@96P@87)C:&EV;R`E<RX*4V4@:&$@96YC;VYT<F%D;R!U;F$@971I<75E
M=&$@9&4@87!E<G1U<F$@96X@;&$@;.UN96$@)60N`%!A<F$@97-T92!B;&]Q
M=64@:&%C92!F86QT82!U;B!M;W1O<B!D92!B87-E(&1E(&1A=&]S+@!392!H
M82!P<F]D=6-I9&\@=6X@97)R;W(@:7)R97!A<F%B;&4`4V4@:&$@<F5C:6)I
M9&\@=6YA('-O;&EC:71U9"!D92!A;'1A('%U92!E<W!E<F$@<W4@8V]N9FER
M;6%C:?-N+@!(86-E(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82!P87)A
M(&-I9G)A<B!U;B!M96YS86IE+@!(86-E(&9A;'1A('5N82!C;&%V92!01U`@
M</IB;&EC82!P87)A(&-O;7!R;V)A<B!U;B!M96YS86IE(&9I<FUA9&\N`$AA
M8V5N(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'
M4"!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9&5S8VEF<F%R('5N
M(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82P@
M=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@
M9FER;6%R('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V92!3+TU)
M344@</IB;&EC82P@=6YA(&-L879E(%,O34E-12!P<FEV861A('D@=6YA(&9R
M87-E(&-L879E('!A<F$@9&5S8VEF<F%R('5N(&UE;G-A:F4N`$AA8V5N(&9A
M;'1A('5N82!C;&%V92!3+TU)344@</IB;&EC82P@=6YA(&-L879E(%,O34E-
M12!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9FER;6%R('5N(&UE
M;G-A:F4N`$AA8V4@9F%L=&$@=6YA(&-L879E(%--24U%('#Z8FQI8V$@<&%R
M82!C:69R87(@=6X@;65N<V%J92X`06=U86-E<F]S(&UA=&EN86QE<P!!32]0
M30!)1"!D92!!4$D`06-E<F-A(&1E;"!E9&ET;W(`06-E<F-A(&1E+BXN`$EN
M9F5R:6]R($%B<RX`16X@;65D:6\@06)S+@!!8V5P=&%R('!E=&EC:?-N`$%C
M97!T861A`%-E(&AA(&1E;F5G861O(&5L(&%C8V5S;R!A;"!C<F5A<B!E;"!D
M:7)E8W1O<FEO(%9&4RX`4V4@:&$@9&5N96=A9&\@96P@86-C97-O(&%L(&-R
M96%R(&5L(&%R8VAI=F\@5D93+@!#;VYT<F%S9?%A(&1E(&%C8V5S;P!)9&5N
M=&ED860@8FQO<75E861A+@!#;VYT86)I;&ED860`06-C:6]N97,`0?%A9&ER
M`$'Q861I<B`E<P!!\6%D:7(@9W)U<&\@9&5S8V5N9&EE;G1E`$'Q861I<B!P
M<FEV:6QE9VEO(&1E<V-E;F1I96YT90!!\6%D:7(@87%U[3H`0?%A9&ER(&=R
M=7!O`$'Q861I<B!P<FEV:6QE9VEO`$'Q861I<B!A("<E<R<@=6X@9W)U<&\@
M9&5S8V5N9&EE;G1E`$'Q861I<B!A("<E<R<@=6X@<')I=FEL96=I;R!D97-C
M96YD:65N=&4`0?%A9&ER('5N('5S=6%R:6\Z`$'Q861I<B!C;VQU;6YA`$'Q
M861I<B!M:65M8G)O<P!!\6%D:7(@<&%R`$'Q861I<B!E;"!M96[Z("5S(&-O
M;6\@<&%N96P@;&%T97)A;"!D92!-;WII;&QA`$'Q861I<B!A(&QA(&%G96YD
M80!!\6%D:7(@82!L87,@9&ER96-C:6]N97,Z`$'Q861I<B!A(&QA<R!D:7)E
M8V-I;VYE<SH`0?%A9&ER('5S=6%R:6\`4V4@:&$@8?%A9&ED;R`G)7,G(&%L
M('-I<W1E;6$L('!E<F\@;F\@<V4@<'5E9&4@8?%A9&ER(&QA(&EN9F]R;6%C
M:?-N(&%D:6-I;VYA;"!D92!A;'1A.B`E<RX`4V4@:&$@8?%A9&ED;R`G)7,G
M(&%L('-I<W1E;6$N(%EA('!U961E(&EN:6-I87(@;&$@<V5S:?-N+@!!\6%D
M:65N9&\@87)C:&EV;W,@;G5E=F]S(&%L(&1E</-S:71O.@!,82!A9&EC:?-N
M(&1E('5S=6%R:6]S(&5S=.$@9&5S:&%B:6QI=&%D82X`1&ER96-C:?-N`$1I
M<F5C8VEO;F5S`$%D;6EN:7-T<F%D;W(@+2!D969I;F4@<')I=FEL96=I;W,@
M9&4@;W1R;W,@=7-U87)I;W,`061M:6YI<W1R86-I\VX`06YU;F-I;W,`069G
M86YI<W3A;@!!;&)A;FEA`$%R9V5L:6$`06QI87,`06QI;F5A<@!!;&EN96%C
M:?-N.@!4;V1O<P!4;V1O<R!L;W,@=7-U87)I;W,@875T96YT:69I8V%D;W,`
M5&]D;W,@;&]S(&=R=7!O<P!4;V1O<R!L;W,@<')I=FEL96=I;W,`5&]D;W,@
M;&]S(&QA9&]S`%!E<FUI=&ER('9A<FEA<R!D:7)E8V-I;VYE<P"_4&5R;6ET
M:7(@8V]N9FEG=7)A8VGS;B!D92!T:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_
M`%EA(&5X:7-T90!!8V-E<V\@24U34"!A;'1E<FYA=&EV;P!#;&%V92!)35-0
M(&%L=&5R;F%T:79A`%5S=6%R:6\@24U04R!A;'1E<FYA=&EV;P!$:7)E8V-I
M\VX@96QE8W1R\VYI8V$@86QT97)N871I=F$`4&QA;G1I;&QA<R!A;'1E<FYA
M=&EV87,`5&5X=&\@86QT97)N871I=F\`4V%M;V$@06UE<FEC86YA`%-E(&AA
M(&EN9&EC861O('5N('9A;&]R(&EL96=A;"X`06YD;W)R80!!;F=O;&$`06YG
M=6EL80!0<F]X>2!A;O-N:6UO`%)E<W!U97-T80!!;G3A<G1I9&$`06YT:6=U
M82!Y($)A<F)A9&]S`$%P;&EC86-I\VX`3&$@87!L:6-A8VGS;B!E<W3A(&QI
M<W1A+@!!<&QI8V%R(&$@<F5C=7)S;W,@8V]M<&%R=&ED;W,@9&5S8V5N9&EE
M;G1E<P!!<')O8F%R`$%B<FEL`$%RX6)I9V\@*%=I;F1O=W,M,3(U-BD`5&%M
M8?%O(&1E;"!A<F-H:79O`$YO;6)R92!D96P@87)C:&EV;P"_17-T82!S96=U
M<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&QA('-O;&EC:71U9"!D92!A;'1A
M(&1E("5S/P"_17-TX2!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R("<E
M<R<@>2!C=6%L<75I97(@<W5B9W)U<&\_`$%R9V5N=&EN80!!<FUE;FEA`$%R
M;65N:6\@*$%235-#24DM."D`07)T90!!<G5B80!)<VQA($%S8V5N<VGS;@!'
M<N%F:6-O<R!!<V-I:0!296=I\VX@9&4@07-I82]086/M9FEC;P"_4V]L:6-I
M=&%R(&-O;F9I<FUA8VGS;B!A;G1E<R!D92!R96%L:7IA<B!O<&5R86-I;VYE
M<R!D92!M86YT96YI;6EE;G1O/P!#;VQU;6YA<R!D92!A<VEG;F%C:?-N`%-E
M(&%D:G5N=&$@=6X@87)C:&EV;R!I0V%L96YD87(@8V]M;R!R97-P=65S=&$@
M82!U;F$@<V]L:6-I='5D('%U92!H86+M82!E;G9I861O+@!);G1E;G1A(&5L
M:6UI;F%R('5N(&=R=7!O(&EN97AI<W1E;G1E+@!);G1E;G1A(&5L:6UI;F%R
M('5N('!R:79I;&5G:6\@:6YE>&ES=&5N=&4N`$EN=&5N=&$@;6]D:69I8V%R
M('5N('!R:79I;&5G:6\@:6YE>&ES=&5N=&4N`$EN=&5N=&$@;6]D:69I8V%R
M('5N(')E8W5R<V\@8V]M<&%R=&ED;R!I;F5X:7-T96YT92X`07-I<W1E;G1E
M<P!!=')I8G5T;W,`06=O<W1O`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER
M<W%L.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@:6UA<"!N96-E<V%R
M:6$N`$%U=&A?8WER=7,Z($5L(&UO=&]R(&-A<F5C92!D92!L87,@8V%P86-I
M9&%D97,@;F5C97-A<FEA<RX`075T:%]C>7)U<SH@3F\@<V4@96YC;VYT<O,@
M;&$@97AT96YS:?-N(&EM87`@;F5C97-A<FEA+@!!=71H7V9T<#H@3F\@<V4@
M96YC;VYT<O,@;&$@97AT96YS:?-N($944"!N96-E<V%R:6$N($-O;7!I;&4@
M4$A0(&-O;B!L82!O<&-I\VX@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z($YO
M('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!)34%0(&YE8V5S87)I82X`075T
M:%]K<F(U.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@:W)B-2!N96-E
M<V%R:6$N`$%U=&A?;&1A<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N
M($Q$05`@;F5C97-A<FEA+@!!=71H7VQD87`Z($YO('-E('!U961E(&'Q861I
M<B!E;"!U<W5A<FEO("5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L('-E<G9I
M9&]R.B``075T:%]L9&%P.B!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L('5S=6%R
M:6\@)7,`075T:%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A;&EZ87(@96P@=7-U
M87)I;R`E<P!!=71H7VUC86PZ($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS
M;B!-0T%,(&YE8V5S87)I82X`075T:%]S;6)A=71H.B!.;R!S92!E;F-O;G1R
M\R!L82!E>'1E;G-I\VX@<VUB875T:"!N96-E<V%R:6$N`$9A;&SS(&QA(&%U
M=&5N=&EF:6-A8VGS;@!&86QL\R!L82!A=71E;G1I9FEC86-I\VXN("5S`$5L
M('-E<G9I9&]R(%)!1$E54R!H82!R96-H87IA9&\@;&$@875T96YT:69I8V%C
M:?-N+@!&86QL\R!L82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R
M($944"X`0V%M<&]S(&1I<W!O;FEB;&5S.@!%<W!E<F%N9&\@<F5S<'5E<W1A
M`$%Z97)B86EJ86X`07IU;"!C96QE<W1E`$5X8W5S87,@0D]&2`!.;R!S92!H
M82!D97-A<G)O;&QA9&\@861E8W5A9&%M96YT92!E;"!M;W1O<BX`1F]N9&\`
M0V]L;W(@9&4@9F]N9&\`0V]N=')A<V7Q82!K97)B97)O<R!I;F-O<G)E8W1A
M+@!.;VUB<F4@9&4@=7-U87)I;R!K97)B97)O<R!I;F-O<G)E8W1O+@!"86AA
M;6%S`$)A:')A:6X`0N%L=&EC;R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`
M0F%R8F%D;W,`0F%R8FEE`$1E<V-U8FEE<G1O`$SM;F5A(&)A<V4`0F5L87)U
M<P!"Z6QG:6-A`$)E;&EZ90!"96YI;@!"97)M=61A<P!":'5T86X`0W5M<&QE
M8?%O<P!.;R!S92!E;F-O;G1R\R!E;"!B;&]Q=64@(B5S(B!D92!L82!A<&QI
M8V%C:?-N("(E<R(N`$]P8VEO;F5S(&1E(&)L;W%U90!4:7!O(&1E(&)L;W%U
M90!396QE8V-I\VX@9&4@8FQO<75E`$%Z=6P@>2!B;&%N8V\`3F5G<FET80!"
M;VQI=FEA`$UA<F-A9&]R97,`0F]R9&4`1W)O<V]R(&1E;"!B;W)D93H`0F]R
M9&5S`$)O<VYI82!(97)Z96=O=FEN80!!;6)O<P!";W1S=V%N80!);F9E<FEO
M<@!)<VQA(&1E($)O=79E=`!"<F%S:6P`5&5R<FET;W)I;R!O8V7A;FEC;R!D
M92!L82!);F1I82!B<FETX6YI8V$`36]R96YO`$)R=6YE:2!$87)U<W-A;&%M
M`$-O;G-T<G5Y96YD;R!A<F-H:79O<R!-3R!D96P@;?-D=6QO("5S+BXN`$-O
M;G-T<G5Y96YD;R!I9&EO;6$@)7,N+BX@`$)U;&=A<FEA`$QI<W1A(&1E<V]R
M9&5N861A`$)U<FMI;F$@1F%S;P!.87)A;FIA('1O<W1A9&\`0G5R=6YD:0!#
M35,`0U)#`%!U;G1O<R!D92!D:7-T<FEB=6-I\VX@0U)#`%!R;W!I961A9&5S
M(&1E(%]C96QD82XN+@!!9V5N9&$`0V%L;6$`0V%M8F]Y80!#86UE<OIN`$-A
M;75F;&%J90!.;R!S92!P=65D92!R96%J=7-T87(@;&$@8VQA=F4@875T;VWA
M=&EC86UE;G1E+"!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"!A9&UI;FES
M=')A9&]R(&1E;"!S:7-T96UA+@!.;R!S92!P=65D92!C;VYE8W1A<B!A;"!S
M97)V:61O<B!)34%0.B`E<P!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@:6YF
M;W)M92!D92!P<F]B;&5M87,`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@87)C
M:&EV;R`B)7,B+@!.;R!S92!E;F-U96YT<F$@=6X@9&ER96-T;W)I;R!T96UP
M;W)A;"X`3F\@<V4@<'5E9&4@8V]N=&EN=6%R('-I;B!E;"!P87+A;65T<F\@
M)W1A<F=E=$9I;&4G+@!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!D:7)E8W1O
M<FEO("(E<R(N`$YO('-E('!U961E(&5L:6UI;F%R+"!T:65N92`E9"!D97-C
M96YD:65N=&5S+@!.;R!S92!P=65D92!R96]R9&5N87(L(&5L(&[Z;65R;R!D
M92!E;G1R861A<R!Q=64@<V4@9&5S96$@;W)D96YA<B!N;R!C;VEN8VED92!C
M;VX@;&%S(&%L;6%C96YA9&%S+@!.;R!S92!P=65D92!D:7)I9VER(&5L(&UE
M;G-A:F4@86P@;OIM97)O(&5S<&5C:69I8V%D;RX`0V%B;R!697)D90!3=6)T
M[71U;&\`0V%T96=O<NUA<R!Y(&5T:7%U971A<P!)<VQA<R!#86EMX6X`5&5L
MZ69O;F\@;?-V:6P`4')O<&EE9&%D97,@9&4@8V5L9&$`36%R9V5N(&1E(&-E
M;&1A.@!0<F]P:65D861E<R!D92!C96QD80!%<W!A8VEA9&\@9&4@8V5L9&$Z
M`%1E;.EF;VYO(&WS=FEL`$/I;'1I8V\@*$E33RTX.#4Y+3$T*0!#96YT<F%R
M`%)E</IB;&EC82!#96YT<F]A9G)I8V%N80!%=7)O<&$@0V5N=')A;"`H25-/
M+3@X-3DM,BD`1&5T86QL97,@9&5L(&-E<G1I9FEC861O`%!O;.UT:6-A<R!D
M96P@8V5R=&EF:6-A9&\`0VAA9`!/8W5P86YT90!#86UB:6%R`$-A;6)I87(@
M;&$@8V]N=')A<V7Q80!#86UB:6%R(&-O;G1R87-E\6$@96XZ`$-A;6)I82!E
M;"!N;VUB<F4@>2!L82!D:7)E8V-I\VX@96QE8W1R\VYI8V$@=FES:6)L97,@
M86P@;&5E<B!O(')E<W!O;F1E<B!A('-U<R!M96YS86IE<RX`0V%M8FEA<B!L
M82!C;VYT<F%S9?%A`$-A;6)I86YD;R!L82!C;VYT<F%S9?%A(&5N("5S`$=R
MX69I8V\`5F5R:69I8V%R(%]V[6YC=6QO+BXN`$%C=&EV92!E;B!L82!C87-I
M;&QA('%UZ2!O<&5R86-I;VYE<R!D97-E82!E:F5C=71A<B!E;B!E<W1A(&]C
M87-I\VXN`$-H:6QE`$-H:6YA`$-H:6YO('-I;7!L:69I8V%D;R`H1T(R,S$R
M*0!#:&EN;R!T<F%D:6-I;VYA;"`H0FEG-2D`16QI:F$@=6YA(&-O;G1R87-E
M\6$`16QI:F$@=6X@;F]M8G)E(&1E('5S=6%R:6\`16QI:F$@=6YA(&%C8VGS
M;CH`16QI:F$@8_-M;R!M;W-T<F%R(&QA<R!F96-H87,Z`%-E;&5C8VEO;F%R
M('1I<&\@9&4@97-T:6QO(&1E(&QI<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D
M87,I`$ES;&$@9&4@4&%S8W5A`$YO('-E(&5N8V]N='+S(&QA(&1E9FEN:6-I
M\VX@9&4@8VQA<V4@9&4@)7,N`$QI;7!I86YD;R!L;W,@87)C:&EV;W,@4$\@
M9&5L(&WS9'5L;R`E<RXN+@!,:6UP:6%N9&\@96P@:61I;VUA("5S+BXN`$QI
M;7!I87(`16QI;6EN87(@971I<75E=&%S($U33V9F:6-E`$)O<G)A<B!U<W5A
M<FEO.B`E<P!";W)R87(@=7-U87)I;P!";W)R87(@9&%T;W,@9&5L('5S=6%R
M:6\`2&%G82!C;&EC:R!P87)A('-E9W5I<@!#;&EC:V%T96QL('!O<B!(5%10
M`$-E<G)A<B!V96YT86YA`$YU8F5S`&YU8F]S;P!)<VQA<R!D92!C;V-O<R`H
M2V5E;&EN9RD`0V]L87!S87(@8F]R9&5S`$-O;&]M8FEA`$-O;&]R`%-E;&5C
M=&]R(&1E(&-O;&]R`%-E;&5C8VGS;B!D92!C;VQO<@!#;VQU;6YA<SH`5.UT
M=6QO<R!D92!L87,@8V]L=6UN87,`0_-M:6-S`$-O;6%N9&\`26YTZ7)P<BX@
M8V]M86YD;W,`3W!C:6]N97,@9&4@8V]M86YD;W,Z`$-O;6%N9&]S.@!#;VUE
M;G1A<FEO`$%C='5A;&EZ86YD;SH`3F]M8G)E(&-O;?IN`$-O;6]R;W,`0V]M
M<&'Q[6$`5&5R;6EN861O`%)E9&%C=&%R(&UE;G-A:F4@*"5S*0!/<F1E;F%D
M;W)E<P!#;VYD:6-I;VYE<P!$:69E<F5N8VEA<R!D92!L82!C;VYF:6=U<F%C
M:?-N`$AA>2!Q=64@86-T=6%L:7IA<B!L82!C;VYF:6=U<F%C:?-N+@!#;VYF
M:6=U<F%R("5S`$-O;F9I<FUA<B!C;VYT<F%S9?%A`$-O;F9I<FUA<B!L82!N
M=65V82!C;VYT<F%S9?%A.@!#;VYG;P!#;VYG;RP@4F5P^F)L:6-A($1E;6]C
M<N%T:6-A(&1E;`!&86QL\R!L82!C;VYE>&GS;BX`1F%L;/,@;&$@8V]N97AI
M\VXZ(`!392!H82!R96-H87IA9&\@;&$@8V]N97AI\VX@86P@<V5R=FED;W(@
M9&4@8VQA=F5S('#Z8FQI8V\N`%-E(&AA(')E8VAA>F%D;R!L82!C;VYE>&GS
M;B!A;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RX@36]T:79O.B`E<R`H
M)7,I`$AA(&9A;&QA9&\@;&$@8V]N97AI\VX@86P@<V5R=FED;W(@1E10+@!#
M;VYT86-T;W,`4V4@:&%N(&'Q861I9&\@8V]R<F5C=&%M96YT92!L;W,@8V]N
M=&%C=&]S(&$@<W5S(&1I<F5C8VEO;F5S`$-O;G1E;FED;R!D92`G)7,G`$-O
M;G1I;G5A<@!)<VQA<R!#;V]K`$-O;VMI90!#;W!I87(`0V]P:6%R('-E;&5C
M8VGS;@!#;W!I86YD;R`E<R!D92`E<P!!>G5L:6YA`$-O<W1A(%)I8V$`0V]S
M=&$@9&4@36%R9FEL`$YO('-E('!U961E(&-I9G)A<B!E;"!M96YS86IE(&UE
M9&EA;G1E(%!'4"X`3F\@<V4@<'5E9&4@9FER;6%R(&5L(&UE;G-A:F4@;65D
M:6%N=&4@4$=0+@!.;R!S92!P=65D92!C:69R87(@96P@;65N<V%J92!M961I
M86YT92!3+TU)344`3F\@<V4@<'5E9&4@9FER;6%R(&5L(&UE;G-A:F4@;65D
M:6%N=&4@(%,O34E-10!.;R!S92!P=65D92!A\6%D:7(@96P@8V]N=&%C=&\N
M("5S`$YO('-E('!U961E(&5N;&%Z87(@86P@<V5R=FED;W(@3$1!4"X`3F\@
M<V4@<'5E9&4@96YL87IA<B!A;"!S97)V:61O<B!L9&%P`$YO('-E('!U961E
M(&QL86UA<B!L82!F=6YC:?-N("5S(&5N(&QA(&%P;&EC86-I\VX@)7,N`$YO
M('-E('!U961E(&-O;7!R;V)A<B!E;"!S86QD;RX@)7,`3F\@<V4@<'5E9&4@
M8V]N96-T87(@86P@<V5R=FED;W(@;&1A<`!.;R!S92!P=65D92!C;VYE8W1A
M<B!A;"!S97)V:61O<B`G)7,G(&UE9&EA;G1E($944#H@)7,`3F\@<V4@<'5E
M9&4@8V]P:6%R("5S(&$@)7,`3F\@<V4@<'5E9&4@8W)E87(@;&$@;&ES=&$@
M9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P=65D92!C<F5A<B!E;"!D:7)E
M8W1O<FEO(&1E(&ED:6]M82!D96P@:61I;VUA("5S.@!.;R!S92!P=65D96X@
M9&5S8VEF<F%R(&QO<R!D871O<R!01U`N`$YO('-E('!U961E;B!D97-C:69R
M87(@;&]S(&1A=&]S(%,O34E-12X`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@
M8V]N=&%C=&\N("5S`$YO('-E('!U961E(&5L:6UI;F%R(&QA(&QI<W1A(&1E
M(&1I<W1R:6)U8VGS;BX@)7,`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9W5I
M\VX@9&4@86-T=6%L:7IA8VGS;B!D92!C;VYF:6=U<F%C:?-N("<E<R<N`$YO
M('-E('!U961E(&1E=&5R;6EN87)A(&QA(&1I<F5C8VGS;B!D92!C;W)R96\@
M9&5L(&1E<W1I;F%T87)I;RX`3F\@<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T
M82!D92!D:7)E8V-I;VYE<R!C;VUP;&5T82X`3F\@<V4@<'5E9&4@=')A97(@
M;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N(&-O;7!L971A+@!.;R!S92!P=65D
M92!T<F%E<B!L82!L:7-T82!C;VUP;&5T82!D92!L:7-T87,@9&4@9&ES=')I
M8G5C:?-N+@!.;R!S92!P=65D92!C87)G87(@;&$@97-T<F%T96=I82`G)7,G
M+@!.;R!S92!P=65D92!C<F5A<B!E;"!D:7)E8W1O<FEO("<E<R<N`$YO('-E
M('!U961E(&]B=&5N97(@;&$@8VQA=F4@</IB;&EC82!D96P@<V5R=FED;W(@
M9&4@8VQA=F5S+@!.;R!S92!P=65D92!A8G)I<B`E<RX`3F\@<V4@<'5E9&4@
M86)R:7(@)R5S)R!P87)A(&5S8W)I8FER+@!.;R!S92!P=65D92!A8G)I<B!E
M;"!M\V1U;&\@9&4@=&%R96%S(&1E(&UA;G1E;FEM:65N=&\@)7,`3F\@<V4@
M<'5E9&4@86)R:7(@96P@9&ER96-T;W)I;R`G)7,G+@!.;R!S92!P=65D92!A
M8G)I<B!U;F$@8V%N86QI>F%C:?-N(&$@<VUB<&%S<W=D+@!.;R!S92!P=65D
M92!L965R("5S+@!.;R!S92!P=65D92!R97-T86)L96-E<B!L82!C;VYT<F%S
M9?%A(&1E;"!U<W5A<FEO('-O;&EC:71A9&\N(%!A<G1E(&1E(&QO<R!D971A
M;&QE<R!O('1O9&]S+"!S;VX@:6YC;W)R96-T;W,N(%!R=65B92!O=')A('9E
M>B!O('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@
M9&5L('-I<W1E;6$@<&%R82!MX7,@:6YF;W)M86-I\VXN`$YO('-E('!U961E
M(&]B=&5N97(@;&$@04-,+@!.;R!S92!P=65D92!O8G1E;F5R(&QA(&QI8G)E
M=&$@9&4@9&ER96-C:6]N97,N("5S`$YO('-E('!U961E(&]B=&5N97(@;&$@
M;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P=65D96X@;V)T96YE
M<B!L87,@;&ES=&%S(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@<V4@<'5E9&5N
M(&]B=&5N97(@;&%S(&-A<&%C:61A9&5S(&1E;"!S97)V:61O<@!.;R!S92!P
M=65D92!R97-T875R87(@;&$@8V]N9FEG=7)A8VGS;BX`3F\@<V4@<'5E9&4@
M96QI;6EN87(@96P@9&ER96-T;W)I;R`G)7,G+@!.;R!S92!P=65D92!G=6%R
M9&%R(&QA(&-O;F9I9W5R86-I\VX@9&4@)7,N`$YO('-E('!U961E(&=U87)D
M87(@=6YA(&-O<&EA(&1E(&QA(&-O;F9I9W5R86-I\VXN`$YO('-E('!U961E
M(&=U87)D87(@;&$@8V]P:6$@)7,@9&4@;&$@8V]N9FEG=7)A8VGS;BX`3F\@
M<V4@<'5E9&4@9W5A<F1A<B!E;"!G=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E
M(&QA(&-O;F9I9W5R86-I\VX@96XZ("<E<R<N`$YO('-E('!U961E(&)U<V-A
M<B!E;B!E;"!S97)V:61O<B!,1$%0+@!.;R!S92!P=65D92!D97-V:6YC=6QA
M<B`G)7,G+@!.;R!S92!P=65D92!A8W1U86QI>F%R(&5L(&-O;G1A8W1O+B`E
M<P!.;R!S92!P=65D92!A8W1U86QI>F%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U
M8VGS;BX@)7,`3F\@<V4@<'5E9&4@97-C<FEB:7(@;&$@8V]N9FEG=7)A8VGS
M;B!D92`G)7,G.B`E<P!.;R!S92!P=65D92!L;V-A;&EZ87(@96P@<&%N96P@
M;&%T97)A;"!D92!-;WII;&QA+B!#;VUP<G5E8F4@<75E(&5S=.D@86)I97)T
M;RX`3F\@<V4@<'5E9&5N(&]T;W)G87(@86P@=7-U87)I;R`G)7,G(&QO<R!S
M:6=U:65N=&5S(&1E<F5C:&]S('!A<F$@;&$@8V%R<&5T82`G)7,G.B`E<P!4
M97AT;R!C;VYT861O`%!A[7,`0W5R<V]S`$-R96%R`$-R96$@=6X@=NUN8W5L
M;P!#<F5A<@!#<F5A<B!S=6)C87)P971A<P!0<FEV:6QE9VEO<R!D92!C<F5A
M9&]R`$[Z;65R;R!D92!T87)J971A(&1E(&-RZ61I=&\`0W)O86-I80!#=6)A
M`$9A<V4@86-T=6%L`$AO<F$@86-T=6%L`%523"!A8W1U86P`5&EE;7!O(&%C
M='5A;`!#;VYD:6-I\VX@86-T=6%L.B``17-T:6QO(&%C='5A;`!097)S;VYA
M;&EZ82!L87,@=&%R96%S(&$@96IE8W5T87(@86P@:6YI8VEA<B!S97-I\VX@
M96X@)7,N`$-O<G1A<@!#;W)T87(@<V5L96-C:?-N`$-H:7!R90!#:7+M;&EC
M;R`H2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W<RTQ,C4Q*0!#:7+M;&EC;R]5
M8W)A;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A($-H96-A`$1$`$1I87)I86UE
M;G1E`$1A=&]S`,%R7V)O;"!D871O<P!&96-H80!392!H82!R96-I8FED;R!L
M82!F96-H80!396QE8V-I\VX@9&4@9F5C:&$`1.UA`$5?;&EM:6YA<B!C;VQU
M;6YA`$1I8VEE;6)R90!.^FUE<F]S(&1E8VEM86QE<P!296-H87IA9&$`4F5D
M=6-I<B!S86YG<F%D;P!#;VQO<B!P;W(@;VUI<VGS;@!)9&5N=&ED860@<&]R
M(&]M:7-I\VX`4')I=FEL96=I;W,@<&]R(&]M:7-I\VX`4')I=FEL96=I;W,@
M<&]R(&]M:7-I\VX`1&5F:6YI8VEO;F5S`%!O<VEC:?-N(&1E;&5G861A`$1E
M;&5G861O`"9N8G-P.T5L:6UI;F%R)FYB<W`[`$5L:6UI;F%R(&=R=7!O`$5L
M:6UI;F%R('!R:79I;&5G:6\`16QI;6EN87(@>2!V86-I87(@;65N<V%J97,`
M16QI;6EN87(@8V5L9&$`16QI;6EN87(@8V]L=6UN80!%;&EM:6YA<B!P;&%N
M=&EL;&%S(&%L=&5R;F%T:79A<R!E>&ES=&5N=&5S`$5L:6UI;F%R('!R:79I
M;&5G:6]S(&1E("<E<R<`OT5L:6UI;F%R('!R:79I;&5G:6]S('!A<F$@)R5S
M)R!Y(&-U86QQ=6EE<B!P<FEV:6QE9VEO(&1E<V-E;F1I96YT93\`16QI;6EN
M87(@9FEL80!%;&EM:6YA<B!I9&5N=&ED860@<V5L96-C:6]N861A`$5L:6UI
M;F$@;&$@8V]L=6UN82!A8W1U86P`16QI;6EN82!L82!F:6QA(&%C='5A;`"_
M16QI;6EN87(@97-T92!P<FEV:6QE9VEO('D@8W5A;'%U:65R('!R:79I;&5G
M:6\@9&5S8V5N9&EE;G1E/P!392!H82!E;&EM:6YA9&\@96P@9W5I\VX@9&4@
M86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N("<E<R<N`$AO<F$@
M9&4@96YT<F5G83H`1&EN86UA<F-A`$1E;F5G87(@;&$@<&5T:6-I\VX`1&5N
M96=A<B!L82!P971I8VGS;B!D92!I;F9O<FUA8VGS;B!D92!T:65M<&\@9&ES
M<&]N:6)L90!$97-C<FEB82!E;"!P<F]B;&5M80!$97-C<FEP8VGS;@!$971A
M;&QE<R`H=&%M8FGI;B!E;B!E;"!A<F-H:79O(&1E(')E9VES=')O(&1E($AO
M<F1E*3H`4V4@:&%N(')E9VES=')A9&\@;&]S(&1E=&%L;&5S('!A<F$@96P@
M861M:6YI<W1R861O<BX`1&5S87)R;VQL;P!0=6YT;R!D92!C;VYD96YS86-I
M\VX`4'5N=&\@9&4@8V]N9&5N<V%C:?-N(&1E(&QA(/IL=&EM82!H;W)A.B``
M4'5N=&\@9&4@8V]N9&5N<V%C:?-N.B``1&4@:7IQ=6EE<F1A(&$@9&5R96-H
M80!$92!D97)E8VAA(&$@:7IQ=6EE<F1A`$1I<F5C=&]R:6\`OTUO<W1R87(@
M96X@9F]R;6%T;R!D92`R-"UH;W)A<S\`3W!C:6]N97,@9&4@5FES=6%L:7IA
M8VGS;@!-;W-T<F%R('!R;V[S<W1I8V\@*%1!1BD`1F]R;6%T;R!D92!V:7-U
M>F%L:7IA8VGS;@!.;W1I9FEC86-I\VX@9&4@8V]N<W5L=&$`1&II8F]U=&D`
M3F\@96QI;6EN87(`3F\@86-C961E<B!D:7)E8W1A;65N=&4@82!M86EN=&5N
M86YC92YP:'``OT-O;G1I96YE(&QA('!R:6UE<F$@9FEL82!L;W,@;F]M8G)E
M<R!D92!L;W,@8V%M<&]S/R!3:2!E<R!A<^TL('-E;&5C8VEO;F4@97-T82!C
M87-I;&QA.@!$;VUI;FEC80!297#Z8FQI8V$@1&]M:6YI8V%N80!$97-C87)G
M87(`1&5S8V%R9V%R("5S`$1E<V-A<F=A<B!L82!C;VYF:6=U<F%C:?-N(&=E
M;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0+@!,:7-T82!D97-P;&5G86)L90!$
M<F]G87,`0V]R<F5O`$524@!%8W5A9&]R`"9N8G-P.TUO9&EF:6-A<B9N8G-P
M.P!-;V1I9FEC87(@8FQO<75E`$UO9&EF:6-A<B!G<G5P;P!-;V1I9FEC87(@
M<')I=FEL96=I;P!-;V1I9FEC87(@<')I=FEL96=I;W,`36]D:69I8V%R('!R
M:79I;&5G:6]S(&1E("5S`$UO9&EF:6-A<B!O<&-I;VYE<R!D93H`36]D:69I
M8V%R('!R:79I;&5G:6]S(&1E("5S`$UO9&EF:6-A<B!P<FEV:6QE9VEO<R!D
M92`G)7,G`$5D=6-A8VGS;@!%9VEP=&\`16P@4V%L=F%D;W(`16QE;65N=&\N
M+BX`16T`0V]R<F5O`$1I<F5C8VGS;B!D92!C;W)R96\`3&%S(&1I<F5C8VEO
M;F5S(&1E(&-O<G)E;R!T:65N96X@<75E(&-O:6YC:61I<BX`0V]R<F5O(&-O
M;B!C;VYF:7)M86-I\VX`16UO=&EC;VYE<P!-96YS86IE(&5N(&)L86YC;P!2
M97-U;'1A9&\@96X@8FQA;F-O+@!,:6UP:6%R('3I<FUI;F]S(&1E(&+Z<W%U
M961A`+]097)M:71I<B!I;G-E<F-I\VX@9&4@:6WA9V5N97,@9&4@;&%S($=A
M;&5R[6%S(&1E(&9O=&]S/P"_4&5R;6ET:7(@;65N^B!D92!C;VYT97AT;R!D
M96P@8F]T\VX@9&5R96-H;R!D96P@<F%T\VX_`$9I;F%L`$'Q;R!D92!T97)M
M:6YA8VGS;@!!9W)A;F1A<B!E9&ET;W(`26YT<F]D=7IC82!U;F$@<')E9W5N
M=&$@9&4@<V5G=7)I9&%D('%U92!S92!L92!F;W)M=6QA<N$@<VD@<')E8VES
M82!R96%J=7-T87(@;&$@8V]N=')A<V7Q82P@<"YE+B`GOT-UX6P@97,@96P@
M;F]M8G)E(&1E('-U(&UA<V-O=&$_)SH`26YT<F]D=7IC82!A<77M(&QA(%52
M3"!D92!L82!I;6%G96X`16YT<F%D87,Z("5D('1O=&%L+"`E9"!A8W1U86QI
M>F%D87,L("5D(&YU979A<RP@)60@8V%M8FEA9&%S+"`E9"!D97-C;VYO8VED
M87,`1W5I;F5A($5C=6%T;W)I86P`17)I=')E80!%<G)O<@!%<G)O<B!A;"!E
M;G9I87(@;&]S(&1A=&]S(&$@<VUB<&%S<W=D+@!%<G)O<B!A;"!E;G9I87(@
M;&$@<F5S<'5E<W1A.B`E<RX`17)R;W(@8V]N(&5L(&UE;G-A:F4@9&4@8V]R
M<F5O+@!%<G)O<B!A;"!E<V-R:6)I<B`G)7,G+@!%<G)O<CH@`$5S=&]N:6$`
M171I;W#M80#)=&YI8V\`175R;W!A`$-A9&$@,34@;6EN=71O<P!#861A(#(@
M;6EN=71O<P!#861A(#,P('-E9W5N9&]S`$-A9&$@-2!M:6YU=&]S`$-A9&$@
M:6YI8VEO(&1E('-E<VGS;@!#861A(&UE9&EA(&AO<F$`0V%D82!M:6YU=&\`
M5F%L;W)E<R!D92!E:F5M<&QO.@!%:F5C=71A<@!%:F5C=71A;F1O.@!%>'!A
M;F1I<@!S92!E<W!E<F%B82`G*2<`4V4@97-P97)A8F$@=6YA(/IN:6-A('!A
M;&%B<F$@;R!U;B!TZ7)M:6YO(&1E(&+Z<W%U961A(&5N=')E8V]M:6QL861O
M`$9E8VAA(&1E('9E;F-I;6EE;G1O`$5X<&]N96YT90!%>'1R87EE;F1O(&1E
M("5S+BXN(`!#;VQO<B!D92!L971R80!#87)G87(@;&$@8V]N9FEG=7)A8VGS
M;B!P;W(@1E10`$9A;&QO(&%L('1R865R(&QA<R!P<F5F97)E;F-I87,N`$EN
M8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!,1$%0+@!);F-A<&%Z
M(&1E(&-O;F5C=&%R<V4@86P@<V5R=FED;W(@4TU"+@!&86QL;R!A;"!C;W!I
M87(@9&4@(B5S(BX`1F%L;&\@86P@8V]P:6%R(&$@(B5S(BX`1F%L;&\@86P@
M8W)E87(@=6YA(&-O;F5X:?-N(%-!4TP`1F%L;&\@86P@=')A<VQA9&%R("(E
M<R(N`$9A;&QO(&%L(&-A;6)I87(@;&$@8V]N=')A<V7Q82!E;B`E<SH@)7,`
M1&5S<&5J861O`$ES;&%S($UA;'9I;F%S("A&86QK;&%N9"D`27-L87,@1F%R
M;V4`H45R<F]R(&ER<F5C=7!E<F%B;&4A`$9A>`!&96)R97)O`%-E('-I96YT
M92!C;VUO`%-E('-I96YT92!C;VUO.B``4&]C87,@;&QU=FEA<P!&:6II`$ZZ
M(&1E(&%R8VAI=F]S.B`E<R!A<F-H:79O`$ZZ(&1E(&%R8VAI=F]S.B`E<R!A
M<F-H:79O<P!!<F-H:79O<P!.;VUB<F4@9&4@87)C:&EV;P!396QE8V-I\VX@
M9&4@87)C:&EV;P!#87)G87(@87)C:&EV;P!,82!C87)G82!D92!A<F-H:79O
M<R!N;R!E<W3A('-O<&]R=&%D82X`1FEL=')O<P!&:6YL86YD:6$`0W5A<G1O
M(&-R96-I96YT90!#=6%R=&\@8W)E8VEE;G1E`%)A>O-N(&9I:F$`5F]L=&5A
M<@!$:7-P;W-I8VGS;@!.:65B;&$`3&$@8V%R<&5T82`E<R!N;R!E>&ES=&4N
M`$-O;&]R(&1E(&QE=')A`$-O;6ED80!087)A(&YA=F5G861O<F5S('%U92!N
M;R!A9&UI=&%N(&EMX6=E;F5S`%!R;V[S<W1I8V\@*%1!1BD`1.UA<R!D96P@
M<')O;O-S=&EC;R`H=&5N9V$@96X@8W5E;G1A('%U92!E;"!P<F]N\W-T:6-O
M(&9A8VEL:71A9&\@:6YC;'5Y92!T86YT;R!E;"!D[6$@8V]M;R!L82!N;V-H
M93L@=6X@;OIM97)O(&=R86YD92!S92!T<F%D=6-I<N$@96X@=6X@8FQO<75E
M(&UU>2!A;F-H;RD`OTAA(&]L=FED861O(&QA(&-O;G1R87-E\6$_`$9O<FUU
M;&%R:6]S`$9O<G1U;F$`5&EP;R!D92!F;W)T=6YA`$9O<G1U;F%S`$9O<G1U
M;F%S(#(`1F]R;W,`4F5E;G;M;W,`4V4@:&%N(&5N8V]N=')A9&\@87!L:6-A
M8VEO;F5S.B`E<P!392!H86X@96YC;VYT<F%D;R!D:7)E8W1O<FEO<SH`5FEE
M`$9R86UE<P!&<F%N8VEA`$9R86YC:6$L($UE=')O<&]L:71A;F$`26YF;W)M
M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4`4F5S<'5E<W1A(&1E('1I96UP
M;R!D:7-P;VYI8FQE`%!E=&EC:?-N(&1E('1I96UP;R!D:7-P;VYI8FQE`%)E
M<W!U97-T82!A('!E=&EC:?-N(&1E('1I96UP;R!D:7-P;VYI8FQE`$=U87EA
M;F$@9G)A;F-E<V$`4&]L:6YE<VEA(&9R86YC97-A`%1E<G)I=&]R:6]S(&9R
M86YC97-E<R!D96P@<W5R`$1E`$1E;"``1&5S8W)I<&-I\VX@8V]M<&QE=&$`
M3'5N82!L;&5N80!.;VUB<F4@8V]M<&QE=&\`0F]R<F]S80!'86+S;@!'86QE
M<NUA(&1E(&QA('%U92!O8G1E;F5R(&QA(&EM86=E;@!'86QE<NUA.@!'86UB
M:6$`1V5N97)A<B!C;VYF:6=U<F%C:?-N(&1E("5S`$/S9&EG;R!G96YE<F%D
M;P!'96YE<F%N9&\@97-T861O(&1E;"!M\V1U;&\@)7,N+BX`1V5O<F=I80!!
M;&5M86YI80!%<G)O<B!D92!'971O<'0Z(`!':&%N80!':6)R86QT87(`3F]M
M8G)E(&EN9&EC861O`$ER`$=O961E;`!"^G-Q=65D82!E;B!';V]G;&4`17-C
M86QA(&1E(&=R:7-E<P!'<F5C:6$`1W)I96=O("A)4T\M.#@U.2TW*0!697)D
M90!'<F]E;FQA;F1I80!'<F%N861A`$=R:7,`061M:6YI<W1R86-I\VX@9&4@
M9W)U<&]S`$QO<R!N;VUB<F5S(&1E(&=R=7!O(&YO('!U961E;B!D96IA<G-E
M(&5N(&)L86YC;P!0<FEV:6QE9VEO<R!D92!G<G5P;P!'<G5P;W,`1W5A9&%L
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N97-E>0!0<FEV:6QE9VEO<R!D92!I
M;G9I=&%D;P!397)V:6-I;W,@9&4@:6YV:71A9&\`4')I=FEL96=I;W,@9&4@
M:6YV:71A9&\`3"X@:6YV:71A9&]S`$=U:6YE80!'=6EN96$M0FES<V%U`$=U
M87EA;F$`2$@`2%1-3`!(5$U,('-E(&YI96=A(&-O8F%R9&5M96YT92!A(&5L
M:6UI;F%R(&QA(/IL=&EM82!C96QD82!D92!L82!F:6QA+@!(5$U,07)E82!S
M92!N:65G82!C;V)A<F1E;65N=&4@82!E;&EM:6YA<B!L82#Z;'1I;6$@8V]L
M=6UN82!D92!L82!T86)L82X`2%1-3"!S92!N:65G82!C;V)A<F1E;65N=&4@
M82!E;&EM:6YA<B!L82#Z;'1I;6$@9FEL82!D92!L82!T86)L82X`3F\@<V4@
M96YC;VYT<O,@;&$@875T96YT:69I8V%C:?-N($A45%`N`$AA:73M`$%L9V]R
M:6UO($AA<V@`3F5B;&EN80!#86)E8V5R80!)<VQA($AE87)D(&4@27-L87,@
M36-$;VYA;&0`2&5B<F5O("A)4T\M.#@U.2TX+4DI`$%L='5R80!!>75D80!!
M>75D82!D96P@961I=&]R`$%Y=61A;G1E`$%P;&EC86-I\VX@875X:6QI87(@
M<&%R82!C<F5A<B!Y(&UA;G1E;F5R('1R861U8V-I;VYE<R!D96P@96YT;W)N
M;R!(;W)D90IY('-U<R!A<&QI8V%C:6]N97,N"DQE82!E;"!A<F-H:79O(%)%
M041-12!D92!E<W1E(&1I<F5C=&]R:6\@8V]M;R!I;G1R;V1U8V-I\VXN`$AE
M;6ES9F5R:6\`07%U[2!T:65N92!E;"!C;VUI96YZ;R!D96P@87)C:&EV;SH`
M06QT80!,;W,@;F]M8G)E<R!D92!E;G1R861A(&1E(&QA<R!H:7-T;W)I87,@
M;F\@<'5E9&5N(&1E:F%R<V4@96X@8FQA;F-O`%]);FEC:6\`4V%N=&$@4V5D
M92`H0VEU9&%D+45S=&%D;R!D96P@5F%T:6-A;F\I`$EN:6-I;P!$;VUI8VEL
M:6\`5&5LZ69O;F\@<&%R=&EC=6QA<@!(;VYD=7)A<P!(;VYG($MO;F<`2&]R
M9&4`1V5N97)A9&]R(&1E('1R861U8V-I;VYE<R!D92!(;W)D90!(;W)D92]+
M;VQA8CH@4V4@:&%N(&5N8V]N=')A9&\@9&%T;W,@6$U,("5S(&YO(';A;&ED
M;W,@96X@96P@;65N<V%J92`E<P!(;W)D92]+;VQA8CH@3FEN9_IN(&UE;G-A
M:F4@8V]R<F5S<&]N9&4@86P@;V)J971O("5S`$AO<F1E+TMO;&%B.B!.;R!S
M92!E;F-O;G1R\R!U;B!O8FIE=&\@9&4@=&EP;R`E<R!E;B!E;"!M96YS86IE
M("5S`$AO<F1E+TMO;&%B.B!392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT
M92`E<R`B)7,B`$AO<F1E+TMO;&%B.B!392!H82!S:6YC<F]N:7IA9&\@8V]R
M<F5C=&%M96YT92`E<R`B)7,B`$AO<F1E+TMO;&%B.B!%;"!M;W1O<B!D92!I
M;G1E9W)A8VGS;B!P<F5C:7-A(&1E(&QA(&5X=&5N<VGS;B!02%`@)V1O;7AM
M;"<`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@8W)E87(@;G5E=F\@X7)B;VP@
M6$U,(&1E;"!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@96QI
M;6EN87(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@;V)T
M96YE<B!)1"!-24U%(&1E(&QA('!A<G1E(&1E('1I<&\@)7,`2&]R9&4O2V]L
M86(Z($EN8V%P87H@9&4@<VEN8W)O;FEZ87(@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z($EN8V%P87H@9&4@<VEN8W)O;FEZ87(@96QE;65N=&]S(&-O;7!A
M<G1I9&]S.B`E<P!(;W)D92]+;VQA8CH@16QE;65N=&\@8V]M<&%R=&ED;R!D
M97-C;VYO8VED;R`B)7,B`$SM;F5A(&AO<FEZ;VYT86P`36%R9V5N(&AO<FEZ
M;VYT86P`2&]R:7IO;G1A;#H`OT/S;6\@;&QE9_,@:&%S=&$@87%U[3\@**%#
M;VUU;NUQ=65L;RP@<&]R(&9A=F]R(2D`OT-U86YT87,@8V]L=6UN87,@9&5S
M96$@8V]M8FEN87(_`+]#=>%N=&]S(&-A;7!O<R`H8V]L=6UN87,I(&AA>3\`
MOT-U86YT87,@9FEL87,@9&5S96$@8V]M8FEN87(_`$AU;65D860`2'5M961A
M9#H@`$AU;6]R:7-T87,`2'5N9W+M80!(82!F86QL861O(&QA(&-R96%C:?-N
M(&1E;"!B=7KS;B!)34%0.B`E<P!(82!F86QL861O(&QA(&5L:6UI;F%C:?-N
M(&1E;"!B=7KS;B!)34%0.B`E<P!(82!F86QL861O(&QA(&-R96%C:?-N(&1E
M(&5S<&%C:6\@87-I9VYA9&\@9&5L(&)U>O-N($E-05`Z("5S`$1I<F5C8VGS
M;B!)4`!,82!D:7)E8V-I\VX@25`@;F\@97-TX2!D:7-P;VYI8FQE+@!,82!D
M:7)E8V-I\VX@25`@;F\@97-TX2!E;G1R92!B;&]Q=65S($-)1%(@<&5R;6ET
M:61O<RX`5FEO;&%C:?-N(&QO8VMD;W=N($E0+@!)7VYS97)T87(@9FEL82!E
M;F-I;6$`27-L86YD:6$`4_-L;R!I8V]N;W,`26-O;F]S(&-O;B!T97AT;P!.
M;VUB<F4@9&4@;&$@:61E;G1I9&%D.@!3:2!N;R!S92!M=65S=')A(&-O<G)E
M8W1A;65N=&4L("5S('!A<F$@86)R:7)L;R!E;B!U;F$@=F5N=&%N82!N=65V
M82X`4VD@;F\@=F4@;FEN9_IN(&EC;VYO(&UE9&EA;G1E($EN=&5R;F5T($5X
M<&QO<F5R+"!P=65D92!T96YE<B!Q=64@86-T:79A<B!E<W1A(&-A<VEL;&$@
M<&%R82!D97-A8W1I=F%R(&QA('1R86YS<&%R96YC:6$@4$Y'+@!3:2!V92!E
M<W1E(&UE;G-A:F4@<VEN(&YI;F=U;F$@:6UA9V5N+"!L82!I;6%G96X@<75E
M('%U:65R92!C87)G87(@;F\@<V4@<'5E9&4@;6]S=')A<B!E;B!S=2!N879E
M9V%D;W(N`%9I<W1A('!R979I83H`55),(&1E(&QA(&EM86=E;@!54DP@9&4@
M;&$@:6UA9V5N.@!);6%G96X@9&4@;&$@9V%L97+M80!);6%G96X@9&4@;&$@
M9V%L97+M83H`4V4@:&$@8V%R9V%D;R!L82!I;6%G96X`26WA9V5N97,`26UP
M;W)T87(L('!A<V\@)60`0V%M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@:6UP
M;W)T861O<SH`4')O8V5S86YD;P!);E]S97)T87(@9FEL82!D96)A:F\`0V]N
M=')A<V7Q82!I;F-O<G)E8W1A`%-E(&AA(&EN9&EC861O('5N(&/S9&EG;R!D
M92!A8V-I\VX@:6YC;W)R96-T;RX`3F]M8G)E(&1E('5S=6%R:6\@>2]O(&-O
M;G1R87-E\6$@:6YC;W)R96-T;W,N`$YO;6)R92!D92!U<W5A<FEO(&\@9&ER
M96-C:?-N(&%L=&5R;F%T:79A(&EN8V]R<F5C=&]S+B!6=65L=F$@82!I;G1E
M;G1A<FQO(&\@</-N9V%S92!E;B!C;VYT86-T;R!C;VX@96P@861M:6YI<W1R
M861O<B!D92!S:7-T96UA<R!P87)A(&WA<R!I;F9O<FUA8VGS;BX`075M96YT
M87(@<V%N9W)A9&\`26YD:6$`57-U87)I;W,@:6YD:79I9'5A;&5S`$EN9&]N
M97-I80!);F9O<FUA8VGS;@!);F9O<FUA8VGS;@!);FEC:6%L:7IA;F1O(&5L
M(&WS9'5L;R`E<RXN+B``26YS97)T87(@8U]O;'5M;F$@9&5T<N%S`$EN<V5R
M=&%R(&EM86=E;@!);G-E<G1A<B!T86)L80!);G-E<G1A<B!V[6YC=6QO(%=E
M8@!);G-E<G1A<B!?8V]L=6UN82!D96QA;G1E`$EN<V5R=&$@=6YA(&YU979A
M(&-O;'5M;F$@9&5T<N%S(&1E(&QA(&%C='5A;`!);G-E<G1A('5N82!N=65V
M82!C;VQU;6YA(&1E;&%N=&4@9&4@;&$@86-T=6%L`$EN<V5R=&$@=6YA(&9I
M;&$@;G5E=F$@9&5B86IO(&1E(&QA(&%C='5A;`!);G-E<G1A('5N82!F:6QA
M(&YU979A(&5N8VEM82!D92!L82!A8W1U86P`26YS97)T82!U;B!PX7)R869O
M('1R87,@96P@;F]D;R!A8W1U86P`26YS97)T82!U;B!PX7)R869O(&%N=&5S
M(&1E;"!N;V1O(&%C='5A;`!);G-E<G1A<B!P;&%N=&EL;&$@86QT97)N871I
M=F$`26YS97)T87(@=6YA(&1I<F5C8VGS;B!D92!C;W)R96\@96X@;&$@<75E
M(')E8VEB:7(@;&$@8V]N=')A<V7Q83H`26YS97)T87(@8V5L9&$@9&5T<N%S
M`$EN<V5R=&%R(&-E;&1A(&%N=&5S`$EN<V5R=&%R(&-O;'5M;F$@9&5T<N%S
M`$EN<V5R=&%R(&-O;'5M;F$@86YT97,`26YS97)T87(@;65N<V%J97,`26YS
M97)T87(@<.%R<F%F;R!D971RX7,`26YS97)T87(@<.%R<F%F;R!A;G1E<P!)
M;G-E<G1A<B!F:6QA(&1E8F%J;P!);G-E<G1A<B!F:6QA(&5N8VEM80!);G-E
M<G1A<B!L82!R97-P=65S=&$@;F5C97-A<FEA(&$@;&$@<')E9W5N=&$@9&4@
M<V5G=7)I9&%D.@!);G-E<G1A<B]-;V1I9FEC87(@:6UA9V5N`$EN<V5R=&%R
M+TUO9&EF:6-A<B!V[6YC=6QO`%-A;&1O(&EN<W5F:6-I96YT92!P87)A(&5N
M=FEA<B!A(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX`4V%L9&\@:6YS=69I
M8VEE;G1E+@!%;G1E<F\`3&ES=&$@9&4@96YT97)O<P!392!H82!S96QE8V-I
M;VYA9&\@=6YA(&%C8VGS;B!N;R!VX6QI9&$@<&%R82!E<W1E(&-O;7!O;F5N
M=&4N`%5$2"`H0V%B96-E<F$@9&4@1&%T;W,@9&4@57-U87)I;RD@;F\@=N%L
M:61A+@!!<&QI8V%C:?-N(&YO(';A;&ED82X`240@9&4@;&]T92!N;R!VX6QI
M9&\N`%-E(&AA;B!E;G9I861O(&1A=&]S(&YO(';A;&ED;W,N`$1I<F5C8VGS
M;B!D92!C;W)R96\@;F\@=N%L:61A+@!&;W)M871O(&1E(&%R8VAI=F\@;F\@
M=N%L:61O`&US9U]T>7!E(&YO(';A;&ED;RX`87!I7VED(&YO(';A;&ED;R!O
M(&1E<V%P87)E8VED;RX`4&%RX6UE=')O<R!N;R!VX6QI9&]S(&\@9&5S87!A
M<F5C:61O<RX`4')I=FEL96=I;R!D96P@<&%D<F4@;F\@=N%L:61O<RX`4')O
M=&]C;VQO(&YO(';A;&ED;RX`1&5S=&EN871A<FEO(&YO(';A;&ED;SH@)R5S
M)RX`3V)J971O(&-O;7!A<G1I9&\@;F\@=N%L:61O+@!$:7)E8V-I\VX@9&5L
M(')E;6ET96YT92!N;R!VX6QI9&$`1&%T;W,@=6YI8V]D92!N;R!VX6QI9&]S
M+@!);G9E;G1A<FEO`$ERX6XL(%)E</IB;&EC82!)<VSA;6EC82!D90!)<F%Q
M`$ER;&%N9&$`27-L82!D92!-86X`0F]R<F%S8V%S(&%I<VQA9&%S`$ES<F%E
M;`!%;6ES;W(`0W5R<VEV80!)=&%L:6$`2F%M86EC80!%;F5R;P!*87#S;@!*
M87!O;NES("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F3A;@!*=6QI;P!*=6YI
M;P!*=7-T:69I8V%R`$%L:6YE87(@86P@8V5N=')O`$IU<W1I9FEC87(`06QI
M;F5A<B!A(&QA(&EZ<75I97)D80!!;&EN96%R(&$@;&$@9&5R96-H80!+87IA
M:VAS=&%N`+]#;VYS97)V87(@96P@;W)I9VEN86P_`$ME;GEA`$5L('-E<G9I
M9&]R($ME<F)E<F]S(&AA(')E8VAA>F%D;R!L82!A=71E;G1I9FEC86-I\VXN
M`$YO=F%T;W,@9&5L($ME<FYE;`!#<F5A8VGS;B!D92!C;&%V90!(=65L;&$@
M9&EG:71A;"!D92!L82!C;&%V90!486UA\6\@9&4@8VQA=F4`5&EP;R!D92!C
M;&%V90!5<V\@9&4@;&$@8VQA=F4Z`$QA(&-L879E('EA(&5X:7-T92!E;B!E
M;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RX`3FGQ;W,`2VER:6)A=&D`
M2V]L86(`0V]R96$L(%)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A(&1E
M`$-O<F5A+"!297#Z8FQI8V$@9&4`0V]R96%N;R`H155#+4M2*0!+=7=A:70`
M2WER9WEZ<W1A;@!?1&ES=')I8G5C:?-N`$ED:6]M80!,86\L(%)E</IB;&EC
M82!$96UO8W+A=&EC82!0;W!U;&%R`$-U87)T;R!M96YG=6%N=&4`0W5A<G1O
M(&UE;F=U86YT90#:;'1I;6$@86-T=6%L:7IA8VGS;CH`VFQT:6UA('-E<VGS
M;CH@)7,`VFQT:6UA('-E<VGS;CH@)7,@9&5S9&4@)7,`VFQT:6UA('-E<VGS
M;CH@3G5N8V$`3&%T=FEA`$QA=F%N9&$`3&5Y97,`1&ES=')I8G5C:?-N`$1E
M:F%R(&5N(&)L86YC;R!P87)A(&5L:6UI;F%R(&5L(&)O<F1E`$QE8F%N;VX`
M27IQ=6EE<F1A`$-A8F5C97)A(&EZ<75I97)D80!686QO<F5S(&1E(&QA(&EZ
M<75I97)D80!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY
M80!,:65C:'1E;G-T96EN`$%Z=6P@8VQA<F\`3&EG97)A(&QL;W9I>FYA`$QL
M=79I82!L:6=E<F$`3&QU=FEA("\@=FEE;G1O(&QI9V5R;W,`3&QU=FEA(&QI
M9V5R82!M871U=&EN80!,;'5V:6$@;&EG97)A('9E<W!E<G1I;F$`06=U86-E
M<F\@;&EG97)O`$QL=79I87,@>2!T<G5E;F]S`$YE=F%D82!S=6%V90!,:6=E
M<F\@86=U86-E<F\@9&4@;FEE=F4`0VAA<V-A<G)I;&QO`%;M;F-U;&\`16P@
M=NUN8W5L;R!A<'5N=&$@83H`5FEN8W5L87(@9&ER96-C:?-N(&1E(&-O<G)E
M;R!A(&QA('#A9VEN82!D92!C;VUP;W-I8VGS;B!A;"!M;W-T<F%R`%;M;F-U
M;&]S`$-O;VMI92!,:6YU>`!,:7-T87(@+2!E;"!U<W5A<FEO('!U961E(&5X
M86UI;F%R(&QA(&-A<G!E=&$`3&ES=&%R(&)A<V5S(&1E(&1A=&]S`$QI<W1A
M<B!T96UA<R!D92!A>75D80!,:7-T87(@=&%B;&%S`$QI<W0M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$5L(&QI<W1A9&\@9&4@=7-U87)I
M;W,@97-TX2!D97-H86)I;&ET861O+@!,:71E<F%T=7)A`$QI='5A;FEA`$QE
M>65N9&\@;&EB<F5R[6%S+BXN`$QE>65N9&\N+BX`2&]R82!L;V-A;#H@`$ED
M:6]M82!Y(&AO<F$`56)I8V%C:?-N`$EN:6-I87(@<V5S:?-N`$EN:6-I87(@
M<V5S:?-N(&5N("5S`%-A;&ER`%-A;&ER(&1E("5S`$EN:6-I87(@<V5S:?-N
M`%1A<F5A<R!D92!I;FEC:6\@9&4@<V5S:?-N`$9A;&SS(&5L(&EN:6-I;R!D
M92!S97-I\VX@<&]R<75E(&EN=')O9'5J;R!I;F-O<G)E8W1A;65N=&4@<W4@
M;F]M8G)E(&1E('5S=6%R:6\@;R!C;VYT<F%S9?%A+@!&86QL\R!E;"!I;FEC
M:6\@9&4@<V5S:?-N+@!386QI<@!497AT;R!C;VUP;&5T;P!!;6]R`$)A:F$`
M06QF86)E=&\@9W)I96=O(&5N(&UI;OIS8RX`06QF86)E=&\@;&%T:6YO(&5N
M(&UI;OIS8RX`3OIM97)O<R!R;VUA;F]S(&5N(&UI;OIS8RX`3&]Y;VQA`$%Z
M=6P@3&]Y;VQA`$QU>&5M8G5R9V\`34T`34]41`!%;"!A9&IU;G1O($U3+51.
M148@;F\@8V]N=&5N[6$@9&%T;W,N`$U31P!-86-A;P!-86-E9&]N:6$L($%N
M=&EG=6$@4F5P^F)L:6-A(%EU9V]S;&%V82!D90!-861A9V%S8V%R`$UA9VEA
M`$-O<G)E;P!!9&TN(&-O<G)E;P!#<F5A<B!?=NUN8W5L;RXN+@!!<V5G^G)E
M<V4@9&4@=&5N97(@:6YS=&%L861O(%!%05(@>2!D92!Q=64@97-TZ2!E;B!L
M82!V[6$@9&4@86-C97-O(&1E(&EN8VQU<VGS;BX`0W)E86YD;R!D:7)E8W1O
M<FEO("5S`$UA;&%W:0!-86QA<VEA`$UA;&1I=F%S`$UA;&D`36%L=&$`1V5S
M=&EO;F$@;&$@;&ES=&$@9&4@8V%T96=O<NUA<R!C;VX@;&$@<75E(&5T:7%U
M971A<B!E;&5M96YT;W,@>2!L;W,@8V]L;W)E<R!A<V]C:6%D;W,@82!D:6-H
M87,@8V%T96=O<NUA<RX`36%P82!M87`R-`!-87!A(&UA<'%U97-T`$UA<GIO
M`$UA<F=E;@!-87)C87(@8V]N(&QA<R!B86YD97)A<R!D92!,9>UD;R]3:6X@
M;&5E<@!-87)C87(@8V]N(&]T<F%R(&)A;F1E<F%S("AP+F4N($EM<&]R=&%N
M=&4O4F5S<&]N9&ED;RD`27-L87,@36%R<VAA;&P`36%R=&EN:6-A`$-A;7!O
M<R!C;VEN8VED96YT97,`36%U<FET86YI80!-875R:6-I;P!386QD;R!MX7AI
M;6\@<&5R;6ET:61O+@!392!H82!S;V)R97!A<V%D;R!E;"!N^FUE<F\@;>%X
M:6UO(&1E('!A<G1E<R!D92!M96YS86IE+@!496UP+B!MX7AI;6$@^FQT:6UA
M<R`R-"!H;W)A<SH@`%1E;7`N(&WA>&EM82#Z;'1I;6%S(#8@:&]R87,Z(`!,
M;VYG:71U9"!MX7AI;6$`36%Y;P!-87EO='1E`$UE9&EC:6YA`$%N=6QA8VGS
M;B!D92!R975N:?-N`$EN9F]R;6%C:?-N(&1E(')E=6YI\VX`4')O<'5E<W1A
M(&1E(')E=6YI\VX`4F5S<'5E<W1A(&$@<F5U;FGS;@!!8W1U86QI>F%C:?-N
M(&1E(')E=6YI\VX`4V]L:6-I='5D(&1E(&%C='5A;&EZ86-I\VX@9&4@<F5U
M;FGS;@!-:65M8G)O<P!&;W)M871O(&1E;"!M96[Z.@!#;VUB:6YA<B!C96QD
M87,`0V]M8FEN86YD;R!T;V1O<R!L;W,@87)C:&EV;W,@)7,N<&\@96X@96P@
M8V]M<&5N9&EO+BXN(`!#;VUB:6YA;F1O(&ED:6]M82`E<RXN+B``0V]M8FEN
M86YD;R!E;"!A<F-H:79O(%!/(&1E("5S(&5N(&5L(&-O;7!E;F1I;RXN+B``
M0V]M8FEN86YD;R!T<F%D=6-C:?-N(&1E;"!M\V1U;&\@)7,N+BX`365N<V%J
M90!392!H82!C;VUP<F]B861O(&-O<G)E8W1A;65N=&4@96P@;65N<V%J92!P
M97)O(&YO('-E('!U961E('9E<FEF:6-A<B!E;"!C97)T:69I8V%D;R!D96P@
M9FER;6%N=&4N`$UE;G-A:F4@8V%D=6-A9&\N`%1I<&\@9&4@;65N<V%J90!4
M:65M<&\@9&4@365T87(`0FQO<75E($UE=&%R(&YO(&1I<W!O;FEB;&4N`$)L
M;W%U92!-971A<B!N;R!D:7-P;VYI8FQE+B!392!H86X@<F5G:7-T<F%D;R!L
M;W,@9&5T86QL97,@<&%R82!E;"!A9&UI;FES=')A9&]R+@!-Z71O9&\`16P@
M;>ET;V1O("<E<R<@;F\@97-TX2!D969I;FED;P!-Z71R:6-O`$WI:FEC;P!-
M:6-R;VYE<VEA+"!%<W1A9&]S($9E9&5R861O<R!D90!%;B!M961I;P!4:7!O
M($UI;64`5&5M<"X@;>UN+B!L87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7`N
M(&WM;BX@;&%S(/IL=&EM87,@-B!H;W)A<SH@`%)E9FQE:F%R`$UI<V-E;.%N
M96$`4&%Q=65T92!014%2($A45%!?4F5Q=65S="!D97-A<&%R96-I9&\N`$9A
M;'1A(&QA(&-O;F9I9W5R86-I\VXN(%1I96YE('%U92!G96YE<F%R;&$@86AO
M<F$@<VD@9&5S96$@=71I;&EZ87(@97-T82!A<&QI8V%C:?-N+@!)1"!D92!M
M96YS86IE(&1E<V%P87)E8VED;RX`4&%Q=65T92!014%2($UA:6P@9&5S87!A
M<F5C:61O+@!)1"!D92!S97-I\VX@9&5S87!A<F5C:61O+@!,=6X`0V]R<F5O
M(&WS=FEL`$UO9&5R861O`%-E(&AA(&UO9&EF:6-A9&\@;&$@9F5C:&$`36]D
M:69I8V%R(%523`!-\V1U;&\`3?-D=6QO`$UO;&1A=FEA+"!297#Z8FQI8V$@
M9&4`3?-N86-O`$UO;F=O;&EA`$UE<R!Y(&'Q;P!-96YS=6%L;65N=&4`36]N
M='-E<G)A=`!&87-E<R!D92!L82!L=6YA`$UA<G)U96-O<P!&=6YD86UE;G1A
M;&UE;G1E(&1E<W!E:F%D;P!&=6YD86UE;G1A;&UE;G1E(&YU8F]S;P!&=6YD
M86UE;G1A;&UE;G1E('-O;&5A9&\`1&5S<&QA>F%R(&AA8VEA(&%B86IO`$1E
M<W!L87IA<B!A(&QA(&EZ<75I97)D80!$97-P;&%Z87(@82!L82!D97)E8VAA
M`$1E<W!L87IA<B!H86-I82!A<G)I8F$`1&5S<&QA>F%R(&AA8VEA(&%B86IO
M`$1E<W!L87IA<B!H86-I82!A<G)I8F$`36]Z86UB:7%U90!-;WII;&QA`$QI
M<W1A<R!D97-P;&5G86)L97,@;75L=&DM;FEV96P`4V5L96-C:?-N(&WZ;'1I
M<&QE`$ED96YT:61A9`!-:2!P;W)T86P`1&ES=')I8G5C:?-N(&1E(&UI('!O
M<G1A;`!->6%N;6%R`$Y/+"!.3R!E<W1O>2!D92!A8W5E<F1O`$YO;6)R90!.
M86UI8FEA`$YA=7)U`$YE6%0`4V4@;F5C97-I=&$@=6YA(&%C8VGS;@!.97!A
M;`!(;VQA;F1A`$%N=&EL;&%S($AO;&%N9&5S87,`55),(&)A<V4@9&4@3F5T
M<V-A<&4`55),(&1E(&%N=6QA8VGS;B!D92!#02!D92!.971S8V%P90!54DP@
M9&4@<&]L[71I8V%S(&1E($-!(&1E($YE='-C87!E`%523"!D92!R96YO=F%C
M:?-N(&1E($YE='-C87!E`%523"!D92!A;G5L86-I\VX@9&4@3F5T<V-A<&4`
M3F]M8G)E(&1E('-E<G9I9&]R(%-33"!D92!.971S8V%P90!#;VUE;G1A<FEO
M(&1E;"!C97)T:69I8V%D;R!D92!.971S8V%P90!4:7!O(&1E(&-E<G1I9FEC
M861O(&1E($YE='-C87!E`%)E9`!.=6YC80!.=65V82!#86QE9&]N:6$`3G5E
M=F$@8V%T96=O<NUA`$QU;F$@;G5E=F$`3G5E=F\@;F]M8G)E(&1E('5S=6%R
M:6\@*&]P8VEO;F%L*0!.=65V82!:96QA;F1A`$YU979A(&-O;G1R87-E\6$Z
M`$YU979A('9E;G1A;F$@*%]B;&%N:RD`3F]T:6-I87,`1RX@9&4@;F]T:6-I
M87,`4VEG=6EE;G1E`%!R\WAI;6$@<.%G:6YA`%!R\WAI;6$@9F%S90!/<&-I
M;VYE<R!S:6=U:65N=&5S`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YO8VAE
M`$YI=64`3F\`3F\@:&%Y(&1A=&]S(&1E(&-O;F9I9W5R86-I\VX@<&%R82!M
M;W-T<F%R(&1I9F5R96YC:6%S+@!.;R!S92!D:7-P;VYE(&1E(&5S=')A=&5G
M:6$@9&4@96QA8F]R86-I\VX@9&4@:6WA9V5N97,@25-/+@!.;R!H87D@<&QA
M;G1I;&QA(&1E(&QO=&5S`$YO(&AA>2!B;&]Q=65S(&5N(&QA('!O<VEC:?-N
M(&EN9&EC861A`$YO('-E(&AA(&EN=')O9'5C:61O('5N(&YO;6)R92!D92!A
M9V5N9&$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@34-!3"X`4VEN(&-A;6)I
M;W,N`$YO('-E('!U961E;B!A\6%D:7(@<')I=FEL96=I;W,@9&5S8V5N9&EE
M;G1E<R!P;W(@9&5B86IO(&1E(&5S=&4@;FEV96PN`$YO('-E('!U961E;B!A
M\6%D:7(@9&5S8V5N9&EE;G1E<R!A(&5S=&4@<')I=FEL96=I;RX`3F\@<V4@
M:&$@97-P96-I9FEC861O('5N(&-O;6%N9&\N`$YO('-E(&AA(&5S<&5C:69I
M8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@)7,N`$YO
M('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C
M:?-N('!A<F$@5D93('!O<B!&5%`N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I
M;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!344PN
M`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U
M<F%C:?-N('!A<F$@5D93('!O<B!A<F-H:79O(%-13"X`3F\@<75E9&$@<V%L
M9&\N`$YO('-E(&AA(&EN=')O9'5C:61O(&5L(&1E<W1I;F\N`$5N(&5L(&%R
M8VAI=F\@9&4@87EU9&$@;W)I9VEN86P@;F\@97AI<W1E(&YI;F=U;F$@96YT
M<F%D82!C;VX@96P@:60@)R5S)RX`3F\@<V4@:&$@8V%R9V%D;R!N:6YG^FX@
M87)C:&EV;P!.;R!S92!H82!E<W!E8VEF:6-A9&\@96P@:61I;VUA+@!.;R!S
M92!H82!D969I;FED;R!L82!U8FEC86-I\VXN`$YO('-E(&AA(&EN=')O9'5C
M:61O('5N(&UE;G-A:F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N;VUB
M<F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N^FUE<F\N`$YO(&]F96YS
M:79A<P!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A
M(&QA(&%U=&5N=&EF:6-A8VGS;B!(5%10+@!.;R!S92!H82!I;G1R;V1U8VED
M;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!)34%0
M+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA
M(&%U=&5N=&EF:6-A8VGS;B!+97)B97)O<RX`3F\@<V4@:&$@:6YT<F]D=6-I
M9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@3$1!
M4"X`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L
M82!A=71E;G1I9FEC86-I\VX@9&4@:6YI8VEO+@!.;R!S92!H82!I;G1R;V1U
M8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!0
M05-35T0N`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A
M<F$@;&$@875T96YT:69I8V%C:?-N(%--0BX`3F\@<V4@:&$@:6YD:6-A9&\@
M=NUA(&1E(&%C8V5S;R!A(&QO<R!B:6YA<FEO<R!/<&5N4U-,+B!087)A('1R
M86)A:F%R(&-O;B!D871O<R!02T-3(#$R(&AA8V5N(&9A;'1A(&QO<R!B:6YA
M<FEO<R!/<&5N4U-,+@!3:6X@86QT87,@<&5N9&EE;G1E<RX`4VEN(')A>6%S
M`$YI;F=U;F\`3F\@<V4@96YC;VYT<O,@96P@;6]T;W(@)R5S)RX`3F\@<V4@
M9&ES<&]N92!D92!U;B!D:7)E8W1O<FEO(&1E(&%L;6%C96YA;6EE;G1O('1E
M;7!O<F%L+@!.;R!S92!H82!E;G9I861O(&5L(&YO;6)R92!D92!U<W5A<FEO
M('DO;R!L82!C;VYT<F%S9?%A+@!.;R!S92!H86X@9&5V=65L=&\@9&%T;W,@
M6$U,(';A;&ED;W,`4VEN('9A;&]R97,`3F\@<V4@96YC;VYT<O,@;&$@=F5R
M<VGS;B!E;B!L82!C;VYF:6=U<F%C:?-N(&]R:6=I;F%L+B!296=E;F5R87(@
M;&$@8V]N9FEG=7)A8VGS;BX`3F\@<V4@96YC;VYT<O,@;&$@=F5R<VGS;B!E
M;B!L82!C;VYF:6=U<F%C:?-N+B!296=E;F5R87(@;&$@8V]N9FEG=7)A8VGS
M;BX`4VEN('!A<G1I8VEP86YT97,`3FEN9W5N80!.:6YG=6YO("AU<V\@:6UP
M;.UC:71O*0!.\W)D:6-O("A)4T\M.#@U.2TQ,"D`27-L82!D92!.;W)F;VQK
M`$AE;6ES9F5R:6\@;F]R=&4`27-L87,@36%R:6%N87,@9&5L($YO<G1E`$YO
M<G5E9V$`3F\@9&5S<'7I<P!.;R!A;G1E<P!.;R!E<R!U;B!D:7)E8W1O<FEO
M`%-I;B!D97-A<G)O;&QA<BX`4VEN(&5S=&%B;&5C97(`3F\@97-TX2!S;W!O
M<G1A9&\N`$YO=&%S`$YO(&AA>2!N861A('9I<W5A;&EZ86)L92P@<F5T<F]C
M961A+@!!=FES;P!.;W9I96UB<F4`3OIM97)O`$[Z;65R;R!D92!C87)A8W1E
M<F5S`$[Z;65R;R!D92!C;VQU;6YA<P!.^FUE<F\@9&4@9FEL87,`3F\@<V4@
M:&%N(&5S<&5C:69I8V%D;R!N^FUE<F]S(&$@86-T=6%L:7IA<B!E;B!L82!L
M:7-T82!D92!D:7-T<FEB=6-I\VXN`$%C97!T87(`3V)J971O`$-R96%D;W(@
M9&4@;V)J971O<P!0<FEV:6QE9VEO<R!D92!C<F5A9&]R(&1E(&]B:F5T;P!/
M8W1A;`!/8W1U8G)E`$9I;'1R87(@;V9E;G-A<P!/9FEC:6YA`$%N=&EG=6$@
M8V]N=')A<V7Q83H`3VWA;@!3\VQO(&QO<R!S97)V:61O<F5S($E-05`@<V]P
M;W)T86X@;&%S(&-A<G!E=&%S(&-O;7!A<G1I9&%S+@!3\VQO(&]F96YS:79A
M<P!3\VQO('-E('!E<FUI=&4@=6YA(&1I<F5C8VGS;B!D92!C;W)R96\N`%/S
M;&\@96P@<')O<&EE=&%R:6\@;R!U;B!A9&UI;FES=')A9&]R(&1E('-I<W1E
M;6%S('!U961E(&-A;6)I87(@;&$@<')O<&EE9&%D(&\@;&]S('!R:79I;&5G
M:6]S(&1E('!R;W!I971A<FEO(&1E('5N(')E8W5R<V\@8V]M<&%R=&ED;P!!
M8G)I<B!E;B!U;F$@;G5E=F$@=F5N=&%N80!%<G)O<B!/<&5N4U-,.B!.;R!S
M92!P=65D96X@97AT<F%E<B!D871O<R!D92!L82!P87)T92!3+TU)344@9FER
M;6%D82X`06)R:7(@97-T92!V[6YC=6QO(&5N('5N82!V96YT86YA(&YU979A
M`%-I<W1E;6$@;W!E<F%T:79O`%!A<G1I8VEP86YT92!O<&-I;VYA;`!/<&-I
M;VYE<P!/<&-I;VYE<R!D92`E<P!/<&-I;VYE<SH`3&ES=&$@;W)D96YA9&$`
M3W)G86YI>F%C:?-N`%5N:61A9"!O<F=A;FEZ871I=F$`3W)G86YI>F%C:?-N
M`%!L86YT:6QL82!D92!A<&QI8V%C:?-N(&]R:6=I;F%L`%!L86YT:6QL87,@
M;W)I9VEN86QE<R!E;B`E<SH`3W1R;P!/=')A(&EN9F]R;6%C:?-N`%!R:79I
M;&5G:6]S(&1E;"!P<F]P:65T87)I;P!,82!A=71E;G1I9FEC86-I\VX@4$%-
M(&YO(&5S=.$@9&ES<&]N:6)L92X`1FER;6$@9&EG:71A;"!01U``1&%T;W,@
M8VEF<F%D;W,@8V]N(%!'4`!#;&%V92!01U`@</IB;&EC80!$871O<R!F:7)M
M861O<R]C:69R861O<R!C;VX@4$=0`$/S9&EG;R!02%``26YTZ7)P<BX@4$A0
M`$QL=79I82!L:6=E<F$@9&4@=&%R9&4`0VAA<&%R<F]N97,@9&4@=&%R9&4`
M0F]R<F%S8V%S(&1E('1A<F1E`$EN=.ER<'(N(%!?2%``36%R9V5N`%!A:VES
M=.%N`%!A;&%U`%!A;&5S=&EN;W,L(%1E<G)I=&]R:6]S($]C=7!A9&]S`%!A
M;F%MX0!087#Z82!.=65V82!'=6EN96$`4&%R86=U87D`4&%R8VEA;&UE;G1E
M(&YU8F]S;P!087-S=V0@;F\@97-TX2!B:65N(&-O;F9I9W5R861O+@!#;VYT
M<F%S9?%A`%-E(&AA(&-A;6)I861O(&QA(&-O;G1R87-E\6$@96X@)7,N`$-O
M;G1R87-E\6$@:6YC;W)R96-T80!%;"!M\V1U;&\@9&4@8V]N=')A<V7Q87,@
M;F\@97-TX2!B:65N(&-O;F9I9W5R861O`$5L(&WS9'5L;R!D92!C;VYT<F%S
M9?%A<R!N;R!E<W3A(&)I96X@8V]N9FEG=7)A9&\N`$AA>2!Q=64@:6YT<F]D
M=6-I<B!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!2
M041)55,N`$-O;G1R87-E\6$@8V]N(&-O;F9I<FUA8VGS;@!#;VYT<F%S9?%A
M.@!#;VYT<F%S9?%A.B``3&%S(&-O;G1R87-E\6%S('1I96YE;B!Q=64@8V]I
M;F-I9&ER+@!096=A<@!096=A<B!D96P@<&]R=&%P87!E;&5S`%;M80!!;'1A
M<R!P96YD:65N=&5S.@!'96YT90!0;W)C96YT86IE`%)E86QI>F%R(&]P97)A
M8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\`OU)E86QI>F%R(&]P97)A8VEO;F5S
M(&1E(&UA;G1E;FEM:65N=&\@86P@:6YI8VEA<B!S97-I\VX_`%!R:79I;&5G
M:6\`3F\@<V4@:&$@96QI;6EN861O(&5L('!R:79I;&5G:6\@)R5S)RX`061M
M:6YI<W1R86-I\VX@9&4@<')I=FEL96=I;W,`4')I=FEL96=I;W,`26YF;W)M
M86-I\VX@<&5R<V]N86P`4&5R^@!-87-C;W1A<P!&:6QI<&EN87,`5&5LZ69O
M;F\`1F]T;V=R86;M87,`4&ET8V%I<FX`4.UX96QE<P!4\W!I8V]S`%!U;'-E
M(&5N('5N82!C96QD80!#;VYF:7)M92!Q=64@9&5S96$@96QI;6EN87(@97-T
M92!E;&5M96YT;SH`0V]N9FER;64@<75E(&1E<V5A(&5L:6UI;F%R(&5L(';M
M;F-U;&\@82!E<W1E(&5L96UE;G1O+@!);G1R;V1U>F-A('5N(&UE<R!Y('5N
M(&'Q;RX`26YT<F]D=7IC82!E;"!N;VUB<F4@9&4@;&$@;G5E=F$@8V%T96=O
M<NUA.@!);G1R;V1U>F-A('5N82!D:7)E8V-I\VX@25`@=N%L:61A+@!);G1R
M;V1U>F-A('5N82!F96-H82!VX6QI9&$L(&-O;7!R=65B92!E;"!N^FUE<F\@
M9&4@9.UA<R!D96P@;65S+@!);G1R;V1U>F-A('5N82!H;W)A(';A;&ED82X`
M4')O<&]R8VEO;F4@=6X@<F5S=6UE;B!D96P@<')O8FQE;6$N`$EN=')O9'5Z
M8V$@<W4@;F]M8G)E(&1E('5S=6%R:6\@>2!C;VYT<F%S9?%A+@!,96$@96P@
M=&5X=&\@<VEG=6EE;G1E+B!$14)%(&%C97!T87(@;&]S('3I<FUI;F]S('-I
M('%U:65R92!U<V%R(&5L('-I<W1E;6$N`$EN9F]R;64@9&4@8W5A;'%U:65R
M(&9A;&QO(&$@:3$X;D!L:7-T<RYH;W)D92YO<F<N`$QE82!C;VX@871E;F-I
M\VX@;&$@:6YF;W)M86-I\VX@<VEG=6EE;G1E('D@<V5L96-C:6]N92!U;F$@
M86-C:?-N(&1E;"!M96[Z(&1E(&1E8F%J;RX`4V5L96-C:6]N92!U;F$@86-C
M:?-N(&1E;"!M96[Z(&1E(&1E8F%J;RX`26YT<F]D=7IC82!E;"!N=65V;R!N
M;VUB<F4@9&4@8V%T96=O<NUA.@!0;VQO;FEA`%!O;.UT:6-A`$5N8W5E<W1A
M<P!0;W)T=6=A;`!0;W-I8VGS;B!D92!L82!I;6%G96X`4&]S:6-I\VX@9&4@
M;&$@=&%B;&$`16YV:6%R(&$@97-T82!C87)P971A("AN;R!O8FQI9V%D;R!P
M;W(@24U!4"D`4&]S=&YU:V4`4')E8VEP:71A8VEO;F5S(&1E(&QA*',I(/IL
M=&EM82AS*2`E<R!H;W)A*',I.B``4')E9G-?;&1A<#H@;F\@<V4@96YC;VYT
M<O,@;&$@97AT96YS:?-N($Q$05`@<F5Q=65R:61A+@!0<F5F<U]S97-S:6]N
M.B!N;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@9&4@<V5S:?-N(')E<75E
M<FED82X`4')E<V5N=&%C+@!0<F5S:?-N`%!R97-I\VX@86P@;FEV96P@9&5L
M(&UA<CH@`%!R97-I\VXZ(`!6:7-T82!P<F5V:6$`5FES=&$@<')E=FEA(&1E
M(&QA(&EM86=E;B!E;B!U;F$@;G5E=F$@=F5N=&%N80!0X6=I;F$@86YT97)I
M;W(`3W!C:6]N97,@86YT97)I;W)E<P!);7!R:6UI<B!D;V-U;65N=&\`0VQA
M=F4@<')I=F%D80"_4')O8FQE;6%S/P!$97-C<FEP8VGS;B!D96P@<')O8FQE
M;6$`4')O>65C=&]S`%1E>'1O(&1E;"!I;F1U8W1O<@!#;&%V92!01U`@</IB
M;&EC80!!;&=O<FET;6\@9&4@8VQA=F4@</IB;&EC80!.;R!S92!G96YE<F%R
M;VX@8V]R<F5C=&%M96YT92!L87,@8VQA=F5S(%#Z8FQI8V$O4')I=F%D82X`
M4'5E<G1O(%)I8V\`46%T87(`0V]N<W5L=&$`0VQA=F4@4E-!('#Z8FQI8V$@
M*"5D(&)I="D`0F]T\VX@9&4@;W!C:?-N`$QL=79I80!,;'5V:6$@+R!.:65V
M90!,;'5V:6$@+R!#:&%P87)R;VYE<P!,;'5V:6$@;6%T=71I;F$`3&QU=FEA
M('9E<W!E<G1I;F$`06=U86-E<F\`4G5E9&$@9&4@;&$@9F]R='5N80!287KS
M;@`F;F)S<#M,965R)FYB<W`[`$QE97(@;65N<V%J97,`OT5L:6UI;F%R(')E
M86QM96YT92`E<S\@17-T82!O<&5R86-I\VX@;F\@<V4@<'5E9&4@9&5S:&%C
M97(N`+]%;&EM:6YA<B!R96%L;65N=&4@;&]S(&1A=&]S(&1E;"!U<W5A<FEO
M("5S/R!%<W1A(&]P97)A8VGS;B!N;R!S92!P=65D92!D97-H86-E<BX`5G5E
M;'9E(&$@<F5A;&EZ87(@;&$@^FQT:6UA(&%C8VGS;@!2969R97-C87(@96QE
M;65N=&]S(&1E(&UE;OH@9&ENX6UI8V]S.@!!8W1U86QI>F%R('9I<W1A(&1E
M;"!P;W)T86P`4F5G97@`3F%V96=A9&]R(&1E(')E;&%C:6]N97,`3V)S97)V
M86-I;VYE<P!296-O<F1A<B!L82!I;F9O<FUA8VGS;B!D92!T:65M<&\@9&ES
M<&]N:6)L92X`4V5R=FED;W)E<R!R96UO=&]S`%523"!R96UO=&$@*&AT='`Z
M+R]W=W<N96IE;7!L;RYC;VTO:&]R9&4I.@!1=6ET87(`475I=&%R(&)L;W%U
M90!1=6ET87(@8V]L=6UN80!%;&EM:6YA<B!F;W)M871O`%%U:71A<B!D92!M
M:2!A9V5N9&$`475I=&%R('!A<@!%;&EM:6YA<B!G=6GS;B!G=6%R9&%D;R!D
M96P@9&ER96-T;W)I;R!T96UP;W)A;"!D96P@<V5R=FED;W(N`$5L:6UI;F%R
M(`!%;&EM:6YA<B!E<W1E(&YO9&\@9&5L(&1O8W5M96YT;P!%;&EM:6YA<B!U
M<W5A<FEO`$5L:6UI;F%R('5S=6%R:6\Z("5S`%)E<W!U97-T82!E;G9I861A
M+@!297-P;VYD97(@8V]N('5N(&UE;G-A:F4@;F\@<V]P;W)T861O`%)E<W!O
M;F1E<B!C;VX@96P@=&EE;7!O(&1I<W!O;FEB;&4@9'5R86YT92!L;W,@<'+S
M>&EM;W,@,B!M97-E<RX`4F5S<&]N9&5R(&-O;B!L82!I;F9O<FUA8VGS;B!D
M92!T:65M<&\@9&ES<&]N:6)L92!P961I9&$N`%)E<W!O;F1E<CH@)7,`3F\@
M<V4@<'5E9&4@<F5S<&]N9&5R(&$@;&$@<V]L:6-I='5D+B!#\V1I9V\@9&4@
M97)R;W(@9&5V=65L=&\Z(`!.;R!S92!H82!E<W!E8VEF:6-A9&\@96P@)R5S
M)R!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A8VGS;B!D92`E<RX`3F\@<V4@
M:&$@97-P96-I9FEC861O(&5L("<E<R<@<F5Q=65R:61O(&5N(&QA(&-O;F9I
M9W5R86-I\VX@9&4@5D93+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@96P@)R5S
M)R!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A8VGS;BX`3&]S("=C;VYT<F]L
M861O<F5S)R!R97%U97)I9&]S(&5S=.%N(&1E<V-O;F9I9W5R861O<R!E;B!L
M82!C;VYF:6=U<F%C:?-N(&1E(%)E9&%C8VGS;BX`3F\@<V4@:&$@97-P96-I
M9FEC861O(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@4&%S<W=D(%-13"!E;"`G
M<&AP='EP92<@<F5Q=65R:61O+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@96X@
M;&$@8V]N9FEG=7)A8VGS;B!D92!344P@96P@)W!H<'1Y<&4G(')E<75E<FED
M;RX`4&%R=&EC:7!A;G1E(')E<75E<FED;P!,:6UP:6%R`$QI;7!I87(@8V]N
M=')A<V7Q80!,:6UP:6%R(&-O;G1R87-E\6$`4F5S=6QT861O<P!297-U;'1A
M9&]S("AI;F-L=6ED;R!(;W)D92DZ`%)E<W5L=&%D;W,Z`%)E9W)E<V%R(&$@
M;W!C:6]N97,`4F5U;FGS;@!297-T875R87(@8V]N9FEG=7)A8VGS;@!/<&-I
M;VYE<R!D92!E9&EC:?-N(&1E('1E>'1O(&5N<FEQ=65C:61O`$-R:6)A<P!$
M97)E8VAA`$-A8F5C97)A(&1E<F5C:&$`5F%L;W)E<R!D92!L82!D97)E8VAA
M`%!R;W!I961A9&5S(&1E(%]F:6QA+BXN`$9U;F-I\VX`4G5M86[M80!':7)A
M<B`Q.#``1VER87(@82!L82!I>G%U:65R9&$`1VER87(@82!L82!D97)E8VAA
M`%!R;W!I961A9&5S(&1E(&9I;&$`4')O<&EE9&%D97,@9&4@9FEL80!&:6QA
M<SH`4F%Y87,`07!A<F5C97+A;B!R87EA<R!E;G1R92!T;V1A<R!L87,@9FEL
M87,@>2!C;VQU;6YA<P!!<&%R96-E<N%N(')A>6%S('/S;&\@96YT<F4@;&%S
M(&-O;'5M;F%S`$%P87)E8V5RX6X@<F%Y87,@<_-L;R!E;G1R92!L87,@9FEL
M87,`16IE8W5T87(`1F5D97)A8VGS;B!2=7-A`%)U86YD80!&:7)M82!C<FEP
M=&]G<N%F:6-A(%,O34E-10!-96YS86IE(&-I9G)A9&\@96X@4R]-24U%`$1A
M=&]S(&9I<FUA9&]S+V-I9G)A9&]S(&-O;B!3+TU)344`3F\@97-TX2!D:7-P
M;VYI8FQE(&QA(&%U=&5N=&EF:6-A8VGS;B!305-,+@!-96YS+B!335,`26YT
MZ7)P<BX@4U%,`%-3`%-32`#)6$E43P!);G3I<G!R+B!37U%,`%-A8@!386YT
M82!(96QE;F$`4V%I;G0@2VET=',@>2!.979I<P!386YT82!,=6/M80!386EN
M="!0:65R<F4@>2!-:7%U96QO;@!386X@5FEC96YT92!Y($=R86YA9&EN87,`
M36ES;6\@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;G1O(%1O
M;>%S('D@4'+M;F-I<&4`4')O=F5E9&]R(&1E('-A=.EL:71E`$%R86)I82!3
M875D:71A`$=U87)D87(`1W5A<F1A<B`E<P!'=6%R9&%R("<E<R<`1W5A<F1A
M<B!O<&-I;VYE<P!'=6%R9&%R(&QA(&-O;F9I9W5R86-I\VX@9V5N97)A9&$@
M8V]M;R!U;B!G=6GS;B!02%`@96X@96P@9&ER96-T;W)I;R!T96UP;W)A;"!D
M92!S=2!S97)V:61O<BX`4V4@:&$@9W5A<F1A9&\@;&$@8V]N9FEG=7)A8VGS
M;B!D92`E<RX`1W5A<F1A<B!G=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E(&QA
M(&-O;F9I9W5R86-I\VX@96XZ("<E<R<N`$-I96YC:6$`0G5S8V%R`$TN(&+Z
M<W%U961A`$)U<V-A;F1O(&%P;&EC86-I;VYE<R!D92!(;W)D92!E;B`E<P!"
M=7-C86YD;R!B:6YA<FEO<R!G971T97AT+BXN`%-E;&5C8VEO;F%R(&%R8VAI
M=F]S`%-E;&5C8VEO;F4@=6YA(&9E8VAA`%-E;&5C8VEO;F4@96P@9W)U<&\@
M82!A\6%D:7(`4V5L96-C:6]N92!U;B!N=65V;R!P<F]P:65T87)I;P!396QE
M8V-I;VYE('5N('-E<G9I9&]R`%-E;&5C8VEO;F4@96P@=7-U87)I;R!A(&'Q
M861I<@!396QE8V-I;VYE('1O9&]S(&QO<R!C;VUP;VYE;G1E<R!D92!L82!F
M96-H82X`4V5L96-C:6]N87(@=6X@;V)J971O`%-E;&5C8VEO;F4@;&]S(&-A
M<N%C=&5R97,@<75E(&YE8V5S:71E(&1E(&QA<R!C87-I;&QA<R!D92!A8F%J
M;RX@4'5E9&4@8V]P:6%R;&]S('D@<&5G87)L;W,@9&5L(.%R96$@9&4@=&5X
M=&\N`%-E;&5C8VEO;F4@96P@9&5L:6UI=&%D;W(@9&4@9F5C:&%S.@!396QE
M8V-I;VYE(&5L(&9O<FUA=&\@9&4@9F5C:&%S.@!396QE8V-I;VYE(&QA(&ED
M96YT:61A9"!Q=64@<75I97)A(&-A;6)I87(Z`%-E;&5C8VEO;F4@96P@9&5L
M:6UI=&%D;W(@9&4@:&]R87,Z`%-E;&5C8VEO;F4@96P@9F]R;6%T;R!D92!H
M;W)A<SH`4V5L96-C:6]N92!D;W,@8V%M<&]S(&-O:6YC:61E;G1E<RX`4V5L
M96-C:6]N92!S=2!C;VUB:6YA8VGS;B!D92!C;VQO<F5S+@!396QE8V-I;VYE
M('-U(&ED:6]M82!P<F5F97)I9&\Z`$5N=FEA<B!I;F9O<FUA8VGS;B!A8W1U
M86QI>F%D80!%;G9I87(@:6YF;W)M92!D92!P<F]B;&5M87,`16YV:6%R(%--
M4P!396YE9V%L`%-E;G-O<CH@`%-E<'1I96UB<F4`4V5R8FEA('D@36]N=&5N
M96=R;P!.^FUE<F\@9&4@<V5R:64`2&$@8V%D=6-A9&\@96P@240@9&4@<V5S
M:?-N+@!%<W1A8FQE8V5R`$5S=&%B;&5C92!O<&-I;VYE<R!Q=64@;&4@<&5R
M;6ET96X@<F5A:G5S=&%R('-U(&-O;G1R87-E\6$@<VD@;&QE9V%R82!A(&]L
M=FED87)L82X`0V]N9FEG=7)A('-E<G9I9&]R97,@<F5M;W1O<R!A(&QO<R!Q
M=64@9&5S964@86-C961E<B!D97-D92!E;"!P;W)T86PN`$1E9FEN92!L87,@
M;W!C:6]N97,@<')E9F5R:61A<R!D92!I9&EO;6$L('IO;F$@:&]R87)I82!Y
M(&9E8VAA<RX`1&5F:6YE(&QA(&%P;&EC86-I\VX@9&4@:6YI8VEO+"!L82!C
M;VUB:6YA8VGS;B!D92!C;VQO<F5S+"!L82!A8W1U86QI>F%C:?-N(&1E('#A
M9VEN82!Y(&]T<F%S(&]P8VEO;F5S(&1E('9I<W5A;&EZ86-I\VXN`$AA>2!G
M=6EO;F5S(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS;@!6
M87)I87,@=6)I8V%C:6]N97,@9&ES<&]N:6)L97,@8V]N(&5L('!A<N%M971R
M;SH@`%-E>6-H96QL97,`0V]M<')A<P!297-U;65N(&-O<G1O`+]$969I;FER
M(&-L879E<R!D92!A8V-E<V\@<&%R82!L82!M87EO<NUA(&1E(&QO<R!V[6YC
M=6QO<S\`)FYB<W`[36]S=')A<B9N8G-P.P!-=65S=')A(&QA<R!D:69E<F5N
M8VEA<R!E;G1R92!L82!N=65V82!C;VYF:6=U<F%C:?-N('D@;&$@86QM86-E
M;F%D80"_36]S=')A<B!H;W)A(&1E(&QA(/IL=&EM82!S97-I\VX@86P@:6YI
M8VEA<C\`36]S=')A<B!O<&-I\VX@9&4@8V]N<V5R=F%R(&5L(&]R:6=I;F%L
M`$UO<W1R87(@<V5L96-T;W(`OTUO<W1R87(@;&$@8F%R<F$@9&4@;65N^B!D
M92!O<&5R86-I;VYE<R!D92!T86)L83\`OTUO<W1R87(@96P@;65N^B`E<R!A
M(&QA(&EZ<75I97)D83\`375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A
M9&5S(&1E(&-E;&1A(&1E('1A8FQA`$UU97-T<F$@96P@9&GA;&]G;R!D92!P
M<F]P:65D861E<R!D92!T86)L80!-=65S=')A(&5L(&1IX6QO9V\@9&4@<')O
M<&EE9&%D97,@9&4@9FEL82!D92!T86)L80!-=65S=')A(&5L(&1IX6QO9V\@
M9&4@<')O<&EE9&%D97,@9&4@:6UA9V5N`$UO<W1R87(@8V%R9V$`06=U86-E
M<F]S`$%G=6%C97)O<R`O(%9I96YT;P!,;'5V:6%S(&UA='5T:6YA<P!,;'5V
M:6%S('9E<W!E<G1I;F%S`%)E9'5C:7(`4')I;65R;R!R961U>F-A(&\@<75I
M=&4@9&4@96YM961I;R!L;W,@8FQO<75E<R!C97)C86YO<P!3:65R<F$@3&5O
M;F$`06QT80!3;VQI8VET87(@86QT82!S:2!N;R!E<W3A(')E9VES=')A9&\`
M1FER;6$`06QG;W)I=&UO(&1E(&9I<FUA`%-I;7!L97@`4VEN9V%P=7(`5&%M
M8?%O`$]M:71I<B!M86YT96YI;6EE;G1O`$]M:71I9&\N+BX`17-L;W9A<75I
M80!%<VQO=F5N:6$`3FEE=F4`06=U86-E<F\@9&4@;FEE=F4`06=U86-E<F\@
M9&4@;FEE=F4`06=U86-E<F\@9&4@;FEE=F4@=F5S<&5R=&EN;P!%<W!E<V]R
M(&1E(&QA(&YI979E.B``17%U:79A;&5N=&4@9&4@;&$@;FEE=F4@96X@86=U
M83H@`$ES;&%S(%-A;&]M\VX`4V]M86QI80!#86YC:6]N97,@)B!0;V5M87,`
M4V5L96-C:?-N(&1E;"!S96YT:61O(&1E(&QA(&-L87-I9FEC86-I\VX`4F5M
M:71E;G1E`%-U9.%F<FEC80!%=7)O<&$@9&5L('-U<B`H25-/+3@X-3DM,RD`
M1V5O<F=I82!D96P@4W5R(&4@27-L87,@4V%N9'=I8V@@9&5L(%-U<@!(96UI
M<V9E<FEO('-U<@!%<W!A8VEA9&\@96YT<F4@8V5L9&%S(&%D>6%C96YT97,`
M17-P86-I861O(&5N=')E(&5L(&-O;G1E;FED;R!Y(&5L(&)O<F1E(&1E('5N
M82!C96QD80!397!A<F%D;W(`17-P86-I861O`$5S<&%C:6%D;R!Y(&UA<F=E
M;@!%<W!A\6$`4W!A;0!%<V-R:71U<F$@9&4@8V%R86-T97)E<R!E<W!E8VEA
M;&5S`$1I=FED:7(@8V5L9&$`1&EV:61I<B!C;VQU;6YA`$1I=FED:7(@9FEL
M80!$97!O<G1E<P!3<FD@3&%N:V$`17-TX6YD87(`4W1A<B!4<F5K`$5M<&EE
M>F$`0?%O(&1E(&EN:6-I;P!%<W1A9&\@;R!P<F]V:6YC:6$`17-T861O`$5S
M=&%D;R!D96P@:61I;VUA("5S+BXN(`!&;W)M871O(&1E(&%L;6%C96YA;6EE
M;G1O`$1I<F5C8VGS;B!D92!L82!C86QL90!486-H861A`$QI<W1A(&1E(&-A
M9&5N87,`16QI;6EN87(@9&]M:6YI;R!D92!L82!D:7)E8V-I\VX`17-T:6QO
M(%M#4U-=`$1O;0!!<W5N=&\`26YF;W)M86-I\VX@9&4@8VQA=F4@</IB;&EC
M82!D96P@87-U;G1O`$5N=FEA<@!392!H82!E;G9I861O('5N82!S;VQI8VET
M=60@9&4@86QT82!D92`G)7,G(&5N(&5L('-I<W1E;6$N($YO('!O9'+A(&EN
M:6-I87(@<V5S:?-N(&AA<W1A('%U92!S92!H87EA(&%P<F]B861O(&QA('-O
M;&EC:71U9"X`4W5B[6YD:6-E`,EX:71O`%-E(&AA(&'Q861I9&\@8V]R<F5C
M=&%M96YT92`G)7,G(&%L('-I<W1E;6$N`%-E(&AA;B!E;&EM:6YA9&\@8V]R
M<F5C=&%M96YT92!L;W,@9&%T;W,@9&5L('5S=6%R:6\@)R5S)R!D96P@<VES
M=&5M82X`4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@)R5S)RX`4V4@
M:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@)R5S)R!D96P@<VES=&5M82X`
M4V4@:&$@<F5S=&%U<F%D;R!C;W)R96-T86UE;G1E(&QA(&-O;F9I9W5R86-I
M\VXN(%)E9G)E<W%U92!P87)A('9E<B!L;W,@8V%M8FEO<RX`4V4@:&$@9W5A
M<F1A9&\@8V]R<F5C=&%M96YT92!L82!C;W!I82`E<R!D92!L82!C;VYF:6=U
M<F%C:?-N+@!392!H82!G=6%R9&%D;R!C;W)R96-T86UE;G1A(&QA(&-O<&EA
M(&1E(&QA(&-O;F9I9W5R86-I\VXN`%-E(&AA(&%C='5A;&EZ861O(&-O<G)E
M8W1A;65N=&4@)R5S)P!392!H82!E<V-R:71O(&-O<G)E8W1A;65N=&4@)R5S
M)P!3=63A;@!297-U;65N`$%M86YE8V5R`$%T87)D96-E<@!3;VQE861O`$%M
M86YE8V5R`$%M86YE8V5R+T%T87)D96-E<@!!;6%N96-E<CH@`$%T87)D96-E
M<@!!=&%R9&5C97(Z(`!3=7!E<NUN9&EC90!3;W!O<G1E`%-U<FEN86T`07!E
M;&QI9&\`4W9A;&)A<F0@>2!*86X@36%Y96X`4W=A>FEL86YD:6$`4W5E8VEA
M`%-U:7IA`$5R<F]R(&1E('-I;G1A>&ES(&5N(&QO<R!TZ7)M:6YO<R!D92!B
M^G-Q=65D80!297#Z8FQI8V$@P7)A8F4@9&4@4VER:6$`0VAU8F%S8V\`0VAU
M8F%S8V]S`$%R8VAI=F\@5%-6`%1A8FQA`%!R;W!I961A9&5S(&1E('1A8FQA
M`%!R;W!I961A9&5S(&1E('1A8FQA`%1A:7?A;@!486EWX6XL(%!R;W9I;F-I
M82!D92!#:&EN80!487EI:VES=.%N`%1A;GIA;FEA+"!297#Z8FQI8V$@56YI
M9&$@9&4`1&5S=&EN;SH`5&%R96%S`%1E86P`3OIM97)O(&1E('1E;.EF;VYO
M`%1E;7!E<F%T=7)A(&1U<F%N=&4@;&$@^FQT:6UA(&AO<F$Z(`!496UP97)A
M='5R80!496UP97)A='5R83H@`$YO('-E(&5N8V]N='+S(&QA('!L86YT:6QL
M82`G)7,G+@!!9&UI;FES=')A8VGS;B!D92!P;&%N=&EL;&%S`$%C97!T87(@
M<&5T:6-I\VX@<')O=FES:6]N86QM96YT90!!8V5P=&%D82!P<F]V:7-I;VYA
M;&UE;G1E`%1E>'1O`%/S;&\@=&5X=&\`06QI;F5A8VGS;B!D92!T97AT;P!"
M;W)D92!S=7!E<FEO<B!D96P@=&5X=&\`2G5E`%1A:6QA;F3I<R`H5$E3+38R
M,"D`5&%I;&%N9&EA`$=R86-I87,@<&]R('5T:6QI>F%R(&5L('-I<W1E;6$N
M`$'Z;B!N;R!E>&ES=&4@96P@87)C:&EV;R!D92!A>75D82`E<R!D92`E<RX@
M0W)E86YD;R!U;F\@;G5E=F\N`%-E(&AA(&5L:6UI;F%D;V5L(';M;F-U;&\@
M)7,@82`E<RX`3F\@97-TX2!D:7-P;VYI8FQE(&QA(&5X=&5N<VGS;B!&5%`N
M`$5L(&UO=&]R(&1E(&EN=&5G<F%C:?-N($AO<F1E+TMO;&%B(&YO('-O<&]R
M=&$@(B5S(@!.;R!S92!H82!C87)G861O(&-O<G)E8W1A;65N=&4@;&$@8VQA
M<V4@36%I;G1E;F%N8V4Z.@!392!H82!C97)R861O(&QA('9E;G1A;F$@9&4@
M;W!C:6]N97,N(%-A;&EE;F1O+@!3:2!D97-E82!U=&EL:7IA<B!P97)M:7-O
M<RP@96P@861M:6YI<W1R861O<B!T:65N92!Q=64@8V]N9FEG=7)A<B!U;B!S
M;W!O<G1E(&1E('!E<FUI<V]S('!E<FUA;F5N=&4N`%/S;&\@96P@8F]R9&4@
M:6YF97)I;W(`3&]S(&1A=&]S(&1E(&QA(&%G96YD82!N;R!S;VX@=N%L:61O
M<P!%;"!)1"!D96P@8V]N=&%C=&\@;F\@<V4@97-P96-I9FEC\RP@<V4@9&5J
M\R!E;B!B;&%N8V\@;R!N;R!S92!E;F-O;G1R\R!E;B!L82!B87-E(&1E(&1A
M=&]S+@!392!H82!A\6%D:61O(&-O<G)E8W1A;65N=&4@96P@8V]N=&%C=&\@
M82!S=7,@9&ER96-C:6]N97,N`%!A<F$@8V]M<')O8F%R(&5L(&UE;G-A:F4@
M9FER;6%D;R!H86-E(&9A;'1A(&5L(&)L;W%U92!D92!F:7)M82!S97!A<F%D
M;RX`16P@240@9&4@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N(&YO('-E(&5S
M<&5C:69I8_,L('-E(&1E:O,@96X@8FQA;F-O(&\@;F\@<V4@96YC;VYT<O,@
M96X@;&$@8F%S92!D92!D871O<RX`3F\@<V4@97-P96-I9FEC\R!L82!L:7-T
M82!D92!D:7-T<FEB=6-I\VXN`$QA<R!C87)A8W1E<NUS=&EC87,@9&4@8VEF
M<F%D;R!N96-E<VET86X@=6YA(&-O;F5X:?-N('=E8B!S96=U<F$N`%-E(&AA
M(&'Q861I9&\@96P@86-O;G1E8VEM:65N=&\@82!S=2!A9V5N9&$N`$5L(&%R
M8VAI=F\@)7,@=&5N9'+M82!Q=64@8V]N=&5N97(@=6YA(&]P8VGS;B`E<RX`
M16P@87)C:&EV;R`E<R!T96YD<NUA('%U92!C;VYT96YE<B!A;&=U;F%S(&]P
M8VEO;F5S("5S+@!.;R!S92!P=65D92!C;W!I87(@96P@87)C:&EV;R!S;V)R
M92!S[2!M:7-M;RX`16P@87)C:&EV;R!N;R!C;VYT:65N92!D871O<RX`02!C
M;VYT:6YU86-I\VX@=&EE;F4@;&%S(&-A8F5C97)A<R!D92!E<W1E(&UE;G-A
M:F4@;65S<V%G92]R9F,X,C(N`%-E('-A8F4@<75E(&5L(&UO9&\@9&4@<&%N
M=&%L;&$@8V]M<&QE=&$@9&$@<')O8FQE;6%S(&-O;B!);G1E<FYE="!%>'!L
M;W)E<B!D96)I9&\@82!F86QL;W,@9&5L(&YA=F5G861O<B!Q=64@;F\@:&5M
M;W,@<&]D:61O('-O<VQA>6%R+B!0=65D92!S=69R:7(@=FES=6%L:7IA8VGS
M;B!D92!B87-U<F$L('#I<F1I9&$@9&4@9G5N8VEO;F5S(&1E;"!E9&ET;W(@
M>2]O(&-U96QG=65S(&%L96%T;W)I;W,@9&5L(&YA=F5G861O<BX@4VD@<W4@
M<VES=&5M82!O<&5R871I=F\@97,@5VEN9&]W<R`Y>"P@97,@;75Y('!R;V)A
M8FQE('%U92!S=69R82!U;B!F86QL;R!D92!P<F]T96-C:?-N(&=E;F5R86P@
M>2!T96YG82!Q=64@<F5I;FEC:6%R(&5L(&5Q=6EP;RY<;EQN66$@97-TX2!A
M=FES861O+B!0=6QS92!!8V5P=&%R('-I(&'Z;B!D97-E82!P<F]B87(@96P@
M961I=&]R(&5N(&UO9&\@9&4@<&%N=&%L;&$@8V]M<&QE=&$N`$5L(&%R8VAI
M=F\@9&4@87EU9&$@)7,@;F\@96UP:65Z82!P;W(@/#]X;6P`4V4@:&$@96QI
M;6EN861O(&QA(&ED96YT:61A9"`B)7,B+@!3\VQO(&5L(&)O<F1E(&EZ<75I
M97)D;P!392!H82!E;&EM:6YA9&\@96P@=NUN8W5L;P!(87D@<75E(&EN9&EC
M87)L92!A(&QA(&-L87-E($-R>7!T7W!G<#HZ(&QA('5B:6-A8VGS;B!D92!L
M;W,@8FEN87)I;W,@1VYU4$<N`%-E(&AA(&UO<W1R861O(&5L(&UE;G-A:F4@
M96YV:6%D;R!E;"`E<R!A("5S(&-O;B!E;"!A<W5N=&\@(B5S(BX*R7-T;R!N
M;R!G87)A;G1I>F$@<75E(&5L(&UE;G-A:F4@:&%Y82!S:61O(&QE:61O(&\@
M8V]M<')E;F1I9&\N`$YO;6)R92!U=&EL:7IA9&\@86P@=FEN8W5L87(@82!L
M82!PX6=I;F$@9&4@8V]M<&]S:6-I\VX`2&%C92!F86QT82!E;"!M\V1U;&\@
M;W!E;G-S;"!P87)A(&QA(&-L87-E($AO<F1E7T-R>7!T7W-M:6UE.CHN`$YO
M('-E('!U961E(&=U87)D87(@;&$@<')E9F5R96YC:6$@(B5S(B!P;W)Q=64@
M<W5S(&1A=&]S('-O8G)E<&%S86X@96P@=&%M8?%O(&WA>&EM;R!P97)M:71I
M9&\`3F\@<V4@96YC;VYT<O,@96X@96P@<VES=&5M82!E;"!P<F]G<F%M82!P
M87)A('9E<B!E<W1E('1I<&\@9&4@9&%T;W,@*"5S*2X`4_-L;R!L;W,@;&%D
M;W,@:7IQ=6EE<F1O('D@9&5R96-H;P!3\VQO(&5L(&QA9&\@9&5R96-H;P!3
M92!H82!E;&EM:6YA9&\@96P@<V5R=FED;W(@(B5S(BX`4V4@:&$@9W5A<F1A
M9&\@96P@<V5R=FED;W(@(B5S(BX`4V4@:&$@96QI;6EN861O(&QA('-O;&EC
M:71U9"!D92!A;'1A(&1E("5S+@!,82!F:6QA(&5S<&5C:69I8V%D82!N;R!E
M>&ES=&4N`%-E(&AA(&'Q861I9&\@;&$@=&%R96$@82!S=2!L:7-T82!D92!T
M87)E87,N`%/S;&\@;&]S(&QA9&]S('-U<&5R:6]R(&4@:6YF97)I;W(`4_-L
M;R!E;"!L861O('-U<&5R:6]R`%-E('!E<F1I97)O;B!L;W,@9&%T;W,@8V%R
M9V%D;W,@9&5S9&4@96P@<&%S;R!A;G1E<FEO<BX`3F\@<V4@<'5D;R!G=6%R
M9&%R(&5L(&%R8VAI=F\@8V%R9V%D;RX`4V4@86QM86-E;O,@8V]R<F5C=&%M
M96YT92!L82!I;F9O<FUA8VGS;B!D92!T:65M<&\@9&ES<&]N:6)L92!D96P@
M=7-U87)I;RX`3F\@97-TX2!D:7-P;VYI8FQE(&5L(&)L;W%U92!D92!W96%T
M:&5R+F-O;2X`3F\@<V4@9&ES<&]N92!D92!O<&-I;VYE<RX`3F\@:&%Y('!A
M<G1E<R!Q=64@<V4@<'5E9&%N(&UO<W1R87(@96X@;.UN96$N`$5N(&5S=&4@
M8V%M<&\@:&%Y(&1E;6%S:6%D;W,@8V%R86-T97)E<RX@2&$@:6YT<F]D=6-I
M9&\@)7,@8V%R86-T97)E<R!Y('1I96YE('%U92!I;G1R;V1U8VER(&UE;F]S
M(&1E("5S+@!!^FX@;F\@97AI<W1E('5N(&%R8VAI=F\@9&4@87EU9&$@9&4@
M)7,N`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A9&ER(&$@)R5S)R!A
M;"!S:7-T96UA+B`E<RX`4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A\6%D
M:7(@82`G)7,G(&%L('-I<W1E;6$Z("5S`%-E('!R;V1U:F\@=6X@<')O8FQE
M;6$@86P@8F]R<F%R(&QO<R!D871O<R!D96P@=7-U87)I;R`G)7,G(&1E;"!S
M:7-T96UA.B``4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!E;&EM:6YA<B!A
M("<E<R<@9&5L('-I<W1E;6$Z(`!392!P<F]D=6IO('5N('!R;V)L96UA(&%L
M(&%C='5A;&EZ87(@)R5S)SH@)7,`4V4@<')O9'5J;R!U;B!P<F]B;&5M82!C
M;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\Z($YO('-E(&-A<F?S("5S+@!392!P
M<F]D=6IO('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D96P@87)C:&EV;RX@
M16P@)7,@97)A(&WA<R!G<F%N9&4@<75E(&5L('1A;6'Q;R!MX7AI;6\@<&5R
M;6ET:61O("@E9"!B>71E<RDN`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@8V]N
M(&QA(&-A<F=A(&1E;"!A<F-H:79O+B!3\VQO('-E(&-A<F?S('!A<F-I86QM
M96YT92!E;"`E<RX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!M;W-T<F%R(&5S
M=&$@<&%R=&4@9&5L(&UE;G-A:F4`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I
M;7!O<G1A<B!L;W,@9&%T;W,@9&5L(&-O;G1A8W1O+@!392!P<F]D=6IO('5N
M(&5R<F]R(&%L(&EM<&]R=&%R(&5L(&%C;VYT96-I;6EE;G1O.B`E<RX`4V4@
M<')O9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L;W,@9&%T;W,@:4-A;&5N
M9&%R+@!392!P<F]D=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QA('1A<F5A
M.B`E<RX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L82!I;F9O
M<FUA8VGS;B!D92!T:65M<&\@9&ES<&]N:6)L92!D96P@=7-U87)I;SH@)7,N
M`%-E('!R;V1U:F\@=6X@97)R;W(@96X@96P@9F]R;75L87)I;R!D92!C;VYF
M:6=U<F%C:?-N+B!0=65D92!Q=64@:&%Y82!O;'9I9&%D;R!R96QL96YA<B!U
M;B!C86UP;R!N96-E<V%R:6\N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@86)R
M:7(@96P@87)C:&EV;R`E<RX@4')U96)E(&$@96IE8W5T87(@=')A;G-L871I
M;VXN<&AP(&-O;B!L82!O<&-I\VX@+60@<&%R82!V97(@;&]S(&UE;G-A:F5S
M(&1E(&5R<F]R(&1E;"!P<F]C97-A9&]R('AM;"X`4V4@<')O9'5J;R!U;B!E
M<G)O<B!A;"!E:F5C=71A<B!L82!F=6YC:?-N(&5S<&5C:69I8V%D82!D92!L
M82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B!6=65L=F$@82!P<F]B87(@;>%S
M(&%D96QA;G1E+@!392!P<F]D=6IO('5N(&5R<F]R(&%L(&%C='5A;&EZ87(@
M;&]S(&1E=&%L;&5S(&1E;"!C;VYT86-T;RX@5G5E;'9A(&$@<')O8F%R(&WA
M<R!A9&5L86YT92X`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A8W1U86QI>F%R
M(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@5G5E;'9A(&$@<')O8F%R(&WA
M<R!A9&5L86YT92X`4V4@<')O9'5J;R!U;B!E<G)O<B!D97-C;VYO8VED;R!A
M;"!V97)I9FEC87(@97-T92!M96YS86IE+@!%<W1E('-E<G9I9&]R($E-05`@
M;F\@<V]P;W)T82!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N`$5S=&$@86-C
M:?-N(&YO(&5S=.$@<V]P;W)T861A+@!%<W1A(&%C8VGS;B!T;V1A=NUA(&YO
M(&5S=.$@9&5S87)R;VQL861A+@#)<W1E(&YO('!A<F5C92!S97(@=6X@87)C
M:&EV;R!R87(@=N%L:61O+@#)<W1E(&YO('!A<F5C92!S97(@=6X@87)C:&EV
M;R!Z:7`@=N%L:61O+@#)<W1E(&YO('!A<F5C92!S97(@=6X@;OIM97)O(&1E
M('1A<FIE=&$@=N%L:61O+@!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV
M:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2DL(&UE9&EA;G1E(&QA($%022!(
M5%10`$5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I87(@;65N<V%J97,@
M82!T<F%VZ7,@9&4@;&$@<&%S87)E;&$@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2DL(&UE9&EA;G1E(&QA($%022!(5%10`$5S=&4@8V]N=')O
M;&%D;W(@<&5R;6ET92!E;G9I87(@;65N<V%J97,@=FEA(%--5%`@82!T<F%V
MZ7,@9&4@;&$@<&%S87)E;&$@9&4@5F]D869O;F4@9&4@271A;&EA+"!S\VQO
M(&$@;OIM97)O<R!6;V1A9F]N92X@2&%C92!F86QT82!U;F$@8W5E;G1A(&1E
M(&-O<G)E;R!D92!6;V1A9F]N92!D92!)=&%L:6$@*&AT='`Z+R]W=W<N,3DP
M+FET*2X`2&%C92!F86QT82!E<W1E(&-A;7!O+@!%<W1E(&-A;7!O('/S;&\@
M<'5E9&4@8V]N=&5N97(@96YT97)O<RX`17-T92!C86UP;R!S\VQO('!U961E
M(&-O;G1E;F5R(&[Z;65R;W,@>2!L;W,@9&]S('!U;G1O<RX`17-T92!C86UP
M;R!S\VQO('!U961E(&-O;G1E;F5R('9A;&]R97,@;V-T86QE<RX`17-T92!C
M86UP;R!T:65N92!Q=64@<V5R('5N82!L:7-T82!D92!E;G1E<F]S('-E<&%R
M861O<R!P;W(@8V]M87,@;R!E<W!A8VEO<RX`17-T92!C86UP;R!T:65N92!Q
M=64@<V5R('5N(&[Z;65R;R!VX6QI9&\N`$5S=&4@8V%M<&\@=&EE;F4@<75E
M(&-O;G1E;F5R('5N(&/S9&EF;R!D92!C;VQO<B!E;B!F;W)M871O(%)'0B!(
M97AA9&5C:6UA;"P@<&]R(&5J96UP;&\@)R,Q,C,T868G+@!982!S92!H82!P
M<F]C97-A9&\@97-T92!F;W)M=6QA<FEO+@!%<W1O(&5S("5S+@#)<W1O(&5S
M('5N(&]B:F5T;R!D92!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=F5R;&\@;F5C
M97-I=&$@=6X@8VQI96YT92!D92!C;W)R96\@('%U92!E;G1I96YD82!E;"!F
M;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R82!V97(@=6YA(&QI<W1A(&1E
M(&1I8VAO<R!C;&EE;G1E<R!V:7-I=&4@)7,`17-T92!M96YS86IE('-E(&5S
M8W)I8FGS(&-O;B!U;B!J=65G;R!D92!C87)A8W1E<F5S("@E<RD@9&ES=&EN
M=&\@86P@<W5Y;RX`17-T92!N^FUE<F\@9&5B92!S97(@<&]R(&QO(&UE;F]S
M('5N('5N;RX`17-T92!G=6GS;B!S92!T:65N92!Q=64@96IE8W5T87(@96X@
M;&$@;.UN96$@9&4@8V]M86YD;W,N`$5S=&4@<V5R=FED;W(@;F\@<'5E9&4@
M9&5S8V]M<')I;6ER(&%R8VAI=F]S('II<"!Y(&=Z:7`N`$5S=&4@<VES=&5M
M82!A8W1U86QM96YT92!E<W3A(&1E<V%C=&EV861O+@!%<W1E('9A;&]R('1I
M96YE('%U92!S97(@=6X@;OIM97)O+@!%<W1A('9E;G1A;F$@<_-L;R!P=65D
M92!A8G)I<G-E(&1E<V1E('5N82!V96YT86YA(&1E(&]P8VEO;F5S`%1R=65N
M;P!);F-I9&5N8VEA<P!(;W)A`$,N('1I96UP;W,`1F]R;6%T;R!H;W)A<FEO
M`%-E;&5C8VGS;B!D92!H;W)A`%1I;6]R+4QE<W1E`%3M='5L;P!4[71U;&\@
M*&-O;G-E:F\I.@!087)A`%!A<F$@<V5L96-C:6]N87(@=F%R:6]S(&-A;7!O
M<RP@;6%N=&5N9V$@<'5L<V%D82!L82!T96-L82!#;VYT<F]L("A00RD@;R!#
M;VUA;F1O("A-86,I(&%L(&AA8V5R(&-L:6-K+@!(;WD`0V]N;75T87(@;W)I
M9V5N($A434P`5&]G;P!4;VME;&%U`$UA\6%N80!4;VYG80!3=7!E<FEO<@!&
M<F%M92!S=7!E<FEO<B`H7W1O<"D`5')A9'5C:61O`%1R861U8V-I;VYE<P!4
M<FEN:61A9"!Y(%1O8F%G;P!697)D861E<F\@;R!F86QS;P!-87(`5/IN97H`
M5'5R<77M80!4=7)C;R`H25-/+3@X-3DM.2D`5'5R:VUE;FES=.%N`$ES;&%S
M(%1U<FMS('D@0V%I8V]S`%1U=F%L=0!%<V-R:6)A('-U(&5L96-C:?-N.B``
MS6YD:6-E(%4N5BXZ(`!54DP`55),(&1E('-U(&EN9F]R;64@9&4@97-T861O
M(&1E(&5N=NUO(&1E;"!G=6GS;@!54DPZ`%5G86YD80!58W)A;FEA`$EN8V%P
M87H@9&4@86-C961E<B!A;"!D:7)E8W1O<FEO(%9&4RX`26YC87!A>B!D92!A
M\6%D:7(@:6YF;W)M86-I\VX@9&4@=7-U87)I;R!A9&EC:6]N86P@86P@<F5A
M;&EZ87(@96P@86QT82X`26YC87!A>B!D92!C86UB:6%R(&QO<R!P<FEV:6QE
M9VEO<R!D96P@87)C:&EV;R!61E,@(B5S(BX`26YC87!A>B!D92!C86UB:6%R
M(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C:&EV;R!61E,@)7,O)7,N`$EN8V%P
M87H@9&4@8V%M8FEA<B!A("5S+@!);F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@
M<V5R=FED;W(@4U%,+@!);F-A<&%Z(&1E(&-O;F5C=&%R(&-O;B!34TPN`$EN
M8V%P87H@9&4@8V]P:6%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&-R
M96%R(&5L(&1I<F5C=&]R:6\@5D93("(E<R(N`$EN8V%P87H@9&4@8W)E87(@
M96P@9&ER96-T;W)I;R!61E,N`$EN8V%P87H@9&4@8W)E87(@96P@87)C:&EV
M;R!61E,N`$EN8V%P87H@9&4@8W)E87(@=6X@87)C:&EV;R!61E,@=F%C[6\N
M`$EN8V%P87H@9&4@9&5S8V]M<')I;6ER(&QO<R!D871O<RX`26YC87!A>B!D
M92!E;&EM:6YA<B`B)7,B+"!E;"!D:7)E8W1O<FEO(&YO(&5S=.$@=F%C[6\N
M`$EN8V%P87H@9&4@96QI;6EN87(@)7,L(&5L(&1I<F5C=&]R:6\@;F\@97-T
MX2!V86/M;P!);F-A<&%Z(&1E(&5L:6UI;F%R("<E<R<Z("5S+@!);F-A<&%Z
M(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93(&1E(&9O<FUA(')E8W5R
M<VEV82X`26YC87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%9&4RX`
M26YC87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%9&4SH@)7,N`$EN
M8V%P87H@9&4@96QI;6EN87(@96P@87)C:&EV;R!61E,@(B5S(BX`26YC87!A
M>B!D92!E;&EM:6YA<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!E;&EM
M:6YA<B!E;"!61E,@9&4@9F]R;6$@<F5C=7)S:79A.B`E<RX`26YC87!A>B!D
M92!D971E<FUI;F%R(&5L(&1I<F5C=&]R:6\@86-T=6%L+@!);F-A<&%Z(&1E
M(&5X=')A97(@;&]S(&1E=&%L;&5S(&1E;"!C97)T:69I8V%D;RX`26YC87!A
M>B!D92!C87)G87(@;&$@9&5F:6YI8VGS;B!D92`E<RX`26YC87!A>B!D92!T
M<F%S;&%D87(@96P@87)C:&EV;R!61E,N`$EN8V%P87H@9&4@86)R:7(@96P@
M87)C:&EV;R!61E,@(B5S(BX`26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O
M(%9&4R!P87)A(&5S8W)I8FER+@!);F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI
M=F\@5D93+@!);F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI=F\@8V]M<')I;6ED
M;RX`26YC87!A>B!D92!L965R(&5L(&1I<F5C=&]R:6\@=F9S<F]O="X`26YC
M87!A>B!D92!R96YO;6)R87(@)7,@8V]M;R`E<SH@;&$@8V%R<&5T82!D97-T
M:6YO('EA(&5X:7-T90!);F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!D:7)E8W1O
M<FEO(%9&4RX`26YC87!A>B!D92!R96YO;6)R87(@96P@9&ER96-T;W)I;R!6
M1E,Z("5S+@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4R`B
M)7,B`$EN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&%R8VAI=F\@5D93("5S+R5S
M+@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4RX`26YC87!A
M>B!D92!E:F5C=71A<B`G;6MI<V]F<R<N`$EN8V%P87H@9&4@=')A9'5C:7(@
M97-T92!D;V-U;65N=&\@5V]R9`!);F-A<&%Z(&1E(&5S8W)I8FER(&5L(&%R
M8VAI=F\@5D93("(E<R(N`$EN8V%P87H@9&4@97-C<FEB:7(@=6X@87)C:&EV
M;R!61E,@*&AA(&9A;&QA9&\@8V]P>2@I*2X`26YC87!A>B!D92!E<V-R:6)I
M<B!L;W,@9&%T;W,@9&5L(&%R8VAI=F\@5D93+@!3=6)R87EA9&$`1&5S:&%C
M97(@8V%M8FEO<P!$97-H86-E(&QA(/IL=&EM82!A8V-I\VX`4F5S<'5E<W1A
M(&EN97-P97)A9&$@9&5L('-E<G9I9&]R(&5N(&QA(&-O;F5X:?-N.B``4F5S
M<'5E<W1A(&EN97-P97)A9&$@9&5L('-E<G9I9&]R(&$Z(`!3:6X@8V%T96=O
M<NUA`$-O;7!O;F5N=&4@;F\@<V]P;W)T861O(&1E('1I<&\Z("5S`%5N:6-O
M9&4@*%541BTX*0!%;6ER871O<R#!<F%B97,@56YI9&]S`$EN9VQA=&5R<F$`
M17-T861O<R!5;FED;W,`17-T861O<R!5;FED;W,@;65N;W,@;&%S(&ES;&%S
M('!E<FEFZ7)I8V%S`%5N:61A9&5S`$1E<V-O;F]C:61O`$%P:6US9VED(&1E
M<V-O;F]C:61O("A)1"!D92!M96YS86IE(&1E(&QA($%022DN`$-L:6US9VED
M(&1E<V-O;F]C:61O("A)1"!D92!M96YS86IE(&1E;"!C;&EE;G1E*2X`0V]M
M86YD;R!D97-C;VYO8VED;SH@)7,`57-U87)I;R!O(&-O;G1R87-E\6$@9&5S
M8V]N;V-I9&]S+@!%;&EM:6YA<B!V[6YC=6QO(&1E;"!E;&5M96YT;R!A8W1U
M86P`4VEN(&YO;6)R90!,;W,@9W5I;VYE<R!S:6X@<')I=FEL96=I;W,@;F\@
M<'5E9&5N(&%C8V5D97(@9&4@9F]R;6$@<')O9W)A;>%T:6-A(&$@0V]R=&%R
M+T-O<&EA<B]096=A<B!P;W(@<F%Z;VYE<R!D92!S96=U<FED860N(%!U;'-E
M($%C97!T87(@<&%R82!V97(@96X@;6]Z:6QL82YO<F<@=6YA(&YO=&$@=.EC
M;FEC82!Q=64@;&4@;75E<W1R92!C\VUO('!E<FUI=&ER('%U92!U;B!G=6GS
M;B!A8V-E9&$@86P@<&]R=&%P87!E;&5S+@!!;G5L87(@8V]L;W(`17AT96YS
M:?-N(&YO('-O<&]R=&%D80!3:6X@=')A9'5C:7(`06-T=6%L:7IA<@!!8W1U
M86QI>F%R("5S`$%C='5A;&EZ87(@97-T861O(&1E(')E<W!U97-T80!!8W1U
M86QI>F%R('5S=6%R:6\`4V4@:&$@86-T=6%L:7IA9&\@)R5S)RX`06-T=6%L
M:7IA;F1O(&5L(&%R8VAI=F\@9&4@87EU9&$@)7,@9&4@)7,N`%-E(&AA(&5L
M:6UI;F%D;R!E;"!G=6GS;B!D92!A8W1U86QI>F%C:?-N+@!#87)G87(`4V4@
M:&%N(&-A<F=A9&\@96X@96P@<V5R=FED;W(@=&]D;W,@;&]S(&%R8VAI=F]S
M(&1E(&-O;F9I9W5R86-I\VX@9&4@87!L:6-A8VEO;F5S+@!!;&9A8F5T;R!L
M871I;F\@96X@;6%Y^G-C+@!.^FUE<F]S(')O;6%N;W,@96X@;6%Y^G-C+@!5
M<G5G=6%Y`%5S;SH`57-A<B!A8W1U86PZ("5S`%5S87(@=F%L;W(@<&]R(&]M
M:7-I\VX`57-A<B!34TP`4V4@=7-A('-I(&5L('5S=6%R:6\O8V]N=')A<V7Q
M82!S;VX@9&ES=&EN=&]S(&5N(&5L('-E<G9I9&]R($E-4U`N`$5L('5S=6%R
M:6\@)7,@8V%R96-E(&1E(&%U=&]R:7IA8VGS;B!P87)A("5S+@!!9&UI;FES
M=')A8VGS;B!D92!U<W5A<FEO<P!/<&-I;VYE<R!D92!U<W5A<FEO`%)E9VES
M=')O(&1E('5S=6%R:6]S`$5S=&$@<V5D92!T:65N92!D97-A8W1I=F%D;R!E
M;"!R96=I<W1R;R!D92!U<W5A<FEO<RX`3F\@<V4@96YC;VYT<O,@96P@=7-U
M87)I;P!.;R!S92!E;F-O;G1R\R!E;"!U<W5A<FEO+@!0<FEV:6QE9VEO<R!D
M92!U<W5A<FEO`%5S=6%R:6\`66$@97AI<W1E(&5L(&YO;6)R92!D92!U<W5A
M<FEO("<E<R<N`%5S=6%R:6\Z`%5S=6%R:6\Z(`!5<W5A<FEO<P!5<W5A<FEO
M<R!E;B!E;"!S:7-T96UA.@!5>F)E:VES=.%N`$YO(&5X:7-T92!E;"!D:7)E
M8W1O<FEO(%9&4RX`075S96YC:6$`3&%S('5B:6-A8VEO;F5S(';A;&ED87,@
M96YC;VYT<F%D87,@:6YC;'5Y96XZ(`!686QI9&5Z`%9A;&]R(&5N(&UI;G5T
M;W,@82!P87)T:7(@9&4@86AO<F$N`%9A;&]R97,`5F%L;W)E<R!A('-E;&5C
M8VEO;F%R`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`$AA(&9A;&QA9&\@
M;&$@8V]M<')O8F%C:?-N("T@97-T92!M96YS86IE('!U961E(&AA8F5R<V4@
M9F]R>F%D;RX`5F5R<VGS;@!#+B!V97)S:6]N97,`06QI;F5A8VGS;B!V97)T
M:6-A;`!-87)G96X@=F5R=&EC86P`5F5R=&EC86PZ`$UU>2!A;'1A`%9I971N
M86T`5FEE=&YA;6ET82`H5DE30TE)*0!697(@)7,`5F5R('5N82!PX6=I;F$@
M=V5B(&5X=&5R;F$`5F5R(&-O;6\@)7,`5F5R(&%C;VYT96-I;6EE;G1O`%9E
M<B!T87)E80!)<VQA<R!6[7)G96YE<RP@0G)I=.%N:6-A<P!)<VQA<R!6[7)G
M96YE<RP@52Y3+@!6:7-I8FEL:61A9`!6:7-I8FEL:61A9#H@`%9O9&%F;VYE
M(&1E($ET86QI82!M961I86YT92!33510`$%625-/`*&AH4%$5D525$5.0TE!
M(2$A($5,24U)3D4@34%.54%,345.5$4@14P@1U5)TTX@1$4@)7,N`%=A;&QI
M<R!Y($9U='5N80!!9'9E<G1E;F-I80!!9'9E<G1E;F-I83H@`$UI90!0<F5V
M:7-I\VX@9&5L('1I96UP;P!$871O<R!D96P@=&EE;7!O('-U;6EN:7-T<F%D
M;W,@<&]R`%=E871H97(N8V]M`%=E8@!3961E(%=E8@!396UA;F%L;65N=&4`
M0FEE;G9E;FED;P!":65N=F5N:61O<R!A("5S`$)I96YV96YI9&\L("5S`$]E
M<W1E("A)4T\M.#@U.2TQ*0!/97-T92`H25-/+3@X-3DM,34I`%/A:&%R82!/
M8V-I9&5N=&%L`+]1=>D@87!L:6-A8VGS;B!D96)E<NUA(&UO<W1R87(@)7,@
M86P@:6YI8VEA<B!L82!S97-I\VX_`+]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E
M;&EM:71A9&]R/P"_0W7A;"!E<R!E;"!C87+A8W1E<B!D92!C:71A9&\_`%%U
MZ2!F87-E<P!0;'5G:6YS(&AA8FEL:71A9&]S(&1E;"!E9&ET;W(@9&4@=&5X
M=&\@96YR:7%U96-I9&\N`$%N8VAU<F$`06YC:'5R82!E;B!U;FED861E<R!#
M4U,`06YC:'5R82!D96P@;65N^B`E<R!I>G%U:65R9&\@*&1I<W!O;FEB;&4@
M96X@;&$@<'+S>&EM82!S97-I\VXI.@!!;F-H=7)A(&1E(&QA('1A8FQA`%5N
M:61A9&5S(&1E(&%N8VAU<F$`06YC:'5R83H`5VEK:0!6:65N=&\`5F5L;V-I
M9&%D(&1E;"!V:65N=&\@96X@;G5D;W,`5FEE;G1O.@!6:65N=&\Z(`!386)I
M9'5R[6$`1&5S96]S`$5M<&QE;P!$:7)E8V-I\VX@9&5L('1R86)A:F\`5&5L
MZ69O;F\@9&5L('1R86)A:F\`3F\@<V4@<'5E9&4@97-C<FEB:7(N(%!U961E
M('5T:6QI>F%R(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&ES<&]N:6)L
M92!O(&-O<&EA<B!M86YU86QM96YT92!A("5S(&5L(&/S9&EG;R!S:6=U:65N
M=&4N`$5S8W)I8FEE;F1O(&%R8VAI=F\@9&4@87EU9&$@86-T=6%L:7IA9&\@
M96X@)7,N`%@M4F5F`$QI;6ET86-I;VYE<R!BX7-I8V%S(%@U,#EV,P!5<V\@
M9&4@8VQA=F4@97AT96YD:61A(%@U,#EV,P!.;VUB<F4@86QT97)N871I=F\@
M9&4@87-U;G1O(%@U,#EV,P!)9&5N=&EF:6-A9&]R(&1E(&-L879E(&1E(&%S
M=6YT;R!8-3`Y=C,`17AT96YS:6]N97,@6#4P.78S`$%!`$%!04$`H4UA<&$@
M9&4@66%H;V\A`$%N=6%L;65N=&4`665M96X`4^T`4^TL(&QO(&%C97!T;P!%
M<W3A(&5N($U/1$\@5$585$\N(%5T:6QI8V4@96P@8F]T\VX@6SP^72!P87)A
M(')E9W)E<V%R(&%L(&UO9&\@5UE325=91RX`3F\@97-TX2!A=71E;G1I9FEC
M861O+@!0=65D92!C;VYF:7)M87(@97-T92!A;'1A(&$@;&$@)7,`3F\@<'5E
M9&4@:6YC;'5I<B!E;"!C87+A8W1E<B`G7"<@96X@96P@;F]M8G)E(&-O;7!L
M971O+@!.;R!P=65D92!C86UB:6%R(&QA(&-L879E(&1E;"!U<W5A<FEO("5S
M`$YO(&EN=')O9'5J;R!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;R!VX6QI9&$N
M`$YO(&%S;V-I\R!N:6YG=6YO(&1E(&QO<R!C86UP;W,@9&5L(&%R8VAI=F\@
M:6UP;W)T861O(&$@;&]S(&-A;7!O<R!C;W)R97-P;VYD:65N=&5S(&1E("5S
M+@!(82!S86QI9&\@9&4@;&$@<V5S:?-N+@!4:65N92!Q=64@:6YT<F]D=6-I
M<B!U;B!N^FUE<F\@9&4@=&5LZ69O;F\@;?-V:6P@=N%L:61O+"!S\VQO(&3M
M9VET;W,@8V]N('5N("<K)R!O<&-I;VYA;"!P87)A(&5L('!R969I:F\@9&4@
M;&QA;6%D82!I;G1E<FYA8VEO;F%L+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U
M;B!V86QO<B!VX6QI9&\N`%!A<F$@=7-A<B!!;'1A<R!T:65N92!Q=64@8V]N
M9FEG=7)A<B!U;B!M;W1O<B!D92!$871A5')E92X`1&5B92!D97-C<FEB:7(@
M96P@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&5L(&EN9F]R;64N`%1I96YE
M('%U92!I;G1R;V1U8VER(&QA(%523"!A(&QA('%U92!A<'5N=&$@97-T92!V
M[6YC=6QO`%1I96YE('%U92!I;G1R;V1U8VER('-U(&-O;G1R87-E\6$@86-T
M=6%L`%1I96YE('%U92!I;G1R;V1U8VER('-U(&YU979A(&-O;G1R87-E\6$`
M5&EE;F4@<75E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R(&$@96QI;6EN87(N
M`%1I96YE('%U92!E<W!E8VEF:6-A<B!U;B!U<W5A<FEO(&$@96QI;6EN87(N
M`%1I96YE('%U92!E<W!E8VEF:6-A<B!U;B!U<W5A<FEO(&$@96QI;6EN87(N
M`%1I96YE('%U92!E<W!E8VEF:6-A<B!E;"!U<W5A<FEO(&$@8?%A9&ER+@!4
M:65N92!Q=64@97-P96-I9FEC87(@96P@=7-U87)I;R!A(&%C='5A;&EZ87(N
M`%1I96YE('%U92!E<W!E8VEF:6-A<B!Q=>D@86-C:?-N('-E(&5J96-U=&%R
MX2X`5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@;G5E=F\@;F]M8G)E(&1E(&-A
M=&5G;W+M82X`5&EE;F4@<75E(&-O;7!R;V)A<B!L82!C;VYT<F%S9?%A(&YU
M979A`$AA(&5X<&ER861O('-U('-E<VGS;B`E<RX@5G5E;'9A(&$@:6YI8VEA
M<B!S97-I\VXN`%-U(&1I<F5C8VGS;B!D92!C;W)R96\`1&ER96-C:?-N($1E
M.@!3=2!I;F9O<FUA8VGS;@!(82!C86UB:6%D;R!S=2!D:7)E8V-I\VX@9&4@
M26YT97)N970@9&5S9&4@96P@8V]M:65N>F\@9&4@<W4@<V5S:?-N("5S+B!0
M;W(@<F%Z;VYE<R!D92!S96=U<FED860@=&EE;F4@<75E('9O;'9E<B!A(&EN
M:6-I87(@;&$@<V5S:?-N+@!3=2!N;VUB<F4`4W4@;6]T;W(@9&4@875T96YT
M:69I8V%C:?-N(&YO('!E<FUI=&4@8?%A9&ER('5S=6%R:6]S+"!O('-E(&AA
M(&1E<VAA8FEL:71A9&\@;&$@8V%R86-T97+M<W1I8V$@<&]R(&%L9_IN(&UO
M=&EV;RX`4W4@;6]T;W(@9&4@875T96YT:69I8V%C:?-N(&YO('!E<FUI=&4@
M;&ES=&%R('5S=6%R:6]S+"!O('-E(&AA(&1E<VAA8FEL:71A9&\@;&$@8V%R
M86-T97+M<W1I8V$@<&]R(&%L9_IN(&UO=&EV;RX`4&%R96-E('%U92!H82!C
M86UB:6%D;R!S=2!N879E9V%D;W(@9&5S9&4@96P@8V]M:65N>F\@9&4@<W4@
M<V5S:?-N("5S+B!0;W(@<F%Z;VYE<R!D92!S96=U<FED860@=&EE;F4@<75E
M('9O;'9E<B!A(&EN:6-I87(@;&$@<V5S:?-N+@!3=2!N879E9V%D;W(@;F\@
M861M:71E(&5S=&$@8V%R86-T97+M<W1I8V$N`$5L(&YA=F5G861O<B!N;R!A
M9&UI=&4@97-T82!O<&-I\VX@9&4@:6UP<F5S:?-N+B!0<F5S:6]N92!#;VYT
M<F]L+T]P8VGS;B`K(%`@<&%R82!I;7!R:6UI<BX`6F]N82!H;W)A<FEA(&%C
M='5A;#H`261E;G1I9&%D('!O<B!O;6ES:?-N.@!.;VUB<F4@8V]M<&QE=&\Z
M`%-U('9E<G-I\VX@9&4@9V5T=&5X="!E<R!D96UA<VEA9&\@86YT:6=U82!Y
M(&YO('-O<&]R=&$@4$A0(&1E(&9O<FUA(&YA=&EV82X*3F\@<V4@97AT<F%E
M<N%N('1O9&%S(&QA<R!C861E;F%S+@!,82!N=65V82!C;VYT<F%S9?%A('!A
M<F$@)7,@97,Z("5S`%-U(&YU979A(&-O;G1R87-E\6$@97,@9&5M87-I861O
M(&QA<F=A.R"A;&%S(&-O;G1R87-E\6%S(&YO('!U961E;B!T96YE<B!MX7,@
M9&4@)60@8V%R86-T97)E<R$`H5-U(&YU979A(&-O;G1R87-E\6$@97,@9&5M
M87-I861O(&;A8VEL(&1E(&%D:79I;F%R(2"A3F\@<V4@:&$@8V%M8FEA9&\A
M`*%3=2!N=65V82!C;VYT<F%S9?%A(&5S(&1E;6%S:6%D;R!FX6-I;"!D92!A
M9&EV:6YA<B$@H4YO('-E(&AA(&-A;6)I861O(0"A4W4@;G5E=F$@8V]N=')A
M<V7Q82!T:65N92!Q=64@=&5N97(@86P@;65N;W,@)60@8V%R86-T97)E<R$`
M4W4@;G5E=F$@8V]N=')A<V7Q82!T:65N92!Q=64@<V5R(&1I<W1I;G1A(&1E
M(&QA(&%C='5A;`!3=2!N=65V82!C;VYT<F%S9?%A('1I96YE('%U92!C;VYT
M96YE<B!A;"!M96YO<R`E9"!C87)A8W1E<F5S(&%L9F%BZ71I8V]S+@!3=2!N
M=65V82!C;VYT<F%S9?%A('1I96YE('%U92!C;VYT96YE<B!A;"!M96YO<R`E
M9"!C87)A8W1E<F5S(&%L9F%N=6WI<FEC;W,N`%-U(&YU979A(&-O;G1R87-E
M\6$@=&EE;F4@<75E(&-O;G1E;F5R(&%L(&UE;F]S("5D('1I<&]S(&1I<W1I
M;G1O<R!D92!C87)A8W1E<F5S+B!,;W,@=&EP;W,@<V]N.B!M:6[Z<V-U;&%S
M+"!M87GZ<V-U;&%S+"!N^FUE<F]S('D@<^UM8F]L;W,N`%-U(&YU979A(&-O
M;G1R87-E\6$@=&EE;F4@<75E(&-O;G1E;F5R(&%L(&UE;F]S("5D(&-A<F%C
M=&5R97,@96X@;6EN^G-C=6QA<RX`4W4@;G5E=F$@8V]N=')A<V7Q82!T:65N
M92!Q=64@8V]N=&5N97(@86P@;65N;W,@)60@8V%R86-T97)E<R!N=6WI<FEC
M;W,N`%-U(&YU979A(&-O;G1R87-E\6$@=&EE;F4@<75E(&-O;G1E;F5R(&%L
M(&UE;F]S("5D(&-A<F%C=&5R97,@96X@;6%Y^G-C=6QA<RX`4W4@;G5E=F$@
M8V]N=')A<V7Q82!T:65N92!Q=64@8V]N=&5N97(@;65N;W,@9&4@)60@97-P
M86-I;W,N`%-U(&YU979A(&-O;G1R87-E\6$@;F\@<'5E9&4@8V]N=&5N97(@
M97-P86-I;W,N`$QA(&-O;G1R87-E\6$@;G5E=F$@>2!L82!A;G1I9W5A(&YO
M(&-O;F-U97)D86X`4V4@:&%N(&%C='5A;&EZ861O('-U<R!O<&-I;VYE<RX`
M4V4@:&$@<F5A:G5S=&%D;R!S=2!C;VYT<F%S9?%A`%-E(&AA(')E86IU<W1A
M9&\@<W4@8V]N=')A<V7Q82P@8V]M<')U96)E(&5L(&-O<G)E;R!E(&EN:6-I
M92!S97-I\VX@8V]N('-U(&YU979A(&-O;G1R87-E\6$N`%-E<G9I9&]R97,@
M<F5M;W1O<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6T]C=6QT87(@=&5X=&\@8VET861O70!;26YF;W)M92!D92!P<F]B;&5M
M85T`6TUO<W1R87(@=&5X=&\@8VET861O("T`6TUO<W1R87(@=&5X=&\@8VET
M861O("T@)7,@;.UN96%S70!;;.UN96$@)7,@9&4@)7-=`%]!9&UI;FES=')A
M8VGS;@!?0TQ)`,%R7V)O;"!D871O<P!%7VQI;6EN87(@9FEL80!?1W)U<&]S
M`$%?>75D80!0<F]P:65D861E<R!D92!?:6UA9V5N+BXN`%]);FEC:6%R('-E
M<VGS;@!?4V%L:7(`36]D:69I8V%R(%]V[6YC=6QO+BXN`%]/<&-I;VYE<P!?
M4')I=FEL96=I;W,`7T5L:6UI;F%R(';M;F-U;&\N+BX`0V]N7V9I9W5R86,N
M`%!R;W!I961A9&5S(&1E(%]T86)L82XN+@!?57-U87)I;W,`9&ER96-C:6]N
M97,`<V4@:&$@<')O9'5C:61O('5N(&5R<F]R.@!A9V5N9&$`8V%L;6$`<'5L
M<V4@87%U[0!T97)M:6YA9&\`9F%L;&%D;P!D97-C96YS;P!A<F-H:79O`&5N
M8V]N=')A9&]S.B``9&5L("5S("@E<RD@82!L87,@)7,@)7,`:#H`:3$X;@!I
M;FUE9&EA=&%M96YT90!E;B!L[6YE80!H82!F86QL861O(&QD87!?<W1A<G1?
M=&QS`&SM;F5A<UT`8_-D:6=O(&1E(&5R<F]R(&UK:7-O9G,@)60@86P@<F5A
M;&EZ87(@25-/+@!N;VUB<F4`<VEN(&-A;6)I;W,`;F\@96YC;VYT<F%D;P!S
M:6X@9&5S87)R;VQL87(`8?IN(&YO('-E(&AA(&1E<V%R<F]L;&%D;P!N;W1A
M<P!P;W)C96YT86IE`'#M>&5L97,`96X@875M96YT;P!M;W-T<F%R(&1I9F5R
M96YC:6%S`'-M<S)E;6%I;"!P;W(@2%144`!E<W1A8FQE`'1A<F5A<P!E;"!A
M<F-H:79O(%!/(&1E($AO<F1E(&1E;"!I9&EO;6$@)7,@;F\@97AI<W1E.@!E
M<V-R:6)A(&1O<R!V96-E<R!L82!C;VYT<F%S9?%A('!A<F$@8V]N9FER;6%R
M;&$`=6YI9FEC861O`'-I;B!N;VUB<F4`86-T=6%L:7IA9&\`=7-U87)I;R!S
M96QE8V-I;VYA9&\`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O9FE?
M1DDO````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-#,`,#(P,3,W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&%S<W=D+VQO8V%L92]F:5]&22],0U]-15-304=%4R\`````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,C$W,C0`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+V9I7T9)+TQ#7TU%4U-!
M1T53+W!A<W-W9"YM;P``````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#0S-3<R`#$P-#$W,S8R
M-S0S`#`R,S4W-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````.L'```<````=#\``),*``#,?@```````!BI``!-
M````&:D``+\```!GJ0``9````">J``"^````C*H``)````!+JP``0P```-RK
M```\````(*P``"L```!=K```+@```(FL```I````N*P``"@```#BK```10``
M``NM``!'````4:T``$H```"9K0``1P```.2M``!%````+*X``$@```!RK@``
M.0```+NN``!&````]:X``$@````\KP``,````(6O``!%````MJ\``$8```#\
MKP``3````$.P```T````D+```#(```#%L```:0```/BP```P````8K$``"4`
M``"3L0``B````+FQ``!`````0K(``/8```"#L@``2@```'JS```L````Q;,`
M`(4```#RLP``2````'BT```.````P;0```\```#0M```#0```."T```(````
M[K0```L```#WM```#`````.U```$````$+4``!L````5M0``+0```#&U```=
M````7[4``"0```!]M0``*0```**U```9````S+4```P```#FM0``$0```/.U
M```E````!;8```\````KM@``"P```#NV```1````1[8```X```!9M@``!0``
M`&BV```H````;K8```@```"7M@``"@```*"V```5````J[8``!(```#!M@``
M"P```-2V```G````X+8``!0````(MP``)@```!VW```G````1+<``"8```!L
MMP``$P```).W```.````I[<```H```"VMP``#0```,&W```N````S[<``"<`
M``#^MP``(````":X```.````1[@``!<```!6N```(@```&ZX```U````D;@`
M`!$```#'N```#0```-FX```,````Y[@```T```#TN```!@````*Y```=````
M";D```\````GN0``&````#>Y```,````4+D``!L```!=N0``#@```'FY```.
M````B+D```@```"7N0``"0```*"Y``!"````JKD``"X```#MN0``&@```!RZ
M```R````-[H``#@```!JN@``5````*.Z``!1````^+H``%H```!*NP``5P``
M`*6[```T````_;L```X````RO```"0```$&\```-````2[P```<```!9O```
M"@```&&\```/````;+P```4```!\O```!@```(*\```1````B;P```@```";
MO```"0```*2\```)````KKP```X```"XO```"````,>\```.````T+P``"4`
M``#?O```(`````6]```0````)KT```\````WO0``"@```$>]```'````4KT`
M``,```!:O0``#P```%Z]```4````;KT```D```"#O0``#0```(V]```2````
MF[T``!D```"NO0``'@```,B]```/````Y[T```H```#WO0``#P````*^```(
M````$KX``"0````;O@``%P```$"^```4````6+X``!8```!MO@``"````(2^
M``!.````C;X``"T```#<O@``'P````J_```9````*K\```<```!$OP``#```
M`$R_```L````6;\```X```"&OP```P```)6_```+````F;\```<```"EOP``
M!P```*V_```%````M;\```4```"[OP``"@```,&_```#````S+\``!<```#0
MOP``"@```.B_```/````\[\```X````#P```&````!+````C````*\````X`
M``!/P```%````%[````7````<\```!<```"+P```%P```*/````3````N\``
M``\```#/P```#@```-_````?````[L```!T````.P0``!P```"S!```&````
M-,$```@````[P0``#P```$3!```&````5,$```H```!;P0``$P```&;!```+
M````>L$``!````"&P0``%0```)?!```5````K<$```<```##P0``$````,O!
M```%````W,$``!4```#BP0``$0```/C!```,````"L(``#L````7P@``.```
M`%/"```)````C,(```<```"6P@``%````)["```#````L\(```4```"WP@``
M$````+W"```)````SL(``!,```#8P@``.0```.S"```2````)L,``#D````Y
MPP``)P```'/#```L````F\,``"H```#(PP``)0```//#```)````&<0```H`
M```CQ```!@```"[$```)````-<0```<````_Q```+P```$?$```W````=\0`
M`"X```"OQ```50```-[$```M````-,4``"T```!BQ0``+0```)#%``!`````
MOL4``",```#_Q0``(P```"/&```M````1\8``#,```!UQ@``%0```*G&```9
M````O\8``"D```#9Q@``)`````/'```1````*,<``!$````ZQP``"@```$S'
M```,````5\<``"(```!DQP``"@```(?'```0````DL<``!8```"CQP``%@``
M`+K'```'````T<<```<```#9QP``%````.''```*````]L<```@````!R```
M)P````K(```(````,L@```<````[R```!P```$/(```&````2\@```4```!2
MR```!P```%C(```&````8,@```@```!GR```*0```'#(```.````FL@```H`
M``"IR```!````+3(```'````N<@```D```#!R```!@```,O(```1````TL@`
M``<```#DR```%@```.S(```$`````\D```@````(R0``!@```!')```-````
M&,D```8````FR0``'@```"W)```1````3,D``"(```!>R0``%@```(')```(
M````F,D```T```"AR0``#````*_)```'````O,D```,```#$R0```P```,C)
M```7````S,D``!,```#DR0``'0```/C)```(````%LH```0````?R@``"```
M`"3*```(````+<H``$$````VR@``(````'C*```&````F<H```8```"@R@``
M%0```*?*```8````O<H``"(```#6R@``+@```/G*```=````*,L``"$```!&
MRP``5````&C+```I````O<L```H```#GRP``!P```/++```5````^LL```X`
M```0S```"@```!_,```/````*LP```T````ZS```#P```$C,```-````6,P`
M``D```!FS```%````'#,```&````A<P``!@```",S```'0```*7,```3````
MP\P``!$```#7S```%````.G,```$````_LP```P````#S0``!@```!#-```/
M````%\T``!,````GS0``5````#O-```4````D,T``!<```"ES0``!````+W-
M```.````PLT``$0```#1S0``!0```!;.```%````',X``!L````BS@``&@``
M`#[.```1````6<X``!$```!KS@``$0```'W.```<````C\X``"H```"LS@``
M$````-?.```A````Z,X``"4````*SP``&0```##/```%````2L\``!,```!0
MSP``$@```&3/```*````=\\```\```""SP``#0```)+/```1````H,\``!,`
M``"RSP``#````,;/```&````T\\```P```#:SP``!@```.?/```7````[L\`
M`!`````&T```$0```!?0```(````*=````4````RT```#````#C0```0````
M1=````4```!6T```#0```%S0```&````:M````<```!QT```#0```'G0```0
M````A]````D```"8T```!P```*+0```+````JM````L```"VT```!P```,+0
M```'````RM````D```#2T```%````-S0```)````\=````H```#[T```&0``
M``;1```=````(-$```P````^T0``$````$O1```5````7-$```4```!RT0``
M)0```'C1```2````GM$``!,```"QT0``*P```,71```[````\=$``"`````M
MT@``-@```$[2```0````A=(```@```"6T@``#````)_2```&````K-(```0`
M``"ST@``#@```+C2```0````Q](```H```#8T@``#0```./2```>````\=(`
M`!L````0TP``(0```"S3```>````3M,``!D```!MTP``'@```(?3```=````
MIM,``!L```#$TP``(````.#3```N`````=0``!<````PU```)@```$C4```P
M````;]0``!L```"@U```'@```+S4```<````V]0``"8```#XU```*P```!_5
M```S````2]4``"8```!_U0``*P```*;5```X````TM4``!T````+U@``%0``
M`"G6```O````/]8``"````!OU@``$@```)#6```I````H]8``!X```#-U@``
M(0```.S6```2````#M<``*(````AUP``%@```,37```C````V]<``"@```#_
MUP``*0```"C8```H````4M@``!\```![V```%0```)O8```@````L=@``"4`
M``#2V```*````/C8```M````(=D``#````!/V0``D@```(#9```A````$]H`
M`!8````UV@``'````$S:```F````:=H``"H```"0V@``00```+O:``!$````
M_=H```P```!"VP``!P```$_;```'````5]L```8```!?VP``#0```&;;```0
M````=-L``!(```"%VP``$P```)C;```2````K-L```<```"_VP``!````,?;
M```0````S-L```P```#=VP``#@```.K;```/````^=L``!,````)W```#0``
M`!W<```H````*]P```,```!4W```#0```%C<```&````9MP``!$```!MW```
M%P```'_<```;````E]P```X```"SW````@```,+<```%````Q=P``!````#+
MW```!````-S<```-````X=P```X```#OW````P```/[<```.`````MT```@`
M```1W0``#P```!K=```(````*MT```\````SW0``!P```$/=```-````2]T`
M`!````!9W0``$P```&K=```3````?MT```L```"2W0``$0```)[=```)````
ML-T```8```"ZW0``#````,'=```1````SMT``!D```#@W0``"P```/K=```-
M````!MX``"(````4W@``&P```#?>```T````4]X```H```"(W@``&````)/>
M```9````K-X``!8```#&W@``+P```-W>```B````#=\```T````PWP``!P``
M`#[?```,````1M\``"8```!3WP``%````'K?```+````C]\``"(```";WP``
M+P```+[?```+````[M\```D```#ZWP``&0````3@```+````'N```!<````J
MX```%P```$+@```)````6N```!8```!DX```#P```'O@```6````B^````X`
M``"BX```&````+'@```(````RN````T```#3X```)@```.'@``!#````".$`
M``@```!,X0``$@```%7A```(````:.$```L```!QX0``+P```'WA```.````
MK>$```4```"\X0``!@```,+A```#````R>$```<```#-X0``!````-7A```*
M````VN$```H```#EX0``#P```/#A```0`````.(``!<````1X@``$0```"GB
M```9````.^(``!<```!5X@``"0```&WB```%````=^(```L```!]X@``"@``
M`(GB```"````E.(```4```"7X@``#0```)WB```;````J^(``!<```#'X@``
M"0```-_B```.````Z>(```T```#XX@``$@````;C```X````&>,``"````!2
MXP```P```'/C```(````=^,```X```"`XP``>P```(_C```8````"^0``$``
M```DY```$0```&7D```'````=^0```4```!_Y```(````(7D```8````IN0`
M`!D```"_Y```$P```-GD```'````[>0```<```#UY```"````/WD```&````
M!N4```8````-Y0``$````!3E```/````)>4``!`````UY0``#P```$;E```+
M````5N4```\```!BY0``#````'+E```/````?^4```<```"/Y0``"@```)?E
M```&````HN4```X```"IY0``#````+CE```H````Q>4```\```#NY0``"```
M`/[E```6````!^8```@````>Y@``$P```"?F```>````.^8``"$```!:Y@``
M(````'SF```9````G>8``!<```"WY@``)0```,_F```7````]>8``!X````-
MYP``)@```"SG```$````4^<``!L```!8YP``#0```'3G```,````@N<```,`
M``"/YP``"````)/G```*````G.<```P```"GYP``"P```+3G```0````P.<`
M``P```#1YP``!````-[G```3````X^<``!0```#WYP``#`````SH```)````
M&>@```X````CZ```"P```#+H```;````/N@```<```!:Z```!P```&+H```*
M````:N@```T```!UZ```"0```(/H```$````C>@```4```"2Z````P```)CH
M```8````G.@```H```"UZ```!````,#H```F````Q>@```X```#LZ```?```
M`/OH```5````>.D```4```".Z0``!P```)3I```,````G.D```@```"IZ0``
M"@```++I```&````O>D```@```#$Z0``%@```,WI```2````Y.D```(```#W
MZ0``!@```/KI```&`````>H``!0````(Z@``%0```!WJ```/````,^H``!$`
M``!#Z@``&@```%7J```-````<.H``!````!^Z@``&P```(_J```$````J^H`
M``D```"PZ@``$````+KJ```)````R^H```D```#5Z@``!0```-_J```%````
MY>H``!H```#KZ@``"`````;K```&````#^L``!D````6ZP``#@```##K```B
M````/^L```<```!BZP``!P```&KK```.````<NL```4```"!ZP``"0```(?K
M```*````D>L```(```"<ZP``!@```)_K```-````INL```D```"TZP``!@``
M`+[K```2````Q>L```D```#8ZP``!P```.+K```4````ZNL``!T```#_ZP``
M$0```!WL```&````+^P```H````V[```!````$'L```)````1NP```@```!0
M[```$0```%GL```1````:^P```D```!][```!@```(?L```-````CNP```8`
M``"<[```!````*/L```Y````J.P``#T```#B[```.@```"#M```>````6^T`
M``4```!Z[0``#@```(#M```$````C^T```8```"4[0``(0```)OM```-````
MO>T``!4```#+[0``!@```.'M```$````Z.T``!$```#M[0``!@```/_M``"@
M````!NX```H```"G[@``(@```++N```$````U>X``"4```#:[@``!0````#O
M```=````!N\```0````D[P``#````"GO```*````-N\```@```!![P``"0``
M`$KO```%````5.\``!L```!:[P``.@```';O```P````L>\``#4```#B[P``
M*0```!CP```N````0O```$<```!Q\```.````+GP```I````\O```#\````<
M\0``+@```%SQ```M````B_$``!\```"Y\0``#P```-GQ```2````Z?$```L`
M``#\\0``)@````CR```I````+_(``"0```!9\@``)@```'[R```(````I?(`
M``H```"N\@``"0```+GR```'````P_(``"````#+\@``(````.SR```F````
M#?,```H````T\P``&0```#_S```I````6?,``!8```"#\P``$@```)KS```'
M````K?,```H```"U\P``#````,#S```/````S?,``!````#=\P``0````.[S
M``!P````+_0``&8```"@]```#@````?U```)````%O4```H````@]0``$@``
M`"OU```3````/O4```P```!2]0``!@```%_U```/````9O4``!(```!V]0``
M$````(GU```*````FO4``!$```"E]0``$@```+?U```<````RO4``",```#G
M]0``:@````OV```/````=O8```4```"&]@``$````(SV```)````G?8```0`
M``"G]@``"P```*SV```:````N/8``!0```#3]@``#````.CV```,````]?8`
M``\````"]P``%0```!+W```I````*/<``"H```!2]P``)@```'WW```G````
MI/<``"D```#,]P``*@```/;W```9````(?@``$(````[^```$0```'[X```2
M````D/@``!,```"C^```%````+?X```/````S/@``!8```#<^```%P```//X
M```0````"_D``!$````<^0``-````"[Y```3````8_D``!(```!W^0``-0``
M`(KY```4````P/D```<```#5^0``#````-WY```K````ZOD``"`````6^@``
M%````#?Z```1````3/H``!<```!>^@``'````';Z```3````D_H``!0```"G
M^@``&@```+SZ```1````U_H``!H```#I^@``'@````3[```:````(_L``!,`
M```^^P``%0```%+[```1````:/L``!<```!Z^P``%````)+[```7````I_L`
M`!4```"_^P``"0```-7[```9````W_L```0```#Y^P``!P```/[[```+````
M!OP``!$````2_```!@```"3\```&````*_P```8````R_```!0```#G\```'
M````/_P```<```!'_```!0```$_\```6````5?P```8```!L_```!@```'/\
M```$````>OP```0```!__```!P```(3\```.````C/P```P```";_```#```
M`*C\```-````M?P```H```##_```#@```,[\```%````W?P``"@```#C_```
M#@````S]```,````&_T```\````H_0``"@```#C]```(````0_T```D```!,
M_0``*P```%;]```$````@OT```@```"'_0``)@```)#]```2````M_T```\`
M``#*_0``!@```-K]```*````X?T```<```#L_0``"````/3]```@````_?T`
M``D````>_@``#````"C^```-````-?X```X```!#_@``%@```%+^```1````
M:?X```8```![_@```P```(+^```&````AOX``!D```"-_@``!P```*?^```$
M````K_X```L```"T_@``"P```,#^```'````S/X```<```#4_@``%@```-S^
M```-````\_X```T````!_P``"@````__```0````&O\```\````K_P``$0``
M`#O_```7````3?\```H```!E_P``$0```'#_```(````@O\```0```"+_P``
M#P```)#_```Z````H/\```4```#;_P``#````.'_```>````[O\```X````-
M``$`$````!P``0`+````+0`!``P````Y``$`"0```$8``0`'````4``!``H`
M``!8``$`"0```&,``0`.````;0`!`!````!\``$`&@```(T``0`*````J``!
M``D```"S``$`%````+T``0`*````T@`!``P```#=``$`#P```.H``0`(````
M^@`!``8````#`0$`!P````H!`0`+````$@$!`$<````>`0$`#0```&8!`0`)
M````=`$!``0```!^`0$``P```(,!`0`3````AP$!`!,```";`0$`$P```*\!
M`0`*````PP$!``(```#.`0$`!````-$!`0`E````U@$!``,```#\`0$`!0``
M```"`0`J````!@(!``H````Q`@$`!0```#P"`0`$````0@(!``H```!'`@$`
M#0```%("`0!`````8`(!`!,```"A`@$`!@```+4"`0`(````O`(!``@```#%
M`@$`!````,X"`0`%````TP(!`&@```#9`@$`"0```$(#`0`,````3`,!``4`
M``!9`P$`!@```%\#`0`;````9@,!`"\```""`P$`$````+(#`0`*````PP,!
M``\```#.`P$`"@```-X#`0`)````Z0,!`!,```#S`P$`&P````<$`0`8````
M(P0!`!<````\!`$`#@```%0$`0`#````8P0!``<```!G!`$`"````&\$`0`4
M````>`0!`!,```"-!`$`$````*$$`0`-````L@0!``X```#`!`$`%@```,\$
M`0`'````Y@0!``H```#N!`$`"P```/D$`0`M````!04!`!4````S!0$`,```
M`$D%`0`D````>@4!``<```"?!0$`40```*<%`0`0````^04!``P````*!@$`
M#0```!<&`0`:````)08!`$H```!`!@$`&0```(L&`0`&````I08!`!H```"L
M!@$`!@```,<&`0`&````S@8!`!\```#5!@$`!@```/4&`0`)````_`8!`!@`
M```&!P$`%P```!\'`0`H````-P<!``8```!@!P$`#0```&<'`0`B````=0<!
M`%<```"8!P$`$P```/`'`0`C````!`@!`!,````H"`$``@```#P(`0`+````
M/P@!``@```!+"`$`#0```%0(`0`*````8@@!``8```!M"`$`!P```'0(`0`4
M````?`@!``8```"1"`$`"````)@(`0`.````H0@!``<```"P"`$`"@```+@(
M`0`+````PP@!``<```#/"`$`#````-<(`0`-````Y`@!``P```#R"`$`"0``
M`/\(`0`)````"0D!``H````3"0$`!P```!X)`0`)````)@D!``<````P"0$`
M"@```#@)`0`;````0PD!`!(```!?"0$`"@```'()`0`)````?0D!`!````"'
M"0$`!P```)@)`0`2````H`D!``0```"S"0$`!P```+@)`0`%````P`D!``P`
M``#&"0$`!0```-,)`0`+````V0D!`!0```#E"0$`$0```/H)`0`:````#`H!
M`!8````G"@$`%````#X*`0`7````4PH!`!@```!K"@$`'````(0*`0`9````
MH0H!``<```"["@$`!0```,,*`0`-````R0H!``P```#7"@$`"````.0*`0`7
M````[0H!``L````%"P$`#0```!$+`0`3````'PL!``0````S"P$`"@```#@+
M`0`$````0PL!``T```!("P$`#````%8+`0`%````8PL!``D```!I"P$`!0``
M`',+`0`'````>0L!``4```"!"P$`!````(<+`0`"````C`L!`#@```"/"P$`
M+````,@+`0`2````]0L!`"D````(#`$`,@```#(,`0`*````90P!`#8```!P
M#`$`+````*<,`0`5````U`P!`"X```#J#`$`,P```!D-`0`S````30T!`#@`
M``"!#0$`#P```+H-`0`8````R@T!`#L```#C#0$`$````!\.`0`/````,`X!
M`!0```!`#@$`$P```%4.`0`5````:0X!`!0```!_#@$`$@```)0.`0`4````
MIPX!`!4```"\#@$`+0```-(.`0`M``````\!`#$````N#P$`+0```&`/`0`N
M````C@\!`"\```"]#P$`+````.T/`0!B````&A`!`!,```!]$`$`"````)$0
M`0`(````FA`!`!L```"C$`$`*P```+\0`0`A````ZQ`!`!H````-$0$`"0``
M`"@1`0!%````,A$!`$$```!X$0$`#P```+H1`0`$````RA$!`!,```#/$0$`
M%````.,1`0`.````^!$!`!,````'$@$`&````!L2`0`&````-!(!``D````[
M$@$`"@```$42`0`/````4!(!`!````!@$@$`!P```'$2`0`.````>1(!``4`
M``"($@$`&P```(X2`0`&````JA(!``@```"Q$@$`!@```+H2`0`4````P1(!
M`!$```#6$@$`#@```.@2`0`X````]Q(!``(````P$P$`!@```#,3`0`.````
M.A,!`!H```!)$P$`!0```&03`0`'````:A,!``X```!R$P$`!@```($3`0`-
M````B!,!``0```"6$P$`*0```)L3`0`7````Q1,!`!\```#=$P$`7````/T3
M`0`4````6A0!`#X```!O%`$`'P```*X4`0`0````SA0!`!0```#?%`$`!P``
M`/04`0`.````_!0!``@````+%0$`#````!05`0`,````(14!`!,````N%0$`
M"@```$(5`0`=````314!`!D```!K%0$`!0```(45`0`1````BQ4!`!$```"=
M%0$`)````*\5`0`5````U!4!`!(```#J%0$`#@```/T5`0`9````#!8!``@`
M```F%@$`"0```"\6`0`-````.18!``H```!'%@$`!P```%(6`0`/````6A8!
M``8```!J%@$`"P```'$6`0`*````?18!``<```"(%@$`"````)`6`0`%````
MF18!`!\```"?%@$`!@```+\6`0`0````QA8!``@```#7%@$`#0```.`6`0`B
M````[A8!``@````1%P$`%P```!H7`0`2````,A<!`"P```!%%P$`+P```'(7
M`0`L````HA<!`"H```#/%P$`*P```/H7`0`L````)A@!`!H```!3&`$`"0``
M`&X8`0`*````>!@!`!4```"#&`$`!0```)D8`0`4````GQ@!``0```"T&`$`
M$````+D8`0`&````RA@!``<```#1&`$`'@```-D8`0`H````^!@!``H````A
M&0$`'````"P9`0`:````21D!``\```!D&0$`%````'09`0`$````B1D!``0`
M``".&0$`"P```),9`0`%````GQD!``8```"E&0$`"````*P9`0`&````M1D!
M``H```"\&0$`&P```,<9`0`T````XQD!`#0````8&@$`(````$T:`0`I````
M;AH!`"````"8&@$`00```+D:`0`:````^QH!`!T````6&P$`*````#0;`0`D
M````71L!`"D```""&P$`40```*P;`0`O````_AL!`%<````N'`$`+````(8<
M`0`B````LQP!`!\```#6'`$`!@```/8<`0`(````_1P!``4````&'0$`"```
M``P=`0`9````%1T!`!D````O'0$`*@```$D=`0`C````=!T!`"X```"8'0$`
M-````,<=`0`(````_!T!`!<````%'@$`"@```!T>`0`'````*!X!`"$````P
M'@$`$````%(>`0`.````8QX!``L```!R'@$`!P```'X>`0`3````AAX!``@`
M``":'@$`"P```*,>`0`*````KQX!`!0```"Z'@$`#P```,\>`0`R````WQX!
M``L````2'P$`!0```!X?`0`%````)!\!`!<````J'P$`#P```$(?`0`$````
M4A\!``H```!7'P$`"0```&(?`0`+````;!\!``T```!X'P$`#````(8?`0`.
M````DQ\!``4```"B'P$`!````*@?`0`-````K1\!`#(```"['P$`10```.X?
M`0`7````-"`!`!X```!,(`$`%````&L@`0`%````@"`!`!0```"&(`$`!P``
M`)L@`0`C````HR`!``X```#'(`$`*@```-8@`0`&`````2$!``P````((0$`
M#0```!4A`0`1````(R$!`!<````U(0$`"P```$TA`0`V````62$!``H```"0
M(0$`(@```)LA`0`+````OB$!``\```#*(0$`"P```-HA`0`@````YB$!`"<`
M```'(@$`*P```"\B`0`)````6R(!`#(```!E(@$`)0```)@B`0`P````OB(!
M`#$```#O(@$`+0```"$C`0`_````3R,!`#T```"/(P$`-@```,TC`0`.````
M!"0!`!0````3)`$`!0```"@D`0`.````+B0!`!,````])`$`!P```%$D`0`:
M````620!``@```!T)`$`$0```'TD`0`'````CR0!`!0```"7)`$`&````*PD
M`0`'````Q20!``4```#-)`$`#````-,D`0`,````X"0!`!(```#M)`$`!```
M```E`0`'````!24!``H````-)0$`"P```!@E`0`,````)"4!``X````Q)0$`
M#@```$`E`0`%````3R4!``4```!5)0$`+@```%LE`0`F````BB4!`",```"Q
M)0$``P```-4E`0`2````V24!``8```#L)0$`'@```/,E`0`8````$B8!`"4`
M```K)@$`#0```%$F`0`)````7R8!``,```!I)@$`!P```&TF`0`*````=28!
M``(```"`)@$`#````(,F`0`5````D"8!``L```"F)@$`&0```+(F`0`@````
MS"8!`!(```#M)@$`!0`````G`0`*````!B<!`!4````1)P$`$@```"<G`0`,
M````.B<!``0```!')P$`!P```$PG`0`)````5"<!``P```!>)P$`4@```&LG
M`0`7````OB<!`"0```#6)P$`$@```/LG`0`'````#B@!``8````6*`$`#@``
M`!TH`0`B````+"@!`!T```!/*`$`#````&TH`0`-````>B@!`!4```"(*`$`
M$@```)XH`0`/````L2@!`!0```#!*`$`&P```-8H`0`0````\B@!`&D````#
M*0$`&@```&TI`0`7````B"D!`"<```"@*0$`&@```,@I`0`7````XRD!`!L`
M``#[*0$`&0```!<J`0`?````,2H!`!<```!1*@$`$P```&DJ`0`(````?2H!
M``<```"&*@$`"````(XJ`0`)````ERH!`!4```"A*@$`#0```+<J`0`C````
MQ2H!`!,```#I*@$``P```/TJ`0!&`````2L!`#\```!(*P$`-P```(@K`0!7
M````P"L!``4````8+`$`'P```!XL`0`O````/BP!``H```!N+`$`"````'DL
M`0`-````@BP!`"T```"0+`$`!````+XL`0!/````PRP!`"4````3+0$`'```
M`#DM`0`+````5BT!`!\```!B+0$`'0```((M`0`E````H"T!`"````#&+0$`
M)````.<M`0`@````#"X!``L````M+@$`!P```#DN`0`-````02X!``P```!/
M+@$`%P```%PN`0`&````="X!`#D```![+@$`#````+4N`0`'````PBX!`!D`
M``#*+@$`"0```.0N`0`3````[BX!``D````"+P$`!`````PO`0`0````$2\!
M``H````B+P$`"````"TO`0`(````-B\!``0````_+P$`"P```$0O`0`,````
M4"\!`!(```!=+P$`$0```'`O`0`,````@B\!`!H```"/+P$`#P```*HO`0`'
M````NB\!``T```#"+P$`%````-`O`0`.````Y2\!``P```#T+P$`&P````$P
M`0`L````'3`!`!,```!*,`$`'````%XP`0`H````>S`!``8```"D,`$`!P``
M`*LP`0`3````LS`!``4```#',`$`!````,TP`0`7````TC`!``H```#J,`$`
M#````/4P`0`)`````C$!``8````,,0$`"0```!,Q`0`(````'3$!``D````F
M,0$`!0```#`Q`0`*````-C$!`!$```!!,0$`!@```%,Q`0`8````6C$!``X`
M``!S,0$`#@```((Q`0`-````D3$!``L```"?,0$`'0```*LQ`0`+````R3$!
M``(```#5,0$`'````-@Q`0`'````]3$!``8```#],0$`90````0R`0`)````
M:C(!``<```!T,@$`)@```'PR`0`X````HS(!`!H```#<,@$`*@```/<R`0`[
M````(C,!`"@```!>,P$`-````(<S`0`9````O#,!`!4```#6,P$`!0```.PS
M`0`'````\C,!``@```#Z,P$`!P````,T`0`%````"S0!``<````1-`$`#@``
M`!DT`0`)````*#0!``8````R-`$`"````#DT`0`+````0C0!``<```!.-`$`
M"````%8T`0`'````7S0!`!8```!G-`$`"0```'XT`0`&````B#0!``L```"/
M-`$`'````)LT`0`4````N#0!``<```#--`$`$0```-4T`0`(````YS0!``X`
M``#P-`$`"````/\T`0`%````"#4!`!`````.-0$`$````!\U`0`&````,#4!
M`!D````W-0$`"@```%$U`0`<````7#4!``<```!Y-0$`!0```($U`0`0````
MAS4!`!0```"8-0$`"P```*TU`0`-````N34!`!@```#'-0$`%P```.`U`0`:
M````^#4!`!0````3-@$`!````"@V`0`)````+38!``H````W-@$`!P```$(V
M`0`"````2C8!``X```!--@$`"````%PV`0`?````938!`#X```"%-@$`(P``
M`,0V`0`X````Z#8!`#$````A-P$`)P```%,W`0!D````>S<!`!0```#@-P$`
M'````/4W`0!5````$C@!`#@```!H.`$`2@```*$X`0!;````[#@!`"@```!(
M.0$`.````'$Y`0`J````JCD!`"@```#5.0$`+````/XY`0`G````*SH!`!L`
M``!3.@$`/@```&\Z`0"I`0``KCH!`"@```!8/`$`(P```($\`0`7````I3P!
M`$@```"]/`$`A0````8]`0`P````C#T!`$$```"]/0$`6P```/\]`0!)````
M6SX!`!T```"E/@$`&````,,^`0`A````W#X!`!\```#^/@$`*P```!X_`0`A
M````2C\!`"D```!L/P$`)P```)8_`0`=````OC\!`!$```#</P$`,P```.X_
M`0`E````(D`!`#@```!(0`$`)P```(%``0`@````J4`!`!\```#*0`$`,```
M`.I``0!I````&T$!`"L```"%00$`,0```+%!`0!!````XT$!`#,````E0@$`
M)0```%E"`0`]````?T(!`&4```"]0@$`30```"-#`0`O````<4,!`"X```"A
M0P$`*P```-!#`0`P````_$,!`"H````M1`$`/@```%A$`0!4````ET0!`(,`
M``#L1`$`6@```'!%`0!(````RT4!`$H````41@$`,@```%]&`0`=````DD8!
M`",```"P1@$`+P```-1&`0`L````!$<!`"T````Q1P$`<0```%]'`0!O````
MT4<!`+,```!!2`$`%P```/5(`0`E````#4D!`#(````S20$`*0```&9)`0`^
M````D$D!`"(```#/20$`4@```/))`0`E````14H!``L```!K2@$`L0```'=*
M`0!%````*4L!`"$```!O2P$`+@```)%+`0`P````P$L!`"4```#Q2P$`'```
M`!=,`0`Q````-$P!``<```!F3`$`!P```&Y,`0`$````=DP!``T```![3`$`
M"P```(E,`0`.````E4P!``L```"D3`$`!0```+!,`0`0````MDP!``(```#'
M3`$`60```,I,`0`%````)$T!`!(````J30$`!````#U-`0`'````0DT!``@`
M``!*30$`!0```%--`0`#````64T!`!````!=30$`"@```&Y-`0`,````>4T!
M`!,```"&30$`#0```)I-`0`"````J$T!``<```"K30$`!@```+--`0`4````
MNDT!``P```#/30$`&````-Q-`0`&````]4T!`!(```#\30$`#`````].`0`#
M````'$X!`"H````@3@$`!````$M.`0`&````4$X!``<```!73@$`'P```%].
M`0`U````?TX!`"X```"U3@$`+P```.1.`0`7````%$\!`"`````L3P$`&P``
M`$U/`0`8````:4\!`"0```""3P$`'P```*=/`0`:````QT\!`"````#B3P$`
M&@````-0`0`R````'E`!`!H```!14`$`+P```&Q0`0`K````G%`!`!\```#(
M4`$`(P```.A0`0`?````#%$!`!H````L40$`)0```$=1`0`F````;5$!`"4`
M``"440$`)````+I1`0`8````WU$!`!T```#X40$`)````!92`0`8````.U(!
M`"(```!44@$`%0```'=2`0`E````C5(!`#P```"S4@$`'P```/!2`0`C````
M$%,!`!\````T4P$`(````%13`0`:````=5,!`!@```"04P$`)@```*E3`0`>
M````T%,!`"D```#O4P$`'@```!E4`0`)````.%0!``P```!"5`$`%P```$]4
M`0`O````9U0!`"0```"75`$`!P```+Q4`0`?````Q%0!``\```#D5`$`%```
M`/14`0`.````"54!``T````850$`)````"95`0`%````2U4!``<```!150$`
M(@```%E5`0`E````?%4!`!,```"B50$`&@```+95`0`=````T54!`!H```#O
M50$`!P````I6`0#'````$E8!``L```#:5@$`%0```.96`0`,````_%8!``8`
M```)5P$`"0```!!7`0`8````&E<!``L````S5P$`#0```#]7`0`=````35<!
M`!<```!K5P$`!@```(-7`0`S````BE<!`!,```"^5P$`$P```-)7`0`'````
MYE<!``8```#N5P$`#P```/57`0`'````!5@!`#(````-6`$`(0```$!8`0`3
M````8E@!``P```!V6`$`$0```(-8`0`R````E5@!``X```#(6`$`#P```-=8
M`0`0````YU@!``@```#X6`$`'0````%9`0`)````'UD!``H````I60$`!0``
M`#19`0`4````.ED!``H```!/60$`'0```%I9`0`(````>%D!`!\```"!60$`
M"````*%9`0`:````JED!`"<```#%60$`!@```.U9`0`5````]%D!``<````*
M6@$`"````!):`0`)````&UH!`#\````E6@$`!P```&5:`0`/````;5H!``X`
M``!]6@$`$````(Q:`0`)````G5H!``D```"G6@$`"````+%:`0`3````NEH!
M``<```#.6@$`&0```-9:`0`*````\%H!``H```#[6@$`"0````9;`0`7````
M$%L!`!0````H6P$`"@```#U;`0`,````2%L!`!<```!56P$`!````&U;`0`J
M````<EL!`!$```"=6P$`!P```*];`0`)````MUL!``(```#!6P$`$````,1;
M`0`8````U5L!``L```#N6P$``P```/I;`0`(````_EL!``8````'7`$`!P``
M``Y<`0`-````%EP!``L````D7`$`%````#!<`0`5````15P!``X```!;7`$`
M+P```&I<`0`@````FEP!`!P```"[7`$`#````-A<`0`Q````Y5P!``4````7
M70$`$@```!U=`0`_````,%T!`!(```!P70$`"@```(-=`0`&````CET!``0`
M``"570$`!````)I=`0`*````GUT!`!,```"J70$`!0```+Y=`0`&````Q%T!
M``8```#+70$`"0```-)=`0`$````W%T!``P```#A70$`"@```.Y=`0`@````
M^5T!``4````:7@$`&````"!>`0`9````.5X!`!\```!37@$`'0```'->`0`1
M````D5X!``(```"C7@$`!````*9>`0`*````JUX!``8```"V7@$`!0```+U>
M`0`#````PUX!``P```#'7@$`10```-1>`0`:````&E\!`#4````U7P$`)0``
M`&M?`0`H````D5\!`%,```"Z7P$`&0````Y@`0!R````*&`!`"````";8`$`
M-0```+Q@`0`A````\F`!`$4````480$`,````%IA`0`C````BV$!`!\```"O
M80$`*````,]A`0`I````^&$!`"8````B8@$`)0```$EB`0`H````;V(!`"@`
M``"88@$`(@```,%B`0`A````Y&(!`"L````&8P$`,````#)C`0`2````8V,!
M`!,```!V8P$`$````(IC`0!Y````FV,!``D````59`$`<@```!]D`0!S````
MDF0!`'P````&90$`*P```(-E`0!4````KV4!`!<````$9@$`%@```!QF`0`/
M````,V8!`&4```!#9@$`'P```*EF`0!1````R68!`#<````;9P$`-@```%-G
M`0`V````BF<!`#X```#!9P$`00````!H`0!#````0F@!`'P```"&:`$`0```
M``-I`0`^````1&D!`$````"#:0$`0@```,1I`0`Y````!VH!`!\```!!:@$`
M0````&%J`0`?````HFH!`!P```#":@$`40```-]J`0`;````,6L!`!0```!-
M:P$`"@```&)K`0`%````;6L!``8```!S:P$`"````'IK`0`%````@VL!`!(`
M``"):P$`$````)QK`0`3````K6L!`!T```#!:P$`#P```-]K`0`/````[VL!
M``0```#_:P$`"0````1L`0`+````#FP!``<````:;`$`!0```")L`0`4````
M*&P!``<````];`$`"````$5L`0`/````3FP!``@```!>;`$`#````&=L`0`/
M````=&P!``8```"$;`$`%````(ML`0`&````H&P!``P```"G;`$`%0```+1L
M`0`(````RFP!``0```#3;`$`"@```-AL`0`$````XVP!``8```#H;`$`!P``
M`.]L`0`$````]VP!``<```#\;`$`&0````1M`0`"````'FT!``(````A;0$`
M"0```"1M`0`&````+FT!`!4````U;0$`!@```$MM`0`G````4FT!``(```!Z
M;0$`!````'UM`0`+````@FT!``D```".;0$`#P```)AM`0`3````J&T!``<`
M``"\;0$`!P```,1M`0`&````S&T!``8```#3;0$`$````-IM`0`2````ZVT!
M``(```#^;0$`!@````%N`0`)````"&X!`#,````2;@$`(@```$9N`0`'````
M:6X!``<```!Q;@$`!P```'EN`0`+````@6X!``4```"-;@$``@```)-N`0`+
M````EFX!`%@!``"B;@$`30```/MO`0"Z````27`!`$`````$<0$`O0```$5Q
M`0!_`````W(!`$@```"#<@$`-P```,QR`0`D````!',!`#<````I<P$`,@``
M`&%S`0`Q````E',!`$@```#&<P$`2P````]T`0!+````6W0!`$@```"G=`$`
M2P```/!T`0!-````/'4!`#L```"*=0$`1@```,9U`0`[````#78!`"T```!)
M=@$`20```'=V`0!&````P78!`$L````(=P$`,P```%1W`0`V````B'<!`&P`
M``"_=P$`*@```"QX`0`>````5W@!`*P```!V>`$`.0```"-Y`0`>`0``77D!
M`#\```!\>@$`+@```+QZ`0"Q````ZWH!`#\```"=>P$`$P```-U[`0`1````
M\7L!``X````#?`$`"0```!)\`0`+````''P!``@````H?`$``0```#%\`0`:
M````,WP!`"H```!.?`$`(0```'E\`0`B````FWP!`!H```"^?`$`$@```-E\
M`0`+````['P!`!<```#X?`$`*````!!]`0`2````.7T!``T```!,?0$`"P``
M`%I]`0`.````9GT!``4```!U?0$`(P```'M]`0`*````GWT!`!````"J?0$`
M#@```+M]`0`2````RGT!``\```#=?0$`+P```.U]`0`7````'7X!`"<````U
M?@$`&P```%U^`0`O````>7X!`!4```"I?@$`$````+]^`0`,````T'X!``\`
M``#=?@$`,````.U^`0`H````'G\!`"@```!'?P$`#````'!_`0`>````?7\!
M`",```"<?P$`)P```,!_`0`0````Z'\!``X```#Y?P$`$`````B``0`1````
M&8`!``8````K@`$`'````#*``0`5````3X`!`!4```!E@`$`#0```'N``0`;
M````B8`!`!4```"E@`$`%0```+N``0`)````T8`!``H```#;@`$`2P```.:`
M`0`\````,H$!`!4```!O@0$`,````(6!`0!#````MH$!`%X```#Z@0$`8```
M`%F"`0!<````NH(!`&8````7@P$`,@```'Z#`0`.````L8,!``D```#`@P$`
M$@```,J#`0`'````W8,!``H```#E@P$`#@```/"#`0`%````_X,!``8````%
MA`$`$@````R$`0`*````'X0!``D````JA`$`#0```#2$`0`.````0H0!``H`
M``!1A`$`$0```%R$`0`N````;H0!`"T```"=A`$`%@```,N$`0`6````XH0!
M``H```#YA`$`"0````2%`0`%````#H4!``X````4A0$`#P```".%`0`,````
M,X4!`!````!`A0$`$0```%&%`0`;````8X4!`!8```!_A0$`%````):%`0`,
M````JX4!`!,```"XA0$`"@```,R%`0`H````UX4!`!<`````A@$`%````!B&
M`0`5````+88!``X```!#A@$`6P```%*&`0`X````KH8!`"0```#GA@$`(0``
M``R'`0`&````+H<!``L````UAP$`.0```$&'`0`(````>X<!``D```"$AP$`
M"P```(Z'`0`'````FH<!``<```"BAP$`!0```*J'`0`%````L(<!``<```"V
MAP$`!@```+Z'`0`>````Q8<!``T```#DAP$`#P```/*'`0`9`````H@!`!4`
M```<B`$`)P```#*(`0`.````6H@!`"<```!IB`$`'````)&(`0`B````KH@!
M`"(```#1B`$`%0```/2(`0`6````"HD!`!(````AB0$`%P```#2)`0`:````
M3(D!``<```!GB0$`!@```&^)`0`(````=HD!``X```!_B0$`!P```(Z)`0`)
M````EHD!`!(```"@B0$`!P```+.)`0`,````NXD!`!(```#(B0$`(0```-N)
M`0`'````_8D!``T````%B@$`"````!.*`0`5````'(H!``P````RB@$`#```
M`#^*`0`_````3(H!`#\```",B@$`"0```,R*`0`'````UHH!`!,```#>B@$`
M!0```/**`0`%````^(H!`!````#^B@$`"P````^+`0`6````&XL!`#8````R
MBP$`$````&F+`0!&````>HL!`"4```#!BP$`)P```.>+`0`G````#XP!`"0`
M```WC`$`#````%R,`0`/````:8P!``8```!YC`$`"0```(",`0`(````BHP!
M`#8```"3C`$`/P```,J,`0`U````"HT!`%T```!`C0$`-````)Z-`0`T````
MTXT!`#0````(C@$`1P```#V.`0`H````A8X!`"H```"NC@$`-````-F.`0`Z
M````#H\!`!D```!)CP$`'0```&./`0`N````@8\!`"L```"PCP$`&P```-R/
M`0`3````^(\!``L````,D`$`#P```!B0`0`E````*)`!``8```!.D`$`"@``
M`%60`0`8````8)`!`!X```!YD`$`!@```)B0`0`'````GY`!`!0```"GD`$`
M"@```+R0`0`(````QY`!`"X```#0D`$`"@```/^0`0`,````"I$!``8````7
MD0$`!@```!Z1`0`%````)9$!``<````KD0$`!@```#.1`0`,````.I$!`"@`
M``!'D0$`#P```'"1`0`,````@)$!``D```"-D0$`!P```)>1`0`,````GY$!
M``4```"LD0$`#P```+*1`0`&````PI$!`!(```#)D0$`"````-R1`0`(````
MY9$!``0```#ND0$`#0```/.1`0`(`````9(!`"<````*D@$`$````#*2`0`K
M````0Y(!`"````!OD@$`"````)"2`0`-````F9(!``P```"GD@$`!P```+22
M`0`#````O)(!``,```#`D@$`$P```,22`0`0````V)(!`"P```#ID@$`"0``
M`!:3`0`%````(),!``D````FDP$`!P```#"3`0!&````.),!`"8```!_DP$`
M!@```*:3`0`$````K9,!`!(```"RDP$`(````,63`0`A````YI,!`"X````(
ME`$`(0```#>4`0`H````690!`&$```""E`$`*0```.24`0`)````#I4!``H`
M```8E0$`%0```".5`0`-````.94!``P```!'E0$`#````%25`0`,````894!
M``P```!NE0$`#````'N5`0`,````B)4!`!0```"5E0$`"@```*J5`0`7````
MM94!`!L```#-E0$`$0```.F5`0`3````^Y4!`!4````/E@$`!````"66`0`-
M````*I8!``4````XE@$`$0```#Z6`0`0````4)8!`$L```!AE@$`$0```*V6
M`0`;````OY8!``8```#;E@$`$P```.*6`0`T````]I8!``4````KEP$`!0``
M`#&7`0`?````-Y<!`!@```!7EP$`$````'"7`0`6````@9<!`!$```"8EP$`
M'P```*J7`0`P````RI<!``L```#[EP$`(`````>8`0`H````*)@!`!T```!1
MF`$`!@```&^8`0`5````=I@!`!,```",F`$`#P```*"8`0`7````L)@!`!0`
M``#(F`$`%````-V8`0`7````\I@!``P````*F0$`!@```!>9`0`/````'ID!
M``@````NF0$`%P```#>9`0`4````3YD!`!(```!DF0$`"````'>9`0`$````
M@)D!``P```"%F0$`"P```)*9`0`&````GID!`!,```"EF0$`"@```+F9`0`'
M````Q)D!``T```#,F0$`%````-J9`0`(````[YD!``D```#XF0$`#0````*:
M`0`,````$)H!``<````=F@$`!@```"6:`0`*````+)H!`!0````WF@$`"P``
M`$R:`0`*````6)H!``\```!CF@$`'P```'.:`0`2````DYH!`"H```"FF@$`
M%@```-&:`0`%````Z)H!`!\```#NF@$`$P````Z;`0`4````(IL!`#,````W
MFP$`0@```&N;`0`D````KIL!`"8```#3FP$`#@```/J;`0`%````"9P!``L`
M```/G`$`!@```!N<`0`&````(IP!``X````IG`$`$0```#B<`0`*````2IP!
M`!$```!5G`$`)````&><`0`P````C)P!`"<```"]G`$`,P```.6<`0`;````
M&9T!`",````UG0$`(````%F=`0`=````>IT!`"(```"8G0$`.0```+N=`0`;
M````]9T!`!\````1G@$`-````#&>`0`F````9IX!`"D```"-G@$`(0```+>>
M`0`A````V9X!`"<```#[G@$`0@```".?`0`A````9I\!`"$```"(GP$`*P``
M`*J?`0`?````UI\!`!\```#VGP$`.@```!:@`0`B````4:`!`!4```!TH`$`
M)P```(J@`0`@````LJ`!`"X```#3H`$`%0````*A`0"2````&*$!`!H```"K
MH0$`'P```,:A`0`?````YJ$!`"`````&H@$`+@```">B`0`=````5J(!`!\`
M``!TH@$`(````)2B`0`L````M:(!`"X```#BH@$`,````!&C`0`O````0J,!
M`*$```!RHP$`*P```!2D`0`@````0*0!`"0```!AI`$`(P```(:D`0`L````
MJJ0!`$````#7I`$`1````!BE`0`/````7:4!``,```!MI0$`!P```'&E`0`#
M````>:4!``\```!]I0$`"````(VE`0`9````EJ4!`!(```"PI0$`$@```,.E
M`0`'````UJ4!``4```#>I0$`&0```.2E`0`9````_J4!``\````8I@$`$@``
M`"BF`0`/````.Z8!``X```!+I@$`3@```%JF`0`'````J:8!``\```"QI@$`
M!@```,&F`0`3````R*8!`!D```#<I@$`&P```/:F`0`0````$J<!``(````C
MIP$`"@```":G`0`/````,:<!``<```!!IP$`&````$FG`0`3````8J<!``4`
M``!VIP$`#@```'RG`0`(````BZ<!`!````"4IP$`"@```*6G`0`3````L*<!
M``8```#$IP$`"@```,NG`0`.````UJ<!``X```#EIP$`#@```/2G`0`+````
M`Z@!`!`````/J`$`"P```""H`0`&````+*@!``P````SJ`$`#0```$"H`0`4
M````3J@!``L```!CJ`$`#0```&^H`0`J````?:@!`!<```"HJ`$`00```,"H
M`0`+`````JD!`!<````.J0$`%0```":I`0`3````/*D!`$L```!0J0$`'P``
M`)RI`0`,````O*D!``8```#)J0$`#0```-"I`0`D````WJD!``\````#J@$`
M!@```!.J`0`Y````&JH!`#@```!4J@$`!P```(VJ`0`,````E:H!`!\```"B
MJ@$`#@```,*J`0`:````T:H!`!H```#LJ@$`"0````>K`0`=````$:L!`!$`
M```OJP$`'````$&K`0`*````7JL!`!,```!IJP$`"````'VK`0`.````AJL!
M`"0```"5JP$`0````+JK`0`.````^ZL!`!@````*K`$`"````".L`0`+````
M+*P!`"0````XK`$`#P```%VL`0`'````;:P!`!````!UK`$`!0```(:L`0`'
M````C*P!``<```"4K`$`#@```)RL`0`.````JZP!`!````"ZK`$`$0```,NL
M`0`6````W:P!`!(```#TK`$`&`````>M`0`8````(*T!``@````YK0$`!@``
M`$*M`0`+````2:T!``P```!5K0$``@```&*M`0`*````9:T!`!````!PK0$`
M)P```(&M`0`9````J:T!``8```##K0$`#0```,JM`0`.````V*T!``\```#G
MK0$`.@```/>M`0`M````,JX!``<```!@K@$`#@```&BN`0`1````=ZX!`&<`
M``")K@$`%````/&N`0!0````!J\!`!8```!7KP$`!P```&ZO`0`%````=J\!
M`#D```!\KP$`(@```+:O`0`:````V:\!`!L```#TKP$`!P```!"P`0`%````
M&+`!``<````>L`$`!P```":P`0`(````+K`!`!(````WL`$`$0```$JP`0`2
M````7+`!`!$```!OL`$`(````(&P`0`4````HK`!``\```"WL`$`#P```,>P
M`0`'````U[`!``P```#?L`$`"````.RP`0`4````];`!`!8````*L0$`,```
M`"&Q`0`/````4K$!``H```!BL0$`$@```&VQ`0`'````@+$!`"````"(L0$`
M&P```*FQ`0`D````Q;$!`",```#JL0$`'P````ZR`0`?````+K(!`"D```!.
ML@$`'````'BR`0`8````E;(!`",```"NL@$`!@```-*R`0`<````V;(!``H`
M``#VL@$`#0````&S`0`%````#[,!``@````5LP$`"P```!ZS`0`-````*K,!
M`!`````XLP$`%````$FS`0`.````7K,!``4```!MLP$`(@```'.S`0`C````
MEK,!`!````"ZLP$`#@```,NS`0`1````VK,!`!````#LLP$`*````/VS`0`+
M````)K0!``4````RM`$`%````#BT`0`5````3;0!``P```!CM`$`#0```'"T
M`0`'````?K0!``0```"&M`$`'````(NT`0`/````J+0!``4```"XM`$`(0``
M`+ZT`0`-````X+0!`),```#NM`$`%0```(*U`0`)````F+4!``H```"BM0$`
M$P```*VU`0`,````P;4!``X```#.M0$`"````-VU`0`2````YK4!`!<```#Y
MM0$`%@```!&V`0`"````*+8!``@````KM@$`!@```#2V`0`1````.[8!`!0`
M``!-M@$`%0```&*V`0`4````>+8!`!X```"-M@$`#@```*RV`0`1````N[8!
M`!T```#-M@$`"0```.NV`0`*````];8!``\`````MP$`"````!"W`0`)````
M&;<!``P````CMP$`!0```#"W`0`<````-K<!``D```!3MP$`!@```%VW`0`0
M````9+<!``\```!UMP$`)P```(6W`0`'````K;<!``4```"UMP$`#@```+NW
M`0`%````RK<!``D```#0MP$`!P```-JW`0`$````XK<!``4```#GMP$`"P``
M`.VW`0`*````^;<!``<````$N`$`%`````RX`0`)````(;@!``<````KN`$`
M#P```#.X`0`C````0[@!`!0```!GN`$`!@```'RX`0`*````@[@!``0```".
MN`$`"0```).X`0`(````G;@!`!0```"FN`$`%````+NX`0`+````T+@!``8`
M``#<N`$`#0```..X`0`&````\;@!``0```#XN`$`1@```/VX`0!/````1+D!
M`$L```"4N0$`(````."Y`0`%`````;H!``X````'N@$`!````!:Z`0`&````
M&[H!`!@````BN@$`%````#NZ`0`5````4+H!``<```!FN@$`!````&ZZ`0`6
M````<[H!``0```"*N@$`L0```(^Z`0`/````0;L!`!L```!1NP$`!@```&V[
M`0`O````=+L!``4```"DNP$`)P```*J[`0`$````TKL!``H```#7NP$`#0``
M`.*[`0`(````\+L!``D```#YNP$`!0````.\`0`7````";P!`#`````AO`$`
M,@```%*\`0`Z````A;P!`"````#`O`$`,````.&\`0!)````$KT!`#D```!<
MO0$`*0```):]`0`X````P+T!`"H```#YO0$`+````"2^`0`A````4;X!`!$`
M``!SO@$`$````(6^`0`+````EKX!`"4```"BO@$`)P```,B^`0`A````\+X!
M`",````2OP$`!P```#:_`0`)````/K\!``H```!(OP$`!@```%._`0`I````
M6K\!`"D```"$OP$`,@```*Z_`0`)````X;\!`!\```#KOP$`+0````O``0`6
M````.<`!`!$```!0P`$`!P```&+``0`+````:L`!``T```!VP`$`$````(3`
M`0`/````E<`!`$````"EP`$`C0```.;``0!D````=,$!`!$```#9P0$`"```
M`.O!`0`)````],$!`!````#^P0$`$0````_"`0`,````(<(!``4````NP@$`
M$````#3"`0`0````1<(!``X```!6P@$`"````&7"`0`3````;L(!``X```""
MP@$`'````)'"`0`F````KL(!`'0```#5P@$`$````$K#`0`%````6\,!`!4`
M``!APP$`"0```'?#`0`$````@<,!``L```"&PP$`&@```)+#`0`5````K<,!
M``H```##PP$`#@```,[#`0`0````W<,!`!,```#NPP$`(@````+$`0`@````
M)<0!`"````!&Q`$`'@```&?$`0`D````AL0!`"(```"KQ`$`&@```,[$`0`U
M````Z<0!`!(````?Q0$`$````#+%`0`2````0\4!`!(```!6Q0$`%````&G%
M`0`5````?L4!`!,```"4Q0$`$````*C%`0`2````N<4!`"D```#,Q0$`$P``
M`/;%`0`5````"L8!`$@````@Q@$`'````&G&`0`,````AL8!`!$```"3Q@$`
M+@```*7&`0`A````U,8!`!$```#VQ@$`$@````C'`0`=````&\<!`!\````Y
MQP$`%@```%G'`0`7````<,<!`"````"(QP$`$P```*G'`0`=````O<<!`"``
M``#;QP$`)0```/S'`0`4````(L@!`!0````WR`$`%````$S(`0`<````8<@!
M`!4```!^R`$`%0```)3(`0`9````JL@!``L```#$R`$`'````-#(`0`$````
M[<@!``<```#RR`$`"0```/K(`0`7````!,D!``8````<R0$`$0```"/)`0`*
M````-<D!``8```!`R0$`!P```$?)`0`(````3\D!``8```!8R0$`%````%_)
M`0`&````=,D!``@```![R0$`"````(3)`0`'````C<D!``<```"5R0$`$```
M`)W)`0`.````KLD!`!(```"]R0$`$````-#)`0`)````X<D!`!4```#KR0$`
M!0````'*`0`P````!\H!`!,````XR@$`#@```$S*`0`0````6\H!``X```!L
MR@$`#@```'O*`0`.````BLH!`"L```"9R@$`!@```,7*`0`(````S,H!`#8`
M``#5R@$`'@````S+`0`.````*\L!``8````ZRP$`"0```$'+`0`)````2\L!
M``4```!5RP$`(P```%O+`0`5````?\L!`!8```"5RP$`%````*S+`0`A````
MP<L!`"4```#CRP$`+0````G,`0`&````-\P!``0````^S`$`"````$/,`0`<
M````3,P!``<```!IS`$`!0```'',`0`,````=\P!``P```"$S`$`!@```)',
M`0`'````F,P!`!4```"@S`$`#````+;,`0`.````P\P!``\```#2S`$`&```
M`.+,`0`9````^\P!`!,````5S0$`'0```"G-`0`3````1\T!`!,```!;S0$`
M"0```&_-`0`&````><T!`!````"`S0$`/P```)'-`0`&````T<T!``\```#8
MS0$`'@```.C-`0`1````!\X!`!4````9S@$`#````"_.`0`.````/,X!``L`
M``!+S@$`"0```%?.`0`/````8<X!``P```!QS@$`#0```'[.`0`=````C,X!
M`"@```"JS@$`#````-/.`0`'````X,X!`!8```#HS@$`"P```/_.`0`3````
M"\\!`!0````?SP$`!@```#3/`0`/````.\\!``T```!+SP$`'@```%G/`0!E
M````>,\!`"````#>SP$`#````/_/`0`'````#-`!``8````4T`$`'@```!O0
M`0`=````.M`!`!H```!8T`$`"0```'/0`0`"````?=`!``0```"`T`$`(```
M`(70`0`&````IM`!``4```"MT`$`*@```+/0`0`*````WM`!``<```#IT`$`
M"@```/'0`0`/````_-`!``X````,T0$`00```!O1`0`5````7=$!``8```!S
MT0$`!P```'K1`0`*````@M$!``4```"-T0$`!0```)/1`0"#````F=$!``P`
M```=T@$`#P```"K2`0`)````.M(!``H```!$T@$`'@```$_2`0`L````;M(!
M``\```";T@$`"@```*O2`0`0````MM(!``H```#'T@$`"0```-+2`0`:````
MW-(!`"D```#WT@$`)P```"'3`0`F````2=,!`!8```!PTP$`"````(?3`0`)
M````D-,!``H```":TP$`$P```*73`0`1````N=,!``\```#+TP$`$P```-O3
M`0`3````[],!`!D````#U`$`!P```!W4`0`,````)=0!``T````RU`$`,0``
M`$#4`0`@````<M0!`"H```"3U`$`)@```+[4`0`&````Y=0!`%(```#LU`$`
M#P```#_5`0`.````3]4!``D```!>U0$`(````&C5`0!9````B=4!`!H```#C
MU0$`!@```/[5`0`>````!=8!``@````DU@$`!P```"W6`0`?````-=8!``@`
M``!5U@$`"P```%[6`0`G````:M8!`"8```"2U@$`.0```+G6`0`)````\]8!
M``H```#]U@$`(@````C7`0!<````*]<!`!0```"(UP$`)@```)W7`0`4````
MQ-<!``(```#9UP$`$0```-S7`0`+````[M<!`!8```#ZUP$`#@```!'8`0`'
M````(-@!``<````HV`$`$@```##8`0`&````0]@!``@```!*V`$`$0```%/8
M`0`-````9=@!``H```!SV`$`#````'[8`0`'````B]@!`!H```"3V`$`&P``
M`*[8`0`>````RM@!``\```#IV`$`$0```/G8`0`/````"]D!``\````;V0$`
M#P```"O9`0`/````.]D!``@```!+V0$`'````%39`0`+````<=D!`!(```!]
MV0$`"@```)#9`0`3````F]D!``\```"OV0$`#0```+_9`0`$````S=D!``<`
M``#2V0$`!0```-K9`0`4````X-D!``8```#UV0$`"@```/S9`0`5````!]H!
M`!$````=V@$`&@```"_:`0`6````2MH!`!0```!AV@$`%P```';:`0`>````
MCMH!`!T```"MV@$`&@```,O:`0`&````YMH!``H```#MV@$`#@```/C:`0`-
M````!]L!``<````5VP$`(P```!W;`0`-````0=L!``X```!/VP$`%````%[;
M`0`'````<]L!`!````![VP$`"````(S;`0`5````E=L!`!,```"KVP$`"0``
M`+_;`0`)````R=L!``4```#3VP$`!P```-G;`0`"````X=L!``0```#DVP$`
M`@```.G;`0!$````[-L!`$,````QW`$`#0```'7<`0`B````@]P!`#8```"F
MW`$`#````-W<`0`X````ZMP!`"D````CW0$`%````$W=`0`=````8MT!`"(`
M``"`W0$`(@```*/=`0`G````QMT!`!````#NW0$`%````/_=`0!"````%-X!
M`!X```!7W@$`%0```';>`0`<````C-X!`!@```"IW@$`'````,+>`0`3````
MW]X!`!<```#SW@$`'`````O?`0`:````*-\!`"\```!#WP$`+P```'/?`0`S
M````H]\!`"\```#7WP$`,`````?@`0`Q````..`!`"X```!JX`$`:P```)G@
M`0`E````!>$!``L````KX0$`"@```#?A`0`D````0N$!`"H```!GX0$`+```
M`)+A`0`H````O^$!``D```#HX0$`6P```/+A`0!-````3N(!``X```"<X@$`
M"0```*OB`0`@````M>(!`"8```#6X@$`#@```/WB`0`8````#.,!`!L````E
MXP$`!0```$'C`0`*````1^,!``@```!2XP$`$````%OC`0`2````;.,!``L`
M``!_XP$`"@```(OC`0`-````EN,!`"4```"DXP$`"````,KC`0`)````T^,!
M``D```#=XP$`$@```.?C`0`5````^N,!`!`````0Y`$`.0```"'D`0`"````
M6^0!``<```!>Y`$`#@```&;D`0`9````=>0!``<```"/Y`$`!P```)?D`0`3
M````G^0!``@```"SY`$`#P```+SD`0`$````S.0!`#````#1Y`$`'`````+E
M`0`L````'^4!`%4```!,Y0$`%@```*+E`0!'````N>4!`",````!Y@$`$0``
M`"7F`0`7````-^8!``D```!/Y@$`$````%GF`0`*````:N8!`!$```!UY@$`
M#````(?F`0`3````E.8!``P```"HY@$`&P```+7F`0`;````T>8!``,```#M
MY@$`"P```/'F`0`2````_>8!`"@````0YP$`'@```#GG`0`3````6.<!`!(`
M``!LYP$`)P```'_G`0`)````I^<!`!$```"QYP$`$@```,/G`0`*````UN<!
M``<```#AYP$`#@```.GG`0`.````^.<!`!`````'Z`$`$@```!CH`0`%````
M*^@!``@````QZ`$`!0```#KH`0`<````0.@!``8```!=Z`$`$0```&3H`0`(
M````=N@!`!$```!_Z`$`+````)'H`0`(````ON@!`!8```#'Z`$`#@```-[H
M`0`L````[>@!`#0````:Z0$`.````$_I`0`H````B.D!`"D```"QZ0$`*P``
M`-OI`0`7````!^H!``D````?Z@$`"@```"GJ`0`=````-.H!``4```!2Z@$`
M$P```%CJ`0`%````;.H!`"@```!RZ@$`!P```)OJ`0`)````H^H!`!P```"M
MZ@$`/````,KJ`0`&````!^L!`!L````.ZP$`$P```"KK`0`)````/NL!``L`
M``!(ZP$`!````%3K`0`(````6>L!``L```!BZP$`!P```&[K`0`)````=NL!
M``@```"`ZP$`!P```(GK`0`'````D>L!`!4```"9ZP$`+0```*_K`0`[````
MW>L!`!<````9[`$`(````#'L`0`5````4NP!`#X```!H[`$`'````*?L`0`B
M````Q.P!`!T```#G[`$`)@````7M`0`E````+.T!`%@```!2[0$`-0```*OM
M`0!1````X>T!`"@````S[@$`(````%SN`0`F````?>X!``4```"D[@$`"@``
M`*KN`0`'````M>X!``D```"][@$`$@```,?N`0`5````VNX!`#@```#P[@$`
M(P```"GO`0`U````3>\!`#H```"#[P$`"@```+[O`0`:````R>\!``P```#D
M[P$`"@```/'O`0`A````_.\!`!,````>\`$`$@```#+P`0`.````1?`!``<`
M``!4\`$`#P```%SP`0`)````;/`!`!````!V\`$`#@```(?P`0`:````EO`!
M`!<```"Q\`$`,````,GP`0`+````^O`!``4````&\0$`!@````SQ`0`>````
M$_$!``P````R\0$`!````#_Q`0`0````1/$!`!$```!5\0$`"0```&?Q`0`,
M````<?$!``X```!^\0$`%@```(WQ`0`%````I/$!``0```"J\0$`$@```*_Q
M`0`Q````PO$!`$0```#T\0$`%P```#GR`0`D````4?(!`!@```!V\@$`%```
M`(_R`0`/````I/(!``T```"T\@$`'````,+R`0`-````W_(!`"\```#M\@$`
M!@```!WS`0`+````)/,!``T````P\P$`#P```#[S`0`5````3O,!``L```!D
M\P$`/````'#S`0`&````K?,!`!X```"T\P$`#P```-/S`0`3````X_,!`!(`
M``#W\P$`*@````KT`0!)````-?0!`#$```!_]`$`"P```+'T`0`G````O?0!
M`!\```#E]`$`.P````7U`0`\````0?4!`#@```!^]0$`20```+?U`0!*````
M`?8!`$,```!,]@$`$0```)#V`0`6````HO8!``@```"Y]@$`$0```,+V`0`3
M````U/8!``@```#H]@$`'@```/'V`0`)````$/<!`!`````:]P$`!P```"OW
M`0`1````,_<!`!P```!%]P$`"P```&+W`0`%````;O<!``P```!T]P$`"P``
M`('W`0`0````C?<!``4```">]P$`!P```*3W`0`*````K/<!`!,```"W]P$`
M$P```,OW`0`,````W_<!``P```#L]P$`!@```/GW`0`)`````/@!`#8````*
M^`$`*````$'X`0`C````:O@!``<```".^`$`(````);X`0`&````M_@!`"0`
M``"^^`$`%0```./X`0`H````^?@!`!$````B^0$`$0```#3Y`0`#````1OD!
M``@```!*^0$`$@```%/Y`0`"````9OD!``P```!I^0$`%````';Y`0`+````
MB_D!`!@```"7^0$`'````+#Y`0`8````S?D!``4```#F^0$`"@```.SY`0`4
M````]_D!`!T````,^@$`#0```"KZ`0`'````./H!``H```!`^@$`#````$OZ
M`0`1````6/H!`$H```!J^@$`'````+7Z`0`V````TOH!`!@````)^P$`!0``
M`"+[`0`$````*/L!``H````M^P$`(P```#C[`0`>````7/L!`!$```![^P$`
M$@```(W[`0`7````H/L!`!4```"X^P$`$````,[[`0`:````W_L!`"0```#Z
M^P$`#P```!_\`0!K````+_P!`"````";_`$`'@```+S\`0`<````V_P!`"``
M``#X_`$`&````!G]`0`D````,OT!`!(```!7_0$`&0```&K]`0`:````A/T!
M`!0```"?_0$`"@```+3]`0`'````O_T!``L```#'_0$`!P```-/]`0`4````
MV_T!``L```#P_0$`.@```/S]`0`:````-_X!``4```!2_@$`2@```%C^`0!/
M````H_X!`$T```#S_@$`8P```$'_`0`'````I?\!`"@```"M_P$`+````-;_
M`0`*`````P`"``@````.``(`#0```!<``@`R````)0`"``4```!8``(`4@``
M`%X``@`L````L0`"`"0```#>``(`#@````,!`@`@````$@$"`!P````S`0(`
M(P```%`!`@`=````=`$"`",```"2`0(`&@```+8!`@`,````T0$"``<```#>
M`0(`$````.8!`@`1````]P$"`!0````)`@(`"````!X"`@!`````)P("``P`
M``!H`@(`"````'4"`@`J````?@("``T```"I`@(`&@```+<"`@`)````T@("
M``0```#<`@(`%@```.$"`@`-````^`("``@````&`P(`"`````\#`@`$````
M&`,"``L````=`P(`"P```"D#`@`4````-0,"`!,```!*`P(`#@```%X#`@`4
M````;0,"``X```""`P(`!P```)$#`@`0````F0,"`!P```"J`P(`"P```,<#
M`@`-````TP,"`!L```#A`P(`*@```/T#`@`8````*`0"`!X```!!!`(`*@``
M`&`$`@`$````BP0"``0```"0!`(`#0```)4$`@`'````HP0"``H```"K!`(`
M%@```+8$`@`(````S00"``H```#6!`(`"````.$$`@`'````Z@0"``D```#R
M!`(`"0```/P$`@`)````!@4"``4````0!0(`#````!8%`@`.````(P4"``0`
M```R!0(`&0```#<%`@`.````404"``H```!@!0(`"@```&L%`@`/````=@4"
M`!P```"&!0(`"P```*,%`@`"````KP4"`!\```"R!0(`!P```-(%`@`&````
MV@4"`&<```#A!0(`#````$D&`@`(````5@8"`"@```!?!@(`1````(@&`@`@
M````S08"`"T```#N!@(`6````!P'`@`F````=0<"`"D```"<!P(`&````,8'
M`@`?````WP<"``4```#_!P(`"@````4(`@`-````$`@"``T````>"`(`"P``
M`"P(`@`+````.`@"`!4```!$"`(`#0```%H(`@`-````:`@"``\```!V"`(`
M#P```(8(`@`$````E@@"``<```";"`(`"````*,(`@`9````K`@"``@```#&
M"`(`!@```,\(`@`'````U@@"`!L```#>"`(`%@```/H(`@`+````$0D"`!<`
M```="0(`#````#4)`@`6````0@D"``P```!9"0(`"````&8)`@`/````;PD"
M``\```!_"0(`!@```(\)`@`7````E@D"``L```"N"0(`'@```+H)`@`&````
MV0D"``@```#@"0(`#0```.D)`@`@````]PD"``D````8"@(`"P```"(*`@`8
M````+@H"`!````!'"@(`&@```%@*`@`6````<PH"``8```"*"@(`"P```)$*
M`@`.````G0H"``D```"L"@(``@```+8*`@`.````N0H"``<```#("@(`)0``
M`-`*`@!$````]@H"`"8````["P(`*P```&(+`@`L````C@L"`"D```"["P(`
M6@```.4+`@`-````0`P"`!L```!.#`(`30```&H,`@`S````N`P"`%,```#L
M#`(`3````$`-`@`A````C0T"`#,```"O#0(`(@```.,-`@`F````!@X"`#(`
M```M#@(`*P```&`.`@`3````C`X"`#T```"@#@(`F`(``-X.`@`M````=Q$"
M`!H```"E$0(`$````,`1`@`_````T1$"`(4````1$@(`+@```)<2`@!$````
MQA("`$\````+$P(`2@```%L3`@`9````IA,"`!````#`$P(`&P```-$3`@`<
M````[1,"`"@````*%`(`(@```#,4`@`C````5A0"`"H```!Z%`(`&0```*44
M`@`-````OQ0"`"L```#-%`(`)````/D4`@`S````'A4"`"@```!2%0(`(0``
M`'L5`@`<````G14"`#H```"Z%0(`90```/45`@`J````6Q8"`#4```"&%@(`
M2P```+P6`@`U````"!<"`"@````^%P(`-@```&<7`@!<````GA<"`#H```#[
M%P(`+P```#88`@`H````9A@"`"@```"/&`(`+````+@8`@`K````Y1@"`#X`
M```1&0(`5P```%`9`@"'````J!D"`%8````P&@(`1P```(<:`@!%````SQH"
M`"\````5&P(`'````$4;`@`F````8AL"`"D```")&P(`*0```+,;`@`I````
MW1L"`&@````''`(`9````'`<`@"[````U1P"`!H```"1'0(`+@```*P=`@`W
M````VQT"`"@````3'@(`9````#P>`@`8````H1X"`%@```"Z'@(`'````!,?
M`@`+````,!\"`,P````\'P(`4@````D@`@`B````7"`"`"<```!_(`(`.P``
M`*<@`@`@````XR`"`!@````$(0(`,P```!TA`@`&````42$"``<```!8(0(`
M!````&`A`@`,````92$"`!````!R(0(`#````(,A`@`+````D"$"``<```"<
M(0(`$@```*0A`@`-````MR$"`((```#%(0(`!@```$@B`@`5````3R("``0`
M``!E(@(`!P```&HB`@`(````<B("``4```![(@(`!````($B`@`9````AB("
M``D```"@(@(`"@```*HB`@`2````M2("`!````#((@(``@```-DB`@`'````
MW"("``8```#D(@(`$P```.LB`@`,````_R("`!8````,(P(`!@```",C`@`4
M````*B,"``\````_(P(``P```$\C`@`N````4R,"``0```""(P(`!@```(<C
M`@`'````CB,"`!X```"6(P(`/````+4C`@`N````\B,"`"\````A)`(`%@``
M`%$D`@`B````:"0"`"H```"+)`(`(````+8D`@`C````UR0"`!X```#[)`(`
M'````!HE`@`D````-R4"`!H```!<)0(`+@```'<E`@`:````IB4"`"P```#!
M)0(`,````.XE`@`@````'R8"`"0```!`)@(`)````&4F`@`?````BB8"`"P`
M``"J)@(`)P```-<F`@`G````_R8"`"4````G)P(`'P```$TG`@`D````;2<"
M`#````"2)P(`'0```,,G`@`J````X2<"`!D````,*`(`)P```"8H`@!-````
M3B@"`"D```"<*`(`+0```,8H`@`M````]"@"`"X````B*0(`*````%$I`@`F
M````>BD"`"$```"A*0(`)P```,,I`@`X````ZRD"`"H````D*@(`#````$\J
M`@`.````7"H"`"````!K*@(`*@```(PJ`@`A````MRH"``\```#9*@(`*P``
M`.DJ`@`/````%2L"`!H````E*P(`&@```$`K`@`+````6RL"`"<```!G*P(`
M#````(\K`@`*````G"L"`"4```"G*P(`*````,TK`@`6````]BL"`!<````-
M+`(`)P```"4L`@`B````32P"``<```!P+`(`W````'@L`@`+````52T"`!,`
M``!A+0(`"P```'4M`@`'````@2T"``H```")+0(`'````)0M`@`0````L2T"
M`!(```#"+0(`(P```-4M`@`<````^2T"``,````6+@(`,P```!HN`@`;````
M3BX"`!@```!J+@(`!P```(,N`@`'````BRX"`!(```"3+@(`$@```*8N`@`S
M````N2X"`"D```#M+@(`$P```!<O`@`3````*R\"`!D````_+P(`,P```%DO
M`@`5````C2\"`!8```"C+P(`$@```+HO`@`.````S2\"`",```#<+P(`#P``
M```P`@`0````$#`"``D````A,`(`%P```"LP`@`*````0S`"`!\```!.,`(`
M#P```&XP`@`=````?C`"``\```"<,`(`'@```*PP`@`L````RS`"``4```#X
M,`(`$````/XP`@`'````#S$"``L````7,0(`"0```",Q`@`X````+3$"``8`
M``!F,0(`#P```&TQ`@`1````?3$"`!````"/,0(`"P```*`Q`@`/````K#$"
M``<```"\,0(`$````,0Q`@`(````U3$"`!L```#>,0(`"````/HQ`@`/````
M`S("``T````3,@(`&P```"$R`@`;````/3("``L```!9,@(`#0```&4R`@`7
M````<S("``@```"+,@(`,0```)0R`@`0````QC("``@```#7,@(`"@```.`R
M`@`"````ZS("``H```#N,@(`$P```/DR`@`+````#3,"``,````9,P(`"P``
M`!TS`@`+````*3,"``H````U,P(`%P```$`S`@`.````6#,"`!@```!G,P(`
M'@```(`S`@`,````GS,"`#D```"L,P(`(@```.8S`@`C````"30"``T````M
M-`(`10```#LT`@`&````@30"`!H```"(-`(`5@```*,T`@`/````^C0"`!``
M```*-0(`!P```!LU`@`$````(S4"``4````H-0(`$0```"XU`@`6````0#4"
M``8```!7-0(`!P```%XU`@`'````9C4"``L```!N-0(``P```'HU`@`,````
M?C4"``T```"+-0(`+0```)DU`@`%````QS4"`!8```#--0(`)0```.0U`@`B
M````"C8"`!\````M-@(`$P```$TV`@`"````838"``0```!D-@(`#0```&DV
M`@`*````=S8"``4```""-@(`!0```(@V`@`/````CC8"`$T```">-@(`%P``
M`.PV`@`B````!#<"`"4````G-P(`,````$TW`@!.````?C<"`!8```#--P(`
M?@```.0W`@`>````8S@"`%D```"".`(`*@```-PX`@!.````!SD"`#````!6
M.0(`)@```(<Y`@`J````KCD"`"@```#9.0(`+0````(Z`@`M````,#H"`"L`
M``!>.@(`+@```(HZ`@`I````N3H"`"@```#C.@(`)@````P[`@`L````,SL"
M`#<```!@.P(`%````)@[`@`:````K3L"``P```#(.P(`IP```-4[`@`&````
M?3P"`'X```"$/`(`A0````,]`@"@````B3T"`"`````J/@(`5P```$L^`@`0
M````HSX"`!$```"T/@(`!P```,8^`@!P````SCX"`!T````_/P(`30```%T_
M`@`_````JS\"`#\```#K/P(`.````"M``@`W````9$`"`#4```"<0`(`00``
M`-)``@"$````%$$"`#T```"900(`-````-=!`@`[````#$("`#X```!(0@(`
M,P```(="`@`E````NT("`$$```#A0@(`&0```"-#`@`6````/4,"`%<```!4
M0P(`'P```*Q#`@`/````S$,"``H```#<0P(`!0```.=#`@`&````[4,"``@`
M``#T0P(`!0```/U#`@`9`````T0"``D````=1`(`&````"=$`@`B````0$0"
M``\```!C1`(`"0```'-$`@`.````?40"``D```",1`(`#````)9$`@`'````
MHT0"``4```"K1`(`$````+%$`@`0````PD0"``X```#31`(`$````.)$`@`*
M````\T0"``D```#^1`(`$`````A%`@`(````&44"`!,````B10(`"@```#9%
M`@`+````044"``\```!-10(`"0```%U%`@`&````9T4"``X```!N10(`!@``
M`'U%`@`+````A$4"``<```"010(`"````)A%`@`(````H44"`"(```"J10(`
M`@```,U%`@`"````T$4"``P```#310(`!@```.!%`@`:````YT4"``8````"
M1@(`)0````E&`@`"````+T8"``0````R1@(`#````#=&`@`+````1$8"`!$`
M``!01@(`%P```&)&`@`+````>D8"``D```"&1@(`"@```)!&`@`'````FT8"
M``H```"C1@(`$@```*Y&`@`"````P48"``4```#$1@(`#````,I&`@`V````
MUT8"`"D````.1P(`!P```#A'`@`'````0$<"``H```!(1P(`$0```%-'`@`%
M````94<"``(```!K1P(`"P```&Y'`@`!````C`,````````U!P```````(H'
M``#3!P``Z`0``'\'```]!@``7@<````````_!0``B00``%P&``"O`@``EP<`
M`+<'```&`````````.,!``!<`0````````(!``!0````\@4``&H#``#N`0``
M<P````````!-`@``J08`````````````E00``-0$```J`P``7@8```````")
M`@``>0,```````#2`0``9`0``+D$``#E!@``^P```#@&````````[0(``(X$
M````````````````````````Q0,``'`$```.````^`4``-0&```$````)0,`
M`,,$``!7````:`4``.`$``!7!@``WP$``#@````J`````````)4```"9!P``
M%08```````!%`0```````+T```#3`@``E0$```(%``"$`@``N`<``-X&````
M````<`4``````````````````&`%``!&````M`<``"8%``"^!@``%`(``*\#
M``!?!````````%@$````````L@0``/@$````````G0`````````.!```MP(`
M``````"S`0``&P(``'("`````````````,T%``##!@``504`````````````
M`````#8!``#H!P```````$H&``!_`P``=0<``-X%``"S`@``W@(``$@"````
M`````````%<$``#>`0``Q`4````````5`@```````*@```#/!P``*P4``%,`
M``#!!@``TP8```````!<!0```````%D`````````E@0```D!````````)P``
M`$,'````````Z`4``-("``#`!P``\`(``,D!``#J!0``]`,```````!7`P``
M'0$`````````````Q`8``#0#````````1P<``/L!``!A!0``D@4``!8$``#F
M!@``'@```````````````````"8'```L`0``SP8``(\$````````\04`````
M``#M!````````#X````P!```F@0``-$!``!'`P``Y04``+`$``#Y!@``.0(`
M````````````R08``!D'```G!0``RP0```````#Z````4`$``'$&``"[!0``
ML`4``)T#``#D!0```````)L'``"K`0``<P,````````A!```X@$``!\#``!O
M`0``DP4``$\#``"G!P```````,\!```E!@``TP4``!D%```W!P```````"(&
M```\`P``80```!H%``!,!```!P$``$X'``"-!@``6`4``.,%``"U!```C@8`
M``````"H`0``S`,`````````````!`(``&4&```R!0``N0$``)L"``"+`P``
M`````((```##`@``;P```&\%``#M`P``300``!@!``!#!0```P(``#,"````
M````8P8``,<&```7`@````````````!+!0``!P8```T#```'`@``_`(`````
M```;!P```````+$`````````E````$L$``!/`0``+`,```````"A!0``C```
M`,H"```]!0````````P%``#?!@``R````(`"```T!0``-@<``+D"````````
M/`0``'H```#$````A0(````````I`0``J`,```````!6`@```````#T!``#&
M!@```````(8"```-`@``9P,```````!:!0``J@```#L$``"K!0``G`8``&4'
M``!W`0```````+0"``````````````$#```W`@``"@8``%`&``#Z!```````
M`.\&```3````P`0``*H%``!!!0``,P$``+,```!5`P`````````````<````
M```````````"!P```````)X$``!H!P``2P(``*P&```9!```````````````
M``````````````#[!@``X00``+4%````````[`(``!L%``!5`@``HP<``'X'
M``!0!0``=P(``),&``#_````>`0```````"@!````````.4#````````I0<`
M``@&``#B`@``-P```(`$``!D!P``=0$``+H&``"N!`````````P&```F````
MGP<``*$``````````````'8#``!&`P``*`<``)H``````````````%<'```K
M`````@(``,0"`````````````"\"````````_@,``'X"```:!P``F`$``&D"
M``#F````3`(```````"@````70```+L'``#*````9@,``!T&````````;`<`
M````````````40(```D&```U`````````````````0```````%P"```N!P``
M`````#`#``#Q`P``=@```"8"``"Y`````````*\'``"#!@``.04`````````
M````Z`(``!(&``!I`P``)0<``%(#```E`0``"@(````````[!0``"`4``-<&
M````````SP4``&$&``#:`P``PP``````````````HP(``*\!````````\0(`
M````````````'P(``(@!``"*````[`$```@$````````4P$```\`````````
M``````X&`````````````#0!``!-!@``T`(``.4"````````B`4````````R
M!P``408``($"``````````4``&H'`````````````$X$````````0`(``&P"
M```+`P``,0<``!L```#I!@``YP<```````!#````S@(``-<!``!P!@``G`4`
M`#`%````````E@4``-D'``"_`0``[0$``,D%``!U`P``6P4``(0'``#2````
M`````-$'``"&`P``CP<``"\#``"\!````````"L!```"`P``!0(``-,#```<
M`0``*````)H#``#F!P``@0```"`&``"Y`P```````.<"```O`0``QP$``$<`
M``!2``````````````!K!```;0,``.H$``"4!@``"P4``,H'````````M@8`
M`-\'``!\!0```````(P%``"Z`0``?````(4'````````D@````````#P````
M@0<``)X#``!C!P``B@$```````#C!P``D0(``!(```"3````(@$```````#0
M!0````````````#Z`@``B`,````````?!0``I@``````````````?`(`````
M````````?`$``!0%``!%!0```````(X`````````\@8``"4```"4!```>@<`
M``8!``"A!P```````&0!````````````````````````+`4``.P#````````
M&@0``+T$````````A00`````````````M`,``#D'````````*04````````:
M`0``5`$``,L`````````<00```````#_`0``$@(``'@&``"I````````````
M``"\`@```````)H!````````DP,``!,!```=!0``9P(``%(%``#,!@``Z0``
M``X#``"8`P``"`,``.X&``#`````NP```-T!````````4P<``(4%``!Y!@``
M]P8```,%``"Z!```S0,``#P&``!C`0``?`,```<#````````3P(```````!.
M!@``I@(``$,$``!Z`@``G08``%L!``"'!```U0$```````#_`@``LP4``%T!
M``````````````\#```U!0``YP0``*X"``#L!0````<````````]!```````
M`!($`````````````/,$````````EP(``#D```"`!P``EP8`````````````
MW0(``)T%````````/````+L$``!+`0``/@<```0!``"]!@`````````````0
M!P``%P<```````#C`P``5@<``#H```#O`@``,````(D````>!P``B@4``!P"
M`````````````-X'``#E!P``,08``'<$```\!0``70(``!<````>!```````
M`*H"``!T`0``>00`````````````;00``(L'````````/0(``'8"```M`P``
MY@4``,(%``#+`0``CP4````````[!P```````.4```!2`@``=P,``$L&```N
M````9@4```````"P`@``X`,``(T%``#=!@``-`(``-P````9!@```P```/(!
M``#<!@``L@,``+L#````````=@4``%$'````````@@(``,('```Q````ZP$`
M`$("``"^!P``HP0``/<$```L`````````%X#```\`@``+@8``-\#```3!@``
M60<``.X$````````$@,``)0%````````C`(``!H```!5!P``L0$`````````
M````30<``-$%``!)!P``AP8``&L```#O`0``7P$````````2!0```````!H&
M``!E!````````-@$```N!0``<P8``#(#```C`@``S`$``!`!````````Q0(`
M``,#``#6`P```````-,!`````````````#<&```Q`0``)P8``'(#```J!```
M000```````#F`0``<0$``.L&```M`0``U08``%0%````````>P$`````````
M````?0(``.`!````````]P$````````S!```$P,`````````````;@$``-P$
M````````=P8``($%``!-`0```````-<#```^!```@`$``,4%``#/````,`(`
M``````![````J`8``)@&````````1P8``/L%``!Q`P``R@0```````!T!@``
M`````,$#````````D@$``/D%``!A`0``)0(``-T$``"$`````````#4#```F
M`P``8`$``-@'````````/@(```````")`0```````,\#````````J04``,$!
M``#?!```V0(```````".!0``ZP,``-@#````````B@8``!``````````K04`
M``````"J`P````8``!D!````````'0````X!``````````````\!````````
MH`$```P#``#P`0``(@4``/,%``#(`@``<P(``.,```"J!P``K@```*H!````
M````5`<``#D$``#6!````````.P`````````F````%X"````````Q@0`````
M``"%````OP```(X'````````!@8``(T$```1!0``L`````````"E`0``\P``
M`#\"````````"@0``#,```!:`0```````%T$``"D`@```````"L$````````
MAP$``/@&``#*`P``BP0```````"$!@``'P0``-(%``#X`@```````$X%``"0
M`P``F@<```<%````````W`(``)T$``#D!P``/0```/8"``#6````$`,```\&
M``!L!0``@08``*T'``"L!0``C0(``/$$```"!```404``,4!``#"`@``````
M``````"D`P``J0<``.$"``#Y`P```````+<%``!$`P``7`0``%X%``#P!```
MZP(```````#)````*`$```````#^!```YP8``*4```"@`P``MP,``)8'```4
M`````````,,#```>!@``*P,``%H#``#\!0``80<`````````````D0```%L&
M````````,`<``%P'``!>!```.`<`````````````%`0``%`"``#(`P``&@,`
M```$`````````````'P&``#4`@``+04```````"-!P``9@<``/0$``"_!0``
MHP$``*4$`````````````"0'```$!````````%4```#F`@``HP````````!$
M`0```````+`!``!D`P``,`$```````#;!0``;@4``!D````R`0```P<``+\#
M````````LP0```\'``!R!0``1P4```````!:!@```````"H&````````,P,`
M`"L&``"Z`@```````!<%``"-````TP```.0$``#H`P``QP,``+8#``!0`P``
M.@,```H%`````````````!8#``![`P``O04``$4"```D!0``X`(```$!``!E
M!0``!`<```````!>````V@```$T#``#B!```Z`8``"<$``!@!````````$4'
M`````````````.T&``"L!```M08`````````````R`4``%P```#!!0``````
M`"H!````````AP(``/X%````````S00``$H#````````:0```,,'``"G`P``
M`````)\#````````V`$```````#A!P``B`<``",!``#:`@``O`4`````````
M````-0(``````````@``-@````````!,````V@8``'L%````````=P<``*(!
M``"+!0``J0,``/8```!H`0``$00``'@`````````#04``"D$``"V`0``4P0`
M``````!J````SP(`````````````Q@4`````````````B@,`````````````
M?@8``'<```!U!0```````)X"``!"`P``\P8``"P"```S!@```````.\%``#=
M````"`$```````"6`@``*@(``*8%````````D`0``$(&``#J!P``?P```)@"
M``!I`0``^P0```P$```K`@``<`<``"X#````````Y`(``.D!``!4````<@0`
M`)X&``!K`P``C@(``&D&``"Y!0``:@0``((&```)`P``2`0```,!``!L!```
M/P0``*T$``#^````9P<``$(```!`!0```````/4"````````KP```&("``#A
M`0``?0```*(#````````>@$``*$!``#I!0``#P0``#8&``#;!P``"P$``-8%
M```O!```;P0```````!Y`@``"@,```````!U!```304``&H!```7!```````
M`"T&``#D!@``QP(``%<!``#I`@``O0$``-L#````````#`$``(D%``!O!@``
M"0(``-L&```G`@```````-(#``"!!```J`<```````#\`P``&0(```````#V
M`0```````.0```!C````A`4````````6!0``40````````#'!0``N@,``%,#
M``!(`P``9P4``"``````````8@<```````![!```H@```+P'````````````
M`"4$````````?P$``*8!``"#`0``]@0``'0#``#0````)`$``/T"``!6````
M90(``)@$``#]`0``HP4``!('```<`P``C`0``(0$````````G`(```8$```V
M!`````````````#L!```5P(```````"<!P````````````",!P``*`4`````
M``![!P``0P,``/0!``!)!```B0,``#0```#6!@``Q@<``!L#``"<`P``````
M`%L#``"F`P``W@0`````````````?0$```````!9!0``D`8``$@%``!;`@``
M"P````````"T````5`,``+H'``!V!````````*($``#_`P``BP(``),$``!N
M`@````````````#(!P``M`0`````````````JP,```````!H!```_0,``*X'
M```E!0``/0,```````!Y``````````````"\`P``7P<``+T"``!\!```U0(`
M`"0```#Z!@``JP<````````T!```JP```.P&````````*08``,<````=`@``
M:P(``!T'``!J!0``+@0```````"/!@``XP(```````!T!```&@(````````?
M`0``.`0``*$$```X`0``30```!0'````````IP```#D&``#+!0``$0```$H`
M``"E!@``3P8``"\&``#G````R`$``((%````````DP(``-H!``"9!@``$08`
M`%H```#P!@``XP8``.D#``"G!@``1@8``"D#``#N`@```````+X`````````
M(`4``(H"``"^`@``K````*<%``!@````O@$``%\"``!R!P``%00``!`"``#-
M`0```````%\&```%!@``-P$``!`%````````O`````````!Y!P```````)0!
M``!'`@``#`(``)H&``#U!```A@<``,4$`````````0<```````"L`P``````
M``````!.`@```````&T%`````````````%$$```U!````````"@&````````
M,@(```````#1`@``@P(``'@!``"#!P```````(<``````````````&0"```T
M!@``3`$``/8#``!]`P``N````&<&```B!P``;`,```@'``!8!P``?08`````
M``""!P``SP0``*H&```%`P``60,```````"B`@```````-T'``#I!```W@,`
M`)$'``"M`@``(0`````````N`@``RP(``",&``#.!P```````,(!``""!```
MU0```&T!``"Q!0``/`$``#@"```[````#@4```````"4!P``X@,``)<!``!:
M!P``0`,```````#5!P``RP,``-('``#5!0``,P4``(8!```P!@``2`$`````
M``"A!@``XP0```````"V`@```````$$"``#X````,0,``)("``!T`@``90,`
M``````"=!P```````$0'```<!@``,P<``+@#````````0`0``)<$````````
MR0<```````!.`````````,$$````````_@8``+X$`````````````&\'``#7
M````4P4``!<&````````2`8```````"O!@``_04``"H'``#K!P``I@<``#@#
M``";``````````````"Q!@``)P<```````!4!@``1P$```````!I!P``````
M`(0!``````````````4!``````````````````"[!@```````'(````3!P``
M!P<``/("```<!0``&P$```````#T``````````````"O!```G0(``.@!``#[
M`@``2P<``(T#```V`@``[@,``.(%````````10,```0%``"6`P``S@4``%X!
M``"/`0```````$$````U!@``7`,``#L"``#T!@```````-@%``"$`P``S`0`
M``````"V!P``A0,``-`!```-!```[P```*X%```%!```$`0``$P'```%!P``
M`````%8&```8!@``204`````````````Q@(````````?````U0,``'X$``"\
M`0``Y00``%0$``#6`0``-P0```````"E`@``!@(````````/!0``````````
M```Q!0``G````-($``"Q`P``9````+$"``"I`@``KP4```T```!@!@``````
M`.H!``#;````!P```%T#```"!@```````$$'``"D!@``T`8``!L$``!2`0``
M``````````!^`0``]`(``"(```"[`0``;0(``+\$````````CP(``$`'```J
M!0``&`<```\"```I`@``-P4``&$"```-!P``%0<``!\&``#"````N`$``,4'
M````````=P4``+4```#M````U`4``)<#``"L!P``V0$``-@&``"0!P``````
M`,(#````````X@8``)\"``";!@```````%,"``#(!@``8P4``/<#``!4`@``
M>`,``%,&```@`@``;`8``%D&``#*`0``+0(``"L'``"C`P``>`(``-L"````
M`````````%8!```X!0```````.L$```8````(@,```````"9````UP<`````
M`````````````#T'``!Z`P```````(X!`````P```````&\"``"?!```%0,`
M`!8"``">!P``J@0```0#``!X!P``>P(```````##!0```````$\'````````
MEP4``*4%```>!0``I`$```````!V!@```````"$!``#?````;0`````````3
M!0``F`<```H'```_````1`4````````&`P``70<``-0`````````]P(``*T#
M`````````````-0'```F!@```````+@"````````;@<``#H$``!K!0``H`(`
M`,D#```)!```^0(```````"5!@``E`(``'X#``!%`````````/4```#A!@``
MGP$``,`%```&!P``.@4```````````````````````!8`P``Z@,``*@$``!9
M!```0````.`%``!#!@```````/`#``"D!P``%0```-8"```1!P```````$H%
M````````80,`````````````S`4``"`'``!S!P``S@,``)4#``!I!```008`
M``````#G`P``FP4```````"+`0```````%H"````````:@8``/<````M!P``
MF04``'H$`````````````!\'``!B`P``:P$``-\"``!G`0``JP0``)\%```G
M`P``(`0```````"H!0`````````````Y`0``-P,``$8$``"S`P```````$D!
M````````V@0``&X```!?`P``2P,``-P%`````````````&X#```C````F0$`
M``````!S`0``L@8``(8&``!@`P``D`(```````!N!```X04``)($``!7!0``
M^00```````!U`@``.@<`````````````\P,``!8'``"`!0``QP<``"`!``#_
M!```Y`,``"$'````````O0<``/P&``"/```````````````<!P``?P4``,X&
M``````````````````"?`````````+8$``#<!P``"0<```@```#Y````/@8`
M`*<"```.!P``[@```-D%```R!```)@$``$P#````````MP8``$H'```(`@``
M@`,```````#.`0``-`<``&8$``"B!@```````$('`````````````%\```"0
M!0```P8``,8!``!C!```B@0```````#U`P```````,X`````````E`,``&$$
M``#*!@``I`````````#!````#@(``$,!``#*!0``M`$```````#$!P``8P(`
M`(D&``!I!0```````%8$````````T`,``/,!``#I!P``_08```````";!```
M20,```````"T!0``208``'(&``!``0``!04``%D"``!&`0``````````````
M````,@````````"?!@``^@4``/D!````````6P<``)@%``#`!@``K0$``-D#
M``!1`0``*0<``!`&``!%!```3P```*`'``!_`@``P`$``+4!``!"!```BP8`
M``````#R!`````````4```"D!`````````````#T!0``(0(``'T$``"K`@``
M?@````H!``#"!@````````````!X!0```````+,&``!/!0``.@8`````````
M````6`(``$0`````````EP```+`&``".`P```````%@&``""`0``-@,``!8`
M`````````````+@$````````E@8``'0'``!:!````04``&@"````````````
M``````#;`0``K@8``*P!```4`P``!@4``-8'````````Q`0```````#1````
M`````+("``#0!P``X````*$"``#8````W04``+(%`````````````!0&``!_
M!@``BP```%$#``##`0``&`(``#X#``!H````$0,``+T#``#,`@``H@4``$0"
M``"R`0````````````!2!```\0$``*D!``!!`P``&P8``-<%```@`P``(P4`
M``````""`P``1P0``+D'````````J00``,X$````````QP0``,T&````````
M0@4``/L#``"&`````````,D$``!P`@```````!,$```!!@```````#D#```D
M!@``Y0$```````#&````508``````````````````!P$``!(````]P4``"0#
M`````````````.$#```8!0```````,T'````````Q08``&P!``!@`@``@P,`
M`!(!``"B!P```````!0!``!L`````````````````````````#H!```#!```
MOP(``)X```"E`P``)`0``"($``#J````$P(```````#9````^`,``)(#````
M````0@$``!X!``#\````'00````````-`0``3`8``/$&```9`P```````+`#
M``!R`0``F@4``)$$``!(!P```````#L&````````Y@0```````"M````1`8`
M`"0"``"2!P``T08```````"!`P``R0(````````C!```20```!<!``![!@``
M``````````!&!0``,00``),'````````U`,``%T%``#O!````````"D````5
M`0``\@```/X!```M`````````#L#````````P`,```L$```=`P``E@```"8$
M````````T`0``+`'```'!```8@8``",'```+!P``B`0``$X#``!+````````
M``````!!`0``(0,``/,"````````I@8``+L"```R!@``8@``````````````
M`````,$"``!*`0``C`8``*X!````````'@,``-$#```6`0``8P,``(,%``#\
M`0``I@0``+4"``"W`0``Q0````````!Z!@```````+('``!M!@``/P<``%@`
M```_`0``3@$``.(```````````````````"Q!P``````````````````=`4`
M`#\&``!P`P```````*`%```A!@```````,$'```8`P``Z````,@$````````
M&`0``&`'``#$`P``9@```&L&``"G!````````)D"```*````UP(``)`!``"D
M!0``OP<```````"/`P``WP4```````````````````````#,`````````'4`
M``";`P```````!$!``#R`P``>@4``',%``#D`0``=08```L"````````8@0`
M`+4#`````````````````````````````$8"``#@!P```````/4&``#-````
M`````.L%``"0````JP8``*`&```H`P```````,`"``!H`P```````$D"````
M````+00``#8%``!D!@``E04``"("``"W!```YP$``+0&`````````@```.T%
M``#=`P``OP8``!8&````````F0,``#P'``"5!P``E0(````````)!0``````
M`&@&``"(````>04``+,'``"^`P```````'\$`````````````-H%``!O`P``
M`````+4'``!=!@``.@(``*,&```5!0`````````````,`````````&(%````
M````9@(````````)````!`8``-X````H`@``V@<`````````````C`$`````
M``#]````/@4``-L$````````G@$``(8%``!S!```5@,``.X%````````*`0`
M`(8$``#V!@```````*P"````````U`$``'T'``!F`0``2@0``)8!``#V!0``
M`````/T$````````8@$```L&``!9`0````````````#X`0```````+H```!E
M`0``Q@,``%`'```!`@``@0$```````#P!0``>0$``(,$``#5!```````````
M``#J!@``W`,``'$'````````M@4````````7`P``IP$```````#7!```D0,`
M`.H"``"\!@```````&T'`````````````,P'````````N@4``/\&````````
MS0(``.L```!G``````````````#9!```[P,``%4!``#2!@```````/X"``"V
M````<````&0%``#"!```6`$``#4!```L!```?@4``+X%````````=````"P&
M````````/P,``-D&``!5!```3P0``-@"``#$`0``F00``$H"````````]04`
M`+@%````````$0(``)H"``"X!@```````,L&``!`!@``#08``(4!````````
M]0$``)$%``"M!@````````````"-`0``<0```$4&``!J`@````````````"`
M!@``'@(```````"(!@``.P$````````!!```;@8```````#@!@``@````.('
M````````,0(``+D&````````(P,```````#A````MP```(,```!0!```````
M`'8'``#+!P``D@8``#X!``!2!P``1`0``(<'````````````````````````
M`````/$```">!0``J`(```````"%!@``4@8``/H!``!Q!0``K@,``-P!```N
M`0``9@8`````````````7P4```````"(`@``FP$``)P!``#Z`P``1@<``'`!
M``"1`0```````%L````O````AP4``(D'````````5@4``'T%``!;!```````
M``````!K!P```````)T!``!\!P``D08``$,"````````T00``(<#``!Q`@``
M`````$P%``"A`P``90```"P'````````TP0``"$%```O!0``YP4``"<!``"Q
M!```L@```),!``#\!```Y@,```````#_!0```````&<$``"<!```#`<``"\'
M``!V`0```"`@+4TL("TM;65S<V%G93U-15-304=%("!5<V4@=&AI<R!C;VUM
M:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N97,N`"`@+6$L
M("TM861D/49)3$4@("`@("`@($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O
M;7!E;F1I=6TN(%5S969U;"!T;PH@("`@("`@("`@("`@("`@("`@("`@("!I
M;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T
M;PH@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V5N97)A=&5D(&-O;7!E
M;F1I=6TN`"`@+6(L("TM8F%S93TO4$%42"`@1G5L;"!P871H('1O('1H92`H
M2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H870@<VAO=6QD(&)E"B`@("`@("`@
M("`@("`@("`@("`@=7-E9"X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@($UE
M<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI<R!C;VUP96YD:75M(&9I;&4*
M("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0@;VYE("AC;VUP96YD:75M+G!O(&EN('1H90H@("`@("`@("`@("`@("`@
M("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+@`@("UC+"`M+6-O;7!E;F1I
M=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@
M=&AE(&1E9F%U;'0*("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M
M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2X`("`M9"P@
M+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE(&5X
M96-U=&5D(&)I;F%R:65S+@`@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A
M=&4@8V]M<&5N9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2X`("`M:"P@+2UH96QP
M("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+@`@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C
M86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C86QE
M/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92X`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($)U:6QD($U/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M
M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P(%!/(&9I
M;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#
M<F5A=&4@82!03R!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F:6QE<R!O;FQY
M(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I
M(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!O;FQY
M('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T
M<F%N<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN`"`@+6XL("TM;F\M8V]M
M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M+@`@("US+"`M+7-T
M871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN
M(&$@;&]C86P@9FEL92X`("`M="P@+2UT97-T("`@("`@("!3:&]W('1H92!E
M>&5C=71E9"!C;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+@`@(&-L
M96%N=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS
M;&%T960@86YD(&]B<V]L971E(&5N=')I97,N`"`@8V]M;6ET("`@("`@0V]M
M;6ET('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BX`("!C;VUM:70M
M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E<BX`("!C
M;VUP96YD:75M("!296)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI
M;F<Z(%1H:7,@;W9E<G=R:71E<R!T:&4*("`@("`@("`@("`@("!C=7)R96YT
M(&-O;7!E;F1I=6TN`"`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA
M=&4@*"YP;W0I(&9I;&5S+@`@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP
M(&UE<W-A9V4N`"`@:6YI="`@("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/
M(&9I;&5S(&9O<B!A(&YE=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7,*("`@("`@
M("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T
M:&ES(&QO8V%L92X`("!M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@9FEL
M97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I;&5S+@`@(&UA:V4M:&5L<"`@
M($UA<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@
M=7`M=&\M9&%T92!A;F0*("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE
M(&9O<B!T:&4@;F5X="!E>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=0H@
M("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@049415(@
M=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H90H@("`@("`@("`@("`@(&AE
M;'`@9FEL92X`("!M97)G92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F
M:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL92X`("!U<&1A
M=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N="X`("!U<&1A
M=&4M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F
M<F]M('1H92!%;F=L:7-H(%A-3"!H96QP"B`@("`@("`@("`@("`@9FEL92!A
M;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+@`@)B,Q-3$[
M("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E
M<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B
M)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E
M9"`E<R!A;F0@)7,`)60@8GET97,@=W)I='1E;BX`)60@;V8@)60@96YT<FEE
M<R!M87)K960@87,@=7`M=&\M9&%T90`E9"UD87D@9F]R96-A<W0`)7,@+2!.
M;W1I8V4`)7,@061M:6YI<W1R871I;VX`)7,@1FEN9V5R<')I;G0`)7,@2T(`
M)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3
M971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E
M861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@9&]E<R!N;W0@97AI<W0@;W(@
M:7,@;F]T(&5X96-U=&%B;&4N`"5S(&AA<R!C86YC96QL960@)7,N`"5S(&AA
M<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L
M:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N="!Y;W4@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!I<R!N;W0@=W)I=&%B;&4N`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!N;W0@
M9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT<F%C="<@9FER<W0N`"5S(')E
M<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T
M<R!Y;W5R('!R97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H
M97,@=&\@861D('1O("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@
M;V8@)7,N`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M
M871I;VX@86)O=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD
M87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!U;F%B
M;&4@=&\@;&]A9"!D<FEV97(Z("5S`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA
M8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R
M-"!H;W5R<P`\4')E=FEO=7,`/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN
M(&9I;&4@)7,N"D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N`$$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F
M871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`041322!E<G)O
M<B`E<RX`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W
M97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'0@<F5Q
M=65S=`!!8V-E<'1E9`!!8V-E<W,@1&5N:65D+@!!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C
M8V]U;G1I;F<`06-T:6]N<P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL
M9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@
M4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H
M:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O
M;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU
M(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R
M`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`
M061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!
M9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M
M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I
M;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG
M;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@
M1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M
M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`
M06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA
M;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E
M<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U
M<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`
M06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A
M=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE
M`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G
M96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A
M`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I
M;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8VAE9"!I
M<R!A;B!I0V%L96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E
M;G0`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!
M='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z
M97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VME;F0@;F]T(&-O<G)E8W1L>2!I
M;7!L96UE;G1E9"X`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K
M97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA
M;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"
M87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M
M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N
M("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O
M;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z
M`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA
M`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5I;&1I;F<@34\@
M9FEL97,@9F]R(&UO9'5L92`E<RXN+@!"=6EL9&EN9R!L;V-A;&4@)7,N+BX@
M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`
M0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T
M:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E
M;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E
M<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E
M;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`
M0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#
M96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@
M069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I
M9FEC871E(%!O;&EC:65S`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N
M9V4@4&%S<W=O<F0`0VAA;F=E('!A<W-W;W)D(&]N.@!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@<&%S<W=O
M<F0`0VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,`0VAA<@!#:&5C7VL@3&EN:RXN
M+@!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT
M('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&EN97-E
M(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG
M-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E
M(&%N(&%C=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T
M;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`
M0VQE86YI;F<@=7`@4$\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!#;&5A;FEN
M9R!U<"!L;V-A;&4@)7,N+BX@`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`
M0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A
M`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V
M:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U
M9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#
M;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`
M0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#
M;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;6%N9"!O<'1I;VYS.@!#;VUM86YD
M<SH`0V]M;65N=`!#;VUM:71T:6YG.@!#;VUM;VX@3F%M90!#;VUO<F]S`$-O
M;7!A;GD`0V]M<&QE=&5D`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U=&5R
M<P!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG
M=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@
M4&%S<W=O<F0`0V]N9FER;2!N97<@<&%S<W=O<F0Z`$-O;F=O`$-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL
M960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N=',@
M;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P
M>2!S96QE8W1I;VX`0V]P>6EN9R`E<R!T;R`E<P!#;W-T82!2:6-A`$-O=&4@
M9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L
M9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U
M<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C;W!Y("5S('1O("5S`$-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!C<F5A
M=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.@!#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S
M971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T
M(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N
M;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"X`0V]U;&0@;F]T(')E860@)7,N
M`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B
M+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#
M;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#
M;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`
M0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET
M(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U
M<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R
M<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`
M0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R
M-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI
M8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E
M9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`
M1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN9&5N=`!$969A
M=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%!E
M<FUI<W-I;VYS`$1E9F%U;'0@<&5R;6ES<VEO;G,`1&5F:6YI=&EO;G,`1&5L
M96=A=&4@<&]S:71I;VX`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@1W)O=7``
M1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$
M96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M`$1E;&5T92!T:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E
M<GD@=&EM90!$96YM87)K`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R
M(&9R964O8G5S>2!I;F9O<FUA=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$
M97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I
M<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4
M048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$
M:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@
M;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI
M8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO
M;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H
M92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R
M90!%;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E
M9"!C:&%N9V5D+"`E9"!U;FMN;W=N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R
M96$`17)R;W(`17)R;W(@<V5N9&EN9R!D871A('1O('-M8G!A<W-W9"X`17)R
M;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<G)O<CH@`$5S=&]N:6$`171H:6]P
M:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN
M=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,
M;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L
M=65S.@!%>&5C=71E`$5X96-U=&EN9SH`17AP86YD`$5X<&%N9"!3:61E8F%R
M`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E
M87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!%>'1R86-T:6YG
M(&9R;VT@)7,N+BX@`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I
M;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R
M=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y
M('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O('9E<FEF>2!O
M;&0@<&%S<W=O<F0N`$9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@;VX@
M)7,Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E
M($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&965L<R!,:6ME
M`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I
M96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C
M=&]R:65S.@!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N
M`$9R964O0G5S>2!);F9O<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"
M=7-Y(%)E<75E<W0`1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H
M($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@
M36]O;@!&=6QL($YA;64`1G5Z>GD`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R
M871I;VX`1V5N97)A=&5D($-O9&4`1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO
M9'5L92`E<RXN+@!'96]R9VEA`$=E<FUA;GD`1V5T;W!T($5R<F]R.B``1VAA
M;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R
M8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL
M86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R;6ES<VEO;G,`1W)O=7!S`$=U
M861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES
M<VEO;G,`1W5E<W0@<&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN
M96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@
M=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE
M8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D
M:71O<@!(96QP97(`2&5L<&5R(&%P<&QI8V%T:6]N('1O(&-R96%T92!A;F0@
M;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@2&]R9&4*9G)A;65W;W)K
M(&%N9"!I=',@87!P;&EC871I;VYS+@I&;W(@86X@:6YT<F]D=6-T:6]N(')E
M860@=&AE(&9I;&4@4D5!1$U%(&EN('1H:7,@9&ER96-T;W)Y+@!(96UI<W!H
M97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(
M:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$AO7VUE`$AO
M;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S
M`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E('1R
M86YS;&%T:6]N(&=E;F5R871O<@!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B
M.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(
M;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY('-Y;F-H<F]N:7-E9"`E<R`B)7,B
M`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S
M('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@
M;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B
M`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A
M;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA
M;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``
M2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`
M25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F
M;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN
M9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S
M964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W
M86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W
M<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G
M92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO
M860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R
M`$EN8V]R<F5C="!087-S=V]R9`!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R
M<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@
M57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YI=&EA;&EZ:6YG
M(&UO9'5L92`E<RXN+B``26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM
M86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU
M;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C
M96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F
M=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E
M<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN
M<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E
M<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!)
M;G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A
M;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I
M;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@
M87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A
M;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R
M96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S
M;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R
M>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE
M(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI
M8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR
M,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I
M9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2
M:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I
M97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME
M>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO
M<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U
M86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L
M9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I
M80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO
M;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&EB97)I
M80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@
M1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I
M;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN
M:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T
M:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#
M;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T
M86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H
M:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI
M<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9R!L:6)R
M87)I97,N+BX`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4
M:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT
M`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T
M=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A
M;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`
M36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN
M+@!-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@
M:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA:VEN9R!D:7)E8W1O<GD@)7,`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R
M=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`
M36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE
M971I;F<@0V%N8V5L;&%T:6]N`$UE971I;F<@26YF;W)M871I;VX`365E=&EN
M9R!0<F]P;W-A;`!-965T:6YG(%)E<&QY`$UE971I;F<@57!D871E`$UE971I
M;F<@57!D871E(%)E<75E<W0`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE<F=I;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M
M+BXN(`!-97)G:6YG(&QO8V%L92`E<RXN+B``365R9VEN9R!T:&4@4$\@9FEL
M92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@`$UE<F=I;F<@=')A;G-L
M871I;VX@9F]R(&UO9'5L92`E<RXN+@!-97-S86=E`$UE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A
M9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I
M;F5D`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G
M92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G
M92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES
M<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I
M9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QE`$UO9'5L=7,`36]L9&]V82P@
M4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO
M;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#
M;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V
M92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-
M;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L
M92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`
M3F%U<G4`3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA
M;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E
M=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@
M4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#
M86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H
M;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9#H`3F5W('=I;F1O
M=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S
M`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.
M:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@
M=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G
M>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.
M;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+@!.;R!C:&%N9V4N`$YO(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A
M9&1E9"!B96QO=R!T:&ES(&QE=F5L+@!.;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VUM86YD('-P96-I9FEE9"X`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@96YT<GD@=VET:"!T:&4@:60@
M(B5S(B!E>&ES=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92X`3F\@9FEL
M92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C86QE('-P96-I9FEE
M9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`
M3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU
M;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.
M;R!S:61E<P!.;R!S=6-H(&)A8VME;F0@(B5S(B!F;W5N9"X`3F\@=&5M<&]R
M87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V
M97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`3F]N90!.;VYE("AU
M<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L
M86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O
M<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO
M=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I8V4`3F]V96UB
M97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU
M;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE
M8W0@0W)E871O<@!/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<P!/8W1A;`!/
M8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@<&%S<W=O<F0Z`$]M
M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R
M871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N
M<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R
M<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-
M12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A
M=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/<'1I
M;VYS(&9O<B`E<P!/<'1I;VYS.@!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N
M`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T
M:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3
M:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-
M($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R
M<P!032!3=6X`4$T@5"U3=&]R;7,`4%](4"!3:&5L;`!0861D:6YG`%!A:VES
M=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N
M86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!0
M87-S=V0@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960N`%!A<W-W;W)D`%!A
M<W-W;W)D(&-H86YG960@;VX@)7,N`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S
M=V]R9"!M;V1U;&4@8V%N)W0@9FEN9"!T:&4@<W5P<&QI960@8FEN+@!087-S
M=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!R97%U:7)E9"!P87)A;65T97)S+@!0
M87-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!T87)G970@<&%R86UE=&5R+@!0
M87-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960`4&%S
M<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+@!087-S
M=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S
M=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!0
M87-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A
M<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B
M)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0
M97)M:7-S:6]N<R!F;W(`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S
M`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA
M=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@
M;F5W('!A<W-W;W)D`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!C=7)R96YT('!A<W-W;W)D
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5P
M;W)T(&%N>2!B=6=S('1O(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!0;&5A<V4@
M<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E
M;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('-E
M;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;&5A<V4@=F5R:69Y('EO=7(@
M;F5W('!A<W-W;W)D`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R
M93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`
M4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T
M97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME
M>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L
M:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R
M;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T
M;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E
M9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R
M`%)E;6%R:W,`4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`
M4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M
M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@9G)O;2!M>2!C86QE;F1A<@!2
M96UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N
M;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R
M.B`E<P!297!L>2!396YT+@!297!L>2!W:71H($YO="!3=7!P;W)T960@365S
M<V%G90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`
M4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!2
M97!L>3H@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1R:79E<G,G(&ES(&UI<V-O
M;F9I9W5R960@:6X@0V]M<&]S:71E(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%!A<W-W9"!344P@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@
M4U%,(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<75I<F5D(%!A
M<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S
M<W=O<F0`4F5S=6QT<P!297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.@!297-U
M;'1S.@!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R="!#;VYF:6=U
M<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT
M`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN
M`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2
M:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU
M;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N
M($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA
M='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L
M;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN
M="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!3
M86UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A
M;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3
M879E`%-A=F4@)7,`4V%V92`G)7,G`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R
M871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!3
M8V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN
M97,`4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<P!396%R8VAI
M;F<@9V5T=&5X="!B:6YA<FEE<RXN+@!396QE8W0@1FEL97,`4V5L96-T(&$@
M9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R
M`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E
M<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@
M9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($E$(&5X<&ER
M960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I
M;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R
M>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3
M:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N('5P(&EF(&YO
M="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I
M;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VMI<'!E9"XN+@!3;&]V
M86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3
M;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T
M:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD
M<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`
M4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D
M97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG
M`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L
M;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A
M;F1A<F0`4W1A<B!4<F5K`%-T87)T`%-T87)T('EE87(`4W1A=&4@;W(@4')O
M=FEN8V4`4W1A='5S`%-T871U<R!F;W(@;&]C86QE("5S+BXN(`!3=&]R86=E
M(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L
M:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=
M`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M
M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@
M8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY
M(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R
M960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S
M(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A
M=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S
M9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A
M;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR
M:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R
M:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T
M;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY
M`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R
M=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES
M=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K
M<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E
M<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N
M`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E;G1A=&EV96QY($%C8V5P="!R
M97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E>'0`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H96QP(&9I
M;&4@9F]R("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O
M;F4N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A
M;&5N9&%R(&1A=&$@:7,@:6YV86QI9`!4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!0
M1U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@
M<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@979E;G0@:&%S(&)E96X@
M861D960@=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H
M92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O
M<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R
M:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA
M=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!H96QP
M(&9I;&4@)7,@9&ED;B=T('-T87)T('=I=&@@/#]X;6P`5&AE(&ED96YT:71Y
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E
M;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES
M<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L
M(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE
M.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A
M=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL
M;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E
M(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="X`5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U
M<B!T87-K;&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@
M97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@
M<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N`%1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A
M<R!S=6-E<W-F=6QL>2!S=&]R960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I
M;&4@9F]R("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O
M('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A
M<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4
M:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U
M<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U
M<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O
M<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO
M;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A
M9V5S(&9R;VT@=&AE('AM;"!P87)S97(N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I;VX@:7,@
M;F]T('EE="!I;7!L96UE;G1E9"X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A
M9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I
M<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N
M`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G
M+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@
M:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V
M:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT
M('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N
M($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I
M="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R
M;VT@=&AE(&-O;6UA;F0@;&EN92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM
M92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET
M;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I
M`%1R86YS;&%T960`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`
M5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S
M`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!5
M4DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),
M.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N
M('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE
M8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S
M+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@
M9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#
M:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N9&QE9"!C
M;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@8V]M;6%N
M9#H@)7,`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R
M;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`
M56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U
M="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P
M<&]R=&5D($5X=&5N<VEO;@!5;G1R86YS;&%T960`57!D871E`%5P9&%T92`E
M<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E
M9"`B)7,B+@!5<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R("5S+@!5<&=R861E
M('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T
M:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE
M='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S86=E.@!5<V4@
M0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO
M;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!N;W0@9F]U;F0`57-E
M<B!N;W0@9F]U;F0N`%5S97(@<&5R;6ES<VEO;G,`57-E<FYA;64`57-E<FYA
M;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``
M57-E<G,`57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R
M:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E
M<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG
M`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE3
M0TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A
M<R`E<P!6:65W(&5V96YT`%9I97<@=&%S:P!6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI
M='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@86YD($9U
M='5N80!787)N:6YG`%=A<FYI;F<Z(`!790!796%T:&5R($9O<F5C87-T`%=E
M871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I
M=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7
M97-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S
M=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E
M<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI
M`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7:7-D;VT`5VES:&QI<W1S`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`5W)I=&EN9R!U<&1A=&5D(&AE;'`@9FEL92!T;R`E<RX`6"U2968`
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!9
M65E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I
M8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@
M>6]U<B!F=6QL(&YA;64N`%EO=2!C86XG="!C:&%N9V4@<&%S<W=O<F0@9F]R
M('5S97(@)7,`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!G:79E('EO=7(@8W5R<F5N
M="!P87-S=V]R9`!9;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D`%EO
M=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+@!9;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0`66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U
M<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O
M<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@
M3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I
M;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U
M<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@
M86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+@I.;W0@86QL('-T
M<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO;F<[('!A
M<W-W;W)D<R!M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T97)S(&QO
M;F<A`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,A
M("!.;W0@8VAA;F=E9"$`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L
M92!T;R!G=65S<RX@3F]T(&-H86YG960A`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8F4@870@;&5A<W0@)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&)E(&1I9F9E<F5N="!F<F]M('EO=7(@8W5R<F5N="!P
M87-S=V]R9`!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@86QP:&%B971I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R
M9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A
M8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S
M="`E9"!D:69F97)E;G0@='EP97,@;V8@8VAA<F%C=&5R<RX@5&AE('1Y<&5S
M(&%R93H@;&]W97(L('5P<&5R+"!N=6UE<FEC+"!A;F0@<WEM8F]L<RX`66]U
M<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&QO=V5R
M8V%S92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A
M:6X@870@;&5A<W0@)60@;G5M97)I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@=7!P97)C87-E(&-H
M87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!L97-S
M('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA<F%C=&5R<RX`
M66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:`!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R
M(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9',@9&\@;F]T(&UA=&-H`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)
M`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0
M<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN
M`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`86X@
M97)R;W(@:&%S(&]C8W5R960Z`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!D
M;VYE`&9A:6QE9`!F86QL:6YG`&9I;&4`9F]U;F0Z(`!F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S`&@Z`&AH`&EM;65D:6%T90!I;FQI;F4`;&1A<%]S=&%R
M=%]T;',@9F%I;&5D`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI
M;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@8VAA;F=E9`!N;W0@9F]U;F0`
M;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P
M97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA
M:6P@=FEA($A45%``<W,`<W1E861Y`'1A<VL@;&ES=`!T:&4@2&]R9&4@4$\@
M9FEL92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`
M=7!D871E9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J
M96-T+4ED+59E<G-I;VXZ(%!A<W-W9"`S+C`M8W9S"E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`U+3`X+3(Y(#$U.C$Y*S`S,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-"TQ,BTQ,"`Q,CHU.2LP,C`P"DQA<W0M5')A;G-L871O<CH@3&5E;F$@2&5I
M;F\@/&QI:6YU0'5T82YF:3X*3&%N9W5A9V4M5&5A;3H@1FEN;FES:"`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`@("U-+"`M+6UE<W-A9V4]3453
M4T%'12`@2^1Y=.0@=.1TY"!C;VUM:70M=FEE<W1I;N0@;F]R;6%A;&EN('9I
M97-T:6X@=&EL86QL80`@("UA+"`M+6%D9#U&24Q%("`@("`@("!,:7/DY"!T
MY&WD(%!/+71I961O<W1O(&MO;7!E;F1I:6XN"B`@("`@("`@("`@("`@("`@
M("`@("`@(%3D=.0@=F]I(&OD>71TY.0@<VEL;&]I;B!K=6X@;&ESY.1T('1O
M:7-E;B!H86%R86X*("`@("`@("`@("`@("`@("`@("`@("`@:V]M<&5N9&EN
M(&QU;W1U=6X@:V]M<&5N9&EI;BX`("`M8BP@+2UB87-E/2]0051(("!0;VQK
M=2!KY'ET971TY';DY&X@*$AO<F1E*2!P97)U<VAA:V5M:7-T;V]N+@`@("UC
M+"`M+6-O;7!E;F1I=6T]1DE,12`@66AD:7-TY"!KY.1N;O9K<V5T('3D:.1N
M(&MO;7!E;F1I:6XN"B`@("`@("`@("`@("`@("`@("`@("`@("!*;W,@96D@
M:&%L=71A(&OD>71TY.0@;VQE='5S=&EE9&]S=&]A(`H@("`@("`@("`@("`@
M("`@("`@("`@("`@*&-O;7!E;F1I=6TN<&\@:&]R9&4O<&\@:&%K96UI<W1O
M<W-A*2X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@($OD>73D('3D=.0@:V]M
M<&5N9&EA(&]L971U:W-E;B!S:6IA<W1A"B`@("`@("`@("`@("`@("`@("`@
M("`@("`H8V]M<&5N9&EU;2YP;R!H;W)D92]P;R!H86ME;6ES=&]S<V$I+@`@
M("UD+"`M+61E8G5G("`@("`@($[D>73D('9I<FAE:6QM;VET=6MS970@:^1Y
M;FYI<W1E='3D=FES=.0@;VAJ96QM:7-T82X`("`M9"P@+2UD:7)E8W1O<GD]
M1$E2("`@3'5O(&MO;7!E;F1I('3D:.1N(&AA:V5M:7-T;V]N+@`@("UH+"`M
M+6AE;'`@("`@("`@($[D>73D('3D;>0@;VAJ92X`("`M;"P@+2UL;V-A;&4]
M;&Q?0T,@("`@($OD>73D('9A:6X@=.1TY"!L;VMA;&ES;VEN=&EA+@`@("UL
M+"`M+6QO8V%L93UL;%]#0R`@("`@2^1Y=.0@=.1TY"!L;VMA;&ES;VEN=&EA
M+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!+Y'ETY"!TY'3D(&QO:V%L:7-O
M:6YT:6$N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!4964@34\M=&EE9&]S
M=&]T('9A:6X@=.1L;&4@*$AO<F1E*2!M;V1U=6QI;&QE+@`@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@4VEI<W1I(%!/+71I961O<W1O="!V86EN('3D;&QE
M("A(;W)D92D@;6]D=75L:6QL92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($MO;6UI=&]I(&ODY&YN]FMS970@=F%I;B!TY&QL92`H2&]R9&4I(&UO9'5U
M;&EL;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!,=6\@34\M=&EE9&]S
M=&]T('9A:6X@=.1L;&4@*$AO<F1E*2!M;V1U=6QI;&QE+@`@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@66AD:7-TY"!03RUT:65D;W-T;R!V86EN('3D;&QE
M("A(;W)D92D@;6]D=75L:6QL92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M(%#D:79I=.0@;VAJ971I961O<W1O="!V86EN('3D;&QE("A(;W)D92D@;6]D
M=75L:6QL92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%#D:79I=.0@=F%I
M;B!TY&WD("A(;W)D92D@;6]D=75L:2X`("`M;2P@+2UM;V1U;&4]34]$54Q%
M("!4964@4$]4+71I961O<W1O('9A:6X@=.1L;&4@*$AO<F1E*2!M;V1U=6QI
M;&QE+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@Q&SD('EH9&ES=.0@:^3D
M;F[V:W-IY"!K;VUP96YD:6EN+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@
MQ&SD(&OD>73D(&MO;7!E;F1I82X`("`M<RP@+2US=&%T:7-T:6-S("`@("`@
M(%1A;&QE=&$@:^3D;F[V<W1I;&%S=&]T('!A:6MA;&QI<V5E;B!T:65D;W-T
M;V]N+@`@("UT+"`M+71E<W0@("`@("`@($[D>73D('-U;W)I=&5T=&%V870@
M:V]M96YN;W0L(&UU='1A(.1LY"!A:F$@;FEI=.0N`"`@8VQE86YU<"`@("`@
M4&]I<W1A82!03RUT:65D;W-T;VES=&$@:^3D;G3D;>1T=/9MY'0@:F$@=F%N
M:&5N='5N965T(&]S:6]T+@`@(&-O;6UI="`@("`@($MO;6UI=&]I(&ODY&YN
M]FMS970@0U93+7!A;'9E;&EM96QL92X`("!C;VUM:70M:&5L<"!+;VUM:71O
M:2!O:&IE=&EE9&]S=&]T($-64RUP86QV96QI;65L;&4N`"`@8V]M<&5N9&EU
M;2`@5&5E(&MO;7!E;F1I('5U9&5S=&%A;BX@5F%R;VET=7,Z(%3D;>0@:VER
M:F]I='1A80H@("`@("`@("`@("`@('5U9&5N(&MO;7!E;F1I;B!V86YH86X@
M<.3D;&QE+@`@(&5X=')A8W0@("`@(%1E92!03RUK86%V871I961O<W1O("@N
M<&]T*2X`("!H96QP("`@("`@("!.Y'ETY"!TY&WD(&]H:F4N`"`@:6YI="`@
M("`@("`@3'5O('EK<VD@=&%I('5S96%M<&D@4$\M=&EE9&]S=&\@=75D96QL
M92!L;VMA;&ES;VEN;FEL;&4N"B`@("`@("`@("`@("`@5F%R;VET=7,Z(%3D
M;>0@:VER:F]I='1A82!L;VMA;&ES;VEN;FEN('5U9&5N(%!/+71I961O<W1O
M;@H@("`@("`@("`@("`@('9A;FAA;B!PY.1L;&4`("!M86ME("`@("`@("!4
M964@8FENY.1R:6YE;B!-3RUT:65D;W-T;R!03RUT:65D;W-T;VES=&$N`"`@
M;6%K92UH96QP("`@365R:VET<V4@:V%I:VMI(&]S:6]T(%A-3"UM=6]T;VES
M97-T82!O:&IE=&EE9&]S=&]S=&$@"B`@("`@("`@("`@("`@<.1I=FET971Y
M:W-I(&IA('9A;&UI<W1E;&4@=&EE9&]S=&\@=7!D871E+6AE;'`@:V]M96YN
M;VX*("`@("`@("`@("`@("!A:F]A('9A<G1E;BX@4VEN=6X@<&ETY.0@86IA
M82!M86ME+6AE;'`@<V5N(&KD;&ME96X@:W5N(&]L970*("`@("`@("`@("`@
M("!PY&EV:71TY&YY="!O:&IE=&EE9&]S=&]A(&IA(&%J86YU="!U<&1A=&4M
M:&5L<"!K;VUE;FYO;BX`("!M97)G92`@("`@("!9:&1I<W3D(&YY:WEI;F5N
M(%!/+71I961O<W1O(&IA(%!/+6MA879A=&EE9&]S=&\N`"`@=7!D871E("`@
M("`@06IA(&5X=')A8W0@:F$@;65R9V4@>6AD:7-T96QMY"X`("!U<&1A=&4M
M:&5L<"!(864@:V%I:VMI('5U9&5T(&IA('#D:79I=&5T>70@;W-I;W0@96YG
M;&%N;FEN:VEE;&ES97-TY`H@("`@("`@("`@("`@(%A-3"UM=6]T;VES97-T
M82!O:&IE=&EE9&]S=&]S=&$@:F$@>6AD:7-TY"!N92!O;&5M87-S86]L979I
M96X*("`@("`@("`@("`@("!O<VEO:61E;B!K86YS<V$N`"`F(S$U,3L@)7,@
M;VX@=F%L;6ES('-U;W)I='1A;6%A;B!V86QI='5T('EL;.1P:71O=&]I;65N
M<&ET965T+@`@*"5S('#D:7;DY"!S:71T96XI`"`H4&EK86[D<'#D:6X@)7,I
M`"`H)7,@<.1I=N1S<^0I`"`H=.1NY.1N*0`@*&AU;VUE;FYA*0`@*&5I;&5N
M*0`@`"(E<R(@96D@:V5L<&%A('9A;&EN;F%K<VDN`"(E<R(@96D@;VQE(&%S
M96YN971T=2!(;W)D96X@<F5K:7-T97)I<W/D+@`B)7,B('!U:61E;B!K=79A
M86IA82!E:2!L]GET>6YY="X`(B5S(B!L:7/D='1I:6X@<GEH;>1JY')J97-T
M96QMY.1N+@`B)7,B(&QI<^1T=&EI;B!O:6ME=6MS:6EN+@`B)7,B(&5I(&QU
M;W1U.B`E<RX`)60@)7,@:F$@)7,`:VER:F]I=&5T=&EI;B`E9"!T879U82X`
M)60@;W-I;W1A("5D.G-TY"!M97)K:71T:6EN('#D:79I=&5T>6MS:0`E9"!P
MY&EVY&X@96YN=7-T=7,`)7,@+2!);&UO:71U<P`E<R!9;&SD<&ET;P`E<R!3
M;W)M96YJY&QK:0`E<R!+0@`E<R!9;&SD<&ET;W1O:6UE;G!I=&5E="`M(%9A
M<FUI<W1U<P`E<R!A<V5N;G5S`"5S(&MI<FIA=71U;6EN96X`)7,@:^1Y='3V
M96AD;W0`)7,@;VX@:F\@;VQE;6%S<V$N`"5S('-U=6YT82`E<R`E<P`E<R!E
M:2!O;&4@;VQE;6%S<V$@=&%I(&5I(&]L92!A:F5T=&%V82!O:&IE;&UA+@`E
M<R!O;B!P97)U=71T86YU="`E<SIN+@`E<R!O;B!V87-T86YN=70@=F%P86$O
M=F%R871T=2!P>7EN=/;V;BX`)7,@;VX@=F%S=&%N;G5T(&MU='-U=6X@)7,N
M`"5S(&]N(&SD:&5T=.1N>70@<VEN=6QL92!V87!A82]V87)A='1U('1I971O
M:F$N`"5S(&5I('9O:2!K:7)J;VET=&%A+@`E<R!O;B!P86MO;&QI;F5N`"5S
M(&UI;G5U='1I80`E<R!E:2!L]GET>6YY="X`)7,@96D@;/9Y='EN>70N($%J
M82!E;G-I;B`G=')A;G-L871I;VX@97AT<F%C="<N`"5S('!Y>73DY"!S:6YU
M;'1A('9A<&%A+W9A<F%T='4@=&EE=&]J82X`)7,@<'EY=.3D('-I;G5A(&]L
M96UA86X@<&%I:V%L;&$@)7,Z<W/D+@`E<R`M("5S("\@)7,`)7,@:&%L=6%A
M(&QI<^1TY"!S:6YU="`E<SIE96XN`"5S(&AA;'5A82!I;&UO:71T86$@<VEN
M=6QL92`E<SIS=.0N`"5S(&AA;'5A82!S86%D82!U=7-I;6UA="!T:65D;W0@
M)7,Z<W3D+@`E<SIN(&]S;VET96MI<FIA`"5S.FX@:V%L96YT97)I`"5S.FX@
M;75I<W1I;&ES=&$`)7,Z;B!T96ATY';D;&ES=&$`)7,Z("5S`"5S.B!E:2!V
M;VD@;&%D871A(&%J=7)I83H@)7,`+"!P=75S:VET=&%I<W1A("5S("5S`"P@
M=F%I:'1E;&5V86$@)7,@+2`E<P`M+2!V86QI='-E("TM`"TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+0`Q,BUT=6YN:6X@:N1R:F5S=&5L;>0`,C0M='5N
M;FEN(&KD<FIE<W1E;&WD`#(T('1U;G1I80`\161E;&QI;F5N`#QG971T97AT
M/B!T86=I82!E:2!L]GET>6YY="!T:65D;W-T;W-T82`E<RX*06QO:71U<R!T
M86=I(&SV>71Y:2!R:79I;'3D("5D+@!4:65T;VMA;G1A=&%U<W1A:N1R:F5S
M=&5L;>3D(&5I(&]L92!MY.1R:71E;'1Y('3D;&QE(&]S:6]L;&4`5&%P86AT
M=6D@=F%K879A('9I<FAE`%9I97-T:6X@<V%L875K<V5E;B!T87)V:71A86X@
M:G5L:VEN96X@4$=0+6%V86EN+@!!;&QE:VER:F]I=&5T=6X@=FEE<W1I;B!T
M87)K:7-T=6MS965N('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XN`%-A
M;&%T=6X@=FEE<W1I;B!A=F%A;6ES965N('1A<G9I=&%A;B!J=6QK:6YE;B!0
M1U`M879A:6XL('-A;&%I;F5N(%!'4"UA=F%I;B!J82!S86QA<V%N871E:W-T
M:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A;6ES96MS:2!T87)V:71A86X@:G5L
M:VEN96X@4$=0+6%V86EN+"!S86QA:6YE;B!01U`M879A:6X@:F$@<V%L87-A
M;F%T96MS=&DN`%9I97-T:6X@879A86UI<V5E;B!T87)V:71A86X@:G5L:VEN
M96X@4R]-24U%+6%V86EN+"!S86QA:6YE;B!3+TU)344M879A:6X@:F$@<V%L
M87-A;F%T96MS=&DN`%9I97-T:6X@86QL96MI<FIO:71T86UI<V5K<VD@=&%R
M=FET86%N(&IU;&MI;F5N(%,O34E-12UA=F%I;BP@<V%L86EN96X@4R]-24U%
M+6%V86EN(&IA('-A;&%S86YA=&5K<W1I+@!6:65S=&EN('-A;&%U:W-E96X@
M=&%R=FET86%N(&IU;&MI;F5N(%--24U%+6%V86EN+@!!1%-)('9I<FAE("5S
M+@!!32!0:6QV:>0`04T@:V5V>71TY"!S861E='1A`$%-('-A9&4`04T@<V%T
M96ET80!!32!L=6UI<V%T96ET80!!32]030!!4$D@240`5&EE=&]J82!E9&ET
M;W)I<W1A`%1I971O:F$N+BX`06)S+B!A;&EN`$%B<RX@:V5S:V5L;.0`2'EV
MY&MS>2!P>7EN=/8`2'EVY&MS>71T>0!+Y'ET=/8@:VEE;&QE='1Y+@!3:6YU
M;&QA(&5I(&]L92!O:6ME=6MS:6$@;'5O9&$@5D93+6AA:V5M:7-T;V$N`%-I
M;G5L;&$@96D@;VQE(&]I:V5U:W-I82!L=6]D82!61E,M=&EE9&]S=&]A+@!+
MY'ET=.1JY'1I;&EN('-A;&%S86YA`$OD>71TY&KD=&EL:2!S=6QJ971T=2X`
M2VER:F%N<&ET;P!4;VEM:6YN;W0`3&ESY.0`3&ESY.0@86QI<GEH;>0`3&ES
MY.0@86QI;VEK975S`$QI<^3D('3D:.1N.@!,:7/DY"!U=7-I(')Y:&WD`$QI
M<^3D('5U<VD@;VEK975S`$QI<^3D(&%L:7)Y:&WD(')Y:&WDY&X@(B5S(@!,
M:7/DY"!A;&EO:6ME=61E="`B)7,B`$QI<^3D('5U<VD@:^1Y='3D:N0Z`$QI
M<^3D('-A<F%K90!,:7/DY"!U=7-I82!JY'-E;FGD`$QI<^3D('!A<FD`3&ES
MY.0@)7,@=F%L:6MK;R!-;WII;&QA;B!3:61E8F%R(&]S:6]O;@!,:7/DY"!T
MY&WD(&MA;&5N=&5R:6EN:0!,:7/DY"!O<V]I=&5K:7)J86%N.@!,:7/DY"!O
M<V]I=&5K:7)J86%N:3H`3&ESY.0@:^1Y='3D:N0`3&ESY'1T:6EN("(E<R(@
M:N1R:F5S=&5L;>3D;BP@;75T=&$@96D@=F]I(&QI<^1TY"!S:7/DY&YK:7)J
M875T=6UI<W!Y>6YN]FX@;&ESY'1I971O:F$Z("5S+@!,:7/D='1I:6X@(B5S
M(B!JY')J97-T96QMY.1N+B!6;VET(&YY="!K:7)J875T=6$@<VESY.1N+@!,
M:7/D=.3D;B!U=7-I82!T:65D;W-T;VIA('9A<F%S=&]O;CH`2^1Y='3D:FEE
M;B!L:7/DY&UI;F5N(&]N(&5S=&5T='DN`$]S;VET90!/<V]I=&5K:7)J80!6
M;VD@87-E='1A82!T86D@;>3D<FET96QLY"!O:6ME=6MS:6$@=&]I<VEL;&4@
M:^1Y='3D:FEL;&4`66QLY'!I=&\`36%I;F]K<V5T`$%F9VAA;FES=&%N`$%L
M8F%N:6$`06QG97)I80!!;&EA<P!487-A80!487-A=7,Z`$MA:6MK:0!+86EK
M:VD@875T96YT:6MO:61U="!KY'ET=.1JY'0`2V%I:VMI(')Y:&WD=`!+86EK
M:VD@;VEK975D970`2V%I:VEL=&$@;F5L:N1L=.0@<VEV=6QT80!386QL:2!M
M;VYE="!O<V]I='1E970`4V%L;&D@:N1R:F5S=&5T>6X@;&ES=&%N('1Y>7!I
M;B!A<V5T=7,N`$]N(&IO(&]L96UA<W-A`%9A:6AT;V5H=&]I;F5N($E-4U`M
M<VESY.1N:VER:F%U='5M:6YE;@!686EH=&]E:'1O:6YE;B!)35-0+7-A;&%S
M86YA`%9A:6AT;V5H=&]I;F5N($E-4U`M:^1Y='3D:N1T=6YN=7,`5F%I:'1O
M96AT;VES970@<^1H:_9P;W-T:6]S;VET=&5E=`!686EH=&]E:'1O:7-E="!M
M86QL:70`5F%I:'1O96AT;VEN96X@=&5K<W1I.@!9:&1Y<W9A;'1A:6X@4V%M
M;V$`06YN971T=2!A<G9O(&5I(&ME;'!A82X`=&%P86AT=6D@='5N=&5M871O
M;B!V:7)H92X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEY;6D@<')O
M>'D`5F%S=&%U<P!!;G1A<FMT:7,`06YT:6=U82!J82!"87)B=61A`$]H:F5L
M;6$`3VAJ96QM86QI<W1A`$]H:F5L;6$@;VX@=F%L;6ES+@!,86ET82!KY'ET
M=/;V;B!K86EK:VD@86QI:F%K;VEH:6X`2'EVY&MS>0!!<G9I;VET=2!K;VMO
M`&AU:'1I:W5U`$%R86)I82`H5VEN9&]W<RTQ,C4V*0!086ME=&EN(&MO:V\`
M4&%K971I;B!N:6UI`$]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A
M82!S:7/DY&YK:7)J875T=6UI<W!Y>6YN]FX@)7,@/P!/;&5T:V\@=F%R;6$L
M(&5T=.0@:&%L=6%T('!O:7-T86$@(B5S(B!J82!K86EK:VD@<V5N(&%L:7)Y
M:&WD=#\`06=E;G1I:6YA`$%R;65N:6$`07)M96YI82`H05)-4T-)22TX*0!4
M86ED90!!<G5B80!!<V-E;G-I;VX@<V%A<F5T`$%S8VEI+71A:61E`$%S:6%N
M+U1Y>6YE;FUE<F5N(&%L=64`2WES>2!V87)M:7-T=7,@96YN96YK=6EN('1E
M:&3DY&X@>6QLY'!I=&]T;VEM96YP:71E970N`%1E:'3D=N1S87)A:VME970`
M3&EI='1E96YA(&]N(&E#86QE;F1A<BUT:65D;W-T;RP@:F]K82!O;B!V87-T
M875S(&SD:&5T=.1MY.1S:2!P>7EN=/;V;@!9<FET971T:6EN('!O:7-T86$@
M;VQE;6%T;VYT82!R>6AMY.0N`%ER:71E='1I:6X@<&]I<W1A82!O;&5M871O
M;G1A(&]I:V5U='1A+@!9<FET971T:6EN(&UU;VMA=&$@;VQE;6%T;VYT82!O
M:6ME=71T82X`67)I=&5T=&EI;B!M=6]K871A(&]L96UA=&]N=&$@:F%K;V$N
M`$]S86QL:7-T=6IA=`!,:7/D;>3D<FET>6MS970`96QO:W5U`$%U<W1R86QI
M80!)=.1V86QT80!!=71H7V-Y<G-Q;#H@5&%R=FET=&%V86$@24U!4"UL86%J
M96YN=7-T82!E:2!L]GET>6YY="X`075T:%]C>7)U<SH@5&%U<W1A:N1R:F5S
M=&5L;>0@96D@='5E('1A<G9I='1A=FEA(&]M:6YA:7-U=6MS:6$N`$%U=&A?
M8WER=7,Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN
M>70N`$%U=&A?9G1P.B!T87)V:71T879A82!&5%`M;&%A:F5N;G5S=&$@96D@
M;/9Y='EN>70N($ODY&YNY"!02%`@:^1Y='3D96X@+2UE;F%B;&4M9G1P(&%S
M971U<W1A+@!!=71H7VEM87`Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S
M=&$@96D@;/9Y='EN>70N`$%U=&A?:W)B-3H@5&%R=FET=&%V86$@:W)B-2UL
M86%J96YN=7-T82!E:2!L]GET>6YY="X`075T:%]L9&%P.B!487)V:71T879A
M82!,1$%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7VQD87`Z($5I
M('9O:61A(&QI<^1TY"!KY'ET=.1JY.0@)7,N(%!A;'9E;&EM96X@=FER:&5I
M;&UO:71U<R!O;&DZ(`!!=71H7VQD87`Z($5I('9O:61A('!O:7-T86$@:^1Y
M='3D:N3D("5S`$%U=&A?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D(&OD>71T
MY&KDY"`E<P!!=71H7VUC86PZ(%1A<G9I='1A=F%A($U#04PM;&%A:F5N;G5S
M=&$@96D@;/9Y='EN>70N`$%U=&A?<VUB875T:#H@5&%R=FET=&%V86$@<VUB
M875T:"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T96YT:6MO:6YT:2!E
M<.1O;FYI<W1U:0!!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I+B`E<P!!=71E
M;G1I:V]I;G1I(%)!1$E54RUP86QV96QI;65L=&$@97#D;VYN:7-T=6DN`$%U
M=&5N=&EK;VEN=&D@1E10+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`2^1Y
M=&5T=.1V:7-SY&]L979A="!K96YTY'0Z`$]D;W1E=&%A;B!V87-T875S=&$`
M07IE<F)A:7ID86X`0D]&2"!S96QI='EK<V5T`%1A=7-T86KD<FIE<W1E;&WD
M(&5I('1O:6UI;G5T(&]I:V5I;BX`5&%U<W1A`%1A=7-T879A<FD`5N3D<N0@
M:V5R8F5R;W,@<V%L87-A;F$N`%;DY'+D(&ME<F)E<F]S(&OD>71TY&KD='5N
M;G5S+@!"86AA;6$`0F%H<F%I;@!"86QT:6$@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97-H`$)A<F)A9&]S`$=R869I:6MO:61E;B!P97)U<VAA:V5M:7-T;V$@
M(B5S(B!E:2!L]GET>6YY="X`4&5R=7-V:6EV80!686QK;RU696[D:N0`0F5L
M9VEA`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!3>6YT>6WD<.1I=N0`
M3W-I;W1A("(E<R(@;VAJ96QM86QL92`B)7,B(&5I(&SV>71Y;GET+@!/<VEO
M;B!A<V5T=6MS970`3W-I;VX@='EY<'!I`$QI:&%V;VET=0!";VQI=FEA`$MI
M<FIA;FUE<FMI=`!2975N80!2975N86X@=F%H=G5U<SH`4F5U;F%T`$)O<VYI
M82!(97)Z96=O=FEN80!-;VQE;6UA=`!";W1S=V%N80!!;&EN`$)O=79E="!S
M86%R970`0G)A<VEL:6$`0G)I=&%N;FEA;B!);G1I86X@=F%L=&%M97)E;B!T
M97)R:71O<FEO`$)R=6YE:2!$87)U<V%L86T`375O9&]S=&5T86%N($U/+71I
M961O<W1O:F$@;6]D=75L:6QL92`E<RXN+@!-=6]D;W-T971A86X@;&]K86QI
M<V]I;G1I("5S+BXN(`!"=6QG87)I80!086QL=6MK86QI<W1A`$)U<FMI;F$@
M1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),+6IA:V5L=6]S;VET=&5E=`!37V]L
M=6X@=&EE9&]T+BXN`%;D;&EM=6ES=&EN(&%L=7-T=7-T82!E:2!S=6]R:71E
M='1U(&QO<'!U=6XN`$MA;&5N=&5R:0!4>7EN:0!+86UP=71S96$`2V%M97)U
M;@!386QA<V%N86$@96D@=F]I('1Y:&IE;G3DY"!A=71O;6%A='1I<V5S=&DL
M(&]T82!Y:'1E>71TY"!Y;&SD<&ETY&KDY&XN`$E-05`M<&%L=F5L:6UE96X@
M96D@<V%A='4@>6AT97ET=.0Z("5S`$MA;F%D80!097)U`%!E<G4@;VYG96QM
M879I97-T:0!%:2!V;VED82!P;VES=&%A('1I961O<W1O82`B)7,B+@!6Y&QI
M86EK86ES:&%K96UI<W1O82!E:2!L]GET>6YY="X`16D@=F]I9&$@:F%T:V%A
M(&EL;6%N("=T87)G971&:6QE)R!P87)A;65T<FEA+@!%:2!V;VED82!P;VES
M=&%A(&AA:V5M:7-T;V$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82P@)60@86QI
M=&%S;VIA(&]L96UA<W-A+@!%:2!V;VD@=75D96QL965N:N1R:F5S=.3D+"!A
M;FYE='1U:F5N('1I971U96ED96X@;>3D<N0@96D@=F%S=&%A('1A;&QE=&5T
M='5J96X@=&EE='5E:61E;B!MY.1RY.0N`$5I('9O:2!O:&IA=&$@=FEE<W1I
MY"!A;FYE='1U=6X@;G5M97)O;VXN`$MA<"!697)D90!+=79A=&5K<W1I`$MA
M=&5G;W)I870@:F$@;W1S:6MO=`!#87EM86X@<V%A<F5T`%!U:&5L:6XH1U--
M*0!3;VQU;B!T:65D;W0`4V]L=6X@=.1Y=&4Z`%-O;'5N('1I961O=`!3;VQU
M;B!VY&QY<SH`36%T:V%P=6AE;&EN`$ME;'1T:2`H25-/+3@X-3DM,30I`$ME
M<VMI=&5T='D`2V5S:VDM069R:6MA;B!T87-A=F%L=&$`2V5S:VDM175R;V]P
M<&$@*$E33RTX.#4Y+3(I`%9A<FUE;G1E96X@=&EE9&]T`%9A<FUE;G1E96X@
M;VUI<W1A:F$`5F%R;65N=&5E;B!P;VQI=&EI:V%T`%1S860`4'5H965N:F]H
M=&%J80!-=75T80!686EH9&$@<V%L87-A;F%S:0!686EH9&$@<V%L87-A;F$Z
M`%9O:70@;75U='1A82!LY&AE='3D;6ES<^1S:2!SY&AK]G!O<W1E:7-S82!N
MY&MY=FGD(&YI;6DM('1A:2!O<V]I=&5T:65T;VIA+@!686EH9&$@<V%L87-A
M;F%S:0!686EH9&5T86%N('-A;&%S86YA82`E<SIL;&4`365R:VMI`%1A<FMI
M<W1?82!L:6YK:VDN+BX`5F%L:71S92!V86QI;G1A<G5U9'5I<W1A('-U;W)I
M=&5T=&%V870@=&]I;65N<&ET965T+@!#:&EL90!+:6EN80!+:6EN82!Y:W-I
M:V5R=&%I<W1E='1U("A'0C(S,3(I`$MI:6YA('!E<FEN=&5I;F5N("A":6<U
M*0!686QI='-E('-A;&%S86YA`%9A;&ET<V4@:^1Y='3D:N1T=6YN=7,`5F%L
M:71S92!T;VEM:6YT;SH`5F%L:71S92!PY&EVY&WDY')I96X@97-I='ES87-U
M.@!686QI='-E(&QI<W1A;B!T>7EP<&D@*&KD<FIE<W1E='EI;&QE(&QI<W1O
M:6QL92D`2F]U;'5S86%R970`3'5O:VMA;>3D<FET>7-TY"`E<R!E:2!L]GET
M>6YY="X`4VEI=F]T86%N(%!/+71I961O<W1O:F$@;6]D=75L:6QL92`E<RXN
M+@!3:6EV;W1A86X@;&]K86QI<V]I;G1I82`E<RXN+@!396QK9>0`4&]I<W1A
M($U33V9F:6-E('1A9VET`%!O:7-T82!KY'ET=.1JY#H@)7,`4&]I<W1A(&OD
M>71TY&KD`%!O:7-T82!KY'ET=.1JY&X@=&EE9&]T`%-E;&ME;F5VY.0@;7GV
M:&5M;6EN`$YA<'-A=71A(&IA=&MA86MS97-I`$-L:6MA=&5L;"!(5%10.FX@
M:V%U='1A`%-U;&IE(&EK:W5N80!0:6QV:>0`4&EL=FGD(&%I:V%I<VEN`%!I
M;'9I;F5N`$MO;VMO<R`H2V5E;&EN9RD@<V%A<F5T`%!I96YE;F[D('-I=G5V
M86QI:VMO`%!I96YE;FYE='ET(')E=6YA=`!+;VQU;6)I80!6Y')I`%;D<FEV
M86QI='-I;@!6Y')I=F%L:6YT80!387)A:SH`4V%R86MK96ED96X@;W1S:6MO
M=`!387)J86MU=F%T`$MO;65N=&\`2V]M96YT;W1U;&MK:0!+;VUE;FYN;VX@
M<&%R86UE=')I=`!+;VUE;G1O.@!+;VUM96YT=&D`2V]M;6ET;VED86%N.@!9
M;&5I;F5N(&YI;6D`2V]M;W)I=`!9<FET>7,`4W5O<FET971T=0!+:7)J;VET
M82!V:65S=&D@*"5S*0!4:65T;VMO;F5E=`!/;&]S=6AT965T`$%S971U:W-I
M96X@97)O=`!!<V5T=7-T:65D;W0@;W9A="!V86YH96YT=6YE970N`$%S971A
M(&%S971U:W-E="`E<P!686AV:7-T82!K:7)J;VET=&%M86QL82!S86QA<V%N
M82!U=61E<W1A86X`5F%H=FES=&$@=75S:2!S86QA<V%N80!+;VYG;P!+;VYG
M;VX@9&5M;VMR86%T=&EN96X@=&%S879A;'1A`%EH=&5Y<R!E<.1O;FYI<W1U
M:2X`66AT97ES(&5PY&]N;FES='5I.B``66AT97ES(&IU;&MI<W1E;B!A=F%I
M;G1E;B!P86QV96QI;65L;&4@97#D;VYN:7-T=6DN`%EH=&5Y<R!J=6QK:7-T
M96X@879A:6YT96X@<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+B!6:7)H93H@
M)7,@*"5S*0!9:'1E>7,@9G1P+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`
M66AT97ES=&EE9&]T(&QI<^1T=&EI;B!O<V]I=&5K:7)J86%S:2X`(B5S(CIN
M('-I<^1L=/8`2F%T:V$`0V]O:R!S86%R970`17;D<W1E`$MO<&EO:0!+;W!I
M;VD@=F%L:6YT80!+;W!I;VD@)7,@)7,Z86MS:0!#;W-T82!2:6-A`$YO<G-U
M;FQU=7)A;FYI:VMO`%9I97-T:6X@4$=0+7-A;&%U<W1A(&5I('9O:71U('1E
M:&3D+@!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@4$=0+6%L;&5K:7)J
M;VET=7-T82X`5FEE<W1I;B!3+TU)344M<V%L875S=&$@96D@=F]I='4@=&5H
M9.0N`%9I97-T:6EN(&5I('9O:71U(&UU;V1O<W1A82!3+TU)344M86QL96MI
M<FIO:71U<W1A+@!%:2!V;VET=2!O='1A82!Y:'1E>71TY"X@)7,`3&1A<"UP
M86QV96QI;65E;B!E:2!S86%T=2!Y:'1E>71TY"X`3$1!4"UP86QV96QI;G1A
M(&5I('9O:71U(&OD>71TY.0`16D@=F]I='4@=&%R:VES=&%A('-A;&1O82X@
M)7,`3$1!4"UP86QV96QI;65E;B!E:2!S86%T=2!Y:'1E>71TY`!%:2!V;VET
M=2!O='1A82!Y:'1E>71TY"!P86QV96QI;65E;B`B)7,B(&OD>71TY&5N($94
M4#H@)7,`16D@=F]I='4@:V]P:6]I9&$@)7,@)7,Z:W-I`$5I('9O:71U(&QU
M;V1A(&IA:V5L=6QI<W1A82X@)7,`16D@=F]I='4@;'5O9&$@;&]C86QE(&AA
M:V5M:7-T;V$@;&]K86QI<V]I;FYI;&QE("5S.@!01U`M<V%L871T=6$@=&EE
M=&]A(&5I('9O:71U(&%U:V%I<W1A+@!3+TU)344M<V%L871T=6$@=&EE=&]A
M(&5I('9O:71U(&%U:V%I<W1A+@!%:2!V;VET=2!P;VES=&%A('EH=&5Y<W1I
M971O82X@)7,`16D@=F]I='4@<&]I<W1A82!J86ME;'5L:7-T86$N("5S`$5I
M('9O:71U('!O:7-T86$@<.1I=FET>7-S:W)I<'1IY"`B)7,B+@!6:65S=&EN
M(&SD:&5T=.1JY&X@<^1H:_9P;W-T:6]S;VET971T82!E:2!P>7-T>71T>2!M
MY.1R:71T96QE;>3D;BX`16D@=F]I='4@:&%K96$@:V]K;R!O<V]I=&5K:7)J
M86$N`$5I('9O:71U(&AA:V5A(&MO:V\@:F%K96QU;&ES=&%A+@!%:2!V;VET
M=2!H86ME82!K;VMO(&QI<W1A82!J86ME;'5L:7-T;VES=&$N`$5I('9O:71U
M(&QU:V5A('-T<F%T96=I86$@(B5S(BX`2V]M96YT;R!M:V1I<B`B)7,B(&5P
MY&]N;FES='5I+@!*=6QK:7-T96X@879A:6YT96X@<&%L=F5L:6UE;'1A(&5I
M('-A871U(&IU;&MI<W1A(&%V86EN=&$N`%1I961O<W1O;VX@(B5S(B!E:2!V
M;VD@:VER:F]I='1A82X`16D@=F]I='4@875K86ES=&$@)7,N`%EL;.1P:71O
M;6]D=75L:6X@)7,@875K86ES=2!E<.1O;FYI<W1U:0!%:2!V;VD@875K86ES
M=&$@:&%K96UI<W1O82`B)7,B+@!%:2!V;VET=2!A=6MA:7-T82!P=71K96$@
M<VUB<&%S<W=D+6]H:F5L;6%L;&4N`"5S.N3D(&5I('9O:71U(&QU:V5A+@!+
MY'ET=.1JY&X@<V%L87-A;F%A(&5I('9O:71U(&YO;&QA=&$N($IO=&MU="!T
M87)V:71T879A="!T:65D;W0@;W9A="!VY.1R:6XN(%ER:73D('5U9&5S=&%A
M;B!T86D@;W1A('EH=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E="!L
M:7/DY"!A<'5A+@!%:2!V;VET=2!H86ME82!!0TPM=&EE=&]J80!%:2!V;VET
M=2!H86ME82!O<V]I=&5K:7)J86$N("5S`$5I('9O:71U(&AA:V5A(&IA:V5L
M=6QI<W1A82X@)7,`16D@=F]I='4@:&%K96$@:F%K96QU;&ES=&]J82X@)7,`
M16D@=F]I='4@:&%K96$@=&EE=&]J82!P86QV96QI;65N('1O:6UI;FYO:7-T
M80!%:2!V;VET=2!P86QA=71T86$@87-E='5K<VEA+@!+;VUE;G1O(')M9&ER
M("(E<R(@97#D;VYN:7-T=6DN`$5I('9O:71U('1A;&QE='1A82`E<R!A<V5T
M=6MS:6$N`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R;75U<VMO
M<&EO=&$N`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R;75U<VMO
M<&EO=&$@)7,`16D@=F]I='4@=&%L;&5T=&%A(&%S971U<W#D:79I='ES<VMR
M:7!T:>0Z("(E<R(N`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R
M;75U<VMO<&EO=&$@)7,N`$%S971U<W1I961O<W1O;B`E<R!T86QL971U<R!E
M<.1O;FYI<W1U:2X@5F]I="!KY'ET=.3D(&IO=&%K:6X@87-E='5S=&$@=&%L
M;&5T=&%A:W-E<VD@:V]O9&EN('1A:V%I<VEN("5S('1A:2!T86D@:V]P:6]I
M9&$@:^1S:6X@86QL82!O;&5V86X@:V]O9&EN('1I961O<W1O;VX@)7,N`$Q$
M05`M<&%L=F5L:6UE;'1A(&5I(&]L92!M86AD;VQL:7-T82!E='-IY"X`2V]M
M96YT;R!U;FQI;FL@(B5S(B!E<.1O;FYI<W1U:2X`16D@=F]I='4@<.1I=FET
M=.3D('EH=&5Y<W1I971O:F$N("5S`$5I('9O:71U('#D:79I='3DY"!J86ME
M;'5L:7-T86$N("5S`%9I97-T96KD(&5I('9O:71U('!O:7-T86$@:V%N<VEO
M<W1A("(E<R(Z("5S`$UO>FEL;&$@4VED96)A<B!E:2!L]GET>6YY="X@5F%R
M;6ES=&$@971TY"!3:61E8F%R(&]S:6\@;VX@875K:2X`2^1Y='3D:N1L;&4@
M(B5S(B!E:2!V;VET=2!A;G1A82!S975R86%V:6$@;VEK975S:6$@:V%N<VEO
M;VX@(B5S(CH@)7,`3&%S:V5T='4@=&5K<W1I`$UA80!+=7)S<VET`$QU;P!,
M=6\@=75S:2!L:6YK:VD`3'5O('5U<VD`5F]I(&QU;V1A('5U<VEA(&MA;G-I
M;VET80!/:6ME=61E="!T96MI:N1L;.0`3'5O='1O:V]R=&EN;G5M97)O`$MR
M;V%T:6$`2W5U8F$`5.1L;.0@:&5T:V5L;.0@-"!V86EH971T80!+96QL;VYA
M:6MA('3D;&SD(&AE=&ME;&SD`$YY:WEI;F5N(%523"!O;@!4Y&WD;B!H971K
M:6YE;B!SY.0`3GEK>6EN96X@=&EL83H@`$YY:WEI;F5N('1Y>6QI`%9O:70@
M;75O:V%T82!T96ATY'9IY"P@:F]T:V$@<W5O<FET971A86X@:W5N(&MI<FIA
M=61U=&%A;B!S:7/DY&X@;VAJ96QM86%N("5S+@!,96EK:V%A`$QE:6MK86$@
M=F%L:71T=0!+>7!R;W,`2WER:6QL:6YE;B`H2T])."U2*0!+>7)I;&QI;F5N
M("A7:6YD;W=S+3$R-3$I`$MY<FEL;&EN96XO56MR86EN82`H2T])."U5*0!4
M<V5K:6X@=&%S879A;'1A`%!0`%#D:79I='3D:6X`1&%T851R964@4V5L86EN
M`%#D:7;D>7,`4.1I=N1MY.1RY"!V87-T86%N;W1E='1U`%#D:7;D;>3D<N1N
M('9A;&EN=&$`4.1I=N0`4&]?:7-T82!S87)A:V4`:F]U;'5K=74`1&5S:6UA
M86QI;G5M97)O=`!+:65L=.1Y='EI`%!I96YE;F[D('-I<V5N;GES=.0`3VQE
M='5S`$]L971U<W;D<FD`3VQE='5S<')O9FEI;&D`3VQE='5S;VEK975D970`
M3VQE='5S;VEK975D970`3>3D<FET96QMY'0`5F%L='5U=&$@=&5H=.1VY`!6
M86QT=75T971T=0!0;VES=&$`4&]I<W1A(')Y:&WD`%!O:7-T82!O:6ME=7,`
M5F]I('!O:7-T86$@=FEE<W1E:N0`4&]I<W1A('-O;'4`4&]I<W1A('-A<F%K
M90!0;VES=&$@;VQE;6%S<V%O;&5V870@=F%I:'1O96AT;VEN96X@;6%L;&D`
M4&]I<W1A("(E<R(Z;B!O:6ME=6MS:6$`3VQE=&MO('9A<FUA+"!E='3D(&AA
M;'5A="!P;VES=&%A("<E<R<@:F$@:V%I:VMI('-E;B!A;&EO:6ME=61E=#\`
M4&]I<W1A(')I=FD`4&]I<W1A('9A;&ET='4@<')O9FEI;&D`4&]I<W1A('9A
M;&ET='4@<V%R86ME`%!O:7-T82!V86QI='1U(')I=FD`3VQE=&MO('9A<FUA
M+"!E='3D(&AA;'5A="!P;VES=&%A('3D;>1N(&]I:V5U9&5N(&IA(&MA:6MK
M:2!S96X@86QI;VEK975D970_`%!O:7-T971T=2!PY&EV:71Y<W-K<FEP=&D@
M(B5S(BX`5&]I;6ET=7-A:6MA`%1A;G-K80!+:65L;.0@<'EY;G3V`$MI96QL
MY"!V87!A82]V87)A='1U('1I971O:F5N('!Y>6YT]@!/;F=E;&UA;B!K=79A
M=7,`2W5V875S`%1A<FME;6UA="!T:65D;W0@*&SV>71Y=N1T(&UY]G,@2&]R
M9&4Z;B!L;VMI=&EE9&]S=&]S=&$I.@!487)K96UM870@=&EE9&]T(&]N('1A
M;&QE=&5T='4@>6QLY'!I9&]N(&OD<VET96QTY';D:W-I+@!+96AI='ES`$MO
M<W1E=7-P:7-T90!%9&5L;&ES96X@='5N;FEN(&MO<W1E=7-P:7-T93H@`$MO
M<W1E=7-P:7-T93H@`%-U=6YT82!V87-E;6UA;'1A(&]I:V5A;&QE`%-U=6YT
M82!O:6ME86QT82!V87-E;6UA;&QE`$AA:V5M:7-T;P!+Y'ETY"`R-"UT=6YN
M:6X@86EK865S:71Y<W3D+@!.Y&MY;>1N(&%S971U:W-E=`!%<VET>7-T87!A
M(&5N;G5S=&5E;&QE("A4048I`$5S:71Y<W1A<&$`4&5R:6QL96UE;F]I;&UO
M:71U<P!$:FEB;W5T:0!%:2!S86$@<&]I<W1A80#$;.0@:^1Y=.0@<W5O<F%A
M;B!M86EN=&5N86YC92YP:'`Z=.0`2F]S(&5N<VEM;>1I;F5N(')I=FD@<VES
MY&QTY.0@<V%R86MK96ED96X@;W1S:6MO="P@;FEI;B!V86QI='-E.@!$;VUI
M;FEK86%N:6YE;@!$;VUI;FEK86%N:6YE;B!T87-A=F%L=&$`5&%L;&5N;F$`
M5&%L;&5N;F$@)7,`5&%L;&5N;F$@;'5O='4@87-E='5S(%!(4"US:W)I<'1I
M;N0N`$%L87-V971O=F%L:6MK;P!(=75M965T`%/D:&OV<&]S=&EO<V]I=&4`
M5DE22$4`16-U861O<@!-=6]K:V%A`$UU;VMK86$@;W-I;W1A`$UU;VMK86$@
M<GEH;>3D`$UU;VMK86$@;VEK975T=&$`375O:VMA82!O:6ME=6MS:6$`375O
M:VMA82`E<SIN(&]I:V5U:W-I80!-=6]K:V%A(&%S971U:W-I83H`375O:VMA
M82`B)7,B.FX@;VEK975K<VEA`$UU;VMK86$@)R5S)SIN(&]I:V5U:W-I80!+
M;W5L=71U<P!%9WEP=&D`16P@4V%L=F%D;W(`16QE;65N='1I+BXN`$5M`%/D
M:&OV<&]S=&D`4^1H:_9P;W-T:6]S;VET90!3Y&AK]G!O<W1I;W-O:71T96ED
M96X@<&ETY.0@;VQL82!S86UA="X`4^1H:_9P;W-T:2!V87)M:7-T=6MS96QL
M80!(>6UI]G0`5'EH:N0@=FEE<W1I+@!4>6AJY"!V87-T875S+@!4>6AJY"!H
M86MU=&5R;6D`4V%L;&D@:W5V:65N(&QA:71T86UI;F5N(&MU=F%G86QL97)I
M87-T82!T96MS=&EN(&IO=6MK;V]N+@!,86ET82!PY.1L;&4@;VEK96%N('!A
M:6YI:VME96X@:V]N=&5K<W1I;65N=2X`4.3D='1Y>0!0Y.1T='EM:7-V=6]S
M:0!3=75R96YN82!E9&ET;W)I80!!;FYA(&MY<WEM>7,@:F]K82!K>7-Y=.3D
M;BP@:F]S('-A;&%S86YA<VD@:F]U9'5T86%N(&YO;&QA86UA86X@97-I;65R
M:VEK<VD@)VUI:^0@;VX@;&5M;6EK:VES:2!N:6UI/R<Z`$QA:71A(&MU=F$@
M55),('3D:.1N`$UE<FMI;G3V:N0Z("5D('EH=&5E;G/D+"`E9"!V;VEM87-S
M82P@)60@=75S:6$L("5D(&UU=71T=6YE:71A+"`E9"!T=6YT96UA='1O;6EA
M`$5K=F%T;W)I86%L:6YE;B!'=6EN96$`17)I=')E80!6:7)H90!487!A:'1U
M:2!V:7)H92!LY&AE=&5T=.1E<W/D('1I971O82!S;6)P87-S=V0M;VAJ96QM
M86QL92X`5FER:&4@;.1H971E='3D97-SY"!V87-T875S=&$Z("5S+@!6:7)H
M92!SY&AK]G!O<W1I=FEE<W1I<W/D+@!6:7)H92!K:7)J;VET971T865S<V$@
M(B5S(BX`5FER:&4Z(`!%97-T:0!%=&EO<&EA`$5T;FEN96X`175R;V]P<&$`
M,34@;6EN=75T:6X@=N1L96EN`#(@;6EN=75T:6X@=N1L96EN`#,P('-E:W5N
M;FEN(';D;&5I;@`U(&UI;G5U=&EN(';D;&5I;@!*;VMA:7-E;&QA('-I<^3D
M;FMI<FIA=71U;6ES96QL80!0=6]L96X@='5N;FEN(';D;&5I;@!-:6YU=71I
M;B!VY&QE:6X`17-I;65R:VMI87)V;W0Z`%-U;W)I=&$`4W5O<FET971A86XZ
M`$QA86IE;FYA`$QA86IE;FYA('-I=G5V86QI:VMO`$]D;W1E='1I:6X@;65R
M:VMIY"`G*2<`4V%N82!S96QL86ES96YA86X@=&%I(&AA:W5T97)M:2!L86EN
M875S;65R:V5I<W/D`$QO<'!U<.1I=N1MY.1RY`!%>'!O;F5N='1I`%!U<F5T
M86%N("5S.G-TY"XN+@!&1R!VY')I`$%S971U<W1I961O<W1O:F5N('1U;VYT
M:2!&5%`Z;&SD`$%S971U<W1E;B!H86MU(&5PY&]N;FES='5I+@!9:'1E>7,@
M3$1!4"UP86QV96QI;65E;B!E<.1O;FYI<W1U:2X`66AT97ES(%--0BUP86QV
M96QI;65E;B!E<.1O;FYI<W1U:2X`2V]P:6]I;G1I("(E<R(Z;'3D(&5PY&]N
M;FES='5I+@!+;W!I;VEN=&D@(B5S(CIL;&4@97#D;VYN:7-T=6DN`%5U9&5N
M(%-!4TPM>6AT97ED96X@;'5O;6EN96X@97#D;VYN:7-T=6DN`%-I:7)T;R`B
M)7,B.N3D;B!E<.1O;FYI<W1U:2X`5F%N:&$@<V%L87-A;F$@;VX@=N3D<N0N
M`%-A;&%S86YA;B!V86EH=&\@97#D;VYN:7-T=6D@)7,Z("5S`$MA=6YI<P!&
M86QK;&%N9&EN('-A87)E="`H36%L=FEN87,I`$;D<B!S86%R970`5F%K879A
M('9I<FAE.@!&86MS:0!H96QM:6MU=0!4=6YT=74@:W5I;@!4=6YT=74@:W5I
M;CH@`$UU=71A;6EA('-A=&5I=&$`375U=&%M:6$@;'5M:7-A=&5I=&$`2V5N
M='3D;6%T<FEI<VD`1FED>FD`5&EE9&]S=&]J96X@;'5K=6WDY'+D.B`E<R!T
M:65D;W-T;P!4:65D;W-T;VIE;B!L=6MU;>3D<N0Z("5S('1I961O<W1O80!4
M:65D;W-T;VAA;&QI;G1A`%1I961O<W1O;B!N:6UI`%1I961O<W1O;B!V86QI
M;G1A`%1I961O<W1O;B!T=6]N=&D`5&EE9&]S=&]J96X@='5O;G1I(&5I(&]L
M92!KY'ET971TY'9I<W/D+@!3=6]D871T:6UE=`!3=6]M:0!%;G-I;6WD:6YE
M;B!P=6]L:7-K;P!%;G-I;6WD:6YE;B!N96QJY&YN97,`2V]R:F%A('-U:&1E
M`$ODY&YNY"!Y;7#D<FD`2V5L;'5V80!3=6UU`$MA;G-I;W1A("5S(&5I(&]L
M92!O;&5M87-S82X`2VER:F%S:6UE;B!VY')I`%)U;VMA`%-E;&%I;6EL;&4L
M(&IO=&MA(&5I=N1T('1U92!K=79I80!%;FYU<W1E("A4048I`$5N;G5S=&5T
M=&%V870@=G5O<F]K875D970@*$AU;VUA871H86X@971TY"!E;FYU<W1U:W-E
M<W-A(&]N('1I961O="!S96OD('#D:79I<W3D(&5T=.0@]FES=.0L(&IO=&5N
M('-U=7)I(&WDY'+D('#D:79IY"!A:6AE=71T86$@;&EI86X@;&5V9>1N(&]S
M:6]N*0!5;F]H9&ET:V\@<V%L87-A;F%S:3\`3&]M86MK965T`$UI971E;&%U
M<V4`36EE=&5L875S965N('1Y>7!P:0!-:65T96QA=7-E970`36EE=&5L875S
M965T(#(`1F]O<G5M:70`575D96QL965N;VAJ875K<V5T`$SV>61E='1I:6X@
M;VAJ96QM870Z("5S`$SV>61E='1I:6X@:&%K96UI<W1O=#H`<&4`2V5H>6MS
M970`4F%N<VMA`%)A;G-K82P@365T<F]P;VQI`%9A<&%A+W9A<F%T='4@=&EE
M9&]T`%9A<&%A+W9A<F%T='4@=F%S=&%U<P!687!A82]V87)A='1U('!Y>6YT
M]@!687-T875S('9A<&%A+W9A<F%T='4@<'EY;G3V]FX`4F%N<VMA;B!'=7EA
M;F$`4F%N<VMA;B!0;VQY;F5S:6$`4F%N<VMA;B!E=&5LY&ES970@=&5R<FET
M;W)I;W0`3.1H971TY&KD`%-U=6YN87-T82``4&ED96UP:2!K=79A=7,Z`%3D
M>7-I:W5U`$MO:V\@;FEM:0!%<.1MY.1RY&EN96X`1V%B;VX`1V%L;&5R:6$L
M(&IO<W1A(&MU=F$@;W1E=&%A;@!'86QL97)I83H`1V%M8FEA`%1E92`E<R!A
M<V5T=6MS970`1V5N97)O:71U(&MO;V1I`$QU;V1A86X@<W1A='5S('1I971O
M:F$@;6]D=75L:6QL92`E<RXN+@!'96]R9VEA`%-A:W-A`$=E=&]P="!V:7)H
M93H@`$=H86YA`$=I8G)A;'1A<@!%='5N:6UI`$UE;F4`1_9D96P`1V]O9VQE
M(&AA:W4`2&%R;6%A<^1V>0!+<F5I:VMA`$MR96EK:V$@*$E33RTX.#4Y+3<I
M`$=R]FYL86YT:0!'<F5N861A`%)Y:&WD;B!Y;&SD<&ET;P!2>6AM:65N(&YI
M;65T(&5I=N1T('-A82!O;&QA('1Y:&IIY`!6:65R86EL:6IA;B!O:6ME=61E
M=`!2>6AMY'0`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!6
M:65R86EL:6IA;B!O:6ME=61E=`!6:65R86EL:6IA;B!O:6ME=61E=`!6:65R
M87-K:7)J80!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,
M07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!R
M:79I;B!V:6EM96ES=.0@<V]L=6$N`$A434Q!<F5A('!E;&MU<FEM86ES97-T
M:2!K:65L=.1Y='EY('!O:7-T86UA<W1A('9I:6UE:7-TY"!S87)A:V5T=&$@
M=&%U;'5K;W-T82X`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET
M>7D@<&]I<W1A;6%S=&$@=FEI;65I<W3D(')I=FGD('1A=6QU:V]S=&$N`$A4
M5%`@875T96YT:6MO:6YT:6$@96D@;/9Y='EN>70N`$AA:71I`$AA<V@M86QG
M;W)I=&UI`%5S=F$`3W1S86ME`$AE87)D(&IA($UC1&]N86QD('-A87)E=`!6
M;VEM86MA<R!U:VMO<VUY<G-K>0!(96)R96$@*$E33RTX.#4Y+3@M22D`2V]R
M:V5U<P!/:&IE`$%P=6$@961I=&]R:6X@:^1Y='3V]FX`3VAJ90!!<'5O:&IE
M;&UA+"!J;VQL82!V;VED86%N(&QU;V1A(&IA('EL;.1P:73DY"!KY.1N;O9K
M<VGD($AO<F1E<W-A(&IA('-I=.0*:^1Y='3D=FES<^0@;VAJ96QM:7-S82X*
M2F]H9&%N=&]N82!O:&IE;&UA;B!KY'ET=/;V;B!K86YN871T86$@;'5K96$@
M4D5!1$U%('1I961O<W1O('3D<W/D(&AA:V5M:7-T;W-S82X`4&%L;&]N<'5O
M;&ES:V\Z`%3D<W/D(&]N('1I961O<W1O;B!A;&MU;W-A.@!+;W)K96$`2&ES
M=&]R:6$@=&EE='5E:61E;B!N:6UE="!E:7;D="!S86$@;VQL82!T>6AJ:>0`
M2V]?=&D`4'EHY"!I<W1U:6X@*%9A=&EK86%N:6X@:V%U<'5N:VEV86QT:6\I
M`$MO=&D`2V]T:6]S;VET90!0=6AE;&EN*&MO=&DI`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92!KY.1N;O9K<V5N('1E:VEJY`!(;W)D92]+;VQA
M8CH@17#D:V5L<&]A("5S(%A-3"UD871A82!V:65S=&ES<^0@)7,`2&]R9&4O
M2V]L86(Z(%EK<VEKY.1N('9I97-T:2!E:2!V87-T86$@;V)J96MT:6$@)7,`
M2&]R9&4O2V]L86(Z(%EH=.1KY.1N(&]B:F5K=&EA("5S(&5I(&SV>71Y;GET
M('9I97-T:7-TY"`E<P!(;W)D92]+;VQA8CH@4&]I<W1E='1I:6X@)7,@(B5S
M(@!(;W)D92]+;VQA8CH@3VYN:7-T=6YE97-T:2!S>6YK<F]N;VET:6EN("5S
M("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F%A=&EO:V]N92!V86%T:6D@=&]I
M;6EA:W-E96X@)V1O;7AM;"<@4$A0+6QA86IE;FYU:W-E;@!(;W)D92]+;VQA
M8CH@16D@=F]I9&$@;'5O9&$@=75T=&$@6$U,+7!U=71A(&]B:F5K=&EL;&4@
M)7,`2&]R9&4O2V]L86(Z($5I('9O:71U('!O:7-T86$@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z($5I('9O:61A(&AA:V5A($U)344@240ZY"!O<VEO;&QE
M('1Y>7!P:>0@)7,`2&]R9&4O2V]L86(Z($5I('9O:2!S>6MR;VYO:61A("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2!V;VED82!S>6YK<F]N;VED82!J
M86MO:F$Z("5S`$AO<F1E+TMO;&%B.B!4=6YT96UA=&]N(&IA:V\@(B5S(@!6
M86%K87-U;W)A('/DY&YT]@!686%K87-U;W)A('3D>71E`%9A86MA<W5O<F$Z
M`$UI=&5N('1U;&ET('3D;FYE/R`H4F%P;W)T;VD@:VEI=&]S(2D`2W5I;FMA
M(&UO;G1A('-A<F%K971T82!H86QU870@>6AD:7-TY.0_`$ME;G1T:65N("AS
M87)A:VME:61E;BD@;'5K=6WDY'+D+@!+=6EN:V$@;6]N=&$@<FEV:>0@:&%L
M=6%T('EH9&ES=.3D/P!+;W-T975S`$MO<W1E=7,Z(`!(=6UO<FES=&ET`%5N
M:V%R:0!)34%0+7!O<W1I;&%A=&EK;VX@;'5O;G1I(&5PY&]N;FES='5I.B`E
M<P!)34%0+7!O<W1I;&%A=&EK;VX@<&]I<W1O(&5PY&]N;FES='5I.B`E<P!)
M34%0+7!O<W1I;&%A=&EK;VX@:VEI;G1I]FX@;'5O;G1I(&5PY&]N;FES='5I
M.B`E<P!)4"UO<V]I=&4`25`M;W-O:71E(&5I(&]L92!KY'ET971TY'9I<W/D
M+@!)4"UO<V]I=&4@96D@;VQE('-A;&QI='5N($-)1%(M8FQO:VEN('-I<^1L
M;.0`25`M<^3D;F[V<W3V;B!R:6MK;VUU<P!,7V%I=&$@<FEV:2!E;FYE;@!)
M<VQA;G1I`%9A:6X@:6MO;FET`$EK;VYI="`E<SIL;&4`26MO;FET(&IA('1E
M:W-T:0!0<F]F:6EL:6X@;FEM:3H`2F]S('-I=G4@96D@;N1Y(&MU;FYO;&QA
M+"!N:6EN(&%U:V%I<V4@)7,@97)I;&QI<V5S<^0@:6MK=6YA<W-A+@!*;W,@
M970@;N1E(&EK;VYE:71A(&OD>71TY&5S<^1S:2!);G1E<FYE="!%>'!L;W)E
M<B!S96QA:6YT82P@;FEI;B!S:6YU;B!P:73DY"!O='1A82!P;VES('#DY&QT
MY"!03D<@;.1P:6[D:WEV>7ES(')A<W1I='1A;6%L;&$@=.1MY"!L86%T:6MK
M;RX`2F]S(&[D970@=.1MY&X@=FEE<W1I;BP@;75T=&$@970@:W5V86$L(&YI
M:6X@='5O;6%A<VD@:W5V86$@96D@=F]I(&[D>71TY.0@:^1Y='3D;>1S<^1S
M:2!S96QA:6UE<W-A+@!+=79I96X@97-I:V%T<V5L=0!+=79A(%523`!+=79A
M(%523#H`2W5V82!G86QL97)I87-T80!+=79A(&=A;&QE<FEA<W1A.@!+=79A
M;B!V:65N=&D`2W5V870`5'5O;G1I+"!A<VME;"`E9`!4=6]T=2!K96YT=.0Z
M("5S`%1U;V1U="!K96YTY'0Z`%1E:V5I;&SD`$QA7VET82!R:79I(&KD;&ME
M96X`5N3D<N0@<V%L87-A;F$`5N3D<N0@=&]I;6EN=&]K;V]D:2!A;FYE='1U
M+@!+Y'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$@;VX@=N3D<FEN+@!6Y.1R
MY"!KY'ET=.1JY'1U;FYU<R!T86D@=F%I:'1O96AT;VEN96X@;W-O:71E+B!9
M<FETY"!U=61E<W1A86X@:F$@;W1A('EH=&5Y='3D('EL;.1P:71O;VX@:F]S
M('1A<G9I='-E="!L:7/DY"!A<'5A+@!,:7/DY"!S:7-E;FYY<W3D`$EN=&EA
M`%EK<VET=.1I<V5T(&OD>71TY&KD=`!);F1O;F5S:6$`26YF;P!);F9O<FUA
M871I;P!!;'5S=&5T86%N(&UO9'5U;&EA("5S+BXN(`!,86ET82!S7V%R86ME
M(&KD;&ME96X`3&%I=&$@:W5V80!,86ET82!T875L=6MK;P!,86ET82!W=W<M
M;&EN:VMI`$QA:71A(%]S87)A:V4@96YN96X`3&%I=&$@=75S:2!S87)A:V4@
M;GEK>6ES96X@:N1L:V5E;@!,86ET82!U=7-I('-A<F%K92!E;FYE;B!N>6MY
M:7-TY`!,86ET82!U=7-I(')I=FD@;GEK>6ES96X@:N1L:V5E;@!,86ET82!U
M=7-I(')I=FD@96YN96X@;GEK>6ES=.0`3&%I=&$@:V%P<&%L92!N>6MY:7-E
M;B!N;V1E;B!JY&QK965N`$QA:71A(&MA<'!A;&4@96YN96X@;GEK>6ES=.0@
M;F]D96$`3&%I=&$@=F%I:'1O96AT;VEN96X@;6%L;&D`06YN82!SY&AK]G!O
M<W1I;W-O:71E(&IO:&]N('5U<VD@<V%L87-A;F$@;.1H971E=.3D;CH`3&%I
M=&$@<V]L=2!JY&QK965N`$QA:71A('-O;'4@96YN96X`3&%I=&$@<V]L=2!J
MY&QK965N`$QA:71A('-A<F%K92!E;FYE;@!6;VD@;&%I='1A82!V:65S=&5J
MY`!,86ET82!K87!P86QE(&KD;&ME96X`3&%I=&$@:V%P<&%L92!E;FYE;@!,
M86ET82!R:79I(&5N;F5N`$QA:71A(')I=FD@:N1L:V5E;@!!;FYA('9A861I
M='1A=F$@=F%S=&%U<R!T=7)V86MY<WEM>6MS965N.@!,:6ETY"]-=6]K:V%A
M(&MU=FEA`$QI:73D+TUU;VMK86$@;&EN:VMIY`!3:6YU;&QA(&5I(&]L92!T
M87)P965K<VD@:W)E9&EI='1E:N0@;.1H971TY.1K<VD@=FEE<W1I;B!J86ME
M;'5L:7-T86QL92X`4FEI='3D;>1T=/9MY'-T:2!K<F5D:6ET=&5JY`!+;VMO
M;F%I<VQU:W4`2V]K;VYA:7-L=6MU;&ES=&$`5.1L;&4@:V]M<&]N96YT:6QL
M92!O;B!V86QI='1U(';DY'+D('1O:6UI;G1O+@!%<.1K96QP;R`@541(("A5
M<V5R($1A=&$@2&5A9&5R*2X`17#D:V5L<&\@;VAJ96QM82X`17#D:V5L<&\@
M8F%T8V@@240N`$SD:&5T971T:6EN(&5PY&ME;'!O82!T:65T;V$N`$5PY&ME
M;'!O('9A<W1A86YO='1A:F%N(&]S;VET92X`17#D:V5L<&\@=&EE9&]S=&]M
M=6]T;P!%<.1K96QP;R!L:7-E;G-S:6%V86EN+@!!;FYE='1U('!A:6MK871I
M971O(&]N(&5PY&ME;'!O+@!%<.1K96QP;R!M<V=?='EP92`N`$5PY&ME;'!O
M('1A:2!P=75T='5V82!A<&E?:60N`$5PY&ME;'!O('1A:2!P=75T='5V82!P
M87)A;65T<FDN`$5PY&ME;'9O="!O:6ME=61E="!Y;&5M;>1L;.0@=&%S;VQL
M82X`17#D:V5L<&\@<&%R=&YE<B!I9"X`17#D:V5L<&\@='5O=&5K;V]D:2X`
M17#D:V5L<&\@<')O=&]K;VQL82X`17#D:V5L<&\@=F%S=&%A;F]T=&%J83H@
M(B5S(@!%<.1K96QP;R!J86MO+6]B:F5K=&D`17#D:V5L<&\@;.1H9&5O<V]I
M=&4N`$5PY&ME;'!O82!U;FEC;V1E+71I971O82X`26YV96YT86%R:6\`27)A
M;BP@27-L86UI;&%I;F5N('1A<V%V86QT80!)<F%K`$ER;&%N=&D`36%N+7-A
M87)I`$5R:6QL:7-IY"!5:VMO<VUY<G-K>6KD`$ES<F%E;`!,:6EK:V5E;&QE
M;&%S:VEJ80!+=7)S:79O:71U`$ET86QI80!*86UA:6MA`'1A;6UI:W5U`$IA
M<&%N:0!*87!A;FD@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:6$`:&5I
M;N1K=74`:V5SY&MU=0!+97-K:73D`$ME<VMI=.0@:V5S:V5L;&4`2V5S:VET
MY"!TY'ES:6X`2V5S:VETY"!V87-E;6UA;&QE`$ME<VMI=.0@;VEK96%L;&4`
M2V%Z86MS=&%N`%/D:6QY=.0@86QK=7!E<N1I;F5N/P!+96YI80!!=71E;G1I
M:V]I;G1I(&5PY&]N;FES='5I($ME<F)E<F]S+7!A;'9E;&EM96QL92X`2V5R
M;F5L(&%L;VET=&5L:6IA=`!!=F%I;65N(&QU;VYT:0!!=F%I;65N('1U;FYI
M<W1E`$%V86EM96X@<&ET=75S`$%V86EM96X@='EY<'!I`$%V86EM96X@:^1Y
M='3V`$%V86EN(&]N(&IO(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L
M;&$`3&%P<V5T`$MI<FEB871I`$MO<F5A+"`@9&5M;VMR86%T=&EN96X@:V%N
M<V%N=&%S879A;'1A("A0;VAJ;VES+4MO<F5A*0!+;W)E82P@=&%S879A;'1A
M("A%=&5LY"U+;W)E82D`2V]R96$@*$550RU+4BD`2W5V86ET`$MI<F=I<W1A
M;@!!<U]E='1E;'4`2VEE;&D`3&%O+"!D96UO:W)A871T:6YE;B!K86YS86YT
M87-A=F%L=&$`2N1L:VEM;>1I;F5N('!U;VQI<VMO`$KD;&MI;6WD:6YE;B!N
M96QJY&YN97,`4.1I=FET971T>2!V:6EM96MS:3H`161E;&QI;F5N('-I<^3D
M;FMI<FIA=71U;6EN96XZ("5S`$5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI
M;F5N.B`E<RP@)7,`161E;&QI;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ($5I
M(&UI;&QO:6YK86%N`$QA='9I80!,86MI`$%S971T96QU`$KD=.0@='EH:N1K
M<VD@:F]S(&5I(')E=6YO:F$`3&EB86YO;@!687-E;@!687-E;B!O='-A:V4`
M5F%S96X@87)V;VIA`$QE<V]T;P!,:6)E<FEA`$QI8GEA($%R86(@2F%M86AI
M<FEY80!,:6-H=&5N<W1A:6X`2V5V>71TY"!RY&YTY.0`2VER:F%U9'4@<VES
MY.1N`$ME=GET=.0@<V%D971T82!A:6MA:7-I;@!+979Y='3D('-A9&5T=&$@
M;7GV:&5M;6EN`$ME=GEI=.0@<V%D96MU=7)O:F$`2V5V>71TY"!S861E='1A
M(&IA(&UY<G-K>6ES=.0`2V5V>71TY"!L=6UI<V%D971T80!+979Y:73D(&QU
M;6EK=75R;VIA`$QI;65R:6MI=`!,:6YK:VD`3&EN:VMI(&]S;VET=&%A.@!,
M:6YK:73D('/D:&OV<&]S=&EO<V]I=&4@:VER:F]I=&$@=75S:2!V:65S=&D@
M<VEV=6QL92!NY&MY;>1S<^0`3&EN:VET`$QI;G5X('!I<&%R96ET80!6;VD@
M;&ES=&%U:W-E<W-A(&[D:&3D(&MA;G-I;VX`3N1Y=.0@=&EE=&]K86YN870`
M3N1Y=.0@;VAJ96ED96X@86EH965T`$[D>73D('1A=6QU=`!,:7-T86XM07)K
M:7-T;P!,:7-T86XM3VAJ90!,:7-T86XM260`3&ES=&%N+4]M:7-T86IA`$QI
M<W1A+79I97-T:0!,:7-T86XM5&EL875S`$QI<W1A;BU4:6QA=6MS96XM;&]P
M971T86UI;F5N`$OD>71TY&KD=&EE=&]J96X@;N1Y='3D;6EN96X@;VX@97-T
M971T>2X`2VER:F%L;&ES=75S`$QI971T=6$`3&%D871A86X@:VER:F%S=&]J
M82XN+@!,861A=&%A;BXN+@!086EK86QL:7-T82!A:6MA83H@`$QO:V%L:7-A
M871I;R!J82!A:6MA`%!A:6MK80!+:7)J875D=2!S:7/DY&X`2VER:F%U9'4@
M=6QO<P!496ATY';D="!S:7/DY&YK:7)J875T=6UI<V5S<V$`4VESY.1N:VER
M:F%U='5M:7-E<VD@97#D;VYN:7-T=6DN(%1O9&5N;N1K]FES97-T:2!K:7)J
M;VET:70@=N3D<FEN(&OD>71TY&KD='5N;G5K<V5S:2!T86D@<V%L87-A;F%S
M:2X`4VESY.1N:VER:F%U='5M:6YE;B!E<.1O;FYI<W1U:2X`4&ET:^0@=&5K
M<W1I`%)A:VMA=7,`36%T86QA`%!I96YE="!K<F5I:VMA;&%I<V5T(&MI<FIA
M:6UE=`!0:65N970@;&%T:6YA;&%I<V5T(&MI<FIA:6UE=`!0:65N970@<F]O
M;6%L86ES970@;G5M97)O=`!,=7AE;F)U<F<`2TL`34]41`!-4RU43D5&(&QI
M:71E=&EE9&]S=&\@;VQI('1Y:&KD+@!624535$D`36%C86\`36%K961O;FEA
M+"!%;G1I;F5N($IU9V]S;&%V:6%N('1A<V%V86QL86XN`$UA9&%G87-K87(`
M5&%I:W5U<P!3Y&AK]G!O<W1I`%!O<W1I;B!Y;&SD<&ET;P!4964@;&EN:U]K
M:2XN+@!487)K:7-T82!E='3D('-I;G5L;&$@;VX@4$5!4B!A<V5N;F5T='5J
M82!J82!S92!L]GET>7D@<&]L=7-T87-I+@!496ADY.1N(&AA:V5M:7-T;V$@
M)7,`36%L879I`$UA;&5S:6$`36%L961I:79I=`!0;W-T:0!-86QT80!6;VET
M(&AA;&QI;FYO:61A(&QI<W1A82!K871E9V]R:6]I<W1A+"!J;VED96X@879U
M;&QA('9O:70@;&EI='3DY"!A<VEO:71A('EH=&5E;B!S86UO:F5N(&]T<V%K
M:V5I9&5N(&%L;&4@:F$@;&EI='3DY"!N:6EH:6X@=N1R96KD+@!-87`R-"!K
M87)T=&$`36%P475E<W0@:V%R='1A`&UA86QI<VMU=0!-87)G:6YA86QI`%9O
M:2!M97)K:73D(%9A;FAA+U5U<VD@=&EE=&]J80!6;VD@;65R:VETY"!V:65S
M=&5JY"`H97-I;2X@5.1R:V7D+U9A<W1A='1U*0!-87)S:&%L;"!S86%R970`
M36%R=&EN:7%U90!4Y'-MY.1VY'0@:V5N=.1T`$UA=7)I=&%N:6$`36%U<FET
M:75S`%-U=7)I;B!S86QL:71T>2!K<F5D:6ET=&DN`%-U=7)I;B!S86QL:71T
M=2!V:65S=&EO<VEO;>3D<N0@>6QI=&5T='DN`$5D96QL:7-E;B`R-"!T=6YN
M:6X@:V]R:V5I;B!LY&UP]G1I;&$Z(`!%9&5L;&ES96X@-B!T=6YN:6X@:V]R
M:V5I;B!LY&UP]G1I;&$Z(`!3=75R:6X@<V%L;&ET='4@<&ET=75S`'1O=6MO
M:W5U`$UA>6]N971T90!,Y.1K971I961E`%1A<&%A;6ES96X@<&5R=75T=7,`
M5&%P86%M:7-E;B!T:65D;W0`5&%P86%M:7-E:&1O='5S`%9A<W1A=7,@=&%P
M86%M:7-E96X`5&%P86%M:7-E;B!PY&EV:71Y<P!487!A86UI<V5N('#D:79I
M='ES<'EY;G3V`$KD<V5N970`365N=6X@;75O=&\Z`%EH9&ES=.0@<V]L=70`
M66AD:7-T973DY&X@:V%I:VMI("5S+G!O('1I961O<W1O="!K;VUP96YD:6EN
M+BXN(`!9:&1I<W1E=.3D;B!L;VMA;&ES;VEN=&EA("5S+BXN(`!9:&1I<W1E
M=.3D;B!03RUT:65D;W-T;V$@)7,@:V]M<&5N9&EI;BXN+B``66AD:7-T973D
MY&X@:^3D;F[V<W3D(&UO9'5U;&EL;&4@)7,N+BX`5FEE<W1I`%9I97-T:6X@
M=&%R:VES='5S(&]N;FES='5I+"!M=71T82!A;&QE:VER:F]I='1A:F%N('9A
M<FUE;FYE='1A(&5I('9O:71U('1A<FMI<W1A82X`5FEE<W1I('9A;FAE;FDN
M`%9I97-T:6X@='EY<'!I`$UE=&%R('/DY`!-971A<BUO<VEO(&5I(&]L92!K
MY'ET971TY'9I<W/D+@!-971A<BUO<VEO(&5I(&]L92!KY'ET971TY'9I<W/D
M+B!487)K96UM870@=&EE9&]T(&]N('1A;&QE=&5T='4@>6QLY'!I9&]N(&OD
M<VET96QTY';D:W-I+@!-971A<D1"(&5I(&]L92!Y:&1I<W1E='1Y+@!-971O
M9&D`365T;V1I82`B)7,B(&5I(&]L92!MY.1R:71E;'1Y`$UE=')I;F5N`$UE
M:W-I:V\`36EK<F]N97-I82P@66AD:7-T>6YE970@=F%L=&EO=`!+97-K96QL
MY`!-:6UE+71Y>7!P:0!%9&5L;&ES96X@,C0@='5N;FEN(&UA=&%L:6X@;.1M
M</9T:6QA.B``161E;&QI<V5N(#8@='5N;FEN(&UA=&%L:6X@;.1M</9T:6QA
M.B``4V%L87-A;F%N('9A:6AT86UI<V5N97-T;V%I:V$@96D@;VQE('9I96SD
M(&MU;'5N=70@=6UP965N`%!E:6QI:W5V80!396MA;&%I<V5T`%!%05(M<&%K
M971T:2!(5%107U)E<75E<W0@<'5U='1U=2X`4'5U='1U=F%T(&%S971U<W1I
M961O<W1O+B!3:6YU;B!P:73DY"!T96ADY"!A<V5T=7-T:65D;W-T;R!J;W,@
M:&%L=6%T(&OD>71TY.0@=.1TY"!O:&IE;&UA82X`4'5U='1U=F$@;65S<V%G
M92!)1"X`5N1L='3D;>1T]FX@4$5!4BUP86ME='1I($UA:6P@<'5U='1U=2X`
M4'5U='1U=F$@<V5S<VEO;B!)1"X`;6$`36]B:6EL:7/D:&OV<&]S=&D`2V]H
M=&%L86EN96X`375O:VMA=6MS96X@<.1I=N1MY.1RY`!-=6]K:V%A(%523#II
M80!-;V1U=6QI`$ME<G)O:6X`36]L9&]V82P@=&%S879A;'1A`$UO;F%C;P!-
M;VYG;VQI80!K=75K875S:2!J82!V=6]S:0!+=75K875S:71T86EN`$UO;G1S
M97)R870`2W5U;B!V86EH965T`$UA<F]K:V\`4W5U<FEM;6%K<VD@;W-A:W-I
M('-E;&MEY.0`4W5U<FEM;6%K<VD@;W-A:W-I('!I;'9I<W3D`%-U=7)I;6UA
M:W-I(&]S86MS:2!A=7)I;FMO:7-T80!3:6ER<N0@86QA<W#D:6X`4VEI<G+D
M('9A<V5M;6%L;&4`4VEI<G+D(&]I:V5A;&QE`%-I:7)RY"!Y;/9S<.1I;@!3
M:6ER<N0@86QA<W#D:6X`4VEI<G+D('EL]G-PY&EN`$UO<V%M8FEK`$UO;FET
M87-O:6YE;B!A;&%S=F5T;W9A;&EK:V\`36]N:79A;&EN=&$`2^1Y='3D:N1T
M=6YN=6MS96YI`%!O<G1A86QI;FD`4&]R=&%A;&EN:2!A<V5T=&5L=0!->6%N
M;6%R("A"=7)M82D`14DL($5.('-U;W-T=0!.:6UI`$YA;6EB:6$`3F%U<G4`
M5F%A=&EI('1O:6UE;G!I9&5T=.0`3F5P86QI`$%L86YK;VUA870`06QA;FMO
M;6%I9&5N($%N=&EL;&ET`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!
M(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A
M<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@4U-,+7!A;'9E;&EM96X@;W-O:71E`$YE='-C87!E('9A<FUE;G1E96X@
M:V]M;65N='1I`$YE='-C87!E('9A<FUE;G1E96X@='EY<'!I`%9E<FMK;P!%
M:2!K;W-K86%N`%5U<VDM2V%L961O;FEA`%5U<VD@;'5O:VET=7,`575S:6MU
M=0!5=7-I(&OD>71TY&KD='5N;G5S("AV87!A865H=&]I;F5N*0!5=7-I+5-E
M96QA;G1I`%5U<VD@<V%L87-A;F$Z`%5U<VD@:6MK=6YA("A?8FQA;FLI`%5U
M=&ES970`2V5S:W5S=&5L=7)Y:&WD=`!3975R86%V80!3975R86%V870@-"!V
M86EH971T82X`4V5U<F%A=F%T(&%S971U:W-E=`!3975R86%V83X`3FEC87)A
M9W5A`$YI9V5R`$YI9V5R:6$`6?8`3FEU90!%:0!!<V5T=7-T:65T;VIA(&5I
M(&]L92!S86%T879I;&QA+"!J;W-T82!V;VES:2!NY'ET=.3D(&5R;V%V86ES
M=75K<VEA+@!%:2!O;&4@<V%A=&%V:6QL82!S=75N;FET96QM86$@25-/(&QE
M=GEK=79A=&EE9&]S=&]J96X@=&5K96UI<V5K<VDN`$5I(&5RY&UA;&QI82X`
M3W-I;W1A(&5I(&]L92!P>7ED971Y<W/D('!A:6MA<W-A+@!+86QE;G1E<FEN
M(&YI;67D(&5I(&]L92!A;FYE='1U($U#04PM875T96YT:6MO:6YN:6QL92X`
M16D@;75U=&]S=&$N`$%L96UP:6$@;VEK975K<VEA(&5I('9O:2!L:7/D=.0@
M=.1MY&X@=&%S;VX@86QA<'5O;&5L;&4N`$%L:71A<V]J82!E:2!V;VD@;&ES
MY'3D('3D;&QE(&]I:V5U9&5L;&4N`$5I(&%N;F5T='4@:V]M96YT;V$N`$%S
M971U:W-I82!E:2!L]GET>6YY="`E<SIL;&4N`$%S971U:W-I82!E:2!L]GET
M>6YY="!&5%`@5D93.FQL92X`07-E='5K<VEA(&5I(&SV>71Y;GET(%-13"!6
M1E,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@4U%,+49I;&4@5D93.FQL
M92X`2W)E9&EI=&ET(&QO<'!U+@!+;VAD971T82!E:2!A;FYE='1U+@!/<VEO
M=&$@:60Z;&SD("(E<R(@96D@;VQE(&]L96UA<W-A(&%L:W5P97+D:7-E<W/D
M(&]H:F5T:65D;W-T;W-S82X`16D@='5O='4@86EN=71T86MA86X@=&EE9&]S
M=&]A`$EK;VYE:71A(&5I(&SV>71Y;GET+@!,;VMA;&ES;VEN=&EA(&5I(&WD
MY')I=&5L='DN`%!A:6MK86$@96D@;VQE(&%S971E='1U+@!086EK:V%T:65T
M;V$@96D@;VQE(&%N;F5T='4N`$5I(&%N;F5T='4@=FEE<W1IY"X`3FEM9>0@
M96D@;VQL=70@86YN971T=2X`3'5K=6WDY'+DY"!E:2!O;&QU="!A;FYE='1U
M+@!%:2!L;W5K:V%A=F%T(&UI971E;&%U<V5E=`!386QA<V%N86$@96D@;VQE
M(&%N;F5T='4@2%144"UA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@
M;VQE(&%N;F5T='4@24U!4"UA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@
M96D@;VQE(&%N;F5T='4@2V5R8F5R;W,M875T96YT:6MO:6YN:7-S82X`4V%L
M87-A;F%A(&5I(&]L92!A;FYE='1U($Q$05`M875T96YT:6MO:6YN:7-S82X`
M4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($QO9VEN+6%U=&5N=&EK;VEN;FES
M<V$N`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!005-35T0M875T96YT:6MO
M:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L92!A;FYE='1U(%--0BUA=71E;G1I
M:V]I;FYI<W-A+@!0;VQK=6$@3W!E;E-33"!K;VUE;G1O;VX@96D@;VQE(&WD
MY')I=&5L='DN($]P96Y34TP@<&ETY.0@;VQL82!KY'ET971TY'9I<W/D(&IO
M<R!KY'-I=&5L;.3D;B!02T-3(#$R(&1A=&%A+@!%:2!S:7/DY&YK:7)J875T
M=6UI<W!Y>6YT]FKD(&IO;F]S<V$N`$5I('/DY&YT]FKD`$5I(')E=6YO:F$`
M5&%U<W1A:N1R:F5S=&5L;>3D("(E<R(@96D@;/9Y='EN>70N`%;D;&EM=6ES
M=&EL;&4@96D@;VQE(';D;&EA:6MA:7-H86ME;6ES=&]A+@!+Y'ET=.1JY'1U
M;FYU<W1A('1A:2!S86QA<V%N86$@96D@;.1H971E='1Y+@!+86EK:VD@<&%L
M875T=6YU="!834PM9&%T82!O;&D@97#D:V5L<&]A`$5I(&%R=F]J80!697)S
M:6]T:65T;VIA(&5I(&SV>71Y;GET(&%L:W5P97+D:7-I=.0@87-E='5K<VES
M=&$N(%-I;G5N('!I=.3D('1E:&3D(&%S971U:W-E="!U=61E<W1A86XN`%9E
M<G-I;W1I971O:F$@96D@;/9Y='EN>70@87-E='5K<VES=&$N(%-I;G5N('!I
M=.3D('1E:&3D(&%S971U:W-E="!U=61E<W1A86XN`$5I(&]S86QL:7-T=6IA
M`$5I(&UI=.3D;@!%:2!M:73DY&X@*$OD>73D(&EM<&QI<VEI='1I<W3D*0!,
M87!P:2]0;VAJ;VES;6%A="]%<VMI;6\@*$E33RTX.#4Y+3$P*0!.;W)F;VQK
M('-A87)E=`!0;VAJ;VEN96X@<&%L;&]N<'5O;&ES:V\`4&]H:F]I<V5T($UA
M<FEA86YI96X@<V%A<F5T`$YO<FIA`$5I(&KD;&ME96X`16D@96YN96X`16D@
M;VQE(&AA:V5M:7-T;P!%:2!O;&4@=&]T975T971T=2X`16D@87-E=&5T='4`
M16D@='5E='1U+@!-=6ES=&EI;G!A;F]T`$5I(&UI=.3D;B!S96QA='1A=F%A
M+"!P86QA82!T86MA:7-I;BX`26QM;VET=7,`;6%R<F%S:W5U`$QU:W5MY.1R
MY`!-97)K:VEE;B!L=6MU;>3D<N0`4V%R86MK86ED96X@;'5K=6WDY'+D`%)I
M=FEE;B!L=6MU;>3D<N0`2F%K96QU;&ES=&%N(&YU;65R;VET82!E:2!O;&4@
M;>3D<FET96QT>2!PY&EV:71E='3D=N1K<VDN`$]+`$]B:F5K=&D`3V)J96MT
M:6X@;'5O:F$`3V)J96MT:6X@=&5K:6KD;B!O:6ME=61E=`!/:W1A86QI`&QO
M:V%K=74`3&]U:VMA879U=7-S=6]D871I;@!4;VEM:7-T;P!686YH82!S86QA
M<V%N83H`3VUA;@!686EN($E-05`M<&%L=F5L:6UE="!T=6ME=F%T(&IA971T
M=6IA(&MA;G-I;VET82X`5F%I;B!L;W5K:V%A=F%T(&UI971E;&%U<V5E=`!6
M;VET(&QA:71T86$@=F%I;B!Y:&1E;B!SY&AK]G!O<W1I;W-O:71T965N+@!6
M86EN(&]M:7-T86IA('1A:2!JY')J97-T96QMY&X@>6QLY'!I=.1JY"!V;VD@
M;75U='1A82!J86MO:F5N(&]M:7-T86II82!T86D@;VEK975K<VEA`$%V86$@
M=75D97-S82!I:VMU;F%S<V$`3W!E;E-33"!V:7)H93H@5&EE=&]J82!E:2!S
M86%T=2!E<VEL;&4@86QL96MI<FIO:71E='5S=&$@4R]-24U%+6]S87-T82X`
M079A82!TY&WD;B!L:6YK:6X@=75D97-S82!I:VMU;F%S<V$`2^1Y='3V:N1R
M:F5S=&5L;>0`36%H9&]L;&EN96X@;W-A;&QI<W1U:F$`07-E='5K<V5T`$%S
M971U:W-E="`E<SIL;&4`07-E='5K<V5T.@!*Y')J97-T971T>2!L:7-T80!/
M<F=A;FES86%T:6\`3W)G86YI<V%A=&EO>6MS:6MK]@!/<F=A;FES;VEN=&D`
M06QK=7!E<N1I;F5N(&]H:F5L;6%N(&UA;&QI`$%L:W5P97+D:7-E="!M86QL
M:70@)7,Z<W/D.@!-=74`375U="!T:65D;W0`3VUI<W1A:F%N(&]I:V5U9&5T
M`%!!32UA=71E;G1I:V]I;G1I82!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`1&EG
M:71A86QI;F5N(%!'4"UA;&QE:VER:F]I='5S`%!'4"US86QA='1U82!T:65T
M;V$`2G5L:VEN96X@4$=0+6%V86EN`%!'4"UA;&QE:VER:F]I=&5T='5A(&IA
M('-A;&%T='5A('1I971O80!02%`M:V]O9&D`4$A0+6MO;65N=&]T=6QK:VD`
M4$T@:V5V>71TY"!S861E='1A`%!-(&MU=7)O:F$`4$T@;'5M:0!032!L=6UI
M<V%T96ET80!032!!=7)I;FMO:7-T80!032!U:VMO<VUY<G-K>6KD`%!?2%`M
M:V]M96YT;W1U;&MK:0!4Y'ET90!086MI<W1A;@!086QA=0!086QE<W1I:6YA
M("AM:65H:71E='1Y(&%L=64I`%!A;F%M80!087!U82!5=7-I+4=U:6YE80!0
M87)A9W5A>0!/<VET=&%I;B!P:6QV:7-TY`!087-S=V]R9"UO:&IE;&UI<W1O
M(&5I(&]L92!A<V5N;F5T='4@;VEK96EN+@!386QA<V%N80!386QA<V%N82!V
M86EH9&5T='4@)7,N`%;DY'+D('-A;&%S86YA`%!A<W-W;W)D+6UO9'5U;&D@
M96D@;/9Y9.0@86YN971T=6$@:V]M96YT;V$N`%!A<W-W;W)D+6UO9'5U;&EL
M=&$@<'5U='1U=2!T87)V:71T879I82!P87)A;65T<F5JY"X`4&%S<W=O<F0M
M;6]D=75L:6QL92!E:2!O;&4@;>3D<FET96QT>2!T87)G970@<&%R86UE=')I
M82X`4&%S<W=O<F0M;6]D=75L:2!E:2!O;&4@87-E;FYE='1U(&]I:V5I;@!0
M87-S=V]R9"UM;V1U=6QI(&5I(&]L92!A<V5N;F5T='4@;VEK96EN+@!386QA
M<V%N86$@=&%R=FET86%N(%)!1$E54RUA=71E;G1I:V]I;G1I:6XN`%-A;&%S
M86YA('9A<FUI<W1U:W-E;&QA`%-A;&%S86YA.@!386QA<V%N83H@`%-A;&%S
M86YO:F5N('!I=.3D(&]L;&$@<V%M870N`$QI:73D`$QI:73D(&QE:6ME</9Y
M9.1L=.0`4&]L:W4`2F]N;W-S82!O;&5V870@<VESY.1N:VER:F%U='5M:7-P
M>7EN;O9T.@!):&UI<V5T`%!R;W-E;G1T:0!3=6]R:71A('EL;.1P:71O=&]I
M;65N<&ET965T`%-U;W)I=&$@>6QLY'!I=&]T;VEM96YP:71E970@<VESY.1N
M:VER:F%U='5M:7-E;B!Y:'1E>61E<W/D+@!/:6ME=7,`3VEK975T=&$@(B5S
M(B!E:2!P;VES=&5T='4N`$]I:V5U:W-I96X@>6QLY'!I=&\`3VEK975K<VEA
M`$]M870@=&EE9&]T`%!E<G4`3&5M;6EK:70`1FEL:7!P:6EN:70`4'5H96QI
M;@!686QO:W5V870`4&ET8V%I<FX`4&EK<V5L:0!+;&ES965T`$YA<'-A=71A
M(&IO=&%I;B!S;VQU80!687)M:7-T82!E='3D(&AA;'5A="!P;VES=&%A('3D
M;>1N(&5L96UE;G1I;CH`5F%R;6ES=&$@971TY"!H86QU870@<&]I<W1A82!L
M:6YK:71Y:W-E;B!TY&CD;B!E;&5M96YT=&EI;BX`06YN82!K=75K875S:2!J
M82!V=6]S:2X`06YN82!N:6UI('5U9&5L;&4@;'5O:VET=6MS96QL93H`06YN
M82!O:6ME82!)4"UO<V]I=&4N`$%N;F$@;VEK96$@<.1I=N1MY.1RY#L@5&%R
M:VES=&$@<.1I=FEE;B!L=6MU;>3D<N0@:W5U:V%U9&5S<V$N`$%N;F$@86EK
M82!O:6ME87-S82!M=6]D;W-S82X`4VEN=6X@=.1Y='EY(&%N=&%A('5U<VD@
M<V%L87-A;F%S:0!!;FYA(&QY:'ET(&MU=F%U<R!O;F=E;&UA<W1A+@!3:6YU
M;B!TY'ET>7D@86YT86$@;GEK>6EN96X@<V%L87-A;F%S:0!!;FYA(&OD>71T
MY&KD='5N;G5K<V5S:2!J82!S86QA<V%N87-I`$QU92!S975R86%V82!T96MS
M=&DN(%-I;G5N(%!)5,3$('-U;W-T=6$@:^1Y='3V96AT;VEH:6X@=F]I9&%K
M<V5S:2!KY'ET=.3D(&KD<FIE<W1E;&WDY"X`4F%P;W)T;VD@=FER:&5I<W3D
M(&]S;VET=&5E<V5E;B!I,3AN0&QI<W1S+FAO<F1E+F]R9RX`5&%R:VES=&$@
M<V5U<F%A=F%T('1I961O="!J82!V86QI='-E('-E;B!JY&QK965N('1O:6UI
M;G1O(&%L;&%O;&5V87-T82!V86QI:V]S=&$N`%9A;&ET<V4@=&]I;6EN=&\@
M86QL86]L979A<W1A('9A;&EK;W-T82X`06YN82!N:6UI('5U9&5L;&4@;'5O
M:VET=6MS96QL93H`4VEN=6X@=.1Y='EY('9A:'9I<W1A82!U=7-I('-A;&%S
M86YA<VD`4'5O;&$`4&]L:71I:6MK80!+>7-E;'ET`%!O<G1U9V%L:0!4Y&WD
M;B!K=79A;B!P86EK:V$`5.1MY&X@=&%U;'5K;VX@<&%I:VMA`%9O:2!LY&AE
M='3DY"!V:65S=&5JY"!K86YS:6]O;B`H96D@:V]S:V4@24U!4"!Y:'1E>6MS
M:>0I`%-A9&5MY.1RY"!E9&5L;&ES:6QL92`E<R!T=6YN:6QL93H@`%!R969S
M7VQD87`Z(%1A<G9I='1A=F%A($Q$05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN
M>70N`%!R969S7W-E<W-I;VXZ(%1A<G9I='1A=F%A('-E<W-I;VXM;&%A:F5N
M;G5S=&$@96D@;/9Y='EN>70`26QM86YP86EN90!);&UA;G!A:6YE(&UE<F5N
M<&EN;F%S<V$Z(`!);&UA;G!A:6YE.B``17-I:V%T<V5L=0!%<VEK871S96QE
M(&MU=F$@=75D97-S82!I:VMU;F%S<V$`161E;&QI<V5T(&%S971U:W-E=`!4
M=6QO<W1A(&1O:W5M96YT=&D`4V%L86EN96X@879A:6X`3VYG96QM80!/;F=E
M;&UA;B!K=79A=7,`4')O:F5K=&ET`$ME:&]T=&5E;B!T96MS=&D`2G5L:VEN
M96X@879A:6X`2G5L:VES96X@879A:6UE;B!A;&=O<FET;6D`2G5L:VES96X@
M879A:6UE;B!T:65D;W0`2G5L:VES96XO<V%L86ES96X@879A:6YP87)I;B!L
M=6]N=&D@97#D;VYN:7-T=6DN`%!U97)T;R!2:6-O`%%A=&%R`$MY<V5L90!2
M4T$@2G5L:VEN96X@879A:6X@*"5D(&)I='1IY"D`4F%D:6]P86EN:6ME`%-A
M9&4`4V%D971T82!A:6MA:7-I;@!3861E='1A(&UY]FAE;6UI;@!3861E:W5U
M<F\`5F5S:2!J82!L=6UI`%9E9&5S=.0@;'5M965N`%-A='5N;F%I;F5N(&UI
M971E;&%U<V4`4W5H9&4`3'5K=0!6;VD@;'5K96$@=FEE<W1E:N0`4&]I<W1E
M=&%A;FMO("5S/R!4Y'3D('1O:6UI;G1O82!E:2!V;VD@<&5R=75T=&%A+@!0
M;VES=&5T86%N:V\@=&EE9&]T(&OD>71TY&KD<W3D("5S/R!4Y'3D('1O:6UI
M;G1O82!E:2!V;VD@<&5R=75T=&%A+@!4964@;75U=&]K<V5T('5U9&5S=&%A
M;@!0Y&EV:73D(&1Y;F%A;6ES970@=F%L:6MK;V5L96UE;G1I=#H`4.1I=FET
MY"!P;W)T86%L:6[D:WEMY.0Z`%/DY&YN]FQL:6YE;B!L875S96ME`%)E86QA
M871I;W-E;&%I;@!-=6ES=&EI;G!A;F]T`$UU:7-T82!V87!A82]V87)A='1U
M('1I961O="X`173D<&%L=F5L:6UE=`!%=.1P86QV96QU;B!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!0;VES=&$`4&]I<W1A(&]S:6\`
M4&]I<W1A('-A<F%K90!0;VES=&$@;75O=&]I;'4`4&]I<W1A(&MA;&5N=&5R
M:7-T86YI`%!O:7-T82!P87)I`%!O:7-T82!T86QL971E='1U('-K<FEP=&D@
M<&%L=F5L:6UE;B!VY&QI86EK86ES:&%K96UI<W1O<W1A+@!0;VES=&$`4&]I
M<W1A('3D;>0@;F]O9&D@9&]K=6UE;G1I<W1A`%!O:7-T82!KY'ET=.1JY`!0
M;VES=&$@:^1Y='3D:N0Z("5S`%9A<W1A=7,@;.1H971E='1Y+@!,Y&AE=.0@
M=F%S=&%U<W9I97-T:2!E:2UT=65T=7-S82!M=6]D;W-S82X`3.1H973D('9A
M<W1A=6MS96YA('9A<&%A+W9A<F%T='4@=&EE9&]T('-E=7)A879A;&QE(&MA
M:&1E;&QE(&MU=6MA=61E;&QE+@!,Y&AE=.0@=F%S=&%U:W-E;F$@<'EY9&5T
M>70@=F%P86$O=F%R871T=2!T:65D;W0N`%9A<W1A=7,Z("5S`%!Y>6YT]O9N
M(&5I('9O:71U('9A<W1A=&$N(%9I<FAE:V]O9&DZ(`!0>7ED971T>>0@<&%L
M=F5L=6$@96D@;/9Y='EN>70N`%1A<G9I='1A=F%A("(E<R(M=&EE=&]A(&5I
M(&]L;'5T(&WDY')I=&5L='D@)7,@87-E='5K<VES<V$N`%1A<G9I='1A=F%A
M("(E<R(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@5D93(&%S971U:W-I
M<W-A+@!487)V:71T879A82`B)7,B+71I971O82!E:2!O;&QU="!MY.1R:71E
M;'1Y(&%S971U:W-I<W-A+@!487)V:71T879A82`G9')I=F5R<R<M87-E='5S
M=&$@96D@;VQL=70@;>3D<FET96QT>2!#;VUP;W-I=&4M87-E='5K<VES<V$N
M`%1A<G9I='1A=F%A("=P:'!T>7!E)RUA<V5T=7-T82!E:2!O;&QU="!MY.1R
M:71E;'1Y(%!A<W-W9"!344PM87-E='5K<VES<V$N`%1A<G9I='1A=F%A("=P
M:'!T>7!E)RUA<V5T=7-T82!E:2!O;&QU="!MY.1R:71E;'1Y(%-13"UA<V5T
M=6MS:7-S82X`4&%K;VQL:6YE;B!K96YT=.0`4&%K;VQL:6YE;B!O<V%L;&ES
M='5J80!4>6AJ96YNY`!4>6AJ96YNY"!S86QA<V%N80!4>6AJ96YNY"!S86QA
M<V%N87-I`%1U;&]K<V5T`%1U;&]K<V5T("AM=6MA86YL=6MI96X@2&]R9&4I
M.@!4=6QO:W-E=#H`4&%L86$@87-E='5K<VEI;@!2975N:6]N`%!A;&%U=&$@
M87-E='5K<V5T`%)I8V@@5&5X="!%9&ET;W)I;B!A<V5T=6MS970`07)V;VET
M=6MS970`3VEK96$`3VEK96$@;W1S86ME`$]I:V5A(&%R=F]T`%)I=FE?;B!T
M:65D;W0N+BX`4F]O;&D`4F]M86YI80!+Y.1N;N0@,3@P`$ODY&YNY"!V87-T
M87#D:7;DY&X`2^3D;F[D(&UY]G3D<.1I=N3D;@!2:79I;B!T:65D;W0`4FEV
M:6X@=&EE9&]T`%)I=FET.@!6:6EV;VET:6X`5FEI=F]I=&EN(&[D:WEY(&MA
M:6MK:65N(')I=FEE;B!J82!S87)A:VME:61E;B!VY&QI;&SD`%9I:79O:71I
M;B!NY&MY>2!V86EN('-A<F%K:V5I9&5N(';D;&EL;.0`5FEI=F]I=&EN(&[D
M:WEY('9A:6X@<FEV:65N(';D;&EL;.0`4W5O<FET80!696[D:N1N($9E9&5R
M871I:79I;F5N('1A<V%V86QT80!2=6%N9&$`4R]-24U%(&MR>7!T;V=R86%F
M:6YE;B!A;&QE:VER:F]I='5S`%,O34E-12!S86QA='1U('9I97-T:0!305-,
M+6%U=&5N=&EK;VEN=&D@96D@;VQE(&OD>71E='3D=FES<^0N`%--4R!496MS
M=&EV:65S=&ET`%-13"UK;VUE;G1O='5L:VMI`%-32`!/3DY)4U1520!37U%,
M+6MO;65N=&]T=6QK:VD`;&$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&IA
M($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!J82!-:7%U96QO;@!3
M86EN="!6:6YC96YT(&IA($=R96YA9&EI;FET`%-A;6%A;B!K96AY:W-E96X@
M*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&IA(%!R:6YC:7!E
M`%-A=&5L:6ET=&D@<&%L=F5L=6QU;G1A<FIO86IA`%-A=61I82!!<F%B:6$`
M5&%L;&5T80!486QL971A("5S`%1A;&QE=&$@)R5S)P!486QL971A(&%S971U
M:W-E=`!486QL971A(&QU;V1U="!A<V5T=6MS970@4$A0+7-K<FEP=&ENY"!P
M86QV96QI;65S:2!VY&QI86EK86ES:&%K96UI<W1O;VXN(`!486QL971E='1I
M:6X@)7,Z;B!A<V5T=6MS970N`%1A;&QE=&5T='5U;B!A<V5T=7-T96X@<.1I
M=FET>7-S:W)I<'1I('!A:6MK86%N.B`B)7,B+@!(86IA;F%I<VEA(%5K:V]S
M;7ER<VMY:N0`5&EE9&4`2&%K=0!(86MU:V]N965T`$5T<VETY.1N($AO<F1E
M(&]H:F5L;6EA('!A:6MA<W-A("5S`$5T<VETY.1N(&=E='1E>'0@8FENY.1R
M96ETY"XN+@!686QI='-E('1I961O<W1O=`!686QI='-E('#D:7;D;>3D<N0`
M5F%L:71S92!L:7/D='3D=N0@<GEH;>0`5F%L:71S92!U=7-I(&]M:7-T86IA
M`%9A;&ET<V4@<&%L=F5L:6X`5F%L:71S92!L:7/D='3D=N0@:^1Y='3D:N0`
M5F%L:71S92!K86EK:VD@<.1I=N1MY.1RY&MO;7!O;F5N=&ET`%9A;&ET<V4@
M;V)J96MT:0!686QI='-E('1A<G9I='1A=F%T(&UE<FMI="!A;&QA(&]L979I
M<W1A('9A;&EK;VES=&$N(%9O:70@<V5N(&KD;&ME96X@:V]P:6]I9&$@:F$@
M;&EI='3DY"!M97)K:70@=&5K<W1I:7-I+@!686QI='-E('#D:7;D>6MS96X@
M97)O=&EN;65R:VMI.@!686QI='-E('#D:7;D>6MS96X@97-I='ES=&%P83H`
M5F%L:71S92!M=75T971T879A('!R;V9I:6QI.@!686QI='-E(&ME;&QO;F%J
M86X@97)O=&EN;65R:VMI.@!686QI='-E(&%J86X@97-I='ES=&%P83H`5F%L
M:71S92!K86MS:2!Y:'1E96YS;W!I=F%A(&ME;G1TY.0N`%9A;&ET<V4@=N1R
M:71E96UA+@!686QI='-E(&OD>71E='3D=N0@:VEE;&DZ`$SD:&5TY"!V:6EM
M96ES:6UMY'0@=&EE9&]T`$SD:&5TY"!O;F=E;&UA=FEE<W1I`$SD:&5TY"!3
M35,`4V5N96=A;`!4=6YN:7-T:6XZ(`!S>7ES:W5U`%-E<F)I82!J82!-;VYT
M96YE9W)O`%-A<FIA;G5M97)O`%!A;'9E;&EM96X@=&EE9&]T(&]V870@=N3D
M<FEN('1A:2!N:6ETY"!E:2!O;&4@<V%A=&%V:6QL82X`4V5S<VEO;B!)1"!O
M;B!V86YH96YT=6YU="X`07-E=&$`4V%L87-A;F%N(')E<V5T;VEN=&EI;B!L
M:6ET='EV:>0@87-E='5K<VEA+"!J;W,@:F]S:W5S('5N;VAD870@<V%L87-A
M;F%S:2X`5F]I="!A<V5T=&%A('5L:V]I<W1E;B!P86QV96QI;6EE;B!A<V5T
M=6MS970L(&IO:71A(&AA;'5A="!KY'ET=.3D('!O<G1A86QI<W-A+@!6;VET
M(&%S971T86$@:^1Y=&5T=.1VY&X@:VEE;&5N+"!A:6MA=GGV:'EK:V5E;B!J
M82!M=6ET82!PY&EVY&WDY'+D87-E='5K<VEA+@!6;VET(&%S971T86$@86QO
M:71U<V]H:F5L;6%N+"!VY')I=&5E;6%N+"!NY&MY;>1N('#D:79I='EK<V5N
M(&IA(&UU:71A(&[D:WEMY.1N(&QI:71Y=FGD(&%S971U:W-I82X`07-E;FYU
M<P!!<V5N;G5K<V5N('#D:79I='ES<VMR:7!T:2!O;B!S86%T879I;&QA`%5S
M96%T('!A:6MA="!S;W!I=F%T(&%N;F5T='5U;B!P87)A;65T<FEI;CH@`%-E
M>6-H96QL:70`3W-T;VMS970`3'EH>70@:W5V875S.@!!<V5T971A('!I:V%V
M86QI;G1A;N1P<.1I;65T('5S96EM;6EL;&4@;&EN:V5I;&QE+@!.Y'ETY`!.
MY'ETY"!E<F]A=F%I<W5U9&5T(&%S971U:W-I96X@=&%L;&5T971U<W-A(&IA
M('5U9&5S<V$@:G5U<FD@;75O:V%T=7-S82!V97)S:6]S<V$N`$[D>73D(&5D
M96QL:7-E;B!S:7/DY&YK:7)J875T=6UI<V5N('#D:7;D>7,N`$[D>73D(&%S
M971U<R!P:73DY&MS97-I(&%L:W5P97+D:7-E;@!.Y'ETY"!V86QI='-I;@!.
MY'ETY"!T875L=6MK;W1O:6UI;FYO="!V86QI:VMO+@!.Y'ETY"!V87-E;6UA
M;&QA("5S('9A;&EK:V\N`$[D>73D('1A=6QU:V]N('-O;'5N('1I961O="!D
M:6%L;V=I`$[D>73D('1A=6QU:V]N('1I961O="!D:6%L;V=I`$[D>73D('1A
M=6QU:V]N(')I=FEN('1I961O="!D:6%L;V=I`$[D>73D(&MU=F%N('1I961O
M="!D:6%L;V=I`$[D>73D('1U;VYT:0!3871E:71A`%-A=&5I=&$@86EK86ES
M:6X`4V%T96ET82!M>?9H96UM:6X`4V%T96ET82!LY&AE='1Y=FEL;&$`4&EE
M;F5N;N0`4&EE;F5N;N0@=&%I('-I:7)R82!V:65R96ES:>0@;W-I;VET82P@
M:F]T=&$@;F4@96EVY'0@;VQE('1I96QLY`!3:65R<F$@3&5O;F4`2VER:F%U
M9'4`2VER:F%U9'4L(&IO<R!E="!O;&4@=FEE;.0@<F5K:7-T97+V:71Y;GET
M`$%L;&5K:7)J;VET=7,`06QL96MI<FIO:71U:W-E;B!A;&=O<FET;6D`4VEN
M9V%P;W)E`$MO:V\`3VAI=&$@>6QLY'!I=&]T96ATY';D=`!/:&ET971T:6EN
M+BXN`%-L;W9A:VEA`%-L;W9E;FEA`$QU;6D`3'5M:7-A9&5T=&$`3'5M:7-A
M=&5I=&$`3'5M:7-A=&5I=&$@86EK86ES:6X`3'5M:7-A=&5I=&$@;7GV:.3D
M;@!,=6UE;B!S>79Y>7,Z(`!,=6UE;B!MY.1RY"!V971E;N0Z(`!386QO;6]N
M('-A87)E=`!3;VUA;&EA`$QA=6QU="!J82!2=6YO=7,`2N1R:F5S='EK<V5N
M('-U=6YN86X@=F%L:6YT80!,Y&AD96]S;VET90!%=&5LY"U!9G)I:VMA`$5T
M96SD+45U<F]O<'!A("A)4T\M.#@U.2TS*0!%=&5LY"U'96]R9VEA(&IA(&5T
M96SD:7-E="!386YD=VEC:"!S86%R970`171E;.1I;F5N('!A;&QO;G!U;VQI
M<VMO`%;D;&D@=FEE<F5I<V5T('-O;'5J96X@=N1L:7-SY`!6Y&QI('-O;'5N
M(&QE:7#D=&5K<W1I;B!J82!R975N86X@=N1L:7-SY"``5N1L:0!6Y&QI`%;D
M;&D@:F$@=.1Y=&4`17-P86YJ80!2;W-K87!O<W1I`$5R:6MO:7-M97)K:VEE
M;B!S>?9T=/8`2F%A('-O;'4`2F%A('-A<F%K90!*86$@<FEV:0!5<FAE:6QU
M`%-R:2!,86YK80!3=&%N9&%R9&D`4W1A<B!4<F5K`$%L:V%A`$%L:V%M:7-V
M=6]S:0!,Y.1N:2!T86D@86QU90!4:6QA`$QO:V%L:7-O:6YN:6X@)7,@=&EL
M82XN+B``5&%L;&5N;G5S;75O=&\`2V%T=6]S;VET90!,Y'!I;'GV;G1I`$UE
M<FMK:6IO;F]L:7-T80!0;VES=&$@=&]I;6EA;'5E(&]S;VET=&5E<W1A`%1Y
M>6QI(%M#4U-=`'-U`$%L:6AA:V5M:7-T;V$@(B5S(B!E:2!L]GET>6YY="X`
M3W1S:6MK;P!,Y&AE=.0`3.1H971E='1I:6X@(B5S(CIN(&QI<^1Y<W!Y>6YT
M]BX@170@=F]I(&MI<FIA=71U82!S:7/DY&X@96YN96YK=6EN('!Y>6YT]G-I
M(&]N(&OD<VET96QT>2!J82!H>7;D:W-Y='1Y+@!!;&EK:7)J;VET=7,`3VYN
M:7-T=6D`(B5S(CH@;&ESY.1M:6YE;B!JY')J97-T96QMY.1N(&]N;FES='5I
M+@!+Y'ET=.1JY&X@(B5S(B!KY'ET=.1JY'1I971O:F5N('!O:7-T86UI;F5N
M(&KD<FIE<W1E;&WD<W3D(&]N;FES='5I+@`B)7,B.B!P;VES=&5T=&EI;B!O
M;FYI<W1U;F5E<W1I+@`B)7,B.B!O;FYI<W1U='1I:6X@<&]I<W1A;6%A;B!J
MY')J97-T96QMY'-TY"X`4&%L871T:6EN(&]N;FES='5N965S=&D@=F%N:&]I
M:&EN(&%S971U:W-I:6XN($QA=&%A('-I=G4@=75D97-T86%N(&[D:&3D:W-E
M<VD@;75U=&]K<V5T+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U
M<VMO<&EO+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U<VMO<&EO
M("5S+@`B)7,B.B!PY&EV:71Y<R!O;FYI<W1U:2X`(B5S(CIN(&MI<FIO:71T
M86UI;F5N(&]N;FES='5I+@!3=61A;@!9:'1E96YV971O`$%U<FEN9V]N;F]U
M<W4`075R:6YG;VYL87-K=0!!=7)I;FMO:6YE;@!!=7)I;FYN;W5S=0!!=7)I
M;FMO(&YO=7-E92]L87-K964`075R:6YN;F]U<W4Z(`!!=7)I;F=O;FQA<VMU
M`$%U<FEN9V]N;&%S:W4Z(`!0Y.1L;&5K:7)J;VET=7,`5'5K:0!3=7)I;F%M
M`%-U:W5N:6UI`$AU:7!P=79U;W)E="!J82!*86X@36%Y96X`4W=A>FEM86$`
M4G5O='-I`%-V96ET<VD`4WEN=&%K<VEV:7)H92!H86MU=&5R;65I<W/D`%-Y
M>7)I82P@87)A8FET87-A=F%L=&$`56MK;W-M>7)S:WD`56MK;W-M>7)S:WD@
M:F$@='5U;&ES=&$`56MK;W-M>7)S:WET`%5K:V]S;7ER<VMY:N0@86EK86ES
M:6X`5%-6+71I961O<W1O`%1A=6QU:VMO`%1A=6QU:V]N('1I961O=`!4875L
M=6MO;B!T:65D;W0`5&%I=V%N`%1A:7=A;BP@2VEI;F%N(&UA86MU;G1A`%1A
M9'II:VES=&%N`%1A;GIA;FEA+"!9:&1I<W1Y;GET('1A<V%V86QT80!+;VAD
M93H`5&5H=.1VY'0`4'5H96QI;FYU;65R;P!,Y&UP]G1I;&$@961E;&QI<V5L
M;&4@='5N;FEL;&4Z(`!,Y&UP]G1I;&$`3.1M</9T:6QA.B``36%L;&EA("(E
M<R(@96D@;/9Y='EN>70N`$UA;&QI96X@:&%L;&EN=&$`2'EVY&MS>2!P>7EN
M=/8@86QU<W1A=F%S=&D`06QU<W1A=F%S=&D@:'EVY&MS>71T>0!496MS=&D`
M5F%I;B!T96MS=&D`5&5K<W1I;B!T87-A=7,`5&5K<W1I=&]P`'1O`%1H86D@
M*%1)4RTV,C`I`%1H86EM86$`2VEI=&]K<V5T(&KD<FIE<W1E;&WD;B!KY'ET
M=.1M:7-E<W3D+@`E<R!A<'5T:65D;W-T;V$@)7,Z;&QE(&5I(&]L92!V:65L
MY"!O;&5M87-S82X@3'5O9&%A;B!U=7-I('1I961O<W1O+@!&5%`M;&ESY'1O
M:6UI;G1O(&5I(&]L92!KY'ET971TY'9I<W/D+@!(;W)D92]+;VQA8B!I;G1E
M9W)O:6YT:6UO;W1T;W)I(&5I('1U92`B)7,B`$UA:6YT96YA;F-E.CH@+6QU
M;VMA;B!L871A86UI;F5N(&5PY&]N;FES='5I`$%S971U:W-E="!I:VMU;F$@
M;VX@<W5L:F5T='4N(%!O:7-T=71A86XN`%EL;.1P:61O;B!P:73DY"!O='1A
M82!KY'ET=/;V;B!P>7-Y=N0@=&%L;&5T=7-T>7EP<&D@4&5R;6ES<VEO;BP@
M:F]S(&AA;'5A="!KY'ET=.3D(&YI:73D+@!686EN(&%L87!U;VQI`$MA;&5N
M=&5R:71I971O(&]N(&5PY&ME;'!O80!#;VYT86-T(&ED(&YU;65R;V$@96D@
M;VQE(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY="!T:65T
M;VMA;FYA<W1A+@!9:'1E>7-T:65D;R!L:7/D='1I:6X@;VYN:7-T=6YE97-T
M:2!O<V]I=&5K:7)J86%S:2X`5FEE<W1I;B!A;&QE:VER:F]I='5K<V5N('1A
M<FMI<W1A;6ES965N('1A<G9I=&%A;B!E<FEL;&EN96X@4$=0+6%L;&5K:7)J
M;VET=7-L;VAK;RX`2F%K96QU;&ES=&%N($E$(&5I(&]L;'5T(&WDY')I=&5L
M='DL(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY="!T:65T;VMA;FYA<W1A+@!*
M86ME;'5L:7-T86$@96D@;VQL=70@;>3D<FET96QT>2X`4V%L875S=&]I;6EN
M;F]N(&OD>71T]B!V86%T:2!S86QA='1U82!75U<M>6AT97ET=.0N`%1A<&%H
M='5M82!O;B!L:7/D='1Y(&MA;&5N=&ER:6ES:2X`5&EE9&]S=&]S<V$@)7,@
M<&ETY&ES:2!O;&QA("5S(&%S971U<RX`5&EE9&]S=&]S<V$@)7,@<&ETY&ES
M:2!O;&QA(&IO:71A:VEN("5S(&%S971U:W-I82X`5&EE9&]S=&]A(&5I('9O
M:61A(&MO<&EO:61A(&ET<V5N<^0@<.3D;&QE+@!4:65D;W-T;R!O;&D@='EH
M:N0N`%-E=7)A879A<W-A(&]N(&]T<VEK:V]T:65D;W0@=.1S=.0@;65S<V%G
M92]R9F,X,C(@+79I97-T:7-TY"X`2V]K;W)U=61U;B!NY'ET=/9T:6QA(&%I
M:&5U='1A82!O;F=E;&UI82!J;VEL;&%K:6X@26YT97)N970@17AP;&]R97(@
M<V5L86EM96X@:^1Y='3D:FEL;.0N(%9A;&ET971T879A<W1I(&MY<V5I;F5N
M('-E;&%I;B!S:7/D;'3DY"!P:6ER=&5I=.0@:F$@=FER:&5I=.0@:F]I:&EN
M(&5I(&]L92!L]GET>6YY="!K;W)J875S=&$@=&%I(&ME:6YO82!K:65R=.3D
M(&]N9V5L;6$N($AU;VUA871H86X@971TY"!J;W,@:^1Y=.1T('3D=.0@;N1Y
M='3V=&EL86$@:F$@26YT97)N970@17AP;&]R97(@<V5L86EN=&$L(&YI:6X@
M;N1Y='3V('-A871T86$@;65N;N0@<V5K86ES:6XL(&IO=&MU="!T;VEM:6YN
M;W0@96EVY'0@=&]I;6D@=&%I('-E;&%I;B!S86%T=&%A(&MA871U82X@2F]S
M(&OD>73D="!7:6YD;W=S(#EX('1A:2!-12!V97)S:6]T82P@;FEI;B!O;B!M
M86AD;VQL:7-T82!E='3D(&OD>71T]FKD<FIE<W1E;&WD(&MA871U=2!N<RX@
M)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@+79I<FAE97-E96X@:F$@<VEN
M=6X@<&ETY.0@:^1Y;FYI<W3DY"!K;VYE('5U9&5S=&%A;BY<;EQN($UU:7-T
M82!E='3D('-I;G5A(&]N('9A<F]I=&5T='4N($YA<'-A=71A($]++6YA<'!U
M;&%A(&IO<R!H86QU870@:V]K96EL;&4@961I=&]R:6X@:V]K;W)U=71U(&[D
M>71T]G1I;&%A+@!!<'5T:65D;W-T;R`E<R!E:2!A;&MA;G5T(&UE<FMK:6IO
M;F]L;&$@/#]X;6P`4&]I<W1E='1I:6X@<')O9FEI;&D@(B5S(BX`5F%I;B!V
M87-E;B!P=6]L:0!';G501R!O:&IE;&UA;B!S:6IA:6YT:2!P:73DY"!MY.1R
M:71E;&SD($-R>7!T7W!G<#HZ("UL=6]K87-S82X`5FEE<W1I(&SD:&5T971T
M>2`E<R!V87-T86%N;W1T86IA;&QE("5S(&]T<VEK:V]N82`B)7,B(&]N(&[D
M>71E='1Y+@I%:2!O;&4@;6ETY.1N('1A:V5I=&$@<VEI=.0@971TY"!V:65S
M=&D@;VX@;'5E='1U('1A:2!Y;6WD<G)E='1Y+@!.:6UI(&IO=&$@:^1Y=&5T
MY.1N(&QI;FMI=&5T=.1E<W-A(&QU;R!S:79U;&QE`$UO9'5U;&D@;W!E;G-S
M;"!T87)V:71A86X@2&]R9&5?0W)Y<'1?<VUI;64Z.B`M;'5O:V%N(&OD>71T
MY&UI<V5K<VDN`$%S971U<W1A("(E<R(@:V]S:V$@<V5N('1I961O="!Y;&ET
M=&EVY'0@=&%L;&5T=7-T879A;B!S=75R:6UM86X@<V%L;&ET=6X@<F%J86X`
M3VAJ96QM86$L(&IO;&QA('9O:2!K871S;V$@=FEE<W1I='EY<'!IY"`H)7,I
M+"!E:2!L]GET>6YY="!JY')J97-T96QMY'-TY"X`5F%I;B!O:6ME82!J82!V
M87-E;B!P=6]L:0!686EN(&]I:V5A('!U;VQI`%!A;'9E;&EN("(E<R(@;VX@
M<&]I<W1E='1U+@!086QV96QI;B`B)7,B(&]N('1A;&QE=&5T='4N`%-I<^3D
M;FMI<FIA=71U;6ES<'EY;G3V("5S(&]N('!O:7-T971T=2X`3>3D<FET96QT
M>>0@<FEV:>0@96D@;VQE(&]L96UA<W-A+@!496ATY';D(&]N(&QI<^1T='D@
M=&5H=.1VY&QI<W1A87-I+@!686QIY&%I:V%I<W1I961O<W1O82`B)7,B(&5I
M(&]L92!O;&5M87-S82X`5F%I;B!Y;.1P=6]L:2!J82!A;&%P=6]L:0!686EN
M('ELY'!U;VQI`%1U;W1U('1I971O(&CD=FES:2!E9&5L;&ES96X@:V]H9&%N
M(&%I:V%N82X`5'5O='5A('1I961O<W1O82!E:2!V;VET=2!T86QL971T86$N
M`$OD>71TY&KD;B!V87!A82]V87)A='1U('1I971O:F5N('1A;&QE='5S(&]N
M;FES='5I+@!/<VEO=&$@=V5A=&AE<BYC;VT@96D@;VQE(&OD>71E='3D=FES
M<^0N`%1E96UA:&%K96UI<W1O82`B)7,B(&5I(&SV>71Y;GET+@!!<V5T=6MS
M:6$@96D@;VQE('-A871A=FEL;&$N`$5I(&]L92!O<VEO:71A+"!J;W1K82!V
M;VED86%N(&[D>71TY.0@=FEE<W1I96X@>6AT97ED97-SY"X`5.1S<^0@:V5N
M=.1S<^0@;VX@;&EI86X@;6]N=&$@;65R:VMIY"X@06YN;VET("5S(&UE<FMK
M:>0[('-I;G5N('!I=.3D(&%N=&%A(';D:&5M;>1N(&MU:6X@)7,@;65R:VMI
MY"X`16D@;VQE('9I96SD(&]L96UA<W-A(&%P=71I961O<W1O82`E<SIL;&4N
M`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@;&ESY.1M:7-E<W/D(&KD<FIE<W1E
M;&WDY&XZ("5S`$OD>71TY&KD;B`B)7,B(&OD>71TY&KD=&EE=&]J96X@<&]I
M<W1A;6ES97-S82!JY')J97-T96QMY'-SY"!O;&D@;VYG96QM:6$Z(`!*;VET
M86MI;B!O;F=E;&UI82`B)7,B('!O:7-T86UI<V5S<V$@:N1R:F5S=&5L;>1S
M=.0Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('#D:79I='EK<V5S<^0Z("5S
M`%1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L;6EA+B!9:'3DY&X@)7,Z
M82!E:2!T=6]T=0!4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O;F=E;&UI82X@
M)7,@:V]K;R!O;&D@<W5U<F5M<&D@:W5I;B!S=75R:6X@<V%L;&ET='4@:V]K
M;R`H)60@=&%V=6$I+@!4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O;F=E;&UI
M82X@)7,@;&%T875T=6D@=F%I;B!O<V%K<VDN`%1A<&%H='5I('9I<FAE(&[D
M>71E='3D97-SY"!V:65S=&EN('3D=.0@;W-I;W1A`%EH=&5Y<W1I971O:F5N
M('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`5&%P86AT=6D@=FER:&4@='5O
M=&%E<W-A('1A<&%H='5M86$Z("5S+@!I0V%L96YD87(M=&EE=&]J96X@='5O
M;FYI<W-A('1A<&%H='5I('9I<FAE+@!487!A:'1U:2!V:7)H92!T=6]T865S
M<V$@=.1TY"!T96ATY';DY#H@)7,N`$OD>71TY&KD;B!V87!A82]V87)A='1U
M('1I971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H93H@)7,N`$%S971U
M<W1I971O;&]M86MK965S<V$@;VX@:F]K:6X@=FER:&4N($5H:^0@:N1T:70@
M:F]N:W5N('!A:V]L;&ES96X@:V]H9&%N('3D>71TY&WD='3D+@!487!A:'1U
M:2!V:7)H92!A=6MA:7-T865S<V$@=&EE9&]S=&]A("5S+B!+;VME:6QE(&%J
M86$@=')A;G-L871I;VXN<&AP('!A<F%M971R:6QLY"`M9"!J82!K871S;R!T
M=6QE96MO('AM;"UP87)S97)I;'1A(&UI=.3D;B!V:7)H96ETY"X`5&%P86AT
M=6D@=FER:&4@>7)I=&5T=.1E<W/D('-U;W)I='1A82!O<V]I=&5K:7)J871O
M:6UI;G1O82X@67)I=.0@;7GV:&5M;6EN('5U9&5S=&%A;BX`66AT97ES=&EE
M=&]J96X@<.1I=FET>6MS97-SY"!T87!A:'1U:2!V:7)H92X@67)I=.0@;7GV
M:&5M;6EN('5U9&5S=&%A;BX`2F%K96QU;&ES=&%N('#D:79I='EK<V5S<^0@
M=&%P86AT=6D@=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U=61E<W1A86XN`%3D
M;>0@24U!4"!P86QV96QI;B!E:2!T=64@:V%N<VEO:61E;B!J86MA;6ES=&$N
M`%3D;>0@=&]I;6EN=&\@96D@;VQE('1U971T=2X`5.1MY"!T;VEM:6YT;R!E
M:2!O;&4@=FEE;.0@=&]T975T971T=2X`5.1MY"!T:65D;W-T;R!E:2!V86EK
M=71A(')A<BUT:65D;W-T;VQT82X`5.1MY"!T:65D;W-T;R!E:2!V86EK=71A
M('II<"UT:65D;W-T;VQT82X`5.1MY"!E:2!V86EK=71A(&]I:V5A;'1A(&MO
M<G1T:6YU;65R;VQT82X`5.1L;.0@86IU<FEL;&$@=F]I(&SD:&5T=.3D('9I
M97-T96KD($-L:6-K871E;&QI;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G
M871E=V%Y('!A;'9E;'5A($A45%`@05!).FQL82X`5.1L;.0@86IU<FEL;&$@
M=F]I(&SD:&5T=.3D('9I97-T96KD('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E
M;6%I;"YC;VTI(&=A=&5W87D@<&%L=F5L=6$@2%144"!!4$DZ;&QA+@!4Y&QL
MY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@5F]D869O;F5N(&YU
M;65R;VEH:6X@4TU44#IL;.0@:^1Y='3D96X@5F]D869O;F4@271A;'D@9V%T
M97=A>2!P86QV96QU82X@5.1TY"!P86QV96QU82!V;VD@:^1Y='3DY"!V86EN
M(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@='5N;G5K<VEL
M;&$N`%3D;>0@:V5N='3D(&]N('!A:V]L;&EN96XN`%3D<W/D(&ME;G3D<W/D
M('!I=.3D(&]L;&$@=F%I;B!K;VMO;F%I<VQU:W5J82X`5.1S<^0@:V5N=.1S
M<^0@<&ETY.0@;VQL82!N=6UE<F]I=&$@:F$@<&EL:VMU+6UE<FMK96KD+@!4
MY'-SY"!K96YTY'-SY"!P:73DY"!O;&QA(&]K=&%A;&EL=6MU:F$N`%3D<W/D
M(&ME;G3D<W/D('!I=.3D(&]L;&$@;&ES=&$@:V]K;VYA:7-L=6MU:F$L(&IO
M=&MA('!I=.3D(&]L;&$@97)O=&5T='4@<&EL:W5L;&$@=&%I(';D;&EL>?9N
M;FEL;.0`07)V;VX@<&ETY.0@;VQL82!N=6UE<F\N`%3D<W/D(&ME;G3D<W/D
M(&]N(';D<FEMY.1R:71Y<RP@:F]N:V$@<&ETY.0@;VQL82!21T(@2&5X(&UU
M;V1O<W,L(&5S:6UE<FMI:W-I("<C,3(S-&%F)RX`5.1MY"!L;VUA:V4@;VX@
M:F\@:^1S:71E;'1Y+@!4Y&WD(&]N("5S+@!4Y&WD(&]N($MO;&%B($=R;W5P
M=V%R92!O8FIE:W1I+B!+871S;V%K<V5S:2!TY&WD;B!O8FIE:W1I;B!S:6YU
M;&QA('!I=.3D(&]L;&$@<^1H:_9P;W-T:6]H:F5L;6$L(&IO:V$@>6UMY')T
MY.0@2V]L86(@1W)O=7!W87)E(&9O<FUA871T:6$N($QI<W1A('EH=&5E;G-O
M<&EV:7-T82!SY&AK]G!O<W1I;VAJ96QM:7-T82!L]GET>7D@;W-O:71T965S
M=&$@)7,`5.1MY"!V:65S=&D@;VX@;VX@:VER:F]I=&5T='4@97)I(&UE<FMI
M<W3V;&SD("@E<RD@:W5I;B!M:6OD('-I;G5L;&$@;VX@:^1Y=/9S<^0N(`!.
M=6UE<F]N('!I=.3D(&]L;&$@=N1H:6YTY.1N('EK<VDN`%3D;>0@<VMR:7!T
M:2!P:73DY"!A:F%A(&MO;65N=&]R:79I;'3D+@!4Y&QLY"!P86QV96QI;65L
M;&$@96D@=F]I(&%U:V%I<W1A('II<"!T86D@9WII<"!T:65D;W-T;VIA+@!4
MY&WD(&KD<FIE<W1E;&WD(&]N('!O:7,@<.3D;'3D+@!!<G9O;B!P:73DY"!O
M;&QA(&YU;65R;RX`5.1MY&X@:6MK=6YA;B!V;VD@875K86ES=&$@=F%I;B!!
M<V5T=6MS970@:6MK=6YA<W1A`$UY<G-K>0!4:6ME=&ET`$%I:V$`06IA;G-E
M=7)A;G1A`$%J86X@97-I='ES;75O=&\`06IA;B!V86QI;G1A`%1I;6]R+4QE
M<W1E`%1I='1E;&D`3W1S:6MK;R`H=&]O;'1I<"DZ`%9A<W1A86YO='1A:F$`
M5F]I9&%K<V5S:2!V86QI=&$@=7-E86UP:6$@=F%I:'1O96AT;VIA+"!P:63D
M($-O;G1R;VPM("A00RD@=&%I($-O;6UA;F0M("A-86,I(&[D<'#D:6YTY"!P
M;VAJ87-S82!K=6X@;F%P<V%U=&%T(&AI:7)E;B!P86EN:6ME='1A+@!4Y&[D
MY&X`3N1Y=.0@2%1-3"ULY&AD96MO;V1I`%1O9V\`5&]K96QA=0!(=6]M96YN
M80!4;VYG80!9;/9S`%EL:6UPY.1N(&ME:'EK<V5E;B`H7W1O<"D`2^3D;FYE
M='1Y`$ODY&YN]FMS970`5')I;FED860@:F$@5&]B86=O`%1O<VD@=F%I(&5P
MY'1O<VD`=&D`5'5N:7-I80!4=7)K:VD`5'5R:VMI("A)4T\M.#@U.2TY*0!4
M=7)K;65N:7-T86X`5'5R:W,@:F$@0V%I8V]S('-A87)E=`!4=79A;'4`2VER
M:F]I=&$@=F%L:6YT87-I.B``52Y6+B`M:6YD96MS:3H@`%523`!54DP@:F]H
M;VX@<&%L875T971A86X@<VMR:7!T:6X@<W1A='5S(')A<&]R='1I`%523#H`
M56=A;F1A`%5K<F%I;F$`5D93+6AA:V5M:7-T;V$@96D@=F]I='4@;'5K96$N
M`$OD>71TY&KD;B!L:7/D=&EE=&]J96X@;&ESY'ES(&5I(&]N;FES='5N=70@
M:VER:F%U='5M:7-E<W-A+@!%:2!V;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93
M+71I961O<W1O;&QE("(E<R(N`$5I('9O:2!V86EH=&%A(&]I:V5U:W-I82!6
M1E,M=&EE9&]S=&]L;&4@)7,O)7,N`$5I('9O:61A('9A:6AT86$@)7,Z;BX`
M4U%,+7!A;'9E;&EM965N(&5I('-A861A('EH=&5Y='3D+@!9:'1E>71TY"!E
M:2!V;VED82!M=6]D;W-T86$@4U-,+7-A;&%T='5N82X`5D93+71I961O<W1O
M82!E:2!V;VED82!K;W!I;VED82X`16D@=F]I9&$@;'5O9&$@5D93+6AA:V5M
M:7-T;V$@(B5S(BX`16D@=F]I9&$@;'5O9&$@5D93+6AA:V5M:7-T;V$N`$5I
M('9O:71U(&QU;V1A(%9&4RUT:65D;W-T;V$`16D@=F]I='4@;'5O9&$@='EH
M:N3D(%9&4RUT:65D;W-T;V$N`%1I971O82!E:2!V;VED82!L86%J96YT86$N
M`$5I('9O:61A('!O:7-T86$@(B5S(BP@:&%K96UI<W1O(&5I(&]L92!T>6AJ
MY"X`16D@=F]I9&$@<&]I<W1A82`B)7,B.B`E<RX`16D@=F]I9&$@<&]I<W1A
M82`E<RP@:&%K96UI<W1O(&5I(&]L92!T>6AJY"X`16D@=F]I9&$@<&]I<W1A
M82!61E,M:&%K96UI<W1O82!R96MU<G-I:79I<V5S=&DN`$5I('9O:61A('!O
M:7-T86$@5D93+6AA:V5M:7-T;V$N`$5I('9O:61A('!O:7-T86$@5D93+6AA
M:V5M:7-T;V$Z("5S+@!%:2!V;VED82!P;VES=&%A(%9&4RUT:65D;W-T;V$@
M(B5S(BX`16D@=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A+@!%:2!V;VED
M82!P;VES=&%A(%9&4SKDY"!R96MU<G-I:79I<V5S=&DZ("5S+@!.>6MY:7-T
MY"!H86ME;6ES=&]A(&5I('9O:71U('-E;'9I='3DY"X`5F%R;65N=&5E;B!T
M:65T;VIA(&5I('9O:61A(&5X=')A:W1O:61A`$WDY')I='EK<V5N("5S(&QU
M:V5M:6YE;B!E<.1O;FYI<W1U:2X`16D@=F]I9&$@<VEI<G3DY"!61E,M=&EE
M9&]S=&]A+@!%:2!V;VED82!P;VES=&%A(%9&4RUT:65D;W-T;V$@(B5S(BX`
M16D@=F]I9&$@879A=&$@5D93+71I961O<W1O82!K:7)J;VET=7-T82!V87)T
M96XN`$5I('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$N`%1I:79I<W1E='EN
M('1I961O<W1O;B!A=6MA:7-U(&5PY&]N;FES='5I+@!%:2!V;VET=2!L=6ME
M82!T:65D;W-T83H@`'9F<W)O;W0@:G5U<FEH86ME;6ES=&]A(&5I('9O:71U
M(&QU:V5A+@!5=61E;&QE96YN:6UEY&UI;F5N("5S("5S.FMS:2!E<.1O;FYI
M<W1U:2!K;W-K82!K;VAD96AA:V5M:7-T;R!O;B!J;R!O;&5M87-S80!%:2!V
M;VED82!N:6UE=.0@=75D96QL965N(%9&4RUH86ME;6ES=&]A+@!%:2!V;VED
M82!N:6UE=.0@=75D96QL965N(%9&4RUH86ME;6ES=&]A.B`E<RX`16D@=F]I
M9&$@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O
M:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82`E<R\E<RX`16D@
M=F]I='4@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A+@!%:2!V;VED
M82!S=6]R:71T86$@:V]M96YT;V$@)VUK:7-O9G,G+@!7;W)D+61O:W5M96YT
M=&EA(&5I('9O:71U(&ODY&YTY.0`16D@=F]I9&$@:VER:F]I='1A82!61E,M
M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O
M<W1O;VX@*&-O<'DH*2!E<.1O;FYI<W1U:2DN`$5I('9O:61A(&MI<FIO:71T
M86$@5D93+71I961O<W1O;B!T:65T;VIA+@!!;&QE=FEI=F%T='4`4&5R=2!M
M=75T;VMS970`4&5R=75T=&%A(&5D96QL:7-E;B!T;VEM96YP:71E96X`5'5N
M=&5M871O;B!V87-T875S('!A;'9E;&EM96QT82!Y:'1E>71E96XZ`%1U;G1E
M;6%T;VX@=F%S=&%U<R!P86QV96QI;65L=&$Z(`!,=6]K:71T96QE;6%T;VX`
M2V]M<&]N96YT=&ET>7EP:6QL92!E:2!O;&4@:^1S:71T96QI:N3D.B`E<P!5
M;FEC;V1E("A55$8M."D`66AD:7-T>6YE970@87)A8FEE;6ER86%T:70`66AD
M:7-T>6YE970@:W5N:6YG87-K=6YN870`66AD>7-V86QL870`66AD>7-V86QT
M;VIE;B!4>7EN96YM97)E;B!E<FEL;&ES<V%A<F5T`$UI='1A>6MS:6OV=`!4
M=6YT96UA=&]N`%1U;G1E;6%T;VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2X`5'5N=&5M871O;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!4
M=6YT96UA=&]N(&MO;65N=&\Z("5S`%1U;G1E;6%T;VX@<&%I:VMA=&EE=&\N
M`%1U;G1E;6%T;VX@:^1Y='3D:N1T=6YN=7,@=&%I('-A;&%S86YA+@!0;VES
M=&$@;GEK>6ES96X@96QE;65N=&EN(&QI;FMI='ES`$YI;65T]FX`5&EE=&]T
M=7)V87-Y:7-TY"!E:2UP<FEV:6QE96=I<V5T('-K<FEP=&ET(&5I=N1T('9O
M:2!K=71S=6$@3&5I:VMA82]+;W!I;VDO3&EI=.0@=&]I;6EN=&]J82X@3F%P
M<V%U=&$@3TLM;F%P<'5L86$@;N1H9.1K<V5S:2!M;WII;&QA+F]R9R!S:79U
M:6QL82!O;&5V86X@;VAJ965N+"!J;W-S82!N975V;W1A86X@;6ET96X@<VMR
M:7!T:7-I('9O:79A="!KY'ET=.3D(&QE:6ME</9Y=.3D+@!0;VES=&$@=N1R
M:0!%:2UT=65T='4@;&%A:F5N;G5S`$ODY&YTY&WD=/9N`%#D:79I=.0`4.1I
M=FETY"`E<P!0Y&EV:73D('9A<W1A86IA;B!T:6QA=&EE9&]T`%#D:79I=.0@
M:^1Y='3D:N0`4.1I=FET971T:6EN("(E<R(N`%#D:79I=&5TY.1N("5S(&%P
M=71I961O<W1O82`E<SIL;&4N`%#D:79I='ES<VMR:7!T:2!P;VES=&5T=&EI
M;BX`5'5O`'1U;R!K86EK:VD@;VAJ96QM:65N(&%S96YN=7-T:65D;W-T;W0@
M<&%L=F5L:6UE;&QE+@!)<V]T(&QA=&EN86QA:7-E="!K:7)J86EM970`27-O
M="!R;V]M86QA:7-E="!N=6UE<F]T`%5R=6=U87D`2^1Y='3V.@!+Y'ETY"!N
M>6MY:7-TY#H@)7,`2^1Y=.0@4U-,+7-A;&%U<W1A`$OD>73D(&IO<R!T=6YN
M=7,O<V%L87-A;F$@;VX@97)I($E-4U`M<&%L=F5L:6UE;&QE+@!+Y'ET=.1J
MY&QLY"`E<R!E:2!O;&4@;VEK975K<VEA('1E:&3D("5S+@!+Y'ET=.1J:65N
M('EL;.1P:71O`$OD>71TY&KD;B!A<V5T=6MS970`2^1Y='3D:N1N(')E:VES
M=&5R]FEM:6YE;@!4Y'-SY"!JY')J97-T96QMY'-SY"!E:2!V;VD@<F5K:7-T
M97+V:63D(&OD>71TY&IIY"X`2^1Y='3D:N3D(&5I(&SV>71Y;GET`$OD>71T
MY&KDY"!E:2!L]GET>6YY="X`3VUI<W1A:F%N(&]I:V5U9&5T`$OD>71TY&KD
M='5N;G5S`$OD>71TY&KD='5N;G5S("(E<R(@;VX@:F\@;VQE;6%S<V$N`$OD
M>71TY&KD='5N;G5S.@!+Y'ET=.1JY'1U;FYU<SH@`$OD>71TY&KD=`!*Y')J
M97-T96QMY&X@:^1Y='3D:N1T.@!5>F)E:VES=&%N`%9&4RUH86ME;6ES=&]A
M(&5I(&]L92!O;&5M87-S82X`4&]I<W-A;VQO=FEE<W1I`%!A:6MK;VIA(&SV
M>71Y:2!E<VEM97)K:6MS:3H@`%9O:6UA<W-A;VQO86EK80!!<G9O(&UI;G5U
M=&5I<W-A(&YY:WEH971K97-TY"X`07)V;R!Y;&ET=.3D(&WDY')I=&5L;'EN
M(&UA:W-I;6EP:71U=61E;B`E<RX`07)V;W0`5F%L:71T879A="!A<G9O=`!6
M86YU871U`%9A:6AT96QE=F%A`%9E;F5Z=65L80!487)K:7-T=7,@97#D;VYN
M:7-T=6D@+2!4Y'3D('9I97-T:>0@;VX@=F]I='4@:^1S:71E;&SD+@!697)S
M:6\`5F5R<VEO;FAA;&QI;G1A`%!Y<W1Y<W5O<F$@=&%S875S`%!Y<W1Y<W5O
M<F$@=.1Y=&4`4'ES='ES=6]R83H`17)I='3D:6X@:V]R:V5A`%9I971N86T`
M5FEE=&YA;2`H5DE30TE)*0!.Y'ETY"`E<P!.Y'ETY"!E<FEL;&ES96[D('=W
M=RUS:79U;F$`3N1Y=.0@)7,`3N1Y=.0@=&%P86AT=6UA`$[D>73D('1E:'3D
M=N0`3F5I='-Y='-A87)E="P@0G)I='1I;.1I;F5N`$YE:71S>71S86%R970L
M(%EH9'ES=F%L=&%I;@!.Y&MY=N1I<WEY<P!.Y&MY=N1I<WEY<SH@`%9O9&%F
M;VYE($ET86QY(%--5%`Z;&SD`%9!4D])5%53`%9!4D])5%53(2$A(%!/25-4
M02!32U))4%1)($OD4TE.(%!!3%9%3$E-14Q402`E<RX`5V%L;&ES(&IA($9U
M='5N80!687)O:71U<P!687)O:71U<SH@`&ME`%/DY&5N;G5S=&4`4^3D=&EE
M9&]T('1O:6UI='1A80!796%T:&5R+F-O;0!75U<`5U=7+7-I=G5S=&\`5FEI
M:V]I='1A:6X`5&5R=F5T=6QO80!497)V971U;&]A(&]H:F5L;6%A;B`E<P!4
M97)V971U;&]A+"`E<P!,Y&YS:6UA:6YE;B`H25-/+3@X-3DM,2D`3.1N<VEM
M86EN96XO175R;R`H25-/+3@X-3DM,34I`$SD;G-I+5-A:&%R80!-:6YKY"!O
M:&IE;&UA;B`E<R!KY'EN;FES=.3D('-I<^3D;FMI<FIA=71U;6ES96X@:N1L
M:V5E;BX`36ETY"!M97)K:VGD(&OD>71E=.3D;B!E<F]T=&EM96YA/P!-:73D
M(&UE<FMK:>0@:^1Y=&5TY.1N(&QA:6YA=6MS965N/P!-:71KY"!V86EH965T
M`%9O:70@;>3D<FET96QLY"!L:7/D=&]I;6EN=&]J82!L86ET971A86X@<.3D
M;&QE(%)I8V@@5&5X="!E9&ET;W)I<W-A+@!,979E>7,`3&5V97ES($-34R!M
M:71T87EK<VEK:_9I;N0`5F%S96UM86QL82!O;&5V86X@)7,@=F%L:6MO;B!L
M979E>7,@*'1U;&5E('9O:6UA86X@<V5U<F%A=F%L;&$@<VESY.1N:VER:F%U
M='5M:7-E;&QA*3H`5&%U;'5K;VX@;&5V97ES`$QE=F5Y9&5N('EK<VEK:_8`
M3&5V97ES.@!7:6MI`%1U=6QI`%1U=6QI<W1A(&%I:V%I<VEN`%1U=6QE;FYO
M<&5U<R!S;VQM=6ES<V$`5'5U;&DZ`%1U=6QI.B``5FEI<V%U<P!4;VEV96QI
M<W1A=`!4>?8`3W-O:71E("A4>?8I`%!U:&5L:6X@*%1Y]BD`2VER:F]I=&5T
M86%N('#D:79I=&5T='GD(&%P=71I961O<W1O82`E<SIL;&4N`%@M4F5F`%@U
M,#EV,R!P97)U<W)A:F]I='1E970`6#4P.78S(&QI<^1T;VEM:6YN;W0@879A
M:6UE;B!KY'ET]FQL90!8-3`Y=C,@2V]H=&5E;B!V86EH=&]E:'1O:6YE;B!N
M:6UI`%@U,#EV,R!+;VAT965N(&%V86EM96X@='5N;FES=&4`6#4P.78S+6QA
M86IE;FYU:W-E=`!65@!65E96`%EA:&]O(2!K87)T=&$`5G5O<VET=&%I;@!*
M96UE;@!+>6QLY`!+>6QLY"P@<W5O<W1U;BX`2^1Y=.1T(%1%2U-4251)3$%!
M+B!+Y'ETY"!;/#Y=(&YA<'!U;&%A('9A:6AT86%K<V5S:2!T86MA:7-I;B!7
M65-)5UE'+71I;&%A;BX`170@;VQE(&%U=&5N=&EK;VET=6YU="X`3FEM97-S
MY'-I(&5I('-A82!O;&QA("=<)RUM97)K:VGD+@!%="!V;VD@=F%I:'1A82!K
MY'ET=.1JY&X@)7,@<V%L87-A;F%A`$5T(&%N=&%N=70@;VEK96%N(&UU;W1O
M:7-T82!SY&AK]G!O<W1I;W-O:71E='1A+@!%="!MY.1R:71E;&QY="!M:71K
MY"!T=6]D=6X@=&EE9&]S=&]N(&ME;G3D="!V87-T86%V870@;6ETY&MI;B!K
M96YT=&GD("5S.G-SY"X`3VQE="!K:7)J875T=6YU="!U;&]S+@!3:6YU;B!P
M:73DY"!A;G1A82!O:6ME82!M871K87!U:&5L:6YN=6UE<F\L('9A:6X@;G5M
M97)O:71A(&IA(&UA:&1O;&QI<V5S=&D@)RLG(&IO<R!KY'ETY'0@:V%N<V%I
M;G;D;&ES=.0@<'5H96QI;FYU;65R;VUU;W1O82X`4VEN=6X@=.1Y='EY(&%N
M=&%A(&]I:V5A(&%R=F\N`%-I;G5N('!I=.3D(&%S96YT86$@1&%T851R964@
M=&%U<W1A:N1R:F5S=&5L;>0@96YN96X@:W5I;B!V;VET(&OD>71TY.0@4VEG
M;G5P+71O:6UI;G1O:F$N`%-I;G5N('!I=.3D(&%S96YT86$@5D93+71A=7-T
M86KD<FIE<W1E;&WD+@!3:6YU;B!T=6QE92!K=79A:6QL82!O;F=E;&UA=&EL
M86YN971T82!E;FYE;FMU:6X@=F]I="!LY&AE='3DY"!O;F=E;&UA=FEE<W1I
M;BX`4VEN=6X@<&ETY.0@86YT86$@55),(&UI:&EN('3D;>0@;&EN:VMI(&]S
M;VET=&%A`%-I;G5N('3D>71Y>2!A;G1A82!N>6MY:6YE;B!S86QA<V%N87-I
M`%-I;G5N('3D>71Y>2!A;G1A82!H86QU86UA<VD@=75S:2!S86QA<V%N80!3
M:6YU;B!P:73DY"!V86QI=&$@<&]I<W1E='1A=F$@<&%L=F5L:6XN`%-I;G5N
M('!I=.3D(&%N=&%A('!O:7-T971T879A(&OD>71TY&KD='5N;G5S+@!3:6YU
M;B!P:73DY"!A;G1A82!P;VES=&5T=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN
M=6X@<&ETY.0@86YT86$@;&ESY'1TY';D(&OD>71TY&KD='5N;G5S+@!3:6YU
M;B!P:73DY"!A;G1A82!PY&EV:71E='3D=N0@:^1Y='3D:N1T=6YN=7,N`%-I
M;G5N('!I=.3D('9A;&ET82!S=6]R:71E='1A=F$@=&]I;6EN=&\N`%-I;G5N
M('!I=.3D(&%N=&%A('5U9&5N(&MA=&5G;W)I86X@;FEM:2X`4VEN=6X@=.1Y
M='EY('9A:'9I<W1A82!U=7-I('-A;&%S86YA<VD`4VEN=6X@<&ETY.0@86YT
M86$@271A;&EA;&%I;F5N('!U:&5L:6YN=6UE<F\`27-T=6YT;W-I("5S(&]N
M('9A;FAE;G1U;G5T+B!+:7)J875D=2!U=61E;&QE96X@<VESY.1N+@!3Y&AK
M]G!O<W1I;W-O:71T965S:0!3:6YU;B!LY&AE='3D:N1O<V]I='1E97-I.@!/
M;6%T('1I971O<VD`4VEN=6X@=&EE=&]K;VYE97-I(&OD>71TY&WD('1I971O
M=F5R:VMO+6]S;VET92!O;B!M=75T='5N=70@<V5N(&KD;&ME96X@:W5N(&]L
M970@86QO:71T86YU="`E<R!I<W1U;FYO;BX@5&EE=&]T=7)V87-Y:7-TY"!S
M:6YU;B!P:73DY"!K:7)J875T=6$@=75D97-T86%N:N1R:F5S=&5L;>3D;BX`
M3FEM97-I`$OD>71TY&WD<VD@875T:&5N=&EC871I;VX@=&%U<W1A:N1R:F5S
M=&5L;>0@96D@='5E(&OD>71TY&II96X@;&ESY.1M:7-TY"!T86D@=.1MY"!P
M:6ER<F4@96D@;VQE(&IO<W1A:VEN('-Y>7-TY"!KY'ET971TY'9I<W/D+@!+
MY'ET=.1MY'-I(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WD(&5I
M('1U92!KY'ET=.1JY'1I971O:F5N(&[D>71TY&UI<W3D('1A:2!TY&WD('!I
M:7)R92!E:2!O;&4@:F]S=&%K:6X@<WEY<W3D(&OD>71E='3D=FES<^0N`%-I
M;G5N(&OD>71TY&WD<VD@=W=W+7-E;&%I;B!NY'ET=.3D(&]L979A;B!M=75T
M='5N=70@<V5N(&KD;&ME96X@:W5N(&]L970@86QO:71T86YU="`E<R!I<W1U
M;FYO;BX@5&EE=&]T=7)V87-Y:7-TY"!S:6YU;B!P:73DY"!K:7)J875T=6$@
M=75D97-T86%N:N1R:F5S=&5L;>3D;BX`4V5L86EM97-I(&5I('1U92!TY'3D
M('1O:6UI;G1O82X`4V5L86EM97-I(&5I('1U92!T87)V:71T879A82!T=6QO
M<W1U<W1O:6UI;G1O82X@4&%I;F$@0V]N=')O;"]/<'1I;VX@*R!0('1U;&]S
M=&%A:W-E<VDN`$%I:V%V>?9H>6MK965S:3H`3VQE='5S<')O9FEI;&ES:3H`
M3FEM97-I.@!+Y'ET=.1MY'-I(&=E='1E>'0@=F5R<VEO(&]N(&QI:6%N('9A
M;FAA(&IA(&5I('1U92!O;&5T=6MS96YA(%!(4#KD+@I+86EK:VEA(&UE<FMK
M:6IO;F]J82!E:2!S86%D82!E>'1R86MT;VET=6$N`%-I;G5N('-A;&%S86YS
M:2`E<SIL;&4@;VXZ("5S`%5U<VD@<V%L87-A;F%S:2!O;B!L:6EA;B!P:71K
MY#L@<V%L87-A;F%T(&5I=N1T('-A82!O;&QA("5D(&UE<FMK:>0@<&ED96UP
M:>0A`%5U<VD@<V%L87-A;F%S:2!O;B!L:6EA;B!H96QP<&\@87)V871A+B!3
M86QA<V%N86$@96D@=F%I:&1E='1U(0!5=7-I('-A;&%S86YA<VD@;VX@;&EI
M86X@:&5L<'!O(&%R=F%T82X@4V%L87-A;F%A(&5I('9A:6AD971T=2$`575D
M96X@<V%L87-A;F%S:2!TY'ET>7D@;VQL82!VY&AI;G3DY&X@)60@;65R:VMI
MY"!P:71KY"$`575S:2!S86QA<V%N82!E:2!S86$@;VQL82!S86UA(&MU:6X@
M;GEK>6EN96X@<V%L87-A;F%S:0!5=61E<W-A('-A;&%S86YA<W-A('!I=.3D
M(&]L;&$@=N1H:6YTY.1N("5D(&MI<FIA:6YT80!5=61E<W-A('-A;&%S86YA
M<W-A('!I=.3D(&]L;&$@=N1H:6YTY.1N("5D(&MI<FIA:6YT82!J82!N=6UE
M<F]A+@!5=61E;B!S86QA<V%N86X@<&ETY.0@=.1Y='3DY"!VY&AI;G3DY&X@
M)60@=F%A=&EM=7-T82X@5F%A=&EM=6MS970@;W9A=#H@<&EE;FGD(&MI<FIA
M:6UI82P@:7-O:F$@:VER:F%I;6EA+"!N=6UE<F]I=&$@:F$@<WEM8F]L96ET
M82X`575D97-S82!S86QA<V%N87-S82!P:73DY"!O;&QA(';D:&EN=.3D;B`E
M9"!P:65N=.0@:VER:F%I;G1A+@!5=61E<W-A('-A;&%S86YA<W-A('!I=.3D
M(&]L;&$@=N1H:6YTY.1N("5D(&YU;65R;V$N`%5U9&5S<V$@<V%L87-A;F%S
M<V$@<&ETY.0@;VQL82!VY&AI;G3DY&X@)60@:7-O82!K:7)J86EN=&$N`%5U
M9&5S<V$@<V%L87-A;F%S<V$@<&ETY.0@;VQL82!VY&AI;G3DY&X@)60@=N1L
M:6QY]FYT:6UE<FMK:>0N`%5U9&5S<V$@<V%L87-A;F%S<V$@96D@<V%A(&]L
M;&$@=N1L:6QY]FYT:6UE<FMK96KD+@!!;G1A;6%S:2!U=61E="!S86QA<V%N
M870@96EVY'0@=.1S;>3D`$%S971U:W-E<VD@;VX@<.1I=FET971T>2!J82!N
M92!O=F%T('9O:6UA<W-A('3D;>1N(&ES='5N;F]N(&%J86XN`$%S971U:W-E
M<VD@;VX@<.1I=FET971T>2X`4V%L87-A;F%S:2!O;B!N;VQL871T=0!386QA
M<V%N87-I(&]N(&YO;&QA='1U+"!T87)K:7-T82!SY&AK]G!O<W1I<VD@:F$@
M:VER:F%U9'4@<VESY.1N('5U9&5L;&$@<V%L87-A;F%L;&%S:2X`06YT86UA
M<VD@<V%L87-A;F%T(&5I=N1T('3D<VWDY`!%=.1P86QV96QI;65S:3H`2G5G
M;W-L879I80!:86ER90!386UB:6$`6FEM8F%B=V4`6FEP<'D`6U!I:6QO=&$@
M;&%I;F%T='4@=&5K<W1I70!;3VYG96QM85T`6T[D>73D(&QA:6YA='1U('1E
M:W-T:2`M`%M.Y'ETY"!L86EN871T=2!T96MS=&D@+2`E<R!R:79IY%T`6W)I
M=FEL;.0@)7,O)7-=`%]9;&SD<&ET;P!?2V]M96YT;W1U;&MK:0!?1&%T851R
M964`7U!O:7-T82!R:79I`%]2>6AMY'0`7T]H:F4`7TMU=F%N('1I961O="XN
M+@!?2VER:F%U9'4@<VESY.1N`%]+:7)J875D=2!U;&]S`%]-=6]K:V%A(&QI
M;FMK:>0`7T%S971U:W-E=`!?3VEK975D970`4&]I<W1A(&QI;FMK:2XN+@!?
M07-E;FYU<P!?5&%U;'5K;VX@=&EE9&]T+BXN`%]+Y'ET=.1JY'0`;W-O:71E
M:VER:F$`=&%P86AT=6D@=FER:&4Z`&MA;&5N=&5R:0!T>7EN=.0`;F%P<V%U
M=&$@=.1S=.0`=F%L;6ES`&5PY&]N;FES='5I`&QA<VME=F$`=&EE9&]S=&\`
M;/9Y='EI.B``<W5U;FYA<W1A("5S("@E<RD@;F]P975D96QL82`E<R`E<P!H
M.@!H:`!VY&QI='3V;>1S=&D`:6YL:6YE`&QD87!?<W1A<G1?=&QS(&5PY&]N
M;FES='5I`')I=FET70!M:VES;V9S('9I<FAE:V]O9&D@)60@25-/.F$@=&5H
M9&5S<^0N`&UM`&YI;6D`96D@;75U='1U;G5T`&5I(&SV>71Y;GET`&5I(&]L
M92!T;W1E=71E='1U`&5I(&]L92!V:65LY"!T;W1E=71E='1U`&UU:7-T:6QI
M<W1A`'!R;W-E;G1T:0!P:6MS96QE:73D`&YO=7-E=F$`;N1Y=.0@97)O=`!S
M;7,R96UA:6P@2%144#IL;.0`<W,`=F%K86$`=&5H=.1VY&QI<W1A`$AO<F1E
M(%!/+71I961O<W1O82!L;VMA;&ES;VEN;FEL;&4@)7,@96D@;VQE(&]L96UA
M<W-A.@!V87)M:7-T86%K<V5S:2!K:7)J;VET82!S86QA<V%N82!K86AD97-T
M:0!U;FEF:65D`&YI;65T]FX`4.1I=FET971T>0!KY'ET=.1JY&X@=F%L:6YT
M80!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+VQO8V%L92]F:5]&22]H96QP+GAM;```````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-C$R-P`Q,#0Q-S,V,C<T,P`P,C$V,30`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]X;6P@
M=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!P87-S=V0O;&]C86QE+V9I
M7T9)+VAE;'`N>&UL+'8@,2XU(#(P,#4O,#8O,3D@,3<Z,#@Z-3D@:F%N($5X
M<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G!A<W-W9"UU<V5R;F%M92(@
M;60U/2(R8F4S86,T-65D,3!B9#0P.6)B8S,Q-#,U8S$U,C8Q92(@<W1A=&4]
M(F-H86YG960B/@H@("`@/'1I=&QE/DLF(WA%-#MY='0F(WA%-#MJ)B-X130[
M='5N;G5S/"]T:71L93X*("`@(#QH96%D:6YG/DLF(WA%-#MY='0F(WA%-#MJ
M)B-X130[='5N;G5K<V5S:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3&%I
M=&$@="8C>$4T.V@F(WA%-#MN('1A<G9I='1A97-S82!K)B-X130[>71T)B-X
M130[:B8C>$4T.W1U;FYU:W-E<VD@*&ME;G1T)B-X130[('-A871T86$@;7DF
M(WA&-CMS(&]L;&$@:F\@="8C>$4T.WET971T>2!V86QM:6EK<VDI+@H@("`@
M/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<&%S<W=D
M+75S97)N86UE(CX*("`@(#QT:71L93Y5<V5R;F%M93PO=&ET;&4^"B`@("`\
M:&5A9&EN9SY9;W5R(%5S97)N86UE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!%;G1E<B!Y;W5R('5S97)N86UE(&AE<F4@*&EF(&ET(&ES(&YO="!A;')E
M861Y('!R969I;&QE9"DN($YO="!A;&P@:6YS=&%L;&%T:6]N<R!S=7!P;W)T
M('1H:7,N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT
M<GD@:60](G!A<W-W9"UO;&0M<&%S<W=O<F0B(&UD-3TB,#AD8V,X-&0Y.#0V
M,F%D-3DP,S4V8V4V960V,#EC-#`B('-T871E/2)U<'1O9&%T92(^"B`@("`\
M=&ET;&4^5F%N:&$@<V%L87-A;F$\+W1I=&QE/@H@("`@/&AE861I;F<^5F%N
M:&$@<V%L87-A;F$\+VAE861I;F<^"B`@("`\<&%R83X*("`@($QA:71A('0F
M(WA%-#MH)B-X130[;B!N>6MY:6YE;BP@=&]I;6EV82!S86QA<V%N87-I+B!3
M:6YU;B!P:70F(WA%-#LF(WA%-#L@:VER:F]I='1A82!S86QA<V%N87-I(&]I
M:V5I;B!T86D@970@<'ES='D@=F%I:'1A;6%A;B!S86QA<V%N86%S:2X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!A<W-W9"UN97<M<&%S
M<W=O<F0B(&UD-3TB-&8R-&1E9C4V.#0Y-S9F8S1E,C4P-V0X,SDS-CDV-#$B
M('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^575S:2!S86QA<V%N83PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY5=7-I('-A;&%S86YA/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!+:7)J;VET82!T)B-X130[:"8C>$4T.VX@=75S:2!S
M86QA<V%N87-I+"!T)B-X130[;28C>$4T.R!T=6QE92!O;&5M86%N('5U<VD@
M<V%L87-A;F%S:2X@2'5O;6%A=&AA;B!E='0F(WA%-#L@<V%L87-A;F%S:2!P
M:70F(WA%-#LF(WA%-#L@="8C>$4T.WET)B-X130[)B-X130[('1I971Y="!M
M:6YI;6EV86%T:6UU:W-E="`H=&%R<&5E:W-I('!I=&LF(WA%-#LL(&5I('-A
M82!O;&QA(&LF(WA%-#MY='0F(WA%-#MJ)B-X130[='5N;G5K<V5S:2!T86D@
M;FEM97-I+"!S86QA<V%N86X@<&ET)B-X130[)B-X130[('-I<R8C>$4T.VQT
M)B-X130[)B-X130[(&MI<FIA:6UI82P@;G5M97)O:71A(&IA(&UU:71A(&UE
M<FMK96HF(WA%-#L@:FYE+BD@=&%I(&UU=71E;B!T=6QE92!V:7)H96EL;6]I
M='5S(&IA('-A;&%S86YA82!E:2!S86$@=F%I:&1E='1U82X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!A<W-W9"UC;VYF:7)M+7!A<W-W
M;W)D(B!M9#4](C4T-F4Q8CDQ.30U-#`P9C<V,#=F831F,3,S-C0X.#5F(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E9A:'9I<W1A('5U<VD@<V%L
M87-A;F$\+W1I=&QE/@H@("`@/&AE861I;F<^5F%H=FES=&$@=75S:2!S86QA
M<V%N83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@2VER:F]I=&$@="8C>$4T
M.V@F(WA%-#MN('5U<VD@<V%L87-A;F%S:2!T;VES965N(&ME<G1A86XN(%0F
M(WA%-#MM)B-X130[('9A<FUI<W1U<R!T96AD)B-X130[)B-X130[;B!S:6MS
M:2!E='0F(WA%-#L@970@='5L92!V86AI;F=O<W-A('1E:&YE96MS:2!K:7)J
M;VET=7-V:7)H971T)B-X130[('5U=&5E;B!S86QA<V%N86%S:2!J82!S:71E
M;B!T=6QI<VET(&QU:VEN;F5E:W-I('1U;FYU:W-E<VDN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P87-S=V0M<V5R=F5R(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y#:&%N9V4@<&%S<W=O<F0@;VX\+W1I=&QE/@H@
M("`@/&AE861I;F<^0VAA;F=E('!A<W-W;W)D(&]N/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!396QE8W0@=&AE('-E<G9E<B!O<B!A<'!L:6-A=&EO;B!I
M;B!W:&EC:"!Y;W4@=V%N="!T;R!C:&%N9V4@=&AE('!A<W-W;W)D+B!.;W0@
M86QL(&EN<W1A;&QA=&EO;G,@<W5P<&]R="!T:&ES+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB0VAA;F=E+7EO=7(M<&%S<W=O<F0B(&UD
M-3TB.#%C,S,R8C9A8C-A,3-E9#!D,#%D,#AF-S@P-&0R9&,B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^5F%I:&1A('-A;&%S86YA<VD\+W1I=&QE
M/@H@("`@/&AE861I;F<^5F%I:&1A('-A;&%S86YA<VD\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($YA<'-A=71A(")686EH9&$@<V%L87-A;F%S:2(@+7!A
M:6YI:V5T=&$@<VEV=6X@86QA;&%I9&%S<V$@;"8C>$4T.VAE='0F(WA%-#LF
M(WA%-#MK<V5S:2!S86QA<V%N86YV86EH=&]P>7EN;B8C>$8V.VXN(%9A<W1A
M('0F(WA%-#MM)B-X130[;B!P86EN:6MK965N('!A:6YA;6ES96X@:B8C>$4T
M.VQK965N('-A;&%S86YA;G9A:6AT;W!Y>6YT)B-X1C8[(&PF(WA%-#MH=&5E
M('!A;'9E;&EM96QL92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G)E<V5T(B!M9#4](C(Y.&0V,F)B.&9F8V,V-38X-#AF.#=C9C9F,V(U
M83(V(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E1Y:&IE;FXF(WA%
M-#L\+W1I=&QE/@H@("`@/&AE861I;F<^5'EH:F5N;B8C>$4T.SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@2R8C>$4T.WET)B-X130[('-I=G5N(&%L86QA
M:61A<W-A(&]L979A82`B5'EH:F5N;B8C>$4T.R(@+7!A:6YI:V5T=&$@='EH
M:F5N="8C>$4T.R8C>$4T.VMS97-I(&QO;6%K:V5E;B!T:65D;W0@:F$@86QO
M:71T86%K<V5S:2!A;'5S=&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!A<W-W9"]L;V-A;&4O971?144O````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`,#(P,30T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]E=%]%12],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<T,P`P,C$W,S$`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O
M;&]C86QE+V5T7T5%+TQ#7TU%4U-!1T53+W!A<W-W9"YM;P``````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#4U,#4S`#$P-#$W,S8R-S0S`#`R,S4W-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#>$@25`````!D!```<````
MY`@``'L!``"L$0```````)@7```H````F1<``$````#"%P``+0````,8```D
M````,1@``"D```!6&```&0```(`8```(````FA@``"(```"C&```!0```,88
M```#````S!@```D```#0&```&0```-H8```>````]!@``!`````3&0``#P``
M`"09```(````-!D```@````]&0``&0```$89```'````8!D```L```!H&0``
M#@```'09```%````@QD``!\```")&0``)0```*D9```G````SQD``"P```#W
M&0``*@```"0:```1````3QH``"(```!A&@``+P```(0:```(````M!H```4`
M``"]&@``!````,,:```#````R!H```@```#,&@``"@```-4:```&````X!H`
M`!4```#G&@``"@```/T:```/````"!L``!0````8&P``%P```"T;``!$````
M11L```H```"*&P``$0```)4;```,````IQL```<```"T&P``$````+P;```5
M````S1L``!````#C&P``&P```/0;```=````$!P``"`````N'```*0```$\<
M```A````>1P```(```";'```!0```)X<```6````I!P``!````"['```!@``
M`,P<```$````TQP``!0```#8'```+P```.T<```+````'1T```\````I'0``
M)@```#D=```$````8!T``!D```!E'0``!0```'\=```-````A1T```4```"3
M'0``(````)D=```0````NAT``!````#+'0``#P```-P=```+````[!T```\`
M``#X'0``#`````@>```/````%1X``"`````E'@``'0```$8>```M````9!X`
M`"$```"2'@``*````+0>```E````W1X``!\````#'P```P```",?```,````
M)Q\``!$````T'P``!0```$8?```$````3!\``!0```!1'P``!@```&8?```)
M````;1\```0```!W'P``#````'P?```*````B1\```4```"4'P``%````)H?
M```:````KQ\``"````#*'P``&0```.L?```.````!2```"`````4(```#@``
M`#4@```2````1"```!````!7(```$@```&@@```<````>R````@```"8(```
M"@```*$@```0````K"```!H```"](```!@```-@@```'````WR```%P```#G
M(```!@```$0A```"````2R$```0```!.(0``&````%,A```1````;"$```\`
M``!^(0``!P```(XA```'````EB$``!H```">(0``!P```+DA```*````P2$`
M``0```#,(0``!P```-$A```%````V2$```T```#?(0``/````.TA```Z````
M*B(``#L```!E(@``/@```*$B```=````X"(``!X```#^(@``&@```!TC```%
M````.",``",````^(P``#0```&(C```'````<",``!$```!X(P``"````(HC
M```1````DR,``"H```"E(P``&@```-`C```5````ZR,``!X````!)```"P``
M`"`D```:````+"0```4```!')```*````$TD```I````=B0```T```"@)```
M$P```*XD```(````PB0```0```#+)```%0```-`D```&````YB0```L```#M
M)```'````/DD``!`````%B4``#T```!7)0``0@```)4E```^````V"4``#\`
M```7)@``0@```%<F```^````FB8``#\```#9)@``0@```!DG```^````7"<`
M`#\```";)P``-@```-LG``!!````$B@``#T```!4*```/@```)(H```_````
MT2@``#L````1*0``/````$TI``!$````BBD``#T```#/*0``.@````TJ``!"
M````2"H``#X```"+*@``/P```,HJ```1````"BL```0````<*P``"0```"$K
M```,````*RL``&@````X*P``&@```*$K```7````O"L``!<```#4*P``&P``
M`.PK```9````""P``!\````B+```$P```$(L``!"````5BP``"0```"9+```
M#@```+XL```$````S2P``!````#2+```,````.,L```Z````%"T``!<```!/
M+0``!P```&<M```F````;RT``!H```"6+0``*@```+$M```%````W"T``(\`
M``#B+0``+@```'(N```R````H2X``%4```#4+@``S0```"HO``";````^"\`
M`*8```"4,```B0```#LQ``!S````Q3$``"$````Y,@``'````%LR```%````
M>#(```X```!^,@``(````(TR```:````KC(``"4```#),@``*@```.\R```F
M````&C,```P```!!,P``%P```$XS```-````9C,``!$```!T,P``$P```(8S
M```,````FC,```X```"G,P``#P```+8S```(````QC,```D```#/,P``!0``
M`-DS```4````WS,```<```#T,P``"````/PS```&````!30```T````,-```
M"P```!HT```,````)C0```H````S-````@```#XT```&````030``"4```!(
M-```/@```&XT``!%````K30``!\```#S-```'P```!,U```F````,S4``"4`
M``!:-0``(0```(`U```P````HC4``!,```#3-0``$````.<U```*````^#4`
M`'(````#-@``<P```'8V``!1````ZC8``#<````\-P``-@```'0W```^````
MJS<``$$```#J-P``0P```"PX``!`````<#@``#X```"Q.```0````/`X``!"
M````,3D``#D```!T.0``'P```*XY```?````SCD``!````#N.0``#P```/\Y
M```1````#SH``$,!```A.@``&0```&4[```L````?SL``"@```"L.P``'@``
M`-4[```8````]#L``!,````-/```"````"$\```;````*CP```4```!&/```
M!````$P\```)````43P``!8```!;/```%0```'(\```.````B#P``!(```"7
M/```"0```*H\```-````M#P``"$```#"/```!P```.0\```)````[#P```8`
M``#V/```!0```/T\```;`````ST``"@````?/0``(````$@]```>````:3T`
M`!H```"(/0``$@```*,]```L````MCT``#,```#C/0``"0```!<^```%````
M(3X```4````G/@```P```"T^```(````,3X```H````Z/@``!0```$4^```%
M````2SX```T```!1/@``#P```%\^```2````;SX``!\```""/@``*````*(^
M```(````RSX```P```#4/@``"0```.$^```%````ZSX``!````#Q/@``$P``
M``(_```)````%C\``!`````@/P``(0```#$_```A````4S\``"D```!U/P``
M)@```)\_```"````QC\```@```#)/P``'0```-(_```/````\#\```<`````
M0```#`````A````2````%4```"@````H0```#````%%````.````7D```"X`
M``!M0```!0```)Q````0````HD````8```"S0```$````+I````$````RT``
M`"0```#00```%````/5````5````"D$``!,````@00``$P```#1!```6````
M2$$```P```!?00``#P```&Q!```7````?$$``!H```"400``*P```*]!```B
M````VT$``!X```#^00``)@```!U"```@````1$(```0```!E0@``"P```&I"
M```*````=D(```@```"!0@``!````(I"```/````CT(```8```"?0@``"@``
M`*9"```#````L4(```X```"U0@``#@```,1"```%````TT(```P```#90@``
M%0```.9"```3````_$(``!0````00P``#@```"5#```D````-$,```\```!9
M0P``$P```&E#```2````?4,```T```"00P``%P```)Y#```$````MD,```H`
M``"[0P``&````,9#```G````WT,```H````'1```"@```!)$``!H````'40`
M``H```"&1````@```)%$```#````E$0``!L```"81```#0```+1$```.````
MPD0```<```#11```!0```-E$```?````WT0```D```#_1```"@````E%```$
M````%$4```0````910``#````!Y%```-````*T4``!H````Y10``)@```%1%
M```A````>T4``"4```"=10``(0```,-%```?````Y44``"4````%1@``!P``
M`"M&```B````,T8```X```!61@``"0```&5&```(````;T8```@```!X1@``
M$@```(%&```N````E$8``!H```##1@``&@```-Y&```3````^48```0````-
M1P``#0```!)'```'````($<``!,````H1P``)````#Q'```)````84<``!,`
M``!K1P``"0```']'```#````B4<``!,```"-1P``!P```*%'```,````J4<`
M`"$```"V1P``,````-A'```L````"4@``#(````V2```,P```&E(```N````
MG4@``#(```#,2```,P```/](```N````,TD``#(```!B20``,P```)5)```N
M````R4D``"D```#X20``,0```")*```R````5$H``"T```"'2@``+P```+5*
M```P````Y4H``"L````62P``.0```$)+```M````?$L``"D```"J2P``,@``
M`-1+```S````!TP``"X````[3```$@```&I,```$````?4P```T```""3```
M$@```)!,``!&````HTP``!<```#J3```%@````)-```6````&4T``!@````P
M30``$````$E-```4````6DT``!D```!O30``10```(E-```5````STT```X`
M``#E30``!0```/1-```3````^DT``"P````.3@``-P```#M.```3````<TX`
M``@```"'3@``%P```)!.```1````J$X``!P```"Z3@``!````-=.``"%````
MW$X``"8```!B3P``*P```(E/``!`````M4\``,<```#V3P``=0```+Y0``!O
M````-%$``(H```"D40``AP```"]2```@````MU(``!\```#84@``"````/A2
M```.`````5,``!X````04P``&@```"]3```N````2E,``"(```!Y4P``*@``
M`)Q3```0````QU,``!,```#84P``#P```.Q3```4````_%,```X````15```
M$@```"!4```3````,U0``!0```!'5```#````%Q4```-````:50```D```!W
M5```%````(%4```'````EE0```@```">5```#````*=4```2````M%0``!$`
M``#'5```#P```-E4```*````Z50```(```#T5```"P```/=4```D`````U4`
M`!(````H50``+@```#M5```B````:E4``",```"-50``*0```+%5```F````
MVU4``"<````"5@``-0```"I6```5````8%8```D```!V5@``"@```(!6``!O
M````BU8``'<```#[5@``10```'-7```^````N5<``"\```#X5P``+P```"A8
M```N````6%@``#H```"'6```,P```,)8```P````]E@``#(````G60``,0``
M`%I9```H````C%D``!T```"U60``'P```--9```0````\UD```\````$6@``
M%@```!1:```!````D@```!H```"]````6P```&P```#1`````````'D```#N
M````B0```!$```"X````OP````L```"\````F@``````````````.0```/(`
M``#Z`````````#@```!E``````````````"E``````$```````#A````,P``
M`.`````^````E@```%\```#7````V````,L`````````(P```$H```#_````
M`````(\````#`0``$@````\!```"`0``[```````````````LP```-L`````
M````-P````````"+````S@```.(```!P````C```````````````1P```%4`
M``#Y````]@````H```!%``````````(```"Q````[P`````````8`0``````
M`!<`````````8``````````O`````````)P```!C````'@```+4````@````
M%@```/$`````````!0```,````#P`````````+8```"T````40````````!7
M````W@```#\`````````HP```%0`````````J````&D```````````````8!
M```4`0``0P```/T```"$`````````.4```#T````?```````````````````
M``````!<````#0```#T````0`0``PP```'X````-`0``8@```!,```">````
M``````````!>````U0```+````!"````XP````````!]````H```````````
M````;@```,T```!(````!````!4````?````F0```%8`````````:```````
M``"O`````````!<!``#=````O@```+H````'`0````````````"#````+```
M`!$!```+`0``:P```,<`````````.@```-P```#9````^P```$P`````````
MSP```*L```````````````````"*````80```(@````*`0`````````````)
M`0```````&<`````````70```)$```#K````K`````````#2`````P``````
M``"D````I@```,$```"``````````((`````````%0$```````"Y````&P``
M``````#&````4````-H```#W````"0```($```!T````]0```$$`````````
M6@```````````````````$8````4````;0```"H```"5````&````"8```#*
M````)````!P```#(```````````````\````TP```"4```";````E```````
M``"R`````````*$``````````````!T```!_``````````````"J````K@``
M`,D```!.````YP```*T```"0`````````%@````U`````````#0````H````
M$@$``!8!``!J````Y````$```````````0$``$\```!R````DP```!````!2
M````=0```#````!D````````````````````````````````````>@```!,!
M``#S````4P```"<````(````T`````P!``"-````GP````0!``!+````_@``
M`'$`````````,0````````"7``````````<````[````!0$``.D```"G````
M"`$```````"[````Q0``````````````=@````````#,````*P```&8````V
M````````````````````#@````````#M````A@````````!9````>P``````
M``"W````20```(<````,````WP```/P````R````+0````````!-````#P``
M`,(```"B``````````8```!W````Z````/@````A````Y@``````````````
MA0```-0`````````U@````````!S````G0```*D````9````(@```,0````.
M`0``&0$``.H````I````;P```)@```".````>````$0````N`````"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+@`G)7,G(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D
M92!296=I<W1R>2X`)R5S)R!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN`"<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M`"<E<R<@=V%S(&YO="!C<F5A=&5D.B`E<RX`,C0@:&]U<G,`/&(^02!F871A
M;"!E<G)O<B!H87,@;V-C=7)R960Z/"]B/@!!32]030!!9&0`061D($-H:6QD
M`$%D9"!A(&-H:6QD(&=R;W5P('1O("<E<R<`061D(&$@8VAI;&0@<&5R;6ES
M<VEO;B!T;R`G)7,G`$%D9"!A(&YE=R!M96UB97(`061D(&$@;F5W('5S97(Z
M`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D<F5S<P!!9&1R97-S8F]O:P!!9&UI;FES=')A=&EO;@!!;&EA<P!!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@)R5S)S\`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!=F%I;&%B;&4@9FEE;&1S.@!"86-K96YD(&YO="!C
M;W)R96-T;'D@:6UP;&5M96YT960N`$)I;F0@=&\@<V5R=F5R("5S.B5D('=I
M=&@@1$X@)7,@9F%I;&5D.B!;)61=("5S`$)I<G1H9&%Y`$)R;W=N`$)U9W,`
M0U93`$-A;&5N9&%R`$-A;6]U9FQA9V4`0V%N8V5L`$-A;F-E;"!0<F]B;&5M
M(%)E<&]R=`!#96QL(%!H;VYE`$-H86YG92!087-S=V]R9`!#:&%N9V4@>6]U
M<B!P87-S=V]R9`!#:&%N9VEN9R!087-S=V]R9"!O;B`E<P!#:&5C:R!T:&4@
M8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@
M870@=&AI<R!T:6UE+@!#;&]S92!(96QP`$-L;W-E($AE;'`@5VEN9&]W`$-L
M;W-E(%=I;F1O=P!#;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]N9FER;2!N
M97<@<&%S<W=O<F0Z`$-O;G1E;G1S(&]F("<E<R<`0V]N=&5N=',@;V8@=&AE
M(%)!4B!A<F-H:79E`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O
M=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N('!I
M<&4@=&\@<VUB<&%S<W=D+@!$1`!$86EL>0!$871A8F%S92!Q=65R>2!F86EL
M960N`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;GD`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&ES8W5S<VEO;G,`1&ES<&QA>2!/<'1I;VYS`$1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5D:70`161I="!P
M97)M:7-S:6]N<R!F;W(@)R5S)P!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R
M`$5R<F]R('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N`$5V97)Y(#$U(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AP96-T960@(D)%1TE.(B!I;B!T:&4@;&EN92`E9"X`17AP96-T
M960@(D5.1#HE<R(@:6X@;&EN92`E9"X`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!P<F5F97)E;F-E<R!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!&86EL960@=&\@;W!E;B!A;B!,1$%0(&-O;FYE8W1I
M;VX@=&\@)7,N`$9A:6QE9"!T;R!R971R:65V92!U<V5R)W,@1$XZ(%LE9%T@
M)7,`1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"`Z(`!&87@`1FEL92!-
M86YA9V5R`$9U;&P@1&5S8W)I<'1I;VXZ`$=R965N`$=R97D`1W)O=7`@061M
M:6YI<W1R871I;VX`1W)O=7!S`$AE861L:6YE<P!(96QP`$AO;64@061D<F5S
M<P!(;VUE(%!H;VYE`$AO<F1E`$AO<F1E($%D;6EN:7-T<F%T:6]N`$AO<F1E
M($=R;W5P($%D;6EN:7-T<F%T:6]N`$AO<F1E(%!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N`$AO<F1E(%5S97(@061M:6YI<W1R871I;VX`2&]R9&4@5VER
M96QE<W,`2&]R9&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960`26UP;W)T
M($5R<F]R.B``26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`
M26YC;W)R96-T(%!A<W-W;W)D`$EN=F%L:60@<F5S<&]N<V4@9G)O;2!S97)V
M97(`3&%N9W5A9V4`3&EG:'0@0FQU90!,:7-T($AE;'`@5&]P:6-S`$QI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(&9A
M:6QE9"!F;W(@<V]M92!R96%S;VXN($UO<W0@;&EK96QY('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9V]U
M=`!-30!-86EL`$UA<"!$871E(&%N9"!4:6UE($9I96QD<P!-87`@26UP;W)T
M($9I96QD<P!-871C:&EN9R!F:65L9',`365M8F5R<P!-97-S86=E`$UE=&AO
M9"`G)7,G(&ES(&YO="!D969I;F5D`$UO;G1H;'D`37D@4W5M;6%R>0!.86UE
M`$YE='=O<FL`3F5V97(`3F5W('!A<W-W;W)D.@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@3$1!4"!0<F5F97)E;F-E<RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!#871E9V]R:65S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%!R969E<F5N8V5S+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P<F5F97)E;F-E<R!A<F4@879A:6QA8FQE+@!.;R!P<F5F97)E;F-E
M<R!W97)E(')E=')I979E9"X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`
M3F]T97,`3F]T:69I8V%T:6]N(&QI<W1E;F5R("5S(&YO="!F;W5N9"X`3VQD
M('!A<W-W;W)D.@!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D
M`%!A<W-W;W)D(&-H86YG960A`%!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O
M<&5R;'D@8V]N9FEG=7)E9`!087-S=V]R9',@8V%N;F]T(&)E(&)L86YK+@!0
M87-S=V]R9',@;75S="!M871C:"X`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4')E<V5N=&%T:6]N<P!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;V)L96T_`%)E
M860`4F5F<F5S:"!3=6UM87)Y(%9I97<Z`%)E;6]V90!296UO=F4@<&%I<@!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D`%)E<75I<F5D("=B87-E9&XG
M(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E
M;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G9&%T86)A<V4G(&YO="!S
M<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF
M:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=H
M;W-T<W!E8R<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@
M:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P
M96,G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE
M;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P87-S=V]R9"<@
M;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I
M9FEE9"!I;B!344P@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G
M(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@8V%T96=O
M<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P
M96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G=&%B;&4G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN
M(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N
M;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=T86)L95)E;&%T:6]N<R<@;F]T('-P96-I9FEE9"!I;B!C871E
M9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U:60G(&YO="!S<&5C
M:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)W5I9"<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@
M875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S97)N
M86UE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN('!R969E
M<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`
M4V%V92`G)7,G`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'1A<F5A+@!396QE8W0@
M=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!3
M96QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5T('EO
M=7(@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D
M:7-P;&%Y(&]P=&EO;G,N`%-E="!Y;W5R('!R969E<G)E9"!D:7-P;&%Y(&QA
M;F=U86=E+@!3:&]R="!3=6UM87)Y.@!3:&]W`%-K:7`@36%I;G1E;F%N8V4`
M4V]M92!O9B!(;W)D92=S(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I
M;F<Z`%-O;64@;V8@4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F
M:6QE<R!A<F4@;6ES<VEN9SH`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5C
M8V5S<P!3=6-C97-S9G5L;'D@861D960@)R5S)R!T;R!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+@!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`G)7,G(&9R;VT@=&AE('-Y<W1E;2X`5&%S:W,`5&AE(')E9VES=')Y(&ES
M(&AO=R!(;W)D92!A<'!L:6-A=&EO;G,@9FEN9"!O=70@:&]W('1O('1A;&L@
M=&\@96%C:"!O=&AE<BX@66]U('-H;W5L9"!L:7-T(&%N>2!I;G-T86QL960@
M2&]R9&4@87!P;&EC871I;VYS('1H870@>6]U(&AA=F4@:&5R92X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+@!4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M
M+@!4:&ES(&9I;&4@8V]N=&%I;G,@8F%C:V5N9"!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N(&9O<B!T:&4@4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N`%1H
M:7,@9FEL92!C;VYT<F]L<R!T:&4@9VQO8F%L('-E="!O9B!-24U%(&1R:79E
M<G,@9F]R('1H92!(;W)D92!F<F%M97=O<FLL(&%L;&]W:6YG(&%P<&QI8V%T
M:6]N<R!T;R!M86ME('5S92!O9B!P<F]G<F%M<R!S=6-H(&%S(&5N<V-R:7!T
M(&]R(&US=V]R9'9I97<@=&\@<F5N9&5R(&-O;G1E;G0@:6YT;R!(5$U,(&9O
M<B!V:65W:6YG(&EN(&$@8G)O=W-E<BX`5&AI<R!F:6QE(&-O;G1R;VQS('1H
M92!S='EL97-H965T('1H870@:7,@=7-E9"!T;R!S970@8V]L;W)S(&%N9"!F
M;VYT<R!F;W(@=&AE($AO<F1E(&9R86UE=V]R:R!A;F0@86QL(&%P<&QI8V%T
M:6]N<R!T:&%T(&1O(&YO="!P<F]V:61E('1H96ER(&]W;B!S971T:6YG<RX`
M5&AI<R!F:6QE(&UA<',@9FEL92!E>'1E;G-I;VYS('1O(&QO9VEC86P@34E-
M12!T>7!E<RP@96YA8FQI;F<@2&]R9&4@87!P;&EC871I;VYS('1O(&9I9W5R
M92!O=70@:&]W('1O(&AA;F1L92!S;VUE(&-O;G1E;G0@<W5C:"!A<R!E;6%I
M;"!A='1A8VAM96YT<R!O<B!#5E,@8VAE8VMO=71S+@!4:&ES(&ES('1H92!M
M86EN($AO<F1E(&-O;F9I9W5R871I;VX@9FEL92X@270@8V]N=&%I;G,@<&%T
M:',@86YD(&)A<VEC(&ET96US('1H870@87!P;'D@=&\@=&AE(&-O<F4@9G)A
M;65W;W)K(&%N9"!A;&P@2&]R9&4@87!P;&EC871I;VYS+@!4:&ES(&ES('1H
M92!M86EN(%!A<W-W;W)D(&UO9'5L92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET
M(&-O;G1A:6YS('!A=&AS(&%N9"!O<'1I;VYS(&9O<B!A;&P@4&%S<W=O<F0@
M;6]D=6QE('-C<FEP=',N`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%1Y<&4@
M;6ES;6%T8V@N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!D96QE=&4@)R5S)SH@)7,N`%5N86)L92!T;R!M;V1I9GD@<')E
M9F5R96YC97,Z(%LE9%T@)7,`56YA8FQE('1O(')E9VES=&5R('!R969E<F5N
M8V5S(&EN('-E<W-I;VXN`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F5X<&5C=&5D(&5N9"!O9B!F:6QE
M+@!5<&1A=&5D("<E<R<N`%5S92!$969A=6QT(%9A;'5E`%5S97(@061M:6YI
M<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@;F]T(&9O=6YD`%5S97(@;F]T
M(&9O=6YD+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<G,`57-E<G,@:6X@=&AE
M('-Y<W1E;3H`5V%R;FEN9P!787)N:6YG(0!7965K;'D`5V5L8V]M92!T;R`E
M<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R
M;'D`66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<P!9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N/&)R("\^5&AA;FL@>6]U(&9O<B!U<VEN
M9R!T:&4@<WES=&5M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9`!9;W4@;75S="!G:79E('EO=7(@
M;VQD('!A<W-W;W)D`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M
M86EL($%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!.86UE.@!9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+@!9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA
M>2!N;W0@8F4@;6]R92!T:&%N("5D(&-H87)A8W1E<G,@;&]N9R$`66]U<B!N
M97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N
M9V5D(0!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H
M87)A8W1E<G,@;&]N9R$`66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F
M97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0`66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA
M<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE
M87-T("5D(&%L<&AA;G5M97)I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;&]W97)C87-E(&-H87)A
M8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S
M="`E9"!N=6UE<FEC(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RX`
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&QE<W,@=&AA;B`E9"!W
M:&ET97-P86-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@
M;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C:&%R86-T97)S+@!9;W5R(&YE=R!P
M87-S=V]R9',@9&ED;B=T(&UA=&-H`%EO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`=&5M
M<&YA;2@I(&9A:6QE9"$`4')O:F5C="U)9"U697)S:6]N.B!087-S=V0*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(`I03U0M0W)E871I;VXM1&%T93H@,C`P-"TP
M-BTP,2`Q-3HQ.2LP,S`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#8M,#$@
M,3DZ-#`K,#,P,`I,87-T+51R86YS;&%T;W(Z(%1O;VUA<R!!87,@/'1O;VUA
M<RYA87-`;6%I;"YE93X*3&%N9W5A9V4M5&5A;3H@17-T;VYI86X@/&DQ.&Y`
M;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,3,*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`)7,@2&]O;&1U<W3V]F0@+2!K:6YN
M:71U<P`E<R!O;B!V86QM:7,@:^1I=FET86UA(&KD<F=M:7-E9"!H;V]L9'5S
M=/;V9``G)7,G(&5I(&]L92!(;W)D92!R96=I<W1R:7,@:.3D;&5S=&%T=60N
M`"<E<R<@;&ES871I(&=R=7!P:61E('/\<W1E96UI+@`G)7,G(&QI<V%T:2!L
M;V%S_'-T965M:2X`)R5S)R!E:2!L;V]D=60Z("5S+@`R-"!T=6YD:0`\8CY*
M=6AT=7,@:V]H=71A=B!V:6=A.CPO8CX`14PO4$P`3&ES80!,:7-A(&%L86T`
M3&ES82!A;&%M9W)U<'`@)R5S)RUL90!,:7-A(&%L86UL=6)A("<E<R<M;&4`
M3&ES82!U=7,@;&EI9V4`3&ES82!U=7,@:V%S=71A:F$Z`$QI<V$@<&%A<@!,
M:7-A(&MA<W5T86IA`$MA<W5T86IA=&4@;&ES86UI;F4@<&]L92!L=6)A='5D
M+@!!861R97-S`$%A9')E<W-I9`!(86QD=7,`06QI87,`4VES97-T871I(&QU
M8F%M871U(';DY')T=7,N`$]L960@<V$@:VEN9&5L(&5T('-O;W9I9"`G)7,G
M(&MU<W1U=&%D83\`2V%T<V4@:W5S='5T861A(&]L96UA='5T(&=R=7!P:2X`
M2V%T<V4@:W5S='5T861A(&]L96UA='5T(&QU8F$N`$MA='-E(&UU=71A(&]L
M96UA='5T(&QU8F$N`$MA<W5T871A=F%D(';D;&IA9`!!;'5S<F%K96YD=7,@
M96D@;VQE(&MO<G)A;&EK=6QT('!A:6=A;&1A='5D+@#<:&5N9'5S('-E<G9E
M<FEG82`E<SHE9"P@1$X@)7,@96)A]6YN97-T=7,Z(%LE9%T@)7,`4_QN;FEP
MY&5V`%!R=75N`$MA;&%D`$-64P!+86QE;F1E<@!-87-K965R:6YG`$QO;V)U
M`$QO;V)U`$UO8FEI;'1E;&5F;VX`5F%H971A('-A;&%S]6YA`$UU=61A(&]M
M82!S86QA<_5N80!386QA<_5N82!M=75T;6EN92!S_'-T965M:7,Z("5S`$WD
M<F=I(&OU:6L@=/;V9"!M:61A('-O;W9I9"!P<F%E9W4@=&5H82X`4W5L92!A
M8FD`4W5L92!A8FEA:V5N`%-U;&4@86ME;@!&:7)M80!+:6YN:71A('-A;&%S
M]6YA`$MO<F1A('5U="!S86QA<_5N83H`)R5S)R!S:7-U`%)!4B!A<FAI:79I
M('-I<W4`16D@<V%A;G5D(/QH96YD=7-T($Q$05`@<V5R=F5R:6=A`$5I('-A
M86YU9"#\:&5N9'5S="!,1$%0('-E<G9E<FEG80!%:2!S=75D82!KY&EV:71A
M9&$@:&]O;&1U<W3V]B!M;V]D=6QI="`E<P!%:2#U;FYE<W1U;G5D(&%V861A
M('1O<G4@<VUB<&%S<W=D+6=A+@!04`!)9V$@<.1E=@!!;F1M96)A87-I<.1R
M:6YG(&5B8?5N;F5S='5S+@!686EK96ED96YT:71E970`2W5S='5T80!,_&MK
M82!T86=A<VD`2VER:F5L9&$@<')O8FQE96UI`-QK<VEK87-J860@;&]G:71I
M(&%D;6EN:7-T<F%A=&]R:2!J86]K<RX`3?5T=&5V86AE='5S`$5K<F%A;FD@
M<V5A9&5D`,1R82#\<FET82!M86EN=&5N86YC92YP:'`@9F%I;&D@;W1S92!K
MY&EV:71A9&$`375U9&$`375U9&$@)7,@;'5B87-I9`!%+6UA:6P`5'5L96UU
M<R!O;B!T_&AI+@!6:6=A`%9I9V$@86YD;65T92!S86%T;6ES96P@<VUB<&%S
M<W=D+6QE+@!)9V$@,34@;6EN=71I('1A9V%N=`!)9V$@,S`@<V5K=6YD:2!T
M86=A;G0`26=A(#4@;6EN=71I('1A9V%N=`!)9V%L('-I<W-E;&]G:6UI<V5L
M`$EG82!P;V]L92!T=6YN:2!T86=A;G0`2V]R9"!M:6YU=&ES`$[D:61I<W;D
MY')T=7-E9`!296%L("5D('!U=61U8B`B0D5'24XB+@`B14Y$.B5S(B!O;B!P
M=75D=2!R96%L("5D+@!%:2!S86%N=60@_&AE;F1U<W0@3$1!4"!HY.1L97-T
M=7-S97)V97)I9V$N`$5I('-A86YU9"#\:&5N9'5S="!,1$%0('-E<G9E<FEG
M82X`16D@<V%A;G5D($Q$05`@_&AE;F1U<W0@)7,G9V$N`$5I('-A86YU9"!K
MY'1T92!K87-U=&%J82!$3B=I.B!;)61=("5S`%-A;&%S]6YA(&UU=71M:6YE
M(&5B8?5N;F5S='5S(#H@`$9A:W,`1F%I;&EH86QD=7(`2VER:F5L9'5S.@!2
M;VAE;&EN90!(86QL`$=R=7!P:61E(&AA;&1U<P!'<G5P:60`4&5A;&MI<FIA
M9`!!8FD`2V]D=6YE(&%A9')E<W,`2V]D=6YE('1E;&5F;VX`2&]R9&4`2&]R
M9&4@:&%L9'5S`$AO<F1E(&=R=7!P:61E(&AA;&1U<P!(;W)D92!L=6)A9&4@
M:&%L9'5S`$AO<F1E(&MA<W5T86IA:&%L9'5S`$IU:'1M971A($AO<F1E`$AO
M<F1E(&5I(&]L92!K;W)R86QI:W5L="!HY.1L97-T871U9`!6:6=A(&EM<&]R
M9&EL.B``26UP;W)D:71U9"!VY&QI.B`E<P!);7!O<F1I='5D(';D;&IA9#H`
M5F%L92!S86QA<_5N80!6:6=A;F4@=F%S='5S('-E<G9E<FEL=`!+965L`$AE
M;&5S:6YI;F4`06)I:6YF;R!T965M861E(&YI;65K:7)I`$MA<W5T86IA=&4@
M;FEM96MI<FIA('!O;&4@;'5B871U9"!NY&AA+@!,;V=I('-I<W-E`$QO9VD@
M=N1L:F$`36EL;&5G:7#D<F%S="!S:7-S96QO9VEM:6YE(&5B8?5N;F5S='5S
M+B!+]6EG92!T]65NY&]L:7-E;6%L="!S:7-E<W1A<VED('9A;&4@:V%S=71A
M:F%N:6UE(';U:2!S86QA<_5N82X`3&]G:2!VY&QJ80!+2P!)35``2W5U<.1E
M=F$@:F$@:V5L;&%A:F$@=N1L:F%D`$EM<&]R9&EVY&QJ860`4V]B:79A9"!V
MY&QJ860`3&EI:VUE9`!496%D90!-965T;V0@)R5S)R!E:2!O;&4@9&5F:6YE
M97)I='5D`$MO<F0@:W5U<P!+;VMK=7;U=&4Z`$YI;6D`5O5R:P!-:71T92!K
M=6YA9VD`575S('-A;&%S]6YA.@!,1$%0(&CDY&QE<W1U<VEN9F\@<'5U9'5B
M+@!344P@:V%T96=O;W)I871E(&CDY&QE<W1U<VEN9F\@<'5U9'5B+@!344P@
M<V5A9&5T92!HY.1L97-T=7-I;F9O('!U=61U8BX`4U%,(&%U=&5N=&EM:7-E
M(&CDY&QE<W1U<VEN9F\@<'5U9'5B+@!(Y.1L97-T=7-I;F9O(&5I(&]L92!K
MY'1T97-A861A=BX`2.3D;&5S='5S:6YF;W0@96D@<V%A;G5D(&OD='1E+@!%
M:2!T86=A<W1A='5D(&MO<G)E:W1S96ED(%A-3"!A;F1M96ED`$WD<FMM960`
M3>1R9W5A;FYE=&4@:W5U;&%J870@)7,@96D@;&5I='5D+@!686YA('-A;&%S
M]6YA.@!(Y.1L97-T=7,`375U(&EN9F\`4V%L87/U;F$`4V%L87/U;F$@;75U
M9&5T=60A`%!A<W-W;W)D(&UO;V1U;"!E:2!O;&4@:V]R<F%L:6MU;'0@:.3D
M;&5S=&%T=60`4V%L87/U;F$@96D@=O5I(&]L;&$@=/QH:2X`4V%L87/U;F%D
M('!E879A9"!K;&%P<&EM82X`2^1I=FET82!H;V]L9'5S=/;V9`!,;V%D`$QU
M8F%D92!H86QD=7,`5&5L969O;@!+:7)J96QD82!P<F]B;&5E;6DN`%-I<V5S
M=&$@;VUA(&MA<W5T86IA;FEM:2!J82!S86QA<_5N80!%<VET;'5S960`4')O
M8FQE96UI(&MI<FIE;&1U<P!0<F]B;&5E;3\`3&]E`%;D<G-K96YD82#\;&5V
M86%D93H`165M86QD80!%96UA;&1A('!A87(`4.1R:6YG=6QE('!O;&YU9"!V
M]6EM86QI:R!V87-T871A`$%U=&5N=&EM:7-E(&CDY&QE<W1U<V5S('!U=61U
M8B!V86IA;&EK("=B87-E9&XG+@!396%D971E(&CDY&QE<W1U<V5S('!U=61U
M8B!V86IA;&EK("=B87-E9&XG+@!!=71E;G1I;6ES92!HY.1L97-T=7-E<R!P
M=75D=6(@=F%J86QI:R`G9&%T86)A<V4G+@!+871E9V]O<FEA=&4@:.3D;&5S
M='5S97,@<'5U9'5B('9A:F%L:6L@)V1A=&%B87-E)RX`4V5A9&5T92!HY.1L
M97-T=7-E<R!P=75D=6(@=F%J86QI:R`G9&%T86)A<V4G+@!!=71E;G1I;6ES
M92!HY.1L97-T=7-E<R!P=75D=6(@=F%J86QI:R`G:&]S='-P96,G+@!+871E
M9V]O<FEA=&4@:.3D;&5S='5S97,@<'5U9'5B('9A:F%L:6L@)VAO<W1S<&5C
M)RX`4V5A9&5T92!HY.1L97-T=7-E<R!P=75D=6(@=F%J86QI:R`G:&]S='-P
M96,G+@!!=71E;G1I;6ES92!HY.1L97-T=7-E<R!P=75D=6(@=F%J86QI:R`G
M<&%S<W=O<F0G+@!+871E9V]O<FEA=&4@:.3D;&5S='5S97,@<'5U9'5B('9A
M:F%L:6L@)W!A<W-W;W)D)RX`4V5A9&5T92!HY.1L97-T=7-E<R!P=75D=6(@
M=F%J86QI:R`G<&%S<W=O<F0G+@!344P@:.3D;&5S='5S97,@<'5U9'5B('9A
M:F%L:6L@)W!H<'1Y<&4G+@!!=71E;G1I;6ES92!HY.1L97-T=7-E<R!P=75D
M=6(@=F%J86QI:R`G<&AP='EP92<N`$MA=&5G;V]R:6%T92!HY.1L97-T=7-E
M<R!P=75D=6(@=F%J86QI:R`G<&AP='EP92<N`%-E861E=&4@:.3D;&5S='5S
M97,@<'5U9'5B('9A:F%L:6L@)W!H<'1Y<&4G+@!!=71E;G1I;6ES92!HY.1L
M97-T=7-E<R!P=75D=6(@=F%J86QI:R`G=&%B;&4G+@!+871E9V]O<FEA=&4@
M:.3D;&5S='5S97,@<'5U9'5B('9A:F%L:6L@)W1A8FQE)RX`4V5A9&5T92!H
MY.1L97-T=7-E<R!P=75D=6(@=F%J86QI:R`G=&%B;&4G+@!+871E9V]O<FEA
M=&4@:.3D;&5S='5S97,@<'5U9'5B('9A:F%L:6L@)W1A8FQE4F5L871I;VYS
M)RX`075T96YT:6UI<V4@:.3D;&5S='5S97,@<'5U9'5B('9A:F%L:6L@)W5I
M9"<N`%-E861E=&4@:.3D;&5S='5S97,@<'5U9'5B('9A:F%L:6L@)W5I9"<N
M`$%U=&5N=&EM:7-E(&CDY&QE<W1U<V5S('!U=61U8B!V86IA;&EK("=U<V5R
M;F%M92<N`$MA=&5G;V]R:6%T92!HY.1L97-T=7-E<R!P=75D=6(@=F%J86QI
M:R`G=7-E<FYA;64G+@!396%D971E(&CDY&QE<W1U<V5S('!U=61U8B!V86IA
M;&EK("=U<V5R;F%M92<N`%1A9V%S:2!HY.1L97-T=7-S90!2;VQL`%-A;'9E
M<W1A("<E<R<`4V%L=F5S=&$@:.3D;&5S='5S`%9A;&D@=F%J86QI:W5D(&WD
M<F=I9"!K87-T:61E<W0N(%-I:7,@<V%A9"!N965D(&MO<&5E<FED82!K:7)J
M82!S:7-S92X`5F%L:2!K=75PY&5V82!E<F%L9&%J83H`5F%L:2!K=75PY&5V
M82!F;W)M86%T.@!686QI(&ME;&QA86IA(&9O<FUA870Z`%9A;&D@:V%K<R!S
M;V)I=F%T(';D;&IA+@!686QI(';D<G9I<VME96TN`%9A;&D@;VUA(&QE;6UI
M:VME96PZ`%-A861A('!R;V)L965M:2!K:7)J96QD=7,`5F%L:2!O;6$@=N1R
M=FES:V5E;6DL(&QE:&5K_&QJ92!VY')S:V5N9&%M:7-E(&IA(&UU=60@97-I
M='5S92!S96%D960N`%9A;&D@965L:7-T871A=B!K965L+@!,_&AI:V]K:W5V
M]71E.@!.Y&ET80!*Y'1A(&AO;VQD=7,@=F%H96QE`$WU;F5D($AO<F1E(&MO
M;F9I9W5R871S:6]O;FEF86EL:60@;VX@<'5U9'4Z`$WU;F5D(%!A<W-W;W)D
M(&UO;V1U;&D@:V]N9FEG=7)A='-I;V]N:69A:6QI9"!O;B!P=75D=3H`17)I
M;>1R:VED92!S:7-E<W1U<P#5;FYE<W1U<P`E<R!O;B!S_'-T965M:2!L:7-A
M='5D+@`E<R!O;B!K=7-T=71A='5D+@`E<R!O;B!S_'-T965M:7-T(&5E;6%L
M9&%T=60N`%3V]F0`4F5G:7-T<FD@86)I;"!T96%V860@2&]R9&4@<F%K96YD
M=7-E9"!K=6ED87,@_&MS=&5I<V5G82!S=6AE;&1A+B!3:6EA('!E86MS:60@
M:VER:G5T86UA(&OU:6L@2&]R9&4@<F%K96YD=7-E9"!M:7,@<W5L(&EN<W1A
M;&QI='5D(&]N+@`E<R!L:7-A;6ES96P@<_QS=&5E;6D@=&5K:VES('!R;V)L
M965M+@`E<R!E96UA;&1A;6ES96P@<_QS=&5E;6ES="!T96MK:7,@<')O8FQE
M96TN`%-E92!F86EL('-I<V%L9&%B(%!A<W-W;W)D(&UO;V1U;&D@86QU<W)A
M:V5N9'5S92!HY.1L97-T=7-I;F9O="X`4V5E(&9A:6P@;>3D<F%B($U)344@
M9')A:79E<FED(&UI9&$@:V%S=71A=F%D(&OU:6L@2&]R9&4@<F%K96YD=7-E
M9"!J82!TY&YU(&UI;&QE;&4@<V%A=F%D(&YA9"!K87-U=&%D82!VY&QI<V5I
M9"!P<F]G<F%M;64@;F%G=2!E;G-C<FEP="!J82!M<W=O<F1V:65W(&5R:6YE
M=F%T92!F86EL:61E(&5S:71A;6ES96MS(&)R;W=S97)I<R!(5$U,:6YA+@!3
M964@9F%I;"!MY.1R86(@=N1R=FED(&IA(&MI<FIA<W1I:6QI9"!(;W)D92!J
M82!K]6EG:2!(;W)D92!R86ME;F1U<W1E(&IA;VMS(&UI;&QE;"!E;F1A;"!E
M:2!O;&4@=F%S=&%V870@:.3D;&5S='5S="X`4V5E(&9A:6P@;>3D<F%B(&9A
M:6QI;&%I96YD:71E;&4@=F%S=&%V860@34E-12!T_/QB:60L('3D;G4@;6EL
M;&5L92!O<VMA8B!(;W)D92!KY'-I=&QE9&$@;?5N:6YG86ED(&9A:6QI=/S\
M<&4N`%-E92!O;B!P96%M:6YE($AO<F1E(&MO;F9I9W5R871S:6]O;FEF86EL
M+B!3964@<VES86QD86(@9F%I;&ED92!A<W5K;VAT:2!J82!TY&AT<V%M86ED
M(&CDY&QE<W1U<VD@;6ES(&ME:'1I=F%D(&OU:6=I;&4@2&]R9&4@<F%K96YD
M=7-T96QE+@!3964@;VX@4&%S<W=O<F0@;6]O9'5L:2!P96%M:6YE(&MO;F9I
M9W5R871S:6]O;FEF86EL+B!3964@<VES86QD86(@9F%I;&ED92!A<W5K;VAT
M:6YI;F<@<V5A9&5I9"!K]6EG:2!087-S=V]R9"!M;V]D=6QI('-K<FEP=&ED
M92!J86]K<RX`4V5E(&%R=B!P96%B(&]L96UA(';D:&5M86QT(/QK<RX`4V5L
M;&4@:V]H82!P96%L('!E86(@;VQE;6$@87)V+@!096%L:VER:0!3;V)I;6%T
M=2!T_/QP+@!%:2!S86$@_&AE;F1U<W0@4U%,('-E<G9E<FEG82X`16D@<V%A
M(&MU<W1U=&%D82`G)7,G.B`E<RX`16D@<V%A('-A;'9E<W1A9&$@;75U9&5T
M=60@:.3D;&5S='5S=#H@6R5D72`E<P!%:2!S=75D82!HY.1L97-T=7-T(')E
M9VES=')E97)I9&$N`%-E9&$@5V]R9&D@9&]K=6UE;G1I(&]N(';U:6UA='4@
M=/5L9V5N9&%D80!4_&AI<W1A(&UU=71U<V5D`$9A:6QI(&]O=&%M871U(&SU
M<'``575E;F1A='5D("<E<R<N`$MA<W5T82!V86EK97;DY')T=7-T`$MA<W5T
M86IA:&%L9'5S`$MA<W5T86IA(&CDY&QE<W1U<P!+87-U=&%J870@96D@;&5I
M='5D`$MA<W5T86IA="!E:2!L96ET=60N`$MA<W5T86IA;FEM:0!+87-U=&%J
M86YI;6DZ`$MA<W5T86IA9`!+87-U=&%J860@<_QS=&5E;6ES.@!(;VEA='5S
M`$AO:6%T=7,A`$MO<F0@;N1D86QA<P!497)E('1U;&5M87-T("5S+6D`5&5R
M92!T=6QE;6%S="P@)7,`5/;V:V]H82!A861R97-S`%3V]G1E;&5F;VX`04$`
M2V]R9"!A87-T87,`4V$@96D@<V%A(&UU=71A(&MA<W5T86IA("5S('-A;&%S
M]6YA`%-I;F0@;&]G:71I(';D;&IA+@!%;FYE('-A871M:7-T(&]L96MS('1A
M<FL@<')O8FQE96UI(&MI<FIE;&1A9&$N`%-A('!E860@<VES97-T86UA(&]M
M82!U=64@<V%L87/U;F$`4V$@<&5A9"!S:7-E<W1A;6$@;VUA('9A;F$@<V%L
M87/U;F$`4&5A9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&5E;6%L9&%D
M82X`4&5A9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&QI<V%D82X`575S
M('-A;&%S]6YA('1U;&5B('-I<V5S=&%D82!K86MS(&MO<F1A`%-I;G4@)7,@
M<V5S<VEO;VX@;VX@865G=6YU9"X@4&%L=6X@;&]G:2!U=65S=&D@<VES<V4N
M`%-I;G4@92UM86EL:2!A861R97-S.@!3:6YU(&EN9F\`4VEN=2!N:6UI.@!3
M:6YU(&%U=&5N=&EM:7-S_'-T965M(&5I(';U:6UA;&1A(&MA<W5T86IA:60@
M;&ES861A+"!V]6D@;VX@<V5E(';U:6UA;'5S(&UI;F=I;"!M=75L('#U:&IU
M<V5L(';D;&IA(&S\;&ET871U9"X`4VEN=2!A=71E;G1I;6ES<_QS=&5E;2!E
M:2!V]6EM86QD82!K87-U=&%J871E(&YI;65K:7)J82!NY&AA+"!V]6D@;VX@
M<V5E(';U:6UA;'5S(&UI;F=I;"!M=75L('#U:&IU<V5L(';D;&IA(&S\;&ET
M871U9"X`575S('-A;&%S]6YA(&]N(&QI:6=A('!I:VL[('-A;&%S]6YA(&5I
M('1O:&D@;VQL82!P:6ME;2!K=6D@)60@;>1R:VDA`%5U="!S86QA<_5N82!O
M;B!L:6EG82!L:6AT;F4@Y')A(&%R=F%T82$@4V%L87/U;F$@96D@;75U9&5T
M=60A`%5U<R!S86QA<_5N82!P96%B(&]L96UA(';D:&5M86QT("5D(&WD<FMI
M('!I:VLA`%5U<R!S86QA<_5N82!P96%B(&5R:6YE;6$@<')A96=U<V5S="!S
M86QA<_5N87-T`%5U<R!S86QA<_5N82!P96%B('-I<V%L9&%M82!VY&AE;6%L
M92`E9"!TY&AT92X`575S('-A;&%S]6YA('!E86(@<VES86QD86UA(';D:&5M
M86QT("5D('3D:'1E(';U:2!N=6UB<FET+@!5=7,@<V%L87/U;F$@<&5A8B!S
M:7-A;&1A;6$@=N1H96UA;'0@)60@=N1I:V5TY&AT92X`575S('-A;&%S]6YA
M('!E86(@<VES86QD86UA(';D:&5M86QT("5D(&YU;6)R:70N`%5U<R!S86QA
M<_5N82!P96%B('-I<V%L9&%M82!VY&AE;6%L="`E9"!S=75R=.1H=&4N`%5U
M<R!S86QA<_5N82!P96%B('-I<V%L9&%M82!VY&AE;2!K=6D@)60@=/QH:6MU
M="X`575S('-A;&%S]6YA(&5I('1O:&D@<VES86QD861A('3\:&EK=6ED+@!3
M:7-E<W1A='5D('-A;&%S]6YA9"!E:2!K;&%P:0!3:6YU(&UU=61A='5S960@
M;VX@<V%L=F5S=&%T=60N`%M(;W)D92!P<F]B;&5E;5T`6W)I9&$@)7,@)7,M
M<W1=`'1E;7!N86TH*2!E8F'U;FYE<W1U<R$`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]F<E]&
M4B\`````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<T,P`P,C`Q-C$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M87-S=V0O;&]C86QE+V9R7T92+TQ#7TU%4U-!1T53+P``````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0S`#`R,3<T-@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O9G)?1E(O3$-?34534T%'
M15,O<&%S<W=D+FUO````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-#0S,#0`,3`T,3<S-C(W
M-#,`,#(S-C$R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-X2!)4`````H0<``!P````D/0``,0H``"QZ````````\*(``$T`
M``#QH@``OP```#^C``!D````_Z,``+X```!DI```D````".E``!#````M*4`
M`#P```#XI0``*P```#6F```N````8:8``"D```"0I@``*````+JF``!%````
MXZ8``$<````IIP``2@```'&G``!'````O*<``$4````$J```2````$JH```Y
M````DZ@``$8```#-J```2````!2I```P````7:D``$4```".J0``1@```-2I
M``!,````&ZH``#0```!HJ@``,@```)VJ``!I````T*H``#`````ZJP``)0``
M`&NK``"(````D:L``$`````:K```]@```%NL``!*````4JT``"P```"=K0``
MA0```,JM``!(````4*X```X```"9K@``#P```*BN```-````N*X```@```#&
MK@``"P```,^N```,````VZX```0```#HK@``#````.VN```1````^JX``"4`
M```,KP``#P```#*O```+````0J\``!$```!.KP``#@```&"O```%````;Z\`
M`"@```!UKP``"````)ZO```*````IZ\``!4```"RKP``$@```,BO```+````
MVZ\``"<```#GKP``$P````^P```.````([````H````RL```#0```#VP```N
M````2[````X```!ZL```$0```(FP```-````F[````P```"IL```#0```+:P
M```&````Q+```!T```#+L```&P```.FP```M````!;$``!T````SL0``)```
M`%&Q```I````=K$``!D```"@L0``#P```+JQ```8````RK$```P```#CL0``
M&P```/"Q```.````#+(```X````;L@``"````"JR```)````,[(``$(````]
ML@``+@```("R```:````K[(``#(```#*L@``.````/VR``!4````-K,``%$`
M``"+LP``6@```-VS``!7````.+0``#0```"0M```#@```,6T```)````U+0`
M``T```#>M```!P```.RT```*````]+0```\```#_M```!0````^U```&````
M%;4``!$````<M0``"````"ZU```)````-[4```D```!!M0``#@```$NU```E
M````6K4``"````"`M0``$````*&U```/````LK4```H```#"M0```P```,VU
M```/````T;4``!0```#AM0``"0```/:U```-`````+8``!(````.M@``&0``
M`"&V```>````.[8```\```!:M@``"@```&JV```/````=;8```@```"%M@``
M)````(ZV```4````L[8``!8```#(M@``"````-^V``!.````Z+8``"T````W
MMP``'P```&6W```9````A;<```<```"?MP``#````*>W```L````M+<```X`
M``#AMP```P```/"W```+````]+<```<`````N```!P````BX```%````$+@`
M``4````6N```"@```!RX```#````)[@``!<````KN```"@```$.X```/````
M3K@```X```!>N```&````&VX```C````AK@```X```"JN```%````+FX```7
M````SK@``!<```#FN```%P```/ZX```3````%KD```\````JN0``#@```#JY
M```?````2;D``!T```!IN0``!P```(>Y```&````C[D```@```"6N0``#P``
M`)^Y```&````K[D```H```"VN0``$P```,&Y```+````U;D``!````#AN0``
M%0```/*Y```5````"+H```<````>N@``$````":Z```%````-[H``!4````]
MN@``$0```%.Z```,````9;H``#L```!RN@``.````*ZZ```)````Y[H```<`
M``#QN@``%````/FZ```#````#KL```4````2NP``$````!B[```)````*;L`
M`!,````SNP``.0```$>[```2````@;L``"<```"4NP``+````+R[```J````
MZ;L``"4````4O```"@```#J\```&````1;P```D```!,O```!P```%:\```O
M````7KP``#<```".O```+@```,:\``!5````];P``"T```!+O0``+0```'F]
M```M````I[T``$````#5O0``(P```!:^```C````.KX``"T```!>O@``,P``
M`(R^```5````P+X``!D```#6O@``*0```/"^```D````&K\``!$````_OP``
M"@```%&_```,````7+\``"(```!IOP``"@```(R_```0````E[\``!8```"H
MOP``%@```+^_```'````UK\```<```#>OP``%````.:_```*````^[\```@`
M```&P```)P````_````(````-\````<```!`P```!P```$C````&````4,``
M``4```!7P```!P```%W````&````9<````@```!LP```*0```'7````.````
MG\````H```"NP```!````+G````'````OL````D```#&P```!@```-#````1
M````U\````<```#IP```%@```/'````$````",$```@````-P0``!@```!;!
M```-````'<$```8````KP0``'@```#+!```1````4<$``"(```!CP0``%@``
M`(;!```(````G<$```T```"FP0``#````+3!```'````P<$```,```#)P0``
M`P```,W!```7````T<$``!,```#IP0``'0```/W!```(````&\(```0````D
MP@``"````"G"```(````,L(``$$````[P@``(````'W"```&````GL(```8`
M``"EP@``%0```*S"```8````PL(``"(```#;P@``+@```/["```=````+<,`
M`"$```!+PP``5````&W#```I````PL,```H```#LPP``!P```/?#```5````
M_\,```X````5Q```"@```"3$```/````+\0```T````_Q```#P```$W$```-
M````7<0```D```!KQ```%````'7$```&````BL0``!@```"1Q```'0```*K$
M```3````R,0``!$```#<Q```%````.[$```$`````\4```8````(Q0``#P``
M``_%```3````'\4``%0````SQ0``%````(C%```7````G<4```0```"UQ0``
M#@```+K%``!$````R<4```4````.Q@``!0```!3&```;````&L8``!H````V
MQ@``$0```%'&```1````8\8``!P```!UQ@``*@```)+&```0````O<8``"$`
M``#.Q@``)0```/#&```9````%L<```4````PQP``$P```#;'```2````2L<`
M``H```!=QP``#P```&C'```-````>,<``!$```"&QP``$P```)C'```,````
MK,<```8```"YQP``#````,#'```&````S<<``!<```#4QP``$````.S'```1
M````_<<```@````/R```!0```!C(```,````'L@``!`````KR```!0```#S(
M```-````0L@```8```!0R```!P```%?(```-````7\@``!````!MR```"0``
M`'[(```'````B,@```L```"0R```"P```)S(```'````J,@```<```"PR```
M%````+C(```)````S<@```H```#7R```&0```.+(```=````_,@```P````:
MR0``$````"?)```5````.,D```4```!.R0``)0```%3)```2````>LD``!,`
M``"-R0``*P```*')```[````S<D``"`````)R@``-@```"K*```0````8<H`
M``@```!RR@``#````'O*```&````B,H```0```"/R@``#@```)3*```0````
MH\H```H```"TR@``#0```+_*```>````S<H``!L```#LR@``(0````C+```>
M````*LL``!D```!)RP``'@```&/+```=````@LL``!L```"@RP``(````+S+
M```N````W<L``!<````,S```)@```"3,```P````2\P``!L```!\S```'@``
M`)C,```<````M\P``"8```#4S```*P```/O,```S````)\T``"8```!;S0``
M*P```(+-```X````KLT``!T```#GS0``%0````7.```O````&\X``!(```!+
MS@``(````%[.```I````?\X``!X```"IS@``(0```,C.```2````ZLX``*(`
M``#]S@``%@```*#/```C````M\\``"@```#;SP``*0````30```H````+M``
M`!\```!7T```%0```'?0```@````C=```"4```"NT```*````-30```M````
M_=```#`````KT0``D@```%S1```A````[]$``!8````1T@``'````"C2```F
M````1=(``"H```!LT@``00```)?2``!$````V=(```P````>TP``!P```"O3
M```'````,],```8````[TP``#0```$+3```0````4-,``!(```!ATP``$P``
M`'33```2````B-,```<```";TP``!````*/3```0````J-,```P```"YTP``
M#@```,;3```/````U=,``!,```#ETP``#0```/G3```H````!]0```,````P
MU```#0```#34```&````0M0``!$```!)U```%P```%O4```;````<]0```X`
M``"/U````@```)[4```%````H=0``!````"GU```!````+C4```-````O=0`
M``X```#+U````P```-K4```.````WM0```@```#MU```#P```/;4```/````
M!M4```<````6U0``#0```![5```0````+-4``!,````]U0``$P```%'5```+
M````9=4```8```!QU0``#````'C5```1````A=4``!D```"7U0``"P```+'5
M```-````O=4``"(```#+U0``&P```.[5```T````"M8```H````_U@``&```
M`$K6```9````8]8``!8```!]U@``+P```)36```B````Q-8```T```#GU@``
M!P```/76```4````_=8```L````2UP``(@```![7```O````0=<```L```!Q
MUP``"0```'W7```9````A]<```L```"AUP``%P```*W7```7````Q=<```D`
M``#=UP``%@```.?7```/````_M<``!8````.V```#@```"78```8````--@`
M``@```!-V```#0```%;8```F````9-@``$,```"+V```"````,_8```2````
MV-@```@```#KV```"P```/38```O`````-D```X````PV0``!0```#_9```&
M````1=D```,```!,V0``!P```%#9```$````6-D```H```!=V0``"@```&C9
M```/````<]D``!````"#V0``%P```)39```1````K-D``!<```"^V0``&0``
M`-;9```)````\-D```4```#ZV0``"P````#:```*````#-H```(````7V@``
M!0```!K:```-````(-H``!L````NV@``%P```$K:```)````8MH```X```!L
MV@``#0```'O:```2````B=H``#@```"<V@``(````-7:```(````]MH```X`
M``#_V@``>P````[;```8````BML``$````"CVP``$0```.3;```'````]ML`
M``4```#^VP``(`````3<```9````)=P``!,````_W```!P```%/<```'````
M6]P```@```!CW```!@```&S<```&````<]P``!````!ZW```#P```(O<```0
M````F]P```\```"LW```"P```+S<```/````R-P```P```#8W```#P```.7<
M```'````]=P```H```#]W```!@````C=```.````#]T```P````>W0``*```
M`"O=```/````5-T```@```!DW0``%@```&W=```(````A-T``!,```"-W0``
M'@```*'=```A````P-T``"````#BW0``&0````/>```7````'=X``"4````U
MW@``%P```%O>```>````<]X``"8```"2W@``!````+G>```;````OMX```T`
M``#:W@``#````.C>```#````]=X```@```#YW@``"@````+?```,````#=\`
M``L````:WP``$````";?```,````-]\```0```!$WP``$P```$G?```4````
M7=\```P```!RWP``"0```'_?```.````B=\```L```"8WP``&P```*3?```'
M````P-\```<```#(WP``"@```-#?```-````V]\```D```#IWP``!````//?
M```%````^-\```,```#^WP``&`````+@```*````&^````0````FX```)@``
M`"O@```.````4N```'P```!AX```%0```-[@```%````].````<```#ZX```
M#`````+A```(````#^$```H````8X0``!@```"/A```(````*N$``!8````S
MX0``$@```$KA```"````7>$```8```!@X0``!@```&?A```4````;N$```T`
M``"#X0``$````)'A```;````HN$```0```"^X0``"0```,/A```0````S>$`
M``D```#>X0``"0```.CA```%````\N$```4```#XX0``&@```/[A```(````
M&>(```8````BX@``&0```"GB```.````0^(``"(```!2X@``!P```'7B```'
M````?>(```X```"%X@``!0```)3B```)````FN(```H```"DX@```@```*_B
M```&````LN(```T```"YX@``"0```,?B```&````T>(``!(```#8X@``"0``
M`.OB```'````]>(``!0```#]X@``'0```!+C```1````,.,```8```!"XP``
M"@```$GC```$````5.,```D```!9XP``"````&/C```1````;.,``!$```!^
MXP``"0```)#C```&````FN,```T```"AXP``!@```*_C```$````MN,``#D`
M``"[XP``/0```/7C```Z````,^0``!X```!NY```!0```(WD```.````D^0`
M``0```"BY```!@```*?D```A````KN0``!4```#0Y```!@```.;D```$````
M[>0``!$```#RY```!@````3E``"@````"^4```H```"LY0``(@```+?E```$
M````VN4``"4```#?Y0``!0````7F```=````"^8```0````IY@``#````"[F
M```*````.^8```@```!&Y@``"0```$_F```%````6>8``!L```!?Y@``.@``
M`'OF```P````MN8``#4```#GY@``*0```!WG```N````1^<``$<```!VYP``
M.````+[G```I````]^<``#\````AZ```+@```&'H```M````D.@``!\```"^
MZ```#P```-[H```2````[N@```L````!Z0``)@````WI```I````-.D``"0`
M``!>Z0``)@```(/I```(````JND```H```"SZ0``"0```+[I```'````R.D`
M`"````#0Z0``(````/'I```F````$NH```H````YZ@``&0```$3J```I````
M7NH``!8```"(Z@``$@```)_J```'````LNH```H```"ZZ@``#````,7J```/
M````TNH``!````#BZ@``0````//J``!P````-.L``&8```"EZP``#@````SL
M```)````&^P```H````E[```$@```##L```3````0^P```P```!7[```!@``
M`&3L```/````:^P``!(```![[```$````([L```1````G^P``!(```"Q[```
M'````,3L```C````X>P``&H````%[0``#P```'#M```%````@.T``!````"&
M[0``"0```)?M```$````H>T```L```"F[0``&@```++M```4````S>T```P`
M``#B[0``#````._M```/````_.T``!4````,[@``*0```"+N```J````3.X`
M`"8```!W[@``)P```)[N```I````QNX``"H```#P[@``&0```!OO``!"````
M->\``!$```!X[P``$@```(KO```3````G>\``!0```"Q[P``#P```,;O```6
M````UN\``!<```#M[P``$`````7P```1````%O```#0````H\```$P```%WP
M```2````<?```#4```"$\```%````+KP```'````S_````P```#7\```(```
M`.3P```4````!?$``!$````:\0``%P```"SQ```<````1/$``!,```!A\0``
M%````'7Q```:````BO$``!$```"E\0``&@```+?Q```>````TO$``!H```#Q
M\0``$P````SR```5````(/(``!$````V\@``%P```$CR```4````8/(``!<`
M``!U\@``%0```(WR```)````H_(``!D```"M\@``!````,?R```'````S/(`
M``L```#4\@``$0```.#R```&````\O(```8```#Y\@``!@````#S```%````
M!_,```<````-\P``!P```!7S```%````'?,``!8````C\P``!@```#KS```&
M````0?,```0```!(\P``!````$WS```'````4O,```X```!:\P``#````&GS
M```,````=O,```T```"#\P``"@```)'S```.````G/,```4```"K\P``*```
M`+'S```.````VO,```P```#I\P``#P```/;S```*````!O0```@````1]```
M"0```!KT```K````)/0```0```!0]```"````%7T```F````7O0``!(```"%
M]```#P```)CT```&````J/0```H```"O]```!P```+KT```(````PO0``"``
M``#+]```"0```.ST```,````]O0```T````#]0``#@```!'U```6````(/4`
M`!$````W]0``!@```$GU```#````4/4```8```!4]0``&0```%OU```'````
M=?4```0```!]]0``"P```(+U```+````CO4```<```":]0``!P```*+U```6
M````JO4```T```#!]0``#0```,_U```*````W?4``!````#H]0``#P```/GU
M```1````"?8``!<````;]@``"@```#/V```1````/O8```@```!0]@``!```
M`%GV```/````7O8``#H```!N]@``!0```*GV```,````K_8``!X```"\]@``
M#@```-OV```0````ZO8```L```#[]@``#`````?W```)````%/<```<````>
M]P``"@```";W```)````,?<```X````[]P``$````$KW```:````6_<```H`
M``!V]P``"0```('W```4````B_<```H```"@]P``#````*OW```/````N/<`
M``@```#(]P``!@```-'W```'````V/<```L```#@]P``1P```.SW```-````
M-/@```D```!"^```!````$SX```#````4?@``!,```!5^```$P```&GX```3
M````??@```H```"1^````@```)SX```$````G_@``"4```"D^````P```,KX
M```%````SO@``"H```#4^```"@```/_X```%````"OD```0````0^0``"@``
M`!7Y```-````(/D``$`````N^0``$P```&_Y```&````@_D```@```"*^0``
M"````)/Y```$````G/D```4```"A^0``:````*?Y```)````$/H```P````:
M^@``!0```"?Z```&````+?H``!L````T^@``+P```%#Z```0````@/H```H`
M``"1^@``#P```)SZ```*````K/H```D```"W^@``$P```,'Z```;````U?H`
M`!@```#Q^@``%P````K[```.````(OL```,````Q^P``!P```#7[```(````
M/?L```<```!&^P``"@```$[[```+````6?L``"T```!E^P``%0```)/[```P
M````J?L``"0```#:^P``!P```/_[``!1````!_P``!````!9_```#````&K\
M```-````=_P``!H```"%_```2@```*#\```9````Z_P```8````%_0``&@``
M``S]```&````)_T```8````N_0``'P```#7]```&````5?T```D```!<_0``
M&````&;]```7````?_T``"@```"7_0``!@```,#]```-````Q_T``"(```#5
M_0``5P```/C]```3````4/X``",```!D_@``$P```(C^```"````G/X```L`
M``"?_@``"````*O^```-````M/X```H```#"_@``!@```,W^```'````U/X`
M`!0```#<_@``!@```/'^```(````^/X```X````!_P``!P```!#_```*````
M&/\```L````C_P``!P```"__```,````-_\```T```!$_P``#````%+_```)
M````7_\```D```!I_P``"@```'/_```'````?O\```D```"&_P``!P```)#_
M```*````F/\``!L```"C_P``$@```+__```*````TO\```D```#=_P``$```
M`.?_```'````^/\``!(```````$`!````!,``0`'````&``!``4````@``$`
M!0```"8``0`+````+``!`!0````X``$`$0```$T``0`:````7P`!`!8```!Z
M``$`%````)$``0`7````I@`!`!@```"^``$`'````-<``0`9````]``!``<`
M```.`0$`!0```!8!`0`-````'`$!``P````J`0$`"````#<!`0`7````0`$!
M``L```!8`0$`#0```&0!`0`3````<@$!``0```"&`0$`"@```(L!`0`$````
ME@$!``T```";`0$`#````*D!`0`%````M@$!``D```"\`0$`!0```,8!`0`'
M````S`$!``4```#4`0$`!````-H!`0`"````WP$!`#@```#B`0$`+````!L"
M`0`2````2`(!`"D```!;`@$`,@```(4"`0`*````N`(!`#8```##`@$`+```
M`/H"`0`5````)P,!`"X````]`P$`,P```&P#`0`S````H`,!`#@```#4`P$`
M#P````T$`0`8````'00!`#L````V!`$`$````'($`0`/````@P0!`!0```"3
M!`$`$P```*@$`0`5````O`0!`!0```#2!`$`$@```.<$`0`4````^@0!`!4`
M```/!0$`+0```"4%`0`M````4P4!`#$```"!!0$`+0```+,%`0`N````X04!
M`"\````0!@$`+````$`&`0!B````;08!`!,```#0!@$`"````.0&`0`(````
M[08!`!L```#V!@$`*P```!('`0`A````/@<!`!H```!@!P$`"0```'L'`0!%
M````A0<!`$$```#+!P$`!`````T(`0`3````$@@!`!0````F"`$`#@```#L(
M`0`3````2@@!`!@```!>"`$`!@```'<(`0`)````?@@!``H```"("`$`#P``
M`),(`0`0````HP@!``<```"T"`$`#@```+P(`0`%````RP@!`!L```#1"`$`
M!@```.T(`0`(````]`@!``8```#]"`$`%`````0)`0`1````&0D!``X````K
M"0$`.````#H)`0`"````<PD!``8```!V"0$`#@```'T)`0`:````C`D!``4`
M``"G"0$`!P```*T)`0`.````M0D!``8```#$"0$`#0```,L)`0`$````V0D!
M`"D```#>"0$`%P````@*`0`?````(`H!`%P```!`"@$`%````)T*`0`^````
ML@H!`!\```#Q"@$`$````!$+`0`'````(@L!``X````J"P$`"````#D+`0`,
M````0@L!``P```!/"P$`$P```%P+`0`*````<`L!`!T```!["P$`&0```)D+
M`0`%````LPL!`!$```"Y"P$`$0```,L+`0`D````W0L!`!4````"#`$`$@``
M`!@,`0`.````*PP!`!D````Z#`$`"````%0,`0`)````70P!``T```!G#`$`
M"@```'4,`0`'````@`P!``\```"(#`$`!@```)@,`0`+````GPP!``H```"K
M#`$`!P```+8,`0`(````O@P!``4```#'#`$`'P```,T,`0`&````[0P!`!``
M``#T#`$`"`````4-`0`-````#@T!`"(````<#0$`"````#\-`0`7````2`T!
M`!(```!@#0$`+````',-`0`O````H`T!`"P```#0#0$`*@```/T-`0`K````
M*`X!`"P```!4#@$`&@```($.`0`)````G`X!``H```"F#@$`%0```+$.`0`%
M````QPX!`!0```#-#@$`!````.(.`0`0````YPX!``8```#X#@$`!P```/\.
M`0`>````!P\!`"@````F#P$`"@```$\/`0`<````6@\!`!H```!W#P$`#P``
M`)(/`0`4````H@\!``0```"W#P$`!````+P/`0`+````P0\!``4```#-#P$`
M!@```-,/`0`(````V@\!``8```#C#P$`"@```.H/`0`;````]0\!`#0````1
M$`$`-````$80`0`@````>Q`!`"D```"<$`$`(````,80`0!!````YQ`!`!H`
M```I$0$`*````$01`0`I````;1$!`%$```"7$0$`+P```.D1`0`B````&1(!
M``8````\$@$`"````$,2`0`%````3!(!``@```!2$@$`&0```%L2`0`9````
M=1(!`"H```"/$@$`(P```+H2`0`N````WA(!`#0````-$P$`"````$(3`0`7
M````2Q,!``H```!C$P$`!P```&X3`0`A````=A,!`!````"8$P$`#@```*D3
M`0`+````N!,!``<```#$$P$`$P```,P3`0`(````X!,!``L```#I$P$`"@``
M`/43`0`4`````!0!``\````5%`$`,@```"44`0`+````6!0!``4```!D%`$`
M!0```&H4`0`7````<!0!``\```"(%`$`!````)@4`0`*````G10!``D```"H
M%`$`"P```+(4`0`-````OA0!``P```#,%`$`#@```-D4`0`%````Z!0!``0`
M``#N%`$`#0```/,4`0`R`````14!`$4````T%0$`%P```'H5`0`>````DA4!
M`!0```"Q%0$`!0```,85`0`4````S!4!``<```#A%0$`#@```.D5`0`J````
M^!4!``8````C%@$`#````"H6`0`-````-Q8!`!$```!%%@$`"P```%<6`0`V
M````8Q8!``H```":%@$`(@```*46`0`+````R!8!``\```#4%@$`,@```.06
M`0`E````%Q<!`#`````]%P$`,0```&X7`0`M````H!<!`#\```#.%P$`/0``
M``X8`0`V````3!@!``X```"#&`$`!0```)(8`0`.````F!@!`!,```"G&`$`
M!P```+L8`0`:````PQ@!``@```#>&`$`$0```.<8`0`'````^1@!`!0````!
M&0$`&````!89`0`'````+QD!``4````W&0$`#````#T9`0`,````2AD!`!(`
M``!7&0$`!````&H9`0`'````;QD!``H```!W&0$`"P```((9`0`,````CAD!
M``X```";&0$`#@```*H9`0`%````N1D!``4```"_&0$`+@```,49`0`F````
M]!D!`",````;&@$``P```#\:`0`2````0QH!``8```!6&@$`'@```%T:`0`8
M````?!H!`"4```"5&@$`#0```+L:`0`)````R1H!``,```#3&@$`!P```-<:
M`0`*````WQH!``(```#J&@$`#````.T:`0`5````^AH!``L````0&P$`&0``
M`!P;`0`@````-AL!`!(```!7&P$`!0```&H;`0`*````<!L!`!4```![&P$`
M$@```)$;`0`,````I!L!``0```"Q&P$`!P```+8;`0`)````OAL!``P```#(
M&P$`4@```-4;`0`7````*!P!`"0```!`'`$`$@```&4<`0`'````>!P!``8`
M``"`'`$`#@```(<<`0`B````EAP!`!T```"Y'`$`#````-<<`0`-````Y!P!
M`!4```#R'`$`$@````@=`0`/````&QT!`!0````K'0$`&P```$`=`0`0````
M7!T!`&D```!M'0$`&@```-<=`0`7````\AT!`"<````*'@$`&@```#(>`0`7
M````31X!`!L```!E'@$`&0```($>`0`?````FQX!`!,```"['@$`"````,\>
M`0`'````V!X!``@```#@'@$`"0```.D>`0`5````\QX!``T````)'P$`(P``
M`!<?`0`3````.Q\!``,```!/'P$`1@```%,?`0`_````FA\!`#<```#:'P$`
M5P```!(@`0`%````:B`!`!\```!P(`$`+P```)`@`0`*````P"`!``@```#+
M(`$`#0```-0@`0`M````XB`!``0````0(0$`3P```!4A`0`E````92$!`!P`
M``"+(0$`"P```*@A`0`?````M"$!`!T```#4(0$`)0```/(A`0`@````&"(!
M`"0````Y(@$`(````%XB`0`+````?R(!``<```"+(@$`#0```),B`0`,````
MH2(!`!<```"N(@$`!@```,8B`0`Y````S2(!``P````'(P$`!P```!0C`0`9
M````'",!``D````V(P$`$P```$`C`0`)````5",!``0```!>(P$`$````&,C
M`0`*````=",!``@```!_(P$`"````(@C`0`$````D2,!``L```"6(P$`#```
M`*(C`0`2````KR,!`!$```#"(P$`#````-0C`0`:````X2,!``\```#\(P$`
M!P````PD`0`-````%"0!`!0````B)`$`#@```#<D`0`,````1B0!`!L```!3
M)`$`+````&\D`0`3````G"0!`!P```"P)`$`*````,TD`0`&````]B0!``<`
M``#])`$`$P````4E`0`%````&24!``0````?)0$`%P```"0E`0`*````/"4!
M``P```!')0$`"0```%0E`0`&````7B4!``D```!E)0$`"````&\E`0`)````
M>"4!``H```"")0$`$0```(TE`0`&````GR4!`!@```"F)0$`#@```+\E`0`.
M````SB4!``T```#=)0$`"P```.LE`0`=````]R4!``L````5)@$``@```"$F
M`0`<````)"8!``<```!!)@$`!@```$DF`0!E````4"8!``D```"V)@$`!P``
M`,`F`0`F````R"8!`#@```#O)@$`&@```"@G`0`J````0R<!`#L```!N)P$`
M*````*HG`0`T````TR<!`!D````(*`$`%0```"(H`0`%````."@!``<````^
M*`$`"````$8H`0`'````3R@!``4```!7*`$`!P```%TH`0`.````92@!``D`
M``!T*`$`!@```'XH`0`(````A2@!``L```".*`$`!P```)HH`0`(````HB@!
M``<```"K*`$`%@```+,H`0`)````RB@!``8```#4*`$`"P```-LH`0`<````
MYR@!`!0````$*0$`!P```!DI`0`1````(2D!``@````S*0$`"````#PI`0`%
M````12D!`!````!+*0$`$````%PI`0`&````;2D!`!D```!T*0$`"@```(XI
M`0`<````F2D!``<```"V*0$`!0```+XI`0`0````Q"D!`!0```#5*0$`"P``
M`.HI`0`-````]BD!`!@````$*@$`%P```!TJ`0`$````-2H!``D````Z*@$`
M"@```$0J`0`'````3RH!``(```!7*@$`#@```%HJ`0`(````:2H!`!\```!R
M*@$`/@```)(J`0`C````T2H!`#@```#U*@$`,0```"XK`0`G````8"L!`&0`
M``"(*P$`%````.TK`0!5`````BP!`#@```!8+`$`2@```)$L`0!;````W"P!
M`"@````X+0$`.````&$M`0`H````FBT!`"P```##+0$`)P```/`M`0`;````
M&"X!`#X````T+@$`J0$``',N`0`H````'3`!`",```!&,`$`%P```&HP`0!(
M````@C`!`(4```#+,`$`,````%$Q`0!!````@C$!`%L```#$,0$`20```"`R
M`0`=````:C(!`!@```"(,@$`(0```*$R`0`?````PS(!`"L```#C,@$`(0``
M``\S`0`G````,3,!`!T```!9,P$`$0```'<S`0`S````B3,!`"4```"],P$`
M)P```.,S`0`@````"S0!`!\````L-`$`,````$PT`0!I````?30!`"L```#G
M-`$`,@```!,U`0`Q````1C4!`$$```!X-0$`,P```+HU`0`E````[C4!`#T`
M```4-@$`90```%(V`0!-````N#8!`"\````&-P$`+@```#8W`0`P````93<!
M`%0```"6-P$`@P```.LW`0!:````;S@!`$@```#*.`$`2@```!,Y`0`R````
M7CD!`"\```"1.0$`+````,$Y`0`M````[CD!`'$````<.@$`;P```(XZ`0"S
M````_CH!`!<```"R.P$`)0```,H[`0`R````\#L!`"D````C/`$`/@```$T\
M`0`B````C#P!`%(```"O/`$`)0````(]`0`+````*#T!`+$````T/0$`10``
M`.8]`0`A````+#X!`"X```!./@$`,````'T^`0`E````KCX!`!P```#4/@$`
M,0```/$^`0`'````(S\!``<````K/P$`!````#,_`0`-````.#\!``L```!&
M/P$`#@```%(_`0`+````83\!``4```!M/P$`$````',_`0`"````A#\!`%D`
M``"'/P$`!0```.$_`0`2````YS\!``0```#Z/P$`!P```/\_`0`(````!T`!
M``4````00`$``P```!9``0`0````&D`!``H````K0`$`#````#9``0`3````
M0T`!``T```!70`$``@```&5``0`'````:$`!``8```!P0`$`%````'=``0`,
M````C$`!`!@```"90`$`!@```+)``0`2````N4`!``P```#,0`$``P```-E`
M`0`J````W4`!``0````(00$`!@````U!`0`'````%$$!`!\````<00$`-0``
M`#Q!`0`N````<D$!`"\```"A00$`%P```-%!`0`@````Z4$!`!L````*0@$`
M&````"9"`0`D````/T(!`!\```!D0@$`&@```(1"`0`@````GT(!`!H```#`
M0@$`,@```-M"`0`O````#D,!`!H````^0P$`*P```%E#`0`?````A4,!`",`
M``"E0P$`'P```,E#`0`:````Z4,!`"4````$1`$`)@```"I$`0`E````440!
M`"0```!W1`$`&````)Q$`0`=````M40!`"0```#31`$`&````/A$`0`B````
M$44!`!4````T10$`)0```$I%`0`\````<$4!`!\```"M10$`(P```,U%`0`?
M````\44!`"`````11@$`&@```#)&`0`8````348!`"8```!F1@$`'@```(U&
M`0`I````K$8!`!X```#61@$`"0```/5&`0`,````_T8!`!<````,1P$`+P``
M`"1'`0`D````5$<!``<```!Y1P$`#P```(%'`0`4````D4<!``X```"F1P$`
M#0```+5'`0`D````PT<!``4```#H1P$`!P```.Y'`0`B````]D<!`"4````9
M2`$`$P```#](`0`:````4T@!`!T```!N2`$`&@```(Q(`0`'````IT@!`,<`
M``"O2`$`"P```'=)`0`5````@TD!``P```"920$`!@```*9)`0`)````K4D!
M``L```"W20$`#0```,-)`0`=````T4D!`!<```#O20$`!@````=*`0`S````
M#DH!`!,```!"2@$`$P```%9*`0`'````:DH!``8```!R2@$`#P```'E*`0`'
M````B4H!`#(```"12@$`(0```,1*`0`3````YDH!``P```#Z2@$`$0````=+
M`0`R````&4L!``X```!,2P$`#P```%M+`0`0````:TL!``@```!\2P$`'0``
M`(5+`0`)````HTL!``H```"M2P$`!0```+A+`0`4````ODL!``H```#32P$`
M'0```-Y+`0`(````_$L!`!\````%3`$`"````"5,`0`:````+DP!`"<```!)
M3`$`!@```'%,`0`5````>$P!``<```".3`$`"````)9,`0`)````GTP!`#\`
M``"I3`$`!P```.E,`0`/````\4P!``X````!30$`$````!!-`0`)````(4T!
M``D````K30$`"````#5-`0`3````/DT!``<```!230$`&0```%I-`0`*````
M=$T!`!<```!_30$`%````)=-`0`*````K$T!``P```"W30$`%P```,1-`0`$
M````W$T!`"H```#A30$`$0````Q.`0`'````'DX!``D````F3@$``@```#!.
M`0`0````,TX!`!@```!$3@$`"P```%U.`0`#````:4X!``@```!M3@$`!@``
M`'9.`0`'````?4X!``T```"%3@$`"P```)-.`0`4````GTX!`!4```"T3@$`
M#@```,I.`0`O````V4X!`"`````)3P$`'````"I/`0`,````1T\!`#$```!4
M3P$`!0```(9/`0`2````C$\!`#\```"?3P$`$@```-]/`0`*````\D\!``8`
M``#]3P$`!`````10`0`$````"5`!``H````.4`$`$P```!E0`0`%````+5`!
M``8````S4`$`!@```#I0`0`)````05`!``0```!+4`$`#````%!0`0`*````
M75`!`"````!H4`$`!0```(E0`0`8````CU`!`!D```"H4`$`'P```,)0`0`=
M````XE`!`!$`````40$``@```!)1`0`$````%5$!``H````:40$`!@```"51
M`0`%````+%$!``,````R40$`#````#91`0!%````0U$!`!H```")40$`-0``
M`*11`0`E````VE$!`"@`````4@$`4P```"E2`0`9````?5(!`'(```"74@$`
M(`````I3`0`U````*U,!`"$```!A4P$`10```(-3`0`P````R5,!`",```#Z
M4P$`'P```!Y4`0`H````/E0!`"D```!G5`$`)@```)%4`0`E````N%0!`"@`
M``#>5`$`*`````=5`0`B````,%4!`"$```!350$`,````'55`0`2````IE4!
M`!,```"Y50$`$````,U5`0!Y````WE4!``D```!85@$`<@```&)6`0!S````
MU58!`'P```!)5P$`*P```,97`0!3````\E<!`!<```!&6`$`%@```%Y8`0`/
M````=5@!`&4```"%6`$`'P```.M8`0!1````"UD!`#<```!=60$`-@```)59
M`0`V````S%D!`#X````#6@$`00```$):`0!#````A%H!`'P```#(6@$`0```
M`$5;`0`^````AEL!`$````#%6P$`0@````9<`0`Y````25P!`!\```"#7`$`
M0````*-<`0`?````Y%P!`!P````$70$`40```"%=`0`4````<UT!``H```"(
M70$`!0```)-=`0`&````F5T!``@```"@70$`!0```*E=`0`2````KUT!`!``
M``#"70$`$P```--=`0`=````YUT!``\````%7@$`#P```!5>`0`$````)5X!
M``D````J7@$`"P```#1>`0`'````0%X!``4```!(7@$`%````$Y>`0`'````
M8UX!``@```!K7@$`#P```'1>`0`(````A%X!``P```"-7@$`#P```)I>`0`&
M````JEX!`!0```"Q7@$`!@```,9>`0`,````S5X!`!4```#:7@$`"````/!>
M`0`$````^5X!``H```#^7@$`!`````E?`0`&````#E\!``<````57P$`!```
M`!U?`0`'````(E\!`!D````J7P$``@```$1?`0`"````1U\!``D```!*7P$`
M!@```%1?`0`5````6U\!``8```!Q7P$`)P```'A?`0`"````H%\!``0```"C
M7P$`"P```*A?`0`)````M%\!``\```"^7P$`$P```,Y?`0`'````XE\!``<`
M``#J7P$`!@```/)?`0`&````^5\!`!``````8`$`$@```!%@`0`"````)&`!
M``8````G8`$`"0```"Y@`0`S````.&`!`"(```!L8`$`!P```(]@`0`'````
MEV`!``<```"?8`$`"P```*=@`0`%````LV`!``(```"Y8`$`"P```+Q@`0"'
M`0``R&`!`%P```!08@$`O````*UB`0!E````:F,!`-(```#08P$`G````*-D
M`0!+````0&4!`#\```",90$`+P```,QE`0`U````_&4!`"\````R9@$`+@``
M`&)F`0!/````D68!`%(```#A9@$`3P```#1G`0!*````A&<!`%$```#/9P$`
M4P```"%H`0`Z````=6@!`$<```"P:`$`4@```/AH`0`W````2VD!`%H```"#
M:0$`1@```-YI`0!2````)6H!`#D```!X:@$`/0```+)J`0!L````\&H!`#4`
M``!=:P$`*0```)-K`0":````O6L!`%$```!8;`$`&`$``*IL`0!1````PVT!
M`#$````5;@$`E````$=N`0!2````W&X!`!(````O;P$`&P```$)O`0`0````
M7F\!``X```!O;P$`"0```'YO`0`'````B&\!``,```"0;P$`"P```)1O`0`6
M````H&\!`"4```"W;P$`%````-UO`0`+````\F\!`!$```#^;P$`$P```!!P
M`0`%````)'`!`#$````J<`$`$P```%QP`0`1````<'`!`!X```""<`$`#P``
M`*%P`0`+````L7`!`"@```"]<`$`&P```.9P`0`2`````G$!``H````5<0$`
M#0```"!Q`0`V````+G$!``T```!E<0$`%P```'-Q`0`,````BW$!`!````"8
M<0$`%0```*EQ`0`'````OW$!`"<```#'<0$`(0```.]Q`0`U````$7(!`#$`
M``!'<@$`(````'ER`0`O````FG(!`!T```#*<@$`#````.AR`0`4````]7(!
M`!(````*<P$`&P```!US`0`0````.7,!`!````!*<P$`"0```%MS`0`*````
M97,!`&(```!P<P$`1````--S`0`@````&'0!`#X````Y=`$`30```'AT`0!N
M````QG0!`&H````U=0$`=````*!U`0!P````%78!`$$```"&=@$`#P```,AV
M`0`/````V'8!`!4```#H=@$`#@```/YV`0`0````#7<!`!@````>=P$`!0``
M`#=W`0`&````/7<!`!<```!$=P$`"P```%QW`0`*````:'<!``T```!S=P$`
M#0```(%W`0`T````CW<!`#````#$=P$`%@```/5W`0`/````#'@!``<````<
M>`$`!P```"1X`0`6````+'@!`"0```!#>`$`#0```&AX`0`9````=G@!`!\`
M``"0>`$`'P```+!X`0`E````T'@!`!\```#V>`$`$P```!9Y`0`;````*GD!
M`!$```!&>0$`*````%AY`0`>````@7D!`!\```"@>0$`%@```,!Y`0!A````
MUWD!`#`````Y>@$`)0```&IZ`0`R````D'H!``<```##>@$`$0```,MZ`0!#
M````W7H!``X````A>P$`!````#![`0`+````-7L!``<```!!>P$`!P```$E[
M`0`%````47L!``<```!7>P$`#````%][`0`$````;'L!`"(```!Q>P$`$```
M`)1[`0`6````I7L!`!````"\>P$`+````,U[`0`Q````^GL!``L````L?`$`
M(0```#A\`0`<````6GP!`"$```!W?`$`'P```)E\`0`.````N7P!`!(```#(
M?`$`#P```-M\`0`D````ZWP!`",````0?0$`!P```#1]`0`&````/'T!``@`
M``!#?0$`#0```$Q]`0`'````6GT!``L```!B?0$`$@```&Y]`0`+````@7T!
M`!0```"-?0$`%P```*)]`0`;````NGT!``@```#6?0$`%````-]]`0`%````
M]'T!`!0```#Z?0$`&0````]^`0`0````*7X!`$T````Z?@$`00```(A^`0`)
M````RGX!``<```#4?@$`%````-Q^`0`#````\7X!``4```#U?@$`#P```/M^
M`0`)````"W\!`!4````5?P$`20```"M_`0`3````=7\!`"X```")?P$`-0``
M`+A_`0`W````[G\!`#(````F@`$`"@```%F``0`$````9(`!``D```!I@`$`
M"````'.``0`P````?(`!`#<```"M@`$`+P```.6``0!>````%8$!`"\```!T
M@0$`+P```*2!`0`O````U($!`%0````$@@$`,P```%F"`0`U````C8(!`"\`
M``##@@$`-0```/."`0`;````*8,!`!X```!%@P$`+@```&2#`0`G````DX,!
M`!0```"[@P$`"P```-"#`0`,````W(,!`"$```#I@P$`#P````N$`0`/````
M&X0!`!T````KA`$`(0```$F$`0`'````:X0!``<```!SA`$`$P```'N$`0`*
M````CX0!``<```":A`$`+````**$`0`-````SX0!``<```#=A`$`"````.6$
M`0`&````[H0!``4```#UA`$`"````/N$`0`'````!(4!``P````,A0$`*@``
M`!F%`0`3````1(4!``P```!8A0$`!````&6%`0`'````:H4!``<```!RA0$`
M!P```'J%`0`9````@H4!``4```"<A0$`$@```**%`0`(````M84!``@```"^
MA0$``P```,>%`0`&````RX4!``8```#2A0$`*@```-F%`0`1````!(8!`#$`
M```6A@$`(````$B&`0`(````:88!``T```!RA@$`#````("&`0`'````C88!
M`!(```"5A@$``P```*B&`0!!````K(8!`!D```#NA@$`,`````B'`0`&````
M.8<!``4```!`AP$`"````$:'`0`(````3X<!`&(```!8AP$`*@```+N'`0`&
M````YH<!``<```#MAP$`'@```/6'`0`J````%(@!`"X````_B`$`-P```&Z(
M`0`J````IH@!`#P```#1B`$`;P````Z)`0`S````?HD!``@```"RB0$`!P``
M`+N)`0`8````PXD!``L```#<B0$`%````.B)`0`8````_8D!`"(````6B@$`
M&````#F*`0`:````4HH!`!4```!MB@$`$P```(.*`0`'````EXH!`!D```"?
MB@$`'0```+F*`0`5````UXH!`!H```#MB@$`&@````B+`0`%````(XL!``@`
M```IBP$`'````#*+`0`B````3XL!`'(```!RBP$`(@```.6+`0`B````"(P!
M``0````KC`$`$0```#",`0`^````0HP!``4```"!C`$`!0```(>,`0`:````
MC8P!`!L```"HC`$`%P```,2,`0`;````W(P!`"<```#XC`$`-@```""-`0`.
M````5XT!`"H```!FC0$`+@```)&-`0`=````P(T!``<```#>C0$`'@```.:-
M`0`9````!8X!`!4````?C@$`)````#6.`0`?````6HX!`!<```!ZC@$`$P``
M`)*.`0`1````IHX!``8```"XC@$`#P```+^.`0`'````SXX!``H```#7C@$`
M&````.*.`0`1````^XX!``@````-CP$`!P```!:/`0`3````'H\!`!<````R
MCP$`!@```$J/`0`1````48\!``0```!CCP$`"````&B/`0`.````<8\!`!@`
M``"`CP$`"P```)F/`0`+````I8\!``P```"QCP$`"0```+Z/`0`'````R(\!
M``<```#0CP$`&0```-B/`0`+````\H\!``H```#^CP$`'`````F0`0`B````
M)I`!``T```!)D`$`&0```%>0`0`C````<9`!``4```"5D`$`(````)N0`0`5
M````O)`!`!@```#2D`$`+0```.N0`0`_````&9$!`"0```!9D0$`/````'Z1
M`0`1````NY$!``H```#-D0$`"0```-B1`0`/````XI$!``8```#RD0$`%0``
M`/F1`0`3````#Y(!``H````CD@$`#0```"Z2`0`B````/)(!`"0```!?D@$`
M+@```(22`0`G````LY(!`"````#;D@$`)````/R2`0`D````(9,!`"H```!&
MDP$`)0```'&3`0`O````EY,!`!\```#'DP$`,@```.>3`0`U````&I0!`"D`
M``!0E`$`+````'J4`0`C````IY0!`#$```#+E`$`,0```/V4`0`V````+Y4!
M`"L```!FE0$`,0```)*5`0!!````Q)4!`"4````&E@$`(P```"R6`0!#````
M4)8!`!L```"4E@$`)P```+"6`0`Q````V)8!`",````*EP$`*0```"Z7`0`:
M````6)<!`+,```!SEP$`'P```">8`0`J````1Y@!`"X```!RF`$`,````*&8
M`0`M````TI@!`#(`````F0$`)0```#.9`0`K````69D!`#L```"%F0$`/```
M`,&9`0`\````_ID!`$(````[F@$`L@```'Z:`0`F````,9L!`!T```!8FP$`
M)@```':;`0`R````G9L!`#<```#0FP$`1@````B<`0!/````3YP!``P```"?
MG`$`!````*R<`0`%````L9P!``4```"WG`$`#0```+V<`0`0````RYP!`!4`
M``#<G`$`%P```/*<`0`9````"IT!``<````DG0$`!````"R=`0`2````,9T!
M``X```!$G0$`&@```%.=`0`6````;IT!`!4```"%G0$`#0```)N=`0`Y````
MJ9T!``8```#CG0$`$P```.J=`0`&````_IT!`!,````%G@$`&0```!F>`0`=
M````,YX!`!(```!1G@$``@```&2>`0`+````9YX!`!8```!SG@$`!````(J>
M`0`1````CYX!`!0```"AG@$`!````+:>`0`5````NYX!``@```#1G@$`$```
M`-J>`0`6````ZYX!``8````"GP$`$@````F?`0`3````')\!`!8````PGP$`
M%P```$>?`0`+````7Y\!``<```!KGP$`$P```'.?`0`8````AY\!`"````"@
MGP$`$@```,&?`0`2````U)\!`"(```#GGP$`)0````J@`0!%````,*`!`!$`
M``!VH`$`(0```(B@`0`;````JJ`!`!H```#&H`$`3P```.&@`0`U````,:$!
M`!(```!GH0$`"````'JA`0`3````@Z$!``L```"7H0$`-````*.A`0`T````
MV*$!``T````-H@$`#@```!NB`0`H````*J(!`!$```!3H@$`$@```&6B`0`2
M````>*(!``H```"+H@$`&````):B`0`3````KZ(!`!L```##H@$`$@```-^B
M`0`1````\J(!``@````$HP$`$`````VC`0`L````'J,!`&(```!+HP$`"0``
M`*ZC`0`6````N*,!``L```#/HP$`#@```-NC`0`X````ZJ,!`!`````CI`$`
M!P```#2D`0`5````/*0!``,```!2I`$`"````%:D`0`(````7Z0!``X```!H
MI`$`$````'>D`0`5````B*0!`!8```">I`$`(@```+6D`0`9````V*0!`"(`
M``#RI`$`)````!6E`0`)````.J4!``8```!$I0$`"````$NE`0`*````5*4!
M``(```!?I0$`%````&*E`0`4````=Z4!`#````",I0$`&@```+VE`0`*````
MV*4!``T```#CI0$`#@```/&E`0`8`````*8!`$4````9I@$`+P```%^F`0`.
M````CZ8!`!(```">I@$`H````+&F`0`F````4J<!`$H```!YIP$`$@```,2G
M`0`(````UZ<!``8```#@IP$`,0```.>G`0`7````&:@!`"(````QJ`$`"0``
M`%2H`0`'````7J@!``@```!FJ`$`"````&^H`0`&````>*@!`!D```!_J`$`
M%````)FH`0`6````KJ@!`!0```#%J`$`$@```-JH`0`:````[:@!`!(````(
MJ0$`%````!NI`0`(````,*D!``X````YJ0$`"@```$BI`0`8````4ZD!``X`
M``!LJ0$`,P```'NI`0`1````KZD!``P```#!J0$`'0```,ZI`0`4````[*D!
M`#H````!J@$`(P```#RJ`0`F````8*H!`"4```"'J@$`(````*VJ`0`?````
MSJH!`"\```#NJ@$`(0```!ZK`0`R````0*L!`#H```!SJP$`!````*ZK`0`9
M````LZL!``H```#-JP$`#P```-BK`0`#````Z*L!``<```#LJP$`%0```/2K
M`0`8````"JP!`!`````CK`$`&````#2L`0`2````3:P!``4```!@K`$`%P``
M`&:L`0`7````?JP!`!@```"6K`$`#@```*^L`0`0````OJP!`!D```#/K`$`
M+0```.FL`0`'````%ZT!``@````?K0$`#@```"BM`0`0````-ZT!``X```!(
MK0$`!````%>M`0`(````7*T!``H```!EK0$`%@```'"M`0`1````AZT!``H`
M``"9K0$`,0```*2M`0`/````UJT!`(,```#FK0$`&@```&JN`0`+````A:X!
M``<```"1K@$`!P```)FN`0`(````H:X!``H```"JK@$`!@```+6N`0`+````
MO*X!`!H```#(K@$`%0```..N`0`"````^:X!``8```#\K@$`!@````.O`0`5
M````"J\!`!`````@KP$`$P```#&O`0`K````1:\!``(```!QKP$``P```'2O
M`0`4````>*\!``L```"-KP$`"P```)FO`0`,````I:\!``4```"RKP$`&@``
M`+BO`0`'````TZ\!``8```#;KP$`'@```.*O`0`+`````;`!`"0````-L`$`
M!P```#*P`0`)````.K`!`!````!$L`$`!0```%6P`0`)````6[`!``8```!E
ML`$`!0```&RP`0`&````<K`!`!````!YL`$`#@```(JP`0`%````F;`!`!$`
M``"?L`$`"0```+&P`0`'````N[`!`!H```##L`$`+````-ZP`0`7````"[$!
M``<````CL0$`"@```"NQ`0`$````-K$!``D````[L0$`"0```$6Q`0`7````
M3[$!`!<```!GL0$`"@```'^Q`0`&````BK$!``T```"1L0$`!@```)^Q`0`$
M````IK$!`$8```"KL0$`1````/*Q`0!#````-[(!`"(```![L@$`!0```)ZR
M`0`5````I+(!``L```"ZL@$`!P```,:R`0`6````SK(!`!4```#EL@$`!P``
M`/NR`0`$`````[,!`!,````(LP$`!````!RS`0"A````(;,!``H```##LP$`
M&@```,ZS`0`%````Z;,!`#D```#OLP$`"````"FT`0`/````,K0!``<```!"
MM`$`$P```$JT`0`3````7K0!``@```!RM`$`"0```'NT`0`%````A;0!`"(`
M``"+M`$`1````*ZT`0`U````\[0!`#X````IM0$`*@```&BU`0`O````D[4!
M`$L```##M0$`10````^V`0`Q````5;8!`%(```"'M@$`-P```-JV`0`Z````
M$K<!`"0```!-MP$`$0```'*W`0`6````A+<!``P```";MP$`,P```*BW`0`K
M````W+<!`"<````(N`$`*@```#"X`0`(````6[@!``L```!DN`$`"@```'"X
M`0`'````>[@!`"\```"#N`$`,@```+.X`0`Y````YK@!``H````@N0$`&@``
M`"NY`0`D````1KD!`!<```!KN0$`%0```(.Y`0`'````F;D!`!````"AN0$`
M#@```+*Y`0`1````P;D!``\```#3N0$`3@```..Y`0"+````,KH!`'<```"^
MN@$`$P```#:[`0`6````2KL!`!@```!ANP$`$````'J[`0`2````B[L!`!<`
M``">NP$`!@```+:[`0`5````O;L!`!(```#3NP$`$0```.:[`0`5````^+L!
M`!8````.O`$`&````"6\`0`U````/KP!`'@```!TO`$`%P```.V\`0`$````
M!;T!`!@````*O0$`"0```".]`0`$````+;T!``P````RO0$`'P```#^]`0`6
M````7[T!``T```!VO0$`$@```(2]`0`3````E[T!`!8```"KO0$`-@```,*]
M`0`V````^;T!`#0````PO@$`-````&6^`0`K````FKX!`"L```#&O@$`%P``
M`/*^`0!4````"K\!`!4```!?OP$`%0```'6_`0`5````B[\!`!4```"AOP$`
M%````+>_`0`8````S+\!`!@```#EOP$`%````/Z_`0`4````$\`!`#`````H
MP`$`&@```%G``0`<````=,`!`#L```"1P`$`$P```,W``0`&````X<`!``X`
M``#HP`$`'P```/?``0`5````%\$!`!,````MP0$`&P```$'!`0`@````7<$!
M`!L```!^P0$`&0```)K!`0`=````M,$!`!0```#2P0$`'@```.?!`0`B````
M!L(!`!0````IP@$`&P```#["`0`9````6L(!`!,```!TP@$`'````(C"`0`9
M````I<(!`!@```"_P@$`&````-C"`0`*````\<(!`!L```#\P@$`!````!C#
M`0`'````'<,!``H````EPP$`$````###`0`&````0<,!``@```!(PP$`"```
M`%'#`0`&````6L,!``@```!APP$`!P```&K#`0`%````<L,!`!8```!XPP$`
M!@```(_#`0`(````EL,!``<```"?PP$`!````*?#`0`)````K,,!``<```"V
MPP$`"0```+[#`0`0````R,,!`!````#9PP$`"@```.K#`0`4````]<,!``4`
M```*Q`$`,````!#$`0`2````0<0!`!````!4Q`$`%````&7$`0`3````>L0!
M``P```".Q`$`%@```)O$`0`V````LL0!``<```#IQ`$`"````/'$`0`-````
M^L0!``P````(Q0$`#P```!7%`0`&````)<4!``P````LQ0$`#0```#G%`0`&
M````1\4!``0```!.Q0$`#@```%/%`0`0````8L4!`!8```!SQ0$`%P```(K%
M`0`F````HL4!`!L```#)Q0$`"````.7%`0`#````[L4!``P```#RQ0$`*0``
M`/_%`0`%````*<8!``8````OQ@$`#0```#;&`0`1````1,8!``<```!6Q@$`
M!P```%[&`0`%````9L8!``T```!LQ@$`#0```'K&`0`,````B,8!`"````"5
MQ@$`$0```+;&`0`/````R,8!`!H```#8Q@$`$P```//&`0`6````!\<!``4`
M```>QP$`!````"3'`0`5````*<<!`$P````_QP$`!0```(S'`0`-````DL<!
M`"@```"@QP$`&@```,G'`0`/````Y,<!`!,```#TQP$`%`````C(`0`0````
M'<@!``\````NR`$`&````#[(`0`0````5\@!`!4```!HR`$`&0```'[(`0`W
M````F,@!``L```#0R`$`"````-S(`0`?````Y<@!``T````%R0$`#P```!/)
M`0`/````(\D!``0````SR0$`"0```#C)`0`+````0LD!`!,```!.R0$`:P``
M`&+)`0`3````SLD!``H```#BR0$`!0```.W)`0`&````\\D!`!H```#ZR0$`
M&0```!7*`0`9````+\H!``H```!)R@$``@```%3*`0`6````5\H!`#,```!N
MR@$``P```*+*`0`%````ILH!`!<```"LR@$`"@```,3*`0`%````S\H!``@`
M``#5R@$`&@```-[*`0`.````^<H!`$H````(RP$`&0```%/+`0`&````;<L!
M``@```!TRP$`"````'W+`0`$````ALL!``4```"+RP$`2@```)'+`0`/````
MW,L!`!(```#LRP$`!````/_+`0`%````!,P!`"4````*S`$`.0```##,`0`-
M````:LP!``H```!XS`$`$0```(/,`0`*````E<P!``<```"@S`$`%@```*C,
M`0`;````O\P!`"\```#;S`$`+@````O-`0`0````.LT!``,```!+S0$`!P``
M`$_-`0`*````5\T!``<```!BS0$`#@```&K-`0`6````><T!`#@```"0S0$`
M&P```,G-`0`L````Y<T!`"<````2S@$`!P```#K.`0!:````0LX!``\```"=
MS@$`#P```*W.`0`+````O<X!`"<```#)S@$`70```/'.`0`;````3\\!``<`
M``!KSP$`(P```'//`0`(````E\\!``<```"@SP$`&P```*C/`0`&````Q,\!
M``D```#+SP$`+@```-7/`0`M````!-`!`#4````RT`$`!@```&C0`0`&````
M;]`!`"P```!VT`$`9@```*/0`0`7````"M$!`"0````BT0$`%P```$?1`0`"
M````7]$!`!$```!BT0$`!@```'31`0`4````>]$!``X```"0T0$`!@```)_1
M`0`&````IM$!``@```"MT0$`!@```+;1`0`(````O=$!``T```#&T0$`#0``
M`-31`0`*````XM$!`!$```#MT0$`!0```/_1`0`7````!=(!`!0````=T@$`
M%P```#+2`0`+````2M(!`!$```!6T@$`$0```&C2`0`,````>M(!``L```"'
MT@$`#````)/2`0`*````H-(!`!\```"KT@$`$@```,O2`0`5````WM(!``L`
M``#TT@$`&P````#3`0`(````'-,!`!4````ETP$``P```#O3`0`'````/],!
M``4```!'TP$`!0```$W3`0`(````4],!`!8```!<TP$`%P```'/3`0`D````
MB],!`",```"PTP$`'@```-33`0`:````\],!`!L````.U`$`(@```"K4`0`;
M````3=0!``8```!IU`$`!@```'#4`0`2````=]0!`!(```"*U`$`#0```)W4
M`0`E````J]0!`!````#1U`$`%@```.+4`0`9````^=0!``D````3U0$`!@``
M`!W5`0`'````)-4!`!(````LU0$`$0```#_5`0`(````4=4!``D```!:U0$`
M!0```&35`0`'````:M4!``0```!RU0$`!````'?5`0`#````?-4!`$<```"`
MU0$`-@```,C5`0`6````_]4!`"H````6U@$`00```$'6`0`,````@]8!`$``
M``"0U@$`0````-'6`0`9````$M<!`#8````LUP$`.0```&/7`0`Y````G=<!
M`#X```#7UP$`&````!;8`0`;````+]@!`$@```!+V`$`%````)38`0`3````
MJ=@!`!<```"]V`$`'````-78`0`@````\M@!`!0````3V0$`$P```"C9`0`6
M````/-D!`!P```!3V0$`.P```'#9`0`[````K-D!`#\```#HV0$`.0```"C:
M`0`T````8MH!`#L```"7V@$`.````-/:`0![````#-L!`!X```"(VP$`#0``
M`*?;`0`,````M=L!`!L```#"VP$`.````-[;`0`S````%]P!`"H```!+W`$`
M#0```';<`0!3````A-P!`$P```#8W`$`!0```"7=`0`>````*]T!`!8```!*
MW0$`"P```&'=`0`/````;=T!`!8```!]W0$`!P```)3=`0`)````G-T!``D`
M``"FW0$`#@```+#=`0`/````O]T!``@```#/W0$`$P```-C=`0`%````[-T!
M`"8```#RW0$`#0```!G>`0`(````)]X!``8````PW@$`%````#?>`0`2````
M3-X!`!$```!?W@$`1````''>`0`"````MMX!``4```"YW@$`$````+_>`0`?
M````T-X!``4```#PW@$`!P```/;>`0`5````_MX!``8````4WP$`%0```!O?
M`0`$````,=\!`#@````VWP$`)@```&_?`0`F````EM\!`%T```"]WP$`(```
M`!O@`0!-````/.`!`"H```"*X`$`%@```+7@`0`'````S.`!``\```#4X`$`
M"0```.3@`0`/````[N`!``P```#^X`$`%P````OA`0`,````(^$!`!T````P
MX0$`&P```$[A`0`%````:N$!`!,```!PX0$`&P```(3A`0`L````H.$!`!<`
M``#-X0$`%0```.7A`0`1````^^$!`!T````-X@$`"````"OB`0`0````-.(!
M`!D```!%X@$`%````%_B`0`2````=.(!`!P```"'X@$`$P```*3B`0`3````
MN.(!`!$```#,X@$`"P```-[B`0`(````ZN(!``4```#SX@$`'0```/GB`0`&
M````%^,!`!D````>XP$`"````#CC`0`5````0>,!`$D```!7XP$`#````*'C
M`0`<````KN,!`!8```#+XP$`2P```.+C`0!-````+N0!`$0```!\Y`$`2```
M`,'D`0!)````"N4!`#,```!4Y0$`'@```(CE`0`.````I^4!``\```"VY0$`
M*@```,;E`0`&````\>4!`!\```#XY0$`!@```!CF`0`:````'^8!``D````Z
MY@$`"P```$3F`0`G````4.8!`#@```!XY@$`"@```+'F`0`E````O.8!`!X`
M``#BY@$`$`````'G`0`4````$N<!``4````GYP$`!P```"WG`0`+````-><!
M``D```!!YP$`!@```$OG`0`(````4N<!``8```!;YP$`"@```&+G`0`<````
M;><!`"T```"*YP$`,0```+CG`0`E````ZN<!`#,````0Z`$`)@```$3H`0!'
M````:^@!`"$```"SZ`$`)P```-7H`0`^````_>@!`%P````\Z0$`0@```)GI
M`0`P````W.D!``<````-Z@$`"0```!7J`0`(````'^H!``@````HZ@$`%P``
M`#'J`0`6````2>H!`"P```!@Z@$`+@```(WJ`0`P````O.H!`#H```#MZ@$`
M"````"CK`0`?````,>L!``L```!1ZP$`!@```%WK`0`K````9.L!`!,```"0
MZP$`%````*3K`0`+````N>L!``@```#%ZP$`%P```,[K`0`'````YNL!``L`
M``#NZP$`#0```/KK`0`;````".P!`"$````D[`$`/````$;L`0`*````@^P!
M``4```".[`$`!P```)3L`0`;````G.P!``\```"X[`$`!0```,CL`0`2````
MSNP!`!H```#A[`$`!P```/SL`0`.````!.T!`!`````3[0$`$0```"3M`0`$
M````-NT!``0````[[0$`#````$#M`0`>````3>T!`%H```!L[0$`'P```,?M
M`0`K````Y^T!`"`````3[@$`%@```#3N`0`6````2^X!``D```!B[@$`$0``
M`&SN`0`N````?NX!``<```"M[@$`#P```+7N`0`2````Q>X!`!0```#8[@$`
M$````.WN`0!!````_NX!``H```!`[P$`'````$OO`0`5````:.\!`!H```!^
M[P$`.0```)GO`0`C````T^\!`$H```#W[P$`3@```$+P`0!'````D?`!`"L`
M``#9\`$`00````7Q`0`Z````1_$!`!$```""\0$``P```)3Q`0`=````F/$!
M`"(```"V\0$`"0```-GQ`0`<````X_$!``L`````\@$`$P````SR`0`'````
M(/(!`"4````H\@$`'@```$[R`0`*````;?(!``8```!X\@$`$````'_R`0`1
M````D/(!`!P```"B\@$`!````+_R`0`(````Q/(!``L```#-\@$`$````-GR
M`0`0````ZO(!`!<```#[\@$`%P```!/S`0`)````*_,!``8````U\P$`0```
M`#SS`0`T````??,!`#,```"R\P$`!@```.;S`0`&````[?,!``8```#T\P$`
M'0```/OS`0`6````&?0!`"P````P]`$`#@```%WT`0`0````;/0!``,```!]
M]`$`!@```('T`0`1````B/0!``(```":]`$`#0```)WT`0`:````J_0!``P`
M``#&]`$`&````-/T`0`?````[/0!`!(````,]0$`$@```!_U`0`+````,O4!
M`!0````^]0$`%0```%/U`0`/````:?4!``L```!Y]0$`#@```(7U`0`2````
ME/4!`!<```"G]0$`:````+_U`0`B````*/8!`#T```!+]@$`#0```(GV`0`'
M````E_8!``D```"?]@$`%````*GV`0`C````OO8!`"$```#B]@$`%P````3W
M`0`5````'/<!`"`````R]P$`)````%/W`0`7````>/<!`"4```"0]P$`+P``
M`+;W`0`3````YO<!`)````#Z]P$`)````(OX`0`@````L/@!`#(```#1^`$`
M)`````3Y`0`C````*?D!`"0```!-^0$`)0```'+Y`0`D````F/D!`!T```"]
M^0$`"P```-OY`0`'````Y_D!``@```#O^0$`"0```/CY`0`4`````OH!``\`
M```7^@$`-P```"?Z`0`0````7_H!``P```!P^@$`:@```'WZ`0!"````Z/H!
M`$H````K^P$`@````';[`0`-````]_L!`#$````%_`$`,0```#?\`0`*````
M:?P!``4```!T_`$`!@```'K\`0!%````@?P!``@```#'_`$`9@```-#\`0`U
M````-_T!`"@```!M_0$`%````);]`0`G````J_T!`!X```#3_0$`+0```/+]
M`0`W````(/X!`$0```!8_@$`-P```)W^`0`;````U?X!``<```#Q_@$`&P``
M`/G^`0`7````%?\!`!4````M_P$`"0```$/_`0`T````3?\!``P```""_P$`
M"@```(__`0`<````FO\!``D```"W_P$`%P```,'_`0`)````V?\!``8```#C
M_P$`%@```.K_`0`(`````0`"``D````*``(`"````!0``@`%````'0`"``\`
M```C``(`$````#,``@`D````1``"`"````!I``(`$P```(H``@`T````G@`"
M``P```#3``(`!P```.```@`2````Z``"`!L```#[``(`#@```!<!`@`.````
M)@$"`!D````U`0(`)@```$\!`@`.````=@$"`"````"%`0(`-@```*8!`@`(
M````W0$"``H```#F`0(`&0```/$!`@`'````"P("``@````3`@(`$P```!P"
M`@`2````,`("`!(```!#`@(`$0```%8"`@`&````:`("``D```!O`@(`"```
M`'D"`@`)````@@("``X```",`@(`$````)L"`@`&````K`("`!@```"S`@(`
M%````,P"`@`#````X0("``4```#E`@(`$````.L"`@`?````_`("``L````<
M`P(``@```"@#`@`A````*P,"``4```!-`P(`!0```%,#`@!R````60,"``8`
M``#,`P(`!@```-,#`@`<````V@,"`$8```#W`P(`'@```#X$`@`<````700"
M`%L```!Z!`(`.P```-8$`@!/````$@4"`"````!B!0(`%0```(,%`@`&````
MF04"``@```"@!0(`#P```*D%`@`1````N04"``H```#+!0(`#P```-8%`@`7
M````Y@4"`!$```#^!0(`$0```!`&`@`4````(@8"``@````W!@(`"@```$`&
M`@`=````2P8"``X```!I!@(`&@```'@&`@`)````DP8"``4```"=!@(`!@``
M`*,&`@`N````J@8"``4```#9!@(`!@```-\&`@`-````Y@8"``8```#T!@(`
M"P```/L&`@`'````!P<"`!4````/!P(`%0```"4'`@`&````.P<"`!D```!"
M!P(`"@```%P'`@`(````9P<"``<```!P!P(`!@```'@'`@`3````?P<"`"4`
M``"3!P(`"P```+D'`@`.````Q0<"`!<```#4!P(`&@```.P'`@`%````!P@"
M``H````-"`(`$P```!@(`@`-````+`@"``(````Z"`(`#@```#T(`@`)````
M3`@"`"$```!6"`(`00```'@(`@`E````N@@"`#H```#@"`(`.````!L)`@`L
M````5`D"`&<```"!"0(`&P```.D)`@!@````!0H"`#@```!F"@(`2@```)\*
M`@!9````Z@H"`"\```!$"P(`,0```'0+`@`K````I@L"`#$```#2"P(`+P``
M``0,`@`F````-`P"`#T```!;#`(`(@(``)D,`@`N````O`X"`",```#K#@(`
M&`````\/`@!*````*`\"`($```!S#P(`,P```/4/`@!`````*1`"`%H```!J
M$`(`4````,40`@`C````%A$"`!<````Z$0(`(0```%(1`@`C````=!$"`#,`
M``"8$0(`'P```,P1`@`J````[!$"`!L````7$@(`$0```#,2`@!4````11("
M`"L```":$@(`+0```,82`@`G````]!("`"(````<$P(`+0```#\3`@!9````
M;1,"`"X```#'$P(`-@```/83`@`U````+10"`%0```!C%`(`.@```+@4`@`\
M````\Q0"`$X````P%0(`;P```'\5`@!8````[Q4"`$<```!(%@(`2@```)`6
M`@!)````VQ8"`&L````E%P(`HP```)$7`@!U````-1@"`&D```"K&`(`9@``
M`!49`@`_````?!D"`"T```"\&0(`+````.H9`@`P````%QH"`'<```!(&@(`
M=0```,`:`@#`````-AL"`!D```#W&P(`*@```!$<`@`]````/!P"`#(```!Z
M'`(`4@```*T<`@`D`````!T"`%L````E'0(`(````($=`@`(````HAT"`+T`
M``"K'0(`2@```&D>`@`C````M!X"`#D```#8'@(`/0```!(?`@`F````4!\"
M`"$```!W'P(`/@```)D?`@`(````V!\"``<```#A'P(`!0```.D?`@`-````
M[Q\"``X```#]'P(`%`````P@`@`.````(2`"``4````P(`(`$P```#8@`@`!
M````2B`"`'D```!,(`(`"P```,8@`@`3````TB`"``0```#F(`(`!P```.L@
M`@`&````\R`"``4```#Z(`(`!``````A`@`4````!2$"``<````:(0(`"P``
M`"(A`@`1````+B$"``P```!`(0(``@```$TA`@`'````4"$"``<```!8(0(`
M$0```&`A`@`,````<B$"`!<```!_(0(`!@```)<A`@`5````GB$"``P```"T
M(0(``P```,$A`@`M````Q2$"``0```#S(0(`!P```/@A`@`'`````"("`"D`
M```((@(`1@```#(B`@!"````>2("`$$```"\(@(`'@```/XB`@`D````'2,"
M`!L```!"(P(`)````%XC`@`M````@R,"`"8```"Q(P(`(P```-@C`@`I````
M_","`"X````F)`(`/````%4D`@`W````DB0"`"8```#*)`(`,````/$D`@`I
M````(B4"`"\```!,)0(`+0```'PE`@`F````JB4"`"H```#1)0(`+````/PE
M`@`O````*28"`"H```!9)@(`)@```(0F`@`J````JR8"`"\```#6)@(`(P``
M``8G`@`M````*B<"`"````!8)P(`+````'DG`@`^````IB<"`"D```#E)P(`
M+@````\H`@`M````/B@"`"P```!L*`(`)@```)DH`@`@````P"@"`"@```#A
M*`(`*@````HI`@!#````-2D"`"\```!Y*0(`"0```*DI`@`7````LRD"`!P`
M``#+*0(`-0```.@I`@`B````'BH"``X```!!*@(`#P```%`J`@`3````8"H"
M``L```!T*@(`"@```(`J`@`?````BRH"``8```"K*@(`!P```+(J`@`B````
MNBH"`"4```#=*@(`%@````,K`@`@````&BL"`"H````[*P(`&````&8K`@`(
M````?RL"`/@```"(*P(`&@```($L`@`=````G"P"``L```"Z+`(`"````,8L
M`@`+````SRP"`!8```#;+`(`%@```/(L`@`I````"2T"`"4````S+0(`!P``
M`%DM`@!3````82T"`!H```"U+0(`&@```-`M`@`'````ZRT"``T```#S+0(`
M&0````$N`@`,````&RX"`$P````H+@(`,````'4N`@`?````IBX"`!@```#&
M+@(`'P```-\N`@`\````_RX"`!8````\+P(`%P```%,O`@`<````:R\"`!$`
M``"(+P(`)P```)HO`@`-````PB\"`!0```#0+P(`#````.4O`@`6````\B\"
M``L````),`(`&@```!4P`@`(````,#`"`"P````Y,`(`"````&8P`@`I````
M;S`"`"\```"9,`(`!P```,DP`@`9````T3`"``<```#K,`(`"````/,P`@`)
M````_#`"`$4````&,0(`!P```$PQ`@`3````5#$"`!,```!H,0(`%````'PQ
M`@`*````D3$"``H```"<,0(`!P```*<Q`@`4````KS$"``<```#$,0(`&0``
M`,PQ`@`-````YC$"`!D```#T,0(`&P````XR`@`*````*C("``T````U,@(`
M%P```$,R`@`&````6S("`#0```!B,@(`$````)<R`@`)````J#("`!````"R
M,@(``@```,,R`@`0````QC("`!H```#7,@(`"P```/(R`@`#````_C("``@`
M```",P(`#@````LS`@`)````&C,"``X````D,P(`#0```#,S`@`7````03,"
M`!@```!9,P(`$0```'(S`@`\````A#,"`"4```#!,P(`(P```.<S`@`.````
M"S0"`#0````:-`(`!P```$\T`@`5````5S0"`%D```!M-`(`$@```,<T`@`0
M````VC0"``D```#K-`(`!````/4T`@`$````^C0"`!$```#_-`(`'@```!$U
M`@`&````,#4"``<````W-0(`!P```#\U`@`3````1S4"``<```!;-0(`%P``
M`&,U`@`7````>S4"`"T```"3-0(`!0```,$U`@`;````QS4"`"$```#C-0(`
M&0````4V`@`E````'S8"`!$```!%-@(``@```%<V`@`$````6C8"`!$```!?
M-@(`#````'$V`@`%````?C8"``,```"$-@(`#@```(@V`@!7````ES8"`!P`
M``#O-@(`00````PW`@!`````3C<"`#8```"/-P(`6````,8W`@`9````'S@"
M`'D````Y.`(`*````+,X`@!(````W#@"`"0````E.0(`1P```$HY`@`L````
MDCD"`"L```"_.0(`+````.LY`@`L````&#H"`"\```!%.@(`+@```'4Z`@`N
M````I#H"`#@```#3.@(`+`````P[`@`T````.3L"`"\```!N.P(`-0```)X[
M`@`9````U#L"`",```#N.P(`&````!(\`@!Z````*SP"``D```"F/`(`?@``
M`+`\`@"0````+ST"`'P```#`/0(`+0```#T^`@!K````:SX"`!T```#7/@(`
M$P```/4^`@`3````"3\"`'@````=/P(`*@```)8_`@!C````P3\"`#H````E
M0`(`.0```&!``@`^````FD`"`#P```#90`(`2P```!9!`@!-````8D$"`(X`
M``"P00(`2````#]"`@!(````B$("`$@```#10@(`1````!I#`@!%````7T,"
M`"P```"E0P(`0````-)#`@`A````$T0"`"4````U1`(`<0```%M$`@`7````
MS40"``L```#E1`(`!0```/%$`@`&````]T0"``@```#^1`(`!0````=%`@`6
M````#44"`!4````D10(`&0```#I%`@`D````5$4"`!````!Y10(`#P```(I%
M`@`2````FD4"``D```"M10(`%````+=%`@`(````S$4"``4```#510(`&0``
M`-M%`@`*````]44"``P`````1@(`&`````U&`@`(````)D8"``P````O1@(`
M$````#Q&`@`.````348"`!8```!<1@(`#0```'-&`@`1````@48"`!L```"3
M1@(`!@```*]&`@`%````MD8"``L```"\1@(`!P```,A&`@`%````T$8"``4`
M``#61@(`!P```-Q&`@`)````Y$8"`!D```#N1@(``@````A'`@`"````"T<"
M``T````.1P(`"@```!Q'`@`7````)T<"``<````_1P(`)@```$='`@`"````
M;D<"``,```!Q1P(`"P```'5'`@`*````@4<"``X```",1P(`%0```)M'`@`*
M````L4<"``L```"\1P(`!@```,A'`@`$````ST<"`!<```#41P(`$@```.Q'
M`@`"````_T<"``0````"2`(`#P````=(`@`T````%T@"`"\```!,2`(`!@``
M`'Q(`@`(````@T@"``H```",2`(`%P```)=(`@`%````KT@"``(```"U2`(`
M"P```+A(`@`!````J@8``!P$``!:`P``B`<``,4#```:`P``+`<``+L#````
M````3`$``/X$````````*08``.$#``!?`P``*P,``",!```/!@``R@,`````
M``#L`@``#0(`````````````<@(``.(```#A`@``10(``$L'``#_!0``````
M`.D#````````_P```)X#````````\P$``'<$``"E!0``4@```/P&```H!```
M&@$``$4$``"O`P``.@,``.T%``!=`P``"00``#L`````````I0(``'4!``!"
M`@````````````!D`@``7`(````````9!P```````)4`````````*@$``%D$
M``#``@``Z`$````````9`0``Q`8``,@%````````M0````````!J`0``_P,`
M`'(````Q`0``1@4``.@&````````*P8````````?`P``"0$``&$```"Y`0``
MA`<``````````````````(H```"X!@``BP```#@"```]`0```````-(%``#&
M!@``P@`````````#!P``50```(L'```H!P``<P```),#``!N`P``=@$``-(!
M```W`P``L0,```````"*`0``;0(```````#W!```K0$``&D````O!@``````
M``<```"W`````````````````````````'`!````````6`8``&4!````````
M*0<``,T$```I!0``[@0``!\%````````4P```"D```#E!`````````````"X
M!````````````````````````.L$``!6`P``X0```)$$``#$`P``.@8``!X#
M``!Z`P``WP,```````!-!```20$`````````````_`0``$(%``#G`@``2P$`
M`!T```!*`````````%$'``#V!```\P,`````````!@`````````````L`0``
M`````%X`````````NP(``,8$```````````````````D`````````*L`````
M`````````#X'``"5`P``+P$```````````````0``-\```!$`@``PP$`````
M``"C!0``QP```'8````$`0``0P$``%T```"?!0``G0$`````````````K`0`
M``````"1``````````````"]`P``QP,``!@!``"J!```4@0``!4"``#N````
M`````#(%``"\````P@8``.T&``!@`@```````$`'``#&`P``>0,``*$#``!<
M`0``;````)P&``"^````:P```)P#```>!@``=`0``#,%``#,````G`<``,H$
M``![`P``R04``'8%``!5`0``K@$``/L!``"?`0````````````!A`P``'P(`
M`,D#````````]@$``%,"``"5!0```````$H#``#E`P```````$D"``#3`@``
M!0$``),!``!C``````````X$```0`@```````,T&``#=`0``^`8``*D#```?
M`0``)08``(X#``")!```?P8``#P#``#;````)`(```````#!!````````/(&
M``#U!````````*0!```;!P````````P#```_````PP(``*8"``!]!```7@0`
M`.4```#3`0``)0,``+8"```V!P```````*\&````````!P4``/X!``"7`0``
M`````/T$````````Y````+@```!K`0``4`4``&T$````````%`,``"<```#"
M!```D@(``!0'````````X@4``#@```"2!@``7@,``*`%```@`P``)0```.T$
M````````_0```-D```"S`0```````&(#```Y`@``;`4``+0```"@`@``(`0`
M`(D'````````9P8``-@!```,!@``F@(```````#G!@``RP,```````!:!P``
M;@4````````L`@``D@<``',&``#(`0``:``````````R`P``!`(``)(#``"2
M````J@(``&(&````````V`4``$`$``!D!P``C0<``$@#``#S!@``H@4``+4%
M`````````````!@$``"!!0``H@8``!`&``"<````>`<``/@`````````````
M`%H%````````.`,```````"%!P````````\```#I!@``:@4``#H"````````
M.`$``!P"``#2`P```````'\%````````V@,``'('```S`0````````0%``!=
M!0``S`(```````#A`0``?`8``%,$``#.`0``R@4`````````````````````
M``!A`0``````````````````9P<``(`````3!@``"`4```````!E!0``7@(`
M`"X%``#$!```-0(````````U!P```````#`"```E`@``T`0``(D"``#[!@``
MX08```````#_!```+04``*,#```G!P``+08``*T&```'`0```````)L```"K
M!````````,P!````````*P(```````#!!0``WP(``)H#``!E`@``&04``/0$
M``!A`@``=`<```````"+!```)P8```L!````````EP0``(T````:!P``````
M``4&``#M`````````#($```Y````<0<``-H&``"B`P``"0````@#````````
MBP4``/`$``#(`P``CP8`````````````'08``-T`````````004```````!!
M`@``]P8``*<````=`P``/`$``%0&``#-`0``OP```#,````1`@``<`<``+0!
M```'!```P````-D$```U!@``,`$```````!H!@````4``!P%``#R!0``D@$`
M`/H&````````)00``,(!``!F!```800``$`&```Q!```/`0`````````````
MQ@4``-X#````````KP$``(`$``#7`P```````/````"#````3@,``"\#``!M
M!0``#P$``!D```"8`P``B`(``(,"````````6@$``&D'``!@!P``,`0``'D!
M````````B@8```X'``!+!@````````````#"!0``XP(```````!Z`0``S@8`
M`%('``!#`````````#X#``""!P``\P4```L`````````VP,``%8&``"P`0``
MW@(``!8```!#!0``JP4``%(&``"#`P````````````"!!```N`,`````````
M````=@0``+X#````````[`$``/`!``!M`P``````````````````,`8``#L#
M```J!```V@$``.,!```.!0````````8#``!1!```*P4``````````````0(`
M``````!R!0``3`,``+\$```A`P``T0````````"=`P``5@```!8'``#&`0``
M7`8``-\%````````W08``$P%``#D`@```````#@%``#1`P``1@$``(X```!H
M`0``````````````````1`$``/X"``"Y`P```````&X&```T!0``E@<`````
M````````:P0``+($````````P0,``-``````````H`,````````L`P``/P0`
M`+T"````````)0<```````````````````````#I`@``D0<``(0%```Q!P``
M^`$```4$``#8`P``YP0``/<```!%!0```````!0```#F!0``,P(``+,$```9
M`@``HP(``*8#``"9!0```````(<!````````F`0``#0!``#D`P``[P$``#('
M``"5!P``\0,``/4"```N`@``&`8``#<&``!R`P```````*`!``"<!0``X04`
M`!0$````````A0$``.8"```5!@````````````"N!0``MP8``,P$````````
M`````'<#```U`0````````````#N`@``8@0``'`````&`0``6`(```````"/
M````-@(``&D#```P````5P$```````!'`````````.@%``#B`@```````((`
M``#*````@P4````````V`0``6`0``),"``!Q````;0<``(4$```-!0``````
M``````"]`0``?`$``(,!``"^`@```````)8!```````````````````0!```
M-P4``'T```!4````7@$```````#Y````!`0``$D&````````M`4``-(&``"N
M`P``0P,``'8#````````6`<``)H%`````````````!0%``!0!```Z@(```T'
M````````]`````````#(!@``ZP$``.P#````````"`0````````#`@``M@$`
M``````#R`@```````.H%```````````````````J!0``1@<``!8&````````
M`````&X!``#P`P```````+<%````````^P4`````````````9@$``,L!``#T
M!0``H04``.H#``#:!```A`8```P'```[!0``QP4``$X!``"`!0````````H`
M```4`@````````````")!0``+@0``(,'``"2!```SP0``.,#```Q!@``8`8`
M`,<&``!6!```+`4``,4%``":!`````````````"$`P```````$H$``#X`@``
M_@8``(@&````````?P$``,8```#G``````$```````"I!0``)@8``/T"``#%
M!````````)(%```+!0````````````!N!`````````````!U`P``K@``````
M``#9!0``O@$``(8&``#J`0``1`8``/P"``"4`@``\@$``-L!```3`0``E@8`
M`!X%`````````````*L"``!"`0``L08``$T````'!P```````)H'```T!@``
M'@<```````#W`P``D`0``!P#``#`!0``#P,``'<&``!U!````````+8$```)
M`@``;08```("````````<00```````#0`0```@,``,$!```#!```:0$``!L"
M``#0`@``C08```````!#!P``20<```X"``"D!```+0(``"T!``"``0``F`8`
M`/4!`````````````&P$```]!@``=P```/0&````````=04```````#D!@``
M-`(```````#%!@``D08``-@"```R!@```````/0"``"Z`P```````"@`````
M````(`(``)\``````````````&H"``#*`0``E0$```D#````````8`4``#\#
M``"R`P``#0,```````"G`@```````!L````;!```TP```.(#``"4`P``FP,`
M`&0!```$`````````&P'`````````````#D'``#S!```?@,``)\'````````
MI00``*,`````````UP(`````````````@`(`````````````?`(``)L$```6
M!```2P(``!@'````````KP4``$<#```O````W@```#T%``"T`@```````!``
M``"C!@``'0(``*H!``";`0``4`(```````!X`P``&00``-0"```]!```G@4`
M`-4%``#M`P``*0,``````````````````&\```#6`@```````,0!``!=`0``
M2@<``)8%``"H!```-P<``/L"``!;`0``F`<``(0"``!^!````````+P#````
M````$@8``#H!`````````````$T'``"9`0````````````"*!0```````&(%
M```8`P``2P4`````````````P0(```8"````````&0,``!<$```B`@``^P``
M`(8$``!#!```\@0``$\'``!<!0``*0(``"$"```!!P``^0$```\$````````
M`````'X%```1`0``(@<``"X'``!6`0```````+4$``"7!@``ZP(``#8&```0
M`0``D`(```X!``!N`@``9````%P#````````(@8```````!S`P```````+("
M```-`0``^0,```````!F!P``0@,``+P&`````````````!H&``#9!@``````
M`&H#````````$`4``!@"````````````````````````E`0``&("``!\````
M,`,````````\!P``'@``````````````C`4``+`&``#Q!````````'($``#-
M````<P4``$,&``#0!@``@0<``````````````````#`'```T!P``/@```)H!
M`````````````*\$````````=0```-8$``!9!@```````"0#``#K!@``Q0$`
M`%T$``#@`0``H@```/@$``">``````````````!\`P``R0$```````#V!0``
MS@4``*`$````````3@4``$<$```"!@``%P4``%,#``!/`0```````'$&````
M````WP$``````````````````*\```"8````-P```)$#``"W`0``7`0``#H$
M``#$!0``O04`````````````4@,``&L#```N`P``"`(```````!@````````
M`)T$```G!```O`4``'L!``"9!@``H@(``!0!````````9`,``((!```L!@``
M$@(``$D$```C!P``4@(``&@'``"=!0```````$$&``"A`0``````````````
M````V@````````````````,``%4'````````````````````````=`(`````
M``#K!0``#0````````#4`P``*`(``),$``!F!@``SP,````'``"U`P``_08`
M`(X"````````,@$``)D"``"*!```+`````````!6!P```````(<%``!1`0``
M,@(``+D%``">`0``00,``)0!``"&`@```````````````````````#P%``"I
M!@``NP4``%0!``!;!````````&\"```"!`````````````#/!0``````````
M```?````808````````A`0``&P8``!P!``"L!@``(04``%D!````````````
M`/X#``#+`@``90<```H"``!/`P``H`8`````````````_P$```````"E````
ML00``'0%````````'P0```````!!!```%@$```````!_`@``(P(``),'``#P
M!0```````*`'```W!```E@0``&L"``!@`0``<P<``)P!``!F`@````````8&
M```_!@```````&P&``!-`@``PP8``)D#`````````````,D"``"K`P``````
M````````````8P0``#H```"L`@``>`0``*L!``">`@``Z@0``",```!)!0``
M`````$<"``"4!0```````$<'``!Q!0``A````(P#``!>!@`````````````A
M!```;@<``%,'``!$!```/@0```4%``!1!0``60```,L```!.`````````&H`
M```1!P``>`4``&,%``!P!@``B@<```````"P`P``#`(```````"U`0``````
M`.`"``!&!@``A`$``"$'``!_!P``&`4``$L#``#J`````````*<!``!'!@``
M#P(``/D&``"[!@``)P$``,L$``!@!```U08``.4!`````````````(X$``"M
M!0```````$8$````````9P4``'X&````````%@(``*8$````````````````
M```F`P`````````````````````````````J`P``!P(```D&```U!```O@0`
M`!0&``!;`@``.0,``*,!``!3!0``V@(``!<&``"<`@````````````"I`0``
M`@```.`&````````X00``,\```#Z!0```````+@%````````B`$``%P```"N
M!```@@4``#D&````````&@````0&``"P!0``'04```````#D`0``\P```'D&
M``!C!@``V0,``-P%````````,P,``.@```#!````Y@$``-4#````````'`8`
M`%T'``"[````&@0``(<"``!\!```>P8``.\%``#5`@``0@<``.@#``"'`P``
M_0$``%\%``#Y`@``TP8````````N`````````%4#``#\!0``^@,``'$#``!0
M`0````````````!`!0``J00``!,"``",`@``3P4``%,!````````^@```!T!
M``#)!@```````(D&```S!P``F0```)\#``"0!@``-``````````B`0``[P``
M`((#```.`P``(@0```,&```H!@``FP(``-0$``".!P```````&@#``#@````
MQP(``"4%```\````A08``*@%`````````````(T%``!C`@```````+,&```O
M!````````"D$``#W`@```````#X!```Z!0``$00`````````````````````
M``"1`0``&````$H!``!?`0``L````,<$``#<`0``N@8``/`"``!O!0``L@``
M`&H'`````````````.@$````````9`8```````!K!0``G08````````7`0``
M``````````"]````OP,``-T#``":````>P4```(%``````````````````#>
M!````````%4"````````W@$``+(&``!``0``(P4```<&``#``P``S`8`````
M``"^!0``!P,``!X"``"0``````````X`````````]04```````#@!0``E@``
M`"@!``#,!0``$@$``,,%`````````````-L"``!_!````````)8#``"L`P``
M@0```#8#```Q`P```````(D`````````9@4``.D!```#`````````.P%``#;
M!@``-0,``#<!``!0!P```````!H%````````W@4``'H```!-`0``SP$``,4`
M``#D!````````'(&``#I!````````+$!``!+````2`8`````````````804`
M`$<!``!1`P``6`$``&D&```K!P``N@(``+H```"E`0``F`(``+P$````````
MLP,``$`"```7!P``\P(``$X"````````.`8``#$"``"Q`@``;@```'L$``!%
M!P``J`(``',"````````$P0``'@&````````#P<``)`'```^`@``````````
M``!?`@```````'L'``!-!0``E`8```````#<!```Y04``"<"``#L!@``T@``
M``````"\`0``D04``"8"``"P`@``5`0``,D```!$`P``90```-D"````````
MK`4````````#`P``H0(``-4$``#7```````````````%`P``UP4```8$````
M``````````````!C`P````````````#Z`0```````)4$````````A04`````
M````````M@4``'T#``#3!0``CP<``!,````D!```00<``'D'```\!@``H00`
M`($"``#R`P``1`4``"(#``#V`P``Y@,``$@"``#(`@```````,X$``!W`0``
M;`(``&4&``#C!@```08``-$%``!/!@``GP8``$\```#/!@``H@$``/H"``!^
M````X@8``'<'``#Y!```"`8``$H%````````"P<``(`'````````<`(``,D$
M```P!0``<`,``````````````````#T#``"]!```J````(\"```,`0``$04`
M`+\"```0`P```0,``'8'``"3!0``\0$``!L!````````"@4```````#B`0``
M>04``/$```!9!P``70(````````&!0``VP4``(H#```2````JP8``)T'``!H
M!0``2`0`````````````C00``,@$``"/`0```````%<&```"!P``.P<``(($
M``!:`@``5P4``,(#````````C@8``(D#``"T`P``GP(```````"[`0``````
M``````!G`P``/@4``&L'``"8`0``60,``(8%``!Y````&08``!8#``"C!```
M4`,``,`$```+!@``PP``````````````40```.X&``"_!0``:P8``-@&``#'
M`0``/`(```````````````````````"-`P``7P8``)0```!&`@``````````
M````````2P0`````````````_`,`````````````U`8```````!G`0``(08`
M`"0%``#L````*P0``+L$```[`@``^P,``,T#````````"P(``'T%``!I!0``
M$08``),```"F!0``=@8``-<&``````````````````"<!```9P````````"D
M!@``````````````````M`8``#L$````````108``&D$``!Z`@``(````"(%
M````````"P,```H#````````I`,```````!8````W@8``)H&```(````9@,`
M`+8&``````````````4`````````T@0``-P````$`P``8@$``'4"```=!P``
M````````````````504``#$%```````````````````^!@``1@```/0!``"P
M!```Y@``````````````0P(``'T"``#6!@``7@4``"\'```G!0```````%D%
M``"&`P``AP0``*X"``"/`P``YP$``!X!``"E!@``_@4``&,!````````````
M`*@#``#@!```3P(``%\$``!,!```J`$``+<"``"_`0``6P4```````#N`P``
M`````'0#````````N@$``(\%````````0@0``%<````<````H0<``&<"``">
M!```@0,``#T'``#C!0``'`<``"$```"&`0```````&\!````````9@```)D$
M``````````````````#0!0``]P4```8'``#T`P``;P8``"H"```#!0``````
M`#D%``"`!@``2@8``.H&``"M`@``4@$```````!;!P````````````#7`0``
M`````)T"```2`P``EP```#8$``#K`P``500``(0$````````>@8``,4"````
M````I`(``(@%````````P`8``(`#``"9!P``B`,``+,%``#U`P``?`<``#@$
M````````B0$``,P#``#V````#P4``#T"``!.!```+0,`````````````````
M``````!.!P``IP,``'4'``!5!@``C`8````````R````C0$``*$`````````
M``````````#Z!```B````$T&```M!P``:@8``+8#````````AP```(\$```;
M!0``IP4```````!]!@`````````````*!@``B`0``'\#````````?`4``+D"
M``"?!````````(,$``#6````@0$``+H$````````FP8``.X!``![`@``V```
M`"@%```M````<0(``)`#```!!```@P8``"T$`````````````+X&``"J`P``
M`````)X&`````````````',!``"'!@``I@$``"8%`````````````#\!````
M`````````&$'``!;`P`````````````;`P``V`0``.\#````````@@(``-P#
M``!``P``A@```"0'``#O!```S04``'8"``!U!@``)@0``'0!``#N!0``````
M`%<'```3`P``````````````````$@0``,H"```5!0``AP<``&P#``!(!0``
M!0(``-P&``!-`P````````````!%`````````"X&```````````````````!
M`0````````````!^`@```````)4&```Y!````````,@``````````````,L%
M````````>@<``!$#````````````````````````10,`````````````5@4`
M`.T"```5!```N0```%\'``!?````P08``+,```````````````````!9`@``
M_P(``/8&```!!0``T@(``````````````````,X```!X`0``10$``)<#``!S
M!```L0```'$!``"B!```8P<``(L!``!B````O08``-$&````````Q````!\'
M``#7!```TP0```````#[!```K0,```````#@`P```````'X'``"4!P``=P(`
M`+\&``"J!0```````,0"``#L!````````%H&```5`0``9P0```````#O`@``
MS0(``%H$``"U`@``+`0``.T!````````0@8``&\#````````IP0``'(!```Y
M`0```````+D&```2!0````````````",`0```````-$"````````$`<``+0$
M`````````````!$```!4`@``F`4``*T$```I`0``:`(``*D````_!P``!@``
M````````````)`$``+@"```)!P``Z`(``"\%``"Q!0``K@8````````-!@``
M`````-`#```3!P```````($&``!`````5`,`````````````TP,``-$$``"0
M!0``BP,``$$````(`0``1@,``*<&``"L`0``3@8``",$``!4!P``8`,``.,`
M``#*!@``C@$``(T"``#5`````````"\"``"*`@``L@$``-8%```*!```````
M`/P```#V`@````````````````````````````"%`P```````&0$``#W`0``
M\08``&4#```?!@``"`<``%````!H!```I@8````````C!@``?0$``/T%``",
M!```9`4``#T```"E`P``.P8``-\&``#;!```T0$``/$"``!'!0``P@(``/D%
M``#P!@``)@````H!````````=`8``%X'````````A0(``!X$``!7`P``M08`
M```````H`P``Q@(``/$%```T!```-@```!4#``#I````'00``#\"````````
M``````T$``"+!@``:@0``"L```",`````````%0%``"0`0``YP4```````#+
M!@```@$``'L`````````(`<``'@```!$````$@<```````!"`````````"H'
M``"I`@```````.<#```3!0``%P(```,!```````````````````S!@``-`,`
M`/\&```V!0``*@8```````!*`@``3````)$"```6!0``PP0`````````````
MU`$``'`%```K`0``)@$``*0%``"7`@``5P0``*H```"M````3`8``"H```!<
M!P``S@,``-T$``"L````_`$``.4"``!O!P``W`(``,,#``!=!@``"04``-H%
M``"X`0``Y@0```````!0!@``4P8``'H%``!2!0``408``&P!``#U!@``>@0`
M`(8'``"D````%P,``'`$```*!P``^`,```````#R`````````-8!``"H!@``
M6`4``$$!``">!P``%0```$@```"V````40(``$@'``"Z!0``=````%@#````
M````6P8```P`````````U`4``$0'```C`P``5P(``/@%```X!P``@@8``#,$
M``#=`@```````$@!``#]`P````````4'``#O!@``:0(``&('```@!0``(@``
M``````#B!```G0```(X%`````````````+P"``!/!```E0(`````````````
MZ04```X&``#.`@````````````"F````20```(L"``!Y!```U````.8&```W
M`@``;0$``'@"``!E!````````!<```"W!```#`4``*````!;````U0$``#\%
M``!]!P``+@$```````!,!P``C`<```````"7!0``_@`````````D!@``Y`4`
M`#H'``#K````&@(```P$``";!0``(`8````````E`0``)@<``#4%``"7!P``
MA0```%8"``!M````W04````````$!P``E@(````"```G`P``,0```+(%``"S
M`@``U@,``'<%``!)`P``%0<```````"W`P```````*$&```@`0``.P$``,`!
M`````````````,\"`````````````%H````+!```N00``)L'``"O`@``Y08`
M`.,$``!O!```>0(``#4```#9`0``?P```-\$``#U````3`(``),&``!^`0``
M```````@("U-+"`M+6UE<W-A9V4]34534T%'12`@57-E('1H:7,@8V]M;6ET
M(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O;F5S+@`@("UA+"`M
M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE('1O('1H92!C;VUP
M96YD:75M+B!5<V5F=6P@=&\*("`@("`@("`@("`@("`@("`@("`@("`@:6YC
M;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A(&1I9F9E<F5N="!B<F%N8V@@=&\*
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R871E9"!C;VUP96YD
M:75M+@`@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@<&%T:"!T;R!T:&4@*$AO
M<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L9"!B90H@("`@("`@("`@
M("`@("`@("`@('5S960N`"`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!-97)G
M92!N97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N9&EU;2!F:6QE"B`@
M("`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F('1H92!D969A=6QT
M(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4*("`@("`@("`@("`@("`@("`@
M("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2X`("`M8RP@+2UC;VUP96YD:75M
M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I;G-T96%D(&]F('1H
M92!D969A=6QT"B`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E
M;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN`"`@+60L("TM
M9&5B=6<@("`@("`@4VAO=R!E<G)O<B!M97-S86=E<R!F<F]M('1H92!E>&5C
M=71E9"!B:6YA<FEE<RX`("`M9"P@+2UD:7)E8W1O<GD]1$E2("`@0W)E871E
M(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN`"`@+6@L("TM:&5L<"`@
M("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`("`M;"P@+2UL;V-A;&4]
M;&Q?0T,@("`@(%5S92!O;FQY('1H:7,@;&]C86QE+@`@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+@`@("UL+"`M+6QO8V%L93UL
M;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,
M12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D
M=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0VQE86YU<"!03R!F:6QE
M<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0V]M;6ET('1R86YS;&%T:6]N<R!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0W)E
M871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@
M("UM+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@4$\@9FEL97,@;VYL>2!F
M;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%
M("`@(%5P9&%T92!H96QP(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M
M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@;VYL>2!T
M:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@($=E
M;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG="!M97)G92!N97<@=')A
M;G-L871I;VYS('1O('1H92!C;VUP96YD:75M+@`@("UN+"`M+6YO+6-O;7!E
M;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2X`("`M<RP@+2US=&%T
M:7-T:6-S("`@("`@(%-A=F4@=')A;G-L871I;VX@<W1A=&ES=&EC<R!I;B!A
M(&QO8V%L(&9I;&4N`"`@+70L("TM=&5S="`@("`@("`@4VAO=R!T:&4@97AE
M8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U;B!A;GET:&EN9RX`("!C;&5A
M;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P(&9R;VT@=6YT<F%N<VQA
M=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+@`@(&-O;6UI="`@("`@($-O;6UI
M="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V97(N`"`@8V]M;6ET+6AE
M;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE($-64R!S97)V97(N`"`@8V]M
M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU;2!F:6QE+B!787)N:6YG
M.B!4:&ES(&]V97)W<FET97,@=&AE"B`@("`@("`@("`@("`@8W5R<F5N="!C
M;VUP96YD:75M+@`@(&5X=')A8W0@("`@($=E;F5R871E(%!/('1E;7!L871E
M("@N<&]T*2!F:6QE<RX`("!H96QP("`@("`@("!3:&]W('1H:7,@:&5L<"!M
M97-S86=E+@`@(&EN:70@("`@("`@($-R96%T92!O;F4@;W(@;6]R92!03R!F
M:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG.B!4:&ES"B`@("`@("`@
M("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@9FEL97,@;V8@=&AI
M<R!L;V-A;&4N`"`@;6%K92`@("`@("`@0G5I;&0@8FEN87)Y($U/(&9I;&5S
M(&9R;VT@=&AE('-P96-I9FEE9"!03R!F:6QE<RX`("!M86ME+6AE;'`@("!-
M87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F:6QE(&)E:6YG('5P
M+71O+61A=&4@86YD"B`@("`@("`@("`@("`@<')E<&%R92!T:&4@9FEL92!F
M;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T92UH96QP+B!9;W4*("`@
M("`@("`@("`@("!S:&]U;&0@;VYL>2!R=6X@;6%K92UH96QP($%&5$52('5P
M9&%T92UH96QP(&%N9"!R979I<VEN9R!T:&4*("`@("`@("`@("`@("!H96QP
M(&9I;&4N`"`@;65R9V4@("`@("`@365R9V4@=&AE(&-U<G)E;G0@4$\@9FEL
M92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E(&9I;&4N`"`@=7!D871E
M("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E<75E;G0N`"`@=7!D871E
M+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N9V5D(&5N=')I97,@9G)O
M;2!T:&4@16YG;&ES:"!834P@:&5L<`H@("`@("`@("`@("`@(&9I;&4@86YD
M(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@;VYE<RX`("8C,34Q.R`E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E
M9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F
M;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!D;V5S
M(&YO="!E>&ES="!O<B!I<R!N;W0@97AE8W5T86)L92X`)7,@:7,@;F]T('=R
M:71A8FQE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@;F]T(&9O=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I
M<G-T+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A
M;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@
M=6YA8FQE('1O(&QO860@9')I=F5R.B`E<P`G)7,G(&ES(&YO="!A('9A;&ED
M(&-H;VEC92X`)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN`"<E<R<@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"<E<R<@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A9&1E
M9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E
M871E9#H@)7,N`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,`+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E
M=FEO=7,`/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N"D]P
M96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N`$$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`041322!E<G)O<B`E<RX`04T@0VQO
M=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@
M4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N
M+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@1&5N:65D+@!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F
M<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI
M;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W
M(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@)R5S)P!!9&0@82!C
M:&EL9"!P97)M:7-S:6]N('1O("<E<R<`061D(&$@;F5W('5S97(Z`$%D9"!C
M;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N
M=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!
M9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("<E<R<@=&\@
M=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N
M=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`G)7,G('1O('1H92!S>7-T96TN
M(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG(&YE=R!F:6QE<R!T;R!R97!O
M<VET;W)Y.@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D
M<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A
M;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U
M=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`
M06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S
M`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I
M8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG
M=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!
M<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P
M<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M
M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A
M;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N
M("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI
M($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM
M96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T
M=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N
M`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S
M97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2
M041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S
M97,`0F%C:V5N9"!N;W0@8V]R<F5C=&QY(&EM<&QE;65N=&5D+@!"86-K9W)O
M=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"
M860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@
M*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI
M8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S
M`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y
M`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L
M;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K
M<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD
M($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA
M;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N
M96D@1&%R=7-S86QA;0!"=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D=6QE("5S
M+BXN`$)U:6QD:6YG(&QO8V%L92`E<RXN+B``0G5L9V%R:6$`0G5L;&5T960@
M3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W
M87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE
M<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E
M<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T
M87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN
M;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E
M;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O
M=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#
M87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#
M96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@
M<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E3
M3RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I
M;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA
M9`!#:&%N9V4`0VAA;F=E(%!A<W-W;W)D`$-H86YG92!P87-S=V]R9"!O;CH`
M0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W
M:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG
M92!Y;W5R('!A<W-W;W)D`$-H86YG:6YG('!A<W-W;W)D(&]N("5S`$-H87(`
M0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAI;&4`
M0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI
M<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)
M<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%N
M:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`0VQE86YI;F<@=7`@
M;&]C86QE("5S+BXN(`!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R
M(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A
M<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A4
M5%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P
M<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U
M<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N
M9`!#;VUM86YD(%-H96QL`$-O;6UA;F0@;W!T:6]N<SH`0V]M;6%N9',Z`$-O
M;6UE;G0`0V]M;6ET=&EN9SH`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY
M`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9FER
M;2!N97<@<&%S<W=O<F0Z`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@
M9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N=',@;V8@)R5S)P!#;VYT:6YU
M90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]P
M>6EN9R`E<R!T;R`E<P!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M
M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C:&5C:R!B86QA
M;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<@!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S`$-O
M=6QD(&YO="!C;W!Y("5S('1O("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!C<F5A=&4@;&]C86QE(&1I<F5C
M=&]R>2!F;W(@;&]C86QE("5S.@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C
M<FEP="`G)7,G+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G
M>2`G)7,G+@!#;W5L9"!N;W0@;6MD:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P
M96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R:71I;F<N`$-O=6QD
M(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO
M="!O<&5N(&1I<F5C=&]R>2`G)7,G+@!#;W5L9"!N;W0@;W!E;B!P:7!E('1O
M('-M8G!A<W-W9"X`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!R;61I<B`G)7,G+@!#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@
M)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E
M<R<N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`G)7,G+@!#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`G
M)7,G.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S
M97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`G
M)7,G.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#
M<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD
M97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R
M;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@5&EM90!#=7)R
M96YT(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ
M(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L
M;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC
M("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A
M5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO
M;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S
M`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L
M="!)9&5N=&ET>0!$969A=6QT(%!E<FUI<W-I;VYS`$1E9F%U;'0@<&5R;6ES
M<VEO;G,`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@
M4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C
M96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<`1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$
M96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E
M('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@!$96QI=F5R>2!T:6UE
M`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N
M=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I
M;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P
M;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O
M<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T
M(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!2
M97!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES
M=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D
M:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@)7,`161I="!P97)M:7-S:6]N<R!F;W(@)R5S)P!%
M9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G
M92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`
M16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC
M:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1R:65S.B`E9"!T;W1A
M;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E9"!C:&%N9V5D+"`E9"!U;FMN
M;W=N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@<V5N
M9&EN9R!D871A('1O('-M8G!A<W-W9"X`17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+@!%<G)O<B!W<FET:6YG("<E<R<N`$5R<F]R.B``17-T;VYI80!%=&AI
M;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M
M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y
M($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V
M86QU97,Z`$5X96-U=&4`17AE8W5T:6YG.@!%>'!A;F0`17AP86YD(%-I9&5B
M87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X=')A8W1I
M;F<@9G)O;2`E<RXN+B``1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&
M86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S
M97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O
M<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@=F5R:69Y
M(&]L9"!P87-S=V]R9"X`1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"!O
M;B`E<SH@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R
M;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI
M:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`
M1FEE;&0@;6%T<FEX`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O
M=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L
M96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D
M+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I
M>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U
M<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO
M=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A
M>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT
M(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS
M`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R
M=6US`$9O<G=A<F1S`$9O=6YD(&%P<&QI8V%T:6]N<SH@)7,`1F]U;F0@9&ER
M96-T;W)I97,Z`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET
M86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T
M:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T
M:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1G5Z>GD`1V%B;VX`1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S
M($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5N97)A=&EN9R!S=&%T
M=7,@9F]R(&UO9'5L92`E<RXN+@!'96]R9VEA`$=E<FUA;GD`1V5T;W!T($5R
M<F]R.B``1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O
M;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM
M-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O
M=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R;6ES<VEO;G,`
M1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E
M<W0@4&5R;6ES<VEO;G,`1W5E<W0@<&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U
M:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A
M9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@
M*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`
M2&5L<&5R`$AE;'!E<B!A<'!L:6-A=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT
M86EN('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E"F9R86UE=V]R:R!A;F0@
M:71S(&%P<&QI8V%T:6]N<RX*1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H
M92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R>2X`2&5M:7-P:&5R90!(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&ES=&]R
M>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!(;U]M90!(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE
M(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92!T<F%N<VQA
M=&EO;B!G96YE<F%T;W(`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES960@)7,@(B5S(@!(;W)D
M92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@
M)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y
M<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H
M87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I
M>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO
M=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I
M96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R
M:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D
M<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E
M<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S
M`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO
M="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W
M('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT
M97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O
M>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H
M:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T
M;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`
M26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O
M;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM
M86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R
M=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(%!A<W-W
M;W)D`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R
M96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`
M26YF;P!);F9O<FUA=&EO;@!);FET:6%L:7II;F<@;6]D=6QE("5S+BXN(`!)
M;G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE
M`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T
M97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!)
M;G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I
M=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T
M(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M
M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T
M97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!)
M;G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`
M26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N
M9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D
M:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T
M8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI
M8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED
M(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES
M<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D
M92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("<E<R<`
M26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`
M26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E
M9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A
M`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`
M2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I
M9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N
M`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N
M`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G
M90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+
M=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G
M<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%%U87)T97(`
M3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F
M<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE
M879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A
M9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*
M86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!2
M86EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A
M:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`
M3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T
M;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L
M<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,
M:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI
M<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET
M97)A='5R90!,:71H=6%N:6$`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN
M9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO
M9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R
M(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA
M;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I
M8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86ME('-U<F4@=&AA
M="!Y;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E
M('!A=&@N`$UA:VEN9R!D:7)E8W1O<GD@)7,`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN
M9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E
M9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@
M;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E
M.@!-97)G92!C96QL<P!-97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@
M8V]M<&5N9&EU;2XN+B``365R9VEN9R!L;V-A;&4@)7,N+BX@`$UE<F=I;F<@
M=&AE(%!/(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G
M:6YG('1R86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BX`365S<V%G90!-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I
M<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-
M971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@)R5S)R!I
M<R!N;W0@9&5F:6YE9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L
M;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI
M<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@
M;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S
M:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D
M97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L90!-;V1U;'5S
M`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A
M;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C
M;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V
M92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N
M`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY
M(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M
M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S
M($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C
M871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N
M97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE
M9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T
M:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9#H`3F5W('=I;F1O=R`H
M7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE
M>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H
M=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE
M;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.
M;R!C:&%N9V4N`$YO(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E
M9"!B96QO=R!T:&ES(&QE=F5L+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VUM86YD('-P96-I9FEE9"X`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@96YT<GD@=VET:"!T:&4@:60@)R5S
M)R!E>&ES=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92X`3F\@9FEL92!U
M<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C86QE('-P96-I9FEE9"X`
M3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@
M;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E
M<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H
M92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S
M:61E<P!.;R!S=6-H(&)A8VME;F0@)R5S)R!F;W5N9"X`3F\@=&5M<&]R87)Y
M(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N
M960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S
M:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC
M("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P
M:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E
M<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N
M`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN`$YO=&EC90!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F
M(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]B:F5C="!C
M<F5A=&]R('!E<FUI<W-I;VYS`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT
M97(`3V9F:6-E`$]L9"!P87-S=V]R9#H`3VUA;@!/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T
M=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@
M:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS
M`$]P=&EO;G,@9F]R("5S`$]P=&EO;G,Z`$]R9&5R960@3&ES=`!/<F=A;FES
M871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I
M=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+
M97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE
M;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3
M:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`
M4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO
M=61Y`%!A<W-W9"!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"X`4&%S<W=O
M<F0`4&%S<W=O<F0@8VAA;F=E9"!O;B`E<RX`4&%S<W=O<F0@:6YC;W)R96-T
M`%!A<W-W;W)D(&UO9'5L92!C86XG="!F:6YD('1H92!S=7!P;&EE9"!B:6XN
M`%!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG(')E<75I<F5D('!A<F%M971E
M<G,N`%!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG('1A<F=E="!P87)A;65T
M97(N`%!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E
M9`!087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960N
M`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R
M9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L
M:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N("<E<R<@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N`%!E<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U
M`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L
M<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE
M;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H
M:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE
M87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L
M;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T
M;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I
M,3AN0&QI<W1S+FAO<F1E+F]R9RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E
M9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z
M(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0
M<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R
M;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X
M=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@
M26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC
M($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY
M`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@
M4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R
M97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!2
M96UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S
M=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`G)7,G
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M)R5S)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@)V1R:79E<G,G(&ES(&UI<V-O;F9I9W5R960@:6X@0V]M<&]S:71E
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF
M:65D(&EN(%!A<W-W9"!344P@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H
M<'1Y<&4G(&YO="!S<&5C:69I960@:6X@4U%,(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@
M4&%S<W=O<F0`4F5S=6QT<P!297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.@!2
M97-U;'1S.@!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R="!#;VYF
M:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I
M9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S
M+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T
M92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2
M=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C
M;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S
M:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3
M:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!3
M86EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M
M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I
M80!3879E`%-A=F4@)7,`4V%V92`G)7,G`%-A=F4@3W!T:6]N<P!3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I
M9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G
M+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N
M9VEN97,`4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<P!396%R
M8VAI;F<@9V5T=&5X="!B:6YA<FEE<RXN+@!396QE8W0@1FEL97,`4V5L96-T
M(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W
M;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE
M8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE
M8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L
M;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!3
M96YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G
M<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A
M:6QA8FQE+@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W
M86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E
M="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U
M<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C
M871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL
M97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@
M8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3
M:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E
M;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D
M`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I
M;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U
M<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O
M;F4`4VEG;B!U<`!3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R
M90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I
M;G1E;F%N8V4`4VMI<'!E9"XN+@!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N
M;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO
M=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E
M;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@
M069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R
M9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(
M96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@
M8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A
M8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#
M:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@
M<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T
M('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T871U<R!F;W(@;&]C
M86QE("5S+BXN(`!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I
M:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`G)7,G(&YO="!F
M;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D
M("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL
M('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U
M8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@)R5S)RX`4W5C8V5S
M<V9U;&QY(')E;6]V960@)R5S)R!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`G)7,G`%-U8V-E<W-F
M=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`
M4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T
M`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M
M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I
M='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@
M07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O
M<FUS`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O
M<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II
M:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!4
M87-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E
M;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@)R5S)R!N;W0@9F]U
M;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H96QP(&9I
M;&4@9F]R("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O
M;F4N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL
M92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W
M97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE
M;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS
M(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T
M96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL
M(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O
M(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E
M<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E
M;B!E9&ET;W(N`%1H92!H96QP(&9I;&4@)7,@9&ED;B=T('-T87)T('=I=&@@
M/#]X;6P`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T
M("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E
M<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4
M:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R
M>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D
M871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("<E
M<R<@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N
M`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T
M(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@9&]E<VXG="!Y970@97AI<W0@
M82!H96QP(&9I;&4@9F]R("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R`G)7,G('1O('1H92!S>7-T96TN("5S+@!4:&5R92!W87,@82!P<F]B;&5M
M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y
M<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M
M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("<E
M<R<Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T
M:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O
M<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO
M;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A
M9V5S(&9R;VT@=&AE('AM;"!P87)S97(N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN92X`
M5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL
M97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T
M<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I
M;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A
M>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O
M;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T960`5')A;G-L871I
M;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI
M<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`
M5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO
M:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B
M;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT
M<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA
M8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@
M=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>0!5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T
M;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@
M8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER
M871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&-O;6UA;F0Z("5S`%5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%
M>'1E;G-I;VX`56YT<F%N<VQA=&5D`%5P9&%T90!5<&1A=&4@)7,`57!D871E
M('5S97(`57!D871E9"`G)7,G+@!5<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R
M("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y
M`%5S86=E.@!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!N
M;W0@9F]U;F0`57-E<B!N;W0@9F]U;F0N`%5S97(@<&5R;6ES<VEO;G,`57-E
M<FYA;64`57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z
M`%5S97)N86UE.B``57-E<G,`57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI
M<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!6
M86QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E
M(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M
M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T
M:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE
M=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B
M('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G
M:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A
M9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@86YD($9U='5N80!787)N
M:6YG`%=A<FYI;F<Z(`!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T
M82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY
M`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)
M4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA
M<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L
M;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I
M<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T
M:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H
M(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN
M9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D
M;VT`5VES:&QI<W1S`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)I
M=&EN9R!U<&1A=&5D(&AE;'`@9FEL92!T;R`E<RX`6"U2968`6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+
M97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O
M(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO
M=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL
M(&YA;64N`%EO=2!C86XG="!C:&%N9V4@<&%S<W=O<F0@9F]R('5S97(@)7,`
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@
M9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@
M=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L
M;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G
M*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;P!9;W4@;75S="!G:79E('EO=7(@8W5R<F5N="!P87-S=V]R
M9`!9;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D`%EO=2!M=7-T('-E
M;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R
M9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@
M;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0`66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@
M061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S
M<R!#;VYT<F]L+T]P=&EO;B`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA
M;64Z`%EO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@86YD(&1O97,@
M;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+@I.;W0@86QL('-T<FEN9W,@=VEL
M;"!B92!E>'1R86-T960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO;F<[('!A<W-W;W)D<R!M
M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T97)S(&QO;F<A`%EO=7(@
M;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,A("!.;W0@8VAA
M;F=E9"$`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G=65S
M<RX@3F]T(&-H86YG960A`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@870@
M;&5A<W0@)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&)E(&1I9F9E<F5N="!F<F]M('EO=7(@8W5R<F5N="!P87-S=V]R9`!9
M;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP
M:&%B971I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O
M;G1A:6X@870@;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N`%EO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!D:69F
M97)E;G0@='EP97,@;V8@8VAA<F%C=&5R<RX@5&AE('1Y<&5S(&%R93H@;&]W
M97(L('5P<&5R+"!N=6UE<FEC+"!A;F0@<WEM8F]L<RX`66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&QO=V5R8V%S92!C:&%R
M86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@;G5M97)I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@=7!P97)C87-E(&-H87)A8W1E<G,N
M`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!L97-S('1H86X@)60@
M=VAI=&5S<&%C92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T
M(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA<F%C=&5R<RX`66]U<B!N97<@
M<&%S<W=O<F1S(&1I9&XG="!M871C:`!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C
M:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S
M=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B
M;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T
M:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y
M($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN
M+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@
M8F]O:P!A;B!E<G)O<B!H87,@;V-C=7)E9#H`8V%L96YD87(`8V%L;0!C;&EC
M:R!H97)E`&1O;F4`9F%I;&5D`&9A;&QI;F<`9FEL90!F;W5N9#H@`&9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,`:#H`:&@`:6UM961I871E`&EN;&EN90!L
M9&%P7W-T87)T7W1L<R!F86EL960`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D
M92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!C:&%N9V5D`&YO
M="!F;W5N9`!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N
M;W1E<&%D`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S
M`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`=&%S:R!L:7-T`'1H92!(
M;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T(&5X:7-T
M.@!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`
M=6YN86UE9`!U<&1A=&5D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N
M8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@4&%S<W=D+6@S+3,N,`I297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TP."TR-B`R,SHP,RLP,C`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#4M,#@M,C8@,C,Z,S`K,#(P,`I,87-T+51R86YS;&%T;W(Z(%1H
M:65R<GD@5&AO;6%S(#QT:&EE<G)Y0'!O;7!O+FYE=#X*3&%N9W5A9V4M5&5A
M;3H@1G)E;F-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX
M.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM
M1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`^(#$I.PH`("`M32P@+2UM
M97-S86=E/4U%4U-!1T4@(%5T:6QI<V5R(&-E(&UE<W-A9V4@9&4@=F%L:61A
M=&EO;B#@(&QA('!L86-E(&1E(&-E;'5I('!A<B!DZ69A=70N("``("`M82P@
M+2UA9&0]1DE#2"`@("`@("`@06IO=71E<B!C92!F:6-H:65R(%!/(&%U(&-O
M;7!E;F1I=6TN(%5T:6QE('!O=7(*("`@("`@("`@("`@("`@("`@("`@("`@
M:6YC;'5R92!U;B!C;VUP96YD:75M(&0G=6YE(&)R86YC:&4@9&EF9NER96YT
M92!A=0H@("`@("`@("`@("`@("`@("`@("`@("!C;VUP96YD:75M(&?I;NER
MZ2X`("`M8BP@+2UB87-E/2]215`@("!#:&5M:6X@8V]M<&QE="!V97)S(&QE
M('+I<&5R=&]I<F4@9&4@8F%S92`H2&]R9&4I(.`*("`@("`@("`@("`@("`@
M("`@("!U=&EL:7-E<BX`("`M8RP@+2UC;VUP96YD:75M/49)0T@@($9U<VEO
M;FYE<B!L97,@;F]U=F5L;&5S('1R861U8W1I;VYS(.`@8V4@9FEC:&EE<@H@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]M<&5N9&EU;2#@(&QA('!L86-E
M(&1E(&-E;'5I('!A<B!DZ69A=70@*&-O;7!E;F1I=6TN<&\*("`@("`@("`@
M("`@("`@("`@("`@("`@(&1A;G,@;&4@<NEP97)T;VER92!H;W)D92]P;RDN
M`"`@+6,L("TM8V]M<&5N9&EU;3U&24-(("!5=&EL:7-E<B!C92!F:6-H:65R
M(&-O;7!E;F1I=6T@X"!L82!P;&%C92!D92!C96QU:0H@("`@("`@("`@("`@
M("`@("`@("`@("`@<&%R(&3I9F%U="`H8V]M<&5N9&EU;2YP;R!D86YS(&QE
M('+I<&5R=&]I<F4@:&]R9&4O<&\I+@`@("UD+"`M+61E8G5G("`@("`@($%F
M9FEC:&5R(&QE<R!M97-S86=E<R!D)V5R<F5U<B!D97,@<')O9W)A;6UE<R!E
M>.EC=73I<RX`("`M9"P@+2UD:7)E8W1O<GD]4D50("`@0W+I97(@;&4@8V]M
M<&5N9&EU;2!D86YS(&-E('+I<&5R=&]I<F4N`"`@+6@L("TM:&5L<"`@("`@
M("`@069F:6-H97(@8V4@;65S<V%G92!D)V%I9&4N`"`@+6PL("TM;&]C86QE
M/6QL7U!0("`@("!.)W5T:6QI<V5R('%U92!C971T92!L;V-A;&4N`"`@+6PL
M("TM;&]C86QE/6QL7U!0("`@("!5=&EL:7-E<B!C971T92!L;V-A;&4N`"`@
M+6PL("TM;&]C86QE/6QL7U!0("`@(%5T:6QI<V5R(&-E='1E(&QO8V%L92X`
M("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($YE(&?I;NER97(@;&5S(&9I8VAI
M97)S($U/('%U92!P;W5R(&-E(&UO9'5L92`H2&]R9&4I+@`@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@3F4@9G5S:6]N;F5R(&QE<R!F:6-H:65R<R!03R!Q
M=64@<&]U<B!C92!M;V1U;&4@*$AO<F1E*2X@`"`@+6TL("TM;6]D=6QE/4U/
M1%5,12`@("!.92!V86QI9&5R(&QE<R!T<F%D=6-T:6]N<R!Q=64@<&]U<B!C
M92!M;V1U;&4@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@3F4@
M8W+I97(@=6X@9FEC:&EE<B!03R!Q=64@<&]U<B!C92!M;V1U;&4@*$AO<F1E
M*2X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($YE(&9U<VEO;FYE<B!L97,@
M9FEC:&EE<G,@4$\@<75E('!O=7(@8V4@;6]D=6QE("A(;W)D92DN`"`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!.92!M+B#@(&HN(&QE<R!F:6-H:65R<R!D
M)V%I9&4@<75E('!O=7(@8V4@;6]D=6QE("A(;W)D92DN`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@("!.92!M+B#@(&HN('%U92!C92!M;V1U;&4@*$AO<F1E
M*2X`("`M;2P@+2UM;V1U;&4]34]$54Q%("!.92!GZ6[I<F5R('5N(&9I8VAI
M97(@4$]4('%U92!C92!M;V1U;&4@*$AO<F1E*2X`("`M;BP@+2UN;RUC;VUP
M96YD:75M("`@($YE('!A<R!F=7-I;VYN97(@;&5S(&YO=79E;&QE<R!T<F%D
M=6-T:6]N<R!A=2!C;VUP96YD:75M+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@
M("`@3F4@<&%S('5T:6QI<V5R(&1E(&-O;7!E;F1I=6TN`"`@+7,L("TM<W1A
M=&ES=&EC<R`@("`@("!%;G)E9VES=')E<B!L97,@<W1A=&ES=&EQ=65S(&1E
M('1R861U8W1I;VX@9&%N<R!U;B!F:6-H:65R(&QO8V%L+@`@("UT+"`M+71E
M<W0@("`@("`@($%F9FEC:&5R(&QE<R!C;VUM86YD97,@X"!E>.EC=71E<B!S
M86YS(&QE<R!L86YC97(N`"`@8VQE86YU<"`@("`@169F86-E<B!L97,@9FEC
M:&EE<G,@4$\@<&]U<B!L97,@96YT<NEE<R!N;VXM=')A9'5I=&5S(&5T(&]B
M<V]LZ'1E<RX`("!C;VUM:70@("`@("!686QI9&5R(&QE<R!T<F%D=6-T:6]N
M<R!S=7(@;&4@<V5R=F5U<B!#5E,N`"`@8V]M;6ET+6AE;'`@5F%L:61E<B!L
M97,@9FEC:&EE<G,@9"=A:61E('-U<B!L92!S97)V975R($-64RX`("!C;VUP
M96YD:75M("!296-O;G-T<G5I<F4@;&4@9FEC:&EE<B!C;VUP96YD:75M+B!!
M='1E;G1I;VZ@.B#G82#I8W)A<V4@;&4*("`@("`@("`@("`@("!C;VUP96YD
M:75M(&-O=7)A;G0N`"`@97AT<F%C="`@("`@1^ENZ7)E<B!L97,@9FEC:&EE
M<G,@4$\@;6]DZ&QE<R`H+G!O="DN`"`@:&5L<"`@("`@("`@069F:6-H97(@
M8V4@;65S<V%G92!D)V%I9&4N`"`@:6YI="`@("`@("`@0W+I97(@=6X@;W4@
M<&QU<VEE=7)S(&9I8VAI97)S(%!/('!O=7(@=6YE(&YO=79E;&QE(&QO8V%L
M92X*("`@("`@("`@("`@("!!='1E;G1I;VZ@.B#G82#I8W)A<V4@;&5S(&9I
M8VAI97)S(%!/(&5X:7-T86YT<R!P;W5R(&-E='1E(&QO8V%L92X`("!M86ME
M("`@("`@("!#;VYS=')U:7)E(&1E<R!F:6-H:65R<R!B:6YA:7)E<R!-3R!P
M;W5R(&QE<R!F:6-H:65R<R!03R!S<.EC:69IZ7,N`"`@;6%K92UH96QP("`@
M36%R<75E<B"KH.`@:F]U<J"[('1O=71E<R!L97,@96YT<NEE<R!D=2!F:6-H
M:65R(&0G86ED92!834P@970*("`@("`@("`@("`@("!P<NEP87)E<B!L92!F
M:6-H:65R('!O=7(@;&$@<')O8VAA:6YE(&5XZ6-U=&EO;B!D)W5P9&%T92UH
M96QP+B!6;W5S"B`@("`@("`@("`@("`@;F4@9&5V<FEE>B!L86YC97(@;6%K
M92UH96QP('%U)T%04LA3('5P9&%T92UH96QP(&5T(&%P<NAS(&%V;VER(&UI
M<PH@("`@("`@("`@("`@(&QE(&9I8VAI97(@9"=A:61E(.`@:F]U<BX`("!M
M97)G92`@("`@("!&=7-I;VYN97(@;&4@9FEC:&EE<B!03R!C;W5R86YT(&%V
M96,@;&4@9FEC:&EE<B!M;V3H;&4@4$]4(&-O=7)A;G0N`"`@=7!D871E("`@
M("`@3&%N8V5R(&5X=')A8W0@970@;65R9V4@X"!L82!S=6ET92X`("!U<&1A
M=&4M:&5L<"!%>'1R86ER92!T;W5T97,@;&5S(&5N='+I97,@;F]U=F5L;&5S
M(&5T(&UO9&EF:>EE<R!D=2!F:6-H:65R(&0G86ED90H@("`@("`@("`@("`@
M(%A-3"!A;F=L86ES(&5T(&QE(&9U<VEO;FYE<B!A=F5C(&-E=7@@<75I(&5X
M:7-T96YT+@`@)B,Q-3$[("5S(',G87!P<NIT92#@(&5F9F5C='5E<B!L97,@
M;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92!C;V-HZ65S(&-I+61E<W-O=7,N
M`"`H:6P@>2!A("5S(&IO=7)S*0`@*%1O=6-H92!D)V%C8^AS(')A<&ED92`E
M<RD`("AD86YS("5S(&IO=7)S*0`@*&%U:F]U<F0G:'5I*0`@*&1E;6%I;BD`
M("AH:65R*0`@X"``)60@)7,@970@)7,`R6-R:71U<F4@9&4@)60@;V-T971S
M+@`E9"!S=7(@)60@96YT<NEE<R!M87)Q=>EE<R"KH.`@:F]U<J"[`"5D+7!R
MZ79I<VEO;B!D=2!J;W5R`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N
M`$5M<')E:6YT92!01U`@9&4@)7,`)7,@2V\`)7,@;W#I<F%T:6]N<R!D92!M
M86EN=&5N86YC92`F;F1A<V@[($-O;F9I<FUA=&EO;@!#;VYF:6=U<F%T:6]N
M(&1E("5S`$EN<V-R:7!T:6]N(&1E("5S`$-O;F1I=&EO;G,@9"=U=&EL:7-A
M=&EO;B!D92`E<P`E<R!E>&ES=&4@9.EJX"X`("5SH.`@)7,@)7,`)7,@;B=E
M>&ES=&4@<&%S(&]U(&XG97-T('!A<R!E>.EC=71A8FQE+@`E<R!E<W0@<')O
M=.EGZ2!E;B#I8W)I='5R92X`)7,@97-T(&]B;&EG871O:7)E`"5S(&UI;G5T
M97,`)7,@;F]N('1R;W5VZ0`E<R!N;VX@=')O=7;I+B!,86YC97H@9"=A8F]R
M9""KH'1R86YS;&%T:6]N(&5X=')A8W2@NRX`)7.@X"`E<R!D92`E<P!#87)N
M970@9"=A9')E<W-E<R!D92`E<P!!9V5N9&$@9&4@)7,`0FQO8RUN;W1E<R!D
M92`E<P!,:7-T92!D92!TXF-H97,@9&4@)7,`)7.@.B`E<P`E<Z`Z(&-H87)G
M96UE;G0@9'4@<&EL;W1E("5S(&EM<&]S<VEB;&4`JZ`E<Z"[(&XG97-T('!A
M<R!U;B!C:&]I>"!V86QI9&4N`*N@)7.@NR!N)V5S="!P87,@8V]N9FEG=7+I
M(&1A;G,@;&4@<F5G:7-T<F4@9&4@2&]R9&4N`$PG:6YT97)P<NET975R(&0G
M87)B<F4@JZ`E<Z"[(&XG82!P87,@Z73I('1R;W5VZ2X`JZ`E<Z"[(&$@Z73I
M(&%J;W5TZ2!A=7@@9W)O=7!E<RX`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S
M>7-TZ&UE(&1E<R!P97)M:7-S:6]N<RX`JZ`E<Z"[(&XG82!P87,@Z73I(&-R
MZ>F@.B`E<RX`<F%F86QE("5S("5S`'9A<FEA8FQE(&1U("5S(&%U("5S`"TM
M(%/I;&5C=&EO;FYE<B`M+0`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T`
M1F]R;6%T(#$R(&AE=7)E<P!&;W)M870@,C0@:&5U<F5S`#(T(&AE=7)E<P`\
M4'+I8^ED96YT`$PGZ71I<75E='1E(#QG971T97AT/B!N)V5S="!P87,@9F5R
M;>EE(&1A;G,@;&4@9FEC:&EE<B`E<RX*R71I<75E='1E(&]U=F5R=&4@=')O
M=7;I(.`@;&$@;&EG;F4@)60N`%5N92!B87-E(&1E(&1O;F[I97,@<')I;F-I
M<&%L92`H8F%C:V5N9"D@97-T(&[I8V5S<V%I<F4@<&]U<B!C92!B;&]C`%5N
M92!E<G)E=7(@9F%T86QE(',G97-T('!R;V1U:71E`%5N92!C;&5F('!U8FQI
M<75E(%!'4"!E<W0@;NEC97-S86ER92!P;W5R(&-H:69F<F5R('5N(&UE<W-A
M9V4N`%5N92!C;&5F('!U8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P;W5R
M(';I<FEF:65R(&QA('-I9VYA='5R92!D)W5N(&UE<W-A9V4N`%5N92!C;&5F
M('!U8FQI<75E(%!'4"P@=6YE(&-L968@<')I=NEE(%!'4"P@970@=6YE('!H
M<F%S92!S96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U<B!DZ6-H:69F<F5R
M('5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%!'4"P@=6YE(&-L968@
M<')I=NEE(%!'4"P@970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@;NEC97-S
M86ER97,@<&]U<B!S:6=N97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ
M=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@<&AR
M87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E<R!P;W5R(&3I8VAI9F9R97(@
M=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%+"!U;F4@8VQE
M9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="!N
MZ6-E<W-A:7)E<R!P;W5R('-I9VYE<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P
M=6)L:7%U92!3+TU)344@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF9G)E<B!U
M;B!M97-S86=E+@!%<G)E=7(@041322`E<RX`3G5A9V5S(&QE(&UA=&EN`%!L
M=6EE(&SI9^AR92!L92!M871I;@!0;'5I92!L92!M871I;@!!=F5R<V5S(&QE
M(&UA=&EN`$-H=71E<R!D92!N96EG92!L92!M871I;@!!32]030!!4$D@240`
MP"!P<F]P;W,@9&4@8V5T(.ED:71E=7(`P"!P<F]P;W,N+BX`0F%S(&%B<V]L
M=0!-:6QI974@86)S;VQU`$%C8^AS(')E9G5SZ2X`06-CZ',@<F5F=7/I(&QO
M<G,@9&4@;&$@8W+I871I;VX@9&4@<NEP97)T;VER92!61E,@+@!!8V/H<R!R
M969U<^D@;&]R<R!D92!L82!C<NEA=&EO;B!D92!F:6-H:65R(%9&4RX`36]T
M(&1E('!A<W-E(&1U(&-O;7!T90!#;VUP=&4@:6YA8W1I=ND`0V]M<'1E<P!!
M:F]U=&5R`$%J;W5T97(@=6X@<V]U<RUG<F]U<&4`06IO=71E<B!U;F4@;F]U
M=F5L;&4@<V]U<RUP97)M:7-S:6]N`$%J;W5T97(@:6-IH#H`06IO=71E<B!U
M;B!N;W5V96%U(&=R;W5P90!!:F]U=&5R('5N92!N;W5V96QL92!P97)M:7-S
M:6]N`$%J;W5T97(@=6X@9W)O=7!E(&9I;',@X""KH"5SH+L`06IO=71E<B!U
M;F4@<&5R;6ES<VEO;B!F:6QL92#@(*N@)7.@NP!!:F]U=&5R('5N(&YO=79E
M;"!U=&EL:7-A=&5U<J`Z`$%J;W5T97(@=6YE(&-O;&]N;F4`06IO=71E<B!D
M92!N;W5V96%U>"!M96UB<F5S`$%J;W5T97(@=6YE('!A:7)E`$%J;W5T97(@
M;&4@;65N=2`E<R#@(&QA(&)A<G)E(&1E($UO>FEL;&$`06IO=71E<B!A=2!C
M87)N970@9"=A9')E<W-E<Z`Z`$%J;W5T97(@X"!M;VX@8V%R;F5T(&0G861R
M97-S97,`06IO=71E<B!U;B!U=&EL:7-A=&5U<@"KH"5SH+L@82#I=.D@86IO
M=73I(&%U('-Y<W3H;64L(&UA:7,@;"=A:F]U="!D)VEN9F]R;6%T:6]N('-U
M<'!LZ6UE;G1A:7)E<R`E<R!N)V5S="!P87,@<&]S<VEB;&4N`*N@)7.@NR!A
M(.ETZ2!A:F]U=.DN(%9O=7,@<&]U=F5Z('9O=7,@8V]N;F5C=&5R+@!!:F]U
M="!D92!N;W5V96%U>"!F:6-H:65R<R!A=2!DZ7#T=*`Z`$QA(&9O;F-T:6]N
M(&0G86IO=70@9"=U=&EL:7-A=&5U<G,@97-T(&3I<V%C=&EVZ64N`$%D<F5S
M<V4`0V%R;F5T(&0G861R97-S97,`061M:6YI<W1R871E=7(@+2!A:G5S=&5R
M(&QE<R!P97)M:7-S:6]N<R!P;W5R(&0G875T<F5S('5T:6QI<V%T975R<P!!
M9&UI;FES=')A=&EO;@!0=6)S`$%F9VAA;FES=&%N`$%L8F%N:64`06QGZ7)I
M90!!;&EA<P!!;&EG;F5R`$%L:6=N96UE;G2@.@!4;W5T`%1O=7,@;&5S('!A
M<G1I8VEP86YT<R!A=71H96YT:69IZ7,`5&]U<R!L97,@9W)O=7!E<P!4;W5T
M97,@;&5S('!E<FUI<W-I;VYS`$QE<R!Q=6%T<F4@8_1TZ7,`4&5R;65T=')E
M(&1E<R!A9')E<W-E<R!D92!C;W5R<FEE;"!M=6QT:7!L97,`075T;W)I<V5R
M(&QA(&UI<V4@96X@<&QA8V4@9&4@;&ES=&5S(&YU;>ER;W3I97.@/P!E>&ES
M=&4@9.EJX`!.;VT@9"=U=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68`36]T
M(&1E('!A<W-E($E-4U`@86QT97)N871I9@!.;VT@9"=U=&EL:7-A=&5U<B!)
M35-0(&%L=&5R;F%T:68`061R97-S92!D92!C;W5R<FEE;"!A;'1E<FYA=&EV
M90!!=71R97,@;6]DZ&QE<P!497AT92!A;'1E<FYA=&EFH#H`4V%M;V$@06WI
M<FEC86EN`%5N92!V86QE=7(@:6QLZ6=A;&4@82#I=.D@<W#I8VEF:>EE+@!5
M;F4@97)R975R(&EN8V]N;G5E(',G97-T('!R;V1U:71E+@!!;F1O<G)E`$%N
M9V]L80!!;F=U:6QL80!0<F]X>2!A;F]N>6UE`%+I<&]N<V4`06YT87)C=&EQ
M=64`06YT:6=U82UE="U"87)B=61A`$%P<&QI8V%T:6]N`$QI<W1E(&0G87!P
M;&EC871I;VYS`$PG87!P;&EC871I;VX@97-T('!RZG1E`$%P<&QI<75E<B!A
M=7@@<&%R=&%G97,@9FEL<P!!<'!R;W5VZ0!486EL;&4@87!P<F]X:6UA=&EV
M90!!=G)I;`!!<F%B92`H5VEN9&]W<RTQ,C4V*0!486EL;&4@9'4@9FEC:&EE
M<B!A<F-H:79E`$YO;2!D92!L)V%R8VAI=F4`RG1E<RUV;W5S(&-E<G1A:6X@
M9&4@=F]U;&]I<B!S=7!P<FEM97(@8V5T=&4@<F5Q=>IT92!D)VEN<V-R:7!T
M:6]N("!P;W5R("5SH#\`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E
M9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U<RUG<F]U<&5SH#\`07)G96YT:6YE
M`$%R;>EN:64`07)MZ6YI96X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N
M<VEO;B`HSFQE*0!!<G0@05-#24D`4NEG:6]N($%S:64O4&%C:69I<75E`$1E
M;6%N9&5R('5N92!C;VYF:7)M871I;VX@879A;G0@9&4@;&%N8V5R(&QE<R!O
M<.ER871I;VYS(&1E(&UA:6YT96YA;F-EH#\`0V]L;VYN97,@9&5S('3B8VAE
M<P!496YT871I=F4@9"=E9F9A8V5M96YT(&0G=6X@9W)O=7!E(&EN97AI<W1A
M;G0N`%1E;G1A=&EV92`@9"=E9F9A8V5M96YT(&0G=6YE('!E<FUI<W-I;VX@
M:6YE>&ES=&%N=&4N`%1E;G1A=&EV92!D92!M;V1I9FEC871I;VX@9"=U;F4@
M<&5R;6ES<VEO;B!I;F5X:7-T86YT92X`5&5N=&%T:79E(&1E(&UO9&EF:6-A
M=&EO;B!D)W5N('!A<G1A9V4@:6YE>&ES=&%N="X`4')O<')IZ73I<P!!;_MT
M`$%U<W1R86QI90!!=71R:6-H90!!=71H7V-Y<G5SH#H@17AT96YS:6]N(')E
M<75I<V4@24U!4"!N;VX@=')O=7;I92X`075T:%]C>7)U<Z`Z(&QE(&)A8VME
M;F0@;B=A('!A<R!L97,@8V%P86-I=.ES(')E<75I<V5S+@!!=71H7V-Y<G5S
MH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I90!!=71H7V9T
M<*`Z(&5X=&5N<VEO;B!R97%U:7-E($944"!N;VX@=')O=7;I92X@26P@9F%U
M="!C;VUP:6QE<B!02%`@879E8R!L)V]P=&EO;B`M+65N86)L92UF='`N`$%U
M=&A?:6UA<*`Z(&5X=&5N<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64N
M`$%U=&A?:W)B-:`Z(&5X=&5N<VEO;B!R97%U:7-E(&MR8C4@;F]N('1R;W5V
MZ64N`$%U=&A?;&1A<*`Z(&5X=&5N<VEO;B!R97%U:7-E($Q$05`@;F]N('1R
M;W5VZ64N`$%U=&A?;&1A<#H@26UP;W-S:6)L92!D)V%J;W5T97(@;"=U=&EL
M:7-A=&5U<B`E<RX@($-E8VD@97-T(&QA('+I<&]N<V4@9'4@<V5R=F5U<J`Z
M(`!!=71H7VQD87`Z($EM<&]S<VEB;&4@9&4@<W5P<')I;65R(&PG=71I;&ES
M871E=7(@)7,`075T:%]L9&%P.B!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E
M(&PG=71I;&ES871E=7(@)7,`075T:%]M8V%LH#H@97AT96YS:6]N(')E<75I
M<V4@34-!3"!N;VX@=')O=7;I92X`075T:%]S;6)A=71HH#H@97AT96YS:6]N
M(')E<75I<V4@<VUB875T:"!N;VX@=')O=7;I92X`R6-H96,@9&4@;"=A=71H
M96YT:69I8V%T:6]N`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO;B`E<P!,
M92!S97)V975R(%)!1$E54R!A(')E:F5TZ2!L)V%U=&AE;G1I9FEC871I;VXN
M`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO;B!S97)V975R($944`!#:&%M
M<',@9&ES<&]N:6)L97.@.@!!>F5R8F'O9&IA;@!%>&-U<V5S($)/1D@`1&]R
M<V%L(&EN8V]R<F5C=&5M96YT(&EM<&SI;65N=.DN`$-O=6QE=7(@9&4@9F]N
M9`!#;W5L975R(&1E(&9O;F0`36]T(&1E('!A<W-E($ME<F)E<F]S(&5R<F]N
MZ2X`3F]M(&1E(&-O;FYE>&EO;B!+97)B97)O<R!E<G)O;NDN`$)A:&%M87,`
M0F%H<F%I;@!"86QT92`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D
M90!2Z7!E<G1O:7)E(&1E<R!G<F%P:&EQ=65S(*N@)7.@NR!N;VX@=')O=7;I
M+@!,:6=N92!D92!B87-E`$+I;&%R=7,`0F5L9VEQ=64`0F5L:7IE`$+I;FEN
M`$)E<FUU9&5S`$)H;W5T86X`06YN:79E<G-A:7)E`$)L;V,@JR5S(+L@9&4@
M;"=A<'!L:6-A=&EO;B"K("5S(+L@:6YC;VYN=0!0<NEFZ7)E;F-E<R!D92!B
M;&]C`%1Y<&4@9&4@8FQO8P!'<F%S`$)O;&EV:64`4VEG;F5T<P!";W)D=7)E
M`,EP86ES<V5U<B!D92!L82!B;W)D=7)EH#H`0F]R9',`0F]S;FEE+4AE<GKI
M9V]V:6YE`$QE<R!D975X`$)O='-W86YA`$)A<P!";W5V970`0G+I<VEL`%1E
M<G)I=&]I<F5S(&)R:71A;FYI<75E<R!D92!L)T]CZ6%N($EN9&EE;@!"<G5N
M96D@1&%R=7-S86QA;0!#;VYS=')U8W1I;VX@9&5S(&9I8VAI97)S($U/('!O
M=7(@;&4@;6]D=6QE("5S+BXN`$-O;G-T<G5C=&EO;B!D92!L82!L;V-A;&4@
M)7,N+BX@`$)U;&=A<FEE`$QI<W1E(.`@<'5C97,`0G5R:VEN82!&87-O`$)U
M<G5N9&D`1V5S=&EO;B!D92!C;VYT96YU`$-20P!$:7-T<FEB=71I;VX@9&5S
M('!O:6YT<R!,4D,@*$QI<W1E(&1E('+I=F]C871I;VX@9&5S(&-E<G1I9FEC
M871S*0!0<F]P<FGI=.ES(&1E(&QA($-?96QL=6QE`$PG:6YI=&EA;&ES871I
M;VX@9'4@8V%C:&4@;F4@<R=E<W0@<&%S('1E<FUI;NEE+@!!9V5N9&$`0V%L
M;64`0V%M8F]D9V4`0V%M97)O=6X`3F4@<&5U="!P87,@<NEI;FET:6%L:7-E
M<B!L92!M;W0@9&4@<&%S<V4@875T;VUA=&EQ=65M96YT+"!C;VYT86-T97H@
M=F]T<F4@861M:6YI<W1R871E=7(@<WES=.AM92X`R6-H96,@9&4@;&$@8V]N
M;F5X:6]N(&%U('-E<G9E=7(@24U!4*`Z("5S`$-A;F%D80!!;FYU;&5R`$%N
M;G5L97(@;&4@<F%P<&]R="!D=2!P<F]B;.AM90!);7!O<W-I8FQE(&1E('-U
M<'!R:6UE<B!L92!F:6-H:65R(*L@)7,@NRX`26UP;W-S:6)L92!D92!T<F]U
M=F5R('5N('+I<&5R=&]I<F4@=&5M<&]R86ER90!);7!O<W-I8FQE(&1E('!R
M;V/I9&5R('-A;G,@;&4@<&%R86WH=')E(*L@=&%R9V5T1FEL92"[`$EM<&]S
M<VEB;&4@9&4@<W5P<')I;65R(&QE(&1O<W-I97(@JR`E<R"[+@!3=7!P<F5S
M<VEO;B!I;7!O<W-I8FQE+"`@:6P@>2!A(&1E<R!E;G)E9VES=')E;65N=',@
M9FEL<R`E9"X`26UP;W-S:6)L92!D92!RZ6]R9&]N;F5R+"!L92!N;VUB<F4@
M9"?I;.EM96YT<R#@('+I;W)D;VYN97(@;F4@8V]R<F5S<&]N9"!P87,@874@
M;F]M8G)E(&0GZ6SI;65N=',@96YR96=I<W1RZ7,N`$YE('!E=70@9&ER:6=E
M<B!L92!M97-S86=E('9E<G,@;&4@;F]M8G)E('-PZ6-I9FGI+@!#87`M5F5R
M=`!,Z6=E;F1E`$-A=.EG;W)I97,@970@R71I<75E='1E<P#.;&5S($-A[VUA
M;@!4Z6SI<&AO;F4@8V5L;'5L86ER90!0<F]P<FGI=.ES(&1E(&QA(&-E;&QU
M;&4`4F5M<&QI<W-A9V4@875T;W5R(&1E(&QA(&-E;&QU;&6@.@!0<F]P<FGI
M=.ES(&1E(&QA(&-E;&QU;&4`17-P86-E;65N="!D92!L82!C96QL=6QEH#H`
M5.ELZ7!H;VYE(&-E;&QU;&%I<F4@`$-E;'1E("A)4T\M.#@U.2TQ-"D`0V5N
M=')E<@!2Z7!U8FQI<75E(&-E;G1R869R:6-A:6YE`$5U<F]PZ65N(&-E;G1R
M86P@*$E33RTX.#4Y+3(I`$3I=&%I;',@9'4@8V5R=&EF:6-A=`!0<F]P<FGI
M=&%I<F4@9'4@8V5R=&EF:6-A=`!0;VQI=&EQ=64@9&4@8V5R=&EF:6-A=&EO
M;@!48VAA9`!-;V1I9FEE<@!-;V1I9FEC871I;VX@9'4@;6]T(&1E('!A<W-E
M`$UO9&EF:6-A=&EO;B!D=2!M;W0@9&4@<&%S<V4@<W5RH#H`0VAA;F=E<B!L
M92!N;VTL(&PG861R97-S92!E="!L82!S:6=N871U<F4@<75E(&QE<R!P97)S
M;VYN97,@=F]I96YT('%U86YD(&5L;&5S(&QI<V5N="!E="!RZ7!O;F1E;G0@
MX"!V;W,@;65S<V%G97,N`$UO9&EF:6-A=&EO;B!D92!V;W1R92!M;W0@9&4@
M<&%S<V4`36]D:69I97(@=F]T<F4@;6]T(&1E('!A<W-E('-U<B`E<P!#:&%R
M`%;I7W)I9FEE<B!L92!L:65N`%/I;&5C=&EO;FYE>B!L82!O=2!L97,@;W#I
M<F%T:6]N*',I('%U92!V;W5S('9O=6QE>B!E9F9E8W1U97(N`$-H:6QI`$-H
M:6YE`$-H:6YO:7,@<VEM<&QI9FGI("A'0C(S,3(I`$-H:6YO:7,@=')A9&ET
M:6]N;F5L("A":6<U*0!#:&]I<VER('5N(&UO="!D92!P87-S90!#:&]I<VER
M('5N(&YO;2!D92!C;VYN97AI;VX`0VAO:7-I<B!L92!M;V1E(&0G869F:6-H
M86=E(&1E<R!D871E<Z`Z`$-H;VES:7(@;&4@<W1Y;&4@9&4@;&ES=&4@*'!O
M=7(@;&5S(&QI<W1E<R!N=6WI<FEQ=65S*0#.;&5S($-H<FES=&UA<P!$Z69I
M;FET:6]N(&1E(&QA(&-L87-S92!D92`E<R!N;VX@=')O=7;I92X`3F5T=&]Y
M86=E(&1E<R!F:6-H:65R<R!03R!P;W5R(&QE(&UO9'5L92`E<RXN+@!.971T
M;WEA9V4@9&4@;&$@;&]C86QE("5S+BXN(`!%9F9A8V5R`$YE='1O>65R(&QE
M<R!B86QI<V5S($U3+4]F9FEC90!2971I<F5R(&PG=71I;&ES871E=7(Z("5S
M`$5F9F%C97(@;"=U=&EL:7-A=&5U<@!%9F9A8V5R(&QE<R!D;VYNZ65S(&1E
M(&PG=71I;&ES871E=7(`R6-L86ER8VEE<R!T87)D(&1A;G,@;&$@:F]U<F[I
M90!#;&EQ=65R('!O=7(@<&]U<G-U:79R90!#;&EC:V%T96QL('9I82!(5%10
M`$9E<FUE<B!L82!F96[J=')E`$YU86=E<P!.=6%G97,@;6%T:6YA=7@`3G5A
M9V5U>`#.;&5S($-O8V]S`%)E<&QI97(@;&$@8F%R<F4@9&4@8_1TZ0!2Z61U
M:7)E(&QE<R!B;W)D<P!#;VQO;6)I90!#;W5L975R`%!A;&5T=&4@9&4@8V]U
M;&5U<G,`4^EL96-T:6]N(&0G=6YE(&-O=6QE=7(`0V]L<Z`Z`%1I=')E<R!D
M92!C;VQO;FYE`$(N1"X`0V]M;6%N9&4`0V]M;6%N9&4@<VAE;&P`3W!T:6]N
M<R!D92!L82!C;VUM86YD9:`Z`$-O;6UA;F1E<Z`Z`$-O;6UE;G1A:7)E`%9A
M;&ED871I;VZ@.@!.;VT@=7-U96P`0V]M;W)E<P!3;V-IZ73I`%+I9&%C=&EO
M;B!D=2!M97-S86=E("@E<RD`3W)D:6YA=&5U<G,`0V]N9&ET:6]N<P!$:69F
MZ7)E;F-E<R!D92!C;VYF:6=U<F%T:6]N`$QA(&-O;F9I9W5R871I;VX@;B=E
M<W0@<&%S(.`@:F]U<BX`0V]N9FEG=7)E<B`E<P!#;VYF:7)M97(@;&4@;6]T
M(&1E('!A<W-E`$-O;F9I<FUE<B!L92!N;W5V96%U(&UO="!D92!P87-S9:`Z
M`$-O;F=O`%+I<'5B;&EQ=64@9.EM;V-R871I<75E(&1U($-O;F=O`,EC:&5C
M(&1E(&QA(&-O;FYE>&EO;@#)8VAE8R!D92!L82!C;VYN97AI;VZ@.B``0V]N
M;F5X:6]N(&%U('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC(')E9G5SZ64N`$-O
M;FYE>&EO;B!A=2!S97)V975R(&1E(&-L969S('!U8FQI8R!R969U<^EE+B!2
M86ES;VZ@.B`@)7,@*"5S*0#)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R
M=F5U<B!&5%``0V5S(&-O;G1A8W1S(&]N="!B:65N(.ETZ2!A:F]U=.ES(.`@
M=F]T<F4@8V%R;F5T(&0G861R97-S97,N`$-O;G1E;G4@9&4@JZ`E<Z"[`%!O
M=7)S=6EV<F4`SFQE<R!#;V]K`%3I;6]I;B`H8V]O:VEE*0!#;W!I97(`4^EL
M96-T:6]N(&0G=6YE(&-O<&EE`$-O<&EE(&1E("5S('9E<G,@)7,`0V]S=&$@
M4FEC80!#]'1E(&0G279O:7)E`$EM<&]S<VEB;&4@9&4@8VAI9F9R97(@;&4@
M;65S<V%G92X`4VEG;F%T=7)E(%!'4"!D=2!M97-S86=E(&EM<&]S<VEB;&4N
M`$EM<&]S<VEB;&4@9&4@8VAI9F9R97(@;&4@;65S<V%G92!A=F5C(%,O34E-
M12X`4VEG;F%T=7)E(%,O34E-12!D=2!M97-S86=E(&EM<&]S<VEB;&4N`$%J
M;W5T(&1U(&-O;G1A8W0@)7,@:6UP;W-S:6)L92X@`$YE('!E=70@<V4@8V]N
M;F5C=&5R(&%U('-E<G9E=7(@3$1!4`!.92!P975T('-E(&-O;FYE8W1E<B!A
M=2!S97)V975R($Q$05``5NER:69I8V%T:6]N(&1E(&QA(&)A;&%N8V4@)7,@
M:6UP;W-S:6)L92X@`,EC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R
M($Q$05``R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@)7,@=FEA
M($944#H@)7,`26UP;W-S:6)L92!D92!C;W!I97(@)7,@=F5R<R`E<P!#<NEA
M=&EO;B!I;7!O<W-I8FQE(&1E(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B`E
M<P!#<NEA=&EO;B!I;7!O<W-I8FQE(&1U('+I<&5R=&]I<F4@<&]U<B!L82!L
M;V-A;&4@)7.@.@!);7!O<W-I8FQE(&1E(&3I8VAI9F9R97(@;&5S(&1O;F[I
M97,@4$=0+@!);7!O<W-I8FQE(&1E(&3I8VAI9F9R97(@;&5S(&1O;F[I97,@
M4R]-24U%+@!.92!P975T('!A<R!S=7!P<FEM97(@;&4@8V]N=&%C="`E<P!.
M92!P975T('!A<R!S=7!P<FEM97(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N
M("5S`$YE('!E=70@<&%S('-U<'!R:6UE<B!L92!S8W)I<'0@9&4@;6ES92#@
M(&IO=7(@)7,`1.ET97)M:6YA=&EO;B!D92!L)V%D<F5S<V4@9'4@9&5S=&EN
M871A:7)E(&EM<&]S<VEB;&4N`$YE('!E=70@<NEC=7#I<F5R('1O=70@;&4@
M8V%R;F5T(&0G861R97-S92X`3F4@<&5U="!RZ6-U<.ER97(@=&]U=&4@;&$@
M;&ES=&4@9&4@9&ES=')I8G5T:6]N+@!.)V$@<&%S('!U('+I8W5PZ7)E<B!L
M82!L:7-T92!C;VUP;.AT92!D92!L:7-T97,@9&4@9&ES=')I8G5T:6]N+@!)
M;7!O<W-I8FQE(&1E(&-H87)G97(@;&$@<W1R873I9VEE("5S`$EM<&]S<VEB
M;&4@9&4@8W+I97(@;&4@9&]S<VEE<B`G)7,G`$EM<&]S<VEB;&4@9"=O8G1E
M;FER(&QA(&-L968@<'5B;&EQ=64@X"!P87)T:7(@9'4@<V5R=F5U<B!D92!C
M;&5F<RX`3W5V97)T=7)E(&1E("5S(&EM<&]S<VEB;&4N`$]U=F5R='5R92!D
M92`E<R!I;7!O<W-I8FQE(&5N(.EC<FET=7)E+@!);7!O<W-I8FQE(&0G;W5V
M<FER(&QE(&UO9'5L92!-86EN=&5N86YC95]487-K("5S`$]U=F5R='5R92!D
M=2!D;W-S:65R("5S(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9&4@8V]M;75N
M:7%U97(@879E8R!S;6)P87-S=V0N`$QE8W1U<F4@9&4@)7,@:6UP;W-S:6)L
M92X@`$XG82!P=2!R96UE='1R92#@('KI<F\@;&4@;6]T(&1E('!A<W-E('!O
M=7(@;"=U=&EL:7-A=&5U<B!D96UA;F3I+B!#97)T86EN<R`H;W4@=&]U<RD@
M;&5S(&3I=&%I;',@;F4@<V]N="!P87,@8V]R<F5C=',N(%+I97-S87EE>B!O
M=2!C;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E=7(@<&]U<B!D92!L)V%I
M9&4N`%+I8W5PZ7)A=&EO;B!D97,@04-,(&EM<&]S<VEB;&4`3F4@<&5U="!R
MZ6-U<.ER97(@;&4@8V%R;F5T(&0G861R97-S97,N("5S`$YE('!E=70@<NEC
M=7#I<F5R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@)7,`3F4@<&5U="!R
MZ6-U<.ER97(@;&5S(&QI<W1E<R!D92!D:7-T<FEB=71I;VXN("5S`$YE('!E
M=70@<NEC=7#I<F5R(&QE<R!P;W-S:6)I;&ETZ7,@9'4@<V5R=F5U<@!.92!P
M975T('!A<R!R979E;FER(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E;G1E
M+@!%9F9A8V5M96YT(&1U(&1O<W-I97(@)7,@:6UP;W-S:6)L92X@`$YE('!E
M=70@<&%S(&5N<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I;VX@)7,`3F4@<&5U
M="!P87,@96YR96=I<W1R97(@=6YE('-A=79E9V%R9&4@9&4@;&$@8V]N9FEG
M=7)A=&EO;BX`26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R('5N92!C;W!I92!D
M92!L82!C;VYF:6=U<F%T:6]NH#H@)7,N`$YE('!E=70@<&%S(&5N<F5G:7-T
M<F5R(&QE('-C<FEP="!D92!M:7-E(.`@:F]U<B!D86YS.B`G)7,G+@!);7!O
M<W-I8FQE(&0G96YR96=I<W1R97(@=6YE(&-O<&EE(&1U(&9I8VAI97(@9&4@
M8V]N9FEG=7)A=&EO;B`E<RX`26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R(&QE
M(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RX@5F]U<R!P;W5V97H@<V]I
M="!U=&EL:7-E<B!U;F4@9&5S(&]P=&EO;G,@<&]U<B!S875V97(@;&4@8V]D
M92!S=7(@)7,@<V]I="!C;W!I97(@;6%N=65L;&5M96YT(&QE(&-O9&4@8VDM
M9&5S<V]U<R!D86YS("5S+@!.92!P975T('!A<R!R96-H97)C:&5R(&QE('-E
M<G9E=7(@3$1!4`!3=7!P<F5S<VEO;B!D92`E<R!I;7!O<W-I8FQE+@!-:7-E
M(.`@:F]U<B!D=2!C;VYT86-T("5S(&EM<&]S<VEB;&4N(`!.92!P975T(&UE
M='1R92#@(&IO=7(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<P!.92!P
M975T('!A<R!E;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N('!O=7(@)R5S
M)Z`Z("5S`$YE('!E=70@=')O=79E<B!L82!B87)R92!D92!-;WII;&QA+B`@
M07-S=7)E>BUV;W5S('%U)V5L;&4@97-T(&%C=&EV92X`3F4@<&5U="!A='1R
M:6)U97(@8V5S(&1R;VET<R#@(&PG=71I;&ES871E=7(@JZ`E<Z"[("!S=7(@
M;&4@9&]S<VEE<B"KH"5SH+N@.B`E<P!497AT92!C;VUP=.D`4&%Y<P!#;W5R
M<P!#<NEE<@!#<NEE<B!U;B!L:65N`$-RZ65R('5N(&YO=79E874`0W+I97(@
M=6X@<V]U<RUD;W-S:65R`%!E<FUI<W-I;VYS($1E($-RZ6%T975R`$YU;>ER
M;R!D92!C87)T92!D92!C<NED:70`0W)O871I90!#=6)A`#0@<&AA<V5S(&-O
M=7)A;G1E<P!(975R92!A8W1U96QL90!,)V%D<F5S<V4@55),(&%C='5E;&QE
M(&5S=`!/8G-E<G9A=&EO;G,@86-T=65L;&5S`$-O;F1I=&EO;B!A8W1U96QL
M9:`Z(`!3='EL92!C;W5R86YT`$3I9FEN:7(@;&5S('3B8VAE<R#@(&5F9F5C
M='5E<B!L;W)S(&1E(&QA(&-O;FYE>&EO;B#@("5S+@!#;W5P97(`0V]U<&5R
M(&QA('/I;&5C=&EO;@!#:'EP<F4`0WER:6QL:7%U92`H2T])."U2*0!#>7)I
M;&QI<75E("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EQ=64O56MR86EN:65N("A+
M3TDX+54I`%+I<'5B;&EQ=64@5&-HZ'%U90!*2@!#:&%Q=64@:F]U<@!.879I
M9V%T975R(&1E($1A=&%4<F5E`$1A=&4`1&%T92!D92!RZ6-E<'1I;VX`4^EL
M96-T:6]N(&0G=6YE(&1A=&4`2F]U<@!3=7!P<FEM97(@7VQA(&-O;&]N;F4`
M1.EC96UB<F4`3F]M8G)E<R!DZ6-I;6%U>`!$:6UI;G5E<B!L)VEN9&5N=&%T
M:6]N`$3I9F%U=`!#;W5L975R('!A<B!DZ69A=70`261E;G1I=.D@<&%R(&3I
M9F%U=`!097)M:7-S:6]N<R!P87(@9.EF875T`%!E<FUI<W-I;VYS('!A<B!D
MZ69A=70@`$3I9FEN:71I;VYS`$5F9F%C97(`4W5P<')I;65R('5N(&=R;W5P
M90!3=7!P<FEM97(@=6YE('!E<FUI<W-I;VX`4W5P<')I;65R(&5T('!U<F=E
M<B!L97,@;65S<V%G97,`169F86-E<B!L82!C96QL=6QE`$5F9F%C97(@;&$@
M8V]L;VYN90!3=7!P<FEM97(@=6X@875T<F4@;6]DZ&QE(&5X:7-T86YT`%-U
M<'!R:6UE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`RG1E<RUV;W5S
M(&-E<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U
M<RUP97)M:7-S:6]N<Z`_`$5F9F%C97(@;&$@<F%N9^EE`%-U<'!R:6UE<B!L
M)VED96YT:73I('/I;&5C=&EO;F[I90!%9F9A8V5R(&QA(&-O;&]N;F4@86-T
M=65L;&4`169F86-E<B!L82!R86YGZ64@86-T=65L;&4`RG1E<RUV;W5S(&-E
M<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(&-E='1E('!E<FUI<W-I;VX@970@
M<V5S('-O=7,M<&5R;6ES<VEO;G.@/P!38W)I<'0@9&4@8V]N9FEG=7)A=&EO
M;B!D92!M:7-E(.`@:F]U<B!S=7!P<FEMZ2`G)7,G+@!(975R92!D92!L:79R
M86ES;VX`1&%N96UA<FL`1.EC<FER92!L92!P<F]B;.AM90!$97-C<FEP=&EO
M;@!$Z71A:6QS("AA=7-S:2!D86YS(&QE(&9I8VAI97(@9&4@=')A8V5S(&1E
M($AO<F1E*:`Z`$QE<R!DZ71A:6QS(&]N="#I=.D@8V]N<VEG;NES('!O=7(@
M;"=A9&UI;FES=')A=&5U<BX`1.EV96QO<'!E;65N=`!0;VEN="!D92!R;W/I
M90!0;VEN="!D92!R;W/I92!P;W5R(&QA(&1E<FYIZ')E(&AE=7)EH#H@`%!O
M:6YT(&1E(')O<^EEH#H@`$1E(&=A=6-H92#@(&1R;VET90!$92!D<F]I=&4@
MX"!G875C:&4`4NEP97)T;VER90!!9F9I8VAE<B!S=7(@,C0@:&5U<F5SH#\`
M3W!T:6]N<R!D)V%F9FEC:&%G90!!9F9I8VAE<B!L82!P<NEV:7-I;VX@*%1!
M1BD`1F]R;6%T(&0G869F:6-H86=E`$%V:7,@9&4@;&EV<F%I<V]N`$1J:6)O
M=71I`$YE('!A<R!S=7!P<FEM97(`3F4@<&%S(&%C8^ED97(@9&ER96-T96UE
M;G0@X"!M86EN=&5N86YC92YP:'``3&4@<')E;6EE<B!E;G)E9VES=')E;65N
M="!C;VYT:65N="UI;"!L92!N;VT@9&5S(&-H86UP<Z`_($1A;G,@;"=A9F9I
M<FUA=&EV92P@8V]C:&5Z(&-E='1E(&)O[G1EH#H`1&]M:6YI<75E`%+I<'5B
M;&EQ=64@9&]M:6YI8V%I;F4`5.ELZ6-H87)G97(`5.ELZ6-H87)G97(@)7,`
M5.ELZ6-H87)G97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE(&-O;6UE('5N
M('-C<FEP="!02%``3&ES=&4@9.ER;W5L86YT90!$<F]G=65S`$-O=7)R:65R
M(.EL96-T<F]N:7%U90!%4E(`R7%U871E=7(`36]D:69I97(`R61I=&5R(&QE
M(&)L;V,`R61I=&5R('5N(&=R;W5P90#)9&ET97(@=6YE('!E<FUI<W-I;VX`
MR61I=&5R(&QE<R!P97)M:7-S:6]N<P#)9&ET97(@;&5S('!E<FUI<W-I;VYS
M('!O=7(@JZ`E<Z"[`,ED:71E<B!L97,@;W!T:6]N<R!P;W5RH#H`R61I=&5R
M(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NP!-;V1I9FEE<B!L97,@<&5R
M;6ES<VEO;G,@<&]U<B"KH"5SH+L`R61U8V%T:6]N`,EG>7!T90!386QV861O
M<@#);.EM96YT+BXN`$5M`$%D<F5S<V4@Z6QE8W1R;VYI<75E`$%D<F5S<V4@
MZ6QE8W1R;VYI<75E`$QE<R!A9')E<W-E<R#I;&5C=')O;FEQ=65S(&1O:79E
M;G0@8V]R<F5S<&]N9')E+@!#;W5R<FEE;"!A=F5C(&-O;F9I<FUA=&EO;@#)
M;6]T:6/T;F5S`$UE<W-A9V4@=FED92X`4NES=6QT870@=FED92X`5&5R;65S
M(&1E(')E8VAE<F-H92!V:61E`$%C=&EV97(@;"=I;G-E<G1I;VX@9"=I;6%G
M97,@=F5N86YT(&1E<R!A;&)U;7,@<&AO=&]S(&1A;G,@;&4@=&5X=&6@/P!!
M8W1I=F5R(&QE(&UE;G4@8V]N=&5X='5E;"!A=F5C('5N(&-L:6,@9')O:72@
M/P!&:6X@9&4@;"=A;F[I90!!9W)A;F1I<B!L)^ED:71E=7(`R6-R:79E>B!U
M;F4@<75E<W1I;VX@9&4@<^EC=7)I=.D@<74G;VX@=F]U<R!P;W-E<F$@<VD@
M=F]U<R!D979E>B!R96UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E
M+"!P87(@97AE;7!L92"K(%%U96P@97-T(&QE(&YO;2!D92!V;W1R92!A;FEM
M86P@<'+I9NERZ:`_H+N@.@!);G-C<FEV97H@;"=A9')E<W-E(%523"!D92!L
M)VEM86=E(&EC:0!%;G1RZ65SH#H@)60@874@=&]T86PL("5D(.`@:F]U<BP@
M)60@;F]U=F5L;&5S+"`E9"!M;V1I9FGI97,L("5D(&EN8V]N;G5E<P!'=6EN
MZ64@Z7%U871O<FEA;&4`R7)Y=&ARZ64`17)R975R`$5R<F5U<B!L;W)S(&1E
M(&PG96YV;VD@9&4@9&]N;NEE<R!V97)S('-M8G!A<W-W9"X`17)R975R(&%V
M96,@;&4@;65S<V%G92X`17)R975R(&QO<G,@9&4@;"=E;G)E9VES=')E;65N
M="`E<P!%<G)E=7*@.B``17-T;VYI90#)=&AI;W!I90!%=&AN:7%U90!%=7)O
M<&4`5&]U<R!L97,@)F9R86,Q-#L@9"=H975R90!4;W5T97,@;&5S(#(@;6EN
M=71E<P!4;W5T97,@;&5S(#,P('-E8V]N9&5S`%1O=71E<R!L97,@-2!M:6YU
M=&5S`,`@8VAA<75E(&-O;FYE>&EO;@!4;W5T97,@;&5S("9F<F%C,3([(&AE
M=7)E<P!4;W5T97,@;&5S(&UI;G5T97,`17AE;7!L92!D92!V86QE=7)SH#H`
M17CI8W5T97(`17CI8W5T:6]N(&1EH#H`1.EV96QO<'!E<@!$Z7!L:65R(&QA
M(&)A<G)E(&1E(&/T=.D`JR`I(+L@871T96YD=64`56X@<V5U;"!M;W0@;W4@
M97AP<F5S<VEO;B!E;G1R92!G=6EL;&5M971S(&%T=&5N9'5S`$1A=&4@9"=E
M>'!I<F%T:6]N`%)E<'+I<V5N=&%N=`!%>'1R86-T:6]N(.`@<&%R=&ER(&1E
M("5S+BXN(`!#;W5L975R(&0G879A;G0M<&QA;@!4Z6SI8VAA<F=E;65N="!V
M97)S(&QE('-E<G9E=7(@9&4@;&$@8V]N9FEG=7)A=&EO;B!P87(@1E10`$QE
M8W1U<F4@9&5S('!RZ6;I<F5N8V5S(&EM<&]S<VEB;&4N`,EC:&5C(&1E(&QA
M(&-O;FYE>&EO;B!A=2!S97)V975R($Q$05`N`,EC:&5C(&1E(&QA(&-O;FYE
M>&EO;B!A=2!S97)V975R(%--0BX`R6-H96,@9&4@;&$@8V]P:64@9&5P=6ES
M(*L@)7,@NRX`R6-H96,@9&4@;&$@8V]P:64@=F5R<R`@JR`E<R"[+@!);7!O
M<W-I8FQE(&1E(&-RZ65R('5N92!N;W5V96QL92!C;VYN97AI;VX@4T%33`#)
M8VAE8R!D=2!DZ7!L86-E;65N="!V97)S(*L@)7,@NRX`R6-H96,@9&4@;&$@
M=NER:69I8V%T:6]N(&1E(&PG86YC:65N(&UO="!D92!P87-S92X`3&$@;6]D
M:69I8V%T:6]N(&1E('9O=')E(&UO="!D92!P87-S92!S=7(@)7,@82#I8VAO
M=>F@.B`E<P!"96%U`,YL97,@1F%L:VQA;F0@*$UA;&]U:6YE<RD`SFQE<R!&
MZ7)OZ0!%<G)E=7(@9F%T86QEH#H`1F%X`$;I=G)I97(`5&5M<.ER871U<F4@
M<F5S<V5N=&EE`%1E;7#I<F%T=7)E(')E<W-E;G1I9:`Z(`!1=65L<75E<R!A
M=F5R<V5S`%%U96QQ=65S(&-H=71E<R!D92!N96EG90!-871R:6-E(&1E<R!C
M:&%M<',`1FED:FD`3F]M8G)E(&1E(&9I8VAI97)SH#H@)7,`3F]M8G)E(&1E
M(&9I8VAI97)SH#H@)7,`1V5S=&EO;FYA:7)E(&1E(&9I8VAI97)S`$YO;2!D
M=2!F:6-H:65R`$-H;VEX(&1E(&9I8VAI97(`5.ELZ6-H87)G96UE;G0@9&4@
M9FEC:&EE<@!,)V5N=F]I(&1E(&9I8VAI97)S(&XG97-T('!A<R!P<FES(&5N
M(&-O;7!T92X`1FEL=')E<P!&:6YL86YD90!0<F5M:>AR92!D96UI90!0<F5M
M:65R('%U87)T:65R`$9I>&5R(&QE(')A=&EO`$9L:7``1FQO='1A;G0`0G)O
M=6EL;&%R9`!$;W-S:65R("5S(&EN97AI<W1A;G0N`$-O=6QE=7(@9&4@<&]L
M:6-E`$YO=7)R:71U<F4`4&]U<B!L97,@;F%V:6=A=&5U<G,@;F4@<W5P<&]R
M=&%N="!P87,@;&5S(&EM86=E<P!0<NEV:7-I;VX@*%1!1BD`2F]U<G,@9&4@
M<'+I=FES:6]N("AN;W1E>B!Q=64@;&5S('!RZ79I<VEO;G,@9F]U<FYI97,@
M9&]N;F5N="!L92!J;W5R(&5T(&QA(&YU:70[('5N(&=R86YD(&YO;6)R92!I
M8VD@<&5U="!F86ER92!U;B!B;&]C('1RZ',@;&%R9V4`3W5B;&GI('9O=')E
M(&UO="!D92!P87-S93\`1F]R;75L86ER97,`1F]R='5N90!&;W)T=6YE`$9O
M<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`%)E9&ER96-T:6]N`$%P<&QI8V%T
M:6]N<R!T<F]U=NEE<Z`Z("5S`%+I<&5R=&]I<F5S('1R;W5VZ7.@.@!690!#
M861R97,`1G)A;F-E`$9R86YC92!MZ71R;W!O;&ET86EN90!'=7EA;F4@9G)A
M;N=A:7-E`%!O;'ENZ7-I92!F<F%NYV%I<V4`5&5R<F5S(&%U<W1R86QE<R!E
M="!A;G1A<F-T:7%U97,@9G)A;N=A:7-E<P!$90!$=2``1&5S8W)I<'1I;VX@
M8V]M<&SH=&4`4&QE:6YE(&QU;F4`3F]M(&-O;7!L970`07!P<F]X:6UA=&EF
M`$=A8F]N`$%L8G5M(&0G;W)I9VEN92!D92!L)VEM86=E`$%L8G5MH#H`1V%M
M8FEE`$?I;NER97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!#;V1E(&?I;NER
MZ0!'Z6[I<F%T:6]N(&1E(&PGZ71A="!D=2!M;V1U;&4@)7,N+BX`1^EO<F=I
M90!!;&QE;6%G;F4`17)R975R($=E=&]P=*`Z(`!':&%N80!':6)R86QT87(`
M4'+I;F]M`$%L;&5R`$=O961E;`!296-H97)C:&4@1V]O9VQE`$YI=F5A=2!D
M92!G<FES`$=RZ&-E`$=R96,@*$E33RTX.#4Y+3<I`$=R;^MN;&%N9`!'<F5N
M861E`$%D;6EN:7-T<F%T:6]N(&1E<R!G<F]U<&5S`$QE<R!N;VUS(&1E(&=R
M;W5P92!N92!P975V96YT('!A<R#J=')E('9I9&5S`%!E<FUI<W-I;VYS(&1E
M<R!G<F]U<&5S`$=R;W5P97,`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'
M=65R;F5S97D`4&5R;6ES<VEO;G,@9&5S(&EN=FETZ7,`4&5R;6ES<VEO;G,@
M9&5S(&EN=FETZ7,`3&EV<F4@9"=O<@!'=6ENZ64`1W5I;NEE+4)I<W-A=0!'
M=7EA;F$`2%1-3`!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I
M;65R(&QA(&1E<FYIZ')E(&-E;&QU;&4@9&4@;&$@<F%N9^EE`$A434Q!<F5A
M(')E9G5S92!BZG1E;65N="!D92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@8V]L
M;VYN92!D=2!T86)L96%U`$A434Q!<F5A(')E9G5S92!BZG1E;65N="!D92!S
M=7!P<FEM97(@;&$@9&5R;FGH<F4@<F%N9^EE(&1U('1A8FQE874`075T:&5N
M=&EF:6-A=&EO;B!(5%10(&YO;B!T<F]U=NEE+@!(8>]T:0!!;&=O<FET:&UE
M(&1E(&AA8VAA9V4`0G)U;64@<^AC:&4`16XM=.IT90#.;&5S($AE87)D(&5T
M($UC1&]N86QD`$CI8G)E=2`H25-/+3@X-3DM."U)*0!(875T975R`$%I9&4`
M06ED92!P;W5R(&PGZ61I=&5U<@!!:61E`$%S<VES=&%N="!P;W5R(&-RZ65R
M(&5T(&UA:6YT96YI<B!L97,@=')A9'5C=&EO;G,@<&]U<B!(;W)D92!E="!S
M97,*9&EF9NER96YT<R!M;V1U;&5S+@I6975I;&QE>B!L:7)E(&QE(&9I8VAI
M97(@4D5!1$U%(&1E(&-E('+I<&5R=&]I<F4@96X@9W5I<V4@9"=I;G1R;V1U
M8W1I;VXN`$CI;6ES<&CH<F4`5F]I8VD@;&4@9.EB=70@9'4@9FEC:&EE<CH`
M2&%U=&4`3&5S(&YO;7,@9&4@;"=E;G1RZ64@:&ES=&]R:7%U92!N92!P975V
M96YT('!A<R#J=')E('9I9&5S`$%?8V-U96EL`$-I=.D@9'4@5F%T:6-A;@!!
M8V-U96EL`$%D<F5S<V4@<&5R<V]N;F5L;&4`5.ELZ7!H;VYE('!E<G-O;FYE
M;`!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`1^ENZ7)A=&5U<B!D92!T<F%D
M=6-T:6]N<R!D92!(;W)D90!(;W)D92]+;VQA8J`Z(&1O;F[I97,@6$U,("5S
M(&EN=F%L:61E<R!R971R;W5VZ65S(&1A;G,@;&4@;65S<V%G92`E<P!(;W)D
M92]+;VQA8J`Z($%U8W5N(&UE<W-A9V4@;F4@8V]R<F5S<&]N9"!A=2!S=6IE
M="`E<P!(;W)D92]+;VQA8J`Z(%!A<R!D)V]B:F5T(&1E('1Y<&4@)7,@=')O
M=7;I(&1A;G,@;&4@;65S<V%G92`E<P!(;W)D92]+;VQA8J`Z($5N;&5VZ2`E
M<R"K("5S(+L@879E8R!S=6-CZ',`2&]R9&4O2V]L86*@.B!3>6YC:')O;FES
MZ2`E<R"K("5S(+L@879E8R!S=6-CZ',`2&]R9&4O2V]L86*@.B!,92!M;W1E
M=7(@9"=I;G3I9W)A=&EO;B!NZ6-E<W-I=&4@;"=E>'1E;G-I;VX@)V1O;7AM
M;"<@9&4@4$A0`$AO<F1E+TMO;&%BH#H@26UP;W-S:6)L92!D92!C<NEE<B!U
M;B!N;W5V96P@87)B<F4@6$U,('!O=7(@;"=O8FIE="`E<P!(;W)D92]+;VQA
M8J`Z(&EM<&]S<VEB;&4@9"=E;FQE=F5R("5S(*L@)7,@NR`Z("5S`$AO<F1E
M+TMO;&%BH#H@:6UP;W-S:6)L92!D92!RZ6-U<.ER97(@;"=I9&5N=&EF:6%N
M="!-24U%('!O=7(@;&$@<&%R=&EE(&1E('1Y<&4@)7,`2&]R9&4O2V]L86*@
M.B!I;7!O<W-I8FQE(&1E('-Y;F-H<F]N:7-E<B`E<R"K("5S(+L@.B`E<P!(
M;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<WEN8VAR;VYI<V5R(&QE<R!P
M87)T86=E<R`Z("5S`$AO<F1E+TMO;&%BH#H@<&%R=&%G92!I;F-O;FYU(*L@
M)7,@NP!,:6=N92!H;W)I>F]N=&%L90!296UP;&ES<V%G92!H;W)I>F]N=&%L
M`$AO<FEZ;VYT86R@.@!#;VUM96YT(.IT97,M=F]U<R!A<G)I=ND@:6-IH#\@
M*%-64"!R87!P;W)T97HM;&6@(2D`0V]M8FEE;B!D92!C;VQO;FYE<R!V;W5L
M97HM=F]U<R!F=7-I;VYN97*@/P!#;VUB:65N(&1E(&-H86UP<R`H8V]L;VYN
M97,I('D@82UT+6ELH#\`0V]M8FEE;B!D92!R86YGZ65S('9O=6QE>BUV;W5S
M(&9U<VEO;FYE<J`_`$AU;6ED:73I`$AU;6ED:73IH#H@`$AU;6]R:7-T97,`
M2&]N9W)I90#)8VAE8R!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1E(&QA(&)O[G1E
M($E-05"@.B`E<P#)8VAE8R!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E(&QA
M(&)O[G1E($E-05"@.B`E<P#)8VAE8R!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1U
M('%U;W1A('-U<B!L82!B;^YT92!)34%0H#H@)7,`061R97-S92!)4`!!9')E
M<W-E($E0(&YO;B!D:7-P;VYI8FQE+@!!9')E<W-E($E0(&AO<G,@9'4@8FQO
M8R!#2412(&%L;&]UZ2X`5FEO;&%T:6]N(&1E(&)L;V-A9V4@25``25]N<^ER
M97(@<F%N9^EE(&%V86YT`$ES;&%N9&4`26/T;F5S('-E=6QE;65N=`!)8_1N
M97,@<&]U<B`E<P!)8_1N97,@<&QU<R!T97AT90!.;VT@9'4@8V]M<'1EH#H`
M4VD@;"=A9F9I8VAA9V4@;B=E<W0@<&%S(&-O<G)E8W0L("`E<R!P;W5R(&PG
M;W5V<FER(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4N`%-I('9O=7,@;F4@
M=F]Y97H@875C=6X@:6/T;F4@96X@=71I;&ES86YT($EN=&5R;F5T($5X<&QO
M<F5R+"!V;W5S('!O=79E>B!A=F]I<B#@(&-O8VAE<B!C971T92!C87-E('!O
M=7(@9.ES86-T:79E<B!L82!T<F%N<W!A<F5N8V4@9&5S(%!.1RX`4VD@=F]U
M<R!V;WEE>B!C92!M97-S86=E(&UA:7,@875C=6YE(&EM86=E+"!L)VEM86=E
M('%U92!V;W5S('9O=6QE>B!E;G9O>65R(&YE('!E=70@ZG1R92!A9F9I8VCI
M92!P87(@=F]T<F4@;F%V:6=A=&5U<BX`07!E<N=U(&1E(&PG:6UA9V6@.@!!
M9')E<W-E(%523"!D92!L)VEM86=E`$%D<F5S<V4@55),(&1E(&PG:6UA9V6@
M.@!);6%G92!D92!L)V%L8G5M`$EM86=E(&1E(&PG86QB=6V@.@!4Z6SI8VAA
M<F=E;65N="!D)VEM86=E<P!);6%G97,`26UP;W)T871I;VXL(.ET87!E("5D
M`$-H86UP(&EM<&]R=.F@.B`E<P!#:&%M<',@:6UP;W)TZ7.@.@!);E]SZ7)E
M<B!R86YGZ64@87!RZ',`36]T(&1E('!A<W-E(&EN8V]R<F5C=`!#;V1E(&0G
M86-T:6]N(&EN8V]R<F5C="X`3F]M(&0G=71I;&ES871E=7(@970O;W4@=F]T
M<F4@;6]T(&1E('!A<W-E(&EN8V]R<F5C="X`3F]M(&0G=71I;&ES871E=7(@
M;W4@861R97-S92!A;'1E<FYA=&EV92!I;F-O<G)E8W0N("!2Z65S<V%Y97H@
M;W4@8V]N=&%C=&5Z('9O=')E(&%D;6EN:7-T<F%T975R('-Y<W3H;64@<&]U
M<B!D92!L)V%I9&4N`$%U9VUE;G1E<B!L)VEN9&5N=&%T:6]N`$EN9&4`571I
M;&ES871E=7)S(&EN9&EV:61U96QS`$EN9&]NZ7-I90!);F9O`$EN9F]R;6%T
M:6]N<P!);FET:6%L:7-A=&EO;B!D=2!M;V1U;&4@)7,N+BX@`$EN<^ER97(@
M8U]O;&]N;F4@87!RZ',`26YSZ7)E<B!I;6%G90!);G/I<F5R('5N('1A8FQE
M874`26YSZ7)E<B!U;B!L:65N('=E8@!);G/I<F5R(%]C;VQO;FYE(&%V86YT
M`$EN<^ER97(@=6YE(&YO=79E;&QE(&-O;&]N;F4@87!RZ',@;&$@8V]L;VYN
M92!A8W1U96QL90!);G/I<F5R('5N92!N;W5V96QL92!C;VQO;FYE(&%V86YT
M(&QA(&-O;&]N;F4@86-T=65L;&4`26YSZ7)E<B!U;F4@;F]U=F5L;&4@<F%N
M9^EE(&%P<NAS(&QA(')A;F?I92!A8W1U96QL90!);G/I<F5R('5N92!N;W5V
M96QL92!R86YGZ64@879A;G0@;&$@<F%N9^EE(&%C='5E;&QE`$EN<^ER97(@
M=6X@<&%R86=R87!H92!A<'+H<R!L92!N;V5U9"!A8W1U96P`26YSZ7)E<B!U
M;B!P87)A9W)A<&AE(&%V86YT(&QE(&YO975D(&%C='5E;`!);G/I<F5R('5N
M(&%U=')E(&UO9.AL90!);G-C<FEV97H@=6YE(&%D<F5S<V4@9&4@8V]U<G)I
M97(@X"!L87%U96QL92!V;W5S(')E8V5V<F5Z(&QE(&YO=79E874@;6]T(&1E
M('!A<W-EH#H`26YSZ7)E<B!C96QL=6QE(&%P<NAS`$EN<^ER97(@8V5L;'5L
M92!A=F%N=`!);G/I<F5R(&-O;&]N;F4@87!RZ',`26YSZ7)E<B!C;VQO;FYE
M(&%V86YT`$EN<^ER97(@;&5S(&UE<W-A9V5S`$EN<^ER97(@<&%R86=R87!H
M92!A<'+H<P!);G/I<F5R('!A<F%G<F%P:&4@879A;G0`26YSZ7)E<B!R86YG
MZ64@87!RZ',`26YSZ7)E<B!R86YGZ64@879A;G0`26YS8W)I=F5Z(&QA('+I
M<&]N<V4@X"!L82!Q=65S=&EO;B!D92!SZ6-U<FETZ:`Z`$EN<^ER97(O36]D
M:69I97(@=6YE(&EM86=E`$EN<^ER97(O36]D:69I97(@=6X@;&EE;B!W96(`
M0W+I9&ET(&EN<W5F9FES86YT('!O=7(@96YV;WEE<B#@(&QA(&QI<W1E(&1E
M(&1I<W1R:6)U=&EO;BX`0W+I9&ET(&EN<W5F9FES86YT+@!%;G1I97(`3&ES
M=&4@8V]M<&SH=&4`541(("A5<V5R($1A=&$@2&5A9&5R*2!I;G9A;&ED90!!
M<'!L:6-A=&EO;B!I;G9A;&ED92X`1W)O=7!E($E$(&EN=F%L:61E+@!%;G9O
M:2!D92!D;VYNZ65S(&EN=F%L:61E<RX`061R97-S92!D92!D97-T:6YA=&EO
M;B!I;G9A;&ED92X`1F]R;6%T(&1E(&9I8VAI97(@:6YV86QI9&4N`$-L968@
M9&4@;&EC96YC92!I;G9A;&ED92X`16UP;&%C96UE;G0@:6YD:7%UZ2!I;G9A
M;&ED92X`JVUS9U]T>7!ENR!I;G9A;&ED92X`JV%P:5]I9+L@:6YV86QI9&4@
M;W4@;6%N<75A;G0N`%!A<F%MZ'1R97,@:6YV86QI9&5S(&]U(&UA;G%U86YT
M<RX`4&5R;6ES<VEO;B!I;G9A;&ED92X`260N(&1E('!A<G1E;F%I<F4@:6YV
M86QI9&4N`$-O9&4@9&4@<')O9'5I="!I;G9A;&ED92X`4')O=&]C;VQE(&EN
M=F%L:61E+@!$97-T:6YA=&%I<F4@:6YV86QI9&6@.B`G)7,G`$]B:F5T(&1E
M('!A<G1A9V4@:6YV86QI9&4`061R97-S92!S;W5R8V4@:6YV86QI9&4N`$1O
M;F[I92!5;FEC;V1E(&EN=F%L:61E+@!);G9E;G1A:7)E`%+I<'5B;&EQ=64@
M:7-L86UI<75E(&0G27)A;@!)<F%K`$ER;&%N9&4`SFQE(&1E($UA;@!496UP
MZG1E<R!I<V]LZ65S`$ES<F'K;`#);65T=&5U<@!)=&%L:7%U90!)=&%L:64`
M2F%M8>]Q=64`2F%N=FEE<@!*87!O;@!*87!O;F%I<R`H25-/+3(P,C(M2E`I
M`$IE<G-E>0!*;W)D86YI90!*=6EL;&5T`$IU:6X`2G5S=&EF:65R`$-E;G1R
M97(`2G5S=&EF:65R`$%L:6=N97(@X"!G875C:&4`06QI9VYE<B#@(&1R;VET
M90!+87IA:VAS=&%N`$=A<F1E<B!L)V]R:6=I;F%L9:`_`$ME;GEA`$QE('-E
M<G9E=7(@2V5R8F5R;W,@82!R96IE=.D@;"=A=71H96YT:69I8V%T:6]N+@!$
MZ6)U=&%N=',@9'4@;F]Y874`0W+I871I;VX@9&4@8VQE9@!%;7!R96EN=&4@
M9&4@;&$@8VQE9@!,;VYG=65U<B!D92!L82!C;&5F`%1Y<&4@9&4@8VQE9@!5
M=&EL:7-A=&EO;B!D92!L82!C;&5F`$QA(&-L968@<V4@=')O=79E(&3I:N`@
M<W5R(&QE('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC+@!%;F9A;G1S`$MI<FEB
M871I`$-O<NEE(&1U($YO<F0`0V]RZ64@9'4@4W5D`$-O<NEE;B`H155#+4M2
M*0!+;W=E[W0`2VER9VAI>FES=&%N`%!RZ5]S96YT871I;VX`3&%N9W5E`$QA
M;W,`1&5R;FGH<F4@9&5M:64`1&5R;FEE<B!Q=6%R=&EE<@!$97)N:>AR92!M
M:7-E(.`@:F]U<J`Z`$1E<FYIZ')E(&-O;FYE>&EO;J`Z("5S`$1E<FYIZ')E
M(&-O;FYE>&EO;J`Z("5S(.`@<&%R=&ER(&1E("5S`$1E<FYIZ')E(&-O;FYE
M>&EO;J`Z(&IA;6%I<P!,971T;VYI90!,;VD`4'+I<V5N=&%T:6]N`$QA:7-S
M97(@=FED92!P;W5R(&YE('!A<R!A=F]I<B!D92!B;W)D=7)E`$QI8F%N`$=A
M=6-H90!%;G3J=&4@9V%U8VAE`%9A;&5U<G,@9&4@9V%U8VAE`$QE<V]T:&\`
M3&EBZ7)I80!,:6)Y90!,:65C:'1E;G-T96EN`$)R=6EN92!LZ6?H<F4`4&QU
M:64@;.EGZ')E`%!L=6EE(&SI9^AR92!T]'0@9&%N<R!L82!J;W5R;NEE`%!L
M=6EE(&SI9^AR92!T87)D`$%V97)S97,@;.EGZ')E<P!0;'5I92!LZ6?H<F4@
M879E8R!T;VYN97)R90!.96EG92!I;G1E<FUI='1E;G1E`$%V97)S92!D92!N
M96EG92!LZ6?H<F4`4FEM97,`3&EE;@!,92!L:65N('!O:6YT92!V97)SH#H`
M3&EE(&PG861R97-S92!D92!C;W5R<FEE;"#@(&QA('!A9V4@9&4@8V]M<&]S
M:71I;VX@9'4@;65S<V%G92!E;B!L)V%F9FEC:&%N=`!,:65N<P!":7-C=6ET
M($QI;G5X`$QI<W1E("T@=71I;&ES871E=7(@<&5U="!V;VER(&QE(&1O<W-I
M97(`3&ES=&4@9&5S(&)A<V5S(&1E(&1O;F[I97,`26YD97@@9&4@;"=A:61E
M`$%F9FEC:&5R(&QE<R!T86)L97,`07)C:&EV97,@9&4@;&$@;&ES=&4`06ED
M92!D92!L82!L:7-T90!)9"X@9&4@;&$@;&ES=&4`4')O<')IZ71A:7)E(&1E
M(&QA(&QI<W1E`$5N=F]I(.`@;&$@;&ES=&4`06)O;FYE;65N="#@(&QA(&QI
M<W1E`$3I<V%B;VYN96UE;G0@9&4@;&$@;&ES=&4`3"=A9F9I8VAA9V4@9&4@
M;&$@;&ES=&4@9&5S('5T:6QI<V%T975R<R!E<W0@9.ES86-T:7;I+@!,:71T
MZ7)A='5R90!,:71U86YI90!#:&%R9V5M96YT(&1E<R!B:6)L:6]T:.AQ=65S
M+BXN`$-H87)G96UE;G0N+BX`2&5U<F4@;&]C86QEH#H@`$AE=7)E(&5T(&QO
M8V%L90!,:65U`$-O;FYE>&EO;@!$Z6-O;FYE>&EO;@!4XF-H97,@9&4@8V]N
M;F5X:6]N`$QA(&-O;FYE>&EO;B!E<W0@<F5F=7/I92X@26P@97-T('!R;V)A
M8FQE('%U92!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!O=2!V;W1R92!M;W0@
M9&4@<&%S<V4@82#I=.D@;6%L('-A:7-I`,EC:&5C(&1E(&-O;FYE>&EO;BX`
M5&5X=&4@;&]N9P!!;6]U<@!&86EB;&4`3&5T=')E(&=R96-Q=65S(&UI;G5S
M8W5L97,`3&5T=')E(&QA=&EN97,@;6EN=7-C=6QE<P!.;VUB<F4@<F]M86EN
M<R!M:6YU<V-U;&5S`$QU>&5M8F]U<F<`34T`365S<V%G92!D=2!J;W5R("A-
M3U1$*0!,82!P:>AC92!J;VEN=&4@35,M5$Y%1B!N92!C;VYT96YA:70@875C
M=6YE(&1O;F[I92X`35-'`$UA8V%O`%+I<'5B;&EQ=64@9&4@36%CZ61O:6YE
M`$UA9&%G87-C87(`36%G:64`0V]U<G)I97(`061M:6YI<W1R871I;VX@9'4@
M8V]U<G)I96P`1F%I<F4@=6X@;&EE7VX`07-S=7)E>B!V;W5S('%U92!014%2
M(&5S="!I;G-T86QLZ2!E="!P<NES96YT(&1A;G,@=F]T<F4@JR!I;F-L=61E
M7W!A=&@@NRX`0W+I871I;VX@9'4@<NEP97)T;VER92`E<P!-86QA=VD`36%L
M86ES:64`36%L9&EV97,`36%L:0!-86QT90!!9&UI;FES=')E>B!L82!L:7-T
M92!D92!C873I9V]R:65S(&5T(&QE<R!C;W5L975R<R!L:>EE<R#@(&-E<R!C
M873I9V]R:65S+@!#87)T92"K($UA<#(T(+L`0V%R=&4@JR!-87!Q=65S=""[
M`$UA<G,`36%R9V4`36%R<75E<B!A=F5C(&1E<R#I=&EQ=65T=&5S(%9U+TYO
M;B!V=0!-87)Q=65R(&%V96,@9"=A=71R97,@Z71I<75E='1E<R`H97@N.B!)
M;7!O<G1A;G0O4NEP;VYD=2D`SFQE<R!-87)S:&%L;`!-87)T:6YI<75E`$-H
M86UP<R!A<'!A<F5N=.ES`$UA=7)I=&%N:64`36%U<FEC90!#<NED:70@;6%X
M:6UU;2!A;&QO=>DN`$QI;6ET92!D=2!M97-S86=E(&3I<&%S<^EE+@!496UP
MZ7)A='5R92!M87AI;6%L92!D97,@,C0@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!4
M96UPZ7)A='5R92!M87AI;6%L92!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@
M`$QO;F=U975R(&UA>&EM=6T`36%I`$UA>6]T=&4`3>ED:6-A;65N=`!-96UB
M<F5S`%1Y<&4@9&4@;65N=:`Z`$9U<VEO;FYE<B!L97,@8V5L;'5L97,`1G5S
M:6]N(&1E('1O=7,@;&5S(&9I8VAI97)S("5S+G!O(&1A;G,@;&4@8V]M<&5N
M9&EU;2XN+B``1G5S:6]N(&1E(&QA(&QO8V%L92`E<RXN+B`@`$9U<VEO;B!D
M=2!F:6-H:65R(%!/(&1E("5S(&%U(&-O;7!E;F1I=6TN+BX@`$9U<VEO;B!D
M92!L82!T<F%D=6-T:6]N(&1U(&UO9'5L92`E<RXN+@!-97-S86=E`%;I<FEF
M:6-A=&EO;B!D=2!M97-S86=E('+I=7-S:64L(&UA:7,@;&4@8V5R=&EF:6-A
M="!D=2!S:6=N871A:7)E(&XG82!P87,@<'4@ZG1R92!VZ7)I9FGI+@!-97-S
M86=E(&5X<&ERZ2X`5'EP92!D92!M97-S86=E`$WI=.EO($UE=&%R`$QE(&)L
M;V,@JR!-971A<B"[(&XG97-T('!A<R!D:7-P;VYI8FQE+@!,92!B;&]C(*L@
M365T87(@NR!N)V5S="!P87,@9&ES<&]N:6)L92X@($QE<R!DZ71A:6QS(&]N
M="#I=.D@8V]N<VEG;NES('!O=7(@;"=A9&UI;FES=')A=&5U<BX`365T87)$
M0B!N)V5S="!P87,@8V]N;F5C=.DN`$WI=&AO9&4`3&$@;>ET:&]D92"KH"5S
MH+L@;B=E<W0@<&%S(&3I9FEN:64`3>ET<FEQ=64`365X:7%U90#)=&%T<R!F
MZ63I<NES(&1E($UI8W)O;NES:64`36EL:65U`%1Y<&4@34E-10!496UPZ7)A
M='5R92!M:6YI;75M(&1E<R`R-"!D97)N:>AR97,@:&5U<F5SH#H@`%1E;7#I
M<F%T=7)E(&UI;FEM=6T@9&5S(#8@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!,)^)G
M92!M:6YI;75M(&1U(&UO="!D92!P87-S92!N)V5S="!P87,@96YC;W)E(&5X
M<&ERZ0!-:7)O:7(`5F%R:>ES`$QE('!A<75E=&%G92!(5%107W)E<75E<W0@
M4$5!4B!E<W0@;6%N<75A;G0N`$-O;F9I9W5R871I;VX@:6YE>&ES=&%N=&4N
M(%9O=7,@9&5V97H@;&$@9^ENZ7)E<B!M86EN=&5N86YT('-I('9O=7,@=F]U
M;&5Z('5T:6QI<V5R(&-E='1E(&%P<&QI8V%T:6]N+@!)1"!D=2!M97-S86=E
M(&UA;G%U86YT+@!,92!P87%U971A9V4@4$5!4B!-86EL(&5S="!M86YQ=6%N
M="X`240@9&4@<V5S<VEO;B!M86YQ=6%N="X`3'4`0V]U<G)I96P@<V%N<R!F
M:6P`36]DZ7+I`$1A=&4@9&4@;6]D:69I8V%T:6]N`$UO9&EF:65R(&PG55),
M`$UO9'5L90!-;V1U;&\`36]L9&%V:64`36]N86-O`$UO;F=O;&EE`$UO:7,@
M970@86YNZ64`365N<W5E;&QE;65N=`!-;VYT<V5R<F%T`%!H87-E<R!D92!L
M82!L=6YE`$UA<F]C`$?I;NER86QE;65N="!E;G-O;&5I;&SI`$?I;NER86QE
M;65N="!N=6%G975X`$?I;NER86QE;65N="!E;G-O;&5I;&SI`%9E<G,@;&4@
M8F%S`$3I<&QA8V5R(.`@9V%U8VAE`$3I<&QA8V5R(.`@9')O:71E`%9E<G,@
M;&4@:&%U=`!697)S(&QE(&)A<P!697)S(&QE(&AA=70`36]Z86UB:7%U90!,
M:7-T97,@9.ER;W5L86YT97,@;75L=&EN:79E875X`%/I;&5C=&EO;B!M=6QT
M:7!L90!087)A;>ET<F%G92!D=2!C;VUP=&4`36]N('!O<G1A:6P`4'+I<V5N
M=&%T:6]N(&1E(&UO;B!P;W)T86EL`$)I<FUA;FEE`$Y/3BP@:F4@;B=A8V-E
M<'1E('!A<P!.;VT`3F%M:6)I90!.875R=0!.Z7!A;`!087ES+4)A<P!!;G1I
M;&QE<R!NZ65R;&%N9&%I<V5S`%523"!D92!B87-E(&1E($YE='-C87!E`%52
M3"!D92!RZ79O8V%T:6]N(&1E(&PG02Y#+B!.971S8V%P90!54DP@9&4@;&$@
M<&]L:71I<75E(&0G02Y#+B!.971S8V%P90!54DP@9&4@<F5N;W5V96QL96UE
M;G0@3F5T<V-A<&4`55),(&1E('+I=F]C871I;VX@3F5T<V-A<&4`3F]M(&1U
M('-E<G9E=7(@4U-,($YE='-C87!E`$-O;6UE;G1A:7)E(&1U(&-E<G1I9FEC
M870@3F5T<V-A<&4`5'EP92!D=2!C97)T:69I8V%T($YE='-C87!E`%+I<V5A
M=0!*86UA:7,`3F]U=F5L;&4M0V%LZ61O;FEE`$YO=79E;&QE(&-A=.EG;W)I
M90!.;W5V96QL92!L=6YE`$YO=79E874@;F]M(&1E(&-O;FYE>&EO;B`H9F%C
M=6QT871I9BD`3F]U=F5L;&4M6NEL86YD90!.;W5V96%U(&UO="!D92!P87-S
M9:`Z`$YO=79E;&QE(&9E;NIT<F4@*%]B;&%N:RD`3F]U=F5L;&5S`$9O<G5M
M<P!3=6EV86YT`#0@<&AA<V5S('-U:79A;G1E<P!/<'1I;VYS('-U:79A;G1E
M<P!3=6EV86YT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.=6ET`$YI=64`
M3F]N`%!A<R!D92!D;VYNZ65S(&1E(&-O;F9I9W5R871I;VX@<&]U<B!L97-Q
M=65L;&5S(&UO;G1R97(@;&5S(&1I9F;I<F5N8V5S`%!A<R!D92!S=')A=.EG
M:64@9&ES<&]N:6)L92!P;W5R(&9A:7)E(&1E<R!I;6%G97,@25-/+@!087,@
M9&4@9V%B87)I="!E;B!L;W0N`$%U8W5N(&)L;V,@;B=E>&ES=&4@X"!L82!P
M;W-I=&EO;B!D96UA;F3I90!087,@9&4@;F]M(&1E(&-A;&5N9')I97(@9F]U
M<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!-0T%,+@!.;VX@;6]D
M:69IZ2X`075C=6YE('-O=7,M<&5R;6ES<VEO;B!N)V$@8F5S;VEN(&0GZG1R
M92!A:F]U=.EE('-O=7,@8V4@;FEV96%U+@!!=6-U;F4@<V]U<RUP97)M:7-S
M:6]N(&XG82!B97-O:6X@9"?J=')E(&%J;W5TZ64@<V]U<R!C92!N:79E874N
M`$%U8W5N92!C;VUM86YD92!S<.EC:69IZ64`075C=6YE(&EN9F]R;6%T:6]N
M(&1E(&-O;F9I9W5R871I;VX@<W#I8VEF:>EE('!O=7(@)7,N`$%U8W5N92!I
M;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N:64@<&]U<B!&5%`@
M5D93+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R
M;FEE('!O=7(@4U%,(%9&4RX`075C=6YE(&EN9F]R;6%T:6]N(&1E(&-O;F9I
M9W5R871I;VX@9F]U<FYI92!P;W5R(%-13"U&:6QE(%9&4RX`075C=6X@8W+I
M9&ET(&1I<W!O;FEB;&4N`$%U8W5N92!D97-T:6YA=&EO;B!T<F]U=NEE+@!)
M;"!N)WD@82!P87,@9"=E;G1RZ64@879E8R!L)VED+B"KH"5SH+L@9&%N<R!L
M92!F:6-H:65R(&0G86ED92!O<FEG:6YA;"X`075C=6X@9FEC:&EE<B!E;G9O
M>>D`075C=6X@:6/T;F4@=')O=7;I+@!!=6-U;F4@;&]C86QE('-PZ6-I9FGI
M90!!=6-U;B!L:65U(&XG97-T('/I;&5C=&EO;F[I`$%U8W5N(&5M<&QA8V5M
M96YT(&XG97-T(&EN9&EQ=>DN`$%U8W5N(&UE<W-A9V4@9F]U<FYI`$%U8W5N
M(&YO;2!S<.EC:69IZ2X`075C=6X@;F]M8G)E('-PZ6-I9FGI+@!087,@9&4@
M8VET871I;VYS(&]F9F5N<V%N=&5S`$%U8W5N(&UO="!D92!P87-S92!F;W5R
M;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($A45%`N`$%U8W5N(&UO
M="!D92!P87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R
M($E-05`N`$%U8W5N(&UO="!D92!P87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE
M;G1I9FEC871I;VX@<&%R($ME<F)E<F]S+@!!=6-U;B!M;W0@9&4@<&%S<V4@
M<W#I8VEF:>D@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@3$1!4"X`075C=6X@
M;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N
M+@!!=6-U;B!M;W0@9&4@<&%S<V4@<W#I8VEF:>D@<&]U<B!L)V%U=&AE;G1I
M9FEC871I;VX@4$%34U=$+@!!=6-U;B!M;W0@9&4@<&%S<V4@<W#I8VEF:>D@
M<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@4TU"+@!!=6-U;B!C:&5M:6X@=F5R
M<R!L92!B:6YA:7)E($]P96Y34TP@9F]U<FYI+B!,92!B:6YA:7)E(&0G3W!E
M;E-33"!E<W0@;NEC97-S86ER92!P;W5R(&9O;F-T:6]N;F5R(&%V96,@9&5S
M(&1O;F[I97,@4$M#4R`Q,BX`075C=6YE(&-O;F9I<FUA=&EO;B!E;B!A='1E
M;G1E`%!A<R!D92!RZ&=L97,`4&%S(&1E(&/T=.ES`$%U8W5N(&1O<G-A;""K
MH"5SH+L@=')O=7;I+@!!=6-U;B!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@97-T
M(&1I<W!O;FEB;&4@<&]U<B!L82!C86-H90!!=6-U;B!N;VT@9"=U=&EL:7-A
M=&5U<B!E="`O;W4@;6]T(&1E('!A<W-E(&5N=F]YZ2X`075C=6YE(&1O;F[I
M92!834P@=F%L:61E(&XG82#I=.D@<F5T;W5R;NEE`%!A<R!D92!V86QE=7(`
M4&%S(&1E('9E<G-I;VX@=')O=7;I92!D86YS(&QA(&-O;F9I9W5R871I;VX@
M;W)I9VEN86QE+B!2Z6?I;NER97H@;&$@8V]N9FEG=7)A=&EO;BX`4&%S(&1E
M('9E<G-I;VX@=')O=7;I92!D86YS('9O=')E(&-O;F9I9W5R871I;VXN(%+I
M9^ENZ7)E>B!L82!C;VYF:6=U<F%T:6]N+@!!=6-U;@!!=6-U;B`H=71I;&ES
M97(@:6UP;&EC:71E;65N="D`3F]R9&EQ=64@*$E33RTX.#4Y+3$P*0#.;&4@
M3F]R9F]L:P!(Z6UI<W!HZ')E($YO<F0`SFQE<R!-87)I86YN97,@9'4@;F]R
M9`!.;W)VZ&=E`%!A<R!A<'+H<P!087,@879A;G0`4&%S('5N(&1O<W-I97(`
M3F]N(&EM<&SI;65N=.DN`$EN86-T:7;I`$YO;B!P<FES(&5N(&-O;7!T92X`
M3F]T97,`4FEE;B#@(&YA=FEG=65R+"!R971O=7)N97H@96X@87)R:>AR92X`
M079E<G1I<W-E;65N=`!.;W9E;6)R90!.;VUB<F4`3F]M8G)E(&1E(&-A<F%C
M=.AR97,`3F]M8G)E(&1E(&-O;&]N;F5S`$YO;6)R92!D92!R86YGZ65S`$YO
M;6)R92!N;VX@<W#I8VEF:>D@<&]U<B!L82!M:7-E(.`@:F]U<B!D92!L82!L
M:7-T92!D92!D:7-T<FEB=71I;VXN`$]+`$]B:F5T`$-RZ6%T975R(&0G;V)J
M970`4&5R;6ES<VEO;B!D92!C<NEA=&5U<B!D)V]B:F5T<P!/8W1A;`!/8W1O
M8G)E`$9I;'1R92!A;G1I+6]F9F5N<V%N=`!"=7)E874`06YC:65N(&UO="!D
M92!P87-S9:`Z`$]M86X`4V5U;"!L97,@<V5R=F5U<G,@24U!4"!S=7!P;W)T
M96YT(&QE<R!D;W-S:65R<R!P87)T86?I<RX`4V5U;&5M96YT(&QE<R"KH&9O
M<G1U;F5SH+L@;V9F96YS86YT97,`56YE('-E=6QE(&%D<F5S<V4@9&4@8V]U
M<G)I96P@<&5R;6ES92X`4V5U;',@;&4@<')O<')IZ71A:7)E(&]U(&PG861M
M:6YI<W1R871E=7(@<WES=.AM92!P975T(&UO9&EF:65R(&QE<R!P97)M:7-S
M:6]N<R!D)W5N('!A<G1A9V4N`$]U=G)I<B!D86YS('5N92!N;W5V96QL92!F
M96[J=')E`$5R<F5U<B!/<&5N4U-,H#H@26UP;W-S:6)L92!D)V5X=')A:7)E
M(&QE<R!D;VYNZ65S(&1E(&QA('!A<G1I92!S:6=NZ64@4R]-24U%`$]U=G)I
M<B!L97,@;&EE;G,@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R90!3>7-TZ&UE
M(&0G97AP;&]I=&%T:6]N`$]P=&EO;G,`3W!T:6]N<R!P;W5R("5S`$]P=&EO
M;G.@.@!,:7-T92!N=6WI<F]TZ64`3W)G86YI<V%T:6]N`%5N:73I(&]R9V%N
M:7-A=&EO;FYE;&QE`$]R9V%N:7-A=&EO;@!-;V3H;&4@;W)I9VEN86P@9"=A
M<'!L:6-A=&EO;@!-;V3H;&5S(&]R:6=I;F%U>"!D86YS("5SH#H`075T<F4`
M075T<F5S(&EN9F]R;6%T:6]N<P!097)M:7-S:6]N<R!D=2!P<F]P<FGI=&%I
M<F4`3"=A=71H96YT:69I8V%T:6]N(%!!32!N)V5S="!P87,@9&ES<&]N:6)L
M92X`4VEG;F%T=7)E(&YU;>ER:7%U92!01U``1&]N;NEE<R!01U`@8VAI9F9R
MZ65S`$-L968@<'5B;&EQ=64@4$=0`$1O;F[I97,@4$=0('-I9V[I97,O8VAI
M9F9RZ65S`$-O9&4@4$A0`$EN=&5R<'+I=&5U<B!02%``4&QU:64@;.EGZ')E
M(&PG87!RZ',M;6ED:0!!=F5R<V5S(&PG87!RZ',M;6ED:0!.96EG92!L)V%P
M<NAS+6UI9&D`0VAU=&5S(&1E(&YE:6=E(&PG87!RZ',M;6ED:0!3;VQE:6P@
M;"=A<'+H<RUM:61I`$]R86=E<R!L)V%P<NAS+6UI9&D`26YT97)P<NET975R
M(%!?2%``4F5M<&QI<W-A9V4`4&%K:7-T86X`0F5L874`4&%L97-T:6YE("AT
M97)R:71O:7)E(&]C8W5PZ2D`4&%N86UA`%!A<&]U87-I92U.;W5V96QL92U'
M=6ENZ64`4&%R86=U87D`4&%R=&EE;&QE;65N="!N=6%G975X`$QE(&UO9'5L
M92!D92!C:&%N9V5M96YT(&1E(&UO="!D92!P87-S92!N)V5S="!P87,@8V]R
M<F5C=&5M96YT(&-O;F9I9W5RZ2X`36]T(&1E('!A<W-E`$UO="!D92!P87-S
M92!M;V1I9FGI('-U<B`E<RX`36]T(&1E('!A<W-E(&EN8V]R<F5C=`!,92!M
M;V1U;&4@9&4@8VAA;F=E;65N="!D=2!M;W0@9&4@<&%S<V4@;F4@=')O=79E
M('!A<R!L92!P<F]G<F%M;64@:6YD:7%UZ2X`4&%R86WH=')E<R!O8FQI9V%T
M;VER97,@86)S96YT<R!P;W5R(&QE(&UO9'5L92!D92!C:&%N9V5M96YT(&1U
M(&UO="!D92!P87-S92X`4&%R86WH=')E(&-I8FQE(&%B<V5N="!P;W5R(&QE
M(&UO9'5L92!D92!C:&%N9V5M96YT(&1U(&UO="!D92!P87-S92X`3&4@;6]D
M=6QE(&1E(&-H86YG96UE;G0@9'4@;6]T(&1E('!A<W-E(&XG97-T('!A<R!C
M;W)R96-T96UE;G0@8V]N9FEG=7+I`$QE(&UO9'5L92!D92!C:&%N9V5M96YT
M(&1U(&UO="!D92!P87-S92!N)V5S="!P87,@8V]R<F5C=&5M96YT(&-O;F9I
M9W5RZ2X`36]T(&1E('!A<W-E(')E<75I<R!P;W5R(&PG875T:&5N=&EF:6-A
M=&EO;B!2041)55,N`$UO="!D92!P87-S92!A=F5C(&-O;F9I<FUA=&EO;@!-
M;W0@9&4@<&%S<V6@.@!-;W0@9&4@<&%S<V6@.B``3&5S(&UO=',@9&4@<&%S
M<V4@9&]I=F5N="#J=')E(&ED96YT:7%U97,N`$-O;&QE<@!#;VQL97(@9&5P
M=6ES(&QE('!R97-S92UP87!I97)S`$-H96UI;@!#;VYF:7)M871I;VYS(&5N
M(&%T=&5N=&6@.@!097)S;VYN97,`4&]U<F-E;G1A9V4`169F96-T=65R(&QE
M<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E`$5F9F5C='5E<B!L97,@;W#I
M<F%T:6]N<R!D92!M86EN=&5N86YC92#@(&QA(&-O;FYE>&EO;J`_`%!E<FUI
M<W-I;VX`3&$@<&5R;6ES<VEO;B`E<R!N)V5S="!P87,@<W5P<')I;>EE+@!!
M9&UI;FES=')A=&EO;B!D97,@<&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@<&]U
M<@!$;VYNZ65S('!E<G-O;FYE;&QE<P!0Z7)O=0!!;FEM875X`%!H:6QI<'!I
M;F5S`%3I;.EP:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D
M97,`4U90(&-L:7%U97H@9&%N<R!U;F4@8V5L;'5L90!35E`@8V]N9FER;65Z
M(&QA('-U<'!R97-S:6]N(&1E(&-E="#I;.EM96YTH#H`4U90(&-O;F9I<FUE
M>B!Q=64@=F]U<R!V;W5L97H@9.EL:65R(&-E="#I;.EM96YT+@!6975I;&QE
M>B!S86ES:7(@=6X@;6]I<R!E="!U;F4@86YNZ64N`%9E=6EL;&5Z('-A:7-I
M<B!U;B!N;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R:66@.@!6975I;&QE
M>B!E;G1R97(@=6YE(&%D<F5S<V4@25`@=F%L:61E+@!6975I;&QE>B!E;G1R
M97(@=6YE(&1A=&4@=F%L:61EH#L@=NER:69I97H@;&4@;F]M8G)E(&1E(&IO
M=7)S(&1U(&UO:7,N(`!6975I;&QE>B!E;G1R97(@=6YE(&AE=7)E('9A;&ED
M92X`5F5U:6QL97H@9F]U<FYI<B!U;B!RZ7-U;>D@9'4@<')O8FSH;64N`%9E
M=6EL;&5Z(&9O=7)N:7(@=F]T<F4@;F]M(&0G=71I;&ES871E=7(@970@=F]T
M<F4@;6]T(&1E('!A<W-E`%9E=6EL;&5Z(&QI<F4@;&4@=&5X=&4@<W5I=F%N
M="X@5F]U<R!D979E>B!A8V-E<'1E<B!L97,@8V]N9&ET:6]N<R!P;W5R('5T
M:6QI<V5R(&QE('-Y<W3H;64N`%9E=6EL;&5Z(&9A:7)E('!A<G0@9&5S(&1Y
M<V9O;F-T:6]N;F5M96YT<R#@(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!6975I
M;&QE>B!E;G1R97(@;&4@;F]U=F5A=2!N;VV@9&4@;&$@8V%TZ6=O<FEEH#H`
M4&]L;V=N90!0;VQI=&EQ=64`4V-R=71I;G,`4&]R='5G86P`4&]S:71I;VX@
M9&4@8V5T=&4@:6UA9V4`4&]S:71I;VX@9&4@8V4@=&%B;&5A=0!%;G9O>65R
M(.`@8V4@9&]S<VEE<B`H;F]N(&%P<&QI<77I('!A<B!)34%0*0!0<NEC:7!I
M=&%T:6]N<R!P;W5R(&QE<R`E<R!D97)N:>AR97,@:&5U<F5SH#H@`%!R969S
M7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE+@!0
M<F5F<U]S97-S:6]NH#H@97AT96YS:6]N(')E<75I<V4@JZ!S97-S:6]NH+L@
M;F]N('1R;W5VZ64N`%!R97-S:6]N`%!R97-S:6]N(&%U(&YI=F5A=2!D92!L
M82!M97*@.B``4')E<W-I;VZ@.B``07!E<N=U`$%P97+G=2!D92!L)VEM86=E
M(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`3W!T:6]N<R!P<NECZ61E;G1E
M<P!);7!R:6UE<B!L92!D;V-U;65N=`!#;&5F('!R:7;I90!0<F]B;.AM90!$
M97-C<FEP=&EO;B!D=2!P<F]B;.AM90!0<F]J971S`%1E>'1E(&-O=7)T`$-L
M968@<'5B;&EQ=64`06QG;W)I=&AM92!D92!C;&5F('!U8FQI<75E`$EN9F]R
M;6%T:6]N<R!S=7(@;&$@8VQE9B!P=6)L:7%U90#)8VAE8R!D92!L82!GZ6[I
M<F%T:6]N(&1E(&QA('!A:7)E(&1E(&-L969S('!U8FQI<75E+W!R:7;I92X`
M4&]R=&\@4FEC;P!1871A<@!297%UZG1E`$-L968@<'5B;&EQ=64@4E-!("@E
M9"!B:71S*0!3Z6QE8W1I;VX@<F%D:6\`4&QU:64`4&QU:64@=/1T(&QE(&UA
M=&EN`%!L=6EE('1A<F0@9&%N<R!L82!J;W5R;NEE`$%V97)S97,`4&QU:64@
M970@;F5I9V4`4&QU:64@<'5I<R!N96EG90!&;W)T=6YE(&%U(&AA<V%R9`!4
M875X`$QI<F4`365S<V%G97,@;'5S`%-U<'!R97-S:6]N(&3I9FEN:71I=F4@
M9&4@)7.@/P!3=7!P<F5S<VEO;B!DZ69I;FET:79E(&1E<R!D;VYNZ65S('!O
M=7(@;"=U=&EL:7-A=&5U<B`E<Z`_($-E='1E(&]PZ7)A=&EO;B!E<W0@9.EF
M:6YI=&EV92X`4F5P<F5N9')E('9O=')E(&1E<FYIZ')E(&%C=&EO;@!2869R
M8>YC:&ER(&QE<R#I;.EM96YT<R!D=2!M96YU(&1Y;F%M:7%U9:`Z`%)A9G)A
M[F-H:7(@;"?I8W)A;B!D=2!S;VUM86ER9:`Z`$5X<')E<W-I;VX@<F%T:6]N
M;F5L;&4`3F%V:6=A=&5U<B!R96QA=&EO;FYE;`!296UA<G%U97,`4V5R=F5U
M<G,@9&ES=&%N=',`55),(&1I<W1A;G1E("AH='1P.B\O=W=W+F5X96UP;&4N
M8V]M+VAO<F1E+RF@.@!2971I<F5R`%)E=&ER97(@;&4@8FQO8P!2971I<F5R
M(&QA(&-O;&]N;F4`4F5T:7)E<B!L92!F;W)M871A9V4`4F5T:7)E<B!L82!P
M86ER90!%;FQE=F5R(&QE('-C<FEP="!E;G)E9VES='+I(&1U('+I<&5R=&]I
M<F4@=&5M<&]R86ER92!D=2!S97)V975R+@!2971I<F5R(&QE`%)E=&ER97(@
M8V4@;F]E=60@9'4@9&]C=6UE;G0`4F5T:7)E<B!L)W5T:6QI<V%T975R`%)E
M=&ER97(@;"=U=&EL:7-A=&5U<J`Z("5S`$%U8W5N92!RZ7!O;G-E(.`@=F]T
M<F4@<F5Q=>IT92X@0V]D92!D)V5R<F5U<B!R971O=7)NZ:`Z(`!,92!S97)V
M:6-E(&1E;6%N9.D@97-T(&EN=')O=79A8FQE+@!,92!P87)A;>AT<F4@;V)L
M:6=A=&]I<F4@)R5S)R!N)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF
M:6=U<F%T:6]N("5S+@!,92!P87)A;>AT<F4@;V)L:6=A=&]I<F4@)R5S)R!N
M)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N(&1U(%9&
M4RX`3&4@<&%R86WH=')E(&]B;&EG871O:7)E("<E<R<@;B=E<W0@<&%S('-P
MZ6-I9FGI(&1A;G,@;&$@8V]N9FEG=7)A=&EO;BX`3&4@<&EL;W1E(&XG97-T
M('!A<R!C;W)R96-T96UE;G0@8V]N9FEG=7+I+@`G<&AP='EP92<@<F5Q=6ES
M(&YO;B!I;F1I<77I(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B!D92!087-S=V0@
M4U%,+@`G<&AP='EP92<@<F5Q=6ES(&YO;B!I;F1I<77I(&1A;G,@;&$@8V]N
M9FEG=7)A=&EO;B!D92!344PN`$-H86UP(&]B;&EG871O:7)E`%+`6@!296UI
M<V4@X"!ZZ7)O(&1U(&UO="!D92!P87-S90!296UE='1R92#@('KI<F\@=F]T
M<F4@;6]T(&1E('!A<W-E`%+I<W5L=&%T<P!2Z7-U;'1A=',@*&EN8VQU86YT
M($AO<F1E*:`Z`%+I<W5L=&%T<Z`Z`%)E=F5N:7(@875X(&]P=&EO;G,`4NEU
M;FEO;@!2979E;FER(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E;G1E`$]P
M=&EO;G,@9&4@;"?I9&ET975R(%)I8V@@5&5X=`!$979I;F5T=&5S`$1R;VET
M90!%;G3J=&4@9&4@9')O:71E`%9A;&5U<G,@8V]R<F5C=&5S`%!R;W!R:>ET
MZ7,@9&4@;&$@<F%N7V?I92`N+BX`4O1L90!2;W5M86YI90!0:79O=&5R(#$X
M,`!0:79O=&5R(.`@9V%U8VAE`%!I=F]T97(@X"!D<F]I=&4`4')O<')IZ73I
M<R!D92!L82!R86YGZ64`4')O<')IZ73I<R!D92!L82!R86YGZ64`4F%N9^EE
M<Z`Z`%+H9VQE<P!$97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!T;W5T
M97,@;&5S(')A;F?I97,@970@;&5S(&-O;&]N;F5S`$1E<R!F:6QE=',@87!P
M87)A[G1R;VYT(&5N=')E(&QE<R!C;VQO;FYE<R!S975L96UE;G0`1&5S(&9I
M;&5T<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(')A;F?I97,@<V5U;&5M96YT
M`$QA;F-E<@!2=7-S:64`4G=A;F1A`%-I9VYA='5R92#I;&5C=')O;FEQ=64@
M4R]-24U%`$UE<W-A9V4@8VAI9F9RZ2!3+TU)344`3"=A=71H96YT:69I8V%T
M:6]N(%-!4TP@;B=E<W0@<&%S(&1I<W!O;FEB;&4`365S<V%G97)I92!335,`
M26YT97)P<NET975R(%-13`!34T@`4U5#0\A3`$EN=&5R<'+I=&5U<B!37U%,
M`%-A`%-A:6YT92U(Z6SH;F4`4V%I;G0M0VAR:7-T;W!H92UE="U.:>EVZ',`
M4V%I;G1E+4QU8VEE`%-A:6YT+5!I97)R92!E="!-:7%U96QO;@!386EN="U6
M:6YC96YT+65T+6QE<R!'<F5N861I;F5S`$WJ;64@8V%D<F4@*%]S96QF*0!3
M86UO82!O8V-I9&5N=&%L97,`4V%I;G0M36%R:6X`4V%O+51O;>DM970M4')I
M;F-I<&4`1F]U<FYI<W-E=7(@<V%T96QL:71E`$%R86)I92!386]U9&ET90!%
M;G)E9VES=')E<@!%;G)E9VES=')E<B`E<P!%;G)E9VES=')E<B"KH"5SH+L`
M16YR96=I<W1R97(@;&5S(&]P=&EO;G,`16YR96=I<W1R97(@;&$@8V]N9FEG
M=7)A=&EO;B!GZ6[I<NEE(&-O;6UE('5N('-C<FEP="!02%`@9&%N<R!L92!R
MZ7!E<G1O:7)E('1E;7!O<F%I<F4@9&4@=F]T<F4@<V5R=F5U<BX`16YR96=I
M<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!%;G)E9VES='+I(&QE('-C
M<FEP="!D92!C;VYF:6=U<F%T:6]N(&1E(&UI<V4@X"!J;W5R('-O=7,Z("5S
M`$]R86=E<R!I<V]LZ7,`4V-I96YC90!296-H97)C:&4`36]T975R<R!D92!R
M96-H97)C:&4`4F5C:&5R8VAE(&1E<R!M;V1U;&5S($AO<F1E(&1A;G,@)7,`
M4F5C:&5R8VAE(&1E<R!B:6YA:7)E<R!G971T97AT+BXN`$-H;VES:7-S97H@
M;&5S(&9I8VAI97)S`%/I;&5C=&EO;FYE>B!U;F4@9&%T90!3Z6QE8W1I;VYN
M97H@=6X@9W)O=7!E(.`@86IO=71E<@!3Z6QE8W1I;VYN97H@=6X@;F]U=F5A
M=2!P<F]P<FGI=&%I<F4`4^EL96-T:6]N;F5Z('5N('-E<G9E=7(`4^EL96-T
M:6]N;F5Z('5N('5T:6QI<V%T975R(.`@86IO=71E<@!3Z6QE8W1I;VYN97H@
M=&]U=&5S(&QE<R!C;VUP;W-A;G1E<R!D92!L82!D871E+@!#:&]I<VES<V5Z
M('5N(&]B:F5T`%/I;&5C=&EO;FYE>B!L97,@8V%R86-TZ')E<R!D;VYT('9O
M=7,@879E>B!B97-O:6X@X"!L)V%I9&4@9&4@;"=O=71I;"!C:2UD97-S;W5S
M+B!6;W5S('!O=79E>B!E;G-U:71E(&QE<R!C;W!I97(@970@;&5S(&-O;&QE
M<B!D86YS('9O=')E('1E>'1E+@!3Z6QE8W1I;VYN97H@;&4@9.EL:6UI=&5U
M<B!D92!D871EH#H`4^EL96-T:6]N;F5Z(&QE(&9O<FUA="!D92!D871EH#H`
M4^EL96-T:6]N;F5R(&QE('!R;V9I;"!Q=64@=F]U<R!DZ7-I<F5Z(&UO9&EF
M:65RH#H`4^EL96-T:6]N;F5Z(&QE(&3I;&EM:71E=7(@9"=H975R9:`Z`%/I
M;&5C=&EO;FYE>B!L92!F;W)M870@9&4@;"=H975R9:`Z`%/I;&5C=&EO;FYE
M>B!D975X(&-H86UP<R!A<'!A<F5N=.ES+@!3Z6QE8W1I;VYN97H@=F]T<F4@
M=&CH;64@9&4@8V]U;&5U<G,N`%/I;&5C=&EO;FYE>B!V;W1R92!L86YG=64@
M<'+I9NERZ66@.@!%;G9O>65R(&QE(')A<'!O<G0@9"=A;F]M86QI90!%;G9O
M>65R(%--4P!3Z6[I9V%L`%-O;F1EH#H@`%-E<'1E;6)R90!397)B:64@970@
M36]N=&5N96=R;P!.=6WI<F\@9&4@<^ER:64`3&5S(&1O;F[I97,@9'4@<V5R
M=F5U<B!S;VYT(&9A=7-S97,@;W4@;F]N(&1I<W!O;FEB;&5S+@!397-S:6]N
M(&5X<&ERZ64N`%/I;&5C=&EO;FYE<@!#;VYF:6=U<F5R(&QE<R!O<'1I;VYS
M('!O=7(@=F]U<R!P97)M971T<F4@9&4@<F5M971T<F4@X"!ZZ7)O('9O=')E
M(&UO="!D92!P87-S92!S:2!J86UA:7,@=F]U<R!L)V]U8FQI97HN`$-O;F9I
M9W5R97(@;&5S('-E<G9E=7)S(&1I<W1A;G1S(&%C8V5S<VEB;&5S(&1E<'5I
M<R!V;W1R92!P;W)T86EL+@!3Z6QE8W1I;VYN97H@=F]T<F4@;&%N9W5E('!R
MZ6;I<NEE+"!F=7-E874@:&]R86ER92!E="!L97,@;W!T:6]N<R!D92!D871E
M+@!$Z69I;FES<V5Z(&QA('!R96UIZ')E(&%P<&QI8V%T:6]N(&QA;F/I92P@
M;&4@=&CH;64@9&4@8V]U;&5U<G,L(&QE(')A9G)A[F-H:7-S96UE;G0@9&5S
M('!A9V5S+"!E="!D)V%U=')E<R!O<'1I;VYS(&0G869F:6-H86=E+@!#;VYF
M:6=U<F%T:6]N`%-C<FEP="!D92!C;VYF:6=U<F%T:6]N(&1E(&UI<V4@X"!J
M;W5R(&1I<W!O;FEB;&4`4&QU<VEE=7)S(&5N9')O:71S('!O<W-I8FQE<R!A
M=F5C(&QE('!A<F%MZ'1R9:`Z(`!397EC:&5L;&5S`$%C:&%T`%+I<W5MZ0!$
M;VET+6]N(&3I9FEN:7(@9&5S('1O=6-H97,@9&4@<F%C8V]U<F-I<R!P;W5R
M(&QA('!L=7!A<G0@9&5S(&QI96YSH#\`069F:6-H97(`36]N=')E<B!L97,@
M9&EF9NER96YC97,@96YT<F4@;&$@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I
M92!A8W1U96QL96UE;G0@970@8V5L;&4@;F]U=F5L;&5M96YT(&?I;NERZ64N
M`$UO;G1R97(@;"=H975R92!D92!L82!D97)N:>AR92!C;VYN97AI;VX@X"!L
M)V5N='+I9:`_`$UO;G1R97(@;"=O<'1I;VX@9&4@8V]N<V5R=F5R(&PG;W)I
M9VEN86P`36]N=')E<B!L92!SZ6QE8W1E=7(`069F:6-H97(@;&$@8F%R<F4@
M9&4@;65N=2!D92!T86)L96%U>*`_`$%F9FEC:&5R(&QE(&UE;G4@)7,@X"!G
M875C:&6@/P!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!T86)L96%U
M(&-E;&QU;&4`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R
M;W!R:>ETZ7,@9'4@=&%B;&5A=0!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L
M;V=U92!D97,@<')O<')IZ73I<R!D92!L82!R86YGZ64@9'4@=&%B;&5A=0!!
M9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!D97,@<')O<')IZ73I<R!D
M92!L)VEM86=E`$%F9FEC:&5R(&PG96YV;VD@9&4@9FEC:&EE<@!!=F5R<V5S
M`$%V97)S97,@=/1T(&1A;G,@;&$@:F]U<F[I90!!=F5R<V5S('1A<F0@96X@
M:F]U<F[I90!!=F5R<V5S(&%U>"!A;&5N=&]U<G,`4F5S<V5R<F5R`%)E<W-E
M<G)E<B!O=2!DZ6=A9V5R(&0G86)O<F0@;&4H<RD@8FQO8RAS*2!V;VES:6XH
M<RD`4VEE<G)A($QE;VYE`%,G:6YS8W)I<F4`4R=I;G-C<FER92!S:2!N;VXM
M96YR96=I<W1RZ0!3:6=N871U<F4`06QG;W)I=&AM92!D92!S:6=N871U<F4`
M4VEN9V%P;W5R`%1A:6QL90!!;FYU;&5R(&QA(&UA:6YT96YA;F-E`%!A<W/I
M+BXN`%-L;W9A<75I90!3;&]VZ6YI90!.96EG90!!=F5R<V4@9&4@;F5I9V4`
M079E<G-E<R!D92!N96EG90!!=F5R<V5S(&1E(&YE:6=E('3T="!D86YS(&QA
M(&IO=7)NZ64`079E<G-E<R!D92!N96EG92!T87)D(&5N(&IO=7)NZ64`2&%U
M=&5U<B!D92!N96EG9:`Z(`!1=6%N=&ETZ2!D)V5A=2#I<75I=F%L96YT92#@
M(&QA('%U86YT:73I(&1E(&YE:6=EH#H@`,YL97,@4V%L;VUO;@!3;VUA;&EE
M`$-H86YS;VYS(&5T('!OZ&UE<P!3Z6QE8W1I;VX@9&4@;"=O<F1R92!D92!T
M<FD`061R97-S92!S;W5R8V4`069R:7%U92!D=2!S=60`4W5D+65U<F]PZ65N
M("A)4T\M.#@U.2TS*0!'Z6]R9VEE+61U+7-U9"!E="#N;&5S(%-A;F1W:6-H
M+61U+7-U9`!(Z6UI<W!HZ')E(%-U9`!%<W!A8V4@96YT<F4@8V5L;'5L97,@
M861J86-E;G1E<P!%<W!A8V4@96YT<F4@;&4@8V]N=&5N=2!E="!L82!B;W)D
M=7)E(&1A;G,@=6YE(&-E;&QU;&4`17-P86-E=7(`17-P86-E;65N=`!%<W!A
M8V5M96YT(&5T(')E;7!L:7-S86=E`$5S<&%G;F4`4&]U<G)I96P`0V%R86-T
MZ')E<R!S<.EC:6%U>`!38VEN9&5R(&QA(&-E;&QU;&4`4V-I;F1E<B!L82!C
M;VQO;FYE`%-C:6YD97(@;&$@<F%N9^EE`%-P;W)T<P!3<FD@3&%N:V$`4W1A
M;F1A<F0`4W1A<B!4<F5K`$%N;NEE(&1E(&3I8G5T`,ET870@;W4@<')O=FEN
M8V4`4W1A='5T`,ET870@9&4@;&$@;&]C86QE("5S+BXN(`!&;W)M870@9&4@
M<V%U=F5G87)D90!2=64`0F%R<ND`3&ES=&4@9&4@8VAA[FYE<P!2971I<F5R
M(&QE(&1O;6%I;F4@9&4@;"=A9')E<W-E`%-T>6QE(%M#4U-=`$1I`%-O=7,M
M<NEP97)T;VER92"KH"5SH+L@;F]N('1R;W5VZ0!3=6IE=`!%;G9O:0!,82!D
M96UA;F1E(&0G86IO=70@9&4@JZ`E<Z"[(&%U('-Y<W3H;64@82#I=.D@<V]U
M;6ES92X@5F]U<R!N92!P;W5R<F5Z('!A<R!V;W5S(&-O;FYE8W1E<B!J=7-Q
M=2?@('-O;B!A<'!R;V)A=&EO;BX`26YD:6-E`%-U8V/H<P"KH"5SH+L@82!B
M:65N(.ETZ2!A:F]U=.DH92DN`$QE<R!D;VYNZ65S(&1E(&PG=71I;&ES871E
M=7(@JZ`E<Z"[(&]N="!B:65N(.ETZ2!R971I<NEE<R!D=2!S>7-TZ&UE+BX`
MJZ`E<Z"[(&$@8FEE;B#I=.D@<W5P<')I;>DH92DN`*N@)7.@NR!A(&)I96X@
MZ73I(')E=&ERZ2AE*2X`4F5T;W5R(.`@;&$@8V]N9FEG=7)A=&EO;B!I;FET
M:6%L92!RZ75S<VDN("!2869R8>YC:&ER(&QA('!A9V4@<&]U<B!V;VER(&QE
M<R!M;V1I9FEC871I;VYS+@!%;G)E9VES=')E;65N="!D92!L82!C;VYF:6=U
M<F%T:6]N(&1E(&QA('-A=79E9V%R9&4@<NEU<W-I+@!%;G)E9VES=')E;65N
M="!RZ75S<VD@9&4@;&$@8V]P:64@9&4@<V%U=F5G87)D92!D=2!F:6-H:65R
M(&1E(&-O;F9I9W5R871I;VX@)7,N`*N@)7.@NR!A(&)I96X@Z73I(&UI<RAE
M*2#@(&IO=7(N`,EC<FET=7)E(&1E("5S('+I=7-S:0!3;W5D86X`4V]M;6%I
M<F4`3&5V97(@9'4@4V]L96EL`$-O=6-H97(@9'4@4V]L96EL`$5N<V]L96EL
M;.D`3&5V97(@9'4@4V]L96EL`$QE=F5R+T-O=6-H97(@9'4@4V]L96EL`$QE
M=F5R(&1U(%-O;&5I;#H@`$-O=6-H97(@9'4@4V]L96EL`$-O=6-H97(@9'4@
M4V]L96ELH#H@`$5X<&]S86YT`$%S<VES=&%N8V4`4W5R:6YA;2!O=2!'=7EA
M;F4@:&]L;&%N9&%I<V4`3F]M(&1E(&9A;6EL;&4`SFQE<R!3=F%L8F%R9"!E
M="!*86X@36%Y96X`4W=A>FEL86YD`%-UZ&1E`%-U:7-S90!%<G)E=7(@9&4@
M<WEN=&%X92!D86YS(&QE<R!T97)M97,@9&4@<F5C:&5R8VAE`%-Y<FEE`$]R
M86=E<P!/<F%G92!E="!V96YT`$]R86=E<P!&:6-H:65R(%135@!486)L96%U
M`%!R;W!R:>ETZ7,@9'4@=&%B;&5A=0!0<F]P<FGI=.ES(&1U('1A8FQE874`
M5&'O=V%N`%1A[W=A;BP@<')O=FEN8V4@9&4@0VAI;F4`5&%J:6MI<W1A;@!4
M86YZ86YI90!#:6)L9:`Z`%3B8VAE<P!.=6WI<F\@9&4@=.ELZ7!H;VYE`%1E
M;7#I<F%T=7)E('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``5&5M<.ER871U
M<F4`5&5M<.ER871U<F6@.B``3&4@<')O9FEL("5S(&YO;B!T<F]U=ND`061M
M:6YI<W1R871I;VX@9&5S(&UO9.AL97,`5&5X=&4`5&5X=&4@<V5U;`!!;&EG
M;F5M96YT(&1U('1E>'1E`%1E>'1E(&5N(&AA=70`2F4`5&AA[R`H5$E3+38R
M,"D`5&AA[VQA;F1E`$UE<F-I(&0G879O:7(@=71I;&ESZ2!L92!S>7-TZ&UE
M+@!,92!F:6-H:65R(&0G86ED92`E<R!P;W5R("5S(&XG97AI<W1E('!A<RX@
M0W+I871I;VX@9"=U;B!N;W5V96%U+@!,)V5X=&5N<VEO;B!&5%`@;B=E<W0@
M<&%S(&1I<W!O;FEB;&4N`$QE(&UO=&5U<B!D)VEN=.EG<F%T:6]N($AO<F1E
M+TMO;&%B(&YE('-U<'!O<G1E('!A<R"K("5S(+L`3&$@8VQA<W-E($UA:6YT
M96YA;F-E.CH@;B=A('!A<R#I=.D@8VAA<F?I92!C;W)R96-T96UE;G0`3&$@
M9F5NZG1R92!D97,@;W!T:6]N<R!S)V5S="!F97)MZ64N(%-O<G1I92X`3"=A
M9&UI;FES=')A=&5U<B!D;VET(&-O;F9I9W5R97(@=6X@8F%C:V5N9"!P97)M
M86YE;G0@<&]U<B!L97,@<&5R;6ES<VEO;G,@<VD@=F]U<R!V;W5L97H@;&5S
M(&5M<&QO>65R+@!,82!B;W)D=7)E(&1U(&)A<R!S975L96UE;G0`3"=)1"!D
M=2!C;VYT86-T(&XG82!P87,@Z73I('-PZ6-I9FGI+"!L86ES<^D@=FED92!O
M=2!N)V$@<&%S(.ETZ2!T<F]U=ND@9&%N<R!L82!B87-E(&1E(&1O;F[I97,N
M`$-E(&-O;G1A8W0@82!B:65N(.ETZ2!A:F]U=.D@X"!V;W1R92!C87)N970@
M9"=A9')E<W-E<RX@`$QE(&)L;V,@9&4@<VEG;F%T=7)E(%!'4"!SZ7!A<ND@
M97-T(&[I8V5S<V%I<F4@<&]U<B!VZ7)I9FEE<B!L82!S:6=N871U<F4N`$PG
M240@9&4@;&$@;&ES=&4@;B=A('!A<R#I=.D@<W#I8VEF:>DL(&QA:7-SZ2!V
M:61E(&]U(&YO;B!T<F]U=ND@9&%N<R!L82!B87-E(&1E(&1O;F[I97,N`$QA
M(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B!N)V$@<&%S(.ETZ2!S<.EC:69IZ64N
M`$QE(&-H:69F<F5M96YT(&[I8V5S<VET92!U;F4@8V]N;F5X:6]N('/I8W5R
M:7/I92X`3&4@9FEC:&EE<B`E<R!D;VET(&-O;G1E;FER(&QE<R!O<'1I;VYS
M("5S+@!,92!F:6-H:65R("5S(&1O:70@8V]N=&5N:7(@8V5R=&%I;F5S(&]P
M=&EO;G,@)7,N`$QE(&9I8VAI97(@;F4@<&5U="!P87,@ZG1R92!C;W!IZ2!S
M=7(@;'5I+6WJ;64N`$QE(&9I8VAI97(@;F4@8V]N=&5N86ET(&%U8W5N92!D
M;VYNZ64N`$-E('%U:2!S=6ET('-O;G0@;&5S(&5N+73J=&5S('!O=7(@8V4@
M;65S<V%G92!M97-S86=E+U)&0S@R,BX`3&4@;6]D92!P;&5I;B#I8W)A;B!C
M875S92!D97,@<')O8FSH;65S(&%V96,@26YT97)N970@17AP;&]R97(@9/L@
MX"!D97,@8F]G=65S(&1U(&YA=FEG871E=7(@<75I(&XG;VYT('!U(.IT<F4@
M8V]N=&]U<F[I<RX@5F]U<R!P;W5V97H@ZG1R92!C;VYF<F]N=.ES(.`@9&4@
M;"=A9F9I8VAA9V4@9&4@8V%R86-TZ')E<R#I=')A;F=E<RP@874@;F]N+69O
M;F-T:6]N;F5M96YT(&1E<R!C97)T86EN97,@9F]N8W1I;VYS(&5T+V]U(&%U
M('!L86YT86=E(&%LZ6%T;VER92!D=2!N879I9V%T975R+B!3:2!V;W1R92!S
M>7-TZ&UE(&5S="!U;B!7:6YD;W=S(#EX+"!I;"!E<W0@='+H<R!P;W-S:6)L
M92!Q=64@=F]U<R!A=7)E>B!U;F4@)T9A=71E(&?I;NER86QE(&1E('!R;W1E
M8W1I;VXG(&5T('%U92!V;W5S(&1E=G)E>B!R963I;6%R<F5R('9O=')E(&]R
M9&EN871E=7(N7&Y<;E9O=7,@879E>B#I=.D@<'+I=F5N=7,N(%-64"!A<'!U
M>65Z('-U<B!/2R!S:2!V;W5S('9O=6QE>B!T;W5J;W5R<R!E<W-A>65R(&QE
M(&UO9&4@<&QE:6X@Z6-R86X@9&4@;"?I9&ET975R`$QE(&9I8VAI97(@9"=A
M:61E("5S(&YE(&-O;6UE;F-E('!A<R!P87(@/#]X;6P`3"=I9&5N=&ETZ2"K
M("5S(+L@(&$@Z73I('-U<'!R:6WI92X`3&4@8_1TZ2!G875C:&4@<V5U;&5M
M96YT`$PG96UP;&%C96UE;G0@9'4@<')O9W)A;6UE($=N=5!'(&1O:70@ZG1R
M92!F;W5R;FD@X"!L82!C;&%S<V4@0W)Y<'1?<&=P.CHN`$QE(&UE<W-A9V4@
M96YV;WGI(&QE("5S(.`@)7,@879E8R!C;VUM92!S=6IE=""K("5S(+L@82#I
M=.D@869F:6-HZ2X@"DEL(&XG>2!A(&%U8W5N92!G87)A;G1I92!Q=64@8V4@
M;65S<V%G92!A(.ETZ2!L=2!O=2!C;VUP<FES+@!,92!N;VT@X"!U=&EL:7-E
M<B!E;B!L:6%N="#@(&QA('!A9V4@9&4@8V]M<&]S:71I;VX`3&4@;6]D=6QE
M($]P96Y34TP@97-T(')E<75I<R!P;W5R(&QA(&-L87-S92!(;W)D95]#<GEP
M=%]S;6EM93HZ+@!,82!P<NEFZ7)E;F-E(*N@)7.@NR!N)V$@<&%S('!U(.IT
M<F4@96YR96=I<W1RZ64@8V%R('-A('1A:6QL92!DZ7!A<W-E(&QE(&UA>&EM
M=6T@875T;W)I<^D`3&4@<')O9W)A;6UE('5T:6QI<^D@<&]U<B!V:7-U86QI
M<V5R(&-E('1Y<&4@9&4@9&]N;NEE<R`H)7,I(&XG82!P87,@Z73I('1R;W5V
MZ2X`3&5S(&/T=.ES(&=A=6-H92!E="!D<F]I="!S975L96UE;G0`3&4@8_1T
MZ2!D<F]I="!S975L96UE;G0`3&4@<V5R=F5U<B"KH"5SH+L@82#I=.D@<W5P
M<')I;>DN`$QE('-E<G9E=7(@JZ`E<Z"[(&$@Z73I(&5N<F5G:7-T<NDN`$QA
M(')E<77J=&4@9"=E;G)E9VES=')E;65N="!P;W5R("5S(&$@Z73I(&3I<&QA
M8^EE+@!,82!L:6=N92!D96UA;F3I92!N)V5X:7-T92!P87,N`$QE(&9I8VAI
M97(@=&5M<&]R86ER92"K("5SH+L@;B=E>&ES=&4@<&%S+@!,92!H875T(&5T
M(&QE(&)A<R!S975L96UE;G0`3&4@:&%U="!S975L96UE;G0`3&5S(&1O;F[I
M97,@=.ELZ6-H87)GZ65S('9E<G,@;&4@<V5R=F5U<B!O;G0@Z73I('!E<F1U
M97,@9&5P=6ES(&PGZ71A<&4@<'+I8^ED96YT92X@`$QE(&9I8VAI97(@Z6UI
M<R!N)V$@<&%S('!U(.IT<F4@96YR96=I<W1RZ2X`3&4@8FQO8R"KH'=E871H
M97(N8V]MH+L@;B=E<W0@<&%S(&1I<W!O;FEB;&4N`%+I<&5R=&]I<F4@9&5S
M('1HZ&UE<R"KH"5SH+L@;F]N('1R;W5VZ0!);"!N)WD@82!P87,@9"=O<'1I
M;VYS(&1I<W!O;FEB;&5S`$%U8W5N92!P87)T:64@;F4@<&5U="#J=')E(&%F
M9FEC:.EE(&5N(&QI9VYE+@!);"!Y("!A('1R;W`@9&4@8V%R86-TZ')E<R!D
M86YS(&-E(&-H86UP+B!6;W5S(&5N(&%V97H@96YT<ND@)7.@.R!I;"!E;B!F
M875T(&UO:6YS(&1E("5S+@!);"!N)WD@82!P87,@96YC;W)E(&1E(&9I8VAI
M97(@9"=A:61E('!O=7(@)7,N`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R
M<R!D92!L)V%J;W5T(&1E(*N@)7.@NRX@("5S+@!5;B!P<F]B;.AM92!E<W0@
M87!P87)U(&QO<G,@9&4@;"=A:F]U="!D92"KH"5SH+N@.B`E<P!5;B!P<F]B
M;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&5S(&1O
M;F[I97,@9&4@;"=U=&EL:7-A=&5U<B"KH"5SH+N@.B``56X@<')O8FSH;64@
M97-T(&%P<&%R=2!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E(*N@)7.@NZ`Z
M(`!5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;&$@;6ES92#@(&IO
M=7(@9&4@JZ`E<Z"[H#H@)7,`56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S
M(&1E(&PG96YV;VD@9'4@9FEC:&EE<J`Z(&%U8W5N("5S(&XG82#I=.D@=')A
M;G-M:7,N`%5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O
M:2!D=2!F:6-H:65RH#H@;&4@)7,@Z71A:70@<&QU<R!G<F]S('%U92!L92!M
M87AI;75M(&%U=&]R:7/I("@E9"!O8W1E=',I+@!5;F4@97)R975R(&5S="!S
M=7)V96YU92!L;W)S(&1E(&PG96YV;VD@9'4@9FEC:&EE<J`Z(&QE("5S(&$@
MZ73I('1R86YS;6ES('!A<G1I96QL96UE;G0N`%5N92!E<G)E=7(@<R=E<W0@
M<')O9'5I=&4@;&]R<R!D92!L)V%F9FEC:&%G92!D92!C971T92!P87)T92!D
M=2!M97-S86=E`%5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L
M)VEM<&]R=&%T:6]N(&1E<R!D;VYNZ65S(&1E(&-E(&-O;G1A8W0N`%5N92!E
M<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L)VEM<&]R=&%T:6]N(&1E
M(&-E='1E(&-A<G1E(&E#86QE;F1A<BX`26P@>2!A=F%I="!U;F4@97)R975R
M(&1A;G,@;&4@9F]R;75L86ER92!D92!C;VYF:6=U<F%T:6]N+B!0975T+>IT
M<F4@879E>BUV;W5S(&QA:7-SZ2!U;B!C:&%M<"!R97%U:7,@=FED92X`56YE
M(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG;W5V97)T=7)E(&1U
M(&9I8VAI97(@)7,N($5S<V%Y97H@9&4@;&%N8V5R('1R86YS;&%T:6]N+G!H
M<"!A=F5C(&PG;W!T:6]N("UD('!O=7(@=F]I<B!L97,@;65S<V%G97,@9"=E
M<G)E=7(@9&4@;"=A;F%L>7-E=7(@6$U,+@!5;F4@97)R975R(',G97-T('!R
M;V1U:71E(&QO<G,@9&4@;"=E>.EC=71I;VX@9&4@8V5T=&4@9F]N8W1I;VX@
M9'4@8V%R;F5T(&0G861R97-S92X@4U90(&5S<V%Y97(@X"!N;W5V96%U('!L
M=7,@=&%R9"X`26P@>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D92!L82!M:7-E
M(.`@:F]U<B!D97,@:6YF;W)M871I;VYS('-U<B!L92!C;VYT86-T+B`@5F5U
M:6QL97H@97-S87EE<B#@(&YO=79E874N`$EL('D@82!E=2!U;F4@97)R975R
M(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES=&4@9&4@9&ES=')I
M8G5T:6]N+B`@5F5U:6QL97H@97-S87EE<B!D92!N;W5V96%U+@!,92!P<NES
M96YT('-E<G9E=7(@24U!4"!N92!S=7!P;W)T92!P87,@;&4@<&%R=&%G92!D
M92!D;W-S:65R<RX`QV$@;F4@<V5M8FQE('!A<R#J=')E('5N92!A<F-H:79E
M(%)!4B!V86QI9&4N`,=A(&YE('-E;6)L92!P87,@ZG1R92!U;B!F:6-H:65R
M(%I)4"!V86QI9&4N`,=A(&YE('-E;6)L92!P87,@ZG1R92!U;B!N=6WI<F\@
M9&4@8V%R=&4@=F%L:61E+@!#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@
M;65S<V%G97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+V-L:6-K871E;&PN8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%14
M4`!#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G97,@X"!T<F%V
M97)S(&QA('!A<W-E<F5L;&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%``0V4@<&EL;W1E('!E<FUE
M="!L)V5N=F]I(&1E(&UE<W-A9V5S('!A<B!33510(.`@=')A=F5R<R!L82!P
M87-S97)E;&QE(%9O9&%F;VYE($ET86QI92P@<V5U;&5M96YT(&%U>"!N=6WI
M<F]S(%9O9&%F;VYE+B!#96QA(&[I8V5S<VET92!U;B!C;VUP=&4@9&4@8V]U
M<G)I96P@5F]D869O;F4@271A;&EE("AH='1P.B\O=W=W+C$Y,"YI="DN`$-E
M(&-H86UP(&5S="!O8FQI9V%T;VER92X`0V4@8VAA;7`@;F4@9&]I="!C;VYT
M96YI<B!Q=64@9&5S(&5N=&EE<G,N`$-E(&-H86UP(&YE(&1O:70@8V]N=&5N
M:7(@<75E(&1E<R!N;VUB<F5S(&5T(&QE<R!D975X+7!O:6YT<RX`0V4@8VAA
M;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S('9A;&5U<G,@;V-T86QE<RX`
M0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U;F4@;&ES=&4@9"=E;G1I97)S('/I
M<&%RZ7,@<&%R(&1E<R!V:7)G=6QE<R!O=2!D97,@97-P86-E<P!#92!C:&%M
M<"!D;VET(.IT<F4@=6X@;F]M8G)E('9A;&ED92X`0V4@8VAA;7`@9&]I="!C
M;VYT96YI<B!U;B!C;V1E(&1E(&-O=6QE=7(@874@9F]R;6%T(%)'0B!H97AA
M9.EC:6UA;"P@<&%R(&5X96UP;&4@)R,Q,C,T868G+@!#92!F;W)M=6QA:7)E
M(&$@9.EJX"#I=.D@=')A:73I+@!#)V5S="`E<P!#96-I(&5S="!U;B!O8FIE
M="!+;VQA8B!'<F]U<'=A<F4N(%!O=7(@=F]I<B!C970@;V)J970L('9O=7,@
M9&5V<F5Z(&%V;VER('5N(&-L:65N="!D92!C;W5R<FEE;"!Q=6D@8V]M<')E
M;F0@;&4@9F]R;6%T($MO;&%B($=R;W5P=V%R92X@4&]U<B!U;F4@;&ES=&4@
M9&4@8V5S(&-L:65N=',@9&4@8V]U<G)I96PL('9I<VET97H@)7,`0V4@;65S
M<V%G92!A(.ETZ2#I8W)I="!D86YS('5N(&-O9&4@9&4@8V%R86-TZ')E<R`H
M)7,I(&%U=')E('%U92!L92!V]'1R92X`0V4@;F]M8G)E(&1O:70@ZG1R92!S
M=7#I<FEE=7(@X"!U;BX`0V4@<V-R:7!T(&1O:70@ZG1R92!E>.EC=73I(&1E
M<'5I<R!U;F4@;&EG;F4@9&4@8V]M;6%N9&4N`$-E('-E<G9E=7(@;F4@<&5U
M="!P87,@9.EC;VUP<F5S<V5R(&QE<R!F:6-H:65R<R!:25`@970@9WII<"X`
M0V4@<WES=.AM92!E<W0@<'+I<V5N=&5M96YT(&3I<V%C=&EVZ2X`0V5T=&4@
M=F%L975R(&1O:70@ZG1R92!U;B!N;VUB<F4N`$-E='1E(&9E;NIT<F4@9&]I
M="#J=')E(&%P<&5LZ64@9&5P=6ES('5N92!F96[J=')E(&1E<R!O<'1I;VYS
M`%1O;FYE<G)E`%1I8VME=',`2&5U<F4`4W5I=FD@:&]R86ER90!&;W)M870@
M9"=H975R90!3Z6QE8W1I;VX@9&4@;"=H975R90!4:6UO<B!O<FEE;G1A;`!4
M:71R90!4:71R92`H:6YF;V)U;&QE*:`Z`,``4&]U<B!SZ6QE8W1I;VYN97(@
M<&QU<VEE=7)S(&ET96US(.`@;&$@9F]I<RP@;6%I;G1E;F5Z(&5N9F]N8^D@
M;&4@8F]U=&]N(*N@0W1R;*"[("A00RD@;W4@JZ!#;VUM86YD9:"[("A-86,I
M(&5N(&-L:7%U86YT+@!!=6IO=7)D)VAU:0!6;VER(&QA('-O=7)C92!(5$U,
M`%1O9V\`5&]K96QA=0!$96UA:6X`5&]N9V$`2&%U=`!#861R92!D=2!H875T
M("A?=&]P*0!4<F%D=6ET`%1R861U8W1I;VYS`%1R:6YI=.DM970M5&]B86=O
M`%9R86D@;W4@9F%U>`!-80!4=6YI<VEE`%1U<G%U:64`5'5R8R`H25-/+3@X
M-3DM.2D`5'5R:VWI;FES=&%N`,YL97,@5'5R<75E<R!E="!#8>]Q=65S`%1U
M=F%L=0!%;G1R97H@=F]T<F4@8VAO:7B@.B``26YD:6-E(%56H#H@`%523`!5
M4DP@<&]U<B!V;W1R92!R87!P;W)T(&1E(&QI=G)A:7-O;B!D=2!S8W)I<'0`
M55),.@!/=6=A;F1A`%5K<F%I;F4`26UP;W-S:6)L92!D)V%T=&5I;F1R92!L
M92!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S:6)L92!D)V%J;W5T97(@9&5S(&EN
M9F]R;6%T:6]N<R!C;VUP;.EM96YT86ER97,@X"!L)VEN<V-R:7!T:6]N+@!)
M;7!O<W-I8FQE(&1E(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N<R!P;W5R(&QE
M(&9I8VAI97(@5D93(*L@)7,@NRX`26UP;W-S:6)L92!D92!M;V1I9FEE<B!L
M97,@<&5R;6ES<VEO;G,@<&]U<B!L92!F:6-H:65R(%9&4R`E<R\E<RX`26UP
M;W-S:6)L92!D92!C:&%N9V5R('!O=7(@)7,N`$-O;FYE>&EO;B!I;7!O<W-I
M8FQE(&%U('-E<G9E=7(@4U%,+@!#;VYN97AI;VX@:6UP;W-S:6)L92!E;B!3
M4TP`26UP;W-S:6)L92!D92!C;W!I97(@=6X@9FEC:&EE<B!61E,N`$EM<&]S
M<VEB;&4@9&4@8W+I97(@=6X@<NEP97)T;VER92!61E,@JR`E<R"[+@!);7!O
M<W-I8FQE(&1E(&-RZ65R('5N('+I<&5R=&]I<F4@5D93+@!);7!O<W-I8FQE
M(&1E(&-RZ65R(&QE(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&1E(&-RZ65R
M('5N(&9I8VAI97(@5D93('9I9&4N(`!/=79E<G1U<F4@:6UP;W-S:6)L92!D
M92!L)V%R8VAI=F4@8V]M<')E<W/I92X@`%-U<'!R97-S:6]N(&EM<&]S<VEB
M;&4@9&4@JR`E<R"[+"!L92!D;W-S:65R(&XG97-T('!A<R!V:61E+@!3=7!P
M<F5S<VEO;B!I;7!O<W-I8FQE(&1E("5S+"!L92!D;W-S:65R(&XG97-T('!A
M<R!V:61E`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@JZ`E<Z"[H#H@)7,N
M`%-U<'!R97-S:6]N('+I8W5R<VEV92!D=2!D;W-S:65R(%9&4R!I;7!O<W-I
M8FQE+@!3=7!P<F5S<VEO;B!D=2!RZ7!E<G1O:7)E(%9&4R!I;7!O<W-I8FQE
M+@!);7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z
M("5S+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&9I8VAI97(@5D93(*L@
M)7,@NRX`4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!F:6-H:65R(%9&4RX`
M4W5P<')E<W-I;VX@5D93('+I8W5R<VEV92!I;7!O<W-I8FQEH#H@)7,N`$EM
M<&]S<VEB;&4@9&4@9.ET97)M:6YE<B!L92!D;W-S:65R(&-O=7)A;G0N`$EM
M<&]S<VEB;&4@9"=E>'1R86ER92!L97,@9.ET86EL<R!D=2!C97)T:69I8V%T
M`$EM<&]S<VEB;&4@9&4@8VAA<F=E<B!L82!DZ69I;FET:6]N(&1E("5S+@!)
M;7!O<W-I8FQE(&1E(&3I<&QA8V5R(&QE(&9I8VAI97(@5D93+@!);7!O<W-I
M8FQE(&0G;W5V<FER(&QE(&9I8VAI97(@5D93(*L@)7,@NRX`26UP;W-S:6)L
M92!D)V]U=G)I<B!U;B!F:6-H:65R(%9&4R!E;B#I8W)I='5R92X`26UP;W-S
M:6)L92!D)V]U=G)I<B!U;B!F:6-H:65R(%9&4RX`3W5V97)T=7)E(&EM<&]S
M<VEB;&4@9&4@;"=A<F-H:79E(&-O;7!R97-SZ64N`$EM<&]S<VEB;&4@9&4@
M;&ER92!L92!F:6-H:65RH#H@`$QE8W1U<F4@9'4@<NEP97)T;VER92!R86-I
M;F4@5D93(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9&4@<F5N;VUM97(@)7,@
M96X@)7.@.B!L92!D;W-S:65R(&-I8FQE(&5X:7-T92!DZ6K@`$EM<&]S<VEB
M;&4@9&4@<F5N;VUM97(@;&4@<NEP97)T;VER92!61E,N`$EM<&]S<VEB;&4@
M9&4@<F5N;VUM97(@;&4@<NEP97)T;VER92!61E.@.B`E<RX`26UP;W-S:6)L
M92!D92!R96YO;6UE<B!L92!F:6-H:65R(%9&4R"K("5S(+LN`$EM<&]S<VEB
M;&4@9&4@<F5N;VUM97(@;&4@9FEC:&EE<B!61E,@)7,O)7,N`$EM<&]S<VEB
M;&4@9&4@<F5N;VUM97(@;&4@9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@9"=E
M>.EC=71E<B`G;6MI<V]F<R<N`$EM<&]S<VEB;&4@9&4@=')A9'5I<F4@8V4@
M9&]C=6UE;G0@5V]R9"X`26UP;W-S:6)L92!D)^EC<FER92!L92!F:6-H:65R
M(%9&4R"K("5S(+LN`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&5S(&1O;F[I97,@
M9'4@9FEC:&EE<B!61E,@*&-O<'DH*2!I;7!O<W-I8FQE*2X`26UP;W-S:6)L
M92!D)^EC<FER92!L97,@9&]N;NEE<R!D=2!F:6-H:65R(%9&4RX`4V]U;&EG
M;F5R`$%N;G5L97(@;&5S(&-H86YG96UE;G1S`$%N;G5L92!V;W1R92!D97)N
M:>AR92!A8W1I;VX`4NEP;VYS92!I;F%T=&5N9'5E(&1U('-E<G9E=7(@;&]R
M<R!D92!L82!C;VYN97AI;VZ@.B``4NEP;VYS92!I;F%T=&5N9'5E(&1U('-E
M<G9E=7(@X*`Z(`!(;W)S(&-A=.EG;W)I90!5;FEC;V1E("A55$8M."D`R6UI
M<F%T<R!!<F%B97,@56YI<P!2;WEA=6UE+55N:0#)=&%T<RU5;FES`,YL97,@
M97ATZ7)I975R97,@9&5S(,ET871S+55N:7,`56YI=.ES`$EN8V]N;G4`87!I
M;7-G:60@:6YC;VYN=2`H05!)($UE<W-A9V4@240I+@!C;&EM<V=I9"!I;F-O
M;FYU("A#;&EE;G0@365S<V%G92!)1"DN`$-O;6UA;F1E(&EN8V]N;G5EH#H@
M)7,`16UP;&%C96UE;G0@<^EL96-T:6]N;ND@:6YC;VYN=2X`3F]M(&0G=71I
M;&ES871E=7(@;W4@;6]T(&1E('!A<W-E(&EN8V]N;G4N`$3I;&EE<B!L)^EL
MZ6UE;G0@8V]U<F%N=`!386YS(&YO;0!,97,@<V-R:7!T<R!N;VXM<')I=FEL
MZ6=IZ7,@;F4@<&5U=F5N="!A8V/I9&5R(&%U>"!F;VYC=&EO;G,@8V]U<&5R
M+V-O<&EE<B]C;VQL97(@<&]U<B!D97,@<F%I<V]N<R!D92!SZ6-U<FETZ2X@
M07!P=7EE>B!S=7(@3TL@<&]U<B!V;VER('5N92!N;W1E('1E8VAN:7%U92!S
M=7(@;6]Z:6QL82YO<F<@<75I('9O=7,@97AP;&EQ=65R82!C;VUM96YT(&%U
M=&]R:7-E<B!U;B!S8W)I<'0@X"!U=&EL:7-E<B!L92!P<F5S<V4M<&%P:65R
M<P!296UE='1R92!L82!C;W5L975R(.`@>NER;P!%>'1E;G-I;VX@;F]N('!R
M:7-E(&5N(&-O;7!T90!.;VX@=')A9'5I=`!-;V1I9FEE<@!-;V1I9FEE<B`E
M<P!-;V1I9FEE<B!L)W5T:6QI<V%T975R`$UI<V4@X"!J;W5R(&1E(*N@)7.@
MNRX`36ES92#@(&IO=7(@9'4@9FEC:&EE<B!D)V%I9&4@)7,@<&]U<B`E<RX`
M3&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&5S="!S=7!P<FEMZ0!#:&%R9V5R
M`%1O=7,@;&5S(&9I8VAI97)S(&1E(&-O;F9I9W5R871I;VX@9&5S(&%P<&QI
M8V%T:6]N<R!O;G0@Z73I(&5N=F]YZ7,@<W5R(&QE('-E<G9E=7(N`$QE='1R
M97,@;&%T:6YE<R!M86IU<V-U;&5S`$YO;6)R97,@<F]M86EN<R!M86IU<V-U
M;&5S`%5R=6=U87D`571I;&ES871I;VZ@.@!%;7!L;WGI(&%C='5E;&QE;65N
M=*`Z("5S`%5T:6QI<V5R(%-33`!5=&EL:7-E<B!S:2!L92!N;VT@9"=U=&EL
M:7-A=&5U<B]M;W0@9&4@<&%S<V4@97-T(&1I9F;I<F5N="!D=2!S97)V975R
M($E-4U`N`$PG=71I;&ES871E=7(@)7,@;B=A('!A<R!L)V%U=&]R:7-A=&EO
M;B!P;W5R("5S+@!!9&UI;FES=')A=&EO;B!D97,@=71I;&ES871E=7)S`%!R
MZ6;I<F5N8V5S('!E<G-O;FYE;&QE<P!%;G)E9VES=')E;65N="!D97,@=71I
M;&ES871E=7)S`$PG96YR96=I<W1R96UE;G0@9"=U=&EL:7-A=&5U<B!E<W0@
M9.ES86-T:7;I('-U<B!C92!S>7-TZ&UE+@!5=&EL:7-A=&5U<B!N;VX@=')O
M=7;I`%5T:6QI<V%T975R(&YO;B!T<F]U=NDN`%!E<FUI<W-I;VYS(&1E(&PG
M=71I;&ES871E=7(`3F]M(&0G=71I;&ES871E=7(`3&4@;F]M(&1E(&-O;FYE
M>&EO;B"KH"5SH+L@97AI<W1E(&3I:N`N`%5T:6QI<V%T975RH#H`3F]M(&0G
M=71I;&ES871E=7*@.B``571I;&ES871E=7)S`%5T:6QI<V%T975R<R!DZ69I
M;FESH#H`3W5Z8NEK:7-T86X`4NEP97)T;VER92!61E,@:6YE>&ES=&%N="X`
M06)S96YC97,`3&5S(&5M<&QA8V5M96YT<R!V86QI9&5S('1R;W5VZ7,@:6YC
M;'5E;G2@.B``5F%L:61I=.D`5F%L975R(&5N(&UI;G5T97,@X"!P87)T:7(@
M9&4@;6%I;G1E;F%N="X`5F%L975R('-U<.ER:65U<F4@X"!L82!L;VYG=65U
M<B!M87AI;6%L92!D92`E<RX`5F%L975R<P!686QE=7)S(.`@<^EL96-T:6]N
M;F5R(&1E`%9A;G5A='4`5F%R:6%B;&4`5NENZ7IU96QA`,EC:&5C(&1E(&QA
M(';I<FEF:6-A=&EO;B`F;61A<V@[(&-E(&UE<W-A9V4@82!P975T+>IT<F4@
MZ73I(&9A;'-I9FGI+@!697)S:6]N`$-O;G1R]&QE(&1E('9E<G-I;VX`06QI
M9VYE;65N="!V97)T:6-A;`!296UP;&ES<V%G92!V97)T:6-A;`!697)T:6-A
M;*`Z`%1RZ',@:&%U=&4`5FEE=&YA;0!6:>IT+6YA;6EE;B`H5DE30TE)*0!6
M;VER("5S`%9O:7(@=6YE('!A9V4@=V5B(&5X=&5R;F4`5F]I<B!C;VUM92`E
M<P#.;&5S(%9I97)G97,@8G)I=&%N;FEQ=65S`,YL97,@5FEE<F=E<R!D97,@
MR71A=',M56YI<P!6:7-I8FEL:73I`%9I<VEB:6QI=.F@.B``5F]D869O;F4@
M271A;'D@=FEA(%--5%``3D]424-%`$%45$5.5$E/3B$A(2`@4U504%))3452
M($Q%(%-#4DE05"!-04Y514Q,14U%3E0@1$4@)7,`5V%L;&ES(&5T($9U='5N
M80!!='1E;G1I;VX`079E<G1I<W-E;65N=*`Z(`!-90!0<NEV:7-I;VYS(&WI
M=.EO`$1O;F[I97,@;>ETZ6\@9F]U<FYI97,@<&%R`%=E871H97(N8V]M`%=E
M8@!3:71E('=E8@!#:&%Q=64@<V5M86EN90!":65N=F5N=64`0FEE;G9E;G5E
M(.`@)7,`0FEE;G9E;G5E+"`E<P!/8V-I9&5N=&%L("A)4T\M.#@U.2TQ*0!/
M8V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4V%H87)A($]C8VED96YT86P`475E
M;&QE(&%P<&QI8V%T:6]N("5S(&1O:70M:6P@<'+I<V5N=&5R(&%P<NAS(&QA
M(&-O;FYE>&EO;J`_`%%U96P@97-T(&QE(&-A<F%C=.AR92!D92!SZ7!A<F%T
M:6]NH#\`475E;"!E<W0@;&4@8V%R86-TZ')E(&1E(&-I=&%T:6]NH#\`475E
M;&QE<R!P:&%S97,`475E;&QE<R!E>'1E;G-I;VYS(&%C=&EV97(@<&]U<B!L
M)^ED:71E=7(@4FEC:"!497AT+@!,87)G975R`$QA<F=E=7(@96X@=6YI=.ES
M($-34P!,87)G975R(&1U(&UE;G4@9&4@9V%U8VAE("5S("`H;&$@8V]N9FEG
M=7)A=&EO;B!P<F5N9')A(&5F9F5T(.`@;&$@<')O8VAA:6YE(&-O;FYE>&EO
M;BF@.@!,87)G975R(&1U('1A8FQE874`56YI=.D@9&4@;&%R9V5U<@!,87)G
M975RH#H`5VEK:0!696YT`%9E;G0@=/1T(&QE(&UA=&EN`%9I=&5S<V4@9'4@
M=F5N="!E;B!N)F]E;&EG.W5D<P!696YTH#H`5F5N=*`Z(`!386=E<W-E`$QI
M<W1E(&1E('8F;V5L:6<[=7@`5')A=F%I;`!!9')E<W-E('!R;V9E<W-I;VYN
M96QL90!4Z6SI<&AO;F4@<')O9F5S<VEO;FYE;`#)8W)I='5R92!D=2!F:6-H
M:65R(&0G86ED92!M:7,@X"!J;W5R('-U<B`E<RX`6"U2968`0V]N=')A:6YT
M97,@8F%S:7%U97,@6#4P.78S`%5T:6QI<V%T:6]N(&1E(&-LZ2#I=&5N9'5E
M(%@U,#EV,P!!=71R92!N;VT@9'4@<W5J970@6#4P.78S`$ED96YT:69I8V%T
M975R(&1E(&-LZ2!D=2!S=6IE="!8-3`Y=C,`17AT96YS:6]N<R!8-3`Y=C,`
M04$`04%!00!#87)T92"KH%EA:&]OH"&@NP!!;FYU96QL96UE;G0`6>EM96X`
M3W5I`$]U:2P@:B=A8V-E<'1E`%9O=7,@ZG1E<R!E;B!M;V1E(*N@5&5X=&6@
MNRP@(%5T:6QI<V5R(&QE(&)O=71O;B!;/#Y=('!O=7(@<F5V96YI<B!A=2!M
M;V1E(*N@5UE325=91Z"[+@!6;W5S(&XGZG1E<R!P87,@875T:&5N=&EF:>DN
M`%9O=7,@;F4@<&]U=F5Z('!A<R!A=F]I<B!L92!C87)A8W3H<F4@JUR[(&1A
M;G,@=F]T<F4@;F]M(&-O;7!L970N`%9O=7,@;F4@<&]U=F5Z('!A<R!C:&%N
M9V5R(&QE(&UO="!D92!P87-S92!P;W5R(&PG=71I;&ES871E=7(@)7,`5F]U
M<R!N)V%V97H@<&%S('-A:7-I('5N92!A9')E<W-E(.EL96-T<F]N:7%U92!V
M86QI9&4N`%9O=7,@;B=A=F5Z('!A<R!A<W-O8VGI(&QE<R!C:&%M<',@9'4@
M9FEC:&EE<B!I;7!O<G3I(&%U>"!C:&%M<',@8V]R<F5S<&]N9&%N=',@9&%N
M<R`E<RX`5F]U<R!A=F5Z(.ETZ2!DZ6-O;FYE8W3I+@!6;W5S(&1E=F5Z(&EN
M<V-R:7)E('5N(&YU;>ER;R!D92!C96QL=6QA:7)E('9A;&ED92P@<V5U;',@
M9&5S(&YO;6)R97,@970@=6X@JRN[(&]P=&EO;FYE;"!P;W5R(&QE<R!A<'!E
M;',@:6YT97)N871I;VYA=7@N`%9O=7,@;B=A=F5Z('!A<R!S86ES:2!U;F4@
M96YT<NEE('9A;&ED92X`5F]U<R!D979E>B!C;VYF:6=U<F5R('5N(&)A8VME
M;F0@1&%T851R964@<&]U<B!U=&EL:7-E<B!L97,@:6YS8W)I<'1I;VYS`%9O
M=7,@9&5V97H@8V]N9FEG=7)E<B!U;B!M;V1U;&4@5D93+@!6;W5S(&1E=F5Z
M(&3I8W)I<F4@;&4@<')O8FSH;64@879A;G0@9&4@;F]U<R!F86ER92!P87)V
M96YI<B!L92!R87!P;W)T+@!6;W5S(&1E=F5Z(&5N=')E<B!U;F4@55),(&_Y
M('!O:6YT92!D92!L:65N+@!6;W5S(&1E=F5Z('-A:7-I<B!V;W1R92!M;W0@
M9&4@<&%S<V4@86-T=65L`%9O=7,@9&5V97H@<V%I<VER('9O=')E(&YO=79E
M874@;6]T(&1E('!A<W-E`$EL(&9A=70@<^EL96-T:6]N;F5R('5N('-E<G9E
M=7(@X"!S=7!P<FEM97(N`%9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T:6QI
M<V%T975R(.`@<F5T:7)E<BX@`%9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T
M:6QI<V%T975R(.`@<F5T:7)E<BX`5F]U<R!D979E>B!S<.EC:69I97(@=6X@
M=71I;&ES871E=7(@X"!A:F]U=&5R+@!6;W5S(&1E=F5Z('-PZ6-I9FEE<B!L
M92!N;VT@9&4@;"=U=&EL:7-A=&5U<B#@(&UO9&EF:65R+@!6;W5S(&1E=F5Z
M(&EN9&EQ=65R('%U96QL92!A8W1I;VX@86-C;VUP;&ER+@!6;W5S(&1E=F5Z
M(.EC<FER92!U;B!N;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R:64N`%9O
M=7,@9&5V97H@<F5S<V%I<VER('9O=')E(&YO=79E874@;6]T(&1E('!A<W-E
M`%9O=')E('-E<W-I;VX@)7,@82!E>'!I<NDN(%9E=6EL;&5Z('9O=7,@<F5C
M;VYN96-T97(N`%9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96P`5F]T<F4@861R
M97-S92!D92!C;W5R<FEE;""K($1E.B"[H#H`5F]S(&1O;F[I97,@<&5R<V]N
M;F5L;&5S`%9O=')E(&%D<F5S<V4@26YT97)N970@82!C:&%N9^D@9&5P=6ES
M(&PG;W5V97)T=7)E(&1E('9O=')E('-E<W-I;VX@)7,N("!0;W5R('9O=')E
M('/I8W5R:73I+"!V;W5S(&1E=F5Z('9O=7,@<F5C;VYN96-T97(N`%9O=')E
M(&YO;0!6;W1R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N(&YE('-U<'!O
M<G1E('!A<R!L)V%J;W5T(&0G=71I;&ES871E=7)S+"!O=2!C971T92!F;VYC
M=&EO;B!A(.ETZ2!R971I<NEE('!O=7(@=6YE(&%U=')E(')A:7-O;BX`5F]T
M<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO;B!N)V5S="!P87,@96X@;65S
M=7)E(&0GZ71A8FQI<B!U;F4@;&ES=&4@9&5S('5T:6QI<V%T975R<RP@;W4@
M8V5T=&4@9F]N8W1I;VX@82#I=.D@<F5T:7+I92!P;W5R('5N92!A=71R92!R
M86ES;VXN`%9O=')E(&YA=FEG871E=7(@<V5M8FQE(&%V;VER(&-H86YGZ2!D
M97!U:7,@;&4@9.EB=70@9&4@=F]T<F4@<V5S<VEO;B`E<RX@(%!O=7(@=F]T
M<F4@<^EC=7)I=.DL('9O=7,@9&5V97H@=F]U<R!R96-O;FYE8W1E<BX`5F]T
M<F4@;F%V:6=A=&5U<B!N92!S=7!P;W)T92!P87,@8V5T=&4@;W!T:6]N`%9O
M=')E(&YA=FEG871E=7(@;F4@<')E;F0@<&%S(&5N(&-O;7!T92!C971T92!O
M<'1I;VX@9"=I;7!R97-S:6]N+B!0<F5S<V5Z($-O;G1R;VPO3W!T:6]N("L@
M4"!P;W5R(&EM<')I;65R`%9O=')E(&9U<V5A=2!H;W)A:7)E(&%C='5E;*`Z
M`%!R;V9I;"!P87(@9.EF875TH#H`5F]T<F4@;F]M(&-O;7!L972@.@!6;W1R
M92!V97)S:6]N(&1E(&=E='1E>'0@97-T('1R;W`@86YC:65N;F4@970@;F4@
M<W5P<&]R=&4@<&%S(%!(4"!N871I=F5M96YT+@I4;W5T97,@;&5S(&-H8>YN
M97,@;F4@<V5R;VYT('!A<R!E>'1R86ET97,`5F]T<F4@;F]U=F5A=2!M;W0@
M9&4@<&%S<V4@<&]U<B`E<R!E<W2@.B5S`%9O=')E(&YO=79E874@;6]T(&1E
M('!A<W-E(&5S="!T<F]P(&QO;F>@.R!U;B!M;W0@9&4@<&%S<V4@;F4@<&5U
M="!P;W-SZ61E<B!P;'5S(&1E("5D(&-A<F%C=.AR97.@(0!6;W1R92!N;W5V
M96%U(&UO="!D92!P87-S92!E<W0@=')O<"!S:6UP;&6@(2!.;VX@;6]D:69I
MZ:`A`%9O=')E(&YO=79E874@;6]T(&1E('!A<W-E(&5S="!T<F]P('-I;7!L
M92X@3F]N(&UO9&EF:>F@(0!6;W1R92!N;W5V96%U(&UO="!D92!P87-S92!D
M;VET(&%V;VER(&%U(&UO:6YS("5D(&-A<F%C=.AR97.@(0!6;W1R92!N;W5V
M96%U(&UO="!D92!P87-S92!D;VET(.IT<F4@9&EF9NER96YT(&1E(&PG86-T
M=65LH"$`5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@9&]I="!A=F]I<B!A
M=2!M;VEN<R`E9"!C87)A8W3H<F5S(&%L<&AA8NET:7%U97,N`%9O=')E(&YO
M=79E874@;6]T(&1E('!A<W-E(&1O:70@879O:7(@874@;6]I;G,@)60@8V%R
M86-TZ')E<R!A;'!H86YU;>ER:7%U97,N`%9O=')E(&YO=79E874@;6]T(&1E
M('!A<W-E(&1O:70@879O:7(@874@;6]I;G,@)60@='EP97,@9&4@8V%R86-T
MZ')E<R!D:69FZ7)E;G1S+DQE<R!T>7!E<R!S;VYTH#H@;6EN=7-C=6QE+"!M
M86IU<V-U;&4L(&YU;>ER:7%U92!E="!S>6UB;VQE<RX`5F]T<F4@;F]U=F5A
M=2!M;W0@9&4@<&%S<V4@9&]I="!A=F]I<B!A=2!M;VEN<R`E9"!C87)A8W3H
M<F5S(&UI;G5S8W5L97,N`%9O=')E(&YO=79E874@;6]T(&1E('!A<W-E(&1O
M:70@879O:7(@874@;6]I;G,@)60@8V%R86-TZ')E<R!N=6WI<FEQ=65S+@!6
M;W1R92!N;W5V96%U(&UO="!D92!P87-S92!D;VET(&%V;VER(&%U(&UO:6YS
M("5D(&-A<F%C=.AR97,@;6%J=7-C=6QE<RX`5F]T<F4@;F]U=F5A=2!M;W0@
M9&4@<&%S<V4@9&]I="!A=F]I<B!M;VEN<R!D92`E9"!C87)A8W3H<F5S(&5S
M<&%C92X`5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@;F4@9&]I="!P87,@
M8V]N=&5N:7(@9&4@8V%R86-TZ')E<R!E<W!A8V4N`%9O=')E(&YO=79E874@
M;6]T(&1E('!A<W-E(&YE(&-O<G)E<W!O;F0@<&%S`%9O<R!O<'1I;VYS(&]N
M="#I=.D@;6ES97,@X"!J;W5R('!O=7(@;&$@9'5RZ64@9&4@8V5T=&4@<V5S
M<VEO;BX`5F]S(&]P=&EO;G,@;VYT(.ETZ2!M:7-E<R#@(&IO=7(N`%9O=')E
M(&UO="!D92!P87-S92!A(.ETZ2!R96UI<R#@('KI<F\`5F]T<F4@;6]T(&1E
M('!A<W-E(&$@Z73I(')E;6ES(.`@>NER;RP@=NER:69I97(@=F]T<F4@8V]U
M<G)I97(@970@8V]N;F5C=&5Z+79O=7,@879E>B!V;W1R92!N;W5V96%U(&UO
M="!D92!P87-S92X`5F]S('-E<G9E=7)S(&1I<W1A;G1SH#H`66]U9V]S;&%V
M:64`6F'O<F4`6F%M8FEE`%II;6)A8G=E`%II<'!Y`%M#86-H97(@;&5S(&-I
M=&%T:6]N<UT`6U)A<'!O<G0@9&4@<')O8FSH;65=`%M!9F9I8VAE<B!L92!T
M97AT92!C:73I("T`6T%F9FEC:&5R(&QE('1E>'1E(&-I=.D@+2`E<R!L:6=N
M97-=`%ML:6=N92`E<R!D92`E<UT`7T%D;6EN:7-T<F%T:6]N`$QI9VYE(&1E
M(%]C;VUM86YD90!?1&%T851R964`4W5P<')I;65R(&QA(%]R86YGZ64`7T=R
M;W5P97,`7T%I9&4`4')O<')?:>ETZ7,@9&4@;"=I;6%G92XN+@!?0V]N;F5X
M:6]N`%]$Z6-O;FYE>&EO;@!?36]D:69I97(@=6X@;&EE;B!W96(N+BX`7T]P
M=&EO;G,`7U!E<FUI<W-I;VYS`%]2971I<F5R('5N(&QI96X`7T-O;F9I9W5R
M871I;VX`4')O<')IZ73I<R!D=2!?=&%B;&5A=0!?571I;&ES871E=7)S`&-A
M<FYE="!D)V%D<F5S<V5S`'5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&6@.@!A
M9V5N9&$`8V%L;64`8VQI<75E>B!I8VD`=&5R;6ENZ0#I8VAE8P!T;VUBZ0!F
M:6-H:65R`'1R;W5VZ:`Z(`!D97!U:7,@;&4@)7,@*"5S*2#@("5S("5S`&@Z
M`&AH`&EM;>ED:6%T96UE;G0`:6YC;W)P;W+I90#)8VAE8R!D92!L9&%P7W-T
M87)T7W1S;`!L:6=N97-=`&5R<F5U<B!M:VES;V9S(&-O9&4@)60@96X@8W+I
M86YT(&PG25-/`&UM`&YO;0!N;VX@;6]D:69IZ0!N;VX@=')O=7;I`&YO;BUI
M;7!LZ6UE;G3I`'!A<R!E;F-O<F4@:6UP;.EM96YTZ0!B;&]C+6YO=&5S`'!O
M=7)C96YT86=E`'!I>&5L<P!L97;I`&UO;G1R97(@;&5S(&1I9F;I<F5N8V5S
M`'-M<S)E;6%I;"!V:6$@2%144`!S<P!F:7AE`&QI<W1E(&1E('3B8VAE<P!L
M92!F:6-H:65R(%!/($AO<F1E(&XG97AI<W1E('!A<R!P;W5R(&QA(&QO8V%L
M92`E<Z`Z`&5N=')E>B!L92!M;W0@9&4@<&%S<V4@9&5U>"!F;VES('!O=7(@
M8V]N9FER;65R`'5N:69IZ0!S86YS(&YO;0!M:7,@X"!J;W5R`%/I;&5C=&EO
M;B!D)W5T:6QI<V%T975R`'9#87)D`'<Z`'=E871H97(N8V]M````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O9VQ?15,O````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-#,`,#(P,34T`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO
M8V%L92]G;%]%4R],0U]-15-304=%4R\`````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<T,P`P,C$W-#$`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P87-S=V0O;&]C86QE+V=L7T53+TQ#7TU%4U-!1T53+W!A<W-W
M9"YM;P```````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0V-3$Q`#$P-#$W,S8R-S0S`#`R,S8P
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````-`````<````G`8``!4!```<#0```````'`1```H````<1$``$``
M``":$0``+0```-L1```(````"1(``"(````2$@``!0```#42```/````.Q(`
M``@```!+$@``!P```%02```+````7!(```4```!H$@``'P```&X2```1````
MCA(``"\```"@$@``"````-`2```#````V1(```@```#=$@``%0```.82```*
M````_!(``!0````'$P``%P```!P3``!$````-!,```H```!Y$P``$0```(03
M```,````EA,```<```"C$P``%0```*L3```0````P1,``!L```#2$P``*0``
M`.X3```"````&!0```4````;%```%@```"$4```0````.!0``!0```!)%```
M+P```%X4```/````CA0``"8```">%```!0```,44```-````RQ0```4```#9
M%```$````-\4```0````\!0```\````!%0``"P```!$5```/````'14```P`
M```M%0``#P```#H5```@````2A4``!T```!K%0``'@```(D5```<````J!4`
M`"T```#%%0``(0```/,5```H````%18``"4````^%@``'P```&06```#````
MA!8``!$```"(%@``!````)H6```,````GQ8```H```"L%@``!0```+<6```+
M````O18```P```#)%@``#@```-86```@````Y18```8````&%P``#@````T7
M```2````'!<``!`````O%P``"````$`7```0````21<```8```!:%P``!P``
M`&$7``!<````:1<```8```#&%P```@```,T7```$````T!<``!@```#5%P``
M$0```.X7```/`````!@```4````0&```!P```!88```'````'A@```H````F
M&```!````#$8```%````-A@```T````\&```/````$H8```Z````AQ@``#L`
M``#"&```/@```/X8```=````/1D``!X```!;&0``!0```'H9```C````@!D`
M``T```"D&0``!P```+(9```1````NAD```@```#,&0``$0```-49```J````
MYQD``!X````2&@``!0```#$:```H````-QH``"D```!@&@``$P```(H:```(
M````GAH``#$```"G&@``0@```-D:```5````'!L```L````R&P``0````#X;
M```]````?QL``$(```"]&P``/@`````<```_````/QP``$(```!_'```/@``
M`,(<```_`````1T``$(```!!'0``/@```(0=```_````PQT``$$````#'@``
M/0```$4>```^````@QX``#\```#"'@``.P````(?```\````/A\``$0```![
M'P``/0```,`?```Z````_A\``$(````Y(```/@```'P@```_````NR````4`
M``#[(```$0````$A```$````$R$```P````8(0``:````"4A```:````CB$`
M`!<```"I(0``%P```,$A```;````V2$``!\```#U(0``$P```!4B```?````
M*2(``$````!)(@``-````(HB```D````OR(```X```#D(@``$````/,B```P
M````!",``#H````U(P``%P```'`C```'````B",```4```"0(P``CP```)8C
M``!T````)B0``,T```";)```FP```&DE``!S````!28``*8```!Y)@``B0``
M`"`G``!S````JB<``"$````>*```'````$`H```%````72@```X```!C*```
M`P```'(H```@````=B@``"4```"7*```*@```+TH```F````Z"@```P````/
M*0``%P```!PI```1````-"D```P```!&*0``"````%,I```)````7"D```<`
M``!F*0``"````&XI```&````=RD```T```!^*0``"P```(PI```,````F"D`
M``H```"E*0```@```+`I```&````LRD``"@```"Z*0``)0```.,I```^````
M"2H``$4```!(*@``'P```(XJ```?````KBH``!D```#.*@``(0```.@J```P
M````"BL``!,````[*P``$````$\K```*````8"L``!\```!K*P``'P```(LK
M```0````JRL```\```"\*P``!0```,PK```C`0``TBL``"H```#V+```20``
M`"$M```O````:RT```@```";+0``(0```*0M```%````QBT```\```#,+0``
M#@```-PM```(````ZRT``!,```#T+0``!@````@N```D````#RX``!,````T
M+@``1````$@N```+````C2X```,```"9+@``"@```)TN```?````J"X```X`
M``#(+@``'````-<N```A````]"X``$D````6+P``#@```&`O```8````;R\`
M``\```"(+P``"````)@O```?````H2\```\```#!+P``%@```-$O```R````
MZ"\```(````;,```"P```!XP```@````*C```!D```!+,```%@```&4P```O
M````?#```!@```"L,```*P```,4P```2````\3````X````$,0``!````!,Q
M```/````&#$``!`````H,0``#@```#DQ```5````2#$```\```!>,0``"P``
M`&XQ```3````>C$``!X```".,0``'P```*TQ```C````S3$``"@```#Q,0``
M/````!HR```C````5S(``"0```![,@``*P```*`R```B````S#(```,```#O
M,@``%````/,R```%````"#,``!,````.,P``$P```"(S```%````-C,``!,`
M```\,P``#0```%`S```.````7C,``"4```!M,P``"````),S```5````G#,`
M`!,```"R,P``$@```,8S```&````V3,``!@```#@,P``!@```/DS```/````
M`#0``'X````0-```$@```(\T```"````HC0```8```"E-```'0```*PT```<
M````RC0``!8```#G-```"@```/XT```'````"34```P````1-0``!@```!XU
M```$````)34```4````J-0``%0```#`U```Z````1C4``#<```"!-0``.0``
M`+DU```_````\S4``"$````S-@``*P```%4V```%````@38``"H```"'-@``
M&0```+(V```'````S#8``!$```#4-@``#P```.8V```:````]C8``#D````1
M-P``(0```$LW```(````;3<``!X```!V-P``+P```)4W```6````Q3<```L`
M``#<-P``00```.@W``!C````*C@``!T```"..```"P```*PX``!4````N#@`
M`%(````-.0``5@```&`Y``!2````MSD``%,````*.@``5@```%XZ``!2````
MM3H``%0````(.P``5@```%T[``!2````M#L``%0````'/```50```%P\``!1
M````LCP``%,````$/0``4P```%@]``!/````K#T``%$```#\/0``6````$X^
M``!1````ISX``$\```#Y/@``5@```$D_``!2````H#\``%0```#S/P``"0``
M`$A````3````4D````<```!F0```$0```&Y```!]````@$```"$```#^0```
M'0```"!!```=````/D$``"4```!<00``%````()!```=````ET$``$0```"U
M00``.@```/I!``!6````-4(``"0```",0@``#0```+%"```3````OT(``#$`
M``#30@``5P````5#```?````74,```T```!]0P``!P```(M#``"$````DT,`
M`(T````81```[@```*9$``"_````E44``*,```!51@``Q0```/E&``"M````
MOT<``)8```!M2```(@````1)```;````)TD```8```!#20``%````$I)```#
M````7TD``"H```!C20``,@```(Y)```T````P4D``"\```#V20``$P```"9*
M```<````.DH``!@```!72@``$@```'!*```'````@TH```@```"+2@``"P``
M`)1*```'````H$H```P```"H2@``#````+5*```-````PDH``!0```#02@``
M%````.5*```"````^DH```H```#]2@``+P````A+```P````.$L``#0```!I
M2P``+@```)Y+```>````S4L``"(```#L2P``'0````],```=````+4P``#P`
M``!+3```'P```(A,```1````J$P```4```"Z3```*````,!,```?````Z4P`
M`!4````)30``#P```!]-```9````+TT```$`````````20`````````\````
MC@```#D````B````70```',`````````+P````````!G````+````%L````E
M`````````$,`````````'````,@````;````BP```&,```"[````!@```"T`
M``"%````'P```+T```#/````J0`````````/````AP```#$`````````E```
M`'````";`````````,$```"8```````````````8````#0```"````!6````
M&0```,`````1````````````````````Q0`````````_````E0````````"/
M````$````*``````````QP```'$````F````,P```)8`````````4@````,`
M``!'````*0```$(```"S````PP```!8`````````%P````````"!````#@``
M``````!$`````````"$```#0`````````%P```!5````G@```)D`````````
MQ`````````!(````I0```&L```!\````O`````````![````>````,D```!Y
M````%`````````!U```````````````^````!0```!T````*````!P```)H`
M```3`````````,P```"-``````````````"O````B0``````````````J```
M`%$`````````Q@```#8````)````0```````````````5P```*H```"7````
M`````+$```!*````3P```$$````G````@````)T```"(````#````!4`````
M````<@```*<````D``````````````"L````B@```+D```!E````8@```)$`
M`````````````*8`````````I````&````#.````H0```"@`````````?0``
M`&D`````````HP```%0``````````````#T```!H````MP```&P```"B````
M:@``````````````;P````````"T````;@```%@`````````4````"L`````
M````K@`````````(````C`````L````[````N@```!(```"&````M@```#H`
M```J````4P```$L```!^````>@```#0```!M`````````&0````>````,@``
M`$4```!_````9@````````"R`````````,L````X`````````#<`````````
M=````*L```"3````OP```%D```!&````G````$X```"$````S0```((```!?
M````````````````````=P````````"2````!```````````````D````+4`
M```U````=@```&$```"M````&@````````"P`````````#````#*````GP``
M`$T```!:`````@```+X````C`````````(,```#"````3````%X```"X````
M+@``````````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N`"<E<R<@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`R-"!H;W5R<P`\8CY!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9#H\+V(^`$%-+U!-`$%C8V]U;G0@36%N86=E
M<@!!9&0@<&%I<@!!9&1R97-S`$%D9')E<W-B;V]K`$%L:6%S`$%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"X`079A:6QA8FQE(&9I96QD<SH`0FEN
M9"!T;R!S97)V97(@)7,Z)60@=VET:"!$3B`E<R!F86EL960Z(%LE9%T@)7,`
M0FER=&AD87D`0U93`$-A;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M96QL(%!H;VYE`$-H86YG92!Y;W5R('!A<W-W;W)D`$-H86YG:6YG(%!A<W-W
M;W)D(&]N("5S`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-L;W-E($AE;'``
M0VQO<V4@2&5L<"!7:6YD;W<`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]N9FER
M;2!N97<@<&%S<W=O<F0Z`$-O;G1E;G1S(&]F("<E<R<`0V]N=&5N=',@;V8@
M=&AE(%)!4B!A<F-H:79E`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1A=&%B87-E('%U97)Y(&9A:6QE9"X`
M1&5F875L="!)9&5N=&ET>0!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7-P
M;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'``16UA:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$5X<&5C=&5D(")"14=)3B(@:6X@=&AE(&QI;F4@)60N`$5X<&5C=&5D
M(")%3D0Z)7,B(&EN(&QI;F4@)60N`$9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+@!&86EL960@<F5T<FEE=FEN9R!P<F5F<R!F;W(@`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<')E9F5R96YC97,@<V5R=F5R+@!&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&]P96X@86X@
M3$1!4"!C;VYN96-T:6]N('1O("5S+@!&86EL960@=&\@<F5T<FEE=F4@=7-E
M<B=S($1..B!;)61=("5S`$9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@
M.B``1F%X`$9U;&P@1&5S8W)I<'1I;VXZ`$AE;'``2&]M92!!9&1R97-S`$AO
M;64@4&AO;F4`2&]R9&4`2&]R9&4@3&]G:6X`2&]R9&4@4WES=&5M`$AO<F1E
M(%=I<F5L97-S`$AO<F1E(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D`$EM
M<&]R=`!);7!O<G0@17)R;W(Z(`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T
M960@9FEE;&1S.@!,86YG=6%G90!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,
M;V<@;W5T`$QO9VEN(&9A:6QE9"!F;W(@<V]M92!R96%S;VXN($UO<W0@;&EK
M96QY('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC
M;W)R96-T;'DN`$QO9V]U=`!-30!-86EL`$UA<"!$871E(&%N9"!4:6UE($9I
M96QD<P!-87`@26UP;W)T($9I96QD<P!-871C:&EN9R!F:65L9',`365M;W,`
M365S<V%G90!-;VYT:&QY`$UY(%-U;6UA<GD`3F%M90!.979E<@!.97<@<&%S
M<W=O<F0Z`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!,1$%0(%!R969E<F5N8V5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,($-A=&5G;W)I97,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@4')E9F5R
M96YC97,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344P@875T:&5N=&EC871I;VXN`$YO('!R969E<F5N8V5S(&%R92!A
M=F%I;&%B;&4N`$YO('!R969E<F5N8V5S('=E<F4@<F5T<FEE=F5D+@!.;W1E
M<P!.;W1I9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+@!/;&0@<&%S
M<W=O<F0Z`$]P=&EO;G,`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&%S
M<W=O<F0@8VAA;F=E9"$`4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L
M>2!C;VYF:6=U<F5D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0
M:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R
M;V)L96T@1&5S8W)I<'1I;VX`4')O8FQE;3\`4F5B:6YD('1O('-E<G9E<B`E
M<SHE9"!W:71H($1.("5S(&9A:6QE9#H@6R5D72`E<P!2969E<G)A;"!T87)G
M970@)7,@9F]R($1.("5S(&ES(&YO="!I;B!T:&4@875T:&]R:7IE9"!S97)V
M97(@;&ES="$`4F5F<F5S:"!3=6UM87)Y(%9I97<Z`%)E;6]V92!P86ER`%)E
M<75I<F5D("=B87-E9&XG(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I
M;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V)A<V5D;B<@;F]T('-P96-I
M9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M9&%T86)A<V4G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D
M(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B
M87-E)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=H;W-T<W!E8R<@;F]T('-P96-I9FEE9"!I;B!A=71H
M96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G
M(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC
M97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E
M8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE
M9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP
M='EP92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!C
M871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N
M;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO
M;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B;&4G(&YO="!S<&5C:69I
M960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B
M;&4G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W1A8FQE4F5L871I;VYS)R!N;W0@<W!E8VEF:65D(&EN
M(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5I9"<@;F]T
M('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G=6ED)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE
M9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@
M<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5S970`4F5T=7)N('1O($]P
M=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H92!C:&%R86-T97)S
M('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@
M8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT87)E82X`4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`
M4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0
M<F]B;&5M(%)E<&]R=`!3970@<F5B:6YD('!R;V,@9F%I;&5D.B!;)61=("5S
M`%-E="!T:&4@;&%N9W5A9V4@=&AA="!M96YU(&ET96US+"!E>'!L86YA=&EO
M;G,L(&%N9"!H96QP(&%R92!I;BX`4V5T('EO=7(@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3970@>6]U<B!P<F5F97)R
M960@9&ES<&QA>2!L86YG=6%G92X`4VAO<G0@4W5M;6%R>3H`4VMI<"!-86EN
M=&5N86YC90!3;VUE(&]F($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A
M<F4@;6ES<VEN9SH`4V]M92!O9B!087-S=V]R9"!M;V1U;&4G<R!C;VYF:6=U
M<F%T:6]N(&9I;&5S(&%R92!M:7-S:6YG.@!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3=6-C97-S`%1A<VMS`%1H92!R96=I<W1R>2!I<R!H;W<@2&]R9&4@
M87!P;&EC871I;VYS(&9I;F0@;W5T(&AO=R!T;R!T86QK('1O(&5A8V@@;W1H
M97(N(%EO=2!S:&]U;&0@;&ES="!A;GD@:6YS=&%L;&5D($AO<F1E(&%P<&QI
M8V%T:6]N<R!T:&%T('EO=2!H879E(&AE<F4N`%1H:7,@9FEL92!C;VYT<F]L
M<R!T:&4@9&5F875L="!P<F5F97)E;F-E<R!F;W(@4&%S<W=O<F0@;6]D=6QE
M+"!A;F0@86QS;R!C;VYT<F]L<R!W:&EC:"!P<F5F97)E;F-E<R!U<V5R<R!C
M86X@86QT97(N`%1H:7,@9FEL92!C;VYT<F]L<R!T:&4@9VQO8F%L('-E="!O
M9B!-24U%(&1R:79E<G,@9F]R('1H92!(;W)D92!F<F%M97=O<FLL(&%L;&]W
M:6YG(&%P<&QI8V%T:6]N<R!T;R!M86ME('5S92!O9B!P<F]G<F%M<R!S=6-H
M(&%S(&5N<V-R:7!T(&]R(&US=V]R9'9I97<@=&\@<F5N9&5R(&-O;G1E;G0@
M:6YT;R!(5$U,(&9O<B!V:65W:6YG(&EN(&$@8G)O=W-E<BX`5&AI<R!F:6QE
M(&-O;G1R;VQS('1H92!S='EL97-H965T('1H870@:7,@=7-E9"!T;R!S970@
M8V]L;W)S(&%N9"!F;VYT<R!F;W(@=&AE($AO<F1E(&9R86UE=V]R:R!A;F0@
M86QL(&%P<&QI8V%T:6]N<R!T:&%T(&1O(&YO="!P<F]V:61E('1H96ER(&]W
M;B!S971T:6YG<RX`5&AI<R!F:6QE(&-O;G1R;VQS('1H92!S='EL97-H965T
M('1H870@:7,@=7-E9"!T;R!S970@8V]L;W)S(&%N9"!F;VYT<R!I;B!A9&1I
M=&EO;B!T;R!O<B!O=F5R<FED:6YG($AO<F1E(&1E9F%U;'1S+@!4:&ES(&9I
M;&4@;6%P<R!F:6QE(&5X=&5N<VEO;G,@=&\@;&]G:6-A;"!-24U%('1Y<&5S
M+"!E;F%B;&EN9R!(;W)D92!A<'!L:6-A=&EO;G,@=&\@9FEG=7)E(&]U="!H
M;W<@=&\@:&%N9&QE('-O;64@8V]N=&5N="!S=6-H(&%S(&5M86EL(&%T=&%C
M:&UE;G1S(&]R($-64R!C:&5C:V]U=',N`%1H:7,@:7,@=&AE(&UA:6X@2&]R
M9&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P871H<R!A;F0@
M8F%S:6,@:71E;7,@=&AA="!A<'!L>2!T;R!T:&4@8V]R92!F<F%M97=O<FL@
M86YD(&%L;"!(;W)D92!A<'!L:6-A=&EO;G,N`%1H:7,@:7,@=&AE(&UA:6X@
M4&%S<W=O<F0@;6]D=6QE(&-O;F9I9W5R871I;VX@9FEL92X@270@8V]N=&%I
M;G,@<&%T:',@86YD(&]P=&EO;G,@9F]R(&%L;"!087-S=V]R9"!M;V1U;&4@
M<V-R:7!T<RX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET;&4`5'EP92!M:7-M871C
M:"X`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!M;V1I9GD@<')E9F5R96YC97,Z(%LE9%T@)7,`56YA8FQE('1O(')E
M9VES=&5R('!R969E<F5N8V5S(&EN('-E<W-I;VXN`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F5X<&5C
M=&5D(&5N9"!O9B!F:6QE+@!5<V4@1&5F875L="!686QU90!5<V5R($]P=&EO
M;G,`57-E<FYA;64`57-E<FYA;64Z`%=A<FYI;F<`5V%R;FEN9R$`5V5E:VQY
M`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`65D`665A<FQY`%EO=2!C86X@;F]T(&-H86YG92!P87-S=V0@9F]R
M(&]T:&5R('5S97(`66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E
M<B`E<P!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N/&)R("\^5&AA;FL@>6]U
M(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9`!9;W4@;75S="!G
M:79E('EO=7(@;VQD('!A<W-W;W)D`%EO=2!M=7-T(&=I=F4@>6]U<B!U<V5R
M:60`66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($5M86EL($%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!.86UE.@!9
M;W5R(&YE=R!P87-S=V]R9',@9&ED;B=T(&UA=&-H`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O
M9B`E<UT`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!P87-S=V0*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#(M,#(M,C@@,#`Z,30M,#8P,`I03RU2979I<VEO
M;BU$871E.B`R,#`S+3`X+3$Y(#$R.C0R1TU4*S$*3&%S="U4<F%N<VQA=&]R
M.B!G=6EL;&4@/&=U:6QL94!U<V,N97,^"DQA;F=U86=E+51E86TZ($=A;&5G
M;PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET"E@M1V5N97)A=&]R.B!+0F%B96P@,"XY+C4*`$]P97)A8VGS;G,@
M9&4@;6%N=&5M96YT;R`E<R`M($-O;F9I<FUA8VGS;@`E<R!E<W3A(&$@<&EQ
M=65S(&1E(&5F96-T=6%R(&%S(&]P97)A8VGS;G,@9&4@;6%N=&5M96YT;R!M
M87)C861A<R!A8F%I>&\N`"<E<R<@;F]N(&5S=.$@8V]N9FEG=7)A9&\@;F\@
M<F5X:7-T<F\@9&4@2&]R9&4N`#(T(&AO<F%S`#QB/E!R;V1U8VEU<V4@=6X@
M97)R;R!G<F%V93H@/"]B/@!!32]030!897-T;W(@9&$@8V]N=&$`16YG861I
M<B!U;B!P87(`16YD97)E>F\`07AE;F1A(&1E(&5N9&5R97IO<P!!;&-U;64`
M3R!V86QO<B!Q=64@97-P96-I9FEC;W4@;F]N(.D@=N%L:61O`$-A;7!O<R!D
M:7-P;_%I8FQE<SH`1F%L;&]U(&$@87-O8VEA8VGS;B!C;R!S97)V:61O<B`E
M<SHE9"!U<V%N9&\@;R!$3B`E<R!F86QL;W4Z(%LE9%T@)7,`06YI=F5R<V%R
M:6\`0U93`$-A;&5N9&%R:6\`0V%N8V5L87(@;R!I;F9O<FUE(&1E('!R;V)L
M96UA<P!496SI9F]N;R!M\V)I;`!#86UB:64@82!S^F$@8VAA=F4@9&4@86-C
M97-O`$-A;6)I86YD;R!A(&-H879E(&1E(&%C8V5S;R!E;B`E<P!-87)Q=64@
M;F$@8W5A9'+M8W5L82!A(&]P97)A8VGS;B!O=2!O<&5R86-I\VYS('%U92!D
M97-E>&$@97AE8W5T87(@86=O<F$N`%!E8VAA<B!A($%X=61A`%!E8VAA<B!A
M('AA;F5L82!D82!!>'5D80!096-H87(@82!X86YE;&$`0V]M<&'Q[6$`0V]N
M9FER;64@;R!N;W9A(&-H879E(&1E(&%C8V5S;P!#;VYT:61O(&1E("<E<R<`
M0V]N=&ED;R!D;R!A<G%U:79O(%)!4@!&86QL;R#S(&%B<FER(&\@;?-D=6QO
M(&1E('1A<F5F87,@9&4@;6%N=&5M96YT;R`E<P!$1`!$:6%R:6%M96YT90!&
M86QL;W4@8V]N<W5L=&$@X2!B87-E(&1E(&1A=&]S+@!)9&5N=&ED861E('!R
M961E=&5R;6EN861A`$1E<V-R:6-I\VX@9&\@<')O8FQE;6$`4F5X:7-T<N%R
M;VYS92!O<R!D971A;&QE<R!P87)A(&\@861M:6YI<W1R861O<BX`3W!C:?-N
M<R!D92!V:7-U86QI>F%C:?-N`$YO;B!A8V-E9&$@9&ER96-T86UE;G1E(&$@
M(FUA:6YT96YA;F-E+G!H<"(`0V]R<F5O(&5L96-T<O-N:6-O`%-E;B!R97-U
M;'1A9&\N`$5R<F\`0V%D82`Q-2!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`
M0V%D82`U(&UI;G5T;W,`0V%D82!I;FEC:6\@9&4@<V5S:?-N`$-A9&$@;65D
M:6$@:&]R80!#861A(&UI;G5T;P!%>&5M<&QO(&1E('9A;&]R97,Z`$5S<&5R
MX6)A<V4@(D)%1TE.(B!N82!L:?%A("5D+@!%<W!E<N%B87-E(")%3D0Z)7,B
M(&YA(&QI\6$@)60N`$9A;&QO=2#S(')E8W5P97)A<B!A<R!P<F5F97)E;F-I
M87,N`$9A;&QO=2#S(')E8W5P97)A<B!A<R!P<F5F97)E;F-I87,@<&%R82``
M1F%L;&]U(/,@:6YT96YT87(@8V]N96-T87(@8V\@<V5R=FED;W(@9&4@<')E
M9F5R96YC:6%S($Q$05`N`$9A;&QO=2#S(&-O;F5C=&%R(&-O('-E<G9I9&]R
M($Q$05`N`$9A;&QO=2#S(&%B<FER(&$@8V]N97AI\VX@3$1!4"!A("5S+@!&
M86QL;W4@\R!R96-U<&5R87(@;R!$3B!D;R!U<W5A<FEO.B!;)61=("5S`$9A
M;&QO=2!O(&-A;6)I;R!D92!C:&%V92!D92!A8V-E<V\`1F%X`$1E<V-R:6-I
M\VX@8V]M<&QE=&$Z`$%X=61A`$5N9&5R97IO('!A<G1I8W5L87(`5&5LZ69O
M;F\@<&%R=&EC=6QA<@!(;W)D90!686QI9&%C:?-N(&5N($AO<F1E`%-I<W1E
M;6$@2&]R9&4`2&]R9&4@<V5N(&;M;W,`2&]R9&4@;F]N('-E(&-O;F9I9W5R
M;W4@8V]R<F5C=&%M96YT90!);7!O<G1A<@!%<G)O(&1E(&EM<&]R=&%C:?-N
M.B``0V%M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@:6UP;W)T861O<SH`3&EN
M9W5A`$QI<W1A<B!O<R!T96UA<R!D92!A>'5D80!%;G1R87(`4&5C:&%R(&$@
M<V5S:?-N`%!O<B!A;&=U;FAA(')A>O-N(&YO;B!S92!D974@:6YI8VEA9&\@
M82!S97-I\VXN(%!R;V)A8FQE;65N=&4@97-C<FEB:74@:6YC;W)R96-T86UE
M;G1E(&\@;F]M92!D92!U<W5A<FEO(&]U(&$@8VAA=F4@9&4@86-C97-O+@!&
M:6YA;&EZ87(@82!S97-I\VX`34T`0V]R<F5O`$%S:6=N87(@8V%M<&]S(&1E
M(&1A=&$@92!H;W)A`$%S:6=N87(@8V%M<&]S('!A<F$@:6UP;W)T87(`0V%M
M<&]S(&-O<G)E<W!O;F1E;G1E<P!-96UO<F%N9&]S`$UE;G-A>&4`365N<W5A
M;&UE;G1E`%)E<W5M;P!.;VUE`$YU;F-A`$-H879E(&1E(&%C8V5S;R!N;W9A
M.@!.;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@87,@<')E
M9F5R96YC:6%S($Q$05`N`$YO;B!E<W!E8VEF:6-O=2!A(&-O;F9I9W5R86-I
M\VX@<&%R82!A<R!C871E9V]R[6%S(%-13"X`3F]N(&5S<&5C:69I8V]U(&$@
M8V]N9FEG=7)A8VGS;B!P87)A(&%S('!R969E<F5N8VEA<R!344PN`$YO;B!E
M<W!E8VEF:6-O=2!A(&-O;F9I9W5R86-I\VX@<&%R82!A(&%U=&5N=&EF:6-A
M8VGS;B!P;W(@4U%,+@!.;VX@:&%I('!R969E<F5N8VEA<R!D:7-P;_%I8FQE
M<RX`3F]N('-E(')E8W5P97)O=2!N:6YG=6YH82!D87,@<')E9F5R96YC:6%S
M+@!.;W1A<P!.;VX@<V4@871O<&]U(&\@87AE;G1E(&1E(&YO=&EF:6-A8VGS
M;B`E<RX`0VAA=F4@9&4@86-C97-O(&%N=&5R:6]R.@!/<&-I\VYS`$]U=')A
M(&EN9F]R;6%C:?-N`$-H879E(&1E(&%C8V5S;P"A0VAA=F4@9&4@86-C97-O
M(&-A;6)I861A(0!/(&WS9'5L;R!P87)A(&-A;6)I87(@82!C:&%V92!D92!A
M8V-E<V\@;F]N('-E(&-O;F9I9W5R;W4`4F5A;&EZ87(@;W!E<F%C:?-N<R!D
M92!M86YT96UE;G1O`%1E;.EF;VYO`$%C:&5G=64@=6X@<F5S=6UO(&1O('!R
M;V)L96UA+@!!8VAE9W5E(&\@<V5U(&YO;64@9&4@=7-U87)I;R!E(&-H879E
M(&1E(&%C8V5S;P!$97-C<FEC:?-N(&1O('!R;V)L96UA`+]0<F]B;&5M87,_
M`$$@=&5N=&%T:79A(&1E(&%S;V-I87(@;R!S97)V:61O<B`E<SHE9"!C;VX@
M1$X@)7,@9F%L;&]U.B!;)61=("5S`*%/('-E<G9I9&]R('!A<F$@82!R969E
M<F5N8VEA("5S('!A<F$@;R!$3B`E<R!N;VX@97-TX2!D969I;FED;R!N82!L
M:7-T82!D92!S97)V:61O<F5S(&%U=&]R:7IA9&]S(0!!8W1U86QI>F%R(&$@
M=FES=&$@9&\@<F5S=6UO.@!386-A<B!O('!A<@!/(&-A;7!O(')E<75I<FED
M;R`G8F%S961N)R!N;VX@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F%C
M:?-N(&1E(&%U=&5N=&EF:6-A8VGS;BX`3R!C86UP;R!R97%U:7)I9&\@)V)A
M<V5D;B<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A8VGS;B!D
M87,@<')E9F5R96YC:6%S+@!/(&-A;7!O(')E<75I<FED;R`G9&%T86)A<V4G
M(&YO;B!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R86-I\VX@9&4@875T
M96YT:69I8V%C:?-N+@!/(&-A;7!O(')E<75I<FED;R`G9&%T86)A<V4G(&YO
M;B!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R86-I\VX@9&%S(&-A=&5G
M;W+M87,N`$\@8V%M<&\@<F5Q=6ER:61O("=D871A8F%S92<@;F]N(&9O:2!E
M<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A8VGS;B!D82!P<F5F97)E;F-I87,N
M`$\@8V%M<&\@<F5Q=6ER:61O("=H;W-T<W!E8R<@;F]N(&9O:2!E<W!E8VEF
M:6-A9&\@;F$@8V]N9FEG=7)A8VGS;B!D82!A=71E;G1I9FEC86-I\VXN`$\@
M8V%M<&\@<F5Q=6ER:61O("=H;W-T<W!E8R<@;F]N(&9O:2!E<W!E8VEF:6-A
M9&\@;F$@8V]N9FEG=7)A8VGS;B!D87,@8V%T96=O<NUA<RX`3R!C86UP;R!R
M97%U:7)I9&\@)VAO<W1S<&5C)R!N;VX@9F]I(&5S<&5C:69I8V%D;R!N82!C
M;VYF:6=U<F%C:?-N(&1A<R!P<F5F97)E;F-I87,N`$\@8V%M<&\@<F5Q=6ER
M:61O("=P87-S=V]R9"<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG
M=7)A8VGS;B!D92!A=71E;G1I9FEC86-I\VXN`$\@8V%M<&\@<F5Q=6ER:61O
M("=P87-S=V]R9"<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A
M8VGS;B!D87,@8V%T96=O<NUA<RX`3R!C86UP;R!R97%U:7)I9&\@)W!A<W-W
M;W)D)R!N;VX@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F%C:?-N(&1A
M<R!P<F5F97)E;F-I87,N`$\@8V%M<&\@<F5Q=6ER:61O("=P:'!T>7!E)R!N
M;VX@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F%C:?-N(&1E(&%U=&5N
M=&EF:6-A8VGS;BX`3R!C86UP;R!R97%U:7)I9&\@)W!H<'1Y<&4G(&YO;B!F
M;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R86-I\VX@9&%S(&-A=&5G;W+M
M87,N`$\@8V%M<&\@<F5Q=6ER:61O("=P:'!T>7!E)R!N;VX@9F]I(&5S<&5C
M:69I8V%D;R!N82!C;VYF:6=U<F%C:?-N(&1A<R!P<F5F97)E;F-I87,N`$\@
M8V%M<&\@<F5Q=6ER:61O("=T86)L92<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@
M;F$@8V]N9FEG=7)A8VGS;B!D92!A=71E;G1I9FEC86-I\VXN`$\@8V%M<&\@
M<F5Q=6ER:61O("=T86)L92<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N
M9FEG=7)A8VGS;B!D87,@8V%T96=O<NUA<RX`3R!C86UP;R!R97%U:7)I9&\@
M)W1A8FQE)R!N;VX@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F%C:?-N
M(&1A<R!P<F5F97)E;F-I87,N`$\@8V%M<&\@<F5Q=6ER:61O("=T86)L95)E
M;&%T:6]N<R<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A8VGS
M;B!D87,@8V%T96=O<NUA<RX`3R!C86UP;R!R97%U:7)I9&\@)W5I9"<@;F]N
M(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A8VGS;B!D82!A=71E;G1I
M9FEC86-I\VXN`$\@8V%M<&\@<F5Q=6ER:61O("=U:60G(&YO;B!F;VD@97-P
M96-I9FEC861O(&YA(&-O;F9I9W5R86-I\VX@9&%S('!R969E<F5N8VEA<RX`
M3R!C86UP;R!R97%U:7)I9&\@)W5S97)N86UE)R!N;VX@9F]I(&5S<&5C:69I
M8V%D;R!N82!C;VYF:6=U<F%C:?-N(&1E(&%U=&5N=&EF:6-A8VGS;BX`3R!C
M86UP;R!R97%U:7)I9&\@)W5S97)N86UE)R!N;VX@9F]I(&5S<&5C:69I8V%D
M;R!N82!C;VYF:6=U<F%C:?-N(&1A<R!C871E9V]R[6%S+@!/(&-A;7!O(')E
M<75I<FED;R`G=7-E<FYA;64G(&YO;B!F;VD@97-P96-I9FEC861O(&YA(&-O
M;F9I9W5R86-I\VX@9&%S('!R969E<F5N8VEA<RX`4F5I;FEC:6%R`%)E9W)E
M<V%R(.%S(&]P8VGS;G,`1G5N8VGS;@!'87)D87(@87,@;W!C:?-N<P!396QE
M8V-I;VYE(&]S(&-A<F%C=&5R97,@<75E(&YE8V5S:71E(&1A<R!C=6%D<NUC
M=6QA<R!Q=64@871O<&%RX2!M86ES(&%B86EX;RX@4&]D92!C;W!I86QO<R!E
M('!E9V%L;W,@9&5N9&4@82#A<F5A(&1E('1E>'1O+@!396QE8V-I;VYE(&\@
M9&5L:6UI=&%D;W(@9&$@9&%T83H`4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@
M9&%T83H`4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@:&]R83H`4V5L96-C:6]N
M92!D;W5S(&-A;7!O<R!Q=64@8V]I;F-I9&%N+@!396QE8V-I;VYE(&$@;&EN
M9W5A.@!%;G9I87(@;R!I;F9O<FUE(&1E('!R;V)L96UA<P!&86QL;W4@\R!E
M<W1A8FQE8V5R(&\@<')O8V5D96UE;G1O(&1E(')E87-O8VEA8VGS;B`H<F5B
M:6YD*3H@6R5D72`E<P!%<W1A8FQE8V4@82!L:6YG=6$@9&]S(&UE;OIS+"!D
M87,@97AP;&EC86-I\VYS(&4@9&$@87AU9&$N`$5S=&%B;&5C92!A(&9R96-U
M96YC:6$@9&4@86-T=6%L:7IA8VGS;B!D87,@<.%X:6YA<R!E(&]U=')A<R!O
M<&-I\VYS(&1E('9I<W5A;&EZ86-I\VXN`$5S=&%B;&5C92!A(&QI;F=U82!D
M92!V:7-U86QI>F%C:?-N+@!297-U;6\@8G)E=F4Z`$]M:71I<B!O(&UA;G1E
M;65N=&\`1F%L=&%N(&%L9_IN<R!A<G%U:79O<R!D92!C;VYF:6=U<F%C:?-N
M(&1E($AO<F1E.@!!;&?Z;G,@9&]S(&%R<75I=F]S(&1E(&-O;F9I9W5R86-I
M\VX@9&\@;?-D=6QO('!A<F$@8V%M8FEA<B!A(&-H879E(&YO;B!S92!D86X@
M871O<&%D;SH`16YT<F%D82!D92!C87)A8W1E<F5S(&5S<&5C:6%I<P!#;W)R
M96-T86UE;G1E`%1A<F5F87,`3R!R97AI<W1R;R!D971E<FUI;F$@8_-M;R!S
M92!C;VUU;FEC86X@87,@87!L:6-A8VGS;G,@9&4@2&]R9&4@96YT<F4@96QA
M<RX@26YC;/IA(&%Q=>T@=/-D86QA<R!A<&QI8V%C:?-N<R!D92!(;W)D92!Q
M=64@9&5S97AE('5S87(N`$5S=&4@87)Q=6EV;R!C;VYT<F]L82!A<R!P<F5F
M97)E;F-I87,@<')E9&5T97)M:6YA9&%S(&1O(&WS9'5L;R!P87)A(&-A;6)I
M87(@82!C:&%V964@861E;6%I<R!C;VYT<F]L82!Q=64@<')E9F5R96YC:6%S
M('!O9&4@;75D87(@;R!U<W5A<FEO+@!%<W1E(&%R<75I=F\@8V]N=')O;&$@
M;R!C;VYX=6YT;R!G;&]B86P@9&4@8V]N=')O;&%D;W)E<R!-24U%('!A<F$@
M82!F97)R86UE;G1A($AO<F1E+"!P97)M:71I;F1O(.%S(&%P;&EC86-I\VYS
M(&9A8V5R('5S;R!D92!P<F]G<F%M87,@=&%L97,@8V]M;R!E;G-C<FEP="!O
M=2!M<W=O<F1V:65W+"!Q=64@=')A9'5C96X@;R!C;VYT:61O(&$@2%1-3"!P
M87)A('!O9&5R('9I<W5A;&EZ86QO(&YU;B!N879E9V%D;W(N`$5S=&4@87)Q
M=6EV;R!C;VYT<F]L82!A(&9O;&QA(&1E(&5S=&EL;R!Q=64@<V4@=7-A('!A
M<F$@97-T86)L96-E<B!A<R!C;W)E<R!E('1I<&]S(&1E(&QE=')A('!A<F$@
M82!F97)R86UE;G1E($AO<F1E(&4@=/-D86QA<R!A<&QI8V%C:?-N<R!Q=64@
M;F]N('-U8FUI;FES=')E;B!A<R!S^F%S('!R;W!I87,@8V]N9FEG=7)A8VGS
M;G,N`$5S=&4@87)Q=6EV;R!C;VYT<F]L82!A<R!F;VQL87,@9&4@97-T:6QO
M('%U92!S92!U<V%N('!A<F$@97-T86)L96-E<B!A<R!C;W)E<R!E('1I<&]S
M(&1E(&QE=')A+"!E(&-O;7!L96UE;G1E;G1A(&]U('-U8G-T:73Z92!O<R!V
M86QO<F5S('!R961E=&5R;6EN861O<R!D92!(;W)D92X`17-T92!A<G%U:79O
M(&%S;V-I82!A<R!E>'1E;G-I\VYS(&1E(&%R<75I=F\@82!T:7!O<R!-24U%
M(&SS>&EC;W,L('!E<FUI=&EN9&\@X7,@87!L:6-A8VGS;G,@2&]R9&4@8V]M
M<')E;F1E<B!C\VUO(&UA;F5X87(@8V5R=&]S(&-O;G1I9&]S('1A;"!C;VUO
M(&%R<75I=F]S(&%N97AO<R!N;R!C;W)R96\@;W4@:6YS<&5C8VGS;G,@;G5N
M($-64RX`17-T92#I(&\@87)Q=6EV;R!P<FEN8VEP86P@9&4@8V]N9FEG=7)A
M8VGS;B!D92!(;W)D92X@0V]N=.EN(&%S(')U=&%S(&$@87)Q=6EV;W,@92!E
M;&5M96YT;W,@8N%S:6-O<R!Q=64@;&QE(&%P;&EC86X@\R!N^F-L96\@9&$@
M9F5R<F%M96YT82!E(&$@=/-D86QA<R!A<&QI8V%C:?-N<R!D92!(;W)D92X`
M17-T92#I(&\@87)Q=6EV;R!P<FEN8VEP86P@9&4@8V]N9FEG=7)A8VGS;B!D
M;R!M\V1U;&\@<&%R82!C86UB:6%R(&$@8VAA=F4@9&4@86-C97-O+B!#;VYT
MZ6X@87,@<G5T87,@92!O<&-I\VYS('!A<F$@=/-D;VQO<R!P<F]G<F%M87,@
M*&1E<W1E(&WS9'5L;RDN`$\@;OIM97)O(&1E8F4@<V5R('!O;&\@;65N;W,@
M=6X@,2X`3R!V86QO<B!D96)E('-E<B!U;B!N^FUE<F\N`%3M='5L;P!/('1I
M<&\@;F]N(&-O:6YC:61E+@!54DP`3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R
M<V4@\R!S97)V:61O<B!344PN`$YO;B!F;VD@<&]S:6)L92!M;V1I9FEC87(@
M87,@<')E9F5R96YC:6%S.B!;)61=("5S`$YO;B!F;VD@<&]S:6)L92!R97AI
M<W1R87(@87,@<')E9F5R96YC:6%S(&YA('-E<VGS;BX`3F]N(&9O:2!P;W-I
M8FQE('1R861U8VER(&5S=&4@9&]C=6UE;G1O(&1E(%=O<F0`1&5S9F%C97(@
M;W,@8V%M8FEO<P!&:6YA;"!D92!A<G%U:79O(&EN97-P97)A9&\N`%5S87(@
M;R!V86QO<B!P;W(@9&5F96-T;P!/<&-I\VYS(&1O('5S=6%R:6\`57-U87)I
M;P!5<W5A<FEO.@!!9'9E<G1E;F-I80"A079I<V\A`%-E;6%N86QM96YT90!"
M96YV:61A(&$@)7,`0F5N=FED;R]A+"`E<P!%;F1E<F5Z;R!D;R!T<F%B86QL
M;P!496SI9F]N;R!D;R!T<F%B86QL;P!!00!!;G5A;&UE;G1E`$YO;B!P;V1E
M(&UU9&%R(&$@8VAA=F4@9&4@86-C97-O(&1O=71R;R!U<W5A<FEO`$YO;B!P
M;V1E(&-A;6)I87(@82!C:&%V92!D92!A8V-E<V\@9&\@=7-U87)I;R`E<P!&
M:6YA;&EZ;W4@82!S97-I\VXN/&)R("\^1W)A8VEA<R!P;W(@=7-A<B!O('-I
M<W1E;6$N`$1E<V-R:6)A(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@
M:6YF;W)M92X`17-C<FEB82!A(&YO=F$@8VAA=F4@9&4@86-C97-O`$5S8W)I
M8F$@82!C:&%V92!D92!A8V-E<V\@86YT97)I;W(`17-C<FEB82!O('-E=2!N
M;VUE(&1E('5S=6%R:6\`4F5P:71A(&$@;F]V82!C:&%V92!D92!A8V-E<V\`
M0V%D=6-O=2!A('/Z82!S97-I\VX@96X@)7,@97AP:7)O=2X@26YI8VEE('5N
M:&$@;F]V82!S97-I\VXN`$5N9&5R97IO(&1E(&-O<G)E;R!E;&5C='+S;FEC
M;SH`02!S^F$@:6YF;W)M86-I\VX`3F]M93H`07,@;F]V87,@8VAA=F5S(&1E
M(&%C8V5S;R!S;VX@9&EF97)E;G1E<P!!8W1U86QI>N%R;VYS92!A<R!S^F%S
M(&]P8VGS;G,N`%M);F9O<FUE(&1O(%!R;V)L96UA70!;;&GQ82`E<R!D92`E
M<UT`5&%R>&5T82!D92!V:7-I=&$@*'9#87)D*0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O:61?240O````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#,`
M,#(P,3,S`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]I
M9%])1"],0U]-15-304=%4R\`````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<T-``P,C$W,C$`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P87-S=V0O;&]C86QE+VED7TE$+TQ#7TU%4U-!1T53+W!A<W-W9"YM;P``
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,C`S-#,P`#$P-#$W,S8R-S0T`#`R,S4U-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`+X#```<````#!X``/T$``#\.P```````/!/```$````\4\``"0```#V3P``
M*0```!M0```9````15```"8```!?4```#````(90```D````DU````\```"X
M4```"P```,A0```H````U%````@```#]4```%0````91```+````'%$``(4`
M```H40``"@```*Y1```.````N5$```D```#(40``#P```-)1```8````XE$`
M``X```#[40``#@````I2```(````&5(``"X````B4@``"0```%%2```-````
M6U(```<```!I4@``"@```'%2```/````?%(```4```",4@``$0```))2```(
M````I%(```D```"M4@``"0```+=2```3````P5(``!````#54@``"@```.92
M```#````\5(```\```#U4@``"0````53```-````#U,``!D````=4P``#P``
M`#=3```/````1U,```@```!74P``)````&!3```(````A5,``$X```".4P``
M+0```-U3```9````"U0```P````E5```#@```#)4```#````050```4```!%
M5```"@```$M4```#````5E0``!<```!:5```"@```')4```.````?50``",`
M``",5```%````+!4```7````Q50``!<```#=5```%P```/54```3````#54`
M``\````A50``!@```#%5```+````.%4``!````!$50``%0```%55```5````
M:U4```<```"!50``!0```(E5```5````CU4``#L```"E50``.````.%5```4
M````&E8```,````O5@``"0```#-6```Y````/58``"<```!W5@``+````)]6
M```J````S%8``"4```#W5@``!@```!U7```1````)%<```P````V5P``(@``
M`$-7```*````9E<``!````!Q5P``%````()7```G````EU<```@```"_5P``
M#@```,A7```*````UU<```0```#B5P``"0```.=7```&````\5<``!$```#X
M5P``!P````I8```$````$E@```8````76```#0```!Y8```#````+%@``!,`
M```P6```"````$18```$````35@``$$```!26```!@```)18```5````FU@`
M``<```"Q6```%0```+E8```/````SU@```T```#?6```#P```.U8```-````
M_5@``!0````+60``!@```"!9```=````)UD```8```!%60``#P```$Q9```4
M````7%D``!<```!Q60``5````(E9```4````WED``!<```#S60``9`````M:
M```$````<%H```X```!U6@``&P```(1:```:````H%H``!P```"[6@``*@``
M`-A:```%`````UL``!,````)6P``$@```!U;```*````,%L```\````[6P``
M#0```$M;```1````65L```P```!K6P``!@```'A;```,````?UL```8```",
M6P``$````)-;```1````I%L```4```"V6P``#````+Q;```%````R5L```8`
M``#/6P``!P```-9;```-````WEL```D```#L6P``"0```/9;```*`````%P`
M`!D````+7```'0```"5<```,````0UP``!````!07```%0```&%<```(````
M=UP```@```"`7```!@```(E<```$````D%P```X```"57```'0```*1<```@
M````PEP``"X```#C7```*P```!)=```A````/ET``*(```!@70``'P````->
M```@````(UX``"8```!$7@``*0```&M>```M````E5X``#````##7@``D@``
M`/1>```J````AU\``$$```"R7P``!P```/1?```&````_%\```T````#8```
M$````!%@```-````(F````P````P8```#@```#U@```/````3&```!,```!<
M8```#0```'!@```H````?F````,```"G8```#0```*M@```1````N6```!<`
M``#+8```&P```.-@```"````_V```!`````"80``#0```!-A```#````(6$`
M``X````E80``"````#1A```/````/6$```\```!-80``!P```%UA```-````
M96$```T```!S80``"P```(%A```&````C6$```L```"480``#````*!A```+
M````K6$```T```"Y80``(@```,=A```*````ZF$``!@```#U80``&0````YB
M```6````*&(``"(````_8@``%````&)B```+````=V(```L```"#8@``"0``
M`(]B```9````F6(```L```"S8@``%P```+]B```7````UV(```D```#O8@``
M%@```/EB```/````$&,``!D````@8P``%@```#IC```F````46,``$,```!X
M8P``'P```+QC```O````W&,```4````,9```!````!)D```*````%V0```H`
M```B9```$````"UD```7````/F0``!$```!69```%P```&AD```)````@&0`
M``H```"*9````@```)5D```-````F&0``#@```"F9```(````-]D```.````
M`&4``'L````/90``&````(ME```%````I&4``"````"J90``&P```,ME```&
M````YV4``!````#N90``#P```/]E```0````#V8```\````@9@``#P```#!F
M```,````0&8```\```!-9@``!P```%UF```.````968```@```!T9@``$P``
M`'UF```?````D68```0```"Q9@``!0```+9F```(````O&8```H```#%9@``
M#````-!F```+````W68``!````#I9@``#````/IF```'````!V<```H````/
M9P``#0```!IG```%````*&<```,````N9P``"@```#)G```$````/6<``"8`
M``!"9P``#@```&EG``!\````>&<``!4```#U9P``!0````MH```'````$6@`
M``P````9:```"````"9H```*````+V@```8````Z:```"````$%H```"````
M2F@```8```!-:```"0```%1H```0````7F@```D```!O:```"0```'EH```:
M````@V@```@```">:```&0```*=H```.````P6@```(```#0:```!@```--H
M```-````VF@``!(```#H:```%````/MH```&````$&D``!$````7:0``"0``
M`"EI```Y````,VD``#T```!M:0``.@```*MI```$````YFD``!4```#K:0``
M!@````%J```$````"&H``!$````-:@``"@```!]J```B````*FH```0```!-
M:@``!0```%)J```.````6&H```4```!G:@``#P```&UJ```2````?6H```L`
M``"0:@``)@```)QJ```I````PVH``"0```#M:@``)@```!)K```(````.6L`
M``H```!":P``"0```$UK```2````5VL```H```!J:P``#````'5K```/````
M@FL``!````"2:P``<````*-K```.````%&P```D````C;```"@```"UL```2
M````.&P``!,```!+;```!@```%]L```/````9FP``!(```!V;```$````(EL
M```1````FFP``!$```"L;```:@```+YL```/````*6T``!`````Y;0``"P``
M`$IM```@````5FT``!0```!W;0``#````(QM```,````F6T```\```"F;0``
M%0```+9M```I````S&T``"H```#V;0``)@```"%N```G````2&X``"D```!P
M;@``*@```)IN```9````Q6X``$(```#?;@``$0```")O```2````-&\``!,`
M``!';P``%````%MO```6````<&\``!<```"';P``$````)]O```1````L&\`
M`#0```#";P``$P```/=O```2````"W```!0````><```&@```#-P```)````
M3G```!$```!8<```!@```&IP```'````<7```!8```!Y<```!````)!P```$
M````E7````<```":<```#@```*)P```,````L7````P```"^<```#0```,MP
M```.````V7````0```#H<```#P```.UP```'````_7````@````%<0``"0``
M``YQ```4````&'$```P````M<0``#0```#IQ```#````2'$```8```!,<0``
M&0```%-Q```$````;7$```T```!R<0``"@```(!Q```0````BW$```\```"<
M<0``$0```*QQ```7````OG$```H```#6<0``$0```.%Q```(````\W$```\`
M``#\<0``#`````QR```.````&7(``!`````H<@``"P```#ER```:````17(`
M``H```!@<@``#````&MR```/````>'(```@```"(<@``!@```)%R```'````
MF'(```4```"@<@``"P```*9R```&````LG(```0```"Y<@```P```+YR```3
M````PG(``!,```#6<@``$P```.IR```"````_G(```0````!<P``!0````9S
M```$````#',```H````1<P``#0```!QS``!H````*G,```4```"3<P``!@``
M`)ES```/````H',``!@```"P<P``%P```,ES```?````X7,```,````!=```
M"`````5T```'````#G0```H````6=```"P```"%T```'````+70```T````U
M=```&@```$-T``!*````7G0```8```"I=```!@```+!T```8````MW0``!<`
M``#0=```#0```.AT``!7````]G0```(```!.=0``"P```%%U```(````774`
M``H```!F=0``"P```'%U```,````?74```T```"*=0``#````)AU```*````
MI74``!8```"P=0``"0```,=U```0````T74``!(```#B=0``!P```/5U```%
M````_74```P````#=@``"````!!V```7````&78```P````Q=@``#0```#YV
M```:````3'8``!,```!G=@``!````'MV```*````@'8```0```"+=@``"@``
M`)!V```%````FW8``#@```"A=@``"@```-IV```/````Y78``!,```#U=@``
M%0````EW```3````'W<```@````S=P``"````#QW```K````17<``$4```!Q
M=P``00```+=W```$````^7<``!,```#^=P``%````!)X```3````)W@```<`
M```[>```!0```$-X```;````27@```@```!E>```$0```&YX```.````@'@`
M``(```"/>```#@```))X```'````H7@```X```"I>```!@```+AX```H````
MOW@```P```#H>```'````/5X```-````$GD``!<````@>0``7````#AY```4
M````E7D``!\```"J>0``$````,IY```'````VWD```X```#C>0``#````/)Y
M```*````_WD``!T````*>@``&0```"AZ```%````0GH``!$```!(>@``$0``
M`%IZ```(````;'H```D```!U>@``#0```']Z```*````C7H```<```"8>@``
M#P```*!Z```&````L'H```L```"W>@``&@```,-Z```*````WGH```<```#I
M>@``#0```/%Z```(````_WH``!X````(>P``$0```"=[```J````.7L```D`
M``!D>P``"@```&Y[```5````>7L```4```"/>P``%````)5[```$````JGL`
M`!````"O>P``!@```,![```'````QWL``!X```#/>P``*````.Y[```<````
M%WP``!H````T?```%````$]\```$````9'P```8```!I?```!@```'!\```*
M````=WP``!L```""?```-````)Y\```T````TWP``"D````(?0``*````#)]
M```I````6WT``%````"%?0``"````-9]```%````WWT``!D```#E?0``&0``
M`/]]```C````&7X``!D````]?@``"````%=^```7````8'X```H```!X?@``
M!P```(-^```A````BWX```X```"M?@``$P```+Q^```(````T'X```@```#9
M?@``!0```.)^```%````Z'X```0```#N?@``"@```/-^```)````_GX```L`
M```(?P``#0```!1_```,````(G\```X````O?P``!````#Y_```R````0W\`
M`$4```!V?P``%P```+Q_```>````U'\``!0```#S?P``!P````B````.````
M$(```"H````?@```!@```$J````,````48```!$```!>@```"P```'"````V
M````?(````H```"S@```(@```+Z````+````X8````\```#M@```-@```/V`
M```%````-($```X````Z@0``$P```$F!```'````78$``!$```!E@0``$P``
M`'>!```4````BX$``!@```"@@0``!P```+F!```%````P8$``!(```#'@0``
M#@```-J!```.````Z8$```4```#X@0``!0```/Z!```N````!((``"8````S
M@@``(P```%J"```#````?H(```T```""@@``"0```)""```#````FH(```H`
M``">@@```@```*F"```2````K((```0```"_@@``!P```,2"```)````S((`
M``P```#6@@``4@```.."```7````-H,``"0```!.@P``$@```'.#```'````
MAH,```8```".@P``#@```)6#```5````I(,``!(```"Z@P``#P```,V#```4
M````W8,``&D```#R@P``&@```%R$```7````=X0``"<```"/A```&@```+>$
M```7````TH0``!L```#JA```&0````:%```?````((4``!,```!`A0``"```
M`%2%```)````784```8```!GA0``1@```&Z%```_````M84``#<```#UA0``
M5P```"V&```%````A88``!\```"+A@``+P```*N&```(````VX8```T```#D
MA@``+0```/*&```$````((<``$\````EAP``)0```'6'```?````FX<``!T`
M``"[AP``)0```-F'```@````_X<``"0````@B```(````$6(```'````9H@`
M``T```!NB```#````'R(```7````B8@``!````"AB```!````+*(```+````
MMX@```P```##B```$@```-"(```1````XX@```P```#UB```&@````*)```Z
M````'8D```T```!8B0``&P```&:)```3````@HD``!P```"6B0``*````+.)
M```'````W(D``!,```#DB0``!````/B)```7````_8D```H````5B@``#```
M`""*```)````+8H```8````WB@``"````#Z*```)````1XH```8```!1B@``
M#0```%B*```+````9HH```(```!RB@``'````'6*``!E````DHH```D```#X
MB@``!P````*+```F````"HL``#@````QBP``&@```&J+```J````A8L``#L`
M``"PBP``*````.R+```T````%8P``!D```!*C```%0```&2,```'````>HP`
M``@```""C```!P```(N,```%````DXP```<```"9C```#@```*&,```)````
ML(P```8```"ZC```"````,&,```+````RHP```<```#6C```!P```-Z,```1
M````YHP```@```#XC```$`````&-```0````$HT```<````CC0``!0```"N-
M```4````,8T```L```!&C0``#0```%*-```H````8(T``!<```")C0``"0``
M`*&-```*````JXT```<```"VC0```@```+Z-```.````P8T``#$```#0C0``
M)P````*.```4````*HX``*D!```_C@``(P```.F/```7````#9```!T````E
MD```&````$.0```A````7)```!\```!^D```*P```)Z0```=````RI```!$`
M``#HD```)P```/J0```@````(I$``#(```!#D0``,0```':1``!!````J)$`
M`#,```#JD0``)0```!Z2``!4````1)(``%4```"9D@``"P```.^2``!S````
M^Y(``#$```!ODP``!P```*&3```'````J9,```T```"QDP``"P```+^3```%
M````RY,``!````#1DP``!0```.*3```2````Z),```@```#[DP```P````24
M```0````")0```P````9E````@```":4```4````*90```P````^E````P``
M`$N4```$````3Y0``"````!4E```&@```'64```)````D)0```P```":E```
M%P```*>4```'````OY0```\```#'E```!0```->4```:````W90``,<```#X
ME```"P```,"5```&````S)4```D```#3E0``"P```-V5```-````Z94``!<`
M``#WE0``!@````^6```S````%I8``!,```!*E@``$P```%Z6```R````<I8`
M`!,```"EE@``$0```+F6```R````RY8``!8```#^E@``#@```!67```/````
M))<```@````TEP``"0```#V7```*````1Y<``!0```!2EP``"````&>7```(
M````<)<```\```!YEP``#@```(F7```0````F)<```D```"IEP``"0```+.7
M```3````O9<``!D```#1EP``"@```.N7```,````]I<``"H````#F```!P``
M`"Z8```"````-I@``!`````YF```&````$J8```#````8Y@```@```!GF```
M!P```'"8```-````>)@```L```"&F```%````)*8```5````IY@``"\```"]
MF```(````.V8```<````#ID```P````KF0``,0```#B9```%````:ID``#\`
M``!PF0``$@```+"9```*````PYD```8```#.F0``!````-69```$````VID`
M``H```#?F0``$P```.J9```%````_ID```8````$F@``!@````N:```(````
M$IH```0````;F@``!0```"":```"````)IH```P````IF@``10```#::```R
M````?)H``"4```"OF@``10```-6:```P````&YL``!\```!,FP``'P```&R;
M```H````C)L``"D```"UFP``)@```-^;```E````!IP``"@````LG```(0``
M`%6<```2````=YP``!,```"*G```$````)Z<```)````KYP``'(```"YG```
M<P```"R=```K````H)T``%,```#,G0``%P```"">```G````.)X``!8```!@
MG@``#P```'>>```?````AYX``%$```"GG@``-P```/F>```V````,9\``#X`
M``!HGP``00```*>?``!#````Z9\``$`````MH```/@```&Z@``!`````K:``
M`$4```#NH```.0```#2A```?````;J$``!P```".H0``40```*NA```4````
M_:$```4````2H@``$@```!BB```0````*Z(``!,````\H@``#P```%"B```$
M````8*(```D```!EH@``"P```&^B```'````>Z(``!0```"#H@``#P```)BB
M```,````J*(```\```"UH@``!@```,6B```4````S*(```8```#AH@``!```
M`.BB```'````[:(``!D```#UH@``!P````^C```&````%Z,```8````>HP``
M!````"6C```'````*J,```8````RHP``!@```#FC```0````0*,```8```!1
MHP``$0```%BC```B````:J,```<```"-HP``"P```)6C```J`0``H:,```8`
M``#,I```+````-.D```L`````*4``!8````MI0``0````$2E```,````A:4`
M`#````"2I0``%0```,.E```2````V:4``"0```#LI0``"````!&F```;````
M&J8```T````VI@``OP```$2F```(````!*<```X````-IP``#P```!RG```5
M````+*<``!@```!"IP``#0```%NG```-````::<```8```!WIP``*P```'ZG
M```*````JJ<```H```"UIP``"````,"G```*````R:<``!````#4IP``!0``
M`.6G```2````ZZ<```L```#^IP``.@````JH```\````1:@``!$```""J```
M#0```)2H```)````HJ@```8```"LJ```$````+.H```.````Q*@``!````#3
MJ```&````.2H```5````_:@``!,````3J0``#P```">I```M````-ZD```\`
M``!EJ0``:P```'6I``!%````X:D``"4````GJ@``#````$VJ```,````6JH`
M``4```!GJ@``!````&VJ```(````<JH```4```![J@``$P```(&J```*````
ME:H``!````"@J@``,@```+&J```4````Y*H``!0```#YJ@``'`````ZK```6
M````*ZL``!(```!"JP``#P```%6K```'````9:L```@```!MJP``#P```':K
M```4````AJL``!L```";JP``"0```+>K```%````P:L``!,```#'JP``20``
M`-NK``!!````):P``!,```!GK```!````'NL```*````@*P``#T```"+K```
M+````,FL```L````]JP``"L````CK0``+0```$^M```'````?:T``!0```"%
MK0``"P```)JM```M````IJT```X```#4K0``%````..M```4````^*T``"P`
M```-K@``.0```#JN```/````=*X```D```"$K@``"P```(ZN```4````FJX`
M``8```"OK@``$````+:N```&````QZX```@```#.K@``!0```->N```-````
MW:X```,```#KK@``#0```.^N```(````_:X```8````&KP``50````VO```%
M````8Z\``!@```!IKP``"P```(*O```2````CJ\```P```"AKP``,0```*ZO
M```,````X*\``!8```#MKP``%`````2P```&````&;```!D````@L```!```
M`#JP```-````/[````\```!-L```%@```%VP``!F````=+```!(```#;L```
M&0```.ZP``!H````"+$```@```!QL0``#P```'JQ```7````BK$``!<```"B
ML0``)0```+JQ```S````X+$```D````4L@``%@```!ZR```6````-;(``!(`
M``!,L@``%P```%^R```8````=[(``!$```"0L@``#0```**R```'````L+(`
M`!0```"XL@``!P```,VR```8````U;(```\```#NL@``!0```/ZR```-````
M!+,```4````2LP``!@```!BS```'````'[,```T````GLP``"````#6S```'
M````/K,```<```!&LP``%0```$ZS```H````9+,```L```"-LP``$````)FS
M```9````JK,```8```#$LP``!@```,NS```&````TK,```4```#9LP``#0``
M`-^S```A````[;,``"$````/M```/@```#&T```Q````<+0``"4```"BM```
MNP```,BT```C````A+4``"4```"HM0``*0```,ZU```L````^+4``#,````E
MM@``,0```%FV``"]````B[8``"X```!)MP``5````'BW```&````S;<```0`
M``#4MP``"0```-FW```)````X[<```T```#MMP``#@```/NW```3````"K@`
M``X````>N```$0```"VX```-````/[@``#<```!-N```!0```(6X```-````
MB[@``!$```"9N```%P```*NX```;````P[@```(```#?N```$````.*X```0
M````\[@```0````$N0``"P````FY```(````%;D```T````>N0``$````"RY
M```'````/;D```T```!%N0``#0```%.Y```(````8;D```4```!JN0``"0``
M`'"Y```*````>KD```D```"%N0``"P```(^Y```G````F[D```L```##N0``
M'0```,^Y```9````[;D``!D````'N@``(````"&Z```0````0KH```D```!3
MN@``#````%VZ```+````:KH``!\```!VN@``"P```):Z```2````HKH``!(`
M``"UN@``"0```,BZ```7````TKH``!$```#JN@``'0```/RZ```=````&KL`
M`"D````XNP``5@```&*[```J````N;L``#@```#DNP``"P```!V\```$````
M*;P```L````NO```"0```#J\```)````1+P``!(```!.O```$P```&&\```2
M````=;P```H```"(O```"0```).\```"````G;P```P```"@O```00```*V\
M```A````[[P```\````1O0``G0```"&]```:````O[T```D```#:O0``)0``
M`.2]```F````"KX```0````QO@``#P```#:^```.````1KX```\```!5O@``
M#@```&6^```3````=+X```P```"(O@``$P```)6^```(````J;X``!<```"R
MO@``"````,J^```6````T[X``!H```#JO@``!0````6_```#````"[\```@`
M```/OP``!P```!B_```(````(+\``!`````IOP``%@```#J_```,````4;\`
M``8```!>OP``'P```&6_```?````A;\```4```"EOP``"````*N_```-````
MM+\```<```#"OP``+P```,J_```3````^K\``)\````.P```%P```*[````(
M````QL````<```#/P```#````-?````'````Y,````D```#LP```!0```/;`
M```*````_,````,````'P0``!0````O!```$````$<$``!$````6P0``#0``
M`"C!```,````-L$``"(```!#P0``!@```&;!```<````;<$``!0```"*P0``
M"````)_!```&````J,$``!````"OP0``$P```,#!```1````U,$```0```#F
MP0``"0```.O!```)````]<$``$X```#_P0``4````$["``!0````G\(```@`
M``#PP@``%0```/G"```&````#\,```<````6PP``&@```![#```,````.<,`
M`!\```!&PP``!@```&;#```%````;<,```X```!SPP``!0```(+#```>````
MB,,``#L```"GPP``"P```./#```Z````[\,``"X````JQ```)````%G$```N
M````?L0```H```"MQ```"P```+C$```'````Q,0``!D```#,Q```"@```.;$
M```-````\<0``!````#_Q```#P```!#%``":````(,4```T```"[Q0``"@``
M`,G%```+````U,4``!(```#@Q0``$P```//%```-````!\8``!$````5Q@``
M%@```"?&```3````/L8``!D```!2Q@``#@```&S&``"3````>\8```X````/
MQP``$````!['```)````+\<``"$````YQP``&0```%O'```/````=<<```X`
M``"%QP``$0```)3'```9````IL<``#0```#`QP``-````/7'```T````*L@`
M`#0```!?R```,````)3(```P````Q<@``!L```#VR```00```!+)```7````
M5,D``!<```!LR0``&0```(3)```9````GLD``!P```"XR0``'````-7)```9
M````\LD``!D````,R@``/````";*```4````8\H``!(```!XR@``%0```(O*
M```7````H<H```H```"YR@``.0```,3*```,````_LH```<````+RP``%```
M`!/+```$````*,L```0````MRP``!````#++```+````-\L``!,```!#RP``
M"0```%?+```*````8<L```X```!LRP``"0```'O+```.````A<L```@```"4
MRP``!@```)W+```@````I,L``!@```#%RP``(````-[+```2````_\L```4`
M```2S```"````!C,```>````(<P```0```!`S```!P```$7,```'````3<P`
M`!0```!5S```&@```&K,```'````A<P``!8```"-S```"````*3,```-````
MK<P```T```"[S```$0```,G,```,````V\P```\```#HS```%````/C,```,
M````#<T``!\````:S0``#0```#K-```,````2,T``!H```!5S0``!@```'#-
M```%````=\T```<```!]S0``!0```(7-```+````B\T```8```"7S0``!0``
M`)[-```&````I,T``!D```"KS0``&````,7-```9````WLT```(```#XS0``
M!````/O-```%`````,X```4````&S@``"P````S.```,````&,X``&P````E
MS@``!0```)+.```&````F,X``!$```"?S@``+@```+'.```L````X,X``"D`
M```-SP```P```#?/```+````.\\```<```!'SP``"@```$_/```-````6L\`
M``4```!HSP``#````&[/```<````>\\``$4```"8SP``!@```-[/```&````
MY<\``"P```#LSP``*P```!G0```)````1=```'(```!/T````P```,+0```+
M````QM````8```#2T```"````-G0```*````XM```!0```#MT```%@````+1
M```4````&=$```H````NT0``%````#G1```(````3M$``!$```!7T0``&```
M`&G1```'````@M$```P```"*T0``#0```)?1```*````I=$``!P```"PT0``
M"@```,W1```.````V-$``!<```#GT0``%````/_1```&````%-(```L````;
MT@``"@```"?2```/````,M(```4```!"T@``2P```$C2```4````E-(``!X`
M``"IT@``'0```,C2```B````YM(``",````)TP``$````"W3```.````/M,`
M`#<```!-TP``8````(73``!;````YM,```D```!"U```(@```$S4```9````
M;]0``!(```")U```#````)S4```'````J=0``"\```"QU```"````.'4```,
M````ZM0```P```#WU````@````35```.````!]4```<````6U0``$@```![5
M```&````,=4``"(````XU0``"@```%O5```7````9M4```X```!^U0``'@``
M`(W5``!K````K-4``!D````8U@``(@```#+6```.````5=8```<```!DU@``
M$````&S6```4````?=8```@```"2U@``%@```)O6```:````LM8```D```#-
MU@``#@```-?6```,````YM8```@```#SU@``"0```/S6```*````!M<```H`
M```1UP``"P```!S7```0````*-<```@````YUP``*@```$+7```>````;=<`
M``D```",UP``%P```);7```0````KM<```4```"_UP``%@```,77```1````
MW-<``#(```#NUP``!@```"'8```&````*-@``!(````OV```!0```$+8```7
M````2-@```0```!@V```&0```&78```%````?]@```8```"%V```(0```(S8
M```S````KM@``"0```#BV```$0````?9```1````&=D``!,````KV0``!```
M`#_9```%````1-D```\```!*V0``(@```%K9```[````?=D``$0```"YV0``
M+P```/[9```I````+MH``"T```!8V@``8@```(;:```'````Z=H```<```#Q
MV@``%P```/G:```6````$=L``"(````HVP``'````$O;```'````:-L``!P`
M``!PVP``"````(W;```%````EML``"<```"<VP``#0```,3;```1````TML`
M``@```#DVP``!@```.W;```%````]-L```4```#ZVP``!0````#<```2````
M!MP``!@````9W```!P```#+<```2````.MP``!P```!-W```#````&K<```$
M````=]P``#T```!\W```7````+K<```9````%]T``!P````QW0``%0```$[=
M```(````9-T```T```!MW0``*0```'O=```)````I=T``!````"OW0``%0``
M`,#=```2````UMT``$4```#IW0``"0```"_>```?````.=X``!(```!9W@``
M%@```&S>``!#````@]X```4```#'W@``$@```,W>```7````X-X```4```#X
MW@``$@```/[>```6````$=\``!8````HWP``&````#_?```)````6-\```4`
M``!BWP``$0```&C?```.````>M\```X```")WP``!@```)C?```&````G]\`
M`#8```"FWP``+````-W?```L````"N````@````WX```"0```$#@```)````
M2N````,```!4X```"@```%C@```#````8^```!<```!GX```!@```'_@```)
M````AN````L```"0X```#@```)S@``!?````J^```!X````+X0``+0```"KA
M```I````6.$``!````""X0``"0```)/A```/````G>$``!D```"MX0``$@``
M`,?A```,````VN$``!T```#GX0``>0````7B```4````?^(``!4```"4X@``
M+````*KB```2````U^(``!,```#JX@``&P```/[B```8````&N,``"`````S
MXP``%0```%3C```'````:N,```D```!RXP``!@```'SC``!>````@^,``#H`
M``#BXP``0````!WD``!4````7N0```4```"SY```'0```+GD```N````U^0`
M``<````&Y0``$`````[E```Y````'^4```D```!9Y0``50```&/E```Q````
MN>4``",```#KY0``(@````_F```C````,N8``!\```!6Y@``)0```';F```@
M````G.8```<```"]Y@``%````,7F```:````VN8``!D```#UY@``$P````_G
M```%````(^<```T````IYP``#0```#?G```:````1><``"````!@YP``$```
M`('G```B````DN<``#````"UYP``#````.;G```:````\^<``!0````.Z```
M(````"/H```H````1.@```L```!MZ```)P```'GH```$````H>@``!D```"F
MZ```#````,#H```.````S>@```X```#<Z```"````.OH```'````].@``!(`
M``#\Z```!@````_I```J````%ND```H```!!Z0```P```$SI```B````4.D`
M`(4```!SZ0``.````/GI```&````,NH``#`````YZ@``0````&KJ```;````
MJ^H``"L```#'Z@``20```//J```K````/>L``#,```!IZP``(````)WK```;
M````ONL```D```#:ZP``#P```.3K```1````].L```4````&[```#P````SL
M```A````'.P``!`````^[```$0```$_L```2````8>P``#$```!T[```"```
M`*;L```G````K^P``"T```#7[```)P````7M```.````+>T```X````\[0``
M!P```$OM```%````4^T``!@```!9[0``!````'+M```%````=^T``"$```!]
M[0``%0```)_M```*````M>T```T```#`[0``$````,[M```#````W^T```X`
M``#C[0``+0```/+M```L````(.X``!<```!-[@``'0(``&7N```=````@_``
M`!8```"A\```(````+CP```7````V?```",```#Q\```)````!7Q```[````
M.O$``"````!V\0``%@```)?Q```E````KO$``"4```#4\0``-P```/KQ```X
M````,O(``$4```!K\@``,````+'R```H````XO(``%X````+\P``2@```&KS
M```.````M?,``'4```#$\P``+@```#KT```%````:?0```4```!O]```#P``
M`'7T```,````A?0```4```"2]```&````)CT```(````L?0``!$```"Z]```
M!0```,ST```$````TO0``!$```#7]```"0```.GT```#````\_0``!(```#W
M]```"P````KU```#````%O4```0````:]0``(0```!_U```E````0?4```L`
M``!G]0``$@```'/U```;````AO4``!````"B]0``#P```+/U```$````P_4`
M`"<```#(]0``&0$``/#U```2````"O<```H````=]P``#0```"CW```3````
M-O<``!@```!*]P``'0```&/W```&````@?<``#,```"(]P``&````+SW```9
M````U?<``#H```#O]P``%0```"KX```4````0/@``#D```!5^```(````(_X
M```7````L/@``!@```#(^```#0```.'X```)````[_@```X```#Y^```&0``
M``CY```'````(OD```@````J^0``#0```#/Y```V````0?D``#$```!X^0``
M"0```*KY```-````M/D``!````#"^0``&````-/Y```-````[/D```X```#Z
M^0``.0````GZ```*````0_H```0```!.^@``#0```%/Z```:````8?H```,`
M``!\^@``"````(#Z```.````B?H``!0```"8^@``$@```*WZ```4````P/H`
M`!4```#5^@``,P```.OZ```E````'_L``"D```!%^P``#@```&_[```\````
M?OL```4```"[^P``1P```,'[```+````"?P```H````5_```!@```"#\```$
M````)_P```4````L_```$@```#+\```=````1?P```8```!C_```!@```&K\
M```.````<?P``!````"`_```"0```)'\```%````F_P```(```"A_```#P``
M`*3\``!B````M/P``#8````7_0``+P```$[]``!.````?OT``#4```#-_0``
M)0````/^```E````*?X``"X```!/_@``.P```'[^```[````NOX``#,```#V
M_@``-P```"K_```H````8O\``!$```"+_P``$@```)W_```.````L/\```D`
M``"__P``?````,G_``!\````1@`!`"T```##``$`7@```/$``0`9````4`$!
M`"0```!J`0$`%P```(\!`0`2````IP$!`",```"Z`0$`6@```-X!`0`_````
M.0(!`#T```!Y`@$`/@```+<"`0!#````]@(!`$<````Z`P$`/@```((#`0!#
M````P0,!`#X````%!`$`/@```$0$`0`U````@P0!`!X```"Y!`$`'0```-@$
M`0!A````]@0!`!,```!8!0$`!0```&P%`0`<````<@4!`!$```"/!0$`&@``
M`*$%`0`-````O`4!``0```#*!0$`"0```,\%`0`+````V04!``4```#E!0$`
M$@```.L%`0`,````_@4!``0````+!@$`$0```!`&`0`&````(@8!`!$````I
M!@$`"````#L&`0`&````1`8!``4```!+!@$`%P```%$&`0`-````:08!`!8`
M``!W!@$`!@```(X&`0`$````E08!``8```":!@$`!0```*$&`0`$````IP8!
M`!,```"L!@$`!0```,`&`0`0````Q@8!`"D```#7!@$`"@````$'`0`+````
M#`<!``$```"M````D`,``/<!````````5`(``+T```!0````T@```-$`````
M````\@$```````"M`0````````,!``";`@``<@$``!\```#J`0``HP$`````
M``"F````3`(```````!O`P``#`$``%,```!_`0```````*4#``#3`@``N`$`
M`'L!````````D@(``%@```#@`0``````````````````20,```````#I````
M`````'`"``!K`0``80(``!<!```#````H0(``$(!```(`@``E@,```````#D
M`@``8`,```@!````````L0(``"T```!&`0``R@$``"4`````````.P$``"$`
M``"A````S@(`````````````[P(``"\"``"`````P@(`````````````8@(`
M``````!V`0``00(`````````````I0(```<!`````````````"\!``!.`P``
MNP$``"<"```[`P``>0,``)D"```@````O@$``"D#``#&`@````````````"3
M`P``B@(``.("``!S`@```````.<"``!7`@``8`(``$("``".`0``6@,```$"
M``"%````'0,```````#^````M````.8"```4`0``.@(```````!X`@``````
M`#<```#C````?0(``.,"``"Y````Z`(```````!$````@P$`````````````
MQP```'D```!A````5@$``$T#````````````````````````CP```'4#``"%
M`@``G@,``-T!``"&`@```````,P!```>`0``4@(``````````````````#\"
M``!L`P``;````),"````````>@```'8```#&`0```````/\!``"M`P``````
M``0!``"J`@``70$``%\```"^```````````````_````^`(``!X#```)`@``
M=P,``#H!````````:0````````#V`@``/P$````````O````+P,``"T"````
M````\`(```0"```P`0``IP,``*H#``!&`P``$0```)T!````````E````#P!
M```\`P```````-0!``"J`0``E0$```T```"@`P``I0$`````````````>P``
M`&D#``"W`P```````%8#``!Q`@``$0,``,\```")`P``7P(``&<#``"^`P``
M`````$H#```<`@````````````"7`````````*4```"2`P``M0(``)D!``!U
M`@``-0,``+4!``#!`0````````````!-``````````````#C`0``2`(``)$"
M````````00````````#3`0``2P```#D```````````````````#\`@``````
M`'@`````````J`,``)X```"N`0``0@````````!6````O0,``&X"``!2`0``
MW@$``+$!``"-`0```````!`#``!P````(0,``",#``!2`P``-0$```````!9
M`P``(@$``*L!``#>`````````+,#``""````PP$``$@```!^````5@(`````
M```R`@```````(`!``````````````````````````````````!E`P``````
M```````X`@``!0```!,"``#P````^0$```````"8`0``;0,``-@`````````
MV@$```\"```<`0```````)0"``"#`P``7@$```D```#<`@``<P`````````J
M`0``B`,``&4!``!+`0``N0$``-\!```\````4P,``%L"``"8`P``C0```%,!
M```&`P``K````.$!`````````````(T"``"(`0``2P(``/`!``"``P``[0``
M``````#[`0``6P,``"P````(````+`,``$4````-`0```````)<"``!'`0``
M`````!X````H`P``ZP``````````````,P(``+4`````````````````````
M````)0,``,T`````````CP(`````````````'P,``$\"```"`P``_@$`````
M``#=`@``V@(``)`"```+`P``CP,``'\"``````````````(!``!T`0``<P,`
M`.4```#_````D0```.H"``"(````'@(`````````````20```,(```"B````
MV0(``%P````B`P``P`$```````#?`````````&,!```S`P``3P```'(`````
M````(`(``!0"``!A`P``)0(``'D!````````7P$``%0#``!I`0``S`(`````
M``!^`@``-P$``#8!```2`0``?0,``)8!```A`@```````&`!``"K`P``#`,`
M```````E`0``'0`````````:````"@,````!``#D````$P,``*,"``"H`@``
M``````````#+`````````%4!``#K`0``30$``"0#```0`````````-<!``#T
M`0``A@$``"8```!$`0``%P(``-("```'`@``T````%<!```$`P``1`,```P"
M````````(@(``+P```!P`0```````#4``````````````+(#```.`0``[`(`
M``````"@`0``8````"<!```S````AP(``*<``````````@(``"H```"Z`0``
MKP,``)H!````````7@```!D!```_`P``LP(``#D"````````)`$``/,```#A
M`@```````*H````Z`P``:P(``$,```!-`@``]P(````````\`@``PP(``'H"
M``">`@``<@,``/X"``"G`@```````*(#``#+`@``R@(``#4"````````Y@$`
M`#0"````````A`$```````"1`0````````````#E`@```````!P#````````
MC`$``(8```"V`P``$@,``,X```"P````;@```(P#``#Q`@``@@(``.`"```+
M`0``_0```*,#``!M````LP```!4#``!!`P``R0(`````````````W0``````
M``"!`P``S@$````````Q````N0,``#<#``#4`@``40```/P```"X````SP$`
M`!D```"?`0``(`,````````'`P``:@$````#``"%`0``T`$```````!W`0``
MFP,``&<```#<````FP```/L"``!H````\0$``*(!``!4````-@(``+0!``#Y
M`@``[@(````````X`````````#8#``!?`P``%P,``!H"````````;P``````
M``````````````````"T`P``?`(`````````````H@(``.<!``!\`P``90``
M```````&`@``$P```!8#````````@@,`````````````JP(`````````````
M[0$```````"[`P``F@```"L#````````/@$``(0"```-`P``F@,``#L"``"6
M`@``?0````````#F````&@$``!8!`````````````)$#``!)`@``0`,`````
M``"=`P``.0,```````!/`P``40,```````"R`0``F`(``(4#``#U`@``R`(`
M```````9`@``40$````````C`0``0P(```$#````````P@$``&H#``!*````
MJ`````````#I`0````````````!V`@``:@(``-8"``"O`0``G0(```````!%
M`@``L@(```,#``"+`````````!`"```8`P```````%H"``"R````EP$``$,#
M``#6`````````/@!``#R`@``%@(``$X```"I`0``4`$``"D````2`@``IP$`
M`````````````````*X"``!<`@``'P(``!D#``"2``````````````"T`@``
MVP$``"D!```"````DP$``","```P````,0(``.````!1`@``20$```````!F
M````````````````````G0```/H```!N`P``@P(``!@"````````OP(`````
M``"S`0``,`(```````#1`@``10$``.\!``!_`P```````#(````@`0``60``
M``````!N`0``6@```)\"``!W````:P,``$H"``#L````%`,``/\"``!>`P``
MO`,``%L```"<`0````````````"$````<0,``.@!````````S0$`````````
M````````````````````AP,`````````````<0```"P"````````QP(`````
M``#T`@```````.\```!2``````````````#G````%@```'L#``"``@``DP``
M`!4```"D`@``P0```/$```"+`@``/0,``$`!``"5````10,``.@```!O`@``
M;P$``*8!```H``````````````#0`@``K@```$<"``"O````R0$``#D!```;
M`````````.H```#8`@``O@(````````T`0```````,0"```P`P``G@$``$$!
M```%`P```````,$"``"D`````````'4````V````OP$```````"]`0``````
M``````!=`@``M@(```````#>`@``/@,``"L"```;`0``K`$``%X"``#``@``
MH0$``*`"``!X`P```````+<!`````````````+@"```0`0``&````-0```#(
M`0``H0,``!(````&`0``:@```$@#``""`0``&P(``.0!````````8P(``#0`
M``!B`0``KP(``/H"``!\`0``;0(``/4```#/`@``;`(``#<"````````K@,`
M`)\#````````+@,``%`"``#;````#P,``/L```!0`P``L`$``#H```!Z`P``
M^0````````"?``````````````!&````J`$`````````````````````````
M````1`(``&0!``````````````````"U`P``U0(``+P!``#9````>`$``$P#
M``![`@``TP```"8"````````Q````"T!````````````````````````````
M```````%`@```````*T"```M`P``*`(``%P!``!^`P``+@```(D"``"K````
M]````-4```"<`P``J0```+H"``!P`P````````````#]`@``Q0$``/,"```S
M`0```````$`"``"!`0``@0`````````5`0``"P```/P!``#U`0``/@(``&@!
M```R`P``G`````````"\`@``#````$X"````````9`(``"$!````````C@``
M``````#R````B@```!0`````````D`````$!````````[@```*,````(`P``
M`````)0!``"-`P``S`````,"```Q`0``:`,``%D"``!Z`0```````-8!``",
M`@```````-<"`````````````+H````]````````````````````60$``+8`
M``#2`0```````&8!``"2`0``,0,``-H````:`P``E`,``,T"``##````````
M``````!M`0``U0$``.$`````````[0(``!L#``!W`@``#@```%P#``!A`0``
ML0```*0#```%`0``'0(``',!``#N`0``V0$`````````````O0(```X"``!&
M`@``9@,```````#B`````````%4#``!_````"@(``,D`````````Q`$``(P`
M``!B`````````'X!````````L0,````````)`0``"@```.D"```F`0``2P,`
M`/8```````````````````#%`@``6`$``&8"``"D`0``@P```!@!``!'````
M``````H!````````E0(``)<#``"L`@``=`````````#W````'````+8!``".
M`@``3````)D#``!C``````````````!8`@``^`````T"``#<`0``C@,`````
M``#S`0``50(``!,!```1`@``5`$```````#7````QP$```X#````````````
M```````^````E0,``*8"``!I`@``I@,``%T````X`P``T0$``(D!````````
M`````!\!``"*`P``3P$``'$!``!C`P``9``````````+`@``NP(``%<#````
M````5P```"0"`````````````)8``````````````"H#``#Z`0``L`,``%@#
M``"X`P``J0,````````&````.`$``$@!````````<@(``(@"``#%````Y0$`
M``````"Z`P``L`(``!<````N`0``)P,`````````````:`(``(<````I`@``
MBP,``"0````L`0``_0$``+<`````````FP$``&0#```G````0`````````!*
M`0```````,8```!U`0``50```$(#````````AP$````````F`P``G`(````"
M``!T`P``A@,``&(#``")````VP(``)`!``#L`0``*P```"H"````````9P$`
M`,@`````````1P,``!T!````````:P```$P!``!V`P``#P```"X"```$````
MK`,``.(!``!#`0``(@```(H!``!L`0``6@$``(\!````````90(``+L```"Y
M`@````````\!``!G`@`````````````)`P``-`,````````H`0``?0$``.L"
M``":`@``>0(``-\"``"+`0```````$X!``!\````RP$``+<"```]`@``,@$`
M`)@```!;`0``H`````<```"$`P``]@$``)D```#*````OP``````````````
M70,````````K`0``P```````````````@0(``'0"``#8`0``4P(``!$!```]
M`0``(P`````````5`@```````*D"```[`````"!A="``(B5S(B!W87,@861D
M960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H
M92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E
M<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@
M)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S
M+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!497)M<R!O
M9B!!9W)E96UE;G0`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!M:6YU=&5S`"5S('1O("5S(&]F
M("5S`"P@9W5S=&EN9P`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M
M("5S('1O("5S`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO
M=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RX`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W
M97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!8F]U="!T:&ES(&5D:71O<@!!
M8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V]U;G0@26YF;W)M871I
M;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@
M1W)O=7``061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D(&$@8VAI;&0@9W)O
M=7`@=&\@)R5S)P!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M96UB97)S`$%D
M9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!
M9&0@=7-E<@!!9&1E9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N
M;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D
M960@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<R!";V]K`$%D;6EN:7-T
M<F%T:6]N`$%D<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC
M871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!F;W5R('-I9&5S`$%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L=&5R;F%T92!)35-0($QO
M9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S
M97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP
M;&%T97,`06QT97)N871E('1E>'0Z`$%N<W=E<@!!<'!L:6-A=&EO;@!!<'!L
M:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#
M:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U
M-BD`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92`G)7,G(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)M96YI86X@*$%235-#
M24DM."D`07)T`$%S8VEI($%R=`!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!"
M3T9(($5X8W5S97,`0F%C:V5N9"!N;W0@8V]R<F5C=&QY(&EM<&QE;65N=&5D
M+@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%L=&EC("A)4T\M.#@U
M.2TQ,RD`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N
M`$)A<V5L:6YE`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";V]K
M;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]T:`!"
M;W1T;VT`0G5L;&5T960@3&ES=`!#35,`0U]E;&P@4')O<&5R=&EE<RXN+@!#
M86QE;F1A<@!#86QM`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;F-E;`!#86YC
M96P@4')O8FQE;2!297!O<G0`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E
M;',`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T
M:65S`$-E;&P@<W!A8VEN9SH`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R
M`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-H86YG90!#:&%N9V4@
M4&%S<W=O<F0`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E(&1E9F%U;'0@
M:61E;G1I='D`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H86YG92!Y;W5R('!A<W-W;W)D`$-H86YG:6YG(%!A<W-W;W)D(&]N
M("5S`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EN97-E(%-I
M;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`
M0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL
M92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VQE87(`0VQE87(@35-/9F9I
M8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U
M<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&]S
M92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO<@!#;VQO<B!0:6-K97(`
M0V]L<SH`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUP=71E<G,`
M0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`
M0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&YE=R!P87-S=V]R9#H`0V]N=&%C
M=',`0V]N=&EN=64`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]U;&0@
M;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("<E<R<@
M=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@
M<V-R:7!T("<E<R<N`$-O=6QD(&YO="!O<&5N('!I<&4@=&\@<VUB<&%S<W=D
M+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S
M=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=F5R
M="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T
M:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U<F%T:6]N.B`E<P!#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B`G)7,G.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5R<V5S`$-R96%T
M90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W5R<F5N="!0:&%S
M90!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!$1`!$871A5')E92!"<F]W
M<V5R`$1A=&4@4F5C96EV960`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R
M`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A
M=6QT($-O;&]R`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E
M;&5T92!#96QL`$1E;&5T92!'<F]U<`!$96QE=&4@8V5L;`!$96QE=&4@8V]L
M=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E
M(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R
M96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`
M1')U9W,`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S
M:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16QE;65N="XN
M+@!%;0!%;6%I;"!!9&1R97-S`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C
M=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U
M(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T
M:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE
M<F4`17)R;W(`17)R;W(@<V5N9&EN9R!D871A('1O('-M8G!A<W-W9"X`17)R
M;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5T:&YI8P!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>&5C=71E`$5X<&%N9"!3:61E8F%R`$9'($-O;&]R`$944"!U
M<&QO860@;V8@<V5T=7``1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"`Z
M(`!&86ER`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@
M`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEL92!-86YA9V5R`$9I
M;'1E<G,`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9L;V%T`$9O9P!&;VYT
M($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9',`1G(`1G)A;65S`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U
M;&P@36]O;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`
M1V%L;&5R>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@
M0V]D90!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F5E:R`H25-/+3@X-3DM
M-RD`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7!S`$=U97-T(%!E<FUI<W-I
M;VYS`$=U97-T8F]O:P!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R
M;W<@:6X@=&%B;&4N`$AA>F4`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H
M=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;6ES<&AE<F4`2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;64@1&ER
M96-T;W)Y`$AO<F1E`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I
M;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@
M<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y
M`$AU;6ED:71Y.B``2'5M;W)I<W1S`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N
M<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG
M<R!N86UE.@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X
M('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EM86=E(%!R979I97<Z
M`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G
M92!F<F]M(&=A;&QE<GDZ`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T
M960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T
M97(`26YC;W)E8W0@4&%S<W=O<F0`26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S
M92!);F1E;G0`26YD:79I9'5A;"!5<V5R<P!);F9O<FUA=&EO;@!);F9O<FUA
M=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E
M<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!)
M;G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R
M="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T('!A
M<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@
M<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO
M9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV96YT;W)Y`$ES
M;VQA=&5D(%0M4W1O<FUS`$ET86QI8P!*86YU87)Y`$IA<&%N97-E("A)4T\M
M,C`R,BU*4"D`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S
M=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$ME<FYE;"!.
M97=B:65S`$MI9',`2V]R96%N("A%54,M2U(I`$QA7WEO=70`3&%N9W5A9V4`
M3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,
M87-T(%5P9&%T960Z`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O
M<F1E<@!,969T`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN
M($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H
M="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO
M=V5R`$QI;65R:6-K`$QI;FL@<&]I;G1S('1O.@!,:6YU>"!#;V]K:64`3&ES
M="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QO8V%L('1I;64Z
M(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G
M:6X`3&]G:6X@5&%S:W,`3&]G;W5T`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$U-`$U/5$0`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`
M36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B
M96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RX`36%R8V@`36%R9VEN`$UA=&-H:6YG(&9I96QD<P!-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S
M.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87D`365D:6-I
M;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365T
M87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!-971R:6,`36ED9&QE`$UI;B!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7-C
M96QL86YE;W5S`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@
M9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI
M8V%T:6]N+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9GD@55),`$UO
M;VX@4&AA<V5S`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3
M=6YN>0!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R
M=&%L`$UY(%!O<G1A;"!,87EO=70`3D\L($D@1&\@3D]4($%G<F5E`$YE='=O
M<FL`3F5V97(`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H
M;W!T:6]N86PI`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0Z`$YE=R!P87-S
M=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.
M97=S9W)O=7!S`$YE>'0`3F5X="!0:&%S90!.:6=H=`!.;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.
M;R!C:&%N9V4N`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N
M`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P96YD:6YG('-I9VYU<',N`$YO
M(')U;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92X`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D
M:6,@*$E33RTX.#4Y+3$P*0!.;W)T:&5R;B!(96UI<W!H97)E`$YO="!S970`
M3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$]+`$]B:F5C="!#<F5A
M=&]R`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W
M('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L
M9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VQD('!A<W-W;W)D.@!/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P
M97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI
M>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R
M(%!E<FUI<W-I;VYS`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN
M`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-
M(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE
M;&P`4&%D9&EN9P!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!C:&%N9V5D(0!087-S=V]R
M9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E
M(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E=',`4&AO=&]S`%!I>&5L<P!0;&%T
M:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE
M;65N="X`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R
M>3H`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;VQI=&EC<P!0;VQL
M<P!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H
M:7,@=&%B;&4`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4')O8FQE;3\`4')O:F5C=',`475E<GD`475O=&$`4F%I
M;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3
M;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!296%D`%)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO
M;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!"
M;&]C:P!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U:7)E9"`G<&AP='EP
M92<@;F]T('-P96-I9FEE9"!I;B!344P@8V]N9FEG=7)A=&EO;BX`4F5S970`
M4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E
M='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5V97)T($-O
M;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`
M4FEG:'0`4F]?=R!0<F]P97)T:65S+BXN`%)O=R!0<F]P97)T:65S`%)O=R!P
M<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'D`4G5N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!37U%,
M(%-H96QL`%-A`%-A;64@9G)A;64@*%]S96QF*0!3879E`%-A=F4@)7,`4V%V
M92`G)7,G`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G+@!38V%T=&5R960@5"U3=&]R
M;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T(&$@9W)O
M=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`
M4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@
M4')O8FQE;2!297!O<G0`4V5N<V]R.B``4V5P=&5M8F5R`%-E<G9E<@!3970@
M;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I
M9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I
M;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E
M(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E
M<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`
M4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=V5R<P!3
M:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I
M;FET>0!3:VEP($UA:6YT96YA;F-E`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3
M:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3
M;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]M92!O
M9B!087-S=V]R9"!M;V1U;&4G<R!C;VYF:6=U<F%T:6]N(&9I;&5S(&%R92!M
M:7-S:6YG.@!3;VYG<R`F(%!O96US`%-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*0!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E
M;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@
M8V5L;`!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A;0!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI
M="!R;W<`4W!O<G1S`%-T86YD87)D`%-T87(@5')E:P!3=&%T=7,`4W1R:6ME
M=&AR;W5G:`!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@)R5S)R!N;W0@
M9F]U;F0N`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`G)7,G('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F
M=6QL>2!A9&1E9"`G)7,G('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D
M("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C
M8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6-C97-S9G5L;'D@=W)O=&4@)7,`
M4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES
M92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP
M=`!3=7!P;W)T`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`
M5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A<F=E=#H`5&%S
M:W,`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U
M<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S
M`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O
M8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D
M:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N
M("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O
M;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R
M=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('=E871H97(N8V]M(&)L
M;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@)R5S)R!N
M;W0@9F]U;F0N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@
M=&AE('-Y<W1E;2X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E
M<R<@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B``5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E
M<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H:7,@9FEL
M92!C;VYT86EN<R!B86-K96YD(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M9F]R('1H92!087-S=V]R9"!M;V1U;&4@<V-R:7!T<RX`5&AI<R!I<R`E<RX`
M5&AI<R!I<R!T:&4@;6%I;B!087-S=V]R9"!M;V1U;&4@8V]N9FEG=7)A=&EO
M;B!F:6QE+B!)="!C;VYT86EN<R!P871H<R!A;F0@;W!T:6]N<R!F;W(@86QL
M(%!A<W-W;W)D(&UO9'5L92!S8W)I<'1S+@!4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T
M<P!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I=&QE`%1I=&QE("AT;V]L
M=&EP*3H`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O;6]R<F]W`%1O<`!4
M;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4=0!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!5+E8N(&EN9&5X.B``55),`%523#H`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`
M56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;@!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET<P!5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N=`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@
M82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R
M`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5
M<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P
M<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA
M=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R($%D
M;6EN:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T
M:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C
M;W5N="!N;W0@9F]U;F0`57-E<B!N;W0@9F]U;F0`57-E<B!N;W0@9F]U;F0N
M`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S
M>7-T96TZ`%9A8V%T:6]N`%9A<FEA8FQE`%9E<G-I;VX@0V]N=')O;`!697)T
M:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI
M9V@`5FEE=&YA;65S92`H5DE30TE)*0!6:65W(&%N(&5X=&5R;F%L('=E8B!P
M86=E`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%=!4DY)3D<A(2$@4D5-3U9%
M(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!787)N:6YG`%=E`%=E871H97(@
M1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E8@!796(@4VET
M90!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H
M25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H
M87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7
M:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z
M`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!8+5)E9@!960!997,L($D@
M06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T
M=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!C86XG
M="!C:&%N9V4@<&%S<W=O<F0@9F]R('5S97(@)7,`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;P!9;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D
M`%EO=2!M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O<F0`66]U(&UU<W0@<V5L
M96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M('5P9&%T92X`66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%EO
M=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF
M;W)M871I;VX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T
M:6]N("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO
M;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T
M97)S(&QO;F<A`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@
M9W5E<W,A("!.;W0@8VAA;F=E9"$`66]U<B!N97<@<&%S<W=O<F0@;75S="!B
M92!A="!L96%S="`E9"!C:&%R86-T97)S(&QO;F<A`%EO=7(@;F5W('!A<W-W
M;W)D(&UU<W0@8F4@9&EF9F5R96YT(&9R;VT@>6]U<B!C=7)R96YT('!A<W-W
M;W)D`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E
M9"!A;'!H86)E=&EC(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!A;'!H86YU;65R:6,@8VAA<F%C=&5R
M<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D
M(&QO=V5R8V%S92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T
M(&-O;G1A:6X@870@;&5A<W0@)60@;G5M97)I8R!C:&%R86-T97)S+@!9;W5R
M(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@=7!P97)C
M87-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I
M;B!A="!L97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T97)S+@!9;W5R
M(&YE=R!P87-S=V]R9"!M=7-T(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA
M<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:`!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!::7!P>0!;
M2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T
M960@5&5X="`M`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L
M971E(%)O=P!?1W)O=7!S`%]);6%G92!0<F]P97)T:65S+BXN`%]-;V1I9GD@
M3&EN:RXN+@!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`8V%L;0!F86QL:6YG`&9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!I;FQI;F4`;&EN97-=`&YA
M;64`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<W1E
M861Y`'1E;7!N86TH*2!F86EL960A`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FT`=6YI9FEE9`!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E
M<G-I;VXZ(%!A<W-W9"!V,BXQ"E!/5"U#<F5A=&EO;BU$871E.B`R,#`T+3`Q
M+3`Y(#`Y.C,W*S`W,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TP,2TP.2`Q
M,SHU-BLP-S`P"DQA<W0M5')A;G-L871O<CH@4VQA;6EN(#QS;&%M:6Y`=6YE
M:BYA8RYI9#X*3&%N9W5A9V4M5&5A;3H@55!4(%1)(%5.14H@/'5P='1I0'5N
M96HN86,N:60^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:70*`"!P861A(``B)7,B('-U9&%H(&1I=&%M8F%H:V%N
M(&ME(&1A;&%M('-I<W1E;2!G<G5P+@`B)7,B('-U9&%H(&1I=&%M8F%H:V%N
M(&ME(&1A;&%M(&EZ:6X@<VES=&5M+@`B)7,B(&)E;'5M(&1I8G5A=#H@)7,N
M`"4N,F9-0B!S=61A:"!D:6=U;F%K86X@9&%R:2`E+C)F34(@>6%N9R!S=61A
M:"!D:6EJ:6YK86X@*"4N,F8E)2D`)60@)7,@9&%N("5S`"5D(&AA<FD@<V%M
M<&%I('-A;F1I(&%N9&$@:&%B:7,@;6%S82!B97)L86MU;GEA+@`E9"UH87)I
M(')A;6%L86X@8W5A8V$`)7,@+2!096UB97)I=&%H=6%N`$MO;F9I<FUA<VD@
M+2!/<&5R87-I(%!E;65L:6AA<F%A;B`E<P`E<R!3971U<``E<R!3>6%R870M
M<WEA<F%T(%!E<FIA;FII86X`)7,@<&%D82`E<R`E<P`E<R!S:6%P('5N='5K
M(&UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;B!Y86YG('-U9&%H
M(&1I=&%N9&%I(&1I(&)A=V%H(&EN:2X@0F5R:6QA:"!T86YD82!P861A(&MO
M=&%K('1E<G-E8G5T('5N='5K(&]P97)A<VD@;6%N87!U;B!Y86YG(&%N9&$@
M:6YG:6YK86X@=6YT=6L@9&EL86MS86YA:V%N('!A9&$@=V%K='4@:6YI+@`E
M<R!M96YI=``E<R!U;G1U:R`E<R`E<P`L(&%N9VEN(&ME;F-A;F<`+"!A;F=I
M;B!K96YC86YG("5S("5S`"P@=F%R:6%B;&4@9&%R:2`E<R!K92`E<P!&;W)M
M870@,3(@2F%M`$9O<FUA="`R-"!*86T`,C0@:F%M`$1A=&%B87-E(&)A8VME
M;F0@9&EP97)L=6MA;B!U;G1U:R!A<F5A(&EN:2X`04T@365N9'5N9P!!32!'
M97)I;6ES`$%-($AU:F%N`$%-($=E<FEM:7,`04T@1V5R:6UI<R!386QJ=0!!
M32]030!496YT86YG(&5D:71O<B!I;FD`5&5N=&%N9RXN+B``2F%R86L@86YT
M87)A(&)A9VEA;B!B87=A:"!B87)I<R!D96YG86X@8F%G:6%N(&)A=V%H(&=A
M;6)A<@!*87)A:R!A;G1A<F$@8F%G:6%N('1E;F=A:"!B87)I<R!D96YG86X@
M8F%G:6%N('1E;F=A:"!G86UB87(`26YF;W)M87-I($%C8V]U;G0`4V%N9&D@
M06-C;W5N=`!!:W5N=&%N<VD`5&%M8F%H`%1A;6)A:"!'<G5P($%N86L`5&%M
M8F%H($1I<VEN:3H`5&%M8F%H($=R=7`@0F%R=0!486UB86@@9W)U<"!A;F%K
M(&ME("<E<R<`5&%M8F%H('!E;F=G=6YA(&)A<G4Z`%1A;6)A:"!A;F=G;W1A
M(&)A<G4`5&%M8F%H('!A<V%N9V%N`%1A;6)A:"!-96YU("5S('-E8F%G86D@
M4&%N96P@;F%V:6=A<VD@36]Z:6QL80!486UB86@@<&5N9V=U;F$`("<E<R<@
M<W5D86@@9&ET86UB86AK86X@:V4@9&%L86T@<VES=&5M+"!T971A<&D@=&ED
M86L@9&%P870@;65N86UB86AK86X@:6YF;W)M87-I('!E;F1A9G1A<F%N('1A
M;6)A:&%N.B`E<RX`("<E<R<@('-U9&%H(&1I=&%M8F%H:V%N(&ME(&1A;&%M
M('-I<W1E;2X@06YD82!D87!A="!L;V<@:6X@<V5K87)A;F<N`%!E;F%M8F%H
M86X@<&5N9V=U;F$@=&ED86L@9&EA:W1I9FMA;BX`0G5K=2!!;&%M870@`$%D
M;6EN:7-T<F%S:0!):VQA;@!2871A`%!E<F%T86%N`%-E;75A`%-E;75A(%!E
M;F=G=6YA($%S;&D`4V5M=6$@1W)U<`!396UU82!E;7!A="!S:7-I`$EZ:6YK
M86X@<&5N9V%T=7)A;B!D87)I('1I<&4@9&%F=&%R(&YO;6]R(&)E<G5R=70_
M`%!E;F=G86YT:2!,;V=I;B!)35-0`%!E;F=G86YT:2!386YD:2!)35-0`%!E
M;F=G86YT:2!.86UA(%!E;F=G=6YA($E-4U``4&5N9V=A;G1I(&%L86UA="!E
M;6%I;`!096YG9V%N=&D@=&5M<&QA=&4`4&5N9V=A;G1I('1E:W,Z`$IA=V%B
M86X`07!L:6MA<VD`1&%F=&%R($%P;&EK87-I`$%P;&EK87-I('-U9&%H('-I
M87`N`$1I9W5N86MA;B!U;G1U:R!"86=I86X@06YA:P!$:7-E='5J=6D`07!R
M:6P`07)A8B`H5VEN9&]W<RTQ,C4V*0!!<&%K86@@86YD82!Y86MI;B!A;F1A
M(&EN9VEN(&UE;6EN9&%H:V%N('!E<FUO:&]N86X@<&5N9&%F=&%R86X@=6YT
M=6L@)7,_`$%P86MA:"!A;F1A('EA:VEN(&%N9&$@:6YG:6X@;65N9VAA<'5S
M("<E<R<@9&%N('-U8BUG<G5P(&UA;F%P=6X_`$%R;65N:6$@*$%235-#24DM
M."D`4V5N:0!+;V1E($%S8VEI`$UE;6EN=&$@:V]N9FER;6%S:2!S96)E;'5M
M(&UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;C\`365N8V]B82!U
M;G1U:R!M96YG:&%P=7,@9W)U<"!Y86YG('1I9&%K(&%D82X`365N8V]B82!U
M;G1U:R!M96YG:&%P=7,@:7II;B!Y86YG('1I9&%K(&%D82X`365N8V]B82!U
M;G1U:R!M96YG=6)A:"!I>FEN('EA;F<@=&ED86L@861A+@!-96YC;V)A('5N
M='5K(&UE;F=U8F%H(&)A9VEA;B!Y86YG('1I9&%K(&%D82X`06=U<W1U<P!+
M;VQO;2!Y86YG('1E<G-E9&EA.@!!;&%S86X@0D]&2`!"86-K96YD('1I9&%K
M(&1I:6UP;&5M96YT87-I:V%N(&1E;F=A;B!B96YA<BX`3&%T87(@0F5L86MA
M;F<`5V%R;F$@3&%T87(@0F5L86MA;F<`0F%L=&EC("A)4T\M.#@U.2TQ,RD`
M1&%S87(@9&ER96MT;W)I(&=R869I:R`G)7,G('1I9&%K(&1I=&5M=6MA;BX`
M2F%R86L@86YT87)A(&)A9VEA;B!B87=A:"!G86UB87(@9&5N9V%N(&=A<FES
M(&1A<V%R(&)A<FES`%!E;F=A='5R86X@07)E80!4:7!E($%R96$`2'5R=68@
M5&5B86P`4&5T=6YJ=6L@:&%L86UA;B!W96(`0F]R9&5R`$ME=&5B86QA;B!"
M;W)D97(`0F]R9&5R`$ME9'5A;GEA`$)A=V%H`$1A9G1A<B!"=6QL970`0TU3
M`%!R;W!E<G1I(%-?96P`2V%L96YD97(`5&5N86YG`%1I9&%K(&1A<&%T(&UE
M;F=A='5R('5L86YG('-A;F1I('-E8V%R82!O=&]M871I<RP@<VEL86MA;B!H
M=6)U;F=I(&%D;6EN:7-T<F%T;W(@86YD82X`0F%T86P`0F%T86QK86X@3&%P
M;W)A;B!-87-A;&%H`$IU9'5L(%1A8F5L`$MA=&5G;W)I(&1A;B!,86)E;`!0
M<F]P97)T:2!396P`2F%R86L@<W!A<VD@9&%R:2!B;W)D97(@9&5N9V%N('1E
M:W,@9&D@9&%L86T@<V5L.@!P<F]P97)T:2!S96P`2F%R86L@<W!A<VD@86YT
M87(@<V5L+@!#96QT:6,@*$E33RTX.#4Y+3$T*0!496YG86@`17)O<&$@5&5N
M9V%H("A)4T\M.#@U.2TR*0!58F%H`%5B86@@4&%S<W=O<F0`56)A:"!386YD
M:2!!;F1A`%5B86@@9&5F875L="!I9&5N=&ET87,`56)A:"!N86UA(&1A;B!A
M;&%M870@<V5H:6YG9V$@;W)A;F<@9&%P870@;65L:6AA=&YY82!K971I:V$@
M;65R96MA(&UE;6)A8V$@9&%N(&UE;6)A;&%S(&ME(&5M86EL(&%N9&$N`%5B
M86@@<&%S<W=O<F0@86YD80!-96YG=6)A:"!087-S=V]R9"!P861A("5S`$UE
M;F=U8F%H('-A;F1I(&%N9&$@=&ED86L@9&ED=6MU;F<@9&5N9V%N(&MO;F9I
M9W5R87-I('EA;F<@<V5K87)A;F<N(%-I;&%K86X@:'5B=6YG:2!A9&UI;FES
M=')A=&]R(&%N9&$N`$MA<F%K=&5R`%!E<FEK<V$@3&EN:RXN+@!#:6YA(%-E
M9&5R:&%N82`H1T(R,S$R*0!#:6YA(%1R861I<VEO;FEL("A":6<U*0!0:6QI
M:"!C87)A('5N='5K(&UE;F%M<&EL:V%N('1A;F=G86PZ`%!I;&EH(&1A9G1A
M<B!T:7!E(&=A>6$@*'5N='5K(&1A9G1A<B!N;VUO<B!B97)U<G5T*0!"97)S
M:6AK86X`0F5R<VEH:V%N('1A9R!-4T]F9FEC90!"97)S:6AK86X@<&5N9V=U
M;F$Z("5S`$)E<G-I:&MA;B!P96YG9W5N80!"97)S:6AK86X@9&%T82!P96YG
M9W5N80!#97)A:"!B96)E<F%P82!S86%T(&QA9VD`2VQI:R!U;G1U:R!,86YJ
M=70`5'5T=7`@2F5N9&5L80!-96YD=6YG`$UE;F1U;F<@9&D@<&%G:2!H87)I
M`$)E<F%W86X`4&5R8F5S87(@4&%N96P@3F%V:6=A<VD@`%!E<F)E<V%R(&)O
M<F1E<@!787)N80!096UI;&EH(%=A<FYA`$MO;&]M`$-O;6EC<P!#;VUM86YD
M`$-O;6UA;F0@4VAE;&P`2V]M<'5T97(`2V]N9&ES:0!+;VYD:7-I`%!E<F)E
M9&%A;B!+;VYF:6=U<F%S:0!+;VYF:6=U<F%S:2!S=61A:"!H86)I<R!M87-A
M(&)E<FQA:W5N>6$N`$UE;F=A='5R("5S`$MO;F9I<FUA<VD@4V%N9&D`2V]N
M9FER;6%S:2!P87-S=V]R9"!B87)U.@!+;VYT86L`3&%N:G5T`$-O;VMI90!3
M86QI;@!386QI;B!0:6QI:&%N`%1I9&%K(&)I<V$@9&EK:7)I;2!K92!S97)V
M97(@;&1A<`!4:61A:R!B:7-A(&MO;F5K<VD@:V4@<V5R=F5R(&QD87``5&ED
M86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B`G)7,G(&1E;F=A;B!M96YG
M9W5N86MA;B!&5%`Z)7,`5&ED86L@9&%P870@;65N9VAA<'5S('-C<FEP="!S
M971U<"!U<&=R861E("<E<R<N(`!4:61A:R!B:7-A(&UE;6)U:V$@<&EP92!K
M92!S;6)P87-S=V0N`%1I9&%K(&1A<&%T(&UE;F=A='5R('5L86YG('5N='5K
M('!E;F=G=6YA('EA;F<@9&EM:6YT82X@0F5B97)A<&$@871A=2!S96UU82!D
M971I;"!T:61A:R!B96YA<BX@0V]B82!L86=I(&%T874@<VEL86MA;B!H=6)U
M;F=I(&%D;6EN:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@;65M97)L=6MA;B!B
M86YT=6%N(&QE8FEH(&QA;FIU="X`5&ED86L@9&%P870@:V5M8F%L:2!K92!K
M;VYF:6=U<F%S:2X`5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I
M("5S+@!4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@8F%C:W5P
M+@!4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@8F%C:W5P.B`E
M<P!4:61A:R!D87!A="!M96YY:6UP86X@<V-R:7!T('-E='5P('5P9W)A9&4@
M:V4Z)R5S)RX`5&ED86L@9&%P870@;65N>6EM<&%N(&9I;&4@:V]N9FEG=7)A
M<VD@8F%C:W5P("5S+@!4:61A:R!D87!A="!M96YY:6UP86X@9FEL92!K;VYF
M:6=U<F%S:2`E<RX@06YD82!D87!A="!M96YG9W5N86MA;B!S86QA:"!S871U
M(&1A<FD@<&EL:6AA;B!U;G1U:R!M96YY:6UP86X@:V]D92!T97)S96)U="!K
M96UB86QI(&ME("5S(&%T875P=6X@;65N>6%L:6X@:V]D92!D:2!B87=A:"!I
M;FD@<V5C87)A(&UA;G5A;"!K92`E<RX`5&ED86L@9&%P870@;65N=6QI<R!K
M;VYF:6=U<F%S:2!U;G1U:R`G)7,G.B`E<P!4:61A:R!D87!A="!M96YE;75K
M86X@4&%N96P@3F%V:6=A<VD@36]Z:6QL82X@4&%S=&EK86X@<&%N96P@;F%V
M:6=A<VD@<W5D86@@=&5R8G5K82X`2W5R<W5S`$)U870`0G5A="!L:6YK`$)U
M870@8F%R=0!&87-E(%-E:V%R86YG`%=A:W1U(%-E:V%R86YG`%523"!396MA
M<F%N9R!A9&%L86@`0W5A8V$@4V5K87)A;F<`2V]N9&ES:2!396MA<F%N9SH`
M1V%Y82!396MA<F%N9P!+;W-T=6UI<V%S:2!T=6=A<R!U;G1U:R!D:6IA;&%N
M:V%N('-E8F5L=6T@;&]G;VX@:V4@)7,N`$AA<'5S`$AA<'5S('!I;&EH86X`
M0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A=&%4<F5E($)R;W=S97(`
M5&%N9V=A;"!$:71E<FEM80!(87)I`$AA<'5S($MO;&]M`$1E<V5M8F5R`$%N
M9VMA($1E<VEM86P`365N9W5R86YG:2!);F1E;@!$969A=6QT`$1E9F%U;'0@
M5V%R;F$`1&5F875L="!3:&5L;`!$969I;FES:0!(87!U<P!(87!U<R!396P`
M2&%P=7,@1W)U<`!(87!U<R!S96P`2&%P=7,@:V]L;VT`2&%P=7,@<&5N9V=A
M;G1I('1E;7!L871E('EA;F<@<W5D86@@861A`$AA<'5S(&)A<FES`$AA<'5S
M(&ED96YT:71A<R!Y86YG('1E<G!I;&EH`$AA<'5S(&MO;&]M('EA;F<@<V5K
M87)A;F<`2&%P=7,@8F%R:7,@>6%N9R!S96MA<F%N9P!(87!U<R!S8W)I<'0@
M<V5T=7`@=7!G<F%D92`G)7,G+@!*96QA<VMA;B!-87-A;&%H`$1E<VMR:7!S
M:0!097)K96UB86YG86X`5&ET:6L@16UB=6X`5&ET:6L@16UB=6X@=6YT=6L@
M:F%M('1E<F%K:&ER.@!4:71I:R!%;6)U;@!!<F%H(&MI<FD@:V4@:V%N86X`
M07)A:"!K86YA;B!K92!K:7)I`$1I<F5K=&]R:0!486UP:6QK86X@=V%K='4@
M,C0@:F%M/P!486UP:6QK86X@4&EL:6AA;@!486UP:6QK86X@9&5T:6P@<F%M
M86QA;B!C=6%C80!486UP:6QK86X@<F%M86QA;B!C=6%C82`H5$%&*0!*86YG
M86X@;&%N9W-U;F<@;65N9V%K<V5S(&UA:6YT96YA;F-E+G!H<`!!<&%K86@@
M8F%R:7,@>6%N9R!P97)T86UA('1E<F1I<FD@9&%R:2!K;VQO;2!N86UA/R!J
M:6MA('EA+"!B97)I('1A;F1A('!A9&$@:V]T86L@:6YI.@!4:61A:R!M96UI
M;&EK:2!A8V-O=6YT/R!3:6QA:V%N(&UE;F1A9G1A<BX`1&]W;FQO860@:V]N
M9FEG=7)A<VD@>6%N9R!D:6AA<VEL:V%N('-E8F%G86D@<V-R:7!T(%!(4"X`
M3V)A="UO8F%T86X`56)A:`!58F%H($)L;VMI<@!58F%H($=R=7``56)A:"!)
M>FEN`%5B86@@27II;B!U;G1U:R`E<P!58F%H('!I;&EH86X@=6YT=6LZ`%5B
M86@@:7II;B!U;G1U:R`E<P!096YD:61I:V%N`$5L96UE;BXN+@!%;0!!;&%M
M870@16UA:6P`06MT:69K86X@<&5N>6ES:7!A;B!G86UB87(M9V%M8F%R(&1A
M<FD@1V%L97)I($9O=&\@9&D@9&%L86T@=&5K<S\`06MT:69K86X@:VQI:R!K
M86YA;B!M96YU(&MO;G1E:W,_`%!E<F)E<V%R($5D:71O<@!-87-U:VMA;B!P
M97)T86YY86%N(&ME86UA;F%N(&1I;6%N82!A;F1A(&%K86X@9&ET86YY86MA
M;B!A<&%B:6QA(&%N9&$@<&5R;'4@=6YT=6L@;65N9V%T=7(@=6QA;F<@<V%N
M9&D@86YD82P@(&-O;G1O:"`G87!A:V%H(&YA;6$@8FEN871A;F<@:V5S87EA
M;F=A;B!A;F1A/R<Z`$UA<W5K:V%N(%523"!G86UB87(@9&ES:6YI`$ME<V%L
M86AA;@!+97-A;&%H86X@;65N9VER:6T@9&%T82!K92!S;6)P87-S=V0N`$ME
M<V%L86AA;B!S86%T(&UE;7!E<F)A:&%R=6D@<V%N9&DZ("5S`%-U:W4`4V5T
M:6%P(#$U(&UE;FET`%-E=&EA<"`R(&UE;FET`%-E=&EA<"`S,"!D971I:P!3
M971I87`@-2!M96YI=`!3971I87`@<V5T96YG86@@:F%M`%-E=&EA<"!M96YI
M=`!#;VYT;V@@;FEL86DM;FEL86DZ`$IA;&%N:V%N`%!E<F)E<V%R(%!A;F5L
M($YA=FEG87-I`%=A<FYA($9'`$944"!U<&QO860@=6YT=6L@<V5T=7``1V%G
M86P@;65N9W5B86@@<&%S<W=O<F0@.B``0V5R86@`1F%X`$9E8G)U87)I`%-E
M<&5R=&D`4V5P97)T:3H`1V5R:6UI<R!396)A9VEA;@!'97)I;6ES(%-A;&IU
M(%-E8F%G:6%N`$9I;&4@36%N86=E<@!&:6QT97(`1F%S92!P97)T86UA(&1A
M<FD@4V5P87)U:"!"=6QA;@!&87-E('!E<G1A;6$@9&%R:2!397!A<G5H($)U
M;&%N`$9L;V%T`$)E<FMA8G5T`%=A<FYA(%1U;&ES86X`36%K86YA;@!5;G1U
M:R!B<F]W<V5R('EA;F<@=&ED86L@9&%P870@;65N9'5K=6YG(&=A;6)A<@!2
M86UA;&%N(&-U86-A("A4048I`$AA<FD@4F%M86QA;B!#=6%C82`H8V%T871A
M;B!B86AW82!R86UA;&%N(&-U86-A('EA;F<@9&EK96UB86QI:V%N(&%K86X@
M;65N9V5M8F%L:6MA;B!B86EK('-I86YG(&%T874@;6%L86T@:&%R:2P@<V5J
M=6UL86@@86YG:V$@9&%P870@9&EH87-I;&MA;B!P861A(&%R96$@:6YI*0!,
M=7!A(&1E;F=A;B!S86YD:2!A;F1A/P!&;W)M=6QI<@!286UA;&%N`%1I<&4@
M4F%M86QA;@!286UA;&%N`%)A;6%L86X@,@!&;W)U;0!$:71E<G5S:V%N`$IM
M=`!&<F%M90!$87)I`$1E<VMR:7!S:2!,96YG:V%P`$)U;&%N(%!U<FYA;6$`
M3F%M82!,96YG:V%P`$=A;&5R:2!U;G1U:R!M96YG86UB:6P@9V%M8F%R(&1A
M<FD`1V%L97)I`$UE;F=H87-I;&MA;B`E<R!+;VYF:6=U<F%S:2``2V]D92!Y
M86YG(&1I:&%S:6QK86X`2F%L86YK86X`1V]E9&5L`%!E;F-A<FEA;B!';V]G
M;&4`675N86YI("A)4T\M.#@U.2TW*0!!9&UI;FES=')A<VD@1W)U<`!'<G5P
M`$EZ:6X@=&%M=0!"=6MU('1A;74`2%1-3$%R96$@9&5N9V%N(')A9W4@;65N
M;VQA:R!U;G1U:R!M96YG:&%P=7,@<V5L('EA;F<@=&5R86MH:7(@9&D@9&%L
M86T@8F%R:7,N`$A434Q!<F5A(&1E;F=A;B!R86=U(&UE;F]L86L@=6YT=6L@
M;65N9VAA<'5S(&MO;&]M('EA;F<@=&5R86MH:7(@9&D@9&%L86T@=&%B96PN
M`$A434Q!<F5A(&1E;F=A;B!R86=U(&UE;F]L86L@=6YT=6L@;65N9VAA<'5S
M(&)A<FES('EA;F<@=&5R86MH:7(@9&D@9&%L86T@=&%B96PN`$)E<FMA8G5T
M`%EA:'5D:2`H25-/+3@X-3DM."U)*0!4:6YG9VD`0F%N='5A;@!"86YT=6%N
M(&UE;F=G=6YA:V%N(&5D:71O<@!"96QA:&%N($)U;6D`26YI(&%D86QA:"!P
M97)M=6QA86X@9&%R:2!F:6QE.@!4:6YG9VD`2&]?;64`1&ER96MT;W)I($AO
M;64`2&]R9&4`1V%R:7,@2&]R:7-O;G1A;"!D:2!D86QA;2!(5$U,`$IA<F%K
M(&=A<FES(&AO<FEZ;VYT86P@9&%R:2!B;W)D97(@9&5N9V%N('1E:W,@9&D@
M9&%L86T@<V5L`$AO<FEZ;VYT86PZ`$)A9V%I;6%N82!C87)A(&%N9&$@8FES
M82!S86UP86D@9&ES:6YI/R`H4VEL86MA;B!M96QA<&]R(2D`0F5R87!A(&)A
M;GEA:R!K;VQO;2!Y86YG(&EN9VEN(&%N9&$@9V%B=6YG:V%N/P!"97)A<&$@
M8F%N>6%K(&MO;&]M('EA;F<@861A(&1I<V%N83\`0F5R87!A(&)A;GEA:R!B
M87)I<R!Y86YG(&EN9VEN(&%N9&$@9V%B=6YG:V%N/P!+96QE;6)A8F%N`$ME
M;&5M8F%B86XZ`%!E;&%W86L`36%S=6MK86X@0F%R:7,@4V5B96QU;6YY80!(
M86YY82!I:V]N`$EK;VX@=6YT=6L@)7,`26MO;B!D96YG86X@=&5K<P!.86UA
M($ED96YT:71A<SH`2FEK82!A;F1A('1I9&%K(&UE;&EH870@:6MO;B!M86YA
M<'5N(&1E;F=A;B!M96YG9W5N86MA;B!);G1E<FYE="!%>'!L;W)E<BP@86YD
M82!M=6YG:VEN('!E<FQU('5N='5K(&UE;F%N9&%I(&MO=&%K(&EN:2!U;G1U
M:R!M96YO;BUA:W1I9FMA;B!K96QE;6%H86X@4$Y'+@!,:6AA="!'86UB87(Z
M`%523"!'86UB87(`55),($=A;6)A<CH`1V%M8F%R(&1A<FD@9V%L97)I`$=A
M;6)A<B!D87)I(&=A;&5R:3H`1V%M8F%R+6=A;6)A<@!);7!O<BP@3&%N9VMA
M:"`E9`!+;VQO;2!Y86YG(&1I:6UP;W(Z("5S`$MO;&]M('EA;F<@9&EI;7!O
M<CH`36%S=6MK86X@0F%R:7,@0F5R:6MU=&YY80!087-S=V]R9"!386QA:`!.
M86UA('!E;F=G=6YA(&%T874@86QA;6%T(&5M86EL('!E;F=G86YT:2!T:61A
M:R!B96YA<BX@0V]B82!L86=I(&%T874@<VEL86MA;B!H=6)U;F=I(&%D;6EN
M:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@;65M97)L=6MA;B!B86YT=6%N(&QE
M8FEH(&QA;FIU="X`365N86UB86@@26YD96X`4&5N9V=U;F$@4')I8F%D:0!)
M;F9O<FUA<VD`26YF;W)M87-I('-U9&%H('1I9&%K(&1I<V5D:6%K86XN`$UA
M<W5K:V%N($MO;&]M($)E<FEK=71N>6$`36%S=6MK86X@1V%M8F%R`$UA<W5K
M:V%N(%1A8F5L`$UA<W5K:V%N(%=E8B!,:6YK`$UA<W5K:V%N($MO;&]M(%-E
M8F5L=6UN>6$`36%S=6MK86X@:V]L;VT@>6%N9R!B87)U('-E=&5L86@@:V]L
M;VT@>6%N9R!S96MA<F%N9P!-87-U:VMA;B!K;VQO;2!Y86YG(&)A<G4@<V5B
M96QU;2!K;VQO;2!Y86YG('-E:V%R86YG`$UA<W5K:V%N(&)A<FES('EA;F<@
M8F%R=2!S971E;&%H(&)A<FES('EA;F<@<V5K87)A;F<`36%S=6MK86X@8F%R
M:7,@>6%N9R!B87)U('-E8F5L=6T@:V]L;VT@>6%N9R!S96MA<F%N9P!-87-U
M:VMA;B!P87)A9W)A9B!S971E;&%H('!A<F%G<F%F('EA;F<@<V5K87)A;F<`
M36%S=6MK86X@<&%R86=R868@<V5B96QU;2!P87)A9W)A9B!Y86YG('-E:V%R
M86YG`$UA<W5K:V%N('1E;7!L871E('!E;F=G86YT:0!-87-U:VMA;B!A;&%M
M870@96UA:6P@9&EM86YA(&%N9&$@9&%P870@;65N97)I;6$@<V%N9&D@>6%N
M9R!B87)U.@!-87-U:VMA;B!S96P@8F5R:6MU=&YY80!-87-U:VMA;B!S96P@
M<V5B96QU;6YY80!-87-U:VMA;B!K;VQO;2!B97)I:W5T;GEA`$UA<W5K:V%N
M(&MO;&]M('-E8F5L=6UN>6$`36%S=6MK86X@<&%R86=R868@8F5R:6MU=&YY
M80!-87-U:VMA;B!P87)A9W)A9B!S96)E;'5M;GEA`$UA<W5K:V%N(&)A<FES
M(&)E<FEK=71N>6$`36%S=6MK86X@8F%R:7,@<V5B96QU;6YY80!-87-U:VMA
M;B!J87=A8F%N('EA;F<@9&EP97)L=6MA;B!U;G1U:R!P97)T86YY86%A;B!K
M96%M86YA;CH`36%S=6MK86XO56)A:"!'86UB87(`36%S=6MK86XO56)A:"!,
M:6YK`$%P;&EK87-I('1I9&%K('9A;&ED+@!)>FEN(&EN9'5K('1I9&%K('9A
M;&ED+@!);G9E;G1O<FES`$AU:F%N('!E=&ER(&1I<V5R=&%I(&%N9VEN(')I
M8G5T(&1I(&1A97)A:"!Y86YG('1E<G!E;F-I;`!(=7)U9B!-:7)I;F<`2F%N
M=6%R:0!*97!A;F<@*$E33RTR,#(R+4I0*0!*=6QI`$IU;FD`4F%T80!2871A
M(%1E;F=A:`!2871A($MI<FD@9&%N($MA;F%N`%)A=&$@2VER:0!2871A($MA
M;F%N`$ME<FYE;"!.97=B:65S`$%N86LM86YA:P!+;W)E82`H155#+4M2*0!4
M86UP:6QA;@!"86AA<V$`1F%S92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L
M86X`4&5R=6)A:&%N(%-A;F1I(%1E<F%K:&ER`$9A<V4@=&5R86MH:7(@9&%R
M:2!397!A<G5H($)U;&%N`%!E<G5B86AA;B!497)A:VER.@!(=6MU;0!486UP
M:6QA;@!4:6YG9V%L:V%N(&MO<V]N9R!T86YP82!B;W)D97(`2VER:0!'97)I
M;6ES`$=E<FEM:7,`1V5R:6UI<R!D:2!P86=I(&AA<FD`1V5R:6UI<R!B96)E
M<F%P82!S86%T(&QA9VD`1V5R:6UI<P!'97)I;6ES(&1I<V5R=&%I('!E=&ER
M`$)E<G-A;&IU`$=E<FEM:7,@4V%L:G4`4&%N='5N($IE;F%K80!,:6YK(&UE
M;G5N:G5K(&ME.@!,:6YU>"!#;V]K:64`1&%F=&%R($1A=&%B87-E`$1A9G1A
M<B!4;W!I:R!"86YT=6%N`$1A9G1A<B!486)E;`!$869T87(@<&5N9V=U;F$@
M9&EN;VXM86MT:69K86XN`$1A9G1A<B!"86-A86X`5V%K='4@;&]C86PZ`%1E
M;7!A="!097)I<W1I=V$@9&%N(%=A:W1U`$QO:V%S:0!,;V=I;@!,;V<@;W5T
M`$QO9VEN`%1U9V%S($QO9VEN`$ME;'5A<@!#:6YT80!296YD86@`4VEM8F]L
M($AU<G5F(&ME8VEL('EU;F%N:0!3:6UB;VP@2'5R=68@:V5C:6P@;&%T:6X`
M4VEM8F]L($AU<G5F(&ME8VEL(')O;6%W:0!-30!-3U1$`%-U;&%P`%-U<F%T
M`%-U<F%T($%D;6EN`$)U870@;&EN:RXN+@!-96YG871U<B!D869T87(@:V%T
M96=O<FD@>6%N9R!H87)U<R!D:6)E<FD@;&%B96P@:71E;2P@9&%N('=A<FYA
M('EA;F<@8F5R:'5B=6YG86X@(&1E;F=A;B!K871E9V]R:2!T97)S96)U="X`
M36%R970`36%R9VEN`$UE;F-O8V]K:V%N(&MO;&]M`"!3=6AU(&UA:W-I;75M
M('EA;F<@8F5R;&%N9W-U;F<@<V5L86UA(#(T(&IA;3H`4W5H=2!M86MS:6UU
M;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`V(&IA;3H`2G5M;&%H(&UA:W-I
M;75M(&1A<FD@<&]R=&%L('EA;F<@9&EB;&]K:7(`365I`$]B870M;V)A=&%N
M`$%N9V=O=&$`365N=2!M;V1E.@!'86)U;F=K86X@<V5L`%!E<V%N`"!#=6%C
M82!-971A<@!!<F5A($UE=&%R('1I9&%K(&1I<V5D:6%K86XN`$%R96$@365T
M87(@=&ED86L@9&ES961I86MA;BX@1&5T:6P@=&5L86@@9&EC871A="!U;G1U
M:R!A9&UI;FES=')A=&]R+@!-971R:6L`5&5N9V%H`%-U:'4@;6EN:6UU;2!Y
M86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ`%-U:'4@;6EN:6UU;2!Y
M86YG(&)E<FQA;F=S=6YG('-E;&%M82`V(&IA;3H`3&%I;BUL86EN`$MO;F9I
M9W5R87-I('1I9&%K(&1I=&5M=6MA;BX@06YD82!H87)U<R!M96YG:&%S:6MA
M;B!K;VYF:6=U<F%S:2!S96MA<F%N9R!J:6MA(&%N9&$@:6YG:6X@;65N9V=U
M;F%K86X@87!L:6MA<VD@:6YI+@!396X`36]B:6QE($UA:6P`4V5D86YG`%5B
M86@@55),`$9A<V4@0G5L86X`4V5B86=I86X@8F5S87(@0V5R86@`4V5B86=I
M86X@8F5S87(@0F5R87=A;@!396)A9VEA;B!B97-A<B!#97)A:`!!8V-O=6YT
M+6MU`$EN9F]R;6%S:2!!8V-O=6YT+6MU`%!O<G1A;&MU`%1A;7!I;&%N(%!O
M<G1A;&MU`%1)1$%++"!387EA(%1)1$%+(%-E='5J=0!.971W;W)K`%1I9&%K
M('!E<FYA:`!+871E9V]R:2!"87)U`$)U;&%N($)A<G4`3F%M82!096YG9W5N
M82!"87)U("AP:6QI:&%N*0!386YD:2!"87)U`%!A<W-W;W)D(&)A<G4Z`%-A
M;F1I(&)A<G4@=&ED86L@8V]C;VLN`%=I;F1O=R!"87)U("A?8FQA;FLI`$)E
M<FET80!'<G5P($)E<FET80!"97)I:W5T;GEA`$9A<V4@0F5R:6MU=&YY80!-
M86QA;0!4:61A:R!A9&$@9&%T82!K;VYF:6=U<F%S:2!Y86YG('1E<G-E9&EA
M('5N='5K(&UE;G5N:G5K:V%N('!E<F)E9&%A;B!U;G1U:RX`5&ED86L@861A
M('!E<G5B86AA;BX`5&ED86L@861A(&EK;VX@>6%N9R!D:71E;75K86XN`%1I
M9&%K(&%D82!L;VMA<VD@>6%N9R!D:6%T=7(N`%1I9&%K(&%D82!R86UA;&%N
M('EA;F<@=&ED86L@<V]P86X`5&ED86L@861A('!E;F1A9G1A<F%N('EA;F<@
M9&ET=6YD82X`5&ED86L@861A(&%T=7)A;@!4:61A:R!A9&$@<VES:0!4:61A
M:R!A9&$@9&ER96MT;W)I('-E;65N=&%R82!Y86YG('1E<G-E9&EA('5N='5K
M(&-A8VAE`%1I9&%K(&%D82!V97)S:2!Y86YG(&1I=&5M=6MA;B!D:2!D86QA
M;2!K;VYF:6=U<F%S:2!Y86YG(&%S;&DN($UE;F=H87-I;&MA;B!K;VYF:6=U
M<F%S:2!K96UB86QI+@!4:61A:R!A9&$@=F5R<VD@>6%N9R!D:71E;75K86X@
M9&D@9&%L86T@:V]N9FEG=7)A<VD@86YD82X@365N9VAA<VEL:V%N(&MO;F9I
M9W5R87-I(&ME;6)A;&DN`%1I9&%K(&%D80!4:61A:R!A9&$@*&1I9W5N86MA
M;B!S96QE;F=K87!N>6$I`%-C86YD:6YA=FEA("A)4T\M.#@U.2TQ,"D`0F5L
M86AA;B!"=6UI(%5T87)A`$)E;'5M(&1I871U<@!#871A=&%N`%1I9&%K(&%D
M82!Y86YG(&1A<&%T(&1I8G)O=W-E+"!S:6QA:V%N(&ME;6)A;&DN`$YO=F5M
M8F5R`$IU;6QA:"!K;VQO;0!*=6UL86@@8F%R:7,`3TL`4&5N8VEP=&$@3V)J
M96L`3VMT;V)E<@!&:6QT97(@4&5L86YG9V%R86X`2V%N=&]R`%-A;F1I(&QA
M;6$@9&%N(&)A<G4@:&%R=7,@8F5R8F5D82X`4V%N9&D@;&%M80!386YD:2!L
M86UA('1I9&%K(&)E;F%R+@!087-S=V]R9"!L86UA.@!(86YY82!R86UA;&%N
M('EA;F<@=&ED86L@<V]P86X`2&%N>6$@<&5M:6QI:R!A=&%U('-I<W1E;2!A
M9&UI;FES=')A=&]R('-A:F$@>6%N9R!D87!A="!M96YG=6)A:"!K97!E;6EL
M:6MA;B!A=&%U('!E;6EL:6L@:7II;B!U;G1U:R!B86=I86X`0G5K82!D:2!J
M96YD96QA('EA;F<@8F%R=0!"=6MA(&QI;FL@:6YI(&1I(&IE;F1E;&$@>6%N
M9R!B87)U`%-I<W1E;2!/<&5R87-I`%!I;&EH86X`4&EL:6AA;B!U;G1U:R`E
M<P!$869T87(@3F]M;W(@0F5R=7)U=`!-96YG871U<@!!<&QI:V%S:2!T96UP
M;&%T92!A<VQI`%1E;7!L871E(&%S;&D@9&D@9&%L86T@)7,Z`$QA:6XM;&%I
M;@!);F9O<FUA<VD@3&%I;@!)>FEN(%!E;6EL:6L`2V]D92!02%``4$A0(%-H
M96QL`%!-($=E<FEM:7,`4$T@1V5R:6UI<P!032!"97)S86QJ=0!032!'97)I
M;6ES(%-A;&IU`%!-($-E<F%H`%!-($AU:F%N('!E=&ER(&1I<V5R=&%I(&1E
M;F=A;B!A;F=I;B!R:6)U=`!%:W-T96YS:2!03U-)6"!T:61A:R!D:71E;75K
M86X`4$A0(%-H96QL`$IA<F%K('-P87-I(&1A<FD@8F]R9&5R`%-E8F%G:6%N
M($)E<F%W86X`4V%N9&D`4V%N9&D@8F5R:&%S:6P@9&EU8F%H+@!087-S=V]R
M9"!B97)U8F%H(0!-;V1U;"!P87-S=V]R9"!T:61A:R!D:6MO;F9I9W5R87-I
M(&1E;F=A;B!S96UP=7)N80!386YD:3H`4V%N9&DZ`%-A;F1I(&AA<G5S(&-O
M8V]K+@!386QI;@!,96MA=&MA;B!D87)I(&-L:7!B;V%R9`!0871H`%!E;F1A
M9G1A<F%N('EA;F<@9&ET=6YD83H`3W)A;F<`4&5R<V5N`$UE;&%K<V%N86MA
M;B!/<&5R87-I(%!E;65L:6AA<F%A;@!-96QA:W-A;F%K86X@;W!E<F%S:2!P
M96UE;&EH87)A86X@<&%D82!W86MT=2!L;V=I;C\`27II;B!U;G1U:R`B)7,B
M('1I9&%K(&1A<&%T(&1I:&%P=7,N`$EZ:6X@061M:6YI<W1R87-I`$EN9F]R
M;6%S:2!0<FEB861I`$)I;F%T86YG($ME<V%Y86YG86X`1F]T;P!0:7AE;`!+
M871A+6MA=&$@:VQI<V4`4VEL86MA;B!K;&EK(&ME(&1A;&%M(&)E8F5R87!A
M('-E;`!3:6QA:V%N(&MO;F9I<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96UI
M;F1A:&MA;B!E;&5M96X@:6YI.@!3:6QA:V%N(&MO;F9I<FUA<VD@8F%H=V$@
M86YD82!I;F=I;B!M96YG:&%P=7,@;&EN:R!U;G1U:R!E;&5M96X@:6YI+@!3
M:6QA:V%N(&UA<W5K:V%N(&YA;6$@=6YT=6L@:V%T96=O<FD@>6%N9R!B87)U
M.@!3:6QA:V%N(&UA<W5K:V%N(')I;F=K87-A;B!U;G1U:R!M87-A;&%H+@!3
M:6QA:V%N(&UA<W5K:V%N(&YA;6$@<&5N9V=U;F$@9&%N('-A;F1I(&%N9&$`
M4VEL86MA;B!M96UB86-A('1E:W,@8F5R:6MU="!I;FDN($%N9&$@2$%255,@
M<V5T=6IU(&1E;F=A;B!S>6%R870M<WEA<F%T('5N='5K(&UE;F=G=6YA:V%N
M('-I<W1E;2X`4&]L:71I:P!0;VQL:6YG`%!O<VES:2!U;G1U:R!G86UB87(@
M:6YI`%!O<VES:2!U;G1U:R!T86)E;"!I;FD`2'5J86X@<V%L:G4@=6YT=6L@
M)7,@:F%M('1E<F%K:&ER.@!+96UU;F=K:6YA;B`\8G(O/DAU:F%N('-A;&IU
M`%1E:V%N86X`5&5K86YA;B!P861A('!E<FUU:V%A;B!L875T.@!496MA;F%N
M.@!,:6AA=`!,:6AA="!G86UB87(@9&D@9&%L86T@:F5N9&5L82!Y86YG(&)A
M<G4`0V5T86L@9&]K=6UE;@!$97-K<FEP<VD@36%S86QA:`!-87-A;&%H/P!0
M<F]J96L`475E<GD`2W5O=&$`2'5J86X`2'5J86X@9&D@<&%G:2!H87)I`$AU
M:F%N(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$AU:F%N(&1A;B!"97)S
M86QJ=0!(=6IA;B!B97)C86UP=7(@9&5N9V%N('-A;&IU`%)A;6%L86X@06-A
M:P!"86-A`%EA:VEN('5N='5K(&UE;F=H87!U<R`E<S\@3W!E<F%S:2!I;FD@
M=&ED86L@9&%P870@9&EB871A;&MA;BX`66%K:6X@=6YT=6L@;65M:6YD86AK
M86X@9&%T82!P96YG9W5N82!U;G1U:R!P96YG9W5N82`E<S\@3W!E<F%S:2!I
M;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`56QA;F=I(&%K<VD@=&5R86MH
M:7(@86YD80!2969R97-H($5L96UE;B!-96YU($1I;F%M:7,Z`%)E9G)E<V@@
M3&EH870@4&]R=&%L.@!$:71A;F1A:0!296UO=&4@4V5R=F5R`%)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I`%!I;F1A:&MA;@!0
M:6YD86AK86X@0FQO:VER`%!I;F1A:&MA;B!#87)A($9O<FUA=`!0:6YD86AK
M86X@<&%S86YG86X`4&EN9&%H:V%N('-C<FEP="!Y86YG('-U9&%H(&1I<VEM
M<&%N(&1A<FD@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A<F$N`%!I;F1A:&MA
M;@!0:6YD86AK86X@;F]D92!I;FD@9&%R:2!D;VMU;65N`%!I;F1A:&MA;B!P
M96YG9W5N80!0:6YD86AK86X@<&5N9V=U;F$Z("5S`"=P:'!T>7!E)R!Y86YG
M(&1I<&5R;'5K86X@=&ED86L@9&ES<&5S:69I:V%S:2!P861A(&MO;F9I9W5R
M87-I(%-13"X`4F5S970`071U<B!K96UB86QI(%-A;F1I`$%T=7(@:V5M8F%L
M:2!386YD:2!!;F1A`$AA<VEL`$ME;6)A;&D@:V4@4&EL:6AA;@!+971I:R!U
M;&%N9R!S86YD:2!B87)U`$ME;6)A;&D@:V4@2V]N9FEG=7)A<VD`4&EL:6AA
M;B!%9&ET;W(@4FEC:"!497AT`%1E:V$M=&5K:0!+86YA;@!0<F]P97)T:2!"
M87)I<RXN+@!0<F]P97)T:2!"87)I<P!0<F]P97)T:2!B87)I<P!"87)I<SH`
M071U<F%N`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&1I86YT87)A('-E;75A
M(&)A<FES(&1A;B!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY
M82!D:6%N=&%R82!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY
M82!D:6%N=&%R82!B87)I<P!*86QA;FMA;@!097-A;B!335,`4U%,(%-H96QL
M`%-32`!37U%,(%-H96QL`%-B=`!&<F%M92!Y86YG('-A;6$@*%]S96QF*0!3
M:6UP86X`4VEM<&%N("5S`%-I;7!A;B`G)7,G`%-I;7!A;B!0:6QI:&%N`%-I
M;7!A;B!K;VYF:6=U<F%S:2!Y86YG(&1I:&%S:6QK86X@<V5B86=A:2!S8W)I
M<'0@4$A0(&ME(&1A;&%M(&1I<F5K=&]R:2!S97)V97(@<V5M96YT87)A(&%N
M9&$N`$MO;F9I9W5R87-I("5S('-U9&%H(&1I<VEM<&%N+@!38W)I<'0@<V5T
M=7`@=7!G<F%D92!S=61A:"!D:7-I;7!A;B!K93H@)R5S)RX`4V5B86=I86X@
M2'5J86X@<&5T:7(@9&ES97)T86D@86YG:6X@<FEB=70`26QM=2!096YG971A
M:'5A;@!096YC87)I86X`365S:6X@4&5N8V%R:6%N`%!I;&EH(&=R=7`@=6YT
M=6L@9&ET86UB86@`4&EL:6@@<&5M:6QI:R!B87)U`%!I;&EH('-E<G9E<@!0
M:6QI:"!P96YG9W5N82!U;G1U:R!D:71A;6)A:`!0:6QI:"!K87)A:W1E<B!Y
M86YG(&%N9&$@<&5R;'5K86X@9&%R:2!K;W1A:RUK;W1A:R!D:6)A=V%H(&EN
M:2X@06YD82!D87!A="!M96YY86QI;B!D86X@;65L96MA=&MA;FYY82!K92!D
M86QA;2!A<F5A('1E:W,N`%!I;&EH(&)A=&%S('1A;F=G86PZ`%!I;&EH(&9O
M<FUA="!T86YG9V%L.@!0:6QI:"!I9&5N=&ET87,@>6%N9R!I;F=I;B!D:75B
M86@@;VQE:"!A;F1A.@!0:6QI:"!B871A<R!W86MT=3H`4&EL:6@@9F]R;6%T
M('=A:W1U.@!0:6QI:"!D=6$@:V]L;VT@>6%N9R!C;V-O:RX`4&EL:6@@=V%R
M;F$@<V-H96UE(&%N9&$N`%!I;&EH(&)A:&%S82!Y86YG(&%N9&$@:6YG:6YK
M86XZ`$MI<FEM($QA<&]R86X@36%S86QA:`!396YS;W(Z`%-E<'1E;6)E<@!3
M97)V97(`071U<B!P:6QI:&%N('5N='5K(&UE;F=I>FEN:V%N(&%N9&$@9&%P
M870@;65N9V%T=7(@=6QA;F<@:V5M8F%L:2!S86YD:2!A;F1A(&%P86)I;&$@
M86YD82!L=7!A+@!!='5R(')E;6]T92!S97)V97(@>6%N9R!I;F=I;B!A;F1A
M(&%K<V5S(&1A<FD@<&]R=&%L(&%N9&$N`$%T=7(@8F%H87-A+"!Z;VYA('=A
M:W1U(&1A;B!P:6QI:&%N('1A;F=G86PL('EA;F<@86YD82!I;F=I;FMA;BX`
M071U<B!A<&QI:V%S:2!A=V%L(&%N9&$L('=A<FYA('-C:&5M92P@:&%L86UA
M;B!R969R97-H(&1A;B!P:6QI:&%N('1A;7!I;&%N(&QA:6YN>6$N`%-E='5P
M`%-C<FEP="!S971U<"!U<&=R861E('1E<G-E9&EA`$)E8F5R87!A(&QO:V%S
M:2!Y86YG(&UU;F=K:6X@9&5N9V%N('!A<F%M971E<CH`0F5L86YJ80!2:6YG
M:V%S86X@4&5N9&5K`%!E<FQU:V%H(&MU;F-I(&%K<V5S(&1I9&5F:6YI<VEK
M86X@=6YT=6L@:V5B86YY86MA;B!L:6YK/P!486UP:6QK86X`5&%M<&EL:V%N
M('!E<F)E9&%A;B!D:6%N=&%R82!K;VYF:6=U<F%S:2!Y86YG(&)A<G4@9&ES
M:6UP86X@9&%N('EA;F<@8F%R=2!D:6AA<VEL:V%N+@!486UP:6QK86X@=V%K
M='4@;&]G:6X@=&5R86MH:7(@:V5T:6MA(&%N9&$@;&]G:6X_`%1A;7!I;&MA
M;B!P86YE;"!M96YU('1A8F5L(&]P97)A<VD_`%1A;7!I;&MA;B!-96YU("5S
M(&1I('-E8F5L86@@:VER:3\`5&%M<&EL:V%N(&1I86QO9R!0<F]P97)T:2!3
M96P@5&%B96P`5&%M<&EL:V%N(&1I86QO9R!0<F]P97)T:2!486)E;`!486UP
M:6QK86X@9&EA;&]G(%!R;W!E<G1I($)A<FES(%1A8F5L`%1A;7!I;&MA;B!D
M:6%L;V<@<')O<&5R=&D@9V%M8F%R`$=E<FEM:7,`1V5R:6UI<R!D:2!P86=I
M(&AA<FD`1V5R:6UI<R!B96)E<F%P82!S86%T(&QA9VD`1V5R:6UI<R!D:2!S
M96MI=&%R(&1A97)A:`!,97=A=&D@4&5M96QI:&%R86%N`%-A;&IU`$=E<FEM
M:7,@4V%L:G4`1V5R:6UI<R!386QJ=0!'97)I;6ES(%-A;&IU(&1I('!A9VD@
M:&%R:0!'97)I;6ES(%-A;&IU(&)E8F5R87!A('-A870@;&%G:0!+961A;&%M
M86X@4V%L:G4Z`%!E<F)A;F1I;F=A;B!S86QJ=2!D:2`H9&%L86TI(&%I<CH`
M0F5B97)A<&$@9FEL92!K;VYF:6=U<F%S:2!M;V1U;"!087-S=V]R9"!H:6QA
M;F<Z`$QA9W4@)B!386IA:P!%<F]P82!396QA=&%N("A)4T\M.#@U.2TS*0!"
M96QA:&%N($)U;6D@4V5L871A;@!*87)A:R!A;G1A<F$@<V5L('EA;F<@8F5R
M9&5K871A;@!*87)A:R!A;G1A<F$@:7-I(&1A;B!B;W)D97(@9&D@9&%L86T@
M<V5L`$IA<F%K('-P87-I`$IA<F%K('-P87-I(&1A;B!J87)A:R!S<&%S:2!D
M87)I(&)O<F1E<@!3<&%M`$UA<W5K:V%N($MA<F%K=&5R(%-P97-I86P`4&ES
M86AK86X@4V5L`%!I<V%H:V%N(&MO;&]M`%!I<V%H:V%N(&)A<FES`$]L86AR
M86=A`%-T86YD87(`4&5R:F%L86YA;B!":6YT86YG`%-T871U<P!!;F=K82]H
M=7)U9B]S:6UB;VP@>6%N9R!D:6)E<FD@=&%N9&$@9V%R:7,`1V%Y82!;0U-3
M70!-:6X`4W5B9&ER96MT;W)I("<E<R<@=&ED86L@9&ET96UU:V%N+@`@4&5R
M;6EN=&%A;B!Y86YG(&1I<V%M<&%I:V%N('5N='5K(&UE;F%M8F%H:V%N("<E
M(',G(&ME(&1A;&%M('-I<W1E;2X@06YD82!T:61A:R!D87!A="!L;V<@:6X@
M<V%M<&%I('!E<FUI;G1A86X@86YD82!T96QA:"!D:7-E='5J=6DN`$%N9VMA
M+VAU<G5F+W-I;6)O;"!Y86YG(&1I='5L:7,@9&EB87=A:"!G87)I<R!B87)I
M<R!T96MS`%-U:W-E<P`G)7,G('-U9&%H(&)E<FAA<VEL(&1I=&%M8F%H:V%N
M(&ME(&1A;&%M('-I<W1E;2X`1&%T82!U;G1U:R!P96YG9W5N82`G)7,G('-U
M9&%H(&)E<FAA<VEL(&1I8F5R<VEH:V%N(&1A<FD@<VES=&5M+@`B)7,B<W5D
M86@@8F5R:&%S:6P@9&EH87!U<RX`)R5S('-U9&%H(&)E<FAA<VEL(&1I<&EN
M9&%H:V%N(&1A<FD@<VES=&5M+@!+;VYF:6=U<F%S:2!S=61A:"!B97)H87-I
M;"!D:6ME;6)A;&EK86XN(%5L86YG:2!U;G1U:R!M96QI:&%T('!E<G5B86AA
M;BX@`$)A8VMU<"!K;VYF:6=U<F%S:2!S=61A:"!B97)H87-I;"!D:7-I;7!A
M;BX`1FEL92!"86-K=7`@2V]N9FEG=7)A<VD@)7,@<W5D86@@8F5R:&%S:6P@
M9&ES:6UP86XN`"<E<R<@<W5D86@@8F5R:&%S:6P@9&EP97)B86AA<G5I`"<E
M<R<@<W5D86@@8F5R:&%S:6P@9&ET=6QI<P!2:6YG:V%S86X`36%T86AA<FD@
M5&5R8FET`$UA=&%H87)I(%1E<F)E;F%M`$-E<F%H`$UA=&%H87)I(%1E<F)I
M=`!-871A:&%R:2!497)B:70O36%T86AA<FD@5&5R8F5N86T`36%T86AA<FD@
M5&5R8FET.@!-871A:&%R:2!497)B96YA;0!-871A:&%R:2!497)B96YA;3H`
M06YG:V$O:'5R=68O<VEM8F]L('EA;F<@9&ET=6QI<R!D:6%T87,@8F%R:7,@
M=&5K<P!$=6MU;F=A;@!(=6IA;B!P971I<B!D:7-E<G1A:2!D96YG86X@86YG
M:6X@<FEB=70`2'5J86X@<&5T:7(@9&ES97)T86D@9&5N9V%N(&)A9&%I(&%N
M9VEN(')I8G5T`$AU:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!A;F=I;B!R
M:6)U=`!0<F]P97)T:2!486)E;`!0<F]P97)T:2!T86)E;`!487)G970Z`%1U
M9V%S`%-U:'4@=6YT=6L@:F%M('1E<F%K:&ER.@!3=6AU`%-U:'4Z`%-U:'4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92!!9&UI;FES
M=')A<VD`2&%N>6$@5&5K<P!097)A=&%A;B!496MS`%1E:W,@0F%G:6%N($%T
M87,`2VUS`%1H86D@*%1)4RTV,C`I`%!E;65L:6AA<F%A;CHZ(&-L87-S('1I
M9&%K(&)E<FAA<VEL(&1I<&%N9V=I;`!7:6YD;W<@4&EL:6AA;B!S=61A:"!D
M:71U='5P+B!3:6QA:V%N($ME;'5A<@!(86YY82!S:7-I(&)A9VEA;B!B87=A
M:`!-;V1E($QA>6%R(%!E;G5H(&1I:V5N86P@9&%P870@;65N>65B86)K86X@
M;6%S86QA:"!D96YG86X@26YT97)N970@17AP;&]R97(L(&IU9V$@=6YT=6L@
M;65N8V%R:2!K97-A;&%H86X@>6%N9R!M96YY96)A8FMA;B!A;F1A('1I9&%K
M(&UA;7!U(&)E:V5R:F$@9&5N9V%N(&)A:6LN($%N9&$@;75N9VMI;B!P97)N
M86@@;65N9V%L86UI('1A;7!I;&%N('EA;F<@8G5R=6LL(&ME:W5R86YG86X@
M9&%R:2!F=6YG<VD@961I=&]R(&1A;B]A=&%U(&)R;W=S97(@>6%N9R!S97)I
M;F<@:V%L:2!R=7-A:R!D86X@:&%R=7,@9&EU;&%N9R!K96UB86QI+B!*:6MA
M('-I<W1E;2!A;F1A(&%D86QA:"!7:6YD;W=S(#EX(&%D82!K96UU;F=K:6YA
M;B!A;F1A(&%K86X@;65N9&%P871K86X@)TME<V%L86AA;B!097)L:6YD=6YG
M86X@56UU;2<@9&%N('!E<FQU('5N='5K(&UE+7)E<W1A<G0@:V]M<'5T97(@
M86YD82Y<;EQN($%N9&$@<W5D86@@9&EP97)I;F=A=&DN(%-I;&%K86X@:VQI
M:R!/2R!J:6MA(&%N9&$@:6YG:6X@;65N8V]B82!E9&ET;W(@;&%Y87(@<&5N
M=6@N`$ED96YT:71A<R`B)7,B('-U9&%H(&1I:&%P=7,N`$AA;GEA('-I<VD@
M8F%G:6%N(&MI<FD`2&%N>6$@<VES:2!B86=I86X@:V%N86X@9&%N(&MI<FD`
M2&%N>6$@<VES:2!B86=I86X@:V%N86X`4V5R=F5R("(E<R(@<W5D86@@8F5R
M:&%S:6P@9&EH87!U<RX`4V5R=F5R("(E<R(@<W5D86@@8F5R:&%S:6P@9&ES
M:6UP86XN`%!E<FUI;G1A86X@<&5N9&%F=&%R86X@=6YT=6L@)7,@<W5D86@@
M8F5R:&%S:6P@9&EP:6YD86AK86XN`$AA;GEA('-I<VD@8F%G:6%N(&%T87,@
M9&%N(&)A=V%H`$AA;GEA('-I<VD@8F%G:6%N(&%T87,`07)E82!K92!W96%T
M:&5R+F-O;2!T:61A:R!D:7-E9&EA:V%N+@!$:7)E:W1O<FD@36]T:68@)R5S
M)R!T:61A:R!D:71E;75K86XN`$%D82!M87-A;&%H(&ME=&EK82!M96YA;6)A
M:&MA;B<E<R<@:V4@9&%L86T@<VES=&5M+B`E<RX`061A(&UA<V%L86@@:V5T
M:6MA(&UE;F%M8F%H:V%N("<E<R<@:V4@9&%L86T@<VES=&5M.B`E<R``061A
M(&UA<V%L86@@:V5T:6MA(&UE;6)E<G-I:&MA;B!D871A('5N='5K('!E;F=G
M=6YA("<E<R<@9&%R:2!S:7-T96TZ`$%D82!M87-A;&%H(&ME=&EK82!M96UI
M;F1A:&MA;B`G)7,G(&1A<FD@<VES=&5M.@!!9&$@;6%S86QA:"!K971I:V$@
M;65M<&5R8F%H87)U:2`G)7,G.B5S`$%D82!K97-A;&%H86X@9&D@9&%L86T@
M9F]R;75L:7(@:V]N9FEG=7)A<VDN($UU;F=K:6X@86YD82!T:61A:R!M96YG
M:7-I(&MO;&]M('EA;F<@9&EP97)L=6MA;BX`1FEL92!I;FD@8F5R:7-I(&EN
M9F]R;6%S:2!K;VYF:6=U<F%S:2!B86-K96YD('5N='5K('-C<FEP="!M;V1U
M;"!087-S=V]R9"X`26YI(&%D86QA:"`E<RX`26YI(&%D86QA:"!F:6QE('5T
M86UA(&MO;F9I9W5R87-I(&UO9'5L(%!A<W-W;W)D+B!&:6QE(&EN:2!B97)I
M<VD@<&%T:"!D86X@<&EL:6AA;B!U;G1U:R!S96UU82!S8W)I<'0@;6]D=6P@
M4&%S<W=O<F0N`%=I;F1O=R!I;FD@:&%R=7,@9&EP86YG9VEL(&1A<FD@4&EL
M:6AA;B!7:6YD;W<`4&5T:7(`5&EK970`365N9VEK=71I(%=A:W1U`$9O<FUA
M="!786MT=0!*=61U;`!*=61U;"`H0V%T871A;B!P971U;FIU:RD`2&%R:2!)
M;FD`1V%N=&D@4V]U<F-E($A434P`0F5S;VL`071A<P!&<F%M92!!=&%S("A?
M=&]P*0!4<F%N<VQA<VD`4V5L`%1U<FMI("A)4T\M.#@U.2TY*0!);F1E:W,@
M52Y6.@!54DP`55),.@!4:61A:R!B:7-A(&MO;F5K<VD@:V4@<V5R=F5R(%-1
M3"X`5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S("(E<R(Z("5S+@!'87)I
M<R!B87=A:`!"871A;&MA;B!097)U8F%H86X`0F%T86QK86X@86MS:2!T97)A
M:VAI<B!A;F1A`%1I9&%K(&1I87)S:7!K86X`56YI8V]D92`H551&+3@I`%5N
M:70`0F%T86QK86X@;&EN:R!P861A(&5L96UE;B!Y86YG('-E:V%R86YG`%-C
M<FEP="!Y86YG('1I9&%K(&UE;7!U;GEA:2!H86L@:7-T:6UE=V$@=&ED86L@
M9&%P870@;65N9V%K<V5S($AA<'5S+U-A;&EN+TQE:V%T:V%N('-E<W5A:2!R
M96YC86YA('5N='5K(&%L87-A;B!K96%M86YA;BY+;&EK($]+('5N='5K(&UE
M;&EH870@8V%T871A;B!T96MN:7,@<&%D82!M;WII;&QA+F]R9R!D:6UA;F$@
M86YD82!A:V%N(&1I<&5R;&EH871K86X@8V%R82!B86=A:6UA;F$@=6YT=6L@
M;65N9VEZ:6YK86X@<V-R:7!T('5N='5K(&1A<&%T(&UE;F=A:W-E<R!K92!C
M;&EP8F]A<F0N`%=A<FYA(&)E;'5M(&1I871U<@!097)B86AA<G5I`%!E<F)A
M:&%R=6D@)7,`4&5R8F%H87)U:2!P96YG9W5N80`B)7,B('-U9&%H(&1I<&5R
M8F%H87)U:2X`4V-R:7!T('5P9W)A9&4@<W5D86@@9&EH87!U<RX`57!L;V%D
M`%-E;75A(&9I;&4@<V5T=7`@87!L:6MA<VD@<W5D86@@9&EU<&QO860@:V4@
M<V5R=F5R+@!3:6UB;VP@:'5R=68@8F5S87(@;&%T:6X`4VEM8F]L(&AU<G5F
M(&)E<V%R(')O;6%W:0!'=6YA:V%N;&%H(&II:V$@;F%M82]S86YD:2!A;F1A
M(&)E<F)E9&$@=6YT=6L@<V5R=F5R($E-4U`N`$%D;6EN:7-T<F%S:2!096YG
M9W5N80!096YD869T87)A;B!096YG9W5N80!096YD869T87)A;B!096YG9W5N
M82!S=61A:"!D:6YO;BUA:W1I9FMA;B!U;G1U:R!S:71E(&EN:2X`06-C;W5N
M="!096YG9W5N82!T:61A:R!D:71E;75K86X`4&5M86MA:2!T:61A:R!D:71E
M;75K86X`4&5M86MA:2!T:61A:R!D:71E;75K86XN`$YA;6$@4&5N9V=U;F$`
M57-E<FYA;64Z`$YA;6$@4&5N9V=U;F$Z`%!E;F=G=6YA(&1I(&1A;&%M('-I
M<W1E;3H`3&EB=7)A;@!687)I86)L90!697)S:2!+;VYT<F]L`$IA<F%K('!O
M<VES:2!V97)T:6MA;"!A;G1A<F$@9V%R:7,@9&%S87(@9&5N9V%N(&=A;6)A
M<@!*87)A:R!P;W-I<VD@=F5R=&EK86P@86YT87)A(&)O<F1E<B!D96YG86X@
M9V%M8F%R`%9E<G1I:V%L.@!386YG870@5&EN9V=I`%9I971N86T@*%9)4T-)
M22D`3&EH870@=V5B('!A9V4@96MS=&5R;F%L`$IA<F%K(%!A;F1A;F<`2F%R
M86L@4&%N9&%N9SH`4$5224Y'051!3B$A(2!024Y$04A+04X@4T-225!4($E.
M22!314-!4D$@34%.54%,($1!4DD@)7,N`%!E<FEN9V%T86X`4F%B=0!286UA
M;&%N($-U86-A`$1A=&$@0W5A8V$@9&ES961I86MA;B!O;&5H`%=E8@!796(@
M4VET90!396QA;6%T($1A=&%N9P!396QA;6%T(&1A=&%N9R!K92`E<P!396QA
M;6%T(&1A=&%N9RP@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H
M25-/+3@X-3DM,34I`$%P86MA:"!A<&QI:V%S:2`E<R!P97)L=2!D:71A;7!I
M;&MA;B!S971E;&%H(&QO9VEN/P!!<&%K86@@>6%N9R!M97)U<&%K86X@8F%T
M87,@:V%R86MT97(_`$%P86MA:"!Y86YG(&UE<G5P86MA;B!K87)A:W1E<B!I
M;F1E;G1A<VD_`$9A<V4@>6%N9R!M86YA`%!L=6=I;B!M86YA:V%H('EA;F<@
M9&%P870@9&EA:W1I9FMA;B!U;G1U:R!E9&ET;W(@4FEC:"!497AT+@!,96)A
M<@!,96)A<B!M96YU("5S('!A9&$@8F%G:6%N(&MI<FD@*&%K86X@8F5R<&5N
M9V%R=6@@<&%D82!L;V=I;B!B97)I:W5T;GEA*0!,96)A<B!T86)E;`!,96)A
M<B!U;FET`$QE8F%R.@!7:6MI`$%N9VEN`$%N9VEN(&1I('!A9VD@:&%R:0!+
M96-E<&%T86X@86YG:6X@9&D@9&%L86T@:VYO=`!!;F=I;CH`06YG:6XZ`$MA
M=&$@0FEJ86MS86YA`$1A9G1A<B!+96EN9VEN86X`4&5K97)J86%N`%@M4F5F
M`%E9`%EA+"!305E!(%-%5%5*50!!;F1A(&)E<F%D82!D:2!D86QA;2!-3T1%
M(%1%2U,N($=U;F%K86X@=&]M8F]L(%L\/ET@=6YT=6L@;65N9V=A;G1I(&ME
M;6)A;&D@:V4@9&%L86T@;6]D92!765-)5UE'+@!!;F1A('1I9&%K(&1I:7II
M;FMA;B!U;G1U:R!M96UB=6%T(&QE8FEH(&1A<FD@)60@87)E82X`06YD82!T
M:61A:R!B:7-A(&UE;F=U8F%H('!A<W-W;W)D('5N='5K('5S97(@)7,`06YD
M82!H87)U<R!M96YJ96QA<VMA;B!M87-A;&%H('-E8F5L=6T@86YD82!D87!A
M="!M96YG:7)I;6MA;B!L87!O<F%N(&UA<V%L86@N`$%N9&$@:&%R=7,@;65M
M87-U:VMA;B!54DP@9&EM86YA(&QI;FL@:6YI(&UE;G5N:G5K(&ME`$%N9&$@
M:&%R=7,@;65M8F5R:2!P87-S=V]R9"!B87)U(&%N9&$`06YD82!H87)U<R!M
M96UB97)I('!A<W-W;W)D(&QA;6$@86YD80!!;F1A(&AA<G5S(&UE;6EL:6@@
M<V5R=F5R('5N='5K(&1A<&%T(&1I:&%P=7,N`$%N9&$@:&%R=7,@;65N971A
M<&MA;B!N86UA('!E;F=G=6YA('EA;F<@:6YG:6X@9&EB97)S:6AK86XN`$%N
M9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('EA;F<@:6YG:6X@
M9&EP:6YD86AK86XN`$%N9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G
M=6YA('5N='5K(&1I=&%M8F%H+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M
M82!P96YG9W5N82!U;G1U:R!D:7!E<F)A:&%R=6DN`$%N9&$@:&%R=7,@=F5R
M:69I:V%S:2!P87-S=V]R9"!B87)U(&%N9&$`06QA;6%T($5M86EL($%N9&$`
M06YD82!$87)I.B!A;&%M870Z`$EN9F]R;6%S:2!!;F1A`$YA;6$@06YD80!"
M86-K96YD(&%S;&D@86YD82!T:61A:R!D87!A="!M96YD=6MU;F<@<&5N86UB
M86AA;B!P96YG9W5N82P@871A=2!F:71U<B!I;FD@<W5D86@@9&EN;VXM86MT
M:69K86X@=6YT=6L@8F5B97)A<&$@86QA<V%N(&QA:6XN`$)A8VME;F0@87-L
M:2!A;F1A('1I9&%K(&1A<&%T(&UE;F1U:W5N9R!P96YD869T87)A;B!P96YG
M9W5N82P@871A=2!F:71U<B!I;FD@<W5D86@@9&EN;VXM86MT:69K86X@=6YT
M=6L@8F5B97)A<&$@86QA<V%N(&QA:6X`0G)O=W-E<B!A;F1A('1I9&%K(&UE
M;F1U:W5N9R!U;G1U:R!F:71U<B!I;FDN`$)R;W=S97(@86YD82!T:61A:R!M
M96YD=6MU;F<@<&EL:6AA;B!U;G1U:R!M96YC971A:RX@5&5K86X@0V]N=')O
M;"]0:6QI:&%N("L@4"!U;G1U:R!M96YC971A:RX`6F]N82!786MT=2!!;F1A
M(%-E:V%R86YG.@!$969A=6QT(&ED96YT:71A<R!A;F1A('-U9&%H(&1I=6)A
M:"X`1&5F875L="!I9&5N=&ET87,@86YD83H`3F%M82!L96YG:V%P(&%N9&$Z
M`%-A;F1I(&)A<G4@86YD82!U;G1U:R`E<R!A9&%L86@Z("5S`%!A<W-W;W)D
M(&)A<G4@86YD82!T97)L86QU('!A;FIA;F<[('!A<W-W;W)D(&UU;F=K:6X@
M=&ED86L@;&5B:6@@<&%N:F%N9R!D87)I("5D(&MA<F%K=&5R(0!087-S=V]R
M9"!B87)U(&%N9&$@=&5R;&%L=2!S:6UP96P@=6YT=6L@9&ET96)A:R$@5&ED
M86L@8F5R=6)A:"$`4&%S<W=O<F0@8F%R=2!A;F1A(&AA<G5S('!A;&EN9R!S
M961I:VET('-E<&%N:F%N9R`E9"!K87)A:W1E<@!087-S=V]R9"!B87)U(&%N
M9&$@:&%R=7,@8F5R8F5D82!D96YG86X@<&%S<W=O<F0@86YD82!S86%T(&EN
M:0!087-S=V]R9"!B87)U(&%N9&$@:&%R=7,@8F5R:7-I('!A;&EN9R!S961I
M:VET("5D(&MA<F%K=&5R(&%L9F%B970N`%!A<W-W;W)D(&)A<G4@86YD82!H
M87)U<R!B97)I<VD@<&%L:6YG('-E9&EK:70@)60@:V%R86MT97(@86QF86YU
M;65R:6LN`%!A<W-W;W)D(&)A<G4@86YD82!H87)U<R!B97)I<VD@<&%L:6YG
M('-E9&EK:70@)60@:'5R=68@:V5C:6PN`%!A<W-W;W)D(&)A<G4@86YD82!H
M87)U<R!B97)I<VD@<&%L:6YG('-E9&EK:70@)60@:V%R86MT97(@;G5M97)I
M:RX`4&%S<W=O<F0@8F%R=2!A;F1A(&AA<G5S(&)E<FES:2!P86QI;F<@<V5D
M:6MI="`E9"!H=7)U9B!B97-A<BX`4&%S<W=O<F0@8F%R=2!A;F1A(&AA<G5S
M(&)E<FES:2!K=7)A;F<@9&%R:2`E9"!K87)A:W1E<B!S<&%S:2X`4&%S<W=O
M<F0@8F%R=2!A;F1A('1I9&%K(&)O;&5H(&)E<FES:2!K87)A:W1E<B!S<&%S
M:2X`4&%S<W=O<F0@8F%R=2!A;F1A('1I9&%K(&-O8V]K`%-A;F1I(&%N9&$@
M<W5D86@@9&EA='5R('5L86YG`%-A;F1I(&%N9&$@<W5D86@@9&EA='5R('5L
M86YG+"!P97)I:W-A;&%H(&5M86EL(&%N9&$@9&%N(&QO9VEN(&1E;F=A;B!M
M96YG9W5N86MA;B!S86YD:2!B87)U(&%N9&$`4F5M;W1E('-E<G9E<B!A;F1A
M.@!#97)I80!;4V5M8G5N>6EK86X@26YD96YT87-I(%1E:W-=`%M,87!O<F%N
M($UA<V%L86A=`%M486UP:6QA;B!);F1E;G1A<VD@5&5K<R`M`%]!9&UI;FES
M=')A<VD`7T-,20!?1&%T851R964`2&%P=7,@0F%R:7,`7T=R=7``4')O<&5R
M=&D@1V%M8F%R+BXN`%5B86@@3&EN:RXN+@!)>FEN`%!I;F1A:&MA;B!,:6YK
M+BXN`%]3971U<`!0<F]P97)T:2!486)E;"XN+@!096YG9W5N80!496YA;F<`
M:F%T=6@`1&%R:2`E<R`H)7,I('!A9&$@)7,@)7,`86YG:6X@:V5N8V%N9P!M
M87-I:"!D:2!D86QA;2!A;G1R:6%N`&)A<FES70!N86UA`'!E<G-E;@!P:7AE
M;`!N86EK`'1A;7!I;&MA;B!P97)B961A86X`=&5T87``=&5M<&YA;2@I(&=A
M9V%L(0!+971I:R!S86YD:2!D=6$@:V%L:2!U;G1U:R!M96YG:V]N9FER;6%S
M:0!M96YY871U:V%N`'=E871H97(N8V]M````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O:'5?2%4O````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`
M,#(P,3<T`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]H
M=5](52],0U]-15-304=%4R\`````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<T-``P,C$W-C$`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P87-S=V0O;&]C86QE+VAU7TA5+TQ#7TU%4U-!1T53+W!A<W-W9"YM;P``
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P-#,V,#`P`#$P-#$W,S8R-S0T`#`R,S8Q-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`(0'```<````/#P``!,*``!<>````````*B@``!-````J:```+\```#WH```
M9````+>A``"^````'*(``)````#;H@``0P```&RC```\````L*,``"L```#M
MHP``+@```!FD```I````2*0``"@```!RI```10```)ND``!'````X:0``$H`
M```II0``1P```'2E``!%````O*4``$@````"I@``.0```$NF``!&````A:8`
M`$@```#,I@``,````!6G``!%````1J<``$8```",IP``3````-.G```T````
M(*@``#(```!5J```:0```(BH```P````\J@``"4````CJ0``B````$FI``!`
M````TJD``/8````3J@``2@````JK```L````5:L``(4```""JP``2`````BL
M```.````4:P```\```!@K```#0```'"L```(````?JP```L```"'K```#```
M`).L```$````H*P```P```"EK```$0```+*L```E````Q*P```\```#JK```
M"P```/JL```1````!JT```X````8K0``*````">M```(````4*T```H```!9
MK0``%0```&2M```2````>JT```L```"-K0``$P```)FM```.````K:T```H`
M``"\K0``#0```,>M```N````U:T```X````$K@``$0```!.N```-````):X`
M``P````SK@``#0```$"N```;````3JX``"T```!JK@``'0```)BN```D````
MMJX``"D```#;K@``&0````6O```/````'Z\``!@````OKP``#````$BO```;
M````5:\```X```!QKP``#@```("O```(````CZ\```D```"8KP``0@```**O
M```N````Y:\``!H````4L```,@```"^P```X````8K```%0```";L```40``
M`/"P``!:````0K$``%<```"=L0``-````/6Q```)````*K(```T````TL@``
M!P```$*R```*````2K(```\```!5L@``!0```&6R```&````:[(``!$```!R
ML@``"````(2R```)````C;(```D```"7L@``)0```*&R```@````Q[(``!``
M``#HL@``#P```/FR```*````";,```,````4LP``#P```!BS```4````*+,`
M``D````]LP``#0```$>S```2````5;,``!D```!HLP``'@```(*S```/````
MH;,```H```"QLP``#P```+RS```(````S+,``"0```#5LP``%````/JS```6
M````#[0```@````FM```3@```"^T```M````?K0``!\```"LM```&0```,RT
M```'````YK0```P```#NM```+````/NT```.````*+4```,````WM0``"P``
M`#NU```'````1[4```<```!/M0``!0```%>U```%````7;4```H```!CM0``
M`P```&ZU```7````<K4```H```"*M0``#P```)6U```.````I;4``!@```"T
MM0``(P```,VU```.````\;4``!0`````M@``%P```!6V```7````+;8``!<`
M``!%M@``$P```%VV```/````<;8```X```"!M@``'P```)"V```=````L+8`
M``<```#.M@``!@```-:V```(````W;8```\```#FM@``!@```/:V```*````
M_;8``!,````(MP``"P```!RW```0````*+<``!4````YMP``%0```$^W```'
M````9;<``!````!MMP``!0```'ZW```5````A+<``!$```":MP``#````*RW
M```[````N;<``#@```#UMP``"0```"ZX```'````.+@``!0```!`N````P``
M`%6X```%````6;@``!````!?N```"0```'"X```3````>K@``#D```".N```
M$@```,BX```G````V[@``"P````#N0``*@```#"Y```E````6[D```H```"!
MN0``!@```(RY```)````D[D```<```"=N0``+P```*6Y```W````U;D``"X`
M```-N@``50```#RZ```M````DKH``"T```#`N@``+0```.ZZ``!`````'+L`
M`",```!=NP``(P```(&[```M````I;L``#,```#3NP``%0````>\```9````
M';P``"D````WO```)````&&\```1````AKP```H```"8O```#````*.\```B
M````L+P```H```#3O```$````-Z\```6````[[P``!8````&O0``!P```!V]
M```'````);T``!0````MO0``"@```$*]```(````3;T``"<```!6O0``"```
M`'Z]```'````A[T```<```"/O0``!@```)>]```%````GKT```<```"DO0``
M!@```*R]```(````L[T``"D```"\O0``#@```.:]```*````];T```0`````
MO@``!P````6^```)````#;X```8````7O@``$0```!Z^```'````,+X``!8`
M```XO@``!````$^^```(````5+X```8```!=O@``#0```&2^```&````<KX`
M`!X```!YO@``$0```)B^```B````JKX``!8```#-O@``"````.2^```-````
M[;X```P```#[O@``!P````B_```#````$+\```,````4OP``%P```!B_```3
M````,+\``!T```!$OP``"````&*_```$````:[\```@```!POP``"````'F_
M``!!````@K\``"````#$OP``!@```.6_```&````[+\``!4```#SOP``&```
M``G````B````(L```"X```!%P```'0```'3````A````DL```%0```"TP```
M*0````G!```*````,\$```<````^P0``%0```$;!```.````7,$```H```!K
MP0``#P```';!```-````AL$```\```"4P0``#0```*3!```)````LL$``!0`
M``"\P0``!@```-'!```8````V,$``!T```#QP0``$P````_"```1````(\(`
M`!0````UP@``!````$K"```&````3\(```\```!6P@``5````&;"```4````
MN\(``!<```#0P@``!````.C"```.````[<(``$0```#\P@``!0```$'#```%
M````1\,``!L```!-PP``&@```&G#```1````A,,``!$```"6PP``'````*C#
M```J````Q<,``!````#PPP``(0````'$```E````(\0``!D```!)Q```!0``
M`&/$```3````:<0``!(```!]Q```"@```)#$```/````F\0```T```"KQ```
M$0```+G$```3````R\0```P```#?Q```!@```.S$```,````\\0```8`````
MQ0``%P````?%```0````'\4``!$````PQ0``"````$+%```%````2\4```P`
M``!1Q0``$````%[%```%````;\4```T```!UQ0``!@```(/%```'````BL4`
M``T```"2Q0``$````*#%```)````L<4```<```"[Q0``"P```,/%```+````
MS\4```<```#;Q0``!P```./%```4````Z\4```D`````Q@``"@````K&```9
M````%<8``!T````OQ@``#````$W&```0````6L8``!4```!KQ@``!0```('&
M```E````A\8``!(```"MQ@``$P```,#&```K````U,8``#L`````QP``(```
M`#S'```V````7<<``!````"4QP``"````*7'```,````KL<```8```"[QP``
M!````,+'```.````Q\<``!````#6QP``"@```.?'```-````\L<``!X`````
MR```&P```!_(```A````.\@``!X```!=R```&0```'S(```>````EL@``!T`
M``"UR```&P```-/(```@````[\@``"X````0R0``%P```#_)```F````5\D`
M`#````!^R0``&P```*_)```>````R\D``!P```#JR0``)@````?*```K````
M+LH``#,```!:R@``)@```([*```K````M<H``#@```#AR@``'0```!K+```5
M````.,L``"\```!.RP``$@```'[+```@````D<L``"D```"RRP``'@```-S+
M```A````^\L``!(````=S```H@```##,```6````T\P``",```#JS```*```
M``[-```I````-\T``"@```!AS0``'P```(K-```5````JLT``"````#`S0``
M)0```.'-```H````!\X``"T````PS@``,````%[.``"2````C\X``"$````B
MSP``%@```$3/```<````6\\``"8```!XSP``*@```)_/``!!````RL\``$0`
M```,T```#````%'0```'````7M````<```!FT```!@```&[0```-````==``
M`!````"#T```$@```)30```3````I]```!(```"[T```!P```,[0```$````
MUM```!````#;T```#````.S0```.````^=````\````(T0``$P```!C1```-
M````+-$``"@````ZT0```P```&/1```-````9]$```8```!UT0``$0```'S1
M```7````CM$``!L```"FT0``#@```,+1```"````T=$```4```#4T0``$```
M`-K1```$````Z]$```T```#PT0``#@```/[1```#````#=(```X````1T@``
M"````"#2```/````*=(```\````YT@``!P```$G2```-````4=(``!````!?
MT@``$P```'#2```3````A-(```L```"8T@``!@```*32```,````J](``!$`
M``"XT@``&0```,K2```+````Y-(```T```#PT@``(@```/[2```;````(=,`
M`#0````]TP``"@```'+3```8````?=,``!D```"6TP``%@```+#3```O````
MQ],``"(```#WTP``#0```!K4```'````*-0``!0````PU```"P```$74```B
M````4=0``"\```!TU```"P```*34```)````L-0``!D```"ZU```"P```-34
M```7````X-0``!<```#XU```"0```!#5```6````&M4```\````QU0``%@``
M`$'5```.````6-4``!@```!GU0``"````(#5```-````B=4``"8```"7U0``
M0P```+[5```(`````M8``!(````+U@``"````![6```+````)]8``"\````S
MU@``#@```&/6```%````<M8```8```!XU@```P```'_6```'````@]8```0`
M``"+U@``"@```)#6```*````F]8```\```"FU@``$````+;6```7````Q]8`
M`!$```#?U@``%P```/'6```9````"=<```D````CUP``!0```"W7```+````
M,]<```H````_UP```@```$K7```%````3=<```T```!3UP``&P```&'7```7
M````?=<```D```"5UP``#@```)_7```-````KM<``!(```"\UP``.````,_7
M```@````"-@```@````IV```#@```#+8``![````0=@``!@```"]V```0```
M`-;8```1````%]D```<````IV0``!0```#'9```7````-]D``"````!/V0``
M&0```'#9```3````BMD```<```">V0``!P```*;9```(````KMD```8```"W
MV0``!@```+[9```0````Q=D```\```#6V0``$````.;9```/````]]D```L`
M```'V@``#P```!/:```,````(]H```\````PV@``!P```$#:```*````2-H`
M``8```!3V@``#@```%K:```,````:=H``"@```!VV@``#P```)_:```(````
MK]H``!8```"XV@``"````,_:```3````V-H``!X```#LV@``(0````O;```@
M````+=L``!D```!.VP``%P```&C;```E````@-L``!<```"FVP``'P```+[;
M```$````WML``!L```#CVP``#0```/_;```,````#=P```,````:W```"```
M`![<```*````)]P```P````RW```"P```#_<```0````2]P```P```!<W```
M!````&G<```3````;MP``!0```""W```#````)?<```)````I-P```X```"N
MW```"P```+W<```;````R=P```<```#EW```!P```.W<```*````]=P```T`
M````W0``"0````[=```$````&-T```,````=W0``&````"'=```*````.MT`
M``0```!%W0``)@```$K=```.````<=T``'P```"`W0``%0```/W=```%````
M$]X```<````9W@``#````"'>```(````+MX```H````WW@``!@```$+>```(
M````2=X``!8```!2W@``$@```&G>```"````?-X```8```!_W@``!@```(;>
M```4````C=X```T```"BW@``$````+#>```;````P=X```0```#=W@``"0``
M`.+>```0````[-X```D```#]W@``"0````??```%````$=\```4````7WP``
M&@```!W?```(````.-\```8```!!WP``&0```$C?```.````8M\``"(```!Q
MWP``!P```)3?```'````G-\```X```"DWP``!0```+/?```)````N=\```H`
M``##WP```@```,[?```&````T=\```T```#8WP``"0```.;?```&````\-\`
M`!(```#WWP``"0````K@```'````%.```!0````<X```'0```#'@```1````
M3^````8```!AX```"@```&C@```$````<^````D```!XX```"````(+@```1
M````B^```!$```"=X```"0```*_@```&````N>````T```#`X```!@```,[@
M```Y````U>```#T````/X0``.@```$WA```>````B.$```4```"GX0``#@``
M`*WA```$````O.$```8```#!X0``(0```,CA```5````ZN$```8`````X@``
M!`````?B```1````#.(```8````>X@``H````"7B```*````QN(``"(```#1
MX@``!````/3B```E````^>(```4````?XP``'0```"7C```$````0^,```P`
M``!(XP``"@```%7C```(````8.,```D```!IXP``!0```'/C```;````>>,`
M`#H```"5XP``,````-#C```U`````>0``"D````WY```+@```&'D``!'````
MD.0``#@```#8Y```*0```!'E```_````.^4``"X```![Y0``+0```*KE```?
M````V.4```\```#XY0``$@````CF```+````&^8``"8````GY@``*0```$[F
M```D````>.8``"8```"=Y@``"````,3F```*````S>8```D```#8Y@``!P``
M`.+F```@````ZN8``"`````+YP``)@```"SG```*````4^<``!D```!>YP``
M*0```'CG```6````HN<``!(```"YYP``!P```,SG```*````U.<```P```#?
MYP``#P```.SG```0````_.<``$`````-Z```<````$[H``!F````O^@```X`
M```FZ0``"0```#7I```*````/^D``!(```!*Z0``$P```%WI```,````<>D`
M``8```!^Z0``#P```(7I```2````E>D``!````"HZ0``$0```+GI```1````
MR^D``!P```#=Z0``(P```/KI``!J````'NH```\```")Z@``!0```)GJ```0
M````G^H```D```"PZ@``!````+KJ```+````O^H``!H```#+Z@``%````.;J
M```,````^^H```P````(ZP``#P```!7K```5````)>L``"D````[ZP``*@``
M`&7K```F````D.L``"<```"WZP``*0```-_K```J````">P``!D````T[```
M0@```$[L```1````D>P``!(```"C[```$P```+;L```4````RNP```\```#?
M[```%@```._L```7````!NT``!`````>[0``$0```"_M```T````0>T``!,`
M``!V[0``$@```(KM```U````G>T``!0```#3[0``!P```.CM```,````\.T`
M`"````#][0``%````![N```1````,^X``!<```!%[@``'````%WN```3````
M>NX``!0```".[@``&@```*/N```1````ONX``!H```#0[@``'@```.ON```:
M````"N\``!,````E[P``%0```#GO```1````3^\``!<```!A[P``%````'GO
M```7````CN\``!4```"F[P``"0```+SO```9````QN\```0```#@[P``!P``
M`.7O```+````[>\``!$```#Y[P``!@````OP```&````$O````8````9\```
M!0```"#P```'````)O````<````N\```!0```#;P```6````//````8```!3
M\```!@```%KP```$````8?````0```!F\```!P```&OP```.````<_````P`
M``""\```#````(_P```-````G/````H```"J\```#@```+7P```%````Q/``
M`"@```#*\```#@```//P```,`````O$```\````/\0``"@```!_Q```(````
M*O$```D````S\0``*P```#WQ```$````:?$```@```!N\0``)@```'?Q```2
M````GO$```\```"Q\0``!@```,'Q```*````R/$```<```#3\0``"````-OQ
M```@````Y/$```D````%\@``#`````_R```-````'/(```X````J\@``%@``
M`#GR```1````4/(```8```!B\@```P```&GR```&````;?(``!D```!T\@``
M!P```([R```$````EO(```L```";\@``"P```*?R```'````L_(```<```"[
M\@``%@```,/R```-````VO(```T```#H\@``"@```/;R```0`````?,```\`
M```2\P``$0```"+S```7````-/,```H```!,\P``$0```%?S```$````:?,`
M``\```!N\P``.@```'[S```%````N?,```P```"_\P``'@```,SS```.````
MZ_,``!````#Z\P``"P````OT```,````%_0```D````D]```!P```"[T```*
M````-O0```D```!!]```#@```$OT```0````6O0``!H```!K]```"@```(;T
M```)````D?0``!0```";]```"@```+#T```,````N_0```\```#(]```"```
M`-CT```&````X?0```<```#H]```"P```/#T``!'````_/0```T```!$]0``
M!@```%+U```)````6?4```0```!C]0```P```&CU```3````;/4``!,```"`
M]0``$P```)3U```*````J/4```(```"S]0``!````+;U```E````N_4```,`
M``#A]0``!0```.7U```J````Z_4```H````6]@``!0```"'V```$````)_8`
M``H````L]@``#0```#?V``!`````1?8``!,```"&]@``!@```)KV```(````
MH?8```@```"J]@``!````+/V```%````N/8``&@```"^]@``"0```"?W```,
M````,?<```4````^]P``!@```$3W```;````2_<``"\```!G]P``$````)?W
M```*````J/<```\```"S]P``"@```,/W```)````SO<``!,```#8]P``&P``
M`.SW```8````"/@``!<````A^```#@```#GX```#````2/@```<```!,^```
M"````%3X```'````7?@```H```!E^```"P```'#X```M````?/@``!4```"J
M^```,````,#X```D````\?@```<````6^0``40```![Y```0````</D```P`
M``"!^0``#0```([Y```:````G/D``$H```"W^0``&0````+Z```&````'/H`
M`!H````C^@``!@```#[Z```&````1?H``!\```!,^@``!@```&SZ```)````
M<_H``!@```!]^@``%P```);Z```&````KOH```T```"U^@``(@```,/Z``!7
M````YOH``!,````^^P``(P```%+[```3````=OL```(```"*^P``"P```(W[
M```(````F?L```T```"B^P``"@```+#[```&````N_L```<```#"^P``%```
M`,K[```&````W_L```@```#F^P``#@```._[```'````_OL```H````&_```
M"P```!'\```'````'?P```P````E_```#0```#+\```,````0/P```D```!-
M_```"0```%?\```*````8?P```<```!L_```"0```'3\```'````?OP```H`
M``"&_```&P```)'\```2````K?P```H```#`_```"0```,O\```0````U?P`
M``<```#F_```$@```.[\```$`````?T```<````&_0``!0````[]```%````
M%/T```L````:_0``%````";]```1````._T``!H```!-_0``%@```&C]```4
M````?_T``!<```"4_0``&````*S]```<````Q?T``!D```#B_0``!P```/S]
M```%````!/X```T````*_@``#````!C^```(````)?X``!<````N_@``"P``
M`$;^```-````4OX``!,```!@_@``!````'3^```*````>?X```0```"$_@``
M#0```(G^```,````E_X```4```"D_@``"0```*K^```%````M/X```<```"Z
M_@``!0```,+^```$````R/X```(```#-_@``.````-#^```L````"?\``!(`
M```V_P``*0```$G_```R````<_\```H```"F_P``-@```+'_```L````Z/\`
M`!4````5``$`+@```"L``0`S````6@`!`#,```".``$`.````,(``0`/````
M^P`!`!@````+`0$`.P```"0!`0`0````8`$!``\```!Q`0$`%````($!`0`3
M````E@$!`!4```"J`0$`%````,`!`0`2````U0$!`!0```#H`0$`%0```/T!
M`0`M````$P(!`"T```!!`@$`,0```&\"`0`M````H0(!`"X```#/`@$`+P``
M`/X"`0`L````+@,!`&(```!;`P$`$P```+X#`0`(````T@,!``@```#;`P$`
M*P```.0#`0`A````$`0!`!H````R!`$`"0```$T$`0!%````5P0!`$$```"=
M!`$`!````-\$`0`3````Y`0!`!0```#X!`$`#@````T%`0`3````'`4!`!@`
M```P!0$`!@```$D%`0`)````4`4!``H```!:!0$`#P```&4%`0`0````=04!
M``<```"&!0$`#@```(X%`0`%````G04!`!L```"C!0$`!@```+\%`0`(````
MQ@4!``8```#/!0$`%````-8%`0`1````ZP4!``X```#]!0$`.`````P&`0`"
M````108!``8```!(!@$`#@```$\&`0`:````7@8!``4```!Y!@$`!P```'\&
M`0`.````AP8!``8```"6!@$`#0```)T&`0`$````JP8!`"D```"P!@$`%P``
M`-H&`0`?````\@8!`%P````2!P$`%````&\'`0`^````A`<!`!\```##!P$`
M$````.,'`0`'````]`<!``X```#\!P$`"`````L(`0`,````%`@!``P````A
M"`$`$P```"X(`0`*````0@@!`!T```!-"`$`&0```&L(`0`%````A0@!`!$`
M``"+"`$`$0```)T(`0`D````KP@!`!4```#4"`$`$@```.H(`0`.````_0@!
M`!D````,"0$`"````"8)`0`-````+PD!``H````]"0$`!P```$@)`0`/````
M4`D!``8```!@"0$`"P```&<)`0`'````<PD!``@```!["0$`!0```(0)`0`?
M````B@D!``8```"J"0$`$````+$)`0`(````P@D!``T```#+"0$`"````-D)
M`0`1````X@D!`!(```#T"0$`*@````<*`0`L````,@H!`!H```!?"@$`"0``
M`'H*`0`*````A`H!`!4```"/"@$`!0```*4*`0`4````JPH!``0```#`"@$`
M$````,4*`0`&````U@H!``<```#="@$`'@```.4*`0`H````!`L!``H````M
M"P$`'````#@+`0`:````50L!``\```!P"P$`%````(`+`0`$````E0L!``0`
M``":"P$`"P```)\+`0`%````JPL!``8```"Q"P$`"````+@+`0`&````P0L!
M``H```#("P$`&P```-,+`0`T````[PL!`#0````D#`$`(````%D,`0`I````
M>@P!`"````"D#`$`00```,4,`0`:````!PT!`"@````B#0$`*0```$L-`0!1
M````=0T!`"\```#'#0$`(@```/<-`0`&````&@X!``@````A#@$`!0```"H.
M`0`(````,`X!`!D````Y#@$`&0```%,.`0`J````;0X!`",```"8#@$`+@``
M`+P.`0`T````ZPX!``@````@#P$`%P```"D/`0`*````00\!``<```!,#P$`
M(0```%0/`0`0````=@\!``X```"'#P$`"P```)8/`0`'````H@\!`!,```"J
M#P$`"````+X/`0`(````QP\!``L```#0#P$`"@```-P/`0`4````YP\!``\`
M``#\#P$`,@````P0`0`+````/Q`!``4```!+$`$`!0```%$0`0`7````5Q`!
M``\```!O$`$`!````'\0`0`*````A!`!``D```"/$`$`"P```)D0`0`-````
MI1`!``P```"S$`$`#@```,`0`0`%````SQ`!``0```#5$`$`#0```-H0`0`R
M````Z!`!`$4````;$0$`%P```&$1`0`>````>1$!`!0```"8$0$`%````*T1
M`0`'````PA$!``X```#*$0$`*@```-D1`0`&````!!(!``P````+$@$`#0``
M`!@2`0`1````)A(!``L````X$@$`-@```$02`0`*````>Q(!`"(```"&$@$`
M"P```*D2`0`/````M1(!`#(```#%$@$`)0```/@2`0`P````'A,!`#$```!/
M$P$`+0```($3`0`V````KQ,!``X```#F$P$`!0```/43`0`.````^Q,!`!,`
M```*%`$`!P```!X4`0`:````)A0!``@```!!%`$`$0```$H4`0`'````7!0!
M`!0```!D%`$`&````'D4`0`'````DA0!``4```":%`$`#````*`4`0`,````
MK10!`!(```"Z%`$`!````,T4`0`'````TA0!``H```#:%`$`"P```.44`0`,
M````\10!``X```#^%`$`#@````T5`0`%````'!4!``4````B%0$`+@```"@5
M`0`F````5Q4!`",```!^%0$``P```*(5`0`2````IA4!``8```"Y%0$`'@``
M`,`5`0`8````WQ4!`"4```#X%0$`#0```!X6`0`#````+!8!``<````P%@$`
M`@```#@6`0`,````.Q8!`!4```!(%@$`"P```%X6`0`9````:A8!`"````"$
M%@$`$@```*46`0`%````N!8!``H```"^%@$`%0```,D6`0`2````WQ8!``P`
M``#R%@$`!````/\6`0`'````!!<!``D````,%P$`#````!87`0!2````(Q<!
M`!<```!V%P$`)````(X7`0`2````LQ<!``<```#&%P$`!@```,X7`0`.````
MU1<!`"(```#D%P$`'0````<8`0`,````)1@!``T````R&`$`%0```$`8`0`2
M````5A@!``\```!I&`$`%````'D8`0`;````CA@!`!````"J&`$`:0```+L8
M`0`:````)1D!`!<```!`&0$`)P```%@9`0`:````@!D!`!<```";&0$`&P``
M`+,9`0`9````SQD!`!\```#I&0$`$P````D:`0`(````'1H!``<````F&@$`
M"````"X:`0`)````-QH!`!4```!!&@$`#0```%<:`0`&````91H!`",```!L
M&@$`$P```)`:`0`#````I!H!`$8```"H&@$`/P```.\:`0`W````+QL!`%<`
M``!G&P$`!0```+\;`0`?````Q1L!`"\```#E&P$`"@```!4<`0`(````(!P!
M``T````I'`$`+0```#<<`0`$````91P!`$\```!J'`$`)0```+H<`0`<````
MX!P!``L```#]'`$`'P````D=`0`=````*1T!`"4```!''0$`(````&T=`0`D
M````CAT!`"````"S'0$`"P```-0=`0`'````X!T!``T```#H'0$`#````/8=
M`0`7`````QX!``8````;'@$`.0```"(>`0`,````7!X!``<```!I'@$`&0``
M`'$>`0`)````BQX!`!,```"5'@$`"0```*D>`0`$````LQX!`!````"X'@$`
M"@```,D>`0`(````U!X!``@```#='@$`!````.8>`0`+````ZQX!``P```#W
M'@$`$@````0?`0`1````%Q\!``P````I'P$`&@```#8?`0`/````41\!``<`
M``!A'P$`.@```&D?`0`-````I!\!`!0```"R'P$`#@```,<?`0`,````UA\!
M`!L```#C'P$`+````/\?`0`3````+"`!`!P```!`(`$`*````%T@`0`&````
MAB`!``<```"-(`$`$P```)4@`0`%````J2`!``0```"O(`$`%P```+0@`0`*
M````S"`!``P```#7(`$`"0```.0@`0`&````[B`!``D```#U(`$`"````/\@
M`0`)````""$!``H````2(0$`$0```!TA`0`&````+R$!`!@````V(0$`#@``
M`$\A`0`.````7B$!``T```!M(0$`"P```'LA`0`=````AR$!``L```"E(0$`
M`@```+$A`0`<````M"$!``<```#1(0$`!@```-DA`0!E````X"$!``D```!&
M(@$`!P```%`B`0`F````6"(!`#@```!_(@$`&@```+@B`0`J````TR(!`#L`
M``#^(@$`*````#HC`0`T````8R,!`!D```"8(P$`%0```+(C`0`%````R",!
M``<```#.(P$`"````-8C`0`'````WR,!``4```#G(P$`!P```.TC`0`.````
M]2,!``D````$)`$`!@````XD`0`(````%20!``L````>)`$`!P```"HD`0`(
M````,B0!``<````[)`$`%@```$,D`0`)````6B0!``8```!D)`$`"P```&LD
M`0`<````=R0!`!0```"4)`$`!P```*DD`0`1````L20!``@```##)`$`"```
M`,PD`0`%````U20!`!````#;)`$`$````.PD`0`&````_20!`!D````$)0$`
M"@```!XE`0`<````*24!``<```!&)0$`!0```$XE`0`0````5"4!`!0```!E
M)0$`"P```'HE`0`-````AB4!`!@```"4)0$`%P```*TE`0`$````Q24!``D`
M``#*)0$`"@```-0E`0`'````WR4!``(```#G)0$`#@```.HE`0`(````^24!
M`!\````")@$`/@```"(F`0`C````828!`#@```"%)@$`,0```+XF`0`G````
M\"8!`&0````8)P$`%````'TG`0!5````DB<!`#@```#H)P$`2@```"$H`0!;
M````;"@!`"@```#(*`$`.````/$H`0`H````*BD!`"P```!3*0$`)P```(`I
M`0`;````J"D!`#X```#$*0$`J0$```,J`0`H````K2L!`",```#6*P$`%P``
M`/HK`0!(````$BP!`(4```!;+`$`,````.$L`0!!````$BT!`%L```!4+0$`
M20```+`M`0`=````^BT!`!@````8+@$`(0```#$N`0`?````4RX!`"L```!S
M+@$`(0```)\N`0`G````P2X!`!T```#I+@$`$0````<O`0`S````&2\!`"4`
M``!-+P$`)P```',O`0`@````FR\!`!\```"\+P$`,````-PO`0!I````#3`!
M`"L```!W,`$`,@```*,P`0`Q````UC`!`$$````(,0$`,P```$HQ`0`E````
M?C$!`#T```"D,0$`90```.(Q`0!-````2#(!`"\```"6,@$`+@```,8R`0`P
M````]3(!`%0````F,P$`@P```'LS`0!:````_S,!`$@```!:-`$`2@```*,T
M`0`R````[C0!`"\````A-0$`+````%$U`0`M````?C4!`'$```"L-0$`;P``
M`!XV`0"S````CC8!`!<```!"-P$`)0```%HW`0`R````@#<!`"D```"S-P$`
M/@```-TW`0`B````'#@!`%(````_.`$`5````)(X`0`E````YS@!``L````-
M.0$`L0```!DY`0!S````RSD!`$4````_.@$`(0```(4Z`0`N````ISH!`#``
M``#6.@$`)0````<[`0`<````+3L!`#$```!*.P$`!P```'P[`0`'````A#L!
M``0```",.P$`#0```)$[`0`+````GSL!``X```"K.P$`"P```+H[`0`%````
MQCL!`!````#,.P$``@```-T[`0!9````X#L!``4````Z/`$`$@```$`\`0`$
M````4SP!``<```!8/`$`"````&`\`0`%````:3P!``,```!O/`$`$````',\
M`0`*````A#P!``P```"//`$`$P```)P\`0`-````L#P!``(```"^/`$`!P``
M`,$\`0`&````R3P!`!0```#0/`$`#````.4\`0`8````\CP!``8````+/0$`
M$@```!(]`0`,````)3T!``,````R/0$`*@```#8]`0`$````83T!``8```!F
M/0$`!P```&T]`0`?````=3T!`#4```"5/0$`+@```,L]`0`O````^CT!`!<`
M```J/@$`(````$(^`0`;````8SX!`!@```!_/@$`)````)@^`0`?````O3X!
M`!H```#=/@$`(````/@^`0`:````&3\!`#(````T/P$`+P```&<_`0`:````
MES\!`"L```"R/P$`'P```-X_`0`C````_C\!`!\````B0`$`&@```$)``0`E
M````74`!`"8```"#0`$`)0```*I``0`D````T$`!`!@```#U0`$`'0````Y!
M`0`D````+$$!`!@```!100$`(@```&I!`0`5````C4$!`"4```"C00$`/```
M`,E!`0`?````!D(!`",````F0@$`'P```$I"`0`@````:D(!`!H```"+0@$`
M&````*9"`0`F````OT(!`!X```#F0@$`*0````5#`0`>````+T,!``D```!.
M0P$`#````%A#`0`7````94,!`"\```!]0P$`)````*U#`0`'````TD,!``\`
M``#:0P$`%````.I#`0`.````_T,!``T````.1`$`)````!Q$`0`%````040!
M``<```!'1`$`(@```$]$`0`E````<D0!`!,```"81`$`&@```*Q$`0`=````
MQT0!`!H```#E1`$`!P````!%`0#'````"$4!``L```#010$`%0```-Q%`0`,
M````\D4!``8```#_10$`"0````9&`0`+````$$8!``T````<1@$`'0```"I&
M`0`7````2$8!``8```!@1@$`,P```&=&`0`3````FT8!`!,```"O1@$`!P``
M`,-&`0`&````RT8!``\```#21@$`!P```.)&`0`R````ZD8!`"$````=1P$`
M$P```#]'`0`,````4T<!`!$```!@1P$`,@```')'`0`.````I4<!``\```"T
M1P$`$````,1'`0`(````U4<!`!T```#>1P$`"0```/Q'`0`*````!D@!``4`
M```12`$`%````!=(`0`*````+$@!`!T````W2`$`"````%5(`0`?````7D@!
M``@```!^2`$`&@```(=(`0`G````HD@!``8```#*2`$`%0```-%(`0`'````
MYT@!``@```#O2`$`"0```/A(`0`_`````DD!``<```!"20$`#P```$I)`0`.
M````6DD!`!````!I20$`"0```'I)`0`)````A$D!``@```".20$`$P```)=)
M`0`'````JTD!`!D```"S20$`"@```,U)`0`7````V$D!`!0```#P20$`"@``
M``5*`0`,````$$H!`!<````=2@$`!````#5*`0`J````.DH!`!$```!E2@$`
M!P```'=*`0`)````?TH!``(```")2@$`$````(Q*`0`8````G4H!``,```"V
M2@$`"````+I*`0`&````PTH!``<```#*2@$`#0```-)*`0`+````X$H!`!0`
M``#L2@$`%0````%+`0`.````%TL!`"\````F2P$`(````%9+`0`<````=TL!
M``P```"42P$`,0```*%+`0`%````TTL!`!(```#92P$`/P```.Q+`0`2````
M+$P!``H````_3`$`!@```$I,`0`$````44P!``0```!63`$`"@```%M,`0`3
M````9DP!``4```!Z3`$`!@```(!,`0`&````ATP!``D```".3`$`!````)A,
M`0`,````G4P!``H```"J3`$`(````+5,`0`%````UDP!`!@```#<3`$`&0``
M`/5,`0`?````#TT!`!T````O30$`$0```$U-`0`"````7TT!``0```!B30$`
M"@```&=-`0`&````<DT!``4```!Y30$``P```']-`0`,````@TT!`$4```"0
M30$`&@```-9-`0`U````\4T!`"4````G3@$`*````$U.`0!3````=DX!`!D`
M``#*3@$`<@```.1.`0`@````5T\!`#4```!X3P$`(0```*Y/`0!%````T$\!
M`#`````64`$`'P```$=0`0`?````9U`!`"@```"'4`$`*0```+!0`0`F````
MVE`!`"4````!40$`*````"=1`0`H````4%$!`"(```!Y40$`(0```)Q1`0`P
M````OE$!`!(```#O40$`$P````)2`0`0````%E(!`'D````G4@$`"0```*%2
M`0!R````JU(!`',````>4P$`?````))3`0`K````#U0!`%0````[5`$`%P``
M`)!4`0`6````J%0!``\```"_5`$`90```,]4`0`?````-54!`%$```!550$`
M-P```*=5`0`V````WU4!`#X````65@$`00```%56`0!#````EU8!`$````#;
M5@$`/@```!Q7`0!`````6U<!`$4```"<5P$`.0```.)7`0`?````'%@!`$``
M```\6`$`'P```'U8`0`<````G5@!`%$```"Z6`$`%`````Q9`0`*````(5D!
M``4````L60$`!@```#)9`0`(````.5D!`!(```!"60$`$````%59`0`3````
M9ED!`!T```!Z60$`#P```)A9`0`/````J%D!``0```"X60$`"P```+U9`0`'
M````R5D!``4```#160$`%````-=9`0`'````[%D!``@```#T60$`#P```/U9
M`0`(````#5H!``P````66@$`#P```"-:`0`&````,UH!`!0````Z6@$`!@``
M`$]:`0`,````5EH!`!4```!C6@$`"````'E:`0`$````@EH!``H```"'6@$`
M!````)):`0`&````EUH!``<```">6@$`!````*9:`0`'````JUH!`!D```"S
M6@$``@```,U:`0`)````T%H!``8```#:6@$`)P```.%:`0`$````"5L!``L`
M```.6P$`"0```!I;`0`/````)%L!`!,````T6P$`!P```$A;`0`'````4%L!
M``8```!86P$`!@```%];`0`0````9EL!`!(```!W6P$`!@```(I;`0`)````
MD5L!`!$```";6P$`,P```*U;`0`B````X5L!``<````$7`$`!P````Q<`0`+
M````%%P!``4````@7`$``@```"9<`0`K`0``*5P!`$T```!570$`OP```*-=
M`0!D````8UX!`+X```#(7@$`D````(=?`0!#````&&`!`#P```!<8`$`*P``
M`)E@`0`N````Q6`!`"D```#T8`$`*````!YA`0!%````1V$!`$<```"-80$`
M2@```-5A`0!'````(&(!`$4```!H8@$`2````*YB`0`Y````]V(!`$8````Q
M8P$`2````'AC`0`P````P6,!`$4```#R8P$`1@```#AD`0!,````?V0!`#0`
M``#,9`$`,@````%E`0!I````-&4!`#````">90$`)0```,]E`0"(````]64!
M`$````!^9@$`]@```+]F`0!*````MF<!`"P````!:`$`A0```"YH`0!,````
MM&@!`!0````!:0$`$P```!9I`0`/````*FD!``4````Z:0$`"0```$!I`0`)
M````2FD!``,```!4:0$`"P```%AI`0`1````9&D!`"4```!V:0$`%````)QI
M`0`3````L6D!`!$```#%:0$`"P```-=I`0`H````XVD!``P````,:@$`%0``
M`!EJ`0`;````+VH!`"$```!+:@$`"@```&UJ`0`4````>&H!`!8```"-:@$`
M!P```*1J`0`1````K&H!`"X```"^:@$`%0```.UJ`0`.`````VL!``H````2
M:P$`#P```!UK`0`1````+6L!`!P````_:P$`+0```%QK`0`K````BFL!`"$`
M``"V:P$`+0```-AK`0`<````!FP!`!4````C;`$`&0```#EL`0`/````4VP!
M`!L```!C;`$`$````']L`0`0````D&P!``8```"A;`$`!@```*AL`0!"````
MKVP!`#P```#R;`$`'@```"]M`0`Y````3FT!`$P```"(;0$`:P```-5M`0!G
M````06X!`'$```"I;@$`;0```!MO`0`\````B6\!`!(```#&;P$`$P```-EO
M`0`,````[6\!`!$```#Z;P$`$@````QP`0`%````'W`!`"L````E<`$`$@``
M`%%P`0`*````9'`!``D```!O<`$`"@```'EP`0`S````A'`!`"T```"X<`$`
M!@```.9P`0`A````[7`!``D````/<0$`!P```!EQ`0`5````(7$!`"(````W
M<0$`$0```%IQ`0`6````;'$!`!H```"#<0$`'0```)YQ`0`J````O'$!`!L`
M``#G<0$`%`````-R`0`2````&'(!`!$````K<@$`+@```#UR`0`<````;'(!
M`!T```")<@$`&0```*=R`0!E````P7(!`$(````G<P$`'P```&IS`0`P````
MBG,!``,```"[<P$`"@```+]S`0`\````RG,!``X````'=`$`"@```!9T`0`+
M````(70!``<````M=`$`!P```#5T`0`%````/70!``H```!#=`$`"0```$YT
M`0`+````6'0!`!T```!D=`$`#@```()T`0`2````D70!`"````"D=`$`&P``
M`,5T`0`S````X70!``L````5=0$`'P```"%U`0`2````074!`!X```!4=0$`
M#P```'-U`0`3````@W4!`!(```"7=0$`#P```*IU`0`B````NG4!`!@```#=
M=0$`!P```/9U`0`&````_G4!``@````%=@$`*`````YV`0`&````-W8!``H`
M```^=@$`$@```$EV`0`*````7'8!`!0```!G=@$`$P```'QV`0`M````D'8!
M``H```"^=@$`$0```,EV`0`'````VW8!`!,```#C=@$`'````/=V`0`:````
M%'<!`#T````O=P$`.@```&UW`0`)````J'<!``P```"R=P$`$@```+]W`0`(
M````TG<!``4```#;=P$`!P```.%W`0`,````Z7<!`!H```#V=P$`20```!%X
M`0`7````6W@!`"D```!S>`$`+0```)UX`0`T````RW@!`#D`````>0$`#0``
M`#IY`0`)````2'D!``H```!2>0$`"````%UY`0`T````9GD!`$@```";>0$`
M,P```.1Y`0!>````&'H!`#(```!W>@$`,@```*IZ`0`R````W7H!`$8````0
M>P$`+@```%=[`0`[````AGL!`#(```#">P$`.````/5[`0`E````+GP!`"@`
M``!4?`$`.0```'U\`0`Z````MWP!`!L```#R?`$`#`````Y]`0`@````&WT!
M`"@````\?0$`!@```&5]`0`+````;'T!`!X```!X?0$`)@```)=]`0`'````
MOGT!``<```#&?0$`$P```,Y]`0`)````XGT!``@```#L?0$`-0```/5]`0`+
M````*WX!`!`````W?@$`!P```$A^`0`&````4'X!``4```!7?@$`!P```%U^
M`0`&````97X!``L```!L?@$`+0```'A^`0`6````IGX!`!(```"]?@$`"```
M`-!^`0`'````V7X!`!````#A?@$`!0```/)^`0`/````^'X!``<````(?P$`
M$P```!!_`0`)````)'\!``@````N?P$`!````#=_`0`-````/'\!``@```!*
M?P$`&@```%-_`0`1````;G\!`"(```"`?P$`%@```*-_`0`(````NG\!``H`
M``##?P$`#````,Y_`0`'````VW\!`!4```#C?P$``P```/E_`0`L````_7\!
M`!,````J@`$`*0```#Z``0`&````:(`!``<```!O@`$`"0```'>``0`'````
M@8`!`$````")@`$`*@```,J``0`&````]8`!``4```#\@`$`&@````*!`0`A
M````'8$!`#\````_@0$`.P```'^!`0`C````NX$!`"(```#?@0$`5P````*"
M`0`L````6H(!`!(```"'@@$`"@```)J"`0`7````I8(!``\```"]@@$`#0``
M`,V"`0`2````VX(!`!(```#N@@$`$@````&#`0`3````%(,!``T````H@P$`
M$P```#:#`0`%````2H,!`!D```!0@P$`&@```&J#`0`7````A8,!`!D```"=
M@P$`)````+>#`0`$````W(,!``L```#A@P$`$````.V#`0!$````_H,!`!``
M``!#A`$`'@```%2$`0`(````<X0!`!(```!\A`$`0@```(^$`0`%````TH0!
M``0```#8A`$`'@```-V$`0`9````_(0!`!$````6A0$`'@```"B%`0`M````
M1X4!`#8```!UA0$`$@```*R%`0`H````OX4!`"4```#HA0$`&0````Z&`0`&
M````*(8!`!D````OA@$`%@```$F&`0`5````8(8!`!\```!VA@$`$````):&
M`0`D````IX8!`"@```#,A@$`$0```/6&`0`)````!X<!`!$````1AP$`"@``
M`".'`0`/````+H<!`!T````^AP$`$0```%R'`0`(````;H<!``0```!WAP$`
M#````'R'`0`-````B8<!``D```"7AP$`$0```*&'`0`&````LX<!``<```"Z
MAP$`$````,*'`0`0````TX<!``D```#DAP$`"@```.Z'`0`+````^8<!``X`
M```%B`$`#P```!2(`0`#````)(@!``X````HB`$`#````#>(`0`1````1(@!
M`!T```!6B`$`(````'2(`0`1````E8@!`!4```"GB`$`%P```+V(`0`%````
MU8@!`!\```#;B`$`%P```/N(`0`8````$XD!`#8````LB0$`0P```&.)`0`L
M````IXD!`#0```#4B0$`#0````F*`0`)````%XH!``T````AB@$`!````"^*
M`0`+````-(H!`!@```!`B@$`$````%F*`0`*````:HH!`!````!UB@$`*P``
M`(:*`0`N````LHH!`#X```#AB@$`,0```""+`0`L````4HL!`!X```!_BP$`
M*````)Z+`0!$````QXL!`!X````,C`$`/@```"N,`0`7````:HP!`"P```""
MC`$`,````*^,`0`\````X(P!`#\````=C0$`(@```%V-`0`H````@(T!`#<`
M``"IC0$`,0```.&-`0`M````$XX!`"\```!!C@$`/````'&.`0`?````KHX!
M`"0```#.C@$`/P```/..`0`<````,X\!`"L```!0CP$`*0```'R/`0`C````
MIH\!`#$```#*CP$`$0```/R/`0#$````#I`!`#H```#3D`$`*0````Z1`0`K
M````.)$!`"T```!DD0$`+P```)*1`0`U````PI$!`"````#XD0$`*````!F2
M`0`N````0I(!`#$```!QD@$`.0```*.2`0`T````W9(!`)`````2DP$`-```
M`*.3`0`8````V),!`"T```#QDP$`*P```!^4`0`O````2Y0!`$0```![E`$`
M2@```,"4`0`/````"Y4!``8````;E0$`"@```"*5`0`*````+94!`!`````X
ME0$`#@```$F5`0`4````6)4!`"@```!ME0$`#P```):5`0`,````II4!``0`
M``"SE0$`$0```+B5`0`*````RI4!``\```#5E0$`$@```.65`0`>````^)4!
M`!`````7E@$`2P```"B6`0`'````=)8!`!@```!\E@$`!@```)66`0`/````
MG)8!`!4```"LE@$`%0```,*6`0`0````V)8!``(```#IE@$`!P```.R6`0`1
M````])8!``4````&EP$`$0````R7`0`2````'I<!``8````QEP$`#@```#B7
M`0`(````1Y<!``8```!0EP$`$````%>7`0`/````:)<!`!\```!XEP$`(0``
M`)B7`0`H````NI<!`"@```#CEP$`"@````R8`0`&````%Y@!`!$````>F`$`
M%0```#"8`0`/````1I@!``\```!6F`$`$0```&:8`0`H````>)@!`!T```"A
MF`$`/@```+^8`0`-````_I@!`"`````,F0$`&@```"V9`0`7````2)D!`#H`
M``!@F0$`*P```)N9`0`2````QYD!``4```#:F0$`&P```."9`0`&````_)D!
M`"\````#F@$`00```#.:`0`*````=9H!``H```"`F@$`%0```(N:`0`,````
MH9H!`!(```"NF@$`$@```,&:`0`&````U)H!`#(```#;F@$`&0````Z;`0`F
M````*)L!`!8```!/FP$`)@```&:;`0`(````C9L!``L```"6FP$`+````**;
M`0!`````SYL!``@````0G`$`%0```!F<`0`(````+YP!``\````XG`$`/0``
M`$B<`0`/````AIP!``P```"6G`$`!0```*.<`0`$````J9P!``<```"NG`$`
M"0```+:<`0`/````P)P!`!$```#0G`$`%0```.*<`0`8````^)P!`!X````1
MG0$`'0```#"=`0`>````3IT!`"````!MG0$`!P```(Z=`0`(````EIT!``@`
M``"?G0$`!P```*B=`0`6````L)T!``4```#'G0$`"0```,V=`0`A````UYT!
M`!<```#YG0$`#@```!&>`0`,````()X!``P````MG@$`&0```#J>`0!#````
M5)X!`#8```"8G@$`#````,^>`0`6````W)X!`'H```#SG@$`&@```&Z?`0!`
M````B9\!`!$```#*GP$`!P```-R?`0`$````Y)\!`!4```#IGP$`)@```/^?
M`0`8````)J`!`"<````_H`$`!P```&>@`0`*````;Z`!``<```!ZH`$`#```
M`(*@`0`&````CZ`!``T```"6H`$`#````*2@`0`2````L:`!``P```#$H`$`
M%P```-&@`0`+````Z:`!``H```#UH`$`#@````"A`0`+````#Z$!``H````;
MH0$`#````":A`0`?````,Z$!`!L```!3H0$`30```&^A`0`7````O:$!``8`
M``#5H0$`%@```-RA`0`$````\Z$!`"<```#XH0$`,0```""B`0`>````4J(!
M`!T```!QH@$`*P```(^B`0`J````NZ(!`"P```#FH@$`+0```!.C`0`;````
M0:,!``8```!=HP$`'````&2C`0`.````@:,!`!<```"0HP$``P```*BC`0`'
M````K*,!`!````"THP$`$@```,6C`0`-````V*,!`!8```#FHP$`"P```/VC
M`0`&````":0!`!(````0I`$`$@```".D`0`.````-J0!``<```!%I`$`#@``
M`$VD`0`/````7*0!`"$```!LI`$`!@```(ZD`0`*````E:0!``@```"@I`$`
M"P```*FD`0`6````M:0!`!$```#,I`$``P```-ZD`0`4````XJ0!``@```#W
MI`$`!@````"E`0`Y````!Z4!`!@```!!I0$`C````%JE`0`9````YZ4!``P`
M```!I@$`!@````ZF`0`.````%:8!``@````DI@$`"@```"VF`0`'````.*8!
M``P```!`I@$`%@```$VF`0`2````9*8!``(```!WI@$`"````'JF`0`-````
M@Z8!``T```"1I@$`#@```)^F`0`1````KJ8!`!8```#`I@$`!@```->F`0`'
M````WJ8!`!````#FI@$`"````/>F`0`*`````*<!``4````+IP$`!0```!&G
M`0`@````%Z<!``L````XIP$`!@```$2G`0`D````2Z<!`!$```!PIP$`(@``
M`(*G`0`&````I:<!``L```"LIP$`#@```+BG`0`%````QZ<!``D```#-IP$`
M"@```->G`0`%````XJ<!``4```#HIP$`#@```.ZG`0`,````_:<!``L````*
MJ`$`$@```!:H`0`(````*:@!``<````RJ`$`%@```#JH`0`<````4:@!`!4`
M``!NJ`$`"0```(2H`0`*````CJ@!``0```"9J`$`"0```)ZH`0`(````J*@!
M`!0```"QJ`$`%````,:H`0`+````VZ@!``8```#GJ`$`#0```.ZH`0`&````
M_*@!`$`````#J0$`10```$2I`0!"````BJD!`"L```#-J0$`!0```/FI`0`/
M````_ZD!``,````/J@$`!@```!.J`0`;````&JH!`!0````VJ@$`"````$NJ
M`0`(````5*H!`",```!=J@$`"````(&J`0"@````BJH!``<````KJP$`$```
M`#.K`0`$````1*L!`#X```!)JP$`"````(BK`0`,````D:L!``@```">JP$`
M"P```*>K`0`/````LZL!``@```##JP$`"````,RK`0`%````U:L!`!L```#;
MJP$`-````/>K`0`W````+*P!`#<```!DK`$`+````)RL`0`S````R:P!`$4`
M``#]K`$`0P```$.M`0`O````AZT!`%@```"WK0$`-````!"N`0!*````1:X!
M`"T```"0K@$`$````+ZN`0`0````SZX!``L```#@K@$`(P```.RN`0`D````
M$*\!`!<````UKP$`(````$VO`0`,````;J\!``X```![KP$`"@```(JO`0`,
M````E:\!`"X```"BKP$`*@```-&O`0`_````_*\!``8````\L`$`'@```$.P
M`0`P````8K`!`!P```"3L`$`%@```+"P`0`&````Q[`!``L```#.L`$`"@``
M`-JP`0`0````Y;`!`"4```#VL`$`1@```!RQ`0"1````8[$!`'0```#UL0$`
M#P```&JR`0`,````>K(!``T```"'L@$`&P```)6R`0`7````L;(!``X```#)
ML@$`!0```-BR`0`5````WK(!`!4```#TL@$`$P````JS`0`6````'K,!``P`
M```ULP$`%P```$*S`0`T````6K,!`(T```"/LP$`$````!VT`0`%````+K0!
M`!(````TM`$`"0```$>T`0`*````4;0!``H```!<M`$`&@```&>T`0`7````
M@K0!`!````":M`$`%0```*NT`0`0````P;0!`!8```#2M`$`%P```.FT`0`6
M`````;4!`!,````8M0$`$P```"RU`0`<````0+4!`!L```!=M0$`(````'FU
M`0`_````FK4!`!D```#:M0$`&````/2U`0`7````#;8!`!8````EM@$`$@``
M`#RV`0`<````3[8!`!L```!LM@$`$P```(BV`0`3````G+8!`#````"PM@$`
M&P```.&V`0`<````_;8!`$(````:MP$`'P```%VW`0`%````?;<!`!0```"#
MMP$`+0```)BW`0`A````QK<!`"8```#HMP$`)0````^X`0`=````-;@!`",`
M``!3N`$`(P```'>X`0`<````F[@!`"(```"XN`$`00```-NX`0`B````';D!
M`"<```!`N0$`)P```&BY`0`@````D+D!`"````"QN0$`(P```-*Y`0`I````
M]KD!`"(````@N@$`(P```$.Z`0`-````9[H!`!@```!UN@$`!````(ZZ`0`(
M````D[H!``H```"<N@$`%````*>Z`0`&````O+H!`!4```##N@$`!````-FZ
M`0`+````WKH!``<```#JN@$`!@```/*Z`0`%````^;H!`!,```#_N@$`!@``
M`!.[`0`(````&KL!``8````CNP$`!@```"J[`0`*````,;L!`!`````\NP$`
M&@```$V[`0`0````:+L!`!$```!YNP$`"@```(N[`0`8````EKL!``4```"O
MNP$`.0```+6[`0`6````[[L!`!$````&O`$`$0```!B\`0`.````*KP!``L`
M```YO`$`$@```$6\`0`O````6+P!``@```"(O`$`"````)&\`0`D````FKP!
M`!(```"_O`$`#P```-*\`0`&````XKP!``P```#IO`$`"0```/:\`0`%````
M`+T!`"0````&O0$`"@```"N]`0`-````-KT!`!,```!$O0$`&````%B]`0`C
M````<;T!`"<```"5O0$`"@```+V]`0`#````R+T!``H```#,O0$`(@```->]
M`0`'````^KT!``,````"O@$`$0````:^`0`2````&+X!``<````KO@$`!P``
M`#.^`0`J````.[X!``T```!FO@$`$@```'2^`0`*````A[X!`!,```"2O@$`
M%P```*:^`0`,````OKX!``X```#+O@$`#@```-J^`0`.````Z;X!``0```#X
MO@$`$0```/V^`0!#````#[\!``8```!3OP$`!0```%J_`0`G````8+\!`!8`
M``"(OP$`-````)^_`0`5````U+\!``X```#JOP$`$P```/F_`0`/````#<`!
M`!`````=P`$`#P```"[``0`>````/L`!`!\```!=P`$`)@```'W``0`(````
MI,`!``@```"MP`$`%````+;``0`+````R\`!``L```#7P`$`$0```./``0`$
M````]<`!``T```#ZP`$`#0````C!`0`F````%L$!`%$````]P0$`'0```(_!
M`0`-````K<$!``T```"[P0$`"````,G!`0`(````TL$!``X```#;P0$`#@``
M`.K!`0`5````^<$!``D````/P@$``@```!G"`0`-````',(!`",````JP@$`
M!@```$["`0`%````5<(!``D```!;P@$`"P```&7"`0`)````<<(!``D```![
MP@$`%````(7"`0`.````FL(!`$````"IP@$`$P```.K"`0`&````_L(!``@`
M```%PP$`#P````[#`0`$````'L,!``4````CPP$`:P```"G#`0`,````E<,!
M``\```"BPP$`!P```++#`0`%````NL,!`"H```#`PP$`,0```.O#`0`1````
M'<0!``H````OQ`$`&0```#K$`0`*````5,0!``D```!?Q`$`*@```&G$`0`>
M````E,0!`"D```"SQ`$`*````-W$`0`/````!L4!``4````6Q0$`!P```!S%
M`0`-````),4!``4````RQ0$`$P```#C%`0`6````3,4!`"T```!CQ0$`%0``
M`)'%`0`P````I\4!`"0```#8Q0$`!@```/W%`0!9````!,8!`!X```!>Q@$`
M$````'W&`0`6````CL8!`"0```"EQ@$`9@```,K&`0`8````,<<!``<```!*
MQP$`(````%+'`0`(````<\<!``8```!\QP$`'@```(/'`0`%````HL<!``H`
M``"HQP$`+@```+/'`0`M````XL<!`!,````0R`$`!@```"3(`0`D````*\@!
M`%8```!0R`$`'P```*?(`0`<````Q\@!`"T```#DR`$``@```!+)`0`9````
M%<D!``<````OR0$`$@```#?)`0`1````2LD!``8```!<R0$`!P```&/)`0`4
M````:\D!``8```"`R0$`"````(?)`0`+````D,D!``<```"<R0$`"@```*3)
M`0`+````K\D!``<```"[R0$`$````,/)`0`0````U,D!``\```#ER0$`"0``
M`/7)`0`,````_\D!``T````,R@$`"@```!K*`0`)````)<H!``H````OR@$`
M"````#K*`0`;````0\H!`!0```!?R@$`&@```'3*`0`6````C\H!`"````"F
MR@$`!P```,?*`0`6````S\H!``,```#FR@$`!P```.K*`0`%````\LH!``4`
M``#XR@$`"0```/[*`0`0````",L!`!(````9RP$`,P```"S+`0`N````8,L!
M`"(```"/RP$`)````+++`0`7````U\L!`!\```#ORP$`&0````_,`0`'````
M*<P!``0````QS`$`#````#;,`0`,````0\P!``8```!0S`$`'@```%?,`0`)
M````=LP!``H```"`S`$`#P```(O,`0`%````F\P!``P```"AS`$`"0```*[,
M`0`1````N,P!`!````#*S`$`"@```-O,`0`)````YLP!``4```#PS`$`!P``
M`/;,`0`'````_LP!``0````&S0$``P````O-`0!9````#\T!`"T```!IS0$`
M1````)?-`0`;````W,T!`#T```#XS0$`#P```#;.`0!`````1LX!`$````"'
MS@$`%0```,C.`0`I````WLX!`!X````(SP$`'@```"?/`0`C````1L\!`#8`
M``!JSP$`#0```*'/`0`[````K\\!`#````#KSP$`&0```!S0`0`4````-M`!
M`!4```!+T`$`%0```&'0`0`/````=]`!`!0```"'T`$`%0```)S0`0`A````
MLM`!`#T```#4T`$`/@```!+1`0!!````4=$!`#X```"3T0$`/@```-+1`0`_
M````$=(!`#T```!1T@$`;0```(_2`0`>````_=(!`!H````<TP$`#P```#?3
M`0`[````1],!`"L```"#TP$`+0```*_3`0`*````W=,!`"D```#HTP$`*P``
M`!+4`0`%````/M0!`"8```!$U`$`%@```&O4`0`.````@M0!``X```"1U`$`
M%P```*#4`0`(````N-0!``H```#!U`$`#````,S4`0`.````V=0!`"\```#H
MU`$`#P```!C5`0`/````*-4!``P````XU0$`)@```$75`0`.````;-4!``@`
M``![U0$`!````(35`0`0````B=4!``X```":U0$`"P```*G5`0`U````M=4!
M``(```#KU0$`"````.[5`0`7````]]4!`"@````/U@$`#````#C6`0`'````
M1=8!``8```!-U@$`$0```%36`0`1````9M8!``0```!XU@$`-P```'W6`0`C
M````M=8!`!X```#9U@$`=P```/C6`0`7````<-<!`$@```"(UP$`)P```-'7
M`0`2````^=<!``8````,V`$`#@```!/8`0`(````(M@!`!0````KV`$`"0``
M`$#8`0`1````2M@!``X```!<V`$`'@```&O8`0`5````BM@!``4```"@V`$`
M$````*;8`0`:````M]@!`#(```#2V`$`%0````79`0`8````&]D!`!,````T
MV0$`'P```$C9`0`'````:-D!`!<```!PV0$`%````(C9`0`4````G=D!`!8`
M``"RV0$`$````,G9`0`6````VMD!``L```#QV0$`"0```/W9`0`%````!]H!
M`!T````-V@$`!@```"O:`0`/````,MH!``@```!"V@$`$@```$O:`0`&````
M7MH!`!8```!EV@$`%````'S:`0`M````D=H!`#,```"_V@$`%0```//:`0`'
M````"=L!``@````1VP$`'@```!K;`0`+````.=L!`!L```!%VP$`!P```&';
M`0`C````:=L!``<```"-VP$`"````)7;`0`D````GML!`#L```##VP$`"P``
M`/_;`0`B````"]P!`!H````NW`$`%@```$G<`0`0````8-P!``0```!QW`$`
M#@```';<`0`.````A=P!``<```"4W`$`#@```)S<`0`(````J]P!``4```"T
MW`$`"0```+K<`0`=````Q-P!`"8```#BW`$`/P````G=`0`H````2=T!`"4`
M``!RW0$`'P```)C=`0`[````N-T!`!X```#TW0$`*@```!/>`0`R````/MX!
M`%T```!QW@$`+P```,_>`0`E````_]X!``T````EWP$`"````#/?`0`*````
M/-\!``H```!'WP$`$0```%+?`0`6````9-\!`$<```![WP$`)0```,/?`0`X
M````Z=\!`$`````BX`$`"0```&/@`0`F````;>`!``L```"4X`$`%````*#@
M`0`G````M>`!``P```#=X`$`&0```.K@`0`,````!.$!``X````1X0$`#@``
M`"#A`0`(````+^$!``\````XX0$`$````$CA`0`/````6>$!`!L```!IX0$`
M&@```(7A`0`U````H.$!``L```#6X0$`!0```.+A`0`5````Z.$!`!X```#^
MX0$`%P```!WB`0`#````->(!``P````YX@$`$````$;B`0`%````5^(!``X`
M``!=X@$`"````&SB`0`/````=>(!``4```"%X@$`!P```(OB`0`0````D^(!
M`$D```"DX@$`4````.[B`0`G````/^,!`#(```!GXP$`*0```)KC`0`1````
MQ.,!``P```#6XP$`$````./C`0`R````].,!``8````GY`$`#0```"[D`0`.
M````/.0!`!4```!+Y`$`#0```&'D`0!<````;^0!``H```#,Y`$`)0```-?D
M`0`5````_>0!`!8````3Y0$`+````"KE`0`F````5^4!`#X```!^Y0$`00``
M`+WE`0`[````_^4!`#0````[Y@$`#@```'#F`0`,````?^8!`!,```",Y@$`
M'````*#F`0`(````O>8!`!H```#&Y@$`"````.'F`0`3````ZN8!``<```#^
MY@$`'P````;G`0`7````)N<!`!`````^YP$`!````$_G`0`2````5.<!`!,`
M``!GYP$`%````'OG`0`&````D.<!``<```"7YP$`$P```)_G`0`.````L^<!
M``\```#"YP$`$0```-+G`0`1````Y.<!``8```#VYP$`!P```/WG`0`H````
M!>@!`"0````NZ`$`(````%/H`0`(````=.@!``\```!]Z`$`!@```(WH`0`8
M````E.@!`"D```"MZ`$`*0```-?H`0`*`````>D!``,````,Z0$`"````!#I
M`0`#````&>D!`!(````=Z0$`%````##I`0`+````1>D!`!@```!1Z0$`(P``
M`&KI`0`7````CND!``8```"FZ0$`"@```*WI`0`4````N.D!`!<```#-Z0$`
M#````.7I`0`&````\ND!``H```#YZ0$`#`````3J`0`5````$>H!`'D````G
MZ@$`'P```*'J`0`O````P>H!`!0```#QZ@$`"`````;K`0`'````#^L!`!<`
M```7ZP$`(@```"_K`0`=````4NL!`!<```!PZP$`&````(CK`0`B````H>L!
M`!T```#$ZP$`$@```.+K`0`E````]>L!`"8````;[`$`&````$+L`0"#````
M6^P!`"@```#?[`$`'P````CM`0`X````*.T!`"<```!A[0$`'@```(GM`0`K
M````J.T!`",```#4[0$`)P```/CM`0`4````(.X!``L````U[@$`"````$'N
M`0`)````2NX!``H```!4[@$`%0```%_N`0`+````=>X!``8```"![@$`.P``
M`(CN`0`K````Q.X!``8```#P[@$`10```/?N`0!5````/>\!`#0```"3[P$`
MG````,CO`0`+````9?`!`#<```!Q\`$`+P```*GP`0`2````V?`!``@```#L
M\`$`$P```/7P`0!$````"?$!``P```!.\0$`6````%OQ`0!(````M/$!`"@`
M``#]\0$`%````";R`0`B````._(!`"(```!>\@$`+````('R`0`B````KO(!
M`"L```#1\@$`'P```/WR`0`5````'?,!``<````S\P$`$````#OS`0`4````
M3/,!``T```!A\P$`"P```&_S`0!1````>_,!``P```#-\P$`'@```-KS`0`Z
M````^?,!`!$````T]`$`'P```$;T`0`)````9O0!``4```!P]`$`&````';T
M`0`*````C_0!``D```":]`$`"0```*3T`0`'````KO0!``<```"V]`$`"0``
M`+[T`0`2````R/0!`!P```#;]`$`#P```/CT`0`?````"/4!`!`````H]0$`
M"````#GU`0!`````0O4!``T```"#]0$`)@```)'U`0`+````N/4!``H```#$
M]0$`&````,_U`0`F````Z/4!``P````/]@$`(@```!SV`0`K````/_8!``L`
M``!K]@$`"````'?V`0`A````@/8!``T```"B]@$`&0```+#V`0`;````RO8!
M`!0```#F]@$`%@```/OV`0`2````$O<!``4````E]P$`"0```"OW`0`(````
M-?<!``D````^]P$`"@```$CW`0`4````4_<!``<```!H]P$`&````'#W`0`0
M````B?<!``H```":]P$`"````*7W`0`,````KO<!`"$```"[]P$`#````-WW
M`0`"````ZO<!`",```#M]P$`!0```!'X`0`*````%_@!`'H````B^`$`"@``
M`)WX`0`(````J/@!`"H```"Q^`$`.@```-SX`0`:````%_D!`"X````R^0$`
M70```&'Y`0`C````O_D!`#,```#C^0$`+P```!?Z`0`E````1_H!``8```!M
M^@$`#0```'3Z`0`(````@OH!``D```"+^@$`!0```)7Z`0`(````F_H!`!(`
M``"D^@$`"@```+?Z`0`)````POH!``L```#,^@$`"P```-CZ`0`:````Y/H!
M``@```#_^@$`"0````C[`0`5````$OL!``H````H^P$`"@```#/[`0`%````
M/OL!`"8```!$^P$`&````&O[`0`'````A/L!`!(```",^P$`"0```)_[`0`S
M````J?L!``@```#=^P$`&````.;[`0`8````__L!``8````8_`$`!@```!_\
M`0`-````)OP!`!P````T_`$`!@```%'\`0`)````6/P!``L```!B_`$`'```
M`&[\`0`+````B_P!``T```"7_`$`'````*7\`0`8````POP!``8```#;_`$`
M"P```.+\`0`0````[OP!``T```#__`$``P````W]`0`.````$?T!``@````@
M_0$`+````"G]`0`^````5OT!`!T```"5_0$`,````+/]`0`N````Y/T!`"X`
M```3_@$`C@```$+^`0`6````T?X!`&,```#H_@$`.````$S_`0!A````A?\!
M`&D```#G_P$`(0```%$``@!-````<P`"`#P```#!``(`1P```/X``@`>````
M1@$"`!@```!E`0(`(P```'X!`@#]`0``H@$"`"@```"@`P(`'0```,D#`@`=
M````YP,"`$D````%!`(`H````$\$`@`T````\`0"`$<````E!0(`6@```&T%
M`@!D````R`4"`"`````M!@(`'@```$X&`@`<````;08"`!\```"*!@(`)```
M`*H&`@`;````SP8"`"8```#K!@(`&@```!('`@`6````+0<"`#$```!$!P(`
M*@```'8'`@`D````H0<"`#P```#&!P(`&@````,(`@`R````'@@"`'$```!1
M"`(`*P```,,(`@`\````[P@"`#L````L"0(`.@```&@)`@`R````HPD"`"D`
M``#6"0(`1P`````*`@!M````2`H"`%\```"V"@(`,````!8+`@`P````1PL"
M`#,```!X"P(`3@```*P+`@"#````^PL"`&8```!_#`(`30```.8,`@!3````
M-`T"`$D```"(#0(`)P```-(-`@`G````^@T"`"0````B#@(`>````$<.`@!W
M````P`X"`,X````X#P(`'`````<0`@`L````)!`"`#8```!1$`(`+@```(@0
M`@!0````MQ`"`!P````($0(`0````"41`@!-````9A$"`#\```"T$0(`!0``
M`/01`@#(````^A$"`(8```##$@(`1@```$H3`@`B````D1,"`"X```"T$P(`
M/@```.,3`@`G````(A0"`!P```!*%`(`+````&<4`@`)````E!0"`!8```">
M%`(``P```+44`@`6````N10"``P```#0%`(`#0```-T4`@`+````ZQ0"``<`
M``#W%`(`#0```/\4`@`'````#14"`'4````5%0(``@```(L5`@`6````CA4"
M``0```"E%0(`!P```*H5`@`&````LA4"``4```"Y%0(`!0```+\5`@`5````
MQ14"``H```#;%0(`"@```.85`@`2````\14"``\````$%@(``@```!06`@`'
M````%Q8"``L````?%@(`$@```"L6`@`-````/A8"`!D```!,%@(`!@```&86
M`@`9````;18"``H```"'%@(``P```)(6`@!;````EA8"``0```#R%@(`!@``
M`/<6`@`'````_A8"`"<````&%P(`3````"X7`@!&````>Q<"`$<```#"%P(`
M*@````H8`@`=````-1@"`"(```!3&`(`'````'88`@`R````DQ@"`"H```#&
M&`(`)````/$8`@`G````%AD"`"X````^&0(`*P```&T9`@`I````F1D"`!8`
M``##&0(`*@```-H9`@`?````!1H"`",````E&@(`(0```$D:`@`9````:QH"
M`"P```"%&@(`,@```+(:`@`S````Y1H"`"<````9&P(`'0```$$;`@`D````
M7QL"`"D```"$&P(`'0```*X;`@`G````S!L"`!D```#T&P(`(P````X<`@`Z
M````,AP"`"(```!M'`(`)@```)`<`@`D````MQP"`"4```#<'`(`'`````(=
M`@`D````'QT"`#````!$'0(`'@```'4=`@`Q````E!T"`"$```#&'0(`"0``
M`.@=`@`0````\AT"`"(````#'@(`1P```"8>`@`L````;AX"``P```";'@(`
M#P```*@>`@`7````N!X"`!(```#0'@(`$````.,>`@`G````]!X"``8````<
M'P(`"@```",?`@`E````+A\"`"@```!4'P(`$P```'T?`@`;````D1\"`"@`
M``"M'P(`'````-8?`@`/````\Q\"`/0````#(`(`%0```/@@`@`7````#B$"
M``P````F(0(`"0```#,A`@`7````/2$"`"(```!5(0(`&P```'@A`@`=````
ME"$"`!X```"R(0(`"0```-$A`@`^````VR$"``\````:(@(`%@```"HB`@`'
M````02("``8```!)(@(`&P```%`B`@`1````;"("`$X```!^(@(`(@```,TB
M`@`<````\"("`!@````-(P(`(P```"8C`@!A````2B,"`!<```"L(P(`%P``
M`,0C`@`:````W","`!````#W(P(`)`````@D`@`1````+20"`!(````_)`(`
M#````%(D`@`8````7R0"``L```!X)`(`'0```(0D`@`I````HB0"`!\```#,
M)`(`"P```.PD`@`S````^"0"`#T````L)0(`!P```&HE`@`3````<B4"``<`
M``"&)0(`!P```(XE`@`)````EB4"`$D```"@)0(`!@```.HE`@`-````\24"
M`!````#_)0(`%@```!`F`@`+````)R8"``P````S)@(`!P```$`F`@`1````
M2"8"``\```!:)@(`'````&HF`@`7````AR8"`!0```"?)@(`&````+0F`@`,
M````S28"``X```#:)@(`+````.DF`@`.````%B<"`#8````E)P(`$````%PG
M`@`.````;2<"``D```!\)P(``P```(8G`@`4````BB<"`!L```"?)P(``P``
M`+LG`@`)````OR<"``<```#))P(`"@```-$G`@`.````W"<"``X```#K)P(`
M&P```/HG`@`<````%B@"``X````S*`(`-````$(H`@`:````=R@"`!4```"2
M*`(`#0```*@H`@`R````MB@"``D```#I*`(`%P```/,H`@!6````"RD"`!4`
M``!B*0(`&0```'@I`@`*````DBD"``0```"=*0(`!````*(I`@`6````IRD"
M`!4```"^*0(`!0```-0I`@`&````VBD"``H```#A*0(`#@```.PI`@`%````
M^RD"``X````!*@(`$@```!`J`@`@````(RH"`"````!$*@(`'````&4J`@`C
M````@BH"`"@```"F*@(`(````,\J`@`5````\"H"``(````&*P(`!`````DK
M`@`-````#BL"``8````<*P(`!0```",K`@`$````*2L"`!$````N*P(`>```
M`$`K`@`M````N2L"`"\```#G*P(`)@```!<L`@`C````/BP"`$@```!B+`(`
M&0```*LL`@".````Q2P"`"(```!4+0(`5````'<M`@`A````S"T"`%<```#N
M+0(`+@```$8N`@`<````=2X"`"$```"2+@(`*0```+0N`@!`````WBX"`#,`
M```?+P(`+P```%,O`@`_````@R\"`!T```##+P(`)0```.$O`@`G````!S`"
M`$T````O,`(`$````'TP`@`;````CC`"`!0```"J,`(`=0```+\P`@`*````
M-3$"`(L```!`,0(`A0```,PQ`@!^````4C("`#@```#1,@(`>@````HS`@`<
M````A3,"`"H```"B,P(`$@```,TS`@!E````X#,"`"0```!&-`(`/P```&LT
M`@`S````JS0"`#,```#?-`(`+P```!,U`@`T````0S4"`$8```!X-0(`-P``
M`+\U`@`U````]S4"`#@````M-@(`.0```&8V`@`M````H#8"`!T```#.-@(`
M1@```.PV`@`B````,S<"`!P```!6-P(`60```',W`@`F````S3<"``L```#T
M-P(`!0`````X`@`&````!C@"``@````-.`(`(@```!8X`@`.````.3@"`"``
M``!(.`(`*````&DX`@`+````DC@"``\```">.`(`"P```*XX`@`)````NC@"
M``H```#$.`(`"0```,\X`@`6````V3@"``T```#P.`(`#@```/XX`@`4````
M#3D"``<````B.0(`#@```"HY`@`1````.3D"``P```!+.0(`%@```%@Y`@`-
M````;SD"``H```!].0(`%0```(@Y`@`&````GCD"``<```"E.0(`#@```*TY
M`@`$````O#D"``8```#!.0(`!P```,@Y`@`$````T#D"``8```#5.0(`(P``
M`-PY`@`"`````#H"``@````#.@(`!`````PZ`@!)````$3H"``,```!;.@(`
M"P```%\Z`@`)````:SH"`"\```!U.@(`+P```*4Z`@`+````U3H"``@```#A
M.@(`!0```.HZ`@`)````\#H"`!H```#Z.@(`(````!4[`@`+````-CL"``P`
M``!".P(`%0```$\[`@`S````93L"`"D```"9.P(`"@```,,[`@`'````SCL"
M`!\```#6.P(`!0```/8[`@`#````_#L"``$```#<!```+`0``#<%``!P`P``
M`````+P!``"%`@``J@0```````"M`@``XP$```````"?`````````!$```";
M`@```````````````````````.````!\!0``(P0``/,%``!.````ZP,``,4&
M```E!P````````T$``##!0```````$4#````````N@(```````!Z`@``QP(`
M`,D"``"0`P``'@<```````!N`0```````-\$``!4!0``D`0```$$````````
M#P(``(<"````````ZP(``),"``";`P```````$(!```````````````````@
M!P``C08``$0!``!R!@``>0$``!P#``"2`0``7P$``-X!``#F`@``/00``'\#
M``""!@``*0<```````!5`0````````````!3!P``"0$``)0&````````````
M`$\%``#0!@```````#<"``!W`@``$`$``/T#``!\`@```````"\```"[!0``
MX`4````````Z!P``]0(```````"M`P```````*@#````````8P```.<&````
M````Z0$``-4#``#4!@``6P(`````````````'00``(0'````````$P4`````
M``!?!```SP4```(#````````-`````````!7````>@```-@!````````````
M`,H"``"7`@``=@,``,P%``"!`0``"@0``````````````````((!``!R`0``
MD@```/$!````````_00````````(!P``LP``````````````KP(````````P
M`P``-`0```T"`````0``/`,``/8!``#L`0``R`,``%H#`````````````-8"
M```Y`P``#P$``+<%``#;!`````````````"^`P``=@0```````#.!0``<@,`
M`(<#``"?!```%@0``&L&``")!@``VP$```````!+!@``.P<``.D#`````@``
M```````&``!4!P``QP$``&8$``#]`0```````'$```"G!```````````````
M````0P,`````````````?`````````"?!0```````*0&```O`P``L@8`````
M``!+````$P(```````!8!0``Z@,``"H&``"M!```608``&0$````````XP4`
M`+$"````````D`8``)H#``#*`````````+,%````````L`,```````!]`@``
MTP,``"H'``"*`P``3`````````!9``````````````!(`@``I@```.H$````
M````_`0``(,$``!/!P``)P0``%`'````````^@0``*4"``#!!0``````````
M``"]`P``0P(``'@'````````@`0``$\"```D!@````````````"P`0``````
M`/T`````````6@4``*H#```;`@```````&\#```C`0```````%0$````````
M`````*\#``##`0````````````!J!0``DP$`````````````1P8``/P```!)
M!P``;````````````````````$@!````````:`,``*,"``"F!````````.@!
M````````*@,````````X!```A```````````````#P```)H```#\`P``:08`
M``````";!@``+P4``)X`````````&@8``+P$```G````30<``-\%````````
M`P```',#```6!P``"@$`````````````A0$````````$`P``O0```+4```"N
M`P```````+L!``!I!P```````#(```!9`P``TP(```````#D!```V@8`````
M``#I!```TP0``+4$```#!P``&`<``"T"``#*!```-@$``,8"````````^`8`
M`"<%```%`````````*`!``!O!```B@$``!@&```0`@``/@,``&<&``""`P``
M5@0``+8!``!I````Y`$``($#``!3!@``70````````!U````V08``(P"````
M````,@4``#X"``!T!@``"P$```H&```H````^@(``&H"```Y!0``JP$``$,'
M```3`P``:`<``)\#```U`0```````+X%```-!P``]04``*$````1!```"0<`
M`#`&```Y!@```````&4"```5`P```````(4#```+!````````#4```"R!```
M,08```````!K!P``*08``/X`````````"@,``$L'````````Z`,``.($````
M`````````(L````C`@````````````#7!@``R08``)0```##````_@8``%8"
M``!L!```I00``,L#``#?````$`0``"L'``!L`0``I@(``$@$``"_`0``````
M```````I`````````%8'```I`0``A@````````#C```````````````:`@``
M^00```````!$!0``;@<``!0'``#1!@``]08``"L#``"`!@````````````!5
M!0``]00```````#%`@````````````!\!```+````($````@````S`,``'L%
M``#_````DP,``#4$```_!0``^08``*P#``"-`@```````(P!``!2`@``P@8`
M``````#(!````````'$&````````K````+D"``!!!P``.`8````````<!P``
M`````'0!```R!```6@$```````![!```6P0```````!^!0``A@4``/4`````
M````.0(``%0&``!%!```2@(`````````````IP,```8%```"!P```````/0$
M``"!!P``"@(``.4```#^`P``L@```````````````````%X%``"4`P``````
M``````#$`0``0@,``'8!``#V!@```````/X!```;`0``;P```(X!```7!0``
M`````%D!``"A`P``Z`0``+H```!G!```B00``)8```#7!0``;0(``)8"````
M````1@8``)@!```6`@```````.T$````````0@```)4&```;!@``>00``#L"
M````````,00``"H````I!0``<P(`````````````Z`8``)H%``#@!@``Y`8`
M``0```!A````2@$``"H"``#G`P``CP8``$P'````````>P,``,T!``"9!```
MQ@````````#6`P```````-("```[!```,`0``.\$````````+P8```P#``")
M!0``10````````#(!@``Z04``+X"```X`P``VP4``(@%``#I`@```````*``
M```[`P```````'`'````````9P<``!H```#J`0``9`8`````````````````
M```````=`0``4`4``#T&````````Q@,``#`!```7````"`0``+\```##`P``
MX`$``"(```"!!````````.T"````````G@$``*X!`````````````&X&``"_
M!@``0P0```````!*!P```````.(#``"I!@``!0(``,<`````````!0,`````
M`````````````+@$```$`@````4```,&```Y!```'P0``'4$``#"````)@<`
M`,,$``#X`P````````````!P`@``EP0``"<'```Q`P``Q04``$8%``!T!P``
M`````)$&````````````````````````*P0````````"!```=@```/H```!@
M!```&0```+D```"B`0``:0(``%H````B!@``4`(``(D"````````"0,`````
M```4!```S`(``*\$```````````````````S`````````#0%````````&0$`
M```````C!0``D04``!P"``#Z!0``BP,``-P&``"M!0``FP4```H%````````
M``````````#V!0``C@0``*H"``#C`@``#`<``*D#```4`P```````/L$``!3
M`@``Q@4```````#0!```4P$``#`"``#@`@``KP```%(%````````:P$``+<&
M``````````<```````#X`0``-P0``+,#``#0!0``E0$``$$$``#T`@``E@0`
M`(4```"W`@``40```)\&```,````;@(``'L'````````DP4``#8`````````
MB`$```<````<!@``@04``%4```#$!0``WP(````````0!@``N08``(@#``!F
M`0`````````````T`@``G00``-X&````````%04```````!^!P``3@0``%<"
M``#J!@``W`$```````!)`0``<`0``.4"```5!@```````*(```!5`P``'@``
M`$P!```-````^P$```````#5!0``&P````$"``!F`P``!@0``(<$``#Q`@``
M`````"('``#A!@``[04```````"H!0``@@```#8"``!&`P```````+@&``!_
M!````````'\&```\!0``/@4``"8$``#S!```F0```+(#````````G@4``&4%
M```H`@``$@,``$$!````````L0````````!M!0```````,H%```Z`0``^@$`
M``````"D`P``NP```$X%``"+!0``8@<````````P!0``D00````````Y````
MEP8``.X#```1`P``IP$```````!?`P``;`<``(0$```<!```B````%<%``#-
M!0``B@(```$!`````````````,D#``"$`P```````````````````````!0&
M``"``0```````$4'``"2`@``CP```#8'``#V!```G`(```````#2!@``(`(`
M`!8%``"/`0``10(``.0%``#]`@``80,``"L!``"#````B@````````##!@``
M[P(``,@"``"E!0```````-`#`````````````)T!``"L!0``G08````````1
M`0``L04``!4"``#>!```-P```'<!``"A!@``*P4``'$$````````S`8`````
M``!P`````````"D"`````````````%D$```7!@``00```&(```#_`P``NP0`
M`,T"``"7!0``!0$``%`$````````OP4``$4%```^`0``U0$```````"B!0``
M`````-,`````````+0<`````````````'0```&H'``#`!0``@`4``(D`````
M``````````````#7!```)`$``%P&`````````````.,&``"-!```7`$``$D$
M``"+`@``[@8``$<$``"D`0```````',&```J`0````````````"<!@``Q@0`
M`&@&````````VP,```````#2`P``+@8``(,#``"C!@``$P8``.,#```9`@``
MP0$``$`#````````O00`````````````%@,```$#``"3````@P4``/<```!W
M!P``6`,``+T&``!W!0``ZP8``-\#``!2`P```````/T%````````G@8``.<"
M`````````````/````"(!@``4P```-T"``"K!`````````,!``"!`@``!@``
M`'$"````````3`,```````!@!@``400``'$#``#]!@``*@0``.X```"<!0``
MVP8``%D"``#B`@``_P4``+4!``````````````8&``!*!0````````````!<
M`P``;P4``%T'``#N`0``&P0`````````````````````````````!`4``'H$
M```2!````````"\$``#E!````````&T#````````4@$``"T&``#4!```7P4`
M``````!]!@``F````!H#``"R`0``TP8``,P`````````EP$```````!.!P``
M-0<```````"=````EP```#8$```W`0``A`$``',!````````80$```X```"U
M!@``1`<`````````````N`4``````````````````/$%``":!```\@8``%4$
M```!!@``CP,``-$```!O`0``C@8``-`!```L`@``8P(``)8#````````"P,`
M`-4```#T!@``%````'`!````````O@8```````"\`P```````'T#````````
M"P<``#$'````````9P(```````!0!@``E0(````````>!@``>04``#X```!$
M!@``V@```&$&````````$0(``*<```!*!@```````)4$`````````````%@"
M````````*0,```````!#`0``C@4``!,!``"A!0``5@4``-\&``!;`0``&0<`
M``````"J`0``3`0``&4$````````?P(``%$#``"V!0``M04``&D!```"````
MJ00```````!@`0``C0```(0%``"V`P```````#T````?!0``S0```&T````E
M`0``L`0``!X!``!Y!@``C04``/`!``#9````\@,``-$%`````````````"(%
M```?!P```````-T```#8````?@0``'8%```M````8@4``.P$```T`P``R0$`
M``<!```Z`@``]P(``-D!```+`@``/@8``($&````````I````'("``#0`@``
M2P0````````X````W0$```````#.`P``>@4``'L"``"H`````````"@!``#'
M!@``A04```````!L`@``I@4```D"``#``P```````)`%``"4`0``T````+P&
M``">!```\08````````0!P``A@(```````#[`P``KP8``"8"```R`0``00,`
M`%,$`````````````"$"```3!P``?`8``$T%````````W04``)($````````
M(0````T#``"Z!```'0(````````_`````P4``)D!``!0`P``"08``/<%```&
M`P``=04``,H#````````Y0,``/X"``!=!@```````(4$``!4`P```````$("
M``"C!0```````-P%``!D!0`````````````!!P``?P4``'T$``!?````VP``
M````````````)`,```T%```U!0``#P<``#L&```B!`````````````!V`@``
M!P<``$<#````````8@$``(,&````````F`8``!$&``"-`P``J0$``.@```#W
M`P``Y@8``-P```"M`0``QP0```````!*`P``;P<``"$%````````A08``+D$
M``"+!```\00``+D#`````````````$`'``!8!```<0$``+\$``!X!0``"P``
M```````O!P``]0$``,\!````````F04```````#-!@``J04````````>`P``
MC`,``#`````9!```\`4``!<$````````50(``'<``````````````+\#```8
M`P``*`0``!T'`````````````/`$``#N!0``'P,``'@"``#!!````````'X!
M``#R`@``'````+@"```/`P``LP0``)0"``!E!P``"00``&4!```E````6P<`
M```````.!@``,0$`````````!```T00``,$&````````6P,```````!H`0``
MS`$``(8$``!!!@``%@$```````!G`0```````,L```!U`0``[@0``+``````
M````X`,``#P&``"Q!@```````.H```"J````````````````````U00`````
M```$!@```````!T%````````]0,``%0```#>`P``(P```"\!``#R````````
M`,@```#8!````````!D&``#[````0`$``+4"``"K`@``;00````````D!P``
M&````(X"``!5!@``+00``)P#``"P`@``@````%$'``#F!```:04``$,&``#A
M`P```````+D%````````&0,``"X$```4!0```````)D&```+!0```````+,!
M``"$!@``$@8``,(#``#[!@````````````":`@``(`8```````#L`P``````
M`'P!``!D!P``*`,```<#````````C`0``+<#``!_`0``+`8`````````````
M`````+`&``#O`P``8`,``%@!``!&!P``@@0````````S!0``J`8``/,```"S
M`@``2``````````L!0``@`<``.\%``"(`@``$P```$H`````````8@,``,D$
M``"N````ZP0```````!6!@`````````````H!P```@8```````!:`@``````
M`*T&```>!```\@$``.P```!+`P``(0$````````L!P```````&4&````````
M`````)`!``#$`@``SP0``$8"``!C!`````````````!L`P``B@4``"$$``"D
M`@``6P8``/$```#!`P``3`8``#<'`````````````-D$``#4`@```````$<`
M`````````````*X%````````_P8``!X"``#7`P``X@4``!H'``!^`P``.`(`
M`+T"`````````````'X```"=`@``C@```/,&````````70$``!@%``!K`@``
MYP4``*T````[`0``M@0``)@#```2`````````"8%```*``````````,"````
M`````04```````#Y`0``2P4``&T'````````JP```/\"``!"!```\P,`````
M```,!@``V`,```````!-!`````````````````````,``+$#````````````
M`%8```#Y!0``=@<```````!P!@```````-T#``"1`0``,@,``%P%``"R!0``
MJ0```*4!```5````T@```*`#``"/!```/@0``-0!``"L`@``_@0``,L"``#[
M`@``?@8``$`$``#$````AP$``-D#``#S`@```````)(%``"E!@``'08``+<$
M```?``````````````"N`@```````/,!``""!P``&@0```<&````````0P``
M`/`#``#!``````````````!Q!0``(08````````S`0``0@4```````#A`@``
M`````(<&``"B`@``)04``*@"````````@@(``$4&``#``0```````#\"````
M````!P4``$\`````````IP(``!L'``#:`P```````$L"``#[!0``E@$``&X#
M``!7`0```````%X$``!9!0``K`0``+`%``#(!0``D@,```````!X`0``@`(`
M`/H#```O`@```````-<"``!C!P``5@,``$H$``"Q`0``_P$``/$#```0!0``
M``````````#!`@``)`(``#,"``!M`0``5P0``$P"````````GP$``!0"``!0
M````KP$```````!2!P```P,```("``#K`0``A`(`````````````\`(``-@"
M``#&`0``0P4``)@%````````D0````````#^!0``F`0``)P!````````````
M``````#A!0```````,4#```&!P``G@,```````"A`@``B0$``)$#``#:`0``
M=P8`````````````80(``&<%``!]````G0,``#`'``#J`@````````````!-
M`@``+@(``)L!``!Z`P``HP,``*4````,!````````*(&````````)0(``"L"
M``#A````S0,````````X!P``-@4```P!```'!````````$P%````````````
M``X$``#A`0``>@$``#(&``#T`0``3@8``/@$``!M!@``/04``$<'``"Z`0``
M`@$``-<!``#/`P``)`0`````````````<P```.P%```#!``````````````M
M`P``\@0``*4#```7`P``"`8``(L&````````;@0``&H&``!-`0``U@0``&X%
M``!4`0``1`(```````!C!@``QP,```````!<`@``/````"8&``"&`0``````
M``````!B`@````````````"@!0``-`8`````````````[0$``#L%``"H`0``
M"``````````_!@``]`,``!X%``#%!```P@(```````"C````B0,``(8&````
M````'P(``/<!``!)`P``"`(``&\&``"F!@``80<``*8#``!Y`@``L@(``/0%
M``#:!`````````````!S!``````````````(`0``O04``*`&````````/0$`
M`!("``!`!@``=`4``*8!``"#`@```````%T$``#I!@```````,H&````````
M`````.(``````````````'($``!S!P``Q`0``'@$``!>`0``60<``'P#``!]
M`0``9P```!4'`````````````.X"``!K````3P,``"4$````````#0$``&P&
M````````$````&4#```.!0``*`4```````"T!```$P0```````!(!@``````
M````````````)`4```````#/````S@```#,&``#P!@``!`$`````````````
M)@,``,P$``#=!@```````&@$``".`P``&`0``"P#``#*`0``6P4``#P'``#E
M!@``[0```'$'```]!P```````-H"``!_`````````%8!``!]!P``R0```$L!
M```C`P```````)L$```Y`0``Q0```%,%``!-````[`8``(L!``!2````C`8`
M```````5!```N0$``*L#``#(`0```````-@%``#X!0``#@(``"(#````````
MO0$``.0`````````VP(``'D```!;````0`(``````````````````+$$``#"
M!0```````,<%````````H0$``#P!```A`P``^@8``*`$`````````````,L!
M`````````````,(!```Y!P``U@$``&8&``#+!0``Y@,``!L%``"U`P``````
M`#$"``"<!````````#X'``"/!0``U`4``/P!``"N!@``^0(``,0&``#``@``
M@`,``)8%``#.`0```````-8%``"-`0```````+P%```V`P``T@4``'`%````
M````#@,````````````````````````S`P``>@<``+X$``!$`````````,D%
M``#%`0``9@```!8````R`@```````%P$````````'P$``*D"``"0`@``4P,`
M`'H&``"(!```5P<``#\'``!F!0``408``%<#```&`0``:P,``,8&````````
M/`0`````````````[P```$D```#6````CP(``$<%``!:!P``5P8```````!=
M`@``8````#$%````````>P8``/8"``!1`0``+@,```````"[`P```````,X$
M``!&````Y`,``/@"``"&`P``MP```(,'```I!```````````````````-0,`
M`$\$```A!P````````````#5!@``M`,``#T#```:`0``:0,`````````````
M(P<``&,#``!.`@``M@````P"``!H`@`````````````-!@``#P8``*,$````
M````9`$``'0"``!:!```50<``'(%``#$`P```````)D"``!2!@``:@```$4!
M````````V0(`````````````>0<```````!L!0``M`8``"H%``!(!P``````
M`%T#``!W!````````$T&``!^`@``Y@4``(H$``!U`P````````````"X`0``
M(@(``%\"``#-!````````),$``"Z`P``E0````L&`````````````!`#``!R
M!P``.`4``'D#```%!P``-P,`````````````]@,``*$$``#2`0``S@8``.0"
M``!'`0``MP$``.<!````````8`<``&8"```F`0``C`4```````!'`@``%0$`
M`+P```"Z!@``ZP```,,"```Z!0```````/8`````````=0<`````````````
M``````````"6!@``!P(```D```!>````(`,``&,!```<!0``H`(```0'```2
M!P``:`4``````````````````#@!``">`@``.P```'\'``!?!P``M`4``&@`
M``!V!@``1@0``-\!``#O`0``90```'0$````````<P4``/<&``!X````+0$`
M`/P%``!@`@``!04``&\"``"J!0``!08``.L%``!`````204```````!/!@``
MH@0``)H&```L`0``#P0`````````````P`8``"X````6!@``,P<``/(%``""
M!0```````$@#``!=!0``&04``"X!```U`@```````&L%````````3@$``%$"
M````````3P$``#T"``#T````!@(``%P'``!W`P``%`$```````"\`@``````
M``````"V`@``````````````````@P$``-<```"T````````````````````
MN````#H#``#3`0````````````"9`P```````)$"``"G!0``X@$```````"5
M`P```````+X!````````>P$``.4!```G`0``9P,``)P```#=!```U`,``&($
M``#F`0``)P,`````````````JP4```````!!!0``U````!T#````````0@8`
M`.$$````````M`(``)````"5!0``%P<`````````````.@0``"8```!U`@``
M)```````````````404```````#G`````````)\"````````W@````\%````
M````30,````````.!P``:P0``%X#````````;@```*0$``#\`@``+04``.H%
M```_!```FP`````````)!0``#@$```````!>`@````````P%````````=```
M`/D#````````V`8``%P```#2!```I`4``-4"````````(`$``'@&``!(!0``
MX@8```````!"!P``*P`````````_`P``%P$``,L&``!\!P``NP8``.D```":
M`0````````4$``#H!0``JP8``"`$````````$0<``!L#``#.`@``"@<``#$`
M``"B`P``OP(``&H$``#@!```3@,``$0#```2`0``-`<```````"'!0``)P(`
M``````!@!0``[`(``#H```#1`P``W`,``$$"``!I!```M`$``)<#````````
M(`4`````````````&@4``(H&``"N!```,@<``*P!``!2!```O@```",&```(
M`P``=08`````````````P`0``-D%```E`P``[08``&,%`````````@4``)(&
M``#E!0``*P8``&(&````````_P0```````#/`@``[P8``-$!``!)!@``````
M`-X%``!:!@``0`4``*\%``!D````1`0```````!)`@``9@<```@%```U!@``
ME`4``*<&``"[`@````````````!D`P``*`8``.,$``#\!@```````.T#``!T
M`P``^0``````````````6`8``$8!``"Z!0````````````#H`@```````'(`
M``"8`@``M@8``&H#``"C`0``$04``&$$```\`@``U@8``"<&``!8````````
M`-X"``"X`P``>P````````!0`0``T0(```````"S!@``$@4``!<"``!?!@``
MP@0``#H&````````7@8```````"'````)08``-P"````````P````!P!```B
M`0``5`(``)0$``",````V@4``#\!``"H!````````/@````N!P```````/<$
M``#3!0```````#0!````````?04``.8```#/!@``6`<```````!A!0``,P0`
M``0$```N!0```````,L$``"J!@``'P8``&H!```V!@``&`(``'@#``#G!```
M7@<``)T%````````&`$``*P&``"3!@``9`(````````W!@```"`@+4TL("TM
M;65S<V%G93U-15-304=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G92!I;G-T
M96%D(&]F('1H92!D969A=6QT(&]N97,N`"`@+6$L("TM861D/49)3$4@("`@
M("`@($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U
M;"!T;PH@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E(&$@8V]M<&5N
M9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T;PH@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@9V5N97)A=&5D(&-O;7!E;F1I=6TN`"`@+6(L("TM
M8F%S93TO4$%42"`@1G5L;"!P871H('1O('1H92`H2&]R9&4I(&)A<V4@9&ER
M96-T;W)Y('1H870@<VAO=6QD(&)E"B`@("`@("`@("`@("`@("`@("`@=7-E
M9"X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA
M=&EO;G,@=&\@=&AI<R!C;VUP96YD:75M(&9I;&4*("`@("`@("`@("`@("`@
M("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE("AC;VUP96YD
M:75M+G!O(&EN('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@:&]R9&4O
M<&\@9&ER96-T;W)Y+@`@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H
M:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U;'0*("`@
M("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T
M:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2X`("`M9"P@+2UD96)U9R`@("`@("!3
M:&]W(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S
M+@`@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M<&5N9&EU;2!I
M;B!T:&ES(&1I<F5C=&]R>2X`("`M:"P@+2UH96QP("`@("`@("!3:&]W('1H
M:7,@:&5L<"!M97-S86=E+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E
M(&]N;'D@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5
M<V4@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@(%5S92!T
M:&ES(&QO8V%L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($)U:6QD($U/
M(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P(%!/(&9I;&5S(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#
M;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U
M;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#<F5A=&4@82!03R!F:6QE
M(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@("!-97)G92!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&AE
M;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@
M+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M
M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@1V5N97)A=&4@4$]4(&9I
M;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;BP@+2UN;RUC
M;VUP96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@
M=&AE(&-O;7!E;F1I=6TN`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG
M="!U<V4@82!C;VUP96YD:75M+@`@("US+"`M+7-T871I<W1I8W,@("`@("`@
M4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL92X`
M("`M="P@+2UT97-T("`@("`@("!3:&]W('1H92!E>&5C=71E9"!C;VUM86YD
M<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+@`@(&-L96%N=7`@("`@($-L96%N
M<R!T:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS;&%T960@86YD(&]B<V]L
M971E(&5N=')I97,N`"`@8V]M;6ET("`@("`@0V]M;6ET('1R86YS;&%T:6]N
M<R!T;R!T:&4@0U93('-E<G9E<BX`("!C;VUM:70M:&5L<"!#;VUM:70@:&5L
M<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E<BX`("!C;VUP96YD:75M("!296)U
M:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E<G=R
M:71E<R!T:&4*("`@("`@("`@("`@("!C=7)R96YT(&-O;7!E;F1I=6TN`"`@
M97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA=&4@*"YP;W0I(&9I;&5S
M+@`@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N`"`@:6YI
M="`@("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/(&9I;&5S(&9O<B!A(&YE
M=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7,*("`@("`@("`@("`@("!O=F5R=W)I
M=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T:&ES(&QO8V%L92X`("!M
M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@9FEL97,@9G)O;2!T:&4@<W!E
M8VEF:65D(%!/(&9I;&5S+@`@(&UA:V4M:&5L<"`@($UA<FL@86QL(&5N=')I
M97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@=7`M=&\M9&%T92!A;F0*
M("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE(&9O<B!T:&4@;F5X="!E
M>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=0H@("`@("`@("`@("`@('-H
M;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@049415(@=7!D871E+6AE;'`@86YD
M(')E=FES:6YG('1H90H@("`@("`@("`@("`@(&AE;'`@9FEL92X`("!M97)G
M92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F:6QE('=I=&@@=&AE(&-U
M<G)E;G0@4$\@=&5M<&QA=&4@9FEL92X`("!U<&1A=&4@("`@("!2=6X@97AT
M<F%C="!A;F0@;65R9V4@<V5Q=65N="X`("!U<&1A=&4M:&5L<"!%>'1R86-T
M(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H
M(%A-3"!H96QP"B`@("`@("`@("`@("`@9FEL92!A;F0@;65R9V4@=&AE;2!W
M:71H('1H92!E>&ES=&EN9R!O;F5S+@`@)B,Q-3$[("5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@
M9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``
M)60@)7,@86YD("5S`"5D(&)Y=&5S('=R:71T96XN`"5D(&]F("5D(&5N=')I
M97,@;6%R:V5D(&%S('5P+71O+61A=&4`)60M9&%Y(&9O<F5C87-T`"5S("T@
M3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S($9I;F=E<G!R:6YT`"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``
M)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E
M>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(&YO="!W<FET86)L92X`)7,@:7,@
M<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(&YO="!F;W5N
M9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T)R!F:7)S="X`)7,@=&\@)7,@
M;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO
M=&5P860`)7,G<R!487-K;&ES=``G)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC
M92X`)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T
M<GDN`"<E<R<@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"<E<R<@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E871E9#H@
M)7,N`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`
M+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0`Q,B!(
M;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`
M/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N"D]P96YI;F<@
M=&%G(&9O=6YD(&EN(&QI;F4@)60N`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@
M4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`
M06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`
M06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U
M<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U
M<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@)R5S
M)P!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("<E<R<`061D(&$@;F5W('5S
M97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T
M:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S
M<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D
M("<E<R<@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I
M;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`G)7,G('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG(&YE=R!F:6QE
M<R!T;R!R97!O<VET;W)Y.@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D
M9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO
M;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI
M<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!
M;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R
M;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S
M<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A
M9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E
M;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E
M>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I
M9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!
M;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T
M:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I
M;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@
M4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@
M*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE
M`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE
M=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA
M`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L
M86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T
M<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5
M;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE
M8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"
M3T9(($5X8W5S97,`0F%C:V5N9"!N;W0@8V]R<F5C=&QY(&EM<&QE;65N=&5D
M+@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I
M;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!"87-E;&EN
M90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N
M`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@
M9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA
M`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!"
M;W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O
M=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I
M=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6EL9&EN9R!-3R!F:6QE<R!F;W(@
M;6]D=6QE("5S+BXN`$)U:6QD:6YG(&QO8V%L92`E<RXN+B``0G5L9V%R:6$`
M0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-2
M3"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C
M:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB
M;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T
M(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W
M:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X
M:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P
M92!697)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@
M27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I
M;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#
M96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E
M<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC
M871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L
M:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%!A<W-W;W)D`$-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V4@>6]U<B!P87-S
M=V]R9`!#:&%N9VEN9R!087-S=V]R9"!O;B`E<P!#:&%R`$-H96-?:R!,:6YK
M+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A
M;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H:6YE
M<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A"
M:6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y
M<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A;FEN9R!U<"!03R!F
M:6QE<R!F;W(@;6]D=6QE("5S+BXN`$-L96%N:6YG('5P(&QO8V%L92`E<RXN
M+B``0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I
M;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N
M`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3
M:&5L;`!#;VUM86YD(&]P=&EO;G,Z`$-O;6UA;F1S.@!#;VUM96YT`$-O;6UI
M='1I;F<Z`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;W-E($UE
M<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O
M;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F9I<FT@;F5W('!A<W-W
M;W)D.@!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S
M;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN`$-O;G1E;G1S(&]F("<E<R<`0V]N=&EN=64`0V]O:R!)<VQA
M;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'EI;F<@)7,@=&\@
M)7,`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U
M;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)
M344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T
M;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@<V5R=F5R("<E<R<@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8V]P
M>2`E<R!T;R`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO
M8V%L92`E<SH`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`
M0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D
M9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN
M`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S)RX`0V]U
M;&0@;F]T(&UK9&ER("<E<R<N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L
M9"!N;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B!-
M86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E
M8W1O<GD@)R5S)RX`0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N
M`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<FUD:7(@)R5S)RX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO
M="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!U;FQI;FL@)R5S)RX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@)7,`0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,`0V]U
M;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN
M:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`
M0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`
M0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S
M='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N
M`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E
M<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE
M=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!)
M;F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F875L="!097)M:7-S:6]N<P!$969A=6QT('!E<FUI<W-I;VYS`$1E9FEN
M:71I;VYS`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`G)7,G`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES('!E<FUI
M<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@)R5S)RX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT
M`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER
M96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS
M`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W
M;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-
M86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D
M:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<`161U8V%T:6]N`$5G
M>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D
M<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C
M;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E
M<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I
M=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4`16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O
M+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;@!%<75A=&]R
M:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R($-H86YG:6YG(%!A<W-W
M;W)D`$5R<F]R('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N`$5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`G)7,G+@!%<G)O<CH@
M`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X96-U=&EN9SH`17AP86YD
M`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O
M;F5N=`!%>'1R86-T:6YG(&9R;VT@)7,N+BX@`$9'($-O;&]R`$944"!U<&QO
M860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N
M;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N
M`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I
M;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"`Z(`!&86ER`$9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&
M87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E
M<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE($-O
M=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E
M<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U
M<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(
M86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1F]G`$9O;&1E<B`E
M<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P
M87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`
M1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1F]U;F0@87!P;&EC871I;VYS
M.B`E<P!&;W5N9"!D:7)E8W1O<FEE<SH`1G(`1G)A;65S`$9R86YC90!&<F%N
M8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S
M:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@
M`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=7IZ>0!'
M86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB
M:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'
M96YE<F%T:6YG('-T871U<R!F;W(@;6]D=6QE("5S+BXN`$=E;W)G:6$`1V5R
M;6%N>0!'971O<'0@17)R;W(Z(`!':&%N80!':6)R86QT87(`1VEV96X@3F%M
M90!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R
M965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI
M;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U
M<"!P97)M:7-S:6]N<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L
M80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S="!P97)M:7-S:6]N
M<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM
M`$AA>F4`2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<P!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN
M9R!E9&ET;W(`2&5L<&5R`$AE;'!E<B!A<'!L:6-A=&EO;B!T;R!C<F5A=&4@
M86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E"F9R86UE
M=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RX*1F]R(&%N(&EN=')O9'5C=&EO
M;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R>2X`2&5M
M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI
M9V@`2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!(;U]M
M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D
M<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92!T<F%N<VQA=&EO;B!G96YE<F%T;W(`2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E
M<R(`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES960@)7,@
M(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U
M:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P
M87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@
M(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ
M;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I
M`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET
M>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E
M<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W
M:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I
M;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O
M;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@
M8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`
M26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@
M=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z
M("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)E
M8W0@4&%S<W=O<F0`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O
M<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E
M<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN
M9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN:71I86QI>FEN9R!M;V1U;&4@
M)7,N+BX@`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E
M<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R
M90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E
M;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E
M<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E
M<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G
M<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W
M(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF
M>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I
M="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I
M96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV
M86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN
M=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N
M`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O
M9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N
M=#H@)R5S)P!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A
M9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N
M`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY
M`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I
M`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT
M97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA
M>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@
M0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`
M2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%
M54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@
M475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,
M87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`
M3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA
M;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE
M`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`
M3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG
M:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6YK`$QI;FL@<&]I;G1S('1O
M.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@
M=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP
M(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI
M<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES
M="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG(&QI8G)A<FEE<RXN+@!,;V%D:6YG
M+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G
M(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2X`3&]G:6X@9F%I;&5D+@!,;V=O=70`3&]N9R!T97AT`$QO=F4`3&]W
M`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E
M<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N
M:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A
M<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86ME('-U
M<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I
M;F-L=61E('!A=&@N`$UA:VEN9R!D:7)E8W1O<GD@)7,`36%L87=I`$UA;&%Y
M<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@
M;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-
M871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W
M960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA
M>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N
M=2!M;V1E.@!-97)G92!C96QL<P!-97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T
M;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!L;V-A;&4@)7,N+BX@`$UE
M<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD:75M+BXN
M(`!-97)G:6YG('1R86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BX`365S<V%G
M90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G
M92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@
M)R5S)R!I<R!N;W0@9&5F:6YE9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER
M<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%
M05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL
M92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U
M;&4`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L
M:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA
M<V5S`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY
M(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P
M`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O
M<"!D;W=N(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY
M(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4
M($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.
M971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P
M92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE
M='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE
M='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E
M<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E
M<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0Z`$YE
M=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T
M(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP
M;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@
M=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]M;6%N9"!S<&5C
M:69I960N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@
M;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&5N=')Y('=I=&@@
M=&AE(&ED("<E<R<@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N
M`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%L92!S
M<&5C:69I960N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O
M=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D
M+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@
M<G5L97,`3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E
M<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE
M`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R
M9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I
M86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A
M(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O
M<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EC
M90!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J
M96-T`$]B:F5C="!#<F5A=&]R`$]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS
M`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!P87-S
M=V]R9#H`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I
M;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD
M;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]P
M=&EO;G,Z`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N
M86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF
M;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@
M16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R
M>7!T960@1&%T80!02%`@0V]D90!032!,:6=H="!286EN`%!-(%-H;W=E<G,`
M4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!A
M9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/
M8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T
M;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960A`%!A<W-W;W)D
M(&EN8V]R<F5C=`!087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O
M;F9I9W5R960`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E
M(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M`%!E<FUI<W-I;VX@)R5S)R!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VX`4&5R;6ES<VEO;G,@9F]R`%!E<G-O;F%L($EN9F]R;6%T
M:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I
M<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C
M96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D
M('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5P;W)T(&%N>2!B
M=6=S('1O(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T
M=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0
M<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T
M92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;V)L96T_`%!R
M;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O
M<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R
M`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO
M;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@
M86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E
M860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;&%T:6]N<VAI
M<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@
M0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@
M<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R
M;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E
M<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!3
M44P@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@
M4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E<W5L=',@
M*&EN8VQU9&EN9R!(;W)D92DZ`%)E<W5L=',Z`%)E='5R;B!T;R!/<'1I;VYS
M`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A
M;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q
M.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O
M=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@
M365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%--4R!-97-S86=I;F<`4U-(`%-50T-%4U,`4V$`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA
M`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/<'1I;VYS`%-A=F4@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG
M=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N
M`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG
M:6YE<P!396%R8VAI;F<@2&]R9&4@87!P;&EC871I;VYS(&EN("5S`%-E87)C
M:&EN9R!G971T97AT(&)I;F%R:65S+BXN`%-E;&5C="!&:6QE<P!396QE8W0@
M82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N
M97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E
M;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R
M;P!397)I86P@3G5M8F5R`%-E<G9E<@!397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T
M:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y
M;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO
M;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS
M+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R
M86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E
M>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG
M:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B
M87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO
M=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE
M:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R
M<F$@3&5O;F4`4VEG;B!U<`!3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VMI<'!E9"XN+@!3;&]V86MI80!3;&]V96YI80!3
M;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R
M;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;64@
M;V8@4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@
M;6ES<VEN9SH`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3
M;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E
M<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`
M4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL
M`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N
M9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@`%-T;W)A9V4@9F]R;6%T
M`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B
M9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M
M:71T960@<F5Q=65S="!T;R!A9&0@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@
M)R5S)R!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@
M9&5L971E9"`G)7,G+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`G)7,G(&9R;VT@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U
M<&1A=&5D("<E<R<`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA
M<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N
M<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P
M<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`
M4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3
M=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@
M4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M
M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!4
M96UP;&%T92`G)7,G(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I
M;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@
M*%1)4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y
M<W1E;2X`5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VXG="!Y970@97AI
M<W0N($-R96%T:6YG(&$@;F5W(&]N92X`5&AE($944"!E>'1E;G-I;VX@:7,@
M;F]T(&%V86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N
M9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T
M=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D
M871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF
M:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A
M("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@
M)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO
M=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@
M;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K
M(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R
M87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R
M>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO
M;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N
M('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T
M;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&AE;'`@9FEL92`E
M<R!D:61N)W0@<W1A<G0@=VET:"`\/WAM;`!4:&4@:61E;G1I='D@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N
M"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E
M96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE
M(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S
M<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C
M875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@
M<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@
M*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4
M:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES
M="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E
M(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R
M979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M`%1H96UE<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`%1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R
M92!D;V5S;B=T('EE="!E>&ES="!A(&AE;'`@9FEL92!F;W(@)7,N`%1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E;2X@)7,N
M`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E
M;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE
M;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H
M)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R
M>2!R=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H92!F;&%G("UD('1O
M('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BX`
M5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A
M9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A
M:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T
M<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@
M;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N
M`%1H:7,@9FEL92!C;VYT86EN<R!B86-K960@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!F;W(@=&AE(%!A<W-W;W)D(&UO9'5L92!S8W)I<'1S+@!4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N
M`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4
M:&ES(&ES('1H92!M86EN(%!A<W-W;W)D(&UO9'5L92!C;VYF:6=U<F%T:6]N
M(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N9"!O<'1I;VYS(&9O<B!A;&P@
M4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N`%1H:7,@;65S<V%G92!W87,@=W)I
M='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@
M;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S
M8W)I<'0@;75S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE+@!4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A
M;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I
M;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4
M:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O
M9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`
M5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871E9`!4<F%N<VQA=&EO;G,`
M5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`
M5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z
M(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O
M<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B
M)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D
M96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N
M86)L92!T;R!D96QE=&4@)R5S)SH@)7,N`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B
M;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A
M8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@
M`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S
M`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-
M:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@8V]M;6%N9#H@)7,`56YK;F]W
M;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R
M:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E
M('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N
M<VEO;@!5;G1R86YS;&%T960`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E
M<@!5<&1A=&5D("<E<R<N`%5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N
M`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@
M;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-A
M9V4Z`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S
M97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO
M;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&YO="!F
M;W5N9`!5<V5R(&YO="!F;W5N9"X`57-E<B!P97)M:7-S:6]N<P!5<V5R;F%M
M90!5<V5R;F%M92`G)7,G(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E
M<FYA;64Z(`!5<V5R<P!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N
M`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED
M(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L
M96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N
M=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M
M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E
M<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L
M('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M
M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)
M<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE
M($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`
M5V%R;FEN9SH@`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E
M<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R
M86-T97(_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U
M;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@
M969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I
M9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E
M960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<FET:6YG('5P9&%T960@:&5L
M<"!F:6QE('1O("5S+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`
M6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U
M,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M
M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S
M92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T
M:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A;B=T
M(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<P!9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O<F0`66]U(&UU<W0@9VEV92!Y;W5R
M(&]L9"!P87-S=V]R9`!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W
M('!A<W-W;W)D`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A
M9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@
M4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!G971T97AT('9E
M<G-I;VX@:7,@=&]O(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T
M:79E;'DN"DYO="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A8W1E9"X`66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&YE=R!P87-S=V]R
M9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@8F4@;6]R92!T:&%N
M("5D(&-H87)A8W1E<G,@;&]N9R$`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O
M('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N9V5D(0!9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H87)A8W1E<G,@;&]N9R$`66]U
M<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F97)E;G0@9G)O;2!Y;W5R(&-U
M<G)E;G0@<&%S<W=O<F0`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN
M(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA<F%C=&5R<RX`66]U<B!N97<@
M<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA;G5M97)I
M8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@
M870@;&5A<W0@)60@;&]W97)C87-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A
M<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!N=6UE<FEC(&-H87)A
M8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S
M="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@
M;75S="!C;VYT86EN(&%T(&QE<W,@=&AA;B`E9"!W:&ET97-P86-E(&-H87)A
M8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI
M=&5S<&%C92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9',@9&ED;B=T
M(&UA=&-H`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE
M(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T
M92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;
M2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T
M960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE
M("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&5L971E(%)O=P!?
M1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO
M9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?
M4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5
M<V5R<P!A9&1R97-S(&)O;VL`86X@97)R;W(@:&%S(&]C8W5R960Z`&-A;&5N
M9&%R`&-A;&T`8VQI8VL@:&5R90!D;VYE`&9A:6QE9`!F86QL:6YG`&9I;&4`
M9F]U;F0Z(`!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z`&EM;65D:6%T
M90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)
M4T\N`&YA;64`;F]T(&-H86YG960`;F]T(&9O=6YD`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`
M<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T
M96%D>0!T87-K(&QI<W0`=&5M<&YA;2@I(&9A:6QE9"$`=&AE($AO<F1E(%!/
M(&9I;&4@9F]R('1H92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z`'1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YN86UE9`!U<&1A=&5D
M`'5S97(@<V5L96-T`'9#87)D`'<Z`%!R;VIE8W0M260M5F5R<VEO;CH@<&%S
M<W=D"E!/5"U#<F5A=&EO;BU$871E.B`R,#`S+3`S+3`V(#$Q.C0V*S`Q,#`*
M4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP,RTP-B`Q,3HT.2LP,3`P"DQA<W0M
M5')A;G-L871O<CH@1WEU;&$@4WIA8F\@/&=Y=69I0'-Z=&%K:2YH=3X*3&%N
M9W5A9V4M5&5A;3H@2'5N9V%R:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*
M34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M."UB:70*`"`@+4TL("TM;65S<V%G93U-15-304=%("!5<V4@=&AI<R!C;VUM
M:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N97,N`"`@+6$L
M("TM861D/49)3$4@("`@("`@($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O
M;7!E;F1I=6TN(%5S969U;"!T;PH@("`@("`@("`@("`@("`@("`@("`@("!I
M;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T
M;PH@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V5N97)A=&5D(&-O;7!E
M;F1I=6TN`"`@+6(L("TM8F%S93TO4$%42"`@1G5L;"!P871H('1O('1H92`H
M2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H870@<VAO=6QD(&)E"B`@("`@("`@
M("`@("`@("`@("`@=7-E9"X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@($UE
M<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI<R!C;VUP96YD:75M(&9I;&4*
M("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0@;VYE("AC;VUP96YD:75M+G!O(&EN('1H90H@("`@("`@("`@("`@("`@
M("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+@`@("UC+"`M+6-O;7!E;F1I
M=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@
M=&AE(&1E9F%U;'0*("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M
M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2X`("`M9"P@
M+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE(&5X
M96-U=&5D(&)I;F%R:65S+@`@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A
M=&4@8V]M<&5N9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2X`("`M:"P@+2UH96QP
M("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+@`@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C
M86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C86QE
M/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92X`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($)U:6QD($U/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M
M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P(%!/(&9I
M;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#
M<F5A=&4@82!03R!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F:6QE<R!O;FQY
M(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I
M(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!O;FQY
M('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T
M<F%N<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN`"`@+6XL("TM;F\M8V]M
M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M+@`@("US+"`M+7-T
M871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN
M(&$@;&]C86P@9FEL92X`("`M="P@+2UT97-T("`@("`@("!3:&]W('1H92!E
M>&5C=71E9"!C;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+@`@(&-L
M96%N=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS
M;&%T960@86YD(&]B<V]L971E(&5N=')I97,N`"`@8V]M;6ET("`@("`@0V]M
M;6ET('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BX`("!C;VUM:70M
M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E<BX`("!C
M;VUP96YD:75M("!296)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI
M;F<Z(%1H:7,@;W9E<G=R:71E<R!T:&4*("`@("`@("`@("`@("!C=7)R96YT
M(&-O;7!E;F1I=6TN`"`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA
M=&4@*"YP;W0I(&9I;&5S+@`@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP
M(&UE<W-A9V4N`"`@:6YI="`@("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/
M(&9I;&5S(&9O<B!A(&YE=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7,*("`@("`@
M("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T
M:&ES(&QO8V%L92X`("!M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@9FEL
M97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I;&5S+@`@(&UA:V4M:&5L<"`@
M($UA<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@
M=7`M=&\M9&%T92!A;F0*("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE
M(&9O<B!T:&4@;F5X="!E>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=0H@
M("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@049415(@
M=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H90H@("`@("`@("`@("`@(&AE
M;'`@9FEL92X`("!M97)G92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F
M:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL92X`("!U<&1A
M=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N="X`("!U<&1A
M=&4M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F
M<F]M('1H92!%;F=L:7-H(%A-3"!H96QP"B`@("`@("`@("`@("`@9FEL92!A
M;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+@`@)B,Q-3$[
M("5S(&OI<WIE;B#A;&P@87H@86SA8F(@:VEJ96SV;'0@:V%R8F%N=&%R=.%S
M:2!F96QA9&%T;VL@96QVZ6=ZZ7/I<F4N`"`H)7,@;F%P<&%L(&5Z96SU='0I
M`"`H06QT+6)I;&QE;G1Y^R`E<RD`("@E<R!N87`@;?IL=F$I`"`H;6$I`"`H
M:&]L;F%P*0`@*'1E9VYA<"D`(#H@`"5D("5S(.ES("5S`"5D(&)Y=&5S('=R
M:71T96XN`"5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4`
M)60@;F%P;W,@96SU<F5J96QZZ7,`)7,@+2!&:6=Y96QM97IT973I<P`E<R!A
M9&UI;FES>G1RX6-I\P`E<R!L96YY;VUA=``E<R!K87)B86YT87)TX7-I(&9E
M;&%D871O:R`M(&UE9V5R]7/M=.ES`"5S(&)EX6QL[73A<P`E<R!L;V=I;B!N
MZ78@:6?I;GELZ7,`)7,@<WIO;&?A;'1A=.%S:2!F96QTZ71E;&5K`$$@(B5S
M(B!N97;[(.%L;&]MX6YY(&WA<B!LZ71E>FEK+@`E<R`Z("5S("5S`"5S(&YE
M;2#M<FAA=/,@9F5L_&PN`"5S(&MI=/9L=.ES92!S>OQK<^EG97,`)7,@<&5R
M8P`E<R!N96T@=&%LX6QH873S+@`E<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L
M871I;VX@97AT<F%C="<@9FER<W0N`"5S("T@)7,@*/9S<WIE<V5N("5S*0`E
M<R!C[6UJ96=Y>NEK90`E<R!N87!TX7)A`"5S(&9E;&IE9WEZZ7-E:0`E<R!F
M96QA9&%T;&ES=.%J80`G)7,G(&YE;2#I<G;I;GEE<R!VX6QA<WITX7,N`"<E
M<R<@;FEN8W,@:V]N9FEG=7+A;'9A(&$@2&]R9&4@4F5G:7-T<GDM8F5N+@`G
M)7,G(&9A<W1R=6MT^G)A+6UE9VIE;&5N[73U(&YE;2!T86SA;&AA=/,N`"<E
M<R<M="!H;WIZX6%D='5K(&$@8W-O<&]R=&]K:&]Z+@`G)7,G+70@:&]Z>N%A
M9'1U:R!A(&IO9V]S=6QT<^%G:2!R96YD<WIE<FAE>BX`)R5S)RUT(&YE;2!H
M;WIT=6L@;.ET<F4Z("5S+@`L("5S("5S+7,@<WKI;&SV:^ES96L`+"!VX6QT
M;WKS("5S(.ES("5S(&OV>O9T=``M+2!VX6QA<W-Z;VX@+2T`+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM`#$R(/-RX7,@9F]R;>%T=6T`,C0@\W+A<R!F
M;W)MX71U;0`R-"#S<F$`/$5L]7KU`#QG971T97AT/B!T86<@;F]T(&-L;W-E
M9"!I;B!F:6QE("5S+@I/<&5N:6YG('1A9R!F;W5N9"!I;B!L:6YE("5D+@!%
M>F5N(&)L;VMK(&AA<WINX6QA=.%H;WH@96=Y(&%D871BX7II<R!A;')E;F1S
M>F5R('-Z_&MSZ6=E<RX`2&5L>7)E:&]Z:&%T871L86X@:&EB82!T]G)TZ6YT
M`$$@;&5VZ6P@=&ET:V]S[73A<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L
M8W,@<WK\:W/I9V5S+@!!(&1I9VETX6QI<V%N(&%LX>UR="!L97;I;"!E;&QE
M;O5R>NESZ6AE>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<R!S>OQK<^EG97,N
M`$$@=&ET:V]S[71O='0@;&5VZ6P@9&5K\V1O;.%SX6AO>B!E9WD@;GEI;';A
M;F]S(%!'4"!K=6QC<RP@96=Y('1I=&MO<R!01U`@:W5L8W,@Z7,@96=Y(&IE
M;&UO;F1A="!S>OQK<^EG97,N`$$@;&5VZ6P@9&EG:73A;&ES(&%LX>URX7/A
M:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S+"!E9WD@=&ET:V]S(%!'4"!K
M=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z_&MSZ6=E<RX`02!T:71K;W/M=&]T
M="!L97;I;"!D96OS9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU
M;&-S+"!E9WD@=&ET:V]S(%,O34E-12!K=6QC<R#I<R!E9WD@:F5L;6]N9&%T
M('-Z_&MSZ6=E<RX`02!L97;I;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y
M(&YY:6QVX6YO<R!3+TU)344@:W5L8W,L(&5G>2!T:71K;W,@4R]-24U%(&MU
M;&-S(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+@!!(&QE=NEL('1I=&MO
M<^UTX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU;&-S('-Z_&MSZ6=E
M<RX`1.EL96SU='0@8F]R=6QT(.EG`$3I;&5L]71T(&=Y96YG92!E<_4`1.EL
M96SU='0@97/U`$3I;&5L]71T:2!ZX7!O<F]K`$3I;&5L]71T(&CS>N%P;W)O
M:P!D92]D=0!!4$D@240@*&$@<')O9W)A;6]ZX7-I(&9E;/QL970@87IO;F]S
M[73S:F$I`$5R<O5L(&%Z(&5D:71O<G+S;`!.Z79J96=Y+BXN`&%B<WH@86QU
M;`!A8G-Z(&OV>NEP`$YI;F-S(&IO9V]S=6QT<^%G82!A(%9&4R!A;&OV;GEV
M=.%R(&SI=')E:&]ZX7/A:&]Z+@!.:6YC<R!J;V=O<W5L='/A9V$@82!61E,@
M9N%J;"!LZ71R96AO>N%SX6AO>BX`2F5L<WKS`$$@:F]G;W-U;'1SX6<@9F5L
M('9A;B!F_&=G97-Z='9E+@!0Z6YZ_&=Y96L`0F5V:71E;`!!;&-S;W!O<G0@
M;.ET<F5H;WKA<V$`2F]G;W-U;'1SX6=I(&%L8W-O<&]R="!LZ71R96AO>N%S
M80!!9&1J=6L@:&]Z>N$@:71T.@#::B!C<V]P;W)T(&SI=')E:&]ZX7-A`-IJ
M(&IO9V]S=6QT<^%G(&SI=')E:&]ZX7-A`$%L8W-O<&]R="!H;WIZX6%DX7-A
M("<E<R<M:&5Z`$IO9V]S=6QT<^%G:2!A;&-S;W!O<G0@:&]Z>N%A9.%S82`G
M)7,G+6AE>@#::B!F96QH87-Z;N%L\R!LZ71R96AO>N%S83H`VFH@;W-Z;&]P
M(&AO>GKA863A<V$`VFH@=&%G;VL@9F5L=NET96QE`-IJ('#A<B!H;WIZX6%D
MX7-A`$$H>BD@)7,@;65N_'0@861J=6L@:&]Z>N$@82!-;WII;&QA(&UE;OQS
M;W)H;WH`061J=6L@:&]Z>N$@82!C[6UJ96=Y>NEK:&5Z.@!!9&IU:R!H;WIZ
MX2!A(&/M;6IE9WEZZ6ME;6AE>@#::B!F96QH87-Z;N%L\R!H;WIZX6%DX7-A
M`"<E<R<@9F5L:&%S>F[A;/-T(&AO>GKA861T=6L@82!R96YD<WIE<FAE>BP@
M9&4@;F5M('-I:V5R_&QT(&$@=/9B8FD@8F5J96QE;G1K97KI<VD@861A="!T
MX7)O;.%S83H@)7,N`"<E<R<@9F5L:&%S>F[A;/-T(&9E;'9E='3I:R!A(')E
M;F1S>F5R8F4N($UO<W0@;>%R(&)E:F5L96YT:V5Z:&5T+@!!9&1I;F<@;F5W
M(&9I;&5S('1O(')E<&]S:71O<GDZ`$$@<F5N9'-Z97)H97H@;F5M(&%D:&%T
M\VL@:&]Z>N$@^FH@9F5L:&%S>F[A;/-K+@!#[6T`0^UM:F5G>7KI:P!!9&UI
M;FES>G1RX6-I\R`M(&IO9V]S=6QT<^%G;VL@863A<V$@=&]VX6)B:2!F96QH
M87-Z;N%L\VMN86L`061M:6YI<WIT<N%C:?,`2&ER9&5TZ7-E:P!!9F=A;FES
M>G3A;@!!;&+A;FEA`$%L9^ER:6$`06QI87,`16QH96QY97KI<P!296YD97KI
M<SH`87H@]G-S>F5S970`36EN9&5N(&YE;2!V96YDZ6<@9F5L:&%S>F[A;/,`
M36EN9&5N(&-S;W!O<G0`36EN9&5N(&IO9V]S=6QT<^%G`$UI;F0@82!NZ6=Y
M(&]L9&%L;VX@;&5G>65N(&ME<F5T`$5N9V5D:OQN:R!M96<@=/9B8B!C[6UE
M="!I<P!!('-O<G-ZX6UO<R!F96QS;W)O;.%S('3M<'5S82!VX6QT;WIT871H
M873S(&QE9WEE;C\`3>%R(&SI=&5Z:6L`24U34"!B96IE;&5N=&ME>NES:2!P
M87)A;>ET97)E:P!-X7-I:RP@24U34"!J96QS>O,`3>%S:6LL($E-4U`@8F5J
M96QE;G1K97KI<VD@;NEV`$WA<VEK(&5M86EL(&/M;0!!;'1E<FYA=.UV('-A
M8FQO;F]K`$%L=&5R;F%T[78@<WKV=F5G.@!!;65R:6MA:2!3>F%M;V$`02!M
M96=A9&]T="#I<G3I:R!N96T@9F]G861H873S(&5L+@!)<VUE<F5T;&5N(&AI
M8F$@=/9R=.EN="X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;FEM('!R
M;WAY;B!K97)E<WIT_&QI(&EN=&5R;F5T(&5LZ7+I<P!6X6QA<WH`06YT87)K
M=&ES>@!!;G1I9W5A(.ES($)A<F)U9&$`06QK86QM87KA<P!!;&MA;&UA>N%S
M;VL@;&ES=.%J80!!>B!A;&MA;&UA>N%S(&OI<WHN`$$@:_9Z]G,@=.%R=&5R
M_&QE="!A;&-S;W!O<G1J86ER82!I<R#I<G;I;GEE<P!*\W;A:&%G>>%S`$OV
M<OQL8F5L_&QI(&WI<F5T`.%P<FEL:7,`87)A8B`H5VEN9&]W<RTQ,C4V*0!!
M('3V;?9R[71E='0@X6QL;VWA;GD@;>ER971E`$$@=/9M]G+M=&5T="#A;&QO
M;>%N>2!N979E`$)I>G1O<R!B96YN92P@:&]G>2!T]G+V;&YI(&OM=N%N:F$@
M)7,@8F5J96QE;G1K97KI<VD@:6?I;GGI=#\`0FEZ=&]S+"!H;V=Y('3V<O9L
M;FD@86MA<FIA("<E<R<M="!A;&-S;W!O<G1J86EV86P@96=Y_'1T/P!!<F=E
M;G3M;F$`UG)MZ6YY;W)S>N%G`/9R;>EN>2`H05)-4T-)22TX*0!-^W;I<WIE
M=`!!<G5B80!0;VAN<&5I`$%S8VEI(')A:GIO:P#!>G-I82]#<V5N9&5S+?-C
M9>%N:2!RZ6=I\P!+Z7)J96X@82!R96YD<WIE<B!M96=E<O5S[73I<W0@82!K
M87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<V4@96SU='0_`$AO>GKA
M<F5N9&5LZ7-I(&]S>FQO<&]K`$YE;6SI=&5Z]2!C<V]P;W)T;W0@:^USZ7)E
M;'0@;65G('3V<O9L;FDN`$YE;6SI=&5Z]2!J;V=O<W5L='/A9V]T(&OM<^ER
M96QT(&UE9R!T]G+V;&YI+@!.96ULZ71E>O4@:F]G;W-U;'1SX6=O="!K[7/I
M<F5L="!M96<@;65G=N%L=&]Z=&%T;FDN`$YE;6SI=&5Z]2!K]GKV<R!TX7)T
M97+\;&5T970@:^USZ7)E;'0@;65G(&UE9W;A;'1O>G1A=&YI+@!4=6QA:F1O
M;G/A9V]K`&%U9W5S>G1U<P!!=7-Z='+A;&EA`$%U<WIT<FEA`$%U=&A?8WER
M<W%L.B!A('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`
M075T:%]C>7)U<SH@82!HX71TZ7)S>F]L9^%L=&%TX7,@;F5M(')E;F1E;&ME
M>FEK(&$@:^UVX6YT(&OI<&5S<^EG96MK96PN`$%U=&A?8WER=7,Z(&$@<WK\
M:W/I9V5S(&EM87`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H7V9T<#H@
M82!S>OQK<^EG97,@9G1P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX@1F]R9.UT
M<V$@;&4@82!02%`M="!A>B`M+65N86)L92UF='`@;W!C:?-V86PN`$%U=&A?
M:6UA<#H@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N
M`$%U=&A?:W)B-3H@82!S>OQK<^EG97,@:W)B-2!B]7;M=.ES(&YE;2!T86SA
M;&AA=/,N`$%U=&A?;&1A<#H@82!S>OQK<^EG97,@3$1!4"!B]7;M=.ES(&YE
M;2!T86SA;&AA=/,N`$%U=&A?;&1A<#H@)7,@9F5L:&%S>F[A;/,@:&]Z>N%A
M9.%S82!N96T@<VEK97+\;'0N($$@<WIE<G9E<B!VX6QA<WIA.B``075T:%]L
M9&%P.B`E<R!F96QH87-Z;N%L\R!T]G)LZ7-E(&YE;2!S:6ME<OQL=`!!=71H
M7VQD87`Z("5S(&9E;&AA<WINX6SS(&%D871A:6YA:R!M96?Z:NUTX7-A(&YE
M;2!S:6ME<OQL=`!!=71H7VUC86PZ(&$@<WK\:W/I9V5S($U#04P@8O5V[73I
M<R!N96T@=&%LX6QH873S+@!!=71H7W-M8F%U=&@Z(&$@<WK\:W/I9V5S('-M
M8F%U=&@@8O5V[73I<R!N96T@=&%LX6QH873S+@!!(&9E;&AA<WINX6SS87IO
M;F]S[73A<R!N96T@<VEK97+\;'0N`$$@9F5L:&%S>F[A;/-A>F]N;W/M=.%S
M(&YE;2!S:6ME<OQL="X@)7,`02!F96QH87-Z;N%L\R!A>F]N;W/M=.%SX70@
M82!2041)55,@<WIE<G9E<B!E;'5T87/M=&]T=&$N`$YE;2!S:6ME<OQL="!A
M>B!&5%`@<WIE<G9E<FAE>B!V86SS(&9E;&AA<WINX6SS87IO;F]S[73A<RX`
M02!R96YD96QK97KI<W)E(.%L;/,@;65Z]6LZ`$%Z97)B86ID>G/A;@!!(&=O
M;F]S>B!R96YD<WIE<F=A>F1A(&UE;G1SZ6=E:0!!($)A8VME;F0@;FEN8W,@
M;65G9F5L96SU96X@8F5I;&QE<WIT=F4N`$CA='3I<@!(X71TZ7(@<WKM;@!.
M96T@;65G9F5L96SU(&ME<F)E<F]S(&IE;'-Z\RX`3F5M(&UE9V9E;&5L]2!K
M97)B97)O<R!F96QH87-Z;N%L\V[I=BX`0F%H86WA:P!"86AR96EN`&)A;'1I
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S`$)A<F)A9&]S`$$@9W)A9FEK=7,@
MX6QL;VWA;GEO:R`G)7,G(&%L:_9N>79TX7)A(&YE;2!T86SA;&AA=/,N`&%L
M87!V;VYA;&]N`$9E:.ER;W)O<WIO<G-ZX6<`0F5L9VEU;0!"96QI>F4`0F5N
M:6X`0F5R;75D80!":'5TX6X`4WK\;&5TZ7-N87``02`B)7,B(&)L;VMK(&$@
M(B5S(B!P<F]G<F%M;6%L(&YE;2!T86SA;&AA=/,N`$OI<&5R;GGU<NES>B!B
M9>%L;.UTX7,`2^EP97)N>?5RZ7-Z('3M<'5S`&;I;&OV=NER`$)O;.UV:6$`
M2V5D=F5N8R!W96)C[6UE:P!+97)E=`!+97)E='9A<W1A9W/A9SH`2V5R971E
M:P!";W-Z;FEA+4AE<F-E9V]V:6YA`$UI;F1K971T]0!";W1S=V%N80!A;'5L
M`$)O=79E="US>FEG970`0G)A>NUL:6$`0G)I="!);F1I86DM\V-EX6YI(%1E
M<OQL970`0G)U;F5I($1A<G5S<V%L86T`0G5I;&1I;F<@34\@9FEL97,@9F]R
M(&UO9'5L92`E<RXN+@!"=6EL9&EN9R!L;V-A;&4@)7,N+BX@`$)U;&?A<FEA
M`$9E;'-O<F]LX7,`0G5R:VEN82!&87-O`$)U<G5N9&D`5V5B;VQD86P@:V%R
M8F%N=&%R=.%S`$-20P!!('1A;OIS[71VX6YY=FES<WIA=F]NX7-I(&QI<W3A
M:R`H0U),*2!C[6UE:0!#96QL82!T=6QA:F1O;G/A9V]K`$$@8V%C:&4@:6YI
M8VEA;&EZX6SA<V$@;F5M(&9E:F5Z]63V='0@8F4N`$YA<'3A<@!.>75G;V1T
M`$MA;6)O9'IS80!+86UE<G5N`$YE;2!S:6ME<OQL="!A(&IE;'-Z\W0@X73A
M;&SM=&%N:2P@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BX`02!K]G9E
M=&ME>O4@24U!4"!S>F5R=F5R(&YE;2#I<FAE=/4@96PZ("5S`$MA;F%D80!-
MZ6=S90!-Z6=S92!K_&QD]FL@:&EB86IE;&5N=.ES=`!!*'HI("(E<R(@X6QL
M;VWA;GD@;F5M('3V<O9L:&5T]2X`3F5M('1A;.%L:&%T\R!A>B!I9&5I9VQE
M;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7(N`$$@)W1A
M<F=E=$9I;&4G('!A<F%MZ71E<B!M96=A9.%S82!NZ6QK_&P@;F5M(&9O;'ET
M871H871J=6LN`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N
M`$YE;2!T]G+V;&AE=/4L("5D(&%L8W-O<&]R=&IA('9A;BX`07H@^FH@<V]R
M8F%R96YD97KI<R!N96T@;&5H971SZ6=E<RP@82!M96=A9&]T="!A9&%T;VL@
M<WKA;6$@;F5M(&5G>65Z:6L@82!TX7)O;'1A:^EV86PN`$$@;65G861O='0@
M<WKA;7)A(&YE;2!K_&QD:&5T]2!E;"!A>B#\>F5N970N`%KV;&0M9F]K:2US
M>FEG971E:P#!8G)A<WKV=F5G`$MA=&5G\W)IX6L@Z7,@:F5L]FSI<_QK`$MA
M:FWA;BUS>FEG971E:P!-;V)I;"!T96QE9F]N`$-E;&QA='5L86ID;VYSX6=O
M:P!#96QL82!B96QS]2!M87)G\SH`0V5L;&%T=6QA:F1O;G/A9V]K`$-E;&SA
M:R!K]GKV='1I('+I<SH`36]B:6P@=&5L969O;@!K96QT82`H25-/+3@X-3DM
M,30I`&OV>NEP`$OV>NEP+6%F<FEK86D@2_9Z=.%R<V%SX6<`:V5L970M975R
M\W!A:2`H25-/+3@X-3DM,BD`02!T86[Z<^UT=N%N>2!RZ7-Z;&5T96D`02!T
M86[Z<^UT=N%N>2!T=6QA:F1O;F]S80!486[Z<^UT=N%N>2!F96QH87-Z;N%L
MX7-I(&ERX6YY96QV96L`0W/A9`!6X6QT;WIT873A<P!*96QS>O,@;?-D;W/M
M=.%S`$%Z(-9N(.%L=&%L(&5L:_QL9/9T="!L979E;&5K96X@<WIE<F5P;/4@
M;NEV(.ES(&/M;2!M96=VX6QT;WIT873A<V$N`$IE;'-Z\R!M\V1O<^UTX7,`
M2F5L<WKS;?-D;W/M=.%S(&$@)7,@<WIE<G9E<F5N`$MA<F%K=&5R`$QI;E]K
M96QL96[U<GKI<RXN+@!*96SV;&IE(&MI(&%Z;VMA="!A(&9E;&%D871O*&MA
M*70L(&%M:2AK92ET(&UO<W0@96P@:^UVX6X@=NEG97IN:2X`0VAI;&4`2^UN
M80!K[6YA:2P@96=Y<WIE<OMS[71E='0@*$=",C,Q,BD`:^UN86DL(&AA9WEO
M;>%N>6]S("A":6<U*0!6X6QA<W-Z;VX@:F5L<WKS=`!6X6QA<W-Z;VX@96=Y
M(&9E;&AA<WINX6SS;F5V970`5N%L87-S>F$@:VD@82!DX71U;6]K(&UE9VIE
M;&5N[73I<VD@9F]R;>%JX70Z`%;A;&%S<WIA(&MI(&$@9F5L<V]R;VSA<R!T
M[7!U<^%T("AS>N%M;WIO='0@;&ES=.%K;N%L*0!+87+A8W-O;GDM<WII9V5T
M96L`02AZ*2`E<R!C;&%S<R!D969I;NUC:?-J82!N96T@=&%LX6QH873S+@!#
M;&5A;FEN9R!U<"!03R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN`$-L96%N:6YG
M('5P(&QO8V%L92`E<RXN+B``1&5R_&QT`%3V<FQI(&%Z($U33V9F:6-E('1A
M9V5K970`)7,@9F5L:&%S>F[A;/,@=/9R;.ES90!!(&9E;&AA<WINX6SS('3V
M<FSI<V4`02!F96QH87-Z;N%L\R!A9&%T86EN86L@=/9R;.ES90!%<W3I<F4@
M9&5R_&QT(.EG`$$@9F]L>71A=.%S:&]Z(&MA='1I;G1S;VX@87H@96?I<G)E
M;`!#;&EC:V%T96QL('-Z;VQGX6QT873A<R!(5%10+6X@:V5R97-Z=/QL`$%Z
M(&%B;&%K(&)E>N%RX7-A`$)O<G5L="#I9P!296=G96P@9F5L:/5S(&ED]0!&
M96QH]7,@:63U`$OS:W5S>BUS>FEG971E:P!4_&YT97-S_&L@96P@87H@;VQD
M86QS\R!M96[\=`#6<W-Z97KA<G0@:V5R971E:P!+;VQU;6)I80!3>NUN`%-Z
M[6YVX6QA<WIT\P!3>NUN=N%L87-Z=.%S`$]S>FQO<&]K.@!!>B!O<WIL;W!O
M:R!C[6UE:0!6:6-C96L`4&%R86YC<P!087)A;F-SZ7)T96QM97KU`$-O;6UA
M;F0@;W!T:6]N<SH`0V]M;6%N9',Z`$UE9VIE9WEZZ7,`0V]M;6ET=&EN9SH`
M3NEV+"!E;&YE=F5ZZ7,`0V]M;W)E+7-Z:6=E=&5K`$/I9P!,97;I;.URX7,@
M*"5S*0!3>N%M[73S9^EP96L`263U:N%RX7-I(&AE;'EZ970`2_QL]FYB<^EG
M96L@82!K;VYF:6=U<N%C:?-B86X`02!K;VYF:6=U<N%C:?,@;>%R(&YE;2#I
M<G;I;GEE<RX`)7,@:V]N9FEG=7+A8VGS:F$`02!J96QS>O,@;65G97+U<^UT
MZ7-E`/IJ(&IE;'-Z\R!M96=E<O5S[73I<V4Z`$MO;F?S`$MO;F?S:2!$96UO
M:W)A=&EK=7,@2_9Z=.%R<V%SX6<`4VEK97)T96QE;B!A(&MA<&-S;VQA="X`
M4VEK97)T96QE;B!A(&MA<&-S;VQA=#H@`$$@;GEI;';A;F]S(&MU;&-S;VL@
M<WIE<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA=&]T+@!!(&YY:6QVX6YO
M<R!K=6QC<V]K('-Z97)V97)E(&5L=71A<^UT:F$@82!K87!C<V]L871O="X@
M3VMA.B`E<R`H)7,I`%-I:V5R=&5L96X@87H@1E10('-Z97)V97)R96P@=F%L
M\R!K87!C<V]L870N`$$@<&%R=&YE<F5K970@<VEK97)E<V5N(&AO>GKA861T
M=6L@82!C[6UJ96=Y>NEKZ6AE>BX`)R5S)R!T87)T86QM80!&;VQY=&%TX7,`
M0V]O:RUS>FEG971E:P!3_'1I`$WA<V]L:G5K(.%T`$$@:VEJ96SV;'0@<NES
M>B!MX7-O;.%S80!#;W!Y:6YG("5S('1O("5S`$-O<W1A(%)I8V$`16QE9N%N
M=&-S;VYT<&%R=`!.96T@<VEK97+\;'0@4$=0+79E;"!T:71K;W/M=&%N:2!A
M(&QE=F5L970N`$$@;&5V96QE="!N96T@<VEK97+\;'0@4$=0(&%LX>URX7-S
M86P@96QLX71N:2X`02!L979E;&5T(&YE;2!S:6ME<OQL="!A>B!3+TU)344@
M<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&%N:2X`02!L979E;&5T(&YE;2!S
M:6ME<OQL="!3+TU)344@86SA[7+A<W-A;"!E;&SA=&YI+@!!('!A<G1N97(@
M861A=&%I="!N96T@<VEK97+\;'0@96QTX7)O;&YI+B`E<P!!>B!,1$%0('-Z
M97)V97(@;F5M(.ER:&5T]2!E;"X`07H@3$1!4"!S>F5R=F5R:&5Z(&YE;2!L
M96AE="!K87!C<V]L\V1N:0!.96T@<VEK97+\;'0@96QL96[U<FEZ;FD@82!S
M>N%M;.%JX6X@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9V5T+B`E<P!!>B!,
M1$%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`3F5M('-I:V5R_&QT(&$H>BD@
M)R5S)R!S>F5R=F5R<F5L($944"!K87!C<V]L871O="!F96QV96YN:3H@)7,`
M0V]U;&0@;F]T(&-O<'D@)7,@=&\@)7,`3F5M('-I:V5R_&QT(&SI=')E:&]Z
M;FD@82!K]G)L97;I;&QI<W3A="X@)7,`0V]U;&0@;F]T(&-R96%T92!L;V-A
M;&4@9&ER96-T;W)Y(&9O<B!L;V-A;&4@)7,Z`$%Z(&%D871O:R!01U`@=&ET
M:V]S[73A<V+S;"!T]G)TZ6[U(&1E:_-D;VSA<V$@;F5M('-I:V5R_&QT+@!!
M>B!A9&%T;VL@4R]-24U%('1I=&MO<^UTX7-B\VP@=/9R=.EN]2!D96OS9&]L
MX7-A(&YE;2!S:6ME<OQL="X`02!P87)T;F5R('3V<FSI<V4@;F5M('-I:V5R
M_&QT+B`E<P!!(&OV<FQE=NEL;&ES=&$@=/9R;.ES92!N96T@<VEK97+\;'0N
M("5S`$YE;2!S:6ME<OQL="!T]G+V;&YI(&$H>BD@)R5S)R!S971U<"!U<&=R
M861E('!R;V=R86UO="X`3F5M('-I:V5R_&QT(&UE9^%L;&%P[71A;FD@82!C
M[6UZ971T(&5M86EL(&/M;>ET+@!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@
M=&5L:F5S(&/M;6IE9WEZZ6ME="X`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A
M('1E;&IE<R!K]G)L97;I;&QI<W3A="X`3F5M('-I:V5R_&QT(&)E;VQV87-N
M:2!A(&OV<FQE=NEL;&ES=.%K('1E;&IE<R!F96QS;W)O;.%SX70N`$$@)R5S
M)R!S=')A=.EG:6$@;F5M('1A;.%L:&%T\RX`02`G)7,G(&%L:_9N>79TX7(@
M;F5M(&AO>FAA=/,@;.ET<F4N`$$@;GEI;';A;F]S(&MU;&-S;W0@;F5M('-I
M:V5R_&QT(&UE9W-Z97)E>FYI(&$@:W5L8W-S>F5R=F5R<O5L+@!.96T@<VEK
M97+\;'0@)7,M="!M96=N>6ET;FDN`$YE;2!S:6ME<OQL="`G)7,G+70@[7+A
M<VD@8^EL;&%L(&UE9VYY:71N:2X`02`E<R!K87)B86YT87)TX7-I(&UO9'5L
M(&YE;2!N>6ET:&%T\R!M96<`02`G)7,G(&%L:_9N>79TX7(@;F5M(&YY:71H
M873S(&UE9RX`3F5M(&QE:&5T(&-S871L86MO>FYI(&%Z('-M8G!A<W-W9"!C
M<_5V97IE=.EK:&5Z+@`E<R!N96T@;VQV87-H873S+@!.96T@<VEK97+\;'0@
M82!K[7;A;G0@9F5L:&%S>F[A;/,@:F5L<WIA=N%T(.%TX6QL[71A;FDN($%Z
M(&UE9V%D;W1T(&%D871O:R!N96T@=F%G>2!N96T@=&5L:F5S96X@9F5L96QN
M96L@;65G+B!0<O-BX6QJ82#Z:G)A+"!V86=Y(&AA('1O=N%B8FD@<V5G[71S
MZ6=R92!V86X@<WK\:W/I9V4L(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H
M;WHN`$YE;2!S:6ME<OQL="!M96=H873A<F]Z;FD@87H@96SI<NES:2!J;V=O
M<W5L='/A9V]K870@*$%#3"D`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&/M
M;6IE9WEZZ6ME="X@)7,`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV<FQE
M=NEL;&ES=.%T+B`E<P!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5V
MZ6QL:7-TX6MA="X@)7,`3F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A('-Z
M97)V97(@:^EP97-SZ6=E:70`3F5M('-I:V5R_&QT('9I<W-Z8>%L;.UT86YI
M(&5Z(&5R961E=&D@:V]N9FEG=7+A8VGS="X`02`G)7,G(&%L:_9N>79TX7(@
M;F5M('3V<O9L:&5T]2X`3F5M('-I:V5R_&QT(&5L;65N=&5N:2`E<R!K;VYF
M:6=U<N%C:?-T+@!.96T@<VEK97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO
M;F9I9W5RX6-I\W0N`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82!B86-K=7`@
M:V]N9FEG=7+A8VGS=#H@)7,`3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A*'HI
M("<E<R<@<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N`$YE;2!S:6ME<OQL="!E
M;&UE;G1E;FD@82AZ*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="X`02AZ*2`E
M<R!K;VYF:6=U<N%C:?-S(.%L;&]MX6YY="!N96T@<VEK97+\;'0@96QM96YT
M96YI+B!686=Y(&AA<WINX6QJ82!A("5S(&]L9&%L;VX@;&5V]2!L96AE=/5S
MZ6=E:V5T+"!V86=Y(&WA<V]L:F$@X70@87H@86SA8F)I(&OS9&]T(&ED93H@
M)7,N`$%Z($Q$05`@<WIE<G9E<F5N(&YE;2!S:6ME<OQL="!E;';I9V5Z;FD@
M82!K97)E<^ES="X`)R5S)R!N96T@=F]L="!T]G+V;&AE=/4N`$$@<&%R=&YE
M<B!A9&%T86ET(&YE;2!S:6ME<OQL="!M\V1O<^UT86YI+B`E<P!.96T@<VEK
M97+\;'0@82!K]G)L97;I;&QI<W1A(&WS9&]S[73A<V$N("5S`$YE;2!S:6ME
M<OQL="!E;&UE;G1E;FD@)R5S)R!K;VYF:6=U<N%C:?-JX70Z("5S`$$@36]Z
M:6QL82!M96[\<V]R(&YE;2!T86SA;&AA=/,N($5L;&5N]7)I>GIE+"!H;V=Y
M(&UE9R!V86XM92!N>6ET=F$N`$YE;2!S:6ME<OQL="`G)7,G(&9E;&AA<WIN
MX6SS;F%K(&IO9V]S=6QT<^%G;W0@861N:2!A*'HI("<E<R<@;6%P<.%H;WHZ
M("5S`$MO<FSA=&]S('-Z]G9E9P!/<G-ZX6<`5.%V;VMT873A<P!,Z71R96AO
M>N%S`$QI;FL@;.ET<F5H;WKA<V$`VFH@;.ET<F5H;WKA<V$`06QM87!PX6L@
M;.ET<F5H;WKA<V$`07H@;V)J96MT=6T@;.ET<F5H;WKS:N%N86L@:F]G;W-U
M;'1SX6=A:0!(:71E;&OA<G1Y87-ZX6T`2&]R=N%T;W)S>N%G`$MU8F$`2F5L
M96YL96=I(#0@9N%Z:7,`4&]N=&]S(&ED]0!!(&IE;&5N;&5G:2!54DP`2F5L
M96YL96=I(&ED]6KA<N%S`$$@:F5L96YL96=I(&ED]6KA<N%S:2!H96QY>F5T
M.@!*96QE;FQE9VD@<W3M;'5S`$UI;'EE;B!P87)A;F-S;VL@9G5S<V%N86L@
M;&4@875T;VUA=&EK=7-A;B!A("5S8F4@=/9R=.EN]2!B96IE;&5N=&ME>NES
M:V]R+@!+:7;A9^%S`$$@:VEJ96SV;'0@<NES>B!K:7;A9^%S80!#:7!R=7,`
M8VER:6QL("A+3TDX+5(I`&-I<FEL;"`H5VEN9&]W<RTQ,C4Q*0!C:7)I;&PM
M=6MRX6X@*$M/23@M52D`0W-E:"!+]GITX7)S87/A9P!$1`!N87!O;G1A`$1A
M=&%4<F5E(&+V;F?I<WKU`$3A='5M`$$@8F7I<FME>NES(&YA<&IA`$3A='5M
M(&MI=N%L87-Z=.%S80!N87!P86P`3W-Z;&]P('3V<FSI<V4`9&5C96UB97(`
M<WKA;6]K`$)E:V5Z9.ES(&MI:FIE8F(`06QA<.ER=&5L;65Z971T`$%Z(&%L
M87#I<G1E;&UE>NES('-Z97)I;G1I('-Z[6X`06QA<.ER=&5L;65ZZ7,@<WIE
M<FEN=&D@87IO;F]S[73S`$%Z(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&IO
M9V]S=6QT<^%G;VL`07H@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@:F]G;W-U
M;'1SX6=O:P!$969I;NUC:?-K`%3V<FSI<P!!(&-S;W!O<G0@=/9R;.ES90!!
M(&IO9V]S=6QT<^%G('3V<FSI<V4`3&5V96QE:R!T]G)LZ7-E`$$@8V5L;&$@
M=/9R;.ES90!!>B!O<WIL;W`@=/9R;.ES90!4]G+V;&K\:R!K:2!A(&UE9VSI
M=O4@86QT97)N873M=B!S86)L;VYT`"<E<R<@:F]G;W-U;'1SX6=A:6YA:R!T
M]G)LZ7-E`%3V<O9L:OQK("<E<R<@:F]G;W-U;'1SX6=A:70@Z7,@96YN96L@
M97-E=&QE9V5S(&%L8W-O<&]R=&IA:70_`$$@<V]R('3V<FSI<V4`02!K:7;A
M;&%S>G1O='0@87IO;F]S[73S('3V<FSI<V4`02!J96QE;FQE9VD@;W-Z;&]P
M('3V<FSI<V4`02!J96QE;FQE9VD@<V]R('3V<FSI<V4`5/9R]FQJ_&L@97IT
M(&$@:F]G;W-U;'1SX6=O="!I;&PN(&5S971L96=E<R!A;&-S;W!O<G1J86ET
M/P!4]G+V;'3\:R!A*'HI("<E<R<@<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N
M`$$@:^EZ8F5S[73I<R!I9&5J90!$X6YI80!!9&IO;B!L9>URX7-T(&$@<')O
M8FSI;>%R\VP`3&7M<N%S`%+I<WIL971E:R`H82!(;W)D92!L;V=FX6IL8F%N
M(&ES(&UE9W1A;.%L:&%T\RDZ`$$@<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID
M82!S>N%MX7)A(&OI<WK\;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN`$9E:FQE
M<WITZ7,`2&%R;6%T<&]N=`!(87)M871P;VYT(&IE;&5N;&5G.B``2&%R;6%T
M<&]N=#H@`&)A;'+S;"!J;V)B<F$@[7+A<P!J;V)B<O-L(&)A;')A(.URX7,`
M0^UM=.%R`$%Z(&ED]7!O;G1O:V%T(#(T(/-RX7,@9F]R;>%T=6UB86X@:F5L
M96[M='/\:R!M96<_`$UE9VIE;&5N[73I<VD@8F7A;&SM=.%S;VL`16SU<F5J
M96QZZ7,@;65G:F5L96[M=.ES92`H<F5P_&SU=.ER:2D`365G:F5L96[M=.ES
M:2!F;W)MX71U;0#)<G1E<^UTZ7,@82!KZ7IB97/M=&5T="!L97;I;"!S;W)S
MX7+S;`!$>G-I8G5T:0!.92!T]G+V;&K\:P!!(&UA:6YT96YA;F-E+G!H<"!N
M96T@Z7)H973U(&5L(&OV>G9E=&QE;OQL+@!!>B!E;'/U('-O<B!A(&UE>O5K
M(&YE=F5I="!T87)T86QM87IZ83\@2&$@:6=E;BP@:F5L]FQJ92!K:2!E>G0Z
M`$1O;6EN:6MA`$1O;6EN:6MA:2!+]GITX7)S87/A9P!,973V;'3I<P!4]FQT
M<_QK(&QE("5S+70`5/9L='/\:R!L92!02%`@<')O9W)A;2!F;W)MX6KA8F%N
M(&%Z(&5L:^ES>OQL="!K;VYF:6=U<N%C:?-T+@!,96?V<F3\;/4@;&ES=&$`
M2^%B[73S<WIE<F5K`&5M86EL`$A)0D$`16-U861O<@!-\V1O<^UTX7,`0FQO
M:VL@;?-D;W/M=.%S`$-S;W!O<G0@;?-D;W/M=.%S`$IO9V]S=6QT<^%G(&WS
M9&]S[73A<P!*;V=O<W5L='/A9V]K(&WS9&]S[73A<V$`)7,@:F]G;W-U;'1S
MX6=A:6YA:R!M\V1O<^UTX7-A`$UE;'EI:R!O<&-I\VMA="!VX6QT;WIT87-S
M=6LZ`"5S(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S80`G)7,G(&IO9V]S
M=6QT<^%G86EN86L@;?-D;W/M=.%S80!/:W1A=.%S`$5G>6EP=&]M`%-A;'9A
M9&]R`$5L96TN+BX`87H@)VTG(&)E=/L@<WKI;&5S<^EG90!%;6%I;`!%;6%I
M;"!C[6T`07H@96UA:6P@8^UM96MN96L@96=Y97IN:?QK(&ME;&PN`$5M86EL
M('9I<W-Z86EG87IO;.%S<V%L`$AA;F=U;&%T:6MO;F]K`-QR97,@_'IE;F5T
M+@!.:6YC<R!I;'EE;BX`5/9R]FQJ_&L@:VD@82!K97)E<^ES96ME=`!%;F=E
M9&K\:R!M96<L(&AO9WD@:^EP96ME="!I;&QE<W-Z_&YK(&$@<WKV=F5G8F4@
M82!&;W3S9V%LZ7)IX6MB\VP_`$QE9WEE;B!J;V)B(&5GZ7)G;VUB8F%L(&5L
MZ7)H973U+"!K;VYT97AT=7-F_&=G]2!M96[\/P!!>B!U=&]L<_,@Z78`P71V
MX6QTX7,@:_QL]FX@86)L86MR80!!9&IA(&UE9R!A>G0@82!B:7IT;VYSX6=I
M(&OI<F3I<W0L(&%M96QY<F4@;6%J9"!VX6QA<WIO;&YI82!K96QL(&IE;'-Z
M87;A;F%K(.%TX6QL[73A<^%H;WHL('!L+B`G:&]G>2!H[79JX6L@82!K=71Y
MX6KA=#\G.@!!9&IA(&UE9R!A(&OI<"!54DPM:NET(&ET=`!%;G1R:65S.B`E
M9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E9"!C:&%N9V5D+"`E
M9"!U;FMN;W=N`$5G>65N;.UT]6DM1W5I;F5A`$5R:71R96$`2&EB80!*96QS
M>O-M\V1O<^UTX7-I(&AI8F$`061A='1O=N%B8NUTX7-I(&AI8F$@87H@<VUB
M<&%S<W=D+6AE>BX`2&EB82!A>B!E;6%I;"#\>F5N971B96XN`$$H>BD@)R5S
M)R#A;&QO;>%N>7)A(&YE;2!S:6ME<OQL="#M<FYI+@!%<G)O<CH@`,ES>G1O
M<G-ZX6<`171I\W!I80!.96UZ971I<^EG96L`175R\W!A`#$U('!E<F-E;FOI
M;G0`,B!P97)C96YKZ6YT`#,P(&WA<V]D<&5R8V5N:^EN=``U('!E<F-E;FOI
M;G0`;6EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(`9NEL\W+A;FOI;G0`<&5R8V5N
M:^EN=`!0Z6QD82#I<G3I:V5K.@!6Z6=R96AA:G3A<P!%>&5C=71I;F<Z`$YY
M:7-S=6L@<WKI=`!*96QE;NUT<_QK(&UE9R!A>B!O;&1A;'/S(&UE;OQT`$ET
M="`G*2<@:V5L;&5N92!K]G9E=&ME>GIE;@!)='0@8W-U<&%S>B!S>O-N86L@
M=F%G>2!I9.EZ]6IE;&)E;B!L97;U(&ME<F5SZ7-I(&MI9F5J97KI<VYE:R!K
M96QL96YE(&QE;FYI90!!>B#I<G;I;GEE<W/I9R!L96KA<F%T80!+:71E=O4`
M17AT<F%C=&EN9R!F<F]M("5S+BXN(`!3>NUN`$$@:V]N9FEG=7+A8VGS($94
M4"UN(.%T('9A;/,@9F5L=/9L=.ES90!!('-Z96WI;'EE<R!B9>%L;.UTX7-O
M:V%T(&YE;2!S:6ME<OQL="!B96]L=F%S;FDN`$%Z($Q$05`@<WIE<G9E<B!N
M96T@Z7)H973U(&5L+@!!>B!334(@<WIE<G9E<B!N96T@Z7)H973U(&5L+@!.
M96T@<VEK97+\;'0@82AZ*2`B)7,B+6+U;"!T]G)TZ6[U(&WA<V]LX7,N`$YE
M;2!S:6ME<OQL="!A*'HI("(E<R(M8F4@=/9R=.EN]2!MX7-O;.%S+@!.96T@
M<VEK97+\;'0@^FH@4T%33"!K87!C<V]L871O="!LZ71R96AO>FYI+@!.96T@
M<VEK97+\;'0@82AZ*2`B)7,B+6)E('3V<G3I;O4@X71H96QY97KI<RX`2&EB
M82!A(&IE;'-Z\VWS9&]S[73A<V[A;#H@`%1I<WIT80!&86QK;&%N9"US>FEG
M971E:R`H36%L=FEN87,I`$9A<F]E+7-Z:6=E=&5K`$AE;'ER96AO>FAA=&%T
M;&%N(&AI8F$Z`$9A>`!F96)R=>%R`$CU;>ER<^EK;&5TZ7)Z970`2/5MZ7)S
MZ6ML973I<GIE=#H@`$5G>2UE9WD@>N%P;W(`4WKS<G;A;GEO<V%N(&CS>N%P
M;W)O:P!-97KU(&WA=')I>`!&:61Z<VD`02!FX6IL;VL@<WKA;6$Z("5S`$$@
M9N%J;&]K('-ZX6UA.B`E<P!&X6IL(&UE;F5D>G-E<@!&X6IL;NEV`$;A:FP@
M:VEJ96SV;.ES`$;A:FP@9F5L=/9L=.ES90!&X6IL;VL@9F5L=/9L=.ES92!N
M96T@;&5H971SZ6=E<RX`4WK[<O5K`$9I;FYO<G-ZX6<`96QS]2!FZ6P`96QS
M]2!N96=Y960`5N%L=&]Z871L86X@;>ER971A<N%N>0!4_&MR]GKI<R`H9O9L
M+VQE*0!+]F0`)7,@;6%P<&$@;F5M(&SI=&5Z:6L`0F5T^W-Z[6X`R71E;&5K
M`$]L>6%N(&+V;F?I<WKU:R!S>N%MX7)A+"!A;6EK(&YE;2!J96QE;NUT:6L@
M;65G(&$@:^EP96ME=`!%;/5R96IE;'KI<R`H<F5P_&SU=.ER:2D`07H@96SU
M<F5J96QZZ7,@:63U=&%R=&%M82!N87!O:V)A;B`H87H@96SU<F5J96QZZ7,@
M;F%P<&%L:2#I<R#I:G-Z86MA:2!A9&%T;VMA="!T87)T86QM87HL(&5ZZ7)T
M(&$@;F%G>2!S>N%M;VL@<WKI;&5S(&)L;VMK;W0@97)E9&WI;GEE>FYE:RD`
M16QF96QE:G1E='1E(&$@:F5L<WIA=N%T/P#;<FQA<&ME>F5LZ7,`263I>F5T
M`$EDZ7IE="!F86ITX6IA`$EDZ7IE=&5K`$EDZ7IE=&5K(#(`1O-R=6UO:P!4
M;W;A8F+M=.%S;VL`1F]U;F0@87!P;&EC871I;VYS.B`E<P!&;W5N9"!D:7)E
M8W1O<FEE<SH`4.D`1G)A;64M96L`1G)A;F-I86]R<WKA9P!&<F%N8VEA;W)S
M>N%G`$9R86YC:6$@1W5Y86YA`$9R86YC:6$@4&]L:6[I>FEA`$9R86YC:6$@
M1.EL:2!497+\;&5T96L`1F5L863S`$ERX6YY.B``4NES>FQE=&5S(&QE[7+A
M<P!T96QI:&]L9`!496QJ97,@;NEV`$9U>GIY`$=A8F]N`$UE;'EI:R!G86SI
M<FGA8O-L('9E9WG\:R!A(&OI<&5T`$OI<&=A;.ER:6$Z`$=A;6)I80!(;WIZ
M=6L@;.ET<F4@82AZ*2`E<R!K;VYF:6=U<N%C:?-JX70`02!K96QE=&ME>F5T
M="!K\V0`1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN+@!'<OIZ
M:6$`3NEM971O<G-ZX6<`1V5T;W!T($5R<F]R.B``1VCA;F$`1VEB<F%L=.%R
M`$ME<F5S>G1NZ78`365H970`1_9D96P`1V]O9VQE(&ME<F5SZ7,`1F5K971E
M+V9E:.ER`$?V<O9G;W)S>N%G`&?V<O9G("A)4T\M.#@U.2TW*0!'<O9N;&%N
M9`!'<F5N861A`$-S;W!O<G0@861M:6YI<WIT<N%C:?,`02!C<V]P;W)T;NEV
M(&UA<F%D:&%T(/QR97-E;@!#<V]P;W)T(&IO9V]S=6QT<^%G;VL`0W-O<&]R
M=&]K`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`5F5N9.EG
M(&IO9V]S=6QT<^%G;VL`5F5N9.EG(&IO9V]S=6QT<^%G;VL`5F5N9.EG:_9N
M>78`1W5I;F5A`$)I<W-A=2U'=6EN96$`1W5Y86YA`$A434Q!<F5A(&=YX79A
M<^%G8O-L(&YE;2!H86IL86YD\R!A('-O<B!U=&]L<_,@8V5L;.%JX70@=/9R
M]FQN:2X`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA:FQA;F3S(&$@=.%B
M;.%Z870@=71O;'/S(&]S>FQO<.%T('3V<O9L;FDN`$A434Q!<F5A(&=YX79A
M<^%G8O-L(&YE;2!H86IL86YD\R!A('3A8FSA>F%T('5T;VQS\R!S;W+A="!T
M]G+V;&YI+@!!($A45%`@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!T86SA
M;&AA=/,N`$AA:71I`$AA<V@@86QG;W)I=&UU<P!+]F0`1F5J;.EC`$AE87)D
M+2#I<R!-8T1O;F%L9"US>FEG971E:P!HZ6)E<B`H25-/+3@X-3DM."U)*0!-
M86=A<W/A9P!396?M='/I9P!396?M='/I9R!A('-Z97)K97-Z=/4@:&%S>F[A
M;&%TX6AO>@!396?M='/I9P!(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E
M(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D90IF<F%M
M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N"D9O<B!A;B!I;G1R;V1U8W1I
M;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O<GDN`$;I
M;'1E:V4`17H@82!FX6IL(&5L96IE.@!N86=Y`$%Z(&%D871VX6QT;WKA<RUL
M9>UR\R`H:&ES=&]R>2D@X6QL;VWA;GEO:R!N979E(&YE;2!L96AE="#\<F5S
M`$ME>F3U;&%P`%9A=&EKX6YVX7)O<P!+97ID]6QA<`!/='1H;VYI(&/M;0!/
M='1H;VYI('1E;&5F;VX`2&]N9'5R87,`2&]N9VMO;F<`2&]R9&4`2&]R9&4@
M=')A;G-L871I;VX@9V5N97)A=&]R`$AO<F1E+TMO;&%B.B!H:6+A<R`E<R!8
M34P@861A="!V86X@82AZ*2`E<R#\>F5N971B96X`2&]R9&4O2V]L86(Z(&YI
M;F-S(&$H>BD@)7,@;V)J96MT=6UN86L@;65G9F5L96SU(/QZ96YE=`!(;W)D
M92]+;VQA8CH@;FEN8W,@)7,@=.UP=7/Z(&]B:F5K='5M(&$H>BD@)7,@_'IE
M;F5T8F5N`$AO<F1E+TMO;&%B.B!3:6ME<F5S96X@=/9R]FQT_&L@97IT.B`E
M<R`B)7,B`$AO<F1E+TMO;&%B.B!3:6ME<F5S96X@<WII;FMR;VYI>N%L='5K
M(&5Z=#H@)7,@(B5S(@!(;W)D92]+;VQA8CH@87H@:6YT96=RX6SS('!R;V=R
M86UH;WH@<WK\:W/I9V5S(&$@)V1O;7AM;"<@4$A0(&+U=NUTZ7,`2&]R9&4O
M2V]L86(Z(&YE;2!S:6ME<OQL="#Z:B!834P@9N%T(&SI=')E:&]Z;FD@82AZ
M*2`E<R!O8FIE:W1U;6AO>@!(;W)D92]+;VQA8CH@3F5M('-I:V5R_&QT('3V
M<O9L;FD@)7,M="`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5M('-I:V5R_&QT
M(&UE9VAA=.%R;WIN:2!A($U)344@240M:N%T(&$@:_9V971K97KU('3M<'5S
M^B!M96QLZ6ML971N96LZ("5S`$AO<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@
M<WII;FMR;VYI>N%L;FD@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YE;2!S
M:6ME<OQL="!A(&OV=F5T:V5Z]2!K]GKV<R!TX7)T97+\;&5T('-Z:6YK<F]N
M:7KA;.%S83H@)7,`2&]R9&4O2V]L86(Z(&ES;65R971L96X@:_9Z]G,@=.%R
M=&5R_&QE="`B)7,B`%;M>G-Z:6YT97,@=F]N86P`5NUZ<WII;G1E<R!M87)G
M\P!6[7IS>FEN=&5S.@!(;V=Y(&IU=&]T="!I9&4_("A+Z7)J_&L@[7)J82!M
M96<A*0!(X6YY(&]S>FQO<&]T(&OM=N%N(/9S<WIE;VQV87-Z=&%N:3\`2.%N
M>2!M97KU("AO<WIL;W`I('9A;C\`2.%N>2!S;W)T(&OM=N%N(/9S<WIE;VQV
M87-Z=&%N:3\`4.%R871A<G1A;&]M`%#A<F%T87)T86QO;3H@`$AU;6]R:7-T
MX6L`36%G>6%R;W)S>N%G`$%Z($E-05`@;&5VZ6QLX61A(&SI=')E:&]ZX7-A
M(&YE;2!S:6ME<OQL=#H@)7,`07H@24U!4"!L97;I;&SA9&$@=/9R;.ES92!N
M96T@<VEK97+\;'0Z("5S`$%Z($E-05`@;&5VZ6QLX63A:&]Z('1A<G1O>O,@
M:W;S=&$@;.ET<F5H;WKA<V$@;F5M('-I:V5R_&QT.B`E<P!)4"!C[6T`07H@
M25`@8^UM(&YE;2!H873A<F]Z:&%T\R!M96<N`$%Z($E0(&/M;2!N:6YC<R!A
M(&UE9V5N9V5D971T($-)1%(@=&%R=&]MX6YY8F%N+@!4:6QT;W1T+VUE9W;A
M;'1O>F]T="!)4"!C[6TN`%-O<B!B96EL;&5S>G3I<V4@96;V;.D`27IL86YD
M`&-S86L@:6MO;F]K`"5S(&EK;VYJ86D`:6MO;F]K(.ES('-Z]G9E9P!!>B!A
M>F]N;W/M=/-H;WH@=N%L87-Z=&]T="!E;&YE=F5ZZ7,Z`$AA(&$@;65G:F5L
M96[M=.ES(&YE;2!M96=F96QE;/4L("5S(&5G>2#Z:B!A8FQA:V)A;B!V86SS
M(&UE9VYY:73A<VAO>BX`2&$@UFX@26YT97)N970@17AP;&]R97)T(&AA<WIN
MX6PL(.ES(&YE;2!J96QE;FYE:R!M96<@87H@:6MO;F]K+"!A:VMO<B!VX6QA
M<W-Z82!E>G0@87H@;W!C:?-T+"!M96QL>65L(&MI:V%P8W-O;&IA(&$@4$Y'
M(&OI<&5K('1R86YS>G!A<F5N8VGA:N%T+@!(82!LX71J82!E>G0@82!S>O9V
M96=E="P@9&4@82!KZ7!E="!N96TL(&%K:V]R(&+V;F?I<WKU<')O9W)A;6IA
M(&YE;2!KZ7!E<R!M96=J96QE;NUT96YI(&$@<WIE<G9E<G)E(&O\;&1E;F3U
M(&OI<&5T+@!%;/5Z971E<R!NZ7IE=#H`02!KZ7`@55),+6IE`$$@:^EP(%52
M3"UJ93H`365L>6EK(&=A;.ER:>%B\VP@=F%N(&$@:^EP`$OI<"!E8F+U;"!A
M(&=A;.ER:>%B\VPZ`$OI<"!F96QT]FQTZ7-E`$OI<&5K`$EM<&]R=.%LX7,L
M("5D+B!LZ7#I<P!!>B!I;7!O<G3A;'0@;65Z]3H@)7,`07H@:6UP;W)TX6QT
M(&UE>O5K.@!3;W(@8F5I;&QE<WITZ7-E(&5Z86SA`$AI8N%S(&IE;'-Z\P!(
M:6+A<R!P87)A;F-S<&%R86WI=&5R+@!.96T@;65G9F5L96SU(&$@8F5J96QE
M;G1K97KI<VD@;NEV(.ES+W9A9WD@82!J96QS>O,N`$YE;2!M96=F96QE;/4@
M82!F96QH87-Z;N%L\VD@;NEV('9A9WD@87H@86QT97)N873M=B!C[6TN(%!R
M\V+A;&IA(/IJ<F$@=F%G>2!F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z
M+"!H82!T;W;A8F)I('-E9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+@!"96ME>F3I
M<R!B96QJ96)B`$EN9&EA`$5G>65S(&9E;&AA<WINX6SS:P!);F1O;NEZ:6$`
M26YF;W)MX6-I\P!);F9O<FWA8VGS`$EN:71I86QI>FEN9R!M;V1U;&4@)7,N
M+BX@`$]S>FQO<"!B97-Z^G+A<V$@97IU=.%N`$OI<"!B96EL;&5S>G3I<V4`
M5.%B;.%Z870@8F5I;&QE<WITZ7-E`$QI;FL@;.ET<F5H;WKA<V$`3W-Z;&]P
M(&)E<WKZ<N%S82!E>F5LZ0!/<WIL;W`@8F5S>OIRX7-A(&5Z=73A;@!/<WIL
M;W`@8F5S>OIRX7-A(&5Z96SI`%-O<B!B97-Z^G+A<V$@97IA;.$`4V]R(&)E
M<WKZ<N%S82!E9O9LZ0!"96ME>F3I<R!B96EL;&5S>G3I<V4@97IU=.%N`$)E
M:V5Z9.ES(&)E:6QL97-Z=.ES92!E>F5LZ0!(;WIZ=6YK(&SI=')E(&%L=&5R
M;F%T[78@<V%B;&]N=`!!9&IO;B!M96<@96=Y(&5M86EL(&/M;65T+"!M96QY
M<F4@96QK_&QD:&5T]2!A>B#6;B#Z:B!J96QS>F%V83H`0V5L;&$@8F5I;&QE
M<WITZ7-E(&5Z=73A;@!#96QL82!B96EL;&5S>G3I<V4@97IE;.D`3W-Z;&]P
M(&)E<WKZ<N%S82!E>G5TX6X`3W-Z;&]P(&)E<WKZ<N%S82!E>F5LZ0!,979E
M;&5K(&)E;>%S;VSA<V$`0F5K97IDZ7,@8F5I;&QE<WITZ7-E(&5Z=73A;@!"
M96ME>F3I<R!B96EL;&5S>G3I<V4@97IE;.D`4V]R(&)E<WKZ<N%S82!E>F%L
MX0!3;W(@8F5S>OIRX7-A(&5F]FSI`$%D:F$@;65G(&$@:^UVX6YT(';A;&%S
M>G0@82!B:7IT;VYSX6=I(&OI<F3I<W)E.@!+Z7`@8F5I;&QE<WITZ7-E+VWS
M9&]S[73A<V$`3&EN:R!B96EL;&5S>G3I<V4O;?-D;W/M=.%S80!!('-ZX6UL
MX6KA;B!N:6YC<R!E;.EG(&9E9&5Z970@_'IE;F5T970@:_QL9&5N:2!A(&OV
M<FQE=NEL;&ES=.%R82X`02!S>N%M;.%JX6X@;FEN8W,@96SI9R!F961E>F5T
M+@!%9^ES>@!%9^ES>B!S>N%M;VL@;&ES=.%J80!(:6+A<R]E;&9O9V%D:&%T
M871L86X@541(("A5<V5R($1A=&$@2&5A9&5R*2X`2&EBX7,O96QF;V=A9&AA
M=&%T;&%N(&%L:V%L;6%ZX7,N`$AI8N%S+V5L9F]G861H871A=&QA;B!B871C
M:"!A>F]N;W/M=/,N`$$@:_QL9/9T="!A9&%T(&AI8N%S+V5L9F]G861H871A
M=&QA;BX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&/M;7KI<RX`2&EBX7,O96QF
M;V=A9&AA=&%T;&%N(&;A:FP@9F]R;>%T=6T`2&EBX7,O96QF;V=A9&AA=&%T
M;&%N(&QI8V5N<WIK=6QC<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(';A<F]S
M+@!(:6+A<R]E;&9O9V%D:&%T871L86X@_'IE;F5T=.UP=7,N`$AI8N%S+V5L
M9F]G861H871A=&QA;B!V86=Y(&AIX6YY>O,@<')O9W)A;6]ZX7-I9F5L_&QE
M="UA>F]N;W/M=/,N`$AI8N%S+V5L9F]G861H871A=&QA;B!P87)A;>ET97)E
M:RX`2&EBX7,@87H@;V)J96MT=6T@96SI<NES:2!J;V=O<W5L='/A9V$N`$AI
M8N%S+V5L9F]G861H871A=&QA;B!P87)T;F5R87IO;F]S[73S+@!(:6+A<R]E
M;&9O9V%D:&%T871L86X@=&5R;>EK:_-D+@!(:6+A<R]E;&9O9V%D:&%T871L
M86X@<')O=&]K;VQL+@!(:6+A<R]E;&9O9V%D:&%T871L86X@8^UM>F5T=#H@
M)R5S)P!(:6+A<R]E;&9O9V%D:&%T871L86X@;65G;W-Z=&]T="!O8FIE:W1U
M;0!(:6+A<R]E;&9O9V%D:&%T871L86X@9F5L863S:2!C[6TN`$AI8N%S+V5L
M9F]G861H871A=&QA;B!U;FEC;V1E(&%D870N`$YY:6QVX6YT87)TX7,`27+A
M;FD@27-Z;.%M($OV>G3A<G-A<^%G`$ER86L`S7)O<G-ZX6<`36%N+7-Z:6=E
M=`!3>O-R=N%N>6]S('II=F%T87)O:P!)>G)A96P`02!T86[Z<^UT=N%N>2!K
M:6%D\VIA`&3U;'0`3VQA<WIO<G-ZX6<`2F%M86EC80!J86YUX7(`2F%PX6X`
M:F%PX6X@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9.%N:6$`:OIL:75S`&KZ
M;FEU<P!3;W)K:7KA<N%S`&OV>NEP<F4@<F5N9&5ZZ7,`<V]R:VEZX7+A<R!M
M:6YD:^ET(&]L9&%L<F$`<V]R:VEZX7+A<R!B86QR80!S;W)K:7KA<N%S(&IO
M8F)R80!+87IA:'-Z=.%N`%1A<G1S=6L@;65G(&%Z(&5R961E=&ET/P!+96YY
M80!!(&ME<F)E<F]S('-Z97)V97(@96QU=&%S[71O='1A(&$@9F5L:&%S>F[A
M;/-A>F]N;W/M=.%S="X`2V5Z9/4@:V5R;F5L9F5J;&5S>G3U:P!+=6QC<R!L
MZ71R96AO>N%S80!!(&MU;&-S(&QE;GEO;6%T80!+=6QC<VAO<W-Z^G/A9P!+
M=6QC<R!T[7!U<P!!(&MU;&-S(&AA<WINX6QA=&$`02!K=6QC<R!MX7(@;.ET
M97II:R!A(&YY:6QVX6YO<R!K=6QC<W-Z97)V97)E;BX`1WEE<F5K96L`2VER
M:6)A=&D`2V]R96%I($[I<&D@1&5M;VMR871I:W5S($OV>G3A<G-A<^%G`$MO
M<F5A:2!+]GITX7)S87/A9P!K;W)E86D@*$550RU+4BD`2W5V86ET`$MI<F=I
M>FES>G3A;@!?5&5R=F5ZZ7,`3GEE;'8`3&%O<WII($[I<&D@1&5M;VMR871I
M:W5S($OV>G3A<G-A<^%G`'5T;VQS\R!FZ6P`=71O;'/S(&YE9WEE9`!5=&]L
M<_,@=N%L=&]Z=&%TX7,Z`%5T;VQS\R!B96IE;&5N=&ME>NES.B`E<P!5=&]L
M<_,@8F5J96QE;G1K97KI<SH@)7,L("5S(&/M;7+U;`!5=&]L<_,@8F5J96QE
M;G1K97KI<SH@;>EG('-O:&$@;F5M('9O;'0`3&5T=&]R<WKA9P!*;V<`16QH
M96QY97KI<P!(86=Y:F$@_')E<V5N+"!H82!N96T@86MA<B!K97)E=&5T`$QI
M8F%N;VX`8F%L`$)A;"!O;&1A;&D@9F5J;.EC`$)A;"!O;&1A;&D@Z7)TZ6ME
M:P!,97-O=&AO`$QI8NER:6$`3.UB:6%I($%R86(@4WIO8VEA;&ES=&$@3F%G
M>2!.Z7!I($OV>O9S<^EG`$QI96-H=&5N<W1E:6X`1WEE;F=E('-Z:73A;/,@
M97/U`$=Y96YG92!E<_4`1.EL96SU='0@9WEE;F=E(&5S]0!$Z6QU=.%N+V5S
M=&4@9WEE;F=E(&5S]0!'>65N9V4@>N%P;W(`1WEE;F=E('II=F%T87(`1WEE
M;F=E(&AA=F%ZX7,`1WEE;F=E(&CS>N%P;W(`3&EN:P!!(&QI;FL@:61E(&UU
M=&%T.@!-96=J96QE;NUTZ7-K;W(@;75T87-S;VX@96=Y(&QI;FL@82!L97;I
M;&/M;7+U;"!A(&QE=NEL[7+S(&%B;&%K:&]Z`$QI;FME:P!,:6YU>`!,:7-T
MX7KA<R`M(&$@9F5L:&%S>F[A;/,@;.%T:F$@82!M87!PX70`07H@861A=&+A
M>FES;VL@;&ES=.%J80!!>F]K;F%K(&$@=.EMX6MN86L@82!L:7-TX6IA(&%M
M:7+U;"!S96?M='/I9R!K87!H873S`$%Z(&%D871TX6)LX6L@;&ES=.%J80!,
M:7-T82!A<F-H[79U;0!,:7-T82!S96?M='/I9VOI<NES`$QI<W1A(&%Z;VYO
M<^UT\P!,:7-T82!T=6QA:F1O;F]S`$QI<W1A(&QE=NEL[7+A<P!,:7-T82!F
M96QI<F%T:V]ZX7,@*'-U8G-C<FEB92D`3&ES=&$@;&5I<F%T:V]ZX7,@*'5N
M<W5B<V-R:6)E*0!!(&9E;&AA<WINX6SS:R!K:6QI<W3A>N%S82!T:6QT=F$@
M=F%N+@!)<F]D86QO;0!,:71VX6YI80!,;V%D:6YG(&QI8G)A<FEE<RXN+@!,
M973V;'3I<RXN+@!(96QY:2!I9/4Z(`!.>65L=BP@9.%T=6TL(&ED]0!(96QY
M`$)E:F5L96YT:V5ZZ7,`2VEJ96QE;G1K97KI<P!"96IE;&5N=&ME>NES<V5L
M(&MA<&-S;VQA=&]S(&9E;&%D871O:P!!(&)E:F5L96YT:V5ZZ7,@;F5M('-I
M:V5R_&QT+"!M97)T(')O<W-Z(&9E;&AA<WINX6SS;F5V970@=F%G>2!J96QS
M>O-T(&%D;W1T(&UE9RX`02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="X`
M2VEJ96QE;G1K97KI<P!(;W-S>OH@<WKV=F5G`%-Z97)E;&5M`&%L86-S;VYY
M`&?V<O9G(&MI<V)E=/MK`&QA=&EN(&MI<V)E=/MK`&MI<V)E=/MS('+S;6%I
M('-ZX6UO:P!,=7AE;6)U<F<`34T`3F%P:2#\>F5N971E:P!!>B!-4RU43D5&
M(&UE;&SI:VQE=&)E;B!N:6YC<R!A9&%T+@#<6D5.150`36%K8?,`36%K963S
M;FEA`$UA9&%G87-Z:^%R`%9A<N%Z<VQA=`!,979E;&5ZZ7,`16UA:6P@9&]M
M86EN(&ME>F5LZ7,`3&EN:R!KZ7-Z[73I<V4`36%K92!S=7)E('1H870@>6]U
M(&AA=F4@4$5!4B!I;G-T86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P871H
M+@!-86MI;F<@9&ER96-T;W)Y("5S`$UA;&%W:0!-86QA:GII80!-86QD[78M
M<WII9V5T96L`36%L:0!-X6QT80!!9&%T86ET(&MA=&5G\W)IX6MB82!S;W)O
M;&AA=&IA+B!%>F5K(&ET="!D969I;FGA;&AA=/-K+"!M\V1O<^UT:&%T\VLL
M('1O=N%B8N$@<WKM;F5K(')E;F1E;&AE=/5K(&AO>GKA:G5K+@!-87`R-"!T
MZ7)KZ7``36%P475E<W0@=.ER:^EP`&WA<F-I=7,`36%R9_,`07H@3VQV87-O
M='0O3VQV87-A=&QA;B!J96QZ971E:R!H87-Z;N%L871A`$WA<R!J96QZ971E
M:R`H<&PN($9O;G1O<R]-96=VX6QA<WIO;'0I(&AA<WINX6QA=&$`36%R<VAA
M;&PM<WII9V5T96L`36%R=&EN:7%U90!%9WEMX7-N86L@;65G9F5L96SU(&UE
M>O5K`$UA=7)I=.%N:6$`36%U<FET:75S`$UA>&EMX6QI<R!R96YD96QK97KI
M<W)E(.%L;/,@<WKA;6QA]G-S>F5G+@!!>B#\>F5N970@=/IL('-O:R!RZ7-Z
M8O5L(.%L;"X`07H@96QM^FQT(#(T(/-R82!M87AI;>%L:7,@:/5MZ7)SZ6ML
M971E.B``07H@96QM^FQT(#8@\W)A(&UA>&EMX6QI<R!H]6WI<G/I:VQE=&4Z
M(`!-87AI;>%L:7,@:&]S<WH`;>%J=7,`36%Y;W1T90!/<G9O<W1U9&]MX6YY
M`%1A9V]K`$$@;65N_"!M96=J96QE;NES93H`0V5L;.%K(&5G>6)E;VQV87-Z
M=.%S80!-97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@8V]M<&5N9&EU
M;2XN+B``365R9VEN9R!L;V-A;&4@)7,N+BX@`$UE<F=I;F<@=&AE(%!/(&9I
M;&4@9F]R("5S('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG('1R86YS
M;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BX`W'IE;F5T`$$@9&EG:73A;&ES86X@
M86SA[7)T(/QZ96YE="!H:71E;&5S+"!D92!A>B!A;.'M<O,@=&%N^G/M=';A
M;GGA="!N96T@<VEK97+\;'0@96QL96[U<FEZ;FDN`$QE:N%R="!A>B#\>F5N
M970@Z7)VZ6YY97-SZ6=E+@!!>B#\>F5N970@=.UP=7-A`$UE=&%R(&ED]6KA
M<N%S:F5L96YTZ7,`02!-971A<B!B;&]K:R!N96T@X6QL(')E;F1E;&ME>NES
M<F4N`$$@365T87(@8FQO:VL@;F5M(.%L;"!R96YD96QK97KI<W)E+B!!('+I
M<WIL971E:R!A(')E;F1S>F5R9V%Z9&$@<WKA;>%R82!KZ7-Z_&SU(&YA<&SS
M9N%J;&)A(&ME<OQL=&5K+@!!($UE=&%R1$(@;F5M(.ER:&5T]2!E;"X`3?-D
M<WIE<@!!*'HI("<E<R<@;?-D<WIE<B!D969I;FGA;&%T;&%N+@!-971R:6MU
M<P!-97AI:_,`36EK<F]NZ7II86D@4WKV=F5T<^EG:2#!;&QA;6]K`&OV>NEP
M`$U)344@=.UP=7,`07H@96QM^FQT(#(T(/-R82!L96=A;&%C<V]N>6%B8B!H
M]6WI<G/I:VQE=&4Z(`!!>B!E;&WZ;'0@-B#S<F$@;&5G86QA8W-O;GEA8F(@
M:/5MZ7)SZ6ML971E.B``5/QK<O9ZZ7,@*&IO8F(O8F%L*0!696=Y97,`2&GA
M;GEZ:6L@82!(5%107U)E<75E<W0@4$5!4B!C<V]M86<N`$MO;F9I9W5RX6-I
M\R!S>OQK<^EG97,N($5Z="!M;W-T(&ME;&P@;.ET<F5H;WIN:6$L(&AA(&AA
M<WINX6QN:2!A:V%R:F$@87H@86QK86QM87KA<W0N`$AIX6YY>FEK(&%Z(/QZ
M96YE="!A>F]N;W/M=/-J82X`2&GA;GEZ:6L@82!-86EL(%!%05(@8W-O;6%G
M+@!(:>%N>7II:R!A(&MA<&-S;VQA=&D@87IO;F]S[73S("AS97-S:6]N($E$
M*2X`2.D`3&5V96QE>NES(&UO8FEL=&5L969O;G+S;`!+]GIE<&5S`$$@;?-D
M;W/M=.%S(&3A='5M80!!>B!54DP@;?-D;W/M=.%S80!-;V1U;&4`36]D=6QU
M<P!-;VQD;W9A:2!+]GITX7)S87/A9P!-;VYA8V\`36]N9_-L:6$`2/-N87`@
MZ7,@Z78`:&%V;VYT80!-;VYT<V5R<F%T`$AO;&1FX7II<V]K`$UA<F]K:_,`
M5/9B8FYY:7)E(&1E<OQL=`!4]F)B;GEI<F4@8F]R=6QT`%3V8F)N>6ER92!N
M87!O<P!V:6=Y_&L@;&4`=FEG>?QK(&)A;')A`'9I9WG\:R!J;V)B<F$`=FEG
M>?QK(&;V;`!V:6=Y_&L@;&4`=FEG>?QK(&;V;`!-;WIA;6)I:P!4]F)B<WII
M;G3[(&QE9_9R9/QL]2!L:7-TX6L`5/9B8G-Z]G+V<R!VX6QA<WITX7,`0F5J
M96QE;G1K97KI<VD@8F7A;&SM=.%S;VL`4V%JX70@]G-S>F5G>O4@;VQD86QA
M;0!386KA="#V<W-Z96=Z]2!O;&1A;&%M('1E<G9E>NES90!-:6%N;6%R`$Y%
M32P@;F5M(&5G>65Z96T@8F5L92X`3NEV`$YA;>UB:6$`3F%U<G4`3F5PX6P`
M2&]L;&%N9&EA`$AO;&QA;F0@06YT:6QLX6L`3F5T<V-A<&4@8N%Z:7,M55),
M`$YE='-C87!E('1A;OIS[71VX6YY:VEA9.%S:6IO9RA#02DM=FES<WIA=F]N
MX7-I(%523`!.971S8V%P92!T86[Z<^UT=N%N>69E;&AA<WINX6SA<VD@:7+A
M;GEE;'8@55),`$YE='-C87!E('1A;OIS[71VX6YY;65G^FKM=.%S:2!54DP`
M3F5T<V-A<&4@=&%N^G/M=';A;GEV:7-S>F%V;V[A<VD@55),`$YE='-C87!E
M(%-33"!S>F5R=F5R;NEV`$YE='-C87!E('1A;OIS[71VX6YY(&UE9VIE9WEZ
MZ7,`3F5T<V-A<&4@=&%N^G/M=';A;GET[7!U<P!(X6SS>F%T`'-O:&$`VFHM
M2V%L963S;FEA`-IJ(&MA=&5G\W)I80#Z:FAO;&0`VFH@9F5L:&%S>F[A;/-N
MZ78@*&]P8VEO;N%L:7,I`-IJ+5KI;&%N9`#::B!J96QS>O,Z`-IJ(&%B;&%K
M("C\<F5S*0!([7)E:P!([7)C<V]P;W)T;VL`2_9V971K97KU`$OV=F5T:V5Z
M]2`T(&;A>FES`$OV=F5T:V5Z]2!O<&-I\VL`2_9V971K97KU/@!.:6-A<F%G
M=6$`3FEG97(`3FEGZ7)I80#I:G-Z86MA`$YI=64`3F5M`$YI;F-S(')E;F1E
M;&ME>NES<F4@X6QL\R!K;VYF:6=U<N%C:?,L(&%M:6AE>B!KZ7!E<W0@82!K
M_&SV;F)SZ6=E:V5T(&UE9R!L96AE=&YE(&UU=&%T;FDN`$YI;F-S(&QE:&5T
M]7/I9R!)4T\@X6QL;VWA;GEO:R!LZ71R96AO>N%SX7)A+@!(:>%N>7II:R!A
M(&OV=&5G96QT(&9E;&1O;&=O>N%S:&]Z('-Z_&MSZ6=E<R!M:6YT82`H8F%T
M8V@@=&5M<&QA=&4I+@!!(&OM=N%N="!H96QY96X@;FEN8W,@8FQO:VL`07H@
M34-!3"!F96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@;FEN8W,@;65G861V82!A
M(&YA<'3A<B!N979E+@!.:6YC<R!VX6QT;WKA<RX`17H@86QA='0@82!S>FEN
M="!A;&%T="!N96T@:&]Z:&%T\R!LZ71R92!J;V=O<W5L='/A9VD@86QC<V]P
M;W)T+@!%:&AE>B!A(&IO9V]S=6QT<^%G:&]Z(&YE;2!H;WIH873S(&SI=')E
M(&IO9V]S=6QT<^%G:2!A;&-S;W!O<G0N`$YO(&-O;6UA;F0@<W!E8VEF:65D
M+@!(:>%N>6]Z;F%K(&$@:V]N9FEG=7+A8VGS<R!A9&%T;VL@)7,M:&5Z+@!!
M>B!&5%`@5D93(&YI;F-S(&MO;F9I9W5RX6QV82X`07H@4U%,(%9&4R!N:6YC
M<R!K;VYF:6=U<N%L=F$N`$%Z(%-13"U&:6QE(%9&4R!N:6YC<R!K;VYF:6=U
M<N%L=F$N`$%Z(-9N('-ZX6ULX6KA;B!E;&9O9WEO='0@82!R96YD96QK97KI
M<W)E(.%L;/,@]G-S>F5G+@!.:6YC<R!C[6UZZ7,N`$YO(&5N=')Y('=I=&@@
M=&AE(&ED("<E<R<@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N
M`$$@<WIE<G9E<G)E(&YE;2!T]FQT]63V='0@9F5L('-E;6UI;'EE;B#A;&QO
M;>%N>0!!>B!I:V]N;VL@;F5M('1A;.%L:&%T\VLN`$YO(&QO8V%L92!S<&5C
M:69I960N`$YI;F-S(&UE9V%D=F$@82!H96QY+@!.:6YC<R!M96=A9'9A(&$@
M:&5L>2X`07H@_'IE;F5T(/QR97,N`$YI;F-S(&UE9V%D=F$@82!NZ78N`$YI
M;F-S(&UE9V%D=F$@82!S>N%M+@!.92!L96=Y96X@;65G8F]T<N%N:V]Z=&%T
M\R!I9.EZ970`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!(5%10(&%L87#Z(&9E
M;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G861V
M82!A>B!)34%0(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.
M:6YC<R!J96QS>O,@;65G861V82!A($ME<F)E<F]S(&%L87#Z(&9E;&AA<WIN
MX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G861V82!A>B!,
M1$%0(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J
M96QS>O,@;65G861V82!A($QO9VEN(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N
M;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G861V82!A(%!!4U-71"!A;&%P
M^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE
M9V%D=F$@87H@4TU"(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z
M+@!.:6YC<R!M96=A9'9A(&%Z($]P96Y34TP@<')O9W)A;2!E;.ERZ7-I(/IT
M=F]N86QA+B!!>B!/<&5N4U-,('!R;V=R86T@<WK\:W/I9V5S(&$@4$M#4R`Q
M,B!A9&%T;VL@:V5Z96SI<^EH97HN`$YI;F-S(/IJ(&)E:F5L96YT:V5ZZ7-I
M(&EGZ6YY+@!.92!L96=Y96YE:R!V;VYA;&%K('-E:&]L+@!.92!L96=Y96X@
M:V5R970`3FEN8W,@:61E:6=L96YE<R#A;&QO;>%N>6]K('3A<F]LX7/A<F$@
M<WIO;&?A;/,@86QK]FYY=G3A<BX`2&GA;GEZ:6L@82!F96QH87-Z;N%L\V[I
M=B#I<R]V86=Y(&$@:F5L<WKS+@!!('9I<W-Z86MA<&]T="!A9&%T;VL@;F5M
M(.ER=NEN>65S(%A-3"!A9&%T;VL`3FEN8W,@861A=`!.:6YC<R!MZ6<@:V]N
M9FEG=7+A8VGS+"!G96YE<N%L:F]N(&5G>65T+@!.:6YC<R!MZ6<@:V]N9FEG
M=7+A8VGS:F$L(&=E;F5RX6QJ;VX@96=Y970N`&YI;F-S`&YI;F-S(&UE9V%D
M=F$@*&QE9WEE;B!A;&%PZ7)T96QM97IE='0I`&YO<F1I:W5S("A)4T\M.#@U
M.2TQ,"D`3F]R9F]L:RUS>FEG970`R7-Z86MI(&;I;'1E:V4`R7-Z86MI+4UA
M<FEA;F$M<WII9V5T96L`3F]R=NEG:6$`3F5M(&OI<_5B8@!.96T@:V]RX6)B
M86X`3F5M(&%L:_9N>79TX7(`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG
M(&YI;F-S(&UE9W9A;/-S[71V82X`3FEN8W,@8F7A;&SM='9A`$YE;2!TX6UO
M9V%T;W1T+@!&96QJ96=Y>NES96L`3FEN8W,@8O9N9^ES>FAE=/4@861A="P@
M=.ER:F5N('9I<W-Z82X`1FEG>65L;65Z=&5TZ7,`;F]V96UB97(`4WKA;0!+
M87)A:W1E<F5K('-ZX6UA`$]S>FQO<&]K('-ZX6UA`%-O<F]K('-ZX6UA`$$@
M:_9R;&5VZ6QL:7-T82!M\V1O<^UTX7/A:&]Z(&YE;2!A9&]T="!M96<@<WKA
M;6]K870N`$]+`$]B:F5K='5M`$%Z(&]B:F5K='5M(&SI=')E:&]Z\VIA`$%Z
M(&]B:F5K='5M(&SI=')E:&]Z\VKA;F%K(&IO9V]S=6QT<^%G86D`3VMTX6QI
M<R!S>N%M`&]K=/-B97(`4WK[<NES`$AI=F%T86PO;75N:V%H96QY`$IE;&5N
M;&5G:2!J96QS>O,Z`$]MX6X`0W-A:R!A>B!)34%0('-Z97)V97)E:R!TX6UO
M9V%T:N%K(&$@;6%P<.%K(&UE9V]S>G3A<^%T+@!#<V%K(&UE9V)O='+A;FMO
M>G1A=/,@:63I>F5T(&QE9WEE;@!#<V%K(&5G>2!E;6%I;"!C[6T@861H873S
M(&UE9RX`0W-A:R!A('1U;&%J9&]N;W,@=F%G>2!A(')E;F1S>F5R9V%Z9&$@
M=N%L=&]Z=&%T:&%T:F$@;65G(&5G>2!K]GKV<R!TX7)T97+\;&5T('1U;&%J
M9&]N;W/A="!V86=Y(&5LZ7+I<VD@:F]G;W-U;'1SX6=A:70`3GEI<W-U:R!M
M96<@^FH@86)L86MB86X`3W!E;E-33"!H:6)A.B!.96T@<VEK97+\;'0@:VEN
M>65R;FD@87H@861A=&]K870@87H@86SA[7)T(%,O34E-12!RZ7-Z8O5L`$YY
M:7-S=6L@;65G(&5Z="!A(&/M;65T(&5G>2#Z:B!A8FQA:V)A;@!/<&5RX6-I
M\W,@<F5N9'-Z97(`3W!C:?-K`"5S(&)EX6QL[73A<V%I`$]P=&EO;G,Z`%-O
M<G-ZX6UO<R!F96QS;W)O;.%S`%-Z97)V97IE=`!3>F5R=F5Z971I(&5G>7/I
M9P!-=6YK87-Z97)V97KI<P!!>B!A;&MA;&UA>N%S(&5R961E=&D@<V%B;&]N
M:F$`)7,@97)E9&5T:2!S86)L;VYJ86DZ`$5G>>EB`$5G>>EB(&EN9F]R;>%C
M:?,`02!T=6QA:F1O;F]S(&IO9V]S=6QT<^%G86D`02!004T@9F5L:&%S>F[A
M;/-A>F]N;W/M=.%S(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X`4$=0(&1I9VET
MX6QI<R!A;.'M<N%S`%!'4"UV96P@=&ET:V]S[71O='0@861A=`!01U`@;GEI
M;';A;F]S(&MU;&-S`%!'4"UV96P@86SA[7)T+W1I=&MO<^UT;W1T(&%D870`
M4$A0(&OS9`!$Z6QU=.%N+V5S=&4@9WEE;F=E(&5S]0!$Z6QU=.%N+V5S=&4@
M>N%P;W)O:P!$Z6QU=.%N+V5S=&4@:&%V87KA<P!$Z6QU=.%N+V5S=&4@:/-Z
MX7!O<F]K`$3I;'5TX6X@;F%P<_QTZ7,`1.EL=73A;B]E<W1E('II=F%T87)O
M:P!B96QS]2!M87)G\P!086MI<WITX6X`4&%L874`4&%L97-Z=&EN(%1E<OQL
M970@*&UE9W-ZX6QL="D`4&%N86UA`%#A<'5A(-IJ+4=U:6YE80!087)A9W5A
M>0!-Z7)SZ6ME;'1E;B!B;W)U;'0`2F5L<WKS`$$@:F5L<WKS(&UE9W;A;'1O
M>F]T="$`3F5M(&UE9V9E;&5L]2!J96QS>O,`02!*96QS>O,@;6]D=6P@;FEN
M8W,@;65G9F5L96SU96X@:V]N9FEG=7+A;'9A`$$@4D%$2553(&9E;&AA<WIN
MX6SS87IO;F]S[73A<VAO>B!J96QS>O,@<WK\:W/I9V5S+@!*96QS>O,@;65G
M97+U<^UTZ7-S96P`2F5L<WKS.@!*96QS>O,Z(`!!(&IE;'-Z879A:VYA:R!E
M9WEE>FYI_&L@:V5L;"X`0F5I;&QE<WITZ7,`0F5I;&QE<WITX7,@82!VX6?S
M87-Z=&%L<O-L`-IT=F]N86P`VFH@9F5L:&%S>F[A;/-N86L@8F5J96QE;G1K
M97IE='1E:SH`16UB97)E:P!S>N%Z86SI:P!+87)B86YT87)TX7-I(&9E;&%D
M871O:R!VZ6=R96AA:G3A<V$`0F5J96QE;G1K97KI<VMO<B!H86IT<W5K(';I
M9W)E(&$@:V%R8F%N=&%R=.%S:2!F96QA9&%T;VMA=#\`2F]G;W-U;'1SX6<`
M02`G)7,G(&IO9V]S=6QT<^%G;W0@;F5M('3V<O9L=/QK+@!*;V=O<W5L='/A
M9R!A9&UI;FES>G1RX6-I\P!%;.ERZ7-I(&IO9V]S=6QT<^%G;VLZ`%-Z96WI
M;'EE<R!A9&%T;VL`4&5R=0#!;&QA=&ME9'9E;F-E:P!&_&SV<"US>FEG971E
M:P!496QE9F]N`$;I;GEKZ7!G86SI<FEA`%!I=&-A:7)N`'!I>&5L`$OV>FAE
M;'EE:P!+871T:6YT<V]N('9A;&%M96QY:6L@8V5L;.%R80!":7IT;W-A;B!T
M]G+V;&YI(&%K87)J82!E>G0@87H@96QE;65T.@!+Z7)E;2!E<O5S[71S92!M
M96<L(&AO9WD@=F%L\V)A;B!T]G+V;&YI(&OM=N%N:F$@97IT(&%Z(&5L96UE
M="X`2^ER96T@861J;VX@;65G(&5G>2!H\VYA<&]T(.ES(&5G>2#I=F5T+@!+
MZ7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E9_-R:6$@;F5VZ70Z`$OI<F5M('9A
M;/-S($E0(&/M;65T(&%D:F]N(&UE9RX`2^ER96T@=F%L\W,@9.%T=6UO="!A
M9&IO;B!M96<L(&5L;&5N]7)I>GIE(&$@:/-N87`@;F%P:F%I="X`2^ER96T@
M=F%L\W,@9.%T=6UO="!A9&IO;B!M96<N`$OI<F5M('+V=FED96X@[7)J82!L
M92!A('!R;V)LZ6UA(&SI;GEE9^ET+@!+Z7)E;2!A9&IA(&UE9R!A(&)E:F5L
M96YT:V5ZZ7-I(&YE=NET(.ES(&IE;'-Z87;A=`!+Z7)E;2!O;'9A<W-A(&5L
M(&$@:_9V971K97KU('-Z]G9E9V5T+B!!(')E;F1S>F5R(&AA<WINX6QA=.%N
M86L@9F5L=.ET96QE:70@96P@2T5,3"!F;V=A9&YI82X`4&QE87-E(')E<&]R
M="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R9RX`2^ER96T@861J
M82!M96<@87H@^FH@:V%T96?S<FEA(&YE=NET.@!,96YG>65L;W)S>N%G`%!O
M;&ET:6MA`%-Z879A>N%S;VL`4&]R='5GX6QI80!!(&OI<"!E;&AE;'EE>NES
M90!!('3A8FSA>F%T(&5L:&5L>65ZZ7-E`$OV>G9E=&QE;B!L97;I;&O\;&3I
M<R!E8F)E(&$@;6%P<.%B82`H24U!4"!N96T@;6EN9&EG('9E<WII(&9I9WEE
M;&5M8F4I`$%Z(&5L;?IL="`E<R#S<F$@8W-A<&%DZ6MM96YN>6ESZ6=E.B``
M4')E9G-?;&1A<#H@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E<R!,1$%0(&MI
M=&5R:F5S>G3I<RX`4')E9G-?<V5S<VEO;CH@;F5M('1A;.%L:&%T\R!A('-Z
M_&MSZ6=E<R`H<V5S<VEO;BD@:VET97)J97-Z=.ES+@!,Z6=N>6]MX7,`02!T
M96YG97)S>FEN=&YE:R!M96=F96QE;/4@;.EG;GEO;>%S.B``3.EG;GEO;>%S
M.B``16SU>F5T97,@;65G=&5K:6YTZ7,`02!KZ7`@96SU>F5T97,@;65G=&5K
M:6YTZ7-E(/IJ(&%B;&%K8F%N`$5L]7KU(&]P8VGS:P!!(&1O:W5M96YT=6T@
M:VEN>6]M=&%TX7-A`%1I=&MO<R!K=6QC<P!(:6)A8F5J96QE;G3I<P!!(&AI
M8F$@;&7M<N%S80!0<F]B;.EM80!0<F]J96MT(&ME>F5LZ7,`02!P<F]M<'0@
M<WKV=F5G90!.>6EL=N%N;W,@:W5L8W,`3GEI;';A;F]S(&MU;&-S^B!A;&=O
M<FET;75S`$YY:6QVX6YO<R!K=6QC<R!I;F9O<FWA8VGS`$$@;GEI;';A;F]S
M+W1I=&MO<R!K=6QC<W#A<G0@;F5M('-I:V5R_&QT(&SI=')E:&]Z;FDN`%!U
M97)T;R!2:6-O`$MA=&%R`$ME<F5S]2]P87)A;F-S('-T<FEN9P!24T$@;GEI
M;';A;F]S(&MU;&-S("@E9"!B:71E<RD`4N%D:?-G;VUB;W,@:VEVX6QA<WIT
MX7,`17/U`$5S]2!DZ6QE;/5T=`!%<_4@9.EL=73A;B]E<W1E`%KA<&]R`$5S
M]2#I<R!H879A>N%S`$AA=F%S97/U`%;I;&5T;&5N(&EDZ7IE=`!!<N%N>0!/
M;'9A<^%S`$QE=F5L96L@;VQV87/A<V$`5.EN>6QE9R!T]G+V;&K\:R`E<R!F
M96QH87-Z;N%L\W0_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M(&9O<F3M=&AA=/,@
M=FES<WIA+@!4Z6YY;&5G('3V<O9L:OQK("5S(&9E;&AA<WINX6SS(&%D871A
M:70_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M(&9O<F3M=&AA=/,@=FES<WIA+@#:
M:G)A(';I9W)E:&%J=&IA(&%Z('5T;VQS\R!VX6QT;WIT873A<W0`02!M96[\
M(&1I;F%M:6MU<R!E;&5M96EN96L@9G)I<W/M=.ES:2!G>6%K;W)I<^%G83H`
M07H@:6YD=6SS;VQD86P@9G)I<W/M=.ESZ6YE:R!G>6%K;W)I<^%G83H`3V)J
M96MT=6T@8O9N9^ES>O4`365G:F5G>7KI<V5K`%3A=F]L:2!S>F5R=F5R96L`
M02!TX79O;&D@55),("AP;"X@:'1T<#HO+W=W=RYV86QA;6DN:'4O;65G=F%L
M86UI*3H`5/9R;.ES`$)L;VMK('3V<FSI<V4`3W-Z;&]P('3V<FSI<V4`02!F
M;W)M871TX6SA<R!T]G)LZ7-E`$$@<.%R('3V<FSI<V4`5/9R]FQJ_&L@87H@
M96QM96YT971T('!R;V=R86UO="!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO
M;>%N>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV=.%RX6+S;"X`5F5G>?QK(&MI
M(`!696=Y_&L@:VD@97IT(&$@<NES>G0@82!D;VMU;65N='5M8O-L`$$@9F5L
M:&%S>F[A;/,@=/9R;.ES90`E<R!F96QH87-Z;N%L\R!T]G)LZ7-E`$$@:^ER
MZ7,@;F5M('1E;&IE<^UT:&5T]2X@02!K87!O='0@:&EB86OS9#H@`$$@:V5R
M97-E='0@<WIO;&?A;'1A=.%S(&YE;2!T86SA;&AA=/,N`$$@:_9T96QE>O5E
M;B!M96=A9&%N9/,@)R5S)R!N96T@<WIE<F5P96P@)7,@:V]N9FEG=7+A8VGS
M:N%B86XN`$$@:_9T96QE>O5E;B!M96=A9&%N9/,@)R5S)R!N96T@<WIE<F5P
M96P@82!61E,@:V]N9FEG=7+A8VGS:N%B86XN`$$@:_9T96QE>O5E;B!M96=A
M9&%N9/,@)R5S)R!N96T@<WIE<F5P96P@82!K;VYF:6=U<N%C:?-B86XN`"=P
M:'!T>7!E)R!N:6YC<R!S<&5C:69I:^%L=F$@87H@4U%,(&MO;F9I9W5RX6-I
M\V)A;BX`4WK\:W/I9V5S(&UE>O4`5&ES>G1A(/MR;&%P`$$@:F5L<WKS(.%T
MX6QL[73A<V$`07H@UFX@:F5L<WIA=N%N86L@X73A;&SM=.%S80!%<F5D;>EN
M>0!297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.@!297-U;'1S.@!6:7-S>F$@
M87H@;W!C:?-K:&]Z`%+I=6YI;VX`P6QL[71S=6L@=FES<WIA(&$@:V]N9FEG
M=7+A8VGS=`!2:6-H(%1E>'0@161I=&]R(&]P8VGS:P!486SA;/-S(&OI<F3I
M<V5K`&IO8F(`2F]B8B!O;&1A;&D@9F5J;.EC`$IO8F(@;VQD86QI(.ER=.EK
M96L`4V]R('1U;&%J9&]N<^%G;VLN+BX`4WIE<F5P`%)O;>%N:6$`1F]R9V%T
MX7,@,3@P(&9O:VMA;`!"86QR82!F;W)G873A<P!*;V)B<F$@9F]R9V%TX7,`
M4V]R('1U;&%J9&]N<^%G;VL`4V]R('1U;&%J9&]N<^%G;VL`4V]R;VLZ`%9O
M;F%L86L`36EN9&5N('-O<B#I<R!O<WIL;W`@:_9Z]G1T(&QE9WEE;B!V;VYA
M;`!#<V%K(&%Z(&]S>FQO<&]K(&OV>O9T="!L96=Y96X@=F]N86P`0W-A:R!A
M('-O<F]K(&OV>O9T="!L96=Y96X@=F]N86P`1G5T=&%TX7,`3W)O<WH@1O9D
M97+A8VGS`%)U86YD80!3+TU)344@9&EG:73A;&ES(&%LX>URX7,`4R]-24U%
M('-Z86)VX6YY('-Z97)I;G0@=&ET:V]S[71O='0@;&5VZ6P`4T%33"!F96QH
M87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('1A;.%L:&%T\RX`4TU3(&O\;&3I<P!3
M4T@`4TE+15+<3%0`4WIO`%-Z96YT($EL;VYA+7-Z:6=E=`!386EN="!+:71T
M<R#I<R!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@Z7,@36EQ=65L
M;VX`4V%I;G0@5FEN8V5N="#I<R!'<F5N861I;F4M<WII9V5T96L`56=Y86YA
M>B!A(&9R86UE("A?<V5L9BD`4WIA;6]A`%-A;B!-87)I;F\`4V%O(%1O;>D@
MZ7,@4'+M;F-I<&4`3?MH;VQD87,@:6YT97)N971E;.ERZ7,`4WIA^F0M07+A
M8FEA`$UE;G3I<P`E<R!M96YTZ7-E`"<E<R<@;65N=.ES90!!(&)EX6QL[73A
M<V]K(&UE;G3I<V4`365N='/\:R!E;"!A>B!E;&OI<WK\;'0@:V]N9FEG=7+A
M8VGS="!02%`@<')O9W)A;2!F;W)MX6KA8F%N(&$@<WIE<G9E<B!I9&5I9VQE
M;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7+A8F%N+@`E
M<R!K;VYF:6=U<N%C:?-JX70@96QM96YT971T_&LN`$5L;65N=&5T=/QK(&$@
M<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0@:61E.B`G)7,G`%-Z\W)VX6YY;W,@
M>FEV871A<F]K`%1U9&]MX6YY`$ME<F5SZ7,`2V5R97/I<VD@<WIO;&?A;'1A
M=.%S;VL`4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<P!396%R
M8VAI;F<@9V5T=&5X="!B:6YA<FEE<RXN+@#!;&QO;>%N>6]K(&MI=N%L87-Z
M=.%S80!6X6QA<W-Z;VX@:VD@96=Y(&3A='5M;W0`365L>6EK(&-S;W!O<G1O
M="!K[7;A;FIA(&AO>GKA861N:0!6X6QA<W-Z82!K:2!A>B#Z:B!T=6QA:F1O
M;F]S=`!6X6QA<W-Z;VX@<WIE<G9E<G0`365L>6EK(&9E;&AA<WINX6SS="!K
M[7;A;FIA(&AO>GKA861N:0!6X6QA<W-Z82!K:2!A>B#V<W-Z97,@9.%T=6WV
M<W-Z971E=O5T+@!6X6QA<W-Z;VX@96=Y(&]B:F5K='5M;W0`5N%L87-S>F$@
M:VD@82!K[7;A;G0@:V%R86MT97(H96ME*70@87H@86SA8F)I(&QE:&5T]7/I
M9V5K(&OV>OQL+B!%>G5TX6X@(F-O<'DO<&%S=&4B(&WS9'-Z97)R96P@82!M
M96=F96QE;/4@:&5L>7)E(&WA<V]L:&%T:F$@]6ME="X`5N%L87-S>F$@:VD@
M82!DX71U;65L=N%L87-Z=/,@:V%R86MT97)T.@!6X6QA<W-Z82!K:2!A(&3A
M='5M(&9O<FWA='5MX70Z`%;A;&%S<WIA(&MI+"!M96QY:6L@87IO;F]S[73S
M:N%T(&OM=N%N:F$@;65G=N%L=&]Z=&%T;FDZ`%;A;&%S<WIA(&MI(&%Z(&ED
M]65L=N%L87-Z=/,@:V%R86MT97)T.@!6X6QA<W-Z82!K:2!A>B!I9/4@9F]R
M;>%T=6WA=#H`5N%L87-S>F]N(&MI(&OI="!E9WEMX7-N86L@;65G9F5L96SU
M(&UE>O5T+@!6X6QA<W-Z82!K:2!A(&OM=N%N="!S>NUN96=Y_'1T97-T+@!6
MX6QA<W-Z82!K:2!A>B#6;FYE:R!M96=F96QE;/4@;GEE;'9E=#H`2&EB86IE
M;&5N=.ES(&O\;&3I<V4`4TU3(&O\;&3I<V4`4WIE;F5GX6P`4WIE;GIO<CH@
M`'-Z97!T96UB97(`4WIE<F)I82#I<R!-;VYT96YE9W+S`%-O<F]Z871S>N%M
M`%-E<G9E<@!!('-Z97)V97)T]6P@:V%P;W1T(&%D870@:&EBX7,L('9A9WD@
M;F5M(.%L;"!R96YD96QK97KI<W)E+@!,96KA<G0@82!K87!C<V]L871I(&%Z
M;VYO<^UT\R`H<V5S<VEO;B!)1"DN`$AA;&UA>@!,96AE=/5SZ6<@:F5L<WIA
M=N%N86L@X73A;&SM=.%SX7)A+"!A8F)A;B!A>B!E<V5T8F5N+"!H82!E;&9E
M;&5J=&5NZ2X`5.%V;VQI('-Z97)V97)E:R!E;.ERZ7-E(.%L;.UT:&%T\R!B
M92P@;65L>65K970@87H@:6YD=6SS;VQD86SA;B!K[7;A;B!M96=J96QE;NUT
M96YI+@!!(&OM=N%N="!N>65L=BP@:63U>O-N82#I<R!DX71U;69O<FWA='5M
M(&)EX6QL[73A<V$N`$)EX6QL[71H873S+"!H;V=Y(&UE;'EI:R!A;&MA;&UA
M>N%S(&IE;&5N:F5N(&UE9R!A(&)E:F5L96YT:V5ZZ7,@=73A;BP@;6EL>65N
M('-Z[6YE9WG\='1E<W0L(&]L9&%L9G)I<W/M=.ES:2!G>6%K;W)I<^%G;W0@
M:6QL+B!E9WGI8B!B9>%L;.UTX7-O:V%T('-Z97)E=&YE+@!"9>%L;.UTX7-O
M:P!!(&)EX6QL[73A<V]K870@;65G^FKM=/,@<')O9W)A;6]K(.%L;&YA:R!R
M96YD96QK97KI<W)E`$$@;65G861O='0@<&%R86WI=&5R('3V8F(@:&5L>65T
M(&ES(&IE;&5N=&AE=#H@`%-E>6-H96QL92US>FEG971E:P!6X7/A<FSA<P!2
M]G9I9"#V<W-Z969O9VQA;.%S`$5L(&OM=N%N:F$@Z7)N:2!A>B!E9WEE<R!F
M=6YK8VGS:V%T($%L="UB:6QL96YT>?LM:V]M8FENX6-I\VMK86P@:7,_`$UE
M9VIE;&5N[73I<P!-=71A<W-U:R!M96<@82!K_&SV;F)SZ6=E:V5T(&%Z(&5L
M;65N=&5T="#I<R!A>B#Z:F]N;F%N(&SI=')E:&]Z;W1T(&MO;F9I9W5RX6-I
M\R!K]GKV='0N`$UI;F1E;B!B96IE;&5N=&ME>NES:V]R(.UR\V1JZ6L@:VD@
M82!K;W+A8F)I('5T;VQS\R!B96IE;&5N=&ME>NES(&ED96IE/P!6X6QA<WIT
M:&%T\R!L96=Y96X@87H@97)E9&5T:2!M96=T87)TX7-A`$QE9WEE;B!DX71U
M;7;A;&%S>G3S`$QE9WEE;B!E9WD@=.%B;.%Z871K97IE;/4@;65N_'-O<C\`
M375T87-S=6L@82`E<R!M96[\="!A(&)A;"!O;&1A;&]N/P!.Z7IZ_&L@;65G
M('3A8FSA>F%T(&-E;&SA:6YA:R!T=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G
M('3A8FSA>F%T('1U;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@=.%B;.%Z870@
M<V]R86EN86L@='5L86ID;VYSX6=A:70`3NEZ>OQK(&UE9R!A(&OI<"!T=6QA
M:F1O;G/A9V%I=`!-=71A<W-U:R!A(&9E;'3V;'3I<W0`6N%P;W)O:P!:X7!O
M<F]K(&3I;&5L]71T`%KA<&]R;VL@9.EL=73A;B]E<W1E`$AE;'EI('KA<&]R
M;VL`2VEC<VEN>>UTZ7,`16SU<WKV<B!K:6-S:6YY[71E;FEE(&ME;&PL('9A
M9WD@96P@:V5L;"!M;WID[71A;FEA(&$@:&5L>65T(&5L9F]G;&%L\R!B;&]K
M:V]K870N`%-I97)R82!,96]N90#::B!F96QH87-Z;N%L\VL@8F5J96QE;G1K
M97KI<V4`2&$@;FEN8W,@<F5G:7-Z='+A;'9A+"!KZ7)J96X@8F5J96QE;G1K
M97KI<VD@:F]G;W-U;'1SX6=O=`!$:6=I=.%L:7,@86SA[7+A<P!!(&1I9VET
MX6QI<R!A;.'M<N%S(&%L9V]R:71M=7-A`%-Z:6YG87#Z<@!-Z7)E=`!!(&MA
M<F)A;G1A<G3A<R!K:6AA9WGA<V$`4VMI<'!E9"XN+@!3>FQO=N%K:6$`4WIL
M;W;I;FEA`$AA=F%ZX7,`2/-ZX7!O<@!(\WKA<&]R;VL`2/-ZX7!O<F]K(&3I
M;&5L]71T`$OI<_4@9.EL=73A;FDO97-T:2!H\WKA<&]R;VL`02!H\R!MZ6QY
M<^EG93H@`$CS(';M>FUE;FYY:7/I9V5B96X@:VEF96IE>G9E.B``4V%L86UO
M;BUS>FEG971E:P!3>F]MX6QI80!!(&OV=F5T:V5Z]2!087-S=V]R9"!M;V1U
M;"!K;VYF:6=U<N%C:?-S(.%L;&]MX6YY;VL@:&GA;GEZ;WIN86LZ`$1A;&]K
M+"!V97)S96L`02!S;W)B87)E;F1E>NES(&ERX6YYX6YA:R!K:7;A;&%S>G3A
M<V$`1F5L863S:2!C[6T`1.EL+4%F<FEK80!DZ6PM975R\W!A:2`H25-/+3@X
M-3DM,RD`1.EL:2U'96]R9VEA(.ES($3I;&D@4V%N9'=I8V@M<WII9V5T96L`
M1.EL:2!FZ6QT96ME`%-Z;VUS>NED;W,@8V5L;.%K(&OV>O9T=&D@=.%V;VQS
MX6<`02!C96QL82!T87)T86QM82#I<R!K97)E=&4@:_9Z]G1T:2!TX79O;'/A
M9P!(96QY:VET]FQT]0!4X79O;'/A9P!4X79O;'/A9R#I<R!B96QS]2!M87)G
M\R!B9>%L;.UTX7,`4W!A;GEO;&]R<WKA9P!3<&%M87-S87-S:6YE(&)EX6QL
M[73A<V]K`%-P96-IX6QI<R!K87)A:W1E<B!B979I=&5L90!!(&-E;&QA(&ME
M='3I8F]N=.%S80!!>B!O<WIL;W`@:V5T=.EB;VYTX7-A`$$@<V]R(&ME='3I
M8F]N=.%S80!3<&]R=`!3<NT@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`$%Z
M(&5L<_4@Z78`P6QL86T@=F%G>2!T87)T;VWA;GD`P6QL87!O=`!3=&%T=7,@
M9F]R(&QO8V%L92`E<RXN+B``365N=.ES:2!F;W)MX71U;0!#[6T@*'5T8V$I
M`.%T:/IZ;W1T`%-T<FEN9R!L:7-T80!4]G+V;&K\:R!A(&/M;6+U;"!A($`@
M=73A;FD@<NES>G0`4W3M;'5S(%M#4U-=`%9A`$$H>BD@)R5S)R!A;&OV;GEV
M=.%R(&YE;2!T86SA;&AA=/,N`%3A<F=Y`$O\;&1J_&L@96P`)R5S)R#Z:B!F
M96QH87-Z;N%L\R!B96IE;&5N=&ME>NES:2!KZ7)E;&WI="!T;W;A8F+M=&]T
M='5K+B#6;B!C<V%K(&OI<F5L;>EN96L@96QF;V=A9.%SX70@:_9V973U96X@
M='5D(&UA:F0@8F5J96QE;G1K97IN:2X`86QS\R!I;F1E>`!3:6ME<OQL=`!3
M:6ME<F5S96X@:&]Z>N%A9'1U:R`G)7,G+70@82!R96YD<WIE<FAE>BX`)R5S
M)R!F96QH87-Z;N%L\R!A9&%T86ET('-I:V5R97-E;B!T]G+V;'3\:R!A(')E
M;F1S>F5R8O5L+@!3:6ME<F5S96X@=/9R]FQT_&L@)R5S)RUT+@!3:6ME<F5S
M96X@96QTX79O;.UT;W1T=6L@)R5S)RUT(&$@<F5N9'-Z97)B]6PN`$$@:V]N
M9FEG=7+A8VGS="!S:6ME<F5S96X@=FES<WIAX6QL[71O='1U:RX@02!VX6QT
M;WKA<V]K(&UE9W1E:VEN=.ESZ6AE>B!F<FES<^UT<V4@87H@;VQD86QT+@!!
M(&)A8VMU<"!K;VYF:6=U<N%C:?-T(&5L;65N=&5T=/QK+@!3:6ME<F5S96X@
M96QM96YT971T_&L@82AZ*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="X`)R5S
M)R!A9&%T86EN86L@;?-D;W/M=.%S82!S:6ME<F5S96X@;65G=/9R=.EN="X`
M4VEK97)E<V5N(&5L;65N=&5T=/QK(&$@)7,@X6QL;VWA;GET+@!3>G5DX6X`
MUG-S>F5F;V=L86SA<P!.87!K96QT90!.87!N>75G=&$`;F%P;W,`3F%P:V5L
M=&4`3F%P:V5L=&4O;F%P;GEU9W1A`$YA<&ME;'1E.B``3F%P;GEU9W1A`$YA
M<&YY=6=T83H@`&9E;'/U(&EN9&5X`$]N;&EN92!K;VUM=6YI:^%C:?,@*&-H
M870I`%-U<FEN86UE`$-S86SA9&[I=@!3=F%L8F%R9"#I<R!*86X@36%Y96X`
M4WIVX7II9O9L9`!3=NED;W)S>N%G`%-VX6IC`%-Z:6YT86MT:6MA:2!H:6)A
M(&$@:V5R97/U:VEF96IE>NES8F5N`%-Z[7)I86D@07)A8B!+]GITX7)S87/A
M9P!::79A=&%R`%II=F%T87(L(&5R]7,@<WKI;`!::79A=&%R;VL`5%-6("A4
M04(@:V%R86MT97)R96P@96QVX6QA<WIT;W1T(.ER=.EK96LI(.%L;&]MX6YY
M`%3A8FSA>F%T`$$@=.%B;.%Z870@='5L86ID;VYSX6=A:0!!('3A8FSA>F%T
M('1U;&%J9&]N<^%G86D`5&%J=F%N`%1A:G9A;@!4861Z<VEK:7-Z=.%N`%1A
M;GKA;FEA:2!%9WEE<_QL="!+:7+A;'ESX6<`02!CZ6PZ`$9E;&%D871O:P!4
M96QE9F]N<WKA;0!!>B!E;&WZ;'0@\W)A(&CU;>ER<^EK;&5T93H@`$CU;>ER
M<^EK;&5T`$CU;>ER<^EK;&5T.B``02`G)7,G('-A8FQO;B!N96T@=&%LX6QH
M873S+@!386)L;VYO:R!A9&UI;FES>G3A8VGS:F$`4WKV=F5G`&-S86L@<WKV
M=F5G`%-Z]G9E9V5L:&5L>65ZZ7,`<WKV=F5G('1E=&5J90!#<_P`=&AA:2`H
M5$E3+38R,"D`5&AA:6;V;&0`2_9S>O9N:OQK+"!H;V=Y(&AA<WINX6QT82!S
M>F]L9^%L=&%TX7-U;FMA="X`5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E
M<VXG="!Y970@97AI<W0N($-R96%T:6YG(&$@;F5W(&]N92X`07H@9G1P(&+U
M=NUTZ7,@;F5M('1A;.%L:&%T\RX`02!(;W)D92]+;VQA8B!I;G1E9W+A8VGS
M(&5Z="!N96T@=.%M;V=A=&IA.B`B)7,B`$$@36%I;G1E;F%N8V4Z.B!O<WIT
MX6QY(&)E=/9L=.ES92!N96T@<VEK97+\;'0`07H@3W!C:?,@86)L86L@8F5Z
MX7)O9&]T="X@2VELZ7#I<R!K]G9E=&ME>FEK+@!!($IO9V]S=6QT<^%G;VL@
M:&%S>F[A;&%TX6YA:R!E;/5F96QTZ71E;&4L(&AO9WD@82!R96YD<WIE<F=A
M>F1A(&MO;F9I9W5RX6QJ;VX@96=Y(&$@:F]G;W-U;'1SX6=I(&%D871O:V%T
M('1A<G3S<V%N('3A<F]L;FD@:^EP97,@86QR96YD<WIE<G0N`$-S86L@86QU
M;"!L96=Y96X@:V5R970`02!P87)T;F5R(&%Z;VYO<^UT\W-ZX6UA(&YE;2!V
M;VQT(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871BX7II<V)A
M;B!N96T@=F]L="!M96=T86SA;&AA=/,N`$$@<&%R=&YE<B!A9&%T86ET('-I
M:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI:^EH97HN`$O\;/9NX6QL
M\R!01U`@86SA[7+A<VD@8FQO:VL@<WK\:W/I9V5S(&$@9&EG:73A;&ES86X@
M86SA[7)T(/QZ96YE="!H:71E;&5S<^EGZ6YE:R!E;&QE;O5R>NESZ6AE>BX`
M02!K]G)L97;I;&QI<W1A(&%Z;VYO<^UT\W-ZX6UA(&YE;2!V;VQT(&UE9V%D
M=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871BX7II<V)A;B!N96T@=F]L
M="!M96=T86SA;&AA=/,N`$$@:_9R;&5VZ6QL:7-T82!N96T@=F]L="!M96=A
M9'9A+@!!('1I=&MO<^UTX7-I('-Z;VQGX6QT873A<V]K:&]Z(&)I>G1O;G/A
M9V]S("AT:71K;W/M=&]T="D@=V5B(&MA<&-S;VQA="!K96QL+@!!*'HI("5S
M(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@96=Y("5S(&)EX6QL
M[73A<VYA:RX`02AZ*2`E<R#A;&QO;>%N>6)A;B!S>F5R97!E;&YI92!K96QL
M96YE('9A;&%M:6QY96X@)7,@8F7A;&SM=.%S*&]K*6YA:RX`02!FX6IL(&YE
M;2!MX7-O;&AA=/,@]FYM86?A<F$N`$$@9N%J;&)A;B!N96T@=F]L="!A9&%T
M+@!!>B#\>F5N970@9F5J;.EC<V]R86D@82!K]G9E=&ME>O5K+@!!('1E;&IE
M<R!KZ7!E<FYY]7,@_'IE;6WS9"!P<F]B;.EMX6MA="!O:V]Z:&%T(&%Z($EN
M=&5R;F5T($5X<&QO<F5R(&AA<WINX6QA=&$@97-E=.EN+"!M97)T(&5B8F5N
M(&]L>6%N('!R;V=R86UH:6+A:R!V86YN86LL(&%M:6ME="!N96T@='5D='5N
M:R!M96=K97+\;&YI+B!!(&OI<&5R;GGU:F4@;VQV87-H871A=&QA;F[A(';A
M;&AA="P@8FEZ;VYY;W,@961I=&]R(&9U;FMC:?-K(&AIX6YY;WIH871N86L@
MZ7,O=F%G>2!VX7)A=&QA;G5L(&QE9F%G>6AA="!A(&+V;F?I<WKU<')O9W)A
M;2X@5VEN9&]W<R`Y>"!H87-Z;N%L871A(&5S973I;B!N86=Y;VX@=F%L\W-Z
M[6[[+"!H;V=Y("='96YE<F%L('!R;W1E8W1I;VX@9F%U;'0G(&AI8F$@;6EA
M='0@^FIR82!K96QL(&EN9.UT86YI82!M86ID(&$@9^EPZ70N7&Y<;D9I9WEE
M;&UE>G1E='3\:R$@2V%T=&EN='-O;B!A>B!/2R!G;VUB<F$L(&AA(&WI9VES
M(&UE9R!K[7;A;FIA(&OM<^ER96QN:2!A('1E;&IE<R!KZ7!E<FYY]7,@_'IE
M;6WS9&]T+@!4:&4@:&5L<"!F:6QE("5S(&1I9&XG="!S=&%R="!W:71H(#P_
M>&UL`$$@(B5S(B!A>F]N;W/M=/-T(&MI=/9R]FQT_&LN`$-S86L@8F%L(&]L
M9&%L;VX@;&5G>65N(&ME<F5T`$$@1VYU4$<@<')O9W)A;2!H96QYZ70@;65G
M(&ME;&P@861N:2!A($-R>7!T7W!G<#HZ(&]S>G3A;'D@:&%S>F[A;&%TX6AO
M>BX`02!L97;I;"P@;65L>65T("5S(&YA<&KA;B!K_&QD]G1T("5S(&/M;7IE
M='1N96L@(B5S(B!TX7)G>6)A;BP@82!C[6UZ971T('-ZX6WM=/-GZ7#I;B!M
M96=J96QE;G0N($%R<F$@;FEN8W,@9V%R86YC:6$L(&AO9WD@96P@:7,@;VQV
M87-TX6L@:6QL+B!H;V=Y(&UE9^ER=&5T=.EK+@!-:2!L96=Y96X@82!L97;I
M;.UR\R!A8FQA:VAO>B!M=71A=/,@;&EN:R!E;&YE=F5ZZ7-E`$%Z(&]P96YS
M<VP@;6]D=6P@<WK\:W/I9V5S(&$@2&]R9&5?0W)Y<'1?<VUI;64Z.B!O<WIT
MX6QY(&AA<WINX6QA=.%H;WHN`$$@(B5S(B!S>F5MZ6QY97,@8F7A;&SM=.%S
M(&YE;2!M96YT:&5T]2!E;"P@;65R="!MZ7)E=&4@;65G:&%L861J82!A(&UE
M9V5N9V5D971T(&UA>&EM=6UO=`!.96T@=&%LX6QH873S(&%Z(&$@<')O9W)A
M;2!A('-Z97)V97)E;BP@86UI('-Z_&MSZ6=E<R!E;FYE:R!A>B!A9&%T=.UP
M=7-N86L@*"5S*2!A(&UE9VIE;&5N[73I<^EH97HN`$IO8F(@Z7,@8F%L(&]L
M9&%L;VX@;&5G>65N(&ME<F5T`$-S86L@:F]B8B!O;&1A;&]N(&QE9WEE;B!K
M97)E=`!!*'HI("(E<R(@<WIE<G9E<G0@=/9R]FQT_&LN`$$H>BD@(B5S(B!S
M>F5R=F5R="!E;&UE;G1E='3\:RX`)7,@8F5J96QE;G1K97KI<VD@:^ER96QM
MZ70@=/9R]FQT_&LN`$$@;65G861O='0@<V]R(&YE;2!LZ71E>FEK+@!!*'HI
M("(E<R(@:61E:6=L96YE<R!FX6IL(&YE;2!LZ71E>FEK+@!!;'5L(.ES(&;V
M;/QL(&QE9WEE;B!K97)E=`!#<V%K(&9E;G0@;&5G>65N(&ME<F5T`$$@9F5L
M=/9L=/9T="!A9&%T;VL@87H@96SU>O4@;.EPZ7,@\W1A(&5L=F5S>G1E:RX`
M02!F96QT]FQT]G1T(&;A:FQT(&YE;2!S:6ME<OQL="!E;&UE;G1E;FDN`$$@
M=V5A=&AE<BYC;VT@8FQO:VL@;F5M(&AA<WINX6QH873S+@!!(&UE9VIE;&5N
MZ7-I('-T[6QU<R`H=&AE;65S*2!A;&OV;GEV=.%R("<E<R<@;F5M('1A;.%L
M:&%T\RX`3FEN8W-E;B!VX6QA<WIT:&%T\R!O<&-I\RX`3FEN8W,@82!L97;I
M;"!B96QS96KI8F5N(&UE9VIE;&5N[71H973U(&UE;&SI:VQE="X`5/IL('-O
M:R!K87)A:W1E<B!V86X@96)B96X@82!M97KU8F5N+B#6;B`E<R!K87)A:W1E
M<G0@861O='0@;65G.R!A(&UA>&EMX6QI<V%N(&UE9V%D:&%T\R!P961I9R!K
M979E<V5B8BP@;6EN="`E<RX`5&AE<F4@9&]E<VXG="!Y970@97AI<W0@82!H
M96QP(&9I;&4@9F]R("5S+@`G)7,G(&9E;&AA<WINX6SS;F%K(&$@<F5N9'-Z
M97)H97H@863A<V%K;W(@:&EB82!T]G)TZ6YT+B`E<RX`)R5S)R!F96QH87-Z
M;N%L\VYA:R!A(')E;F1S>F5R:&5Z(&%DX7-A:V]R(&AI8F$@=/9R=.EN="X@
M)7,`)R5S)R!F96QH87-Z;N%L\R!A9&%T86EN86L@=/9R;.ES92!S;W+A;B!H
M:6)A(&SI<&5T="!F96PZ(``G)7,G(')E;F1S>F5R8O5L('9A;/,@=/9R;.ES
M96MO<B!H:6)A(&SI<&5T="!F96PZ(``G)7,G(&WS9&]S[73A<V$@<V]RX6X@
M:&EB82!LZ7!E='0@9F5L.B`E<P!!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT
M(&$@<WIE<G9E<G)E(&9E;'3V;'1E;FDN("5S(&YE;2!T]FQT]63V='0@9F5L
M+@!!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@<WIE<G9E<G)E(&9E;'3V
M;'1E;FDN("5S(&YA9WEO8F(L(&UI;G0@82!M87AI;>%L:7-A;B!M96=E;F=E
M9&5T="!MZ7)E="`H)60@8N%J="DN`$%Z(.%L;&]MX6YY="!N96T@<VEK97+\
M;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@02AZ*2`E<R!FX6IL;F%K(&-S
M86L@96=Y('+I<WIE('3V;'3U9/9T="!F]FPN`$$@;&5VZ6P@92!RZ7-ZZ6YE
M:R!M96=J96QE;NUTZ7-E:V]R(&AI8F$@=/9R=.EN=`!!('!A<G1N97(@861A
M=&]K(&EM<&]R=.%LX7-A('-O<N%N(&AI8F$@=/9R=.EN="X`07H@:4-A;&5N
M9&%R(&%D871O:R!I;7!O<G3A;.%S82!S;W+A;B!H:6)A('3V<G3I;G0N`$AI
M8N%S(&$@;65G861O='0@:V]N9FEG=7+A8VGS+B!,96AE="P@:&]G>2!N96T@
M=/9L=/9T="!K:2!E9WD@<WK\:W/I9V5S(&UE>O5T+@!4:&5R92!W87,@86X@
M97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L
M871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M
M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+@!!('!A<G1N97)J96=Y>NEK
M:V5L(&MA<&-S;VQA=&]S(&9E;&%D870@=NEG<F5H86ITX7-A('-O<N%N(&AI
M8F$@;.EP971T(&9E;"X@2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BX`2&EB
M82!T]G)TZ6YT(&$@<&%R=&YE<B!A9&%T86EN86L@9G)I<W/M=.ES92!S;W+A
M;BX@2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BX`02!K]G)L97;I;&QI<W1A
M(&%D871A:6YA:R!F<FES<^UTZ7-E('-O<N%N(&AI8F$@=/9R=.EN="X@2^ER
M96T@<'+S8N%L:F$@;65G(&OI<_5B8BX`17H@87H@24U!4"!S>F5R=F5R(&YE
M;2!TX6UO9V%T:F$@82!M87!PX6MH;WH@=F%L\R!H;WIZX6;I<NES(&UE9V]S
M>G3A<^%T+@!%>B!N96T@=/MN:6L@<WIA8N%L>6]S(')A<B#A;&QO;>%N>6YA
M:RX`17H@;F5M('3[;FEK('-Z86+A;'EO<R!Z:7`@X6QL;VWA;GEN86LN`$5Z
M(&YE;2!T^VYI:R#I<G;I;GEE<R!KX7)T>6%S>N%M;F%K+@!%>B!A(&UE9VAA
M:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y($A45%`M:V%P8W-O;&%T;VX@4TU3
M+70@:_QL9&K\;FL@82!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI('-Z;VQGX6QT873S;B#A="X`17H@82!M96=H86IT\R!L96AE=/5VZ2!T
M97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&%Z
M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI('-Z;VQGX6QT873S
M;B#A="X`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!33510
M+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(%9O9&%F;VYE('-ZX6UO:W)A
M(&$@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!S>F]L9^%L
M=&%T\VX@X70N($$@<WIO;&?A;'1A=.%S(&EGZ6YY8F5VZ71E;.EH97H@5F]D
M869O;F4@271A;'D@96UA:6P@8^UM('-Z_&MSZ6=E<RX`17H@82!M97KU(&YE
M;2!M87)A9&AA="#\<F5S+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S
M>N%M;VL@X6QL:&%T;F%K+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S
M>N%M;VL@Z7,@:V5T=/5S<&]N="!L96AE="X`16)B96X@82!M97KU8F5N(&-S
M86L@;VMTX6QI<R!S>N%M;VL@X6QL:&%T;F%K+@!%>B!A(&UE>O4@8W-A:R!V
M97-S>O5V96P@=F%G>2!S>O-K]GIZ96P@96QVX6QA<WIT;W1T(&5GZ7-Z('-Z
MX6UO:V%T('1A<G1A;&UA>FAA=`!%>B!A>B#I<G3I:R!C<V%K('-ZX6T@;&5H
M970N`$5B8F5N(&$@;65Z]6)E;B!H97AA9&5C:6WA;&ES(%)'0B!S>NUN:_-D
M(.%L;&AA="P@<&PN("<C,3(S-&%F)RX`17H@82!F:6QE('1A<G1A;&UA>GIA
M(&$@4&%S<W=D(&UO9'5L('-Z:W)I<'1J96EN96L@:V]N9FEG=7+A8VGS<VEN
M9F]R;>%C:?-I="X`17IE;B!A9&%T;VMK86P@:V%P8W-O;&%T;W,@9F5L861A
M=&]K870@82!S>F5R=F5R(&WA<B!E;';I9V5Z=&4N`$5Z("5S`$5Z(&5G>2!+
M;VQA8B!'<F]U<'=A<F4@;V)J96MT=6TN($%Z(&EL>65N(&]B:F5K='5M(&UE
M9VIE;&5N[73I<^EH97H@;VQY86X@96UA:6P@:VQI96YS<')O9W)A;2!S>OQK
M<^EG97,L(&%M96QY(&OI<&5S(&$@2V]L86(@1W)O=7!W87)E(&9O<FWA='5M
M(&ME>F5LZ7/I<F4N($EL>65N(&5M86EL(&ML:65N<V5K(&QI<W3A:F$@;.%T
M:&%T\R!I='0Z("5S`$5Z(&$@4&%S<W=D(&UO9'5L(&;U(&MO;F9I9W5RX6-I
M\W,@X6QL;VWA;GEA+B!%>B!T87)T86QM87IZ82!A>B#I;.ERZ7-I(/IT=F]N
M86QA:V%T+.ES(&%Z(&]P8VGS:V%T(&$@4&%S<W=D(&UO9'5L(/9S<WIE<R!S
M>FMR:7!T:NEH97HN`$5Z="!A(&QE=F5L970@;>%S(&MA<F%K=&5R:^ES>FQE
M='1E;"`H)7,I(.UR=.%K+"!M:6YT(&%M:70@UFX@:&%S>F[A;"X`17H@82!S
M>N%M(&YE;2!L96AE="!E9WENZ6P@:VES96)B+@!4:&ES('-C<FEP="!M=7-T
M(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F4N`$5Z(&$@<WIE<G9E<B!N
M96T@:^EP97,@:VEB;VYT86YI(&$@>FEP(&EL;"X@9WII<"#A;&QO;>%N>6]K
M870N`$5Z(&$@<F5N9'-Z97(@:F5L96YL96<@:6YA:W1I=N%L=F$@=F%N+@!%
M>B!A>B#I<G3I:R!C<V%K('-ZX6T@;&5H970N`$5Z="!A>B!A8FQA:R!C<V%K
M(&%Z($]P8VGS:R!A8FQA:V+S;"!H[79H873S`%9I;&SA;6SA<P!(:6)A8F5J
M96QE;G3I<RUK97IE;.ES`$ED]0!-=6YK86ED]2UN>6EL=N%N=&%R=.%S`$ED
M]2!F;W)MX71U;0!)9/4@=N%L87-Z=.%S`$ME;&5T+51I;6]R`%1I='5L=7,`
M0^UM("AT;V]L=&EP*0!#[6UZ971T`$AA('3V8F(@96QE;65T(&ES(&MI(&%K
M87(@:F5L]FQN:2P@=&%R='-A(&QE;GEO;79A(&$@0V]N=')O;"`H4$,I('9A
M9WD@82!#;VUM86YD("A-86,I(&)I;&QE;G1Y^W0@82!K871T:6YTX7,@:_9Z
M8F5N+@!-80!(5$U,(&9O<G+A<V[I>F5T(&MI+V)E`%1O9V\`5&]K96QA=0!(
M;VQN87``5&]N9V$`9O9L_&P`3&5G9F5L<_4@9G)A;64@*%]T;W`I`%1R86YS
M;&%T960`1F]R9.UTX7-O:P!4<FEN:61A9"#I<R!4;V)A9V\`26=A>B!V86=Y
M(&AA;6ES`$ME`%1U;NEZ:6$`5/9R]FMO<G-ZX6<`=/9R]FL@*$E33RTX.#4Y
M+3DI`%3\<FMM96YI<WITX6X`5'5R:W,M(.ES($-A:6-O<RUS>FEG971E:P!4
M=79A;'4`S7)J82!B92P@;6ET(';A;&%S>G1O='0Z(`!55B!I;F1E>#H@`%52
M3`!54DPL(&UE;'EE;B!E9WD@<')O9W)A;2!E;&9O9V%D:F$@82!S>F]L9^%L
M=&%T\R#A;'1A;"!K_&QD]G1T(&O\;&3V='0@:^EZ8F5S[73I<VD@:F5L96YT
MZ7-T`%523#H`56=A;F1A`%5K<F%J;F$`3F5M('-I:V5R_&QT(&$@5D93(&%L
M:_9N>73A<F)A(&)E;.EP;FDN`$$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1S
MX6<@:6?I;GELZ7-E:V]R(&YE;2!S:6ME<OQL="!A>B!A9&%T;VL@96QTX7)O
M;.%S82X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(B!61E,@9N%J;"!E;.ERZ7-I
M(&IO9V]S=6QT<^%G86ET(&UE9W;A;'1O>G1A=&YI+@!.96T@<VEK97+\;'0@
M82AZ*2`E<R\E<R!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET(&UE
M9W;A;'1O>G1A=&YI+@!.96T@<VEK97+\;'0@82AZ*2`E<R!A;&OV;GEV=.%R
M8F$@8F5LZ7!N:2X`07H@4U%,('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`07H@
M4U-,(&MA<&-S;VQA="!N96T@Z7#M=&AE=/4@9F5L+@!!(%9&4R!FX6IL(&YE
M;2!MX7-O;&AA=/,@X70N`$YE;2!S:6ME<OQL="!A*'HI("(E<R(@5D93(&%L
M:_9N>79TX7)T(&SI=')E:&]Z;FDN`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI
M(&$@5D93(&%L:_9N>79TX7)T+@!.96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A
M(%9&4R!FX6IL="X`3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@_')E<R!61E,@
M9N%J;'0N`$$@=/9M]G+M=&5T="#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&MI
M8F]N=&%N:2X`(B5S(B!N96T@=/9R]FQH973U+"!A>B!A;&OV;GEV=.%R(&YE
M;2#\<F5S+@`E<R!N96T@=/9R]FQH973U+"!A>B!A;&OV;GEV=.%R(&YE;2#\
M<F5S+@`G)7,G(&YE;2!T]G+V;&AE=/4Z("5S`$$@5D93(&%L:_9N>79TX7(@
M;F5M('3V<O9L:&5T]2!R96MU<GKM=F%N+@!!(%9&4R!A;&OV;GEV=.%R(&YE
M;2!T]G+V;&AE=/4N`$$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]3H@
M)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@=/9R]FQH973U+@!!(%9&4R!F
MX6IL(&YE;2!T]G+V;&AE=/4N`$YE;2!VZ6=E>FAE=/,@<F5K=7)Z[78@=/9R
M;.ES(&$@5D93+6)E;CH@)7,N`$YE;2!H873A<F]Z:&%T\R!M96<@82!J96QE
M;FQE9R#I<G;I;GEE<R!A;&OV;GETX7(N`$$@=&%N^G/M=';A;GD@<NES>FQE
M=&5S(&%D871A:2!N96T@:&%TX7)O>FAA=/-K(&UE9P!.96T@<VEK97+\;'0@
M8F5O;'9A<VYI("5S(&1E9FEN[6-I\VKA="X`02!61E,@9N%J;"!N96T@:&5L
M>65Z:&5T\R#A="X`02AZ*2`B)7,B(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M
M96<N`$$@5D93(&;A:FP@;F5M(&YY:71H873S(&UE9R#M<N%S:2!CZ6QL86PN
M`$$@5D93(&;A:FP@;F5M(&YY:71H873S(&UE9R`N`$$@=/9M]G+M=&5T="#A
M;&QO;>%N>2!N96T@;GEI=&AA=/,@;65G+@!%>B!A(&;A:FP@;F5M(&]L=F%S
M:&%T\SH@`$$@=F9S<F]O="!A;&OV;GEV=.%R(&YE;2!O;'9A<VAA=/,N`"5S
M(&YE;2!N979E>FAE=/4@X70@)7,@;NEV<F4Z(&WA<B!LZ71E>FEK(&EL>65N
M(&YE=OL@;6%P<&$`02!61E,@86QK]FYY=G3A<B!N96T@;F5V97IH973U(.%T
M+@!!(%9&4R!A;&OV;GEV=.%R(&YE;2!N979E>FAE=/4@X70Z("5S+@!!*'HI
M("(E<R(@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`02AZ*2`E<R\E<R!6
M1E,@9N%J;"!N96T@;F5V97IH973U(.%T+@!!(%9&4R!FX6IL(&YE;2!N979E
M>FAE=/4@X70N`$%Z("=M:VES;V9S)R!P<F]G<F%M(&YE;2!F=71T871H873S
M+@!.96T@<VEK97+\;'0@;&5F;W)D[71A;FD@97IT(&$@5V]R9"!D;VMU;65N
M='5M;W0`02AZ*2`B)7,B(%9&4R!FX6IL(&YE;2#M<FAA=/,N`$$@5D93(&;A
M:FP@;F5M(.UR:&%T\R`H82!C;W!Y*"D@<VEK97)T96QE;B!V;VQT*2X`02!6
M1E,@9N%J;"!A9&%T86D@;F5M(.UR:&%T\VL@:VDN`&%LX6CZ>F]T=`!-Z6=S
M92!M96YT<_QK(&5L`%9I<W-Z879O;FIA(&%Z('5T;VQS\R!VX6QT;WIT873A
M<W0`02!K87!C<V]L870@9F5L=NET96SI="!K]G9E=/5E;B!VX7)A=&QA;B!V
MX6QA<WH@Z7)K97IE='0@82!S>F5R=F5R=/5L.B``5N%R871L86X@=N%L87-Z
M(.ER:V5Z971T(&$@<WIE<G9E<G3U;"!E<G)E.B``0F5S;W)O;&%T;&%N`%5N
M:6-O9&4@*%541BTX*0!%9WEE<_QL="!!<F%B($5M[7)SZ6=E:P!%9WEE<_QL
M="!+:7+A;'ESX6<`16=Y97/\;'0@P6QL86UO:P!%9WEE<_QL="#!;&QA;6]K
M+"!K:7-E8F(@:_QL<_4@<WII9V5T96L`96=Y<^EG`$ES;65R971L96X`27-M
M97)E=&QE;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!)<VUE<F5T;&5N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@8V]M;6%N
M9#H@)7,`02!M96=A9&]T="!H96QY(&ES;65R971L96XN`$ES;65R971L96X@
M9F5L:&%S>F[A;/-I(&[I=B!V86=Y(&IE;'-Z\RX`5.%V;VSM='-U:R!E;"!I
M;FYE;B!A(&QI;FME=`!.:6YC<R!E;&YE=F5Z=F4`0FEZ=&]N<^%G:2!O:V]K
M8O-L(&$@9F5L:&%S>F[A;/-I('!R;V=R86UO:R!N96T@:&%S>F[A;&AA=&KA
M:R!A($MI=N%GX7,O3>%S;VSA<R]"96EL;&5S>G3I<R!M\V1S>F5R="X@2V%T
M=&EN='-O;B!A>B!/2R!G;VUB<F$L(&AA(&$@;6]Z:6QL82YO<F<@=V5B;VQD
M86QO;B!E;"!K[7;A;FIA(&]L=F%S;FD@82!T96-H;FEK86D@;&7M<N%S="!M
M96QY(&UE9V%D:F$L(&AO9WEA;B!L96AE="!E>G0@;>EG:7,@96YG963I;'EE
M>FYI+@!!('-Z[6X@=FES<WIAX6QL[73A<V$`3F5M('3A;6]G871O='0@97AT
M96YZ:?,`56YT<F%N<VQA=&5D`$WS9&]S[73A<P`E<R!A9&%T86EN86L@;?-D
M;W/M=.%S80!!(&9E;&AA<WINX6SS(&%D871A:6YA:R!M\V1O<^UTX7-A`"<E
M<R<@;?-D;W/M=.%S82!M96=T]G)TZ6YT+@!5<&1A=&EN9R`E<R!H96QP(&9I
M;&4@9F]R("5S+@!!>B!U<&=R861E('!R;V=R86UO="!T]G+V;'3\:RX`1F5L
M=/9L=.ES`$%Z(/9S<WIE<R!A;&MA;&UA>N%S(&MO;F9I9W5RX6-I\VKA="!F
M96QT]FQT]G1T_&L@82!S>F5R=F5R<F4N`&QA=&EN(&YA9WEB973[:P!N86=Y
M8F5T^W,@<O-M86D@<WKA;6]K`%5R=6=U87D`57-A9V4Z`$AA<WINX6QJ=6L@
M82!J96QE;FQE9VET.B`E<P!(87-Z;N%L:G5N:R!34TPM=`!!:VMO<B!H87-Z
M;N%L:G5K+"!H82!A>B!)35-0('-Z97)V97)E;B!MX7,@82!B96IE;&5N=&ME
M>NES:2!N97;\;FLO:F5L<WIA=G5N:RX`)7,@9F5L:&%S>F[A;/,@;F5M(&IO
M9V]S=6QT("5S+7)E+@!&96QH87-Z;N%L\VL@861M:6YI<WIT<N%LX7-A`$9E
M;&AA<WINX6SS:2!B9>%L;.UTX7-O:P!"96IE;&5N=&ME>NES(&IO9V]S=6QT
M<^%G(&EGZ6YY;.ES90!%>F5N(&$@<F5N9'-Z97)E;B!N:6YC<R!E;F=E9.EL
M>65Z=F4@87H@^FH@9F5L:&%S>F[A;/-K(&)E:F5L96YT:V5ZZ7-I(&IO9V]S
M=6QT<^%GX6YA:R!I9^EN>6SI<V4N`$YI;F-S(&EL>65N(&9E;&AA<WINX6SS
M`$YI;F-S(&EL>65N(&9E;&AA<WINX6SS`$9E;&AA<WINX6SS:2!J;V=O<W5L
M='/A9V]K`$9E;&AA<WINX6SS:2!NZ78`02`G)7,G(&9E;&AA<WINX6SS:2!N
MZ78@;>%R(&SI=&5Z:6LN`$9E;&AA<WIN\VSS:2!NZ78Z`$9E;&AA<WINX6SS
M:2!NZ78Z(`!&96QH87-Z;N%L\VL`02!R96YD<WIE<B!F96QH87-Z;N%L\VDZ
M`-QZ8F5G:7-Z=.%N`$$@5D93(&%L:_9N>79TX7(@;F5M(&SI=&5Z:6LN`%-Z
M86)A9'/A9R!A;&%T=&D@875T;VUA=&EK=7,@96UA:6PM=N%L87-Z`$$@:_9V
M971K97KU(&AE;'EE:V5T('1A;.%L='5K.B``R7)VZ6YY97-SZ6<`07H@Z7)T
MZ6ME:V5T('!E<F-B96X@861J=6L@;65G+"!M;W-T86YT\VP@<WKA;>UT=F$N
M`$$@Z7)TZ6L@;F%G>6]B8BP@;6EN="!A(&QE9VYA9WEO8F(@;65G96YG961E
M='0@:&]S<WKZ<^%G.B`E<RX`R7)TZ6ME:P!6X6QA<WIT:&%T\R#I<G3I:V5K
M`%9A;G5A='4`=N%L=&]Z\P!696YE>G5E;&$`02!H:71E;&5S[73I<R!N96T@
M<VEK97+\;'0@+2!L96AE="P@:&]G>2!A(&QE=F5L970@=F%L86MI(&UE9W;A
M;'1O>G1A='1A+@!697)Z:?,`5F5R>FGS:_9V973I<P!&_&=G+B!E;&AE;'EE
M>NES`$;\9V?U;&5G97,@8F5L<_4@;6%R9_,`9OQG9_5L96=E<SH`;F%G>6]N
M(&UA9V%S`%9I971N86T`=FEE=&YA;6D@*%9)4T-)22D`)7,@;65G=&5K:6YT
MZ7-E`$O\;'/U('=E8F]L9&%L(&UE9VIE;&5N[73I<V4`2F5L96[M='/\:R!M
M96<L(&UI;G0@)7,`0G)I="!6:7)G:6XM<WII9V5T96L`06UE<FEK86D@5FER
M9VEN+7-Z:6=E=&5K`$SA=/-TX79O;'/A9P!,X73S=.%V;VQSX6<Z(`!6;V1A
M9F]N92!)=&%L>2!S>F]L9^%L=&%TX7,@4TU44"UN(&ME<F5S>G3\;`!&24=9
M14Q-15I4153)4P!&24=914Q-15I4153)4R$@2\E:6D5,(%3!5D],S51302!%
M3"!!(%-#4DE05$54("5S+5+53"X`5V%L;&ES(.ES($9U='5N80!&:6=Y96QM
M97IT973I<P!787)N:6YG.B``4WIE`$ED]6KA<N%S(&5L]7)E:F5L>NES`$%Z
M(&ED]6KA<N%S:2!A9&%T;VL@9F]R<N%S80!796(`5V5B:&5L>65K`&AE=&5N
M=&4`W&1V]GKV;&K\:P#<9';V>O9L:OQK.B`E<P#<9';V>O9L:OQK+"`E<P!N
M>75G870M975R\W!A:2`H25-/+3@X-3DM,2D`;GEU9V%T+65U<O-P86D@*$E3
M3RTX.#4Y+3$U*0!.>75G870M4WIA:&%R80!-:6QY96X@86QK86QM87KA<W0@
M;75T87-S;VX@)7,@82!B96IE;&5N=&ME>NES('5TX6X_`$UI(&%Z(&5L=N%L
M87-Z=/,@:V%R86MT97(_`$UI(&%Z(&EDZ7IE=&MA<F%K=&5R/P!-96QY:6L@
M8VEK;'5S`$UE;'EI:R!M;V1U;&]K870@86MT:7;A;&IU:R!A(%)I8V@@5&5X
M="!E9&ET;W)B86X_`%-ZZ6QE<W/I9P!3>NEL97-SZ6<@0U-3(&5G>7/I9V)E
M;@!!("5S(&UE;OP@<WKI;&5S<^EG92!A(&)A;"!O;&1A;&]N("AA(&OV=F5T
M:V5Z]2!B96IE;&5N=&ME>NES="!K]G9E=/5E;B!L97-Z(.ER=NEN>65S*0!!
M('3A8FSA>F%T('-ZZ6QE<W/I9V4`02!S>NEL97-SZ6<@;>ER=.EK96=Y<^EG
M90!3>NEL97-SZ6<Z`%=I:VD`4WKI;`!3>NEL(&$@<F5G9V5L:2#S<N%K8F%N
M`%-ZZ6QS96)E<W/I9R!C<V]M\V)A;@!3>NEL.@!3>NEL.B``0O9L8W-E<W/I
M9P!+[7;A;G/A9VQI<W3A:P!-=6YK80!-=6YK86AE;'EI(&/M;0!-=6YK86AE
M;'EI('1E;&5F;VX`5W)I=&EN9R!U<&1A=&5D(&AE;'`@9FEL92!T;R`E<RX`
M3&EN=7@@9F]R<N%S:_-D(&ME<F5S>G)E9F5R96YC:6$`6#4P.78S(&%L87!V
M973U(&MO<FSA=&]ZX7-O:P!8-3`Y=C,@:VET97)J97-Z=&5T="!K=6QC<VAA
M<WINX6QA=`!8-3`Y=C,@='5L86ID;VYO<R!A;'1E<FYA=.UV(&UE9VYE=F5Z
MZ7-E`%@U,#EV,R!T=6QA:F1O;F]S(&MU;&-S87IO;F]S[73S`%@U,#EV,R!K
M:71E<FIE<WITZ7-E:P!960!965E9`%EA:&]O(2!TZ7)KZ7``Z79E;G1E`$IE
M;65N`$EG96X`26=E;BP@8F5L96=Y97IE;2X`36]S="!(5$U,(%1%6%0@;?-D
M8F%N('9A;BX@2&%S>F[A;&IA(&$@6SP^72!G;VUB;W0L(&AA('9I<W-Z82!A
M:V%R(';A;'1A;FD@82!S>F]KX7-O<R!G<F%F:6MU<R`H5UE325=91RD@;65G
M:F5L96[M=.ES<F4N`$%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73A<V$@;F5M
M('3V<G3I;G0@;65G+@!!('1E;&IE<R!NZ79B96X@;F5M('-Z97)E<&5L:&5T
M(&$@)UPG(&MA<F%K=&5R+@!.96T@='5D;V0@;65G=N%L=&]Z=&%T;FD@)7,@
M:F5L<WIA=N%T(0!.96T@861O='0@;65G(.ER=NEN>65S(&5M86EL(&/M;65T
M+@!.96T@861T82!M96<@82!M96=F96QE;'1E=.ES="!A>B!I;7!O<G3A;'0@
M9N%J;"#I<R!A*'HI("5S(&UE>O5I(&OV>O9T="X`4VEK97)E<V5N(&MI:F5L
M96YT:V5Z971T+@!%9WD@;6]B:6QT96QE9F]N<WKA;6]T(&ME;&P@;65G861N
M:6$L(&-S86L@82!S>N%M:F5G>65K970L(&5S971L96<@96=Y("<K)R!K87)A
M:W1E<G)E;"!K97ID=F4L(&AA(&YE;7IE=&OV>FD@=.%R8W/A>N%S:2!M\V1O
M="!K[7;A;B!H87-Z;N%L;FDN`$5L9F]G861H873S(.ER=.EK970@:V5L;"!M
M96=A9&YI82X`02!$871A5')E92!A;')E;F1S>F5R="!B92!K96QL(.%L;.UT
M86YI(&$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6=O:R!I9^EN>6SI<^EH
M97HN`$$@5D93(&%L<F5N9'-Z97(@;FEN8W,@8F7A;&SM='9A+@!%;/5B8B!L
M92!K96QL(.UR;FEA+"!H;V=Y(&UI;'EE;B!P<F]B;.EMX70@=&%P87-Z=&%L
M="P@;6EE;/5T="!E;&O\;&1I(&$@:&EB86IE;&5N=.ES="X`365G(&ME;&P@
M861N:2!E9WD@55),+70L(&%H;W9A(&5Z(&$@;&EN:R!M=71A=`!-96<@:V5L
M;"!A9&YO9"!A>B#Z:B!J96QS>O-T`$UE9R!K96QL(&%D;F]D(&%Z(&5R961E
M=&D@:F5L<WKS=`!+:2!K96QL(';A;&%S>G1A;FD@96=Y('3V<FQE;F3U('-Z
M97)V97)T+@!-96<@:V5L;"!A9&YI82P@:&]G>2!M96QY:6L@9F5L:&%S>F[A
M;/,@861A=&%I="!K[7;A;FIA('3V<O9L;FDN`$UE9R!K96QL(&%D;FEA(&%Z
M(&5L=.%V;VSM=&%N9/,@9F5L:&%S>F[A;/-I(&YE=F5T+@!-96<@:V5L;"!A
M9&YI82!A(&AO>GKA861A;F3S(&9E;&AA<WINX6SS(&YE=NET+@!-96<@:V5L
M;"!A9&YI82P@:&]G>2!M96QY:6L@9F5L:&%S>F[A;/,@861A=&%I="!K[7;A
M;FIA(.%T[7)N:2X`365G(&ME;&P@861N:6$@96=Y('!A<F%N8W-O="X`365G
M(&ME;&P@861N:6$@87H@^FH@:V%T96?S<FEA(&YE=NET+@!!>B#Z:B!J96QS
M>F%V861A="!KZ71S>F5R(&ME;&P@;65G861N;V0`07H@UFX@)7,@:V%P8W-O
M;&%T82!I9/5T^FQLZ7#I<R!M:6%T="!M96=S>F%K861T+B!+Z7)E;2!J96QE
M;G1K97IZ96X@8F4@^FIR82X`07H@UFX@96UA:6P@8^UM90!!>B#6;B!F96QA
M9/-I("A&<F]M.BD@8^UM93H`4WIE;>EL>65S(&EN9F]R;>%C:?,`07H@UFX@
M)7,@:V%P8W-O;&%TX6YA:R!K97ID971E(/-T82!M96=VX6QT;WIO='0@87H@
M:6YT97)N970@8^UM92X@0FEZ=&]N<^%GX6YA:R#I<F1E:^EB96X@:7-MZ70@
M8F4@:V5L;"!J96QE;G1K97IN:64N`$%Z(-9N(&YE=F4`07H@UFX@9F5L:&%S
M>F[A;/-A>F]N;W/M=/,@86QR96YD<WIE<F4@;F5M('1E<WII(&QE:&5T]7;I
M(&%Z(/IJ(&9E;&AA<WINX6SS:R!LZ71R96AO>N%SX70L('9A9WD@=F%L86UI
M(&]K8O-L(&QE=&EL=&]T=.%K(&5Z="!A(&QE:&5T]7/I9V5T+@!!>B#6;B!F
M96QH87-Z;N%L\V%Z;VYO<^UT\R!A;')E;F1S>F5R92!N96T@=&5S>FD@;&5H
M973U=ND@82!F96QH87-Z;N%L\VL@;&ES=.%ZX7/A="P@=F%G>2!V86QA;6D@
M;VMB\VP@;&5T:6QT;W1TX6L@97IT(&$@;&5H973U<^EG970N`$%Z(-9N(&+V
M;F?I<WKU<')O9W)A;6IA(&UE9W;A;'1O>F]T="!A>B#6;B`E<R!M=6YK86MA
M<&-S;VQA=.%N86L@:V5Z9&5T92#S=&$N($)I>G1O;G/A9V$@Z7)D96OI8F5N
M(&ES;>ET(&)E(&ME;&P@:F5L96YT:V5Z;FEE+@!!>B#6;B!B]FYGZ7-Z]7!R
M;V=R86UJ82!N96T@=.%M;V=A=&IA(&5Z="!A(&QE:&5T]7/I9V5T+@!!>B#6
M;B!B]FYGZ7-Z]7!R;V=R86UJ82!N96T@=.%M;V=A=&IA(&5Z="!A(&YY;VUT
M873A<VD@;W!C:?-T+B!0<O-BX6QJ;VX@82!#=')L+5`@*'9A9WD@0V]M;6%N
M9"U0*2!L96YY;VWA<^%V86P@;GEO;71A=&YI+@!!(&IE;&5N;&5G(.ER=NEN
M>65S(&ED]7KS;F$Z`$%Z(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z
M;VYO<^UT\VIA.@!!>B#6;B!T96QJ97,@;F5V93H`66]U<B!G971T97AT('9E
M<G-I;VX@:7,@=&]O(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T
M:79E;'DN"DYO="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A8W1E9"X`07H@
MUFX@)7,M<F4@:&%S>F[A;'0@^FH@:F5L<WIA=F$Z("5S`$$@:F5L<WIA=F%D
M('3Z;"!H;W-S>OHA($$@:F5L<WKS(&YE;2!L96AE="!T]F)B("5D(&MA<F%K
M=&5R;NEL(0!!(&IE;'-Z879A9"!T^FP@:_9N;GEE;B!K:71A;.%L:&%T\R$@
M3F5M(&WS9&]S[71O;2$`07H@^FH@:F5L<WKS;F%K(&QE9V%LX6)B("5D(&MA
M<F%K=&5N96L@:V5L;"!L96YN:64A`$%Z(/IJ(.ES(&$@:F5L96YL96=I(&IE
M;'-Z\VYA:R!K_&SV;F+V>FYI92!K96QL`$%Z(/IJ(&IE;'-Z\VYA:R!L96=A
M;.%B8B`E9"!B973[="!K96QL('1A<G1A;&UA>FYI82X`07H@^FH@:F5L<WKS
M;F%K(&QE9V%LX6)B("5D(&%L9F%N=6UE<FEK=7,@:V%R86MT97)T(&ME;&P@
M=&%R=&%L;6%Z;FEA+@!!>B#Z:B!J96QS>O-N86L@;&5G86SA8F(@)60@:VES
M8F5T^W0@:V5L;"!T87)T86QM87IN:6$N`$%Z(/IJ(&IE;'-Z\VYA:R!L96=A
M;.%B8B`E9"!S>N%M;W0@:V5L;"!T87)T86QM87IN:6$N`$%Z(/IJ(&IE;'-Z
M\VYA:R!L96=A;.%B8B`E9"!N86=Y8F5T^W0@:V5L;"!T87)T86QM87IN:6$N
M`$%Z(/IJ(&IE;'-Z\R!N96T@=&%R=&%L;6%Z:&%T("5D+6[A;"!T]F)B(/QR
M97,@:V%R86MT97)T+@!!>B#Z:B!J96QS>O,@;F5M('1A<G1A;&UA>FAA="#\
M<F5S(&MA<F%K=&5R="X`07H@^FH@:F5L<WIA=F%K(&YE;2!E9WEE>FYE:R$`
M07H@UFX@^FH@8F7A;&SM=.%S86ET(.ER=NEN>65S[71E='3\:R!A(&UO<W1A
M;FD@8F5J96QE;G1K97KI<R!I9&5JZ7)E+@!!>B#6;B#Z:B!B9>%L;.UTX7-A
M:70@96QM96YT971T_&LN`$%Z(-9N(&IE;'-Z87;A="#A=.%L;.UT;W1T=6L`
M07H@UFX@:F5L<WIA=N%T(.%TX6QL[71O='1U:RP@;NEZ>F4@;65G(&$@;&5V
M96QE:70L(&UA:F0@:F5L96YT:V5Z>F5N(&)E(&%Z(/IJ(&IE;'-Z\W9A;"X`
M07H@UFX@X6QT86P@:&%S>F[A;'0@=.%V;VQI('-Z97)V97)E:SH`2G5G;W-Z
M;.%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%M.92!M=71A<W-U:R!A(&)E
M:63I>F5T="!S>O9V96=E=%T`6TAI8F%J96QE;G3I<UT`6TUU=&%S<W5K(&$@
M8F5I9.EZ971T('-Z]G9E9V5T("T`6TUU=&%S<W5K(&$@8F5I9.EZ971T('-Z
M]G9E9V5T("T@)7,@<V]R70!;)7,O)7,@<V]R70!?061M:6YI<WIT<N%C:?,`
M7U!A<F%N8W-S;W(`4V]R=/9R;.ES`%]#<V]P;W)T;VL`4V5?9^UT<^EG`$$@
M:^EP('1U;&%J9&]N<^%G86DN+BX`0F5J96QE;G1K97KI<P!?2VEJ96QE;G1K
M97KI<P!!(&QI;FL@;?-D;W/M=.%S82XN+@!?3W!C:?-K`%]*;V=O<W5L='/A
M9V]K`$$@;&EN:R!T]G)LZ7-E+BXN`%]"9>%L;.UTX7-O:P!4X6)LX7IA="!T
M=6QA:F1O;G/A9V]K`%]&96QH87-Z;N%L\VL`8^UM:F5G>7KI:P!A;B!E<G)O
M<B!H87,@;V-C=7)E9#H`;F%P=.%R`&YY=6=O9'0`:V%T=&EN='-O;B!I9&4`
M9&]N90!F86EL960`8W/V:VME;@!FX6IL`&9O=6YD.@`E<R`H)7,I(&ERX6YY
M8O-L+"`E<R`E<R!S96)E<W/I9V=E;`!M.@!A>F]N;F%L:0!S;W)=`$%Z(&UK
M<VEO9G,@<')O9W)A;2`E9"!H:6)A:_-D9&%L(&QEX6QL="!A>B!)4T\@X6QL
M;VWA;GD@:^ES>NUTZ7-E(&OV>F)E;BX`;NEV`&YO="!C:&%N9V5D`&YO="!F
M;W5N9`!!('!R;V=R86UN86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L
M\W/M='9A+@!!('!R;V=R86UN86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G
M=F%L\W/M='9A+@!J96=Y>F5T=/9M8@!S>N%Z86SI:P!P:7AE;`!E;65L:V5D
M:6L`;NEZ>OQK(&UE9R!A(&O\;/9N8G/I9V5K970`<VUS,F5M86EL('-Z;VQG
MX6QT873A<R!(5%10+6X@X70`=N%L=&]Z871L86X`9F5L861A=&QI<W1A`'1E
M;7!N86TH*2!S:6ME<G1E;&5N(0!T:&4@2&]R9&4@4$\@9FEL92!F;W(@=&AE
M(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`;65G97+U<^UTZ7-KZ6YT(&OI
M='-Z97(@[7)J82!B92!A(&IE;'-Z\W0`;NEV(&[I;&O\;`!U<&1A=&5D`&$@
M9F5L:&%S>F[A;/,@X6QT86P@=N%L87-Z=&AA=/,`=D-A<F0`<WHZ`"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]H=5](52]H96QP
M+GAM;```````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3,U,``Q,#0Q
M-S,V,C<T-``P,C$V-#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O
M+3@X-3DM,B(_/@H\(2TM("1(;W)D93H@<&%S<W=D+VQO8V%L92]H=5](52]H
M96QP+GAM;"QV(#$N,B`R,#`U+S`V+S$Y(#$W.C`X.C4X(&IA;B!%>'`@)"`M
M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)P87-S=V0M=7-E<FYA;64B(&UD-3TB
M,F)E,V%C-#5E9#$P8F0T,#EB8F,S,30S-6,Q-3(V,64B('-T871E/2)C:&%N
M9V5D(CX*("`@(#QT:71L93Y&96QH87-Z;L.A;,.S:2!NPZEV/"]T:71L93X*
M("`@(#QH96%D:6YG/D%Z(,.V;B!F96QH87-Z;L.A;,.S:2!N979E/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("##C7)J82!B92!I9&4@82!F96QH87-Z;L.A
M;,.S:2!N97;#J70@*&AA(&W#J6<@;FEN8W,@:VETP[9L='9E*0H@("`@/"]P
M87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<&%S<W=D+75S
M97)N86UE(CX*("`@(#QT:71L93Y5<V5R;F%M93PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY9;W5R(%5S97)N86UE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%
M;G1E<B!Y;W5R('5S97)N86UE(&AE<F4@*&EF(&ET(&ES(&YO="!A;')E861Y
M('!R969I;&QE9"DN($YO="!A;&P@:6YS=&%L;&%T:6]N<R!S=7!P;W)T('1H
M:7,N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](G!A<W-W9"UO;&0M<&%S<W=O<F0B(&UD-3TB,#AD8V,X-&0Y.#0V,F%D
M-3DP,S4V8V4V960V,#EC-#`B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET
M;&4^4L.I9VD@:F5L<WK#LSPO=&ET;&4^"B`@("`\:&5A9&EN9SY2PZEG:2!J
M96QS>L.S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("##C7)J82!B92!I9&4@
M82!M;W-T86YI+"!MQ;%KP[9DQ9$@8F5LPZEPPZES:2!J96QS>F%VPZ%T+B!(
M96QY97-E;B!K96QL(&UE9V%D;FEA(&5Z="!A(&IE;'-ZP[-T+"!MPZ%S:\.\
M;,.V;F)E;B!N96T@=L.A;'1O>G1A=&IA=&IA(&UE9RX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!A<W-W9"UN97<M<&%S<W=O<F0B(&UD
M-3TB-&8R-&1E9C4V.#0Y-S9F8S1E,C4P-V0X,SDS-CDV-#$B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^PYIJ(&IE;'-ZP[,\+W1I=&QE/@H@("`@
M/&AE861I;F<^PYIJ(&IE;'-ZP[,\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(,.-<FIA(&)E(&ED92!A>B##NFH@:F5L<WK#LW0L(&%M:7)E(';#H6QT;WIT
M871N:2!A:V%R+B!!>B##NFH@:F5L<WK#LVYA:R!M96<@:V5L;"!F96QE;&YI
M(&)I>F]N>2!M:6YI;<.A;&ES(&5L=L.A<L.A<V]K;F%K("AM96=F96QE;,61
M(&AO<W-Z+"!N96T@96=Y97IH970@;65G(&$@9F5L:&%S>F[#H6S#LVD@;L.I
M=G9E;"P@:V5L;"!B96YN92!L96YN:2!B973%L6YE:R##J7,@;<.A<R!K87)A
M:W1E<FYE:R!I<RP@<V%TP[9B8FDI+"!KP[QLP[9N8F5N(&AI8F$@P[QZ96YE
M=&5T(&9O9R!K87!N:2$*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!A<W-W9"UC;VYF:7)M+7!A<W-W;W)D(B!M9#4](C4T-F4Q8CDQ.30U
M-#`P9C<V,#=F831F,3,S-C0X.#5F(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@
M/'1I=&QE/D5RQ9%SPZUT<V4@;65G(&%Z(,.Z:B!J96QS>L.S=#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY%<L61<\.M='-E(&UE9R!A>B##NFH@:F5L<WK#LW0\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($ED92!A>B##NFH@:F5L<WK#LW0@
M:V5L;"!MPZEG96=Y<WIE<B!B96ER;FEA+B!%>GIE;"!B:7IT;W/#K71J=6LL
M(&AO9WD@96=Y(&?#J7!E;,.I<VD@:&EB82!V86=Y(&W#H7,@=,.I=F5DPZES
M(&UI871T(&YE;2!ZPZ%R:F$@:VD@;6%GPZ%T(&$@<F5N9'-Z97)BQ9%L+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&%S<W=D+7-E<G9E
M<B(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^0VAA;F=E('!A<W-W;W)D(&]N
M/"]T:71L93X*("`@(#QH96%D:6YG/D-H86YG92!P87-S=V]R9"!O;CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@4V5L96-T('1H92!S97)V97(@;W(@87!P
M;&EC871I;VX@:6X@=VAI8V@@>6]U('=A;G0@=&\@8VAA;F=E('1H92!P87-S
M=V]R9"X@3F]T(&%L;"!I;G-T86QL871I;VYS('-U<'!O<G0@=&AI<RX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](D-H86YG92UY;W5R+7!A
M<W-W;W)D(B!M9#4](C@Q8S,S,F(V86(S83$S960P9#`Q9#`X9C<X,#1D,F1C
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D$@:F5L<WK#LR!M96=V
MPZ%L=&]Z=&%TPZ%S83PO=&ET;&4^"B`@("`\:&5A9&EN9SY!(&IE;'-ZP[,@
M;65G=L.A;'1O>G1A=,.A<V$\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@
M:F5L<WK#LW;#H6QT;WIT873#H7-I(&O#J7)E;&5M(&5L:\.\;&3#J7/#J6AE
M>B!N>6]M:F$@;65G(&$@(D$@:F5L<WK#LR!M96=VPZ%L=&]Z=&%TPZ%S82(@
M9V]M8F]T(&%L=6PN($5N;F5K(&$@9V]M8FYA:R!A(&UE9VYY;VW#H7-A(&O#
MJ7)VPZEN>65Z:2!A(&MO;FMRPZET(';#H6QT;WIT873#H7-T+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<F5S970B(&UD-3TB,CDX9#8R
M8F(X9F9C8S8U-C@T.&8X-V-F-F8S8C5A,C8B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^4F5S970\+W1I=&QE/@H@("`@/&AE861I;F<^4F5S970\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@(E)E<V5T(B!G;VUB(&UE9VYY
M;VW#H7-A(&MI=,.V<FQI(&%Z(&5D9&EG(&)EPZUR="!A9&%T;VMA="##J7,@
MP[IJ<F%K97ID:2!A>F]K(&)E:\.I<L.I<\.I="X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*/"]H96QP/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P87-S=V0O;&]C86QE+VET7TE4+P``````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,#$W-``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O:71?250O3$-?
M34534T%'15,O````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-#0`,#(Q-S8Q`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D
M+VQO8V%L92]I=%])5"],0U]-15-304=%4R]P87-S=V0N;6\`````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#$T,#(T,``Q,#0Q-S,V,C<T-``P,C,V,34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````#V`@``'```
M`,P7``#U`P``?"\```````!0/P``2````%$_```$````FC\```P```"?/P``
M$0```*P_```E````OC\```L```#D/P``$````/`_```H`````4````L````J
M0```%0```#9````+````3$````L```!80```"@```&1````-````;T````X`
M``!]0```)````(Q````I````L4```!D```#;0```#P```/5````8````!4$`
M``X````>00``#@```"U!```(````/$$``#T```!%00``"@```(-!```%````
MCD$```D```"400``"0```)Y!```0````J$$```H```"Y00```P```,1!```&
M````R$$```\```#/00``"0```-]!```-````Z4$``!D```#W00``'@```!%"
M```/````,$(```\```!`0@``"````%!"```D````64(```@```!^0@``3@``
M`(="```M````UD(``!\````$0P``&0```"1#```,````/D,```X```!+0P``
M`P```%I#```%````7D,```H```!D0P``%P```&]#```*````AT,```\```"2
M0P``#@```*)#```C````L4,``!0```#50P``%P```.I#```7`````D0``!<`
M```:1```$P```#)$```/````1D0```8```!61```"P```%U$```5````:40`
M``4```!_1```.P```(5$```X````P40``#D```#Z1```)P```#1%```L````
M7$4``"H```")10``)0```+1%```&````VD4``!$```#A10``"@```/-%```(
M````_D4```X````'1@``"@```!9&```.````(48```0````P1@``"0```#5&
M```&````/T8```<```!&1@``!@```$Y&```%````548``"(```!;1@``%@``
M`'Y&```,````E48```,```"B1@``$P```*9&```.````ND8```@```#)1@``
M!````-)&```&````UT8``!4```#>1@``!P```/1&```5````_$8```\````2
M1P``#0```")'```/````,$<```T```!`1P``!@```$Y'```&````54<```\`
M``!<1P``5````&Q'```4````P4<```0```#61P``#@```-M'``!$````ZD<`
M`!P````O2```)0```$Q(```9````<D@``!(```",2```"@```)](```/````
MJD@``!$```"Z2```!@```,Q(```-````TT@```P```#A2```!@```.Y(```&
M````]4@``!$```#\2```!0````Y)```,````%$D```4````A20``!@```"=)
M```'````+DD```T````V20``$````$1)```)````54D```L```!?20``"0``
M`&M)```*````=4D``!T```"`20``#````)Y)```0````JTD``!4```"\20``
M"````-))```$````VTD```X```#@20``$````.])```*`````$H``"`````+
M2@``+@```"Q*```7````6TH``#````!S2@``*P```*1*```A````T$H``!\`
M``#R2@``(````!)+```E````,TL``"H```!92P``!P```(1+```&````C$L`
M``T```"32P``$````*%+```3````LDL```P```#&2P``#@```--+```/````
MXDL``!,```#R2P``#0````9,```H````%$P```,````]3```#0```$%,```"
M````3TP```0```!23```$````%=,```-````:$P```,```!V3```#@```'I,
M```(````B4P```\```"23```#0```*),```3````L$P```8```#$3```#```
M`,M,```+````V$P```T```#D3```(@```/),```;````%4T```H````Q30``
M&````#Q-```9````54T``!8```!O30``+P```(9-```B````MDT``!0```#9
M30``"P```.Y-```+````^DT```D````&3@``"0```!!.```6````&DX```\`
M```Q3@``#0```$%.```F````3TX``$,```!V3@``+P```+I.```$````ZDX`
M``H```#O3@``"@```/I.```0````!4\``!<````63P``$0```"Y/```7````
M0$\``!D```!83P``#0```')/```@````@$\``$````"A3P``!0```.)/```@
M````Z$\```<````)4```$````!%0```/````(E```!`````R4```#P```$-0
M```/````4U````P```!C4```#P```'!0```'````@%````H```"(4```%@``
M`)-0```(````JE```!,```"S4```!````,=0```(````S%````H```#54```
M#````.!0```+````[5````P```#Y4```!P````91```*````#E$```T````9
M40``!0```"=1```.````+5$```H````\40``)@```$=1```5````;E$```4`
M``"$40``!P```(I1```,````DE$```@```"?40``!@```*A1```(````KU$`
M`!8```"X40``$@```,]1```"````XE$```8```#E40``"0```.Q1```0````
M]E$```D````'4@``"0```!%2```9````&U(```X````U4@``(@```$12```.
M````9U(```(```!V4@``#0```'E2```%````AU(```0```"-4@``%````))2
M```1````IU(```8```"Y4@``$0```,!2```.````TE(``!$```#A4@``!@``
M`/-2```$````^E(```H```#_4@``!`````I3```%````#U,```4````54P``
M%````!M3```3````,%,``!L```!$4P``$@```&!3```+````<U,``"D```!_
M4P``)````*E3```F````SE,```@```#U4P``$@```/Y3```*````$50```\`
M```<5```$````"Q4```.````/50```D```!,5```"@```%94```&````850`
M``\```!H5```$@```'A4```0````BU0``!$```"<5```$@```*Y4```0````
MP50```L```#25```&@```-Y4```4````^50```P````.50``#````!M5```/
M````*%4``!4````X50``*0```$Y5```J````>%4``"8```"C50``)P```,I5
M```9````\E4``!$````,5@``$@```!Y6```3````,58``!0```!%5@``%@``
M`%I6```7````<58``!````")5@``$0```)I6```3````K%8``!0```#`5@``
M&@```-56```)````\%8```8```#Z5@``!P````%7```6````"5<```0````@
M5P``!````"57```'````*E<```<````R5P``"````#I7```,````0U<```T`
M``!05P``#@```%Y7```6````;5<``!$```"$5P``"````)97```&````GU<`
M``0```"F5P``"@```*M7```*````ME<``!````#!5P``&@```-)7```*````
M[5<```P```#X5P``#P````58```(````%5@```8````>6```!P```"58```+
M````+5@```,````Y6```$P```#U8```"````45@```0```!46```"@```%E8
M``!`````9%@``!,```"E6```:````+E8```%````(ED```8````H60``#P``
M`"]9```#````/UD```<```!#60``"P```$M9```5````5UD```T```!M60``
M&@```'M9``!*````EED```8```#A60``!@```.A9```"````[UD```L```#R
M60``"````/Y9```*````!UH```P````26@``!P```!]:```*````)UH```D`
M```R6@``$````#Q:```2````35H```0```!@6@``!P```&5:```%````;5H`
M``P```!S6@``%P```(!:```-````F%H```0```"F6@``"@```*M:```$````
MMEH```4```"[6@``+````,%:```5````[EH``#L````$6P``%````$!;```3
M````55L```@```!I6P``"````');```K````>UL``$4```"G6P``00```.U;
M```$````+UP```<````T7```!0```#Q<```&````0EP```@```!)7```$0``
M`%)<```.````9%P```(```!S7```#@```'9<```:````A5P```<```"@7```
M!@```*A<```-````KUP``!0```"]7```'P```-)<```'````\EP```X```#Z
M7```"`````E=```*````$ET``!T````=70``!0```#M=```1````05T``!$`
M``!370``"````&5=```-````;ET```@```!\70``*@```(5=```)````L%T`
M``H```"Z70``%0```,5=```%````VUT```0```#A70``$````.9=```'````
M]UT``!X```#_70``*````!Y>```*````1UX``!P```!27@``&@```&]>```4
M````BEX```8```"?7@``!@```*9>```T````K5X``#0```#B7@``*0```!=?
M```I````05\``%$```!K7P``!0```+U?```9````PU\``!D```#=7P``"```
M`/=?```-`````&````@````.8```%P```!=@```*````+V````<````Z8```
M(0```$)@```-````9&````X```!R8```!P```(%@```3````B6````@```"=
M8```!0```*9@```$````K&````H```"Q8```"0```+Q@```.````QF````0`
M``#58```,@```-I@``!%````#6$``!X```!380``%````')A```'````AV$`
M``X```"/80``*@```)YA```&````R6$```P```#080``$0```-UA```+````
M[V$```H```#[80``"P````9B```/````$F(``#8````B8@``"````%EB```%
M````8F(```X```!H8@``$P```'=B```'````BV(``!H```"38@``"````*YB
M```1````MV(``!0```#)8@``&````-YB```'````]V(```4```#_8@``$@``
M``5C```.````&&,```X````G8P``!0```#9C```%````/&,```,```!"8P``
M#0```$9C```"````5&,```0```!78P``!P```%QC```)````9&,```P```!N
M8P``4@```'MC```7````SF,``"0```#F8P``!@````MD```.````$F0``"(`
M```A9```%0```$1D```2````6F0```\```!M9```%````'UD``!I````DF0`
M`!H```#\9```%P```!=E```G````+V4``!H```!790``%P```')E```;````
MBF4``!D```"F90``'P```,!E```3````X&4```@```#T90``"0```/UE```_
M````!V8``#<```!'9@``5P```']F```?````UV8```@```#W9@``#0````!G
M```M````#F<```0````\9P``)0```$%G```?````9V<``!T```"'9P``)0``
M`*5G```@````RV<``"0```#L9P``!P```!%H```-````&6@```P````G:```
M&0```#1H```0````3F@```H```!?:```#````&IH```'````=V@```0```!_
M:```%P```(1H```*````G&@```P```"G:```"0```+1H```(````OF@```8`
M``#':```&````,YH```"````YV@``&4```#J:```"0```%!I```'````6FD`
M`"8```!B:0``.````(EI```:````PFD``"H```#=:0``*`````AJ```9````
M,6H``!4```!+:@``!P```&%J```(````:6H```<```!R:@``!P```'IJ```.
M````@FH```D```"1:@``!@```)MJ```(````HFH```L```"K:@``!P```+=J
M```'````OVH```@```#':@``$````-!J```0````X6H```<```#R:@``!```
M`/IJ```%````_VH```0````%:P``%`````IK```+````'VL```T````K:P``
M%P```#EK```)````46L```H```!;:P``!P```&9K```"````;FL``!\```!Q
M:P``/@```)%K```C````T&L``"@```#T:P``(P```!UL```9````06P``"$`
M``!;;```'P```'UL```K````G6P``"<```#);```*P```/%L```R````'6T`
M`#$```!0;0``00```()M```S````Q&T``"4```#X;0``@P```!YN```+````
MHFX```<```"N;@``!P```+9N```-````OFX```L```#,;@``!0```-AN```%
M````WFX```@```#D;@```P```.UN```*````\6X```(```#\;@```P```/]N
M```$`````V\``"`````(;P``&@```"EO```)````1&\```P```!.;P``!P``
M`%MO```%````8V\``!,```!I;P``&@```'UO```+````F&\```P```"D;P``
M!@```+%O```)````N&\```L```#";P``#0```,YO```=````W&\```P```#Z
M;P``%P````=P```&````'W```!,````F<```!@```#IP```1````07```#(`
M``!3<```$P```(9P```1````FG```#(```"L<```#@```-]P```/````[G``
M`!````#^<```"`````]Q```)````&'$```H````B<0``%````"UQ```(````
M0G$```@```!+<0``#P```%1Q```.````9'$``!````!S<0``"0```(1Q```)
M````CG$``!D```"8<0``"@```+)Q```,````O7$```D```#*<0```@```-1Q
M```0````UW$```,```#H<0``!P```.QQ```-````]'$```L````"<@``+P``
M``YR```@````/G(``!P```!?<@``,0```'QR```%````KG(``#\```"T<@``
M$@```/1R```*````!W,```8````2<P``!0```!ES```&````'W,```D````F
M<P``(````#!S```"````47,```P```!4<P``)0```&%S```9````AW,``",`
M``"A<P``'P```,5S```H````Y7,``"D````.=```)@```#AT```E````7W0`
M`"@```"%=```(0```*YT```2````T'0``!,```#C=```$````/=T```)````
M"'4``'(````2=0``<P```(5U```K````^74``%,````E=@``%P```'EV```6
M````D78```\```"H=@``40```+AV```W````"G<``#8```!"=P``/@```'EW
M``!!````N'<``$,```#Z=P``0````#YX```^````?W@``$````"^>```0@``
M`/]X```Y````0GD``!\```!\>0``%````)QY```0````L7D``!,```#">0``
M#P```-9Y```.````YGD```D```#U>0``"P```/]Y```'````"WH```4````3
M>@``%````!EZ```(````+GH```\````W>@``"````$=Z```,````4'H```\`
M``!=>@``%````&UZ```&````@GH``!4```")>@``!````)]Z```$````I'H`
M``8```"I>@``!P```+!Z```9````N'H```0```#2>@``%0```-=Z```&````
M[7H```0```#T>@``"P```/EZ```)````!7L```<````/>P``!@```!=[```&
M````'GL```8````E>P``,P```"Q[```B````8'L```<```"#>P``"P```(M[
M``!1`0``EWL``$L```#I?```!@```#5]```*````/'T``!$```!'?0``)0``
M`%E]```/````?WT``!$```"/?0``*````*%]```+````RGT``!````#6?0``
M"@```.=]```-````\GT```D`````?@``#P````I^```-````&GX``",````H
M?@``)0```$Q^```<````<GX```D```"/?@``%@```)E^```.````L'X```X`
M``"_?@``!@```,Y^``!%````U7X```D````;?P``!0```"5_```%````*W\`
M``8````Q?P``$````#A_```,````27\```@```!6?P``"P```%]_```5````
M:W\```T```"!?P``%0```(]_```<````I7\``!X```#"?P``&0```.%_```8
M````^W\```T````4@```/````"*````/````7X```&H```!O@```/````-J`
M```A````%X$``"P````Y@0``!P```&:!```/````;H$```H```!^@0``#```
M`(F!```-````EH$``!P```"D@0``#@```,&!```0````T($``!0```#A@0``
M*0```/:!```=````(((``"`````^@@``%P```%^"```;````=X(``!<```"3
M@@``$@```*N"```(````OH(```P```#'@@``%P```-2"```&````[((``$``
M``#S@@``-P```#2#```\````;(,``#0```"I@P``-0```-Z#```P````%(0`
M`#````!%A```!@```':$```2````?80```8```"0A```"````)>$```3````
MH(0```X```"TA```#````,.$```)````T(0```D```#:A```!P```.2$```'
M````[(0```4```#TA```!P```/J$```D`````H4``!D````GA0``$````$&%
M```#````4H4``!D```!6A0``$````'"%```*````@84```4```",A0``"```
M`)*%```<````FX4```<```"XA0``%0```,"%```5````UH4```\```#LA0``
M%0```/R%```-````$H8```8````@A@``"````">&```/````,(8``'0```!`
MA@``%@```+6&```$````S(8``!$```#1A@``1````..&```D````*(<``"<`
M``!-AP``%0```'6'```2````BX<```X```">AP``(P```*V'```5````T8<`
M``<```#GAP``#@```.^'```2````_H<```8````1B```!@```!B(```2````
M'X@```8````RB```$````#F(```(````2H@```@```!3B```!P```%R(```0
M````9(@``!0```!UB```"````(J(```(````DX@```H```"<B```"@```*>(
M```I````LH@```P```#<B```$0```.F(```?````^X@```@````;B0``!0``
M`"2)```2````*HD``!`````]B0``"````$Z)```F````5XD``#4```!^B0``
M'````+2)```R````T8D``#8````$B@``)@```#N*```H````8HH``"D```"+
MB@``/````+6*```T````\HH```4````GBP``!````"V+```4````,HL``!``
M``!'BP``%````%B+```+````;8L``!````!YBP``#0```(J+```4````F(L`
M``T```"MBP``-0```+N+```&````\8L``!````#XBP```@````F,```$````
M#(P``!`````1C```#0```"*,```&````,(P``!`````WC```"````$B,```/
M````48P``!$```!AC```$P```'.,```(````AXP```T```"0C```#0```)Z,
M```/````K(P``!<```"\C```&0```-2,```+````[HP``!X```#ZC```&P``
M`!F-```8````-8T``#,```!.C0``-````(*-```4````MXT```L```#,C0``
M"````-B-```0````X8T```@```#RC0``'@```/N-```7````&HX```T````R
MC@``*P```$".``!.````;(X``#,```"[C@``"````.^.```/````^(X```\`
M```(CP``$0```!B/```8````*H\``!4```!#CP``&````%F/```:````<H\`
M`!(```"-CP``,P```*"/``!'````U(\```8````<D```)0```".0```(````
M29````X```!2D```#0```&&0```/````;Y````T```!_D```#0```(V0```+
M````FY```!(```"GD```"@```+J0```+````Q9```!,```#1D```"0```.60
M```I````[Y````8````9D0``"````""1```-````*9$```\````WD0``$```
M`$>1```,````6)$```8```!ED0``"P```&R1```/````>)$```4```"(D0``
M$0```(Z1```+````H)$``"H```"LD0``(````->1```&````^)$```@```#_
MD0``#`````B2```(````%9(```4````>D@``!P```"22```5````+)(``!(`
M``!"D@```P```%62```&````69(```0```!@D@``%````&62```*````>I(`
M``T```"%D@``&0```).2```/````K9(``"(```"]D@``#P```."2```%````
M\)(```X```#VD@``!0````63```&````"Y,``!8````2DP``$@```"F3```&
M````/),```\```!#DP``$@```%.3```/````9I,```<```!VDP``!0```'Z3
M```(````A),```0```"-DP``!@```)*3```%````F9,``!@```"?DP``%P``
M`+B3```>````T),``!<```#ODP``#`````>4```:````%)0``!\````OE```
M&````$^4```'````:)0``!@```!PE```"@```(F4```/````E)0``!,```"D
ME```$@```+B4```,````RY0```P```#8E```"````.64```1````[I0``!,`
M````E0``$````!25```8````)94```\````^E0``$@```$Z5```,````894`
M`!T```!NE0``&P```(R5```5````J)4``!$```"^E0``&@```-"5```8````
MZY4``#`````$E@``-````#66```M````:I8``#$```"8E@``(0```,J6```4
M````[)8``!4````!EP``%0```!>7```7````+9<``!@```!%EP``&0```%Z7
M```3````>)<``!0```",EP``&P```*&7```6````O9<``!````#4EP``"@``
M`.67```'````\)<```<```#XEP``&`````"8```&````&9@```8````@F```
M#````">8```(````-)@```8````]F```#0```$28```5````4I@``!(```!H
MF```&````'N8```3````E)@```<```"HF```!P```+"8```(````N)@```H`
M``#!F```#P```,R8```=````W)@``"H```#ZF```"@```"69```,````,)D`
M``P````]F0``!0```$J9```%````4)D```0```!6F0``&@```%N9```%````
M=ID``!<```!\F0```@```)29```%````EYD``!@```"=F0``.````+:9```6
M````[YD``%8````&F@``!0```%V:```'````8YH``!0```!KF@``!@```(":
M```&````AYH```P```".F@``%````)N:```-````L)H``!8```"^F@``)0``
M`-6:```'````^YH```8````#FP```P````J;```+````#IL```@````:FP``
M#````".;```5````,)L```@```!&FP``"P```$^;```+````6YL``!<```!G
MFP``%P```'^;```$````EYL```0```"<FP```P```*&;```/````I9L``!T`
M``"UFP``#P```-.;```'````XYL``!$```#KFP``"````/V;```%````!IP`
M`"@````,G```'````#6<``!$````4IP``!D```"7G```(````+&<```.````
MTIP```L```#AG```-@```.V<``!4````))T``$X```!YG0``!P```,B=```-
M````T)T```0```#>G0``!````..=```(````Z)T``!$```#QG0``#P````.>
M```"````$YX```P````6G@``&0```".>```'````/9X```<```!%G@``$0``
M`$V>```6````7YX``"H```!VG@``!P```*&>```.````J9X```@```"XG@``
M"0```,&>```4````RYX```4```#@G@``$@```.:>```9````^9X```H````3
MGP``$@```!Z?```(````,9\``#,````ZGP``"0```&Z?```*````>)\``"$`
M``"#GP``!P```*6?```(````K9\``!@```"VGP``"P```,^?```D````VY\`
M`"X`````H```"````"^@```<````.*```!P```!5H```%@```'*@```$````
MB:````4```".H```)P```)2@```C````O*```"D```#@H```+@````JA``!2
M````.:$```@```",H0``(@```)6A```@````N*$```@```#9H0``#0```.*A
M```)````\*$``!X```#ZH0``"P```!FB```)````):(``"D````OH@``%```
M`%FB```1````;J(```@```"`H@``&````(FB```(````HJ(```<```"KH@``
M!P```+.B```.````NZ(```T```#*H@``#P```-BB```%````Z*(``$,```#N
MH@``3@```#*C```F````@:,``"0```"HHP``!````,VC```-````TJ,``"H`
M``#@HP``!P````ND```.````$Z0``!4````BI```#````#BD```*````1:0`
M``X```!0I```$@```%^D``!#````<J0```L```"VI```!P```,*D```0````
MRJ0``!<```#;I```"0```/.D```:````_:0```H````8I0``$P```".E```9
M````-Z4``!@```!1I0``!P```&JE```&````<J4``!@```!YI0``%````)*E
M```4````IZ4```8```"\I0``!@```,.E```&````RJ4```P```#1I0```P``
M`-ZE```%````XJ4```@```#HI0``"@```/&E```-````_*4``%H````*I@``
M'0```&6F```U````@Z8```<```"YI@``$0```,&F```A````TZ8``"````#U
MI@``'P```!:G```3````-J<``"$```!*IP``<P```&RG```B````X*<``!\`
M```#J```(P```".H```C````1Z@``!L```!KJ```(P```(>H```?````JZ@`
M`",```#+J```'````.^H```)````#*D```D````6J0``/P```""I```O````
M8*D``%X```"0J0``+0```.^I```(````':H```\````FJ@``+0```#:J```&
M````9*H``"(```!KJ@``+P```(ZJ```A````OJH``"$```#@J@``&P````*K
M```@````'JL```H````_JP``$@```$JK```0````7:L``!\```!NJP``$@``
M`(ZK```*````H:L``!4```"LJP``"@```,*K```$````S:L``!(```#2JP``
M#````.6K```.````\JL```L````!K```"`````VL```%````%JP``!,````<
MK````P```#"L``!K````-*P```L```"@K```"````*RL```9````M:P``",`
M``#/K```'````/.L```9````$*T``!H````JK0``'````$6M```7````8JT`
M``D```!ZK0``!````(2M```(````B:T```0```"2K0``#0```)>M```&````
MI:T```@```"LK0``"@```+6M```+````P*T```@```#,K0``"@```-6M```*
M````X*T``!$```#KK0``$0```/VM```-````#ZX```@````=K@``"````":N
M```&````+ZX``!@````VK@``"P```$^N```-````6ZX``!@```!IK@``"@``
M`(*N```2````C:X```T```"@K@```P```*ZN```@````LJX``#L```#3K@``
M(@````^O```H````,J\``",```!;KP``(````'^O```B````H*\``"````##
MKP``-P```.2O```H````'+```"H```!%L```/````'"P```\````K;```#@`
M``#JL```.````".Q```P````7+$``(0```"-L0``#0```!*R```%````(+(`
M``8````FL@``$@```"VR```+````0+(```8```!,L@``!````%.R```&````
M6+(```0```!?L@``"````&2R```#````;;(```,```!QL@``!````'6R```F
M````>K(``"````"AL@``"@```,*R```4````S;(```H```#BL@``!0```.VR
M```7````\[(``!D````+LP``#@```"6S```,````-+,```@```!!LP``"P``
M`$JS```/````5K,```\```!FLP``)0```':S```6````G+,``"(```"SLP``
M"````-:S```1````W[,```D```#QLP``'0```/NS```Y````&;0``!8```!3
MM```%````&JT```X````?[0``!(```"XM```$P```,NT```/````W[0```L`
M``#OM```#````/NT```,````"+4``!,````5M0``!P```"FU```)````,;4`
M`!(````[M0``#````$ZU```5````6[4```H```!QM0``"@```'RU```A````
MA[4```H```"IM0``#````+2U```+````P;4```,```#-M0``$````-&U```#
M````XK4```D```#FM0``#@```/"U```-````_[4``#`````-M@``'@```#ZV
M```@````7;8``"X```!^M@``"0```*VV``!%````M[8``!8```#]M@``#P``
M`!2W```*````)+<```8````OMP``!P```#:W```2````/K<``"H```!1MP``
M`@```'RW```2````?[<``"T```"2MP``'@```,"W```E````W[<``",````%
MN```*````"FX```J````4K@``"H```!]N```*P```*BX```K````U+@``#(`
M````N0``$P```#.Y```3````1[D``!,```!;N0``"P```&^Y``"!````>[D`
M`(<```#]N0``*0```(6Z``!0````K[H``!L`````NP``$P```!R[```,````
M,+L``%,````]NP``1@```)&[```V````V+L``#L````/O```-P```$N\``!'
M````@[P``$,```#+O```0@````^]``!#````4KT``%$```"6O0``20```.B]
M```E````,KX``!4```!8O@``)P```&Z^```7````EKX``!````"NO@``#P``
M`+^^```)````S[X```T```#9O@``!P```.>^```&````[[X``!L```#VO@``
M#@```!*_```2````(;\```@````TOP``"0```#V_```0````1[\``!@```!8
MOP``!P```'&_```5````>;\```4```"/OP``!0```)6_```'````F[\```@`
M``"COP``&````*R_```$````Q;\``!4```#*OP``!@```."_```$````Y[\`
M``X```#LOP``"P```/N_```(````!\````8````0P```"P```!?````(````
M(\```#`````LP```*P```%W````*````B<````L```"4P````0```-\```#G
M`@``60(```````!T````^`````4"``#I`0``%````(L"``#'````I0(`````
M``!E`````````((!``"]````3@```-<"```0`@```````#8!````````I0``
M`&,```````````````````"H`0````````````">`````````!H!````````
M$@```.P```!J`0``8`(``.0"```G`0``F0```$\```!+`@``7@(``&0!````
M````2P```/8"``"=````O0$``#<!``"1`0``+0(``/8```"4````1P```!``
M``#*`0``HP(``'$```"<````C0(``'P!``````````````````"J`@``````
M```````(````\@$``````````````````#,"```Q`@``*0````````"^`@``
M`````+<"``#V`0``80$``$@"``#H`0``E0$````````3````)@$``#D!``"`
M````X0```-0"``#O`@```````&D```!'`@``.0(```````##````````````
M``"N`@```````"``````````SP(``.4```!I`0``X````"4````\````[`(`
M`*L```"\`@``.@(``-T"``#(`0```````#(````9````:@(``'T!``!X````
M,0$``,4"``#0`@```````$,!```\`@```````#L```#8`@``A@(``#,```#Q
M````0P(``.H!```M`0``#0$```````!Z`````````.8"```6`````````.@`
M``!U````[0`````````E`@``<P```%4````F````HP````````#%````'P``
M`!4!``#L`0``Z@```","````````KP$````````D`````````)`!```5````
MXP(```````!V`0``'0$``/@!``#E`0```````,L````Z`0``E@(`````````
M``````````L"```[`@``00```$4```!(`0``MP````````"[`0```````+,"
M```_`0``C````(\!``#P`0```````%T!``";`0``X@````````")`@``90$`
M```````/````.````&`!```"`@``=@(`````````````J0(```````#%`0``
M`````*<"``````````````````#Y````'0```(X`````````R0$``%L"````
M````10(``+4!``!*`0``R````*8"``!;`````P$``.4"``#5`@```````-$`
M```7`@``7P````````!6````@`(``*P"```<`@```````"`"```H`@``O@$`
M`.X!````````C`(``%T`````````00$``'T"``!P`0``Q`$``&L"``"%`0``
M[P```)X!``"R`0``XP````<!````````>P````````!M````M@```#4"``#?
M`0````````````!R`````````+$```!1`@``L`(``!X````;`0``5`$``*$"
M``!7`@`````````````$`@``X0$``*@```#A`@```````-P"``!E`@``F`$`
M```````N`````````'$"````````F````#0`````````.`$```````"2`0``
M;0(```````!M`0``O0(````````O`@``N@$``.0!`````````@```+`````9
M`0```````&P!```X`@```````(D```!,`0``V````+D"``"6`0``20$``!@!
M``"'````8@$``%P"``!H`@```````%D````3`0``\@```&X"````````[0$`
M`"\``````````````!T"``#!`0``5@$```````!_`@``/@$``+D`````````
M`````!(!``!*`@```````'P````K`0``N````+\!````````[@(``+$"``!F
M`0``R@````H!```*`````````*L!```U````RP(````````[`0``Y@```,$`
M````````#0(``/0!````````QP(```````"9`@``3````&$````'````_P``
M`!X!``"U````J0$``)$"``!:`@``>P$```````!F````/@```"$````7`0``
M`````!`!````````"@(``*D```````````````````!U`0```````,T"````
M````G@(`````````````V0$``/4!```&`````````.8!```?`@``[@``````
M``#3`````````)<!``!H`0````````````!0`@``H0```"D"```C`0``4```
M`#\"``!)````+@(``(8```!,`@``T0$``!,"``"_`@``NP(``*4!````````
MN`$``-,"``"*`0``UP```````````````````!L"````````!```````````
M``````````````!W`0``]P$````````,`0``7P(``(8!````````20(``(4`
M``"K`@``\P(``*@"``"R````D`(``$0"```V`@```````%@"``#&````#@$`
M`!$`````````*P(```````".`@``G`(```````"+````#@```&D"``"(````
M``````````"M`@``W0```%4!````````1`$``.`!``#;````9P```-H"````
M````"`(``$@````+````)P``````````````!`$`````````````AP(``!0"
M````````S@(`````````````;`(`````````````F@```)0!``!-`@``GP``
M`%D!``"7````(@$``,\!``!=`@```````!\!``"+`0``@P````4!````````
MI@$```````"D`````````&(````1`0```````"\!``"%`@``W`$``%X!``"X
M`@```````-T!``",`0``WP(``,8"``````````(``'T````,````*````,$"
M``!:`0``\@(``"8"```-````?P```)4```!*````)P(```(!```]````B`$`
M````````````E@```)````#;`0```````"0!````````6@````````##`@``
MM@$``!8"``````````````````#2`@``;P$``/<```#[`0``-P(``/$"``#4
M````^@$``-X"`````````````.L!````````&0(``/P```#)`@``,`````$"
M``#H`@``4P$``,0```!"`@``5`(```````!>````0@$`````````````````
M`#,!``"4`@``J@$``.D```#P`@``10$```8!``"*````00(```D```!#````
M/0(```````"Z`@``C@$```````!&`@``1@$``#4!``#>`0``/`$``"H````5
M`@``"`$````````@`0``B`(```,"````````>0$``/X!``"#`@``Q@$`````
M``#@`@``O@```*H```"G````S`$``,(```!.`@``-@``````````````````
M``````"Y`0``U@(``-D`````````50(``+H```"V`@``1P$``.,!````````
M,@$````````^`@``6`$``,\```"8`@``5@(`````````````>`$``(\"``"'
M`0```````"("````````<`(``-8!``!W`@``*P````````"``0``IP$``/,!
M```:````YP$``*0!```L`@`````````````)`@```````,D```!2`0``````
M````````````(0$``&<!``!1````H@$``#<```!A`@``1````-L"````````
M:P$````````!`0```````&P`````````@0(```````!+`0``@@(```````!P
M````KP```$`!````````T@$```````!N````:@`````````T`0``4@``````
M``#K`@``R@(``/0```!S`@```````!("``#Y`0``NP````````!3`@``&P``
M`-H!``!-````D@(``&,"``!B`@```````'@"```R`@``!0```'H"````````
MMP$``/T``````0``R`(``!@"``"<`0``!@(```````#S````3P$``'X!``"7
M`@``G0$``%`!``!U`@``#`(``)$```"_````@0```.D"``!T`@```P```*X!
M``"/`````````"H"``!R`@````````````#_`0``?@(``#H```"9`0``#P$`
M`.(!`````````````/4"````````'@(````````_````K@```"P`````````
MH`(```````#"`@```````*$!```'`@``(0(``',!``!7`0``^P```-@!``#.
M````?`(``'(!``"M`0``+@$``.H"``"=`@``X@(``$8```#T`@``?P$``#`"
M`````````````-`!```Y````,0```,P```#:````#@(```````"\````````
M`"P!``"$````P````'8```"?`@``_0$```````#``@``%@$```````!C`0``
MC0$``*P````<````DP$``,T```![`@``H`$``,X!````````6P$````````T
M`@``H@```)L"```B````C0```&\"```8````)0$``",```!"`````````/4`
M``"U`@``5P```,P"````````4@(```````!N`0```````.T"````````````
M`)\!````````````````````````^@```*0"``!<`0``M`(`````````````
M9`(``+P!``#5`0``7P$``%,```#0````30$``-$"``"P`0``````````````
M````U0````````#7`0``I@```+,````+`0``+0``````````````D@``````
M``!Y````[P$``"H!``"!`0```````$`"````````QP$``(D!````````B@(`
M`&````#6````&@(``%@```#\`0```````%P````H`0```````(,!``"3````
M#P(``&<"``#$`@``K`$``"D!``":`@``L@(``*,!```1`@``M`````````#K
M````/0$``'H!``"5`@``3P(``&L`````````TP$```````#>`````````((`
M``"M`````````&\```!F`@``T@```)H!````````H@(``/````!4````\0$`
M`,,!```D`@```````!P!``"T`0``FP```.<```#``0``U`$``!0!``!Y`@``
MRP$``(0"````````P@$``-D"````````?@```.0````P`0``40$```D!``"Q
M`0``W``````````7````<0$``),"``!T`0``0````(0!``!.`0```````*\"
M``#^`````````*````#-`0``:````'<```!D````LP$`````````("8C,34Q
M.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R
M871I;VYS(&-H96-K960@8F5L;W<N`"!A="``)60@)7,@86YD("5S`"5D(&)Y
M=&5S('=R:71T96XN`"5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O
M+61A=&4`)7,@+2!.;W1I8V4`)7,@0V]N9FEG=7)A=&EO;@`E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-T86YD87)D`"5S
M(%1E<FUS(&]F($%G<F5E;65N=``E<R!A="`E<R`E<P`E<R!A="`E<R!F=``E
M<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)R5S)R!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"<E<R<@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"<E<R<@=V%S(&YO="!C<F5A
M=&5D.B`E<RX`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!
M(&YE=R!S:6=N=7`@:&%S(&)E96X@<F5C96EV960@86YD(&ES(&%W86ET:6YG
M('EO=7(@87!P<F]V86PN`$%-(%-H;W=E<G,`04TO4$T`06)S8F]T=&]M`$%B
M<VUI9&1L90!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G1I;F<`061D`$%D9"`E
M<P!!9&0@0VAI;&0@1W)O=7``061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D
M(&$@8VAI;&0@9W)O=7`@=&\@)R5S)P!!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O("<E<R<`061D(&$@;F5W('5S97(Z`$%D9"!N97<@;65M8F5R<P!!9&0@
M<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D
M('5S97(`061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T
M(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D
M("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I
M;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%D<P!!;&EG
M;@!!;&EG;FUE;G0Z`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U
M<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L=&5R;F%T92!)35-0($QO9VEN
M`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N
M86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T
M97,`06QT97)N871E('1E>'0Z`$%N<W=E<@!!<'!L:6-A=&EO;@!!<'!L:6-A
M=&EO;B!I<R!R96%D>2X`07!R:6P`07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B+6=R;W5P
M<S\`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+@!!=6=U<W0`079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N9`!"87-E;&EN
M90!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)L=64@86YD(%=H:71E`$)O
M;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97)S`$)O='1O;0!"<F]W;@!"=6EL
M9&EN9R!-3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN`$)U:6QD:6YG(&QO8V%L
M92`E<RXN+B``0G5R;G0@3W)A;F=E`$--4P!#7V5L;"!0<F]P97)T:65S+BXN
M`$-?;VUM86YD(%-H96QL`$-A;&5N9&%R`$-A;&T`0V%N8V5L`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#
M96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`
M0V5L;"!S<&%C:6YG.@!#96YT97(`0VAA;F=E`$-H86YG92!087-S=V]R9`!#
M:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H
M96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E
M('EO=7(@<&%S<W=O<F0`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@
M8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@
M870@=&AI<R!T:6UE+@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-L
M96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`0VQE86YI;F<@
M=7`@;&]C86QE("5S+BXN(`!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E
M<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI96YT`$-L
M:65N="!4:6-K970`0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]L;&%P
M<V5D(&)O<F1E<G,`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;',Z`$-O;6EC<P!#
M;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;6%N9"!O<'1I;VYS.@!#;VUM86YD
M<SH`0V]M;6ET=&EN9SH`0V]M<&QE=&5D`$-O;F1I=&EO;G,`0V]N9FEG=7)A
M=&EO;B!N965D<R!U<&1A=&EN9RX`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S
M<W=O<F0`0V]N9FER;2!N97<@<&%S<W=O<F0Z`$-O;G1I;G5E`$-O<'D`0V]P
M>2!S96QE8W1I;VX`0V]P>6EN9R`E<R!T;R`E<P!#;W)N9FQO=V5R`$-O=6QD
M(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C;VYN96-T
M('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-O<'D@
M)7,@=&\@)7,`0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER96-T;W)Y(&9O
M<B!L;V-A;&4@)7,Z`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@)R5S)RX`0V]U;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N
M`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F
M;W(@)R5S)SH@)7,`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A
M=&4@82!N97<@;VYE`$-R96%T;W(@4&5R;6ES<VEO;G,`0W5R<F5N="!4:6UE
M`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I
M=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!$1`!$871A`$1A
M=&%4<F5E($)R;W=S97(`1&%T92!296-E:79E9`!$87D`1&5?;&5T92!#;VQU
M;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E9F%U;'0@0V]L;W(`1&5F
M875L="!097)M:7-S:6]N<P!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!C
M96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<`1&5L971E(')O
M=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES('!E
M<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1I<F5C=&]R>0!$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@
M9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`161I=`!%9&ET($)L;V-K`$5D
M:70@1W)O=7``161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET('!E<FUI<W-I;VYS(&9O<B`G)7,G`$5M86EL($%D9')E<W,`16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YT<FEE<SH@)60@=&]T
M86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK
M;F]W;@!%<G)O<@!%<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+@!%
M<G)O<CH@`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y
M(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AE8W5T:6YG
M.@!%>'1R86-T:6YG(&9R;VT@)7,N+BX@`$9'($-O;&]R`$944"!U<&QO860@
M;V8@<V5T=7``1F%I<@!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z
M(`!&97<@4VAO=V5R<P!&:6QE($UA;F%G97(`1FEL=&5R<P!&:7)S="!(86QF
M`$9I<G-T(%%U87)T97(`1FQO870`1F]L;&]W('5P('1A<VL`1F]N="!#;VQO
M<@!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)G
M;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`
M1F]R='5N97,`1F]R=6US`$9O<G=A<F1S`$9O=6YD(&%P<&QI8V%T:6]N<SH@
M)7,`1F]U;F0@9&ER96-T;W)I97,Z`$9R`$9R86UE<P!&<F]M('1H92``1G5L
M;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=E;F5R871E("5S
M($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5N97)A=&EN9R!S=&%T
M=7,@9F]R(&UO9'5L92`E<RXN+@!'971O<'0@17)R;W(Z(`!';P!';V]G;&4@
M4V5A<F-H`$=R965N`$=R97D`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@
M<&5R;6ES<VEO;G,`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T(%-E
M<G9I8V5S`$=U97-T('!E<FUI<W-I;VYS`$AE:6=H=`!(96QP`$AE;6ES<&AE
M<F4`2&EG:`!(;U]M90!(;W)D90!(;W)D92!!9&UI;FES=')A=&EO;@!(;W)D
M92!#;VYF:6=U<F%T:6]N`$AO<F1E('1R86YS;&%T:6]N(&=E;F5R871O<@!(
M;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AU;6ED:71Y`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N
M<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EM86=E
M(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E<P!);7!O<G0L
M(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`
M26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(%!A<W-W;W)D`$EN9&EV:61U
M86P@57-E<G,`26YF;W)M871I;VX`26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN
M+B``26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!4
M86)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T90!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`
M26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E
M<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN
M<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T+TUO9&EF
M>2!);6%G90!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED('!A<F5N="!P
M97)M:7-S:6]N+@!);G9E;G1O<GD`271A;&EC`$IA;G5A<GD`2F%P86YE<V4@
M*$E33RTR,#(R+4I0*0!*=6QY`$IU;F4`2G5S=&EF>0!,85]Y;W5T`$QA;F=U
M86=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%V
M96YD97(`3&%Y;W5T`$QE9G0`3&EG:'0@0FQU90!,:6=H="!286EN`$QI<W0@
M2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A
M='5R90!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO
M9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO=P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$U-`$UA:6P`36%I;"!!9&UI;@!-86ME('-U<F4@=&AA="!Y;W4@:&%V
M92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA
M:VEN9R!D:7)E8W1O<GD@)7,`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%R8V@`36%R9VEN
M`$UA=&-H:6YG(&9I96QD<P!-87D`365M8F5R<P!-97)G92!C96QL<P!-97)G
M:6YG(&QO8V%L92`E<RXN+B``365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-
M971R:6,`36ED9&QE`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF>2!5
M4DP`36]S=&QY($-L96%R`$UO>FEL;&$`37D@06-C;W5N=`!->2!0;W)T86P`
M37D@4&]R=&%L($QA>6]U=`!.3RP@22!$;R!.3U0@06=R964`3F585`!.971W
M;W)K`$YE=F5R`$YE=R!#871E9V]R>0!.97<@57-E<FYA;64@*&]P=&EO;F%L
M*0!.97<@<&%S<W=O<F0Z`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YI9VAT`$YO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO
M(&-O;6UA;F0@<W!E8VEF:65D+@!.;R!E;G1R>2!W:71H('1H92!I9"`G)7,G
M(&5X:7-T<R!I;B!T:&4@;W)I9VEN86P@:&5L<"!F:6QE+@!.;R!L;V-A;&4@
M<W!E8VEF:65D+@!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I
M9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92X`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO;F4`3F]T('-E=`!.;W1E<P!.;W1I8V4`3F]V96UB97(`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3TL`3V)J96-T($-R96%T;W(`
M3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,`3V-T;V)E<@!/9F9I8V4`3VQD
M('!A<W-W;W)D.@!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W!T
M:6]N<SH`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M90!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!0
M2%`@0V]D90!032!,:6=H="!286EN`%!A<W-W;W)D`%!A<W-W;W)D(&UO9'5L
M92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9`!087-S=V]R9#H`4&%S<W=O
M<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%T:`!096YD:6YG
M(%-I9VYU<',Z`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6ES<VEO;@!097)M:7-S:6]N("<E<R<@;F]T(&1E;&5T960N`%!E<FUI
M<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H
M;W1O<P!0:7AE;',`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@<WES=&5M+@!0;VQL<P!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E
M`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S=&YU:V4`4')E<V5N=&%T
M:6]N<P!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R
M93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M`%!R979I;W5S('1A<VL`4')I;G0@9&]C=6UE;G0`4')O8FQE;0!0<F]B;&5M
M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%%U97)Y`%)A:6X`4F%I;B!%87)L>0!2
M86EN($QA=&4`4F%N9&]M($9O<G1U;F4`4F5A9`!296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E
M;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A
M:7(`4F5M;W9E('1H90!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q
M=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@4U%,(&-O;F9I9W5R
M871I;VXN`%)E<V5L;&5R`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO
M=7(@4&%S<W=O<F0`4F5S=6QT<P!297-U;'1S("AI;F-L=61I;F<@2&]R9&4I
M.@!297-U;'1S.@!2971U<FX@=&\@3W!T:6]N<P!2979E<G0@0V]N9FEG=7)A
M=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2
M;U]W(%!R;W!E<G1I97,N+BX`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I
M97,`4F]W<SH`4G5L97,`4G5N`%--4R!-97-S86=I;F<`4V$`4V%V90!3879E
M("5S`%-A=F4@)R5S)P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3
M879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`4V5A<F-H`%-E
M87)C:"!%;F=I;F5S`%-E87)C:&EN9R!(;W)D92!A<'!L:6-A=&EO;G,@:6X@
M)7,`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!3
M96QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H
M;W<`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W=E<G,`4VAO=V5R
M<R!%87)L>0!3:&]W97)S($QA=&4`4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E
M9`!3:VEP($UA:6YT96YA;F-E`%-K:7!P960N+BX`4VYO=R!D97!T:#H@`%-P
M86-I;F<`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL
M`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W1A;F1A<F0`4W1A='5S`%-T871U
M<R!F;W(@;&]C86QE("5S+BXN(`!3=0!3=6)M:71T960@<F5Q=65S="!T;R!A
M9&0@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT
M:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`
M4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@)R5S)R!T;R!T:&4@<WES=&5M
M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("<E<R<@9G)O
M;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+@!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`G)7,G(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L
M;'D@=7!D871E9"`G)7,G`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6UM87)Y
M`%-U;B!2:7-E`%-U;B!3970`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR
M:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`5"U3
M=&]R;0!4+5-T;W)M<P!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I
M97,`5&%R9V5T.@!487-K`%1A<VMS`%1E86P`5&5M<"!F;W(@;&%S="!H;W5R
M.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES
M=')A=&EO;@!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86YK
M('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE("5S(&AE;'`@9FEL92!F
M;W(@)7,@9&]E<VXG="!Y970@97AI<W0N($-R96%T:6YG(&$@;F5W(&]N92X`
M5&AE("5S(&QI;FL@=&\@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE(&AE;'`@
M9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\/WAM;`!4:&4@:61E;G1I='D@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&EN:R!H87,@8F5E;B!R96UO
M=F5D`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R
M=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&1O97-N)W0@>65T(&5X:7-T(&$@
M:&5L<"!F:6QE(&9O<B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@
M)R5S)R!T;R!T:&4@<WES=&5M+B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B
M;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T
M96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T
M:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`G)7,G
M.B`E<P!4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@
M5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@
M=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R
M+@!4:&ES(&ES("5S+@!4:'5N9&5R`%1I8VME=',`5&EM92!4<F%C:VEN9P!4
M:6UE(&9O<FUA=`!4:71L90!4;V1A>0!4;VUO<G)O=P!4;W``5')A;G-L871E
M9`!4=0!54DP`55),.@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+@!5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+@!5;F1E<FQI;F4`56YD;R!#
M:&%N9V5S`%5N9FEL960`56YI=',`56YK;F]W;B!C;VUM86YD.B`E<P!5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;G-E="!C;VQO<@!5;G1R86YS;&%T
M960`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("<E<R<N
M`%5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N`%5P9&%T:6YG("XN+@!5
M<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!P97(@<F]M86X@;G5M
M8F5R<P!5<V%G93H`57-E($1E9F%U;'0@5F%L=64`57-E(&EF(&YA;64O<&%S
M<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B!!9&UI
M;FES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO
M;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&YO="!F
M;W5N9`!5<V5R(&YO="!F;W5N9"X`57-E<B!P97)M:7-S:6]N<P!5<V5R;F%M
M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!6
M86-A=&EO;@!687)I86)L90!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI
M9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I97<@
M86X@97AT97)N86P@=V5B('!A9V4`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``
M5V%R;FEN9SH@`%=E`%=E871H97(@1F]R96-A<W0`5V5B`%=E;&-O;64`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET
M97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BX`5VED=&@`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A
M:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L
M90!7:61T:"!U;FET`%=I9'1H.@!7:6YD.@!7:6YD.B``5VES:&QI<W1S`%=R
M:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@)7,N`%E9`%EE<RP@22!!9W)E
M90!9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D(&9O<B!U<V5R("5S`%EO=2!H
M879E(&)E96X@;&]G9V5D(&]U="X`66]U(&UU<W0@9VEV92!Y;W5R(&-U<G)E
M;G0@<&%S<W=O<F0`66]U(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9`!9
M;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!V97)I9GD@>6]U<B!N97<@
M<&%S<W=O<F0`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S
M<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@
M0V]N=')O;"]/<'1I;VX@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE
M.@!9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@;&]N9SL@<&%S<W=O<F1S(&UA
M>2!N;W0@8F4@;6]R92!T:&%N("5D(&-H87)A8W1E<G,@;&]N9R$`66]U<B!N
M97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G=65S<R$@($YO="!C:&%N
M9V5D(0!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D(&-H
M87)A8W1E<G,@;&]N9R$`66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F
M97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0`66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@8VAA
M<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE
M87-T("5D(&%L<&AA;G5M97)I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S
M=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;&]W97)C87-E(&-H87)A
M8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S
M="`E9"!N=6UE<FEC(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R<RX`
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&QE<W,@=&AA;B`E9"!W
M:&ET97-P86-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@
M;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C:&%R86-T97)S+@!9;W5R(&YE=R!P
M87-S=V]R9',@9&ED;B=T(&UA=&-H`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M0
M<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!?061M:6YI<W1R
M871I;VX`7T-O;F9I9W5R871I;VX`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'
M<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!O=70`7TUO
M9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI
M;FLN+BX`7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%N(&5R<F]R(&AA
M<R!O8V-U<F5D.@!C86QM`&1O;F4`9F%I;&5D`&9O=6YD.B``9G)O;2!T:&4@
M)7,@*"5S*2!A="`E<R`E<P!I,3AN`&QD87!?<W1A<G1?=&QS(&9A:6QE9`!L
M:6YE<UT`;F%M90!N;W0@8VAA;F=E9`!N;W0@9F]U;F0`<&5R8V5N=`!P:7AE
M;',`<FES:6YG`'-T96%D>0!T:&4@2&]R9&4@4$\@9FEL92!F;W(@=&AE(&QO
M8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;0!U<&1A=&5D`'=E871H97(N8V]M`%!R;VIE8W0M260M
M5F5R<VEO;CH@<&%S<W=D"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`T+3`X+3,P(#$T
M.C$Q*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP,RTR-2`P-#HQ,"TM
M,3`P"DQA<W0M5')A;G-L871O<CH@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO
M+F-O;3X*3&%N9W5A9V4M5&5A;3H@271A;&EA;B`\9&5V0&QI<W1S+FAO<F1E
M+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=`H`("8C,34Q.R`E<R#H('!R;VYT;R!P97(@97-E9W5I<F4@
M;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4@<V5L97II;VYA=&4N`"!A
M;&QE(``E9"`E<R!E("5S`"5D(&)Y=&5S('-C<FET=&DN`"5D(&1I("5D(&1A
M=&D@<V5G;F%T:2!C;VUE(&%G9VEO<FYA=&D`)7,@+2!!='1E;GII;VYE`"5S
M($-O;F9I9W5R87II;VYE`"5S($]P97)A>FEO;FD@9&D@36%N=71E;GII;VYE
M("T@0V]N9F5R;6$`)7,@4W1A;F1A<F0`)7,@5&5R;6EN:2!D)U5S;P`E<R!A
M("5S("5S`"5S(&$@)7,@<&EE9&D`)7,@;6EN=71I`"5S(&YO;B!T<F]V871O
M+@`E<R!A("5S(&1I("5S`$%G9VEU;G1O("<E<R<@86P@<VES=&5M82!D:2!G
M<G5P<&DN`"<E<R<@86=G:75N=&\@86P@<VES=&5M82!D:2!P97)M97-S:2X`
M)R5S)R!N;VX@92<@<W1A=&\@8W)E871O.B`E<P`L(&$@)7,@)7,`+"!V87)I
M86)I;&4@9&$@)7,@82`E<P!&;W)M871O(#$R(&]R90!&;W)M871O(#(T(&]R
M90`R-"!O<F4`56X@;G5O=F\@:7-C<FET=&\@92<@<W1A=&\@:6YS97)I=&\@
M92!S=&$@87-P971T86YD;R!L82!T=6$@8V]N9F5R;6$N`$UO<W1R82!!30!!
M32]030!686D@80!296=O;&4`06-C;W5N="!087-S=V]R9`!#;VYT86)I;&ET
M82<`06=G:75N9VD`06=G:75N9VD@)7,`06=G:75N9VD@4V]T=&\@1W)U<'!O
M`$%G9VEU;F=I('%U:3H`06=G:75N9VD@3G5O=F\@571E;G1E`$%G9VEU;F=I
M('-O='1O+6=R=7!P;R!A("<E<R<`06=G:75N9VD@<V]T=&\M<&5R;65S<V\@
M82`G)7,G`$%G9VEU;F=I('5N(&YU;W9O('5T96YT93H`06=G:75N9VD@=6X@
M;G5O=F\@;65M8G)O`$%G9VEU;F=I('!A:6\`06=G:75N9VD@8V]M92!B;V]K
M;6%R:R!I;"!-96YU(&1I("5S(&%L;&$@4VED96)A<B!D:2!-;WII;&QA`$%G
M9VEU;F=I('5T96YT90!!9V=I=6YT;R`G)7,G(&%L('-I<W1E;6$L(&UA(&YO
M;B!E<F$@<&]S<VEB:6QE(&EN<V5R:7)E(&PG:6YF;W)M87II;VYE(&%G9VEU
M;G1I=F4@9&5L;&$@<F5G:7-T<F%Z:6]N93H@)7,N`$%G9VEU;G1O("<E<R<@
M86P@<VES=&5M82X@3W)A('!U;VD@:6YI>FEA<F4@;&$@='5A('-E<W-I;VYE
M+@!!9V=I=6YG:2!N=6]V;R!F:6QE(&%L;"=A<F-H:79I;SH`3&$@9G5N>FEO
M;F4@9&D@86=G:75N=&$@=71E;G1I(&YO;B#H(&%T=&EV82X`4G5B<FEC80!!
M;6UI;FES=')A>FEO;F4`4'5B8FQI8VETX`!!;&QI;F5A;65N=&\`06QL:6YE
M86UE;G1O.@!4=71T:2!G;&D@571E;G1I($%U=&5N=&EC871I`%1U='1I(&D@
M1W)U<'!I`%1U='1I(&D@4&5R;65S<VD`5'5T=&D@:2!Q=6%T=')O(&QA=&D`
M0V]N<V5N=&D@8V%M8FEA;65N=&D@86QL82!L:7-T82!O<F1I;F%T83\`3&]G
M:6X@571E;GIA($E-4U`@86QT97)N871I=F$`4&%S<W=O<F0@571E;GIA($E-
M4U`@86QT97)N871I=F$`571E;GIA($E-4U`@86QT97)N871I=F$`26YD:7)I
M>GIO(&5M86EL(&%L=&5R;F%T:79O`$%V=FES82!S=2!A9V=I;W)N86UE;G1I
M`%1E<W1O(&%L=&5R;F%T:79O.@!2:7-P;W-T80!!<'!L:6-A>FEO;F4`07!P
M;&EC87II;VYE(&4G('!R;VYT82X`07!R:6QE`%-E:2!S:6-U<F\@9&D@=F]L
M97(@96QI;6EN87)E(&QA(')I8VAI97-T82!D:2!I<V-R:7II;VYE('!E<B`E
M<S\`4VEC=7)O(&1I('9O;&5R(&-A;F-E;&QA<F4@)R5S)R!E('1U='1I(&D@
M<V]T=&\M9W)U<'!I/P!#:&EE9&D@8V]N9F5R;6$@<')I;6$@9&D@97-E9W5I
M<F4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4`5&5N=&%T:79O(&1I(&-A
M;F-E;&QA>FEO;F4@9&D@=6X@9W)U<'!O(&EN97-I<W1E;G1E+@!496YT871I
M=F\@9&D@96QI;6EN87II;VYE(&1I('5N('!E<FUE<W-O(&EN97-I<W1E;G1E
M+@!496YT871I=F\@9&D@;6]D:69I8V$@9&D@=6X@<&5R;65S<V\@:6YE<VES
M=&5N=&4`5&5N=&%T:79O(&1I(&UO9&EF:6-A(&1I('5N('!E<FUE<W-O(&EN
M97-I<W1E;G1E`$%G;W-T;P!#86UP:2!D:7-P;VYI8FEL:3H`4V9O;F1O`$)A
M<V5L:6YE`$EM<&]S=&%Z:6]N:2!";&]C8V\`5&EP;R!D:2!";&]C8V\`0FQU
M(&4@0FEA;F-O`$=R87-S971T;P!0<F5F97)I=&D`36%R9VEN90!-87)G:6YI
M`$)A<W-O`$UA<G)O;F4`0V]S=')U>FEO;F4@9FEL92!-3R!P97(@;6]D=6QO
M("5S+BXN`$-O<W1R=7II;VYE(&QO8V%L92`E<RXN+B``07)A;F-I;R!B<G5C
M:6%T;P!#35,`4')O<')I973@(&1E;&QE($-?96QL92XN+@!3:&5L;"!D:2!#
M;VUA;F1I`$-A;&5N9&%R:6\`0V%L;6\`0V%N8V5L;&$`16QI;6EN82!287!P
M;W)T;R!D:2!0<F]B;&5M80!/<'II;VYI`$-A=&5G;W)I92!E($5T:6-H971T
M90!0<F]P<FEE=.`@9&5L;&4@8V5L;&4`4W!E<W-O<F4@8V5L;&4Z`%!R;W!R
M:65TX"!D96QL92!C96QL90!3<&%Z:6\@8V5L;&4Z`$-E;G1R80!-;V1I9FEC
M80!#86UB:6$@4&%S<W=O<F0`36]D:69I8V$@;F]M92P@:6YD:7)I>GIO(&4@
M9FER;6$@8VAE('9E<G)A;FYO('9I<W5A;&EZ>F%T:2!D86QL92!P97)S;VYE
M(&-H92!L96=G;VYO(&4@<FES<&]N9&]N;R!A:70@='5O:2!M97-S86=G:2X`
M0V%M8FEA(&QA('1U82!P87-S=V]R9`!#:6%D`%9E<FEF:5]C82!,:6YK+BXN
M`$-O;G1R;VQL82!L82!C87-E;&QA('!E<B!Q=6%L<VEA<VD@;W!E<F%Z:6]N
M92AI*2!T=2!V;V=L:6$@9F%R92!O<F$N`%-E;&5Z:6]N82!C;VUE('9I<W5A
M;&EZ>F%R92!L92!D871E.@!0=6QI>FEA(&1E;"!F:6QE(%!/('!E<B!I;"!M
M;V1U;&\@)7,N+BX`4'5L:7II82!L;V-A;&4@)7,N+BX@`$5L:6UI;F$@=71E
M;G1E.B`E<P!%;&EM:6YA('5T96YT90!%;&EM:6YA(&QE(&EN9F]R;6%Z:6]N
M:2!D96QL)W5T96YT90!#;&EC8V$@<&5R($-O;G1I;G5A<F4`0VQI96YT90!4
M:6-K970@0VQI96YT90!#:&EU9&D@;&$@1FEN97-T<F$`3G5V;VQE`$YU=F]L
M90!-87)G:6YI(&-O;&QA<W-A=&D`0V]L;W)E`%-E;&5Z:6]N82!#;VQO<F4`
M0V]L;VYN93H`5FEG;F5T=&4`0V]M86YD;P!3:&5L;"!D:2!#;VUA;F1I`$]P
M>FEO;FD@9&5L(&-O;6%N9&\Z`$-O;6%N9&DZ`$EM<&5G;F\Z`$-O;7!L971A
M=&\`0V]N9&EZ:6]N:0!,82!C;VYF:6=U<F%Z:6]N92!D979E(&5S<V5R92!A
M9V=I;W)N871A+@!#;VYF:6=U<F$@)7,`0V]N9F5R;6$@4&%S<W=O<F0`0V]N
M9F5R;6$@;&$@='5A(&YU;W9A('!A<W-W;W)D.@!#;VYT:6YU80!#;W!I80!3
M96QE>FEO;F4@;&$@8V]P:6$`0V]P:6%N9&\@)7,@82`E<P!':7)A<V]L90!)
M;7!O<W-I8FEL92!C;VYN971T97)S:2!A;"!S97)V97(@;&1A<`!);7!O<W-I
M8FEL92!C;VYN971T97)S:2!A;"!S97)V97(@)R5S)R!U<V%N9&\@1E10.B`E
M<P!);7!O<W-I8FEL92!C;W!I87)E("5S(&EN("5S`$EM<&]S<VEB:6QE(&-R
M96%R92!D:7)E8W1O<GD@;&]C86QE('!E<B!L;V-A;&4@)7,Z`$EM<&]S<VEB
M:6QE(&5L:6UI;F%R92!L;R!S8W)I<'0@9&D@86=G:6]R;F%M96YT;R`G)7,G
M+@!.;VX@<&]T979O(&%P<FER92!U;B!P:7!E(&$@<VUB<&%S<W=D+@!);7!O
M<W-I8FEL92!I;G9E<G1I<F4@;&$@8V]N9FEG=7)A>FEO;F4N`$EM<&]S<VEB
M:6QE('-A;'9A<F4@;&$@8V]N9FEG=7)A>FEO;F4@)7,N`$EM<&]S<VEB:6QE
M('-A;'9A<F4@=6YA(&-O<&EA(&1I('-C;W)T82!D96QL82!C;VYF:6=U<F%Z
M:6]N90!);7!O<W-I8FEL92!S8W)I=F5R92!L82!C;VYF:6=U<F%Z:6]N92!P
M97(@)R5S)SH@)7,N`$-O<G-I`$-R96$`0W)E82!U;B!C;VQL96=A;65N=&\`
M0W)E86YE('5N;R!N=6]V;P!097)M97-S:2!D:2!#<F5A=&]R90!/<F$@871T
M=6%L90!,82!54DP@871T=6%L92#H`$UE=&5O($%T='5A;&4`0V]N9&EZ:6]N
M:2!A='1U86QI.B``4W1I;&4@871T=6%L90!);7!O<W1A(&QE(&]P97)A>FEO
M;FD@9&$@97-E9W5I<F4@<75A;F1O(&5N=')I(&EN("5S+@!486=L:6$`4V5L
M97II;VYE(%1A9VQI80!'1P!$871I`$)R;W=S97(@1&%T851R964`1&%T82!2
M:6-E=G5T;P!':6]R;F\`15]L:6UI;F$@0V]L;VYN80!$:6-E;6)R90!.=6UE
M<F\@9&5C:6UA;&4`0V]L;W)E(&1I($1E9F%U;'0`4&5R;65S<VD@9&D@9&5F
M875L=`!#86YC96QL80!%;&UI;F$@1W)U<'!O`$5L:6UI;F$@8V5L;&$`16QI
M;6EN82!C;VQO;FYA`$%V=FES82!S=2!A9V=I;W)N86UE;G1I`$5L:6UI;F$@
M<&5R;65S<VD@<&5R("<E<R<`16QM:6YA(')I9V$`16QI;6EN82!L)VED96YT
M:73@('-E;&5Z:6]N871A`$5L:6UI;F$@;&$@8V]L;VYN82!C;W)R96YT90!%
M;&EM:6YA(&QA(')I9V$@8V]R<F5N=&4`16QI;6EN82!Q=65S=&\@<&5R;65S
M<V\@92!Q=6%L<VEA<VD@<V]T=&\M<&5R;65S<V\_`$5L:6UI;F%T;R!I;"!S
M8W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96P@<V5T=7`@)R5S)RX`1&5S8W)I
M=FD@:6P@4')O8FQE;6$`1&5S8W)I>FEO;F4`4W9I;'5P<&\`4'5N=&\@9&D@
M4G5G:6%D80!#87)T96QL80!6:7-U86QI>GIA(&YE;"!F;W)M871O(#(T(&]R
M93\`3W!Z:6]N:2!6:7-U86QI>GIA>FEO;F4`3F]N(&5L:6UI;F%R90!.;VX@
M86-C961E<F4@9&ER971T86UE;G1E(&$@;6%I;G1E;F%N8V4N<&AP`$QA('!R
M:6UA(')I9V$@8V]N=&EE;F4@;&4@971I8VAE='1E(&1I(&-A;7!O/R!-87)C
M82!S92!S:2P@;&%S8VEA('9U;W1A('-E(&YO.@!38V%R:6-A(&QA(&-O;F9I
M9W5R87II;VYE(&=E;F5R871A(&-O;64@<V-R:7!T(%!(4"X`36]D:69I8V$`
M36]D:69I8V$@0FQO8V-O`$UO9&EF:6-A($=R=7!P;P!-;V1I9FEC82!097)M
M97-S:0!-;V1I9FEC82!P97)M97-S:2!P97(@)7,`36]D:69I8V$@;W!Z:6]N
M:2!P97(Z`$UO9&EF:6-A('!E<FUE<W-I('!E<B`E<P!-;V1I9FEC82!P97)M
M97-S:2!P97(@)R5S)P!);F1I<FEZ>F\@9&D@4&]S=&$`1&ES86)I;&ET82!I
M;"!P=6QS86YT92!D97-T<F\@<W5L(&UE;G4@9&D@8V]N=&5S=&\_`$1A=&DZ
M("5D('1O=&%L:2P@)60@86=G:6]R;F%T:2P@)60@;G5O=FDL("5D(&UO9&EF
M:6-A=&DL("5D('-C;VYO<V-I=71I`$5R<F]R90!%<G)O<F4@;F5L(&EN=FEO
M(&1I(&1A=&D@82!S;6)P87-S=V0N`$5R<F]R93H@`$]G;FD@,34@;6EN=71I
M`$]G;FD@,B!M:6YU=&D`3V=N:2`S,"!S96-O;F1I`$]G;FD@-2!M:6YU=&D`
M3V=N:2!-97IZ)V]R80!/9VYI(&UI;G5T;P!686QO<FD@9&D@97-E;7!I;SH`
M17-E8W5Z:6]N90!%<V5C=7II;VYE.@!%<W1R87II;VYE(&1A("5S+BXN`$-O
M;&]R92!&1P!5<&QO860@*$-A<FEC86UE;G1O*2!F:6QE(&YO;B!S=7!P;W)T
M871O+@!':75S=&\`1F5B8G)A:6\`4VD@<V5N=&4@8V]M90!3:2!S96YT92!C
M;VUE.B``4&]C:&D@06-Q=6%Z>F]N:0!&:6QE($UA;F%G97(`1FEL=')I`%!R
M:6UA($UE=&$G`%!R:6UO(%1R:6UE<W1R90!&;&]A=`!!='1I=FETX"!&;VQL
M;W=5<`!#;VQO<F4@1F]N=`!097(@8G)O=W-E<B!C:&4@;F]N('-O<'!O<G1A
M;F\@;&4@:6UM86=I;FD`2&%I(&1I;65N=&EC871O(&QA('1U82!P87-S=V]R
M9#\`36]D=6QI`$EN9&]V:6YO`$9O<G1U;F4@5'EP90!&;W)T=6YE<P!&;W)U
M;0!);F]L=')I`%!R;V=R86UM:2!4<F]V871I.B`E<P!$:7)E8W1O<GD@5')O
M=F%T93H`5F5N`$9R86UE<P!$86P@`$1E<V-R:7II;VYE($-O;7!L971A`$QU
M;F$@4&EE;F$`3F]M92!#;VUP;&5T;P!'96YE<F$@0V]N9FEG=7)A>FEO;F4@
M)7,@`$-O9&EC92!'96YE<F%T;P!'96YE<F%Z:6]N92!S=&%T;R!P97(@;6]D
M=6QO("5S+BXN`$5R<F]R92!'971O<'0Z(`!686D@80!2:6-E<F-A($=O;V=L
M90!697)D90!'<FEG:6\`06UM:6YI<W1R87II;VYE($=R=7!P:0!097)M97-S
M:2!D:2!G<G5P<&\`1W)U<'!I`%!E<FUE<W-I($]S<&ET:0!397)V:7II('!E
M<B!/<W!I=&D`4&5R;65S<VD@;W-P:71I`$%L=&5Z>F$`06EU=&\`16UI<V9E
M<F\`06QT80!(;U]R9&4`2&]R9&4`06UM:6YI<W1R87II;VYE(&1I($AO<F1E
M`$-O;F9I9W5R87II;VYE(&1I($AO<F1E`$=E;F5R871O<F4@9&D@=')A9'5Z
M:6]N92!(;W)D90!2:65M<&EM96YT;R!/<FEZ>F]N=&%L90!/<FEZ>F]N=&%L
M93H`475A;G1E(&-O;&]N;F4@=G5O:2!U;FER93\`475A;G1I(&-A;7!I("AC
M;VQO;FYE*2!C:2!S;VYO/P!1=6%N=&4@<FEG:&4@=G5O:2!U;FER93\`56UI
M9&ETX`!)7VYS97)I<V-I(&QA(')I9V$@<')I;6$`4V]L;R!)8V]N90!)8V]N
M92!C;VX@5&5S=&\`3F]M92!D96QL)TED96YT:73@.@!!;G1E<')I;64@26UM
M86=I;F4`55),($EM;6%G:6YE`%523"!);6UA9VEN90!);6UA9VEN:0!);7!O
M<G1A+"!087-S;R`E9`!#86UP;R!I;7!O<G1A=&\Z("5S`$-A;7!I(&EM<&]R
M=&%T:3H`26Y?<V5R:7-C:2!U;F$@<FEG82!D;W!O`%!A<W-W;W)D($5R<F%T
M80!5=&5N=&D@26YD:79I9'5A;&D`26YF;W)M87II;VYE`$EN:7II86QI>GIA
M>FEO;F4@;6]D=6QO("5S+BXN`$EN<V5R:7-C:2!U;F$@0U]O;&]N;F$@9&]P
M;P!);G-E<FES8VD@=6XG:6UM86=I;F4`26YS97)I<V-I(%1A8F5L;&$`26YS
M97)I<V-I($-O;&QE9V%M96YT;R!796(`26YS97)I<V-I(%]C;VQO;FYA(%!R
M:6UA`$EN<V5R:7-C:2!U;F$@;G5O=F$@8V]L;VYN82!D;W!O('%U96QL82!C
M;W)R96YT90!);G-E<FES8VD@=6YA(&YU;W9A(&-O;&]N;F$@<')I;6$@9&D@
M<75E;&QA(&-O<G)E;G1E`$EN<V5R:7-C:2!U;F$@;G5O=F$@<FEG82!D;W!O
M('%U96QL82!C;W)R96YT90!);G-E<FES8VD@=6YA(&YU;W9A(')I9V$@<')I
M;6$@9&D@<75E;&QA(&-O<G)E;G1E`$EN<V5R:7-C:2!U;B!T96UP;&%T92!A
M;'1E<FYA=&EV;P!);G-E<FES8VD@8V5L;&$@9&]P;P!);G-E<FES8VD@8V5L
M;&$@<')I;6$`06=G:75N9VD@8V]L;VYN82!D;W!O`$EN<V5R:7-C:2!C;VQO
M;FYA('!R:6UA`$EN<V5R:7-C:2!P87)A9W)A9F\@9&]P;P!);G-E<FES8VD@
M<&%R86=R869O('!R:6UA`$EN<V5R:7-C:2!R:6=A(&1O<&\`26YS97)I<V-I
M(')I9V$@<')I;6$`26YS97)I<V-I+TUO9&EF:6-A($EM;6%G:6YE`$%P<&QI
M8V%Z:6]N92!I;G9A;&ED82X`1&%T;R!N;VX@=F%L:61O+@!);G9E;G1A<FEO
M`$-O<G-I=F\`1V5N;F%I;P!':6%P<&]N97-E("A)4T\M,C`R,BU*4"D`3'5G
M;&EO`$=I=6=N;P!':75S=&EF:6-A=&\`7T9O<FUA=&\`3&EN9W5A`%5L=&EM
M;R!1=6%R=&\`56QT:6UO($%G9VEO<FYA;65N=&\Z`%5L=&EM;R!A8V-E<W-O
M.B`E<P!5;'1I;6\@86-C97-S;SH@)7,@9&$@)7,`56QT:6UO(&%C8V5S<V\Z
M($UA:0!,879A;F1A`$9O<FUA=&\`<VEN:7-T<F$`0FQU($-H:6%R;P!0:6]G
M9VEA($QE9V=E<F$`16QE;F-A(&=L:2!A<F=O;65N=&D@9&D@06EU=&\`3F]N
M(.@@871T:79A(&QA(&9U;GII;VYE(&1I(&5L96YC;R!U=&5N=&DN`$QI=&5R
M871U<F$`3W)A(&QO8V%L93H@`$QI;F=U82!E($]R80!,=6]G;P!%;G1R80!%
M<V-I`$-O;7!I=&D@9&D@:6YI>FEO('-E<W-I;VYE`$)A<W-A`&YU;65R:2!R
M;VUA;FD@<&GY(&)A<W-I`$U-`%!O<W1A`$EN9&ER:7IZ;R!!;6UI;FES=')A
M=&]R90!!<W-I8W5R871I(&-H92!H86D@4$5!4B!I;G-T86QL871O(&YE;"!T
M=6\@:6YC;'5D92!P871H+@!#<F5A>FEO;F4@9&ER96-T;W)Y("5S`$=E<W1I
M<V-I(&QA(&QI<W1A(&1E;&QE(&-A=&5G;W)I92!D86YD;R!L;W)O('5N)V5T
M:6-H971T82!E(&%S<V]C:6%N9&\@;&]R;R!U;B!C;VQO<F4N`$UA<GIO`$UA
M<F=I;F4`0V%M<&D@8V]R<FES<&]N9&5N=&D`36%G9VEO`$UE;6)R:0!5;FES
M8VD@0V5L;&4`56YI;VYE(&QO8V%L92`E<RXN+B``365T96\@071T=6%L90!"
M;&]C:R!N;VX@9&ES<&]N:6)I;&4N`$1E='1A9VQI(&QO9V=A=&D@<&5R(&PG
M86UM:6YI<W1R871O<F4`;65T<FEC;P!#96YT<F\`3'5N`$UO8FEL92!-86EL
M`$UO9&5R871O`$UO9&EF:6-A(%523`!0<FEN8VEP86QM96YT92!397)E;F\`
M3F5T<V-A<&4`36EO($%C8V]U;G0`36EO(%!O<G1A;&4`1F]R;6%T;R!D96P@
M36EO(%!O<G1A;&4`3D\L($Y/3B!3;VYO(&0G06-C;W)D;RX`3F585`!2971E
M`$UA:0!.=6]V82!#871E9V]R:6$`3G5O=F\@3F]M92!5=&5N=&4@*$]P>FEO
M;F%L92D`3G5O=F$@<&%S<W=O<F0Z`$YO=&EZ:64`1W)U<'!I(&1I(&YO=&EZ
M:64`4')O<W-I;6\`3F]T=&4`3F]N('!U;VD@8W)E87)E(&9I9VQI(&$@<75E
M<W1O('!E<FUE<W-O+@!.97-S=6X@8V]M;6%N9&\@<W!E8VEF:6-A=&\N`$YE
M<W-U;F$@:6YF;W)M87II;VYE(&-O;B!I9"`G)7,G(&5S:7-T92!N96P@9FEL
M92!D:2!A:75T;R!O<FEG:6YA;&4N`$YE<W-U;B!,;V-A;&4@4W!E8VEF:6-A
M=&\`3F5S<W5N82!R96=I<W1R87II;VYE(&EN(&%T=&5S82X`3F5S<W5N82!R
M96=O;&$`3F5S<W5N(&QA=&\`3F5S<W5N(&1I<F5T=&]R:6\@=&5M<&]R86YE
M;R!D:7-P;VYI8FEL92!P97(@;&$@8V%C:&4N`$YE<W-U;F$@=F5R<VEO;F4@
M=')O=F%T82!N96QL82!C;VYF:6=U<F%Z:6]N92!O<FEG:6YA;&4N(%)E9V5N
M97)A(&QA(&-O;F9I9W5R87II;VYE+@!.97-S=6YA('9E<G-I;VYE('1R;W9A
M=&$@;F5L;&$@='5A(&-O;F9I9W5R87II;VYE+B!296=E;F5R82!L82!C;VYF
M:6=U<F%Z:6]N92X`3F5S<W5N;P!.;VX@:6UP;W-T871O`$YO=&4`3F]T80!.
M;W9E;6)R90!.=6UE<F\@9&D@8V]L;VYN90!.=6UE<F\@9&D@<FEG:&4`3TL`
M4')O<')I971A<FEO`%!E<FUE<W-I(&1E;"!0<F]P<FEE=&%R:6\`3W1T;V)R
M90!59F9I8VEO`%9E8V-H:6$@<&%S<W=O<F0Z`$%P<FD@:6X@;G5O=F$@9FEN
M97-T<F$`07!R:2!Q=65S=&\@8V]L;&5G86UE;G1O(&EN(&YU;W9A(&9I;F5S
M=')A`$]P>FEO;FD`3W!Z:6]N:2!P97(@)7,`3W!Z:6]N:3H`1W)O=7!787)E
M`&%P<&QI8V%Z:6]N92!I;G1E<FYA`$%L=')O`$%L=')E($EN9F]R;6%Z:6]N
M:0!097)M97-S:2!D96P@4')O<')I971A<FEO`$-O9&EC92!02%``4$T@4&EO
M9V=I82!,96=G97)A`%!A<W-W;W)D`$EL(&UO9'5L;R!P87-S=V]R9"!N;VX@
M92<@8V]N9FEG=7)A=&\@8V]R<F5T=&%M96YT90!087-S=V]R9#H`4&%S<W=O
M<F0Z(`!,92!P87-S=V]R9"!D979O;F\@8V]R<FES<&]N9&5R92X`26YC;VQL
M80!097)C;W)S;P!296=I<W1R87II;VYI(&EN($%T=&5S83H`4&5R8V5N='5A
M;&4`17-E9W5I(&QE($]P97)A>FEO;FD@9&D@36%N=71E;GII;VYE`$5S96=U
M:2!L92!O<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N92!A;"!L;V=I;C\`4&5R
M;65S<VD`4&5R;65S<VD@)R5S)R!N;VX@96QI;6EN871I+@!!;6UI;FES=')A
M>FEO;F4@9&5I(%!E<FUE<W-I`$EN9F]R;6%Z:6]N:2!097)S;VYA;&D`1F]T
M;P!0:7AE;`!0<F5G;R!C;VYF97)M87)E(&5L:6UI;F%Z:6]N92!E;&5M96YT
M;SH`4')E9V\@8V]N9F5R;6%R92!E;&EM:6YA>FEO;F4@;&EN:SH`26YS97)I
M<V-I('5N(&YO;64@<&5R(&QA(&YU;W9A(&-A=&5G;W)I83H`1&5V:2!I;G-E
M<FER92!I;"!T=6\@;F]M92!U=&5N=&4@92!L82!P87-S=V]R9`!,96=G:2!I
M;"!S96=U96YT92!T97-T;RX@1$5622!A8V-E='1A<F4@:2!T97)M:6YI(&0[
M=7-O('!E<B!U=&EL:7IZ87)E(&EL('-I<W1E;6$N`%-O;F1A9V=I`%!O<VEZ
M:6]N86UE;G1O(&1I('%U97-T82!I;6UA9VEN92X`4&]S:7II;VYA;65N=&\@
M9&D@<75E<W1A('1A8F5L;&$`4&]S=&YU:V4`4')E<V5N=&%Z:6]N:0!0<F5S
M<VEO;F4`4')E<W-I;VYE(&%L(&QI=F5L;&\@9&D@;6%R93H@`%!R97-S:6]N
M93H@`$%N=&5P<FEM80!!;G1E<')I;6$@9&5L;"=I;6UA9VEN92!I;B!N=6]V
M82!F:6YE<W1R80!!='1I=FET82<@<')E8V5D96YT90!3=&%M<&$@9&]C=6UE
M;G1O(`!0<F]B;&5M80!$97-C<FEZ:6]N92!D96P@<')O8FQE;6$`4')O9V5T
M=&D`1&]M86YD80!0:6]G9VEA`%!I;V=G:6$@4')E<W1O`%!I;V=G:6$@5&%R
M9&D`1F]R='5N82!#87-U86QE`$QE9V=I`%-I8W5R;R!D:2!V;VQE<B!E;&EM
M:6-A<F4E<S\@3"=O<&5R87II;VYE(&YO;B!P=6\G(&5S<V5R92!A;FYU;&QA
M=&$`4VEC=7)O(&1I('9O;&5R(&5L:6UI;F%R92!I(&1A=&D@9&D@)7,_($PG
M;W!E<F%Z:6]N92!N;VX@<'5O)R!E<W-E<F4@86YN=6QL871A`$%G9VEO<FYA
M(&=L:2!%;&5M96YI(&1E;"!-96YU($1I;F%M:6-O`$%G9VEO<FYA(&QA('9I
M<W5A;&EZ>F%Z:6]N92!0;W)T86QE.@!.;W1E`%-E<G9E<B!296UO=&D`55),
M(')E;6]T82`H:'1T<#HO+W=W=RYE<V5M<&EO+F-O;2]H;W)D92DZ`$5L:6UI
M;F$`16QI;6EN82!B;&]C8V\`4FEM=6]V:2!&;W)M871T87II;VYE`$5L:6UI
M;F$@<&%I;P!%;&EM:6YA(&EL`$5L:6UI;F$@=71E;G1E`$5L:6UI;F$@=71E
M;G1E.B`E<P`G<&AP='EP92<@;F]N('-P96-I9FEC871O(&YE;&QA(&-O;F9I
M9W5R87II;VYE(%-13"!D96QL92!C871E9V]R:64N`%)I=F5N9&ET;W)E`$%N
M;G5L;&$`06YN=6QL82!087-S=V]R9`!!;FYU;&QA(&QA('1U82!087-S=V]R
M9`!2:7-U;'1A=&D`4FES=6QT871I("AI;F-L=7-O($AO<F1E*3H`4FES=6QT
M871I.@!4;W)N82!A;&QE($]P>FEO;FDN`$EN=F5R=&D@;&$@0V]N9FEG=7)A
M>FEO;F4`3W!Z:6]N:2!%9&ET;W(@4FEC:"!497AT`%)I9&1L97,`1&5S=')A
M`%!R;W!R:65TX"!D96QL82!27VEG82XN+@!0<F]P<FEE=&$@9&5L;&$@<FEG
M80!0<F]P<FEE=.`@9&5L;&$@<FEG80!2:6=H93H`4F5G;VQE`$5S96=U:0!-
M97-S86=G:2!335,`4V%B`%-A;'9A`%-A;'9A("5S`%-A;'9A("<E<R<`4V%L
M=F$@3W!Z:6]N:0!386QV82!L82!C;VYF:6=U<F%Z:6]N92!G96YE<F%T92!C
M;VUE('-C<FEP="!02%`@<W5L;&$@8V%R=&5L;&$@=&5M<&]R86YE82!D96P@
M='5O('-E<G9E<BX`4V%L=F%T;R!L82!C;VYF:6=U<F%Z:6]N92`E<RX`4V%L
M=F%T;R!I;"!S8W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96P@<V5T=7`@83H@
M)R5S)RX`4FEC97)C80!-;W1O<F4@9&D@<FEC97)C80!#97)C86YD;R!A<'!L
M:6-A>FEO;FD@2&]R9&4@:6X@)7,`4VQE>FEO;F$@=6X@9W)U<'!O(&1A(&%G
M9VEU;F=E<F4`4V5L97II;VYA('5N(&YU;W9O('!R;W!R:65T87)I;P!396QE
M>FEO;F$@=6X@<V5R=F5R`%-E;&5Z:6]N82!U;B!U=&5N=&4@9&$@86=G:75N
M9V5R90!396QE>FEO;F$@:2!C87)A='1E<FD@9&D@8W5I(&AA:2!B:7-O9VYO
M(&1A;&QE(&-A<V5L;&4@<75I('-O='1O+B!0=6]I('%U:6YD:2!C;W!I87)L
M92!E(&EN8V]L;&%R;&4@9&%L;&$@=&5X=&%R96$N`%-E;&5Z:6]N82!I;"!D
M96QI;6ET871O<F4@9&D@9&%T83H`4V5S8V5G;&D@:6P@9F]R;6%T;R!D96QL
M82!D871A.@!396QE>FEO;F$@;"=I9&5N=&ETX"!D82!M;V1I9FEC87)E.@!3
M96QE>FEO;F$@:6P@9&5L:6UI=&%T;W)E(&1E;&PG;W)A.@!38V5G;&D@:6P@
M9F]R;6%T;R!D96QL)V]R83H`4V5L97II;VYA(&1U92!C86UP:2!C;W)R:7-P
M;VYD96YT:2X`4V5L97II;VYA(&EL('1U;R!S8VAE;6$@8V]L;W)I+@!396QE
M>FEO;F$@;&$@;&EN9W5A(&-H92!P<F5F97)I<V-I.@!);G9I82!I;"!R97!O
M<G0@9&5L('!R;V)L96UA`%-E;G-O<F4Z(`!3971T96UB<F4`26UP;W-T:2!I
M('-E<G9E<B!R96UO=&D@86D@<75A;&D@=G5O:2!A8V-E9&5R92!D86P@='5O
M('!O<G1A;&4N`%-E;&5Z:6]N82!L82!L:6YG=6$@<')E9F5R:71A(&4@:6P@
M9G5S;R!O<F%R:6\N`$UO9&EF:6-A(&QA('1U82!A<'!L:6-A>FEO;F4@9&D@
M879V:6\L(&=L:2!S8VAE;6D@8V]L;W)E+"!E9"!A;'1R92!O<'II;VYI(&1I
M('9I<W5A;&EZ>F%Z:6]N92X`4V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L
M('-E='5P(&1I<W!O;FEB:6QE`%-H;W!P:6YG`$)R979E(%)I87-S=6YT;P!$
M969I;FEA;6\@9VQI(&%C8V5S<VD@9&$@=&%S=&EE<F$@<&5R(&D@;&EN:S\`
M36]S=')A`$UO<W1R82!L)W5L=&EM;R!L;V=I;B!A;&PG86-C97-S;S\`36]S
M=')A('1A8F5L;&$@;W!E<F%Z:6]N:2!N96QL82!B87)R82!D96P@;65N=3\`
M36]S=')A(&EL("5S($UE;F\@<W5L;&$@<VEN:7-T<F$_`$UO<W1R82!L92!0
M<F]P<FEE=.`@5&%B96QL82!#96QL80!-;W-T<F$@;&4@4')O<')I973@(%1A
M8F5L;&$`36]S=')A(&QE(%!R;W!R:65TX"!486)E;&QA(%)I9V$`06-Q=6%Z
M>F]N:0!!8W%U87IZ;VYI(&$@0G)E=F4`06-Q=6%Z>F]N:2!487)D:0!)<V-R
M:79I=&D@<V4@;F]N('-E:2!R96=I<W1R871O`%-A;'1A($UA;G5T96YZ:6]N
M90!386QT871O+BXN`%!R;V9O;F1I=&$G(&1I(&YE=F4Z(`!3<&%Z:6%T=7)A
M`%-P86T`0V%R871T97)E(%-P96-I86QE`$1I=FED:2!#96QL80!$:79I9&D@
M8V]L;VYN80!$:79I9&D@4FEG80!3=&%N9&%R9`!3=&%T;P!3=&%T;R!L;V-A
M;&4@)7,N+BX@`$1O;0!);G9I871O(&QA(')I8VAI97-T82!P97(@86=G:75N
M9V5R92`G)7,G(&%L('-I<W1E;6$N($YO;B!P=6]I(&9A<F4@=6X@;&]G:6X@
M9FEN8VAE)R!N;VX@92<@<W1A=&$@87!P<F]V871A+@!3;W1T;W-C<FEV:0!3
M=6-C97-S;P!!9V=I=6YT;R`G)7,G(&%L('-I<W1E;6$N`$1A=&D@9&D@)R5S
M)R!E;&EM:6YA=&D@9&%L('-I<W1E;6$N`"<E<R<@96QI;6EN871O(&-O;B!S
M=6-C97-S;RX`4FEM;W-S;R`G)7,G(&1A;"!S:7-T96UA+@!386QV871O(&QA
M(&-O;F9I9W5R87II;VYE+@`G)7,G(&%G9VEO<FYA=&\@8V]N('-U8V-E<W-O
M`%-C<FET=&\@8V]N('-U8V-E<W-O("5S`%)I87-S=6YT;P!!;&)A`%1R86UO
M;G1O`$%L8F$`06QB82]4<F%M;VYT;P!!;&)A.B``5')A;6]N=&\`5')A;6]N
M=&\Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T;P!4+51E;7!E<W1A`%0M5&5M<&5S
M=&4`4')O<')I973@(%1A8F5L;&$`4')O<')I973@(%1A8F5L;&$`1&5S=&EN
M87II;VYE.@!!='1I=FETX`!!='1I=FETX`!4;W1A;&4`5&5M<&5R871U<F$@
M=6QT:6UA(&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``06UM:6YI
M<W1R87II;VYE(%1E;7!L871E`%-O;&\@5&5S=&\`06QL:6YE86UE;G1O('1E
M<W1O`%1E<W1O(&EN(&%L=&\`1VEO`$=R87II92!D:2!A=F5R('5S871O(&EL
M('-I<W1E;6$N`$EL(&9I;&4@9&D@86EU=&\@)7,@<&5R("5S(&YO;B!E<VES
M=&4@86YC;W)A+B!);B!#<F5A>FEO;F4N`$EL(&QI;FL@)7,@82`E<R#H('-T
M871O(&5L:6UI;F%T;RX`26P@9FEL92!D:2!A:75T;R`E<R!N;VX@:6YZ:6%Z
M(&-O;B`\/WAM;`!,)VED96YT:73@("(E<R(@92<@<W1A=&$@96QI;6EN871A
M+@!);"!C;VQL96=A;65N=&\@Z"!S=&%T;R!R:6UO<W-O+@!);"!S97)V97(@
M(B5S(B!E)R!S=&%T;R!E;&EM:6YA=&\N`$EL('-E<G9E<B`B)7,B(&4G('-T
M871O('-A;'9A=&\N`$QA(')I8VAI97-T82!D:2!R96=I<W1R87II;VYE('!E
M<B`E<R#H('-T871A(&5L:6UI;F%T82X`26P@;6]D=6QO('=E871H97(N8V]M
M(&YO;B#H(&1I<W!O;FEB:6QE+@!.;VYE('-I<W1E(&%N8V]R82!U;B!F:6QE
M(&1I(&%I=71O('!E<B`E<RX`4VD@Z"!V97)I9FEC871O('5N('!R;V)L96UA
M(&%G9VEU;F=E;F1O("<E<R<@86P@<VES=&5M82X@)7,N`%-I(.@@=F5R:69I
M8V%T;R!U;B!P<F]B;&5M82!A9V=I=6YG96YD;R`G)7,G(&%L('-I<W1E;6$N
M("5S+@!3:2#H('9E<FEF:6-A=&\@=6X@<')O8FQE;6$@<FEM=6]V96YD;R`G
M)7,G(&1A;"!S:7-T96UA+@!3:2#H('9E<FEF:6-A=&\@=6X@<')O8FQE;6$@
M<FEM=6]V96YD;R`G)7,G(&1A;"!S:7-T96UA+@!3:2#H('9E<FEF:6-A=&\@
M=6X@<')O8FQE;6$@86=G:6]R;F%N9&\@)R5S)SH@)7,`17)R;W)E(&YE;&PG
M87!E<G1U82!D96P@9FEL92`E<RX@4')O=F$@82!E<V5G=6ER92!T<F%N<VQA
M=&EO;BYP:'`@8V]N(&EL(&9L86<@+60@<&5R('9I<W5A;&EZ>F%R92!M97-S
M86=G:2!D:2!E<G)O<F4@9&%L('!A<G-E<B!X;6PN`%%U97-T;R!E)R`E<RX`
M5'5O;F\`5&EC:V5T`$=E<W1I;VYE(&1E;"!496UP;P!&;W)M871O($]R80!4
M:71O;&\`3V=G:0!$;VUA;FD`06QT;P!4<F%D;W1T;P!-87(`55),`%523#H`
M26UP;W-S:6)I;&4@8V]N;F5T=&5R<VD@86P@<V5R=F5R(%-13"X`26UP;W-S
M:6)I;&4@8V%N8V5L;&%R92`G)7,G.B`E<RX`4V]T=&]L:6YE80!!;FYU;&QA
M(&QE($UO9&EF:6-H90!);F1E9FEN:71O`%5N:73@`$-O;6%N9&\@<V-O;F]S
M8VEU=&\Z("5S`$5L:6UI;F$@16QE;65N=&\@0V]R<F5N=&4`16QI;6EN82!#
M;VQO<F4`3F]N('1R861O='1O`$%G9VEO<FYA`$%G9VEO<FYA("5S`$%G9VEO
M<FYA('5T96YT90!!9V=I;W)N871O("<E<R<`06=G:6]R;F%M96YT;R!F:6QE
M(&1I(&AE;'`@)7,@<&5R("5S+@!!9V=I;W)N86YD;VEN(&-O<G-O+BXN`%-C
M<FEP="!D:2!A9V=I;W)N86UE;G1O(&5L:6UI;F%T;RX`06=G:6]R;F$`3G5M
M97(@<F]M86YI(&%L=&D`571I;&EZ>F\Z`%5T:6QI>GIA(&EL('9A;&]R92!D
M:2!D969A=6QT`%5T:6QI>GIA('-E(&YO;64O<&%S<W=O<F0@92!D:69F97)E
M;G1E('!E<B!I;"!S97)V97(@24U34`!!;6UI;FES=')A>FEO;F4@571E;G1I
M`%)E9VES=')A>FEO;F4@571E;G1E`$ES8W)I>FEO;F4@571E;G1E(&4G('-T
M871O(&1I<V%B:6QI=&%T;R!P97(@<75E<W1O('-I=&\N`%5T96YT92!N;VX@
M=')O=F%T;P!5=&5N=&4@;F]N('1R;W9A=&\N`%!E<FUE<W-I('5T96YT90!.
M;VUE(%5T96YT90!.;VUE('5T96YT93H`3F]M92!5=&5N=&4Z`%5T96YT:2!N
M96P@<VES=&5M83H`5F%C86YT90!687)I86)I;&4`0V]N=')O;&QO(%9E<G-I
M;VYE`$%L;&EN96%M96YT;P!2:65M<&EM96YT;R!697)T:6-A;&4`5F5R=&EC
M86QE.@!-;VQT;R!!;'1O`%9I<W5A;&EZ>F$@=6YA('!A9VEN82!W96(@97-T
M97)N80!6:7-I8FEL:73@`%9I<VEB:6QI=.`Z(`!!='1E;GII;VYE.@!-97(`
M4')E=FES:6]N92!-971E;P!796(`0F5N=F5N=71O`$)E;G9E;G5T;R!A("5S
M`$)E;G9E;G5T;RP@)7,`0VAE(&%P<&QI8V%Z:6]N92`E<R!D979E(&UO<W1R
M87)E(&1O<&\@:6P@;&]G:6X_`$-O<V$@92<@8V%R871T97)E(&1E;&EM:71A
M=&]R90!#;W-A(&4G(&EL(&-A<F%T=&5R92!V:7)G;VQE='1E/P!0;'5G:6YS
M(&1A(&1I<V%B:6QI=&%R92!P97(@;"=E9&ET;W(@4FEC:"!497AT`$QA<F=H
M97IZ80!,87)G:&5Z>F$@9&5L(&UE;G4@9&D@)7,@<W5L;&$@<VEN:7-T<F$@
M*&5F9F5T=&\@86P@<')O<W-I;6\@;&]G+6EN*3H`06UP:65Z>F$@9&5L;&$@
M=&%B96QL80!5;FETX"!,87)G:&5Z>F$`3&%R9VAE>GIA.@!696YT;SH`5F5N
M=&\Z(`!,:7-T82!D96D@9&5S:61E<FD`4V-R:71T=7)A(&1E;"!F:6QE(&%I
M=71O(&%G9VEO<FYA=&\@:6X@)7,N`$%!`%-I+"!S;VYO(&0G86-C;W)D;P!.
M;VX@<'5O:2!C86UB:6%R92!L82!P87-S=V]R9"!P97(@;"=U=&5N=&4@)7,`
M3&$@<V5S<VEO;F4@Z"!S=&%T82!T97)M:6YA=&$N`$1E=FD@:6YS97)I<F4@
M;&$@='5A('!A<W-W;W)D(&%T='5A;&4`1&5V:2!I;G-E<FER92!L82!T=6$@
M;G5O=F$@<&%S<W=O<F0`1&5V:2!S<&5C:69I8V%R92!I;"!S97)V97(@9&$@
M96QI;6EN87)E+@!$979I('-P96-I9FEC87)E(&QO('5S97)N86UE(&1A(')I
M;75O=F5R92X`1&5V:2!S<&5C:69I8V%R92!L;R!U<V5R;F%M92!D82!R:6UU
M;W9E<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@9&$@86=G:75N
M9V5R92X`1&5V:2!S<&5C:69I8V%R92!L;R!U<V5R;F%M92!D82!A9V=I;W)N
M87)E+@!$979I(&EN<V5R:7)E(&QA('1U82!N=6]V82!P87-S=V]R9"!N96QL
M82!V97)I9FEC80!4=6\@26YD:7)I>GIO($5M86EL`%1U;R!);F1I<FEZ>F\@
M16UA:6P`5F]S=')A(&EN9F]R;6%Z:6]N90!);"!T=6\@;F]M90!);"!T=6\@
M8F%C:V5N9"!D:2!A=71E;G1I8V%Z:6]N92!N;VX@<W5P<&]R=&$@;&$@86=G
M:75N=&$@9&D@=71E;G1I+"!O(&QA(&-A<F%T=&5R:7-T:6-A(.@@<W1A=&$@
M9&ES86)I;&ET871A('!E<B!Q=6%L8VAE(&UO=&EV;RX`26P@='5O(&)A8VME
M;F0@9&D@875T96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A(&QA(&5L96YC87II
M;VYE(&1E9VQI('5T96YT:2P@;R!L82!C87)A='1E<FES=&EC82#H('-T871A
M(&1I<V%B:6QI=&%T82!P97(@<75A;&-H92!M;W1I=F\N`$EL('1U;R!B<F]W
M<V5R(&YO;B!H82!Q=65S=&$@8V%P86)I;&ET82<N`$EL('1U;R!B<F]W<V5R
M(&YO;B!S=7!P;W)T82!L82!V:7-U86QI>GIA>FEO;F4@:6YL:6YE(&1I('%U
M97-T;R!T:7!O(&1I(&EM;6%G:6YE`$EL('1U;R!F=7-O(&]R87)I;R!A='1U
M86QE.@!)9&5N=&ETX"!D:2!$969A=6QT`$EL('1U;R!N;VUE.@!,82!T=6$@
M<&%S<W=O<F0@92<@=')O<'!O(&QU;F=A.R!U;F$@<&%S<W=O<F0@;F]N('!U
M;R<@97-S97)E('!I=2<@9&D@)60@8V%R871T97)I(0!,82!T=6$@<&%S<W=O
M<F0@92<@=')O<'!O(&9A8VEL92!A9"!I;F1O=FEN87)E(2!.;VX@92<@<W1A
M=&$@8V%M8FEA=&$A`$QA('1U82!P87-S=V]R9"!D979E(&5S<V5R92!L=6YG
M82!M:6YI;6\@)60@8V%R871T97)I(0!,82!T=6$@;G5O=F$@<&%S<W=O<F0@
M9&5V92!E<W-E<F4@9&EF9F5R96YT92!D86QL82!V96-C:&EA+@!,82!T=6$@
M;G5O=F$@<&%S<W=O<F0@9&5V92!C;VYT96YE<F4@;6EN:6UO("5D(&QE='1E
M<F4N`$QA('1U82!N=6]V82!P87-S=V]R9"!D979E(&-O;G1E;F5R92!M:6YI
M;6\@)60@8V%R871T97)I(&%L<&AA;G5M97)I8VDN`$QA('1U82!N=6]V82!P
M87-S=V]R9"!D979E(&-O;G1E;F5R92!M:6YI;6\@)60@8V%R871T97)I(&UI
M;G5S8V]L:2X`3&$@='5A(&YU;W9A('!A<W-W;W)D(&1E=F4@8V]N=&5N97)E
M(&UI;FEM;R`E9"!C87)A='1E<FD@;G5M97)I8VDN`$QA('1U82!N=6]V82!P
M87-S=V]R9"!D979E(&-O;G1E;F5R92!M:6YI;6\@)60@8V%R871T97)I(&UA
M:75S8V]L:2X`3&$@='5A(&YU;W9A('!A<W-W;W)D(&1E=F4@8V]N=&5N97)E
M(&UE;F\@9&D@)60@8V%R871T97)I(&1E;"!T:7!O('-P87II(&)I86YC:&DN
M`$QA('1U82!N=6]V82!P87-S=V]R9"!N;VX@<'7R(&-O;G1E;F5R92!C87)A
M='1E<FD@9&5L('1I<&\@<W!A>FD@8FEA;F-H:2X`3&4@9'5E(&YU;W9E('!A
M<W-W;W)D('-O;F\@9&EF9F5R96YT:0!)('1U;VD@<V5R=F5R(')E;6]T:3H`
M6T1O8W5M96YT;R!D:2!D97-C<FEZ:6]N92!D96P@<')O8FQE;6%=`%M-;W-T
M<F$@5&5S=&\@<75O=&%T;R`M`%]!;6UI;FES=')A>FEO;F4`7T-O;F9I9W5R
M87II;VYE`%]$871A5')E90!?16QI;6EN82!2:6=A`%]'<G5P<&D`7T%I=71O
M`%!R;W!R:65TX"!D96QL)U]);6UA9VEN92XN+@!?1FEN92!S97-S:6]N90!?
M36]D:69I8V$@3&EN:RXN+CH`7T]P>FEO;FD`7U!E<FUE<W-I`%]%;&EM:6YA
M($QI;FLN+BX`4')O<')I973@(&1E;&QA(%]486)E;&QA`%]5=&5N=&D`92<@
M879V96YU=&\@=6X@97)R;W)E`&-A;&UO`&9A='1O`&9A;&QI=&\`=')O=F%T
M;SH`9&%L;&4@)7,@*"5S*2!A;&QE("5S("5S`&DQ.&X`;&1A<%]S=&%R=%]T
M;',@9F%L:71O`&QI;F5E70!N;VUE`&YO;B!M;V1I9FEC871O`&YO;B!T<F]V
M871O`'!E<F-E;G1O`'!I>&5L<P!A=6UE;G1A;F1O)P!C;W-T86YT90!I;"!F
M:6QE(%!/(&1I($AO<F1E('!E<B!L82!L:6YG=6$@)7,@;F]N(&5S:7-T93H`
M9&EG:71A(&QA('!A<W-W;W)D(&1U92!V;VQT92!P97(@8V]N9F5R;6%R90!A
M9V=I;W)N871O`'=E871H97(N8V]M````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W
M9"]L;V-A;&4O;'1?3%0O````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(P,C`R`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]L=%],5"],0U]-15-304=%4R\`
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P
M,C$W-C<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+VQT
M7TQ4+TQ#7TU%4U-!1T53+W!A<W-W9"YM;P``````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#`P
M,3,W`#$P-#$W,S8R-S0T`#`R,S8R-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````$X'```<````C#H``,<)``#\
M=````````!B<``!(````&9P```X```!BG```#P```'&<```(````@9P```P`
M``"*G```!````)><```,````G)P```\```"IG```"P```+F<```1````Q9P`
M`!````#7G```#@```.B<```%````]YP``"@```#]G```"@```":=```5````
M,9T``!(```!'G0``"P```%J=```4````9IT``"8```![G0``)P```**=```F
M````RIT```X```#QG0``"@````">```-````"YX``"<````9G@``(````$&>
M```.````8IX``!<```!QG@``(@```(F>```U````K)X``!$```#BG@``#0``
M`/2>```,`````I\```T````/GP``!@```!V?```=````))\``!L```!"GP``
M+0```%Z?```=````C)\``"0```"JGP``*0```,^?```9````^9\```\````3
MH```&````".@```,````/*````X```!)H```#@```%B@```(````9Z```"X`
M``!PH```&@```)^@```R````NJ```#@```#MH```5````":A``!1````>Z$`
M`%H```#-H0``5P```"BB```T````@*(```X```"UH@``"@```,2B```%````
MSZ(```8```#5H@``$0```-RB```(````[J(```D```#WH@``"0````&C```.
M````"Z,```@````:HP``#@```".C```E````,J,``"````!8HP``$````'FC
M```/````BJ,```H```":HP``!P```*6C```#````K:,```\```"QHP``%```
M`,&C```)````UJ,```T```#@HP``$@```.ZC```9`````:0``!X````;I```
M#P```#JD```*````2J0```\```!5I```"````&6D```D````;J0``!<```"3
MI```%````*ND```6````P*0```@```#7I```3@```."D```M````+Z4``!D`
M``!=I0``!P```'>E```,````?Z4``"P```",I0``#@```+FE```#````R*4`
M``L```#,I0``!P```-BE```'````X*4```4```#HI0``!0```.ZE```*````
M]*4```,```#_I0``%P````.F```*````&Z8```\````FI@``#@```#:F```8
M````1:8``",```!>I@``#@```(*F```4````D:8``!<```"FI@``%P```+ZF
M```7````UJ8``!,```#NI@``#P````*G```.````$J<``!\````AIP``!P``
M`$&G```&````2:<```@```!0IP``#P```%FG```&````::<```H```!PIP``
M$P```'NG```+````CZ<``!4```";IP``%0```+&G```'````QZ<```4```#/
MIP``%0```-6G```1````ZZ<```P```#]IP``.P````JH```X````1J@```D`
M``!_J```!P```(FH```4````D:@```,```"FJ```!0```*JH```0````L*@`
M``D```#!J```$P```,NH```Y````WZ@``!(````9J0``.0```"RI```G````
M9JD``"P```".J0``*@```+NI```E````YJD```D````,J@``"@```!:J```&
M````(:H```D````HJ@``!P```#*J```O````.JH``#<```!JJ@``+@```**J
M``!5````T:H``"T````GJP``+0```%6K```M````@ZL``$````"QJP``(P``
M`/*K```C````%JP``"T````ZK```,P```&BL```5````G*P``!D```"RK```
M*0```,RL```D````]JP``!$````;K0``$0```"VM```*````/ZT```P```!*
MK0``(@```%>M```*````>JT``!````"%K0``%@```):M```6````K:T```<`
M``#$K0``!P```,RM```4````U*T```H```#IK0``"````/2M```$````_:T`
M``@````"K@``!P````NN```'````$ZX```8````;K@``!0```"*N```'````
M**X```8````PK@``"````#>N```.````0*X```H```!/K@``#P```%JN```$
M````:JX```<```!OK@``"0```'>N```&````@:X``!$```"(K@``!P```)JN
M```6````HJX```0```"YK@``"````+ZN```&````QZX```T```#.K@``!@``
M`-RN```>````XZX``!$````"KP``"````!2O```-````':\```P````KKP``
M!P```#BO```#````0*\```,```!$KP``%P```$BO```3````8*\```@```!T
MKP``!````'VO```(````@J\```@```"+KP``00```)2O```@````UJ\```8`
M``#WKP``!@```/ZO```5````!;```!@````;L```(@```#2P```N````5[``
M`!T```"&L```(0```*2P``!4````QK```"D````;L0``"@```$6Q```'````
M4+$``!4```!8L0``#@```&ZQ```*````?;$```\```"(L0``#0```)BQ```/
M````IK$```T```"VL0``"0```,2Q```4````SK$```8```#CL0``&````.JQ
M```=`````[(``!,````AL@``%````#6R```$````2K(```P```!/L@``!@``
M`%RR```/````8[(``!,```!SL@``5````(>R```4````W+(``!<```#QL@``
M!`````FS```.````#K,``$0````=LP``!0```&*S```%````:+,``!L```!N
MLP``&@```(JS```1````I;,``!$```"WLP``$0```,FS```<````V[,``"H`
M``#XLP``$````".T```A````-+0```4```!6M```$P```%RT```2````<+0`
M``H```"#M```#P```(ZT```1````GK0``!,```"PM```#````,2T```&````
MT;0```8```#8M```%P```-^T```1````][0```@````)M0``!0```!*U```,
M````&+4``!`````EM0``!0```#:U```-````/+4```8```!*M0``!P```%&U
M```-````6;4```<```!GM0``"P```&^U```'````>[4```<```"#M0``"0``
M`(NU```4````E;4```D```"JM0``"@```+2U```9````O[4``!T```#9M0``
M#````/>U```0````!+8``!4````5M@``!0```"NV```E````,;8``!(```!7
MM@``$P```&JV```K````?K8``#L```"JM@``(````.:V```V````![<``!``
M```^MP``"````$^W```,````6+<```8```!EMP``!````&RW```.````<;<`
M``H```"`MP``#0```(NW```>````F;<``!L```"XMP``(0```-2W```>````
M]K<``!D````5N```'@```"^X```=````3K@``"T```!LN```&P```)JX```@
M````MK@``"X```#7N```)@````:Y```;````+;D``!X```!)N0``'````&BY
M```F````A;D``"L```"LN0``,P```-BY```F````#+H``"L````SN@``.```
M`%^Z```=````F+H``!4```"VN@``+P```,RZ```2````_+H``"`````/NP``
M*0```#"[```>````6KL``"$```!YNP``$@```)N[``"B````KKL``!8```!1
MO```(P```&B\```H````C+P``"D```"UO```*````-^\```?````"+T``!4`
M```HO0``(````#Z]```E````7[T``"D```"%O0``+0```*^]```A````W;T`
M`!8```#_O0``'````!:^```F````,[X``"H```!:O@``00```(6^``!$````
MQ[X```P````,OP``!P```!F_```'````(;\```8````IOP``#0```#"_```0
M````/K\``!(```!/OP``$P```&*_```2````=K\```<```")OP``!````)&_
M```-````EK\```P```"DOP``#@```+&_```/````P+\``!,```#0OP``#0``
M`.2_```H````\K\```,````;P```#0```!_````&````+<```!$````TP```
M%P```$;````;````7L````X```!ZP````@```(G````%````C,````0```"2
MP```$````)?````$````J,````T```"MP```#@```+O````#````RL````X`
M``#.P```"````-W````/````YL````@```#VP```#P```/_````-````#\$`
M`!`````=P0``$P```"[!```3````0L$```L```!6P0``$0```&+!```)````
M=,$```8```!^P0``#````(7!```1````DL$``!D```"DP0``"P```+[!```-
M````RL$``"(```#8P0``&P```/O!```T````%\(```H```!,P@``&````%?"
M```9````<,(``!8```"*P@``+P```*'"```B````T<(```T```#TP@``!P``
M``+#```,````"L,``"8````7PP``%````#[#```+````4\,``"(```!?PP``
M+P```(+#```+````LL,```D```"^PP``&0```,C#```+````XL,``!<```#N
MPP``%P````;$```)````'L0``!8````HQ```#P```#_$```6````3\0```X`
M``!FQ```&````'7$```(````CL0```T```"7Q```)@```*7$``!#````S,0`
M``@````0Q0``$@```!G%```(````+,4```L````UQ0``+P```$'%```.````
M<<4```4```"`Q0``!@```(;%```#````C<4```<```"1Q0``!````)G%```*
M````GL4```H```"IQ0``#P```+3%```0````Q,4``!<```#5Q0``$0```.W%
M```7````_\4``!D````7Q@``"0```#'&```%````.\8```L```!!Q@``"@``
M`$W&```"````6,8```4```!;Q@``#0```&'&```;````;\8``!<```"+Q@``
M"0```*/&```.````K<8```T```"\Q@``$@```,K&```X````W<8``"`````6
MQP```P```#?'```(````.\<```X```!$QP``>P```%/'```8````S\<``!$`
M``#HQP``!P```/K'```%`````L@``"`````(R```&````"G(```9````0L@`
M`!,```!<R```!P```'#(```(````>,@```8```"!R```!@```(C(```0````
MC\@```\```"@R```$````+#(```/````P<@```L```#1R```#P```-W(```,
M````[<@```\```#ZR```!P````K)```&````$LD```P````9R0``*````";)
M```/````3\D```@```!?R0``"````&C)```3````<<D``!X```"%R0``(0``
M`*3)```@````QLD``!D```#GR0``%P````'*```E````&<H``!<````_R@``
M'@```%?*```F````=LH```0```"=R@``&P```*+*```-````OLH```P```#,
MR@```P```-G*```(````W<H```H```#FR@``#````/'*```+````_LH```0`
M```*RP``$P````_+```4````(\L```P````XRP``"0```$7+```.````3\L`
M``L```!>RP``&P```&K+```'````ALL```<```".RP``"@```);+```-````
MH<L```D```"ORP``!````+G+```%````OLL```,```#$RP``&````,C+```*
M````X<L```0```#LRP``)@```/'+```.````&,P``'P````GS```%0```*3,
M```%````NLP```<```#`S```#````,C,```(````U<P```H```#>S```!@``
M`.G,```(````\,P```(```#YS```!@```/S,```&`````\T``!0````*S0``
M%0```!_-```/````-<T``!$```!%S0``&@```%?-```-````<LT``!````"`
MS0``&P```)'-```$````K<T```D```"RS0``$````+S-```)````S<T```D`
M``#7S0``!0```.'-```:````Y\T```@````"S@``!@````O.```9````$LX`
M``X````LS@``!P```#O.```'````0\X```4```!+S@``"0```%'.```*````
M6\X```(```!FS@``!@```&G.```-````<,X```D```!^S@``!@```(C.```2
M````C\X```D```"BS@``!P```*S.```4````M,X``!T```#)S@``$0```.?.
M```&````^<X```H`````SP``!`````O/```)````$,\```@````:SP``$0``
M`"//```1````-<\```D```!'SP``!@```%'/```-````6,\```8```!FSP``
M`@```&W/```$````<,\``#D```!USP``/0```*_/```Z````[<\``!X````H
MT```!0```$?0```.````3=````0```!<T```!@```&'0```A````:-```!4`
M``"*T```!@```*#0```$````I]```!$```"LT```!@```+[0```*````Q=``
M`"(```#0T```!````//0```E````^-````4````>T0``'0```"31```$````
M0M$```P```!'T0``"@```%31```(````7]$```D```!HT0``!0```'+1```Z
M````>-$``#````"ST0``-0```.31```I````&M(``"X```!$T@``1P```'/2
M```X````N](``"D```#TT@``/P```![3```N````7M,``"T```"-TP``'P``
M`+O3```/````V],``!(```#KTP``"P```/[3```F````"M0``"D````QU```
M)````%O4```F````@-0```@```"GU```"@```+#4```)````N]0```<```#%
MU```(````,W4```@````[M0``"8````/U0``"@```#;5```9````0=4``"D`
M``!;U0``%@```(75```2````G-4```<```"OU0``"@```+?5```/````PM4`
M`!````#2U0``0````./5``!F````)-8```X```"+U@``"0```)K6```*````
MI-8``!(```"OU@``$P```,+6```,````UM8```8```#CU@``#P```.K6```2
M````^M8``!`````-UP``"@```![7```1````*=<``!(````[UP``'````$[7
M```C````:]<``&H```"/UP``#P```/K7```%````"M@``!`````0V```"0``
M`"'8```$````*]@```L````PV```%````#S8```,````4=@```P```!>V```
M#P```&O8```5````>]@``"D```"1V```*@```+O8```F````YM@``"<````-
MV0``*0```#79```J````7]D``!D```"*V0``0@```*39```1````Y]D``!(`
M``#YV0``$P````S:```4````(-H```\````UV@``%@```$7:```7````7-H`
M`!````!TV@``$0```(7:```T````E]H``!,```#,V@``$@```.#:```U````
M\]H``!0````IVP``!P```#[;```,````1ML``"L```!3VP``(````'_;```4
M````H-L``!$```"UVP``%P```,?;```<````W]L``!,```#\VP``$0```!#<
M```:````(MP``!X````]W```&@```%S<```1````=]P``!<```")W```%```
M`*'<```7````MMP``!4```#.W```"0```.3<```9````[MP```0````(W0``
M!P````W=```+````%=T``!$````AW0``!@```#/=```&````.MT```8```!!
MW0``!0```$C=```'````3MT```<```!6W0``!0```%[=```6````9-T```8`
M``![W0``!@```(+=```$````B=T```0```".W0``!P```)/=```.````F]T`
M``P```"JW0``#````+?=```-````Q-T```H```#2W0``#@```-W=```%````
M[-T``"@```#RW0``#@```!O>```,````*MX```\````WW@``"@```$?>```(
M````4MX```D```!;W@``*P```&7>```$````D=X```@```"6W@``)@```)_>
M```2````QMX```\```#9W@``!@```.G>```*````\-X```<```#[W@``"```
M``/?```@````#-\```D````MWP``#````#??```-````1-\```X```!2WP``
M%@```&'?```1````>-\```8```"*WP```P```)'?```&````E=\``!D```"<
MWP``!P```+;?```$````OM\```L```##WP``"P```,_?```'````V]\```<`
M``#CWP``%@```.O?```-`````N````T````0X```"@```![@```1````*>``
M`!`````[X```#P```$S@```1````7.```!<```!NX```"@```(;@```1````
MD>````@```"CX```!````*S@```/````L>```#H```#!X```!0```/S@```,
M`````N$``!X````/X0``#@```"[A```0````/>$```L```!.X0``#````%KA
M```)````9^$```<```!QX0``"@```'GA```)````A.$```X```".X0``$```
M`)WA```:````KN$```H```#)X0``"0```-3A```*````WN$```P```#IX0``
M#P```/;A```(````!N(```8````/X@``!P```!;B```+````'N(``$<````J
MX@``#0```'+B```)````@.(```0```"*X@```P```(_B```3````D^(``!,`
M``"GX@``$P```+OB```*````S^(```(```#:X@``!````-WB```E````XN(`
M``,````(XP``!0````SC```J````$N,```H````]XP``!0```$CC```$````
M3N,```H```!3XP``#0```%[C```&````;.,```@```!SXP``"````'SC```$
M````A>,```4```"*XP``:````)#C```)````^>,```P````#Y```!0```!#D
M```&````%N0``!L````=Y```+P```#GD```0````:>0```H```!ZY```#P``
M`(7D```*````E>0```D```"@Y```$P```*KD```;````ON0``!@```#:Y```
M%P```//D```.````"^4```,````:Y0``!P```![E```(````)N4``!0````O
MY0``$P```$3E```0````6.4```T```!IY0``#@```'?E```6````AN4```<`
M``"=Y0``"@```*7E```+````L.4```<```"\Y0``40```,3E```0````%N8`
M``P````GY@``#0```#3F```:````0N8``$H```!=Y@``!@```*CF```:````
MK^8```8```#*Y@``!@```-'F```?````V.8```8```#XY@``"0```/_F```8
M````"><``!<````BYP``*````#KG```&````8^<```T```!JYP``(@```'CG
M``!7````F^<``!,```#SYP``(P````?H```3````*^@```(````_Z```"P``
M`$+H```(````3N@```T```!7Z```"@```&7H```'````<.@``!0```!XZ```
M!@```(WH```(````E.@```X```"=Z```!P```*SH```*````M.@```L```"_
MZ```!P```,OH```,````T^@```T```#@Z```#````.[H```)````^^@```D`
M```%Z0``"@````_I```'````&ND```D````BZ0``!P```"SI```*````-.D`
M`!L````_Z0``$@```%OI```*````;ND```D```!YZ0``$````(/I```'````
ME.D``!(```"<Z0``!````*_I```'````M.D```4```"\Z0``#````,+I```%
M````S^D```L```#5Z0``%````.'I```1````]ND``!H````(Z@``%@```"/J
M```4````.NH``!<```!/Z@``&````&?J```<````@.H``!D```"=Z@``!P``
M`+?J```%````O^H```T```#%Z@``#````-/J```(````X.H``!<```#IZ@``
M"P````'K```-````#>L``!,````;ZP``!````"_K```*````-.L```0````_
MZP``"0```$3K```*````3NL```P```!9ZP``"0```&;K```%````<.L```<`
M``!VZP``!0```'[K```$````A.L```(```")ZP``.````(SK```L````Q>L`
M`!(```#RZP``*0````7L```R````+^P```H```!B[```-@```&WL```L````
MI.P``"X```#1[```,P````#M```S````-.T``#@```!H[0``#P```*'M```8
M````L>T``!````#*[0``$P```-OM```4````[^T``!(````$[@``%````!?N
M```5````+.X``"T```!"[@``+0```'#N```Q````GNX``"T```#0[@``+@``
M`/[N```O````+>\``"P```!=[P``8@```(KO```3````[>\```@````!\```
M"`````KP```;````$_```"L````O\```(0```%OP```:````??````D```"8
M\```10```*+P``!!````Z/````\````J\0``!````#KQ```3````/_$``!0`
M``!3\0``#@```&CQ```3````=_$``!@```"+\0``!@```*3Q```)````J_$`
M``H```"U\0``#P```,#Q```0````T/$```<```#A\0``#@```.GQ```%````
M^/$``!L```#^\0``!@```!KR```(````(?(```8````J\@``%````#'R```1
M````1O(```X```!8\@``.````&?R```"````H/(```8```"C\@``#@```*KR
M```:````N?(```4```#4\@``!P```-KR```.````XO(```8```#Q\@``#0``
M`/CR```$````!O,``"D````+\P``%P```#7S```?````3?,``%P```!M\P``
M%````,KS```?````W_,``!````#_\P``%````!#T```'````)?0```X````M
M]```#````#ST```,````2?0``!,```!6]```"@```&KT```=````=?0``!D`
M``"3]```!0```*WT```1````L_0``!$```#%]```)````-?T```5````_/0`
M`!(````2]0``#@```"7U```9````-/4```@```!.]0``"0```%?U```-````
M8?4```H```!O]0``"P```'KU```*````AO4```<```"1]0``"````)GU```%
M````HO4``!\```"H]0``!@```,CU```0````S_4```@```#@]0``#0```.GU
M```B````]_4```@````:]@``%P```"/V```2````._8``"P```!.]@``+P``
M`'OV```L````J_8``"H```#8]@``*P````/W```L````+_<``!H```!<]P``
M"0```'?W```*````@?<``!4```",]P``!0```*+W```4````J/<```0```"]
M]P``$````,+W```&````T_<```<```#:]P``'@```.+W```H`````?@```H`
M```J^```'````#7X```:````4O@```\```!M^```%````'WX```$````DO@`
M``0```"7^```"P```)SX```%````J/@```8```"N^```"````+7X```&````
MOO@```H```#%^```&P```-#X```T````[/@``#0````A^0``(````%;Y```I
M````=_D``"````"A^0``00```,+Y```:````!/H``"@````?^@``*0```$CZ
M``!1````<OH``%<```#$^@``+````!S[```B````2?L```8```!L^P``"```
M`'/[```%````?/L```@```""^P``&0```(O[```9````I?L``"H```"_^P``
M(P```.K[```N````#OP``#0````]_```#0```'+\```(````@/P``!<```")
M_```"@```*'\```'````K/P``"$```"T_```#0```-;\```0````Y/P```X`
M``#U_```"P````3]```'````$/T``!,````8_0``"````"S]```+````-?T`
M``H```!!_0``%````$S]```R````8?T```L```"4_0``!0```*#]```%````
MIOT``!<```"L_0``#P```,3]```$````U/T```L```#9_0``$P```.7]```+
M````^?T```H````%_@``"0```!#^```+````&OX```X````F_@``!0```#7^
M```$````._X```T```!`_@``,@```$[^``!%````@?X``!<```#'_@``'@``
M`-_^```4````_OX```4````3_P``%````!G_```'````+O\``",````V_P``
M#@```%K_```J````:?\```8```"4_P``#````)O_```-````J/\``!$```"V
M_P``%P```,C_```+````X/\``#8```#L_P``"@```",``0`B````+@`!``L`
M``!1``$`#P```%T``0`+````;0`!`"````!Y``$`)P```)H``0`K````P@`!
M``D```#N``$`,@```/@``0`P````*P$!`#$```!<`0$`+0```(X!`0`_````
MO`$!`#T```#\`0$`-@```#H"`0`4````<0(!``4```"&`@$`#@```(P"`0`3
M````FP(!``<```"O`@$`$0```+<"`0`'````R0(!`!0```#1`@$`&````.8"
M`0`'````_P(!``4````'`P$`#`````T#`0`,````&@,!`!(````G`P$`!```
M`#H#`0`'````/P,!``H```!'`P$`"P```%(#`0`,````7@,!``X```!K`P$`
M#@```'H#`0`%````B0,!``4```"/`P$`+@```)4#`0`F````Q`,!`",```#K
M`P$``P````\$`0`2````$P0!``8````F!`$`'@```"T$`0`8````3`0!`"4`
M``!E!`$`#0```(L$`0`)````F00!``(```"C!`$``P```*8$`0`'````J@0!
M``H```"R!`$``@```+T$`0`,````P`0!`!4```#-!`$`"P```.,$`0`9````
M[P0!`"`````)!0$`$@```"H%`0`%````/04!``H```!#!0$`%0```$X%`0`2
M````9`4!``P```!W!0$`!````(0%`0`'````B04!``D```"1!0$`#````)L%
M`0!2````J`4!`!<```#[!0$`)````!,&`0`'````.`8!``8```!`!@$`#@``
M`$<&`0`,````5@8!``T```!C!@$`%0```'$&`0`2````AP8!``\```":!@$`
M%````*H&`0`;````OP8!`!````#;!@$`:0```.P&`0`:````5@<!`!<```!Q
M!P$`)P```(D'`0`:````L0<!`!<```#,!P$`0@```.0'`0`;````)P@!`!D`
M``!#"`$`'P```%T(`0`7````?0@!`!,```"5"`$`"````*D(`0`'````L@@!
M``@```"Z"`$`"0```,,(`0`5````S0@!``T```#C"`$`$P```/$(`0`#````
M!0D!`$8````)"0$`/P```%`)`0`W````D`D!`%<```#("0$`'P```"`*`0`O
M````0`H!``H```!P"@$`"````'L*`0`-````A`H!`"T```"2"@$`!````,`*
M`0!/````Q0H!`"4````5"P$`'````#L+`0`+````6`L!`!\```!D"P$`'0``
M`(0+`0`E````H@L!`"````#("P$`)````.D+`0`@````#@P!``L````O#`$`
M!P```#L,`0`.````0PP!``T```!2#`$`#````&`,`0`&````;0P!`#D```!T
M#`$`#````*X,`0`'````NPP!`!D```###`$`"0```-T,`0`3````YPP!``D`
M``#[#`$`!`````4-`0`0````"@T!``@````;#0$`"````"0-`0`+````+0T!
M``P````Y#0$`&@```$8-`0`/````80T!``<```!Q#0$`#0```'D-`0`4````
MAPT!``X```"<#0$`#````*L-`0`;````N`T!`"P```#4#0$`$P````$.`0`<
M````%0X!`"@````R#@$`!@```%L.`0`'````8@X!`!,```!J#@$`!0```'X.
M`0`$````A`X!`!<```")#@$`"@```*$.`0`,````K`X!``D```"Y#@$`!@``
M`,,.`0`)````R@X!``@```#4#@$`"0```-T.`0`%````YPX!``H```#M#@$`
M$0```/@.`0`&````"@\!``X````1#P$`#@```"`/`0`-````+P\!``L````]
M#P$`'0```$D/`0`+````9P\!``(```!S#P$`!P```'8/`0`7````?@\!``8`
M``"6#P$`90```)T/`0`)`````Q`!``<````-$`$`)@```!40`0`X````/!`!
M`!H```!U$`$`*@```)`0`0`[````NQ`!`"L```#W$`$`*````",1`0`9````
M3!$!`!4```!F$0$`!0```'P1`0`'````@A$!``@```"*$0$`!P```),1`0`%
M````FQ$!``<```"A$0$`#@```*D1`0`)````N!$!``8```#"$0$`"````,D1
M`0`+````TA$!``<```#>$0$`"````.81`0`'````[Q$!`!8```#W$0$`"0``
M``X2`0`&````&!(!``L````?$@$`'````"L2`0`4````2!(!``<```!=$@$`
M"````&42`0`(````;A(!``4```!W$@$`$````'T2`0`0````CA(!``8```"?
M$@$`&0```*82`0`*````P!(!`!P```#+$@$`!P```.@2`0`%````\!(!`!``
M``#V$@$`%`````<3`0`+````'!,!``T````H$P$`&````#83`0`7````3Q,!
M`!H```!G$P$`%````((3`0`$````EQ,!``D```"<$P$`"@```*83`0`'````
ML1,!``(```"Y$P$`#@```+P3`0`(````RQ,!`!\```#4$P$`(P```/03`0`X
M````&!0!`#$```!1%`$`)P```(,4`0!D````JQ0!`!0````0%0$`'````"45
M`0!5````0A4!`#@```"8%0$`2@```-$5`0!;````'!8!`"@```!X%@$`.```
M`*$6`0`J````VA8!`"@````%%P$`+````"X7`0`G````6Q<!`!L```"#%P$`
M/@```)\7`0"I`0``WA<!`",```"(&0$`%P```*P9`0!(````Q!D!`(4````-
M&@$`,````),:`0!!````Q!H!`%L````&&P$`20```&(;`0`=````K!L!`!@`
M``#*&P$`(0```.,;`0`?````!1P!`"L````E'`$`(0```%$<`0`I````<QP!
M`!T```"='`$`$0```+L<`0`S````S1P!`"4````!'0$`.````"<=`0`G````
M8!T!`!\```"('0$`,````*@=`0!I````V1T!`#(```!#'@$`,0```'8>`0!!
M````J!X!`#,```#J'@$`)0```!X?`0`]````1!\!`&4```""'P$`30```.@?
M`0`O````-B`!`"X```!F(`$`*P```)4@`0`P````P2`!`"H```#R(`$`/@``
M`!TA`0!4````7"$!`%H```"Q(0$`2`````PB`0!*````52(!`#(```"@(@$`
M'0```-,B`0`C````\2(!`"\````5(P$`+````$4C`0`M````<B,!`'$```"@
M(P$`;P```!(D`0"S````@B0!`!<````V)0$`)0```$XE`0`R````="4!`"D`
M``"G)0$`/@```-$E`0`B````$"8!`%(````S)@$`)0```(8F`0`+````K"8!
M`+$```"X)@$`10```&HG`0`A````L"<!`#````#2)P$`)0````,H`0`<````
M*2@!`#$```!&*`$`!P```'@H`0`'````@"@!``0```"(*`$`#0```(TH`0`+
M````FR@!``X```"G*`$`"P```+8H`0`%````PB@!`!````#(*`$``@```-DH
M`0!9````W"@!``4````V*0$`$@```#PI`0`$````3RD!``<```!4*0$`"```
M`%PI`0`%````92D!``,```!K*0$`$````&\I`0`,````@"D!`!,```"-*0$`
M#0```*$I`0`"````KRD!``<```"R*0$`!@```+HI`0`4````P2D!``P```#6
M*0$`&````.,I`0`&````_"D!`!(````#*@$`#````!8J`0`#````(RH!`"H`
M```G*@$`!````%(J`0`&````5RH!``<```!>*@$`'P```&8J`0`U````ABH!
M`"X```"\*@$`+P```.LJ`0`7````&RL!`"`````S*P$`&P```%0K`0`8````
M<"L!`"0```")*P$`'P```*XK`0`:````SBL!`"````#I*P$`&@````HL`0`R
M````)2P!`"\```!8+`$`&@```(@L`0`K````HRP!`!\```#/+`$`(P```.\L
M`0`?````$RT!`!H````S+0$`)0```$XM`0`F````="T!`"4```";+0$`)```
M`,$M`0`8````YBT!`!T```#_+0$`)````!TN`0`8````0BX!`"(```!;+@$`
M)0```'XN`0`\````I"X!`!\```#A+@$`(P````$O`0`?````)2\!`"````!%
M+P$`&@```&8O`0`8````@2\!`"8```":+P$`'@```,$O`0`I````X"\!`!X`
M```*,`$`"0```"DP`0`,````,S`!`!<```!`,`$`+P```%@P`0`D````B#`!
M``<```"M,`$`'P```+4P`0`/````U3`!`!0```#E,`$`#@```/HP`0`-````
M"3$!`"0````7,0$`!0```#PQ`0`'````0C$!`"(```!*,0$`)0```&TQ`0`=
M````DS$!`!H```"Q,0$`!P```,PQ`0#'````U#$!``L```"<,@$`%0```*@R
M`0`&````OC(!``D```#%,@$`&````,\R`0`+````Z#(!``T```#T,@$`%P``
M``(S`0`&````&C,!`#,````A,P$`$P```%4S`0`3````:3,!``<```!],P$`
M#P```(4S`0`'````E3,!`#(```"=,P$`(0```-`S`0`3````\C,!``P````&
M-`$`$0```!,T`0`R````)30!``X```!8-`$`#P```&<T`0`0````=S0!``@`
M``"(-`$`'0```)$T`0`)````KS0!``H```"Y-`$`!0```,0T`0`4````RC0!
M``H```#?-`$`'0```.HT`0`(````"#4!`!\````1-0$`"````#$U`0`:````
M.C4!``8```!5-0$`%0```%PU`0`'````<C4!``@```!Z-0$`"0```(,U`0`_
M````C34!``<```#--0$`#P```-4U`0`.````Y34!`!````#T-0$`"0````4V
M`0`)````#S8!``@````9-@$`$P```"(V`0`'````-C8!`!D````^-@$`"@``
M`%@V`0`*````8S8!``D```!N-@$`%P```'@V`0`4````D#8!``H```"E-@$`
M#````+`V`0`7````O38!``0```#5-@$`*@```-HV`0`1````!3<!``<````7
M-P$``@```!\W`0`0````(C<!`!@````S-P$`"P```$PW`0`#````6#<!``@`
M``!<-P$`!@```&4W`0`'````;#<!``T```!T-P$`"P```((W`0`4````CC<!
M`!4```"C-P$`#@```+DW`0`O````R#<!`"````#X-P$`'````!DX`0`,````
M-C@!`#$```!#.`$`!0```'4X`0`2````>S@!`#\```"..`$`$@```,XX`0`*
M````X3@!``8```#L.`$`!````/,X`0`3````^#@!``4````,.0$`!@```!(Y
M`0`&````&3D!``D````@.0$`!````"HY`0`,````+SD!``H````\.0$`;```
M`$<Y`0`%````M#D!`!@```"Z.0$`&0```-,Y`0`?````[3D!`!T````-.@$`
M$0```"LZ`0`"````/3H!``0```!`.@$`"@```$4Z`0`&````4#H!``4```!7
M.@$``P```%TZ`0`,````83H!`$4```!N.@$`&@```+0Z`0`U````SSH!`"4`
M```%.P$`*````"L[`0!3````5#L!`!D```"H.P$`<@```,([`0`@````-3P!
M`#4```!6/`$`10```(P\`0`P````TCP!`",````#/0$`'P```"<]`0`H````
M1ST!`"D```!P/0$`)@```)H]`0`E````P3T!`"@```#G/0$`*````!`^`0`B
M````.3X!`"$```!</@$`,````'X^`0`2````KSX!`!,```#"/@$`$````-8^
M`0!Y````YSX!``D```!A/P$`<@```&L_`0!S````WC\!`'P```!20`$`*P``
M`,]``0!3````^T`!`!<```!/00$`%@```&=!`0`/````?D$!`!\```".00$`
M40```*Y!`0`W`````$(!`#8````X0@$`-@```&]"`0`^````ID(!`$$```#E
M0@$`0P```"=#`0!\````:T,!`$````#H0P$`/@```"E$`0!`````:$0!`$(`
M``"I1`$`.0```.Q$`0`?````)D4!`!\```!&10$`'````&9%`0!1````@T4!
M`!0```#510$`"@```.I%`0`%````]44!``8```#[10$`"`````)&`0`%````
M"T8!`!(````11@$`$````"1&`0`3````-48!`!T```!)1@$`#P```&=&`0`/
M````=T8!``0```"'1@$`"0```(Q&`0`+````ED8!``<```"B1@$`!0```*I&
M`0`4````L$8!``<```#%1@$`"````,U&`0`/````UD8!``@```#F1@$`#```
M`.]&`0`/````_$8!``8````,1P$`%````!-'`0`&````*$<!``P````O1P$`
M"````#Q'`0`$````14<!``H```!*1P$`!P```%5'`0`$````74<!`!D```!B
M1P$``@```'Q'`0`$````?T<!``D```"$1P$`!@```(Y'`0`5````E4<!``8`
M``"K1P$`)P```+)'`0`$````VD<!``\```#?1P$`$P```.]'`0`'`````T@!
M``<````+2`$`!@```!-(`0`&````&D@!`!`````A2`$`$@```#)(`0`&````
M14@!``D```!,2`$`(@```%9(`0`'````>4@!``<```"!2`$`"P```(E(`0`%
M````E4@!``(```";2`$`"P```)Y(`0!8`0``JD@!`$`````#2@$`$@```$1*
M`0`.````5TH!``L```!F2@$`"````')*`0`!````>TH!``L```!]2@$`$0``
M`(E*`0`,````FTH!``L```"H2@$`#0```+1*`0`-````PDH!``4```#02@$`
M*0```-9*`0`/`````$L!``P````02P$`$@```!U+`0`(````,$L!``\````Y
M2P$`(P```$E+`0`B````;4L!`"8```"02P$`$0```+=+`0`*````R4L!``P`
M``#42P$`(@```.%+`0`;````!$P!`!,````@3`$`'````#1,`0`H````44P!
M`"P```!Z3`$`$0```*=,`0`.````N4P!`!$```#(3`$`$````-I,`0`&````
MZTP!`"0```#R3`$`'````!=-`0`F````-$T!`!\```!;30$`$P```'M-`0`3
M````CTT!`!@```"C30$`#@```+Q-`0`5````RTT!`!$```#A30$`$P```/--
M`0`3````!TX!``L````;3@$`+````"=.`0`2````5$X!`#T```!G3@$`20``
M`*5.`0!E````[TX!`&8```!53P$`:````+Q/`0!I````)5`!`$````"/4`$`
M#P```-!0`0`*````X%`!``4```#K4`$`!@```/%0`0`2````^%`!``<````+
M40$`$0```!-1`0`3````)5$!`!`````Y40$`!P```$I1`0`1````4E$!`"L`
M``!D40$`*````)!1`0`+````N5$!`!,```#%40$`"````-E1`0`(````XE$!
M``<```#K40$`#P```/-1`0`0`````U(!`!`````44@$`$P```"52`0`5````
M.5(!`!X```!/4@$`'@```&Y2`0`:````C5(!`!````"H4@$`%@```+E2`0`,
M````T%(!`"T```#=4@$`'@````M3`0`:````*E,!`!\```!%4P$`$0```&53
M`0!:````=U,!`"T```#24P$`'`````!4`0`'````'50!``<````E5`$`.0``
M`"U4`0`(````9U0!``@```!P5`$`#````'E4`0`(````AE0!``<```"/5`$`
M"````)=4`0`(````H%0!``L```"I5`$`!0```+54`0`:````NU0!``P```#6
M5`$`#````.-4`0`4````\%0!`!0````%50$`(0```!I5`0`.````/%4!`!\`
M``!+50$`'0```&M5`0`B````B54!`!X```"L50$`%0```,M5`0`4````X54!
M``X```#V50$`&P````56`0`&````(58!``8````H5@$`!P```"]6`0`9````
M-U8!``D```!15@$`"@```%M6`0`2````9E8!``<```!Y5@$`%0```(%6`0`7
M````EU8!``L```"O5@$`"````+M6`0`7````Q%8!`!,```#<5@$`&0```/!6
M`0`S````"E<!`#(````^5P$`"0```'%7`0`(````>U<!`!4```"$5P$`!0``
M`)I7`0`%````H%<!`!T```"F5P$`"P```,17`0`@````T%<!`"X```#Q5P$`
M%0```"!8`0`Z````-E@!`"@```!Q6`$`*@```)I8`0`K````Q5@!`"L```#Q
M6`$`"````!U9`0`)````)ED!``D````P60$`"@```#I9`0`(````15D!`"\`
M``!.60$`+````'Y9`0`N````JUD!`%````#:60$`+0```"M:`0`M````65H!
M`"T```"'6@$`/P```+5:`0`I````]5H!`"L````?6P$`+0```$M;`0`S````
M>5L!`!0```"M6P$`&````,);`0`J````VUL!`"<````&7`$`#@```"Y<`0`1
M````/5P!``T```!/7`$`$0```%U<`0`V````;UP!``4```"F7`$`"P```*Q<
M`0`A````N%P!`"8```#:7`$`!P````%=`0`)````"5T!`!8````370$`"@``
M`"I=`0`*````-5T!``<```!`70$`#@```$A=`0`+````5UT!``<```!C70$`
M!P```&M=`0`'````<UT!``@```![70$`!P```(1=`0`+````C%T!`!````"8
M70$`"P```*E=`0`2````M5T!``H```#(70$`"````--=`0`'````W%T!``<`
M``#D70$`$````.Q=`0`'````_5T!`!8````%7@$`!0```!Q>`0`(````(EX!
M``@````K7@$`"@```#1>`0`)````/UX!`"````!)7@$`%0```&I>`0`)````
M@%X!`!$```"*7@$`#@```)Q>`0`)````JUX!``,```"U7@$``P```+E>`0`7
M````O5X!`!0```#57@$`"P```.I>`0`$````]EX!``@```#[7@$`"0````1?
M`0!/````#E\!`"H```!>7P$`!@```(E?`0`(````D%\!`!P```"97P$`'```
M`+9?`0`A````TU\!`"@```#U7P$`'P```!Y@`0`I````/F`!`%@```!H8`$`
M+````,%@`0`*````[F`!``L```#Y8`$`"P````5A`0`-````$6$!`!$````?
M80$`$````#%A`0`.````0F$!`!````!180$`$@```&)A`0`3````=6$!`!,`
M``")80$`!@```)UA`0`<````I&$!`!X```#!80$`$P```.!A`0`2````]&$!
M``4````'8@$`!P````UB`0`(````%6(!`!4````>8@$`(````#1B`0!B````
M56(!`!4```"X8@$`(@```,YB`0`(````\6(!`!8```#Z8@$`+0```!%C`0`$
M````/V,!``8```!$8P$`'````$MC`0`;````:&,!`!8```"$8P$`&P```)MC
M`0`4````MV,!`"$```#,8P$`)````.YC`0`+````$V0!``\````?9`$`!@``
M`"]D`0`8````-F0!`!T```!/9`$`&P```&UD`0`;````B60!``4```"E9`$`
M$P```*MD`0`.````OV0!``D```#.9`$`"0```-AD`0`6````XF0!`!L```#Y
M9`$`"0```!5E`0`&````'V4!`!(````F90$`%````#EE`0`+````3F4!`!4`
M``!:90$`"````'!E`0`'````>64!`!````"!90$`"@```))E`0`.````G64!
M``<```"L90$`"0```+1E`0`'````OF4!`!(```#&90$`#````-EE`0`'````
MYF4!`!0```#N90$`)@````-F`0`/````*F8!`!4````Z9@$`'0```%!F`0`&
M````;F8!`!P```!U9@$`%0```))F`0`6````J&8!`#$```"_9@$`/@```/%F
M`0`G````,&<!`#(```!89P$`#````(MG`0`%````F&<!``H```">9P$`#@``
M`*EG`0`)````N&<!`!4```#"9P$`"@```-AG`0`6````XV<!`!X```#Z9P$`
M'P```!EH`0`A````.6@!`"(```!;:`$`'0```'YH`0`H````G&@!`"<```#%
M:`$`+````.UH`0`?````&FD!`"<````Z:0$`,P```&)I`0`I````EFD!`!\`
M``#`:0$`(@```.!I`0`>`````VH!`"H````B:@$`*P```$UJ`0`K````>6H!
M`",```"E:@$`*0```,EJ`0`P````\VH!`",````D:P$`'P```$AK`0`O````
M:&L!`!8```"8:P$`(````*]K`0`N````T&L!`"$```#_:P$`(0```"%L`0`5
M````0VP!`+<```!9;`$`$@```!%M`0`B````)&T!`"<```!';0$`)P```&]M
M`0`E````EVT!`!P```"];0$`(````-IM`0`@````^VT!`"\````<;@$`,@``
M`$QN`0`N````?VX!`"````"N;@$`'0```,]N`0`@````[6X!`"P````.;P$`
M)````#MO`0!'````8&\!`#X```"H;P$`#P```.=O`0`(````]V\!``8`````
M<`$`!P````=P`0`/````#W`!`!0````?<`$`%````#1P`0`0````27`!`!L`
M``!:<`$`"````'9P`0`$````?W`!``X```"$<`$`$0```)-P`0`1````I7`!
M`!8```"W<`$`%````,YP`0`2````XW`!`#,```#V<`$`"````"IQ`0`4````
M,W$!``8```!(<0$`$0```$]Q`0`7````87$!`!\```!Y<0$`$@```)EQ`0`"
M````K'$!``<```"O<0$`"````+=Q`0`7````P'$!``0```#8<0$`!0```-UQ
M`0`2````XW$!``4```#V<0$`$@```/QQ`0`'````#W(!`!4````7<@$`"@``
M`"UR`0`5````.'(!`!(```!.<@$`%````&%R`0`3````=G(!`!,```"*<@$`
M"P```)YR`0`(````JG(!``T```"S<@$`"````,%R`0`.````RG(!``X```#9
M<@$`&0```.AR`0`-`````G,!`!$````0<P$`*@```")S`0`4````37,!`#@`
M``!B<P$`#P```)MS`0`:````JW,!`!0```#&<P$`$P```-MS`0`X````[W,!
M`"0````H=`$`$0```$UT`0`&````7W0!`!````!F=`$`'0```'=T`0`3````
ME70!``D```"I=`$`+@```+-T`0`M````XG0!``@````0=0$`"0```!EU`0`=
M````(W4!``L```!!=0$`&@```$UU`0`:````:'4!``D```"#=0$`&@```(UU
M`0`5````J'4!`!4```"^=0$`$P```-1U`0`<````Z'4!``@````%=@$`"```
M``YV`0`J````%W8!`"(```!"=@$`"````&5V`0`4````;G8!``H```"#=@$`
M#0```(YV`0`T````G'8!`!D```#1=@$`!P```.MV`0`1````\W8!``,````%
M=P$`"0````EW`0`&````$W<!`!<````:=P$`#P```#)W`0`0````0G<!`!``
M``!3=P$`%0```&1W`0`2````>G<!`!4```"-=P$`%P```*-W`0`'````NW<!
M``<```##=P$`"@```,MW`0`,````UG<!``(```#C=P$`"@```.9W`0`1````
M\7<!`!\````#>`$`(0```"-X`0`*````17@!``X```!0>`$`$P```%]X`0`;
M````<W@!`#L```"/>`$`)@```,MX`0`'````\G@!``X```#Z>`$`$P````EY
M`0!R````'7D!`!D```"0>0$`$@```*IY`0`(````O7D!``8```#&>0$`+0``
M`,UY`0`>````^WD!``X````:>@$`$P```"EZ`0`&````/7H!``@```!$>@$`
M!P```$UZ`0`&````57H!``X```!<>@$`#0```&MZ`0`0````>7H!``T```"*
M>@$`&P```)AZ`0`.````M'H!``H```##>@$`"P```,YZ`0`'````VGH!``H`
M``#B>@$`#P```.UZ`0`\````_7H!``X````Z>P$`"@```$E[`0`-````5'L!
M`!P```!B>P$`'0```'][`0`H````G7L!`"<```#&>P$`'0```.Y[`0`<````
M#'P!`"(````I?`$`&0```$Q\`0`F````9GP!`"L```"-?`$`!P```+E\`0`:
M````P7P!``P```#<?`$`#P```.E\`0`&````^7P!``<`````?0$`"@````A]
M`0`,````$WT!`!,````@?0$`!@```#1]`0`9````.WT!`!P```!5?0$`#P``
M`')]`0`1````@GT!`!(```"4?0$`#P```*=]`0`B````MWT!``<```#:?0$`
M!P```.)]`0`,````ZGT!`!(```#W?0$`%P````I^`0`+````(GX!``H````N
M?@$`!0```#E^`0`9````/WX!``T```!9?@$`!P```&=^`0`I````;WX!`!(`
M``"9?@$`AP```*Q^`0`:````-'\!``8```!/?P$`!0```%9_`0`,````7'\!
M``8```!I?P$`"````'!_`0`*````>7\!``P```"$?P$`!0```)%_`0`)````
MEW\!``H```"A?P$`%@```*Q_`0`4````PW\!`!<```#8?P$`'@```/!_`0`I
M````#X`!`!(````Y@`$`%@```$R``0`@````8X`!``,```"$@`$`!````(B`
M`0`0````C8`!``@```">@`$`#0```*>``0`'````M8`!`#4```"]@`$`"0``
M`/.``0`'````_8`!`!<````%@0$`$@```!V!`0`'````,($!``D````X@0$`
M!````$*!`0`+````1X$!``8```!3@0$`!@```%J!`0`'````88$!``X```!I
M@0$`"P```'B!`0`(````A($!`!8```"-@0$`"P```*2!`0`'````L($!`!8`
M``"X@0$`(0```,^!`0`-````\8$!``8```#_@0$`"0````:"`0`%````$((!
M``D````6@@$`!P```"""`0`-````*((!``T````V@@$`#````$2"`0`'````
M48(!``X```!9@@$`!@```&B"`0`"````;X(!``0```!R@@$`,P```'>"`0`W
M````JX(!`#8```#C@@$`(````!J#`0`&````.X,!``\```!"@P$`!0```%*#
M`0`(````6(,!`!X```!A@P$`%@```("#`0`'````EX,!``<```"?@P$`(```
M`*>#`0`-````R(,!``D```#6@P$`&P```."#`0`&````_(,!`!X````#A`$`
M"0```"*$`0`D````+(0!``@```!1A`$`#````%J$`0`.````9X0!``@```!V
MA`$`"0```'^$`0`(````B80!`#,```"2A`$`+P```,:$`0`R````]H0!`"8`
M```IA0$`+P```%"%`0!&````@(4!`#H```#'A0$`*@````*&`0`R````+88!
M`#(```!@A@$`,P```).&`0`E````QX8!`!(```#MA@$`$P````"'`0`.````
M%(<!`"`````CAP$`'P```$2'`0`?````9(<!`!T```"$AP$`"0```**'`0`+
M````K(<!``H```"XAP$`"````,.'`0`G````S(<!`"@```#TAP$`,````!V(
M`0`*````3H@!`!D```!9B`$`(P```'.(`0`.````EX@!`!<```"FB`$`"0``
M`+Z(`0`/````R(@!`!4```#8B`$`$P```.Z(`0`H`````HD!`&D````KB0$`
M%0```)6)`0`0````JXD!`!$```"\B0$`&0```,Z)`0`:````Z(D!`!4````#
MB@$`!P```!F*`0`5````(8H!`!(````WB@$`#@```$J*`0`)````68H!`!@`
M``!CB@$`%P```'R*`0`:````E(H!`#$```"OB@$`HP```.&*`0`5````A8L!
M``8```";BP$`%P```**+`0`*````NHL!``L```#%BP$`"P```-&+`0`;````
MW8L!`!,```#YBP$`#P````V,`0`/````'8P!`!D````MC`$`+P```$>,`0`N
M````=XP!`"P```"FC`$`*P```-.,`0`C````_XP!`"(````CC0$`&P```$:-
M`0!!````8HT!`!(```"DC0$`%@```+>-`0`9````SHT!`!@```#HC0$`#P``
M``&.`0`7````$8X!`!L````IC@$`%````$6.`0`8````6HX!`"\```!SC@$`
M'0```*..`0`9````P8X!`#$```#;C@$`$@````V/`0`(````((\!``\````I
MCP$`)@```#F/`0`D````8(\!`!0```"%CP$`#P```)J/`0`;````JH\!`!0`
M``#&CP$`&@```-N/`0`5````]H\!`!T````,D`$`(P```"J0`0`>````3I`!
M`!<```!MD`$`&0```(60`0`4````GY`!`!T```"TD`$`'````-*0`0`+````
M[Y`!`!H```#[D`$`!@```!:1`0`&````'9$!``D````DD0$`$P```"Z1`0`(
M````0I$!``D```!+D0$`"````%61`0`'````7I$!``<```!FD0$`!@```&Z1
M`0`(````=9$!`!<```!^D0$`!P```):1`0`)````GI$!``4```"HD0$`"```
M`*Z1`0`&````MY$!``\```"^D0$`#@```,Z1`0`0````W9$!`!$```#ND0$`
M"P````"2`0`4````#)(!``8````AD@$`+````"B2`0`3````59(!``T```!I
MD@$`#P```'>2`0`+````AY(!``L```"3D@$`$@```)^2`0`G````LI(!``8`
M``#:D@$`"0```.&2`0`G````ZY(!`!(````3DP$`%0```":3`0`(````/),!
M``D```!%DP$`"P```$^3`0`%````6Y,!`"4```!ADP$`"@```(>3`0`4````
MDI,!``L```"GDP$`'````+.3`0`I````T),!`!@```#ZDP$`!P```!.4`0`%
M````&Y0!``H````AE`$`,````"R4`0`'````790!``<```!EE`$`$0```&V4
M`0`3````?Y0!``<```"3E`$`"````)N4`0`6````I)0!``X```"[E`$`#@``
M`,J4`0`0````V90!`!8```#JE`$`%0````&5`0`7````%Y4!``\````OE0$`
M'0```#^5`0`1````794!`!(```!OE0$`"0```(*5`0`'````C)4!``H```"4
ME0$`.0```)^5`0`(````V94!`!0```#BE0$`+P```/>5`0`;````)Y8!`!4`
M``!#E@$`%@```%F6`0`6````<)8!`!4```"'E@$`$````)V6`0`8````KI8!
M`!4```#'E@$`'@```-V6`0`<````_)8!`!T````9EP$`"@```#>7`0`'````
M0I<!``D```!*EP$`$0```%27`0`0````9I<!``4```!WEP$`"P```'V7`0`*
M````B9<!`!,```"4EP$`5````*B7`0`5````_9<!``T````3F`$`!0```"&8
M`0`(````)Y@!`!H````PF`$`&@```$N8`0`:````9I@!``T```"!F`$``@``
M`(^8`0`$````DI@!`"@```"7F`$``P```,"8`0`%````Q)@!``H```#*F`$`
M#````-68`0`&````XI@!``8```#IF`$`#@```/"8`0`3````_Y@!``<````3
MF0$`"0```!N9`0`(````)9D!``4````NF0$`!0```#29`0!7````.ID!``\`
M``"2F0$`$@```**9`0`%````M9D!``<```"[F0$`(P```,.9`0`Q````YYD!
M``T````9F@$`"0```">:`0`/````,9H!``L```!!F@$`"@```$V:`0`4````
M6)H!`"L```!MF@$`&@```)F:`0`9````M)H!`!````#.F@$`!@```-^:`0`&
M````YIH!``@```#MF@$`%P```/::`0`7````#IL!`!8````FFP$`&@```#V;
M`0`8````6)L!`"````!QFP$`!@```)*;`0`.````F9L!``X```"HFP$`!@``
M`+>;`0!,````OIL!`!(````+G`$`#0```!Z<`0`+````+)P!`!8````XG`$`
M1````$^<`0`'````E)P!`!@```"<G`$`!0```+6<`0`'````NYP!`"(```##
MG`$`"````.:<`0`*````[YP!`!D```#ZG`$`&@```!2=`0`W````+YT!``D`
M``!GG0$`!0```'&=`0`C````=YT!`$D```";G0$`$````.6=`0`G````]IT!
M`!`````>G@$`!0```"^>`0`.````-9X!``D```!$G@$`#P```$Z>`0`*````
M7IX!``<```!IG@$`$P```'&>`0`'````A9X!``D```"-G@$`$0```)>>`0`*
M````J9X!``H```"TG@$`#0```+^>`0`'````S9X!`!$```#5G@$`%````.>>
M`0`2````_)X!``\````/GP$`$````!^?`0`1````,)\!`!$```!"GP$`$```
M`%2?`0`2````99\!``H```!XGP$`)@```(.?`0`3````JI\!``T```"^GP$`
M#0```,R?`0`7````VI\!``D```#RGP$`#0```/R?`0`&````"J`!``@````1
MH`$`!@```!J@`0`4````(:`!``<````VH`$`"P```#Z@`0`2````2J`!`!4`
M``!=H`$`(0```'.@`0`?````E:`!`!@```"UH`$`%@```,Z@`0`<````Y:`!
M`!X````"H0$`&@```"&A`0`'````/*$!``<```!$H0$`$@```$RA`0`0````
M7Z$!``X```!PH0$`(P```'^A`0`1````HZ$!`!,```"UH0$`%@```,FA`0`)
M````X*$!``\```#JH0$`"````/JA`0`1`````Z(!``P````5H@$`$P```"*B
M`0`)````-J(!``<```!`H@$`"````$BB`0`&````4:(!``4```!8H@$``@``
M`%ZB`0`E````8:(!`"(```"'H@$`%P```*JB`0`@````PJ(!`#0```#CH@$`
M#@```!BC`0`H````)Z,!`",```!0HP$`*````'2C`0`M````G:,!`"T```#+
MHP$`,@```/FC`0`4````+*0!`!(```!!I`$`$@```%2D`0`4````9Z0!`!(`
M``!\I`$`$````(^D`0`2````H*0!`!P```"SI`$`+0```-"D`0`M````_J0!
M`#$````LI0$`+0```%ZE`0`N````C*4!`"\```"[I0$`+````.NE`0!@````
M&*8!`"````!YI@$`$@```)JF`0`1````K:8!`!4```"_I@$`)````-6F`0`Q
M````^J8!`!D````LIP$`#0```$:G`0!`````5*<!`$````"5IP$`"0```-:G
M`0`*````X*<!``0```#KIP$`%0```/"G`0`.````!J@!`!(````5J`$`&```
M`"BH`0`)````0:@!``@```!+J`$`#````%2H`0`,````8:@!``T```!NJ`$`
M"@```'RH`0`-````AZ@!``<```"5J`$`(0```)VH`0`'````OZ@!``D```#'
MJ`$`!P```-&H`0`1````V:@!`!(```#KJ`$`$````/ZH`0`S````#ZD!``(`
M``!#J0$`"````$:I`0`2````3ZD!`!@```!BJ0$`"P```'NI`0`&````AZD!
M`!````".J0$`!@```)^I`0`2````IJD!``8```"YJ0$`+P```,"I`0`8````
M\*D!`"@````)J@$`5@```#*J`0`7````B:H!`",```"AJ@$`$@```,6J`0`-
M````V*H!``H```#FJ@$`#0```/&J`0`3````_ZH!``P````3JP$`"0```""K
M`0`,````*JL!`!\````WJP$`%P```%>K`0`$````;ZL!`!````!TJP$`$0``
M`(6K`0`E````EZL!`!@```"]JP$`&0```-:K`0`3````\*L!`"$````$K`$`
M"0```":L`0`'````,*P!`!$````XK`$`"0```$JL`0`*````5*P!``@```!?
MK`$`#0```&BL`0`*````=JP!``4```"!K`$`'@```(>L`0`&````IJP!`!4`
M``"MK`$`"@```,.L`0`1````SJP!`"\```#@K`$`"P```!"M`0`C````'*T!
M`!<```!`K0$`.P```%BM`0`Z````E*T!`#D```#/K0$`+@````FN`0`O````
M.*X!`"P```!HK@$`&P```)6N`0`,````L:X!``T```"^K@$`&P```,RN`0`&
M````Z*X!`"L```#OK@$`!@```!NO`0`=````(J\!``8```!`KP$`"0```$>O
M`0`?````4:\!`#4```!QKP$`!@```*>O`0`8````KJ\!`!8```#'KP$`!@``
M`-ZO`0`4````Y:\!``0```#ZKP$`!P```/^O`0`)````![`!``D````1L`$`
M"@```!NP`0`)````)K`!``D````PL`$`"0```#JP`0`;````1+`!`#4```!@
ML`$`/@```):P`0`9````U;`!`"<```#OL`$`'````!>Q`0`\````-+$!`!@`
M``!QL0$`%````(JQ`0`N````G[$!`%\```#.L0$`4````"ZR`0`D````?[(!
M`"8```"DL@$`!P```,NR`0`)````T[(!``H```#=L@$`"P```.BR`0`5````
M]+(!`!$````*LP$`*0```!RS`0`@````1K,!`"X```!GLP$`,P```):S`0`-
M````RK,!``8```#8LP$`%0```-^S`0`(````];,!``@```#^LP$`)`````>T
M`0`3````++0!`!0```!`M`$`%@```%6T`0`0````;+0!``@```!]M`$`$P``
M`(:T`0`)````FK0!`!````"DM`$`#P```+6T`0`8````Q;0!`"H```#>M`$`
M#`````FU`0`'````%K4!``<````>M0$`'@```":U`0`4````1;4!``8```!:
MM0$`#@```&&U`0`0````<+4!``P```"!M0$`"P```(ZU`0`-````FK4!``8`
M``"HM0$`$0```*^U`0`(````P;4!``@```#*M0$`$P```-.U`0`P````Y[4!
M`$,````8M@$`&P```%RV`0`D````>+8!`!H```"=M@$`!0```+BV`0`0````
MOK8!``@```#/M@$`(````-BV`0`0````^;8!`"P````*MP$`"````#>W`0`/
M````0+<!`!,```!0MP$`%@```&2W`0`>````>[<!``T```":MP$`/````*BW
M`0`)````Y;<!`"(```#OMP$`$@```!*X`0`6````);@!`!0````\N`$`(P``
M`%&X`0`V````=;@!`"$```"LN`$`#````,ZX`0`L````V[@!`"\````(N0$`
M,````#BY`0`L````:;D!`#X```"6N0$`/````-6Y`0`U````$KH!`!,```!(
MN@$`"````%RZ`0`3````9;H!`!4```!YN@$`"@```(^Z`0`3````FKH!``@`
M``"NN@$`%P```+>Z`0`<````S[H!``8```#LN@$`"````/.Z`0`2````_+H!
M`!0````/NP$`%@```"2[`0`$````.[L!``@```!`NP$`"P```$F[`0`.````
M5;L!``\```!DNP$`$@```'2[`0`2````A[L!``@```":NP$`"0```*.[`0`H
M````K;L!`!P```#6NP$`&@```/.[`0`'````#KP!`!(````6O`$`!@```"F\
M`0`.````,+P!`!D````_O`$`)@```%F\`0`+````@+P!``<```",O`$``@``
M`)2\`0`#````E[P!``8```";O`$`"````**\`0`%````J[P!``\```"QO`$`
M%P```,&\`0`-````V;P!`!T```#GO`$`'0````6]`0`:````([T!``4````^
MO0$`"P```$2]`0`4````4+T!``D```!EO0$`#0```&^]`0`)````?;T!``P`
M``"'O0$`#@```)2]`0`4````H[T!`%8```"XO0$`&`````^^`0`H````*+X!
M``<```!1O@$`!P```%F^`0`'````8;X!`!(```!IO@$`$````'R^`0`1````
MC;X!`!L```"?O@$`$P```+N^`0`5````S[X!`"0```#EO@$`$P````J_`0!B
M````'K\!`!L```"!OP$`&@```)V_`0`I````N+\!`!L```#BOP$`&@```/Z_
M`0!2````&<`!`"0```!LP`$`&@```)'``0`9````K,`!`!P```#&P`$`&@``
M`./``0`*````_L`!``D````)P0$`"P```!/!`0`(````'\$!`!8````HP0$`
M#P```#_!`0`5````3\$!``@```!EP0$`4````&[!`0!!````O\$!`"@````!
MP@$`3P```"K"`0`;````>L(!`"L```"6P@$`"````,+"`0`*````R\(!`!$`
M``#6P@$`*0```.C"`0`&````$L,!`$T````9PP$`)0```&?#`0`A````C<,!
M`!(```"OPP$`(````,+#`0`8````X\,!`!P```#\PP$`'P```!G$`0`>````
M.<0!`",```!8Q`$`%````'S$`0`&````D<0!``P```"8Q`$`"P```*7$`0`-
M````L<0!``D```"_Q`$`*@```,G$`0`+````],0!``P`````Q0$`*`````W%
M`0`'````-L4!`!$````^Q0$`"@```%#%`0`%````6\4!`!8```!AQ0$`"0``
M`'C%`0`)````@L4!``0```",Q0$`#@```)'%`0`8````H,4!``X```"YQ0$`
M!P```,C%`0`5````T,4!`!X```#FQ0$`$`````7&`0`,````%L8!`!H````C
MQ@$`*````#[&`0`1````9\8!`!$```!YQ@$`)@```(O&`0`&````LL8!`!$`
M``"YQ@$`!@```,O&`0`(````TL8!``8```#;Q@$`'0```.+&`0`.`````,<!
M`!(````/QP$`$````"+'`0`'````,\<!``D````[QP$`"@```$7'`0`,````
M4,<!``<```!=QP$`#P```&7'`0`7````=<<!``8```"-QP$`$@```)3'`0`.
M````I\<!``D```"VQP$`#@```,#'`0`8````S\<!``T```#HQP$`!0```/;'
M`0`$````_,<!`!D````!R`$`!@```!O(`0!3````(L@!``@```!VR`$`"```
M`'_(`0`B````B,@!`#<```"KR`$`&````./(`0`E````_,@!`%0````BR0$`
M.0```'?)`0`T````L<D!`!L```#FR0$`&0````+*`0`'````',H!``<````D
MR@$`"@```"S*`0`*````-\H!``<```!"R@$`"@```$K*`0`5````5<H!``P`
M``!KR@$`"@```'C*`0`,````@\H!``@```"0R@$`#````)G*`0`)````ILH!
M``<```"PR@$`&````+C*`0`+````T<H!``<```#=R@$`"@```.7*`0`E````
M\,H!`!@````6RP$`!P```"_+`0`(````-\L!``H```!`RP$`!P```$O+`0`3
M````4\L!`!,```!GRP$`"````'O+`0`<````A,L!``T```"ARP$`'@```*_+
M`0`)````SLL!``8```#8RP$`$````-_+`0`5````\,L!``L````&S`$`#0``
M`!+,`0`7````(,P!`!<````XS`$`&P```%#,`0`1````;,P!``<```!^S`$`
M"P```(;,`0`/````DLP!``X```"BS`$`!0```+',`0`8````M\P!``D```#0
MS`$`'````-K,`0`1````]\P!`#,````)S0$`)@```#W-`0`C````9,T!`'L`
M``"(S0$`%`````3.`0`@````&<X!`#\````ZS@$`-````'K.`0!%````K\X!
M`$,```#US@$`'P```#G/`0!D````6<\!`"<```"^SP$`)@```.;/`0`S````
M#=`!`"H```!!T`$`$P```&S0`0`8````@-`!`'T!``"9T`$`%P```!?2`0`2
M````+](!`#@```!"T@$`@0```'O2`0`\````_=(!`#<````ZTP$`20```'+3
M`0!$````O-,!`!X````!U`$`$P```"#4`0`8````--0!`!D```!-U`$`)```
M`&?4`0`=````C-0!`"@```"JU`$`(P```-/4`0`4````]]0!`!L````,U0$`
M(0```"C5`0`S````2M4!`!<```!^U0$`#P```);5`0`P````IM4!`%L```#7
MU0$`&@```#/6`0`9````3M8!`#8```!HU@$`&````)_6`0`<````N-8!`"P`
M``#5U@$`4@````+7`0`Y````5=<!`",```"/UP$`)@```+/7`0`:````VM<!
M`",```#UUP$`&@```!G8`0`S````--@!`$<```!HV`$`1P```+#8`0`]````
M^-@!`#P````VV0$`,````'/9`0`:````I-D!`!L```"_V0$`*@```-O9`0`J
M````!MH!`"T````QV@$`9P```%_:`0!E````Q]H!`*L````MVP$`%@```-G;
M`0`M````\-L!`#$````>W`$`,````%#<`0!)````@=P!`!X```#+W`$`3@``
M`.K<`0`6````.=T!``<```!0W0$`L0```%C=`0!%````"MX!`"@```!0W@$`
M,P```'G>`0`:````K=X!`!X```#(W@$`+@```.?>`0`)````%M\!``@````@
MWP$`!@```"G?`0`.````,-\!``X````_WP$`$@```$[?`0`*````8=\!``@`
M``!LWP$`#````'7?`0`#````@M\!`&P```"&WP$`"````//?`0`0````_-\!
M``4````-X`$`!P```!/@`0`%````&^`!``4````AX`$`!P```"?@`0`9````
M+^`!``@```!)X`$`%0```%+@`0`,````:.`!``4```!UX`$`!P```'O@`0`'
M````@^`!`!4```"+X`$`"@```*'@`0`7````K.`!``8```#$X`$`&P```,O@
M`0`/````Y^`!``,```#WX`$`)@```/O@`0`$````(N$!``8````GX0$`!P``
M`"[A`0`B````-N$!`$$```!9X0$`*````)OA`0`J````Q.$!`!8```#OX0$`
M)P````;B`0`@````+N(!`!\```!/X@$`(P```&_B`0`>````D^(!`!L```"R
MX@$`(@```,[B`0`>````\>(!`"L````0XP$`*0```#SC`0`;````9N,!`"L`
M``""XP$`'P```*[C`0`C````SN,!`"$```#RXP$`'````!3D`0`F````,>0!
M`"<```!8Y`$`(P```(#D`0`>````I.0!`!P```##Y`$`(@```.#D`0`E````
M`^4!`!T````IY0$`)0```$?E`0`F````;>4!`#H```"4Y0$`(0```,_E`0`E
M````\>4!`",````7Y@$`)````#OF`0`>````8.8!`!P```!_Y@$`)````)SF
M`0`@````P>8!`"L```#BY@$`(P````[G`0`)````,N<!`!,````\YP$`&@``
M`%#G`0`:````:^<!`!H```"&YP$`"@```*'G`0`A````K.<!`!````#.YP$`
M&0```-_G`0`2````^><!`!,````,Z`$`(@```"#H`0`(````0^@!``D```!,
MZ`$`)````%;H`0`G````>^@!`"\```"CZ`$`(0```-/H`0`,````]>@!`/H`
M```"Z0$`$0```/WI`0`5````#^H!``H````EZ@$`#0```##J`0`;````/NH!
M`!0```!:Z@$`$````&_J`0`?````@.H!``@```"@Z@$`,0```*GJ`0`<````
MV^H!`!H```#XZ@$`"0```!/K`0`5````'>L!``L````SZP$`10```#_K`0`O
M````A>L!`!D```"UZP$`%````,_K`0`6````Y.L!`"````#[ZP$`$P```!SL
M`0`4````,.P!`!````!%[`$`$````%;L`0`E````9^P!`!$```"-[`$`$@``
M`)_L`0`*````LNP!`!L```"][`$`#````-GL`0`;````YNP!``D````"[0$`
M&P````SM`0`*````*.T!`!P````S[0$`"````%#M`0`C````6>T!``<```!]
M[0$`"0```(7M`0`)````C^T!`#$```"9[0$`!P```,OM`0`0````T^T!`!0`
M``#D[0$`$0```/GM`0`+````"^X!``T````7[@$`"0```"7N`0`7````+^X!
M``T```!'[@$`%@```%7N`0`2````;.X!`!````!_[@$`$````)#N`0`7````
MH>X!`!4```"Y[@$`"0```,_N`0`+````V>X!`!D```#E[@$`!````/_N`0`J
M````!.\!``\````O[P$`!P```#_O`0`%````1^\!``P```!-[P$`$@```%KO
M`0`+````;>\!``,```!Y[P$`#````'WO`0`+````BN\!``8```"6[P$`$@``
M`)WO`0`)````L.\!`!,```"Z[P$`%````,[O`0`.````X^\!`"L```#R[P$`
M%P```![P`0`6````-O`!``P```!-\`$`)````%KP`0`&````?_`!`!$```"&
M\`$`1@```)CP`0`/````W_`!``P```#O\`$`!P```/SP`0`$````!/$!`!0`
M```)\0$`!@```![Q`0`'````)?$!``@````M\0$`#````#;Q`0`&````0_$!
M``T```!*\0$`#P```%CQ`0!J````:/$!``4```#3\0$`'@```-GQ`0`B````
M^/$!`!H````;\@$`'0```#;R`0`/````5/(!``(```!D\@$`!````&?R`0`0
M````;/(!``8```!]\@$`!P```(3R`0`$````C/(!`!````"1\@$`1P```*+R
M`0`1````ZO(!`"D```#\\@$`+P```";S`0`D````5O,!`$0```![\P$`$```
M`,#S`0!E````T?,!`!L````W]`$`6````%/T`0`N````K/0!`!8```#;]`$`
M)P```/+T`0`9````&O4!`#`````T]0$`,P```&7U`0`D````F?4!`",```"^
M]0$`)P```.+U`0`3````"O8!`#`````>]@$`'````$_V`0`P````;/8!`!<`
M``"=]@$`$@```+7V`0`4````R/8!`$\```#=]@$`$P```"WW`0!W````0?<!
M`&T```"Y]P$`5````"?X`0`G````?/@!`&8```"D^`$`$@````OY`0`:````
M'OD!`!0````Y^0$`(@```$[Y`0!.````<?D!`#(```#`^0$`,@```//Y`0`M
M````)OH!`#````!4^@$`*0```(7Z`0`L````K_H!`(X```#<^@$`,@```&O[
M`0`K````GOL!`#0```#*^P$`.````/_[`0`I````./P!`!T```!B_`$`&P``
M`(#\`0`:````G/P!`%P```"W_`$`%@```!3]`0`+````*_T!``8````W_0$`
M!P```#[]`0`(````1OT!``H```!/_0$`&P```%K]`0`6````=OT!`!H```"-
M_0$`)@```*C]`0`1````S_T!``D```#A_0$`!````.O]`0`.````\/T!`!``
M``#__0$`!P```!#^`0`(````&/X!`!L````A_@$`#````#W^`0`+````2OX!
M`!$```!6_@$`"P```&C^`0`'````=/X!`!0```!\_@$`#@```)'^`0`7````
MH/X!``L```"X_@$`#@```,3^`0`+````T_X!``4```#?_@$`#0```.7^`0`&
M````\_X!``8```#Z_@$`$0````'_`0`"````$_\!``8````6_P$`"@```!W_
M`0`(````*/\!`!4````Q_P$`"````$?_`0`F````4/\!``8```!W_P$`#```
M`'[_`0`0````B_\!``X```"<_P$`"0```*O_`0`)````M?\!``0```"__P$`
M$````,3_`0`2````U?\!``<```#H_P$`#0```/#_`0`C````_O\!``H````B
M``(`!0```"T``@`6````,P`"``4```!*``(``@```%```@`+````4P`"``$`
M``!/!0``X`,``.`&``!_!0``1P0``$$&``##````E`(``*($``#*!0``+P0`
M`)`!````````.0````````````````````````"J`0````````T$``!?`@``
MG@````````#I`0``K00``,X```"]!@``E@4``+\#``!K!```[P````````#6
M`````````````````````````%4$````````<`8```````!A!@``508``/@"
M``!&````H@4``!4!````````Z@$``$\```"(!0`````````````"!P``^`,`
M`/L$``#>`@``*P8``)\&`````````````.L````]!```J@,``#<"``"Y`P``
M/P<````'``#T!@```````.@$``!"`P``(`,``(X!``!'`@```````#8"``"^
M!@``@P8``'$$``!Z!@``2`(``/H"``!I````A0```)$#``!N`@``\08``'<!
M``#;!@``_P(``(T&````````:P```.<&````````>P4```````#U`@``&@,`
M`.D&```'````.`$```````!S````7P4````````'!````````$T&````````
MG@(``!D&```0!@``NP8``"8$``!'`P``#`(```````#V!````````!<$``"N
M!0``60(``-`!```G`@```````,@!``````````````````#X!@``F`,``&L&
M````````)P````D%``"5`0```````.<%```P!@````````````";`P``#P<`
M``````"P`P```````(X"````````]04``!4```"D`0``_@0``'T````(!```
MX`0``!4$``""!```<P,``#P"```.!```,@0``%@%``"R`@``104``,D`````
M````T00`````````````9P,``-4$```S`0``:@```)P"````````OP4``+(&
M````````F08``,L!``#]!@``Z@0``!X`````````D`(``*8#``#=!```U0,`
M`!<%````````.`(``'$%```V!0```````)$```!/`P``Q@0``/\%``#3!```
M"@0```````#_`0``%P(``*`"```M`P``<````````````````````$@&``!/
M!```?`,``.<#```H!```908```````#+````Y@8``)$$````````?P```"\#
M``#7!0``-````#,'```D!P``*08``-\#``!B!@````````````"N!@``0@``
M``````!W!@``;@4`````````````+P4``$4````@!@``G`4``&8"``"C!@``
M,`,````````H!0``+04``(<!```S`````````(<%``#0!```$04``(X#````
M````QP4``&(%```&!@``408````````/!@``!`0``)X!``#E!````````",!
M`````````````/L````%!@``E@,``.8```!O````I````*H%``#-!@``'`8`
M`'\!```A````(@<`````````````90,``$L#`````````````*(!````````
M`````,8&```+!P``+@,``-8$```2!0``(@(```````#K!@``!P,``.L$````
M````2`$``(\#``!G!```N@,`````````````BP0``!````"(`0``Y`,``)0#
M```"`P``N`(``((%```!!```5`(````"```R!@``X@(``$L```"S!0``9P8`
M````````````!````(H"``#2!@```````#X#```>`P```````&($```L!P``
M.0<``(T$```2!P``V````&\$``!7!@````````````!(````^08``&X````#
M`P```````,0&``#2````6P,```````!9`P``Z`(``.P```!C````608`````
M```_`@```````"@"``!!`P``G@,``!T#``".!0``=````!@%```G!P``VP0`
M`!`!```\!@``1@,```````!Y`P``8`````````#U`0``&@8``"<&````````
M````````````````=@,``,<"```X`P```````(`"``#7`0``P0$``!<#``"^
M````60```(P"``"D`@``#`,``#,%````````2P<```````!E`0``/`,`````
M``"W!0``<P$```````#,`@``0`,``%H````_````-@8``&D%``"1`@``/`4`
M````````````V`,```T&````````?0,``#$$``#F`P`````````````)````
M"`$````````7````````````````````%@$``(<&````````3`8``'D$``#3
M!0```````/0%````````;08``#P$``#U`P``V0,``.T$``!!!0``-P0``%P$
M``#>`0``I`8``"H%``#!`P``$@,``+T%``!0!```N`4````````J`@``X`(`
M```````Q`0```````*H"```6`@```````'4!````````<@,``!D"``"4!```
M8P4`````````````J04```````````````````````##`P``$`4```````":
M`@``A@8``(,#``!N`P``W0$``)@&````````SP$``/@!``""`@``````````
M```,!0``I@8```8$``#\````]P8``*<#``".!@``Z@8``(`%``#T`P``M00`
M`"L%`````````````,D"``"K`P``D@8``.D$``">!```A0(```````#)!```
M``````````!^!`````````````"*`0``UP8``.0&```'!0`````````````3
M`P`````````````%````'P$``$X&```R`P``]@8``+@&````````(`$``&<%
M```X!P``@@8``",'````````_@4``#4%``!.!0``?`(``(\!``!"!```G`$`
M`#H&````````>P```"8&`````````````*$"``````````````T#````````
MI0(```````"`!@```````!D#``"(!@```````.X"```6!0``(0$```````!E
M`@````````````#F!```R@0`````````````"0,```$'````````<P4``(\&
M``#6`0``2@<``$@%``````````,``%0&```#!````````*T%``"U`@``````
M`.$&``!5`````@(``!L`````````(08``"8"``"T`0```````"T!```E!P``
M,`4``&P"``")!```````````````````LP```(\%```1`0``FP4``)D#``"I
M`0``?`8``"P&```^````=04``'\"``!.`P``-0$``%X#``!=!@```````&P$
M``"?!````````',&``!Z````LP0```````!4`````````"D!````````HP,`
M````````````*0```$`!````````&0```,(!```,!```V00``#8'````````
M`````$D'````````T08``(,"``#T````W0(``*<"``#Q`````````#L$```;
M`@```````,(%```3!0``X@0`````````````Z`8```X'`````````````&("
M````````SP8``$`$``#A!```800``'8!`````0``A`$``.X!````````````
M`+8%````````1@0``+H`````````7P8`````````````0P8```````!&!@``
M.@````````"Y````+`0``+$"````````Z`,```````##!0``K`(```````#Z
M!0``?`````````#)!@``RP8```````"W`0```````!\$```D`P``PP(``,(#
M````````^P$``'`$````````&`,``,4"```(!0``CP```-H$```G!```````
M``````#0````2@$``"D%```U`@``+@0````````V````ZP$``.(`````````
MAP0```````#1!0``H`0``(T#``"G!@````````````!)`P``>08```````"S
M`@``6`,``/(```"\`@``M`8``)8"``#)`P``$P<``(X$```)`@``)`(``&$%
M```>!0``P0```$4$```8````F@```*L`````````N@8`````````````````
M`'8%```0!P``QP$``*(&``"8!```NP$``,<#``#S`P``J`(``-8&```_!0``
M70```,P```"1!@```````.(!``!W!```6P$``-H```!&`0``K@0``(0&````
M````'P,```````!?`0```````'L#``!+!```@P4``,0```#K`@``MP0``)X%
M``!7`P``[@,```````"#!```\@$``/$!````````2`0``$T```"+!0``````
M`*$$````````404``&X!```#!@``/@4``,T`````````.0(```````"(````
M5P4``&4```!<`0``:P4``/T%```^!@``)@$``'X``````````````(<#````
M````_P0``/L%````````K@```'4$``#,`P````````````#@`0``'08``'(&
M``#0!0``OP0``/,!``#[!@```````.4#```]`````````.,!```>!@``?0(`
M``````!1`0``20$```````!$````VP(``*P#``!Z!0``:00``+$#``#7````
M+0```&8!``!X!0```````*(#````````Z@4``*,!``"O!```LP8````````3
M!```,`0``%0#``!$!```-P4``%`#``!>`0``M04``(T!``!5`@``E@$``!P#
M``!`!P``[`(`````````````Q00```````"[`P``E08``"\&``#5!0``````
M`(4#```S!@``904``$$`````````%0,```````!Q`0``%0<``"<%``#,!```
M`````#H'``#7`@``9`4``.,"```G`P``[`,```````!#````L08``&L"``!<
M`@``70,```````#-`0``+P$`````````````P00``#P````&!P``D@4`````
M``#=````&P,```````!V!@``T@(```````#V`0``%P<```L$``!L````````
M`````````````````+0"`````````````*L$``"_!@``Q@4``/P#```$!0``
MK0````````"U`0``_0$``(H#````````Z0(````````,!@``8`$``"4!``"Y
M!```300`````````````\@0```````!1`````0,``%0%````````,08```4$
M``"O!0``-@0``%H$````````+`,``-P&````````2@(``#4#```U!```;P(`
M`)D```!>````5@$````````Z`@``K@$``#\#``!`````W@````````!K`0``
M``````0#```)!```R@(``'T$```>`0``3P$``,`$```P`0```````*H````I
M`P``>P0``&H$````````IP$``(L#```O````-`,``$H#``"1`0``/0(`````
M```B!0```````-D"``!?``````````````!)`@``8`8``+X!``":`P``@@``
M`*$```!^!0``V@,```````!X!```1P8````````Q!0``-`0``)L````!!@``
ML@$``)````"P!0``!@(``&P#```H!P```````.\"```A!P``Z`4``&0`````
M````'0```&,!````````#P,`````````````/P8``%`!```4`P```````'<"
M`````````````$\&```*!0``/04```````!C`P``Y0```-T&```9`0``````
M`)8&``";!```WP4```````#]`@``7@0``"X&````````R`8``"`$```K!```
M%`````````#!!0``%@<``````````````````!D%``"G!```-`<``$H%````
M````]08``%(#``!2`0``VP4``!P%``"&`0``60$`````````````N```````
M````````#@4```````!=!0``LP,``+$%````````S@$``+P!````````"P4`
M`-8%````````"@```'\$``!"`@``*@8``%8&```+`0``'04``!\`````````
MTP$```\%````````[@````````!$`@```````&8#``"3`0``C0(``(P$``#B
M!0```````/X!``"I!```+@<```````"5`@```````$$$``#W`````````(@#
M``#=`P``O````&<!``"[!0``X0,``#L#```"`0```````&8```#Y````WP(`
M`&@%```<!```30(``!4"```#!P```````"8'``"\!0``5P(``!8`````````
MD@(```````!:!0``#0(``"X```!S`@``8`(``,$&``"`````=08``"0&```N
M`0``%`$`````````````4@4``+@$````````R@```!X$``#E`0``(P4``#<#
M``!`!0``(P0``*4$````````2P$`````````````5@```(D!````````````
M``````"%`0``J@0```````!;!```0P4```8!``!``@```````!,```"=`@``
MSP4``!,"``!O`0```````,<&`````````````!$$````````(````"4"``"4
M!@``V@(```````#.!```^0,```@#``````````````````!0`@``(@,``($&
M``!W!0``:```````````````W````!4&````````:0$``&8$``"Z!```[P0`
M`)4%```"````=`0``%X&``!.!``````````%``#G`````````#X"``"!!```
MM@0````````9!P``````````````````,0``````````````=@```",```"8
M````H0$``,4!``!"!@``A@(``%(```",!@``KP,``/8````Q`P``[0```#(%
M```/`@``X04```````!@`P``?P,``,X"``"&!````````)$%```5!0``)08`
M`.T"``#7`P``T0(``%@!```A`P``=P```&(`````````7`8``*P%``"3````
M`````,<```"]!```XP,``*8"```>`@```````.T!``!0!@```````!\&```E
M!```````````````````I0,``*8```!%`@``H0,``!8$```K````R04``$$!
M```%!0``M@````````#*!@``1`4``%\$``"&!0``YP$``!P"``#;````@0,`
M`.P%```+!@```````$@'````````A`4``/0$``##!@``#04`````````````
MAP````````!F!@```````%@```#:`0``_0,`````````````4@0``$('````
M````WP8```````!H!```MP(``$X'`````````````.8"````````G```````
M``!+!0``Q04``)@!````````&P<``+X"```[`@````````````!3`P``E0,`
M`/X&``"9!0``,`(``"H$``"/!```!P8``'D"````````XP4``!L!``#!`@``
MKP`````````4!```D`0``/`&````````^P,``/D$`````````````)H$````
M`````````,T"``#?````U08``!`$``!6!0``B0,``"\'``!A`@```````#`'
M````````E````(\"```<!P``C``````````+`P``L@4``#@&``!:`@``ZP,`
M`&H"``"@`0``I04``!8&`````````````-8"``"H`P``_0```",&``#"!@``
M`P4``+H!````````>P$```````!H`0``D`4`````````````30,``/$#``!'
M````LP$``#,"``"@`P``;0$``/\#``!F!0``$@0`````````````/08``+X$
M```A!```]P$``(T%``#W!0``BP(``*````!>`@``GP(``.@!``!D`0``+0<`
M`'0%``#P!```1`8``,`%``![!@``80```+8!`````````````+X%````````
MX0$```````!O!0``0P<``)4```#D`0```````#L'```C`P```````#4&``"M
M`@``T`8```@'``"[`@``U`8``$<!````````KP$``#\$````````1`,``)T%
M``"E````Y08``,T#``"X`P``^0$```8````J`0```````#D&``!I!@``````
M`-L!````````T`(``+0#``#6`P``#0```*8%``!E!```#@$`````````````
M-P<``&0$``"*!```?`0``+4``````````````)H!``!!!P```````%(&````
M````.P4``-,&``#Q!0``Z0`````````Y!`````````($``#E`@``2P8``+D&
M``!M`P``204``*D```#(`@``7`4``,L$```/````Y@$``$P$``!J!0``V`(`
M`(D"``!G`````````(L&```3!@``N@(```````#3`@``_`0```````#K!0``
M.````&H!````````:P,``,H!```;!```:`,``*,$```'!P``G0$```````!P
M`0``U0```#\!````````%`(``&,$``"@!0```P```#P'``#\!@``C`$``.X$
M``"H!```HP`````````2!@```````#T!``!O`P``8`4``,`"``#W`P``6P8`
M`,P%``"*!0``-`(``!\%``"%!```6P```'$&``"4`0``3`,``$T!````````
M8@,``!0'````````:0,``)`&``!=`@``9P(``!H```#P!0``````````````
M````J0,``-\!```Q!P``=0,```````#%````3@(```````#L`0``````````
M``!,`0``/0<````````=!```U`$``+P#``!%!@``V@8``$H$``"0`P``A`(`
M`)P&``#M!@``R`,``#('````````````````````````=0```/H!```I`@``
MT@4``#P!``"9!```.@4```````"E`0``T0,``````````````````,X%````
M`````````)P#``!Y!0``4P4``%8"```````````````````R`0```````,(`
M``"X`0``7P,``(0``````````@4``(4%``"\!```GP````P```#G`@``HP(`
M`*("``";!@``*`$```````"?!0````````````";`@``'@<``$8'``!*````
M:@,``,@````4!0``\@,`````````````OP```.H#````````E00```````":
M!0``F`4````````1!P```````$H&```/`0```````&0&```^`0``````````
M``"7`P``"@(``#0%``"*````>`,``"8#``#\`0``20```)($```D`0``````
M`+X#``"U!@```````.X&``#9````JP$``"<!````````-0```&`$``!L!0``
M'P<``,0#````````[P4`````````````FP$````````E`P``,P0``)(````A
M!0```````,0!``#X!0``J`$``.T%``#V!0``3`(``$$"``"C!0``XP8`````
M``!3`@`````````````F!0``J08``($"``!,!0``W@0``'4"``"Y`0``?@,`
M`(D%````````U`0`````````````+P(``.@`````````50$``,L%````````
M5P$``````````````````*L&``#2!````````#D#```E!0``G0````````!Z
M`0````````````````````````````!#`0```````%H&``"R`````````!D$
M``#D``````````\$```2`@``#@````X"```1`@``@`$``-<$``#V`P``+08`
M`.D%````````Z@(``````````````````'(````3`0```````,\#``"9`@``
M^0(```````#>!0``\@4```````#=!0``Q@,````````Z`0``3@```+0$```W
M!@``=`(``)\#``!;!0``:0(``%8#``#<!```.`4``-0#``#S!0``/@<``+`!
M````````SP(``+<&`````````````&(!````````10$``+`"``".````````
M`.<$````````>@,``%P#``#R`@```````*D"``"(`@```````/,$``!]!@``
MS`8```````!Y`0``1`$``)P$``"?`0``@@$``-0%``#P`@``6@,``!@$``"G
M````\`,``%,```#"`@``L@,``.\!``#:!0``Q0,``&X&````````(`4``#4'
M```I!`````````````!)!@``````````````````5@0``,@$``#X!```?04`
M`.H`````````W`,`````````````X0`````````H!@``40(``*H&```)!P``
MPP0``),#````````1P<``$T'````````]P(``)T#``#>`P``;`8``/T$``#2
M`0``5P```*X"``"6!```````````````````QP0``,`&``"O!@``>````!0&
M``!X`@``!0(``&0"``!>!0``4P8``/H```#B`P``3P(````````;!0``H@``
M`"(````L`@``?`4``#L!``"`!```.P```-D!````````;`$``#(```#-!```
M\`$`````````````!0,``+H%``!M````6@$``.(&```J!P``4P$``&T%``#5
M`@``M@,```$%``"O`@``!@,``/8"````````W`4``%T$```8!P```````)<"
M````````````````````````<0,``(T```!,`````````-P"````````````
M``````"*!@``&@<``'`%``"_`0````````````#I`P``:`(``&T"``"$!```
MWP0``$0'````````!`(``$(!``#U!```#`<``(P#``"%!@`````````````P
M````+0(``.\&``"F!```V`8``.0$``#Z!@``?@8``)<$``#.`P``XP```,4&
M```=`@```````,\$``#L!@``(`<``+<````)!@```````$4'``"R!```````
M`(L``````````````*0%``"@!@``&@0```@`````````\P(``-0"```E````
M]`(``(8#```L````50,``#0!``#$!0``"`8``.\#```$`0```````,($``">
M!@``/@0```````#Q`@``*@```"X"`````````````%@"````````#@,`````
M``#1````Y`4``!<&``"H````(0(```H&``"Y!0``_P````````!&`@```P(`
M`-X&`````````````*<%``"M`0```````%@$``#E!0``+@4``%$$```S`P``
M/0,``&,"``!)!```"`(``.$"``#Q!```R@,``!\"```Y`0``0@4```````#3
M````3`<``-@!``!_!@```````+`````:`@``L`8``,0"``#L!```X`4``!@!
M``"D!````````/,```!4!```8P8```L"``"[`````````'8$```$!P``;P8`
M`,````#Y!0```P$``$4#``"L`````````%("````````R`4``,0$``")````
M;00``"P!```1!@```````*$&`````````````-L#``#[`@``"@,```4'``"U
M`P``\@8`````````````'````"($``"#`0``=@(```````"L!@``.@,``(D&
M``!3!```'0<``"8````W````_`(``)@"``##`0``=P,```````!-!0``U0$`
M`'L"``#X```````````````T!@``(`(``"@#``!^`@``^@0``"L'``#P````
MJ`8``'`#```[!@```````#8#``"``P``?`$```````"K`@``=`$``+0%```W
M`0``!P$```````````````````````#8!0`````````````0`P``L`0``#H$
M``#F!0``0P0``),$``"3!0``!`8``$8%``#9!@``O`8``*P!``!A`0``4`4`
M```````'`@``5P0``-@$``!5!0``&P8```````"H!0``G00`````````````
MD@$```````#^`@``?@$````````Q`@``L0$``!@&``!X!@``EP4`````````
M````*````(8`````````````````````````@0$``*L%``",!0``*@,`````
M``#T`0``M`````````#&`@``#`$``#8!``""`P````8```L```!A`P``BP$`
M``````"2`P``!@4```````"3!@```````',$``#Z`P``)`0``'(!``"N`P``
MW`$```````"!!0``RP(``'H"````````>`$``.0"``"M!@````````T!````
M````AP(`````````````<0`````````1`P``M@(``+T!````````````````
M``"Y`@``K0,``/<$````````.`0``!P!`````````0$``-$!````````R0$`
M`,L#````````$@$``)0%``"V!@``O0,``($`````````T@,``$X!```)`0``
M``0``%0!``"D`P``K`0```````!P`@``[@4``'(%```"!@``+`4``,8```#\
M!0``0P(``(,```````````````H'``#0`P```````,P!``!N!```(@8``*8!
M``"W`P```````"(!````````````````````````6`8````````6`P``P`,`
M`/X#``"_`@```0(``"0%``!1`P``B`0``)D!```=`0``]0````````"[!```
MXP0``$,#```K`P``2P(```T'````````>@0```````!=`0``#@8``-,#```K
M`@````````````":!@```````,X&````````&`(````````%`0```````)<&
M````````X````&H&````````4````!H%``!9!```G08``+T````1````9`,`
M`,8!``#S!@``<@(``"0```!Y`````````"L!``!Q`@``"@$````````2````
M(P(``)<!``!<````*0<``$@#``#4````,@(```````!'!0``_@````````!T
M`P```````/\&```Y!0``E@``````````````0`8```````#``0``S04``+$$
M``"$`P```````),"```7`0```````!`"``!H!@``I08``%D%```:`0``H04`
M`,\`````````+00```````"7````=`8`````````````6P(``+$```!]`0``
M<@0``-D%````````[0,``+T"````("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P
M97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L
M;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@
M*'EE<W1E<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60M9&%Y(&9O<F5C87-T
M`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S($-O;F9I9W5R871I
M;VX`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G
M<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:&%S
M(&-A;F-E;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@
M<F5Q=65S="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@
M)7,N`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!R97%U
M97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@<F5Q=65S=',@
M>6]U<B!P<F5S96YC92!A="`E<RX`)7,@=&\@)7,@;V8@)7,`)7,@=VES:&5S
M('1O(&%D9"!T;R`E<RX`)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F
M("5S+@`E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T
M:6]N(&%B;W5T("5S+@`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R
M`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@=6YA8FQE
M('1O(&QO860@9')I=F5R.B`E<P`G)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC
M92X`)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T
M<GDN`"<E<R<@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"<E<R<@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E871E9#H@
M)7,N`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`
M+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T
M(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`041322!E<G)O<B`E<RX`04T@4VAO=V5R<P!!32]030!!4$D@240`06)O
M=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!
M8V-E<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E<W,@1&5N:65D+@!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F
M<F]Z96XN`$%C8V]U;G1I;F<`06-T:6]N<P!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P
M`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`G)7,G
M`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@)R5S)P!!9&0@82!N97<@=7-E
M<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY
M(&-A;&5N9&%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R
M97-S(&)O;VL`061D('5S97(`061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B
M=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO
M;CH@)7,N`$%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D
M<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A
M;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U
M=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`
M06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S
M`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I
M8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YD
M;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!
M;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P
M;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R
M;W9E`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@
M4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B+6=R;W5P<S\`
M07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R
M=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!2
M96=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8VAE
M9"!I<R!A;B!I0V%L96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U
M('-E;G0`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E
M<P!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I
M=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE
M('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E
M`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VME;F0@;F]T(&-O<G)E8W1L
M>2!I;7!L96UE;G1E9"X`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A
M9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"
M86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87)B861O<P!"87)E`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI
M>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";&]C:R!S96QE8W1I;VX`0F]L9`!";VQI=FEA`$)O
M;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N
M:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E
M="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R
M>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U
M<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0
M;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A;6)O
M9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E
M(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)
M<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E
M;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A
M=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86ER(%!E
M<G-O;@!#:&%N9V4`0VAA;F=E(%!A<W-W;W)D`$-H86YG92!P87-S=V]R9"!O
M;CH`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H
M86YG92!Y;W5R('!A<W-W;W)D`$-H86YG:6YG('!A<W-W;W)D(&]N("5S`$-H
M87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A
M=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAI
M;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@
M5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A
M('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H;V]S92!H;W<@=&\@9&ES
M<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R
M960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE
M87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L
M:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN
M9&]W`$-L;W5D<P!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L
M;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O
M;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M
M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O
M<P!#;VUP86YY`$-O;7!L971E9`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP
M=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O
M;F9I9W5R871I;VX@;F5E9',@=7!D871I;F<N`$-O;F9I9W5R92`E<P!#;VYF
M:7)M(%!A<W-W;W)D`$-O;F9I<FT@;F5W('!A<W-W;W)D.@!#;VYG;P!#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@
M9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N
M;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E
M;G1S(&]F("<E<R<`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y
M`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-A;&P@9G5N
M8W1I;VX@)7,@:6X@87!P;&EC871I;VX@)7,N`$-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<@!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N`$-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N`$-O=6QD(&YO="!M:V1I<B`G
M)7,G+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@)R5S
M)R!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N`$-O
M=6QD(&YO="!O<&5N('!I<&4@=&\@<VUB<&%S<W=D+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("<E<R<N
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=7)A=&EO;B`E<RX`0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N`$-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("<E<R<N`$-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R("<E<R<Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I
M=F4@=7-E<B`G)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R("<E<R<Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E
M871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@4&AA<V4`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO
M;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL
M:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A
M=&$`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S
M96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@
M;G5M8F5R<P!$96-L:6YE9`!$96-R96%S92!);F1E;G0`1&5F875L="!#;VQO
M<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L
M="!P97)M:7-S:6]N<P!$969I;FET:6]N<P!$96QE9V%T92!P;W-I=&EO;@!$
M96QE9V%T960`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO
M;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T
M92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<`1&5L971E('!E<FUI<W-I;VYS
M(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W
M`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@<&5R
M;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S971U
M<"!U<&=R861E('-C<FEP="`G)7,G+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`
M1&5N>2!R97%U97-T`$1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`
M1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT
M.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O
M(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA
M>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M
M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D
M96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P
M=6)L:6,`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`
M1')U9W,`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET
M($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<`161U
M8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`
M16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA
M:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N
M`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9`!%;F0@>65A
M<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@1W5I
M;F5A`$5R:71R96$`17)R;W(`17)R;W(@<V5N9&EN9R!D871A('1O('-M8G!A
M<W-W9"X`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`G)7,G+@!%<W1O;FEA`$5T:&EO
M<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AE8W5T90!%>'!A;F0`17AP96-T960@)RDG`$5X<&5C=&5D(&)A
M<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E
M`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O
M("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`
M1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O('9E<FEF>2!O;&0@
M<&%S<W=O<F0N`$9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,Z
M("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES
M;&%N9',`1F%T86P@17)R;W(A`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E
M96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&:6II`$9I;&4@0V]U;G0Z("5S(&9I
M;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M
M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@
M475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S
M="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R
M;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W
M;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T
M=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC
M92P@365T<F]P;VQI=&%N`$9R964O0G5S>2!);F9O<FUA=&EO;@!&<F5E+T)U
M<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`1G)E92]"=7-Y(%)E<75E<W0@
M4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC
M:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E
M<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S
M($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY
M`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@
M4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R
M965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI<W-I;VYS`$=R;W5P
M<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E
M<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`
M1W5I;F5A+4)I<W-A=0!'=7EA;F$`2$@`2%1-3`!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E
M<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93H`2&EG:`!(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`
M2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R
M<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@
M;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE
M`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R
M>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB
M;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E
M871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V
M86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O
M<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET
M>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T97(`26YC;W)R
M96-T(%!A<W-W;W)D`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!)
M;F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);G-E<G0@0U]O;'5M;B!!9G1E
M<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!)
M;G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R
M="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE
M<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P
M:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!)
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK
M`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E
M<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O
M;F5N="X`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI
M9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A
M('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A
M;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L
M+@!);G9A;&ED(')E8VEP:65N=#H@)R5S)P!);G9A;&ED('-H87)E(&]B:F5C
M=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T
M82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)
M<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)
M<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A
M;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU
M<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F
M=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N
M>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+
M97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME
M>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T
M<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P
M=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA
M7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L
M:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@
M;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@
M3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O
M<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S
M;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS
M=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B`O(%=I
M;F0`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I
M;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,
M:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O
M.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@
M=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP
M(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI
M<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES
M="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A
M;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S
M:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,
M;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L
M871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-
M30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`
M35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U
M8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME
M(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A
M`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA
M8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H
M;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`
M36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@
M;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L
M;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N
M:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T
M90!-961I8VEN90!-965T:6YG($-A;F-E;&QA=&EO;@!-965T:6YG($EN9F]R
M;6%T:6]N`$UE971I;F<@4')O<&]S86P`365E=&EN9R!297!L>0!-965T:6YG
M(%5P9&%T90!-965T:6YG(%5P9&%T92!297%U97-T`$UE;6)E<G,`365N=2!M
M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP
M90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971H;V0@)R5S
M)R!I<R!N;W0@9&5F:6YE9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU
M;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES
M8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-
M:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K
M86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`
M36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L
M9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y
M96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO
M<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O
M=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V
M92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-
M=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R
M=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA
M;6EB:6$`3F%U<G4`3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE
M=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E
M($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T
M<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R
M`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R
M;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9#H`3F5W
M('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(%!A
M9V4`3F5X="!0:&%S90!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP
M;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@
M=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!L;V-A=&EO;B!I<R!S970N
M`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N
M=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC
M871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D
M+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET
M:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`
M3F\@<VED97,`3F\@<W5C:"!B86-K96YD("<E<R<@9F]U;F0N`$YO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F]N(%!A<G1I8VEP86YT`$YO;F4`3F]N92`H
M=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES
M;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L
M86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T
M;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.
M;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E`$YO=F5M
M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L
M=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J
M96-T($-R96%T;W(`3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,`3V-T86P`
M3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD('!A<W-W;W)D.@!/
M;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E
M<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;F%L(%!A<G1I8VEP86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E
M9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N
M:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@
M5"U3=&]R;7,`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE
M=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V0@:7,@;F]T
M('!R;W!E<FQY(&-O;F9I9W5R960N`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG
M960@;VX@)7,N`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!M;V1U;&4@
M8V%N)W0@9FEN9"!T:&4@<W5P<&QI960@8FEN+@!087-S=V]R9"!M;V1U;&4@
M:7,@;6ES<VEN9R!R97%U:7)E9"!P87)A;65T97)S+@!087-S=V]R9"!M;V1U
M;&4@:7,@;6ES<VEN9R!T87)G970@<&%R86UE=&5R+@!087-S=V]R9"!M;V1U
M;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960`4&%S<W=O<F0@;6]D=6QE
M(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+@!087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S
M="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD
M:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`G)7,G(&YO="!D96QE
M=&5D+@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)M:7-S:6]N<R!F
M;W(`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S
M`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K
M('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E
M<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U
M($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN
M`%!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD
M('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0
M;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0
M;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI
M=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E
M`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E
M<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA
M<W0@)7,@:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S96YT871I;VYS`%!R97-S
M=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE
M=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@
M4&%G90!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@
M2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M
M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI
M8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN
M`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@+R!3;F]W`%)A:6X@+R!3
M;F]W(%-H;W=E<G,`4F%I;B`O(%=I;F0`4F%I;B!%87)L>0!286EN($QA=&4`
M4F%I;B!3:&]W97(`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE
M<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@
M>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R
M;W=S97(`4F5M87)K<P!296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@
M8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M(&UY(&-A;&5N
M9&%R`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T
M:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E
M('5S97(Z("5S`%)E<&QY(%-E;G0N`%)E<&QY('=I=&@@3F]T(%-U<'!O<G1E
M9"!-97-S86=E`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N
M=&AS+@!297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN`%)E<&QY.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2
M971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"`G)7,G(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)R5S)R!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G)7,G(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1R:79E
M<G,G(&ES(&UI<V-O;F9I9W5R960@:6X@0V]M<&]S:71E(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(%!A<W-W
M9"!344P@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S
M<&5C:69I960@:6X@4U%,(&-O;F9I9W5R871I;VXN`%)E<75I<F5D(%!A<G1I
M8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O
M<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R="!#
M;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S
M`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T
M:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O
M=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S
M.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O
M;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2
M=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-1
M3"!3:&5L;`!34P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE
M;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I
M($%R86)I80!3879E`%-A=F4@)7,`4V%V92`G)7,G`%-A=F4@3W!T:6]N<P!3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S
M(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B`G)7,G+@!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@
M1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L
M96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R
M('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N
M(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T
M:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T
M:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM
M:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T:&ES(&EF
M('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG('1H92!);G1E<FYE="!%
M>'!L;W)E<@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z`%-E;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA
M(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I
M<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M(&1I<W!L87D@;W!T:6]N<RX`4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H
M;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@+R!7:6YD`%-H;W=E
M<G,@16%R;'D`4VAO=V5R<R!,871E`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE
M<G)A($QE;VYE`%-I9VX@=7``4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9`!3
M:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3
M:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<@4VAO=V5R
M`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO
M;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@
M<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%
M=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C
M92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N
M="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A
M;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I
M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!Y96%R`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B
M:F5C="!0=6)L:6,@2V5Y($EN9F\`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C
M<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@)R5S
M)R!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("<E<R<N
M`%-U8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O
M('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VX@)7,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BX`4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6-C97-S9G5L
M;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z
M97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R
M86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!4
M86)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E
M<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R
M93H@`%1E;7!L871E("<E<R<@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES
M=')A=&EO;@!496YT871I=F5L>2!!8V-E<'0@<F5Q=65S=`!496YT871I=F5L
M>2!!8V-E<'1E9`!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN
M9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA
M8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@
M;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@
M8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O
M;FQY`%1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;G1A8W0@
M240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A
M<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R
M97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&5V96YT
M(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO
M="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N
M;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI
M<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B
M86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@
M<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F
M="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S
M(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H
M870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4
M:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A
M9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O
M('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R
M:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S
M<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&%S:R!H87,@8F5E
M;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T
M82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY
M(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E
M<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E;2X@
M)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y
M<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A
M<R!A('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ
M92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D
M+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@
M<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT
M.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A
M<VLZ("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F
M<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+@!4:&5R92!W87,@86X@97)R;W(@
M:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O
M=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES
M(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@
M>65T(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@
M82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E
M<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S
M`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M
M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O
M;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE
M(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME
M;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS
M;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`
M5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R
M(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP
M="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='D`56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RX`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@
M=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5
M;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@
M<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`G)7,G+@!5
M<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P
M<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA
M=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#
M=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I
M9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U=&AO
M<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N
M<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&YO="!F;W5N9`!5<V5R
M(&YO="!F;W5N9"X`57-E<B!P97)M:7-S:6]N<P!5<V5R;F%M90!5<V5R;F%M
M92`G)7,G(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5
M<V5R<P!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E
M8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N
M<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F
M<F]M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U
M`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@
M*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I
M97<@87,@)7,`5FEE=R!E=F5N=`!6:65W('1A<VL`5FER9VEN($ES;&%N9',L
M($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I
M8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%L;&ES(&%N
M9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@
M9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E
M:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!3
M86AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E
M<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`5VAI8V@@
M<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7
M:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@
M;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I
M9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0@
M<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`
M5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<FET:6YG(&YO="!P;W-S
M:6)L92X@66]U(&-A;B!E:71H97(@=7-E('1H92!A=F%I;&%B;&4@=7!G<F%D
M92!S8W)I<'0@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E
M<RX`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS
M:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L
M($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!C86XG="!C:&%N9V4@<&%S
M<W=O<F0@9F]R('5S97(@)7,`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E
M;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@
M=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S
M(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@
M=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E
M+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S
M92!3:6=N=7!S+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T(&=I=F4@>6]U<B!C=7)R96YT('!A<W-W;W)D`%EO=2!M=7-T(&=I=F4@
M>6]U<B!N97<@<&%S<W=O<F0`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!M=7-T('9E<FEF>2!Y;W5R
M(&YE=R!P87-S=V]R9`!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O
M;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N
M("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D
M969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&YE=R!P87-S=V]R9"!I<R!T;V\@
M;&]N9SL@<&%S<W=O<F1S(&UA>2!N;W0@8F4@;6]R92!T:&%N("5D(&-H87)A
M8W1E<G,@;&]N9R$`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T
M;R!G=65S<R$@($YO="!C:&%N9V5D(0!9;W5R(&YE=R!P87-S=V]R9"!I<R!T
M;V\@<VEM<&QE('1O(&=U97-S+B!.;W0@8VAA;F=E9"$`66]U<B!N97<@<&%S
M<W=O<F0@;75S="!B92!A="!L96%S="`E9"!C:&%R86-T97)S(&QO;F<A`%EO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@9&EF9F5R96YT(&9R;VT@>6]U<B!C
M=7)R96YT('!A<W-W;W)D`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I
M;B!A="!L96%S="`E9"!A;'!H86)E=&EC(&-H87)A8W1E<G,N`%EO=7(@;F5W
M('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!A;'!H86YU;65R
M:6,@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN
M(&%T(&QE87-T("5D(&1I9F9E<F5N="!T>7!E<R!O9B!C:&%R86-T97)S+B!4
M:&4@='EP97,@87)E.B!L;W=E<BP@=7!P97(L(&YU;65R:6,L(&%N9"!S>6UB
M;VQS+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@
M)60@;&]W97)C87-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!N=6UE<FEC(&-H87)A8W1E<G,N`%EO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!U<'!E
M<F-A<V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT
M86EN(&QE<W,@=&AA;B`E9"!W:&ET97-P86-E(&-H87)A8W1E<G,N`%EO=7(@
M;F5W('!A<W-W;W)D(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C:&%R
M86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9',@9&ED;B=T(&UA=&-H`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C
M:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R
M9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB
M:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M
M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X
M="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N
M`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM
M86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI
M;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?
M4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O
M:P!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`9F%L;&EN9P!F:6QE`&9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,`:#H`:3$X;@!I;6UE9&EA=&4`:6YL:6YE
M`&QD87!?<W1A<G1?=&QS(&9A:6QE9`!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C
M;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D
M`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!R
M:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W1E
M861Y`'1A<VL@;&ES=`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T
M:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(%!A<W-W9"`S+C`M8W9S"E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`T+3$Q+3(T(#$V.C0T*S`R,#`*4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-"TQ,2TS,"`R,#HT-RLP,C`P"DQA<W0M5')A;G-L871O
M<CH@5FEL:75S(%-U;7-K87,@/'9I;&EU<T!L;FLN;'0^"DQA;F=U86=E+51E
M86TZ($QI=&AU86YI86X@/'9I;&EU<T!L;FLN;'0^"DU)344M5F5R<VEO;CH@
M,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U
M.2TQ,PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@)B,Q-3$[
M("5S('!A<VER96YGYG,@871L:6MT:2!N=7)O9'ET=7,@<')O9FEL86MT:6YI
M=7,@=F5I:W-M=7,N`"`H<')I9?`@)7,@9&EE;F%S*0`@*&UY9W1U:V%S("5S
M*0`@*/!I86YD:65N*0`@*'9A:V%R*0`@`"5D("5S(&ER("5S`"5D+61I96[X
M('!R;V=N;WKK`"5S("T@<&%S=&%B80`E<R!V86QD>6UA<P`E<R!N=7-T871Y
M;6%I`"5S(&%N='-P875D87,`)7,@2T(`)7,@<')O9FEL86MT:6MO<R!V96EK
M<VUA:2`M('!A='9I<G1I;FEM87,`)7,@<F5G:7-T<F%C:6IA`"5S(&YU;W-T
M871O<P`E<R!J874@96=Z:7-T=6]J82X`)7,@)7,@)7,`)7,@;G5T<F%U:^L@
M)7,N`"5S(&%T<V%KZR#A('7^:VQA=7/@(&%P:64@=?YI;71U;>`N`"5S(&%T
M<V%KZR#A(&MV:65T:6W@(&1A;'EV875T:2`E<RX`)7,@871S:75N=.L@:6YF
M;W)M86-I:N`@87!I92!U_FEM='5MX"X`)7,@>7)A('!R:79A;&]M87,`)7,@
M;6EN=73K<P`E<R!N97)A<W1A<RX`)7,@:VQA=7-I82!A<B!*^W,@=?YI;71A
M<R]L86ES=F%S+@`E<R!P<F'P;R!*^W/X(&1A;'EV875T:2`E<RX`;G5O("5S
M(&EK:2`E<R!I\"`E<P`E<R!N;W)I('!R:7-I:G5N9W1I('!R:64@)7,N`"5S
M(&YO<FD@<')A;F7P=&D@:G5M<R!A<&EE(&%R=.MJ86YTX2`E<RX`)7,@;F]R
M:2!G875T:2!N875J875S:>`@:6YF;W)M86-I:N`@87!I92`E<RX`)7,@861R
M97/X(&MN>6=E;.L`)7,@:V%L96YD;W)I=7,`)7,@=?YR8?#X(&MN>6=E;.L`
M)7,@9&%R8O@@<^!R8?!A<P`E<SH@)7,`)7,Z(&YE<&%V>6MO('7^:W)A=71I
M('1V87)K>6MLZW,Z("5S`"<E<R<@>7)A(&YE;&5I<W1I;F$@<F5I:_!MZRX`
M)R5S)R!N97-U:V]N9FEG^W)U;W1A<R!(;W)D92!R96=I<W1R92X`3NMR82`G
M)7,G(&UE9/YI;R!G96YE<F%T;W)I875S+@!'<G5PZR`G)7,G('-U:W5R=&$N
M`%1E:7/K("<E<R<@<W5K=7)T82X`)R5S)R!N96)U=F\@<W5K=7)T83H@)7,N
M`"P@9_MS:6%I("5S("5S`"P@:VEN=&$@;G5O("5S(&EK:2`E<P`M+2!P87-I
M<FEN:VET92`M+0`Q,B!V86QA;F3X(&9O<FUA=&%S`#(T('9A;&%N9/@@9F]R
M;6%T87,`,C0@=F%L86YD;W,`T&EA;2!B;&]K=6D@<F5I:V%L:6YG82!V:65T
M82!D=6]M96[X(&)A>NMJ92X`P79Y:V\@<FEM=&$@:VQA:61A`$YO<NMD86UI
M('7^:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%!'
M4"!R86MTX"X`3F]RZV1A;6D@<&%T:6MR:6YT:2!P87-I<F'P>73@(&QA:?!K
MX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4$=0(')A:W3@+@!.;W+K9&%M
M:2!A=&MO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I
M<B!S;&%P=.!JX2!01U`@<F%K='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R
M87KF+@!.;W+K9&%M:2!P87-I<F'P>71I(&QA:?!KX"!P<FEV86QO=&4@='5R
MZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4$=0(')A:W1U<RP@8F5I(/YI;F]T
M:2!S;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@871K;V1U;W1I(&QA:?!KX"!P
M<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%(')A
M:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@<&%S
M:7)A\'ET:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L
M87!TX&KA(%,O34E-12!R86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A
M>N8N`$YO<NMD86UI('7^:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT
M:2!V:67PX&KA(%,O34E-12!R86MTX"X`041322!K;&%I9&$@)7,N`$%-(')O
M9'EM87,`04TO4$T`05!)($E$`$%P:64@\.$@<F5D86MT;W)I^`!!<&EE+BXN
M`%9I<VGP:V%I(&%P8>AI;VIE`%9I<VGP:V%I('!E<B!V:61U<N$`4')I:6UT
M:2!U_FML875SX`!0<FEI;71A`$YE=?YT96YK82!T96ES:?@N`%-I<W1E;6$@
M;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!K871A;&]GX"X`4VES=&5M82!N
M971U<FD@=&5I<VGX('-U:W5R=&D@5D93(&9A:6S@+@!3;&%P=&'^;V1I<P!3
MX'-K86ET82!U_O!A;&1Y=&$N`$%P<VMA:71A`%9E:6MS;6%I`%-U:W5R=&D`
M4W5K=7)T:2!P;V=R=7#A`%-U:W5R=&D@<&]T96ES97,`0FQO:V\@X71E<G!I
M;6%S.@!3=6MU<G1I(&YA=6K@(&=R=7#F`%-U:W5R=&D@;F%U:F%S('1E:7-E
M<P!0;V=R=7!I;R!G<G5P96D@)R5S)R!S=6O[<FEM87,`4&]T96ESZW,@=&5I
M<V5I("<E<R<@<W5K^W)I;6%S`$YA=6IO('9A<G1O=&]J;R!S=6O[<FEM87,Z
M`%!R:63K=&D@<W1U;'!E;.$`3F%U:O@@;F%R:?@@<')I9.MJ:6UA<P!3=6MU
M<G1I('!O<N``4')I9.MT:2`E<R!M96YI=2!P<FEE($UO>FEL;W,@X7)A;FMI
M^"!J=6]S=&]S`,%T<F%U:W1I('1A:2#A(&UA;F\@:V%L96YD;W)I^`#!=')A
M=6MT:2#A(&%D<F5S^"!K;GEG96SF.@#!=')A=6MT:2#A(&UA;F\@861R97/X
M(&MN>6=E;.8Z`%-U:W5R=&D@=F%R=&]T;VK@`%9A<G1O=&]J87,@)R5S)R!S
M=6MU<G1A<RP@=&'H:6%U('!A<&EL9&]M82!R96=I<W1R86-I:F]S(&EN9F]R
M;6%C:6IA(&YE8G5V;R!I\'-A=6=O=&$Z("5S+@!687)T;W1O:F%S("<E<R<@
M<W5K=7)T87,N($=A;&ET92!P<FES:6IU;F=T:2X`5F%R=&]T;VKX(&O[<FEM
M87,@:?!J=6YG=&%S+@!!9')E<V%S`$%D<F5S86D`061M:6YI<W1R=6]T:2`M
M(&=A;&D@;G5S=&%T>71I('1E:7-E<R!K:71I96US('9A<G1O=&]J86US`%9A
M;&1Y;6%S`$)A;F5R:6%I`$%F9V%N:7-T86YA<P!!;&)A;FEJ80!!;/YY<F%S
M`%!R879A<F3K`$QY9VEU;W1I`$QY9VEA=FEM87,Z`%9I<V]S`%9I<VD@<')I
M<VEJ=6YGYB!V87)T;W1O:F%I`%9I<V]S(&=R=7#K<P!6:7-O<R!T96ESZW,`
M5FES;W,@:V5T=7)I;W,@<'5SZW,`3&5I<W1I(&ME;&5TX"!A9')E<_@`3&5I
M<W1I(&YA=61O=&D@<W5R^_!I=6]TX"!SX')A\.`_`$IA=2!E9WII<W1U;VIA
M`$%L=&5R;F%T>79U<R!)35-0('!R:7-I:G5N9VEM87,`06QT97)N871Y=G5S
M($E-4U`@<VQA<'1A_F]D:7,`06QT97)N871Y=G5S($E-4U`@=F%R=&]T;VIO
M('9A<F1A<P!!;'1E<FYA='EV=7,@96PN('!A\'1O(&%D<F5S87,`06QT97)N
M871Y=OMS(/!A8FQO;F%I`$%L=&5R;F%T>79U<R!T96MS=&%S`$%M97)I:V]S
M(%-A;6]A`,%V963K=&4@;F5L96ES=&ENX"!R96EK\&WF+@!!;F1O<F$`06YG
M;VQA`$%N9VEL86D`06YO;FEM:6YI<R!P<F]X>2!S97)V97)I<P!!='-A:WEM
M87,`06YT87)K=&ED80!!;G1I9W5A(&ER($)A<F)U9&$`36]D=6QI<P!-;V1U
M;&ES('9E:6MI82!G97)A:2X`4')I=&%I:WET:2!I<B!P;_!A:VEA;7,`4&%T
M=FER=&EN=&D`0F%L86YD:7,`07)A8FGP:V$@*%=I;F1O=W,M,3(U-BD`07)C
M:'EV;R!F86EL;R!D>61I<P!!<F-H>79O(&9A:6QO('!A=F%D:6YI;6%S`$%R
M('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@)7,@<F5G:7-T<F%C:6IO<R!P<F'P
M>6W@/P!!<B!T:6MR86D@;F]R:71E(&GP=')I;G1I("<E<R<@:7(@=FES=7,@
M<&]G<G5P:75S/P!!<F=E;G1I;F$`07)MZVYI:F$`07)MZVYI\&MA("A!4DU3
M0TE)+3@I`$UE;F%S`$%R=6)A`$MR:7-T875S(/YE;F=I;6\@X2!D86YG^"!S
M86QA`$%C<VEI(&UE;F%S`$%Z:6IA+U)A;6EO:F\@=F%N9&5N>6YO(')E9VEO
M;F%S`$%R('!R8?!Y=&D@<&%T=FER=&EN=&D@<')O9FEL86MT:6MO<R!V96EK
M<VUU<S\`4')I<VMY<FEM;R!S='5L<&5L:6%I`%!R:6MA8FEN=&%S(&9A:6QA
M<R!Y<F$@871S86MY;6%S(.$@2OMS^"!I0V%L96YD87(@=?YK;&%U<^``0F%N
M9&]T92!I\'1R:6YT:2!N965G>FES='5O:F%NZ&G@(&=R=7#F+@!"86YD;W1E
M(&GP=')I;G1I(&YE96=Z:7-T=6]J86[H:6%S('1E:7-E<RX`0F%N9&]T92!R
M961A9W5O=&D@;F5E9WII<W1U;VIA;NAI87,@=&5I<V5S+@!"86YD;W1E(')E
M9&%G=6]T:2!N965G>FES='5O:F%N=.$@96QE;65N=.`N`$1A;'EV:6%I`$%T
M<FEB=71A:0!2=6=P:OMT:7,`075S=')A;&EJ80!!=7-T<FEJ80!!=71H7V-Y
M<G-Q;#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+@!!=71H
M7V-Y<G5S.B!C>7)U<R!N971U<FD@<F5I:VEA;?@@9V%L:6UY8FGX+@!!=71H
M7V-Y<G5S.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0(&UO9'5L:7,N`$%U
M=&A?9G1P.B!N97)A<W1A<R!R96EK86QI;F=A<R!&5%`@;6]D=6QI<RX@4W5K
M;VUP:6QI=6]K:71E(%!(4"!S=2`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@
M;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+@!!=71H7VMR8C4Z
M(&YE<F%S=&%S(')E:6MA;&EN9V%S(&MR8C4@;6]D=6QI<RX`075T:%]L9&%P
M.B!N97)A<W1A<R!R96EK86QI;F=A<R!,1$%0(&UO9'5L:7,N`$%U=&A?;&1A
M<#H@<W5K=7)T:2!V87)T;W1O:N`@)7,@;F5P879Y:V\N(%-E<G9E<FEO('!R
M86YE\&EM87,Z(`!!=71H7VQD87`Z(&GP=')I;G1I('9A<G1O=&]JX"`E<R!N
M97!A=GEK;P!!=71H7VQD87`Z(&%T;F%U:FEN=&D@=F%R=&]T;VK@("5S(&YE
M<&%V>6MO`$%U=&A?;6-A;#H@;F5R87-T87,@<F5I:V%L:6YG87,@34-!3"!M
M;V1U;&ES+@!!=71H7W-M8F%U=&@Z(&YE<F%S=&%S(')E:6MA;&EN9V%S('-M
M8F%U=&@@;6]D=6QI<RX`4')I<VEJ=6YG=&D@;F5P879Y:V\`4')I<VEJ=6YG
M=&D@;F5P879Y:V\N("5S`%)!1$E54R!S97)V97)I<R!N96QE:63^:6$@875T
M96YT:69I:W5O=&ES+@!0<FES:6IU;F=T:2!P<FEE($944"!S97)V97)I;R!N
M97!A=GEK;RX`1V%L:6UI(&QA=6MA:3H`3&%U:VEA;6$@871S86MY;6\`07IE
M<F)A:63^86YA<P!"3T9((&%T<VEP<F'P>6UA:0!3;&%P=&'^;V3^:6\@:V5I
M=&EM;R!P;W-I<W1E;>L@;F5T96ES:6YG86D@<F5A;&EZ=6]T82X`1F]N87,`
M1F]N;R!S<&%L=F$`3F5T96ES:6YG87,@:V5R8F5R;W,@<VQA<'1A_F]D:7,N
M`$YE=&5I<VEN9V%S(&ME<F)E<F]S('9A<G1O=&]J;R!V87)D87,N`$)A:&%M
M86D`0F%H<F5I;F%S`$)A;'1I\&MA("A)4T\M.#@U.2TQ,RD`0F%G;&%D9?!A
M<P!"87)B861O<V%S`%1U\.AI87,`4&%G<BX@;&EN:6IO:F4`0F%L=&%R=7-I
M:F$`0F5L9VEJ80!"96QI>F%S`$)E;FEN87,`0F5R;75D86D`0G5T86YA<P!'
M:6UT861I96YI<P!";&]K;R!P87)A;65T<F%I`$)L;VMO('1I<&%S`$)L;VOX
M('!A<VER:6YK:6UA<P!087-T;W)I;G1I`$)O;&EV:6IA`$%T_GEM;W,`2W)A
M\'1A<P!+<F'P=&\@<W1O<G5M87,Z`$MR8?!T86D`0F]S;FEJ82!I<B!(97)C
M96=O=FEN80!6:7-O<P!";W1S=F%N80!!<&'H:6]J90!"=79E="!S86QA`$)R
M87II;&EJ80!"<FET^"!);F1I:F]S('9A;F1E;GEN;R!T97)I=&]J80!"<G5N
MZVIA=7,@9&%R=7-A;&5M87,`0G5L9V%R:6IA`%-U_GEMZW1A<R!SX')A\&%S
M`$)U<FMI;F%S($9A<V%S`$)U<G5N9&EJ80!45E,`0U)#`$-23"!P87-K:7)S
M='EM;R!P=6YK=&%I`%]#96SK<R!N=7-T871Y;6%I+BXN`$MA;&5N9&]R:75S
M`%)A;74`2V%M8F]D_F$`2V%M97+[;F%S`$YE=F5I:VEA(&%U=&]M871I;FES
M('-L87!T8?YO9/YI;R!P86ME:71I;6%S+"!S=7-I<VEE:VET92!S=2!A9&UI
M;FES=')A=&]R:75M:2X`3F5G86QI=2!P<FES:6IU;F=T:2!P<FEE($E-05`@
M<V5R=F5R:6\Z("5S`$MA;F%D80!!=/!A=6MT:0!!=/!A=6MT:2!P<F]B;&5M
M;W,@<')A;F7P:6W@`$YE9V%L:74@:?!T<FEN=&D@9F%I;&\@(B5S(BX`3F5G
M86QI=2!R87-T:2!L86EK:6YO:F\@:V%T86QO9V\N`$YE9V%L:74@87!D;W)O
M=&D@)W1A<F=E=$9I;&4G('!A<F%M971R;RX`3F5G86QI=2!I\'1R:6YT:2!K
M871A;&]G;R`B)7,B+@!.96=A;&EU(&GP=')I;G1I+B!%9WII<W1U;VIA("5D
M('!O\&%K:6%I+@!.96=A;&EU('!E<G+[\&EU;W1I+B#!=F5S=&%S(.%R8?#X
M('-K86GH:75S(&YE<W5T86UP82!S=2#A<F'P^"!S:V%IZ&EU;6D@9'5O;65N
M^"!B87KK:F4N`$YE9V%L:74@;G5K<F5I<'1I(/YI;G5TZW,@X2!N=7)O9'ET
MX"!N=6UE<N$N`$ME:7!V97)D:7,`4&%V861I;FEM87,`2V%T96=O<FEJ;W,`
M2V%I;6%N^"!S86QO<P!-;V)I;'5S('1E;&5F;VYA<P!#96SK<R!N=7-T871Y
M;6%I`%1A<G!A:2!C96SK<V4Z`$-E;.MS(&YU<W1A='EM86D`5&%R<&%I('1A
M<G`@8V5L:?@Z`$UO8FEL=7-I<R!T96QE9F]N87,`2V5L=/@@*$E33RTX.#4Y
M+3$T*0!#96YT<F4`0V5N=')I;NMS($%F<FEK;W,@4F5S<'5B;&EK80!#96YT
M<FENZW,@175R;W!O<R`H25-/+3@X-3DM,BD`4V5R=&EF:6MA=&\@9&5T86SK
M<P!397)T:69I:V%T;R!T96ESZW,`R&%D87,`5F%D;W9A<P!086ME:7-T:0!3
M;&%P=&'^;V3^:6\@:V5I=&EM87,`4VQA<'1A_F]D_FEO(&ME:71I;6%S('-E
M<G9E<GEJ93H`2OMS^"!V87)D;R!I<B!A9')E<V\L(&MU<FEU;W,@;6%T>7,@
M_FUO;NMS+"!S:V%I=&%N='ES(&ER(&%T<V%K:6[K:F%N='ES(.$@2OMS^"!L
M86GP:W5S+"!K96ET:6UA<RX`4VQA<'1A_F]D_FEO(&ME:71I;6%S`%-L87!T
M8?YO9/YI;R!K96ET:6UA<R!S97)V97)Y:F4@)7,`4VEM8F]L:7,`4&%?=&EK
M<FEN=&D@;G5O<F]DX"XN+@!08?YY;>MK:71E+"!K=7)I87,@;W!E<F%C:6IA
M<R!N;W)I=&4@871L:6MT:2X`R&ELZP!+:6YI:F$`2VEN:65T:?!K82!P87!R
M87-T82`H1T(R,S$R*0!+:6YI971I\&MA('1R861I8VENZR`H0FEG-2D`4&%S
M:7)I;FMI=&4@<VQA<'1A_F]DX0!087-I<FEN:VET92!V87)T;W1O:F\@=F%R
M9.``4&%S:7)I;FMI=&4@=F5I:W-MX#H`4&%S:7)I;FMI=&4@:V%I<"!V86EZ
M9'5O=&D@9&%T87,Z`%!A<VER:6YK:71E('-U<OOP:75O=&\@<^!R8?!O('-T
M:6QI^`!+86SK9/@@<V%L80!+;&%SZW,@)7,@;NMR82X`1VEE9')A`$GP=')I
M;G1I($U3($]F9FEC92#^>6UE<P!687)T;W1O:F\@9'5O;65N^"!V86QY;6%S
M.B`E<P!)\'9A;'ET:2!V87)T;W1O:F\@9'5O;65N:7,`2?!V86QY=&D@=F%R
M=&]T;VIO(&1U;VUE;FES`%3F<W1I`$-L:6-K871E;&P@<&5R($A45%``5?YD
M87)Y=&D@;&%N9^``1&5B97-U;W1A`$1E8F5S=6]T80!+;VMO<V\@*$MY;&EN
M9V\I('-A;&]S`%1U\.AI^"!C96QI^"!K<F'P=/@@<F]D>6UA<P!+;VQU;6)I
M:F$`4W!A;'9A`%!A<VER:6YK:71E('-P86QVX`!3<&%L=F]S('!A<VER:6YK
M:6UA<P!3='5L<&5L:6%I.@!3='5L<&5L:?@@<&%V861I;FEM86D`2V]M:6MS
M86D`2V]M86YD80!+;VUA;F1I;NL@96EL=73K`$MO;65N=&%R87,`5F%R9&%S
M+W!A=F%R9.L`2V]M;W)A:0!+;VUP86YI:F$`071L:6MT80!28?!Y=&D@;&%I
M\&O@("@E<RD`2V]M<&EU=&5R:6%I`%/@;'EG;W,`3G5S=&%T>6WX('!A:V5I
M=&EM86D`4F5I:VEA(&%T;F%U:FEN=&D@:V]N9FEG^W)A8VENX2!F86ELX"X`
M2V]N9FEG^W)U;W1I("5S`%-L87!T8?YO9&ES(&1A<B!K87)TX`!086MA<G1O
M:VET92!N875JX"!S;&%P=&'^;V3A.@!+;VYG87,`1&5M;VMR871I;NL@2V]N
M9V\@4F5S<'5B;&EK80!0<FES:6IU;F=T:2!N97!A=GEK;RX`4')I<VEJ=6YG
M=&D@;F5P879Y:V\Z(`!0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@
M<V5R=F5R:6\@;F5P879Y:V\N`%!R:7-I:G5N9W1I('!R:64@=FEE\/AJ^"!R
M86MT^"!S97)V97)I;R!N97!A=GEK;RP@;F5S.B`E<R`H)7,I`%!R:7-I:G5N
M9W1I('!R:64@1E10('-E<G9E<FEO(&YE<&%V>6MO+@!+;VYK86MT86D@<^MK
M;6EN9V%I(.%T<F%U:W1I(.$@2OMS^"!A9')E<_@@:VYY9V5LY@`G)7,G('1U
M<FEN>7,`5.9S=&D`2W5K;R!S86QO<P!,86EMZW,@_FEN=73K<P!+;W!I:G5O
M=&D`2V]P:6IU;W1I('!A<VER:6YK:6W@`$MO<W1A(%)I:V$`1')A;6)L:6\@
M2V%U;&\@2W)A;G1A<P!.97!A=GEK;R!U_FMO9'5O=&D@4$=0(&QA:?!K;RX`
M3F5P879Y:V\@<&%S:7)A\'ET:2!01U`@;&%I\&MO+@!.97!A=GEK;R!U_FMO
M9'5O=&D@4R]-24U%(&QA:?!K;RX`3F5P879Y:V\@<&%S:7)A\'ET:2!3+TU)
M344@;&%I\&MO+@!.97!A=GEK;R!P<FEDZW1I(&MO;G1A:W1O+B`E<P!.97!A
M=GEK;R!A=71E;G1I9FEK=6]T:7,@X2!,1$%0('-E<G9E<N$N`$YE<&%V>6MO
M(&%U=&5N=&EF:6MU;W1I<R#A($Q$05`@<V5R=F5RX0!.97!A=GEK;R!I\&MV
M:65S=&D@9G5N:V-I:F]S("5S(&UO9'5L>6IE("5S+@!.97!A=GEK;R!P871I
M:W)I;G1I(&)A;&%N<V\N("5S`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@
M3$1!4"!S97)V97)I;P!.97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE("<E<R<@
M<V5R=F5R:6\@<&5R($944#H@)7,`3F5P879Y:V\@<W5K=7)T:2!D:7-T<FEB
M=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@871K;V1U;W1I(%!'4"!D=6]M
M96[X+@!.97!A=GEK;R!A=&MO9'5O=&D@4R]-24U%(&1U;VUE;O@N`$YE<&%V
M>6MO(&GP=')I;G1I(&MO;G1A:W1O+B`E<P!.97!A=GEK;R!I\'1R:6YT:2!D
M:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@:?!T<FEN=&D@871N
M875J:6YI;6\@<VMR:7!T;R`G)7,G+@!.97!A=GEK;R!N=7-T871Y=&D@9V%V
MZVIO(&5L+B!P8?!T;R!A9')E<V\N`%!A=GEK;R!G875T:2!V:7-O<R!A9')E
M<_@@:VYY9V5LZW,N`$YE<&%V>6MO(&=A=71I('9I<V\@9&ES=')I8G5C:6IO
M<R!SX')A\&\N`$YE<&%V>6MO(&=A=71I('9I<V\@9&ES=')I8G5C:6IO<R!S
MX')A\/@@<^!R8?!O+@!.97!A=GEK;R!U_FMR875T:2!S=')A=&5G:6IO<R`G
M)7,G+@!.97!A=GEK;R!S=6MU<G1I(&MA=&%L;V=O("<E<R<N`$YE<&%V>6MO
M(&=A=71I('9I9?!O:F\@<F%K=&\@:?`@<F%K=/@@<V5R=F5R:6\N`$YE<&%V
M>6MO(&%T:61A<GET:2`E<RX`3F5P879Y:V\@871I9&%R>71I("<E<R<@<F'P
M>6UU:2X`3F5P879Y:V\@871I9&%R>71I($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QI;R`E<P!.97!A=GEK;R!A=&ED87)Y=&D@:V%T86QO9V\@)R5S)RX`2VQA
M:61A(&IU;F=I86YT:7,@<')I92!S;6)P87-S=V0N`$YE<&%V>6MO('-K86ET
M>71I("5S+@!.97!A=GEK;R!P86ME:7-T:2!S;&%P=&'^;V3^:6\@\&EA;2!V
M87)T;W1O:G5I+B!+86D@:W5R:2!A<F)A('9I<V$@:6YF;W)M86-I:F$@>7)A
M(&YE=&EK<VQI+B!086)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S=7-I<VEE
M:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA;&EN
M9V$@<&%G86QB82X`3F5P879Y:V\@9V%U=&D@04-,`$YE<&%V>6MO(&=A=71I
M(&%D<F5S^"!K;GEG96SK<RX@)7,`3F5P879Y:V\@9V%U=&D@9&ES=')I8G5C
M:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ;W,@
M<^!R8?#X+B`E<P!.97!A=GEK;R!N=7-T871Y=&D@<V5R=F5R:6\@9V%L:6UY
M8FGX`$YE<&%V>6MO(&%T:V5I<W1I(&YU<W1A='EM^"X`3F5P879Y:V\@:?!T
M<FEN=&D@:V%T86QO9V\@)R5S)RX`3F5P879Y:V\@:?!S875G;W1I("5S(&YU
M<W1A='EM^"X`3F5P879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R!N=7-T871Y
M;?@@:V]P:6IO<RX`3F5P879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R`E<R!N
M=7-T871Y;?@@:V]P:6IO<RX`3F5P879Y:V\@:?!S875G;W1I(&%T;F%U:FEN
M:6UO('-K<FEP="#A.B`G)7,G+@!.97!A=GEK;R!P86EE\&MA($Q$05`@<V5R
M=F5R>6IE+@!.97!A=GEK;R!N=71R875K=&D@<GGPX2`G)7,G+@!.97!A=GEK
M;R!A=&YA=6II;G1I(&MO;G1A:W1O+B`E<P!.97!A=GEK;R!A=&YA=6II;G1I
M(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<P!.97!A=GEK;R!U_G)A\'ET:2`G
M)7,G(&YU<W1A='EM^#H@)7,`3F5P879Y:V\@<F%S=&D@36]Z:6QO<R#A<F%N
M:VGX(&IU;W-T;W,N(,%S:71I:VEN:VET92P@:V%D(&II(&%T:61A<GET82X`
M3F5P879Y:V\@<W5T96EK=&D@\&GX('1E:7-I^"!V87)T;W1O:G5I("<E<R<@
M:V%T96QO9V4@)R5S)SH@)7,`4FEB;W1A<R!T96MS=&%S`%9A;'-T>6+K`$MU
M<G-A:0!3=6MU<G1I`%-U:W5R=&D@;G5O<F]DX`!3=6MU<G1I(&YA=6K@(&%P
M<F'PX`!3=6MU<G1I('!A:V%T86QO9VEU<P!3879I;FEN:V\@=&5I<^MS`$MR
M961I=&ENZW,@:V]R=&5LZW,@;G5M97)I<P!+<F]A=&EJ80!+=6)A`$1A8F%R
M=&ENZR!F87KK`$1A8F%R=&EN:7,@;&%I:V%S`-!I=6\@;65T=2!54DP@>7)A
M`$1A8F%R=&ENZW,@;W)O('/@;'EG;W,`1&%B87)T:6[K<R!SX&QY9V]S.B``
M1&%B87)T:6YI<R!S=&EL:75S`%9E:6MS;?@L(&%T;&EE:V%M^"!P<FES:6IU
M;F=U<R!P<FEE("5S+"!N=7-T871Y;6%S+@!097)K96QT:0!097)K96QT:2!P
M87-I<FEN:VEMX`!+:7!R87,`2VER:6QI8V$@*$M/23@M4BD`2VER:6QI8V$@
M*%=I;F1O=W,M,3(U,2D`2VER:6QI8V$O56MR86EN:65T:?!K82`H2T])."U5
M*0#(96MI:F]S(%)E<W!U8FQI:V$`1$0`2V%S9&EE;@!$=6]M96YY<P!$=6]M
M96[X(&UE9/YI;R!N87+P>6MLZP!$871A`$=A=71A`$1A=&]S('!A<VER:6YK
M:6UA<P!$:65N80!)\'1R:6YT:2!?<W1U;'!E;.$`1W)U;V1I<P!$9?!I;71A
M:6YI86D@<VMA:>AI86D`4&%S:6)A:6?F<P!3=6UA_FEN=&D@871I=')A=6MI
M;>``4W1A;F1A<G1I;NL@<W!A;'9A`%-T86YD87)T:6YI<R!A<')A\&%S`%-T
M86YD87)T:6[K<R!T96ESZW,`4W1A;F1A<G1I;NMS('1E:7/K<P!!<&EB<NO^
M:6UA:0!!='-T;W9A<P!!='-T;W9A=6IA;6%S`$GP=')I;G1I`$GP=')I;G1I
M(&=R=7#F`$GP=')I;G1I('1E:7/F`%9I<VGP:V%I(&GP=')I;G1I(&QA:?!K
M=7,`2?!T<FEN=&D@8V5LY@!)\'1R:6YT:2!S='5L<&5LX0!)\'1R:6YT:2!E
M9WII<W1U;VIA;G3A(&%L=&5R;F%T>7;X(/!A8FQO;N``)R5S)R!T96ES:?@@
M=')Y;FEM87,`07(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2`G)7,G('1E:7-E
M<R!I<B!V:7-A<R!P;W1E:7-E<S\`2?!T<FEN=&D@96EL=73F`$GP=')I;G1I
M('!A<VER:6YK=.`@87!R8?#@`$GP=')I;G1I(/#A('-T=6QP96SA`$GP=')I
M;G1I(/!IX"!E:6QU=.8`07(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#P:6%S
M('1E:7-E<R!I<B!V:7-A<R!P;W1E:7-E<S\`071N875J:6YI;6\@<VMR:7!T
M87,@)R5S)R!I\'1R:6YT87,N`%!R:7-T871Y;6\@;&%I:V%S`$1A;FEJ80!!
M=&UE<W1I('7^:VQA=7/@`$%T;65S=&D@=?YK;&%U<^`@9.ML('7^:6UT=6UO
M`%!R;V)L96UO<R!A<')A\'EM87,`07!R8?!Y;6%S`$1E=&%L:6%U("AT86EP
M('!A="#^:?MRZVMI=&4@2&]R9&4@;&]G(&9A:6QE*3H`061M:6YI<W1R871O
M<FEU:2!I\'-I^'-T87,@9&5T86QU<R!A<')A\'EM87,N`%9Y<W1Y;6%S`$1R
MZV=N=6UA<P!$<NMG;G5M87,@<&%S:W5T:6[F('9A;&%N9.`Z(`!$<NMG;G5M
M87,Z(`!+<GEP=&ES(&GP(&MA:7+K<R#A(&1E\&ENY@!+<GEP=&ES(&GP(&1E
M\&ENZW,@X2!K86ERY@!+871A;&]G87,`4F]D>71I(#(T+6GX('9A;"X@9F]R
M;6%TX#\`5F%I>F1A=FEM;R!N=7-T871Y;6%I`%)O9'ET:2!P<F]G<F]NYB`H
M5$%&*0!686EZ9&%V:6UO(&9O<FUA=&%S`$QA:?!K;R!P<FES=&%T>6UO('!R
M86YE\&EM86D`1/YI8G5T:7,`3F5T<FEN=&D`3F5S:6MR96EP:VET92!T:65S
M:6]G:6%I(.$@;6%I;G1E;F%N8V4N<&AP`$%R('!I<FUA<R#A<F'P87,@>7)A
M(&QA=6MO('9A<F1A:3\`1&]M:6YI:V$`1&]M:6YI:V]S(%)E<W!U8FQI:V$`
M071S:7-I^'-T:0!!='-I<VGX<W1I("5S`$%T<VES:?AS=&D@<W5G96YE<G5O
M='5S(&YU<W1A='EM=7,@:V%I<"!02%`@<VMR:7!TX"X`2?!S:7-K;&5I9/YI
M86YT:7,@<^!R8?!A<P!686ES=&%I`$5L+B!P8?!T;R!A9')E<V%S`$524@!%
M:W9A9&]R87,`2V5I<W1I`$ME:7-T:2!B;&]K;R!P87)A;65T<G5S`%)E9&%G
M=6]T:2!G<G5PY@!2961A9W5O=&D@=&5I<V5S`%)E9&%G=6]T:2!T96ES97,`
M)7,@=&5I<VGX(')E9&%G879I;6%S`$ME:7-T:2!N=7-T871Y;75S.@`E<R!T
M96ES:?@@<F5D86=A=FEM87,`)R5S)R!T96ES:?@@<F5D86=A=FEM87,`56=D
M>6UA<P!%9VEP=&%S`%-A;'9A9&]R87,`16QE;65N=&%S+BXN`$5M`$5L+B!P
M8?!T87,`16PN('!A\'1O(&%D<F5S87,`16PN('!A\'1O(&%D<F5S86D@='5R
M:2!S=71A<'1I+@!%;"X@<&'P=&\@861R97-A<R!S=2!P871V:7)T:6YI;74`
MT'EP<V5NZVSK<P#>:6YU=.L@='7PZ&EA+@!297IU;'1A=&%S('1U\.AI87,N
M`$YE;G5R;V3K=&4@<&%I9?!K;W,@=&5R;6EN^`!,96ES=&D@=&5K<W1E(.%T
M97)P=&D@<&%V96EK<VSK;&EU<R!I\"!.=6]T<F%U:_@@9V%L97)I:F]S/P#!
M:G5N9W1I(&1E\&EN:6]J;R!P96SK<R!M>6=T=6MO(&UE;FEU/P!086)A:6=A
M`$=A;&EN:6%I(&UE=&%I`$GP<&SK<W1I(')E9&%K=&]R:?@`P7)A\'EK:71E
M(&ML875S:6W@+"!K=7)I<R!J=6US(&)U<R!U_F1U;W1A<R!J96EG=2!P86UI
M<O!I=&4@<V%V;R!S;&%P=&'^;V3A+"!P=GHN.B`G:V]K<R!Y<F$@2OMS^"!G
M>7;[;F\@=F%R9&%S/R<Z`,%V97-K:71E('!A=F5I:W-LZVQI;R!54DP`16MV
M871O<FENZR!'=FENZVIA`$5R:71RZVIA`$ML86ED80!+;&%I9&$@<VEU;NAI
M86YT(&1U;VUE;FES('-M8G!A<W-W9"!K;VUA;F1A:2X`2VQA:61A('-I=6[H
M:6%N="!A='-A:WEMX#H@)7,N`$ML86ED82!L86GP:V4N`$ML86ED82!R8?!A
M;G0@)R5S)RX`17-T:6IA`$5T:6]P:6IA`$5T;FENZW,`175R;W!A`$MA<R`Q
M-2!M:6YUZ&GX`$MA<R`R(&UI;G5T97,`2V%S(#,P('-E:W5N9/YI^`!+87,@
M-2!M:6YU=&5S`$MI96MV:65N;R!P<FES:6IU;F=I;6\@;65T=0!+87,@<'5S
M=F%L86YDX0!+87,@;6EN=73F`%!A=GEZ9/YI=6DZ`%9Y:V1Y=&D`2?!S:VQE
M:7-T:0!296EK86QI;F=A<R`G*2<`4F5I:V%L:6YG87,@_F]D:7,@87)B82!K
M86)U=.MS92#A<F'P>71A<R!P86EE\&MO<R!K<FET97)I:G5S`$=A;&EO:FEM
M;R!D871A`$5K<W!O;F5N=.L`5&5K<W1O('-P86QV80!.=7-T871Y;?@@<VEU
M;G1I;6%S('!E<B!&5%`N`$ML86ED82!N=7-K86ET86YT(&YU<W1A='EM=7,N
M`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@3$1!4"!S97)V97)I;RX`3F5P
M879Y:V\@<')I<VEJ=6YG=&D@<')I92!334(@<V5R=F5R:6\N`$YE<&%V>6MO
M(&YU:V]P:6IU;W1I(&GP("(E<R(N`$YE<&%V>6MO(&YU:V]P:6IU;W1I(.$@
M(B5S(BX`3F5P879Y:V\@<W5K=7)T:2!N875J;R!305-,(')Y\&EO+@!.97!A
M=GEK;R!P97)K96QT:2#A("(E<R(N`$YE<&%V>6MO('!A=&EK<FEN=&D@<V5N
M;R!S;&%P=&'^;V3^:6\N`$ML86ED82!K96GH:6%N="!S;&%P=&'^;V3A('-E
M<G9E<GEJ92`E<SH@)7,`T'9E;&YU<P!&;VQK;&%N9/@@<V%L;W,@*$UA;'9I
M;F%I*0!&87)E<O@@<V%L;W,`2W)I=&ENZR!K;&%I9&$A`$9A:W-A<P!687-A
M<FES`$%T<F]D;R!L>6<`071R;V1O(&QY9SH@`%1R=6UP86QA:6MI<R!L:65T
M=7,`1FED_FES`$9A:6SX('-K86GH:75S.B`E<R!F86EL87,`1F%I;/@@<VMA
M:>AI=7,Z("5S(&9A:6QA:2CX*0!&86EL^"!T=F%R:WEM87,`1F%I;&\@<&%V
M861I;FEM87,`1F%I;&\@<&%S:7)I;FMI;6%S`$9A:6QO('-I=6YT:6UA<P!.
M87+P>6MLZR!N97!A;&%I:V\@9F%I;/@@<VEU;G1I;6\N`$9I;'1R86D`4W5O
M;6EJ80!0:7)M;VII('!U<^L`4&ER;6%S:7,@:V5T=FER=&ES`$YU<W1A='ET
M87,@:V]E9FEC:65N=&%S`$%T=FER:_#H:6%S`$GP9.MS='EM87,`4OMK87,`
M2V%T86QO9V%S("5S(&YE96=Z:7-T=6]J80!496MS=&\@<W!A;'9A`$UA:7-T
M87,`3F%R\'EK;.MM<RP@:W5R:6]S(&YE<&%L86EK;R!P879E:6MS;.ML:?@`
M3W+X('!R;V=N;WKK("A4048I`$]R^"!P<F]G;F]ZZW,@87!I;71I<R`HX7-I
M9.MMZVMI=&4L(&MA9"#P:2!F=6YK8VEJ82!G<F'^:6YA(&ER(&1I96YO<R!I
M<B!N86MT:65S('!R;V=N;WKF.R!P97(@9&ED96QI<R!S:V%IZ&EU<R!G86QI
M('-U9&%R:WET:2!D:7IA:6[@*0!086UI<O!O=&4@<V%V;R!S;&%P=&'^;V3A
M/P!&;W)M;W,`1G)A>NL`1G)A>FGX('1I<&%S`$9R87KK<P!&<F%ZZW,@,@!$
M:7-K=7-I:F]S`%!E<G-I=6YT:6UA:0!096YK+@!+<F'P=&ENZW,`4')A;F/[
M>FEJ80!0<F%N8_MZ:6IA+"!-971R;W!O;&ES`%7^:6UT=6UO(&EN9F]R;6%C
M:6IA`$%T<V%K>6UA<R!A<&EE('7^:6UT=6W@`%!R8?!Y;6%S('7^:6UT=6UO
M(&EN9F]R;6%C:6IA:0!!='-A:WEM87,@X2!P<F'P>6W@('7^:6UT=6UO(&EN
M9F]R;6%C:6IA:0!0<F%N8_MZ:6IO<R!'=FEA;F$`4')A;F/[>FEJ;W,@4&]L
M:6YE>FEJ80!0<F%N8_MZ:6IO<R!P:65T:6[K<R!T97)I=&]R:6IO<P!.=6\`
M3G5O(`!0:6QN87,@87!R8?!Y;6%S`%!I;&YA=&ES`%!I;&YA<R!V87)D87,`
M1V%B;VYA<P!'86QE<FEJ82!I\"!K=7)I;W,@:?`@:W5R:6]S(&)U<R!R;V1O
M;6%S('!A=F5I:W-LZVQI<P!'86QE<FEJ83H`1V%M8FEJ80!'96YE<G5O=&D@
M)7,@;G5S=&%T>6UU<P!3=6=E;F5R=6]T87,@:V]D87,`1W)U>FEJ80!6;VMI
M971I:F$`1V%N80!':6)R86QT87)A<P!687)D87,`4F]D>71I`$=A9&5L:7,`
M1V]O9VQE('!A:67P:V$`3F5S<&%L=F]T87,`1W)A:6MI:F$`1W)A:6MI\&MA
M("A)4T\M.#@U.2TW*0!'<F5N;&%N9&EJ80!'<F5N861A`$=R=7!I^"!A9&UI
M;FES=')A=FEM87,`1W)U<.MS('9A<F1A<R!T=7)I(&+[=&D@;F5T=?#H:6%S
M`$=R=7#K<R!T96ESZW,`1W)U<.MS`$=V861E;'5PZP!'=6%M80!'=F%T96UA
M;&$`1V5R;G-I<P!3=F7H:?@@=&5I<^MS`%-V9>AI^"!T96ESZW,`4W9EZ&GX
M(&MN>6=A`$=V:6[K:F$`0FES<V%U+4=V:6[K:F$`1V%J86YA`$A(`$A434P`
M2%1-3$%R96$@;F5G86QI(&GP=')I;G1I('!A<VMU=&ENZW,@8V5LZW,@96EL
M=73K:F4N`$A434Q!<F5A(&YE9V%L:2!I\')I;G1I('!A<VMU=&EN:6\@<W1U
M;'!E;&EO(&QE;G1E;.MJ92X`2%1-3$%R96$@;F5G86QI(&GP=')I;G1I('!A
M<VMU=&ENZW,@96EL=73K<R!L96YT96SK:F4N`%)E:6MA;&EN9V$@2%144"!A
M=71E;G1I9FEK86-I:F$N`$AA:71I<P!(87-H+4%L9V]R:71M87,`36EG;&$`
M06YT<F'P=.L`2&5R9&\@<V%L82!I<B!-86MD;VYA;&1O('-A;&]S`$AE8G)A
M:O@@*$E33RTX.#4Y+3@M22D`075K\'1I<P!086=A;&)A`%)E9&%K=&]R:6%U
M<R!N875D;VII;6]S:2!P86=A;&)A`%!A9V%L8FEN:6YK87,`2&5M:7-F97)A
M`-!T86D@Z&EA('ER82!F86EL;R!P<F%D_FEA.@!3=F%R8G4`P7)A\/@@=F%R
M9&%I('1U<FD@8OMT:2!N971U\'1I`%]0;W)T86QA<P#0=F5N=&%S:7,@4V]S
M=&%S("A6871I:V%N;R!V86QS=&EJ82D`4&]R=&%L87,`3F%M^"!A9')E<V%S
M`$YA;?@@=&5L969O;F%S`$AO;F3[<F%S`$AO;FMO;F=A<P!0;W)T86QA<P!(
M;W)D92]+;VQA8CH@;F5T96ES:6YG:2`E<R!834P@9'5O;65N>7,@_FEN=73K
M:F4@)7,`2&]R9&4O2V]L86(Z(&]B:F5K=&\@)7,@;F5A=&ET:6YK82!J;VMI
M82#^:6YU=.L`2&]R9&4O2V]L86(Z(&]B:F5K=&\@=&EP87,@)7,@;F5R87-T
M87,@_FEN=73K:F4@)7,`2&]R9&4O2V]L86(Z("5S("(E<R(@<^MK;6EN86D@
M:?!T<FEN=&$`2&]R9&4O2V]L86(Z("5S("(E<R(@<^MK;6EN9V%I('-U<VEN
M8VAR;VYI>G5O=&$`2&]R9&4O2V]L86(Z(&EN=&5G<F%C:6IO<R!V87)I:VQI
M=6MU:2!R96EK86QI;F=A<R`G9&]M>&UL)R!02%`@;6]D=6QI<P!(;W)D92]+
M;VQA8CH@;F5P879Y:V\@<W5K=7)T:2!N875J;R!834P@;65D_FEO(&]B:F5K
M='5I("5S`$AO<F1E+TMO;&%B.B!N97!A=GEK;R!I\'1R:6YT:2`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@9V%U=&D@34E-12!)1"!D86QI
M86D@)7,@=&EP;P!(;W)D92]+;VQA8CH@;F5P879Y:V\@<W5S:6YC:')O;FEZ
M=6]T:2`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@<W5S:6YC
M:')O;FEZ=6]T:2!E;&5M96YT^#H@)7,`2&]R9&4O2V]L86(Z(&YE_FEN;VUA
M<R!E;&5M96YT87,@(B5S(@!(;W)I>F]N=&%L:2!L:6YI:F$`2&]R:7IO;G1A
M;'5S('1A<G!A<P!(;W)I>F]N=&%L:6%I.@!+86EP(.AI82!P871E:V]T93\@
M*%!R86YE\&MI=&4A*0!+:65K('-T=6QP96QI^"!N;W)I=&4@<W5J=6YG=&D_
M`$MI96L@;&%U:_@@*'-T=6QP96QI^"D@=&5N('ER83\`2VEE:R!E:6QUZ&GX
M(&YO<FET92!S=6IU;F=T:3\`1'+K9VYU;6%S`$1RZV=N=6UA<SH@`$IU;6]R
M97-K;W,`5F5N9W)I:F$`3F5P879Y:V\@<W5K=7)T:2!)34%0('!A\'1O(&3K
M_G5TZW,Z("5S`$YE<&%V>6MO(&GP=')I;G1I($E-05`@<&'P=&\@9.O^=73K
M<SH@)7,`3F5P879Y:V\@;G5S=&%T>71I($E-05`@<&'P=&\@9.O^=73K<R!D
M>63^:6\Z("5S`$E0(&%D<F5S87,`3F5P879Y:V\@9V%U=&D@25`@861R97-O
M+@!)4"!A9')E<V%S(&YE=&5I<VEN9V%M92!#2412(&)L;VME+@!)4"!U_G)A
M:VEN=&%S+@!?P71E<G!T:2!E:6QU=.8@=FER\'5J90!)<VQA;F1I:F$`5&EK
M('!I:W1O9W)A;6]S`%!I:W1O9W)A;6]S('-U('1E:W-T=0!!<')A\&\@<&%V
M861I;FEM87,Z`$IE:2!N96=A;&ET92!P97)S:V%I='ET:2#P:6\@;&%I\&MO
M+"`E<RX`2F5I9W4@;6%T;W1E(/!IX"#^:6YU=.8@=FEE=&]J('!A=F5I:W-L
MZVQI;RP@:W5RX2!N;W)I=&4@X6ME;'1I+"!T86D@2OMS^"!N87+P>6MLZR!N
M96=A;&D@:F\@871V86EZ9'5O=&DN`%!A=F5I:W-LZVQI;R!P97+^:?MR80!0
M879E:6MS;.ML:6\@55),`%!A=F5I:W-LZVQI;R!54DPZ`%!A=F5I:W-LZVQI
M<R!I\"!G86QE<FEJ;W,`4&%V96EK<VSK;&ES(&GP(&=A;&5R:6IO<SH`4&%V
M96EK<VSK;&EO(.%KZVQI;6%S`%9A:7ID86D`P6OK;&EM87,L("5D(/YI;F=S
M;FES`$QA=6MA<R#A:V5L=&%S.B`E<P#!:V5L=&D@;&%U:V%I.@!!=&QI96MA
M;6$`P5]T97)P=&D@96EL=73F(&%P8>AI;VIE`%-L87!T8?YO9&ES(&YE=&5I
M<VEN9V%S`$YE=&5I<VEN9V%S('9E:6MS;6\@:V]D87,N`$YE=&5I<VEN9V%S
M('9A<G1O=&]J;R!V87)D87,@:7(O87)B82!S;&%P=&'^;V1I<RX`3F5I=&5I
M<VEN9V%S('9A<G1O=&]J;R!V87)D87,@87)B82!A;'1E<FYA='EV=7,@96PN
M('!A\'1O(&%D<F5S87,N($)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S=7-I
M<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA
M;&EN9V$@=&]L97-NZR!P86=A;&)A+@!0861I9&EN=&D@871I=')A=6MI;>``
M26YD:6IA`$EN9&EV:61U86S[<R!V87)T;W1O:F%I`$EN9&]N97II:F$`26YF
M;W)M86-I:F$`26YF;W)M86-I:F$`P71R875K=&D@<W1U;'!E;.$@7V1E\&EN
MZVIE`,%T97)P=&D@<&%V96EK<VSK;.$`P71E<G!T:2!L96YT96SF`,%T97)P
M=&D@;G5O<F]DX`#!=&5R<'1I('-T=6QP96SA(%]K86ERZVIE`,%T97)P=&D@
M;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&1E\&ENZVIE`,%T97)P
M=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&MA:7+K:F4`P71E
M<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@87!AZ&EO:F4`P71E
M<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@=FER\'5J90#!=&5R
M<'1I('!A<F%G<F%FX"!E;&5M96YT;R!A<&'H:6]J90#!=&5R<'1I('!A<F%G
M<F%GX"!E;&5M96YT;R!V:7+P=6IE`,%T97)P=&D@86QT97)N871Y=O@@\&%B
M;&]NX`#!<F'P>6MI=&4@96PN('!A\'1O(&%D<F5SX"P@X2!K=7+A(&YO<FET
M92!G875T:2!N875JX"!S;&%P=&'^;V3A.@#!=&5R<'1I(&-E;.8@<&\@=&\`
MP71E<G!T:2!C96SF('!R:67P('1A:0#!=&5R<'1I('-T=6QP96SA(&1E\&EN
MZVIE`,%T97)P=&D@<W1U;'!E;.$@:V%I<NMJ90#!=&5R<'1I(&QA:?!K=7,`
MP71E<G!T:2!P87)A9W)A9N`@<&\@=&\`P71E<G!T:2!P87)A9W)A9N`@<')I
M9?`@=&%I`,%T97)P=&D@96EL=73F('!O('1O`,%T97)P=&D@96EL=73F('!R
M:67P('1A:0#!<F'P>6MI=&4@<F5I:VEA;>`@871S86MY;>`@X2!K;&%U<VEM
MX"!V:7+P=6IE.@#!=&5R<'1I+W)E9&%G=6]T:2!P879E:6MS;.MLX0#!=&5R
M<'1I+U)E9&%G=6]T:2!N=6]R;V3@`$1I<W1R:6)U8VEJ;W,@<^!R8?!U:2!N
M=7-I^'-T:2!N977^=&5N:V$@:W)E9&ET;RX`3F5U_G1E;FMA(&MR961I=&\N
M`%-K86GH:75S`%-K86GH:?@@<^!R8?!A<P!.971E:7-I;F=A<R!V96EK<VUA
M<R#P:6%M(&MO;7!O;F5N='5I+@!.971E:7-I;F=A<R!51$@N("A5<V5R($1A
M=&$@2&5A9&5R*2X`3F5T96ES:6YG87,@;6]D=6QI<RX`3F5T96ES:6YG87,@
M240N`,%V97-T:2!N971E:7-I;F=I(&1U;VUE;GES+@!.971E:7-I;F=A<R!A
M9')E<V%S+@!.971E:7-I;F=A<R!F86EL;R!F;W)M871A<P!.971E:7-I;F=A
M<R!M<V=?='EP92X`3F5T96ES:6YG87,@87)B82!NZW)A(&%P:5]I9"X`4&%R
M86UE=')A:2!N971E:7-I;F=I(&%R8F$@:O@@;NMR82X`3F5T96ES:6YG;W,@
M<&%V96QD:6UO<R!T96ESZW,N`$YE=&5I<VEN9V%S('!R;W1O:V]L87,N`$YE
M=&5I<VEN9V%S(&=A=NMJ87,Z("<E<R<`3F5T96ES:6YG87,@;V)J96MT87,`
M3F5T96ES:6YG87,@<VEU;G3K:F\@861R97-A<RX`3F5T96ES:6YG:2!U;FEK
M;V1O(&1U;VUE;GES+@!);G9E;G1O<FEU<P!)<VQA;6GP:V$@27)A;F\@4F5S
M<'5B;&EK80!)<F%K87,`06ER:6IA`$UE;F\@<V%L80!)>F]L:75O=&]S(%0M
M875D<F]S`$EZ<F%E;&ES`$GP9&%VZVIA<P!+=7)S>79A<P!)=&%L:6IA`$IA
M;6%I:V$`4V%U<VES`$IA<&]N:6IA`$IA<&]N:?!K82`H25-/+3(P,C(M2E`I
M`$3^97)S:7,`2F]R9&%N:6IA`$QI97!A`$)I<OYE;&ES`%!I;&YA:0!,>6=I
M=6]T:2!C96YT<F4`3'EG=6]T:2!P:6QN86D`3'EG:75O=&D@:V%I<NMJ90!,
M>6=I=6]T:2!D9?!I;NMJ90!+87IA:W-T86YA<P!)\'-A=6=O=&D@;W)I9VEN
M86S@/P!+96YI:F$`3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!+97)B97)O
M<R!S97)V97)I;RX`0G)A;F1U;VQI;R!N875J;VMA:0!286MT;R!K^W)I;6%S
M`%)A:W1O(&%T<W!A=61A<P!286MT;R!I;&=I<P!286MT;R!T:7!A<P!286MT
M;R!P86YA=61O:FEM87,`4F%K=&%S(&IA=2!Y<F$@=FEE\/AJ^"!R86MT^"!S
M97)V97)Y:F4N`%9A:6MA:0!+:7)I8F%T:7,`1&5M;VMR871I;NL@2V]RZVIO
M<R!,:6%U9&EE<R!297-P=6)L:6MA`$MO<NMJ;W,@4F5S<'5B;&EK80!+;W+K
M:FEE=&GP:V$@*$550RU+4BD`2W5V96ET87,`2VER9VEZ:6IA`%])\&3K<W1Y
M;6%S`$MA;&)A`$QA;W-O($1E;6]K<F%T:6[K($QI875D:65S(%)E<W!U8FQI
M:V$`06YT<F$@<'5SZP!087-K=71I;FES(&ME='9I<G1I<P!!=&YA=6II;G1A
M.@!087-K=71I;FES('!R:7-I:G5N9VEM87,Z("5S`%!A<VMU=&EN:7,@<')I
M<VEJ=6YG:6UA<SH@)7,@:?`@861R97-O("5S`%!R:7-I:G5N9^MT92!P:7)M
MX"!K87)TX`!,871V:6IA`%1E:7/K`$GP9.MS='EM87,`2F5I9W4@;F5N;W)I
M=&4@;F5N875D;W1I(&MR8?!T^"P@<&%L:6MI=&4@='7PZ&G@`$QI8F%N87,`
M2V%I<NMJ90!+86ER:6]J:2!A;G1R8?!TZP!+86ER:6]S:6]S(')E:6OP;>MS
M`$QE<V]T87,`3&EB97)I:F$`3&EB:6IO<R!!<F%B^"!%;7ER871A:0!,:6-H
M=&5N\'1E:6YA<P!3;75L:W5S(&QI971U<P!.961I9&5L:7,@;&EE='5S`$YE
M9&ED96QI<R!L:65T=7,O=NMJ87,`3F5D:61E;&ES(&QI971U<R!R>71E`$YE
M9&ED96QI<R!L:65T=7,@=F%K87)E`$YE9&ED96SK(&QI^W1I<P!.961I9&5L
M:7,@;&EE='5S('-U('!E<FO[;FEJ80!.961I9&5L:7,@<VYI96=A<P!.961I
M9&5LZR#P;&%P9')I8F$`3&EM97)I:V%S`$YU;W)O9&$`3G5O<F]D82#A.@!0
M861A<GET:2!E;"X@<&'P=&\@861R97/@(&YU;W)O9&$@X2!L86GP:V\@<F'P
M>6UO('!U<VQA<.$`3G5O<F]D;W,`3&EN=7@@;&%I;>MS(/YI;G5TZW,`4F]D
M>71I("T@=F%R=&]T;VIA<R!G86QI(&UA='ET:2!K871A;&]G;R!T=7)I;N$`
M4F]D>71I(&1U;VUE;O@@8F%Z:?@@<^!R8?#@`%)O9'ET:2!P86=A;&)O<R!T
M96UA<P!2;V1Y=&D@;&5N=&5L:?@@<^!R8?#@`$MO;F9E<F5N8VEJ;W,@87)C
M:'EV87,`2V]N9F5R96YC:6IO<R!P86=A;&)A`$MO;F9E<F5N8VEJ;W,@240`
M2V]N9F5R96YC:6IO<R!S879I;FEN:V%S`%)A\'ET:2#A(&MO;F9E<F5N8VEJ
MX`!0<FES:6IU;F=T:2!P<FEE(&MO;F9E<F5N8VEJ;W,`071S:6IU;F=T:2!N
M=6\@:V]N9F5R96YC:6IO<P!687)T;W1O:O@@<^!R8?!A<R!U_F1R875S=&%S
M+@!,:71E<F%T^W)A`$QI971U=F$`2W)A=6YA+BXN`%9I971I;FES(&QA:6MA
M<SH@`$QO:V%LZR!I<B!L86EK87,`5FEE=&$`4')I<VEJ=6YG=&D`071S:6IU
M;F=T:0!0<FES:6IU;F=I;6\@9&%R8F%I`%!R:7-I:G5N9W1I(&YE<&%V>6MO
M+B!.971E:7-I;F=A<R!*^W/X(&YU<F]D>71A<R!V87)T;W1O:F\@=F%R9&%S
M(&ER+V%R('-L87!T8?YO9&ES+@!0<FES:6IU;F=T:2!N97!A=GEK;RX`26QG
M87,@=&5K<W1A<P!-96ELZP!.97-V87)B=0!-8?YO<VEO<R!G<F%I:VGP:V]S
M(')A:63K<P!-8?YO<VEO<R!L;W1Y;FGP:V]S(')A:63K<P!-8?YI96II(')O
M;>MN:?!K:2!S:V%IZ&EA:0!,:75K<V5M8G5R9V%S`$U-`$U/5$0`4')I:V%B
M:6YT86UE($U3+51.148@9F%I;&4@;NMR82!D=6]MZV[X+@!-4T<`36%K86\`
M36%K961O;FEJ80!-861A9V%S:V%R87,`36%G:6IA`%!A\'1A<P!08?!T;R!V
M86QD>6UA<P!3=6MU<G1I(%]N=6]R;V3@+BXN`$UA;&%V:7,`36%L86EZ:6IA
M`$UA;&1Y=F%I`$UA;&ES`$UA;'1A`$MA=&5G;W)I:O@@<^!R8?!O+"!K=7)I
M;VUS('!R:7-K:7)I86UI(&]B:F5K=&%I+"!I<B!S=2!J;VUI<R!S=7-I:G5S
M:?@@<W!A;';X(&ME:71I;6%S+@!-87`R-"#^96WK;&%P:7,`36%P475E<W0@
M_F5MZVQA<&ES`$MO=F%S`%!A<F'P=.L`4&'^>6WK=&D@:V%I<"!S:V%I='ET
M=7,O;F5S:V%I='ET=7,`4&'^>6WK=&D@:VET86ES(&%T<FEB=71A:7,@*'!V
M>BX@<W9A<F)U+V%T<V%K>71A*0!-87+P86QO('-A;&]S`$UA<G1I;FEK80!3
M=6IU;F=T:2!L875K86D`36%U<FET86YI:F$`36%U<FEC:6IU<P!-86MS:6UA
M;'5S(&MR961I=&%S+@!-86MS:6UA;'5S(/YI;G7H:?@@9&%L:?@@:VEE:VES
M(&GP96EK=F]T87,N`$UA:W,N('1E;7`N('!A<VLN(#(T('9A;#H@`$UA:W,N
M('1E;7`N('!A<VLN(#8@=F%L.B``36%K<VEM86QU<R!I;&=I<P!'96=U_NL`
M36]J;W3K`$UE9&EC:6YA`%-U<VER:6YK:6UO(&YU=')A=6MI;6%S`%-U<VER
M:6YK:6UO(&EN9F]R;6%C:6IA`%-U<VER:6YK:6UO('!A<VG[;'EM87,`071S
M86MY;6%S(&%P:64@<W5S:7)I;FMI;>``4W5S:7)I;FMI;6\@871N875J:6YI
M;6%S`%-U<VER:6YK:6UO(&%T;F%U:FEN:6UO('7^:VQA=7-A`$YA<FEA:0!-
M96YI=2!R9?YI;6%S.@!3=6IU;F=T:2!C96QE<P#>:6YU=.L`3&%I\&MA<R!P
M879I<G1I;G1A<RP@=&'H:6%U(&YE<&%T=FER=&EN=&%S('!A<VER8?!I=7-I
M;R!A<VUE;G,@<V5R=&EF:6MA=&%S+@#>:6YU=.L@;F5I\'-I^'-T82X`WFEN
M=73K<R!T:7!A<P!/<F\@<V%L>6=O<P!/<F\@<^!L>6?X(&)L;VMO(&[K<F$N
M`$]R;R!SX&QY9_@@8FQO:V\@;NMR82X@061M:6YI<W1R871O<FEU:2!I\'-I
M^'-T87,@9&5T86QU<R!A<')A\'EM87,N`$UE=&]D87,`365T;V1A<R`G)7,G
M(&YE87!R8?!Y=&%S`$UA=&%I`$UE:W-I:V$`36EK<F]N97II:F]S($9E9&5R
M86-I;NMS(%9A;'-T:6IO<P!6:61U<GEJ90!-24U%('1I<&%S`$UI;BX@=&5M
M<"X@<&%S:RX@,C0@=F%L.B``36EN+B!T96UP+B!P87-K+B`V(&AO=7)S.B``
M36EN:6UA;'5S('-L87!T8?YO9/YI;R!G86QI;VII;6\@;&%I:V%S(&1A<B!N
M97!A<VEB86EGZP!!='-P:6YD>7,`2VET;W,`3F5R87-T87,@4$5!4B!(5%10
M7U)E<75E<W0@<&%K971A<RX`3G5S=&%T>6WX(&[K<F$N($IE:6=U(&YO<FET
M92!N875D;W1I(/#A(&UO9'5LX2P@='5R:71E(&KA('-U:V]N9FEG^W)U;W1I
M+@!.ZW)A(/YI;G5TZW,@240N`$YE<F%S=&%S(')E:6MA;&EN9V%S(%!%05(@
M36%I;"!P86ME=&%S+@!.ZW)A('-E<VEJ;W,@240N`%!I<FTN`$UO8FEL=7,@
M<&'P=&%S`%9I9'5T:6YI<P!2961A9V%V:6UO(&1A=&$`2V5I<W1I(%523`!-
M;V1U;&ES`$UO;&1O=F]S(%)E<W!U8FQI:V$`36]N86MA<P!-;VYG;VQI:F$`
M3>MN97-I86D@:7(@;65T86D`2V%S(&WK;F5SX0!-;VYS97)A=&%S`$WK;G5L
M:6\@9F%ZZW,`36%R;VMA<P!$875G:6%U<VEA(&=I961R80!$875G:6%U<VEA
M(&%P<VEN875KY@!$875G:6%U<VEA('-A=6SK=&$`4&5R:V5L=&D@_F5M:6%U
M`%!E<FME;'1I(&MA:7)I874`4&5R:V5L=&D@9&7P:6YI874`4&5R:V5L=&D@
M875K\.AI874`4&5R:^ML:6UA<R#^96UY;@!097)KZVQI;6%S(&%U:_!T>6X`
M36]Z86UB:6MA<P!+96QE=&\@;'EG:?@@:?!S:7-K;&5I9/YI86YT:7,@<^!R
M8?!A<P!+96QE=&%S('!A<VER:6YK:6WX`$UA;F\@<^!S:V%I=&$`36%N;R!P
M;W)T86QA<P!-86YO('!O<G1A;&\@:?!DZW-T>6UA<P!-86EN;6%R87,`3D4L
M($Y%4U5424Y+50!687)D87,`3F%M:6)I:F$`3F%U<F%S`%)E:6MA;&EN9V%S
M('9E:6MS;6%S`$YE<&%L87,`3GED97)L86YD86D`3GED97)L86YD^"!!;G1I
M;&%I`$YE='-C<&%P92!B87II;FES(%523`!.971S8W!A92!S97)I9FEK871O
M(&%T\&%U:VEM;R!54DP`3F5T<V-P864@<V5R=&EF:6MA=&\@=&5I<VGX(%52
M3`!.971S8V%P92!A=&YA=6II;F]M;R!54DP`3F5T<V-A<&4@873P875K:6UO
M(%523`!.971S8V%P92!34TP@<V5R=F5R:6\@=F%R9&%S`$YE='-C87!E('-E
M<G1I9FEK871O(&%P<F'P>6UA<P!.971S8V%P92!S97)T:69I:V%T;R!T:7!A
M<P!4:6YK;&%S`$YI96MA9&$`3F%U:F]J:2!+86QE9&]N:6IA`$YA=6IA(&MA
M=&5G;W)I:F$`3F%U:F%S(&WK;G5L:7,`3F%U:F%S('9A<G1O=&]J;R!V87)D
M87,@*&YE8OMT:6YA<RD`3F%U:F]J:2!:96QA;F1I:F$`3F%U:F%S('-L87!T
M8?YO9&ES.@!.875J86UE(&QA;F=E("A?8FQA;FLI`$YA=6II96YO<P!.875J
M:65N^"!G<G5PZW,`4V5K86YT:7,`4V5K86YT:7,@<'5S;&%P:7,`4V5K86YT
M:2!F87KK`%-E:V%N='ES(&YU<W1A='EM86D`3FEK87)A9W9A`$YI9V5R:7,`
M3FEG97)I:F$`3F%K=&ES`$YI=6KK`$YE`$YE=?YT96YK82!D=6]M96[X('-K
M:7)T=6WX('!A<F]D>6UU:2X`3F5N=7)O9'ET82!S=')A=&5G:6IA($E33R!R
M8?!Y;75I+@!.ZW)A('-U9.MT:6YI;R#P86)L;VYO+@!.=7)O9'ET;VIE('!O
M>FEC:6IO:F4@8FQO:V\@;NMR80!.9>%V963K=&4@:V%L96YD;W)I875S('9A
M<F1O($U#04P@875T96YT:69I:V%C:6IO:F4N`%-K:7)T=6WX(&[K<F$N`$YU
M;R#P:6\@;'EG:6\@;F%U9&]T:2!P;W1E:7-I^"!N96=A;&EM82X`T&EO<R!T
M96ESZW,@;F5G86QI('1U<NMT:2!P;W1E:7-I^"X`3NMR82!I;F9O<FUA8VEJ
M;W,@87!I92`E<R!K;VYF:6?[<F%C:6K@+@!.ZW)A(&EN9F]R;6%C:6IO<R!A
M<&EE($944"!61E,@:V]N9FEG^W)A8VEJX"X`3NMR82!I;F9O<FUA8VEJ;W,@
M87!I92!344P@5D93(&MO;F9I9_MR86-I:N`N`$[K<F$@:6YF;W)M86-I:F]S
M(&%P:64@4U%,+49I;&4@5D93(&MO;F9I9_MR86-I:N`N`$MR961I=&%S(&GP
M96EK=F]T87,N`$YEX79E<W1A<R!G87;K:F%S+@!&86EL87,@;F5N=7-I^'-T
M87,`3F5N=7-T871Y=&$@=FEE=&]VZRX`3F7A<F'PZW1E(/YI;G5TZW,N`$YE
MX7)A\.MT92!V87)D;RX`3F7A<F'PZW1E(&YU;65R:6\N`$YE<F]D>71I(.'^
M96ED_FEA;NAI^"!F<F%Z:?@`3F7A=F5DZW1E('-L87!T8?YO9/YI;R!(5%10
M(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT92!S;&%P=&'^;V3^:6\@24U!
M4"!A=71E;G1I9FEK86-I:F%I+@!.9>%V963K=&4@<VQA<'1A_F]D_FEO($ME
M<F)E<F]S(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT92!S;&%P=&'^;V3^
M:6\@3$1!4"!A=71E;G1I9FEK86-I:F%I+@!.9>%V963K=&4@<VQA<'1A_F]D
M_FEO($QO9VEN(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT92!S;&%P=&'^
M;V3^:6\@4$%34U=$(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT92!S;&%P
M=&'^;V3^:6\@4TU"(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E<W1A<R!K96QI
M87,@:6MI($]P96Y34TP@<&%G<FEN9&EN:?@@9F%I;/@N($]P96Y34TP@<F5I
M:V%L:6YG82!D87)B=6D@<W4@4$M#4R`Q,B!D=6]M96YI;6ES+@!.97!A='9I
M<G1I;G3X(')E9VES=')A8VEJ^"!NZW)A+@!.96YA=61O=&D@<VMI<G1U:_@`
M3NL@=FEE;F]J92!P=7/K:F4`)R5S)R!P;W-I<W1E;>MS(&[K<F$N`%-P87)T
M:6YI;75I(&[K<F$@;&%I:VEN;VIO(&MA=&%L;V=O+@!687)T;W1O:F\@=F%R
M9&%S(&ER+V%R8F$@<VQA<'1A_F]D:7,@;F5N=7-I^'-T87,N`%1E:7-I;F?X
M(%A-3"!D=6]M96[X(&[K<F$`3NMR82!R96EK\&UI^`!+;VYF:6?[<F%C:6YI
M86UE(&9A:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E;F5R=6]K:71E(&YU<W1A
M='EM=7,N`$MO;F9I9_MR86-I;FEA;64@9F%I;&4@;NMR82!V97)S:6IO<RX@
M4&5R9V5N97)U;VMI=&4@;G5S=&%T>6UU<RX`3F5D86QY=FES`$YE;G5R;V1Y
M=&$`3NMR80#0:6%U<NMS("A)4T\M.#@U.2TQ,"D`3F]R9F]L:V\@<V%L;W,`
MT&EA=7)I;NL@:&5M:7-F97)A`-!I875R:6[K<R!-87)I:F%N^"!S86QO<P!.
M;W)V96=I:F$`3F4@<&\@=&\`3F4@<')I9?`@=&%I`$YE(&MA=&%L;V=A<P!.
M97)E86QI>G5O=&$N`$YE;G5R;V1Y=&$`3F5P86QA:6MO;6%S+@!5_G)A\&%I
M`$[K<F$@:^`@<&5R_FG[<NMT:2P@96EK:71E(&%T9V%L+@!087-T86)A`$QA
M<&MR:71I<P!.=6UE<FES`%-I;6)O;&GX('-K86GH:75S`%-T=6QP96QI^"!S
M:V%IZ&EU<P!%:6QUZ&GX('-K86GH:75S`$YEX79E<W1I(&1I<W1R:6)U8VEJ
M;W,@<^!R8?!O(&%T;F%U:FEN:6UO('-K86GH:6%I+@!/2P!/8FIE:W1A<P!/
M8FIE:W1O('-A=FEN:6YK87,`3V)J96MT;R!S879I;FEN:V\@=&5I<^MS`$'P
M='5N=&%I;FES`%-P86QI<P#>:6%U<G5M;R!F:6QT<F%S`$]F:7-A<P!396YA
M<R!S;&%P=&'^;V1I<SH`3VUA;F%S`$MA=&%L;V?X(&1A;&EJ:6W@<VD@<&%L
M86EK;R!T:6L@24U!4"!S97)V97)I86DN`%1I:R#A_F5I9/YI86[H:6]S(&9R
M87KK<P!,96ED_FEA;6%S('1I:R!V:65N87,@96PN('!A\'1O(&%D<F5S87,N
M`$5L96UE;G1O('-A=FEN:6YK;R!T96ES97,@9V%L:2!K96ES=&D@=&EK(&IO
M('-A=FEN:6YK87,@87)B82!S:7-T96UO<R!A9&UI;FES=')A=&]R:75S`$%T
M:61A<GET:2!N875J86UE(&QA;F=E`$%T:61A<GET:2#P:>`@;G5O<F]DX"!N
M875J86UE(&QA;F=E`$]P<F%C:6[K<R!S:7-T96UO<P!+:71I(&1A;'EV:6%I
M`$YU<W1A='EM86D`)7,@;G5S=&%T>6UA:0!3=7+[\&EU;W1A<R!SX')A\&%S
M`$]R9V%N:7IA8VEJ80!0861A;&EN>7,`4VES=&5M:6YI;6%S`$]R:6=I;F%L
M=7,@87!L:6MA8VEJ;W,@\&%B;&]N87,`3W)I9VEN86SX<R#P86)L;VYA:2`E
M<SH`2VET80!+:71A(&EN9F]R;6%C:6IA`%-A=FEN:6YI:V\@=&5I<^MS`$[K
M<F$@4$%-(&%U=&5N=&EF:6MA8VEJ;W,@;65C:&%N:7IM;RX`4$=0('-K86ET
M;65N:6YI<R!P87)A\&%S`%!'4"!U_FMO9'5O=&$@:6YF;W)M86-I:F$`4$=0
M('9I9?!A<VES(')A:W1A<P!01U`@<&%S:7)A\'ET:2]U_FMO9'5O=&D@9'5O
M;65N>7,`4$A0(&MO9&%S`%!(4"!#3$D`4$T@;&5N9W9A<R!L:65T=7,`4$T@
M;&G[=&ES`%!-(%0M875D<F$`4%](4"!#3$D`5&%R<&%I(&-E;.MS90!086MI
M<W1A;F%S`%!A;&%U`%7^:6UT;VII(%!A;&5S=&EN;W,@=&5R:71O<FEJ80!0
M86YA;6$`4&%P=6$@3F%U:F]J:2!'=FENZVIA`%!A<F%G=F%J=7,`1&%L:6YA
M:2!D96)E<W5O=&$`4VQA<'1A_F]D_FEO(&ME:71I;6\@;6]D=6QI<R!N97-U
M:V]N9FEG^W)U;W1A<RX`4VQA<'1A_F]D:7,`4VQA<'1A_F]D:7,@<V5R=F5R
M>6IE("5S('!A:V5I<W1A<RX`4VQA<'1A_F]D:7,@;F5T96ES:6YG87,`4VQA
M<'1A_F]D_FEO(&ME:71I;6\@;6]D=6QI<R!N96=A;&D@<F%S=&D@<F5I:VEA
M;?@@9'5O;65N^"X`4VQA<'1A_F]D_FEO(&ME:71I;6\@;6]D=6QI<R!N97)A
M;F1A(')E:6MA;&EN9_@@<&%R86UE='+X+@!3;&%P=&'^;V3^:6\@:V5I=&EM
M;R!M;V1U;&ES(&YE<F%N9&$@;G5S=&%T>73X('!A<F%M971R^"X`4VQA<'1A
M_F]D_FEO(&ME:71I;6\@;6]D=6QI<R!N97-U:V]N9FEG^W)U;W1A<P!3;&%P
M=&'^;V3^:6\@:V5I=&EM;R!M;V1U;&ES(&YE<W5K;VYF:6?[<G5O=&%S+@!2
M041)55,@875T96YT:69I:V%C:6IA:2!R96EK:6$@<VQA<'1A_F]D_FEO+@!3
M;&%P=&'^;V1I<R!S=2!P871V:7)T:6YI;74`4VQA<'1A_F]D:7,Z`%-L87!T
M8?YO9&ES.B``4VQA<'1A_F]D_FEA:2!T=7)I('-U=&%P=&DN`,%K96QT:0#!
M:V5L=&D@:?`@;&%I:VEN;W-I;W,@<V%U9WEK;&]S("AC;&EP8F]A<F0I`$ME
M;&EA<P!.97!A='9I<G1I;G1O<R!R96=I<W1R86-I:F]S.@#>;6]NZW,`4')O
M8V5N=&%I`$%T;&EK=&D@<')O9FEL86MT:6YI=7,@=F5I:W-M=7,`07(@871L
M:6MT:2!P<F]F:6QA:W1I;FEU<R!V96EK<VUU<R!P<FES:6IU;F=I;6\@;65T
M=3\`5&5I<^MS`%1E:7/K<R`G)7,G(&YE:?!T<FEN=&]S+@!496ES:?@@861M
M:6YI<W1R879I;6%S`%1E:7/K<P!!<VUE;FENZR!I;F9O<FUA8VEJ80!097)U
M`$=Y=OMN86D`1FEL:7!I;F%I`%1E;&5F;VYA<P!.=6]T<F%U:V]S`%!I=&MR
M86YA<P!0:6MS96QI86D`0F%N86QY8NMS`$GP<VER:6YK:71E(&MU<FG@(&YO
M<G,@8V5LY@!0871V:7)T:6YK:71E+"!A<B!T:6MR86D@;F]R:71E(&GP=')I
M;G1I(/#A(&5L96UE;G3@.@!0871V:7)T:6YK:71E+"!A<B!T:6MR86D@;F]R
M:71E(&GP=')I;G1I(/!I;R!E;&5M96YT;R!N=6]R;V3@+@#!=F5S:VET92!M
MZVYE<^$@:7(@;65T=7,N`,%V97-K:71E(&YA=6IO<R!K871E9V]R:6IO<R!P
M879A9&EN:6W@.@#!=F5S:VET92!T96ES:6YGX"!)4"!A9')E<^`N`,%V97-K
M:71E('1E:7-I;F?@(&1A=.`L('!A=&EK<FEN:VET92!D:65N^"!S:V%IZ&GX
M(&WK;F5S>6IE+@#!=F5S:VET92!T96ES:6YGX"!L86EKX"X`07!R8?!Y:VET
M92!P<F]B;&5MX"X`3G5R;V1Y:VET92!S879O('9A<G1O=&]J;R!V87)DX"!B
M96D@<VQA<'1A_F]DX0!0<F'P;VUE('!E<G-K86ET>71I(/#A('1E:W-TX"X@
M2OMS(%!2259!3$]412!S=71I:W1I('-U('/@;'EG;VUI<RP@:F5I(&YO<FET
M92!N875D;W1I<R!S:7-T96UA+@!097)S:V%I='EK:71E(&EN9F]R;6%C:6K@
M(&ER(&GP(/YE;6EA=2!E<V%NZ&EO(&UE;FEU('!A<VER:6YK:71E(&YO<FEM
MX"!V96EK<VW@+@!087-I<FEN:VET92!V96EK<VW@(&GP(&UE;FEU(/YE;6EA
M=2X`P79E<VMI=&4@;F%U:N`@:V%T96=O<FEJ;W,@<&%V861I;FEMX#H`3&5N
M:VEJ80!0;VQI=&EK86D`0F%L<V%V:6UA:0!0;W)T=6=A;&EJ80!0879E:6MS
M;.ML:6\@<&]Z:6-I:F$`3&5N=&5LZW,@<&]Z:6-I:F$`2?!S875G;W1I(/!I
M86UE(&MA=&%L;V=E("AN96=A;&EO:F$@24U!4"D`2W)I='5L:6%I('!A<VLN
M("5S('9A;&%N9.`H87,I.B``4')E9G-?;&1A<#H@;F5R87-T87,@<F5I:V%L
M:6YG87,@3$1!4"!M;V1U;&ES+@!0<F5F<U]S97-S:6]N.B!N97)A<W1A<R!R
M96EK86QI;F=A<R!S97-I:O@@;6]D=6QI<RX`4')E>F5N=&%C:6IO<P!3;.MG
M:7,`4VSK9VES(&K[<F]S(&QY9WEJ93H@`%-LZV=I<SH@`%!E<OYI^W)A`%!E
M<OYI^W+K=&D@<&%V96EK<VSK;.$@;F%U:F%M92!L86YG90!!;FMS=&5S;FES
M('!U<VQA<&ES`$%N:W-T97-N:2!N=7-T871Y;6%I`$%T<W!A=7-D:6YT:2!D
M;VMU;65N=.``4VQA<'1A<VES(')A:W1A<P!0<F]B;&5M80!0<F]B;&5M;W,@
M87!R8?!Y;6%S`%!R;VIE:W1A:0!0<F'P>6UA<R!T96MS='5I`%9I9?!A<VES
M(')A:W1A<P!6:67P;VIO(')A:W1O(&%L9V]R:71M87,`5FEE\&]J;R]S;&%P
M=&]J;R!R86MT^"!P;W)A(&YE<W5G96YE<G5O=&$N`%!U97)T;R!2:6MA<P!+
M871A<F%S`%-A:VEN>7,`4E-!('9I9?!A<VES(')A:W1A<R`H)60@8FET86DI
M`"=2861I;R<@<&%S:7)I;FMI;6%S`$QI971U<P!,:65T=7,O4VYI96=A<P!,
M:65T=7,OT&QA<&1R:6)A`$QI971U<R]6ZVIA<P!,:65T=7,@<GET90!,:65T
M=7,@=F%K87)E`$QI^W1I<P!!='-I=&EK=&ENZR!F<F%ZZP!386YT>6MI<P!3
M:V%I='ET:0!097)S:V%I='ET:2!L86GP:V%I`%1I:W)A:2!I\'1R:6YT:2`E
M<S\@1W)A_FEN=&D@871G86P@;F5B96=A;.MS:71E+@!4:6MR86D@:?!T<FEN
M=&D@=F%R=&]T;VIO("5S(&1U;VUE;FES/R!'<F'^:6YT:2!A=&=A;"!N96)E
M9V%LZW-I=&4N`%!A:V%R=&]T:2!A;FMS=&5S;N$@=F5I:W-MX`!!=&YA=6II
M;G1I(&MA:7)I;VIO(&UE;FEU(&5L96UE;G1U<SH`071N875J:6YT:2!P;W)T
M86QO('9A:7IDX#H`4F5G97@`4^!R>?!I^"!N87+P>6MLZP!087-T86)O<P!0
M<FES:6UI;G1I('7^:6UT=6UO(&EN9F]R;6%C:6K@+@!.=71O;.8@<V5R=F5R
M:6%I`$YU=&]LYG,@55),("AH='1P.B\O=W=W+G!A=GEZ9'ES+F-O;2]H;W)D
M92DZ`$GP=')I;G1I`%!A\&%L:6YT:2!B;&]KX`!086YA:6MI;G1I('-T=6QP
M96SA`%!A;F%I:VEN=&D@9F]R;6%T879I;>``4&'P86QI;G1I(&GP(&UA;F\@
M:V%L96YD;W)I875S`$GP=')I;G1I('!O<N``2?!T<FEN=&D@871N875J:6YI
M;6\@<VMR:7!TX"!I\"!S97)V97)I;R!L86EK:6YO:F\@:V%T86QO9V\N`%!A
M\&%L:6YT:0!08?!A;&EN=&D@\.$@96QE;65N=.`@:?`@9&]K=6UE;G1O`$GP
M=')I;G1I('9A<G1O=&]JX`!687)T;W1O:F\@=')Y;FEM87,Z("5S`$%T<V%K
M>6UA<R!I\'-I^'-T87,N`$%T<V%K>6UO(/YI;G5TZW,@=&EP87,@;F5P86QA
M:6MO;6%S`$%T<V%K>71I('-U('7^:6UT=6UO(&EN9F]R;6%C:6IA('-E:V%N
MZ&EU<R`R(&WK;F5S:75S+@!!='-A:WET:2!S=2!U_FEM='5M;R!I;F9O<FUA
M8VEJ82X`071S86MY=&DZ("5S`$YE9V%L:74@871S86MY=&D@X2!U_FML875S
MX"X@2VQA:61O<R!K;V1A<SH@`%!A<F%M971R87,@)R5S)R!N96YU<F]D>71A
M<R`E<R!K;VYF:6?[<F%C:6IO:F4N`%!A<F%M971R87,@)R5S)R!N96YU<F]D
M>71A<R!61E,@:V]N9FEG^W)A8VEJ;VIE+@!087)A;65T<F%S("<E<R<@;F5N
M=7)O9'ET87,@:V]N9FEG^W)A8VEJ;VIE+@!087)A;65T<F%S("=D<FEV97)S
M)R!N971E:7-I;F=A:2!S=6MO;F9I9_MR=6]T87,@;G5S=&%T>6UU;W-E+@!0
M87)A;65T<F%S("=P:'!T>7!E)R!N96YU<F]D>71A<R!087-S=V0@4U%,(&MO
M;F9I9_MR86-I:F]J92X`4&%R86UE=')A<R`G<&AP='EP92<@;F5N=7)O9'ET
M87,@4U%,(&MO;F9I9_MR86-I:F]J92X`4F5I:V%L:6YG87,@9&%L>79I<P!)
M\'9A;'ET:0!086ME:7-T:2!S;&%P=&'^;V3A`%-L87!T8?YO9/YI;R!K96ET
M:6UA<P!297IU;'1A=&%I`$=RX?YT:2#A(&YU<W1A='EM=7,`4F5J^VYI:F$`
M071S=&%T>71I(&MO;F9I9_MR86-I:N``2%1-3"!R961A:W1O<FEA=7,@;G5S
M=&%T>6UA:0!-X7-LZW,`1&7P:6[K:F4`1&7P:6YI;VII(&%N=')A\'3K`$1E
M\&EN:6]S:6]S(')E:6OP;>MS`%]%:6QU=.MS(&YU<W1A='EM86DN+BX`4F]L
MZP!2=6UU;FEJ80!087-U:W1I(#$X,`!087-U:W1I(&MA:7+K;@!087-U:W1I
M(&1E\&ENZVX`16EL=73K<R!N=7-T871Y;6%I`$5I;'5TZW,@;G5S=&%T>6UA
M:0!%:6QU=.MS.@!3:VER='5K86D`4VMI<G1U:V%I('1A<G`@=FES^"!E:6QU
MZ&GX(&ER('-T=6QP96QI^`!3:VER='5K86D@=&EK('1A<G`@<W1U;'!E;&GX
M`%-K:7)T=6MA:2!T:6L@=&%R<"!E:6QUZ&GX`%9Y:V1Y=&D`4G5S:6IO<R!&
M961E<F%C:6IA`%)U86YD80!3+TU)344@<&%R8?!A<P!3+TU)344@=?YK;V1U
M;W1A<R!L86GP:V%S`$[K<F$@4T%33"!A=71E;G1I9FEK86-I:F]S(&UE8VAA
M;FEZ;6\N`%--4R#^:6YU=.MS`%-13"!#3$D`4U,`4U-(`%!!5EE+3P!37U%,
M($-,20#09?!T+@#0=F5N=&]J:2!(96QE;F$`4V%I;G0@2VET<V%S(&ER($YE
M=FES87,`4V%I;G0@3&EU8VEJ80#0=F5N=&%S:7,@4&5T<F%S(&ER($UI9V5L
M;VYA<P!386EN="!6:6YC96YT87,@:7(@1W)E;F%D:6YA:0!486UE('!AZ&EA
M;64@;&%N9V4@*%]S96QF*0!386UO80!386X@36%R:6YA<P!386\@5&]M92!I
M<B!0<FEN8VEPZP!086QY9&]V87,`4V%U9&\@07)A8FEJ80!)\'-A=6=O=&D`
M2?!S875G;W1I("5S`$GP<V%U9V]T:2`G)7,G`$GP<V%U9V]T:2!N=7-T871Y
M;75S`$GP<V%U9V]T:2!S=6=E;F5R=6]T=7,@;G5S=&%T>6UU<R!K86EP(%!(
M4"!S:W)I<'3@(&K[<_@@<V5R=F5R:6\@;&%I:VEN86IA;64@:V%T86QO9V4N
M`"5S(&YU<W1A='EM86D@:?!S875G;W1I+@!!=&YA=6II;FEM;R!S:W)I<'1A
M<R!I\'-A=6=O=&%S(.$Z("<E<R<N`$UO:W-L87,`267P:V]T:0!086EE\&MA
M`%!A<VER:6YK:71E(&9A:6QU<P!087-I<FEN:VET92!D873@`%!A<VER:6YK
M:71E(&=R=7#F`%!A<VER:6YK:71E(&YA=6K@('-A=FEN:6YKX`!087-I<FEN
M:VET92!S97)V97+A`%!A<VER:6YK:71E('9A<G1O=&]JX`!087-I<FEN:VET
M92!V:7-U<R!D871O<R!K;VUP;VYE;G1U<RX`4&%S:7)I;FMI=&4@;V)J96MT
MX`!)\"#^96UI874@97-A;NAI^"!SX')A\/@@<&%S:7)I;FMI=&4@<F5I:VEA
M;75S('-I;6)O;&EU<RX@5NML:6%U(&=A;&ET92!J=6]S(&YU:V]P:6IU;W1I
M(.$@;&%I\&O@+@!087-I<FEN:VET92!D871O<R!S:VER='5KX#H`4&%S:7)I
M;FMI=&4@9&%T;W,@9F]R;6%TX#H`4&%S:7)I;FMI=&4@87!R8?#@(&MU<N$@
M;F]R:71E(')E9&%G=6]T:3H`4&%S:7)I;FMI=&4@;&%I:V\@<VMI<G1U:^`Z
M`%!A<VER:6YK:71E(&QA:6MO(&9O<FUA=.`Z`%!A<VER:6YK:71E('1A:2P@
M:F5I9W4@;F%U9&]J871E($EN=&5R;F5T($5X<&QO<F5R(&YA<O!Y:VSF(&ER
M(&YE;6%T;W1E('!I:W1O9W)A;?@`4&%S:7)I;FMI=&4@9'4@871I=&EN:V%N
MZ&EU<R!L875K=7,N`%!A<VER:6YK:71E('-P86QV^"!D97)I;N$N`%!A<VER
M:6YK:71E(&YO<FEMX"!K86QBX#H`4VGX<W1I(&YA=6IA=7-IX"!I;F9O<FUA
M8VEJX`!3:?AS=&D@<')O8FQE;6]S('!R86YE\&EMX`!3:?AS=&D@4TU3`%-E
M;F5G86QA<P!396YS;W)I=7,Z(`!2=6=SZVII<P!397)B:6IA(&ER($UO;G1E
M;F5G<F%S`%-E<FEJ;W,@;G5M97)I<P!397-I:F]S($E$('!A<VEB86EGZRX`
M4FEN:VEN>7,`3G5S=&%T>6UA:2!L96ED_FEA;G1Y<R!*=6US('!A<VEK96ES
M=&D@<VQA<'1A_F]DX2P@:F5I9W4@:N$@:V%D82!N;W)S('!A;6ER\&ET92X`
M3G5T;VQU<VGX('-E<G9E<FGX+"!K=7)I=6]S(&YO<FET92!M871Y=&D@:?`@
M<&]R=&%L;RP@;G5S=&%T>6UA:2X`2V%L8F]S+"!L86EK;R!Z;VYO<R!I<B!D
M871O<R!N=7-T871Y;6%I+@!0=7-L87!I;R!S<&%L=O@L(&%T<VEN875J:6YI
M;6\@9&'^;G5M;R!I<B!K:73X('9A:7ID879I;6\@<&%R86UE='+X(&YU<W1A
M='EM86DN`%)A<W1A<R!A=&YA=6II;FEM;R!S:W)I<'1A<P!3=2#P:75O('!A
M<F%M971R=2!G86QI;6]S(&ME;&EO<R!V:65T;W;K<SH@`%-E:?!E;&%I`%!A
M<F1U;W1U=NL`5')U;7!A<R!A<')A\'EM87,`07(@;F%U9&]T:2!K;&%V:6%T
M^W)O<R!M>6=T=6MU<R!V86QD>6UU:3\`4F]D>71I`%!A<F]D>71I('-K:7)T
M=6UU<R!T87)P(&GP<V%U9V]T;R!I<B!KX"!T:6L@<W5G96YE<G5O=&\@:V]N
M9FEG^W)A8VEN:6\@9F%I;&\N`%)O9'ET:2!P87-K=71I;FEO('!R:7-I:G5N
M9VEM;R!L86EKX#\`4F]D>71I(&=A;&EM>6+F('!A;&EK=&D@;W)I9VEN86S@
M`%)O9'ET:2!P87)I<VEN:VEMX`!2;V1Y=&D@;&5N=&5LZW,@;W!E<F%C:6KX
M(&UE;FEU/P!2;V1Y=&D@)7,@;65N:74@:V%I<NMJ93\`4F]D>71I(&-E;.MS
M(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@;&5N=&5LZW,@;G5S=&%T>6WX(&QA
M;F?@`%)O9'ET:2!E:6QU=.MS(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@<&%V
M96EK<VSK;&EO(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@9F%I;/@@X6OK;&EM
MX`!,:?MT:7,`3&G[=&ES+U;K:F%S`$QI^W1I<R!R>71E`$QI^W1I<R!V86MA
M<F4`4W5M8?YI;G1I`%-U;6'^:6YT:2!A<F)A('!A<W1U;71I(&MA:6UY;FEN
M:75S(&)L;VMU<P!3:65R82!,96]NZP!296=I<W1R86-I:F$`2F5I9W4@;F5U
M_G-I<F5G:7-T<F%V;W1E+"!P861A<GEK:71E('1A:0!087)A\&%S`%!A<F'P
M;R!A;&=O<FET;6%S`%-I;F=A</MR87,`1'ED:7,`4')A;&5I<W1I('!R;V9I
M;&%K=&EKX`!3;&]V86MI:F$`4VQO=NMN:6IA`%#[9V$`4VYI96=O(&=Y;&ES
M.B``4VYI96=O(&MI96MI<R!V86YD96YI=3H@`%-O;&]M;VYO('-A;&]S`%-O
M;6%L:6$`1&%I;F]S(&ER($5I;.MR8?#H:6%I`%+[\&EA=FEM;R!T=F%R:V]S
M('!A<VER:6YK:6UA<P!3:75N=.MJ;R!A9')E<V%S`%!I973X($%F<FEK80!0
M:65T^"!%=7)O<&]S("A)4T\M.#@U.2TS*0!0:65T^"!$_F]R9/YI:F]S(&ER
M(%!I973X(%-A;F1V:>AO('-A;&]S`%!I971I;NL@:&5M:7-F97)A`%1A<G!A
M<R!T87)P(&-E;&GX`%1A<G!A<R!T87)P(&-E;.MS('1U<FEN:6\@:7(@:W)A
M\'1I;NMS`%1A<G!A<P!487)P86D@=&%R<"!C96QI^`!487)P86D`27-P86YI
M:F$`4W!A;6%S`%-P96-I9FEN:?@@<VEM8F]L:?@@X71E<G!I;6%S`%!E<G-K
M96QT:2!C96SF`%!E<G-K96QT:2!S='5L<&5LX0!097)S:V5L=&D@96EL=73F
M`%-P;W)T87,`T')I($QA;FMA`%-T86YD87)T87,`4W1A<B!4<F5K)V%S`%!R
M863K=&D`4')A9&EN:6%I(&UE=&%I`%)A:F]N87,@87)B82!P<F]V:6YC:6IA
M`$+[<V5N80!3875G;VII;6\@9F]R;6%T87,`1V%T=NMS(&%D<F5S87,`5?YB
M<F%U:W1I`-YO9/YI^"!SX')A\&%S`$YU:6UT:2!D;VUE;N`@;G5O(&%D<F5S
M;P!3=&EL:75S(%M#4U-=`%-E:VTN`%1E;6$`5FEE\&]J;R!R86MT;R!I;F9O
M<FUA8VEJ80#!=F5S=&D`5F%R=&]T;VIA<R`G)7,G('-U:W5R=&%S('-I<W1E
M;6]J92X@2V]L(&II<R!N97!A='9I<G1I;G1A<RP@<')I<VEJ=6YG=&D@;F5G
M86SK<VET92X`26YD96MS87,`4^MK;6EN9V$`)R5S)R!SZVMM:6YG86D@<W5K
M=7)T87,@<VES=&5M;VIE+@!687)T;W1O:F\@)R5S)R!D=6]M96YY<R!SZVMM
M:6YG86D@:?!T<FEN=&D@:?`@<VES=&5M;W,N`"<E<R<@<^MK;6EN9V%I(&GP
M=')I;G1A+@`G)7,G('/K:VUI;F=A:2!I\'1R:6YT87,@:?`@<VES=&5M;W,N
M`$MO;F9I9_MR86-I:F$@871S=&%T>71A('/K:VUI;F=A:2X@4&5R:W)A=6MI
M=&4@<'5S;&%PX2P@:V%D('!A;6%T>71U;>MT92!P86ME:71U;75S+@!!='-A
M<F=I;NL@:V]N9FEG^W)A8VEJ;W,@:V]P:6IA('/K:VUI;F=A:2!I\'-A=6=O
M=&$@X2`E<RX`071S87)G:6[K(&MO;F9I9_MR86-I:F]S(&MO<&EJ82!SZVMM
M:6YG86D@:?!S875G;W1A+@`G)7,G('/K:VUI;F=A:2!A=&YA=6II;G1A<RX`
M)R5S)R!SZVMM:6YG86D@=?YR8?!Y=&%S+@!3=61A;F%S`%1U<FEN>7,`4V%U
M;.MT96MI<P!3875LZVQY9VES`%-A=6SK=&$`4V%U;.MT96MI<P!3875LZW1E
M:VES+U-A=6SK;'ED:7,`4V%U;.MT96MI<SH@`%-A=6SK;'EG:7,`4V%U;.ML
M>6=I<SH@`$QA:7!S;FES`$%P=&%R;F%V:6UA<P!3=7)I;F%M87,`4&%V87)D
MZP!3=F%L8F%R9&%S(&ER($3^86YM86EN87,`4W9A>FEL86YD87,`T'9E9&EJ
M80#0=F5I8V%R:6IA`%-I;G1A:W/K<R!K;&%I9&$@<&%I9?!K;W,@:W)I=&5R
M:6IU:F4`4VER:6IO<R!!<F%B^"!297-P=6)L:6MA`%0M875D<F$`5"UA=61R
M;W,`5%-6(&9A:6QA<P!,96YT96SK`$QE;G1E;.MS(&YU<W1A='EM86D`3&5N
M=&5LZW,@;G5S=&%T>6UA:0!486EV86YA<P!486EV86YA<RP@2VEN:6IO<R!P
M<F]V:6YC:6IA`%1A9/YI:VES=&%N87,`2G5N9W1I;NL@5&%N>F%N:6IO<R!2
M97-P=6)L:6MA`%1A:6MI;GES.@!$87)B86D`5&5L969O;F\@;G5M97)I<P!4
M96UP+B!P87-K+B!V86QA;F3@.B``5&5M<&5R873[<F$`5&5M<&5R873[<F$Z
M(`!.97)A<W1A<R`G)7,G(/!A8FQO;F%S+@#086)L;V[X(&%D;6EN:7-T<F%V
M:6UA<P!5_FML875S82!L86EK:6YA;2!P<FGK;6EM=6D`3&%I:VEN86D@<')I
M:6UT87,`5&5K<W1A<P!4:6L@=&5K<W1A<P!,>6=I=6]T:2!T96MS=.``5&5K
M<W1O('9I<O!U:F4`2V5T=BX`5&%I;&%N9&EE=&GP:V$@*%1)4RTV,C`I`%1A
M:6QA;F1A<P!!Z&G[(&MA9"!N875D;VIA=.MS('-I<W1E;6$N`$[K<F$@1E10
M(&UO9'5L:6\N`$AO<F1E+TMO;&%B(&EN=&5G<F%C:6IO<R!V87)I:VQI=6MA
M<R!N97!A;&%I:V\@(B5S(@!.97!A=GEK;R!U_FMR875T:2!-86EN=&5N86YC
M93HZ(&ML87/K<P!.=7-T871Y;?@@;&%N9V%S('7^9&%R>71A<RX@2?!E:6YU
M+@!*96EG=2!N;W)I=&4@;F%U9&]T:2!N=7-T871Y;75S+"!P87!R8?!Y:VET
M92!K860@861M:6YI<W1R871O<FEU<R!S=6MO;F9I9_MR=6]T^"!P87-T;W9I
MX"!D=6]M96[X(&)A>N8@;G5S=&%T>6UA;7,@<V%U9V]T:2X`5&EK(&%P871I
M;NMJ92!P=7/K:F4`2V%L96YD;W)I875S(&1U;VUE;GES(&YE=&5I<VEN9VD`
M3F7A<F'PZW1E(&-O;G1A:W1O($E$(&YU;65R:6\@87)B82!J:7,@;F5R87-T
M87,@9'5O;65N^"!B87KK:F4N`$MO;G1A:W1A<R!SZVMM:6YG86D@X71R875K
M=&%S(.$@2OMS^"!A9')E<_@@:VYY9V5LYBX`3F]RZV1A;6D@<&%T:6MR:6YT
M:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!A='-K:7+@(%!'4"!P87)A\&\@
M8FQO:^`N`$YEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P;R!)1"!A<F)A
M(&II<R!N97)A<W1A<R!D=6]M96[X(&)A>NMJ92X`3F7A<F'PZW1E(&1I<W1R
M:6)U8VEJ;W,@<^!R8?!O+@!01U`@=?YK;V1A=FEM;R!G86QI;7EBZR!R96EK
M86QA=6IA('-A=6=A=7,@<')I<VEJ=6YG:6UO+B!"86YD>6MI=&4@<F'P>71I
M(&AT='!S.B\O(&%D<F5S;R!P<F%D_FEO:F4N`,%V>6MI<R!P<FEDZW1A<R!P
M<FEE($K[<_@@:V%L96YD;W)I875S+@!&86EL87,@)7,@<')I=F%L;R!T=7+K
M=&D@)7,@<&%R86UE='+@+@!&86EL87,@)7,@<')I=F%L;R!T=7+K=&D@:V%I
M(&MU<FEU;W,@)7,@<&%R86UE=')U<RX`1F%I;&%S(&YE9V%L:2!B^W1I(&YU
M:V]P:6IU;W1A<R!A;G0@<V%VYG,N`$9A:6QE(&[K<F$@9'5O;65N^"X`4D9#
M.#@R(&QA:?!K;R!A;G1R8?!TZW,N`$IE:6=U(&1I<F)A=&4@26YT97)N970@
M17AP;&]R97(@;F%R\'EK;&4L('!I;&YA96MR86YI<R!R961A:W1O<FEA=7,@
M<F7^:6UA<R!G86QI('-U:V5L=&D@<')O8FQE;?@L(&3K;"#P:6]S(&YA<O!Y
M:VSK<R!K;&%I9/@N($=A;&ET92!N96UA='ET:2!K86D@:W5R:?@@<F5D86MT
M;W)I875S(&5L96UE;G3X+B!*96EG=2!N875D;VIA=&4@5VEN9&]W<R`Y>"!/
M4R!G<F5IZ&EA=7-I86D@:OMS^"!K;VUP:75T97)I<R!P87!R8?#H:6%U<VEA
M:2!N=6QU\"!P87-K96QB9&%M87,@87!I92!P86=R:6YD:6[F(&ML86EDX"Y<
M;EQN2OMS(&)U=F]T92!P97)S<.MT87,N($IE:6=U('9I<W1I96L@;F]R:71E
M(&GP8F%N9'ET:2!P:6QN865K<F%NX2!R9?YI;>`@<W!A=7-K:71E($]++@!!
M<')A\&%S("(E<R(@:?!T<FEN=&%S+@!4:6L@:V%I<NMJ92!P=7/K:F4`0W)Y
M<'1?<'%P.CH@:VQA<V5I(')E:6MI82!N=7)O9'ET:2!K=7(@>7)A($=N=5!'
M(&9A:6QA:2X`3&%I\&MA<R!I\'-I^'-T87,@)7,@861R97-A='5I("5S('1E
M;6$@(B5S(B!B=79O('!A<F]D>71A<RX*5&'H:6%U('1A:2!N96=A<F%N='5O
M:F$@:V%D(&QA:?!K87,@8G5V;R!P97)S:V%I='ET87,@87)B82!S=7!R87-T
M87,N`%!A=F%D:6YI;6%S(&MU<N$@;F%U9&]S:71E(&YU;W)O9&]J92#A(&QA
M:?!K;R!R8?!Y;6\@<'5S;&%PX0!(;W)D95]#<GEP=%]S;6EM93HZ(&ML87-E
M:2!R96EK86QI;F=A<R!/<&5N4U-,(&UO9'5L:7,N`$YE9V%L:74@:?!S875G
M;W1I(&YU<W1A='EM;R`B)7,B+"!N97,@9'5O;65N^"!D>61I<R!V:7+P>6IA
M(&QE:7-T:6[@(')I8N``4')O9W)A;6$L('-K:7)T82!P97+^:?MRZW1I(/#A
M(&1U;VUE;O@@=&EPX"`H)7,I+"!N97)A<W1A('-I<W1E;6]J92X`5&EK(&MA
M:7+K:F4@:7(@9&7P:6[K:F4@<'5SZW-E`%1I:R!D9?!I;NMJ92!P=7/K:F4`
M4V5R=F5R:7,@(B5S(B!I\'1R:6YT87,N`%-E<G9E<FES("(E<R(@:?!S875G
M;W1A<RX`)7,@<F5G:7-T<F%C:6IO<R!P<F'P>6UA<R!I\'1R:6YT87,N`$YU
M<F]D>71A(&5I;'5TZR!N965G>FES='5O:F$N`%7^9'5O=&ES('!R:63K=&$@
M<')I92!J^W/X(&1A<F+X('/@<F'P;RX`5&EK('9I<O!U=&ENZVIE(&ER(&%P
M871I;NMJ92!P=7/K<V4`5&EK(&%P871I;NMJ92!P=7/K:F4`3G5S:?AS=&D@
M9'5O;65N>7,@<')A<F%S=&DN`$YE9V%L:74@:?!S875G;W1I(&YU<VGX<W1O
M(&9A:6QO+@!687)T;W1O:F\@=?YI;71U;6\@:6YF;W)M86-I:F$@<^MK;6EN
M9V%I(&GP<V%U9V]T82X`5V5A=&AE<BYC;VT@8FQO:V\@;NMR82X`3G5S=&%T
M>6WX(&[K<F$N`$1A;&GX+"!K=7)I87,@9V%L:6UA(')O9'ET:2!L86GP:V\@
M=&5K<W1E+"!NZW)A+@#0:6%M92!L875K92#A=F5S=&$@<&5R(&1A=6<@<VEM
M8F]L:?@N($K[<R#A=F5DZW1E("5S+"!O(&UA:W-I;6%L=7,@<VMA:>AI=7,@
M+2`E<R!S:6UB;VQI86DN`%-U:W5R=&D@)R5S)R!N97!A=GEK;RX@)7,N`%-U
M:W5R=&D@)R5S)R!N97!A=GEK;SH@)7,`3F5P879Y:V\@:?!T<FEN=&D@=F%R
M=&]T;VIO("<E<R<@9'5O;65N^"!I\"!S:7-T96UO<SH@`$GP=')I;G1I("<E
M<R<@;F5P879Y:V\Z(`!!=&YA=6II;G1I("<E<R<@;F5P879Y:V\Z("5S`%!R
M;V)L96UO<R!S=2!F86EL^"!S:75N=&EM=3H@)7,@;F5N=7-I^'-T87,N`$YU
M<VGX<W1I(&9A:6QO(&YE<&%V>6MO+B!&86EL87,@)7,@>7)A(&1I9&5S;FES
M(&YE9W4@;&5I9/YI86UA<R!D>61I<R`H)60@8F%I=&%I*2X`3G5S:?AS=&D@
M9F%I;&\@;F5P879Y:V\N($9A:6QA<R`E<R!T:6L@9&%L:6YA:2!N=7-I^'-T
M87,N`$YE9V%L:74@<&%R;V1Y=&D@\&EO<R!L86GP:V\@9&%L:65S`$ML86ED
M82#A:V5L:6%N="!K;VYT86MT:6YI=7,@9'5O;65N:7,N`$ML86ED82#A:V5L
M:6%N="#A=GEKX3H@)7,N`$ML86ED82#A:V5L:6%N="!I0V%L96YD87(@9'5O
M;65N:7,N`$ML86ED82#A:V5L:6%N="!D87)BX#H@)7,N`$ML86ED82#A:V5L
M:6%N="!V87)T;W1O:F\@=?YI;71U;6\@:6YF;W)M86-I:N`Z("5S+@!+;&%I
M9&$@:V]N9FEG^W)A8VEJ;W,@9F]R;6]J92X@1W)E:>AI875S:6%I(&YE=?YP
M:6QDZW1E(')E:6MI86WX(&QA=6OX+@!+;&%I9&$@871L:65K86YT(&YU<F]D
M>73@(&%D<F5S^"!K;GEG96SK<R!F=6YK8VEJX"X@4&%B86YD>6MI=&4@=NML
M:6%U+@!+;&%I9&$@871N875J:6YA;G0@:V]N=&%K=&EN:75S(&1U;VUE;FES
M+B!086)A;F1Y:VET92!VZVQI874N`$ML86ED82!A=&YA=6II;F%N="!D:7-T
M<FEB=6-I:F]S('/@<F'PX"X@4&%B86YD>6MI=&4@=NML:6%U+@#0:7,@24U!
M4"!S97)V97)I<R!N97!A;&%I:V\@:V%T86QO9_@@9&%L:6II;6]S:2X`T&ES
M('9E:6MS;6%S(&YE<&%L86EK;VUA<RX`T&ES('9E:6MS;6%S(&YE<F5A;&EZ
M=6]T87,N`$%T<F]D;RP@:V%D('1A:2!N971V87)K:6YG87,@4D%2(&%R8VAY
M=F%S+@!!=')O9&\L(&MA9"!T86D@;F5T=F%R:VEN9V%S(%I)4"!A<F-H>79A
M<RX`071R;V1O+"!K860@=&%I(&YE=&5I<VEN9V%S(&MO<G1E;.MS(&YU;65R
M:7,N`-!I('1V87)K>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S('!E<B!#
M;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI('!A<VEN875D;VIA
M;G0@2%144"!P<F]T;VMO;'4`T&D@='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I
M(/YI;G5T97,@<&5R('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M('!A<VEN875D;VIA;G0@2%144"!P<F]T;VMO;'4`T&D@='9A<FMY:VSK(&QE
M:63^:6$@<VGX<W1I(/YI;G5T97,@4TU44"!P<F]T;VMO;'4@<&5R(%9O9&%F
M;VYE($ET86QI:F]S('9A<G1U<RP@=&EK(%9O9&%F;VYE(&YU;65R:6%M<RX@
M2FD@<F5I:V%L875J82!E;"X@<&'P=&\@861R97-O(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`-!I<R!L875K87,@<')I=F%L;VUA<RX`
MT&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S=F5I:VEE:FD@<VMA:>AI86DN
M`-!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@<VMA:>AI86D@:7(@9'9I=&'P
M:VEA:2X`T&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!A\'1U;G1A:6YI86D@
M<VMA:>AI86DN`-!I86UE(&QA=6ME('1U<FD@8OMT:2!K86)L96QI86ES(&%R
M8F$@=&%R<&%I<R!A='-K:7)T:2!S=F5I:VEE:FD@<VMA:>AI86D`T&D@<F5I
M:_!MZR!T=7)I(&+[=&D@<VMA:>AI=7,N`-!I86UE(&QA=6ME(&=A;&D@8OMT
M:2!T:6L@<W!A;'9O<R!K;V1A<R!21T(@2&5X(&9O<FUA=&4L('!A=GEZ9/YI
M=6D@)R,Q,C,T048G+@#0:2!F;W)M82!J874@87!D;W)O=&$N`%1A:2`E<RX`
M5&%I($MO;&%B($=R;W5P=V%R92!O8FIE:W1A<RX@3F]RZV1A;6D@<&5R_FG[
M<NMT:2!O8FIE:W3@('!R:79A;&]T92!T=7+K=&D@96PN('!A\'1O(&ML:65N
M=.`L(&MU<FES('-U<')A;G3@(/#A(&9O<FUA=.`N(%1O:VGX(&5L+B!P8?!T
M;R!K;&EE;G3X('/@<F'PX"!G86QI=&4@<F%S=&D@87!S:6QA;FOF("5S`-!I
M<R!L86GP:V%S(&)U=F\@<&%R8?!Y=&%S("5S(&MO9'5O=&4N($K[<R!N875D
M;VIA=&4@:VET;VMIX"!K;V1U;W3F+@#0:7,@<VMA:>AI=7,@='5R:2!B^W1I
M(&1I9&5S;FES('7^(&YU;.$N`-!I<R!S97)V97)I<R!N96=A;&D@:?!A<F-H
M>79U;W1I('II<"!I<B!G>FEP(&9A:6SX+@#0:2!S:7-T96UA(&1A8F%R(&GP
M:G5N9W1A+@#0:2!R96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RX`T.$@;&%N
M9^`@<F5I:VEA(&%T:61A<FENZW1I(&GP(&YU<W1A='EM^"!L86YG;P!097)K
M^VYI:F$`0FEL:65T86D`3&%I:V%S`$QA:6MO(&%P<VMA:71A`$QA:6MO(&9O
M<FUA=&%S`$QA:6MO('!A<VER:6YK:6UA<P!4:6UO<FQE<W3K`%!A<F5I9V]S
M`%!A=F%D:6YI;6%S.@!+86T`3F]RZV1A;6D@<&%S:7)I;FMT:2!K96QE=.`@
M96QE;65N=/@L(&QA:6MY:VET92!#;VYT<F]L("A00RD@87)B82!#;VUM;F%D
M("A-86,I(&ML879I\.`L(&ER('!A<VER:6YK:71E('!E;&4N`-!I86YD:65N
M`%)O9'ET:2!(5$U,(&MO9.``5&]G87,`5&]K96QA=0!2>71O:@!4;VYG80!6
M:7+P=6IE`%9I<O!U=&EN:6%M92!L86YG92`H7W1O<"D`5F5R=&EM86D`5')I
M;FED861A<R!I<B!4;V)A9V%S`%1A:7`@87)B82!N90!!;G1R+@!4=6YI<V%S
M`%1U<FMI:F$`5'5R:VGP:V$@*$E33RTX.#4Y+3DI`%1U<FMMZVYI:F$`5'5R
M:W-O(&ER($MA:6MO<V\@<V%L;W,`5'5V86QU`,%V97-K:71E('-A=F\@<&%S
M:7)I;FMI;>`Z(`!5+E8N(&EN9&5K<V%S.B``55),`%-K<FEP=&\@<')I<W1A
M='EM;R!S=&%T=7-O(')A<&]R=&\@55),`%523#H`56=A;F1A`%5K<F%I;F$`
M3F5P879Y:V\@<&5R<VMA:71Y=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!P
M<FEDZW1I('!A<&EL9&]M;W,@=F%R=&]T;VIO(')E9VES=')A8VEJ;W,@:6YF
M;W)M86-I:F]S+@!.97!A=GEK;R!P86ME:7-T:2!61E,@9F%I;&\@(B5S(B!T
M96ES:?@N`$YE<&%V>6MO('!A:V5I<W1I('1E:7-I^"!61E,@9F%I;'5I("5S
M+R5S+@!.97!A=GEK;R!P97)E:71I(.$@)7,N`$YE<&%V>6MO('!R:7-I:G5N
M9W1I('!R:64@4U%,('-E<G9E<FEO+@!.97!A=GEK;R!P<FES:6IU;F=T:2!3
M4TP@<F7^:6UU+@!.97!A=GEK;R!N=6MO<&EJ=6]T:2!61E,@9F%I;&\N`$YE
M<&%V>6MO('-U:W5R=&D@5D93(&MA=&%L;V=O("(E<R(N`$YE<&%V>6MO('-U
M:W5R=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!S=6MU<G1I(%9&4R!F86EL
M;RX`3F5P879Y:V\@<W5K=7)T:2!T=?#H:6\@5D93(&9A:6QO+@!.97!A=GEK
M;R!I\&%R8VAY=G5O=&D@9'5O;65N^"X`3F5P879Y:V\@:?!T<FEN=&D@(B5S
M(BP@:V%T86QO9V%S(&YE='7PZ&EA<P!.97!A=GEK;R!I\'1R:6YT:2`E<RP@
M:V%T86QO9V%S(&YE='7PZ&EA<P!.97!A=GEK;R!I\'1R:6YT:2`G)7,G.B`E
M<RX`3F5P879Y:V\@<F5K=7)S:?!K86D@:?!T<FEN=&D@5D93(&MA=&%L;V=O
M+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO(&GP
M=')I;G1I(%9&4R!K871A;&]G;SH@)7,N`$YE<&%V>6MO(&GP=')I;G1I(%9&
M4R!F86EL;R`B)7,B+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\N`$YE
M<&%V>6MO(')E:W5R<VGP:V%I(&GP=')I;G1I(%9&4SH@)7,N`$YE<&%V>6MO
M(&YU<W1A='ET:2!D86)A<G1I;FEO(&MA=&%L;V=O+@!.97!A=GEK;R!G875T
M:2!S97)T:69I:V%T;R!A<')A\'EM;P!.97!A=GEK;R!U_FMR875T:2`E<R!A
M<')A\'EM;RX`3F5P879Y:V\@<&5R:V5L=&D@5D93(&9A:6QO+@!.97!A=GEK
M;R!A=&ED87)Y=&D@5D93(&9A:6QO("(E<R(N`$YE<&%V>6MO(&%T:61A<GET
M:2!61E,@9F%I;&\@<F'P>6UU:2X`3F5P879Y:V\@871I9&%R>71I(%9&4R!F
M86EL;RX`3F5P879Y:V\@871I9&%R>71I('-U<W!A=7-T;R!A<F-H>79O+@!.
M97!A=GEK;R!P97)S:V%I='ET:2!V9G-R;V]T(&MA=&%L;V=O+@!.97!A=GEK
M;R!P97)V861I;G1I("5S(.$@)7,Z('1O:W,@:V%T86QO9V%S(&IA=2!E9WII
M<W1U;VIA`$YE<&%V>6MO('!E<G9A9&EN=&D@5D93(&MA=&%L;V=O+@!.97!A
M=GEK;R!P97)V861I;G1I(%9&4R!K871A;&]G;SH@)7,N`$YE<&%V>6MO('!E
M<G9A9&EN=&D@5D93(&9A:6QO("(E<R(N`$YE<&%V>6MO('!E<G9A9&EN=&D@
M5D93(&9A:6QO("5S+R5S+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL
M;RX`3F5P879Y:V\@<&%L96ES=&D@)VUK:7-O9G,G+@!.97!A=GEK;R!I\'9E
M<G-T:2#P:6\@5V]R9"!D;VMU;65N=&\`3F5P879Y:V\@X7)A\'ET:2!61E,@
M9F%I;&\@(B5S(BX`3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@*&-O<'DH
M*2!K;&%I9&$I+@!.97!A=GEK;R#A<F'P>71I(%9&4R!F86EL;R!D=6]M96[X
M+@!086)R875K=&D`073P875K=&D@<&%K96ET:6UU<P!!=/!A=6MT:2!A;FMS
M=&5S;N$@=F5I:W-MX`!.971I:^MT82!S97)V97)I;R!K;&%I9&$Z(`!.971I
M:^MT82!S97)V97)I;R!K;&%I9&$Z(`!.96YU<F]D>71A`$MO;7!O;F5N=&\@
M=&EP87,@;F5P86QA:6MO;6%S.B`E<P!5;FEK;V1A<R`H551&+3@I`$IU;F=T
M:6YI86D@07)A8O@@16UY<F%T86D`2G5N9W1I;NL@2V%R86QY<W3K`$IU;F=T
M:6[K<R!686QS=&EJ;W,`2G5N9W1I;FGX(%9A;'-T>6KX($%T;VME<V[K<R!S
M86QO<P!6:65N971A:0!.9?YI;F]M87,`3F7^:6YO;6%S(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`$YE_FEN;VUA<R!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+@!.9?YI;F]M87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A
M('-L87!T8?YO9&ES+@!086YA:6MI;G1I(&YU;W)O9.`@\&EA;2!E;&5M96YT
M=6D`3F7A=F%R9&EN=&%S`%-A=6=U;6\@<W5M971I;6%I<R!N97!R:79I;&5G
M:6IU;W1I('-K<FEP=&%I(&YE9V%L:2!A=&QI:W1I(%!E<FOK;&EM;R]+;W!I
M:F%V:6UO+\%KZVQI;6\@<')O9W)A;6GP:V%I+B!.;W+K9&%M:2!P97+^:?MR
MZW1I('1E8VAN:6YE<R!D971A;&5S(&UO>FEL;&$N;W)G('1I;FML87!Y:F4L
M(&ER('-U_FEN;W1I(&MA:7`@<VMR:7!T86US(&QE:7-T:2!P<FEE:71I('!R
M:64@;&%I:VEN;W-I;W,@<V%U9WEK;&]S+"!P87-P875S:VET92!/2RX`3F5N
M875D;W1I('-P86QV;W,`4&SK=&EN>7,@;F5P86QA:6MO;6%S`$%T;F%U:FEN
M=&D`071N875J:6YT:2`E<P!!=&YA=6II;G1I(&%T<V%K;W;X('-T871U<^``
M071N875J:6YT:2!V87)T;W1O:N``)R5S)R!A=&YA=6II;G1A+@!!=&YA=6II
M;FEM;R!S:W)I<'1A<R!I\'1R:6YT87,N`$YU<VGX<W1I`%9I<VD@;6]D=6QI
M^"!A=&YA=6II;FEM;R!F86EL86D@X6ME;'1I(.$@<V5R=F5RX2X`1&ED_FEO
M<VEO<R!L;W1I;FGP:V]S(')A:63K<P!$:61I96II(')O;>MN:?!K:2!S:V%I
MZ&EA:0!5<G5G=F%J=7,`3F%U9&]T:2!D86)A<G1I;N8Z("5S`$YA=61O=&D@
M4U-,`$YA=61O=&D@:F5I9W4@=F%R=&]T;VIO('9A<F1A<R]S;&%P=&'^;V1I
M<R!)35-0('-E<G9E<FEU:2!Y<F$@:VET;VMS+@!687)T;W1O:F%S("5S(&YE
M875T;W)I>G5O=&%S('!R:>MJ:6UU:2!P<FEE("5S+@!687)T;W1O:O@@861M
M:6YI<W1R879I;6%S`%9A<G1O=&]J;R!N=7-T871Y;6%I`%9A<G1O=&]J^"!R
M96=I<W1R86-I:F$`5F%R=&]T;VKX(')E9VES=')A8VEJ82!I\&IU;F=T82X`
M5F%R=&]T;VIA<R!N97)A<W1A<P!687)T;W1O:F%S(&YE<F%S=&%S+@!687)T
M;W1O:F\@=&5I<^MS`%9A<G1O=&]J;R!V87)D87,`5F%R=&]T;VIO('9A<F1A
M<R`G)7,G(&IA=2!E9WII<W1U;VIA+@!687)T;W1O:F\@=F%R9&%S.@!687)T
M;W1O:F\@=F%R9&%S.B``5F%R=&]T;VIA:0!687)T;W1O:F%I(/!I;VIE('-I
M<W1E;6]J93H`57IB96MI<W1A;F%S`%9&4R!K871A;&]G87,@;F5E9WII<W1U
M;VIA+@!!=&]S=&]G;W,`4F%S=&]S('1E:7-I;F=O<R!V:65T;W;K<SH@`$=A
M;&EO:FEM87,`4F5I:_!MZR!M:6YU=.MM:7,@;G5O(&1A8F%R+@!296EK\&WK
M<P!296EK\&WK<R!I\"!K=7)I^"!G86QI;6$@<&%S:7)I;FMT:0!686YU871U
M`$MI;G1A;G1I<P!696YE<W5E;&$`4&%T=FER=&EN:6UA<R!N96)A:6=T87,@
M+2#P:7,@;&%I\&MA<R!S=6=A9&EN=&%S+@!697)S:6IA`%9E<G-I:O@@:V]N
M=')O;.L`3'EG:75O=&D@=F5R=&EK86QI86D`5F5R=&EK86QU<R!T87)P87,`
M5F5R=&EK86QU<SH`3&%B86D@9&ED96QI<P!6:65T;F%M87,`5FEE=&YA;6EE
M=&GP:V$@*%9)4T-)22D`4&5R_FG[<NMT:2`E<P!2;V1Y=&D@:?!O<FENX2!P
M=7-L87#A`%!E<OYI^W+K=&D@:V%I<"`E<P!097+^:?MRZW1I(.%V>6OA`%!E
M<OYI^W+K=&D@9&%R8N``0G)I=/@@5FER9/YI;FEJ;W,@<V%L;W,`2D%6(%9I
M<F3^:6YI:F]S('-A;&]S`$UA=&]M=6UA<P!-871O;75M87,Z(`!6;V1A9F]N
M92!)=&%L:6IA('!E<B!33510`%=!4DX`1,M-15-)3R$A(2!005194R!)T%12
M24Y+251%(%-+4DE05,`@2=`@)7,N`%9A;&ES(&ER($9U='5N80!$ZVUE<VEO
M`%1R9>@N`$]R^"!P<F]G;F]ZZP!/<O@@<')O9VYO>NL@<&%G86P`5V5A=&AE
M<BYC;VT`5U=7`%=75R!P=7-L87!I<P!+87,@<V%V86ETY@!3=F5I:VD`4W9E
M:6MI(&%T=GEKYB#A("5S`$QA8F%S+"`E<P!686MA<O@@*$E33RTX.#4Y+3$I
M`%9A:V%R^"`H25-/+3@X-3DM,34I`%9A:V%R^"!386-H87)A`$MO:^$@;6]D
M=6SA("5S('1U<FD@<F]D>71I('!O('!R:7-I:G5N9VEM;S\`2V]K<R!S:VER
M='5K;R!S:6UB;VQI<S\`2V]K<R!K86)UZ&GX('-I;6)O;&ES/P!+=7)I;W,@
M9F%ZZW,`2%1-3"!R961A:W1O<FEA=7,@;6]D=6QI^"#A:G5N9VEM87,N`%!L
M;W1I<P!0;&]T:7,@0U-3(&UA=&%I<P`E<R!K86ER:6]J;R!M96YI=2!P;&]T
M:7,@*'!A:V5I=&EM86D@8G5S(&UA='ET:2!P;R!K:71O('!R:7-I:G5N9VEM
M;RDZ`$QE;G1E;.MS('!L;W1I<P!0;&_H:6\@;6%T87,`4&QO=&ES.@!7:6MI
M`%;K:F\@9W)E:71I<R!M87IG86ES`%;K:F%S.@!6ZVIA<SH@`$GP;6EN=&ES
M`%!A9V5I9&%V:6UA:0!$87)B87,`1&%R8F\@861R97-A<P!$87)B;R!T96QE
M9F]N87,`3F5P879Y:V\@=?YR8?!Y=&DN($K[<R!G86QI=&4@87)B82!N875D
M;W1I<R!A=&YA=6II;FEM;R!S:W)I<'1U(&%R8F$@<&%T>7,@;G5K;W!I:G5O
M=&D@:V]DX"!A<&'H:6]J92#A("5S+@!8+5)E9@!8-3`Y=C,@<&%G<FEN9&EN
M:6%I(&YU<W1A='EM86D`6#4P.78S(&GP<&SK<W1O(')A:W1O('!A;F%U9&]J
M:6UA<P!8-3`Y=C,@86QT97)N871Y=G5S('9A<F1A<P!8-3`Y=C,@<F%K=&\@
M:61E;G1I9FEK871O<FEU<P!8-3`Y=C,@;6]D=6QI86D`65D`65E960!986AO
M;R$@_F5MZVQA<&ES`$MA<VUE=`!*96UE;F%S`%1A:7``5&%I<"P@8?`@<W5T
M:6YK=0!*^W,@97-A=&4@5$5+4U1)3DE!344@4D7>24U%+B!.;W+K9&%M:2!G
M<N'^=&D@X2!765-)5UE'('-P875S:VET92!;/#Y=+@!*^W,@;F5P<FES:6IU
M;F?F+@!3879O('9A<F1E(&YE9V%L:71E(&YA=61O=&D@<VEM8F]L:6\@)UPG
M+@!*^W,@;F5G86QI=&4@<&%K96ES=&D@=F%R=&]T;VIO("5S('-L87!T8?YO
M9/YI;P#!=F5DZW1E(&YE=&5I<VEN9^`@96PN('!A\'1O(&%D<F5SX"X`3F5P
M<FEJ=6YGZW1E(&IO:VGX(&QA=6OX(&GP(.%K96QI86UO(&9A:6QO('!R:64@
M)7,@871I=&EN:V%M^"!L875K^"X`2OMS(&%T<VEJ=6YGZW1E+@!4=7)I=&4@
MX79E<W1I('1E:7-I;F?@('1E;&5F;VYO(&YU;65RX2`H=&EK('-K86GH:75S
M(&ER("<K)RP@:F5I9W4@;F]R:71E(&YU<F]D>71I('1A<G!T875T:6[A(&MO
M9.`I+@#!=F5DZW1E(&YE=&5I<VEN9^`@<F5I:_!MYBX`3F]RZV1A;6D@;F%U
M9V]T:7,@<F5G:7-T<F%C:6IO<R!S:7-T96UA+"!T=7)I=&4@<W5K;VYF:6?[
M<G5O=&D@9'5O;65N^"!M963^:6\@<&]S:7-T96WF+@!0<FEE\"!S:?AS9&%M
M:2!P<F%N9?!I;>`L(&%P<F'P>6MI=&4@<')O8FQE;>`N`,%R8?!Y:VET92!N
M=6]R;V1O<R!54DP`4')I=F%L;W1E(&YU<F]D>71I(&1A8F%R=&ENX2!S;&%P
M=&'^;V3A`,%V97-K:71E(&YA=6K@('-L87!T8?YO9.$`5'5R:71E('!A<VER
M:6YK=&D@<V5R=F5RX2P@:W5RX2!N;W)I=&4@:?!T<FEN=&DN`$YU<F]D>6MI
M=&4@=F%R=&]T;VIO('9A<F3@+"!K=7)I;R!D=6]M96YI<R!T<FEN871E+@!.
M=7)O9'EK:71E('9A<G1O=&]J;R!V87)DX"!T<GEN:6UU:2X`3G5R;V1Y:VET
M92!K=7)I86UO('9A<G1O=&]J;R!V87)DX"X`3G5R;V1Y:VET92!A=&YA=6II
M;F%M;R!V87)T;W1O:F\@=F%R9.`N`$YU<F]D>6MI=&4@=F5I:W-MX"X`2OMS
M('1U<FET92#A=F5S=&D@;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`N
M`%!A:V%R=&]K:71E(&YA=6K@('-L87!T8?YO9.$`)7,@<V5S:6IA(&)A:6?K
M<VDN(%!R8?!O;64@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@96PN('!A
M\'1O(&%D<F5S87,Z`$5L+B!P8?!T;R!A9')E<V%S.@!);F9O<FUA8VEJ82!A
M<&EE($IU<P!.=6\@)7,@<V5S:6IO<R!P<F%D_FEO<R!J^W/X($E0(&%D<F5S
M87,@<&%S:6ME:73K+B!4=7)I=&4@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[
M<_@@=F%R9&%S+W!A=F%R9.L`2OMS^"!S:7-T96UO<R!A=71E;G1I9FEK879I
M;6\@<&]S:7-T96WK(&YE<&%L86EK;R!V87)T;W1O:O@@:_MR:6UO+"!A<F)A
M(/!I(&=A;&EM>6+K(&GP:G5N9W1A(&3K;"!T86T@=&EK<O@@<')I9?YA<^AI
M^"X`2OMS^"!A=71E;G1I9FEK879I;6\@<VES=&5M82!N97!A;&%I:V\@=F%R
M=&]T;VKX('/@<F'P;RP@87)B82#P:2!F=6YK8VEJ82!U_F1R875S=&$@9.ML
M('1A;2!T:6MR^"!P<FEE_F%SZ&GX+@!.=6\@)7,@<V5S:6IO<R!P<F%D_FEO
M<R!J^W/X(&YA<O!Y:VSK<R!T:7!A<R!P87-I:V5I=.LN(%1U<FET92!P<FES
M:6IU;F=T:2!I\"!N875J;RX`2OMS^"!N87+P>6MLZR!N97!A;&%I:V\@\&EO
M<R!G86QI;7EBZW,N`$K[<_@@;F%R\'EK;.L@;F5P86QA:6MO(/!I;R!S<&%U
M<V1I;FEM;R!N=7-T871Y;6\N($YO<NMD86UI(&%T<W!A=7-D:6YT:2!S<&%U
M<VMI=&4@0V]N=')O;"]/<'1I;VX@*R!0+@!*^W/X(&QA:6MO(&IU;W-T83H`
M2OMS^"!S=&%N9&%R=&EN:7,@87!R8?!A<SH`2OMS^"!V87)D87,O<&%V87)D
MZSH`2OMS^"!N875J87,@)7,@<VQA<'1A_F]D:7,@>7)A.B`E<P!*^W/X(&YA
M=6IA<VES('-L87!T8?YO9&ES('!E<B!I;&=A<SL@:F%M92!G86QI(&+[=&D@
M;F5D875G:6%U(&YE:2`E9"!S:6UB;VQI86D`4VQA<'1A_F]D:7,@<&5R('!A
M<')A<W1A<R`M(.%V97-K:71E('-U9.MT:6YG97-NX2$`4VQA<'1A_F]D:7,@
M<&5R('!A<')A<W1A<R`M(.%V97-K:71E('-U9.MT:6YG97-NX2X`4VQA<'1A
M_F]D:7,@='5R:2!B^W1I(&)E;G0@)60@<VEM8F]L:?@@:6QG:6\A`$YA=6IA
M<VES('-L87!T8?YO9&ES('1U<FD@<VMI<G1I<R!N=6\@9&%B87)T:6YI;P!3
M;&%P=&'^;V1Y:F4@<')I=F%L;R!B^W1I(&)E;G0@)60@<F%I9.MS+@!3;&%P
M=&'^;V1Y:F4@<')I=F%L;R!B^W1I(&)E;G0@)60@<VEM8F]L:6%I+@!*^W/X
M(&YA=6K@:N$@<VQA<'1A_F]DX2!T=7)I('-U9&%R>71I(&)E;G0@)60@<VMI
M<G1I;F=I('-I;6)O;&GX('1I<&%I+B!4:7!A:3H@9&ED_FEO<VEO<R!R86ED
MZW,L(&UA_F]S:6]S(')A:63K<RP@<VMA:>AI86D@:7(@:VET:2!S:6UB;VQI
M86DN`%-L87!T8?YO9'EJ92!P<FEV86QO(&+[=&D@8F5N="`E9"!M8?YO<VEO
M<R!R86EDZW,N`%-L87!T8?YO9'ET92!P<FEV86QO(&+[=&D@8F5N="`E9"!S
M:V%IZ&EA:2X`4VQA<'1A_F]D>6IE('!R:79A;&\@8OMT:2!B96YT("5D(&1I
M9/YI;W-I;W,@<F%I9.MS+@!.875J86IA;64@<VQA<'1A_F]D>6IE(&=A;&D@
M8OMT:2!N961A=6=I874@;F5I("5D('1A<G#X+@!.875J86IA;64@<VQA<'1A
M_F]D>6IE(&YE9V%L:2!B^W1I('1A<G#X+@!.875J:2!S;&%P=&'^;V3^:6%I
M(&YE<W5T86UP80!*^W/X(&YU<W1A='EM86D@871N875J:6YT:2X`2OMS^"!S
M;&%P=&'^;V1I<R!P86ME:7-T87,`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T
M87,N(%!A<VET:6MR:6YK:71E('-A=F\@<&'P=.`@:7(@<')I<VEJ=6YK:71E
M('-U(&YA=6IU('-L87!T8?YO9/YI=2X`2OMS^"!N=71O;.8@<V5R=F5R:6%I
M.@!*=6=O<VQA=FEJ80!:86ER87,`6F%M8FEJ80!::6UB86)VZP!%;F5R9VEN
M9V]S`%M087-LZW!T:2!C:71U;VIA;>`@=&5K<W3@70!;4')O8FQE;6]S('!R
M86YE\&EM87-=`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M`%M2;V1Y=&D@
M8VET=6]J86W@('1E:W-TX"`M("5S(&5I;'5T97-=`%ME:6QU=.L@)7,@:?`@
M)7-=`%]686QD>6UA<P!?0TQ)`%]$=6]M96[X(&UE9&ES`%])\'1R:6YT:2!E
M:6QU=.8`1U]R=7#K<P!085]G86QB80!?4&%V96EK<VSK;&EO(&YU<W1A='EM
M86DN+BX`4')I<VE?:G5N9W1I`$%T<VE?:G5N9W1I`%]+96ES=&D@;G5O<F]D
MX"XN`%].=7-T871Y;6%I`%]496ESZW,`7TGP=')I;G1I(&YU;W)O9.`N+BX`
M7TMO;F9I9_MR86-I:F$`7TQE;G1E;.MS(&YU<W1A='EM86DN+BX`5E]A<G1O
M=&]J86D`861R97/X(&MN>6=E;.L`2V%L96YD;W)I=7,`<F%M=7,`<W!A=7-K
M:71E(.AI80!K<F5N=&$`9F%I;&%S`&YU;R`E<R`H)7,I("5S("5S`&$Z`$MA
M;&)O<P!T=6]J874@<&%T`'!A<')A<W1I`&QD87!?<W1A<G1?=&QS(&ML86ED
M80!E:6QU=&5S70!M:VES;V9S(&ML86ED;W,@:V]D87,@)60@8F5D87)A;G0@
M25-/+@!V87)D87,`;F5R96%L:7IU;W1A`&1A<B!N97)E86QI>G5O=&$`=?YR
M8?#X(&MN>6=E;.L`<')O8V5N=&%I`'!I:W-E;&EA:0!K>6QA`')O9'ET:2!S
M:VER='5M=7,`<VUS,F5M86EL('!E<B!(5%10`'-T86)I;&D`9&%R8O@@<^!R
M8?!A<P!S;&%P=&'^;V3A('1U<FET92#A<F'P>71I(&1U(&MA<G1U<P!U;FEF
M:6MU;W1I`&1A;&ES`'9A<G1O=&]J;R!P87-I<FEN:VEM87,`=D-A<F0`<#H`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P87-S=V0O;&]C86QE+VYL7TY,+P``````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,#$V-@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O;FQ?3DPO3$-?
M34534T%'15,O````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-#0`,#(Q-S4S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D
M+VQO8V%L92]N;%].3"],0U]-15-304=%4R]P87-S=V0N;6\`````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#0S-3$R-``Q,#0Q-S,V,C<T-``P,C,V,3<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````"T!P``'```
M`+P]``!)"@``7'L```````"`I```30```(&D``"_````SZ0``&0```"/I0``
MO@```/2E``"0````LZ8``$,```!$IP``/````(BG```K````Q:<``"X```#Q
MIP``*0```""H```H````2J@``$4```!SJ```1P```+FH``!*`````:D``$<`
M``!,J0``10```)2I``!(````VJD``#D````CJ@``1@```%VJ``!(````I*H`
M`#````#MJ@``10```!ZK``!&````9*L``$P```"KJP``-````/BK```R````
M+:P``&D```!@K```,````,JL```E````^ZP``(@````AK0``0````*JM``#V
M````ZZT``$H```#BK@``+````"VO``"%````6J\``$@```#@KP``#@```"FP
M```/````.+````T```!(L```"````%:P```+````7[````P```!KL```!```
M`'BP```,````?;```!$```"*L```)0```)RP```/````PK````L```#2L```
M$0```-ZP```.````\+````4```#_L```*`````6Q```(````+K$```H````W
ML0``%0```$*Q```2````6+$```L```!KL0``%````'>Q```F````C+$``"<`
M``"SL0``)@```-NQ```3`````K(```X````6L@``"@```"6R```-````,+(`
M`"X````^L@``)P```&VR```@````E;(```X```"VL@``%P```,6R```B````
MW;(``#4`````LP``$0```#:S```-````2+,```P```!6LP``#0```&.S```&
M````<;,``!L```!XLP``+0```)2S```=````PK,``"0```#@LP``*0````6T
M```9````+[0```\```!)M```&````%FT```,````<K0``!L```!_M```#@``
M`)NT```.````JK0```@```"YM```0@```,*T```N````!;4``!H````TM0``
M,@```$^U```X````@K4``%0```"[M0``40```!"V``!:````8K8``%<```"]
MM@``-````!6W```'````2K<```H```!2MP``#P```%VW```%````;;<```8`
M``!SMP``$0```'JW```(````C+<```D```"5MP``"0```)^W```.````J;<`
M``@```"XMP``)0```,&W```@````Y[<``!`````(N```#P```!FX```*````
M*;@```<````TN````P```#RX```/````0+@``!0```!0N```"0```&6X```-
M````;[@``!(```!]N```&0```)"X```>````JK@```\```#)N```"@```-FX
M```/````Y+@```@```#TN```)````/VX```7````(KD``!0````ZN0``%@``
M`$^Y```(````9KD``$X```!ON0``+0```+ZY```?````[+D``!D````,N@``
M!P```":Z```,````+KH``"P````[N@``#@```&BZ```#````=[H```L```![
MN@``!P```(>Z```'````C[H```4```"7N@``!0```)VZ```*````H[H```,`
M``"NN@``%P```+*Z```*````RKH```\```#5N@``#@```.6Z```8````]+H`
M`",````-NP``#@```#&[```4````0+L``!<```!5NP``%P```&V[```7````
MA;L``!,```"=NP``#P```+&[```.````P;L``!\```#0NP``!P```/"[```&
M````^+L```@```#_NP``#P````B\```&````&+P```H````?O```$P```"J\
M```+````/KP``!````!*O```%0```%N\```5````<;P```<```"'O```$```
M`(^\```%````H+P``!4```"FO```$0```+R\```,````SKP``#L```#;O```
M.````!>]```)````4+T```<```!:O0``%````&*]```#````=[T```4```![
MO0``$````(&]```)````DKT``!,```"<O0``.0```+"]```2````ZKT``#D`
M``#]O0``)P```#>^```L````7[X``"H```",O@``)0```+>^```)````W;X`
M``H```#GO@``!@```/*^```)````^;X```<````#OP``+P````N_```W````
M.[\``"X```!SOP``50```**_```M````^+\``"T````FP```+0```%3```!`
M````@L```",```##P```(P```.?````M````"\$``#,````YP0``%0```&W!
M```9````@\$``"D```"=P0``)````,?!```1````[,$``!$```#^P0``"@``
M`!#"```,````&\(```H````HP@``$````#/"```6````1,(``!8```!;P@``
M!P```'+"```'````>L(``!0```""P@``"@```)?"```(````HL(```0```"K
MP@``)P```+#"```(````V,(```<```#AP@``!P```.G"```&````\<(```4`
M``#XP@``!P```/["```&````!L,```@````-PP``*0```!;#```.````0,,`
M``H```!/PP``!````%K#```'````7\,```D```!GPP``!@```''#```1````
M>,,```<```"*PP``%@```)+#```$````J<,```@```"NPP``!@```+?#```-
M````OL,```8```#,PP``'@```-/#```1````\L,``"(````$Q```%@```"?$
M```(````/L0```T```!'Q```#````%7$```'````8L0```,```!JQ````P``
M`&[$```7````<L0``!,```"*Q```"````)[$```$````I\0```@```"LQ```
M"````+7$``!!````OL0``"``````Q0``!@```"'%```&````*,4``!4````O
MQ0``&````$7%```B````7L4``"X```"!Q0``'0```+#%```A````SL4``%0`
M``#PQ0``*0```$7&```*````;\8```<```!ZQ@``%0```(+&```.````F,8`
M``H```"GQ@``#P```++&```-````PL8```\```#0Q@``#0```.#&```)````
M[L8``!0```#XQ@``!@````W'```8````%,<``!T````MQP``$P```$O'```4
M````7\<```0```!TQP``#````'G'```&````AL<``%0```"-QP``%````.+'
M```$````]\<```X```#\QP``1`````O(```%````4,@```4```!6R```&P``
M`%S(```:````>,@``!$```"3R```$0```*7(```1````M\@``!P```#)R```
M*@```.;(```0````$<D``"$````BR0``)0```$3)```9````:LD```4```"$
MR0``$P```(K)```2````GLD```H```"QR0``#P```+S)```1````S,D``!,`
M``#>R0``#````/+)```&````_\D```8````&R@``%P````W*```0````)<H`
M`!$````VR@``"````$C*```%````4<H```P```!7R@``$````&3*```%````
M=<H```T```![R@``!@```(G*```'````D,H```T```"8R@``$````*;*```)
M````M\H```<```#!R@``"P```,G*```+````U<H```<```#AR@``!P```.G*
M```)````\<H``!0```#[R@``"0```!#+```*````&LL``!D````ERP``'0``
M`#_+```,````7<L``!````!JRP``%0```'O+```%````D<L``"4```"7RP``
M$@```+W+```3````T,L``"L```#DRP``.P```!#,```@````3,P``#8```!M
MS```$````*3,```(````M<P```P```"^S```!@```,O,```$````TLP```X`
M``#7S```$````.;,```*````]\P```T````"S0``'@```!#-```;````+\T`
M`"$```!+S0``'@```&W-```9````C,T``!X```"FS0``&P```,7-```N````
MX<T``!<````0S@``)@```"C.```P````3\X``!L```"`S@``'@```)S.```<
M````N\X``"8```#8S@``*P```/_.```S````*\\``"8```!?SP``*P```(;/
M```X````LL\``!T```#KSP``%0````G0```O````']```!(```!/T```(```
M`&+0```I````@]```!X```"MT```$@```,S0``"B````W]```!8```""T0``
M(P```)G1```H````O=$``"D```#FT0``*````!#2```?````.=(``!4```!9
MT@``(````&_2```E````D-(``"@```"VT@``+0```-_2```P````#=,``)(`
M```^TP``(0```-'3```6````\],``!P````*U```)@```"?4```J````3M0`
M`$$```!YU```1````+O4```,`````-4```<````-U0``!P```!75```&````
M'=4```T````DU0``$````#+5```2````0]4``!,```!6U0``$@```&K5```'
M````?=4```0```"%U0``#0```(K5```,````F-4```X```"EU0``#P```+35
M```3````Q-4```T```#8U0``*````.;5```#````#]8```T````3U@``!@``
M`"'6```1````*-8``!<````ZU@``&P```%+6```.````;M8```(```!]U@``
M!0```(#6```$````AM8``!````"+U@``!````)S6```-````H=8```X```"O
MU@```P```+[6```.````PM8```@```#1U@``#P```-K6```(````ZM8```\`
M``#SU@``!P````/7```-````"]<``!`````9UP``$P```"K7```3````/M<`
M``L```!2UP``$0```%[7```)````<-<```8```!ZUP``#````('7```1````
MCM<``!D```"@UP``"P```+K7```-````QM<``"(```#4UP``&P```/?7```T
M````$]@```H```!(V```&````%/8```9````;-@``!8```"&V```+P```)W8
M```B````S=@```T```#PV```!P```/[8```,````!MD``"8````3V0``%```
M`#K9```+````3]D``"(```!;V0``+P```'[9```+````KMD```D```"ZV0``
M&0```,39```+````WMD``!<```#JV0``%P````+:```)````&MH``!8````D
MV@``#P```#O:```6````2]H```X```!BV@``&````'':```(````BMH```T`
M``"3V@``)@```*':``!#````R-H```@````,VP``$@```!7;```(````*-L`
M``L````QVP``+P```#W;```.````;=L```4```!\VP``!@```(+;```#````
MB=L```<```"-VP``!````)7;```*````FML```H```"EVP``#P```+#;```0
M````P-L``!<```#1VP``$0```.G;```7````^]L``!D````3W```"0```"W<
M```%````-]P```L````]W```"@```$G<```"````5-P```4```!7W```#0``
M`%W<```;````:]P``!<```"'W```"0```)_<```.````J=P```T```"XW```
M$@```,;<```X````V=P``"`````2W0```P```#/=```(````-]T```X```!`
MW0``>P```$_=```8````R]T``$````#DW0``$0```"7>```'````-]X```4`
M```_W@``&````$7>```9````7MX``!,```!XW@``!P```(S>```'````E-X`
M``@```"<W@``!@```*7>```&````K-X``!````"SW@``#P```,3>```0````
MU-X```\```#EW@``"P```/7>```/`````=\```P````1WP``#P```![?```'
M````+M\```H````VWP``!@```$'?```.````2-\```P```!7WP``*````&3?
M```/````C=\```@```"=WP``%@```*;?```(````O=\``!,```#&WP``'@``
M`-K?```A````^=\``"`````;X```&0```#S@```7````5N```"4```!NX```
M%P```)3@```?````K.````0```#,X```&P```-'@```-````[>````P```#[
MX````P````CA```(````#.$```H````5X0``#````"#A```+````+>$``!``
M```YX0``#````$KA```$````5^$``!,```!<X0``%````'#A```,````A>$`
M``D```"2X0``#@```)SA```+````J^$``!L```"WX0``!P```-/A```'````
MV^$```H```#CX0``#0```.[A```)````_.$```0````&X@``!0````OB```#
M````$>(``!@````5X@``"@```"[B```$````.>(``"8````^X@``#@```&7B
M``!\````=.(``!4```#QX@``!0````?C```'````#>,```P````5XP``"```
M`"+C```*````*^,```8````VXP``"````#WC```6````1N,``!(```!=XP``
M`@```'#C```&````<^,```8```!ZXP``%````('C```5````EN,```\```"L
MXP``$0```+SC```:````SN,```T```#IXP``$````/?C```;````".0```0`
M```DY```"0```"GD```0````,^0```D```!$Y```"0```$[D```%````6.0`
M``4```!>Y```&@```&3D```(````?^0```8```"(Y```&0```(_D```.````
MJ>0``"(```"XY```!P```-OD```'````X^0```X```#KY```!0```/KD```)
M`````.4```H````*Y0```@```!7E```&````&.4```T````?Y0``"0```"WE
M```&````-^4``!(````^Y0``"0```%'E```'````6^4``!0```!CY0``'0``
M`'CE```1````EN4```8```"HY0``"@```*_E```$````NN4```D```"_Y0``
M"````,GE```1````TN4``!$```#DY0``"0```/;E```&`````.8```T````'
MY@``!@```!7F```"````'.8```0````?Y@``.0```"3F```]````7N8``#H`
M``"<Y@``'@```-?F```%````]N8```X```#\Y@``!`````OG```&````$.<`
M`"$````7YP``%0```#GG```&````3^<```0```!6YP``$0```%OG```&````
M;><``*````!TYP``"@```!7H```B````(.@```0```!#Z```)0```$CH```%
M````;N@``!T```!TZ```!````)+H```,````E^@```H```"DZ```"````*_H
M```)````N.@```4```#"Z```&P```,CH```Z````Y.@``#`````?Z0``-0``
M`%#I```I````AND``"X```"PZ0``1P```-_I```X````)^H``"D```!@Z@``
M/P```(KJ```N````RNH``"T```#YZ@``'P```"?K```/````1^L``!(```!7
MZP``"P```&KK```F````=NL``"D```"=ZP``)````,?K```F````[.L```@`
M```3[```"@```!SL```)````)^P```<````Q[```(````#GL```@````6NP`
M`"8```![[```"@```*+L```9````K>P``"D```#'[```%@```/'L```2````
M".T```<````;[0``"@```"/M```,````+NT```\````[[0``$````$OM``!`
M````7.T``'````"=[0``9@````[N```.````=>X```D```"$[@``"@```([N
M```2````F>X``!,```"L[@``#````,#N```&````S>X```\```#4[@``$@``
M`.3N```0````]^X```H````([P``$0```!/O```<````)>\``",```!"[P``
M:@```&;O```/````T>\```4```#A[P``$````.?O```)````^.\```0````"
M\```"P````?P```:````$_```!0````N\```#````$/P```,````4/````\`
M``!=\```%0```&WP```I````@_```"H```"M\```)@```-CP```G````__``
M`"D````G\0``*@```%'Q```9````?/$``$(```"6\0``$0```-GQ```2````
MZ_$``!,```#^\0``%````!+R```/````)_(``!8````W\@``%P```$[R```0
M````9O(``!$```!W\@``-````(GR```3````OO(``!(```#2\@``-0```.7R
M```4````&_,```<````P\P``#````#CS```K````1?,``"````!Q\P``%```
M`)+S```1````I_,``!<```"Y\P``'````-'S```3````[O,``!$````"]```
M&@```!3T```>````+_0``!H```!.]```$0```&GT```7````>_0``!0```"3
M]```%P```*CT```5````P/0```D```#6]```&0```.#T```$````^O0```<`
M``#_]```"P````?U```1````$_4```8````E]0``!@```"SU```&````,_4`
M``4````Z]0``!P```$#U```'````2/4```4```!0]0``%@```%;U```&````
M;?4```8```!T]0``!````'OU```$````@/4```<```"%]0``#@```(WU```,
M````G/4```P```"I]0``#0```+;U```*````Q/4```X```#/]0``!0```-[U
M```H````Y/4```X````-]@``#````!SV```/````*?8```H````Y]@``"```
M`$3V```)````3?8``"L```!7]@``!````(/V```(````B/8``"8```"1]@``
M$@```+CV```/````R_8```8```#;]@``"@```.+V```'````[?8```@```#U
M]@``(````/[V```)````'_<```P````I]P``#0```#;W```.````1/<``!8`
M``!3]P``$0```&KW```&````?/<```,```"#]P``!@```(?W```9````CO<`
M``<```"H]P``!````+#W```+````M?<```L```#!]P``!P```,WW```'````
MU?<``!8```#=]P``#0```/3W```-`````O@```H````0^```$````!OX```/
M````+/@``!$````\^```%P```$[X```*````9O@``!$```!Q^```"````(/X
M```$````C/@```\```"1^```.@```*'X```%````W/@```P```#B^```'@``
M`._X```.````#OD``!`````=^0``"P```"[Y```,````.OD```D```!'^0``
M!P```%'Y```*````6?D```D```!D^0``#@```&[Y```0````??D``!H```".
M^0``"@```*GY```)````M/D``!0```"^^0``"@```-/Y```,````WOD```\`
M``#K^0``"````/OY```&````!/H```<````+^@``"P```!/Z``!'````'_H`
M``T```!G^@``!@```'7Z```)````?/H```0```"&^@```P```(OZ```3````
MC_H``!,```"C^@``$P```+?Z```*````R_H```(```#6^@``!````-GZ```E
M````WOH```,````$^P``!0````C[```J````#OL```H````Y^P``!0```$3[
M```$````2OL```H```!/^P``#0```%K[``!`````:/L``!,```"I^P``!@``
M`+W[```(````Q/L```@```#-^P``!````-;[```%````V_L``&@```#A^P``
M"0```$K\```,````5/P```4```!A_```!@```&?\```;````;OP``"\```"*
M_```$````+K\```*````R_P```\```#6_```"@```.;\```)````\?P``!,`
M``#[_```&P````_]```8````*_T``!<```!$_0``#@```%S]```#````:_T`
M``<```!O_0``"````'?]```4````@/T``!,```"5_0``$````*G]```-````
MNOT```X```#(_0``%@```-?]```'````[OT```H```#V_0``"P````'^```M
M````#?X``!4````[_@``,````%'^```D````@OX```<```"G_@``40```*_^
M```0`````?\```P````2_P``#0```!__```:````+?\``$H```!(_P``!@``
M`)/_```:````FO\```8```"U_P``!@```+S_```?````P_\```8```#C_P``
M"0```.K_```8````]/\``!<````-``$`!@```"4``0`-````+``!`"(````Z
M``$`5P```%T``0`3````M0`!`",```#)``$`$P```.T``0`"`````0$!``L`
M```$`0$`"````!`!`0`-````&0$!``H````G`0$`!@```#(!`0`'````.0$!
M`!0```!!`0$`!@```%8!`0`(````70$!``X```!F`0$`!P```'4!`0`*````
M?0$!``L```"(`0$`!P```)0!`0`,````G`$!``T```"I`0$`#````+<!`0`)
M````Q`$!``D```#.`0$`"@```-@!`0`'````XP$!``D```#K`0$`!P```/4!
M`0`*````_0$!`!L````(`@$`$@```"0"`0`*````-P(!``D```!"`@$`$```
M`$P"`0`'````70(!`!(```!E`@$`!````'@"`0`'````?0(!``4```"%`@$`
M#````(L"`0`%````F`(!``L```">`@$`%````*H"`0`1````OP(!`!H```#1
M`@$`%@```.P"`0`4`````P,!`!<````8`P$`&````#`#`0`<````20,!`!D`
M``!F`P$`!P```(`#`0`%````B`,!``T```".`P$`#````)P#`0`(````J0,!
M`!<```"R`P$`"P```,H#`0`-````U@,!`!,```#D`P$`!````/@#`0`*````
M_0,!``0````(!`$`"0````T$`0`*````%P0!``P````B!`$`"0```"\$`0`%
M````.00!``<````_!`$`!0```$<$`0`$````300!``(```!2!`$`.````%4$
M`0`L````C@0!`!(```"[!`$`*0```,X$`0`R````^`0!``H````K!0$`-@``
M`#8%`0`L````;04!`!4```":!0$`+@```+`%`0`S````WP4!`#,````3!@$`
M.````$<&`0`/````@`8!`!@```"0!@$`.P```*D&`0`0````Y08!``\```#V
M!@$`%`````8'`0`3````&P<!`!0````O!P$`$@```$0'`0`4````5P<!`!4`
M``!L!P$`+0```(('`0`M````L`<!`#$```#>!P$`+0```!`(`0`N````/@@!
M`"\```!M"`$`+````)T(`0!B````R@@!`!,````M"0$`"````$$)`0`(````
M2@D!`"L```!3"0$`(0```'\)`0`:````H0D!``D```"\"0$`10```,8)`0!!
M````#`H!``\```!."@$`!````%X*`0`3````8PH!`!0```!W"@$`#@```(P*
M`0`3````FPH!`!@```"O"@$`!@```,@*`0`)````SPH!``H```#9"@$`#P``
M`.0*`0`0````]`H!``<````%"P$`#@````T+`0`%````'`L!`!L````B"P$`
M!@```#X+`0`(````10L!``8```!."P$`%````%4+`0`1````:@L!``X```!\
M"P$`.````(L+`0`"````Q`L!``8```#'"P$`#@```,X+`0`:````W0L!``4`
M``#X"P$`!P```/X+`0`.````!@P!``8````5#`$`#0```!P,`0`$````*@P!
M`"D````O#`$`%P```%D,`0`?````<0P!`%P```"1#`$`%````.X,`0`^````
M`PT!`!\```!"#0$`$````&(-`0`4````<PT!``<```"(#0$`#@```)`-`0`(
M````GPT!``P```"H#0$`#````+4-`0`3````P@T!``H```#6#0$`'0```.$-
M`0`9````_PT!``4````9#@$`$0```!\.`0`1````,0X!`"0```!##@$`%0``
M`&@.`0`2````?@X!``X```"1#@$`&0```*`.`0`(````N@X!``D```###@$`
M#0```,T.`0`*````VPX!``<```#F#@$`#P```.X.`0`+````_@X!``H````*
M#P$`!P```!4/`0`(````'0\!``4````F#P$`'P```"P/`0`&````3`\!`!``
M``!3#P$`"````&0/`0`-````;0\!``@```![#P$`$0```(0/`0`2````E@\!
M`"H```"I#P$`+````-0/`0`:`````1`!``D````<$`$`"@```"80`0`5````
M,1`!``4```!'$`$`%````$T0`0`$````8A`!`!````!G$`$`!@```'@0`0`'
M````?Q`!`!X```"'$`$`*````*80`0`*````SQ`!`!P```#:$`$`&@```/<0
M`0`/````$A$!`!0````B$0$`!````#<1`0`$````/!$!``L```!!$0$`!0``
M`$T1`0`&````4Q$!``@```!:$0$`!@```&,1`0`*````:A$!`!L```!U$0$`
M-````)$1`0`T````QA$!`"````#[$0$`*0```!P2`0`@````1A(!`$$```!G
M$@$`&@```*D2`0`H````Q!(!`"D```#M$@$`40```!<3`0`O````:1,!`%<`
M``"9$P$`+````/$3`0`B````'A0!``8```!!%`$`"````$@4`0`%````410!
M``@```!7%`$`&0```&`4`0`9````>A0!`"H```"4%`$`(P```+\4`0`N````
MXQ0!`#0````2%0$`#0```$<5`0`(````514!`!<```!>%0$`"@```'85`0`'
M````@14!`"$```")%0$`#0```*L5`0`0````N14!``X```#*%0$`"P```-D5
M`0`'````Y14!`!,```#M%0$`"`````$6`0`(````"A8!``L````3%@$`"@``
M`!\6`0`4````*A8!`#(````_%@$`"P```'(6`0`%````?A8!``4```"$%@$`
M%P```(H6`0`/````HA8!``0```"R%@$`"@```+<6`0`)````PA8!``L```#,
M%@$`#0```-@6`0`,````YA8!``X```#S%@$`!0````(7`0`$````"!<!``T`
M```-%P$`,@```!L7`0!%````3A<!`!<```"4%P$`'@```*P7`0`4````RQ<!
M``4```#@%P$`%````.87`0`'````^Q<!`",````#&`$`#@```"<8`0`J````
M-A@!``8```!A&`$`#````&@8`0`-````=1@!`!$```"#&`$`%P```)48`0`+
M````K1@!`#8```"Y&`$`"@```/`8`0`B````^Q@!``L````>&0$`#P```"H9
M`0`+````.AD!`"````!&&0$`)P```&<9`0`K````CQD!``D```"[&0$`,@``
M`,49`0`P````^!D!`#$````I&@$`+0```%L:`0`.````B1H!`!0```"8&@$`
M!0```*T:`0`.````LQH!`!,```#"&@$`!P```-8:`0`:````WAH!``@```#Y
M&@$`$0````(;`0`'````%!L!`!0````<&P$`&````#$;`0`'````2AL!``4`
M``!2&P$`#````%@;`0`,````91L!`!(```!R&P$`!````(4;`0`'````BAL!
M``H```"2&P$`"P```)T;`0`,````J1L!``X```"V&P$`#@```,4;`0`%````
MU!L!``4```#:&P$`+@```.`;`0`F````#QP!`",````V'`$``P```%H<`0`2
M````7AP!``8```!Q'`$`'@```'@<`0`8````EQP!`"4```"P'`$`#0```-8<
M`0`)````Y!P!``(```#N'`$``P```/$<`0`'````]1P!``H```#]'`$``@``
M``@=`0`,````"QT!`!4````8'0$`"P```"X=`0`9````.AT!`"````!4'0$`
M$@```'4=`0`%````B!T!``H```".'0$`%0```)D=`0`2````KQT!``P```#"
M'0$`!````,\=`0`'````U!T!``D```#<'0$`#````.8=`0!2````\QT!`!<`
M``!&'@$`)````%X>`0`'````@QX!``8```"+'@$`#@```)(>`0`B````H1X!
M`!T```#$'@$`#````.(>`0`-````[QX!`!4```#]'@$`$@```!,?`0`/````
M)A\!`!0````V'P$`&P```$L?`0`0````9Q\!`&D```!X'P$`&@```.(?`0`7
M````_1\!`"<````5(`$`&@```#T@`0`7````6"`!`!L```!P(`$`&0```(P@
M`0`?````IB`!`!<```#&(`$`$P```-X@`0`(````\B`!``<```#[(`$`"```
M``,A`0`)````#"$!`!4````6(0$`#0```"PA`0`3````.B$!``,```!.(0$`
M1@```%(A`0!`````F2$!`#\```#:(0$`-P```!HB`0!7````4B(!``4```"J
M(@$`'P```+`B`0`O````T"(!``H`````(P$`"`````LC`0`-````%",!`"T`
M```B(P$`!````%`C`0!/````52,!`"4```"E(P$`'````,LC`0`+````Z",!
M`!\```#T(P$`'0```!0D`0`E````,B0!`"````!8)`$`)````'DD`0`@````
MGB0!``L```"_)`$`!P```,LD`0`-````TR0!``P```#A)`$`%P```.XD`0`&
M````!B4!`#D````-)0$`#````$<E`0`'````5"4!`!D```!<)0$`"0```'8E
M`0`3````@"4!``D```"4)0$`!````)XE`0`0````HR4!``H```"T)0$`"```
M`+\E`0`(````R"4!``0```#1)0$`"P```-8E`0`,````XB4!`!(```#O)0$`
M$0````(F`0`,````%"8!`!H````A)@$`#P```#PF`0`'````3"8!`#H```!4
M)@$`#0```(\F`0`4````G28!``X```"R)@$`#````,$F`0`;````SB8!`"P`
M``#J)@$`$P```!<G`0`<````*R<!`"@```!()P$`!@```'$G`0`'````>"<!
M`!,```"`)P$`!0```)0G`0`$````FB<!`!<```"?)P$`"@```+<G`0`,````
MPB<!``D```#/)P$`!@```-DG`0`)````X"<!``@```#J)P$`"0```/,G`0`%
M````_2<!``H````#*`$`$0````XH`0`&````("@!`!@````G*`$`#@```$`H
M`0`.````3R@!``T```!>*`$`"P```&PH`0`=````>"@!``L```"6*`$``@``
M`*(H`0`<````I2@!``<```#"*`$`%P```,HH`0`&````XB@!`&4```#I*`$`
M"0```$\I`0`'````62D!`"8```!A*0$`.````(@I`0`:````P2D!`"H```#<
M*0$`.P````<J`0`H````0RH!`#0```!L*@$`&0```*$J`0`5````NRH!``4`
M``#1*@$`!P```-<J`0`(````WRH!``<```#H*@$`!0```/`J`0`'````]BH!
M``X```#^*@$`"0````TK`0`&````%RL!``@````>*P$`"P```"<K`0`'````
M,RL!``@````[*P$`!P```$0K`0`6````3"L!``D```!C*P$`!@```&TK`0`+
M````="L!`!P```"`*P$`%````)TK`0`'````LBL!``@```"Z*P$`"````,,K
M`0`%````S"L!`!````#2*P$`$````.,K`0`&````]"L!`!D```#[*P$`"@``
M`!4L`0`<````("P!``<````]+`$`!0```$4L`0`0````2RP!`!0```!<+`$`
M"P```'$L`0`-````?2P!`!@```"++`$`%P```*0L`0`:````O"P!`!0```#7
M+`$`!````.PL`0`)````\2P!``H```#[+`$`!P````8M`0`"````#BT!``X`
M```1+0$`"````"`M`0`?````*2T!`#X```!)+0$`(P```(@M`0`X````K"T!
M`#$```#E+0$`)P```!<N`0!D````/RX!`!0```"D+@$`'````+DN`0!5````
MUBX!`#@````L+P$`2@```&4O`0!;````L"\!`"@````,,`$`.````#4P`0`J
M````;C`!`"@```"9,`$`+````,(P`0`G````[S`!`!L````7,0$`/@```#,Q
M`0"I`0``<C$!`"@````<,P$`(P```$4S`0`7````:3,!`$@```"!,P$`A0``
M`,HS`0`P````4#0!`$$```"!-`$`6P```,,T`0!)````'S4!`!T```!I-0$`
M&````(<U`0`A````H#4!`!\```#"-0$`*P```.(U`0`A````#C8!`"D````P
M-@$`)P```%HV`0`=````@C8!`!$```"@-@$`,P```+(V`0`E````YC8!`#@`
M```,-P$`)P```$4W`0`@````;3<!`!\```".-P$`,````*XW`0!I````WS<!
M`"L```!).`$`,@```'4X`0`Q````J#@!`$$```#:.`$`,P```!PY`0`E````
M4#D!`#T```!V.0$`90```+0Y`0!-````&CH!`"\```!H.@$`+@```)@Z`0`K
M````QSH!`#````#S.@$`*@```"0[`0`^````3SL!`%0```"..P$`@P```.,[
M`0!:````9SP!`$@```#"/`$`2@````L]`0`R````5CT!`!T```")/0$`(P``
M`*<]`0`O````RST!`"P```#[/0$`+0```"@^`0!Q````5CX!`&\```#(/@$`
MLP```#@_`0`7````[#\!`"4````$0`$`,@```"I``0`I````74`!`#X```"'
M0`$`(@```,9``0!2````Z4`!`'0````\00$`<P```+%!`0`E````)4(!``L`
M``!+0@$`L0```%="`0!S````"4,!`$4```!]0P$`(0```,-#`0`N````Y4,!
M`#`````41`$`)0```$5$`0`<````:T0!`#$```"(1`$`!P```+I$`0`'````
MPD0!``0```#*1`$`#0```,]$`0`+````W40!``X```#I1`$`"P```/A$`0`%
M````!$4!`!`````*10$``@```!M%`0!9````'D4!``4```!X10$`$@```'Y%
M`0`$````D44!``<```"610$`"````)Y%`0`%````IT4!``,```"M10$`$```
M`+%%`0`*````PD4!``P```#-10$`$P```-I%`0`-````[D4!``(```#\10$`
M!P```/]%`0`&````!T8!`!0````.1@$`#````"-&`0`8````,$8!``8```!)
M1@$`$@```%!&`0`,````8T8!``,```!P1@$`*@```'1&`0`$````GT8!``8`
M``"D1@$`!P```*M&`0`?````LT8!`#4```#31@$`+@````E'`0`O````.$<!
M`!<```!H1P$`(````(!'`0`;````H4<!`!@```"]1P$`)````-9'`0`?````
M^T<!`!H````;2`$`(````#9(`0`:````5T@!`#(```!R2`$`+P```*5(`0`:
M````U4@!`"L```#P2`$`'P```!Q)`0`C````/$D!`!\```!@20$`&@```(!)
M`0`E````FTD!`"8```#!20$`)0```.A)`0`D````#DH!`!@````S2@$`'0``
M`$Q*`0`D````:DH!`!@```"/2@$`(@```*A*`0`E````RTH!`#P```#Q2@$`
M'P```"Y+`0`C````3DL!`!\```!R2P$`(````))+`0`:````LTL!`!@```#.
M2P$`)@```.=+`0`>````#DP!`"D````M3`$`'@```%=,`0`)````=DP!``P`
M``"`3`$`%P```(U,`0`O````I4P!`"0```#53`$`!P```/I,`0`?`````DT!
M``\````B30$`%````#)-`0`.````1TT!``T```!630$`)````&1-`0`%````
MB4T!``<```"/30$`(@```)=-`0`E````NDT!`!,```#@30$`'0```/1-`0`:
M````$DX!``<````M3@$`QP```#5.`0`+````_4X!`!4````)3P$`#````!]/
M`0`&````+$\!``D````S3P$`&````#U/`0`+````5D\!``T```!B3P$`'0``
M`'!/`0`7````CD\!``8```"F3P$`,P```*U/`0`3````X4\!`!,```#U3P$`
M!P````E0`0`&````$5`!``\````84`$`!P```"A0`0`R````,%`!`"$```!C
M4`$`$P```(50`0`,````F5`!`!$```"F4`$`,@```+A0`0`0````ZU`!``@`
M``#\4`$`'0````51`0`)````(U$!``H````M40$`!0```#A1`0`4````/E$!
M``H```!340$`'0```%Y1`0`(````?%$!`!\```"%40$`"````*51`0`:````
MKE$!``8```#)40$`%0```-!1`0`'````YE$!``@```#N40$`"0```/=1`0`_
M`````5(!``<```!!4@$`#P```$E2`0`.````65(!`!````!H4@$`"0```'E2
M`0`)````@U(!``@```"-4@$`$P```)92`0`'````JE(!`!D```"R4@$`"@``
M`,Q2`0`*````UU(!``D```#B4@$`%P```.Q2`0`4````!%,!``H````94P$`
M#````"13`0`7````,5,!``0```!)4P$`*@```$Y3`0`1````>5,!``<```"+
M4P$`"0```)-3`0`"````G5,!`!````"@4P$`&````+%3`0`+````RE,!``,`
M``#64P$`"````-I3`0`&````XU,!``<```#J4P$`#0```/)3`0`+`````%0!
M`!0````,5`$`%0```"%4`0`.````-U0!`"\```!&5`$`(````'94`0`<````
MEU0!``P```"T5`$`,0```,%4`0`%````\U0!`!(```#Y5`$`/P````Q5`0`2
M````3%4!``H```!?50$`!@```&I5`0`$````<54!``0```!V50$`"@```'M5
M`0`3````AE4!``4```":50$`!@```*!5`0`&````IU4!``D```"N50$`!```
M`+A5`0`,````O54!``H```#*50$`(````-55`0`%````]E4!`!@```#\50$`
M&0```!56`0`?````+U8!`!T```!/5@$`$0```&U6`0`"````?U8!``0```""
M5@$`"@```(=6`0`&````DE8!``4```"95@$``P```)]6`0`,````HU8!`$4`
M``"P5@$`&@```/96`0`H````$5<!`#4````Z5P$`)0```'!7`0`H````EE<!
M`%,```"_5P$`&0```!-8`0!R````+5@!`"````"@6`$`-0```,%8`0`A````
M]U@!`$4````960$`,````%]9`0`?````D%D!`!\```"P60$`&0```-!9`0`H
M````ZED!`"D````36@$`)@```#U:`0`E````9%H!`"@```"*6@$`*````+-:
M`0`B````W%H!`"$```#_6@$`,````"%;`0`2````4EL!`!,```!E6P$`$```
M`'E;`0!Y````BEL!``D````$7`$`<@````Y<`0!S````@5P!`'P```#U7`$`
M*P```')=`0!3````GET!`!<```#R70$`%@````I>`0`/````(5X!`&4````Q
M7@$`'P```)=>`0`?````MUX!`$````#77@$`'P```!A?`0`<````.%\!`%$`
M``!57P$`%````*=?`0`*````O%\!``4```#'7P$`!@```,U?`0`(````U%\!
M``4```#=7P$`$@```.-?`0`0````]E\!`!,````'8`$`'0```!M@`0`/````
M.6`!``\```!)8`$`!````%E@`0`)````7F`!``L```!H8`$`!P```'1@`0`%
M````?&`!`!0```""8`$`!P```)=@`0`(````GV`!``\```"H8`$`"````+A@
M`0`,````P6`!``\```#.8`$`!@```-Y@`0`4````Y6`!``8```#Z8`$`#```
M``%A`0`5````#F$!``@````D80$`!````"UA`0`*````,F$!``0````]80$`
M!@```$)A`0`'````26$!``0```!180$`!P```%9A`0`9````7F$!``(```!X
M80$`!````'MA`0`)````@&$!``8```"*80$`!@```)%A`0`G````F&$!``0`
M``#`80$`"P```,5A`0`)````T6$!``\```#;80$`$P```.MA`0`'````_V$!
M``<````'8@$`!@````]B`0`&````%F(!`!`````=8@$`$@```"YB`0`&````
M06(!``D```!(8@$`,P```%)B`0`B````AF(!``<```"I8@$`!P```+%B`0`'
M````N6(!``L```#!8@$`!0```,UB`0`"````TV(!``L```#68@$`*`$``.)B
M`0!2````"V0!`-H```!>9`$`<0```#EE`0#=````JV4!`*@```")9@$`1@``
M`#)G`0`Z````>6<!`"D```"T9P$`.P```-YG`0`U````&F@!`#0```!0:`$`
M4````(5H`0!0````UF@!`$P````G:0$`30```'1I`0!2````PFD!`%(````5
M:@$`/@```&AJ`0!,````IVH!`%````#T:@$`,P```$5K`0!-````>6L!`$@`
M``#':P$`3````!!L`0`T````76P!`#<```"2;`$`=@```,IL`0`T````06T!
M`"0```!V;0$`JP```)MM`0!.````1VX!`!$!``"6;@$`60```*AO`0`S````
M`G`!`)`````V<`$`30```,=P`0`3````%7$!``\````I<0$`$@```#EQ`0`*
M````3'$!``D```!7<0$`"P```&%Q`0`$````;7$!``L```!R<0$`%````'YQ
M`0`L````DW$!`!,```#`<0$`#@```-1Q`0`)````XW$!``\```#M<0$`!0``
M`/UQ`0`H`````W(!``P````L<@$`#@```#ER`0`9````2'(!``X```!B<@$`
M"P```'%R`0`5````?7(!`"X```"3<@$`+@```,)R`0`M````\7(!`!<````?
M<P$`#0```#=S`0`*````17,!`!$```!0<P$`-P```&)S`0`C````FG,!`"$`
M``"^<P$`$````.!S`0`>````\7,!`"H````0=`$`-````#MT`0`.````<'0!
M``L```!_=`$`$````(MT`0`/````G'0!``8```"L=`$`&P```+-T`0`R````
MSW0!`"(````"=0$`)P```"5U`0`G````374!`!P```!U=0$`$@```))U`0`8
M````I74!`!````"^=0$`&P```,]U`0`/````ZW4!``\```#[=0$`!P````MV
M`0!,````$W8!`"X```!@=@$`*````(]V`0`^````N'8!`$T```#W=@$`:```
M`$5W`0!K````KG<!`&X````:>`$`<0```(EX`0!`````^W@!`!0````\>0$`
M%````%%Y`0`:````9GD!``4```"!>0$`!@```(=Y`0`0````CGD!``<```"?
M>0$`"0```*=Y`0`)````L7D!`!(```"[>0$`#````,YY`0`R````VWD!`#``
M```.>@$`$0```#]Z`0`1````47H!``X```!C>@$`"P```')Z`0`)````?GH!
M`!4```"(>@$`%0```)YZ`0`/````M'H!`!8```#$>@$`%0```-MZ`0`C````
M\7H!`",````5>P$`&P```#E[`0`/````57L!`!8```!E>P$`#@```'Q[`0`M
M````BWL!`!T```"Y>P$`%P```-=[`0`;````[WL!`!,````+?`$`6P```!]\
M`0`U````>WP!`"4```"Q?`$`*@```-=\`0`%`````GT!``D````(?0$`,0``
M`!)]`0`&````1'T!``P```!+?0$`"@```%A]`0`'````8WT!``@```!K?0$`
M!0```'1]`0`)````>GT!``L```"$?0$`!````)!]`0`@````E7T!``P```"V
M?0$`#````,-]`0`0````T'T!`!H```#A?0$`+````/Q]`0`*````*7X!`!P`
M```T?@$`&P```%%^`0`@````;7X!`!<```".?@$`%@```*9^`0`3````O7X!
M`!````#1?@$`'P```.)^`0`'`````G\!``8````*?P$`"````!%_`0`.````
M&G\!``@````I?P$`"@```#)_`0`2````/7\!``H```!0?P$`$0```%M_`0`5
M````;7\!`!@```"#?P$`"@```)Q_`0`1````IW\!``4```"Y?P$`%P```+]_
M`0`6````UW\!``L```#N?P$`0@```/I_`0`\````/8`!``H```!Z@`$`!P``
M`(6``0`3````C8`!``4```"A@`$`!0```*>``0`0````K8`!``L```"^@`$`
M%0```,J``0!%````X(`!`!$````F@0$`1@```#B!`0`R````?X$!`#$```"R
M@0$`+@```.2!`0`O````$X(!``H```!#@@$`"@```$Z"`0`(````68(!``D`
M``!B@@$`"@```&R"`0`R````=X(!`#@```"J@@$`,0```.."`0!7````%8,!
M`#````!M@P$`,````)Z#`0`P````SX,!`$8`````A`$`-````$>$`0`S````
M?(0!`#````"PA`$`-@```.&$`0`5````&(4!`!D````NA0$`+@```$B%`0`D
M````=X4!`!,```"<A0$`&@```+"%`0`,````RX4!``P```#8A0$`"P```.6%
M`0`0````\84!`!@````"A@$`'0```!N&`0`'````.88!``<```!!A@$`%@``
M`$F&`0`*````8(8!``@```!KA@$`!````'2&`0`O````>88!``D```"IA@$`
M"P```+.&`0`&````OX8!``8```#&A@$`!0```,V&`0`'````TX8!``8```#;
MA@$`"@```.*&`0`L````[88!`!`````:AP$`"````"N'`0`#````-(<!``<`
M```XAP$`"0```$"'`0`$````2H<!``H```!/AP$`!@```%J'`0`5````88<!
M``8```!WAP$`"````'Z'`0`)````AX<!``T```"1AP$`"````)^'`0`A````
MJ(<!`!$```#*AP$`*0```-R'`0`@````!H@!``D````GB`$`$0```#&(`0`,
M````0X@!``<```!0B`$``P```%B(`0`#````7(@!`!4```!@B`$`%````':(
M`0`&````BX@!``0```"2B`$`"````)>(`0`(````H(@!`%(```"IB`$`)@``
M`/R(`0`&````(XD!``@````JB0$`&````#.)`0`B````3(D!`"4```!OB0$`
M,````)6)`0`D````QHD!`"H```#KB0$`>@```!:*`0`U````D8H!``H```#'
MB@$`"0```-**`0`5````W(H!``\```#RB@$`#0````*+`0`0````$(L!`!$`
M```ABP$`$````#.+`0`.````1(L!``T```!3BP$`%@```&&+`0`&````>(L!
M`!T```!_BP$`'@```)V+`0`2````O(L!`!$```#/BP$`!@```.&+`0`*````
MZ(L!``@```#SBP$`80```/R+`0`1````7HP!``@```!PC`$`$P```'F,`0`_
M````C8P!``4```#-C`$`!0```-.,`0`>````V8P!`!L```#XC`$`$P```!2-
M`0`7````*(T!`!,```!`C0$`$P```%2-`0`L````:(T!`!````"5C0$`)```
M`*:-`0`H````RXT!`!\```#TC0$`!@```!2.`0`4````&XX!`!$````PC@$`
M#0```$*.`0`2````4(X!`!8```!CC@$`$P```'J.`0`,````CHX!``8```";
MC@$`!P```**.`0`8````JHX!`!$```##C@$`$0```-6.`0`(````YXX!``4`
M``#PC@$`#0```/:.`0`-````!(\!``D````2CP$`"P```!R/`0`&````*(\!
M``@````OCP$`#0```#B/`0`/````1H\!``L```!6CP$`"0```&*/`0`+````
M;(\!``T```!XCP$`!P```(:/`0`'````CH\!``@```"6CP$`$@```)^/`0`)
M````LH\!``D```"\CP$`&P```,:/`0`H````XH\!``\````+D`$`$P```!N0
M`0`:````+Y`!``4```!*D`$`*````%"0`0`3````>9`!`!0```"-D`$`.```
M`**0`0!'````VY`!`"(````CD0$`-0```$:1`0`/````?)$!``@```",D0$`
M#0```)61`0`&````HY$!``@```"JD0$`$````+.1`0`3````Q)$!``H```#8
MD0$`"0```..1`0`=````[9$!`"(````+D@$`(````"Z2`0`E````3Y(!`!P`
M``!UD@$`+0```)*2`0`?````P)(!`"X```#@D@$`'`````^3`0`C````+),!
M`#X```!0DP$`'````(^3`0`?````K),!`!X```#,DP$`*0```.N3`0`O````
M%90!`#(```!%E`$`)````'B4`0`K````G90!`#<```#)E`$`(@````&5`0`A
M````))4!`#T```!&E0$`$P```(25`0`=````F)4!`"@```"VE0$`'P```-^5
M`0`2````_Y4!`,0````2E@$`%````->6`0`>````[)8!`"4````+EP$`)P``
M`#&7`0`C````69<!`"(```!]EP$`)````*"7`0`A````Q9<!`"0```#GEP$`
M,0````R8`0`O````/I@!`#(```!NF`$`I@```*&8`0`C````2)D!`!@```!L
MF0$`'````(69`0`G````HID!`#````#*F0$`1P```/N9`0!$````0YH!``T`
M``"(F@$`!````)::`0`)````FYH!``4```"EF@$`#0```*N:`0`/````N9H!
M``X```#)F@$`#P```-B:`0`0````Z)H!``<```#YF@$`!`````&;`0`,````
M!IL!``P````3FP$`#@```"";`0`+````+YL!`!(````[FP$`#0```$Z;`0`N
M````7)L!``<```"+FP$`$````).;`0`&````I)L!`!,```"KFP$`&0```+^;
M`0`;````V9L!`!4```#UFP$``@````N<`0`)````#IP!``0````8G`$`$```
M`!V<`0`%````+IP!``\````TG`$`#@```$2<`0`#````4YP!`!````!7G`$`
M"````&B<`0`1````<9P!``D```"#G`$`%0```(V<`0`)````HYP!``\```"M
MG`$`%````+V<`0`1````TIP!`!$```#DG`$`"@```/:<`0`2`````9T!``P`
M```4G0$`"P```"&=`0`1````+9T!`!$````_G0$`&@```%&=`0`-````;)T!
M``\```!ZG0$`*0```(J=`0`<````M)T!`#8```#1G0$`#0````B>`0`D````
M%IX!`!H````[G@$`&````%:>`0`I````;YX!`"4```"9G@$`"P```+^>`0`*
M````RYX!``X```#6G@$`*0```.6>`0`6````#Y\!``P````FGP$`)````#.?
M`0`M````6)\!``P```"&GP$`"````).?`0`A````G)\!``H```"^GP$`&0``
M`,F?`0`:````XY\!``D```#^GP$`%0````B@`0`.````'J`!`!T````MH`$`
M#P```$N@`0`9````6Z`!``@```!UH`$`$````'Z@`0`F````CZ`!`#T```"V
MH`$`"````/2@`0`6````_:`!``H````4H0$`#0```!^A`0`R````+:$!``\`
M``!@H0$`!0```'"A`0`&````=J$!``,```!]H0$`!P```(&A`0`(````B:$!
M``T```"2H0$`#@```*"A`0`.````KZ$!`!````"^H0$`&0```,^A`0`5````
MZ:$!`!<```#_H0$`&0```!>B`0`)````,:(!``8````[H@$`"P```$*B`0`*
M````3J(!``(```!9H@$`!@```%RB`0`+````8Z(!`",```!OH@$`%@```).B
M`0`)````JJ(!``T```"TH@$`#P```,*B`0`/````TJ(!`#X```#BH@$`)@``
M`"&C`0`%````2*,!``@```!.HP$`#P```%>C`0"+````9Z,!`!X```#SHP$`
M10```!*D`0`2````6*0!``<```!KI`$`!````'.D`0`D````>*0!`!<```"=
MI`$`'````+6D`0`&````TJ0!``<```#9I`$`"````.&D`0`'````ZJ0!``8`
M``#RI`$`#P```/FD`0`.````":4!`!`````8I0$`#@```"FE`0`/````.*4!
M``P```!(I0$`"P```%6E`0`1````8:4!``D```!SI0$`"@```'VE`0`*````
MB*4!`!(```"3I0$`#@```*:E`0`N````M:4!``L```#DI0$`"````/"E`0`1
M````^:4!``X````+I@$`%````!JF`0`F````+Z8!`"D```!6I@$`*````("F
M`0`=````J:8!`!X```#'I@$`+````.:F`0`A````$Z<!`"4````UIP$`!```
M`%NG`0`<````8*<!``\```!]IP$`#````(VG`0`#````FJ<!``@```">IP$`
M"0```*>G`0`+````L:<!``P```"]IP$`$0```,JG`0`*````W*<!``0```#G
MIP$`'````.RG`0`>````":@!``T````HJ`$`#````#:H`0`.````0Z@!``T`
M``!2J`$`)P```&"H`0`'````B*@!``<```"0J`$`#````)BH`0`/````I:@!
M`!4```"UJ`$`!P```,NH`0`'````TZ@!``0```#;J`$`$P```."H`0`)````
M]*@!``<```#^J`$`,`````:I`0`7````-ZD!`((```!/J0$`%P```-*I`0`+
M````ZJD!``<```#VJ0$`"P```/ZI`0`(````"JH!``H````3J@$`!@```!ZJ
M`0`*````):H!`!D````PJ@$`%0```$JJ`0`"````8*H!``8```!CJ@$`"0``
M`&JJ`0`9````=*H!`!4```".J@$`$P```*2J`0`2````N*H!`!L```#+J@$`
M#````.>J`0`/````]*H!`!P````$JP$``P```"&K`0`'````):L!`!8````M
MJP$`"@```$2K`0`.````3ZL!``4```!>JP$`!0```&2K`0`S````:JL!``8`
M``">JP$`!@```*6K`0`8````K*L!`!$```#%JP$`(@```->K`0`'````^JL!
M``D````"K`$`#0````RL`0`%````&JP!``D````@K`$`"````"JL`0`"````
M,ZP!``8````VK`$`#0```#VL`0`+````2ZP!``L```!7K`$`$P```&.L`0`)
M````=ZP!``<```"!K`$`#````(FL`0`?````EJP!``P```"VK`$`!P```,.L
M`0`*````RZP!``0```#6K`$`"0```-NL`0`(````Y:P!``P```#NK`$`#```
M`/NL`0`*````"*T!``8````3K0$`#0```!JM`0`&````**T!``(````OK0$`
M!````#*M`0!`````-ZT!`$0```!XK0$`0@```+VM`0`A`````*X!``4````B
MK@$`#P```"BN`0`%````.*X!``,````^K@$`(0```$*N`0`8````9*X!``8`
M``!]K@$`!````(2N`0`;````B:X!``8```"EK@$`H@```*RN`0`(````3Z\!
M`"(```!8KP$`!````'NO`0`I````@*\!``4```"JKP$`%P```+"O`0`$````
MR*\!``T```#-KP$`#P```-NO`0`(````ZZ\!``D```#TKP$`!0```/ZO`0`9
M````!+`!`#T````>L`$`-@```%RP`0`[````D[`!`"H```#/L`$`,````/JP
M`0`X````*[$!`#H```!DL0$`+0```)^Q`0!2````S;$!`#`````@L@$`.0``
M`%&R`0`I````B[(!`!````"UL@$`&````,:R`0`,````W[(!`"0```#LL@$`
M)````!&S`0`B````-K,!`"$```!9LP$`"P```'NS`0`-````A[,!``H```"5
MLP$`"0```*"S`0`B````JK,!`"@```#-LP$`*````/:S`0`(````'[0!`!H`
M```HM`$`,P```$.T`0`8````=[0!`!(```"0M`$`!P```*.T`0`3````J[0!
M`!0```"_M`$`%@```-2T`0`0````Z[0!`%$```#\M`$`D0```$ZU`0"$````
MX+4!`!<```!EM@$`#@```'VV`0`/````C+8!`!0```"<M@$`%0```+&V`0`1
M````Q[8!``P```#9M@$`$P```.:V`0`5````^K8!`!4````0MP$`#@```":W
M`0`/````-;<!`"(```!%MP$`*0```&BW`0"-````DK<!`!0````@N`$`!0``
M`#6X`0`6````.[@!``D```!2N`$`!````%RX`0`*````8;@!`!\```!LN`$`
M$0```(RX`0`3````GK@!``X```"RN`$`$````,&X`0`4````TK@!`"<```#G
MN`$`*0````^Y`0`E````.;D!`"4```!?N0$`,````(6Y`0`P````MKD!`!T`
M``#GN0$`10````6Z`0`/````2[H!`!$```!;N@$`$0```&VZ`0`3````?[H!
M`!(```"3N@$`%0```*:Z`0`7````O+H!``\```#4N@$`$0```.2Z`0`Y````
M]KH!`!T````PNP$`%P```$Z[`0`Z````9KL!`!,```"ANP$`!P```+6[`0`-
M````O;L!`#0```#+NP$`(@````"\`0`5````([P!`!(````YO`$`&0```$R\
M`0`9````9KP!`!0```"`O`$`$@```)6\`0`>````J+P!`"0```#'O`$`%@``
M`.R\`0`2`````[T!`!D````6O0$`%P```#"]`0`3````2+T!`!<```!<O0$`
M"@```'2]`0`@````?[T!``0```"@O0$`!P```*6]`0`*````K;T!`!@```"X
MO0$`!@```-&]`0`(````V+T!``<```#AO0$`!@```.F]`0`'````\+T!``<`
M``#XO0$`!0````"^`0`4````!KX!``8````;O@$`"````"*^`0`$````*[X!
M``0````PO@$`"0```#6^`0`5````/[X!`!(```!5O@$`#P```&B^`0`0````
M>+X!``H```")O@$`$P```)2^`0`%````J+X!`"<```"NO@$`#@```-:^`0`-
M````Y;X!`!,```#SO@$`#0````>_`0`+````%;\!``X````AOP$`,P```#"_
M`0`(````9+\!``@```!MOP$`)P```':_`0`4````GK\!`!$```"SOP$`!P``
M`,6_`0`)````S;\!``<```#7OP$`!````-^_`0`@````Y+\!``T````%P`$`
M$````!/``0`2````),`!`!8````WP`$`'0```$[``0`9````;,`!``<```"&
MP`$`!P```([``0`&````EL`!`!@```"=P`$`!P```+;``0`%````OL`!``H`
M``#$P`$`#@```,_``0`'````WL`!``<```#FP`$`'0```.[``0`-````#,$!
M``P````:P0$`#````"?!`0`2````-,$!``P```!'P0$`#P```%3!`0`7````
M9,$!``T```!\P0$`$````(K!`0`(````F\$!``0```"DP0$`$````*G!`0!!
M````NL$!``4```#\P0$`#`````+"`0`A````#\(!``T````QP@$`&0```#_"
M`0`*````6<(!``T```!DP@$`"@```'+"`0`(````?<(!``X```"&P@$`"@``
M`)7"`0`1````H,(!`!(```"RP@$`+P```,7"`0`*````]<(!``@`````PP$`
M%0````G#`0`(````'\,!``P````HPP$`%@```#7#`0`'````3,,!``D```!4
MPP$`"````%[#`0`,````9\,!`$X```!TPP$`$P```,/#`0`(````U\,!``L`
M``#@PP$`!@```.S#`0`$````\\,!`!8```#XPP$`%P````_$`0`8````)\0!
M``D```!`Q`$``@```$K$`0`$````3<0!`"(```!2Q`$``P```'7$`0`%````
M><0!`#,```!_Q`$`"@```+/$`0`%````OL0!``8```#$Q`$`#0```,O$`0`-
M````V<0!`$@```#GQ`$`$0```##%`0`&````0L4!``@```!)Q0$`"0```%+%
M`0`$````7,4!``4```!AQ0$`8@```&?%`0`+````RL4!``T```#6Q0$`!0``
M`.3%`0`%````ZL4!`"8```#PQ0$`-P```!?&`0`1````3\8!``H```!AQ@$`
M%0```&S&`0`*````@L8!``D```"-Q@$`'````)?&`0`G````M,8!`"T```#<
MQ@$`+`````K'`0`/````-\<!``,```!'QP$`!P```$O'`0`+````4\<!`!4`
M``!?QP$`%@```'7'`0`4````C,<!`!0```"AQP$`$@```+;'`0`9````R<<!
M``4```#CQP$`"@```.G'`0`2````],<!`#8````'R`$`(0```#[(`0`U````
M8,@!`"<```"6R`$`!P```+[(`0!I````QL@!`!$````PR0$`"P```$+)`0`*
M````3LD!`!\```!9R0$`30```'G)`0`'````Q\D!`"$```#/R0$`"````/')
M`0`&````^LD!`!\````!R@$`!@```"'*`0`)````*,H!`"T````RR@$`+```
M`&#*`0`&````C<H!``H```"4R@$`)0```)_*`0!A````Q<H!`!8````GRP$`
M*````#[+`0`5````9\L!``(```!]RP$`#@```(#+`0`)````C\L!``\```"9
MRP$`"@```*G+`0`&````M,L!``<```"[RP$`%P```,/+`0`&````V\L!``@`
M``#BRP$`#0```.O+`0`+````^<L!``H````%S`$`"0```!#,`0`'````&LP!
M`!8````BS`$`%````#G,`0`3````3LP!``P```!BS`$`"@```&_,`0`+````
M>LP!``H```"&S`$`#````)',`0`*````GLP!``H```"IS`$`'0```+3,`0`4
M````TLP!``P```#GS`$`#````/3,`0`2`````<T!``4````4S0$`)0```!K-
M`0`$````0,T!``<```!%S0$`!0```$W-`0`/````4\T!``4```!CS0$`"0``
M`&G-`0`3````<\T!`!(```"'S0$`&@```)K-`0`6````M<T!`!@```#,S0$`
M%P```.7-`0`7````_<T!`!X````5S@$`&````#3.`0`'````3<X!``4```!5
MS@$`#P```%O.`0`0````:\X!``L```!\S@$`(0```(C.`0`-````JLX!`!$`
M``"XS@$`%0```,K.`0`&````X,X!``T```#GS@$`"````/7.`0`/````_LX!
M``T````.SP$`#P```!S/`0`)````+,\!``4````VSP$`!P```#S/`0`%````
M1,\!``0```!*SP$``P```$_/`0`_````4\\!`#D```"3SP$`$P```,W/`0`L
M````X<\!`#(````.T`$`$0```$'0`0`V````4]`!`#H```"*T`$`&````,70
M`0`N````WM`!`#,````-T0$`,P```$'1`0`[````==$!`!(```"QT0$`&@``
M`,31`0!!````W]$!`!4````AT@$`&P```#?2`0`>````4](!`!T```!RT@$`
M%@```)#2`0`4````I](!`!4```"\T@$`&0```-+2`0`R````[-(!`#(````?
MTP$`-0```%+3`0`R````B-,!`#,```"[TP$`-````._3`0`Q````)-0!`&L`
M``!6U`$`'0```,+4`0`.````X-0!``L```#OU`$`,````/O4`0`O````+-4!
M`",```!<U0$`#````(#5`0!)````C=4!`$(```#7U0$`#@```!K6`0`$````
M*=8!`!`````NU@$`'````#_6`0`.````7-8!`!,```!KU@$`"````'_6`0`)
M````B-8!``<```"2U@$`"0```)K6`0`.````I-8!`!4```"SU@$`#@```,G6
M`0`1````V-8!``@```#JU@$`'````//6`0`)````$-<!``@````:UP$`!0``
M`"/7`0`0````*=<!``\````ZUP$`#````$K7`0`_````5]<!``(```"7UP$`
M!@```)K7`0`.````H=<!`!L```"PUP$`!@```,S7`0`'````T]<!`!````#;
MUP$`!P```.S7`0`/````]-<!``0````$V`$`,0````G8`0`;````.]@!`"(`
M``!7V`$`6````'K8`0`8````T]@!`$@```#LV`$`(P```#79`0`0````6=D!
M``\```!JV0$`!@```'K9`0`.````@=D!``<```"0V0$`#P```)C9`0`,````
MJ-D!`!,```"UV0$`"P```,G9`0`=````U=D!`!H```#SV0$`!@````[:`0`1
M````%=H!``\````GV@$`)@```#?:`0`9````7MH!`!,```!XV@$`%````(S:
M`0`@````H=H!``@```#"V@$`"0```,O:`0`9````U=H!`!(```#OV@$`$P``
M``+;`0`8````%ML!`!D````OVP$`"@```$G;`0`,````5-L!``@```!AVP$`
M!0```&K;`0`=````<-L!``8```".VP$`$@```)7;`0`(````J-L!`!0```"Q
MVP$`"@```,;;`0`5````T=L!`!(```#GVP$`)0```/K;`0`P````(-P!`!H`
M``!1W`$`"P```&S<`0`,````>-P!`"$```"%W`$`!P```*?<`0`6````K]P!
M``,```#&W`$`&````,K<`0`&````X]P!``<```#JW`$`(0```/+<`0`Q````
M%-T!``4```!&W0$`&P```$S=`0`-````:-T!``P```!VW0$`%P```(/=`0`$
M````F]T!``H```"@W0$`#````*O=`0`(````N-T!``8```#!W0$`"````,C=
M`0`&````T=T!``H```#8W0$`%P```./=`0`T````^]T!`#0````PW@$`(@``
M`&7>`0`S````B-X!`"````"\W@$`1P```-W>`0`=````)=\!`"X```!#WP$`
M+````'+?`0!@````G]\!`#$`````X`$`80```#+@`0`Y````E.`!`"4```#.
MX`$`!0```/3@`0`(````^N`!``D````#X0$`"`````WA`0`A````%N$!`!P`
M```XX0$`,````%7A`0`C````AN$!`#$```"JX0$`-@```-SA`0`,````$^(!
M``D````@X@$`&````"KB`0`+````0^(!``H```!/X@$`*P```%KB`0`-````
MAN(!``T```"4X@$`$@```*+B`0`-````M>(!``@```##X@$`%````,SB`0`)
M````X>(!``D```#KX@$`#````/7B`0`0`````N,!`!L````3XP$`+````"_C
M`0`+````7.,!``8```!HXP$`!0```&_C`0`=````=>,!`!0```"3XP$`!0``
M`*CC`0`+````KN,!``H```"ZXP$`"````,7C`0`/````SN,!`!````#>XP$`
M#@```._C`0`*````_N,!``4````)Y`$`#@````_D`0!%````'N0!`&(```!D
MY`$`'````,?D`0`C````Y.0!`!D````(Y0$`!0```"+E`0`4````*.4!``L`
M```]Y0$`(@```$GE`0`2````;.4!`"X```!_Y0$`"P```*[E`0`0````NN4!
M`!$```#+Y0$`$@```-WE`0`9````\.4!`!`````*Y@$`20```!OF`0`,````
M9>8!`"0```!RY@$`%0```)?F`0`7````K>8!`!,```#%Y@$`)0```-GF`0`S
M````_^8!`"T````SYP$`#````&'G`0`]````;N<!`#````"LYP$`,0```-WG
M`0`M````#^@!``P````]Z`$`$@```$KH`0`*````7>@!`!````!HZ`$`$P``
M`'GH`0`*````C>@!`!T```"8Z`$`"P```+;H`0`1````PN@!``<```#4Z`$`
M&````-SH`0`7````]>@!``@````-Z0$`!@```!;I`0`+````'>D!``\````I
MZ0$`%````#GI`0`#````3ND!``@```!2Z0$`"P```%OI`0`2````9^D!`!,`
M``!ZZ0$`$0```([I`0`1````H.D!``8```"RZ0$`"0```+GI`0`W````P^D!
M`#````#[Z0$`+0```"SJ`0`'````6NH!`!,```!BZ@$`!@```';J`0`C````
M?>H!`!@```"AZ@$`)P```+KJ`0`-````XNH!``D```#PZ@$``@```/KJ`0`#
M````_>H!``8````!ZP$`"@````CK`0`"````$^L!``D````6ZP$`$0```"#K
M`0`(````,NL!`!4````[ZP$`&P```%'K`0`4````;>L!``4```""ZP$`"@``
M`(CK`0`4````D^L!`!$```"HZP$`#````+KK`0`'````Q^L!``H```#/ZP$`
M#````-KK`0`.````Y^L!`%T```#VZP$`&@```%3L`0`K````;^P!``H```";
M[`$`!@```*;L`0`,````K>P!`!\```"Z[`$`'0```-KL`0`.````^.P!`!,`
M```'[0$`)````!OM`0`=````0.T!`!0```!>[0$`*````'/M`0`@````G.T!
M`!0```"][0$`=````-+M`0`C````1^X!`!L```!K[@$`+````(?N`0`B````
MM.X!`!L```#7[@$`)0```//N`0`9````&>\!`!L````S[P$`&@```$_O`0`9
M````:N\!``L```"$[P$`!P```)#O`0`(````F.\!``D```"A[P$`%````*OO
M`0`+````P.\!`!,```#,[P$`"0```.#O`0!>````ZN\!`#D```!)\`$`1P``
M`(/P`0`X````R_`!`%L````$\0$`"0```&#Q`0`A````:O$!`#(```",\0$`
M"@```+_Q`0`(````RO$!`!(```#3\0$`/P```.;Q`0`)````)O(!`&@````P
M\@$`,````)GR`0`G````RO(!`!````#R\@$`(@````/S`0`D````)O,!`"X`
M``!+\P$`*P```'KS`0`N````IO,!`#$```#5\P$`$`````?T`0`%````&/0!
M``L````>]`$`"@```"KT`0`5````-?0!``H```!+]`$`+````%;T`0`,````
M@_0!``D```"0]`$`)@```)KT`0`,````P?0!`!<```#.]`$`"0```.;T`0`'
M````\/0!`!,```#X]`$`#P````SU`0`)````'/4!``@````F]0$`!@```"_U
M`0`+````-O4!``L```!"]0$`$0```$[U`0`0````8/4!``X```!Q]0$`&P``
M`(#U`0`0````G/4!``<```"M]0$`0P```+7U`0`5````^?4!`!@````/]@$`
M"0```"CV`0`+````,O8!`!H````^]@$`*0```%GV`0`2````@_8!`"4```"6
M]@$`)P```+SV`0`/````Y/8!``H```#T]@$`&@```/_V`0`&````&O<!``0`
M```A]P$`&````";W`0`.````/_<!`!````!.]P$`#@```%_W`0`%````;O<!
M``D```!T]P$`"0```'[W`0`)````B/<!``4```"2]P$`"0```)CW`0`2````
MHO<!``8```"U]P$`(````+SW`0`-````W?<!``4```#K]P$`"0```/'W`0`+
M````^_<!`!H````'^`$`"P```"+X`0`"````+O@!`"`````Q^`$`"0```%+X
M`0`D````7/@!``H```"!^`$`;0```(SX`0`)````^O@!``8````$^0$`*P``
M``OY`0`^````-_D!`!\```!V^0$`*P```);Y`0!$````POD!`"H````'^@$`
M-````#+Z`0`:````9_H!`!@```""^@$`!@```)OZ`0`,````HOH!``H```"O
M^@$`#0```+KZ`0`&````R/H!``H```#/^@$`&````-KZ`0`,````\_H!``T`
M````^P$`#P````[[`0`+````'OL!``T````J^P$`"````#C[`0`*````0?L!
M`!@```!,^P$`"0```&7[`0`&````;_L!``L```!V^P$`&````(+[`0`<````
MF_L!``H```"X^P$`#````,/[`0`+````T/L!``4```#<^P$`$@```.+[`0`2
M````]?L!``8````(_`$`&P````_\`0`,````*_P!`"$````X_`$`!0```%K\
M`0`%````8/P!``X```!F_`$`(P```'7\`0`+````F?P!``T```"E_`$`&P``
M`+/\`0`.````S_P!`!P```#>_`$`%@```/O\`0`%````$OT!``P````8_0$`
M#P```"7]`0`.````-?T!``(```!$_0$`#P```$?]`0`(````5_T!`"L```!@
M_0$`0@```(S]`0`D````S_T!`"\```#T_0$`*````"3^`0`H````3?X!`%T`
M``!V_@$`$P```-3^`0`9````Z/X!`%D````"_P$`-````%S_`0!>````D?\!
M`%L```#P_P$`)@```$P``@`]````<P`"`"L```"Q``(`,P```-T``@`W````
M$0$"`#4```!)`0(`'@```'\!`@`[````G@$"`.0!``#:`0(`)P```+\#`@`A
M````YP,"`!0````)!`(`5````!X$`@""````<P0"`$(```#V!`(`/P```#D%
M`@!R````>04"`%(```#L!0(`(````#\&`@`5````8`8"`!T```!V!@(`'0``
M`)0&`@`M````L@8"`!X```#@!@(`*````/\&`@`H````*`<"`!T```!1!P(`
M$P```&\'`@`Z````@P<"`"@```"^!P(`0P```.<'`@`I````*P@"`"@```!5
M"`(`&````'X(`@!`````EP@"`&D```#8"`(`*````$()`@`\````:PD"`#L`
M``"H"0(`3@```.0)`@`[````,PH"`"L```!O"@(`.@```)L*`@!C````U@H"
M`$P````Z"P(`,@```(<+`@`M````N@L"`#,```#H"P(`,0```!P,`@`L````
M3@P"`$L```![#`(`5````,<,`@"3````'`T"`%L```"P#0(`30````P.`@!1
M````6@X"`#0```"L#@(`)@```.$.`@`J````"`\"`"X````S#P(`+@```&(/
M`@`N````D0\"`(@```#`#P(`A@```$D0`@#0````T!`"`!,```"A$0(`)@``
M`+41`@`Y````W!$"`"P````6$@(`2````$,2`@`K````C!("`$P```"X$@(`
M>P````43`@"2````@1,"`"`````4%`(`"@```#44`@#!````0!0"`((````"
M%0(`1P```(45`@`F````S14"`#T```#T%0(`-0```#(6`@`G````:!8"`"0`
M``"0%@(`/@```+46`@`&````]!8"``<```#[%@(`!`````,7`@`,````"!<"
M``L````5%P(`#````"$7`@`+````+A<"``4````Z%P(`$````$`7`@`#````
M41<"`&<```!5%P(`!P```+T7`@`5````Q1<"``0```#;%P(`!P```.`7`@`&
M````Z!<"``4```#O%P(`"0```/47`@`5````_Q<"``@````5&`(`"P```!X8
M`@`2````*A@"``T````]&`(``@```$L8`@`'````3A@"``<```!6&`(`$@``
M`%X8`@`,````<1@"`!@```!^&`(`!@```)<8`@`.````GA@"``P```"M&`(`
M`P```+H8`@`K````OA@"``0```#J&`(`!P```.\8`@`(````]Q@"`"L`````
M&0(`1P```"P9`@`Z````=!D"`#L```"O&0(`(@```.L9`@`M````#AH"`",`
M```\&@(`)@```&`:`@`J````AQH"`"4```"R&@(`(P```-@:`@`L````_!H"
M`"$````I&P(`/````$L;`@`Z````B!L"`"8```##&P(`-0```.H;`@`K````
M(!P"`"X```!,'`(`+@```'L<`@`I````JAP"`"X```#4'`(`*P````,=`@`P
M````+QT"`"X```!@'0(`*0```(\=`@`I````N1T"`#,```#C'0(`)````!<>
M`@`N````/!X"`"H```!K'@(`0P```)8>`@`I````VAX"`"P````$'P(`+```
M`#$?`@`M````7A\"`"<```",'P(`'0```+0?`@`K````TA\"`"P```#^'P(`
M-P```"L@`@`L````8R`"``P```"0(`(`$P```)T@`@`@````L2`"`#$```#2
M(`(`)`````0A`@`)````*2$"`"0````S(0(`#P```%@A`@`<````:"$"`!0`
M``"%(0(`$````)HA`@`Q````JR$"``@```#=(0(`"````.8A`@`C````[R$"
M`"8````3(@(`%@```#HB`@`G````42("`!\```!Y(@(`"0```)DB`@#A````
MHR("`!(```"%(P(`&@```)@C`@`*````LR,"``D```"^(P(`#````,@C`@`<
M````U2,"`!0```#R(P(`$`````<D`@`E````&"0"`!H````^)`(`!@```%DD
M`@`W````8"0"`!4```"8)`(`%P```*XD`@`'````QB0"``@```#.)`(`$P``
M`-<D`@`+````ZR0"`#P```#W)`(`*P```#0E`@`0````8"4"`!````!Q)0(`
M%0```((E`@`T````F"4"`!$```#-)0(`#@```-\E`@`?````[B4"``X````.
M)@(`$````!TF`@`*````+B8"`!H````Y)@(`"P```%0F`@`;````8"8"``L`
M``!\)@(`)````(@F`@`*````K28"`!L```"X)@(`!P```-0F`@`G````W"8"
M``<````$)P(`"0````PG`@`)````%B<"`#L````@)P(`!@```%PG`@`.````
M8R<"`!,```!R)P(`%@```(8G`@`*````G2<"``@```"H)P(`!P```+$G`@`3
M````N2<"``L```#-)P(`'````-DG`@`/````]B<"`!(````&*`(`"P```!DH
M`@`8````)2@"`!8````^*`(`!0```%4H`@`'````6R@"`!<```!C*`(`!```
M`'LH`@`S````@"@"`!````"T*`(`#````,4H`@`-````TB@"``(```#@*`(`
M$0```.,H`@`B````]2@"``L````8*0(``P```"0I`@`'````*"D"``D````P
M*0(`!@```#HI`@`-````02D"``H```!/*0(`%````%HI`@`5````;RD"`!$`
M``"%*0(`-@```)<I`@`>````SBD"`!H```#M*0(`"P````@J`@`S````%"H"
M``<```!(*@(`%P```%`J`@!+````:"H"`!0```"T*@(`#P```,DJ`@`(````
MV2H"``0```#B*@(`!````.<J`@`*````["H"`!8```#W*@(`!0````XK`@`&
M````%"L"``@````;*P(`"P```"0K`@`$````,"L"``D````U*P(`#@```#\K
M`@`I````3BL"``4```!X*P(`%P```'XK`@`@````EBL"`"$```"W*P(`)0``
M`-DK`@`0````_RL"``(````0+`(`!````!,L`@`*````&"P"``D````C+`(`
M!0```"TL`@`"````,RP"`!\````V+`(`3@```%8L`@`>````I2P"`#T```#$
M+`(`,P````(M`@`T````-BT"`"H```!K+0(`8````)8M`@`0````]RT"`'P`
M```(+@(`)P```(4N`@!3````K2X"`"@````!+P(`4@```"HO`@`X````?2\"
M`"$```"V+P(`'P```-@O`@`E````^"\"`#,````>,`(`-````%(P`@`Y````
MAS`"`#@```#!,`(`/P```/HP`@`_````.C$"`"T```!Z,0(`)@```*@Q`@`S
M````SS$"``X````#,@(`#@```!(R`@`-````(3("`(,````O,@(`"````+,R
M`@"$````O#("`(T```!!,P(`B````,\S`@`N````6#0"`&````"'-`(`%```
M`.@T`@`8````_30"`!(````6-0(`8@```"DU`@`C````C#4"`"8```"P-0(`
M-P```-<U`@`:````#S8"`!@````J-@(`5@```$,V`@`6````FC8"``L```"Q
M-@(`!0```+TV`@`&````PS8"``@```#*-@(`!0```-,V`@`;````V38"`!$`
M``#U-@(`'@````<W`@`?````)C<"`!$```!&-P(`!P```%@W`@`$````8#<"
M``D```!E-P(`#@```&\W`@`(````?C<"``4```"'-P(`'````(TW`@`*````
MJC<"``D```"U-P(`#P```+\W`@`'````SS<"``@```#7-P(`$@```.`W`@`*
M````\S<"`!8```#^-P(`"P```!4X`@`)````(3@"`"$````K.`(`"````$TX
M`@`$````5C@"``D```!;.`(`!@```&4X`@`'````;#@"``8```!T.`(`!P``
M`'LX`@`*````@S@"`!<```"..`(``@```*8X`@`$````J3@"``L```"N.`(`
M!@```+HX`@`'````P3@"`"T```#).`(`!````/<X`@`.````_#@"``T````+
M.0(`$P```!DY`@`7````+3D"``L```!%.0(`!P```%$Y`@`&````63D"``@`
M``!@.0(`$````&DY`@`2````>CD"``<```"-.0(`"@```)4Y`@`\````H#D"
M`#(```#=.0(`!P```!`Z`@`)````&#H"``H````B.@(`$0```"TZ`@`%````
M/SH"``(```!%.@(`"P```$@Z`@`!`````````)T!``"``0``F0$``!@"``!F
M!P``:P0```````!*`@``(@8``$T#``#P````\`4``!8%````````!````/X%
M```,!@``4`(``-T```"D!```400``"@%``"G!0``<0,``/L$``"$````>`$`
M`'<#``"<````G`,``.$&````````3@(``)\%```,`0``2@$```````#I!0``
MI@8``&4#```)!P``8@4``+L%``"7````V`````,!````````W`$``&4'```;
M!@``O`0```,$``#M`P``;0$`````````````'P$``#,%````````5`$``-@&
M``"6````4@0``!`'``#G!```O@(```````#1!```F`,``"0```"Z!@``I@<`
M`+X#``"B!P``&````$D`````````S````-$!`````````````)`"```K````
M*04``!4`````````TP$``%X"``!(!P``)P0``.0#````````.`4`````````
M`````````!8#``#!````#0$``"4%``!0`0``-@(``#$"``#%!@``J@```(,!
M```[!@``?04``+4#```W`0``00,````````-!```;@8`````````````0@(`
M``````#1`@``BP$`````````````J08``&``````````%P````````!Y`0``
M8P```,0$``!?`@``:`0``````````````````!@&````````5`8``(8"``"A
M`````````&H#``#*!@```````&0$```_!0```````+T`````````_0(```L&
M``#4`0``HP(``&@```!?!@```````!`"````````$P`````````G`P``W0$`
M`!8'``"T`@``?P0``,,#````````K@,```````#F`P``6@,``&<'````````
M]P(``-L!``!/!```O`,``)D#````````$P,``%H%``!U`@``]`,```````#X
M!0```````(8'``"V!```>`4``(T#```D`0```````"4'``#9`0```````%<`
M``"Z!0``X0(``&@"````````70<``',!````````)0$``!$$``#:!@``@```
M`%<!``!_`P``/@0````````F````DP$``*P!``#L!```-0,``$T&``"@`0``
M/`4``*\!``"7`0``KP4```````"#!P````````````"G!P``KP0````'```[
M!P``)`4``*X!````````$`$``$P'````````"@```,@!``"N!0``+@8``.$`
M```C`@``?P(```````#Z`@``O@4``,P"``!S`````````'4&``#4!```3`4`
M`.`%````````(@,``!$#``#:!````````+$"``#D!````````.L"``#]!0``
MI`,``/<!```:`@``U@0``,8$``!@`@``FP8```````!$!P``U@```*8%``!Y
M!P``0@8``)0#``!*!```E0(``+,$``!E`0``Z@(``$4!```^`P``E`(``)X#
M``"#!@``QP0``*$$``"P!@``"0$``!D$````````M`0``$L$````````````
M`-P"````````0P,```````"F`P``T04``%("```_!@``"P(``-D$````````
ML`$``*0&``````````````````"[!```I0<``)P$``"B`@```@`````````M
M`P`````````````V!@``-@<```L#``#.`0``!`$``,T$``#M`0``P0$``.(!
M``!C!0``<0<``,@%``"!`````````-`%``"/`@``&P4``!4'```2`0``=@``
M`*P&``!0!@``9@0``%<$``!<````F`(````````1`@```````!0&``#>!@``
M`````#(&``"J`P```````+@!``"M````;0<``)T$````````:@0```````#2
M`@`````````````\`@``/P,```,#``!%`P```````$T'`````P``M@$``($$
M```'!0``^`(``#H!``"*!@````````````#_!0``(@<``!8"``"Q`0``````
M`````````````````-0"``"3!@``O08``/<```!#`@``>P```(D&``!$!```
M@0<``(T%``#+!```?P```,D"```.!@````````4$````````K`(``$8"````
M````3P(````````1!P``80$``%X!``#(!```^````%8"``!$!0```````$,%
M``#.!``````````````D!P``*P,```````!C!P```````,`$```?````QP8`
M`(@```"Y`P``Y@0``/T$``#8`0``M08``.4&```U!0``?08``&(&``"N!@``
M\0$``#<'````````'0```+@#``"2!0``?`<``````````````````,,&``!I
M!```(`8````````;`0``.0<``/D%````````2`8``-8"```J````````````
M```R`0``!`0````````````````````````=`0``M`<``,0!``"E````<```
M`#4&``!D`@```````/D"``#/!0``408````````K!P```````$T!``!P`@``
M5P,```````#2`0``X`(``$X!````````#P<``#````#N!@``Y04``(4```#V
M`0``904``.8``````````````*$"``````````````````!3!@``TP8```L!
M```M````1P,```````#0!```S`4``!8&```O!@``PP$``%@%````````+P4`
M`+L`````````2`,```````!)`@``"08```````!^`0``,P$``&$%```$!@``
M%@````````")`@``;P4``"T%``"+!P```````(\'``!Q!@``*00````````&
M````5````(,#``!`!0``_P````````!"!0``?`8``&H`````````C0``````
M````````F@$````````U!P````````T#``!S!P```````/P"``!U````.08`
M`,$#``"^````,@(``#<"``")!```#`0``)L#``#I!```C@<``&4&``#M`@``
M1@```*T'````````C@```%8'````````R08``!,&````````W04``!H```#J
M!0``A`$```````#R`P``10`````````8!P``U@$```````"*`P``````````
M``#R!```V0(``"<"``"I`0``D@$``"L%``#B`P```````-T&``"W!0``(08`
M`-$````\!P``%`$``#,#``"J!0``NP$```````"W`0``LP<``/H#``"@!```
M,@4``(P````*`@```````"D```!+`0``H`(``((%````````1@8``&L'```X
M!```0P$```T'````````'P(``"@#``"]`0``R`,``,$$``"3`@``K`<`````
M``!U!```]````,T!``#0`P``/04``*<"``">`````````#,"``"G!@``.`,`
M`/$```"?!```_@,``*0%````````H@4```````!1!P``DP<``,,```#!`@``
M`````(@$``"%!0``Y`8``%<%```X````)`(``"0#```,!0````4```````!@
M`0``V`0```````!.!P``IP```*$!``#9`P````````````#:`P``[@,`````
M``#B!@``OP(``-8#``!Q`0``;0,```(%````````!0<``),#``!7!@``WP$`
M`/(!`````````````#8%```*!```N@$``'`%``!6`````````(L#````````
M20,```````"U!0``7`0`````````````+P<```````"5!@``````````````
M````=P<```````!D!@``Y@$``(\$```B````_0$``+@$``!5`0``"`(``$`'
M```V````C@$``%\!```L`P``4@<``/D&```M`@``\P(````````!!```I```
M`!P&````````GP,``&`$````````[@```.P"````````M@``````````````
M`````-4$```````````````````3!P```````&$"``!*!@``*P0```@$````
M`````````,`"````````N0``````````````9P(```H'``!;`P``5`,``)H%
M````````<04``"\$``"S!0``.0`````````^!P```````%8%`````@``````
M`-T#``"N!P``P`,``$@!``"(!P``>P4``*4"``!0!```404``&\"``"``@``
M``````@```!N````(P<``/L&``!5!```\P4``.X"```K!@``=P(``#L!``!;
M`0``S04``#P&``#S!@``'P8``&H'``#`!0``AP$`````````````0P```.H$
M````````'````-4"````````A@$``!@$````````6P8``%,'``!X`P``````
M`%$#`````````````.4```"<!0``/P0``````````````````-D`````````
M]0$``%L'``"X`@``K`,``'\'``!%!@``Z@,````````"!P```````.,%``"[
M`P``U```````````````A@0```````!5`P```````&T&```@`P```````+`#
M``"\````````````````````)P4``'8#``!>!P``R````)<%```J`0``80,`
M```````X`0``FP4``(L&```[````E@(```````!X!@```````,8````2`@``
M(@0``*(&```-````8`,`````````````+00``'D%``"?!@``/P(````````'
M````QP$``%(!``"M!```\0,``!4#````````.0$``*H'``">!@``[P4``*D%
M``",`@``%@0``,4%``!(`@``/P$`````````````>@0``%L```!L`@``&@<`
M``````#7`@``Q@8``(4'``"I`@``4`,``$D!``"P!```*@<``,L````1`0``
M>08``+D&```!`0``Z0````````"?`@```````#0#``!G````X0,``)X"``!.
M!0``(P$`````````````1P8``$$````C!0```````.P%``#W!@``6@0``!H&
M````````W@,``"H%``"``P``Y0$``)P'``!"`P`````````````H!```E@,`
M`+$&``"W!@``K`0```H!````````AP0``.,$``"$!```'`<``%4```#0`@``
M_`,``'P$``#S`P``O0,``#4"````````>P8```````"Y`0````````````#0
M`0``G0(``.P!````````_@8``,D#``#B````;P8``'@```"<`@```````#P`
M``"9!@``900``+```````````````'`'``#;`P```````+D$````````6`0`
M`%\%``#9!@```````&D#````````/`$``($#````````3`,``#\'````````
M2P8``'X#````````S`$``!X```!?`P```````&$'```R!```QP,``.$!```)
M!0``1@$```4```#>````#0(```D"````````8P0```````!?````D0<``&T"
M``#*`P``G0,``$@%```9!0``1`(```````!T`P``00<``*,```!<`P``Q`,`
M``````";`@``E`4````````"`0``1@0``+("``#"``````````````#8`P``
MZ0(``*D'``#;`@``]`$``"8$``!/`P```````,4#````````C0$``'8"```M
M!@``V@```#0$````````;`$```````"*!0``?`````````":!@``.P0``(<%
M```A`0``XP8``%`%``",!```8P(``.D!``````````````\"````````;0``
M``````#/`P``9@,``-<$``!5!0``B0,``.\#``!'!```@`8``"@!````````
M`````-\&````````\@4``,\````9!P```````&8&``"_`P``C`$``)\!```T
M````>00``!`&```J`P``E@8``&X'``!-!````````!\$``!5`@``````````
M```L!0``H08``(8%```4````Q`4```L%``!R!0```````!<!``"#`@``8`8`
M```````2!@``Q@$``(X%````````[0```&("``!4`@```````!T"``#``0``
M``````````"I`````````.$%`````````````",&````````(P``````````
M````YP$``#4$``"Z!`````````\$``"%`P``9`$```````!]!````````-H"
M``#X`0``1P(``'8%``#;`````````+T%``#Z````)@<`````````````````
M`((&``"9!0```````'H"``"F`@``_P8``+(#`````````````$<'``!(!```
MC`<```````!.````&0(```````#N!0``=P4``#H'````````HP4```,"``"Z
M`@``EP,```````"O`@``.00````````2!P``;@$``,X```#G!0``V04`````
M``#G````>P(``%,$``#2!`````````8'```.`@``XP```#H"```B`@``<P(`
M`#\```!T!0``@@```)D"````````3P4``.<&`````````````)@%````````
MRP8````````1!@``DP0``)4$````````^0```!,%``#(`@``600``'0```!A
M`````````$4"``#A!````````%D!``!#!@``%`(`````````````=`(`````
M```G````%04``#P#```=!0``M@,``*0'``!&!P``OP```)H'````````WP(`
M`+<$``#3`@``E0,``%X```#[!0``J`````@&````````&P,``*`#````````
MR@0```<'``!2!@````````````!H`0````````````!H!0``HP,``$H'```@
M`@```````/4```#&`@``_0```%X$````````5@0`````````````2P(``.@%
M``"[`@``(`$``,L"``````````````````"^!`````````0#``"0!P``````
M`!\#``#&`P```````)$$```>!```>0,``+8&``"%!````````$H#``"B!```
M`````$X$``!O`P``P04``'(&``!R````(P0``)X%````````G`$``%H'````
M````Y`(````````%`0``1P4```````!,`````````/8"``!S!````````#('
M``!J`@``_P(`````````````*`<````````A!P```````&X#``!^````````
M`)8!``#1!@``"`$``+P"````````\@````````!Q!```C0(``*4!``!J`0``
M`````($"````````?@<``'X&```*!0``G0`````````&!0``B@```!H%``#>
M!0``40```*$%``!9`P``+@,```L$``!3`P``J`,``"(%````````004```<&
M```9`0``.P4```````!3!0``W`,``)4'``"X!@``R@(``,X&```]!P``4P$`
M`#0&``!%!0``!@(``',#``!U!0``>@<``#(```!6`0``7@4``+\!``!;`@``
M`````&<%````````B04``&(#``"4`0``D@,``+H#``!_`0``$`4``&\$```P
M!````````,X"``#.`P```````(<"```^`0``_P,``#<$``!W!@``)0,`````
M````````Q0$``)X'``"%!@``4@,``,0```#K!0``-P8``-,```!\`0``]`0`
M````````````XP(``+<```!<`0``M@(``-\```!U`P``RP,``+P%```N`0``
MB`(``'H&``#``````````,<```"*`0``#P8```````"&`P``D04``%P'````
M````6@```)@```".!```,04``&<&```[`@``(P,``/T&```E!@``$`0``)($
M```=`P``+`(``'(#```;`````````,P#`````````````/@#``"0!0``H@$`
M`*0"````````K0$``&<!``!W!`````````P"````````)0(```````"6!P``
MJP0``&($``")`0``L@0`````````````DP4`````````````;@4```````!P
M!@``J00``*<$``##`@```````-X$```5`@``R@4``$``````````````````
M```%`P``D0,``&<$```9!@``C@8````````7!P``>0(``'@$``!:`@``]P0`
M`-(%````````8@```!H#``````````````````!@!0```````(P&``#G`P``
M;`0``-0#``#S`````````,D%``";!P```04`````````````'@$```````":
M!```>@,```````!G`P```````#P$````````CP```)H````F!0``0@<``)T'
M``!;!0``[00``#T#``!2````/@(```````"J`0``?@0``,@&``#)!```````
M```````;!P````````P#``#M!@``C08````````.`````````(\%```S!```
M`````,D```#\!0``704``(@#````````#@,``"@&``"C`0``M`4``%`'``"\
M!@``8@$``&P%```Z!````````$D'````````70,```0"``"C!```%`4```,&
M```````````````````M!P``XP,``,T#``"U`0``800``/P!```]`0``````
M```````S````30(``"H&``#3!0``D`0``"X'````````SP(``&P&``!5!@``
M$@0``"X$````````>P,``/L```#4!@``1P```'8'``#Q!0``[@0``!<$```L
M!```JP(``+0&````````6`<``$$$``"1`@``@@<``)@'````````N`4```T%
M``!Z`0```````!0$```,!P`````````````%!@``L04``)\'```%!0``````
M``$#``#2`P``Y`4``&0%```R`P``(00``,,%``"2!@`````````````/`0``
M`````#H%````````3P$``(8```!N!```!`4``$<!``#%`@``1````#D#``"$
M!@``Z0,```8&``")````)`0``)X!``"^!@`````````````>`@``(```````
M```J`@``D08```8$``!Z!0``)@$`````````````L0```#@&````````H0,`
M`.0!```)!`````````````#/`0``[P(`````````````C@(``&L#``"H!@``
M6`$```````"Y`@``6````"@"``#2!@``KP<````````'!```NP8``.8&``!3
M````@@0```````"P`@```````#8!```H````IP$```X$``!5!P``BP0``-P%
M``#S!```'`(``.T%```S!P``7`4``*8``````````````$`#````````````
M``````#P!```L00`````````````7@,``/\$```F`@``;````-0%``#0````
M`````(0'``"J`@```````````````0``BP4``(X#``!<!@``:P$``(`'``"0
M!@```````'0$`````````@(``+0#```=!```ZP0``!X#``"J!```VP8``$P!
M````````C0<````````Q`P```````````````````````.P`````````````
M`#X`````````]08```````!``@``Q`8``%H&```7!0``K04```````"!!0``
M\00```````"&!@``:08``*`'```9`P``!P(````````4!P``/0```*<#````
M````CP8``*@!````````````````````````#08``*L!``"'````D@(``($!
M``!\`@``I00``/P&````````CP$``-P&```+````W00``,0"``"X````O`$`
M``````!7`@``<`$``"$#``"M`@``;@(```````"%`@``UP$``.L&````````
MS`0``,4$``"4````8@<``/4"``"4!```200``*X$```F!@```````)4%````
M````KP```)(`````````M0```'L'`````````````$T%``"Z````G@0``!H!
M```2````4P(``#D%```3!```K````&D%`````````````/4$````````J`0`
M`,D!``````````````(&``"E!0``W@$```(#``!\!0``````````````````
MQP4```,'``!=````RP$``"H$```W`````0<``*@%``"@`````````/<#``!R
M`0```````,$&````````"@,``+('``#;!0```````+4$``!O!P``>`<``-<%
M````````-P,``#0!``#P!@`````````````M`0`````````````8!0``UP8`
M`.(%``!4!```=P$``+<#``"O`P``TP0``+8%``!:`0````````````"M!@``
M'`$````````2!0``E0```#4````G!P``,0``````````````2@```"$%``!$
M`0``A`(``$\&``#S`0``$0`````````N!0```````*(```!1`0``60```(4!
M``!&`P``[`8``+T"``"1````:P(``+D%``#D````Y0,``"8#``!!`@``%`,`
M`/X"````````QP(``#`&```?!P``608``.8"``!Z````Z@```&@'````````
M.0(```````!M!0``=@8``$$!```<!```=0$```````#<````[P$```<!``"#
M!0```````-$#``!O`````````-\%````````604``/$"`````````````'8$
M``#V!@``LP$``((#``"9!````````%T&``#X!`````````````#7````EP8`
M`/8%``#V!````````!H$`````````````"D&``!R`@``L@```),```"'!P``
MTP,``!4&````````^0,```````#;!```]0,``(,$``!]`@``F0```+T$````
M``````````($``#/!@``D`$```@#``#^`0``M`$``.\````@!```````````
M``#@````````````````````JP4``&D````8`0``B`8``'T'``""`0``%P(`
M`)<"``#?!````````/D$````````2P````````!D`P``/08`````````````
ML`4``.4$```D!@``````````````````-@,``,H```!"!```?P4````&````
M````Z`,```@%```P!P``G04```````!.`P``X`,``)$!``!7!P``````````
M``![`0````````````"J!@``6`(``/L#``!,!```9@````0'``"R`0``I0,`
M`)@$``!L!P``@08``!(#``!O`0``U0```"\!``#:`0```````$(!````````
M)P8`````````````GP````````#Z`0``^P$``(@%``#@!```.@```/0"``#H
M`@``=`<``$`$`````````````'@"``"4!@```````&$&``#+!0``4```````
M``"B`P``$`,``,T&``!]`0```````-(```"R!@``B@(``,4`````````````
M`#T"``!=!````````.("````````=`$```````!(````ZP```*X```!I`0``
M`````&,!```T`@``MP(`````````````9@4``$D%``"N`@``6P0``*L'````
M````````````````````=`8``$D&````````]@```&H&````````6`8``#0'
M````````+@```(P%```#!0``T`8```````!+!P``+@(```X%``"4!P``P@0`
M`$0&``"F`0``XP$``*L&``!Q````+P,``.X!```/````U@8``/H&``"9!P``
MHP8```4"``#&!0``U0,``)L!``"_!````````/H$``"Q!P````````````#E
M`@``I08``-<#```.!P``)P$```````!`!@``;`,``"$```"T``````````X!
M````````%P,``$$&``````````0``/("````````H0<``%0%``!^!0``````
M`'P#``"^`0``#`````````"H!P``6`,``#L#````````9@$``,X%``!R!```
M`````#$$``#5!0``P@8```````!/!P``7@8``$4'``#K`P```````&L```#I
M!@```````,(!``#V`P```````-H%``#J!@``:P8```````"'!@``70$``/L"
M```Q`0```````"\"``"@!0``[P8``,("```&`P``"0,```````#G`@``7P<`
M`/`#```;!```G08``/\!``!_!@``4@4``%\$``"`!```%@$``"4`````````
M`````*L#``!"``````````,`````````/00``*\&```Q!@``,`(``!4!````
M````<0(```````#-`@``%00``&0'````````V`4``&T$``";````.@,``/`"
M````````,0<```````!]`P`````````````3`0``@@(```````!1`@``````
M``````#T!0```````*L`````````D`,``/P$``"_!@``WP,``%D"```*!@``
M`````-X"``````````````````!,!@``F`$``'('````````&0```$\```!H
M!@``\`$``'8!``"2!P``J`(``%D'``!%!````````-4&``#K`0```````%T"
M```8`P``E@4``)L$``"F!````````"`%``!$`P``/@4``$L%``#Y`0``````
M`*`&````````[P0``/0&``#H`0``!P,``!P#``````````````````":`P``
M<P4``"$"```=!P``LP,````````I`P``1@4````````@!P```0(```````!`
M`0``F`8``%P"``"(`0``)00``(D'``#,!@``Z``````````L````:0<``#8$
M``````````````````#W!0```````$H%```&`0``BP```&,#```B`0``U0$`
M``````#@`0``:P4``'`#``"S!@``$P(``(T$````````&P(```````!+`P``
M3@8`````````````EP<``(H$```/!0``A`,`````````````+`<``#@"```T
M!0``,`4`````````````````````````````Y@4``&,&``"<!@``*P$``$,'
M```>!@````````````"U`@``_0,`````````````A`4``+$#``"'`P``````
M`-P$````````LP(``'L$```+!P``+`8``#H&`````````````&@#``!P!```
M``````````!6!@``_@```,\$````````P@,``,H!```>!0``=0<`````````
M````*0<```````#H!```:@4``!P%``!Y````\@8```````#@!@```````$T`
M```!!@``:0(``(\#```(!P``=P```,`&```)````I`$``#`!``!]````'@<`
M`',&``#"!0``W0(```````"_!0``.`<``+(%``"C!P``D````-8%``"M`P``
M-0$``)H"```I`0``/@8``$P"``",`P```````!T&``#B!```BP(``"D"````
M````B@<``'X"`````````````````````````````$,$```7!@``E@0```\#
M``#Z!0``5`<``!$%``"I`P``9````(,````S!@``L`<``"\```"`!0``````
M`/X$``#J`0``Z`8``/P```#Q!@``8`<``%8#````````[`,``#<%````````
M90(``&4``````````````"L"``##!```LP```&8"``"L!0``$````!\%````
M`````````#`#````````^`8``,T`````````+`$``)4!`````````````-@"
M````````EP0`````````````]04````@("U-+"`M+6UE<W-A9V4]34534T%'
M12`@57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F
M875L="!O;F5S+@`@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!0
M3R!F:6QE('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&\*("`@("`@("`@
M("`@("`@("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A(&1I
M9F9E<F5N="!B<F%N8V@@=&\*("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&=E;F5R871E9"!C;VUP96YD:75M+@`@("UB+"`M+6)A<V4]+U!!5$@@($9U
M;&P@<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H
M;W5L9"!B90H@("`@("`@("`@("`@("`@("`@('5S960N`"`@+6,L("TM8V]M
M<&5N9&EU;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H:7,@
M8V]M<&5N9&EU;2!F:6QE"B`@("`@("`@("`@("`@("`@("`@("`@("!I;G-T
M96%D(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4*
M("`@("`@("`@("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2X`
M("`M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@
M9FEL92!I;G-T96%D(&]F('1H92!D969A=6QT"B`@("`@("`@("`@("`@("`@
M("`@("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I
M<F5C=&]R>2DN`"`@+60L("TM9&5B=6<@("`@("`@4VAO=R!E<G)O<B!M97-S
M86=E<R!F<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RX`("`M9"P@+2UD:7)E
M8W1O<GD]1$E2("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O
M<GDN`"`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G
M92X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY('1H:7,@;&]C
M86QE+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE
M+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N`"`@
M+6TL("TM;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D
M=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R86YS;&%T
M:6]N<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@365R
M9V4@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S(&]N;'D@
M9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,
M12`@("!5<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M
M+6UO9'5L93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$
M;VXG="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP96YD:75M
M+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N
M9&EU;2X`("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A;G-L871I
M;VX@<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N`"`@+70L("TM=&5S="`@
M("`@("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U
M;B!A;GET:&EN9RX`("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S
M('5P(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+@`@
M(&-O;6UI="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S
M97)V97(N`"`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE
M($-64R!S97)V97(N`"`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N
M9&EU;2!F:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE"B`@("`@
M("`@("`@("`@8W5R<F5N="!C;VUP96YD:75M+@`@(&5X=')A8W0@("`@($=E
M;F5R871E(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RX`("!H96QP("`@("`@
M("!3:&]W('1H:7,@:&5L<"!M97-S86=E+@`@(&EN:70@("`@("`@($-R96%T
M92!O;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N
M:6YG.B!4:&ES"B`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I
M;F<@4$\@9FEL97,@;V8@=&AI<R!L;V-A;&4N`"`@;6%K92`@("`@("`@0G5I
M;&0@8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!03R!F:6QE
M<RX`("!M86ME+6AE;'`@("!-87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@
M:&5L<"!F:6QE(&)E:6YG('5P+71O+61A=&4@86YD"B`@("`@("`@("`@("`@
M<')E<&%R92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P
M9&%T92UH96QP+B!9;W4*("`@("`@("`@("`@("!S:&]U;&0@;VYL>2!R=6X@
M;6%K92UH96QP($%&5$52('5P9&%T92UH96QP(&%N9"!R979I<VEN9R!T:&4*
M("`@("`@("`@("`@("!H96QP(&9I;&4N`"`@;65R9V4@("`@("`@365R9V4@
M=&AE(&-U<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L
M871E(&9I;&4N`"`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E
M('-E<75E;G0N`"`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C
M:&%N9V5D(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<`H@("`@
M("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I
M;F<@;VYE<RX`("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y
M<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI
M`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E
M9"!B>71E<R!W<FET=&5N+@`E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U
M<"UT;RUD871E`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI
M;FES=')A=&EO;@`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC
M92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@
M57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E
M<R!A="`E<R`E<P`E<R!H87,@8V%N8V5L;&5D("5S+@`E<R!H87,@<F5P;&EE
M9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E<R!H87,@<F5P;&EE9"!T;R!T
M:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S('-E;G0@>6]U(&9R964O8G5S
M>2!I;F9O<FUA=&EO;BX`)7,@:7,@;F]T('=R:71A8FQE+@`E<R!I<R!R97%U
M:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@;F]T(&9O=6YD+B!2
M=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I<G-T+@`E<R!R97%U97-T<R!Y
M;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P
M<F5S96YC92!A="`E<RX`)7,@=&\@)7,@;V8@)7,`)7,@=VES:&5S('1O(&%D
M9"!T;R`E<RX`)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E
M<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B
M;W5T("5S+@`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`G)7,G(&ES(&YO="!A('9A
M;&ED(&-H;VEC92X`)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN`"<E<R<@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"<E
M<R<@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@
M8W)E871E9#H@)7,N`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,`+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\
M9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RX*3W!E;FEN9R!T
M86<@9F]U;F0@:6X@;&EN92`E9"X`02!D871A8F%S92!B86-K96YD(&ES(')E
M<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3
M:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN
M+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P="!R97%U97-T`$%C8V5P=&5D
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!
M8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@0VAI
M;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.
M97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P
M('1O("<E<R<`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G`$%D9"!A
M(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1H
M:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O
M(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`G)7,G('1O('1H92!S
M>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN
M9F]R;6%T:6]N.B`E<RX`061D960@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!N97<@9FEL97,@=&\@<F5P;W-I=&]R
M>3H`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@
M0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!
M;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT
M:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F
M;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E
M<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E
M<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!
M;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!3
M86UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`
M06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C
M=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T
M:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD
M(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC
M("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M
M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E("<E<R<@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI
M80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES
M;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A
M<B!F:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@<V5N=`!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD965S`$%T=')I8G5T97,`075G
M=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA
M8FQE(&9I96QD<SH`07=A:71I;F<@4F5S<&]N<V4`07IE<F)A:6IA;@!"3T9(
M($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B
M97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S
M`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B
M861O<P!"87)E`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O
M=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E
M<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I
M;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`
M0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S
M<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A
M;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6EL9&EN9R!-
M3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN`$)U:6QD:6YG(&QO8V%L92`E<RXN
M+B``0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD
M:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E
M<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN
M;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E
M<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E
M<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A
M9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A
M=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE
M`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE
M<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T
M*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R
M;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF
M:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V4@>6]U
M<B!P87-S=V]R9`!#:&%R`$-H96-?:R!,:6YK+BXN`$-H96-K('1H92!B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S
M=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@86-T:6]N.@!#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y
M<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A;FEN9R!U<"!03R!F
M:6QE<R!F;W(@;6]D=6QE("5S+BXN`$-L96%N:6YG('5P(&QO8V%L92`E<RXN
M+B``0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R
M`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM86YD(&]P=&EO;G,Z`$-O;6UA
M;F1S.@!#;VUM96YT`$-O;6UI='1I;F<Z`$-O;6UO;B!.86UE`$-O;6]R;W,`
M0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!-97-S86=E("@E<RD`0V]M<'5T
M97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF
M:6=U<F%T:6]N(&YE961S('5P9&%T:6YG+@!#;VYF:6=U<F4@)7,`0V]N9FER
M;2!087-S=V]R9`!#;VYF:7)M(&YE=R!P87-S=V]R9#H`0V]N9V\`0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT
M<R!O9B`G)7,G`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#
M;W!Y('-E;&5C=&EO;@!#;W!Y:6YG("5S('1O("5S`$-O<W1A(%)I8V$`0V]T
M92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,`0V]U
M;&0@;F]T(&-O<'D@)7,@=&\@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER96-T
M;W)Y(&9O<B!L;V-A;&4@)7,Z`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T("<E<R<N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D
M<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O
M9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y
M("<E<R<N`$-O=6QD(&YO="!M:V1I<B`G)7,G+@!#;W5L9"!N;W0@;V)T86EN
M('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E
M;B`E<RX`0V]U;&0@;F]T(&]P96X@)R5S)R!F;W(@=W)I=&EN9RX`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T
M(&]P96X@9&ER96-T;W)Y("<E<R<N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C
M="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#
M3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@)R5S)RX`0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`G)7,G+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C
M:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@)R5S)RX`0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A
M=&EO;B!F;W(@)R5S)SH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3
M:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N
M)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@)R5S)SH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E
M<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T
M92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D
M(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!0:&%S90!#=7)R96YT(%1I
M;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N
M9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#
M>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I
M;'D`1&%T80!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$
M871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C
M:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN9&5N=`!$969A=6QT
M`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%!E<FUI
M<W-I;VYS`$1E9F%U;'0@<&5R;6ES<VEO;G,`1&5F:6YI=&EO;G,`1&5L96=A
M=&4@<&]S:71I;VX`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@1W)O=7``1&5L
M971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G`$1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E
M;&5T92!T:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_
M`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`1&5L:79E<GD@
M=&EM90!$96YM87)K`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R
M964O8G5S>2!I;F9O<FUA=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C
M=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I
M`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB
M;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`
M1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R
M;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D
M:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M
M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@
M9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET('!E<FUI<W-I;VYS
M(&9O<B`G)7,G`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT
M+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%
M;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M
M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/P!%;F0`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET
M>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E
M9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N
M86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%
M;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E9"!C
M:&%N9V5D+"`E9"!U;FMN;W=N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`
M17)R;W(`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`G)7,G+@!%<G)O<CH@`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X96-U=&EN9SH`17AP86YD`$5X<&%N
M9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!%
M>'1R86-T:6YG(&9R;VT@)7,N+BX@`$9'($-O;&]R`$944"!U<&QO860@;V8@
M<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE
M9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;'5R92!I
M;B!C:&%N9VEN9R!P87-S=V]R9"`Z(`!&86ER`$9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F5B
M<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W
M(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE($-O=6YT.B`E
M<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE
M($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S
M(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I
M<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E
M<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P
M87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`
M1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1F]U;F0@87!P;&EC871I;VYS
M.B`E<P!&;W5N9"!D:7)E8W1O<FEE<SH`1G(`1G)A;65S`$9R86YC90!&<F%N
M8V4L($UE=')O<&]L:71A;@!&<F5E+T)U<WD@26YF;W)M871I;VX`1G)E92]"
M=7-Y(%)E<&QY`$9R964O0G5S>2!297%U97-T`$9R964O0G5S>2!297%U97-T
M(%)E<W!O;G-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$
M97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9U>GIY`$=A8F]N`$=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;F5R871I
M;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BX`1V5O<F=I80!'97)M86YY`$=E
M=&]P="!%<G)O<CH@`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O
M961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E3
M3RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T
M:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI
M<W-I;VYS`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T
M8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2$@`2%1-3`!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL
M(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H
M;0!(87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I
M;F<@961I=&]R`$AE;'!E<@!(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E
M(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D90IF<F%M
M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N"D9O<B!A;B!I;G1R;V1U8W1I
M;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O<GDN`$AE
M;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(
M:6=H`$AI<W1O<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM96UP='D`2&]?
M;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D
M9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R
M9&4@=')A;G-L871I;VX@9V5N97)A=&]R`$AO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S
M("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E
M("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I
M>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(
M;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I
M='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R
M97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@
M=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T
M:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC
M;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS
M('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE
M8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@
M>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@
M>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ
M`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E
M('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD
M.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@
M069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN
M8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I
M80!);F9O`$EN9F]R;6%T:6]N`$EN:71I86QI>FEN9R!M;V1U;&4@)7,N+BX@
M`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B
M;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E
M`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C
M96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E
M<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L
M=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A
M9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R
M`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R
M('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G
M90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S
M96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R
M961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!!8W1I;VX@<V5L
M96-T960@9F]R('1H:7,@8V]M<&]N96YT+@!);G9A;&ED(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A
M=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M
M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`G)7,G
M`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N
M`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T
M960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC
M80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y
M`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T
M:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A
M;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T
M960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO
M;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A
M9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`
M2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!1=6%R=&5R
M`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,
M96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE
M861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@
M4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!2
M86EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W
M`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@
M=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE
M;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``
M3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,
M:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI
M=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<@;&EB<F%R:65S+BXN`$QO861I
M;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S
M92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R
M<F5C=&QY+@!,;V=I;B!F86EL960N`$QO9V]U=`!,;VYG('1E>'0`3&]V90!,
M;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO
M=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@
M071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D
M;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S
M8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA:V4@
M<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS=&%L;&5D(&%N9"!I;B!Y;W5R
M(&EN8VQU9&4@<&%T:"X`36%K:6YG(&1I<F5C=&]R>2`E<P!-86QA=VD`36%L
M87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R
M-"!M87``36%P475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E
M`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL
M;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365E=&EN9R!#
M86YC96QL871I;VX`365E=&EN9R!);F9O<FUA=&EO;@!-965T:6YG(%!R;W!O
M<V%L`$UE971I;F<@4F5P;'D`365E=&EN9R!5<&1A=&4`365E=&EN9R!5<&1A
M=&4@4F5Q=65S=`!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365R
M9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@`$UE
M<F=I;F<@;&]C86QE("5S+BXN(`!-97)G:6YG('1H92!03R!F:6QE(&9O<B`E
M<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!T<F%N<VQA=&EO;B!F
M;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C
M97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N
M;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E
M`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=&AO9"`G)7,G
M(&ES(&YO="!D969I;F5D`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`
M36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N
M+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA
M:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L90!-
M;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-
M;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`
M36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N
M;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V
M92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R
M=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R
M964`3F%M90!.86UI8FEA`$YA=7)U`$YE961S($%C=&EO;@!.97!A;`!.971H
M97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%52
M3`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI
M8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I
M;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T
M:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T
M=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O
M;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S
M<W=O<F0Z`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE
M>'0`3F5X="!086=E`$YE>'0@4&AA<V4`3F5X="!O<'1I;VYS`$YI8V%R86=U
M80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@
M8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&0@<&5R;6ES
M<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN`$YO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O
M;6UA;F0@<W!E8VEF:65D+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`
M3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!E
M;G1R>2!W:71H('1H92!I9"`G)7,G(&5X:7-T<R!I;B!T:&4@;W)I9VEN86P@
M:&5L<"!F:6QE+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.
M;R!L;V-A;&4@<W!E8VEF:65D+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&UE
M<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@
M<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN
M`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`3F\@<VED
M97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE
M+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@
M6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@
M:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`
M3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I
M`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.
M;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S
M=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.
M;W1I8V4`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+
M`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8FIE8W0@8W)E871O<B!P97)M:7-S
M:6]N<P!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@
M<&%S<W=O<F0Z`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@
M96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O
M=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@
M<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<'1I;VYS.@!/<F1E<F5D($QI<W0`
M3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T
M97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI
M<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!0
M1U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0
M=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`
M4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-
M(%-N;W<@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`
M4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO
M=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960A`%!A<W-W;W)D(&EN8V]R
M<F5C=`!087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R
M960`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N
M=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI
M<W-I;VX@)R5S)R!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VX`4&5R;6ES<VEO;G,@9F]R`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E
M<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX
M96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@
M=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O
M(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!0;&5A<V4@<F5V:65W('1H92!F;VQL
M;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@
M9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('-E;&5C="!A;B!A8W1I;VX@
M9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E
M9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E<V5N=&%T:6]N<P!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R979I;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0
M<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O8FQE;3\`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC
M($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP
M86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1
M871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE
M8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!2
M86EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I
M;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R
M(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!2
M96QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E;65M8F5R('1H92!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E
M($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E
M(&9R;VT@;7D@8V%L96YD87(`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V
M92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO
M=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5P;'D@4V5N="X`4F5P;'D@=VET
M:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@
M9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O
M8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DZ("5S`%)E<75E<W0@8V]U;&1N)W0@
M8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75I<F5D("<E
M<R<@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G)7,G(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"!&:65L9`!297%U:7)E9"!087)T:6-I<&%N=`!297-E=`!297-E
M="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5S=6QT
M<R`H:6YC;'5D:6YG($AO<F1E*3H`4F5S=6QT<SH`4F5T=7)N('1O($]P=&EO
M;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I
M=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@
M=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E
M(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`
M4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U,`4U-(`%-50T-%4U,`4U]1
M3"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES
M`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I
M`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L
M;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@
M)R5S)P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`4V-I96YC90!396%R8V@`4V5A
M<F-H($5N9VEN97,`4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E
M<P!396%R8VAI;F<@9V5T=&5X="!B:6YA<FEE<RXN+@!396QE8W0@1FEL97,`
M4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@
M;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D
M9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C
M=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!,871E<W0@26YF;W)M871I;VX`
M4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@
M`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E
M<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N`%-E="!T:&4@;&%N9W5A9V4@=&AA="!M96YU(&ET96US+"!E>'!L
M86YA=&EO;G,L(&%N9"!H96QP(&%R92!I;BX`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W
M`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO
M=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@
M3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VX@=7`@:68@;F]T(')E9VES
M=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E
M`%-I>F4`4VMI<"!-86EN=&5N86YC90!3:VEP<&5D+BXN`%-L;W9A:VEA`%-L
M;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO
M=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L
M:6$`4V]M92!O9B!087-S=V]R9"!M;V1U;&4G<R!C;VYF:6=U<F%T:6]N(&9I
M;&5S(&%R92!M:7-S:6YG.@!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L
M96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@
M<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P
M;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA
M;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!Y96%R`%-T871E
M(&]R(%!R;W9I;F-E`%-T871U<P!3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B``
M4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3
M=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL
M92!;0U-370!3=0!3=6)D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`%-U8FIE
M8W0`4W5B:F5C="!0=6)L:6,@2V5Y($EN9F\`4W5B;6ET`%-U8FUI='1E9"!R
M97%U97-T('1O(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T
M(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N
M`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@)R5S)R!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D
M("<E<R<N`%-U8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L
M;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@
M)R5S)P!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@
M4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N
M<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U
M<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA
M;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!4
M4U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I
M97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A
M;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`
M5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A
M='5R90!496UP97)A='5R93H@`%1E;7!L871E("<E<R<@;F]T(&9O=6YD+@!4
M96UP;&%T92!!9&UI;FES=')A=&EO;@!496YT871I=F5L>2!!8V-E<'0@<F5Q
M=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497AT`%1E>'0@3VYL>0!497AT
M(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA
M;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@)7,@:&5L<"!F:6QE
M(&9O<B`E<R!D;V5S;B=T('EE="!E>&ES="X@0W)E871I;F<@82!N97<@;VYE
M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C86QE
M;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0
M('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I
M9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I
M=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I
M;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T
M('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&5V96YT(&AA<R!B965N(&%D
M9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@
M;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T
M;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@
M=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA
M<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T
M96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E
M(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W
M86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:&5L<"!F
M:6QE("5S(&1I9&XG="!S=&%R="!W:71H(#P_>&UL`%1H92!I9&5N=&ET>2`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY
M`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV
M96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L
M87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H
M87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W
M86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O
M;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R
M=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E
M<R!N;W0@97AI<W0N`%1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@
M=&%S:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I
M9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@
M<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@
M;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N
M9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N`%1H97)E(&1O97-N)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE
M(&9O<B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T
M:&4@<WES=&5M+B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S
M)R!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M
M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`G)7,G.B`E<P!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W
M87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L
M;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@=&%S:SH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@
M97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L
M871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M
M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N
M(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E
M;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL
M("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@
M5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R
M97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE
M(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L
M=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A
M<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V
M86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S
M-&%F)RX`5&AI<R!F:6QE(&-O;G1R;VQS('1H92!D969A=6QT('!R969E<F5N
M8V5S(&9O<B!087-S=V]R9"!M;V1U;&4L(&%N9"!A;'-O(&-O;G1R;VQS('=H
M:6-H('!R969E<F5N8V5S('5S97)S(&-A;B!A;'1E<BX`5&AI<R!F:6QE(&-O
M;G1R;VQS('1H92!S='EL97-H965T('1H870@:7,@=7-E9"!T;R!S970@8V]L
M;W)S(&%N9"!F;VYT<R!I;B!A9&1I=&EO;B!T;R!O<B!O=F5R<FED:6YG($AO
M<F1E(&1E9F%U;'1S+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C
M97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@
M96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S
M('!L96%S92!V:7-I="`E<P!4:&ES(&ES('1H92!M86EN(%!A<W-W;W)D(&UO
M9'5L92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N
M9"!O<'1I;VYS(&9O<B!A;&P@4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N`%1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92X`5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O;2!T:&4@
M8V]M;6%N9"!L:6YE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`
M5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O
M;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@
M8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L
M874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L
M871E9`!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R
M(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI
M`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU
M`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@
M>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD
M80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@)R5S)SH@)7,N`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN
M92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E
M<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O
M<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`
M56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I
M;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF
M:6QE9`!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S`%5N:6-O9&4@
M*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5
M;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+@!5;FMN;W=N(&-O;6UA;F0Z("5S`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E
M;G-I;VX`56YT<F%N<VQA=&5D`%5P9&%T90!5<&1A=&4@)7,`57!D871E(')E
M<W!O;F1E;G0@<W1A='5S`%5P9&%T92!U<V5R`%5P9&%T960@)R5S)RX`57!D
M871I;F<@)7,@:&5L<"!F:6QE(&9O<B`E<RX`57!G<F%D92!S8W)I<'0@9&5L
M971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R
M(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V%G93H`57-E($-U<G)E;G0Z("5S
M`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G
M:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N`%5S97(@<&5R;6ES<VEO;G,`57-E<FYA;64`57-E
M<FYA;64@)R5S)R!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE
M.B``57-E<G,`57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T
M97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N
M=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M
M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E
M<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L
M('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M
M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M90!6:65W(&%S("5S`%9I97<@979E;G0`5FEE=R!T87-K`%9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`
M5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V%R;FEN9SH@`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E
M8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H
M('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED
M=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`
M5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K($%D9')E
M<W,`5V]R:R!0:&]N90!7<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S
M+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@8VAA;F=E('!A<W-W9"!F;W(@
M;W1H97(@=7-E<@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D
M(&9O<B!U<V5R("5S`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@
M861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I
M;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E
M<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@
M86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG
M('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U
M(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG
M;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@9VEV92!Y;W5R(&YE
M=R!P87-S=V]R9`!9;W4@;75S="!G:79E('EO=7(@;VQD('!A<W-W;W)D`%EO
M=2!M=7-T(&=I=F4@>6]U<B!U<V5R:60`66]U(&UU<W0@<V5L96-T(&%N('-E
M<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@
M;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!M=7-T('9E<FEF
M>2!Y;W5R(&YE=R!P87-S=V]R9`!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO
M=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO
M3W!T:6]N("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`
M66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!G
M971T97AT('9E<G-I;VX@:7,@=&]O(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R
M="!02%`@;F%T:79E;'DN"DYO="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A
M8W1E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&YE
M=R!P87-S=V]R9',@9&ED;B=T(&UA=&-H`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L
M(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A
M<W-W;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R
M;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R
M871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L
M<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I
M9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK
M+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S
M<R!B;V]K`&%N(&5R<F]R(&AA<R!O8V-U<F5D.@!C86QE;F1A<@!C86QM`&-L
M:6-K(&AE<F4`9&]N90!F86EL960`9F%L;&EN9P!F:6QE`&9O=6YD.B``9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I,3AN`&EM;65D:6%T90!I;FQI
M;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@
M25-/+@!N86UE`&YO="!C:&%N9V5D`&YO="!F;W5N9`!N;W0@:6UP;&5M96YT
M960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&EX96QS
M`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S
M=&5A9'D`=&%S:R!L:7-T`'1H92!(;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C
M86QE("5S(&1O97,@;F]T(&5X:7-T.@!T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<&1A=&5D`'5S97(@<V5L
M96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@
M<&%S<W=D"E!/5"U#<F5A=&EO;BU$871E.B`R,#`R+3`R+3$Y(#$P.C(S+3`V
M,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-BTP,2`Q,CHP,"LP,C`P"DQA
M<W0M5')A;G-L871O<CH@4F5S86X@4V$M07)D;G5A;2`\:&]R9&5`<V$M87)D
M;G5A;2YN;`I,86YG=6%G92U496%M.B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*`"`@+4TL("TM;65S<V%G93U"15))0TA4("!'96)R=6EK(&1I="!C
M;VUM:70@8F5R:6-H="!I+G`N=BX@9&4@<W1A;F1A87)D(&)E<FEC:'1E;BX`
M("`M82P@+2UA9&0]0D535$%.1"`@("`@5F]E9R!D:70@4$\@8F5S=&%N9"!A
M86X@:&5T(&-O;7!E;F1I=6T@=&]E+B!$:70@:7,*("`@("`@("`@("`@("`@
M("`@("`@("`@=V%A<F1E=F]L(&]M(&5E;B!C;VUP96YD:75M('9A;B!E96X@
M86YD97)E('1A:R!S86UE;@H@("`@("`@("`@("`@("`@("`@("`@("!T92!V
M;V5G96X@;65T(&AE="!G96=E;F5R965R9&4@8V]M<&5N9&EU;2X`("`M8BP@
M+2UB87-E/2]0040@(%9O;&QE9&EG('!A9"!N86%R(&1E("A(;W)D92D@8F%S
M:7,@9&ER96-T;W)Y+"!D:64@9V5B<G5I:W0*("`@("`@("`@("`@("`@("`@
M(&1I96YT('1E('=O<F1E;BX`("`M8RP@+2UC;VUP96YD:75M/4)%4U1!3D0@
M($YI975W92!V97)T86QI;F=E;B!S86UE;G9O96=E;B!M970@9&ET(&-O;7!E
M;F1I=6UB97-T86YD+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:2YP
M+G8N(&AE="!S=&%N9&%A<F1C;VUP96YD:75M8F5S=&%N9"`H8V]M<&5N9&EU
M;2YP;R!I;B!D90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:&]R9&4O
M<&\@9&ER96-T;W)Y*2X`("`M8RP@+2UC;VUP96YD:75M/4)%4U1!3D0@($=E
M8G)U:6L@9&ET(&-O;7!E;F1I=6UB97-T86YD+"!I+G`N=BX@:&5T('-T86YD
M86%R9"T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;7!E;F1I=6UB
M97-T86YD("AC;VUP96YD:75M+G!O(&EN(&1E(&AO<F1E+W!O(&1I<F5C=&]R
M>2DN`"`@+60L("TM9&5B=6<@("`@("`@5&]O;B!F;W5T8F5R:6-H=&5N('9A
M;B!D92!U:71G979O97)D92!A<'!L:6-A=&EE<RX`("`M9"P@+2UD:7)E8W1O
M<GD]1$E2("`@36%A:R!C;VUP96YD:75M(&EN(&1E>F4@9&ER96-T;W)Y+@`@
M("UH+"`M+6AE;'`@("`@("`@(%1O;VX@9&ET(&AE;'!B97)I8VAT+@`@("UL
M+"`M+6QO8V%L93UL;%]#0R`@("`@1V5B<G5I:R!A;&QE96X@9&5Z92!L86YD
M:6YS=&5L;&EN9P`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@1V5B<G5I:R!D
M97IE(&QA;F1I;G-T96QL:6YG+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!'
M96)R=6EK(&1E>F4@;&%N9&EN<W1E;&QI;F<N`"`@+6TL("TM;6]D=6QE/4U/
M1%5,12`@("!#;VUP:6QE97(@34\@8F5S=&%N9&5N(&%L;&5E;B!V;V]R(&1E
M>F4@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!/
M<'-C:&]N96X@4$\@8F5S=&%N9&5N(&%L;&5E;B!V;V]R(&1E>F4@*$AO<F1E
M*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;VUM:70@=F5R
M=&%L:6YG96X@86QL965N('9O;W(@9&5Z92`H2&]R9&4I(&UO9'5L92X`("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($UA86L@965N(%!/(&)E<W1A;F0@86QL
M965N('9O;W(@9&5Z92`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@(%-A;65N=F]E9V5N(%!/(&)E<W1A;F1E;B!A;&QE96X@=F]O
M<B!D97IE("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@0FEJ=V5R:V5N(&AE;'`@8F5S=&%N9&5N(&%L;&5E;B!V;V]R(&1E>F4@
M*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!!;&QE
M96X@9&5Z92`H2&]R9&4I(&UO9'5L92!B:6IW97)K96XN`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@1V5N97)E97(@4$]4(&)E<W1A;F0@86QL965N('9O;W(@
M9&5Z92`H2&]R9&4I(&UO9'5L92X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@
M($YI975W92!V97)T86QI;F=E;B!N:65T('-A;65N=F]E9V5N(&UE="!H970@
M8V]M<&5N9&EU;2X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($=E96X@8V]M
M<&5N9&EU;2!G96)R=6EK96XN`"`@+7,L("TM<W1A=&ES=&EC<R`@("`@("!6
M97)T86QI;F=S=&%T:7-T:65K96X@;W!S;&%A;B!I;B!E96X@;&]K86%L(&)E
M<W1A;F0N`"`@+70L("TM=&5S="`@("`@("`@5&]O;B!D92!U:71G979O97)D
M92!C;VUM86YD;R=S+"!M86%R('9O97(@;FEE=',@=6ET+@`@(&-L96%N=7`@
M("`@($]P<V-H;VYE;B!V86X@;VYV97)T86%L9&4@96X@=F5R=F%L;&5N(&EN
M=F]E<B!I;B!03R!B97-T86YD96XN`"`@8V]M;6ET("`@("`@0V]M;6ET('9E
M<G1A;&EN9V5N(&YA87(@9&4@0U93('-E<G9E<BX`("!C;VUM:70M:&5L<"!#
M;VUM:70@:&5L<"!B97-T86YD96X@;F%A<B!D92!#5E,@<V5R=F5R+@`@(&-O
M;7!E;F1I=6T@($AE<F-O;7!I;&5E<B!H970@8V]M<&5N9&EU;6)E<W1A;F0N
M(%=A87)S8VAU=VEN9SH@1&ET(&]V97)S8VAR:6IF=`H@("`@("`@("`@("`@
M(&AE="!H=6ED:6=E(&-O;7!E;F1I=6TN`"`@97AT<F%C="`@("`@1V5N97)E
M97(@4$\@<VIA8FQO;VX@*"YP;W0I(&)E<W1A;F1E;BX`("!H96QP("`@("`@
M("!4;V]N(&1I="!H96QP(&)E<FEC:'0N`"`@:6YI="`@("`@("`@36%A:R#I
MZ6X@;V8@;65E<B!03R!B97-T86YD96X@=F]O<B!E96X@;FEE=7=E(&QA;F1I
M;G-T96QL:6YG+B!786%R<V-H=7=I;F<Z"B`@("`@("`@("`@("`@1&ET(&]V
M97)S8VAR:6IF="!D92!B97-T86%N9&4@4$\@8F5S=&%N9&5N('9A;B!D97IE
M(&QA;F1I;G-T96QL:6YG+@`@(&UA:V4@("`@("`@($-O;7!I;&5E<B!D92!B
M:6YA:7)E($U/(&)E<W1A;F1E;B!U:70@9&4@;W!G96=E=F5N(%!/(&)E<W1A
M;F1E;BX`("!M86ME+6AE;'`@("!-87)K965R(&%L;&4@:6YV;V5R(&EN(&AE
M="!834P@:&5L<"!B97-T86YD(&%L<R!U<"UT;RUD871E(&5N"B`@("`@("`@
M("`@("`@<')E<&%R965R(&AE="!B97-T86YD('9O;W(@9&4@=F]L9V5N9&4@
M=6ET=F]E<FEN9R!V86X@=7!D871E+6AE;'`N"B`@("`@("`@("`@("`@52!D
M:65N="!M86ME+6AE;'`@86QL965N('5I="!T92!V;V5R96X@3D$@=7!D871E
M+6AE;'`@96X@8FEJ=V5R:V5N"B`@("`@("`@("`@("`@=F%N(&AE="!H96QP
M(&)E<W1A;F0N`"`@;65R9V4@("`@("`@4V%M96YV;V5G96X@=F%N(&AE="!H
M=6ED:6=E(%!/(&)E<W1A;F0@;65T(&AE="!H=6ED:6=E(%!/('-J86)L;V]N
M(&)E<W1A;F0N`"`@=7!D871E("`@("`@17AT<F%C="!E;B!M97)G92!N82!E
M;&MA87(@=6ET=F]E<F5N+@`@('5P9&%T92UH96QP($9I;'1E<B!A;&QE(&YI
M975W92!E;B!G97=I:GII9V1E(&EN=F]E<B!U:70@:&5T($5N9V5L<V4@6$U,
M(&AE;'`*("`@("`@("`@("`@("!B97-T86YD(&5N('9O96<@9&5Z92!S86UE
M;B!M970@9&4@8F5S=&%A;F1E(&EN=F]E<BX`("8C,34Q.R`E<R!I<R!K;&%A
M<B!O;F1E<G-T86%N9&4L(&=E<V5L96-T965R9&4L('=E<FMZ86%M:&5D96X@
M=6ET('1E('9O97)E;BX`("@E<R!D86=E;B!G96QE9&5N*0`@*%-N96QT;V5T
M<R`E<RD`("AB:6YN96X@)7,@9&%G96XI`"`H=F%N9&%A9RD`("AM;W)G96XI
M`"`H9VES=&5R96XI`"!O<"``)60@)7,@96X@)7,`)60@8GET97,@9V5S8VAR
M979E;BX`)60@=F%N("5D(&EN=F]E<F5N(&=E;6%R:V5E<F0@86QS('5P+71O
M+61A=&4`)60M9&%G('9O;W)U:71Z:6-H=``E<R`M($]P;65R:VEN9P`E<R!B
M96AE97(`)7,@=FEN9V5R869D<G5K`"5S($M"`"5S($]N9&5R:&]U9'-W97)K
M>F%A;6AE9&5N("T@0F5V97-T:6=I;F<`)7,@:6YS=&5L;&5N`"5S(&EN<V-H
M<FEJ=F5N`"5S(&=E8G)U:6ME<G-O=F5R965N:V]M<W0`)7,@8F5S=&%A="!A
M;"X`)7,@;W`@)7,@)7,`)7,@:&5E9G0@)7,@869G97IE9V0N`"5S(&AE969T
M(&=E86YT=V]O<F0@;W`@965N('9R:6HO8F5Z970@=F5R>F]E:RX`)7,@:&5E
M9G0@9V5A;G1W;V]R9"!O<"!D92!U:71N;V1I9VEN9R!V;V]R("5S+@`E<R!H
M965F="!U('9R:6HO8F5Z970@:6YF;W)M871I92!T;V5G97IO;F1E;BX`)7,@
M:7,@;FEE="!S8VAR:6IF8F%A<BX`)7,@:7,@=F5R96ES=``E<R!M:6YU=&5N
M`"5S(&YI970@9V5V;VYD96XN`"5S(&YI970@9V5V;VYD96XN(%9O97(@965R
M<W0@)W1R86YS;&%T:6]N(&5X=')A8W0G('5I="X`)7,@=G)A86=T('5W('9R
M:6HO8F5Z970@:6YF;W)M871I92X`)7,@=G)A86=T('5W(&%A;G=E>FEG:&5I
M9"!B:6H@)7,N`"5S('1O="`E<R!V86X@)7,`)7,@=V5N<W0@=&]E('1E('9O
M96=E;B!A86X@)7,N`"5S('=E;G-T('4@;W`@9&4@:&]O9W1E('1E(&)R96YG
M96X@=F%N("5S+@`E<R!W96YS="!D92!L86%T<W1E(&EN9F]R;6%T:64@=&4@
M;VYT=F%N9V5N(&]V97(@)7,N`"5S)W,@861R97-B;V5K`"5S)W,@86=E;F1A
M`"5S)W,@;F]T:71I96)O96L`)7,G<R!T86ME;FQI:G-T`"5S.B`E<P`G)7,G
M(&ES(&=E96X@9V5L9&EG92!K975Z92X`)R5S)R!I<R!N:65T(&=E8V]N9FEG
M=7)E97)D(&EN(&AE="!(;W)D92!R96=I<W1E<BX`)R5S)R!T<F5E('=E97)G
M979E<B!N:65T(&=E=F]N9&5N+@`G)7,G(&%A;B!H970@9W)O97!E;G-Y<W1E
M96T@=&]E9V5V;V5G9"X`)R5S)R!A86X@:&5T(')E8VAT96YS>7-T965M('1O
M96=E=F]E9V0N`"<E<R<@:7,@;FEE="!A86YG96UA86MT.B`E<RX`+"!W:6YD
M=FQA9V5N("5S("5S`"P@=F%R:6%B96P@=F%N("5S('1O="`E<P`M+2!S96QE
M8W1E<F5N("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0`Q,B!U=7)S
M=V5E<F=A=F4`,C0@=75R<W=E97)G879E`#(T('5U<G,`/&=E='1E>'0^('1A
M9R!N:65T(&=E<VQO=&5N(&EN(&)E<W1A;F0@)7,N"D]P96YI;F=S=&%G(&=E
M=F]N9&5N(&EN(')E9V5L("5D+@!%96X@9&%T86)A<V4@8F%C:V5N9"!I<R!V
M97)E:7-T('9O;W(@9&ET(&)L;VLN`$5R(&AE969T('II8V@@965N(&9A=&%L
M92!F;W5T('9O;W)G961A86X`165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES
M('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@8V]D97)E;BX`165N(&]P96YB
M87)E(%!'4"!S;&5U=&5L(&ES('9E<F5I<W0@;VT@965N(&]N9&5R=&5K96YD
M(&)E<FEC:'0@=&4@=F5R:69IZW)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U
M=&5L+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ
M;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&1E8V]D97)E;BX`165N(&]P
M96YB87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W86-H
M='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&]N
M9&5R=&5K96YE;BX`165N(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P<FEV
MZ2!3+TU)344@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E
M:7-T(&]M(&5E;B!B97)I8VAT('1E(&1E8V]D97)E;BX`165N(&]P96YB87)E
M(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)344@<VQE=71E;"!E;B!W86-H
M='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&]N
M9&5R=&5K96YE;BX`165N(&]P96YB87)E(%--24U%('-L975T96P@:7,@=F5R
M96ES="!O;2!E96X@8F5R:6-H="!T92!C;V1E<F5N+@!296=E;B!V;V]R(#$R
M+C`P('5U<@!"=6EE;B!V;V]R(#$R+C`P('5U<@!3;F5E=7=B=6EE;B!V;V]R
M(#$R+C`P('5U<@!!32]030!!4$D@240`3W9E<B!D97IE(&5D:71O<@!/=F5R
M+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`5F5R>F]E:R!A8V-E<'1E<F5N`$=E
M86-C97!T965R9`!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A
M;B!61E,@9&ER96-T;W)Y+@!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA
M:V5N('9A;B!61E,@8F5S=&%N9"X`06-C;W5N='=A8VAT=V]O<F0`06-C;W5N
M="!B979R;W)E;BX`5F5R86YT=V]O<F1I;F<`0F5W97)K:6YG96X`5&]E=F]E
M9V5N`$-H:6QD(&=R;V5P('1O979O96=E;@!#:&EL9"!R96-H="!T;V5V;V5G
M96X`2&EE<B!T;V5V;V5G96XZ`$YI975W92!G<F]E<"!T;V5V;V5G96X`3FEE
M=7<@<F5C:'0@=&]E=F]E9V5N`$5E;B`B8VAI;&1G<F]E<"(@86%N("<E<R<@
M=&]E=F]E9V5N`$5E;B`B8VAI;&1R96-H="(@86%N("<E<R<@=&]E=F]E9V5N
M`$YI975W92!G96)R=6EK97(@=&]E=F]E9V5N.@!+;VQO;2!T;V5V;V5G96X`
M3FEE=7=E(&QE9&5N('1O979O96=E;@!086%R('1O979O96=E;@!(970@)7,@
M;65N=2!T;V5V;V5G96X@86QS(&5E;B!-;WII;&QA(%-I9&5B87(`1&ET(&%A
M;B!M:6IN(&%G96YD82!T;V5V;V5G96X`5F]E9R!T;V4@86%N(&%D<F5S8F]E
M:SH`5F]E9R!T;V4@86%N(&UI:FX@861R97-B;V5K`$=E8G)U:6ME<B!T;V5V
M;V5G96X`)R5S)R!A86X@:&5T('-Y<W1E96T@=&]E9V5V;V5G9"P@;6%A<B!K
M;VX@9V5E;B!E>'1R82!I;G-C:')I:G9I;F=S:6YF;W)M871I92!T;V5V;V5G
M96XZ("5S+@`G)7,G(&%A;B!H970@<WES=&5E;2!T;V5G979O96=D+B!5(&MU
M;G0@;G4@86%N;65L9&5N+@!.:65U=V4@8F5S=&%N9&5N(&%A;B!D97!O="!T
M;V5V;V5G96XZ`%1O979O96=E;B!V86X@9V5B<G5I:V5R<R!I<R!U:71G97-C
M:&%K96QD+@!!9')E<P!!9')E<V)O96L`0F5H965R("T@<F5C:'1E;B!V;V]R
M(&%N9&5R92!G96)R=6EK97)S(&EN<W1E;&QE;@!"96AE97(`061V97)T96YT
M:65S`$%F9V%N:7-T86X`06QB86YIZP!!;&=E<FEJ90!!;&EA<P!5:71L:6IN
M96X`56ET;&EJ;FEN9SH`06QL90!!;&QE(&=E875T:&5N=&EC965R9&4@9V5B
M<G5I:V5R<P!!;&QE(&=R;V5P96X`06QL92!R96-H=&5N`$%L;&4@=FEE<B!Z
M:6ID96X`365E<F1E<F4@861R97-S96X@=&]E<W1A86X`26YS=&5L;&5N('9A
M;B!G96]R9&5N9&4@;&EJ<W0@='EP92!T;V5S=&%A;C\`0F5S=&%A="!A;`!!
M;'1E<FYA=&EE=F4@24U34"!A86YM96QD:6YG`$%L=&5R;F%T:65F($E-4U`@
M=V%C:'1W;V]R9`!!;'1E<FYA=&EE=F4@24U34"!G96)R=6EK97)S;F%A;0!!
M;'1E<FYA=&EE9B!E+6UA:6QA9')E<P!!;'1E<FYA=&EE=F4@<VIA8FQO;F5N
M`$%L=&5R;F%T:65V92!T96MS=#H`06UE<FEK86%N<R!386UO80!%96X@;VYG
M96QD:6=E('=A87)D92!O<&=E9V5V96XN`$%N9&]R<F$`06YG;VQA`$%N9W5I
M;&QA`$%N;VYI96UE('!R;WAY`$%N='=O;W)D`$%N=&%R8W1I8V$`06YT:6=U
M82!E;B!"87)B=61A`%1O97!A<W-I;F<`5&]E<&%S<VEN9V5N;&EJ<W0`5&]E
M<&%S<VEN9R!I<R!G97)E960N`$]P(&-H:6QD<VAA<F5S('1O97!A<W-E;@!'
M;V5D:V5U<F5N`$)E;F%D97)D92!G<F]O='1E`$%P<FEL`$%R86)I<V-H("A7
M:6YD;W=S+3$R-38I`$%R8VAI969B97-T86YD<V=R;V]T=&4`07)C:&EE9FYA
M86T`5V5E="!U('IE:V5R(&1A="!U(&AE="!A86YM96QD:6YG<W9E<GIO96L@
M=F%N("5S('=I;'0@=F5R=VEJ9&5R96X_`%=E970@=2!Z96ME<B!D870@=2`G
M)7,G(&5N(&%L;&4@<W5B9W)O97!E;B!W:6QT('9E<G=I:F1E<F5N/P!!<F=E
M;G1I;FGK`$%R;65N:>L`07)M965N<R`H05)-4T-)22TX*0!+=6YS=`!!<G5B
M80!!<V-E;G-I;VX@96EL86YD`$%S8VEI(&MU;G-T`$%Z:>LO4&%C:69I<V-H
M92!296=I;P!/;2!B979E<W1I9VEN9R!V<F%G96X@=F]O<B!H970@=6ET=F]E
M<F5N('9A;B!O;F1E<FAO=61S=V5R:WIA86UH961E;C\`3W!D<F%C:'0@:V]L
M;VUM96X`165N(&E#86QE;F1A<F)E<W1A;F0@:7,@8FEJ9V5V;V5G9"P@:6X@
M86YT=V]O<F0@;W`@=7<@9V5Z;VYD96X@=F5R>F]E:P!0;V=I;F<@;VT@965N
M(&YI970@8F5S=&%A;F1E(&=R;V5P('1E('9E<G=I:F1E<F5N+@!0;V=I;F<@
M;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@=F5R=VEJ9&5R96XN`%!O
M9VEN9R!O;2!E96X@;FEE="!B97-T86%N9"!R96-H="!T92!B97=E<FME;BX`
M4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD92!S:&%R92!T92!B97=E<FME
M;BX`06%N=V5Z:6=E;@!!='1R:6)U=&5N`$%U9W5S='5S`$%U<W1R86QIZP!/
M;W-T96YR:6IK`$%U=&A?8WER<W%L.B!V97)E:7-T92!I;6%P(&5X=&5N=&EE
M(&YI970@9V5V;VYD96XN`$%U=&A?8WER=7,Z(&)A8VME;F0@:&5E9G0@;FEE
M="!D92!V97)E:7-T92!B96MW86%M:&5D96XN`$%U=&A?8WER=7,Z('9E<F5I
M<W1E(&EM87`@97AT96YT:64@;FEE="!G979O;F1E;BX`075T:%]F='`Z('9E
M<F5I<W1E($944"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B!#;VUP:6QE97(@
M4$A0(&UE="!D92`M+65N86)L92UF='`@;W!T:64N`$%U=&A?:6UA<#H@=F5R
M96ES=&4@24U!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7VMR8C4Z
M('9E<F5I<W1E(&MR8C4@97AT96YT:64@;FEE="!G979O;F1E;BX`075T:%]L
M9&%P.B!V97)E:7-T92!,1$%0(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U
M=&A?;&1A<#H@3FEE="!I;B!S=&%A="!G96)R=6EK97(@)7,@=&]E('1E('9O
M96=E;BX@1&4@<V5R=F5R(&UE;&1T.B``075T:%]L9&%P.B!.:65T(&EN('-T
M86%T(&=E8G)U:6ME<B`E<R!T92!V97)W:6ID97)E;@!!=71H7VQD87`Z($YI
M970@:6X@<W1A870@9V5B<G5I:V5R("5S(&)I:B!T92!W97)K96X`075T:%]M
M8V%L.B!V97)E:7-T92!-0T%,(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U
M=&A?<VUB875T:#H@=F5R96ES=&4@<VUB875T:"!E>'1E;G1I92!N:65T(&=E
M=F]N9&5N+@!!=71H96YT:6-A=&EE(&UI<VQU:W0`075T:&5N=&EC871I92!M
M:7-L=6MT+B`E<P!!=71H96YT:6-A=&EE(&=E=V5I9V5R9"!D;V]R(&1E(%)!
M1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:64@;W`@1E10('-E<G9E<B!M:7-L
M=6MT+@!"97-C:&EK8F%R92!V96QD96XZ`$EN(&%F=V%C:'1I;F<@=F%N(&%N
M='=O;W)D`$%Z97)B86ED>FIA;@!"3T9(($5X8W5S97,`06-H=&5R9W)O;F0`
M06-H=&5R9W)O;F1K;&5U<@!&;W5T(&ME<F)E<F]S=V%C:'1W;V]R9"X`1F]U
M=&4@:V5R8F5R;W-G96)R=6EK97)S;F%A;2X`0F%H86UA<P!"86AR96EN`$)A
M;'1I<V-H("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!+86%L
M`$)A<VES(&%F8F5E;&1I;F=E;F1I<F5C=&]R>2`G)7,G(&YI970@9V5V;VYD
M96XN`$)A<VES;&EJ;@!7:70@<G5S;&%N9`!"96QG:>L`0F5L:7IE`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`%9E<FIA87)D86<`0FQO:R`B)7,B('9A;B!T;V5P
M87-S:6YG("(E<R(@;FEE="!G979O;F1E;BX`0FQO:VEN<W1E;&QI;F=E;@!"
M;&]K='EP90!6970`0F]L:79I80!";V]K;6%R:W,`4F%N9`!286YD9&EK=&4Z
M`%)A;F1E;@!";W-N:>L@96X@2&5R>F5G;W9I;F$`0F5I9&5N`$)O='-W86YA
M`$]N9&5R:V%N=`!";W5V970@96EL86YD`$)R87II;&GK`$)R:71S($EN9&ES
M8VAE($]C96%A;B!497)R:71O<FEU;0!"<G5N96D@1&%R=7-S86QA;0!#;VUP
M:6QE<F5N($U/(&)E<W1A;F1E;B!V;V]R(&UO9'5L92`E<RXN+@!#;VUP:6QE
M<F5N(&QA;F1I;G-T96QL:6YG("5S+BXN(`!"=6QG87)I:F4`3VYG96]R9&5N
M9&4@;&EJ<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES
M=')I8G5T:65P=6YT96X`0U]E;&5I9V5N<V-H87!P96XN+BX`06=E;F1A`$MA
M;&T`0V%M8F]D:F$`2V%M97)O96X`2V%N('=A8VAT=V]O<F0@;FEE="!A=71O
M;6%T:7-C:"!R97-E='1E;BP@;F5E;2!C;VYT86-T(&]P(&UE="!D92!S>7-T
M965M8F5H965R9&5R+@!+86X@;FEE="!V97)B:6YD96X@;65T($E-05`@<V5R
M=F5R.B`E<P!#86YA9&$`069B<F5K96X`4')O8FQE96UR87!P;W)T(&%F8G)E
M:V5N`$MA;B!B97-T86YD("(E<R(@;FEE="!V97)W:6ID97)E;BX`2V%N(&=E
M96X@=&EJ9&5L:6IK92!D:7)E8W1O<GD@=FEN9&5N+@!+86X@;FEE="!D;V]R
M9V%A;B!Z;VYD97(@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`2V%N(&1I<F5C
M=&]R>2`B)7,B(&YI970@=F5R=VEJ9&5R96XN`$MA;B!N:65T('9E<G=I:F1E
M<F5N.R`E9"!C:&EL9')E;B!B97-T86%N+@!+86X@;FEE="!O<&YI975W(')A
M;F=S8VAI:VME;BP@:&5T(&%A;G1A;"!I;G9O97)E;B!O;2!O<&YI975W('1E
M(')A;F=S8VAI:VME;B!K;VUT(&YI970@;W9E<F5E;B!M970@:&5T(&]P9V5S
M;&%G96X@86%N=&%L+@!+86X@8F5R:6-H="!N:65T(&YA87(@:&5T(&]P9V5G
M979E;B!N=6UM97(@=F5R<W1U<F5N+@!+86%P(%9E<F1E`$]P<V-H<FEF=`!#
M871E9V]R:67K;B!E;B!L86)E;',`0V%Y;6%N(&5I;&%N9&5N`%1E;"YN<BYM
M;V)I96P`0V5L96EG96YS8VAA<'!E;@!#96P@=G)I:F4@<G5I;71E.@!#96QE
M:6=E;G-C:&%P<&5N`$-E;'-P871IZW)I;F<Z`%1E;"YN<BYM;V)I96P`2V5L
M=&ES8V@@*$E33RTX.#4Y+3$T*0!-:61D96X`0V5N=')A86P@069R:6MA86YS
M92!297!U8FQI96L`0V5N=')A86P@175R;W!E97,@*$E33RTX.#4Y+3(I`$-E
M<G1I9FEC86%T9&5T86EL<P!#97)T:69I8V%A=&)E;&5I9`!4<VIA860`5F]O
M<GII='1E<@!7:6IZ:6=E;@!7:6IZ:6<@9&4@;F%A;2P@861R97,@96X@;VYD
M97)T96ME;FEN9R!D:64@;65N('II970@8FEJ(&AE="!L97IE;B!E;B!B96%N
M='=O;W)D96X@=F%N('5W(&4M;6%I;',N`%=I:GII9R!W86-H='=O;W)D`$MA
M<F%K=&5R`$-O;G1?<F]L965R(&QI;FLN+BX`4V5L96-T965R(&1E('=E<FMZ
M86%M:&5D96XL(&1I92!U(&]P(&1I="!M;VUE;G0@=VEL="!U:71V;V5R96XN
M`$-H:6QI`$-H:6YA`$-H:6YE97,@=F5R965N=F]U9&EG9"`H1T(R,S$R*0!#
M:&EN965S('1R861I=&EO;F5E;"`H0FEG-2D`2VEE<R!E96X@=V%C:'1W;V]R
M9`!+:65S(&5E;B!G96)R=6EK97)S;F%A;0!+:65S(&5E;B!B97=E<FMI;F<Z
M`$MI97,@9&%T=6UW965R9V%V93H`2VEE<R!L:6IS='-T:6IL='EP92`H=F]O
M<B!G96]R9&5N9&4@;&EJ<W1E;BD`0VAR:7-T;6%S(&5I;&%N9`!#;&%S<V1E
M9FEN:71I92!V86X@)7,@;FEE="!G979O;F1E;BX`3W!S8VAO;F5N(%!/(&)E
M<W1A;F1E;B!V;V]R(&UO9'5L92`E<RXN+@!/<'-C:&]N96X@;&%N9&EN<W1E
M;&QI;F<@)7,N+BX@`$AE;&1E<@!-4T]F9FEC92!T86=S('=I<W-E;@!7:7,@
M9V5B<G5I:V5R.B`E<P!7:7,@9V5B<G5I:V5R`%=I<R!G96)R=6EK97)S9&%T
M80!+;&EK(&]M('9E<F1E<B!T92!G86%N`$-L:6-K871E;&P@=FEA($A45%``
M4VQU:70@<V-H97)M`%=O;&ME;@!"97=O;&MT`$-O8V]S("A+965L:6YG*2!E
M:6QA;F1E;@!::6IB86QK(&EN:VQA<'!E;@!);F=E:VQA<'1E(')A;F1E;@!#
M;VQO;6)I80!+;&5U<@!+;&5U<F5N:VEE>F5R`$ML975R<V5L96-T:64`2V]L
M;VUM96XZ`$MO;&]M=&ET96QS`%-T<FEP<P!/<&1R86-H=`!/<&1R86-H='-H
M96QL`$]P9')A8VAT;W!T:65S.@!/<&1R86-H=&5N.@!/<&UE<FMI;F<`0V]M
M;6ET=&EN9SH`06QG96UE;F4@;F%A;0!#;VUO<F5N`$)E9')I:F8`069G97)O
M;F0`3FEE=7<@8F5R:6-H="`H)7,I`$-O;7!U=&5R<P!#;VYD:71I97,`5F5R
M<V-H:6QL96X@:6X@8V]N9FEG=7)A=&EE`$-O;F9I9W5R871I92!D:65N="!B
M:6IG97=E<FMT('1E('=O<F1E;BX`)7,@8V]N9FEG=7)E<F5N`$)E=F5S=&EG
M('=A8VAT=V]O<F0`3F]G;6%A;',@;FEE=7<@=V%C:'1W;V]R9#H`2V]N9V\`
M2V]N9V\L($1E($1E;6]C<F%T:7-C:&4@4F5P=6)L:65K('9A;B!D90!697)B
M:6YD:6YG(&UI<VQU:W0N`%9E<F)I;F1I;F<@;6ES;'5K=#H@`%9E<F)I;F1I
M;F<L(&UE="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E:6=E
M<F0N`%9E<F)I;F1I;F<L(&UE="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R
M+"!I<R!G97=E:6=E<F0N(%)E9&5N.B`E<R`H)7,I`%9E<F)I;F1I;F<@;65T
M($944"!S97)V97(@;6ES;'5K="X`061R97-S96X@>FEJ;B!M970@<W5C8V5S
M(&%A;B!U=R!A9')E<V)O96L@=&]E9V5V;V5G9"X`26YH;W5D('9A;B`G)7,G
M`$1O;W)G86%N`$-O;VL@96EL86YD96X`0V]O:VEE`$MO<&GK<F5N`$MO<&EE
M97(@<V5L96-T:64`)7,@:V]P:>MR96X@;F%A<B`E<P!#;W-T82!2:6-A`$EV
M;V]R:W5S=`!+;VX@4$=0(&)E<FEC:'0@;FEE="!C;V1E<F5N+@!+;VX@4$=0
M(&)E<FEC:'0@;FEE="!O;F1E<G1E:V5N96XN`$MO;B!B97)I8VAT(&YI970@
M4R]-24U%(&-O9&5R96XN`$MO;B!B97)I8VAT(&YI970@4R]-24U%(&]N9&5R
M=&5K96YE;BX`2V]N(&%D<F5S("5S(&YI970@=&]E=F]E9V5N+@!+;VX@9V5E
M;B!V97)B:6YD:6YG(&UE="!D92!,1$%0+7-E<G9E<B!M86ME;BX`2V]N('1E
M9V]E9"`E<R!N:65T(&-O;G1R;VQE<F5N+@!+;VX@;FEE="!V97)B:6YD96X@
M;65T('-E<G9E<B`G)7,G(&UE="!&5%`Z("5S`$MO;B`E<R!N:65T(&MO<&GK
M<F5N(&YA87(@)7,`2V]N(&=E96X@9&ES=')I8G5T:65L:6IS="`E<R!M86ME
M;BX`2V]N(&=E96X@;&%N9&EN<W1E;&QI;F=D:7)E8W1O<GD@=F]O<B!L86YD
M:6YS=&5L;&EN9R`E<R!M86ME;CH`2V]N(%!'4"!D871A(&YI970@9&5C;V1E
M<F5N+@!+;VX@4R]-24U%(&1A=&$@;FEE="!D96-O9&5R96XN`$MO;B!A9')E
M<R`E<R!N:65T('9E<G=I:F1E<F5N+@!+;VX@9&ES=')I8G5T:65L:6IS="`E
M<R!N:65T('9E<G=I:F1E<F5N+@!+;VX@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M)R5S)R!N:65T('9E<G=I:F1E<F5N+@!+;VX@:&5T(&4M;6%I;&%D<F5S('9A
M;B!D92!O;G1V86YG97(@;FEE="!B97!A;&5N+@!+;VX@8V]M<&QE=&4@861R
M97-B;V5K(&YI970@;W!H86QE;BX`2V]N(&-O;7!L971E(&1I<W1R:6)U=&EE
M;&EJ<W0@;FEE="!O<&AA;&5N+@!+;VX@8V]M<&QE=&4@;&EJ<W0@=F%N(&1I
M<W1R:6)U=&EE;&EJ<W1E;B!N:65T(&]P:&%L96XN`$MO;B!S=')A=&5G:64@
M)R5S)R!N:65T('1O979O96=E;BX`2V]N(&1I<F5C=&]R>2`G)7,G(&YI970@
M86%N;6%K96XN`$MO;B!D92!O<&5N8F%R92!S;&5U=&5L(&YI970@=F5R:W)I
M:F=E;B!V86X@9&4@<VQE=71E;'-E<G9E<BX`2V]N("5S(&YI970@;W!E;F5N
M+@!+;VX@;FEE="!S8VAR:6IV96X@;F%A<B`G)7,G+@!+;VX@;VYD97)H;W5D
M<W1A:V5N;6]D=6QE("5S(&YI970@;W!E;F5N`$MO;B!D:7)E8W1O<GD@)R5S
M)R!N:65T(&]P96YE;BX`2V]N("5S(&YI970@;&5Z96XN`$MO;B!H970@=V%C
M:'1W;V]R9"!V86X@9&4@9V5W96YS=&4@9V5B<G5I:V5R(&YI970@<F5S971T
M96XN(%-O;6UI9V4@;V8@86QL92!D971A:6QS('II:FX@;FEE="!J=6ES="X@
M4')O8F5E<B!O<&YI975W(&]F(&YE96T@8V]N=&%C="!O<"!M970@9&4@<WES
M=&5E;6)E:&5E<F1E<BP@=V%N;F5E<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H
M965F="X`2V]N($%#3"!N:65T(&]P:&%L96X`2V]N(&%D<F5S8F]E:R`E<R!N
M:65T(&]P:&%L96XN`$MO;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@;W!H
M86QE;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W1E;B`E<R!N:65T(&]P:&%L96XN
M`$MO;B!S97)V97)B96MW86%M:&5D96X@;FEE="!O<&AA;&5N`$MO;B!C;VYF
M:6=U<F%T:64@;FEE="!T97)U9WIE='1E;BX`2V]N(&1I<F5C=&]R>2`G)7,G
M(&YI970@=F5R=VEJ9&5R96XN`$MO;B!C;VYF:6=U<F%T:64@)7,@;FEE="!O
M<'-L86%N+@!+;VX@9V5E;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S;&%A;BX`
M2V]N(&AE="!B86-K=7!C;VYF:6=U<F%T:65B97-T86YD("5S(&YI970@;W!S
M;&%A;@!+;VX@<V5T=7`@=7!G<F%D92!S8W)I<'0@;FEE="!O<'-L86%N(&%L
M<SH@)R5S)P!+;VX@:&5T(&)A8VMU<&-O;F9I9W5R871I96)E<W1A;F0@)7,@
M;FEE="!O<'-L86%N+@!+;VX@:&5T(&-O;F9I9W5R871I96)E<W1A;F0@)7,@
M;FEE="!O<'-L86%N+B!5(&MU;G0@;V8@Z>EN('9A;B!D92!O<'1I97,@9V5B
M<G5I:V5N("P@;VT@9&4@8V]D92!T97)U9R!N86%R("5S(&]P('1E('-L86%N
M(&]F(&]M(&1E(&-O9&4@:&%N9&UA=&EG(&YA87(@)7,@=&4@:V]P:>MR96XN
M`$MO;B!D92!,1$%0+7-E<G9E<B!N:65T(&1O;W)Z;V5K96XN`$MO;B`E<R!N
M:65T('9E<G=I:F1E<F5N+@!+;VX@861R97,@)7,@;FEE="!B:6IW97)K96XN
M`$MO;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@8FEJ=V5R:V5N+@!+;VX@
M8V]N9FEG=7)A=&EE('9O;W(@)R5S)R!N:65T('=E9W-C:')I:G9E;CH@)7,`
M2V]N(&1E($UO>FEL;&$@4VED96)A<B!N:65T('9I;F1E;BX@6F]R9R!E<G9O
M;W(@9&%T(&1E('-I9&5B87(@;W!E;B!I<RX`2V]N(&=E8G)U:6ME<B`G)7,G
M(&1E('9O;&=E;F1E(')E8VAT96X@;W`@9&4@;6%P("<E<R<@;FEE="!G979E
M;CH@)7,`1V5T96QD92!T96MS=`!,86YD`$-U<G-U<W-E;@!-86ME;@!-86%K
M(&5E;B!L:6YK`$UA86L@965N(&YI975W90!-86%K('-U8FUA<'!E;@!%:6=E
M;F%A<G)E8VAT96X`0W)E9&ET8V%R9&YU;6UE<@!+<F]A=&GK`$-U8F$`2'5I
M9&EG92!F87-E`$AU:61I9V4@=&EJ9`!(=6ED:6=E(%523"!I<P!(=6ED:6<@
M=V5E<@!(=6ED:6=E(&-O;F1I=&EE.B``2'5I9&EG92!S=&EJ;`!!86YP87-S
M96X@=F%N('1A:V5N('1I:F1E;G,@86%N;65L9&EN9R!B:6H@)7,N`$MN:7!P
M96X`4V5L96-T:64@:VYI<'!E;@!#>7!R=7,`0WER:6QL:7-C:"`H2T])."U2
M*0!#>7)I;&QI<V-H("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&ES8V@O56MR86EN
M<R`H2T])."U5*0!4<VIE8VAI<V-H92!297!U8FQI96L`1$0`1&%G96QI:FMS
M`$1A=&$`1&%T851R964@8G)O=W-E<@!$871U;0!$871U;2!/;G1V86YG96X`
M1&%T=6T@<V5L96-T:64`1&%G`%9E<E]W:6ID97(@:V]L;VT`1&5C96UB97(`
M1&5C:6UA;&4@9V5T86QL96X`069G96YO;65N`$EN<W!R:6YG96X@=F5R:VQE
M:6YE;@!3=&%N9&%A<F0`4W1A;F1A87)D(&ML975R`%-T86YD86%R9"!I9&5N
M=&ET96ET`%-T86YD86%R9"!R96-H=&5N`%-T86YD86%R9"!R96-H=&5N`$1E
M9FEN:71I97,`4&]S:71I92!O=F5R9')A9V5N`$]V97)G961R86=E;@!697)W
M:6ID97)E;@!'<F]E<"!V97)W:6ID97)E;@!296-H="!V97)W:6ID97)E;@!6
M97)W:6ID97(@96X@=VES(&)E<FEC:'1E;@!697)W:6ID97(@8V5L`%9E<G=I
M:F1E<B!K;VQO;0!"97-T86%N9"!A;'1E<FYA=&EE9B!S:F%B;&]O;B!V97)W
M:6ID97)E;@!296-H=&5N('9A;B`G)7,G('9E<G=I:F1E<F5N`%)E8VAT96X@
M96X@979E;G1U96QE('-U8G)E8VAT96X@=F]O<B`G)7,G('9E<G=I:F1E<F5N
M/P!697)W:6ID97(@<FEJ`$=E<V5L96-T965R9&4@:61E;G1I=&5I="!V97)W
M:6ID97)E;@!697)W:6ID97(@9&4@:'5I9&EG92!K;VQO;0!697)W:6ID97(@
M9&4@:'5I9&EG92!R:6H`1&ET(')E8VAT(&5N(&%L;&4@<W5B<F5C:'1E;B!V
M97)W:6ID97)E;C\`4V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)R!V97)W:6ID
M97)D+@!!9FQE=F5R=&EJ9`!$96YE;6%R:V5N`%=E:6=E<B!V97)Z;V5K`%=E
M:6=E<B!V97)Z;V5K('9O;W(@=G)I:B]B97IE="!I;F9O<FUA=&EE`$)E<V-H
M<FEJ9B!H970@<')O8FQE96T`0F5S8VAR:6IV:6YG`$1E=&%I;',@*&]O:R!I
M;B!(;W)D92=S(&QO9V)E<W1A;F0I.@!$971A:6QS('II:FX@9V5L;V=D('9O
M;W(@9&4@<WES=&5E;6)E:&5E<F1E<BX`3VYT=VEK:V5L:6YG`$1A=7=P=6YT
M`$1A=7=P=6YT('9O;W(@:&5T(&%F9V5L;W!E;B!U=7(Z(`!$875W<'5N=#H@
M`%)I8VAT:6YG(&QI;FMS(&YA87(@<F5C:'0`4FEC:'1I;F<@<F5C:'1S(&YA
M87(@;&EN:W,`1&ER96-T;W)Y`#(T+75U<G,@=&EJ9'=E97)G879E/P!7965R
M9V%V96]P=&EE<P!7965R<W9O;W)S<&5L;&EN9R!T;VYE;B`H5$%&*0!7965R
M9V%V969O<FUA870`5F]O<F)E<F5I9&EN9W-N;W1I9FEC871I90!$:FEB;W5T
M:0!.:65T('9E<G=I:F1E<F5N`&UA:6YT96YA;F-E+G!H<"!N:65T(&1I<F5C
M="!A86YS<')E:V5N`$)E=F%T(&1E(&5E<G-T92!R:6H@9&4@=F5L9&YA;65N
M/R!:;R!J82P@9&ET(&AO:VIE(&%A;G9I;FME;CH`1&]M:6YI8V$`1&]M:6YI
M8V%A;G-E(%)E<'5B;&EE:P!$;W=N;&]A9&5N`"5S(&1O=VYL;V%D96X`1&]W
M;FQO860@9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92!A;',@4$A0('-C<FEP
M="X`1')O<"!D;W=N(&QI:G-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!"
M97=E<FME;@!";&]K(&)E=V5R:V5N`$=R;V5P(&)E=V5R:V5N`%)E8VAT(&)E
M=V5R:V5N`%)E8VAT96X@8F5W97)K96X`4F5C:'1E;B!V86X@)R5S)R!B97=E
M<FME;@!/<'1I97,@8F5W97)K96X@=F]O<CH`4F5C:'1E;B!V86X@)7,@8F5W
M97)K96X`4F5C:'1E;B!V86X@)R5S)R!B97=E<FME;@!/;F1E<G=I:G,`16=Y
M<'1E`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`12UM86EL`$4M;6%I;&%D
M<F5S`$4M;6%I;&%D<F5S<V5N(&UO971E;B!O=F5R965N:V]M96XN`$4M;6%I
M;"!M970@8F5V97-T:6=I;F<`16UO=&EC;VYS`$QE96<@8F5R:6-H="X`1V5E
M;B!R97-U;'1A870N`$QE9V4@>F]E:W1E<FUE;@!);G9O96=E;B!V86X@869B
M965L9&EN9V5N('5I="!F;W1O86QB=6US(&EN('1E:W-T(&EN<V-H86ME;&5N
M/P!296-H=&ML:6MK96X@8V]N=&5X="!M96YU(&EN<V-H86ME;&5N/P!%:6YD
M90!%:6YD:F%A<@!697)G<F]O="!E9&ET;W(`1V5E9B!E96X@8F5V96EL:6=I
M;F=S=G)A86<@9&EE('4@9V5V<F%A9V0@=V]R9'0L('=A;FYE97(@:&5T(&YO
M9&EG(&ES(&]M('5W('=A8VAT=V]O<F0@=&4@<F5S971T96XL(&(N=BX@)W=A
M="!I<R!D92!N86%M('9A;B!U=R!H=6ES9&EE<C\G.@!6;V5R(&1E(&%F8F5E
M;&1I;F<@55),(&AI97(@:6X`26YV;V5R.B`E9"!T;W1A86PL("5D('5P+71O
M+61A=&4L("5D(&YI975W+"`E9"!G97=I:GII9V0L("5D(&]N8F5K96YD`$5Q
M=6%T;W)I86%L($=U:6YE90!%<FET<F5A`$9O=70`1F]U="!B:6H@=F5R>F5N
M9&5N('9A;B!A;G1W;V]R9#H@)7,N`$9O=70@;65T(&4M;6%I;&)E<FEC:'0N
M`$9O=70@8FEJ('-C:')I:G9E;B!V86X@)R5S)RX`1F]U=#H@`$5S=&QA;F0`
M171H:6]P:>L`171N:7-C:`!%=7)O<&$`16QK92`Q-2!M:6YU=&5N`$5L:V4@
M,B!M:6YU=&5N`$5L:V4@,S`@<V5C;VYD96X`16QK92`U(&UI;G5T96X`16QK
M92!A86YM96QD:6YG`$5L:R!H86QF('5U<@!%;&ME(&UI;G5U=`!6;V]R8F5E
M;&1W86%R9&5N.@!5:71V;V5R96X`56ET=F]E<F5N.@!5:71K;&%P<&5N`%II
M:F)A;&L@=6ET:VQA<'!E;@!697)W86-H='1E("<I)P!697)W86-H='1E(&5N
M:V5L('=O;W)D(&]F(&%A;F=E:&%A;&1E('IO96MT97)M`%9E<G9A;&1A='5M
M`$5X<&]N96YT`$9I;'1E<B!U:70@)7,N+BX@`%9O;W)G<F]N9&ML975R`$94
M4"!U<&QO860@=F%N('-E='5P`$]P:&%L96X@=F]O<FME=7)S:6YS=&5L;&EN
M9V5N(&UI<VQU:W0N`%9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&ES
M(&UI<VQU:W0N`%9E<F)I;F1I;F<@;65T(&1E(%--0BUS97)V97(@:7,@;6ES
M;'5K="X`2V]P:>MR96X@=6ET("(E<R(@:7,@;6ES;'5K="X`2V]P:>MR96X@
M;F%A<B`B)7,B(&ES(&UI<VQU:W0N`$UA:V5N('9A;B!N:65U=V4@4T%33"!V
M97)B:6YD:6YG(&ES(&UI<VQU:W0N`%9E<G!L86%T<V5N(&YA87(@(B5S(B!I
M<R!M:7-L=6MT+@!&;W5T(&)I:B!V97)A;F1E<F5N('9A;B!W86-H='=O;W)D
M(#H@`$UO;VD`1F%L:VQA;F0@96EL86YD96X@*$UA;'9I;F%S*0!&87)OZW(@
M96EL86YD96X`1F%T86QE(&9O=70Z`$9A>`!&96)R=6%R:0!6;V5L="!A;',`
M5F]E;'0@86QS.B``16YK96QE(&)U:65N`$5N:6=E('-N965U=V)U:65N`%9E
M;&1M871R:7@`1FEJ:0!!86YT86P@8F5S=&%N9&5N.B`E<R!B97-T86YD`$%A
M;G1A;"!B97-T86YD96XZ("5S(&)E<W1A;F1E;@!"97-T86YD8F5H965R`$)E
M<W1A;F1S;F%A;0!"97-T86YD(&MI97IE;@!"97-T86YD=7!L;V%D`$)E<W1A
M;F1U<&QO861S('=O<F1E;B!N:65T(&]N9&5R<W1E=6YD+@!&:6QT97)S`$9I
M;FQA;F0`165R<W1E(&AE;&9T`$5E<G-T92!K=V%R=&%A;`!697)H;W5D:6YG
M(&AE<G-T96QL96X`3VUK97)E;@!$<FEJ=F5N`$UI<W0`36%P("5S(&)E<W1A
M870@;FEE=`!&;VYT:VQE=7(`5F]E9'-E;`!6;V]R(&)R;W=S97)S(&1I92!G
M965N(&%F8F5E;&1I;F=E;B!O;F1E<G-T975N96X`5V5E<G-V;V]R<W!E;&QI
M;F<@*%1!1BD`5F]O<G5I='II8VAT9&%G96X@*&UE<FL@;W`@9&%T(&AE="!G
M96=E=F5N('9O;W)U:71Z:6-H="!D86=E;B!E;B!N86-H=&5N(&=E969T.R!E
M96X@9W)O;W0@86%N=&%L(&MA;B!R97-U;'1E<F5N(&EN(&5E;B!B<F5E9"!B
M;&]K*0!5=R!W86-H='=O;W)D('9E<F=E=&5N/P!&;W)M=6QI97)E;@!&;W)T
M=6YE`$9O<G1U;F5T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$1O
M;W)S='5R96X`1V5V;VYD96X@=&]E<&%S<VEN9V5N.B`E<P!'979O;F1E;B!D
M:7)E8W1O<FEE<SH`5G(`1G)A;65S`$9R86YK<FEJ:P!&<F%N:W)I:FLL($AO
M;V9D<W1E9&5L:6IK`%9R:6HO0F5Z970@:6YF;W)M871I90!6<FEJ+T)E>F5T
M(&%N='=O;W)D`%9R:6HO0F5Z970@=F5R>F]E:P!6<FEJ+T)E>F5T('9E<GIO
M96L@86YT=V]O<F0`1G)A;G,@1W5Y86YA`$9R86YS(%!O;'EN97-IZP!&<F%N
M<V4@6G5I9&5L:6IK92!497)R:71O<FEA`%9A;@!686X@9&4@`%9O;&QE9&EG
M92!B97-C:')I:G9I;F<`5F]L;&4@;6%A;@!6;VQL961I9V4@;F%A;0!&=7IZ
M>0!'86)O;@!!;&)U;2!W86%R=6ET(&1E(&%F8F5E;&1I;F<@9V5H86%L9"!D
M:65N="!T92!W;W)D96X`06QB=6TZ`$=A;6)I80!'96YE<F5E<B`E<R!C;VYF
M:6=U<F%T:64`1V5G96YE<F5E<F1E(&-O9&4`1V5N97)E<F5N('-T871U<R!V
M;V]R(&UO9'5L92`E<RXN+@!'96]R9VGK`$1U:71S;&%N9`!'971O<'0@9F]U
M=#H@`$=H86YA`$=I8G)A;'1A<@!6;V]R;F%A;0!'80!';V5D96P`1V]O9VQE
M('IO96ME;@!'<FEJ<W-C:&%A;`!'<FEE:V5N;&%N9`!'<FEE:W,@*$E33RTX
M.#4Y+3<I`$=R;V5N;&%N9`!'<F5N861A`$=R;V5P<V)E:&5E<@!'<F]E<&YA
M;65N(&UO9V5N(&YI970@;&5E9R!Z:6IN`$=R;W5P<F5C:'1E;@!'<F]E<&5N
M`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1V%S="!R96-H
M=&5N`$=A<W0@<F5C:'1E;@!'87-T96YB;V5K`$=U:6YE90!'=6EN964M0FES
M<V%U`$=U>6%N80!(2`!(5$U,`$A434Q!<F5A('=E:6=E<G0@;&%F(&]M(&1E
M(&QA871S=&4@8V5L(&EN(&1E(')I:B!T92!V97)W:6ID97)E;BX`2%1-3$%R
M96$@=V5I9V5R="!L868@;VT@9&4@;&%A='-T92!K;VQO;2!I;B!D92!T86)E
M;"!T92!V97)W:6ID97)E;BX`2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@
M;&%A='-T92!R:6H@:6X@9&4@=&%B96P@=&4@=F5R=VEJ9&5R96XN`$A45%`@
M875T:&5N=&EC871I92!N:65T(&=E=F]N9&5N+@!(86ET:0!(87-H+6%L9V]R
M:71H;64`3F5V96P`2V]P`$AE87)D(&5I;&%N9"!E;B!-8T1O;F%L9"!E:6QA
M;F1E;@!(96)R965U=W,@*$E33RTX.#4Y+3@M22D`2&]O9W1E`$AE;'``2&5L
M<"!B:6H@9V5B<G5I:R!V86X@961I=&]R`$AE;'!E<@!(96QP=&]E<&%S<VEN
M9R!O;2!V97)T86QI;F=E;B!T92!M86ME;B!E;B!T92!O;F1E<FAO=61E;B!V
M86X@:&5T($AO<F1E"G)A86UW97)K(&5N('II:FX@=&]E<&%S<VEN9V5N+@I,
M965S+"!T97(@:6YT<F]D=6-T:64L(&AE="!214%$344@8F5S=&%N9"!I;B!D
M97IE(&1I<F5C=&]R>2X`2&%L9G)O;F0`2&EE<B!I<R!H970@8F5G:6X@=F%N
M(&AE="!B97-T86YD.@!(;V]G`$AI<W1O<GD@:6YV;V5R(&YA;65N(&UO9V5N
M(&YI970@;&5E9R!Z:6IN`$AO7VUE`$AO;'D@4V5E("A6871I8V%A;G-T860I
M`$AO;64`061R97,@*'!R:7;I*0!496PN;G(N("AP<FEVZ2D`2&]N9'5R87,`
M2&]N9R!+;VYG`$AO<F1E`$AO<F1E('9E<G1A;&EN9R!G96YE<F%T;W(`2&]R
M9&4O2V]L86(Z($]N9V5L9&EG92`E<R!834P@9&%T82!T96=E;F=E:V]M96X@
M:6X@8F5R:6-H="`E<P!(;W)D92]+;VQA8CH@1V5E;B!B97)I8VAT(&-O<G)E
M<W!O;F1E97)T(&UE="!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($=E96X@;V)J
M96-T('9A;B!T>7!E("5S(&=E=F]N9&5N(&EN(&)E<FEC:'0@)7,`2&]R9&4O
M2V]L86(Z("5S(&UE="!S=6-C97,@=F5R=VEJ9&5R9"`B)7,B`$AO<F1E+TMO
M;&%B.B`E<R!M970@<W5C8V5S(&=E<WEN8VAR;VYI<V5E<F0@(B5S(@!(;W)D
M92]+;VQA8CH@1&4@:6YT97)G<F%T:64@=F5R96ES="!D92`G9&]M>&UL)R!E
M>'1E;G-I90!(;W)D92]+;VQA8CH@2V%N(&=E96X@;FEE=7=E(%A-3"!B;V]M
M(&UA:V5N('9O;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!+86X@)7,@(B5S
M(B!N:65T('9E<G=I:F1E<F5N.B`E<P!(;W)D92]+;VQA8CH@3FEE="!I;B!S
M=&%A="!H970@34E-12!)1"P@=F]O<B!H970@9V5D965L=&4@;65T('1Y<&4@
M)7,L(&]P('1E(&AA;&5N`$AO<F1E+TMO;&%B.B!+86X@)7,@(B5S(B!N:65T
M('-Y;F-H<F]N:7-E<F5N.B`E<P!(;W)D92]+;VQA8CH@2V%N(&=E9&5E;&1E
M(&)R;VYN96X@;FEE="!S>6YC:')O;FES97)E;CH@)7,`2&]R9&4O2V]L86(Z
M($]N8F5K96YD92!G961E96QD92!B<F]N("(E<R(`2&]R:7IO;G1A;&4@;&EJ
M;@!(;W)I>F]N=&%L92!V<FEJ92!R=6EM=&4`2&]R:7IO;G1A86PZ`$AO92!K
M=V%M('4@:&EE<C\@*$=R86%G(')A<'!O<G1A9V4A*0!(;V5V965L(&MO;&]M
M;65N('=I;'0@=2!S86UE;G9O96=E;C\`2&]E=F5E;"!V96QD96X@*&MO;&]M
M;65N*2!Z:6IN(&5R/P!(;V5V965L(')I:F5N('=I;'0@=2!S86UE;G9O96=E
M;C\`5F]C:'1I9VAE:60`5F]C:'1I9VAE:60Z(`!(=6UO<FES=&5N`$AO;F=A
M<FEJ90!-86ME;B!V86X@24U!4"!M86EL8F]X(&UI<VQU:W0Z("5S`%9E<G=I
M:F1E<F5N('9A;B!)34%0(&UA:6QB;W@@;6ES;'5K=#H@)7,`36%K96X@=F%N
M($E-05`@;6%I;&)O>"!Q=6]T82!M:7-L=6MT.B`E<P!)4"!!9')E<P!)4"!A
M9')E<R!N:65T(&)E<V-H:6MB86%R+@!)4"!A9')E<R!V86QT(&YI970@8FEN
M;F5N(&AE="!T;V5G97-T86YE($-)1%(@8FQO:RX`25`@;&]C:V1O=VX@;W9E
M<G1R961I;F<N`%)I:B!I7VYV;V5G96X@=F]O<@!)2G-L86YD`$%L;&5E;B!P
M:6-T;V=R86UM96X`4&EC=&]G<F%M;65N('9O;W(@)7,`4&EC=&]G<F%M;65N
M(&UE="!T96MS=`!)9&5N=&ET96ET<VYA86TZ`%=A;FYE97(@:&5T(&YI970@
M9V]E9"!W;W)D="!W965R9V5G979E;BP@)7,@;VT@:&5T(&EN(&5E;B!N:65U
M=R!S8VAE<FT@=&4@;W!E;F5N+@!!;',@=2!G965N('!I8W1O9W)A;6UE;B!Z
M:65T+"!B:6H@9V5B<G5I:R!V86X@26YT97)N970@17AP;&]R97(L(&MA;B!H
M970@;F]D:6<@>FEJ;B!D:70@=F%K:F4@86%N('1E('9I;FME;B!O;2!03D<@
M=')A;G-P87)A=&EE('5I="!T92!S8VAA:V5L96XN`%=A;FYE97(@=2!D:70@
M8F5R:6-H="!Z:65T+"!M86%R(&=E96X@869B965L9&EN9RP@9&%N(&MA;B!D
M92!A9F)E96QD:6YG(&1I92!U('=I;'0@=7!L;V%D96X@;FEE="!D;V]R('5W
M(&)R;W=S97(@=V]R9&5N('=E97)G96=E=F5N+@!!9F)E96QD:6YG<V)E;V]R
M9&5L:6YG.@!!9F)E96QD:6YG(%523`!!9F)E96QD:6YG(%523#H`069B965L
M9&EN9R!U:70@86QB=6T`069B965L9&EN9R!U:70@86QB=6TZ`$%F8F5E;&1I
M;F=S=7!L;V%D`$%F8F5E;&1I;F=E;@!);7!O<G1E<F5N+"!S=&%P("5D`$=E
M:6UP;W)T965R9"!V96QD.B`E<P!'96EM<&]R=&5E<F1E('9E;&1E;CH`26X@
M8F5H86YD96QI;F<`4FEJ(&EN=F]E9V5N(&YA`$]N:G5I<W1E(&)E=V5R:VEN
M9W-C;V1E(&]P9V5G979E;BX`3VYJ=6ES=&4@9V5B<G5I:V5R<VYA86T@96XO
M;V8@=V%C:'1W;V]R9"X`3VYJ=6ES=&4@9V5B<G5I:V5R<VYA86T@;V8@86QT
M97)N871I968@861R97,N(%!R;V)E97(@;W!N:65U=R!O9B!N965M(&-O;G1A
M8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(L('=A;FYE97(@=2!V97)D
M97)E(&AU;'`@;F]D:6<@:&5E9G0N`%9E<F=R;V]T(&EN<W!R:6YG:6YG`$EN
M9&EA`$EN9&EV:61U96QE(&=E8G)U:6ME<G,`26YD;VYE<VGK`$EN9F\`26YF
M;W)M871I90!);FET:6%L:7-E<F5N('9A;B!M;V1U;&4@)7,N+BX@`$MO;&]M
M(&EN=F]E9V5N(&YA`$%F8F5E;&1I;F<@:6YV;V5G96X`5&%B96P@:6YV;V5G
M96X`5V5B;&EN:R!I;G9O96=E;@!?2V]L;VT@:6YV;V5G96X@=F]O<@!%96X@
M;FEE=7=E(&MO;&]M(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4`165N(&YI975W
M92!K;VQO;2!I;G9O96=E;B!V;V]R(&1E(&AU:61I9V4`165N(&YI975W92!R
M:6H@:6YV;V5G96X@;F$@9&4@:'5I9&EG90!%96X@;FEE=7=E(')I:B!I;G9O
M96=E;B!N82!D92!H=6ED:6=E`$5E;B!N:65U=V4@<&%R86=R86%F(&EN=F]E
M9V5N(&YA(&1E(&AU:61I9V4@;F]D90!%96X@;FEE=7=E('!A<F%G<F%A9B!I
M;G9O96=E;B!N82!D92!H=6ED:6=E(&YO9&4`06QT97)N871I968@<VIA8FQO
M;VX@:6YV;V5G96X`165N(&4M;6%I;&%D<F5S(&EN=F]E9V5N+"!W86%R('4@
M:&5T(&YI975W92!W86-H='=O;W)D(&MA;B!O;G1V86YG96XZ`$-E;"!I;G9O
M96=E;B!N80!#96P@:6YV;V5G96X@=F]O<@!+;VQO;2!I;G9O96=E;B!N80!+
M;VQO;2!I;G9O96=E;B!V;V]R`$)E<FEC:'1E;B!I;G9O96=E;@!087)A9W)A
M868@:6YV;V5G96X@;F$`4&%R86=R86%F(&EN=F]E9V5N('9O;W(`4FEJ(&EN
M=F]E9V5N(&YA`%)I:B!I;G9O96=E;B!V;V]R`$AE="!G97=E;G-T92!A;G1W
M;V]R9"!V;V]R(&1E(&)E=F5I;&EG:6YG<W9R86%G(&EN=F]E9V5N.@!!9F)E
M96QD:6YG(&EN=F]E9V5N+V%A;G!A<W-E;@!,:6YK(&EN=F]E9V5N+V%A;G!A
M<W-E;@!/;G9O;&1O96YD92!K<F5D:65T(&]M(&YA87(@9&4@9&ES=')I8G5T
M:65L:6IS="!T92!Z96YD96XN`$]N=F]L9&]E;F1E(&MR961I970`26YT96=E
M<@!);G1E9V5R(&QI:G-T`$]N9V5L9&EG92!B97=E<FMI;F<@9V5S96QE8W1E
M97)D('9O;W(@9&ET(&]N9&5R9&5E;"X`3VYG96QD:6=E(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+@!/;F=E;&1I9V4@=&]E<&%S<VEN9RX`3VYG96QD:6<@
M8F%T8V@@240N`$]N9V5L9&EG92!D871A(&]P9V5G979E;BX`3VYG96QD:6<@
M8F5S=&5M;6EN9V%D<F5S+@!/;F=E;&1I9R!T:6ID9F]R;6%A=`!/;F=E;&1I
M9R!M<V=?='EP92X`3VYG96QD:6<@;V8@;VYT8G)E:V5N9"!A<&E?:60N`$]N
M9V5L9&EG92!O9B!O;G1B<F5K96YD92!P87)A;65T97)S+@!/;F=E;&1I9R!P
M87)E;G0@<F5C:'0N`$]N9V5L9&EG('!R;W1O8V]L+@!/;F=E;&1I9V4@;VYT
M=F%N9V5R.B`G)7,G`$]N9V5L9&EG92!G961E96QD92!B<F]N`$]N9V5L9&EG
M(&)R;VYA9')E<RX`3VYG96QD:6=E('5N:6-O9&4@9&%T82X`26YV96YT87)I
M<P!)<F%N+"!)<VQA;6ET:7-C:&4@4F5P=6)L:65K('9A;@!)<F%K`$EE<FQA
M;F0`16EL86YD($UA;@!'96ES;VQE97)D92!O;G=E97)S8G5I96X`27-R8>ML
M`%5I=&=E=F5R`$-U<G-I968`271A;&GK`$IA;6%I8V$`2F%N=6%R:0!*87!A
M;@!*87!A;G,@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:>L`2G5L:0!*
M=6YI`'5I=&QI:FYE;@!'96-E;G1R965R9"!U:71L:6IN96X`5F]L;&5D:6<@
M=6ET;&EJ;F5N`$QI;FMS('5I=&QI:FYE;@!296-H=',@=6ET;&EJ;F5N`$MA
M>F%C:'-T86X`3W)I9VEN965L(&)E:&]U9&5N/P!+96YI80!+97)B97)O<R!S
M97)V97(@=V5I9V5R9&4@875T:&5N=&EC871I92X`2V5R;F5L($YE=V)I97,`
M4VQE=71E;"!M86ME;@!3;&5U=&5L=FEN9V5R869D<G5K`%-L975T96QL96YG
M=&4`4VQE=71E;'1Y<&4`4VQE=71E;&=E8G)U:6L`1&4@<VQE=71E;"!B97-T
M86%T(&%L(&]P(&1E(&]P96YB87)E('-L975T96QS97)V97(N`$MI;F1E<F5N
M`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K
M('9A;@!+;W)E82P@4F5P=6)L:65K('9A;@!+;W)E86%N<R`H155#+4M2*0!+
M;V5W96ET`$MY<F=I97-IZP!/7W!M86%K`%1A86P`1&5M;V-R871I<V-H92!6
M;VQK<W)E<'5B;&EE:R!,86\`3&%A='-T92!H96QF=`!,86%T<W1E(&MW87)T
M:65R`$QA871S="!B:6IG97=E<FMT.@!,86%T<W1E(&%A;FUE;&1I;F<Z("5S
M`$QA871S=&4@86%N;65L9&EN9SH@)7,@=F%N("5S`$QA871S=&4@86%N;65L
M9&EN9SH@3F]O:70`3&5T;&%N9`!296-H=&5N`$]P;6%A:P!,86%T(&QE96<@
M=F]O<B!G965N(')A;F0`3&EB86YO;@!,:6YK<P!,:6YK<V4@:V]P`$QI;FMS
M92!W86%R9&5N`$QE<V]T:&\`3&EB97)I80!,:6)I<V-H92!!<F%B:7-C:&4@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`%IA8VAT(&)U:71J90!,:6-H=&4@
M<F5G96X`5G)O96<@;&EC:'1E(')E9V5N`$QI8VAT92!R96=E;@!,:6-H=&4@
M<F5G96YB=6D`3&EC:'1E(')E9V5N(&UE="!O;G=E97(`3&EC:'1E('-N965U
M=P!,:6-H=&4@<VYE975W8G5I`$QI;65R:6-K`$QI;FL`3&EN:R!W:6IS="!N
M86%R.@!,:6YK(&AE="!E+6UA:6QA9')E<R!A86X@9&4@;FEE=7<@8F5R:6-H
M="!P86=I;F$@=&EJ9&5N<R!W965R9V%V90!,:6YK<P!,:6YU>"!#;V]K:64`
M3&EJ<W0@+2!G96)R=6EK97(@:V%N(&1E(&UA<"!Z:65N`$1A=&%B87-E;&EJ
M<W0`3&EJ<W0@=F%N(&AE;'`@;VYD97)D96QE;@!486)E;&QI:G-T`$QI:G-T
M+4%R8VAI968`3&EJ<W0M2&5L<`!,:6IS="U)9`!,:6IS="U%:6=E;F%A<@!,
M:6IS="U0;W-T`$QI:G-T+4EN<V-H<FEJ=F5N`$QI:G-T+55I='-C:')I:G9E
M;@!7965R9V5V96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!U:71G97-C:&%K
M96QD+@!,:71E<F%T=75R`$QI=&]U=V5N`$QA9&5N(&)I8FQI;W1H96ME;BXN
M+@!,861E;BXN+@!,;VMA;&4@=&EJ9#H`3&%N9&EN<W1E;&QI;F<@96X@=&EJ
M9`!,;V-A=&EE`$%A;FUE;&1E;@!!9FUE;&1E;@!!86YM96QD=&%K96X`06%N
M;65L9&EN9R!M:7-L=6MT(&]M9&%T('5W(&=E8G)U:6ME<G-N86%M(&]F('=A
M8VAT=V]O<F0@;VYJ=6ES="!I<R!I;F=E=F]E<F0N`$%A;FUE;&1I;F<@;6ES
M;'5K="X`069M96QD96X`3&%N9V4@=&5K<W0`3&EE9F1E`$QA86<`1W)I96MS
M92!K;&5I;F4@;&5T=&5R<P!,871I:FYS92!K;&5I;F4@;&5T=&5R<P!+;&5I
M;F4@4F]M96EN<V4@9V5T86QL96X`3'5X96UB=7)G`$U-`$U/5$0`35,M5$Y%
M1B!B:6IL86=E(&)E=F%T=&4@9V5E;B!D871A+@!-4T<`36%C86\`36%C961O
M;FGK+"!$92!V<F]E9V5R92!*;V5G;W-L879I<V-H92!297!U8FQI96L@=F%N
M`$UA9&%G87-C87(`36%G:64`12UM86EL`$UA:6QB96AE97)D97(`36%A:R!L
M:6Y?:RXN+@!,970@;W`Z(%!%05(@9&EE;G0@9V7O;G-T86QL965R9"!T92!Z
M:6IN(&5N(&EN('5W(&EN8VQU9&4@<&%T:"!T92!S=&%A;BX`36%A:R!D:7)E
M8W1O<GD@)7,`36%L87=I`$UA;&5I<VGK`$UA;&%D:79E;@!-86QI`$UA;'1A
M`$)E:&5E<B!U=R!L:6IS="!M970@8V%T96=O<FEEZVX@96X@9&4@8V]R<F5S
M<&]N9&5R96YD92!K;&5U<F5N+"!W86%R;65E(&]N9&5R9&5L96X@=V]R9&5N
M(&=E;&%B96QD`$UA<#(T(&MA87)T`$UA<%%U97-T:V%A<G0`36%A<G0`36%R
M9V4`36%R:V5E<B!M970@1V5Z:65N+TYI970@1V5Z:65N('9L86=G96X`36%R
M:V5E<B!M970@86YD97)E('9L86=G96X@*&(N=BX@0F5L86YG<FEJ:R]"96%N
M='=O;W)D*0!-87)C:&%L;"!E:6QA;F1E;@!-87)T:6YI<75E`$]V97)E96YK
M;VUE;F1E('9E;&1E;@!-875R971A;FGK`$UA=7)I=&EU<P!-87AI;6%A;"!T
M;V5G97-T86%N(&MR961I970N`$UA>&EM=6T@8F5R:6-H=&]N9&5R9&5L96X@
M;W9E<G-C:')E9&5N+@!-87AI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E
M;&]P96X@,C0@=75R.B``36%X:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G
M96QO<&5N(#8@=75R.B``36%X:6UA;&4@;&5N9W1E`$UE:0!-87EO='1E`$=E
M;F5E<VMU;F1E`%9E<F=A9&5R:6YG<V%F>F5G9VEN9P!697)G861E<FEN9W-I
M;F9O<FUA=&EE`%9E<F=A9&5R:6YG<W9O;W)S=&5L`%9E<F=A9&5R:6YG<V%N
M='=O;W)D`%9E<F=A9&5R:6YG<W5P9&%T90!697)G861E<FEN9W-U<&1A=&5V
M97)Z;V5K`$QE9&5N`$UE;G4@;6]D93H`0V5L;&5N('-A;65N=F]E9V5N`$%L
M;&4@)7,N<&\@8F5S=&%N9&5N('-A;65N=F]E9V5N(&UE="!H970@8V]M<&5D
M:75M+BXN(`!,86YD:6YS=&5L;&EN9R`E<R!S86UE;G9O96=E;BXN+B``4$\@
M8F5S=&%N9"!V;V]R("5S('-A;65N=F]E9V5N(&UE="!H970@8V]M<&5N9&EU
M;2XN+B``5F5R=&%L:6YG('9O;W(@;6]D=6QE("5S('-A;65N=F]E9V5N+BXN
M`$)E<FEC:'0`0F5R:6-H="!M970@<W5C8V5S(&=E=F5R:69I965R9"P@;6%A
M<B!H970@8V5R=&EF:6-A870@=F%N(&1E(&]N9&5R9V5T96ME;F1E(&MO;B!N
M:65T('=O<F1E;B!G979E<FEF:65E<F0N`$)E<FEC:'0@=F5R;&]P96XN`$)E
M<FEC:'1T>7!E`$UE=&%R(%=E97(`345405(@8FQO:R!I<R!N:65T(&)E<V-H
M:6MB86%R+@!-151!4B!B;&]K(&ES(&YI970@8F5S8VAI:V)A87(N($1E=&%I
M;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S>7-T965M8F5H965R9&5R+@!-971H
M;V1E`$UE=&AO9&4@)R5S)R!I<R!N:65T(&=E9&5F:6YI965R9`!-971R:7-C
M:`!-97AI8V\`36EC<F]N97-IZRP@1F5D97)A;&4@4W1A=&5N('9A;@!-:61D
M96X`36EM92!T>7!E`$UI;FEM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L
M;W!E;B`R-"!U=7(Z(`!-:6YI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E
M;&]P96X@-B!U=7(Z(`!-:7)R;W(`06QL97)H86YD90!/;G1B<F5K96YD92!0
M14%2(&UO9'5L92!(5%107U)E<75E<W0N`$]N=&)R96ME;F1E(&-O;F9I9W5R
M871I92X@52!D:65N="!D97IE(&YU('1E(&=E;F5R97)E;BP@=V%N;F5E<B!U
M(&1E>F4@=&]E<&%S<VEN9R!W:6QT(&=E8G)U:6ME;BX`3VYT8G)E:V5N9"!B
M97)I8VAT($E$+@!/;G1B<F5K96YD92P@=F5R96ES=&4L(%!%05(@;6]D=6QE
M($UA:6PN`$]N=&)R96ME;F0@<V5S<VEE($E$+@!-80!-;V)I96QE(&4M;6%I
M;`!'96UI9&1E;&0`5VEJ>FEG:6YG<V1A='5M`%=I:GII9R!54DP`36]D=6QE
M`$UO9'5L=7,`36]L9&%V:>LL(%)E<'5B;&EE:R!V86X`36]N86-O`$UO;F=O
M;&GK`$UA86YD(&5N(&IA87(`36%A;F1E;&EJ:W,`36]N='-E<G)A=`!-86%N
M9F%S96X`36%R;VMK;P!6;V]R;F%M96QI:FL@;VYB97=O;&MT`%9O;W)N86UE
M;&EJ:R!B97=O;&MT`%9O;W)N86UE;&EJ:R!Z;VYN:6<`3F%A<B!B96YE9&5N
M`$YA87(@;&EN:W,`3F%A<B!R96-H=',`3F%A<B!B;W9E;@!.86%R(&)E;F5D
M96X`3F%A<B!B;W9E;@!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:6IS=&5N`$UE97)V;W5D:6=E('-E;&5C=&EE`$UI:FX@86-C;W5N=`!-
M:6IN('!O<G1A86P`36EJ;B!P;W)T86%L;&%Y;W5T`$)I<FUA`$YE92P@:6L@
M86-C97!T965R(&1E('9O;W)W86%R9&5N($Y)150`3F%A;0!.86UI8FGK`$YA
M=7)U`$AA;F1E;&EN9R!N;V1I9P!.97!A;`!.961E<FQA;F0`3F5D97)L86YD
M<R!!;G1I;&QE;@!.971S8V%P92!"87-I<R!54DP`3F5T<V-A<&4@0T$@:6YT
M<F5K:VEN9R!54DP`3F5T<V-A<&4@0T$@8F5L96ED(%523`!.971S8V%P92!V
M97)N:65U=VEN9R!54DP`3F5T<V-A<&4@:6YT<F5K:VEN9R!54DP`3F5T<V-A
M<&4@4U-,('-E<G9E<FYA86T`3F5T<V-A<&4@8V5R=&EF:6-A871C;VUM96YT
M86%R`$YE='-C87!E(&-E<G1I9FEC86%T='EP90!.971W97)K`$YO;VET`$YI
M975W($-A;&5D;VYIZP!.:65U=V4@8V%T96=O<FEE`$YI975W92!M86%N`$YI
M975W92!G96)R=6EK97)S;F%A;2`H;W!T:6]N965L*0!.:65U=R!:965L86YD
M`$YI975W('=A8VAT=V]O<F0Z`$YI975W('-C:&5R;2`H7V)L86YK*0!.:65U
M=W,`3FEE=7=S9W)O97!E;@!6;VQG96YD90!6;VQG96YD92!P86=I;F$`5F]L
M9V5N9&4@9F%S90!6;VQG96YD92!O<'1I97,`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3F%C:'0`3FEU90!.964`1V5E;B!B97-C:&EK8F%R92!C;VYF:6=U
M<F%T:65D871A(&]M('9E<G-C:&EL;&5N('1E(&QA=&5N('II96XN`$=E96X@
M8F5S8VAI:V)A<F4@<W1R871E9VEE('9O;W(@:&5T(&UA:V5N('9A;B!)4T\@
M:6UA9V5S+@!'965N(&)A=&-H<VIA8FQO;VXN`$5R(&)E<W1A870@9V5E;B!B
M;&]K(&]P(&1E(&=E=G)A86=D92!P;W-I=&EE`$=E96X@86=E;F1A;F%A;2!O
M<&=E9V5V96X@=F]O<B!-0T%,(&%U=&AE;G1I8V%T:64N`$=E96X@=VEJ>FEG
M:6YG96XN`$]N9&5R(&1I="!N:79E874@=V]R9&5N(&=E96X@8VAI;&0@<F5C
M:'1E;B!T;V5G979O96=D+@!!86X@9&ET(')E8VAT(&MU;FYE;B!G965N(&-H
M:6QD(')E8VAT96X@=V]R9&5N('1O96=E=F]E9V0N`$=E96X@;W!D<F%C:'0@
M;W!G96=E=F5N+@!'965N(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E
M=F5N('9O;W(@)7,N`$=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E
M9V5V96X@=F]O<B!&5%`@5D93+@!'965N(&-O;F9I9W5R871I96EN9F]R;6%T
M:64@;W!G96=E=F5N('9O;W(@4U%,(%9&4RX`1V5E;B!C;VYF:6=U<F%T:65I
M;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R(%-13"UB97-T86YD(%9&4RX`1V5E
M;B!K<F5D:65T(&UE97(N`$=E96X@8F5S=&5M;6EN9R!O<&=E9V5V96XN`$5R
M(&)E<W1A870@9V5E;B!I;G9O97(@;65T(&ED("<E<R<@:6X@:&5T(&]R:6=I
M;F5L92!H96QP(&)E<W1A;F0N`$=E96X@8F5S=&%N9"!U<&QO861E9`!'965N
M('!I8W1O9W)A;6UE;B!G979O;F1E;BX`1V5E;B!L86YD:6YS=&5L;&EN9R!O
M<&=E9V5V96XN`$5R(&ES(&=E96X@;&]C871I92!I;F=E<W1E;&0N`$=E96X@
M8F5R:6-H="!G96QE=F5R9"X`1V5E;B!N86%M(&]P9V5G979E;BX`1V5E;B!G
M971A;"!O<&=E9V5V96XN`$=E96X@8F5L961I9V5N9&4@9F]R='5N97,`1V5E
M;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R($A45%`@875T:&5N=&EC871I
M92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R($E-05`@875T:&5N
M=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V86X@2V5R8F5R
M;W,@875T:&5N=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V
M;V]R($Q$05`@875T:&5N=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G
M979E;B!V;V]R($QO9VEN(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R
M9"!O<&=E9V5V96X@=F]O<B!005-35T0@875T:&5N=&EC871I92X`1V5E;B!W
M86-H='=O;W)D(&]P9V5G979E;B!V;V]R(%--0B!A=71H96YT:6-A=&EE+@!'
M965N('!A9"!N86%R(&1E($]P96Y34TP@8FEN87)Y(&]P9V5G979E;BX@1&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F]D:6<@;VT@=&4@:W5N;F5N('=E<FME;B!M
M970@4$M#4R`Q,B!D871A+@!'965N(&AA;F=E;F1E(&EN<V-H<FEJ=FEN9V5N
M+@!'965N(&QI;FGK<FEN9P!'965N('II:F1E;@!'965N('1I:F1E;&EJ:R!D
M:7)E8W1O<GD@8F5S8VAI:V)A87(@=F]O<B!C86-H92X`1V5E;B!G96)R=6EK
M97)S;F%A;2!E;B]O9B!W86-H='=O;W)D('9E<GIO;F1E;BX`1V5E;B!G96QD
M:6=E(%A-3"!D871A('1E<G5G9V5S='5U<F0`1V5E;B!W86%R9&5N`$=E96X@
M=F5R<VEE(&=E=F]N9&5N(&EN(&]R:6=I;F5L92!C;VYF:6=U<F%T:64N($AE
M<F=E;F5R965R(&-O;F9I9W5R871I92X`1V5E;B!V97)S:64@9V5V;VYD96X@
M:6X@=7<@8V]N9FEG=7)A=&EE+B!(97)G96YE<F5E<B!C;VYF:6=U<F%T:64N
M`$=E96X@9&5E;&YE;65R`$=E96X`1V5E;B`H=F5R<&QI8VAT*0!.;V]R9"!%
M=7)O<&5E<R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@96EL86YD`$YO;W)D96QI
M:FL@:&%L9G)O;F0`36%R:6%N96X`3F]O<G=E9V5N`$YI970@;F$`3FEE="!V
M;V]R`$=E96X@9&ER96-T;W)Y`$YI970@9V5I;7!L96UE;G1E97)D+@!.:65T
M(&EN9V5S=&5L9`!.:65T(&]N9&5R<W1E=6YD+@!.;W1I=&EE<P!.:65T<R!T
M92!B;&%D97)E;BP@9V$@=&5R=6<N`$]P;65R:VEN9P!.;W9E;6)E<@!'971A
M;`!!86YT86P@:V%R86MT97)S`$%A;G1A;"!K;VQO;6UE;@!!86YT86P@<FEJ
M96X`1V5T86QL96X@;FEE="!O<&=E9V5V96X@=F]O<B!B:6IW97)K96X@:6X@
M965N(&1I<W1R:6)U=&EE;&EJ<W0N`$]+`$]B:F5C=`!/8FIE8W1E:6=E;F%A
M<@!'96)E=7)T96YI<R!E:6=E;F%A<G)E8VAT96X`3V-T86%L`$]K=&]B97(`
M0F5L961I9VEN9V9I;'1E<@!+86YT;V]R`$]U9"!W86-H='=O;W)D.@!/;6%N
M`$%L;&5E;B!)34%0('-E<G9E<G,@;VYD97)S=&5U;F5N(&=E9&5E;&1E(&UA
M<'!E;BX`06QL965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S`%-L96-H="#IZ6X@
M92UM86EL861R97,@=&]E9V5S=&%A;BX`06QL965N(&1E(&5I9V5N86%R(&]F
M(&5E;B!S>7-T965M8F5H965R9&5R(&UA9R!D92!E:6=E;F%A<G)E8VAT96X@
M=F%N(&5E;B!S:&%R92!W:6IZ:6=E;@!/<&5N(&EN(&5E;B!N:65U=R!S8VAE
M<FT`3W!E;E-33"!F;W5T.B!K;VX@9V5E;B!D871A('5I="!H970@;VYD97)T
M96ME;F1E(%,O34E-12!O;F1E<F1E96P@:&%L96XN`$]P96YT(&1E>F4@;&EN
M:R!I;B!E96X@;FEE=7<@<V-H97)M`$)E<W1U<FEN9W-S>71E96T`17AT<F$@
M9&5E;&YE;65R`$]P=&EE<P!/<'1I97,@=F]O<B`E<P!/<'1I97,Z`$=E;W)D
M96YD92!L:6IS=`!/<F=A;FES=&%T:64`3W)G86YI<V%T:64@965N:&5I9`!/
M<F=A;FES97)E;@!/<FEG:6YE96P@=&]E<&%S<VEN9W-S:F%B;&]O;@!/<FEG
M:6YE;&4@<VIA8FQO;F5N(&EN("5S.@!!;F1E<F4`06YD97)E(&EN9F]R;6%T
M:64`16EG96YA87)R96-H=&5N`%!!32!A=71H96YT:6-A=&EE(&ES(&YI970@
M8F5S8VAI:V)A87(N`$1I9VET86QE(%!'4"!H86YD=&5K96YI;F<`1V5C;V1E
M97)D92!01U`@9&%T80!/<&5N8F%R92!01U`@<VQE=71E;`!/;F1E<G1E:V5N
M9&4O9V5C;V1E97)D92!01U`@9&%T80!02%`@8V]D90!02%`@<VAE;&P`3&EC
M:'1E(')E9V5N(&YA(#$R+C`P('5U<@!"=6EE;B!N82`Q,BXP,"!U=7(`4VYE
M975W(&YA(#$R+C`P('5U<@!3;F5E=7=B=6EE;B!N82`Q,BXP,"!U=7(`3VYW
M965R<V)U:65N(&YA(#$R+C`P('5U<@!02%`@7U-H96QL`%9R:6IE(')U:6UT
M90!086MI<W1A;@!086QA=0!086QE<W1I:FYS(%1E<G)I=&]R:75M+"!"97IE
M=`!086YA;6$`4&%P=6$@3FEE=7<@1W5I;F5A`%!A<F%G=6%Y`$=E9&5E;'1E
M;&EJ:R!B97=O;&MT`%=A8VAT=V]O<F0`5V%C:'1W;V]R9"!V97)A;F1E<F0A
M`%=A8VAT=V]O<F0@;VYJ=6ES=`!087-S=V]R9"!I<R!N:65T(&IU:7-T(&=E
M8V]N9FEG=7)E97)D`%=A8VAT=V]O<F0@:7,@=F5R96ES="!V;V]R(%)!1$E5
M4R!A=71H96YT:6-A=&EE+@!786-H='=O;W)D(&UE="!B979E<W1I9VEN9P!7
M86-H='=O;W)D.@!786-H='=O;W)D.B``5V%C:'1W;V]R9&5N(&UO971E;B!O
M=F5R965N:V]M96XN`%!L86MK96X`4&QA:VME;B!V86YA9B!P<FEK8F]R9`!0
M860`2&%N9V5N9&4@:6YS8VAR:6IV:6YG96XZ`$UE;G-E;@!0<F]C96YT`$]N
M9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I='9O97)E;@!/;F1E<FAO=61S=V5R
M:WIA86UH961E;B!U:71V;V5R96X@8FEJ(&%A;FUE;&1I;F<_`%)E8VAT`%)E
M8VAT("<E<R<@;FEE="!V97)W:6ID97)D+@!296-H=&5N8F5H965R`%)E8VAT
M96X@=F]O<@!097)S;V]N;&EJ:V4@:6YF;W)M871I90!097)U`$AU:7-D:65R
M96X`4&AI;&EP<&EJ;F5N`%1E;&5F;V]N`$9O=&\G<P!0:71C86ER;@!0:7AE
M;',`4&QA=&ET=61E<P!+;&EK(&EN(&5E;B!C96PL(&$N=2YB+@!"979E<W1I
M9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!V97)W:6ID97)E;BP@82YU+F(Z
M`$)E=F5S=&EG+"!D870@=2!D:70@96QE;65N="!W:6QT(&QO<VMO<'!E;&5N
M+"!A+G4N8BX`1V5E9B!E96X@;6%A;F0@96X@965N(&IA87(L(&$N=2YB+@!%
M96X@;F%A;2!V;V]R(&1E(&YI975W92!C871E9V]R:64@:6YV;V5R96XL(&$N
M=2YB+CH`1V5E9B!E96X@9V5L9&EG($E0(&%D<F5S+"!A+G4N8BX`1V5E9B!E
M96X@9V5L9&EG92!D871U;2!A+G4N8BXL(&-O;G1R;VQE97(@:&5T(&%A;G1A
M;"!D86=E;B!I;B!D92!M86%N9"X`1V5E9B!E96X@9V5L9&EG92!T:6ID+"!A
M+G4N8BX`1V5E9B!E96X@<V%M96YV871T:6YG('9A;B!H970@<')O8FQE96TL
M(&$N=2YB+@!'965F('5W(&=E8G)U:6ME<G-N86%M(&5N('=A8VAT=V]O<F0L
M(&$N=2YB+@!,965S(&1E('9O;&=E;F1E('1E:W-T+"!A+G4N8BX@52!D:65N
M="!D92!V;V]R=V%A<F1E;B!T92!A8V-E<'1E<F5N(&]M(&AE="!S>7-T965M
M('1E(&=E8G)U:6ME;BX`4F%P<&]R=&5E<B!B=6=S(&YA87(@:3$X;D!L:7-T
M<RYH;W)D92YO<F<L(&$N=2YB+@!"96MI:FL@9&4@=F]L9V5N9&4@:6YF;W)M
M871I92!A+G4N8BX@96X@<V5L96-T965R(&1A87)N82!E96X@8F5W97)K:6YG
M('5I="!H970@;VYD97)S=&%A;F1E(&UE;G4N`%-E;&5C=&5E<B!E96X@8F5W
M97)K:6YG('5I="!H970@;VYD97)S=&%A;F1E(&UE;G4L(&$N=2YB+@!'965F
M(&1E(&YI975W92!C871E9V]R:65N86%M+"!A+G4N8BXZ`%!O;&5N`%!O;&ET
M:65K`%!E:6QI;F=E;@!0;W)T=6=A;`!0;W-I=&EO;F5R:6YG('9A;B!D97IE
M(&%F8F5E;&1I;F<`4&]S:71I;VYE<FEN9R!V86X@9&5Z92!T86)E;`!3='5U
M<B!N86%R(&1E>F4@;6%P("AN:65T(&%F9V5D=V]N9V5N(&1O;W(@24U!4"D`
M3F5E<G-L86<@=F%N(&1E(&%F9V5L;W!E;B`E<R!U<F5N.B``4')E9G-?;&1A
M<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!0<F5F
M<U]S97-S:6]N.B!V97)E:7-T92!S97-S:64@97AT96YT:64@;FEE="!G979O
M;F1E;BX`4')E<V5N=&%T:65S`$QU8VAT9')U:P!,=6-H=&1R=6L@;W`@>F5E
M;FEV96%U.B``3'5C:'1D<G5K.B``0F5O;W)D96QE;@!"96]O<F1E96P@9&4@
M869B965L9&EN9R!I;B!E96X@;FEE=7<@<V-H97)M`%9O<FEG92!P86=I;F$`
M5F]R:6=E(&]P=&EE<P!$;V-U;65N="!A9F1R=6MK96X`4')I=F4@<VQE=71E
M;`!0<F]B;&5E;0!0<F]B;&5E;6)E<V-H<FEJ=FEN9P!0<F]B;&5E;3\`4')O
M:F5C=&5N`%!R;VUP="!T96MS=`!/<&5N8F%R92!S;&5U=&5L`$]P96YB87)E
M('-L975T96P@86QG;W)I=&AM90!/<&5N8F%A<B]0<FEV92!S;&5U=&5L<&%A
M<B!N:65T(&=E9V5N97)E97)D+@!0=65R=&\@4FEC;P!1=6%T87(`475E<GD`
M4E-!(&]P96YB87)E('-L975T96P@*"5D(&)I="D`2V5U>F5R;VYD:F4@<V5L
M96-T:64`4F5G96X`5G)O96<@<F5G96X`3&%A="!R96=E;@!296=E;F)U:0!2
M96=E;B!E;B!S;F5E=7<`4F5G96X@=&]T('-N965U=P!286YD;VT@1F]R='5N
M90!697)H;W5D:6YG`$QE>F5N`$QE97,@8F5R:6-H=&5N`"5S(&5C:'0@=F5R
M=VEJ9&5R96X_($1E>F4@8F5W97)K:6YG(&MA;B!N:65T(&]N9V5D86%N(&=E
M;6%A:W0@=V]R9&5N+@!'96)R=6EK97)S9&%T82!V86X@9V5B<G5I:V5R("5S
M(&5C:'0@=F5R=VEJ9&5R96X_($1E>F4@8F5W97)K:6YG(&MA;B!N:65T(&]N
M9V5D86%N(&=E;6%A:W0@=V]R9&5N+@!(97)H86%L="!U=R!V;W)I9V4@8F5W
M97)K:6YG`%9E<G9E<G,@9'EN86UI<V-H92!M96YU(&]N9&5R9&5L96XZ`%!O
M<G1A;'=E97)G879E('9E<G9E<G-E;CH`4F5G97@`0F5T<F5K:VEN9V5N(&)R
M;W=S97(`3W!M97)K:6YG96X`3VYT:&]U9'0@9&4@=G)I:B]B97IE="!I;F9O
M<FUA=&EE+@!397)V97)S(&]P(&%F<W1A;F0`55),(&]P(&%F<W1A;F0@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!697)W:6ID97)E;@!";&]K
M('9E<G=I:F1E<F5N`$MO;&]M('9E<G=I:F1E<F5N`$]P;6%A:R!V97)W:6ID
M97)E;@!697)W:6ID97(@=6ET(&UI:FX@86=E;F1A`%!A87(@=F5R=VEJ9&5R
M96X`5F5R=VEJ9&5R(&AE="!O<&=E<VQA9V5N('-C<FEP="!U:70@9&4@=&EJ
M9&5L:6IK92!D:7)E8W1O<GD@;W`@9&4@<V5R=F5R+@!697)W:6ID97(@9&4`
M5F5R=VEJ9&5R(&1E>F4@;F]D92!U:70@:&5T(&1O8W5M96YT`$=E8G)U:6ME
M<B!V97)W:6ID97)E;@!697)W:6ID97(@9V5B<G5I:V5R.B`E<P!!;G1W;V]R
M9"!V97)Z;VYD96XN`$%N='=O;W)D(&UE="!.:65T($]N9&5R<W1E=6YD($)E
M<FEC:'0`06YT=V]O<F0@;65T('9R:6HO8F5Z970@=F]O<B!D92!V;VQG96YD
M92`R(&UA86YD96XN`$%N='=O;W)D(&UE="!G979R86%G9&4@=G)I:B]B97IE
M="!I;F9O<FUA=&EE+@!!;G1W;V]R9#H@)7,`5F5R>F]E:R!K;VX@;FEE="!W
M;W)D96X@8F5A;G1W;V]R9"X@1V5R971O=7)N965R9&4@9F]U=&-O9&4Z(`!6
M97)E:7-T92`G)7,G(&YI970@;W!G96=E=F5N(&EN("5S(&-O;F9I9W5R871I
M92X`5F5R96ES=&4@)R5S)R!N:65T(&]P9V5G979E;B!I;B!61E,@8V]N9FEG
M=7)A=&EE+@!697)E:7-T92`G)7,G(&YI970@;W!G96=E=F5N(&EN(&-O;F9I
M9W5R871I92X`5F5R96ES="!V96QD`%9E<F5I<W1E(&1E96QN96UE<@!(97)S
M=&5L;&5N`%)E<V5T('=A8VAT=V]O<F0`4F5S970@=7<@=V%C:'1W;V]R9`!2
M97-U;'1A=&5N`%)E<W5L=&%T96X@*&EN8VQU<VEE9B!(;W)D92DZ`%)E<W5L
M=&%T96XZ`%1E<G5G(&YA87(@;W!T:65S`%)E=6YI;VX`0V]N9FEG=7)A=&EE
M('1E<G5G>F5T=&5N`%)I8V@@5&5X="!%9&ET;W(@;W!T:65S`%)A861S96QS
M`%)E8VAT<P!296-H='-E(&MO<`!296-H='-E('=A87)D96X`4FE?:F5I9V5N
M<V-H87!P96XN+BX`4F]L`%)O96UE;FGK`#$X,"!D<F%A:65N`$YA87(@;&EN
M:W,@9')A86EE;@!.86%R(')E8VAT<R!D<F%A:65N`%)I:B!E:6=E;G-C:&%P
M<&5N`%)I:B!E:6=E;G-C:&%P<&5N`%)I:F5N.@!,:6YIZW)I;F<`3&EN:>MR
M:6YG('IA;"!V97)S8VAI:FYE;B!T=7-S96X@86QL92!R:6IE;B!E;B!K;VQO
M;6UE;@!,:6YIZW)I;F<@>F%L(&%L;&5E;B!T=7-S96X@:V]L;VUM96X@=F5R
M<V-H:6IN96X`3&EN:>MR:6YG('IA;"!A;&QE96X@='5S<V5N(')I:F5N('9E
M<G-C:&EJ;F5N`%-T87)T96X`4G5S<VES8VAE($9E9&5R871I90!2=V%N9&$`
M0W)Y<'1O9W)A9FES8VAE(%,O34E-12!H86YD=&5K96YI;F<`4R]-24U%(&=E
M8V]D965R9"!B97)I8VAT`%-!4TP@875T:&5N=&EC871I92!I<R!N:65T(&)E
M<V-H:6MB86%R+@!335,@=F5R<W1U<F5N`%-13"!S:&5L;`!34P!34T@`4U5#
M0T53`%-?44P@<VAE;&P`6F$`4W0@2&5L96YA`%-T($MI='1S(&5N($YE=FES
M`%-T($QU8VEA`%-T(%!I97)R92!E;B!-:7%U96QO;@!3="!6:6YC96YT(&5N
M(&1E($=R96YA9&EN97,`6F5L9F1E(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!E;B!0<FEN8VEP90!3871E;&QI971P<F]V:61E
M<@!3875D:2!!<F%B:>L`3W!S;&%A;@`E<R!O<'-L86%N`"<E<R<@;W!S;&%A
M;@!/<'1I97,@;W!S;&%A;@!'96=E;F5R965R9&4@8V]N9FEG=7)A=&EE(&%L
M<R!02%`@<V-R:7!T(&]P9V5S;&%G96X@:6X@9&4@=&EJ9&5L:6IK92!D:7)E
M8W1O<GD@=F%N('5W('-E<G9E<BX`)7,@8V]N9FEG=7)A=&EE(&]P9V5S;&%G
M96X`4V5T=7`@=7!G<F%D92!S8W)I<'0@;W!G97-L86=E;B!N86%R.B`G)7,G
M+@!7971E;G-C:&%P`%IO96ME;@!:;V5K;6%C:&EN97,`2&]R9&4@=&]E<&%S
M<VEN9V5N('IO96ME;B!I;B`E<P!'971T97AT('!R;V=R86UM82=S('IO96ME
M;BXN+@!+:65S(&)E<W1A;F1E;@!396QE8W1E97(@965N(&1A='5M`%-E;&5C
M=&5E<B!E96X@9W)O97`@;VT@=&]E('1E('9O96=E;@!396QE8W1E97(@965N
M(&YI975W92!E:6=E;F%A<@!396QE8W1E97(@965N('-E<G9E<@!396QE8W1E
M97(@965N(&=E8G)U:6ME<B!O;2!T;V4@=&4@=F]E9V5N`%-E;&5C=&5E<B!A
M;&QE(&1A='5M8V]M<&]N96YT96XN`%-E;&5C=&5E<B!E96X@;V)J96-T`%-E
M;&5C=&5E<B!D92!B96YO9&EG9&4@:V%R86MT97)S('5I="!D92!O;F1E<G-T
M86%N9&4@=F%K:F5S+B!5(&MU;G0@9&5Z92!D86X@:V]P:>MR96X@96X@<&QA
M:VME;B!I;B!H970@=&5K<W1G96)I960N`%-E;&5C=&5E<B!H970@9&%T=6US
M8VAE:61I;F=S=&5K96XZ`%-E;&5C=&5E<B!H970@9&%T=6UF;W)M86%T.@!3
M96QE8W1E97(@9&4@:61E;G1I=&5I="!D:64@=2!W:6QT('=I:GII9V5N.@!3
M96QE8W1E97(@:&5T('1I:F1S8VAE:61I;F=S=&5K96XZ`%-E;&5C=&5E<B!H
M970@=&EJ9'-F;W)M86%T.@!396QE8W1E97(@='=E92!O=F5R965N:V]M96YD
M92!V96QD96XN`%-E;&5C=&5E<B!U=R!K;&5U<G-C:&5M82X`4V5L96-T965R
M('5W('1A86P@=F]O<FME=7(Z`%9E<GIE;F0@;&%A='-T92!I;F9O<FUA=&EE
M`%!R;V)L965M<F%P<&]R="!V97)Z96YD96X`5F5R>F5N9"!335,`4V5N96=A
M;`!396YS;W(Z(`!397!T96UB97(`4V5R=FGK(&5N($UO;G1E;F5G<F\`4V5R
M:65N=6UM97(`4V5S<VEE($E$('9E<FQO<&5N+@!);G-T96QL96X`26YS=&5L
M;&5N('9A;B!O<'1I97,@;VT@=2!T;V4@=&4@<W1A86X@=7<@=V%C:'1W;V]R
M9"!T92!R97-E='1E;BP@=V%N;F5E<B!U(&1I="!B96YT('9E<F=E=&5N+@!3
M=&5L(&1E('1A86P@:6X@=F]O<B!M96YU(&ET96US+"!V97)K;&%R:6YG96X@
M96X@:&5L<"!I;B``26YS=&5L;&5N('9A;B!S97)V97)S(&]P(&%F<W1A;F0@
M9&EE('4@=VEL="!B96YA9&5R96X@=F%N=6ET('5W('!O<G1A;"X`26YS=&5L
M;&5N('9A;B!U=R!G97=E;G-T92!T86%L+"!T:6ID>F]N92!E;B!D871U;6]P
M=&EE<RX`26YS=&5L;&5N('9A;B!U=R!O<'-T87)T=&]E<&%S<VEN9RP@:VQE
M=7)S8VAE;6$L('!A9VEN879E<G9E<G-I;F<@96X@86YD97)E('=E97)G879E
M;W!T:65S+@!);G-T96QL96X`4V5T=7`@=7!G<F%D92!S8W)I<'1S(&)E<V-H
M:6MB86%R`%9E<G-C:&EL;&5N9&4@;&]C871I97,@;6]G96QI:FL@;65T(&1E
M('!A<F%M871E<CH@`%-E>6-H96QL96X`5VEN:V5L96X`2V]R=&4@<V%M96YV
M871T:6YG`$1I96YE;B!S;F5L=&]E='-E;B!V;V]R(&1E(&UE97-T92!L:6YK
M<R!G961E9FEN:65E<F0@=&4@=V]R9&5N/P!7965R9V5V96X`5F5R<V-H:6QL
M96X@;&%T96X@>FEE;B!T=7-S96X@9&4@:'5I9&EG92!O<&=E<VQA9V5N(&-O
M;F9I9W5R871I92!E;B!D92!N:65U=V4@9V5G96YE<F5E<F1E(&-O;F9I9W5R
M871I92X`3&%A='-T92!A86YM96QD:6YG<W1I:F0@=V5E<F=E=F5N(&)I:B!A
M86YM96QD96X_`$]P=&EE('=E97)G979E;B!O;2!O<FEG:6YE96P@=&4@8F5W
M87)E;@!+:65Z97(@=V5E<F=E=F5N`%1A8F5L8F5W97)K:6YG<W1A86MB86QK
M('=E97)G979E;C\`)7,@;65N=2!A86X@9&4@;&EN:V5R:V%N="!W965R9V5V
M96X_`%1A8F5L8V5L96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R
M9V5V96X`5&%B96QE:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS=&5R('=E97)G
M979E;@!486)E;')I:F5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E
M<F=E=F5N`$%F8F5E;&1I;F=S96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E
M<B!W965R9V5V96X`57!L;V%D('=E97)G979E;@!"=6EE;@!"=6EE;B!V<F]E
M9P!"=6EE;B!L86%T`$)U:65N(&EN(&1E(&YA8FEJ:&5I9`!697)K;&5I;F5N
M`%9E<FML96EN(&]F('9E<G!L86%T<R!N86)U<FEG92!B;&]K:V5N(&5E<G-T
M`%-I97)R82!,96]N90!);G1E:V5N96X`26YS8VAR:6IV96X@=V%N;F5E<B!N
M:65T(&=E<F5G:7-T<F5E<F0`2&%N9'1E:V5N:6YG`$AA;F1T96ME;FEN9R!A
M;&=O<FET:&UE`%-I;F=A<&]R90!'<F]O='1E`$]N9&5R:&]U9"!O=F5R<VQA
M86X`3W9E<F=E<VQA9V5N+BXN`%-L;W=A:VEJ90!3;&]V96YIZP!3;F5E=7<`
M4VYE975W=FQA86<`4VYE975W8G5I96X`4VYE975W8G5I96X@=G)O96<`4VYE
M975W8G5I96X@;&%A=`!3;F5E=7=D:65P=&4Z(`!3;F5E=7=E<75I=F%L96YT
M(&EN('=A=&5R.B``4V]L;VUO;B!E:6QA;F1E;@!3;VUA;&GK`$5E;B!A86YT
M86P@8V]N9FEG=7)A=&EE(&)E<W1A;F1E;B!V86X@9&4@4&%S<W=O<F0@;6]D
M=6QE(&]N=&)R96ME;CH`3&EE9&5R96X@96X@9V5D:6-H=&5N`%-O<G1E97)V
M;VQG;W)D92!S96QE8W1I90!"<F]N861R97,`6G5I9"!!9G)I:V$`6G5I9"!%
M=7)O<&5E<R`H25-/+3@X-3DM,RD`6G5I9"!'96]R9VGK(&5N(&1E(%IU:60@
M4V%N9'=I8V@@96EL86YD96X`6G5I9&5L:6IK(&AA;&9R;VYD`%-P871IZW)I
M;F<@='5S<V5N(&%A;F=R96YZ96YD92!C96QL96X`4W!A=&GK<FEN9R!T=7-S
M96X@:6YH;W5D(&5N(')A;F0@:6X@8V5L`%-C:&5I9&EN9W-T96ME;@!3<&%T
M:>MR:6YG`%-P871IZW)I;F<@96X@=G)I:F4@<G5I;71E`%-P86YJ90!3<&%M
M`%-P96-I86%L(&MA<F%K=&5R(&EN=F]E<@!#96P@;W!S<&QI='-E;@!+;VQO
M;2!O<'-P;&ET<V5N`%)I:B!O<'-P;&ET<V5N`%-P;W)T`%-R:2!,86YK80!3
M=&%N9&%A<F0`4W1A<B!4<F5K`%-T87)T`%-T87)T:F%A<@!3=&%A="!O9B!P
M<F]V:6YC:64`4W1A='5S`%-T871U<R!V86X@;&%N9&EN<W1E;&QI;F<@)7,N
M+BX@`$]P<VQA9V9O<FUA870`061R97,`1&]O<FAA;&5N`%-T<FEN9VQI:G-T
M`%-T<FEP(&1O;65I;B!V86X@:&5T(&%D<F5S`%-T:6IL(%M#4U-=`%IO`%-U
M8F1I<F5C=&]R>2`G)7,G(&YI970@9V5V;VYD96XN`$]N9&5R=V5R<`!/<&5N
M8F%R92!S;&5U=&5L(&]N9&5R=V5R<&EN9F]R;6%T:64`0F5V97-T:6=E;@!6
M97)Z;V5K('9E<G-T=75R9"!O;2`G)7,G(&%A;B!H970@<WES=&5E;2!T;V4@
M=&4@=F]E9V5N+B!5(&MU;G0@;FEE="!A86YM96QD96X@=&]T('5W('9E<GIO
M96L@:7,@9V]E9&=E:V5U<F0N`%-U8G-C<FEP=`!'96QU:W0`)R5S)R!M970@
M<W5C8V5S(&%A;B!H970@<WES=&5E;2!T;V5G979O96=D+@!$871A('9A;B!G
M96)R=6EK97(@)R5S)R!M970@<W5C8V5S('5I="!H970@<WES=&5E;2!V97)W
M:6ID97)D+@`G)7,G(&UE="!S=6-C97,@86%N('9E<G=I:F1E<F0N`"<E<R<@
M;65T('-U8V-E<R!U:70@:&5T('-Y<W1E96T@=F5R=VEJ9&5R9"X`0V]N9FEG
M=7)A=&EE(&UE="!S=6-C97,@=&5R=6=G97IE="X@5F5R;FEE=7<@;VT@=VEJ
M>FEG:6YG96X@=&4@>FEE;BX`0F%C:W5P8V]N9FEG=7)A=&EE(&UE="!S=6-C
M97-S(&]P9V5S;&%G96XN`$)A8VMU<&-O;F9I9W5R871I96)E<W1A;F0@)7,@
M;65T('-U8V-E<W,@;W!G97-L86=E;BX`)R5S)R!M970@<W5C8V5S(&)I:F=E
M=V5R:W0`)7,@;65T('-U8V-E<R!G97-C:')E=F5N`%-O961A;@!386UE;G9A
M='1I;F<`6F]N<V]P9V%N9P!:;VYS;VYD97)G86YG`%IO;FYI9P!:;VYS;W!G
M86YG`%IO;G-O<&=A;F<O6F]N<V]N9&5R9V%N9P!:;VYS;W!G86YG.B``6F]N
M<V]N9&5R9V%N9P!:;VYS;VYD97)G86YG.B``4W5P97)S8W)I<'0`3VYD97)S
M=&5U;FEN9P!3=7)I;F%M90!!8VAT97)N86%M`%-P:71S8F5R9V5N(&5N($IA
M;B!-87EE;@!3=V%Z:6QA;F0`6G=E9&5N`%IW:71S97)L86YD`%-Y;G1A>&9O
M=70@:6X@>F]E:W1E<FUE;@!3>7)I<V-H92!!<F%B:7-C:&4@4F5P=6)L:65K
M`$]N=V5E<G-B=6D`3VYW965R<V)U:65N`%135B!B97-T86YD`%1A8F5L`%1A
M8F5L96EG96YS8VAA<'!E;@!486)E;&5I9V5N<V-H87!P96X`5&%I=V%N`%1A
M:7=A;BP@4')O=FEN8VEE('9A;B!#:&EN80!4861Z:FEK:7-T86X`5&%N>F%N
M:6$L(%9E<F5N:6=D92!297!U8FQI96L@=F%N`$1O96PZ`%1A:V5N`%1E;&5F
M;V]N;G5M;65R`%1E;7!E<F%T=75R('9A;B!H970@869G96QO<&5N('5U<CH@
M`%1E;7!E<F%T=75R`%1E;7!E<F%T=75R.B``4VIA8FQO;VX@)R5S)R!N:65T
M(&=E=F]N9&5N`%-J86)L;V]N8F5H965R`%9E<GIO96L@=F]O<FQO<&EG(&%C
M8V5P=&5R96X`5F]O<FQO<&EG(&=E86-C97!T965R9`!496MS=`!!;&QE96X@
M=&5K<W0`5&5K<W0@=6ET;&EJ;F5N`%1E:W-T8F]V96YK86YT`$1O`%1H86ES
M("A425,M-C(P*0!4:&%I;&%N9`!"961A;FMT('9O;W(@:&5T(&=E8G)U:6ME
M;B!V86X@:&5T('-Y<W1E96TN`$AE="`E<R!H96QP8F5S=&%N9"!V;V]R("5S
M(&)E<W1A870@;F]G(&YI970N($UA:V5N('9A;B!E96X@;FEE=7=E+@!$92!&
M5%`@97AT96YT:64@:7,@;FEE="!B97-C:&EK8F%A<BX`1&4@2&]R9&4O2V]L
M86(@:6YT96=R871I92!O;F1E<G-T975N="`B)7,B(&YI970`1&4@36%I;G1E
M;F%N8V4Z.B!C;&%S<R!W97)D(&YI970@9V5L861E;@!(970@3W!T:65S<V-H
M97)M(&ES(&=E<VQO=&5N+B!!9G-L=6ET96XN`$1E(&)E:&5E<F1E<B!D:65N
M="!E96X@<&5R;6%N96YT(')E8VAT96YB86-K96YD('1E(&-O;F9I9W5R97)E
M;B!A;',@=2!R96-H=&5N('=I;'0@9V5B<G5I:V5N+@!!;&QE96X@9&4@;VYD
M97)K86YT`$1E(&%G96YD861A=&$@:7,@;VYG96QD:6<`2&5T(&-O;G1A8W0@
M240@;G5M;65R(&ES(&YI970@;W!G96=E=F5N+"!L965G(&=E;&%T96X@;V8@
M:7,@;FEE="!G979O;F1E;B!I;B!D92!D871A8F%S92X`2&5T(&%D<F5S(&ES
M(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E:R!T;V5G979O96=D+@!(970@
M;&]S9V5K;W!P96QD92!01U`@;VYD97)T96ME;FEN9W-B;&]K(&ES('9E<F5I
M<W0@;VT@:&5T(&]N9&5R=&5K96YD92!B97)I8VAT('1E('9E<FEF:>MR96XN
M`$AE="!D:7-T<G5B=71I96QI:G-T($E$(&ES(&YI970@;W!G96=E=F5N+"!L
M965G(&=E;&%T96X@;V8@:7,@;FEE="!G979O;F1E;B!I;B!D92!D871A8F%S
M92X`1&4@9&ES=')I8G5T:65L:6IS="!I<R!N:65T(&]P9V5G979E;BX`1&4@
M8V]D965R;6]G96QI:FMH961E;B!V97)E:7-E;B!E96X@8F5V96EL:6=D92!W
M96)V97)B:6YD:6YG+@!$92!G96)E=7)T96YI<R!I<R!A86X@=7<@86=E;F1A
M('1O96=E=F]E9V0N`$AE="!B97-T86YD("5S(&1I96YT(&5E;B`E<R!I;G-T
M96QL:6YG('1E(&)E=F%T=&5N+@!(970@8F5S=&%N9"`E<R!D:65N="!E;FEG
M92`E<R!I;G-T96QL:6YG96X@=&4@8F5V871T96XN`$AE="!B97-T86YD(&MA
M;B!N:65T(&YA87(@>FEC:'IE;&8@9V5K;W!I965R9"!W;W)D96XN`$AE="!B
M97-T86YD(&)E=F%T=&4@9V5E;B!D871A+@!(970@=F]L9V5N9&4@>FEJ;B!D
M92!K;W!P96X@=F%N(&1I="!M97-S86=E+W)F8S@R,B!B97)I8VAT+@!686X@
M9&4@=F]L;&5D:6<@<V-H97)M(&UO9&4@:7,@8F5K96YD+"!D870@9&ET('!R
M;V)L96UE;B!K86X@=F5R;V]R>F%K96X@;65T($EN=&5R;F5T($5X<&QO<F5R
M+"!V86YW96=E(&)R;W=S97)B=6=S('=A87(@=VEJ(&YI970@;VUH965N(&MU
M;FYE;BX@2&5T(&ES(&UO9V5L:6IK(&1A="!U(')O;6UE;"!I;B!H970@8F5E
M;&1S8VAE<FTL(&=E8G)E:R!A86X@961I=&]R9G5N8W1I97,@96XO;V8@<F%N
M9&]M(&)R;W=S97(M(&-R87-H97,@97)V86%R="X@5V%N;F5E<B!U=R!S>7-T
M965M(%=I;F1O=W,@.7@@:7,L(&ES(&AE="!W86%R<V-H:6IN;&EJ:R!D870@
M=2!E96X@)T%L9V5M96YE($)E=F5I;&EG:6YG<R!&;W5T)R!K<FEJ9W0L(&5N
M(&]P;FEE=7<@9&EE;G0@=&4@:&5R<W1A<G1E;BY<;EQN52!B96YT(&=E=V%A
M<G-C:'5W9"X@1')U:R!O<"!/2R!W86YN965R('4@=&]C:"!D92!V;VQL961I
M9R!S8VAE<FT@961I=&]R('=I;'0@<')O8F5R96XN`$AE="!H96QP8F5S=&%N
M9"`E<R!B96=O;B!N:65T(&UE="`\/WAM;`!$92!I9&5N=&ET96ET("(E<R(@
M:7,@=F5R=VEJ9&5R9"X`06QL965N(&1E(&QI;FME<FMA;G0`1&4@<&QA871S
M('9A;B!H970@1VYU4$<@<')O9W)A;6UA(&1I96YT(&]P9V5G979E;B!T92!W
M;W)D96X@:6X@9&4@0W)Y<'1?<&=P.CH@8VQA<W,N`$AE="!B97)I8VAT('9E
M<G-T=75R9"!O<"`E<R!A86X@)7,@;65T(&]N9&5R=V5R<"`B)7,B(&ES('=E
M97)G96=E=F5N+@I$:70@:7,@9V5E;B!G87)A;G1I92!D870@:&5T(&)E<FEC
M:'0@:7,@9V5L97IE;B!O9B!B96=R97!E;BX`1&4@;F%A;2!D:64@9V5B<G5I
M:W0@=V]R9'0@8FEJ(&QI;FME;B!N86%R(&1E(&YI975W(&)E<FEC:'0@<&%G
M:6YA`$1E(&]P96YS<VP@;6]D=6QE(&ES('9E<F5I<W0@=F]O<B!D92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+@!$92!V;V]R:V5U<G-I;G-T96QL:6YG
M("(E<R(@:V]N(&YI970@=V]R9&5N(&]P9V5S;&%G96XL(&]M9&%T(&1E(&1A
M=&$@9&4@;6%X:6UU;2!T;V5L86%T8F%R92!G<F]O='1E(&]V97)S8VAR:6ID
M="X`2&5T('!R;V=R86UM82!O;2!D:70@9&%T871Y<&4@*"5S*2!T92!B96MI
M:FME;BP@=V5R9"!N:65T(&]P(&AE="!S>7-T965M(&=E=F]N9&5N+@!!;&QE
M96X@9&4@<F5C:'1E<BT@96X@;&EN:V5R:V%N=`!!;&QE96X@9&4@<F5C:'1E
M<FMA;G0`1&4@<V5R=F5R("(E<R(@:7,@=F5R=VEJ9&5R9"X`1&4@<V5R=F5R
M("(E<R(@:7,@;W!G97-L86=E;BX`2&5T(&%A;FUE;&1I;F=S=F5R>F]E:R!V
M;V]R("5S(&ES('9E<G=I:F1E<F0N`$1E(&]P9V5G979E;B!R:6H@8F5S=&%A
M="!N:65T+@!$92!T86%K(&ES(&%A;B!U=R!T86ME;FQI:G-T('1O96=E=F]E
M9V0N`$AE="!T:6ID96QI:FL@8F5S=&%N9"`B)7,B(&)E<W1A870@;FEE="X`
M06QL965N(&1E(&)O=F5N+2!E;B!O;F1E<FMA;G0`06QL965N(&1E(&)O=F5N
M:V%N=`!$92!U<&QO861E9"!D871A(&ES(&YA(&1E('9O;W)G86%N9&4@<W1A
M<"!V97)L;W)E;B!G96=A86XN`$AE="!U<&QO861E9"!B97-T86YD(&ES(&YI
M970@;W!G97-L86=E;BX`1&4@=G)I:B]B97IE="!I;F9O<FUA=&EE('9A;B!D
M92!G96)R=6EK97(@:7,@;65T('-U8V-E<R!O<&=E<VQA9V5N+@!(970@=V5A
M=&AE<BYC;VT@8FQO:R!I<R!N:65T(&)E<V-H:6MB86%R+@!+;&5U<G-C:&5M
M861I<F5C=&]R>2`G)7,G(&YI970@9V5V;VYD96XN`$=E96X@;W!T:65S(&)E
M<V-H:6MB86%R+@!%<B!Z:6IN(&=E96X@;VYD97)D96QE;BP@=V5L:V4@:6YL
M:6YE('=E97)G96=E=F5N(&MU;FYE;B!W;W)D96XN`$5R('II:FX@=&4@=F5E
M;"!K87)A:W1E<G,@:6X@9&ET('9E;&0N(%4@:&5E9G0@)7,@:V%R86MT97)S
M(&]P9V5G979E;CL@=2!D:65N="!M:6YD97(@9&%N("5S(&]P('1E(&=E=F5N
M+@!%<B!B97-T86%T(&YO9R!G965N(&AE;'!B97-T86YD('9O;W(@)7,N`$5E
M;B!P<F]B;&5E;2!M970@:&5T('1O979O96=E;B!V86X@)R5S)R!A86X@:&5T
M('-Y<W1E96TN("5S+@!%96X@<')O8FQE96T@;65T(&AE="!T;V5V;V5G96X@
M=F%N("<E<R<@86%N(&AE="!S>7-T965M.B`E<P!%96X@<')O8FQE96T@;65T
M(&AE="!V97)W:6ID97)E;B!V86X@9&%T82!V86X@9V5B<G5I:V5R("<E<R<@
M=6ET(&AE="!S>7-T965M.B``165N('!R;V)L965M(&UE="!H970@=F5R=VEJ
M9&5R96X@=F%N("<E<R<@=6ET(&AE="!S>7-T965M.B``165N('!R;V)L965M
M(&UE="!H970@8FEJ=V5R:V5N('9A;B`G)7,G.B`E<P!%96X@<')O8FQE96T@
M;65T(&1E(&)E<W1A;F1S=7!L;V%D.B!'965N("5S('=E<F0@9V5U<&QO860N
M`$5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($AE="`E<R!I
M<R!G<F]T97(@9&%N(&1E(&UA>&EM=6T@=&]E;&%A=&)A<F4@9W)O;W1T92`H
M)60@8GET97,I+@!%96X@<')O8FQE96T@;65T(&1E(&)E<W1A;F1S=7!L;V%D
M.B!(970@)7,@:7,@<VQE8VAT<R!G961E96QT96QI:FL@9V5U<&QO860N`$5E
M;B!F;W5T(&)I:B!H970@8F5K:6IK96X@=F%N(&1I="!B97)I8VAT;VYD97)D
M965L`$5E;B!F;W5T(&)I:B!H970@:6UP;W)T97)E;B!V86X@9&4@861R97-D
M871A+@!%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R96X@=F%N(&1E(&=E8F5U
M<G1E;FES.B`E<RX`165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D
M92!I0V%L96YD87)D871A+@!%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R96X@
M=F%N(&1E('1A86LZ("5S+@!%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R96X@
M=F%N('9R:6HO8F5Z970@:6YF;W)M871I92!V86X@9&4@9V5B<G5I:V5R.B`E
M<RX`165N(&9O=70@:6X@:&5T(&-O;F9I9W5R871I969O<FUU;&EE<BX@36ES
M<V-H:65N(&)E;G0@=2!E96X@=F5R<&QI8VAT('9E;&0@=F5R9V5T96XN`$5E
M;B!F;W5T(&)I:B!H970@;W!E;F5N('9A;B!B97-T86YD("5S+B!0<F]B965R
M(&]M('1R86YS;&%T:6]N+G!H<"!U:70@=&4@=F]E<F5N(&UE="!D92`M9"!V
M;&%G+"!O;2!F;W5T8F5R:6-H=&5N('9A;B!D92!X;6P@=F5R=V5R:V5R('1E
M(&)E:VEJ:V5N+@!%96X@9F]U="!B:6H@:&5T('5I='9O97)E;B!V86X@9&4@
M;W!G96=E=F5N(&%D<F5S8F]E:V9U;F-T:64N(%!R;V)E97(@;&%T97(@;W!N
M:65U=RP@82YU+F(N`$5E;B!F;W5T(&UE="!H970@8FEJ=V5R:V5N('9A;B!D
M92!A9')E<V1E=&%I;',N(%!R;V)E97(@;&%T97(@;W!N:65U=RP@82YU+F(N
M`$5E;B!F;W5T(&UE="!H970@8FEJ=V5R:V5N('9A;B!D92!D:7-T<FEB=71I
M96QI:G-T+B!0<F]B965R(&QA=&5R(&]P;FEE=7<L(&$N=2YB+@!$97IE($E-
M05`@<V5R=F5R(&]N9&5R<W1E=6YT(&=E96X@9&5L:6YG('9A;B!M87!P96XN
M`$1E>F4@8F5W97)K:6YG('=O<F1T(&YI970@;VYD97)S=&5U;F0N`$1E>F4@
M8F5W97)K:6YG(&ES(&YO9R!N:65T('9A;B!T;V5P87-S:6YG+@!$:70@;&EJ
M:W0@;FEE="!E96X@9V5L9&EG(')A<B!B97-T86YD('1E('II:FXN`$1I="!L
M:6IK="!N:65T(&5E;B!G96QD:6<@>FEP(&)E<W1A;F0@=&4@>FEJ;BX`1&ET
M(&QI:FMT(&YI970@965N(&=E;&1I9R!K86%R=&YU;6UE<B!T92!Z:6IN+@!$
M:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E
M<FEC:'1E;B!V:6$@9&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN
M8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@9"YM+G8N(&1E($A45%`@05!)
M`$1I="!S='5U<G!R;V=R86UM82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@
M8F5R:6-H=&5N('9I82!D92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN
M8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@9"YM+G8N(&1E($A45%`@05!)
M`$1I="!S='5U<G!R;V=R86UM82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@
M8F5R:6-H=&5N('9I82!33510(&0N;2YV+B!D92!6;V1A9F]N92!)=&%L>2!G
M871E=V%Y('1E('9E<GIE;F1E;B!N86%R(%9O9&%F;VYE(&YU;6UE<G,N($AI
M97)V;V]R(&ES(&5E;B!6;V1A9F]N92!)=&%L>2!E+6UA:6QA9')E<R`H:'1T
M<#HO+W=W=RXQ.3`N:70I(&YO;V1Z86ME;&EJ:RX`1&ET('9E;&0@:7,@=F5R
M96ES=`!$:70@=F5L9"!M86<@86QL965N(&EN=&5G97)S(&)E=F%T=&5N+@!$
M:70@=F5L9"!M86<@86QL965N(&=E=&%L;&5N(&5N(&1E(&1U8F)E;&4@<'5N
M="!B979A='1E;BX`1&ET('9E;&0@;6%G(&%L;&5E;B!O8W1A86P@=V%A<F1E
M;B!B979A='1E;BX`1&ET('9E;&0@9&EE;G0@965N(&MO;6UA(&]F('-P871I
M92!G97-C:&5I9&5N(&QI:G-T(&UE="!I;G1E9V5R<R!T92!Z:6IN`$1E>F4@
M=V%A<F1E(&1I96YT(&5E;B!G96QD:6<@9V5T86P@=&4@>FEJ;BX`1&ET('9E
M;&0@9&EE;G0@965N(&ML975R8V]D92!I;B!21T(@2$58+69O<FUA870@=&4@
M8F5V871T96XL(&(N=BX@)R,Q,C,T868G+@!$:70@8F5S=&%N9"!R96=E;'0@
M9&4@<W1A;F1A87)D(&EN<W1E;&QI;F=E;B!V;V]R(&1E(%!A<W-W;W)D(&UO
M9'5L92P@96X@;V]K=V5L:V4@:6YS=&5L;&EN9V5N(&1E(&=E8G)U:6ME<B!K
M86X@=F5R86YD97)E;BX`1&ET(&)E<W1A;F0@8F5H965R="!D92!S='EL97-H
M965T(&1I92!G96)R=6EK="!W;W)D="!O;2!K;&5U<F5N(&5N(&QE='1E<G1Y
M<&5N('1O92!T92!V;V5G96X@;V8@9&4@<W1A;F1A87)D(&EN<W1E;&QI;F<@
M=F%N($AO<F1E(&1E(&]V97)S8VAR:6IV96X`1&ET(&9O<FUU;&EE<B!I<R!R
M965D<R!V97)W97)K="X`1&ET(&ES("5S+@!$:70@:7,@965N($MO;&%B($=R
M;W5P=V%R92!O8FIE8W0N($]M(&1I="!O8FIE8W0@=V5E<B!T92!G979E;B!H
M965F="!U(&5E;B!E+6UA:6P@8VQI96YT(&YO9&EG(&1I92!H970@2V]L86(@
M1W)O=7!W87)E(&9O<FUA870@8F5G<FEJ<'0N(%9O;W(@965N(&QI:G-T(&UE
M="!D97IE(&4M;6%I;&-L:65N=',L(&)E>F]E:R`E<RP@82YU+F(N`$1I="!I
M<R!H970@8F5L86YG<FEJ:W-T92!C;VYF:6=U<F%T:64@8F5S=&%N9"!V86X@
M9&4@4&%S<W=O<F0@;6]D=6QE+B!(970@8F5V870@<&%D96X@96X@;W!T:65S
M('9O;W(@86QL92!087-S=V]R9"!M;V1U;&4@<V-R:7!T<RX`1&ET(&)E<FEC
M:'0@:7,@:6X@965N(&%N9&5R92!K87)A:W1E<G-E="`H)7,I(&=E<V-H<F5V
M96XL(&1A;B!U=R!E:6=E;BX`1&ET(&=E=&%L(&1I96YT('1E;FUI;G-T92#I
MZ6X@=&4@>FEJ;BX`1&ET('-C<FEP="!D:65N="!V86YA9B!D92!O<&1R86-H
M=')E9V5L('1E('=O<F1E;B!U:71G979O97)D+@!$97IE('-E<G9E<B!K86X@
M9V5E;B!Z:7`@96X@9WII<"!B97-T86YD96X@=6ET<&%K:V5N+@!(970@<WES
M=&5E;2!I<R!M;VUE;G1E96P@=6ET9V5S8VAA:V5L9"X`1&5Z92!W86%R9&4@
M9&EE;G0@965N(&=E=&%L('1E('II:FXN`$1I="!S8VAE<FT@9&EE;G0@86%N
M9V5R;V5P96X@=&4@=V]R9&5N('9A;G5I="!E96X@3W!T:65S<V-H97)M`$]N
M=V5E<@!4:6-K971S`%1I:F0`5&EJ9'!L86YN:6YG`%1I:F1F;W)M86%T`%1I
M:F1S96QE8W1I90!4:6UO<BU,97-T90!4:71E;`!4:71E;"`H=&]O;'1I<"DZ
M`$%A;@!/;2!M965R9&5R92!O;F1E<F1E;&5N('1E('-E;&5C=&5R96XL(&AO
M=60@9&4@0V]N=')O;"`H4$,I(&]F($-O;6UA;F0@*$UA8RD@=&]E=',@=F%S
M="!T:6ID96YS(&ML:6MK96XN`%9A;F1A86<`2%1-3"!B<F]N(&]M<V-H86ME
M;&5N`%1O9V\`5&]K96QA=0!-;W)G96X`5&]N9V$`0F]V96YK86YT`$)O=F5N
M<W1E(&9R86UE("A?=&]P*0!697)T86%L9`!697)T86QI;F=E;@!4<FEN:61A
M9"!E;B!4;V)A9V\`5')U92!O9B!F86QS90!$:0!4=6YE<VGK`%1U<FMI:F4`
M5'5R:W,@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!E;B!#86EC
M;W,@96EL86YD96X`5'5V86QU`%1Y<"!U=R!K975Z93H@`%4N5BX@:6YD97@Z
M(`!54DP`55),('9O;W(@=7<@869L979E<FEN9W-S=&%T=7-R87!P;W)T('-C
M<FEP=`!54DPZ`$]E9V%N9&$`3V5K<F'O;F4`3FEE="!I;B!S=&%A="!61E,@
M9&ER96-T;W)Y(&%A;B!T92!S<')E:V5N+@!.:65T(&EN('-T86%T(&5X=')A
M(&=E8G)U:6ME<G-I;F9O<FUA=&EE('1O92!T92!V;V5G96X@8FEJ(&EN<V-H
M<FEJ=F5N+@!.:65T(&EN('-T86%T(&1E(')E8VAT96X@=F%N(%9&4R!B97-T
M86YD("(E<R(@=&4@=VEJ>FEG96XN`$YI970@:6X@<W1A870@9&4@<F5C:'1E
M;B!V86X@5D93(&)E<W1A;F0@)7,O)7,@=&4@=VEJ>FEG96XN`$YI970@:6X@
M<W1A870@=&4@=VEJ>FEG96X@;F%A<B`E<RX`3FEE="!I;B!S=&%A="!M970@
M9&4@4U%,('-E<G9E<B!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@;65T
M(%-33"!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M=&4@:V]P:>MR96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`B)7,B
M('1E(&UA:V5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@;6%K
M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@
M:6X@<W1A870@965N(&QE96<@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@
M:6X@<W1A870@9&%T82!U:70@=&4@<&%K:V5N+@!.:65T(&EN('-T86%T("(E
M<R(@=&4@=F5R=VEJ9&5R96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE96<`
M3FEE="!I;B!S=&%A="`E<R!T92!V97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y
M(&ES(&YI970@;&5E9P!.:65T(&EN('-T86%T("<E<R<Z("5S('1E('9E<G=I
M:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@<F5C=7)S:65F
M('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@
M=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`E
M<R!T92!V97)W:6ID97)E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"`B
M)7,B('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD
M('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R`E<R!R96-U<G-I
M968@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@:'5I9&EG92!D:7)E
M8W1O<GD@=&4@8F5P86QE;BX`3FEE="!I;B!S=&%A="!C97)T:69I8V%A=&1E
M=&%I;',@=6ET('1E(&9I;'1E<F5N`$YI970@:6X@<W1A870@;VT@9&4@9&5F
M:6YI=&EE('9A;B`E<R!T92!L861E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S
M=&%N9"!T92!V97)P;&%A='-E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N
M9"`B)7,B('1E(&]P96YE;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T
M92!O<&5N96X@=F]O<B!S8VAR:6IV96XN`$YI970@:6X@<W1A870@5D93(&)E
M<W1A;F0@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&AE="!I;F=E<&%K=&4@
M8F5S=&%N9"!T92!O<&5N96XN`$YI970@:6X@<W1A870@=F9S<F]O="!D:7)E
M8W1O<GD@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&]M("5S('1E(&AE<FYO
M96UE;B!N86%R("5S.B!B97-T96UM:6YG<VUA<"!B97-T86%T(&%L`$YI970@
M:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!H97)N;V5M96XN`$YI970@:6X@
M<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!H97)N;V5M96XN`$YI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!H97)N;V5M96XN`$YI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@)7,O)7,@=&4@:&5R;F]E;65N+@!.:65T(&EN
M('-T86%T(%9&4R!B97-T86YD('1E(&AE<FYO96UE;BX`2V%N("=M:VES;V9S
M)R!N:65T('5I='9O97)E;BX`3FEE="!I;B!S=&%A="!D:70@5V]R9"!D;V-U
M;65N="!T92!V97)T86QE;@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD("(E
M<R(@=&4@<V-H<FEJ=F5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E
M('-C:')I:G9E;B`H8V]P>2@I(&9A:6QE9"DN`$YI970@:6X@<W1A870@5D93
M(&)E<W1A;F1S9&%T82!T92!S8VAR:6IV96XN`$]N9&5R<W1R97!E;@!(97)S
M=&5L('=I:GII9VEN9V5N`$1O970@=7<@;&%A='-T92!B97=E<FMI;F<@=&5N
M:65T`$]N=F5R=V%C:'0@86YT=V]O<F0@=F%N(&1E('-E<G9E<B!O<"!V97)B
M:6YD:6YG.B``3VYV97)W86-H="!A;G1W;V]R9"!V86X@<V5R=F5R(&%A;CH@
M`$]N8F5N;V5M9`!.:65T('9E<G=E<FMT(&]N9&5R9&5E;"!V86X@='EP93H@
M)7,`56YI8V]D92`H551&+3@I`%9E<F5N:6=D92!!<F%B:7-C:&4@16UI<F%T
M96X`5F5R96YI9V0@2V]N:6YG:W)I:FL`5F5R96YI9V1E(%-T871E;@!697)E
M;FEG9&4@4W1A=&5N+"!K;&5I;F4@8G5I=&5N(&QI9V=E;F1E(&5I;&%N9&5N
M`$5E;FAE9&5N`$]N8F5K96YD`$]N8F5K96YD(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`$]N8F5K96YD(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN`$]N8F5K96YD92!O<&1R86-H=#H@)7,`3VYB96ME;F1E(&=E8G)U:6ME
M<G-N86%M(&]F('=A8VAT=V]O<F0N`$AE="!H=6ED:6=E(&5L96UE;G0@;&]S
M:V]P<&5L96X`3VYB96YO96UD`$YI970@9V5R96-H=&EG9&4@<V-R:7!T<R!K
M=6YN96X@<')O9W)A;6UA;6%T:6<@;FEE="!+;FEP<&5N+TMO<&GK<F5N+U!L
M86MK96XL('9A;G=E9V4@8F5V96EL:6=I;F=S<F5D96YE;BX@2VQI:R!O<"!/
M2R!O;2!E96X@=&5C:&YI<V-H92!O<&UE<FMI;F<@;W`@;6]Z:6QL82YO<F<@
M=&4@8F5K:6IK96X@:&]E('4@965N('-C<FEP="!T;V5S=&%A="!H970@<')I
M:V)O<F0@=&4@8F5N861E<F5N+@!+;&5U<B!T97)U9W-T96QL96X`3FEE="!O
M;F1E<G-T975N9&4@97AT96YT:64`3VYV97)T86%L9`!":6IW97)K96X`)7,@
M8FEJ=V5R:V5N`$)E86YT=V]O<F1E<G-T871U<R!B:6IW97)K96X`1V5B<G5I
M:V5R(&)I:G=E<FME;BX`)R5S)R!B:6IG97=E<FMT+@!":6IW97)K96X@=F%N
M("5S(&AE;'!B97-T86YD('9O;W(@)7,N`%5P9W)A9&4@<V-R:7!T('9E<G=I
M:F1E<F0N`%5P;&]A9`!!;&QE('1O97!A<W-I;F<@<V5T=7!B97-T86YD96X@
M;F%A<B!D92!S97)V97(@9V5U<&QO860N`$QA=&EJ;G-E(&AO;V9D;&5T=&5R
M<P!'<F]T92!2;VUE:6YS92!G971A;&QE;@!5<G5G=6%Y`$=E8G)U:6LZ`$=E
M8G)U:6L@:'5I9&EG93H@)7,`1V5B<G5I:R!34TP`1V5B<G5I:V5N('=A;FYE
M97(@;F%A;2]W86-H='=O;W)D('9E<G-C:&EL="!M970@24U34"!S97)V97(N
M`$=E8G)U:6ME<B`E<R!I<R!N:65T(&=E875T;W)I<V5E<F0@=F]O<B`E<RX`
M1V5B<G5I:V5R<V)E:&5E<@!'96)R=6EK97)S;W!T:65S`$=E8G)U:6ME<G-R
M96=I<W1R871I90!'96)R=6EK97)S<F5G:7-T<F%T:64@:7,@=6ET9V5S8VAA
M:V5L9"!O<"!D97IE('-I=&4N`$=E8G)U:6ME<G-R96-H=&5N`$=E8G)U:6ME
M<G-N86%M`$=E8G)U:6ME<G-N86%M("<E<R<@8F5S=&%A="!A;"X`1V5B=6EK
M97)S;F%A;3H`1V5B<G5I:V5R<VYA86TZ(`!'96)R=6EK97)S`$=E8G)U:6ME
M<G,@:6X@:&5T('-Y<W1E96TZ`$]E>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@
M8F5S=&%A="!N:65T+@!!9G=E>FEG:&5I9`!'979O;F1E;B!G96QD:6=E(&QO
M8V%T:65S(&)E=F%T=&5N.B``1V5L9&EG:&5I9`!786%R9&4@:6X@;6EN=71E
M;B!V86YA9B!N=2X`5V%A<F1E;@!786%R9&5N('=A87)U:70@9V5S96QE8W1E
M97)D(&MA;B!W;W)D96X`5F%N=6%T=0!687)I86)E;&4`5F5N97IU96QA`%9E
M<FEF:6-A=&EE(&UI<VQU:W0@+2!E<B!K86X@;65T(&1I="!B97)I8VAT(&=E
M:VYO96ED('II:FXN`%9E<G-I90!697)S:65C;VYT<F]L90!697)T:6MA86P@
M=6ET;&EJ;F5N`%9E<G1I:V%L92!V<FEJ92!R=6EM=&4`5F5R=&EK86%L.@!%
M<F<@:&]O9P!6:65T;F%M`%9I971N86UE97,@*%9)4T-)22D`)7,@8F5K:6IK
M96X`0F5K:6IK(&5E;B!E>'1E<FYE('=E8G!A9VEN80!"96MI:FME;B!A;',@
M)7,`0F5K:6IK(&=E8F5U<G1E;FES`$)E:VEJ:R!T86%K`$UA86=D96X@96EL
M86YD96XL($)R:71S90!-86%G9&5N(&5I;&%N9&5N+"!6+E,N`%II8VAT`%II
M8VAT.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!704%24T-(55=)
M3D<A(2$@(%9%4E=)2D1%4B!30U))4%0@2$%.1$U!5$E'(%5)5"`E<RX`5V%L
M;&ES(&5N($9U='5N80!786%R<V-H=7=I;F<`5V%A<G-C:'5W:6YG.@!7;P!7
M965R<W9O;W)U:71Z:6-H=`!7965R8F5R:6-H="!G96=E=F5N<R!G96QE=F5R
M9"!D;V]R`%=E871H97(N8V]M`%=E8@!796)S:71E`%=E:V5L:6IK<P!796QK
M;VT`5V5L:V]M(&)I:B`E<P!796QK;VTL("5S`%=E<W1E<G,@*$E33RTX.#4Y
M+3$I`%=E<W1E<G,@*$E33RTX.#4Y+3$U*0!797-T96QI:FME(%-A:&%R80!7
M96QK92!T;V5P87-S:6YG(&1I96YT("5S('=E97(@=&4@9V5V96X@;F$@86%N
M;65L9&EN9S\`5V%T(&ES(&AE="!S8VAE:61I;F=S:V%R86MT97(_`%=A="!I
M<R!H970@8VET86%T:V%R86MT97(_`%=E;&ME(&9A<V5N`%=E;&ME('!L=6=I
M;G,@=F]O<B!D92!2:6-H(%1E>'0@961I=&]R(&EN<V-H86ME;&5N+@!"<F5E
M9'1E`$)R965D=&4@:6X@0U-3(&5E;FAE9&5N`$)R965D=&4@=F%N(&AE="`E
M<R!M96YU(&%A;B!D92!L:6YK97)K86YT("AA:W1I968@8FEJ('9O;&=E;F1E
M(&%A;FUE;&1I;F<I.@!"<F5E9'1E('9A;B!D92!T86)E;`!"<F5E9'1E(&5E
M;FAE:60`0G)E961T93H`5VEK:0!7:6YD`%9R;V5G('=I;F0`5VEN9'-N96QH
M96ED(&EN(&MN;W!E;@!7:6YD.@!7:6YD.B``5VEJ<VAE:60`5V5N<VQI:G-T
M96X`5V5R:P!797)K861R97,`5&5L+FYR+B`H=V5R:RD`0FEJ9V5W97)K="!H
M96QP8F5S=&%N9"!N86%R("5S('-C:')I:G9E;BX`6"U2968`6#4P.78S(&)A
M<VES8F5P97)K:6YG96X`6#4P.78S('5I=&=E8G)E:60@<VQE=71E;&=E8G)U
M:6L`6#4P.78S(&%L=&5R;F%T:65V92!O;F1E<G=E<G!N86%M`%@U,#EV,R!O
M;F1E<G=E<G`@<VQE=71E;&ED96YT:69I8V%T;W(`6#4P.78S(&5X=&5N=&EE
M<P!*2@!*2DI*`%EA:&]O(2!M87``2F%A<FQI:FMS`$IE;65N`$IA`$IA+"!I
M:R!A8V-E<'1E97(@9&4@=F]O<G=A87)D96X`52!B96YT(&EN(%1%2U-4($U/
M1$4N($=E8G)U:6L@9&4@6SP^72!K;F]P(&]M(&YA87(@5UE325=91R!T97)U
M9R!T92!S8VAA:V5L96XN`%4@8F5N="!N:65T(&=E875T:&5N=&EF:6-E97)D
M+@!5(&MA;B!N:65T(&5E;B!W86-H='=O;W)D('9E<F%N9&5R96X@=F%N(&5E
M;B!A;F1E<F4@9V5B<G5I:V5R`%4@:W5N="!G965N("=<)R!K87)A:W1E<B!I
M;B!U=R!V;VQL96=E(&YA86T@:&5B8F5N+@!5(&MA;B!N:65T(&AE="!W86-H
M='=O;W)D('=I:GII9V5N('9O;W(@9V5B<G5I:V5R("5S`%4@:&5E9G0@9V5E
M;B!G96QD:6<@92UM86EL861R97,@;W!G96=E=F5N+@!5(&AE969T(&=E96X@
M=F5L9&5N('5I="!H970@9V5I;7!O<G1E97)D92!B97-T86YD(&=E:V]P<&5L
M9"!M970@9&4@;W9E<F5E;FMO;7-T:6=E('9E;&1E;B!I;B`E<RX`52!B96YT
M(&%F9V5M96QD+@!5(&1I96YT(&5E;B!G96QD:6<@;6]B:65L(&YU;6UE<B!I
M;B!T92!V;V5R96XL(&%L;&5E;B!C:6IF97)S(&UE="!E96X@;W!T:6]N96QE
M("<K)R!V;V]R(&AE="!I;G1E<FYA=&EO;F%L92!K:65S=F]O<G9O96=S96PN
M`%4@9&EE;G0@965N(&=E;&1I9V4@=V%A<F1E(&]P('1E(&=E=F5N+@!5(&1I
M96YT(&5E;B!$871A5')E92!B86-K96YD('1E(&-O;F9I9W5R97)E;B!O;2!I
M;G-C:')I:G9I;F=E;B!T92!K=6YN96X@9V5B<G5I:V5N+@!5(&1I96YT(&5E
M;B!61E,@8F%C:V5N9"!T92!C;VYF:6=U<F5R96XN`%4@9&EE;G0@:&5T('!R
M;V)L965M('1E(&)E<V-H<FEJ=F5N+"!V;V]R9&%T('4@:&5T('!R;V)L965M
M<F%P<&]R="!K=6YT('9E<GIE;F1E;BX`52!D:65N="!E96X@55),(&EN('1E
M('9O97)E;B!W86%R;F%A<B!D97IE(&QI;FL@=F5R=VEJ<W0`52!M;V5T('5W
M(&YI975W92!W86-H='=O;W)D(&=E=F5N`%4@;6]E="!U=R!O=61E('=A8VAT
M=V]O<F0@9V5V96X`52!M;V5T('5W(&YI975W92!G96)R=6EK97)S;F%A;2!G
M979E;@!5(&1I96YT(&5E;B!S97)V97(@=&4@<V5L96-T97)E;B!O;2!T92!V
M97)W:6ID97)E;BX`52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@
M9V5V96X@;VT@=&4@=VES<V5N+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A
M;2!O<"!T92!G979E;B!O;2!T92!V97)W:6ID97)E;BX`52!D:65N="!E96X@
M9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@=&]E('1E('9O96=E;BX`
M52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@8FEJ
M('1E(&MU;FYE;B!W97)K96XN`%4@9&EE;G0@965N(&)E=V5R:VEN9R!O<"!T
M92!G979E;B!W96QK92!U:71G979O97)D(&UO970@=V]R9&5N+@!5(&1I96YT
M(&5E;B!N:65U=V4@8V%T96=O<FEE;F%A;2!O<"!T92!G979E;BX`52!M;V5T
M('5W(&YI975W92!W86-H='=O;W)D('9E<FEF:>MR96X`57<@)7,@<V5S<VEE
M(&ES('9E<FQO<&5N+B!/<&YI975W(&%A;FUE;&1E;BP@82YU+F(N`%5W(&4M
M;6%I;&%D<F5S`%5W(%9A;CH@861R97,Z`%5W($EN9F]R;6%T:64`57<@:6YT
M97)N971A9')E<R!I<R!G97=I:GII9V0@<VEN9',@:&5T(&)E9VEN('9A;B!U
M=R`E<R!S97-S:64N($]M('5W('9E:6QI9VAE:60@=&4@8F5S8VAE<FUE;BP@
M9&EE;G0@=2!Z:6-H(&]P;FEE=7<@86%N('1E(&UE;&1E;BX`57<@;F%A;3H`
M2&5T('1O979O96=E;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R
M<W1E=6YD(&1O;W(@=7<@875T:&5N=&EC871I92!B86-K96YD+"!O9B!D97IE
M(&]P=&EE(&ES(&]M(&%N9&5R92!R961E;F5N('5I=&=E<V-H86ME;&0N`$AE
M="!W965R9V5V96X@=F%N(&5E;B!G96)R=6EK97)S;&EJ<W0@=V]R9'0@;FEE
M="!O;F1E<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T:64@8F%C:V5N9"P@
M;V8@9&5Z92!O<'1I92!I<R!O;2!A;F1E<F4@<F5D96YE;B!U:71G97-C:&%K
M96QD+@!5=R!B<F]W<V5R(&QI:FMT('1E('II:FX@9V5W:6IZ:6=D('-I;F1S
M(&AE="!B96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U=R!V96EL:6=H96ED
M('1E(&)E<V-H97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T92!M
M96QD96XN`%5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z92!M;V=E;&EJ:VAE
M:60@;FEE="X`57<@8G)O=W-E<B!O;F1E<G-T975N="!D97IE('!R:6YT;W!T
M:64@;FEE="X@1')U:R!O<"!#;VYT<F]L("L@4"!O9B!/<'1I;VX@*R!0(&]M
M(&%F('1E(&1R=6MK96XN`%5W(&AU:61I9V4@=&EJ9'IO;F4Z`%5W('-T86YD
M86%R9"!I9&5N=&ET96ET.@!5=R!V;VQL961I9V4@;F%A;3H`57<@9V5T=&5X
M="!V97)S:64@:7,@=&4@;W5D(&5N(&]N9&5R<W1E=6YT(&=E96X@4$A0+@I.
M:65T(&%L;&4@<W1R:6YG<R!Z=6QL96X@=V]R9&5N('5I=&=E9FEL=&5R9"X`
M57<@;FEE=7=E('=A8VAT=V]O<F0@=F]O<B`E<R!I<SH@)7,`57<@;FEE=7=E
M('=A8VAT=V]O<F0@:W=A;2!N:65T(&]V97)E96X`57<@;W!T:65S('II:FX@
M8FEJ9V5W97)K="!V;V]R(&1E(&1U=7(@=F%N(&1E>F4@<V5S<VEE+@!5=R!O
M<'1I97,@>FEJ;B!B:6IG97=E<FMT+@!5=R!W86-H='=O;W)D(&ES(&=E<F5S
M970`57<@=V%C:'1W;V]R9"!I<R!V97)N:65U=V0L(&-O;G1R;VQE97(@=7<@
M92UM86EL(&5N(&UE;&0@86%N(&UE="!U=R!N:65U=V4@=V%C:'1W;V]R9"X`
M57<@<V5R=F5R<R!O<"!A9G-T86YD.@!*;V5G;W-L879IZP!:8>]R90!:86UB
M:6$`6FEM8F%B=V4`6FEP<'D`6U9E<F)E<F<@86%N9V5H86%L9&4@=&5K<W1=
M`%M0<F]B;&5E;7)A<'!O<G1=`%M!86YG96AA86QD92!T96MS="!W965R9V5V
M96X@+0!;06%N9V5H86%L9&4@=&5K<W0@+2`E<R!R96=E;'-=`%MR96=E;"`E
M<R!V86X@)7-=`$)?96AE97(`7T-,20!?1&%T851R964`5F5R7W=I:F1E<B!R
M:6H`7T=R;V5P96X`7TAE;'``7T%F8F5E;&1I;F=S96EG96YS8VAA<'!E;BXN
M+@!?06%N;65L9&5N`%]!9FUE;&1E;@!?5VEJ>FEG(&QI;FLN+BX`7T]P=&EE
M<P!?4F5C:'1E;@!?5F5R=VEJ9&5R(&QI;FLN+BX`7TEN<W1E;&QE;@!?5&%B
M96QE:6=E;G-C:&%P<&5N+BXN`$=E7V)R=6EK97)S`$%D<F5S8F]E:P!E<B!H
M965F="!Z:6-H(&5E;B!F;W5T('9O;W)G961A86X`2V%L96YD97(`2V%L;0!+
M;&EK(&AI97(`9V5D86%N`&UI<VQU:W0`9&%L96YD`&)E<W1A;F0`9V5V;VYD
M96XZ(`!V86X@9&4@)7,@*"5S*2!O<"`E<R`E<P!H.@!I,3AN`&]N;6ED9&5L
M:6IK`&EN;&EN90!R96=E;'-=`&UK:7-O9G,@9F]U=&-O9&4@)60@8FEJ(&AE
M="!A86YM86ME;B!V86X@25-/+@!N86%M`&YI970@9V5W:6IZ:6=D`&YI970@
M9V5V;VYD96X`;FEE="!V86X@=&]E<&%S<VEN9P!.;V<@;FEE="!V86X@=&]E
M<&%S<VEN9P!N;W1I=&EE8F]E:P!P<F]C96YT`'!I>&5L<P!S=&EJ9V5N9`!T
M;V]N('9E<G-C:&EL;&5N`'-M<S)E;6%I;"!V:6$@2%144`!S=&%B:65L`'1A
M:V5N;&EJ<W0`:&5T($AO<F1E(%!/(&)E<W1A;F0@=F]O<B!D92!L86YD:6YS
M=&5L;&EN9R`E<R!B97-T86%T(&YI970Z`%9O97(L('1E<B!B979E<W1I9VEN
M9RP@:&5T('=A8VAT=V]O<F0@='=E92!M86%L(&EN`'5N:69I960`;VYB96YO
M96UD`$)I:F=E=V5R:W0`1V5B<G5I:V5R<V5L96-T:64`=D-A<F0`=SH`=V5A
M=&AE<BYC;VT`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O;FQ?3DPO:&5L<"YX;6P`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<U,34`,3`T,3<S-C(W-#0`
M,#(Q-C0U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@<&%S<W=D
M+VQO8V%L92]N;%].3"]H96QP+GAM;"QV(#$N-"`R,#`U+S`V+S$Y(#$W.C`X
M.C4X(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)P87-S=V0M
M=7-E<FYA;64B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E5S97)N86UE/"]T
M:71L93X*("`@(#QH96%D:6YG/EEO=7(@57-E<FYA;64\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($5N=&5R('EO=7(@=7-E<FYA;64@:&5R92`H:68@:70@
M:7,@;F]T(&%L<F5A9'D@<')E9FEL;&5D*2X@3F]T(&%L;"!I;G-T86QL871I
M;VYS('-U<'!O<G0@=&AI<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!A<W-W9"UO;&0M<&%S<W=O<F0B('-T871E/2)U;FMN;W=N(CX*
M("`@(#QT:71L93Y/=61E('=A8VAT=V]O<F0\+W1I=&QE/@H@("`@/&AE861I
M;F<^3W5D92!W86-H='=O;W)D/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%
M;G1E<B!Y;W5R(&-U<G)E;G0L('=O<FMI;F<@;&]G:6X@<&%S<W=O<F0@:&5R
M92X@(%EO=2!M=7-T(&-O<G)E8W1L>2!E;G1E<B!Y;W5R(&-U<G)E;G0@;&]G
M:6X@<&%S<W=O<F0L(&]R('EO=2!C86X@;F]T(&-H86YG92!Y;W5R('!A<W-W
M;W)D+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I
M9#TB<&%S<W=D+6]L9"UP87-S=V]R9"(^"B`@("`\=&ET;&4^3VQD(%!A<W-W
M;W)D/"]T:71L93X*("`@(#QH96%D:6YG/D]L9"!087-S<W=O<F0\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5N=&5R('EO=7(@8W5R<F5N="P@=V]R:VEN
M9R!L;V=I;B!P87-S=V]R9"!H97)E+B`@66]U(&UU<W0@8V]R<F5C=&QY(&5N
M=&5R('EO=7(@8W5R<F5N="!L;V=I;B!P87-S=V]R9"P@;W(@>6]U(&-A;B!N
M;W0@8VAA;F=E('EO=7(@<&%S<W=O<F0N"B`@("`\+W!A<F$^"CPO96YT<GD^
M+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G!A<W-W9"UN97<M<&%S<W=O<F0B
M('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y.:65U=R!W86-H='=O;W)D
M/"]T:71L93X*("`@(#QH96%D:6YG/DYI975W('=A8VAT=V]O<F0\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($=E968@=7<@;FEE=7=E('=A8VAT=V]O<F0@
M;W`L(&1I="!I<R!H970@=V%C:'1W;V]R9"!W86%R:6X@=2!H970@;W5D92!W
M:6QT('9E<F%N9&5R96XN($]N=&AO=60@9&%T(&AE="!W86-H='=O;W)D(&%A
M;B!V97)S8VAI;&QE;F1E(&5I<V5N(&UO970@=F]L9&]E;B`H:7,@:&5T(&QA
M;F<@9V5N;V5G+"!I<R!H970@;FEE="!G96QI:FL@86%N('5W(&=E8G)U:6ME
M<G-N86%M+"!E96X@8V]M8FEN871I92!V86X@;&5T=&5R<R!E;B!C:6IF97)S
M+"!E=&,I(&%N9&5R<R!K<FEJ9W0@=2!E96X@9F]U=&UE;&1I;F<N"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)P87-S=V0M
M;F5W+7!A<W-W;W)D(CX*("`@(#QT:71L93Y.97<@4&%S<W=O<F0\+W1I=&QE
M/@H@("`@/&AE861I;F<^3F5W(%!A<W-W;W)D/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!%;G1E<B!T:&4@;F5W('!A<W-W;W)D+"!T:&%T(&ES('=H870@
M>6]U('=A;G0@=&\@8VAA;F=E('EO=7(@<&%S<W=O<F0@=&\N("!.;W1E('1H
M870@=&AE('!A<W-W;W)D(&5N=&5R960@;75S="!M965T('-O;64@;6EN:6UU
M;2!S=&%N9&%R9',@*'-U9F9I8VEE;G0@;&5N9W1H+"!N;W0@;6%T8V@@>6]U
M<B!U<V5R;F%M92P@:&%V92!A(&-O;6)I;F%T:6]N(&]F(&QE='1E<G,@86YD
M(&]T:&5R(&-H87)A8W1E<G,L(&5T8RD@;W(@>6]U('=I;&P@9V5T(&%N(&5R
M<F]R+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P87-S=V0M8V]N9FER;2UP87-S=V]R9"(@<W1A=&4](G5N:VYO=VXB
M/@H@("`@/'1I=&QE/DYO9VUA86QS(&YI975W('=A8VAT=V]O<F0\+W1I=&QE
M/@H@("`@/&AE861I;F<^3F]G;6%A;',@;FEE=7<@=V%C:'1W;V]R9#PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@1V5E9B!O<&YI975W('5W(&YI975W92!W
M86-H='=O;W)D(&]P(&EN(&AE="!697)I9FEE97(@=V%C=&AW;V]R9"!V96QD
M+B`@1&ET(&ES(&]M('1E('9E<FMO;65N(&1A="!U('!E<B!O;F=E;'5K(&5E
M;B!T>7!E(&9O=70@:&5E9G0@9V5M86%K="!E;B!N:65T(&UE97(@:6X@=7<@
M86-C;W5N="!K=6YT(&MO;65N+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@
M96YT<GDZ"CQE;G1R>2!I9#TB<&%S<W=D+6-O;F9I<FTM<&%S<W=O<F0B/@H@
M("`@/'1I=&QE/D-O;F9I<FT@3F5W(%!A<W-W;W)D/"]T:71L93X*("`@(#QH
M96%D:6YG/D-O;F9I<FT@3F5W(%!A<W-W;W)D/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!%;G1E<B!T:&4@;F5W('!A<W-W;W)D(&$@<V5C;VYD('1I;64@
M:6X@=&AE($-O;F9I<FT@3F5W(%!A<W-W;W)D(&%R96$N("!4:&ES(&ES('1O
M(&UA:V4@<W5R92!Y;W4@9&]N)W0@;6%K92!A('1Y<&\@;W(@;W1H97(@;6ES
M=&%K92!A;F0@;&]C:R!Y;W4@;W5T(&]F('EO=7(@86-C;W5N="X*("`@(#PO
M<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&%S<W=D
M+7-E<G9E<B(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^0VAA;F=E('!A<W-W
M;W)D(&]N/"]T:71L93X*("`@(#QH96%D:6YG/D-H86YG92!P87-S=V]R9"!O
M;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5L96-T('1H92!S97)V97(@
M;W(@87!P;&EC871I;VX@:6X@=VAI8V@@>6]U('=A;G0@=&\@8VAA;F=E('1H
M92!P87-S=V]R9"X@3F]T(&%L;"!I;G-T86QL871I;VYS('-U<'!O<G0@=&AI
M<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](D-H86YG92UY
M;W5R+7!A<W-W;W)D(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^5F5R
M86YD97(@=V%C:'1W;V]R9#PO=&ET;&4^"B`@("`\:&5A9&EN9SY697)A;F1E
M<B!W86-H='=O;W)D/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$<G5K(&]P
M(&1E(")#:&%N9V4@>6]U<B!P87-S=V]R9"(@8G5T=&]N(&]N9&5R(&1E('9E
M;&1E;B!O;2!H970@=V%C:'1W;V]R9"!T92!W:6IZ:6=E;B!I;B!H970@<WES
M=&5E;2X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@
M:60](D-H86YG92UY;W5R+7!A<W-W;W)D(CX*("`@(#QT:71L93Y#:&%N9V4@
M>6]U<B!P87-S=V]R9#PO=&ET;&4^"B`@("`\:&5A9&EN9SY#:&%N9V4@>6]U
M<B!P87-S=V]R9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4')E<W,@=&AE
M("9Q=6]T.T-H86YG92!Y;W5R('!A<W-W;W)D)G%U;W0[(&)U='1O;B!A="!T
M:&4@8F]T=&]M(&]F('1H92!F;W)M('1O('-U8FUI="!Y;W5R('!A<W-W;W)D
M(')E<75E<W0@8VAA;F=E('1O('1H92!S>7-T96TN("!4:&ES(&)U='1O;B!T
M96QL<R!T:&4@<WES=&5M('1O(&%C='5A;&QY(&-H86YG92!Y;W5R('!A<W-W
M;W)D+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)R97-E="(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E)E<V5T
M/"]T:71L93X*("`@(#QH96%D:6YG/E)E<V5T/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!$<G5K(&]P(&1E>F4@:VYO<"!O;2!A;&QE('9E;&1E;B!T92!L
M96=E;B!Z;V1A="!U(&]P;FEE=7<@=7<@=V%C:'1W;V]R9&5N(&EN(&MU;G0@
M=G5L;&5N+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB<F5S970B/@H@("`@/'1I=&QE/E)E<V5T/"]T:71L93X*("`@(#QH
M96%D:6YG/E)E<V5T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!5<V4@=&AE
M(%)E<V5T(&)U='1O;B!A="!T:&4@8F]T=&]M(&]F('1H92!F;W)M('1O(&-L
M96%R(&%N>2!F;W)M(&1A=&$@=&AA="!Y;W4@:&%V92!E;G1E<F5D(&%N9"!S
M=&%R="!O=F5R+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O
M;FY?3D\O````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#0`,#(P,3<S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&%S<W=D+VQO8V%L92]N;E].3R],0U]-15-304=%4R\`````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P,C$W-C``(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+VYN7TY/+TQ#7TU%
M4U-!1T53+W!A<W-W9"YM;P``````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8Q-#<U`#$P-#$W
M,S8R-S0T`#`R,S8S,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#>$@25`````"P!```<````?`D``)$!``#<$@```````"`9
M```+````(1D``"@````M&0``"P```%89```5````8AD``$````!X&0``+0``
M`+D9```D````YQD``"D````,&@``&0```#8:```(````4!H``"(```!9&@``
M!0```'P:```#````@AH```D```"&&@``&0```)`:```>````JAH``!````#)
M&@``#P```-H:```(````ZAH```@```#S&@``&0```/P:```'````%AL```P`
M```>&P``"P```"L;```.````-QL```4```!&&P``'P```$P;```E````;!L`
M`#D```"2&P``)P```,P;```L````]!L``"H````A'```$0```$P<```&````
M7AP```@```!E'```!0```&X<```$````=!P```P```!Y'````P```(8<```(
M````BAP```H```"3'```!@```)X<```5````I1P```H```"['```%````,8<
M``!$````VQP```8````@'0``$0```"<=```*````.1T``!$```!$'0``#```
M`%8=```'````8QT``!````!K'0``%0```'P=```K````DAT``!````"^'0``
M&P```,\=```>````ZQT``!L````*'@``&P```"8>```S````0AX``"\```!V
M'@``*0```*8>```"````T!X```4```#3'@``%@```-D>```0````\!X```8`
M```!'P``!`````@?```4````#1\``"\````B'P``"P```%(?```/````7A\`
M`"8```!N'P``!````)4?```9````FA\```4```"T'P``#0```+H?```%````
MR!\``!````#.'P``$````-\?```/````\!\```L`````(```#P````P@```,
M````'"````\````I(```(````#D@```=````6B```!X```!X(```(0```)<@
M```?````N2````,```#9(```#````-T@```&````ZB```!$```#Q(```!0``
M``,A```$````"2$``!0````.(0``!@```",A```)````*B$```0````T(0``
M#````#DA```*````1B$```4```!1(0``%````%<A```:````;"$```L```"'
M(0``(````),A```9````M"$```X```#.(0``(````-TA```&````_B$```X`
M```%(@``$@```!0B```0````)R(```X````X(@``'````$<B```(````9"(`
M``H```!M(@``$````'@B```:````B2(```8```"D(@``!P```*LB``!<````
MLR(```8````0(P```@```!<C```E````&B,```0```!`(P``&````$4C```1
M````7B,```\```!P(P``!P```(`C```%````B",```<```".(P``&@```)8C
M```)````L2,```<```"[(P``"@```,,C```2````SB,```0```#A(P``!P``
M`.8C```%````[B,```T```#T(P``/`````(D```Z````/R0``#L```!Z)```
M,P```+8D```^````ZB0``!T````I)0``&@```$<E``!)````8B4```4```"L
M)0``(P```+(E```-````UB4```<```#D)0``!@```.PE```1````\R4```@`
M```%)@``$0````XF```J````("8``!H```!+)@``%0```&8F```>````?"8`
M`"@```";)@``"P```,0F```:````T"8```4```#K)@``*````/$F```I````
M&B<``%$```!$)P``#0```)8G```3````I"<```@```"X)P``,@```,$G```$
M````]"<``!4```#Y)P``!@````\H```+````%B@``!P````B*```0````#\H
M```]````@"@``#<```"^*```0@```/8H```^````.2D``#\```!X*0``-P``
M`+@I``!"````\"D``#X````S*@``/P```'(J```W````LBH``$(```#J*@``
M/@```"TK```_````;"L``#8```"L*P``00```.,K```]````)2P``#X```!C
M+```-````*(L```_````URP``#L````7+0``/````%,M``!$````D"T``#T`
M``#5+0``.@```!,N```W````3BX``$(```"&+@``/@```,DN```_````""\`
M``4```!(+P``$0```$XO```$````8"\```D```!E+P``#````&\O``!H````
M?"\``!H```#E+P``%P`````P```7````&#```!L````P,```&0```$PP```?
M````9C```!,```"&,```0@```)HP```D````W3````X````",0``!````!$Q
M```0````%C$``#`````G,0``.@```%@Q```,````DS$``!<```"@,0``!P``
M`+@Q```F````P#$``!H```#G,0``*@````(R```#````+3(```4````Q,@``
M,0```#<R```X````:3(``$P```"B,@``CP```.\R```N````?S,``#(```"N
M,P``=````.$S``#-````5C0``)L````D-0``<P```,`U``"F````-#8``(D`
M``#;-@``<P```&4W```A````V3<``!P```#[-P``!0```!@X```.````'C@`
M``,````M.```(````#$X```:````4C@``"H```!M.```)@```)@X```,````
MOS@``!<```#,.```!@```.0X```-````ZS@``!$```#Y.```$P````LY```,
M````'SD```@````L.0``!0```#4Y```4````.SD```<```!0.0``"````%@Y
M```&````83D```T```!H.0``"P```'8Y```,````@CD```H```"/.0```@``
M`)HY```&````G3D```P```"D.0``)0```+$Y```^````USD``$4````6.@``
M'P```%PZ```?````?#H``"8```"<.@``)0```,,Z```A````Z3H``#`````+
M.P``$P```#P[```0````4#L```H```!A.P``<@```&P[``!S````WSL``!\`
M``!3/```'P```',\```?````DSP``!````"S/```#P```,0\```$````U#P`
M``4```#9/```.P$``-\\```*````&SX``"@````F/@``"P```$\^```4````
M6SX``$,```!P/@``,0```+0^```B````YCX``"0````)/P``'````"X_```(
M````2S\``"@```!4/P``!0```'T_```(````@S\``!H```",/P``*0```*<_
M```J````T3\``!0```#\/P``$P```!%````,````)4````\````R0```'@``
M`$)````'````84````H```!I0```"@```'1````.````?T````4```".0```
M(P```)1````F````N$```#L```#?0```+0```!M!```O````24$``"X```!Y
M00``$P```*A!```&````O$$```<```##00``!````,M!```#````T$$```T`
M``#400```P```.)!```(````YD$```H```#O00``!@```/I!```5`````4(`
M``P````70@``#0```"1"```K````,D(```@```!>0@``%@```&="```*````
M?D(``!0```")0@``#@```)Y"```%````K4(``!````"S0@``%@```,1"```K
M````VT(```X````'0P``%0```!9#```=````+$,``"````!*0P``'````&M#
M```P````B$,``#8```"Y0P``+````/!#```"````'40```8````@1```%P``
M`"=$```1````/T0```8```!11```!````%A$```1````740``"8```!O1```
M"0```)9$```1````H$0``",```"R1```!0```-9$```6````W$0```8```#S
M1```#@```/I$```$````"44``!`````.10``$````!]%```/````,$4```\`
M``!`10``#P```%!%```,````8$4``!````!M10``&@```'Y%```;````F44`
M`!\```"U10``(P```-5%```<````^44```0````61@``#0```!M&```&````
M*48```\````P1@``!````$!&```#````148``!0```!)1@``!P```%Y&```,
M````9D8```4```!S1@``#P```'E&```/````B48```4```"91@``%````)]&
M```:````M$8``!````#/1@``'````.!&```:````_48```X````81P``)```
M`"='```&````3$<```P```!31P``$P```&!'```0````=$<```L```"%1P``
M%@```)%'```%````J$<```<```"N1P``$@```+9'```@````R4<```@```#J
M1P``!P```/-'``!I````^T<```<```!E2````@```&U(```E````<$@```8`
M``"62```&@```)U(```1````N$@``!````#*2```"0```-M(```%````Y4@`
M``<```#K2```&@```/-(```)````#DD```@````820``#@```"%)```5````
M,$D```0```!&20``"````$M)```%````5$D```T```!:20``0P```&A)```_
M````K$D``$(```#L20``.````"]*``!"````:$H``"4```"K2@``(````-%*
M``!$````\DH```<````W2P``&P```#]+```0````6TL```H```!L2P``!P``
M`'=+```1````?TL```<```"12P``#@```)E+```N````J$L``!X```#72P``
M%0```/9+```<````#$P``"P````I3```!P```%9,```6````7DP```<```!U
M3```)0```'U,```D````HTP``%0```#(3```#@```!U-```6````+$T```@`
M``!#30``+P```$Q-```#````?$T``!D```"`30``!0```)I-```)````H$T`
M`"````"J30``4````,M-``!'````'$X``#\```!D3@``20```*1.``!&````
M[DX``$D````U3P``/P```']/``!)````OT\``$8````)4```20```%!0```_
M````FE```$D```#:4```1@```"11``!)````:U$``#X```"U40``2````/11
M``!%````/5(``$@```"#4@``/````,Q2``!&````"5,``$,```!04P``1@``
M`)13``!,````VU,``$0````H5```1````&U4```_````LE0``$D```#R5```
M1@```#Q5``!)````@U4```D```#-50``%@```-=5```%````[E4```H```#T
M50``$````/]5``!8````$%8``!D```!I5@``#P```(-6```/````DU8``!@`
M``"C5@``$````+Q6```0````S58``!,```#>5@``/````/)6```0````+U<`
M``\```!`5P```P```%!7```5````5%<``#````!J5P``.P```)M7```0````
MUU<``!H```#H5P``!P````-8```9````"U@```P````E6```&0```#)8```#
M````3%@```@```!06```*0```%E8```U````@U@``$@```"Y6```DP````)9
M```J````EED``"H```#!60``?P```.Q9``#D````;%H``+$```!16P``CP``
M``-<``"D````DUP``)L````X70``@P```-1=```>````6%X``!X```!W7@``
M!@```)9>```-````G5X```,```"K7@``'@```*]>```<````SEX``"H```#K
M7@``*````!9?```/````/U\``!4```!/7P``"````&5?```0````;E\``!(`
M``!_7P``%````))?```0````IU\```H```"X7P``"````,-?```4````S%\`
M``@```#A7P``"0```.I?```)````]%\```\```#^7P``#`````Y@```/````
M&V````\````K8````@```#M@```%````/F````X```!$8```*@```%-@```Z
M````?F```#H```"Y8```(0```/1@```C````%F$``"H````Z80``+0```&5A
M```@````DV$``#(```"T80``$0```.=A```/````^6$```H````)8@``%0``
M`!1B``!Y````*F(``"````"D8@``(P```,5B```F````Z6(``!`````08P``
M$````"%C```$````,F,```4````W8P```0```)<```#,`````````,<`````
M````V````"<```#Y````\@```*$```!R````J0```%\`````````-0``````
M`````````````(D`````````%`$```4`````````"````+@`````````````
M`!(!``!5`````````.(`````````]0```(0`````````B````/H````+`0``
MP0```%0``````````````$P```#[`````````*T````R````;````+0````@
M`0``J@```)@```#+`````````%@```"Z````H````&4````)`0``P````+4`
M````````+`$```````!/````20````````!9````"0````4!```*`0``)0$`
M`(8```"P````.````.,````5````JP````````"#````?0````````!@````
MAP````T!``#:````#```````````````E0```#````">````YP````````#S
M````_0```!@````6````@0```!````#3````C0```.8````(`0````````,`
M```F````'@```"X```#K`````````%P```!A````/@````````#V````````
M`#$`````````X0```%,```"[`````````"L!```3`0`````````````?````
MA0```````````0``B@```!P```#Q````8@```#,`````````>@```#T````8
M`0```````````````````````-X```"0````-@```'@```"_````*0````\`
M``"?````=```````````````$@```$0````;````KP````````!G````/P``
M`'X`````````*````)$```"D`````````$T````K````&@$``'P````9`0``
MIP```.0```![````)````*@```!Y````=P```*P````I`0``O0````````!:
M``````````````!'````)`$``$H````A````6P```$4````?`0```````!P!
M``"6`````````*,````'````WP``````````````9@````````#<````&@``
M`#H``````````````-````!.````9````.\`````````Q```````````````
M?P```/0```!P`````````,4`````````!@$``!4!``"<`````````!$!````
M````PP```*8```#=````2````(P````"`0```````.H```!"````40``````
M`````````````/<````6`0``U@````X!`````````@`````````&````````
M`'8````/`0``*@$````````O````O@```'$```"4````^`````````!`````
MV0````````#(````(P$``"(!`````````````)H```#I````#`$``!<!``#"
M````;@```$,````0`0``(````#0````H`0```P$``,H```!0````M@```*X`
M`````````````+,`````````_P```%(`````````C@````X`````````Y0``
M`&H`````````DP```,8```!&````S0```#P`````````[0```&\```#4````
M&0```%8`````````00```*4````J````Z`````````#2````H@```,X```"R
M`````````',```#\````)0```-4``````````````.P`````````%P```&@`
M``"9````$0```#L`````````+```````````````(@```&,`````````````
M`+P```!=````[@```!0`````````N0`````````>`0``)P$``+$```"2````
M(P```!L!``!I````!P$``$L`````````$P````L````=`0``"@```,\`````
M````!`````````!K````-P````````#@````.0```%X```#^````'0``````
M```!`0``+0````T```#;````=0```,D```#P````CP```-<```"`````;0``
M`((```#1````MP```(L````$`0```````)T`````````FP````````!7````
M)@$``"$!````)7,@+2!.;W1I8V4`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!3=&%N9&%R9``E<R!497)M<R!O9B!!9W)E
M96UE;G0`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`G)7,G(&ES(&YO="!C;VYF:6=U
M<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`)R5S)R!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN`"<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN`"<E<R<@=V%S(&YO="!C<F5A=&5D.B`E<RX`,C0@
M:&]U<G,`/&(^02!F871A;"!E<G)O<B!H87,@;V-C=7)R960Z/"]B/@!!32]0
M30!!9&0`061D($-H:6QD`$%D9"!A(&-H:6QD(&=R;W5P('1O("<E<R<`061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G`$%D9"!A(&YE=R!M96UB97(`
M061D(&$@;F5W('5S97(Z`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061D<F5S<V)O
M;VL`061M:6YI<W1R871I;VX`06QI87,`06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+@!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("<E
M<R<_`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%V86EL86)L92!F:65L9',Z`$)A<F)I90!":7)T:&1A>0!"
M<F]W;@!"=6=S`$)U<FYT($]R86YG90!#5E,`0V%L96YD87(`0V%M;W5F;&%G
M90!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-E;&P@4&AO;F4`0VAA
M;F=E('EO=7(@<&%S<W=O<F0`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A
M=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAE
M<G)Y`$-L:6-K('1O($-O;G1I;G5E`$-L;W-E($AE;'``0VQO<V4@2&5L<"!7
M:6YD;W<`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]N9FER;2!087-S=V]R9`!#
M;VYF:7)M(&YE=R!P87-S=V]R9#H`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYT96YT<R!O9B`G)7,G`$-O;G1E;G1S
M(&]F('1H92!205(@87)C:&EV90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!D
M96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I
M<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L
M:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&%T86)A<V4@<75E
M<GD@9F%I;&5D+@!$969A=6QT($ED96YT:71Y`$1E;&5T90!$96YY`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$1I<V-U<W-I;VYS`$1I<W!L87D@3W!T:6]N
M<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%9&ET
M`$5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<`16UA:6P`16UP='D@<F5S=6QT
M+@!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E
M<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R
M>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X<&5C=&5D(")"14=)3B(@:6X@
M=&AE(&QI;F4@)60N`$5X<&5C=&5D(")%3D0Z)7,B(&EN(&QI;F4@)60N`$9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R
M9"`Z(`!&87@`1FEL92!-86YA9V5R`$9N;W)R90!&=6QL($1E<V-R:7!T:6]N
M.@!'<F5E;@!'<F5Y`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P<P!(96%D
M;&EN97,`2&5L<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!(;W)D
M92!!9&UI;FES=')A=&EO;@!(;W)D92!'<F]U<"!!9&UI;FES=')A=&EO;@!(
M;W)D92!,;V=I;@!(;W)D92!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!(
M;W)D92!5<V5R($%D;6EN:7-T<F%T:6]N`$AO<F1E(%=I<F5L97-S`$AO<F1E
M(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D`$EM<&]R=`!);7!O<G0@17)R
M;W(Z(`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);G1E
M<FYA;"!%<G)O<@!);G9A;&ED(')E<W!O;G-E(&9R;VT@<V5R=F5R`$QA;F=U
M86=E`$QI9VAT($)L=64`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!F86EL960@9F]R
M('-O;64@<F5A<V]N+B!-;W-T(&QI:V5L>2!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=O=70`34T`35,M
M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-86EL`$UA<"!$
M871E(&%N9"!4:6UE($9I96QD<P!-87`@26UP;W)T($9I96QD<P!-871C:&EN
M9R!F:65L9',`365M8F5R<P!-96UO<P!-97-S86=E`$UE=&AO9"`G)7,G(&ES
M(&YO="!D969I;F5D`$UI;64@5'EP90!-;VYT:&QY`$UY(%-U;6UA<GD`3D\L
M($D@1&\@3D]4($%G<F5E`$YA;64`3F5T=V]R:P!.979E<@!.97<@<&%S<W=O
M<F0Z`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!,1$%0(%!R969E<F5N8V5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,($-A=&5G;W)I97,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@4')E9F5R96YC
M97,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(&%U=&AE;G1I8V%T:6]N+@!.;R!P<F5F97)E;F-E<R!A
M<F4@879A:6QA8FQE+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;W1E
M.B!9;W4@=VEL;"!N965D('1O(&QO9V]U="!A;F0@8F%C:R!I;B!A9G1E<B!Y
M;W4@8VAA;F=E('EO=7(@<&%S<W=O<F0A`$YO=&5S`$YO=&EF:6-A=&EO;B!L
M:7-T96YE<B`E<R!N;W0@9F]U;F0N`$]L9"!P87-S=V]R9#H`3W!T:6]N<P!/
M<F%N9V4`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&%S<W=O<F0@8VAA
M;F=E9"$`4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U
M<F5D`%!A<W-W;W)D<R!C86YN;W0@8F4@8FQA;FLN`%!A<W-W;W)D<R!M=7-T
M(&UA=&-H+@!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0:&]N90!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@<WES=&5M+@!0<F5S96YT871I;VYS`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O8FQE;3\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4F5A9`!2969R97-H(%-U;6UA<GD@
M5FEE=SH`4F5M;W9E`%)E;6]V92!P86ER`%)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960`4F5Q=6ER960@)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I;B!A
M=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G8F%S961N
M)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D
M(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D
M871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!P
M<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=H;W-T<W!E8R<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I
M960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S
M='-P96,G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S<W=O<F0G(&YO="!S<&5C
M:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D
M(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T
M>7!E)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO
M;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I
M9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P
M:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D
M(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=T
M86)L92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E
M;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B;&5296QA=&EO;G,G
M(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G=6ED)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U:60G(&YO="!S<&5C:69I960@
M:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S97)N
M86UE)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I
M;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E
M8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I
M9W5R871I;VXN`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92`G
M)7,G`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'1A<F5A+@!396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@
M=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5T('EO=7(@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E="!Y;W5R('!R969E<G)E9"!D:7-P;&%Y(&QA;F=U86=E
M+@!3:&]R="!3=6UM87)Y.@!3:&]W`%-K:7`@36%I;G1E;F%N8V4`4V]M92!O
M9B!(;W)D92=S(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I;F<Z`%-O
M;64@;V8@4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A
M<F4@;6ES<VEN9SH`4W!A;4%S<V%S<VEN`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("<E<R<@=&\@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@)R5S)RX`4W5C8V5S<V9U;&QY
M(')E;6]V960@)R5S)R!F<F]M('1H92!S>7-T96TN`%-U;@!487-K<P!4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&UE
M<W-A9V4@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`
M5&AE(')E9VES=')Y(&ES(&AO=R!(;W)D92!A<'!L:6-A=&EO;G,@9FEN9"!O
M=70@:&]W('1O('1A;&L@=&\@96%C:"!O=&AE<BX@66]U('-H;W5L9"!L:7-T
M(&%N>2!I;G-T86QL960@2&]R9&4@87!P;&EC871I;VYS('1H870@>6]U(&AA
M=F4@:&5R92X`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T
M:&4@<WES=&5M+@!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@
M9G)O;2!T:&4@<WES=&5M+@!4:&ES(&9I;&4@8V]N=')O;',@=&AE(&1E9F%U
M;'0@<')E9F5R96YC97,@9F]R(%!A<W-W;W)D(&UO9'5L92P@86YD(&%L<V\@
M8V]N=')O;',@=VAI8V@@<')E9F5R96YC97,@=7-E<G,@8V%N(&%L=&5R+@!4
M:&ES(&9I;&4@8V]N=')O;',@=&AE(&=L;V)A;"!S970@;V8@34E-12!D<FEV
M97)S(&9O<B!T:&4@2&]R9&4@9G)A;65W;W)K+"!A;&QO=VEN9R!A<'!L:6-A
M=&EO;G,@=&\@;6%K92!U<V4@;V8@<')O9W)A;7,@<W5C:"!A<R!E;G-C<FEP
M="!O<B!M<W=O<F1V:65W('1O(')E;F1E<B!C;VYT96YT(&EN=&\@2%1-3"!F
M;W(@=FEE=VEN9R!I;B!A(&)R;W=S97(N`%1H:7,@9FEL92!C;VYT<F]L<R!T
M:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S960@=&\@<V5T(&-O;&]R<R!A;F0@
M9F]N=',@9F]R('1H92!(;W)D92!F<F%M97=O<FL@86YD(&%L;"!A<'!L:6-A
M=&EO;G,@=&AA="!D;R!N;W0@<')O=FED92!T:&5I<B!O=VX@<V5T=&EN9W,N
M`%1H:7,@9FEL92!C;VYT<F]L<R!T:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S
M960@=&\@<V5T(&-O;&]R<R!A;F0@9F]N=',@:6X@861D:71I;VX@=&\@;W(@
M;W9E<G)I9&EN9R!(;W)D92!D969A=6QT<RX`5&AI<R!F:6QE(&UA<',@9FEL
M92!E>'1E;G-I;VYS('1O(&QO9VEC86P@34E-12!T>7!E<RP@96YA8FQI;F<@
M2&]R9&4@87!P;&EC871I;VYS('1O(&9I9W5R92!O=70@:&]W('1O(&AA;F1L
M92!S;VUE(&-O;G1E;G0@<W5C:"!A<R!E;6%I;"!A='1A8VAM96YT<R!O<B!#
M5E,@8VAE8VMO=71S+@!4:&ES(&ES('1H92!M86EN($AO<F1E(&-O;F9I9W5R
M871I;VX@9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD(&)A<VEC(&ET96US
M('1H870@87!P;'D@=&\@=&AE(&-O<F4@9G)A;65W;W)K(&%N9"!A;&P@2&]R
M9&4@87!P;&EC871I;VYS+@!4:&ES(&ES('1H92!M86EN(%!A<W-W;W)D(&UO
M9'5L92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N
M9"!O<'1I;VYS(&9O<B!A;&P@4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N`%1I=&QE`%1Y<&4@;6ES;6%T8V@N`%523`!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@9&5L971E
M("<E<R<Z("5S+@!5;F%B;&4@=&\@<F5G:7-T97(@<')E9F5R96YC97,@:6X@
M<V5S<VEO;BX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YD;R!#:&%N9V5S`%5N97AP96-T960@96YD(&]F(&9I;&4N`%5P9&%T
M90!5<&1A=&5D("<E<R<N`%5S92!$969A=6QT(%9A;'5E`%5S97(@061M:6YI
M<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97)N86UE`%5S97)S`%5S97)S(&EN
M('1H92!S>7-T96TZ`%=A<FYI;F<`5V%R;FEN9R$`5V5E:VQY`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`
M665A<FQY`%EE<RP@22!!9W)E90!9;W4@8V%N)W0@8VAA;F=E('!A<W-W;W)D
M(&9O<B!U<V5R("5S`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X\8G(@+SY4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D`%EO
M=2!M=7-T(&=I=F4@>6]U<B!O;&0@<&%S<W=O<F0`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S
M<W=O<F0`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($YA;64Z`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@;F5W('!A<W-W;W)D<R!D:61N)W0@
M;6%T8V@`66]U<B!O;&0@<&%S<W=O<F0@:7-N)W0@8V]R<F5C=`!9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI
M;F4@)7,@;V8@)7-=`&DQ.&X`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!0
M87-S=V0@,"XP+C$M8W9S"E!/5"U#<F5A=&EO;BU$871E.B`R,#`R+3`V+3`Y
M(#`Q.C`Q*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP-BTP.2`P,3HQ
M,BLP,3`P"DQA<W0M5')A;G-L871O<CH@4&5R+5-T:6%N(%9A=&YE(#QP<W9`
M;W)S=&$N;W)G/@I,86YG=6%G92U496%M.B!.;W)W96=I86X@3GEN;W)S:R`\
M;GEN;W)S:T!O<G-T82YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"5S("T@3F]T:7,`)7,@=F5D;&EK
M96AA;&1S;W!E<F%S:F]N87(@+2!3=&%D9F5S=&EN9P`E<R!3=&%N9&%R9``E
M<R!6:6QKY7(@9F]R(&%V=&%L90`E<R!E<B!K;&%R('1I;"#E(&OX>7)E('9E
M9&QI:V5H86QD<V]P97)A<VIO;F%N92!S;VT@97(@=F%L9&4@=6YD97(N`"<E
M<R<@97(@:6MK:F4@:V]N9FEG=7)E<G0@:2!R96=I<W1E<F5T('1I;"!(;W)D
M92X`)R5S)R!V87)T(&QA9W0@=&EL(&=R=7!P97-Y<W1E;65T+@`G)7,G('9A
M<G0@;&%G="!T:6P@=&EL9V%N9W-S>7-T96UE="X`)R5S)R!V87)T(&EK:VIE
M(&]P<')E='1A.B`E<P`R-"!T:6UA<@`\8CY$970@<VMJ961D92!E:6X@:V%T
M87-T<F]F86P@9F5I;#H\+V(^`$%-+U!-`$QE9V<@=&EL`$QE9V<@=&EL('5N
M9&5R;W)D;F$@;V)J96MT`$QE9V<@=&EL('5N9&5R;W)D;F$@;V)J96MT9W)U
M<'!E('1I;"`G)7,G`$QE9V<@=&EL('5N9&5R;W)D;F$@;V)J96MT=&EL9V%N
M9R!T:6P@)R5S)P!,96=G('1I;"!N>71T(&UE9&QE;0!,96=G('1I;"!N>2!B
M<G5K87(Z`$QE9V<@=&EL('!A<@!,96=G('1I;"!B<G5K87(`3&5G9R!T:6P@
M8G)U:V%R87(@97(@<VSE='0@878N`$%D<F5S<V4`061R97-S96)O:P!!9')E
M<W-E8F]K`$%D;6EN:7-T<F5R:6YG`$%L:6%S`$5I;B!U;&]V;&5G('9E<F1I
M('9A<G0@<W!E<VEF:7-E<G0N`$5R(&1U('-I:VME<B!PY2!A="!D=2!V:6P@
M<VQE='1E("<E<R<_`%-P^'(@;VT@<W1A9&9E<W1I;F<@9OAR(&OX>7)I;F<@
M878@=F5D;&EK96AA;&1S;W!E<F%S:F]N87(_`%!R^'9D92#E('-L971T92!E
M:2!I:VMJ92UE:W-I<W1E<F%N9&4@9W)U<'!E+@!0<OAV9&4@Y2!S;&5T=&4@
M96EN(&EK:VIE+65K<VES=&5R86YD92!T:6QG86YG+@!0<OAV9&4@Y2!E;F1R
M92!E:6X@:6MK:F4M96MS:7-T97)A;F1E('1I;&=A;F<N`%1I;&=J96YG96QE
M9V4@9F5L=#H`0F%R8FEE`$)U<G-D86<`0G)U;@!,=7,`0G)E;G0@;W)A;G-J
M90!#5E,`2V%L96YD97(`2V%M=69L87-J90!!=F)R>70`079B<GET('!R;V)L
M96UR87!P;W)T`$UO8FEL=&5L969O;@!%;F1R92!P87-S;W)D`$MR>7-S(&%V
M(&9O<B!O<&5R87-J;VXH87(I(&1U('9I;"!K^'ER92!N;RX`2VER<V5BYG(`
M2VQI:VL@9F]R(.4@:&%L9&4@9G)A;0!,=6MK($AJ96QP`$QU:VL@2&IE;'`M
M=FEN9&%U9V5T`$QU:VL@=FEN9&%U9V5T`$9I<FUA`%-T861F97-T('!A<W-O
M<F0`4W1A9&9E<W0@;GET="!P87-S;W)D.@!/<'!K;W!L:6YG(&UO="!O9F9E
M;G1L96<@;OAK:V5L=&5N87(@;F5K=&$N`$EN;FAA;&0@:2`G)7,G`$EN;FAA
M;&0@:2!205(M87)K:79E=`!+=6YN92!I:VMJ92!01U`M:V]D92!M96QD:6YG
M+@!+=6YN92!I:VMJ92!01U`M<VEG;F5R92!M96QD:6YG+@!+=6YN92!I:VMJ
M92!D96MO9&4@4$=0+61A=&$N`$MU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K
M87)E;B!S:2!E+7!O<W1A9')E<W-E+@!+=6YN92!I:VMJ92!S:V%F9F4@;V9F
M96YT;&5G(&[X:VME;"!F<N4@;OAK:V5L=&5N87)E;BX`2W5N;F4@:6MK:F4@
M;W!N92!-86EN=&5N86YC95]487-K+6UO9'5L96X@)7,`1$0`1&%G;&5G`$1A
M=&%B87-E<W#X<FII;F<@9F5I;&$N`%-T86YD87)D:61E;G1I=&5T`%-L971T
M90!.96MT`%-K:6QD<F4@<')O8FQE;65T`$1E=&%L:F%R(&5R(&QO9V=A(&9O
M<B!A9&UI;FES=')A=&]R96XN`$1I<VMU<VIO;@!6:7-I;F=S86QT97)N871I
M=@!):VMJ92!B<G5K(&UA:6YT96YA;F-E+G!H<"!D:7)E:W1E+@!%;F1R90!%
M;F1R92!T:6QG86YG(&9O<B`G)7,G`$4M<&]S=`!4;VUT(')E<W5L=&%T+@!&
M96EL`$MV87)T(#$U+B!M:6YU='0`2W9A<G0@,S`N('-E:W5N9`!+=F%R="`U
M+B!M:6YU='0`2W9A<B!I;FYL;V=G:6YG`$MV87(@:&%L=F4@=&EM90!+=F%R
M="!M:6YU='0`16MS96UP96QV97)D:6%R.@!696YT82`B0D5'24XB('#E(&QI
M;FIE("5D+@!696YT82`B14Y$.B5S(B!PY2!L:6YJ92`E9"X`2W5N;F4@:6MK
M:F4@:&5N=&4@:6YN<W1I;&QI;F=A<@!+=6YN92!I:VMJ92!K;W!L92!T:6P@
M3$1!4"UT96YA<F5N+@!&96EL('9E9"!E;F1R:6YG(&%V('!A<W-O<F0Z`$9A
M:W,`1FEL:&%N9'-A;6EN9P!&;F]R<F4`1G5L;"!S:VEL9')I;F<Z`$=R^&X`
M1W+E`$=R=7!P96%D;6EN:7-T<F5R:6YG`$=R=7!P97(`3W9E<G-K<FEF=&5R
M`$AJ96QP`$%D<F5S<V4L('!R:79A=`!496QE9F]N+"!P<FEV870`2&]R9&4`
M2&]R9&4@061M:6YI<W1R97)I;F<`2&]R9&4@1W)U<'!E861M:6YI<W1R97)I
M;F<`2&]R9&4@26YN;&]G9VEN9P!(;W)D92!4:6QG86YG<V%D;6EN:7-T<F5R
M:6YG`$AO<F1E($)R=6MA<F%D;6EN:7-T<F5R:6YG`$AO<F1E(%1RY61L875S
M`$AO<F1E(&5R(&EK:VIE(&]R9&5N=&QE9R!K;VYF:6=U<F5R=`!);7!O<G0`
M26UP;W)T9F5I;#H@`$EM<&]R=&5R=&4@9F5L=#H@)7,`26UP;W)T97)T92!F
M96QT.@!);G1E<FX@9F5I;`!59WEL9&EG('-V87(@9G+E('1E;F%R`%-P<N5K
M`$QY<R!B;.4`5FES(&5M;F4@9G+E($AJ96QP`$QI<W1I;F<@878@8G)U:V%R
M87(@97(@<VSE='0@878N`$QO9V<@:6YN`$QO9V<@=70`2W5N;F4@878@96EN
M(&5L;&5R(&%N;F%N(&=R=6YN(&EK:VIE(&QO9V=E(&EN;BX@4V%N;G-Y;FQE
M9W9I<R!E<B!B<G5K87)N86UN(&5L;&5R('!A<W-O<F0@=&%S=&$@:6YN(&9E
M:6PN`$QO9V<@=70`34T`35,M5$Y%1BUV961L96=G(&EN;F5H96QD="!I;F=E
M;B!D871A+@!%+7!O<W0`2V]P;&4@9F5L="!F;W(@9&%T;R!O9R!T:60`2V]P
M;&4@:6UP;W)T9F5L=&$`4V%M<W9A<F%N9&4@9F5L=`!-961L96UM87(`3F]T
M870`365L9&EN9P!-971O9&4@)R5S)R!I:VMJ92!D969I;F5R=`!-24U%+71Y
M<&4`3>5N861L96<`36ET="!S86UA;F1R86<`3D5)+"!E9R!E<B!)2TM*12!S
M86UD`$YA;6X`3F5T='9E<FL`06QD<FD`3GET="!P87-S;W)D.@!);F=E;B!K
M;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!,1$%0
M+6EN;G-T:6QL:6YG87(N`$EN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J
M;VX@<W!E<VEF:7-E<G0@9F]R(%-13"UK871E9V]R:6%R+@!);F=E;B!K;VYF
M:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344PM:6YN
M<W1I;&QI;F=A<BX`26YG96X@:V]N9FEG=7)A<VIO;G-I;F9O<FUA<VIO;B!S
M<&5S:69I<V5R="!F;W(@4U%,(%9&4RX`26YG96X@:V]N9FEG=7)A<VIO;G-I
M;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N
M`$EN9V5N(&EN;G-T:6QL:6YG87(@97(@=&EL9VIE;F=E;&5G92X`26YG96X@
M9WEL9&EG92!834PM9&%T82!R971U<FYE<G0`365R:SH@1'4@;>4@;&]G9V4@
M=70@;V<@:6YN(&EG:F5N(&5T=&5R(&%T(&1U(&5N9')A<B!P87-S;W)D970@
M9&ET="$`3F]T871A<@!&86YN(&EK:VIE('9A<G-E;&QY='1A<B`E<RX`1V%M
M;6%L="!P87-S;W)D.@!!;'1E<FYA=&EV`$]R86YS:F4`06YN86X@:6YF;W)M
M87-J;VX`4&%S<V]R9`!087-S;W)D(&5N9')A(0!087-S;W)D+6UO9'5L96X@
M97(@:6MK:F4@;W)D96YT;&5G(&MO;F9I9W5R97)T`%!A<W-O<F0@:V%N(&EK
M:VIE('9E<F4@8FQA;FME+@!087-S;W)D82!MY2!S86US=F%R92X`2_AY<B!V
M961L:6ME:&%L9'-O<&5R87-J;VYA<@!+^'ER('9E9&QI:V5H86QD<V]P97)A
M<VIO;F%R('9E9"!I;FYL;V=G:6YG/P!4:6QG86YG`%1I;&=A;F=S861M:6YI
M<W1R97)I;F<`5&5L969O;@!3:W)I=B!I;FX@96ET('-A;6%N9')A9R!A=B!P
M<F]B;&5M970N`%-K<FEV(&EN;B!D:71T(&)R=6MA<FYA;6X@;V<@<&%S<V]R
M9`!697(@=F5N;&5G(&]G(&QE<R!F^&QG:F%N9&4@=&5K<W0N($1U($W%('9E
M<F4@<V%M9"!M960@=FEL:^5R82!F;W(@Y2!B<G5K92!S>7-T96UE="X`4')E
M<V5N=&%S:F]N87(`4VMI;&1R:6YG(&%V('!R;V)L96UE=`!0<F]B;&5M/P!/
M9F9E;G1L96<O<')I=F%T(&[X:VME;'!A<B!V87)T(&EK:VIE(&=E;F5R97)T
M+@!,97,`1G)I<VL@;W!P(&]V97)S:6MT=FES:6YG.@!&:F5R;@!&:F5R;B!P
M87(`2W5N;F4@:6MK:F4@<W9A<F4@<.4@9OAR97-P=7)N860`3OAD=F5N9&EG
M('9A<FEA8F5L("=B87-E9&XG(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG
M=7)A<VIO;B!F;W(@875T96YT:7-E<FEN9RX`3OAD=F5N9&EG("=B87-E9&XG
M(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@:6YN<W1I
M;&QI;F=A<BX`3OAD=F5N9&EG("=D871A8F%S92<@:6MK:F4@<W!E<VEF:7-E
M<G0@:2!K;VYF:6=U<F%S:F]N(&9O<B!61E,N`$[X9'9E;F1I9R`G9&%T86)A
M<V4G(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@875T
M96YT:7-E<FEN9RX`3OAD=F5N9&EG("=D871A8F%S92<@:6MK:F4@<W!E<VEF
M:7-E<G0@:2!K;VYF:6=U<F%S:F]N(&9O<B!K871E9V]R:6%R+@!.^&1V96YD
M:6<@)V1A=&%B87-E)R!I:VMJ92!S<&5S:69I<V5R="!I(&MO;F9I9W5R87-J
M;VX@9F]R(&EN;G-T:6QL:6YG87(N`$[X9'9E;F1I9R`G:&]S='-P96,G(&EK
M:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@5D93+@!.^&1V
M96YD:6<@)VAO<W1S<&5C)R!I:VMJ92!S<&5S:69I<V5R="!I(&MO;F9I9W5R
M87-J;VX@9F]R(&%U=&5N=&ES97)I;F<N`$[X9'9E;F1I9R`G:&]S='-P96,G
M(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@:V%T96=O
M<FEA<BX`3OAD=F5N9&EG("=H;W-T<W!E8R<@:6MK:F4@<W!E<VEF:7-E<G0@
M:2!K;VYF:6=U<F%S:F]N(&9O<B!I;FYS=&EL;&EN9V%R+@!.^&1V96YD:6<@
M)W!A<W-W;W)D)R!I:VMJ92!S<&5S:69I<V5R="!I(&MO;F9I9W5R87-J;VX@
M9F]R(%9&4RX`3OAD=F5N9&EG("=P87-S=V]R9"<@:6MK:F4@<W!E<VEF:7-E
M<G0@:2!K;VYF:6=U<F%S:F]N(&9O<B!A=71E;G1I<V5R:6YG+@!.^&1V96YD
M:6<@)W!A<W-W;W)D)R!I:VMJ92!S<&5S:69I<V5R="!I(&MO;F9I9W5R87-J
M;VX@9F]R(&MA=&5G;W)I87(N`$[X9'9E;F1I9R`G<&%S<W=O<F0G(&EK:VIE
M('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@:6YN<W1I;&QI;F=A
M<BX`3OAD=F5N9&EG("=P:'!T>7!E)R!I:VMJ92!S<&5S:69I<V5R="!I(&MO
M;F9I9W5R87-J;VX@9F]R(%9&4RX`3OAD=F5N9&EG("=P:'!T>7!E)R!I:VMJ
M92!S<&5S:69I<V5R="!I(&MO;F9I9W5R87-J;VX@9F]R(&%U=&5N=&ES97)I
M;F<N`$[X9'9E;F1I9R`G<&AP='EP92<@:6MK:F4@<W!E<VEF:7-E<G0@:2!K
M;VYF:6=U<F%S:F]N(&9O<B!K871E9V]R:6%R+@!.^&1V96YD:6<@)W!H<'1Y
M<&4G(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@:6YN
M<W1I;&QI;F=A<BX`3OAD=F5N9&EG("=T86)L92<@:6MK:F4@<W!E<VEF:7-E
M<G0@:2!K;VYF:6=U<F%S:F]N(&9O<B!61E,N`$[X9'9E;F1I9R`G=&%B;&4G
M(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@875T96YT
M:7-E<FEN9RX`3OAD=F5N9&EG("=T86)L92<@:6MK:F4@<W!E<VEF:7-E<G0@
M:2!K;VYF:6=U<F%S:F]N(&9O<B!K871E9V]R:6%R+@!.^&1V96YD:6<@)W1A
M8FQE)R!I:VMJ92!S<&5S:69I<V5R="!I(&MO;F9I9W5R87-J;VX@9F]R(&EN
M;G-T:6QL:6YG87(N`$[X9'9E;F1I9R`G=&%B;&5296QA=&EO;G,G(&EK:VIE
M('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@:V%T96=O<FEA<BX`
M3OAD=F5N9&EG("=U:60G(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A
M<VIO;B!F;W(@875T96YT:7-E<FEN9RX`3OAD=F5N9&EG("=U:60G(&EK:VIE
M('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@:6YN<W1I;&QI;F=A
M<BX`3OAD=F5N9&EG("=U<V5R;F%M92<@:6MK:F4@<W!E<VEF:7-E<G0@:2!K
M;VYF:6=U<F%S:F]N(&9O<B!61E,N`$[X9'9E;F1I9R`G=7-E<FYA;64G(&EK
M:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@875T96YT:7-E
M<FEN9RX`3OAD=F5N9&EG("=U<V5R;F%M92<@:6MK:F4@<W!E<VEF:7-E<G0@
M:2!K;VYF:6=U<F%S:F]N(&9O<B!K871E9V]R:6%R+@!.^&1V96YD:6<@)W5S
M97)N86UE)R!I:VMJ92!S<&5S:69I<V5R="!I(&MO;F9I9W5R87-J;VX@9F]R
M(&EN;G-T:6QL:6YG87(N`$YU;&QS=&EL;`!4:6QB86ME('1I;"!A;'1E<FYA
M=&EV`%)O;&QE`$QA9W)E("<E<R<`3&%G<F4@86QT97)N871I=@!696P@=&5I
M:VYA(&1U('1R96YG(&9RY2!B;VMS86YE('5N9&5R+B!$=2!K86X@<^4@:V]P
M:65R92!O9R!L:6UE(&1E:2!I;FX@9G+E('1E:W-T8F]K<V$N`%9E;"!S:VEL
M:F5T96EK;B!F;W(@9&%T;SH`5F5L(&1A=&]F;W)M870Z`%9E;"!T:61S9F]R
M;6%T.@!696P@=&\@<V%M<W9A<F%N9&4@9F5L="X`5F5L(&9A<F=E<VMJ96UA
M+@!696P@^&YS:V$@<W!RY6LZ`%-E;F0@<')O8FQE;7)A<'!O<G0`4V5T(&9A
M<F=E<VMJ96UA+"!S:61E;W!P9G)I<VMI;F<@;V<@86YD<F4@=FES:6YG<V%L
M=&5R;F%T:78N`%9E;"#X;G-K82!S<'+E:RX`2V]R="!S86UA;F1R86<Z`%9I
M<P!(;W!P(&]V97(@=F5D;&EK96AA;&0`3F]K<F4@878@2&]R9&4@<VEN92!K
M;VYF:6=U<F%S:F]N<V9I;&5R(&UA;F=L87(Z`$YO:W)E(&%V(%!A<W-O<F0M
M;6]D=6QE;B!S:6YD92!K;VYF:6=U<F%S:F]N<V9I;&5R(&UA;F=L87(Z`%/X
M<'!E;'!O<W1M;W)D87(`26YN=&%S=&EN9R!A=B!S<&5S:6%L=&5I:VX`4W5K
M<V5S<P!,82!T:6P@)R5S)R!T:6P@<WES=&5M970N`%-L971T82`G)7,G+@!&
M:F5R;F$@)R5S)R!F<N4@<WES=&5M970N`%-O;`!/<'!GY79E<@!+;&%S<V$@
M36%I;G1E;F%N8V4Z.B!V87)T(&EK:VIE(&QA<W1A(&EN;@!+<GEP=&5R:6YG
M<V9U;FMS:F]N86YE(&MR978@96D@<VEK:V5R(&YE='1O<'!K;W!L:6YG+@!&
M86YN(&EK:VIE('!R;V=R86UM970@<V]M(&)R=6MA<W0@=&EL(.4@=FES92!D
M96YN92!T>7!E;B!M96QD:6YG87(@*"5S*2X`4F5G:7-T97)E="!E<B!D97(@
M2&]R9&4M87!P;&EK87-J;VYA<B!F:6YN('5T(&MO<FQE:7,@9&5I('-K86P@
M<VYA:VME(&UE9"!K=F%R86YD<F4N(%-K<FEV(&]P<"!A;&QE(&1E:2!(;W)D
M92UA<'!L:6MA<VIO;F%N92!D=2!H87(@:6YS=&%L;&5R="!H97(N`%!R;V)L
M96T@;65D(.4@;&5G9V4@=&EL("<E<R<@=&EL('-Y<W1E;65T+@!0<F]B;&5M
M('9E9"!F:F5R;FEN9R!A=B`G)7,G(&9RY2!S>7-T96UE="X`1&5N;F4@9FEL
M82!K;VYT<F]L;&5R97(@<W1A;F1A<F1I;FYS=&EL;&EN9V%N92!F;W(@4&%S
M<V]R9"UM;V1U;&5N+"!O9R!K;VYT<F]L;&5R97(@;V=SY2!K=F$@:6YN<W1I
M;&QI;F=A<B!B<G5K87)A;F4@:V%N(&5N9')E+@!$96YN92!F:6QA(&MO;G1R
M;VQL97)E<B!D970@9VQO8F%L92!S971T970@;65D($U)344M:V]P;&EN9V%R
M(&9O<B!R86UM979E<FME="!T:6P@2&]R9&4N($1E='1E(&=J97(@870@87!P
M;&EK87-J;VYA<B!K86X@8G)U:V4@<')O9W)A;2!S;VT@96YS8W)I<'0@96QL
M97(@;7-W;W)D=FEE=R!F;W(@Y2!G:F5R92!O;2!I;FYH86QD('1I;"!(5$U,
M('-O;2!K86X@=FES87-T(&D@96EN(&YE='1L97-A<BX`1&5N;F4@9FEL82!K
M;VYT<F]L;&5R97(@<W1I;&%R:V5T('-O;2!B;&ER(&)R=6MT('1I;"#E(&1E
M9FEN97)E(&9A<F=A<B!O9R!S:W)I9G1T>7!A<B!F;W(@<F%M;65V97)K970@
M=&EL($AO<F1E+"!O9R!T:6P@86QL92!A<'!L:6MA<VIO;F%R('-O;2!I:VMJ
M92!H87(@<VEN92!E:6=N92!D969I;FES:F]N87(N`$1E;FYE(&9I;&$@:V]N
M=')O;&QE<F5R('-T:6QA<FME="!S;VT@8FQI<B!B<G5K="!T:6P@Y2!D969I
M;F5R92!F87)G87(@;V<@<VMR:69T='EP87(L(&]G(&QE9V<@=&EL(&5L;&5R
M(&]V97)S='ER97(@<W1A;F1A<F1V97)D:6%N92!T:6P@2&]R9&4N`$1E;FYE
M(&9I;&$@:V]P;&%R(&9I;&5T=&5R;F%M;B!T:6P@;&]G:7-K92!-24U%+71Y
M<&%R+"!S;&EK(&%T($AO<F1E+6%P<&QI:V%S:F]N87(@:V%N(&9I;FYE('5T
M(&MO<FQE:7,@:6YN:&%L9"!S;VT@92UP;W-T=F5D;&5G9R!E;&QE<B!#5E,M
M=71S:F5K:R!S:V%L(&AA;F1S86UA<W0N`$1E='1E(&5R(&AO=F5D:V]N9FEG
M=7)A<VIO;G-F:6QA(&9O<B!(;W)D92X@1&5N(&EN;F5H96QD(&MA=&%L;V=N
M86UN(&]G(&=R=6YN;&5G9VIA;F1E(&5L96UE;G0@<V]M(&=J96QD(&MJ97)N
M82!A=B!R86UM979E<FME="!O9R!A;&QE($AO<F1E+6%P<&QI:V%S:F]N87(N
M`$1E='1E(&5R(&AO=F5D:V]N9FEG=7)A<VIO;G-F:6QA(&9O<B!087-S;W)D
M+6UO9'5L96XN($1E;B!I;FYE:&5L9"!K871A;&]G;F%M;B!O9R!I;FYS=&EL
M;&EN9V%R(&9O<B!A;&QE('-K<FEP=&$@:2!087-S;W)D+6UO9'5L96XN`$1E
M='1E('1A;&5T(&WE('9E<F4@;6EN<W0@96EN+@!$96YN92!V97)D:65N(&WE
M('9E<F4@96ET('1A;"X`5&ET=&5L`%1Y<&5K;VYF;&EK="X`55),`$MA;B!I
M:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+@!+=6YN92!I:VMJ92!S;&5T=&4@
M)R5S)SH@)7,N`$MA;B!I:VMJ92!R96=I<W1R97)E(&EN;G-T:6QL:6YG87(@
M:2#X:W1A+@!+86X@:6MK:F4@;VUS971J92!D971T92!7;W)D+61O:W5M96YT
M970N`$%N9W)E(&5N9')I;F=A<@!5=F5N=&$@<VQU='0@<.4@9FEL82X`3W!P
M9&%T97(`3W!P9&%T97)T92`G)7,G+@!"<G5K('-T86YD87)D=F5R9&D`0G)U
M:V%R861M:6YI<W1R97)I;F<`0G)U:V%R86QT97)N871I=@!"<G5K87)N86UN
M`$)R=6MA<F%R`$)R=6MA<F%R(&D@<WES=&5M970Z`,5T=F%R:6YG`,5T=F%R
M:6YG(0!+=F%R('9E:V4`5F5L:V]M96X@=&EL("5S`%9E;&MO;65N+"`E<P!!
M9')E<W-E+"!A<F)E:60`5&5L969O;BP@87)B96ED`,7%`,5R;&5G`$IA+"!E
M9R!E<B!S86UD`$1U(&MA;B!I:VMJ92!E;F1R92!P87-S;W)D(&9O<B!B<G5K
M87)E;B`E<P!$=2!E<B!L;V=G82!U="X\8G(@+SY486MK(&9O<B!A="!D=2!B
M<G5K87(@9&5T=&4@<WES=&5M970N`$1U(&WE('-K:6QD<F4@<')O8FQE;65T
M(&;X<B!D=2!K86X@<V5N9&4@<')O8FQE;7)A<'!O<G1E;BX`1'4@;>4@<VMR
M:79E(&EN;B!D:71T(&YY92!P87-S;W)D`$1U(&WE('-K<FEV92!I;FX@9&ET
M="!G86UL92!P87-S;W)D`$1U(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N
M86UN(.4@9FIE<FYE+@!$=2!MY2!S<&5S:69I<V5R92!E:70@8G)U:V%R;F%M
M;B#E(&QE9V=E('1I;"X`1'4@;>4@<W1A9&9E<W1E(&1I='0@;GEE('!A<W-O
M<F0`V&MT82!D:2`H)7,I(&AA<B!GY71T('5T('#E('1I9"X@3&]G9R!I;FX@
M<.4@;GET="X`1&D@92UP;W-T861R97-S93H`1&EN(&EN9F]R;6%S:F]N`$1I
M='0@;F%M;CH`075T96YT:7-E<FEN9W-B86MD96QN`$QI<W1I;F<@878@8G)U
M:V%R87(@97(@:6MK:F4@<W3X='1A(&%V(&)A:W)E(&%U=&5N=&ES97)I;F<L
M(&5L;&5R(&9U;FMS:F]N96X@:&%R(&%V(&5I;B!E;&QE<B!A;FYA;B!G<G5N
M;B!B;&ET="!S;.5T="!A=BX`1&EN92!N>64@<&%S<V]R9"!S86US=F%R=&4@
M:6MK:F4`1&ET="!G86UL92!P87-S;W)D(&5R(&EK:VIE(&MO<G)E:W0`06QT
M97)N871I=F$@9&EN92!H87(@8FQI='0@;W!P9&%T97)T92X`6U!R;V)L96UR
M87!P;W)T70!;;&EN:F4@)7,@878@)7-=`&DQ.&X`=D-A<F0`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE
M+W!L7U!,+P``````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S0T`#`R,#$W,@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!A<W-W9"]L;V-A;&4O<&Q?4$PO3$-?34534T%'15,O````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(Q-S4W`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]P;%]03"],0U]-
M15-304=%4R]P87-S=V0N;6\`````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P,S$S-@`Q,#0Q
M-S,V,C<T-``P,C,V,38`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````WA($E0````!%`@``'````$02```3`P``;"0```````"X
M,```2````+DP```.`````C$```T````1,0``"````!\Q```+````*#$```P`
M```T,0``$0```$$Q```1````4S$```4```!E,0``*````&LQ```(````E#$`
M``H```"=,0``$@```*@Q```3````NS$```X```#/,0``"@```-XQ```-````
MZ3$``!$```#W,0``#0````DR```,````%S(```T````D,@``!@```#(R```;
M````.3(``"T```!5,@``)````(,R```I````J#(``!D```#2,@``#````.PR
M```.````^3(```X````(,P``"````!<S```)````(#,``#(````J,P``.```
M`%TS``!4````EC,``%$```#K,P``6@```#TT``!7````F#0``#0```#P-```
M!0```"4U```1````*S4```@````]-0``$````$8U```/````5S4```,```!G
M-0``"0```&LU```-````=34``!(```"#-0``#P```)8U```*````IC4```\`
M``"Q-0``"````,$U```D````RC4``!0```#O-0``%@````0V```(````&S8`
M`"T````D-@``&0```%(V```'````;#8```P```!T-@``#@```($V```+````
MD#8```<```"<-@``!P```*0V```%````K#8```H```"R-@``#P```+TV```8
M````S38```X```#F-@``%````/4V```7````"C<``!<````B-P``%P```#HW
M```/````4C<``!\```!B-P``!P```((W```&````BC<```\```"1-P``!@``
M`*$W```*````J#<```L```"S-P``$````+\W```5````T#<```<```#F-P``
M!0```.XW```1````]#<```P````&.```"0```!,X```'````'3@``#D````E
M.```"@```%\X```&````:C@```D```!Q.```!P```'LX``!5````@S@``"T`
M``#9.```+0````<Y```M````-3D``"T```!C.0``,P```)$Y```5````Q3D`
M`!D```#;.0``*0```/4Y```D````'SH``!$```!$.@``"@```%8Z```,````
M83H```H```!N.@``$````'DZ```6````BCH``!8```"A.@``!P```+@Z```'
M````P#H```H```#(.@``!P```-,Z```'````VSH```4```#C.@``"````.DZ
M```.````\CH```H````!.P``!P````P[```)````%#L``!8````>.P``!```
M`#4[```&````.CL```@```!!.P```P```$H[```#````3CL```@```!2.P``
M"````%L[```(````9#L``$$```!M.P``(````*\[```&````T#L```8```#7
M.P``%0```-X[```8````]#L``"(````-/```'0```#`\```5````3CP```H`
M``!D/```#P```&\\```/````?SP```D```"//```&````)D\```=````LCP`
M`!,```#0/```$0```.0\```$````]CP```8```#[/```5`````(]```4````
M5ST```X```!L/0``1````'L]```%````P#T```4```#&/0``$0```,P]```1
M````WCT``!P```#P/0``$0````T^```,````'SX``!`````L/@``"````#T^
M```%````1CX```P```!,/@``$````%D^```-````:CX```<```!X/@``#0``
M`(`^```'````CCX```<```"6/@``%````)X^```)````LSX```H```"]/@``
M#````,@^```0````U3X``!4```#F/@``!0```/P^```E`````C\``!(````H
M/P``$P```#L_```K````3S\``#L```![/P``(````+<_```V````V#\``!``
M```/0```!````"!````.````)4```!4````T0```$@```$I````@````74``
M`"D```!^0```!P```*A````&````L$````T```"W0```$````,5````'````
MUD````0```#>0```#````.-````H````\$````8````900``#@```"!!```"
M````+T$```4````R00``!````#A!```.````/4$```@```!,00``#0```%5!
M```0````8T$``!,```!T00``$P```(A!```&````G$$```P```"C00``"P``
M`+!!```-````O$$```H```#*00``&````-5!```'````[D$``!0```#V00``
M"0````M"```6````%4(```\````L0@``#0```#Q"```F````2D(```@```!Q
M0@``"P```'I"```%````AD(```8```",0@``!P```)-"```$````FT(```H`
M``"@0@``#P```*M"```0````NT(``!<```#,0@``$0```.1"```7````]D(`
M`!D````.0P``!0```"A#```%````+D,```T````T0P``&P```$)#```)````
M7D,```X```!H0P``#0```'=#```@````A4,```<```"F0P``!0```*Y#```3
M````M$,```<```#(0P``!P```-!#```(````V$,```8```#A0P``$````.A#
M```/````^4,``!`````)1```#P```!I$```+````*D0```\````V1```#```
M`$9$```/````4T0```X```!C1```(0```')$```?````E$0```,```"T1```
M"````+A$```,````P40```D```#.1```#@```-A$```+````YT0``!L```#S
M1```!P````]%```'````%T4```0````?10``%0```"1%```&````.D4```0`
M``!!10``!P```$9%```"````3D4```T```!110``!@```%]%```)````9D4`
M``<```!P10``!@```'A%```$````?T4```4```"$10``!````(I%```,````
MCT4```H```"<10``!0```*=%```*````K44```\```"X10``$````,A%```&
M````V44``!(```#@10``$````/-%```.````!$8```0````31@``!P```!A&
M```&````($8```4````G1@``!P```"U&```'````-48```4````]1@``!@``
M`$-&```$````2D8```0```!/1@``"@```%1&```%````7T8```0```!E1@``
M!@```&I&```(````<48```X```!Z1@``%@```(E&```1````H$8```8```"R
M1@``!P```+E&```0````P48``!H```#21@``"0```.U&```,````]T8```\`
M```$1P``!@```!1'```'````&T<```L````C1P``1P```"]'```-````=T<`
M``8```"%1P``"@```(Q'```"````ET<```0```":1P```P```)]'```*````
MHT<```0```"N1P``"````+-'```(````O$<```0```#%1P``!0```,I'``!H
M````T$<```4````Y2```!@```#](```/````1D@```,```!62```"@```%I(
M```+````94@```<```!Q2```&@```'E(``!*````E$@```8```#?2```!@``
M`.9(```(````[4@```<```#V2```"P```/Y(```'````"DD```H````220``
M!````!U)```+````(DD```<````N20``!0```#9)```-````/$D```P```!*
M20``"P```%=)```-````8TD```0```!Q20``#````'9)```)````@TD```<`
M``"-20``"@```)5)```$````H$D```8```"E20``!P```*Q)```.````M$D`
M`$D```##20``!0````U*```&````$TH```@````:2@``$0```"-*```.````
M-4H```(```!$2@``!P```$=*```&````3TH```T```!62@``!P```&1*```.
M````;$H```H```![2@``!0```(9*```1````C$H``!$```">2@``"````+!*
M```)````N4H```H```##2@``"````,Y*```&````UTH```@```#>2@``"```
M`.=*```1````\$H``!(````"2P``*@```!5+```)````0$L```H```!*2P``
M%0```%5+```%````:TL``!0```!Q2P``'@```(9+```4````I4L```0```"Z
M2P``!0```+]+```H````Q4L``"D```#N2P``!@```!A,```(````'TP```<`
M```H3```$P```#!,```(````1$P```4```!-3```!0```%-,```>````64P`
M`!0```!X3```#@```(U,```&````G$P```P```"C3```#0```+!,```+````
MODP```H```#*3```"P```-5,```/````X4P```4```#Q3```$0```/=,```8
M````"4T```0````B30``!P```"=-```&````+TT```D````V30```P```$!-
M```*````1$T```P```!/30``!````%Q-```'````84T```D```!I30``#```
M`'--```:````@$T``!<```";30``)P```+--```7````VTT``!L```#S30``
M&0````].```?````*4X``!,```!)3@``!P```%U.```)````94X``#\```!O
M3@``-P```*].``!7````YTX```4````_3P``"@```$5/```$````4$\``"4`
M``!53P``'0```'M/```,````F4\```D```"F3P``"0```+!/```$````ND\`
M`!````"_3P``"````-!/```(````V4\```\```#B3P``!P```/)/```Z````
M^D\```P````U4```!0```$)0```$````2%```!<```!-4```!@```&50```'
M````;%```"8```!T4```*@```)M0```.````QE````8```#54```"P```-Q0
M```&````Z%```!D```#O4```"@````E1```%````%%$```D````:40``"```
M`"11```?````+5$``!<```!-40``<P```&51``!S````V5$```0```!-4@``
M"P```%)2```%````7E(```4```!D4@``"````&I2```-````<U(```<```"!
M4@``!@```(E2```,````D%(```,```"=4@``!````*%2```&````IE(```<`
M``"M4@``(````+52```F````UE(```P```#]4@``#@````I3```-````&5,`
M``<````G4P``"@```"]3```(````.E,``!0```!#4P``"@```%A3```)````
M8U,```@```!M4P``&0```'93```'````D%,```D```"84P```P```*)3```&
M````IE,```<```"M4P``#0```+53```+````PU,``"\```#/4P``,0```/]3
M```_````,50```P```!Q5```"@```'Y4```"````B50```0```",5```!@``
M`)%4```#````F%0```P```"<5```)0```*E4```9````SU0``$4```#I5```
M'P```"]5```?````3U4``"8```!O50``)0```)95```A````O%4``!(```#>
M50``$P```/%5```0````!58``'D````65@``"0```)!6``!R````FE8``',`
M```-5P``%P```(%7```6````F5<```\```"P5P``40```,!7```W````$E@`
M`#8```!*6```'P```(%8```?````H5@``!0```#!6```"@```-98```&````
MX5@```@```#H6```$````/%8```/`````ED```0````260``"P```!=9```'
M````(UD```4````K60``!P```#%9```(````.5D```\```!"60``"````%)9
M```,````6UD```\```!H60``!@```'A9```&````?UD```P```"&60``"```
M`)-9```$````G%D```0```"A60``!````*99```'````JUD```<```"S60``
M!0```+M9```P`0``P5D``$,```#R6@``#@```#9;```1````15L```<```!7
M6P``"````%];```*````:%L``!,```!S6P``$````(=;```%````F%L``"<`
M``">6P``#P```,9;```.````UEL``!````#E6P``%@```/9;```0````#5P`
M``@````>7```$0```"=<```3````.5P```P```!-7```"P```%I<```.````
M9EP```8```!U7```(@```'Q<```O````GUP``!T```#/7```(@```.U<```>
M````$%T```T````O70``$@```#U=```2````4%T```@```!C70``"@```&Q=
M```_````=UT``$@```"W70``7`````!>``!9````75X``&(```"W7@``7P``
M`!I?``!!````>E\```4```"\7P``#@```,)?```.````T5\```X```#@7P``
M$@```.]?```%`````F````P````(8```$````!5@```6````)F```!D````]
M8```#0```%=@```5````96````H```![8```'@```(9@```;````I6```"``
M``#!8```$0```.)@```M````]&```"8````B80``!0```$EA```0````3V$`
M``T```!@80``"@```&YA```'````>6$```@```"!80``!0```(IA```/````
MD&$``!4```"@80``%P```+9A```,````SF$``!<```#;80``%P```/-A```C
M````"V(``!@````O8@``$P```$AB```E````7&(```8```""8@``!@```(EB
M```/````D&(```D```"@8@``"@```*IB```)````M6(```\```"_8@``$```
M`,]B```)````X&(```@```#J8@``$0```/-B```.````!6,```D````48P``
M!P```!YC```]````)F,```@```!D8P``"````&UC```)````=F,```<```"`
M8P``6P```(AC```W````Y&,``#<````<9```-P```%1D```W````C&0``#T`
M``#$9```(0````)E```E````)&4``"\```!*90``,0```'IE```.````K&4`
M``L```"[90``#````,=E```#````U&4```D```#890``%````.)E```?````
M]V4```P````79@``!P```"1F```*````+&8```@````W9@``!@```$!F```%
M````1V8```X```!-9@``$````%QF```)````;68```<```!W9@``"````']F
M```4````B&8```,```"=9@``"````*%F```(````JF8```,```"S9@```P``
M`+=F```)````NV8```@```#%9@``!P```,YF``!/````UF8``"T````F9P``
M!@```%1G```&````6V<``!D```!B9P``'0```'QG```L````FF<``"````#'
M9P``%@```.AG```)````_V<``!,````):```$P```!UH```)````,6@``!H`
M```[:```'P```%9H```5````=F@``!8```",:```!````*-H```%````J&@`
M`$8```"N:```"P```/5H```/`````6D``#,````1:0``!0```$5I```%````
M2VD```L```!1:0``%P```%UI```@````=6D``!8```"6:0``#````*UI```-
M````NFD```@```#(:0``!0```-%I```-````UVD```P```#E:0``#0```/)I
M```'`````&H```<````(:@``"0```!!J```%````&FH``!4````@:@``"0``
M`#9J```'````0&H```X```!(:@``#P```%=J```/````9VH```4```!W:@``
M'0```'UJ```<````FVH``!T```"X:@``+````-9J```[`````VL``"D````_
M:P``/@```&EK```.````J&L```<```"W:P``#0```+]K```@````S6L``!8`
M``#N:P``(@````5L```M````*&P```0```!6;```!@```%ML```+````8FP`
M``L```!N;```"0```'IL```$````A&P```L```");```-P```)5L```$````
MS6P```\```#2;````@```.)L```*````Y6P```0```#P;```#0```/5L```(
M`````VT```X````,;0``$@```!MM```4````+FT``!0```!#;0``!````%AM
M```*````76T```P```!H;0``#````'5M```+````@FT``!@```".;0``!0``
M`*=M```-````K6T```<```"[;0``)@```,-M```2````ZFT```D```#];0``
M+@````=N```(````-FX```L````_;@``"0```$MN```&````56X```<```!<
M;@``!@```&1N```*````:VX``!$```!V;@``$0```(AN```8````FFX``!4`
M``"S;@``&````,EN```:````XFX```4```#];@``!0````-O```+````"6\`
M`"4````5;P``"0```#MO```0````16\``!````!6;P``-@```&=O```'````
MGF\```0```"F;P``%P```*MO```%````PV\```<```#);P``!P```-%O```&
M````V6\``!$```#@;P``$0```/)O```2````!'```!`````7<```%````"AP
M```4````/7````\```!2<```%0```&)P```,````>'```"H```"%<```'```
M`+!P```$````S7````0```#2<```#P```-=P```+````YW````L```#S<```
M#P```/]P```F````#W$```8````V<0``"0```#UQ```(````1W$``!(```!0
M<0``!P```&-Q```"````:W$```8```!N<0```P```'5Q```3````>7$```8`
M``"-<0``"@```)1Q```'````GW$``!````"G<0``!0```+AQ```&````OG$`
M``@```#%<0``#````,YQ```)````VW$```4```#E<0``"P```.MQ```/````
M]W$``!$````'<@``!P```!ER```4````(7(``!$````V<@``#P```$AR```$
M````6'(```@```!=<@``!@```&9R```&````;7(```<```!T<@``!P```'QR
M```'````A'(```8```",<@``!@```)-R```(````FG(```H```"C<@``!0``
M`*YR```&````M'(```8```"[<@``!0```,)R```6````R'(``!L```#?<@``
M&0```/MR```%````%7,```<````;<P``%@```"-S```G````.G,```4```!B
M<P``#@```&AS```9````=W,```<```"1<P``!P```)ES```6````H7,``%<`
M``"X<P``&P```!!T```'````+'0```H````T=````@```#]T```$````0G0`
M``,```!'=```"@```$MT```&````5G0```<```!==```"````&5T```$````
M;G0```4```!S=```6P```'ET```&````U70```@```#<=```#0```.5T```#
M````\W0```H```#W=```#@````)U```)````$74``!\````;=0``6@```#MU
M```&````EG4```8```"==0``"````*1U```*````K74```T```"X=0``!@``
M`,9U```%````S74```@```#3=0``"````-QU```$````Y74```4```#J=0``
M#@```/!U```.````_W4```T````.=@``"@```!QV```*````)W8```X````R
M=@``"0```$%V```'````2W8```H```!3=@``!0```%YV```(````9'8```P`
M``!M=@``#@```'IV``!`````B78```4```#*=@``!0```-!V```(````UG8`
M``T```#?=@``#@```.UV```"````_'8```L```#_=@``!0````MW```+````
M$7<```4````==P``"````"-W```+````+'<```0````X=P``#P```#UW```0
M````37<```<```!>=P``"P```&9W```,````<G<```@```!_=P``!@```(AW
M```(````CW<```4```"8=P``$````)YW```3````KW<``#$```##=P``!@``
M`/5W```'````_'<``!,````$>```!0```!AX```0````'G@``!H````O>```
M$P```$IX```$````7G@```<```!C>```%@```&MX```F````@G@```8```"I
M>```"@```+!X```'````NW@```T```##>```#@```-%X```%````X'@```D`
M``#F>```(0```/!X```6````$GD```X````I>0``!````#AY```)````/7D`
M``P```!'>0``"0```%1Y```$````7GD``!````!C>0``%@```'1Y```'````
MBWD```\```"3>0``&0```*-Y```*````O7D```<```#(>0``!@```-!Y```+
M````UWD```,```#C>0``#````.=Y```0````]'D```8````%>@``"0````QZ
M```+````%GH```P````B>@``&P```"]Z```4````2WH``!P```!@>@``%0``
M`'UZ```:````DWH``!@```"N>@``'P```,=Z```9````YWH```<````!>P``
M"`````E[```^````$GL``#4```!1>P``5@```(=[```,````WGL```@```#K
M>P``!0```/1[```S````^GL``!<````N?```#````$9\```&````4WP```@`
M``!:?```"````&-\```8````;'P```@```"%?```"````(Y\```.````EWP`
M``<```"F?```+````*Y\```1````VWP```D```#M?```!````/=\```9````
M_'P```8````6?0``"@```!U]```@````*'T``"````!)?0``%````&I]```'
M````?WT```H```"'?0``!@```))]```&````F7T```L```"@?0``!P```*Q]
M```+````M'T```D```#`?0``)````,I]```6````[WT``"P````&?@``>```
M`#-^```$````K'X```P```"Q?@``!0```+Y^```$````Q'X```4```#)?@``
M$````,]^```'````X'X```8```#H?@``#````.]^```#````_'X```0`````
M?P``!@````5_```'````#'\``"D````4?P``+0```#Y_```-````;'\```\`
M``!Z?P```P```(I_```'````CG\``!(```"6?P``$0```*E_```7````NW\`
M``H```#3?P``"0```-Y_```'````Z'\``!````#P?P``"P````&````-````
M#8````,````;@```"@```!^````&````*H````L````Q@```"@```#V````S
M````2(```#<```!\@```3P```+2````.````!($```T````3@0```@```"&!
M```$````)($```8````I@0```P```#"!```0````-($``"D```!%@0``$```
M`&^!```G````@($``!<```"H@0``&````,"!```S````V8$``#(````-@@``
M'@```$""```1````7X(```X```!Q@@``$````(""``"!````D8(```H````3
M@P``70```!Z#``!>````?(,``!P```#;@P``$P```/B#```<````#(0``$L`
M```IA```1@```'6$```V````O(0``"4```#SA```)````!F%```5````/H4`
M``H```!4A0``!@```%^%```(````9H4``!0```!OA0``#@```(2%```$````
MDX4```P```"8A0``!@```*6%```&````K(4```@```"SA0``"````+R%```-
M````Q84```8```#3A0``#````-J%```,````YX4```T```#TA0``#`````*&
M```0````#X8```D````@A@``"````"J&```$````,X8```@````XA@``"0``
M`$&&```,````2X8```4```!8A@```0```.T!```-`````````"P"``#K````
M@0$``%$```````````````L`````````(P$``(@!```W````70$``,,!```"
M````*P(``%8`````````^0$``)(```"5````1@```)P!````````Q`$`````
M````````LP$``.0!``":``````````````#4`````````$,"````````````
M`/0```#Z````N`````````!'`````````)P```#2``````````````"+`0``
M;0````````!!`````````.8```""`0```````)D``````````@$```````#E
M`0``$0(``&D!``"A````W````/<!```P````````````````````E0$`````
M``"=````<P$``#$`````````/`````````"Y````7@$``!X"``#F`0``5`$`
M``````#+````5````&T!``#G`0``>@$``+`!```7`@``EP```$0"```3`0``
M`````)X!``!"````$@```$D````$`0```````!\"```J`0``L0$```````!!
M`@``I@$````````<`@````````````#9``````````````"-`````````(8`
M```K````[P```#0```!Y`0``````````````````!0(`````````````````
M``````"3`````````%4!```Y`@```````'T`````````U@```#4```"8````
M<`$``!\!```A````1````,8```!E`0```````#<"``#V`0``FP```/4````(
M````?P```,4!``#?````@P$```````````````````````"I````8P$``+8`
M``"C````D0```!`!``".`0``/`(``*4!``#;`0``R`$``#8"````````=```
M`#L"``#L````:P$``*L```!D````.`$``&(````M````2@```(T!````````
M`````,D!``#B````[P$``-@!``!U`0``O``````````]````^@$``!8```#A
M`0``\`$````````H`@``B````-4```!``0```````$X!``#_`0``&````#L!
M````````O0```"D"`````````````-4!````````.@$``"X"``!#`0``````
M``````!:`0```````"L!``#'`0``Z0````````#;`````````&8`````````
M)P(````````4````(`````@"``#\`0``C`$````````N`````````,0````V
M````V@$``$0!``"M`0``/0(``````````````````!<```"T`0``7`$``"0`
M```'`@```````!H````J````)@(``(4```!*`0``UP```!8!``#^````#@$`
M`&H````)````?0$``"P```!R````X`$``"X!``!O`0``L@```+@!```\`0``
MH``````````$````T`$``(\!```H````E@$```$"``!\````;@$```T"````
M````"@$``*@```"D`````````'L`````````&@(``,@````C````>`$```P`
M```U`0``30```(H!``#?`0``&`$``-@`````````H`$``!0"```+`@``````
M````````````8`$``/T````O`@``0@(`````````````5@$```````"8`0``
MT0$````````F`0``M````#D```#6`0``5P$```8```#]`0``IP```'(!``!I
M````MP$``&4`````````,@(``'$!`````````````'X```#-`0``R@```.0`
M```J`@```````/0!````````+P$```````#^`0`````````````H`0``X0``
M``````"2`0```````$@!``!N````#0$``'X!``!,````.`(``.H!```S````
M@````+D!````````S````$4!``#E`````````,H!``!0`0``O0$```8"````
M````/P````P!```_`0```````%L!```8`@``SP```,X!````````4@$``"`!
M````````G@```"\````;`@``]@```"T"``!"`0``I`$``%<`````````````
M`)``````````=`$``*D!```5`@``,@```/\`````````80$```````!W````
M*0````````"A`0`````````````#`@``C@```/D`````````^P```,4`````
M````T@$``"0"``"F``````````````"E````K````($``````@``XP```,(!
M```Y`0``9P$``!`"``"U`0``$0$```````"4`0``T````/@```#<`0``````
M`-$```!Y````\P```"<```"'````V0$``$T!``"[`0``+0$```4!``";`0``
M2P$``!P!``!``````````!<!````````)`$``/$```!X````Q@$``(8!``"4
M````"`$``(`!``#>``````````````!0````>@```#`!```/`@``&0(``&@`
M``"Z`0``!P$```````#"````.@(``%@!``"O`0``4@````H"```@`@``(@$`
M`!D````>`0```````)D!`````0``#P$``$8!``!:````)@```%$!``"6````
MA````$D!````````````````````````8@$``,$!``#B`0``$P```+H`````
M````"@````0"``#Q`0``S0```',`````````;````.``````````Z````$X`
M```Z````F@$`````````````HP$``*L!````````(@(``'4````V`0``KP``
M`)$!``!C````,P(``*H!````````10```/(```#N````S`$````````Q`@``
M`````%T`````````4P```#0"````````>P$```````!9````Z@```$L```"Q
M````;P```!T```"_`0```````"4!``!G````3`$``,\!``#H`0``&P```'P!
M``!J`0``A0$```$!``#7`0```@(`````````````````````````````80``
M`$4"```;`0``H@$``#\"```Q`0``B0```!H!``"N````G0$``'8````E`@``
M``````````!?````O@$``,``````````(0(``%X`````````EP$``(,````1
M````ZP$``#L```#[`0```````"D!``!F`0``<0```$\```#N`0``L@$`````
M````````/@(```````#3````V@````````"$`0``=P$``#X`````````````
M`!4```"G`0``W0```!4!`````````````$@```#>`0`````````````R`0``
M#P`````````2`0``%@(``*T`````````(0$```````"P````(@````````"?
M`0```````*(`````````9`$``%\!````````'P```$<!```0````````````
M```+`0``LP```!,"``!/`0```````+4```")`0``O@```*@!```&`0``P`$`
M``D!```S`0``GP`````````G`0````````D"``!!`0``````````````````
M6P```/@!`````````````/P```#!````R0```#4"````````;`$```````#M
M````QP```!0!`````````````#T!``#L`0``6````!("``"'`0``````````
M```#````NP```"4```!<````U`$``/,!``#3`0``60$``#@```#R`0``@@``
M`!T"````````:`$``&```````````````!D!````````J@```!P````=`0``
M]0$``+P!``!#````YP````X```!``@``````````````````+`$``/<```#I
M`0``'@````````"3`0```````#X!``"V`0```````(P`````````=@$``,X`
M```P`@``:P````<`````````<````(L`````````PP```(\```!5````?P$`
M`%,!``"_`````````#<!````````K`$``/```````````````-T!``"0`0``
MXP$``#0!```.`@``#`(``","````````!0```*X!````````B@``````````
M``````````,!``#+`0``MP`````@)B,Q-3$[("5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX`("@E<R!D87ES(&%G;RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O
M;6]R<F]W*0`@*'EE<W1E<F1A>2D`)60@8GET97,@=W)I='1E;BX`)7,@061M
M:6YI<W1R871I;VX`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(&%L<F5A9'D@
M97AI<W1S+@`E<R!I<R!N;W0@=W)I=&%B;&4N`"5S(&ES(')E<75I<F5D`"5S
M(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R=S($%D9')E<W,@0F]O:P`E<R=S
M($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`G
M)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC92X`)R5S)R!I<R!N;W0@8V]N9FEG
M=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"<E<R<@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E871E9#H@)7,N`"TM
M('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H
M;W5R<P`\4')E=FEO=7,`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE
M;BX`061D`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES
M<VEO;@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E
M<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O
M;VL`061D('5S97(`061D960@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S
M<P!!9&1R97-S($)O;VL`061M:6YI<W1R871I;VX`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;')E861Y(&5X:7-T<P!!;'1E
M<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E
M<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!
M;'1E<FYA=&4@=&5X=#H`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D
M+@!!;F1O<G)A`$%N9V]L80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R
M8W1I8V$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO
M;B!I<R!R96%D>2X`07!P<F]V90!!<')I;`!!<F-H:79E($9I;&4@4VEZ90!!
M<F-H:79E($YA;64`07)G96YT:6YA`$%R;65N:6$`07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T
M=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T
M:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!
M=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I
M96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K
M9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E
M<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%N9VQA9&5S:`!"96QA
M<G5S`$)E;&=I=6T`0F5N:6X`0FER=&AD87D`0FQO8VL@4V5T=&EN9W,`0FQO
M8VL@5'EP90!";VQI=FEA`$)O;VMM87)K<P!";W-N:6$@86YD($AE<GIE9V]V
M:6YA`$)O=&@`0G)A>FEL`$)U;&=A<FEA`$--4P!#4D,`0V%L96YD87(`0V%M
M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N
M;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4&AO
M;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<')O<&5R=&EE<P!#96QL<&AO;F4`
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N
M97(`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B!E;6%I;',N`$-H86YG92!Y;W5R('!A<W-W;W)D`$-H96-?:R!,:6YK+BXN
M`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H;V]S92!A
M('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES
M<&QA>2!D871E<SH`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-O
M;&QA<'-E(%-I9&5B87(`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O
M;&]U<B!S96QE8W1I;VX`0V]L=6UN('1I=&QE<P!#;VUM86YD`$-O;6UA;F0@
M4VAE;&P`0V]M;65N=`!#;VUP86YY`$-O;7!O<V4@365S<V%G92`H)7,I`$-O
M;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W
M;W)D`$-O;F9I<FT@;F5W('!A<W-W;W)D.@!#;VYG;P!#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G1S(&]F("<E
M<R<`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@;6MD:7(@)R5S)RX`
M0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R
M:71I;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-O=6YT<GD`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W
M(&]N90!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0WEP<G5S`$-Z96-H(%)E<'5B
M;&EC`$1$`$1A:6QY`$1A=&4`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5F
M875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO
M;G,`1&5F875L="!P97)M:7-S:6]N<P!$96QE=&4`1&5L971E($=R;W5P`$1E
M;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(')O=P!$96QE=&4@<V5L
M96-T960@:61E;G1I='D`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$
M:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO
M;G,`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<`!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$<G5G<P!%+4UA:6P`
M16-U861O<@!%9&ET`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@
M4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I
M;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!P97)M:7-S
M:6]N<R!F;W(@)R5S)P!%9WEP=`!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6]T:6-O;G,`16UP='D@;65S<V%G
M92X`16UP='D@<F5S=6QT+@!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%<FET<F5A`$5R<F]R`$5R<F]R('=R:71I;F<@)R5S)RX`17)R;W(Z
M(`!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>'!A;F0@4VED96)A<@!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R
M9"`Z(`!&87@`1F5B<G5A<GD`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9O;V0`1F]R9V]T('EO=7(@<&%S<W=O
M<F0_`$9R86YC90!&<F]M`$=E<FUA;GD`1V\`1V]O9VQE(%-E87)C:`!'<F5E
M8V4`1W)E96YL86YD`$=R96YA9&$`1W)O=7!S`$AE;'``2&]?;64`2&]M90!(
M;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)8V]N<R!/;FQY`$EC;VYS
M('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EM86=E<P!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);G1E<FYA;"!%<G)O<@!)<F%Q
M`$ER96QA;F0`27-R865L`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*
M;W)D86X`2G5L>0!*=6YE`$MA>F%K:'-T86X`2V5N>6$`2VED<P!+=7=A:70`
M3&%N9W5A9V4`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&EB97)I80!,:7-T($AE;'`@
M5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&AU86YI80!,
M;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO9R!I;@!,;V<@;W5T`$QO
M9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A
M:6QE9"X`3&]G;W5T`$QU>&5M8F]U<F<`34T`34]41`!-4T<`36%D86=A<V-A
M<@!-86EL`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RX`36%R8V@`36%R9VEN`$UA=&-H:6YG(&9I96QD<P!-87D`365N=2!M
M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE>&EC;P!-
M;VYA8V\`36]N9V]L:6$`36]N=&AL>0!-;V]N(%!H87-E<P!-;W)O8V-O`$UY
M($%C8V]U;G0`3F%M90!.971H97)L86YD<P!.971W;W)K`$YE=F5R`$YE=R!#
M86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!:96%L86YD`$YE=R!P87-S=V]R
M9#H`3F5W<P!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R:6$`3F\@8VAA
M;F=E+@!.;VYE`$YO<G=A>0!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&4Z
M(%EO=2!W:6QL(&YE960@=&\@;&]G;W5T(&%N9"!B86-K(&EN(&%F=&5R('EO
M=2!C:&%N9V4@>6]U<B!P87-S=V]R9"$`3F]T97,`3F]T:6-E`$YO=F5M8F5R
M`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$]+`$]C=&]B97(`
M3V9F:6-E`$]L9"!P87-S=V]R9#H`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F=A;FEZ:6YG`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI
M<W-I;VYS`%!(4"!#;V1E`%!(4"!3:&5L;`!07TA0(%-H96QL`%!A:VES=&%N
M`%!A;F%M80!087)A9W5A>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D(0!0
M87-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P
M97)L>2!C;VYF:6=U<F5D`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D
M<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R<V]N86P@26YF;W)M871I
M;VX`4&5R=0!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!O;&%N9`!0;W)T=6=A;`!0<F]B;&5M`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4')O8FQE;3\`46%T87(`475E<GD`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;6]T92!397)V
M97)S`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@
M<&%I<@!296UO=F4@=&AE`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!2
M97-E=`!2971U<FX@=&\@3W!T:6]N<P!2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,`4F]L90!2;VUA;FEA`%)W86YD80!344P@4VAE;&P`4U-(`%-?44P@4VAE
M;&P`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/
M<'1I;VYS`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N96=A;`!397!T96UB97(`4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T
M:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H
M96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO
M;G,N`%-E='5P`%-E>6-H96QL97,`4VAO=P!3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-I97)R82!,96]N90!3:6=N871U<F4`4VEN9V%P;W)E`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;VQO;6]N($ES;&%N
M9',`4V]M86QI80!3;VUE(&]F(%!A<W-W;W)D(&UO9'5L92=S(&-O;F9I9W5R
M871I;VX@9FEL97,@87)E(&UI<W-I;F<Z`%-O=71H($%F<FEC80!3<&%I;@!3
M<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8FUI=`!3=6-C97-S`%-U
M8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3=6YR:7-E+U-U
M;G-E=`!3=V5D96X`4W=I='IE<FQA;F0`5&%I=V%N`%1A:7=A;BP@4')O=FEN
M8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!487-K<P!497AT($]N;'D`5&AA:6QA
M;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&ES(&9I96QD
M(&ES(')E<75I<F5D+@!4:&ES(&9I;&4@8V]N=')O;',@=&AE('-T>6QE<VAE
M970@=&AA="!I<R!U<V5D('1O('-E="!C;VQO<G,@86YD(&9O;G1S(&EN(&%D
M9&ET:6]N('1O(&]R(&]V97)R:61I;F<@2&]R9&4@9&5F875L=',N`%1H:7,@
M:7,@=&AE(&UA:6X@4&%S<W=O<F0@;6]D=6QE(&-O;F9I9W5R871I;VX@9FEL
M92X@270@8V]N=&%I;G,@<&%T:',@86YD(&]P=&EO;G,@9F]R(&%L;"!087-S
M=V]R9"!M;V1U;&4@<V-R:7!T<RX`5&EM90!4:6UE(&9O<FUA=`!4:71L90!4
M;V1A>0!4;VUO<G)O=P!4<G5E(&]R(&9A;'-E`%1U;FES:6$`5'5R:V5Y`%1U
M<FMM96YI<W1A;@!54DP`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5<G5G=6%Y`%5S97(@;F%M93H`57-E<FYA;64`57-E
M<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!696YE>G5E;&$`5FEE="!.
M86T`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!787)N:6YG`%=A<FYI;F<Z
M(`!796(`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E
M<P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO
M9VEN/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!960!965E9`%EE87)L>0!997,`665S+"!)($%G<F5E`%EO=2!C
M86XG="!C:&%N9V4@<&%S<W=O<F0@9F]R('5S97(@)7,`66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9`!9;W4@;75S="!G:79E('EO=7(@
M;VQD('!A<W-W;W)D`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%EO=7(@16UA:6P@
M061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT
M:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O
M(&QO;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R
M86-T97)S(&QO;F<A`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@
M=&\@9W5E<W,A("!.;W0@8VAA;F=E9"$`66]U<B!N97<@<&%S<W=O<F0@;75S
M="!B92!A="!L96%S="`E9"!C:&%R86-T97)S(&QO;F<A`%EO=7(@;F5W('!A
M<W-W;W)D<R!D:61N)W0@;6%T8V@`66]U<B!O;&0@<&%S<W=O<F0@:7-N)W0@
M8V]R<F5C=`!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA;6)I
M80!::6UB86)W90!;4')O8FQE;2!297!O<G1=`%]!9&UI;FES=')A=&EO;@!?
M0TQ)`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TQO9R!I;@!?3&]G(&]U
M=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO
M=F4@3&EN:RXN+@!?4V5T=7``7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A
M<@!D;VYE`&9I;&4`;F%M90!U;FYA;65D`'5P9&%T960`=D-A<F0`4')O:F5C
M="U)9"U697)S:6]N.B!P87-S=V0*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#(M
M,#@M,CD@,34Z-3`K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`R+3$Y
M(#$P.C(S+3`V,#`*3&%S="U4<F%N<VQA=&]R.B!-87)I=7-Z(%IY;F5L(#QM
M87)I=7-Z0'-O;&%R:7,M>#@V+F]R9SX*3&%N9W5A9V4M5&5A;3H@4&]L:7-H
M(#QD979`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,@I#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`E<R`M(&=O=&]W>2!D;R!W
M>6MO;F%N:6$@8WEK;&EC>FYY8V@@;W!E<F%C:FD@>F%Z;F%C>F]N>6-H('!O
M;FF_96HN`"`H)7,@9&YI('1E;74I`"`H=R!C:;%G=2`E<R!D;FDI`"`H9'II
MMBD`("AJ=71R;RD`("AW8WIO<F%J*0!Z87!I<V%N;R`E9"!B86IT\W<N`$%D
M;6EN:7-T<F%C:F$@)7,`)7,@:T(`)7,@+2!C>6ML:6-Z;F4@;W!E<F%C:F4@
M+2!P;W1W:65R9'IE;FEE`$MO;F9I9W5R86-J82`E<P!296IE<W1R86-J82`E
M<P`E<R!J=;\@:7-T;FEE:F4N`"5S(&YI92!M82!P<F%W('IA<&ES=2X`)7,@
M:F5S="!W>6UA9V%N>0`E<R!M:6YU=``E<R!N:65Z;F%L97II;VYY+@!+<VFQ
MOVMA(&%D<F5S;W=A("5S`$MA;&5N9&%R>B`E<P!.;W1A=&YI:R`E<P!,:7-T
M82!Z861A\2`E<P`E<SH@)7,`)R5S)R!N:64@:F5S="!P<F%W:62S;W=Y;2!W
M>6)O<F5M+@`G)7,G(&YI92!J97-T('-K;VYF:6=U<F]W86YY('<@<F5J97-T
M<GIE($AO<F1E+@!59&&S;R!S:>H@9&]D8>8@)R5S)R!D;R!G<G5P+@!59&&S
M;R!S:>H@9&]D8>8@)R5S)R!D;R!U<')A=VYI9?$N`"<E<R<@;FEE('IO<W1A
MLR!S='=O<GIO;GDZ("5S+@`M+2!W>6)I97)Z("TM`#$R+6=O9'II;FYY(&9O
M<FUA=``R-"UG;V1Z:6YN>2!F;W)M870`,C0@9V]D>BX`/%!O<')Z961N:0!0
M;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4$=0(&1O('IA<WIY9G)O
M=V%N:6$@=VEA9&]M;[9C:2X`4&]T<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC
M>FYY(%!'4"!D;R!S<')A=V1Z96YI82!P;V1P:7-A;F5J('=I861O;6^V8VDN
M`%!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW
M871N>2!01U`@;W)A>B!H87.S;R!D;R!O9'-Z>69R;W=A;FEA('=I861O;6^V
M8VDN`%!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P
M<GEW871N>2!01U`@;W)A>B!H87.S;R!D;R!P;V1P:7-A;FEA('=I861O;6^V
M8VDN`%!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C
M>B!P<GEW871N>2!3+TU)344@;W)A>B!H87.S;R!D;R!O9'-Z>69R;W=A;FEA
M('=I861O;6^V8VDN`%!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-
M24U%+"!K;'5C>B!P<GEW871N>2!3+TU)344@;W)A>B!H87.S;R!D;R!P;V1P
M:7-A;FEA('=I861O;6^V8VDN`%!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI
M8WIN>2!334E-12!D;R!Z87-Z>69R;W=A;FEA('=I861O;6^V8VDN`$%-+U!-
M`$\@='EM(&5D>71O<GIE`$\@<')O9W)A;6EE+BXN`$AA<[-O(&1O(&MO;G1A
M`$MO;G1O('IA8FQO:V]W86YE+@!$;V1A:@!$;V1A:B!T=71A:CH`1&]D86H@
M;F]WL2!G<G5PZ@!$;V1A:B!N;W=E('5P<F%W;FEE;FEE`$1O9&%J(&YO=V5G
M;R!UOWET:V]W;FEK83H`1&]D86H@:V]L=6UNZ@!$;V1A:B!N;W=Y8V@@8WJS
M;VYK\W<`1&]D86H@<&%RZ@!$;V1A:B!M96YU("5S(&1O('!A<VMA($UO>FEL
M;&D`1&]D86H@9&\@:W-IL;]K:2!A9')E<V]W96HZ`$1O9&%J(&1O(&UO:F5J
M(&MS:;%Z:VD@861R97-O=V5J`$1O9&%J('6_>71K;W=N:6MA`$1O9&%N;R`G
M)7,G(&1O('-Y<W1E;74N($UOOV5S>B!S:>H@>F%L;V=O=V'F+@!$;V1A=V%N
M:64@=;]Y=&MO=VYI:_-W(&IE<W0@=WFS86-Z;VYE+@!!9')E<P!+<VFQOVMA
M(&%D<F5S;W=A`$%D;6EN:7-T<F%C:F$`069G86YI<W1A;@!!;&)A;FEA`$%L
M9VEE<FEA`$%L:6%S`%=S>GES=&MI92!G<G5P>0!7<WIY<W1K:64@=7!R87=N
M:65N:6$`4&]Z=_-L(&YA('=I96QE(&%D<F5S\W<`2G6_(&ES=&YI96IE`$%L
M=&5R;F%T>7=N>2!L;V=I;B!)35-0`$%L=&5R;F%T>7=N>2!H87.S;R!)35-0
M`$%L=&5R;F%T>7=N82!N87IW82!UOWET:V]W;FEK82!)35-0`$%L=&5R;F%T
M>7=N>2!A9')E<R!E;6%I;`!!;'1E<FYA='EW;GD@=&5K<W0Z`%IO<W1ALV$@
M<&]D86YA(&YI97!R87=I9+-O=V$@=V%R=&^VYBX`06YD;W)A`$%N9V]L80!!
M;F]N:6UO=V4@4')O>'D`3V1P;W=I962\`$%N=&%R:W1Y9&$`07!L:6MA8VIA
M`$QI<W1A(&%P;&EK86-J:0!!<&QI:V%C:F$@9V]T;W=A`%IA='=I97)DO`!+
M=VEE8VEE\0!7:65L:V^VYB!A<F-H:7=U;0!.87IW82!A<F-H:7=U;0!!<F=E
M;G1Y;F$`07)M96YI80!0;W!R;[8@;R!P;W1W:65R9'IE;FEE('!R>F5D('=Y
M:V]N86YI96T@;W!E<F%C:FD@8WEK;&EC>FYY8V@_`$%T<GEB=71Y`%-I97)P
M:67Q`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?9G1P.B!.:64@>FYA;&5Z:6]N
M;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!&5%`N(%-K;VUP:6QU:B!02%`@
M>B!P87)A;65T<F5M("TM96YA8FQE("X`075T:%]I;6%P.B!.:64@>FYA;&5Z
M:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!)34%0+@!!=71H7VMR8C4Z
M($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&MR8C4N
M`$%U=&A?;&1A<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R
M>F5N:6$@3$1!4"X`075T:%]M8V%L.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N
M96=O(')O>G-Z97)Z96YI82!-0T%,+@!!=71H7W-M8F%U=&@Z($YI92!Z;F%L
M97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA('-M8F%U=&@N`%5W:65R
M>GET96QN:65N:64@;FEE('!O=VEO9+-O('-IZ@!5=VEE<GIY=&5L;FEE;FEE
M(&YI92!P;W=I;V2S;R!S:>HN("5S`%5W:65R>GET96QN:65N:64@;V1R>G5C
M;VYE('!R>F5Z('-E<G=E<B!2041)55,N`%5W:65R>GET96QN:65N:64@9&\@
M<V5R=V5R82!&5%`@;FEE('!O=VEO9+-O('-IZBX`1&]S=.IP;F4@<&]L83H`
M07IE<F)E:F2_86X`5WEM\W=K:2!"3T9(`%2S;P!+;VQO<B!TLV$`6K-E(&AA
M<[-O($ME<F)E<F]S82X`6K-A(&YA>G=A('6_>71K;W=N:6MA($ME<F)E<F]S
M80!7>7-P>2!"86AA;6$`0F%H<F%J;@!"86YG;&%D97-Z`$)I8;-O<G6V`$)E
M;&=I80!"96YI;@!$871A('5R;V1Z96YI80!5<W1A=VEE;FEA(&)L;VMU`%1Y
M<"!B;&]K=0!";VQI=VEA`%IA:[-A9&MI`$)OMFYI82!I($AE<F-E9V]W:6YA
M`$]B80!"<F%Z>6QI80!"=;-G87)I80!#35,`0U)#`$MA;&5N9&%R>@!+86UB
M;V2_80!+86UE<G5N`$YI92!U9&&S;R!S:>H@>G)E<V5T;W=AYB!H87.S82!A
M=71O;6%T>6-Z;FEE+"!S:V]N=&%K='5J('-IZB!Z(&%D;6EN:7-T<F%T;W)E
M;2X`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($E-05`Z
M("5S`$MA;F%D80!!;G5L=6H`06YU;'5J(')A<&]R="!O('!R;V)L96UI90!.
M:64@;6^_;F$@<VMA<V]W8>8@<&QI:W4@(B5S(@!.:64@=61ALV\@<VGJ('IN
M86QEO.8@:V%T86QO9W4@='EM8WIA<V]W96=O+@!.:64@;6^_;F$@<VMA<V]W
M8>8@:V%T86QO9W4@(B5S(@!+871E9V]R:64@:2!O>FYA8WIE;FEA`%1E;"X@
M:V]M+@!7LV&V8VEW;[9C:2!K;VWS<FMI`%>S8;9C:7=OMF-I(&MO;?-R:VD`
M5&5L+B!K;VTN`%)E<'5B;&EK82"F<F]D:V]W96H@069R>6MI`*9R;V1K;W=O
M975R;W!E:G-K:2`H25-/+3@X-3DM,BD`4WIC>F5G\[-Y(&-E<G1Y9FEK871U
M`%>S8;9C:6-I96P@8V5R='EF:6MA='4`0WIA9`!:;6EE\0!:;6EE\2!I;6GJ
M+"!N87IW:7-K;R!I(&%D<F5S+"!K=/-R>2!I;FYI('=I9'JQ('<@5'=O:6-H
M(&QI<W1A8V@@96UA:6PN`%IM:67Q(&AA<[-O`%-P<F%W9+P@;&EN:RXN+@!:
M87IN86-Z('!O>GEC:NH@9&QA(&MT\W)E:B!C:&-E<WH@=WEK;VYAYB!O<&5R
M86-JZBX`0VAI;&4`0VAI;GD`4&]D86H@:&%SLV\`4&]D86H@;F%Z=^H@=;]Y
M=&MO=VYI:V$`5WEB:65R>B!S<&]S\V(@=WFV=VEE=&QA;FEA(&1A=#H`2VQI
M:VYI:B!B>2!K;VYT>6YU;W=AY@!:86UK;FEJ(&]K;F\`4V-H;W=A:B!P87-E
M:P!+;VQU;6)I80!+;VQO<@!7>6)I97)Z(&MO;&]R`%=Y8O-R(&MO;&]R=0!4
M>71ULWD@:V]L=6UN`$MO;65N9&$`4&]WLV]K80!+;VUE;G1A<GH`1FER;6$`
M4W1W\W)Z('=I861O;6^VYB`H)7,I`$MO;7!U=&5R>0!787)U;FMI`%-K;VYF
M:6=U<G5J("5S`%!O='=I97)DO"!H87.S;P!0;W1W:65R9+P@:&%SLV\`2V]N
M9V\`1&5M;VMR871Y8WIN82!297!U8FQI:V$@2V]N9V\`4&^SL6-Z96YI92!N
M:64@<&]W:6]DLV\@<VGJ+@!0;[.Q8WIE;FEE(&YI92!P;W=I;V2S;R!S:>HZ
M(`!/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L:6-Z;F5G;R!S97)W97)A
M+@!/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L:6-Z;F5G;R!S97)W97)A
M+B!0;W?S9#H@)7,@*"5S*0!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@1E10+@!+;VYT86MT>2!Z;W-T8;-Y('!O;7FV;&YI92!D;V1A
M;F4@9&\@5'=O:F5J(&MS:;&_:VD@861R97-O=V5J+@!:87=A<G1OMN8@)R5S
M)P!3:V]P:75J`%-K;W!I=6H@=WEB\W(`3FEE(&UOOVYA('5T=V]R>GGF(&MA
M=&%L;V=U("<E<R<`3FEE(&UOOVYA(&]T=V]R>GGF("5S+@!.:64@;6^_;F$@
M;W1W;W)Z>>8@)R5S)R!D;R!Z87!I<W4N`$YI92!M;[]N82!O='=O<GIYYB!M
M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<P!+<F%J`%-T=_-R>@!3='?S<GH@
M;&EN:P!3='?S<GH@;F]WL0!#:&]R=V%C:F$`2W5B80!/8F5C;GD@8WIA<P!3
M<&5R<V]N86QI>G5J('IA9&%N:6$@=7)U8VAA;6EA;F4@<')Z>2!L;V=O=V%N
M:74@9&\@)7,N`$-Y<'(`4F5P=6)L:6MA($-Z96-H`$1$`$-O9'II96YN:64`
M1&%T80!?57-U\2!K;VQU;6[J`$=R=61Z:67Q`$1O;7FV;&YY(&MO;&]R`$1O
M;7FV;&YA('1OOW-A;6^VY@!$;VUYMFQN92!U<')A=VYI96YI80!$;VUYMFQN
M92!U<')A=VYI96YI80!5<W7Q`%5S=?$@1W)U<.H`57-U\2!K;VWS<FOJ`%5S
M=?$@:V]L=6UNZ@!5<W7Q('=I97)S>@!3:V%S=6H@=WEB<F%NL2!T;[]S86UO
MMN8`1&%N:6$`3W!I<WH@<')O8FQE;0!+871A;&]G`%=YMG=I971L(&-Z87,@
M=R!F;W)M86-I92`R-"UG;V1Z:6YN>6T_`%5S=&%W:65N:6$@=WEG;+%D=0!.
M:64@:V%S=6H`0G)A:R!B97IP;[9R961N:65G;R!D;W-TZG!U(&1O(&UA:6YT
M96YA;F-E+G!H<`"F8VFQ9VYI:@"F8VFQ9VYI:B`E<P!.87)K;W1Y:VD`12UM
M86EL`$5K=V%D;W(`161Y8VIA`%5S=?$@1W)U<.H`6FUI9?$@=7!R87=N:65N
M:64`6FUI9?$@=7!R87=N:65N:6$`6FUI9?$@=7!R87=N:65N:6$@9&QA("5S
M`%IM:67Q('5S=&%W:65N:6$@9&QA.@!:;6EE\2!U<')A=VYI96YI82!D;&$@
M)7,`6FUI9?$@=7!R87=N:65N:6$@9&QA("<E<R<`16=I<'0`16UA:6P`061R
M97,@96UA:6P`061R97-Y(&5M86EL(&UU<WJQ(&1O('-I96)I92!P87-O=V'F
M+@!%;6]T:6MO;GD`4'5S=&$@=VEA9&]M;[;F+@!"<F%K(')E>G5L=&%T\W<N
M`%>SL6-Z>>8@;65N=2!K;VYT96MS=&]W92!P;V0@<')A=WEM('!R>GEC:7-K
M:65M(&UY<WIY/P!%<GET<F5A`$*SL60`0K.Q9"!P<GIY('IA<&ES:64@)R5S
M)RX`0K.Q9#H`17-T;VYI80!%=&EO<&EA`$5U<F]P80!#;R!K8;]D92`Q-2!M
M:6YU=`!#;R!K8;]D92`R(&UI;G5T>0!#;R!K8;]D92`S,"!S96MU;F0`0V\@
M:V&_9&4@-2!M:6YU=`!#;R!K8;]D92!Z86QO9V]W86YI90!#;R!K8;]D92!P
M\[,@9V]D>FEN>0!#;R!K8;]DL2!M:6YU=.H`4')Z>6NS861O=V4@=V%R=&^V
M8VDZ`%)O>G=I\2!P87-E:P!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@3$1!4"X`0K.Q9"!P;V1C>F%S('IM:6%N>2!H87.S82`Z(`!&
M86MS`$QU='D`365N962_97(@<&QI:_-W`$YA>G=A('!L:6MU`%=Y8O-R('!L
M:6MU`%=G<GEW86YI92!P;&EK=0!79W)Y=V%N:64@<&QI:_-W(&YI92!J97-T
M(&]B<[-U9VEW86YE+@!&:6QT<GD`1FEN;&%N9&EA`$IE9'IE;FEE`%IA<&]M
M;FEALV6V(&AA<[-A/P!&<F%N8VIA`$]D`$YI96UC>0!)9+P`5WES>G5K:7=A
M<FMA($=O;V=L90!'<F5C:F$`1W)E;FQA;F1I80!'<F5N861A`$=R=7!Y(&1Y
M<VMU<WEJ;F4`4&]M;V,`7U-T87)T`%!O8WJQ=&5K`$%D<F5S(&1O;6]W>0!4
M96PN(&1O;2X`2&]R9&4`5'EL:V\@:6MO;GD`26MO;GD@>B!T96MS=&5M`$YA
M>G=A('1OOW-A;6^V8VDZ`$=R869I:V$`26UP;W)T;W=A;F4@<&]L93H@)7,`
M26UP;W)T;W=A;F4@<&]L83H`0K.Q9"!W97=NZG1R>FYY`$ER86L`27)L86YD
M:6$`27IR865L`%>S;V-H>0!*86UA:FMA`%-T>6-Z9?$`2F%P;VYI80!*;W)D
M86X`3&EP:65C`$-Z97)W:65C`$MA>F%C:'-T86X`2V5N:6$`1'II96-I`$MU
M=V5J=`!*ZGIY:P!/<W1A=&YI92!L;V=O=V%N:64Z("5S`$]S=&%T;FEE(&QO
M9V]W86YI93H@)7,@>B`E<P!/<W1A=&YI92!L;V=O=V%N:64Z(&YI9V1Y`*-O
M='=A`$QI8F5R:6$`5WFV=VEE=&P@=&5M871Y('!O;6]C>0!,:7-T;W=A;FEE
M('6_>71K;W=N:6OS=R!J97-T('=YL[%C>F]N92X`3&ET=V$`0WIA<R!L;VMA
M;&YY.B``57-T87=I96YI82!L;VMA;&YE(&D@8WIA<P!:86QO9W5J`%=Y;&]G
M=6H`6F%D86YI82!P<GIY(&QO9V]W86YI=0!,;V=O=V%N:64@;FEE('!O=VEO
M9+-O('-IZBP@<&]N:65W8;\@<&]D8;-EMB!N:65P<F%W:62S;W=E(&AA<[-O
M(&QU8B!N87IWZB!UOWET:V]W;FEK82X`3&]G;W=A;FEE(&YI92!P;W=I;V2S
M;R!S:>HN`%=Y;&]G=6H`3'5K<V5M8G5R9P!-30!-3U1$`$U31P!-861A9V%S
M:V%R`%!O8WIT80!-86QE>FIA`$UA;&5D:7=Y`$UA;&D`36%L=&$`6F%R>K%D
M>F%J(&QI<W2Q(&MA=&5G;W)I:2P@:W3S<GEM:2!BZF1Z:65S>B!O>FYA8WIA
MLR!P;WIY8VIE+"!I(&MO;&]R86UI('H@;FEM:2!Z=VFQ>F%N>6UI+@!-87)Z
M96,`36%R9VEN97,`4&%S=6JQ8V4@<&]L80!-86H`5')Y8B!M96YU.@!0;[.Q
M8WH@:V]M\W)K:0!7:6%D;VUOMN8`0FQO:R`B365T87(B(&YI92!J97-T(&1O
M<W3J<&YY+@!";&]K(")-971A<B(@;FEE(&IE<W0@9&]S=.IP;GDN(%-Z8WIE
M9_.S>2!Z9&%R>F5N:6$@>F]S=&&S>2!Z86QO9V]W86YE(&1L82!A9&UI;FES
M=')A=&]R82X`365K<WEK`$UO;F%K;P!-;VYG;VQI80!#;R!M:65S:;%C`$9A
M>GD@:W-IZK]Y8V$`36%R;VMO`$MO;G1O`$YA>G=I<VMO`$AO;&%N9&EA`%-I
M9>8`3FEG9'D`3F]W82!+86QE9&]N:6$`3F]W82!K871E9V]R:6$`3F]W82!:
M96QA;F1I80!.;W=E(&AA<[-O`%=I861O;6^V8VD`3F%S=.IP;F4@;W!C:F4`
M3FEK87)A9W5A`$YI9V5R:6$`0F5Z('IM:6%N+@"O861N80!.;W)W96=I80!.
M:65U<W1A=VEO;F4`3FEE;V)SLW5G:7=A;F4`57=A9V$Z(%!O('IM:6%N:64@
M:&%SLV$@;75S:2!S:>H@=WEL;V=O=V'F(&D@>F%L;V=O=V'F('!O;F]W;FEE
M(0!5=V%G:0!5=V%G80!,:7-T;W!A9`!,:6-Z8F$@:V]L=6UN`$QI8WIB82!W
M:65R<WIY`$]+`%!AO&1Z:65R;FEK`$)I=7)O`%-T87)E(&AA<[-O`$]P8VIE
M`$]P8VIE("5S`$]R9V%N:7IA=&]R`$EN;F4`26YN92!I;F9O<FUA8VIE`$EN
M;F4@=7!R87=N:65N:6$`2V]D(%!(4`!0;W>S;VMA(%!(4`!0;W>S;VMA(%!?
M2%``4&%K:7-T86X`4&%N86UA`%!A<F%G=V%J`$AA<[-O`$AA<[-O('IM:65N
M:6]N92$`2&%SLV\@;FEE<')A=VEDLV]W90!-;V1ULR!087-S=V]R9"!N:64@
M:F5S="!P<F%W:62S;W=O('-K;VYF:6=U<F]W86YY`$AA<[-O.@!(87.S;SH@
M`$AA<[-O(&UU<VD@<&%S;W=AYBX`5VML96H`5VML96H@>F4@<V-H;W=K80!7
M>6MO;F%J(&-Y:VQI8WIN92!O<&5R86-J90!);F9O<FUA8VIE(&]S;V)I<W1E
M`%!E<G4`5&5L969O;@!0<F]S>NH@;W!I<V'F('!R;V)L96TN`%!R;W-ZZB!P
M;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O`%!O;'-K80!0;W)T=6=A
M;&EA`%!R;V)L96T`3W!I<R!P<F]B;&5M=0!-87-Z('!R;V)L96UY/P!+871A
M<@!:87!Y=&%N:64`3V2V=VEEOR!D>6YA;6EC>FYE(&5L96UE;G1Y(&UE;G4Z
M`$]DMG=I9;\@=VED;VL@<V5R=VES=3H`6F1A;&YE('-E<G=E<GD`57-U\0!5
M<W7Q(&)L;VL`57-U\2!K;VQU;6[J`%5S=?$@<&%RZ@!5<W7Q`%5S=?$@=;]Y
M=&MO=VYI:V$`6F1A;&YE('6_>71K;W=N:6MA.B`E<P!7>6-Z>;;F`%!O=W+S
M="!D;R!O<&-J:0!2;WIB=61O=V%N>2!E9'ET;W(@=&5K<W1U`%-T86YO=VES
M:V\`4G5M=6YI80!2=6%N9&$`4&]W;&]K82!344P`4U-(`%!O=[-O:V$@4U]1
M3`!!<F%B:6$@4V%U9'EJ<VMA`%IA<&ES>@!:87!I<WH@)7,`6F%P:7-Z("<E
M<R<`6F%P:7-Z(&]P8VIE`%=Y8FEE<GH@>FYA:R!P;V1Z:6&S=2!D871Y.@!7
M>6)I97)Z(&9O<FUA="!D871Y.@!7>6)I97)Z('1OOW-A;6^VYB!D;R!Z;6EA
M;GDZ`%=Y8FEE<GH@9F]R;6%T(&-Z87-U.@!7>6)I97)Z(&1W82!P87-U:K%C
M92!P;VQA+@!7>6)I97)Z('-C:&5M870@:V]L;W+S=RX`5WEB:65R>B!T=_-J
M('!R969E<F]W86YY(&KJ>GEK.@!7>;9L:6H@<F%P;W)T(&\@<')O8FQE;6EE
M`%-E;F5G86P`5W)Z97-I9?$`57-T87<@>F1A;&YE('-E<G=E<GDL(&1O(&MT
M\W)Y8V@@8VAC97-Z(&UI9>8@9&]S=.IP('H@<V5R=VES=2X`57-T87<@<')E
M9F5R;W=A;GD@:NIZ>6LL('-T<F5FZB!C>F%S;W>Q(&D@;W!C:F4@9&%T>2X`
M57-T87<@=7.S=6?J('!O8WJQ=&MO=[$L('-C:&5M870@:V]L;W+S=RP@;V2V
M=VEEOV%N:64@<W1R;VYY(&D@:6YN92!O<&-J92!W>;9W:65T;&%N:6$`2V]N
M9FEG=7)A8VIA`%-Z97-Z96QE`%!O:V&_`%!O:V%Z>7=AYB!C>F%S(&]S=&%T
M;FEE9V\@>F%L;V=O=V%N:6$@<&\@;&]G;W=A;FEU/P!0;VMAOR!M96YU("5S
M('!O(&QE=V5J/P!3:65R<F$@3&5O;F4`4&]D<&ES`%-I;F=A<'5R`%=I96QK
M;[;F`%!O;6GQ(&]P97)A8VIE(&-Y:VQI8WIN90!3LV]W86-J80!3LV]W96YI
M80!7>7-P>2!386QO;6]N80!3;VUA;&EA`$)R86L@<&QI:_-W(&MO;F9I9W5R
M86-Y:FYY8V@@;6]D=;-U(%!A<W-W;W)D`%!OLW5D;FEO=V$@069R>6MA`$AI
M<WIP86YI80!3<&%M`$5D>6-J82!Z;F%K\W<@<W!E8VIA;&YY8V@`5WFV;&EJ
M`%!O=V]D>F5N:64`561ALV\@<VGJ(&1O9&'F("<E<R<@9&\@<WES=&5M=2X`
M561ALV\@<VGJ('5S=6ZQYB`G)7,G('H@<WES=&5M=2X`5W-C:/-D+WIA8VCS
M9"!SLV_Q8V$`4WIW96-J80!3>G=A:F-A<FEA`%1A:G=A;@!486IW86X`5&%D
MOWEK:7-T86X`6F%D86YI80!4>6QK;R!T96MS=`!486IL86YD:6$`1'IIZFMU
M:F5M>2!Z82!K;W)Z>7-T86YI92!Z('-E<G=I<W4N`%1O('!O;&4@:F5S="!W
M>6UA9V%N92X`5&5N('!L:6L@;V1P;W=I861A('IA('-T>6P@9F]N=/-W(&D@
M:V]L;W+S=RX`5&\@:F5S="!GL_-W;GD@<&QI:R!K;VYF:6=U<F%C>6IN>2!M
M;V1ULW4@4&%S<W=O<F0L(%IA=VEE<F$@;VX@MF-I9;]K:2`@:2!O<&-J92!D
M;&$@=W-Z>7-T:VEC:"!S:W)Y<'3S=R!M;V1ULW4@4&%S<W=O<F0N`$-Z87,`
M1F]R;6%T(&-Z87-U`%1Y='6S`$1Z:;8`2G5T<F\`4')A=V1A(&QU8B!F8;-S
M>@!4=6YE>FIA`%1U<F-J80!4=7)K;65N:7-T86X`55),`%523#H`56=A;F1A
M`%5K<F%I;F$`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M
M(%-13"X`3FEE(&UOOVYA('!R>F5TLW5M86-Z>>8@=&5G;R!D;VMU;65N='4@
M5V]R9"UA`$-O9FYI:B!Z;6EA;GD`5VEE;&MA($)R>71A;FEA`%5300!5<G5G
M=V%J`$YA>G=A('6_>71K;W=N:6MA.@!.87IW82!UOWET:V]W;FEK80!5OWET
M:V]W;FEC>2!W('-Y<W1E;6EE.@!5>F)E:VES=&%N`%=E;F5Z=65L80!7:65T
M;F%M`%!O:V&_('-T<F]NZB!75U<`3W-T<GIEOV5N:64`3W-T<GIEOV5N:64Z
M(`!75U<`0V\@='ED>FEE\0!7:71A;7D`5VET86UY('<@)7,`5VET86UY+"`E
M<P!*86NQ(&%P;&EK86-JZB!M82`E<R!W>;9W:65T;&'F('!O('IA;&]G;W=A
M;FEU('-IZC\`2F%K:64@=W1Y8WIK:2!A:W1Y=V]W8>8@=R!2;WIB=61O=V%N
M>6T@961Y=&]R>F4@=&5K<W1U+@!3>F5R;VMOMN8@;&5W96=O(&UE;G4@)7,@
M*'IM:6%N82!Z86-Z;FEE(&]B;W=IL7IY=V'F('!R>GD@;F%S=.IP;GEM(&QO
M9V]W86YI=2DZ`$%D<F5S(&1O('!R86-Y`%1E;"X@9&\@<')A8WD`4E(`4E)2
M4@!#;R!R;VL`5&%K`%1A:RP@>F=A9'IA;2!S:>H`3FEE(&UOOV5S>B!Z;6EE
M;FGF(&AA<[-A('6_>71K;W=N:6MO=VD@)7,`5WEL;V=O=V&S9;8@<VGJ+@!-
M=7-I<WH@;W!I<V'F('!R;V)L96T@>F%N:6T@9V\@=WFV;&5S>BX`375S:7-Z
M('!O9&'F(&YO=V4@:&%SLV\`375S:7-Z('!O9&'F('-T87)E(&AA<[-O`$UU
M<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U
M;K'F+@!-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC
M97-Z(&1O9&'F+@!-=7-I<WH@>G=E<GEF:6MO=V'F(&YO=V4@:&%SLV\`5'?S
M:B!A9')E<R!E+6UA:6P`5'?S:B!A9')E<R!/9#H`5'=O:F4@:6YF;W)M86-J
M90!4=_-J(&%D<F5S(&EN=&5R;F5T;W=Y('-IZB!Z;6EE;FFS(&]D('!O8WJQ
M=&MU('-E<VII("5S+B!7('IW:;%Z:W4@>B!B97IP:65C>F7Q<W1W96T@5'=O
M:F5G;R!K;VYT82!M=7-I<WH@>F%L;V=O=V'F('-IZB!P;VYO=VYI92X`5'=O
M:F4@:6UIZ@!496X@<WES=&5M(&%U=&5N='EK86-J:2!N:64@;V)SLW5G=6IE
M(&1O9&%W86YI82!UOWET:V]W;FEK\W<L(&QU8B!T82!O<&-J82!Z;W-T8;-A
M('=YL[%C>F]N82X`5&5N('-Y<W1E;2!A=71E;G1Y:V%C:FD@;FEE(&]B<[-U
M9W5J92!L:7-T;W=A;FEA('6_>71K;W=N:6OS=RP@;'5B('1A(&]P8VIA('IO
M<W1ALV$@=WFSL6-Z;VYA+@!4=V]J82!O8F5C;F$@<W1R969A(&-Z87-O=V$Z
M`$1O;7FV;&YA('1OOW-A;6^VYCH`5'=O:F4@<&6S;F4@:6UIZB!I(&YA>G=I
M<VMO.@!4=V]J92!H87.S;R!H97-T('IB>70@9+-U9VEE.R!H87.S82!N:64@
M;6]GL2!Z87=I97)AYB!W:>IC96H@;FF_("5D('IN86OS=R$`5'=O:F4@;F]W
M92!H87.S;R!J97-T(&%B>70@LV%T=V4@=&\@;V1G861N:>IC:6$A("!(87.S
M;R!N:64@>FUI96YI;VYE(0!4=V]J92!N;W=E(&AA<[-O(&UU<VD@>F%W:65R
M8>8@<')Z>6YA:FUN:65J("5D('IN86OS=R$`5'=O:F4@;F]W92!H87.S82!N
M:64@<&%S=6JQ(&1O('-I96)I90!4=V]J92!S=&%R92!H87.S;R!J97-T(&YI
M97!R87=I9+-O=V4`5'=O:F4@>F1A;&YE('-E<G=E<GDZ`$IU9V]SLV%W:6$`
M6F%M8FEA`%II;6)A8G=E`%M287!O<G0@;R!P<F]B;&5M:65=`%]!9&UI;FES
M=')A8VIA`%]#3$D`7U5S=?$@=VEE<G-Z`%]'<G5P>0!?4&]M;V,`7UIA;&]G
M=6H`7U=Y;&]G=6H`6FUI9?$@;&EN:RXN+@!?3W!C:F4`7U5P<F%W;FEE;FEA
M`%5S=?$@;&EN:RXN+@!?2V]N9FEG=7)A8VIA`%]5OWET:V]W;FEC>0!K<VFQ
MOVMA(&%D<F5S;W=A`&MA;&5N9&%R>@!Z<F]B:6]N90!P;&EK`$YA>G=I<VMO
M`&)E>B!N87IW>0!U86MT=6%L;FEO;GD`=D-A<F0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]P=%]"4B\`
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<T-``P,C`Q-S(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S
M=V0O;&]C86QE+W!T7T)2+TQ#7TU%4U-!1T53+P``````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,3<U-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O<'1?0E(O3$-?34534T%'15,O
M<&%S<W=D+FUO````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,S<U-#(`,3`T,3<S-C(W-#0`
M,#(S-C,Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-X2!)4`````O0<``!P````$/@``5PH``.Q[````````2*4``$T```!)
MI0``OP```)>E``!D````5Z8``+X```"\I@``D````'NG``!#````#*@``#P`
M``!0J```*P```(VH```N````N:@``"D```#HJ```*````!*I``!%````.ZD`
M`$<```"!J0``2@```,FI``!'````%*H``$4```!<J@``2````**J```Y````
MZZH``$8````EJP``2````&RK```P````M:L``$4```#FJP``1@```"RL``!,
M````<ZP``#0```#`K```,@```/6L``!I````**T``#````"2K0``)0```,.M
M``"(````Z:T``$````!RK@``]@```+.N``!*````JJ\``"P```#UKP``A0``
M`"*P``!(````J+````X```#QL```#P````"Q```-````$+$```@````>L0``
M"P```">Q```,````,[$```0```!`L0``#````$6Q```1````4K$``"4```!D
ML0``#P```(JQ```+````FK$``!$```"FL0``$````+BQ```.````R;$```4`
M``#8L0``*````-ZQ```*````![(``!4````2L@``$@```"BR```+````.[(`
M`!0```!'L@``)@```%RR```G````@[(``"8```"KL@``$P```-*R```.````
MYK(```H```#UL@``#0````"S```N````#K,``"<````]LP``(````&6S```.
M````AK,``!<```"5LP``(@```*VS```U````T+,``!$````&M```#0```!BT
M```,````)K0```T````SM```!@```$&T```;````2+0``"T```!DM```'0``
M`)*T```D````L+0``"D```#5M```&0```/^T```/````&;4``!@````IM0``
M#````$*U```;````3[4```X```!KM0``#@```'JU```(````B;4``$(```"2
MM0``+@```-6U```:````!+8``#(````?M@``.````%*V``!4````B[8``%$`
M``#@M@``6@```#*W``!7````C;<``#0```#EMP``!P```!JX```*````(K@`
M``4````MN```!@```#.X```1````.K@```@```!,N```"0```%6X```)````
M7[@```X```!IN```"````'BX```E````@;@``"````"GN```$````,BX```/
M````V;@```H```#IN```!P```/2X```#````_+@```\`````N0``%````!"Y
M```)````);D```T````ON0``$@```#VY```9````4+D``!X```!JN0``#P``
M`(FY```*````F;D```\```"DN0``"````+2Y```D````O;D``!<```#BN0``
M%````/JY```6````#[H```@````FN@``3@```"^Z```M````?KH``!\```"L
MN@``&0```,RZ```'````YKH```P```#NN@``+````/NZ```.````*+L```,`
M```WNP``"P```#N[```'````1[L```<```!/NP``!0```%>[```%````7;L`
M``H```!CNP```P```&Z[```7````<KL```H```"*NP``#P```)6[```.````
MI;L``!@```"TNP``(P```,V[```.````\;L``!0`````O```%P```!6\```7
M````+;P``!<```!%O```$P```%V\```/````<;P```X```"!O```'P```)"\
M```'````L+P```8```"XO```"````+^\```/````R+P```8```#8O```"@``
M`-^\```3````ZKP```L```#^O```$`````J]```5````&[T``!4````QO0``
M!P```$>]```%````3[T``!4```!5O0``$0```&N]```,````?;T``#L```"*
MO0``.````,:]```)````_[T```<````)O@``%````!&^```#````)KX```4`
M```JO@``$````#"^```)````0;X``!,```!+O@``.0```%^^```2````F;X`
M`#D```"LO@``)P```.:^```L````#K\``"H````[OP``)0```&:_```)````
MC+\```H```"6OP``!@```*&_```)````J+\```<```"ROP``+P```+J_```W
M````ZK\``"X````BP```50```%'````M````I\```"T```#5P```+0````/!
M``!`````,<$``",```!RP0``(P```);!```M````NL$``#,```#HP0``%0``
M`!S"```9````,L(``"D```!,P@``)````';"```1````F\(``!$```"MP@``
M"@```+_"```,````RL(```H```#7P@``$````.+"```6````\\(``!8````*
MPP``!P```"'#```'````*<,``!0````QPP``"@```$;#```(````4<,```0`
M``!:PP``)P```%_#```(````A\,```<```"0PP``!P```)C#```&````H,,`
M``4```"GPP``!P```*W#```&````M<,```@```"\PP``*0```,7#```.````
M[\,```H```#^PP``#P````G$```$````&<0```<````>Q```"0```";$```&
M````,,0``!$````WQ```!P```$G$```6````4<0```0```!HQ```"````&W$
M```&````=L0```T```!]Q```!@```(O$```>````DL0``!$```"QQ```(@``
M`,/$```6````YL0```@```#]Q```#0````;%```,````%,4```<````AQ0``
M`P```"G%```#````+<4``!<````QQ0``$P```$G%```(````7<4```0```!F
MQ0``"````&O%```(````=,4``$$```!]Q0``&@```+_%```@````VL4``!4`
M``#[Q0``!@```!'&```&````&,8``!4````?Q@``&````#7&```B````3L8`
M`"X```!QQ@``'0```*#&```A````OL8``%0```#@Q@``*0```#7'```*````
M7\<```<```!JQP``%0```'+'```.````B,<```H```"7QP``#P```*+'```-
M````LL<```\```#`QP``#0```-#'```)````WL<``!0```#HQP``!@```/W'
M```8````!,@``!T````=R```$P```#O(```4````3\@```0```!DR```#```
M`&G(```&````=L@``!0```!]R```5````)+(```4````Y\@``&0```#\R```
M!````&')```.````9LD``$0```!UR0``!0```+K)```%````P,D``!L```#&
MR0``&@```.+)```1````_<D``!$````/R@``$0```"'*```<````,\H``"H`
M``!0R@``$````'O*```A````C,H``"4```"NR@``&0```-3*```%````[LH`
M`!,```#TR@``$@````C+```*````&\L```\````FRP``$0```#;+```3````
M2,L```P```!<RP``!@```&G+```&````<,L``!<```!WRP``$````(_+```1
M````H,L```@```"RRP``!0```+O+```,````P<L``!````#.RP``!0```-_+
M```-````Y<L```8```#SRP``!P```/K+```-`````LP``!`````0S```"0``
M`"',```'````*\P```L````SS```"P```#_,```'````2\P```<```!3S```
M"0```%O,```4````9<P```D```!ZS```"@```(3,```9````C\P``!T```"I
MS```#````,?,```0````U,P``!4```#ES```!0```/O,```E`````<T``!(`
M```GS0``$P```#K-```K````3LT``#L```!ZS0``(````+;-```V````U\T`
M`!`````.S@``"````!_.```,````*,X```8````US@``!````#S.```.````
M0<X``!````!0S@``"@```&'.```-````;,X``!X```!ZS@``&P```)G.```A
M````M<X``!X```#7S@``&0```/;.```>````$,\``!L````OSP``+@```$O/
M```7````>L\``"8```"2SP``,````+G/```;````ZL\``!X````&T```'```
M`"70```F````0M```"L```!IT```,P```)70```F````R=```"L```#PT```
M.````!S1```=````5=$``!4```!ST0``+P```(G1```2````N=$``"````#,
MT0``*0```.W1```>````%](``!(````VT@``H@```$G2```6````[-(``",`
M```#TP``*````"?3```I````4-,``"@```!ZTP``'P```*/3```5````P],`
M`"````#9TP``)0```/K3```H````(-0``"D```!)U```+0```'/4```A````
MH=0``!8```##U```'````-K4```F````]]0``"H````>U0``00```$G5``!$
M````B]4```P```#0U0``!P```-W5```'````Y=4```8```#MU0``#0```/35
M```0`````M8``!(````3U@``$P```";6```2````.M8```<```!-U@``!```
M`%76```-````6M8```P```!HU@``#@```'76```/````A-8``!,```"4U@``
M#0```*C6```H````MM8```,```#?U@``#0```./6```&````\=8``!$```#X
MU@``%P````K7```;````(M<```X````^UP```@```$W7```%````4-<```0`
M``!6UP``$````%O7```$````;-<```T```!QUP``#@```'_7```#````CM<`
M``X```"2UP``"````*'7```/````JM<```@```"ZUP``#P```,/7```-````
MT]<``!````#AUP``$P```/+7```3````!M@```L````:V```$0```";8```)
M````.-@```8```!"V```#````$G8```1````5M@``!D```!HV```"P```(+8
M```-````CM@``"(```"<V```&P```+_8```T````V]@```H````0V0``&```
M`!O9```9````--D``!8```!.V0``+P```&79```B````E=D```T```"XV0``
M!P```,;9```,````SMD``"8```#;V0``%`````+:```+````%]H``"(````C
MV@``+P```$;:```+````=MH```D```""V@``&0```(S:```+````IMH``!<`
M``"RV@``%P```,K:```)````XMH``!8```#LV@``#P````/;```6````$]L`
M``X````JVP``&````#G;```(````4ML```T```!;VP``)@```&G;``!#````
MD-L```@```#4VP``$@```-W;```(````\-L```L```#YVP``+P````7<```.
M````-=P```4```!$W```!@```$K<```#````4=P```<```!5W```!````%W<
M```*````8MP```H```!MW```#P```'C<```0````B-P``!<```"9W```$0``
M`+'<```7````P]P``!D```#;W```"0```/7<```%````_]P```L````%W0``
M"@```!'=```"````'-T```4````?W0``#0```"7=```;````,]T``!<```!/
MW0``"0```&?=```.````<=T```T```"`W0``$@```([=```X````H=T``"``
M``#:W0```P```/O=```(````_]T```X````(W@``>P```!?>```8````D]X`
M`$````"LW@``$0```.W>```'````_]X```4````'WP``&`````W?```;````
M)M\``!D```!"WP``$P```%S?```'````<-\```<```!XWP``"````(#?```&
M````B=\```8```"0WP``$````)??```/````J-\``!````"XWP``#P```,G?
M```+````V=\```\```#EWP``#````/7?```/`````N````<````2X```"@``
M`!K@```&````)>````X````LX```#````#O@```H````2.````\```!QX```
M"````('@```6````BN````@```"AX```$P```*K@```>````ON```"$```#=
MX```(````/_@```9````(.$``!<````ZX0``)0```%+A```7````>.$``!\`
M``"0X0``!````+#A```;````M>$```T```#1X0``#````-_A```#````[.$`
M``@```#PX0``"@```/GA```,````!.(```L````1X@``!````!WB```3````
M(N(``!0````VX@``#````$OB```)````6.(```X```!BX@``"P```''B```;
M````?>(```<```"9X@``!P```*'B```*````J>(```T```"TX@``"0```,+B
M```$````S.(```4```#1X@```P```-?B```8````V^(```H```#TX@``!```
M`/_B```F````!.,```X````KXP``?````#KC```5````M^,```4```#-XP``
M!P```-/C```,````V^,```@```#HXP``"@```/'C```&````_.,```@````#
MY```%@````SD```2````(^0```(````VY```!@```#GD```&````0.0``!0`
M``!'Y```%0```%SD```/````<N0``!$```""Y```&@```)3D```-````K^0`
M`!````"]Y```&P```,[D```$````ZN0```D```#OY```$````/GD```)````
M"N4```D````4Y0``!0```![E```%````).4``!H````JY0``"````$7E```&
M````3N4``!D```!5Y0``#@```&_E```B````?N4```<```"AY0``!P```*GE
M```.````L>4```4```#`Y0``"0```,;E```*````T.4```(```#;Y0``!@``
M`-[E```-````Y>4```D```#SY0``!@```/WE```2````!.8```D````7Y@``
M!P```"'F```4````*>8``!T````^Y@``$0```%SF```&````;N8```H```!U
MY@``!````(#F```)````A>8```@```"/Y@``$0```)CF```1````JN8```D`
M``"\Y@``!@```,;F```-````S>8```8```#;Y@```@```.+F```$````Y>8`
M`#D```#JY@``/0```"3G```Z````8N<``!X```"=YP``!0```+SG```.````
MPN<```0```#1YP``!@```-;G```A````W><``!4```#_YP``!@```!7H```$
M````'.@``!$````AZ```!@```#/H``"@````.N@```H```#;Z```(@```.;H
M```$````">D``"4````.Z0``!0```#3I```=````.ND```0```!8Z0``#```
M`%WI```*````:ND```@```!UZ0``"0```'[I```%````B.D``!L```".Z0``
M.@```*KI```P````Y>D``#4````6Z@``*0```$SJ```N````=NH``$<```"E
MZ@``.````.WJ```I````)NL``#\```!0ZP``+@```)#K```M````O^L``!\`
M``#MZP``#P````WL```2````'>P```L````P[```)@```#SL```I````8^P`
M`"0```"-[```)@```++L```(````V>P```H```#B[```"0```.WL```'````
M]^P``"````#_[```(````"#M```F````0>T```H```!H[0``&0```'/M```I
M````C>T``!8```"W[0``$@```,[M```'````X>T```H```#I[0``#````/3M
M```/`````>X``!`````1[@``0````"+N``!P````8^X``&8```#4[@``#@``
M`#OO```)````2N\```H```!4[P``$@```%_O```3````<N\```P```"&[P``
M!@```)/O```/````FN\``!(```"J[P``$````+WO```*````SN\``!$```#9
M[P``'````.OO```C````"/```&H````L\```#P```)?P```%````I_```!``
M``"M\```"0```+[P```$````R/````L```#-\```&@```-GP```4````]/``
M``P````)\0``#````!;Q```/````(_$``!4````S\0``*0```$GQ```J````
M<_$``"8```">\0``)P```,7Q```I````[?$``"H````7\@``&0```$+R``!"
M````7/(``!$```"?\@``$@```+'R```3````Q/(``!0```#8\@``#P```.WR
M```6````_?(``!<````4\P``$````"SS```1````/?,``#0```!/\P``$P``
M`(3S```2````F/,``#4```"K\P``%````.'S```'````]O,```P```#^\P``
M#@````OT```K````&O0``"````!&]```%````&?T```1````?/0``!<```".
M]```'````*;T```3````P_0``!$```#7]```&@```.GT```>````!/4``!H`
M```C]0``$0```#[U```7````4/4``!0```!H]0``%P```'WU```5````E?4`
M``D```"K]0``&0```+7U```$````S_4```<```#4]0``"P```-SU```1````
MZ/4```8```#Z]0``!@````'V```&````"/8```4````/]@``!P```!7V```'
M````'?8```4````E]@``%@```"OV```&````0O8```8```!)]@``!````%#V
M```$````5?8```<```!:]@``#@```&+V```,````<?8```P```!^]@``#0``
M`(OV```*````F?8```X```"D]@``!0```+/V```H````N?8```X```#B]@``
M#````/'V```/````_O8```H````.]P``"````!GW```)````(O<``"L````L
M]P``!````%CW```(````7?<``"8```!F]P``$@```(WW```/````H/<```8`
M``"P]P``"@```+?W```'````PO<```@```#*]P``(````-/W```)````]/<`
M``P```#^]P``#0````OX```.````&?@``!8````H^```$0```#_X```&````
M4?@```,```!8^```!@```%SX```9````8_@```<```!]^```!````(7X```+
M````BO@```L```"6^```!P```*+X```'````JO@``!8```"R^```#0```,GX
M```-````U_@```H```#E^```$````/#X```/`````?D``!$````1^0``%P``
M`"/Y```*````._D``!$```!&^0``"````%CY```$````8?D```\```!F^0``
M.@```';Y```%````L?D```P```"W^0``'@```,3Y```.````X_D``!````#R
M^0``"P````/Z```,````#_H```D````<^@``!P```";Z```*````+OH```D`
M```Y^@``#@```$/Z```0````4OH``!H```!C^@``"@```'[Z```)````B?H`
M`!0```"3^@``"@```*CZ```,````L_H```\```#`^@``"````-#Z```&````
MV?H```<```#@^@``"P```.CZ``!'````]/H```T````\^P``!@```$K[```)
M````4?L```0```!;^P```P```&#[```3````9/L``!,```!X^P``$P```(S[
M```*````H/L```(```"K^P``!````*[[```E````L_L```,```#9^P``!0``
M`-W[```J````X_L```H````._```!0```!G\```$````'_P```H````D_```
M#0```"_\``!`````/?P``!,```!^_```!@```)+\```(````F?P```@```"B
M_```!````*O\```%````L/P``&@```"V_```"0```!_]```,````*?T```4`
M```V_0``!@```#S]```;````0_T``"\```!?_0``$````(_]```*````H/T`
M``\```"K_0``"@```+O]```)````QOT``!,```#0_0``&P```.3]```8````
M`/X``!<````9_@``#@```#'^```#````0/X```<```!$_@``"````$S^```4
M````5?X``!,```!J_@``$````'[^```-````C_X```X```"=_@``%@```*S^
M```'````P_X```H```#+_@``"P```-;^```M````XOX``!4````0_P``,```
M`";_```D````5_\```<```!\_P``40```(3_```0````UO\```P```#G_P``
M#0```/3_```:`````@`!`$H````=``$`!@```&@``0`:````;P`!``8```"*
M``$`!@```)$``0`?````F``!``8```"X``$`"0```+\``0`8````R0`!`!<`
M``#B``$`!@```/H``0`-`````0$!`"(````/`0$`5P```#(!`0`3````B@$!
M`",```">`0$`$P```,(!`0`"````U@$!``L```#9`0$`"````.4!`0`-````
M[@$!``H```#\`0$`!@````<"`0`'````#@(!`!0````6`@$`!@```"L"`0`(
M````,@(!``X````[`@$`!P```$H"`0`*````4@(!``L```!=`@$`)P```&D"
M`0`'````D0(!``P```"9`@$`#0```*8"`0`,````M`(!``D```#!`@$`"0``
M`,L"`0`*````U0(!``<```#@`@$`"0```.@"`0`'````\@(!``H```#Z`@$`
M&P````4#`0`2````(0,!``H````T`P$`"0```#\#`0`0````20,!``<```!:
M`P$`$@```&(#`0`$````=0,!``<```!Z`P$`!0```((#`0`,````B`,!``4`
M``"5`P$`"P```)L#`0`4````IP,!`!$```"\`P$`&@```,X#`0`6````Z0,!
M`!0`````!`$`%P```!4$`0`8````+00!`!P```!&!`$`&0```&,$`0`'````
M?00!``4```"%!`$`#0```(L$`0`,````F00!``@```"F!`$`%P```*\$`0`+
M````QP0!``P```#3!`$`'P```.`$`0`-``````4!`!H````.!0$`$P```"D%
M`0`$````/04!``H```!"!0$`!````$T%`0`)````4@4!``H```!<!0$`#```
M`&<%`0`)````=`4!``4```!^!0$`!P```(0%`0`%````C`4!``0```"2!0$`
M`@```)<%`0`X````F@4!`"P```#3!0$`$@`````&`0`I````$P8!`#(````]
M!@$`"@```'`&`0`V````>P8!`"P```"R!@$`%0```-\&`0`N````]08!`#,`
M```D!P$`,P```%@'`0`X````C`<!``\```#%!P$`&````-4'`0`[````[@<!
M`!`````J"`$`#P```#L(`0`4````2P@!`!,```!@"`$`%````'0(`0`2````
MB0@!`!0```"<"`$`%0```+$(`0`M````QP@!`"T```#U"`$`,0```",)`0`M
M````50D!`"X```"#"0$`+P```+()`0`L````X@D!`&(````/"@$`$P```'(*
M`0`(````A@H!`!<```"/"@$`"````*<*`0`K````L`H!`"$```#<"@$`&@``
M`/X*`0`)````&0L!`$4````C"P$`00```&D+`0`/````JPL!``0```"["P$`
M$P```,`+`0`4````U`L!``X```#I"P$`$P```/@+`0`8````#`P!``8````E
M#`$`"0```"P,`0`*````-@P!``\```!!#`$`$````%$,`0`'````8@P!``X`
M``!J#`$`20```'D,`0`%````PPP!`!L```#)#`$`!@```.4,`0`(````[`P!
M``8```#U#`$`%````/P,`0`1````$0T!``X````C#0$`.````#(-`0`"````
M:PT!``8```!N#0$`#@```'4-`0`:````A`T!``4```"?#0$`!P```*4-`0`.
M````K0T!``8```"\#0$`*````,,-`0`,````[`T!`!P```#Y#0$`#0```!8.
M`0`$````)`X!`"D````I#@$`%P```%,.`0`?````:PX!`%P```"+#@$`%```
M`.@.`0`^````_0X!`!\````\#P$`$````%P/`0`4````;0\!``<```""#P$`
M#@```(H/`0`(````F0\!``P```"B#P$`#````*\/`0`3````O`\!``H```#0
M#P$`'0```-L/`0`9````^0\!``4````3$`$`$0```!D0`0`1````*Q`!`"0`
M```]$`$`%0```&(0`0`2````>!`!``X```"+$`$`&0```)H0`0`(````M!`!
M``D```"]$`$`#0```,<0`0`*````U1`!``\```#@$`$`"P```/`0`0`*````
M_!`!``<````'$0$`"`````\1`0`%````&!$!`!\````>$0$`!@```#X1`0`0
M````11$!``@```!6$0$`#0```%\1`0`(````;1$!`!X```!V$0$`$0```)41
M`0`2````IQ$!`"H```"Z$0$`+````.41`0`:````$A(!``D````M$@$`"@``
M`#<2`0`5````0A(!``4```!8$@$`%````%X2`0`$````<Q(!`!````!X$@$`
M!@```(D2`0`'````D!(!`!X```"8$@$`*````+<2`0`*````X!(!`!P```#K
M$@$`&@````@3`0`/````(Q,!`!0````S$P$`!````$@3`0`$````31,!``L`
M``!2$P$`!0```%X3`0`&````9!,!``@```!K$P$`!@```'03`0`*````>Q,!
M`!L```"&$P$`-````*(3`0`T````UQ,!`"`````,%`$`*0```"T4`0`@````
M5Q0!`$$```!X%`$`&@```+H4`0`H````U10!`"D```#^%`$`40```"@5`0`O
M````>A4!`%<```"J%0$`+`````(6`0`B````+Q8!``8```!2%@$`"````%D6
M`0`%````8A8!``@```!H%@$`&0```'$6`0`9````BQ8!`"H```"E%@$`(P``
M`-`6`0`N````]!8!`#0````C%P$`#0```%@7`0`(````9A<!`!<```!O%P$`
M"@```(<7`0`'````DA<!`"$```":%P$`#0```+P7`0`0````RA<!``X```#;
M%P$`"P```.H7`0`'````]A<!`!,```#^%P$`"````!(8`0`(````&Q@!``L`
M```D&`$`"@```#`8`0`4````.Q@!`#(```!0&`$`"P```(,8`0`%````CQ@!
M``4```"5&`$`%P```)L8`0`/````LQ@!``0```##&`$`"@```,@8`0`)````
MTQ@!``L```#=&`$`#0```.D8`0`.````]Q@!``4````&&0$`!`````P9`0`-
M````$1D!`#(````?&0$`10```%(9`0`7````F!D!`!X```"P&0$`%````,\9
M`0`%````Y!D!`!0```#J&0$`!P```/\9`0`C````!QH!``X````K&@$`*@``
M`#H:`0`&````91H!``P```!L&@$`#0```'D:`0`1````AQH!`!<```"9&@$`
M"P```+$:`0`V````O1H!``H```#T&@$`(@```/\:`0`+````(AL!``\````N
M&P$`"P```#X;`0`@````2AL!`"<```!K&P$`*P```),;`0`)````OQL!`#(`
M``#)&P$`,````/P;`0`Q````+1P!`"T```!?'`$`%````(T<`0`%````HAP!
M``X```"H'`$`$P```+<<`0`'````RQP!`!H```#3'`$`"````.X<`0`1````
M]QP!`!,````)'0$`!P```!T=`0`4````)1T!`!@````Z'0$`!P```%,=`0`%
M````6QT!``P```!A'0$`#````&X=`0`2````>QT!``0```".'0$`!P```),=
M`0`*````FQT!``L```"F'0$`#````+(=`0`.````OQT!``X```#.'0$`!0``
M`-T=`0`%````XQT!`"X```#I'0$`)@```!@>`0`C````/QX!``,```!C'@$`
M$@```&<>`0`&````>AX!`!X```"!'@$`&````*`>`0`E````N1X!``T```#?
M'@$`"0```.T>`0`"````]QX!``,```#Z'@$`!P```/X>`0`*````!A\!``(`
M```1'P$`#````!0?`0`5````(1\!``L````W'P$`&0```$,?`0`@````71\!
M`!(```!^'P$`!0```)$?`0`*````EQ\!`!4```"B'P$`$@```+@?`0`,````
MRQ\!``0```#8'P$`!P```-T?`0`)````Y1\!``P```#O'P$`4@```/P?`0`7
M````3R`!`"0```!G(`$`!P```(P@`0`&````E"`!``X```";(`$`(@```*H@
M`0`=````S2`!``P```#K(`$`#0```/@@`0`5````!B$!`!(````<(0$`#P``
M`"\A`0`4````/R$!`!L```!4(0$`$````'`A`0!I````@2$!`!H```#K(0$`
M%P````8B`0`G````'B(!`!H```!&(@$`%P```&$B`0`;````>2(!`!D```"5
M(@$`'P```*\B`0`7````SR(!`!,```#G(@$`"````/LB`0`'````!",!``@`
M```,(P$`"0```!4C`0`5````'R,!``T````U(P$`$P```$,C`0`#````5R,!
M`$8```!;(P$`/P```*(C`0`W````XB,!`%<````:)`$`'P```'(D`0`O````
MDB0!``H```#")`$`"````,TD`0`-````UB0!`"T```#D)`$`!````!(E`0!/
M````%R4!`"4```!G)0$`'````(TE`0`+````JB4!`!\```"V)0$`'0```-8E
M`0`E````]"4!`"`````:)@$`)````#LF`0`@````8"8!``L```"!)@$`!P``
M`(TF`0`-````E28!``P```"C)@$`%P```+`F`0`&````R"8!`#D```#/)@$`
M#`````DG`0`'````%B<!`!D````>)P$`"0```#@G`0`3````0B<!``D```!6
M)P$`!````&`G`0`0````92<!``H```!V)P$`"````($G`0`(````BB<!``0`
M``"3)P$`"P```)@G`0`,````I"<!`!$```"Q)P$`#````,,G`0`:````T"<!
M``\```#K)P$`!P```/LG`0`Z`````R@!``T````^*`$`%````$PH`0`.````
M82@!``P```!P*`$`&P```'TH`0`L````F2@!`!,```#&*`$`'````-HH`0`H
M````]R@!``8````@*0$`!P```"<I`0`3````+RD!``4```!#*0$`!````$DI
M`0`7````3BD!``H```!F*0$`#````'$I`0`)````?BD!``8```"(*0$`"0``
M`(\I`0`(````F2D!``D```"B*0$`!0```*PI`0`*````LBD!`!$```"]*0$`
M!@```,\I`0`8````UBD!``X```#O*0$`#@```/XI`0`-````#2H!``L````;
M*@$`'0```"<J`0`+````12H!``(```!1*@$`'````%0J`0`'````<2H!`!<`
M``!Y*@$`!@```)$J`0!E````F"H!``D```#^*@$`!P````@K`0`F````$"L!
M`#@````W*P$`&@```'`K`0`J````BRL!`#L```"V*P$`*P```/(K`0`H````
M'BP!`!D```!'+`$`%0```&$L`0`%````=RP!``<```!]+`$`"````(4L`0`'
M````CBP!``4```"6+`$`!P```)PL`0`.````I"P!``D```"S+`$`!@```+TL
M`0`(````Q"P!``L```#-+`$`!P```-DL`0`(````X2P!``<```#J+`$`%@``
M`/(L`0`)````"2T!``8````3+0$`"P```!HM`0`<````)BT!`!0```!#+0$`
M!P```%@M`0`(````8"T!``@```!I+0$`!0```'(M`0`0````>"T!`!````")
M+0$`!@```)HM`0`9````H2T!``H```"[+0$`'````,8M`0`'````XRT!``4`
M``#K+0$`$````/$M`0`4`````BX!``L````7+@$`#0```",N`0`8````,2X!
M`!<```!*+@$`&@```&(N`0`4````?2X!``0```"2+@$`"0```)<N`0`*````
MH2X!``<```"L+@$``@```+0N`0`.````MRX!``@```#&+@$`'P```,\N`0`^
M````[RX!`",````N+P$`.````%(O`0`Q````BR\!`"<```"]+P$`9````.4O
M`0`4````2C`!`!P```!?,`$`50```'PP`0`X````TC`!`$H````+,0$`6P``
M`%8Q`0`H````LC$!`#@```#;,0$`*@```!0R`0`H````/S(!`"P```!H,@$`
M)P```)4R`0`;````O3(!`#X```#9,@$`J0$``!@S`0`H````PC0!`",```#K
M-`$`%P````\U`0!(````)S4!`(4```!P-0$`,````/8U`0`E````)S8!`$$`
M``!--@$`6P```(\V`0!)````ZS8!`#$````U-P$`'0```&<W`0`8````A3<!
M`"L```">-P$`(0```,HW`0`?````[#<!`"L````,.`$`(0```#@X`0`I````
M6C@!`!T```"$.`$`$0```*(X`0`S````M#@!`"4```#H.`$`.`````XY`0`G
M````1SD!`"````!O.0$`'P```)`Y`0`P````L#D!`&D```#A.0$`*P```$LZ
M`0`R````=SH!`#$```"J.@$`00```-PZ`0`S````'CL!`"4```!2.P$`/0``
M`'@[`0!E````MCL!`$T````</`$`+P```&H\`0`N````FCP!`"L```#)/`$`
M,````/4\`0`J````)CT!`#X```!1/0$`5````)`]`0"#````Y3T!`%H```!I
M/@$`2````,0^`0!*````#3\!`#(```!8/P$`'0```(L_`0`C````J3\!`"\`
M``#-/P$`+````/T_`0`M````*D`!`'$```!80`$`;P```,I``0"S````.D$!
M`!<```#N00$`)0````9"`0`R````+$(!`"D```!?0@$`/@```(E"`0`B````
MR$(!`%(```#K0@$`=````#Y#`0!S````LT,!`"4````G1`$`"P```$U$`0"Q
M````640!`',````+10$`10```']%`0`A````Q44!`"X```#G10$`,````!9&
M`0`E````1T8!`!P```!M1@$`,0```(I&`0`'````O$8!``<```#$1@$`!```
M`,Q&`0`-````T48!``L```#?1@$`#@```.M&`0`+````^D8!``4````&1P$`
M$`````Q'`0`"````'4<!`%D````@1P$`!0```'I'`0`2````@$<!``0```"3
M1P$`!P```)A'`0`(````H$<!``4```"I1P$``P```*]'`0`0````LT<!``H`
M``#$1P$`#````,]'`0`3````W$<!``T```#P1P$``@```/Y'`0`'`````4@!
M``8````)2`$`%````!!(`0`,````)4@!`!@````R2`$`!@```$M(`0`2````
M4D@!``P```!E2`$``P```')(`0`J````=D@!``0```"A2`$`!@```*9(`0`'
M````K4@!`!\```"U2`$`-0```-5(`0`N````"TD!`"\````Z20$`%P```&I)
M`0`@````@DD!`!L```"C20$`&````+])`0`D````V$D!`!\```#]20$`&@``
M`!U*`0`@````.$H!`!H```!92@$`,@```'1*`0`O````ITH!`!H```#72@$`
M*P```/)*`0`?````'DL!`",````^2P$`'P```&)+`0`:````@DL!`"4```"=
M2P$`)@```,-+`0`E````ZDL!`"0````03`$`&````#5,`0`=````3DP!`"0`
M``!L3`$`&````)%,`0`B````JDP!`"4```#-3`$`/````/-,`0`?````,$T!
M`",```!030$`'P```'1-`0`@````E$T!`!H```"U30$`&````-!-`0`F````
MZ4T!`!X````03@$`*0```"].`0`>````64X!``D```!X3@$`#````().`0`7
M````CTX!`"\```"G3@$`)````-=.`0`'````_$X!`!\````$3P$`#P```"1/
M`0`4````-$\!``X```!)3P$`#0```%A/`0`D````9D\!``4```"+3P$`!P``
M`)%/`0`B````F4\!`"4```"\3P$`$P```.)/`0`=````]D\!`!H````44`$`
M!P```"]0`0#'````-U`!``L```#_4`$`%0````M1`0`,````(5$!``8````N
M40$`"0```#51`0`8````/U$!``L```!840$`#0```&11`0`=````<E$!`!<`
M``"040$`!@```*A1`0`S````KU$!`!,```#C40$`$P```/=1`0`'````"U(!
M``8````34@$`#P```!I2`0`'````*E(!`#(````R4@$`(0```&52`0`3````
MAU(!``P```";4@$`$0```*A2`0`R````NE(!`!````#M4@$`"````/Y2`0`=
M````!U,!``D````E4P$`"@```"]3`0`%````.E,!`!0```!`4P$`"@```%53
M`0`=````8%,!``@```!^4P$`'P```(=3`0`(````IU,!`!H```"P4P$`!@``
M`,M3`0`5````TE,!``<```#H4P$`"````/!3`0`)````^5,!`#\````#5`$`
M!P```$-4`0`/````2U0!``X```!;5`$`$````&I4`0`)````>U0!``D```"%
M5`$`"````(]4`0`3````F%0!``<```"L5`$`&0```+14`0`*````SE0!``H`
M``#95`$`"0```.14`0`7````[E0!`!0````&50$`"@```!M5`0`,````)E4!
M`!<````S50$`!````$M5`0`J````4%4!`!$```![50$`!P```(U5`0`)````
ME54!``(```"?50$`$````*)5`0`8````LU4!``L```#,50$``P```-A5`0`(
M````W%4!``8```#E50$`!P```.Q5`0`-````]%4!``L````"5@$`%`````Y6
M`0`5````(U8!``X````Y5@$`+P```$A6`0`@````>%8!`!P```"95@$`#```
M`+96`0`Q````PU8!``4```#U5@$`$@```/M6`0`_````#E<!`!(```!.5P$`
M"@```&%7`0`&````;%<!``0```!S5P$`!````'A7`0`*````?5<!`!,```"(
M5P$`!0```)Q7`0`&````HE<!``8```"I5P$`"0```+!7`0`$````NE<!``P`
M``"_5P$`"@```,Q7`0!L````UU<!`"````!$6`$`+@```&58`0`%````E%@!
M`!@```":6`$`&0```+-8`0`?````S5@!`!T```#M6`$`$0````M9`0`"````
M'5D!``0````@60$`"@```"59`0`&````,%D!``4````W60$``P```#U9`0`,
M````05D!`$4```!.60$`&@```)19`0`U````KUD!`"4```#E60$`*`````M:
M`0!3````-%H!`!D```"(6@$`<@```*):`0`@````%5L!`#4````V6P$`(0``
M`&Q;`0!%````CEL!`#````#46P$`'P````5<`0`?````)5P!`"@```!%7`$`
M*0```&Y<`0`F````F%P!`"4```"_7`$`*````.5<`0`H````#ET!`"(````W
M70$`(0```%I=`0`P````?%T!`!(```"M70$`$P```,!=`0`0````U%T!`'D`
M``#E70$`"0```%]>`0!R````:5X!`',```#<7@$`?````%!?`0`K````S5\!
M`%,```#Y7P$`%P```$U@`0`6````96`!``\```!\8`$`90```(Q@`0`7````
M\F`!`!\````*80$`'P```"IA`0`?````2F$!`!P```!J80$`40```(=A`0`:
M````V6$!`!0```#T80$`"@````EB`0`%````%&(!``8````:8@$`"````"%B
M`0`%````*F(!`!(````P8@$`$````$-B`0`3````5&(!`!T```!H8@$`#P``
M`(9B`0`/````EF(!``0```"F8@$`"0```*MB`0`+````M6(!``<```#!8@$`
M!0```,EB`0`4````SV(!``<```#D8@$`"````.QB`0`/````]6(!``@````%
M8P$`#`````YC`0`/````&V,!``8````K8P$`%````#)C`0`&````1V,!``P`
M``!.8P$`%0```%MC`0`(````<6,!``0```!Z8P$`"@```']C`0`$````BF,!
M``8```"/8P$`!P```)9C`0`$````GF,!``<```"C8P$`&0```*MC`0`"````
MQ6,!``0```#(8P$`"0```,UC`0`&````UV,!``8```#>8P$`)P```.5C`0`$
M````#60!``L````29`$`"0```!YD`0`/````*&0!`!,````X9`$`!P```$QD
M`0`'````5&0!``8```!<9`$`!@```&-D`0`0````:F0!`!(```![9`$`!@``
M`(YD`0`)````E60!`#,```"?9`$`(@```--D`0`'````]F0!``<```#^9`$`
M!P````9E`0`+````#F4!``4````:90$``@```"!E`0`+````(V4!`$L!```O
M90$`3@```'MF`0"Y````RF8!`&P```"$9P$`MP```/%G`0"-````J6@!`$<`
M```W:0$`.0```']I`0`Q````N6D!`#H```#K:0$`,@```"9J`0`Q````66H!
M`$X```"+:@$`3````-IJ`0!*````)VL!`$T```!R:P$`30```,!K`0!5````
M#FP!`#X```!D;`$`20```*-L`0!!````[6P!`#(````O;0$`30```&)M`0`S
M````L&T!`$T```#D;0$`,@```#)N`0`Z````96X!`&<```"@;@$`+`````AO
M`0`K````-6\!`)L```!A;P$`50```/UO`0`2`0``4W`!`#T```!F<0$`/```
M`*1Q`0"%````X7$!`%````!G<@$`$````+AR`0`5````R7(!``T```#?<@$`
M!P```.UR`0`)````]7(!``@```#_<@$``P````AS`0`*````#',!`!(````7
M<P$`+````"IS`0`2````5W,!``H```!J<P$`$````'5S`0`/````AG,!`!<`
M``"6<P$`!0```*YS`0`H````M',!``X```#=<P$`$P```.QS`0`-`````'0!
M``H````.=`$`#P```!ET`0`Z````*70!`"(```!D=`$`+@```(=T`0`2````
MMG0!`!````#)=`$`"@```-IT`0`2````Y70!`#H```#X=`$`*P```#-U`0`A
M````7W4!``T```"!=0$`&0```(]U`0`D````J74!`"\```#.=0$`&P```/YU
M`0`0````&G8!``\````K=@$`%@```#MV`0`&````4G8!`!X```!9=@$`+P``
M`'AV`0`O````J'8!`"D```#8=@$`+0````)W`0`8````,'<!``T```!)=P$`
M%@```%=W`0`/````;G<!`!L```!^=P$`$````)IW`0`0````JW<!``@```"\
M=P$`5````,5W`0`[````&G@!`!4```!6>`$`0P```&QX`0!)````L'@!`%4`
M``#Z>`$`30```%!Y`0!R````GGD!`&H````1>@$`1@```'QZ`0`.````PWH!
M``\```#2>@$`!0```.)Z`0`&````Z'H!`!$```#O>@$`"`````%[`0`)````
M"GL!``D````4>P$`$P```!Y[`0`&````,GL!`"4````Y>P$`(P```%][`0`.
M````@WL!`!$```"2>P$`!@```*1[`0`%````JWL!``D```"Q>P$`&P```+M[
M`0`A````UWL!``X```#Y>P$`%`````A\`0`8````'7P!`"4````V?`$`*@``
M`%Q\`0`:````AWP!`!````"B?`$`%P```+-\`0`-````RWP!`#4```#9?`$`
M(`````]]`0`C````,'T!`"8```!4?0$`$0```'M]`0!8````C7T!`#8```#F
M?0$`*@```!U^`0`E````2'X!``@```!N?@$`%0```'=^`0`W````C7X!``T`
M``#%?@$``P```--^`0`+````UWX!``<```#C?@$`!P```.M^`0`'````\WX!
M``<```#[?@$`#`````-_`0`%````$'\!`!L````6?P$`#````#)_`0`0````
M/W\!`!(```!0?P$`'````&-_`0`O````@'\!``D```"P?P$`%@```+I_`0`6
M````T7\!`!@```#H?P$`'0````&``0`4````'X`!`!(````T@`$`#P```$>`
M`0`A````5X`!``<```!Y@`$`!@```(&``0`(````B(`!``T```"1@`$`"```
M`)^``0`)````J(`!`!(```"R@`$`"0```,6``0`3````SX`!`!@```#C@`$`
M*@```/R``0`'````)X$!``4````O@0$`%@```#6!`0`2````3($!``\```!?
M@0$`0@```&^!`0`Z````LH$!``D```#M@0$`!P```/>!`0`3````_X$!``0`
M```3@@$`!0```!B"`0`-````'H(!``H````L@@$`%P```#>"`0!#````3X(!
M`!4```"3@@$`4@```*F"`0`D````_((!`"L````A@P$`*@```$V#`0`P````
M>(,!``T```"I@P$`"0```+>#`0`&````P8,!``D```#(@P$`!P```-*#`0`[
M````VH,!`#P````6A`$`.@```%.$`0!?````CH0!`#D```#NA`$`.0```"B%
M`0`Y````8H4!`%(```"<A0$`*@```.^%`0`L````&H8!`#D```!'A@$`/P``
M`(&&`0`5````P88!`!D```#7A@$`+````/&&`0`F````'H<!`!,```!%AP$`
M$P```%F'`0`*````;8<!``X```!XAP$`!0```(>'`0`,````C8<!`!D```":
MAP$`&P```+2'`0`'````T(<!``<```#8AP$`%0```."'`0`*````]H<!``@`
M```!B`$`"`````J(`0`T````$X@!`!````!(B`$`"@```%F(`0`'````9(@!
M``8```!LB`$`!0```'.(`0`(````>8@!``4```""B`$`"P```(B(`0`R````
ME(@!`!8```#'B`$`#0```-Z(`0`0````[(@!``<```#]B`$`!P````6)`0`)
M````#8D!``4````7B0$`$0```!V)`0`&````+XD!`!0````VB0$`!0```$N)
M`0`(````48D!``8```!:B0$`"P```&&)`0`&````;8D!`"(```!TB0$`!@``
M`)>)`0`J````GHD!`!T```#)B0$`"````.>)`0`4````\(D!``P````%B@$`
M!P```!**`0`#````&HH!``,````>B@$`&@```"**`0`:````/8H!``H```!8
MB@$`!0```&.*`0`(````:8H!``@```!RB@$`6@```'N*`0`@````UHH!`"P`
M``#WB@$`(````"2+`0`&````18L!``@```!,BP$`'@```%6+`0`F````=(L!
M`#$```";BP$`-@```,V+`0`H````!(P!`"\````MC`$`;0```%V,`0`Z````
MRXP!``H````&C0$`!@```!&-`0`2````&(T!``P````KC0$`$````#B-`0`6
M````28T!`!$```!@C0$`%@```'*-`0`6````B8T!`!````"@C0$`%0```+&-
M`0`&````QXT!`!L```#.C0$`&P```.J-`0`7````!HX!`!@````>C@$`!@``
M`#>.`0`(````/HX!``<```!'C@$`$````$^.`0!<````8(X!`!,```"]C@$`
M8````-&.`0`$````,H\!`!(````WCP$`6````$J/`0`%````HX\!``4```"I
MCP$`'````*^/`0`9````S(\!`!$```#FCP$`$@```/B/`0`1````"Y`!`!H`
M```=D`$`.@```#B0`0`/````<Y`!`"\```"#D`$`*````+.0`0`;````W)`!
M``8```#XD`$`%````/^0`0`3````%)$!``\````HD0$`&````#B1`0`5````
M49$!`!,```!GD0$`#0```'N1`0`&````B9$!``<```"0D0$`#@```)B1`0`6
M````IY$!``\```"^D0$`"````,Z1`0`#````UY$!`!````#;D0$`#@```.R1
M`0`%````^Y$!`!,````!D@$`"@```!62`0`'````()(!`!$````HD@$`$P``
M`#J2`0`)````3I(!``@```!8D@$`"0```&&2`0`*````:Y(!``<```!VD@$`
M"0```'Z2`0`(````B)(!`!0```"1D@$`#````*:2`0`)````LY(!`!H```"]
MD@$`)@```-B2`0`-````_Y(!`!`````-DP$`&````!Z3`0`%````-Y,!`!\`
M```]DP$`$0```%V3`0`2````;Y,!`#(```""DP$`0@```+63`0`A````^),!
M`$<````:E`$`$````&*4`0`)````<Y0!``H```!]E`$`!@```(B4`0`&````
MCY0!``X```"6E`$`$P```*64`0`*````N90!``\```#$E`$`,0```-24`0`L
M````!I4!`#0````SE0$`+P```&B5`0`F````F)4!`"L```"_E0$`)@```.N5
M`0`]````$I8!`"(```!0E@$`,@```'.6`0!(````II8!`"P```#OE@$`+P``
M`!R7`0`F````3)<!`#0```!SEP$`1@```*B7`0!!````[Y<!`#T````QF`$`
M/0```&^8`0!'````K9@!`"P```#UF`$`*````"*9`0!&````2YD!`!H```"2
MF0$`*@```*V9`0`U````V)D!`"@````.F@$`&````#>:`0#)````4)H!`!P`
M```:FP$`,@```#>;`0`R````:IL!`#0```"=FP$`,0```-*;`0`I````!)P!
M`"H````NG`$`*@```%F<`0`R````A)P!`#4```"WG`$`-0```.V<`0!)````
M(YT!`"P```!MG0$`)0```)J=`0`H````P)T!`#8```#IG0$`,@```"">`0!9
M````4YX!`$X```"MG@$`#0```/R>`0`$````"I\!``8````/GP$`!0```!:?
M`0`-````')\!``X````JGP$`$````#F?`0`4````2I\!`!L```!?GP$`!P``
M`'N?`0`$````@Y\!``H```"(GP$`"@```).?`0`-````GI\!``L```"LGP$`
M$````+B?`0`,````R9\!`#8```#6GP$`!@````V@`0`.````%*`!``8````C
MH`$`$0```"J@`0`7````/*`!`!L```!4H`$`$````'"@`0`"````@:`!``L`
M``"$H`$`!0```)"@`0`5````EJ`!``0```"LH`$`$P```+&@`0`/````Q:`!
M``,```#5H`$`#P```-F@`0`(````Z:`!`!````#RH`$`"`````.A`0`0````
M#*$!``H````=H0$`$0```"BA`0`2````.J$!`!(```!-H0$`"@```&"A`0`/
M````:Z$!``@```![H0$`!P```(2A`0`-````C*$!`!$```":H0$`&@```*RA
M`0`.````QZ$!``X```#6H0$`(P```.6A`0`<````":(!`#P````FH@$`#0``
M`&.B`0`>````<:(!`!8```"0H@$`%0```*>B`0`V````O:(!`#0```#TH@$`
M#P```"FC`0`)````.:,!`!$```!#HP$`+0```%6C`0`3````@Z,!``D```"7
MHP$`(@```*&C`0`W````Q*,!``\```#\HP$`$`````RD`0`E````':0!`!(`
M``!#I`$`(````%:D`0`@````=Z0!``D```"8I`$`&P```**D`0`2````OJ0!
M`!4```#1I`$`#@```.>D`0`9````]J0!``<````0I0$`"P```!BE`0`F````
M)*4!`$@```!+I0$`"@```)2E`0`4````GZ4!``8```"TI0$`"0```+NE`0`P
M````Q:4!`!````#VI0$`!@````>F`0`'````#J8!``,````6I@$`!P```!JF
M`0`&````(J8!``P````II@$`#````#:F`0`0````0Z8!`!$```!4I@$`&0``
M`&:F`0`1````@*8!`!D```"2I@$`&P```*RF`0`(````R*8!``4```#1I@$`
M"P```->F`0`+````XZ8!``(```#OI@$`!0```/*F`0`1````^*8!`"8````*
MIP$`&````#&G`0`)````2J<!``\```!4IP$`$````&2G`0`9````=:<!`$8`
M``"/IP$`+P```-:G`0`%````!J@!``P````,J`$`#P```!FH`0"*````*:@!
M`!P```"TJ`$`30```-&H`0`0````'ZD!``@````PJ0$`!````#FI`0`<````
M/JD!`!T```!;J0$`$0```'FI`0`3````BZD!``8```"?J0$`!P```*:I`0`'
M````KJD!``8```"VJ0$`!@```+VI`0`/````Q*D!``X```#4J0$`$````..I
M`0`.````]*D!``P````#J@$`#@```!"J`0`+````'ZH!`!,````KJ@$`"```
M`#^J`0`+````2*H!``@```!4J@$`%@```%VJ`0`,````=*H!`#4```"!J@$`
M$0```+>J`0`(````R:H!`!,```#2J@$`%0```.:J`0`:````_*H!`!L````7
MJP$`(P```#.K`0`B````5ZL!`!@```!ZJP$`&@```).K`0`E````KJL!`!D`
M``#4JP$`*@```.ZK`0`%````&:P!`!D````?K`$`"P```#FL`0`+````1:P!
M``,```!1K`$`"0```%6L`0`0````7ZP!`!(```!PK`$`$0```(.L`0`$````
ME:P!`"````":K`$`(0```+NL`0`7````W:P!``\```#UK`$`$@````6M`0`0
M````&*T!`"(````IK0$`!P```$RM`0`)````5*T!``\```!>K0$`#P```&ZM
M`0`)````?JT!``4```"(K0$`"@```(ZM`0`%````F:T!`!,```"?K0$`#```
M`+.M`0`&````P*T!`"D```#'K0$`#@```/&M`0""`````*X!`!$```"#K@$`
M"P```)6N`0`%````H:X!``T```"GK@$`!@```+6N`0`(````O*X!``8```#%
MK@$`$0```,RN`0`:````WJX!`!<```#YK@$``P```!&O`0`&````%:\!``8`
M```<KP$`%````".O`0`8````.*\!`!8```!1KP$`)P```&BO`0`S````D*\!
M``\```#$KP$`$@```-2O`0`<````YZ\!``(````$L`$`!0````>P`0`2````
M#;`!``D````@L`$`#0```"JP`0`1````.+`!``4```!*L`$`(````%"P`0`(
M````<;`!``8```!ZL`$`&@```(&P`0`-````G+`!`"4```"JL`$`!P```-"P
M`0`(````V+`!``X```#AL`$`!````/"P`0`)````];`!``T```#_L`$``@``
M``VQ`0`&````$+$!`!(````7L0$`$````"JQ`0`&````.[$!`!(```!"L0$`
M"@```%6Q`0`'````8+$!`!<```!HL0$`*0```("Q`0`3````JK$!``8```"^
ML0$`"0```,6Q`0`$````S[$!``D```#4L0$`"````-ZQ`0`7````Y[$!`!<`
M``#_L0$`$````!>R`0`%````*+(!``P````NL@$`!@```#NR`0`"````0K(!
M``0```!%L@$`00```$JR`0!"````C+(!`$$```#/L@$`(0```!&S`0`%````
M,[,!``\````YLP$`!P```$FS`0`)````4;,!`!L```!;LP$`%0```'>S`0`&
M````C;,!``4```"4LP$`#P```)JS`0`*````JK,!`(\```"ULP$`"@```$6T
M`0`>````4+0!``0```!OM`$`.````'2T`0`'````K;0!`"0```"UM`$`!@``
M`-JT`0`4````X;0!`!0```#VM`$`"`````NU`0`)````%+4!``4````>M0$`
M'0```"2U`0`[````0K4!`#8```!^M0$`0P```+6U`0`I````^;4!`"T````C
MM@$`0@```%&V`0!"````E+8!`"L```#7M@$`2@````.W`0`O````3K<!`#D`
M``!^MP$`+P```+BW`0`0````Z+<!`!$```#YMP$`"P````NX`0`M````%[@!
M`"D```!%N`$`(0```&^X`0`H````D;@!``<```"ZN`$`"0```,*X`0`*````
MS+@!``<```#7N`$`)````-^X`0`F````!+D!`"T````KN0$`"P```%FY`0`;
M````9;D!`"T```"!N0$`&````*^Y`0`3````R+D!``@```#<N0$`#@```.6Y
M`0`.````]+D!``X````#N@$`$P```!*Z`0!$````)KH!`'X```!KN@$`<0``
M`.JZ`0`;````7+L!``T```!XNP$`#@```(:[`0`1````E;L!`!(```"GNP$`
M#P```+J[`0`'````RKL!`!(```#2NP$`$P```.6[`0`2````^;L!``L````,
MO`$`$P```!B\`0`H````++P!`!X```!5O`$`A````'2\`0`2````^;P!``4`
M```,O0$`%````!*]`0`)````)[T!``H````QO0$`"@```#R]`0`;````1[T!
M`!0```!CO0$`#@```'B]`0`.````A[T!`!,```"6O0$`%0```*J]`0`D````
MP+T!`"8```#EO0$`(P````R^`0`E````,+X!`"$```!6O@$`(P```'B^`0`=
M````G+X!`$4```"ZO@$`$P````"_`0`4````%+\!`!,````IOP$`%````#V_
M`0`1````4K\!`!8```!DOP$`%P```'N_`0`2````D[\!`!,```"FOP$`/```
M`+J_`0`6````][\!`!0````.P`$`/@```"/``0`5````8L`!``X```!XP`$`
M$0```(?``0`,````F<`!`"\```"FP`$`+0```-;``0`3````!,$!`!<````8
MP0$`'0```##!`0`?````3L$!`!T```!NP0$`'````(S!`0`C````J<$!`"$`
M``#-P0$`(````._!`0`3````$,(!`!L````DP@$`'0```$#"`0`;````7L(!
M`!@```!ZP@$`"@```)/"`0`:````GL(!``8```"YP@$`!P```,#"`0`-````
MR,(!`!(```#6P@$`!@```.G"`0`'````\,(!``<```#XP@$`!@````##`0`'
M````!\,!``<````/PP$`!0```!?#`0`5````'<,!``8````SPP$`"````#K#
M`0`%````0\,!``4```!)PP$`"@```$_#`0`1````6L,!``H```!LPP$`$@``
M`'?#`0`1````BL,!``L```"<PP$`$@```*C#`0`&````N\,!`"H```#"PP$`
M$0```.W#`0`0````_\,!`!H````0Q`$`$````"O$`0`-````/,0!``P```!*
MQ`$`+P```%?$`0`(````A\0!``@```"0Q`$`*````)G$`0`4````PL0!`!``
M``#7Q`$`!@```.C$`0`+````[\0!``<```#[Q`$`!@````/%`0`A````"L4!
M``T````LQ0$`#0```#K%`0`3````2,4!`!````!<Q0$`'P```&W%`0`3````
MC<4!``<```"AQ0$``P```*G%`0`&````K<4!`!\```"TQ0$`!@```-3%`0`(
M````V\4!`!(```#DQ0$`$P```/?%`0`&````"\8!``<````2Q@$`%@```!K&
M`0`-````,<8!``L````_Q@$`"P```$O&`0`4````5\8!`!8```!LQ@$`%P``
M`(/&`0`9````F\8!``H```"UQ@$`#0```,#&`0`&````SL8!``0```#5Q@$`
M$0```-K&`0`[````[,8!``4````HQP$`#P```"['`0`A````/L<!`!8```!@
MQP$`%P```'?'`0`.````C\<!``P```">QP$`"0```*O'`0`'````M<<!``H`
M``"]QP$`"0```,C'`0`.````TL<!`!````#AQP$`)P```/+'`0`*````&L@!
M``@````ER`$`&0```"[(`0`-````2,@!``P```!6R`$`$@```&/(`0`+````
M=L@!``@```""R`$`"P```(O(`0`2````E\@!`#P```"JR`$`#P```.?(`0`%
M````]\@!``L```#]R`$`!`````G)`0`%````#LD!`!L````4R0$`'````##)
M`0`<````3<D!``H```!JR0$``@```'7)`0`$````>,D!`"$```!]R0$``P``
M`)_)`0`%````H\D!`"D```"IR0$`"@```-/)`0`&````WLD!``<```#ER0$`
M&````.W)`0`.````!LH!`$4````5R@$`%````%O*`0`&````<,H!``<```!W
MR@$`"````'_*`0`$````B,H!``4```"-R@$`/````)/*`0`)````T,H!``P`
M``#:R@$`!0```.?*`0`&````[<H!`!X```#TR@$`,P```!/+`0`.````1\L!
M``D```!6RP$`%@```&#+`0`*````=\L!``@```""RP$`&0```(O+`0`L````
MI<L!`"D```#2RP$`*````/S+`0`.````)<P!``0````TS`$`!P```#G,`0`(
M````0<P!`!<```!*S`$`%0```&+,`0`3````>,P!`!(```",S`$`%@```)_,
M`0`E````MLP!``<```#<S`$`#0```.3,`0`/````\LP!`"\````"S0$`'```
M`#+-`0`M````3\T!`"8```!]S0$`"0```*3-`0!7````KLT!`!(````&S@$`
M$````!G.`0`+````*LX!`!L````VS@$`4````%+.`0`&````H\X!`!T```"J
MS@$`!P```,C.`0`&````T,X!`"````#7S@$`!````/C.`0`)````_<X!`"D`
M```'SP$`*````#'/`0`'````6L\!``@```!BSP$`(@```&O/`0!9````CL\!
M`!@```#HSP$`)@````'0`0`6````*-`!``,````_T`$`#0```$/0`0`'````
M4=`!``\```!9T`$`"P```&G0`0`&````==`!``8```!\T`$`%0```(/0`0`&
M````F=`!``@```"@T`$`"0```*G0`0`+````L]`!``H```"_T`$`#````,K0
M`0`M````U]`!``@````%T0$`$@````[1`0`4````(=$!`!<````VT0$`#```
M`$[1`0`0````6]$!``\```!LT0$`"P```'S1`0`,````B-$!``L```"5T0$`
M"@```*'1`0`E````K-$!`!````#2T0$`"P```./1`0`*````[]$!`!0```#Z
MT0$`"`````_2`0`4````&-(!``0````MT@$`!P```#+2`0`%````.M(!`!$`
M``!`T@$`!0```%+2`0`'````6-(!`!,```!@T@$`%````'32`0`B````B=(!
M`"(```"LT@$`'````,_2`0`<````[-(!`"`````)TP$`)0```"K3`0`?````
M4-,!``0```!PTP$`!0```'73`0`.````>],!``X```"*TP$`"````)G3`0`7
M````HM,!``T```"ZTP$`"@```,C3`0`:````T],!``L```#NTP$`'P```/K3
M`0`4````&M0!``@````OU`$`$@```#C4`0`'````2]0!``X```!3U`$`#```
M`&+4`0`/````;]0!``D```!_U`$`!0```(G4`0`'````C]0!``4```"7U`$`
M!````)W4`0`#````HM0!`$$```"FU`$`-0```.C4`0`7````'M4!`"D````V
MU0$`/0```&#5`0`2````GM4!`$4```"QU0$`.````/?5`0`<````,-8!`#@`
M``!-U@$`/0```(;6`0`]````Q-8!`$(````"UP$`&````$77`0`9````7M<!
M`$(```!XUP$`%@```+O7`0`8````TM<!`"$```#KUP$`(`````W8`0`;````
M+M@!`!D```!*V`$`&P```&38`0`4````@-@!`#$```"5V`$`,0```,?8`0`U
M````^=@!`#$````OV0$`,@```&'9`0`S````E-D!`#````#(V0$`=P```/G9
M`0`9````<=H!``H```"+V@$`(@```);:`0`)````N=H!`#0```##V@$`)0``
M`/C:`0`@````'ML!``L````_VP$`40```$O;`0!-````G=L!`!$```#KVP$`
M!P```/W;`0`7````!=P!`!4````=W`$`#````#/<`0`0````0-P!`!8```!1
MW`$`!P```&C<`0`(````<-P!``D```!YW`$`$@```(/<`0`1````EMP!``\`
M``"HW`$`#@```+C<`0`_````Q]P!``4````'W0$`&`````W=`0`%````)MT!
M``@````LW0$`!@```#7=`0`4````/-T!`!$```!1W0$`$````&/=`0!"````
M=-T!``(```"WW0$`!@```+K=`0`1````P=T!`!\```#3W0$`!0```//=`0`'
M````^=T!`!$````!W@$`"@```!/>`0`J````'MX!``P```!)W@$`'@```%;>
M`0`-````==X!``,```"#W@$`-P```(?>`0`8````O]X!`"@```#8W@$`A@``
M``'?`0`8````B-\!`$$```"AWP$`(0```./?`0`3````!>`!`!4````9X`$`
M!@```"_@`0`,````-N`!``<```!#X`$`#@```$O@`0`+````6N`!`!8```!F
MX`$`"P```'W@`0`<````B>`!`!8```"FX`$`!0```+W@`0`2````P^`!`!H`
M``#6X`$`)0```/'@`0`6````%^$!`!P````NX0$`$0```$OA`0`F````7>$!
M``H```"$X0$`%````(_A`0`6````I.$!`!(```"[X0$`$@```,[A`0`5````
MX>$!`!0```#WX0$`!@````SB`0`)````$^(!``4````=X@$`'0```"/B`0`&
M````0>(!`!````!(X@$`"````%GB`0`4````8N(!``4```!WX@$`&P```'WB
M`0`1````F>(!``\```"KX@$`,P```+OB`0`M````[^(!`!4````=XP$`!@``
M`#/C`0`'````.N,!`!@```!"XP$`!0```%OC`0`>````8>,!``0```"`XP$`
M%````(7C`0`'````FN,!``L```"BXP$`(````*[C`0`M````S^,!``H```#]
MXP$`'@````CD`0`;````)^0!``T```!#Y`$`%````%'D`0`$````9N0!`!0`
M``!KY`$`"0```(#D`0`(````BN0!``4```"3Y`$`"````)GD`0`&````HN0!
M``8```"IY`$`(0```+#D`0`W````TN0!`#\````*Y0$`(@```$KE`0`P````
M;>4!`"@```">Y0$`10```,?E`0`B````#>8!`"@````PY@$`)0```%GF`0!5
M````?^8!`#@```#5Y@$`6P````[G`0`T````:N<!`"H```"?YP$`!P```,KG
M`0`(````TN<!``<```#;YP$`"````./G`0`4````[.<!`!0````!Z`$`,```
M`!;H`0`M````1^@!`#4```!UZ`$`/0```*OH`0`-````Z>@!``<```#WZ`$`
M&0```/_H`0`)````&>D!`!`````CZ0$`(@```#3I`0`/````5^D!`!$```!G
MZ0$`$@```'GI`0`-````C.D!``@```":Z0$`%0```*/I`0`)````N>D!``@`
M``##Z0$`"P```,SI`0`-````V.D!`!L```#FZ0$`/`````+J`0`*````/^H!
M``4```!*Z@$`"0```%#J`0`:````6NH!`!$```!UZ@$`!0```(?J`0`.````
MC>H!`!````"<Z@$`$0```*WJ`0`,````O^H!``\```#,Z@$`!P```-SJ`0`#
M````Y.H!``T```#HZ@$`.@```/;J`0!.````,>L!`!4```"`ZP$`)@```);K
M`0`=````O>L!``4```#;ZP$`%0```.'K`0`+````]^L!`",````#[`$`$@``
M`"?L`0`J````.NP!``<```!E[`$`#0```&WL`0`.````>^P!`!(```"*[`$`
M&0```)WL`0`+````M^P!`#L```##[`$`"0```/_L`0`<````">T!``\````F
M[0$`$P```#;M`0`1````2NT!`"0```!<[0$`-P```('M`0`V````N>T!``T`
M``#P[0$`/P```/[M`0`Y````/NX!`#H```!X[@$`-@```+/N`0`8````ZNX!
M``8````#[P$`$`````KO`0`0````&^\!``H````L[P$`'0```#?O`0`+````
M5>\!`!$```!A[P$`'0```'/O`0`'````D>\!`!4```"9[P$`&@```*_O`0`(
M````RN\!``<```#3[P$`$0```-OO`0`2````[>\!`!D`````\`$`!0```!KP
M`0`'````(/`!``\````H\`$`%0```#CP`0`4````3O`!`!4```!C\`$`%0``
M`'GP`0`'````C_`!``8```"7\`$`,0```)[P`0`G````T/`!`"8```#X\`$`
M"````!_Q`0`/````*/$!``8````X\0$`'P```#_Q`0`A````7_$!`"8```"!
M\0$`"P```*CQ`0`4````M/$!``(```#)\0$``P```,SQ`0`'````T/$!`!4`
M``#8\0$``P```.[Q`0`,````\O$!`!$```#_\0$`"P```!'R`0`4````'?(!
M`!@````R\@$`$P```$OR`0`%````7_(!``H```!E\@$`$@```'#R`0`4````
M@_(!``X```"8\@$`!@```*?R`0`)````KO(!``L```"X\@$`#0```,3R`0!:
M````TO(!`!8````M\P$`-0```$3S`0`'````>O,!``@```""\P$`$@```(OS
M`0`A````GO,!`"$```#`\P$`%0```.+S`0`2````^/,!`"$````+]`$`&```
M`"WT`0`5````1O0!`",```!<]`$`)P```(#T`0`3````J/0!`'````"\]`$`
M(0```"WU`0`<````3_4!`"T```!L]0$`(0```)KU`0`<````O/4!`"8```#9
M]0$`'P````#V`0`?````(/8!`!H```!`]@$`'````%OV`0`*````>/8!``<`
M``"#]@$`"````(OV`0`(````E/8!`!,```"=]@$`#P```+'V`0`5````P?8!
M``8```#7]@$`3P```-[V`0!)````+O<!`#X```!X]P$`9@```+?W`0`R````
M'O@!`#````!1^`$`"0```(+X`0`'````C/@!``8```"4^`$`0````)OX`0`&
M````W/@!`$````#C^`$`-````"3Y`0`C````6?D!``X```!]^0$`+0```(SY
M`0`<````NOD!`#,```#7^0$`*`````OZ`0`R````-/H!`"@```!G^@$`#0``
M`)#Z`0`&````GOH!``\```"E^@$`$@```+7Z`0`5````R/H!``<```#>^@$`
M0@```.;Z`0`*````*?L!``D````T^P$`(P```#[[`0`*````8OL!`!@```!M
M^P$`"0```(;[`0`'````D/L!`!(```"8^P$`"P```*O[`0`*````M_L!``D`
M``#"^P$`!````,S[`0`'````T?L!``@```#9^P$`%````.+[`0`6````]_L!
M`!T````._`$`#0```"S\`0`'````.OP!`#4```!"_`$`$````'C\`0`/````
MB?P!`!(```"9_`$`#0```*S\`0`8````NOP!`"@```#3_`$`#@```/S\`0`?
M````"_T!`"D````K_0$`"0```%7]`0`+````7_T!`!0```!K_0$`!P```(#]
M`0`$````B/T!`!\```"-_0$`#@```*W]`0`.````O/T!``T```#+_0$`"```
M`-G]`0`)````XOT!``8```#L_0$`"0```//]`0`'````_?T!``L````%_@$`
M$P```!'^`0`&````)?X!`!P````L_@$`&````$G^`0`+````8OX!``<```!N
M_@$`'@```';^`0`F````E?X!``P```"\_@$``P```,G^`0`A````S?X!``<`
M``#O_@$`)@```/?^`0`&````'O\!`'8````E_P$`"@```)S_`0`'````I_\!
M`"<```"O_P$`0````-?_`0`:````&``"`"4````S``(`1````%D``@`L````
MG@`"`"D```#+``(`&P```/4``@`6````$0$"``4````H`0(`!@```"X!`@`)
M````-0$"``H````_`0(`"@```$H!`@`)````50$"`!0```!?`0(`"P```'0!
M`@`*````@`$"``P```"+`0(`#````)@!`@`'````I0$"``@```"M`0(`"0``
M`+8!`@`4````P`$"``L```#5`0(`!@```.$!`@`%````Z`$"`"4```#N`0(`
M&````!0"`@`(````+0("``D````V`@(`"P```$`"`@`&````3`("`!8```!3
M`@(`%@```&H"`@`'````@0("`!L```")`@(`"P```*4"`@`6````L0("``4`
M``#(`@(`!P```,X"`@`2````U@("`"````#I`@(`"P````H#`@`-````%@,"
M`!L````D`P(`&````$`#`@`C````60,"`!8```!]`P(`!0```)0#`@`-````
MF@,"`!0```"H`P(`%P```+T#`@`#````U0,"`!,```#9`P(`"0```.T#`@`@
M````]P,"`#T````8!`(`(P```%8$`@`S````>@0"`#8```"N!`(`)P```.4$
M`@!J````#04"`!<```!X!0(`)````)`%`@!G````M04"`$(````=!@(`5```
M`&`&`@!N````M08"`"T````D!P(`.P```%('`@`J````C@<"`#,```"Y!P(`
M.````.T'`@`N````)@@"`!L```!5"`(`-````'$(`@#7`0``I@@"`"L```!^
M"@(`'P```*H*`@`7````R@H"`$P```#B"@(`=P```"\+`@`S````IPL"`"4`
M``#;"P(`0P````$,`@!<````10P"`%H```"B#`(`*@```/T,`@`C````*`T"
M`!8```!,#0(`*````&,-`@`=````C`T"`!H```"J#0(`+0```,4-`@`@````
M\PT"`"\````4#@(`(P```$0.`@`6````:`X"`#@```!_#@(`)0```+@.`@!!
M````W@X"`"H````@#P(`+0```$L/`@`?````>0\"`#@```"9#P(`;0```-(/
M`@`M````0!`"`#,```!N$`(`,0```*(0`@!"````U!`"`"X````7$0(`)P``
M`$81`@!`````;A$"`&,```"O$0(`2````!,2`@`N````7!("`"X```"+$@(`
M)P```+H2`@`P````XA("`"<````3$P(`1````#L3`@!?````@!,"`(H```#@
M$P(`;P```&L4`@!8````VQ0"`%D````T%0(`-0```(X5`@`:````Q!4"`"8`
M``#?%0(`*@````86`@`J````,18"`"\```!<%@(`:0```(P6`@!O````]A8"
M`+<```!F%P(`&0```!X8`@`O````.!@"`#````!H&`(`+0```)D8`@!2````
MQQ@"`"4````:&0(`4P```$`9`@"!````E!D"`'\````6&@(`(@```)8:`@`*
M````N1H"`-@```#$&@(`/0```)T;`@!8````VQL"`",````T'`(`/````%@<
M`@`X````E1P"`"@```#.'`(`'@```/<<`@`Y````%AT"``0```!0'0(`"```
M`%4=`@`$````7AT"`!D```!C'0(`#P```'T=`@`/````C1T"``L```"='0(`
M!@```*D=`@`/````L!T"``0```#`'0(`6````,4=`@`$````'AX"`!<````C
M'@(`!````#L>`@`'````0!X"``8```!('@(`!0```$\>`@`$````51X"`!4`
M``!:'@(`"0```'`>`@`)````>AX"`!$```"$'@(`$P```)8>`@`#````JAX"
M``<```"N'@(`!P```+8>`@`2````OAX"``T```#1'@(`%````-\>`@`&````
M]!X"`!H```#['@(`#0```!8?`@`#````)!\"`"D````H'P(`!````%(?`@`&
M````5Q\"``<```!>'P(`(0```&8?`@!`````B!\"`#$```#)'P(`,@```/L?
M`@`;````+B`"`"0```!*(`(`(P```&\@`@`>````DR`"`"0```"R(`(`'P``
M`-<@`@`=````]R`"`",````5(0(`'@```#DA`@`T````6"$"`#$```"-(0(`
M'````+\A`@`R````W"$"`"$````/(@(`)0```#$B`@`D````5R("`!\```!\
M(@(`*@```)PB`@`H````QR("`"H```#P(@(`)@```!LC`@`?````0B,"`"(`
M``!B(P(`*P```(4C`@`=````L2,"`"0```#/(P(`)P```/0C`@`\````'"0"
M`"0```!9)`(`)@```'XD`@`E````I20"`"8```#+)`(`(````/(D`@`>````
M$R4"`"<````R)0(`(P```%HE`@`N````?B4"`"<```"M)0(`"@```-4E`@`3
M````X"4"`!8```#T)0(`,P````LF`@`F````/R8"``T```!F)@(`)````'0F
M`@`/````F28"`!8```"I)@(`"P```,`F`@`.````S"8"`"P```#;)@(`"```
M``@G`@`,````$2<"`"<````>)P(`*@```$8G`@`8````<2<"`!\```"*)P(`
M'````*HG`@`(````QR<"`-0```#0)P(`#0```*4H`@`6````LR@"``T```#*
M*`(`"0```-@H`@`-````XB@"`!P```#P*`(`$0````TI`@`0````'RD"`"@`
M```P*0(`'P```%DI`@`&````>2D"`$L```"`*0(`'````,PI`@`<````Z2D"
M``<````&*@(`"P````XJ`@`2````&BH"``P````M*@(`-@```#HJ`@`G````
M<2H"`!D```"9*@(`$@```+,J`@`4````QBH"`#(```#;*@(`%0````XK`@`'
M````)"L"`!<````L*P(`"````$0K`@`)````32L"``@```!7*P(`%````&`K
M`@`+````=2L"`!L```"!*P(`!@```)TK`@`J````I"L"``@```#/*P(`(P``
M`-@K`@`'````_"L"`!<````$+`(`!P```!PL`@`(````)"P"``D````M+`(`
M/@```#<L`@`&````=BP"`!(```!]+`(`%````)`L`@`/````I2P"``D```"U
M+`(`"@```+\L`@`&````RBP"`!,```#1+`(`#0```.4L`@`A````\RP"`!(`
M```5+0(`$0```"@M`@`1````.BT"`!D```!,+0(`%0```&8M`@`,````?"T"
M``X```")+0(`&@```)@M`@`'````LRT"`"T```"[+0(`#P```.DM`@`'````
M^2T"``D````!+@(``P````LN`@`1````#RX"`!P````A+@(`"P```#XN`@`#
M````2BX"``@```!.+@(`#````%<N`@`)````9"X"``\```!N+@(`#0```'XN
M`@`6````C"X"`!<```"C+@(`$````+LN`@`O````S"X"`!T```#\+@(`'```
M`!HO`@`+````-R\"`#````!#+P(`!P```'0O`@`7````?"\"`$4```"4+P(`
M$0```-HO`@`2````["\"``@```#_+P(`!`````@P`@`%````#3`"`!$````3
M,`(`&@```"4P`@`&````0#`"``<```!',`(`"0```$\P`@`0````63`"``@`
M``!J,`(`$@```',P`@`2````AC`"`'<```"9,`(`*P```!$Q`@`V````/3$"
M``4```!T,0(`&0```'HQ`@`D````E#$"`"(```"Y,0(`*````-PQ`@`0````
M!3("``(````6,@(`!````!DR`@`+````'C("``H````J,@(`!0```#4R`@`#
M````.S("`!`````_,@(`3P```%`R`@`:````H#("`#<```"[,@(`+0```/,R
M`@`O````(3,"`%,```!1,P(`%@```*4S`@"%````O#,"`"0```!"-`(`00``
M`&<T`@`D````J30"`$<```#.-`(`*P```!8U`@`A````0C4"`",```!D-0(`
M,P```(@U`@`N````O#4"`"X```#K-0(`,````!HV`@`P````2S8"`"T```!\
M-@(`,@```*HV`@`B````W38"`#<`````-P(`%0```#@W`@`@````3C<"`!``
M``!O-P(`?````(`W`@`(````_3<"`'`````&.`(`<@```'<X`@!^````ZC@"
M`"8```!I.0(`7@```)`Y`@`7````[SD"`!8````'.@(`$@```!XZ`@!Z````
M,3H"`!0```"L.@(`'````,$Z`@`:````WCH"`!X```#Y.@(`&0```!@[`@!/
M````,CL"`!(```"".P(`&````)4[`@`*````KCL"``4```"Y.P(`!@```+\[
M`@`(````QCL"``4```#/.P(`%@```-4[`@`7````[#L"`!8````$/`(`(0``
M`!L\`@`0````/3P"``X```!./`(`!````%T\`@`)````8CP"``\```!L/`(`
M!P```'P\`@`&````A#P"`!H```"+/`(`"0```*8\`@`,````L#P"`!````"]
M/`(`!P```,X\`@`+````UCP"`!````#B/`(`"P```/,\`@`:````_SP"``D`
M```:/0(`%0```"0]`@`0````.CT"``H```!+/0(`!0```%8]`@`+````7#T"
M``4```!H/0(`!@```&X]`@`%````=3T"``<```![/0(`#````(,]`@`;````
MD#T"``(```"L/0(`!````*\]`@`(````M#T"``L```"]/0(`!P```,D]`@`S
M````T3T"``0````%/@(`#`````H^`@`.````%SX"`!`````F/@(`%@```#<^
M`@`.````3CX"``L```!=/@(`!@```&D^`@`(````<#X"`!$```!Y/@(`$@``
M`(L^`@`'````GCX"`!````"F/@(`-P```+<^`@`L````[SX"``D````</P(`
M"````"8_`@`*````+S\"`!(````Z/P(`!0```$T_`@`"````4S\"``L```!6
M/P(``0`````````,`0``:`0``#8!````````````````````````!04`````
M``!I!```PP(```4'``!:`@```````$<&````````D`<``!,!``#8`@``````
M`"@&```%`P``O00``+<'``#Z``````````````#`!0``B0$```````!X!```
M``````````#C````,@8```````!4`0``PP8``.X#``#3`P```````%0"``":
M!P````````,"``!_`0``P00````````(!P``NP````````!O`0``\@,`````
M``"N!P``G`,``%L#`````````````#L%``#W`P``=`4``'\#``"'`0``````
M`"X```!S`0``+04```````".`@``-00``.`&````````3`4```````#I`P``
MMP,``&,!``!P`````````(8`````````L`(``"T'``"N!```?`$``!X%```C
M`@``0@8````````7`0``S08``!0#``#6!0`````````````]!@``[00``)@&
M``````````````T$```0!@``<`<``,0!`````````````-(&``"@!@```0$`
M`$`%```I!@``=`$``&T$``#*`P``000``!L#``````````````````#8!```
M>````.X&``!;`0``!`4``/D%``"'!0``W@$``%@$``#+`@```````%8'````
M`````````!\%```,`P``OP(``#\!````````<@<```````"^`P``0```````
M``"'!@```P4```,$```Q````R`0````````&`@``H@4```````"X!0``%0,`
M``L#``"G!P``(P,``*8%````````L00``"`'``"O`P``00$`````````````
M`````"X$``#J`0``[`8``#H&``#V!0```````)\#```H`@``208``$P$```;
M`@``W0$``.P`````````0P4```````"9!```K08``)``````````Y0``````
M``"<!@``\0$``#`'```P````@00````````@````-0<`````````!```````
M``````#9!`````<``%0%``!V!P```````!`"``#'`P``<`$``+H`````````
M50``````````````7P<``'(````````````````&`````````````$<#````
M`````````!L%````````X@0```````!2`0``4`<``"0$````````M00`````
M``!&````PP$``)X#````````B`0``/4%```,!P``F`4``-(%````````?P4`
M`&L```!W`P``R@8```\&``#G!```O08``)L%``#T`@```````#8```#``P``
MNP0```````#%!@``:P<```0$```V`@```````%\$```4`0``^08``(,#```G
M`P```````%X!````````7@<``'$"````````P@8``%L'`````````````#D"
M``#\!```NP4```````````````````````#J`@```````!L'````````6@8`
M``L'```+!0```````+$&``#E`@``P`8``&D&``"[!@``10$``',#````````
M!@$```````````````````<!`````````````"`#``!=!```K`0``'$%``#&
M!0``N08``"$"```W!`````````````!>`P``'0``````````````'@0`````
M``!\````/00``&T%````````2@0``&<`````````B@$``"H"``!L!P``'P<`
M`"4&``"5!```6@$````````R!````@$``(0'```D!@``^````"$&``#D!@``
M`````,D```#(`@````````````#&!@```@(``"<!``!Z`0``$`,``",```"<
M!```;`0``&$$```:!@``K0<``!4'``"Y````U0$``%,%``#H````````````
M``#0`P``(0$```````!"`@```````*0$``````````````H#``!<`P``#P4`
M`(X````H!P````````````"C!```$P```&`'``",!@``9`8``-P%``"2````
M+@,``&D```"=`P``%P(``'\'``!8`P``[0,``%P```"?!0``UP,```````#[
M!@``I`$``(L%``!&`P``6P(``&8"``#.!```1`<```````"?!@``J`8`````
M``!]`0``-P8``-X&``"4`0``90````8'``!9!P```````,<&``!O`P``ZP4`
M`,H$``!S`@``\0,``.`%```Q`@`````````````X!@``CP(```````!@`P``
M``````````````````````````!)````S`,```````"L!0``.0<``'8$``"N
M````X@(``-@!````````/`4``%4$````````U00``#\$``#S!````````+D#
M````````Z04``*X"`````````````"L!``#O!0``2@$``,X````Y`P``Q`,`
M`!P#```=!```3@<``(P%``#+`0``N@<```````#$!0``J04``)T'``#/`P``
MF0````````!]`@``LP,`````````````E@<``#@$`````````````+L!``"2
M`P``JP<``-H$``#[`P```````#L#```]`@```````%4'``#9`0``*@$``,P$
M``!?!0``B`$``*<```"8`0``9P,``$D"```]!0````````0&``#*`@``70,`
M```````K`P``P`$``)4'``!=`0```````(`&````````/P,``+X$``!%````
MX@,```L"````````FP(```````!Y`0``V0(``*D&``")``````````````"&
M`@```````(L#```O````LP8``-````"4!@``````````````````4P,``/@$
M```)`0``SP$```````!(!```3P,``"@$````````.````/\!``"C`P``<0,`
M`$0!``!R`0```````%T%``"3````6P````````"Z`P``4P8``+\$``#9`P``
MG@4``+8"``",`P``>0```-H%````````$00```````!+`@``F`,`````````
M````O@$``'$$``"\`P``2@(``!`$``"6!```T04``#D%````````M`,`````
M``!6````<`4``(T"````````^0$``&D#```J!@``A@4``.(`````````*@0`
M`&($``!]`P``S0(``,("``#!`0``'@8``"4'``"/!```(P0``$X$```S`P``
M`````&P```"1!```$@8``/H#```L!```'P(``*(!``#9!@````````````#I
M`````````!@!``".!`````````````!?`@``OP$``)T$``#L`@``@@$``#@'
M```D!P``^P$``*P'```(````]P4``$`!````````^P```"(!``#S````B00`
M``````"/!P``H`<``-T```!8!P``E```````````````OP8``&\'````````
M!08`````````````0`,``'<%``!`!P``4````'L$``!G!0```````+X```!^
M!P``@@8````#````````WP8``&D%````````1`8``(P$```'`P```````/@#
M``!E!````````&````!B````.`,``$4$``!-!P``?`4``*\%````````````
M`$P"```Q!````````&T&``";!@```````%4#``!D`@``Q`(``+4%````````
M````````````````^@8```L`````````)@4``(@`````````7P,``/`!````
M````*````.L`````````/@(``"D!``!/!@```````)P```"*`@``I@8``+H"
M``!0!0```````/8&``"#!````````!H````7`P```````%P!``!<!P``/P``
M`%L$``!)`0``<P0````````2!0``,@4``#,$``"L`@``E0,``$0%```R`@``
MR04``'4#``#2!```Q0```%4%````````?00``,H%``"O!`````````````#^
M!```9P<````````\!P``Y`4```H%```^````S0```%<$````````!@0``%4&
M````````H0```$T#``#%!```6`8``/P%```/`P``&0```#0$``"8!P``````
M`````````````````($"``#'`0``W`,``(4!``#K!@``2`8``(P```#'!```
M`````$8%````````<@8``/\%````````:@0``.<"````````4`(``&("``#&
M!```,@$``#P"````````(`4```````#A!0``D`0``(L&``#7!```80,``%0`
M```A`P``1@(``)P%``#@`0``1@0``&4"``".`P``J@(``%,"````````-@4`
M`````````````````!(!``#F!0```````/<$``#"`P``6`4``(`````U`0``
M*`4``+0&``!Y!@``L@```'0#```V`P``?`<``,<"``!^!0``6P8````````@
M!@``L`8```H!````````<`0``*4#```P!0``J0<``,8!``#S!0```````$\`
M```I`P``4P$``$H&``````````````````";`0``;@8``$<!``#8!0``O04`
M``T"````````.P<``+<%```P!@```````(`$````````308`````````````
M`````.,%``!#`@```@```)D'```'`@``]@,``'<!``"$`@``!`<```````"E
M`````````%$'``!C`P```````(8$``"2`0``+P(```````#*`0``!P0``$@!
M``#G`0``S`$```````"#!0``'`0``,X%```<````L@4`````````````%`(`
M`+0!``#S`P```````%P$```/````/P8````````^!0````````````#6`0``
MD@8``$@```"S`0```````+8$````````1P``````````````6`$```````#Z
M!0```````#,&``#S!@``K`8``)(%```Q`0``$@,``'4"``#;!0```````"X%
M```S!P``R`,````````O!P``-P$``&,$`````````````!<```"N`P``0@4`
M``````"C!0``;`4``%8&````````]@````4```!<!0``P08`````````````
M@`4``&,```#4!@```````*<!````````B@4``.8!``#P`@``L0(``)`&``"$
M`0``7@8``!$&``#.`P``&@4````````E`@``;P4``,,#``!(!0``!0$``%("
M`````````````),'```\!@``6@0``$8!``!Z!0``AP<```````#$!```H0<`
M`(,&``!?`0``T0$``"<```"N!@``G@(````````!`@``YP,``)X&``!Q!P``
MU`4``"<$``#^`P``"@```&@#```#!@``>@0``"H#``"W!@``R08```````#H
M`P``:`4```````#O`@``"0```"4!``#0!@``^00``#\"`````````````.8$
M````````/@0``.D"```G!0``[`0``($#``"]!P``,08```````#+`P``JP$`
M`%(#``#"`0``;`$``"8!````````#P0``%8"```6`````````&\`````````
MY0,``.`#````````G04`````````````#@,```````!>!```SP0``$$&```2
M!```C04``(X%````````Y`$``-P$````````_````$4"``#A!````````&<&
M````````AP(``$H#``!=````L`,````````O!````````!0`````````]```
M````````````@@(``'0$``#P````VP,``)8!``!3`````````&0`````````
MG@```"8#``"K!0``*P<`````````````*`,``+X&```!!````````-`"````
M````Y00``%<!````````*@`````````:!P``=P`````````5`@``[P0``&`%
M``"#````1````#<#``"J!@``=@,``(<$``#3`@``L0```)<!```Z!P``L0,`
M`*0&````````1P<``-,%````````^P(``(4"``!_!```%P<``,@!``!O!@``
MB`,``/8!``!.````;P(``,L%``!``@``^@(``!@"``"2`@``,P(``-H"``!7
M!P``#@$``-L$``!/`@``/@<```````"?`````````*$!````````K@$``(D&
M``"X`0``&@,``.`$``"$!````````&D'``#7!0``804``$($````````V@8`
M`%$$``!,`P````````````")!0``:`8``-4%``#J````N0<``/4#````````
M```````````Q!P``S@$``(T'```)!@```````'H&`````````````!H"``"$
M`P```````,L$``!T!P``@@,``(\!``!2!@``Y`(``&4'```?`P``KP(``(`"
M``!K`0``_0(```$&````````<P4```````!1````YP8``'L"``!^````I@,`
M`*X%``"=`````````$`&``![`P``+P,``-H#````````@P(```@%``"9`@``
M`````-,$```6`P```````)\$``#>`P```````'4&`````````````-0```"V
M`P``9P0``"P'``````````````````"A`P``.@$````````5!```"`8``&H"
M`````````````-(!``#P!0```````*\&``"C`@```````%<"``#?`0``Y08`
M`*0#``"<!P````````,```"!!0``S0,``%D```#Z`0``+0(```````!#!@``
M!@8``!X```#F`@``W08```````"T!P``=`````P$``#T!```808``!L`````
M````U`$``+H&``"]`0```````,P"````````%`8``"L&``"#`0``E@8``'X!
M````````J0,``"L$``#6````J@```"H'``"C````#@(``$X!``""!0``-@8`
M`&@!``"8`@```````'X"``!!!0````````<%``">!```30$``'\"```V!```
M,P$``)0"```$`0```````.L$``#?`@```````),"`````````@0`````````
M````A@$`````````````!0(``-P"````````?P```*P#``"[`P``&`0``%\&
M``#7!@``?@8``$\!```+!```JP8``',```!F!`````````<&``!H````'`4`
M````````````M@8``%T'``!3!```>@,``!P&```Q!0``V04``)<```#7`@``
M4@```)<"`````````````%<#``!'!0``3@,`````````````[08``&0#```L
M`@``ZP$``'8&```A!0``!@4``.T```#;````````````````````#P$``,P%
M````````!P<``&,&`````````````+4````1!P``L@$```````#1!```MP0`
M``P%``!X!P``I00```````#)`0``.08``.<%````````3@4``-<```#6`P``
M\`8``/D````-`0``,`(```````"5!@``D0$``+8'``"1!@``-P(``)<&``#W
M`0``7@4``(X&```L`P```````%`&``#"!0``(@,``.\#``#J!```(0<``#0`
M``!D!0``!`````H&````````?P8``*T"`````````````"H%``"Y!```C08`
M`(T#``"!!P``V`,``%D"````````3````(`#``#W````M`0``*($``!+!0``
MN````.(&`````````````$(`````````JP,``"<"``````````````````"P
M!````````#0"```M!```"`(```````#V`@``304````````<!P``Q`8`````
M``!K!@``4@0``%H'`````````````*@`````````50(``(@%````````````
M`.D!`````````````+<"``#5!@```````-("````````-@<``((```#5`P``
M``````````"H`0```````)H!```[`0``%@8``#P```!M`0``S@(``,<%````
M````"`$``*<$``":`@``2`<``%$"``""!P``L04``&`$```.!```>@<`````
M``"-`0``5@0``!@&``#?!```>0,``$P&```9`0``-P<``"$$```0!0``````
M``````#-!```604``&D"``"I`@``/@8``-T#``!#````Z`4``%$#``""!```
M`````,D$````````W@0``'("`````````````&,"```U````1P0```````!6
M`P```````-$&``!#`0````````````#<`0``HP<```````!`!```\`,``*\!
M``!Y!0``H0(``$H%````````]P8``,T!``#K`@``9@<```````!-````A0,`
M`$H'`````````````&8#``#^`````````!4!``"V`0``+0$`````````````
M)0,``!T%```=`@``_04``/4!``````````````````"3`P``:@4````````L
M`````````-$`````````/`$``#H``````````````$4&````````.@,``$H`
M```4!0``````````````!0```````-4```"4!0``:P(``"P%```D`P``6@4`
M``4$```@`0``N0$``-$#```1````%04``,$%```F`@``(`0```````"D`@``
MY@8```````!A`0``-P```.4%``!6!0``10<``'P#````````/P<```````!+
M!@``A`8``$$```!0`P``'`(``'(#``"S!P``NP(``/`$```9!P``````````
M```"!@``B0,```````"%!@``I`4``)H$````````)@0``)D!``"I`0``````
M`!\$```Q`P```````'`&``#_!```HP8``+````#^`0````````````!8````
M\@8``'D$````````D`$``+4&````````G@<`````````````.P8``#('```D
M!0```04``%@"````````]P(```````"X!````````'P"```0````````````
M````````H@<```````#U``````````````#U`@``)@8```````!K!```4@4`
M`,$#````````]`,````````&````8@$`````````````4`0``(L!``"\````
M3P0`````````````DP4``.,"```U!@```````)@```!3!P``^0(``!T&``!/
M!P``>P<``&H'``![`0```````*T!```I!```\@$``,4#```#`P``````````
M``#N!0``$P4``'8!``!.!@``J@0`````````````"@<``!L&``#O````O0(`
M`'P&````````8`$`````````````"`,``'T'```/!P```````)($``#J!0``
MQ0(``````````````````$8&``"0!0``B@,``#\%``!Z````=04``"0"``!+
M!P```````.4!``#[!0``AP```$T$``"?!P``+P$```````#M`0```````*T%
M``"I````/@$``+\```#I!@``(0`````````1!0```````&X%````````M@4`
M`!H$```(!`````````````"H`@``CP,````````3!P``X0,```````!I`0``
MJ@<``(4'````````=P(``/("```L!@``1`,```````#M!0``A04```P&````
M````M0(``````````````````&4#``!N!P``V````-\%``#+````Z@,```(%
M``"V````,P4``"D%``"M!```_0,``+@&``"Z!0```````+P&```Y````+0``
M`)@$```E````C0```.$!``!]!0``)@```%D$``!>`@``MP$``'4`````````
M]`8``'<$```B`@````$``#4%``#_!@``"0,``*P!```2`@```````"8'``"H
M`P``%P0``#X#``"E`@``&`<``#`#````````[`4``*("````````O0,``#(#
M```;`0``^`(```````#/!0``E0```,`````E!0``.`4``!8'``#-!0``'P8`
M`#L$``"<`0```````'H"``#X`0``I@````X'```C!P``:`<``"0!````````
M`````#4"``#0!0``8P4```````!1!0``2P0```0"``"K`@``-P4```````"9
M`P``BP(``$(#``"\!0```````/P!``!Q!@````````('``#/!@``F@4``/P"
M``#A````H00``)H`````````K0,``+4!```6!````````'T&``")`@``VP(`
M`'@%````````90$```````"Z`0``O`<``+($``#C!@```````(`!````````
M+08``%<&```-!P``;0,``.X``````````````!8"``#Q!@``BP```*0'```D
M````.@(``#0%````````$P8``(P"```"`P``$P(``%D!```)!P``=@(``!`!
M`````````````,,`````````=P<```````".`0```````$\%```\!```904`
M````````````<P8``-P```!L`P``Z`(``$@#``#*`````````-L&````````
MH08``$L#``!%!0``SP(``%X`````````;0(``*`%`````````````$,#``!F
M!@``9`<``'$!``#&````IP8``$D$``"7!0```````"($````````````````
M``"&!@``XP0`````````````-`<```````"1!0``"P8``$D#````````````
M`$D%```;!```1`(``/T!````````G`(````````>`@``[`,```````"Q`0``
MA0```/@%``![````D0````````!U!```\0(``*8$````````'P$``,P&```C
M!@``WP,``!4```!F`0``6P4``#P#```[`@``Q@(``)$'````````;0<``",!
M``!Y`@````````````#O!@``_@8``($&`````````````,@&``"H!0``````
M`-8&````````D0(``%D#````````P0(``#4#`````````````&(%``#?````
MZ`8``,4!``#S`0``=`8``%0'``"$`````````#`$``!#!P``/0$`````````
M````-`,``/,"``#V!```F@,``)4%``#O`0``P@0``%D&```9`@``_0```.0$
M````````908``"<&``"S!```\@4``#T```"+!P``;P0``&H&``#]!@``````
M`#0!``"K````*0`````````-`P``I@(``)<#``";!P``U0(```````"0`@``
M`````"L"```P`0``C@<``%H#``"P`0```````'`"``"#!P``.`$``!T'```9
M!```U@(``%0#``"6!0``^P0``'<&``!X`P``_@(``.(%``!+`0```````)$#
M``"S````80````T%``#1`@``DP0``)\!``"3`0``0P0`````````````&08`
M`'$```"(`@``"00``*T`````````M`(````"``!<`@```````-,&```:`0``
M4@<``&P"``"X!P```````)<'```I`@``#`(``%\```#X!@``H`,``.X$```*
M`@``A@<``%T&```4!```*0<``'@&``!U!P```````/X%````````+P8`````
M``!+````B@```!T#``"`!P``V@```*(&``````````````````#B`0``^0,`
M`+$'``#U!@``+@8``+X"````````N04``%T"``#C`P```````$(!``!B!@``
M`````$X"``"$!0``>`$```````"(!P````````````!P`P``/0,`````````
M````;@,``!@%``#R`````````+P!``"!````U`0`````````````A00`````
M``!D!```+P4``,0`````````P`0``,@`````````#P(`````````````````
M```````M`P``L@(``.L#``##!```AP,``.X!``#3`0``&`,``(H'``"H!```
M``````X````T!@``\0```*<%````````]00```````!$!```C00`````````
M`````````)D%``!0`0``J@$``,X&``#)`@``M0<```,'``!1`0``+@$`````
M````````I08``&L%``!R!0```````*@'``"/````E@(``*L$````````````
M`%P&`````````````$8'``"\`@``8`8``*,!``!X`@``L@<``&('``#Q!0``
M`````&T```#8!@``G0$``.X"``#>````Q04``/\````5!@``?0```"`"```2
M!P``5P4``````````````````'4!````````)P<``&$'``"6`P``I@<``"X'
M``!6`0```````-,```"@````Z`$```H$``#J!@````````````!N`0``J@,`
M`(H$``"[!P``6@````````"B`````````$T"``![!@``UP$```````";````
MT@```&H````S````C`$``(D'``"^!0``20<``(H&```<`0``K````*D$``"]
M````H@,``!@`````````=`(``%0&``"E!0``LP4``)<$``!,`0```````+P$
M```B!P``CP4``/0%`````````````&X`````````.@0``*0```"5`@``PP4`
M`'($````````A@,``/($````````$@```*4'```#`0```````-L!````````
M9P$``$$"````````N@0`````````````F08```````">`0```````.<````H
M`0``$P0``)`#```1`P``+`$``)0#``#A!@```````.@$````````P@```+0`
M`````````````+,"```Z!0``8`(``(L$````````'@<``.$"``!A`@``!@,`
M```````,`````````-T"``#D````(@8``'8```#2`P``9`$``!D#```'````
M``````````#_`@``N`,``+`'```>`0```````'D'``#&`P``IP(``#(```#>
M`@````````0#```Y`0``W00``)T"``!L!@``$0(``+(#``#L`0``_`,``&<"
M``#:`0``W04``)H&````````1P(``%$&``"_`P``Y@,````````Y!```N`(`
M`(P'``"F`0``T`$``-`$```B````_00``+0%``#\!@``KP````$'``"O!P``
MP0```+`%``#C`0``U`,```````#4`@`````````````X`@``M0,``/\#````
M````+@(```````!J`0``[0(````````4!P```````!8%``"Y`@```````&X$
M``"4!```(@4``$$#````````H`$``*`"``"@!`````````````"2!P``9@4`
M`*4!```[````@0$```````!J`P``(P4``&,'````````L@8```````#@`@``
M`0,``.8`````````*P4``$$'````````P`(```````!N`@```````$4#``!\
M!```E`<``!$!```6`0``'0$``"L````)`@``GP(```````!H`@```````$@"
M``!B`P``<P<``,P```"/!@``%P4```D%``"G`P``FP0````````+`0``$P,`
M`%<`````````'@,``'8%``#(!0``'P```),&``"6````QP```-D```!4!```
M:P,```````#6!```%P8```X&``#T`0``#0````X%````````9@````````#I
M!`````````````!^!```?@,``-X%````````H04````````-!@``E0$``)L#
M````````W`8``'L%``#)`P``J@4```````#D`P```````!D%``"=!@``$`<`
M`.`````]!P```````+<```#+!@``^@0``/$$``!"!P``3`<```````"(!@``
MOP4``%4!``#/````)00````@("U-+"`M+6UE<W-A9V4]34534T%'12`@57-E
M('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O
M;F5S+@`@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE
M('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&\*("`@("`@("`@("`@("`@
M("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A(&1I9F9E<F5N
M="!B<F%N8V@@=&\*("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R
M871E9"!C;VUP96YD:75M+@`@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@<&%T
M:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L9"!B
M90H@("`@("`@("`@("`@("`@("`@('5S960N`"`@+6,L("TM8V]M<&5N9&EU
M;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N
M9&EU;2!F:6QE"B`@("`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F
M('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4*("`@("`@
M("`@("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2X`("`M8RP@
M+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I
M;G-T96%D(&]F('1H92!D969A=6QT"B`@("`@("`@("`@("`@("`@("`@("`@
M("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R
M>2DN`"`@+60L("TM9&5B=6<@("`@("`@4VAO=R!E<G)O<B!M97-S86=E<R!F
M<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RX`("`M9"P@+2UD:7)E8W1O<GD]
M1$E2("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN`"`@
M+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`("`M
M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY('1H:7,@;&]C86QE+@`@
M("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+@`@("UL
M+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0VQE
M86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@
M("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R86YS;&%T:6]N<R!O
M;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-
M3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@4$\@
M9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM
M;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5
M<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L
M93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO
M<F1E*2!M;V1U;&4N`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG="!M
M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP96YD:75M+@`@("UN
M+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2X`
M("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A;G-L871I;VX@<W1A
M=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N`"`@+70L("TM=&5S="`@("`@("`@
M4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U;B!A;GET
M:&EN9RX`("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P(&9R
M;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+@`@(&-O;6UI
M="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V97(N
M`"`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE($-64R!S
M97)V97(N`"`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU;2!F
M:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE"B`@("`@("`@("`@
M("`@8W5R<F5N="!C;VUP96YD:75M+@`@(&5X=')A8W0@("`@($=E;F5R871E
M(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RX`("!H96QP("`@("`@("!3:&]W
M('1H:7,@:&5L<"!M97-S86=E+@`@(&EN:70@("`@("`@($-R96%T92!O;F4@
M;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG.B!4
M:&ES"B`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@
M9FEL97,@;V8@=&AI<R!L;V-A;&4N`"`@;6%K92`@("`@("`@0G5I;&0@8FEN
M87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!03R!F:6QE<RX`("!M
M86ME+6AE;'`@("!-87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F
M:6QE(&)E:6YG('5P+71O+61A=&4@86YD"B`@("`@("`@("`@("`@<')E<&%R
M92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T92UH
M96QP+B!9;W4*("`@("`@("`@("`@("!S:&]U;&0@;VYL>2!R=6X@;6%K92UH
M96QP($%&5$52('5P9&%T92UH96QP(&%N9"!R979I<VEN9R!T:&4*("`@("`@
M("`@("`@("!H96QP(&9I;&4N`"`@;65R9V4@("`@("`@365R9V4@=&AE(&-U
M<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E(&9I
M;&4N`"`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E<75E
M;G0N`"`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N9V5D
M(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<`H@("`@("`@("`@
M("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@;VYE
M<RX`("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I
M`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M
M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E9"!B>71E
M<R!W<FET=&5N+@`E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD
M871E`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A
M=&EO;@`E<R!#;VYF:6=U<F%T:6]N`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4VEG
M;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N
M`"5S(&%T("5S("5S`"5S(&AA<R!C86YC96QL960@)7,N`"5S(&AA<R!R97!L
M:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L:65D('1O
M('1H92!I;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N="!Y;W4@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N+@`E<R!I<R!N;W0@=W)I=&%B;&4N`"5S(&ES(')E
M<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!N;W0@9F]U;F0N
M(%)U;B`G=')A;G-L871I;VX@97AT<F%C="<@9FER<W0N`"5S(')E<75E<W1S
M('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R
M('!R97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@=&\@
M861D('1O("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N
M`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@
M86)O=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G
M<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"<E<R<@:7,@;F]T(&$@
M=F%L:60@8VAO:6-E+@`G)7,G(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(
M;W)D92!296=I<W1R>2X`)R5S)R!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`
M)R5S)R!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"<E<R<@=V%S
M(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"<E<R<@=V%S(&YO
M="!C<F5A=&5D.B`E<RX`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S
M`#QG971T97AT/B!T86<@;F]T(&-L;W-E9"!I;B!F:6QE("5S+@I/<&5N:6YG
M('1A9R!F;W5N9"!I;B!L:6YE("5D+@!!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$%-(%)A:6X`04T@4VAO=V5R<P!!32]030!!
M4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B
M<VUI9&1L90!!8V-E<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN
M`$%C8V]U;G1I;F<`06-T:6]N<P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#
M:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.
M97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`G)7,G`$%D9"!A
M(&-H:6QD('!E<FUI<W-I;VX@=&\@)R5S)P!!9&0@82!N97<@=7-E<CH`061D
M(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N
M9&%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O
M;VL`061D('5S97(`061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N
M`$%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W
M+@!!9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R
M871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!
M;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!
M;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G
M:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E
M<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L
M871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL
M80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A
M;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI
M8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V
M90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I
M>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B
M80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G
M:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T86-H960@
M:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S
M96YT`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E;F1E97,`
M071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C
M:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT
M:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!!
M>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@
M0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E
M<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<F)A9&]S`$)A<F4`0F%S92!G<F%P:&EC<R!D:7)E8W1O
M<GD@)R5S)R!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"
M96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S
M(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";&]C:R!S96QE8W1I;VX`0F]L9`!";VQI=FEA`$)O
M;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N
M:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E
M="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R
M>0!"<G5N96D@1&%R=7-S86QA;0!"=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D
M=6QE("5S+BXN`$)U:6QD:6YG(&QO8V%L92`E<RXN+B``0G5L9V%R:6$`0G5L
M;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD
M87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A
M`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F
M:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R
M+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E
M+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O
M9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H
M(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N
M9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E
M<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C
M:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E
M;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC
M:65S`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@66]U<B!087-S
M=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`
M0VAA;F=E('EO=7(@<&%S<W=O<F0`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I
M<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO
M;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,
M:6YK+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#
M:&]O<V4@86X@86-T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#
M:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O
M=6YD+@!#;&5A;FEN9R!U<"!03R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN`$-L
M96%N:6YG('5P(&QO8V%L92`E<RXN+B``0VQE87(`0VQE87(@35-/9F9I8V4@
M=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R
M(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#
M;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M
M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z
M`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#
M;VUM86YD(&]P=&EO;G,Z`$-O;6UA;F1S.@!#;VUM96YT`$-O;6UI='1I;F<Z
M`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S
M92!-97-S86=E("@E<RD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&YE961S('5P9&%T:6YG
M+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&YE=R!P
M87-S=V]R9#H`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC
M(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z
M(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@
M4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`G)7,G`$-O;G1I;G5E`$-O;VL@
M27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W!Y:6YG("5S
M('1O("5S`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H
M96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`G
M)7,G('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-O<'D@)7,@=&\@)7,`0V]U
M;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&-R96%T92!L;V-A;&4@9&ER96-T;W)Y(&9O<B!L;V-A;&4@)7,Z`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N`$-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N`$-O=6QD(&YO="!M:V1I<B`G
M)7,G+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@)R5S
M)R!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N`$-O
M=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D
M(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D
M971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`
M0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D
M<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I
M97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@
M<FUD:7(@)R5S)RX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5R871I;VX@)7,N`$-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G+@!#;W5L9"!N;W0@<V5A
M<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`G)7,G+@!#
M;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B`G)7,G.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L
M9&XG="!G:79E('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B`G)7,G.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R
M<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E
M871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A
M<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%!H87-E`$-U<G)E;G0@
M5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C
M;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S
M`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y
M<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$
M86EL>0!$871A`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D
M`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$
M96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%!E<FUI<W-I;VYS
M`$1E9F%U;'0@<&5R;6ES<VEO;G,`1&5F:6YI=&EO;G,`1&5L96=A=&4@<&]S
M:71I;VX`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E
M<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L
M;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G`$1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L
M971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T
M:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`1&5L:79E<GD@=&EM90!$
M96YM87)K`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S
M>2!I;F9O<FUA=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO
M;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L
M;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E
M=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R
M:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L
M87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI
M8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W
M;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO
M8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N
M<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET('!E<FUI<W-I;VYS(&9O<B`G
M)7,G`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M
M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T
M8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0`
M16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1R:65S
M.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E9"!C:&%N9V5D
M+"`E9"!U;FMN;W=N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`
M17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('5P9&%T:6YG('!A<W-W
M;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I
M;F<@)R5S)RX`17)R;W(Z(`!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O
M<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@
M<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L
M9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%
M>&5C=71I;F<Z`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`
M17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I
M<F%T:6]N($1A=&4`17AP;VYE;G0`17AT<F%C=&EN9R!F<F]M("5S+BXN(`!&
M1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O
M(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M
M;W9E('1O("(E<R(N`$9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@.B``
M1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD
M<P!&871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@
M;&EK93H@`$9E=R!3:&]W97)S`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I
M;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R
M=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_
M`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S
M(#(`1F]R=6US`$9O<G=A<F1S`$9O=6YD(&%P<&QI8V%T:6]N<SH@)7,`1F]U
M;F0@9&ER96-T;W)I97,Z`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R
M;W!O;&ET86X`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O0G5S>2!297!L
M>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS
M90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I
M;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=7IZ>0!'86)O;@!'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96YE<F%T:6YG('-T871U
M<R!F;W(@;6]D=6QE("5S+BXN`$=E;W)G:6$`1V5R;6%N>0!'971O<'0@17)R
M;W(Z(`!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O
M9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW
M*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<"!P97)M:7-S:6]N<P!'
M<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S
M="!097)M:7-S:6]N<P!'=65S="!P97)M:7-S:6]N<P!'=65S=&)O;VL`1W5I
M;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A(`$A434P`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(
M96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E
M=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O
M<@!(96QP97(`2&5L<&5R(&%P<&QI8V%T:6]N('1O(&-R96%T92!A;F0@;6%I
M;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@2&]R9&4*9G)A;65W;W)K(&%N
M9"!I=',@87!P;&EC871I;VYS+@I&;W(@86X@:6YT<F]D=6-T:6]N(')E860@
M=&AE(&9I;&4@4D5!1$U%(&EN('1H:7,@9&ER96-T;W)Y+@!(96UI<W!H97)E
M`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(:7-T
M;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$AO7VUE`$AO;'D@
M4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO
M;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E('1R86YS
M;&%T:6]N(&=E;F5R871O<@!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@
M9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.
M;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA
M8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(
M;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY('-Y;F-H<F]N:7-E9"`E<R`B)7,B`$AO
M<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H
M92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@
M='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO
M<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA
M;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M
M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@
M)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL
M8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!
M9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N
M<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@
M)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F
M<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`
M26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R
M;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!)
M;F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!)
M;F9O<FUA=&EO;@!);FET:6%L:7II;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@
M0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R
M="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@
M8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O
M<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@
M<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T
M+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN
M=&5G97(`26YT96=E<B!L:7-T`$EN=&5R;F%L($5R<F]R`$EN=F%L:60@06-T
M:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV
M86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN
M=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN
M=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P
M97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N
M=#H@)R5S)P!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A
M9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N
M`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY
M`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I
M`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT
M97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA
M>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@
M0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`
M2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%
M54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@
M475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,
M87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`
M3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA
M;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE
M`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`
M3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG
M:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@
M<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP
M;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`
M3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES
M="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S
M8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG(&QI8G)A<FEE<RXN
M+@!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C
M871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;V=O=70`3&]N9R!T97AT
M`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T
M=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A
M;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`
M36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN
M+@!-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@
M:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA:VEN9R!D:7)E8W1O<GD@)7,`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R
M=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`
M36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE
M971I;F<@0V%N8V5L;&%T:6]N`$UE971I;F<@26YF;W)M871I;VX`365E=&EN
M9R!0<F]P;W-A;`!-965T:6YG(%)E<&QY`$UE971I;F<@57!D871E`$UE971I
M;F<@57!D871E(%)E<75E<W0`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE<F=I;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M
M+BXN(`!-97)G:6YG(&QO8V%L92`E<RXN+B``365R9VEN9R!T:&4@4$\@9FEL
M92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@`$UE<F=I;F<@=')A;G-L
M871I;VX@9F]R(&UO9'5L92`E<RXN+@!-97-S86=E`$UE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A
M9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971H
M;V0@)R5S)R!I<R!N;W0@9&5F:6YE9`!-971R:6,`365X:6-O`$UI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``
M36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO
M8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-
M;V1U;&4`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N
M9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@
M4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD('1H86X@=&AE(&5X<&5C=&5D("5D
M+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3
M=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-
M;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0
M;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!
M9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5E9',@06-T:6]N`$YE<&%L`$YE
M=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@
M55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O
M;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.
M971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-
M;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P
M87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P
M87-S=V]R9#H`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O
M=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(%!A9V4`3F5X
M="!0:&%S90!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`
M3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@
M861D960@8F5L;W<@=&AI<R!L979E;"X`3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]M;6%N9"!S<&5C:69I960N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&5N=')Y('=I=&@@=&AE(&ED
M("<E<R<@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N`$YO(&9I
M;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%L92!S<&5C:69I
M960N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`
M3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F
M9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%14
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($Q$05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@
M3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I
M<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N
M9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D
M+@!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F
M;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.
M;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!087)T
M:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M
M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.
M;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@
M0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S
M970`3F]T('-U<'!O<G1E9"X`3F]T93H@66]U('=I;&P@;F5E9"!T;R!L;V=O
M=70@86YD(&)A8VL@:6X@869T97(@>6]U(&-H86YG92!Y;W5R('!A<W-W;W)D
M(0!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E`$YO
M=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@
M8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@
M9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`
M3V)J96-T($-R96%T;W(`3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,`3V-T
M86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;&0@<&%S<W=O<F0Z`$]M86X`
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F
M;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN
M9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/<'1I;VYS
M(&9O<B`E<P!/<'1I;VYS.@!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R
M9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A
M=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R
M`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N
M871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI
M9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W(%-H;W=E<G,`4$T@5"U3=&]R
M;7,`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN
M96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C
M:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@8VAA;F=E9"$`4&%S<W=O
M<F0@:6YC;W)R96-T`%!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@
M8V]N9FEG=7)E9`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE
M;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R
M9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S
M=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L
M90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I
M;VX`4&5R;6ES<VEO;B`G)7,G(&YO="!D96QE=&5D+@!097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;@!097)M:7-S:6]N<R!F;W(`4&5R<V]N86P@26YF;W)M
M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C
M86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE
M(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T
M96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E
M860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R97!O<G0@86YY
M(&)U9W,@=&\@:3$X;D!L:7-T<RYH;W)D92YO<F<N`%!L96%S92!R979I97<@
M=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N
M(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T(&%N
M(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T
M=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!0<F5S96YT871I;VYS`%!R97-S=7)E`%!R97-S=7)E(&%T
M('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@4&%G90!0<F5V:6]U<R!O
M<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O
M8FQE;2!$97-C<FEP=&EO;@!0<F]B;&5M/P!0<F]J96-T<P!0<F]M<'0@=&5X
M=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T
M;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A
M9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@
M4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A
M9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A
M(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I
M;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UE;6)E<B!T:&4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C
M:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M
M(&UY(&-A;&5N9&%R`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE
M`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S
M97(`4F5M;W9E('5S97(Z("5S`%)E<&QY(%-E;G0N`%)E<&QY('=I=&@@3F]T
M(%-U<'!O<G1E9"!-97-S86=E`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N
M97AT(#(@;6]N=&AS+@!297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN`%)E<&QY.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"`G)7,G(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)R5S
M)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G)7,G(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@4&%R=&EC:7!A;G0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-U;'1S`%)E<W5L=',@*&EN8VQU9&EN9R!(;W)D92DZ
M`%)E<W5L=',Z`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O
M<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I
M=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@
M=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E
M(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`
M4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U,`4U-(`%-50T-%4U,`4U]1
M3"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES
M`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I
M`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L
M;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@
M)R5S)P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`4V-I96YC90!396%R8V@`4V5A
M<F-H($5N9VEN97,`4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E
M<P!396%R8VAI;F<@9V5T=&5X="!B:6YA<FEE<RXN+@!396QE8W0@1FEL97,`
M4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@
M;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D
M9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C
M=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!,871E<W0@26YF;W)M871I;VX`
M4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@
M`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E
M<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<"!U<&=R
M861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`
M4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@
M8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO
M=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI
M='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS
M*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3
M:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@
M06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VMI
M<'!E9"XN+@!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N
M;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L
M:6$`4V]M92!O9B!087-S=V]R9"!M;V1U;&4G<R!C;VYF:6=U<F%T:6]N(&9I
M;&5S(&%R92!M:7-S:6YG.@!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L
M96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@
M<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P
M;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA
M;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!Y96%R`%-T871E
M(&]R(%!R;W9I;F-E`%-T871U<P!3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B``
M4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3
M=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL
M92!;0U-370!3=0!3=6)D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`%-U8FIE
M8W0`4W5B:F5C="!0=6)L:6,@2V5Y($EN9F\`4W5B;6ET`%-U8FUI='1E9"!R
M97%U97-T('1O(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T
M(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N
M`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@)R5S)R!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D
M("<E<R<N`%-U8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L
M;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VX@)7,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6-C
M97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@
M4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U
M;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U
M<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N
M`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER
M:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!4
M86)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N
M`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE
M($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP
M97)A='5R93H@`%1E;7!L871E("<E<R<@;F]T(&9O=6YD+@!496UP;&%T92!!
M9&UI;FES=')A=&EO;@!496YT871I=F5L>2!!8V-E<'0@<F5Q=65S=`!496YT
M871I=F5L>2!!8V-E<'1E9`!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E
M>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O
M<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@)7,@:&5L<"!F:6QE(&9O<B`E<R!D
M;V5S;B=T('EE="!E>&ES="X@0W)E871I;F<@82!N97<@;VYE+@!4:&4@1E10
M(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C86QE;F1A<B!D871A
M(&ES(&EN=F%L:60`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A
M=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T
M86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`5&AE(&5V96YT(&AA<R!B965N(&%D9&5D('1O('EO
M=7(@8V%L96YD87(N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E
M;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG
M(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S
M86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E
M<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9
M;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@
M961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE
M<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI
M:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R
M;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:&5L<"!F:6QE("5S(&1I
M9&XG="!S=&%R="!W:71H(#P_>&UL`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M
M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E
M9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F
M97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A
M=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R
M;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO
M="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F
M="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P
M87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M`%1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY
M`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U
M<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M`%1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F
M=6QL>2!S=&]R960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O
M(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E
M<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E
M<RX`5&AE<F4@9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S
M+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T
M96TN("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H
M92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG("<E<R<Z("5S`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N
M=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E
M=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!O
M<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP
M:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S
M(&9R;VT@=&AE('AM;"!P87)S97(N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI
M<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I;VX@:7,@;F]T
M('EE="!I;7!L96UE;G1E9"X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z
M+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET
M(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L
M>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN
M('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4
M:&ES(&9I;&4@8V]N=')O;',@=&AE(&1E9F%U;'0@<')E9F5R96YC97,@9F]R
M(%!A<W-W;W)D(&UO9'5L92P@86YD(&%L<V\@8V]N=')O;',@=VAI8V@@<')E
M9F5R96YC97,@=7-E<G,@8V%N(&%L=&5R+@!4:&ES(&9I;&4@8V]N=')O;',@
M=&AE('-T>6QE<VAE970@=&AA="!I<R!U<V5D('1O('-E="!C;VQO<G,@86YD
M(&9O;G1S(&EN(&%D9&ET:6]N('1O(&]R(&]V97)R:61I;F<@2&]R9&4@9&5F
M875L=',N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`
M5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E
M('9I<VET("5S`%1H:7,@:7,@=&AE(&UA:6X@4&%S<W=O<F0@;6]D=6QE(&-O
M;F9I9W5R871I;VX@9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD(&]P=&EO
M;G,@9F]R(&%L;"!087-S=V]R9"!M;V1U;&4@<V-R:7!T<RX`5&AI<R!M97-S
M86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R
M('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+@!4:&ES('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD
M(&QI;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T
M960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R
M`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@
M<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`
M5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN
M9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO
M<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&5D`%1R
M86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`
M5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE
M;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y
M;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C
M<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I
M;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O
M)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5
M;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`
M56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='D`56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RX`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E
M;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI
M;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N
M:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I
M`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3
M=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N
M:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO
M=VX@8V]M;6%N9#H@)7,`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O
M('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5
M;G1R86YS;&%T960`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N9&5N
M="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`G)7,G+@!5<&1A=&EN9R`E
M<R!H96QP(&9I;&4@9F]R("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5
M<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@
M;G5M8F5R<P!5<G5G=6%Y`%5S86=E.@!5<V4@0W5R<F5N=#H@)7,`57-E(%-3
M3`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E
M<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I
M;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92X`57-E<B!P97)M:7-S:6]N<P!5<V5R;F%M90!5<V5R;F%M92`G
M)7,G(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R
M<P!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A
M<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!6
M97)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN
M9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)
M4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@
M87,@)7,`5FEE=R!E=F5N=`!6:65W('1A<VL`5FER9VEN($ES;&%N9',L($)R
M:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL
M:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%L;&ES(&%N9"!&
M=71U;F$`5V%R;FEN9P!787)N:6YG.B``5V4`5V5A=&AE<B!&;W)E8V%S=`!7
M96%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3
M:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E
M<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK
M:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7
M:6YD.B``5VES9&]M`%=I<VAL:7-T<P!7;W)K`%=O<FL@061D<F5S<P!7;W)K
M(%!H;VYE`%=R:71I;F<@;F]T('!O<W-I8FQE+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@=&AE(&%V86EL86)L92!U<&=R861E('-C<FEP="!O<B!C;W!Y(&UA;G5A
M;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!7<FET:6YG('5P9&%T960@:&5L
M<"!F:6QE('1O("5S+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L
M=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`
M6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!9
M96UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@
M57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'
M+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E
M('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@8V%N
M)W0@8VAA;F=E('!A<W-W;W)D(&9O<B!U<V5R("5S`%EO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY
M(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P
M;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L
M(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@
M8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@
M5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S
M="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U
M(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9`!9;W4@;75S="!G:79E('EO
M=7(@;VQD('!A<W-W;W)D`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@
M8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L
M96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP
M92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;75S="!V97)I9GD@>6]U<B!N
M97<@<&%S<W=O<F0`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ
M(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P
M<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO;B`K
M(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V
M97)S:6]N(&ES('1O;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA
M=&EV96QY+@I.;W0@86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO
M=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,`66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:`!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O
M<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E
M<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y
M`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U
M;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI
M;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?
M1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN
M`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]0
M97)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P
M97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`86X@97)R;W(@:&%S(&]C
M8W5R960Z`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!D;VYE`&9A:6QE9`!F
M86QL:6YG`&9I;&4`9F]U;F0Z(`!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M`&@Z`&DQ.&X`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O
M<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&-H86YG960`
M;F]T(&9O=6YD`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D
M`&YO=&5P860`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC
M97,`<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!T87-K(&QI<W0`=&AE($AO
M<F1E(%!/(&9I;&4@9F]R('1H92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U
M;FYA;65D`'5P9&%T960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC
M;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C$@4&%S<W=D"E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`R+3`U+3`S(#$T.C`Y+3`S,#`*4$\M4F5V:7-I
M;VXM1&%T93H@,C`P,BTP-2TP,R`Q-#HP.2TP,S`P"DQA<W0M5')A;G-L871O
M<CH@1&%R8VD@06YT;VYI;R!487)T87)I(#QD=&%R=&%R:4!P;W)T;W)I;V=R
M86YD92YC;VTN8G(^"DQA;F=U86=E+51E86TZ(%!O<G1U9W5E<V4M0G)A>FEL
M(#Q,3$!L:2YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#@M8FET"@`@("U-+"`M+6UE<W-A9V4]345.4T%'14T@
M(%5T:6QI>F$@97-T82!M96YS86=E;2!D92!E;G9I;R!A;R!I;G;I<R!D87,@
M<&%D<O5E<RX`("`M82P@+2UA9&0]05)154E63R`@("`@061I8VEO;F$@97-T
M92!A<G%U:79O(%!/(&%O(&-O;7#J;F1I;RX@VG1I;"!P87)A"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EN8VQU:7(@=6T@8V]M<.IN9&EO(&1E('5M82!S
M9>?C;R!D:69E<F5N=&4@;F\*("`@("`@("`@("`@("`@("`@("`@("`@8V]M
M<.IN9&EO(&=E<F%D;RX`("`M8BP@+2UB87-E/2]0051(("!#86UI;FAO(&-O
M;7!L971O(&1O(&1I<F5T\W)I;R!B87-E("A(;W)D92D@<75E(&1E=F5RX2!S
M97(*("`@("`@("`@("`@("`@("`@("!U=&EL:7IA9&\N`"`@+6,L("TM8V]M
M<&5N9&EU;3U!4E%5259/("!-97-C;&$@;F]V87,@=')A9'7G]65S(&$@97-T
M92!A<G%U:79O(&-O;7#J;F1I;PH@("`@("`@("`@("`@("`@("`@("`@("`@
M86\@:6YVZ7,@9&\@<&%D<N-O("AC;VUP96YD:75M+G!O(&YO"B`@("`@("`@
M("`@("`@("`@("`@("`@("!D:7)E=/-R:6\@:&]R9&4O<&\I+@`@("UC+"`M
M+6-O;7!E;F1I=6T]05)154E63R`@571I;&EZ82!E<W1E(&%R<75I=F\@8V]M
M<.IN9&EO(&%O(&EN=NES(&1O('!A9'+C;PH@("`@("`@("`@("`@("`@("`@
M("`@("`@*&-O;7!E;F1I=6TN<&\@;F\@9&ER973S<FEO(&AO<F1E+W!O*2X`
M("`M9"P@+2UD96)U9R`@("`@("!%>&EB92!A<R!M96YS86=E;G,@9&4@97)R
M;R!D;W,@8FENX7)I;W,@97AE8W5T861O<RX`("`M9"P@+2UD:7)E8W1O<GD]
M1$E2("`@0W)I82!O(&-O;7#J;F1I;R!N97-T92!D:7)E=/-R:6\N`"`@+6@L
M("TM:&5L<"`@("`@("`@17AI8F4@97-T82!M96YS86=E;2!D92!A:G5D82X`
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5T:6QI>F$@<V]M96YT92!E<W1A
M(&QO8V%L:7IAY^-O+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@571I;&EZ
M82!E<W1A(&QO8V%L:7IAY^-O+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5
M=&EL:7IA(&5S=&$@;&]C86QI>F'GXV\N`"`@+6TL("TM;6]D=6QE/4W31%5,
M3R`@("!#;VUP:6QA(&%R<75I=F]S($U/('-O;65N=&4@<&%R82!E<W1E(&WS
M9'5L;R`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@3&EM<&$@
M87)Q=6EV;W,@4$\@<V]M96YT92!P87)A(&5S=&4@;?-D=6QO("A(;W)D92DN
M`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!%;G9I82!T<F%D=>?U97,@<V]M
M96YT92!P87)A(&5S=&4@;?-D=6QO("A(;W)D92DN`"`@+6TL("TM;6]D=6QE
M/4W31%5,3R`@("!#<FEA('5M(&%R<75I=F\@4$\@<V]M96YT92!P87)A(&5S
M=&4@;?-D=6QO("A(;W)D92DN`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!-
M97-C;&$@87)Q=6EV;W,@4$\@<V]M96YT92!P87)A(&5S=&4@;?-D=6QO("A(
M;W)D92DN`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!!='5A;&EZ82!A<G%U
M:79O<R!D92!A:G5D82!S;VUE;G1E('!A<F$@97-T92!M\V1U;&\@*$AO<F1E
M*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($%T=6%L:7IA('-O;65N=&4@
M97-T92!M\V1U;&\@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/("!'
M97)A(&%R<75I=F\@4$]4('-O;65N=&4@<&%R82!E<W1E(&WS9'5L;R`H2&]R
M9&4I+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@3N-O(&UE<V-L82!N;W9A
M<R!T<F%D=>?U97,@86\@8V]M<.IN9&EO+@`@("UN+"`M+6YO+6-O;7!E;F1I
M=6T@("`@3N-O('5T:6QI>F$@=6T@8V]M<.IN9&EO+@`@("US+"`M+7-T871I
M<W1I8W,@("`@("`@4V%L=F$@97-T873M<W1I8V%S(&1E('1R861UY_5E<R!E
M;2!U;2!A<G%U:79O(&QO8V%L+@`@("UT+"`M+71E<W0@("`@("`@(%-I;75L
M82!A(&5X96-UY^-O(&1O<R!C;VUA;F1O<RX`("!C;&5A;G5P("`@("!,:6UP
M82!O<R!R96=I<W1R;W,@;N-O('1R861U>FED;W,@92!O8G-O;&5T;W,@9&]S
M(&%R<75I=F]S(%!/("X`("!C;VUM:70@("`@("!%;G9I82!T<F%D=>?U97,@
M<&%R82!O('-E<G9I9&]R($-64RX`("!C;VUM:70M:&5L<"!%;G9I82!A<G%U
M:79O<R!D92!A:G5D82!P87)A(&\@<V5R=FED;W(@0U93+@`@(&-O;7!E;F1I
M=6T@(%)E8V]M<&EL82!O(&%R<75I=F\@8V]M<.IN9&EO+B!!=&5NY^-O.B!)
M<W1O('-O8G)E<V-R979E(&\*("`@("`@("`@("`@("!C;VUPZFYD:6\@871U
M86PN`"`@97AT<F%C="`@("`@1V5R82!A<G%U:79O(%!/(&UO9&5L;R`H+G!O
M="DN`"`@:&5L<"`@("`@("`@17AI8F4@97-T82!M96YS86=E;2!D92!A:G5D
M82X`("!I;FET("`@("`@("!#<FEA('5M(&]U(&UA:7,@87)Q=6EV;W,@4$\@
M<&%R82!A(&YO=F$@;&]C86QI>F'GXV\N($%T96[GXV\Z($ES=&\*("`@("`@
M("`@("`@("!S;V)R97-C<F5V92!O<R!A<G%U:79O<R!03R!E>&ES=&5N=&5S
M('!A<F$@97-T82!L;V-A;&EZ8>?C;RX`("!M86ME("`@("`@("!#;VUP:6QA
M(&]S(&%R<75I=F]S(&)I;N%R:6]S($U/(&$@<&%R=&ER(&1O<R!A<G%U:79O
M<R!03R!E<W!E8VEF:6-A9&]S+@`@(&UA:V4M:&5L<"`@($UA<F-A('1O9&]S
M(&]S(')E9VES=')O<R!D;R!A<G%U:79O(%A-3"!D92!A:G5D82!C;VUO(&%T
M=6%L:7IA9&]S(&4*("`@("`@("`@("`@("!P<F5P87)A(&\@87)Q=6EV;R!P
M87)A(&$@<'+S>&EM82!E>&5C=>?C;R!D92`B=7!D871E+6AE;'`B+B!6;V/J
M"B`@("`@("`@("`@("`@9&5V97)I82!S;VUE;G1E(&5X96-U=&%R(")M86ME
M+6AE;'`B($%0TU,@(G5P9&%T92UH96QP(B!E(')E=FES87(@;PH@("`@("`@
M("`@("`@(&%R<75I=F\@9&4@86IU9&$N`"`@;65R9V4@("`@("`@365S8VQA
M(&\@87)Q=6EV;R!03R!A='5A;"!A;R!A<G%U:79O(%!/(&UO9&5L;RX`("!U
M<&1A=&4@("`@("!%>&5C=71A(")E>'1R86-T(B!E(")M97)G92)N82!S97%U
M96YC:6%L;65N=&4N`"`@=7!D871E+6AE;'`@17AT<F%I('1O9&]S(&]S(')E
M9VES=')O<R!N;W9O<R!E(&%L=&5R861O<R!D;R!A<G%U:79O(%A-3"!D92!A
M:G5D82!E;2!);F=LZG,*("`@("`@("`@("`@("!E(&]S(&UE<V-L82!A;W,@
M97AI<W1E;G1E<RX`("8C,34Q.R`E<R!E<W3A('!R;VYT;R!P87)A(&5X96-U
M=&%R(&%S(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&-H96-A9&%S(&%B86EX
M;RX`("@E<R!D:6%S(&%T<N%S*0`@*%1E8VQA(&1E($%T86QH;R`E<RD`("AE
M;2`E<R!D:6%S*0`@*&AO:F4I`"`H86UA;FCC*0`@*&]N=&5M*0`@82``)60@
M)7,@92`E<P`E9"!B>71E<R!E<V-R:71O<RX`)60@9&4@)60@<F5G:7-T<F]S
M(&UA<F-A9&]S(&-O;6\@871U86QI>F%D;W,`)60@<')E=FESXV\@9&\@9&EA
M`"5S("T@079I<V\`)7,@061M:6YI<W1R8>?C;P`E<R!#;VYF:6=U<F'GXV\`
M26UP<F5S<^-O($1I9VET86P@9&4@)7,`)7,@2T(`)7,@3W!E<F'G]65S(&1E
M($UA;G5T96[GXV\@+2!#;VYF:7)M8>?C;P!296=I<W1R;R!D92`E<P`E<R!4
M97)M;W,@9&\@06-O<F1O`"5S(&KA(&5X:7-T92X`)7,@82`E<R`E<P`E<R!C
M86YC96QO=2`E<RX`)7,@<F5S<&]N9&5U(&$@=6UA(')E<75I<VGGXV\@9&4@
M:6YF;W)M8>?C;R!L:79R92]O8W5P861O+@`E<R!R97-P;VYD974@82!U;2!C
M;VYV:71E('!A<F$@)7,N`"5S(&5N=FEO=2!A('9O8^H@=6UA(&EN9F]R;6'G
MXV\@;&EV<F4O;V-U<&%D;RX`)7,@;N-O(.D@9W)A=N%V96PN`"5S(.D@;V)R
M:6=A=/-R:6\`)7,@;6EN=71O<P`E<R!NXV\@96YC;VYT<F%D;RX`)7,@;N-O
M(&5N8V]N=')A9&\N($5X96-U=&4@)W1R86YS;&%T:6]N(&5X=')A8W0G('!R
M:6UE:7)O+@`E<R!R97%U:7-I=&]U('-U82!I;F9O<FUAY^-O(&QI=G)E+V]C
M=7!A9&\N`"5S(')E<75I<VET;W4@<W5A('!R97-E;N=A(&5M("5S+@`E<R!A
M("5S(&1E("5S`"5S(&1E<V5J82!A9&EC:6]N87(@82`E<RX`)7,N(&1E<V5J
M82!D96EX87(@=F]CZB!C:65N=&4@9&4@)7,N`"5S(&1E<V5J82!R96-E8F5R
M(&$@^FQT:6UA(&EN9F]R;6'GXV\@<V]B<F4@)7,N`$-A=.%L;V=O(&1E($5N
M9&5R9>=O<R!D92`E<P!#86QE;F3A<FEO(&1E("5S`$%N;W1AY_5E<R!D92`E
M<P!,:7-T82!D92!487)E9F%S(&1E("5S`"5S.B`E<P`G)7,G(&[C;R#I('5M
M82!E<V-O;&AA(';A;&ED82X`)R5S)R!NXV\@97-TX2!C;VYF:6=U<F%D;R!N
M;R!296=I<W1R;R!D;R!(;W)D92X`3R!R96YD97)I>F%D;W(@9&4@X7)V;W)E
M("5S(&[C;R!F;VD@96YC;VYT<F%D;RX`)R5S)R!F;VD@861I8VEO;F%D;R!A
M;R!S:7-T96UA(&1E(&=R=7!O<RX`)R5S)R!F;VD@861I8VEO;F%D;R!A;R!S
M:7-T96UA(&1E('!E<FUI<W/U97,N`"<E<R<@;N-O(&9O:2!C<FEA9&\Z("5S
M+@`L(&)R:7-A("5S("5S`"P@=F%R:>%V96P@9&4@)7,@=&\@)7,`+2T@<V5L
M96-I;VYE("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0!&;W)M871O
M(#$R($AO<F%S`$9O<FUA=&\@,C0@2&]R87,`,C0@:&]R87,`/&=E='1E>'0^
M('1A9R!NXV\@9F]I(&9E8VAA9&$@;F\@87)Q=6EV;R`E<RX*06)E<G1U<F$@
M9&$@=&%G(&5N8V]N=')A9&$@;F$@;&EN:&$@)60N`%5M(&)A8VME;F0@9&4@
M8F%N8V\@9&4@9&%D;W,@Z2!O8G)I9V%T\W)I;R!P87)A(&5S=&4@8FQO8V\N
M`%5M(&5R<F\@9F%T86P@;V-O<G)E=0!5;6$@8VAA=F4@</IB;&EC82!01U`@
MZ2!O8G)I9V%T\W)I82!P87)A(&-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN
M`%5M82!C:&%V92!P^F)L:6-A(%!'4"#I(&]B<FEG873S<FEA('!A<F$@=F5R
M:69I8V%R('5M82!M96YS86=E;2!A<W-I;F%D82X`56UA(&-H879E('!R:79A
M9&$@4$=0(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I87,@<&%R82!D97-C
M<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+@!5;6$@8VAA=F4@<')I=F%D82!0
M1U`@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA<R!P87)A(&%S<VEN87(@
M=6UA(&UE;G-A9V5M+@!5;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82!C
M:&%V92!P<FEV861A(%,O34E-12!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R
M:6%S('!A<F$@9&5S8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`56UA(&-H
M879E('#Z8FQI8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@
M92!U;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA<R!P87)A(&%S<VEN87(@=6UA
M(&UE;G-A9V5M+@!5;6$@8VAA=F4@</IB;&EC82!3+TU)344@Z2!O8G)I9V%T
M\W)I82!P87)A(&-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN`$-H=79A(&UA
M='5T:6YA`$-H=79A<R!M871I;F%I<P!!32]030!!4$D@240`4V]B<F4@97-T
M92!E9&ET;W(`4V]B<F4N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V5I=&%R
M('-O;&EC:71AY^-O`$%C96ET80!!8V5S<V\@;F5G861O(&%O(&-R:6%R(&1I
M<F5T\W)I;R!61E,N`$%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q=6EV;R!6
M1E,N`%-E;FAA(&1A($-O;G1A`$-O;G1A(&1E<V%T:79A9&$N`$-O;G1A<P!!
MY_5E<P!!9&EC:6]N87(`061I8VEO;F%R($=R=7!O(%-U8F]R9&EN861O`$%D
M:6-I;VYA<B!097)M:7-S]65S(%-U8F]R9&EN861A<P!!9&EC:6]N92!!<75I
M.@!!9&EC:6]N87(@3F]V;R!'<G5P;P!!9&EC:6]N87(@3F]V82!097)M:7-S
MXV\`061I8VEO;F%R('5M(&=R=7!O('-U8F]R9&EN861O(&$@)R5S)P!!9&EC
M:6]N87(@=6UA('!E<FUI<W/C;R!S=6)O<F1I;F%D82!A("<E<R<`061I8VEO
M;F%R('5M(&YO=F\@=7-UX7)I;SH`061I8VEO;F%R(&-O;'5N80!!9&EC:6]N
M87(@;F]V;W,@;65M8G)O<P!!9&EC:6]N87(@<&%R`$%D:6-I;VYA<B!O($UE
M;G4@)7,@8V]M;R!U;6$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA`$%D:6-I
M;VYA<B!I<W1O(&%O(&UE=2!C86QE;F3A<FEO`$%D:6-I;VYA<B!A;R!C873A
M;&]G;R!D92!E;F1E<F7G;W,Z`$%D:6-I;VYA<B!A;R!M974@8V%TX6QO9V\@
M9&4@96YD97)EYV]S`$%D:6-I;VYA<B!U<W7A<FEO`"<E<R<@861I8VEO;F%D
M;R!A;R!S:7-T96UA+"!M87,@;N-O('!U9&4@:6YC;'5I<B!I;F9O<FUAY_5E
M<R!A9&EC:6]N86ES(&1O(')E9VES=')O.B`E<RX`)7,@861I8VEO;F%D;R!A
M;R!S:7-T96UA+B!6;V/J('!O9&4@<V4@8V]N96-T87(@86=O<F$N`$%D:6-I
M;VYA;F1O(&YO=F]S(&%R<75I=F]S(&%O(')E<&]S:73S<FEO.@!!9&GGXV\@
M9&4@=7-UX7)I;W,@97-TX2!D97-A8FEL:71A9&$N`$5N9&5R9>=O`$-A=.%L
M;V=O(&1E($5N9&5R9>=O<P!!9&UI;FES=')A<B`M(&-O;F9I9W5R82!P97)M
M:7-S]65S('!A<F$@;W5T<F]S('5S=>%R:6]S`$%D;6EN:7-T<F'GXV\`061S
M`$%F96=A;FES=.-O`$%L8N)N:6$`07)GZ7)I80!!<&5L:61O`$%L:6YH87(`
M06QI;FAA;65N=&\Z`%1O9&%S`%1O9&]S(%5S=>%R:6]S($%U=&5N=&EC861O
M<P!4;V1O<R!'<G5P;W,`5&]D87,@4&5R;6ES<_5E<P!4;V1O<R!Q=6%T<F\@
M;&%D;W,`4&5R;6ET:7(@;?IL=&EP;&]S(&5N9&5R9>=O<P!097)M:71I<B!C
M;VYF:6=U<F%R(&\@=&EP;R!D92!L:7-T87,@;W)D96YA9&%S/P!*X2!E>&ES
M=&4`3&]G:6X@24U34"!!;'1E<FYA=&EV;P!396YH82!)35-0($%L=&5R;F%T
M:79A`%5S=>%R:6\@24U34"!!;'1E<FYA=&EV;P!%;F1E<F7G;R!D92!E;6%I
M;"!A;'1E<FYA=&EV;P!-;V1E;&]S(&%L=&5R;F%T:79O<P!497AT;R!A;'1E
M<FYA=&EV;SH`4V%M;V$@06UE<FEC86YA`%5M('9A;&]R(&EL96=A;"!F;VD@
M97-P96-I9FEC861O+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!0<F]X>2!A
M;O1N:6UO`%)E<W!O<W1A`$%N=.%R=&ED80!!;G1I9W5A(&4@0F%R8F%D;W,`
M07!L:6-AY^-O`$QI<W1A(&1E($%P;&EC8>?U97,`02!A<&QI8V'GXV\@97-T
MX2!P<F]N=&$N`$%P;&EC87(@86]S($-O;7!A<G1I;&AA;65N=&]S(%-U8F]R
M9&EN861O<P!!<')O=F%R`$%B<FEL`$%RX6)I8V\@*%=I;F1O=W,M,3(U-BD`
M5&%M86YH;R!D;R!!<G%U:79O`$YO;64@9&\@07)Q=6EV;P!6;V/J('1E;2!C
M97)T97IA('%U92!Q=65R(')E;6]V97(@82!S;VQI8VET8>?C;R!D92!R96=I
M<W1R;R!D92`E<S\`5F]CZB!T96T@8V5R=&5Z82!Q=64@9&5S96IA(&5X8VQU
M:7(@)R5S)R!E('-E=7,@<W5B9W)U<&]S/P!!<F=E;G1I;F$`07)MZFYI80!!
M<FWJ;FEO("A!4DU30TE)+3@I`$%R=&4`07)U8F$`26QH82!!<V-E;G/C;P!!
M<G1E($%S8VEI`,%S:6$O4F5G:>-O(&1O(%!A8^UF:6-O`%-O;&EC:71A<B!C
M;VYF:7)M8>?C;R!A;G1E<R!D92!E>&5C=71A<B!A<R!O<&5R8>?U97,@9&4@
M;6%N=71E;N?C;S\`0V]L=6YA<R!D92!D97-I9VYAY^-O`%-E(&5N8V]N=')A
M(&%N97AA9&\@=6T@87)Q=6EV;R!I0V%L96YD87(@96T@<F5S<&]S=&$@82!S
M;VQI8VET8>?C;R!Q=64@=F]CZB!E;G9I;W4`5&5N=&]U(&5X8VQU:7(@=6T@
M9W)U<&\@:6YE>&ES=&5N=&4N`%1E;G1O=2!E>&-L=6ER('5M82!P97)M:7-S
MXV\@;N-O(&5X:7-T96YT92X`5&5N=&]U(&5D:71A<B!U;6$@<&5R;6ES<^-O
M(&[C;R!E>&ES=&5N=&4N`%1E;G1O=2!E9&ET87(@=6T@8V]M<&%R=&EL:&%M
M96YT;R!NXV\@97AI<W1E;G1E+@!087)T:6-I<&%N=&5S`$%T<FEB=71O<P!!
M9V]S=&\`075S='+A;&EA`,%U<W1R:6$`075T:%]C>7)S<6PZ($[C;R!F;VD@
M96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82X`075T:%]C
M>7)U<SH@3R!B86-K96YD(&[C;R!P;W-S=6D@87,@8V%P86-I9&%D97,@;F5C
M97-SX7)I87,N`$%U=&A?8WER=7,Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X
M=&5N<^-O(&EM87`@;F5C97-SX7)I82X`075T:%]F='`Z($[C;R!F;VD@96YC
M;VYT<F%D82!A(&5X=&5N<^-O($944"!N96-E<W/A<FEA+B!#;VUP:6QE(&\@
M4$A0(&-O;2!A(&]PY^-O("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!.XV\@
M9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N`$%U
M=&A?:W)B-3H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:W)B-2!N
M96-E<W/A<FEA+@!!=71H7VQD87`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X
M=&5N<^-O($Q$05`@;F5C97-SX7)I82X`075T:%]L9&%P.B!);7!O<W/M=F5L
M(&%D:6-I;VYA<B!O('5S=>%R:6\@)7,N($ES=&\@9F]I(&\@<75E(&\@<V5R
M=FED;W(@<F5P;W)T;W4Z(`!!=71H7VQD87`Z($EM<&]S<^UV96P@<F5M;W9E
M<B!O('5S=>%R:6\@)7,`075T:%]L9&%P.B!);7!O<W/M=F5L(&%T=6%L:7IA
M<B!O('5S=>%R:6\@)7,`075T:%]M8V%L.B!.XV\@9F]I(&5N8V]N=')A9&$@
M82!E>'1E;G/C;R!-0T%,(&YE8V5S<^%R:6$N`$%U=&A?<VUB875T:#H@3N-O
M(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@<VUB875T:"!N96-E<W/A<FEA
M+@!&86QH82!N82!A=71E;G1I8V'GXV\`1F%L:&$@;F$@875T96YT:6-AY^-O
M.B`E<P!!=71E;G1I8V'GXV\@<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$
M2553+@!!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U+@!#
M86UP;W,@9&ES<&]N[79E:7,Z`$%G=6%R9&%N9&\@<F5S<&]S=&$`07IE<F)A
M:6KC;P!$97-C=6QP87,@0D]&2`!&=6YD;P!#;W(@9&4@1G5N9&\`4V5N:&$@
M:V5R8F5R;W,@:6YC;W)R971A+@!5<W7A<FEO(&ME<F)E<F]S(&EN8V]R<F5T
M;RX`0F%H86UA<P!"86AR86EN`$+A;'1I8V\@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97-H`$)A<F)A9&]S`$QI;6ET861O`$[C;R!F;VD@96YC;VYT<F%D;R!O
M(&1I<F5T\W)I;R!B87-E(&1E(&EM86=E;G,@)R5S)RX`3&EN:&$@9&4@4&%R
M=&ED80!"96QO<OIS<VEA`$+I;&=I8V$`0F5L:7IE`$)E;FEN`$)E<FUU9&%S
M`$)U=.-O`$%N:79E<G/A<FEO`$[C;R!F;VD@96YC;VYT<F%D;R!O(&)L;V-O
M("(E<R(@9&$@87!L:6-AY^-O("(E<R(N`$-O;F9I9W5R8>?U97,@9&\@0FQO
M8V\`5&EP;R!D92!";&]C;P!396QEY^-O(&1O(&)L;V-O`$YE9W)I=&\`0F]L
M[79I80!&879O<FET;W,`0F]R9&$`3&%R9W5R82!D82!B;W)D83H`0F]R9&%S
M`$+S<VYI82!E($AE<GIE9V]V:6YA`$%M8F]S`$)O='-U86YA`%)O9&%PZ0!)
M;&AA($)O=79E=`!"<F%S:6P`5&5R<FET\W)I;R!D;R!/8V5A;F\@S6YD:6-O
M($EN9VSJ<P!"<G5N96D`0V]M<&EL86YD;R!A<G%U:79O<R!-3R!P87)A(&\@
M;?-D=6QO("5S+BXN`$-O;7!I;&%N9&\@;&]C86QI>F'GXV\@)7,N+BX@`$)U
M;&?A<FEA`$QI<W1A(&-O;2!-87)C861O<F5S`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`4&]N=&]S(&1E($1I<W1R:6)U:>?C;R!#4DP`4')O<')I
M961A9&5S(&1A($/I7VQU;&$N+BX`0V%L96YDX7)I;P!#86QM;P!#86UB;V1J
M80!#86UA<O5E<P!.XV\@Z2!P;W-S[79E;"!G97)A<B!U;6$@;F]V82!S96YH
M82!A=71O;6%T:6-A;65N=&4L(&5N=')E(&5M(&-O;G1A=&\@8V]M(&\@861M
M:6YI<W1R861O<BX`26UP;W-S[79E;"!G<F%V87(@;R!A<G%U:79O("(E<R(`
M3N-O(.D@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@24U!4#H@)7,`
M26UP;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@(B5S(BX`0V%N863A`$-A;F-E
M;&%R`$-A;F-E;&%R(%)E;&%T\W)I;R!D92!0<F]B;&5M80!.XV\@Z2!P;W-S
M[79E;"!E>&-L=6ER(&\@87)Q=6EV;R`B)7,B+@!.XV\@Z2!P;W-S[79E;"!E
M;F-O;G1R87(@=6T@9&ER973S<FEO('1E;7!O<N%R:6\N`$[C;R#I('!O<W/M
M=F5L(&-O;G1I;G5A<B!S96T@;R!P87+B;65T<F\@)W1A<F=E=$9I;&4G+@!.
MXV\@Z2!P;W-S[79E;"!E>&-L=6ER(&\@9&ER973S<FEO("(E<R(N`$[C;R#I
M('!O<W/M=F5L(&5X8VQU:7(L("5D('!O<W-U:2!S=6)O<F1I;F%D;W,N`$[C
M;R#I('!O<W/M=F5L(')E;W)D96YA<BP@;OIM97)O(&1E(')E9VES=')O<R!F
M;W)N96-I9&]S('!A<F$@<F5O<F1E;F%R(&[C;R!C;W)R97-P;VYD92!A;R!N
M^FUE<F\@87)M87IE;F%D;RX`3N-O(.D@<&]S<^UV96P@<F]T96%R(&UE;G-A
M9V5M('!A<F$@;R!N^FUE<F\@97-P96-I9FEC861O+@!#86)O(%9E<F1E`%3M
M='5L;P!#871E9V]R:6%S(&4@3F]M97,`26QH87,@0V%Y;6%N`%1E;&5F;VYE
M($-E;'5L87(`4')O<')I961A9&5S(&1A($/I;'5L80!-87)G96T@9&$@8^EL
M=6QA.@!0<F]P<FEE9&%D97,@9&$@0^EL=6QA`$5S<&'G86UE;G1O(&1A(&/I
M;'5L83H`5&5L969O;F4@8V5L=6QA<@!#Z6QT:6-O("A)4T\M.#@U.2TQ-"D`
M0V5N=')O`%)E</IB;&EC82!D82#!9G)I8V$@0V5N=')A;`!%=7)O<&$@0V5N
M=')A;"`H25-/+3@X-3DM,BD`1&5T86QH97,@9&\@0V5R=&EF:6-A9&\`4&]L
M[71I8V%S(&1O($-E<G1I9FEC861O`%1C:&%D90!/8W5P86YT90!!;'1E<F%R
M`$%L=&5R92!3=6$@4V5N:&$`06QT97)A<B!O(&YO;64@92!O(&5N9&5R9>=O
M('%U92!A<R!P97-S;V%S('9EZFT@<75A;F1O(&5L87,@;&7J;2!E(')E<W!O
M;F1E;2!S=6%S(&UE;G-A9V5N<RX`36]D:69I<75E('-U82!S96YH80!!;'1E
M<F'GXV\@9&4@<V5N:&$@;N-O(.D@<W5P;W)T861A(&YA(&-O;F9I9W5R8>?C
M;R!A='5A;"X@($5N=')E(&5M(&-O;G1A=&\@8V]M(&\@861M:6YI<W1R861O
M<BX`0VAA<@!697)I9FEC87(@3&EN7VLN+BX`0VQI<75E(&YA<R!C86EX87,@
M9&4@<V5L9>?C;R!P87)A('%U86QQ=65R(&]P97)AY^-O('%U92!V;V/J('%U
M96ER82!E>&5C=71A<B!N97-T82!H;W)A+@!#:&EL90!#:&EN80!#:&ENZG,@
M4VEM<&QI9FEC861O("A'0C(S,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG
M-2D`17-C;VQH82!U;6$@<V5N:&$`17-C;VQH82!U;2!U<W7A<FEO`$5S8V]L
M:&$@=6UA(&'GXV\Z`$5S8V]L:&$@8V]M;R!E>&EB:7(@9&%T87,Z`$5S8V]L
M:&$@;R!T:7!O(&1E(&5S=&EL;R!D92!L:7-T87,@*'!A<F$@;&ES=&%S(&]R
M9&5N861A<RD`26QH87,@0VAR:7-T;6%S`$[C;R!F;VD@96YC;VYT<F%D82!A
M(&1E9FEN:>?C;R!D92!C;&%S<V4@9&4@)7,N`$QI;7!A;F1O(&%R<75I=F]S
M(%!/('!A<F$@;R!M\V1U;&\@)7,N+BX`3&EM<&%N9&\@;&]C86QI>F'GXV\@
M)7,N+BX@`$QI;7!A<@!,:6UP87(@=&%G<R!-4T]F9FEC90!%>&-L=6ER('5S
M=>%R:6\Z("5S`$5X8VQU:7(@=7-UX7)I;P!%>&-L=6ER(&1A9&]S(&1O('5S
M=>%R:6\`0VQI<75E('!A<F$@0V]N=&EN=6%R`$-L:6-K871E;&P@=FEA($A4
M5%``1F5C:&%R($IA;F5L80!.=79E;G,`3G5B;&%D;P!);&AA<R!D92!#;V-O
M<P!#;VYT<F%I<B!"87)R82!,871E<F%L`$-O;G1R86ER(&)O<F1A<P!#;VST
M;6)I80!#;W(`4&%L;&5T82!D92!#;W)E<P!396QEY^-O(&1E($-O<@!#;VQS
M.@!4[71U;&]S(&1A<R!#;VQU;F%S`%%U861R:6YH;W,`0V]M86YD;P!0<F]M
M<'0@9&4@0V]M86YD;P!/<.?U97,@9&4@8V]M86YD;W,Z`$-O;6%N9&]S.@!#
M;VUE;G1A<@!%;G9I86YD;SH`3F]M92!#;VUU;0!#;VUO<F]S`$-O;7!A;FAI
M80!#;VUP;&5T;P!#;VUP;W(@365N<V%G96T@*"5S*0!#;VUP=71A9&]R97,`
M0V]N9&GG]65S`$1I9F5R96[G87,@9&4@0V]N9FEG=7)AY^-O`$-O;F9I9W5R
M8>?C;R!N96-E<W-I=&$@9&4@871U86QI>F'GXV\N`$-O;F9I9W5R87(@)7,`
M0V]N9FER;64@82!396YH80!#;VYF:7)M92!S=6$@<V5N:&$@;F]V83H`0V]N
M9V\`0V]N9V\L(%)E</IB;&EC82!$96UO8W+A=&EC82!D;P!&86QH82!N82!C
M;VYE>.-O+@!&86QH82!N82!C;VYE>.-O.B``0V]N97CC;R!R96-U<V%D82!P
M96QO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RX`0V]N97CC;R!R96-U
M<V%D82!P96QO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RX@36]T:79O
M.B`E<R`H)7,I`$$@8V]N97CC;R!A;R!S97)V:61O<B!&5%`@9F%L:&]U+@!/
M<R!C;VYT871O<R!F;W)A;2!A9&EC:6]N861O<R!C;VT@<W5C97-S;R!A;R!S
M974@8V%TX6QO9V\@9&4@96YD97)EYV]S+@!#;VYT9?ID;R!D92`G)7,G`$-O
M;G1I;G5A<@!);&AA<R!#;V]K`$-O;VMI90!#;W!I87(`0V]P:6%R('-E;&7G
MXV\`0V]P:6%N9&\@)7,@<&%R82`E<P!#;W-T82!2:6-A`$-O<W1A(&1O($UA
M<F9I;0!.XV\@9F]I('!O<W/M=F5L(&-R:7!T;V=R869A<B!A(&UE;G-A9V5M
M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M
M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@;65N
M<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A<W-I;F%R(&$@
M;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A9&EC:6]N
M87(@8V]N=&%T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S
M97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L('9E<FEF:6-A<B!O('-A
M;&1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R
M("<E<R<@=71I;&EZ86YD;R!&5%`Z("5S`$[C;R!F;VD@<&]S<^UV96P@8V]P
M:6%R("5S('!A<F$@)7,`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!O
M(&1I<F5T\W)I;R!D92!L;V-A;&EZ8>?C;R!P87)A(&$@;&]C86QI>F'GXV\@
M)7,Z`$[C;R!F;VD@<&]S<^UV96P@9&5S8W)I<'1O9W)A=F%R(&\@9&%D;R!0
M1U`N`$[C;R!F;VD@<&]S<^UV96P@9&5S8W)I<'1O9W)A9F%R(&\@9&%D;R!3
M+TU)344N`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!O(&-O;G1A=&\N("5S
M`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!A(&QI<W1A(&1E(&1I<W1R:6)U
M:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER(&\@<V-R:7!T(&1E
M(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R`G)7,G+@!.XV\@9F]I('!O
M<W/M=F5L(&1E=&5R;6EN87(@;R!E;F1E<F7G;R!D92!E+6UA:6P@9&\@9&5S
M=&EN873A<FEO+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&-O;7!L971A;65N
M=&4@;R!C873A;&]G;R!D92!E;F1E<F7G;W,N`$[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@8V]M<&QE=&%M96YT92!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX`
M3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&$@;&ES=&$@
M9&4@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX`3N-O(&9O:2!P;W-S[79E;"!C
M87)R96=A<B!A(&5S=')A=.EG:6$@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!C
M<FEA<B!O(&1I<F5T\W)I;R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R
M(&$@8VAA=F4@</IB;&EC82!A('!A<G1I<B!D;R!S97)V:61O<B!D92!C:&%V
M97,N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@)7,N`$[C;R!F;VD@<&]S<^UV
M96P@86)R:7(@)R5S)R!P87)A(&=R879AY^-O+@!.XV\@9F]I('!O<W/M=F5L
M(&%B<FER(&\@;?-D=6QO("=-86EN=&5N86YC95]487-K)R`E<P!.XV\@9F]I
M('!O<W/M=F5L(&%B<FER(&\@9&ER973S<FEO("<E<R<N`$[C;R!F;VD@<&]S
M<^UV96P@;&5R("5S+@!.XV\@9F]I('!O<W/M=F5L(&=E<F%R('5M82!N;W9A
M('-E;FAA('!A<F$@;R!U<W7A<FEO('-O;&EC:71A9&\N($%L9W5N<R!O=2!T
M;V1O<R!O<R!D971A;&AE<R!NXV\@97-TXV\@8V]R<F5T;W,N(%1E;G1E(&YO
M=F%M96YT92!O=2!E;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D
M;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@;6%I<R!A:G5D82X`3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!A($%#3`!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@
M8V%TX6QO9V\@9&4@96YD97)EYV]S+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B
M=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M
M=F5L(&]B=&5R(&%S(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@87,@8V%P86-I9&%D97,@9&\@<V5R=FED;W(`
M3N-O(&9O:2!P;W-S[79E;"!R979E<G1E<B!A(&-O;F9I9W5R8>?C;RX`3N-O
M(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@9&ER973S<FEO("<E<R<N`$[C;R!F
M;VD@<&]S<^UV96P@<V%L=F%R(&$@8V]N9FEG=7)AY^-O("5S+@!.XV\@9F]I
M('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@9&$@8V]N9FEG=7)AY^-O+@!.
MXV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@9&$@8V]N9FEG=7)A
MY^-O.B`E<P!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@9&$@
M8V]N9FEG=7)AY^-O("5S+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!O('-C
M<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@96TZ("<E<R<N
M`$[C;R!F;VD@<&]S<^UV96P@<&5S<75I<V%R(&YO('-E<G9I9&]R($Q$05`N
M`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&QI;FL@)R5S)RX`3N-O(&9O
M:2!P;W-S[79E;"!A='5A;&EZ87(@;R!C;VYT871O+B`E<P!.XV\@9F]I('!O
M<W/M=F5L(&%T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`
M3N-O(&9O:2!P;W-S[79E;"!G<F%V87(@82!C;VYF:6=U<F'GXV\@9&4@)R5S
M)SH@)7,`3N-O(&9O:2!P;W-S[79E;"!E;F-O;G1R87(@82!"87)R82!,871E
M<F%L(&1O($UO>FEL;&$N($-E<G1I9FEQ=64M<V4@<75E(&5L82!E<W3A(&%B
M97)T82X`3N-O(&9O:2!P;W-S[79E;"!D87(@86\@=7-UX7)I;R`E<R!O<R!S
M96=U:6YT97,@9&ER96ET;W,@<&%R82!A('!A<W1A("<E<R<Z("5S`%1E>'1O
M(&-O;G1A9&\`4&'M<P!#=7)S;W,`0W)I87(`0W)I87(@=6T@;&EN:P!#<FEA
M<B!U;6$@;F]V80!#<FEA<B!S=6(@<&%S=&%S`%!E;6ES<_5E<R!D;R!C<FEA
M9&]R`$[Z;65R;R!D;R!C87)TXV\@9&4@8W+I9&ET;P!#<F_A8VEA`$-U8F$`
M1F%S92!!='5A;`!(;W)A($%T=6%L`$$@55),(&%T=6%L(.D`0VQI;6$@071U
M86P`0V]N9&GGXV\@871U86PZ(`!%<W1I;&\@871U86P`0W5S=&]M:7IA('1A
M<F5F87,@82!S97)E;2!E>&5C=71A9&%S(&%O(&-O;F5C=&%R(&$@)7,N`$-O
M<G1A<@!#;W)T87(@<V5L9>?C;P!#:&EP<F4`0VER[6QI8V\@*$M/23@M4BD`
M0VER[6QI8V\@*%=I;F1O=W,M,3(U,2D`0VER[6QI8V\O56-R86YI86YO("A+
M3TDX+54I`%)E</IB;&EC82!48VAE8V$`1$0`1&EA<FEA;65N=&4`1&%D;W,`
M3F%V96=A9&]R(&1E($1A=&%4<F5E`$1A=&$`1&%T82!D92!296-E8FEM96YT
M;P!396QEY^-O(&1E(&1A=&$`1&EA`$5?>&-L=6ER($-O;'5N80!$97IE;6)R
M;P!.^FUE<F]S(&1E8VEM86ES`%)E8W5S861O`%)E8W5A<B!)9&5N=&'GXV\`
M0V]R(%!A9'+C;P!)9&5N=&ED861E(%!A9'+C;P!097)M:7-S]65S(%!A9'+U
M97,`4&5R;6ES<_5E<R!P861R]65S`$1E9FEN:>?U97,`1&5L96=A<B!P;W-I
MY^-O`$1E;&5G861O`$5X8VQU:7(`17AC;'5I<B!'<G5P;P!%>&-L=6ER(%!E
M<FUI<W/C;P!%>&-L=6ER(&4@<'5R9V%R(&UE;G-A9V5N<P!%>&-L=6ER(&/I
M;'5L80!%>&-L=6ER(&-O;'5N80!%>&-L=6ER(&UO9&5L;R!S=6)S=&ET=71O
M(&5X:7-T96YT90!%>&-L=6ER('!E<FUI<W/U97,@<&%R82`G)7,G`$5X8VQU
M:7(@<&5R;6ES<_5E<R!P87)A("<E<R<@92!Q=6%L<75E<B!O=71R82!S=6(M
M<&5R;6ES<^-O/P!%>&-L=6ER(&QI;FAA`$5X8VQU:7(@:61E;G1I9&%D92!S
M96QE8VEO;F%D80!%>&-L=6ER(&$@8V]L=6YA(&%T=6%L`$5X8VQU:7(@82!L
M:6YH82!A='5A;`!%>&-L=6ER(&5S=&$@<&5R;6ES<^-O(&4@<75A;'%U97(@
M;W5T<F$@<W5B+7!E<FUI<W/C;S\`4V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E
M(&-O;F9I9W5R8>?C;R`G)7,G(&5X8VQU:61O+@!(;W)A(&1E(&5N=')E9V$`
M1&EN86UA<F-A`$YE9V%R('-O;&EC:71AY^-O`$YE9V%R('-O;&EC:71AY^-O
M(&1E(&EN9F]R;6'GXV\@;&EV<F4O;V-U<&%D;P!$97-C<F5V82!O('!R;V)L
M96UA`$1E<V-R:>?C;P!$971A;&AE<R`H=&%M8NEM(&YO(&QO9R!D;R!(;W)D
M92DZ`$]S(&1E=&%L:&5S(&9O<F%M(&=R879A9&]S(&5M(&QO9R!P87)A(&\@
M861M:6YI<W1R861O<BX`1&5S96YV;VQV:6UE;G1O`%!O;G1O(&1E($]R=F%L
M:&\`4&]N=&\@9&4@3W)V86QH;R!P87)A(&$@^FQT:6UA(&AO<F$Z(`!0;VYT
M;R!D92!/<G9A;&AO.B``1&ER9>?C;R!D82!E<W%U97)D82!P87)A(&1I<F5I
M=&$`1&ER9>?C;R!D82!D:7)E:71A('!A<F$@97-Q=65R9&$`1&ER973S<FEO
M`$5X:6)I<B!E;2!F;W)M871O(#(T(&AO<F%S/P!/<.?U97,@9&4@17AI8FGG
MXV\`17AI8FER(%!R979I<^-O("A4048I`$5X:6)I<B!F;W)M871O`$YO=&EF
M:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.XV\@97AC;'5I<@!.XV\@
M86-E<W-E(&1I<F5T86UE;G1E(&UA:6YT96YA;F-E+G!H<`!!('!R:6UE:7)A
M(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S/R!392!S:6TL(&-L
M:7%U92!N97-T82!C86EX83H`1&]M:6YI8V%N80!297#Z8FQI8V$@1&]M:6YI
M8V%N80!"86EX87(`0F%I>&%R("5S`$)A:7AA<B!A(&-O;F9I9W5R8>?C;R!G
M97)A9&$@8V]M;R!U;2!S8W)I<'0@4$A0+@!,:7-T82!D92!S96QEY^-O`$1R
M;V=A<P!#;W)R96EO`$524@!%<75A9&]R`$5D:71A<@!%9&ET87(@0FQO8V\`
M161I=&%R($=R=7!O`$5D:71A<B!097)M:7-SXV\`161I=&%R(%!E<FUI<W/U
M97,`161I=&%R(%!E<FUI<W/U97,@<&%R82`E<P!%9&ET87(@;W#G]65S(&1E
M.@!%9&ET87(@<&5R;6ES<_5E<R!P87)A("5S`$5D:71A<B!P97)M:7-S]65S
M('!A<F$@)R5S)P!%9'5C8>?C;P!%9VET;P!%;"!386QV861O<@!%;&5M96YT
M;RXN+@!%;0!%;6%I;`!%;F1E<F7G;R!D92!%;6%I;`!/(&5N9&5R9>=O(&1E
M(&5M86EL(&1E=F4@8V]R<F5S<&]N9&5R+@!-96YS86=E;2!C;VT@8V]N9FER
M;6'GXV\`16UO=&EC;VYS`$UE;G-A9V5M('9A>FEA+@!297-U;'1A9&\@=F%Z
M:6\N`%1E<FUO<R!D92!P97-Q=6ES82!V87II;W,`2&%B:6QI=&%R(&EN<V5R
MY^-O(&1E(&EM86=E;G,@82!P87)T:7(@9&$@1V%L97)I82!D92!);6%G96YS
M(&YO('1E>'1O/P!(86)I;&ET87(@;65N=2!D92!C;VYT97AT;R!C;VT@;R!B
M;W3C;R!D:7)E:71O/P!&:6YA;`!&:6YA;"!D;R!A;F\`075M96YT87(@161I
M=&]R`$9O<FYEYV$@=6UA('!E<F=U;G1A(&1E('-E9W5R86[G82!A('%U86P@
M=F]CZB!S97+A('!E<F=U;G1A9&\@<V4@=F]CZB!N96-E<W-I=&%R(&=E<F%R
M('5M82!N;W9A('-E;FAA+"!E>"X@)W%U86P@;R!N;VUE(&1O('-E=2!C86-H
M;W)R;S\G.@!&;W)N9>=A(&$@55),(&1A(&EM86=E;2!A<75I`%)E9VES=')O
M<SH@)60@=&]T86PL("5D(&%T=6%L:7IA9&]S+"`E9"!N;W9O<RP@)60@86QT
M97)A9&]S+"`E9"!D97-C;VYH96-I9&]S`$=U:6[I($5Q=6%T;W)I86P`17)I
M='+I:6$`17)R;P!%<G)O(&%O(&5N=FEA<B!R97-P;W-T83H@)7,N`$5R<F\@
M86\@871U86QI>F%R(&$@<V5N:&$Z("5S`$5R<F\@;F$@;65N<V%G96TN`$5R
M<F\@9W)A=F%N9&\@)R5S)RX`17)R;SH@`$5S=/1N:6$`171I\W!I80#)=&YI
M8V\`175R;W!A`$-A9&$@,34@;6EN=71O<P!#861A(#(@;6EN=71O<P!#861A
M(#,P('-E9W5N9&]S`$-A9&$@-2!M:6YU=&]S`$-A9&$@0V]N97CC;P!#861A
M(&UE:6$@:&]R80!#861A(&UI;G5T;P!686QO<F5S(&1E(&5X96UP;&\Z`$5X
M96-U=&%R`$5X96-U=&%N9&\Z`$5X<&%N9&ER`$5X<&%N9&ER($)A<G)A($QA
M=&5R86P`17-P97)A9&\@)RDG`$5S<&5R861O('5M82!P86QA=G)A(&]U('1E
M<FUO(&1E('!E<W%U:7-A(&5N=')E(&%S<&%S`$1A=&$@9&4@17AP:7)AY^-O
M`$5X<&]E;G1E`$5X=')A:6YD;R!D92`E<RXN+B``0V]R(&1O('!R:6UE:7)O
M('!L86YO`$-O;F9I9W5R8>?C;R!D92!U<&QO860@1E10`$9A;&AA(&]B=&5N
M9&\@<')E9F5RZFYC:6%S+@!&86QH82!A;R!C;VYE8W1A<B!A;R!S97)V:61O
M<B!,1$%0+@!&86QH82!A;R!C;VYE8W1A<B!A;R!S97)V:61O<B!334(N`$9A
M;&AA(&%O(&-O<&EA<B!D92`B)7,B+@!&86QH82!A;R!C;W!I87(@<&%R82`B
M)7,B+@!&86QH82!A;R!C<FEA<B!U;6$@;F]V82!C;VYE>.-O(%-!4TPN`$9A
M;&AA(&%O(&UO=F5R('!A<F$@(B5S(BX`3V-O<G)E=2!U;6$@9F%L:&$@86\@
M;6]D:69I8V%R('-U82!S96YH82`Z`$IU<W1O`$EL:&%S($9A;&ML86YD("A-
M86QV:6YA<RD`26QH87,@1F%R;V4`17)R;R!&871A;#H`1F%X`$9E=F5R96ER
M;P!396YS8>?C;R!TZ7)M:6-A`%-E;G-AY^-O('3I<FUI8V$Z(`!086YC861A
M<R!D92!#:'5V80!&:6II`$-O;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U
M:79O`$-O;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O<P!'97)E;F-I
M861O<B!D92!!<G%U:79O<P!.;VUE(&1O($%R<75I=F\`4V5L9>?C;R!D92!A
M<G%U:79O`$5N=FEO(&1E(&%R<75I=F\`16YV:6\@9&4@87)Q=6EV;W,@;N-O
M(.D@<W5P;W)T861O+@!&:6QT<F]S`$9I;FSB;F1I80!0<FEM96ER82!-971A
M9&4`4')I;65I<F\@475A<G1O`%1A>&$@9FEX80!':7)A<@!$:7-P;W-IY^-O
M`$[I=F]A`%!A<W1A("5S(&[C;R!E>&ES=&4`0V]R(&1A($9O;G1E`$-O;6ED
M80!087)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P;W)T86T@:6UA9V5N<P!0
M<F5V:7/C;R`H5$%&*0!$:6%S(%!R979I<W1O<R`H3F]T92!Q=64@82!P<F5V
M:7/C;R!E>&EB:61A(&UO<W1R82!A;6)O<R!D:6$@92!N;VET93L@=6T@;OIM
M97)O(&UU:71O(&%L=&\@87%U:2!P;V1E(')E<W5L=&%R(&5M('5M(&)L;V-O
M(&5X=&5N<V\I`$5S<75E8V5U(&$@<V5N:&$_`$9O<FUU;.%R:6]S`%-O<G1E
M`%1I<&\@9&4@4V]R=&4`4V]R=&5S`%-O<G1E<R`R`$;S<G5N<P!2961I<F5C
M:6]N86UE;G1O<P!!<&QI8V'G]65S(&5N8V]N=')A9&%S.B`E<P!$:7)E=/-R
M:6]S(&5N8V]N=')A9&]S.@!397@`1G)A;65S`$9R86[G80!&<F%NYV$@365T
M<F]P;VQI=&%N80!);F9O<FUAY^-O($QI=G)E+T]C=7!A9&\`4F5S<&]S=&$@
M3&EV<F4O3V-U<&%D;P!3;VQI8VET8>?C;R!D92!);F9O<FUAY^-O($QI=G)E
M+T]C=7!A9&\`4F5S<&]S=&$@9&$@4V]L:6-I=&'GXV\@9&4@26YF;W)M8>?C
M;R!,:79R92]/8W5P861O`$=U:6%N82!&<F%N8V5S80!0;VQI;NES:6$@1G)A
M;F-E<V$`5&5R<FET\W)I;W,@1G)A;F-E<V5S(&1O(%-U;`!$90!$;RAA*0!$
M97-C<FGGXV\@0V]M<&QE=&$`3'5A($-H96EA`$YO;64@0V]M<&QE=&\`17-T
M861O($%P<F]X:6UA9&\`1V%BXV\`1V%L97)I82!D92!O;F1E(&]B=&5R(&%S
M(&EM86=E;G,`1V%L97)I83H`1^)M8FEA`$=E<F%R(&$@0V]N9FEG=7)AY^-O
M(&1E("5S`$/S9&EG;R!'97)A9&\`4W1A='5S(&1E($=E<F'GXV\@<&%R82!O
M(&WS9'5L;R`E<RXN+@!'9?-R9VEA`$%L96UA;FAA`$=E=&]P="!%<G)O<CH@
M`$=A;F$`1VEB<F%L=&%R`%!R:6UE:7)O($YO;64`27(`1V]E9&5L`%!R;V-U
M<F%R(&YO($=O;V=L90!%<V-A;&$@9&4@0VEN>F%S`$=RZ6-I80!'<F5G;R`H
M25-/+3@X-3DM-RD`1W)O96SB;F1I80!'<F%N861A`$%D;6EN:7-T<F'GXV\@
M9&4@1W)U<&]S`$YO;65S(&1E(&=R=7!O<R!NXV\@9&5V96T@97-T87(@96T@
M8G)A;F-O`%!E<FUI<W/U97,@9&4@9W)U<&\`1W)U<&]S`$=U861A;'5P90!'
M=6%M`$=U871E;&%M80!'=65R;G-E>0!097-M:7-S]65S(&1E($-O;G9I9&%D
M;P!097)M:7-S]65S(&1E(&-O;G9I9&%D;P!,:79R;R!D92!6:7-I=&%S`$=U
M:6[I`$=U:6[I+4)I<W-A=0!'=6EA;F$`2$@`2%1-3`!(5$U,07)E82!S92!N
M96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@8^EL=6QA(&1A
M(&QI;FAA+@!(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU
M:7(@82#Z;'1I;6$@8V]L=6YA(&1A('1A8F5L82X`2%1-3$%R96$@<V4@;F5G
M82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA(&QI;FAA(&1A('1A
M8F5L82X`075T96YT:6-AY^-O($A45%`@;N-O(&5N8V]N=')A9&$N`$AA:71I
M`$%L9V]R[71I;6\@2&%S:`!.96)L:6YA`$-A8F7G86QH;P!);&AA($AE87)D
M(&4@26QH87,@36-$;VYA;&0`2&5B<F5U("A)4T\M.#@U.2TX+4DI`$%L='5R
M80!!:G5D80!!:G5D82!D;R!E9&ET;W(`07-S:7-T96YT90!!<&QI8V'GXV\@
M875X:6QI87(@<&%R82!C<FEA<B!E(&UA;G1E<B!T<F%D=>?U97,@<&%R82!O
M('-I<W1E;6$*2&]R9&4@92!S=6%S(&%P;&EC8>?U97,N"DQE:6$@;R!A<G%U
M:79O(%)%041-12!N97-T92!D:7)E=/-R:6\@8V]M;R!I;G1R;V1UY^-O+@!(
M96UI<V;I<FEO`$%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A<G%U:79O.@!!;'1A
M`$YO;65S(&1E(')E9VES=')O<R!D;R!H:7-T\W)I;R!NXV\@9&5V96T@97-T
M87(@96T@8G)A;F-O`$E?;NUC:6\`4V%N=&$@4^D@*$-I9&%D92U%<W1A9&\@
M9&\@5F%T:6-A;F\I`$EN[6-I;P!%;F1E<F7G;R!297-I9&5N8VEA;`!496QE
M9F]N92!297-I9&5N8VEA;`!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`1V5R
M861O<B!D92!T<F%D=>?U97,@9&\@2&]R9&4`2&]R9&4O2V]L86(Z($1A9&\@
M6$U,("5S(&EN=N%L:61O(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,`2&]R
M9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G96T@8V]R<F5S<&]N9&4@86\@;V)J
M971O("5S`$AO<F1E+TMO;&%B.B!.96YH=6T@;V)J971O(&1O('1I<&\@)7,@
M9F]I(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,`2&]R9&4O2V]L86(Z(%)E
M;6]V:61O(&-O;2!S=6-E<W-O("5S("(E<R(`2&]R9&4O2V]L86(Z(%-I;F-R
M;VYI>F%D;R!C;VT@<W5C97-S;R`E<R`B)7,B`$AO<F1E+TMO;&%B.B!!(&5N
M9VEN92!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N<^-O(%!(4"`G9&]M
M>&UL)P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A
M<G9O<F4@6$U,('!A<F$@;R!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z($EM<&]S
M<^UV96P@<F5M;W9E<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S
M[79E;"!O8G1E<B!A(&ED96YT:69I8V'GXV\@34E-12!P87)A(&$@<&%R=&4@
M9&\@=&EP;R`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA
M<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N
M:7IA<B!C;VUP87)T:6QH86UE;G1O<SH@)7,`2&]R9&4O2V]L86(Z($-O;7!A
M<G1I;&AA;65N=&\@9&5S8V]N:&5C:61O("(E<R(`3&EN:&$@2&]R:7IO;G1A
M;`!-87)G96T@:&]R:7IO;G1A;`!(;W)I>F]N=&%L.@!#;VUO('9O8^H@8VAE
M9V]U(&%Q=6D_("A0;W(@9F%V;W(@8V]M=6YI<75E(2D`475A;G1A<R!C;VQU
M;F%S('9O8^H@9V]S=&%R:6$@9&4@;65S8VQA<C\`475A;G1O<R!C86UP;W,@
M*&-O;'5N87,I(&5X:7-T96T_`%%U86YT87,@;&EN:&%S('9O8^H@9V]S=&%R
M:6$@9&4@;65S8VQA<C\`56UI9&%D90!5;6ED861E.B``2'5M;W)I<W1A<P!(
M=6YG<NUA`$9A;&AA(&%O(&-R:6%R(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&
M86QH82!A;R!E>&-L=6ER(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&86QH82!A
M;R!C<FEA<B!Q=6]T82!D82!C86EX82!P;W-T86P@24U!4#H@)7,`16YD97)E
MYV\@25``16YD97)EYV\@25`@;N-O(&1I<W!O;NUV96PN`$5N9&5R9>=O($E0
M(&[C;R!E<W3A(&YO(&)L;V-O('!E<FUI=&ED;R!#2412+@!6:6]L8>?C;R!D
M;R!B;&]Q=65I;R!)4"X`25]N<VER82!,:6YH82!!;G1E<P!)<VSB;F1I80!3
M;VUE;G1E(,UC;VYE<P#-8V]N97,@<&%R82`E<P#-8V]N97,@92!T97AT;P!.
M;VUE(&1A(&ED96YT:61A9&4Z`%-E(&[C;R!F;W(@97AI8FED;R!C;W)R971A
M;65N=&4L("5S('!A<F$@86)R[2UL;R!E;2!U;6$@;F]V82!J86YE;&$N`%-E
M('9O8^H@;N-O(';J(&YE;FAU;2#M8V]N92!A;R!U=&EL:7IA<B!O($EN=&5R
M;F5T($5X<&QO<F5R+"!V;V/J('!O9&4@8VAE8V%R(&5S=&$@8V%I>&$@<&%R
M82!D97-A8FEL:71A<B!A('1R86YS<&%RZFYC:6$@4$Y'+@!392!V;V/J(';J
M(&5S=&$@;65N<V%G96T@;6%S(&[C;R!A(&EM86=E;2P@82!I;6%G96T@<75E
M('9O8^H@<75E<B!E;G9I87(@;N-O('!O9&4@<V5R(&5X:6)I9&$@<&5L;R!S
M974@;F%V96=A9&]R+@!0<NDM=FES=6%L:7IAY^-O(&1A($EM86=E;3H`55),
M(&1A($EM86=E;0!54DP@9&$@26UA9V5M.@!);6%G96T@9&$@9V%L97)I80!)
M;6%G96T@9&$@9V%L97)I83H`16YV:6\@9&4@26UA9V5M`$EM86=E;G,`26UP
M;W)T87(L(%!A<W-O("5D`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM
M<&]R=&%D;W,Z`%!R;V-E<W-A;F1O`$EN7W-E<FER($QI;FAA($%P\W,`0_-D
M:6=O(&1E(&'GXV\@9F]R;F5C:61O(&5S=.$@:6YC;W)R971O+@!5<W7A<FEO
M(&4O;W4@<V5N:&$@:6YC;W)R971O<RX`57-UX7)I;R!O=2!E;F1E<F7G;R!A
M;'1E<FYA=&EV;R!I;F-O<G)E=&]S+B!496YT92!N;W9A;65N=&4@;W4@96YT
M<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R('-E('9O8^H@;F5C
M97-S:71A(&1E(&UA:7,@86IU9&$N`$%U;65N=&%R($ED96YT8>?C;P#-;F1I
M80!5<W7A<FEO<R!I;F1I=FED=6%I<P!);F1O;NES:6$`26YF;W)M8>?C;P!)
M;F9O<FUAY^-O`$EN:6-I86QI>F%N9&\@;?-D=6QO("5S+BXN(`!);G-E<FER
M($-?;VQU;F$@07#S<P!);G-E<FER($EM86=E;0!);G-E<FER(%1A8F5L80!)
M;G-E<FER($QI;FL@9&$@5V5B`$EN<V5R:7(@7T-O;'5N82!!;G1E<P!);G-E
M<FER('5M82!N;W9A(&-O;'5N82!A</-S(&$@871U86P`26YS97)I<B!U;6$@
M;F]V82!C;VQU;F$@86YT97,@9&$@871U86P`26YS97)I<B!U;6$@;F]V82!L
M:6YH82!A</-S(&$@871U86P`26YS97)I<B!U;6$@;F]V82!L:6YH82!A;G1E
M<R!D82!A='5A;`!);G-E<FER('5M('!A<N%G<F%F;R!A</-S(&\@871U86P`
M26YS97)I<B!U;2!P87+A9W)A9F\@86YT97,@9&\@871U86P`26YS97)I<B!U
M;2!M;V1E;&\@86QT97)N871I=F\`1F]R;F7G82!U;2!E;F1E<F7G;R!D92!E
M+6UA:6P@;F\@<75A;"!V;V/J('!O9&4@<F5C96)E<B!A(&YO=F$@<V5N:&$Z
M`$EN<V5R:7(@8^EL=6QA(&%P\W,`26YS97)I<B!CZ6QU;&$@86YT97,`26YS
M97)I<B!C;VQU;F$@87#S<P!);G-E<FER(&-O;'5N82!A;G1E<P!);G-E<FER
M(&UE;G-A9V5N<P!);G-E<FER('!A<N%G<F%F;R!A</-S`$EN<V5R:7(@<&%R
MX6=R869O(&%N=&5S`$EN<V5R:7(@;&EN:&$@87#S<P!);G-E<FER(&QI;FAA
M(&%N=&5S`$9O<FYEYV$@82!R97-P;W-T82!O8G)I9V%T\W)I82!P87)A(&$@
M<&5R9W5N=&$@9&4@<V5G=7)A;N=A.@!);G-E<FER+T%L=&5R87(@26UA9V5M
M`$EN<V5R:7(O06QT97)A<B!,:6YK`$-RZ61I=&\@:6YS=69I8VEE;G1E('!A
M<F$@96YV:6%R('!A<F$@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N`$-RZ61I
M=&\@:6YS=69I8VEE;G1E+@!.^FUE<F\@26YT96ER;P!,:7-T82!D92!);G1E
M:7)O<P!%<G)O($EN=&5R;F\`0>?C;R!I;G;A;&ED82!S96QE8VEO;F%D82!P
M87)A(&5S=&4@8V]M<&]N96YT92X`0T15("A#86)EYV%L:&\@9&4@1&%D;W,@
M9&4@57-UX7)I;RD@:6YVX6QI9&\N`$%P;&EC8>?C;R!I;G;A;&ED82X`1W)U
M<&]S(&1E($E$(&EN=N%L:61O<RX`1&%D;W,@96YV:6%D;W,@<^-O(&EN=N%L
M:61O<RX`16YD97)EYV\@9&4@9&5S=&EN;R#I(&EN=N%L:61O+@!&;W)M871O
M(&1O(&%R<75I=F\@Z2!I;G;A;&ED;P!4:7!O(&1A(&UE;G-A9V5M(.D@:6YV
MX6QI9&\N`$%P:5]I9"#I(&EN=N%L:61O(&]U(&5S=.$@9F%L=&%N9&\N`%!A
M<N)M971R;W,@:6YVX6QI9&]S(&]U(&9A;'1A;F1O+@!097)M:7-S]65S(&1O
M('!A:2!SXV\@:6YVX6QI9&%S+@!0<F]T;V-O;&\@:6YVX6QI9&\N`$1E<W1I
M;F%TX7)I;R!I;G;A;&ED;SH@)R5S)P!/8FIE=&\@8V]M<&%R=&EL:&%D;R!I
M;G;A;&ED;P!&;VYT92!D;R!E;F1E<F7G;R!I;G;A;&ED82X`1&%D;W,@=6YI
M8V]D92!I;G;A;&ED;W,N`$EN=F5N=.%R:6\`27+C+"!297#Z8FQI8V$@27-L
MXFUI8V$@9&\`27)A<75E`$ER;&%N9&$`26QH82!D;R!(;VUE;0!4<F]V;V%D
M87,@27-O;&%D87,`27-R865L`$5M:7-S;W(`273A;&EC;P!)=.%L:6$`2F%M
M86EC80!*86YE:7)O`$IA<.-O`$IA<&]NZG,@*$E33RTR,#(R+4I0*0!*97)S
M97D`2F]R9.)N:6$`2G5L:&\`2G5N:&\`2G5S=&EF:6-A<@!!;&EN:&%R(&%O
M($-E;G1R;P!*=7-T:69I8V%R`$%L:6YH87(@X"!%<W%U97)D80!!;&EN:&%R
M(.`@1&ER96ET80!#87IA<75I<W3C;P!-86YT97(@;R!O<FEG:6YA;#\`477J
M;FEA`%-E<G9I9&]R(&ME<F)E<F]S(')E:F5I=&]U(&$@875T96YT:6-AY^-O
M+@!.;W9A=&]S(&1E($ME<FYE;`!#<FEAY^-O(&1E($-H879E`$EM<')E<W/C
M;R!$:6=I=&%L(&1A($-H879E`%1A;6%N:&\@9&$@0VAA=F4`5&EP;R!D82!#
M:&%V90!5<V\@9&$@0VAA=F4`0VAA=F4@:N$@97AI<W1E(&YO('-E<G9I9&]R
M(&1E(&-H879E<R!P^F)L:6-A<RX`0W)I86[G87,`2VER:6)A=&D`0V]RZ6EA
M+"!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D80!#;W+I:6$L(%)E
M</IB;&EC82!D80!#;W)E86YO("A%54,M2U(I`$MU=V%I=`!1=6ER9W5I<W3C
M;P!,85]Y;W5T`$ED:6]M80!,86\@4F5P^F)L:6-A($1E;6]C<N%T:6-A(%!O
M<'5L87(`VFQT:6UA($UE=&%D90#:;'1I;6\@475A<G1O`-IL=&EM82!!='5A
M;&EZ8>?C;SH`VFQT:6UO(&QO9VEN.B`E<P#:;'1I;6\@;&]G:6XZ("5S(.`@
M<&%R=&ER(&1E("5S`-IL=&EM;R!L;V=I;CH@3G5N8V$`3&5T]&YI80!,96D`
M3&%Y;W5T`$1E:7AA('9A>FEO('-E('%U:7-E<B!S96T@8F]R9&$`3.UB86YO
M`$5S<75E<F1A`$-A8F7G86QH;R!E<W%U97)D;P!686QO<F5S(&1A(&5S<75E
M<F1A`$QE<V]T;P!,:6+I<FEA`$SM8FEA(,%R86)E($IA;6%H:7)I>6$`3&EE
M8VAT96YS=&5I;@!#:'5V82!&<F%C80!#:'5V82!&<F%C80!#:'5V82!&<F%C
M82!-871U=&EN80!#:'5V82!&<F%C82!697-P97)T:6YA`$QE=F5S(%!A;F-A
M9&%S(&1E($-H=79A`$-H=79A<R!&<F%C87,@8V]M(%1R;W;U97,`3F5V92!&
M<F%C80!"<F5V92!.979A<V-A`%!OZFUA<P!,:6YK`$QI;FL@87!O;G1A('!A
M<F$Z`$QI9V%R(&\@96YD97)EYV\@9&4@92UM86EL(.`@<.%G:6YA(&1E(&-O
M;7!O<VGGXV\@86\@97AI8FER`$QI;FMS`$-O;VMI92!D;R!,:6YU>`!,:7-T
M87(@+2!U<W7A<FEO('!O9&4@=F5R(&$@<&%S=&$`3&ES=&%R($)A;F-O<R!D
M92!$861O<P!,:7-T87(@5/-P:6-O<R!D92!!:G5D80!,:7-T87(@5&%B96QA
M<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,
M:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T
M86=E;2!D92!U<W7A<FEO<R!E<W3A(&1E<V%B:6QI=&%D82X`3&ET97)A='5R
M80!,:71UXFYI80!#87)R96=A;F1O(&)I8FQI;W1E8V%S+BXN`$-A<G)E9V%N
M9&\N+BX`2&]R82!L;V-A;#H@`$QO8V%L:7IAY^-O(&4@2&]R80!,;V-A;&EZ
M8>?C;P!#;VYE8W1A<@!$97-C;VYE8W1A<@!487)E9F%S(&1E($-O;F5XXV\`
M3R!L;V=I;B!F86QH;W4@<&]R<75E('-E=2!U<W7A<FEO(&]U('-E;FAA(&5S
M=&%V82!I;F-O<G)E=&$N`$9A;&AA(&1E($QO9VEN+@!386ED80!497AT;R!L
M;VYG;P!!;6]R`$)A:7AA`$%L9F%B971O(&=R96=O(&5M(&UI;OIS8W5L;P!!
M;&9A8F5T;R!L871I;F\@96T@;6EN^G-C=6QO`$[Z;65R;W,@<F]M86YO<R!E
M;2!M:6[Z<V-U;&\`3'5X96UB=7)G;P!-30!-3U1$`$\@86YE>&\@35,M5$Y%
M1B!NXV\@8V]N=.EM(&1A9&]S+@!-4T<`36%C86\`36%C961O;FEA+"!!;G1I
M9V$@4F5P^F)L:6-A($EU9V]S;.%V:6$@9&$`36%D86=A<V-A<@!-X6=I8V\`
M0V]R<F5I;P!!9&UI;FES=')A9&]R(&1O($-O<G)E:6\`0W)I87(@;&EN7VLN
M+BX`0V5R=&EF:7%U92US92!Q=64@=F]CZB!T96T@;R!014%2(&EN<W1A;&%D
M;R!E(&5S=.$@;F\@(FEN8VQU9&4@<&%T:"(N`$-R:6%N9&\@9&ER973S<FEO
M("5S`$UA;&%W:0!-86SA<VEA`$UA;&1I=F%S`$UA;&D`36%L=&$`1V5R96YC
M:6$@82!L:7-T82!D92!C871E9V]R:6%S(&4@87,@8V]R97,@87-S;V-I861A
M<R!A(&5L87,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%RYV\`36%R9V5M
M`$UA<F-A<B!C;VT@9FQA9W,@3&ED82].XV\@3&ED80!-87)C87(@8V]M(&]U
M=')O<R!F;&%G<R`H97@N($EM<&]R=&%N=&4O4F5S<&]N9&ED82D`26QH87,@
M36%R<VAA;&P`36%R=&EN:6-A`$-A;7!O<R!C;W)R97-P;VYD96YT97,`36%U
M<FETXFYI80!-875R[6-I;P!#<NED:71O(&WA>&EM;R!P97)M:71I9&\N`$[Z
M;65R;R!MX7AI;6\@9&4@<&%R=&5S(&1A(&UE;G-A9V5M(&5X8V5D974N`%1E
M;7!E<F%T=7)A(&WA>&EM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E
M<F%T=7)A(&WA>&EM82!N87,@^FQT:6UA<R`V(&AO<F%S.B``5&%M86YH;R!M
MX7AI;6\`36%I;P!-87EO='1E`$UE9&EC:6YA`$-A;F-E;&%M96YT;R!D92!2
M975N:>-O`$EN9F]R;6'GXV\@9&$@4F5U;FGC;P!0<F]P;W-T82!D92!2975N
M:>-O`%)E<W!O<W1A(.`@4F5U;FGC;P!!='5A;&EZ8>?C;R!D92!2975N:>-O
M`%-O;&EC:71AY^-O(&1E($%T=6%L:7IAY^-O(&1E(%)E=6YIXV\`365M8G)O
M<P!-;V1O(&1O(&UE;G4Z`$UE<V-L87(@8^EL=6QA<P!-97-C;&%N9&\@=&]D
M;W,@87)Q=6EV;W,@)7,N<&\@86\@8V]M<.IN9&EO+BXN(`!-97-C;&%N9&\@
M;&]C86QI>F'GXV\@)7,N+BX@`$UE<V-L86YD;R!O(&%R<75I=F\@4$\@9&4@
M)7,@86\@8V]M<.IN9&EO+BXN(`!-97-C;&%N9&\@=')A9'7GXV\@<&%R82!O
M(&WS9'5L;R`E<RXN+@!-96YS<V%G96T`365N<V%G96T@5F5R:69I8V%D82!C
M;VT@4W5C97-S;R!M87,@;R!C97)T:69I8V%D;R!D;R!A<W-I;F%N=&4@;N-O
M('#T9&4@<V5R('9E<FEF:6-A9&\N`$UE;G-A9V5M(&5X<&ER861A+@!4:7!O
M(&1E(&UE;G-A9V5M`$-L:6UA($UE=&%R`$)L;V-O($UE=&%R(&[C;R!D:7-P
M;V[M=F5L+@!";&]C;R!-971A<B!NXV\@9&ES<&]N[79E;"X@1&5T86QH97,@
M9F]R86T@9W)A=F%D;W,@96T@;&]G('!A<F$@;R!A9&UI;FES=')A9&]R+@!-
MZ71O9&\`3>ET;V1O("<E<R<@;N-O(&5S=.$@9&5F:6YI9&\`3>ET<FEC80!-
MZ7AI8V\`36EC<F]NZ7-I82P@17-T861O<R!&961E<F%D;W,@9&$`365I;P!4
M:7!O($UI;64`5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#(T(&AO
M<F%S.B``5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#8@:&]R87,Z
M(`!%<W!E;&AO`$1I=F5R<V]S`%!A8V]T92!014%2($A45%!?4F5Q=65S="!F
M86QT86YD;RX`0V]N9FEG=7)AY^-O(&9A;'1A;F1O+B!6;V/J('1E;2!Q=64@
M9V5R87(@96QA(&%G;W)A('-E('9O8^H@<75E<B!U=&EL:7IA<B!E<W1A(&%P
M;&EC8>?C;RX`240@9&$@;65N<V%G96T@9F%L=&%N9&\N`%!A8V]T92!O8G)I
M9V%T\W)I;R!014%2($UA:6P@9F%L=&%N9&\N`$E$(&1A('-E<W/C;R!F86QT
M86YD;RX`4V5G`$-O<G)E:6\@3?-V96P`36]D97)A<@!$871A($UO9&EF:6-A
M9&$`06QT97)A<B!54DP`3?-D=6QO`$WS9'5L;P!-;VQD;W9A+"!297#Z8FQI
M8V$@9&$`3?1N86-O`$UO;F?S;&EA`$WJ<R!E(&%N;P!-96YS86QM96YT90!-
M;VYT<V5R<F%T`$9A<V5S(&1A($QU80!-86ES(&-A;7!O<R!E;F-O;G1R861O
M<R!D;R!Q=64@;R!E<W!E<F%D;R`E9"X`36%R<F]C;W,`1W)A;F1E(%!A<G1E
M($QI;7!A`$=R86YD92!087)T92!.=6)L861O`$=R86YD92!087)T92!%;G-O
M;&%R861O`$UO=F5R($%B86EX;P!-;W9E<B#@($5S<75E<F1A`$UO=F5R(.`@
M1&ER96ET80!-;W9E<B!!8VEM80!-;W9E<B!A8F%I>&\`36]V97(@86-I;6$`
M36_G86UB:7%U90!,:7-T87,@9&4@<V5L9>?C;R!D92!M^FQT:7!L;W,@;NUV
M96ES`%-E;&7GXV\@;?IL=&EP;&$`36EN:&$@0V]N=&$`365U(%!O<G1A;`!-
M974@3&%Y;W5T(&1E(%!O<G1A;`!":7)MXFYI80!.PT\L($5U($[#3R!#;VYC
M;W)D;P!.;VUE`$YA;>UB:6$`3F%U<G4`3F5C97-S:71A(&1E($'GXV\`3F5P
M86P`2&]L86YD80!!;G1I;&AA<R!(;VQA;F1E<V%S`%523"!"87-E(&1O($YE
M='-C87!E`%523"!D92!2979O9V'GXV\@9&4@0T$@9&\@3F5T<V-A<&4`55),
M(&1E('!O;.UT:6-A<R!D92!#02!D;R!.971S8V%P90!54DP@9&4@4F5N;W9A
MY^-O(&1O($YE='-C87!E`%523"!D92!2979O9V'GXV\@9&\@3F5T<V-A<&4`
M3F]M92!D;R!S97)V:61O<B!34TP@9&\@3F5T<V-A<&4`0V]M96YTX7)I;R!D
M;R!C97)T:69I8V%D;R!D;R!.971S8V%P90!4:7!O(&1E(&-E<G1I9FEC861O
M(&1O($YE='-C87!E`%)E9&4`3G5N8V$`3F]V82!#86QE9/1N:6$`3F]V82!#
M871E9V]R:6$`3'5A($YO=F$`3F]V;R!5<W7A<FEO("AO<&-I;VYA;"D`3F]V
M82!:96SB;F1I80!.;W9A('-E;FAA`$YO=F$@<V5N:&$@97AP:7)A<N$@96T@
M)7@N`%-E;FAA(&YO=F$Z`$%S(&YO=F%S('-E;FAA<R!NXV\@<^-O(&EG=6%I
M<RX`3F]V82!J86YE;&$@*%]B;&%N:RD`3F]T[6-I87,`1W)U<&]S(&1E($YO
M=.UC:6%S`%!R\WAI;6$`4'+S>&EM82!0X6=I;F$`4'+S>&EM82!&87-E`%!R
M\WAI;6%S(&]PY_5E<P!.:6-A<N%G=6$`3FEG97(`3FEGZ7)I80!.;VET90!.
M:75E`$[C;P!.96YH=6T@9&%D;R!D92!C;VYF:6=U<F'GXV\@9&ES<&]N[79E
M;"!P87)A(&5X:6)I<B!A<R!D:69E<F5NYV%S+@!.96YH=6UA(&5S=')A=.EG
M:6$@9&ES<&]N[79E;"!P87)A(&-R:6%R(&EM86=E;G,@25-/+@!.96YH=6T@
M;6]D96QO(&1E(&)A=&-H+@!.96YH=6T@8FQO8V\@97AI<W1E(&YA('!O<VGG
MXV\@<V]L:6-I=&%D80!.96YH=6T@;F]M92!D92!C86QE;F3A<FEO(&9O<FYE
M8VED;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN`$YE;FAU;6$@86QT97)A
MY^-O+@!.96YH=6UA('!E<FUI<W/C;R!S=6)O<F1I;F%D82!D979E('-E<B!A
M9&EC:6]N861A(&%B86EX;R!D97-T92!N[79E;"X`3F5N:'5M('-U8F]R9&EN
M861O('!O9&4@<V5R(&%D:6-I;VYA9&\@82!E<W1A('!E<FUI<W/C;RX`3F5N
M:'5M(&-O;6%N9&\@97-P96-I9FEC861O+@!.96YH=6UA(&EN9F]R;6'GXV\@
M9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A("5S+@!.96YH=6UA
M(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A
M($944"!61E,N`$YE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@
M97-P96-I9FEC861A('!A<F$@4U%,(%9&4RX`3F5N:'5M82!I;F9O<FUAY^-O
M(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@<&%R82!344PM1FEL92!6
M1E,N`$YE;FAU;2!C<NED:71O(')E<W1A;G1E+@!.96YH=6T@9&5S=&EN;R!F
M;W)N96-I9&\N`$YE;FAU;2!R96=I<W1R;R!C;VT@;R!I9"`G)7,G(&5X:7-T
M92!N;R!A<G%U:79O(&]R:6=I;F%L(&1E(&%J=61A+@!.96YH=6T@87)Q=6EV
M;R!E;G9I861O`$YE;FAU;2#M8V]N92!E;F-O;G1R861O+@!.96YH=6UA(&QO
M8V%L:7IAY^-O(&5S<&5C:69I8V%D82X`3F5N:'5M82!L;V-A;&EZ8>?C;R!C
M;VYF:6=U<F%D82X`3F5N:'5M82!M96YS86=E;2!F;W)N96-I9&$N`$YE;FAU
M;2!N;VUE(&5S<&5C:69I8V%D;RX`3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A
M9&\N`%-E;2!S;W)T97,@;V9E;G-I=F%S`$YE;FAU;6$@<V5N:&$@9F]R;F5C
M:61A('!A<F$@82!A=71E;G1I8V'GXV\@2%144"X`3F5N:'5M82!S96YH82!F
M;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!)34%0+@!.96YH=6UA('-E
M;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O($ME<F)E<F]S+@!.
M96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O($Q$
M05`N`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'G
MXV\@3&]G:6XN`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E
M;G1I8V'GXV\@4$%34U=$+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A
M(&$@875T96YT:6-AY^-O(%--0BX`3F5N:'5M('!A=&@@<&%R82!O(&)I;N%R
M:6\@9&\@3W!E;E-33"!F;VD@9F]R;F5C:61O+B!/(&)I;N%R:6\@9&\@3W!E
M;E-33"#I(&YE8V5S<^%R:6\@<&%R82!M86YI<'5L87(@;W,@9&%D;W,@4$M#
M4R`Q,BX`3F5N:'5M(')E9VES=')O('!E;F1E;G1E+@!396T@;&EN:&%S`$YE
M;FAU;2!S97!A<F%D;W(@9F]I(&5S<&5C:69I8V%D;RX`4V5M(&QA9&]S`$YE
M;FAU;2!D:7)E=/-R:6\@=&5M<&]RX7)I;R!D:7-P;V[M=F5L('!A<F$@;R!C
M86-H92X`3F5N:'5M('5S=>%R:6\@92]O=2!S96YH82!F;W)N96-I9&]S+@!.
M96YH=6T@9&%D;R!834P@=N%L:61O(')E=&]R;F%D;P!396T@=F%L;W)E<P!.
M96YH=6T@=F5R<^-O(&5N8V]N=')A9&$@;F$@8V]N9FEG=7)AY^-O(&]R:6=I
M;F%L+B!'97)E(&YO=F%M96YT92!A(&-O;F9I9W5R8>?C;RX`3F5N:'5M82!V
M97)SXV\@96YC;VYT<F%D82!N82!S=6$@8V]N9FEG=7)AY^-O+B!'97)E(&YO
M=F%M96YT92!A(&-O;F9I9W5R8>?C;RX`4V5M(%!A<G1I8VEP86YT97,`3F5N
M:'5M80!.96YH=6UA("AU<V\@:6UP;.UC:71O*0!.\W)D:6-O("A)4T\M.#@U
M.2TQ,"D`26QH82!.;W)F;VQK`$AE;6ES9NER:6\@3F]R=&4`26QH87,@36%R
M:6%N82!D;R!.;W)T90!.;W)U96=A`$[C;R!!</-S`$[C;R!!;G1E<P!.XV\@
MZ2!U;2!D:7)E=/-R:6\`3N-O($EM<&QE;65N=&%D;RX`3N-O(&-O;F9I9W5R
M861O`$[C;R!S=7!O<G1A9&\N`$%V:7-O.B!6;V/J(&1E=F5RX2!S86ER(&4@
M<F5T;W)N87(@87#S<R!A(&UU9&%NYV$@9&$@<W5A('-E;FAA(0!.;W1A<P!.
M861A('!A<F$@97AI8FER+"!V;VQT92X`079I<V\`3F]V96UB<F\`3OIM97)O
M`$[Z;65R;R!D92!C87)A8W1E<F5S`$[Z;65R;R!D92!C;VQU;F%S`$[Z;65R
M;R!D92!L:6YH87,`3OIM97)O(&[C;R!E<W!E8VEF:6-A9&\@<&%R82!A='5A
M;&EZ8>?C;R!N82!L:7-T82!D92!D:7-T<FEB=6GGXV\N`$]+`$]B:F5T;P!#
M<FEA9&]R(&1O($]B:F5T;P!097)M:7-S]65S(&1O(&-R:6%D;W(@9&\@;V)J
M971O`$]C=&%L`$]U='5B<F\`1FEL=')A<B!O9F5N<VEV;W,`17-C<FET\W)I
M;P!396YH87,@86YT:6=A(&4@;F]V82!D979E;2!S97(@9&EF97)E;G1E<RX`
M4V5N:&$@86YT:6=A`%-E;FAA(&%N=&EG82!NXV\@97-TX2!C;W)R971A+@!3
M96YH82!A;G1I9V$Z`$]MXP!3;VUE;G1E('-E<G9I9&]R97,@24U!4"!S=7!O
M<G1A;2!P87-T87,@8V]M<&%R=&EL:&%D87,N`%-O;65N=&4@<V]R=&5S(&]F
M96YS:79A<P!3;VUE;G1E('5M(&5N9&5R9>=O(&1E(&4M;6%I;"!P97)M:71I
M9&\N`%-O;65N=&4@;R!P<F]P<FEE=.%R:6\@;W4@;R!A9&UI;FES=')A9&]R
M(&1O('-I<W1E;6$@<&]D96T@86QT97)A<B!A<R!P97)M:7-S]65S(&1E('!R
M;W!R:65D861E(&]U('!R;W!R:65TX7)I;R!D92!U;2!C;VUP87)T:6QH86UE
M;G1O`$%B<FER(&5M('5M82!N;W9A(&IA;F5L80!%<G)O(&1O($]P96Y34TPZ
M($[C;R!P=61E(&5X=')A:7(@9&%D;W,@9&$@<&%R=&4@87-S:6YA9&$@4R]-
M24U%+@!!8G)E(&5S=&4@;&EN:R!E;2!U;6$@;F]V82!J86YE;&$`4VES=&5M
M82!/<&5R86-I;VYA;`!087)T:6-I<&%N=&4@3W!C:6]N86P`3W#G]65S`$]P
MY_5E<R!D92`E<P!/<.?U97,Z`$QI<W1A($]R9&5N861A`$]R9V%N:7IAY^-O
M`%5N:61A9&4@3W)G86YI>F%C:6]N86P`3W)G86YI>F%N9&\`36]D96QO(&]R
M:6=I;F%L(&1E(&%P;&EC8>?C;P!-;V1E;&\@;W)I9VEN86P@96T@)7,Z`$]U
M=')O`$]U=')A<R!);F9O<FUAY_5E<P!097)M:7-S]65S(&1O(%!R;W!R:65T
MX7)I;P!!=71E;G1I8V'GXV\@4$%-(&[C;R!E<W3A(&1I<W!O;NUV96PN`$%S
M<VEN871U<F$@1&EG:71A;"!01U``1&%D;W,@0W)I<'1O9W)A9F%D;W,@8V]M
M(%!'4`!#:&%V92!0^F)L:6-A(%!'4`!$861O<R!!<W-I;F%D;W,O0W)I<'1O
M9W)A9F%D;W,@8V]M(%!'4`!#\V1I9V\@4$A0`$QI;FAA(&1E($-O;6%N9&\@
M4$A0`$-H=79A($9R86-A(%9E<W!E<G1I;F$`0VAU=F%S(%9E<W!E<G1I;F%S
M`$YE=F%S8V$@5F5S<&5R=&EN80!4<F]V;V%D87,@5F5S<&5R=&EN87,`3&EN
M:&$@9&4@0V]M86YD(%!?2%``36%R9V5M`%!A<75I<W3C;P!086QA=0!086QE
M<W1I;F\L(%1E<G)I=/-R:6\@3V-U<&%D;P!086YA;>$`4.%P=6$@3F]V82!'
M=6ENZ0!087)A9W5A:0!087)C:6%L;65N=&4@3G5B;&%D;P!396YH80!396YH
M82!A;'1E<F%D82!C;VT@<W5C97-S;RX`4V5N:&$@;6]D:69I8V%D82$`4V5N
M:&$@:6YC;W)R971A`$\@;?-D=6QO(&1E('-E;FAA(&[C;R!E<W3A(&-O;F9I
M9W5R861O(&-O<G)E=&%M96YT90!396YH82!O8G)I9V%T\W)I82!P87)A(&$@
M875T96YT:6-AY^-O(%)!1$E54RX`4V5N:&$@8V]M(&-O;F9I<FUAY^-O`%-E
M;FAA.@!396YH83H@`%-E;FAA<R!D979E;2!S97(@:6=U86ES+@!#;VQA<@!#
M;VQA<B!D82#A<F5A(&1E('1R86YS9F5RZFYC:6$`4&%T:`!296=I<W1R;W,@
M4&5N9&5N=&5S.@!097-S;V%S`%!O<F-E;G1A9V5M`$5X96-U=&%R($]P97)A
MY_5E<R!D92!-86YU=&5NY^-O`$5X96-U=&%R(&]P97)AY_5E<R!D92!M86YU
M=&5NY^-O(&%O(&-O;F5C=&%R/P!097)M:7-S]65S`%!E<FUI<W/U97,@)R5S
M)R!NXV\@97AC;'7M9&%S+@!!9&UI;FES=')AY^-O(&1E(%!E<FUI<W/U97,`
M4&5R;6ES<_5E<R!D90!);F9O<FUAY_5E<R!097-S;V%I<P!097)U`$%N:6UA
M:7,@9&4@17-T:6UAY^-O`$9I;&EP:6YA<P!496QE9F]N90!&;W1O<P!0:71C
M86ER;@!0:7AE;',`0VQI8VCI`%!O<B!F879O<B!C;&EQ=64@96T@86QG=6UA
M(&/I;'5L80!0;W(@9F%V;W(@8V]N9FER;64@<75E('9O8^H@<75E<B!R96UO
M=F5R(&5S=&4@96QE;65N=&\Z`%!O<B!F879O<B!C;VYF:7)M92!Q=64@=F]C
MZB!Q=65R(')E;6]V97(@;R!L:6YK(&1E<W1E(&5L96UE;G1O+@!0;W(@9F%V
M;W(@9F]R;F7G82!U;2!MZG,@92!U;2!A;F\N`%!O<B!F879O<B!F;W)N9>=A
M('5M(&YO;64@<&%R82!A(&YO=F$@8V%T96=O<FEA.@!0;W(@9F%V;W(@9F]R
M;F7G82!U;2!E;F1E<F7G;R!)4"!VX6QI9&\N`%!O<B!F879O<B!F;W)N9>=A
M('5M82!D871A(';A;&ED82P@=F5R:69I<75E(&\@;OIM97)O(&1E(&1I87,@
M;F\@;>IS+@!0;W(@9F%V;W(@9F]R;F7G82!U;6$@:&]R82!VX6QI9&$N`%!O
M<B!F879O<B!F;W)N9>=A('5M(')E<W5M;R!D;R!P<F]B;&5M82X`4&]R(&9A
M=F]R(&9O<FYEYV$@<V5U('5S=>%R:6\@92!S96YH80!0;W(@9F%V;W(@;&5I
M82!O('1E>'1O(&$@<V5G=6ER+B!6;V/J($1%5D4@8V]N8V]R9&%R(&-O;2!O
M<R!T97)M;W,@9&4@=7-O(&1O('-I<W1E;6$N`%!O<B!F879O<B!R96QA=&4@
M<75A;'%U97(@8G5G('!A<F$@:3$X;D!L:7-T<RYH;W)D92YO<F<N`%!O<B!F
M879O<B!R979E:F$@82!S96=U:6YT92!I;F9O<FUAY^-O+"!E(&5N=.-O('-E
M;&5C:6]N92!U;6$@8>?C;R!A('!A<G1I<B!D;R!M96YU(&%B86EX;RX`4&]R
M(&9A=F]R('-E;&5C:6]N92!U;6$@8>?C;R!A('!A<G1I<B!D;R!M96YU(&%C
M:6UA+@!0;W(@9F%V;W(@9&EG:71E(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I
M83H`4&]L]&YI80!0;VSM=&EC80!%;G%U971E`%!O<G1U9V%L`%!O<VGGXV\@
M9&5S=&$@:6UA9V5M`%!O<VGGXV\@9&5S=&$@=&%B96QA`$5N=FEE('!A<F$@
M97-T82!P87-T82`H;N-O(.D@;V)R:6=A9&\@<&5L;R!)34%0*0!0<F5C:7!I
M=&'GXV\@<&%R82!A*',I(/IL=&EM82AS*2`E<R!H;W)A*',I.B``4')E9G-?
M;&1A<#H@17AT96YSXV\@3$1!4"!O8G)I9V%T\W)I82!NXV\@96YC;VYT<F%D
M82X`4')E9G-?<V5S<VEO;CH@17AT96YSXV\@9&4@<V5S<^-O(&]B<FEG873S
M<FEA(&[C;R!E;F-O;G1R861A+@!!<')E<V5N=&'G]65S`%!R97-SXV\`4')E
M<W/C;R!E;2!N[79E;"!D;R!M87(Z(`!0<F5S<^-O.B``4'+I+79I<W5A;&EZ
M8>?C;P!0<F5V97(@82!I;6%G96T@96T@=6UA(&YO=F$@:F%N96QA`%#A9VEN
M82!!;G1E<FEO<@!/<.?U97,@86YT97)I;W)E<P!);7!R:6UI<B!D;V-U;65N
M=&\`0VAA=F4@4')I=F%D80!0<F]B;&5M80!$97-C<FGGXV\@9&\@4')O8FQE
M;6$`4')O8FQE;6$_`%!R;VIE=&]S`%1E>'1O(&)R979E`$-H879E(%#Z8FQI
M8V$`06QG;W+M=&EM;R!D82!#:&%V92!0^F)L:6-A`%!A<B!D92!C:&%V97,@
M4/IB;&EC82]0<FEV861A(&[C;R!F;W)A;2!G97)A9&]S(&-O;2!S=6-E<W-O
M+@!0;W)T;R!2:6-O`%%A=&%R`$-O;G-U;'1A<@!#:&%V92!0^F)L:6-A(%)3
M02`H)60@8FET*0!";W3U97,@9&4@<V5L9>?C;P!#:'5V80!#:'5V82!-871U
M=&EN80!#:'5V82!697-P97)T:6YA`%!A;F-A9&%S(&1E($-H=79A`$-H=79A
M(&4@3F5V90!3;W)T92!!;&5A=/-R:6$`4F5L8>?C;P!,97(`3&5R(&UE;G-A
M9V5N<P!%>&-L=6ER(')E86QM96YT92`E<S\@17-T82!O<&5R8>?C;R!NXV\@
M<&]D92!S97(@9&5S9F5I=&$N`%)E;6]V97(@<F5A;&UE;G1E(&]S(&1A9&]S
M(&1O('5S=>%R:6\@)7,_($5S=&$@;W!E<F'GXV\@;N-O('!O9&4@<V5R(&1E
M<V9E:71A+@!2969A>B!S=6$@^FQT:6UA(&'GXV\`071U86QI>F%R($UE;G4@
M9&4@16QE;65N=&]S($1I;N)M:6-O<SH`071U86QI>F%R($5X:6)IY^-O(&1O
M(%!O<G1A;#H`4F5G97@`3F%V96=A9&]R(&1E(%)E;&'G]65S`$]B<V5R=F'G
M]65S`$QE;6)R87(@82!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\N`%-E<G9I
M9&]R97,@4F5M;W1O<P!54DP@4F5M;W1A("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`4F5M;W9E<@!296UO=F5R($)L;V-O`%)E;6]V97(@8V]L
M=6YA`%)E;6]V97(@9F]R;6%T8>?C;P!296UO=F5R(&1O(&UE=2!C86QE;F3A
M<FEO`%)E;6]V97(@<&%R`%)E;6]V97(@<V-R:7!T(&=R879A9&\@;F\@9&ER
M973S<FEO('1E;7!O<N%R:6\@9&\@<V5R=FED;W(N`%)E;6]V97(@;P!296UO
M=F5R(&5S=&4@;O,@9&\@9&]C=6UE;G1O`%)E;6]V97(@=7-UX7)I;P!296UO
M=F5R('5S=>%R:6\Z("5S`%)E<W!O<W1A($5N=FEA9&$N`%)E<W!O;F1E<B!C
M;VT@365N<V%G96T@3N-O(%-U<&]R=&%D80!297-P;VYD97(@8V]M(&EN9F]R
M;6'GXV\@;&EV<F4O;V-U<&%D;R!D=7)A;G1E(#(@;65S97,N`%)E<W!O;F1E
M<B!C;VT@<V]L:6-I=&'GXV\@9&4@:6YF;W)M8>?C;R!L:79R92]O8W5P861O
M+@!297-P;VYD97(Z("5S`%-O;&EC:71AY^-O(&[C;R!P]&1E('-E<B!R97-P
M;VYD:61A+B!#\V1I9V\@9&4@97)R;R!R971O<FYA9&\Z(``G)7,G(&]B<FEG
M873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R`E
M<RX`)R5S)R!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C
M;VYF:6=U<F'GXV\@5D93+@`G)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P
M96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;RX`4&%R=&EC:7!A;G1E($]B<FEG
M873S<FEO`$QI;7!A<@!'97)A<B!.;W9A(%-E;FAA`$=E<F%R($YO=F$@4V5N
M:&$`4F5S=6QT861O<P!297-U;'1A9&]S("AI;F-L=6EN9&\@2&]R9&4I.@!2
M97-U;'1A9&]S.@!2971O<FYA<B#@($]PY_5E<P!$:6=I=&4@82!N;W9A('-E
M;FAA(&YO=F%M96YT90!2975N:>-O`%)E=F5R=&5R($-O;F9I9W5R8>?C;P!/
M<.?U97,@9&\@161I=&]R(%)I8V@@5&5X=`!#:&%R861A<P!$:7)E:71A`$-A
M8F7G86QH;R!D:7)E:71O`%9A;&]R97,@9&$@9&ER96ET80!0<F]P<FEE9&%D
M97,@9&$@7TQI;FAA+BXN`%)E9W)A`%)O;>IN:6$`1VER87(@,3@P(&=R875S
M`$=I<F%R('!A<F$@82!%<W%U97)D80!':7)A<B!P87)A(&$@1&ER96ET80!0
M<F]P<FEE9&%D97,@9&$@3&EN:&$`4')O<')I961A9&5S(&1A(&QI;FAA`$QI
M;FAA<SH`3&EN:&%S`$QI;FAA<R!A<&%R96-E<N-O(&5N=')E('1O9&%S(&%S
M(&QI;FAA<R!E(&-O;'5N87,`3&EN:&%S(&%P87)E8V5RXV\@<V]M96YT92!E
M;G1R92!C;VQU;F%S`$QI;FAA<R!A<&%R96-E<N-O('-O;65N=&4@96YT<F4@
M;&EN:&%S`$5X96-U=&%R`$9E9&5R8>?C;R!2=7-S80!2=6%N9&$`07-S:6YA
M='5R82!#<FEP=&]G<N%F:6-A(%,O34E-10!-96YS86=E;2!#<FEP=&]G<F%F
M861A(&-O;2!3+TU)344`075T96YT:6-AY^-O(%-!4TP@;N-O(&5S=.$@9&ES
M<&]N[79E;"X`0V]R<F5I;R!335,`3&EN:&$@9&4@8V]M86YD;R!344P`4U,`
M4U-(`%-50T534T\`3&EN:&$@9&4@8V]M86YD;R!37U%,`%-A8@!386YT82!(
M96QE;F$`4^-O($MI='1S(&4@3F5V:7,`4V%N=&$@3'5Z:6$`4^-O(%!E9')O
M(&4@36EQ=65L;VX`4^-O(%9I8V5N=&4@92!'<F%N861I;F%S`$UE<VUO(&9R
M86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3XV\@5&]MZ2!E(%!R[6YC
M:7``4')O=F5D;W(@9&4@4V%TZ6QI=&4`07+A8FEA(%-A=61I=&$`4V%L=F%R
M`%-A;'9A<B`E<P!386QV87(@)R5S)P!386QV87(@3W#G]65S`%-A;'9A<B!C
M;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@<V-R:7!T(%!(4"!P87)A(&\@
M9&ER973S<FEO('1E;7!O<N%R:6\@9&\@<V5U('-E<G9I9&]R+@!#;VYF:6=U
M<F'GXV\@)7,@<V%L=F$N`%-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF
M:6=U<F'GXV\@<V%L=F\@96TZ("<E<R<N`$-IZFYC:6$`4')O8W5R87(`16YG
M:6YE<R!D92!0<F]C=7)A`%!R;V-U<F%N9&\@87!L:6-AY_5E<R!(;W)D92!E
M;2`E<P!0<F]C=7)A;F1O(&)I;N%R:6]S(&1O(&=E='1E>'0N+BX`4V5L96-I
M;VYE(&]S($%R<75I=F]S`%-E;&5C:6]N92!U;6$@9&%T80!396QE8VEO;F4@
M=6T@9W)U<&\@<&%R82!A9&EC:6]N87(`4V5L96-I;VYE('5M(&YO=F\@;65M
M8G)O`%-E;&5C:6]N92!U;2!S97)V:61O<@!396QE8VEO;F4@=6T@=7-UX7)I
M;R!P87)A(&%D:6-I;VYA<@!396QE8VEO;F4@=&]D;W,@;W,@8V]M<&]N96YT
M97,@9&4@9&%T82X`4V5L96-I;VYE('5M(&]B:F5T;P!396QE8VEO;F4@;W,@
M8V%R86-T97)E<R!Q=64@=F]CZB!P<F5C:7-A(&YA(&-A:7AA(&%B86EX;RX@
M5F]CZB!P;V1E(&5N=.-O(&-O<&GA+6QO<R!E(&-O;.$M;&]S(&YA(.%R96$@
M9&4@=&5X=&\N`%-E;&5C:6]N92!U;2!D96QI;6ET861O<B!D92!D871A.@!3
M96QE8VEO;F4@;R!F;W)M871O(&1E(&1A=&$Z`%-E;&5C:6]N92!A(&ED96YT
M:61A9&4@<75E('9O8^H@<75E<B!A;'1E<F%R.@!396QE8VEO;F4@=6T@9&5L
M:6UI=&%D;W(@9&4@:&]R83H`4V5L96-I;VYE(&\@9F]R;6%T;R!D92!H;W)A
M.@!396QE8VEO;F4@9&]I<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S+@!396QE
M8VEO;F4@<V5U(&5S<75E;6$@9&4@8V]R97,N`%-E;&5C:6]N92!S974@:61I
M;VUA('!R969E<FED;SH`16YV:6%R(-IL=&EM87,@26YF;W)M8>?U97,`16YV
M:6%R(%)E;&%T\W)I;R!D92!0<F]B;&5M80!%;G9I87(@4TU3`%-E;F5G86P`
M4V5N<V]R.B``4V5T96UB<F\`4V5R=FEA(&4@36]N=&5N96=R;P!.^FUE<F\@
M9&4@4^ER:64`240@9&$@4V5S<^-O(&5X<&ER;W4N`%!R;VYT;P!#;VYF:6=U
M<F$@87,@;W#G]65S('!A<F$@<&5R;6ET:7(@=F]CZB!G97)A<B!U;6$@;F]V
M82!S96YH82!S92!V;V/J(&5S<75E8^HM;&$N`$-O;F9I9W5R82!O<R!S97)V
M:61O<F5S(')E;6]T;W,@<75E('9O8^H@<75E<B!A8V5S<V%R(.`@<&%R=&ER
M(&1O('!O<G1A;"X`0V]N9FEG=7)A('-E=2!I9&EO;6$@<')E9F5R:61O+"!F
M=7-O(&AO<N%R:6\@92!O<.?U97,@9&4@9&%T82X`0V]N9FEG=7)A('-U82!A
M<&QI8V'GXV\@:6YI8VEA;"P@97-Q=65M82!D92!C;W)E<RP@871U86QI>F'G
MXV\@9&4@<.%G:6YA<R!E(&]U=')A<R!O<.?U97,@9&4@97AI8FGGXV\N`%-C
M<FEP=',@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV
M96ES`$1I=F5R<V%S(&QO8V%L:61A9&5S('!O<W/M=F5I<R!C;VT@;R!P87+B
M;65T<F\Z(`!396EC:&5L97,`0V]M<')A<P!297-U;6\`5&5C;&%S(&1E(&%T
M86QH;R!D979E<N)O('-E<B!D969I;FED87,@<&%R82!A(&UA:6]R:6$@9&]S
M(&QI;FMS/P!%>&EB:7(`17AI8FER(&%S(&1I9F5R96[G87,@96YT<F4@82!C
M;VYF:6=U<F'GXV\@871U86P@92!A(&YO=F$@9V5R861A+@!%>&EB:7(@9&%T
M82!E(&AO<F$@9&$@^FQT:6UA(&-O;F5XXV\@86\@<V4@8V]N96-T87(_`$5X
M:6)I<B!A(&]PY^-O(&1E(&UA;G1E<B!O(&]R:6=I;F%L`$5X:6)I<B!S96QE
M=&]R`$5X:6)I<B!B87)R82!D92!M96YU(&-O;2!O<&5R8>?U97,@9&4@=&%B
M96QA/P!%>&EB:7(@;R!-96YU("5S(.`@97-Q=65R9&$_`$5X:6)I<B!D:>%L
M;V=O(&1E(%!R;W!R:65D861E<R!D92!#Z6QU;&%S(&1A(%1A8F5L80!%>&EB
M:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&$@5&%B96QA`$5X:6)I<B!D
M:>%L;V=O(&1E(%!R;W!R:65D861E<R!D92!,:6YH87,@9&$@5&%B96QA`$5X
M:6)I<B!D:>%L;V=O(&1E('!R;W!R:65D861E<R!D92!I;6%G96T`17AI8FER
M('5P;&]A9`!#:'5V87,`0VAU=F%S(&UA=&EN86ES`$-H=79A<R!697-P97)T
M:6YA<P!#:'5V87,@;F%S(')E9&]N9&5Z87,`4F5D=7II<@!0<FEM96ER86UE
M;G1E(')E9'5Z82!O=2!T:7)E(&1O(&-A;6EN:&\@;RAS*2!B;&]C;RAS*2!A
M9&IA8V5N=&4H<RD`4V5R<F$@3&5O80!296=I<W1R87(`4F5G:7-T<F%R('-E
M(&[C;R!E<W1I=F5R(')E9VES=')A9&\`07-S:6YA='5R80!!;&=O<NUT:6UO
M(&1A($%S<VEN871U<F$`0VEN9V%P=7)A`%1A;6%N:&\`26=N;W)A<B!-86YU
M=&5NY^-O`$EG;F]R861O+BXN`$5S;&]VX7%U:6$`17-L;W9E;FEA`$YE=F4`
M3F5V87-C80!.979A<V-A<P!.979A<V-A<R!697-P97)T:6YA<P!0<F]F=6YD
M:61A9&4@9&$@3F5V93H@`$5Q=6EV86QE;G1E(&1E(&YE=F4@96T@X6=U83H@
M`$EL:&%S(%-A;&]MXV\`4V]MX6QI80!!;&=U;G,@87)Q=6EV;W,@9&\@;?-D
M=6QO(%-E;FAA(&[C;R!F;W)A;2!E;F-O;G1R861O<P!#86[G]65S(&4@4&]E
M;6%S`$]R9&5N87(@<V5L9>?C;P!%;F1E<F7G;R!D92!O<FEG96T`P69R:6-A
M(&1O(%-U;`!3=6P@175R;W!E=2`H25-/+3@X-3DM,RD`4W5L(&1A($=E;W)G
M:6$@92!3=6P@9&%S($EL:&%S(%-A;F1U[6-H90!(96UI<V;I<FEO(%-U;`!%
M<W!AYV\@96YT<F4@8^EL=6QA<R!A9&IA8V5N=&5S`$5S<&'G;R!E;G1R92!O
M(&-O;G1E^F1O(&4@8F]R9&$@9&$@8^EL=6QA`$5S<&'G861O<@!%<W!AYV%M
M96YT;P!%<W!AYV%M96YT;R!E(&UA<F=E;0!%<W!A;FAA`%-P86T`16YT<F%D
M82!D92!#87)A8W1E<F5S($5S<&5C:6%I<P!$:79I9&ER(&/I;'5L80!$:79I
M9&ER(&-O;'5N80!$:79I9&ER(&QI;FAA`$5S<&]R=&5S`%-R:2!,86YK80!0
M861RXV\`4W1A<B!4<F5K`$EN:6-I87(`06YO(&EN:6-I86P`17-T861O(&]U
M(%!R;W;M;F-I80!%<W1A9&\`17-T861O(&1A(&QO8V%L:7IAY^-O("5S+BXN
M(`!&;W)M871O(&1O(&%R;6%Z96YA;65N=&\`3F]M92!D82!2=6$`5')AYV%D
M;P!,:7-T82!D92!C861E:6%S(&1E(&-A<F%C=&5R97,`4F5T:7)A<B!A('!A
M<G1E(&1O(&1O;>UN:6\@9&\@96YD97)EYV\`17-T:6QO(%M#4U-=`$1O;0!3
M=6)D:7)E=/-R:6\@)R5S)R!NXV\@96YC;VYT<F%D;RX`07-S=6YT;P!);F9O
M<FUAY^-O(&1A($-H879E(%#Z8FQI8V$@9&\@07-S=6YT;P!%;G9I87(`16YV
M:6%D82!A('-O;&EC:71AY^-O('!A<F$@861I8VEO;F%R("<E<R<@86\@<VES
M=&5M82X@5F]CZB!NXV\@<&]D92!C;VYE8W1A<BUS92!A=.D@<75E('-U82!S
M;VQI8VET8>?C;R!S96IA(&%P<F]V861A+@!3=6)S8W)E=F5R`%-U8V5S<V\`
M)R5S)R!A9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N`$]S(&1A
M9&]S(&1O('5S=>%R:6\@)R5S)R!F;W)A;2!R96UO=FED;W,@9&\@<VES=&5M
M82!C;VT@<W5C97-S;RX`)R5S)R!E>&-L=6ED;R!C;VT@<W5C97-S;RX`17AC
M;'7M9&\@)R5S)R!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+@!#;VYF:6=U<F'G
MXV\@<F5V97)T:61A(&-O;2!S=6-E<W-O+B!!='5A;&EZ92!P87)A('9E<B!A
M<R!A;'1E<F'G]65S+@!"86-K=7`@9&$@8V]N9FEG=7)AY^-O("5S('-A;'9O
M(&-O;2!S=6-E<W-O+@!"86-K=7`@9&$@8V]N9FEG=7)AY^-O('-A;'9A(&-O
M;2!S=6-E<W-O+@`G)7,G(&%T=6%L:7IA9&\@8V]M('-U8V5S<V\`)7,@9W)A
M=F%D;R!C;VT@<W5C97-S;P!3=63C;P!297-U;6\`06UA;FAE8V5R`%#T<BUD
M;RU3;VP`16YS;VQA<F%D;P!!;6%N:&5C97(`06UA;FAE8V5R+U#T<BUD;RU3
M;VP`06UA;FAE8V5R.B``4/1R+61O+5-O;`!0]'(M9&\M4V]L.B``4V]B<F5S
M8W)E=F5R`%-U<&]R=&4`4W5R:6YA;64`4V]B<F5N;VUE`%-V86QB87)D(&4@
M2F%N($UA>65N`%-U87II;.)N9&EA`%-UZ6-I80!3=>WG80!%<G)O(&1E('-I
M;G1A>&4@;F]S('1E<FUO<R!D82!P<F]C=7)A`%)E</IB;&EC82#!<F%B92!D
M82!3[7)I80!4<F]V;V%D80!4<F]V;V%D87,`07)Q=6EV;R!44U8`5&%B96QA
M`%!R;W!R:65D861E<R!D82!486)E;&$`4')O<')I961A9&5S(&1A('1A8F5L
M80!&;W)M;W-A`$9O<FUO<V$L(%!R;W;M;F-I82!D82!#:&EN80!486II<75I
M<W3C;P!486YZXFYI82P@4F5P^F)L:6-A(&1A`$%L=F\Z`%1A<F5F87,`3OIM
M97)O(&1E(%1E;&5F;VYE`%1E;7!E<F%T=7)A('!A<F$@82#Z;'1I;6$@:&]R
M83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``36]D96QO("<E<R<@;N-O
M(&5N8V]N=')A9&\N`$%D;6EN:7-T<F'GXV\@9&4@36]D96QO<P!!8V5I=&%R
M('-O;&EC:71AY^-O('!R;W9I<V]R:6%M96YT90!!8V5I=&\@<')O=FES;W)I
M86UE;G1E`%1E>'1O`%-O;65N=&4@5&5X=&\`06QI;FAA;65N=&\@9&4@5&5X
M=&\`0F]R9&$@<W5P97)I;W(@9&\@5&5X=&\`475I`%1A:6QA;F3J<R`H5$E3
M+38R,"D`5&%I;.)N9&EA`$]B<FEG861O('!O<B!U=&EL:7IA<B!O('-I<W1E
M;6$N`$\@87)Q=6EV;R!D92!A:G5D82`E<R!P87)A("5S(&[C;R!E>&ES=&4@
M86EN9&$N($-R:64@=6T@;F]V;RX`02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@
M9&ES<&]N[79E;"X`02!E;F=I;F4@9&4@:6YT96=R8>?C;R!(;W)D92]+;VQA
M8B!NXV\@<W5P;W)T82`B)7,B`$$@8VQA<W-E(")-86EN=&5N86YC93HZ(B!N
MXV\@9F]I(&-A<G)E9V%D82!C;VT@<W5C97-S;P!!(&IA;F5L82!D92!/<.?U
M97,@9F]I(&9E8VAA9&$N(%-A:6YD;RX`3R!A9&UI;FES=')A9&]R('!R96-I
M<V$@8V]N9FEG=7)A<B!U;2`B8F%C:V5N9"(@<&5R;6%N96YT92!D92!097)M
M:7-S]65S('-E('9O8^H@<75E<B!U=&EL:7IA<B!097)M:7-S]65S+@!3;VUE
M;G1E(&\@;&%D;R!D92!B86EX;P!/<R!D861O<R!D;R!C86QE;F3A<FEO('/C
M;R!I;G;A;&ED;W,`3R!N^FUE<F\@240@9&\@8V]N=&%T;R!NXV\@9F]I(&5S
M<&5C:69I8V%D;RP@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O
M;G1R861O(&YO(&)A;F-O(&1E(&1A9&]S+@!/(&-O;G1A=&\@9F]I(&%D:6-I
M;VYA9&\@8V]M('-U8V5S<V\@86\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O
M<RX`4&%R82!V97)I9FEC87(@82!M96YS86=E;2!A<W-I;F%D82#I(&YE8V5S
M<^%R:6\@=6T@8FQO8V\@<V5P87)A9&\@9&$@87-S:6YA='5R82!01U`N`$\@
M240@9&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC
M861O+"!D96EX861O(&5M(&)R86YC;R!O=2!NXV\@9F]I(&5N8V]N=')A9&\@
M;F\@8F%N8V\@9&4@9&%D;W,N`$$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C
M;R!F;VD@97-P96-I9FEC861A+@!!<R!F=6[G]65S(&1E(&-R:7!T;V=R869I
M82!R97%U97)E;2!U;6$@8V]N97CC;R!W96(@<V5G=7)A+@!/(&5V96YT;R!F
M;VD@861I8VEO;F%D;R!A;R!S974@8V%L96YDX7)I;RX`3R!A<G%U:79O("5S
M(&1E=F5R:6$@8V]N=&5R('5M82!C;VYF:6=U<F'GXV\@9&4@)7,N`$\@87)Q
M=6EV;R`E<R!D979E<FEA(&-O;G1E<B!A;&=U;6%S(&-O;F9I9W5R8>?U97,@
M9&4@)7,N`$\@87)Q=6EV;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A(&5L
M92!M97-M;RX`3R!A<G%U:79O(&[C;R!C;VYTZ6T@9&%D;W,N`%-E9W5E;2!O
M<R!C86)EYV%L:&]S(&1E<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F8S@R,BX`
MR2!S86)I9&\@<75E(&\@;6]D;R!T96QA(&-H96EA(&-A=7-A('!R;V)L96UA
M<R!C;VT@;R!);G1E<FYE="!%>'!L;W)E<BP@96T@=FER='5D92!D92!B=6=S
M(&1O(&YA=F5G861O<B!Q=64@;O-S(&[C;R!E<W1A;6]S(&%P=&]S(&$@8V]N
M=&]R;F%R+B!6;V/J('!O9&4@;V)S97)V87(@97)R;W,@9&4@97AI8FGGXV\L
M(&9A;'1A(&1E(&9U;N?U97,@9&\@961I=&]R(&4O;W4@=')A=F%M96YT;W,@
M86QE873S<FEO<R!D;R!N879E9V%D;W(N(%-E('-E=2!S:7-T96UA(.D@5VEN
M9&]W<R`Y>"#I(&UU:71O('!R;W;A=F5L('%U92!V;V/J(')E8V5B82!U;2!E
M<G)O(&1E("=&86QH82!'97)A;"!D92!0<F]T9>?C;R<@92!P<F5C:7-A<N$@
M<F5I;FEC:6%R+B!<;EQN(%9O8^H@9F]I(&%V:7-A9&\N(%!O<B!F879O<B!P
M<F5S<VEO;F4@3TL@<V4@=F]CZB!A:6YD82!Q=65R('1E;G1A<B!U<V%R(&\@
M961I=&]R(&1E('1E;&$@8VAE:6$N`$\@87)Q=6EV;R!D92!A:G5D82`E<R!N
MXV\@:6YI8VEO=2!C;VT@/#]X;6P`02!I9&5N=&ED861E("(E<R(@9F]I(&5X
M8VQU[61A+@!3;VUE;G1E(&\@;&%D;R!E<W%U97)D;P!!(&QO8V%L:7IAY^-O
M(&1O(&)I;N%R:6\@9&\@1VYU4$<@9&5V92!S97(@9F]R;F5C:61A(.`@8VQA
M<W-E(")#<GEP=%]P9W`Z.B(N`$$@;65N<V%G96T@96YV:6%D82!E;2`E<R!P
M87)A("5S(&-O;2!O(&%S<W5N=&\@(B5S(B!F;VD@97AI8FED82X*27-T;R!N
MXV\@9V%R86YT92!Q=64@82!M96YS86=E;2!F;VD@;&ED82!O=2!E;G1E;F1I
M9&$N`$\@;F]M92!U=&EL:7IA9&\@86\@=FEN8W5L87(@82!PX6=I;F$@9&4@
M8V]M<&]S:>?C;P!/(&[Z;65R;R!D92!C86UP;W,@9&5V92!S97(@;G5MZ7)I
M8V\N`$\@;?-D=6QO(&]P96YS<VP@Z2!O8G)I9V%T\W)I;R!P87)A(&$@8VQA
M<W-E(")(;W)D95]#<GEP=%]S;6EM93HZ(BX`02!P<F5F97+J;F-I82`B)7,B
M(&[C;R!P;V1E('-E<B!S86QV82!P;W)Q=64@<V5U<R!D861O<R!E>&-E9&5R
M86T@;R!T86UA;FAO(&WA>&EM;R!P97)M:71I9&\`3R!P<F]G<F%M82!U=&EL
M:7IA9&\@<&%R82!V:7-U86QI>F%R(&5S=&4@=&EP;R!D92!D861O("@E<RD@
M;N-O(&9O:2!E;F-O;G1R861O(&YO('-I<W1E;6$N`$\@8V%R86-T97)E('!A
M<F$@8VET8>?C;R!D92!S97(@87!E;F%S('5M+@!3;VUE;G1E(&]S(&QA9&]S
M(&1I<F5I=&\@92!E<W%U97)D;P!3;VUE;G1E(&\@;&%D;R!D:7)E:71O`$\@
M<V5P87)A9&]R(&1E=F4@<V5R('5M(/IN:6-O(&-A<F%C=&5R92X`3R!S97)V
M:61O<B`B)7,B(&9O:2!E>&-L=>UD;RX`3R!S97)V:61O<B`B)7,B(&9O:2!S
M86QV;RX`02!S;VQI8VET8>?C;R!D92!R96=I<W1R;R!D92`E<R!F;VD@97AC
M;'7M9&$N`$$@;&EN:&$@97-P96-I9FEC861A(&[C;R!E>&ES=&4N`$$@=&%R
M969A(&9O:2!A9&EC:6]N861A(&$@<W5A(&QI<W1A(&1E('1A<F5F87,N`%-O
M;65N=&4@;W,@;&%D;W,@9&4@8VEM82!E(&1E(&)A:7AO`%-O;65N=&4@;R!L
M861O(&1E(&-I;6$`3W,@9&%D;W,@96YV:6%D;W,@9F]R86T@<&5R9&ED;W,@
M9&5S9&4@;R!P87-S;R!A;G1E<FEO<BX`3R!A<G%U:79O(&5N=FEA9&\@;N-O
M('#T9&4@<V5R('-A;'9O+@!!(&EN9F]R;6'GXV\@;&EV<F4O;V-U<&%D;R!D
M;R!U<W7A<FEO(&9O:2!A<FUA>F5N861A(&-O;2!S=6-E<W-O+@!/(&)L;V-O
M(")W96%T:&5R+F-O;2(@;N-O(&5S=.$@9&ES<&]N[79E;"X`3R!D:7)E=/-R
M:6\@9&4@=&5M87,@)R5S)R!NXV\@9F]I(&5N8V]N=')A9&\N`$[C;R!E>&ES
M=&5M(&]PY_5E<R!D:7-P;V[M=F5I<RX`3N-O(&5X:7-T96T@<&%R=&5S('%U
M92!P;W-S86T@<V5R(&5X:6)I9&%S(&EN8V]R<&]R861A<RX`17AI<W1E;2!M
M=6ET;W,@8V%R86-T97)E<R!N97-T92!C86UP;RX@5F]CZB!P<F5E;F-H974@
M8V]M("5S(&-A<F%C=&5R97,[('9O8^H@9&5V92!P<F5E;F-H97(@8V]M("5S
M(&]U(&UE;F]S+@!!:6YD82!NXV\@97AI<W1E('5M(&%R<75I=F\@9&4@86IU
M9&$@<&%R82`E<RX`2&]U=F4@=6T@<')O8FQE;6$@86\@861I8VEO;F%R("<E
M<R<@86\@<VES=&5M82X@)7,N`$AO=79E('5M('!R;V)L96UA(&%D:6-I;VYA
M;F1O("<E<R<@86\@<VES=&5M83H@)7,`2&]U=F4@=6T@<')O8FQE;6$@86\@
M97AC;'5I<B!D;R!S:7-T96UA(&]S(&1A9&]S(&1O('5S=>%R:6\@)R5S)SH@
M`$AO=79E('5M('!R;V)L96UA(&%O(&5X8VQU:7(@)R5S)R!D;R!S:7-T96UA
M.B``2&]U=F4@=6T@<')O8FQE;6$@86\@871U86QI>F%R("<E<R<Z("5S`$AO
M=79E('5M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\Z($YE;FAU
M;2`E<R!F;VD@96YV:6%D;RX`2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@96YV
M:6\@9&\@87)Q=6EV;RX@3R`E<R!E<F$@;6%I;W(@<75E(&\@=&%M86YH;R!M
MX7AI;6\@<&5R;6ET:61O("@E9"!B>71E<RDN`$AO=79E('5M('!R;V)L96UA
M(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\N($\@)7,@9F]I(&5N=FEA9&\@<&%R
M8VEA;&UE;G1E+@!(;W5V92!U;2!E<G)O(&%O(&5X:6)I<B!E<W1A('!A<G1E
M(&1A(&UE;G-A9V5M`$AO=79E('5M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D
M;W,@9&\@8V]N=&%T;RX`2&]U=F4@=6T@97)R;R!A;R!I;7!O<G1A<B!O(&5V
M96YT;SH@)7,N`$AO=79E('5M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@
M9&\@:4-A;&5N9&%R+@!(;W5V92!U;2!E<G)O(&%O(&EM<&]R=&%R(&$@=&%R
M969A.B`E<RX`2&]U=F4@=6T@97)R;R!A;R!I;7!O<G1A<B!A(&EN9F]R;6'G
MXV\@;&EV<F4O;V-U<&%D;R!D;R!U<W7A<FEO.B`E<RX`2&]U=F4@=6T@97)R
M;R!N;R!F;W)M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('9O8^H@
M9&5I>&]U('5M(&-A;7!O(&]B<FEG873S<FEO(&5M(&)R86YC;RX`2&]U=F4@
M=6T@97)R;R!A;R!A8G)I<B!O(&%R<75I=F\@)7,N(%1E;G1E(&5X96-U=&%R
M(")T<F%N<VQA=&EO;BYP:'`B(&-O;2!A(&9L86<@+60@<&%R82!V97(@<75A
M;'%U97(@;65N<V%G96T@9&4@97)R;R!D;R!V97)I9FEC861O<B!X;6PN`$AO
M=79E('5M(&5R<F\@86\@97AE8W5T87(@82!F=6[GXV\@9&4@8V%TX6QO9V\@
M9&4@96YD97)EYV]S(&5S<&5C:69I8V%D82X@4&]R(&9A=F]R('1E;G1E(&YO
M=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T=6%L:7IA
M<B!O<R!D971A;&AE<R!D;R!C;VYT871O+B!0;W(@9F%V;W(@=&5N=&4@;F]V
M86UE;G1E(&UA:7,@=&%R9&4N`$AO=79E('5M(&5R<F\@86\@871U86QI>F%R
M(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B!0;W(@9F%V;W(@=&5N=&4@;F]V
M86UE;G1E(&UA:7,@=&%R9&4N`$5S=&4@<V5R=FED;W(@24U!4"!NXV\@<W5P
M;W)T82!P87-T87,@8V]M<&%R=&EL:&%D87,N`$5S=&$@8>?C;R!NXV\@Z2!S
M=7!O<G1A9&$N`$5S=&$@8>?C;R!A:6YD82!NXV\@97-TX2!I;7!L96UE;G1A
M9&$N`$5S=&4@;N-O('!A<F5C92!S97(@=6T@87)Q=6EV;R!R87(@=N%L:61O
M+@!%<W1E(&[C;R!P87)E8V4@<V5R('5M(&%R<75I=F\@>FEP(';A;&ED;RX`
M17-T92!NXV\@<&%R96-E('-E<B!U;2!N^FUE<F\@9&4@8V%R=.-O(';A;&ED
M;RX`17-T92!D<FEV97(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%V
MZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2P@=71I
M;&EZ86YD;R!A($%022!(5%10`$5S=&4@9')I=F5R('!E<FUI=&4@96YV:6%R
M(&UE;G-A9V5N<R!A=')A=NES(&1O(&=A=&5W87D@<VUS,F5M86EL("AH='1P
M.B\O<VUS,F5M86EL+F-O;2DL('5T:6QI>F%N9&\@;R!!4$D@2%144`!%<W1E
M(&1R:79E<B!P97)M:71E(&5N=FEA<B!U;6$@;65N<V%G96X@=FEA(%--5%`@
M871R87;I<R!D;R!6;V1A9F]N92!)=&%L:6%N;RP@<V]M96YT92!P87)A(&[Z
M;65R;W,@5F]D869O;F4N(,D@;V)R:6=A=/-R:6\@<&]S<W5I<B!U;6$@8V]N
M=&$@;F\@5F]D869O;F4@271A;&EA;F\@*&AT='`Z+R]W=W<N,3DP+FET*2X`
M17-T92!C86UP;R#I(&]B<FEG873S<FEO+@!%<W1E(&-A;7!O('!O9&4@8V]N
M=&5R(&%P96YA<R!N^FUE<F]S(&EN=&5I<F]S+@!%<W1E(&-A;7!O('!O9&4@
M8V]N=&5R(&%P96YA<R!N^FUE<F]S(&4@=NUR9W5L82X`17-T92!C86UP;R!P
M;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O8W1A:7,N`$5S=&4@8V%M<&\@
M9&5V92!S97(@=6UA(&QI<W1A(&1E(&[Z;65R;W,@:6YT96ER;W,@<V5P87)A
M9&$@<&]R(';M<F=U;&%S(&]U(&5S<&'G;W,`17-T92!C86UP;R!D979E('-E
M<B!U;2!N^FUE<F\@=N%L:61O+@!%<W1E(&-A;7!O(&1E=F4@8V]N=&5R('5M
M(&/S9&EG;R!D92!C;W(@96T@9F]R;6%T;R!21T(@2&5X82P@<&]R(&5X96UP
M;&\@)R,Q,C,T868G+@!%<W1E(&%R<75I=F\@8V]N=')O;&$@87,@<')E9F5R
MZFYC:6%S('!A9'+C;R!P87)A(&\@;?-D=6QO(&1E(%-E;FAA(&4@=&%M8NEM
M(&-O;G1R;VQA('%U86ES('!R969E<NIN8VEA<R!O('5S=>%R:6\@<&]D92!M
M;V1I9FEC87(`17-T92!A<G%U:79O(&-O;G1R;VQA(&\@97-T:6QO('5T:6QI
M>F%D;R!P87)A(&1E9FEN:7(@8V]R97,@92!F;VYT97,@96T@8V]M<&QE;65N
M=&\@;W4@<V]B<F5E<V-R979E;F1O(&\@97-T:6QO('!A9'+C;R!D;R!(;W)D
M90!%<W1E(&9O<FUU;.%R:6\@:N$@9F]I('!R;V-E<W-A9&\N`$ES=&\@Z2`E
M<RX`17-T92#I('5M(&]B:F5T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=FES
M=6%L:7IA<B!E<W1E(&]B:F5T;R!V;V/J('!R96-I<V%RX2!D92!U;2!C;&EE
M;G1E(&1E(&-O<G)E:6\@<75E(&5N=&5N9&$@;R!F;W)M871O($MO;&%B($=R
M;W5P=V%R92X@4&%R82!U;6$@;&ES=&$@9&4@8VQI96YT97,@9&4@8V]R<F5I
M;R!C;VT@97-T87,@9G5NY_5E<R!P;W(@9F%V;W(@=FES:71E("5S`$5S=&4@
MZ2!O(&%R<75I=F\@<')I;F-I<&%L(&1E(&-O;F9I9W5R8>?C;R!D;R!M\V1U
M;&\@9&4@<V5N:&$`17-T82!M96YS86=E;2!F;VD@97-C<FET82!E;2!U;2!C
M;VYJ=6YT;R!D92!C87)A8W1E<F5S("@E<RD@<75E(&[C;R#I(&\@;65S;6\@
M<75E(&\@<V5U+@!%<W1E(&[Z;65R;R!D979E('-E<B!P96QO(&UE;F]S('5M
M+@!%<W1E('-C<FEP="!D979E('-E<B!E>&5C=71A9&\@82!P87)T:7(@9&$@
M;&EN:&$@9&4@8V]M86YD;RX`17-T92!S97)V:61O<B!NXV\@<&]D92!D97-C
M;VUP<FEM:7(@87)Q=6EV;W,@>FEP(&4@9WII<"X`17-T92!S:7-T96UA(&5S
M=.$@871U86QM96YT92!D97-A=&EV861O+@!%<W1E('9A;&]R(&1E=F4@<V5R
M('5M(&[Z;65R;RX`17-T82!J86YE;&$@9&5V92!S97(@8VAA;6%D82!A('!A
M<G1I<B!D82!J86YE;&$@9&4@3W#G]65S`%+A:6\`0FEL:&5T97,`2&]R80!!
M8V]M<&%N:&%M96YT;R!D92!(;W+A<FEO`$9O<FUA=&\@9&4@:&]R80!396QE
MY^-O(&1E(&AO<F$`5&EM;W(@3&5S=&4`5.UT=6QO`$%S<W5N=&\@*&1I8V$I
M.@!087)A`%!A<F$@<V5L96-I;VYA<B!M^FQT:7!L;W,@:71E;G,L('-E9W5R
M92!A('1E8VQA($-O;G1R;VP@*%!#*2!O=2!#;VUM86YD("A-86,I(&%O(&-L
M:6-A<BX`2&]J90!4<F]C87(@<&%R82!C\V1I9V\@2%1-3`!4;V=O`%1O:V5L
M874`06UA;FCC`%1O;F=A`%1O<&\`475A9')O(&1O(%1O<&\@*%]T;W`I`%1R
M861U>FED;P!4<F%D=>?U97,`5')I;F1A9&4@92!4;V)A9V\`5F5R9&%D96ER
M;R!O=2!F86QS;P!497(`5'5N[7-I80!4=7)Q=6EA`%1U<F-O("A)4T\M.#@U
M.2TY*0!4=7)C;VUE;FES=.-O`$EL:&%S(%1U<FMS(&4@0V%I8V]S`%1U=F%L
M=0!0<F5E;F-H82!C;VT@<W5A(&5S8V]L:&$Z(`#-;F1I8V4@52Y6+CH@`%52
M3`!54DP@9&\@<V5U(')E;&%T\W)I;R!D92!E<W1A9&\@9&4@96YT<F5G80!5
M4DPZ`%5G86YD80!58W+B;FEA`$EM<&]S<^UV96P@86-E<W-A<B!D:7)E=/-R
M:6\@5D93+@!);7!O<W/M=F5L(&%D:6-I;VYA<B!I;F9O<FUAY_5E<R!E>'1R
M87,@9&4@=7-UX7)I;R!A;R!R96=I<W1R87(N`$EM<&]S<^UV96P@86QT97)A
M<B!P97)M:7-SXV\@9&\@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!A
M;'1E<F%R('!E<FUI<W/C;R!D;R!A<G%U:79O(%9&4R`E<R\E<RX`26UP;W-S
M[79E;"!A;'1E<F%R('!A<F$@)7,N`$EM<&]S<^UV96P@8V]N96-T87(@86\@
M<V5R=FED;W(@4U%,+@!);7!O<W/M=F5L(&-O;F5C=&%R('5T:6QI>F%N9&\@
M4U-,+@!);7!O<W/M=F5L(&-O<&EA<B!A<G%U:79O(%9&4RX`26UP;W-S[79E
M;"!C<FEA<B!D:7)E=/-R:6\@5D93("(E<R(N`$EM<&]S<^UV96P@8W)I87(@
M9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!C<FEA<B!A<G%U:79O(%9&4RX`
M26UP;W-S[79E;"!C<FEA<B!A<G%U:79O(%9&4R!V87II;RX`26UP;W-S[79E
M;"!D97-C;VUP<FEM:7(@9&%D;W,N`$EM<&]S<^UV96P@97AC;'5I<B`B)7,B
M+"!O(&1I<F5T\W)I;R!NXV\@97-TX2!V87II;RX`26UP;W-S[79E;"!E>&-L
M=6ER("5S+"!O(&1I<F5T\W)I;R!NXV\@97-TX2!V87II;P!);7!O<W/M=F5L
M(&5X8VQU:7(@)R5S)SH@)7,N`$EM<&]S<^UV96P@97AC;'5I<B!R96-U<G-I
M=F%M96YT92!O(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@97AC;'5I<B!D
M:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@9&ER973S<FEO(%9&
M4SH@)7,N`$EM<&]S<^UV96P@97AC;'5I<B!A<G%U:79O(%9&4R`B)7,B+@!)
M;7!O<W/M=F5L(&5X8VQU:7(@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@97AC
M;'5I<B!61E,@<F5C=7)S:79A;65N=&4Z("5S+@!);7!O<W/M=F5L(&1E=&5R
M;6EN87(@;R!D:7)E=/-R:6\@871U86PN`$EM<&]S<^UV96P@97AT<F%I<B!D
M971A;&AE<R!D;R!C97)T:69I8V%D;P!);7!O<W/M=F5L(&-A<G)E9V%R(&$@
M9&5F:6YIY^-O(&1E("5S+@!);7!O<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!6
M1E,N`$EM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S
M[79E;"!A8G)I<B!A<G%U:79O(%9&4R!P87)A(&=R879AY^-O+@!);7!O<W/M
M=F5L(&%B<FER(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&%B<FER(&%R<75I
M=F\@8V]M<')I;6ED;RX`26UP;W-S[79E;"!L97(@82!R86EZ(&1O(&1I<F5T
M\W)I;R!61E,N`$EM<&]S<^UV96P@<F5N;VUE87(@)7,@<&%R82`E<SH@82!P
M87-T82!D92!D97-T:6YO(&KA(&5X:7-T90!);7!O<W/M=F5L(')E;F]M96%R
M(&\@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!R96YO;65A<B!D:7)E=/-R
M:6\@5D93.B`E<RX`26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O(%9&4R`B
M)7,B+@!);7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93("5S+R5S+@!)
M;7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&5X
M96-U=&%R("=M:VES;V9S)RX`26UP;W-S[79E;"!T<F%D=7II<B!E<W1E(&1O
M8W5M96YT;R!7;W)D`$EM<&]S<^UV96P@9W)A=F%R(&%R<75I=F\@5D93("(E
M<R(N`$EM<&]S<^UV96P@9W)A=F%R(&%R<75I=F\@5D93("AC;W!Y*"D@9F%L
M:&]U*2X`26UP;W-S[79E;"!G<F%V87(@9&%D;W,@9&\@87)Q=6EV;R!61E,N
M`%-U8FQI;FAA9&\`1&5S9F%Z97(@06QT97)AY_5E<P!$97-F87H@<W5A(/IL
M=&EM82!AY^-O`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@9'5R
M86YT92!A(&-O;F5XXV\Z(`!297-P;W-T82!I;F5S<&5R861A(&1O('-E<G9I
M9&]R('!A<F$Z(`!396T@8V%T96=O<FEA`$-O;7!O;F5N=&4@;N-O('-U<&]R
M=&%D;R!D;R!T:7!O.B`E<P!5;FEC;V1E("A55$8M."D`16UI<F%D;W,@P7)A
M8F5S(%5N:61O<P!296EN;R!5;FED;P!%<W1A9&]S(%5N:61O<P!);&AA<R!0
M97)I9NER:6-A<R!-96YO<F5S(&1O<R!%<W1A9&]S(%5N:61O<P!5;FED861E
M<P!$97-C;VYH96-I9&\`87!I;7-G:60@9&5S8V]N:&5C:61O("A!4$D@365S
M<V%G92!)1"DN`&-L:6US9VED(&1E<V-O;FAE8VED;R`H0VQI96YT($UE<W-A
M9V4@240I+@!#;VUA;F1O(&1E<V-O;FAE8VED;SH@)7,`57-UX7)I;R!O=2!S
M96YH82!D97-C;VYH96-I9&]S+@!$97-V:6YC=6QA<B!O(&5L96UE;G1O(&%T
M=6%L`%-E;2!.;VUE`%-C<FEP=',@;N-O('!R:79I;&5G:6%D;W,@;N-O('!O
M9&5M('5T:6QI>F%R($-O<G1A<B]#;W!I87(O0V]L87(@<&]R(')A>O5E<R!D
M92!S96=U<F%NYV$N($-L:7%U92!E;2!/2R!P87)A('9E<B!A(&YO=&$@=.EC
M;FEC82!E;2!M;WII;&QA+F]R9R!A('%U86P@;6]S=')A(&-O;6\@<&5R;6ET
M:7(@<V-R:7!T<R!A8V5S<V%R96T@82#A<F5A(&1E('1R86YS9F5RZFYC:6$N
M`$1E<VUA<F-A<B!C;W(`17AT96YSXV\@3N-O(%-U<&]R=&%D80!.XV\@5')A
M9'5Z:61O`$%T=6%L:7IA<@`E<R!A='5A;&EZ861O`$%T=6%L:7IA<B!E<W1A
M9&\@9&$@<F5S<&]S=&$`071U86QI>F%R('5S=>%R:6\`)R5S)R!A='5A;&EZ
M861O+@!!='5A;&EZ86YD;R!A<G%U:79O(&1E(&%J=61A("5S('!A<F$@)7,N
M`%-C<FEP="!D92!A='5A;&EZ8>?C;R!R96UO=FED;RX`16YV:6%R`%1O9&]S
M(&%R<75I=F]S(&1E("!C;VYF:6=U<F'G]65S(&1A<R!A<&QI8V'G]65S(&9O
M<F%M(&5N=FEA9&]S(&%O('-E<G9I9&]R+@!!;&9A8F5T;R!L871I;F\@96T@
M;6%I^G-C=6QO`$[Z;65R;W,@<F]M86YO<R!E;2!M86GZ<V-U;&\`57)U9W5A
M:0!5=&EL:7IAY^-O.@!5=&EL:7IA<B!!='5A;#H@)7,`571I;&EZ87(@4U-,
M`%5T:6QI>F%R('-E(&\@;F]M92]S96YH82#I(&1I9F5R96YT92!N;R!S97)V
M:61O<B!)35-0+@!5<W7A<FEO("5S(&[C;R!E<W3A(&%U=&]R:7IA9&\@<&%R
M82`E<RX`061M:6YI<W1R8>?C;R!D92!5<W7A<FEO<P!/<.?U97,@9&4@57-U
MX7)I;W,`4F5G:7-T<F\@9&4@57-UX7)I;W,`4F5G:7-T<F\@9&4@57-UX7)I
M;W,@97-TX2!D97-A8FEL:71A9&\@;F5S=&4@<VET92X`4&5R;6ES<_5E<R!D
M92!U<W7A<FEO`%5S=>%R:6\`57-UX7)I;R`G)7,G(&KA(&5X:7-T92X`57-U
MX7)I;SH`57-UX7)I;SH@`%5S=>%R:6]S`%5S=>%R:6]S(&YO('-I<W1E;6$Z
M`%5Z8F5Q=6ES=.-O`$\@9&ER973S<FEO(%9&4R!NXV\@97AI<W1E+@!&Z7)I
M87,`3&]C86QI>F'G]65S(';A;&ED87,@96YC;VYT<F%D87,@:6YC;'5E;3H@
M`%9A;&ED861E`%9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@9&4@86=O<F$N
M`%9A;&]R97,`5F%L;W)E<R!P87)A('-E;&5C:6]N87(`5F%N=6%T=0!687)I
MX79E;`!696YE>G5E;&$`1F%L:&$@;F$@=F5R:69I8V'GXV\@+2!E<W1A(&UE
M;G-A9V5M('!O9&4@=&5R('-I9&\@861U;'1E<F%D82X`5F5R<^-O`$-O;G1R
M;VQE(&1E(%9E<G/C;P!!;&EN:&%M96YT;R!V97)T:6-A;`!-87)G96T@=F5R
M=&EC86P`5F5R=&EC86PZ`$UU:71O($%L=&$`5FEE=&[C`%9I971N86UI=&$@
M*%9)4T-)22D`5FES=6%L:7IA<B`E<P!6:7-U86QI>F%R('5M82!PX6=I;F$@
M=V5B(&5X=&5R;F$`5FES=6%L:7IA<B!C;VUO("5S`%9I<W5A;&EZ87(@979E
M;G1O`%9I<W5A;&EZ87(@=&%R969A`$EL:&%S(%9I<F=E;G,L($)R:73B;FEC
M87,`26QH87,@5FER9V5N<RP@12Y5+D$N`%9I<VEB:6QI9&%D90!6:7-I8FEL
M:61A9&4Z(`!6;V1A9F]N92!)=&%L:6%N;R!V:6$@4TU44`!!5$5.Q\-/`$%4
M14['PT\A(2$@4D5-3U9!($\@4T-225!4($U!3E5!3$U%3E1%($1%("5S+@!7
M86QL:7,@92!&=71U;F$`071E;N?C;P!!=&5NY^-O.B``475A`%!R979I<^-O
M(&1O(%1E;7!O`$1A9&]S(&1O($-L:6UA(&9O<FYE8VED;R!P;W(`5V5A=&AE
M<BYC;VT`5V5B`%-I=&4@5V5B`%-E;6%N86QM96YT90!"96TM=FEN9&\`0F5M
M+79I;F1O(&%O("5S`$)E;2UV:6YD;RP@)7,`3V-I9&5N=&%L("A)4T\M.#@U
M.2TQ*0!/8VED96YT86P@*$E33RTX.#4Y+3$U*0!386AA<F$@3V-I9&5N=&%L
M`%%U92!A<&QI8V'GXV\@)7,@9&5V97)I82!E>&EB:7(@87#S<R!A(&-O;F5X
MXV\_`%%U86P@;R!C87)A8W1E<F4@9&5L:6UI=&%D;W(_`%%U86P@;R!C87)A
M8W1E<F4@9&4@8VET8>?C;S\`475A:7,@9F%S97,`475A:7,@<&QU9VEN<R!H
M86)I;&ET87(@<&%R82!O(&5D:71O<B!2:6-H(%1E>'0N`$QA<F=U<F$`3&%R
M9W5R82!E;2!U;FED861E<R!#4U,`3&%R9W5R82!D;R!M96YU("5S(&1O(&QA
M9&\@97-Q=65R9&\@*'1E<N$@969E:71O(&YA('!R\WAI;6$@8V]N97CC;RDZ
M`$QA<F=U<F$@9&$@=&%B96QA`%5N:61A9&4@9&4@3&%R9W5R80!,87)G=7)A
M.@!7:6MI`%9E;G1O`%9E;G1O<R!P96QA(&UA;FCC`%9E;&]C:61A9&4@9&\@
M=F5N=&\@96T@;O-S`%9E;G1O.@!696YT;SH@`%-A8F5D;W)I80!,:7-T82!D
M92!P961I9&]S`%1R86)A;&AO`$5N9&5R9>=O($-O;65R8VEA;`!496QE9F]N
M92!#;VUE<F-I86P`26UP;W-S[79E;"!G<F%V87(N(%9O8^H@<&]D92!U=&EL
M:7IA<B!O('-C<FEP="!D92!A='5A;&EZ8>?C;R!D:7-P;V[M=F5L(&]U(&UA
M;G5A;&UE;G1E(&-O<&EA<B!O(&/S9&EG;R!A8F%I>&\@<&%R82`E<RX`1W)A
M=F%R(&\@87)Q=6EV;R!D92!A:G5D82!A='5A;&EZ861O(&5M("5S+@!.^FUE
M<F\@97)R861O(&1E(&-A;7!O<RX@17-P97)A9&]S("5D+"!E;F-O;G1R861O
M<R`E9"X`6"U2968`4F5S=')IY_5E<R!"X7-I8V%S(%@U,#EV,P!5=&EL:7IA
MY^-O(&1E($-H879E($5X=&5N9&ED82!8-3`Y=C,`3F]M92!!;'1E<FYA=&EV
M;R!D92!!<W-U;G1O(%@U,#EV,P!)9&5N=&EF:6-A9&]R(&1A($-H879E(&1E
M($%S<W5N=&\@6#4P.78S`$5X=&5N<_5E<R!8-3`Y=C,`04$`04%!00!-87!A
M(%EA:&]O(0!!;G5A;&UE;G1E`$SJ;65N`%-I;0!3:6TL($5U($-O;F-O<F1O
M`%9O8^H@97-TX2!E;2!-3T1/(%1%6%1/+B`@571I;&EZ82!O(&)O=.-O(%L\
M/ET@<&%R82!V;VQT87(@<&%R82!O(&UO9&\@5UE325=91RX`5F]CZB!NXV\@
M97-TX2!A=71E;G1I8V%D;RX`5F]CZB!NXV\@<&]D92!T97(@;R!C87)A8W1E
M<F4@)UPG(&YO('-E=2!N;VUE(&-O;7!L971O+@!6;V/J(&[C;R!P;V1E(&UU
M9&%R(&$@<V5N:&$@<&%R82!O('5S=>%R:6\@)7,`5F]CZB!NXV\@9F]R;F5C
M974@=6T@96YD97)EYV\@9&4@92UM86EL(';A;&ED;RX`5F]CZB!NXV\@;6%P
M96]U(&YE;FAU;2!C86UP;R!D;R!A<G%U:79O(&EM<&]R=&%D;R!A;W,@8V%M
M<&]S(&-O<G)E<W!O;F1E;G1E<R!E;2`E<RX`5F]CZB!F;VD@9&5S8V]N96-T
M861O+@!6;V/J(&1E=F4@<')E96YC:&5R('5M(&[Z;65R;R!D92!T96QE9F]N
M92!C96QU;&%R(';A;&ED;RP@<V]M96YT92!D[6=I=&]S(&-O;2!U;2!O<&-I
M;VYA;"`G*R<@<&%R82!D:7-C86=E;2!D92!P<F5F:7AO(&EN=&5R;F%C:6]N
M86PN`%9O8^H@9&5V92!P<F5E;F-H97(@=6T@=F%L;W(@=N%L:61O+@!6;V/J
M(&1E=F4@8V]N9FEG=7)A<B!U;2!B86-K96YD($1A=&%4<F5E('!A<F$@=71I
M;&EZ87(@4F5G:7-T<F]S+@!6;V/J(&1E=F4@8V]N9FEG=7)A<B!U;2!B86-K
M96YD(%9&4RX`5F]CZB!D979E(&1E<V-R979E<B!O('!R;V)L96UA(&%N=&5S
M(&1E(&5N=FEA<B!O(')E;&%T\W)I;R!D92!P<F]B;&5M82X`5F]CZB!D979E
M(&9O<FYE8V5R(&$@55),(&]N9&4@;R!L:6YK(&%P;VYT80!6;V/J(&1E=F4@
M9F]R;F5C97(@<W5A('-E;FAA(&YO=F$`5F]CZB!D979E(&9O<FYE8V5R('-U
M82!S96YH82!A;G1I9V$`5F]CZB!D979E('-E;&5C:6]N87(@=6T@<V5R=FED
M;W(@<&%R82!S97(@97AC;'7M9&\N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U
M;2!U<W7A<FEO('!A<F$@97AC;'5I<BX`5F]CZB!D979E(&5S<&5C:69I8V%R
M('5M('5S=>%R:6\@<&%R82!R96UO=F5R+@!6;V/J(&1E=F4@97-P96-I9FEC
M87(@=6T@=7-UX7)I;R!P87)A(&%D:6-I;VYA<BX`5F]CZB!D979E(&5S<&5C
M:69I8V%R('5M('5S=>%R:6\@<&%R82!A='5A;&EZ87(N`%9O8^H@9&5V92!E
M<W!E8VEF:6-A<B!U;6$@8>?C;R!P87)A(&5X96-U=&%R+@!6;V/J(&1E=F4@
M<')E96YC:&5R('5M(&YO;64@<&%R82!A(&YO=F$@8V%T96=O<FEA+@!6;V/J
M(&1E=F4@8V]N9FER;6%R('-U82!S96YH82!N;W9A`%-U82!S97-SXV\@)7,@
M97AP:7)O=2X@4&]R(&9A=F]R+"!C;VYE8W1E+7-E(&YO=F%M96YT92X`4V5U
M($5N9&5R9>=O(&1E($5M86EL`%-E=2!%;F1E<F7G;R!D92!296UE=&5N=&4@
M*$1E.BDZ`%-U87,@26YF;W)M8>?U97,`4V5U($5N9&5R9>=O(&1E($EN=&5R
M;F5T(&UU9&]U(&1E<V1E(&\@:6[M8VEO(&1E('-U82!S97-SXV\@)7,N(%!A
M<F$@<')O=&5G97(@<W5A('-E9W5R86[G82!V;V/J(&1E=F4@8V]N96-T87(M
M<V4@;F]V86UE;G1E+@!3974@3F]M90!3974@8F%C:V5N9"!D92!A=71E;G1I
M8V'GXV\@;N-O('-U<&]R=&$@861IY^-O(&1E('5S=>%R:6]S+"!O=2!A(&9U
M;N?C;R!F;VD@9&5S86)I;&ET861A('!O<B!A;&=U;6$@;W5T<F$@<F%ZXV\N
M`%-E=2!B86-K96YD(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T82!L:7-T
M86=E;2!D92!U<W7A<FEO<RP@;W4@82!F=6[GXV\@9F]I(&1E<V%B:6QI=&%D
M82!P;W(@86QG=6UA(&]U=')A(')A>N-O+@!3974@;F%V96=A9&]R('!A<F%C
M92!T97(@;75D861O(&1E<V1E(&\@:6[M8VEO(&1E('-U82!S97-SXV\@)7,N
M(%!A<F$@<')O=&5G97(@<W5A('-E9W5R86[G82P@=F]CZB!D979E(&-O;F5C
M=&%R+7-E(&YO=F%M96YT92X`4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E
M<W1A(&9U;N?C;RX`4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&]P
MY^-O(&1E(&EM<')E<W/C;RX@4')E<W-I;VYE($-O;G1R;VPO3W!T:6]N("L@
M4"!P87)A(&EM<')I;6ER+@!3974@9G5S;R!H;W+A<FEO(&%T=6%L.@!3=6$@
M:61E;G1I9&%D92!P861RXV\Z`%-E=2!N;VUE(&-O;7!L971O.@!!('9E<G/C
M;R!D92!S974@9V5T=&5X="#I(&UU:71O(&%N=&EG82!O=2!NXV\@<W5P;W)T
M82!02%`@;F%T:79A;65N=&4N"DYE;2!T;V1A<R!A<R!C861E:6%S(&1E(&-A
M<F%C=&5R97,@<V5RXV\@97AT<F%I9&%S+@!3=6$@8V]N97CC;R!E>'!I<F]U
M+@!3=6$@;F]V82!S96YH82!P87)A("5S(.DZ("5S`%-U82!S96YH82!N;W9A
M(&[C;R!C;VUB:6YA`%-U87,@;W#G]65S(&9O<F%M(&%T=6%L:7IA9&%S+@!3
M=6$@;F]V82!S96YH82!F;VD@9V5R861A`%-U82!N;W9A('-E;FAA(&9O:2!G
M97)A9&$L('9E<FEF:7%U92!S974@96UA:6P@92!C;VYE8W1E+7-E(&-O;2!S
M=6$@;F]V82!S96YH82X`4W5A('-E;FAA(&5X<&ER;W4N`%-E=7,@<V5R=FED
M;W)E<R!R96UO=&]S.@!)=6=O<VSA=FEA`%IA:7)E`%KB;6)I80!::6UB86)W
M90!::7!P>0!;3V-U;'1A<B!497AT;R!#:71A9&]=`%M296QA=/-R:6\@9&4@
M4')O8FQE;6%=`%M%>&EB:7(@5&5X=&\@0VET861O("T`6T5X:6)I<B!497AT
M;R!#:71A9&\@+2`E<R!L:6YH87-=`%ML:6YH82`E<R!D92`E<UT`7T%D;6EN
M:7-T<F'GXV\`7T-,20!$871A7U1R964`15]X8VQU:7(@0V]L=6YA`%]'<G5P
M;W,`05]J=61A`%!R;W!R:65D861E<R!D82!?26UA9V5M+BXN`%]#;VYE8W1A
M<@!?1&5S8V]N96-T87(`05]L=&5R87(@3&EN:RXN+@!?3W#G]65S`%]097)M
M:7-S]65S`%]296UO=F5R($QI;FLN+BX`0V]N9FEG=7)A7W(`4')O<')I961A
M9&5S(&1A(%]486)E;&$N+BX`7U5S=>%R:6]S`&-A=.%L;V=O(&1E(&5N9&5R
M9>=O<P!U;2!E<G)O(&]C;W)R974Z`&-A;&5N9.%R:6\`8V%L;6\`8VQI<75E
M(&%Q=6D`9F5I=&\`9F%L:&]U`'%U961A`&%R<75I=F\`96YC;VYT<F%D;SH@
M`&$@<&%R=&ER(&1E("5S("@E<RD@X"`E<R`E<P!H.@!I,3AN`&EM961I871O
M`&EN8V]R<&]R861O`&QI;FAA<UT`8_-D:6=O(&1E(&5R<F\@)60@9&\@;6MI
M<V]F<R!E;G%U86YT;R!G97)A=F$@82!)4T\N`&YO;64`;N-O(&%L=&5R861O
M`&[C;R!E;F-O;G1R861O`&[C;R!I;7!L96UE;G1A9&\`;N-O(&EM<&QE;65N
M=&%D;R!A:6YD80!B;&]C;R!D92!N;W1A<P!P;W)C96YT86=E;0!P:7AE;',`
M;F%S8V5N=&4`97AI8FER(&1I9F5R96[G87,`<VUS,F5M86EL('9I82!(5%10
M`&5S=.%V96P`;&ES=&$@9&4@=&%R969A<P!O(&%R<75I=F\@4$\@9&\@2&]R
M9&4@<&%R82!A(&QO8V%L:7IAY^-O("5S(&[C;R!E>&ES=&4Z`'!R965N8VAA
M('-U82!S96YH82!D=6%S('9E>F5S('!A<F$@8V]N9FER;6%R`'5N:69I8V%D
M;P!S96T@;F]M90!A='5A;&EZ861O`'-E;&7GXV\@9&4@=7-UX7)I;P!V0V%R
M9`!W.@!W96%T:&5R+F-O;0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]R;U]23R\`````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<T-``P,C`R,#0`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O
M;&]C86QE+W)O7U)/+TQ#7TU%4U-!1T53+P``````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,3<W,0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O<F]?4D\O3$-?34534T%'15,O<&%S
M<W=D+FUO````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#4R,C$`,3`T,3<S-C(W-#0`,#(S
M-C,P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````V````!P```#<!@``)0$``)P-````````,!(``"@````Q$@``
M0````%H2```M````FQ(```@```#)$@``(@```-(2```%````]1(```@```#[
M$@``!P````03```+````#!,```4````8$P``'P```!X3```1````/A,``"(`
M``!0$P``"````',3```#````?!,```@```"`$P``%0```(D3```*````GQ,`
M``\```"J$P``%````+H3```7````SQ,``$0```#G$P``"@```"P4```1````
M-Q0```P```!)%```!P```%84```5````7A0``!````!T%```&P```(44```=
M````H10``"````"_%```*0```.`4```A````"A4```(````L%0``!0```"\5
M```6````-14``!````!,%0``%````%T5```O````<A4```\```"B%0``)@``
M`+(5```%````V14```T```#?%0``!0```.T5```@````\Q4``!`````4%@``
M$````"46```/````-A8```L```!&%@``#P```%(6```,````8A8```\```!O
M%@``(````'\6```=````H!8``!X```"^%@``(0```-T6```?````_Q8```,`
M```?%P``$0```",7```$````-1<```P````Z%P``"@```$<7```%````4A<`
M``L```!8%P``#````&07```.````<1<``"````"`%P``!@```*$7```.````
MJ!<``!(```"W%P``$````,H7```1````VQ<```@```#M%P``$````/87```&
M````!Q@```<````.&```7````!88```&````<Q@```(```!Z&```!````'T8
M```8````@A@``!$```";&```#P```*T8```%````O1@```<```##&```!P``
M`,L8```*````TQ@```0```#>&```!0```.,8```-````Z1@``#P```#W&```
M.@```#09```[````;QD``#X```"K&0``'0```.H9```%````"!H``",````.
M&@``#0```#(:```'````0!H``!$```!(&@``"````%H:```1````8QH``"H`
M``!U&@``'@```*`:```%````OQH``"@```#%&@``*0```.X:```3````&!L`
M``@````L&P``%0```#4;```+````2QL``$````!7&P``/0```)@;``!"````
MUAL``#X````9'```/P```%@<``!"````F!P``#X```#;'```/P```!H=``!"
M````6AT``#X```"='0``/P```-P=```V````'!X``$$```!3'@``/0```)4>
M```^````TQX``#\````2'P``.P```%(?```\````CA\``$0```#+'P``/0``
M`!`@```Z````3B```$(```")(```/@```,P@```_````"R$```4```!+(0``
M$0```%$A```$````8R$```P```!H(0``:````'4A```:````WB$``!<```#Y
M(0``%P```!$B```;````*2(``!\```!%(@``$P```&4B```&````>2(``#0`
M``"`(@``)````+4B```.````VB(``!````#I(@``,````/HB```Z````*R,`
M`!<```!F(P``!P```'XC```%````AB,``(\```",(P``50```!PD``#-````
M<B0``)L```!`)0``I@```-PE``")````@R8``',````-)P``(0```($G```<
M````HR<```4```#`)P``#@```,8G```#````U2<``"````#9)P``*@```/HG
M```F````)2@```P```!,*```%P```%DH```1````<2@```P```"#*```#@``
M`)`H```/````GR@```@```"O*```"0```+@H```'````PB@```@```#**```
M!@```-,H```-````VB@```L```#H*```#````/0H```*`````2D```(````,
M*0``!@````\I```E````%BD``#X````\*0``10```'LI```?````P2D``!\`
M``#A*0``(0````$J```P````(RH``!,```!4*@``$````&@J```*````>2H`
M`%$```"$*@``-P```-8J```V````#BL``#X```!%*P``00```(0K``!#````
MQBL``$`````*+```/@```$LL``!`````BBP``$4```#++```.0```!$M```?
M````2RT``!\```!K+0``$````(LM```/````G"T``!$```"L+0``!0```+XM
M```T`0``Q"T``"@```#Y+@``10```"(O```I````:"\```D```"2+P``(```
M`)PO```%````O2\```\```##+P``!@```-,O```&````VB\```4```#A+P``
M(P```.<O```4````"S```!T````@,```#P```#XP```#````3C````@```!2
M,```$0```%LP```-````;3````X```![,```$0```(HP```6````G#```#H`
M``"S,```#@```.XP```9````_3```!$````7,0``"````"DQ```7````,C$`
M`!\```!*,0``%@```&HQ```D````@3$``"0```"F,0``*````,LQ```@````
M]#$```(````5,@``!@```!@R```D````'S(``!0```!$,@``$````%DR```Q
M````:C(``!(```"<,@``)P```*\R```%````US(``!D```#=,@``!@```/<R
M```M````_C(``!,````L,P``%````$`S```3````53,``!0```!I,P``$P``
M`'XS```0````DC,``!(```"C,P``(@```+8S```C````V3,``!D```#],P``
M)@```!<T```?````/C0```,```!>-```$P```&(T```&````=C0```\```!]
M-```$@```(TT```%````H#0``!(```"F-```#@```+DT```.````R#0``"8`
M``#7-```!@```/XT```2````!34``!$````8-0``$@```"HU```0````/34`
M``4```!.-0``&@```%0U```)````;S4```L```!Y-0``40```(4U```&````
MUS4```(```#>-0``#0```.$U```D````[S4``!T````4-@``'0```#(V```$
M````4#8```4```!5-@``!0```%LV```+````838```0```!M-@``"0```'(V
M```,````?#8``"4```")-@``(0```*\V```D````T38``"8```#V-@``(0``
M`!TW```$````/S<``"\```!$-P``#0```'0W```'````@C<```\```"*-P``
M!@```)HW```1````H3<``"4```"S-P``(@```-DW```'````_#<``"<````$
M.```,````"PX```4````73@```D```!R.```(P```'PX```/````H#@``#<`
M``"P.```-````.@X```Y````'3D``#4```!7.0``-@```(TY```Y````Q#D`
M`#4```#^.0``-@```#0Z```Y````:SH``#4```"E.@``-@```-LZ```K````
M$CL``#D````^.P``-````'@[```U````K3L``#8```#C.P``,@```!H\```S
M````33P``#L```"!/```-````+T\```Q````\CP``#D````D/0``-0```%X]
M```V````E#T```@```#+/0``$0```-0]```0````YCT```\```#W/0``:@``
M``<^```4````<CX``!P```"'/@``&P```*0^```B````P#X``!L```#C/@``
M&````/\^```&````&#\``$0````?/P``)@```&0_```,````BS\``!4```"8
M/P``+P```*X_```P````WC\``!8````/0```!@```"9````'````+4```(``
M```U0```20```+9```#<`````$$``)0```#=00``LP```')"``"2````)D,`
M`&L```"Y0P``%@```"5$```H````/$0```4```!E1```"P```&M$```#````
M=T0``"$```![1```-0```)U$```N````TT0``!0````"10``'0```!=%```;
M````-44``!(```!110``$@```&1%```3````=T4```H```"+10``"P```)9%
M```+````HD4```@```"N10``"@```+=%```<````PD4``!$```#?10``$@``
M`/%%```3````!$8```(````81@``!0```!M&```M````(48``#D```!/1@``
M.@```(E&```?````Q$8``!\```#D1@``'@````1'```[````(T<``!,```!?
M1P``%@```'-'```+````BD<``$<```"61P``,0```-Y'```Q````$$@``#4`
M``!"2```/0```'A(```_````MD@``#P```#V2```/P```#-)```\````<TD`
M`#8```"P20``*0```.=)```<````$4H``!H````N2@``$0```$E*```1````
M6TH``!$```!M2@``$0```']*```!````J0```(0```!)````*P````4`````
M````*0```-@```##`````````*P````J`````````$8````]`````````#X`
M``"R````P0```!P```"F````/``````````F`````P```%P`````````!```
M`'<````,````M````',````M````E@```!8```!P`````````+D```"5````
M(0```&P`````````-@```)(````"`````````-(````7`````````'\```!,
M`````````#<```#'````O@```%@```#&`````````$0```"=````1P```)X`
M````````E````(D`````````G````$@```":``````````@```!?````D```
M``````"D````(@```!4```!>````O0````````!1````70```*L````*````
MHP```-````"B````?0```*T```#1`````````'(```!U``````````````"%
M`````````"@```"(`````````,H```"'````.@````````!Z````0@```'X`
M``#-````>`````````!:````@P````````#%````50```&,`````````&```
M`+\``````````````!L```!;`````````)\```!A````TP```-0```"X````
M;@```((```!9````,P```,X````>````$@```%``````````D0```'D```"U
M````UP`````````-````A@`````````N````,````,L`````````;0```!``
M`````````````&\```#5`````````,P```"V````+P```#D```#)````@```
M`),```#(````(````%8````/`````````%,````L``````````8`````````
M`````#$```!+`````````!D`````````SP````````"S`````````(\`````
M````KP```$X```"W````U@``````````````00````````"Z````J````&L`
M``"G````-````(L```"7````9`````````![````&@``````````````````
M`(H``````````````+L```#$````30````````"@````C0```'8````_````
M@0`````````4`````````"<```"\````$P`````````1````0````"0`````
M````?`````````!7``````````````!4````.`````````!F````!P``````
M````````P@````````!#````9P````X`````````H0```"4```"9````````
M`#L```",````3P```$H```"N````8@```,````!2`````````&D```"8````
M`````$4````=````-0```'$````+``````````D```!@````:`````````!T
M````(P````````";````'P````````!E````L0```*4``````````````+``
M``".`````````#(```!J````J@`````E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX`)R5S)R!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`#(T(&AO
M=7)S`#QB/D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D.CPO8CX`04TO4$T`
M061D('!A:7(`061D<F5S<P!!9&1R97-S8F]O:P!!;&EA<P!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%V86EL86)L92!F:65L9',Z`$)A8VME
M;F0@;F]T(&-O<G)E8W1L>2!I;7!L96UE;G1E9"X`0FER=&AD87D`0U93`$-A
M;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-H86YG
M92!087-S=V]R9`!#:&%N9V4@>6]U<B!P87-S=V]R9`!#:&%N9VEN9R!087-S
M=V]R9"!O;B`E<P!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#;&]S92!(96QP
M`$-L;W-E($AE;'`@5VEN9&]W`$-L;W-E(%=I;F1O=P!#;VUP86YY`$-O;F9I
M<FT@;F5W('!A<W-W;W)D.@!#;VYT96YT<R!O9B`G)7,G`$-O;G1E;G1S(&]F
M('1H92!205(@87)C:&EV90!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E
M<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E
M;B!P:7!E('1O('-M8G!A<W-W9"X`1$0`1&%I;'D`1&%T86)A<V4@<75E<GD@
M9F%I;&5D+@!$969A=6QT($ED96YT:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R`$5R<F]R
M('-E;F1I;F<@9&%T82!T;R!S;6)P87-S=V0N`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`
M179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`
M17AP96-T960@(D)%1TE.(B!I;B!T:&4@;&EN92`E9"X`17AP96-T960@(D5.
M1#HE<R(@:6X@;&EN92`E9"X`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC
M97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL=7)E
M(&EN(&-H86YG:6YG('!A<W-W;W)D(#H@`$9A>`!&=6QL($1E<V-R:7!T:6]N
M.@!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO<F1E($QO
M9VEN`$AO<F1E(%-Y<W1E;0!(;W)D92!7:7)E;&5S<P!(;W)D92!I<R!N;W0@
M<')O<&5R;'D@8V]N9FEG=7)E9`!);7!O<G0`26UP;W)T($5R<F]R.B``26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YC;W)E8W0@4&%S
M<W=O<F0`3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC<P!,;V<@:6X`3&]G(&]U
M=`!,;V=I;B!F86EL960@9F]R('-O;64@<F5A<V]N+B!-;W-T(&QI:V5L>2!Y
M;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C
M=&QY+@!,;V=O=70`34T`36%I;`!-87`@1&%T92!A;F0@5&EM92!&:65L9',`
M36%P($EM<&]R="!&:65L9',`36%T8VAI;F<@9FEE;&1S`$UE;6]S`$UE<W-A
M9V4`36]N=&AL>0!->2!3=6UM87)Y`$YA;64`3F5V97(`3F5W('!A<W-W;W)D
M.@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M3$1!4"!0<F5F97)E;F-E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!#871E9V]R:65S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%!R969E<F5N8V5S
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(&%U=&AE;G1I8V%T:6]N+@!.;R!P<F5F97)E;F-E<R!A<F4@879A:6QA
M8FQE+@!.;W1E<P!.;W1I9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD
M+@!/;&0@<&%S<W=O<F0Z`$]P=&EO;G,`3W1H97(@26YF;W)M871I;VX`4&%S
M<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"$`4&%S<W=O<F0@;6]D=6QE(&ES(&YO
M="!P<F]P97)L>2!C;VYF:6=U<F5D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O8FQE;3\`4F5F<F5S:"!3
M=6UM87)Y(%9I97<Z`%)E;6]V92!P86ER`%)E<75I<F5D("=B87-E9&XG(&YO
M="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G9&%T86)A<V4G(&YO="!S<&5C
M:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D
M(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=H;W-T
M<W!E8R<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@
M8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G
M(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I
M8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P87-S=V]R9"<@;F]T
M('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE
M9"!I;B!344P@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO
M="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I
M9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M=&%B;&4G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN(&-A
M=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@
M<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("=T86)L95)E;&%T:6]N<R<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R
M:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U:60G(&YO="!S<&5C:69I
M960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M)W5I9"<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@875T
M:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S97)N86UE
M)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N
M8V5S(&-O;F9I9W5R871I;VXN`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)O
M;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E
M9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD
M('!A<W1E('1H96T@9G)O;2!T:&4@=&5X=&%R96$N`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!2
M97!O<G0`4V5R=F5R`%-E="!Y;W5R('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T('EO=7(@<')E9F5R<F5D(&1I<W!L
M87D@;&%N9W5A9V4N`%-H;W)T(%-U;6UA<GDZ`%-K:7`@36%I;G1E;F%N8V4`
M4V]M92!O9B!(;W)D92=S(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I
M;F<Z`%-O;64@;V8@4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F
M:6QE<R!A<F4@;6ES<VEN9SH`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5C
M8V5S<P!487-K<P!4:&4@<F5G:7-T<GD@:7,@:&]W($AO<F1E(&%P<&QI8V%T
M:6]N<R!F:6YD(&]U="!H;W<@=&\@=&%L:R!T;R!E86-H(&]T:&5R+B!9;W4@
M<VAO=6QD(&QI<W0@86YY(&EN<W1A;&QE9"!(;W)D92!A<'!L:6-A=&EO;G,@
M=&AA="!Y;W4@:&%V92!H97)E+@!4:&ES(&9I;&4@8V]N=&%I;G,@8F%C:V5N
M9"!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N(&9O<B!T:&4@4&%S<W=O<F0@
M;6]D=6QE('-C<FEP=',N`%1H:7,@9FEL92!C;VYT<F]L<R!T:&4@9VQO8F%L
M('-E="!O9B!-24U%(&1R:79E<G,@9F]R('1H92!(;W)D92!F<F%M97=O<FLL
M(&%L;&]W:6YG(&%P<&QI8V%T:6]N<R!T;R!M86ME('5S92!O9B!P<F]G<F%M
M<R!S=6-H(&%S(&5N<V-R:7!T(&]R(&US=V]R9'9I97<@=&\@<F5N9&5R(&-O
M;G1E;G0@:6YT;R!(5$U,(&9O<B!V:65W:6YG(&EN(&$@8G)O=W-E<BX`5&AI
M<R!F:6QE(&-O;G1R;VQS('1H92!S='EL97-H965T('1H870@:7,@=7-E9"!T
M;R!S970@8V]L;W)S(&%N9"!F;VYT<R!F;W(@=&AE($AO<F1E(&9R86UE=V]R
M:R!A;F0@86QL(&%P<&QI8V%T:6]N<R!T:&%T(&1O(&YO="!P<F]V:61E('1H
M96ER(&]W;B!S971T:6YG<RX`5&AI<R!F:6QE(&UA<',@9FEL92!E>'1E;G-I
M;VYS('1O(&QO9VEC86P@34E-12!T>7!E<RP@96YA8FQI;F<@2&]R9&4@87!P
M;&EC871I;VYS('1O(&9I9W5R92!O=70@:&]W('1O(&AA;F1L92!S;VUE(&-O
M;G1E;G0@<W5C:"!A<R!E;6%I;"!A='1A8VAM96YT<R!O<B!#5E,@8VAE8VMO
M=71S+@!4:&ES(&ES('1H92!M86EN($AO<F1E(&-O;F9I9W5R871I;VX@9FEL
M92X@270@8V]N=&%I;G,@<&%T:',@86YD(&)A<VEC(&ET96US('1H870@87!P
M;'D@=&\@=&AE(&-O<F4@9G)A;65W;W)K(&%N9"!A;&P@2&]R9&4@87!P;&EC
M871I;VYS+@!4:&ES(&ES('1H92!M86EN(%!A<W-W;W)D(&UO9'5L92!C;VYF
M:6=U<F%T:6]N(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N9"!O<'1I;VYS
M(&9O<B!A;&P@4&%S<W=O<F0@;6]D=6QE('-C<FEP=',N`%1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N
M=6UB97(N`%1I=&QE`%1Y<&4@;6ES;6%T8V@N`%523`!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@<F5G:7-T97(@<')E9F5R
M96YC97,@:6X@<V5S<VEO;BX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5N97AP96-T960@96YD(&]F(&9I
M;&4N`%5S92!$969A=6QT(%9A;'5E`%5S97(@3W!T:6]N<P!5<V5R(&YO="!F
M;W5N9`!5<V5R(&YO="!F;W5N9"X`57-E<FYA;64`57-E<FYA;64Z`%=A<FYI
M;F<`5V%R;FEN9R$`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EO=2!C86XG="!C
M:&%N9V4@<&%S<W=O<F0@9F]R('5S97(@)7,`66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+CQB<B`O/E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`
M66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@
M<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&=I=F4@>6]U<B!N
M97<@<&%S<W=O<F0`66]U(&UU<W0@9VEV92!Y;W5R(&]L9"!P87-S=V]R9`!9
M;W4@;75S="!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA
M:6P@061D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($YA;64Z`%EO=7(@
M;F5W('!A<W-W;W)D(&ES('1O;R!L;VYG.R!P87-S=V]R9',@;6%Y(&YO="!B
M92!M;W)E('1H86X@)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R(&YE=R!P87-S
M=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H86YG960A`%EO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@870@;&5A<W0@)60@8VAA<F%C=&5R
M<R!L;VYG(0!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&1I9F9E<F5N="!F
M<F]M('EO=7(@8W5R<F5N="!P87-S=V]R9`!9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%B971I8R!C:&%R86-T97)S
M+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@
M86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@8V]N=&%I;B!A="!L96%S="`E9"!L;W=E<F-A<V4@8VAA<F%C=&5R<RX`
M66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&YU
M;65R:6,@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT
M86EN(&%T(&QE87-T("5D('5P<&5R8V%S92!C:&%R86-T97)S+@!9;W5R(&YE
M=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5S<R!T:&%N("5D('=H:71E
M<W!A8V4@8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!N;W0@
M8V]N=&%I;B!W:&ET97-P86-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W
M;W)D<R!D:61N)W0@;6%T8V@`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!T96UP;F%M
M*"D@9F%I;&5D(0!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ(%!A<W-W9"`R
M+C(*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#,M,#(M,C0@,30Z-#DK,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`S+3`S+3`Q(#$R.C`P*S`R,#`*3&%S="U4
M<F%N<VQA=&]R.B!%=6=E;B!(;V%N8V$@/&5U9V5N:$!U<F)A;BUG<F%F>"YR
M;SX*3&%N9W5A9V4M5&5A;3H@4F]M86YI86X@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET"@`E<R!/<&5R871I=6YI(&1E(&UE;G1E;F%N=&$@+2!#;VYF
M:7)M87)E`"5S(&5S=&4@9V%T82!S82!E>&5C=71E(&]P97)A=&EU;FEL92!D
M92!M96YT96YA;G1A('-E;&5C=&%T92!M86D@:F]S+@`G)7,G(&YU(&5S=&4@
M8V]N9FEG=7)A="!I;B!(;W)D92!296=I<W1R>0`R-"!D92!O<F4`/&(^02!A
M<&%R=70@;R!E<F]A<F4@9F%T86QA.CPO8CX`04TO4$T`061A=6=A('!E<F5C
M:&5A`$%D<F5S80!!9V5N9&$`06QI87,`4RUA('-P96-I9FEC870@;R!V86QO
M87)E(&EN8V]R96-T82X`0VEM<'5R:2!D:7-P;VYI8FEL93H`0F%C:V5N9"!I
M;F-O<F5C="!I;7!L96UE;G1A="X`6FEU82!D92!N87-T97)E`$-64P!#86QE
M;F1A<@!296YU;G1A(&QA(%)A<&]R=`!496QE9F]N($UO8FEL`%-C:&EM8F$@
M<&%R;VQA`%-C:&EM8F$@<&%R;VQA('1A`%-C:&EM8F%R92!P87)O;&$@;&$@
M)7,`0FEF871I(&]P97)A=&EU;BAE82]I;&4I('!E(&-A<F4@9&]R:71I('-A
M(&QE(&9A8V5T:2!A8W5M+@!);F-H:61E($AE;'!U;`!);F-H:61E(&9E<F5A
M<W1R82!D92!(96QP`$EN8VAI9&4@9F5R96%S=')A`$-O;7!A;FEA`$-O;F9I
M<FUA<F4@<&%R;VQA(&YO=6$Z`$-O;G1I;G5T=6P@;'5I("<E<R<@+2!D92!T
M<F%D=7,`0V]N=&EN=71U;"!A<FAI=F5I(%)!4@!#;VYE8W1A<F4@;F5R975S
M:71A(&QA('-E<G9E<G5L(&QD87``0V]N96-T87)E(&YE<F5U<VET82!L82!S
M97)V97)U;"!L9&%P`$YU('!O="!D97-C:&ED92!M;V1U;'5L(&1E($UE;G1E
M;F%N=&$@)7,`3&5G871U<F$@:6UP;W-I8FEL82!C=2!S;6)P87-S=V0`6EH`
M6FEL;FEC`$5R;V%R92!I;B!I;G1E<F]G87)E82!B87IE:2!D92!D871E+@!)
M9&5N=&ET871E($EM<&QI8VET80!$97-C<FEE('!R;V)L96UA`$1E=&%L:6D@
M:6YR96=I<W1R871E(&EN($Q/1R!P96YT<G4@861M:6YI<W1R871O<BX`3W!T
M:75N:2!D92!!9FES87)E`%1E(')O9R!N=2!A8V-E<V$@9&ER96-T(&UA:6YT
M96YA;F-E+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N("T@9&4@=')A9'5S`$5R
M;V%R90!%<F]A<F4@;&$@=')I;6ET97)E82!D871E;&]R(&-A=')E('-M8G!A
M<W-W9"X`3R!D871A(&QA(#$U(&UI;G5T90!/(&1A=&$@;&$@,S`@<V5C=6YD
M90!,82!F:65C87)E(#4@;6EN=71E`$QA(&9I96-A<F4@0V]N96-T87)E`$\@
M9&%T82!L82`S,"!M:6YU=&4`26X@9FEE8V%R92!M:6YU=`!%>&5M<&QE(&1E
M('9A;&]R:3H`36$@87-T97!T86T@;&$@(D)%1TE.(B!P92!L:6YI82`E9`!-
M82!A<W1E<'1A;2!L82`B14Y$.B5S(B!P92!L:6YI82`E9`!.=2!P;W0@8VET
M:2!P<F5F97)I;G1E;&4N`$YU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L
M(&1E($Q$05`N`$5R;V%R92!I;B!S8VAI;6)A<F5A('!A<F]L96D@.B``1F%X
M`$1E<V-R:65R92!C;VUP;&5T83H`06IU=&]R`$%D<F5S82!D92!A8V%S80!4
M96QE9F]N=6P@9&4@86-A<V$`2&]R9&4`0V]N96-T87)E(&QA($AO<F1E`%-I
M<W1E;75L($AO<F1E`$AO<F1E(%=I<F5L97-S`$AO<F1E(&YU(&5S=&4@8V]N
M9FEG=7)A="!C;W)E<W!U;GIA=&]R`$EM<&]R=`!%<F]A<F4@9&4@:6YT<F%R
M93H`0VEM<"!I;7!O<G1A=#H@)7,`0VEM<'5R:2!I;7!O<G1A=&4Z`%!A<F]L
M82!I;F-O<F5C=&$`3&EM8F$`3&ES=&$@<W5B:65C=&5L;W(@9&EN($AE;'``
M0V]N96-T87)E`$1E8V]N96-T87)E`%!R;V)L96UA(&-U($-O;F5C=&%R96$N
M(%!R;V)A8FEL(&YU;65L92!D92!5=&EL:7IA=&]R('-A=2]S:2!087)O;&$@
M<VEN="!G<F5S:71E+@!)97-I<F4`3$P`0V]R97-P;VYD96YT80!-87`@1&%T
M92!A;F0@5&EM92!&:65L9',@+2!D92!T<F%D=7,`36%P($EM<&]R="!&:65L
M9',@+2!D92!T<F%D=7,`0VEM<'5R:2!P;W1R:79I=&4@+2!D92!T<F%D=7,`
M3F]T90!-97-A:@!,=6YA<@!3=6UA<G5L($UE=0!.=6UE`$YI8VEO9&%T80!0
M87)O;&$@;F]U83H`3G4@<VEN="!C;VYF:6=U<F%T92!0<F5F97)I;G1E;&4@
M3$1!4`!.=2!E<W1E(&-O;F9I9W5R871A($-A=&5G;W)I82!344P`3G4@<VEN
M="!C;VYF:6=U<F%T92!0<F5F97)I;G1E;&4@4U%,`$YU(&5S=&4@8V]N9FEG
M=7)A=&$@875T96YT:69I8V%R96$@4U%,`$YU(&5X:7-T82!P<F5F97)I;G1E
M(&1I<W!O;FEB:6QE+@!.;W1E`$YO=&EF:6-A=&EO;B!L:7-T96YE<B`E<R!N
M;W0@9F]U;F0N("T@9&4@=')A9'5S`%!A<F]L82!V96-H93H`3W!T:75N:0!!
M;'1E(&EN9F]R;6%T:6D`4&%R;VQA`%!A<F]L82!S8VAI;6)A=&$A`$UO9'5L
M=6P@9&4@<&%R;VQE(&EN8V]R96-T(&-O;F9I9W5R870`17AE8W5T82!/<&5R
M871I=6YI;&4@9&4@365N=&5N86YT80!496QE9F]N`%1E(')O9R!S<&5C:69I
M8V$@=6X@<W5M87(@86P@<')O8FQE;65I+@!492!R;V<@:6YT<F]D=2!U;B!N
M=6UE(&1E('5T:6QI>F%T;W(@<VD@;R!P87)O;&$`1&5S8W)I97)E82!P<F]B
M;&5M96D`4')O8FQE;6$_`%)E:6UP<F]S<&%T96%Z82!3=6UA<G5L("T@9&4@
M=')A9'5S`%-T97)G92!P97)E8VAE80`G8F%S961N)R!N97-P96-I9FEC870@
M:6X@8V]N9FEG=7)A=&EA(&1E(&%U=&5N=&EF:6-A<F4N`"=B87-E9&XG(&YE
M<W!E8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@<')E9F5R:6YT92X`)V1A
M=&%B87-E)R!N97-P96-I9FEC870@:6X@8V]N9FEG=7)A=&EA(&1E(&%U=&5N
M=&EF:6-A<F4N`"=D871A8F%S92<@;F5S<&5C:69I8V%T(&EN(&-O;F9I9W5R
M871I82!D92!C871E9V]R:6DN`"=D871A8F%S92<@;F5S<&5C:69I8V%T(&EN
M(&-O;F9I9W5R871I82!D92!P<F5F97)I;G1E+@`G:&]S='-P96,G(&YE<W!E
M8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@875T96YT:69I8V%R92X`)VAO
M<W1S<&5C)R!N97-P96-I9FEC870@:6X@8V]N9FEG=7)A=&EA(&1E(&-A=&5G
M;W)I:2X`)VAO<W1S<&5C)R!N97-P96-I9FEC870@:6X@8V]N9FEG=7)A=&EA
M(&1E('!R969E<FEN=&4N`"=P87-S=V]R9"<@;F5S<&5C:69I8V%T(&EN(&-O
M;F9I9W5R871I82!D92!A=71E;G1I9FEC87)E+@`G<&%S<W=O<F0G(&YE<W!E
M8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@8V%T96=O<FEI+@`G<&%S<W=O
M<F0G(&YE<W!E8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@<')E9F5R:6YT
M92X`)W!H<'1Y<&4G(&YE<W!E8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@4U%,
M+@`G=7-E<FYA;64G(&YE<W!E8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@
M875T96YT:69I8V%R92X`)W!H<'1Y<&4G(&YE<W!E8VEF:6-A="!I;B!C;VYF
M:6=U<F%T:6$@9&4@8V%T96=O<FEI+@`G<&AP='EP92<@;F5S<&5C:69I8V%T
M(&EN(&-O;F9I9W5R871I82!D92!P<F5F97)I;G1E+@`G=&%B;&4G(&YE<W!E
M8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@875T96YT:69I8V%R92X`)W1A
M8FQE)R!N97-P96-I9FEC870@:6X@8V]N9FEG=7)A=&EA(&1E(&-A=&5G;W)I
M:2X`)W1A8FQE)R!N97-P96-I9FEC870@:6X@8V]N9FEG=7)A=&EA(&1E('!R
M969E<FEN=&4N`"=T86)L95)E;&%T:6]N<R<@;F5S<&5C:69I8V%T(&EN(&-O
M;F9I9W5R871I82!D92!C871E9V]R:6DN`"=U:60G(&YE<W!E8VEF:6-A="!I
M;B!C;VYF:6=U<F%T:6$@9&4@875T96YT:69I8V%R92X`)W5I9"<@;F5S<&5C
M:69I8V%T(&EN(&-O;F9I9W5R871I82!D92!P<F5F97)I;G1E+@`G=7-E<FYA
M;64G(&YE<W!E8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@875T96YT:69I
M8V%R92X`)W5S97)N86UE)R!N97-P96-I9FEC870@:6X@8V]N9FEG=7)A=&EA
M(&1E(&-A=&5G;W)I:2X`)W5S97)N86UE)R!N97-P96-I9FEC870@:6X@8V]N
M9FEG=7)A=&EA(&1E('!R969E<FEN=&4N`%)E<V5T87)E`$EN87!O:2!L82!O
M<'1I=6YI`%)O;&4@+2!D92!T<F%D=7,`4V%L=F%Z82!/<'1I=6YI`$%L96=E
M(&-A<F%C=&5R96QE(&1E(&-A<F4@86D@;F5V;VEE(&1I;B!C87-U=&5L92!D
M92!M86D@:F]S+B!696D@<'5T96$@87!O:2!S82!L92!C;W!I97II(&EN('IO
M;F$@9&4@=&5X="X`1&5L:6UI=&%T;W(@9&4@9&%T83H`1F]R;6%T=6P@9&4@
M869I<V%R92!A(&1A=&5I.@!&;W)M871U;"!D92!A9FES87)E(&$@;W)E:3H`
M4V5L96-T96%Z82!D;W5A(&-I;7!U<FD@<&]T<FEV:71E+@!396QE8W1E87IA
M(&QI;6)A('!R969E<F%T83H`5')I;6ET92!287!O<G0@9&4@17)O87)E`%-E
M<G9E<@!!;&5G92!T:6UP=6P@9&4@<F5I;7!R;W-P871A<F4@82!P86=I;FEI
M('-I(&%L=&4@;W!T:75N:2!D92!A9FES87)E+@!396QE8W1E87IA(&QI;6)A
M(&1E(&%F:7-A<F4@<')E9F5R871A+@!3=6UA<B!S8W5R=#H`4V%R:2!P97-T
M92!-96YT96YA;G1A`%5N96QE(&9I<VEE<F4@9&4@8V]N9FEG=7)A<F4@;&EP
M<V5S8R!D:6X@2&]R9&4N`$%N=6UI=&4@9FES:65R92!D92!C;VYF:6=U<F%R
M92!087-S=V]R9"!L:7!S97-C.@!#87)A8W1E<F4@4W!E8VEA;&4@+BXN`%-U
M8V-E<P!387)C:6YI`%)E9VES=')Y=6P@9&5T97)M:6YA(&-U;2!S:6YT(&EN
M=&5R8V]N96-T871E(&1I9F5R:71E;&4@87!L:6-A=&EI($AO<F1E+D%R('1R
M96)U:2!S82!S<&5C:69I8VD@=&]A=&4@87!L:6-A=&EI;&4@:6YS=&%L871E
M(&%I8VDN`$%C97-T(&9I<VEE<B!C;VYT:6YE(&EN9F]R;6%T:6EL92!D92!C
M;VYF:6=U<F%R92!P96YT<G4@;6]D=6QU;"!087-S=V]R9"``06-E<W0@9FES
M:65R(&-O;G1I;F4@9')I=F5R96QE($U)344@9VQO8F%L92!P96YT<G4@87!L
M:6-A=&EI;&4@2&]R9&4@<&5R;6ET:6YD9F]L;W-I<F5A(&1E('!R;V=R86UE
M(&-U;2!S:6YT(&5N8W)I<'0@<V%U(&US=V]R9'9I97<@<&5N=')U(&$@<F%N
M9&$@9&EF97)I=&5L965L96UE;G1E(&EN('!A9VEN82!(5$U,('!E;G1R=2!A
M(&QE('!U=&5A('9I>G5A;&EZ82!I;B!B<F]W<V5R+@!!8V5S="!F:7-I97(@
M8V]N=')O;&5A>F$@4W1Y;&5S:&5E='5L(&9O;&]S:70@<&5N=')U('-E;&5C
M=&%R96$@8W5L;W)I;&]R<VD@9F]N='5R:6QO<B!P96YT<G4@87!L:6-A=&EI
M;&4@2&]R9&4@8V%R92!N=2!A=2!D969I;FET92!S=&EL=7)I('!R;W!R:6DN
M`$%C97-T(&9I<VEE<B!C;VYT:6YE(&5X=&5N<VEI;&4@;&]G:6-E('!E;G1R
M=2!T:7!U<FEL92!-24U%+"!D:6YD('!O<VEB:6QI=&%T96%C82!(;W)D92!S
M82!R96-U;F]A<V-A(&-U;2!S82!T<F%T97IE(&%N=6UI=&4@96QE;65N=&4@
M8W5M('-I;G0@871A<V%M96YT92!%;6%I;'-A=2!C:&5C:V]U='5R:2!#5E,N
M`$%C97-T82!E<W1E('!R:6YC:7!A;'5L(&9I<VEE<B!D92!C;VYF:6-U<F%R
M92!(;W)D92X@0V]N=&EN92!C86D@<VD@96QE;65N=&4@9&4@8F%Z86-A<F4@
M<VEN="!V86QA8FEE('!E;G1R=2!T;V%T92!A<&QI8V%T:6EL92!D:6X@<&%C
M:&5T=6P@2&]R9&4N`$%C97-T82!E(&9I<VEE<G5L('!R:6YC:7!A;"!D92!C
M;VYF:6=U<F%R92!087-S=V]R9"X@0V]N=&EN92!C86EL92!S:2!O<'1I=6YI
M;&4@<&5N=')U('-C<FEP='5R:6QE(%!A<W-W9"X@`%9A;&]A<F5A(&UI;FEM
M82!E<W1E(#$`06-E87-T82!V86QO87)E('1R96)U:64@<V$@9FEE(&YU;65R
M:6-A+@!4:71L=0!4:7`@9W)E<VET+@!54DP`0V]N96-T87)E(&QA('-E<G9E
M<G5L(%-13"!E<W5A=&$N`$YU('!O="!I;G)E9VES=')A('!R969E<FEN=&5L
M92!I;B!S97-I=6YE("T@9&4@=')A9'5S`$YU('!O="!T<F%D=6-E(&%C97-T
M(&1O8W5M96YT(%=O<F0@+2!D92!T<F%D=7,`06YU;&5A>F$@4V-H:6UB87)I
M;&4`4V9I<G-I="!D92!F:7-I97(@;F5A<W1E<'1A="X`571I;&EZ96%Z82!6
M86QO<FD@26UP;&EC:71E`$]P=&EU;FD@571I;&EZ871O<@!5=&EL:7IA=&]R
M(&YE9V%S:70`571I;&EZ871O<B!N96=A<VET+@!5=&EL:7IA=&]R`%5T:6QI
M>F%T;W(Z`$%V97)T:7-M96YT`$%T96YT:64A`%-A<'1A;6EN86P`0FEN92!A
M:2!V96YI="!I;B!S:7-T96UU;"`E<P!":6YE(&%I('9E;FET+"`E<P!!9')E
M<V$@;&$@4V5R=FEC:74`5&5L969O;B!L82!397)V:6-I=0!!00!!;G5A;`!.
M=2!P;W1I('-C:&EM8F$@<&%R;VQA('!E;G1R=2!U=&EL:7IA=&]R=6P@)7,`
M06D@9F]S="!D96-O;F5C=&%T+CQB<B`O/DUU;'1U;65S8R!C82!F;VQO<V5S
M=&D@<VES=&5M=6PN`%1R96)U:64@<V$@9&5S8W)I:2!P<F]B;&5M82!I;F%I
M;G1E(&1E(&$@=')I;6ET92!R87!O<G1U;"X`5')E8G5I92!I;G1R;V1U<V$@
M;R!N;W5A('!A<F]L80!4<F5B=6EE(&EN=')O9'5S82!V96-H96$@<&%R;VQA
M`%1R96)U:64@=F5R:69I8V%T82!N;W5A('!A<F]L80!397-I=6YE82!T82!D
M92`E<R!A(&5X<&ER870N(%1E(')O9R!S82!F86-I($QO9R!);B!D:6X@;F]U
M+@!!9')E<V$@=&$@9&4@16UA:6PZ`$EN9F]R;6%T:6D@9&5S<')E('1I;F4`
M3G5M96QE('1A=3H`3F]U82!P87)O;&$@92!P<F5A(&QU;F=A.R!P87)O;&5L
M92!N=2!P;W0@9FD@;6%I(&QU;F=I(&1E("5D(&-A<F%C=&5R92$`3F]U82!P
M87)O;&$@92!P<F5A('-I;7!L=2!D92!G:&EC:70A($YE<V-H:6UB871A(0!.
M;W5A('!A<F]L82!T<F5B=6EE('-A(&9I92!D92!M:6YI;2`E9"!C87)A8W1E
M<F4A`$YO=6$@<&%R;VQA('1R96)U:64@<V$@9FEE(&1I9F5R:71A(&1E('!A
M<F]L82!C=7)E;G1A`$YO=6$@<&%R;VQA('1R96)U:64@<V$@8V]N=&EN82!M
M:6YI;2`E9"!C87)A8W1E<F4@86QF86)E=&EC92X`3F]U82!P87)O;&$@=')E
M8G5I92!S82!C;VYT:6YA(&UI;FEM("5D(&-A<F%C=&5R92!A;&9A;G5M97)I
M8V4N`$YO=6$@<&%R;VQA('1R96)U:64@<V$@8V]N=&EN82!M:6YI;2`E9"!C
M87)A8W1E<F4@;6EN=7-C=6QE+@!.;W5A('!A<F]L82!T<F5B=6EE('-A(&-O
M;G1I;F$@8V5L('!U=&EN("5D(&-A<F%C=&5R92!N=6UE<FEC92X`3F]U82!P
M87)O;&$@=')E8G5I92!S82!C;VYT:6YA(&UI;FEM("5D(&-A<F%C=&5R92!M
M86IU<V-U;&4N`$YO=6$@<&%R;VQA('1R96)U:64@<V$@8V]N=&EN82!M86D@
M<'5T:6X@9&4@)60@<W!A=&EI+@!.;W5A('!A<F]L82!N=2!T<F5B=6EE('-A
M(&-O;G1I;F$@<W!A=&EI+@!087)O;&5L92!N;VD@;G4@<V4@<&]T<FEV97-C
M`$]P=&EU;FEL92!A=2!F;W-T('-A;'9A=&4N`%M287!O<G0@4')O8FQE;6%=
M`%ML:6YI82`E<R!D:6X@)7-=`'1E;7!N86TH*2!E<W5A=&$A`'9#87)D("T@
M9&4@=')A9'5S````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A
M<W-W9"]L;V-A;&4O<G5?4E4O````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(P,C(P`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]R=5]252],0U]-15-304=%
M4R\````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T
M-``P,C(P,#4`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE
M+W)U7U)5+TQ#7TU%4U-!1T53+W!A<W-W9"YM;P``````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#0V,S0U`#$P-#$W,S8R-S0T`#`R,S8U-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````!L!```<````]`@``'L!
M``#,$0```````+@7```H````N1<``"<```#B%P``'0````H8```M````*!@`
M``X```!6&```#@```&48```(````=!@```X```!]&```!0```(P8```.````
MDA@```,```"A&```"0```*48```(````KQ@``"0```"X&```!P```-T8```,
M````Y1@```4```#R&````P```/@8```C````_!@``!0````@&0``%P```#49
M```7````31D``!\```!E&0``.0```(49```1````OQD``"(```#1&0``"```
M`/09```.````_1D```H````,&@``!````!<:```(````'!H```8````E&@``
M%0```"P:```5````0AH```H```!8&@``#P```&,:```3````<QH``%0```"'
M&@``%````-P:```7````\1H``$0````)&P``'````$X;```,````:QL```<`
M``!X&P``%````(`;```5````E1L``!````"K&P``'0```+P;```@````VAL`
M`"D```#[&P``(0```"4<```&````1QP```T```!.'```#````%P<```H````
M:1P```(```"2'```!0```)4<```$````FQP```T```"@'```$````*X<```&
M````OQP``!0```#&'```+P```-L<```)````"QT``!8````5'0``#P```"P=
M```F````/!T```@```!C'0``"P```&P=```$````>!T``!$```!]'0``!0``
M`(\=```-````E1T``"````"C'0``!0```,0=```@````RAT``!````#K'0``
M#P```/P=```0````#!X```\````='@``"P```"T>```/````.1X```P```!)
M'@``#P```%8>```>````9AX``"$```"%'@``'@```*<>```F````QAX```,`
M``#M'@``%0```/$>```0````!Q\```T````8'P``!@```"8?```$````+1\`
M``H````R'P``!0```#T?```$````0Q\```P```!('P``"@```%4?```%````
M8!\```H```!F'P``#P```'$?```0````@1\```8```"2'P``$@```)D?```0
M````K!\``!(```"]'P``!P```-`?```(````V!\```X```#A'P``%@```/`?
M```1````!R````8````9(```$````"`@```/````,2````@```!!(```!@``
M`$H@```'````42````L```!9(````@```&4@```$````:"```&@```!M(```
M#P```-8@```*````YB````<```#Q(```*````/D@```'````(B$```L````J
M(0``!````#8A```%````.R$```P```!!(0``#0```$XA```$````7"$```0`
M``!A(0``"0```&8A```*````<"$```(```![(0``&P```'XA```3````FB$`
M``4```"N(0```@```+0A```-````MR$```<```#%(0``#@```,TA```*````
MW"$``!$```#G(0``(@```/DA```(````'"(``!<````E(@``+````#TB```O
M````:B(``"P```":(@``*@```,<B```K````\B(```D````>(P``"@```"@C
M```>````,R,``"@```!2(P``%````'LC```%````D",``"D```"6(P``'0``
M`,`C```H````WB,``"0````')```*0```"PD```?````5B0```T```!V)```
M!P```(0D```3````C"0``!X```"@)```%````+\D```.````U"0``"H```#C
M)```"P````XE```_````&B4``#T```!:)0``-@```)@E```%````SR4``!$`
M``#5)0``&````.<E```$`````"8```0````%)@``#`````HF```&````%R8`
M``\````>)@``&@```"XF```7````228``!<```!A)@``&P```'DF```9````
ME28``!\```"O)@``$P```,\F```_````XR8``#<````C)P``5P```%LG```-
M````LR<``"T```#!)P``)0```.\G```?````%2@``!T````U*```!````%,H
M```0````6"@``!,```!I*```%P```'TH```'````E2@```8```"=*```!P``
M`*0H```.````K"@```D```"[*```'P```,4H```O````Y2@``"$````5*0``
M'````#<I```+````5"D```4```!@*0```@```&8I```#````:2D``"````!M
M*0``)````(XI```F````LRD```P```#:*0``!P```.<I```R````[RD```P`
M```B*@``#@```"\J```/````/BH```@```!.*@``"0```%<J```*````82H`
M``<```!L*@``&0```'0J```'````CBH```,```"6*@``!@```)HJ```-````
MH2H```L```"O*@``+P```+LJ```,````ZRH``#$```#X*@``/P```"HK```,
M````:BL```H```!W*P```@```((K```&````A2L```,```",*P``)0```)`K
M```9````MBL``$4```#0*P``(P```!8L```?````.BP``"$```!:+```,```
M`'PL```2````K2P``!,```#`+```$````-0L```)````Y2P``%,```#O+```
M%P```$,M```/````6RT``%$```!K+0``-P```+TM```V````]2T``#8````L
M+@``/@```&,N``!!````HBX``$,```#D+@``0````"@O```^````:2\``$``
M``"H+P``0@```.DO```Y````+#```!\```!F,```'P```(8P```;````IC``
M`!0```#",```$````-<P```/````Z#````4```#X,```"````/XP```(````
M!S$``!4````0,0``!0```"8Q``#)`0``+#$``"4```#V,@``(P```!PS```D
M````0#,``#0```!E,P``"@```)HS```*````I3,```<```"P,P``#@```+@S
M```%````QS,```\```#-,P``"````-TS```)````YC,```T```#P,P``$P``
M`/XS```%````$C0```X````8-```"0```"<T```#````,30``!X````U-```
M$P```%0T```'````:#0``!8```!P-```(P```(<T``!"````JS0```\```#N
M-```'0```/XT```-````'#4```H````J-0``"@```#4U```&````0#4```D`
M``!'-0``!@```%$U```8````6#4``!$```!Q-0``%````(,U```.````F#4`
M`!(```"G-0``(0```+HU```.````W#4``!0```#K-0``/@`````V```8````
M/S8```P```!8-@``"````&4V```:````;C8``!D```")-@``#P```*,V```E
M````LS8``"8```#9-@``*@`````W```F````*S<```<```!2-P``!P```%HW
M```-````8C<``"8```!P-P```@```)<W```)````FC<```0```"D-P``$0``
M`*DW```4````NS<```<```#0-P``$````-@W```V````Z3<```<````@.```
M)@```"@X```0````3S@``"P```!@.```"0```(TX```,````ES@```X```"D
M.```"0```+,X```%````O3@``!(```##.```+@```-8X```&````!3D``"4`
M```,.0``#P```#(Y```/````0CD``!````!2.0``#@```&,Y```4````<CD`
M``X```"'.0``#0```)8Y```0````I#D``",```"U.0``)0```-DY```C````
M_SD``",````C.@``!````$<Z```/````3#H``!D```!<.@``#@```'8Z```&
M````A3H```D```",.@``"0```)8Z```&````H#H```8```"G.@``#@```*XZ
M```0````O3H```8```#..@``#0```-4Z```0````XSH```P```#T.@``"```
M``$[```6````"CL``!,````A.P``#P```#4[```)````13L```0```!/.P``
M%P```%0[```G````;#L``!\```"4.P``!0```+0[```9````NCL```L```#4
M.P``#````.`[```$````[3L```4```#R.P``!````/@[```"````_3L```4`
M````/```,@````8\```0````.3P```L```!*/```"0```%8\```M````8#P`
M``H```"./```"0```)D\```#````HSP```<```"G/```#P```*\\```,````
MOSP```<```#,/```!0```-0\```2````VCP```D```#M/````P```/<\```4
M````^SP``!(````0/0``!P```",]```"````*ST```X````N/0``"0```#T]
M```0````1ST```H```!8/0``$0```&,]```I````=3T```8```"?/0``%```
M`*8]```H````NST``#````#D/0``+0```!4^```I````0SX``"D```!M/@``
M!@```)<^```&````GCX``"````"E/@``-````,8^```&````^SX```<````"
M/P``(0````H_```6````+#\``",```!#/P``&````&<_```R````@#\``"(`
M``"S/P``$P```-8_```)````ZC\``!$```#T/P``(P````9````5````*D``
M`!````!`0```*P```%%````,````?4```$L```"*0```.@```-9````S````
M$4$```@```!%00``%@```$Y!```?````94$```@```"%00``"0```(Y!```3
M````F$$```4```"L00``#P```+)!```@````PD$``!4```#C00``)````/E!
M```>````'D(``!,````]0@``$````%%"```<````8D(``$,```!_0@``10``
M`,-"``!,````"4,``!(```!60P``)@```&E#```I````D$,``"(```"Z0P``
M'@```-U#```&````_$,``!0````#1```#P```!A$```3````*$0```0````\
M1```!@```$%$```'````2$0``!0```!01```#````&5$```N````<D0``"L`
M``"A1```)P```,U$```@````]40``!(````610``"0```"E%```$````,T4`
M``,````X10``(0```#Q%```D````7D4``"L```"#10``$@```*]%```&````
MPD4``$@```#)10``%@```!)&```6````*48``!8```!`1@``$````%=&```1
M````:$8``!````!Z1@``"P```(M&```5````ET8```@```"M1@```P```+9&
M```+````ND8``!4```#&1@``%````-Q&```E````\48```0````71P``,0``
M`!Q'```_````3D<```T```".1P``#P```)Q'```"````K$<```@```"O1P``
M`@```+A'```N````NT<``!0```#J1P``2````/]'```8````2$@``!8```!A
M2```(@```'A(``!!````FT@```H```#=2```%@```.A(```/````_T@```D`
M```/20``1````!E)```,````7DD```D```!K20``10```'5)```O````NTD`
M`"\```#K20``)````!M*```J````0$H``$````!K2@``0````*Q*``!'````
M[4H``#X````U2P``2````'1+```Y````O4L``#````#W2P``&0```"A,```>
M````0DP``!,```!A3```$0```'5,```6````ATP``!$```">3```!@```+!,
M```%````MTP```D```"]3```%P```,=,```%````WTP```$```!T````:0``
M`+8`````````:P`````````N````&@$`````````````#@````````"X````
M#`````\```"D```````````````&`````````!D!````````+````*8````4
M`0``````````````````V@`````````P````C@```+,````\````-P```-T`
M``"2````X```````````````3@```,8`````````@P```#D```#G````UP``
M`.@```#A````H`````````"_````3P`````````5````Y0```/@```"(````
MZ@````D!``"-````?0```-$```!*````^0```/,```#/````"@```!$````/
M`0```@```(H```#D`````@$``,4````I````$@```%8```!?````J`````<`
M``#_`````````#4````;`````````!P`````````$0$```````!P````TP``
M`-(```!%````X@````````!X````R````+X```#5````/P```&``````````
M5P``````````````XP````````#8````90```!`!``!$````Y@```(4`````
M````A`````````">````\`````````````````````````![````/@``````
M````````2P````````!D````+P```.X```!<````6````%X```!;````O0``
M`$,``````````P$``'X```!(````"@$```````#?````1@```$P````%````
M60````````!Y``````````L!``!Z````&0```*(`````````%0$```````#*
M````_````+H`````````MP```!\````J````#0$```8!``!J````_@``````
M``!0`````````*X```",````40````````#Q````M````.T```!=````J0``
M`*T```!C````T`````````#"````0@```)\`````````8@````````"!````
ME0```*4````V````<@```-L```"&````%@```)D````>````NP````X!```3
M`0``&P$``*P```#.````%P```&<````Z`````````,````!5````00```(<`
M``"6````@@````````#K````L@```#L``````````````/H`````````20``
M`!`````,`0``*``````````8````(0```(D````@````)``````````4````
M`````#T```"C````[P````L```#-````N0````````````````````````!:
M````&@```'4````````````````````%`0``PP```%,```#>````#0````0`
M``"7````-````#$```#,``````````````!H````$@$``/8`````````0```
M````````````]P```#@```":``````````````#)````'0```,$```"A````
M$P``````````````````````````````@````&$`````````(@````@````C
M````F````"<`````````_0```-P```"4````<P``````````````U`````0!
M```#`````0$````!```S````BP```/L````6`0``"`$``&T```";````````
M`-D`````````IP```,L```#6````QP```#(`````````]0````<!``"0````
M`````),```````````````````!\````Q`````````!-````L````)$`````
M````<0```!@!```F`````````%(```"<````O````*\`````````5````&8`
M````````\@````D```"=````*P```.D`````````[````'\````7`0``````
M`'8```"J`````````&P`````````L0```+4````M````JP```"4```!N````
M;P```(\```#T````1P```'<`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!D;V5S(&YO="!E>&ES="!O<B!I<R!N;W0@
M97AE8W5T86)L92X`)7,Z('5N86)L92!T;R!L;V%D(&1R:79E<CH@)7,`)R5S
M)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$%$4TD@97)R
M;W(@)7,N`$%-+U!-`$%C8V5S<R!$96YI960N`$%D9`!!9&0@2&5R93H`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9')E<W,`061D<F5S<R!";V]K`$%L:6%S`$%L;`!!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E
M<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!
M=F%I;&%B;&4@9FEE;&1S.@!"86-K96YD(&YO="!C;W)R96-T;'D@:6UP;&5M
M96YT960N`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]T
M:`!#86QE;F1A<@!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A=&5G
M;W)I97,@86YD($QA8F5L<P!#96QL(%!H;VYE`$-H86YG92!087-S=V]R9`!#
M:&%N9V4@<&%S<W=O<F0@;VXZ`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@96UA:6QS+@!#:&%N9V4@>6]U<B!P87-S=V]R9`!#:&%N9VEN9R!P
M87-S=V]R9"!O;B`E<P!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N
M*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&]O<V4@
M:&]W('1O(&1I<W!L87D@9&%T97,Z`$-L;W-E(%=I;F1O=P!#;VUP86YY`$-O
M;7!O<V4@365S<V%G92`H)7,I`$-O;F9I<FT@;F5W('!A<W-W;W)D.@!#;VYT
M96YT<R!O9B`G)7,G`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O
M=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N('!I
M<&4@=&\@<VUB<&%S<W=D+@!#<F5A=&4`0W5R<F5N="!0:&%S90!#=7)R96YT
M(%1I;64`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+@!$1`!$86EL>0!$871E`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$96QE=&4`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O=VYL;V%D`$1O=VYL
M;V%D("5S`$5D:70`161I="!O<'1I;VYS(&9O<CH`16UA:6P`16UP='D@<F5S
M=6QT+@!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%<G)O<@!%
M<G)O<B!S96YD:6YG(&1A=&$@=&\@<VUB<&%S<W=D+@!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE
M9"!T;R!V97)I9GD@;VQD('!A<W-W;W)D+@!&86EL=7)E(&EN(&-H86YG:6YG
M('!A<W-W;W)D(&]N("5S.B`E<P!&87@`1G)E92]"=7-Y($EN9F]R;6%T:6]N
M`$9U;&P@1&5S8W)I<'1I;VX`1V]O9VQE(%-E87)C:`!'<F]U<',`2&5L<`!(
M96UI<W!H97)E`$AO7VUE`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]R9&4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!);6%G97,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD
M<SH`26YC;W)R96-T(%!A<W-W;W)D`$QA7WEO=70`3&%N9W5A9V4`3&%S="!L
M;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.
M979E<@!,87EO=70`3&ES="!(96QP(%1O<&EC<P!,;V-A;&4@86YD(%1I;64`
M3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`34T`36%I;`!-
M86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E
M;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+@!-871C:&EN9R!F:65L9',`365N=2!M;V1E.@!-97-S
M86=E`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`
M36]N=&AL>0!-;V]N(%!H87-E<P!.86UE`$YE=F5R`$YE=R!#871E9V]R>0!.
M97<@<&%S<W=O<F0Z`$YE=W,`3F5X=`!.97AT(%!A9V4`3F5X="!0:&%S90!.
M;P!.;R!S=6-H(&)A8VME;F0@)R5S)R!F;W5N9"X`3F]R=&AE<FX@2&5M:7-P
M:&5R90!.;W1E<P!/2P!/;&0@<&%S<W=O<F0Z`$]P=&EO;G,`3W!T:6]N<R!F
M;W(@)7,`3W)G86YI>FEN9P!/=&AE<B!);F9O<FUA=&EO;@!087-S=V0@:7,@
M;F]T('!R;W!E<FQY(&-O;F9I9W5R960N`%!A<W-W;W)D`%!A<W-W;W)D(&-H
M86YG960@;VX@)7,N`%!A<W-W;W)D(&UO9'5L92!C86XG="!F:6YD('1H92!S
M=7!P;&EE9"!B:6XN`%!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG(')E<75I
M<F5D('!A<F%M971E<G,N`%!A<W-W;W)D(&UO9'5L92!I<R!M:7-S:6YG('1A
M<F=E="!P87)A;65T97(N`%!A<W-W;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R
M;'D@8V]N9FEG=7)E9`!087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R;W!E<FQY
M(&-O;F9I9W5R960N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!P<F]V:61E(&$@;F5W('!A<W-W;W)D`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!C=7)R
M96YT('!A<W-W;W)D`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!L96%S92!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0`4')E
M=FEO=7,@4&%G90!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5F<F5S
M:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z
M`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.@!296UO=F4@<&%I<@!297%U:7)E9"`G9')I=F5R<R<@
M:7,@;6ES8V]N9FEG=7)E9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@4&%S<W=D(%-1
M3"!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I
M9FEE9"!I;B!344P@8V]N9FEG=7)A=&EO;BX`4F5S970`4F5T=7)N('1O($]P
M=&EO;G,`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)O;&4`4V%V90!3879E
M($]P=&EO;G,`4V5A<F-H`%-E;&5C="!A('-E<G9E<@!396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@
M=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5T('5P(')E;6]T
M92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P
M;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D
M:7-P;&%Y(&]P=&EO;G,N`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K
M97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:7IE
M`%-K:7`@36%I;G1E;F%N8V4`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3=6)J96-T`%-U8FUI=`!3=6-C97-S`%-U;G)I
M<V4O4W5N<V5T`%1E>'0@3VYL>0!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S
M>7-T96TN`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I;64@9F]R;6%T`%1I=&QE
M`%1O`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B
M;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O('1R
M86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5N9FEL
M960`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0
M('-E<G9E<BX`57-E<B!/<'1I;VYS`%5S97(@;F]T(&9O=6YD`%5S97(@;F]T
M(&9O=6YD+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!6:65W("5S
M`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5V%R;FEN9P!796(`5V5E:VQY
M`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5VAA="!A<'!L:6-A=&EO;B!S
M:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAI8V@@<&AA<V5S`%=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BX`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F
M9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE
M`%E9`%EE87)L>0!997,`66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@
M=7-E<B`E<P!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!G:79E('EO=7(@8W5R<F5N="!P87-S
M=V]R9`!9;W4@;75S="!G:79E('EO=7(@;F5W('!A<W-W;W)D`%EO=2!M=7-T
M('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9`!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R
M97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R
M($YA;64`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R!P<FEN="X`
M66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!F=6QL(&YA;64Z`%EO=7(@
M;F5W('!A<W-W;W)D(&ES('1O;R!L;VYG.R!P87-S=V]R9',@;6%Y(&YO="!B
M92!M;W)E('1H86X@)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R(&YE=R!P87-S
M=V]R9"!I<R!T;V\@<VEM<&QE('1O(&=U97-S(2`@3F]T(&-H86YG960A`%EO
M=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,N($YO="!C
M:&%N9V5D(0!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&)E(&%T(&QE87-T("5D
M(&-H87)A8W1E<G,@;&]N9R$`66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!D
M:69F97)E;G0@9G)O;2!Y;W5R(&-U<G)E;G0@<&%S<W=O<F0`66]U<B!N97<@
M<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&%L<&AA8F5T:6,@
M8VAA<F%C=&5R<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T
M(&QE87-T("5D(&%L<&AA;G5M97)I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@;&]W97)C87-E(&-H
M87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L
M96%S="`E9"!N=6UE<FEC(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D
M(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!U<'!E<F-A<V4@8VAA<F%C=&5R
M<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&QE<W,@=&AA;B`E
M9"!W:&ET97-P86-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU
M<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C:&%R86-T97)S+@!9;W5R(&YE
M=R!P87-S=V]R9',@9&ED;B=T(&UA=&-H`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!P87-S=V]R9',@9&\@;F]T(&UA=&-H`%EO=7(@
M<F5M;W1E('-E<G9E<G,Z`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@
M)7-=`%](96QP`%],;V<@;W5T`%]/<'1I;VYS`&QD87!?<W1A<G1?=&QS(&9A
M:6QE9`!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ(%!A<W-W9"!(,R`H,RXP
M+6-V<RD*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,#@M,C(@,C,Z,3$K,#DP,`I0
M3RU2979I<VEO;BU$871E.B`R,#`U+3`X+3(R(#$V.C0P*S`P,#`*3&%S="U4
M<F%N<VQA=&]R.B!);&QY82!"96QO=B`\8F5L;W9`:6]P+FER:W!S+G)U/@I,
M86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I
M;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0U`Q
M,C4Q"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU<F%L+49O
M<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]/3$@)B8@;B4Q,#`A/3$Q
M(#\@,"`Z(&XE,3`^/3(@)B8@;B4Q,#P]-"`F)B`H;B4Q,#`\,3`@?'P@;B4Q
M,#`^/3(P*2`_(#$@.B`R*3L*`,[OY?#@]NC_(._NY.3E\.;JZ"`E<R`M(,_N
MY/+BY?#FY.7MZ.4`)7,@[>4@\?/YY?'RXO/E\B#HZ^@@[>4@Z/'O[NOM_^7L
M^^D`)7,Z(.WEXN[G[.[F[>X@Y^#C\//GZ/+\(.3PX.GBY?`Z("5S`,_PZ.ON
MYN7MZ.4@)R5S)R#MY2#QZN[M].CC\_#H\.[BX.WN(.(@2&]R9&4@4F5G:7-T
M<GD`,3(M]^#Q[N+NZ0`R-"WWX/'NXN[I`#(T(/?@\>``SOCHX>K@($%$4TD@
M)7,`04TO4$T`Q.[Q\O/O(.?@[_#E^>7M`,3NX>#BZ/+\`,3NX>#BZ/+\.@#$
M[N'@XNCR_"#OX/#S`$%D9"!-;WII;&QA('-I9&5B87(`P.3PY?$`P.3PY?'M
MX/\@ZNWHX^``S_'EXN3N[>CL`,+QY0#0X.?PY?CH\OP@[N_E\.#VZ.@@\>X@
M\>_H\>K@[.@`P.O\\N7P[>#RZ.+M^^D@25--4`#/X/#NZ_PZ`,CL_R#O[NO\
MY^[BX/+EZ_\@25--4#H`P?OK[B#SZN#GX.WN(.WEZN[P\.7J\NWNY2#G[>#W
MY>WHY2X`Q^#O\.#XZ.+@\OP@[^[D\N+E\.;DY>WHY2#OY?#EY"#B^^_NZ^WE
M[>CE["#N[^7PX/;HZ2#NX?'K\^;HXN#MZ/\_`,3N\?+S[^W[Y2#O[NO_.@!"
M86-K96YD(.WE(.KN\/#EZO+M[B#MX/'R\.[E[0#$Y>W\(/#NYN3E[>C_`,W@
M\?+P[NGJX#H`T.#Q^.CPY>WHY0#"[.7Q\N4`RN#KY>WDX/#\`,[R[.7MX`#.
M\NSE[>`@[O+WY?+@(.X@[_#NX>OE[.4`RN#RY>/N\.CH(.@@[.7RZN@`RNOE
M\N[W[>#_(/#@Y.CN\>+_Y_P`T>SE[>CR_"#OX/#NZ_P`T>SE[>CR_"#OX/#N
MZ_P@[>`Z`,W@\?+P[NGJZ"#H[.7MZ"P@X.3PY?'@+"#O[N3OZ/'H+@#1[.7M
MZ/+\(._@\.[K_`#1[.7MZ/+\(._@\.[K_"#MX"`E<P#.\NSE\OSRY2#TZ^#F
MZN#LZ"#N[^7PX/;H_BCHZ"DL(.KN\N[P^^4@POL@]>[RZ/+E(.[Q\_GE\?+B
MZ/+\+@#4[O#LX/(@[O+NX?#@YN7MZ/\@Y.#R^SH`Q^#J\/OR_"#NZNWN`,KN
M[._@[>C_`-'N\?+@XNOE[>C_(/'N[N'YY>WH_R`H)7,I`,_NY/+BY?#DZ/+E
M(.WNXOOI(._@\.[K_#H`T>[DY?#FZ.SNY2`G)7,G`,WEXN[G[.[F[>X@\>+_
MY^#R_/'_(/$@;&1A<"#QY?#BY?#N["X`S>7B[N?L[N;M[B#Q[N7DZ.WH\O'_
M(/$@;&1A<"#QY?#BY?#N["X`S>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN
M=&5N86YC95]487-K("5S`,WEXN[G[.[F[>X@[O+J\/OR_"!P:7!E(.3K_R!S
M;6)P87-S=V0N`-'NY^3@\OP`TN7J\_G@_P#2Y>KS^>7E(.+PY>S_`,?@Y.#W
MZ"P@Y^#O\_'JX.7L^^4@[_#H(.+U[N3E(.(@S^[P\N#K`,3$`,7FY>3MY>+M
M[@#$X/+@`-;BY?(@[^X@\^SNZ_?@[>C^`,_P[O3HZ_P@[^X@\^SNZ_?@[>C^
M`-/DX.OH\OP`SN_H^.CRY2#O\.[AZ^7L\P#/[N3P[N'M[O'RZ"#A^^OH(.?@
M[^CQX.W[(.(@YO/P[>#K(.3K_R#@Y.SH[>CQ\O#@\N[PX"X`RN#RX.ONXP#.
M\N[A\.#FX/+\(.+PY>S_(.(@,C0M]^#Q[N+N["#T[O#LX/+E/P#$\//CZ.4@
M[>#Q\O#NZ>KH`,WE(.+[Y_OBX.GRY2!M86EN=&5N86YC92YP:'`@[>7O[O'P
MY>3Q\N+E[>WN`,?@X_#SY^CR_`#'X./P\^?H\OP@)7,`T.7DX.KRZ/#NXN#M
MZ.4`S>#Q\O#NZ>KH`$5M86EL`,WSZ^7B[ND@\.7G\^O\\N#R+@#*[NWRY>KQ
M\NWNY2#LY>W^(._N(.W@YN#RZ.@@[_#@XN[I(.KM[N_JZ"#L^_CH`,[XZ.'J
MX`#.^.CAZN`@[O+O\.#BZN@@Y.#M[?OU(.3K_R!S;6)P87-S=V0N`,K@YN3[
MY2`Q-2#LZ.WS\@#*X.;D^^4@,B#LZ.WS\OL`RN#FY/OE(#,P(/'EZO/MY`#*
MX.;D^^4@-2#LZ.WS\@#*X.;D^^D@\.#G(._PZ"#B]>[DY0#*X.;D^^4@[^[K
M]^#QX`#*X.;D\_X@[.CM\_+S`,_PZ.SE\"#G[>#WY>WHZ3H`PN[Q\?+@[>[B
MZ^7MZ.4@[>#Q\O#NY>H@[>4@\^3@Z^[Q_"X`S>7SY.#W[>[E(/'NY>3H[>7M
MZ.4@\2#QY?#BY?#N["!,1$%0+@#-Y?/DX.ON\?P@[^[D\N+E\.3H\OP@\?+@
M\/OI(._@\.[K_`#-Y2#SY.#E\O'_(/'LY>WH\OP@[^#P[NO\(.W@("5S.B`E
M<P#4X.KQ`,+@^.`@Z.WT[O#LX/;H_P#/[NOM[N4@[N_H\>#MZ.4@[_#NX>OE
M[/LZ`,_NZ/'J(.(@1V]O9VQE`,/P\^_O^P#/[N3QZN#GZN``S^[K\_C@\.CE
M`,_N\/+@ZP#/[O#RX.L`Q.[LX/CMZ.D@X.3PY?$`Q.[LX/CMZ.D@\N7KY?3N
M[0#/[O#RX.L`TN[K_.KN(.CJ[NWJZ`#(ZN[MZN@@\2#RY>KQ\N[L`,CL_R#O
M\.[TZ.O_.@#*X/#RZ.WJZ`#([._N\/+H\.[BX.WN(._NZ^4Z("5S`,CL[^[P
M\NCP[N+@[?L@[^[K_SH`S>7BY?#M^^D@[^#P[NO\`-#@\>KKX.3JX`#?Y_OJ
M`,_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S`,_PY>3[Y//YZ.D@XO7NY"#A^^LZ
M("5S(/$@ZN[L[_S^\N7PX"`E<P#/\.7D^^3S^>CI(.+U[N0@[>4@Y^#TZ.KQ
MZ/#NXN#M`,+[]>[D`-'OZ/'NZB#PX.?DY>ONXB#O[N3QZN#GZN@`R^[JX.OH
MY^#VZ/\`T.#Q[^[K[N;E[>CE`,+U[N0`POOU[N0`PO7NY`#,S`#/[O?RX`#-
MX/'R\.[IZN`@\>_H\>K@(.K@\N7C[O#HZ2#H(/;BY?+NXB#H]2#N\N[A\.#F
MY>WH_P#1[N+OX.3@_OGHY2#O[NO_`-#EYNCL(.SE[?XZ`-'N[N'YY>WHY0#,
MZ.WH[.#K_.W[Z2#Q\.[J(.3EZ?'RXNC_(._@\.[K_R#E^>4@[>4@Z/'RY>H`
MQ>;E[.7Q__?M[@#4X.?[(,OS[?L`R.S_`,WHZN[CY.``S>[BX/\@ZN#RY>/N
M\.C_`,WNXOOI(._@\.[K_`#-[N+N\?+H`,3@Z^7E`-'KY>3S_OGE_R#Q\O#@
M[>CVX`#1Z^7D\_[YX/\`S>7R`,WE(.W@Z>3E[2!B86-K96YD("5S`-'EXN7P
M[>[E(._NZ_/XX/#HY0#'X.SE\NKH`$]+`-'RX/#[Z2#OX/#NZ_PZ`,W@\?+P
M[NGJZ`#-X/'R\.[IZN@@Y.O_("5S`,[PX^#MX.GGY?``S_#N]^#_(.CM].[P
M[.#VZ/\`4&%S<W=D(.WE(/'J[NWTZ./S\.CP[N+@[2#D[NOF[?OL(.[A\.#G
M[NP`S^#P[NO\`,_@\.[K_"#HY^SE[>7M(.W@("5S`%!A<W-W9"#L[N3SZ_P@
M[>4@[.[FY?(@[>#I\N@@[>7NX?7NY.CL^^4`4&%S<W=D(.SNY//K_"X@SO+Q
M\_+Q\N+S_O(@[>7NX?7NY.CL^^4@[^#PX.SE\O#[`%!A<W-W9"#L[N3SZ_PN
M(,[R\?/R\?+B\_[R(.+[]>[D[?OE(._@\.#LY?+P^P!087-S=V0@[.[D\^O\
M(.WE(.W@\?+P[N7M(.3NZ^;M^^P@[N'PX.?N[`!087-S=V0@[.[D\^O\(.WE
M(.W@\?+P[N7M(.3NZ^;M^^P@[N'PX.?N[`#/X/#NZ_P`S^#P[NO\`,[Q\_GE
M\?+BZ^7MZ.4@[N_E\.#VZ.D@[^[DY.7PYNKH`,+[[^[K[>CR_"#N[^7PX/;H
MZ"#NX?'K\^;HXN#MZ/\@[_#H(.+U[N3E(.(@\>CQ\N7L\S\`R^CW[?OE`-+E
MZ^7T[NT`PN+EY.CRY2#MX.?BX.WHY2#M[N+NZ2#JX/+EX^[PZ.@Z`,WE[N'U
M[N3H["#M[N+[Z2#OX/#NZ_P`S^[FX.OSZ?'RX"P@\>[NX?GH\N4@\?/R_"#O
M\.[AZ^7L^RX`S>7NX?7NY.CL(/+EZO/YZ.D@[^#P[NO\`,_NYN#K\^GQ\N`L
M(.+BY>3H\N4@PN#XZ"#H[/\@[^[K_.?NXN#RY>O_(.@@[^#P[NO\`,+[(.3N
MZ^;M^R#O[N3RXN7PY.CR_"#M[N+[Z2#OX/#NZ_P`S_#EY/OD\_G@_R#Q\O#@
M[>CVX`#/\.[AZ^7LX#\`SN_H\>#MZ.4@[_#NX>OE[/L`SN'M[N+K__+\(.3H
M[>#LZ/?E\>KHY2#O\^WJ\OL@[.7M_CH`SN'M[N+K__+\(.CM].[P[.#VZ/XZ
M`,_N]_+NXOOE(/'E\.+E\.``P.3PY?$@\>7PXN7PX"`H[>#O\.CLY?`@:'1T
M<#HO+VUA:6PN='5T+F)Y*0#3Y.#KZ/+\(._@\/,`TO#EX?/E[/OE(.3PX.GB
MY?#@(.WE(/'J[NWTZ./S\.CP[N+@[?L@XB#Q[O'RX.+M[ND@*$-O;7!O<VET
M92D@ZN[M].CC\_#@]NCH`-+PY>'SY>S[Z2`G<&AP='EP92<@[>4@[N_PY>3E
MZ^7M(.(@ZN[M].CC\_#@]NCH(%!A<W-W9"!344P`TO#EX?/E[/OI("=P:'!T
M>7!E)R#MY2#N[_#EY.7KY>T@XB#J[NWTZ./S\.#VZ.@@4U%,`-'A\.[QZ/+\
M`,+E\.WS\OSQ_R#J(.W@\?+P[NGJX.P`S>#Q\O#NZ>KH(.+HY_/@Z_SM[N/N
M(/#EY.#J\N[PX`#1]N7MX/#HZ0#1[O7PX.WH\OP`T>[U\.#MZ/+\(.W@\?+P
M[NGJZ`#/[NCQZ@#"^^'E\.CRY2#QY?#BY?``POOAY?#H\N4@\.#GY.7KZ/+E
MZ_P@[^[KY>D@Y.#R^SH`POOAY?#H\N4@].[P[.#R(.3@\OLZ`,+[X>7PZ/+E
M(.[R[N'PX.;E[>C_(/3N\.S@\B#B\.7LY>WH.@#"^^'E\.CRY2#DXN`@\>[B
M[^#DX/[YZ/4@[^[K_RX`PN#XX"#VXN7R[N+@_R#Q]>7LX`#?Y_OJ(.[R[N'P
MX.;E[>C_`,_N\>O@\OP@\>[NX?GE[>CE(.X@[_#NX>OE[.4`T>'N\"#O[O?R
M^R#Q(,+@^.CU(._N]_+NXOOU(/_YZ.KNXBP@\.#Q[^[K[N;E[?OU(.W@(.3P
M\^/H]2#QY?#BY?#@]0#3\?+@[>[BZN`@_^?[ZN`@XOOB[N3@+"#B\.7LY>WM
M[ND@Y^[M^R#H(/3N\.S@\N`@[O+NX?#@YN7MZ/\@XO#E[.7MZ"X`T_'RX.WN
MXNK@(._PZ.ONYN7MZ/\@[^X@\^SNZ_?@[>C^+"#VXN7R[N+NZ2#Q]>7L^R#H
M(._P[O?H]2#N[_;HZ2#N\N[A\.#FY>WH_P#*\.#RZN[E(.[A[N'YY>WHY3H`
MSN_PY>3EZ^CR_"#A^_'R\/OE(.KKX.+H^.@@Y.O_(/'Q^^ONZC\`S^[JX.?[
MXN#R_"#H[?3N\.S@]NC^(.X@[_#EY/OD\_GE["#B]>[DY3\`S^[JX.?@\OP@
M[.7M_B#N[^7PX/;HZ2#Q(/+@X>OH]N#LZ`#.\N[A\.#FX/+\(.SE[?X@S^[P
M\N#KX"#QZ^7BX#\`T.#G[.7P`,_P[N_S\?+H\OP@[^[DY.7PYNKS`-[F[>[E
M(._NZ_/XX/#HY0#1[^7VZ.#K_.W[Y2#QZ.SB[NO[`-+E[.``R/'JX/+\`-/Q
M[^7X[>X`PO#E[/\@XN[Q]>[DX"_GX.K@\N``TN[K_.KN(/+EZO'R`,3K_R#O
M[N+R[O#M[N/N(.+U[N3@(.CQ[^[K_.?SZ?+E(.CL_R#H(._@\.[K_"X`SOCH
MX>K@(._PZ"#N\N[A\.#FY>WHZ"#]\N[I(/?@\?+H(/'N[N'YY>WH_P#=\NX@
M]^CQZ^X@[>4@[.[FY?(@X?OR_"#LY>W\^.4@Y>3H[>CV^RX`W?+N(.?MX/?E
M[>CE(.3NZ^;M[B#A^_+\(/?H\>ON["X`U.[P[.#R(.[R[N'PX.;E[>C_`,?@
MX^[K[N+NZ@#*[NSS`%523`#-Y2#L[N/S(/'NY>3H[>CR\?\@\2!344P@\>7P
MXN7P[NP`S>7B[N?L[N;M[B#GX./P\^?H\OP@[N_PY>3EZ^7MZ.4@)7,N`-WR
M[O(@Y.[J\^SE[?(@5V]R9"#MY2#L[N;E\B#A^_+\(._E\.7BY>3E[2X`SO+L
MY>WH\OP@Z.?LY>WE[>C_`,_S\?+NZ0#(\>_NZ_SG\^7R\?\@Y?'KZ"#BX/CH
M(.CL_R_OX/#NZ_P@Y.O_($E-4U`@\>7PXN7PX"#N\NOH]^#^\O'_(.[R(/+E
MZO/YZ/4`S>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_P#/[NO\Y^[BX/+EZ_P@[>4@
M[>#IY.7M`,_NZ_SG[N+@\N7K_"#MY2#MX.GDY>T`R.S_(._NZ_SG[N+@\N7K
M_P#([/\@[^[K_.?NXN#RY>O_.@#([/\@[^[K_.?NXN#RY>O_`,_P[O'L[O+P
M("5S`,_NZN#GX/+\(.+EX2WQ\O#@[>CV\P#"[>CLX.WHY0#"Y>$`Q>;E[>7D
MY>O\[>X`Q.[A\.X@[^[FX.ONXN#R_"#B("5S`,3NX?#N(._NYN#K[N+@\OPL
M("5S`-?R[B#N\N[A\.#FX/+\(._N\>OE(.+U[N3@(.(@\>CQ\N7L\SH`U.#G
MX`#*X.KHY2#N[_;HZ"#A\^3S\B#D[O'R\^_M^R#B(.+HY_/@Z_SM[NP@\.7D
MX.KR[O#E`-CH\.CMX"#LY>W^(,_N\/+@Z^`@\>OEXN`@*.'SY.7R(._PZ.SE
M[>7MX"#O\.@@\>OEY//^^>7L(.+U[N3E*0#0X.'N]^CI(.#D\.7Q`-#@X>[W
MZ.D@\N7KY?3N[0##PP#%YN7C[N3M[@#$X`#"^R#MY2#L[N;E\N4@[.7M__+\
M(._@\.[K_"#DZ_\@[^[K_.?NXN#RY>O_("5S`,+[(.+[^.OH(.CG(/'H\?+E
M[/LN`,+[(.3NZ^;M^R#N[^CQX/+\(._P[N'KY>S[+"#O\.7FY.4@]^7L(/'L
M[N;E\N4@[O+N\>O@\OP@\>[NX?GE[>CE(.X@[>7I+@#-Y>[A]>[DZ.P@\N7J
M\_GHZ2#OX/#NZ_P`S>7NX?7NY.CL(.WNXOOI(._@\.[K_`#"^R#D[NOF[?L@
M[^[D\N+E\.3H\OP@[>[B^^D@[^#P[NO\`,+@^.`@)7,@\>7Q\>C_(.?@ZN[M
M]^CKX/'\+B#/[N;@Z_/I\?+@+"#B[NGDZ/+E(.(@\>CQ\N7L\R#GX.WNXNXN
M`,+@^"!%;6%I;#H`PN#X(.#D\.7Q(.[R[_#@XNCRY>O_.@#"X/C@(.CM].[P
M[.#VZ/\`PN#XY2#H[/\Z`,+@^"#A\.[SY^7P(.WE(._NY.3E\.;HXN#E\B#N
M[_;H_B#OY??@\N@N(,3K_R#OY??@\N@@[>#F[.CRY2!#5%),*U`N`-?@\>[B
M[ND@[^[_\0#"X/CE(.CL_SH`S^#P[NO\(/'KZ/CJ[NP@Y.OH[>W[Z3L@[^#P
M[NO\(.WE(.3NZ^;MY2#O\.CB^_C@\OP@Y.OH[>WS("5D(/'H[.+NZ^[B`,_@
M\.[K_"#QZ^CXZN[L(.OEX^KHZ2$@R.?LY>WE[>CI(.WE(._P[NCGXN7DY>WN
M`,_@\.[K_"#QZ^CXZN[L(.OEX^KHZ2$@R.?LY>WE[>CI(.WE(._P[NCGXN7D
MY>WN`,_@\.[K_"#D[NOFY>T@X?OR_"#A[NOEY2`E9"#QZ.SB[NONX@#-[N+[
MZ2#OX/#NZ_P@Y.[KYN7M(.[RZ^CWX/+\\?\@[O(@\N7J\_GEX^X`S>[B^^D@
M[^#P[NO\(.3NZ^;E[2#Q[N3E\.;@\OP@ZN#J(.SH[>CL\^P@)60@X.OTX.+H
M\NW[]2#QZ.SB[NONX@#-[N+[Z2#OX/#NZ_P@Y.[KYN7M(/'NY.7PYN#R_"#J
MX.H@[.CMZ.SS["`E9"#@Z_3@XNCR[?OU(/'H[.+NZ^[B`,WNXOOI(._@\.[K
M_"#D[NOFY>T@\>[DY?#FX/+\(.K@ZB#LZ.WH[//L("5D(/'H[.+NZ^[B(.(@
M[>CF[>7L(/#EX^CQ\O#E`,WNXOOI(._@\.[K_"#D[NOFY>T@\>[DY?#FX/+\
M(.K@ZB#LZ.WH[//L("5D(/?H\>ONXOOU(/'H[.+NZ^[B`,WNXOOI(._@\.[K
M_"#D[NOFY>T@\>[DY?#FX/+\(.K@ZB#LZ.WH[//L("5D(/'H[.+NZ^[B(.(@
MXN7P]>WE["#PY>/H\?+PY0#-[N+[Z2#OX/#NZ_P@Y.[KYN7M(/'NY.7PYN#R
M_"#O\.[AY>O[+B#*X.H@[.CMZ.SS["`E9"#X\BX`S>[B^^D@[^#P[NO\(.3N
MZ^;E[2#MY2#D[NOFY>T@\>[DY?#FX/+\(._P[N'EZ^[B`,WNXOOI(._@\.[K
M_"#MY2#Q[N+OX.3@Y?(`PN#XZ"#MX/'R\.[IZN@@X?OKZ"#NX>WNXNOE[?LN
M`,_@\.[KZ"#MY2#Q[N+OX.3@_O(`T?+N\.[M[>CI(/'E\.+E\#H`6]'N[N'Y
MY>WHY2#N(._P[N'KY>SE70!;\?+P[NK@("5S(.CG("5S70#/[NSN^?P`POOU
M[N0`S>#Q\O#NZ>KH`&QD87!?<W1A<G1?=&QS(.WE\^3@Z_'_`'9#87)D````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L
M;V-A;&4O<G5?4E4O:&5L<"YX;6P`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#0U,C4`,3`T,3<S-C(W-#0`,#(Q-C<U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_>&UL('9E<G-I;VX](C$N
M,"(@96YC;V1I;F<](D-0,3(U,2(_/@H\(2TM("1(;W)D93H@<&%S<W=D+VQO
M8V%L92]R=5]252]H96QP+GAM;"QV(#$N,2`R,#`U+S`X+S(S(#`W.C`V.C(U
M(&IA;B!%>'`@)"`M+3X*/&AE;'`^"@H\96YT<GD@:60](G!A<W-W9"UU<V5R
M;F%M92(@;60U/2(R-C`R,F8P9#<R9&0R.3$P.#DW.#5E.#,V-F)A.6$T,R(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93[([/\@[^[K_.?NXN#RY>O_
M/"]T:71L93X*("`@(#QH96%D:6YG/L+@^.4@Z.S_(._NZ_SG[N+@\N7K_SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@PN+EY.CRY2#Q_N3@(.CL_R#O[NO\
MY^[BX/+EZ_\@*.7QZ^@@[NWN(.7YY2#MY2#GX._NZ^WE[>XI+B#-Y2#B\>4@
M\_'RX.WNXNKH(._NY.3E\.;HXN#^\B#]\NXN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"@H*/&5N=')Y(&ED/2)P87-S=V0M;VQD+7!A<W-W;W)D(B!M9#4](C`X
M9&-C.#1D.3@T-C)A9#4Y,#,U-F-E-F5D-C`Y8S0P(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/M'RX/#[Z2#OX/#NZ_P\+W1I=&QE/@H@("`@/&AE
M861I;F<^T?+@\/OI(._@\.[K_#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
MPN+EY.CRY2#Q_N3@(,+@^"#RY>KS^>CI(/#@X>[WZ.D@[^#P[NO\+B`@POL@
MY.[KYNW[(%EO=2!M=7-T(._PX.+HZ_SM[B#BXN7Q\N@@\N7J\_GHZ2#OX/#N
MZ_PL(.CMX/?E(.+[(.WE(/'L[N;E\N4@\_'RX.WNXNCR_"#M[N+[Z2#OX/#N
MZ_PN"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](G!A<W-W9"UN
M97<M<&%S<W=O<F0B(&UD-3TB-&8R-&1E9C4V.#0Y-S9F8S1E,C4P-V0X,SDS
M-CDV-#$B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^S>[B^^D@[^#P
M[NO\/"]T:71L93X*("`@(#QH96%D:6YG/LWNXOOI(._@\.[K_#PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@PN+EY.CRY2#M[N+[Z2#OX/#NZ_PL(.KN\N[P
M^^D@POL@]>[RZ/+E(//Q\N#M[N+H\OPN("#"XN7DY>WM^^D@[^#P[NO\(.3N
MZ^;E[2#Q[N[RXN7R\>+NXN#R_"#MY>KN\N[P^^P@[.CMZ.S@Z_SM^^P@\?+@
M[>3@\/+@["`HY.[Q\N#R[O?MX/\@Y.OH[>W@+"#MY2#Q[N+OX.3@\OP@\2#H
M[.7MY>P@[^[K_.?NXN#RY>O_+"#Q[O'R[O_R_"#HYR#J[NSAZ.W@]NCH(.'S
MZN(@Z"#D\//CZ/4@\>CLXN[K[N(L(.@@\B[D+BDL(.CMX/?E(,+[(._NZ_/W
MZ/+E(.[XZ.'J\RX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB
M<&%S<W=D+6-O;F9I<FTM<&%S<W=O<F0B(&UD-3TB-30V93%B.3$Y-#4T,#!F
M-S8P-V9A-&8Q,S,V-#@X-68B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET
M;&4^S^[D\N+E\.;DY>WHY2#M[N+NX^X@[^#P[NO_/"]T:71L93X*("`@(#QH
M96%D:6YG/L_NY/+BY?#FY.7MZ.4@[>[B[N/N(._@\.[K_SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@PN+EY.CR(.WNXOOI(._@\.[K_"#B\N[P[ND@\.#G
M(.(@[^[KY2`BS^[D\N+E\.3H\N4@[>[B^^D@[^#P[NO\(BX@(-WR[B#DX.7R
M(//BY?#E[>WN\?+\+"#W\NX@XOL@[>4@Y.[O\_'RZ.OH(.[XZ.'JZ"X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB<&%S<W=D+7-E<G9E<B(@
M;60U/2(W-CAF-S(S,S`X-C!B8CAC.69F-SED-6)E8SAF931F,"(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93[1[.7MZ/+\(._@\.[K_"#MX#PO=&ET
M;&4^"B`@("`\:&5A9&EN9S[1[.7MZ/+\(._@\.[K_"#MX#PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@POOAY?#E\N4@\>7PXN7P(.CKZ"#O\.CK[N;E[>CE
M+"#Q(._N[.[Y_/X@ZN[R[O#NX^X@\>SE[>CR_"#OX/#NZ_PN(,WE(.+QY2#S
M\?+@[>[BZN@@[^[DY.7PYNCBX/[R(/WR[BX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*"CQE;G1R>2!I9#TB0VAA;F=E+7EO=7(M<&%S<W=O<F0B(&UD-3TB.#%C
M,S,R8C9A8C-A,3-E9#!D,#%D,#AF-S@P-&0R9&,B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^T>SE[>CR_"#OX/#NZ_P\+W1I=&QE/@H@("`@/&AE
M861I;F<^T>SE[>CR_"#OX/#NZ_P\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(,W@YNSH\N4@ZNWN[^KS("+1[.7MZ/+\(._@\.[K_"(@Y.O_(._NY.#WZ"#G
MX._P[O'@(.W@(/'LY>WS(._@\.[K_RX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M"CQE;G1R>2!I9#TB<F5S970B(&UD-3TB,CDX9#8R8F(X9F9C8S8U-C@T.&8X
M-V-F-F8S8C5A,C8B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^T>'P
M[O'H\OP\+W1I=&QE/@H@("`@/&AE861I;F<^T>'P[O'H\OP\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(,CQ[^[K_.?SZ?+E(.KM[N_J\R#1X?#N\>CR_"#B
M[>CG\R#T[O#L^R#DZ_\@[O?H\?+JZ"#PX.WEY2#BXN7DY>WM^_4@Y.#M[?OU
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/"]H96QP/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!A<W-W9"]L;V-A;&4O<VM?4TLO````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(P,3<V`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]S:U]32R],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<T-``P,C$W-C,`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O
M;&]C86QE+W-K7U-++TQ#7TU%4U-!1T53+W!A<W-W9"YM;P``````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P-#(T-3<P`#$P-#$W,S8R-S0T`#`R,S8S,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#>$@25`````(P'```<````
M?#P``!,*``#<>````````"BA``!-````*:$``+\```!WH0``9````#>B``"^
M````G*(``)````!;HP``0P```.RC```\````,*0``"L```!MI```+@```)FD
M```I````R*0``"@```#RI```10```!NE``!'````8:4``$H```"II0``1P``
M`/2E``!%````/*8``$@```""I@``.0```,NF``!&````!:<``$@```!,IP``
M,````)6G``!%````QJ<``$8````,J```3````%.H```T````H*@``#(```#5
MJ```:0````BI```P````<JD``"4```"CJ0``B````,FI``!`````4JH``/8`
M``"3J@``2@```(JK```L````U:L``(4````"K```2````(BL```.````T:P`
M``\```#@K```#0```/"L```(````_JP```L````'K0``#````!.M```$````
M(*T```P````EK0``$0```#*M```E````1*T```\```!JK0``"P```'JM```1
M````AJT```X```"8K0``!0```*>M```H````K:T```@```#6K0``"@```-^M
M```5````ZJT``!(`````K@``"P```!.N```G````'ZX``!,```!'K@``#@``
M`%NN```*````:JX```T```!UK@``+@```(.N```.````LJX``!$```#!K@``
M#0```-.N```,````X:X```T```#NK@``!@```/RN```=`````Z\``!L````A
MKP``+0```#VO```=````:Z\``"0```")KP``*0```*ZO```9````V*\```\`
M``#RKP``&`````*P```,````&[```!L````HL```#@```$2P```.````4[``
M``@```!BL```"0```&NP``!"````=;```"X```"XL```&@```.>P```R````
M`K$``#@````UL0``5````&ZQ``!1````P[$``%H````5L@``5P```'"R```T
M````R+(```X```#]L@``"0````RS```-````%K,```<````DLP``"@```"RS
M```/````-[,```4```!'LP``!@```$VS```1````5+,```@```!FLP``"0``
M`&^S```)````>;,```X```"#LP``)0```)*S```@````N+,``!````#9LP``
M#P```.JS```*````^K,```,````%M```#P````FT```4````&;0```D````N
MM```#0```#BT```2````1K0``!D```!9M```'@```'.T```/````DK0```H`
M``"BM```#P```*VT```(````O;0``"0```#&M```%````.NT```6`````+4`
M``@````7M0``3@```""U```M````;[4``!\```"=M0``&0```+VU```'````
MU[4```P```#?M0``+````.RU```.````&;8```,````HM@``"P```"RV```'
M````.+8```<```!`M@``!0```$BV```%````3K8```H```!4M@```P```%^V
M```7````8[8```H```![M@``#P```(:V```.````EK8``!@```"EM@``(P``
M`+ZV```.````XK8``!0```#QM@``%P````:W```7````'K<``!<````VMP``
M$P```$ZW```/````8K<```X```!RMP``'P```(&W```=````H;<```<```"_
MMP``!@```,>W```(````SK<```\```#7MP``!@```.>W```*````[K<``!,`
M``#YMP``"P````VX```0````&;@``!4````JN```%0```$"X```'````5K@`
M`!````!>N```!0```&^X```1````=;@```P```"'N```.P```)2X```X````
MT+@```D````)N0``!P```!.Y```#````&[D```4````?N0``$````"6Y```)
M````-KD``!,```!`N0``.0```%2Y```G````CKD``"P```"VN0``*@```..Y
M```E````#KH```H````TN@``!@```#^Z```)````1KH```<```!0N@``+P``
M`%BZ```W````B+H``"X```#`N@``50```.^Z```M````1;L``"T```!SNP``
M+0```*&[``!`````S[L``",````0O```(P```#2\```M````6+P``#,```"&
MO```%0```+J\```9````T+P``"D```#JO```)````!2]```1````.;T```H`
M``!+O0``#````%:]```B````8[T```H```"&O0``$````)&]```6````HKT`
M`!8```"YO0``!P```-"]```'````V+T```H```#@O0``"````.N]```G````
M]+T```@````<O@``!P```"6^```'````+;X```8````UO@``!0```#R^```'
M````0KX```8```!*O@``"````%&^```I````6KX```X```"$O@``"@```).^
M```$````GKX```<```"CO@``"0```*N^```&````M;X``!$```"\O@``!P``
M`,Z^```6````UKX```0```#MO@``"````/*^```&````^[X```T````"OP``
M!@```!"_```>````%[\``!$````VOP``(@```$B_```6````:[\```@```""
MOP``#0```(N_```,````F;\```<```"FOP```P```*Z_```#````LK\``!<`
M``"VOP``$P```,Z_```=````XK\```@`````P```!`````G````(````#L``
M``@````7P```00```"#````@````8L````8```"#P```!@```(K````5````
MD<```!@```"GP```(@```,#````N````X\```!T````2P0``(0```##!``!4
M````4L$``"D```"GP0``"@```-'!```'````W,$``!4```#DP0``#@```/K!
M```*````"<(```\````4P@``#0```"3"```/````,L(```T```!"P@``"0``
M`%#"```&````6L(``!@```!AP@``$P```'K"```1````CL(``!0```"@P@``
M!````+7"```&````NL(```\```#!P@``$P```-'"``!4````Y<(``!0````Z
MPP``%P```$_#```$````9\,```X```!LPP``1````'O#```%````P,,```4`
M``#&PP``$0```,S#```1````WL,``!P```#PPP``*@````W$```0````.,0`
M`"$```!)Q```)0```&O$```9````D<0```4```"KQ```$P```+'$```2````
MQ<0```H```#8Q```#P```./$```-````\\0``!$````!Q0``$P```!/%```,
M````)\4```8````TQ0``#````#O%```&````2,4``!<```!/Q0``$````&?%
M```1````>,4```@```"*Q0``!0```)/%```,````F<4``!````"FQ0``!0``
M`+?%```-````O<4```8```#+Q0``!P```-+%```-````VL4``!````#HQ0``
M"0```/G%```'`````\8```L````+Q@``"P```!?&```'````(\8```<````K
MQ@``%````#/&```)````2,8```H```!2Q@``&0```%W&```=````=\8```P`
M``"5Q@``$````*+&```5````L\8```4```#)Q@``)0```,_&```2````]<8`
M`!,````(QP``*P```!S'```[````2,<``"````"$QP``-@```*7'```0````
MW,<```@```#MQP``#````/;'```&`````\@```0````*R```#@````_(```0
M````'L@```H````OR```#0```#K(```>````2,@``!L```!GR```(0```(/(
M```>````I<@``!D```#$R```'@```-[(```=````_<@``!L````;R0``(```
M`#?)```N````6,D``!<```"'R0``)@```)_)```P````QLD``!L```#WR0``
M'@```!/*```<````,LH``"8```!/R@``*P```';*```S````HLH``"8```#6
MR@``*P```/W*```X````*<L``!T```!BRP``%0```(#+```O````ELL``!(`
M``#&RP``(````-G+```I````^LL``!X````DS```(0```$/,```2````9<P`
M`*(```!XS```%@```!O-```C````,LT``"@```!6S0``*0```'_-```H````
MJ<T``!\```#2S0``%0```/+-```@````",X``"4````IS@``*````$_.```M
M````>,X``#````"FS@``D@```-?.```A````:L\``!8```",SP``'````*//
M```F````P,\``"H```#GSP``00```!+0``!$````5-````P```"9T```!P``
M`*;0```'````KM````8```"VT```#0```+W0```0````R]```!(```#<T```
M$P```._0```2`````]$```<````6T0``!````![1```0````(]$```P````T
MT0``#@```$'1```/````4-$``!,```!@T0``#0```'31```H````@M$```,`
M``"KT0``#0```*_1```&````O=$```X```#$T0```@```-/1```%````UM$`
M`!````#<T0``!````.W1```-````\M$```X`````T@```P````_2```.````
M$](```@````BT@``#P```"O2```/````.](```<```!+T@``#0```%/2```0
M````8=(``!,```!RT@``$P```(;2```+````FM(```8```"FT@``#````*W2
M```1````NM(``!D```#,T@``"P```.;2```-````\M(``"(`````TP``&P``
M`"/3```T````/],```H```!TTP``&````'_3```9````F-,``!8```"RTP``
M+P```,G3```B````^=,```T````<U```!P```"K4```4````,M0```L```!'
MU```(@```%/4```O````=M0```L```"FU```"0```++4```9````O-0```L`
M``#6U```%P```.+4```7````^M0```D````2U0``%@```!S5```/````,]4`
M`!8```!#U0``#@```%K5```8````:=4```@```""U0``#0```(O5```F````
MF=4``$,```#`U0``"`````36```2````#=8```@````@U@``"P```"G6```O
M````-=8```X```!EU@``!0```'36```&````>M8```,```"!U@``!P```(76
M```$````C=8```H```"2U@``"@```)W6```/````J-8``!````"XU@``%P``
M`,G6```1````X=8``!<```#SU@``&0````O7```)````)=<```4````OUP``
M"P```#77```*````0=<```(```!,UP``!0```$_7```-````5=<``!L```!C
MUP``%P```'_7```)````E]<```X```"AUP``#0```+#7```2````OM<``#@`
M``#1UP``(`````K8```(````*]@```X````TV```>P```$/8```8````O]@`
M`$````#8V```$0```!G9```'````*]D```4````SV0``(````#G9```9````
M6MD``!,```!TV0``!P```(C9```'````D-D```@```"8V0``!@```*'9```&
M````J-D``!````"OV0``#P```,#9```0````T-D```\```#AV0``"P```/'9
M```/````_=D```P````-V@``#P```!K:```'````*MH```H````RV@``!@``
M`#W:```.````1-H```P```!3V@``*````&#:```/````B=H```@```"9V@``
M%@```*+:```(````N=H``!,```#"V@``'@```-;:```A````]=H``"`````7
MVP``&0```#C;```7````4ML``"4```!JVP``%P```)#;```>````J-L``"8`
M``#'VP``!````.[;```;````\]L```T````/W```#````!W<```#````*MP`
M``@````NW```"@```#?<```,````0MP```L```!/W```$````%O<```,````
M;-P```0```!YW```$P```'[<```4````DMP```P```"GW```"0```+3<```.
M````OMP```L```#-W```&P```-G<```'````]=P```<```#]W```"@````7=
M```-````$-T```D````>W0``!````"C=```%````+=T```,````SW0``&```
M`#?=```*````4-T```0```!;W0``)@```&#=```.````A]T``'P```"6W0``
M%0```!/>```%````*=X```<````OW@``#````#?>```(````1-X```H```!-
MW@``!@```%C>```(````7]X``!8```!HW@``$@```'_>```"````DMX```8`
M``"5W@``!@```)S>```4````H]X```T```"XW@``$````,;>```;````U]X`
M``0```#SW@``"0```/C>```0`````M\```D````3WP``"0```!W?```%````
M)]\```4````MWP``&@```#/?```(````3M\```8```!7WP``&0```%[?```.
M````>-\``"(```"'WP``!P```*K?```'````LM\```X```"ZWP``!0```,G?
M```)````S]\```H```#9WP```@```.3?```&````Y]\```T```#NWP``"0``
M`/S?```&````!N````D````-X```!P```!?@```4````'^```!T````TX```
M$0```%+@```&````9.````H```!KX```!````';@```)````>^````@```"%
MX```$0```([@```1````H.````D```"RX```!@```+S@```-````P^````8`
M``#1X```!````-C@```Y````W>```#T````7X0``.@```%7A```>````D.$`
M``4```"OX0``#@```+7A```$````Q.$```8```#)X0``(0```-#A```&````
M\N$```0```#YX0``$0```/[A```&````$.(``*`````7X@``"@```+CB```B
M````P^(```0```#FX@``)0```.OB```%````$>,``!T````7XP``!````#7C
M```,````.N,```H```!'XP``"````%+C```)````6^,```4```!EXP``&P``
M`&OC```Z````A^,``#````#"XP``-0```//C```I````*>0``"X```!3Y```
M1P```(+D```X````RN0``"D````#Y0``/P```"WE```N````;>4``"T```"<
MY0``'P```,KE```/````ZN4``!(```#ZY0``"P````WF```F````&>8``"D`
M``!`Y@``)````&KF```F````C^8```@```"VY@``"@```+_F```)````RN8`
M``<```#4Y@``(````-SF```@````_>8``"8````>YP``"@```$7G```9````
M4.<``"D```!JYP``%@```)3G```2````J^<```<```"^YP``"@```,;G```,
M````T><```\```#>YP``$````.[G``!`````_^<``'````!`Z```9@```+'H
M```.````&.D```D````GZ0``"@```#'I```2````/.D``!,```!/Z0``#```
M`&/I```&````<.D```\```!WZ0``$@```(?I```0````FND``!$```"KZ0``
M$@```+WI```<````T.D``",```#MZ0``:@```!'J```/````?.H```4```",
MZ@``$````)+J```)````H^H```0```"MZ@``"P```++J```:````ONH``!0`
M``#9Z@``#````.[J```,````^^H```\````(ZP``%0```!CK```I````+NL`
M`"H```!8ZP``)@```(/K```G````JNL``"D```#2ZP``*@```/SK```9````
M)^P``$(```!![```$0```(3L```2````ENP``!,```"I[```%````+WL```/
M````TNP``!8```#B[```%P```/GL```0````$>T``!$````B[0``-````#3M
M```3````:>T``!(```!][0``-0```)#M```4````QNT```<```#;[0``#```
M`./M```@````\.T``!0````1[@``$0```";N```7````..X``!P```!0[@``
M$P```&WN```4````@>X``!H```"6[@``$0```+'N```:````P^X``!X```#>
M[@``&@```/WN```3````&.\``!4````L[P``$0```$+O```7````5.\``!0`
M``!L[P``%P```('O```5````F>\```D```"O[P``&0```+GO```$````T^\`
M``<```#8[P``"P```.#O```1````[.\```8```#^[P``!@````7P```&````
M#/````4````3\```!P```!GP```'````(?````4````I\```!@```"_P```&
M````-O````0````]\```!````$+P```'````1_````X```!/\```#````%[P
M```,````:_````T```!X\```"@```(;P```.````D?````4```"@\```*```
M`*;P```.````S_````P```#>\```#P```.OP```*````^_````@````&\0``
M"0````_Q```K````&?$```0```!%\0``"````$KQ```F````4_$``!(```!Z
M\0``!@```(WQ```*````E/$```<```"?\0``"````*?Q```@````L/$```D`
M``#1\0``#````-OQ```-````Z/$```X```#V\0``%@````7R```1````'/(`
M``8````N\@```P```#7R```&````.?(``!D```!`\@``!P```%KR```$````
M8O(```L```!G\@``"P```'/R```'````?_(```<```"'\@``%@```(_R```-
M````IO(```T```"T\@``"@```,+R```0````S?(```\```#>\@``$0```.[R
M```7`````/,```H````8\P``$0```"/S```(````-?,```0````^\P``#P``
M`$/S```Z````4_,```4```".\P``#````)3S```>````H?,```X```#`\P``
M$````,_S```+````X/,```P```#L\P``"0```/GS```'`````_0```H````+
M]```"0```!;T```.````(/0``!`````O]```&@```$#T```*````6_0```D`
M``!F]```%````'#T```*````A?0```P```"0]```#P```)WT```(````K?0`
M``8```"V]```!P```+WT```+````Q?0``$<```#1]```#0```!GU```)````
M)_4```0````Q]0```P```#;U```3````.O4``!,```!.]0``$P```&+U```*
M````=O4```(```"!]0``!````(3U```E````B?4```,```"O]0``!0```+/U
M```J````N?4```H```#D]0``!0```._U```$````]?4```H```#Z]0``#0``
M``7V``!`````$_8``!,```!4]@``!@```&CV```(````;_8```@```!X]@``
M!````('V```%````AO8``&@```",]@``"0```/7V```,````__8```4````,
M]P``!@```!+W```;````&?<``"\````U]P``$````&7W```*````=O<```\`
M``"!]P``"@```)'W```)````G/<``!,```"F]P``&P```+KW```8````UO<`
M`!<```#O]P``#@````?X```#````%O@```<````:^```"````"+X```'````
M*_@```H````S^```"P```#[X```M````2O@``!4```!X^```,````([X```D
M````O_@```<```#D^```40```.SX```0````/OD```P```!/^0``#0```%SY
M```:````:OD``$H```"%^0``&0```-#Y```&````ZOD``!H```#Q^0``!@``
M``SZ```&````$_H``!\````:^@``!@```#KZ```)````0?H``!@```!+^@``
M%P```&3Z```H````?/H```8```"E^@``#0```*SZ```B````NOH``%<```#=
M^@``$P```#7[```C````2?L``!,```!M^P```@```('[```+````A/L```@`
M``"0^P``#0```)G[```*````I_L```8```"R^P``!P```+G[```4````P?L`
M``8```#6^P``"````-W[```.````YOL```<```#U^P``"@```/W[```+````
M"/P```<````4_```#````!S\```-````*?P```P````W_```"0```$3\```)
M````3OP```H```!8_```!P```&/\```)````:_P```<```!U_```"@```'W\
M```;````B/P``!(```"D_```"@```+?\```)````POP``!````#,_```!P``
M`-W\```2````Y?P```0```#X_```!P```/W\```%````!?T```4````+_0``
M"P```!']```4````'?T``!$````R_0``&@```$3]```6````7_T``!0```!V
M_0``%P```(O]```8````H_T``!P```"\_0``&0```-G]```'````\_T```4`
M``#[_0``#0````'^```,````#_X```@````<_@``%P```"7^```+````/?X`
M``T```!)_@``$P```%?^```$````:_X```H```!P_@``!````'O^```-````
M@/X```P```"._@``!0```)O^```)````H?X```4```"K_@``!P```+'^```%
M````N?X```0```"__@```@```,3^```X````Q_X``"P`````_P``$@```"W_
M```I````0/\``#(```!J_P``"@```)W_```V````J/\``"P```#?_P``%0``
M``P``0`N````(@`!`#,```!1``$`,P```(4``0`X````N0`!``\```#R``$`
M&`````(!`0`[````&P$!`!````!7`0$`#P```&@!`0`4````>`$!`!,```"-
M`0$`%0```*$!`0`4````MP$!`!(```#,`0$`%````-\!`0`5````]`$!`"T`
M```*`@$`+0```#@"`0`Q````9@(!`"T```"8`@$`+@```,8"`0`O````]0(!
M`"P````E`P$`8@```%(#`0`3````M0,!``@```#)`P$`"````-(#`0`;````
MVP,!`"L```#W`P$`(0```",$`0`:````100!``D```!@!`$`10```&H$`0!!
M````L`0!``0```#R!`$`$P```/<$`0`.````"P4!`!,````:!0$`&````"X%
M`0`&````1P4!``D```!.!0$`"@```%@%`0`/````8P4!`!````!S!0$`!P``
M`(0%`0`.````C`4!``4```";!0$`&P```*$%`0`&````O04!``@```#$!0$`
M!@```,T%`0`4````U`4!`!$```#I!0$`#@```/L%`0`X````"@8!``(```!#
M!@$`!@```$8&`0`.````308!`!H```!<!@$`!0```'<&`0`'````?08!``X`
M``"%!@$`!@```)0&`0`-````FP8!``0```"I!@$`*0```*X&`0`7````V`8!
M`!\```#P!@$`7````!`'`0`4````;0<!`#X```""!P$`'P```,$'`0`0````
MX0<!``<```#R!P$`#@```/H'`0`(````"0@!``P````2"`$`#````!\(`0`3
M````+`@!``H```!`"`$`'0```$L(`0`9````:0@!``4```"#"`$`$0```(D(
M`0`1````FP@!`"0```"M"`$`%0```-((`0`2````Z`@!``X```#["`$`&0``
M``H)`0`(````)`D!``D````M"0$`#0```#<)`0`*````10D!``<```!0"0$`
M#P```%@)`0`&````:`D!``L```!O"0$`"@```'L)`0`'````A@D!``@```".
M"0$`!0```)<)`0`?````G0D!``8```"]"0$`$````,0)`0`(````U0D!``T`
M``#>"0$`(@```.P)`0`(````#PH!`!<````8"@$`$@```#`*`0`L````0PH!
M`"\```!P"@$`+````*`*`0`J````S0H!`"L```#X"@$`+````"0+`0`:````
M40L!``D```!L"P$`"@```'8+`0`5````@0L!``4```"7"P$`%````)T+`0`$
M````L@L!`!````"W"P$`!@```,@+`0`'````SPL!`!X```#7"P$`*````/8+
M`0`*````'PP!`!P````J#`$`&@```$<,`0`/````8@P!`!0```!R#`$`!```
M`(<,`0`$````C`P!``L```"1#`$`!0```)T,`0`&````HPP!``@```"J#`$`
M!@```+,,`0`;````N@P!`#0```#6#`$`-`````L-`0`@````0`T!`"D```!A
M#0$`(````(L-`0!!````K`T!`!H```#N#0$`'0````D.`0`H````)PX!`"0`
M``!0#@$`*0```'4.`0!1````GPX!`"\```#Q#@$`(@```"$/`0`?````1`\!
M``8```!D#P$`"````&L/`0`%````=`\!``@```!Z#P$`&0```(,/`0`9````
MG0\!`"H```"W#P$`(P```.(/`0`N````!A`!`#0````U$`$`"````&H0`0`7
M````<Q`!``H```"+$`$`!P```)80`0`A````GA`!`!````#`$`$`#@```-$0
M`0`+````X!`!``<```#L$`$`$P```/00`0`(````"!$!``L````1$0$`"@``
M`!T1`0`4````*!$!``\````]$0$`,@```$T1`0`+````@!$!``4```",$0$`
M!0```)(1`0`7````F!$!``\```"P$0$`!````,`1`0`*````Q1$!``D```#0
M$0$`"P```-H1`0`-````YA$!``P```#T$0$`#@````$2`0`%````$!(!``0`
M```6$@$`#0```!L2`0`R````*1(!`$4```!<$@$`%P```*(2`0`>````NA(!
M`!0```#9$@$`!0```.X2`0`4````]!(!``<````)$P$`#@```!$3`0`J````
M(!,!``8```!+$P$`#````%(3`0`-````7Q,!`!$```!M$P$`"P```'\3`0`V
M````BQ,!``H```#"$P$`(@```,T3`0`+````\!,!``\```#\$P$`,@````P4
M`0`E````/Q0!`#````!E%`$`,0```)84`0`M````R!0!`#\```#V%`$`/0``
M`#85`0`V````=!4!``X```"K%0$`!0```+H5`0`.````P!4!`!,```#/%0$`
M!P```.,5`0`:````ZQ4!``@````&%@$`$0````\6`0`'````(18!`!0````I
M%@$`&````#X6`0`'````5Q8!``4```!?%@$`#````&46`0`,````<A8!`!(`
M``!_%@$`!````)(6`0`'````EQ8!``H```"?%@$`"P```*H6`0`,````MA8!
M``X```##%@$`#@```-(6`0`%````X18!``4```#G%@$`+@```.T6`0`F````
M'!<!`",```!#%P$``P```&<7`0`2````:Q<!``8```!^%P$`'@```(47`0`8
M````I!<!`"4```"]%P$`#0```.,7`0`)````\1<!``,```#[%P$`!P```/\7
M`0`*````!Q@!``(````2&`$`#````!48`0`5````(A@!``L````X&`$`&0``
M`$08`0`@````7A@!`!(```!_&`$`!0```)(8`0`*````F!@!`!4```"C&`$`
M$@```+D8`0`,````S!@!``0```#9&`$`!P```-X8`0`)````YA@!``P```#P
M&`$`4@```/T8`0`7````4!D!`"0```!H&0$`$@```(T9`0`'````H!D!``8`
M``"H&0$`#@```*\9`0`B````OAD!`!T```#A&0$`#````/\9`0`-````#!H!
M`!4````:&@$`$@```#`:`0`/````0QH!`!0```!3&@$`&P```&@:`0`0````
MA!H!`&D```"5&@$`&@```/\:`0`7````&AL!`"<````R&P$`&@```%H;`0`7
M````=1L!`!L```"-&P$`&0```*D;`0`?````PQL!`!,```#C&P$`"````/<;
M`0`'`````!P!``@````('`$`"0```!$<`0`5````&QP!``T````Q'`$`(P``
M`#\<`0`3````8QP!``,```!W'`$`1@```'L<`0`_````PAP!`#<````"'0$`
M5P```#H=`0`%````DAT!`!\```"8'0$`+P```+@=`0`*````Z!T!``@```#S
M'0$`#0```/P=`0`M````"AX!``0````X'@$`3P```#T>`0`E````C1X!`!P`
M``"S'@$`"P```-`>`0`?````W!X!`!T```#\'@$`)0```!H?`0`@````0!\!
M`"0```!A'P$`(````(8?`0`+````IQ\!``<```"S'P$`#0```+L?`0`,````
MR1\!`!<```#6'P$`!@```.X?`0`Y````]1\!``P````O(`$`!P```#P@`0`9
M````1"`!``D```!>(`$`$P```&@@`0`)````?"`!``0```"&(`$`$````(L@
M`0`*````G"`!``@```"G(`$`"````+`@`0`$````N2`!``L```"^(`$`#```
M`,H@`0`2````UR`!`!$```#J(`$`#````/P@`0`:````"2$!``\````D(0$`
M!P```#0A`0`-````/"$!`!0```!*(0$`#@```%\A`0`,````;B$!`"P```![
M(0$`$P```*@A`0`<````O"$!`"@```#9(0$`!@````(B`0`'````"2(!`!,`
M```1(@$`!0```"4B`0`$````*R(!`!<````P(@$`"@```$@B`0`,````4R(!
M``D```!@(@$`!@```&HB`0`)````<2(!``@```![(@$`"0```(0B`0`*````
MCB(!`!$```"9(@$`!@```*LB`0`8````LB(!``X```#+(@$`#@```-HB`0`-
M````Z2(!``L```#W(@$`'0````,C`0`+````(2,!``(````M(P$`'````#`C
M`0`'````32,!``8```!5(P$`90```%PC`0`)````PB,!``<```#,(P$`)@``
M`-0C`0`X````^R,!`!H````T)`$`*@```$\D`0`[````>B0!`"@```"V)`$`
M-````-\D`0`9````%"4!`!4````N)0$`!0```$0E`0`'````2B4!``@```!2
M)0$`!P```%LE`0`%````8R4!``<```!I)0$`#@```'$E`0`)````@"4!``8`
M``"*)0$`"````)$E`0`+````FB4!``<```"F)0$`"````*XE`0`'````MR4!
M`!8```"_)0$`"0```-8E`0`&````X"4!``L```#G)0$`'````/,E`0`4````
M$"8!``<````E)@$`$0```"TF`0`(````/R8!``@```!()@$`!0```%$F`0`0
M````5R8!`!````!H)@$`!@```'DF`0`9````@"8!``H```":)@$`'````*4F
M`0`'````PB8!``4```#*)@$`$````-`F`0`4````X28!``L```#V)@$`#0``
M``(G`0`8````$"<!`!<````I)P$`!````$$G`0`)````1B<!``H```!0)P$`
M!P```%LG`0`"````8R<!``@```!F)P$`'P```&\G`0`^````CR<!`",```#.
M)P$`.````/(G`0`Q````*R@!`"<```!=*`$`9````(4H`0`4````ZB@!`%4`
M``#_*`$`.````%4I`0!*````CBD!`%L```#9*0$`*````#4J`0`X````7BH!
M`"@```"7*@$`+````,`J`0`G````[2H!`!L````5*P$`/@```#$K`0"I`0``
M<"L!`"@````:+0$`(P```$,M`0`7````9RT!`$@```!_+0$`A0```,@M`0`P
M````3BX!`$$```!_+@$`6P```,$N`0!)````'2\!`!T```!G+P$`&````(4O
M`0`A````GB\!`!\```#`+P$`*P```.`O`0`A````##`!`"<````N,`$`'0``
M`%8P`0`1````=#`!`#,```"&,`$`)0```+HP`0`G````X#`!`"`````(,0$`
M'P```"DQ`0`P````23$!`&D```!Z,0$`*P```.0Q`0`R````$#(!`#$```!#
M,@$`00```'4R`0`S````MS(!`"4```#K,@$`/0```!$S`0!E````3S,!`$T`
M``"U,P$`+P````,T`0`N````,S0!`#````!B-`$`5````),T`0"#````Z#0!
M`%H```!L-0$`2````,<U`0!*````$#8!`#(```!;-@$`+P```(XV`0`L````
MOC8!`"T```#K-@$`<0```!DW`0!O````BS<!`+,```#[-P$`%P```*\X`0`E
M````QS@!`#(```#M.`$`*0```"`Y`0`^````2CD!`"(```").0$`4@```*PY
M`0`E````_SD!``L````E.@$`L0```#$Z`0!%````XSH!`"$````I.P$`+@``
M`$L[`0`P````>CL!`"4```"K.P$`'````-$[`0`Q````[CL!``<````@/`$`
M!P```"@\`0`$````,#P!``T````U/`$`"P```$,\`0`.````3SP!``L```!>
M/`$`!0```&H\`0`0````<#P!``(```"!/`$`60```(0\`0`%````WCP!`!(`
M``#D/`$`!````/<\`0`'````_#P!``@````$/0$`!0````T]`0`#````$ST!
M`!`````7/0$`"@```"@]`0`,````,ST!`!,```!`/0$`#0```%0]`0`"````
M8CT!``<```!E/0$`!@```&T]`0`,````=#T!`!@```"!/0$`!@```)H]`0`2
M````H3T!``P```"T/0$``P```,$]`0`J````Q3T!``0```#P/0$`!@```/4]
M`0`'````_#T!`!\````$/@$`-0```"0^`0`N````6CX!`"\```")/@$`%P``
M`+D^`0`@````T3X!`!L```#R/@$`&`````X_`0`D````)S\!`!\```!,/P$`
M&@```&P_`0`@````AS\!`!H```"H/P$`,@```,,_`0`O````]C\!`!H````F
M0`$`*P```$%``0`?````;4`!`",```"-0`$`'P```+%``0`:````T4`!`"4`
M``#L0`$`)@```!)!`0`E````.4$!`"0```!?00$`&````(1!`0`=````G4$!
M`"0```"[00$`&````.!!`0`B````^4$!`!4````<0@$`)0```#)"`0`\````
M6$(!`!\```"50@$`(P```+5"`0`?````V4(!`"````#Y0@$`&@```!I#`0`8
M````-4,!`"8```!.0P$`'@```'5#`0`I````E$,!`!X```"^0P$`"0```-U#
M`0`,````YT,!`!<```#T0P$`+P````Q$`0`D````/$0!``<```!A1`$`%```
M`&E$`0`.````?D0!``T```"-1`$`!0```)M$`0`'````H40!`"(```"I1`$`
M)0```,Q$`0`3````\D0!`!H````&10$`'0```"%%`0`:````/T4!``<```!:
M10$`QP```&)%`0`+````*D8!`!4````V1@$`#````$Q&`0`&````648!``D`
M``!@1@$`"P```&I&`0`-````=D8!`!T```"$1@$`%P```*)&`0`&````ND8!
M`#,```#!1@$`$P```/5&`0`3````"4<!``<````=1P$`!@```"5'`0`/````
M+$<!``<````\1P$`,@```$1'`0`A````=T<!`!,```"91P$`#````*U'`0`1
M````ND<!`#(```#,1P$`#@```/]'`0`/````#D@!`!`````>2`$`"````"](
M`0`=````.$@!``D```!62`$`"@```&!(`0`%````:T@!`!0```!Q2`$`"@``
M`(9(`0`=````D4@!``@```"O2`$`'P```+A(`0`(````V$@!`!H```#A2`$`
M)P```/Q(`0`&````)$D!`!4````K20$`!P```$%)`0`(````24D!``D```!2
M20$`/P```%Q)`0`'````G$D!``\```"D20$`#@```+1)`0`0````PTD!``D`
M``#420$`"0```-Y)`0`(````Z$D!``<```#Q20$`&0```/E)`0`*````$TH!
M`!<````>2@$`%````#9*`0`*````2TH!``P```!62@$`%P```&-*`0`$````
M>TH!`"H```"`2@$`$0```*M*`0`'````O4H!``D```#%2@$``@```,]*`0`0
M````TDH!`!@```#C2@$`"P```/Q*`0`#````"$L!``@````,2P$`!@```!5+
M`0`'````'$L!``T````D2P$`"P```#)+`0`.````/DL!`"\```!-2P$`(```
M`'U+`0`<````GDL!``P```"[2P$`,0```,A+`0`%````^DL!`!(`````3`$`
M/P```!-,`0`2````4TP!``H```!F3`$`!@```'%,`0`$````>$P!``0```!]
M3`$`"@```(),`0`3````C4P!``4```"A3`$`!@```*=,`0`&````KDP!``D`
M``"U3`$`!````+],`0`,````Q$P!``H```#13`$`(````-Q,`0`%````_4P!
M`!@````#30$`&0```!Q-`0`?````-DT!`!T```!630$`$0```'1-`0`"````
MADT!``0```")30$`"@```(Y-`0`&````F4T!``4```"@30$``P```*9-`0`,
M````JDT!`$4```"W30$`&@```/U-`0`U````&$X!`"4```!.3@$`*````'1.
M`0!3````G4X!`!D```#Q3@$`<@````M/`0`@````?D\!`#4```"?3P$`(0``
M`-5/`0!%````]T\!`#`````]4`$`(P```&Y0`0`?````DE`!`"@```"R4`$`
M*0```-M0`0`F````!5$!`"4````L40$`*````%)1`0`H````>U$!`"(```"D
M40$`(0```,=1`0`P````Z5$!`!(````:4@$`$P```"U2`0`0````05(!`'D`
M``!24@$`"0```,Q2`0!R````UE(!`',```!)4P$`?````+U3`0`K````.E0!
M`%0```!F5`$`%P```+M4`0`6````TU0!``\```#J5`$`90```/I4`0`?````
M8%4!`%$```"`50$`-P```-)5`0`V````"E8!`#8```!!5@$`/@```'A6`0!!
M````MU8!`$,```#Y5@$`?````#U7`0!`````NE<!`#X```#[5P$`0````#I8
M`0!"````>U@!`#D```"^6`$`'P```/A8`0!`````&%D!`!\```!960$`'```
M`'E9`0!1````EED!`!L```#H60$`%`````1:`0`*````&5H!``4````D6@$`
M!@```"I:`0`(````,5H!``4````Z6@$`$@```$!:`0`0````4UH!`!,```!D
M6@$`'0```'A:`0`/````EEH!``\```"F6@$`!````+9:`0`)````NUH!``L`
M``#%6@$`!P```-%:`0`%````V5H!`!0```#?6@$`!P```/1:`0`(````_%H!
M``\````%6P$`"````!5;`0`,````'EL!``\````K6P$`!@```#M;`0`4````
M0EL!``8```!76P$`#````%Y;`0`5````:UL!``@```"!6P$`!````(I;`0`*
M````CUL!``0```":6P$`!@```)];`0`'````IEL!``0```"N6P$`!P```+-;
M`0`9````NUL!``(```#56P$``@```-A;`0`)````VUL!``8```#E6P$`%0``
M`.Q;`0`&`````EP!`"<````)7`$``@```#%<`0`$````-%P!``L````Y7`$`
M"0```$5<`0`/````3UP!`!,```!?7`$`!P```'-<`0`'````>UP!``8```"#
M7`$`!@```(I<`0`0````D5P!`!(```"B7`$``@```+5<`0`&````N%P!``D`
M``"_7`$`,P```,E<`0`B````_5P!``<````@70$`!P```"A=`0`'````,%T!
M``L````X70$`!0```$1=`0`"````2ET!``L```!-70$`CP$``%E=`0!9````
MZ5X!`+\```!#7P$`90````-@`0"S````:6`!`(@````=80$`/````*9A`0!!
M````XV$!`#8````E8@$`-0```%QB`0`Q````DF(!`#$```#$8@$`1P```/9B
M`0!'````/F,!`$4```"&8P$`1@```,QC`0!%````$V0!`%(```!99`$`/0``
M`*QD`0!(````ZF0!`$<````S90$`,P```'ME`0!&````KV4!`$$```#V90$`
M30```#AF`0`M````AF8!`#4```"T9@$`:P```.IF`0`R````5F<!`#````")
M9P$`F0```+IG`0!'````5&@!`/0```"<:`$`1````)%I`0`O````UFD!`'\`
M```&:@$`3@```(9J`0`0````U6H!`!<```#F:@$`"P```/YJ`0`&````"FL!
M``D````1:P$`"````!MK`0`*````)&L!``H````O:P$`%0```#IK`0`M````
M4&L!`!,```!^:P$`#0```))K`0`0````H&L!``L```"Q:P$`!0```+UK`0`M
M````PVL!``T```#Q:P$`'0```/]K`0`5````'6P!``\````S;`$`$0```$-L
M`0`D````56P!`!8```!Z;`$`#@```)%L`0`(````H&P!`!$```"I;`$`/0``
M`+ML`0`-````^6P!`!8````';0$`%P```!YM`0`7````-FT!`!H```!.;0$`
M!@```&EM`0`E````<&T!`!D```"6;0$`+````+!M`0`E````W6T!`"0````#
M;@$`(P```"AN`0`?````3&X!`!(```!L;@$`'0```']N`0`0````G6X!`!L`
M``"N;@$`$@```,IN`0`2````W6X!``@```#P;@$`!0```/EN`0!3````_VX!
M`#````!3;P$`&0```(1O`0`V````GF\!`#T```#5;P$`4````!-P`0!/````
M9'`!`%@```"T<`$`5@````UQ`0`X````9'$!``X```"=<0$`$P```*QQ`0`7
M````P'$!`!$```#8<0$`%0```.IQ`0`=`````'(!``@````><@$`!@```"=R
M`0`/````+G(!``0````^<@$`$````$-R`0`/````5'(!`!,```!D<@$`,@``
M`'AR`0`P````JW(!``X```#<<@$`$0```.MR`0`)````_7(!``8````'<P$`
M&0````YS`0`7````*',!``<```!`<P$`#@```$AS`0`1````5W,!`!X```!I
M<P$`'````(AS`0`3````I7,!``T```"Y<P$`#0```,=S`0`*````U7,!`"8`
M``#@<P$`$P````=T`0`8````&W0!`!(````T=`$`5````$=T`0`W````G'0!
M`"4```#4=`$`)````/IT`0`&````'W4!``<````F=0$`-@```"YU`0`-````
M974!``<```!S=0$`"@```'MU`0`(````AG4!``@```"/=0$`!0```)AU`0`(
M````GG4!``L```"G=0$`!@```+-U`0`C````NG4!``X```#>=0$`#````.UU
M`0`3````^G4!`!8````.=@$`*P```"5V`0`+````478!`"0```!==@$`%P``
M`()V`0`D````FG8!`!T```"_=@$`%````-UV`0`2````\G8!``X````%=P$`
M'````!1W`0`6````,7<!``<```!(=P$`!@```%!W`0`(````5W<!``X```!@
M=P$`!P```&]W`0`*````=W<!`!$```""=P$`"0```)1W`0`0````GG<!`!@`
M``"O=P$`*@```,AW`0`(````\W<!`!$```#\=P$`!0````YX`0`/````%'@!
M``P````D>`$`,0```#%X`0`O````8W@!``D```"3>`$`"````)UX`0`&````
MIG@!``4```"M>`$`$````+-X`0`,````Q'@!`!4```#1>`$`-````.=X`0`H
M````''D!`"<```!%>0$`)````&UY`0`Q````DGD!``@```#$>0$`!@```,UY
M`0`)````U'D!``<```#>>0$`-P```.9Y`0`O````'GH!`#8```!.>@$`7@``
M`(5Z`0`U````Y'H!`#4````:>P$`-0```%![`0!"````AGL!`#$```#)>P$`
M-````/M[`0`U````,'P!`#L```!F?`$`%@```*)\`0`:````N7P!`"8```#4
M?`$`+````/M\`0`1````*'T!``L````Z?0$`#````$9]`0`F````4WT!``<`
M``!Z?0$`#0```()]`0`7````D'T!`"0```"H?0$`!@```,U]`0`'````U'T!
M``D```#<?0$`"````.9]`0`H````[WT!``\````8?@$`"@```"A^`0`(````
M,WX!``8````\?@$`!0```$-^`0`'````27X!``4```!1?@$`"@```%=^`0`G
M````8GX!`!````"*?@$`"0```)M^`0`%````I7X!``<```"K?@$`!P```+-^
M`0`%````NWX!``T```#!?@$`!@```,]^`0`3````UGX!``,```#J?@$`"```
M`.Y^`0`&````]WX!``T```#^?@$`"`````Q_`0`@````%7\!`!$````V?P$`
M)@```$A_`0`=````;W\!``D```"-?P$`$@```)=_`0`,````JG\!``<```"W
M?P$``P```+]_`0`#````PW\!`!0```#'?P$`%````-Q_`0`S````\7\!``@`
M```E@`$`"0```"Z``0`(````.(`!``<```!!@`$`2P```$F``0`H````E8`!
M``8```"^@`$`!@```,6``0`8````S(`!`"$```#E@`$`)`````>!`0`N````
M+($!`"4```!;@0$`+0```(&!`0!@````KX$!`"X````0@@$`$@```#^"`0`'
M````4H(!`!,```!:@@$`$0```&Z"`0`/````@((!`!````"0@@$`$````*&"
M`0`0````LH(!`!````##@@$`#P```-2"`0`)````Y((!`!<```#N@@$`(0``
M``:#`0`4````*(,!`!@````]@P$``P```%:#`0`&````6H,!``P```!A@P$`
M$````&Z#`0!5````?X,!`!$```#5@P$`$P```.>#`0`$````^X,!`!8`````
MA`$`/````!>$`0`%````5(0!``0```!:A`$`#P```%^$`0`<````;X0!`"0`
M``",A`$`,````+&$`0`/````XH0!`",```#RA`$`(P```!:%`0`;````.H4!
M``4```!6A0$`&@```%R%`0`9````=X4!`!4```"1A0$`&P```*>%`0`,````
MPX4!`!D```#0A0$`$P```.J%`0`-````_H4!``8````,A@$`#````!.&`0`'
M````((8!`!<````HA@$`$@```$"&`0`.````4X8!``@```!BA@$`!0```&N&
M`0`+````<88!``L```!]A@$`!P```(F&`0`/````D88!``8```"AA@$`!@``
M`*B&`0`5````KX8!`!(```#%A@$`"````-B&`0`(````X88!``P```#JA@$`
M"@```/>&`0`&`````H<!``H````)AP$`$0```!2'`0`(````)H<!``D````O
MAP$`%P```#F'`0`;````48<!``\```!MAP$`#@```'V'`0`4````C(<!``4`
M``"AAP$`'````*>'`0`1````Q(<!`!(```#6AP$`+@```.F'`0`]````&(@!
M`"````!6B`$`,````'>(`0`*````J(@!``H```"SB`$`#P```+Z(`0`&````
MSH@!``D```#5B`$`#P```-^(`0`4````[X@!``D````$B0$`$@````Z)`0`L
M````(8D!`"H```!.B0$`+P```'F)`0`M````J8D!`"$```#7B0$`)@```/F)
M`0`F````((H!`"D```!'B@$`)0```'&*`0`U````EXH!`"````#-B@$`*P``
M`.Z*`0`R````&HL!`",```!-BP$`)@```'&+`0`A````F(L!`"H```"ZBP$`
M.@```.6+`0`N````((P!`"0```!/C`$`,````'2,`0`Y````I8P!`"4```#?
MC`$`&0````6-`0`T````'XT!`!D```!4C0$`)0```&Z-`0`O````E(T!`",`
M``#$C0$`+````.B-`0`:````%8X!`+$````PC@$`$@```.*.`0`@````]8X!
M`"D````6CP$`*0```$"/`0`Q````:H\!`"(```"<CP$`(0```+^/`0`E````
MX8\!`"D````'D`$`+````#&0`0`]````7I`!`#,```"<D`$`EP```-"0`0`E
M````:)$!`!L```".D0$`)@```*J1`0`O````T9$!`"\````!D@$`4@```#&2
M`0!$````A)(!``T```#)D@$`!P```->2`0`%````WY(!``@```#ED@$`#@``
M`.Z2`0`-````_9(!`!4````+DP$`#````"&3`0`5````+I,!``H```!$DP$`
M!````$^3`0`/````5),!``P```!DDP$`#P```'&3`0`0````@9,!`!0```"2
MDP$`#0```*>3`0!"````M9,!``H```#XDP$`$`````.4`0`&````%)0!``\`
M```;E`$``@```"N4`0`%````+I0!`",````TE`$`!0```%B4`0`.````7I0!
M``P```!ME`$``P```'J4`0`1````?I0!``@```"0E`$`$````)F4`0`1````
MJI0!`!4```"\E`$`$P```-*4`0`;````YI0!`!`````"E0$`$````!.5`0`)
M````))4!``<````NE0$`#P```#:5`0`-````1I4!`!H```!4E0$`#0```&^5
M`0`.````?94!`"<```",E0$`%@```+25`0`R````RY4!``X```#^E0$`&```
M``V6`0`7````)I8!`!<````^E@$`.````%:6`0`Q````CY8!``T```#!E@$`
M!@```,^6`0`/````UI8!``4```#FE@$`*P```.R6`0`L````&)<!``4```!%
MEP$`"0```$N7`0`>````59<!``L```!TEP$`$@```("7`0`2````DY<!``<`
M``"FEP$`)@```*Z7`0`5````U9<!`!@```#KEP$`$0````28`0`5````%I@!
M``D````LF`$`"0```#:8`0`C````0)@!`#T```!DF`$`"````**8`0`6````
MJY@!``@```#"F`$`"P```,N8`0`R````UY@!`!`````*F0$`!0```!N9`0`&
M````(9D!``,````HF0$`!P```"R9`0`'````-)D!``P````\F0$`#P```$F9
M`0`-````69D!``T```!GF0$`%````'69`0`7````BID!`!0```"BF0$`%@``
M`+>9`0`+````SID!``4```#:F0$`"````."9`0`*````Z9D!``(```#TF0$`
M!0```/>9`0`0````_9D!`",````.F@$`$P```#*:`0`)````1IH!``\```!0
MF@$`$0```&":`0`:````<IH!`"T```"-F@$`*P```+N:`0`+````YYH!``X`
M``#SF@$`=@````*;`0`3````>9L!`$H```"-FP$`$````-B;`0`'````Z9L!
M``4```#QFP$`-@```/>;`0`:````+IP!`!H```!)G`$`!P```&2<`0`(````
M;)P!``<```!UG`$`!P```'V<`0`&````A9P!`!````",G`$`#@```)V<`0`1
M````K)P!``\```"^G`$`%0```,Z<`0`/````Y)P!``P```#TG`$`"@````&=
M`0`'````#)T!``H````4G0$`"````!^=`0`4````*)T!``X````]G0$`-P``
M`$R=`0`/````A)T!``@```"4G0$`$0```)V=`0`+````KYT!`!H```"[G0$`
M(````-:=`0`J````]YT!`"D````BG@$`'P```$R>`0`@````;)X!`"H```"-
MG@$`'P```+B>`0`A````V)X!`!\```#ZG@$`!0```!J?`0`=````()\!``\`
M```^GP$`#@```$Z?`0`#````79\!``<```!AGP$`#0```&F?`0`/````=Y\!
M``L```"'GP$`%0```).?`0`+````J9\!``4```"UGP$`%P```+N?`0`9````
MTY\!``\```#MGP$`"P```/V?`0`,````":`!``\````6H`$`)@```":@`0`&
M````3:`!``8```!4H`$`#0```%N@`0`*````::`!``L```!TH`$`!@```("@
M`0`.````AZ`!``0```"6H`$`%P```)N@`0`+````LZ`!``<```"_H`$`*@``
M`,>@`0`/````\J`!`(,````"H0$`$@```(:A`0`)````F:$!``<```"CH0$`
M"P```*NA`0`'````MZ$!``D```"_H0$`!````,FA`0`-````SJ$!`!4```#<
MH0$`$0```/*A`0`#````!*(!``4````(H@$`"@````ZB`0`3````&:(!`!(`
M```MH@$`%````$"B`0`:````5:(!``(```!PH@$`"0```'.B`0`+````?:(!
M``0```")H@$`"@```(ZB`0`(````F:(!``4```"BH@$`)@```*BB`0`(````
MSZ(!``8```#8H@$`)P```-^B`0`.````!Z,!`"`````6HP$`!P```#>C`0`'
M````/Z,!``X```!'HP$`!0```%:C`0`)````7*,!``L```!FHP$`!P```'*C
M`0`&````>J,!`!````"!HP$`#0```)*C`0`&````H*,!``<```"GHP$`!P``
M`*^C`0`4````MZ,!`!T```#,HP$`#P```.JC`0`'````^J,!``H````"I`$`
M!`````VD`0`)````$J0!``@````<I`$`'0```"6D`0`=````0Z0!``D```!A
MI`$`!@```&ND`0`-````<J0!``8```"`I`$`!````(>D`0`R````C*0!`#0`
M``"_I`$`-````/2D`0`C````*:4!``4```!-I0$`'0```%.E`0`$````<:4!
M``@```!VI0$`)````'^E`0`%````I*4!``@```"JI0$`'P```+.E`0`(````
MTZ4!`)H```#<I0$`"````'>F`0`6````@*8!``8```"7I@$`*````)ZF`0`&
M````QZ8!``<```#.I@$`!0```-:F`0`-````W*8!``T```#JI@$`"````/BF
M`0`)`````:<!``4````+IP$`&0```!&G`0`[````*Z<!`#@```!GIP$`/```
M`*"G`0`G````W:<!`"P````%J`$`.````#*H`0!`````:Z@!`#````"LJ`$`
M.@```-VH`0`U````&*D!`#X```!.J0$`*0```(VI`0`2````MZD!`!8```#*
MJ0$`#0```.&I`0`J````[ZD!`!P````:J@$`'0```#>J`0`<````5:H!``<`
M``!RJ@$`"0```'JJ`0`)````A*H!``@```".J@$`*````)>J`0`G````P*H!
M`"4```#HJ@$`"0````ZK`0`:````&*L!`"\````SJP$`)@```&.K`0`1````
MBJL!``8```"<JP$`"0```*.K`0`,````K:L!``P```"ZJP$`#P```,>K`0`V
M````UZL!`((````.K`$`=@```)&L`0`/````"*T!``L````8K0$`#````"2M
M`0`1````,:T!`!(```!#K0$`$````%:M`0`'````9ZT!``\```!OK0$`%```
M`'^M`0`2````E*T!``\```"GK0$`#P```+>M`0`?````QZT!`"H```#GK0$`
MA@```!*N`0`1````F:X!``4```"KK@$`%P```+&N`0`)````R:X!``0```#3
MK@$`"@```-BN`0`<````XZX!`!$`````KP$`#@```!*O`0`.````(:\!``P`
M```PKP$`$P```#VO`0`>````4:\!`"````!PKP$`'@```)&O`0`@````L*\!
M`!\```#1KP$`(0```/&O`0`;````$[`!`#@````OL`$`#P```&BP`0`1````
M>+`!`!````"*L`$`$@```)NP`0`-````KK`!`!(```"\L`$`%````,^P`0`0
M````Y+`!`!(```#UL`$`,@````BQ`0`6````.[$!`!0```!2L0$`/0```&>Q
M`0`4````I;$!``H```"ZL0$`$P```,6Q`0!!````V;$!`!,````;L@$`$@``
M`"^R`0`=````0K(!`!@```!@L@$`%@```'FR`0`6````D+(!`!X```"GL@$`
M&@```,:R`0`H````X;(!`",````*LP$`&@```"ZS`0`5````2;,!`!8```!?
MLP$`$0```':S`0`7````B+,!`!D```"@LP$`&0```+JS`0`7````U+,!``@`
M``#LLP$`!````/6S`0`$````^K,!``4```#_LP$`"P````6T`0`/````$;0!
M``8````AM`$`"0```"BT`0`'````,K0!``D````ZM`$`!P```$2T`0`&````
M3+0!``@```!3M`$`!@```%RT`0`&````8[0!``,```!JM`$``P```&ZT`0`(
M````<K0!`!(```![M`$`$0```(ZT`0`.````H+0!``\```"OM`$`"@```+^T
M`0`2````RK0!``0```#=M`$`*````.*T`0`2````"[4!`!`````>M0$`&```
M`"^U`0`+````2+4!``D```!4M0$`#@```%ZU`0`M````;;4!``0```";M0$`
M"````*"U`0`B````J;4!`!(```#,M0$`!@```-^U`0`)````YK4!``<```#P
MM0$`!0```/BU`0`$````_K4!`!$````#M@$`#@```!6V`0`6````)+8!`!@`
M```[M@$`'0```%2V`0`;````<K8!``@```".M@$`!0```)>V`0`&````G;8!
M`"$```"DM@$`!P```,:V`0`%````SK8!``X```#4M@$`#0```..V`0`'````
M\;8!``<```#YM@$`!0````&W`0`/````![<!``\````7MP$`"@```">W`0`/
M````,K<!`!$```!"MP$`%@```%2W`0`4````:[<!``X```"`MP$`%@```(^W
M`0`(````IK<!``4```"OMP$`$0```+6W`0`V````Q[<!``4```#^MP$`#```
M``2X`0`C````$;@!`!8````UN`$`%````$RX`0`7````8;@!``P```!YN`$`
M"0```(:X`0`'````D+@!``H```"8N`$`"0```*.X`0`.````K;@!`!````"\
MN`$`+@```,VX`0`*````_+@!``4````'N0$`&0````VY`0`.````)[D!``T`
M```VN0$`$0```$2Y`0`(````5KD!``L```!?N0$`"````&NY`0`4````=+D!
M`%$```")N0$`%````-NY`0`)````\+D!``4```#ZN0$`!0````"Z`0`3````
M!KH!`!4````:N@$`$P```#"Z`0`+````1+H!``(```!0N@$`"@```%.Z`0`J
M````7KH!``,```")N@$`!0```(VZ`0`*````D[H!``H```">N@$`!0```*FZ
M`0`%````K[H!`!X```"UN@$`$@```-2Z`0!(````Y[H!`!4````PNP$`!@``
M`$:[`0`(````3;L!``@```!6NP$`!````%^[`0`%````9+L!`&$```!JNP$`
M"@```,R[`0`-````U[L!``4```#ENP$`!0```.N[`0`G````\;L!`#0````9
MO`$`$P```$Z\`0`(````8KP!``P```!KO`$`"@```'B\`0`)````@[P!`!H`
M``"-O`$`+````*B\`0`J````U;P!`"D`````O0$`#P```"J]`0`#````.KT!
M``<````^O0$`"````$:]`0`(````3[T!`!````!8O0$`#````&F]`0`V````
M=KT!`!P```"MO0$`,@```,J]`0`B````_;T!``8````@O@$`20```">^`0`9
M````<;X!``H```"+O@$`#0```):^`0`<````I+X!`$T```#!O@$`(`````^_
M`0`&````,+\!`!T````WOP$`"````%6_`0`&````7K\!`!T```!EOP$`!0``
M`(._`0`(````B;\!`"H```"2OP$`*0```+V_`0`H````Y[\!`!$````0P`$`
M!0```"+``0`>````*,`!`%T```!'P`$`$````*7``0`A````ML`!`!$```#8
MP`$``P```.K``0`,````[L`!``8```#[P`$`%0````+!`0`+````&,$!``4`
M```DP0$`!P```"K!`0`)````,L$!``8````\P0$`"0```$/!`0`,````3<$!
M``<```!:P0$`"@```&+!`0`,````;<$!``8```!ZP0$`#@```('!`0`0````
MD,$!`!````"AP0$`#0```++!`0`.````P,$!``\```#/P0$`#0```-_!`0`-
M````[<$!``T```#[P0$`"`````G"`0`>````$L(!`!$````QP@$`"@```$/"
M`0`*````3L(!`!0```!9P@$`!P```&["`0`0````=L(!``0```"'P@$`!P``
M`(S"`0`%````E,(!``4```":P@$`"0```*#"`0`0````JL(!`!4```"[P@$`
M+0```-'"`0`<````_\(!`#$````<PP$`*@```$[#`0`9````><,!`!T```"3
MPP$`&````+'#`0`$````RL,!``4```#/PP$`#@```-7#`0`.````Y,,!``,`
M``#SPP$`(P```/?#`0`+````&\0!``L````GQ`$`$@```#/$`0`$````1L0!
M`!````!+Q`$`!0```%S$`0`2````8L0!`!$```!UQ`$`!@```(?$`0`)````
MCL0!``4```"8Q`$`!P```)[$`0`#````IL0!``0```"JQ`$``P```*_$`0!2
M````L\0!`$`````&Q0$`'0```$?%`0`N````9<4!`#4```"4Q0$`#0```,K%
M`0`W````V,4!`#8````0Q@$`(@```$?&`0`B````:L8!`"<```"-Q@$`)P``
M`+7&`0`L````W<8!``X````*QP$`)````!G'`0`Y````/L<!`!0```!XQP$`
M'````(W'`0`A````JL<!`!H```#,QP$`%P```.?'`0`<````_\<!`"$````<
MR`$`&P```#[(`0`7````6L@!`"P```!RR`$`+````)_(`0`P````S,@!`"P`
M``#]R`$`+0```"K)`0`N````6,D!`"L```"'R0$`7@```+/)`0`@````$LH!
M``@````SR@$`"0```#S*`0`;````1LH!`$````!BR@$`,0```*/*`0`?````
MU<H!``X```#UR@$`50````3+`0!,````6LL!``8```"GRP$`(@```*[+`0`.
M````T<L!`!````#@RP$`&0```/'+`0`&````"\P!``H````2S`$`#````!W,
M`0`.````*LP!`!8````YS`$`"P```%#,`0`3````7,P!``@```!PS`$`(@``
M`'G,`0`(````G,P!``@```"ES`$`!0```*[,`0`,````M,P!``T```#!S`$`
M#0```,_,`0`^````W<P!``(````<S0$`!@```!_-`0`-````)LT!`!0````T
MS0$`"0```$G-`0`'````4\T!`!$```!;S0$`"@```&W-`0`,````>,T!``0`
M``"%S0$`+@```(K-`0`4````N<T!`"@```#.S0$`:@```/?-`0`4````8LX!
M`$0```!WS@$`'P```+S.`0`/````W,X!``H```#LS@$`#0```/?.`0`+````
M!<\!``\````1SP$`"P```"'/`0`4````+<\!``T```!"SP$`&0```%#/`0`5
M````:L\!``,```"`SP$`$0```(3/`0`/````EL\!`",```"FSP$`%````,K/
M`0`=````W\\!`!````#]SP$`)P````[0`0`'````-M`!``D````^T`$`%```
M`$C0`0`2````7=`!``X```!PT`$`&@```'_0`0`1````FM`!``\```"LT`$`
M"@```+S0`0`)````Q]`!``@```#1T`$`$````-K0`0`2````Z]`!``8```#^
MT`$`$0````71`0`(````%]$!`!$````@T0$`+````#+1`0`%````7]$!`!0`
M``!ET0$`#P```'K1`0`[````BM$!`"T```#&T0$`)@```/31`0`M````&](!
M`"X```!)T@$`+@```'C2`0`2````I](!``8```"ZT@$`!P```,'2`0`8````
MR=(!``8```#BT@$`$@```.G2`0`%````_-(!`!D````"TP$`!0```!S3`0`'
M````(M,!`!<````JTP$`)P```$+3`0`%````:M,!`!L```!PTP$`$@```(S3
M`0`)````G],!`!$```"ITP$`!````+O3`0`/````P-,!``@```#0TP$`!P``
M`-G3`0`*````X=,!``@```#LTP$`!0```/73`0`@````^],!`#,````<U`$`
M/````%#4`0`<````C=0!`"<```"JU`$`(````-+4`0`^````\]0!`!H````R
MU0$`&0```$W5`0`@````9]4!`!T```"(U0$`+P```*;5`0!6````UM4!`#X`
M```MU@$`)P```&S6`0`B````E-8!``8```"WU@$`"````+[6`0`&````Q]8!
M``L```#.U@$`&0```-K6`0`9````]-8!`"P````.UP$`'P```#O7`0`V````
M6]<!`#P```"2UP$`!````,_7`0`5````U-<!``8```#JUP$`!@```/'7`0`D
M````^-<!`!D````=V`$`$0```#?8`0`-````2=@!``<```!7V`$`#@```%_8
M`0`(````;M@!`!8```!WV`$`#````([8`0`:````F]@!`!L```"VV`$`.```
M`-+8`0`)````"]D!``4````5V0$`!0```!O9`0`;````(=D!`!(````]V0$`
M!````%#9`0`)````5=D!``L```!?V0$`$````&O9`0`+````?-D!`!<```"(
MV0$`#P```*#9`0`%````L-D!``4```"VV0$`#````+S9`0`U````R=D!`%D`
M``#_V0$`'@```%G:`0`B````>-H!`!L```";V@$`#P```+?:`0`2````Q]H!
M``@```#:V@$`$0```./:`0`M````]=H!``D````CVP$`#@```"W;`0`0````
M/-L!`!8```!-VP$`#0```&3;`0`Z````<ML!``D```"MVP$`'P```+?;`0`5
M````U]L!`!D```#MVP$`.P````?<`0`A````0]P!`#X```!EW`$`/P```*3<
M`0`[````Y-P!`$H````@W0$`2P```&O=`0!$````M]T!``\```#\W0$`$```
M``S>`0`-````'=X!`!(````KW@$`"````#[>`0`9````1]X!``D```!AW@$`
M%````&O>`0`'````@-X!`!,```"(W@$`*````)S>`0`'````Q=X!``8```#-
MW@$`#P```-3>`0`.````Y-X!`!4```#SW@$`!`````G?`0`(````#M\!``P`
M```7WP$`#````"3?`0`-````,=\!`!$````_WP$`$0```%'?`0`'````8]\!
M``4```!KWP$`-````''?`0`D````IM\!`"0```#+WP$`!P```/#?`0`/````
M^-\!``8````(X`$`'`````_@`0`A````+.`!`"0```!.X`$`#@```'/@`0`)
M````@N`!``,```",X`$`!@```)#@`0`*````E^`!``(```"BX`$`#````*7@
M`0`3````LN`!``L```#&X`$`%0```-+@`0`9````Z.`!`!8````"X0$`!0``
M`!GA`0`*````'^$!`!,````JX0$`%@```#[A`0`.````5>$!``8```!DX0$`
M"0```&OA`0`+````=>$!`!$```"!X0$`50```)/A`0`=````Z>$!`"X````'
MX@$`#P```#;B`0`$````1N(!``8```!+X@$`"P```%+B`0`?````7N(!`!X`
M``!^X@$`#@```)WB`0`-````K.(!`!L```"ZX@$`&````-;B`0`.````[^(!
M`!\```#^X@$`(````![C`0`.````/^,!`&H```!.XP$`)````+GC`0`6````
MWN,!`"8```#UXP$`(@```!SD`0`4````/^0!`!D```!4Y`$`&0```&[D`0`.
M````B.0!`!@```"7Y`$`"@```+#D`0`'````N^0!``@```##Y`$`"0```,SD
M`0`4````UN0!``T```#KY`$`*0```/GD`0`=````(^4!``X```!!Y0$`.P``
M`%#E`0!.````C.4!`"\```#;Y0$`>`````OF`0`*````A.8!`"@```"/Y@$`
M-P```+CF`0`(````\.8!``@```#YY@$`#`````+G`0`V````#^<!``@```!&
MYP$`20```$_G`0`Y````F><!`"@```#3YP$`(````/SG`0`G````'>@!`"$`
M``!%Z`$`+````&?H`0`F````E.@!`"T```"[Z`$`)@```.GH`0`0````$.D!
M``@````AZ0$`#0```"KI`0`/````..D!`!0```!(Z0$`!P```%WI`0`T````
M9>D!``P```":Z0$`$````*?I`0`I````N.D!``8```#BZ0$`$@```.GI`0`(
M````_.D!``<````%Z@$`$`````WJ`0`-````'NH!``D````LZ@$`"0```#;J
M`0`$````0.H!`!````!%Z@$`$````%;J`0`5````9^H!`!<```!]Z@$`#0``
M`)7J`0`B````H^H!`!(```#&Z@$`"````-GJ`0`.````XNH!`!4```#QZ@$`
M#P````?K`0`,````%^L!`"8````DZP$`#@```$OK`0`?````6NL!`"4```!Z
MZP$`"0```*#K`0`&````JNL!`!(```"QZP$`"@```,3K`0`$````S^L!`!L`
M``#4ZP$`#@```/#K`0`/````_^L!``\````/[`$`!@```!_L`0`)````)NP!
M``H````P[`$`"0```#OL`0`.````1>P!`!0```!4[`$`!````&GL`0`:````
M;NP!``\```")[`$`"````)GL`0`+````HNP!``\```"N[`$`&0```+[L`0`*
M````V.P!``(```#C[`$`(````.;L`0`'````!^T!``<````/[0$`<@```!?M
M`0`+````BNT!``8```"6[0$`)0```)WM`0`^````P^T!`!P````"[@$`)P``
M`!_N`0!1````1^X!`"$```"9[@$`)````+ON`0`?````X.X!`!8`````[P$`
M!0```!?O`0`%````'>\!``P````C[P$`"P```##O`0`'````/.\!``P```!$
M[P$`$@```%'O`0`.````9.\!``L```!S[P$`#0```'_O`0`+````C>\!``<`
M``"9[P$`!P```*'O`0`*````J>\!`!0```"T[P$`"0```,GO`0`'````T^\!
M``L```#;[P$`*````.?O`0`%````$/`!``4````6\`$`#@```!SP`0`%````
M*_`!``D````Q\`$`!P```#OP`0`2````0_`!`!(```!6\`$`!@```&GP`0`6
M````</`!``L```"'\`$`"````)/P`0`%````G/`!``4```"B\`$`#P```*CP
M`0`<````N/`!``<```#5\`$`"0```-WP`0`<````Y_`!``T````$\0$`!```
M`!+Q`0`(````%_$!`!`````@\0$`"0```#'Q`0`"````._$!``<````^\0$`
M(P```$;Q`0`Q````:O$!`!\```"<\0$`)P```+SQ`0`J````Y/$!`"D````/
M\@$`60```#GR`0`1````D_(!`%\```"E\@$`+@````7S`0!)````-/,!`&P`
M``!^\P$`'@```.OS`0`P````"O0!`"@````[]`$`,0```&3T`0`K````EO0!
M`!\```#"]`$`.@```.+T`0#+`0``'?4!`"H```#I]@$`'````!3W`0`/````
M,?<!`#\```!!]P$`?````('W`0!#````_O<!`#(```!"^`$`7@```'7X`0!(
M````U/@!`!<````=^0$`$````#7Y`0`9````1OD!`!@```!@^0$`)P```'GY
M`0`@````H?D!`!X```#"^0$`&0```.'Y`0`0````^_D!`#0````,^@$`(P``
M`$'Z`0`A````9?H!`"$```"'^@$`(@```*GZ`0`Y````S/H!`%0````&^P$`
M)P```%O[`0`P````@_L!`"\```"T^P$`1P```.3[`0`P````+/P!`"<```!=
M_`$`.@```(7\`0!>````P/P!`$4````?_0$`,````&7]`0`L````EOT!`"L`
M``##_0$`5@```._]`0"#````1OX!`$\```#*_@$`2@```!K_`0!)````9?\!
M`#,```"O_P$`+````./_`0`L````$``"`"T````]``(`90```&L``@!C````
MT0`"`)T````U`0(`%0```-,!`@`C````Z0$"`"\````-`@(`+P```#T"`@!!
M````;0("`"````"O`@(`5````-`"`@`A````)0,"``L```!'`P(`M0```%,#
M`@!(````"00"`!\```!2!`(`,0```'($`@`V````I`0"`"(```#;!`(`'@``
M`/X$`@`L````'04"``<```!*!0(`!P```%(%`@`#````6@4"``T```!>!0(`
M"P```&P%`@`*````>`4"``L```"#!0(`!P```(\%`@`9````EP4"``,```"Q
M!0(`6P```+4%`@`$````$08"`"<````6!@(`!````#X&`@`'````0P8"``8`
M``!+!@(`!0```%(&`@`$````6`8"`!,```!=!@(`"0```'$&`@`(````>P8"
M`!$```"$!@(`%0```)8&`@`"````K`8"``<```"O!@(`!P```+<&`@`,````
MOP8"``X```#,!@(`!@```-L&`@`4````X@8"``P```#W!@(``P````0'`@`G
M````"`<"``0````P!P(`!@```#4'`@`(````/`<"`#````!%!P(`1P```'8'
M`@`N````O@<"`"\```#M!P(`&P```!T(`@`D````.0@"`"$```!>"`(`(P``
M`(`(`@`H````I`@"`",```#-"`(`(0```/$(`@`I````$PD"`"(````]"0(`
M,P```&`)`@`P````E`D"`!D```#%"0(`+0```-\)`@`B````#0H"`"8````P
M"@(`)0```%<*`@`@````?0H"`"D```">"@(`)0```,@*`@`O````[@H"`!P`
M```>"P(`(0```#L+`@`E````70L"`"D```"#"P(`(````*T+`@`J````S@L"
M`!X```#Y"P(`)````!@,`@!`````/0P"`"4```!^#`(`*0```*0,`@`H````
MS@P"`"D```#W#`(`(P```"$-`@`@````10T"`"H```!F#0(`)0```)$-`@`Y
M````MPT"`"<```#Q#0(`#````!D.`@`,````)@X"`!0````S#@(`+P```$@.
M`@`C````>`X"``L```"<#@(`%P```*@.`@`.````P`X"`!8```#/#@(`"```
M`.8.`@`'````[PX"`"(```#W#@(`)0```!H/`@`2````0`\"`!T```!3#P(`
M)P```'$/`@`E````F0\"``P```"_#P(`ZP```,P/`@`/````N!`"`!@```#(
M$`(`"P```.$0`@`,````[1`"``\```#Z$`(`&`````H1`@`?````(Q$"`"D`
M``!#$0(`'P```&T1`@`&````C1$"`#4```"4$0(`%@```,H1`@`4````X1$"
M``<```#V$0(`"0```/X1`@`3````"!("``H````<$@(`/````"<2`@`H````
M9!("`!,```"-$@(`&````*$2`@`7````NA("`#@```#2$@(`&`````L3`@`9
M````)!,"``\````^$P(`$@```$X3`@`D````81,"`!,```"&$P(`%````)H3
M`@`,````KQ,"`!4```"\$P(`"@```-(3`@`7````W1,"``D```#U$P(`'0``
M`/\3`@`(````'10"`!P````F%`(`*0```$,4`@`'````;10"`",```!U%`(`
M!P```)D4`@`(````H10"``D```"J%`(`-````+04`@`&````Z10"`!````#P
M%`(`%0````$5`@`4````%Q4"``L````L%0(`#````#@5`@`'````114"``L`
M``!-%0(`'````%D5`@`/````=A4"`!@```"&%0(`&0```)\5`@`+````N14"
M``T```#%%0(`%P```-,5`@`)````ZQ4"`"L```#U%0(`#P```"$6`@`)````
M,18"``L````[%@(``@```$<6`@`1````2A8"`!@```!<%@(`"P```'46`@`#
M````@18"``L```"%%@(`"````)$6`@`'````FA8"``L```"B%@(`"P```*X6
M`@`.````NA8"`"T```#)%@(`&@```/<6`@`:````$A<"``H````M%P(`.@``
M`#@7`@`%````<Q<"`!8```!Y%P(`-P```)`7`@`-````R!<"``X```#6%P(`
M!@```.47`@`$````[!<"``8```#Q%P(`"P```/@7`@`7````!!@"``<````<
M&`(`"````"08`@`'````+1@"``D````U&`(`!0```#\8`@`/````11@"`!``
M``!5&`(`,````&88`@`%````EQ@"`!H```"=&`(`(0```+@8`@`A````VA@"
M`",```#\&`(`$0```"`9`@`"````,AD"``0````U&0(`"@```#H9`@`%````
M11D"``4```!+&0(``P```%$9`@`)````51D"`$P```!?&0(`&````*P9`@`G
M````Q1D"`"@```#M&0(`)0```!8:`@!?````/!H"`!,```"<&@(`>0```+`:
M`@`<````*AL"`%(```!'&P(`(0```)H;`@`_````O!L"`#0```#\&P(`(```
M`#$<`@`<````4AP"`"P```!O'`(`-@```)P<`@`V````TQP"`#4````*'0(`
M,P```$`=`@`H````=!T"`"(```"='0(`)0```,`=`@!,````YAT"`!0````S
M'@(`-````$@>`@`/````?1X"`&\```"-'@(`"0```/T>`@!Q````!Q\"`'L`
M``!Y'P(`<````/4?`@`H````9B`"`%,```"/(`(`&@```.,@`@`7````_B`"
M``H````6(0(`90```"$A`@`=````AR$"`$4```"E(0(`/0```.LA`@`]````
M*2("`"D```!G(@(`+P```)$B`@`R````P2("`$(```#T(@(`>````#<C`@`Y
M````L","`#(```#J(P(`.@```!TD`@`T````6"0"`"D```"-)`(`'@```+<D
M`@`T````UB0"`",````+)0(`&````"\E`@!4````2"4"`!D```"=)0(`%P``
M`+<E`@`*````SR4"``0```#:)0(`!@```-\E`@`(````YB4"``4```#O)0(`
M%0```/4E`@`3````"R8"`!D````?)@(`)0```#DF`@`0````7R8"``X```!P
M)@(`!````'\F`@`)````A"8"``\```".)@(`"````)XF`@`)````IR8"`!8`
M``"Q)@(`#0```,@F`@`,````UB8"`!$```#C)@(`"P```/4F`@`&`````2<"
M`!,````()P(`"P```!PG`@`6````*"<"``T````_)P(`!P```$TG`@`.````
M52<"``@```!D)P(`"0```&TG`@`,````=R<"``8```"$)P(`!0```(LG`@`%
M````D2<"``4```"7)P(`"0```)TG`@`A````IR<"``(```#))P(``@```,PG
M`@`(````SR<"``@```#8)P(`%@```.$G`@`(````^"<"`"T````!*`(``@``
M`"\H`@`$````,B@"``D````W*`(`"0```$$H`@`0````2R@"`!<```!<*`(`
M#P```'0H`@`'````A"@"``4```",*`(`!0```)(H`@`1````F"@"`!(```"J
M*`(``@```+TH`@`(````P"@"``L```#)*`(`+0```-4H`@`D`````RD"``L`
M```H*0(`#````#0I`@`-````02D"`!,```!/*0(`!0```&,I`@`"````:2D"
M``L```!L*0(``0```-\$```G!```/P4``&L#````````A@8``(("``"K!```
M`````*D"``#?`0``^@8``*4`````````$0```)<"````````````````````
M````X@```(,%```>!```]P4``%(```#F`P``Q`8``"('````````"`0``,@%
M````````0`,```````"V`@```````'<"``##`@``Q0(``(H#```<!P``````
M`&T!````````X@0``%L%``"2!```_`,````````+`@``A`(```````#G`@``
MCP(``)4#````````00$``````````````````!T'``".!@``0P$``',&``!X
M`0``&`,``)$!``!>`0``V@$``.("```Y!```>@,``(,&```F!P```````%0!
M``",!P```````%0'```+`0```0<`````````````5@4``,\&````````,@(`
M`'0"```2`0``^`,``'D"````````+P```/L$`````````````#@'``#Q`@``
M`````*<#````````H@,```````!H````Y@8```````#E`0``T`,``-(&``!8
M`@`````````````8!```BP<````````9!0```````%H$``#4!0``_@(``+@$
M```U````A@<``%L```"`````U`$`````````````Q@(``),"``!Q`P``T04`
M`(`!```%!```````````````````@0$``'$!``"8````[0$````````#!0``
M``````4'``"W`````````&\'``"K`@```````"P#```O!```"0(```(!```W
M`P``\@$``.@!``#"`P``5`,```````"/!```T@(``#0#```1`0``O`4``-X$
M`````````````+@#``!Q!````````-,%``!M`P``@@,``*$$```1!```;`8`
M`(H&``#7`0```````$T&```Y!P``Y`,``/P!````````!`8``%8'``##`0``
M800``/D!````````=P```#8'```````````````````^`P``B00```````""
M`````````*0%````````HP8``"L#``"Q!@```````$\````/`@```````%\%
M``#E`P``+@8``*X$``!:!@``7P0```````#G!0``K0(```````#Y!@``E`,`
M`,T`````````N`4```````"J`P```````'H"``#.`P``)P<``(0#``!0````
M`````%T``````````````$0"``"L````[@0````````"!0``@`0``%`'```B
M!```40<`````````!0``C00``,8%`````````````+<#```_`@``?@<`````
M``!\!```2P(``"@&`````````````*\!````````_P````````!A!0``I`,`
M`!<"````````:@,``",!````````3P0`````````````J0,``+\!````````
M`````'$%``"2`0````````````!)!@``_@```"`'``!R``````````````"S
M!```1P$```````!B`P``H`(``*@$````````Y`$````````F`P```````#,$
M``"*````<0<````````/````H````/<#``!J!@``#`4``)H&```W!0``I```
M```````>!@``P`0``"<````W!P``Y`4````````#````;@,``!,'```,`0``
M``````````"$`0`````````#``#`````N0```*@#````````I@8``&L'````
M````,@```%,#``#/`@```````.@$``#8!@```````.T$``#6!```N00````'
M```5!P``*`(``,T$```U`0``P@(```````#U!@``+P4```4`````````GP$`
M`&H$``")`0``'`8```P"```Y`P``:`8``'T#``!1!```M0$``&\```#@`0``
M?`,``%4&``!B`````````'L```#7!@``B`(````````Z!0``.0(``'4&```-
M`0``#@8``"@```#V`@``9P(``$$%``"J`0``0@<```\#``!J!P``F0,``#0!
M````````PP4```H'``#Y!0``IP````P$```&!P``,P8``#L&````````8@(`
M`!$#````````@`,```8$````````-@```+4$`````````````$<'```M!@``
M``$````````&`P``2P<```````#C`P``Y00`````````````D0```!X"````
M`````````-4&``#(!@``F@```,8```#[!@``4@(``&<$``"G!```Q0,``.$`
M```+!```*`<``&L!``"B`@``0P0``+L!`````````````"D`````````6`<`
M`.@"``",`````````.4``````````````!8"``#_!````````$P%``!S!P``
M$0<``-`&``#R!@``)P,``($&`````````````%P%``#Y!````````,$"``!^
M!````````'@$```L````AP```"````#&`P``@@4```$!``"-`P``,`0``$<%
M``#V!@``I@,``(D"````````BP$``$X"``#!!@```````,P$````````<@8`
M``````"Q````M0(````````Z!@```````!D'````````<P$``"T$``!9`0``
M`````'8$``!6!```F`(``(4%``",!0``]P`````````T`@``[08``$`$``!&
M`@````````````"A`P``8```````````````^`0``(@'```&`@``YP```/D#
M``"V`````````````````````````(X#`````````````,`!```]`P``=0$`
M`/,&````````^@$``!T!``!U````C0$``!T%````````6`$``)L#``#L!```
MO0```&($``"&!```G````-P%``!J`@``D@(```````!(!@``EP$``!("````
M````\00```````!$````E`8``!\&``#7!0`````````````L!```*@```#$%
M``!P`@````````````#G!@``GP4``-X&``#C!@``!````&8```!)`0``)0(`
M`.(#``"0!@````````````!V`P``R0$``)L$``#)`````````-$#````````
MS@(``#8$```K!```\P0````````R!@``"`,``(X%``!)`````````,<&``#M
M!0``N@(``#,#``#@!0```````.4"````````I@```#8#````````=@<`````
M``!I!P``&@```.8!``!E!@```````````````````````*D%``!7!0``/P8`
M``````#``P``I`0``!<````#!```P@```+T#``#<`0``(@```'T$``!Y!```
MZ0(```````"=`0``K0$`````````````;P8``+X&```_!````````$H'````
M````W0,``*@&```!`@``R@`````````!`P``````````````````O`0````"
M```&!0``!P8``#0$```:!```<`0``,4````C!P``QP0``/,#````````````
M`&T"``"9!```)`<``"T#``#*!0``3@4``+L&````````D08`````````````
M```````````F!````````/T#``!\````_````%L$```9````O````*$!``!F
M`@``7@```"8&``!,`@``A@(````````%`P````````\$``#(`@``L`0`````
M`````````````#,`````````/`4````````;`0```````"L%``"6!0``&`(`
M`/X%``"%`P``V@8``"H!``"@!0``$`4``````````````````/H%``"0!```
MI@(``-\"```)!P``HP,``!`#`````````04``$\"``#+!0```````-,$``!2
M`0``*P(``-P"``"T````604```````!J`0``M@8```````#]!@```````/0!
M```R!```K0,``-4%``"4`0``/00``/`"``"8!```BP```+,"``!5````G@8`
M``P```!K`@``@@<```````"8!0``-P````````"'`0``!P```"`&``"(!0``
M60```,D%``#;`@```````!0&``"X!@``904``&4!`````````````"\"``"?
M!```W`8````````;!0```````(0'``!)!```4P(```````#8`0```````$@!
M``!K!```X0(``!D&````````J````$\#```>````2P$```T```#W`0``````
M`-H%```;````_0$``&`#```!!```A`0``.T"````````'P<``-\&``#Q!0``
M`````*T%``"(````,0(``$$#````````MP8``'L$````````@`8``$0%``!&
M!0``(00```````"?````K`,```````"C!0``;`4``","```.`P``0`$`````
M```4!P```````'0%````````SP4``#D!``#V`0```````)X#``"^````````
M`)`%``!D!P```````#@%``"3!````````#H```"6!@``Z0,``#P"``"F`0``
M`````%D#``!N!P``@00``!<$``".````7@4``-(%``"'`@```P$`````````
M````PP,``'\#````````````````````````&`8``'\!`````````````(X"
M``"5````,P<``/H$``"9`@```````-$&```;`@``'`4``(X!``!!`@``Z`4`
M`/D"``!;`P``+`$``(D```"0`````````,(&``#K`@``Q`(``*H%````````
MRP,`````````````G`$``+$%``"<!@```````!,!``"V!0``$0(``.$$```X
M````=@$``*`&```S!0``;`0```````#+!@```````'8`````````)`(`````
M````````5`0``!L&``!#````9P```/H#``"_!```R0(``)P%```'`0``2P0`
M``````#$!0``304``#T!``#1`0```````*<%````````U@`````````J!P``
M```````````=````;`<``,4%``"'!0``CP```+$$`````````````-H$```D
M`0``708`````````````X08``(X$``!;`0``1`0``"`$``#K!@``0@0``*,!
M````````=`8``"L!``",!````````)L&``#*!```:08```````#6`P``````
M````````````?@,``*(&```7!@``W@,``!4"``"]`0``.P,```````#!!```
M```````````2`P``_0(``)D```!P!@``^0```'T'``!2`P``O`8``'X%``!,
M!P``V@,``$P#`````````08```````"=!@``XP(````````W!```\@```(D&
M``!7````V0(``*P$```-`P``!0$``'X"```&````;@(```````!&`P``````
M`&$&``!,!```;`,```L&```E!```\````*$%``#9!@``50(``-X"```#!@``
MM`$`````````````"@8``%(%`````````````%8#``!V!0``7P<``.H!```6
M!``````````````````````````````*!0``=00```T$````````*@0``.D$
M````````:`,```````!1`0``,08``-<$``!F!0```````'X&``">````%@,`
M`+$!````````SP````````"6`0```````$\'```R!P```````*,```"=````
M,00``#8!``"#`0``<@$```````!@`0``#@```+0&``!#!P````````````!&
M````````````````````DP4``)P$``#O!@``4`0```4&``")`P``U````&X!
M``"/!@``S`$``"<"``!@`@``D`,````````'`P``V````/$&```4````;P$`
M``````"]!@```````+8#````````>`,````````(!P``+@<```````!D`@``
M`````%(&``"1`@```````"(&````````0````$8&``#=````8@8````````-
M`@``K0```$P&````````EP0`````````````5`(````````E`P```````$(!
M``!E`P``%0$``*8%``!=!0``W08``%H!```6!P```````*D!``!'!```8`0`
M``````!\`@``2P,``+L%``"Z!0``:`$```(```"J!````````%\!``"3````
M70<``+`#````````/P```"<%``#0````<P```"4!``"R!```'P$``'H&``"2
M!0``[`$``-P```#M`P``U@4`````````````*@4`````````````WP```-L`
M``!Z!```?04``"T```!I!0``\`0``"\#``#%`0``"0$``#4"``#S`@``U0$`
M``<"``!`!@``@@8```````"J````;P(``,P"``!&!````````#D```#9`0``
M`````,D#``"!!0``>`(``*X`````````*0$``,8&``"+!0```````&D"``"K
M!0``!0(``+H#````````E04``),!``#3````;08``*`$``#N!@````````T'
M``"#`@```````/8#````````(0(``#$!```\`P``3@0`````````````'`(`
M`!`'``!]!@``504```````#B!0``E`0````````A````"0,``+X$```9`@``
M`````$$````)!0``F`$``$H#```-!@``^P4```(#``!\!0``Q`,```````#@
M`P``^@(``%X&````````@@0``$X#````````/@(``*@%````````X04``&L%
M`````````````/X&``"&!0``5P(``&0```!4!@`````````````@`P``$P4`
M`#T%```,!P``/08``!T$`````````````',"```$!P``0@,```````!A`0``
MA`8```````"7!@``%08``(<#``"H`0``Z@```/(#``#E!@``W@```*P!``#+
M!````````$4#``!T!P``*04`````````````O00```````#U!```LP,`````
M````````/P<``%,$``!P`0``PP0``'\%```+`````````"P'``#Q`0``RP$`
M``````">!0```````,P&``"N!0```````!H#``"&`P``,````!0$``#T!0``
M$@0```````!1`@``.P``````````````N0,``!0#```C!```&@<`````````
M````]`0``/(%```;`P``=0(``,4$```T````?0$``.X"```<````M`(```L#
M``"V!```D`(``&<'```$!```9`$``"4``````````````!(&```P`0``````
M`/L#``#4!```P`8```````!5`P```````&<!``#(`0``@P0``$,&```8`0``
M`````&8!````````S@```'0!``#R!```M0````````#;`P``/@8``+`&````
M````[````'0$``````````````````#8!`````````@&````````)04`````
M``#P`P``6````-D#```C`````````/0`````````RP```-L$````````'08`
M`/T````_`0``L0(``*<"``!H!````````"$'```8````B@(``%8&```H!```
ME@,``*P"``"&````4@<``.H$``!P!0``108``%X#````````O@4````````5
M`P``*00``!H%````````F`8``!$%````````L@$``(4&```6!@``O`,``/@&
M`````````````)8"```D!@```````.<#````````>P$``&8'```D`P```P,`
M``````"`!0``L0,``'X!```P!@``````````````````KP8``.H#``!:`P``
M5P$``$4'``!_!````````#L%``"G!@``]0```*\"``!,`````````'T```"'
M!P``\P4``(4"```3````3@````````!<`P```````+,```#O!````````%<&
M`````````````"4'```&!@```````%8"````````K`8``!D$``#N`0``[@``
M`'D#```A`0```````"D'``!U!P``9@8`````````````CP$``,`"``#2!```
M0@(``%X$`````````````&<#``"/!0``'`0``*$"``!<!@``\P```+L#``!.
M!@``-`<`````````````W`0``-`"````````2P```,`%````````LP4`````
M``#\!@``-@(``-(#``#F!0``%P<````````S`@``N0(`````````````A```
M`)H"``"4````\`8```````!<`0``'@4``&@"``#K!0``L@```#H!``"Z!```
MD@,``!(`````````+@4```H`````````_P$````````'!0```````/4!``!3
M!0``<`<```````"P````^P(``#X$``#N`P```````!`&``#3`P```````$@$
M``````````````````#\`@``JP,``.(&```D!0``6@```/T%``!\!P``````
M`'$&````````V`,``)`!````````8P4``+<%``"O````I`$``!4```#5````
MF@,``)$$```Z!```T`$``*@"```$!0``QP(``/<"``!_!@``/`0``,<```"&
M`0``U`,``.\"````````EP4``*0&```A!@``NP0``!\``````````````*H"
M````````[P$``(D'```5!```/0(```````!%````ZP,``,0`````````````
M`'@%```E!@```````#(!``!*!0```````-T"``!-!P``B`8``)\"```M!0``
MI`(``#P'``!_`@``1P8``+P!````````.@(````````-!0``4P```%4'``"C
M`@``&`<``-4#````````1P(``/\%``"5`0``:0,``%8!````````600``&`%
M``"M!```M04``,T%``",`P```````'<!``!]`@``]0,``"H"````````````
M`&4'``!0`P``100``+`!``#[`0``[`,``!8%`````````````+T"```?`@``
M+@(``&P!``!2!```2`(```````">`0``$`(``%0```"N`0``AP0``%,'``#_
M`@``_@$``.<!``"!`@````````````#L`@``U`(``,(!``!+!0``G04``"L'
M``"7``````````(&``":!```FP$``````````````````.4%``"L!0``OP,`
M``````"8`P```````)X"``"(`0``BP,``-8!``!X!@``=P0```````!>`@``
M;@4``(,```"7`P``+0<``(H$````````R`,``$D"```I`@``F@$``'4#``"=
M`P``JP````<$````````H08````````@`@``)@(``.,```#'`P```````#4'
M```^!0``#@$```($````````5`4`````````````"00``-T!``!Y`0``````
M`/`!```G`0``_@0``&X&``!%!0``1@<```X"```$`0``TP$``,H#```?!```
M``````````!Y````\`4``/X#````````3@<``"D#``#V!```GP,``!,#```,
M!@``C`8```````!I!```:P8``$P!```K!@``=04``%,!``!``@```````&0&
M``#!`P```````%D"```^````*@8``(4!`````````````%\"````````````
M`*4%```V!@````````````#I`0``0P4``*<!```(`````````$$&``#O`P``
M)@4``,D$``"^`@```````*D```"#`P``AP8````````:`@``\P$``$0#```$
M`@```````*4&``!C!P``H`,``'8"``"N`@``^`4``-T$````````>@<``&X$
M``````````````H!``#"!0``GP8````````\`0``S0,``$(&``![!0``I0$`
M`(`"````````6`0``.@&````````R08`````````````Y```````````````
M;00``'D'``#(!```<P0``%T!``!;!P``=P,``'P!``!M````$@<`````````
M````Z@(``'$```!)`P``B@4````````/`0``'P4````````0````7P,``!0%
M```P!0```````+<$```.!````````$H&```````````````````L!0``````
M`-(```#1````-08```,'```&`0`````````````B`P``SP0``-L&````````
M8P0``(@#```3!```*`,``,8!``!B!0``.@<``.0&``#O````=P<``#L'``"!
M!P``U@(``(4```!)!P``50$```````#,````2@$``!\#````````G00``#@!
M``#(````6@4``%$```#I!@``B@$``%8```"-!@```````!`$``"X`0``I0,`
M`,0!````````W04``/P%```*`@``'@,```````"Y`0``Y@````````#7`@``
M?P```%\````[`@``````````````````M`0``,<%````````S`4``#0%``"@
M`0``.P$``!T#``#W!@``H@0`````````````QP$`````````````O@$``*T&
M``#2`0``9P8``-`%``#A`P``(@4``*\#````````+`(``)X$````````/0<`
M`)0%``#9!0``^`$``/P$``#U`@``PP8``+P"``![`P``FP4``,H!````````
MVP4``(P!````````P04``#$#````````=P4````````*`P``````````````
M````0`<``"X#``"`!P``P@0``$@`````````S@4``,$!``!K````%@```"T"
M```````````````````@`0``I0(``(P"``!-`P``>P8``(4$``!9!P``/@<`
M`&T%``!3!@``40,```@!``!F`P``Q08````````X!`````````````#Q````
M30```-D```"+`@``3P4``%P'``!8!@```````%H"``!E````.04```````!\
M!@``\@(``%`!```J`P```````+4#````````T00``$H```#?`P``]`(``($#
M``"[````B@<``"0$`````````````'('```P`P``2@0``!X'````````````
M`-,&``"N`P``.`,``!P!``!C`P`````````````;!P``70,``$H"``"Z````
M"`(``&4"`````````````!$&```3!@``I00```````!C`0``<0(``%4$``!7
M!P``>04``+X#``"R!0``E0(``$0'``!P````1`$```````#5`@```````+T%
M``!_!P``YP0``',%``"S!@``,@4``$@'````````5P,``'($``#<`P``3P8`
M`'L"``#J!0``B`0``'`#````````4`8``+<!```=`@``7`(``-`$````````
ME00``+0#``";````#P8`````````````#`,``'@'``!`!0``=`,```('```R
M`P````````````#Q`P``HP0``,X!``#-!@``X`(``$8!``"V`0``XP$`````
M``!B!P``8P(``"8!``"1!0```````$,"```7`0``OP```+D&``#M````OP(`
M`$(%````````^`````````![!P```````````````````````)4&```#`@``
M"0```&,````<`P``8@$``",%``"=`@````````\'``!O!0``````````````
M````-P$``)L"```]````A0<``&$'``"Y!0``;@```'<&``!!!```VP$``.L!
M``!J````;P0```````!Z!0``]`8``'X````N`0````8``%T"```+!0``;`(`
M`*\%```)!@``[P4``$(```!1!0```````%$&````````F08``"T!```*!```
M``````````"_!@``+@```!H&```P!P``]@4``(D%````````0P,``&0%``!'
M````+P$``#`"````````<@4```````!-`0``30(```````!.`0``.`(``/8`
M```"`@``7@<``'(#```6`0```````+@"````````;0<``+("````````````
M``````""`0``V@```+@```````````````````!7!```-0,``,\!````````
M`````),#````````C0(``.8"``#>`0```````(\#````````N@$```````!Z
M`0``X0$``"@!``!A`P``H@```.`$``#/`P``700``.(!```C`P``````````
M``"P!0```````$D%``#7````&0,```````!$!@``Y`0```````"P`@``E@``
M`)H%```````````````````U!```)@```'("```D``````````````!8!0``
M`````.D`````````G`(```````#@````%04```````!'`P````````L'``!F
M!```6`,```````!T````I@0``/@"```U!0``[@4``#L$``"A``````````\%
M```0`0``]04``%L"````````$@4``(L$``!Z````]`,```````#6!@``80``
M`-4$```T!@``T0(```````#3`@``>08``%`%``#@!@```````$$'```K````
M`````#H#```9`0``R@8``(,'``"Z!@``ZP```)D!``````````0``.P%``"J
M!@``&P0````````.!P``%P,``,H"```'!P``,0```)P#``"[`@``900``.,$
M``!(`P``/P,``!0!```Q!P```````(T%```B`@```````&<%``#C!0``/```
M`,P#``#7`P``]P0``&0$``"S`0``D0,````````H!0`````````````@!0``
MBP8``*\$```O!P``JP$``$T$``#!````)P8```0#``!V!@````````````#$
M!```W@4``"$#``#J!@``:@4````````(!0``D@8``.D%```O!@``8P8`````
M```%!0```````,L"``#L!@``S0$``$L&````````K@8``%L&``!(!0``M`4`
M`&D```#9!````````$4"``!H!P``#@4``#<&``"9!0```````+<"````````
M`````&P````L!@``Y@0``/\&````````Z`,``&\#``#[``````````````!9
M!@``10$``+\%`````````````.0"````````>````)0"``"U!@``9`,``*(!
M```7!0``7`0``#<"``#4!@```````%P`````````V@(``+(#``"!````````
M`$\!``#-`@```````+(&```8!0``$P(``&`&``#&!```/`8```````!?!@``
M`````(T````I!@``V`(```````##````'@$``"(!``!0`@``E@0``)(```#?
M!0``/@$``*D$````````^@```"$%````````_00``-@%````````,P$`````
M``"$!0``Z````,X&``!:!P```````&@%```N!```_P,``#8%````````S@0`
M`*D&```C!@``:0$``#@&```4`@``<P,``.L$``!@!P``H@4````````:`0``
MJP8``),&``!A`@```````#D&````("`M32P@+2UM97-S86=E/4U%4U-!1T4@
M(%5S92!T:&ES(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0@;VYE<RX`("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@
M9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F
M97)E;G0@8G)A;F-H('1O"B`@("`@("`@("`@("`@("`@("`@("`@('1H92!G
M96YE<F%T960@8V]M<&5N9&EU;2X`("`M8BP@+2UB87-E/2]0051(("!&=6QL
M('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U
M;&0@8F4*("`@("`@("`@("`@("`@("`@("!U<V5D+@`@("UC+"`M+6-O;7!E
M;F1I=6T]1DE,12`@365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O
M;7!E;F1I=6T@9FEL90H@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A
M9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE"B`@
M("`@("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E8W1O<GDN`"`@
M+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I
M;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L=`H@("`@("`@("`@("`@("`@("`@
M("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E
M8W1O<GDI+@`@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G
M97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I97,N`"`@+60L("TM9&ER96-T
M;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y
M+@`@("UH+"`M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N
M`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L
M92X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92X`
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+@`@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO
M;G,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U
M;&4]34]$54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E
M(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM
M;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N
M)W0@;65R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2X`
M("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I
M=6TN`"`@+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N
M('-T871I<W1I8W,@:6X@82!L;V-A;"!F:6QE+@`@("UT+"`M+71E<W0@("`@
M("`@(%-H;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@
M86YY=&AI;F<N`"`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U
M<"!F<F]M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RX`("!C
M;VUM:70@("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R
M=F5R+@`@(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#
M5E,@<V5R=F5R+@`@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I
M=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H90H@("`@("`@
M("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2X`("!E>'1R86-T("`@("!'96YE
M<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N`"`@:&5L<"`@("`@("`@
M4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`("!I;FET("`@("`@("!#<F5A=&4@
M;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN
M9SH@5&AI<PH@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG
M(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+@`@(&UA:V4@("`@("`@($)U:6QD
M(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N
M`"`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE
M;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9`H@("`@("`@("`@("`@('!R
M97!A<F4@=&AE(&9I;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A
M=&4M:&5L<"X@66]U"B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA
M:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE"B`@
M("`@("`@("`@("`@:&5L<"!F:6QE+@`@(&UE<F=E("`@("`@($UE<F=E('1H
M92!C=7)R96YT(%!/(&9I;&4@=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T
M92!F:6QE+@`@('5P9&%T92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S
M97%U96YT+@`@('5P9&%T92UH96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA
M;F=E9"!E;G1R:65S(&9R;VT@=&AE($5N9VQI<V@@6$U,(&AE;'`*("`@("`@
M("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG
M(&]N97,N`"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@
M*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60@
M8GET97,@=W)I='1E;BX`)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M
M=&\M9&%T90`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@061M:6YI
M<W1R871I;VX`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@9&]E<R!N;W0@97AI<W0@;W(@:7,@;F]T(&5X96-U=&%B
M;&4N`"5S(&ES(&YO="!W<FET86)L92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN
M=71E<P`E<R!N;W0@9F]U;F0N`"5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA
M=&EO;B!E>'1R86-T)R!F:7)S="X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R
M97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K
M;&ES=``E<SH@)7,`)7,Z('5N86)L92!T;R!L;V%D(&1R:79E<CH@)7,`)R5S
M)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"<E<R<@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`G)7,G('1R964@<F5N9&5R97(@
M;F]T(&9O=6YD+@`G)7,G('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E
M;2X`)R5S)R!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`
M)R5S)R!W87,@;F]T(&-R96%T960Z("5S+@`L(&=U<W1I;F<@)7,@)7,`+"!V
M87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M
M870`,C0@:&]U<G,`/%!R979I;W5S`#QG971T97AT/B!T86<@;F]T(&-L;W-E
M9"!I;B!F:6QE("5S+@I/<&5N:6YG('1A9R!F;W5N9"!I;B!L:6YE("5D+@!!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%$4TD@
M97)R;W(@)7,N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@
M4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H
M:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S
M($1E;FEE9"X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A
M<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI
M;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.
M97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P
M('1O("<E<R<`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G`$%D9"!A
M(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O
M(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E
M<@!!9&1E9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D
M(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@)R5S
M)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!N
M97<@9FEL97,@=&\@<F5P;W-I=&]R>3H`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`
M069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N
M;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`
M06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E
M/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA
M=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E
M<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R
M;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`
M06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P
M<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`
M07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A;F0@86YY
M('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R=`!!<G5B80!!<V-E
M;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T
M<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N
M9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`
M075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R
M96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E
M<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A
M=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E
M<P!"86-K96YD(&YO="!C;W)R96-T;'D@:6UP;&5M96YT960N`$)A8VMG<F]U
M;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A
M9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;F=L861E
M<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@
M9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`
M0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A
M=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP
M90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN
M97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S
M=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I
M86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U:6QD:6YG
M($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`0G5I;&1I;F<@;&]C86QE("5S
M+BXN(`!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O
M<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE
M;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL
M92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@
M3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T
M:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN
M9SH`0V5L;'!H;VYE`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`
M0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I
M8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@4&%S<W=O<F0`0VAA
M;F=E('!A<W-W;W)D(&]N.@!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@<&%S<W=O<F0`0VAA;F=I;F<@<&%S
M<W=O<F0@;VX@)7,`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&]O<V4@82!P87-S=V]R9`!#:&]O
M<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I
M<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+@!#;&5A;FEN9R!U<"!03R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN`$-L96%N
M:6YG('5P(&QO8V%L92`E<RXN+B``0VQE87(`0VQE87(@35-/9F9I8V4@=&%G
M<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A
M=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL
M('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L
M;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R
M`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM86YD(&]P=&EO;G,Z`$-O;6UA
M;F1S.@!#;VUM96YT`$-O;6UI='1I;F<Z`$-O;6UO;B!.86UE`$-O;6]R;W,`
M0V]M<&%N>0!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET
M:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F9I<FT@;F5W('!A<W-W;W)D.@!#;VYG;P!#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN
M96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G1S(&]F("<E<R<`
M0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T
M:6]N`$-O<'EI;F<@)7,@=&\@)7,`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E
M`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V
M97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("<E<R<@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<P!#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@8W)E871E(&QO8V%L
M92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SH`0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@)R5S)RX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T
M92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@)R5S)RX`0V]U;&0@;F]T(&UK9&ER("<E<R<N`$-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD
M(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG
M+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(&]P96X@
M<&EP92!T;R!S;6)P87-S=V0N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N
M;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N
M(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#
M;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V
M92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@)R5S)RX`0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B`G)7,G+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T
M:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU
M86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@)R5S)RX`0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@)R5S)SH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@
M9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F
M;VQD97(@)R5S)SH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#
M<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S
M=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%1I
M;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N
M9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#
M>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`
M1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU
M;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$
M969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT
M(%!E<FUI<W-I;VYS`$1E9F%U;'0@<&5R;6ES<VEO;G,`1&5F:6YI=&EO;G,`
M1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`
M1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("<E<R<`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E
M;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES<VEO;B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S971U<"!U<&=R861E
M('-C<FEP="`G)7,G+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@
M=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O
M:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`
M1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA
M>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R
M;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI
M<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$
M;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2
M`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M
M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@
M)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`
M161I="!P97)M:7-S:6]N<R!F;W(@)R5S)P!%9'5C871I;VX`16=Y<'0`16P@
M4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M
M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%
M;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L
M:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT
M97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME
M9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G
M92!54DP@:&5R90!%;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@
M)60@;F5W+"`E9"!C:&%N9V5D+"`E9"!U;FMN;W=N`$5Q=6%T;W)I86P@1W5I
M;F5A`$5R:71R96$`17)R;W(`17)R;W(@<V5N9&EN9R!D871A('1O('-M8G!A
M<W-W9"X`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG
M("<E<R<N`$5R<F]R.B``17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E
M`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E
M8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@
M:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AE
M8W5T:6YG.@!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X
M<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A
M=&EO;B!$871E`$5X<&]N96YT`$5X=')A8W1I;F<@9G)O;2`E<RXN+B``1D<@
M0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C
M;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V
M92!T;R`B)7,B+@!&86EL960@=&\@=F5R:69Y(&]L9"!P87-S=V]R9"X`1F%I
M;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"!O;B`E<SH@)7,`1F%I<@!&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%
M<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E
M=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`
M1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE
M($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D
M`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`
M1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T
M`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9O=6YD
M(&%P<&QI8V%T:6]N<SH@)7,`1F]U;F0@9&ER96-T;W)I97,Z`$9R`$9R86UE
M<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1G5Z>GD`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`
M1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N
M97)A=&5D($-O9&4`1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN
M+@!'96]R9VEA`$=E<FUA;GD`1V5T;W!T($5R<F]R.B``1VAA;F$`1VEB<F%L
M=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R8V@`1W)A>7-C
M86QE`$=R965C90!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A
M=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<"!P97)M
M:7-S:6]N<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R
M;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S="!P97)M:7-S:6]N<P!'=65S
M=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`
M2&%Z90!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96QP97(@
M87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO
M;G,@9F]R('1H92!(;W)D90IF<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO
M;G,N"D9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$344@
M:6X@=&AI<R!D:7)E8W1O<GDN`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AI<W1O<GD@96YT<GD@;F%M97,@
M;75S="!B92!N;VXM96UP='D`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A
M<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4@=')A;G-L871I;VX@9V5N97)A=&]R
M`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@
M='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<WEN8VAR;VYI<V5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-
M3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R
M:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO
M<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@
M:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)
M34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL
M86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C
M:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`
M26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E
M>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O
M<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO
M=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R
M+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T
M(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T
M(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z
M`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G
M92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3
M=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN
M7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!087-S=V]R9`!);F-O<G)E8W0@
M86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN
M9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I
M;VX`26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN+B``26YS97)T($-?;VQU;6X@
M069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI
M;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F
M;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL
M(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S
M<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!)
M;G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R
M="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A
M9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O
M<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y
M('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@
M3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN
M=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!)
M;G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N
M`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV
M86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@
M<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O
M=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`G)7,G`$EN=F%L:60@<VAA<F4@
M;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D
M92!D871A+@!);G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)
M<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R
M865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N
M`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT
M97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA
M>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@
M0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`
M2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2W5W86ET`$MY
M<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D
M871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,
M87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T
M('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY
M80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H
M="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E
M<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N
M;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S
M964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S
M`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,
M:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B
M<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`
M3&ET:'5A;FEA`$QO861I;F<@;&EB<F%R:65S+BXN`$QO861I;F<N+BX`3&]C
M86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G
M(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,
M;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L
M971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R
M<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-
M86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%K92!S=7)E('1H870@>6]U(&AA
M=F4@4$5!4B!I;G-T86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P871H+@!-
M86MI;F<@9&ER96-T;W)Y("5S`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M
M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-
M87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D
M*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S
M`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-
M87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@
M8V5L;',`365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I
M=6TN+BX@`$UE<F=I;F<@;&]C86QE("5S+BXN(`!-97)G:6YG('1H92!03R!F
M:6QE(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!T<F%N
M<VQA=&EO;B!F;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`365S<V%G92!697)I
M9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T
M92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S
M<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I
M<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("<E<R<@:7,@;F]T(&1E
M9FEN960`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-
M:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;&4`36]D=6QU<P!-;VQD;W9A
M+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`
M36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`36]S=&QY
M($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-
M;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P
M`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I
M<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@
M3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I
M80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE
M<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%52
M3`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),
M`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@
M;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE
M=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.
M97<@6F5A;&%N9`!.97<@<&%S<W=O<F0Z`$YE=R!W:6YD;W<@*%]B;&%N:RD`
M3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO
M;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.
M;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E
M+@!.;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@8F5L;W<@
M=&AI<R!L979E;"X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BX`3F\@8V]M;6%N9"!S<&5C:69I960N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I
M;VX@<W5P<&QI960N`$YO(&5N=')Y('=I=&@@=&AE(&ED("<E<R<@97AI<W1S
M(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N`$YO(&9I;&4@=7!L;V%D960`
M3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%L92!S<&5C:69I960N`$YO(&QO8V%T
M:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@
M<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF
M:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A
M=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-3
M3"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A
M=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@
M<W5C:"!B86-K96YD("(E<R(@9F]U;F0N`$YO('1E;7!O<F%R>2!D:7)E8W1O
M<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A
M;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F9O;&L@27-L86YD
M`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S
M`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`
M3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S
M`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I8V4`3F]V96UB97(`
M3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@
M0W)E871O<@!/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<P!/8W1A;`!/8W1O
M8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@<&%S<W=O<F0Z`$]M86X`
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F
M;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN
M9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<'1I;VYS.@!/<F1E
M<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G
M86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W
M;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$
M871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`
M4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!0
M32!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4%](
M4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R
M86=U87D`4&%R=&QY($-L;W5D>0!087-S=V0@:7,@;F]T('!R;W!E<FQY(&-O
M;F9I9W5R960N`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@;VX@)7,N`%!A
M<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!M;V1U;&4@8V%N)W0@9FEN9"!T
M:&4@<W5P<&QI960@8FEN+@!087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN9R!R
M97%U:7)E9"!P87)A;65T97)S+@!087-S=V]R9"!M;V1U;&4@:7,@;6ES<VEN
M9R!T87)G970@<&%R86UE=&5R+@!087-S=V]R9"!M;V1U;&4@:7,@;F]T('!R
M;W!E<FQY(&-O;F9I9W5R960`4&%S<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P
M97)L>2!C;VYF:6=U<F5D+@!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!0
M87-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;B`G)7,G(&YO="!D96QE=&5D+@!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)M:7-S:6]N<R!F;W(`4&5R<V]N86P@
M26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O
M<P!0:71C86ER;@!0:7AE;',`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@
M96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI
M;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y
M.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT
M97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@
M=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@
M<')O=FED92!A(&YE=R!P87-S=V]R9`!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@8W5R<F5N
M="!P87-S=V]R9`!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P
M87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`
M4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R
M9RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;&5A<V4@
M=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%!O;&%N9`!0;VQI=&EC<P!0;VQL
M<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`
M4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE
M8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U
M97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD
M(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO
M=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO
M=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G9')I=F5R<R<@:7,@;6ES8V]N9FEG=7)E
M9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y
M<&4G(&YO="!S<&5C:69I960@:6X@4&%S<W=D(%-13"!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!344P@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O
M<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E<W5L=',@*&EN8VQU
M9&EN9R!(;W)D92DZ`%)E<W5L=',Z`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI
M;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2
M;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T
M871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P
M97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G
M90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-
M97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`
M4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I
M80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@
M36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED
M97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/
M<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z("<E<R<N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E
M87)C:`!396%R8V@@16YG:6YE<P!396%R8VAI;F<@2&]R9&4@87!P;&EC871I
M;VYS(&EN("5S`%-E87)C:&EN9R!G971T97AT(&)I;F%R:65S+BXN`%-E;&5C
M="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!3
M96QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S
M97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@
M86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P
M;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I
M82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R
M;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@240@97AP:7)E9"X`4V5T
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W
M`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO
M=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@
M3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VX@=7`@:68@;F]T(')E9VES
M=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E
M`%-I>F4`4VMI<"!-86EN=&5N86YC90!3:VEP<&5D+BXN`%-L;W9A:VEA`%-L
M;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO
M=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L
M:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@
M861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C
M92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N
M="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A
M;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I
M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R
M(%!R;W9I;F-E`%-T871U<P!3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B``4W1O
M<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I
M;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;
M0U-370!3=0!3=6)D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`%-U8FIE8W0`
M4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`G)7,G('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F
M=6QL>2!A9&1E9"`G)7,G('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!D96QE=&5D("<E<R<N`%-U8V-E<W-F=6QL>2!R96UO=F5D
M("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C
M8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6-C97-S9G5L;'D@=W)O=&4@)7,`
M4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`
M4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E
M<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD
M($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`
M5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!44U8@9FEL90!4
M86)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N
M`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE
M($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP
M97)A='5R93H@`%1E;7!L871E("<E<R<@;F]T(&9O=6YD+@!496UP;&%T92!!
M9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T
M;W``5&@`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M
M+@!4:&4@)7,@:&5L<"!F:6QE(&9O<B`E<R!D;V5S;B=T('EE="!E>&ES="X@
M0W)E871I;F<@82!N97<@;VYE+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E
M;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG
M(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S
M86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E
M<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9
M;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@
M961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE
M<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI
M:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R
M;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:&5L<"!F:6QE("5S(&1I
M9&XG="!S=&%R="!W:71H(#P_>&UL`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@
M<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4
M:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE
M`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI
M<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL
M>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO
M=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D
M+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE
M;65S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P
M=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A
M8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R
M86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E(&1O
M97-N)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RX`5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+B`E<RX`5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M)R5S)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O
M8FQE;2!U<&1A=&EN9R`G)7,G.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F
M;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4
M:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U
M;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E
M(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+@!4:&5R
M92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E
M<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A
M('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@
M271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T
M:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI
M<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S
M+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T
M:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H
M92!C;VUM86YD(&QI;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@
M>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@
M9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R
M;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT
M;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL
M92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K
M96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N
M<VQA=&5D`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@
M;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VUE;FES=&%N`%1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@
M`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R
M>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O
M(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S
M97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T
M;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P
M>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E
M<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E
M;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA
M8FQE('1O(&1E;&5T92`G)7,G.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``
M56YF:6QE9`!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5
M;FET960@4W1A=&5S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S
M<V%G92!)1"DN`%5N:VYO=VX@8V]M;6%N9#H@)7,`56YK;F]W;B!L;V-A=&EO
M;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL
M:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@
M<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA
M=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5;G1R
M86YS;&%T960`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D
M("<E<R<N`%5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N`%5P9W)A9&4@
M<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I
M;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T
M=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-A9V4Z`%5S92!#
M=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I
M9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U=&AO
M<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N
M<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&YO="!F;W5N9`!5<V5R
M(&YO="!F;W5N9"X`57-E<B!P97)M:7-S:6]N<P!5<V5R;F%M90!5<V5R;F%M
M92`G)7,G(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5
M<V5R<P!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E
M8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N
M<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F
M<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@
M)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I
M86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R
M<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`
M5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65W("5S`%9I97<@86X@
M97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB
M:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A
M(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@86YD
M($9U='5N80!787)N:6YG`%=A<FYI;F<Z(`!790!796%T:&5R($9O<F5C87-T
M`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B
M(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E
M<P!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA
M<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H
M87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z
M`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!7<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S+@!8
M+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS
M`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!
M9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A;B=T(&-H86YG92!P87-S=V]R
M9"!F;W(@=7-E<B`E<P!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@
M)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T(&=I=F4@>6]U<B!C
M=7)R96YT('!A<W-W;W)D`%EO=2!M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O
M<F0`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N`%EO=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9`!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N
M`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET
M>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O
M;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+@I.;W0@
M86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO
M;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T
M97)S(&QO;F<A`%EO=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@
M9W5E<W,A("!.;W0@8VAA;F=E9"$`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O
M('-I;7!L92!T;R!G=65S<RX@3F]T(&-H86YG960A`%EO=7(@;F5W('!A<W-W
M;W)D(&UU<W0@8F4@870@;&5A<W0@)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R
M(&YE=R!P87-S=V]R9"!M=7-T(&)E(&1I9F9E<F5N="!F<F]M('EO=7(@8W5R
M<F5N="!P87-S=V]R9`!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@
M870@;&5A<W0@)60@86QP:&%B971I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P
M87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%N=6UE<FEC
M(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A
M="!L96%S="`E9"!D:69F97)E;G0@='EP97,@;V8@8VAA<F%C=&5R<RX@5&AE
M('1Y<&5S(&%R93H@;&]W97(L('5P<&5R+"!N=6UE<FEC+"!A;F0@<WEM8F]L
M<RX`66]U<B!N97<@<&%S<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D
M(&QO=V5R8V%S92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T
M(&-O;G1A:6X@870@;&5A<W0@)60@;G5M97)I8R!C:&%R86-T97)S+@!9;W5R
M(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@=7!P97)C
M87-E(&-H87)A8W1E<G,N`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I
M;B!L97-S('1H86X@)60@=VAI=&5S<&%C92!C:&%R86-T97)S+@!9;W5R(&YE
M=R!P87-S=V]R9"!M=7-T(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA<F%C
M=&5R<RX`66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M871C:`!9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T
M:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9',@9&\@;F]T(&UA
M=&-H`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M
M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE
M;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO
M;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%])
M;6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,
M:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`
M7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O
M;VL`86X@97)R;W(@:&%S(&]C8W5R960Z`&-A;&5N9&%R`&-A;&T`8VQI8VL@
M:&5R90!D;VYE`&9A:6QE9`!F86QL:6YG`&9I;&4`9F]U;F0Z(`!F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S`&@Z`&AH`&EM;65D:6%T90!I;FQI;F4`;&1A
M<%]S=&%R=%]T;',@9F%I;&5D`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@
M)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@8VAA;F=E9`!N;W0@
M9F]U;F0`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T
M97!A9`!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S
M;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'1A<VL@;&ES=`!T:&4@2&]R
M9&4@4$\@9FEL92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N
M;F%M960`=7!D871E9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O
M;0!0<F]J96-T+4ED+59E<G-I;VXZ('!A<W-W9"`S+C`*4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#4M,#DM,38@,C(Z,3<K,#(P,`I03RU2979I<VEO;BU$871E.B`R
M,#`U+3`Y+3$V(#(R.C$W*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!)=F%N($YO
M<FES(#QV:7A`=F%Z:V$N<VL^"DQA;F=U86=E+51E86TZ(%-L;W9A:R`\=FEX
M0'9A>FMA+G-K/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,@I#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU
M<F%L/2AN/3TQ*2`_(#`@.B`H;CX],B`F)B!N/#TT*2`_(#$@.B`R.PH`("`M
M32P@+2UM97-S86=E/5-04L%602`@4&]UOFF[('3Z=&\@<W!RX79U('!R:2!V
M:VQA9&%N[2!D;R#Z;&^^:7-K82!N86UI97-T;R"Y=&%N9&%R9&YE:BX`("`M
M82P@+2UA9&0]4]I"3U(@("`@("`@4')I9&&[('1E;G1O(%!/('/Z8F]R(&1O
M('/Z:')N;W;I:&\@<_IB;W)U+B!6:&]D;ND@<')E"B`@("`@("`@("`@("`@
M("`@("`@("`@('IA:')N=71I92!S^FAR;G4@>B!I;F5J('9E='9Y(&1O(&=E
M;F5R;W9A;NEH;PH@("`@("`@("`@("`@("`@("`@("`@("!S^FAR;F]VZ6AO
M('/Z8F]R=2X`("`M8BP@+2UB87-E/2]#15-402!0;&[A(&-E<W1A(&L@>N%K
M;&%D;NEM=2!A9')E<^%R=2`H2&]R9&4I+"!K=&]RX2!S82!MX0H@("`@("`@
M("`@("`@("`@("`@('!O=;YINRX`("`M8RP@+2UC;VUP96YD:75M/5/:0D]2
M(%IL^NAINR!N;W;I('!R96ML861Y(',@=/UM=&\@<_IH<FYO=OUM('/Z8F]R
M;VT*("`@("`@("`@("`@("`@("`@("`@("`@(&YA;6EE<W1O(+ET86YD87)D
M;NEH;R`H8V]M<&5N9&EU;2YP;R!V(&%D<F5SX7)I"B`@("`@("`@("`@("`@
M("`@("`@("`@("!H;W)D92]P;RX`("`M8RP@+2UC;VUP96YD:75M/5/:0D]2
M(%!O=;YINR!T96YT;R!S^FAR;F]V_2!S^F)O<B!N86UI97-T;R"Y=&%N9&%R
M9&[I:&\*("`@("`@("`@("`@("`@("`@("`@("`@("AC;VUP96YD:75M+G!O
M('8@861R97/A<FD@:&]R9&4O<&\I+@`@("UD+"`M+61E8G5G("`@("`@(%IO
M8G)A>FF[('-P<N%V>2!Z;R!S</JYNV%N_6-H('!R;V=R86UO=BX`("`M9"P@
M+2UD:7)E8W1O<GD]0412("`@5GET=F]R:;L@<_IH<FYO=OT@<_IB;W(@=B!T
M;VUT;R!A9')E<^%R:2X`("`M:"P@+2UH96QP("`@("`@("!:;V)R87IINR!T
M:65T;R!P;VUO8V[I(&EN9F]R;>%C:64N`"`@+6PL("TM;&]C86QE/6QL7T-#
M("`@("!0;W6^:;L@:6)A('3Z=&\@;&]K86QI>N%C:74N`"`@+6PL("TM;&]C
M86QE/6QL7T-#("`@("!0;W6^:;L@=/IT;R!L;VMA;&EZX6-I=2X`("`M;"P@
M+2UL;V-A;&4];&Q?0T,@("`@(%!O=;YINR!T^G1O(&QO:V%L:7KA8VEU+@`@
M("UM+"`M+6UO9'5L93U-3T153"`@("!6>71V;W)INR!-3R!S^F)O<GD@:6)A
M('!R92!T96YT;R`H2&]R9&4I(&UO9'5L+@`@("UM+"`M+6UO9'5L93U-3T15
M3"`@("!6>>AI<W1INR!-3R!S^F)O<GD@:6)A('!R92!T96YT;R`H2&]R9&4I
M(&UO9'5L+@`@("UM+"`M+6UO9'5L93U-3T153"`@("!/9&]S;&&[('!R96ML
M861Y(&EB82!P<F4@=&5N=&\@*$AO<F1E*2!M;V1U;"X`("`M;2P@+2UM;V1U
M;&4]34]$54P@("`@5GET=F]R:;L@4&\@<_IB;W(@:6)A('!R92!T96YT;R`H
M2&]R9&4I(&UO9'5L+@`@("UM+"`M+6UO9'5L93U-3T153"`@("!:;/KH:;L@
M4$\@<_IB;W)Y(&EB82!P<F4@=&5N=&\@*$AO<F1E*2!M;V1U;"X`("`M;2P@
M+2UM;V1U;&4]34]$54P@("`@06MT=6%L:7IO=F&[('/Z8F]R>2!P;VUO8V[M
M:V$@:6)A('!R92!T96YT;R`H2&]R9&4I(&UO9'5L+@`@("UM+"`M+6UO9'5L
M93U-3T153"`@("!!:W1U86QI>F]V8;L@:6)A('1E;G1O("A(;W)D92D@;6]D
M=6PN`"`@+6TL("TM;6]D=6QE/4U/1%5,("`@($=E;F5R;W9ANR!03U0@<_IB
M;W(@:6)A('!R92!T96YT;R`H2&]R9&4I(&UO9'5L+@`@("UN+"`M+6YO+6-O
M;7!E;F1I=6T@("`@3F5P<FEDX79ANR!N;W;I('!R96ML861Y(&1O('/Z:')N
M;W;I:&\@<_IB;W)U+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@3F5P;W6^
M[79ANR!S^FAR;F]V_2!S^F)O<BX`("`M<RP@+2US=&%T:7-T:6-S("`@("`@
M(%5L;[YINR"Y=&%T:7-T:6MY('!R96ML861U('8@;&]KX6QN;VT@<_IB;W)E
M+@`@("UT+"`M+71E<W0@("`@("`@(%IO8G)A>FF[('-P^KF[86[I('!R[6MA
M>GDL(&%L92!N97-P^KF[8;L@:6-H+@`@(&-L96%N=7`@("`@(%9YZ&ES=&F[
M(%!/('/Z8F]R>2`H;V1S='+A;FF[(&YE<')E;&^^96[I(&$@>F%S=&%R86SI
M('!O;&^^:WDI+@`@(&-O;6UI="`@("`@($]D;W-L8;L@<')E:VQA9'D@;F$@
M0U93('-E<G9E<BX`("!C;VUM:70M:&5L<"!/9&]S;&&[('/Z8F]R>2!P;VUO
M8V[M:V$@;F$@0U93('-E<G9E<BX`("!C;VUP96YD:75M("!:;F]V=2!V>71V
M;W)INR!S^FAR;F]V_2!S^F)O<BX@5F%R;W9A;FEE.B!T;W1O('!R97#MN64*
M("`@("`@("`@("`@("!A:W1UX6QN>2!S^FAR;F]V_2!S^F)O<BX`("!E>'1R
M86-T("`@("!'96YE<F]V8;L@N6%B;/-N>2!03R!S^F)O<F]V("@N<&]T*2X`
M("!H96QP("`@("`@("!:;V)R87IINR!T:65T;R!P;VUO8V[I(&EN9F]R;>%C
M:64N`"`@:6YI="`@("`@("`@5GET=F]R:;L@:F5D96X@86QE8F\@=FEA8V5R
M;R!03R!S^F)O<F]V('!R92!N;W;Z(&QO:V%L:7KA8VEU+@H@("`@("`@("`@
M("`@(%9A<F]V86YI93H@=&]T;R!P<F5P[;EE(&5X:7-T=6KZ8V4@4$\@<_IB
M;W)Y('1E:G1O(&QO:V%L:7KA8VEE+@`@(&UA:V4@("`@("`@(%9Y='9O<FF[
M(&)I;N%R;F4@34\@<_IB;W)Y('IO(+EP96-I9FEK;W9A;OUC:"!03R!S^F)O
M<F]V+@`@(&UA:V4M:&5L<"`@($]Z;F'H:;L@=KEE=&MY('!O;&^^:WD@=B!8
M34P@<_IB;W)E('!O;6]C;NUK82!A:V\@86MT=>%L;F4*("`@("`@("`@("`@
M("!A('!R:7!R879INR!S^F)O<B!N82#O86RY:64@<W!U<W1E;FEE('5P9&%T
M92UH96QP+B!M86ME+6AE;'`*("`@("`@("`@("`@("!B>2!S=&4@;6%L:2!P
M;W6^[79ANR!I8F$@4$\@=7!D871E+6AE;'`@82!K;VYT<F]L92!S^F)O<G4*
M("`@("`@("`@("`@("!P;VUO8V[M:V$N`&UE<F=E("`@("`@(%IL^NAINR!A
M:W1UX6QN>2!03R!S^F)O<B!S(&%K='7A;&YO=2"Y86)L\VYO=2!03R!S^F)O
M<G4N`"`@=7!D871E("`@("`@4W!U<W1INR!E>'1R86-T(&$@;65R9V4@>F$@
M<V5B;W4N`"`@=7!D871E+6AE;'`@5GEB<F&[(':Y971K>2!N;W;I(&$@>FUE
M;F5NZ2!P;VQOOFMY('H@86YG;&EC:^EH;R!834P@<_IB;W)U"B`@("`@("`@
M("`@("`@<&]M;V-N[6MA(&$@>FSZZ&F[(&EC:"!S(&5X:7-T=6KZ8VEM:2X`
M("8C,34Q.R!!<&QI:^%C:6$@)7,@:F4@<')I<')A=F5NX2!N82!V>6MO;F%N
M:64@;F%S;&5D=6KZ8VEC:"!O<&5RX6-I[2#Z9'*^8GDN`"`H<')E9"`E<R!D
M\F%M:2D`("A+;.%V97-O=N$@<VMR871K82`E<RD`("AO("5S(&1N[2D`*&1N
M97,I`"`H>F%J=')A*0`@*';H97)A*0`@<OUC:&QO<[L@`"5D("5S(&$@)7,`
M>F%P[7-A;OUC:"`E9"!B86IT;W8N`"5D('H@)60@<&]L;[YI96L@8F]L;R!O
M>FYAZ&5N_6-H(&%K;R!A:W1UX6QN90!P<F5D<&]V9>\@;F$@)60@9&[M`"5S
M("T@4&]Z;N%M:V$`061M:6YI<W1RX6-I82`E<P!/9'1L8>AO:R`E<P`E<R!+
M0@!/<&5RX6-I92#Z9'*^8GD@<')E(&%P;&EKX6-I=2`E<R`M(%!O='9R9&5N
M:64`3F%S=&%V96YI92`E<P!296=I<W1R;W9A;FEE(&1O(&%P;&EKX6-I92`E
M<P!0;V1M:65N:WD@<&]UOFET:6$@)7,`)7,@=;X@97AI<W1U:F4N`"5S('9O
M(';]N6ME("5S("5S`"5S(&YE97AI<W1U:F4@86QE8F\@<V$@;F5DX2!S<'5S
M=&F[+@!.96UOOFYO('IA<.US8;L@9&\@)7,N`%!OOF%D=6IE('-A("5S`"5S
M(&UI;OIT`"5S(&YE8F]L(&[A:F1E;OTN`"5S('-A(&YE<&]D87)I;&\@;N%J
M<[LN(%-P=7-T:71E(&YA:G!R("=T<F%N<VQA=&EO;B!E>'1R86-T)RX`)7,@
M8;X@)7,@>B`E<P!!9')E<^%R('!O=;[M=F%T9;5A("5S`$MA;&5N9.%R('!O
M=;[M=F%T9;5A("5S`%!O>F[A;6MY('!O=;[M=F%T9;5A("5S`%IO>FYA;2#Z
M;&]H('!O=;[M=F%T9;5A("5S`"5S.B`E<P`E<SH@;F5P;V1A<FEL;R!S82!N
M8>CM=&&[(&]V;.%D8>@Z("5S`"<E<R<@;FEE(&IE('!L871NX2!V;[5B82X`
M)R5S)R!N:64@:F4@<VMO;F9I9W5R;W9A;ND@=B!R96=I<W1R:2!(;W)D92X`
M>F]B<F%Z;W9AZ"!S=')O;74@)R5S)R!N96)O;"!NX6ID96[]+@!3:W5P:6YA
M("<E<R<@8F]L('!R:61A;N$@9&\@<WES=.EM=2X`4'+A=F\@)R5S)R!B;VQO
M('!R:61A;ND@9&\@<WES=.EM=2X`)R5S)R!N96)O;&\@;6^^;ND@=GET=F]R
M:;LZ("5S+@`L('8@;N%R87IO8V@@)7,@)7,`+"!P<F5M96YNX2!V(')O>G-A
M:'4@)7,@8;X@)7,`+2T@=GEB97)T92!S:2`M+0`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T`,3(M:&]D:6YO=OT@9F]R;>%T`#(T+6AO9&EN;W;](&9O
M<FWA=``R-"!H;V3M;@`\4W#DNP!0<NUK87H@/&=E='1E>'0^(&YE8F]L('5Z
M879R973]('8@<_IB;W)E("5S+@I:8>AI871O:R!P<NUK87IU(&[A:F1E;OT@
M;F$@<FEA9&MU("5D+@!0<F4@=&5N=&\@8FQO:R!J92!P;[YA9&]V86[](&1A
M=&%BX7IO=OT@8F%C:V5N9"X`5GES:WET;&$@<V$@>N%V8;YNX2!C:'EB80!.
M82!Z8;EI9G)O=F%N:64@<W!RX79Y(&IE('!OOF%D;W9A;OT@=F5R96IN_2!0
M2%`@:[7ZZ"X`3F$@;W9E<F5N:64@<&]D<.US86YE:B!S<'+A=GD@:F4@<&^^
M861O=F%N_2!V97)E:F[](%!'4"!KM?KH+@!.82!D9;EI9G)O=F%N:64@<W!R
MX79Y('/Z('!O=')E8F[I.B!V97)E:F[](%!'4"!KM?KH+"!P<FEVX71N>2!0
M1U`@:[7ZZ"!A(&AE<VQO+@!.82!P;V1P[7-A;FEE('-P<N%V>2!S^B!P;[YA
M9&]V86[I.B!V<F5J;OT@4$=0(&NU^N@L('!R:7;A=&YY(%!'4"!KM?KH(&$@
M:&5S;&\N`$YA(&1EN6EF<F]V86YI92!S<'+A=GD@<_H@<&^^861O=F%NZ3H@
M=F5R96IN_2!3+TU)344@:[7ZZ"P@<')I=N%T;GD@4R]-24U%(&NU^N@@82!H
M97-L;RX`3F$@<&]D<.US86YI92!S<'+A=GD@<_H@<&^^861O=F%NZ3H@=F5R
M96IN_2!3+TU)344@:[7ZZ"P@<')I=N%T;GD@4R]-24U%(&NU^N@@82!H97-L
M;RX`3F$@>F&Y:69R;W9A;FEE('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J
M;OT@4TU)344@:[7ZZ"X`0VAY8F$@041322`E<RX`4')E9'!O;'5D;NUM(&]B
M;&%K>0!0<F5D<&]L=61N[6T@M6%H:_T@9.&^[P!0<F5D<&]L=61N[6T@9.&^
M[P!0<F5D<&]L=61N[6T@<')E:.%N:WD`4')E9'!O;'5D;NUM('-N96AO=ND@
M<')E:.%N:WD`,3(@:&]D[6X`05!)($E$`$\@=&]M=&\@961I=&]R90!/+BXN
M`$%B<V]L^G1N>2!S<&]D;VL`06)S;VSZ=&YY('-T<F5D`%!R[7-T=7`@>F%M
M:65T;G5T_2X`4')I('9Y=';A<F%N[2!61E,@861R97/A<F$@8F]L('IA;6EE
M=&YU=/T@<'+M<W1U<"X`4')I('9Y=';A<F%N[2!61E,@<_IB;W)U(&)O;"!Z
M86UI971N=73]('!R[7-T=7`N`$AE<VQO('!R92#ZZ&5T`-KH970@>F%B;&]K
M;W9A;OTN`-KH=&]V86YI90!0<FED8;L`4')I9&&[('!O9')I861E;OH@<VMU
M<&EN=0!0<FED8;L@<&]D<FEA9&5NZ2!P<N%V;P!0<FED8;LZ`%!R:61ANR!S
M:W5P:6YU`%!R:61ANR!N;W;I('!RX79O`%!R:61ANR!D8^ER<VMU('-K=7!I
M;G4@9&\@)R5S)P!0<FED8;L@9&/I<G-K92!P<N%V;R!D;R`G)7,G`%!R:61A
MNR!P;W6^[79A=&6U83H`4')I9&&[('-TY7!E8P!0<FED8;L@Z&QE;F]V`%!R
M:61ANR!PX7(`4')I9&&[(&UE;G4@)7,@86MO(&)OZ&[]('!A;F5L($UO>FEL
M;'D`4')I9&&[(&1O(&%D<F5SX7)A.@!0<FED8;L@9&\@;?1J:&\@861R97/A
M<F$`4')I9&&[('!O=;[M=F%T9;5A`"<E<R<@8F]L('!R:61A;OT@9&\@<WES
M=.EM=2P@86QE(&YE;6^^;F\@<')I9&&[(.]A;+EI92!P<FEH;&%S;W9A8VEE
M(&EN9F]R;>%C:64Z("5S+@`G)7,G(&)O;"!P<FED86[](&1O('-Y<W3I;74N
M(%1E<F%Z('-A(&WTOF5T92!P<FEH;.%S:;LN`%!R:63A=F%J^B!S82!N;W;I
M('/Z8F]R>2!D;R#Z;&^^:7-K83H`4')I9.%V86YI92!P;W6^[79A=&6U;W8@
M:F4@>F%KX7IA;NDN`$%D<F5S80!!9')E<^%R`$%D;6EN:7-T<N%C:6$@+2!N
M87-T879E;FEE('!RX78@<')E(&EN_6-H('!O=;[M=F%T9;5O=@!!9&UI;FES
M='+A8VEA`%)E:VQA;7D`069G86YI<W1A;@!!;&+A;G-K;P!!;+[M<G-K;P!!
M;&EA<P!:87)O=FYANP!:87)O=FYA;FEE.@!6N65T:WD`5KEE=&-I(&%U=&5N
M=&EF:6MO=F%N[2!P;W6^[79A=&5L:6$`5KEE=&MY('-K=7!I;GD`5KEE=&MY
M('!RX79A`%:Y971K>2"Y='ER:2!S=')A;GD`4&]V;VQINR!V:6%C97+I(&%D
M<F5S>0!0;W9O;&F[(&YA<W1A=F5N:64@='EP=2!Z;W)A9&5NZ6AO('IO>FYA
M;74_`%6^(&5X:7-T=6IE`$%L=&5R;F%T[79N92!P<FEH;&%S;W9A8VEE(&UE
M;F\@24U34`!!;'1E<FYA=.UV;F4@:&5S;&\@24U34`!!;'1E<FYA=.UV;F4@
M<&]UONUV871EM7-KZ2!M96YO($E-4U``06QT97)N873M=FYA(&4M;6%I;&]V
MX2!A9')E<V$`06QT97)N873M=FYE(+EA8FSS;GD`06QT97)N873M=FYY('1E
M>'0Z`$%M97)I8VOA(%-A;6]A`$)O;&$@>F%D86[A(&YE<&QA=&[A(&AO9&YO
M=&$`3F%S=&%L82!N97INX6UA(&-H>6)A+@!!;F1O<G)A`$%N9V]L80!!;F=U
M:6QL80!!;F]N>6UNZ2!P<F]X>0!/9'!O=F7O`$%N=&%R:W1I:V$`06YT:6=U
M82!A($)A<F)U9&$`07!L:6OA8VEA`%IO>FYA;2!A<&QI:^%C:>T`07!L:6OA
M8VEA(&IE('!R:7!R879E;N$N`$%P;&EK;W9ANR!N82!P;V1R:6%D96[I('ID
M:66U86[I('!R:67H:6YK>0!38VAVX6QINP!0<FEB;&F^;N$@=F6U:V]SNP!!
M<'+M;`!69;5K;W.[(&%R8VCM=G4`365N;R!A<F-H[79U`$YA;WIA:B!C:&-E
M=&4@=GEM87IANR"^:6%D;W.[(&\@<')I:&SA<V5N:64@)R5S)S\`3F%O>F%J
M(&-H8V5T92!V>6UA>F&[("<E<R<@82!VN65T:WD@<&]D<VMU<&EN>3\`07)G
M96YT[6YA`$%R;>EN<VMO`%5M96YI90!!<G5B80!/<W1R;W8@07-C96YS:6]N
M`$%S8VEI('5M96YI90#!>FEA+U!A8VEF:6-K_2!R96=I\VX`5GF^861O=F&[
M('!O='9R9&5N:64@<')E9"!V>6MO;F%N[6T@;W!E<N%C:>T@^F1ROF)Y/P!0
M;VMU<R!O('9Y;6%Z86YI92!N965X:7-T=6KZ8V5J('-K=7!I;GDN`%!O:W5S
M(&\@=GEM87IA;FEE(&YE97AI<W1U:OIC96AO('!RX79A+@!0;VMU<R!O(/IP
M<F%V=2!N965X:7-T=6KZ8V5H;R!P<N%V82X`4&]K=7,@;R#Z<')A=G4@;F5E
M>&ES='5J^F-E:&\@>F1I9;5A;NEH;R!O8FIE:W1U+@!!=')I8OIT>0!!=6=U
M<W0`075S='+A;&EA`%)A:_IS:V\`075T:%]C>7)S<6PZ(%!OOF%D;W9A;ND@
M<F]ZN>UR96YI92!I;6%P(&YE8F]L;R!NX6ID96[I+@!!=71H7V-Y<G5S.B!B
M86-K96YD(&YE;>$@<&^^861O=F%NZ2!S8VAO<&YO<W1I+@!!=71H7V-Y<G5S
M.B!P;[YA9&]V86[I(')O>KGM<F5N:64@:6UA<"!N96)O;&\@;N%J9&5NZ2X`
M075T:%]F='`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!&5%`@;F5B;VQO(&[A
M:F1E;NDN(%-K;VUP:6QU:G1E(%!(4"!S('!R97#M;F'H;VT@+2UE;F%B;&4M
M9G1P+@!!=71H7VEM87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!)34%0(&YE
M8F]L;R!NX6ID96[I+@!!=71H7VMR8C4Z('!OOF%D;W9A;ND@<F]ZN>UR96YI
M92!K<F(U(&YE8F]L;R!NX6ID96[I+@!!=71H7VQD87`Z('!OOF%D;W9A;ND@
M<F]ZN>UR96YI92!,1$%0(&YE8F]L;R!NX6ID96[I+@!!=71H7VQD87`Z($YE
M<&]D87)I;&\@<V$@<')I9&&[('!O=;[M=F%T9;5A("5S+B!397)V97(@;V1P
M;W9E9&%L.B``075T:%]L9&%P.B!N97!O9&%R:6QO('-A(&]D<W1RX6YINR!P
M;W6^[79A=&6U82`E<P!!=71H7VQD87`Z(&YE<&]D87)I;&\@<V$@86MT=6%L
M:7IO=F&[('!O=;[M=F%T9;5A("5S`$%U=&A?;6-A;#H@<&^^861O=F%NZ2!R
M;WJY[7)E;FEE($U#04P@;F5B;VQO(&[A:F1E;NDN`$%U=&A?<VUB875T:#H@
M<&^^861O=F%NZ2!R;WJY[7)E;FEE('-M8F%U=&@@;F5B;VQO(&[A:F1E;NDN
M`$%U=&5N=&EF:6OA8VEA('IL>6AA;&$`075T96YT:69I:^%C:6$@>FQY:&%L
M82X@)7,`4V5R=F5R(%)!1$E54R!Z86UI971O;"!A=71E;G1I9FEKX6-I=2X`
M075T96YT:69I:^%C:6$@<&]M;V-O=2!&5%`@<V5R=F5R;VT@>FQY:&%L82X`
M1&]S='5P;ND@<&]L;[YK>3H`07IE<F)A:F2^86X`0D]&2"!%>&-U<V5S`$)A
M8VME;F0@;FEE(&IE('-P<N%V;F4@:6UP;&5M96YT;W9A;OTN`%!O>F%D:64`
M1F%R8F$@<&]Z861I80!:;.D@:&5S;&\@<')E(&ME<F)E<F]S+@!:;.D@<&]U
MONUV871EM7-KZ2!M96YO('!R92!K97)B97)O<RX`0F%H86UY`$)A:')A:FX`
M0F%N9VQA9.FY`$)A<F)A9&]S`%!R:67H:6YO:R!S(&=R869I:V]U("<E<R<@
M;F5B;VP@;N%J9&5N_2X`6N%K;&%D;OT@<FEA9&]K`$)I96QO<G5S:V\`0F5L
M9VEC:V\`0F5L:7IE`$)E;FEN`$)E<FUU9'D`0G5TX6X`3F%R;V1E;FEN>0!"
M;&]K("(E<R(@87!L:6OA8VEE("(E<R(@;F5B;VP@;N%J9&5N_2X`3F%S=&%V
M96YI82!B;&]K=0!4>7`@8FQO:W4`5'7H;ND`0F]L[79I80!:X6QOOFMY`$]K
M<F%J`*GM<FMA(&]K<F%J83H`3VMR86IE`$)O<VYA(&$@2&5R8V5G;W9I;F$`
M3V)E`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87KM;&EA`$)R
M:71S:^D@^GIE;6EE('8@26YD:6-K;VT@;V-EX6YE`$)R=6YE:2!$87)U<W-A
M;&%M`%9Y=';A<F%J^B!S82!-3R!S^F)O<GD@<')E(&UO9'5L("5S+BXN`%9Y
M=';A<F$@<V$@;&]K86QI>N%C:6$@)7,N+BX@`$)U;&AA<G-K;P!:;WIN86T@
M<R!O9'+AOFMA;6D`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!$:7-T
M<FEB=>ANZ2!B;V1Y($-23`!6;&%S=&YO<W1I(%]B=6YK>2XN+@!);FEC:6%L
M:7KA8VEA('9Y<F]V;N%V86-E:B!P86WD=&D@;F5B;VQA(&1O:V]NZ&5NX2X`
M2V%L96YDX7(`0F5Z=F5T<FEE`$MA;6)O9+YA`$MA;65R=6X`3F5P;V1A<FEL
M;R!S82!A=71O;6%T:6-K>2!O8FYO=FF[(&AE<VQO+"!K;VYT86MT=6IT92!S
M=F]J:&\@861M:6YI<W1RX71O<F$N`$YE<&]D87)I;&\@<V$@<W!O:FF[(',@
M24U!4"!S97)V97)O;3H@)7,`2V%N861A`%IR=;EINP!:<G6Y:;L@<W!RX79U
M(&\@<')O8FSI;64`3F5P;V1A<FEL;R!S82!V>6UA>F&[('/Z8F]R("(E<R(N
M`$YE<&]D87)I;&\@<V$@;N%J<[L@9&_H87-N_2!A9')E<^%R+@!.96UOOFYO
M('!O:W)AZ&]V8;L@8F5Z('!A<F%M971R82`G=&%R9V5T1FEL92<N`$YE<&]D
M87)I;&\@<V$@;V1S='+A;FF[(&%D<F5SX7(@(B5S(BX`3F5M;[YN;R!O9'-T
M<N%N:;LL(&5X:7-T=6IE("5D(&YA<VQE9&]V;NUK;W8N`$YE;6^^;F\@<')E
M=7-P;W)I861ANRP@<&_H970@<&]L;[YI96L@<')E('!R975S<&]R:6%D86YI
M92!N97/Z:&QA<^T@<R!P;^AT;VT@=6QOOF5N_6-H('!O;&^^:65K+@!.97!O
M9&%R:6QO('-A('-M97)O=F&[('-P<N%V=2!N82!U<NAE;ND@Z.US;&\N`$MA
M<'9E<F1S:^D@;W-T<F]V>0!4:71U;&]K`$MA=&5G\W)I92!A('!O<&ES:WD`
M2V%J;6%N<VOI(&]S=')O=GD`36]B:6QN_2!T96QE9O-N`%9L87-T;F]S=&D@
M8G5N:WD`5GEP;&YE;FEE(&)U;FMY.@!6;&%S=&YO<W1I(&)U;FMY`%)O>F]S
M='5P(&)U;FEE:SH`36]B:6QN_2!T96QE9O-N`$1O('-T<F5D=0!3=')E9&]A
M9G)I8VOA(')E<'5B;&EK80!0;V1R;V)NZ2!I;F9O<FWA8VEE(&\@8V5R=&EF
M:6OA=&4`5FQA<W1N[6L@8V5R=&EF:6OA='4`4&]L:71I:WD@<')E(&-E<G1I
M9FEKX71Y`,AA9`!:;65N:;L`6FUE;FF[(&AE<VQO`%IM96YINR!H97-L;R!N
M83H`3F%S=&%V96YI92!M96YA(&$@861R:65S+"!K=&]RZ2!V:61I82"U=61I
M82P@:V7O(.CM=&%J^B!A(&]D<&]V961A:OH@;F$@5F&Y92!E+6UA:6QY+@!:
M;65N:;L@5F&Y92!H97-L;P!-96[M('-A(&AE<VQO(&YA("5S`%IN86L`4U]K
M;VYT<F]L;W9ANR!L:6YK=2XN+@!/>FYAZ'1E(+ET=F]RZ&5K('!R:2!O<&5R
MX6-IX6-H+"!K=&]RZ2!C:&-E=&4@=GEK;VYANR!T97)A>BX`0VAI;&4`R.UN
M80!:=F^U=&4@<VD@:&5S;&\`6G9OM71E('-I('!O=;[M=F%T9;5S:^D@;65N
M;P!6>6)E<G1E('-P]'-O8B!Z;V)R87IO=F%N:6$@9.%T=6UO=CH`5GEB97)T
M92!T>7`@N73];'4@>F]Z;F%M=2`H<')E('IO<F%D96[I('IO>FYA;7DI`%9I
M86YOZ&[](&]S=')O=@!$969I;NUC:6$@=')I961Y("5S(&YE8F]L82!NX6ID
M96[A+@#(:7-T:6$@<V$@4$\@<_IB;W)Y('!R92!M;V1U;"`E<RXN+@#(:7-T
M[2!S82!L;VMA;&EZX6-I82`E<RXN+B``2F%S;F\`3V1S='+A;FF[('!R[6MA
M>GD@35-/9F9I8V4`3V1S='+A;FF[('!O=;[M=F%T9;5A.B`E<P!/9'-T<N%N
M:;L@<&]UONUV871EM6$`5GEM87IANR!P;W6^[79A=&6U<VOI(/ID86IE`$YE
M<VOT<B!J87-N;P!+;&EK;FET92!P<F4@<&]K<F'H;W9A;FEE`$-L:6-K871E
M;&P@8V5Z($A45%``6F%T=F]R:;L@;VMN;P!/8FQA:WD`4N%N;R!O8FQAZ&YO
M`$]B;&'H;F\`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`6F)A;&F[(&)OZ&[]
M('!A;F5L`%IB86QE;ND@;VMR86IE`$MO;'5M8FEA`$9A<F)A`%;]8F5R(&9A
M<F)Y`%;]8F5R(&9A<F)Y`%-TY7!C93H`3F%D<&ES>2!S=.5P8V]V`$MO;6EK
M<P!0<NUK87H`4'+M:V%Z;W;](&EN=&5R<')E=&5R`%!A<F%M971R92!P<NUK
M87IU.@!0<NUK87IY.@!+;VUE;G3A<@!/9&]S:65L82!S83H`0F6^;ND@;65N
M;P!+;VUO<GD`4W!O;&_H;F]SNP!0[7-ANR!S<'+A=G4@*"5S*0!0;^CM=&'H
M90!0;V1M:65N:WD`4F]Z9&EE;'D@=B!K;VYF:6=U<N%C:6D`2V]N9FEG=7+A
M8VEA(&IE(&YE86MT=>%L;F$N`$MO;F9I9W5R;W9ANR`E<P!0;W1V<N]T92!H
M97-L;P!0;W1V<N]T92!N;W;I(&AE<VQO.@!+;VYG;P!$96UO:W)A=&EC:^$@
M<F5P=6)L:6MA($MO;F=O`%-P;VIE;FEE('IL>6AA;&\N`%-P;VIE;FEE('IL
M>6AA;&\Z(`!+M?KH(&)O;"!Z86UI971N=73]('-E<G9E<F]M('9E<F5J;OUC
M:"!KM?KH;W8N`$NU^N@@8F]L('IA;6EE=&YU=/T@<V5R=F5R;VT@=F5R96IN
M_6-H(&NU^NAO=BX@1/1V;V0Z("5S("@E<RD`4W!O:F5N:64@<R!&5%`@<V5R
M=F5R;VT@>FQY:&%L;RX`2V]N=&%K='D@8F]L:2#Z<W!EN6YE('9L;[YE;N$@
M9&\@5N&Y:&\@861R97/A<F$N`$]B<V%H("<E<R<`4&]K<F'H;W9ANP!#;V]K
M;W9E(&]S=')O=GD`0V]O:VEE`$MO<.UR;W9ANP!+;W#M<F]V8;L@=OUB97(`
M2V]P[7)U:F4@<V$@)7,@9&\@)7,`2V]S=&%R:6MA`%!O8G)EOFEE('-L;VYO
M=FEN>0!.97!O9&%R:6QO('-A('IAN6EF<F]V8;L@<W!RX79U('!O;6]C;W4@
M4$=0+@!.97!O9&%R:6QO('-A('!O9'#M<V&[('-P<N%V=2!P;VUO8V]U(%!'
M4"X`3F5P;V1A<FEL;R!S82!Z8;EI9G)O=F&[('-P<N%V=2!P;VUO8V]U(%,O
M34E-12X`3F5P;V1A<FEL;R!S82!P;V1P[7-ANR!S<'+A=G4@<&]M;V-O=2!3
M+TU)344N`$YE<&]D87)I;&\@<V$@<')I9&&[(&MO;G1A:W0N("5S+@!.97!O
M9&%R:6QO('-A('!R:7!O:FF[(&L@3$1!4"!S97)V97)U+@!.97!O9&%R:6QO
M('-A('!R:6ALX7-INR!K(&QD87`@<V5R=F5R=0!.97!O9&%R:6QO('-A(&]V
M97)INR!Z;W-T871O:R!N82#ZZ'1E+B`E<P!.97!O9&%R:6QO('-A('!R:7!O
M:FF[(&L@;&1A<"!S97)V97)U`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!S
M97)V97)U("<E<R<@<&]M;V-O=2!&5%`Z("5S`$YE<&]D87)I;&\@<V$@:V]P
M[7)O=F&[("5S(&1O("5S`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@>F]Z;F%M
M('!R[6IE;6-O=BX@)7,`3F5P;V1A<FEL;R!S82!V>71V;W)INR!A9')E<^%R
M('!R92!L;VMA;&EZX6-I=2`E<SH`3F5P;V1A<FEL;R!S82!D9;EI9G)O=F&[
M(%!'4"#Z9&%J92X`3F5P;V1A<FEL;R!S82!D9;EI9G)O=F&[(%,O34E-12#Z
M9&%J92X`3F5P;V1A<FEL;R!S82!V>6UA>F&[(&MO;G1A:W0N("5S`$YE<&]D
M87)I;&\@<V$@=GEM87IANR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R
M:6QO('-A('9Y;6%Z8;L@<VMR:7!T(&YA('5P9W)A9&4@:V]N9FEG=7+A8VEE
M("<E<R<N`$YE<&]D87)I;&\@<V$@=7+H:;L@92UM86EL;W;Z(&%D<F5S=2!P
M<NUJ96UC=2X`3F5P;V1A<FEL;R!S82!S=&EA:&YUNR!C96S](&%D<F5SX7(N
M`$YE<&]D87)I;&\@<V$@>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@<'+M:F5M
M8V]V+@!.97!O9&%R:6QO('-A('KM<VMANR!K;VUP;&5T;OT@>F]Z;F%M('IO
M>FYA;6]V('!R[6IE;6-O=BX`3F5P;V1A<FEL;R!S82!N8>CM=&&[('-T<F%T
MZ6=I=2`G)7,G+@!.97!O9&%R:6QO('-A(&UK9&ER("<E<R<N`$YE<&]D87)I
M;&\@<V$@>NUS:V&[('9E<F5J;OT@:[7ZZ"!Z;R!S97)V97)A(&NU^NAO=BX`
M3F5P;V1A<FEL;R!S82!O='9O<FF[("5S+@!.97!O9&%R:6QO('-A(&]T=F]R
M:;L@)R5S)R!P<F4@>N%P:7,N`$YE<&]D87)I;&\@<V$@;W1V;W)INR!M;V1U
M;"!-86EN=&5N86YC95]487-K("5S`$YE<&]D87)I;&\@<V$@;W1V;W)INR!A
M9')E<^%R("<E<R<N`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!P<F]G<F%M
M=2!S;6)P87-S=V0N`$YE<&]D87)I;&\@<V$@<')EZ.UT8;L@)7,N`$YE<&]D
M87)I;&\@<V$@;V)N;W9INR!H97-L;R!Z861A;NEH;R!P;W6^[79A=&6U82X@
M3FEE:W1O<ND@86QE8F\@=KEE=&MY('!O9')O8FYO<W1I(&YI92!S^B!S<'+A
M=FYE+B!3:_IS=&4@=&\@>FYO=G4@86QE8F\@:V]N=&%K='5J=&4@5N&Y:&\@
M861M:6YI<W1RX71O<F$L(&%K('!O=')E8G5J971E('!O;6]C+@!.96UOOFYO
M('KM<VMANR!!0TP`3F5P;V1A<FEL;R!S82!Z[7-K8;L@861R97/A<BX@)7,`
M3F5P;V1A<FEL;R!S82!Z[7-K8;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,`3F5P
M;V1A<FEL;R!S82!Z[7-K8;L@>F]Z;F%M>2!P<NUJ96UC;W8@)7,`3F5M;[YN
M;R!Z[7-K8;L@:6YF;W)MX6-I92!O('9L87-T;F]S=&EA8V@@<V5R=F5R80!.
M97!O9&%R:6QO('-A('9RX71INR!K;VYF:6=U<N%C:74N`$YE<&]D87)I;&\@
M<V$@<W!U<W1INR!R;61I<B`G)7,G+@!.97!O9&%R:6QO('-A('5L;[YINR!K
M;VYF:6=U<N%C:74@)7,N`$YE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K
M;VYF:6=U<N%C:64N`$YE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K;VYF
M:6=U<N%C:64Z("5S`$YE<&]D87)I;&\@<V$@=6QOOFF[('-K<FEP="!N82!U
M<&=R861E(&MO;F9I9W5RX6-I92!D;SH@)R5S)RX`3F5P;V1A<FEL;R!S82!U
M;&^^:;L@>N%L;[YN_2!K;VYF:6=U<F'H;OT@<_IB;W(@)7,N`$YE<&]D87)I
M;&\@<V$@=6QOOFF[(&MO;F9I9W5R8>AN_2!S^F)O<B`E<RX@3?2^971E('!O
M=;YINR!J961N=2!Z(&UOOFYO<W3M(&YA('5L;[YE;FEE(&OS9'4@<W#DNR!N
M82`E<R!A;&5B;R!S:V]P[7)O=F&[(')UZ&YE(&OS9"!U=F5D96[](&YIOKEI
M92!D;R`E<RX`3F5P;V1A<FEL;R!S82!HM6%D8;L@;F$@3$1!4"!S97)V97)I
M+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@)R5S)RX`3F5P;V1A<FEL;R!S82!A
M:W1U86QI>F]V8;L@:V]N=&%K="X@)7,`3F5P;V1A<FEL;R!S82!A:W1U86QI
M>F]V8;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,`3F5P;V1A<FEL;R!S82!Z87#M
M<V&[(&MO;F9I9W5RX6-I=2!P<F4@)R5S)SH@)7,`3F5P;V1A<FEL;R!S82!N
MX6ISNR!B;^AN_2!P86YE;"!-;WII;&QY+B!3:V]N=')O;'5J=&4L(+YE(&IE
M(&)OZ&[]('!A;F5L(&]T=F]R96[]+@!0;W6^[79A=&6U;W9I("<E<R<@<V$@
M;F5P;V1A<FEL;R!P<FED8;L@<'+A=F$@<')E('!R:67H:6YO:R`G)7,G.B`E
M<P!0;^CM=&%N_2!T97AT`$MR86II;F$`2W5R>GD`5GET=F]R:;L`5GET=F]R
M:;L@;&EN:W4`5GET=F]R:;L@;F]V_0!6>71V;W)INR!P;V1P<FEEZ&EN;VL`
M4'+A=F$@='9O<F-U`,CM<VQO(&MR961I=&YE:B!K87)T>0!#:&]R=N%T<VMO
M`$MU8F$`06MT=>%L;F4@-"!FX7IY`$%K='7A;&YY(.AA<P!!:W1UX6QN82!5
M4DP@:F4`06MT=>%L;F4@<&_H87-I90!!:W1UX6QN92!P;V1M:65N:WDZ(`!!
M:W1UX6QN>2"Y=/UL`$YA<W1A=F5N:64@^FQO:"P@:W1O<ND@<V$@<W#ZN;MA
M:OH@<')I('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S+@!6>7-T<FEH;OJ[
M`%9Y<W1R:6AN^KL@=OUB97(`0WEP<G5S`,AE<VOA(')E<'5B;&EK80!$1`!$
M96YN90!0<F5Z97)AZ"!DX71O=NEH;R!S=')O;74@*$1A=&%4<F5E*0!$X71U
M;0!$X71U;2!P<FEJ871I80!6_6)E<B!DX71U;74`1&7R`$]?9'-T<N%N:;L@
M<W3E<&5C`$1E8V5M8F5R`$1E<VEA=&MO=ND@Z.US;&$`6FUE;KEINR!O9'-A
M9&5N:64`4')E9&YA<W1A=F5NZ2!H;V1N;W1Y`%!R961N87-T879E;N$@9F%R
M8F$`5F&Y82!P<F5D;F%S=&%V96[A(&ED96YT:71A`*ET86YD87)D;ND@<'+A
M=F$`J71A;F1A<F1NZ2!P<N%V80!$969I;NUC:64`5GEM87IANP!6>6UA>F&[
M('-K=7!I;G4`5GEM87IANR!P<N%V;P!6>6UA>F&[(&$@;V1S='+A;FF[('-P
M<N%V>0!6>6UA>F&[(&)U;FMU`%9Y;6%Z8;L@<W3E<&5C`%9Y;6%Z8;L@97AI
M<W1U:OIC=2!A;'1E<FYA=.UV;G4@N6%B;/-N=0!6>6UA>F&[('!RX79A('!R
M92`G)7,G`$YA;WIA:B!C:&-E=&4@=GEM87IANR`G)7,G(&$@=KEE=&MY(&IE
M:&\@<&]D<'+A=F$_`%9Y;6%Z8;L@<FEA9&]K`%9Y;6%Z8;L@=GEB<F%N^B!I
M9&5N=&ET=0!6>6UA>F&[(&%K='7A;&YY('-TY7!E8P!6>6UA>F&[(&%K='7A
M;&YY(')I861O:P!.86]Z86H@8VAC971E('9Y;6%Z8;L@=&]T;R!P<N%V;R!A
M(':Y971K>2!J96AO('!O9'!RX79A/P!3:W)I<'0@;F$@=7!G<F%D92!K;VYF
M:6=U<N%C:64@)R5S)R!B;VP@=GEM87IA;OTN`,AA<R!D;W)UZ&5N:6$`1.%N
M<VMO`%!O<.VY=&4@<')O8FSI;0!0;W!I<P!0;V1R;V)N;W-T:2`H=&EEOB!V
M(&QO9V]V86-O;2!S^F)O<F4@2&]R9&4I`$1E=&%I;'D@8F]L:2!Z87IN86UE
M;F%NZ2!P<F4@861M:6YI<W1RX71O<F$N`%;]=F]J`%)O<V[](&)O9`!2;W-N
M_2!B;V0@>F$@<&]S;&5D;OH@:&]D:6YU.B``4F]S;OT@8F]D.B``4VUE<B!Z
MM6%V82!D;W!R879A`%-M97(@<W!R879A(&1OM6%V80!!9')E<^%R`%IO8G)A
M>F]V8;L@Z&%S('8@,C0M:&]D:6YO=F]M(&9O<FWA=&4_`$YA<W1A=F5N:64@
M>F]B<F%Z96YI80!:;V)R87IINR!P<F5D<&]V9>\@*%1!1BD`1F]R;>%T('IO
M8G)A>F5N:6$`4&]T=G)D96YI92!O(&1O<G7H96[M`$2^:6)U='-K;P!.979Y
M;6%Z8;L`3F5P;W6^[79A:G1E('!R:6%M;R!M86EN=&5N86YC92YP:'``3V)S
M86AU:F4@<')V_2!R:6%D;VL@;N%Z=GD@<&]L[3\@06L@X6YO+"!Z8;EK<G1N
M:71E('!O;.WH:V\Z(`!$;VUI;FEC80!$;VUI;FEKX6YS:V$@<F5P=6)L:6MA
M`%-T:6%H;G6[`%-T:6%H;G6[("5S`%-T:6%H;G6[('9Y9V5N97)O=F%N^B!K
M;VYF:6=U<N%C:74@86MO(%!(4"!S:W)I<'0N`%IO>FYA;2!S(';]8F5R;VT`
M1')O9WD`12UM86EL`$524@!%:W;A9&]R`%5P<F%V:;L`57!R879INR!B;&]K
M`%5P<F%V:;L@<VMU<&EN=0!5<')A=FF[('!RX79O`%5P<F%V:;L@<'+A=F$`
M57!R879INR!P<N%V82!P<F4@)7,`57!R879INR!N87-T879E;FEA('!R93H`
M57!R879INR!P<N%V82!P<F4@)7,`57!R879INR!P<N%V82!P<F4@)R5S)P!6
M>F1E;.%V86YI90!%9WEP=`!386QVX61O<@!%;&5M96YT+BXN`$5M`$5M86EL
M`$5M86EL;W;A(&%D<F5S83H`12UM86EL;W;I(&%D<F5S>2!M=7-I82!B>;L@
M<F]V;F%KZ2X`12UM86EL(',@<&]T=G)D96[M;0!%;6]T:6MO;GD`4'+A>F1N
M82!S<'+A=F$N`%!RX7ID;GD@=OUS;&5D;VLN`%!RX7ID;F4@<&]D;6EE;FMY
M(&BU861A;FEA`%!O=F]L:;L@=FQOOF5N:64@;V)RX7IK;W8@>B!'86SI<FGM
M(&1O('1E>'1U/P!0;W9O;&F[(&MO;G1E>'1O=ND@;65N=2!P<F4@<')A=ND@
M=&QAZ&ED;&\_`$MO;FEE8R!R;VMA`%IVY.BY:;L@961I=&]R`%IA9&%J=&4@
M8F5Z<&7H;F]S=&[Z(&]TX7IK=2P@;F$@:W1O<OH@8G5D971E(&UU<VEENR!O
M9'!O=F5D8;L@86L@>F%B=61N971E(&AE<VQO+"!N87!R+B`G86MO('-A('9O
M;.$@;6]J92!Z=FEE<F%T:V\_)SH`6F%D86IT92!54DP@;V)RX7IK80!0;VQO
MOFEE:SH@)60@8V5L:V]V;RP@)60@86MT=>%L;GEC:"P@)60@;F]V_6-H+"`E
M9"!Z;65N96[]8V@L("5D(&YE>F[A;7EC:`!2;W9N[6MO=N$@1W5I;F5A`$5R
M:71R96$`0VAY8F$`3F%S=&%L82!C:'EB82!P<FD@<&]S:65L86[M(/ID86IO
M=B!P<F]G<F%M=2!S;6)P87-S=V0N`$-H>6)A('8@92UM86EL;W9E:B!S<'+A
M=F4N`$-H>6)A('!R:2!Z87!I<V]V86[M("<E<R<N`$-H>6)A.B``17-T\VYS
M:V\`171I\W!I80!%=&YI8VOI`$5U<O-P80!+8;YD_6-H(#$U(&UI;OIT`$MA
MOF3I(#(@;6EN^G1Y`$MAOF3]8V@@,S`@<V5K^FYD`$MAOF3]8V@@-2!M:6[Z
M=`!0<FD@:V&^9&]M('!R:6ALX7-E;NT`2V&^9/H@<&]L:&]D:6YU`$MAOF3Z
M(&UI;OIT=0!.87!R[6ML860Z`%-P=7-T:;L`4W#ZN;MA('-A.@!2;WIB86QI
MNP!2;WIB86QINR!B;^AN_2!P86YE;`!/Z&%KX79A('-A("<I)P!/Z&%KX79A
M('-A('-L;W9O(&%L96)O('!O9&UI96YK82!HM6%D86YI82!V(/IV;V1Z;W9K
MX6-H`$3A='5M(&5X<&ERX6-I90!%>'!O;F5N=`!6>6)E<N$@<V$@>B`E<RXN
M+@!&87)B82!T97AT=0!.86AR8;L@:V]N9FEG=7+A8VEU(&YA($944`!.97!O
M9&%R:6QO('-A('KM<VMANR!N87-T879E;FEA+@!.87-T86QA(&-H>6)A('!R
M:2!S<&]J96[M(',@3$1!4"!S97)V97)O;2X`3F%S=&%L82!C:'EB82!P<FD@
M<'+M<W1U<&4@:R!334(@<V5R=F5R=2X`3F5P;V1A<FEL;R!S82!K;W#M<F]V
M8;L@>B`B)7,B+@!.97!O9&%R:6QO('-A(&MO<.UR;W9ANR!D;R`B)7,B+@!.
M97!O9&%R:6QO('-A('9Y='9O<FF[(&YO=ND@4T%33"!S<&]J96YI92X`3F5P
M;V1A<FEL;R!S82!P<F5S=6[ZNR!D;R`B)7,B+@!.97!O9&%R:6QO('-A(&]V
M97)INR!S=&%RZ2!H97-L;RX`0VAY8F$@<')I('IM96YE(&AE<VQA(&YA("5S
M.B`E<P!$;V)RZ0!&86QK;&%N9'-KZ2!O<W1R;W9Y("A-86QV[6YY*0!&865R
M<VOI(&]S=')O=GD`6N%V8;YNX2!C:'EB83H`1F%X`$9E8G)UX7(`4&]C:70@
M=&5P;&]T>0!0;V-I="!T97!L;W1Y.B``36%LZ2!Z<N&^:WD`36%LZ2!S;F5H
M;W;I('!R96CA;FMY`$UA=&EC82!P;VSM`$9I9+YI`%!OZ&5T('/Z8F]R;W8Z
M("5S('/Z8F]R`%!OZ&5T('/Z8F]R;W8Z("5S('/Z8F]R;W8`4W!RX79C82!S
M^F)O<F]V`$UE;F\@<_IB;W)U`%;]8F5R('/Z8F]R=0!.86AR871I92!S^F)O
M<G4`3F%H<N%V86YI92!S^F)O<F]V(&YI92!J92!P;V1P;W)O=F%NZ2X`1FEL
M=')E`$;M;G-K;P!0<G;A('!O;&]V:6-A`%!R=N$@N71V<KL`4&5V;OT@<&]M
M97(`3W1OZ&F[`%!LX79A:OIC:2!T97AT`$AM;&$`4')I9>AI;F]K("5S(&YE
M97AI<W1U:F4`1F%R8F$@<.US;6$`4&]T<F%V80!0<F4@<')E:&QI861AZ&4L
M(&MT;W+I(&YE<&]D<&]R=6KZ(&]B<N%Z:WD`4')E9'!O=F7O("A4048I`%!R
M961P;W9E[R!N82!U=F5D96[]('!OZ&5T(&1N[2`H<&%MY'1A:G1E(&YA('1O
M+""^92!P<F5D<&]V9>\@:F4@<')E(&1N:2!A:B!N;V-I(&$@=&%K(&WTOF4@
M=F6U:^D@Z.US;&\@=GET=F]R:;L@=F6U;6D@N6ER;VO](&)L;VLI`%IA8G5D
M;&D@<W1E(&AE<VQO/P!&;W)M=6SA<F4`1F]R='5N80!4>7`@9F]R='5N>0!&
M;W)T=6YY`$9O<G1U;GD@,@!&\W)A`%!R97-M97)O=F%N:6$`3N%J9&5NZ2!A
M<&QI:^%C:64Z("5S`$[A:F1E;ND@861R97/A<F4Z`%!I80!2X6UC90!&<F%N
M8_IZ<VMO`$9R86YC^GIS:V\@*$5U<O-P82D`1G)A;F/Z>G-K82!'=6%Y86YA
M`$9R86YC^GIS:V$@4&]L>6[I>FEA`$9R86YC^GIS:V4@:G6^;ND@=&5R:73S
M<FGA`$]D`%IO('-M97)U(`#:<&QN_2!P;W!I<P!3<&QN`$-E;.D@;65N;SH`
M3F5P<F5S;ND`1V%B=6X`1V%LZ7)I82P@>B!K=&]R96H@8VAC971E('9Z:6&[
M(&]B<N%Z;VL`1V%LZ7)I83H`1V%M8FEA`$=E;F5R;W9ANR!K;VYF:6=U<N%C
M:74@<')E(&%P;&EKX6-I=2`E<P!'96YE<F]V86[](&OS9`!'96YE<G5J92!S
M82!S=&%V('!R92!M;V1U;"`E<RXN+@!'96]R9VEA`$YE;65C:V\`0VAY8F$@
M1V5T;W!T.B``1VAA;F$`1VEB<F%L=.%R`$MR<W1NZ2!M96YO`$]D;W-L8;L`
M1V]E9&5L`$BU861ANR!N82!';V]G;&4`3V1T:65N92"Y961E:@!'<NEC:V\`
M1W+S;G-K;P!'<F5N861A`$%D;6EN:7-T<N%C:6$@<VMU<.UN`$UE;N$@<VMU
M<.UN(&YE<VWZ(&)YNR!P<N%Z9&YE`%-K=7!I;F]VZ2!P<N%V80!3:W5P:6YY
M`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`4'+A=F$@86YO
M;GEM;OUC:"!P;W6^[79A=&6U;W8`4'+A=F$@86YO;GEM;OUC:"!P;W6^[79A
M=&6U;W8`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(
M5$U,`$A434Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@<&]S;&5D;OH@8G5N:W4@
M=B!R:6%D:W4N`$A434Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@<&]S;&5D;OT@
M<W3E<&5C('8@=&%B=;5K92X`2%1-3$%R96$@;F5D;W9O;.T@=GEM87IANR!P
M;W-L961N_2!R:6%D;VL@=B!T86)UM6ME+@!(5%10(&%U=&5N=&EF:6OA8VEA
M(&YE8F]L82!NX6ID96[A+@!(86ET:0!!;&=O<FET;75S(&AA<VAO=F%C96H@
M9G5N:V-I90!/<&%R`$AL879IZ&MA`$AE87)D;W8@;W-T<F]V(&$@36-$;VYA
M;&1O=F4@;W-T<F]V>0!6_;EK80!0;VUO8V[M:P!0;VUO8V[M:R!P<F4@<&]U
MONUV86YI92!E9&ET;W)A`%!O;6]C;NUK`%!O;6]C;N$@87!L:6OA8VEA(&YA
M('9Y='9O<F5N:64@82#Z9'*^8G4@<')E:VQA9&]V('!R92!S>7-TZ6T@2&]R
M9&4*82!J96AO(&%P;&EKX6-I92X*4')E('KA:VQA9&[I(&EN9F]R;>%C:64@
M<VD@<')EZ.UT86IT92!S^F)O<B!214%$344@=B!T;VUT;R!A9')E<^%R:2X`
M4&]L;V=UM6$`5'4@:F4@>F'H:6%T;VL@<_IB;W)U.@!6>7-O:^$`365NX2!P
M;VQOOFEE:R!H:7-T\W)I92!N97-M^B!B>;L@<'+A>F1N90!$;U]M;W8`5F%T
M:6OA;@!$;VUO=@!$;VWA8V$@861R97-A`%1E;&5F\VX@9&]M;W8`2&]N9'5R
M87,`2&]N9R!+;VYG`$AO<F1E`$=E;F5RX71O<B!P<F5K;&%D;W8@2&]R9&4`
M2&]R9&4O2V]L86(Z('8@<W!RX79E("5S(&)O;&D@;N%J9&5NZ2!N97!L871N
MZ2`E<R!834P@^F1A:F4`2&]R9&4O2V]L86(Z(',@;V)J96MT;VT@)7,@;F5K
M;W)EN7!O;F1U:F4@OFEA9&YA('-P<N%V82X`2&]R9&4O2V]L86(Z('8@<W!R
MX79E("5S(&YE8F]L(&[A:F1E;OT@OFEA9&5N(&]B:F5K="!T>7!U("5S`$AO
M<F1E+TMO;&%B.B#Z<W!EN6YE(&]D<W1RX6YE;ND@)7,@(B5S(@!(;W)D92]+
M;VQA8CH@^G-P9;EN92!S>6YC:')O;FEZ;W9A;ND@)7,@(B5S(@!(;W)D92]+
M;VQA8CH@:6YT96=RX6-I82!V>;YA9'5J92!02%`@<F]ZN>UR96YI92`G9&]M
M>&UL)P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!V>71V;W)INR!N;W;]
M(%A-3"!S=')O;2!P<F4@;V)J96MT("5S`$AO<F1E+TMO;&%B.B!N97!O9&%R
M:6QO('-A(&]D<W1RX6YINR`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P
M;V1A<FEL;R!S82!Z[7-K8;L@34E-12!)1"!P<F4@Z&%SNR!T>7!U("5S`$AO
M<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A('-Y;F-H<F]N:7IO=F&[("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A('-Y;F-H<F]N:7IO
M=F&[('ID:66U86[I(&]B:F5K='DZ("5S`$AO<F1E+TMO;&%B.B!N97INX6UY
M('ID:66U86[](&]B:F5K="`B)7,B`$AO<FEZ;VYTX6QN82#H:6%R80!(;W)I
M>F]N=.%L;F4@=GEP;&YE;FEE`$AO<FEZ;VYTX6QN93H`06MO('-T92!S82!S
M96T@9&]S=&%L:3\@*%!R;W/M;2!N86ALX7-T92$I`$MOM6MO('-TY7!C;W8@
M8VAC971E('IL^NAINS\`6F%D86IT92!P;^AE="!P;VSM("AS=.5P8V]V*3\`
M2V^U:V\@<FEA9&MO=B!C:&-E=&4@>FSZZ&F[/P!6;&AK;W.[`%9L:&MO<[LZ
M(`!(=6UO<FES=&D`36'O87)S:V\`3F5P;V1A<FEL;R!S82!V>71V;W)INR!)
M34%0('-C:'+A;FMU.B`E<P!.97!O9&%R:6QO('-A('9Y;6%Z8;L@24U!4"!S
M8VARX6YK=3H@)7,`3F5P;V1A<FEL;R!S82!V>71V;W)INR!)34%0(&MV\W1U
M.B`E<P!)4"!A9')E<V$`25`@861R97-A(&YI92!J92!D;W-T=7!NX2X`25`@
M861R97-A(&YI92!J92!V('+A;6-I(&1O=F]L96[I:&\@0TE$4B!B;&]K=2X`
M4&]R=;EE;FEE('!R879I9&QA(&\@<&5V;F5J($E0(&%D<F5S92X`5FQOOFF[
M(&NU^N@@7W!R960`27-L86YD`$EB82!I:V]N>0!):V]N>2!P<F4@)7,`26MO
M;GD@82!T97AT`$[A>F]V(&ED96YT:71Y.@!!:R!S82!N97IO8G)A>NT@:V]R
M96MT;F4L("5S(&$@;W1V;W+M('-A('8@;F]V;VT@;VMN92X`06L@;F5V:63M
M=&4@<')I('!O=;YI=.T@26YT97)N970@17AP;&]R97)A(+YI861N92!I:V]N
M>2P@<&]T<F5B=6IE=&4@>F&Y:W)T;OJ[('3Z=&\@=F^U8G4@<')E('9Y<&YU
M=&EE('!R:65S=FET;F]S=&D@4$Y'(&]B<N%Z:V]V+@!!:R!V:63M=&4@=/IT
M;R!S<'+A=G4@82!N979I9.UT92!O8G+A>F]K+"!O8G+A>F]K+"!K=&]R_2!S
M=&4@8VAC96QI(&YA:')ANRP@;F5M]+YE(&)YNR!Z;V)R87IE;OT@=F\@5F&Y
M;VT@<')E:&QI861AZ&DN`%5KX;YK82!O8G+A>FMA.@!54DP@;V)RX7IK80!5
M4DP@;V)RX7IK83H`3V)RX7IO:R!Z(&=A;.ER:64`3V)RX7IO:R!Z(&=A;.ER
M:64Z`$YA:')A=&EE(&]B<N%Z:W4`3V)RX7IK>0!);7!O<G0L(&MR;VL@)60`
M26UP;W)T;W9A;ND@<&]L93H@)7,`26UP;W)T;W9A;ND@<&]L:6$Z`%9L;[YI
MNR!KM?KH(%]Z80!.97-P<N%V;F4@:&5S;&\`0F]L('IA9&%N_2!N97-P<N%V
M;GD@:_-D(&%K8VEE+@!.97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&$O
M86QE8F\@:&5S;&\`3F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B
M;R!A;'1E<FYA=.UV;F$@861R97-A+B!3:_IS=&4@=&\@>FYO=G4@86QE8F\@
M:V]N=&%K='5J=&4@<W!RX79C=2!6X;EH;R!S>7-TZ6UU+"!A:R!P;W1R96)U
M:F5T92!P;VUO8RX`6G;DZ+EINR!O9'-A9&5N:64`26YD:6$`2F5D;F]T;&EV
M[2!P;W6^[79A=&5L:6$`26YD;V[I>FEA`$EN9F\`26YF;W)MX6-I90!);FEC
M:6%L:7IU:F4@<V$@;6]D=6P@)7,N+BX@`%9L;[YINR!?<W3E<&5C('IA`%9L
M;[YINR!O8G+A>F]K`%9L;[YINR!T86)UM6MU`%9L;[YINR!L:6YK=0!6;&^^
M:;L@7W-TY7!E8R!P<F5D`%9L;[YINR!N;W;]('-TY7!E8R!Z82!A:W1UX6QN
M>0!6;&^^:;L@;F]V_2!S=.5P96,@<')E9"!A:W1UX6QN>0!6;&^^:;L@;F]V
M_2!R:6%D;VL@>F$@86MT=>%L;GD`5FQOOFF[(&YO=OT@<FEA9&]K('!R960@
M86MT=>%L;GD`5FQOOFF[(&]D<W1A=F5C('IA(&%K='7A;&YY(&)O9`!6;&^^
M:;L@;V1S=&%V96,@<')E9"!A:W1UX6QN>2!B;V0`5FQOOFF[(&%L=&5R;F%T
M[79N=2"Y86)L\VYU`%IA9&%J=&4@92UM86EL;W;Z(&%D<F5S=2P@;F$@:W1O
M<OH@9&]S=&%N971E(&YO=ND@:&5S;&\Z`%9L;[YINR!B=6YK=2!Z80!6;&^^
M:;L@8G5N:W4@<')E9`!6;&^^:;L@<W3E<&5C('IA`%9L;[YINR!S=.5P96,@
M<')E9`!6;&^^=&4@<W!RX79Y`%9L;[YINR!O9'-T879E8R!Z80!6;&^^:;L@
M;V1S=&%V96,@<')E9`!6;&^^:;L@<FEA9&]K('IA`%9L;[YINR!R:6%D;VL@
M<')E9`!:861A:G1E('!OOF%D;W9A;OH@;V1P;W9E[R!N82!B97IP9>AN;W-T
M;OH@;W3A>FMU.@!6;&^^:;LO=7!R879INR!O8G+A>F]K`%9L;[YINR]U<')A
M=FF[(&QI;FMU`$YA(&]D;W-I96QA;FEE('!R92!Z;WIN86T@<'+M:F5M8V]V
M(&YE;>%T92!D;W-T871OZ&[](&MR961I="X`3F5D;W-T871OZ&[](&MR961I
M="X`0V5LZ2#H[7-L;P!:;WIN86T@8V5L_6-H(.AI<V5L`$YE<&QA9&[I(%5$
M2"`H57-E<B!$871A($AE861E<BP@2&QA=FGH:V$@<&]UONUV871EM7-K_6-H
M(/ID86IO=BDN`$YE<&QA=&[A(&%P;&EKX6-I82X`3F5P;&%T;ND@240@9.%V
M:WDN`$)O;&D@;V1O<VQA;ND@;F5P;&%T;ND@^F1A:F4N`$YE<&QA=&[A(&-I
M9;5O=N$@861R97-A+@!.97!L871N_2!F;W)MX70@<_IB;W)U`$YE<&QA=&[]
M(&QI8V5NZ&[](&NU^N@`0F]L82!Z861A;N$@;F5P;&%T;N$@;&]K86QI=&$N
M`$YE<&QA=&[A(&AO9&YO=&$@;7-G7W1Y<&4N`$YE<&QA=&[A(&%L96)O(&-H
M_6)A:OIC82!H;V1N;W1A(&%P:5]I9"X`3F5P;&%T;ND@86QE8F\@8VC]8F%J
M^F-E('!A<F%M971R92X`3F5P;&%T;ND@<F]D:>AO=G-KZ2!P<N%V;RX`3F5P
M;&%T;ND@:60@<&%R=&YE<F$N`$YE<&QA=&[](&OS9"!P<F]D=6MT=2X`3F5P
M;&%T;OT@<')O=&]K;VP`3F5P;&%T;OT@<'+M:F5M8V$Z("<E<R<`3F5P;&%T
M;OT@;V)J96MT('ID:66U86YI80!.97!L871NX2!Z9')O:F]VX2!A9')E<V$N
M`$YE<&QA=&[I(/ID86IE('5N:6-O9&4N`$EN=F5N=.%R`$ERX6X`27)A:P#-
M<G-K;P!)<VQE(&]F($UA;@!/:F5D:6YE;.D@8OIR:WD`27IR865L`%9Y9&%V
M871EM0!+=7)Z[79A`%1A;&EA;G-K;P!*86UA:FMA`$IA;G7A<@!*87!O;G-K
M;P!*97)S97D`2F]R9.%N`$KZ;`!*^FX`6F%R;W9N8;L`6F%R;W9N8;L@9&\@
M<W1R961U`%IA<F]V;F&[(&1O(&)L;VMU`%IA<F]V;F&[(':U879O`%IA<F]V
M;F&[('9P<F%V;P!+87IA8VAS=&%N`%!O;F5C:&&[(&]R:6=I;N%L/P!+9?)A
M`$ME<F)E<F]S('-E<G9E<B!Z86UI971O;"!A=71E;G1I9FEKX6-I=2X`2V5R
M;F5L+6YO=N'H:6MO=FEA`%9Y='9O<F5N:64@:[7ZZ&$`1&EG:73A;&YY(&]D
M=&QAZ&]K(&NU^NAA`$3EOFMA(&NU^NAA`%1Y<"!KM?KH80!0;W6^:71I92!K
MM?KH80!+M?KH('6^(&5X:7-T=6IE(&YA('-E<G9E<FD@=F5R96IN_6-H(&NU
M^NAO=BX`1&5T:0!+:7)I8F%T:0"E=61O=F]D96UO:W)A=&EC:^$@<F5P=6)L
M:6MA($OS<F5A`$OS<F5J<VOA(')E<'5B;&EK80!+=79A:G0`2VER9VFY<VMO
M`%9Z7VBU860`2F%Z>6L`3&%O<P!0;W-L961NX2!P;VQO=FEC80!0;W-L961N
MX2"Y='9RNP!0;W-L961NX2!A:W1U86QI>N%C:6$Z`%!O<VQE9&[I('!R:6AL
MX7-E;FEE.B`E<P!0;W-L961NZ2!P<FEH;.%S96YI93H@)7,@>B`E<P!0;W-L
M961NZ2!P<FEH;.%S96YI93H@;FEK9'D`3&]T>;ES:V\`4'+A=F\`5GIHM6%D
M`$YE8VAA:G1E('!RX7ID;F4@<')E(+YI861E;B!O:W)A:@!,:6)A;F]N`%:U
M879O`$AL879IZ&MA(':U879O`$AO9&YO='D@=K5A=F\`3&5S;W1H;P!,:6+I
M<FEA`$SM8GEA`$QI8VAT96ZY=&%J;G-K;P"E86AKZ2!M<FAO;&5N:64`I6%H
M:_T@9.&^[P!2X6YO(+5A:&O](&3AON\`3F5S:_1R(+5A:&O](&3AON\`I6%H
M:^D@9&&^[V]VZ2!P<F5HX6YK>0"E86AK_2!DX;[O(',@:')M96[M;0"E86AK
MZ2!S;F6^96YI90"E86AKZ2!S;F5H;W;I('!R96CA;FMY`$QI;65R:6-K`$QI
M;FMA`$QI;FMA('5K87IU:F4@;F$Z`%!R97!O:FF[(&4M;6%I;&]V^B!A9')E
M<W4@<V\@<W1RX6YK;W4@;F$@<.US86YI92!P;[ET>0!,:6YK>0!,:6YU>"!#
M;V]K:64`6F]Z;F%M("T@<&]UONUV871EM2!U=FED[2!P<FEEZ&EN;VL`5GEP
M[7-ANR!Z;WIN86T@9&%T86+A>@!:;WIN86T@=.EM(%!O;6]C;NUK80!6>7#M
M<V&[('IO>FYA;2!T86)U;&EE:P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI
M<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES
M="U5;G-U8G-C<FEB90!:;V)R87IO=F%N:64@>F]Z;F%M=2!P;W6^[79A=&6U
M;W8@:F4@>F%KX7IA;NDN`$QI=&5R873Z<F$`3&ET=F$`3F'H[71A=F%J^B!S
M82!K;FF^;FEC92XN+@!.8>CM=&%V82!S82XN+@!-:65S=&YY(.AA<SH@`$QO
M:V%L:7KA8VEA(&$@Z&%S`$QO:V%L:71A`%!R:6ALX7-E;FEE`$]D:&SA<VF[
M`-IL;VAY('!R:2!P<FEH;.%S96[M`%!R:6ALX7-E;FEE('IL>6AA;&\L('!R
M971OOF4@<W1E('IA9&%L:2!N97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO
M(&%L96)O(&AE<VQO+@!0<FEH;.%S96YI92!Z;'EH86QO+@!$;&C]('1E>'0`
M3.%S:V$`3NUZ:V$`36%LZ2!G<NEC:V4@<.US;65NX0!-86SI(&QA=&EN<VOI
M('#M<VUE;N$`36%LZ2!R[6US:V4@Z.US;&EC90!,=7AE;6)U<G-K;P!-30!3
M<'+A=F$@9/)A`%!R[6QO:&$@35,M5$Y%1B!N96]B<V%H;W9A;&$@OFEA9&YE
M(/ID86IE+@!-4T<`36%C86\`36%C963S;G-K;P!-861A9V%S:V%R`$WA9VEA
M`%!ON71A`%!O<VQANR!E+6UA:6P@861M:6YI<W1RX71O<F]V:0!6>71V;W)I
MNR!L:6Y?:W4N+BX`4VMO;G1R;VQU:G1E+""^92!MX71E(&YA:6ZY=&%L;W9A
M;OT@4$5!4B!A(+YE(&IE('8@8V5S=&4@(FEN8VQU9&4@<&%T:"(N`%9Y=';A
M<F$@<V$@861R97/A<B`E<P!-86QA=VD`36%L86IZ:6$`36%L961I=GD`36%L
M:0!-86QT80!3<')A=F]V8;L@>F]Z;F%M(&MA=&5G\W)I[2P@<R!K=&]R_6UI
M(&]Z;F'H=6IE=&4@<&]L;[YK>2!A(&9A<F)Y(&%S;V-I;W9A;ND@<R!T_6UI
M=&\@:V%T96?S<FEA;6DN`$UA<&$@36%P,C0`36%P82!-87!1=65S=`!-87)E
M8P!/:W)A:@!/>FYAZ&F[('!R[7IN86MM:2!0<F7H[71A;NDO3F5P<F7H[71A
M;ND`3WIN8>AINR!I;OUM:2!P<NUZ;F%K;6D@*&YA<'(N($3T;&6^:73I+UIO
M9'!O=F5D86[I*0!-87)S:&%L;&]V92!O<W1R;W9Y`$UA<G1I;FEK`%IH;V1N
MZ2!P;VQI80!-875R973A;FEA`$UA=7+M=&EU<P!-87AI;>%L;GD@<&]V;VQE
M;OT@:W)E9&ET+@!";VP@<')E:W)OZ&5N_2!M87AI;>%L;GD@<&_H970@Z&%S
M=.T@<W!RX79Y+@!.86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#(T
M(&AO9.UN.B``3F%J=GFYN6EA('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`V(&AO
M9.UN.B``36%X:6WA;&YA(&3EOFMA`$WA:@!-87EO='1E`$UE9&EC[6YA`,AL
M96YO=FEA`%IO8G)A>F5N:64@;65N=3H`6FSZZ&F[(&)U;FMY`%:Y971K>2`E
M<RYP;R!S^F)O<GD@<V$@>FQUZ'5J^B!S;R!S^FAR;F]V_6T@<_IB;W)O;2XN
M+@!:;'7H=6IE('-A(&QO:V%L:7KA8VEA("5S+BXN`%IL=>AU:F4@<V$@4$\@
M<_IB;W(@<')E("5S('-O('/Z:')N;W;];2!S^F)O<F]M+BXN`%IL=>AU:F4@
M<V$@<')E:VQA9"!P<F4@;6]D=6P@)7,N+BX`4W!RX79A`%-P<N%V82!B;VQA
M(/IS<&6Y;F4@;W9E<F5NX2P@86QE(&-E<G1I9FEKX70@<&]D<&ES=2!S82!N
M97!O9&%R:6QO(&]V97)INRX`4&QA=&YO<[L@<W!RX79Y('9Y<'*Y86QA+@!4
M>7`@<W!RX79Y`%!OZ&%S:64@365T87(`VF1A:F4@365T87(@;FEE('/Z(&1O
M<W1U<&[I+@#:9&%J92!-971A<B!N:64@<_H@:R!D:7-P;WKM8VEI+B!$971A
M:6QY(&)O;&D@>F%Z;F%M96YA;ND@<')E(&%D;6EN:7-T<N%T;W)A+@!3;'6^
M8F$@365T87)$0B!N:64@:F4@<')I<&]J96[A+@!-973S9&$`365T\V1A("<E
M<R<@;FEE(&IE(&1E9FEN;W9A;N$`365T<FEC:^D`365X:6-O`$UI:W)O;NEZ
M<VME(&9E9&5R873M=FYE(+ETX71Y`%-T<F5D`%1Y<"!-:6UE`$YA:FYIOKEI
M82!T97!L;W1A('IA('!O<VQE9&[]8V@@,C0@:&]D[6XZ(`!.86IN:;ZY:6$@
M=&5P;&]T82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ(`!-:6YI;>%L;F$@<&QA
M=&YO<[L@:&5S;&$@9;ET92!N979Y<'*Y86QA`%IR:V%D;&]V;R!O8G+A=&F[
M`%+T>FYE`$-H_6)A(&)A;.UK(%!%05(@2%144%]297%U97-T+@!#:/UB82!K
M;VYF:6=U<N%C:6$N($%K(&-H8V5T92!P;W6^[79ANR!T^G1O(&%P;&EKX6-I
M=2P@;75S[71E('1E<F%Z('9Y9V5N97)O=F&[(&MO;F9I9W5RX6-I=2X`0VC]
M8F$@240@<W!RX79Y+@!#:/UB82!P;[YA9&]V86[](%!%05(@8F%L[6L@36%I
M;"X`0VC]8F$@240@<F5LX6-I92X`4&]N`$UO8FEL;OT@;6%I;`!-:65R;GD`
M1.%T=6T@<&]S;&5D;F5J('IM96YY`%5P<F%V:;L@55),`$UO9'5L`$UO9'5L
M=7,`36]L9&%V<VMO`$UO;F%K;P!-;VYG;VQS:V\`365S:6%C(&$@<F]K`$UE
M<V'H;F4`36]N='-E<G)A=`!-97-AZ&[I(&;A>GD`36%R;VMO`%!R979AOFYE
M(&IA<VYO`%!R979AOFYE(&]B;&'H;F\`4')E=F&^;F4@<VQN9>AN;P!0<F5S
M=6[ZNR!D;VQU`%!R97-U;OJ[(':U879O`%!R97-U;OJ[('9P<F%V;P!0<F5S
M=6[ZNR!H;W)E`%!R97-U;OJ[(&1O;'4`4')E<W5N^KL@:&]R90!-;WIA8FUI
M:P!6:6%C^G)O=O)O=ND@=GEB97)A8VEE('IO>FYA;7D`5FEA8V[A<V]B;OT@
M=OUB97(`36]J92!K;VYT;P!-]&H@<&]R=.%L`%9Z:+5A9"!M]&IH;R!P;W)T
MX6QU`$UY86YM87(`3FEE+"!.15/:2$Q!4\U-+@!-96YO`$YA;>UB:6$`3F%U
M<G4`3F5PX6P`2&]L86YD<VMO`$AO;&%N9'-KZ2!!;G1I;'D`6N%K;&%D;N$@
M55),($YE='-C87!E`%523"!P<F4@>FYE<&QA=&YE;FEE(&-E<G1I9FEKX71O
M=B!#02!.971S8V%P90!54DP@<')E('!O;&ET:6MU($-!($YE='-C87!E`%52
M3"!P<F4@;V)N;W9E;FEE('!L871N;W-T:2!C97)T:69I:^%T;W8@3F5T<V-A
M<&4`55),('!R92!Z;F5P;&%T;F5N:64@8V5R=&EF:6OA=&]V($YE='-C87!E
M`$UE;F\@4U-,('-E<G9E<F$@3F5T<V-A<&4`2V]M96YTX7(@8V5R=&EF:6OA
M='4@3F5T<V-A<&4`5'EP(&-E<G1I9FEKX71U($YE='-C87!E`%-I9;L`3FEK
M9'D`3F]VX2!+86QE9/-N:6$`3F]VX2!K871E9_-R:6$`3F]V`$YO=ND@<&]U
MONUV871EM7-KZ2!M96YO("AN97!O=FEN;NDI`$YO=OT@6NEL86YD`$YO=ND@
M:&5S;&\Z`$YO=ND@;VMN;R`H7V)L86YK*0!.97=S`$1I<VMU<V[I('-K=7!I
M;GD`SV%L96H`3F%S;&5D=6KZ8V4@-"!FX7IY`,]A;+EI92!N87-T879E;FEA
M`,]A;&5J/@!.:6MA<F%G=6$`3FEG97(`3FEGZ7)I80!.;V,`3FEU90!.:64`
M3FEE('/Z(&1O<W1U<&[I(+YI861N92!K;VYF:6=U<F'H;ND@^F1A:F4L('!R
M92!K=&]RZ2!B>2!S82!D86QI('IO8G)A>FF[(')O>F1I96QY+@!0<F4@=GET
M=N%R86YI92!)4T\@;V)R87IO=B!N:64@:F4@:R!D:7-P;WKM8VEI(+YI861N
M82!S=')A=.EG:6$N`$YE97AI<W1U:F4@N6%B;/-N82!P<F4@9.%V:W4N`$YA
M('!OOF%D;W9A;F5J('!O>NUC:6D@;F5E>&ES='5J92"^:6%D96X@8FQO:RX`
M4')E($U#04P@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!M96YO(&MA
M;&5N9.%R82X`KFEA9&YA('IM96YA+@!0;V0@=&]U=&\@^G)O=O)O=2!S82!N
M97!R:61A:OH@OFEA9&YE('!O9')I861E;ND@<'+A=F$N`$L@=&]M=71O('!R
MX79U(&YE;6^^;F\@<')I9&&[(+YI861N92!P;V1R:6%D96[I('!RX79A+@!.
M96)O;""Y<&5C:69I:V]V86[](+YI861E;B!P<NUK87HN`%!R92`E<R!N96)O
M;&$@=7+H96[A(&MO;F9I9W5RX6-I82X`4')E($944"!61E,@;F5B;VQA('5R
MZ&5NX2!K;VYF:6=U<N%C:6$N`%!R92!344P@5D93(&YE8F]L82!U<NAE;N$@
M:V]N9FEG=7+A8VEA+@!0<F4@4U%,+49I;&4@5D93(&YE8F]L82!U<NAE;N$@
M:V]N9FEG=7+A8VEA+@"N:6%D96X@:W)E9&ET+@!.96)O;&\@N7!E8VEF:6MO
M=F%NZ2!M:65S=&\@=7+H96YI82X`5B!P]'9O9&YO;2!S^F)O<F4@<&]M;V-N
M[6MA(&YE97AI<W1U:F4@<&]L;[YK82!S(&ED("<E<R<N`%/Z8F]R(&YE8F]L
M(&YA:')A;OTN`$YE8F]L:2!NX6ID96[I(+YI861N92!I:V]N>2X`3F5B;VQA
M(+EP96-I9FEK;W9A;N$@;&]K86QI>N%C:6$N`$YI92!J92!N87-T879E;N$@
M;&]K86QI=&$N`$YE8F]L82!Z861A;N$@;&]K86QI=&$N`$YE8F]L82!Z861A
M;N$@OFEA9&YA('-P<N%V82X`3F5B;VQO(+EP96-I9FEK;W9A;ND@OFEA9&YE
M(&UE;F\N`$YE8F]L;R"Y<&5C:69I:V]V86[I(.CM<VQO+@"N:6%D;F4@=7+A
MOFQI=ND@9F]R='5N>0!0<F4@2%144"!A=71E;G1I9FEKX6-I=2!N96)O;&\@
M>F%D86[I(&AE<VQO+@!0<F4@24U!4"!A=71E;G1I9FEKX6-I=2!N96)O;&\@
M>F%D86[I(&AE<VQO+@!0<F4@2V5R8F5R;W,@875T96YT:69I:^%C:74@;F5B
M;VQO('IA9&%NZ2!H97-L;RX`4')E($Q$05`@875T96YT:69I:^%C:74@;F5B
M;VQO('IA9&%NZ2!H97-L;RX`4')E($QO9VEN(&%U=&5N=&EF:6OA8VEU(&YE
M8F]L;R!Z861A;ND@:&5S;&\N`%!R92!005-35T0@875T96YT:69I:^%C:74@
M;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E(%--0B!A=71E;G1I9FEKX6-I=2!N
M96)O;&\@>F%D86[I(&AE<VQO+@!.96)O;&$@>F%D86[A(&-E<W1A(&L@<')O
M9W)A;74@3W!E;E-33"X@4')O9W)A;2!/<&5N4U-,(&IE('!O=')E8F[](&YA
M('!RX6-U(',@^F1A:FUI(%!+0U,@,3(N`*YI861N92!P<F5B:65H86KZ8V4@
M<')I:&SA<V5N:6$N`$)E>B#H:6%R`$)E>B!S='+A;@!"86-K96YD("(E<R(@
M;F5B;VP@;N%J9&5N_2X`4')E('9Y<F]V;N%V86-I=2!P86WDNR!N:64@:F4@
M9&]S='5P;OT@OFEA9&5N(&1OZ&%S;OT@<')I9>AI;F]K+@!.96)O;&\@;V1O
M<VQA;ND@<&]UONUV871EM7-KZ2!M96YO(&$O86QE8F\@:&5S;&\N`$YE8F]L
M:2!V<N%T96[I('!L871NZ2!834P@^F1A:F4`KFEA9&YE(&AO9&YO='D`5B!P
M]'9O9&YE:B!K;VYF:6=U<N%C:6D@;F5B;VQA(&[A:F1E;N$@OFEA9&YA('9E
M<GII82X@5GEG96YE<G5J=&4@>FYO=G4@:V]N9FEG=7+A8VEU+@!6(&MO;F9I
M9W5RX6-I:2!N96)O;&$@;N%J9&5NX2"^:6%D;F$@=F5R>FEA+B!6>6=E;F5R
M=6IT92!Z;F]V=2!K;VYF:6=U<N%C:74N`*YI861E;@"N:6%D;F4@*'!O=;YI
MNR!I;7!L:6-I=&[Z(&AO9&YO='4I`$]S=')O=B!.;W)F;VQK`%-E=F5R;N$@
M<&]L;V=UM6$`4V5V97)NZ2!-87)IX6YS:V4@;W-T<F]V>0!.\W)S:V\`3F5P
M;&%T[2!P;P!.97!L873M('!R960`3FEE(&IE(&%D<F5SX7(`3FEE(&IE(&EM
M<&QE;65N=&]V86[I+@!.96YA<W1A=F5NZ0!.:64@:F4@<&]D<&]R;W9A;NDN
M`%!O>F[A;6MY`$YIZ"!N82!P<F5Z97)A;FEE+"!V<N&[=&4@<V$@<W#DNRX`
M4&]Z;N%M:V$`3F]V96UB97(`R.US;&\`4&_H970@>FYA:V]V`%!OZ&5T('-T
MY7!C;W8`4&_H970@<FEA9&MO=@!0<F4@86MT=6%L:7KA8VEU('IO>FYA;74@
M<'+M:F5M8V]V(&YE8F]L:2"Y<&5C:69I:V]V86[I(.CM<VQA+@!/2P!/8FIE
M:W0`075T;W(@;V)J96MT=0!0<N%V82!T=F]R8W4@;V)J96MT=0!/<VUIZ&MO
M=OT`3VMT\V)E<@!&:6QT97(@;F$@;F%DX79K>0!0<F%C;W9I<VMO`%-T87+I
M(&AE<VQO.@!/;>%N`$EB82!)34%0('-E<G9E<GD@<&]D<&]R=6KZ('ID:66U
M86[I('!R:67H:6YK>2X`26)A('5RX;YL:7;I(&9O<G1U;GD`2F4@<'+M<'5S
M=&[A(&EB82!J961N82!E+6UA:6QO=N$@861R97-A+@!6;&%S=&[M:V$@86QE
M8F\@<'+A=F$@=FQA<W1N[6MA('!R92!Z9&EEM6%N_2!O8FIE:W0@;?2^92!Z
M;65N:;L@:6)A('9L87-T;NUK(&%L96)O('-Y<W3I;6]V_2!A9&UI;FES='+A
M=&]R`$]T=F]R:;L@=B!N;W9O;2!O:VYE`$-H>6)A($]P96Y34TPZ(&YE<&]D
M87)I;&\@<V$@>NUS:V&[(/ID86IE('H@<&]D<.US86YE:B#H87-T:2!3+TU)
M344N`$]T=F]R:;L@=/IT;R!L:6YK=2!V(&YO=F]M(&]K;F4`3W!E<F'H;OT@
M<WES=.EM`$YA<W1A=F5N:6$`3F%S=&%V96YI82`E<P!.87-T879E;FEA.@!:
M;W)A9&5N_2!Z;WIN86T`3W)G86YI>N%C:6$`3W)G86YI>F'H;N$@:F5D;F]T
M:V$`3W)G86YI>F]V86YI90!0]'9O9&[A(+EA8FSS;F$@87!L:6OA8VEE`%#T
M=F]D;ND@N6%B;/-N>2!V("5S.@!);ND`SV%LN6EE(&EN9F]R;>%C:64`4'+A
M=F$@=FQA<W1N[6MA`%!!32!A=71E;G1I9FEKX6-I82!N:64@:F4@9&]S='5P
M;N$N`$1I9VETX6QN>2!P;V1P:7,@4$=0`-ID86IE('IAN6EF<F]V86[I('!O
M;6]C;W4@4$=0`%!'4"!V97)E:F[](&NU^N@`VF1A:F4@<&]D<.US86[I+WIA
MN6EF<F]V86[I('!O;6]C;W4@4$=0`%!(4"!K\V0`4$A0(%-H96QL`%!O<&]L
M=61N[2"U86AK_2!DX;[O`%!O<&]L=61N[2!P<F5HX6YK>0!0;W!O;'5D;NT@
M<VYE:`!0;W!O;'5D;NT@<VYE:&]VZ2!P<F5HX6YK>0!0;W!O;'5D;NT@<VQN
M9>AN;P!0;W!O;'5D;NT@8OIR:WD`4%](4"!3:&5L;`!6>7!L;F5N:64`4&%K
M:7-T86X`4&%L875S:^D@;W-T<F]V>0!086QE<W3M;G-K92#Z>F5M:64`4&%N
M86UA`%!A<'5A($YO=N$@1W5I;F5A`%!A<F%G=6%Y`,AI87-T;^AN92!O8FQA
MZ&YO`$UO9'5L(%!A<W-W9"!N:64@:F4@<W!RX79N92!N86MO;F9I9W5R;W9A
M;OTN`$AE<VQO`$AE<VQO(&YA("5S('IM96YE;NDN`$YE<W!RX79N92!H97-L
M;P!-;V1U;"!N82!Z;65N=2!H97-I96P@;F5M;VAO;"!NX6ISNR!D;V1A;OT@
M8FENX7)N>2!P<F]G<F%M+@!-;V1U;'4@4&%S<W=O<F0@8VC]8F%J^B!P;[YA
M9&]V86[I('!A<F%M971R92X`36]D=6QU(%!A<W-W;W)D(&-H_6)A('!A<F%M
M971E<B!C:66U82X`36]D=6P@4&%S<W=O<F0@;FEE(&IE('-P<N%V;F4@;F%K
M;VYF:6=U<F]V86[]`$UO9'5L(%!A<W-W;W)D(&YI92!J92!S<'+A=FYE(&YA
M:V]N9FEG=7)O=F%N_2X`4')E(&%U=&5N=&EF:6OA8VEU(%)!1$E54R!J92!V
M>;YA9&]V86[I(&AE<VQO+@!(97-L;R!S('!O='9R9&5N[6T`2&5S;&\Z`$AE
M<VQO.B``2&5S;.$@;75S:6$@8GF[(')O=FYA:^DN`%9L;[YINP!6;&^^:;L@
M>F\@<V-H<N%N:WD`0V5S=&$`4')E8FEE:&%J^F-E(')E9VES='+A8VEE.@"E
M=61I80!097)C96YT`%9Y:V]N8;L@;W!E<N%C:64@^F1ROF)Y`%9Y:V]N8;L@
M;W!E<N%C:64@^F1ROF)Y('!R:2!P<FEH;.%S96[M/P!0<N%V;P!0<N%V;R`G
M)7,G(&YE8F]L;R!V>6UA>F%NZ2X`061M:6YI<W1RX6-I82!P<N%V`%!RX79A
M('!R90!/<V]B;ND@:6YF;W)MX6-I90!097)U`$1O;>%C92!Z=FEE<F%TX0!&
M:6QI<.UN>0!496QE9O-N`$9O=&]G<F%F:64`4&ET8V%I<FX`0F]D;W8`2VQI
M:VYI=&4@<')O<^UM(&1O(&YE:F%K96H@8G5N:WD`4&]T=G+O=&4@<')O<^UM
M+""^92!C:&-E=&4@;V1S='+A;FF[('1E;G1O(&5L96UE;G0Z`%!O='9R[W1E
M('!R;W/M;2P@OF4@8VAC971E(&]D<W1RX6YINR!L:6YK=2!Z('1O:'1O(&5L
M96UE;G1U+@!:861A:G1E('!R;W/M;2!M97-I86,@82!R;VLN`%IA9&%J=&4@
M<')O<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S<FEU.@!:861A:G1E('!R;W/M
M;2!P;&%T;OH@25`@861R97-U+@!:861A:G1E('!R;W/M;2!P;&%T;OT@9.%T
M=6TL('-K;VYT<F]L=6IT92!P;^AE="!D;NT@=B!M97-I86-I+@!:861A:G1E
M('!R;W/M;2!P;&%T;OT@Z&%S+@!0<F]S[6T@>F%D86IT92!N;W;I(&AE<VQO
M`%!R;W/M;2!U=F7O=&4@>FAR;G5T:64@<')O8FSI;74N`%!R;W/M;2!Z861A
M:G1E(&%K='7A;&YE(&AE<VQO`%!R;W/M;2!Z861A:G1E('-V;VIE('!O=;[M
M=F%T9;5S:^D@;65N;R!A(&AE<VQO`%!R9>CM=&%J=&4@<VD@<')O<^UM(&YA
M<VQE9'5J^F-I('1E>'0N($U54\U412!S^FAL87-INR!S('!O9&UI96YK86UI
M('!O=;YI=&EA('-Y<W3I;74N`%!R;W/M;2!O:&SA<W1E(&%KZ6MOM79E:R!C
M:'EB>2!N82!A9')E<W4@:3$X;D!L:7-T<RYH;W)D92YO<F<N`%IA9&%J=&4@
M<')O<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S<FEU.@!0<F]S[6T@>F%D86IT
M92!EN71E(')A>B!N;W;I(&AE<VQO`%!OM7-K;P!0;VQI=&EK80!!;FME='D`
M4&]R='5G86QS:V\`56UI97-T;F5N:64@=&]H=&\@;V)RX7IK=0!5;6EE<W1N
M96YI92!T96IT;R!T86)UM6MY`$]D;W-L8;L@9&\@=&]H=&\@<')I9>AI;FMA
M("AN979Y;G5C=6IE($E-05`I`%IRX;YK>2!Z82!P;W-L961N_6-H("5S(&AO
M9.UN.B``4')E9G-?;&1A<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($Q$05`@
M;F5B;VQO(&[A:F1E;NDN`%!R969S7W-E<W-I;VXZ('!OOF%D;W9A;ND@<F]Z
MN>UR96YI92!S97-S:6]N(&YE8F]L;R!NX6ID96[I+@!4;&%K`%1L86L@;F$@
M^G)O=FYI(&UO<F$Z(`!4;&%K.B``56OAOFMA`%IO8G)A>FF[('5KX;YK=2!O
M8G+A>FMU('8@;F]V;VT@;VMN90!0<F5D8VCA9'IA:OIC92!N87-T879E;FEA
M`%9Y=&QAZ&F[(&1O:W5M96YT`%!R:7;A=&YY(&NU^N@`4')O8FSI;0!0;W!I
M<R!P<F]B;.EM=0!0<F]J96MT>0!6_7IV82!N82!Z861A;FEE('1E>'1U`%9E
M<F5J;OT@:[7ZZ`!!;&=O<FET;75S('9E<F5J;NEH;R!KM?KH80!);F9O<FWA
M8VEE(&\@=F5R96IN;VT@:[7ZZ&D`5F5R96IN_2]P<FEVX71N>2!KM?KH;W;]
M('#A<B!N96)O;"#Z<W!EN6YE('9Y9V5N97)O=F%N_2X`4&]R=&]R:6MO`$MA
M=&%R`$1O=&%Z`%)302!V97)E:F[](&NU^N@@*"5D(&)I=&]V*0!0<F5P[6YA
MZ"!S(';]8F5R;VT`1.&^[P!2X6YO(&3AON\`3F5S:_1R(&3AON\`1&&^[V]V
MZ2!P<F5HX6YK>0!$X;[O(&$@<VYE:`!$X;[O(&UE;FEA8VD@<V$@;F$@<VYE
M:`!.X6AO9&[A(&9O<G1U;F$`4&]M97(`R.UT8;L`R.UT8;L@<W!RX79Y`$YA
M;WIA:B!V>6UA>F&[("5S/R!4^G1O(&]P97+A8VEU(&YE;6^^;F\@=G+A=&F[
M('-PY+LN`$YA;WIA:B!V>6UA>F&[('!O=;[M=F%T9;5S:^D@^F1A:F4@<')E
M('!O=;[M=F%T9;5A("5S/R!4^G1O(&]P97+A8VEU(&YE;6^^;F\@=G+A=&F[
M('-PY+LN`%9RX71I('-PY+L@5F&Y=2!P;W-L961N^B!A:V-I=0!/8FYO=FF[
M(&5L96UE;G1Y(&1Y;F%M:6-KZ6AO(&UE;G4Z`$]B;F]V:;L@>F]B<F%Z96YI
M92!P;W)TX6QU.@!296=U;.%R;GD@=OUR87H`4')E:&QI861AZ"!V>KMA:&]V
M`%!O<W1R96AY`%9Z9&EA;&5NZ2!S97)V97)Y`%9Z9&EA;&5NX2!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!/9'-T<N%N:;L`3V1S='+A
M;FF[(&)L;VL`3V1S='+A;FF[('-TY7!E8P!/9'-T<N%N:;L@9F]R;>%T;W9A
M;FEE`$]D<W1RX6YINR!PX7(`3V1S='+A;FF[('5L;[YE;OT@<VMR:7!T('H@
M9&_H87-NZ6AO('!R:67H:6YK82!N82!S97)V97)I+@!/9'-T<N%N:;L`3V1S
M='+A;FF[('1E;G1O(&)O9"!Z(&1O:W5M96YT=0!/9'-T<N%N:;L@<&]UONUV
M871EM6$`3V1S='+A;FF[('!O=;[M=F%T9;5A.B`E<P!.82!P;[YI861A=FMU
M(&YE8F]L;R!M;[YNZ2!O9'!O=F5D8;LN($[A=G)A=&]V_2!K\V0@8VAY8GDZ
M(`!0;[YA9&]V86[A('-L=;YB82!N96)O;&$@;N%J9&5NX2X`5B!K;VYF:6=U
M<N%C:6D@)7,@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQO
MOFMA("<E<R<`5B!K;VYF:6=U<N%C:6D@5D93(&YI92!J92"Y<&5C:69I:V]V
M86[A('!OOF%D;W9A;N$@<&]L;[YK82`G)7,G`%8@:V]N9FEG=7+A8VEI(&YI
M92!J92"Y<&5C:69I:V]V86[A('!OOF%D;W9A;N$@<&]L;[YK82`G)7,G`%8@
M:V]N9FEG=7+A8VEI($-O;7!O<VET92!N:64@:F4@N7!E8VEF:6MO=F%NX2!P
M;[YA9&]V86[A('!O;&^^:V$@)V1R:79E<G,G`%8@:V]N9FEG=7+A8VEI(%!A
M<W-W9"!344P@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQO
MOFMA("=P:'!T>7!E)P!6(&MO;F9I9W5RX6-I:2!344P@;FEE(&IE(+EP96-I
M9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA("=P:'!T>7!E)P!0;[YA9&]V
M86[I('!O;&4`5GEM87IANR!F;W)M=6SA<@!/8FYO=FF[(&AE<VQO`$]B;F]V
M:;L@5F&Y92!H97-L;P!6_7-L961K>0!6_7-L961K>2`H=G+A=&%N92!(;W)D
M92DZ`%;]<VQE9&MY.@!.X79R870@;F$@;F%S=&%V96YI80!2975N:6]N`%9R
MX71INR!K;VYF:6=U<N%C:74`3F%S=&%V96YI82!R;WJY[7)E;NEH;R!T97AT
M;W;I:&\@961I=&]R=0!(X61A;FMY`%9P<F%V;P!(;&%V:>AK82!V<')A=F\`
M2&]D;F]T>2!V<')A=F\`5FQA<W1N;W-T:2!?<FEA9&MA+BXN`%)O;&$`4G5M
M=6YS:V\`3W1OZ&F[(&\@,3@P`$]T;^AINR!VM6%V;P!/=&_H:;L@=G!R879O
M`%9L87-T;F]S=&D@<FEA9&MA`%9L87-T;F]S=&D@<FEA9&MA`%)I861K>3H`
MR&EA<GD`R&EA<GD@<V$@>F]B<F%Z:6$@;65D>FD@=KEE=&O];6D@<FEA9&MA
M;6D@82!S=.5P8V%M:0#(:6%R>2!S82!Z;V)R87II82!I8F$@;65D>FD@<W3E
M<&-A;6D`R&EA<GD@<V$@>F]B<F%Z:6$@:6)A(&UE9'II(')I861K86UI`%-P
M=7-T:;L`4G5S:^$@9F5D97+A8VEA`%)W86YD80!3+TU)344@:W)Y<'1O9W)A
M9FEC:_T@<&]D<&ES`%-P<N%V82!Z8;EI9G)O=F%NX2!P;VUO8V]U(%,O34E-
M10!305-,(&%U=&5N=&EF:6OA8VEA(&YI92!J92!D;W-T=7!NX2X`4&]S:65L
M86YI92!335,`4U%,(%-H96QL`%-32`#:4U!%0T@`4U]13"!3:&5L;`!3;P!3
M=N1TX2!(96QE;F$`4W;D=/T@2VET=',@82!.979I<P!3=N1TX2!,=6-I80!3
M=BX@4&EE<G)E(&$@36EQ=65L;VX`4W;D=/T@5FEN8V5N="!A($=R96YA9&EN
M>0!496X@:7-T_2!RX6UE8R`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@82!0<FEN8VEP90!3871E;&ET;OT@<&]S:WET;W9A=&6U`%-A=61S
M:^$@07+A8FEA`%5L;[YINP!5;&^^:;L@)7,`56QOOFF[("<E<R<`56QOOFF[
M(&YA<W1A=F5N:6$`56QOOFF[('9Y9V5N97)O=F%N^B!K;VYF:6=U<N%C:74@
M86MO(%!(4"!S:W)I<'0@9&\@9&_H87-NZ6AO('!R:67H:6YK82!6X;EH;R!S
M97)V97)A+@!+;VYF:6=U<N%C:6$@)7,@8F]L82!U;&^^96[A+@!3:W)I<'0@
M;F$@=7!G<F%D92!N87-T879E;NT@8F]L('5L;[YE;OTZ("<E<R<N`$]J961I
M;F5LZ2!B^G)K>0!6961A`$BU861ANP!6>6BU863A=F'H90!(M6%D86KZ('-A
M(&%P;&EKX6-I92!(;W)D92!V("5S`$BU861A:OH@<V$@<')O9W)A;7D@9V5T
M=&5X="XN+@!6>6)E<G1E('/Z8F]R>0!6>6)E<G1E(&3A='5M`%9Y8F5R=&4@
M<VMU<&EN=2!N82!P<FED86YI90!6>6)E<G1E(&YO=NEH;R!V;&%S=&[M:V$`
M5GEB97)T92!S97)V97(`5GEB97)T92!P;W6^[79A=&6U82!N82!P<FED86YI
M90!6>6)E<G1E(':Y971K>2!K;VUP;VYE;G1Y(&3A='5M=0!6>6)E<G1E(&]B
M:F5K=`!6>6)E<G1E('IN86MY+"!K=&]RZ2!P;W1R96)U:F5T92P@>B!O:VEE
M;F]K(&YIOKEI92X@4&]T;VT@:6-H(&WTOF5T92!S:V]P[7)O=F&[(&$@=FQO
MOFF[('H@=&5X=&]VZ6AO('!OM6$N`%9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O
M<FWA=&4@9.%T=6UU.@!6>6)E<G1E(&9O<FWA="!DX71U;74Z`%9Y8F5R=&4@
M:61E;G1I='4L(&MT;W+Z(&-H8V5T92!Z;65N:;LZ`%9Y8F5R=&4@;V1D9;5O
M=F'H('9O(&9O<FWA=&4@Z&%S=3H`5GEB97)T92!F;W)MX70@Z&%S=3H`5GEB
M97)T92!D=F4@>FAO9&[I('!O;&EA+@!6>6)E<G1E('-I(&9A<F5B;OH@<V-H
MZ6UU`%9Y8F5R=&4@:F%Z>6LZ`%!O<VQANR!S<'+A=G4@;R!P<F]B;.EM90!0
M;W-L8;L@4TU3`%-E;F5G86P`4V5N>F]R.B``4V5P=&5M8F5R`%-R8G-K;R!A
M(,AI97)N82!H;W)A`%/I<FEO=ND@Z.US;&\`VF1A:F4@>F\@<V5R=F5R82!S
M^B!Z;.D@86QE8F\@;F5D;W-T=7!NZ2X`4&QA=&YO<[L@240@<F5LX6-I92!V
M>7!RN6%L82X`36YOOFEN82!H;V1N]'0`3F%S=&%V=&4@;6^^;F]S=&D@;F$@
M;V)N;W9E;FEE(%;AN6AO(&AE<VQA(&%K(&AO('IA8G5D;F5T92X`3F%S=&%V
M96YI92!V>F1I86QE;OUC:"!S97)V97)O=BP@:W4@:W1O<OUM(&-H8V5T92!P
M<FES='5P;W9ANR!Z(%;AN6AO('!O<G3A;'4N`%9Y8F5R=&4@:F%Z>6LL(.AA
M<V]V^B!Z\VYU(&$@;F%S=&%V96YI82!DX71U;74N`$YA<W1A=F5N:64@87!L
M:6OA8VEE('-P^KF[86YE:B!P<FD@N71A<G1E+"!F87)E8FYE:B!S8VCI;7DL
M(&EN=&5R=F%L=2!O8FYO=F]V86YI82!S='+A;FMY(&$@:6[]8V@@=FQA<W1N
M;W-T[2!Z;V)R87IE;FEA+@!.87-T879E;FEE`%/Z(&1O<W1U<&[I('-K<FEP
M='D@;F$@=7!G<F%D92!N87-T879E;NT`1&\@^G9A:'D@<')I8VCA9'IA(&YI
M96MOM6MO(&QO:V%L[70@<&]M;V-O=2!P87)A;65T<F$Z(`!397EC:&5L>0!3
M:&]P<&EN9P!+<N%T:WD@<_IH<FX`36%J^B!S82!P<F4@=N3HN6EN=2!L:6YI
M96L@=GET=F]R:;L@<VMR871K;W;I(&MLX79E<WD_`%IO8G)A>FF[`%IO8G)A
M>FF[(')O>F1I96QY(&UE9'II('!RX79E('5L;[YE;F]U(&$@;F]V;W9Y9V5N
M97)O=F%N;W4@:V]N9FEG=7+A8VEO=2X`3>$@<V$@<')I('!R:6ALX7-E;NT@
M>F]B<F%Z:;L@Z&%S('!O<VQE9&[I:&\@<')I:&SA<V5N:6$_`%IO8G)A>FF[
M(&UOOFYO<[L@;F$@<&]N96-H86YI92!O<FEG:6[A;'4`6F]B<F%Z:;L@;N%S
M=')O:B!N82!V_6)E<B!F87)I96(`6F]B<F%Z:;L@;65N=2!P<F4@;W!E<N%C
M:64@<R!T86)UM6MA;6D_`%IO8G)A>FF[(&UE;G4@)7,@;F$@M6%V96H@<W1R
M86YE/P!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@8G5N:WD@=&%B
M=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@=&%B=;5K>0!:
M;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@<FEA9&MU('1A8G6U:WD`
M6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI(&]B<N%Z:W4`6F]B<F%Z
M:;L@;F%H<F%NZ0!0<F5HX6YK>0!2X6YO('!R96CA;FMY`$YE<VOT<B!P<F5H
MX6YK>0!0<F5HX6YK>2!V(&)L[7IK;W-T:0!:;65NN6F[`$YA:G!R=B!M=7/M
M=&4@>FUE;KEINR!A;&5B;R!P<F5S=6[ZNR!S=7-E9&[](&)L;VLH>2D`4VEE
M<G)A($QE;VYE`%IA<F5G:7-T<F]V8;L@<V$`6F%R96=I<W1R;W9ANR!S82P@
M86L@;FEE('-T92!R96=I<W1R;W9A;OT`4&]D<&ES`$%L9V]R:71M=7,@<&]D
M<&ES=0!3:6YG87!U<@!69;5K;W.[`%!R97-K;^AINR#Z9'*^8G4`4')E<VMO
MZ&5NZ2XN+@!3;&]V96YS:V\`4VQO=FEN<VMO`%-N96@`4VYE:&]VX2!P<F5H
MX6YK80!3;F5H;W;I('!R96CA;FMY`%+A;F\@<VYE:&]VZ2!P<F5HX6YK>0!.
M97-K]'(@<VYE:&]VZ2!P<F5HX6YK>0!(Y6)K82!S;F5H=3H@`$UN;[YS='9O
M('9O9'D@96MV:79A;&5N=&[I('-N96AU.B``J6%L86WZ;F]V92!O<W1R;W9Y
M`%-O;>%L<VMO`%!I97-N92!A(&+A<VYE`%;]8F5R('-M97)U('1R:65D96YI
M80!:9')O:F]VX2!A9')E<V$`2G6^;N$@069R:6MA`$IUOF[A($=E;W)G:6$@
M82!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$IUOF[A('!O;&]G=;5A`$UE9'IE
M<F$@;65D>FD@<W5S961N_6UI(&)U;FMA;6D`365D>F5R82!M961Z:2!O8G-A
M:&]M(&$@;VMR86IO;2!B=6YK>0!/9&1EM6]V8>@`3V1S='5P`$]D<W1U<"!A
M('9Y<&QN96YI90"I<&%N:65L<VMO`%-P86T`5FQOOF5N:64@N7!E8VGA;&YY
M8V@@>FYA:V]V`%)O>F1E;&F[(&)U;FMU`%)O>F1E;&F[('-TY7!E8P!2;WID
M96QINR!R:6%D;VL`J7!O<G1Y`%-R[2!,86YK80"I=&%N9&%R9&[I`%-T87(@
M5')E:P!0;^AI871OZ&[](')O:P"I=.%T(&%L96)O('!R;W9I;F-I80!3=&%V
M`%-T878@<')E(&QO:V%L:7KA8VEU("5S+BXN`$9O<FWA="!U;&^^96YI80!"
M>61L:7-K;P!0<F6Y:W)T;G5TZ0!:;WIN86T@<F6[87IC;W8`3V1S='+A;FF[
M(&1O;>EN=2!Z(&%D<F5S>0"I=/UL(%M#4U-=`$YE`%!O9'!R:67H:6YO:R`G
M)7,G(&YE8F]L(&[A:F1E;OTN`%!R961M970`3V1O<VQANP!0;[YI861A=FMA
M(&YA('!R:61A;FEE("<E<R<@9&\@<WES=.EM=2!B;VQA(&]D;W-L86[A+B!.
M96WTOF5T92!S82!P<FEH;.%S:;LL(&O];2!N96)U9&4@5F&Y82!P;[YI861A
M=FMA('-C:';A;&5NX2X`1&]L;OT@:6YD97@`VG-P96-H`"<E<R<@8F]L82#Z
M<W!EN6YE('!R:61A;N$@9&\@<WES=.EM=2X`5GEM87IA;FEE(/ID86IO=B!Z
M;R!S>7-TZ6UU('!R92!P;W6^[79A=&6U82`G)7,G(&)O;&\@^G-P9;ENZ2X`
M5GEM87IA;FEE("<E<R<@8F]L82#Z<W!EN6[I+@!6>6UA>F%N:64@)R5S)R!Z
M;R!S>7-TZ6UU(&)O;&\@^G-P9;ENZ2X`3N%V<F%T(&MU(&MO;F9I9W5RX6-I
M:2!B;VP@^G-P9;EN_2X@4')E('IO8G)A>F5N:64@>FUI96X@>FYO=G4@;F'H
M[71A:G1E('-T<N%N:W4N`%KA;&]H82!K;VYF:6=U<N%C:64@8F]L82!U;&^^
M96[A+@!:X6QO:&$@:V]N9FEG=7+A8VEE("5S(&)O;&$@=6QOOF5NX2X`06MT
M=6%L:7KA8VEA("<E<R<@8F]L82#Z<W!EN6[A+@`E<R!B;VP@^G-P9;ENZ2!U
M;&^^96[]`%-U9.%N`%/Z:')N`%;]8VAO9"!S;&YK80!:X7!A9"!S;&YK80!3
M;&YEZ&YO`%;]8VAO9"!S;&YK80!6_6-H;V0O>N%P860@<VQN:V$`5OUC:&]D
M('-L;FMA.B``6N%P860@<VQN:V$`6N%P860@<VQN:V$Z(`!(;W)N_2!I;F1E
M>`!0;V1P;W)A`%-U<FEN86T`4')I97IV:7-K;P!3=F%L8F%R9"!A($IA;B!-
M87EE;@!3=F%Z:6IS:V\`J7;I9'-K;P"I=F%JZ&EA<G-K;P!3>6YT86MT:6-K
MX2!C:'EB82!V('!O9&UI96YK86-H(&BU861A;FEA`%/]<FEA`$+Z<FMA`$+Z
M<FMA(&$@=FEE=&]R`$+Z<FMY`%135B!S^F)O<@!486)UM6MA`%9L87-T;F]S
M=&D@=&%B=;5K>0!6;&%S=&YO<W1I('1A8G6U:WD`5&%I=V%N`%1A:7=A;BP@
M<')O=FEN8VEA(,CM;GD`5&%DOFEK:7-T86X`5&%N>N%N:6$`0VEEM3H`VFQO
M:'D`5&5L96;S;FYE(.CM<VQO`%1E<&QO=&$@>F$@<&]S;&5D;OH@:&]D:6YU
M.B``5&5P;&]T80!497!L;W1A.B``J6%B;/-N82`G)7,G(&YE8F]L82!NX6ID
M96[A+@!3<'+A=F$@N6%B;/-N`%1E>'0`26)A('1E>'0`6F%R;W9N86YI92!T
M97AT=0!497AT(&AO<F4`J70`5&AA:G-K;P#/86MU:F5M92!Z82!P;W6^:71I
M92!T;VAT;R!S>7-TZ6UU+@!3^F)O<B!P;VUO8V[M:V$@)7,@<')E("5S(&YE
M97AI<W1U:F4N(%9Y=';A<F$@<V$N`%)O>KGM<F5N:64@1E10(&YI92!J92!D
M;W-T=7!NZ2X`26YT96=RX6-I82!(;W)D92]+;VQA8B!N97!O9'!O<G5J92`B
M)7,B`%1R:65D82!-86EN=&5N86YC93HZ('-A(&YE;F'H[71A;&$@^G-P9;EN
M90!/:VYO(',@;F%S=&%V96YI86UI('-A('IA='9O<FEL;RX@2V]N:65C+@!!
M9&UI;FES='+A=&]R(&UU<^T@<VMO;F9I9W5R;W9ANR!P97)M86YE;G1N_2!B
M86-K96YD('!R92!0<N%V82P@86L@8VAC971E('!O=;[M=F&[(%!RX79A+@!)
M8F$@<W!O9&[A('-T<F%N80!)1"#H[7-L;R!K;VYT86MT=2!N96)O;&\@N7!E
M8VEF:6MO=F%NZ2P@8F]L;R!P;VYE8VAA;ND@<'+A>F1N92!A;&5B;R!N96)O
M;&\@;N%J9&5NZ2!V(&1A=&%BX7IE+@!+;VYT86MT(&)O;"#Z<W!EN6YE('9L
M;[YE;OT@9&\@5N&Y:&\@861R97/A<F$N`$YA(&]V97)E;FEE('!O9'#M<V%N
M96H@<W!RX79Y(&IE('!OOF%D;W9A;OT@;V1D96QE;OT@8FQO:R!S(%!'4"!P
M;V1P:7-O;2X`240@>F]Z;F%M=2!P<NUJ96UC;W8@8G7O(&YE8F]L;R"Y<&5C
M:69I:V]V86[I+"!A;&5B;R!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE(&%L96)O
M(&YE8F]L;R!NX6ID96[I('8@9&%T86+A>F4N`$YE8F]L('5RZ&5N_2!Z;WIN
M86T@<'+M:F5M8V]V+@"I:69R;W9A;FEE('9YOF%D=6IE(&)E>G!EZ&[I('!R
M:7!O:F5N:64@*&AT='!S*2X`4_IB;W(@)7,@8GD@;6%L(&]B<V%H;W9ANR!N
M87-T879E;FEE("5S+@!3^F)O<B`E<R!B>2!M86P@;V)S86AO=F&[(&YI96MT
M;W+I(&YA<W1A=F5N:6$@)7,N`%ID<F]J;W;](&$@8VEEM6]V_2!S^F)O<B!M
M=7-I82!B>;L@;V1L:;ENZ2X`4_IB;W(@;F5O8G-A:&]V86P@OFEA9&YE(/ID
M86IE+@!.87-L961U:OH@:&QA=FGH:WD@=&5J=&\@<W!RX79Y('9O(&9O<FWA
M=&4@;65S<V%G92]R9F,X,C(N`$-E;&]O8G)A>F]V:V]V_2!R9;YI;2!S</1S
M;V)U:F4@<')O8FSI;7D@=B!);G1E<FYE="!%>'!L;W)E<FD@:W;T;&D@8VAY
M8N%M('!R96AL:6%D8>AA+"!K=&]RZ2!S82!NX6T@;F5P;V1A<FEL;R!O8NUS
MNRX@3?2^=2!S82!P<F5J879INR!N97-P<N%V;GEM('IO8G)A>F5N[6TL(&-H
M_6)A:OIC:6UI(&9U;FMC:6%M:2!E9&ET;W)A(&$O86QE8F\@;N%H;V1N_6UI
M('#A9&UI('!R96AL:6%D8>AA+B!!:R!J92!6X;D@<WES=.EM(%=I;F1O=W,@
M.7@L(&IE('9EM6UI('!R879D97!O9&]B;NDL(+YE('-A('IO8G)A>NT@8VAY
M8F$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@82!B=61E=&4@;75S:66[
M(')EN71A<G1O=F&[('!OZ.UT8>@N7&Y<;E9A<F]V86QI('-M92!6X7,N(%-T
M;&'H=&4@<')O<^UM($]+(&%K(&YA;WIA:B!C:&-E=&4@<&]UOFF[(&5D:71O
M<B!V(&-E;&]O8G)A>F]V:V]V;VT@<F6^:6UE+@!3^F)O<B!P;VUO8V[M:V$@
M)7,@;F5Z8>CM;F$@<F6[87IC;VT@/#]X;6P`261E;G1I=&$@(B5S(B!B;VQA
M('9Y;6%Z86[A+@!)8F$@M6%VX2!S=')A;F$`5')I961A($-R>7!T7W!G<#HZ
M('!O=')E8G5J92!P;WIN8;L@=6UI97-T;F5N:64@<')O9W)A;74@1VYU4$<N
M`%-P<N%V82!O9&]S;&%NX2`E<R!P<F4@)7,@<R!P<F5D;65T;VT@(B5S(B!B
M;VQA('IO8G)A>F5NX2X*3F5E>&ES='5J92!VN6%K('KA<G5K82P@OF4@<W!R
MX79A(&)O;&$@<')EZ.UT86[A(&%L96)O('!O8VAO<&5NX2X`365N;RP@:W1O
M<ND@<V$@;>$@<&]UOFF[('!R:2!L:6YK;W9A;NT@;F$@<W1RX6YK=2!N82!P
M[7-A;FEE('-P<N%V(`!4<FEE9&$@2&]R9&5?0W)Y<'1?<VUI;64Z.B!V>;YA
M9'5J92!M;V1U;"!O<&5N<W-L+@!.87-T879E;FEE("(E<R(@<V$@;F5P;V1A
M<FEL;R!U;&^^:;LL('!R971OOF4@:F5H;R#Z9&%J92!P<F5K<F'H=6KZ(&UA
M>&EMX6QN=2!P;W9O;&5N^B!V9;5K;W.[`%!R;V=R86T@<&]UONUV86[](&YA
M('IO8G)A>F5N:64@=&]H=&\@^F1A:F]VZ6AO('1Y<'4@*"5S*2!N96)O;"!N
MX6ID96[]+@!)8F$@<')A=N$@82"U87;A('-T<F%N80!)8F$@<')A=N$@<W1R
M86YA`%-E<G9E<B`B)7,B(&)O;"!V>6UA>F%N_2X`4V5R=F5R("(E<R(@8F]L
M('5L;[YE;OTN`*YI861O<[L@;R!P<FEH;.%S96YI92`E<R!B;VQA('9Y;6%Z
M86[A+@"I<&5C:69I:V]V86[](')I861O:R!N965X:7-T=6IE+@!$;^AA<V[]
M('/Z8F]R("(E<R(@;F5E>&ES='5J92X`26)A(&AO<F[A(&$@<W!O9&[A('-T
M<F%N80!)8F$@:&]R;N$@<W1R86YA`$YA:')A;ND@^F1A:F4@<V$@;V0@<')E
M9&-HX61Z86KZ8V5H;R!K<F]K=2!S=')A=&EL:2X`3F%H<F%N_2!S^F)O<B!S
M82!N97!O9&%R:6QO('5L;[YINRX`0FQO:R!W96%T:&5R+F-O;2!N:64@:F4@
M9&]S='5P;OTN`%!R:67H:6YO:R!TZ6T@)R5S)R!N96)O;"!NX6ID96[]+@"N
M:6%D;F4@;F%S=&%V96YI82!N:64@<_H@9&]S='5P;NDN`*YI861N92!A;'1E
M<FYA=.UV;F4@Z&%S=&D@;F5M;[YN;R!Z;V)R87IINR!V('1E;&4@<W!RX79Y
M+@!6('1O;71O('!O;&D@:F4@<'+M;&FY('9EM6$@>FYA:V]V+B!:861A;&D@
M<W1E("5S('IN86MO=CL@;75S[71E('IA9&&[(&UE;F5J(&%K;R`E<RX`4_IB
M;W(@<&]M;V-N[6MA('!R92`E<R!EN71E(&YE97AI<W1U:F4N`$YA<W1A;&$@
M8VAY8F$@<')I('!R:63A=F%N[2`G)7,G(&1O('-Y<W3I;74Z("5S+@!.87-T
M86QA(&-H>6)A('!R:2!P<FEDX79A;NT@)R5S)R!D;R!S>7-TZ6UU.B`E<P!.
M87-T86QA(&-H>6)A('!R:2!O9'-T<F'R;W9A;NT@<&]UONUV871EM7-K_6-H
M(/ID86IO=B`G)7,G('IO('-Y<W3I;74Z(`!.87-T86QA(&-H>6)A('!R:2!O
M9'-T<F'R;W9A;NT@)R5S)R!Z;R!S>7-TZ6UU.B``3F%S=&%L82!C:'EB82!P
M<FD@86MT=6%L:7KA8VEI("<E<R<Z("5S`%9Y<VMY=&]L('-A('!R;V)LZ6T@
M<R!N86ARX79A;NUM('/Z8F]R=3H@)7,@;F5B;VP@;F%H<F%N_2X`5GES:WET
M;VP@<V$@<')O8FSI;2!S(&YA:'+A=F%N[6T@<_IB;W)U.B`E<R!B;VP@=N3H
MN>T@86MO(&YA:G;DZ+GM('!O=F]L96[](&QI;6ET("@E9"!B86IT;W8I+@!6
M>7-K>71O;"!S82!P<F]B;.EM(',@=6ML861A;NUM('/Z8F]R=3H@)7,@8F]L
M(&YA:')A;OT@;&5N(.AI87-T;^AN92X`3F%S=&%L82!C:'EB82!P<FD@>F]B
M<F%Z;W9A;NT@=&5J=&\@Z&%S=&D@<W!RX79Y`$YA<W1A;&$@8VAY8F$@<')I
M(&EM<&]R=&4@^F1A:F]V(&\@:V]N=&%K=&4N`$YA<W1A;&$@8VAY8F$@<')I
M(&EM<&]R=&4@^F1A:F]V(&E#86QE;F1A<BX`3F%S=&%L82!C:'EB82!V(&MO
M;F9I9W5R8>AN;VT@9F]R;75LX7)I+B!0<F%V9&5P;V1O8FYE('-T92!N979Y
M<&QN:6QI('!OOF%D;W9A;ND@<&]L92X`3F%S=&%L82!C:'EB82!P<FD@;W1V
MX7)A;NT@<_IB;W)U("5S+B!3:_IS=&4@<W!U<W1INR!T<F%N<VQA=&EO;BYP
M:'`@<R!P<F5P[6YAZ&]M("UD(&YA('IO8G)A>F5N:64@8VAY8F]V_6-H(&AL
MX7-E;NT@>B!X;6P@<&%R<V5R82X`3F%S=&%L82!C:'EB82!P<FD@=GEK;V[A
M=F%N[2!U<NAE;F5J(&9U;FMC:64@861R97/A<F$N(%!R;W/M;2!S:_IS=&4@
M=&\@;F5S:_1R+@!.87-T86QA(&-H>6)A('!R:2!A:W1U86QI>N%C:6D@9&5T
M86EL;W8@:V]N=&%K='4N(%!R;W/M;2!S:_IS=&4@=&\@;F5S:_1R+@!.87-T
M86QA(&-H>6)A('!R:2!A:W1U86QI>N%C:6D@>F]Z;F%M=2!P<NUJ96UC;W8N
M(%!R;W/M;2!S:_IS=&4@=&\@>FYO=G4N`%1E;G1O($E-05`@<V5R=F5R(&YE
M<&]D<&]R=6IE('ID:66U86YI92!P<FEEZ&EN:V]V+@!4;W1O('!R879D97!O
M9&]B;F4@;FEE(&IE('!L871N_2!A<F-H[78@<F%R+@!4;W1O('!R879D97!O
M9&]B;F4@;FEE(&IE('!L871N_2!A<F-H[78@>FEP+@!4;W1O('!R879D97!O
M9&]B;F4@;FEE(&IE('!L871NZ2#H[7-L;R!K87)T>2X`5&5N=&\@;W9LX61A
MZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V(&-E>B!B<N%N=2!#;&EC:V%T
M96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI('!O;6]C;W4@2%144"!!4$D`
M5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V(&-E>B!B
M<N%N=2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!P;VUO8V]U
M($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L8;L@<W!R
MX79Y(&-E>B!33510(&-E>B!B<N%N=2!6;V1A9F]N92!)=&%L>2`H:6)A(&YA
M(.CM<VQA(%9O9&%F;VYE*2X@5GF^861U:F4@92UM86EL;W;](/KH970@5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&]T;R!P;VQE(&IE
M('!O=FEN;NDN`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US;&$N
M`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US;&$@82!D=F]J8F]D
M:W4N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@;W-M:>AK;W;I(&AO
M9&YO='DN`%1O=&\@<&]L92!M=7/M(&)YNR!Z;WIN86T@Z.US96P@;V1D96QE
M;OUC:"#H:6%R:V]U(&%L96)O(&UE9'IE<F]U`%1O=&\@<&]L92!M=7/M(&)Y
MNR!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M=7/M(&]B<V%H;W9ANR!K\V0@
M9F%R8GD@=B"Y97-T;N%S=&MO=F]M(&9O<FWA=&4@4D="+"!N87!R[6ML860@
M)R,Q,C,T868G+@!496YT;R!F;W)M=6SA<B!UOB!B;VP@<W!R86-O=F%N_2X`
M5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE:W0@2V]L86(@1W)O=7!W87)E+B!0
M<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE:W1U('!O=')E8G5J971E(&4M;6%I
M;&]VZ6AO(&ML:65N=&$L(&MT;W+](')O>G5M:64@9F]R;>%T=2!+;VQA8B!'
M<F]U<'=A<F4N(%!R92!Z;WIN86T@=&%K_6-H=&\@:VQI96YT;W8@;F%VN73M
M=G1E('!R;W/M;2`E<P!4X71O('-P<N%V82!B;VQA(&YA<.US86[A('8@:6YE
M:B!A:V\@5F%M:2!P;W6^[79A;F5J('IN86MO=F5J('-A9&4@*"5S*2X`5&]T
M;R#H[7-L;R!M=7/M(&)YNR!N86IM96YE:B`Q+@!496YT;R!S:W)I<'0@;75S
M[71E('-P=7-T:;L@>B!P<NUK87IO=NEH;R!R:6%D:W4N`%1E;G1O('-E<G9E
M<B!N961O:^&^92!D96MO;7!R:6UO=F&[('/Z8F]R>2!Z:7`@82!G>FEP+@!3
M>7-TZ6T@:F4@;6]M96YTX6QN92!D96%K=&EV;W9A;OTN`%3A=&\@:&]D;F]T
M82!M=7/M(&)YNR#H[7-E;&[A+@!4;W1O(&]K;F\@;75S[2!B>;L@>F%V;VQA
M;ND@>B!O:VYA($YA<W1A=F5N[0!(<FUE;FEE`%1I8VME=',`R&%S`%1I;64@
M5')A8VMI;F<`1F]R;>%T(.AA<W4`5OUB97(@Z&%S=0!4:6UO<BU,97-T90!4
M:71U;&]K`$YA9'!I<R`H8G5B;&EN;W;](';]<&ES*3H`4')E`%!R92!V_6)E
M<B!V:6%C97+]8V@@<&]L;[YI96L@9'*^=&4@<&_H87,@:VQI:V%N:6$@:VSA
M=F5S=2!#;VYT<F]L("A00RD@86QE8F\@0V]M;6%N9"`H36%C*2X`1&YE<P!0
M<F5P;OJ[('IO8G)A>F5N:64@>F1R;VIO=NEH;R!K\V1U($A434P`5&]G;P!4
M;VME;&%U`%IA:G1R80!4;VYG80!6<F-H`%9R8VAN_2!RX6UE8R`H7W1O<"D`
M4')E;&^^96[I`%!R96ML861Y`%1R:6YI9&%D(&$@5&]B86=O`%!R879D82!A
M;&5B;R!N97!R879D80!5=`!4=6YI<VMO`%1U<F5C:V\`5'5R:VUE;FES=&%N
M`%1U<FMS(&$@0V%I8V]S`%1U=F%L=0!:861A:G1E(%9AN74@=F^U8G4Z(`!5
M+E8N(&EN9&5X.B``55),`%523"!6X;EH;R!S:W)I<'1U('!R92!S<'+A=G4@
M;R!D;W)UZ&5N[0!54DPZ`%5G86YD80!5:W)A:FEN80!.97!O9&%R:6QO('-A
M('5S:W5T;^AN:;L@<'+M<W1U<"!K(%9&4R!A9')E<^%R=2X`3F5P;V1A<FEL
M;R!S82!P<FED8;L@[V%LN6EE(&EN9F]R;>%C:64@;R!P;W6^[79A=&6U;W9I
M('!R:2!R96=I<W1RX6-I:2X`3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@
M<')E(%9&4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IM96YINR!P<N%V
M;R!P<F4@5D93('/Z8F]R("5S+R5S+@!.97!O9&%R:6QO('-A('IM96YINR!N
M82`E<RX`3F5P;V1A<FEL;R!S82!S<&]J:;L@<R!344P@<V5R=F5R;VTN`$YE
M<&]D87)I;&\@<V$@<W!O:FF[('!O;6]C;W4@4U-,+@!.97!O9&%R:6QO('-A
M('-K;W#M<F]V8;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A('9Y='9O<FF[
M(%9&4R!A9')E<^%R("(E<R(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93
M(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93('/Z8F]R+@!.
M97!O9&%R:6QO('-A('9Y='9O<FF[('!RX7ID;GD@5D93('/Z8F]R+@!.97!O
M9&%R:6QO('-A(&1E:V]M<')I;6]V8;L@^F1A:F4N`$YE<&]D87)I;&\@<V$@
M=GEM87IANR`B)7,B+"!A9')E<^%R(&YI92!J92!P<N%Z9&YY+@!.97!O9&%R
M:6QO('-A('9Y;6%Z8;L@)7,L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GD`3F5M
M;[YN;R!V>6UA>F&[("<E<R<Z("5S+@!.97!O9&%R:6QO('-A(')E:W5R>NUV
M;F4@=GEM87IANR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!V>6UA>F&[
M(%9&4R!A9')E<^%R+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93(&%D<F5S
MX7(Z("5S+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('/Z8F]R("(E<R(N
M`$YE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<_IB;W(N`$YE<&]D87)I;&\@
M<V$@<F5K=7)Z[79N92!V>6UA>F&[(%9&4SH@)7,N`$YE<&]D87)I;&\@<V$@
M=7+H:;L@86MT=>%L;GD@861R97/A<BX`3F5P;V1A<FEL;R!S82!Z:7-T:;L@
M<&]D<F]B;F]S=&D@;R!C97)T:69I:^%T92X`3F5M;[YNZ2!N86AR8;L@9&5F
M:6[M8VEU("5S+@!.97!O9&%R:6QO('-A('!R97-U;OJ[(%9&4R!S^F)O<BX`
M3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B`B)7,B+@!.97!O9&%R
M:6QO('-A(&]T=F]R:;L@5D93('/Z8F]R(&YA('KA<&ES+@!.97!O9&%R:6QO
M('-A(&]T=F]R:;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A(&]T=F]R:;L@
M:V]M<')I;6]V86[](&%R8VCM=BX`3F5P;V1A<FEL;R!S82!P<F7H[71ANR!S
M^F)O<CH@`$YE<&]D87)I;&\@<V$@Z.UT8;L@861R97/A<B!V9G-R;V]T+@!.
M97!O9&%R:6QO('-A('!R96UE;F]V8;L@)7,@;F$@)7,Z(&-I9;5O=OT@<')I
M9>AI;F]K('6^(&5X:7-T=6IE`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!6
M1E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A9')E
M<^%R.B`E<RX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<B`B
M)7,B+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R("5S+R5S
M+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R+@!.97!O9&%R
M:6QO('-A('-P=7-T:;L@)VUK:7-O9G,G+@!.97!O9&%R:6QO('-A('!R96QO
MOFF[('1E;G1O(&1O:W5M96YT(%=O<F0`3F5P;V1A<FEL;R!S82!Z87#M<V&[
M(%9&4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IA<.US8;L@5D93('/Z
M8F]R("AF=6YK8VEA(&-O<'DH*2!Z;'EH86QA*2X`3F5P;V1A<FEL;R!S82!Z
M87#M<V&[(/ID86IE(%9&4R!S^F)O<G4N`%!O9.AI87)K;G5TZ0!:<G6Y:;L@
M>FUE;GD`6G)UN>T@<&]S;&5D;OH@86MC:74`3F5OZ&%KX79A;N$@;V1P;W9E
M[R!O9"!S97)V97)A('!OZ&%S('-P;VIE;FEA.B``3F5OZ&%KX79A;N$@;V1P
M;W9E[R!O9"!S97)V97)A(&YA.B``3F5N87-T879E;N$`4W!O:F5NZ2!A<F%B
M<VOI(&5M:7+A='D`5F6U:^$@0G)I=.%N:6$`4W!O:F5NZ2"Y=.%T>2!!;65R
M:6-KZ0!*961N;W1K>0!.97INX6UE`$YE>F[A;64@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2X`3F5Z;N%M92!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+@!.97INX6UY('!R[6MA>CH@)7,`0F]L82!Z861A;N$@;F5Z;N%M82!L
M;VMA;&ET82X`3F5Z;N%M92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S
M;&\N`$]D<W1RX6YINR!L:6YK=2!Z(&%K='7A;&YE:&\@96QE;65N='4`3F5P
M;VUE;F]V86[A`$YE<')I=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6%J^B!Z(&)E
M>G!EZ&YO<W1N_6-H(&3T=F]D;W8@<'+M<W1U<"!K('9OM6+A;2!6>7-T<FEH
M;OJ[+TMO<.UR;W9ANR]6;&^^:;LN($ML:6MN:71E(&YA($]+(&$@>F]B<F%Z
M[2!S82!T96-H;FEC:^$@:6YF;W)MX6-I82!N82!S='+A;FME(&UO>FEL;&$N
M;W)G+"!K=&]RX2!6X7,@:6YF;W)M=6IE+"!A:V\@=6UOOFYINR!S:W)I<'1U
M('!R[7-T=7`@:R!S8VARX6YK92X`3V1S='+A;FF[(&9A<F)U`$YE<&]D<&]R
M;W9A;ND@<F]ZN>UR96YI90!.97!R96QOOF5NZ0!!:W1U86QI>N%C:6$`06MT
M=6%L:7IO=F&[("5S`$%K='5A;&EZ;W9ANR!P;W6^[79A=&6U80!!:W1U86QI
M>N%C:6$@)R5S)R!B;VQA(/IS<&6Y;N$N`$%K='5A;&EZ=6IE('-A('/Z8F]R
M('!O;6]C;NUK82`E<R!P<F4@)7,N`%-K<FEP="!N82!U<&=R861E(&)O;"!V
M>6UA>F%N_2X`3F%H<F&[`%:Y971K>2!S^F)O<GD@<R!K;VYF:6=U<N%C:6]U
M(&)O;&D@;F%H<F%NZ2!N82!S97)V97(N`%9EM6OI(&QA=&EN<VOI('#M<VUE
M;N$`5F6U:^D@<NUM<VME(.CM<VQI8V4`57)U9W5A>0!0;W6^:71I93H`4&]U
MOFF[(&%K='7A;&YE.B`E<P!0;W6^:;L@4U-,`%!O=;YI=&4@=B!P<NUP861E
M+""^92!J92!M96YO+VAE<VQO(&]D;&FY;ND@<')E($E-4U`@<V5R=F5R+@!0
M;W6^[79A=&6U("5S(&YI92!J92!A=71O<FEZ;W9A;OT@;F$@)7,N`%-P<N%V
M82!P;W6^[79A=&6U;W8`4&]UONUV871EM7-KZ2!N87-T879E;FEA`%)E9VES
M='+A8VEA('!O=;[M=F%T9;5A`%)E9VES='+A8VEA('!O=;[M=F%T9;5O=B!B
M;VQA('!R92!T96YT;R!S>7-TZ6T@>F%KX7IA;N$N`%!O=;[M=F%T9;4@;F5B
M;VP@;N%J9&5N_0!0;W6^[79A=&6U(&YE8F]L(&[A:F1E;OTN`%!RX79A('9L
M87-T;NUK80!0;W6^[79A=&6U<VOI(&UE;F\`4&]UONUV871EM7-KZ2!M96YO
M("<E<R<@=;X@97AI<W1U:F4N`%!O=;[M=F%T9;5S:^D@;65N;SH`4&]UONUV
M871EM7-KZ2!M96YO.B``4&]UONUV871E;&EA`%!O=;[M=F%T96QI82!S>7-T
MZ6UU.@!5>F)E:VES=&%N`%9&4R!A9')E<^%R(&YE97AI<W1U:F4N`$1O=F]L
M96YK80!0;&%T;ND@=6UI97-T;F5N:6$@>F%HX/)A:OHZ(`!0;&%T;F]SNP!0
M;&%T;F]SNR!V(&UI;OIT86-H(&]D=&5R87HN`$AO9&YO=&$@:F4@=N3HN6EA
M(&%K;R!M87AI;>%L;F$@9.6^:V$@)7,N`$AO9&YO='D`2&]D;F]T>2P@>B!K
M=&]R_6-H('-I(&WTOF5T92!V>6)R8;L`5F%N=6%T=0!0<F5M96YNX0!696YE
M>G5E;&$`3W9E<F5N:64@>FQY:&%L;R`M('3A=&\@<W!RX79A(&UO:&QA(&)Y
MNR!S9F%LN6]V86[A+@!697)Z:6$`36%N8;YM96YT('9E<GII[0!697)T:6OA
M;&YE('IA<F]V;F%N:64`5F5R=&EKX6QN92!V>7!L;F5N:64`5F5R=&EKX6QN
M93H`5F6U;6D@=GES;VOA`%9I971N86T`6F]B<F%Z:;L@)7,`6F]B<F%Z:;L@
M97AT97)N^B!W=W<@<W1RX6YK=0!:;V)R87IINR!A:V\@)7,`0G)I='-KZ2!0
M86YE;G-KZ2!O<W1R;W9Y`$%M97)I8VOI(%!A;F5N<VOI(&]S=')O=GD`5FED
M:71EM6YO<[L`5FED:71EM6YO<[LZ(`!6;V1A9F]N92!)=&%L>2!C97H@4TU4
M4`!605)/5D%.244`55!/6D]23D5.244A(2$@3T135%+!TE1%(%-+4DE05"!:
M("5S(%)5R$Y%+@!786QL:7,@82!&=71U;F$`5F%R;W9A;FEE`%9A<F]V86YI
M93H@`%-T`%!R961P;W9E[R!P;^AA<VEA`-ID86IE(&\@<&_H87/M('!O<VMY
M='5J90!796%T:&5R+F-O;0!796(`5U=7('-T<N%N:V$`5/V^9&5N;F4`5FET
M86IT90!6[71A(%;A<R`E<P!6:71A:G1E+"`E<P!:X7!A9&[A(%-A:&%R80!+
M=&]R^B!A<&QI:^%C:74@;>$@)7,@>F]B<F%Z:;L@<&\@<')I:&SA<V5N[3\`
M06O](&IE('IN86L@<')E(&]D9&6U;W9AZ#\`06O](&IE('IN86L@<')E(/IV
M;V1Z;W9K=3\`2W1O<ND@9N%Z>0!+=&]RZ2!ZX7-U=F[I(&UO9'5L>2!P;W9O
M;&F[('!R92!R;WJY[7)E;OT@=&5X=&]V_2!E9&ET;W(N`*GM<FMA`*GM<FMA
M('8@:F5D;F]T:^%C:"!#4U,`J>UR:V$@;65N=2`E<R!VM6%V;R`H<')E:F%V
M[2!S82!P<FD@[V%LN6]M('!R:6ALX7-E;NTI.@"I[7)K82!T86)UM6MY`$IE
M9&YO=&MA(+GM<FMY`*GM<FMA.@!7:6MI`%9I971O<@!2X6YO('9I971O<@!2
M_6-H;&]SNR!V971R82!V('5Z;&]C:`!6:65T;W(Z`%9I971O<CH@`$WZ9')O
M<[L`5VES:&QI<W1S`%!RX6-A`$%D<F5S82!D;R!P<N%C90!496QE9O-N(&1O
M('!RX6-E`%IA<&ES=6IE('-A(&%K='5A;&EZ;W9A;OT@<_IB;W(@<&]M;V-N
M[6MA(&1O("5S+@!8+5)E9@!:X6ML861NZ2!O8FUE9'IE;FEA(%@U,#EV,P!0
M;W6^:71I92!R;WJY[7)E;NEH;R!KM?KH82!8-3`Y=C,`06QT97)N873M=FYE
M(&UE;F\@<W5B:F5K='4@6#4P.78S`$ED96YT:69I:^%T;W(@:[7ZZ&$@<W5B
M:F5K='4@6#4P.78S`%@U,#EV,R!R;WJY[7)E;FEA`%E9`%E965D`66%H;V\A
M(&UA<`!2;^AN90!*96UE;@!!;F\`4_IH;&%S[6TN`%-T92!V(%1%6%1/5D]-
M(%)%KDE-12X@4&]UOFET92!T;&'H:61L;R!;/#Y=(&YA('!R97!N=71I92!N
M87-PY+L@9&\@5UE325=91RX`3FEE('-T92!A=71E;G1I9FEK;W9A;OTN`%9O
M(%9AN6]M(&UE;F4@;F5M]+YE=&4@<&]UOFF[('IN86L@)UPG+@!.96WTOF5T
M92!Z;65N:;L@:&5S;&\@<')E('!O=;[M=F%T9;5A("5S`$YE>F%D86QI('-T
M92!P;&%T;OH@92UM86EL;W;Z(&%D<F5S=2X`3F5U<NAI;&D@<W1E('9ZNV%H
M(&UE9'II(+YI861N>6UI('!O;&EA;6D@>B!I;7!O<G1O=F%NZ6AO('/Z8F]R
M=2!A('IO9'!O=F5D86KZ8VEM:2!P;[5A;6D@=B`E<RX`0F]L:2!S=&4@;V1H
M;.%S96[]+@!-=7/M=&4@>F%D8;L@<&QA=&[I(.CM<VQO(&UO8FEL;NEH;R!T
M96QE9O-N=2P@:W1O<ND@;V)S86AU:F4@:6)A(.CM<VQA(',@=F]L:71EM6[]
M;2!P<F5F:7AO;2`G*R<@<')E(&UE9'II;N%R;V1N_2!F;W)MX70N`$UU<^UT
M92!Z861ANR!P;&%T;OH@:&]D;F]T=2X`06)Y('-T92!M;VAL:2!P;W6^[79A
MNR!296=I<W1RX6-I92P@;75S[71E(&YA:G-K]'(@<VMO;F9I9W5R;W9ANR!$
M871A5')E92!B86-K96YD+@!-=7/M=&4@<VMO;F9I9W5R;W9ANR!61E,@8F%C
M:V5N9"X`375S[71E('!O<.US8;L@<')O8FSI;2!P<F5D=/UM+"!A:V\@;V1O
MN6QE=&4@<W!RX79U(&\@<')O8FSI;64N`$UU<^UT92!Z861ANR!54DP@861R
M97-U+"!N82!K=&]R^B!TX71O(&QI;FMA('5K87IU:F4`375S[71E('IA9&&[
M(%9AN64@86MT=>%L;F4@:&5S;&\`375S[71E('IA9&&[(%9AN64@;F]VZ2!H
M97-L;P!-=7/M=&4@=GEB<F&[('-E<G9E<BP@:W1O<OT@;>$@8GF[('9Y;6%Z
M86[]+@!-=7/M=&4@=7+H:;L@;65N;R!P;W6^[79A=&6U82P@:W1O<NEH;R!C
M:&-E=&4@=GEM87IANRX`375S[71E('5RZ&F[(&UE;F\@<&]UONUV871EM6$L
M(&MT;W+I:&\@8VAC971E('9Y;6%Z8;LN`$UU<^UT92!U<NAINR!M96YO('!O
M=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!P<FED8;LN`$UU<^UT92!U<NAI
MNR!P;W6^[79A=&6U82P@:W1O<OT@<V$@;>$@86MT=6%L:7IO=F&[+@!-=7/M
M=&4@=7+H:;L@86MC:74L(&MT;W+A('-A(&WA('9Y:V]N8;LN`$UU<^UT92!Z
M861ANR!M96YO(&YO=F5J(&MA=&5G\W)I92X`375S[71E(&6Y=&4@<F%Z('IA
M9&&[(%9AN64@;F]VZ2!H97-L;P!0;&%T;F]SNR!68;EE:B!R96SA8VEE('!R
M92!A<&QI:^%C:74@)7,@=GEP<KEA;&$N(%!R;W/M;2!P<FEH;.%S=&4@<V$@
M>FYO=G4N`%9AN6$@16UA:6QO=N$@861R97-A`%9AN6$@16UA:6QO=N$@861R
M97-A('!O=;YI=.$@<')E(&]D8VCA9'IA:OIC=2!P;[ET=3H`5F&Y92!I;F9O
M<FWA8VEE`%9AN6$@:6YT97)N971O=N$@861R97-A('-A('IM96YI;&$@;V0@
M>F'H:6%T:W4@5F&Y96H@<F5LX6-I92`E<RX@4')E(%9AN74@8F5Z<&7H;F]S
MNR!S82!M=7/M=&4@>FYO=G4@<')I:&SA<VF[+@!68;EE(&UE;F\`5N&Y(&%U
M=&5N=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('!R:63A=F%N:64@<&]U
MONUV871EM6]V+"!A;&5B;R!B;VQA('3A=&\@;6^^;F]SNR!Z(&YE:F%KZ6AO
M(&3T=F]D=2!Z86OA>F%NX2X`5N&Y(&%U=&5N=&EF:6MAZ&[](&UO9'5L(&YE
M<&]D<&]R=6IE('IO8G)A>F]V86YI92!Z;WIN86UU('!O=;[M=F%T9;5O=BP@
M86QE8F\@8F]L82!TX71O(&UOOFYO<[L@>B!N96IA:^EH;R!D]'9O9'4@>F%K
MX7IA;N$N`%IDX2!S82P@OF4@5N&Y('!R96AL:6%D8>@@<V$@>FUE;FEL(&]D
M('IAZ&EA=&MU(%9AN65J(')E;.%C:64@)7,N(%!R92!68;EU(&)E>G!EZ&YO
M<[L@<V$@;75S[71E('IN;W9U('!R:6ALX7-INRX`5N&Y('!R96AL:6%D8>@@
M;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU+@!6X;D@<')E:&QI861AZ"!N97!O
M9'!O<G5J92!T^G1O(&9U;FMC:74@=&QAZ&4N(%-T;&'H=&4@0V]N=')O;"]/
M<'1I;VX@*R!0('!R92!T;&'H+@!68;EA(&%K='7A;&YA(.AA<V]VX2!Z\VYA
M.@!0<F5D;F%S=&%V96[A(&ED96YT:71A.@!68;EE(&UE;F\Z`%9E<GII82!P
M<F]G<F%M=2!G971T97AT(&IE('!R[6QIN2!S=&%RX2!A(&YE<&]D<&]R=6IE
M(&YA=.UV;F4@4$A0+@I.97!O9&%R[2!S82!Z[7-K8;L@=KEE=&MY(')ENV%Z
M8V4N`%9AN64@;F]VZ2!H97-L;R!P<F4@)7,@:F4Z("5S`%9AN64@;F]VZ2!H
M97-L;R!J92!P<NUL:;D@9&QHZ3L@:&5S;.$@;F5S;?H@8GF[(&1L:+EI92!A
M:V\@)60@>FYA:V]V(0!68;EE(&YO=ND@:&5S;&\@:F4@<'+M;&FY(&IE9&YO
M9'5C:.D@;F$@=6CA9&YU=&EE(2!.97IM96YE;NDA`%9AN64@;F]VZ2!H97-L
M;R!J92!P<NUL:;D@:F5D;F]D=6-HZ2!N82!U:.%D;G5T:64N($YE>FUE;F5N
MZ2$`5F&Y92!N;W;I(&AE<VQO(&UU<^T@;6&[(&%S<&_R("5D('IN86MO=B$`
M5F&Y92!N;W;I(&AE<VQO(&UU<^T@8GF[(&ENZ2!A:V\@86MT=>%L;F4@:&5S
M;&\`5F&Y92!N;W;I(&AE<VQO(&UU<^T@;V)S86AO=F&[(&YA:FUE;F5J("5D
M('#M<VUE;BX`5F&Y92!N;W;I(&AE<VQO(&UU<^T@;V)S86AO=F&[(&YA:FUE
M;F5J("5D(&%L9F%N=6UE<FEC:_UC:"!Z;F%K;W8N`%9AN64@;F]VZ2!H97-L
M;R!M=7/M(&]B<V%H;W9ANR!N86IM96YE:B`E9"!T>7!O=B!Z;F%K;W8N(%1Y
M<'D@>FYA:V]V('/Z.B!M86SI('#M<VUE;N$L('9EM6OI('#M<VUE;N$L(.CM
M<VQI8V4@82!S>6UB;VQY+@!68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V
M8;L@;F%J;65N96H@)60@;6%L_6-H('#M<VUE;BX`5F&Y92!N;W;I(&AE<VQO
M(&UU<^T@;V)S86AO=F&[(&YA:FUE;F5J("5D(.CM<VQI8RX`5F&Y92!N;W;I
M(&AE<VQO(&UU<^T@;V)S86AO=F&[(&YA:FUE;F5J("5D('9EM6O]8V@@<.US
M;65N+@!68;EE(&YO=ND@:&5S;&\@;75S[2!O8G-A:&]V8;L@;65N96H@86MO
M("5D(&UE9'II97(N`%9AN64@;F]VZ2!H97-L;R!N97-M:64@;V)S86AO=F&[
M(&UE9'IE<GDN`%9AN64@;F]VZ2!H97-LX2!N:64@<_H@<F]V;F%KZ0!68;EE
M(&YA<W1A=F5N:6$@8F]L:2!A:W1U86QI>F]V86[I('!R92!T^G1O(')E;.%C
M:74N`%9AN64@;F%S=&%V96YI82!B;VQI(&%K='5A;&EZ;W9A;NDN`%9AN64@
M:&5S;&\@8F]L;R!O8FYO=F5NZ0!68;EE(&AE<VQO(&)O;&\@;V)N;W9E;NDL
M('-K;VYT<F]L=6IT92!S:2!P;[ET=2!A('!R:6ALX7-T92!S82!S(%9AN>UM
M(&YO=OUM(&AE<VQO;2X`5F&Y92!H97-LX2!N:64@<_H@<F]V;F%KZ0!68;EE
M('9Z9&EA;&5NZ2!S97)V97)Y.@!*=6AO<VSA=FEA`%IA:7(`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M3:W)YNR!C:71O=F%N_2!T97AT70!;4W!RX79A(&\@
M<')O8FSI;65=`%M:;V)R87IINR!C:71O=F%N_2!T97AT("T`6UIO8G)A>FF[
M(&-I=&]V86[]('1E>'0@+2`E<R!R:6%D:V]V70!;<FEA9&]K("5S('H@)7-=
M`%]!9&UI;FES='+A8VEA`%]#3$D`7T1A=&%4<F5E`%]6>6UA>F&[(')I861O
M:P!?4VMU<&EN>0!?4&]M;V-N[6L`5FQA<W1N;W-T:2!?;V)RX7IK=2XN+@!?
M4')I:&SA<VF[('-A`%]/9&ALX7-INR!S80!?57!R879INR!L:6YK=2XN+@!?
M3F%S=&%V96YI80!?4'+A=F$`3V1S=%]RX6YINR!L:6YK=2XN+@!.85]S=&%V
M96YI90!6;&%S=&YO<W1I(%]T86)UM6MY+BXN`%!O7W6^[79A=&5L:6$`861R
M97/A<@!N87-T86QA(&-H>6)A.@!K86QE;F3A<@!B97IV971R:64`:VQI:VYI
M=&4@<V5M`&AO=&]V;P!C:'EB80!K;&5SX0!S^F)O<@!NX6ID96[].B``>F\@
M<VUE<G4@)7,@*"5S*2!R_6-H;&]SNV]U("5S("5S`'8Z`&AH`&]K86V^:71E
M`'8@<W!RX79E`&QD87!?<W1A<G1?=&QS('IL>6AA;&\`<FEA9&MO=ET`<&_H
M87,@=GET=N%R86YI82!)4T\@;F%S=&%L82!C:'EB82!M:VES;V9S("5D`&UM
M`&UE;F\`;F5Z;65N96[]`&YE;N%J9&5N_0!N96EM<&QE;65N=&]V86[I`'IA
M=&EAM2!N96EM<&QE;65N=&]V86[I`'!O>F[A;6MO=OT@8FQO:P!P97)C96YT
M`&)O9&]V`'-T^G!A`'IO8G)A>FF[(')O>F1I96QY`'-M<S)E;6%I;"!C97H@
M2%144`!S<P!U<W3A;&5N_0!Z;WIN86T@^FQO:`!03R!S^F)O<B!(;W)D92!P
M<F4@;&]K86QI>N%C:74@)7,@;F5E>&ES='5J93H`<')E('!O='9R9&5N:64@
M>F%D86IT92!H97-L;R!D=F%K<N%T`'5N:69I:V]V86[I`&YE<&]M96YO=F%N
MX0!A:W1U86QI>F]V86[]`&1E9FEN=6IE('!O=;[M=F%T9;4`=D-A<F0`N3H`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D
M+VQO8V%L92]S=E]312\`````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P,C`R,#,`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P87-S=V0O;&]C86QE+W-V7U-%+TQ#7TU%4U-!1T53+P``
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R
M,3<W,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O<W9?
M4T4O3$-?34534T%'15,O<&%S<W=D+FUO````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,C$Q
M,S<`,3`T,3<S-C(W-#0`,#(S-C,P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-X2!)4`````K0(``!P```"$%0``EP,``.PJ
M````````2#D``$@```!).0``#````)(Y```1````GSD``"4```"Q.0``#P``
M`-<Y```+````YSD``!$```#S.0``*`````4Z```(````+CH``!4````W.@``
M$P```$TZ```*````83H```T```!L.@``#@```'HZ```D````B3H``"D```"N
M.@``&0```-@Z```/````\CH``!@````".P``#@```!L[```.````*CL```@`
M```Y.P``+@```$([```'````<3L```H```!Y.P``#P```(0[```%````E#L`
M`!$```":.P``"````*P[```)````M3L```D```"_.P``$````,D[```*````
MVCL```,```#E.P``#P```.D[```)````^3L```T````#/```&0```!$\```>
M````*SP```\```!*/```#P```%H\```(````:CP``"0```!S/```"````)@\
M``!.````H3P``"T```#P/```&0```!X]```,````.#T```X```!%/0```P``
M`%0]```%````6#T```H```!>/0```P```&D]```7````;3T```H```"%/0``
M#P```)`]```.````H#T``",```"O/0``%````-,]```7````Z#T``!<`````
M/@``%P```!@^```3````,#X```\```!$/@``!@```%0^```+````6SX``!``
M``!G/@``%0```'@^```5````CCX```<```"D/@``!0```*P^```[````LCX`
M`#@```#N/@```P```"<_```)````*S\``#D````U/P``)P```&\_```L````
MES\``"H```#$/P``)0```.\_```&````%4```!$````<0```"@```"Y````0
M````.4```"<```!*0```"````')````.````>T````H```"*0```!````)5`
M```)````FD````8```"D0```$0```*M````'````O4````0```#%0```!@``
M`,I````B````T4````T```#T0````P````)!```3````!D$```@````:00``
M!````"-!``!!````*$$```8```!J00``%0```'%!```'````AT$``!4```"/
M00``#P```*5!```-````M4$```\```##00``#0```--!```&````X4$```8`
M``#H00``5````.]!```4````1$(```0```!90@``1````%Y"```<````HT(`
M`"4```#`0@``!0```.9"```2````[$(```H```#_0@``#P````I#```,````
M&D,```8````G0P``!@```"Y#```%````-4,```P````[0P``!0```$A#```&
M````3D,```<```!50P``#0```%U#```0````:T,```D```!\0P``"0```(9#
M```9````D$,``!T```"J0P``#````,A#```0````U4,``!4```#F0P``"```
M`/Q#```&````!40```0````,1```#@```!%$```0````($0``"8````Q1```
M(````%A$```N````>40``!<```"H1```(````,!$```E````X40``"@````'
M10``+0```#!%```P````7D4``"H```"/10``!P```+I%```&````PD4```T`
M``#)10``$````-=%```3````Z$4```T```#\10``#`````I&```.````%T8`
M``\````F1@``$P```#9&```-````2D8``"@```!81@```P```(%&```"````
MA48```0```"(1@``$````(U&```-````GD8```,```"L1@``#@```+!&```(
M````OT8```\```#(1@``#P```-A&```'````Z$8```T```#P1@``$P```/Y&
M```+````$D<```8````>1P``#````"5'```+````,D<```T````^1P``(@``
M`$Q'```;````;T<```H```"+1P``&````)9'```9````KT<``!8```#)1P``
M"P```.!'```+````[$<```D```#X1P``%@````)(```/````&4@``!8````I
M2```#0```$!(```O````3D@```0```!^2```"@```(-(```*````CD@``!``
M``"92```%P```*I(```1````PD@``!<```#42```&0```.Q(```)````!DD`
M``T````020``#@```!Y)```%````+4D```<````S20``$````#M)```/````
M3$D``!````!<20``#P```&U)```/````?4D```P```"-20``#P```)I)```'
M````JDD``!\```"R20``"````-))```,````VTD```<```#H20``"@```/!)
M```-````^TD```H````)2@``!````!1*```F````&4H``!4```!`2@``!0``
M`%9*```&````7$H```@```!C2@``%@```&Q*```"````@TH```8```"&2@``
M"0```(U*```0````ETH```D```"H2@``"0```+)*```9````O$H```X```#6
M2@``(@```.5*```.````"$L```T````72P``%````"5+```1````.DL```8`
M``!,2P``$0```%-+```1````94L```D```!W2P``!@```(%+```$````B$L`
M``0```"-2P``!0```))+```%````F$L``!(```">2P``"@```+%+```,````
MO$L```\```#)2P``$````-E+```.````ZDL```\```#Y2P``$@````E,```0
M````'$P``!$````M3```#P```#],```+````3TP``!0```!;3```#````'!,
M```,````?4P``!4```"*3```*0```*!,```J````RDP``"<```#U3```&0``
M`!U-```1````-TT``!(```!)30``$P```%Q-```4````<$T``!8```"%30``
M%P```)Q-```0````M$T``!$```#%30``$P```-=-```2````ZTT```X```#^
M30``%`````U.```&````(DX```<````I3@``!````#%.```$````-DX```<`
M```[3@``#@```$-.```,````4DX```P```!?3@``#0```&Q.```$````>DX`
M``<```!_3@``"````(=.```)````D$X```P```":3@``#0```*=.```&````
MM4X```0```"\3@``"@```,%.```0````S$X```L```#=3@``&@```.E.```,
M````!$\```@````13P``!@```!I/```'````(4\```L````I3P``!@```#5/
M```#````/$\```(```!`3P``!````$-/```3````2$\```4```!<3P``!@``
M`&)/```/````:4\``!@```!Y3P``%P```))/```#````JD\```<```"N3P``
M"@```+9/```+````P4\``$H```#-3P``!@```!A0```8````'U```!<````X
M4````@```%!0```+````4U````P```!?4```#0```&Q0```,````>E````H`
M``"'4```!P```))0```%````FE````P```"@4```"````*U0```7````ME``
M``T```#.4```$P```-Q0```$````\%````H```#U4```!`````!1```*````
M!5$```4````040``"@```!91```L````(5$``!4```!.40``#P```&11```(
M````=%$```@```!]40``*P```(91```$````LE$```<```"W40``20```+]1
M```%````"5(```8````/4@``"````!92```"````'U(```X````B4@``!P``
M`#%2```&````.5(```T```!`4@``7````$Y2```4````JU(``!\```#`4@``
M!P```.!2```.````Z%(```@```#W4@``#`````!3```%````#5,``!$````3
M4P``$0```"53```(````-U,```D```!`4P``!P```$I3```/````4E,```L`
M``!B4P``"@```&Y3```(````>5,``!$```""4P``*@```)13```)````OU,`
M``H```#)4P``%0```-13```%````ZE,``!0```#P4P``!`````54```'````
M"E0``!X````25```*````#%4```*````6E0``!P```!E5```&@```()4```4
M````G50```8```"R5```-````+E4```I````[E0``"@````850``*0```$%5
M``!1````:U4```@```"]50``!0```,95```-````S%4```<```#:50``#@``
M`.)5```3````\54```@````%5@``!0````Y6```$````%%8```L````95@``
M#0```"56```,````,U8```0```!`5@``,@```$56``!%````>%8``!X```"^
M5@``%````-U6```'````\E8```X```#Z5@``!@````E7```,````$%<``!$`
M```=5P``"P```"]7```*````.U<```L```!&5P``#P```%)7```%````8E<`
M``X```!H5P``$P```'=7```'````BU<```@```"35P``$0```)Q7```4````
MKE<``!@```##5P``!P```-Q7```%````Y%<``!(```#J5P``#@```/U7```.
M````#%@```4````;6````P```"%8```-````)5@```D````S6````P```#U8
M```*````05@```(```!,6```!````$]8```'````5%@```D```!<6```#```
M`&98```7````<U@```<```"+6```!@```)-8```.````FE@``"(```"I6```
M%0```,Q8```2````XE@```\```#U6```%`````59``!I````&ED``!H```"$
M60``%P```)]9```G````MUD``!H```#?60``%P```/I9```;````$EH``!D`
M```N6@``'P```$A:```)````:%H``#<```!R6@``5P```*I:```%`````EL`
M``T````(6P``!````!9;```E````&UL``!\```!!6P``'0```&%;```'````
M?UL```T```"'6P``#````)5;```9````HEL```0```"\6P``"P```,%;```,
M````S5L``!(```#:6P``$0```.U;```,````_UL``#H````,7```#0```$=<
M```'````55P```0```!=7```%P```&)<```*````>EP```P```"%7```"0``
M`))<```&````G%P```@```"C7```"0```*Q<```&````MEP```T```"]7```
M`@```,M<```<````SEP```D```#K7```!P```/5<```F````_5P``#@````D
M70``&@```%U=```J````>%T``"@```"C70``-````,Q=```9`````5X``!4`
M```;7@``!P```#%>```(````.5X```<```!"7@``!0```$I>```'````4%X`
M``X```!87@``"0```&=>```&````<5X```@```!X7@``"P```(%>```'````
MC5X``!````"57@``$````*9>```'````MUX```4```"_7@``"P```,5>```-
M````T5X``!<```#?7@``"0```/=>```*`````5\```(````,7P``)P````]?
M```C````-U\``!T```!;7P``&````'E?```A````DE\``!\```"T7P``'0``
M`-1?```1````\E\``"`````$8```,@```"5@```Q````6&```$$```"*8```
M,P```,Q@```E`````&$``'0````F80``<P```)MA```+````#V(``',````;
M8@``!P```(]B```-````EV(```L```"E8@``!0```+%B```%````MV(```@`
M``"]8@```P```,9B```0````RF(```H```#;8@``#````.9B```"````\V(`
M``,```#V8@``!````/IB```:````_V(```D````:8P``#````"1C```'````
M,6,``!,````Y8P``&@```$UC```,````:&,```8```!U8P``"0```'QC```+
M````AF,```T```"28P``%P```*!C```&````N&,```8```"_8P``$P```,9C
M```1````VF,``#(```#L8P``$````!]D```(````,&0```D````Y9```"@``
M`$-D```4````3F0```@```!C9```#P```&QD```.````?&0``!````"+9```
M"0```)QD```)````IF0```(```"P9````P```+-D```(````MV0```<```#`
M9```#0```,AD```+````UF0``"\```#B9```(````!)E```<````,V4``#$`
M``!090``!0```()E```_````B&4``!(```#(90``!@```-ME```$````XF4`
M`!,```#G90``!0```/ME```&`````68```8````(9@``"0````]F```$````
M&68```(````>9@``#````"%F```E````+F8``$4```!49@``,````)IF```?
M````RV8``!\```#K9@``*`````MG```I````-&<``"8```!>9P``)0```(5G
M```H````JV<``"$```#49P``$@```/9G```3````"6@``!`````=:```"0``
M`"YH``!R````.&@``',```"K:```*P```!]I``!3````2VD``!<```"?:0``
M%@```+=I```/````SFD``!\```#>:0``'P```/YI```?````'FH``!P````^
M:@``40```%MJ```4````K6H``!(```#":@``$````-5J```3````YFH```\`
M``#Z:@``!`````IK```)````#VL```L````9:P``!P```"5K```4````+6L`
M``\```!":P``#````%)K```/````7VL```8```!O:P``%````'9K```&````
MBVL``!4```"2:P``!````*AK```$````K6L```8```"R:P``!P```+EK```'
M````P6L``!D```#):P``!````.-K```&````Z&L```8```#O:P``!````/9K
M```+````^VL```D````';```!P```!%L```&````&6P```8````@;```$```
M`"=L```B````.&P```<```!;;```!P```&-L```+````:VP``"L!``!W;```
M3````*-M```,````\&T``!$```#];0``)@````]N```4````-FX``!$```!+
M;@``%````%UN```C````<FX```@```"6;@``$@```)]N```4````LFX```H`
M``#';@``"@```-)N```0````W6X``"````#N;@``)@````]O```7````-F\`
M`!$```!.;P``'0```&!O```1````?F\``!$```"0;P``"0```*)O```J````
MK&\```X```#7;P``$````.9O```8````]V\```4````0<```"@```!9P```%
M````(7````8````G<```!@```"YP```.````-7````8```!$<```"0```$MP
M```4````57````X```!J<```$@```'EP```=````C'```"(```"J<```&@``
M`,UP```4````Z'````T```#]<```*@````MQ```3````-G$``$P```!*<0``
M+P```)=Q```D````QW$```D```#L<0``#@```/9Q```&````!7(```<````,
M<@``"@```!1R```$````'W(``!T````D<@``#````$)R```1````3W(```\`
M``!A<@``)@```'%R```:````F'(``!T```"S<@``(0```-%R```9````\W(`
M``\````-<P``$````!US```$````+G,```L````S<P``$0```#]S```6````
M47,``!\```!H<P``!P```(AS```%````D',``#$```"6<P``0@```,AS```%
M````"W0```L````1=```.P```!UT```O````670``#0```")=```+@```+YT
M```M````[70```<````;=0``$@```"-U```(````-G4```T````_=0``*P``
M`$UU```(````>74``!(```""=0``"````)5U```#````GG4```D```"B=0``
M`P```*QU```)````L'4```4```"Z=0``!````,!U```&````Q74``"(```#,
M=0``"@```.]U```#````^G4``!8```#^=0``"````!5V```%````'G8``$4`
M```D=@``!@```&IV```5````<78```8```"'=@``%P```(YV```1````IG8`
M``X```"X=@``$0```,=V```.````V78```D```#H=@``!0```/)V``!5````
M^'8```P```!.=P``!@```%MW```H````8G<``!L```"+=P``(P```*=W```%
M````RW<``!,```#1=P``#P```.5W```2````]7<```T````(>```!````!9X
M```(````&W@```0````D>```#0```"EX```)````-W@```L```!!>```"```
M`$UX```/````5G@``!8```!F>```"@```'UX```'````B'@``!@```"0>```
M(0```*EX```.````RW@``!$```#:>```%P```.QX```(````!'D```8````-
M>0``!P```!1Y```1````''D``!,````N>0``*P```$)Y```D````;GD``"D`
M``"3>0``&P```+UY```D````V7D``"0```#^>0``*P```"-Z```L````3WH`
M`"<```!\>@``*0```*1Z```&````SGH```4```#5>@``"@```-MZ```(````
MYGH``!8```#O>@``"P````9[```+````$GL```X````>>P``#@```"U[```2
M````/'L```P```!/>P``-@```%Q[```(````DWL```(```"<>P``!````)][
M```2````I'L```X```"W>P```P```,9[```.````RGL```@```#9>P``"0``
M`.)[```-````['L```<```#Z>P``#`````)\```2````#WP```P````B?```
M!@```"]\```,````-GP```L```!#?```#0```$]\```?````77P``!H```!]
M?```"@```)A\```5````HWP``!4```"Y?```$@```,]\```+````XGP```H`
M``#N?```!P```/E\```7`````7T``!4````9?0``%P```"]]```+````1WT`
M`"T```!3?0``!0```(%]```+````AWT```L```"3?0``$````)]]```9````
ML'T``!@```#*?0``&0```.-]```;````_7T```H````9?@``#0```"1^```/
M````,GX```,```!"?@``!0```$9^```.````3'X```X```!;?@``#@```&I^
M```-````>7X```\```"'?@``"P```)=^```2````HWX```,```"V?@``)@``
M`+I^```(````X7X```P```#J?@``!@```/=^```-````_GX```X````,?P``
M"````!M_```#````)'\``"4````H?P``%````$Y_```(````8W\```4```!L
M?P``#0```')_```9````@'\```(```":?P``!@```)U_```)````I'\``!<`
M``"N?P``"````,9_```$````SW\``!T```#4?P``#0```/)_```@`````(``
M``P````A@```#0```"Z````3````/(```!$```!0@```!P```&*````0````
M:H```!````![@```!P```(R````$````E(````4```"9@````P```)^````$
M````HX````4```"H@```$````*Z````-````OX````T```#-@```#P```-N`
M```2````ZX```!4```#^@```$@```!2!```4````)X$``!$````\@0``$0``
M`$Z!```*````8($```L```!K@0``%````'>!```+````C($```T```"8@0``
M$P```*:!```E````NH$``"0```#@@0``'@````6"```6````)((``!$````[
M@@``$````$V"```3````7H(``!(```!R@@``%0```(6"```4````FX(``!``
M``"P@@``#P```,&"```1````T8(``!$```#C@@``"P```/6"```5`````8,`
M``8````7@P``!P```!Z#```$````)H,```0````K@P``!P```#"#```-````
M.(,```P```!&@P``#@```%.#```,````8H,```0```!O@P``!P```'2#```%
M````?(,```P```""@P``#0```(^#```2````G8,```8```"P@P``!P```+>#
M```(````OX,```\```#(@P``#````-B#```B````Y8,```L````(A```!0``
M`!2$```(````&H0```@````CA```$````"R$```(````/80```,```!&A```
M`@```$J$```&````380```X```!4A```!````&.$```(````:(0```X```!Q
MA```*````("$```G````J80```,```#1A```"0```-6$```)````WX0```\`
M``#IA```3````/F$```&````1H4``"<```!-A0``)@```'6%```"````G(4`
M``P```"?A0``#P```*R%```1````O(4``!````#.A0``!@```-^%```'````
MYH4```8```#NA0``"P```/6%```&`````88``!P````(A@``#@```"6&```5
M````-(8```<```!*A@``#0```%*&```%````8(8```H```!FA@``!````'&&
M```.````=H8``"\```"%A@``%P```+6&```5````S88```L```#CA@``"@``
M`.^&```L````^H8```4````GAP``"@```"V'```\````.(<```P```!UAP``
M#````(*'```(````CX<```(```"8AP``#0```)N'```'````J8<```8```"Q
MAP``$0```+B'``!9````RH<``!0````DB```&0```#F(```-````4X@``!0`
M``!AB```#@```':(```.````A8@```4```"4B```$P```)J(```0````KH@`
M``<```"_B```"````,>(```/````T(@``!H```#@B```&@```/N(```)````
M%HD```@````@B0``%````"F)```M````/HD```D```!LB0``"@```':)```9
M````@8D```H```";B0``(@```*:)```&````R8D```<```#0B0``&@```-B)
M```J````\XD```H````>B@``'P```"F*```9````28H``!4```!CB@``!0``
M`'F*```F````?XH``"````"FB@``'0```,>*```D````Y8H``%L````*BP``
M!P```&:+```.````;HL```X```!]BP``#P```(R+```1````G(L``!(```"N
MBP``"````,&+```%````RHL```0```#0BP``"@```-6+```,````X(L```T`
M``#MBP```P```/N+```Y````_XL``$H````YC```(````(2,```3````I8P`
M``L```"YC```#0```,6,```'````TXP```T```#;C```$P```.F,```+````
M_8P```<````)C0``$0```!&-```5````(XT```D````YC0``$@```$.-```2
M````5HT```@```!IC0``"0```'*-```;````?(T``!<```"8C0``(@```+"-
M```%````TXT```4```#9C0``%````-^-```0````](T``!`````%C@``!@``
M`!:.```#````'8X```\````AC@``"````#&.```#````.HX```D````^C@``
M`@```$B.```%````2XX```@```!1C@``"````%J.```3````8XX``!T```!W
MC@``"0```)6.```#````GXX```H```"CC@``&P```*Z.```9````RHX```T`
M``#DC@``"P```/*.```=````_HX``&`````<CP``&````'V/```1````EH\`
M`!T```"HCP``%````,:/```0````VX\``!@```#LCP``%0````60```9````
M&Y````D````UD```.@```#^0``!;````>I````4```#6D```#@```-R0```$
M````ZY```"L```#PD```(0```!R1```>````/I$```8```!=D0``#0```&21
M```+````<I$``"````!^D0```P```)^1```'````HY$```D```"KD0``$```
M`+61```.````QI$```D```#5D0``-@```-^1```1````%I(```D````HD@``
M!````#*2```=````-Y(```D```!5D@``"P```%^2```(````:Y(```4```!T
MD@``"````'J2```)````@Y(```8```"-D@``#````)22```"````H9(``"$`
M``"DD@``"````,:2```&````SY(``!L```#6D@``)P```/*2```/````&I,`
M`!T````JDP``'````$B3```?````99,``!(```"%DP``"````)B3```/````
MH9,```H```"QDP``"@```+R3```&````QY,```H```#.DP``$@```-F3```,
M````[),```H```#YDP``#`````24```'````$90```<````9E```$P```"&4
M```3````-90```0```!)E```"0```$Z4```*````6)0```P```!CE```%@``
M`'"4```+````AY0```T```"3E````@```*&4```K````I)0``!L```#0E```
M'````.R4```/````"94``!8````9E0``%0```#"5```9````1I4```T```!@
ME0``'````&Z5```Q````BY4``#$```"]E0``0P```.^5```L````,Y8``",`
M``!@E@``<P```(26``!U````^)8```X```!NEP``70```'V7```$````VY<`
M``\```#@EP``"@```/"7```%````^Y<```0````!F```!P````:8```#````
M#I@``!`````2F```"````".8```.````+)@```(````[F````P```#Z8```$
M````0I@``!<```!'F```#````%^8```/````;)@``!````!\F```$@```(V8
M```3````H)@```L```"TF```"0```,"8```,````RI@``!,```#7F```$0``
M`.N8```;````_9@```D````9F0``"P```".9```6````+YD``!0```!&F0``
M)@```%N9```4````@ID```P```"7F0``#0```*29```.````LID``!4```#!
MF0``"````->9```0````X)D``!(```#QF0``$@````2:```)````%YH```D`
M```AF@```@```"N:```$````+IH```<````SF@``"0```#N:```1````19H`
M``T```!7F@``,@```&6:```>````F)H``",```"WF@``,P```-N:```%````
M#YL``$(````5FP``"P```%B;```&````9)L```0```!KFP``%````'";```%
M````A9L```8```"+FP``!@```)*;```*````F9L```8```"DFP```@```*N;
M```1````KIL``"L```#`FP``00```.R;```H````+IP``!\```!7G```(0``
M`'><```J````F9P``#````#$G```,0```/6<```U````)YT``#0```!=G0``
M)````)*=```1````MYT``!$```#)G0``#P```-N=```)````ZYT``%\```#U
MG0``8````%6>```N````MIX``%L```#EG@``%0```$&?```7````5Y\``!<`
M``!OGP``'P```(>?```K````IY\``",```#3GP``(P```/>?``!7````&Z``
M`!(```!SH```$@```(:@```0````F:```!0```"JH```#P```+^@```$````
MSZ````D```#4H```"P```-Z@```(````ZJ```!4```#SH```#@````FA```-
M````&*$``!`````FH0``!@```#>A```7````/J$```H```!6H0``%@```&&A
M```%````>*$```0```!^H0``#````(.A```(````D*$```D```"9H0``&0``
M`*.A```$````O:$```8```#"H0``!@```,FA```$````T*$```L```#5H0``
M#0```.&A```'````[Z$```8```#WH0``"````/ZA```/````!Z(``"L````7
MH@``!````$.B```*````2*(```L```!3H@```0```$L"````````^P```+L!
M``#=`0``O`$``'P"``!1````(@$````````4`@``'0```,,!``!9````D@``
M``8"```Z`0``'@(``(H!````````>0````````!0`0``?@$``,X!```Z`@``
MH0```,P``````````````&4"``"R`0``%@```.T!``!\````Z@```#`"```I
M`0``_0```"<!``!6`0```````*4"```O`0``I0```(4!`````````````+\!
M````````JP(``)D!``"^`0``'`````````#^`````````)<````9````````
M`-`!``"S`0``N@```-X!``!E````$@```%H`````````(0(```````#1````
M.0```#X```#G`0``&`(```````#O`0``G@```+`!``"-`0``\P```,@!```S
M`0``Q0$```@`````````8P```*<"``#7`0``4````"`!``";`0```````"(`
M``!K````-@`````````````````````````I`@``D`$``*D!``!*`@``````
M`)4```!&````3@$``%@```!2````D0(````````5````/@$``*8"``##````
M/0``````````````DP$``-H!````````J0(```$!``!Q````K`(``,X```!!
M`````````,$```"%`@``/````$<"```:`@``>0(``!0`````````,P(``%X`
M`````````````($!``!9`0``B@````````!:`@``````````````````2@$`
M`"X!``"*`@```````,8!``!)`0``&`$```(```#T`````````*H!````````
MG`$`````````````5`(```H!``!K`@``F@$````````?`0``:P$``$@````Y
M`@```````-L```!4`0```````#\```#+`0``R@$```````"8`````````"4!
M```````````````````;````N`$``#$"````````70```+X```"6````]`$`
M`)8!````````T0$``%\```!+``````````X```!J`@```````*H```"Z`0``
M/@(``(,"``"U`0``X0$``%0`````````3P$``#P!````````8@```,\!````
M````%P(``(8!````````0P(``'\"```O`@``<@$``%4```"C````#P```%P"
M``"?`@``>P```!,"``!?`0``%0(``.$`````````J0```*<!``!V`@```P``
M`)<!```X````BP```"`"``"N````DP(```````!%`0``$``````````0`@``
M4P```-8```````````(``(L!``!W````,@$``%$"````````H@```&D!``#P
M`0``+`(``%P```````````````````#=````"0(``&\!``"5`0```````&("
M``#[`0``HP(```````!S`0```````$````"B`@```````+4`````````#`$`
M`"\```#"````50$``+(```#S`0```````-4```````````````P"````````
M"0````````"Y`0``?0$```L"````````8P$``"P````$`0```````"@!````
M````]@$``+$```"``0``MP``````````````ZP````````#(````IP```!`!
M``"-`@``Q0````T````X`0``'P```.T``````````````*8!``!U````@@``
M`(0!````````:0````````!>`0``#````#4```"4````YP```)``````````
MR0````````!L````=0$``$X"``"#````G@(``#L"``!)````*@(``-D```!$
M`@````````````"/`@``#P(``*$!``!-`0``)P``````````````Y@$``&0"
M``#F````(0$```````#@````K````#\!``!T``````````T!``"-````HP$`
M```````"`@``;P(``(P!``!G`````````%@"``#J`0````````$"``!@`0``
M`````-D!```7`0``$@$```<```":`@``,`$``-0````+````)@$`````````
M````80(``"4"``!Z``````````````#V`````````"8"```H`@``GP$`````
M``!O`````````$<!``!6`````````"@`````````-`(``,H`````````;`$`
M`#0!``#U````9P$``-,``````````````+0````]`@```````$0!````````
M-P(````````D`@```@$``,8````U`0``;@(``*0!``"'`0```````$@"```%
M`@``;0```!<````A````_0$``'X"```;`0```````'P!``#U`0``````````
M``!3`0```````'H!``!1`0``#P$``````````````````!$"``"9`@``R0$`
M`&H!``"1`0``30```/<```#4`0``*@````0```!P`@``@@$``#````!]`@``
M`````````````````````/\!```*````<P(``(0```#L`0`````````````Q
M````I`(```````!.`````````*(!``"'`@``>`$``$T"`````````````+@`
M``"4`0``P````(4```"9````$0$```````#-````JP$```````"V`0``G0$`
M`$$"```3`0``L````,<!``!R`@```````(L"````````X@```&0```#K`0``
M/`(``(8```"M````6P(``-H````[`0```````-,!```=`0``MP$``!P"``"`
M`@``*@$``&4!`````````````$H````M`0``3P(````````X`@``````````
M``!F`0``&0(`````````````9@(``)T"``!_`0```````!P!``!G`@``````
M``````#C````WP$``(D```#-`0````````````#'````C@$```````"_````
M``````@!``#Y``````````````"/`````````"L```#Z````.@```!("````
M````@@(``+T!```$`@``^`$``/P!````````8@$````````R`@``9@```&T!
M```C`0``80$``,(!````````;`(``"````"@`@``9`$``!,```"#`0``\0``
M``,!``"/`0```````)X!``#$`0``4@(```````"@````F@```-L!``!Y`0``
MZ`$``(P"```D`0``.0$``'<"``"L`0``7P(``-X```!'````3P```$4````N
M````L0$``%T"````````N0````````"[````_P```!8!```#`@``O```````
M````````G0```````````````````'T```!``@``!P(`````````````60(`
M`'X```"D````1```````````````H`$``"D``````````````%T!``!T`@``
M2`$``*@"``!@`@````````````";`@````````````#8`0```````$D"``#B
M`0``I0$``$(`````````6P```&,"```;`@````````````#6`0``B````(D"
M`````````````/````!Z`@```````.X!```F`````````%`"``!J````#0(`
M`!D!````````S`$``/(!``#Q`0````````````!#````O0```/D!``"3````
MRP```.X```#X`````````*@!````````,0$``%<````)`0``=`$```````![
M`0``'0(``!$```#R````+0(``$$!```%````7@(``'4"``#7````XP$``*X!
M``#!`0```````'`````L`0``50(``'\```"4`@``LP```(8"````````:```
M`!8"````````@0```)<"```D````1@(``*$"```.`@``&@```#8!```R````
MK0(``&X!`````````````*8```"2`0``-````)("`````0``80```.D```"(
M`@``(P(``*@```!@````'P(``&@!``````````````@"``".`@``Q````-(!
M``"``````````+0!```V`@``K0$`````````````*P(``#4"```8````KP$`
M`(<```#D`0``/0$``'8!``#2````J@(````````[````3`$``!H!``"6`@``
MGP```'$"``!X`@``]P$``%@!``!P`0```````"("````````!@``````````
M````Y0```.D!```*`@```````)$```!7`@``4P(````````G`@``W`$```L!
M````````SP```)@"``"K````*P$``````````````````$P"``!M`@``````
M`)P"````````0P$``%<!``!V`````````````````````````$4"``#O````
M`````&@"````````0@$``%(!``!Q`0````````<!``".````3````-\```#\
M`````````-P````E````U0$````````%`0``6P$``!4!````````A`(`````
M``!S````D`(```8!``")`0``Y0$```````"V````+0```-````![`@``=P$`
M`.@````N`@``0@(``.P```!&`0``Y````/H!````````(P```)L````_`@``
M`````!X!```W`0```````*\```#@`0``<@```#<```"<`````````$`!``!I
M`@``,P```)4"```.`0```````($"``",````6@$`````````````_@$`````
M````````%`$``!X```"8`0```````%8"````````2P$``(@!``!X````P`$`
M`-@```!<`0``;@`````@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX`)60@
M)7,@86YD("5S`"5D(&)Y=&5S('=R:71T96XN`"5D(&]F("5D(&5N=')I97,@
M;6%R:V5D(&%S('5P+71O+61A=&4`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T
M:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&ES(&YO="!W<FET86)L92X`)7,@;6EN=71E<P`E<R!N;W0@9F]U
M;F0N`"5S('1O("5S(&]F("5S`"<E<R<@=V%S(&%D9&5D('1O('1H92!G<F]U
M<',@<WES=&5M+@`G)7,G('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@
M<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E871E9#H@)7,N`"P@9W5S=&EN9R`E
M<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`,3(@2&]U<B!&;W)M870`
M,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!32!286EN`$%-(%-H;W=E<G,`
M04T@4VYO=R!3:&]W97)S`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T
M+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C;W5N="!087-S=V]R9`!!8V-O
M=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($AE<F4Z`$%D9"!.97<@
M1W)O=7``061D(&$@8VAI;&0@9W)O=7`@=&\@)R5S)P!!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O("<E<R<`061D(&$@;F5W('5S97(Z`$%D9"!N97<@;65M
M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I
M9&5B87(`061D('5S97(`061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M)7,N`$%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,@0F]O:P!!
M9&UI;FES=')A=&EO;@!!9',`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U
M=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`
M06QL(&9O=7(@<VED97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S
M<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL
M(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`
M06YS=V5R`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I
M;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P
M<FEL`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D
M96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_`$%R=`!!<V-I:2!!<G0`
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!
M=6=U<W0`079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N9`!"86-K9W)O=6YD
M($-O;&]R`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD
M+@!"87-E;&EN90!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]O
M:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O=&@`
M0F]T=&]M`$)U:6QD:6YG($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`0G5L
M;&5T960@3&ES=`!#35,`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#
M86QM`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;F-E;`!#86YC96P@4')O8FQE
M;2!297!O<G0`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V5L;"!0
M<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@
M<W!A8VEN9SH`0V5N=&5R`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D
M9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L
M>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@<&%S<W=O<F0`0VAA<@!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z`$-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`
M0VQE87(`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E
M<B!D871A`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O;&]R`$-O;&]R
M(%!I8VME<@!#;VQS.@!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O
M;6UA;F0@;W!T:6]N<SH`0V]M;6%N9',Z`$-O;7!U=&5R<P!#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@;F5E9',@=7!D871I;F<N
M`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F9I<FT@;F5W('!A
M<W-W;W)D.@!#;VYT:6YU90!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#
M;W!Y:6YG("5S('1O("5S`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R
M(&%S(&=U97-T`$-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,`
M0V]U;&0@;F]T(&-O<'D@)7,@=&\@)7,`0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E<R<Z
M("5S`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W
M(&]N90!#<F5A=&]R(%!E<FUI<W-I;VYS`$-U<G)E;G0@4&AA<V4`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT
M(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`1$0`1&%T80!$871A5')E92!"
M<F]W<V5R`$1A=&4@4F5C96EV960`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M
M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$
M969A=6QT($-O;&]R`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F:6YI=&EO;G,`
M1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`G)7,G`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D
M(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H
M92!C=7)R96YT(')O=P!$97-C<FEP=&EO;@!$979E;&]P;65N=`!$:7)E8W1O
M<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*0!$;R!N;W0@9&5L971E`$1O=VYL;V%D(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$5D:70`161I
M="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M
M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S
M:6]N<R!F;W(@)7,`161I="!P97)M:7-S:6]N<R!F;W(@)R5S)P!%9'5C871I
M;VX`16UA:6P@061D<F5S<P!%;FQA<F=E($5D:71O<@!%<G)O<@!%<G)O<CH@
M`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E
M8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M
M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`1F%I;'5R92!I;B!C:&%N
M9VEN9R!P87-S=V]R9"`Z(`!&96)R=6%R>0!&:6QE($UA;F%G97(`1FEL=&5R
M<P!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F=O="!Y
M;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)U;7,`1F]R=V%R9',`1F]U;F0@87!P
M;&EC871I;VYS.B`E<P!&<@!&<F%M97,`1G)O;2!T:&4@`$9U;&P@1&5S8W)I
M<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;F5R871I;F<@<W1A='5S(&9O<B!M
M;V1U;&4@)7,N+BX`1V5T;W!T($5R<F]R.B``1V]O9VQE(%-E87)C:`!'<F]U
M<"!!9&UI;FES=')A=&EO;@!'<F]U<"!P97)M:7-S:6]N<P!'<F]U<',`1W5E
M<W0@4&5R;6ES<VEO;G,`1W5E<W0@<&5R;6ES<VEO;G,`1W5E<W1B;V]K`$AE
M:6=H=`!(96QP`$AI9V@`2&]?;64`2&]R9&4`25]N<V5R="!2;W<@0F5F;W)E
M`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N
M=&ET>2=S(&YA;64Z`$EM86=E(%!R979I97<Z`$EM<&]R="P@4W1E<"`E9`!)
M;7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O
M=R!!9G1E<@!);F-R96%S92!);F1E;G0`26YF;W)M871I;VX`26YS97)T($-?
M;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@
M7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!C96QL(&%F
M=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN
M<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@
M3&EN:P!);G1E<FYA;"!%<G)O<@!);G9A;&ED(&%P<&QI8V%T:6]N+@!)=&%L
M:6,`2F%N=6%R>0!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*
M=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2VED<P!,
M85]Y;W5T`$QA;F=U86=E`$QA<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5
M<&1A=&5D.@!,87EO=70`3&5F=`!,:6=H="!3;F]W`$QI<W0@2&5L<"!4;W!I
M8W,`3&ES="!486)L97,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]C
M86P@=&EM93H@`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS
M`$QO9V]U=`!,;W<`34T`36%I;`!-86MI;F<@9&ER96-T;W)Y("5S`$UA<F-H
M`$UA<F=I;@!-871C:&EN9R!F:65L9',`36%X('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>0!-96UB97)S`$UE;G4@
M;6]D93H`365R9V4@8V5L;',`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`36ED9&QE`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-;P!-;V)I;&4@36%I;`!-;W-T;'D@0VQE87(`36]S
M=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`37D@06-C;W5N=`!.971W;W)K`$YE
M=F5R`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO
M;F%L*0!.97<@<&%S<W=O<F0Z`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.
M97=S9W)O=7!S`$YE>'0`3F5X="!0:&%S90!.:6=H=`!.;R!C:&%N9V4N`$YO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO
M(&-O;6UA;F0@<W!E8VEF:65D+@!.;R!I8V]N<R!F;W5N9"X`3F\@<G5L97,`
M3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+@!.;VYE`$YO="!S970`3F]T93H@66]U('=I;&P@;F5E9"!T;R!L
M;V=O=70@86YD(&)A8VL@:6X@869T97(@>6]U(&-H86YG92!Y;W5R('!A<W-W
M;W)D(0!.;W1E<P!.;W1I8V4`3F]V96UB97(`3TL`3V)J96-T($-R96%T;W(`
M3V-T;V)E<@!/9F9I8V4`3VQD('!A<W-W;W)D.@!/;FQY('1H92!O=VYE<B!O
M<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O
M<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W
M('=I;F1O=P!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W!T:6]N<SH`3W)D97)E9"!,:7-T`$]T:&5R
M`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!(4"!#;V1E
M`%!(4"!3:&5L;`!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!4+5-T;W)M
M<P!07TA0(%-H96QL`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960A`%!A<W-W
M;W)D(&UO9'5L92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9`!087-S=V]R
M9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S
M=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!097)C96YT`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`G)7,G(&YO="!D
M96QE=&5D+@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!)
M;F9O<FUA=&EO;@!0:&]T;W,`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X
M="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@
M<WES=&5M+@!0;VQI=&EC<P!0;VQL<P!0<F5S96YT871I;VYS`%!R979I97<`
M4')I;G0@9&]C=6UE;G0`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]B;&5M/P!1
M=65R>0!286EN`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3
M;F]W`%)E860`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W
M.@!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]V90!296UO=F4@0FQO8VL`
M4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('1H90!296UO
M=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5S970`4F5S970@4&%S<W=O<F0`
M4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E<W5L=',Z`%)E='5R;B!T
M;R!/<'1I;VYS`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)O7W<@4')O<&5R=&EE<RXN+@!2
M;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2=6QE<P!2=6X`4TU3($UE
M<W-A9VEN9P!344P@4VAE;&P`4U-(`%-?44P@4VAE;&P`4V$`4V%V90!3879E
M("5S`%-A=F4@)R5S)P!3879E($]P=&EO;G,`4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BX`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H:6YG
M($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<P!396QE8W0@82!G<F]U<"!T;R!A
M9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@
M82!U<V5R('1O(&%D9`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5P=&5M8F5R`%-E
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@
M;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P
M=&EO;G,N`%-E='5P`%-H;W)T(%-U;6UA<GD`4VAO=P!3:&]W(&QA<W0@;&]G
M:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO
M=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:6=N('5P(&EF(&YO
M="!R96=I<W1E<F5D`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N
M;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H
M.B``4V]M92!O9B!087-S=V]R9"!M;V1U;&4G<R!C;VYF:6=U<F%T:6]N(&9I
M;&5S(&%R92!M:7-S:6YG.@!3;VYG<R`F(%!O96US`%-P86-I;F<`4W!A;0!3
M<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M
M;@!3<&QI="!R;W<`4W!O<G1S`%-T86YD87)D`%-T87(@5')E:P!3=&%T=7,`
M4W1R:6ME=&AR;W5G:`!3=0!3=6)D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N
M`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@)R5S)R!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D
M("<E<R<N`%-U8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6-C97-S9G5L
M;'D@=W)O=&4@)7,`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U
M;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z
M(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@
M<')O<&5R=&EE<P!487)G970Z`%1A<VMS`%1E;7!E<F%T=7)E`%1E;7!E<F%T
M=7)E.B``5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X="!/;FQY`%1E>'0@
M86QI9VX`5&@`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!R
M:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@
M;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&5M97,@9&ER96-T;W)Y
M("<E<R<@;F]T(&9O=6YD+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G
M)7,G('1O('1H92!S>7-T96TN("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D
M9&EN9R`G)7,G('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L
M96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("<E<R<Z
M("5S`%1H:7,@9FEL92!C;VYT<F]L<R!T:&4@9&5F875L="!P<F5F97)E;F-E
M<R!F;W(@4&%S<W=O<F0@;6]D=6QE+"!A;F0@86QS;R!C;VYT<F]L<R!W:&EC
M:"!P<F5F97)E;F-E<R!U<V5R<R!C86X@86QT97(N`%1H:7,@9FEL92!C;VYT
M<F]L<R!T:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S960@=&\@<V5T(&-O;&]R
M<R!A;F0@9F]N=',@:6X@861D:71I;VX@=&\@;W(@;W9E<G)I9&EN9R!(;W)D
M92!D969A=6QT<RX`5&AI<R!I<R`E<RX`5&AI<R!I<R!T:&4@;6%I;B!087-S
M=V]R9"!M;V1U;&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P
M871H<R!A;F0@;W!T:6]N<R!F;W(@86QL(%!A<W-W;W)D(&UO9'5L92!S8W)I
M<'1S+@!4:'5N9&5R`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&ET;&4`
M5&]D87D`5&]M;W)R;W<`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871E
M9`!4<F%N<VQA=&EO;G,`5'4`55),`%523#H`56YA8FQE('1O(&1E;&5T92`G
M)7,G.B`E<RX`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5N:VYO
M=VX@8V]M;6%N9#H@)7,`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YT
M<F%N<VQA=&5D`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E
M9"`G)7,G+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57-A9V4Z
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!296=I<W1R871I;VX`57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`
M57-E<B!P97)M:7-S:6]N<P!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!686-A=&EO;@!697)S:6]N($-O;G1R
M;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`
M5V%R;FEN9SH@`%=E`%=E8@!796(@4VET90!796QC;VUE`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H
M`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@Z
M`%=I;F0`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M
M`%=I<VAL:7-T<P!7;W)K`%E9`%EE<RP@22!!9W)E90!9;W4@8V%N)W0@8VAA
M;F=E('!A<W-W;W)D(&9O<B!U<V5R("5S`%EO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P
M;VEN=',@=&\`66]U(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9`!9;W4@
M;75S="!G:79E('EO=7(@;VQD('!A<W-W;W)D`%EO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N`%EO=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9`!9;W5R($5M
M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T
M:6]N`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO;B`K
M(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!N97<@<&%S<W=O<F1S(&1I9&XG="!M
M871C:`!9;W5R(&]L9"!P87-S=V]R9"!I<VXG="!C;W)R96-T`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M(:61E(%%U;W1E
M9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`
M7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'
M<F]U<',`7TEM86=E(%!R;W!E<G1I97,N+BX`7TUO9&EF>2!,:6YK+BXN`%]0
M97)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P
M97)T:65S+BXN`%]5<V5R<P!A;B!E<G)O<B!H87,@;V-C=7)E9#H`8V%L;0!D
M;VYE`&9A:6QE9`!F86QL:6YG`&9O=6YD.B``9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<P!I,3AN`&EN;&EN90!L:6YE<UT`;F%M90!N;W0@8VAA;F=E9`!N
M;W0@9F]U;F0`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC
M97,`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5P9&%T960`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!P87-S
M=V0*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#(M,#8M,38@,C,Z,S(K,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`R+3`V+3$U(#`S.C$S*S`R,#`*3&%S="U4
M<F%N<VQA=&]R.B!-871T:6%S(%=E8FKV<FX@17)I:W-S;VX@/&UA='1I87-`
M=V5B:F]R;CX*3&%N9W5A9V4M5&5A;3H@4W=E9&ES:"`\4T5`;&DN;W)G/@I-
M24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M+6)I=`H`)B,Q-3$[("5S(&MO;6UE<B!A='0@=71F]G)A(&1E('5N9&5R:.5L
M;'-F=6YK=&EN97)N82!S;VT@Y'(@:6MR>7-S861E(&YE9&%N+@`E9"`E<R!O
M8V@@)7,`)60@=&5C:V5N('-K<F5V<RX`)60@878@)60@<&]S=&5R(&UA<F5R
M861E<R!S;VT@86MT=65L;&$`)60M9&%G<R!F]G)U='/D9V5L<V4`)7,@+2!&
M]G(@:^1N;F5D;VT`061M:6YI<W1R871I;VX@878@)7,`)7,@56YD97)HY6QL
M<V9U;FMT:6]N("T@0F5K<N1F=&5L<V4`)7,@4V5T=7``3&EC96YS879T86P@
M9O9R("5S`"5S(.1R(&EN=&4@<VMR:79B87(N`"5S(&UI;G5T97(`)7,@<V%K
M;F%S+@`E<R!T:6QL("5S(&%V("5S`"<E<R<@;&%D97,@=&EL;"!I(&=R=7!P
M<WES=&5M970N`"<E<R<@;&%D97,@=&EL;"!I(&)E:/9R:6=H971S<WES=&5M
M970N`"<E<R<@<VMA<&%D97,@:6YT93H@)7,N`"P@<W1O<FUB>6%R("5S("5S
M`"P@=F%R:6%B;&5M(&UE;&QA;B`E<R!T:6QL("5S`#$R+71I;6UA<G,@9F]R
M;6%T`#(T+71I;6UA<G,@9F]R;6%T`#(T('1I;6UA<@`G1&%T86)A<V)A8VME
M;F0G(&MRY'9S(&;V<B!A:W1U96QL="!B;&]C:RX`1O9R;6ED9&%G<W)E9VX`
M1O9R;6ED9&%G<W-K=7)A<@!&]G)M:61D86=S<VMU<F%R(&UE9"!S;O8`04TO
M4$T`3VT@961I=&]R;@!/;2XN+@!";W1T96X`36ET=&5N`$MO;G1O(&SV<V5N
M;W)D`$)U9&=E=`!,Y&=G('1I;&P`3.1G9R!T:6QL('5N9&5R9W)U<'``3.1G
M9R!T:6QL(&CD<CH`3.1G9R!T:6QL(&YY(&=R=7!P`$SD9V<@=&EL;"!B87)N
M9W)U<'`@=&EL;"`G)7,G`$SD9V<@=&EL;"!B87)N8F5H]G)I9VAE="!T:6QL
M("<E<R<`3.1G9R!T:6QL(&5N(&YY(&%N=N1N9&%R93H`3.1G9R!T:6QL(&YY
M82!M961L96T`3.1G9R!T:6QL('!A<@!,Y&=G('1I;&P@;65N>6X@9O9R("5S
M('-O;2!-;WII;&QA(%-I9&5B87(`3.1G9R!T:6QL(&%N=N1N9&%R90!,82!T
M:6QL("<E<R<@=&EL;"!S>7-T96UE="P@;65N(&MU;F1E(&EN=&4@;.1G9V$@
M=&EL;"!E>'1R82!I;F9O<FUA=&EO;CH@)7,N`$QA('1I;&P@)R5S)R!T:6QL
M('-Y<W1E;65T+B!$=2!K86X@;&]G9V$@:6X@;G4N`%5P<&SD9V<@878@86YV
MY&YD87)E(.1R(&EN86MT:79E<F%T+@!!9')E<W-B;VL`061M:6YI<W1R871I
M;VX`4F5K;&%M`$IU<W1E<F$`2G5S=&5R:6YG.@!!;&QA`$%L;&$@875T:&5N
M=&ES97)A9&4@86YVY&YD87)E`$%L;&$@9W)U<'!E<@!!;&QA(&)E:/9R:6=H
M971E<@!!;&QA(&9Y<F$@<VED;W(`5&EL;.5T(&EN<W3D;&QN:6YG(&;V<B!S
M;W)T97)A9"!L:7-T83\`06QT97)N871I=B!)35-0+6EN;&]G9VYI;F<`06QT
M97)N871I=G0@;/9S96YO<F0@9O9R($E-4U``06QT97)N871I=G0@86YVY&YD
M87)N86UN(&;V<B!)35-0`$%L=&5R;F%T:78@92UP;W-T(&%D<F5S<SH`06QT
M97)N871I=B!M86QL`$%L=&5R;F%T:78@=&5X=#H`4W9A<@!!<'!L:6MA=&EO
M;@!!<'!L:6MA=&EO;G-L:7-T80!!<'!L:6MA=&EO;F5N(.1R(&ML87(N`%9E
M<FMS=.1L;"!T:6QL('5N9&5R=71D96QN:6YG87(`1V]D:^1N;@!A<')I;`#$
M<B!D970@<^1K97)T(&%T="!D=2!V:6QL('1A(&)O<G0@86YMY&QA;B!F]G(@
M)7,_`,1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@<F%D97)A("<E<R<@;V-H
M(&5V96YT=65L;&$@=6YD97)G<G5P<&5R/P!+;VYS=`!!<V-I:2!K;VYS=`!&
M<N5G82!E9G1E<B!B96MRY&9T96QS92!I;FYA;B!U;F1E<FCE;&QS86MT:79I
M=&5T97(@=71F]G)S/P!&]G)S]FL@=&EL;"!A='0@<F%D97)A(&5N(&=R=7!P
M('-O;2!I;G1E(&9I;FYS+@!&]G)S]FL@=&EL;"!A='0@<F%D97)A(&5N(&)E
M:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N`$;V<G/V:R!A='0@Y&YD<F$@96X@
M8F5H]G)I9VAE="!S;VT@:6YT92!F:6YN<RX`1O9R<_9K(&%T="#D;F1R82!E
M;B!U=&1E;&YI;F<@<V]M(&EN=&4@9FEN;G,N`&%U9W5S=&D`5&EL;&?D;F=L
M:6=A(&;D;'0Z`$)A:V=R=6YD`$)A:V=R=6YD<V;D<F<`1W)U;F1K871A;&]G
M("<E<R<@9O9R(&)I;&1E<B!H:71T861E<R!I;G1E+@!"87-L:6YJ90!";&]C
M:VEN<W3D;&QN:6YG87(`0FQO8VMT>7``1F5T`$)O:VWD<FME;@!286T`4F%M
M8G)E9&0Z`%)A;6%R`$+E9&$`0F]T=&5N`$=E;F5R97)A<B!-3RUF:6QE<B!F
M]G(@;6]D=6P@)7,N+BX`4'5N:W1L:7-T80!#35,`0U]E;&P@:6YS=.1L;&YI
M;F=A<BXN+@!+86QE;F1E<@!,=6=N=`!+86X@:6YT92!N;VQL<W3D;&QA(&SV
M<V5N;W)D(&%U=&]M871I<VMT+"!K;VYT86MT82!D:6X@861M:6YI<W1R873V
M<BX`079B<GET`$%V8G)Y="!P<F]B;&5M<F%P<&]R=`!2=6)R:6L`2V%T96=O
M<FEE<B!O8V@@<G5B<FEK97(`0V5L;&EN<W3D;&QN:6YG87(`0V5L;'5T9GEL
M;&YA9#H`0V5L;&EN<W3D;&QN:6YG87(`0V5L;&UE;&QA;G)U;3H`0V5N=')E
M<F%D`,1N9')A`,1N9')A(&YA;6X@;V-H(&%D<F5S<R!S;VT@;6]T=&%G87)N
M82!S97(@;N1R(&1E(&SD<V5R(&]C:"!S=F%R87(@<.4@9&EN82!M961D96QA
M;F1E;BX`0GET(&SV<V5N;W)D`%1E8VME;@!+<GES<V$@:2!D92!F=6YK=&EO
M;BAE<BD@9'4@=FEL;"!U=&;V<F$N`%;D;&H@:'5R(&1A='5M('-K86QL('9I
M<V%S.@!296YS87(@=7!P(%!/+69I;&5R(&;V<B!M;V1U;"`E<RXN+@!296YS
M80!296YS82!A;G;D;F1A<F4Z("5S`%)E;G-A(&%N=N1D;F%R90!296YS82!A
M;G;D;F1A<F1A=&$`4W3D;F<@9O9N<W1E<@!-;VQN`$UO;&YI;F=T`$;D<F<`
M1N1R9VAA;G1E<F%R90!+;VQU;6YE<CH`3'5S=&EG:&5T97(`2V]M;6%N9&\`
M2V]M;6%N9&]F]FYS=&5R`$MO;6UA;F1O:6YS=.1L;&YI;F=A<CH`2V]M;6%N
M9&]N.@!$871O<F5R`$MO;F9I9W5R871I;VYS<VMI;&QN861E<@!+;VYF:6=U
M<F%T:6]N(&)E:/9V97(@=7!P9&%T97)A<RX`2V]N9FEG=7)E<F$@)7,`0F5K
M<N1F=&$@;/9S96YO<F0`0F5K<N1F=&$@9&ET="!L]G-E;F]R9#H`1F]R='/D
M='0`0V]O:VEE`$MO<&EE<F$`2V]P:65R82!M87)K97)I;F<`2V]P:65R87(@
M)7,@=&EL;"`E<P!+=6YD92!I;G1E(&)I;F1A('1I;&P@;&1A<"!S97)V97)N
M('-O;2!GY'-T`$MU;F1E(&EN=&4@86YS;'5T82!T:6QL(&QD87`@<V5R=F5R
M;@!+86X@:6YT92!K;VYT86MT82!S97)V97(@)R5S)R!V:6$@1E10.B`E<P!+
M86X@:6YT92!K;W!I97)A("5S('1I;&P@)7,`2V%N(&EN=&4@<W!A<F$@:V]N
M9FEG=7)A=&EO;B!F]G(@)7,N`$MA;B!I;G1E('-P87)A(&)A8VMU<"UK;VYF
M:6=U<F%T:6]N+@!+86X@:6YT92!S<&%R82!E;B!B86-K=7`M:V]N9FEG=7)A
M=&EO;CH@)7,N`$MA;B!I;G1E('-P87)A('5P<&=R861E<FEN9W-S8W)I<'0@
M=&EL;#H@)7,N`$MA;B!I;G1E('-P87)A(&)A8VMU<"UK;VYF:6=U<F%T:6]N
M("5S+@!+86X@:6YT82!S<&%R82!K;VYF:6=U<F%T:6]N(&;V<B`G)7,G.B`E
M<P!+=7)S97(`4VMA<&$`4VMA<&$@;.1N:P!3:V%P82!N>0!"96CV<FEG:&5T
M97(@9O9R(.1G87)A`$%K='5E;&P@9F%S`$%K='5E;&P@=&ED`$%K='5E;&P@
M55),(.1R`$%K='5E;&QT(';D9&5R`$%K='5E;&QA('9I;&QK;W(Z(`!!:W1U
M96QL('-T:6P`4VMRY&1D87)S>2!A:W1I=FET971E<B!S;VT@:_9R<R!V:60@
M:6YL;V=N:6YG('1I;&P@)7,N`$ML:7!P('5T`$1$`$1A=&$`1&%T851R964@
M8FSD9&1R87)E`$1A='5M(&UO='1A9V5T`$1A9P!?4F%D97)A(&MO;'5M;@!D
M96-E;6)E<@!$96-I;6%L97(`36EN<VMA(&EN9')A9P!&]G)V86QT`$;V<G9A
M;&0@9N1R9P!&]G)V86QD(&)E:/9R:6=H970`1&5F:6YI=&EO;F5R`%)A9&5R
M80!2861E<F$@9W)U<'``4F%D97)A(&-E;&P`4F%D97)A(&MO;'5M;@!2861E
M<F$@8F5F:6YT;&EG(&%L=&5R;F%T:79M86QL`%)A9&5R82!B96CV<FEG:&5T
M(&;V<B`G)7,G`%)A9&5R82!R860`4F%D97)A('9A;&0@:61E;G1I=&5T`%)A
M9&5R82!A:W1U96QL(&MO;'5M;@!2861E<F$@86MT=65L;"!R860`0F5S:W)I
M=FYI;F<`571V96-K;&EN9P!+871A;&]G`%9I<V$@,C0M=&EM;6%R<R!K;&]C
M:V$_`%9I<VYI;F=S:6YS=.1L;&YI;F=A<@!6:7-A(&;V<G5T<^1G96QS92`H
M5$%&*0!2861E<F$@:6YT90!(Y&UT82!G96YE<F5R860@:V]N9FEG=7)A=&EO
M;B!S;VT@4$A0+7-K<FEP="X`Q&YD<F$`Q&YD<F$@8FQO8VL`Q&YD<F$@9W)U
M<'``UFYD<F$@8F5H]G)I9VAE=`#$;F1R82!B96CV<FEG:&5T97(@9O9R("5S
M`,1N9')A(&EN<W3D;&QN:6YG87(@9O9R.@#$;F1R82!B96CV<FEG:&5T97(@
M9O9R("5S`,1N9')A(&)E:/9R:6=H971E<B!F]G(@)R5S)P!5=&)I;&1N:6YG
M`$4M<&]S="!A9')E<W,`1O9R<W1O<F$@961I=&]R`$9E;`!&96PZ(`!687(@
M,34Z92!M:6YU=`!687)A;FYA;B!M:6YU=`!687(@,S`Z92!M:6YU=`!687(@
M-3IE(&UI;G5T`%9A<FIE(&AA;'9T:6UM80!687)J92!M:6YU=`!%>&5M<&5L
M('#E(';D<F1E;CH`2_9R`$UI<W-L>6-K861E<R!M960@871T(.1N9')A(&SV
M<V5N;W)D(#H@`&9E8G)U87)I`$9I;&AA;G1E<F%R90!&:6QT97(`1O9R<W1A
M(&AA;'9A;@!&]G)S=&$@:W9A<G1E;@!&;VYT9N1R9P!-870`1O9R('=E8FSD
M<V%R92!S;VT@:6YT92!S=/9D:F5R(&)I;&1E<@!';/9M="!D:71T(&SV<V5N
M;W)D/P!&;W)M=6SD<@!&;W)U;0!6:61A<F)E9F]D<F%R`$AI='1A9&4@87!P
M;&EK871I;VYE<CH@)7,`1G(`1G)A;65S`$9RY6X@9&5N(`!&=6QL<W3D;F1I
M9R!B97-K<FEV;FEN9P!&=6QL;>5N90!.86UN`$=E;F5R97)A(&MO;F9I9W5R
M871I;VX@9O9R("5S`$=E;F5R97)A9"!K;V0`1V5N97)E<F%R('-T871U<R!F
M]G(@;6]D=6P@)7,N+BX`1V5T;W!T(&9E;#H@`$=O;V=L97/V:VYI;F<`1W)U
M<'!A9&UI;FES=')A=&EO;@!'<G5P<&)E:/9R:6=H971E<@!'<G5P<&5R`$?D
M<W1B96CV<FEG:&5T97(`1^1S=&)E:/9R:6=H971E<@!'Y'-T8F]K`$CV:F0`
M2&KD;'``2/9G`$AE7VT`2&]R9&4`25]N9F]G82!R860@9O9R90!%;F)A<G0@
M:6MO;F5R`$EK;VYE<B!F]G(@)7,`26MO;F5R(&UE9"!T97AT`$ED96YT:71E
M=&5N<R!N86UN.@!&]G)H86YD<V=R86YS:V$@8FEL9#H`26UP;W)T97)A+"!S
M=&5G("5D`$EM<&]R=&5R861E(&;D;'0Z("5S`$EM<&]R=&5R861E(&;D;'0Z
M`$EN7V9O9V$@<F%D(&5F=&5R`-9K82!I;F1R86<`26YF;W)M871I;VX`26YF
M;V=A(&M?;VQU;6X@969T97(`26YF;V=A(&)I;&0`26YF;V=A('1A8F5L;`!)
M;F9O9V$@7VMO;'5M;B!F]G)E`$EN9F]G82!N>2!K;VQU;6X@969T97(@86MT
M=65L;"!K;VQU;6X`26YF;V=A(&YY(&MO;'5M;B!F]G)E(&%K='5E;&P@:V]L
M=6UN`$EN9F]G82!N>2!R860@9O9R92!E:W1U96QL(')A9`!);F9O9V$@86QT
M97)N871I=B!M86QL`$EN9F]G82!C96QL(&5F=&5R`$EN9F]G82!C96QL(&;V
M<F4`26YF;V=A(&MO;'5M;B!E9G1E<@!);F9O9V$@:V]L=6UN(&;V<F4`26YF
M;V=A('!A<F%G<F%F(&5F=&5R`$EN9F]G82!P87)A9W)A9B!F]G)E`$EN9F]G
M82!R860@969T97(`26YF;V=A(')A9"!F]G)E`$EN9F]G82_$;F1R82!B:6QD
M`$EN9F]G82_$;F1R82!LY&YK`$EN=&5R;G0@9F5L`$9E;&%K=&EG(&%P<&QI
M:V%T:6]N+@!+=7)S:78`:F%N=6%R:0!J=6QI`&IU;FD`2G5S=&5R80!#96YT
M97)J=7-T97)A`$IU<W1E<F$@:N1M=`!6Y&YS=&5R:G5S=&5R80!(]F=E<FIU
M<W1E<F$`0F%R;@!,85]Y;W5T`%-P<N5K`%-I<W1A(&AA;'9A;@!3:7-T82!K
M=F%R=&5N`%-E;F%S="!U<'!D871E<F%D.@!,87EO=70`5N1N<W1E<@!,Y'1T
M('-N]@!6:7-A(&AJY&QPY&UN96X`3&ES='1A8F5L;&5R`$QI<W1N:6YG(&%V
M(&%N=N1N9&%R92!A=F%K=&EV97)A9"X`3&]K86P@=&ED.B``4&QA=',`3&]G
M9V$@:6X`3&]G9V$@=70`3&]G:6YA:W1I=FET971E<@!,;V=G82!U=`!,Y6<`
M34T`12UP;W-T`%-K87!A<B!M87!P("5S`&UA<G,`36%R9VEN86P`36%T8VAA
M;F1E(&;D;'0`2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S=&4@,C0@=&EM;6%R
M;F$Z(`!(]F=S=&$@=&5M<&5R871U<F4@<V5N87-T92`V('1I;6UA<FYA.B``
M;6%J`$UE9&QE;6UA<@!-96YY;.1G93H`4VSE(&EH;W`@8V5L;&5R`$UE=&%R
M+6)L;V-K(&5J('1I;&QGY&YG;&EG="X@1&5T86QJ97(@:&%R(&QO9V=A=',@
M9O9R('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BX`36ET=&5N`$SD9W-T82!T96UP
M97)A='5R('-E;F%S=&4@,C0@=&EM;6%R;F$Z(`!,Y&=S=&$@=&5M<&5R871U
M<B!S96YA<W1E(#8@=&EM;6%R;F$Z(`!-Y0!-;V)I;"!E+7!O<W0`365S=&%D
M96QS(&ML87)T`$UE<W1A9&5L<R!M;VQN:6=T`$UE<W1A9&5L<R!S;VQI9W0`
M2V]N=&]N`$[D='9E<FL`06QD<FEG`$YY(&MA=&5G;W)I`$YY;>5N90!.>71T
M(&%N=N1N9&%R;F%M;B`H=F%L9G)I='0I`$YY='0@;/9S96YO<F0Z`$YY='0@
M9O9N<W1E<B`H7V)L86YK*0!.>6AE=&5R`$YY:&5T<V=R=7!P97(`3N1S=&$`
M3N1S=&$@9F%S(`!.871T`$EN9V5N(.1N9')I;F<N`$EN9V$@8F%R;B!K86X@
M;.1G9V%S('1I;&P@9&5N(&CD<B!B96CV<FEG:&5T96XN`$EN9V5T(&MO;6UA
M;F1O(&%N9VEV970N`$EN9V$@:6MO;F5R(&AI='1A9&5S+@!);F=A(')E9VQE
M<@!);F=A('-I9&]R`$EN9V5N('1E;7!O<N1R:V%T86QO9R!T:6QL9^1N9VQI
M9R!F]G(@8V%C:&4N`$EN9V5N`$5J(&%N9VEV96X`3T)3(2!$=2!MY7-T92!L
M;V=G82!U="!D:7)E:W0@969T97(@871T(&1U(&AA<B!B>70@;/9S96YO<F0A
M`$%N=&5C:VYI;F=A<@!&]G(@:^1N;F5D;VT`;F]V96UB97(`3TL`3V)J96MT
M<VMA<&%R90!O:W1O8F5R`$MO;G1O<@!'86UM86QT(&SV<V5N;W)D.@!%;F1A
M<W0@Y&=A<F4@96QL97(@<WES=&5M861M:6YI<W1R873V<B!K86X@Y&YD<F$@
MY&=A<F4@96QL97(@8F5H]G)I9VAE=&5R('#E(&5N('5T9&5L;FEN9P#6<'!N
M82!I(&YY='0@9O9N<W1E<@#6<'!N82!LY&YK(&D@;GET="!F]FYS=&5R`$EN
M<W3D;&QN:6YG87(`26YS=.1L;&YI;F=A<B!F]G(@)7,`26YS=.1L;&YI;F=A
M<CH`4V]R=&5R860@;&ES=&$`06YN86X`06YD<F$@:6YS=.1L;&YI;F=A<@#$
M9V%R8F5H]G)I9VAE=&5R`%!(4"UK;V0`4$A0+7-K86P`169T97)M:61D86=S
M<V[V`$5F=&5R;6ED9&%G<W-K=7)A<B!M960@<V[V`,5S:W-K=7)A<B!PY2!E
M9G1E<FUI9&1A9V5N`%!?2%`M<VMA;`!,]G-E;F]R9`!,]G-E;F]R9&5T(.1N
M9')A9&5S(0!,]G-E;F]R9'-M;V1U;&5N(.1R(&EN=&4@8V]R<F5C="!K;VYF
M:6=U<F5R860`3/9S96YO<F0Z`$SV<V5N;W)D.B``3/9S96YO<F0@;>5S=&4@
M=F%R82!L:6MA+@!+;&ES=')A(&EN`$ML:7-T<F$@:6X@9G+E;B!U<FML:7!P
M<VAA;G1E<F%R96X`4_9K=N1G`%!R;V-E;G0`571F]G(@=6YD97)HY6QL<V9U
M;FMT:6]N97(`571F]G(@=6YD97)HY6QL<V9U;FMT:6]N97(@=FED(&EN;&]G
M9VYI;F<_`$)E:/9R:6=H970`0F5H]G)I9VAE="`G)7,G(')A9&5R861E<R!I
M;G1E+@!"96CV<FEG:&5T<V%D;6EN:7-T<F%T:6]N`%!E<G-O;FQI9R!I;F9O
M<FUA=&EO;@!&;W1O;@!"96MRY&9T82!A='0@9'4@=FEL;"!R861E<F$@=F%L
M9"!P;W-T/P!687(@9V]D(&%N9V4@;F%M;B!F]G(@:V%T96=O<FEN.@!687(@
M9V]D('-U;6UE<F$@9&ET="!P<F]B;&5M+@!!;F=E(&1I='0@86YVY&YD87)N
M86UN(&]C:"!L]G-E;F]R9"X`5F%R(&=O9"!LY',@:6=E;F]M(&;V;&IA;F1E
M('1E>'0N($1U($W%4U1%('-A;71Y8VMA(&UE9"!V:6QL:V]R96X@9O9R(&%T
M="!A;G;D;F1A('-Y<W1E;65T+@!0;VQI=&EK`%5N9&5R<_9K;FEN9V%R`%!R
M97-E;G1A=&EO;F5R`$;V<FAA;F1S=FES;FEN9P!3:W)I=B!U="!D;VMU;65N
M=`!0<F]B;&5M8F5S:W)I=FYI;F<`4')O8FQE;3\`1G+E9V$`4F5G;@!296=N
M<VMU<F%R`%)E9VX@;V-H('-N]@!296=N('1I;&P@<V[V`$SD<P!3Y&ME<G0@
M871T(&1U('9I;&P@<F%D97)A("5S/R!2861E<FEN9V5N(&MA;B!I;G1E(.5N
M9W)A<RX`4^1K97)T(&%T="!D=2!V:6QL(')A9&5R82!A;G;D;F1A<F1A=&$@
M9O9R("5S/R!2861E<FEN9V5N(&MA;B!I;G1E(.5N9W)A<RX`57!P9&%T97)A
M(&1Y;F%M:7-K82!M96YY96QE;65N=#H`57!P9&%T97)A('!O<G1A;'9Y.@!+
M;VUM96YT87)E<@!&:N1R<B!S97)V<F%R`%1A(&)O<G0`5&$@8F]R="!B;&]C
M:P!482!B;W)T(&9O<FUA=&5R:6YG`%1A(&)O<G0@<&%R`%1A(&)O<G0`5&$@
M8F]R="!A;G;D;F1A<F4`5&$@8F]R="!A;G;D;F1A<F4Z("5S`,5T97)S=.1L
M;`#%=&5R<W3D;&P@;/9S96YO<F0`Q71E<G-TY&QL(&SV<V5N;W)D`%)E<W5L
M=&%T`%)E<W5L=&%T.@#%=&5R=N1N9"!T:6QL(&EN<W3D;&QN:6YG87(`Q71E
M<G-TY&QL(&MO;F9I9W5R871I;VX`26YS=.1L;&YI;F=A<B!F]G(@4FEC:"!4
M97AT($5D:71O<@!'Y71O<@!(]F=E<@!285]D:6YS=.1L;&YI;F=A<BXN+@!2
M861I;G-TY&QL;FEN9V%R`%)A9&EN<W3D;&QN:6YG87(`3&EN:F%L`$OV<@!3
M35,@;65D9&5L86YD96X`4U%,+7-K86P`4U-(`%-?44PM<VMA;`!,]@!3<&%R
M80!3<&%R82`E<P!3<&%R82`E<P!3<&%R82!I;G-TY&QL;FEN9V%R`%-P87)A
M9&4@:V]N9FEG=7)A=&EO;B!F]G(@)7,N`%9E=&5N<VMA<`!3]FL`4_9K;6]T
M;W)E<@!3]FL@2&]R9&5A<'!L:6MA=&EO;F5R(&D@)7,`5N1L:B!G<G5P<"!A
M='0@;.1G9V$@=&EL;`!6Y&QJ(&YY(.1G87)E`%;D;&H@<V5R=F5R`%;D;&H@
M86YVY&YD87)E(&%T="!LY&=G82!T:6QL`$%N9V4@9&4@=&5C:V5N(&1U(&)E
M:/9V97(@:2!R=71O<FYA(&YE9&%N+B!$=2!K86X@<V5D86X@:V]P:65R82!O
M8V@@:VQI<W1R82!I;B!D96T@:2!T97AT87)U=&%N+@!6Y&QJ(&%V9^1N<V%R
M92!F]G(@9&%T83H`5N1L:B!D871U;69O<FUA=#H`5N1L:B!I9&5N=&ET970@
M9'4@=FEL;"#D;F1R83H`5N1L:B!T:61S879S:VEL:F%R93H`5N1L:B!T:61S
M9F]R;6%T.@!6Y&QJ('1VY2!M871C:&%N9&4@9N1L=#H`5N1L:B!D:71T(&;D
M<F=S8VAE;6$N`$%N9V4@9&ET="!F]G)V86QD82!S<'+E:SH`<V5P=&5M8F5R
M`$%N9V4@9&ET="!F]G)V86QD82!S<'+E:RP@=&ED<WIO;VX@8V]H(&1A='5M
M:6YS=.1L;&YI;F=A<BX`4^1T="!D:71T(&EN:71I86QA(&%P<&QI:V%T:6]N
M+"!FY')G<V-H96UA+"!S:61U<'!D871E<FEN9R!O8V@@86YD<F$@=FES;FEN
M9W-I;G-TY&QL;FEN9V%R+@!3971U<`!+;W)T('-U;6UE<FEN9P!6:7-A`%9I
M<V$@<V5N87-T92!I;FQO9V=N:6YG<W1I9"!V:60@:6YL;V=G;FEN9S\`5FES
M82`G=&%B96QL86MT:79I=&5T97(G(&D@;65N>6X_`%9I<V$@;65N>2!F]G(@
M)7,@=&EL;"!VY&YS=&5R/P!3:W5R87(`5&ED:6=A('-K=7)A<@!396YA('-K
M=7)A<@!!;FWD;"!D:6<@;VT@9'4@:6YT92!R96=I<W1R97)A9`!3;O8`4V[V
M<VMU<@!3;O9S:W5R87(`5&ED:6=A('-N]G-K=7)A<@!396YA('-N]G-K=7)A
M<@!3;O9D:G5P.B``3N5G<F$@878@;/9S96YO<F1S;6]D=6QE;G,@:V]N9FEG
M=7)A=&EO;G,@9FEL97(@<V%K;F%S`%/E;F=E<B!O8V@@9&EK=&5R`$UE;&QA
M;G)U;0!3<&%M`$EN;6%T;FEN9R!A=B!S<&5C:65L;&$@=&5C:V5N`$1E;&$@
M8V5L;`!$96QA(&MO;'5M;@!$96QA(')A9`!3<&]R=`!3=&%N9&%R9`!3=&%R
M(%1R96L`4W1A='5S`$=E;F]M<W1R=6ME;@!3]@!+86X@:6YT92!H:71T82!U
M;F1E<FMA=&%L;V<@)R5S)RX`3F5D<^1N:W0`3'EC:V%T`"<E<R<@;&%D97,@
M=&EL;"!I('-Y<W1E;65T+@!2861E<F%D92!I;F9R;VUA=&EO;B!O;2!A;G;D
M;F1A<F4@)R5S)RX`)R5S)R!R861E<F%D97,N`"<E<R<@=&]G<R!B;W)T(&9R
MY6X@<WES=&5M970N`%-P87)A9&4@8F%C:W5P:V]N9FEG=7)A=&EO;BX`4W!A
M<F%D92!B86-K=7!K;VYF:6=U<F%T:6]N("5S+@`G)7,G('5P<&1A=&5R861E
M<RX`4VMR978@)7,`4V%M;6%N<W3D;&QN:6YG`%-O;'5P<&?E;F<`4V]L;F5D
M9^5N9P!3;VQI9W0`4V]L=7!P9^5N9P!3;VQU<'!GY6YG+VYE9&?E;F<`4V]L
M=7!P9^5N9SH@`%-O;&YE9&?E;F<`4V]L;F5D9^5N9SH@`%5P<&CV:F0`4W5P
M<&]R=`!486)E;&QI;G-TY&QL;FEN9V%R`%1A8F5L;&EN<W3D;&QN:6YG87(`
M3>5L.@!5<'!G:69T97(`5&5M<&5R871U<@!496UP97)A='5R.B``06YVY&YD
M87)A9&UI;FES=')A=&EO;@!%;F)A<G0@=&5X=`!497AT:G5S=&5R:6YG`%1O
M`$EN<W3D;&QN:6YG<V;V;G-T<F5T(&AA<B!S=.1N9W1S+B!!=G-L=71A<BX`
M261E;G1I=&5T96X@)R5S)R!R861E<F%D97,N`$)A<F$@:/9G97(@;V-H(';D
M;G-T97(@<VED;W(`0F%R82!H]F=E<B!S:61A`%-E<G9E<B`G)7,G(')A9&5R
M861E<RX`4V5R=F5R("<E<R<@<W!A<F%D97,N`$)A<F$@=&]P<"!O8V@@8F]T
M=&5N('-I9&$`0F%R82!T;W!P<VED80!496UA:V%T86QO9R`G)7,G(&9I;FYS
M(&EN=&4N`%!R;V)L96T@;65D(&%T="!LY&=G82!T:6QL("<E<R<@=&EL;"!S
M>7-T96UE="X@)7,`4')O8FQE;2!M960@871T(&SD9V=A('1I;&P@)R5S)R!T
M:6QL('-Y<W1E;65T.B`E<P!0<F]B;&5M(&UE9"!A='0@<F5N<V$@:6YF<F]M
M871I;VX@;VT@86YVY&YD87)E("<E<R<@9G+E;B!S>7-T96UE=#H@`%!R;V)L
M96T@;65D(&%T="!T82!B;W)T("<E<R<@9G+E;B!S>7-T96UE=#H@`%!R;V)L
M96T@=FED('5P<&1A=&5R:6YG(&%V("<E<R<Z("5S`$1E;FYA(&9I;"!H86YT
M97)A<B!S=&%N9&%R9"!I;G-TY&QL;FEN9V%R;F$@9O9R(&SV<V5N;W)D<VUO
M9'5L96XL('-A;70@=FEL:V$@:6YS=.1L;&YI;F=A<B!S;VT@86YVY&YD87)N
M82!K86X@Y&YD<F$`1&5N(&CD<B!F:6QE;B!H86YT97)A<B!S='EL97-H965T
M<RP@=FEL:V5T(&%N=N1N9',@9O9R(&;D<F=E<B!O8V@@9F]N=&5R+"!U=/9V
M97(@9&4@<W1A;F1A<F0@=N1R9&5N(&9RY6X@2&]R9&5M;V1U;&5N`$1E="!H
MY'(@Y'(@)7,N`$1E="!HY'(@Y'(@:'5V=61K;VYF:6=U<F%T:6]N<V9I;&5N
M(&;V<B!L]G-E;F]R9'-M;V1U;&5N+B!$96X@:6YN96CE;&QE<B!V86P@9O9R
M(&%L;&$@<VMR:7!T+@#%<VMA`%1I9'-R961O=FES;FEN9P!4:61S9F]R;6%T
M`%1I=&5L`$ED86<`26UO<F=O;@!4;W``5&]P(&9R86UE("A?=&]P*0#6=F5R
M<V%T=`#6=F5R<^1T=&YI;F=A<@!4:0!54DP`55),.@!+86X@:6YT92!R861E
M<F$@)7,Z("5S+@!5;F1E<G-T<G5K96X`Q6YG<F$@Y&YD<FEN9V%R`$5J(&MA
M=&5G;W)I<V5R860`3VOD;G0@:V]M;6%N9&\Z("5S`%)A9&5R82!A:W1U96QL
M('!O<W0`16H@]G9E<G-A='0`57!P9&%T97)A`%5P<&1A=&5R82`E<P!5<'!D
M871E<F$@86YVY&YD87)E`%5P<&1A=&5R861E("<E<R<N`%5P<&1A=&5R:6YG
M<W-C<FEP="!R861E<F%T+@!,861D82!U<'``06YVY&YD;FEN9SH`06YVY&YD
M87)A9&UI;FES=')A=&EO;@!!;G;D;F1A<G)E9VES=')E<FEN9P!!;G;D;F1A
M<G)E9VES=')E<FEN9R!H87(@879A:W1I=F5R871S+@!!;G;D;F1A<F)E:/9R
M:6=H971E<@!!;G;D;F1A<FYA;6X`06YVY&YD87)N86UN.@!!;G;D;F1A<FYA
M;6XZ(`!!;G;D;F1A<F4@:2!S>7-T96UE=#H`4V5M97-T97(`5F5R<VEO;FAA
M;G1E<FEN9P!697)T:6MA;"!J=7-T97)I;F<`5F5R=&EK86P@=71F>6QL;F%D
M`%9E<G1I:V%L.@!687)N:6YG.B``3VX`5V5B8@!796)S:71E`%;D;&MO;6UE
M;@!6Y&QK;VUM96X@=&EL;"`E<P!6Y&QK;VUM96XL("5S`%9I;&ME;B!A<'!L
M:6MA=&EO;B!S:V%L;"`E<R!V:7-A(&5F=&5R(&EN;&]G9VYI;F<_`%9I;&ME
M;B#D<B!A=F=RY&YS;FEN9W-T96-K;F5T/P!6:6QK970@Y'(@=&5C:VYE="!F
M]G(@8VET97)A9"!T97AT/P!6:6QK82!P;'5G:6X@<VMA;&P@86MT:79E<F%S
M(&;V<B!2:6-H(%1E>'0@961I=&]R;BX`0G)E9&0`0G)E9&0@<.4@;65N>6X@
M9O9R("<E<R<@=&EL;"!VY&YS=&5R("AGY&QL97(@9G+E;B!NY'-T82!I;FQO
M9V=N:6YG`%1A8F5L;&)R961D`$)R961D.@!6:6YD`%9I;F1H87-T:6=H970@
M:2!K;F]P`%9I;F0Z`%9I;F0Z(`!6:7-D;VT`UFYS:V5L:7-T80!!<F)E=&4`
M65D`2F$L(&IA9R!S86UT>6-K97(`1'4@:V%N(&EN=&4@Y&YD<F$@;/9S96YO
M<F0@9O9R(&%N=N1N9&%R92`E<P!$=2!MY7-T92!B97-K<FEV82!P<F]B;&5M
M96XL(&EN;F%N(&1U(&MA;B!R87!P;W)T97)A(&5T="!P<F]B;&5M+@!$=2!M
MY7-T92!A;F=E(&5N(%523"!S;VT@;.1N:V5N('!E:V%R('#E`$1U(&WE<W1E
M(&%N9V4@9&ET="!N>6$@;/9S96YO<F0`1'4@;>5S=&4@86YG92!D:71T(&=A
M;6QA(&SV<V5N;W)D`$1U(&WE<W1E(&%N9V4@96X@<V5R=F5R('-O;2!S:V%L
M;"!R861E<F%S+@!$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M
M('-K86QL(')E;G-A<RX`1'4@;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN
M('-O;2!S:V%L;"!R861E<F%S+@!$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A
M<FYA;6X@<V]M('-K86QL(&SD9V=A<R!T:6QL+@!$=2!MY7-T92!A;F=E(&5T
M="!A;G;D;F1A<FYA;6X@<V]M('-K86QL('5P<&1A=&5R87,N`$1U(&WE<W1E
M('9E<FEF:65R82!D:71T(&YY82!L]G-E;F]R9`!$:6X@92UP;W-T(&%D<F5S
M<P!$:6X@1G+E;CH@861R97-S.@!$:6X@:6YF;W)M871I;VX`1&ET="!N86UN
M`$1I='0@875T96YT:7-E<FEN9W,@8F%C:V5N9"!S=/9D:F5R(&EN=&4@=7!P
M;.1G9R!A=B!A;G;D;F1A<F4L(&5L;&5R('/E(.1R(&9U;FMT:6]N96X@879S
M=.1N9V0N`$1I='0@875T96YT:7-E<FEN9W,@8F%C:V5N9"!S=/9D:F5R(&EN
M=&4@;&ES=&YI;F<@878@86YVY&YD87)E+"!E;&QE<B!SY2#D<B!F=6YK=&EO
M;F5N(&%V<W3D;F=D+@!$:6X@=V5B;.1S87)E('-T]F1J97(@:6YT92!D96X@
M:.1R(&9U;FMT:6]N96XN`$1I;B!W96)LY'-A<F4@<W3V9&IE<B!I;G1E('5T
M<VMR:69T<V9U;FMT:6]N96XN(%1R>6-K(&-O;G1R;VPO;W!T:6]N("L@4"!F
M]G(@871T('-K<FEV82!U="X`1&EN(&%K='5E;&QA('1I9'-Z;VXZ`$1I;B!F
M]G)V86QD82!I9&5N=&ET970Z`$1I='0@9G5L;'-TY&YD:6=A(&YA;6XZ`$1I
M='0@;GEA(&SV<V5N;W)D(&;V<B`E<R#D<CH@)7,`1&ET="!N>6$@;/9S96YO
M<F0@=F5R:69I97)A9&5S(&EN=&4@:V]R<F5K=`!$:71T(&=A;6QA(&SV<V5N
M;W)D(.1R(&EN=&4@:V]R<F5K=`!$:71T(&SV<V5N;W)D(&AA<B!B;&EV:70@
MY71E<G-TY&QL=`!$:71T(&SV<VYO<F0@:&%R(.5T97)S=.1L;'1S+"!K;VYT
M<F]L;&5R82!D:6X@97!O<W0@;V-H(&QO9V=A(&EN(&UE9"!D:71T(&YY82!L
M]G-E;F]R9"X`1&EN82!F:N1R<G-E<G9R87(Z`%M']FT@8VET97)A9"!T97AT
M70!;4')O8FQE;7)A<'!O<G1=`%M6:7-A(&-I=&5R860@=&5X="`M`%]!9&UI
M;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?4F%D97)A(')A9`!?1W)U<'!E
M<@!?0FEL9&EN<W3D;&QN:6YG87(N+BX`Q%]N9')A(&SD;FLN+BX`7T)E:/9R
M:6=H971E<@!?5&$@8F]R="!LY&YK+BXN`%]3971U<`!?5&%B96QL:6YS=.1L
M;&YI;F=A<BXN+@!?06YVY&YD87)E`&5T="!F96P@:&%R(&EN='+D9F9A=#H`
M;'5G;G0`:VQA<@!M:7-S;'EC:V%D97,`9F%L;&%N9&4`:&ET=&%D93H@`&9R
MY6X@9&5N("5S("@E<RD@:VP@)7,@)7,`:3$X;@!I;FQI;F4`<F%D97)=`&YA
M;6X`:6YT92#D;F1R860`:&ET=&%D97,@:6YT90!P<F]C96YT`'!I>&QA<@!S
M=&EG86YD90!V:7-A('-K:6QL;F%D97(`86YG92!L]G-E;F]R9&5T('1VY2!G
MY6YG97(@9O9R(&%T="!B96MRY&9T80!E;F%D`'5P<&1A=&5R860`=V5A=&AE
M<BYC;VT`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M87-S=V0O;&]C86QE+WIH7T-.+P``````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,#$V-0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]L;V-A;&4O>FA?0TXO3$-?34534T%'
M15,O````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-#0`,#(Q-S4R`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L
M92]Z:%]#3B],0U]-15-304=%4R]P87-S=V0N;6\`````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#(W-#,Q,0`Q,#0Q-S,V,C<T-``P,C,V,34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0`````#!@``'````#0P```%
M"```3&````````!@@```30```&&```"_````KX```&0```!O@0``O@```-2!
M``"0````DX(``$,````D@P``/````&B#```K````I8,``"X```#1@P``*0``
M``"$```H````*H0``$4```!3A```1P```)F$``!*````X80``$<````LA0``
M10```'2%``!(````NH4``#D````#A@``1@```#V&``!(````A(8``#````#-
MA@``1@```/Z&``!,````18<``#0```"2AP``,@```,>'``!I````^H<``#``
M``!DB```)0```)6(``"(````NX@``$````!$B0``2@```(6)```L````T(D`
M`(4```#]B0``2````(.*```.````S(H```\```#;B@``#````.N*```(````
M^(H```P````!BP``!0````Z+```$````%(L``!$````9BP``)0```"N+```/
M````48L```L```!ABP``$````&V+```.````?HL```4```"-BP``*````).+
M```*````O(L```L```#'BP``%0```-.+```2````Z8L```L```#\BP``"P``
M``B,```4````%(P``"8````IC```)P```%",```F````>(P```X```"?C```
M"@```*Z,```-````N8P``"X```#'C```)P```/:,```@````'HT```X````_
MC0``%P```$Z-```B````9HT``#4```")C0``!@```+^-```;````QHT``"T`
M``#BC0``)````!".```I````-8X``!D```!?C@``#P```'F.```8````B8X`
M``P```"BC@``&P```*^.```>````RXX```@```#JC@``+@```/..```:````
M(H\``#T````]CP``,@```'N/```X````KH\``%0```#GCP``40```#R0``!:
M````CI```%<```#ID```-````$&1```%````=I$```8```!\D0``$0```(.1
M```(````E9$```X```">D0``"````*V1```E````MI$``"````#<D0``#P``
M`/V1```*````#9(```<````8D@```P```""2```&````))(```\````KD@``
M%````#N2```)````4)(```T```!:D@``$@```&B2```9````>Y(``!X```"5
MD@``#P```+22```/````Q)(```@```#4D@``)````-V2```7`````I,``!<`
M```:DP``"````#*3``!.````.Y,``"T```"*DP``'P```+B3```9````V),`
M``<```#RDP``#````/J3```L````!Y0```X````TE````P```$.4```+````
M1Y0```<```!3E```!P```%N4```%````8Y0``!<```!IE```"@```(&4```/
M````C)0``!@```"<E```'P```+64```.````U90``!0```#DE```%P```/F4
M```7````$94``!,````IE0``#@```#V5```I````3)4``!\```!VE0``!P``
M`):5```&````GI4```@```"EE0``#P```*Z5```*````OI4``!,```#)E0``
M"P```-V5```5````Z94``!4```#_E0``!P```!66```%````'98``!4````C
ME@``$0```#F6```,````2Y8``#L```!8E@``.````)26```)````S98```<`
M``#7E@``%````-^6```%````])8``!````#ZE@``$P````N7```Y````'Y<`
M`#D```!9EP``)P```).7```L````NY<``"H```#HEP``)0```!.8```)````
M.9@```H```!#F```!@```$Z8```)````59@```<```!?F```+P```&>8```W
M````EY@``"X```#/F```50```/Z8```M````5)D``"T```""F0``+0```+"9
M``!`````WID``",````?F@``(P```$.:```M````9YH``#,```"5F@``%0``
M`,F:```9````WYH``"D```#YF@``)````".;```1````2)L``!$```!:FP``
M"@```&R;```0````=YL``!8```"(FP``%@```)^;```'````MIL```<```"^
MFP``%````,:;```*````VYL```@```#FFP``!@```.^;```'````]IL```<`
M``#^FP``!@````:<```%````#9P```<````3G```!@```!N<```(````(IP`
M``X````KG```"@```#J<```/````19P```X```!5G```!````&2<```'````
M:9P```D```!QG```%@```'N<```(````DIP```T```";G```!@```*F<```>
M````L)P```4```#/G```$0```-6<```B````YYP``!8````*G0``"````"&=
M```-````*IT```P````XG0``#````$6=```'````4IT```,```!:G0```P``
M`%Z=```7````8IT```@```!ZG0``!````(.=```(````B)T```@```"1G0``
M"@```)J=```@````I9T```8```#&G0``!@```,V=```5````U)T``!@```#J
MG0``'0````.>```B````(9X``%0```!$G@``*0```)F>```*````PYX```X`
M``#.G@``"@```-V>```4````Z)X``!@```#]G@``'0```!:?```3````-)\`
M`!0```!(GP``!````%V?```,````8I\```8```!OGP``%````':?``!$````
MBY\```4```#0GP``!0```-:?```;````W)\``!H```#XGP``$0```!.@```1
M````):```!$````WH```'````$F@```0````9J```"$```!WH```)0```)F@
M```9````OZ```!$```#9H```!@```.N@```-````\J````P`````H0``!@``
M``VA```7````%*$```@````LH0``!0```#6A```,````.Z$```8```!(H0``
M!P```$^A```-````5Z$``!````!EH0``"0```':A```'````@*$```L```"(
MH0``"P```)2A```'````H*$```<```"HH0``"0```+"A```*````NJ$```T`
M``#%H0``#````-.A```0````X*$``!4```#QH0``!0````>B```E````#:(`
M`!,````SH@``.P```$>B```@````@Z(``!````"DH@``#````+6B```.````
MPJ(``!````#1H@``"@```.*B```*````[:(```T```#XH@``'@````:C```;
M````):,``"$```!!HP``'@```&.C```>````@J,``!T```"AHP``+0```+^C
M```@````[:,``"X````.I```%P```#VD```P````5:0``!L```"&I```'@``
M`**D```K````P:0``#,```#MI```)P```"&E```F````2:4``"\```!PI0``
M$@```*"E```I````LZ4``"$```#=I0``$@```/^E```6````$J8``$$````I
MI@``*````&NF``!3````E*8``"````#HI@``+0````FG```A````-Z<``"H`
M``!9IP``00```(2G``!$````QJ<```<````+J```!@```!.H```2````&J@`
M`!,````MJ```$@```$&H```'````5*@```\```!<J```!````&RH```-````
M<:@```P```!_J```#P```(RH```3````G*@```T```"PJ```#0```+ZH```&
M````S*@``!$```#3J```%P```.6H```;````_:@```X````9J0```@```"BI
M```%````*ZD```0````QJ0``!````#:I```-````.ZD```X```!)J0```P``
M`%BI```(````7*D```@```!EJ0``#P```&ZI```0````?JD``!,```"/J0``
M$P```*.I```)````MZD```8```#!J0``#````,BI```1````U:D``!D```#G
MJ0``&P````&J```T````':H``!````!2J@``+P```&.J```B````DZH```T`
M``"VJ@``!P```,2J```,````S*H``"8```#9J@``%`````"K```+````%:L`
M`"(````AJP``+P```$2K```+````=*L```D```"`JP``&0```(JK```+````
MI*L``!<```"PJP``%P```,BK```)````X*L```L```#JJP``%@```/:K```/
M````#:P```X````=K```"````"RL```-````-:P``"8```!#K```0P```&JL
M```(````KJP``!(```"WK```"````,JL```+````TZP``"\```#?K```#@``
M``^M```&````'JT```,````EK0``!P```"FM```$````,:T```H````VK0``
M"@```$&M```/````3*T``!````!<K0``%P```&VM```1````A:T``!<```"7
MK0``&0```*^M```%````R:T```L```#/K0``!0```-NM```-````X:T``!L`
M``#OK0``%P````NN```)````(ZX```X````MK@``#0```#RN```#````2JX`
M``@```!.K@``#@```%>N``!`````9JX``!$```"GK@``!P```+FN```%````
MP:X``!\```#'K@``(````.>N```8````"*\```<````AKP``!P```"FO```(
M````,:\```8````ZKP``$````$&O```0````4J\```\```!CKP``"P```'.O
M```/````?Z\```P```"/KP``#P```)RO```'````K*\```H```"TKP``!@``
M`+^O```/````QJ\```@```#6KP``%@```-^O```3````]J\``!X````*L```
M(0```"FP```@````2[```!D```!LL```%P```(:P```E````GK```!<```#$
ML```'P```-RP```;````_+````T````8L0``#````":Q```#````,[$```@`
M```WL0``"@```$"Q```,````2[$```0```!8L0``$P```%VQ```4````<;$`
M``P```"&L0``"0```).Q```.````G;$```L```"LL0``&P```+BQ```'````
MU+$```<```#<L0``"@```.2Q```-````[[$```D```#]L0``!`````>R```8
M````#+(```X````EL@``"@```#2R```9````/[(``!0```!9L@``?````&ZR
M```%````Z[(```<```#QL@``#````/FR```(````!K,```8````/LP``"```
M`!:S```6````'[,``!(````VLP```@```$FS```&````3+,``!4```!3LP``
M#P```&FS```1````>;,``!H```"+LP``#0```*:S```0````M+,```0```#%
MLP``"0```,JS```0````U+,```D```#ELP``"0```.^S```%````^;,```4`
M``#_LP``!@````6T```9````#+0``"(````FM```!P```$FT```'````4;0`
M``X```!9M```!0```&BT```)````;K0```H```!XM````@```(.T```-````
MAK0```D```"4M```!@```)ZT```2````I;0```4```"XM```"0```+ZT```'
M````R+0```0```#0M```%````-6T```=````ZK0``!$````(M0``!@```!JU
M```*````(;4```0````LM0``"0```#&U```(````.[4``!$```!$M0``#@``
M`%:U```1````9;4```D```!WM0``!@```(&U```-````B+4```8```"6M0``
M`@```)VU```$````H+4``!X```"EM0``!0```,2U```.````RK4```8```#9
MM0``(0```."U```5`````K8```0````8M@``$0```!VV```&````+[8``*``
M```VM@``(@```->V```E````^K8``!T````@MP``!````#ZW```,````0[<`
M``H```!0MP``"````%NW```)````9+<```4```!NMP``%````'2W```3````
MB;<``!L```"=MP``#P```+FW```D````R;<```@```#NMP``"@```/>W```'
M`````K@``"`````*N```(````"NX```F````3+@``!D```!SN```*0```(VX
M```'````M[@```H```"_N```#P```,JX```Y````VK@```P````4N0``!@``
M`"&Y```J````*+D``"D```!3N0``'0```'VY```S````F[D``#H```#/N0``
M)0````JZ```/````,+H``!(```!`N@``$````%.Z```*````9+H``!8```!O
MN@``'````(:Z```A````H[H``!D```#%N@``$P```-^Z```?````\[H```\`
M```3NP``!0```".[```0````*;L```D````ZNP``!````$2[```+````2;L`
M`!H```!5NP``#````'"[```/````?;L``!D```"-NP``#P```*>[```3````
MM[L``!(```#+NP``!P```-Z[```,````YKL```X```#SNP``*P````*\```@
M````+KP``!0```!/O```$0```&2\```7````=KP``!P```".O```$P```*N\
M```1````O[P``!H```#1O```'@```.R\```:````"[T``!$````FO0``%P``
M`#B]```7````4+T``!4```!HO0``&0```'Z]```$````F+T```<```"=O0``
M"P```*6]```&````L;T```8```"XO0``!@```+^]```%````QKT```<```#,
MO0``!P```-2]```%````W+T``!8```#BO0``!@```/F]```&`````+X```0`
M```'O@``!`````R^```.````$;X```P````@O@``#````"V^```-````.KX`
M``H```!(O@``#@```%.^```%````8KX``"@```!HO@``#````)&^```/````
MGKX```H```"NO@``"````+F^```)````PKX``"L```#,O@``"````/B^```F
M`````;\``!(````HOP``#P```#N_```&````2[\```H```!2OP``"````%V_
M```@````9K\```D```"'OP``#````)&_```-````GK\```X```"LOP``%@``
M`+N_```1````TK\```8```#DOP``"````.N_```&````]+\```<```#[OP``
M!P````/````'````"\```!8````3P```#0```"K````*````.,````0```!#
MP```!0```$C````>````3L```!````!MP```#````'[````)````B\````<`
M``"5P```"@```)W````)````J,````X```"RP```$````,'````:````TL``
M``H```#MP```"0```/C````4`````L$```P````7P0``#P```"3!```(````
M-,$```8````]P0``#````$3!```'````4<$```T```!9P0``!0```&?!``!'
M````;<$```T```"UP0``!@```,/!```*````RL$```(```#5P0``!````-C!
M```E````W<$```,````#P@``!0````?"```J````#<(```H````XP@``!```
M`$/"```+````2,(```H```!4P@``0````%_"```3````H,(```8```"TP@``
M"````+O"```(````Q,(```0```#-P@``!0```-+"```%````V,(``!L```#>
MP@``+P```/K"```0````*L,```H````[PP``#P```$;#```*````5L,```D`
M``!APP``&P```&O#```8````A\,``!<```"@PP``#@```+C#```#````Q\,`
M``<```#+PP``%@```-/#```R````ZL,``!0````=Q```$P```#+$```0````
M1L0```T```!7Q```#@```&7$```6````=,0```<```"+Q```"@```)/$```M
M````GL0``#````#,Q```)````/W$```'````(L4``%$````JQ0``$````'S%
M```,````C<4``!H```":Q0``2@```+7%```&`````,8``!H````'Q@``!@``
M`"+&```&````*<8``!\````PQ@``"0```%#&```8````6L8``!<```!SQ@``
M!@```(O&``!7````DL8``!,```#JQ@``(P```/[&```3````(L<```(````V
MQP``"P```#G'```-````1<<```8```!3QP``!P```%K'```4````8L<```8`
M``!WQP``"````'['```.````A\<```<```"6QP``"@```)['```+````J<<`
M``<```"UQP``"0```+W'```)````Q\<```H```#1QP``!P```-S'```)````
MY,<```<```#NQP``"@```/;'```'`````<@``!(````)R```"@```!S(```)
M````)\@``!`````QR```!P```$+(```2````2L@```0```!=R```!P```&+(
M```%````:L@```0```!PR```#````'7(```%````@L@```L```"(R```%```
M`)3(```1````J<@``!@```"[R```'````-3(```9````\<@```<````+R0``
M!0```!/)```-````&<D```@````GR0``%P```##)```+````2,D```T```!4
MR0``$P```&+)```$````=LD```0```![R0``"0```(#)```,````BLD```D`
M``"7R0``!0```*')```'````I\D```4```"OR0``!````+7)```I````NLD`
M`#(```#DR0``-@```!?*```5````3LH``"X```!DR@``,P```)/*```S````
MQ\H``#X```#[R@``.````#K+```4````<\L``#L```"(RP``$````,3+```4
M````U<L``!,```#JRP``+0```/[+```M````+,P``#$```!:S```+0```(S,
M```N````NLP``"\```#IS```+````!G-```3````1LT```P```!:S0``*P``
M`&?-```:````D\T```D```"NS0``10```+C-``!!````_LT```\```!`S@``
M!````%#.```4````5<X```X```!JS@``$P```'G.```8````C<X```8```"F
MS@``"0```*W.```*````M\X```\```#"S@``$P```-+.```2````YLX```\`
M``#YS@``'`````G/```A````)L\``"4```!(SP``#@```&[/``!)````?<\`
M``4```#'SP``!@```,W/```(````U,\```8```#=SP``%````.3/```1````
M^<\```X````+T````@```!K0```.````'=```!H````LT```!0```$?0```'
M````3=````,```!5T```!@```%G0```-````8-````0```!NT````@```'/0
M```I````=M```!\```"@T```7````,#0```4````'=$``!0````RT0``!P``
M`$?1```.````3]$```@```!>T0``#````&?1```,````=-$``!,```"!T0``
M'0```)71```9````L]$```4```#-T0``$0```-/1```1````Y=$``"0```#W
MT0``"@```!S2```5````)](``!(````]T@``#@```%#2```9````7](```@`
M``!YT@``"0```(+2```(````C-(```4```"5T@``'P```)O2```&````N](`
M`!````#"T@``"````-/2```(````W-(``!$```#ET@``*@```/?2```N````
M(M,``"L```!1TP``*P```'W3```L````J=,``!H```#6TP``"0```/'3```*
M````^],``!4````&U```!0```!S4```4````(M0```0````WU```$````#S4
M```>````3=0``"@```!LU```"@```)74```<````H-0``!$```"]U```"P``
M`,_4```:````V]0```\```#VU```%`````;5```$````&]4```L````@U0``
M!0```"S5```&````,M4```@````YU0``(````$+5``!!````8]4``!H```"E
MU0``*````,#5```I````Z=4``%$````3U@``+P```&76``!7````E=8``"P`
M``#MU@``!@```!K7```%````(=<```@````GUP``*@```##7```(````6]<`
M`",```!DUP``+@```(C7```T````M]<```T```#LUP``"````/K7```7````
M`]@```H````;V```!P```";8```-````+M@``!`````\V```#0```$W8```+
M````6]@``!,```!GV```"````'O8```(````A-@```L```"-V```"@```)G8
M```4````I-@``#(```"YV```"P```.S8```%````^-@``!<```#^V```#P``
M`!;9```%````)MD```0````LV0``#0```#'9```R````/]D``!<```!RV0``
M%````(K9```%````G]D```<```"EV0``(P```*W9```.````T=D``"H```#@
MV0``!@````O:```,````$MH``!<````?V@``"P```#?:```V````0]H```L`
M``!ZV@``#P```(;:```+````EMH``"````"BV@``)P```,/:```K````Z]H`
M``D````7VP``,@```"';```P````5-L``#$```"%VP``+0```+?;``!"````
MY=L``$(````HW```0@```&O<``!!````KMP``#\```#PW```0@```##=```4
M````<]T```4```"(W0``!P```([=```:````EMT```@```"QW0``$0```+K=
M```'````S-T```0```#4W0``!P```-G=```*````X=T```L```#LW0``#```
M`/C=```#````!=X``!(````)W@``!@```!S>```>````(]X``!@```!"W@``
M)0```%O>```-````@=X```D```"/W@``"0```)G>```"````H]X```,```"F
MW@``!P```*K>```"````LMX```P```"UW@``%0```,+>```+````V-X``!D`
M``#DW@``(````/[>```2````']\```4````RWP``"@```#C?```5````0]\`
M`!(```!9WP``#````&S?```$````>=\```<```!^WP``"0```(;?```,````
MD-\``%(```"=WP``%P```/#?```D````".````8````MX```'P```#3@```=
M````5.````T```!RX```%0```(#@```2````EN````\```"IX```%````+G@
M```;````SN```&D```#JX```&@```%3A```7````;^$``!H```"'X0``%P``
M`*+A```;````NN$``!D```#6X0``'P```/#A```7````$.(``!,````HX@``
M!P```#SB```(````1.(```D```!-X@``%0```%?B```-````;>(``!,```![
MX@```P```(_B```_````D^(``#<```#3X@``5P````OC```O````8^,```H`
M``"3XP``"````)[C```-````I^,``"T```"UXP``!````./C```E````Z.,`
M``L````.Y```'0```!KD```&````..0```P````_Y```!P```$SD```9````
M5.0```D```!NY```$P```'CD```)````C.0```0```"6Y```$````)OD```*
M````K.0```@```"WY```"````,#D```,````R>0```\```#6Y```!P```.;D
M```Z````[N0``!0````IY0``#@```#[E```,````3>4``!L```!:Y0``+```
M`';E```3````H^4```4```"WY0``!````+WE```7````PN4```D```#:Y0``
M"````.3E```%````[>4```H```#SY0``$0```/[E```&````$.8``!@````7
MY@``#@```##F```.````/^8```T```!.Y@``"P```%SF```"````:.8```<`
M``!KY@``%P```'/F```&````B^8```D```"2Y@``!P```)SF```F````I.8`
M`!H```#+Y@``*@```.;F```9````$><``!4````KYP``!0```$'G```'````
M1^<```@```!/YP``!P```%CG```'````8.<```X```!HYP``"0```'?G```&
M````@><```@```"(YP``"P```)'G```'````G><```@```"EYP``!P```*[G
M```6````MN<```D```#-YP``!@```-?G```+````WN<``!0```#JYP``"```
M`/_G```&````".@``!D````/Z```"@```"GH```<````-.@```<```!1Z```
M!````%GH```%````7N@```0```!DZ```$````&GH```4````>N@```L```"/
MZ```#0```)OH```8````J>@``!<```#"Z```&@```-KH```4````]>@```0`
M```*Z0``"0````_I```"````&>D```X````<Z0``"````"OI```?````-.D`
M`#X```!4Z0``(P```)/I```C````M^D``#$```#;Z0``)P````WJ```<````
M->H``$H```!2Z@``.````)WJ```J````UNH``"@````!ZP``+````"KK```;
M````5^L``#X```!SZP``*````++K```9````V^L``$@```#UZP``+P```#[L
M``!!````;NP``%L```"P[```20````SM```A````5NT``!\```!X[0``*P``
M`)CM```A````Q.T``"D```#F[0``,P```!#N```E````1.X``#@```!J[@``
M)P```*/N```P````R^X``&D```#\[@``*P```&;O```R````DN\``#$```#%
M[P``,P```/?O```E````*_```#T```!1\```90```(_P``!-````]?```"\`
M``!#\0``+@```'/Q```K````HO$``"H```#.\0``/@```/GQ``!4````./(`
M`(,```"-\@``,@```!'S```R````1/,``!T```!W\P``(P```)7S``!8````
MN?,``"\````2]```+````$+T```M````;_0``!<```"=]```)0```+7T```R
M````V_0``"D````.]0``/@```#CU```B````=_4``%(```":]0``)0```.WU
M```+````$_8``',````?]@``(0```)/V```N````M?8``#````#D]@``)0``
M`!7W```<````._<``#$```!8]P``!````(KW```-````C_<```L```"=]P``
M#@```*GW```+````N/<```4```#$]P```@```,KW``!9````S?<```4````G
M^```$@```"WX```$````0/@```<```!%^```"````$WX```%````5O@```H`
M``!<^```$P```&?X```-````>_@```(```")^```!P```(SX```&````E/@`
M`!0```";^```#````+#X```8````O?@```8```#6^```$@```-WX```,````
M\/@```,```#]^```!`````'Y```&````!OD```<````-^0``'P```!7Y```U
M````-?D``"T```!K^0``(P```)GY```N````O?D``"\```#L^0``%P```!SZ
M```@````-/H``!L```!5^@``&````''Z```D````BOH``!\```"O^@``&@``
M`,_Z```=````ZOH``!H````(^P``+P```"/[```P````4_L``!H```"$^P``
M*P```)_[```?````R_L``",```#K^P``'P````_\```:````+_P``"4```!*
M_```)@```'#\```E````E_P``!@```"]_```)````-;\```8````^_P``!T`
M```4_0``)````#+]```8````5_T``"(```!P_0``'0```)/]```;````L?T`
M`"4```#-_0``'P```//]```C````$_X``!\````W_@``(````%?^```:````
M>/X``$$```"3_@``&P```-7^``!&````\?X``#X````X_P``)@```'?_```>
M````GO\``!X```"]_P``"0```-S_```,````YO\``!<```#S_P``(P````L`
M`0`O````+P`!`"0```!?``$`'P```(0``0`/````I``!`!0```"T``$`#@``
M`,D``0`-````V``!`"0```#F``$`!0````L!`0`'````$0$!`!,````9`0$`
M'@```"T!`0`9````3`$!`!<```!F`0$`'0```'X!`0`5````G`$!`!\```"R
M`0$`#````-(!`0`&````WP$!``D```#F`0$`&````/`!`0`+````"0(!``T`
M```5`@$`'0```","`0`7````00(!``8```!9`@$`,P```&`"`0`'````E`(!
M``8```"<`@$`$0```*,"`0`A````M0(!`!0```#7`@$`$P```.P"`0`,````
M``,!`!$````-`P$`,@```!\#`0`0````4@,!``@```!C`P$`'0```&P#`0`)
M````B@,!``H```"4`P$`!0```)\#`0`4````I0,!``H```"Z`P$`'0```,4#
M`0`(````XP,!`!\```#L`P$`"`````P$`0`:````%00!``8````P!`$`!P``
M`#<$`0`(````/P0!``D```!(!`$`/P```%($`0`'````D@0!``\```":!`$`
M"````*H$`0`3````LP0!``<```#'!`$`&0```,\$`0`*````Z00!``H```#T
M!`$`"0```/\$`0`7````"04!`!0````A!0$`"@```#8%`0`,````004!`!<`
M``!.!0$`!````&8%`0`J````:P4!`!$```"6!0$`!P```*@%`0`)````L`4!
M``(```"Z!0$`$````+T%`0`#````S@4!``@```#2!0$`!@```-L%`0`'````
MX@4!``T```#J!0$`"P```/@%`0`4````!`8!`!4````9!@$`#@```"\&`0`O
M````/@8!`"````!N!@$`'````(\&`0`3````K`8!``4```#`!@$`!@```,8&
M`0`)````S08!``P```#7!@$`"@```.0&`0!L````[P8!`"````!<!P$`$0``
M`'T'`0`"````CP<!``0```"2!P$`"@```)<'`0`&````H@<!``4```"I!P$`
M#````*\'`0!%````O`<!`"$````""`$`)0```"0(`0`H````2@@!`%,```!S
M"`$`&0```,<(`0`@````X0@!`#,````""0$`-0```#8)`0!%````;`D!`#``
M``"R"0$`'P```.,)`0`?`````PH!`"@````C"@$`)@```$P*`0`E````<PH!
M`"@```"9"@$`*````,(*`0`A````ZPH!`#`````-"P$`$@```#X+`0`0````
M40L!`'D```!B"P$`"0```-P+`0!R````Y@L!`',```!9#`$`?````,T,`0`K
M````2@T!`%,```!V#0$`%P```,H-`0!E````X@T!`%$```!(#@$`-P```)H.
M`0`V````T@X!`!\````)#P$`'P```"D/`0`?````20\!`!0```!I#P$`"@``
M`'X/`0`%````B0\!``8```"/#P$`"````)8/`0`0````GP\!``\```"P#P$`
M%0```,`/`0`#````U@\!``0```#:#P$`!````-\/`0`&````Y`\!``0```#K
M#P$`!P```/`/`0`9````^`\!``(````2$`$`!````!40`0`%````&A`!``0`
M```@$`$`"0```"40`0`&````+Q`!``<````V$`$`!0```#X0`0`&````1!`!
M``0```!+$`$`"P```%`0`0`)````7!`!``\```!F$`$`$P```'80`0`&````
MBA`!``<```"1$`$`$0```)D0`0`S````JQ`!`"(```#?$`$`!P````(1`0`'
M````"A$!``L````2$0$`!0```!X1`0`0````)!$!``(````U$0$`"P```#@1
M`0`$````1!$!``4```!)$0$`!````$\1`0`%````5!$!`#0!``!:$0$`.```
M`(\2`0!T````R!(!`",````]$P$`@@```&$3`0!T````Y!,!`"P```!9%`$`
M*P```(84`0`@````LA0!`"H```#3%`$`*````/X4`0`G````)Q4!`#<```!/
M%0$`-P```(<5`0`W````OQ4!`#8```#W%0$`-P```"X6`0`W````9A8!`"T`
M``">%@$`-@```,P6`0`R`````Q<!`"0````V%P$`+0```%L7`0`Q````B1<!
M`"@```"[%P$`*````.07`0`X````#1@!`"@```!&&`$`%P```&\8`0!N````
MAQ@!`#$```#V&`$`,@```"@9`0`Q````6QD!`&4```"-&0$`*````/,9`0`*
M````'!H!``P````G&@$`!P```#0:`0`'````/!H!``<```!$&@$`!@```$P:
M`0`"````4QH!`!````!6&@$`*@```&<:`0`2````DAH!``L```"E&@$`"P``
M`+$:`0`'````O1H!``4```#%&@$`$@```,L:`0`'````WAH!``<```#F&@$`
M"P```.X:`0`)````^AH!``L````$&P$`#0```!`;`0`-````'AL!`!T````L
M&P$`%0```$H;`0`=````8!L!``D```!^&P$`!0```(@;`0`*````CAL!`"H`
M``"9&P$`&P```,0;`0`1````X!L!``\```#R&P$`$0````(<`0`1````%!P!
M`"(````F'`$`!@```$D<`0`8````4!P!`"T```!I'`$`'@```)<<`0`4````
MMAP!`!(```#+'`$`#````-X<`0`2````ZQP!``H```#^'`$`&P````D=`0`4
M````)1T!``D````Z'0$`'0```$0=`0`4````8AT!`"D```!W'0$`)0```*$=
M`0`M````QQT!`#P```#U'0$`0````#(>`0!`````<QX!`$8```"T'@$`)P``
M`/L>`0`%````(Q\!``@````I'P$`#@```#(?`0`'````01\!``@```!)'P$`
M!@```%(?`0`;````61\!`!L```!U'P$`"P```)$?`0`$````G1\!``0```"B
M'P$`!````*<?`0`'````K!\!``H```"T'P$`#````+\?`0`*````S!\!``H`
M``#7'P$`"````.(?`0`3````ZQ\!`!,```#_'P$`#0```!,@`0`-````(2`!
M``8````O(`$`'P```#8@`0`.````5B`!`!````!E(`$`"````'8@`0`S````
M?R`!`"L```"S(`$`#P```-\@`0`9````[R`!``0````)(0$`!@````XA`0`?
M````%2$!``0````U(0$`"````#HA`0`&````0R$!``H```!*(0$`"@```%4A
M`0`$````8"$!`!````!E(0$`"@```'8A`0`(````@2$!`!0```"*(0$`%0``
M`)\A`0`&````M2$!``X```"\(0$`#@```,LA`0`.````VB$!``@```#I(0$`
M"@```/(A`0`;````_2$!`!4````9(@$`!@```"\B`0`&````-B(!``8````]
M(@$`"````$0B`0`&````32(!`!````!4(@$`"````&4B`0`.````;B(!`!(`
M``!](@$`!````)`B`0`$````E2(!`!<```":(@$`#````+(B`0`,````OR(!
M`!H```#,(@$`)````.<B`0`&````#",!``@````3(P$`%@```!PC`0`&````
M,R,!``H````Z(P$`#P```$4C`0`=````52,!`#,```!S(P$`&P```*<C`0`9
M````PR,!`!L```#=(P$`&0```/DC`0`(````$R0!``0````<)`$`!````"$D
M`0`(````)B0!``8````O)`$`*@```#8D`0`C````820!`"D```"%)`$`:P``
M`*\D`0`H````&R4!`"@```!$)0$`*````&TE`0`G````EB4!`!H```"^)0$`
M&@```-DE`0`H````]"4!`"X````=)@$`"0```$PF`0`,````5B8!`!````!C
M)@$`#0```'0F`0`+````@B8!``H```".)@$`"````)DF`0`(````HB8!`!(`
M``"K)@$`%````+XF`0`*````TR8!``0```#>)@$`&````.,F`0`(````_"8!
M``@````%)P$`!@````XG`0`(````%2<!``8````>)P$`!@```"4G`0`$````
M+"<!``H````Q)P$`!````#PG`0`$````02<!``@```!&)P$`"````$\G`0`(
M````6"<!``8```!A)P$`!````&@G`0`(````;2<!``0```!V)P$`%````'LG
M`0`(````D"<!``@```"9)P$`!````*(G`0`.````IR<!``0```"V)P$`!```
M`+LG`0`=````P"<!`!<```#>)P$`"````/8G`0`(````_R<!``H````(*`$`
M!````!,H`0`&````&"@!``P````?*`$``P```"PH`0`*````,"@!``0````[
M*`$`!@```$`H`0`&````1R@!``8```!.*`$`!````%4H`0`:````6B@!``8`
M``!U*`$`!````'PH`0`,````@2@!`!(```".*`$`$@```*$H`0`8````M"@!
M`#$```#-*`$`&0```/\H`0`&````&2D!``@````@*0$`"````"DI`0`6````
M,BD!``H```!)*0$`$0```%0I`0`(````9BD!``@```!O*0$`!````'@I`0`$
M````?2D!``0```""*0$`"````(<I`0`5````D"D!``0```"F*0$`!````*LI
M`0`1````L"D!``\```#"*0$`"````-(I`0`.````VRD!``D```#J*0$`#0``
M`/0I`0`&`````BH!`!4````)*@$`'0```!\J`0`7````/2H!``P```!5*@$`
M!@```&(J`0`*````:2H!``@```!T*@$`!````'TJ`0`*````@BH!``@```"-
M*@$`!````)8J`0`&````FRH!``0```"B*@$`!````*<J`0`(````K"H!``D`
M``"U*@$`!@```+\J`0`$````QBH!``D```#+*@$`!@```-4J`0`&````W"H!
M``0```#C*@$`!@```.@J`0`$````[RH!``0```#T*@$`!P```/DJ`0`(````
M`2L!``H````**P$`!````!4K`0`*````&BL!``H````E*P$`*P```#`K`0`:
M````7"L!``T```!W*P$`"````(4K`0`(````CBL!`!$```"7*P$`!@```*DK
M`0`*````L"L!``@```"[*P$`%````,0K`0`8````V2L!`!<```#R*P$`%P``
M``HL`0`4````(BP!`!8````W+`$`'0```$XL`0`6````;"P!`"(```"#+`$`
M$0```*8L`0`A````N"P!`!(```#:+`$`%0```.TL`0`6`````RT!`!T````:
M+0$`%0```#@M`0`8````3BT!`!T```!G+0$`#````(4M`0`7````DBT!`!T`
M``"J+0$`#````,@M`0`7````U2T!`$(```#M+0$`&````#`N`0`Y````22X!
M`!,```"#+@$`&0```)<N`0`6````L2X!`!D```#(+@$`,````.(N`0`K````
M$R\!``0````_+P$`!````$0O`0`,````22\!``P```!6+P$`"@```&,O`0`(
M````;B\!``@```!W+P$`!````(`O`0`(````A2\!``@```".+P$`"````)<O
M`0`*````H"\!``@```"K+P$`"````+0O`0`(````O2\!`!$```#&+P$`%P``
M`-@O`0`:````\"\!``H````+,`$``@```!8P`0`$````&3`!``0````>,`$`
M!````",P`0`(````*#`!``@````Q,`$`!````#HP`0`&````/S`!``0```!&
M,`$`"````$LP`0`,````5#`!``@```!A,`$`"````&HP`0`&````<S`!``0`
M``!Z,`$`"@```'\P`0`(````BC`!``X```"3,`$`#P```*(P`0`C````LC`!
M``P```#6,`$`(````.,P`0`5````!#$!``@````:,0$`!````",Q`0`(````
M*#$!`!D````Q,0$`"````$LQ`0`$````5#$!`!T```!9,0$`%P```'<Q`0`$
M````CS$!``@```"4,0$`%@```)TQ`0`*````M#$!``@```"_,0$`"````,@Q
M`0`$````T3$!``H```#6,0$`$0```.$Q`0`(````\S$!``@```#\,0$`!@``
M``4R`0`&````##(!`!P````3,@$`*0```#`R`0`(````6C(!``X```!C,@$`
M!````'(R`0`'````=S(!`!X```!_,@$`"````)XR`0`(````IS(!``0```"P
M,@$`"````+4R`0`$````OC(!``@```##,@$`"@```,PR`0`(````US(!``@`
M``#@,@$`#@```.DR`0`(````^#(!``X````!,P$`#P```!`S`0`$````(#,!
M``@````E,P$`"````"XS`0`,````-S,!`!4```!$,P$`#````%HS`0`(````
M9S,!``D```!P,P$`"0```'HS`0`$````A#,!``0```"),P$`"@```(XS`0`Q
M````F3,!``H```#+,P$`"@```-8S`0`$````X3,!`"$```#F,P$`'P````@T
M`0`7````*#0!``8```!`-`$`"````$<T`0`*````4#0!``0```!;-`$`"@``
M`&`T`0`*````:S0!``D```!V-`$`"````(`T`0`*````B30!``D```"4-`$`
M!P```)XT`0`$````IC0!``<```"K-`$`!````+,T`0`&````N#0!``8```"_
M-`$`$0```,8T`0`-````V#0!`!````#F-`$`%0```/<T`0`4````#34!`!``
M```B-0$`$````#,U`0`;````1#4!`!````!@-0$`#````'$U`0`=````?C4!
M``@```"<-0$`"0```*4U`0`$````KS4!``0```"T-0$`"````+DU`0`*````
MPC4!``0```#--0$`$P```-(U`0`1````YC4!``H```#X-0$`"`````,V`0`*
M````##8!``@````7-@$`%0```"`V`0`&````-C8!``0````]-@$`!@```$(V
M`0`&````238!``@```!0-@$`!````%DV`0`.````7C8!``@```!M-@$`"```
M`'8V`0`3````?S8!``\```"3-@$`3@```*,V`0`$````\C8!``0```#W-@$`
M"````/PV`0`$````!3<!``0````*-P$`"`````\W`0`0````&#<!``D````I
M-P$`!@```#,W`0`$````.C<!``T````_-P$`#0```$TW`0`.````6S<!`!(`
M``!J-P$`"@```'TW`0`.````B#<!``8```"7-P$``@```)XW`0`(````H3<!
M``0```"J-P$`!````*\W`0`(````M#<!``0```"]-P$`!@```,(W`0`2````
MR3<!`!H```#<-P$`"````/<W`0`$`````#@!``T````%.`$`!````!,X`0`(
M````&#@!``(````A.`$`!````"0X`0`+````*3@!``0````U.`$`!````#HX
M`0`3````/S@!``0```!3.`$`!@```%@X`0`(````7S@!``0```!H.`$`"@``
M`&TX`0`2````>#@!``H```"+.`$`!@```)8X`0`*````G3@!``0```"H.`$`
M"````*TX`0`(````MC@!``@```"_.`$`"````,@X`0`(````T3@!``@```#:
M.`$`!@```.,X`0`0````ZC@!``8```#[.`$``@````(Y`0`$````!3D!`!$`
M```*.0$`!````!PY`0`)````(3D!``0````K.0$`$````#`Y`0`7````03D!
M``0```!9.0$`#@```%XY`0`$````;3D!`*````!R.0$`$0```!,Z`0`0````
M)3H!``8````V.@$`!````#TZ`0`(````0CH!``@```!+.@$`"````%0Z`0`(
M````73H!``4```!F.@$`#@```&PZ`0`.````>SH!`!````"*.@$`!@```)LZ
M`0`-````HCH!``0```"P.@$`!@```+4Z`0`&````O#H!`!4```##.@$`%0``
M`-DZ`0`=````[SH!`!`````-.P$`(````!X[`0`$````/SL!``@```!$.P$`
M"@```$T[`0`D````6#L!``@```!].P$`!````(8[`0`B````BSL!`"````"N
M.P$`%0```,\[`0`N````Y3L!`#`````4/`$`&@```$4\`0`-````8#P!``P`
M``!N/`$`"0```'L\`0`&````A3P!`!D```",/`$`$P```*8\`0`8````NCP!
M`!````#3/`$`$````.0\`0`8````]3P!``@````./0$`!````!<]`0`(````
M'#T!``H````E/0$`!````#`]`0`$````-3T!`!0````Z/0$`"````$\]`0`,
M````6#T!``X```!E/0$`"````'0]`0`-````?3T!`!$```"+/0$`!````)T]
M`0`&````HCT!``@```"I/0$`'0```+(]`0`9````T#T!``\```#J/0$`#P``
M`/H]`0`/````"CX!``X````:/@$`$````"D^`0`0````.CX!`!8```!+/@$`
M$P```&(^`0`/````=CX!``\```"&/@$`#@```)8^`0`/````I3X!`!$```"U
M/@$`$````,<^`0`&````V#X!``8```#?/@$`!````.8^`0`&````ZSX!``8`
M``#R/@$`!````/D^`0`&````_CX!``8````%/P$`!`````P_`0`,````$3\!
M`!(````>/P$`!@```#$_`0`$````.#\!``0````]/P$`!````$(_`0`$````
M1S\!``@```!,/P$`"````%4_`0`(````7C\!``H```!G/P$`"@```'(_`0`&
M````?3\!`!(```"$/P$`"````)<_`0`(````H#\!``@```"I/P$`"````+(_
M`0`(````NS\!`"@```#$/P$`#@```.T_`0`$````_#\!``0````!0`$`#0``
M``9``0`&````%$`!``H````;0`$`!````"9``0`$````*T`!``8````P0`$`
M!@```#=``0`)````/D`!``X```!(0`$`%````%=``0`6````;$`!``@```"#
M0`$`!@```(Q``0`(````DT`!``8```"<0`$`!@```*-``0`(````JD`!``8`
M``"S0`$`"@```+I``0`$````Q4`!``0```#*0`$`!````,]``0`=````U$`!
M``P```#R0`$`$0```/]``0`/````$4$!`!,````A00$`$0```#5!`0`1````
M1T$!``\```!900$`$P```&E!`0`4````?4$!``0```"200$`!@```)=!`0`/
M````GD$!``H```"N00$`"@```+E!`0`$````Q$$!``0```#)00$`"0```,Y!
M`0`$````V$$!``<```#=00$`!````.5!`0`K````ZD$!``D````60@$`!```
M`"!"`0`&````)4(!``(````L0@$`"````"]"`0`;````.$(!``,```!40@$`
M"````%A"`0`,````84(!``P```!N0@$`!````'M"`0`*````@$(!``@```"+
M0@$`.P```)1"`0`.````T$(!``8```#?0@$`"````.9"`0`(````[T(!``0`
M``#X0@$`!@```/U"`0`$````!$,!`!(````)0P$`)````!Q#`0`*````04,!
M``H```!,0P$`#````%=#`0`*````9$,!``@```!O0P$`%P```'A#`0`8````
MD$,!`!<```"I0P$`#````,%#`0`$````SD,!``H```#30P$`$@```-Y#`0`G
M````\4,!``@````91`$`"````")$`0`(````*T0!``@````T1`$`"````#U$
M`0`,````1D0!``0```!31`$`"0```%A$`0`E````8D0!`"(```"(1`$`&@``
M`*M$`0`$````QD0!`"P```#+1`$`"P```/A$`0`(````!$4!`!,````-10$`
M*P```"%%`0`$````344!`!(```!210$`!````&5%`0`&````:D4!`!(```!Q
M10$`"0```(1%`0`8````CD4!`!<```"G10$`!````+]%`0`W````Q$4!`!``
M``#\10$`&`````U&`0`0````)D8!``8````W1@$`"````#Y&`0`(````1T8!
M``0```!01@$`!````%5&`0`(````6D8!``8```!C1@$`!````&I&`0`&````
M;T8!``0```!V1@$`"@```'M&`0`(````AD8!``8```"/1@$`!````)9&`0`$
M````FT8!``0```"@1@$`!````*5&`0`$````JD8!``0```"O1@$`"````+1&
M`0`'````O48!``0```#%1@$`"````,I&`0`(````TT8!`!````#<1@$`!```
M`.U&`0`+````\D8!``0```#^1@$`"`````-'`0`$````#$<!``0````11P$`
M#````!9'`0`&````(T<!``0````J1P$`#````"]'`0`3````/$<!`!<```!0
M1P$`$P```&A'`0`1````?$<!``0```".1P$`!````)-'`0`,````F$<!``0`
M``"E1P$`$0```*I'`0`&````O$<!``@```##1P$`#P```,Q'`0`$````W$<!
M``8```#A1P$`!@```.A'`0`*````[T<!``@```#Z1P$`!@````-(`0`(````
M"D@!``0````32`$`!@```!A(`0`:````'T@!`!\````Z2`$`(0```%I(`0`-
M````?$@!`!<```"*2`$`'````*)(`0`;````OT@!`!\```#;2`$`(````/M(
M`0`(````'$D!`"0````E20$`"@```$I)`0`/````54D!`!````!E20$`&P``
M`'9)`0`;````DDD!`!\```"N20$`&P```,Y)`0`<````ZDD!`!T````'2@$`
M&@```"5*`0`3````0$H!``@```!42@$`$P```%U*`0`9````<4H!``8```"+
M2@$`+P```))*`0`Q````PDH!``@```#T2@$``@```/U*`0`6`````$L!``@`
M```72P$`!@```"!+`0`.````)TL!``0````V2P$`!@```#M+`0`&````0DL!
M``@```!)2P$`&````%)+`0`7````:TL!``P```"#2P$`$@```)!+`0`7````
MHTL!`!8```"[2P$`"````-)+`0`A````VTL!``8```#]2P$`!`````1,`0`&
M````"4P!``0````03`$`!@```!5,`0`(````'$P!``0````E3`$``@```"I,
M`0`*````+4P!`!`````X3`$`!@```$E,`0`$````4$P!``0```!53`$`!@``
M`%I,`0`(````84P!``0```!J3`$`!````&],`0`C````=$P!`!,```"83`$`
M)@```*Q,`0`.````TTP!``X```#B3`$`!````/%,`0`)````]DP!``0`````
M30$`"`````5-`0`$````#DT!``@````330$`$````!Q-`0`4````+4T!``0`
M``!"30$`"````$=-`0`*````4$T!``T```!;30$`"0```&E-`0`,````<TT!
M``P```"`30$`#````(U-`0`6````FDT!``P```"Q30$`"````+Y-`0`(````
MQTT!``0```#030$`$````-5-`0`&````YDT!``X```#M30$`!@```/Q-`0`$
M`````TX!``L````(3@$`$@```!1.`0`6````)TX!`!,````^3@$`%````%).
M`0`=````9TX!``@```"%3@$`!0```(Y.`0`&````E$X!``T```";3@$`!```
M`*E.`0`$````KDX!``0```"S3@$`"@```+A.`0`,````PTX!`!,```#03@$`
M!````.1.`0`4````Z4X!``@```#^3@$`!`````=/`0`(````#$\!``0````5
M3P$`!````!I/`0`$````'T\!``8````D3P$`!````"M/`0`$````,$\!``@`
M```U3P$`%0```#Y/`0`F````5$\!`!$```![3P$`$0```(U/`0`6````GT\!
M`"X```"V3P$`-````.5/`0`J````&E`!`!<```!%4`$`!````%U0`0`$````
M8E`!``8```!G4`$`*P```&Y0`0`(````FE`!`!8```"C4`$`*0```+I0`0`O
M````Y%`!``0````440$`!````!E1`0`,````'E$!``8````K40$`!````#)1
M`0`&````-U$!``H````^40$`#@```$E1`0`(````6%$!``@```!A40$`!0``
M`&I1`0`$````<%$!``@```!U40$`"````'Y1`0`,````AU$!`!H```"440$`
M"````*]1`0`&````N%$!`!0```"_40$`!````-11`0`$````V5$!``0```#>
M40$`"````.-1`0`E````[%$!``@````24@$`#0```!M2`0`*````*5(!``0`
M```T4@$`&````#E2`0`*````4E(!`"@```!=4@$`!````(92`0`(````BU(!
M`!````"44@$`!@```*52`0`G````K%(!``@```#44@$`#````-U2`0`)````
MZE(!`!0```#T4@$`'`````E3`0`>````)E,!``@```!%4P$`%P```$Y3`0`:
M````9E,!`!<```"!4P$`%0```)E3`0`C````KU,!`",```#34P$`(P```/=3
M`0`B````&U0!`"`````^5`$`(P```%]4`0`.````@U0!``0```"25`$`!```
M`)=4`0`2````G%0!``4```"O5`$`"````+54`0`2````OE0!``0```#15`$`
M$@```-94`0`+````Z50!``@```#U5`$`"````/Y4`0`$````!U4!`!L````,
M50$`#P```"A5`0`/````.%4!`!8```!(50$`#@```%]5`0`$````;E4!``H`
M``!S50$`"@```'Y5`0`"````B54!``H```",50$`!````)=5`0`&````G%4!
M``H```"C50$`#@```*Y5`0`*````O54!`!0```#(50$`$@```-U5`0`2````
M\%4!``8````#5@$`"`````I6`0`0````$U8!``H````D5@$`"@```"]6`0`$
M````.E8!``<````_5@$`"0```$=6`0`(````458!`#H```!:5@$`#P```)56
M`0`7````I58!``0```"]5@$`(````,)6`0`4````XU8!``P```#X5@$`%@``
M``57`0`2````'%<!``X````O5P$`%````#Y7`0`1````4U<!`$,```!E5P$`
M#0```*E7`0`1````MU<!``T```#)5P$`$0```-=7`0`7````Z5<!`!`````!
M6`$`#0```!)8`0`.````(%@!``P````O6`$`$@```#Q8`0`(````3U@!``0`
M``!86`$`+````%U8`0`$````BE@!``\```"/6`$`!````)]8`0`A````I%@!
M`",```#&6`$`.@```.I8`0`<````)5D!`!,```!"60$`!````%99`0`(````
M6UD!`"$```!D60$`!````(99`0`@````BUD!``H```"L60$`$P```+=9`0`$
M````RUD!`!<```#060$`!````.A9`0`4````[5D!``0````"6@$`"`````=:
M`0`2````$%H!``0````C6@$`"````"A:`0`)````,5H!`!,````[6@$`%0``
M`$]:`0`*````95H!`!P```!P6@$`$@```(U:`0`<````H%H!``P```"]6@$`
M"````,I:`0`3````TUH!`!$```#G6@$`+````/E:`0`&````)EL!``X````M
M6P$`"````#Q;`0`,````15L!`!0```!26P$`!````&=;`0`$````;%L!``@`
M``!Q6P$``@```'I;`0`$````?5L!`!(```""6P$`"````)5;`0`$````GEL!
M``8```"C6P$`"````*I;`0`&````LUL!``0```"Z6P$`#````+];`0`$````
MS%L!``0```#16P$`!````-9;`0`7````VUL!``\```#S6P$`%P````-<`0`-
M````&UP!``T````I7`$`#````#=<`0`$````1%P!``0```!)7`$`!````$Y<
M`0`$````4UP!``D```!87`$`!@```&)<`0`$````:5P!``8```!N7`$`!```
M`'5<`0`$````>EP!`!$```!_7`$`!````)%<`0`6````EEP!`!0```"M7`$`
M#0```,)<`0`2````T%P!`!T```#C7`$`$`````%=`0`$````$ET!``0````7
M70$`%0```!Q=`0`G````,ET!``4```!:70$`"````&!=`0`(````:5T!``0`
M``!R70$`"````'==`0`2````@%T!``0```"370$`!@```)A=`0`0````GUT!
M``@```"P70$`#````+E=`0`(````QET!``0```#/70$`!@```-1=`0`&````
MVUT!``X```#B70$`#P```/%=`0`1`````5X!`#@````37@$`'0```$Q>`0`8
M````:EX!`!P```"#7@$`%@```*!>`0`0````MUX!`"@```#(7@$`&P```/%>
M`0`9````#5\!`!T````G7P$`'0```$5?`0`1````8U\!`!D```!U7P$`'0``
M`(]?`0`.````K5\!`#(```"\7P$`&P```.]?`0`O````"V`!`#$````[8`$`
M+P```&U@`0`7````G6`!`!<```"U8`$`%@```,U@`0`3````Y&`!`!\```#X
M8`$`'P```!AA`0`3````.&$!`"````!,80$`&0```&UA`0`1````AV$!`$(`
M``"980$`%````-QA`0`C````\6$!`"0````58@$`'P```#IB`0`<````6F(!
M`"0```!W8@$`.0```)QB`0`O````UF(!`!<````&8P$`&P```!YC`0`=````
M.F,!`"$```!88P$`*@```'IC`0`X````I6,!`&T```#>8P$`&P```$QD`0`E
M````:&0!``\```".9`$`$0```)YD`0`Z````L&0!`!X```#K9`$`'@````IE
M`0`;````*64!`!$```!%90$`&0```%=E`0`;````<64!`!L```"-90$`)```
M`*EE`0`/````SF4!`#T```#>90$`$P```!QF`0`(````,&8!`#H````Y9@$`
M$P```'1F`0`G````B&8!`"T```"P9@$`%P```-YF`0`/````]F8!`"0````&
M9P$`!````"MG`0`(````,&<!``@````Y9P$`"````$)G`0`+````2V<!``0`
M``!79P$`!@```%QG`0!/````8V<!``0```"S9P$`#0```+AG`0`$````QF<!
M``H```#+9P$`!````-9G`0`$````VV<!``8```#@9P$`$````.=G`0`&````
M^&<!``8```#_9P$`!@````9H`0`&````#6@!`!4````4:`$`"@```"IH`0`2
M````-6@!``8```!(:`$`#@```$]H`0`,````7F@!``0```!K:`$`!0```'!H
M`0`&````=F@!``8```!]:`$`$@```(1H`0`=````EV@!`!\```"U:`$`&```
M`-5H`0`>````[F@!`!\````-:0$`#@```"UI`0`7````/&D!`!(```!4:0$`
M$@```&=I`0`7````>FD!`!(```"2:0$`$@```*5I`0`3````N&D!`!$```#,
M:0$`&@```-YI`0`:````^6D!`!(````4:@$`$0```"=J`0`2````.6H!`!8`
M``!,:@$`%P```&-J`0`2````>VH!`!4```".:@$`$P```*1J`0`0````N&H!
M``H```#):@$`%P```-1J`0`2````[&H!`!<```#_:@$`$@```!=K`0`2````
M*FL!`!$````]:P$`%````$]K`0`2````9&L!`!8```!W:P$`&````(YK`0`6
M````IVL!`!X```"^:P$`'P```-UK`0`8````_6L!`#4````6;`$`%0```$QL
M`0`M````8FP!`#,```"0;`$`$@```,1L`0`7````UVP!`!8```#O;`$`!@``
M``9M`0`(````#6T!``0````6;0$`'````!MM`0`>````.&T!`!L```!7;0$`
M$P```'-M`0`.````AVT!`!````"6;0$`!````*=M`0`$````K&T!`"0```"Q
M;0$`!````-9M`0`&````VVT!``X```#B;0$`$@```/%M`0`2````!&X!`!(`
M```7;@$`$P```"IN`0`.````/FX!`!8```!-;@$`!@```&1N`0`$````:VX!
M``<```!P;@$`#````'AN`0`(````A6X!``P```".;@$`&P```)MN`0`/````
MMVX!``0```#';@$`)0```,QN`0`&````\FX!``4```#Y;@$`"@```/]N`0`=
M````"F\!`!$````H;P$`"````#IO`0`(````0V\!``@```!,;P$`&P```%5O
M`0`(````<6\!``8```!Z;P$`$P```(%O`0`'````E6\!``8```"=;P$`!```
M`*1O`0`-````J6\!``P```"W;P$`$0```,1O`0`$````UF\!`!(```#;;P$`
M!@```.YO`0`8````]6\!``(````.<`$`"````!%P`0`$````&G`!``@````?
M<`$`)````"AP`0`$````37`!``@```!2<`$`!````%MP`0`/````8'`!``<`
M``!P<`$`#````'AP`0`*````A7`!``@```"0<`$`#````)EP`0`.````IG`!
M``P```"U<`$`!@```,)P`0`(````R7`!`!T```#2<`$`!````/!P`0`;````
M]7`!`!`````1<0$`!````")Q`0`&````)W$!``8````N<0$`"````#5Q`0`$
M````/G$!``0```!#<0$`!````$AQ`0`$````37$!``D```!2<0$`"````%QQ
M`0`1````97$!`!(```!W<0$`"````(IQ`0`C````DW$!``\```"W<0$`#0``
M`,=Q`0`(````U7$!``4```#><0$`!@```.1Q`0`(````ZW$!``H```#T<0$`
M"@```/]Q`0`^````"G(!`!8```!)<@$`#0```&!R`0`"````;G(!``(```!Q
M<@$`#````'1R`0`$````@7(!``0```"&<@$`"P```(MR`0`]````EW(!`!@`
M``#5<@$`&````.YR`0`A````!W,!`"4````I<P$`"P```$]S`0`7````6W,!
M`#<```!S<P$`/P```*MS`0`A````ZW,!`!P````-=`$`$````"IT`0`0````
M.W0!`!4```!,=`$`$P```&)T`0`3````=G0!`!,```"*=`$`$P```)YT`0`0
M````LG0!`!X```##=`$`$````.)T`0`(````\W0!`%$```#\=`$`"````$YU
M`0`K````5W4!`"L```"#=0$`40```*]U`0`;`````78!`"X````==@$`$P``
M`$QV`0!*````8'8!`"L```"K=@$`'P```-=V`0`?````]W8!`!`````7=P$`
M$````"AW`0`/````.7<!``\```!)=P$`"````%EW`0`&````8G<!``8```!I
M=P$`"````'!W`0`*````>7<!`!0```"$=P$`#P```)EW`0`"````J7<!``(`
M``"L=P$`!````*]W`0`$````M'<!``0```"Y=P$`!@```+YW`0`3````Q7<!
M``,```#9=P$`!````-UW`0`$````XG<!``0```#G=P$`!````.QW`0`"````
M\7<!``(```#T=P$``@```/=W`0`"````^G<!``0```#]=P$`!P````)X`0`&
M````"G@!``D````1>`$`"0```!MX`0`"````)7@!``(````H>`$`$````"MX
M`0`D````/'@!`!H```!A>`$`!@```'QX`0`&````@W@!``@```"*>`$`!0``
M`)-X`0`,````F7@!``4```"F>`$`$````*QX`0`"````O7@!``(```#`>`$`
M`@```,-X`0`"````QG@!``$`````````%P(``'````!I````-0````````#W
M`@```````+`%````````Y0,```````!K`````P```-(%``"Y!```I`$```H%
M``````````````````".`P``6@0```````"K`@``````````````````````
M``````!-!```S@$``%`%``"(`P``2P```$`$``#*!0```````$\```#Q````
MPP4``'\$``#J!0````````````"/`@``````````````````+@0```\$````
M````"`4``.P````+`0```````$$%``"-````+P4``+8!````````9P(`````
M```!!```(00``$@$``!+!```[`$``!8!``"Y`0```````!X$``!Y`P``700`
M````````````=P4``,8!```"!```,0(````````6`@``<`4```````"N`P``
M`````*,%``#H`P``WP(``.0```"A`0``W0```#8"```S`P``'@```)H$```Q
M`P``H00``!4$`````````````,,!``#C`0``/P,````````@````%@4``","
M```.!```B@$``)$%````````/P(```````````````````````"M````KP$`
M`%$$``#I`P``"00```````!J!```8@4``,`"``#D!```/P4``#X!```Y`@``
MI0$`````````````;````*`"````````!P````````!<`P``G`,``&\"```W
M!0``?P4``#<#````````Q0(``)`#``````````````T$``#M`0``80$`````
M```Q!```50,``#(%``"$`@``ZP$``,0"```'`@``<P4``#@%````````````
M``````!=````L`(```````#Y`P``:00``"(%`````````````"$#``!K`P``
M900``&T#``"&`@``G@(``&(`````````3P,``)<#````````^`4``/X$``#B
M`0``&0```$8"````````$0```+8"``````````````````#=`0``1P,```$"
M````````Z`0``-X!``#/`@``,P0``%<%```\````GP(``%\```#Z!```````
M``````"4!0``.@0``)H!``#[`P```````$8$````````I`(```````"?`0``
M,0$``$8#``!9!0``=P```+8$``!F`@``00````````````````````````"T
M`P``-`$``!(%````````?0,`````````````?P(``(4`````````L@4``,$#
M```J`0````````````";`@```````*,!```U!```3P$```````#B````````
M`$P%``#U`0``&````,D$``!;`0``80(``*L$````````!P4``/8#````````
MD@(``*8%``"L!```V00``/(%````````*0,```L"``!1`0```````'X!````
M````DP(``/T"``#3`0```````)L$``!,`0``/P```)(#````````-0(``*4#
M``"+````^P4`````````````K0$``!H#``!N!0``9@$```````"J!```IP0`
M````````````[@(``,@#``````````````````"_`0``E0,``!(#``!\`P``
M@P$`````````````TP,```````#8`P``N`$```````!'`@``BP$````````T
M!0``]0,``,H$`````````````*T%``!U`@``?`0``#H#``#-`P```P0``-`#
M``#S`P``,0```-4"``#5`0``<0```(`!`````````````!@%````````O0(`
M`,,#````````7P$``%8#``!"!0```````-(```!$`0``0P$``.D```!F````
M``````````````````````$!``"(!0``O`4``*X$``"=!0``&`0``.P#``":
M!0``B0```"L%``#[!```_@,``)@!``"&!````````)4%``!)`P``C@``````
M``"N`0``(P$``.D%``"/!```TP```)`````R`@``+0`````````K`P``````
M```````7!```*`(``%0%``!<````DP0``!X!``!/!```.00```````#P!0``
M`````(H%```<`P````````H"``!"`P```````&`$```)!0``X04```````"0
M`0``)@0``'`#``"V!0``!`0``+P!``##`@```````&,!``#4`0``D`(``$,#
M``!C`P``Z`````\#``#!````I@0```````#?````Z@$``!\#``"D!```````
M`!T`````````J04``#T!`````````````/(!```R`0``A0$```````"_!0``
M`````"T#``#"!0```````),````S!0``I@$``(T%````````;@$``&X$``!;
M````RP0``.$"``#O!```A0,``,(!``"A`P``)P0``"@%``!"`0```````'@%
M``!.`P``1`,```````#^``````````````!:`P``O`(``)4"``!=!0``30$`
M````````````]`4```````#F`P``R04``!H```!)`````````,T$``#%````
MG`$``$P```"F````100``,D#`````````````/@$``#9`P```````!$"``"U
M`0``#@```'X"``"!!0``P@```-`"``"V`P``0@````````#.`P```````!<`
M```2`0``Q00``!\$``"[`@``7`4`````````````%04``,<!````````````
M``D!``"<!0``O@0```````#$`0```````-P!````````5`$``*\%```R````
M$P0```````",````@@0`````````````2P4``*$%```B````U0,``)4!``#E
M````J0,``-D!``#1!```)`(``%(%``!A````90```'8#```%!0``W`4``)0$
M``##!`````````````"2!```4P0``*`!```4!0``IP```%8"``#5!```J@$`
M`+@#``!8`@````````@!``!F`P``ZP0``/0```!Q!````````-\#``#\`@``
MH@$``+P$```\`0``F@(``#\$````````?@0``,$"```V`P``(`$``/P$````
M````!`4``$@%``#Y!```YP$``"8`````````I04``$,"``",!```_`$``$H!
M`````0``?04`````````````$P4``#H``````P``_P0```8%``!D!0``T@(`
M`&$$``#4````@`4```P$```^`P``UP```/$$````````H@``````````````
M@`,``-L```!Y`@``PP```/<$```>!0```````.`%````````[@,``$0$```\
M!```Q@(```$%````````LP0```````"$````/`4``-P#````````VP$``-H#
M````````E@0``,`!``#G`@``00$````````L`P``'00```````#=!0``=P0`
M`!,!``"6`@```````#X$``"[!```>04``+,%``!0`P``T````$`#````````
M/0(``.H```!@!0``:`4``&H!``````````````````#(!0```````/$#``#<
M!```+@```#@```#>````=`(``)<```!-`P``%P$``)$$````````K00`````
M``#V!0``<04``(D#``!5!0``*@,``"($````````:@```!\```#U`@``G@``
M`$P"```\`P``ZP,````````2`@``G0```!H"````````\P4``)T$``!-`@``
MLP(``-\$````````,04```````#F`0``,P$``)\#``!*`P``V````&T"``!U
M!0``[`4``,X$``![!0``YP,```````![`0```````%T"``"0!0```````/\#
M``!D`@```````"0!````````:`0```````#1`P``304```T!``#'````%`,`
M``````!Z`0```````)8!````````:`,```````#`!```U`,``"4```#O`@``
M<P0``%@```!P!````````/H"``#@!```@P0````````H`0``U@4``!4#````
M````Y0$``(T!````````9`$``!$!``!N`P``SP$```````#B!```[`0``*\"
M```.`P``)04``+@```#I`@``5P$````````-`@``\@(``&P"````````[0(`
M`%8```!9!```UP4``$\%```\`@``60$``)<"````````:P(``*0%```2````
M+@,````````E!```RP,``%,!``"9`@```````+X```#1`````````!T#``!:
M`@``L0````````"Y!0``5P,``-L$````````#`$``+X!``!A`P```````$`!
M``#G!```.P$``(D!```L`````````%`$````````^P$```@$``#`!0``!@(`
M`"L"``"/!0``V@````@"```;`P``H````*L`````````Z00```````"/`0``
M0`(``%,%``"L`P```````/$"````````SP```'(#``#*````U@,``/@#``#H
M`@```````,0#``"#!0``O`,``+T```#(!```NP$``$X"``!L!```X`,``$0"
M``"O!```P`,```````!M!0``X````+\#`````````````(@````&`P``>`$`
M``````",`P``]P,```````".!```6P(```````#,`P``_P```'H#````````
M1@$````````C`P``H@4``+T$``!K!```U@$``%$``````````````(H`````
M````````````````````!P0````````&`0``!0$``,<#``"Z````!`$```D#
M```%!```X00``$("``"'````[04``"<#``#]!```(P4``&`#``"Q`@``````
M``````"P`P```````"8%``#,`0```````'P"``!G`0``+P(`````````````
M[P4```````#-`0``HP```-$!````````#`(``)`$``"?!0```````$T```"9
M`P``MP4```````!U`P```````'X%````````G`(```````"^`P``^04``*H"
M````````404``#@"```````````````````'`P``1````(8```#J`P``F04`
M`)P`````````;00``````````````````(@$````````NP4``&4!``#&!```
M`````'\#``"8!0``Q@```%8%````!```G@,``&D#````````3@$``#X%``#_
M!0```P$```````!8!```)0(``.0%``!Z````_`4````````7`P``$`0``!$#
M``"*!```A`4``-\!``"2!0``804``&,%``!6!```2`,``$D"```;`@``/@(`
M`*T"``"'`P``"@0``*H````S````@P(``$``````````@@,``/L"``"+!```
MQ0$```L#````````MP0``*("```8`@```````/X"```Z`@``=@(``/4%````
M`````````+P`````````DP,``'P!``#]!0``N@,``+\$````````XP0``(@"
M``"[`````````#T```"4`P``C0(``&8%``"2`0````````X%``"!````A`,`
M`-D```!>`P```````/($```K!```G`0```````#P`0``<@4``%H!``#=`P``
M5`0``+4$``"``@``-0$``%@#```>`@``BP,``````````````@4``.<```!!
M`P``.04``'@#`````````````)X!``#/!````````"H%````````K```````
M``"W````C@(```\%```@`@``OP(``.`"``!8!0``O04``'0$``!2!```````
M`%8!``!5````'`4`````````````]0```-L#```4!```U`0``"D```"H````
M&00````````/`0``7P4``$4!``#,````.@4`````````````V@$`````````
M````N0,``&,$````````K0,```4```#\````CP,``'L#`````````````!$%
M``#M`P``J`,``)L#````````(0(``/D!``"T!````````/X%````````^@$`
M`$\"``!M`0```````.4"``#,!0```````&X"````````<P,``"\```!G`P``
MMP(``($$``!;!```<0,``$H"```3````RP4``/0"```L!````````"(#``!D
M`P``K@````````"7`0``^````&\!``!I`@``I`````````!2````=`4```X!
M````````J0(``$H$``!>!0```````)4$``!\````000``'8````=`@``E@``
M`#D#``"'!```-`,``+,#```"`0``CP```&("``#!`0````````````#/`P``
M`````(X%```C````VP(``%$"``````````````````#_`0``L@,``/H`````
M`````````"T"``"8!````````#8!``!]`0```````'(!```[!0``D0,``$P$
M``#]`0``I0(```````#C``````````0`````````10,``!L!````````\`0`
M`!8````^````%0(```````",`0``Z0$``$L!```#!0``O@4```````">!0``
MAP$``.0!````````XP(``!`!``#+`````````.(%``!L`P``_P(``$D%``"A
M`@``*04`````````````>````/8"````````'@,```````#Z`P``<0(`````
M````````(`4``.X%``!R`@``J`4``!P!``"H`@```````/H%``"G`0``P```
M`-T"```<````X0$``+$!```W`@```````&,"``!(`0``N0(``),!``#3!```
MT`4```4#``"C!````````&X`````````4P(``#8```"!`0``"@```-<$``![
M````L00``($"``"8````.@$``!$$```9!0```````#4#``!4`P``A`$`````
M``!<`@```````$8%``"K`P``50$````````&!```4P,``.("``#]`P``````
M``0#``"=`0``)`4``$4````D`P``\`(``*H#``"Z`0``$P,```````"N`@``
M```````````:!0``.`0``-,%``!'`0``F@,``-$"``"G`P``+P0``+4#````
M````:`$``'\!````````N`(``)T"``#O````>P0```````"T`@``````````
M``#.!0```P,`````````````%@,``&H"``#1!0``*P$``(4"````````\P0`
M`&````";`0``J0```,X````G`0```@````````!Y!````````$8```"R````
MX`$``.8%```?`0```````"<"````````\04``"T$```E`0``O0$``"\!```6
M!```EP4``+H"```F`P``````````````````[0```"4#```@!```U0```,P"
M``#)````7@(``!4```!)`0``[`(``.$```!4`@```````!D"``!=`P``,P(`
M`",$```]!````````.X`````````J0$``"8"``#'`@````````````"&`0``
MN`0`````````````9P4``+0%``#&!0``=@$```````!@`@``@`0`````````
M````L`0```````!L!0``?@,``'4```!*````C`4``)@#``!O`P``````````
M``"$!```-P0```L%``#V!``````````````T`@``_`,```````"Y````0P``
M`/``````````\P(``'`!```!!@``F0```!D#``#"`P``R0$``'($``",`@``
M````````````````.P0`````````````O0,```````#/!0````````H#````
M````8@$`````````````P00```````#U!```@@(``'T"```P!0``D@```*(#
M````````)P4``!,"```<`@``.0````````#7`0``0`4``$X$``"L!0``S0``
M`,T%````````S`0````````7!0``6`$``)X$```)`@``BP(``-H$````````
M`````.@!````````^0(``)@"``#C`P``W@,``(4$``!:````AP4``,0$``"9
M`0```````%L%````````I@(``.4$```"`@``200`````````````E```````
M```,````DP4```L$``#2`0``[@0``)\```#D`P``N@0``"P"``#6````.`,`
M``````!,`P``+@(``%P!````````L@$`````````````\@```*@$````````
MZP(````````A`````````&8$````````60````````#:!0``<@`````````-
M!0``Q`4``&<````A!0``O@(```L````-`P``R@(```````!@`0``QP0``(<"
M``"(`0``````````````````TP(```````"E````M`$``.8$```=`0``0P4`
M`!T%``"=`P`````````````?`@```````/<````0`@``W00```````#.`@``
MM0(``&\$``#<`````````%<$``!V!```I@,``/D```!0`@``+@4``#<!```%
M`@``B@(```@`````````<0$```````!V!0```````&4#````````GP0`````
M``"1`@``5P(``%X$``!(`@``C00``-8$````````-@4``.4%``!\!0``+0$`
M`"8!````````.`$``/,```!Z`@``+`4``/,!```8`0``=00``"`#````````
MF00``-4%``"4`@``Y@(``"X!``"D`P``<`(``&H%``!D````;0```#4%```P
M!````````"@$`````````@8``-L%``#Q`0```P(``((```!D!```%````,<%
M````````/0,```````!C````(@(``($#``!7````-P```.\!``"*`P``]@``
M`!\%````````R@$````````4`@````````````#+`0```````$<%``!?`@``
MV@(``+4%``#9!0```````%0```"O````Y@````T```!G!```0@0``*D$````
M!0``@@$``%D#``!Y````]P4``*,#```2!```UP,```H!``"A`````````+,!
M``!U`0``````````````````IP(``%P$``!E!0``:P$``%4"````````FP4`
M`*`%``#+`@````````````"7!````````.H$````````%`$``$<$````````
MQ@,``/T`````!@``JP$``,@"``!X`@``3@4``"0`````````&P```!````#(
M`0```````"H```!*!0``4@,``#L```#>!0```````!4!``!2`@```````+\`
M````````&`,``"@#````````:P4```````"O`P```````)8%``#A`P``=P$`
M`-<"``"P````#P(```````!+`P``/P$```X"``"P`0``*````&(#````````
M`````(L%````````````````````````@@4``-(#``!?`P``V0(``-\%````
M`````````(4%``")`@``=`,``*X%```I`@``"0```'X```";````)`0`````
M``!I`0```````)H`````````D0$``%T!```R!```6@4``/<!``"@`P``````
M``````!!`@``2P(``/(#```K````!P$```````!W`P``]@$``.<%```I!```
M`@,``"<`````````;P```'T```!>`0```````%L#````````<P$``',"```P
M````8@0``'<"``"5````V`0`````````````?P`````````,!0``:`(``'0!
M``"#````,`$```````!%!0``L04``/X!````````1`4``#(#````````*@0`
M``````#4`@``P@(``*L%````````L@0``-8"``#<`@``&@0``(X!``"C`@``
M.P(``#D!``!L`0``X@,````````9`0```````*($``#8`0```````"D!``#"
M!```]`,```````#4!0``90(`````````````+04```\`````````V`4``-`$
M``#[````N`4``+$#```]!0```````(8%``"R`@``:```````````````J@4`
M`(,#``#0`0``M````'D!`````@```````,H#``"[`P``-`0``+4````A`0``
M@````%,```#O`P`````````````&````C0,``*P!``#P`P``Y`(``*@!````
M`````````+<#```T````>`0``````````````````%X`````````B04``,0`
M```<!```1P```'0```!2`0``^`(```````!5!```P04``&\%``"S````````
M`*P"``#H!0``A@,``%\$````````-@0``"(!``!Z!0``40,``-@"``#T!```
M``````````!0`0```P8``#`"````````R0(``"P!```;!``````````````0
M`P```````!H!``#%!0``Z@(``!L%``!9`@````````````"4`0``R````$4"
M```,`P``?00``&D%``#>`@````````````")!```T@0``.L%```0!0``````
M`)$`````````!`(``.T$``"6`P``:@,``.,%````````N@4``#`#``!0````
M`````',```#>!```.P,``$@```!#!```^`$``/0!```O`P``M@````````!.
M`````````*`$``![`@```0,``````````````````*4$```(`P```````.L`
M````````S0(``"H"``"W`0``>@0``*<%````````[@$``,4#````("`M32P@
M+2UM97-S86=E/4U%4U-!1T4@(%5S92!T:&ES(&-O;6UI="!M97-S86=E(&EN
M<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE<RX`("`M82P@+2UA9&0]1DE,12`@
M("`@("`@061D('1H:7,@4$\@9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E
M9G5L('1O"B`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP
M96YD:75M(&9R;VT@82!D:69F97)E;G0@8G)A;F-H('1O"B`@("`@("`@("`@
M("`@("`@("`@("`@('1H92!G96YE<F%T960@8V]M<&5N9&EU;2X`("`M8BP@
M+2UB87-E/2]0051(("!&=6QL('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D
M:7)E8W1O<GD@=&AA="!S:&]U;&0@8F4*("`@("`@("`@("`@("`@("`@("!U
M<V5D+@`@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@365R9V4@;F5W('1R86YS
M;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@9FEL90H@("`@("`@("`@("`@
M("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E
M;F1I=6TN<&\@:6X@=&AE"B`@("`@("`@("`@("`@("`@("`@("`@("!H;W)D
M92]P;R!D:7)E8W1O<GDN`"`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5<V4@
M=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L=`H@
M("`@("`@("`@("`@("`@("`@("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN
M('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+@`@("UD+"`M+61E8G5G("`@("`@
M(%-H;W<@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I
M97,N`"`@+60L("TM9&ER96-T;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M
M(&EN('1H:7,@9&ER96-T;W)Y+@`@("UH+"`M+6AE;'`@("`@("`@(%-H;W<@
M=&AI<R!H96QP(&UE<W-A9V4N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5
M<V4@;VYL>2!T:&ES(&QO8V%L92X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@
M(%5S92!T:&ES(&QO8V%L92X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-E
M('1H:7,@;&]C86QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@
M34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@
M+2UM;V1U;&4]34]$54Q%("`@($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($-O;6UI="!T<F%N<VQA=&EO;G,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO
M9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-R96%T92!A(%!/(&9I
M;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U
M;&4]34]$54Q%("`@($UE<F=E(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO
M<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@
M:&5L<"!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I
M(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@
M9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UN+"`M+6YO
M+6-O;7!E;F1I=6T@("`@1&]N)W0@;65R9V4@;F5W('1R86YS;&%T:6]N<R!T
M;R!T:&4@8V]M<&5N9&EU;2X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O
M;B=T('5S92!A(&-O;7!E;F1I=6TN`"`@+70L("TM=&5S="`@("`@("`@4VAO
M=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U;B!A;GET:&EN
M9RX`("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P(&9R;VT@
M=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+@`@(&-O;6UI="`@
M("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V97(N`"`@
M8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE($-64R!S97)V
M97(N`"`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU;2!F:6QE
M+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE"B`@("`@("`@("`@("`@
M8W5R<F5N="!C;VUP96YD:75M+@`@(&5X=')A8W0@("`@($=E;F5R871E(%!/
M('1E;7!L871E("@N<&]T*2!F:6QE<RX`("!H96QP("`@("`@("!3:&]W('1H
M:7,@:&5L<"!M97-S86=E+@`@(&EN:70@("`@("`@($-R96%T92!O;F4@;W(@
M;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG.B!4:&ES
M"B`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@9FEL
M97,@;V8@=&AI<R!L;V-A;&4N`"`@;6%K92`@("`@("`@0G5I;&0@8FEN87)Y
M($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!03R!F:6QE<RX`("!M97)G
M92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F:6QE('=I=&@@=&AE(&-U
M<G)E;G0@4$\@=&5M<&QA=&4@9FEL92X`("!U<&1A=&4@("`@("!2=6X@97AT
M<F%C="!A;F0@;65R9V4@<V5Q=65N="X`("!U<&1A=&4M:&5L<"!%>'1R86-T
M(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H
M(%A-3"!H96QP"B`@("`@("`@("`@("`@9FEL92!A;F0@;65R9V4@=&AE;2!W
M:71H('1H92!E>&ES=&EN9R!O;F5S+@`@)B,Q-3$[("5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H4F5A9"!O
M;FQY*0`@*'1O9&%Y*0`@*'EE<W1E<F1A>2D`(&%N9"``(&%T(``E9"!B>71E
M<R!W<FET=&5N+@`E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD
M871E`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!#;VYF:6=U<F%T
M:6]N`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!3=&%N9&%R9``E
M<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T
M("5S("5S`"5S(&%T("5S(&9T`"5S(&AA<R!C86YC96QL960@)7,N`"5S(&AA
M<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L
M:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N="!Y;W4@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU
M=&5S`"5S(&YO="!F;W5N9"X`)7,@;F]T(&9O=6YD+B!2=6X@)W1R86YS;&%T
M:6]N(&5X=')A8W0G(&9I<G-T+@`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S
M>2!I;F9O<FUA=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E
M<RX`)7,@=&\@)7,@;V8@)7,`)7,@=VES:&5S('1O(&%D9"!T;R`E<RX`)7,@
M=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E<R!W:7-H97,@=&\@
M<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+@`E<SH@
M)7,`)R5S)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"<E<R<@:7,@;F]T(&-O
M;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`G)7,G('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`)R5S)R!W87,@861D960@=&\@=&AE
M('!E<FUI<W-I;VYS('-Y<W1E;2X`)R5S)R!W87,@;F]T(&-R96%T960Z("5S
M+@`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM
M('-E;&5C="`M+0`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T`,38M8FET
M(&1E<'1H(&YO="!S=7!P;W)T960Z("5S`#(T(&AO=7)S`$$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960`02!N97<@<VEG;G5P(&AA<R!B965N(')E8V5I
M=F5D(&%N9"!I<R!A=V%I=&EN9R!Y;W5R(&%P<')O=F%L+@!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06-C
M97!T(')E<75E<W0`06-C97!T960`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+@!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@
M)7,`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(
M97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C
M:&EL9"!G<F]U<"!T;R`G)7,G`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@
M)R5S)P!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M96UB97)S`$%D9"!P86ER
M`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&AI
M<R!T;R!M>2!C86QE;F1A<@!!9&0@=&\@;7D@861D<F5S<R!B;V]K.@!!9&0@
M=7-E<@!!9&1E9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@
M)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN
M9R!N97<@9FEL97,@=&\@<F5P;W-I=&]R>3H`061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!
M9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L;"!!=71H
M96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L
M;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;'!H82!C:&%N;F5L(&YO="!S=7!P
M;W)T960Z("5S`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN
M`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N
M86UE`$%L=&5R;F%T92!T96UP;&%T97,`06UE<FEC86X@4V%M;V$`06X@97)R
M;W(@;V-C=7)R960@9F]L;&]W:6YG('1H:7,@;&EN:SH@)7,`06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL
M80!!;F]N>6UO=7,@4')O>'D`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B
M=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T
M;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M
M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A
M;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N
M("A!4DU30TE)+3@I`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-I82]086-I
M9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T86-H960@:7,@86X@:4-A;&5N
M9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S96YT`$%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E;F1E97,`071T<FEB=71E<P!!
M=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N
M9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B
M-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E
M<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H
M7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL
M960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I
M;&%B;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!!>F5R8F%I:F%N`$)A
M8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R
M8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX
M.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<F)I90!"96QA<G5S`$)E
M;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L
M;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQO8VL@<V5L96-T:6]N`$)L=64@
M86YD(%=H:71E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]S;FEA(&%N9"!(
M97)Z96=O=FEN80!";W1S=V%N80!";W5V970@27-L86YD`$)R87II;`!"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)O=VX`0G)U;F5I($1A<G5S
M<V%L86T`0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!"=6EL
M9&EN9R!L;V-A;&4@)7,N+BX@`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R
M:VEN82!&87-O`$)U<FYT($]R86YG90!"=7)U;F1I`$--4P!#4D,`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE
M<F]O;@!#86UO=69L86=E`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO
M="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B
M)7,B+@!#86YN;W0@<F5M;W9E.R!C:&EL9')E;B!E>&ES="`H)7,I`$-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A
M>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@4&]L
M:6-I97,`0VAA9`!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG92!Y;W5R('!A
M<W-W;W)D`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#
M:&]O<V4@86X@86-T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N`$-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`
M0VQE86YI;F<@=7`@;&]C86QE("5S+BXN(`!#;&EC:R!T;R!#;VYT:6YU90!#
M;&EE;G0`0VQI96YT(%1I8VME=`!#;&]S92!7:6YD;W<`0VQO=61S`$-O8V]S
M("A+965L:6YG*2!)<VQA;F1S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UA;F0@;W!T:6]N
M<SH`0V]M;6%N9',Z`$-O;6UE;G0`0V]M;6ET=&EN9SH`0V]M;6]N($YA;64`
M0V]M;W)O<P!#;VUP86YY`$-O;7!L971E9`!#;VYD:71I;VYS`$-O;F9I9W5R
M871I;VX`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9FER;2!N
M97<@<&%S<W=O<F0Z`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S
M*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT96YT<R!O
M9B`G)7,G`$-O;VL@27-L86YD<P!#;W!Y('-E;&5C=&EO;@!#;W!Y:6YG("5S
M('1O("5S`$-O<FYF;&]W97(`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V
M97(`0V]U;&0@;F]T(&-A;&P@9G5N8W1I;VX@)7,@:6X@87!P;&EC871I;VX@
M)7,N`$-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,`0V]U;&0@
M;F]T(&-O<'D@)7,@=&\@)7,`0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER
M96-T;W)Y(&9O<B!L;V-A;&4@)7,Z`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D
M871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@!#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U
M;&0@;F]T(&EN8VQU9&4@9F]N="!D969I;FET:6]N(&9I;&4N`$-O=6QD(&YO
M="!I;F-L=61E(&9O;G0@;65T<FEC(&9I;&4Z("5S`$-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O
M<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#;W5L9"!N;W0@;W!E;B!P:7!E('1O('-M8G!A<W-W9"X`0V]U;&0@
M;F]T(')E860@)7,N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T
M(')E=')I979E($%#3"X@4U-,(&-O;FYE8W1I;VYS(')E<75I<F4@4$A0(#0N
M,R!O<B!B971T97(`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B
M:6QI=&EE<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET
M:65S+B!34TP@8V]N;F5C=&EO;G,@<F5Q=6ER92!02%`@-"XS(&]R(&)E='1E
M<@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`0V]U;&0@;F]T
M('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B`G)7,G.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#
M;W5L9&XG="!G:79E('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B`G)7,G.B`E<P!#;W5N=')Y`$-R96%T90!#<F5A=&4@
M<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N
M=6UB97(`0W)O871I80!#<F]S<R!2969E<F5N8V4`0W5B80!#=7)R96YT(%!H
M87-E`$-U<G)E;G0@5&EM90!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD
M:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y
M<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$86EL
M>0!$871A`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`
M1&5C96UB97(`1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@261E
M;G1I='D`1&5F875L="!097)M:7-S:6]N<P!$969A=6QT('!E<FUI<W-I;VYS
M`$1E;&5G871E9`!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S
M:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`G)7,G`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A;F0@
M86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E('1H:7,@;&EN:P!$96QE=&4@
M=&AI<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N`$1E;&EV97)Y('1I;64`
M1&5N;6%R:P!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U
M<WD@:6YF;W)M871I;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I
M;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E
M;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$
M97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@
M<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES8W5S<VEO;G,`1&ES<&QA>2`R
M-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)M870`
M1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN
M:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!$<F]P(&1O=VX@;&ES=`!%+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET
M($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES
M<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O
M<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!P97)M:7-S:6]N<R!F
M;W(@)R5S)P!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%;6%I;"!!9&1R97-S
M`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I
M<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT
M+@!%;F0`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT<FEE<SH@)60@=&]T
M86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK
M;F]W;@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-L
M;W-I;F<@<&EP92!T;R!S;6)P87-S=V0`17)R;W(@<V5N9&EN9R!D871A('1O
M('-M8G!A<W-W9"X`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R.B``
M17-T;VYI80!%=&AI;W!I80!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C
M=71E`$5X96-U=&EN9SH`17AP86YD`$5X<&ER871I;VX@1&%T90!%>'!O;F5N
M=`!%>'1R86-T:6YG(&9R;VT@)7,N+BX@`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C
M;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;'5R92!I;B!C:&%N
M9VEN9R!P87-S=V]R9"`Z(`!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`
M1F%R;V4@27-L86YD<P!&871A;"!%<G)O<B$`1F%X`$9E8G)U87)Y`$9E96QS
M($QI:V4`1F5E;',@;&EK93H@`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I
M;&4@3F]T($9O=6YD`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R
M=&5R`$9I>"!R871I;P!&;&EP`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&
M;VQL;W<@=7`@=&%S:P!&;VYT($-O;&]R`$9O;G0@86QR96%D>2!A9&1E9#H@
M)7,@)7,`1F]N="!F:6QE(&YO="!F;W5N9"X`1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@
M:6X@82!W:61E(&)L;V-K*0!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&
M;W)T=6YE<P!&;W)U;7,`1F]R=V%R9',`1F]U;F0@87!P;&EC871I;VYS.B`E
M<P!&;W5N9"!D:7)E8W1O<FEE<SH`1G(`1G)A;F-E`$9R964O0G5S>2!);F9O
M<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`1G)E
M92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&<F5N8V@@
M4&]L>6YE<VEA`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L
M;"!-;V]N`$9U;&P@3F%M90!&=7IZ>0!'86)O;@!'86UB:6$`1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T:6YG('-T871U<R!F;W(@;6]D=6QE
M("5S+BXN`$=E;W)G:6$`1V5R;6%N>0!'971O<'0@17)R;W(Z(`!':&%N80!'
M:6)R86QT87(`1VEV96X@3F%M90!';P!';V]G;&4@4V5A<F-H`$=R87ES8V%L
M90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N`$=R965N;&%N9`!'
M<F5N861A`$=R97D`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R;6ES<VEO;G,`1W)O=7!S`$=U
M861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES
M<VEO;G,`1W5E<W0@4V5R=FEC97,`1W5E<W0@<&5R;6ES<VEO;G,`1W5E<W1B
M;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(2`!(5$U,`$A45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H
M;0!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE
M8G)E=R`H25-/+3@X-3DM."U)*0!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;'!E<@!(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I
M;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D90IF<F%M97=O<FL@86YD(&ET
M<R!A<'!L:6-A=&EO;G,N"D9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@
M9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O<GDN`$AE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93H`2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>0!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(
M;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92!!9&UI;FES=')A=&EO;@!(;W)D92!#;VYF:6=U<F%T
M:6]N`$AO<F1E('1R86YS;&%T:6]N(&=E;F5R871O<@!(;W)I>F]N=&%L(%)U
M;&4`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AU;6ED
M:71Y`$AU;6ED:71Y.B``2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R
M97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO
M=V5D($-)1%(@8FQO8VLN`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H
M('1E>'0`26UA9V4@9FEL92!H87,@;F\@97AT96YS:6]N(&%N9"!N;R!T>7!E
M('=A<R!S<&5C:69I960Z("5S`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T
M($5R<F]R.B!%>'!E8W1E9"`B0D5'24XB(&]N(&QI;F4@)60N`$EM<&]R="!%
M<G)O<CH@17AP96-T:6YG($)%1TE.(&]N(&QI;F4@)60N`$EM<&]R="!%<G)O
M<CH@36%L9F]R;65D(&QI;F4N`$EM<&]R="!%<G)O<CH@36ES;6%T8V@[(&5X
M<&5C=&EN9R!%3D0Z)7,@;VX@;&EN92`E9`!);7!O<G0@17)R;W(Z(%1Y<&4@
M;6ES;6%T8V@N($5X<&5C=&5D(")%3D0Z)7,B(&]N(&QI;F4@)60N`$EM<&]R
M="!%<G)O<CH@56YE>'!E8W1E9"!E;F0@;V8@9FEL92X`26UP;W)T+"!3=&5P
M("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R
M;V-E<W,`26YC;W)R96-T(%!.1R!F:6QE.B`E<P!);F-O<G)E8W0@86-T:6]N
M(&-O9&4@9VEV96XN`$EN8V]R<F5C="!L87EO=70@9&ES<&QA>2!M;V1E.B`E
M<P!);F-O<G)E8W0@;W)I96YT871I;VXZ("5S`$EN8V]R<F5C="!U;FET<SH@
M)7,`26YC;W)R96-T('IO;VT@9&ES<&QA>2!M;V1E.B`E<P!);F-R96%S92!)
M;F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!)
M;F9O<FUA=&EO;@!);FET:6%L:7II;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@
M5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4`26YS97)T(&UE<W-A9V5S`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T
M+TUO9&EF>2!,:6YK`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=&5R;F%L($5R
M<F]R`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N
M="X`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A
M<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U
M8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED
M(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!)
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!)
M;G9A;&ED(')E=FES:6]N(&YU;6)E<@!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-R865L`$ES<W5E<@!)
M=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>2!#
M96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT
M`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y
M($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VER
M:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`
M2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER
M9WEZ<W1A;@!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8P!,87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,871V:6$`3&%V96YD97(`3&%Y;W5T`$QE8F%N;VX`3&5S;W1H
M;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I
M;@!,:6=H="!";'5E`$QI;FL`3&EN:W,`3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R`$QI<W0@2&5L<"!4;W!I8W,`3&ES="U!<F-H:79E`$QI<W0M
M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R
M:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9R!L:6)R87)I97,N+BX`
M3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`
M3&]G(&EN('1O("5S`$QO9R!O=70`3&]G(&]U="!O9B`E<P!,;V=I;@!,;V=I
M;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A
M<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO9V]U=`!,
M=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%I;`!-86EL("8@3F5W
M<P!-86EL($%D;6EN`$UA:V4@<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS
M=&%L;&5D(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"X`36%K:6YG(&1I<F5C
M=&]R>2`E<P!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-
M87)C:`!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T
M:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@
M27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA
M`$UA=7)I=&EU<P!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA
M>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UD865M;VX@<&%T:"!N;W0@9F]U
M;F0`361A96UO;B!U<V5R;&ES="!F:6QE(&YO="!A8V-E<W-A8FQE(&]R(&YO
M="!F;W5N9"X`365E=&EN9R!#86YC96QL871I;VX`365E=&EN9R!);F9O<FUA
M=&EO;@!-965T:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P;'D`365E=&EN9R!5
M<&1A=&4`365E=&EN9R!5<&1A=&4@4F5Q=65S=`!-96UB97)S`$UE;G4@;6]D
M93H`365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN
M+BX@`$UE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD
M:75M+BXN(`!-97)G:6YG('1R86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BX`
M365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`
M365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T
M:&]D`$UE=&AO9"`G)7,G(&ES(&YO="!D969I;F5D`$UE=')I8P!-97AI8V\`
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:6UE(%1Y<&4`36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UI<G)O<@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(&]R(&EN8V]R<F5C
M="!I;6%G92!F:6QE.B`E<P!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL
M92!-86EL`$UO9&EF:65D($1A=&4`36]D=6QE`$UO9'5L=7,`36]L9&]V82P@
M4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO
M;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO=F4@1&]W
M;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E
M('5P`$UO>F%M8FEQ=64`36]Z:6QL80!-=6QT:7!L92!S96QE8W1I;VX`37D@
M06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/
M+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F585`!.965D
M<R!!8W1I;VX`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL
M97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE
M`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($UO
M;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A
M<W-W;W)D.@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5X=`!.97AT(%!A
M9V4`3F5X="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT
M`$YI=64`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BX`3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D
M(&)E;&]W('1H:7,@;&5V96PN`$YO(&-O;6UA;F0@<W!E8VEF:65D+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"!A=71H96YT:6-A=&EO;BX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@
M9&5S8W)I<'1I;VX@9F]U;F0`3F\@96YT<GD@=VET:"!T:&4@:60@)R5S)R!E
M>&ES=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92X`3F\@9FEL92!U<&QO
M861E9`!.;R!L;V-A;&4@<W!E8VEF:65D+@!.;R!L;V-A=&EO;B!I<R!S970N
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3$1!4"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P96YD:6YG('-I9VYU<',N`$YO(')E=FES:6]N
M<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N
M`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N(%!A
M<G1I8VEP86YT`$YO;F4`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)
M<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES
M;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!);7!L96UE
M;G1E9`!.;W0@82!*4$5'(&9I;&4Z("5S`$YO="!A(%!.1R!F:6QE.B`E<P!.
M;W0@82!D:7)E8W1O<GD`3F]T(&%B;&4@=&\@8W)E871E(&QO8VL@9FEL90!.
M;W0@86)L92!T;R!C<F5A=&4@<V5M87!H;W)E(&9I;&4`3F]T(&%B;&4@=&\@
M<F5T<FEE=F4@8W5R<F5N="!D971A:6QS+@!.;W0@<W5P<&]R=&5D+@!.;W1E
M.B!9;W4@=VEL;"!N965D('1O(&QO9V]U="!A;F0@8F%C:R!I;B!A9G1E<B!Y
M;W4@8VAA;F=E('EO=7(@<&%S<W=O<F0A`$YO=&5S`$YO=&EC90!.;W9E;6)E
M<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M
M;G,`3G5M8F5R(&]F(')O=W,`3TL`3V)J96-T($-R96%T;W(`3V)J96-T(&-R
M96%T;W(@<&5R;6ES<VEO;G,`3V-T86P`3V-T;V)E<@!/9F8`3V9F:6-E`$]L
M9"!P87-S=V]R9#H`3VUA;@!/;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+@!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A
M('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P=&EO;F%L(%!A<G1I8VEP
M86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W!T:6]N<SH`3W)D97)E9"!,
M:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(@17)R
M;W(`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!0
M1U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#
M;V1E`%!(4"!3:&5L;`!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G
M=6%Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960A`%!A<W-W;W)D(&UO9'5L
M92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9`!087-S=V]R9"!M;V1U;&4@
M:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960@340U`%!A<W-W;W)D(&UO9'5L
M92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"$`4&%S<W=O<F0@;6]D=6QE
M(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+@!087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S
M="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD
M:6YG(%-I9VYU<',Z`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI
M<W-I;VX`4&5R;6ES<VEO;B`G)7,G(&YO="!D96QE=&5D+@!097)M:7-S:6]N
M($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;@!097)M:7-S:6]N<R!F;W(`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&QE87-E(&5N=&5R
M(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T
M92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM
M87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N
M86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE
M('-Y<W1E;2X`4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S
M+FAO<F1E+F]R9RX`4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R
M;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE
M;G4@8F5L;W<N`%!L96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE
M;G4@8F5L;W<N`%!O;&%N9`!0;VQL<P!0;W)T=6=A;`!0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4&]S=&YU:V4`4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-E
M;G1A=&EO;G,`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E
M<W-U<F4Z(`!0<F5V:65W`%!R979I;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N
M<P!0<F5V:6]U<R!T87-K`%!R:79A=&4@2V5Y`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4')O8FQE;3\`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0
M=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!2
M4T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%T:6\`
M4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;6%R:W,`4F5M96UB
M97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M;W1E(%-E<G9E<G,`
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E
M;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&9R;VT@;7D@8V%L96YD87(`4F5M
M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297!L>2!396YT+@!297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G
M90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P
M;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L
M>3H@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B``4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN("5S
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T
M('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC
M871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@
M<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T
M:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=T86)L92<@;F]T('-P96-I
M9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@4&%R=&EC:7!A;G0`4F5S970`4F5S
M=6QT<P!297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.@!297-U;'1S.@!2971U
M<FX@=&\@3W!T:6]N<P!2975N:6]N`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P
M`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2=6X`4G5S<VEA;B!&961E<F%T
M:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@475E<GD`4U%,(%-H
M96QL`%-3`%-32`!354-#15-3`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T
M<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U
M96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R
M86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I
M;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A
M=F4@)7,`4V%V92`G)7,G`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN
M`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G+@!396%R8V@`
M4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<RXN+@!396%R8VAI;F<@9V5T
M=&5X="!B:6YA<FEE<RXN+@!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P
M('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E
M;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD($QA=&5S="!);F9O<FUA
M=&EO;@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F5G86P`4V5N<V]R.B``4V5P
M=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E
M<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I
M;VYS+@!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H
M;W<`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M('!I8VME<@!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:')I;FL`
M4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E
M9`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ
M90!3:VEP($UA:6YT96YA;F-E`%-K:7!P960N+BX`4VQO=F%K:6$`4VQO=F5N
M:6$`4VYO=R!D97!T:#H@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;64@
M;V8@4&%S<W=O<F0@;6]D=6QE)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@
M;6ES<VEN9SH`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`
M4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T
M:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T
M:&5R;B!(96UI<W!H97)E`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W)I($QA;FMA`%-T86YD87)D`%-T87)T`%-T87)T('EE87(`4W1A
M=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T871U<R!F;W(@;&]C86QE("5S+BXN
M(`!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H
M`%-T<FEN9R!L:7-T`%-U`%-U8FIE8W0`4W5B:F5C="!0=6)L:6,@2V5Y($EN
M9F\`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E
M9"`G)7,G('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("<E
M<R<N`%-U8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M
M+@!3=6-C97-S9G5L;'D@=7!D871E9"`G)7,G`%-U8V-E<W-F=6QL>2!W<F]T
M92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N<FES90!3
M=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R
M<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@
M2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WER:6%N
M($%R86(@4F5P=6)L:6,`5%-6(&9I;&4`5&%I=V%N`%1A:7=A;BP@4')O=FEN
M8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F`%1A<F=E=#H`5&%S:P!487-K<P!496%L`%1E;&5P:&]N92!.=6UB
M97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U
M<F4Z(`!496UP;&%T92`G)7,G(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI
M<W1R871I;VX`5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0`5&5N=&%T:79E
M;'D@06-C97!T960`5&5X=`!497AT($]N;'D`5&@`5&AA:2`H5$E3+38R,"D`
M5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@
M)7,@:&5L<"!F:6QE(&9O<B`E<R!D;V5S;B=T('EE="!E>&ES="X@0W)E871I
M;F<@82!N97<@;VYE+@!4:&4@)7,@;&EN:R!T;R`E<R!H87,@8F5E;B!R96UO
M=F5D+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@
M8V%L96YD87(@9&%T82!I<R!I;G9A;&ED`%1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E=F5N="!H87,@8F5E;B!A9&1E
M9"!T;R!Y;W5R(&-A;&5N9&%R+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O
M;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+@!4:&4@:&5L<"!F:6QE("5S(&1I9&XG="!S=&%R
M="!W:71H(#P_>&UL`%1H92!L:6YK(&AA<R!B965N(')E;6]V960`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M971H;V0@)7,@:7,@;F]T(&1E
M9FEN960@:6X@=&AE($%022!F;W(@)7,N`%1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I
M>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E
M<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O
M<F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!D;V5S;B=T('EE="!E>&ES="!A
M(&AE;'`@9FEL92!F;W(@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG
M("<E<R<@=&\@=&AE('-Y<W1E;2X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG("<E<R<@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A
M<R!A('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ
M92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D
M+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@
M<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT
M.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@
M)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T
M:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A
M(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T
M:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@
M=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H
M92!X;6P@<&%R<V5R+@!4:&5R92!W87,@86X@=6YK;F]W;B!E<G)O<B!V97)I
M9GEI;F<@=&AI<R!M97-S86=E+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&%C=&EO;B!I<R!N;W0@
M<W5P<&]R=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D
M+@!4:&ES(&-O;G1A8W0@9&%T82!H87,@8F5E;B!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN($-L:6-K(&)E;&]W('1O('9I97<Z
M`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I
M;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@=&AE(&UA
M:6X@4&%S<W=O<F0@;6]D=6QE(&-O;F9I9W5R871I;VX@9FEL92X@270@8V]N
M=&%I;G,@<&%T:',@86YD(&]P=&EO;G,@9F]R(&%L;"!087-S=V]R9"!M;V1U
M;&4@<V-R:7!T<RX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN
M92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@
M9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`
M5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T
M(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1I;64`5&EM92!4
M<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T
M90!4:71L90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE
M(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME
M;&%U`%1O;6]R<F]W`%1O;F=A`%1R86YS;&%T960`5')I;FED860@86YD(%1O
M8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@
M*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``
M55),`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@861D(&UE<W-A9V4@9G)O
M;2`E<R!T;R!M86EL8F]X("5S.B``56YA8FQE('1O(&%N;F]T871E.R!S97)V
M97(@<V%I9#H@)7,`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@;6%I;&)O>"`E<SH@`%5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I
M9FEC871E(&1E=&%I;',`56YA8FQE('1O(&9I;F0@9&ER96-T;W)Y`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N`%5N86)L92!T;R!O<&5N(&EM86=E(&9I;&4Z("5S`%5N86)L92!T;R!O
M<&5N(&UA:6QB;W@@)7,Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B!U<V5R("5S(&]N
M('-E<G9E<B`E<P!5;F%B;&4@=&\@<V%V92!01$8@9FEL93H@)7,`56YA8FQE
M('1O('-E;F0@4$1&(&9I;&4L('-O;64@9&%T82!H87,@86QR96%D>2!B965N
M(&]U='!U="!T;R!B<F]W<V5R+@!5;F%B;&4@=&\@<W1O<F4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(&9O<B!U<V5R("5S(&]N('-E<G9E<B`E<P!5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A
M8W1I;VX`56YE>'!E8W1E9"!O=71P=70@9G)O;2!#:&5C:V]U=#H@)7,`56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N:&%N9&QE
M9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N
M:VYO=VX`56YK;F]W;B!C;VUM86YD.B`E<P!5;FMN;W=N(&-O;7!R97-S:6]N
M(&UE=&AO9#H@)7,`56YK;F]W;B!F:6QT97(@;65T:&]D.B`E<P!5;FMN;W=N
M('!A9V4@9F]R;6%T.B`E<P!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`56YS=7!P;W)T960@:6UA9V4@9FEL
M92!T>7!E.B`E<P!5;G1R86YS;&%T960`57!D871E`%5P9&%T92`E<P!5<&1A
M=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`G)7,G
M+@!5<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R("5S+@!5<&=R861E('-C<FEP
M="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E
M='5P(&9I;&5S('1O('1H92!S97)V97(N`%5R=6=U87D`57-A9V4Z`%5S92!$
M969A=6QT(%9A;'5E`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+@!5<V5R("5S0"5S(&YO="!F;W5N9`!5<V5R($%D;6EN:7-T<F%T:6]N`%5S
M97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO
M;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R('!E<FUI
M<W-I;VYS`%5S97)N86UE`%5S97)N86UE("<E<R<@86QR96%D>2!E>&ES=',N
M`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S`%5S97)S(&EN('1H92!S>7-T
M96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%N=6%T
M=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I
M;VX`5F5R<VEO;B!#;VYT<F]L`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)
M22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@
M)7,`5FEE=R!E=F5N=`!6:65W('1A<VL`5FER9VEN($ES;&%N9',L($)R:71I
M<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y
M.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%L;&ES(&%N9"!&=71U
M;F$`5V%R;FEN9P!787)N:6YG.B``5V4`5V5A=&AE<B!&;W)E8V%S=`!796(`
M5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ
M-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:6YD('-P
M965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-H;&ES=',`5V]R:R!!9&1R
M97-S`%=O<FL@4&AO;F4`5W)I=&EN9R!N;W0@<&]S<VEB;&4N(%EO=2!C86X@
M96ET:&5R('5S92!T:&4@879A:6QA8FQE('5P9W)A9&4@<V-R:7!T(&]R(&-O
M<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`%=R:71I;F<@=7!D
M871E9"!H96QP(&9I;&4@=&\@)7,N`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E9
M65D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S+"!)($%G<F5E`%EO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@8V%N(&%P<')O=F4@=&AI<R!S:6=N
M=7`@870@)7,`66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E
M<P!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO
M=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL
M92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E
M(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V
M86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T
M;R!U<V4@2&]R9&4N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\`66]U(&UU<W0@9VEV92!Y;W5R(&YE=R!P87-S=V]R9`!9;W4@;75S
M="!G:79E('EO=7(@;VQD('!A<W-W;W)D`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`
M66]U(&UU<W0@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M
M86EL($%D9')E<W,`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N
M("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!G
M971T97AT('9E<G-I;VX@:7,@=&]O(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R
M="!02%`@;F%T:79E;'DN"DYO="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A
M8W1E9"X`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO;F<[('!A<W-W;W)D
M<R!M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T97)S(&QO;F<A`%EO
M=7(@;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,A("!.;W0@
M8VAA;F=E9"$`66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!A="!L96%S="`E
M9"!C:&%R86-T97)S(&QO;F<A`%EO=7(@;F5W('!A<W-W;W)D<R!D:61N)W0@
M;6%T8V@`66]U<B!O;&0@<&%S<W=O<F0@:7-N)W0@8V]R<F5C=`!9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z
M`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%M0<F]B;&5M(%)E
M<&]R=%T`6VQI;F4@)7,@;V8@)7-=`&%N(&5R<F]R(&AA<R!O8V-U<F5D.@!D
M87D`9&%Y<P!D;VYE`&9A:6QE9`!F:6QE`&9O=6YD.B``9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<P!H.@!H;W5R`&AO=7)S`&DQ.&X`:6UM961I871E`&UI
M;G5T90!M:6YU=&5S`&UO;G1H`&UO;G1H<P!N86UE`&YO="!C:&%N9V5D`&YO
M="!F;W5N9`!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!S
M96-O;F0`<V5C;VYD<P!T96UP;F%M*"D@9F%I;&5D(0!T:&4@2&]R9&4@4$\@
M9FEL92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FYA;65D`'5P9&%T960`
M=7-E<B!S96QE8W0`=D-A<F0`=F5R>2!L:71T;&4@=&EM90!W.@!W96%T:&5R
M+F-O;0!W965K`'=E96MS`'EE87(`>65A<G,`4')O:F5C="U)9"U697)S:6]N
M.B!P87-S=V0*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#(M,3(M,#4@,C(Z-38K
M,#@P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3$R+3$R(#$R.C(S*S`X,#`*
M3&%S="U4<F%N<VQA=&]R.B!796YZ:'5O(%IH86YG(#QW96YZ:'5O0'IH;6%I
M;"YC;VT^"DQA;F=U86=E+51E86TZ(%-I;7!L:69I960@0VAI;F5S92`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U'0C(S,3(*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`H`("`M32P@+2UM97-S86=E/4U%4U-!1T4@
M(,JYT\/5XKCVS.&]N]#%SZ+2T<SFM/K4I,GHT,7/HBX`("`M82P@+2UA9&0]
M1DE,12`@("`@("`@T,+4]K3+(%!/(,[$O/ZUO=6JTJK6T"X@LZ/3P]/:O:NR
MN\VLL.:QOK7$U:K2JK#\NJP*("`@("`@("`@("`@("`@("`@("`@("`@M;W2
MU++ZR?JUQ-6JTJK6T"X`("`M8BP@+2UB87-E/2]0051(("!(;W)D92"UQ,BK
MPK>^MBX`("`M8RP@+2UC;VUP96YD:75M/49)3$4@(+K/LJ+0PK7$MZW2Z[6]
MM,O.Q+S^UM#2U+3ZS.;4I,GH"B`@("`@("`@("`@("`@("`@("`@("`@(""U
MQ-6JTJK.Q+S^*-3:Q+_"O"!H;W)D92]P;R#6T+7$(&-O;7!E;F1I=6TN<&\I
M+@`@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@RKG3P[3+SL2\_M+4M/K,YM2D
MR>C5JM*JSL2\_@H@("`@("`@("`@("`@("`@("`@("`@("`@*-3:Q+_"O"!H
M;W)D92]P;R#6T+7$(&-O;7!E;F1I=6TN<&\I+@`@+60L("TM9&5B=6<@("`@
M("`@S]3*OM:TT-"Y_;/,UM"UQ+3MSO/0Q<^B+@`@("UD+"`M+61I<F5C=&]R
M>3U$25(@("#4VK3+Q+_"O-;0O:C!HM6JTJHN`"`M:"P@+2UH96QP("`@("`@
M("#/U,J^R[7#]]#%SZ(N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("#6N\JY
MT\.TR[6QM=C3[]'4+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@RKG3P[3+
MM;&UV-/OT=0N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@(,JYT\.TR[6QM=C3
M[]'4+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@UKN]J,&BM,O$H[_I*$AO
M<F1E*;7$($U/(,[$O/XN`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("#6N\?E
ML_VTR\2CO^DH2&]R9&4IM<0@4$\@SL2\_BX`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@(-:[S.&]N[3+Q*._Z2A(;W)D92FUQ+>MTNO.Q+S^+@`@("UM+"`M
M+6UO9'5L93U-3T153$4@("#6N[VHP:*TR\2CO^DH2&]R9&4IM<0@4$\@SL2\
M_BX`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(-:[NL^RHK3+Q*._Z2A(;W)D
M92FUQ+>MTNO.Q+S^+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@UKNX_-#"
MM,O$H[_I*$AO<F1E*;7$R[7#]\[$O/XN`"`@+6TL("TM;6]D=6QE/4U/1%5,
M12`@("#6N[C\T,*TR\2CO^DH2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-3T15
M3$4@(-:[LOK)^K3+Q*._Z2A(;W)D92FUQ"!03U0@SL2\_BX`("`M;BP@+2UN
M;RUC;VUP96YD:75M("`@(+*[TJJZS[*BT,*UQ+>MTNNUO=6JTJK6T"X`("`M
M;BP@+2UN;RUC;VUP96YD:75M("`@(+*[RKG3P]6JTJHN`"`@+70L("TM=&5S
M="`@("`@("`@S]3*OM:TT-"Z\[7$P_S![K6KLKO6M-#0+@`@(&-L96%N=7`@
M("`@(,?EL_T@4$\@SL2\_M;0SK2WK=+KTM2\L+G]RK&UQ,K]OMTN`"`@8V]M
M;6ET("`@("`@S.&]N[>MTNO.Q+S^UL$@0U93(+?^SO'&]RX`("!C;VUM:70M
M:&5L<"#,X;V[R[7#]\[$O/[6P2!#5E,@M_[.\<;W+@`@(&-O;7!E;F1I=6T@
M(-;8O:C5JM*JSL2\_BX@OJ^XYCK5XKVKN+*XQ[6QQ["UQ-6JTJK.Q+S^+@`@
M(&5X=')A8W0@("`@(++ZR?H@4$\@SL2\_K7$T?FQOB`H+G!O="DN`"`@:&5L
M<"`@("`@("`@S]3*OLNUP_<N`"`@:6YI="`@("`@("`@SK2UL;78T^_1U+VH
MP:+2N[CVTM3)S[7$(%!/(,[$O/XN(+ZON.8Z(+3+T:'/[KVK"B`@("`@("`@
M("`@("`@N+*XQ\OYT]#*]-/:M,NUL;78T^_1U+7$(%!/(,[$O/XN`"`@;6%K
M92`@("`@("`@T\G6N+:HM<0@4$\@SL2\_KVHP:*V_KWXUL8@34\@SL2\_BX`
M("!M97)G92`@("`@(""ZS[*BS];3T+7$(%!/(,[$O/[2U+RP(%!/5"#1^;&^
MSL2\_BX`("!U<&1A=&4@("`@("#2P-#RUK30T+WBOZHH97AT<F%C="F\L+K/
MLJ(H;65R9V4I+@`@('5P9&%T92UH96QP(-?4TZ+3[\NUP_?.Q+S^(%A-3"#6
MT+WBOZK+^=/0T,+4]KRPL>2X_+7$O,W"O`H@("`@("`@("`@("`@(,B[NO.Z
MS[*BM;W/UK3FM<3+M</WSL2\_M;0+@`@)B,Q-3$[("5S(-+1U>NVU,_"P=#*
MPL_NHZS.K+NDLMG7][[-T/<N`"`H)7,@S.S'L"D`("B_[+W=O/P@)7,I`"`H
MUKNVP2D`("B]\<SL*0`@*-?RS.PI`""V^,?2(`#3V@`E9"#7UK?[U^G2T="T
MR.LN`-?<O,8@)3(D9""QRKS'PKS6T+7$("4Q)&0@TM&QZLJVSJK7[KW\N/S0
MP@#7[KW\("5D(,SLQOC/\]2DL:@`)7,@+2"QN,W\PKP`)7,@S[7-L\7DUL,`
M)7,@UKC.Q@`E<R!+0@`E<R#.K+NDLMG7]R`M(,BWR,\`)7,@UZ*RX0`E<R"Q
MZM>\`"5S(,VLTN+/[L2_`"5S(-+1M.;4V@`E<R#4VB`E<R`E<P`E<R#4VB`E
M<R#3HK/?`"5S(-+1R*'/^R`E<RX`)7,@TM&[V+BTTKNX]B!F<F5E+V)U<WD@
MT.C'\RX`)7,@TM&[V+BTM,O1^\?KN/@@)7,N`"5S(-+1M*O+S;CXQ/H@9G)E
M92]B=7-Y(-#%SZ(N`+'8T.C2JB`E<P`E<R"WU@#5TK*[M;T@)7,N`-72LKNU
MO2`E<RX@Q^O/R-:TT-`@)W1R86YS;&%T:6]N(&5X=')A8W0G+@`E<R#'Z\?S
MQ/JUQ"!F<F5E+V)U<WD@T,7/HBX`)7,@Q^O'\\3ZL_;/KR`E<RX`("5S(+6]
M("5S(+FR("5S`"5S(,^CS?N\T\CKM;T@)7,N`"5S(,^CS?O,X=#1Q/H@)7,N
M`"5S(,^CS?O$W+;!R*'3T+G8T]H@)7,@M<37[M#"T,7/HBX`)7,Z("5S`"<E
M<R<@LKO*Q]*[N/;3T-"GM<31H=3Q+@`G)7,G(,G0SK34VB!(3U)$12"UQ->B
MLN'.Q+S^*%)E9VES=')Y*=;0Q>36PRX`)R5S)R#2T;/)N::\T\CKM;W3P[NG
MU^G/M<VSUM`N`"<E<R<@TM&\T\CKR*C/WL^US;,N`"<E<R<@LJ+.M+VHP:(Z
M("5S+@`L(-7SM^<@)7,@)7,`++'DNZ_!O[33("5S(+6]("5S`"TM(-&AU/$@
M+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`+*[UJ>SUB`Q-B#.N\FK
MLLHZ("5S`#(T(-"ARK'6Q@"TR\?XO^FQV-#KTJK6N+:HROV^W;_BM_[.\;;+
M+@"WHLGZP<O2N[CVT<_6V+7$M.W.\P#2T<K5M;W2N[CVT,+3P[NGM<37HK+A
MR>K'Z[*BM<BZ\L3ZM<2ZR]>\+@#3^[S3P]S3RKS^++NYT.C2JM/0TKNX]B!0
M1U`@N:N_JL/<U+\N`-/[T>G6I-+1QZG#^[7$T\J\_BR[N=#HTJK3T-*[N/8@
M4$=0(+FKOZK#W-2_+@#3^[WBP]S3RKS^++NYT.C2JM/0TKNX]KFKOZH@4$=0
M(,/<U+\LR[W#W"!01U`@P]S4ORS2U+RPO]K![BX`T_O6M-#0T\J\_L>IP_LL
MN[G0Z-*JT]#2N[CVN:N_JB!01U`@P]S4ORS+O</<(%!'4"##W-2_+-+4O+"_
MVL'N+@#3^[WBP]S3RKS^++NYT.C2JM/0TKNX]KFKOZH@4TU)344@P]S4ORS+
MO</<(%--24U%(,/<U+\LTM2\L+_:P>XN`-/[UK30T-/*O/['J</[++NYT.C2
MJM/0TKNX]KFKOZH@4R]-24U%(,/<U+\LR[W#W"!3+TU)344@P]S4ORS2U+RP
MO]K![BX`T_N\T\/<T\J\_BR[N=#HTJK3T-*[N/8@4TU)344@N:N_JL/<U+\N
M`$%-+U!-`$%022"QX+K%`+G8T]K5XKCVL>"\K<;W`+G8T]HN+BX`O=/*W,?K
MQ_,`TM&]T\K<`,BHS]ZRN]?C+,[>MZB]J,&B(%9&4R#$O\*\+@#(J,_>LKO7
MXRS.WK>HO:C!HB!61E,@SL2\_BX`U<NZQ=+1MK.]X2X`O>'5R@#7]]/#`-#"
MU/8`T,+4]B`E<P#0PM3VS\*\MM?I`-#"U/;/PKRVR*C/W@#4VK3+T,+4]J.Z
M`-#"U/;3P[NGU^D`T,+4]LBHS]X`T,+4]L_"O+;3P[NGU^D@)R5S)P#0PM3V
MS\*\MLBHS][6P2`G)7,G`-#"U/;2N[CVT\.[ISH`T,+4]M*[N/:SR=2Q.@#0
MPM3VMM0`T,+4]B`E<R#.JB!-;WII;&QA(%-I9&5B87(@LLNUI0#0PM3VM;W.
MTK7$R-7`^@#0PM3VM;W.TK7$S:C1MK*^`-#"U/;3P[NG`-+1T,+4]B`G)7,G
M(+6]S[7-L];0+B"UJ\[>MZC0PM3VMN[-XK7$UZ*RX=#%SZ(Z("5S+@#2T=#"
MU/8@)R5S)R"UO<^US;/6T"X@Q/K/UM3:O\G2U+WXT-"UQ\*\P<LN`-#"U/;.
MQ+S^M;VRUK_B.@#0PM3VT\.[I[7$N:;$W+6QQ["QN[G8L=4N`+78UK<`S:C1
MMK*^`+/)SJJYW,#MU+$@+2#.JL;DR_S3P[NGQ>36P\BHS]X`N=S`[0"YX[CF
MN=S`[0"PHKB[NKD`L**V^[#-Q.'1QP"PHK;[O+#`^]''`+'PP_L`R_G3T-+1
MT>G6I+7$T\.[IP#+^=/0T\.[I]?I`,OYT]#(J,_>`-3*T.VVX+CVM>?7T]/*
MO/ZUV-:W`+*[UJ>SUB!!;'!H82#&M;7`.B`E<P#2T;3FU-H`L>2X_"!)35-0
M(+7'PKP`L>2X_"!)35-0(,/<PNL`L>2X_"!)35-0(-/#NZ<`L>2X_,2CL.8`
MP\#*],CXQ*;1QP#/PL'0P:R]TSH@)7,@MZ+)^L'+TKNX]K3MSO,`TKNX]K*[
MNL^WJ+7$UK6QN\JYT\,N`+"RM<"V^P"PLKCGP*T`L+*YY\"M`,3DP_NT^L#M
M`,3/O*O6W@"PLLSAN<^\L+#-MONRO+3O`-.FT\.SS-#R`-.FT\.SS-#RTM&^
MS=#W`-.FT\.UO<OYT]#/PKRVN;+/[0#%^M>\`,O$U,(`L*+`K;*NSL0@*%=I
M;F1O=W,M,3(U-BD`T;G+]<[$O/ZT\]"A`-&YR_7.Q+S^P_NSQ@#$^LBWMJC2
MJLF^L_T@)7,@M<37HK+APO`@/P#$^LBWMJC2JLF^L_T@)R5S)R#2U+RPR,ZZ
MSM?3T\.[I]?I(#\`L**X^<VB`-''P\#$X=''`-''P\#$X=''SL0@*$%235-#
M24DM."D`L*+"L[#-`+"BR:W+R<BZM;H`T<?6WB_,J\:]T?.UV,?X`-:TT-#.
MK+NDLMG7]\>PS]3*OLBWR,^VU+NPO_(_`,3ZR_FTJ\O-M<2[V+BTQ^O'\]#%
MO/[2T;B]M/C2N[CVR-7`^L[$O/XH:4-A;&5N9&%R*0#*U,V\R;ZS_=*[N/:R
MN[3FU-JUQ-/#NZ?7Z2X`RM3-O,F^L_W2N[CVLKNTYM3:M<3(J,_>+@#*U,V\
ML>"\K=*[N/:RN[3FU-JUQ-/#NZ?7Z2X`RM3-O+'@O*W2N[CVLKNTYM3:M<2Y
MLL_M+@"S]L^OR,O4L0#*]-#4`+#+U,(`L,2T\\#[T<<`L,*UV,#[`$%U=&A?
M8W)Y<W%L.B#5TK*[M;W+^=#HTJJUQ"!I;6%P(,"IU;G7Z;S^+@!!=71H7V-Y
M<G5S.B"W_L[QMLNRHLZTS.&YJ;C#S^[6I[/6+@!!=71H7V-R>75S.B#5TK*[
MM;W+^=#HTJJUQ"!I;6%P(,"IU;G7Z;S^+@!!=71H7V9T<#H@U=*RN[6]R_G0
MZ-*JM<0@1E10(,"IU;G7Z;S^+L?KUMC0PK'@TNL@4$A0(+*BQ]*\T\CK("TM
M96YA8FQE+69T<"#1H<_N+,#]R.<@8V]N9FEG=7)E("TM96YA8FQE+69T<`!!
M=71H7VEM87`Z(-72LKNUO<OYT.C2JK7$($E-05`@P*G5N=?IO/XN`$%U=&A?
M:W)B-3H@U=*RN[6]R_G0Z-*JM<0@:W)B-2#`J=6YU^F\_BX`075T:%]L9&%P
M.B#5TK*[M;W+^=#HTJJUQ"!,1$%0(,"IU;G7Z;S^+@!!=71H7VQD87`Z(,[>
MMZC0PM3VT\.[IR`E<RX@M_[.\<;WN]C3ICH`075T:%]L9&%P.B#.WK>HR;ZS
M_=/#NZ<@)7,`075T:%]L9&%P.B#.WK>HN/S0PM/#NZ<@)7,`075T:%]M8V%L
M.B#5TK*[M;W+^=#HTJJUQ"!-0T%,(,"IU;G7Z;S^+@!!=71H7W-M8F%U=&@Z
M(-72LKNUO<OYT.C2JK7$('-M8F%U=&@@P*G5N=?IO/XN`-'IUJ3*I[#<+@#1
MZ=:DRJ>PW"X@)7,`4D%$2553(-'IUJ2T[<[S+@!&5%`@T>G6I+3MSO,N`+_)
MT\.UQ-?6MLXZ`+7(M/V[V-.FUM``L*+(^[#=O:X`L;.^L-'5R:L`:V5R8F5R
M;W,@P]S"Z[3MSO,N`&ME<F)E<F]S(-/#NZ?#^[3MSO,N`+#-N?["[<BZM;H`
ML,W!U@"RJ,+>M<2ZH\[$("A)4T\M.#@U.2TQ,RD`P\^\T\"MN?H`L,VPS;;@
MR[D`M]NZ[,FK`+#7MNW"WLNY`+'(P/O*L0"RKL#[U\@`L;3$_@"PV<2]M//(
MNK6Z`+*[M:0`R?K(U0#'^+_IQ>36PP#'^+_IP.#0S0#'^+_IT:'4\0#`MM/K
ML-<`M-;,Y0"RH\#[SJS1QP#*Z<>I`+*HR[G$X=''NLVZVLC[N.?.K,3'`+*I
MM,3-W\3)`+*HSJS,V+6Z`+#-SO<`TZ+*]-.AMLC1\\'LM=@`U]C)JP#.Q,"S
M`-7]U-J]J,&B("5S(,2CO^FUQ"!-3R#.Q+S^+BXN`-7]U-J]J,&BM;&UV-/O
MT=0@)7,N+BX@`+&CO-/`^]''`,_NQ+^W^[K%`+*\O*K$R;>HR_<`]/?)JP"R
MO,*AM<\`Q-K(W;G<P.W/M<VS`$-20P!#4DP@M]:RO+7C`,C5P/H`P>.\MK?G
M`+SMQM+5KP"_IL+SPJ$`P]2RR@#.WK>HP:J[^M;!($E-05`@M_[.\<;W.B`E
M<P"\T\3#M/,`R*'/^P#(H<_[SLK,XK&HN.8`SMZWJ,F^L_W.Q+S^("(E<R(N
M`,[>MZC)OK/]Q+_"O"`B)7,B+@#.WK>HR;ZS_3O3T,_"O+:TYM3:("@E<RD`
MSMZWJ-;8U^FAH\OYS.&YJ;7$O,?"O,K]Q+_3Z\_(Q[#+^;&CM.:UQ,K]OMVR
MN[?[+@#.WK>HM*O+S=#%SZ*UO=:XMJBUQ+K%PNLN`+?PM<.]QP"_JL+\R+JU
MN@#2QK:OM>>[L`#(^[;[S-C.Q"`H25-/+3@X-3DM,30I`-;0M\>YLKK-N?H`
MUM#%MR`H25-/+3@X-3DM,BD`QK[6I,^XO=H`QK[6I++?PM0`U:>UPP#6]\^O
M`+C\N,0`T-ZXQ,/<PNL`T:'4\<3ZS^O2JK+9U_>UQ,SUQ+\N`-;'P/L`UM"Y
M^@"\\LSEUM#.Q"`H1T(R,S$R*0"WL<SEUM#.Q"`H0FEG-2D`T:'4\</<PNL`
MT:'4\=*[N/;3P[NGP_L`T:'4\;:OU_<Z`,C5QMK/U,J^M[W*O3H`RJ6UKK6Z
M`-72LKNUO2`E<R"UQ,#@L?"VJ-+E+@#5_=3:Q^6S_2`E<R#$H[_IM<0@4$\@
MSL2\_BXN+@#5_=3:Q^6S_;6QM=C3[]'4("5S+BXN(`"PM,KSL>J\_+S,T/@`
MO\V[I[;+`+_-NZ>YI-?WM:4`N=BQU;2PO]H`U,;!OP"_QK_&R[G(NK6Z`+CG
MPM>QR-''`-'5R:L`M??)J\7,`+^HS:@`P_S![@##_,'NO<6QO@##_,'NT:'/
M[CH`P_S![J.Z`,;`PML`U?W4VLSAO;LZ`,VHT\/#^P"_QL2FPMX`N:O+O@#2
MT<WJL\D`S/6\_@#%Y-;#`,7DUL,@)7,`R+?(S\/<PNL`R+?(S]#"P]S"ZP"X
MU;G[`+C5N?NYLKK-N?H`P:R]T\JGL-PZ(`#!K+W3UL&YJ[^JP]S4O[?^SO'&
M]\JQU.*^W+[X+B#4K=+R.B`E<R`H)7,I`,&LO=/6P2!&5%`@SL2\_K?^SO'&
M]\JGL-PN`"<E<R<@SL2\_L3:R-T`O^*_R\BZM;H`N+36QM&AU/$`U?W4VKBT
MUL8@)7,@M;T@)7,`RKBSM;[5`+CGR[FT[\#HO-,`O\;,V+7/S=\`SMZWJ-+4
M(%!'4""\T\/<T\J\_BX`SMZWJ,ZJ(%!'4"#6M-#0T\J\_L>IP_LN`,[>MZC2
MU"!3+TU)344@O-/#W-/*O/XN`,[>MZC.JB!3+TU)344@T\J\_L>IP_LN`,[>
MMZBP\[:H($Q$05`@M_[.\<;W`,[>MZBP\[:HM;T@;&1A<""W_L[QQO<`SMZW
MJ+KTO=`@)3(D<R#6T+7$("4Q)',@N:;$W"X`SMZWJ,&LO=.UO2!L9&%P(+?^
MSO'&]P#.WK>HP:R]T];!M_[.\<;W("<E<R<@RKG3PR!&5%`Z("5S`,[>MZBX
MM-;&("5S(+6]("5S`,[>MZB]J,&BL;ZUV-/OT=0@)7,@R_G0Z-*JM<3$O\*\
M.@#.WK>HO>+#W"!01U`@ROV^W2X`SMZWJ+WBP]P@4R]-24U%(,K]OMTN`,[>
MMZC)OK/]N/S0PK/,T/(@)R5S)RX`SMZWJ+[VMJC*U;S^R,NUQ+7GU]/3RKS^
MM=C6MRX`SMZWJ+#\NJS7ULSEMJC2Y<[$O/XN`,[>MZBP_+JLU];,Y<JXP;_.
MQ+S^.B`E<P#.WK>HU]3#W-2_M_[.\<;WR*&UP[FKOZK#W-2_+@#.WK>HM/*_
MJB`E<RX`SMZWJ+3ROZK.K+NDN:37]\2CO^D@)7,`SMZWJ+3ROZJUO2!S;6)P
M87-S=V0@M<2YW+7`H:,`SMZWJ+;!R*$@)7,N`,[>MZBVP<BAM.;(H;_8UL:Q
M[2A!0TPI`,[>MZBVP<BAM.;(H;_8UL:Q[2A!0TPI+B!34TP@L++(J]#4P:R]
MT];!R=G0Z-*J(%!(4"`T+C,@N_*X_+C?L.:QO@#.WK>HML'(H;?^SO'&][7$
MS^"YV,S8T-0`SMZWJ+;!R*&W_L[QQO>UQ,_@N=C,V-#4+B!34TP@P:R]T]#H
MTJH@4$A0(#0N,R"[\KC\N-^PYK&^`,[>MZBQH[3F("5S(+7$Q>36PRX`SMZW
MJ+&CM.:X_-#"L\S0\K6].B`G)7,G+@#.WK>HLNG5TB!,1$%0(""W_L[QQO<N
M`,[>MZBXLKC'("<E<R<Z("5S(+7$Q>36PRX`U=*RN[6]($UO>FEL;&$@4VED
M96)A<BX@Q^O(M\C/('-I9&5B87(@RL>W\;3ROZHN`,[>MZBXL]/HT\.[IR`G
M)7,G(,_"P=#(J,_>M;W.Q+S^O-`@)R5S)SH@)7,`N?J\T@"]J,&B`+VHP:+7
MT\[$O/Z\T`"]J,&BU=^UQ,BHS]X`T,73P[^HNL7"ZP"_R\+>M=C1QP"]N[NE
MLL[5U0"YQ;#-`+6QQ[#/X,Z[`+6QQ[#*L;SD`+6QQ[#,[,;X`+6QQ[#7M+_V
M.B``M;''L+?GN/$`O/3'T-&AU/$`R/O&UL*WR[D`SO?`[[;[SL0@*$M/23@M
M4BD`SO?`[[;[SL0@*%=I;F1O=W,M,3(U,2D`SO?`[[;[SL0OSMJ_R\"\SL0@
M*$M/23@M52D`O=V_R[FRNLVY^@#(U0##O\C5`,K]OMT`R-7&V@#*U;6]R-7&
MV@#1H=3QR-7&V@"PU\SL`,JNMO[4P@#0N[[X`+SUR=G+]<7%`,2LR,_)[;?=
MRK:Q\`#$K,C/R*C/W@#$K,C/R*C/W@#2T<ZOS=``R;ZS_0#)OK/]T\.[I]?I
M`,F^L_W(J,_>`,F^L_VAHL?EO]73RKS^`,F^L_T@)R5S)[7$R*C/W@#(M[:H
MTJK)OK/]("<E<R>UQ,BHS][2U+RPS\*\MLBHS]X@/P#)OK/]U>*X]L&LO=,`
MR+>VJ-*JR;ZS_;3+R*C/WM+4O+#&Y,_"O+;(J,_>(#\`N/S0PK/,T/(@)R5S
M)R#2T<F^L_TN`+7=R\W*L;SD`+6DPO,`OMR^^,?KQ_,`OMR^^"!F<F5E+V)U
M<WD@M<3'Z\?ST,7/H@#.RLSBP^C*]@##Z,KV`,^XO=H@*,?KLLZ_O"!(;W)D
M92"\Q\*\SL2\_BDZ`,^XO=K'Z[+.O[S/M<VSN=S`[;7'PKPN`-'0MZ(`PK:U
MX\["ML@`U^ZZ\]*[T*'*L;7$PK:UX\["ML@Z(`#"MK7CSL*VR#H@`+33U_/6
MP=/2`+33T]+6P=?S`,2_PKP`T,+.Q=/#NZ?7Z0#2U"`R-"#0H<JQUL;/U,J^
M/P#/U,J^T:'/[@#/U,J^N/'*O0"\JK*\S.$`LKO)OK/]`+*[TJK6L;W3M.;(
MH2!M86EN=&5N86YC92YP:'``M=K2N['*O,?"O,K'M_&P_+JLU]:VSL/[L\8_
M(,CGN?O*Q\?KT:'4\2X`MN##U\3AO-,`MN##U\3AO-.YLKK-N?H`S\+4V`#/
MPM38("5S`,_"U-C)^K/)M<3%Y-;#SL2\_LZJ(%!(4""SS-#R+@#/PL"MLLNU
MI0"UY]?3T\J\_@"T[<[S`+;RN<^VX+;[`+'@O*T`L>"\K<?XO^D`L>"\K=/#
MNZ?7Z0"QX+RMR*C/W@"QX+RMR*C/W@"QX+RM("5S(+7$R*C/W@"QX+RMT:'/
M[@"QX+RM("5S(+7$R*C/W@"QX+RM("<E<R>UQ,BHS]X`L*.\L`#(^+;[S=^V
MX`"UY]?3T\J\_@"UY]?3T\J\_K78UK<`M>?7T]/*O/ZUV-:WL=C0Z\['NL\N
M`+7GU]/3RKS^R+?(SP"Q[<?IM_NZQ0"_U;#7T,6\_BX`O]6PU[WAN?LN`+WA
MSK(`Q.JUUP"WQ;3SL>"\K<;W`+S'PKPZ(-?<O,8@)60LU^Z]_+C\T,(@)60L
MT,+4]B`E9"RQY+C\("5D+,ZTUJH@)60`L^"UP+RXQ-K1QP"V\L&BS-C`[]''
M`+3MSO,`N=BQU;6]('-M8G!A<W-W9""UQ+G<M<#*L;>BR?JT[<[S`+>BR\W*
M_;[=M;T@<VUB<&%S<W=D(,JQMZ+)^K3MSO,`M*O+S;O8N+3*L;>BR?JT[<[S
M.B`E<RX`M.W.\SH@`+"NR;/$X=''`+"CR/NV[;'(T<<`Q;?6W@##OR`Q-2"W
MUM;3`,._(#,P(,/KUM,`P[\@-2"WUM;3`,._M,ZUQ\*\`,._(#,P(+?6UM,`
MP[\@,2"WUM;3`+>VP/W6M3H`UK30T`#6M-#0UM`Z`-6YOZH`M;W&VLC5`+WB
MR[74L0#5_=3:M-,@)7,@O>*_JBXN+@!&5%`@R<^TJ\7DUL,N`+;!R*'&J[K#
MQ>36P\JGL-P`SMZWJ,&LO=,@3$1!4""W_L[QQO<N`,[>MZC!K+W3(%--0B"W
M_L[QQO<N`+BTUL;*I[#<U]0@(B5S(BX`N+36QLJGL-RUO2`B)7,B+@#.WK>H
MO:C!HM*[N/;0PK7$(%-!4TP@P:R]TRX`TL:VK[6]("(E<R+*I[#<+@#0WKC$
MP]S"Z\JGL-P`MZC`O+_+N*/(NK6Z("C"[;;[SJS$R<NYR+JUNBD`MZC"WLBZ
MM;H`T<_6V+3MSO,A`+2KU>8`MO[4P@"XT+[US_'*QP"XT+[US_'*QSH@`.RS
MO,,`SL2\_LK]Q+\Z("5S(+CVSL2\_@#.Q+S^ROW$OSH@)7,@SL2\_@#.Q+S^
MN=S`[<;W`,[$O/[#^[/&`-72LKNUO<[$O/X`SL2\_LG/M*L`SL2\_LG/M*NY
MIL3<SK2QN]:GL]8N`+G]PLO&]P"WTL"\`,G/L.O4P@#)S\_2U,(`N<RVJ+'(
MP/T`MZW7J@#$O\*\("5S(+*[M.;4V@"]^+W7RL+/[@#7UM#-T=7)JP#7UM#-
MU.?2T=#"U/8Z("5S("5S`-72LKNUO=?6T,W.Q+S^+@#4I+&HS.S*_2`HU*2Q
MJ,SLROVP_,"HL-?,[-+4O+#2N;SDM<3*_;[=.\CGN?O4I+&HS.S*_;W/LZ2]
MJ]6\T\.QR+W/O^VW^;7$L.;#YBD`M+#,Y0#+X\/\`,OCP_S`X-#-`,OCP_P`
MPMO,LP#7U+:OUZK0Q0#5TK6]TZ;3P[/,T/(Z("5S`-72M;W$O\*\.@#0Q\;:
MSN4`MZBY^@!&964O0G5S>2#0Q<^B`$9E92]"=7-Y(+O8N+0`1G)E92]"=7-Y
M(,?KQ_,`S^S3IK_)T\/*L;SDM<3'Z\?S`+>HRO2YY]''Q,<`MZC*]+*CP/O$
MX<[WT<<`O,2\_LC+`+33`,WJU?O#Z,KV`,+ZU,(`R*O#^P#$H[K]MZW2ZP"\
MT\7N`+C4L<C1QP"R^LGZ("5S(+7$S[7-L\7DUL,`U?W4VK+ZR?K$H[_I("5S
M(+7$U[3,K"`N+BX`N/'"L[RJT<<`M<*Y^@!'971O<'0@M.W.\SH@`.7(Q,D`
MUK&RO,+>S=,`P_L`UZJUO0!';V]G;&4@R]'+]P"[TK;(`,^CP+``SZ/`L,[$
M("A)4T\M.#@U.2TW*0#"S,FK`+CQP>K`O`"X\<'6Q,FT[P"[TLFK`-/#NZ?7
MZ;G<P.T`T\.[I]?IP_NSQK*[M<._U;#7`-/#NZ?7Z<BHS]X`T\.[I]?I`+G/
MM<+"WL;5M;H`N=BUN@#.H[78PNW`K0"X\;;WSO>UN@"WP[_-R*C/W@"WP[_-
MM_[.\0"WP[_-R*C/W@"WP[_-P?31U`"\N,3:T<<`O+C$VM''L<C)W+FRNLVY
M^@"YY]''Q,<`RK$`2%1-3`#5TK*[M;T@2%144"#1Z=:D+@"ZH[78`-33M-4M
MR^.WJ`"Q[<VW`+K5M<*ZS<+TM;'`S<BZM;H`SZ.RKL"TSL0@*$E33RTX.#4Y
M+3@M22D`L._6^@"QX+RMQO?*N=/#L._6^@"P[];Z`$AE;'!E<B!A<'!L:6-A
M=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@
M=&AE($AO<F1E"F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RX*1F]R
M(&%N(&EN=')O9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES
M(&1I<F5C=&]R>2X`U>+`[\K'SL2\_K7$OZK*O#H`P/K*M\/[L\:RN[7#O]6P
MUP#H\[79N-0`RM?2LP#*U]*SM=C6MP#*U]*SM>>[L`"ZZ;:\P*W+N0#6T+GZ
MS^.XVP!(;W)D90!(;W)D92#3P[NGN=S`[0!(;W)D92#/M<VSQ>36PP!(;W)D
M92"WK=+KR?JSR<;W`,NNQKW/WP#7UK;.ROW$O[FRO,8_`,JJML@`RJJVR#H@
M`-#9T<#`^P!)34%0(-/*S^2]J,&BRJ>PW#H@)7,`24U!4"#3RL_DR;ZS_<JG
ML-PZ("5S`$E-05`@T\K/Y+3%Q<S%Y-;#O:C!HLJGL-PZ("5S`$E0(+78UK?.
MWK>HRKG3PRX`25`@M=C6M[*BLKO4VB!#2412(+7$O=/*W,?XO^G6T"X`L?FU
MN@#6N]/0S;RQZ@#-O+'JO+#.Q-?6`,V\QJS.Q+S^P[O3T,"IU;G#^[;XQ]+`
MX-#-SK36N+:H.B`E<P#)S[2KS;S&K`#-O,:L`+OCR.NT[<[S.M2DQMK4VM#0
M("5D("*_JLJ\(K7$M=BWO2X`N^/(Z[3MSO,ZU*3&VM3:T-`@)60@OZK*O+7$
MM=BWO2X`N^/(Z[3MSO,Z(+*[NL^WJ+7$T-`N`+OCR.NT[<[S.M?*P<^RN[?[
M+M2DQMH@O>'*^#HE<R#4VM#0("5D(+7$M=BWO2X`N^/(Z[3MSO,ZP.#0S;*[
MM_LNU*3&VB`BO>'*^#HE<R(@U-K0T"`E9""UQ+78M[TN`+OCR.NT[<[S.K?'
MU*3&VK7$SL2\_KWASK(N`+OCR.LL(+*]UN@@)60`N^/(Z]?6MLXZ("5S`+OC
MR.O7UK;..@"TIL#MUM``LKO5_<BWM<0@4$Y'(+CQRKW.Q+S^.B`E<P#*Y,CK
MLKO5_<BWM<37]]/#PNLN`+*[U?W(M[7$L.;#YL_4RK[$H\J].B`E<P"RN]7]
MR+>UQ+:HSKLZ("5S`+*[U?W(M[7$M:7.NSH@)7,`LKO5_<BWM<3+];?%S]3*
MOL2CRKTZ("5S`-3VO-/+]<7%`-.AML@`N/:Q\-/#NZ<`TZ&VR,3ASO?1QP#0
MQ<^B`-#%SZ(`Q*._Z2`E<R"S]<J\NZ_6T"XN+B``LN7(Z['MN/$`LN7(Z\WX
MPN?!K+W3`++ER.N_R<SFM/K$H[#F`++ER.O3RKS^`++ER.LOL>2X_,V\QJP`
MLN7(ZR^QY+C\S?C"Y\&LO=,`U?O*_0#5^\K]P=``Q-JRO[3MSO,`R_G1H=3Q
MM<37]]/#MM2TR]?IO/ZRHL[>T*?3PRX`SM[0I[7$(%5$2"C3P[NGROV^W;'M
MS;<I+@#.WM"GM<33IM/#L\S0\BX`SM[0I[7$Q?JTSKK%PNLN`,SAO;NUQ,K]
MOMW.WM"G+@#.WM"GM<3$O['JUZ'6MP"RN[K/MZBUQ,[$O/ZX\<J]`,[>T*>U
MQ"!M<V=?='EP92X`SM[0I[7$N_+5TK*[M;T@87!I7VED+@#.WM"GM<2[\M72
MLKNUO;+.ROTN`+*[NL^WJ+7$N+C(J,_>+@#.WM"GM<3-J-&VT*W2Z2X`SM[0
MI[7$L.:QOKK%PNL`SM[0I[7$P+34M->AUK<N`,[>T*>UQ,WRT\/"Z\K]OMTN
M`-+!P,K2P<NYP+RYLKK-N?H`TL'`K;_+`+"NMOO`O`#"_+6Z`-+4R:O!T`#'
MJ;>BU=\`T+',Y0#2XK3SP/L`T<#"\KS3`-*[U,(`2F%P86X@*,C5L;XI`,C5
MSL0@*$E33RTR,#(R+4I0*0#4\\[WM;H`U+RUJ0#&W]3"`,'YU,(`UL/6T`#7
M\]/2MM3&ZP"_O]?SMM3&ZP"_O]/2MM3&ZP"Y_LCXO\O+N<RY`+&CP?34K='Y
M(#\`O\_$X=''`$ME<F)E<F]S(,C/UJ2T[<[S+@##W-2_O:C!H@##W-2_S-C5
M]P##W-2_LZ2VR`##W-2_P.#0S0##W-2_T^^WJ`"UL<>PM<2YJ[^JP]S4O[?^
MSO'&]];0+-+1OJVTYM3:Q/JUQ,/<U+\N`+OYP.^PS<NYN;*ZS;GZ`+.OS\H`
MNJNY^@"ZJ\[$("A%54,M2U(I`+_&S?[,V`"\JK;[O*K+N<RY`-/OT=0`P,_.
MS@#/PK#KU,(`S\+/TM3"`,G/M,ZX_-#".@#)S]*[M,ZUQ\*\.B`E<P#)S]*[
MM,ZUQ\*\.B`E<R#7U"`E<P#)S]*[M,ZUQ\*\.B"UVM*[M,ZUQ\*\`,"MS='.
MK-''`-&LTL*RW0"PYL/FQ>36PP#`Z+#-Q-L`P+/+]\W0`,#[L<C`[]''`,#[
ML<C1QP#!T-:GMMC*O[7'`+6MP+8`P:R]TP#!K+W3`,'0L_8@+2#3P[NGO\G2
MU+^TM;W5XKCVSL2\_KS0`,'0L_;+M</WL>K,X@#,UL+;T\.[I]?I+<[$O/ZY
M\0#,UL+;T\.[I]?I+<?SUOH`S-;"V]/#NZ?7Z2W*MK'PNL7"ZP#,UL+;T\.[
MI]?I+=.UT]#5WP#,UL+;T\.[I]?I+;S$O/[(RP#,UL+;T\.[I]?I+;:IU,0`
MS-;"V]/#NZ?7Z2W(H<_[MJG4Q`#!T+/VT\.[I[7$N:;$W+&[N=BQU0#.Q-&G
M`,&BS-7-\`#4V,CKNJ_*O;_BUM`N+BX`M;&UV,JQO.0Z(`"UV,?XT^O*L;SD
M`+78Q_@`M<?"O`"UQ\*\M;T@)7,`UZ+/^@#7HL_Z("5S`+7'PKP`M<?"O,JG
ML-PL(,?KO.RRZ<3ZM<33P[NGP_NZS</<PNLL(,B[NO/6V,K4+@"UQ\*\RJ>P
MW"X`UZ+/^@#"K,FML:0`U,(`P[_(U=#%SZ(`35,M5$Y%1B"XO;S3SL2\_M;0
MP[O3T,K]OMTN`$U31P#6T+GZL,3#Q0#"[<;DMMFYLKK-N?H`PNVT[[S3R[F\
MT[6Z`-/*O/X`T\J\_M/KT,+.Q0#3RKS^N=S`[0#'Z\BWR,_$^M+1OJVPLM>P
M(%!%05(@MOC'TLZ[T]K$^K7$L/RZK,*WOK;6T"AI;F-L=61E('!A=&@I+@"T
MM+VHQ+_"O"`E<R#6T`#"[<"MS?X`PNW`M,[WT<<`PNVV^[3ZM_(`PNW`^P#"
M[;;ZR_L`R/W4P@"QZKS'L\D@O[2Y_2_.M+^TN?T`L>J\Q[/)QN3+_+7$RK:Q
M\"`HP/W(YRX@UMC2JB_2T;O8N+0I`,+MR=RV^\BZM;H`PNW,X<3AO\NUN@#5
M_=3:QJ7%Y-?6MLX`PZO`[\O^Q.'1QP##J\#OQ_/+N0"XO;S^ROW$O]+1LZRS
M]KW3RMS)S\_>+@#7[KW\(#(T(-"ARK&UQ-?NN-_.PK;(.B``U^Z]_"`V(-"A
MRK&UQ-?NN-_.PK;(.B``O=/*W-?NM/.SI+;(`,[EU,(`PNW4O,S8R+JUN@!-
M9&%E;6]N(,*WOK;.M-72M;T`361A96UO;B!U<V5R;&ES="#.Q+S^LKN_R;?#
MSLJ[\LZTU=*UO:&C`+OATNG(H<_[`+OATNG0Q<^B`+OATNG,X=+I`+OATNF[
MV+BT`+OATNFX_-#"`+OATNFX_-#"Q^O'\P"SR=2Q`-&AM:7$H\J].@#5_=3:
MNL^RHLOYT]"UQ"`E<RYP;R#.Q+S^M;W5JM*JUM`N+BX@`-7]U-JZS[*B("5S
M(+7$(%!/(,[$O/ZUO=6JTJK6T"XN+B``U?W4VKK/LJ+$H[_I("5S(+7$MZW2
MZR`N+BX`S_O/H@#3RKS^T>G6I-+1S>JSR2RUJ\K'T\.[I[7$QZG#^\BTSMZW
MJ,VHN?W1Z=:D+@#0Q<^BTM&Y_<;:+@#0Q<^BP.#0S0!-971A<B#'^+_ISMZW
MJ,JYT\,N`$UE=&%R(,?XO^G.WK>HRKG3PRX@S[B]VL?KLLZ_O,^US;.YW,#M
MM<?"O"X`M[VWJ`"WO;>H("<E<R<@SK2QN[:HTN4`N:O6Q@#$J\[WN.<`P]R_
MR\+>Q.'.]]''P:JP[KGZ`$UI;64@P.#0S0#7[KW\(#(T(-"ARK&UQ-?NM<W.
MPK;(.B``U^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B``T[/)Y`#%Y-;#SL2\_M+%
MRJ<N(,CGN?O2JLJYT\/5XKCVTZ;3P[/,T/+$^K'8T.O/UM3:OLVR^LGZR_LN
M`-72LKNUO=#%SZ*UQ"!)1"X`TL7*I[ORM.W.\[7$S;S&K,[$O/XZ("5S`-72
MLKNUO;OAQMJUQ"!)1"X`T,?&VM*[`-#0MJ_3RKS^`+C\T,+(U<;:`,2CO^D`
MQ*._Z0#$IK;[MN#-WP#$IL3)N.<`P\FYQ0#4PKK-Q.H`P[_4P@##R<S8R/O`
MK<S8`-3"P<'3K[_W`,2FPN6XYP#/PM+&`-?STL8`T]+2Q@#)S]+&`,_"TL8`
MR<_2Q@#$JLFCL<B_RP!-;WII;&QA`+BTT:$`SM*UQ-7+NL4`SM*UQ,/%NZ<`
MSM*UQ,/%NZ?2L\/FQ>36PP##Y;7I`+*[+,[2LKO-K-+B`,/[L\8`Q,G#U['(
MT<<`Z*?"LP!.95A4`-#HTJK7]]/#M[W*O0#$X;*TMOL`NLG`O`"ZR<KTL+*U
MV,'0R[D`N_G3VDYE='-C87!E(+7$S?C6MP!.971S8V%P92!34TP@M_[.\<;W
MP_NSQ@!.971S8V%P92#(S]:DM<3%^M>B`$YE='-C87!E(,C/UJ3`X-#-`,WX
MPN<`M-/.M`#0PK^FP.^VX,3AT<<`T,+4P@#0PM/#NZ?#^R`HM\>QV-*J*0#0
MPL[WP+P`T,+#W,+KH[H`T,*TL+_:("A?8FQA;FLI`-#"SL4`S\+2N[*]`,_"
MTKO2LP#/PM*[N/;1H<_N`,3AO-/`K;G/`,3AR-6V^P#$X<C5P/O1QP#-[<G/
M`,6FL*.UN@#+^=:XMJBUQ,Z[UL/)S\.[T]#'^+_IM.;4V@##N]/0S.&YJ<C5
MP/K#^[/&TM2YJ2!-0T%,(-'IUJ0N`+6QQ[#+^;2FM<35XKCVM<B\ML[>MZC4
M]KS3M,[(J,_>+@#)T,ZTUKBVJ,/\P>XN`,.[T]#6N+:HM<0@)7,@Q>36P]#%
MSZ(N`,.[T]#6N+:HM<0@1E10(%9&4R#%Y-;#T,7/HBX`P[O3T-:XMJBUQ"!3
M44P@5D93Q>36P]#%SZ(N`,.[T]#.JB!344P@R,_6I,GHMJBUQ,7DUL/0Q<^B
MH:,`P[O3T-:XMJBUQ"!344PM1FEL92!61E/%Y-;#T,7/HBX`P[O3T,/HRO8`
MU*W*O+7$Q_/6^L[$O/[6T-72LKNUO<JVL?"ZQ<+K("<E<R<N`,[$O/[.M,G/
MM*L`SK36N+:HM;&UV-/OT=0N`,Z[UL/0Q<^BR=#.M,7DUL,`P[O3T-:XMJC#
MW,+KTM2YJ2!(5%10(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4N:D@24U!4"#1Z=:D
M+@##N]/0UKBVJ,/<PNO2U+FI($ME<F)E<F]S(-'IUJ0N`,.[T]#6N+:HP]S"
MZ]+4N:D@3$1!4"#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI($QO9VEN(-'IUJ0N
M`,.[T]#6N+:HP]S"Z]+4N:D@4$%34U=$(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4
MN:D@4TU"(-'IUJ0N`,.[T]"T_<GSM<37HK+AR>K'ZRX`P[O3T-#>MJD`SM[4
MW;3FQ+_"O+_)N:F_[,BA+@##N]/0NL^WJ+7$(%A-3"#*_;[=L;NTJ[O8`+_5
ML-?6M0#4K<J\Q>36P\[$O/[6T-72LKNUO;#FL;[0Q<^B+B#6V-#"LOK)^L7D
MUL/.Q+S^+@#4VL3ZM<3%Y-;#SL2\_M;0U=*RN[6]L.:QOM#%SZ(N(-;8T,*R
M^LGZQ>36P\[$O/XN`+?'T^N[X=7?`,[>`,C5MOK"_,[$("A)4T\M.#@U.2TQ
M,"D`Q;6XH[_+M;H`L;&PZ\?R`+&QPNW`[]''Q,G(NK6Z`,6RS?X`M\?6KKKS
M`+?'UJ['L`#)T,ZTRK7/U@"RN\K'($I014<@N/'*O;7$SL2\_CH@)7,`LKO*
MQR!03D<@N/'*O;7$SL2\_CH@)7,`LKO*Q]*[N/;$O\*\`,[>MZBTM+VH(&QO
M8VL@SL2\_@#.WK>HM+2]J"!S96UA<&AO<F4@SL2\_@#.WK>HN_'(H;6QQ["U
MQ,_JS[C0Q<^B`,ZTL;O6I[/6`->BTN*CNM#>N,3#W,+KNO.QV-#KS<NS]M;8
MT,*UQ\*\(0"QN,W\PKP`S:C6J@#*KM*[U,(`ROW7U@#7UK?[ROT`U]:VSLK]
MQ+\`L<K*_0!/2P"VU,_SO:C!HM7?`+;4S_.]J,&BU=^UQ,BHS]X`L,N]^,Z[
M`,JNU,(`N=BQU0"P[+FKRM(`OLG#W,+KH[H`L*+"_`"T\K^J`-:[T]`@24U!
M4""W_L[QQO?6I[/6SL2\_KS0N;+/[;FFQ-PN`-:[O=/*W-*[N/;3RKS^M=C6
MMRX`UKO3T-.UT]#5W]/KS[7-L[G<P.W4L;_)TM2QY+C\N;+/[<BHS]X`U-K0
MPK2PO]K6T+3ROZH`M\>QV-#KL_;/K\C+U+$`T:'/[@`E<R"UQ-&AS^X`T:'/
M[@#/[L2_L>"ZQ0#7Z=:O`-?IUJ^UI<Z[`-2MRKS3IM/#L\S0\L2CL.8`U-H@
M)7,Z(-;0M<34K<J\Q*.PYBX`QN3+_`#&Y,O\T,7/H@#3M=/0U=_(J,_>`%!!
M32#1Z=:DSM[0IRX`4$5!4B"T[<[S`%!'4"#*_=?6QZG#^P!01U`@O-/#W-?*
MP<\`4$=0(+FKOZK#W-2_`%!'4"#2T<>IP_LOTM&\T\/<(-?*P<\`4$A0(+/,
MT/*T^L+K`%!(4""]Q;&^`+#-N_G+N<RY`,7!P,T`L,W`U<NYS+FQN]6\P>S'
M^`"PS<3#PNT`L,VRO-''T,*\N,3:T<<`L,W`K;GG`,/<PNL`P]S"Z]+1T-ZX
MQ"$`P]S"Z\2CO^G%Y-;#LKO5_<BW`,/<PNO$H[_IQ>36P[*[U?W(MR!-1#4`
MP]S"Z\2CO^G%Y-;#LKO5_<BW(0##W,+KQ*._Z<7DUL.RN]7]R+>AHP##N]/0
MUKBVJ,/<PNO2U+FI(%)!1$E54R#1Z=:D+@##W,+KR+?(SP##W,+K.@##W,+K
M.B``P]S"Z['8T.O.Q[K/+@#,^<G/`,SYR<\`PK>^M@"T_<GSM<?"O*.Z`-:T
MT-#.K+NDLMG7]P"UQ\*\NO/6M-#0SJR[I++9U_<_`,BHS]X`)R5S)R"UQ,BH
MS][.M+&[R;ZS_2X`M.;(H=3BOMP`R*C/W@#(J,_>N=S`[0#(J,_>`,[2M<0`
MP]C"LP"WQL+)L?8`M>>[L`#5U<:L`,:DS-B_M;6Z`,?KRN3(Z]*[N/;4PK?=
MO+#$ZK?=+@#'Z\KDR.O2N[CVNL^WJ+7$R-7&VCO1H=3QM,O4PK?=M<3(U<;:
M+@#'Z\KDR.NZS[>HM<3*L;SD+@#'Z\SAN:G.RLSBM<35JM*J+@#'Z\KDR.O$
M^K7$T\.[I\/[O+##W,+K`,?KU,2VP<_"P=#$VLC=+L3ZL=C0Z\VLTN+5XM"I
MRL+/[K+%Q-S*N=/#S[7-LRX`R.?3T,C.NLZUQ,[*S.+'Z]+4M>?7T]/*O/[!
MJL+G(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@#'Z[O8N<O/PL'0T,7/HBS6KKKS
MU-G3R;++M:76T-&AU/'2N[CVU_?3PRX`Q^O3R;++M:76T-&AU/'2N[CVU_?3
MPRX`LJC`O`#-ML:Q`,;/S-'1P`"UW<O-T\J\_K6]U>*X]L[$O/Z\T"`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I`%!O<W1N=6ME`-?NO?P@)7,@T*'*L;7$O;73
MZL&_.B``4')E9G-?;&1A<#H@U=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\
M_BX`4')E9G-?<V5S<VEO;CH@U=*RN[6]R_G0Z-*JM<0@<V5S<VEO;B#`J=6Y
MU^F\_BX`MZ*Q[0#&^-&Y`+JCQKW#YL;XT;DZ(`#&^-&Y.B``U*3`P`#)S]*[
MTK,`R<_2N[CVT:'/[@#)S]*[N/:T_;#LRL+/[@#+O</<P]S4OP#.RLSBP^C*
M]@#.RLSB/P#7J+"X`,SARK[$VLC=`+FKOZK#W-2_`+FKOZK#W-2_T=W+XP"Y
MJ[^J+\N]P]S#W-2_MM2RHLZTL;NR^LGZ+@"RJ+;@P.BX]P"_J,O^MOL`4E-!
M(+FKOZK#W-2_("@E9"#.NRD`M:71H0"QR,+*`+;!R*$`ML'(H=/*O/X`U>:U
MQ-*JR;ZS_2`E<R#"\#\@U>+/[K+9U_>]J\[>MZB[UKBT+@#(H<_[N+34K0#+
MHM#"P\6[I\K3S;PZ`+GFU/*Q[;3ORKT`QL#"VP"\Q]>AU>*X]B!F<F5E+V)U
M<WD@T,7/HBX`U+:SS+?^SO'&]P#4MK/,S?C6MR`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`,F^L_T`R;ZS_<?XO^D`U]3.TK7$R-7`^M;0R;ZS
M_0#)OK/]MM0`U]2W_L[QQO?4W;3FQ+_"O-;0R;ZS_=+1L:.TYK7$Q>36P[/,
MT/(N`,F^L_W3P[NG`,F^L_W3P[NG.B`E<P"[V+BTO,2\_BX`TM3.M+&[UJ>S
MUK7$T\J\_KO8N+0`TM2V_KCVU,*Z\[7$(&9R964O8G5S>2"[V+BT+@#2U,OY
MQ^O'\[7$(&9R964O8G5S>2#0Q<^BN]BXM"X`N]BXM#H@)7,`T.C'\\ZTL;O/
M[-.F.B"T[<[SNL7"ZSH`)3(D<R"UQ,7DUL.QV-#KUKBVJ"`G)3$D<R<`5D93
M(+7$Q>36P['8T.O6N+:H("<E<R<`Q>36P\K]OMVQV-#KUKBVJ"`G)7,G`,C/
MUJ3%Y-;#UM#.M,GHMJBQV-#HM<0@)V1A=&%B87-E)Z&C`,C/UJ3%Y-;#UM#.
MM,GHMJBQV-#HM<0@)VAO<W1S<&5C)Z&C`,C/UJ3%Y-;#UM#.M,GHMJBQV-#H
MM<0@)W!A<W-W;W)D)Z&C`,C/UJ3%Y-;#UM#.M,GHMJBQV-#HM<0@)W!H<'1Y
M<&4GH:,`R,_6I,7DUL/6T,ZTR>BVJ+'8T.BUQ"`G=&%B;&4GH:,`R,_6I,7D
MUL/6T,ZTR>BVJ+'8T.BUQ"`G=7-E<FYA;64GH:,`L=C0Z[/VSZ^UQ,C+U+$`
MUMC6PP"]X;G[`+WAN?L@*+#\NJP@2&]R9&4I.@"]X;G[.@"WM;O8T:'/[@!2
M975N:6]N("C!],3AS?JUNBD`O<?)JP!2;VUA;FEA("C"WL+MQ.'1QRD`T/W7
MJB`Q.#`@ML@`S_+7\]#]UZH`S_+3TM#]UZH`UK30T`!2=7-S:6%N($9E9&5R
M871I;VX@*+;MPM[+N2D`4G=A;F1A("C"K+"RM.\I`%,O34E-12"\T\/<QZG#
M^P#3RKS^TM'*N=/#(%,O34E-12"\T\/<`%-!4TP@T>G6I,[>T*<N`-#%SZ(`
MROV^W;_BLNG1KP#*_;[=O^*]Q;&^`,/K`+S3P]S6U;;+N_H`L\FYI@#0Q\;:
MP?D`RJ6ZU<#5Q,.UN@#*I;OYM<*ZS<'0SJS+N0#*I<*LSO?1Q[6Z`,JEQJ2P
MH[;[NLW"\[_+PM?(NK6Z`,JESL3)K<S8NLVX\<'6Q,FT[P#-K-*[N/:TL+_:
M("A?<V5L9BD`R/C$IM''`,JEPNW!IL6U`,JEMN##P+K-QM7!UL[WL<@`SL#0
MQ\SAN:G5WP#)L\S8L*+`K;*N`+&CM.8`L:.TYB`E<P"QH[3F("<E<R<`L:.T
MYM&AS^X`O:NR^LGZM<3%Y-;#SL2\_M+4(%!(4"#3[]'4N/'*O;&CM.:UO<3Z
MM<2W_L[QQO?4W;3FQ+_"O-;0+@#%Y-;#("5S(-+1L:.TYBX`N/S0PK/,T/+2
MT;&CM.:UO3H@)R5S)RX`R]'1L`#5_=3:R]'1L"!(;W)D92"UQ,OYT]#3IM/#
ML\S0\BXN+@#5_=3:R]'1L"!G971T97AT("XN+@#1H=3QTKNX]LC5QMH`T:'4
M\=*[N/;3P[NGU^G3P]+4T,+4]@#1H=3QTKO.N]#"M<33M=/0U=\`T:'4\=*[
MLK^W_L[QQO<`T:'4\=*[SKO3P[NGT\/2U-#"U/8`T:'4\<OYT]#(U<;:U^F\
M_BX`T]K2U,_"M<2TL+_:UM#1H<BAQ/K2JK7$U]:W^R[2U,KSL>JXM-;&R_G1
MH<[$U]8LR+NZ\\SYR<_.Q+S^L>"\K<?X+@#1H=3QR-7&VK?6N/0Z`-&AU/'(
MU<;:R-7&VKCQRKTZ`-&AU/'*L;SDM]:X]#H`T:'4\<C5QMK*L;SDN/'*O3H`
MT:'4\<_@NZ7&I<7DM<2V_KCVU]:VSBX`T:'4\<3ZM<31U<FKQ>36PP#1H=3Q
MQJNZP]/OT=0Z`+2KR\W7[KKSM<30Q<^B`+2KR\W.RLSBM[33I@!396YE9V%L
M("C(^\3:O-.V^RD`M*NXT,;W.B``OL74P@!397)B:6$@86YD($UO;G1E;F5G
M<F\@*,C[MOO.K-''T^O#R<S8Q.&XY\+>*0#0\KK%`+OAQMH@240@TM&Y_<;:
M+@#%Y-;#`,7DUL/4MK/,M_[.\<;WR<_*]-/:Q/JUQ+CVR,O5OLRH+@#%Y-;#
MQ/JUQ,:KNL/3[]'4+"#*L<?XTM2\L,C5QMJX\<J]+@#%Y-;#Q/JUQ,;TRKS3
MIM/#L\S0\BS1U<FKQ>36PRS2L\/FN/S0PL:UPLHLO+#&Y,O\S]3*OM&AS^XN
M`-/0NL.\N+CVM=BUX[K-U>*X]K+.ROW3T+G8.B``4V5Y8VAE;&QE<R`HR/O.
M]+;[*0"YNL[O`+SRMLS5JM*J`,K'M_'.JK3SLK^WW;7$P:R]T[:HTN6_[+W=
MN:;$W+S\/P#/U,J^`,._M,ZUQ\*\NO//U,J^R<_2N[3.M<2UQ\*\RK&\Y"`_
M`,_4RKZUX]&AQO<`T]K7\['?S]3*OB`E<R"RR[6E/P#*U<OU`%-I97)R82!,
M96]N92`HRJC7T\F]N?HI`->BLN$`R.>Y^[NYLKO*Q]/#NZ?'Z]>BLN$`QZG#
M^P#'J</[T=W+XP!3:6YG87!O<F4@*-#"O-/&PBD`M//0H0#"U+G]SJR[I`#2
MT<SXN?TN+BX`4VQO=F%K:6$@*,NYPN6WI;_+*0!3;&]V96YI82`HR[G"Y;>E
MQ.'1QRD`N_W1J<GNML@Z(`!3;VQO;6]N($ES;&%N9',@*,OWPM[#Q<BZM;HI
M`%-O;6%L:6$@*,OWPNW`^]''*0##W,+KQ*._Z;7$LK^WUL7DUL/.Q+S^MJK*
MIZ.Z`,7%P="WO<_RT:'4\0#`M-2TM=C6MP!3;W5T:"!!9G)I8V$@*,3/M\<I
M`,3/Q;<@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T
M:"!386YD=VEC:"!)<VQA;F1S`,3/L.O'\@!3<&%I;B`HSO>PX-'`*0#`K+OX
MT\J\_@#,V,KBU]:W^\KDR.L`4W)I($QA;FMA("C+N<#OP+R_J"D`L>K7O`#&
M]+:O`,;TRKS$ZK?=`,JA`->TS*P`T^_1U"`E<R"UQ->TS*PN+BX@`+&CM.:X
M\<J]`+W6M<``R;ZS_<_?`-?6M_NTKL'0`-#'QMK,[`#6]]:\`+FKOZK#W-2_
MT,7/H@#,X;V[`,_"L>H`L\FYI@"SR;FFO-/(ZR`G)7,G(+6]S[7-L];0+@"S
MR;FFR;ZS_2`G)7,G("X`L\FYIM?4S[7-L];0R;ZS_2`G)7,G("X`L\FYIKC\
MT,(@)R5S)P#2T;/)N::XLKC'("5S`%-U9&%N("C+U;6D*0#5JM*J`,C5L_8`
MR-7"Y`#(U;/V`,C5L_8OR-7"Y`#(U;/V.B``R-7"Y`#(U<+D.B``R<^QZ@#6
MI[/6`%-U<FEN86UE("C+U<#[Q,\I`+3"NL4`4W9A;&)A<F0@86YD($IA;B!-
M87EE;@!3=V%Z:6QA;F0@*,JWS=^\P\"\*0!3=V5D96X@*,CPM>0I`%-W:71Z
M97)L86YD("C(\,J_*0!3>7)I86X@07)A8B!297!U8FQI8R`HT/#`^]''*0!4
M04(@M]:X]+CQRKW.Q+S^`,RHS>4`S*C-Y0!486II:VES=&%N("C+_KRJR[G,
MN2D`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B`HS+G)T,3AT<<I`,2_
ML>HZ`+3]L.S*PL_N`+3]L.S*PL_N`%1E86P`M>>[L+K%PNL`U^Z]_-*[T*'*
ML;7$SL*VR#H@`,["ML@`SL*VR#H@`-72LKNUO<2CL.8@)R5S)RX`Q*.PYKG<
MP.T`U-W*L;W3RMS'Z\?S`-3=RK&]T\K<`,3:R-T`M+_.Q-?6`-#'QMK+Q`#,
MJ<[$("A425,M-C(P*0!4:&%I;&%N9"`HS*FY^BD`T+O0N\3ZRKG3P[&^S[7-
MLRX`)3(D<R"UQ"`E,21S(,NUP_?.Q+S^LJ*RN[3FU-HN(-7]U-J]J,&BTKNX
M]M#"M<3+M</WSL2\_BX`M;T@)3(D<R"UQ"`E,21S(,&LO=/2T;&[R;ZS_2X`
M1E10(-'3R>PH97AT96YS:6]N*<[>T*<N`$UA:6YT96YA;F-E(,#@L?"RHLZT
ML\FYIM38R.L`T:'/[K2PO]K2U+G8L=4NP.N_JM;0+@"RN]7]R+>UQ,C5P/K*
M_;[=`-'IUJ33RKS^QZG#^]#HTJK3T-*[N/;2T;WBOZJUQ"!01U`@Q_B_Z2X`
MT.C2JM*[N/:^K;G]O-/#W+7$S?C"Y\&LO=,N`+3+RL*\_M+1U/:\T[6]Q/JU
MQ,C5P/K6T"X`SL2\_B`E<R#3IKC#L/RZK-*[N/8@)7,@Q>36PRX`SL2\_B`E
M<R#3IKC#L/RZK-*[T*D@)7,@Q>36PRX`M,O.Q+S^UM##N]/0ROV^W2X`TM3/
MPLK'(')F8S@R,B#3RKS^M<2Q[<VW+@#'\];ZSL2\_B`E<R"RHLZTTM0@/#]X
M;6P@OZK*O`"TR\&LO=/2T;&[R;ZS_0!';G501R"V_M2JSL2\_K7$PK>^MK'8
MT.NVJ-+EU-H@0W)Y<'1?<&=P.CH@P."Q\-;0+@"WO;>H("5S(,ZTL;L@05!)
M("5S(,OYMJC2Y2X`2&]R9&5?0W)Y<'1?<VUI;64Z.B#`X+'P++'8T.C2JM/0
M(&]P96YS<VP@Q*._Z2X`M,O&J[K#("(E<R(@ROV^W=+RSJJSK+G]U^ZT\[W3
MRMS6M2S+^=+4SMZWJ+&[L:.TY@#3P]+4O.S*T[3+ROV^W<#@T,T@*"5S*2"U
MQ+/,T/*RHK*[M.;4VM/:S[7-L\G/+@"TR[?^SO'&]R`B)7,B(-+1L;O)OK/]
M+@"TR[?^SO'&]R`B)7,B(-+1L;NQH[3F+@`E<R"UQ->BLN'0Z,?STM&QN\F^
ML_TN`-:XMJBUQ+S'PKRRHK*[M.;4VBX`M,NT_;#LRL+/[M+1U/:\T[6]Q/JU
MQ+3]L.RROM;0+@"TT\G/TKNX]K*]UNC6KKKSR<^TJ[7$ROV^W=+%RJ<N`,G/
MM*O.Q+S^LJ+.M+&[L:.TYBX`T\.[I[7$(&9R964O8G5S>2#0Q<^BTM&QH[3F
MS>JSR2X`=V5A=&AE<BYC;VT@Q_B_Z<[>MZC*N=/#+@#.WKB]O/Z_R=:QO=.T
M\K^J+@"TR]?6ML[6T+#\NJS,J[;@M<37ULK]+L3ZTM'*Y,CK("5S(+CVU];*
M_3O$^LKDR.NUQ-?6ROVQV-#KT*'3VB`E<RX`)7,@UM#5TK*[M;W'\];ZSL2\
M_BX`T,+4]B`G)7,G(+6]S[7-LR`E<R#*L;>BR?K2N[CVSLK,XBX`T,+4]B`G
M)7,G(+6]S[7-LSH@)7,@RK&WHLGZTKNX]L[*S.(N`-?4S[7-L\F^L_T@)R5S
M)R#*L;>BR?K2N[CVSLK,XCH`N/S0PB`G)7,G.B`E<R#*L;>BR?K2N[CVSLK,
MX@#)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB.B`E<R#.M+&[R<^TJRX`R<^TJ\[$
MO/[*L;>BR?K2N[CVSLK,XCH@)7,@M//0H;.LN?V]T\K<U^ZT\]:U("@E9"!B
M>71E<RDN`,G/M*O.Q+S^RK&WHLGZTKNX]L[*S.(Z(+WVLK^WUK7$("5S(,[$
MO/ZQN\G/M*LN`+SLRM/3RKS^RK&WHLGZTKNX]K3MSO,N`+OCR.NTR\VHT;:R
MOLK]OMW*L;>BR?JT[<[S+@"[X\CKM,O*PKS^RK&WHLGZTKNX]K3MSO,Z("5S
M+@"UO,CKM,NT_;#LRL+/[LJQMZ+)^M*[N/:T[<[S.B`E<RX`M;S(Z]/#NZ>U
MQ"!F<F5E+V)U<WD@T,7/HK>BR?K2N[CVM.W.\SH@)7,N`-3:Q>36P[2PS.76
MT+>BR?K!R]*[N/:T[<[S+M/0O\G$W,3ZTL7"J<'+L=C0Z\SNT+2UQ-?6MLXN
M`+3ROZK.Q+S^("5S(,JQMZ+)^L'+TKNX]K3MSO,N(,?KRM3-O-/#('1R86YS
M;&%T:6]N+G!H<"`M9"#6N,'NUK30T"R_M+^TRL>W\=/0R,ZZSB!X;6P@O>+.
M]L;WR_FR^LGZM<2T[<[ST,7/HBX`T>G6I+3+T\J\_LJQMZ+)^LZTUJJUQ+3M
MSO,N`+3+($E-05`@M_[.\<;WLJ+.M-:GL];.Q+S^O-"WUL_MN:;$W"X`M,O7
M]]/#SK2QN]:GL]8N`+3+U_?3P\G0SK2QN\JUU_<N`,VHT;;*_;[=TM&SR;FF
MM<34]KS3M;W$^K7$S:C1MK*^UM`NT\/*\['JL+3/PL'0S^[$O]+4O.S*TSH`
MU>++QKKULKO*Q]7]R+>UQ"!R87(@T;G+]<[$O/XN`-7BR\:Z];*[RL?5_<BW
MM<0@>FEP(-&YR_7.Q+S^+@#5XLO&NO6RN\K'U?W(M[7$T,73P[^HNL7"ZRX`
MM,O7UK;.RL>QV-#HTJJUQ"X`M,O7UK;.Q-K(W=:[O=/*W-7[ROW*_=?6+@"T
MR]?6ML[$VLC=UKN]T\K<ROW7UKRPP["ZQ2X`M,O7UK;.Q-K(W=:[O=/*W+#+
MO?C6QLK]UK4N`+3+U]:VSL3:R-VQV-#KSJJVNKK%N_*_U;#7M]:X]+7$ROW7
MU@"QV-#KRL?2N[CVROW7UBX`M,O7UK;.Q-K(W;'8T.NP_+JLTKO7Z<JNP?F]
M^-;&M<0@4D="(-'5R:NT^L+K+,#]R.<@)R,Q,C,T868G+@#5XKCVM+#,Y=+1
ML;NTIL#MN?TN`-7BRL<@)7,N`-7BRL?#W,+KQ*._Z;7$UO?%Y-;#SL2\_J&C
MR_RP_+JLR_G3T,2CO^F]Q;&^M<3"M[ZVO+#1H<_NH:,`M,O*_=:UU^[)V;'8
MT.O*QR`Q+@"TR[/,T/+6N\3<U-K#_,'NP=#)S]:TT-`H8V]M;6%N9"!L:6YE
M*2X`M,NW_L[QQO?.WK>HMM0@>FEP(+RP(&=Z:7`@N/'*O<[$O/Z]^-#0O>+1
MN<OU`+3+S[7-L[6QQ[#*Q\VCT\.UQ->TS*PN`+'8T.O*Q]*[N/;*_=?6+@"T
MR[2PO]JQV-#KTJK3R=&AS^ZTL+_:*$]P=&EO;BG+^;KTO=``RK&\Y`#*L;SD
MU[?7V0#*L;SDN/'*O0#*L<?XT:'4\0!4:6UO<BU,97-T90"QZLSB`,K5O/[(
MRP#(Y[G[TJJXM-&A+,?KU-JUX]&ARO.QZK7$S:S*L;"T($-O;G1R;VR\_"BX
M]LC+O,;+X[OZ*2"[\B!#;VUM86YDO/PHQKNY^[S&R^.[^BDN`+WQS.P`2%1-
M3"#4K<J\SL2\_@"VX+CG`,W0O\O`S<BZM;H`P_?,[`#,P+S3`-+1MZW2ZP#,
MV,&BQ.&T[[K-MN"PS;CG`-7FN_*\V0#0Q\;:MOX`S;O$X<NY`,W!MOK&Y`#-
MP;;ZQN3.Q"`H25-/+3@X-3DM.2D`S<&_XL+\R[G,N0#,V+_+R[FZS;^MO\;+
MN<BZM;H`S;S-W\*L`,KDR.O$^K7$T:'4\3H@`-?/S>+/W]:XROTZ(`#-^-:W
M`,WXUK<Z`,[:N,FT[P#.VK_+P+P`SMZWJ+3FR*$@5D93(,2_PKPN`->BLN'*
ML<[>MZC4]KS3MN[-XK7$T\.[I]#%SZ(N`,[>MZBTTR`E<R#0PM3VT\J\_K6]
MT,6\_M6B("5S.B``SMZWJ,7ZUZ([(+?^SO'&][O8TZ8Z("5S`,[>MZBXQ+'D
M(%9&4R#.Q+S^("(E<R(@M<3(J,_>+@#.WK>HL>2X_"!61E,@SL2\_B`E<R\E
M<R"UQ,BHS]XN`,[>MZBQY+C\SJH@)7,N`,[>MZC!K+W3M;T@4U%,(+?^SO'&
M]Z&C`,[>MZC*N=/#(%-33"#!K+W3+@#.WK>HN+36QB!61E,@SL2\_BX`SMZW
MJ+VHP:(@5D93(,2_PKP@(B5S(BX`SMZWJ+VHP:(@5D93(,2_PKPN`,[>MZB]
MJ,&B(%9&4R#.Q+S^+@#.WK>HO:C!HM#%O/[5HB`E<SH@`,[>MZB]J\K]OMV]
MXM&YR_4N`,[>MZC)OK/]("5S++3+Q+_"O+*BM\>_U;#7`,[>MZC)OK/]("5S
M++3+Q+_"O+*BM\>_U;#7`,[>MZC)OK/]("<E<R<Z("5S+@#.WK>HM=VYZ<F^
ML_W$O\*\+@#.WK>HR;ZS_2!61E,@Q+_"O"X`SMZWJ,F^L_T@5D93(,2_PKPZ
M("5S+@#.WK>HR;ZS_2!61E,@SL2\_B`B)7,B+@#.WK>HR;ZS_2!61E,@SL2\
M_BX`SMZWJ+7=N>G)OK/](%9&4SH@)7,N`,[>MZC%T+;/M;''L+7$Q+_"O"X`
MSMZWJ+WBOZK&OM:DS[B]V@#5TK*[M;W$O\*\`,[>MZB\T]38("5S(+7$MJC2
MY<K]OMTN`,[>MZC2QK:O(%9&4R#.Q+S^+@#.WK>HM/*_JB!61E,@SL2\_B`B
M)7,B+@#.WK>HT+3(ZR!61E,@SL2\_BX`SMZWJ+3ROZH@5D93(,[$O/XN`,[>
MMZBT\K^JT;G+]<[$O/XN`,[>MZBT\K^JS;S&K,[$O/XZ("5S`,[>MZBT\K^J
MT,6\_M6B("5S.@#.WK>HML'(H2!V9G-R;V]T(,2_PKPN`,[>MZBQY+C\(%9&
M4R#$O\*\M<3#^[/&+@#.WK>HR;ZS_2!61E,@Q+_"O#H@)7,N`,[>MZBQY+C\
M(%9&4R#.Q+S^("(E<R(@M<3#^[/&+@#.WK>HL>2X_"!61E,@SL2\_B`E<R\E
M<R"UQ,/[L\8N`,[>MZBQY+C\(%9&4R#.Q+S^M<3#^[/&+@#.WK>HML'(H;?^
MSO'&]R`E,B1S(-;0N=C3VM/#NZ<@)3$D<R"UQ"!F<F5E+V)U<WD@T,7/H@#.
MWK>HL:.TYB!01$8@SL2\_CH@)7,`SMZWJ+2KR\T@4$1&(,[$O/XLLK^WULK]
MOMW2T<KDL_:UO>2OP,#&]\G/P^8N`,[>MZC4VK?^SO'&]R`E,B1S(,G/L:.T
MYM/#NZ<@)3$D<R"UQ"!F<F5E+V)U<WD@T,7/H@#.WK>HUZJ[NR!7;W)D(,[$
MO/X`SMZWJ-"TR.L@5D93("(E<R(@SL2\_BX`SMZWJ-"TR.L@5D93(,[$O/[*
M_;[=+@#/PKNNS]\`R*'/^[C\N,0`N+34K0#.M-2DQMJUQ,KDL_8LU]0@0VAE
M8VMO=70Z("5S`+?^SO'&]\&LO=/*L;>BR?K.M-2DQMJUQ+O8TZ8Z(`"WHLGZ
MSK34I,;:M<2[V-.F+-/)M_[.\<;W.B``P.#0S3H@)7,@SMZWJ+&[UJ>SU@#-
M\M/#PNL@*%541BTX*0"PHL"MLJ[!JKK/Q_6SI+GZ`-.BN?H`P\"Y^@!5;FET
M960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`M:74J@#.M-:JM<0`
MSK36JK7$P_S![CH@)7,`SK36JK7$T;G+];>]RKTZ("5S`,ZTUJJUQ+G]PLNW
MO<J].B`E<P#.M-:JM<32L\/FN/'*O3H@)7,`SK36JK7$T\.[I\/[N_+#W,+K
M+@#.M-:GL]:UQ,"IU;G#^P"RN]:GL];-O,:LSL2\_KCQRKTZ("5S`,ZTMZW2
MZP"QY+C\`+C\T,(@)7,`N/S0PK>TTZ;7M,RL`+C\T,+3P[NG`-+1N/S0PB`G
M)7,G+@#5_=3:N/S0PB`E,B1S("4Q)'/'\];ZSL2\_BX`N/S0PK/,T/+2T<F^
ML_TN`,G/M*L`TM')S[2KR_G3T-.FT\.SS-#RM<3%Y-;#SL2\_K6]M_[.\<;W
M+@#.VL"MN><`T^^WJ#H`RKG3P\2LR,_6M0#3P[NG("5S(,ZTS:BY_2`E<R"U
MQ,K:R*C1Z=:D+@#3P[NG("5S0"5S(,ZTU=*UO0#3P[NGN=S`[0#3P[NGT:'/
M[@#3P[NGUZ*RX0"TR]6^S*BUQ-/#NZ?7HK+AS[7-L]+1S:/3PRX`T\.[I\BH
MS]X`T\.[I\/[`-/#NZ?#^R`G)7,G(-+1M.;4VBX`T\.[I\/[.@#3P[NG.B``
MT\.[IP#/M<VSUM"UQ-/#NZ<Z`,[:U\BQ\+_+R[G,N0!61E,@Q+_"O+*BLKNT
MYM3:+@"\V<;:`-+1U=*UO=/0T*>UQ+78M>,Z(`#3T-"GT-0`TM2WUM;3SJJU
MI<Z[*+33S];4VL;PR^,I`-:U`,W?PK.PHLV\`+'DNZ\`SJ_$VLCPP*T`T>G6
MI,JGL-P@+2"TR]/*O/Z_R<3<TM'4XLC+R</7U+3;N,0N`+#FL;X`L.:QOK_8
MUL8`U+W$SP#4O<3/SL0@*%9)4T-)22D`O.S*TR`E<P#4VM#"M+"_VK3ROZH`
MTM0@)7,@LNF_M`"RZ;^TRL*\_@"RZ;^TM/VP[,K"S^X`TZ+*],ZLMON^J<BZ
MM;H`P\#*],ZLOJG(NK6Z`,3<O/NVR`#$W+S[ML@Z(`#2XK3SP/NW_+7"M^>U
MY]#%N:O+OLVXN?T@4TU44`"^K[CF`+ZON.8A(2$@M-,@)7,@RM:VK\F^L_VS
MS-#R+@#-W\#[R[FZS;B[S;S(NK6Z`+ZON.8`OJ^XYCH@`-#'QMK(_0#,[,;X
MU*2RX@#-^-6^`,WXU;X`P[_6W`"[MM.M`+NVTZVUO2`E<P"[MM.M+"`E<P#.
M]\6W("A)4T\M.#@U.2TQ*0#.]\6W("A)4T\M.#@U.2TQ-2D`SO?(]KG^P*T`
MM<?"O+KSTZ:XP\_(S]3*OB`E<R#$Q-*[N/;3IM/#L\S0\C\`U]:VSK7$M]:X
M]-?6M_L_`-+]RO:UQ,>PM;RW^S\`M^?+V2B]VBD`M^?+V3H`M^?+V3H@`,;:
MM/W/[L2_`+#LN:O*TK78UK<`L.RYJ\K2M>>[L`#.WK>HT+3(ZRX@Q/J_R=+4
MRKG3P\C.NLZUQ,G]O+:SS-#RN_+*UK:ON+36QL_"P^:SS-#RM/K"Z[6]("5S
M+@#5_=3:T+3(Z\?SUOK.Q+S^M;T@)7,N`%@U,#EV,R#`J=6YP_L`Q.H`Q.H`
M66%H;V\@(2"UV,V\`,._Q.H`TK+#Q0#*Q[7$+,[2S:S2X@#$^K6QQ[#*N=/#
MM+_.Q-?6L>#0M,2CRKTN(,JYT\,@6SP^72"PM,6EO\G'T+N[SJK-^-*SL>#0
MM,2CRKTN`,3ZO\G2U-3:("5S(-:DRK75XKCVQZG#^P#$X[*[Q-S0WKC$T\.[
MIR`E<R"UQ,/<PNL`Q/JRHLZTRN3(Z]*[N/:ZS[>HM<2UY]?3T\J\_K78UK<N
M`,3ZLJ+.M-/)M;S(Z[7$SL2\_M;0MM33L\C.NL[7UK;.M;T@)7,`Q/K2T;ZM
MUZ+/^BX`Q/JQV-#KRN3(Z]*[N/:ZS[>HM<36M2X`Q/JQV-#KS\BYYKNNNL/*
M_;[=RO<H1&%T851R964IM_[.\;;+LL7$W+S,T/C*N=/#($AO<F1E+@#$^K'8
MT.O/R+GFNZZZP\K]OMW*]RA$871A5')E92FW_L[QMLNRQ<3<O,S0^,JYT\/0
MPM/#NZ?7HK+AM_[.\2X`Q^O#Z,KVSLK,XJ.LU-K$^K2KR\W.RLSBL:BXYM:N
MQ[`N`,3ZL=C0Z\KDR.NTR\&LO=/+^=:XS_*UQ,WXUK<`Q..QV-#KRN3(Z]#"
MP]S"ZP#$X['8T.O,X;FIOLG#W,+K`,?KUKBVJ-*JR;ZS_;7$M_[.\<;W+@#'
MZ]:XMJC2JLF^L_VUQ-/#NZ<N`,?KUKBVJ-*JT,+4]K7$T\.[IRX`Q^O6N+:H
MTJJX_-#"M<33P[NG+@#'Z]:XMJC2JM:TT-"UQ-?WT\,N`,3CL=C0Z\BWR,_0
MPL/<PNL`Q/JUQ"`E<R"[X<;:TM&Y_<JQ+L?KUMC0PK7'PKPN`,3ZM<2UY]?3
MT\J\_K78UK<`Q/JUQ-#%SZ(`U]2TT\3ZM<0@)7,@N^'&VK^JRKS2U,"TQ/JU
MQ-+RS-C-^+78UK?2T;'DN/PN(,ZJL:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQV-#K
MUMC0PK7'PKPN`,3ZM<30U</[`,3ZM<31Z=:DMLNRHLZTUJ>SUM#"U/;3P[NG
MN_*XP[FFQ-S2T;&[N=BQU2X`Q/JUQ-'IUJ2VR[*BSK36I[/6P="S]M/#NZ>[
M\KC#N:;$W-+1L;NYV+'5+@#7U+33Q/JUQ"`E<R"[X<;:OZK*O-+4P+3$^K7$
MY*_`P,;WR\:Z]=+1L>2X_"X@SJJQH[NDQ/JUQ+"RR*O&\+S[HZS$^K'8T.O6
MV-#"M<?"O"X`Q/JUQ.2OP,#&][*BSK36I[/6U>*X]KFFQ-PN`,3ZM<3DK\#`
MQO>RHLZTUJ>SUK3RTZ'1H<_N+L?KL+0@0U123"M0(-+4M/+3H2X`Q/JUL<>P
MR_G%Y-;#M<3*L<?X.@#$^K7$(&=E='1E>'0@L.:QOLRKOLFRHL?2LKO6I[/6
M(%!(4"X*TO*TR[*BM\?+^=/0M<37UK?[M*ZVO,3<L;O5_<BWM<2]XK^J+@#$
MX[7$T,+#W,+KS*NSI#L@P]S"Z[.DMLBRN\3<LZRY_2`E9""X]M?6M_LA`,3C
MM<30PL/<PNO,J[SRM:72U[+"(2#.M-?WT-ZXQ"$`Q..UQ-#"P]S"Z['8T.O6
MP<G9("5D(+CVU]:W^[.D(0#$X[7$T,+#W,+KLKO2N];"`,3CM<2^R</<PNNR
MN]7]R+<`Q/JUQ-&AS^[2T;C\T,(N`,3ZM<34MK/,M_[.\<;W.@#$S\NYP*VW
M\@#4^M+!MOL`U-ZQR-''`+WRL,VRO,ZD`%O.RLSBL:BXYET`6\Z[T]K0T"`E
M<R"YLB`E<R#0T%T`MZ+)^L'+TKNX]K3MSO,Z`,C5`,C5`,WJL\D`RJ>PW`#.
MQ+S^`-72M;TZ(`"TTR`E<R`H)7,I(-/:("5S("5S`,JQ.@#0H<JQ`-"ARK$`
M:3$X;@#!HKRT`+?6`+?6`-3"`-3"`,/[L\8`SK2QY+C\+@#5TK*[M;T`R=#.
MM,JUS]8N`,G0SK3*M<_6+@##ZP##ZP!T96UP;F%M92@I(,JGL-PA`$AO<F1E
M(+7$L;ZUV-/OT=0@)7,@4$\@SL2\_K*BLKNTYM3:.@#4V;3.RN3(Z\3ZM<3#
MW,+KTM3(M\C/SM[.\P#.M,/\P_L`TM&X_-#"`-/#NZ?1H=3Q`'9#87)D`+?'
MLZ.VS+7$RK&\Y`#0Q\;:.@!W96%T:&5R+F-O;2#-^-6^`-;<`-;<`,3J`,3J
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O;&]C86QE+WIH7U17+P``
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S0T`#`R,#(Q-P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W
M9"]L;V-A;&4O>FA?5%<O3$-?34534T%'15,O````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(R,#`T`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&%S<W=D+VQO8V%L92]Z:%]45R],0U]-15-304=%4R]P
M87-S=V0N;6\````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,V,#$S-P`Q,#0Q-S,V,C<T-``P
M,C,V-3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````!Y!P``'````.0[``#W"0``K'<```````"(GP``30```(F?
M``"_````UY\``&0```"7H```O@```/R@``"0````NZ$``$,```!,H@``/```
M`)"B```K````S:(``"X```#YH@``*0```"BC```H````4J,``$4```![HP``
M1P```,&C``!*````":0``$<```!4I```10```)RD``!(````XJ0``#D````K
MI0``1@```&6E``!(````K*4``#````#UI0``10```":F``!&````;*8``$P`
M``"SI@``-`````"G```R````-:<``&D```!HIP``,````-*G```E`````Z@`
M`(@````IJ```0````+*H``#V````\Z@``$H```#JJ0``+````#6J``"%````
M8JH``$@```#HJ@``#@```#&K```/````0*L```T```!0JP``"````%ZK```+
M````9ZL```P```!SJP``!````("K```,````A:L``!$```"2JP``)0```*2K
M```/````RJL```L```#:JP``$0```.:K```.````^*L```4````'K```*```
M``VL```(````-JP```H````_K```%0```$JL```2````8*P```L```!SK```
M)P```'^L```3````IZP```X```"[K```"@```,JL```-````U:P``"X```#C
MK```#@```!*M```1````(:T```T````SK0``#````$&M```-````3JT```8`
M``!<K0``'0```&.M```;````@:T``"T```"=K0``)````,NM```I````\*T`
M`!D````:K@``#P```#2N```8````1*X```P```!=K@``&P```&JN```.````
MAJX```X```"5K@``"````*2N```)````K:X``$(```"WK@``+@```/JN```:
M````*:\``#(```!$KP``.````'>O``!4````L*\``%$````%L```6@```%>P
M``!7````LK```#0````*L0``#@```#^Q```)````3K$```T```!8L0``!P``
M`&:Q```*````;K$```\```!YL0``!0```(FQ```&````C[$``!$```"6L0``
M"````*BQ```)````L;$```D```"[L0``#@```,6Q```E````U+$``"````#Z
ML0``$````!NR```/````++(```H````\L@```P```$>R```/````2[(``!0`
M``!;L@``"0```'"R```-````>K(``!(```"(L@``&0```)NR```>````M;(`
M``\```#4L@``"@```.2R```/````[[(```@```#_L@``)`````BS```4````
M+;,``!8```!"LP``"````%FS``!.````8K,``"T```"QLP``'P```-^S```9
M````_[,```<````9M```#````"&T```L````+K0```X```!;M````P```&JT
M```+````;K0```<```!ZM```!P```(*T```%````BK0```4```"0M```"@``
M`):T```#````H;0``!<```"EM```"@```+VT```/````R+0```X```#8M```
M&````.>T```C`````+4```X````DM0``%````#.U```7````2+4``!<```!@
MM0``%P```'BU```3````D+4```\```"DM0``#@```+2U```?````P[4``!T`
M``#CM0``!P````&V```&````";8```@````0M@``#P```!FV```&````*;8`
M``H````PM@``$P```#NV```+````3[8``!````!;M@``%0```&RV```5````
M@K8```<```"8M@``$````*"V```%````L;8``!4```"WM@``$0```,VV```,
M````W[8``#L```#LM@``.````"BW```)````8;<```<```!KMP``%````'.W
M```#````B+<```4```",MP``$````)*W```)````H[<``!,```"MMP``.0``
M`,&W```2````^[<``"<````.N```+````#:X```J````8[@``"4```".N```
M"@```+2X```&````O[@```D```#&N```!P```-"X```O````V+@``#<````(
MN0``+@```$"Y``!5````;[D``"T```#%N0``+0```/.Y```M````(;H``$``
M``!/N@``(P```)"Z```C````M+H``"T```#8N@``,P````:[```5````.KL`
M`!D```!0NP``*0```&J[```D````E+L``!$```"YNP``"@```,N[```B````
MUKL```H```#YNP``$`````2\```6````%;P``!8````LO```!P```$.\```'
M````2[P``!0```!3O```"@```&B\```(````<[P``"<```!\O```"````*2\
M```'````K;P```<```"UO```!@```+V\```%````Q+P```<```#*O```!@``
M`-*\```(````V;P``"D```#BO```#@````R]```*````&[T```0````FO0``
M!P```"N]```)````,[T```8````]O0``$0```$2]```'````5KT``!8```!>
MO0``!````'6]```(````>KT```8```"#O0``#0```(J]```&````F+T``!X`
M``"?O0``$0```+Z]```B````T+T``!8```#SO0``"`````J^```-````$[X`
M``P````AO@``!P```"Z^```#````-KX```,````ZO@``%P```#Z^```3````
M5KX``!T```!JO@``"````(B^```$````D;X```@```"6O@``"````)^^``!!
M````J+X``"````#JO@``!@````N_```&````$K\``!4````9OP``&````"^_
M```B````2+\``"X```!KOP``'0```)J_```A````N+\``%0```#:OP``*0``
M`"_````*````6<````<```!DP```%0```&S````.````@L````H```"1P```
M#P```)S````-````K,````\```"ZP```#0```,K````)````V,```!0```#B
MP```!@```/?````8````_L```!T````7P0``$P```#7!```1````2<$``!0`
M``!;P0``!````'#!```&````=<$```\```!\P0``$P```(S!``!4````H,$`
M`!0```#UP0``%P````K"```$````(L(```X````GP@``1````#;"```%````
M>\(```4```"!P@``&P```(?"```:````H\(``!$```"^P@``$0```-#"```<
M````XL(``"H```#_P@``$````"K#```A````.\,``"4```!=PP``&0```(/#
M```%````G<,``!,```"CPP``$@```+?#```*````RL,```\```#5PP``#0``
M`.7#```1````\\,``!,````%Q```#````!G$```&````)L0```P````MQ```
M!@```#K$```7````0<0``!````!9Q```$0```&K$```(````?,0```4```"%
MQ```#````(O$```0````F,0```4```"IQ```#0```*_$```&````O<0```<`
M``#$Q```#0```,S$```0````VL0```D```#KQ```!P```/7$```+````_<0`
M``L````)Q0``!P```!7%```'````'<4``!0````EQ0``"0```#K%```*````
M1,4``!D```!/Q0``'0```&G%```,````A\4``!````"4Q0``%0```*7%```%
M````N\4``"4```#!Q0``$@```.?%```3````^L4``"L````.Q@``.P```#K&
M```@````=L8``#8```"7Q@``$````,[&```(````W\8```P```#HQ@``!```
M`/7&```.````^L8``!`````)QP``"@```!K'```-````)<<``!X````SQP``
M&P```%+'```A````;L<``!X```"0QP``&0```*_'```>````R<<``!T```#H
MQP``&P````;(```@````(L@``"X```!#R```%P```'+(```F````BL@``#``
M``"QR```&P```.+(```>````_L@``!P````=R0``)@```#K)```K````8<D`
M`#,```"-R0``)@```,')```K````Z,D``#@````4R@``'0```$W*```5````
M:\H``"\```"!R@``$@```+'*```@````Q,H``"D```#ER@``'@````_+```A
M````+LL``!(```!0RP``H@```&/+```6````!LP``",````=S```*````$',
M```I````:LP``"@```"4S```'P```+W,```5````W<P``"````#SS```)0``
M`!3-```H````.LT``"T```!CS0``,````)'-``"2````PLT``"$```!5S@``
M%@```'?.```<````CLX``"8```"KS@``*@```-+.``!!````_<X``$0````_
MSP``#````(3/```'````D<\```<```"9SP``!@```*'/```-````J,\``!``
M``"VSP``$@```,?/```3````VL\``!(```#NSP``!P````'0```$````"=``
M``P````.T```#@```!O0```/````*M```!,````ZT```#0```$[0```H````
M7-````,```"%T```#0```(G0```&````E]```!$```">T```%P```+#0```;
M````R-````X```#DT````@```//0```%````]M```!````#\T```!`````W1
M```-````$M$```X````@T0```P```"_1```.````,]$```@```!"T0``#P``
M`$O1```/````6]$```<```!KT0``#0```'/1```0````@=$``!,```"2T0``
M$P```*;1```+````NM$```8```#&T0``#````,W1```1````VM$``!D```#L
MT0``"P````;2```-````$M(``"(````@T@``&P```$/2```T````7](```H`
M``"4T@``&````)_2```9````N-(``!8```#2T@``+P```.G2```B````&=,`
M``T````\TP``!P```$K3```4````4M,```L```!GTP``(@```'/3```O````
MEM,```L```#&TP``"0```-+3```9````W-,```L```#VTP``%P````+4```7
M````&M0```D````RU```%@```#S4```/````4]0``!8```!CU```#@```'K4
M```8````B=0```@```"BU```#0```*O4```F````N=0``$,```#@U```"```
M`"35```2````+=4```@```!`U0``"P```$G5```O````5=4```X```"%U0``
M!0```)35```&````FM4```,```"AU0``!P```*75```$````K=4```H```"R
MU0``"@```+W5```/````R-4``!````#8U0``%P```.G5```1`````=8``!<`
M```3U@``&0```"O6```)````1=8```4```!/U@``"P```%76```*````8=8`
M``4```!LU@``#0```'+6```;````@-8``!<```"<U@``"0```+36```.````
MOM8```T```#-U@``$@```-O6```X````[M8``"`````GUP``"````$C7```.
M````4=<``'L```!@UP``&````-S7``!`````]=<``!$````VV```!P```$C8
M```%````4-@``"````!6V```$P```'?8```'````B]@```<```"3V```"```
M`)O8```&````I-@```8```"KV```$````++8```/````P]@``!````#3V```
M#P```.38```+````]-@```\`````V0``#````!#9```/````'=D```<````M
MV0``"@```#79```&````0-D```X```!'V0``#````%;9```/````8]D```@`
M``!SV0``%@```'S9```(````D]D``!,```"<V0``'@```+#9```A````S]D`
M`"````#QV0``&0```!+:```7````+-H``"4```!$V@``%P```&K:```>````
M@MH``"8```"AV@``!````,C:```;````S=H```T```#IV@``#````/?:```#
M````!-L```@````(VP``"@```!';```,````'-L```L````IVP``$````#7;
M```,````1ML```0```!3VP``$P```%C;```4````;-L```P```"!VP``"0``
M`([;```.````F-L```L```"GVP``&P```+/;```'````S]L```<```#7VP``
M"@```-_;```-````ZML```D```#XVP``!`````+<```%````!]P```,````-
MW```&````!'<```*````*MP```0````UW```)@```#K<```.````8=P``'P`
M``!PW```%0```.W<```%`````]T```<````)W0``#````!'=```(````'MT`
M``H````GW0``!@```#+=```(````.=T``!8```!"W0``$@```%G=```"````
M;-T```8```!OW0``!@```';=```4````?=T```T```"2W0``$````*#=```;
M````L=T```0```#-W0``"0```-+=```0````W-T```D```#MW0``"0```/?=
M```%`````=X```4````'W@``"`````W>```&````%MX``!D````=W@``#@``
M`#?>```B````1MX```<```!IW@``!P```''>```.````>=X```4```"(W@``
M"0```([>```*````F-X```(```"CW@``!@```*;>```-````K=X```D```"[
MW@``!@```,7>```2````S-X```D```#?W@``!P```.G>```4````\=X``!T`
M```&WP``$0```"3?```&````-M\```H````]WP``!````$C?```)````3=\`
M``@```!7WP``$0```&#?```1````<M\```D```"$WP``!@```([?```-````
ME=\```8```"CWP``!````*K?```>````K]\```4```#.WP``#@```-3?```$
M````X]\```8```#HWP``(0```._?```5````$>````8````GX```!````"[@
M```1````,^````8```!%X```H````$S@```*````[>```"(```#XX```!```
M`!OA```E````(.$```4```!&X0``'0```$SA```$````:N$```P```!OX0``
M"@```'SA```(````A^$```D```"0X0``!0```)KA```;````H.$``#H```"\
MX0``,````/?A```U````*.(``"D```!>X@``+@```(CB``!'````M^(``#@`
M``#_X@``*0```#CC```_````8N,``"X```"BXP``+0```-'C```?````_^,`
M``\````?Y```$@```"_D```+````0N0``"8```!.Y```*0```'7D```D````
MG^0``"8```#$Y```"````.OD```*````].0```D```#_Y```!P````GE```@
M````$>4``"`````RY0``)@```%/E```*````>N4``!D```"%Y0``*0```)_E
M```2````R>4```<```#<Y0``"@```.3E```,````[^4```\```#\Y0``$```
M``SF``!`````'>8``'````!>Y@``9@```,_F```.````-N<```D```!%YP``
M"@```$_G```2````6N<``!,```!MYP``#````('G```&````CN<```\```"5
MYP``$@```*7G```0````N.<``!$```#)YP``$@```-OG```<````[N<``",`
M```+Z```:@```"_H```/````FN@```4```"JZ```$````+#H```)````P>@`
M``0```#+Z```"P```-#H```:````W.@``!0```#WZ```#`````SI```,````
M&>D```\````FZ0``%0```#;I```I````3.D``"H```!VZ0``)@```*'I```G
M````R.D``"D```#PZ0``*@```!KJ```9````1>H``$(```!?Z@``$0```*+J
M```2````M.H``!,```#'Z@``%````-OJ```/````\.H``!8`````ZP``%P``
M`!?K```0````+^L``!$```!`ZP``-````%+K```3````A^L``!(```";ZP``
M-0```*[K```4````Y.L```<```#YZP``#`````'L```@````#NP``!0````O
M[```$0```$3L```7````5NP``!P```!N[```$P```(OL```4````G^P``!H`
M``"T[```$0```,_L```:````X>P``!X```#\[```&@```!OM```3````-NT`
M`!4```!*[0``$0```&#M```7````<NT``!0```"*[0``%P```)_M```5````
MM^T```D```#-[0``&0```-?M```$````\>T```<```#V[0``"P```/[M```1
M````"NX```8````<[@``!@```"/N```&````*NX```4````Q[@``!P```#?N
M```'````/^X```4```!'[@``%@```$WN```&````9.X```8```!K[@``!```
M`'+N```$````=^X```<```!\[@``#@```(3N```,````D^X```P```"@[@``
M#0```*WN```*````N^X```X```#&[@``!0```-7N```H````V^X```X````$
M[P``#````!/O```/````(.\```H````P[P``"````#OO```)````1.\``"L`
M``!.[P``!````'KO```(````?^\``"8```"([P``$@```*_O```/````PN\`
M``8```#2[P``"@```-GO```'````Y.\```@```#L[P``(````/7O```)````
M%O````P````@\```#0```"WP```.````._```!8```!*\```$0```&'P```&
M````<_````,```!Z\```!@```'[P```'````A?````0```"-\```"P```)+P
M```+````GO````<```"J\```!P```++P```6````NO````T```#1\```#0``
M`-_P```*````[?```!````#X\```#P````GQ```1````&?$``!<````K\0``
M"@```$/Q```1````3O$```@```!@\0``!````&GQ```/````;O$``#H```!^
M\0``!0```+GQ```>````O_$```X```#>\0``$````.WQ```+````_O$```P`
M```*\@``"0```!?R```'````(?(```H````I\@``"0```#3R```.````/O(`
M`!````!-\@``&@```%[R```*````>?(```D```"$\@``%````([R```*````
MH_(```P```"N\@``#P```+OR```(````R_(```8```#4\@``!P```-OR```+
M````X_(``$<```#O\@``#0```#?S```)````1?,```0```!/\P```P```%3S
M```3````6/,``!,```!L\P``$P```(#S```*````E/,```(```"?\P``!```
M`*+S```E````I_,```,```#-\P``!0```-'S```J````U_,```H````"]```
M!0````WT```$````$_0```H````8]```#0```"/T``!`````,?0``!,```!R
M]```!@```(;T```(````C?0```@```"6]```!````)_T```%````I/0``&@`
M``"J]```"0```!/U```,````'?4```4````J]0``!@```##U```;````-_4`
M`"\```!3]0``$````(/U```*````E/4```\```"?]0``"@```*_U```)````
MNO4``!,```#$]0``&P```-CU```8````]/4``!<````-]@``#@```"7V```#
M````-/8```<````X]@``"````$#V```'````2?8```H```!1]@``"P```%SV
M```M````:/8``!4```"6]@``,````*SV```D````W?8```<````"]P``40``
M``KW```0````7/<```P```!M]P``&@```'KW``!*````E?<``!D```#@]P``
M!@```/KW```:`````?@```8````<^```!@```"/X```?````*O@```8```!*
M^```"0```%'X```8````6_@``!<```!T^```*````(SX```&````M?@```T`
M``"\^```(@```,KX``!7````[?@``!,```!%^0``(P```%GY```3````??D`
M``(```"1^0``"P```)3Y```(````H/D```T```"I^0``"@```+?Y```&````
MPOD```<```#)^0``%````-'Y```&````YOD```@```#M^0``#@```/;Y```'
M````!?H```H````-^@``"P```!CZ```'````)/H```P````L^@``#0```#GZ
M```,````1_H```D```!4^@``"0```%[Z```*````:/H```<```!S^@``"0``
M`'OZ```'````A?H```H```"-^@``&P```)CZ```2````M/H```H```#'^@``
M"0```-+Z```0````W/H```<```#M^@``$@```/7Z```$````"/L```<````-
M^P``!0```!7[```%````&_L```L````A^P``%````"W[```1````0OL``!H`
M``!4^P``%@```&_[```4````AOL``!<```";^P``&````+/[```<````S/L`
M`!D```#I^P``!P````/\```%````"_P```T````1_```#````!_\```(````
M+/P``!<````U_```"P```$W\```-````6?P``!,```!G_```!````'O\```*
M````@/P```0```"+_```#````)#\```%````G?P```D```"C_```!0```*W\
M```'````L_P```4```"[_```!````,'\```"````QOP``#@```#)_```+```
M``+]```2````+_T``"D```!"_0``,@```&S]```*````G_T``#8```"J_0``
M+````.']```5````#OX``"X````D_@``,P```%/^```S````A_X``#@```"[
M_@``#P```/3^```8````!/\``#L````=_P``$````%G_```/````:O\``!0`
M``!Z_P``$P```(__```5````H_\``!0```"Y_P``$@```,[_```4````X?\`
M`"T```#V_P``+0```"0``0`Q````4@`!`"T```"$``$`+@```+(``0`O````
MX0`!`"P````1`0$`8@```#X!`0`3````H0$!``@```"U`0$`"````+X!`0`;
M````QP$!`"L```#C`0$`(0````\"`0`:````,0(!``D```!,`@$`10```%8"
M`0!!````G`(!``0```#>`@$`$P```.,"`0`4````]P(!``X````,`P$`$P``
M`!L#`0`8````+P,!``8```!(`P$`"0```$\#`0`*````60,!``\```!D`P$`
M$````'0#`0`'````A0,!``X```"-`P$`!0```)P#`0`;````H@,!``8```"^
M`P$`"````,4#`0`&````S@,!`!0```#5`P$`$0```.H#`0`.````_`,!`#@`
M```+!`$``@```$0$`0`&````1P0!``X```!.!`$`&@```%T$`0`%````>`0!
M``<```!^!`$`!@```(8$`0`-````C00!``0```";!`$`*0```*`$`0`?````
MR@0!`%P```#J!`$`%````$<%`0`^````7`4!`!\```";!0$`$````+L%`0`'
M````S`4!``X```#4!0$`"````.,%`0`,````[`4!``P```#Y!0$`$P````8&
M`0`*````&@8!`!T````E!@$`&0```$,&`0`%````708!`!$```!C!@$`$0``
M`'4&`0`D````AP8!`!4```"L!@$`$@```,(&`0`.````U08!`!D```#D!@$`
M"````/X&`0`)````!P<!``T````1!P$`"@```!\'`0`'````*@<!``\````R
M!P$`!@```$('`0`+````20<!``H```!5!P$`!P```&`'`0`(````:`<!``4`
M``!Q!P$`'P```'<'`0`&````EP<!`!````">!P$`"````*\'`0`-````N`<!
M`"(```#&!P$`"````.D'`0`7````\@<!`!(````*"`$`+````!T(`0`O````
M2@@!`"P```!Z"`$`*@```*<(`0`K````T@@!`"P```#^"`$`&@```"L)`0`)
M````1@D!``H```!0"0$`%0```%L)`0`%````<0D!`!0```!W"0$`!````(P)
M`0`0````D0D!``8```"B"0$`!P```*D)`0`>````L0D!`"@```#0"0$`"@``
M`/D)`0`<````!`H!`!H````A"@$`#P```#P*`0`4````3`H!``0```!A"@$`
M!````&8*`0`+````:PH!``4```!W"@$`!@```'T*`0`(````A`H!``8```"-
M"@$`&P```)0*`0`T````L`H!`#0```#E"@$`(````!H+`0`I````.PL!`"``
M``!E"P$`00```(8+`0`:````R`L!`"@```#C"P$`*0````P,`0!1````-@P!
M`"\```"(#`$`(@```+@,`0`&````VPP!``@```#B#`$`!0```.L,`0`(````
M\0P!`!D```#Z#`$`&0```!0-`0`J````+@T!`",```!9#0$`+@```'T-`0`T
M````K`T!``@```#A#0$`%P```.H-`0`*`````@X!``<````-#@$`(0```!4.
M`0`0````-PX!``X```!(#@$`"P```%<.`0`'````8PX!`!,```!K#@$`"```
M`'\.`0`+````B`X!``H```"4#@$`%````)\.`0`/````M`X!`#(```#$#@$`
M"P```/<.`0`%`````P\!``4````)#P$`%P````\/`0`/````)P\!``0````W
M#P$`"@```#P/`0`)````1P\!``L```!1#P$`#0```%T/`0`,````:P\!``X`
M``!X#P$`!0```(</`0`$````C0\!``T```"2#P$`,@```*`/`0!%````TP\!
M`!<````9$`$`'@```#$0`0`4````4!`!``4```!E$`$`%````&L0`0`'````
M@!`!``X```"($`$`*@```)<0`0`&````PA`!``P```#)$`$`#0```-80`0`1
M````Y!`!``L```#V$`$`-@````(1`0`*````.1$!`"(```!$$0$`"P```&<1
M`0`/````<Q$!`#(```"#$0$`)0```+81`0`P````W!$!`#$````-$@$`+0``
M`#\2`0`_````;1(!`#T```"M$@$`-@```.L2`0`.````(A,!``4````Q$P$`
M#@```#<3`0`3````1A,!``<```!:$P$`&@```&(3`0`(````?1,!`!$```"&
M$P$`!P```)@3`0`4````H!,!`!@```"U$P$`!P```,X3`0`%````UA,!``P`
M``#<$P$`#````.D3`0`2````]A,!``0````)%`$`!P````X4`0`*````%A0!
M``L````A%`$`#````"T4`0`.````.A0!``X```!)%`$`!0```%@4`0`%````
M7A0!`"X```!D%`$`)@```),4`0`C````NA0!``,```#>%`$`$@```.(4`0`&
M````]10!`!X```#\%`$`&````!L5`0`E````-!4!``T```!:%0$`"0```&@5
M`0`#````<A4!``<```!V%0$`"@```'X5`0`"````B14!``P```",%0$`%0``
M`)D5`0`+````KQ4!`!D```"[%0$`(````-45`0`2````]A4!``4````)%@$`
M"@````\6`0`5````&A8!`!(````P%@$`#````$,6`0`$````4!8!``<```!5
M%@$`"0```%T6`0`,````9Q8!`%(```!T%@$`%P```,<6`0`D````WQ8!`!(`
M```$%P$`!P```!<7`0`&````'Q<!``X````F%P$`(@```#47`0`=````6!<!
M``P```!V%P$`#0```(,7`0`5````D1<!`!(```"G%P$`#P```+H7`0`4````
MRA<!`!L```#?%P$`$````/L7`0!I````#!@!`!H```!V&`$`%P```)$8`0`G
M````J1@!`!H```#1&`$`%P```.P8`0`;````!!D!`!D````@&0$`'P```#H9
M`0`3````6AD!``@```!N&0$`!P```'<9`0`(````?QD!``D```"(&0$`%0``
M`)(9`0`-````J!D!`",```"V&0$`$P```-H9`0`#````[AD!`$8```#R&0$`
M/P```#D:`0`W````>1H!`%<```"Q&@$`!0````D;`0`?````#QL!`"\````O
M&P$`"@```%\;`0`(````:AL!``T```!S&P$`+0```($;`0`$````KQL!`$\`
M``"T&P$`)0````0<`0`+````*AP!`!\````V'`$`'0```%8<`0`E````=!P!
M`"````":'`$`)````+L<`0`@````X!P!``L````!'0$`!P````T=`0`-````
M%1T!``P````C'0$`%P```#`=`0`&````2!T!``P```!/'0$`!P```%P=`0`9
M````9!T!``D```!^'0$`$P```(@=`0`)````G!T!``0```"F'0$`$````*L=
M`0`*````O!T!``@```#''0$`"````-`=`0`$````V1T!``L```#>'0$`#```
M`.H=`0`2````]QT!`!$````*'@$`#````!P>`0`/````*1X!``<````Y'@$`
M#0```$$>`0`4````3QX!``X```!D'@$`#````',>`0`;````@!X!`"P```"<
M'@$`$P```,D>`0`&````W1X!``<```#D'@$`$P```.P>`0`%`````!\!``0`
M```&'P$`%P````L?`0`*````(Q\!``P````N'P$`"0```#L?`0`&````11\!
M``D```!,'P$`"````%8?`0`*````7Q\!`!$```!J'P$`!@```'P?`0`8````
M@Q\!``X```"<'P$`#@```*L?`0`-````NA\!``L```#('P$`'0```-0?`0`+
M````\A\!``(```#^'P$`'`````$@`0`'````'B`!``8````F(`$`90```"T@
M`0`)````DR`!``<```"=(`$`)@```*4@`0`X````S"`!`!H````%(0$`*@``
M`"`A`0`[````2R$!`"@```"'(0$`-````+`A`0`9````Y2$!`!4```#_(0$`
M!0```!4B`0`'````&R(!``@````C(@$`!P```"PB`0`%````-"(!``<````Z
M(@$`#@```$(B`0`)````42(!``8```!;(@$`"````&(B`0`+````:R(!``<`
M``!W(@$`"````'\B`0`'````B"(!`!8```"0(@$`"0```*<B`0`&````L2(!
M``L```"X(@$`'````,0B`0`4````X2(!``<```#V(@$`$0```/XB`0`(````
M$",!``@````9(P$`!0```"(C`0`0````*",!`!`````Y(P$`!@```$HC`0`9
M````42,!``H```!K(P$`'````'8C`0`'````DR,!``4```";(P$`$````*$C
M`0`4````LB,!``L```#'(P$`#0```-,C`0`8````X2,!`!<```#Z(P$`!```
M`!(D`0`)````%R0!``H````A)`$`!P```"PD`0`"````-"0!``X````W)`$`
M"````$8D`0`?````3R0!`#X```!O)`$`(P```*XD`0`X````TB0!`#$````+
M)0$`)P```#TE`0!D````924!`!0```#*)0$`50```-\E`0`X````-28!`$H`
M``!N)@$`6P```+DF`0`H````%2<!`#@````^)P$`*````'<G`0`L````H"<!
M`"<```#-)P$`&P```/4G`0`^````$2@!`"@```!0*`$`(P```'DH`0`7````
MG2@!`$@```"U*`$`A0```/XH`0`P````A"D!`$$```"U*0$`6P```/<I`0!)
M````4RH!`!T```"=*@$`&````+LJ`0`A````U"H!`!\```#V*@$`*P```!8K
M`0`A````0BL!`"<```!D*P$`'0```(PK`0`1````JBL!`#,```"\*P$`)0``
M`/`K`0`G````%BP!`"`````^+`$`'P```%\L`0`P````?RP!`&D```"P+`$`
M*P```!HM`0`R````1BT!`#$```!Y+0$`00```*LM`0`S````[2T!`"4````A
M+@$`/0```$<N`0!E````A2X!`$T```#K+@$`+P```#DO`0`N````:2\!`#``
M``"8+P$`5````,DO`0"#````'C`!`%H```"B,`$`2````/TP`0!*````1C$!
M`#(```"1,0$`+P```,0Q`0`L````]#$!`"T````A,@$`%P```$\R`0`E````
M9S(!`#(```"-,@$`*0```,`R`0`^````ZC(!`"(````I,P$`4@```$PS`0`E
M````GS,!``L```#%,P$`L0```-$S`0!%````@S0!`"$```#)-`$`+@```.LT
M`0`P````&C4!`"4```!+-0$`'````'$U`0`Q````CC4!``<```#`-0$`!P``
M`,@U`0`$````T#4!``T```#5-0$`"P```.,U`0`.````[S4!``L```#^-0$`
M!0````HV`0`0````$#8!``(````A-@$`60```"0V`0`%````?C8!`!(```"$
M-@$`!````)<V`0`'````G#8!``@```"D-@$`!0```*TV`0`#````LS8!`!``
M``"W-@$`"@```,@V`0`3````TS8!``T```#G-@$``@```/4V`0`'````^#8!
M``8`````-P$`%`````<W`0`,````'#<!`!@````I-P$`!@```$(W`0`2````
M23<!``P```!<-P$``P```&DW`0`$````;3<!``8```!R-P$`!P```'DW`0`?
M````@3<!`#4```"A-P$`+@```-<W`0`O````!C@!`!<````V.`$`(````$XX
M`0`;````;S@!`!@```"+.`$`)````*0X`0`?````R3@!`!H```#I.`$`(```
M``0Y`0`:````)3D!`#(```!`.0$`+P```',Y`0`:````HSD!`"L```"^.0$`
M'P```.HY`0`C````"CH!`!\````N.@$`&@```$XZ`0`E````:3H!`"8```"/
M.@$`)0```+8Z`0`D````W#H!`!@````!.P$`'0```!H[`0`D````.#L!`!@`
M``!=.P$`(@```'8[`0`5````F3L!`"4```"O.P$`/````-4[`0`?````$CP!
M`",````R/`$`'P```%8\`0`@````=CP!`!H```"7/`$`&````+(\`0`F````
MRSP!`!X```#R/`$`*0```!$]`0`>````.ST!``D```!:/0$`#````&0]`0`7
M````<3T!`"\```")/0$`)````+D]`0`'````WCT!``\```#F/0$`%````/8]
M`0`.````"SX!``T````:/@$`)````"@^`0`%````33X!``<```!3/@$`(@``
M`%L^`0`E````?CX!`!,```"D/@$`&@```+@^`0`=````TSX!`!H```#Q/@$`
M!P````P_`0#'````%#\!``L```#</P$`%0```.@_`0`,````_C\!``8````+
M0`$`"0```!)``0`+````'$`!``T````H0`$`'0```#9``0`7````5$`!``8`
M``!L0`$`,P```'-``0`3````IT`!`!,```"[0`$`!P```,]``0`&````UT`!
M``\```#>0`$`!P```.Y``0`R````]D`!`"$````I00$`$P```$M!`0`,````
M7T$!`!$```!L00$`,@```'Y!`0`.````L4$!``\```#`00$`$````-!!`0`(
M````X4$!`!T```#J00$`"0````A"`0`*````$D(!``4````=0@$`%````"-"
M`0`*````.$(!`!T```!#0@$`"````&%"`0`?````:D(!``@```"*0@$`&@``
M`)-"`0`&````KD(!`!4```"U0@$`!P```,M"`0`(````TT(!``D```#<0@$`
M/P```.9"`0`'````)D,!``\````N0P$`#@```#Y#`0`0````34,!``D```!>
M0P$`"0```&A#`0`(````<D,!`!,```![0P$`!P```(]#`0`9````ET,!``H`
M``"Q0P$`%P```+Q#`0`4````U$,!``H```#I0P$`#````/1#`0`7`````40!
M``0````91`$`*@```!Y$`0`1````240!``<```!;1`$`"0```&-$`0`"````
M;40!`!````!P1`$`&````(%$`0`+````FD0!``,```"F1`$`"````*I$`0`&
M````LT0!``<```"Z1`$`#0```,)$`0`+````T$0!`!0```#<1`$`%0```/%$
M`0`.````!T4!`"\````610$`(````$9%`0`<````9T4!``P```"$10$`,0``
M`)%%`0`%````PT4!`!(```#)10$`/P```-Q%`0`2````'$8!``H````O1@$`
M!@```#I&`0`$````048!``0```!&1@$`"@```$M&`0`3````5D8!``4```!J
M1@$`!@```'!&`0`&````=T8!``D```!^1@$`!````(A&`0`,````C48!``H`
M``":1@$`(````*5&`0`9````QD8!`!T```#@1@$`$0```/Y&`0`"````$$<!
M``0````31P$`"@```!A'`0`&````(T<!``4````J1P$``P```#!'`0`,````
M-$<!`$4```!!1P$`&@```(='`0`U````HD<!`"4```#81P$`*````/Y'`0!3
M````)T@!`!D```![2`$`<@```)5(`0`@````"$D!`#4````I20$`(0```%])
M`0!%````@4D!`#````#'20$`(P```/A)`0`?````'$H!`"@````\2@$`*0``
M`&5*`0`F````CTH!`"4```"V2@$`*````-Q*`0`H````!4L!`"(````N2P$`
M(0```%%+`0`P````<TL!`!(```"D2P$`$P```+=+`0`0````RTL!`'D```#<
M2P$`"0```%9,`0!R````8$P!`',```#33`$`?````$=-`0`K````Q$T!`%0`
M``#P30$`%P```$5.`0`6````74X!``\```!T3@$`90```(1.`0`?````ZDX!
M`%$````*3P$`-P```%Q/`0`V````E$\!`#8```#+3P$`/@````)0`0!!````
M05`!`$,```"#4`$`?````,=0`0!`````1%$!`#X```"%40$`0````,11`0!"
M````!5(!`#D```!(4@$`'P```()2`0!`````HE(!`!\```#C4@$`'`````-3
M`0!1````(%,!`!0```!R4P$`"@```(=3`0`%````DE,!``8```"84P$`"```
M`)]3`0`2````J%,!`!````"[4P$`$P```,Q3`0`=````X%,!``\```#^4P$`
M#P````Y4`0`$````'E0!``D````C5`$`"P```"U4`0`'````.50!``4```!!
M5`$`%````$=4`0`'````7%0!``@```!D5`$`#P```&U4`0`(````?50!``P`
M``"&5`$`#P```)-4`0`&````HU0!`!0```"J5`$`!@```+]4`0`,````QE0!
M`!4```#35`$`"````.E4`0`*````\E0!``0```#]5`$`!@````)5`0`$````
M"54!``<````.50$`&0```!95`0`"````,%4!``(````S50$`"0```#95`0`&
M````0%4!`!4```!'50$`!@```%U5`0`"````9%4!``0```!G50$`"P```&Q5
M`0`)````>%4!``\```""50$`$P```))5`0`'````IE4!``<```"N50$`!@``
M`+95`0`&````O54!`!````#$50$`$@```-55`0`"````Z%4!``8```#K50$`
M"0```/)5`0`S````_%4!`"(````P5@$`!P```%-6`0`'````6U8!``<```!C
M5@$`"P```&M6`0`%````=U8!``(```!]5@$`"P```(!6`0!A`0``C%8!`#@`
M``#N5P$`<@```"=8`0`C````FE@!`(````"^6`$`<@```#]9`0`L````LED!
M`"L```#?60$`(`````M:`0`J````+%H!`"@```!76@$`)P```(!:`0`U````
MJ%H!`#4```#>6@$`-0```!1;`0`T````2EL!`#4```!_6P$`-0```+5;`0`M
M````ZUL!`#0````97`$`,@```$Y<`0`D````@5P!`#<```"F7`$`+0```-Y<
M`0`Q````#%T!`"8````^70$`)@```&5=`0`T````C%T!`"8```#!70$`%P``
M`.A=`0!J`````%X!`"T```!K7@$`F@```)E>`0`N````-%\!`#$```!C7P$`
M80```)5?`0`H````]U\!``H````@8`$`#````"M@`0`*````.&`!``<```!#
M8`$`!P```$M@`0`'````4V`!``(```!;8`$`#0```%Y@`0`0````;&`!`"H`
M``!]8`$`$@```*A@`0`+````NV`!``8```#'8`$`!P```,Y@`0`%````UF`!
M`!(```#<8`$`!P```.]@`0`'````]V`!``L```#_8`$`"0````MA`0`+````
M%6$!`!0````A80$`#````#9A`0`)````0V$!``4```!-80$`"@```%-A`0`I
M````7F$!``\```"(80$`"@```)AA`0`*````HV$!``H```"N80$`"@```+EA
M`0`&````Q&$!`!@```#+80$`&````.1A`0`K````_6$!`!X````I8@$`%```
M`$AB`0`2````76(!``P```!P8@$`$@```'UB`0`*````D&(!`!L```";8@$`
M"0```+=B`0`)````P6(!``D```#+8@$`!@```-5B`0!`````W&(!`!T````=
M8P$`%````#MC`0`E````4&,!`"T```!V8P$`0````*1C`0!$````Y6,!`$0`
M```J9`$`2@```&]D`0`G````NF0!``T```#B9`$`"````/!D`0`(````^60!
M``@````"90$`"`````ME`0`(````%&4!``D````=90$`"````"=E`0`.````
M,&4!``<````_90$`!@```$=E`0`&````3F4!``D```!590$`&P```%]E`0`;
M````>V4!``H```"790$`"P```*)E`0`$````KF4!``0```"S90$`"````+AE
M`0`*````P64!``D```#,90$`"````-9E`0`(````WV4!`!$```#H90$`$P``
M`/IE`0`/````#F8!``@````>9@$`#0```"=F`0`&````-68!`!D````\9@$`
M#P```%9F`0`0````9F8!``H```!W9@$`,P```()F`0`K````MF8!`!8```#B
M9@$`&P```/EF`0`$````%6<!``8````:9P$`(0```"%G`0`$````0V<!``0`
M``!(9P$`%````$UG`0`4````8F<!`!0```!W9P$`"````(QG`0`$````E6<!
M``D```":9P$`!````*1G`0`2````J6<!``@```"\9P$`"````,5G`0`&````
MSF<!`!8```#59P$`%P```.QG`0`&````!&@!``X````+:`$`#@```!IH`0`0
M````*6@!`!`````Z:`$`"````$MH`0`(````5&@!`!T```!=:`$`$P```'MH
M`0`5````CV@!`!````"E:`$`#P```+9H`0`3````QF@!``P```#::`$`!```
M`.=H`0`5````[&@!`"H````":0$`"````"UI`0`,````-FD!``X```!#:0$`
M$@```%)I`0`$````96D!``@```!J:0$`!````'-I`0`7````>&D!``H```"0
M:0$`"@```)MI`0`:````IFD!`"0```#!:0$`$@```.9I`0`2````^6D!`!8`
M```,:@$`!````"-J`0`0````*&H!`!`````Y:@$`"````$IJ`0`/````4VH!
M`!L```!C:@$`"````']J`0`9````B&H!`!D```"B:@$`&0```+QJ`0`9````
MUFH!``0```#P:@$`!````/5J`0`4````^FH!`!`````/:P$`*@```"!K`0`C
M````2VL!`"D```!O:P$`:P```)EK`0`H````!6P!`"@````N;`$`*````%=L
M`0`I````@&P!`!P```"J;`$`'````,=L`0`H````Y&P!`"X````-;0$`"0``
M`#QM`0`,````1FT!`!````!3;0$`#0```&1M`0`+````<FT!`!4```!^;0$`
M%P```)1M`0`$````K&T!``@```"Q;0$`$@```+IM`0`8````S6T!`!````#F
M;0$`#@```/=M`0`8````!FX!`!,````?;@$`$0```#-N`0`4````16X!``0`
M``!:;@$`!P```%]N`0`0````9VX!``\```!X;@$`#````(AN`0`0````E6X!
M``T```"F;@$`!````+1N`0`A````N6X!``@```#;;@$`"````.1N`0`$````
M[6X!`!(```#R;@$`!`````5O`0`$````"F\!``@````/;P$`!````!AO`0`M
M````'6\!``0```!+;P$`$0```%!O`0`$````8F\!``T```!G;P$`#0```'5O
M`0`>````@V\!`!@```"B;P$`&P```+MO`0`7````UV\!`!,```#O;P$`"```
M``-P`0`9````#'`!`!`````F<`$`"````#=P`0`#````0'`!``H```!$<`$`
M#P```$]P`0`3````7W`!``8```!S<`$`!@```'IP`0`1````@7`!`!$```"3
M<`$`)@```*5P`0`:````S'`!``\```#G<`$`!````/=P`0`,````_'`!`!(`
M```)<0$`#P```!QQ`0`C````+'$!`!(```!0<0$`&@```&-Q`0`Q````?G$!
M`!D```"P<0$`$P```,IQ`0`(````WG$!``H```#G<0$`&0```/)Q`0`(````
M#'(!``H````5<@$`"P```"!R`0`*````+'(!``L````W<@$`"````$-R`0`6
M````3'(!``0```!C<@$`)0```&AR`0`1````CG(!``@```"@<@$`"@```*ER
M`0`(````M'(!``L```"]<@$`!````,ER`0`(````SG(!``L```#7<@$`&P``
M`.-R`0`(````_W(!`!(````(<P$`!````!MS`0`-````(',!`!4````N<P$`
M#````$1S`0`,````47,!`!$```!><P$`#P```'!S`0`(````@',!`!(```")
M<P$`#0```)QS`0`2````JG,!`!D```"]<P$`%0```-=S`0`;````[7,!`!<`
M```)=`$``@```"%T`0`4````)'0!``X````Y=`$`"@```$AT`0`0````4W0!
M``8```!D=`$`#@```&MT`0`4````>G0!``@```"/=`$`!````)AT`0`&````
MG70!``(```"D=`$`%P```*=T`0`*````OW0!``@```#*=`$`$P```--T`0`$
M````YW0!``8```#L=`$`#@```/-T`0`#`````G4!``@````&=0$`!`````]U
M`0`$````%'4!``@````9=0$`"0```")U`0`$````+'4!``0````Q=0$`!P``
M`#9U`0`$````/G4!`!````!#=0$`!````%1U`0`*````674!``0```!D=0$`
M!````&EU`0`$````;G4!``T```!S=0$`!P```(%U`0`(````B74!``L```"2
M=0$`#````)YU`0`R````JW4!``D```#>=0$`"@```.AU`0`;````\W4!`"D`
M```/=@$`&@```#EV`0`?````5'8!``T```!T=@$`!````()V`0`7````AW8!
M``0```"?=@$`!````*1V`0`1````J78!`!<```"[=@$`&````--V`0`4````
M['8!`!@````!=P$`%P```!IW`0`7````,G<!`!(```!*=P$`%````%UW`0`4
M````<G<!`!````"'=P$`%````)AW`0`B````K7<!`!$```#0=P$`%````.)W
M`0`A````]W<!`!(````9>`$`%0```"QX`0`2````0G@!`!0```!5>`$`%@``
M`&IX`0`=````@7@!`!4```"?>`$`%P```+5X`0`9````S7@!`!(```#G>`$`
M$@```/IX`0`=````#7D!``P````K>0$`%````#AY`0`7````37D!`!(```!E
M>0$`'````'AY`0`,````E7D!`$L```"B>0$`)P```.YY`0`2````%GH!`!0`
M```I>@$`%````#YZ`0`8````4WH!``T```!L>@$`$@```'IZ`0`3````C7H!
M`!$```"A>@$`%0```+-Z`0`9````R7H!`!0```#C>@$`3````/AZ`0`6````
M17L!``X```!<>P$`$@```&M[`0`4````?GL!`!D```"3>P$`*@```*U[`0`M
M````V'L!``8````&?`$`!`````U\`0`$````$GP!``0````7?`$`#````!Q\
M`0`,````*7P!``P````V?`$`#````$-\`0`*````4'P!`!(```!;?`$`"P``
M`&Y\`0`(````>GP!``@```"#?`$`"````(Q\`0`,````E7P!``H```"B?`$`
M'P```*U\`0`$````S7P!``0```#2?`$`$0```-=\`0`1````Z7P!`!<```#[
M?`$`&@```!-]`0`;````+GT!``(```!*?0$`!````$U]`0`,````4GT!``0`
M``!??0$`"````&1]`0`(````;7T!``0```!V?0$`"@```'M]`0`&````AGT!
M``H```"-?0$`"````)A]`0`$````H7T!``@```"F?0$`#@```*]]`0`*````
MOGT!``H```#)?0$`!````-1]`0`$````V7T!``@```#>?0$`"````.=]`0`.
M````\'T!``H```#_?0$`"`````I^`0`2````$WX!``\````F?@$`(0```#9^
M`0`&````6'X!`!@```!??@$`#@```'A^`0`,````AWX!`!X```"4?@$`%0``
M`+-^`0`(````R7X!``X```#2?@$`"````.%^`0`$````ZGX!`!T```#O?@$`
M%P````U_`0`$````)7\!``@````J?P$`%@```#-_`0`*````2G\!``@```!5
M?P$`"````%Y_`0`$````9W\!`!$```!L?P$`"````'Y_`0`.````AW\!``@`
M``"6?P$`"````)]_`0`1````J'\!``8```"Z?P$`'````,%_`0`I````WG\!
M`!,````(@`$`(P```!R``0`$````0(`!``<```!%@`$`'````$V``0`*````
M:H`!``0```!U@`$`"````'J``0`$````@X`!`!(```"(@`$`!````)N``0`(
M````H(`!``@```"I@`$`"````+*``0`(````NX`!``P```#$@`$`"````-&`
M`0`,````VH`!``\```#G@`$`!````/>``0`,````_(`!`!8````)@0$`!P``
M`""!`0`(````*($!``P````Q@0$`%0```#Z!`0`,````5($!``@```!A@0$`
M"0```&J!`0`)````=($!``P```!^@0$`*@```(N!`0`3````MH$!``@```#*
M@0$`"@```-.!`0`\````WH$!`!(````;@@$`,0```"Z"`0`>````8((!`!0`
M``!_@@$`!````)2"`0`@````F8(!`!4```"Z@@$`!@```-""`0`2````UX(!
M`!,```#J@@$`!````/Z"`0`-`````X,!``H````1@P$`"0```!R#`0`*````
M)H,!``D````Q@P$`"````#N#`0`*````1(,!``D```!/@P$`!P```%F#`0`$
M````88,!``<```!F@P$`!````&Z#`0`*````<X,!``@```!^@P$`!@```(>#
M`0`&````CH,!``\```"5@P$`"````*6#`0`-````KH,!`!````"\@P$`%P``
M`,V#`0`6````Y8,!`!````#\@P$`$`````V$`0`;````'H0!`!`````ZA`$`
M#P```$N$`0`4````6X0!``0```!PA`$`+@```'6$`0`-````I(0!``D```"R
MA`$`!````+R$`0`$````P80!``0```#&A`$`!@```,N$`0`&````TH0!``@`
M``#9A`$`"````.*$`0`+````ZX0!`!,```#WA`$`$0````N%`0`(````'84!
M``@````FA0$`"````"^%`0`(````.(4!`!4```!!A0$`!@```%>%`0`.````
M7H4!``8```!MA0$`!````'2%`0`(````>84!``@```""A0$`!````(N%`0`"
M````D(4!``X```"3A0$`"````**%`0`$````JX4!`!L```"PA0$`#@```,R%
M`0!.````VX4!``H````JA@$`!````#6&`0`$````.H8!``@````_A@$`!```
M`$B&`0`&````388!``0```!4A@$`"````%F&`0`0````8H8!``D```!SA@$`
M!@```'V&`0`$````A(8!``T```")A@$`%````)>&`0`:````K(8!`"$```#'
MA@$`&P```.F&`0`&````!8<!``(````,AP$`"`````^'`0`$````&(<!``0`
M```=AP$`"@```"*'`0`,````+8<!``4````ZAP$`#P```$"'`0`2````4(<!
M`!````!CAP$`&@```'2'`0`6````CX<!``X```"FAP$`#0```+6'`0`,````
MPX<!`!0```#0AP$`!````.6'`0`$````ZH<!``8```#OAP$`"P```/:'`0`$
M`````H@!``T````'B`$`$P```!6(`0`4````*8@!`!(````^B`$`"````%&(
M`0`0````6H@!``@```!KB`$`!````'2(`0`5````>8@!``L```"/B`$`%```
M`)N(`0`(````L(@!``@```"YB`$`"````,*(`0`(````RX@!``\```#4B`$`
M(````.2(`0`/````!8D!``P````5B0$`$0```"*)`0`,````-(D!``D```!!
MB0$``@```$N)`0`$````3HD!`"$```!3B0$`%P```'6)`0`$````C8D!``0`
M``"2B0$`#@```)>)`0`$````IHD!`*````"KB0$`!````$R*`0`1````48H!
M``(```!CB@$`$````&:*`0`$````=XH!`!$```!\B@$``@```(Z*`0`(````
MD8H!``@```":B@$`$P```*.*`0`0````MXH!``4```#(B@$`$````,Z*`0`P
M````WXH!`!X````0BP$`+````"^+`0`A````7(L!`"$```!^BP$`+@```*"+
M`0`F````SXL!`"$```#VBP$`,0```!B,`0`A````2HP!`!T```!LC`$`'```
M`(J,`0`&````IXP!``@```"NC`$`!0```+>,`0`6````O8P!`!4```#4C`$`
M#0```.J,`0`1````^(P!``0````*C0$`!@````^-`0`(````%HT!`!`````?
MC0$`%0```#"-`0`5````1HT!`!T```!<C0$`!P```'J-`0`0````@HT!`"``
M``"3C0$`#@```+2-`0`.````PXT!``8```#2C0$`"````-F-`0`*````XHT!
M``\```#MC0$`,````/V-`0!I````+HX!`#X```"8C@$`"0```->.`0`(````
MX8X!``D```#JC@$`#````/2.`0`-`````8\!``@````/CP$`!````!B/`0`-
M````'8\!``P````KCP$`"0```#B/`0`.````0H\!``P```!1CP$`$P```%Z/
M`0`:````<H\!`$8```"-CP$`"````-2/`0`,````W8\!``H```#JCP$`$```
M`/6/`0`$````!I`!``0````+D`$`%````!"0`0`0````)9`!``@````VD`$`
M"````#^0`0`,````2)`!`!````!5D`$`'````&:0`0`<````@Y`!`!@```"@
MD`$`&````+F0`0`:````TI`!`!H```#MD`$`#@````B1`0`;````%Y$!`!``
M```SD0$`$````$21`0`.````59$!``X```!DD0$`"````'.1`0`.````?)$!
M``X```"+D0$`#````)J1`0`,````IY$!``\```"TD0$`#0```,21`0`1````
MTI$!`"$```#DD0$`"0````:2`0`$````$)(!``8````5D@$`&P```!R2`0`/
M````.)(!``\```!(D@$`#P```%B2`0`.````:)(!``X```!WD@$`#0```(:2
M`0`+````E)(!`!````"@D@$`%@```+&2`0`3````R)(!``T```#<D@$`$0``
M`.J2`0`-````_)(!``\````*DP$`$@```!J3`0`/````+9,!``\````]DP$`
M$0```$V3`0`$````7Y,!`"````!DDP$`#0```(63`0`0````DY,!`!(```"D
MDP$`"````+>3`0`/````P),!``8```#0DP$`!````->3`0`.````W),!`!``
M``#KDP$`!````/R3`0`,`````90!`!(````.E`$`!@```"&4`0`-````*)0!
M``0````VE`$`!````#N4`0`$````0)0!``0```!%E`$`"````$J4`0`(````
M4Y0!``@```!<E`$`"@```&64`0`*````<)0!``P```![E`$`$@```(B4`0`(
M````FY0!``@```"DE`$`"````*V4`0`(````MI0!``@```"_E`$`"````,B4
M`0`H````T90!``0```#ZE`$`$P```/^4`0`M````$Y4!`!D```!!E0$`#0``
M`%N5`0`/````:94!``H```!YE0$`"@```(25`0`$````CY4!`"<```"4E0$`
M!@```+R5`0`&````PY4!``D```#*E0$`#@```-25`0`4````XY4!`!8```#X
ME0$`$0````^6`0`$````(98!``@````FE@$`$````"^6`0`$````0)8!``@`
M``!%E@$`!@```$Z6`0`0````598!`!(```!FE@$`'P```'F6`0`:````F98!
M``0```"TE@$`!````+F6`0`(````OI8!``@```#'E@$`!@```-"6`0`(````
MUY8!``0```#@E@$`!@```.66`0`&````[)8!``0```#SE@$`"0```/B6`0`@
M`````I<!``0````CEP$`'P```"B7`0`*````2)<!``P```!3EP$`"````&"7
M`0`/````:9<!``T```!YEP$`$0```(>7`0`/````F9<!``\```"IEP$`#0``
M`+F7`0`1````QY<!`!8```#9EP$`!````/"7`0`2````]9<!``\````(F`$`
M"0```!B8`0`*````(I@!``H````MF`$`!````#B8`0`$````/9@!``0```!"
MF`$`"````$>8`0`M````4)@!``D```!^F`$`!````(B8`0`$````C9@!``(`
M``"2F`$`#````)68`0`,````HI@!``P```"OF`$`$P```+R8`0`"````T)@!
M``@```#3F`$`&P```-R8`0`#````^)@!``P```#\F`$`.0````F9`0`7````
M0YD!``0```!;F0$`!````&"9`0`(````99D!``T```!NF0$`.P```'R9`0`.
M````N)D!``\```#'F0$`$P```->9`0`3````ZYD!``L```#_F0$`#@````N:
M`0`@````&IH!``H````[F@$`#0```$::`0`$````5)H!``0```!9F@$`$@``
M`%Z:`0`D````<9H!`!T```"6F@$`%P```+2:`0`*````S)H!`!<```#7F@$`
M%````.^:`0`/````!)L!`!<````4FP$`&````"R;`0`7````19L!``P```!=
MFP$`!````&J;`0`2````;YL!``0```""FP$`!````(>;`0`)````C)L!``H`
M``"6FP$`(P```*&;`0`7````Q9L!`"````#=FP$`&@```/Z;`0`$````&9P!
M`"X````>G`$`"P```$V<`0`(````69P!`!,```!BG`$`*P```':<`0`1````
MHIP!``0```"TG`$`$@```+F<`0`$````S)P!``\```#1G`$`+@```.&<`0`$
M````$)T!``D````5G0$`&````!^=`0`7````.)T!`!8```!0G0$`!````&>=
M`0`$````;)T!`!X```!QG0$`-0```)"=`0`0````QIT!`!P```#7G0$`$```
M`/2=`0`&````!9X!``@````,G@$`!````!6>`0`(````&IX!``@````CG@$`
M!````"R>`0`$````,9X!`!\````VG@$`#P```%:>`0`/````9IX!``8```!V
MG@$`!````'V>`0`(````@IX!``0```"+G@$`!@```)">`0`(````EYX!``@`
M``"@G@$`"````*F>`0`$````LIX!``0```"WG@$`!````+R>`0`$````P9X!
M``0```#&G@$`!````,N>`0`5````T)X!`!````#FG@$`!````/>>`0`(````
M_)X!``@````%GP$`$`````Z?`0`.````'Y\!``L````NGP$`!````#J?`0`2
M````/Y\!``P```!2GP$`#@```%^?`0`2````;I\!`",```"!GP$`%0```*6?
M`0`5````NY\!`!4```#1GP$`$0```.>?`0`1````^9\!`!<````+H`$`$P``
M`".@`0`1````-Z`!``@```!)H`$`!````%*@`0`<````5Z`!``@```!TH`$`
M!````'V@`0`5````@J`!`!0```"8H`$`!P```*V@`0`/````M:`!``0```#%
MH`$`"````,J@`0`&````TZ`!``H```#:H`$`!@```.6@`0`4````[*`!``P`
M```!H0$`$@````ZA`0`$````(:$!``T````FH0$``@```#2A`0`9````-Z$!
M`!H```!1H0$`#0```&RA`0`:````>J$!`"$```"5H0$`"0```+>A`0`A````
MP:$!`!L```#CH0$`#0```/^A`0`7````#:(!`!P````EH@$`&P```$*B`0`@
M````7J(!``L```!_H@$`"P```(NB`0`B````EZ(!``H```"ZH@$`"P```,6B
M`0`/````T:(!`!````#AH@$`$0```/*B`0`+````!*,!``L````0HP$`"P``
M`!RC`0`;````**,!`!L```!$HP$`'P```&"C`0`;````@*,!`!P```"<HP$`
M'0```+FC`0`:````UZ,!`$@```#RHP$`$P```#ND`0`&````3Z0!``8```!6
MI`$`%@```%VD`0`3````=*0!`!<```"(I`$`%P```*"D`0`&````N*0!`"L`
M``"_I`$`+0```.ND`0`"````&:4!`!$````<I0$`%@```"ZE`0`9````1:4!
M``8```!?I0$`&````&:E`0`-````?Z4!``8```"-I0$`!@```)2E`0`,````
MFZ4!``T```"HI0$`!@```+:E`0`(````O:4!``8```#&I0$`$@```,VE`0`$
M````X*4!``8```#EI0$`!````.RE`0`&````\:4!``@```#XI0$`!`````&F
M`0`9````!J8!``(````@I@$`!````".F`0`*````**8!`!`````SI@$`!@``
M`$2F`0`$````2Z8!``8```!0I@$`!P```%>F`0`+````7Z8!`",```!KI@$`
M$P```(^F`0`F````HZ8!``X```#*I@$`+0```-FF`0`2````!Z<!``@````:
MIP$`!````".G`0`&````**<!``0````OIP$`"````#2G`0`$````/:<!``@`
M``!"IP$`!````$NG`0`0````4*<!`!0```!AIP$`!````':G`0`(````>Z<!
M``H```"$IP$`#0```(^G`0`,````G:<!``P```"JIP$`#````+>G`0`6````
MQ*<!``H```#;IP$`"````.:G`0`(````[Z<!``@```#XIP$`"`````&H`0`(
M````"J@!``8````3J`$`"````!JH`0`*````(Z@!``0````NJ`$`$P```#.H
M`0`,````1Z@!`#````!4J`$`#P```(6H`0`A````E:@!`!$```"WJ`$`!```
M`,FH`0`8````SJ@!``0```#GJ`$`$````.RH`0`*````_:@!`!X````(J0$`
M'@```">I`0`<````1JD!`!D```!CJ0$`&@```'VI`0`=````F*D!``@```"V
MJ0$`!0```+^I`0`&````Q:D!``T```#,J0$`!````-JI`0`$````WZD!``0`
M``#DJ0$`"@```.FI`0`$````]*D!``8```#YJ0$`#`````"J`0`3````#:H!
M``0````AJ@$`%````":J`0`(````.ZH!``0```!$J@$`!````$FJ`0`+````
M3JH!``0```!:J@$`%````%^J`0`$````=*H!``0```!YJ@$`"````'ZJ`0`$
M````AZH!`!````",J@$`$P```)VJ`0`;````L:H!`!4```#-J@$`%0```..J
M`0`8````^:H!`"8````2JP$`%0```#FK`0`1````3ZL!`!H```!AJP$`+@``
M`'RK`0`T````JZL!`!,```#@JP$`#0```/2K`0`$`````JP!``0````'K`$`
M$0````RL`0`(````'JP!``@````GK`$`*P```#"L`0`6````7*P!`"D```!S
MK`$`+P```)VL`0`$````S:P!``P```#2K`$`!@```-^L`0`$````YJP!`!(`
M``#KK`$`"@```/ZL`0`(````":T!``@````2K0$`!````!NM`0`(````(*T!
M``0````IK0$`"````"ZM`0`(````-ZT!``P```!`K0$`#````$VM`0`:````
M6JT!`!8```!UK0$`#````(RM`0`$````F:T!`!8```">K0$`!@```+6M`0`"
M````O*T!``8```"_K0$`!@```,:M`0`$````S:T!``8```#2K0$`!@```-FM
M`0`(````X*T!``0```#IK0$`!````.ZM`0`(````\ZT!`"4```#\K0$`,@``
M`"*N`0`(````5:X!`!4```!>K@$`%0```'2N`0`*````BJX!``H```"5K@$`
M!````*"N`0`*````I:X!`"@```"PK@$`!````-FN`0`(````WJX!``@```#G
MK@$`"````/"N`0`&````^:X!`"<`````KP$`!````"BO`0`4````+:\!``H`
M``!"KP$`#@```$VO`0`7````7*\!`!$```!TKP$`&@```(:O`0`7````H:\!
M`!4```"YKP$`*@```,^O`0`D````^J\!`!H````?L`$`"````#JP`0`$````
M0[`!``@```!(L`$`#0```%&P`0`$````7[`!`!(```!DL`$`!0```'>P`0`(
M````?;`!`!(```"&L`$`"````)FP`0`.````HK`!``0```"QL`$`!````+:P
M`0`(````N[`!``8```#$L`$`"P```,NP`0`$````U[`!`!(```#<L`$`"P``
M`.^P`0`0````^[`!`!`````,L0$`!@```!VQ`0`&````)+$!``(````KL0$`
M!````"ZQ`0`,````,[$!``@```!`L0$`!@```$FQ`0`$````4+$!`!L```!5
ML0$`#P```'&Q`0`/````@;$!`!8```"1L0$`#@```*BQ`0`$````M[$!``H`
M``"\L0$`"@```,>Q`0`$````TK$!``P```#7L0$`!@```.2Q`0`7````Z[$!
M`"P````#L@$`%@```#"R`0`9````1[(!`#,```!AL@$`$@```)6R`0`2````
MJ+(!`!4```"[L@$`*````-&R`0`*````^K(!`!L````%LP$`!````"&S`0`'
M````)K,!``D````NLP$`"````#BS`0`X````0;,!``\```!ZLP$`%P```(JS
M`0`(````HK,!``0```"KLP$`!````+"S`0`(````M;,!`"$```"^LP$`%```
M`."S`0`(````];,!``P```#^LP$`%`````NT`0`2````(+0!``X````SM`$`
M%@```$*T`0`1````6;0!``P```!KM`$`0P```'BT`0`-````O+0!`!$```#*
MM`$`%0```-RT`0`-````\K0!`!$`````M0$`%P```!*U`0`0````*K4!``T`
M```[M0$`#````$FU`0`(````5K4!`!(```!?M0$`"````'*U`0`$````>[4!
M`"P```"`M0$`!````*VU`0`;````LK4!``\```#.M0$`"````-ZU`0`H````
MY[4!`"$````0M@$`(P```#*V`0`Z````5K8!``0```"1M@$`#````):V`0`<
M````H[8!`!,```#`M@$`!````-2V`0`(````V;8!`"$```#BM@$`!`````2W
M`0`?````";<!`"`````IMP$`"@```$JW`0`4````5;<!`!4```!JMP$`%@``
M`("W`0`4````E[<!`!(```"LMP$`%````+^W`0`(````U+<!``@```#=MP$`
M"````.:W`0`(````[[<!``H```#XMP$`!`````.X`0`7````"+@!``0````@
MN`$`%````"6X`0`$````.K@!``@````_N`$`$@```$BX`0`$````6[@!``@`
M``!@N`$`"0```&FX`0`3````<[@!`!4```"'N`$``@```)VX`0`$````H+@!
M``0```"EN`$`"````*JX`0`(````L[@!``H```"\N`$`'````,>X`0`2````
MY+@!``8```#WN`$`#````/ZX`0`(````"[D!`!,````4N0$`$0```"BY`0`L
M````.KD!``8```!GN0$`!@```&ZY`0`$````=;D!``H```!ZN0$`#@```(6Y
M`0`(````E+D!``P```"=N0$`"````*JY`0`(````L[D!``8```"\N0$`!```
M`,.Y`0`4````R+D!``0```#=N0$`"````.*Y`0`"````Z[D!``0```#NN0$`
M$@```/.Y`0`(````!KH!``0````/N@$`!@```!2Z`0`&````&[H!`!@````B
MN@$`"@```#NZ`0`&````1KH!`!````!-N@$`!````%ZZ`0`$````8[H!`#\`
M``!HN@$`!````*BZ`0`$````K;H!`!D```"RN@$`)0```,RZ`0`1````\KH!
M`!D````$NP$`)0```!Z[`0`5````1+L!`!@```!:NP$`#P```'.[`0`/````
M@[L!``P```"3NP$`!````*"[`0`$````I;L!``0```"JNP$``@```*^[`0`$
M````LKL!``D```"WNP$`!@```,&[`0`$````R+L!``8```#-NP$`!````-2[
M`0`$````V;L!`!$```#>NP$`!````/"[`0`6````];L!`!0````,O`$`#0``
M`"&\`0`2````+[P!`!0```!"O`$`'0```%>\`0`$````=;P!``@```!ZO`$`
M!````(.\`0`0````B+P!``0```"9O`$`"````)Z\`0`(````I[P!``0```"P
MO`$`!````+6\`0`5````NKP!`"<```#0O`$`!0```/B\`0`(````_KP!``@`
M```'O0$`$@```!"]`0`$````([T!``8````HO0$`$````"^]`0`(````0+T!
M``0```!)O0$`!@```$Z]`0`(````5;T!``P```!>O0$`!@```&N]`0`.````
M<KT!``\```"!O0$`$0```)&]`0`T````H[T!`!@```#8O0$`(0```/&]`0`<
M````$[X!`!8````PO@$`.P```$>^`0`&````@[X!`"8```"*O@$`'P```+&^
M`0`H````T;X!`#H```#ZO@$`#P```#6_`0`;````1;\!`!T```!AOP$`'0``
M`'^_`0`3````G;\!`!$```"QOP$`&0```,._`0`;````W;\!`!4```#YOP$`
M!@````_``0`P````%L`!`&4```!'P`$`'@```*W``0`O````S,`!`#$```#\
MP`$`+P```"[!`0`(````7L$!``8```!GP0$`%P```&[!`0`7````AL$!`!8`
M``">P0$`$P```+7!`0`3````R<$!``@```#=P0$`!@```.;!`0`?````[<$!
M`!,````-P@$`&0```"'"`0`8````.\(!``T```!4P@$`$0```&+"`0!"````
M=,(!`!(```"WP@$`(P```,K"`0`D````[L(!`"4````3PP$`'P```#G#`0`<
M````6<,!`"0```!VPP$`.0```)O#`0`O````U<,!`!<````%Q`$`&P```!W$
M`0`B````.<0!`#@```!<Q`$`;0```)7$`0`Q`````\4!`"L````UQ0$`*0``
M`&'%`0`E````B\4!`!X```"QQ0$`'@```-#%`0`;````[\4!`!$````+Q@$`
M&0```!W&`0`;````-\8!`!L```!3Q@$`)````&_&`0`/````E,8!`#T```"D
MQ@$`$P```.+&`0`(````]L8!`&H```#_Q@$`,P```&K'`0`3````GL<!`"<`
M``"RQP$`+0```-K'`0`7````",@!``\````@R`$`)````##(`0`"````5<@!
M``@```!8R`$`!````&'(`0`(````9L@!``@```!OR`$`"````'C(`0`+````
M@<@!``0```"-R`$`#P```)+(`0`&````HL@!`$L```"IR`$`!````/7(`0`+
M````^L@!``L````&R0$`!P```!+)`0`$````&LD!``P````?R0$`!````"S)
M`0`1````,<D!``8```!#R0$`#@```$K)`0`&````6<D!``8```!@R0$`$@``
M`&?)`0`/````>LD!`!4```"*R0$`#````*#)`0`8````K<D!``\```#&R0$`
M#@```-;)`0`,````Y<D!``0```#RR0$`!0```/?)`0`/````_<D!`!`````-
MR@$`$@```![*`0`?````,<H!`!X```!1R@$`'P```'#*`0`.````D,H!`!0`
M``"?R@$`$@```+3*`0`2````Q\H!`!<```#:R@$`$@```/+*`0`2````!<L!
M`!@````8RP$`$0```#'+`0`=````0\L!`!H```!ARP$`$@```'S+`0`1````
MC\L!`!(```"ARP$`%@```+3+`0`7````R\L!`!(```#CRP$`%0```/;+`0`3
M````#,P!`!`````@S`$`$0```#',`0`2````0\P!`!<```!6S`$`$@```&[,
M`0`2````@<P!``\```"4S`$`#@```*3,`0`6````L\P!`"<```#*S`$`&```
M`/+,`0`6````"\T!`!X````BS0$`'P```$'-`0`8````8<T!`!,```!ZS0$`
M$@```([-`0`7````H<T!`"(```"YS0$`%@```-S-`0`$````\\T!``@```#X
MS0$`!`````'.`0`>````!LX!`!L````ES@$`!@```$'.`0`.````2,X!`"<`
M``!7S@$`%0```'_.`0`4````E<X!`"0```"JS@$`!````,_.`0`&````U,X!
M`"4```#;S@$`)`````'/`0`.````)L\!``\````USP$`%P```$7/`0`2````
M7<\!``8```!PSP$`C0```'?/`0`(````!=`!``X````.T`$`!@```!W0`0`$
M````)-`!``<````IT`$`"@```#'0`0`,````/-`!`!D```!)T`$`#P```&/0
M`0`$````<]`!`",```!XT`$`#````)S0`0`,````J=`!`!````"VT`$`!0``
M`,?0`0`.````S=`!``@```#<T`$`-0```.70`0`?````&]$!``H````[T0$`
M"@```$;1`0`*````4=$!`!T```!<T0$`#````'K1`0`-````A]$!``H```"5
MT0$`"@```*#1`0`7````J]$!``L```##T0$`"````,_1`0`&````V-$!``\`
M``#?T0$`%0```._1`0`1````!=(!``0````7T@$`$@```!S2`0`&````+](!
M`!@````VT@$``@```$_2`0`(````4M(!`!(```!;T@$`!````&[2`0`4````
M<](!`"0```"(T@$`!````*W2`0`(````LM(!``@```"[T@$`"````,32`0`%
M````S=(!``8```#3T@$`#P```-K2`0`/````ZM(!``<```#ZT@$`#`````+3
M`0`*````#],!`"8````:TP$`(P```$'3`0`&````9=,!``@```!LTP$`'0``
M`'73`0`$````D],!`!L```"8TP$`$0```+33`0`$````QM,!``8```#+TP$`
M!@```-+3`0`(````V=,!``P```#BTP$`$````._3`0`$`````-0!``0````%
MU`$`!`````K4`0`$````#]0!``D````4U`$`"````![4`0`1````)]0!`!(`
M```YU`$`&0```$S4`0`C````9M0!``\```"*U`$`#P```)K4`0`(````JM0!
M`"(```"SU`$`!````-;4`0`3````V]0!`",```#OU`$`"````!/5`0`(````
M'-4!``4````EU0$`"````"O5`0`"````--4!``8````WU0$`"````#[5`0`%
M````1]4!``8```!-U0$`!````%35`0`(````6=4!``0```!BU0$`"@```&?5
M`0`*````<M4!`!0```!]U0$`$P```)+5`0`5````IM4!``T```"\U0$``@``
M`,K5`0`"````S=4!``P```#0U0$`!````-W5`0`,````XM4!``(```#OU0$`
M"P```/+5`0`]````_M4!``L````\U@$`(0```$C6`0`:````:M8!`"$```"%
MU@$`)0```*?6`0`+````S=8!`%,```#9U@$`%P```"W7`0!!````1=<!`"@`
M``"'UP$`(0```+#7`0`<````TM<!`!0```#OUP$`$`````38`0`5````%=@!
M`!4````KV`$`%0```$'8`0`5````5]@!`!4```!MV`$`$P```(/8`0`7````
ME]@!`!0```"OV`$`'@```,38`0`0````X]@!`!<```#TV`$`"`````S9`0!3
M````%=D!``@```!IV0$`+0```'+9`0`M````H-D!`%$```#.V0$`&P```"#:
M`0`V````/-H!`!,```!SV@$`$P```(?:`0`)````F]H!`$@```"EV@$`&```
M`.[:`0`D````!]L!`"L````LVP$`*P```%C;`0`;````A-L!`"(```"@VP$`
M)P```,/;`0`M````Z]L!`%D````9W`$`*P```'/<`0`E````G]P!`"L```#%
MW`$`)0```/'<`0`9````%]T!`!`````QW0$`&P```$+=`0`/````7MT!`!(`
M``!NW0$`.@```('=`0`/````O-T!`!4```#,W0$`#````.+=`0`/````[]T!
M`!$```#_W0$`"@```!'>`0`*````'-X!``L````GW@$`$@```#/>`0`4````
M1MX!``8```!;W@$`"````&+>`0`*````:]X!``@```!VW@$`!@```'_>`0`&
M````AMX!``T```"-W@$`!@```)O>`0`&````HMX!``T```"IW@$`!@```+?>
M`0`&````OMX!``\```#%W@$`!@```-7>`0`-````W-X!``@```#JW@$`!@``
M`//>`0`/````^MX!``8````*WP$`!````!'?`0`$````%M\!``0````;WP$`
M!````"#?`0`&````)=\!`!,````LWP$``P```$#?`0`"````1-\!``0```!'
MWP$`$````$S?`0`3````7=\!``,```!QWP$``@```'7?`0`$````>-\!``<`
M``!]WP$`!@```(7?`0`)````C-\!``D```"6WP$`!@```*#?`0`&````I]\!
M``0```"NWP$`!````+/?`0`(````N-\!`!,```#!WP$``@```-7?`0`$````
MV-\!``8```#=WP$`(@```.3?`0`:````!^`!``8````BX`$`!@```"G@`0`&
M````,.`!``H````WX`$`!0```$+@`0`%````2.`!`!````!.X`$``0```.L$
M``#L!```A`$```T!``"M`P````````<#``"H`P``V08```D"```M`0``U`8`
M``````#T`@```0$``````````````````(@&````````2@0``!X&```/!P``
MFP$``((%````````EP,``#P%``#G!```M`8``!X$``"U!```IP8```````"[
M!0````````````!2`@``I`,```````!\`P``&@8``/T#````````608``-\&
M```]!```^`8``"(#``#P`0``6`4``&@&````````]P(``$D#````````N08`
M``````"L````$@4``!`#```@!P``V@$``$@%``#V!@```@0``*H#````````
MO0(```0"```'!0``H`4``-<$``!T`0``I@```%D'```5`0```````!`&``!D
M!0``+P8``"D#```(`0``&00```X#```]`@````````L```#D`P``IP$``%0&
M```-!P``M`(``)4"```L!```*@8```````````````````````!2!0``^0(`
M`','`````````````!$'``!D!```.P4``-8&``!B`@``2`<``"0&``#R`@``
M``````````#!!@``B@```````````````````/<!``"7!```3@<```````#:
M!@``8````"D"``!2!```'0(``!<$``#I`P```````%P'``!<!0``@00``!P!
M````````OP```.(%``"X!````````,L#```(!```9````$X!``!]````&0$`
M`-\#`````````````!0%````````_0```-L%````````2````/,!````````
MS@,``-X```#/!```9@```*,$``"K````-04``*L&````````````````````
M````=@0````!``#\`P``````````````````#`(``),#``"7`@``N0(``+X%
M``#Z!```#0````@````!!```=@,``)T!````````U````,\```#B````R`0`
M`.D&````````9P8`````````````708``/D#```:````QP``````````````
M70<``%H```#``@``'@(``#D!```H````#@(```8```#X`0``]@```)$#````
M````+@$``.$%````````_P4``"H'````````)P,``,P!````````````````
M``!M```````````````!!@``9@$``$<'``"^`0``T@4```````#A!@``H`8`
M`!4"``#O!0``P`8``/(#``">`@```````),!````````>0,``-@````5!@``
MU0,``*<#```]!P``.`,``-(&``"J`@``T@$``"<!````````H@```)4!````
M`````````)@$```4`0`````````````B!0``LP0`````````````@0,``#$!
M``!;````T@(``&P'``!:`P``SP4``.L````\!```ZP8```````"D!```V@(`
M`%$&``#`````800``(,%```5!0``'`0``````````````````$`````%````
M4P,```````",`P``<@0``&X#`````````````"0#````````6@<``/L"```G
M!```]@0``%`#````````60(``#D%```C!@``E`,``-@$``!L!```0P4``,\"
M``#3!@``)`(``/,"``"S`P``T`4``&D'``!F`@```````%P$``!G````4@8`
M`!@'```:`P```````-8$``"1!@```````"@#`````````````+P&````````
M`````)X%``#T`P```````*4```!L`P`````````````2````8`0``%`$``!V
M`0``(@<``,(&``!7!P``Z````,$%`````````````#H"``!/`@``*P0``"4$
M``#T`0``B0$```D%``!#`````````$@"``"Y`0``7@(``)0!``"@`@``K@8`
M`*4#`````````````)X```"7`0````````````".!`````````````"$!@``
MU`0``.0&``##`@``?@`````````-`P``500``%\$``"4````^08```@'``"M
M!@``)P4``$T&``#]!0```````*$```">!```(@$``'@````X`@```````(P%
M``"9`0``\P0``)8"``#J`0```````/L#``![`0``I0$`````````````````
M`'8%```V`P``@@$`````````````'@<```````#D`0``E@,```<$```[!P``
M`````%,`````````F@$``#\&``!:!0```````#@%``#G`@``H08``',!``"K
M`0``"P<```````#G`0``P@,``%<"```;````BP8``$\$```_`P``+@<``+\%
M``!F!P``2@,``)<%```D!P``;@0``)@"``!R````5`,``+0#``"W!@``MP$`
M`*@&````````5@8``#4$``#\`````````````````````````+@&````````
M`````.0```#^`P``-0<``(4%````````/P(``",%```'!P``<0```&4&``#-
M!0``[0(``+0!``"X`P``<`0``!8$``"A!```RP8``)4#``!T!@``````````
M``!_````B0``````````````&0````````"N`0``[P8```````"O`P``````
M`$(```#9````]@$````````T!@``7`8``(<$````````J`(``.H`````````
M`````.\!``#*!```B`0``#T!```M!0```````&4!``!!!```.0````````#M
M!@``3@8``&L$````````,@(``'H%``#;`P``504```P%``".`@``#`<``.L%
M```2!@``#@$``)0&```#`@```````%,"``!'`0``W`4``#8```!C`0``#P(`
M`"````!)`0``?`0``+$```"P`@```````"D'``!'!```N@8```````#'`@``
M$@0```````!5`````````+8%``#P!0``>@,`````````````H@4``,4$```'
M````L0,``(H#``":!0``208``$8$``!I!````````,4"```C`P``9`$``)`"
M````````+P(```````"H````A0```-L```!Z!@``^````'@&```4!P``.00`
M`'("``!I`0``]P``````````````808````````&`@``R0(``.,#``!Y`@``
MU`4```(!`````````````"@&`````````````"H$`````````````)````!O
M!P``XP(````````Q`@``_@$``*4%````````:P8```````!#`P``A`,``'0$
M``!Y!```,@4``'4$``#"!```.`<``#@!``"!!@``2P,``.,%````````>P``
M`"P#``#_````F`8``+T%``#S!0``,0```.<%````````;@$``.0"```\!P``
M!0(``/4"````````QP,``!H'``!!`@``,P(``.0%``"M!0``!`4``"H%``#4
M`P```````*L$```````````````````-`@``:@8````````#`0``OP,``)X&
M``"/`0``'P0``+````!^!@```````/$#``"P`P``&@(``.D"``"$!0``````
M`%@```#E````$0$``)D"``#$`P``'`,``)0%``````````````````!8`0``
M!08``/8%``"@`````````(X#``#/`0``/@,``&`"``#7`P``,P0`````````
M````@`(```````"#!```E@8``$D"``"2!`````````````!5`P``S0```#<&
M``!5`0``MP```#(#``"C!0``7@8``.$#```I`0``Q@4``'$&``#H`@``````
M````````````[0$``#,#```$!@``=`<``$`#``!P!P``5`(``"L`````````
M[0,``-@&````````/@`````````&!````````&D"````````=@(````````6
M!0``R`$``&<!````````GP$``.("````````;P(``#(&``!+`0``;@<``$`"
M``".!@``A0(``(T#``!)````O0,```````"P!```,`0``.@&``!1!P``W@(`
M`"0!``!.`@``\`,````&`````````````%T"``!\!0``N````#````!F!```
MT@0```````"T!0``I`$``*\&````````_`(``/D%``"P!0```````$`$``"Q
M`@``N@,``````````````````',#``#M!````````)T"``#+!0```````%@'
M``#P!```O`0```````#[!@``<`````````"G````V`(``$(#``#U!@``````
M`(<````P`P``R00````````)````7P,``&X&``"Z!````````&,$````````
M#P,```````#,`P```````&T&````````"`8``-L$``!)!0``U@,```````!,
M!```X@0``"<&``!]`P```````&0#```"!P``>@(``%$"``"/````Q0$```X`
M``!"!@``=@8``.4"````````8@,``,L"``#=`0```````.X&``#+!```.@0`
M`'$!``#%!@```````&0'``!%!P``2@(```````#C!@```````)H&````````
M+@8``#,&``";!```?P,``',%```%!P```````"`&```A`P``GP0``)8!```"
M!@``>@0``'`%````````Q@0``````````````````!L'````````Y@0``)D#
M````````AP,``+8#```.!@``I08``!H!```M`P``8@```&P&``"A`0``\0``
M`!('```8`0```````'\&````````H`0``&('``#1`P```````(0"``"3!@``
M1@4``&8#``#Y````F`,```````"8!0````````L$``!/````$0(``-`!``#E
M`P```P,``&(%``!Q!0``E`(``$0#``!Y!@``:`4``(8#``!-`0``````````
M```@!````````,D```#W`P``K0`````````A`0``Q`8``',$```V!P``$0,`
M````````````@P,``.D%``#/`P``_08```````!M`P``Q@(``*`#````````
MX`4``'(!````````1`````````"U`0``$`(``/8#``"N`P``7@<``-X%``"<
M!```+@0``"8!```R!```(@```)4$```&!@``)P(``.(!````````K`$`````
M```-!@``[@(``&(!```6!P````````0$`````````````!,&````````+`(`
M`),"```W`P``3P8`````````````4`(``'P`````````D`8```````!*````
M?@4``(T$```K!@``50<```````#M!0``%0,```````!J`P``4`<`````````
M`````````#`!``#R`0```@,```````#'!```^0$``(8!````````I@0``,P&
M``"6`````````-\"````````4@```-(```"$!```(@(``!L$``#;`@``CP0`
M`!D%```0!P``(@0``+D```#*!0````````````!4!P``-`0``!D&````````
MG`4`````````````R@8``"4%````````_0$``(@%``!!`P``/P<``&`&````
M````!@<```````#<`0`````````````H!P````````````!/!P``````````
M``!L````R04``/4#`````````````$X```"U!@``&@0``.8&``"$````@P``
M``H#``"A`@``400```````!M`0```````*8"``"[`@``1@<``)(```"O!```
MO````/$%``!\`0``'@$``&\&``!J!```G0,``),```#@`@``M@$```````#)
M!@``&`4``.<#``!N`@```````&\````4!@```````,X"````````*04``*("
M``!.!`````````````"K`P``]``````"``!K!0``?04``%$#``!H`@``?0(`
M`-H$``#F`@``30,```````!2`P``7@4``*P"``#F````ZP(``#X!```?`0``
M10$``!(!````````'`(``-@#``#,````K`4``,$!``")!0``1P(```````!&
M`P``"00```````#&`0```````,4#``"[!```'0$``*P$````````OP8``,8`
M``!L!0``(`$``````````````````+@!``"#`@``@`8``#T&``##!```I0(`
M`&D%`````````````,T!```3`@``@@```+P#``#D!````````'`!````````
M9P<``.X$``"O`@``!0,``/L$`````````````(T```!R`P``YP````,$```]
M!0``#@4``)L#````````C@4``%L'``#R!0```````-H#```T!P``,@<``,@`
M``#G!@``F00``(4&```E!@``Y@,``,0"````````QP$````````#!0``0@4`
M`````````````````$$````2`P``(0<``&T"``"V`@``````````````````
MY08``%\'``"8`0``_P(``.$```"F!@``P@(``($!``"&`@``W08````````9
M!P``FP8``#T#``")!@``J0`````````R`0``QP8``.X!``#+`0``_P0`````
M```*!```508``+,"`````````````)$%``#/!@````````````#+````&@4`
M`.(&```7!P```````'$#```N`@``'@4``$`'``"``P```````"T'``"Z`0``
M,P$``$D$``!9````7P4``#P#````````G`,```````".````W0(``%8!````
M````^P$```````"2!@``R@,`````````````+`$``/H```#$!0``E@0``-$%
M``"/`@```````(L#``"W`@`````````````U`@``"P$``%T```#7````````
M`#<%``#.!0```````(("``"R`P``#P4```@%````````6P8````````.!```
M80```%H!````````)0```*T!````````"P4``)(!``!W!P``4`$``%L"````
M````P`0``#@&``#0`P``&0(``#X'``#1`@```````#L"```!`@``DP0``#H%
M```+!@``'0````````#L!0``NP8``#<$``#,!```$00``)@```!J!P``````
M`"<'``#_`P``%@$````````"`@``'00````````W````````````````````
MO@8``%<$``!T````L08```X'``#?!```+P<```````#'!0```````*<$``!Y
M!0``10,``+8&```V`0``8`$`````````````(P0```````!C`@``AP4`````
M``#_!@``\@```&$!``"<`@``'````*X%``#J`P``L@8``!`$``!X!```9P4`
M`#`%```;!@``\0$``"H!``!6````\00``)(#````````9P,``&4'````````
M`````+8`````````-`(``"`%```P!P``'P4``!@`````````@@8```````"A
M!0``%@8``!4````O!0``+0(``,$$``#?`0``*00``.$"````````BP4`````
M````````HP```%@$``!H`0```````-X&``#9!0``R`,```````#H`P``````
M`-D"``!U!0``O@,``````````````````!4$```K`P``1`8```````"0`P``
M3`,``'0"```^`@````````@#```_!```8`<``"4'````````5P8``%X#``#9
M`P``4@<```````!U!P``N0,``-L!``#2`P``I``````````U`P``3`(``(`!
M``"&!@````````````"H!0`````````````?!@``P0,``+X"````````PP``
M`/(&```3!0``P0```%8#````````P`,```D!``#X!`````````````!O!0``
M`````.@$```;`0``=P0``,H"```D!0``2P0``$<#``"D`@``P`4``&T$``#F
M`0``KP```.H$```Y!P```````)L```!;`P``-0```",````[`0``MP4``+P!
M``#4`@```````(D$``#:!0``9P(```````##`0```````!@"````````:`0`
M`+4#```D!```M`0`````````````*@(``!,```"'!@```````-D!````````
M:0```'P&``#^!@``C`$``&D#``````````````````"1`@``````````````
M`````````"\````6`P``#`0```````!W`0```````&X%``".`0``#00``.4%
M````````>0$``/T"``!1`0```````$P```"I`0```````)D&``!Q!```````
M`-`"````````$@(`````````````\0(``*`!```G`````````(P$```[!```
M`````,H````S!P``\P````````!$!``````````````M!@``J0,``+`&``#?
M!0``"08``%0$``"Y!0``1@$``*@$``!E`P``+`4``.(#``"+!```O`(``%0`
M``!O`0``$0````````!?`@```````.X#``!-`@```````%,$``#3!0``$`$`
M``4!````````C`(``%\!````````?@$`````````````3`4``"$```"`!```
MW04```````#@`P``]`4``(D"``"7!@``_`8``%<!```<!0``S@```!L%```<
M!@```````*H``````````````"H#``#^`@``:`<``.\````Q!P``2P8``',&
M```3!P``/`(``.P&````````:08``*(#``":`P``CP4```\$``#Z`P``/P``
M`&H````@`P``*08``($"``!U`P````````````"/`P``7@$````````#!P``
MC04``"@!``#<!```@`4``)<``````````````'T!```4`@`````````````E
M`P``NP,``,,#```;`P``+P$```````"1`0``MP,``%,%``!=!0``1@```&4"
M`````````````#$%```=!0``W@,```0````'`@````````0!``!^!```Z00`
M``````!X`0``W@0``,0```!(!``````````````8!```*`4`````````````
M"`(``$8"``!%`@```````$4$``!0!0```````)P````3!```R0$```0'```W
M!P```````/4$``#$`0``AP(```````!6!P``B`$`````````!0``I`4``+`!
M``!/!0````````````"G`@```````*,#``!<`0``,0,``)4```#1!@``8P4`
M`+8$````````J00``!@&```\````]@(`````````````<P(``-D$``""`P``
MQ`0``*(!```Z!P``1`$``(L```!X!0``F04``*,"``!H`P``D0```-<"````
M`````````%L$```[!@``Z@(``/X$````````T````,,&``"_`@``W0,``(<!
M````````!@$``"@"```@`@``?`(```````````````````````"3!0``````
M`!$%``"S````I@$``$\#``"&!````````$L`````````B@8```````!_`@``
MNP```,4%````````#P$``"8%``"+`0``0`8``&0"``!9!0```````%,&``"%
M`0``4P$````````Q!@``.````"X```!K!P``+@,```````!_!0``````````
M```=!P``U0(```````!X`@```````!D#``":`@``M``````````7!@``````
M`%\```#H!0``^P4``,,%``#<````2@8``,8&```Y`P````````````!Z`0``
MI00``&,&``"S!0``^P```/`"``#!`@``0P$``*,&`````````````#$$```M
M````$08```P&``!^`P``\08``)T$``#7`0``1`4`````````````A@```&4$
M``!P!@``^@(``*8#``!``0``!`,```,```!;!0``R0,``!0`````````````
M`.P"``!A`@```````````````````````.L#``#%````.P```/0$``#6!0``
M`````-$!``!9!```VP8`````````````]P0``&H%````````90```$,$``#Z
M`0```````#H````K`0``U@$``'`"``"F!0``]`8````````L!@``^@4``,T&
M``#?`````@4``"0`````````TP,``%P"```C`0``)@,``/@"``"Z````\P8`
M``````"C`0````````````!$!P``3`$```````#-!```70,``)$$``![!```
M```````````0````P@4``.$!``!,!P````````````!C````P`$``+T!````
M`````````+$!```=`P``=0$``#8"``!Y!P``TP````8#``"K!0``````````
M`````````````$L%```U`0```````*<%``!+!P``.P,```8%``!.`P``-`,`
M`'0%`````````````"L%``!"!```S0,````````7````30``````````````
M5P````````"X!0``-@8```````#1````8@8``-@!``!A!P``9@4```````"D
M!@``K00```````!5`@``S`4``)`!```E`0``0P<``.$$``"?`@``G04```$'
M```R`````````%L!``!J`@`````````#`````````````(T!```%!0``````
M`($`````````J@8```````"J!```;0<```````"9`````````"8"```4`P``
M`````'D```!!`0``7@```#<!``"U`@```````%$%``"?````F@0``/X````\
M!@``U04``)T```!]!```2`$``'('``"Y!```5@0`````````````300``&L#
M``#0!```-`4```````!7`P````````P```!G!```Z`$``&8&``!0````````
M`!@#``!L`@``&P(```````!A`P```````(L"``!Z````30<``&$%````````
M`````#H&```M!````````#X%``#4`0```````*X$``#@!@``60$``'$"````
M````T`8```````"*`0```````)`%``#1!```;P,``.X```#P!@```````.P#
M```+`P``JP(``'(&``#U!0``-@4``*@!``"I!@``0@(``$(!``#7!0``G@$`
M``````"^!```L@(``!4'``!$`@``@04``&@````6`@```````"$%``!.!0``
M`04```````#5!```K@(``&($``"X`@``-@0``,T"``#@`0``+@4``%`&````
M````N@4``,8#``"N````#`,``.`$``!=`0``'08``)L%``!9`P``GP,``&T%
M````````B0,``"8'```>`P```````)T&``!8`P``````````````````````
M`-P"``#U````L@0``!8```!%!0``UP8``+P%```P`@``+````&4%```3`0``
M,P```!\"``!>!```[`$```````````````````````#<!@``?@(``'\!``!L
M`0``1P```",'``````````````````#3`@``B@(``-4````/````X```````
M```*!0``;@```%0!``#I`0``-`$```H&``"(``````````````![`@``````
M``````"#!@``R@$``$8&```?!P``"0,``/T$``#\!```*P<`````````````
M``````````#W!0``+P0``%8"``#:`````P8``"\#```-!0``10```(\&``#6
M`@```````-,!``"5!@``=@<``#T```"U!0``%P4``*P#``!C!P``NP$``#`&
M``#,`@``G`$``(@#``!X`P````````````!7!0``7`,`````````````*0``
M`'<#``!(`P```````$L"````````<0<``'<```"]````:P```$\!````````
M``````````"O`0``1P8``$4&``#8!0```````-4!````````2@<``!<#``"I
M!0``6`(````````_!0``!00``'0#``!#`@``-```````````````<`,``$('
M``#O!```B@0``/X%``!W`@``S@8``!<!``"#`0`````````````+`@``.08`
M`)H```#S`P``U@```!,#```J````[0```+T$``#\`0``D@(```````"I`@``
M?08``````````````````"4"``"L!@``MP0``$`%````````=08``/($``",
M!@```````-P#````````H@0``,X!`````````````)\%`````````````%,'
M``````````````(```"2!0``=P8`````````````%`0``.D````*`0``````
M`,@%````````+`<```$#```?````J@4``&,#``!X!P``:@$``&\$````````
M4@$``+$$``!!!@``2`8``"L"````````[````+T&``#=!````````"$"``#O
M`P``ZP$``%\&````````^`4``+(%``#F!0``W@$``.\"```,`0``````````
M``!S````/@8```H"``"0!```-08``"$&``![`P``@@0`````````````(@8`
M``````#J!@```````/P%``!D!@```````"8$``#E!```````````````````
M%P(``$D'```X!````````)4%```Y`@```````'8```#_`0``A0,```````#(
M`@``<@4```````#5!@```````"8&``#"`0``.@$`````````````XP``````
M``!:!@``G@,``)0$``!8!@```````.H%``"-`@```````'4```"*!0``S@0`
M`(````!@!0``GP8``#X$``!1````R`8`````````````(00``+\$````````
M```````'``"-!@``.@,``"8```!*!0```````#\!`````````````$,&``"Q
M!0``:P(``&`#``#3!```1P4``*$#``"<!@``6@(```````!=!```H@8`````
M````````K0(``.X%``"S`0``"0<``-T```#Z!@``XP0``!X```",````FP(`
M````````````7`````````![!@``004```````"(`@````````<!``"&!0``
M304``.4!``!:!`````````````"_`0``*`0``+X```!U`@``$`4``/`````'
M!@``J@$``*\%````````M0```)8%```<!P``(P(``/@#```W`@``2@$``+(!
M``#"````L@```$$'``!W!0``#P8```````!6!0``'P,```H'```\`0``XP$`
M``````!K`0``A00``'L%``!_!```3`8``+H"``#Y!`````0``/4!``"S!@``
M```````````*````,P4```````#W!@``5`4````@("U-+"`M+6UE<W-A9V4]
M34534T%'12`@57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T
M:&4@9&5F875L="!O;F5S+@`@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@
M=&AI<R!03R!F:6QE('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&\*("`@
M("`@("`@("`@("`@("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@9G)O
M;2!A(&1I9F9E<F5N="!B<F%N8V@@=&\*("`@("`@("`@("`@("`@("`@("`@
M("`@=&AE(&=E;F5R871E9"!C;VUP96YD:75M+@`@("UB+"`M+6)A<V4]+U!!
M5$@@($9U;&P@<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T
M:&%T('-H;W5L9"!B90H@("`@("`@("`@("`@("`@("`@('5S960N`"`@+6,L
M("TM8V]M<&5N9&EU;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O
M('1H:7,@8V]M<&5N9&EU;2!F:6QE"B`@("`@("`@("`@("`@("`@("`@("`@
M("!I;G-T96%D(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I
M;B!T:&4*("`@("`@("`@("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C
M=&]R>2X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E
M;F1I=6T@9FEL92!I;G-T96%D(&]F('1H92!D969A=6QT"B`@("`@("`@("`@
M("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E
M+W!O(&1I<F5C=&]R>2DN`"`@+60L("TM9&5B=6<@("`@("`@4VAO=R!E<G)O
M<B!M97-S86=E<R!F<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RX`("`M9"P@
M+2UD:7)E8W1O<GD]1$E2("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D
M:7)E8W1O<GDN`"`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@
M;65S<V%G92X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY('1H
M:7,@;&]C86QE+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@
M;&]C86QE+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A
M;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O
M;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-
M3T153$4@("`@0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R
M86YS;&%T:6]N<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@365R9V4@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S
M(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@("!5<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+@`@
M("UM+"`M+6UO9'5L93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@
M9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6XL("TM;F\M8V]M<&5N9&EU
M;2`@("!$;VXG="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP
M96YD:75M+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@
M8V]M<&5N9&EU;2X`("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A
M;G-L871I;VX@<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N`"`@+70L("TM
M=&5S="`@("`@("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O
M;B=T(')U;B!A;GET:&EN9RX`("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/
M(&9I;&5S('5P(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R
M:65S+@`@(&-O;6UI="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE
M($-64R!S97)V97(N`"`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@
M=&\@=&AE($-64R!S97)V97(N`"`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@
M8V]M<&5N9&EU;2!F:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE
M"B`@("`@("`@("`@("`@8W5R<F5N="!C;VUP96YD:75M+@`@(&5X=')A8W0@
M("`@($=E;F5R871E(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RX`("!H96QP
M("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+@`@(&EN:70@("`@("`@
M($-R96%T92!O;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE
M+B!787)N:6YG.B!4:&ES"B`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@
M97AI<W1I;F<@4$\@9FEL97,@;V8@=&AI<R!L;V-A;&4N`"`@;6%K92`@("`@
M("`@0G5I;&0@8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!0
M3R!F:6QE<RX`("!M86ME+6AE;'`@("!-87)K(&%L;"!E;G1R:65S(&EN('1H
M92!834P@:&5L<"!F:6QE(&)E:6YG('5P+71O+61A=&4@86YD"B`@("`@("`@
M("`@("`@<')E<&%R92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N
M(&]F('5P9&%T92UH96QP+B!9;W4*("`@("`@("`@("`@("!S:&]U;&0@;VYL
M>2!R=6X@;6%K92UH96QP($%&5$52('5P9&%T92UH96QP(&%N9"!R979I<VEN
M9R!T:&4*("`@("`@("`@("`@("!H96QP(&9I;&4N`"`@;65R9V4@("`@("`@
M365R9V4@=&AE(&-U<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/
M('1E;7!L871E(&9I;&4N`"`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD
M(&UE<F=E('-E<75E;G0N`"`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W
M(&%N9"!C:&%N9V5D(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L
M<`H@("`@("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@
M97AI<W1I;F<@;VYE<RX`("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M
M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H
M)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H
M=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"5D("5S(&%N
M9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E9"!O9B`E9"!E;G1R:65S(&UA<FME
M9"!A<R!U<"UT;RUD871E`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E
M<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S
M(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI
M<W1S+@`E<R!A="`E<R`E<P`E<R!D;V5S(&YO="!E>&ES="!O<B!I<R!N;W0@
M97AE8W5T86)L92X`)7,@:7,@;F]T('=R:71A8FQE+@`E<R!I<R!R97%U:7)E
M9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@;F]T(&9O=6YD+B!2=6X@
M)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I<G-T+@`E<R!T;R`E<R!O9B`E<P`E
M<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E
M<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@=6YA8FQE('1O(&QO860@9')I=F5R
M.B`E<P`G)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC92X`)R5S)R!I<R!N;W0@
M8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"<E<R<@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E871E9#H@
M)7,N`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`
M+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0`Q,B!(
M;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`
M/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N"D]P96YI;F<@
M=&%G(&9O=6YD(&EN(&QI;F4@)60N`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`041322!E<G)O<B`E<RX`04T@0VQO=61S`$%-
M($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R
M<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S
M8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@1&5N:65D+@!!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN
M`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R
M;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI
M<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@)R5S)P!!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O("<E<R<`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`
M061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@
M;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("<E<R<@=&\@=&AE('-Y
M<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF
M;W)M871I;VXZ("5S+@!!9&1E9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;&]G(&EN(&YO=RX`061D:6YG(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y
M.@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!"
M;V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S
M97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L
M9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I
M8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O
M=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R
M;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R
M;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L
M=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A
M;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD
M($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A
M=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`
M07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`
M07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A;F0@86YY
M('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU3
M0TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!
M<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O
M;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T
M97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"86-K96YD(&YO="!C;W)R
M96-T;'D@:6UP;&5M96YT960N`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO
M<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M
M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N
M;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N
M:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L
M:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@
M5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI
M8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!"
M;W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U:6QD
M:6YG($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`0G5I;&1I;F<@;&]C86QE
M("5S+BXN(`!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@
M4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#
M86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@
M<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D
M80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A
M8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE
M<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@4&%S
M<W=O<F0`0VAA;F=E('!A<W-W;W)D(&]N.@!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@<&%S<W=O<F0`0VAA
M;F=I;F<@<&%S<W=O<F0@;VX@)7,`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C
M:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E
M<F9O<FT@870@=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO
M;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET
M:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE86YI;F<@=7`@4$\@9FEL97,@9F]R
M(&UO9'5L92`E<RXN+@!#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@`$-L96%R
M`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R
M('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@
M0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO
M=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I
M80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#
M;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M
M;6%N9"!O<'1I;VYS.@!#;VUM86YD<SH`0V]M;65N=`!#;VUM:71T:6YG.@!#
M;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&]S92!-97-S86=E("@E
M<RD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@
M)7,`0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&YE=R!P87-S=V]R9#H`0V]N
M9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN
M96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!#;VYT96YT<R!O9B`G)7,G`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;W!Y
M`$-O<'D@<V5L96-T:6]N`$-O<'EI;F<@)7,@=&\@)7,`0V]S=&$@4FEC80!#
M;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E
M;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E
M+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("<E
M<R<@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<P!#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SH`0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@)R5S)RX`0V]U;&0@;F]T(&UK9&ER("<E
M<R<N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B`G)7,G
M(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RX`0V]U
M;&0@;F]T(&]P96X@<&EP92!T;R!S;6)P87-S=V0N`$-O=6QD(&YO="!R96%D
M("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@)R5S)RX`
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`G)7,G+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@
M)R5S)RX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@
M8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R
M961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO
M;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL
M:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A
M=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T
M:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E
M<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A
M=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M
M:7-S:6]N<P!$969I;FET:6]N<P!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T
M92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E
M(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)P!$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_
M`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T
M:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE
M=&4@=&AI<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N`$1E;&EV97)Y('1I
M;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M
M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P
M;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H
M="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I
M<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@
M9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N
M;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N
M(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L
M:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`
M161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET('!E<FUI<W-I;VYS(&9O<B`G)7,G
M`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M86EL
M`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M
M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E
M+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS
M97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT
M/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%
M;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H
M('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_
M)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=')I97,Z("5D('1O=&%L
M+"`E9"!U<"UT;RUD871E+"`E9"!N97<L("5D(&-H86YG960L("5D('5N:VYO
M=VX`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!S96YD
M:6YG(&1A=&$@=&\@<VUB<&%S<W=D+@!%<G)O<B!W<FET:6YG("<E<R<N`$5R
M<F]R.B``17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U
M(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E
M<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R
M>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AE8W5T:6YG.@!%
M>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&ER871I;VX@
M1&%T90!%>'!O;F5N=`!%>'1R86-T:6YG(&9R;VT@)7,N+BX@`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F
M<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@
M(B5S(BX`1F%I;&5D('1O('9E<FEF>2!O;&0@<&%S<W=O<F0N`$9A:6QU<F4@
M:6X@8VAA;F=I;F<@<&%S<W=O<F0@;VX@)7,Z("5S`$9A:7(`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z
M`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO
M=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@
M0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA
M9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T
M($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H
M5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O
M<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O
M="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&
M;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&;W5N9"!A<'!L
M:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C=&]R:65S.@!&<@!&<F%M97,`1G)A
M;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H
M(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&
M<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE
M`$9U>GIY`$=A8F]N`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;F5R871I;F<@<W1A='5S(&9O
M<B!M;V1U;&4@)7,N+BX`1V5O<F=I80!'97)M86YY`$=E=&]P="!%<G)O<CH@
M`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@
M4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R
M965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI<W-I;VYS`$=R;W5P
M<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E
M<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`
M1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5%10($%U=&AE;G1I8V%T:6]N
M(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/
M+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP
M97(`2&5L<&5R(&%P<&QI8V%T:6]N('1O(&-R96%T92!A;F0@;6%I;G1A:6X@
M=')A;G-L871I;VYS(&9O<B!T:&4@2&]R9&4*9G)A;65W;W)K(&%N9"!I=',@
M87!P;&EC871I;VYS+@I&;W(@86X@:6YT<F]D=6-T:6]N(')E860@=&AE(&9I
M;&4@4D5!1$U%(&EN('1H:7,@9&ER96-T;W)Y+@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(:7-T;W)Y(&5N
M=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$AO7VUE`$AO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO
M;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E('1R86YS;&%T:6]N
M(&=E;F5R871O<@!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S
M86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@
M;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@4W5C8V5S<V9U;&QY('-Y;F-H<F]N:7-E9"`E<R`B)7,B`$AO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S
M.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT
M86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I
M9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L
M=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S
M`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!
M4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U
M;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D
M($-)1%(@8FQO8VLN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS
M($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S
M(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E
M;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM
M86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R
M>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T
M960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T
M97(`26YC;W)R96-T(%!A<W-W;W)D`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A
M;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);FET:6%L:7II
M;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC
M871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T
M960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE
M(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!)
M;G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI
M9"!R96-I<&EE;G0Z("<E<R<`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI
M9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N
M=&]R>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)
M<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET
M86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E3
M3RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE
M=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H
M`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F
M`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA
M;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@
M2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E
M<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA
M='9I80!,87<`3&%Y;W5T`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T
M('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY
M80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H
M="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E
M<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N
M;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<`3&EN:W,`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`
M3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES
M="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A
M9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C
M86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A
M<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`
M3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@
M;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`
M34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N
M`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K
M92!L:6Y?:RXN+@!-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A
M;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA:VEN9R!D:7)E8W1O
M<GD@)7,`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G
M:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES
M;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-
M875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T
M<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP
M(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE
M9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97)G:6YG
M(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN
M9R!L;V-A;&4@)7,N+BX@`$UE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O
M('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG('1R86YS;&%T:6]N(&9O<B!M
M;V1U;&4@)7,N+BX`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T
M:&]D("<E<R<@:7,@;F]T(&1E9FEN960`365T<FEC`$UE>&EC;P!-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER
M<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%
M05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL
M92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U
M;&4`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L
M:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA
M<V5S`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY
M(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P
M`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O
M<"!D;W=N(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY
M(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4
M($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.
M971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P
M92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE
M='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE
M='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E
M<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E
M<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0Z`$YE
M=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O
M<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI
M=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H
M86YG92X`3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E
M;&]W('1H:7,@;&5V96PN`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN`$YO(&-O;6UA;F0@<W!E8VEF:65D+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I
M;F%T:6]N('-U<'!L:65D+@!.;R!E;G1R>2!W:71H('1H92!I9"`G)7,G(&5X
M:7-T<R!I;B!T:&4@;W)I9VEN86P@:&5L<"!F:6QE+@!.;R!F:6QE('5P;&]A
M9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A;&4@<W!E8VEF:65D+@!.;R!L
M;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S
M86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P
M96-I9FEE9"X`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@
M8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S
M87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG
M;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@<W5C:"!B86-K96YD("<E<R<@
M9F]U;F0N`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C
M86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A
M;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU
M<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L
M86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O
M<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO
M=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I8V4`3F]V96UB
M97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU
M;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE
M8W0@0W)E871O<@!/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<P!/8W1A;`!/
M8W1O8F5R`$]F9FEC90!/;&0@<&%S<W=O<F0Z`$]M86X`3VYL>2!)34%0('-E
M<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M
M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<'1I
M;VYS.@!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L
M(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R
M;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N
M8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@
M4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3
M=&]R;7,`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S
M=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'
M=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V0@:7,@;F]T('!R
M;W!E<FQY(&-O;F9I9W5R960N`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@
M;VX@)7,N`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!M;V1U;&4@8V%N
M)W0@9FEN9"!T:&4@<W5P<&QI960@8FEN+@!087-S=V]R9"!M;V1U;&4@:7,@
M;6ES<VEN9R!R97%U:7)E9"!P87)A;65T97)S+@!087-S=V]R9"!M;V1U;&4@
M:7,@;6ES<VEN9R!T87)G970@<&%R86UE=&5R+@!087-S=V]R9"!M;V1U;&4@
M:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960`4&%S<W=O<F0@;6]D=6QE(&ES
M(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D+@!087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I
M<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M
M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG
M(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`G)7,G(&YO="!D96QE=&5D
M+@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)M:7-S:6]N<R!F;W(`
M4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H
M;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT
M:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5P;W)T
M(&%N>2!B=6=S('1O(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL
M<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`
M4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE
M8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U
M97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD
M(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO
M=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO
M=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G9')I=F5R<R<@:7,@;6ES8V]N9FEG=7)E
M9"!I;B!#;VUP;W-I=&4@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y
M<&4G(&YO="!S<&5C:69I960@:6X@4&%S<W=D(%-13"!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!344P@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O
M<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E<W5L=',@*&EN8VQU
M9&EN9R!(;W)D92DZ`%)E<W5L=',Z`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI
M;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2
M;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T
M871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P
M97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G
M90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-
M97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`
M4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I
M80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@
M36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED
M97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/
M<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z("<E<R<N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E
M87)C:`!396%R8V@@16YG:6YE<P!396%R8VAI;F<@2&]R9&4@87!P;&EC871I
M;VYS(&EN("5S`%-E87)C:&EN9R!G971T97AT(&)I;F%R:65S+BXN`%-E;&5C
M="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!3
M96QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S
M97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@
M86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P
M;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I
M82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R
M;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@240@97AP:7)E9"X`4V5T
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W
M`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('!I8VME<@!3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E
M('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R
M<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`
M4VAR:6YK`%-I97)R82!,96]N90!3:6=N('5P`%-I9VX@=7`@:68@;F]T(')E
M9VES=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P
M;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3:VEP<&5D+BXN`%-L;W9A:VEA
M`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@
M4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``
M4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R
M9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`
M4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M
M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L
M=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87)T
M('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T871U<R!F;W(@;&]C
M86QE("5S+BXN(`!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I
M:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`G)7,G(&YO="!F
M;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D
M("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL
M('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U
M8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@)R5S)RX`4W5C8V5S
M<V9U;&QY(')E;6]V960@)R5S)R!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`G)7,G`%-U8V-E<W-F
M=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`
M4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T
M`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M
M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I
M='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@
M07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O
M<FUS`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O
M<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II
M:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!4
M87-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E
M;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@)R5S)R!N;W0@9F]U
M;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H96QP(&9I
M;&4@9F]R("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O
M;F4N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL
M92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!H96QP(&9I
M;&4@)7,@9&ED;B=T('-T87)T('=I=&@@/#]X;6P`5&AE(&ED96YT:71Y("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`
M5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E
M;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@
M;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA
M>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H
M96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D
M(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A
M8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<FEG
M:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N
M;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S
M(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@
M97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@
M<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA
M8FQE+@!4:&5M97,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA
M;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D
M("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`
M5&AE<F4@9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+@!4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TN
M("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S
M>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F
M;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R
M;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG("<E<R<Z("5S`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E
M('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C
M="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@
M9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE("5S
M+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@9FQA9R`M
M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S
M97(N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A
M9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI
M<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I
M<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S8W)I<'0@;75S="!B92!R=6X@
M9G)O;2!T:&4@8V]M;6%N9"!L:6YE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O
M;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N
M<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4
M:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4
M:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@
M:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K
M97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4
M;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O
M<"D`5')A;G-L871E9`!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L
M<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R
M:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP
M92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),.@!59V%N9&$`
M56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!3
M4TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@9FEL93H@`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET
M960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S
M`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5
M;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&-O
M;6UA;F0Z("5S`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@
M=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5
M;G-U<'!O<G1E9"!%>'1E;G-I;VX`56YT<F%N<VQA=&5D`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E('5S97(`57!D871E9"`G)7,G+@!5<&1A=&EN9R`E<R!H
M96QP(&9I;&4@9F]R("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO
M860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M
M8F5R<P!5<G5G=6%Y`%5S86=E.@!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!
M9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92X`57-E<B!N;W0@9F]U;F0`57-E<B!N;W0@9F]U;F0N`%5S97(@<&5R
M;6ES<VEO;G,`57-E<FYA;64`57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T
M<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,`57-E<G,@:6X@=&AE('-Y
M<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A
M;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU
M97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E
M<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@
M2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`
M5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V%R;FEN9SH@`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E
M8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H
M('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED
M=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`
M5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K($%D9')E
M<W,`5V]R:R!0:&]N90!7<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S
M+@!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($ME
M>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A
M(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN
M(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A
M8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U
M(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@
M;F%M92X`66]U(&-A;B=T(&-H86YG92!P87-S=V]R9"!F;W(@=7-E<B`E<P!9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E
M96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O`%EO=2!M=7-T(&=I=F4@>6]U<B!C=7)R96YT('!A<W-W;W)D
M`%EO=2!M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O<F0`66]U(&UU<W0@<V5L
M96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F
M;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!M
M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9`!9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!
M9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S
M($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA
M;64Z`%EO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@86YD(&1O97,@
M;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+@I.;W0@86QL('-T<FEN9W,@=VEL
M;"!B92!E>'1R86-T960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO;F<[('!A<W-W;W)D<R!M
M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T97)S(&QO;F<A`%EO=7(@
M;F5W('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,A("!.;W0@8VAA
M;F=E9"$`66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O('-I;7!L92!T;R!G=65S
M<RX@3F]T(&-H86YG960A`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8F4@870@
M;&5A<W0@)60@8VAA<F%C=&5R<R!L;VYG(0!9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&)E(&1I9F9E<F5N="!F<F]M('EO=7(@8W5R<F5N="!P87-S=V]R9`!9
M;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP
M:&%B971I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O
M;G1A:6X@870@;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,N`%EO
M=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L96%S="`E9"!D:69F
M97)E;G0@='EP97,@;V8@8VAA<F%C=&5R<RX@5&AE('1Y<&5S(&%R93H@;&]W
M97(L('5P<&5R+"!N=6UE<FEC+"!A;F0@<WEM8F]L<RX`66]U<B!N97<@<&%S
M<W=O<F0@;75S="!C;VYT86EN(&%T(&QE87-T("5D(&QO=V5R8V%S92!C:&%R
M86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@;G5M97)I8R!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M
M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@=7!P97)C87-E(&-H87)A8W1E<G,N
M`%EO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!L97-S('1H86X@)60@
M=VAI=&5S<&%C92!C:&%R86-T97)S+@!9;W5R(&YE=R!P87-S=V]R9"!M=7-T
M(&YO="!C;VYT86EN('=H:71E<W!A8V4@8VAA<F%C=&5R<RX`66]U<B!N97<@
M<&%S<W=O<F1S(&1I9&XG="!M871C:`!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C
M:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S
M=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E
M<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M
M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#
M3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E
M(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN
M+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T
M=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A
M;B!E<G)O<B!H87,@;V-C=7)E9#H`8V%L96YD87(`8VQI8VL@:&5R90!D;VYE
M`&9A:6QE9`!F:6QE`&9O=6YD.B``9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<P!H.@!H:`!I;6UE9&EA=&4`:6YL:6YE`&QD87!?<W1A<G1?=&QS(&9A:6QE
M9`!L:6YE<UT`;6T`;F%M90!N;W0@8VAA;F=E9`!N;W0@9F]U;F0`;F]T(&EM
M<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT
M`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA
M($A45%``<W,`<W1E861Y`'1A<VL@;&ES=`!T:&4@2&]R9&4@4$\@9FEL92!F
M;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`='EP92!T:&4@<&%S
M<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7!D871E
M9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED
M+59E<G-I;VXZ('!A<W-W9"`R+C(M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3`X+3(Q(#$S.C$V*S`X,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP,BTQ
M.2`Q,#HR,RTP-C`P"DQA<W0M5')A;G-L871O<CH@1&%V:60@0VAA;F<@/&1A
M=FED0'1M=BYG;W8N='<^"DQA;F=U86=E+51E86TZ(%1R861I=&EO;F%L($-H
M:6YE<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0FEG-0I#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@("U-+"`M+6UE<W-A9V4]
M34534T%'12`@J,^ESK-OK=.THZ7FL%2NIZ1WM,"E3KEWLUVP5*ZG+@`@("UA
M+"`M+6%D9#U&24Q%("`@("`@(""W<[Q7IKD@4$\@P,FH[+KUK6ZDI"X@L6"E
MSJGSL4ZDHZ90JJFENZJZNO6M;J5=IW0*("`@("`@("`@("`@("`@("`@("`@
M("`@J.RE2+*CI<VJNKKUK6ZDI"X`("`M8BP@+2UB87-E/2]0051(("!(;W)D
M92"JNJ7^N/2N?"X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@(*98J-:W<ZJZ
MPKW$MJCLIKG`R:[7I*2E2*5.M,"Y=[-="B`@("`@("`@("`@("`@("`@("`@
M("`@(""JNKKUK6[`R2BF8J78O_T@:&]R9&4O<&\@I*2JNB!C;VUP96YD:75M
M+G!O*2X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@(*C/I<ZFN<#)KM>E2*5.
MM,"Y=[-=NO6M;L#)"B`@("`@("`@("`@("`@("`@("`@("`@("`HIF*EV+_]
M(&AO<F1E+W!O(*2DJKH@8V]M<&5N9&EU;2YP;RDN`"`M9"P@+2UD96)U9R`@
M("`@("#%XZ7<L/6FYKE,M7NDI*JZO_F[?K!4KJ<N`"`@+60L("TM9&ER96-T
M;W)Y/41)4B`@(*9BIKFEV+_]I*2KV*7?NO6M;BX`("UH+"`M+6AE;'`@("`@
M("`@(,7CI=R[H:GZL%2NIRX`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(*5U
MJ,^ESJ:YM^VF8;MYJ'0N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@(""HSZ7.
MIKFW[:9ANWFH="X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@J,^ESJ:YM^VF
M8;MYJ'0N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@(""E=:O8I=^FN;S2LM4H
M2&]R9&4IJKH@34\@P,DN`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@(""E=;)-
ML*.FN;S2LM4H2&]R9&4IJKH@4$\@P,DN`"`@+6TL("TM;6]D=6QE/4U/1%5,
M12`@(""E=;2CI>:FN;S2LM4H2&]R9&4IJKK"O<2VP,DN`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@(*5UJ]BEWZ:YO-*RU2A(;W)D92FJNB!03R#`R2X`("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@(*5UIEBHUJ:YO-*RU2A(;W)D92FJNL*]
MQ+;`R2X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(*5UI_.W<Z:YO-*RU2A(
M;W)D92FJNKNAJ?K`R2X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(*5UI_.W
M<Z:YO-*RU2A(;W)D92DN`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@I76RHZ7-
MIKF\TK+5*$AO<F1E*:JZ(%!/5"#`R2X`("`M;BP@+2UN;RUC;VUP96YD:75M
M("`@(*2CK6ZF6*C6MW.JNL*]Q+:H[+KUK6ZDI"X`("`M;BP@+2UN;RUC;VUP
M96YD:75M("`@(*2CJ,^ESKKUK6XN`"`@("US+"`M+7-T871I<W1I8W,@("`@
M("`@P'BF<\*]Q+:RSJUPN.JNQJGSI;NF8<#)KM>DI"X`("`M="P@+2UT97-T
M("`@("`@("#%XZ7<L/6FYJOAJKJI4J5/IOVDH[#UIN8N`"`@8VQE86YU<"`@
M("`@LDVPHR!03R#`R:[7I*2EO,*]Q+:E2*3.N4RNR:JZN.JNQBX`("!C;VUM
M:70@("`@(""THZ7FPKW$ML#)IMP@0U93(*;XJD&^N2X`("!C;VUM:70M:&5L
M<""THZ7FNZ&I^L#)IMP@0U93(*;XJD&^N2X`("!C;VUP96YD:75M(""MJZO8
MNO6M;L#)+B#$M:=I.K-OL4["T+QGI=BK9:JZNO6M;L#)+@`@(&5X=')A8W0@
M("`@(+*CI<T@4$\@P,FJNKS+I;L@*"YP;W0I+@`@(&AE;'`@("`@("`@(,7C
MI=R[H:GZ+@`@(&EN:70@("`@("`@(*6\M^VF8;MYJ'2KV*7?I$"MTZ5(I%>J
MNB!03R#`R2X@Q+6G:3H@IKF_[[:UL4X*("`@("`@("`@("`@("#"T+QGJ=*F
ML\3=J?.FN;?MIF&[>:ATJKH@4$\@P,DN`"`@;6%K92`@("`@("`@I=&K_*EW
MJKH@4$\@P,FKV*7?I$>V::;L($U/(,#)+@`@(&UA:V4M:&5L<"`@(*?SMW,@
M6$U,(+NAJ?K`R:2DJKJITJ:SK/:__:RPL\RW<ZJLND$*J,.LL*15I$"FN*UN
ML/6FYJJZI_.W<[NAJ?JPM;?'L\8N"J=!P+.XTZ5UIK.F8B!U<&1A=&4M:&5L
M<""P]:;FI[FRIJC#J^&MUZUQNZ&I^L#)J^&DZ*_@L/6FYB!M86ME+6AE;'`N
M`"`@;65R9V4@("`@("`@IEBHUK)[IK.JNB!03R#`R:5(I,X@4$]4(+S+I;O`
MR2X`("!U<&1A=&4@("`@(""HS*?'L/6FYKC1MGTH97AT<F%C="FDSJ98J-8H
M;65R9V4I+@`@('5P9&%T92UH96QP(*;;K5Z[>;NAJ?K`R2!834P@I*2XT;9]
MJ=*FL[=SO%>DSL7<I_.JNJSVO_T*("`@("`@("`@("`@(""U3:OAIEBHUJCL
MLGNF<ZJZNZ&I^L#)I*0N`"`F(S$U,3L@)7,@I'>P=[GOI%6F0ZC&MK6A0;K[
MQ4"^WJ=`M$ZZ_"X`("@E<R"DT:ME*0`@**?6L;;!Y"`E<RD`("@E<R"DT:2Z
M*0`@**2UI-$I`"`HJ?JDT2D`("BL4:31*0"I\P`E9"`E<R"E2*3.("5S`"5D
M(*9RI+BRU:1WO&>D2BX`P6"M<"`E,B1D(+6GL$^__:2DJKH@)3$D9""D=[S0
MP]&LL+/,JO&G\[=S`+/,JO$@)60@I-&N\+9(N7>S^``E<R`M(+/&I]&__0`E
M<[K>LGH`)7,@J_ROO@`E<R!+0@`E<R"Z^\5`OMZG0"`M(+U4NWL`)7,@LUVI
M=P`E<R"U^:55`"5S(*90MTZVM:78`"5S(*1WIG.F8@`E<R"F8B`E<R`E<P`E
M<R"DHZ9SIF*ISK5,JFNP]:;F+@`E<R"DHZ5IO&>D2BX`I;*[W:UN("5S`"5S
M(*3``*?DI*.H["`E<RX`I^2DHZCL("5S+B"]T*7]L/6FYB`G=')A;G-L871I
M;VX@97AT<F%C="X`("5S(*CL("5S(*9`("5S`"5SJKJS<;!4O_T`)7.JNJ;F
MJ,:^Y``E<ZJZL\:GT;_]`"5SJKJKW;_LPZ\`)7,Z("5S`"5S.B"U3*IKN/RD
M2L58L,JU>Z:A.B`E<P`G)7,G(*2CK$^D0*W3IK.NQ*JZO^^^W"X`)R5S)R"I
M?*6\IF(@2$]21$4@JKJU^:55P,DH4F5G:7-T<GDII*2S7:EW+@`G)7,G(*1W
MIJBE7*JZI5ND2JCLN'.RU:ATLLZDI"X`)R5S)R"D=Z5;I$K%=JVMJ'2RSBX`
M)R5S)R"HPZ6\J]BEWSH@)7,N`"P@L'VMMR`E<R`E<P`LQ=RDQK9QL7$@)7,@
MJ.P@)7,`+2T@O^^^W"`M+0`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T`
M,3(@I'"NR:CN`#(T(*1PKLFH[@`R-""D<*[)J.X`I%>D0*VV`,#)KM<@)7,@
MI*2JNB`\9V5T=&5X=#X@O-#%TJE\I;S#]K.L+@JF8K+$("5D(*;FI^2H[+9]
ML=*DI*JZO-#%TBX`IKFPS[;TI;*VMZUNJ_RI=[CJKL:N=Z;XJD&ZW2X`M6^E
MS:1&I$"MT\19K:NJNK_YNWX`L?VE6[%+MFRE\RS!V;O=K6ZFLZ1`K=,@4$=0
M(*2]MGVJ]\9?+@"Q_<7GP]*D=\.QL[FJNK9LI?,LP=F[W:UNIK.D0*W3(%!'
M4""DO;9]JO?&7RX`L?VXT;%+MFRE\RS!V;O=K6ZFLZ1`K=.DO;9](%!'4""J
M]\9?+*APL4L@4$=0(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_;#UIN:V;*7SP[&S
MN2S!V;O=K6ZFLZ1`K=.DO;9](%!'4""J]\9?+*APL4L@4$=0(*KWQE\LI4BD
MSK-QP_:D9J5/+@"Q_;C1L4NV;*7S+,'9N]VM;J:SI$"MTZ2]MGT@4TU)344@
MJO?&7RRH<+%+(%--24U%(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_;#UIN:V;*7S
MP[&SN2S!V;O=K6ZFLZ1`K=.DO;9](%,O34E-12"J]\9?+*APL4L@4R]-24U%
M(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_:5;L4NV;*7S+,'9N]VM;J:SI$"MTR!3
M34E-12"DO;9]JO?&7RX`041322"_^;M^("5S+@"DR*MEIK.VLP"DR*MEI'"K
M0@"DR*MEIK.K0@"DR*MEL'VK0@"DR*MEL'VSMP"DR*ME+Z3(J^$`05!)(+US
MN+D`P_:I\[-OK=.]<[_HOKD`P_:I\RXN+@"EOZ15I.@`I;^DI*6A`*9SJ/J^
M1*G:+@#%=JVMI*.HK"RU3*IKJ]BEWR!61E,@I=B__2X`Q7:MK:2CJ*PLM4RJ
M:ZO8I=\@5D93(,#)KM<N`+%BN+F[4+%+O5@`L6*XN:1WK>&ULBX`M;*Q8@"W
M<[Q7`+=SO%>D;+:P`+=SO%>D;,5VK:T`IF*FN;=SO%<Z`+=SO%>X<[+5`+=S
MO%?%=JVM`+=SO%>D;+:PN'.RU2`G)7,G`+=SO%>D;+:PQ7:MK:;<("<E<R<`
MMW.\5Z1`K=.HSZ7.JLPZ`+=SO%?$YJ;L`+=SO%>D0*W3IJBM^SH`MW.\5[GO
M`+=SO%<@)7,@K+`@36]Z:6QL82"JNJ3`K;8`MW.\5ZCLJKJS<;!4O_TZ`+=S
MO%>H[*?:JKJS<;!4O_T`MW.\5ZC/I<ZJS`"D=[=SO%<@)R5S)R"H[*ATLLZD
MI"X@IOVU3*IKMW.\5\-"I7ZJNK7YI56XZK!4.B`E<RX`I'>W<[Q7("<E<R<@
MJ.RH=++.I*0N(*=!LGNF8J5II4BV::;FM6ZD2J1&+@"W<[Q7P,FNUZCL(')E
M<&]S:71O<GDZ`+=SO%>HSZ7.JLRJNJ5<K^"EV*MELU'#]K.L+@"F8:=]`+-Q
ML%2__0"FJ*RPNMZR>JW[("T@K+"HY*5,J,^ESJK,LUVI=\5VK:T`NMZR>@"\
M<Z=I`$%F9VAA;FES=&%N("BJ_+1)IKTI`$%L8F%N:6$@**K\NKBDVJ6GJ,@I
M`$%L9V5R:6$@**K\NKBDSJ=1J,@I`+9LI?.G3Z97`+GON_0`N>^[]*3HIJ$Z
M`*G2IK,`J=*FLZ1WQ>?#TJJZJ,^ESJK,`*G2IK.X<[+5`*G2IK/%=JVM`*5^
MKMB]=0"DN;-<IFZT6*W3N7&D;+9LI?.F8:=]`*2YLUS%W*?SMK6EV+USN+FJ
MNJNLND$_`*1WIG.F8@#%W*?S($E-4U`@M6ZD2@#%W*?S($E-4U`@L4N]6`#%
MW*?S($E-4U`@J,^ESJK,`,7<I_.Y<:1LMFRE\Z;MIWT`Q=RG\[S+JD\`M,"E
M3J3EIG(`06UE<FEC86X@4V%M;V$@**S\Q%*P[<+$O*^HR"D`I$"MT[5,KL2J
MNJW(LU&HSZ7.+@"U;Z7-I$:D0*W3I;RJOJJZO_F[?BX`06YD;W)R82`HIG>Y
M1*;5*0!!;F=O;&$@**9WK?2IU"D`06YG=6EL;&$@**9WIF.IU*YQ*0"PSJ97
MI4ZR>J9SJ/H`M:JNUP!!;G1A<F-T:6-A("BK;K>EI&JSL"D`06YT:6=U82!A
M;F0@0F%R8G5D82`HIG>THZ7*KG&DSJ3:NKBEK+E&KG$I`,"SI<ZU>Z:A`,"S
MI<ZU>Z:ALDVSY@#`LZ7.M7NFH:1WM$ZZ_`"N3:7.J.RITJ:SJKJFN*9`J,D`
MI^6MXP"Y=Z;TI&JD<`"E?*3K`*K\J=2G0J3E("A7:6YD;W=S+3$R-38I`,"C
MP5G`R:1JI'``P*/!6<#)IE>ZV0"G0;U4J7>M;J=2L*,@)7,@JKJU^:55MMP@
M/P"G0;U4J7>M;J=2L*,@)R5S)R"E2*3.I?2F\ZJZIKBX<[+5(#\`07)G96YT
M:6YA("BJ_*[:I\HI`$%R;65N:6$@**C(K/REIZC(*0"HR*S\I:>HR*3E("A!
M4DU30TE)+3@I`,/`LTX`07)U8F$@**K\OGRDVJYQ*0!!<V-E;G-I;VX@27-L
M86YD`*3EIG+#P+-.`*C(K'<OI-.EK:QVIF&PSP"P]:;FOMZG0+K[Q4"K9<7C
MI=R]5+M[N>^XW#\`I,"P=,3FINP`P'RXU:=2L*.D0*W3I*.F<Z9BJKJX<[+5
M+@#`?+C5IU*PHZ1`K=.DHZ9SIF*JNL5VK:TN`,!\N-6]<[_HI$"MTZ2CIG.F
M8JJZN'.RU2X`P'RXU;USO^BD0*W3I*.F<Z9BJKJF0*C)+@#$W:G*`*1+I.L`
M075S=')A;&EA("B_1*1JIU&HR"D`075S=')I82`HMOBF8:=1*0!!=71H7V-R
M>7-Q;#H@I^2DHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RX`075T:%]C>7)U
M<SH@IOBJ0;K=J,.EO+2CJ-&XT[:UI.2TJ2X`075T:%]C<GEU<SH@I^2DHZCL
MJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RX`075T:%]F='`Z(*?DI*.H[*G2N]VM
M;JJZ($944""IM:;YKDVE\RZ]T*VKMW.]<\2V(%!(4""HPZ5"I5ND2B`M+65N
M86)L92UF='`@O^^VM2RHTJ9P(&-O;F9I9W5R92`M+65N86)L92UF='``075T
M:%]I;6%P.B"GY*2CJ.RITKO=K6ZJNB!)34%0(*FUIOFN3:7S+@!!=71H7VMR
M8C4Z(*?DI*.H[*G2N]VM;JJZ(&MR8C4@J;6F^:Y-I?,N`$%U=&A?;&1A<#H@
MI^2DHZCLJ=*[W:UNJKH@3$1!4""IM:;YKDVE\RX`075T:%]L9&%P.B"U3*IK
MMW.\5ZC/I<ZJS"`E<RX@IOBJ0;ZYIE[`LSH`075T:%]L9&%P.B"U3*IKLKZP
MHZC/I<ZJS"`E<P!!=71H7VQD87`Z(+5,JFNG\[=SJ,^ESJK,("5S`$%U=&A?
M;6-A;#H@I^2DHZCLJ=*[W:UNJKH@34-!3""IM:;YKDVE\RX`075T:%]S;6)A
M=71H.B"GY*2CJ.RITKO=K6ZJNB!S;6)A=71H(*FUIOFN3:7S+@#%Y\/2I:*Q
MT2X`Q>?#TJ6BL=$N("5S`%)!1$E54R#%Y\/2O_F[?BX`1E10(,7GP]*_^;M^
M+@"E::7.JKK$YJ;L.@!!>F5R8F%I:F%N("BHR+;KJ_2U32D`J^&ZW:;XJD&^
MN:E\I;REO[U4I[FFJ"X`K4FTN@"M2;2ZPT.FX@!K97)B97)O<R"Q2[U8O_F[
M?BX`:V5R8F5R;W,@J,^ESJK,IE>ZV;_YNWXN`$)A:&%M87,@**3:JZ*PJ"D`
M0F%H<F%I;B`HI-JJ3"D`JFG#N:JZKORDY2`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<V@@**ESI5NIU"D`0F%R8F%D;W,@**3:J*FF:"D`I^2DHZCLN<^EW*78
MO_T@)R5S)RX`L/*]=0!"96QA<G5S`$)E;&=I=6T@**3QIU&NR2D`0F5L:7IE
M("BHJ:B]M+4I`$)E;FEN("BHJ;GG*0!"97)M=61A("BFRKQ]N48I`$)H=71A
M;B`HI*.DIBD`I<VDZ0"GY*2CJ.S`LZ7.M7NFH2(E,B1S(JJZL,^V]"(E,21S
M(BX`L,^V]+-=J7<`L,^V]*NLND$`LLK%Z0!";VQI=FEA("BLP:=1NONHR"D`
MKM'%T@"NV+UU`*[8O76D:J1P`*[8O74`0F]S;FEA(&%N9"!(97)Z96=O=FEN
M82`HJFFD:*6GJ,BDSK;"P<FM]+K[J+HI`*7^LZ$`0F]T<W=A;F$@**III;ZH
MNBD`J;.SH0!";W5V970@27-L86YD`$)R87II;"`HI-JFZ"D`0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M("BH6K7<
M*0"EOZ9BJ]BEWR`E<R"\TK+5JKH@34\@P,DN+BX`I;^F8JO8I=^W[:9ANWFH
M="`E<RXN+B``0G5L9V%R:6$@**M/I5NG4:C(*0"VM:78LL6XN0!"=7)K:6YA
M($9A<V\@**6LM%BOQZIKK\$I`$)U<G5N9&D@*+M:MJFF82D`JJFML;K>LGH`
M0U)#`$-23""DP+.APDD`P'BF<Z[FI+JN92XN+E]E`*?6J/JJ[*ELI,:I?*6\
MI[FFJ"X`IN:HQK[D`+ESK\6MMP!#86UB;V1I82`HK%JN2+GK*0!#86UE<F]O
M;B`HL]BSP;:I*0"U3*IKIMNPRJVKN&VQ2[U8++W0P7"UN*=!JKJH=++.NMZR
M>JW[+@"U3*IKLW.]=:;<($E-05`@IOBJ0;ZY.B`E<P!#86YA9&$@**5;KK.D
M:BD`J/JN^`"H^J[XL-W#1*9>L_@`M4RJ:Z=2L*/`R:[7("(E<R(N`*?DI*.H
M[+S(IG.EV+_]+@"ORJ36("=T87)G971&:6QE)R"PT;S&M4RJ:\1^Q/*S0K)Z
M+@"U3*IKLKZPHZ78O_T@(B5S(BX`M4RJ:[*^L*,[("5D(*W3I&RVL*1WIG.F
M8BX`M4RJ:ZVKLM6A0ZG2M*.HT:JZL$^__;S&I=B[4*7]JV6ITL!XIG.JNKCJ
MKL:DH[+%+@"U3*IKML>P9<*RL%2H[*O\J7>JNKBYO5@N`$-A<&4@5F5R9&4@
M*+K[O'>HI"D`NZ&I^J3EIG(`I,##_KM0O-#%T@!#87EM86X@27-L86YD<R`H
MMGVPTKASKG$I`*;FL,JY<;C<`,!XIG.NYJ2ZKF4`P'BF<Z[FN=2E4CH`P'BF
M<Z[FI+JN90#`>*9SKN:VH;9:.@"FYK#*N7&XW`"VZ[JXKU.DY2`H25-/+3@X
M-3DM,30I`+AMI*0`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC("BDI*M$ID"I
M3;#J*0"DI+S:("A)4T\M.#@U.2TR,`"^S,/2LM.X8`"^S,/2OM:FLZK,`+[,
MP]*L1K6F`$-H860@**QDO'<I`*?SI^\`I_.G[[%+O5@`I_.G[[%+O5BI\SH`
MI_.G[Z=!JKJJNJ7^IE>E2*3.IEZV;*9AIWTN`*?SI^^Q2[U8`,7<I_.F8B`E
M<R"JNK%+O5BDI`"F<J2X`,#+K&2S<[6R+BXN7VL`I,2_[Z=!MU&M;K[>IT"J
MNK:UI=@N`$-H:6QE("BTO*=1*0!#:&EN82`HI*2PZBD`PK+%Z:2DI.4@*$="
M,C,Q,BD`I;_%Z:2DI.4@*$)I9S4I`+_OOMRQ2[U8`+_OOMRD0*W3J,^ESJK,
MIE>ZV0"DZ;3!Q>.EW*3HIJ$Z`+_OOMRVM:78JZRZ0:JZK;>NY@!#:')I<W1M
M87,@27-L86YD("BX=+W/KG$I`*?DI*.H["`E<R"JNL/^IT^I=[AQ+@"EOZ9B
MLDVPHR`E<R"\TK+5JKH@4$\@P,DN+BX`I;^F8K)-L*.W[:9ANWFH="`E<RXN
M+B``M+@`LDVPH[=,LVX@3V9F:6-E(+S0Q=(`LDVPHZC/I<ZJS#H@)7,`LDVP
MHZC/I<ZJS`"R3;"CJ,^ESJK,JKJXZJ[&`+'?PN"TN`"K]K?&N:O!Y*5(Q'[$
M\@!#;&EC:V%T96QL(+-ZN4P@2%144`##]K.LM?BUH0"VL[9Q`*:MIFBVLP"S
ML0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P"GZ<5\N.JNQJ>H`*?IQ7S#Y*S)
M`$-O;&]M8FEA("BM]*W;I/&HR"D`PT.FX@"]U:;BO4P`,3:V::;LPT.FXJ5.
MO5@`Q.8Z`,3FINR\T,-$`*5DLW$`J5*E3P"GY::XJ5*E3P"I4J5/O^^VM3H`
MJ5*E3P"U^[W7`+2CI>:DI#H`NMFI20!#;VUO<F]S("BL[+ROP[DI`*2]I7$`
MO&>K2+6Y*"5S*0"Y<;BC`+'XI?,`KG2RIP"S7:EWN.JNQKE,M,$N`+-=J7<@
M)7,`O52[>[%+O5@`O52[>[=SL4N]6#H`0V]N9V\@**WHJD<I`$-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4@**WHJD>F0*E-L.HI`+-S
MM;*EHK'1+@"S<[6RI:*QT3H@`+-SM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^1*G:
M+@"S<[6RIMRDO;9]JO?&7Z;XJD&^N:[)OD2IVBX@K>RF73H@)7,@*"5S*0"S
M<[6RIMP@1E10(,#)KM>F^*I!OKFEHK'1+@"P3[_]I'>FJ*5<IF&W<[Q7IMRG
M0:JZLW&P5+_]I*0N`"<E<R<@P,FNUZ2ZKF4`Q'[$\@!#;V]K($ES;&%N9',@
M**SLITJX<ZYQ*0"]QKMS`+W&NW,`I;^F8KW&NW,@)7,@J.P@)7,`0V]S=&$@
M4FEC82`HK?2TM:1JOJ2E6RD`0V]T92!D)TEV;VER92`HMDBD^J[\J:0I`+5,
MJFNE2"!01U`@I5NQ2[9LI?,N`+5,JFNLL"!01U`@L/6FYK9LI?/#L;.Y+@"U
M3*IKI4@@4R]-24U%(*5;L4NV;*7S+@"U3*IKK+`@4R]-24U%(+9LI?/#L;.Y
M+@"U3*IKMW.\5[-SM;BD2"X@)7,`M4RJ:\.TM;(@3$1!4""F^*I!OKD`M4RJ
M:\.TM;(@;&1A<""F^*I!OKD`M4RJ:\#+K&2W;*]Q+B`E<P"U3*IKLW.ULB!L
M9&%P(*;XJD&^N0"U3*IKLW.ULJ;<IOBJ0;ZY("<E<R<@J,^ESB!&5%`Z("5S
M`+5,JFN]QKMS("5S(*CL("5S`+5,JFNKV*7?L'2X;;ASLM4N("5S`+5,JFNK
MV*7?I;NF8;MYJ'0@)7,@J=*[W:UNJKJEV+_].@"U3*IKN-&Q2R!01U`@N.JN
MQBX`M4RJ:[C1L4L@4R]-24U%(+CJKL8N`+5,JFNG4K"CLW.UN*1(+B`E<P"U
M3*IKIU*PH[!TN&VR3;/F+B`E<P"U3*IKIU*PHZ?SMW.U>Z:A("<E<R<N`+5,
MJFNH3:EWIJRE\Z1(JKJY<:1LMFRE\Z;LIWTN`+5,JFO`\JCZI[F^XZJZLW&P
M5+_]+@"U3*IKP/*H^J>YON.JNK!TN&VR3;/F+@"U3*IKP/*H^K!TN&VR3;/F
MI*2JNKASLM4N`+5,JFNX_*1*M::RI"`G)7,G+@"U3*IKJ]BEWZ78O_T@)R5S
M)RX`M4RJ:Z;;JO?&7Z;XJD&^N:CZL6^DO;9]JO?&7RX`M4RJ:[9]L=(@)7,N
M`+5,JFNV?;'2("<E<R>E2+QGI$HN`+5,JFNV?;'2NOO%0*1UIT"\TK+5("5S
M`+5,JFNV?;'2I=B__2`G)7,G+@"U3*IKMGVQTJCL('-M8G!A<W-W9""JNKK>
MO74N`+5,JFO%JJCZ("5S+@"U3*IKK:NW<[-=J7>HSZ7.JLRJNK%+O5@N(+.A
MI,"JNK+3N&"DHZ6_O50N(+W0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R
M>BX`M4RJ:\6JJ/JF<ZCZL;&H[JKM*$%C8V5S<R!#;VYT<F]L($QI<W0I`+5,
MJFO%JJCZLW&P5+_]+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E<P"U3*IKQ:JH
M^K!TN&VR3:55+B`E<P"U3*IKQ:JH^J;XJD&^N:JZK-O#]J]3J<H`M4RJ:Z9>
MM%^S7:EW+@"U3*IKIU*PHZ78O_T@)R5S)RX`M4RJ:\!XIG,@)7,@JKJS7:EW
M+@"U3*IKP'BF<[/&I?>S7:EW+@"U3*IKP'BF<[/&I?>S7:EW.B`E<RX`M4RJ
M:\!XIG.G\[=SM7NFH:CL.B`G)7,G+@"U3*IKP'BF<[/&I?>S7:EW("5S+@"U
M3*IKP'BF<[-=J7?`R25S+B"G0:5II4BHSZ7.)7.DI*JZJ.2E3*5<K^#`>*9S
MLUVI=ZG.I.*PRKW&NW.D5:VQM7NFH;U8J.P@)7,N`+5,JFNW:K1-($Q$05`@
M(*;XJD&^N2X`M4RJ:Z=2L*,@)R5S)RX`M4RJ:Z?SMW.S<[6XI$@N("5S`+5,
MJFNG\[=SL'2X;;)-I54N("5S`+5,JFO"T+QG("<E<R<Z("5S(*JZLUVI=RX`
MI^2DHZCL($UO>FEL;&$@JKJDP*VV+B"]T+U4NWNDP*VVK$^G7[9]L=(N`+5,
MJFN]X:2IJ,^ESJK,("<E<R<@I%6F0\5VK:VH[*M(I?.G6"`G)7,G.B`E<P"G
MWK-.I7D`L.JN80"]TJKM`*O8I=\`J]BEWZ1`K=.S<[6R`*O8I=^D0*W3MW.J
MN@"KV*7?IKBK2*7SIU@`J]BEWZK,JKK%=JVM`*M(I<ZE9+BYO5@`0W)O871I
M82`HITK#N:;HJ,@I`$-U8F$@**5JI-HI`*78JV6NR;:A`*78JV6Z]*=]`*78
MJV6DT:[P`*78JV6JNJJLJG`Z(`"EV*MEJKJMMZ[F`*;;K7&D0*C'M6ZD2B5S
MJ^&ITJUNL/6FYJJZI'6G0"X`L,6D50"PQ:15`$-Y<')U<R`HP<FTMK#'M+4I
M`*;HJ+VZN*3E("A+3TDX+5(I`*;HJ+VZN*3E("A7:6YD;W=S+3$R-3$I`*;H
MJ+VZN*3E+Z]1ITK$]:3E("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC("BQMJ=*
MID"I3;#J*0"DZ0"H0Z3I`+[PJJRXZJ[&PG/$_0"DZ;3!`*:LJ.RDZ;3!`+_O
MOMRDZ;3!`*75I-$`IU*PH\3FINQ?;`"D4:1'I.L`I%&V::;LO,:F<@"T[J36
MP5FQQ@"Y=[-=`+EWLUW#0Z;B`+EWLUVJNJBMI??#T:=/`+EWLUVJNL5VK:T`
MN7>S7:JZQ7:MK0"I=[AQ`*=2L*,`IU*PH[ASLM4`IU*PH\5VK:T`IU*PHZ%"
MLDVJQ;9LI?,`IU*PH\!XIG.NY@"G4K"CQ.:F[`"G4K"CLGNF<ZJZM,"E3KS+
MJD\`IU*PHR`G)7,GJKK%=JVM`+U4J7>M;J=2L*,@)R5S)ZJZQ7:MK:5(I,ZF
MN,5VK:T@/P"G4K"CID,`IU*PHZG2O^^^W*JZJ*VE]\/1IT^XZJ[&`*=2L*.E
MV*MEJKK$YJ;L`*=2L*.EV*MEJKJF0P"]5*EWK6ZG4K"CIKG%=JVMI4BDSJCD
MIKC%=JVM(#\`I_.W<[5[IJ$@)R5S)R"D=Z=2L*,N`+N\L&6NR;:A`$1E;FUA
M<FL@**2FL\$I`+#=PT2T>:UZ`+1YK7H`LM.X8"`HO="PT:;2($AO<F1E(+!/
MO_W`R:[7*3H`LM.X8+W0L-&FTJATLLZZWK)ZM6Z__2X`K..U;P#%4\))M\6K
MUP"SS*OAI$"D<*[)JKK%4\))M\6KUSH@`,53PDFWQ:O7.B``L7&EJJ;<I6L`
ML7&E:Z;<I:H`I=B__0"E2"`R-""D<*[)J.[%XZ7</P#%XZ7<O^^VM0#%XZ7<
MN7>S^"`H5$%&*0#%XZ7<KN:FH0"VQ[!EIEZQ^`!$:FEB;W5T:2`HIDZEK*9A
M*0"DHZ=2L*,`I*.M;JJ]L;6F<ZCZ(&UA:6YT96YA;F-E+G!H<`"RQ*1`M:>P
M3[_]K$^G7Z5=IW3$YJ;LIE>ZV3\@IG"J1ZQ/O="DQ+_O+@!$;VUI;FEC82`H
MIFBI^J6GI5LI`$1O;6EN:6-A;B!297!U8FQI8R`HIFBI^J6GI5NF0*E-L.HI
M`*15N/P`I%6X_"`E<P"D5;C\LUVI=\#)KM>E=*9SK+`@4$A0(+5[IJ$N`*15
MJ=2E7*_@JNT`P\2K?@"Y<:1LMFRE\P"_^;M^`$5C=6%D;W(@**3,I<JF:+JX
M*0"]<[_H`+USO^BPS[;T`+USO^BX<[+5`+USO^C%=JVM`+USO^C%=JVM`+US
MO^@E<ZJZQ7:MK0"]<[_HO^^VM0"]<[_H)7.JNL5VK:T`O7._Z"`G)7,GJKK%
M=JVM`+'0J'P`16=Y<'0@**Y*I,XI`$5L(%-A;'9A9&]R("C"Q+JXI<NF:"D`
MI+BE\RXN+@"Y<:1LMFRE\P"Y<:1LMFRE\Z;MIWT`N7&D;+9LI?.F[:=]I;*V
MMZ=KIE@N`+EQI&RV;*7SO52[>P"J[;&ALL6XN0"JQ:75JTBE\RX`JL6EU;6R
MJD<N`*K%I=6W:K1-MK6EV`"DN;-<IMO#P+19M*&D2K?3I/FH[*M(I?.DI"BZ
M]*VVO7.\9[S2IJ$I(#\`L=*PRK?&N:NE:\'DI5ROX*KM/P"ULJ?TIGZE]P"I
M\:1JO7._Z+ZY`*9PJD>G0;O=K6ZMJ[-=L4N]6"R]T+_II$JD0*W3IG>E_K#=
MI7DLJ-*F<"`GIT'#9*JKJKJF5[K9(#\G.@"F8J:YO^FD2KQVN;.JNKKTIWT`
ML$^__3H@P6"M<"`E9"RSS*KQI_.W<R`E9"RW<[Q7("5D+,7<I_,@)60LI;RJ
MOB`E9`!%<75A=&]R:6%L($=U:6YE82`HJ*JY1+18I+JHR"D`17)I=')E82`H
MI,REWZ]3J+VF=RD`O_F[?@"VQ[!EN.JNQJCL('-M8G!A<W-W9""NR;5OI<V_
M^;M^+@"\9Z1*("<E<R<@KLFU;Z7-O_F[?BX`O_F[?CH@`$5S=&]N:6$@*+=2
MJ$:EIZC(*0!%=&AI;W!I82`HIN>OP:3QJ,@I`+K8L=H`175R;W!E("B\VJQW
M*0"H0R`Q-2"DP,3!`*A#(#(@I,#$P0"H0R`S,""L[<3!`*A#(#4@I,#$P0"H
M0Z:XM6ZD2@"H0R`S,""DP,3!`*A#(#$@I,#$P0"]9*C2K<@Z`+#UIN8`L/6F
MYJ2D.@"N:;9]`*YIMGVXZJ[&IZ@`K6ZH1"`G*2<`J.RTP:3I`+C1NZ&M^P"F
MVR`E<R"XT;9]I*0N+BX`JV6TNL-#IN(`1E10(*17ML>S7:EW+@#%JJCZL+ZF
M;K-=J7>EHK'1`+5,JFNS<[UUIMP@3$1!4""F^*I!OKDN`+5,JFNS<[UUIMP@
M4TU"(*;XJD&^N2X`O<:[<Z6BL=&FVR`B)7,B+@"]QKMSI:*QT:CL("(E<R(N
M`+5,JFNKV*7?I$"MT[=SJKH@4T%33""S<[&U+@"W:+*^I:*QT:CL("(E<R(N
M`,+"L4N]6+U4NWNEHK'1+@#%W*?S("5S(+%+O5BEHK'1.B`E<P"TMK-Q`$9A
M;&ML86YD($ES;&%N9',@JFO$]:=*NM:X<ZYQ("BPJ+JXNONOQ[2UN'.N<2D`
M1F%R;V4@27-L86YD<P#$6:VKO_F[?CH`ML>O=0"D1Z3K`+=0Q+$`MU#$L3H@
M`*3RI/*K0@"U=;S(L'VSMP#$YJ;LL'VF0P!&:6II("BTM,#9*0#`R:[7O,:E
MV#H@)7,@K=/`R:[7`,#)KM>\QJ78.B`E<R#`R:[7`,#)KM?!8+K>`,#)KM>F
M5[K9`,#)KM>_[[[<`,#)KM>D5[;'`,#)KM>D5[;'I5ROX*6\LU&DY+2I+@"Y
M3,)OOKD`1FEN;&%N9"`HJN+$]2D`I%>E8J3K`*17J;8`J52I=Z3QJ-(`I%>D
M5<1!K<L`KT*PR@##^@"EV+_]("5S(*2CIG.F8@"F<JNLPT.FX@"MN:JK`*9=
MK+#"<\3]OKFHPZ6\I.2TJ;QVN;.E7*_@+@"N\+9(N7>S^"`H5$%&*0"Y=[/X
MI-&\QB`HN7>S^*31O,:E7:Q!I=6DT:5(I,ZI7;:AJKJXZJ[&.Z9PJD>Y=[/X
MI-&\QKC[JOBQ3J;[I<ZD\;C[O&6T5*JZJJFML2D`I]&P3[%+O5@@/P"J[;/F
M`*1PNWD`I'"[></^JZP`I'"[>0"D<+MY(#(`O=>^P@"FV[#*PN"K2`"GY*CL
MP+.ESK5[IJ$Z("5S`*?DJ.REV+_].@"L4+3!I*T`KMBL6P!&<F%N8V4@**IK
ML.HI`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$@**IKQ-V[
M7*C(J+HI`$9R96YC:"!0;VQY;F5S:6$@**IKQ-VLP:=1I:>FZ*C(*0!&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`L4BE\Z1(`+%Q`*>YON.T>:UZ`+JA
MI.L`I?ZF5P"G=+UKJKK"O<2V`$=A8F]N("BE6[1>*0##P+19.@!'86UB:6$@
M**7,I/&HR"D`LJ.ES2`E<R"MTZATLLZS7:EW`*1WLJ.ES:JZLUVI=[CJKL8`
MI;^F8K*CI<V\TK+5("5S(*JZJJRZ02`N+BX`1V5O<F=I82`HL^RJ=JC(ID"I
M3;#J*0!'97)M86YY("B\=[#J*0!'971O<'0@O_F[?CH@`$=H86YA("BM>Z_'
M*0!':6)R86QT87(@**J]I:S#N:K[*0"F5[K9`*MEJ;D`K?2\=[JX`$=O;V=L
M92"W:K1-`*;'MJ4`1W)E96-E("BGQL.^*0"GQL.^I.4@*$E33RTX.#4Y+3<I
M`$=R965N;&%N9"`HKN:SKL3UKG$I`&=R96YA9&$@**[FM^>OQ[E&*0"X<[+5
MNMZR>@"X<[+5IE>ZV:2CL6^JQ:75`+ASLM7%=JVM`+ASLM4`1W5A9&5L;W5P
M92`HK?2\=ZREM+8I`$=U86T@*,/VKG$I`$=U871E;6%L82`HI<JF8;"HJ=0I
M`*[FKJ:FZ*YQ`*C3NZO%=JVM`*C3NZO%=JVM`+-8J\BO9*BE`$=U:6YE82`H
MM%BDNJC(*0!'=6EN96$M0FES<V%U("BT6*2ZJ,BD\:_!ID"I3;#J*0!'=7EA
M;F$@*+M<J,BHNBD`ME>DY;-SM;*[>:BE`*?DI*.H["!(5%10(,7GP](N`$AA
M:71I("BN_*9A*0#"^+3J+;ITNN(`QD<`JNW`60!(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',`I\:G0JC3I.4@*$E33RTX.#4Y+3@M22D`L*JK
MUP"[H:GZ`+USO^B^N:C/I<Z[H:GZ`+NAJ?H`2&5L<&5R(&%P<&QI8V%T:6]N
M('1O(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@
M2&]R9&4*9G)A;65W;W)K(&%N9"!I=',@87!P;&EC871I;VYS+@I&;W(@86X@
M:6YT<F]D=6-T:6]N(')E860@=&AE(&9I;&4@4D5!1$U%(&EN('1H:7,@9&ER
M96-T;W)Y+@"E8K)Y`+-ON,RL3\#)KM>JNK9]J6PZ`+"J`+[ZI7:F5[K9I*.Q
M;ZK%I=4`KF%?;0!(;VQY(%-E92`HL>N_S:FC*0"N80"F[:YAIF&G?0"F[:YA
MN7&XW`!(;VYD=7)A<R`HI[NSHZG4M+4I`$AO;F<@2V]N9R`HK;NTY"D`2&]R
M9&4`2&]R9&4@PKW$MK*CI<V^N0!(;W)D92]+;VQA8CH@MFRE\R`E,B1S(*2D
MN4JH[+5,KL2JNB`E,21S(%A-3+CJKL8`2&]R9&4O2V]L86(Z(+5,MFRE\[Y!
MIEBJJZ7S("5S`$AO<F1E+TMO;&%B.B"V;*7S("4R)',@I*2GY*2CJ.RJJZ7S
MJZRZ02`E,21S`$AO<F1E+TMO;&%B.B"D=Z:HI5RJNK*^L*,@)7,@(B5S(@!(
M;W)D92]+;VQA8CH@I'>FJ*5<JKJF4*A"("5S("(E<R(`2&]R9&4O2V]L86(Z
M(+[CIEBD=;5[N]VM;B`G9&]M>&UL)R"JNB!02%`@J;6F^0!(;W)D92]+;VQA
M8CH@M4RJ:ZO8I=\@)7,@JJNE\ZJZ(%A-3""^\`!(;W)D92]+;VQA8CH@M4RJ
M:[*^L*,@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(+5,JFO`\JCZLZ&E]R`E
M<R"KK+I!JKH@34E-12##T:=/N+F]6`!(;W)D92]+;VQA8CH@M4RJ:Z90J$(@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(+5,JFNF4*A"I,"HR3H@)7,`2&]R
M9&4O2V]L86(Z(*6\JKZJNJ3`J,D@(B5S(@"D]*6MO74`I/2EK;G4I5(`I/2E
MK3H`IT&F<*;SJ.RFN2`_("B]T+'4K7HA*0"G0:UNIEBHUJ9HI-:MT\3FINRI
M3S\`Q.:F[+S&I=BF0*UP/P"G0:UNIEBHUJ9HI-:F0ZE//P"WPZO7`+?#J]<Z
M(`"WQKU=I&JN=@!(=6YG87)Y("BF2:3ZIU$I`$E-05`@MFR]8ZO8I=^EHK'1
M.B`E<P!)34%0(+9LO6.G4K"CI:*QT3H@)7,`24U!4""V;+UCNL^ZT+!TN&VK
MV*7?I:*QT3H@)7,`25`@INRG?0!)4""F[*=]M4RJ:ZC/I<XN`$E0(*;LIWVH
MPZ2CIF(@0TE$4B"JNJ2YLURPS[;TI*0N`*9BJ^&ML;2AI$JF0U]N`$EC96QA
M;F0@**9"KG$I`*_"N<^EW``E<ZJZN<^EW`"YSZ7<I,ZDY:9R`*BMI??#T:=/
MJKJF5[K9.@"F<*I'M4RJ:Z6_O52F8<7CI=PL("5S(*5(I72V?;'2MFRE\ZGS
MMW.U^+6AM^VDI"X`J,^ESB!);G1E<FYE="!%>'!L;W)E<B#"<\3]OKFNR:9P
MJD>H4Z:SK-VH[*7TIO.JNJ1PN<^EW"P@IT&E::_@N]VM;J3$O^^S;ZW3MK6E
MV*5(P_:SK"!03D<@O':YLZJZP?3"PZ[$JD<N`*9PJD>LW:CLLV^K:*A3IK.\
M=KFSJKJP5*ZG++-OJNVEW*=!JKK"<\3]OKFU3*IKQ>.EW*17ML>JNKQVN;,N
M`+QVN;.Y=\3].@"\=KFSNO2G?0"\=KFSNO2G?3H`O':YLZC3IMO#P+19`+QV
MN;.HTZ;;P\"T63H`I%>VQ[QVN;,`O':YLP"VUZ1*+""H0L9*("5D`+;7I$K$
MYJ;L.B`E<P"VUZ1*Q.:F[#H`IF*KX:VQM*&D2J9#7W,`I*.EO[U4JKJQ2[U8
M`+_II$JDHZ6_O52JNJ=`I<Z]6"X`O=#`RZQDIT&JNJC/I<ZJS*97NMFDSK%+
MO5@`J,^ESJK,IE>ZV:2CI;^]5*G.JLRY<:1LMFRE\Z;MIWVD=\7<I_,NO=#!
M<+6XIT&JNJATLLZZWK)ZK?NE2*CSIU6S0K)Z+@"\5Z5;P5FQQ@!);F1I82`H
MIDRKURD`K=.G3ZC/I<ZJS`!);F1O;F5S:6$@**9,I:<I`+CJL%0`N.JP5`"\
MTK+5("5S(*KLJ6RDQJ2D+BXN(`"F8JOAK;&TH:1*Q.:F[%]O`+2AI$JYSZ3Y
M`+2AI$JJ[:[F`+2AI$JZ]+CTLW.UL@"F8JMEK;&TH:1*Q.:F[%]#`*9BI=BK
M9<3FINRKX:VQM*&D2J1`K=.W<\3FINP`IF*EV*MEQ.:F[*MEK;&TH:1*I$"M
MT[=SQ.:F[`"F8J78JV6F0ZOAK;&TH:1*I$"MT[=SID,`IF*EV*MEID.K9:VQ
MM*&D2J1`K=.W<Z9#`*9BI=BK9;A@PDFKX:VQM*&D2J1`K=.L<;BH`*9BI=BK
M9;A@PDFK9:VQM*&D2J1`K=.L<;BH`+2AI$JE:;3`I4Z\RZI/`+=SL4N]6+%.
ML4BU;ZCLLV^MT[9LI?.F8:=].@"F8JOAK;&TH:1*P'BF<Z[F`*9BJV6ML;2A
MI$K`>*9SKN8`IF*KX:VQM*&D2L3FINP`IF*K9:VQM*&D2L3FINP`M*&D2K9L
MI?,`IF*KX:VQM*&D2JQQN*@`IF*K9:VQM*&D2JQQN*@`IF*KX:VQM*&D2J9#
M`*9BJV6ML;2AI$JF0P"F=Z7^L-VE>:JZM:JNUSH`M*&D2B_%W*?SO':YLP"T
MH:1*+\7<I_.Z]+CTLW.UL@#"2;S&I*.HK*5(IMRI\[5,JFNVQ[!EM;FP=+AM
MN'.RU2X`PDF\QJ2CJ*PN`+[CO,8`ON.\QJ9#`+5,KL2JNB!51$@HJ,^ESJK,
MN.JNQJKMP%DI+@"U3*[$JKK`LZ7.M7NFH2X`M4RNQ*JZI^6FN+BYO5@N`+!E
MI5BJNKCJKL:U3*[$+@"U3*[$JKJEV+S0INVG?0"U3*[$JKK`R:[7KN:FH0"U
M3*[$JKJQPL5VO5@N`+5,KL2JNJ9AL,\N`+5,KL2JNB!M<V=?='EP92X`M4RN
MQ*JZJ<ZGY*2CJ.P@87!I7VED+@"U3*[$JKJISJ?DI*.H[+#1O,8N`+5,KL2J
MNJ3WQ7:MK2X`M4RNQ*JZN=FF\</1IT^]6"X`M4RNQ*JZLJ.K?KU8+@"U3*[$
MJKJS<;!4J/.I=RX`M4RNQ*JZIJRE\Z1(.B`G)7,G`+5,KL2JNJ3`J,FJJZ7S
M+@"U3*[$JKJHT[>]INVG?2X`M4RNQ*JZN%6PZKU8N.JNQBX`N.JRHP!)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F("BE[*[4*0!)<F%Q("BE[*G4ITHI`$ER
M96QA;F0@*+=2NKC$]2D`27-L92!O9B!-86X@*+#2KG$I`*>]LZ&Y<*M"`$ES
M<F%E;"`HI4BFXJ9#*0##L;5OJLP`L=?%Z0!)=&%L>2`HN'&D:J=1*0!*86UA
M:6-A("BD^K92I5LI`*1`I.L`2F%P86X@**3II;LI`*3II.4@*$E33RTR,#(R
M+4I0*0"_0:;HKG$`2F]R9&%N("BL^:6Y*0"D0Z3K`*2[I.L`N>^[]`"X;:2D
M`*6JI6NY[[OT`+YAI:JY[[OT`+YAI6NY[[OT`$MA>F%K:'-T86X`JT^O9*WL
MO,L@/P!+96YY82`HJM:HR"D`2V5R8F5R;W,@NWO#TK_YNWXN`*[6I-^W<Z3B
M`*KWQE^KV*7?`*KWQE^O4[QX`*KWQE^J^*O7`*KWQE^KK+I!`*KWQE^[>:IK
M`*78JV6JNJ2]MGVJ]\9?IOBJ0;ZYI*0LI'>X9Z9SIF*G0:JZJO?&7RX`J."U
MHP!+:7)I8F%T:2`HL/*HO:3:M+4I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F("BE7\'Z*0!+;W)E82P@4F5P=6)L:6,@;V8@**MN
MP?HI`,'ZI.4@*$550RU+4BD`2W5W86ET("BL[*O"KU,I`$MY<F=Y>G-T86X`
MJJFML;!TN&U?>0"[>:BE`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC("B\9+#J*0"D5:5BI.L`I%6IMJ3K`*17IKBG\[=S.@"D5Z1`IKBU;J1*
M.B`E<P"D5Z1`IKBU;J1*.B`E<R"FVR`E<P"D5Z1`IKBU;J1*.B"RQ*1`IKBU
M;J1*`$QA='9I82`HJ=2RYKK[J,@I`*IKJ]\`JJFML;!TN&T`3&5B86YO;B`H
MOJ2DVKG@*0"EJL/D`*6JP^2J[<!9`*6JP^2MR`!,97-O=&AO("B_X*_!IJLI
M`$QI8F5R:6$@*+_@I/&WYZC(*0!,:6)Y86X@07)A8B!*86UA:&ER:7EA("BG
M4:3QJ,@I`$QI96-H=&5N<W1E:6X@**9#I.2TL+2UM6XI`+=,JT(`I'"K0@"F
MK::SI'"K0@"QWZ:SI'"K0@"D<+!]JT(`I'"K0J:SN7``I'"SMP"D<+!]L[<`
MI;2J;[C6`+-SM;(`LW.ULL))J.PZ`,7CI=RNR;-SM;*V;*7SINVG?:CLO7.\
M9[9LI?.MMJVQ`+-SM;(`ID.E6"`M(*C/I<ZJS*5II4BLW:CLLV^MTZM(I?.G
M6`"F0Z58N.JNQJYW`*9#I5B[H:GZO-##1`"F0Z58JNVNY@"P4;W7N'.RU2W`
MR:[7PF0`L%&]U[ASLM4MJ$2G50"P4;W7N'.RU2W#T:=/N+F]6`"P4;W7N'.R
MU2V^UJ:SJLP`L%&]U[ASLM4ML4BE\Z1(`+!1O=>X<[+5+:UQOEP`L%&]U[AS
MLM4MJ/JN^*UQOEP`ID.E6*C/I<ZJS*JZI5ROX+-1P_:SK`"DY;['`$QI=&AU
M86YI82`HI=^SLZE[*0"X_*1*J.>FH:YWI*0N+BX`N/RD2J2D+BXN`+?MIF&N
MR;:A.B``IF&PS[M0KLFVH0"F8;#/`+5NI$H`M6ZE6`"U;J1*I'6G0`"U;J1*
MI:*QT2P@O=#`RZQDN]6D5:JZI<ZDX:97J4VQ2[U8+""U3:OAK:NXU2X`M6ZD
M2J6BL=$N`*KXI7D`MU*QH0"G0P"D<+QGI\;#OKS&IG(`I'"\9ZG4I$*\QJ9R
M`*1PO&?#N;"HO,:F<@!,=7AE;6)O=7)G("B_8[3+L_DI`*3K`*A#I.FP5*ZG
M`$U3+51.148@JOZE6\#)KM>DI*A3IK.XZJ[&+@!-4T<`36%C86\@*+]$JODI
M`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B`H
ML*BHY+EYID"I3;#J*0!-861A9V%S8V%R("BPJ+E&I5NTM:5;*0#%7;-.`+9L
MI?,`MFRE\[K>LGH`J]BEW[-SM;)?:RXN+@"]T+U4NWNG0:1WN&>F=[C+(%!%
M05(@IM.E0J;LJ?.G0:JZI5VG=+CTKGRDI"AI;F-L=61E('!A=&@I+@"KV*7?
MI=B__2`E<R"DI`!-86QA=VD@*+"HJ=2KPBD`36%L87ES:6$@*+"HJ-.FZ*C(
M*0!-86QD:79E<R`HL*BZN*9AI-(I`$UA;&D@*+"HIU$I`$UA;'1A("BPJ+JX
MI4PI`+K>LGJG0:JZI,##_BRHPZ5"K+"DP,/^LUVI=\-#IN(N`$UA<#(T(*9A
MN<\`36%P475E<W0@IF&YSP"D5*3K`,/DK,D`O-"P3Z:H(*S=N4POI;RLW;E,
M`+S0L$^FJ*CDI4RJNL/1IT\@**C2IG`N(*VKK6XOI'>F7L+0*0!-87)S:&%L
M;"!)<VQA;F1S("BPJ*Y,NKBX<ZYQ*0!-87)T:6YI<75E("BPJ+2CI:>G2JYQ
M*0"DQ[!TQ.:F[*2D`$UA=7)I=&%N:6$@**U4IU&V\*6GJ,@I`$UA=7)I=&EU
M<R`HO*^HO:;HM+4I`*2YLURJNK/,I&K"2;S&+@"J_J7SO,:EV*1WME>E6*2Y
MLURD5ZVM+@"SS*KQ(#(T(*1PKLFJNK/,L*JWQ:O7.B``L\RJ\2`V(*1PKLFJ
MNK/,L*JWQ:O7.B``I+FS7+/,I&JJ^*O7`*2MI.L`36%Y;W1T92`HL*BL^:]3
MKG$I`,+EOL<`IJBM^P"_[[/FO-*FH3H`IEBHUL!XIG.NY@"EOZ9BIEBHUJG2
MIK.JNB`E<RYP;R#`R:CLNO6M;J2D+BXN(`"EOZ9BIEBHUK?MIF&[>:AT("5S
M+BXN(`"EOZ9BIEBHUB`E<R"JNB!03R#`R:CLNO6M;J2D+BXN(`"EOZ9BIEBH
MUKS2LM4@)7,@JKK"O<2V("XN+@"V;*7S`+9LI?/%Y\/2I'>GN::H+*;]K$^H
MSZ7.JLRJNL.QL[FK;[5,JFNS<;E,Q>?#TBX`PK*P5*1WN4RTP2X`PK*P5*NL
MND$`365T87(@L,^V]+5,JFNHSZ7.+@!-971A<B"PS[;TM4RJ:ZC/I<XN(++3
MN&"]T+#1IM*H=++.NMZR>K5NO_TN`$UE=&%R1$(@J7REO+-SL;4N`*3HJFL`
MI.BJ:R`G)7,G(*6\LU&I=[AQ`*2]J.X`365X:6-O("B^I:;HK?0I`$UI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8@*+%+ITK#N:6GINBHR"D`I*2V
MH0!-:6UE(*NLND$`L\RJ\2`R-""D<*[)JKJSS*=#M\6KUSH@`+/,JO$@-B"D
M<*[)JKJSS+"JM\6KUSH@`,+"L4N]6*6\N4:D0*EWJ,^ESJ[)MJ$`K$VN9P#"
M^+:U`*?DI*.H["!014%2(*5=N,L@2%144%]297%U97-T+@"S7:EWP,F_\J6B
M+B"F<*I'K6ZHSZ7.LV^MT\"SI<ZU>Z:AIT&ELK:WLGNF8K1.LJ.ES:5,+@"G
MY*2CJ.S"LK!4JKH@240N`*?DI*.H[*6RMK>JNB!014%2(*5=N,L@36%I;"X`
MI^2DHZCLMWRTP:JZ($E$+@"L4+3!I$``IN:PRK9LI?,`M\6I30"G\[=SI.FT
MP0"MUZ?ONO2G?0"\TK+5`+S2LM4`36]L9&]V82P@4F5P=6)L:6,@;V8@*+RO
MNKBF:*7+*0!-;VYA8V\@*+ROK\>M]"D`36]N9V]L:6$@*+M8I6HI`*3KI,ZF
M?@"H0Z3K`+M8MNNIU*]3`*3KK-L`O*^LI:WT`*9HMK.NR;2X`*9HMK.NR;.Q
M`+2XKLFF:+:S`*15LKX`I:JRO@"E:[*^`*17LKX`I%6RO@"D5[*^`$UO>F%M
M8FEQ=64@*++VI%2D\:=**0"]QK_OIJ&D5:G4I5ROX*KM`+W&O^\`I]JJNK%B
MN+D`K=.D2*^XI7@`K=.D2*^XI7BMMJVQL'2X;0!->6%N;6%R("B]<:AL*0"D
MHRRGVJ2CIE"W3@"F5[K9`$YA;6EB:6$@**BZILRD\:C(*0!.875R=2`HO]6^
M?"D`3F5P86P@**6GJGFZN"D`3F5T:&5R;&%N9',@*++\Q/4I`$YE=&AE<FQA
M;F1S($%N=&EL;&5S("BR_,3=IG>F8:9#M+4I`$YE='-C87!E(*RPL/+"IJJZ
MNO2G?0!.971S8V%P92"^S,/2IT"\;[KTIWT`3F5T<V-A<&4@OLS#TJQ&M::Z
M]*=]`$YE='-C87!E(*?SMW.Z]*=]`$YE='-C87!E(*=`O&^Z]*=]`$YE='-C
M87!E(%-33""F^*I!OKFF5[K9`$YE='-C87!E(+[,P]*JNK7YN-$`3F5T<V-A
M<&4@OLS#TJNLND$`NO2X]*1UJ.,`L7&EO`!.97<@0V%L961O;FEA("BW<[/8
MJ+VF:*6GJ,@I`+=SO%>DP,/^`+=SI.L`MW.HSZ7.JLRF5[K9("BK1*6RK6XI
M`$YE=R!:96%L86YD("BOPZ;HQ/4I`+=SL4N]6#H`MW.U^+6A("A?8FQA;FLI
M`+=SNT0`MW.[1+ASLM4`I%6D0*A"`*15I$"MT[_OMK4`I%6D0*VV`$YI8V%R
M86=U82`HI:>E6ZG4I<HI`$YI9V5R("BEIZ3I*0!.:6=E<FEA("BI8*3.IU&H
MR"D`L=^D5P!.:75E("BOPZY*KG$I`*=?`+5,I6FHT<7CI=RN=+*GJKJS7:EW
MN.JNQBX`M4RE::7.JKJUIK*DJ]BS>2!)4T\@O':YLRX`J%.FLZ?EIKB\RZ:A
M+@"ITJO\J7>JNJ;LN&VD5ZA3IK.PS[;TIG.F8@"H4Z:SM*.HT:;FJ,:^Y*97
MNMFE2*C1($U#04P@Q>?#TBX`J%.FL\7<I_,N`*78JV6ITK-"JKJS;ZW3M:6O
MQ;5,JFN\5Z5;IKC%=JVM+@"U3*IKIF*EV*MEQ7:MK:2DO%>E6Z:XQ7:MK2X`
MJ7REO*O\J7>I4J5/+@"H4Z:SJ_RI=ZJZ("5S(+-=J7>XZK!4+@"H4Z:SJ_RI
M=ZJZ($944"!61E,@LUVI=[CJL%0N`*A3IK.K_*EWJKH@4U%,(%9&4[-=J7>X
MZK!4+@"H4Z:SJ_RI=ZJZ(%-13"U&:6QE(%9&4[-=J7>XZK!4+@"U3+/1OFS"
M2;S&+@"EO+2CJ-&EV*JZ+@"M[*ELJKJH1*=5P,FDI*?DI*.H[,/1IT^XN;U8
M("<E<R<N`,#)KM>EO*17ML<`I^2DHZCLN<^EW"X`I;RK_*EWM^VF8;MYJ'0N
M`*;LN&VXZK!4J7REO+-=J7<`J7REO+2CJ-&F[+AMN.JP5"X`I;RTHZC1PK*P
M5"X`I;RK_*EWIE>ZV2X`I;RK_*EWN+F]6"X`J%.FLZO\J7>Q2[U8I4BHT2!(
M5%10(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@24U!4"#%Y\/2+@"H4Z:SJ_RI
M=[%+O5BE2*C1($ME<F)E<F]S(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@3$1!
M4"#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1($QO9VEN(,7GP](N`*A3IK.K_*EW
ML4N]6*5(J-$@4$%34U=$(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@4TU"(,7G
MP](N`*6\O^FD2B!/<&5N4U-,(*1'I+BP]:;FP,FJNJ7^N/2N?"X@4$M#4R`Q
M,B"S5Z[FJKJE6[%+N.JNQKO=K6ZESJCLN-.U>Z:A+@"H4Z:SJ]V\9JJZM?FE
M5:73O=`N`+5,KN:]=0"U3*[8O74`I^2DHZCLIKFF^*I!NMVZW2`G)7,G+@"U
M3+S(IG.EV+_]I6FHT:?6J/HN`*6\ML>P9:C/I<ZJS*97NMFISK%+O5@N`+5,
MI6FESJJZ(%A-3""XZJ[&LU&VQZ9>`*K%I=6MR`"M[*ELLUVI=\#)I*2GY*2C
MJ.RJJ:6[N.JP5"X@K:NW<[*CI<VS7:EWP,DN`*9BIT&JNK-=J7?`R:2DI^2D
MHZCLJJFEN[CJL%0N(*VKMW.RHZ7-LUVI=\#)+@"U3`"U3"`H=7-E(&EM<&QI
M8VET*0"DZ:;5L-*DY2`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD("B_
MU;K6ITJN<2D`I5^E8K)Y`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W
M87D@**Z_J\(I`*M$I*>KX0"K1*2GJV4`I*.L3Z1`K=.EV+_]`+5[IJ&I?*6\
MI[FFJ"X`I*.S7:EW`*6\LU&DY+2I`+/&I]&__0"H4Z:SI6G"<\3]JKHLIEZE
M:"X`LW&JO@"D4:1`I.L`O,:F<@"F<J2XO,8`IG*DN+QEJ]<`IN:\Q@"G\[=S
ML'2X;;ASLM6NR:6\J_RI=[S&I=@N`$]+`*JKI?,`JJNE\ZO8I=^JS`"JJZ7S
MJ]BEWZK,JKK%=JVM`*1+MFFF[`"D4:3K`+_LI+VKQP#"PK%+O5@Z`$]M86X@
M**K\L-(I`*5UIK,@24U!4""F^*I!OKFDY+2IJTBE\Z=8I,"HR:5<K^`N`*5U
MI+FS7*1`K=.V;*7SINVG?2X`I76FL[[6IK.JS+M0J'2RSKK>LGJM^Z5II4C%
MW*?SID"HR<5VK:T`IF*W<ZJZM?BUH;9]L=(`3W!E;E-33""_^;M^.B"U3*IK
ML7$@4R]-24U%(,.QL[FJ_J7SN-&V?;CJKL8N`*9BMW.JNK7XM:&V?;'2LW.U
ML@"G0+=^J'2RS@"_[[:U`"5SO^^VM0"_[[:U`+:UI=B]<[BY`++5PK0`LM7"
MM+/FINP`LM7"M`"M[*ELP+.ESK5[IJ&\RZI/`*9B("5S.B"DI*JZK>RI;+S+
MJD\N`*CDI4P`J.2E3+CJL%0`OM:FLZK,Q7:MK0!004T@Q>?#TK5,KL0N`%!'
M4""\QJ;LP[&SN0!01U`@I5NQ2[CJKL8`4$=0(*2]MGVJ]\9?`%!'4""D=\.Q
ML[DOI'>E6[%+(+CJKL8`4$A0(+5[IJ&]6`!02%`@K_.]6@"DR*OAI'"K0@"D
MR*OAL'VK0@"DR*OAIK.SMP"DR*OAL'VSMP"DR*OAM+@`I,BKX;EPJT(`4$A0
M(*_SO5I?2`"YU*52`%!A:VES=&%N("BDVK#RM+6I6BD`4&%L874@**FMKULI
M`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960@**3:L,>TM:E:ION[
MXK#/*0!086YA;6$@**3:KK.PJ"D`4&%P=6$@3F5W($=U:6YE82`HI-JEK*C(
MMW.T6*2ZJ,@I`%!A<F%G=6%Y("BDVJG4IF,I`*9HMK,`4&%S<W=D(+S2LM6I
M?*6\I[F^X[-7N;HN`+%+O5@`)7,@JKJQ2[U8I'?%W*?S+@"Q2[U8I*.EO[U4
M`%!A<W-W;W)D(+S2LM6GY*2CJ.RDY+2IJKJU>Z:A+@!087-S=V]R9""\TK+5
MI^2DHZCLI;*M;JJZL-&\QBX`4&%S<W=O<F0@O-*RU:?DI*.H[*78O-"PT;S&
M+@!087-S=V]R9""\TK+5J7REO*>YON.S5[FZ`%!A<W-W;W)D(+S2LM6I?*6\
MI[F^X[-7N;HN`*A3IK.K_*EWL4N]6*5(J-$@4D%$2553(,7GP](N`+%+O5B]
M5+M[`+%+O5@Z`+%+O5@Z(`"Q2[U8I;*VMZ=KIE@N`+9+I%<`MDND5P"X]*Y\
M`*O=O&:U;K_]H4<`IJBM^P"FRJ3`I/$`L/6FYKK[Q4"^WJ=``+5NI$JKX;#U
MIN:Z^\5`OMZG0#\`Q7:MK0`G)7,G(*JZQ7:MK:6\LU&G4K"C+@#%=JVMNMZR
M>@#%=JVM`*?:JKH`4&5R=2`HK[6^?"D`PV2JJP!0:&EL:7!P:6YE<R`HM>&K
MW[NK*0"Y<;C<`,/`M%D`4&ET8V%I<FX`N;.OP`"]T+9II$K`>*9SKN;"2;_O
M`+W0O52I=ZUNLKZPHZ:YI+BE\SH`O="]5*EWIT&M;J2DPE^FN:2XI?.JNK-S
MM;(N`+W0O^FD2J1`K=.DZZ7WI,ZF?J7W+@"]T+_II$JW<[Q7I,##_JJZIE>Z
MV3H`O="_Z:1*I$"MTZ:SKL2JNB!)4""F[*=]`+W0O^FD2J1`K=.FLZ[$JKJD
MZ;3!.Z3$O^^FN:3KI?>JNJ3IM,$N`+W0O^FD2J1`K=.FLZ[$JKJNR;:A+@"]
MT+2CJ-&PW<-$JKJZ2ZUN+@"]T+_II$JG0:JZJ,^ESJK,IE>ZV:3.L4N]6`"]
MT+Y<Q:JD5:9#I+JN92ZG0:6RMK>F4+=.LV^HQZC&MK6D?J_@J,^ESJATLLXN
M`*9PIK.E]*;SJKJPW<-$O="E2+EQI&RV;*7SP7"UN"!I,3AN0&QI<W1S+FAO
M<F1E+F]R9RX`O="_Z:1*MW.JNJ3`P_ZF5[K9.@!0;VQA;F0@**IIQ/4I`*Q&
MJG8`I^NRO`!0;W)T=6=A;"`HN+*UY:3Z*0"\=KFSINRX;0"J[:[FINRX;0"[
MO+!EMFRE\ZCLLV^MTZM(I?.G6"`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`+/,
MJO$@)7,@I'"NR:JZK;"K0K9Q.B``4')E9G-?;&1A<#H@I^2DHZCLJ=*[W:UN
MJKH@3$1!4""IM:;YKDVE\RX`4')E9G-?<V5S<VEO;CH@I^2DHZCLJ=*[W:UN
MJKH@<V5S<VEO;B"IM:;YKDVE\RX`KO#`HP"N_*6MK;&N\,"C.B``KO#`HSH@
M`+EWQ/T`IF*W<ZJZM?BUH;EWQ/V\=KFS`*17I$"MT[_OMK4`ID.F3*3EI?,`
MJ'"Q2ZKWQE\`L-W#1`"PW<-$M'FM>@"Q3:[7`+2CI=RDNJYE`*2]MGVJ]\9?
M`*2]MGVJ]\9?NG2ZX@"DO;9]JO?&7[CJL%0`I+VV?2^H<+%+JO?&7[GOJ,.E
MO+-1LJ.ES2X`4'5E<G1O(%)I8V\@**IIIFB^I*95*0!1871A<B`HI62Y1BD`
MK&2XWP!24T$@I+VV?:KWQE\@*"5D(*;LI+@I`+_OOMRV<P"K0@"FK::SJT(`
ML=^FLZM"`+!]JT(`JT*FL[.W`*M"PN"SMP#`2+[WI'"[>0"D\;)V`,6JJ/H`
MQ:JH^K9LI?,`KW6JNJUNIU*PHR`E<R"VW#\@LV^VM;[>IT"Q3K5,JFNK[+1?
M+@"O=:JZK6ZR3;"CJ,^ESJK,("5S(*JZN.JNQK;<(#\@LV^VM;[>IT"Q3K5,
MJFNK[+1?+@"H^J[XM%^M[`"MJ[=SON.R>K#*ND&EV+_]I+BE\SH`K:NW<[[C
MLGJMTZ1(K[BE>*2ZKF4Z`+%@LU>J[:7<IJ$`P_;!<,)SQ/V^N0"U^[W7`+NW
MNMVF^*I!OKD`N[>ZW;KTIWT@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.@"ROK"C`+*^L*.PS[;T`+*^L*/$YJ;L`*5HL*.NYJ:A`+*^L*.Y[P"F
MVZ;XJD&^N;S(IG.EV+_]I*2ROK"CI'?`>*9SJKJS7:EWM7NFH2X`LKZPHP"F
MVZ3EI?.DI+*^L*.FN:1`N&#"20"ROK"CJ,^ESJK,`+*^L*.HSZ7.JLPZ("5S
M`+O=J$2EO+-1IE[`LSH@O_F[?KBYO5@Z`*?DI*.H[*G2N]VJNJI!L,@N`"4R
M)',@JKJS7:EWI;*VMZO\J7<@)R4Q)',G`%9&4R"JNK-=J7>ELK:WJ_RI=R`G
M)7,G`+-=J7>XZJ[&I;*VMZO\J7<@)R5S)P"Z[J98LUVI=\#)I*0LI^2DHZCL
MP_:I\R`G9')I=F5R<R>S7:EWN.JNQBX`4&%S<W=D(*JZ(%-13""S7:EWI;*V
MMZO\J7<@)W!H<'1Y<&4G`%-13""S7:EWI;*VMZO\J7<@)W!H<'1Y<&4G`*6R
MMK?$YJ;L`*VKLUT`K:NS7;%+O5@`K:NS7:=!JKJQ2[U8.@"ULJI'`+6RJD<@
M**5=IW0@2&]R9&4I.@"ULJI'.@"J\*9>O^^VM0!2975N:6]N("BO9*6GJ?2N
M<2D`IEZT7[-=J7<`NO2MMKUSO^B^N;_OMK4`P;R[>0"E:\/D`*5KP^2J[<!9
M`*5KP^2MR`"F0Z2ZKF5?=RXN+@"HI*;B`%)O;6%N:6$@*,.YL*BEIZC(*0"Q
MV\+@(#$X,""KUP"P9J[)L'<@.3`@J]>QV\+@`+:VKLFP=R`Y,""KU[';PN``
MID.DNJYE`*9#I+JN90"F0P"NYKUU`,3FINR[4*9#KN:]=0#$YJ;LKN:]=0"F
M0Z[FO74`L/6FY@!2=7-S:6%N($9E9&5R871I;VX@**M8P[FTM2D`4G=A;F1A
M("B_8Z9WN48I`%,O34E-12"E6[%+P[&SN0"V;*7SI'>HSZ7.(%,O34E-12"E
M6[%+`%-!4TP@Q>?#TK5,KL0N`,*RL%0`N.JNQJYWK_.]6@"E6[%+LM>ZW;[W
M`*:HI5P`N.JNQJYWK_.]6E]1`*Q0M,&DNP!386EN="!(96QE;F$@*+ATNZZP
MQZ_'*0!386EN="!+:71T<R!A;F0@3F5V:7,@*+ATITJHO;2UIFBZUJ3.I:>Z
M^[2U*0!386EN="!,=6-I82`HN'3%4Z;HJ,@I`%-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,@*+AT
MI.6TRZ3.KN:WYZBZI$(I`*90I$"MT[7XM:$@*%]S96QF*0!386UO82`HPL2\
MKZC(N'.N<2D`4V%N($UA<FEN;R`HN'2PJ*=1O]4I`%-A;R!4;VUE(&%N9"!0
M<FEN8VEP92`HN'2F:*S\I,ZTMJI,INBD\2D`O<.L4+2CJ-&JS`!3875D:2!!
M<F%B:6$@**A&KU&F8:K\J=2G0BD`P'BF<P#`>*9S("5S`,!XIG,@)R5S)P#`
M>*9SO^^VM0"Q3K*CI<VJNK-=J7?`R:5((%!(4""[>:BEKN:FH<!XIG.H[*=!
MJKJF^*I!OKF\R*9SI=B__:2D+@"S7:EW("5S(*1WP'BF<RX`I_.W<[5[IJ&D
M=\!XIG.H[#H@)R5S)RX`N7.L4+EPJT(`K.R^QP"W:K1-`+=JM$VDWL"Z`+=J
MM$VF8B`E<R"DI*JZJ=*FLR!(;W)D92#`LZ7.M7NFH0"EOZ9BMVJT32!G971T
M97AT("XN+@"_[[[<P,FNUP"_[[[<I$"MTZ3IM,$`O^^^W*1`K=.X<[+5I<ZE
M2+=SO%<`O^^^W*1`INRW<ZJZOM:FLZK,`+_OOMRD0+.AIOBJ0;ZY`+_OOMRD
M0*;LJ,^ESJK,I<ZE2+=SO%<`O^^^W*G2IK.DZ;3!I+BE\RX`O^^^W*1`K=.J
MJZ7S`*GSI4BD5:JZM?BUH:2DO^^H^J=!K6ZJNJ9RI+@NI4BWQKFKO<:[<ZG2
MO^^DY:9R++5-J^&V2Z17I.6E\[USO^BPSRX`O^^^W*3IM,&DP+EJ.@"_[[[<
MI.FTP:3IM,&NYJ:A.@"_[[[<L?W%W*?SJKJHK:7WP]&G3SH`O^^^W*[)MJ&D
MP+EJ.@"_[[[<I.FTP:[)MJ&NYJ:A.@"_[[[<K-NDK*3'L'2JNJ1'K=/$YJ;L
M+@"_[[[<IT&JNL-#IN*P=+AM`+_OOMRPOJ9NNWFHI3H`ML>P9;#=PT2DS\"S
M`+;'L&7"LK!4`%-E;F5G86P@*+;KI+JE6[JX*0"W4+3ZOKDZ(`"D1:3K`%-E
M<F)I82!A;F0@36]N=&5N96=R;R`HMNNZN+K[J,B[4+M8KU.EIZWTP[DI`*?'
MN+D`IOBJ0;ZYN.JNQK_YNWZISJK,M4RJ:ZC/I<XN`+=\M,$@240@I'>Y3+3!
M+@"NUJCZI.BV]`"DN;-<IT&I\Z?1L$^Q2[U8JKJNR:W4+*5II4BFVZ;FK:NS
M7;%+O5@N`+-=J7>[M[K=IOBJ0;ZYI%?$W:GSIT&JNJW3I$BON*5X+@"S7:EW
MIT&JNK"^IFZ[>:BE+""NR;#/I4BDSJ3IM,&NYJ:A+@"S7:EWIT&JNK'2J6S`
MLZ7.M7NFH2S#0Z;BL'2X;2RMMJVQI_.W<\!7LG8LI,ZHY*5,Q>.EW+_OMK4N
M`+-=J7<`I_.W<[5[IJ&T3KK\`*:SIFZT6*W3IF'"2:E-LV^MT[#1O,:FL\/V
M.B``4V5Y8VAE;&QE<R`HMNNI];JX*0#!RJJK`,*RM76Z2ZUN`*Q/IU^LL*1J
MLZ&E]ZJZLW.ULJEWN'&GUK&VI5ROX,'D/P#%XZ7<`,7CI=RW<[*CI<V[4*WL
MP'BF<[-=J7?`R:JZKG2RIRX`J$.FN+5NI$JKX<7CI=RD5Z1`IKBJNK5NI$JN
MR;:A(#\`Q>.EW,))O^^^N0#%XZ7<JNVNYK[>IT"E7*_@JNT@/P"I\Z6JP^3%
MXZ7<("5S(*5<K^"J[3\`Q>.EW,!XIG.NYJ2ZKF6Y[[C<I.BV]`#%XZ7<JNVN
MYJ2ZKF6Y[[C<I.BV]`#%XZ7<ID.DNJYEN>^XW*3HMO0`Q>.EW+QVN;.DNJYE
MN>^XW*3HMO0`Q>.EW*17ML<`J_G$\K!]JT(`IJVFL[!]JT(`L=^FL[!]JT(`
MN[>DZ*:SL'VK0@"FK,%9`%-I97)R82!,96]N92`HM^"D;*1SL.HI`+7YI54`
MIG"J1\'9I*.L3Z7.I.&]T+7YI54`P[&SN0##L;.YNG2ZX@!3:6YG87!O<F4@
M*+=SI5NI62D`I&JD<`"RI+E,NOO%0`"D=[CUN4PN+BX`4VQO=F%K:6$@*+2U
MK*6E[Z=**0!3;&]V96YI82`HM+6LI:7OI:>HR"D`L[<`L'VSMP"P?;.W`*:M
MIK.P?;.W`+'?IK.P?;.W`+]NL[>R8*O7.B``4V]L;VUO;B!)<VQA;F1S("BO
MP<.YJOFX<ZYQ*0!3;VUA;&EA("BOP;"HIU&HR"D`NG&[4+C6`+'&ID.DZ*96
MO^^^W`"HT[>]IF&G?0!3;W5T:"!!9G)I8V$@**MNJT0I`*MNO-H@*$E33RTX
M.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)
M<VQA;F1S`*MNI6*R>0"JQ:75IN8`MJ&V6@"VH;9:NU"YU*52`%-P86EN("BF
MZ*]:I/HI`*E5IZ.V;*7S`*]3KNVF<J2XO^FD2@"DP+/.P'BF<P"DP+/.Q.:F
M[`"DP+/.ID,`N4*PR@!3<FD@3&%N:V$@*+2UJ+W$]:5D*0"\T+?'`+'2J6RF
M?J7W`*S9`*JLND$`NWFH="`E<R"JNJJLND$N+BX@`,!XIG.NYJ:A`+7SN40`
MIU*PH[UU`*9RINJF0P"FV[9LI?.F8:=]I*2E:+"CNO2P[*97NMD`O,NFH2!;
M0U-370"L4+3!I-$`I^2DHZCLIKBEV+_])R5S)P"E1*:N`+!EI5@`O%>E6R`G
M)7,G(*CLJ'2RSJJZN]VH1*1WL&6E6"X@IT&ELK:WM:6H[+C3N]VH1+-1KM:M
MXZOAI'ZOX+5NI$HN`*15O-``IJBE7`"FJ*5<JKJE6Z1*("<E<R<@J.RH=++.
MI*0N`*:HI5RJNJ;;J'2RSJ2DLDVPHZC/I<ZJS"`G)7,G(*JZN.JNQBX`IJBE
M7*JZIU*PHR`G)7,G("X`IJBE7*JZIMNH=++.I*2ROK"C("<E<R<@+@"D=Z:H
MI5RJNJ9>M%^S7:EW+B"]T*VKMW.X_*1*P,NU^*YTLJ<N`*1WIJBE7*JZL\:E
M][-=J7>XZJ[&+@"D=Z:HI5RJNK/&I?>S7:EWN.JNQB`E<RX`IJBE7*JZI_.W
M<R`G)7,G`*1WIJBE7*JZPM"\9R`E<P!3=61A;B`HQ*RDIBD`NDNM;@"DZ:58
M`*3IN*@`M+@`I.FE6`"DZ:58+Z3IN*@`I.FE6#H@`*3IN*@`I.FXJ#H@`*17
MO-``I.2TJ0!3=7)I;F%M92`HQ*RG4:MN*0"Z[[BY`%-V86QB87)D(&%N9"!*
M86X@36%Y96X`4W=A>FEL86YD("BE=J7+P-G$]2D`4W=E9&5N("BWYZCE*0!3
M=VET>F5R;&%N9"`HM^>D:"D`MVJT3;:UI=BDI*JZNWFJ:[_YNWX`4WER:6%N
M($%R86(@4F5P=6)L:6,@*+'4IU&HR"D`N7"K0@"Y<*M"IK.MMP"Y<*M"`%1!
M0B"DP+EJKN:FH<#)KM<`JNVSY@"J[:[FI+JN90"J[:[FI+JN90"E>,97`*5X
MQE<`5&%J:6MI<W1A;B`HMO"F3K2UJ5HI`%1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8@**E:J7REIZC(*0"EV+S0.@"KW;_LJ,:VM0"Y<;C<N+F]6`"S
MS*KQI$"D<*[)JKJWQ:O7.B``M\6KUP"WQ:O7.B``I^2DHZCLO,NJ3R`G)7,G
M+@"\RZI/NMZR>@"DNJYE`*_"I.6F<@"Y[[OTI.6F<@"Y[[OTI.6F<K.[NMT`
MK%"TP:5\`*[UI.4@*%1)4RTV,C`I`%1H86EL86YD("BN];#J*0#!PL'"IT&H
MSZ7.I;NH=++.+@`E,B1S(*JZ("4Q)',@NZ&I^L#)J,.DHZ9SIF(N(*6_IF*K
MV*7?I$"MT[=SJKJ[H:GZP,DN`$944""IM:;Y*&5X=&5N<VEO;BFU3*[$+@!(
M;W)D92]+;VQA8B"^XZ98I'6U>ZC#I;RDY+2I("(E<R(`36%I;G1E;F%N8V4@
MP_ZG3ZC#I;RFJ*5<N/RD2@"_[[:UM?BUH:5(P_:SK"["][9]I*0N`*=!JKJH
M=++.NMZR>JW[I;*VMZ7]LUVI=Z9NI$"MT\5VK:VKX;K=I'ZOX,7]IT&HSZ7.
MQ7:MK:ATLLXN`*FSKMB]=0#!<+6XN+F]6*6\J_RI=RRJQ:75J<ZF8KCJKL:N
M=Z2DI^2DHZCL+@"D=Z:HI5RJNK%.P7"UN*1(MW.\5Z;<LW&P5+_]I*0N`,7G
MP]*V;*7SP[&SN;O=K6ZFLZ1`K=.D=[C1MGVJNB!01U`@L,^V]"X`L'2X;;AS
MLM6JNL/1IT^XN;U8*$E$*:2CK$^EO*O\J7<LM$ZL3ZK%I=6ISJK,I*.F8KCJ
MKL:N=Z2D+@"P=+AMN'.RU:6\J_RI=RX`N]VM;J1`K=.X9[E,I5NQ2ZJZNO2X
M]+-SM;(N`,#)KM<@)7,@P+.XTZ5=IW2D0*W3("5S(+-=J7<N`,#)KM<@)7,@
MP+.XTZ5=IW2D0*C'("5S(+-=J7<N`+5,JFN]QKMSJ.RFVZBMP,FNURX`IKG`
MR:[7I*2H4Z:SN.JNQBX`I4BD5:Q/(')F8S@R,B"V;*7SJKJJ[<!9+@"H1*=5
MP,D@)7,@J,.EO*5((#P_>&UL(+9]J6P`J*VE]\/1IT\@)7,@I'>S4:=2L*,N
M`*6JKMB]=0!';G501R"D1Z2XP,FJNKCTKGRELK:WJ7>X<:9B($-R>7!T7W!G
M<#HZ(,/^IT^DI"X`IT&TOZGS("5S(+%(M;D@)7,@I$"KRJ5$IJZLL"`B)7,B
M(*JZJTBE\Z1WLU&V?;'2+@JF_;-OJ,.DHZ_@JT_#TKC3JTBE\ZJZI+JN9:1W
MI[FE_K-1IJRE\Z1(K-VGN:G.I$:XT2X`LW.ULJCLO7.\9[9LI?.MMJVQJ=*H
MSZ7.JKJF5[K9`$AO<F1E7T-R>7!T7W-M:6UE.CH@P_ZG3RRELKO=K6ZFLR!O
M<&5N<W-L(+S2LM4N`*:YL+ZF;B`B)7,B(+CJKL:F7:RPME>Y3+/,I&JDN;-<
MK<@LJ=*E2+5,JFNS4<!XIG,`I<ZE2,#+M?BFN;CJKL;#_JNL("@E<RD@JKJU
M>Z:AJ,.DHZ9SIF*I\ZATLLZD5RX`I:JE:Z[8O74`I6NNV+UU`*:YIOBJ0;ZY
M("(E<R(@I'>S4:=2L*,N`*:YIOBJ0;ZY("(E<R(@I'>S4<!XIG,N`"5S(*JZ
MM?FE5;O=J$2D=[-1LKZPHRX`J_RI=ZJZL$^__:C#I*.F<Z9B+@"\R*9SP,FN
MUR(E<R*DHZ9SIF(N`*17I%6NV+UU`*17KMB]=0"Q<:17I$"MTZA"QDJDIZOA
MI%>VQZJZN.JNQK_RI:(N`*17ML?`R:[7J,.EO+-1P'BF<RX`=V5A=&AE<BYC
M;VT@L,^V]+5,JFNHSZ7.+@"GY*2CJ.R\RZ:AL'2X;:78O_T@)R5S)RX`M4RE
M::7.JKJ_[[:U+@"U3*K^I?.E::J]L;6V?;'2+@"FN<3FINRDI*5=IW2DTZ9H
MJKJF<KS&+J=!I'>_Z:1*("5S(*W3IG*\QCNG0;_II$JJNJ9RO,:ELK:WI'"I
M\R`E<RX`)7,@I*2GY*2CJ.RH1*=5P,DN`+=SO%<@)R5S)R"H[*ATLLX@)7,@
MKLFU;Z7-I$"MT[#=PT0N`+=SO%<@)R5S)R"H[*ATLLXZ("5S(*[)M6^ES:1`
MK=.PW<-$+@"FVZATLLZR3;"C("<E<R<@JKJXZJ[&KLFU;Z7-I$"MT[#=PT0Z
M`*;;J'2RSK*^L*,@)R5S)R"NR;5OI<VD0*W3L-W#1#H`I_.W<R`G)7,G.B`E
M<R"NR;5OI<VD0*W3L-W#1`"D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E<R"E
MO+-1I%>VQRX`I%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@)7,@I&JD<+97N4RD
MN;-<L\RD:JW(("@E9"!B>71E<RDN`*17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z
M(+;(LZ&DP*JZ("5S(,#)KM>S4:17ML<N`,#+M?BV;*7SKLFU;Z7-I$"MT[_Y
MNWXN`+;7I$JFN;-QL%2__;CJKL:NR;5OI<V_^;M^+@"VUZ1*(&E#86QE;F1A
M<B"XZJ[&KLFU;Z7-I$"MT[_YNWXN`*9BLUVI=ZKML^:DI+5OI<VD1J1`K=._
M^;M^+J:SI6FOX*=!O_*Z?*1&I;*VM[;QO&>JNL3FINPN`+9]L=+`R:[7("5S
M(*[)M6^ES:1&I$"MT[_YNWXN(+W0N<&XU:7.('1R86YS;&%T:6]N+G!H<"`M
M9""K_*5/L/6FYBRLW:S=K$^G7Z:SI?2F\R!X;6P@N-&J4KZYJ=*RHZ7-JKJ_
M^;M^L%2NIRX`L/6FYK-QL%2__:O\J7>E7*_@KLFU;Z7-I$"MT[_YNWXN(+W0
MM7FKX:9!N-6D0*:X+@"G\[=SP7"UN*1(N.JNQJ[)M6^ES:1&I$"MT[_YNWXN
M(+W0M7FKX:9!N-4N`*?SMW.P=+AMN'.RU:[)M6^ES:1&I$"MT[_YNWXN(+W0
MM7FKX:9!N-4N`*:Y($E-05`@IOBJ0;ZYJ,.EO*3DM*FK2*7SIUBDP*C)I5RO
MX"X`LV^F_*5'I*.L3Z6_O52JNB!R87(@P*/!6<#)KM<N`+-OIORE1Z2CK$^E
MO[U4JKH@>FEP(,"CP5G`R:[7+@"S;Z;\I4>DHZQ/I;^]5*JZJTBESJ5DN+F]
M6"X`IKG$YJ;LK$^ELKO=K6ZJNBX`IKG$YJ;LI+JN9:5UI+FS7+[CO,:\QJ9R
M+@"FN<3FINRDNJYEI76DN;-<O,:F<J3.JU^XN2X`IKG$YJ;LI+JN9:5UI+FS
M7*1+MFFF[+S&K<@N`*:YQ.:F[*2ZKF6ELK:WK+"S<KBYJ<ZJQ:75I,"Y:JJZ
MO,:F<@"ELK:WK$^D0*W3O,:F<BX`IKG$YJ;LI+JN9:6RMK>E7:=TI$"RU:11
MI+NV::;LJKH@4D="(,-#IN*E3KU8+*C2IG`@)R,Q,C,T868G+@"S;ZW3JNVS
MYJ1WLU&S0K)ZN4PN`+-OK$\@)7,N`+-OK$\@2V]L86(@N'.RU:JZI$"MTZJK
MI?,N(+']P,NU^*:YJJNE\[O=K6ZOX*3DM*E+;VQA8B"X<[+5KN:FH:JZN7&D
M;+9LI?.S;L7I+KW0L-&FTB`E<R"E2*1&N-&S;ZC'MFRE\[-NQ>D`LV^KRK9L
MI?.HPZM$I4BG0;I$I<ZJNJ9RI+BVL*;3K$^HSZ7.("@E<RD@KM&\9Z;3IJ@N
M`*:YO,:MR+/,I-:ELK:WK$\@,2X`IKFU>Z:AI76OX*9BJ5*E3Z9#I%>P]:;F
M*&-O;6UA;F0@;&EN92DN`*:YIOBJ0;ZYM4RJ:[GO('II<""DSB!G>FEP(*[F
MIJ'`R:[7MFFFYKC1P*/!60"FN:ATLLZEV*MEK$^PL:7.JKJJK+I!+@"ELK:W
MK$^D0*W3O,:F<BX`IKFU^+6AI;*VMZUNI=&_[[:UM?BUH2A/<'1I;VXIJ=*I
M2:5S`+EP`+#=PT2P;,+<`*[)MJ$`KLFVH:O\JVX`KLFVH:[FIJ$`KLFPS[_O
MOMP`5&EM;W(M3&5S=&4`O-##1`"\T,-$("AT;V]L=&EP*3H`IJRE\Z1(`*9P
MJD>M;KW&O^\LO="F8L))O^^WQKFKJKJF4*[)J_8@0V]N=')O;,'D**W3I$BY
M<;BC*2"ISB!#;VUM86YDP>0HQ*NJ1[EQN*,I+@"DM:31`$A434P@K>RI;,#)
M`%1O9V\@**9HK?0I`%1O:V5L874`J?JDT0!4;VYG82`HJD:E6RD`L[NSH0"S
MS*17O&BNV*Q;("A?=&]P*0"D=\*]Q+8`I&2HO;E&I,ZFJZBIK?0`KW6ISK"P
M`*Q0M,&D1P!4=6YI<VEA("BL\*6GINBHR"D`5'5R:V5Y("BD9Z;5J.0I`*1G
MIM6HY*3E("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A
M:6-O<R!)<VQA;F1S`%1U=F%L=2`HI&>ER[Y\*0"_Z:1*IT&JNK_OOMPZ(`"U
MM:5^O76K_+S&.B``NO2G?0"Z]*=].@!59V%N9&$@**]1I'JY1BD`56MR86EN
M92`HKU&G2L3U*0"U3*IKIG.H^B!61E,@I=B__2X`M?FE5:[)M4RJ:[Q7I5O#
M0J5^JKJHSZ7.JLRXZK!4+@"U3*IKI^_%W"!61E,@P,FNUR`B)7,B(*JZQ7:M
MK2X`M4RJ:\7<I_,@5D93(,#)KM<@)7,O)7,@JKK%=JVM+@"U3*IKQ=RG\ZRP
M("5S+@"U3*IKLW.ULB!344P@IOBJ0;ZY+@"U3*IKJ,^ESB!34TP@LW.ULBX`
MM4RJ:[W&NW,@5D93(,#)KM<N`+5,JFNKV*7?(%9&4R"EV+_]("(E<R(N`+5,
MJFNKV*7?(%9&4R"EV+_]+@"U3*IKJ]BEWR!61E,@P,FNURX`M4RJ:ZO8I=^J
MQ:75JKH@5D93(,#)KM<N`+5,JFNQ3KCJKL:XT<"CP5DN`+5,JFNG4K"C("(E
M<R(LIKFEV+_]J,.K1*K%I=4N`+5,JFNG4K"C("5S+*:YI=B__:C#JT2JQ:75
M`+5,JFNG4K"C("<E<R<Z("5S+@"U3*IKN[RP:J=2L*.EV+_]+@"U3*IKIU*P
MHR!61E,@I=B__2X`M4RJ:Z=2L*,@5D93(*78O_TZ("5S+@"U3*IKIU*PHR!6
M1E,@P,FNUR`B)7,B+@"U3*IKIU*PHR!61E,@P,FNURX`M4RJ:[N\L&JG4K"C
M(%9&4SH@)7,N`+5,JFNG4,)?I=BK9:JZI=B__2X`M4RJ:[C1MGV^S,/2LM.X
M8`"U3*IKN/RD2B5SJKJI=[AQ+@"U3*IKMVBROB!61E,@P,FNURX`M4RJ:[9]
ML=(@5D93(,#)KM<@(B5S(BX`M4RJ:[QGI$H@5D93(,#)KM<N`+5,JFNV?;'2
M(%9&4R#`R:[7+@"U3*IKMGVQTL"CP5G`R2X`M4RJ:\6JJ/K`R:[7.B``M4RJ
M:\6JJ/H@=F9S<F]O=""EV+_]+@"U3*IKI_.F5R`E<R"LL"`E<SH@IEVLL*78
MO-"K2*7SIUBD=Z9SIF(`M4RJ:\7<I_,@5D93(*78O_VJNJ97NMDN`+5,JFNR
MOK"C(%9&4R"EV+_].B`E<RX`M4RJ:\7<I_,@5D93(,#)KM<@(B5S(B"JNJ97
MNMDN`+5,JFO%W*?S(%9&4R#`R:[7("5S+R5S(*JZIE>ZV2X`M4RJ:\7<I_,@
M5D93(,#)KM>JNJ97NMDN`+5,JFNP]:;F("=M:VES;V9S)RX`M4RJ:\+@M*L@
M5V]R9""DY:7S`+5,JFN\9Z1*(%9&4R`B)7,B(,#)KM<N`+5,JFN\9Z1*(%9&
M4R#`R:[7("AC;W!Y*"D@9F%I;&5D*2X`M4RJ:[QGI$H@5D93(,#)KM>XZJ[&
M+@"IL[UU`*CZKOBG\Z?O`+1?K>P`IOBJ0;ZYLW.ULJ[)M6^ES:6\N7>TP:JZ
MIE[`LSH@`+5OI<VEO+EWM,&JNJ9>P+,LI=&F^*I!OKDZ(`"EO*3`P_X`N%6P
MZKU8("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,@**K\J=2G0L%PIEBD
M:J2]L.HI`%5N:71E9"!+:6YG9&]M("BM7K#J*0!5;FET960@4W1A=&5S("BL
M_+#J*0!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`L^:F
M[`"EO*J^JKH`I;RJOJJZ($%022"P5*ZGO7.XN2`H05!)($UE<W-A9V4@240I
M+@"EO*J^JKJKR*3AL%2NI[USN+D@*$%022!-97-S86=E($E$*2X`I;RJOJJZ
MJ5*E3SH@)7,`I;RJOJJZINRX;;CJL%0N`*6\JKZJNJC/I<ZJS*97NMFISK%+
MO5@N`*2DPE^EV*MEI+BE\ZJZLW.UL@"EO*E2IE<`IEVF=Z7^Q56\>Z2CI+FS
M7*6\L<+%=JJZM7NFH;#UIN:PQ:15+[W&NW,OMDND5RX@PDF_[[U4J7>E2,#+
MM?@@;6]Z:6QL82YO<F<@J=*THZC1JKJLV\/VI]ZS3J3EI?,LQ?VG0:5II4BX
MT;"CIKFD0*VMJ.ZHPZ;;IN:V?:GQM7NFH:9SJ/JPQ;9+PZ\N`*CZKOC#0Z;B
M`*6\I.2TJ:JZL,;`R:97`*6\PKW$M@#%W*?S`*?SMW,@)7,`I_.W<ZC/I<ZJ
MS`"D=Z?SMW,@)R5S)RX`I;^F8J?SMW,@)3(D<R`E,21SJ$2G5<#)+@"G\[=S
MM7NFH:1WIU*PHRX`I%>VQP"D=Z17ML>ITJ:SP+.ESK5[IJ&JNK-=J7?`R:CL
MIOBJ0;ZY+@"D:KQGJ=2D0KS&IG(`I&J\9\.YL*B\QJ9R`%5R=6=U87D@**]1
MJ=2F8RD`NWFJ:SH`J,^ESJ78JV6JNCH@)7,`J,^ESB!34TP`IG"J1Z=!JKJH
MSZ7.JLRF5[K9+[%+O5B[4"!)35-0(*;XJD&^N:2CIE`LI6FF8J:YLUVI=RX`
MJ,^ESJK,("5S(*6\LW&Y3"`E<R"JNK'"Q7;%Y\/2+@"HSZ7.JLRZWK)Z`*C/
MI<ZJS+_OMK4`J,^ESJK,M?FE50"FN:^XI7BJNJC/I<ZJS+7YI56H=++.I'>P
ML:7.+@"GY*2CJ.RHSZ7.JLP`I^2DHZCLJ,^ESJK,+@"HSZ7.JLS%=JVM`*C/
MI<ZJS*97NMD`J,^ESJK,IE>ZV2`G)7,G(*1WIG.F8BX`J,^ESJK,IE>ZV3H`
MJ,^ESJK,.B``J,^ESJK,`*ATLLZDI*JZJ,^ESJK,.@!5>F)E:VES=&%N("BO
M4:_WIT^G2BD`5D93(*78O_VHPZ2CIG.F8BX`L+*TP0"D=Z?DJ.RFLZ[$JKJF
M8<)).B``IK.NQ*G*`*5(I,#$P:RPL^:F["BQ<;)[IF*P7[KB*0"MR`"_[ZCZ
MK<BFVP!686YU871U("BERZ6CJORYSRD`Q=RDQ@!696YE>G5E;&$@**EEI+JW
MYZG4*0#%Y\/2I:*QT2`M(*:YMFRE\Z5IK^"D=[Y$I$B^U:;;OWFG[RX`JJFE
MNP"JJ:6[L;&H[@"KJZJ]N>^[]`"KJZJ]N=2E4@"KJZJ].@"K1+%@L*H`5FEE
M="!.86T@*+96JVXI`+96JVZDY2`H5DE30TE)*0#`R[7X("5S`*9BMW.U^+6A
MMGVQT@"E2"`E<R#`R[7X`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H("BM7L3=
MNONHRKASKG$I`%9I<F=I;B!)<VQA;F1S+"!5+E,N("BL_,3=NONHRKASKG$I
M`*_@J*.KUP"OX*BCJ]<Z(`"X<:1JIU&E\;QWK;>Y<:M(I+VE<;-ZN4P@4TU4
M4`#$M:=I`,2UIVDA(2$@L7$@)7,@I.*PRK*^L*.U>Z:A+@!786QL:7,@86YD
M($9U='5N80#$M:=I`,2UIVDZ(`"L4+3!I%0`I-&N\+EWM/H`KO"V2+CJKL:T
MHZC1`'=E871H97(N8V]M(+KTK[@`NO2ON`"Z]*^X`*A#MF<`Q7>J[P#%=ZKO
MJ.P@)7,`Q7>J[RP@)7,`INB\VB`H25-/+3@X-3DM,2D`INB\VB`H25-/+3@X
M-3DM,34I`%=E<W1E<FX@4V%H87)A("BFZ+R[JZ*IU"D`M6ZD2JOAP+.XTZ7]
MQ>.EW"`E<R"M_J1`K=/`LZ7.M7NFH3\`Q.:F[*JZI,"Y:J9RI+@_`*3>K7JJ
MNJMEN&VF<J2X/P"M_JW3I.NLVP"Z]*VVO7._Z+ZYJKJTH:7S*'!L=6=I;G,I
ML=*PRK&QJ.XN`+QEJ]<`I4@@0U-3(*RPL^:F[*JZO&6KUP"EJL/D)7.E7*_@
MJNVJNKQEJ]<HI%6FN+5NI$JI;*7-KL0I.@"J[:[FO&6KUP"\9:O7L^:F[`"\
M9:O7.@"VL,7IL]"G0`"MMP"FK::SK;<`K;>S="BX8"D`K;>S=#H`K;>S=#H@
M`+2\O'H`M,&KW;:UI=@`I'6G0`"_[*2]J\>F8:=]`+_LI+VKQ[EQN-P`I;^F
M8KQGI$JH1*=5P,FH["`E<RX`6#4P.78S(*FUIOFJ]\9?NWFJ:P!8-3`Y=C,@
MI42FKJKWQE_#T:=/JLP`6#4P.78S(+#&P,FF5P"F?@"F?@!986AO;R`A(*9A
MN<\`J$.F?@!996UE;B`HN*VJ^2D`K$\`K$^JNBRGVJ90MTX`IT&EV*MEJ,^E
MSJ_"I.6F<KUSO&>\TJ:A+B"HSZ7.(%L\/ET@J_:V<Z5II,&TJZRPNO2MMKUS
MO&>\TJ:A+@"G0:6\LU&QPL5V+@"G0:JZI?ZF5Z2DI*.E:::S("=<)R"S;[S+
MJKJF<J2X+B``IT&DHZ_@Q=RG\ZC/I<ZJS"`E<R"JNK%+O5@`IT&HPZ6\O^FD
M2J1`K=.FLZ[$JKJY<:1LMFRE\Z;LIWTN`*=!J,.EO*71MM>D2JJZP,FNUZ2D
MN>^L3:7TIO/$YJ;LJ.P@)7,`IT&D=[AGM6ZE6"X`O="_Z:1*I$"MTZ:SKL2J
MNKEQN-RXN;U8++#JN]JY<;C<N+F]6+;(I76DN;-<O,:F<KBYO5@LJ,.U^+&A
MJG"E::GSJV6ML:9!I5ND0*W3("<K)RX`IT&ELK:WO^FD2J1`K=.FLZ[$JKJM
MR"X`IT&ELK:WI?VS5[FZIFZ^\*JLN.JNQBA$871A5')E92FF^*I!NMVD?J_@
MQ'[$\JC/I<ZW<Z7.I.&U^:55JD&PR"X`IT&ELK:WI?VS5[FZI$"MT[7JP,#`
MR:[7J'2RSBA61E,IIOBJ0;K=+@"]T+1YK7JPW<-$H4&F8J=!ML>P9;#=PT2S
M^*=II*>K92X`IT&ELK:WO^FD2J:YLW.ULJG2J_RF5JJZNO2G?0"G0:6RMK>_
MZ:1*I=BK9:JZL4N]6`"G0:6RMK>_Z:1*MW.Q2[U8`+W0J_RI=ZUNIU*PHZJZ
MIOBJ0;ZY+@"]T*O\J7>M;K)-L*.JNJC/I<ZJS"X`O="K_*EWK6ZROK"CJKJH
MSZ7.JLPN`+W0J_RI=ZUNMW.\5ZJZJ,^ESJK,+@"]T*O\J7>M;J?SMW.JNJC/
MI<ZJS"X`O="K_*EWK6ZP]:;FJKJG0*7.+@"G0:6RMK>_Z:1*MW.DP,/^JKJF
M5[K9+@"G0:6RMK>]5*EWIT&JNK=SL4N]6`"G0:JZ("5S(+=\M,&D=[E,KLDN
MO="MJ[=SM6ZD2BX`IT&JNKEQI&RV;*7SINVG?0"G0:JZL4BE\Z1(N7&D;+9L
MI?.F[:=].@"G0:JZN.JP5`"FV[%QIT&JNB`E<R"W?+3!MGVI;*5(J-.G0:JZ
MNO2[VKKTN/2F[*=]I'?%W*?S+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!I;*V
MMZVKMW.U;J1*+@"G0:JZIE>ZV0"G0:JZQ>?#TKK=J,.EO*3DM*FW<[Q7J,^E
MSJK,J<ZXTZ5<K^"D=[-1P_:SK"X`IT&JNL7GP]*ZW:C#I;RDY+2IID.E6*C/
MI<ZJS*G.N-.E7*_@I'>S4</VLZPN`*;;L7&G0:JZ("5S(+=\M,&V?:ELI4BH
MTZ=!JKK"<\3]OKFF_*5'I'?%W*?S+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!
MI;*VMZVKMW.U;J1*+@"G0:JZPG/$_;ZYJ,.EO*3DM*FS;ZW3I5ROX"X`IT&J
MNL)SQ/V^N:C#I;RDY+2IID.F3+_OMK4NO="K]B!#5%),+T-O;6UA;F0@*R!0
M(*9#IDPN`*=!I=BK9:G2LUVI=ZJZKLFPSSH`N]6D5;EWLUVJNJBMI??#T:=/
M.@"G0:JZI?ZF5SH`IT&JNB!G971T97AT(*JII;NDT\+"J,.E0J2CI.2TJ2!0
M2%`N"J9=IKFHPZM$J=*FLZJZIG*FZK.CK^"S4:6_O52JNKC1MGTN`*=!IF(@
M)7,@I*2JNK=SL4N]6*Q/.B`E<P"G0:JZMW.Q2[U8I-.J^#NSS*9HI*.OX+97
MN4P@)60@K=.F<B$`IT&JNK=SL4N]6*33N4S"LK/FIK.S4;)QJ.RJNJ5IK^`A
M(+5,JFO%W*?S(0"G0:JZMW.Q2[U8I-.Y3,*RL^:FL[-1LG&H[*JZI6FOX"$@
MM4RJ:\7<I_,A`*=!JKJW<[%+O5BFW*36K6ZFLR`E9""MTZ9R(0"G0:JZMW.Q
M2[U8I;*VM[M0I=BK9:JZL4N]6*:SJ=*DHZ90`*=!JKJW<[%+O5BFW*36K6ZE
M7:=T("5D(*W3I4BD5ZJZK5ZDY:9R+@"G0:JZMW.Q2[U8IMRDUJUNI5VG="`E
M9""MTZ5(I%>JNJU>I.6F<KM0O,:F<BX`IT&JNK=SL4N]6*;<I-:M;J5=IW0@
M)60@NMBDHZ90JZRZ0:JZI.6F<BZS;ZC'JZRZ0:5=K$$ZI'"\9ZU>I.6F<BRD
M:KQGK5ZDY:9R++S&IG*E2*3.LL6XN2X`IT&JNK=SL4N]6*;<I-:M;J5=IW0@
M)60@K=.E2*17JKJD<+QGK5ZDY:9R+@"G0:JZMW.Q2[U8IMRDUJUNI5VG="`E
M9""MTZ5(I%>JNKS&IG(N`*=!JKJW<[%+O5BFW*36K6ZE7:=T("5D(*W3I4BD
M5ZJZI&J\9ZU>I.6F<BX`IT&JNK=SL4N]6*2CL6^E7:=T("5D(*W3I4BD5ZJZ
MJL6EU:9R+@"G0:JZMW.Q2[U8I*.Q;Z5=IW2JQ:75IG(N`*=!JKJW<[%+O5BD
MH[+%IE@`IT&F8K5NI$JTP;:AJKJ_[[:UI'>S4:?SMW,N`*=!JKJ_[[:UI'>G
M\[=S+@"G0:JZL4N]6*1WK:NW<[-=J7<`L4N]6*1WLU&MJ[=SLUVI=RRW<ZJZ
ML4N]6*1WLWJY3+EQI&RV;*7SL4BU;[W0I4BXT[%+O5BU;J1*+@"G0:JZN[>Z
MW:;XJD&^N3H`675G;W-L879I82`HJVZTM:G4I-(I`%IA:7)E("C"Q*7L*0!:
M86UB:6$@**E\I/&HR"D`6FEM8F%B=V4@**BOI-JKPBD`6\'TPL.DWJUZ70!;
ML-W#1*3/K$U=`%O%XZ7<I-ZM>B`M`%O%XZ7<I-ZM>B`M("5S(*;F70!;INRI
M\Z;F("5S(*9`("5S(*;F70"ZWK)Z7T$`J5*E3Z9#7T,`OO"JK+CJKL9?1`"G
M4K"CID-?1`"X<[+57T<`NZ&I^E](`+QVN;.DNJYE7TDN+BX`M6ZD2E],`+5N
MI5A?3`"MUZ?OLW.ULE]-+BXN`+_OMK5?3P#%=JVM7U``LKZPH[GOLW.ULE]2
M+BXN`+-=J7=?4P"J[:[FI+JN95]4+BXN`*C/I<ZJS%]5`+-QL%2__0"U;Z7-
MI$:D0*W3O_F[?CH`IN:HQK[D`*OVIKD`I[FFJ`"EHK'1`,#)KM<`I^2H[#H@
M`+%Q("5S("@E<RD@J?,@)7,@)7,`KLDZ`*[)`*7?IUD`JKVQM<7CI=RI\Z6[
MI.6PSP!L9&%P7W-T87)T7W1L<R"EHK'1`*;F70"DP`"F5[K9`*6\Q=RG\RX`
MI^2DHZCL`*E\I;RYZJ=`+@"I?*6\N>JG0"X`L\:GT;_]`*;*I,"D\0"YLZ_`
M`*17I,D`Q>.EW*YTLJ<`<VUS,F5M86EL(+AGI=$@2%144`"L[0##K:EW`*O=
MO^S#KP!(;W)D92"JNJ6[IF&[>:AT("5S(%!/(,#)J,.DHZ9SIF(Z`*9!IKB_
MZ:1*IT&JNK%+O5BE2+U4NWNU3+M^`*1WO=6^XP"EO*E2IE<`I'>G\[=S`*C/
MI<ZJS+_OOMP`=D-A<F0`K%"TP3H`=V5A=&AE<BYC;VT@NO2ON```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]I;F1E>"YP
M:'``````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$R-C<`,3`T,3<S-C(W-#0`,#$W-34P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z('!A
M<W-W9"]I;F1E>"YP:'`L=B`Q+C$U(#(P,#4O,#@O,38@,3<Z,SDZ,C8@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#4@17)I8R!*;VX@4F]S
M=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A!4TPI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+V%S;"YP:'`N
M"B`J+PH*0&1E9FEN92@G4$%34U=$7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2D["B1P87-S=V1?8V]N9FEG=7)E9"`]("A`:7-?<F5A9&%B;&4H4$%34U=$
M7T)!4T4@+B`G+V-O;F9I9R]C;VYF+G!H<"<I("8F"B`@("`@("`@("`@("`@
M("`@("`@("!`:7-?<F5A9&%B;&4H4$%34U=$7T)!4T4@+B`G+V-O;F9I9R]B
M86-K96YD<RYP:'`G*2D["@II9B`H(21P87-S=V1?8V]N9FEG=7)E9"D@>PH@
M("`@<F5Q=6ER92!005-35T1?0D%312`N("<O+BXO;&EB+U1E<W0N<&AP)SL*
M("`@($AO<F1E7U1E<W0Z.F-O;F9I9T9I;&5S36ES<VEN9R@G4&%S<W=D)RP@
M4$%34U=$7T)!4T4L(&%R<F%Y*"=C;VYF+G!H<"<L("=B86-K96YD<RYP:'`G
M*2D["GT*"G)E<75I<F4@4$%34U=$7T)!4T4@+B`G+VUA:6XN<&AP)SL*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!A<W-W9"]M
M86EN+G!H<```````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,C0U-#,`,3`T,3<S-C(W-#0`,#$W,S8W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z('!A<W-W9"]M86EN+G!H<"QV(#$N-C<@,C`P-2\Q,"\P.2`Q-#HT.#HU
M."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-2!%<FEC($IO
M;B!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D
M=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$%33"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O87-L
M+G!H<"X*("HO"@I`9&5F:6YE*"=005-35T1?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I*3L*<F5Q=6ER95]O;F-E(%!!4U-71%]"05-%("X@)R]L:6(O8F%S
M92YP:'`G.PIR97%U:7)E(%!!4U-71%]"05-%("X@)R]C;VYF:6<O8F%C:V5N
M9',N<&AP)SL*"B\O(%5S92!A(&1O+7=H:6QE('1O(&%L;&]W(&5A<WD@8G)E
M86MI;F<@:68@86X@97)R;W(@:7,@9F]U;F0N"F1O('L*("`@("\O($AA<R!T
M:&4@=7-E<B!S=6)M:71T960@=&AE(&9O<FT@>65T/PH@("`@)'-U8FUI="`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=S=6)M:70G+"!F86QS92D["B`@("!I9B`H
M(21S=6)M:70I('L*("`@("`@("`O+R!.;R!S;R!W92!D;VXG="!N965D('1O
M(&1O(&%N>71H:6YG(&EN('1H:7,@;&]O<"X*("`@("`@("!B<F5A:SL*("`@
M('T*"B`@("`O+R!'970@=&AE(&)A8VME;F0@9&5T86EL<RX*("`@("1B86-K
M96YD7VME>2`](%5T:6PZ.F=E=$9O<FU$871A*"=B86-K96YD)RP@9F%L<V4I
M.PH@("`@)&1R:79E<B`]("1B86-K96YD<ULD8F%C:V5N9%]K97E=6R=D<FEV
M97(G73L*("`@("1P87)A;7,@/2`D8F%C:V5N9'-;)&)A8VME;F1?:V5Y75LG
M<&%R86US)UT["B`@("`D<&%S<W=O<F1?<&]L:6-Y(#T@:7-S970H)&)A8VME
M;F1S6R1B86-K96YD7VME>5U;)W!A<W-W;W)D('!O;&EC>2==*0H@("`@("`@
M(#\@)&)A8VME;F1S6R1B86-K96YD7VME>5U;)W!A<W-W;W)D('!O;&EC>2==
M"B`@("`@("`@.B!A<G)A>2@I.PH*("`@("\O($=E="!T:&4@=7-E<FYA;64N
M"B`@("!I9B`H)&-O;F9;)W5S97(G75LG8VAA;F=E)UT@/3T]('1R=64I('L*
M("`@("`@("`D=7-E<FED(#T@571I;#HZ9V5T1F]R;41A=&$H)W5S97)I9"<I
M.PH@("`@?2!E;'-E('L*("`@("`@("!I9B`H)&-O;F9;)VAO;VMS)UU;)V1E
M9F%U;'1?=7-E<FYA;64G72D@>PH@("`@("`@("`@("`D=7-E<FED(#T@2&]R
M9&4Z.F-A;&Q(;V]K*"=?<&%S<W=D7VAO;VM?9&5F875L=%]U<V5R;F%M92<L
M(&%R<F%Y*$%U=&@Z.F=E=$%U=&@H*2DI.PH@("`@("`@('T@96QS96EF("@D
M8V]N9ELG:&]O:W,G75LG9G5L;%]N86UE)UTI('L*("`@("`@("`@("`@)'5S
M97)I9"`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=7-E<FED(#T@075T:#HZ9V5T075T:"@I.PH@("`@("`@('T*
M("`@('T*"B`@("`O+R!#:&5C:R!F;W(@=7-E<G,@=&AA="!C86X@;F]T(&-H
M86YG92!T:&5I<B!P87-S=V]R9',N"B`@("!I9B`H:6Y?87)R87DH)'5S97)I
M9"P@)&-O;F9;)W5S97(G75LG<F5F=7-E9"==*2D@>PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")9;W4@8V%N)W0@8VAA;F=E('!A
M<W-W;W)D(&9O<B!U<V5R("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1U<V5R:60I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("!B<F5A:SL*("`@('T*"B`@("`O+R!792!M=7-T(&)E('!A<W-E9"!T:&4@
M;VQD("AC=7)R96YT*2!P87-S=V]R9"P@;W(@:71S(&%N(&5R<F]R+@H@("`@
M)&]L9%]P87-S=V]R9"`](%5T:6PZ.F=E=$9O<FU$871A*"=O;&1P87-S=V]R
M9"<L(&9A;'-E*3L*("`@(&EF("@A)&]L9%]P87-S=V]R9"D@>PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&UU<W0@9VEV92!Y;W5R(&-U
M<G)E;G0@<&%S<W=O<F0B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@8G)E86L["B`@("!]"@H@("`@
M+R\@4V5E(&EF('1H97D@96YT97)E9"!T:&4@;F5W('!A<W-W;W)D(&%N9"!V
M97)I9FEE9"!I="X*("`@("1N97=?<&%S<W=O<F0P(#T@571I;#HZ9V5T1F]R
M;41A=&$H)VYE=W!A<W-W;W)D,"<L(&9A;'-E*3L*("`@("1N97=?<&%S<W=O
M<F0Q(#T@571I;#HZ9V5T1F]R;41A=&$H)VYE=W!A<W-W;W)D,2<L(&9A;'-E
M*3L*("`@(&EF("@A)&YE=U]P87-S=V]R9#`I('L*("`@("`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*%\H(EEO=2!M=7-T(&=I=F4@>6]U<B!N97<@<&%S<W=O
M<F0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!B<F5A:SL*("`@('T*
M("`@(&EF("@A)&YE=U]P87-S=V]R9#$I('L*("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*%\H(EEO=2!M=7-T('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R
M9"(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@(&)R96%K.PH@("`@?0H@
M("`@:68@*"1N97=?<&%S<W=O<F0P("$]("1N97=?<&%S<W=O<F0Q*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W5R(&YE=R!P87-S=V]R
M9',@9&ED;B=T(&UA=&-H(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@
M8G)E86L["B`@("!]"B`@("!I9B`H)&YE=U]P87-S=V]R9#`@/3T@)&]L9%]P
M87-S=V]R9"D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U
M<B!N97<@<&%S<W=O<F0@;75S="!B92!D:69F97)E;G0@9G)O;2!Y;W5R(&-U
M<G)E;G0@<&%S<W=O<F0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!B
M<F5A:SL*("`@('T*"B`@("`O+R!#:&5C:R!M87@O;6EN(&QE;F=T:',@:68@
M<W!E8VEF:65D(&EN('1H92!B86-K96YD(&-O;F9I9RX*("`@(&EF("AI<W-E
M="@D<&%S<W=O<F1?<&]L:6-Y6R=M:6Y,96YG=&@G72D@)B8*("`@("`@("!S
M=')L96XH)&YE=U]P87-S=V]R9#`I(#P@)'!A<W-W;W)D7W!O;&EC>5LG;6EN
M3&5N9W1H)UTI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN
M=&8H7R@B66]U<B!N97<@<&%S<W=O<F0@;75S="!B92!A="!L96%S="`E9"!C
M:&%R86-T97)S(&QO;F<A(BDL("1P87-S=V]R9%]P;VQI8WE;)VUI;DQE;F=T
M:"==*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!B<F5A:SL*("`@('T*
M("`@(&EF("AI<W-E="@D<&%S<W=O<F1?<&]L:6-Y6R=M87A,96YG=&@G72D@
M)B8*("`@("`@("!S=')L96XH)&YE=U]P87-S=V]R9#`I(#X@)'!A<W-W;W)D
M7W!O;&EC>5LG;6%X3&5N9W1H)UTI('L*("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B66]U<B!N97<@<&%S<W=O<F0@:7,@=&]O(&QO
M;F<[('!A<W-W;W)D<R!M87D@;F]T(&)E(&UO<F4@=&AA;B`E9"!C:&%R86-T
M97)S(&QO;F<A(BDL("1P87-S=V]R9%]P;VQI8WE;)VUA>$QE;F=T:"==*2P@
M)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!B<F5A:SL*("`@('T*"B`@("`O
M+R!$:7-E8W0@=&AE('!A<W-W;W)D(&EN(&$@;&]C86QI<V5D('=A>2X*("`@
M("1C;&%S<V5S(#T@87)R87DH*3L*("`@("1A;'!H82`]("1A;&YU;2`]("1N
M=6T@/2`D=7!P97(@/2`D;&]W97(@/2`D<W!A8V4@/2`D<WEM8F]L(#T@,#L*
M("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE;B@D;F5W7W!A<W-W;W)D,"D[
M("1I*RLI('L*("`@("`@("`D8VAA<B`]('-U8G-T<B@D;F5W7W!A<W-W;W)D
M,"P@)&DL(#$I.PH@("`@("`@(&EF("AC='EP95]L;W=E<B@D8VAA<BDI('L*
M("`@("`@("`@("`@)&QO=V5R*RL[("1A;'!H82LK.R`D86QN=6TK*SL@)&-L
M87-S97-;)VQO=V5R)UT@/2`Q.PH@("`@("`@('T@96QS96EF("AC='EP95]U
M<'!E<B@D8VAA<BDI('L*("`@("`@("`@("`@)'5P<&5R*RL[("1A;'!H82LK
M.R`D86QN=6TK*SL@)&-L87-S97-;)W5P<&5R)UT@/2`Q.PH@("`@("`@('T@
M96QS96EF("AC='EP95]D:6=I="@D8VAA<BDI('L*("`@("`@("`@("`@)&YU
M;2LK.R`D86QN=6TK*SL@)&-L87-S97-;)VYU;6)E<B==(#T@,3L*("`@("`@
M("!](&5L<V5I9B`H8W1Y<&5?<'5N8W0H)&-H87(I*2!["B`@("`@("`@("`@
M("1S>6UB;VPK*SL@)&-L87-S97-;)W-Y;6)O;"==(#T@,3L*("`@("`@("!]
M(&5L<V5I9B`H8W1Y<&5?<W!A8V4H)&-H87(I*2!["B`@("`@("`@("`@("1S
M<&%C92LK.R`D8VQA<W-E<ULG<WEM8F]L)UT@/2`Q.PH@("`@("`@('T*("`@
M('T*"B`@("`O+R!#:&5C:R!R96%M86EN:6YG('!A<W-W;W)D('!O;&EC>2!O
M<'1I;VYS+@H@("`@:68@*&ES<V5T*"1P87-S=V]R9%]P;VQI8WE;)VUI;E5P
M<&5R)UTI("8F"B`@("`@("`@)'!A<W-W;W)D7W!O;&EC>5LG;6EN57!P97(G
M72`^("1U<'!E<BD@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@;&5A
M<W0@)60@=7!P97)C87-E(&-H87)A8W1E<G,N(BDL("1P87-S=V]R9%]P;VQI
M8WE;)VUI;E5P<&5R)UTI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@(&)R
M96%K.PH@("`@?0H@("`@:68@*&ES<V5T*"1P87-S=V]R9%]P;VQI8WE;)VUI
M;DQO=V5R)UTI("8F"B`@("`@("`@)'!A<W-W;W)D7W!O;&EC>5LG;6EN3&]W
M97(G72`^("1L;W=E<BD@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M<W!R:6YT9BA?*")9;W5R(&YE=R!P87-S=V]R9"!M=7-T(&-O;G1A:6X@870@
M;&5A<W0@)60@;&]W97)C87-E(&-H87)A8W1E<G,N(BDL("1P87-S=V]R9%]P
M;VQI8WE;)VUI;DQO=V5R)UTI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@
M(&)R96%K.PH@("`@?0H@("`@:68@*&ES<V5T*"1P87-S=V]R9%]P;VQI8WE;
M)VUI;DYU;65R:6,G72D@)B8*("`@("`@("`D<&%S<W=O<F1?<&]L:6-Y6R=M
M:6Y.=6UE<FEC)UT@/B`D;G5M*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"AS<')I;G1F*%\H(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I
M;B!A="!L96%S="`E9"!N=6UE<FEC(&-H87)A8W1E<G,N(BDL("1P87-S=V]R
M9%]P;VQI8WE;)VUI;DYU;65R:6,G72DL("=H;W)D92YW87)N:6YG)RD["B`@
M("`@("`@8G)E86L["B`@("!]"B`@("!I9B`H:7-S970H)'!A<W-W;W)D7W!O
M;&EC>5LG;6EN06QP:&$G72D@)B8*("`@("`@("`D<&%S<W=O<F1?<&]L:6-Y
M6R=M:6Y!;'!H82==(#X@)&%L<&AA*2!["B`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"AS<')I;G1F*%\H(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N
M=&%I;B!A="!L96%S="`E9"!A;'!H86)E=&EC(&-H87)A8W1E<G,N(BDL("1P
M87-S=V]R9%]P;VQI8WE;)VUI;D%L<&AA)UTI+"`G:&]R9&4N=V%R;FEN9R<I
M.PH@("`@("`@(&)R96%K.PH@("`@?0H@("`@:68@*&ES<V5T*"1P87-S=V]R
M9%]P;VQI8WE;)VUI;D%L<&AA3G5M)UTI("8F"B`@("`@("`@)'!A<W-W;W)D
M7W!O;&EC>5LG;6EN06QP:&%.=6TG72`^("1A;&YU;2D@>PH@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")9;W5R(&YE=R!P87-S=V]R
M9"!M=7-T(&-O;G1A:6X@870@;&5A<W0@)60@86QP:&%N=6UE<FEC(&-H87)A
M8W1E<G,N(BDL("1P87-S=V]R9%]P;VQI8WE;)VUI;D%L<&AA3G5M)UTI+"`G
M:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@(&)R96%K.PH@("`@?0H@("`@:68@
M*&ES<V5T*"1P87-S=V]R9%]P;VQI8WE;)VUI;D-L87-S97,G72D@)B8*("`@
M("`@("`D<&%S<W=O<F1?<&]L:6-Y6R=M:6Y#;&%S<V5S)UT@/B!A<G)A>5]S
M=6TH)&-L87-S97,I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS
M<')I;G1F*%\H(EEO=7(@;F5W('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!A="!L
M96%S="`E9"!D:69F97)E;G0@='EP97,@;V8@8VAA<F%C=&5R<RX@5&AE('1Y
M<&5S(&%R93H@;&]W97(L('5P<&5R+"!N=6UE<FEC+"!A;F0@<WEM8F]L<RXB
M*2P@)'!A<W-W;W)D7W!O;&EC>5LG;6EN0VQA<W-E<R==*2P@)VAO<F1E+G=A
M<FYI;F<G*3L*("`@("`@("!B<F5A:SL*("`@('T*("`@(&EF("AI<W-E="@D
M<&%S<W=O<F1?<&]L:6-Y6R=M87A3<&%C92==*2`F)@H@("`@("`@("1P87-S
M=V]R9%]P;VQI8WE;)VUA>%-P86-E)UT@/"`D<W!A8V4I('L*("`@("`@("!I
M9B`H)'!A<W-W;W)D7W!O;&EC>5LG;6%X4W!A8V4G72`^(#`I('L*("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(EEO=7(@;F5W
M('!A<W-W;W)D(&UU<W0@8V]N=&%I;B!L97-S('1H86X@)60@=VAI=&5S<&%C
M92!C:&%R86-T97)S+B(I+"`D<&%S<W=O<F1?<&]L:6-Y6R=M87A3<&%C92==
M*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=7(@;F5W('!A<W-W;W)D
M(&UU<W0@;F]T(&-O;G1A:6X@=VAI=&5S<&%C92!C:&%R86-T97)S+B(I+"`G
M:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*("`@
M('T*"B`@("`O+R!$;R!S;VUE('-I;7!L92!S=')E;F=T:"!T97-T<RP@:68@
M96YA8FQE9"!I;B!T:&4@8V]N9FEG(&9I;&4N"B`@("!I9B`H)&-O;F9;)W!A
M<W-W;W)D)UU;)W-T<F5N9W1H=&5S=',G72D@>PH@("`@("`@("\O($-H96-K
M(&9O<B!N97<]/6]L9"P@<&%S<ST]=7-E<BP@<VEM<&QE(')E=F5R<V4@<W1R
M:6YG<RP@971C+@H@("`@("`@(&EF("@H<W1R8V%S96-M<"@D;F5W7W!A<W-W
M;W)D,"P@)'5S97)I9"D@/3T@,"D@?'P*("`@("`@("`@("`@*'-T<F-A<V5C
M;7`H)&YE=U]P87-S=V]R9#`L('-T<G)E=B@D=7-E<FED*2D@/3T@,"D@?'P*
M("`@("`@("`@("`@*'-T<F-A<V5C;7`H)&YE=U]P87-S=V]R9#`L("1O;&1?
M<&%S<W=O<F0I(#T](#`I('Q\"B`@("`@("`@("`@("AS=')C87-E8VUP*"1N
M97=?<&%S<W=O<F0P+"!S=')R978H)&]L9%]P87-S=V]R9"DI(#T](#`I("D@
M>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=7(@;F5W
M('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,N($YO="!C:&%N9V5D
M(2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YW
M87)N:6YG)RD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@("`@
M("`O+R!#:&5C:R!F;W(@<&5R8V5N=&%G97,@<VEM:6QA<FET>2!A;'-O+B`@
M5&AI<R!W:6QL(&-A=&-H('9E<GD@<VEM<&QE"B`@("`@("`@+R\@5&AI;F=S
M(&QI:V4@(G!A<W-W;W)D(B`M/B`B<&%S<W=O<F0R(B!O<B`B>'!A<W-S=V]R
M9"(N+BX*("`@("`@("!`<VEM:6QA<E]T97AT*"1N97=?<&%S<W=O<F0P+"`D
M;VQD7W!A<W-W;W)D+"`D<&5R8V5N=#$I.PH@("`@("`@($!S:6UI;&%R7W1E
M>'0H)&YE=U]P87-S=V]R9#`L("1U<V5R:60L("1P97)C96YT,BD["B`@("`@
M("`@:68@*"@D<&5R8V5N=#$@/B`X,"D@?'P@*"1P97)C96YT,B`^(#@P*2D@
M>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=7(@;F5W
M('!A<W-W;W)D(&ES('1O;R!S:6UP;&4@=&\@9W5E<W,A("!.;W0@8VAA;F=E
M9"$B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N
M=V%R;FEN9R<I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]
M"@H@("`@+R\@0W)E871E(&$@4&%S<W=O<F1?1')I=F5R(&EN<W1A;F-E+@H@
M("`@<F5Q=6ER95]O;F-E(%!!4U-71%]"05-%("X@)R]L:6(O1')I=F5R+G!H
M<"<["B`@("`D9&%E;6]N(#T@)E!A<W-W9%]$<FEV97(Z.F9A8W1O<GDH)&1R
M:79E<BP@)'!A<F%M<RD["@H@("`@:68@*&ES7V$H)&1A96UO;BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B4&%S
M<W=O<F0@;6]D=6QE(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!B<F5A:SL*("`@('T*"B`@("`D8F%C:V5N9%]U<V5R:60@/2`D=7-E
M<FED.PH*("`@(&EF("@D8V]N9ELG:&]O:W,G75LG=7-E<FYA;64G72D@>PH@
M("`@("`@("1B86-K96YD7W5S97)I9"`]($AO<F1E.CIC86QL2&]O:R@G7W!A
M<W-W9%]H;V]K7W5S97)N86UE)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)'5S97)I9"DI.PH@("`@("`@(&EF
M("AI<U]A*"1B86-K96YD7W5S97)I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1B86-K96YD7W5S97)I9"P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M("`@('T*"B`@("`D<F5S(#T@)&1A96UO;BT^8VAA;F=E4&%S<W=O<F0H)&)A
M8VME;F1?=7-E<FED+"`D;VQD7W!A<W-W;W)D+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N97=?<&%S<W=O<F0P*3L*"B`@("!I9B`H
M(6ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(&EF("@A:7-S
M970H)&)A8VME;F1S6R1B86-K96YD7VME>5U;)VYO7W)E<V5T)UTI('Q\"B`@
M("`@("`@("`@("$D8F%C:V5N9'-;)&)A8VME;F1?:V5Y75LG;F]?<F5S970G
M72D@>PH@("`@("`@("`@("!087-S=V0Z.G)E<V5T0W)E9&5N=&EA;',H)&]L
M9%]P87-S=V]R9"P@)&YE=U]P87-S=V]R9#`I.PH@("`@("`@('T*"B`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E!A<W-W;W)D(&-H
M86YG960@;VX@)7,N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1B86-K96YD<ULD8F%C:V5N9%]K97E=6R=N86UE)UTI+"`G:&]R
M9&4N<W5C8V5S<R<I.PH@("`@("`@("1R971U<FY?=&\@/2!5=&EL.CIG971&
M;W)M1&%T82@G<F5T=7)N7W1O)RD["B`@("`@("`@:68@*"%E;7!T>2@D<F5T
M=7)N7W1O*2D@>PH@("`@("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@
M)')E='5R;E]T;RD["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H@("`@
M?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B1F%I;'5R92!I;B!C:&%N9VEN9R!P87-S=V]R9"!O;B`E<SH@)7,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&)A8VME;F1S
M6R1B86-K96YD7VME>5U;)VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<RT^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("!]"GT@=VAI;&4@*&9A;'-E*3L*"B\O($-H;V]S92!T:&4@
M<')E9F5R960@8F%C:V5N9"!F<F]M(&-O;F9I9R]B86-K96YD<RYP:'`N"F9O
M<F5A8V@@*"1B86-K96YD<R!A<R`D:V5Y(#T^("1C=7)R96YT7V)A8VME;F0I
M('L*("`@(&EF("@A:7-S970H)&)A8VME;F1?:V5Y*2`F)B!S=6)S='(H)&ME
M>2P@,"P@,2D@(3T@)U\G*2!["B`@("`@("`@)&)A8VME;F1?:V5Y(#T@)&ME
M>3L*("`@('T*("`@(&EF("A087-S=V0Z.FES4')E9F5R<F5D0F%C:V5N9"@D
M8W5R<F5N=%]B86-K96YD*2D@>PH@("`@("`@("1B86-K96YD7VME>2`]("1K
M97D["B`@("`@("`@8G)E86L["B`@("!]"GT*"B\O($)U:6QD('1H92`\<V5L
M96-T/B!W:61G970@9F]R('1H92!B86-K96YD<R!L:7-T+@II9B`H)&-O;F9;
M)V)A8VME;F0G75LG8F%C:V5N9%]L:7-T)UT@/3T@)W-H;W=N)RD@>PH@("`@
M)&)A8VME;F1S7VQI<W0@/2`G)SL*"B`@("!F;W)E86-H("@D8F%C:V5N9',@
M87,@)&ME>2`]/B`D8W5R<F5N=%]B86-K96YD*2!["B`@("`@("`@)'-E;"`]
M("@D:V5Y(#T]("1B86-K96YD7VME>2D@/R`G('-E;&5C=&5D/2)S96QE8W1E
M9"(G(#H@)R<["B`@("`@("`@)&)A8VME;F1S7VQI<W0@+CT@(CQO<'1I;VX@
M=F%L=64]7"(D:V5Y7"(D<V5L/B(["B`@("`@("`@)&)A8VME;F1S7VQI<W0@
M+CT@)&-U<G)E;G1?8F%C:V5N9%LG;F%M92==("X@)SPO;W!T:6]N/B<["B`@
M("!]"GT*"B\O($5X=')A8W0@=7-E<FED('1O(&)E('-H;W=N(&EN('1H92!U
M<V5R;F%M92!F:65L9"X*:68@*&5M<'1Y*"1U<V5R:60I*2!["B`@("!I9B`H
M)&-O;F9;)VAO;VMS)UU;)V1E9F%U;'1?=7-E<FYA;64G72D@>PH@("`@("`@
M("1U<V5R:60@/2!(;W)D93HZ8V%L;$AO;VLH)U]P87-S=V1?:&]O:U]D969A
M=6QT7W5S97)N86UE)RP@87)R87DH075T:#HZ9V5T075T:"@I*2D["B`@("!]
M(&5L<V5I9B`H)&-O;F9;)VAO;VMS)UU;)V9U;&Q?;F%M92==*2!["B`@("`@
M("`@)'5S97)I9"`]($%U=&@Z.F=E=$%U=&@H*3L*("`@('T@96QS92!["B`@
M("`@("`@)'5S97)I9"`]($%U=&@Z.F=E=$%U=&@H*3L*("`@('T*("`@(&EF
M("AI<U]A*"1U<V5R:60L("=014%27T5R<F]R)RDI('L*("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@D=7-E<FED+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("1U<V5R:60@/2`G)SL*("`@('T*?0H*)&YO=&EF:6-A=&EO;BT^
M<'5S:"@G<V5T1F]C=7,H*2<L("=J879A<V-R:7!T)RD["B1T:71L92`](%\H
M(D-H86YG92!087-S=V]R9"(I.PIR97%U:7)E(%!!4U-71%]414U03$%415,@
M+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!005-35T1?5$5-4$Q!
M5$53("X@)R]M86EN+VUA:6XN:6YC)SL*<F5Q=6ER92`D<F5G:7-T<GDM/F=E
M="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC
M)SL*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&%S<W=D+W1E<W0N<&AP````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3`Q-@`Q,#0Q-S,V,C<T-``P,3<T,30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@<&%S<W=D+W1E<W0N<&AP+'8@,2XR(#(P,#4O
M,#@O,38@,3<Z,SDZ,C8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U
M($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A!4TPI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+V%S;"YP:'`N"B`J
M+PH*+RH@26YC;'5D92!(;W)D92=S(&-O<F4N<&AP(&9I;&4N("HO"FEN8VQU
M9&5?;VYC92`G+BXO;&EB+V-O<F4N<&AP)SL*"B\J(%=E('-H;W5L9"!H879E
M(&QO861E9"!T:&4@4W1R:6YG(&-L87-S+"!F<F]M('1H92!(;W)D95]5=&EL
M('!A8VMA9V4L(&EN"B`J(&-O<F4N<&AP+B!)9B!3=')I;F<Z.B!I<VXG="!D
M969I;F5D+"!T:&5N('=E)W)E(&YO="!F:6YD:6YG('-O;64@8W)I=&EC86P*
M("H@;&EB<F%R:65S+B`J+PII9B`H(6-L87-S7V5X:7-T<R@G4W1R:6YG)RDI
M('L*("`@(&5C:&\@)SQB<B`O/CQS<&%N('-T>6QE/2)C;VQO<CH@<F5D.R!F
M;VYT+7-I>F4Z(#$X<'@[(&9O;G0M=V5I9VAT.B!B;VQD.R(^5&AE($AO<F1E
M7U5T:6P@<&%C:V%G92!W87,@;F]T(&9O=6YD+B!)9B!02%!<)W,@97)R;W)?
M<F5P;W)T:6YG('-E='1I;F<@:7,@:&EG:"!E;F]U9V@L('1H97)E('-H;W5L
M9"!B92!E<G)O<B!M97-S86=E<R!P<FEN=&5D(&%B;W9E('1H870@;6%Y(&AE
M;'`@>6]U(&EN(&1E8G5G9VEN9R!T:&4@<')O8FQE;2X@268@>6]U(&%R92!S
M:6UP;'D@;6ES<VEN9R!T:&5S92!F:6QE<RP@=&AE;B!Y;W4@;F5E9"!T;R!G
M970@=&AE(#QA(&AR968](FAT='`Z+R]C=G,N:&]R9&4N;W)G+V-V<RYP:'`O
M9G)A;65W;W)K(CYF<F%M97=O<FL\+V$^(&UO9'5L92!F<F]M(#QA(&AR968]
M(FAT='`Z+R]H;W)D92YO<F<O<V]U<F-E+R(^2&]R9&4@0U93/"]A/BP@86YD
M(&EN<W1A;&P@=&AE('!A8VMA9V5S(&EN(&ET('=I=&@@=&AE(&EN<W1A;&PM
M<&%C:V%G97,N<&AP('-C<FEP="X\+W-P86X^)SL*("`@(&5X:70["GT*"B\J
M($EN:71I86QI>F4@=&AE($AO<F1E7U1E<W0Z.B!C;&%S<RX@*B\*:68@*"$H
M0&ES7W)E861A8FQE*"<N+B]L:6(O5&5S="YP:'`G*2DI('L*("`@(&5C:&\@
M)T524D]2.B!9;W4@;75S="!I;G-T86QL($AO<F1E(&)E9F]R92!R=6YN:6YG
M('1H:7,@<V-R:7!T+B<["B`@("!E>&ET.PI]"G)E<75I<F5?;VYC92`G+BXO
M;&EB+U1E<W0N<&AP)SL*)&AO<F1E7W1E<W0@/2`F;F5W($AO<F1E7U1E<W0[
M"@HO*B!!8V-O=6YT<R!D969I;FET:6]N<RX@*B\*)&UO9'5L92`]("=087-S
M=V0G.PIR97%U:7)E7V]N8V4@)RXO;&EB+W9E<G-I;VXN<&AP)SL*)&UO9'5L
M95]V97)S:6]N(#T@4$%34U=$7U9%4E-)3TX["@IR97%U:7)E(%1%4U1?5$5-
M4$Q!5$53("X@)VAE861E<BYI;F,G.PIR97%U:7)E(%1%4U1?5$5-4$Q!5$53
M("X@)W9E<G-I;VXN:6YC)SL*"B\J(%!(4"!M;V1U;&4@8V%P86)I;&ET:65S
M+B`J+PHD;6]D=6QE7VQI<W0@/2!A<G)A>2@*("`@("=M8W)Y<'0G(#T^(&%R
M<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G;6-R>7!T)RP*("`@("`@("`G
M97)R;W(G(#T^("=)9B!Y;W4@=VEL;"!B92!U<VEN9R!T:&4@<VUB;&1A<"!D
M<FEV97(@9F]R('!A<W-W;W)D(&-H86YG97,L(%!(4"!M=7-T(&AA=F4@;6-R
M>7!T('-U<'!O<G0N($-O;7!I;&4@4$A0(#QC;V1E/BTM=VET:"UM8W)Y<'0\
M+V-O9&4^(&)E9F]R92!C;VYT:6YU:6YG+B<*("`@("DL"B`@("`G;6AA<V@G
M(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G;6AA<V@G+`H@("`@
M("`@("=E<G)O<B<@/3X@)TEF('EO=2!W:6QL(&)E('5S:6YG('1H92!S;6)L
M9&%P(&1R:79E<B!F;W(@<&%S<W=O<F0@8VAA;F=E<RP@4$A0(&UU<W0@:&%V
M92!M:&%S:"!S=7!P;W)T+B!#;VUP:6QE(%!(4"`\8V]D93XM+7=I=&@M;6AA
M<V@\+V-O9&4^(&)E9F]R92!C;VYT:6YU:6YG+B<*("`@("D**3L*"@HO*B!0
M14%2("HO"B1P96%R7VQI<W0@/2!A<G)A>2@*("`@("=#<GEP=%]#2$%0)R`]
M/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)T-R>7!T+T-(05`N<&AP)RP*
M("`@("`@("`G97)R;W(G(#T^("=)9B!Y;W4@=VEL;"!B92!U<VEN9R!T:&4@
M<VUB;&1A<"!D<FEV97(@9F]R('!A<W-W;W)D(&-H86YG97,L('1H96X@>6]U
M(&UU<W0@:6YS=&%L;"!T:&4@4$5!4B!#<GEP=%]#2$%0(&UO9'5L92XG"B`@
M("`I"BD["@HO*B!'970@=&AE('-T871U<R!O=71P=70@;F]W+B`J+PHD;6]D
M=6QE7V]U='!U="`]("1H;W)D95]T97-T+3YP:'!-;V1U;&5#:&5C:R@D;6]D
M=6QE7VQI<W0I.PH*/SX*/&@Q/E!(4"!-;V1U;&4@0V%P86)I;&ET:65S/"]H
M,3X*/'5L/@H@("`@/#]P:'`@96-H;R`D;6]D=6QE7V]U='!U="`_/@H\+W5L
M/@H*/&@Q/E!%05(@36]D=6QE<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@
M)&AO<F1E7W1E<W0M/E!%05)-;V1U;&5#:&5C:R@D<&5A<E]L:7-T*2`_/@H\
M+W5L/@H*/#]P:'`*<F5Q=6ER92!415-47U1%35!,051%4R`N("=F;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P87-S=V0O8V]N
M9FEG````````````````````````````````````````````````````````
M`````````````````````````#`Q,C`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R-34S,P`@,B]U<W(O;&]C86PO<'-A
M+V5T8R]P<V$M:&]R9&4O<&%S<W=D````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VUN96UO+P``````````````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#8`,#$U-30Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O<V-R:7!T<R\`````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<T-``P,3<R,C8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M
M;R]S8W)I<'1S+W-Q;"\`````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,#`R-0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VUN96UO+W-C<FEP=',O<W%L+VUN96UO+G-Q;```````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-C,`,3`T,3<S-C(W-#0`
M,#(Q-C4W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM("1(;W)D93H@;6YE;6\O<V-R:7!T<R]S<6PO;6YE;6\N<W%L+'8@
M,2XU(#(P,#0O,3(O,C$@,34Z-34Z,C0@8VAU8VL@17AP("0*"E5312!H;W)D
M93L*"D-214%412!404),12!M;F5M;U]M96UO<R`H"B`@("!M96UO7V]W;F5R
M("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@;65M;U]I9"`@("`@
M("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@;65M;U]U:60@("`@("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&UE;6]?9&5S8R`@("`@("!6
M05)#2$%2*#8T*2!.3U0@3E5,3"P*("`@(&UE;6]?8F]D>2`@("`@("!415A4
M+`H@("`@;65M;U]C871E9V]R>2`@(%9!4D-(05(H.#`I+`H@("`@;65M;U]P
M<FEV871E("`@(%--04Q,24Y4($Y/5"!.54Q,($1%1D%53%0@,"P*+2T*("`@
M(%!224U!4ED@2T59("AM96UO7V]W;F5R+"!M96UO7VED*0HI.PH*0U)%051%
M($E.1$58(&UN96UO7VYO=&5P861?:61X($].(&UN96UO7VUE;6]S("AM96UO
M7V]W;F5R*3L*0U)%051%($E.1$58(&UN96UO7W5I9%]I9'@@3TX@;6YE;6]?
M;65M;W,@*&UE;6]?=6ED*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!
M5$4L($1%3$5412!/3B!M;F5M;U]M96UO<R!43R!H;W)D94!L;V-A;&AO<W0[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W-C<FEP=',O<W%L+VUN96UO+F]C
M:3@N<W%L````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P-C4`,3`T,3<S
M-C(W-#0`,#(R-3(Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"TM("1(;W)D93H@;6YE;6\O<V-R:7!T<R]S<6PO;6YE;6\N
M;V-I."YS<6PL=B`Q+C$N,BXS(#(P,#4O,3`O,3@@,3,Z,#$Z,38@:F%N($5X
M<"`D"@I#4D5!5$4@5$%"3$4@;6YE;6]?;65M;W,@*`H@("`@;65M;U]O=VYE
M<B`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@("!M96UO7VED("`@
M("`@("`@5D%20TA!4C(H,S(I($Y/5"!.54Q,+`H@("`@;65M;U]U:60@("`@
M("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@("!M96UO7V1E<V,@("`@
M("`@5D%20TA!4C(H-C0I($Y/5"!.54Q,+`H@("`@;65M;U]B;V1Y("`@("`@
M(%9!4D-(05(R*#0P,#`I+`H@("`@;65M;U]C871E9V]R>2`@(%9!4D-(05(R
M*#@P*2P*("`@(&UE;6]?<')I=F%T92`@("!.54U"15(H-BD@1$5&055,5"`P
M($Y/5"!.54Q,+`HM+0H@("`@4%))34%262!+15D@*&UE;6]?;W=N97(L(&UE
M;6]?:60I"BD["@I#4D5!5$4@24Y$15@@;6YE;6]?;F]T97!A9%]I9'@@3TX@
M;6YE;6]?;65M;W,@*&UE;6]?;W=N97(I.PI#4D5!5$4@24Y$15@@;6YE;6]?
M=6ED7VED>"!/3B!M;F5M;U]M96UO<R`H;65M;U]U:60I.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W-C<FEP=',O<W%L+VUN
M96UO+FUS<W%L+G-Q;```````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-34`
M,3`T,3<S-C(W-#0`,#(S,#$V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM("1(;W)D93H@;6YE;6\O<V-R:7!T<R]S<6PO
M;6YE;6\N;7-S<6PN<W%L+'8@,2XQ+C(N,2`R,#`V+S`Q+S$X(#$Y.C4Y.C(X
M(&)E;B!%>'`@)`H*0U)%051%(%1!0DQ%(&UN96UO7VUE;6]S("@*("`@(&UE
M;6]?;W=N97(@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!M96UO
M7VED("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!M96UO7W5I
M9"`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@;65M;U]D97-C
M("`@("`@(%9!4D-(05(H-C0I($Y/5"!.54Q,+`H@("`@;65M;U]B;V1Y("`@
M("`@(%9!4D-(05(H34%8*2P*("`@(&UE;6]?8V%T96=O<GD@("!605)#2$%2
M*#@P*2P*("`@(&UE;6]?<')I=F%T92`@("!334%,3$E.5"!.3U0@3E5,3"!$
M149!54Q4(#`L"BTM"B`@("!04DE-05)9($M%62`H;65M;U]O=VYE<BP@;65M
M;U]I9"D**3L*"D-214%412!)3D1%6"!M;F5M;U]N;W1E<&%D7VED>"!/3B!M
M;F5M;U]M96UO<R`H;65M;U]O=VYE<BD["D-214%412!)3D1%6"!M;F5M;U]U
M:61?:61X($].(&UN96UO7VUE;6]S("AM96UO7W5I9"D["@I'4D%.5"!314Q%
M0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@;6YE;6]?;65M;W,@5$\@
M:&]R9&4["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W-C<FEP=',O
M=7!G<F%D97,O````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#0`,#(Q,#0P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;6YE;6\O<V-R:7!T<R]U<&=R861E<R\Q+C%?=&]?,BXP+G!G<W$N<W%L
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C8R-@`Q,#0Q-S,V,C<T-``P,C0Q,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2T@57!D
M871E('-C<FEP="!T;R!U<&1A=&4@;6YE;6\@,2XQ(&1A=&$@=&\@,BYX(&1A
M=&$@9F]R('!G<W%L"BTM($-O;G9E<G1E9"!F<F]M(&UY<W%L('9E<G-I;VX@
M8GD@1&%N:65L($4N($UA<FML92`\;&5X:6-O;D!S975L+F]R9SX*+2T*+2T@
M66]U(&-A;B!S:6UP;'D@97AE8W5T92!T:&ES(&9I;&4@:6X@>6]U<B!D871A
M8F%S92X*+2T*+2T@4G5N(&%S.@HM+0HM+2`D('!S<6P@/&1B(&YA;64^("UF
M(#P@,2XQ7W1O7S(N,"YP9W-Q;"YS<6P*"D%,5$52(%1!0DQ%(&UN96UO7VUE
M;6]S($123U`@0T],54U.(&UE;6]?;6]D:69I960["@I"14=)3CL*04Q415(@
M5$%"3$4@;6YE;6]?;65M;W,@041$($-/3%5-3B!M96UO7W5I9"!605)#2$%2
M*#(U-2D["E501$%412!M;F5M;U]M96UO<R!3150@;65M;U]U:60@/2`G)SL*
M04Q415(@5$%"3$4@;6YE;6]?;65M;W,@04Q415(@0T],54U.(&UE;6]?=6ED
M(%-%5"!.3U0@3E5,3#L*0T]-34E4.PH*0D5'24X["D%,5$52(%1!0DQ%(&UN
M96UO7VUE;6]S($%$1"!#3TQ534X@;65M;U]I9%]N97<@5D%20TA!4B@S,BD[
M"E501$%412!M;F5M;U]M96UO<R!3150@;65M;U]I9%]N97<@/2!M96UO7VED
M.PI!3%1%4B!404),12!M;F5M;U]M96UO<R!$4D]0(&UE;6]?:60["D%,5$52
M(%1!0DQ%(&UN96UO7VUE;6]S(%)%3D%-12!M96UO7VED7VYE=R!43R!M96UO
M7VED.PI!3%1%4B!404),12!M;F5M;U]M96UO<R!!3%1%4B!#3TQ534X@;65M
M;U]I9"!3150@3D]4($Y53$P["D-/34U)5#L*"D)%1TE..PI!3%1%4B!404),
M12!M;F5M;U]M96UO<R!!1$0@0T],54U.(&UE;6]?8V%T96=O<GE?;F5W(%9!
M4D-(05(H.#`I.PI54$1!5$4@;6YE;6]?;65M;W,@4T54(&UE;6]?8V%T96=O
M<GE?;F5W(#T@;65M;U]C871E9V]R>3L*04Q415(@5$%"3$4@;6YE;6]?;65M
M;W,@1%)/4"!M96UO7V-A=&5G;W)Y.PI!3%1%4B!404),12!M;F5M;U]M96UO
M<R!214Y!344@;65M;U]C871E9V]R>5]N97<@5$\@;65M;U]C871E9V]R>3L*
M0T]-34E4.PH*0D5'24X["D%,5$52(%1!0DQ%(&UN96UO7VUE;6]S($%$1"!#
M3TQ534X@;65M;U]P<FEV871E7VYE=R!334%,3$E.5#L*55!$051%(&UN96UO
M7VUE;6]S(%-%5"!M96UO7W!R:79A=&5?;F5W(#T@;65M;U]P<FEV871E.PI!
M3%1%4B!404),12!M;F5M;U]M96UO<R!$4D]0(&UE;6]?<')I=F%T93L*04Q4
M15(@5$%"3$4@;6YE;6]?;65M;W,@4D5.04U%(&UE;6]?<')I=F%T95]N97<@
M5$\@;65M;U]P<FEV871E.PI!3%1%4B!404),12!M;F5M;U]M96UO<R!!3%1%
M4B!#3TQ534X@;65M;U]P<FEV871E(%-%5"!.3U0@3E5,3#L*04Q415(@5$%"
M3$4@;6YE;6]?;65M;W,@04Q415(@0T],54U.(&UE;6]?<')I=F%T92!3150@
M1$5&055,5"`P.PI#3TU-250["@I#4D5!5$4@24Y$15@@;6YE;6]?=6ED7VED
M>"!/3B!M;F5M;U]M96UO<R`H;65M;U]U:60I.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]S8W)I<'1S+W5P9W)A
M9&5S+S(P,#0M,3(M,C%?861D7VUE;6]?=6ED+G-Q;```````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S,V
M`#$P-#$W,S8R-S0T`#`R-3(W,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+2`D2&]R9&4Z(&UN96UO+W-C<FEP=',O=7!G
M<F%D97,O,C`P-"TQ,BTR,5]A9&1?;65M;U]U:60N<W%L+'8@,2XQ(#(P,#0O
M,3(O,C$@,34Z,S@Z-#<@8VAU8VL@17AP("0*"D%,5$52(%1!0DQ%(&UN96UO
M7VUE;6]S($%$1"!#3TQ534X@;65M;U]U:60@5D%20TA!4B@R-34I($Y/5"!.
M54Q,.PI#4D5!5$4@24Y$15@@;6YE;6]?=6ED7VED>"!/3B!M;F5M;U]M96UO
M<R`H;65M;U]U:60I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;6YE;6\O<V-R:7!T<R]U<&=R861E<R\Q+C%?=&]?
M,BXP+FUY<W%L+G-Q;``````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(U,``Q,#0Q-S,V,C<T
M-``P,C0S,#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@)$AO<F1E.B!M;F5M;R]S8W)I<'1S+W5P9W)A9&5S+S$N,5]T
M;U\R+C`N;7ES<6PN<W%L+'8@,2XT(#(P,#0O,3(O,C$@,34Z,C8Z-#<@8VAU
M8VL@17AP("0*+2T*+2T@66]U(&-A;B!S:6UP;'D@97AE8W5T92!T:&ES(&9I
M;&4@:6X@>6]U<B!D871A8F%S92X*+2T*+2T@4G5N(&%S.@HM+0HM+2`D(&UY
M<W%L("TM=7-E<CUR;V]T("TM<&%S<W=O<F0]/$UY4U%,+7)O;W0M<&%S<W=O
M<F0^(#QD8B!N86UE/B`\(#$N,5]T;U\R+C`N;7ES<6PN<W%L"@I!3%1%4B!4
M04),12!M;F5M;U]M96UO<R!$4D]0($-/3%5-3B!M96UO7VUO9&EF:65D.PH*
M04Q415(@5$%"3$4@;6YE;6]?;65M;W,@041$($-/3%5-3B!M96UO7W5I9"!6
M05)#2$%2*#(U-2D@3D]4($Y53$P["@I!3%1%4B!404),12!M;F5M;U]M96UO
M<R!#2$%.1T4@0T],54U.(&UE;6]?:60@;65M;U]I9"!605)#2$%2*#,R*2!.
M3U0@3E5,3#L*04Q415(@5$%"3$4@;6YE;6]?;65M;W,@0TA!3D=%($-/3%5-
M3B!M96UO7V-A=&5G;W)Y(&UE;6]?8V%T96=O<GD@5D%20TA!4B@X,"D["D%,
M5$52(%1!0DQ%(&UN96UO7VUE;6]S($-(04Y'12!#3TQ534X@;65M;U]P<FEV
M871E(&UE;6]?<')I=F%T92!334%,3$E.5"!.3U0@3E5,3"!D969A=6QT(#`[
M"@I#4D5!5$4@24Y$15@@;6YE;6]?=6ED7VED>"!/3B!M;F5M;U]M96UO<R`H
M;65M;U]U:60I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O<V-R:7!T<R]U<&=R861E<R]U
M<&=R861E+6UN96UO+G-Q;```````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,R,0`Q,#0Q
M-S,V,C<T-``P,C0S,3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1$5,151%($923TT@;7ES<6PN=7-E<B!72$5212!U<V5R
M/2=H;W)D92<@86YD(&AO<W0])R4G.PI$14Q%5$4@1E)/32!M>7-Q;"YT86)L
M97-?<')I=B!72$5212!U<V5R/2=H;W)D92<@86YD(&AO<W0])R4G.PI'4D%.
M5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@;6YE;6]?;65M
M;W,@5$\@:&]R9&5`;&]C86QH;W-T.PI&3%532"!04DE624Q%1T53.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VUN96UO+W-C<FEP=',O+FAT86-C97-S````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S-C(W-#0`,#(Q
M,#$V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$1E;GD@9G)O;2!A;&P*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M
M;F5M;R]S8W)I<'1S+VEM<&]R=%]V;F]T97,N<&AP````````````````````
M`````````````````````````````````````#`Q,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`S-#(P`#$P-#$W,S8R-S0T`#`R,C8T-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C(2]U<W(O8FEN
M+W!H<`H\/W!H<`HO*BH*("H@5&AI<R!S8W)I<'0@:6UP;W)T<R!V3F]T92!D
M871A(&EN=&\@36YE;6\@;F]T97!A9',N"B`J(%1H92!D871A(&ES(')E860@
M9G)O;2!S=&%N9&%R9"!I;G!U="P@=&AE(&YO=&5P860@86YD('5S97(@;F%M
M92!P87-S960@87,*("H@<&%R86UE=&5R<RX*("H*("H@)$AO<F1E.B!M;F5M
M;R]S8W)I<'1S+VEM<&]R=%]V;F]T97,N<&AP+'8@,2XS+C(N,B`R,#`V+S`Q
M+S`Q(#(Q.C(Y.C`V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A!4TPI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N
M"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H
M)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*
M"B\O($1O($-,22!C:&5C:W,@86YD(&5N=FER;VYM96YT('-E='5P(&9I<G-T
M+@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*
M<F5Q=6ER95]O;F-E("=(;W)D92]#3$DN<&AP)SL*"B\O($UA:V4@<W5R92!N
M;R!O;F4@<G5N<R!T:&ES(&9R;VT@=&AE('=E8BX*:68@*"%(;W)D95]#3$DZ
M.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@(&5X:70H(DUU<W0@8F4@<G5N(&9R
M;VT@=&AE(&-O;6UA;F0@;&EN95QN(BD["GT*"B\O($QO860@=&AE($-,22!E
M;G9I<F]N;65N="`M(&UA:V4@<W5R92!T:&5R92=S(&YO('1I;64@;&EM:70L
M(&EN:70@<V]M90HO+R!V87)I86)L97,L(&5T8RX*)&-L:2`]("9(;W)D95]#
M3$DZ.G-I;F=L971O;B@I.PHD8VQI+3YI;FET*"D["@HO+R!296%D(&-O;6UA
M;F0@;&EN92!P87)A;65T97)S+@II9B`H8V]U;G0H)&%R9W8I("$](#,I('L*
M("`@("1C;&DM/FUE<W-A9V4H)U1O;R!M86YY(&]R('1O;R!F97<@<&%R86UE
M=&5R<RXG+"`G8VQI+F5R<F]R)RD["B`@("!U<V%G92@I.PI]"B1N;W1E<&%D
M(#T@)&%R9W9;,5T["B1U<V5R(#T@)&%R9W9;,ET["@HO+R!296%D('-T86YD
M87)D(&EN<'5T+@HD=FYO=&4@/2`D8VQI+3YR96%D4W1D:6XH*3L*:68@*&5M
M<'1Y*"1V;F]T92DI('L*("`@("1C;&DM/FUE<W-A9V4H)TYO(&EM<&]R="!D
M871A('!R;W9I9&5D+B<L("=C;&DN97)R;W(G*3L*("`@('5S86=E*"D["GT*
M"B\O(%)E9VES=')Y+@HD<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O
M;B@I.PH*+R\@4V5T('5S97(N"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D
M8V]N9ELG875T:"==6R=D<FEV97(G72D["B1A=71H+3YS971!=71H*"1U<V5R
M+"!A<G)A>2@I*3L*"B\O($EM<&]R="!D871A+@HD<F5S=6QT(#T@)')E9VES
M=')Y+3YC86QL*"=N;W1E<R]I;7!O<G0G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"1V;F]T92P@)W1E>'0O>"UV;F]T92<L("1N;W1E<&%D
M*2D["FEF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("1C
M;&DM/F9A=&%L*"1R97-U;'0M/G1O4W1R:6YG*"DI.PI]"@HD8VQI+3YM97-S
M86=E*"=);7!O<G1E9"!S=6-C97-S9G5L;'D@)R`N(&-O=6YT*"1R97-U;'0I
M("X@)R!N;W1E<R<L("=C;&DN<W5C8V5S<R<I.PH*9G5N8W1I;VX@=7-A9V4H
M*0I["B`@("`D1TQ/0D%,4ULG8VQI)UTM/G=R:71E;&XH)U5S86=E.B!I;7!O
M<G1?=FYO=&5S+G!H<"!N;W1E<&%D('5S97(G*3L*("`@(&5X:70["GT*"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O
M;&]C86QE+P``````````````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-@`P,3<P,#``(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O8F=?0D<O````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`Q
M-S<S-@`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]B9U]"
M1R],0U]-15-304=%4R\`````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-#0`,#(Q-3(S`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;6YE;6\O;&]C86QE+V)G7T)'+TQ#7TU%4U-!1T53+VUN96UO+FUO````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`T-S<S,P`Q,#0Q-S,V,C<T-``P,C,R,#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````WA($E0`````D
M`0``'````#P)``"%`0``7!(```````!P&```#@```'$8```(````@!@```P`
M``")&```"````)88```+````GQ@``"@```"K&```%0```-08```=````ZA@`
M``X````(&0``!@```!<9```(````'AD``#(````G&0``.````%H9``!4````
MDQD``%$```#H&0``-````#H:```%````;QH``!P```!U&@``#0```)(:```2
M````H!H```\```"S&@``$0```,,:```9````U1H```<```#O&@``#````/<:
M```.````!!L```,````3&P``!0```!<;```*````'1L```\````H&P``'P``
M`#@;```1````6!L```P```!J&P``"0```'<;```Y````@1L``"<```"[&P``
M+````.,;```J````$!P```H````['```%0```$8<```I````7!P``!$```"&
M'```#P```)@<```6````J!P``!8```"_'```"````-8<```$````WQP```D`
M``#D'````P```.X<```#````\AP```@```#V'```(````/\<```&````(!T`
M``@````G'0``"@```#`=```M````.QT```P```!I'0``!@```'8=```'````
M?1T``!````"%'0``*P```)8=```$````PAT``!X```#''0``&P```.8=```;
M`````AX``#,````>'@``+P```%(>```I````@AX```,```"L'@```@```+`>
M```%````LQX``!````"Y'@``&0```,H>```:````Y!X```8```#_'@``"@``
M``8?```,````$1\``"\````>'P``#P```$X?```%````7A\```T```!D'P``
M&P```'(?```-````CA\```4```"<'P``$````*(?```0````LQ\```\```#$
M'P``"P```-0?```/````X!\```P```#P'P``#P```/T?```,````#2```!X`
M```:(```(0```#D@```@````6R````,```!\(```$P```(`@```4````E"``
M``P```"I(```"0```+8@```;````P"````<```#<(```!@```.0@```)````
MZR```!0```#U(```!@````HA```1````$2$``!X````C(0``!````$(A```$
M````1R$```P```!,(0``"@```%DA```%````9"$``"````!J(0``(````(LA
M```F````K"$``"D```#3(0``"@```/TA```/````""(``!,````8(@``$@``
M`"PB```0````/R(``!<```!0(@``!@```&@B```,````;R(```P```!\(@``
M#0```(DB```H````ER(``"L```#`(@``"````.PB```0````]2(``!H````&
M(P``!@```"$C```'````*",```(````P(P``)0```#,C```$````62,```\`
M``!>(P``!P```&XC```)````=B,```H```"`(P``!P```(LC```&````DR,`
M``D```":(P``#0```*0C```,````LB,```<```"_(P``"@```,<C```$````
MTB,```<```#7(P``!0```-\C```(````Y2,``!<```#N(P```@````8D```S
M````"20``#,````])```.````'$D```(````JB0``"T```"S)```,0```.$D
M```L````$R4``!H```!`)0``"0```%LE```-````924```P```!S)0``"@``
M`(`E```)````BR4```\```"5)0``"````*4E```%````KB4```(```"T)0``
M!P```+<E```,````OR4``!$```#,)0``#0```-XE```1````["4```D```#^
M)0``"`````@F```)````$28```H````;)@``%0```"8F```%````/"8``"@`
M``!")@``&@```&LF```%````AB8``"````",)@``,@```*TF```%````X"8`
M``0```#F)@``,@```.LF```,````'B<``"H````K)P``!@```%8G```/````
M72<```0```!M)P``"0```'(G```#````?"<```8```"`)P``#@```(<G```,
M````EB<``!4```"C)P``$@```+DG```0````S"<```\```#=)P``%````.TG
M```:`````B@``!<````=*```&@```#4H```7````4"@``!L```!H*```&0``
M`(0H```?````GB@``%<```"^*```!````!8I```$````&RD``!`````@*0``
M%P```#$I```&````22D```<```!0*0``!0```%@I```)````7BD``$H```!H
M*0``.````+,I``!(````["D``!4````U*@``(@```$LJ```B````;BH``"``
M``"1*@``20```+(J```P````_"H``&D````M*P``/0```)<K``!E````U2L`
M`$T````[+```+@```(DL```>````N"P``"\```#7+```+`````<M```7````
M-"T``"4```!,+0``,@```'(M```^````I2T``"4```#D+0``(0````HN```P
M````+"X``!P```!=+@``#0```'HN```%````B"X```,```".+@``(````)(N
M```9````LRX``"(```#-+@``)0```/`N```F````%B\```D````]+P``!P``
M`$<O```&````3R\```D```!6+P``$P```&`O```(````="\```D```!]+P``
M"@```(<O```4````DB\```@```"G+P``/P```+`O```'````\"\```8```#X
M+P``#0```/\O```+````#3```"\````9,```*P```$DP```,````=3````H`
M``"",````@```(TP```&````D#````,```"7,```*````)LP```H````Q#``
M`"8```#M,```)0```!0Q```H````.C$``!````!C,0``<P```'0Q```5````
MZ#$```X```#^,0``'P````TR```4````+3(```\```!",@``!````%(R```'
M````5S(```4```!?,@``50$``&4R```/````NS,```<```#+,P``"````-,S
M```*````W#,```X```#G,P``)0```/8S```<````'#0``!\````Y-```#```
M`%DT```)````9C0```<```!P-```-0```'@T```U````KC0``%(```#D-```
M3P```#<U```W````AS4```4```"_-0``)@```,4U```6````[#4``!8````#
M-@``%@```!HV```8````,38``"8```!*-@``!0```'$V```0````=S8```X`
M``"(-@``!P```)<V```)````GS8```P```"I-@``#````+8V```C````PS8`
M`!<```#G-@``#0```/\V```*````#3<``#<````8-P``+0```%`W```M````
M?C<``"\```"L-P``"````-PW```8````Y3<``#(```#^-P``#P```#$X```3
M````03@``!L```!5.```)0```'$X```*````ES@```D```"B.```!P```*PX
M```#````M#@```,```"X.```"````+PX```F````Q3@```8```#L.```"0``
M`/,X```/````_3@``#<````-.0``$````$4Y```'````5CD```@```!>.0``
M$P```&<Y```I````>SD```<```"E.0``)0```*TY```E````TSD``"<```#Y
M.0``)0```"$Z```Z````1SH``#4```"".@``!@```+@Z```"````OSH```D`
M``#".@``&P```,PZ```F````Z#H``"0````/.P``!@```#0[```*````.SL`
M``D```!&.P``+@```%`[```-````?SL```4```"-.P``"P```),[```B````
MGSL``!````#".P``!@```-,[```/````VCL``!````#J.P``#@```/L[```-
M````"CP``!0````8/```#````"T\```3````.CP```\```!./```*0```%X\
M```R````B#P``"0```"[/```!````.`\```5````Y3P``!8```#[/```#```
M`!(]```+````'ST``"8````K/0``!@```%(]```&````63T```L```!@/0``
M%P```&P]```%````A#T```X```"*/0``(0```)D]```%````NST```8```#!
M/0``#0```,@]```/````UCT```4```#F/0``+P```.P]```O````'#X``#P`
M``!,/@``)@```(D^```*````L#X```T```"[/@``&0```,D^```4````XSX`
M`!,```#X/@``'P````P_```)````+#\``!(````V/P``$0```$D_```2````
M6S\``"H```!N/P``+0```)D_```$````QS\```H```#,/P``(0```-<_```$
M````^3\```4```#^/P```@````1````M````!T````0````U0```$````#I`
M```'````2T````4```!30```#@```%E````%````:$````4```!N0```"```
M`'1````1````?4````X```"/0```!P```)Y````*````ID````,```"Q0```
M!0```+5````&````NT````P```#"0```(P```,]````"````\T```"8```#V
M0```)@```!U!```K````1$$```P```!P00``*P```'U!```O````J4$``#4`
M``#900``&0````]"```.````*4(``!$````X0@``#P```$I"```.````6D(`
M``T```!I0@``$0```'="```)````B4(```<```"30@```@```)M"```%````
MGD(```\```"D0@``$````+1"```+````Q4(``!0```#10@``"0```.9"```&
M````\$(```<```#W0@``"````/]"```2````"$,```8````;0P``,@```")#
M```9````54,```<```!O0P``'@```'=#```W````ED,```H```#.0P``!@``
M`-E#``!"````X$,```\````C1```*0```#-$```(````740``!<```!F1```
M!````'Y$```)````@T0```,```"-1```!0```)%$```6````ET0``!$```"N
M1```&@```,!$```@````VT0```\```#\1```#P````Q%```=````'$4``!D`
M```Z10``&@```%1%```8````;T4``!@```"(10``'@```*%%```C````P$4`
M`"0```#D10``:`````E&```)````<D8```8```!\1@``%0```(-&```>````
MF48```<```"X1@``!0```,!&```&````QD8```H```#-1@``1P```-A&```K
M````($<``$D```!,1P``%P```)9'```=````KD<``!X```#,1P``'````.M'
M``!7````"$@``"\```!@2```7P```)!(```U````\$@``&$````F20``/P``
M`(A)```G````R$D``!@```#P20``'`````E*```;````)DH``!<```!"2@``
M*@```%I*```Q````A4H``$4```"W2@``(````/U*```D````'DL``#<```!#
M2P``(````'M+```5````G$L```@```"R2P```P```+M+```D````OTL``!X`
M``#D2P``*P````-,```E````+TP``"@```!53```"@```'Y,```*````B4P`
M``<```"43```"@```)Q,```?````ITP```,```#'3```!````,M,```%````
MT$P``!@```#63```"````.],```]````^$P```@````V30``"````#]-```0
M````2$T```\```!930``-````&E-```L````GDT```P```#+30``#@```-A-
M```"````YTT```<```#J30```@```/)-```A````]4T``#(````73@``*P``
M`$I.```J````=DX``"T```"A3@``$0```,].``!E````X4X``"````!'3P``
M$@```&A/```K````>T\```\```"G3P``$````+=/```$````R$\```<```#-
M3P``!0```-5/```!`````````((```"P````G@```)T```#)`````````!4!
M``!*````T`````@```!Y````A0```-H```````````````````#R````&`$`
M```````I`````````!(!`````````````,$```"!````'@$``/4````D`0``
M`````,L````)`0``XP```%0```"7````<````$P```#O````!P$``+,```!`
M`````````'P```#B````WP`````````X````Y@````````"(````Q0```!4`
M``"^````C``````````?`0````````````#T````5P````````#2````I```
M``````"Y````SP```$X```!M````QP```+@````<````+0```+<```#H````
M`````"X```#A````1@````````"*````H````)````#$````&````%(`````
M`````````-D````9`````P``````````````C0```'<````:`0``8````"P`
M````````%P```)$```#M````?0```-<```#(````````````````````L@``
M``T!``#[````O0`````````K````^````%8```#_``````````L```"_````
M;`````````#P````VP```*D````=````;@````0```#8````(@```!0!````
M``````````(`````````0P```$\```!?````-P```%D`````````)0```&D`
M```/`0```````&0```#Y`````````),```!(````I@```#``````````(0$`
M``````!X````AP````P!``!Q````9P``````````````:`````````!B````
MF@````````"#````````````````````K``````````]````!0$``+L```#S
M`````````.`````H````JP```!X```#,````,@````````#=````]@```)@`
M``!+````)P```)P```";````>@```%H````;`0```````/H```#1````"`$`
M`%X````1`0```````!`!``#W````(P$```````"/````+P```.0`````````
M%P$`````````````#0```````````````````*X```!0`````````+8```"4
M````U@````````"O`````````/$````6````J````/T````,`````@$``"`!
M``!)````C@```'(```!=````(0```!8!``!U````!0```$4````/````````
M``D```"+````H@```#,```#L`````````'\````@````)````!P!```3````
M7````)4`````````[@````````!K````N@```'L````Y``````````8!``#K
M````0@```*$```#<`````````!\```#G`````````#P```!$````P@```-X`
M````````#@$`````````````6````,T```"`````````````````````Q@``
M```````:````(P```,X`````````.P```/X```##````HP```)D```"\````
M?@````<```#`````-@```````````````0$``%$```!;````$P$``.H```"M
M````M0```!L`````````30`````````B`0```````+$```#*`````````*4`
M```0````"@$```H````=`0``TP````L!```F`````````&8```"G````GP``
M``````!J`````P$``!D!``"$````4P```(D``````0```````)8```"&````
M50```!0````.````90```+0````1````=````$$````T````=@````8`````
M````;P```.4`````````*@```#H```!S`````````#$````2````/P```-0`
M``#I````/@```````````````````#4```!C`````````)(```!'````J@``
M``````#5``````````````#\````80````0!```````````````@*"5S(&1A
M>7,@86=O*0`@*'1O9&%Y*0`@*'EE<W1E<F1A>2D`)60@;F]T97,`)7,@+2!.
M;W1I8V4`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@9FEL92!S=6-C97-S9G5L;'D@
M:6UP;W)T960`)7,@:7,@<F5Q=6ER960`,2!N;W1E`#(T(&AO=7)S`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`
M02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+@!!32]030!!8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N`$%D
M9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U<V5R
M.@!!9&1I;F<@02!.97<@3F]T90!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N
M`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%D<P!!;&EA
M<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M
M90!!<V-E;F1I;F<`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T<FEB=71E<P!!=71H96YT:6-A=&EO;B!F
M86EL960`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BX`079A:6QA8FQE(&9I96QD<SH`0F%C:R!T;R!.;W1E<&%D`$)A9"!K97)B
M97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!":7)T:&1A
M>0!";VQD`$)O;VMM87)K<P!#35,`0U)#`$-A;&5N9&%R`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F-E;`!#871E9V]R>0!#96QL(%!H
M;VYE`$-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I
M;VYS+@!#;VQO<B!0:6-K97(`0V]M:6-S`$-O;7!A;GD`0V]N9FER;2!087-S
M=V]R9`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N`$-O<'D`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T82X`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-U=`!$1`!$86EL>0!$969A=6QT($ED96YT:71Y`$1E
M9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C
M=&EO;CH`1&5L971E`$1E<V-E;F1I;F<`1&5S8W)I<'1I;VXZ`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L
M87D@3W!T:6]N<P!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+@!%;7!T>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AP;W)T($YO=&5S`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%X`$9I;&4@0V]U;G0Z("5S
M(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@
M3F%M90!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&;W)U
M;7,`1G5L;"!.86UE`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P<P!'=65S
M="!097)M:7-S:6]N<P!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`
M2&5L<`!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$E-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F
M86EL960Z("5S`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@
M8FQO8VLN`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$EM<&]R="]%>'!O
M<G0@3F]T97,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`
M26YV86QI9"!D871A('-U8FUI='1E9"X`271A;&EC`$IU<W1I9GD@1G5L;`!*
M=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+97)B97)O<R!S97)V97(@<F5J
M96-T960@875T:&5N=&EC871I;VXN`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC
M<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G(&]U=`!-
M30!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$UA:6P`
M36%T8VAI;F<@9FEE;&1S`$UE;6)E<G,`365M;R!497AT`$UE;G4@;6]D93H`
M365S<V%G90!-971H;V0`36EM92!4>7!E`$UO9&EF:65D($1A=&4`36]D:69Y
M:6YG("5S`$UO;G1H;'D`37D@06-C;W5N=`!.86UE`$YE='=O<FL`3F5V97(`
M3F5W($YO=&4`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F\`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+@!.;R!N;W1E<P!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!V86QI9"!834P@
M9&%T82!R971U<FYE9`!.;R!V86QU97,`3F]T92!#871E9V]R>0!.;W1E($1E
M=&%I;',`3F]T92!,:7-T<P!.;W1E(%1E>'0`3F]T97!A9"=S(&YA;64Z`$YO
M=&5P861S`$YO=&5S`$]+`$]P=&EO;G,`3W)D97)E9"!,:7-T`$]T:&5R($EN
M9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`4$A0
M(%-H96QL`%!A<W-W;W)D`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D
M<R!M=7-T(&UA=&-H+@!087-T90!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!H
M;VYE`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%)A
M=&EO`%)E860`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5F<F5S:"!,:7-T`%)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E('5S97(Z
M("5S`%)O;&4`4U%,(%-H96QL`%-32`!396%R8V@`4V5A<F-H(%)E<W5L=',`
M4V5A<F-H(%-C;W!E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N
M97<@;W=N97(`4V5L96-T(&$@;F]T97!A9`!396QE8W0@82!S97)V97(`4V5L
M96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM
M<&]R=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4VAO=P!3:7IE`%-O<G0@8GD@0V%T
M96=O<GD`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5B;6ET`%-U8V-E<W,`
M5&%S:W,`5&5X="!/;FQY`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L
M;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@
M;F]T92!W87,@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!H87,@8F5E;B!C
M<F5A=&5D+@!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!N;W1E<&%D("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T
M97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C
M=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L
M;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L
M;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82X`5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E>'!O<G0N`%1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M
M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BX`5&EM92!4<F%C:VEN9P!4:71L90!54DP`56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E
M<P!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD97)L:6YE`%5N9FEL960`57!D
M871E`%5P9&%T92`E<P!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97)N86UE`%5S
M97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%9A8V%T
M:6]N`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+@!787)N:6YG`%=E96ML>0!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_`%=H:6-H($YO=&5P860@<VAO=6QD('1H
M92!N;W1E<R!B92!A9&1E9"!T;S\`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`
M65D`665A<FQY`%EE<P!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L
M971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=7(@26YF;W)M
M871I;VX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&1E9F%U;'0@
M;F]T97!A9#H`66]U<B!N;W1E<&%D<SH`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!;;&EN92`E<R!O9B`E
M<UT`9FEL90!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@36YE
M;6\@,BXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,3$M,3D@,C`Z-#0M,#4P,`I,
M87-T+51R86YS;&%T;W(Z($UI<F]S;&%V(%!E;F1E=B`\;6ER;T!C>6)E<G-H
M861E+G5S/@I,86YG=6%G92U496%M.B!"1R!I,3AN0&QI<W1S+FAO<F1E+F]R
M9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]0U`Q,C4Q"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*`"`H)7,@Y.WH(.W@Y^#D*0`@*.3MY?$I`"`HXO?E\.`I`"5D(.'EZ^7F
MZN@`)7,@+2#'X.'EZ^7FZN``)7,@SN'QZ_/FXN#YZ"#N[^7PX/;HZ"`M(,_N
M\N+Z\.;DY>WHY0`E<R#3\>ONXNC_(._N(-'O[O#@Y_/LY>WHY?+N`"5S(/3@
MZ>L@X>7XY2#H[._N\/+H\.#M(//Q[^7X[>X`)7,@[>7NX?7NY.CL`#$@X>7K
MY>;JX``R-"#WX/'@`,?@(.3@(.KPZ._RZ/#@\N4@[^CQ[.X@Y2#MY>[A]>[D
MZ.P@[_/AZ^CWY>T@4$=0(.KK_O<N`,?@(.3@(._P[N+E\.CRY2#O[N3OZ/'@
M[>X@[^CQ[.X@Y2#MY>[A]>[DZ.P@4$=0(.KK_O<N`,?@(.3@(.3EZO#H[_+H
M\.#RY2#OZ/'L[B#QX"#MY>[A]>[DZ.SH.B#O\^'KZ/?E[2#JZ_[W+"#KZ/?E
M[2#JZ_[W(.@@ZNO^]^[BX"#T\.#GX"X`Q^`@Y.`@[^[D[^CXY?+E(._H\>SN
M(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(.KK_O<L(.OH]^7M(.KK_O<@Z"#J
MZ_[W[N+@(/3PX.?@+@#'X"#DX"#J\.CO\NCPX/+E(._H\>SN(.4@[>7NX?7N
MY.CL(._SX>OH]^7M(%--24U%(.KK_O<N`$%-+U!-`,[RZN#GX.T@Y.[Q\OKO
M(.?@(.CG\O#HXN#MY2#MX"#AY>OEYNK@`,3NX>#B_^WE(.W@(.WNXN`@X_#S
M[^``Q.[AX.+_[>4@[>`@[>[BZ"#O\.#BX`#$[N'@XN@@[>[B(._N\O#EX>CR
MY>LZ`,3NX>#B_^WE(.W@(.WNXN`@X>7KY>;JX`#$[N'@XO_MY?+N(.W@(._N
M\O#EX>CRY>OH(.4@Y^#A\.#MY>WN+@#`Y/#E\0#`Y/#E\>7M(.'EZ^7F[>CJ
M`,#D[.CMZ/'R\.CPX.WE`,3NX>#BZN@`S_'EXN3N[>CL`,+QZ/?JZ"#C\//O
MZ`#"\>CWZN@@[_#@XN``POKBY>3E[>#RX"#Q\N[I[>[Q\B#MY2#E(.3N[_/Q
M\NCLX"X`T.#G[.7P(.W@(.#P]>CB[>C_(/3@Z>L`R.SE(.W@(.#P]>CBX`#-
MX/#@\?+BX/GH`,3@(/'E(.CQZN`@Z^@@[^[RXOKPYN3E[>CE(._PY>3H(.[A
M\>OSYN+@^>CRY2#N[^7PX/;HZ#\`P_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@
M[>7Q^OGE\?+B\^+@^>`@X_#S[^`N`,/PY?CJX"#O\.@@Z.?R\.CBX.WE(.WE
M(.WE\?KYY?'RXO/BX/GH(._PX.+@+@##\.7XZN`@[_#H(/#EY.#J\NCPX.WE
M(.W@(.WE\?KYY?'RXO/BX/GH(._PX.+@+@#`\O#HX?/RZ`##\.7XZN`@[_#H
M(.CDY>WRZ/3HZN#VZ/\`R.3E[?+H].CJX/;H__+@(.'E^.4@[O+UXOKPZ^7M
MX"#N\B!2041)55,@\?KPXOKPX"X`S>#KZ/?MZ"#O[NOE\N`Z`,[A\.#R[>X@
MXB#AY>OEYNWHZN``S>7BX.OHY.W@(&ME<F)E<F]S("#OX/#NZ^`N`,WEXN#K
MZ.3M[B!K97)B97)O<R#O[O+PY>'H\N7K\>KN(.CLY2X`T.[FY.7M(.3E[0#3
MY.7AY>OE[>@`SO+LY?+JZ`!#35,`0U)#`,K@Z^7MY.#P`,/PY?CJX"#O\.@@
M\>+Z\.?BX.WE(/$@[.7IZR#Q^O#B^O`Z("5S`,[RZN#FZ`#*X/+EX^[PZ/\`
MS.[AZ.OE[2#RY>OE].[M`-/Q\N#M[N+E\N4@[_#EY._N]^CRX.WH\N4@\>[P
M\NCPX.WE(.@@[N_VZ.@@[>`@Y.CQ[^OE_RX`R.?AZ/#@[>4@[>`@]N+_\@#*
M[NSHZO'H`,KN[._@[>C_`,_N\N+Z\.3E\N4@[^#P[NO@\N``Q.[Q\OKOX"#D
M[B#O\^'KZ/?MZ/\@\?KPXOKP(.'E^.4@[O+JX.?@[2X`RN[OZ/#@Z0##\.7X
MZN`@[_#H(%!'4"#J\.CO\NCPX.WE\NX@[>`@[^CQ[.XN`,/PY?CJX"#O\.@@
M4$=0(._NY._H\>+@[>7R[B#MX"#OZ/'L[BX`P_#E^.K@(._PZ"#DY>KPZ._R
MZ/#@[>7R[B#MX"!01U`@Y.#M[>@N`,WEZN[PY>KRY>T@96UA:6P@X.3PY?$@
M[>`@[^[K\_?@\N7K_RX`P_#E^.K@(._PZ"#O[NOS]^#BX.WE\NX@[>`@[_/A
MZ^CW[>C_(.KK_O<@[O(@ZNO^]RWQ^O#B^O#@+@#-Y>+ZY^SNYNWN\?(@Y.`@
M\>4@[O+B[O#H(,[A\>OSYN+@^>A?Y^#DX/?H(.SNY//K("5S(`#HY_#EYN@`
MQ,0`Q>;EY.WEXNWN`,CDY>WRZ/?M[O'R(._N(._NY/#@Y^'H\.#MY0#*\.CR
MY?#HZ"#GX"#Q[O#RZ/#@[>4@[^X@[^[D\.#GX>CPX.WE.@#/[O'NZN`@[>`@
M\>[P\NCPX.WE(._N(._NY/#@Y^'H\.#MY3H`R.?R\.CI`,W@[.#K_^+@^>@`
MSN_H\>#MZ.4Z`,3E\N#IZ^CRY2#A__7@(/#EX^CQ\O#H\.#MZ"#GX"#@Y.SH
M[>CQ\O#@\N[PX"X`Q.CQ[^OEZ2#.[_;HZ`#/Z/'L[@#%;6%I;"#@Y/#E\0!%
M;6%I;"#@Y/#E\>CRY2#R\/_AXN`@Y.`@\?KB[^#DX/(N`,_PX.?E[2#PY>?S
MZ_+@\BX`P_#E^.K@`,+QY>KH(#$U(.SH[?/RZ`#"\>7JZ"`S,"#QY>KS[>3H
M`,+QY>KH(#4@[.CM\_+H`,+Q_^KN(.ONX^+@[>4`S>`@XO'EZN@@[^[K[N+H
M[2#WX/$`PO'_ZN`@[.CM\_+@`,_PZ.SE\.WH(/'R[NGM[O'RZ#H`Q>KQ[^[P
M\B#AY>OEYNKH`,WEXOKG[.[F[>[Q\B#DX"#QY2#GX/#EY/_R(._PY?3E\.7M
M]NCH\N4N`,WEXOKG[.[F[>[Q\B#DX"#QY2#N\?KYY?'RXN@@XO#ZY^K@(/$@
M3$1!4"#Q^O#B^O`N`,/PY?CJX"#O\.@@\>+Z\.?BX.WE(/'Z\2!334(@\?KP
MXOKP+@#4X.KQ`,'P[ND@].#IZ^[BY3H@)7,@].#IZP#!\.[I(/3@Z>ONXN4Z
M("5S(/3@Z>O@`-3@Z>L@[.7MX.;E\`#([.4@[>`@].#IZP#(Y^_PX/G@[>7R
M[B#MX"#TX.GK[N+E(.WE(/'E(._NY.3Z\.;@+@#4Z.OR^O``U.[P\^SH`,CL
MY2#MX"#TX.GK`,#D[.CMZ/'R\.CPX.WE(.W@(./P\^_H`,/P\^_H`,_PX.+@
M(.?@(./N\?+H`$A45%`@Z.3E[?+H].CJX/;H_R#MY2#E(.W@[.7PY>W@+@#/
M[NSN^0#-X/?@Z^X`Q.[LX/CE[2#@Y/#E\0#$[NS@^.7M(/+EZ^7T[NT`2&]R
M9&4`P_#E^.K@(._PZ"#Q^N?DX.+@[>4@[>`@24U!4"#O[OGE[?'JX"#J\_+H
M_SH@)7,`P_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@24U!4"#O[OGE[?'JX"#J
M\_+H_SH@)7,`P_#E^.K@(._N\.#DZ"#JXN[RX"#O\.@@\?KGY.#BX.WE(.W@
M($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S`$E0(.#D\.7QX"#MY2#E(.(@[^[G
MXN[KY>WH_R!#2412(.'K[NHN`-'@[.X@Z.KN[>@`R.KN[>@@\2#RY>KQ\@#(
M[._N\/(OQ>KQ[^[P\B#MX"#AY>OEYNKH`,CL[^[P\NCPX.WN(._NZ^4Z("5S
M`,CL[^[P\NCPX.WH(._NZ^7RX#H`R.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7B
MX.OHY.WH+@#-X.KK[NWE[>@`[_KK[>X@[^[D\.#B[?_BX.WE`.O_XNX@[^[D
M\.#B[?_BX.WE`.3_\>WN(._NY/#@XNW_XN#MY0!+97)B97)O<R#Q^O#B^O#@
M(.[R]>+Z\.OH(.CDY>WRZ/3HZN#VZ/_RX"X`RNO^]^`@XN7WY2#Q^OGE\?+B
M\^+@(.(@[_/AZ^CW[>C_(.KK_O?Q^O#B^O`N`,7GZ.H`S^[L[OD@\N7LZ`#1
M[^CQ^NK@(/$@[^[R\.7AZ/+EZ^@@Y2#GX.'PX.WE[2X`PO7NY`#(Y_7NY`#,
MS`!-4RU43D5&(._PZ.KPY>_E[>C_\B#TX.GK(.WE(/'ZY/KPYN#XY2#DX.WM
MZ"X`S^[YX`#1^N+OX.3@^>@@[^[KY?+@`-?KY>WNXN4`TN7J\?(`PNCD(.W@
M(.SE[?[R[CH`S^CQ[.X`S.7R[N0`36EM92#RZ.\`Q.#RX"#MX"#O\.[LY>W_
M[>4`S.[DZ/3H]NCPX.D@)7,`S.7QY??M[@#,[O_RX"#/[OG@`,CLY0#,\.7F
MX`#-Z.KNX^``S>[BX"#AY>OEYNK@`,WNXNX@[^[R\.7AZ/+EZ_'J[B#H[.4@
M*.[O]NCN[>#K[>XI`,WE`,W_[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@
M($944"!61E,N`,W_[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@(%-13"!6
M1E,N`,W_[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@(%-13"U&:6QE(%9&
M4RX`S?_LX"#AY>OEYNKH`,W_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($E-05`@
MZ.3E[?+H].CJX/;H_RX`S?_LX"#GX.3@Y.7MX"#OX/#NZ^`@Y^`@2V5R8F5R
M;W,@Z.3E[?+H].CJX/;H_RX`S?_LX"#J[NWTZ./S\.#VZ.[M[>`@Z.WT[O#L
MX/;H_R#GX"!334(@Z.3E[?+H].CJX/;H_RX`POKP[>#RZ/+E(.3@[>WH(.WE
M(/'@(%A-3`#-_^S@(/'R[NGM[O'RZ`#!Y>OEYNK@(.K@\N7C[O#H_P#!Y>OE
MYNK@(.3E\N#IZ^@`T>_H\?KJ(.'EZ^7FZN@`P>7KY>;JX"#RY>KQ\@#([.4@
M[>`@X>7KY>;MZ.K@.@#!Y>OEYNWH]N@`P>7KY>;JZ`#.R@#.[_;HZ`#/[N3P
MY>3E[2#Q[^CQ^NH`Q/#SX^`@Z.WT[O#LX/;H_P#$\//CZ"#.[_;HZ`#/\.#B
MX"#MX"#O\.CRY>;@\N7K_P!01U`@4VAE;&P`S^#P[NO@`,_@\.[KX#H`S^#P
M[NO@.B``S>7J[O#EZO+MX"#OX/#NZ^`N`,+L^NKMZ`#$X"#QY2#HY^+Z\/CB
MX/(@Z^@@[N'QZ_/FXN#YZ/+E(.[OY?#@]NCH(._PZ"#"]>[D/P#`Y.SH[>CQ
M\O#H\.#MY2#MX"#O\.#BX/+@`-+EZ^7T[NT`S.[K_RP@XOKBY>3E\N4@[.7Q
MY?8@Z"#C[N3H[>`N`,KK_O?NXN`@Y.+NZ>K@(._SX>OH]^7M+_?@\?+E[2#J
MZ_[W(.WE(.'E^.4@X^7MY?#H\.#MX"X`RN[E].CVZ.7M\@#7Y?+E[>4`R/'J
MX/+E(.3@(.CG\O#HY?+E("5S(.OH/R#2X.?H(.[OY?#@]NC_(.WE(.SNYN4@
MY.`@\>4@XOKP[>4@[>#GX.0N`,[O\.7Q[>@@\>_H\?KJX`#`Y/#E\2!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@#/\.7LX/7MZ`#/\.7L
MX/7MZ"#O[O+PY>'H\N7K.B`E<P#0[NO_`%-13"!3:&5L;`!34T@`TOKP\>@`
MT.7G\^ORX/+H(.[R(/+Z\/'E[>7R[@#.X?7BX/(@[>`@\OKP\>7MY0#(Y^'E
M\.7RY2#C\//OX"#GX"#D[N'@XO_MY0#(Y^'E\.7RY2#M[N(@[_#H\N7FX/+E
MZR#MX"#C\//OX`#(Y^'E\.@@X>7KY>;MZ.H`R.?AY?#E\N4@\?KPXOKP`,CG
MX>7PZ"#O[O+PY>'H\N7K(.?@(.3NX>#B_^WE`,CGX>7PY?+E(,3@\N`@\.#G
MY.7KZ/+EZSH`R.?AY?#E\N4@].[P[.#R(.?@(,3@\N#RX#H`R.?AY?#E\N4@
M].#IZR#GX"#H[._N\/(Z`,CGX>7PY?+E(/3N\.S@\B#GX"#7X/'@.@#(Y^'E
M\.7RY2#DXN4@\?KB[^#DX/GH(._NZ^7RX#H`R.?AY?#E\N4@XN#XX/+@(/'U
MY>S@(.?@(/;BY?+NXN7RY2X`R.?AY?#E\N4@[_#EY._N]^CRX.WH__(@[O(@
MPN#Q(.7GZ.HZ`,?@Y.#I\N4@PN#XY?+N(.W@]^#K[>X@[_#HZ^[FY>WHY2P@
M\?7E[.`@Y^`@]N+E\N[BY2P@[N_PY?'M_^+@[>4@[>`@\?+PX.WH]N#RX"#H
M(.3P\^/H(.[O]NCH(.?@(.3H\>_KY?\N`,_NZN#GXN#MY0#0X.?LY?``T>[P
M\NCPX.D@[^X@ZN#RY>/N\.C_`,+ZXN7FY.#MY2#MX"#Q[^7VZ.#K[>@@\>CL
MXN[KZ`#(Y^_PX/+H`-/Q[^7U`,?@Y.#WZ`#1X.SN(/+EZO'R`,_PZ.KPY>_E
M[>C_\B!01U`@[^[D[^CQ(.4@[>7NX?7NY.CL(.?@(.3@(/'E(._P[N+E\.@@
M[^[D[^CQX.WN\NX@[^CQ[.XN`,KPZ._RZ/#@[>7R[B#HY^CQZN+@(.KPZ._R
MZ/#@[>`@=V5B(.+P^N?JX"X`S.7Q\N[O[NONYN7MZ.7R[B#MX"!';G501R#T
MX.GKX"#R\/_AXN`@Y.`@X?KDY2#DX.3E[6\@[>`@0W)Y<'1?<&=P.CH@8VQA
M<P#!Y>OEYNK@\N`@X>7XY2#HY_+PZ/+@+@#!Y>OEYNWHZN`@(B5S(B#AY?CE
M(/'ZY^3@Y.7M+@#!Y>OEYNWHZN`@(B5S(B#AY?CE(._PY>S@]>W@\BX`P>7K
MY>;MZ.K@("(E<R(@X>7XY2#GX._H\>#M+@#/\.[C\.#LX/+@+"#J[O_R[B#Q
MZ_/FZ"#GX"#O[NK@Y^+@[>4@[>`@\N[GZ"#RZ.\@Y.#M[>@@*"5S*2#MY2#A
MY?CE(.[RZO#H\N`@XB#QZ/'RY>S@\N``S?_LX"#DXN[IZN@L(.KNZ/+N(.3@
M(.'ZY.#R(._NZN#GX.WH(.(@Z^CMZ/_RX"X`R.S@(/+B^O#DY2#L[>[C[B#Q
MZ.SB[NOH(.(@\N[BX"#O[NOE+B#"^N+EZ^@@\?+E("5S(/'H[.+NZ^`[(/+P
M_^'BX"#DX"#B^N+EY.7RY2#O[BWLX.OJ[B#N\B`E<RX`P_#E^.K@(._PZ"#H
MY^_PX/G@[>7R[B#MX"#TX.GKX#H@)7,@[>4@X>7XY2#HY^_PX/+E[2X`R.S@
M^.4@[_#NX>OE["#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`N("5S(.4@[^XM
MX^[K_^P@[O(@[.#J\>CLX.OM[B#D[N_S\?+H[.C_(/#@Y^SE\"`H)60@X>#I
M\N`I+@##\.7XZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@Z>O@+B`E<R#AY?CE
M(/'@[.X@[O+WX/'RZ"#HY^_PX/+E[2X`P_#E^.K@(._PZ"#H[._N\/(@[>`@
MY.#M[>@@Y^`@ZN[M\N#J\N@N`,W_[.`@X>7KY>;JZ"#GX"#EZO'O[O#R+@#2
M[N+@(.WE(.4@XN#KZ.3E[2!R87(@X/#UZ.(N`-+NXN`@[>4@Y2#BX.OHY.7M
M('II<"#TX.GK+@#2[N+@(._NZ^4@Y2#MY>[A]>[DZ.SN+@#2[N+@(._NZ^4@
M[.[FY2#DX"#Q^N3Z\.;@(/'@[.X@]N7KZ"#WZ/'KX"X`TN[BX"#O[NOE(.SN
MYN4@Y.`@\?KD^O#FX"#QX.SN(/?H\>O@(.@@Y.+NY?+N]^CE+@#2[N+@(._N
MZ^4@\O#_X>+@(.3@(.4@Y^#OY?+@_R#HZ^@@Z.WRY?#BX.L@\.#GY.7KY>T@
M\>_H\?KJ(._P[NSE[>OHXN@`TN#GZ"#T[O#LX"#BY??E(.'E^.4@[N'PX.'N
M\N7MX"X`TN[BX"#WZ/'K[B#R\/_AXN`@Y.`@Y2#O[NWE(.7DZ.WH]N`N`-+N
MY^@@\?KPXOKP(.WE(.SNYN4@Y.`@Y.7J[NSO\.7QZ/#@('II<"#H(&=Z:7`@
M].#IZ^[BY2X`TN#GZ"#Q\N[I[>[Q\B#R\/_AXN`@Y.`@Y2#WZ/'K[BX`S_#N
M\>OEY/_BX.WE(.WE(.+PY>SE`,3K^N;M[O'R`%523`#-Y>+ZY^SNYNWN\?(@
MY^`@XO#ZY^K@(/$@4U%,(/'Z\.+Z\"X`P_#E^.K@(._PZ"#HY_+PZ.+@[>4@
M(B5S(CH@)7,N`,/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO\.7QZ/#@
M[2#@\/7HXBX`P_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@
M+@##\.7XZN`@[_#H(._PY>+NY.`@[>`@\N[GZ"!7;W)D(.3NZO/LY>WR`,_N
MY/?E\/+@[>@`S>7O[N_ZZ^WE[0#.[_#E\>WH`,[O\.7Q[>@@)7,`P.3LZ.WH
M\?+PZ/#@[>4@[>`@[^[R\.7AZ/+EZ^CRY0#([.4`R.SE.@#([.4Z(`#/[O+P
MY>'H\N7KZ"#B(/'H\?+E[.#RX#H`PN#JX.WVZ/\`P_#E^.K@(._PZ"#O\.[B
MY?#JX/+@("T@\N[BX"#OZ/'L[B#L[N;E(.3@(.4@X>CK[B#O[N3O\.#BY>WN
M+@#"[>CLX.WHY0#1Y>3LZ/?M[@#$[N'PY2#$[OCKZ"#B("5S`,3NX?#E(.3N
M^.OH+"`E<P#(Y^'E\.7RY2#O\.CK[N;E[>CE\NXL(.KNY?+N("5S(.3@(._N
MZN#FY2#QZ^7D(.+U[N0N`,KZ["#J[ND@X>7KY>;MZ.H@Y.`@X?KDY2#D[N'@
MXN7MX"#AY>OEYNK@\N`_`,'HY^WE\2#@Y/#E\0#!Z.?MY?$@\N7KY?3N[0##
MPP##[N3H^.WN`,3@`,WE(.+ZXN7D[O7RY2#BX.OHY.7M(&5M86EL(.#D\.7Q
M+@#2\/_AXN`@Y.`@Z.?AY?#E\N4@X>7KY>;MZ.HL(.KNZ?+N(.3@(.'ZY.4@
MZ.?R\.CR+@#2\/_AXN`@Y.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#HY_+P
MZ.+@[>4N`-+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.3NX>#B
M_^WE+@#2\/_AXN`@Y.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#N[_#E\>W_
MXN#MY2X`R.WT[O#LX/;H_R#GX"#"X/$`PN#XZ/_R(.CDY>WRZ/3HZN#VZ.[M
MY>T@Y/#@Z>+E\"#MY2#O[N3D^O#FX"#Q[^CQ^NH@[>`@[^[R\.7AZ/+EZ^CR
MY2P@Z.OH(/+@Y^@@XOKG[.[F[>[Q\B#E(.?@X?#@[>7MX"X`PN#XZ/_R(.'E
MZ^7F[>CJ(._N(._NY/#@Y^'H\.#MY3H`PN#XZ/+E(.'EZ^7F[>CVZ#HZ`,+@
M^.CRY2#J[NWTZ./S\.#VZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"X`PN#X
MZ/+E(/'Z\.+Z\.@Z`%OKZ.WH_R`E<R#N\B`E<UT`].#IZP#AY><@Z.SE`'9#
M87)D```````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]D85]$2R\`````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-#0`,#$W-S0P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O
M;&]C86QE+V1A7T1++TQ#7TU%4U-!1T53+P``````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P,C$U,C4`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O9&%?1$LO3$-?34534T%'15,O;6YE
M;6\N;6\``````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-3(U`#$P-#$W,S8R-S0T`#`R
M,S(P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25`````&L````<````=`,``)4```#,!@```````"`)```H````(0D`
M``@```!*"0``!0```%,)```/````60D```@```!I"0``"````'()```9````
M>PD```<```"5"0``#@```)T)```%````K`D```D```"R"0``$0```+P)```(
M````S@D```@```#7"0``%0```.`)```(````]@D```H```#_"0``"@````H*
M```,````%0H```<````B"@``$````"H*```I````.PH```(```!E"@``!0``
M`&@*```0````;@H``!D```!_"@``&@```)D*```*````M`H``!0```"_"@``
M#P```-0*```F````Y`H```4````+"P``#0```!$+```%````'PL```L````E
M"P``#P```#$+```A````00L```,```!C"P``#````&<+```$````=`L```P`
M``!Y"P``"@```(8+```%````D0L``!(```"7"P``$````*H+```0````NPL`
M`!H```#,"P``!@```.<+```'````[@L```(```#V"P``!````/D+```/````
M_@L```D````.#```!P```!@,```,````(`P```<````M#```!````#4,```'
M````.@P```0```!"#```!0```$<,```-````30P```@```!;#```%0```&0,
M```>````>@P```4```"9#```*````)\,```I````R`P``!,```#R#```#```
M``8-```+````$PT``!$````?#0``!````#$-```,````-@T```8```!##0``
M#@```$H-```,````60T``!H```!F#0``%P```($-```7````F0T``!L```"Q
M#0``$P```,T-```0````X0T``!````#R#0``%P````,.```'````&PX```4`
M```C#@``!0```"D.```#````+PX``"`````S#@``)@```%0.```,````>PX`
M``<```"(#@``"````)`.```4````F0X```<```"N#@``!@```+8.```+````
MO0X```P```#)#@``"@```-8.```"````X0X```8```#D#@``10```.L.```F
M````,0\``"4```!8#P``<P```'X/```0````\@\``&T!```#$```(````'$1
M```(````DA$```4```";$0``%0```*$1```)````MQ$```P```#!$0``(@``
M`,X1```'````\1$```X```#Y$0``"0````@2```(````$A(``!0````;$@``
M"@```#`2```(````.Q(``!T```!$$@``"````&(2```%````:Q(```P```!Q
M$@``"@```'X2```%````B1(```\```"/$@``+````)\2```"````S!(```8`
M``#/$@``$@```-82```<````Z1(``!L````&$P``"````"(3```1````*Q,`
M`!D````]$P``*````%<3```%````@!,```\```"&$P``!````)83```/````
MFQ,``!````"K$P``+````+P3```#````Z1,```T```#M$P``!0```/L3```.
M`````10```X````0%```!0```!\4```6````)10``!,````\%```&0```%`4
M```@````:A0```<```"+%```!@```),4```"````FA0```0```"=%```%@``
M`*(4```6````N10```H```#0%```"0```-L4```(````Y10```0```#N%```
M!P```/,4```'````^Q0```4````#%0``$P````D5```'````'14``!D````E
M%0``%0```#\5```'````514``#H```!=%0``)@```)@5```2````OQ4```T`
M``#2%0``"````.`5```;````Z14```4````%%@``$P````L6```#````'Q8`
M`!0````C%@``$````#@6```6````218``!````!@%@``$````'$6```H````
M@A8``!<```"K%@``&P```,,6```5````WQ8``!\```#U%@``"````!47```'
M````'A<```4````F%P```P```"P7```K````,!<``"@```!<%P``$0```(47
M```,````EQ<```H```"D%P``$P```*\7```(````PQ<```@```#,%P``#0``
M`-47```1````XQ<``!$```#U%P```@````<8```%````"A@``$H````0&```
M+P```%L8```P````BQ@``(,```"\&```%````$`9```!````40`````````[
M````2@````L```!'````````````````````+````"X```!.````-P``````
M```4````8@````0```!8````*@```%X`````````-@```"4```!)````#P``
M```````=````%@```&L``````````````"(```!I````"````$\`````````
M/@```#H```!3````0@````X````2````(P```#P```!&````-0```$P```!2
M````9P``````````````'P```%D````,````8P`````````9````7````!4`
M```````````````````D````50```$,`````````90``````````````!P``
M`&$```!@````)P```#@```!%````5@`````````3`````````&8````%````
M`````"T```!:```````````````0````4`````(`````````,@```$L`````
M````7P````8`````````&P```$`````Y`````````!<````S````'```````
M```*````&@````````!(`````P```#T````O````30```!@````I````````
M```````K````:````$0````>`````````%T`````````#0```%<````@````
M/P````````!J````"0```%L`````````00```#$````H``````````````!4
M````$0`````````A````````````````````)@```&0````P````-``````E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`#(T(&AO
M=7)S`$%-+U!-`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E<@!!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061M:6YI<W1R871I
M;VX`06QI87,`07-C96YD:6YG`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y
M`$-A;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#871E9V]R>0!#96QL
M(%!H;VYE`$-L96%R($9O<FT`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]N9FER
M;2!087-S=V]R9`!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<P!$1`!$86EL>0!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@<V]R
M=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5S
M8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$:7-P;&%Y($]P=&EO;G,`
M1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``16UA:6P`
M16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2!,;V=I;@!%>&%M<&QE('9A;'5E
M<SH`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&:6QE
M($UA;F%G97(`2&5L<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)
M;7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!,:7-T($AE;'`@
M5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO9R!I;@!,;V<@
M;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE;6\@5&5X=`!-97-S86=E
M`$UO9&EF>6EN9R`E<P!-;VYT:&QY`$YA;64`3F5T=V]R:P!.97=S`$YO=&5S
M`$]T:&5R($]P=&EO;G,`4&%S<W=O<F0`4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4F5F<F5S:"!,:7-T`%)E;6]V92!P86ER`%)E='5R;B!T;R!/<'1I
M;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E87)C:`!396%R8V@@4F5S=6QT<P!3
M96%R8V@@4V-O<&4`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;F0@4')O8FQE;2!297!O<G0`
M4VMI<"!-86EN=&5N86YC90!3;W)T(&)Y($-A=&5G;W)Y`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-U8V-E<W,`5&%S:W,`5&ET;&4`55),`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5S97)N
M86UE`%5S97)S(&EN('1H92!S>7-T96TZ`%=A<FYI;F<`5V5E:VQY`%=E;&-O
M;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%M0<F]B;&5M(%)E
M<&]R=%T`4')O:F5C="U)9"U697)S:6]N.B!-;F5M;R`R+C`M8W9S"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P,BTV,2TR,2`Q,CHQ,2LP,3`P"DQA<W0M5')A;G-L871O<CH@
M36%R=&EN($QI<W0M4&5T97)S96X@/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K
M/@I,86YG=6%G92U496%M.B!$86YI<V@@/&1K+6AO<F1E0&AU;'!S>7-T96US
M+FYE=#X*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=`H`)7,@5F5D;&EG96AO;&1E;'-E("T@0F5K<N9F=&5L<V4`
M,C0@=&EM97(`04TO4$T`3W!R971T92!E;B!N>2!B<G5G97(Z`$]P<F5T('!A
M<@!/<')E="!B<G5G97(`3W!R971T96QS92!A9B!B<G5G97)E(&5R('-LY65T
M(&9R80!!9')E<W-E`$%D;6EN:7-T<F%T:6]N`$MA;&1E;F%V;@!3=&EG96YD
M90!&96QT97(@=&EL('+E9&EG:&5D.@!&^&1S96QS9&%G`$MA;&5N9&5R`$%F
M8G)Y9"!R97!O<G1E<FEN9R!A9B!P<F]B;&5M`$MA=&5G;W)I`$UO8FEL`%3X
M;2!F96QT97)N90!,=6L@=FEN9'5E`$9I<FUA`$)E:W+F9G0@:V]D96]R9`!+
M=6YN92!I:VME(.5B;F4@;6]D=6P@=&EL('9E9&QI9V5H;VQD96QS92`E<P!$
M1`!$86=L:6<`4W1A;F1A<F0M:61E;G1I=&5T`%-T86YD87)D('-O<G1E<FEN
M9W-K<FET97)I93H`4W1A;F1A<F0@<V]R=&5R:6YG<W)E=&YI;F<Z`$9A;&1E
M;F1E`$)E<VMR:78@<')O8FQE;65T`$EN9'-T:6QL:6YG97(@9F]R('9I<VYI
M;F<`1'4@;>4@:6MK92!K86QD92!M86EN=&5N86YC92YP:'`@9&ER96MT90!E
M36%I;`!);G1E="!R97-U;'1A="X`1F5J;`!!;'1I9"!V960@;&]G:6X`16MS
M96UP96QVYG)D:65R.@!+=6YN92!I:VME(&;E(&9O<F)I;F1E;'-E('1I;"!,
M1$%0('-E<G9E<F5N+@!&87@`1FEL:.5N9'1E<FEN9P!(:N9L<`!!9')E<W-E
M("AH:F5M*0!496QE9F]N("AH:F5M*0!(;W)D90!);7!O<G1E<F5D92!F96QT
M97(Z("5S`$EM<&]R=&5R961E(&9E;'1E<CH`3W!L:7-T;FEN9R!A9B!H:N9L
M<&5E;6YE<@!6:7-N:6YG(&%F(&)R=6=E<F4@97(@<VSE970@9G)A+@!,;V<@
M:6YD`$QO9R!U9`!-30!-86EL`$]V97)E;G-P87-S96YD92!F96QT97(`5&5K
M<W1E;B!A9B!H=7-K97-E9&1E;`!-961D96QE;'-E`,9N9')E<B`E<P!-Y6YE
M9&QI9P!.879N`$YE=';F<FL`3GEH961E<@!.;W1E<@!!;F1R92!I;F1S=&EL
M;&EN9V5R`$MO9&5O<F0`2V]D96]R9&5N92!S:V%L(';F<F4@96YS+@!59&;X
M<B!V961L:6=E:&]L9&5L<V4`5&5L969O;@!3:W)I=B!V96YL:6=S="P@:'9A
M9"!P<F]B;&5M970@9^5R('5D('#E(&]G(&AV860@9&5R('-K97(N`$EN9'1A
M<W0@=F5N;&EG<W0@8G)U9V5R;F%V;B!O9R!K;V1E;W)D`%!R;V)L96UB97-K
M<FEV96QS90!/<&1A=&5R(&QI<W1E`%-L970@<&%R`%1I;&)A9V4@=&EL(&EN
M9'-T:6QL:6YG97)N90!296=E;`!'96UM92!);F1S=&EL;&EN9V5R`%/X9P!2
M97-U;'1A="!F;W(@<_AG;FEN9P!-961T86<@:2!S^&=N:6YG`%;F;&<@9&%T
M;RUA9'-K:6QL97)E;CH`5N9L9R!D871O9F]R;6%T.@!6YFQG('1I9'-F;W)M
M870Z`%;F;&<@=&\@9F5L=&5R+"!D97(@<W9A<F5R('1I;"!H:6YA;F1E;BX`
M4V5N9"!P<F]B;&5M8F5S:W)I=F5L<V4`4W!R:6YG('9E9&QI9V5H;VQD96QS
M92!O=F5R`%-O<G1E<B!E9G1E<B!K871E9V]R:0!);F1T87-T;FEN9R!F;W(@
M<W!E8VEA;&MA<F%K=&5R`$QY:VME9&5S`$]P9V%V97(`5&ET96P`55),`$MU
M;FYE(&EK:V4@9N4@9F]R8FEN9&5L<V4@=&EL(%-13"!S97)V97)E;BX`2W5N
M;F4@:6MK92!O=F5R<^9T=&4@9&5T=&4@5V]R9"!D;VMU;65N=`!&;W)T<GED
M(.9N9')I;F=E<@!):VME('1I;&1E;'0`0G)U9V5R;F%V;@!"<G5G97)E(&D@
M<WES=&5M970Z`$%D=F%R<V5L`%5G96YT;&EG`%9E;&MO;6UE;BP@)7,`061R
M97-S92`H87)B96ID92D`5&5L969O;B`H87)B96ID92D`Q<4`Q7)L:6<`1'4@
M8FQI=F5R(&[X9"!T:6P@870@;&%V92!E;B!P<F]B;&5M8F5S:W)I=F5L<V4L
M(&;X<B!D=2!K86X@<V5N9&4@9&5N(&EN9"X`1'4@<VMA;"!A;F=I=F4@8G)U
M9V5R;F%V;F5T+"!S;VT@9'4@=FEL(&9J97)N92X`1'4@<VMA;"!A;F=I=F4@
M8G)U9V5R;F%V;F5T+"!S;VT@9'4@=FEL('1I;&;X:F4N`$1I;B!A=71O<FES
M871I;VYS+6)A8VME;F0@=6YD97)S=/AT=&5R(&EK:V4@;W!L:7-T;FEN9V5N
M(&%F(&)R=6=E<F4@96QL97(@97(@9&5N(&9U;FMT:6]N(&%F(&5N(&5L;&5R
M(&%N9&5N(&=R=6YD(&)L979E="!S;.5E="!F<F$N`%M0<F]B;&5M8F5S:W)I
M=F5L<V5=````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+V1A7T1++VAE
M;'`N>&UL````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#<Q-0`Q
M,#0Q-S,V,C<T-``P,C$T,38`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO
M<F1E.B!M;F5M;R]L;V-A;&4O9&%?1$LO:&5L<"YX;6PL=B`Q+C(@,C`P,B\Q
M,"\R,"`Q-CHS,3HP,B!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB3W9E<G9I97<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D]V97)V:65W
M/"]T:71L93X*("`@(#QH96%D:6YG/DEN=')O9'5C=&EO;CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@/&D^3F]T97,\+VD^(&ES(&%N(&%P<&QI8V%T:6]N
M('=H:6-H(&%L;&]W<R!Y;W4@=&\@8W)E871E('1H92!C;VUP=71E<B!E<75I
M=F%L96YT(&]F('-T:6-K>2!N;W1E<RX@($YO=&5S(&-A;B!B92!C<F5A=&5D
M+"!M;V1I9FEE9"P@9&5L971E9"P@86YD('!R:6YT960N("!9;W4@8V%N(&%L
M<V\@<V5A<F-H(&]N('EO=7(@;F]T97,@=&\@;&]C871E(&EN9F]R;6%T:6]N
M+B`@(%-U<'!O<G0@9F]R(&EM<&]R=&EN9R!A;F0@97AP;W)T:6YG(&YO=&5S
M(&ES(&%L<V\@879A:6QA8FQE+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!5;FQI:V4@<F5A;"!S=&EC:WD@;F]T97,L('EO=7(@8V]M<'5T97(@;F]T
M97,@8V%N(&)E('-H87)E9"!W:71H(&]T:&5R<R!I;B!D:69F97)E;G0@<&AY
M<VEC86P@;&]C871I;VYS+B`@3F]T97,@8V%N(&)E(&]R9V%N:7IE9"!I;G1O
M(&1I9F9E<F5N="!N;W1E<&%D<RP@86YD(&%S<VEG;F5D(&-A=&5G;W)I97,N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)L:7-T+6%C=&EO
M;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y6:7-N:6YG(&9O<B!(
M=7-K97-E9&QE<CH@2&%N9&QI;F=E<CPO=&ET;&4^"B`@("`\:&5A9&EN9SY(
M86YD;&EN9V5R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3;&5T(&AU<VME
M<V5D;&5R('-L971T97(@86QL92!M87)K97)E9&4@:'5S:V5S961L97(N"B`@
M("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)L:7-T
M+6%C=&EO;G,B/@H@("`@/'1I=&QE/DYO=&5S($QI<W0Z($%C=&EO;G,\+W1I
M=&QE/@H@("`@/&AE861I;F<^06-T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@/&D^1&5L971E($YO=&4\+VD^('!E<FUA;F5N=&QY(&1E;&5T97,@
M=&AE('-E;&5C=&5D(&YO=&4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M(#QI/DUO9&EF>2!.;W1E/"]I/B!A;&QO=W,@>6]U('1O(&UO9&EF>2!A;B!E
M>&ES=&EN9R!N;W1E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`\:3Y"
M86-K('1O($YO=&5P860\+VD^('1A:V5S('EO=2!B86-K(&9R;VT@;F]T92!V
M:65W('1O('1H92!N;W1E<&%D('1H870@8V]N=&%I;G,@=&AE(&-U<G)E;G0@
M;F]T92X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB;65N=2UA8W1I;VYS(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-
M96YU($ET96US/"]T:71L93X*("`@(#QH96%D:6YG/DUE;G4@271E;7,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(#QI/DQI<W0@3F]T97,\+VD^(&QI<W1S
M(&%L;"!T:&4@;F]T97,@:6X@=&AE(&-U<G)E;G0@;F]T97!A9"X*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@/&D^3F5W($YO=&4\+VD^(&%L;&]W<R!Y
M;W4@=&\@8W)E871E(&$@;F5W(&YO=&4@:6X@=&AE(&-U<G)E;G0@;F]T97!A
M9"X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@/&D^4V5A<F-H/"]I/B!A
M;&QO=W,@>6]U('1O('-E87)C:"!F;W(@=&5X="!I;B!Y;W5R(&YO=&5S+B`@
M66]U(&-A;B!S96%R8V@@=&AE(&1E<V-R:7!T:6]N(&9I96QD(&]N;'DL(&]R
M('1H92!F=6QL('1E>'0@;V8@=&AE(&YO=&5S+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("`\:3Y);7!O<G0O17AP;W)T/"]I/B!A;&QO=W,@>6]U('1O
M(&EM<&]R="!O<B!E>'!O<G0@;F]T97,N("!#=7)R96YT;'D@;VYL>2!#4U8@
M9F]R;6%T=&5D(&9I;&5S(&%R92!S=7!P;W)T960N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@(#QI/E!R:6YT/"]I/B!A;&QO=W,@>6]U('1O('!R:6YT
M(&$@;F]T92X@(%1H92`\:3Y0<FEN=#PO:3X@:6-O;G,@:7,@;VYL>2!I;B!T
M:&4@;65N=2!B87(@=VAE;B!A(&YO=&4@:7,@8F5I;F<@=FEE=V5D+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V]R=&EN9R(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4V]R=&EN9R!%;G1R:65S/"]T:71L93X*("`@
M(#QH96%D:6YG/E-O<G1I;F<@16YT<FEE<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5VAE;B!V:65W:6YG(&$@;&ES="!O9B!E;G1R:65S+"!Y;W4@8V%N
M('-O<G0@=&AE(&5N=')I97,@8GD@86YY(&-O;'5M;B!B>2!C;&EC:VEN9R!O
M;B!T:&4@87!P<F]P<FEA=&4@8V]L=6UN(&AE861I;F<@=&ET;&4N("!4;R!S
M=VET8V@@82!C;VQU;6X@8F5T=V5E;B!A<V-E;F1I;F<@86YD(&1E<V-E;F1I
M;F<@<V]R=&EN9R!O<F1E<BP@8VQI8VL@;VX@=&AE(&%R<F]W(&EC;VX@:6X@
M=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE
M;'`^"@``````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C
M86QE+V1E7T1%+P``````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P,3<W,S8`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]M;F5M;R]L;V-A;&4O9&5?1$4O3$-?34534T%'15,O````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,34R
M,P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]D95]$12],
M0U]-15-304=%4R]M;F5M;RYM;P``````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-#0V,#<`
M,3`T,3<S-C(W-#0`,#(S,C`W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````_`<``!P```#\/P``J0H``-Q_````
M````@*H```X```"!J@``#P```)"J```-````H*H```@```"NJ@``"P```+>J
M```,````PZH```0```#0J@``&````-6J```;````[JH``"T````*JP``'0``
M`#BK```D````5JL``"D```![JP``&0```*6K```F````OZL```P```#FJP``
M)````/.K```(````&*P```\````AK```"P```#&L```.````/:P```4```!,
MK```*````%*L```(````>ZP```H```"$K```%0```(^L```2````I:P```L`
M``"XK```#0```,2L```=````TJP``(4```#PK```#@```':M```*````A:T`
M``T```"0K0``#@```)ZM```1````K:T```T```"_K0``#````,VM```-````
MVJT```8```#HK0``E````.^M```*````A*X```\```"/K@``&````)^N```,
M````N*X```8```#%K@``#@```,RN```.````VZX```@```#JK@``"0```/.N
M```N````_:X``!H````LKP``,@```$>O```X````>J\``%0```"SKP``40``
M``BP``!:````6K```%<```"UL```-`````VQ```)````0K$```T```!,L0``
M!P```%JQ```*````8K$```\```!ML0``!0```'VQ```&````@[$``!$```"*
ML0``"````)RQ```)````I;$```D```"OL0``)0```+FQ```@````W[$``!P`
M````L@``'@```!VR```@````/+(``!T```!=L@``$P```'NR```0````C[(`
M``\```"@L@``"@```+"R```#````N[(```\```"_L@``%````,^R```)````
MY+(```T```#NL@``$@```/RR```9````#[,``!X````ILP``#P```$BS```,
M````6+,```H```!ELP``#P```'"S```(````@+,``"0```")LP``%````*ZS
M```6````P[,```@```#:LP``3@```..S```M````,K0``!$```!@M```&0``
M`'*T```'````C+0```P```"4M```+````*&T```.````SK0```,```#=M```
M"P```.&T```'````[;0```<```#UM```!0```/VT```%`````[4```H````)
MM0```P```!2U```7````&+4```H````PM0``#P```#NU```.````2[4``!@`
M``!:M0``(P```'.U```.````E[4``!0```"FM0``%P```+NU```7````T[4`
M`!<```#KM0``$P````.V```/````%[8```X````GM@``'P```#:V```=````
M5K8```<```!TM@``!@```'RV```(````@[8```\```",M@``!@```)RV```*
M````H[8``!,```"NM@``"P```,*V```0````SK8``!4```#?M@``%0```/6V
M```'````"[<``!`````3MP``!0```"2W```5````*K<``!$```!`MP``#```
M`%*W```[````7[<``#@```";MP``"0```-2W```'````WK<``!0```#FMP``
M`P```/NW```%````_[<```D````%N```$`````^X```)````(+@``!,````J
MN```.0```#ZX```2````>+@``"<```"+N```+````+.X```J````X+@``"4`
M```+N0``"@```#&Y```&````/+D```D```!#N0``!P```$VY```O````5;D`
M`#<```"%N0``+@```+VY``!5````[+D``"T```!"N@``+0```'"Z```]````
MGKH``#\```#<N@``+0```!R[``!`````2KL``",```"+NP``(P```*^[``!`
M````T[L``"T````4O```,P```$*\```E````=KP``!4```"<O```&0```+*\
M```I````S+P``"0```#VO```*````!N]```5````1+T``!$```!:O0``"@``
M`&R]```,````=[T```\```"$O0``%P```)2]```*````K+T``!````"WO0``
M%@```,B]```6````W[T```<```#VO0``!P```/Z]```4````!KX```H````;
MO@``"````":^```G````+[X```@```!7O@``!P```&"^```'````:+X```8`
M``!PO@``!0```'>^```'````?;X```8```"%O@``"````(R^```I````E;X`
M``X```"_O@``"@```,Z^```$````V;X```<```#>O@``"0```.:^```&````
M\+X``!$```#WO@``!P````F_```6````$;\```0````HOP``"````"V_```&
M````-K\```T````]OP``!@```$N_```>````4K\``!$```!QOP``"````(._
M```-````C+\```P```":OP``!P```*>_```#````K[\```,```"SOP``%P``
M`+>_```#````S[\``!,```#3OP``'0```.>_```(````!<````0````.P```
M"````!/````(````',```$$````EP```&@```&?````K````@L```"````"N
MP```%0```,_````&````Y<````8```#LP```%0```//````8````"<$``"(`
M```BP0``+@```$7!```=````=,$``"$```"2P0``5````+3!```I````"<(`
M``H````SP@``!P```#["```'````1L(``!4```!.P@``"````&3"```.````
M;<(```H```!\P@``#P```(?"```-````E\(```\```"EP@``#0```+7"```)
M````P\(``!0```#-P@``!@```.+"```8````Z<(``!T````"PP``$P```"##
M```1````-,,``!0```!&PP``!````%O#```&````8,,``!0```!GPP``5```
M`'S#```M````T<,``&0```#_PP``!````&3$```.````:<0```4```!XQ```
M!0```'[$```;````A,0``!H```"@Q```$P```+O$```1````S\0``!$```#A
MQ```'````//$```J````$,4``#<````[Q0``'````'/%```0````D,4``"$`
M``"AQ0``!0```,/%```*````R<4``!,```#4Q0``"P```.C%```2````],4`
M``H````'Q@``#P```!+&```-````(L8``!$````PQ@``$P```$+&```,````
M5L8```8```!CQ@``#````&K&```&````=\8``!<```!^Q@``$````);&```1
M````I\8```@```"YQ@``!0```,+&```,````R,8``!````#5Q@``!0```.;&
M```-````[,8```8```#ZQ@``!P````''```-````"<<```<````7QP``"P``
M`!_'```'````*\<```<````SQP``"0```#O'```)````1<<```H```!/QP``
M&0```%K'```]````=,<``!T```"RQP``#````-#'```0````W<<```4```#N
MQP``)0```/3'```2````&L@``!,````MR```*P```$'(```[````;<@``"``
M``"IR```"````,K(```V````T\@``"$````*R0``$````"S)```(````/<D`
M``P```!&R0``!@```%/)```$````6LD```\```!?R0``#@```&_)```'````
M?LD```H```"&R0``#0```)')```?````G\D``!P```"_R0``(0```-S)```>
M````_LD``!D````=R@``'@```#?*```;````5LH``"$```!RR@``+@```)3*
M```F````P\H``!P```#JR@``'@````?+```<````)LL``"8```!#RP``*P``
M`&K+```S````ELL``"8```#*RP``*P```/'+```X````'<P``!T```!6S```
M%0```'3,```O````BLP``"````"ZS```$@```-O,```I````[LP``!X````8
MS0``(````#?-```2````6,T``*(```!KS0``%@````[.```C````)<X``"@`
M``!)S@``*0```'+.```H````G,X``!\```#%S@``%0```.7.```@````^\X`
M`"4````<SP``*````$+/```M````:\\``#````"9SP``D@```,K/```A````
M7=```!8```!_T```'````);0```F````L]```"H```#:T```00````71``!$
M````1]$```P```",T0``!P```)G1```'````H=$```8```"IT0``#0```+#1
M```0````OM$``!(```#/T0``!P```.+1```3````ZM$``!(```#^T0``!P``
M`!'2```$````&=(``!`````>T@``$````"_2```,````0-(```X```!-T@``
M#0```%S2```/````:M(``!,```!ZT@``#0```([2```H````G-(```,```#%
MT@``#0```,G2```&````U](``!$```#>T@``%P```/#2```;````"-,```X`
M```DTP```@```#/3``!)````-M,```4```"`TP``$````(;3```/````E],`
M``0```"GTP``#0```*S3```.````NM,```,```#)TP``#@```,W3```(````
MW-,```\```#ETP``#P```/73```'````!=0```T````-U```$````!O4```/
M````+-0```T````\U```&0```$K4```:````9-0```L```!_U```!@```(O4
M```+````DM0``!,```">U```#````++4```*````O]0``!$```#*U```&0``
M`-S4```7````]M0```L````.U0``#0```!K5```B````*-4```\```!+U0``
M&P```%O5```T````=]4```H```"LU0``&````+?5```2````T-4``!D```#C
MU0``%@```/W5```0````%-8``"(````EU@``#0```$C6```'````5M8```H`
M``!>U@``%````&G6```+````?M8```P```"*U@``(@```)?6```O````NM8`
M``L```#JU@``"0```/;6```9`````-<```L````:UP``%P```";7```7````
M/M<```D```!6UP``%@```&#7```/````=]<``!D```"'UP``%@```*'7```.
M````N-<``!@```#'UP``"````.#7```-````Z=<``"8```#WUP``*````![8
M``!#````1]@```@```"+V```$@```)38```?````I]@```@```#'V```"P``
M`-#8```O````W-@```X````,V0``!0```!O9```&````(=D``$4````HV0``
M`P```&[9```'````<MD```0```!ZV0``"0```'_9```*````B=D```H```"4
MV0``"0```)_9```/````J=D``!````"YV0``%P```,K9```:````XMD``!$`
M``#]V0``&0````_:```7````*=H```D```!!V@``!0```$O:```+````4=H`
M``H```!=V@```@```&C:```%````:]H```T```!QV@``&P```'_:```7````
MF]H``!0```"SV@``"0```,C:```*````TMH```X```#=V@``#0```.S:```2
M````^MH``#@````-VP``(````$;;```(````9]L```X```!PVP``>P```'_;
M```8````^]L``!@````4W```$0```"W<```'````/]P```4```!'W```&```
M`$W<```>````9MP``!L```"%W```&0```*'<```;````N]P``!D```#7W```
M$P```/'<```'````!=T```@````-W0``!@```!;=```&````'=T``!`````D
MW0``#P```#7=```0````1=T```\```!6W0``"P```&;=```/````<MT```P`
M``""W0``#P```(_=```'````G]T```8```"GW0``#@```*[=```,````O=T`
M`"@```#*W0``#P```//=```(`````]X```8````,W@``#````!/>```(````
M(-X``!,````IW@``"@```#W>```>````2-X``"$```!GW@``(````(G>```9
M````JMX``!<```#$W@``)0```-S>```7`````M\``!8````:WP``!````#'?
M```;````-M\```T```!2WP``#````&#?```#````;=\```4```!QWP``"```
M`'??```*````@-\```P```"+WP``"P```)C?```0````I-\```P```"UWP``
M#@```,+?```+````T=\```0```#=WP``!````.+?```3````Y]\``!0```#[
MWP``#````!#@```)````'>````X````GX```"P```#;@```;````0N````<`
M``!>X```!P```&;@```*````;N````T```!YX```"0```(?@```$````D>``
M``4```"6X````P```)S@```8````H.````H```"YX```!````,3@```F````
MR>````X```#PX```?````/_@```5````?.$```4```"2X0``!P```)CA```,
M````H.$```@```"MX0``"@```+;A```&````P>$```@```#(X0```@```-'A
M```&````U.$```8```#;X0``%````.+A```-````]^$``!`````%X@``&P``
M`!;B```$````,N(```D````WX@``$````$'B```)````4N(```D```!<X@``
M!0```&;B```:````;.(```@```"'X@``!@```)#B```/````E^(``!D```"G
MX@``#@```,'B```'````T.(```<```#8X@``!0```.#B```)````YN(```H`
M``#PX@``#@```/OB```"````"N,```8````-XP``"P```!3C```-````(.,`
M``D````NXP``!@```#CC```2````/^,```D```!2XP``!P```%SC```4````
M9.,``!T```!YXP``0@```)?C```E````VN,``"4`````Y```!@```";D```*
M````+>0```0````XY```"0```#WD```(````1^0``!$```!0Y```"0```&+D
M```&````;.0```T```!SY```!@```('D```$````B.0``#D```"-Y```/0``
M`,?D```Z````!>4``!X```!`Y0``!0```%_E```.````9>4```0```!TY0``
M!@```'GE```'````@.4``"$```"(Y0``#0```*KE```5````N.4```8```#.
MY0``!````-7E```1````VN4```8```#LY0``"@```//E```B````_N4```0`
M```AY@``!0```";F```=````+.8```0```!*Y@``#````$_F```.````7.8`
M``H```!KY@``"````';F```)````?^8```4```")Y@``.@```(_F```P````
MRN8``#4```#[Y@``*0```#'G``!'````6^<``#@```"CYP``*0```-SG```_
M````!N@``"X```!&Z```+0```'7H```?````H^@```\```##Z```$@```-/H
M```+````YN@``"8```#RZ```*0```!GI```D````0^D``"8```!HZ0``"```
M`(_I```*````F.D```D```"CZ0``!P```*WI```@````M>D``"````#6Z0``
M)@```/?I```*````'NH``!D````IZ@``*0```$/J```6````;>H``!(```"$
MZ@``!P```)?J```*````G^H```P```"JZ@``#P```+?J```0````Q^H``$``
M``#8Z@``<````!GK``!F````BNL```X```#QZP``"0````#L```*````"NP`
M`!(````5[```$P```"CL```,````/.P```8```!)[```%0```%#L```/````
M9NP``!,```!V[```$@```(KL```0````G>P``!$```"N[```'````,#L```C
M````W>P``&H````![0``#P```&SM```%````?.T``!````""[0``"0```)/M
M```$````G>T```L```"B[0``(````*[M```4````S^T```P```#D[0``#```
M`/'M```/````_NT``!4````.[@``*0```"3N```J````3NX``"8```!Y[@``
M)P```*#N```I````R.X``"H```#R[@``&0```!WO``!"````-^\``!$```!Z
M[P``$@```(SO```3````G^\``!0```"S[P``#P```,CO```6````V.\``!<`
M``#O[P``$`````?P```1````&/```#0````J\```$P```%_P```2````<_``
M`#4```"&\```%````+SP```'````T?````P```#9\```(````.;P```0````
M!_$``!0````8\0``$0```"WQ```7````/_$``!P```!7\0``$P```'3Q```4
M````B/$``!H```"=\0``$0```+CQ```:````RO$``!X```#E\0``&@````3R
M```3````'_(``!4````S\@``$0```$GR```7````6_(``!0```!S\@``%P``
M`(CR```5````H/(```D```"V\@``$````,#R```9````T?(```0```#K\@``
M!P```/#R```+````^/(``!$````$\P``!@```!;S```&````'?,```8````D
M\P``!0```"OS```'````,?,```<````Y\P``!0```$'S```6````1_,```8`
M``!>\P``!@```&7S```$````;/,```0```!Q\P``!P```';S```.````?O,`
M``P```"-\P``#````)KS```-````I_,```H```"U\P``#@```,#S```%````
MS_,``"@```#5\P``#@```/[S```,````#?0```\````:]```"@```"KT```(
M````-?0```D````^]```*P```$CT```$````=/0```@```!Y]```)@```(+T
M```2````J?0```\```"\]```!@```,ST```*````T_0```<```#>]```"```
M`.;T```@````[_0```D````0]0``#0```!KU```4````*/4```P````]]0``
M#0```$KU```.````6/4``!8```!G]0``$0```'[U```&````D/4```,```"7
M]0``!@```)OU```9````HO4```<```"\]0``!````,3U```+````R?4```L`
M``#5]0``!P```.'U```%````Z?4```<```#O]0``%@```/?U```-````#O8`
M``T````<]@``"@```"KV```0````-?8```\```!&]@``$0```%;V```7````
M:/8```H```"`]@``$0```(OV```(````G?8```0```"F]@``#P```*OV```Z
M````N_8```4```#V]@``#````/SV```>````"?<```X````H]P``$````#?W
M```+````2/<```P```!4]P``"0```&'W```'````:_<```H```!S]P``"0``
M`'[W```.````B/<``!````"7]P``&P```*CW```8````Q/<``!H```#=]P``
M"@```/CW```)`````_@```H````-^```#````!CX```/````)?@```@````U
M^```!@```#[X```<````1?@```<```!B^```!0```&KX```+````</@``$<`
M``!\^```#0```,3X```)````TO@```0```#<^````P```.'X```3````Y?@`
M`!,```#Y^```$P````WY```*````(?D```(````L^0``!````"_Y```E````
M-/D```,```!:^0``!0```%[Y```J````9/D```H```"/^0``!0```)KY```$
M````H/D```H```"E^0``#0```+#Y```&````OOD```@```#%^0``"````,[Y
M```$````U_D```4```#<^0``:````.+Y```)````2_H```P```!5^@``$```
M`&+Z```%````<_H```8```!Y^@``&P```(#Z```O````G/H``!````#,^@``
M"@```-WZ```/````Z/H```H```#X^@``"0````/[```3````#?L``!L````A
M^P``&````#W[```7````5OL``!<```!N^P``'P```(;[```.````IOL```,`
M``"U^P``!P```+G[```(````P?L```<```#*^P``"0```-+[```*````W/L`
M``L```#G^P``!P```//[``!1````^_L``!````!-_```#````%[\```-````
M:_P``!H```!Y_```2@```)3\```9````W_P```8```#Y_```&@````#]```E
M````&_T```8```!!_0``!@```$C]```?````3_T```8```!O_0``"0```';]
M```8````@/T``!<```"9_0``*````+']```&````VOT```T```#A_0``(@``
M`._]``!7````$OX``!,```!J_@``(P```'[^```3````HOX```(```"V_@``
M"P```+G^```(````Q?X```T```#._@``"@```-S^```,````Y_X```<```#T
M_@``%````/S^```&````$?\```@````8_P``#@```"'_```'````,/\```H`
M```X_P``"P```$/_```R````3_\```<```""_P``#````(K_```-````E_\`
M`!<```"E_P``#````+W_```)````RO\```D```#4_P``"@```-[_```'````
MZ?\```D```#Q_P``!P```/O_```*`````P`!`!L````.``$`#P```"H``0`2
M````.@`!``H```!-``$`%@```%@``0`(````;P`!``D```!X``$`$````((`
M`0`'````DP`!`!(```";``$`!````*X``0`'````LP`!``4```"[``$`!0``
M`,$``0`+````QP`!`!0```#3``$`$0```.@``0`:````^@`!`!8````5`0$`
M%````"P!`0`7````00$!`!@```!9`0$`'````'(!`0`9````CP$!``<```"I
M`0$`!0```+$!`0`-````MP$!``P```#%`0$`"````-(!`0`(````VP$!`!<`
M``#D`0$`"P```/P!`0`,````"`(!`!\````5`@$`&@```#4"`0`3````4`(!
M``0```!D`@$`"@```&D"`0`$````=`(!``T```!Y`@$`#````(<"`0`%````
ME`(!``D```":`@$`!0```*0"`0`'````J@(!``4```"R`@$`!````+@"`0`"
M````O0(!`#@```#``@$`+````/D"`0`2````)@,!`"D````Y`P$`,@```&,#
M`0`*````E@,!`"P```"A`P$`+@```,X#`0`S````_0,!`#,````Q!`$`.```
M`&4$`0`/````G@0!`!@```"N!`$`$````,<$`0`<````V`0!``\```#U!`$`
M$P````4%`0`5````&04!`!0````O!0$`$@```$0%`0`D````5P4!``@```!\
M!0$`)````(4%`0`3````J@4!`!0```"^!0$`%0```-,%`0`M````Z04!`"T`
M```7!@$`,0```$4&`0`N````=P8!`"\```"F!@$`+````-8&`0!B`````P<!
M`!,```!F!P$`#0```'H'`0`(````B`<!`!<```"1!P$`"````*D'`0`,````
ML@<!`"L```"_!P$`(0```.L'`0`:````#0@!``D````H"`$`10```#((`0!!
M````>`@!``4```"Z"`$`!````,`(`0`3````Q0@!`!0```#9"`$`#@```.X(
M`0`3````_0@!`!@````1"0$`!@```"H)`0`)````,0D!``H````["0$`#P``
M`$8)`0`0````5@D!``<```!G"0$`#@```&\)`0`-````?@D!``P```","0$`
M"@```)D)`0`)````I`D!``H```"N"0$`#P```+D)`0`(````R0D!``\```#2
M"0$`"````.()`0`:````ZPD!``4````&"@$`#0````P*`0`;````&@H!``@`
M```V"@$`!@```#\*`0`4````1@H!`!$```!;"@$`#@```&T*`0`X````?`H!
M``(```"U"@$`!@```+@*`0`.````OPH!``4```#."@$`!P```-0*`0`.````
MW`H!``8```#K"@$`*````/(*`0`,````&PL!`!P````H"P$`!````$4+`0`I
M````2@L!`!<```!T"P$`'P```(P+`0!<````K`L!`!0````)#`$`/@```!X,
M`0`?````70P!`!````!]#`$`!P```(X,`0`.````E@P!``P```"E#`$`#```
M`+(,`0`3````OPP!``H```#3#`$`'0```-X,`0`9````_`P!``4````6#0$`
M$0```!P-`0`1````+@T!`"0```!`#0$`$@```&4-`0`5````>`T!`!(```".
M#0$`#@```*$-`0`9````L`T!``@```#*#0$`"0```-,-`0`-````W0T!``<`
M``#K#0$`"@```/,-`0`'````_@T!``\````&#@$`!@```!8.`0`+````'0X!
M`!H````I#@$`"@```$0.`0`'````3PX!``@```!7#@$`!0```&`.`0`?````
M9@X!``8```"&#@$`$````(T.`0`(````G@X!``T```"G#@$`"````+4.`0`>
M````O@X!`!(```#=#@$`+````/`.`0`:````'0\!``D````X#P$`"@```$(/
M`0`5````30\!``4```!C#P$`%````&D/`0`$````?@\!`!````"##P$`!@``
M`)0/`0`'````FP\!`!X```"C#P$`*````,(/`0`*````ZP\!`!P```#V#P$`
M$0```!,0`0`+````)1`!`!H````Q$`$`%````$P0`0`$````81`!``0```!F
M$`$`"P```&L0`0`%````=Q`!``8```!]$`$`"````(00`0`&````C1`!``H`
M``"4$`$`&P```)\0`0`T````NQ`!`#0```#P$`$`(````"41`0`I````1A$!
M`"````!P$0$`00```)$1`0`:````TQ$!`"@```#N$0$`*0```!<2`0!0````
M01(!`"(```"2$@$`!@```+42`0`(````O!(!``4```#%$@$`"````,L2`0`9
M````U!(!`!D```#N$@$`*@````@3`0`C````,Q,!`!D```!7$P$`+@```'$3
M`0`T````H!,!``@```#5$P$`%P```-X3`0`*````]A,!``<````!%`$`(0``
M``D4`0`0````*Q0!``X````\%`$`"P```$L4`0`'````5Q0!`!,```!?%`$`
M"````',4`0`+````?!0!``H```"(%`$`%````),4`0`/````J!0!`#(```"X
M%`$`"P```.L4`0`.````]Q0!``4````&%0$`!0````P5`0`%````$A4!`!<`
M```8%0$`#P```#`5`0`$````0!4!``H```!%%0$`"0```%`5`0`+````6A4!
M``T```!F%0$`#````'05`0`.````@14!``4```"0%0$`!````)85`0`-````
MFQ4!`#(```"I%0$`&````-P5`0!%````]14!`!<````[%@$`!P```%,6`0`>
M````6Q8!``P```!Z%@$`%````(<6`0`%````G!8!`!0```"B%@$`!@```+<6
M`0`'````OA8!``X```#&%@$`*@```-46`0`&`````!<!``P````'%P$`#P``
M`!07`0`-````)!<!`!$````R%P$`"P```$07`0`V````4!<!``H```"'%P$`
M(@```)(7`0`+````M1<!``\```#!%P$`,@```-$7`0`E````!!@!`#`````J
M&`$`,0```%L8`0`M````C1@!``X```"[&`$`!0```,H8`0`.````T!@!`!,`
M``#?&`$`$@```/,8`0`'````!AD!`!$````.&0$`$P```"`9`0`'````-!D!
M`!0````\&0$`&````%$9`0`'````:AD!``4```!R&0$`#````'@9`0`,````
MA1D!`!(```"2&0$`!````*49`0`'````JAD!``H```"R&0$`"P```+T9`0`,
M````R1D!``X```#6&0$`#@```.49`0`%````]!D!``4```#Z&0$`+@`````:
M`0`F````+QH!`",```!6&@$``P```'H:`0`2````?AH!``8```"1&@$`'@``
M`)@:`0`8````MQH!`"4```#0&@$`#0```/8:`0`)````!!L!`!\````.&P$`
M`P```"X;`0`'````,AL!``H````Z&P$``@```$4;`0`,````2!L!`!4```!5
M&P$`"P```&L;`0`9````=QL!`"````"1&P$`$@```+(;`0`%````Q1L!``H`
M``#+&P$`%0```-8;`0`2````[!L!``P```#_&P$`!`````P<`0`)````$1P!
M``<````;'`$`#````",<`0!2````,!P!`!<```"#'`$`)````)L<`0`2````
MP!P!``<```#3'`$`!@```-L<`0`.````XAP!``X```#Q'`$`#``````=`0`,
M````#1T!``P````:'0$`#0```"<=`0`5````-1T!`!(```!+'0$`$````%X=
M`0`/````;QT!`!0```!_'0$`"@```)0=`0`;````GQT!`!````"['0$`"P``
M`,P=`0`;````V!T!`&D```#T'0$`&@```%X>`0`7````>1X!`!D```"1'@$`
M&@```*L>`0`E````QAX!`"<```#L'@$`&@```!0?`0`7````+Q\!`!L```!'
M'P$`&0```&,?`0`?````?1\!`!0```"='P$`$P```+(?`0`(````QA\!``<`
M``#/'P$`"````-<?`0`)````X!\!`!4```#J'P$`#0`````@`0`C````#B`!
M``T````R(`$`$P```$`@`0`(````5"`!``,```!=(`$`1@```&$@`0`_````
MJ"`!`#<```#H(`$`5P```"`A`0`%````>"$!`!\```!^(0$`+P```)XA`0`*
M````SB$!``@```#9(0$`#0```.(A`0`M````\"$!``0````>(@$`%````",B
M`0!/````."(!`"4```"((@$`$@```*XB`0`@````P2(!`!P```#B(@$`"P``
M`/\B`0`?````"R,!`!T````K(P$`)0```$DC`0`@````;R,!`"0```"0(P$`
M(````+4C`0`+````UB,!``<```#B(P$`#0```.HC`0`,````^",!`!<````%
M)`$`!@```!TD`0`Y````)"0!``P```!>)`$`!P```&LD`0`)````<R0!`!,`
M``!])`$`"0```)$D`0`$````FR0!`!````"@)`$`"````+$D`0`(````NB0!
M``0```##)`$`"P```,@D`0`,````U"0!`!(```#A)`$`$0```/0D`0`,````
M!B4!`!H````3)0$`#P```"XE`0`'````/B4!``T```!&)0$`$````%0E`0`1
M````924!`!0```!W)0$`#@```(PE`0`,````FR4!`!L```"H)0$`+````,0E
M`0`3````\24!`!P````%)@$`*````"(F`0`&````2R8!``<```!2)@$`$P``
M`%HF`0`%````;B8!``0```!T)@$`%P```'DF`0`*````D28!``P```"<)@$`
M"0```*DF`0`&````LR8!``D```"Z)@$`"````,0F`0`)````S28!``H```#7
M)@$`$0```.(F`0`&````]"8!``X```#[)@$`#@````HG`0`-````&2<!``L`
M```G)P$`'0```#,G`0`+````42<!``(```!=)P$`'````&`G`0`'````?2<!
M``8```"%)P$`9````(PG`0`)````\2<!``<```#[)P$`)@````,H`0`X````
M*B@!`!H```!C*`$`*@```'XH`0`[````J2@!`!@```#E*`$`*````/XH`0`T
M````)RD!`!D```!<*0$`%0```'8I`0`%````C"D!``<```"2*0$`"````)HI
M`0`'````HRD!``4```"K*0$`!P```+$I`0`.````N2D!``D```#(*0$`!@``
M`-(I`0`(````V2D!``L```#B*0$`!P```.XI`0`(````]BD!``<```#_*0$`
M%@````<J`0`)````'BH!``8````H*@$`"P```"\J`0`0````.RH!``8```!,
M*@$`'````%,J`0`4````<"H!``<```"%*@$`$0```(TJ`0`(````GRH!``X`
M``"H*@$`"````+<J`0`0````P"H!``D```#1*@$`$````-LJ`0`&````["H!
M`!D```#S*@$`"@````TK`0`<````&"L!``<````U*P$`!0```#TK`0`0````
M0RL!`!0```!4*P$`"P```&DK`0`-````=2L!`"@```"#*P$`&````*PK`0`7
M````Q2L!``0```#=*P$`"0```.(K`0`*````["L!``<```#W*P$``@```/\K
M`0`.`````BP!``@````1+`$`(P```!HL`0`?````/BP!`#@```!>+`$`)@``
M`)<L`0`Q````OBP!`"<```#P+`$`9````!@M`0`4````?2T!`%4```"2+0$`
M.````.@M`0!*````(2X!`%L```!L+@$`*````,@N`0`X````\2X!`"@````J
M+P$`+````%,O`0`F````@"\!`!L```"G+P$`/@```,,O`0"I`0```C`!`",`
M``"L,0$`%P```-`Q`0!(````Z#$!`(4````Q,@$`,````+<R`0`5````Z#(!
M`"@```#^,@$`(@```"<S`0`B````2C,!`"````!M,P$`)0```(XS`0!!````
MM#,!`%L```#V,P$`20```%(T`0`Q````G#0!`!T```#.-`$`&````.PT`0`K
M````!34!`"$````Q-0$`'P```%,U`0`K````<S4!`"8```"?-0$`)P```,8U
M`0`Z````[C4!`!T````I-@$`$0```$<V`0`S````638!`"4```"--@$`)P``
M`+,V`0`@````VS8!`!\```#\-@$`,````!PW`0!I````33<!`#$```"W-P$`
M00```.DW`0`S````*S@!`"4```!?.`$`/0```(4X`0!E````PS@!`$T````I
M.0$`+P```'<Y`0`N````ISD!`"D```#6.0$`,``````Z`0`L````,3H!`%0`
M``!>.@$`6@```+,Z`0`H````#CL!`"8````W.P$`2````%X[`0!*````ISL!
M`"L```#R.P$`'@```!X\`0`R````/3P!`"\```!P/`$`+````*`\`0`M````
MS3P!`'$```#[/`$`9@```&T]`0!O````U#T!`+,```!$/@$`%P```/@^`0`E
M````$#\!`#(````V/P$`*0```&D_`0`^````DS\!`"(```#2/P$`4@```/4_
M`0`B````2$`!`"4```!K0`$`"P```)%``0"Q````G4`!`$4```!/00$`(0``
M`)5!`0`P````MT$!`"4```#H00$`'`````Y"`0`Q````*T(!``<```!=0@$`
M!P```&5"`0`$````;4(!``T```!R0@$`"P```(!"`0`.````C$(!``L```";
M0@$`!0```*="`0`0````K4(!``(```"^0@$`60```,%"`0`%````&T,!`!(`
M```A0P$`!````#1#`0`'````.4,!``@```!!0P$`!0```$I#`0`P````4$,!
M``,```"!0P$`$````(5#`0`,````ED,!`!,```"C0P$`#0```+=#`0`"````
MQ4,!``<```#(0P$`!@```-!#`0`4````UT,!``P```#L0P$`&````/E#`0`&
M````$D0!`!(````91`$`#````"Q$`0`#````.40!`"H````]1`$`!````&A$
M`0`&````;40!``<```!T1`$`'P```'Q$`0`U````G$0!`"X```#21`$`+P``
M``%%`0`7````,44!`"(```!)10$`)0```&Q%`0`@````DD4!`!L```"S10$`
M&````,]%`0`D````Z$4!`!\````-1@$`&@```"U&`0`A````2$8!`"````!J
M1@$`&@```(M&`0`R````ID8!`!D```#91@$`&@```/-&`0`O````#D<!`"L`
M```^1P$`'P```&I'`0`C````BD<!`!\```"N1P$`&@```,Y'`0`A````Z4<!
M`"4````+2`$`)@```#%(`0`E````6$@!`"0```!^2`$`&````*-(`0`=````
MO$@!`"0```#:2`$`&````/](`0`B````&$D!`"P````[20$`+P```&A)`0`5
M````F$D!`"4```"N20$`/````-1)`0`?````$4H!`",````Q2@$`'P```%5*
M`0`@````=4H!`!H```"62@$`&````+%*`0`F````RDH!`!X```#Q2@$`*0``
M`!!+`0`>````.DL!`#$```!92P$`"0```(M+`0`,````E4L!``P```"B2P$`
M%P```*]+`0`O````QTL!`"0```#W2P$`!P```!Q,`0`/````)$P!`!0````T
M3`$`#@```$E,`0`-````6$P!`"0```!F3`$`!0```(M,`0`'````D4P!`"(`
M``"93`$`)0```+Q,`0`:````XDP!`!T```#]3`$`&@```!M-`0`'````-DT!
M`,<````^30$`"P````9.`0`<````$DX!`!4````O3@$`!@```$5.`0`)````
M3$X!``L```!63@$`#0```&).`0`7````<$X!``8```"(3@$`,P```(].`0`3
M````PTX!`!,```#73@$`!P```.M.`0`/````\TX!``<````#3P$`,@````M/
M`0`$````/D\!`"$```!#3P$`$P```&5/`0`,````>4\!`!$```"&3P$`,@``
M`)A/`0`6````RT\!``@```#B3P$`'0```.M/`0`)````"5`!``H````34`$`
M%````!Y0`0`*````,U`!`!T````^4`$`"````%Q0`0`?````95`!``@```"%
M4`$`&@```(Y0`0`G````J5`!``8```#14`$`%0```-A0`0`'````[E`!``@`
M``#V4`$`"0```/]0`0`_````"5$!``<```!)40$`#P```%%1`0`.````85$!
M`!````!P40$`"0```(%1`0`)````BU$!``@```"540$`$P```)Y1`0`'````
MLE$!`!D```"Z40$`"@```-11`0`7````WU$!`!0```#W40$`"@````Q2`0`,
M````%U(!`!<````D4@$`!````#Q2`0`J````05(!``P```!L4@$`$0```'E2
M`0`'````BU(!``(```"34@$`$````)92`0`8````IU(!``L```#`4@$``P``
M`,Q2`0`(````T%(!``8```#94@$`!P```.!2`0`-````Z%(!``L```#V4@$`
M%`````)3`0`5````%U,!``X````M4P$`+P```#Q3`0`@````;%,!`!P```"-
M4P$`%0```*I3`0`K````P%,!``P```#L4P$`,0```/E3`0`%````*U0!`!(`
M```Q5`$`/P```$14`0`2````A%0!``H```"75`$`!@```*)4`0`$````J50!
M``0```"N5`$`"@```+-4`0`3````OE0!``4```#25`$`!@```-A4`0`&````
MWU0!``@```#F5`$`!````.]4`0`,````]%0!``H````!50$`.0````Q5`0`N
M````1E4!`"D```!U50$`!0```)]5`0`8````I54!`!D```"^50$`'P```-A5
M`0`=````^%4!`!$````65@$``@```"A6`0`$````*U8!``H````P5@$`!@``
M`#M6`0`%````0E8!``,```!(5@$`#````$Q6`0!%````658!`#(```"?5@$`
M,0```-)6`0`:````!%<!`#0````?5P$`*````%17`0!3````?5<!`#(```#1
M5P$`&0````18`0!R````'E@!`"````"16`$`-0```+)8`0`A````Z%@!`$4`
M```*60$`,````%!9`0`H````@5D!`"@```"J60$`*0```--9`0`F````_5D!
M`"4````D6@$`*````$I:`0`H````<UH!`"(```"<6@$`*P```+]:`0`P````
MZUH!`!(````<6P$`$P```"];`0`0````0UL!`'D```!46P$`"0```,Y;`0"A
M````V%L!`',```!Z7`$`?````.Y<`0`K````:UT!`%0```"770$`%P```.Q=
M`0`G````!%X!`!8````L7@$`%0```$->`0`/````65X!`!<```!I7@$`'P``
M`(%>`0`.````H5X!`$````"P7@$`'P```/%>`0`<````$5\!`%$````N7P$`
M&@```(!?`0`4````FU\!``H```"P7P$`!0```+M?`0`&````P5\!``@```#(
M7P$`!0```-%?`0`2````UU\!`!````#J7P$`$P```/M?`0`=````#V`!``\`
M```M8`$`#P```#U@`0`0````36`!``0```!>8`$`"0```&-@`0`)````;6`!
M``<```!W8`$`"P```']@`0`%````BV`!``L```"18`$`!P```)U@`0`%````
MI6`!`!0```"K8`$`#@```,!@`0`+````SV`!``<```#;8`$`"````.-@`0`/
M````[&`!``P```#\8`$`"0````EA`0`(````$V$!``P````<80$`!@```"EA
M`0`/````,&$!``<```!`80$`!@```$AA`0`4````3V$!``8```!D80$`#```
M`&MA`0`1````>&$!``@```"*80$`!````)-A`0`9````F&$!`!$```"R80$`
M"@```,1A`0`8````SV$!`!,```#H80$`'````/QA`0`1````&6(!``0````K
M8@$`#P```#!B`0`'````0&(!``0```!(8@$`&0```$UB`0`'````9V(!``(`
M``!O8@$``@```')B`0`1````=6(!``D```"'8@$`!@```)%B`0`2````F&(!
M`!<```"K8@$`!@```,-B`0`G````RF(!``(```#R8@$`!````/5B`0`/````
M^F(!`!,````*8P$`!P```!YC`0`)````)F,!``<````P8P$`$0```#AC`0`&
M````2F,!`!@```!18P$`!@```&IC`0`3````<6,!`!````"%8P$`$@```)9C
M`0`"````J6,!``8```"L8P$`#````+-C`0`)````P&,!`!$```#*8P$`(@``
M`-QC`0`'````_V,!``<````'9`$`"P````]D`0`%````&V0!``4````A9`$`
M`@```"=D`0`+````*F0!`%$!```V9`$`#P```(AE`0`3````F&4!``X```"L
M90$`"````+ME`0`)````Q&4!``H```#.90$`!0```-EE`0`:````WV4!`!\`
M``#Z90$`,@```!IF`0`P````368!`"D```!^9@$`*````*AF`0`>````T68!
M`#,```#P9@$`#````"1G`0`G````,6<!``H```!99P$`$@```&1G`0`,````
M=V<!`!````"$9P$`!0```)5G`0`A````FV<!`!````"]9P$`$````,YG`0`6
M````WV<!`!4```#V9P$`#`````QH`0`*````&6@!`"D````D:`$`A0```$YH
M`0`0````U&@!``H```#E:`$`$@```/!H`0`0`````VD!``X````4:0$`#```
M`"-I`0`.````,&D!`!$````_:0$`!@```%%I`0#!````6&D!``<````::@$`
M"P```")J`0`:````+FH!``\```!):@$`!P```%EJ`0`1````86H!`!$```!S
M:@$`"@```(5J`0`'````D&H!`"P```"8:@$`)````,5J`0!5````ZFH!`&$`
M``!`:P$`>0```*)K`0!X````'&P!`'P```"5;`$`>P```!)M`0!8````CFT!
M`!$```#G;0$`&0```/EM`0`0````$VX!`!(````D;@$`&````#=N`0`%````
M4&X!``8```!6;@$`$@```%UN`0`'````<&X!``T```!X;@$`#0```(9N`0`W
M````E&X!`"X```#,;@$`*@```/MN`0`N````)F\!`$(```!5;P$`+P```)AO
M`0`2````R&\!``T```#;;P$`$@```.EO`0`+````_&\!``H````(<`$`&P``
M`!-P`0`;````+W`!`!````!+<`$`%@```%QP`0`6````<W`!`!X```"*<`$`
M'@```*EP`0`E````R'`!`!0```#N<`$`$0````-Q`0`:````%7$!``\````P
M<0$`*@```$!Q`0`:````:W$!`!\```"&<0$`$P```*9Q`0!Z````NG$!`$(`
M```U<@$`&@```'AR`0`O````DW(!``<```##<@$`"@```,MR`0`P````UG(!
M``X````'<P$`!P```!9S`0`+````'G,!``@````J<P$`"````#-S`0`)````
M/',!``L```!&<P$`#````%)S`0`$````7W,!`!0```!D<P$`#````'ES`0`+
M````AG,!`!````"2<P$`&0```*-S`0`F````O7,!`!$```#D<P$`&@```/9S
M`0`:````$70!`!X````L=`$`&````$MT`0`4````9'0!`!(```!Y=`$`$@``
M`(QT`0`G````GW0!`"<```#'=`$`!P```.]T`0`&````]W0!``@```#^=`$`
M#@````=U`0`'````%G4!``D````>=0$`$P```"AU`0`)````/'4!``\```!&
M=0$`%0```%9U`0`8````;'4!``H```"%=0$`#P```)!U`0`%````H'4!`!<`
M``"F=0$`"P```+YU`0`*````RG4!`$L```#5=0$`10```"%V`0`+````9W8!
M``@```!S=@$`%0```'QV`0`%````DG8!``4```"8=@$`"P```)YV`0`0````
MJG8!``L```"[=@$`%P```,=V`0`N````WW8!`!`````.=P$`/0```!]W`0`\
M````77<!`#\```":=P$`/P```-IW`0`)````&G@!``8````D>`$`"@```"MX
M`0`*````-G@!`$$```!!>`$`/0```(-X`0!`````P7@!`'$````">0$`/P``
M`'1Y`0!#````M'D!`%,```#X>0$`4````$QZ`0`_````G7H!`%$```#=>@$`
M,P```"][`0`W````8WL!`%<```";>P$`/P```/-[`0!#````,WP!`"H```!W
M?`$`(````*)\`0`<````PWP!`#T```#@?`$`*0```!Y]`0`I````2'T!`!8`
M``!R?0$`$@```(E]`0`-````G'T!``T```"J?0$`%0```+A]`0`?````SGT!
M``L```#N?0$`$````/I]`0`;````"WX!`!\````G?@$`!P```$=^`0`'````
M3WX!`!8```!7?@$`"P```&Y^`0`(````>GX!`"T```"#?@$`"@```+%^`0`*
M````O'X!``<```#'?@$`!@```,]^`0`%````UGX!``@```#<?@$`!@```.5^
M`0`*````['X!`"T```#W?@$`$@```"5_`0`(````.'\!``0```!!?P$`"```
M`$9_`0`+````3W\!``0```!;?P$`#````&!_`0`&````;7\!`!,```!T?P$`
M!@```(A_`0`(````CW\!``4```"8?P$`"P```)Y_`0`)````JG\!`"D```"T
M?P$`$0```-Y_`0`)````\'\!`!,```#Z?P$`#`````Z``0`'````&X`!``,`
M```C@`$``P```">``0`7````*X`!``,```!#@`$`%P```$>``0`W````7X`!
M``@```"7@`$`"0```*"``0`*````JH`!``<```"U@`$`8P```+V``0`L````
M(8$!`#H```!.@0$`/````(F!`0`J````QH$!``8```#Q@0$`"0```/B!`0`8
M`````H(!`"P````;@@$`)0```$B"`0`V````;H(!`#(```"E@@$`,P```-B"
M`0"1````#(,!`$@```">@P$`"0```.>#`0`+````\8,!``@```#]@P$`'0``
M``:$`0`)````)(0!``T````NA`$`#````#R$`0`3````280!``T```!=A`$`
M$P```&N$`0`.````?X0!``P```".A`$`%@```)N$`0`)````LH0!`!P```"\
MA`$`'0```-F$`0`1````]X0!`!(````)A0$`%0```!R%`0`&````,H4!``8`
M```YA0$`%P```$"%`0"$````6(4!`$(```#=A0$`>P```""&`0`'````G(8!
M`!,```"DA@$`!0```+B&`0`%````OH8!`!\```#$A@$`'@```.2&`0`4````
M`X<!`!<````8AP$`'@```#"'`0`T````3X<!`"\```"$AP$`3````+2'`0`I
M`````8@!``\````KB`$`*````#N(`0`&````9(@!`!4```!KB`$`&````(&(
M`0`4````FH@!`!D```"OB`$`%0```,F(`0`5````WX@!`!$```#UB`$`"@``
M``>)`0`3````$HD!`!$````FB0$`!@```#B)`0`+````/XD!``<```!+B0$`
M"P```%.)`0`.````7XD!`!<```!NB0$`"0```(:)`0`%````D(D!``L```"6
MB0$`"````**)`0`(````JXD!`!0```"TB0$`!@```,F)`0`&````T(D!``P`
M``#7B0$`"0```.2)`0`0````[HD!``<```#_B0$`!0````>*`0`(````#8H!
M``L````6B@$`"P```"**`0`:````+HH!`$0```!)B@$`*P```(Z*`0`0````
MNHH!`!,```#+B@$`!0```-^*`0`<````Y8H!`!H````"BP$`&P```!V+`0`]
M````.8L!`$P```!WBP$`*````,2+`0`(````[8L!`#T```#VBP$`)````#2,
M`0`/````68P!``8```!IC`$`"P```'",`0`&````?(P!``@```"#C`$`&P``
M`(R,`0`0````J(P!``D```"YC`$`"@```,.,`0`.````SHP!`#D```#=C`$`
M.0```!>-`0`[````48T!`#L```"-C0$`*P```,F-`0`J````]8T!`"P````@
MC@$`*@```$V.`0!"````>(X!`"\```"[C@$`+@```.N.`0`P````&H\!`"@`
M``!+CP$`+P```'2/`0`\````I(\!`#X```#ACP$`-````""0`0`Q````59`!
M`#D```"'D`$`+P```,&0`0`R````\9`!`$8````DD0$`,````&N1`0`?````
MG)$!`#H```"\D0$`+@```/>1`0`[````)I(!`!\```!BD@$`W````(*2`0`?
M````7Y,!`"X```!_DP$`,0```*Z3`0`R````X),!`#4````3E`$`,````$F4
M`0`N````>I0!`#$```"IE`$`.0```-N4`0`\````%94!`$0```!2E0$`/```
M`)>5`0#%````U)4!`"\```":E@$`(@```,J6`0`O````[98!`#,````=EP$`
M/@```%&7`0!D````D)<!`%T```#UEP$`#@```%.8`0`$````8I@!``4```!G
MF`$`"0```&V8`0`.````=Y@!`!8```"&F`$`%0```)V8`0`(````LY@!``\`
M``"\F`$`$@```,R8`0`(````WY@!``0```#HF`$`$0```.V8`0`1````_Y@!
M``T````1F0$`$````!^9`0`1````,)D!`!````!"F0$`&````%.9`0`.````
M;)D!`%$```![F0$`#````,V9`0`4````VID!``8```#OF0$`$P```/:9`0`9
M````"IH!`!X````DF@$`%0```$.:`0`"````69H!`$L```!<F@$`!P```*B:
M`0`0````L)H!`!````#!F@$`!0```-*:`0`-````V)H!``T```#FF@$``P``
M`/2:`0`/````^)H!``@````(FP$`!@```!&;`0`1````&)L!``@````JFP$`
M#0```#.;`0`1````09L!`!,```!3FP$`#0```&>;`0`3````=9L!`!````")
MFP$`#````)J;`0`'````IYL!``T```"OFP$`$````+V;`0`.````SIL!``L`
M``#=FP$`#@```.F;`0`A````^)L!`!<````:G`$`#0```#*<`0`.````0)P!
M`"8```!/G`$`$P```':<`0`7````BIP!`"T```"BG`$`#0```-"<`0`=````
MWIP!`!,```#\G`$`&P```!"=`0`:````+)T!`!,```!'G0$`+@```%N=`0`1
M````BIT!``@```"<G0$`"@```*6=`0`;````L)T!``P```#,G0$`#0```-F=
M`0`B````YYT!`#`````*G@$`"P```#N>`0`(````1YX!`!T```!0G@$`"@``
M`&Z>`0`5````>9X!`!4```"/G@$`"P```*6>`0`C````L9X!`!4```#5G@$`
M'P```.N>`0`9````"Y\!``T````EGP$`$P```#.?`0`)````1Y\!``T```!1
MGP$`+P```%^?`0`Q````CY\!`%$```#!GP$`"````!.@`0`7````'*`!`"(`
M```TH`$`#0```%>@`0`0````9:`!`#0```!VH`$`#````*N@`0`&````N*`!
M``4```"_H`$`2P```,6@`0`&````$:$!``<````8H0$`"@```""A`0`/````
M*Z$!`!`````[H0$`$0```$RA`0`0````7J$!`!$```!OH0$`$0```(&A`0`:
M````DZ$!`"````"NH0$`'0```,^A`0`:````[:$!`!@````(H@$`!P```"&B
M`0`'````*:(!``L````QH@$`"@```#VB`0`"````2*(!``4```!+H@$`#```
M`%&B`0`E````7J(!`!4```"$H@$`%@```)JB`0`'````L:(!``L```"YH@$`
M$````,6B`0`0````UJ(!`!0```#GH@$`.P```/RB`0`G````.*,!``<```!@
MHP$`$0```&BC`0"7````>J,!`!D````2I`$`(P```"RD`0`1````4*0!``<`
M``!BI`$`!@```&JD`0`F````<:0!`#(```"8I`$`,````,ND`0`D````_*0!
M`"0````AI0$`'0```$:E`0`?````9*4!``<```"$I0$`"0```(RE`0`)````
MEJ4!``8```"@I0$`#P```*>E`0`.````MZ4!`!````#&I0$`#@```->E`0`3
M````YJ4!`!$```#ZI0$`$`````RF`0`.````':8!``D````LI@$`"@```#:F
M`0`.````0:8!``P```!0I@$`/0```%VF`0`-````FZ8!``@```"II@$`"P``
M`+*F`0`3````OJ8!`!````#2I@$`(P```..F`0`)````!Z<!`#,````1IP$`
M)P```$6G`0`F````;:<!`"\```"4IP$`*0```,2G`0`V````[J<!`"P````E
MJ`$`%0```%*H`0`&````:*@!``X```!OJ`$`!@```'ZH`0`0````A:@!``,`
M``"6J`$`!````)JH`0`'````GZ@!`!,```"GJ`$`%0```+NH`0`3````T:@!
M`!D```#EJ`$`"@```/^H`0`.````"JD!``L````9J0$`!P```"6I`0`%````
M+:D!`!`````SJ0$`$@```$2I`0`,````5ZD!``D```!DJ0$`#````&ZI`0`/
M````>ZD!`#$```"+J0$`!@```+VI`0`(````Q*D!``P```#-J0$`#@```-JI
M`0`7````Z:D!``@````!J@$`"`````JJ`0`%````$ZH!`"(````9J@$`#```
M`#RJ`0`%````2:H!`"H```!/J@$`$````'JJ`0!Q````BZH!`!,```#]J@$`
M"0```!&K`0`*````&ZL!``T````FJP$`"P```#2K`0`-````0*L!``4```!.
MJP$`#0```%2K`0`"````8JL!``8```!EJP$`"@```&RK`0`7````=ZL!`!,`
M``"/JP$`%@```*.K`0`Q````NJL!``,```#LJP$`!````/"K`0`9````]:L!
M``@````/K`$`$@```!BL`0`%````*ZP!`!D````QK`$`"````$NL`0`&````
M5*P!`!@```!;K`$`&0```'2L`0`.````CJP!``@```"=K`$`"P```*:L`0`%
M````LJP!``D```"XK`$`!P```,*L`0`8````RJP!``,```#CK`$`!@```.>L
M`0`+````[JP!``P```#ZK`$`"@````>M`0`,````$JT!`!<````?K0$`"```
M`#>M`0`'````0*T!`!$```!(K0$`(P```%JM`0!0````?JT!`#8```#/K0$`
M.@````:N`0`'````0:X!``H```!)K@$`!````%2N`0`)````6:X!``@```!C
MK@$`"@```&RN`0`)````=ZX!``8```"!K@$`#0```(BN`0`&````EJX!``0`
M``"=K@$`.P```**N`0`^````WJX!`#T````=KP$`)@```%NO`0`%````@J\!
M`!````"(KP$`!@```)FO`0`+````H*\!``P```"LKP$`&0```+FO`0`0````
MTZ\!`!@```#DKP$`!````/VO`0`%`````K`!``L````(L`$`!0```!2P`0`*
M````&K`!`!X````EL`$`!````$2P`0`+````2;`!``P```!5L`$`"@```&*P
M`0`.````;;`!``\```!\L`$`#@```(RP`0`(````F[`!``D```"DL`$`!0``
M`*ZP`0`S````M+`!`#,```#HL`$`/````!RQ`0`O````6;$!`$X```")L0$`
M2````-BQ`0`U````(;(!`%8```!7L@$`.P```*ZR`0!,````ZK(!`#`````W
MLP$`$0```&BS`0`9````>K,!``L```"4LP$`0P```*"S`0`O````Y+,!`"(`
M```4M`$`+@```#>T`0`0````9K0!`!(```!WM`$`!P```(JT`0`&````DK0!
M`#$```"9M`$`,0```,NT`0`X````_;0!``H````VM0$`&P```$&U`0`I````
M7;4!`!\```"'M0$`$P```*>U`0`&````N[4!``H```#"M0$`#````,VU`0`/
M````VK4!`!D```#JM0$`7P````2V`0!]````9+8!`'H```#BM@$`#0```%VW
M`0`(````:[<!``D```!TMP$`$````'ZW`0`1````C[<!``X```"AMP$`!@``
M`+"W`0`?````M[<!`!<```#7MP$`%0```.^W`0`5````!;@!`!,````;N`$`
M%````"^X`0`;````1+@!`"H```!@N`$`E0```(NX`0`1````(;D!``8````S
MN0$`$0```#JY`0`*````3+D!``L```!7N0$`#0```&.Y`0`C````<;D!`!8`
M``"5N0$`#P```*RY`0`0````O+D!``T```#-N0$`%P```-NY`0`L````\[D!
M`"L````@N@$`*P```$RZ`0`J````>+H!`#8```"CN@$`-0```-JZ`0`<````
M$+L!`$\````MNP$`%0```'V[`0`4````D[L!`!8```"HNP$`%0```+^[`0`6
M````U;L!`!8```#LNP$`%0````.\`0`5````&;P!`!0````OO`$`,P```$2\
M`0`8````>+P!`!@```"1O`$`.P```*J\`0`2````YKP!``@```#YO`$`%```
M``*]`0`C````%[T!`!0````[O0$`%````%"]`0`3````9;T!`!D```!YO0$`
M%@```).]`0`6````JKT!`!L```#!O0$`&0```-V]`0`4````][T!`!\````,
MO@$`(@```"R^`0`5````3[X!`!4```!EO@$`%P```'N^`0`5````D[X!`!H`
M``"IO@$`'0```,2^`0`;````XKX!`!@```#^O@$`"````!>_`0`0````(+\!
M`!@````QOP$`!````$J_`0`&````3[\!``L```!6OP$`%````&*_`0`&````
M=[\!``H```!^OP$`!@```(F_`0`'````D+\!``<```"8OP$`!@```*"_`0`%
M````I[\!`!<```"MOP$`!@```,6_`0`)````S+\!``0```#6OP$`!````-N_
M`0`)````X+\!``H```#JOP$`"0```/6_`0`0````_[\!`!$````0P`$`"@``
M`"+``0`5````+<`!``4```!#P`$`-0```$G``0`/````?\`!`!(```"/P`$`
M'````*+``0`.````O\`!``P```#.P`$`#@```-O``0!)````ZL`!``8````T
MP0$`"````#O!`0`A````1,$!``X```!FP0$`$P```'7!`0`&````B<$!``L`
M``"0P0$`"0```)S!`0`'````IL$!``0```"NP0$`#0```+/!`0`/````P<$!
M`!<```#1P0$`#P```.G!`0`6````^<$!`!0````0P@$`&P```"7"`0`:````
M0<(!``@```!<P@$`!@```&7"`0`&````;,(!`!T```!SP@$`!P```)'"`0`%
M````F<(!`!$```"?P@$`"P```+'"`0`'````O<(!``4```#%P@$`!P```,O"
M`0`&````T\(!``T```#:P@$`"@```.C"`0`.````\\(!`!,````"PP$`%0``
M`!;#`0`4````+,,!`!L```!!PP$`$P```%W#`0`5````<<,!``@```"'PP$`
M!````)##`0`2````E<,!`!<```"HPP$`!0```,##`0`1````QL,!`"4```#8
MPP$`%````/[#`0`6````$\0!`!$````JQ`$`#0```#S$`0`,````2L0!``D`
M``!7Q`$`#P```&'$`0`.````<<0!`!````"`Q`$`$````)'$`0`P````HL0!
M`#````#3Q`$`+`````3%`0`)````,<4!``<````[Q0$`!P```$/%`0`0````
M2\4!`!````!<Q0$``P```&W%`0`(````<<4!`"````!ZQ0$`"````)O%`0`(
M````I,4!``\```"MQ0$`:0```+W%`0`9````)\8!``L```!!Q@$`!0```$W&
M`0`'````4\8!`!H```!;Q@$`&@```';&`0`3````D<8!``D```"EQ@$``@``
M`*_&`0`$````LL8!`"0```"WQ@$`!P```-S&`0`%````Y,8!`"\```#JQ@$`
M"@```!K'`0`%````)<<!``<````KQP$`%````#/'`0`0````2,<!``8```!9
MQP$`"````&#'`0`)````:<<!``0```!SQP$`!0```'C'`0!T````?L<!``L`
M``#SQP$`#@```/_'`0`8````#L@!``0````GR`$`#````"S(`0`F````.<@!
M`#4```!@R`$`#@```);(`0`*````I<@!`!(```"PR`$`"P```,/(`0`)````
MS\@!`!D```#9R`$`*````//(`0`I````',D!`"@```!&R0$`&@```&_)`0`@
M````BLD!``X```"KR0$``P```+K)`0`.````OLD!``<```#-R0$`"@```-7)
M`0`+````X,D!``H```#LR0$`%````/?)`0`)````#,H!`%H````6R@$`'```
M`''*`0`.````CLH!``P```"=R@$`&P```*K*`0!,````QLH!`!T````3RP$`
M!P```#'+`0`D````.<L!`#````!>RP$`"````(_+`0`&````F,L!`"(```"?
MRP$`!0```,++`0`'````R,L!`"D```#0RP$`*````/K+`0`T````(\P!``@`
M``!8S`$`#0```&',`0`>````;\P!`&(```".S`$`&````/',`0`6````"LT!
M`!4````AS0$``@```#?-`0`+````.LT!``4```!&S0$`#@```$S-`0`.````
M6\T!``T```!JS0$`!P```'C-`0`/````@,T!``8```"0S0$`"````)?-`0`.
M````H,T!``D```"OS0$`"@```+G-`0`*````Q,T!`#<```#/S0$`!P````?.
M`0`2````#\X!`!,````BS@$`'@```#;.`0`2````5<X!``H```!HS@$`"@``
M`'/.`0`+````?LX!``D```"*S@$`"@```)3.`0`)````G\X!``@```"IS@$`
M'P```++.`0`1````TLX!``\```#DS@$`"@```/3.`0`*````_\X!``T````*
MSP$`"P```!C/`0`1````),\!``4````VSP$`&0```#S/`0`$````5L\!``<`
M``!;SP$`!0```&//`0`%````:<\!``L```!OSP$`&````'O/`0`2````E,\!
M`!D```"GSP$`&P```,'/`0`B````W<\!`!8`````T`$`%P```!?0`0`2````
M+]`!`!8```!"T`$`"````%G0`0`#````8M`!``T```!FT`$`#@```'30`0`'
M````@]`!``H```"+T`$`'0```);0`0`*````M-`!``X```"_T`$`)@```,[0
M`0`K````]=`!`!8````AT0$`"P```#C1`0`+````1-$!``8```!0T0$`$```
M`%?1`0`5````:-$!``<```!^T0$`"0```(;1`0`%````D-$!``<```"6T0$`
M!@```)[1`0`$````I=$!``0```"JT0$`0````*_1`0`Z````\-$!`!0````K
MT@$`,P```$#2`0`[````=-(!`!$```"PT@$`3````,+2`0`Z````#],!`$L`
M``!*TP$`2P```);3`0!1````XM,!`!<````TU`$`&0```$S4`0`7````9M0!
M`"D```!^U`$`%0```*C4`0`=````OM0!`!,```#<U`$`&@```/#4`0`4````
M"]4!`"X````@U0$`#0```$_5`0`L````7=4!``T```"*U0$`%P```)C5`0`<
M````L-4!`#<```#-U0$`-P````76`0`[````/=8!`#@```!YU@$`.0```++6
M`0`V````[-8!`'4````CUP$`(P```)G7`0`I````O=<!``P```#GUP$`'```
M`/37`0`,````$=@!`!0````>V`$`-````#/8`0`L````:-@!`#````"5V`$`
M"P```,;8`0!<````TM@!`%8````OV0$`!@```(;9`0`%````C=D!`!D```"3
MV0$`%@```*W9`0`,````Q-D!`!0```#1V0$`$@```.;9`0`(````^=D!``H`
M```"V@$`"0````W:`0`0````%]H!`!0````HV@$`$````#W:`0`2````3MH!
M``X```!AV@$`#````'#:`0`*````?=H!``D```"(V@$`"@```)+:`0`5````
MG=H!``L```"SV@$`#P```+_:`0`+````S]H!`"4```#;V@$`!P````';`0`7
M````"=L!`"4````AVP$`"````$?;`0`$````4-L!`!(```!5VP$`$@```&C;
M`0`1````>]L!`"\```"-VP$``@```+W;`0`&````P-L!``\```#'VP$`"0``
M`-?;`0`'````X=L!`!P```#IVP$`!`````;<`0`[````"]P!``X```!'W`$`
M&````%;<`0`$````;]P!`"\```!TW`$`&0```*3<`0`?````OMP!`%X```#>
MW`$`%P```#W=`0!'````5=T!`"D```"=W0$`#0```,?=`0`-````U=T!`!0`
M``#CW0$`$0```/C=`0`,````"MX!`!8````7W@$`#````"[>`0`=````.]X!
M`!8```!9W@$`"````'#>`0`4````>=X!``X```".W@$`*@```)W>`0`2````
MR-X!`!D```#;W@$`&````/7>`0`:````#M\!`"L````IWP$`"````%7?`0`)
M````7M\!`!D```!HWP$`$0```(+?`0`3````E-\!`!(```"HWP$`&0```+O?
M`0`1````U=\!`!0```#GWP$`&P```/S?`0`*````&.`!``P````CX`$`"```
M`##@`0`%````.>`!`"$````_X`$`!@```&'@`0`/````:.`!``@```!XX`$`
M$0```('@`0`(````D^`!`!X```"<X`$`$0```+O@`0`Y````S>`!`!@````'
MX0$`"0```"#A`0`*````*N$!`"(````UX0$`"````%CA`0`?````8>$!``0`
M``"!X0$`'````(;A`0`(````H^$!``<```"LX0$`'````+3A`0`P````T>$!
M``8````"X@$`(`````GB`0`2````*N(!``8````]X@$`$````$3B`0`3````
M5>(!``0```!IX@$`"0```&[B`0`+````>.(!``<```"$X@$`!0```(SB`0`(
M````DN(!``4```";X@$`"P```*'B`0`?````K>(!`#X```#-X@$`3`````SC
M`0`G````6>,!`#8```"!XP$`)P```+CC`0!5````X.,!`"<````VY`$`-P``
M`%[D`0`W````EN0!`(L```#.Y`$`*````%KE`0`%````@^4!``<```")Y0$`
M"````)'E`0`(````FN4!`!L```"CY0$`'0```+_E`0`J````W>4!`"H````(
MY@$`)@```#/F`0!`````6N8!`$8```";Y@$`"0```.+F`0`7````[.8!``L`
M```$YP$`"````!#G`0`X````&><!`!8```!2YP$`$````&GG`0`2````>N<!
M``@```"-YP$`$P```);G`0`(````JN<!``T```"SYP$`%@```,'G`0`G````
MV.<!`"@`````Z`$`0P```"GH`0`+````;>@!`!T```!YZ`$`!0```)?H`0`'
M````G>@!`!@```"EZ`$`(P```+[H`0`,````XN@!``4```#OZ`$`"@```/7H
M`0`,`````.D!``P````-Z0$`"P```!KI`0`:````)ND!``H```!!Z0$`"@``
M`$SI`0`%````5^D!`!$```!=Z0$`20```&_I`0`=````N>D!`%T```#7Z0$`
M'@```#7J`0`,````5.H!`"8```!AZ@$`$P```(CJ`0`<````G.H!`!(```"Y
MZ@$`$P```,SJ`0`-````X.H!``L```#NZ@$`$````/KJ`0`M````"^L!``D`
M```YZP$`#0```$/K`0`3````4>L!``X```!EZP$`%@```'3K`0`,````B^L!
M`#X```"8ZP$`"````-?K`0`I````X.L!`!`````*[`$`%````!OL`0!%````
M,.P!`#,```!V[`$`-P```*KL`0`T````XNP!`#`````7[0$`$````$CM`0`,
M````6>T!`!4```!F[0$`'@```'SM`0`7````F^T!``H```"S[0$`%P```+[M
M`0`>````UNT!``<```#U[0$`&@```/WM`0`<````&.X!``8````U[@$`!@``
M`#SN`0`2````0^X!``P```!6[@$`%P```&/N`0`%````>^X!``@```"![@$`
M#@```(KN`0`1````F>X!`!(```"K[@$`$P```+[N`0`3````TNX!``<```#F
M[@$`!@```.[N`0`H````]>X!`!L````>[P$`&@```#KO`0`'````5>\!`!4`
M``!=[P$`!@```'/O`0`C````>N\!`",```">[P$`*P```,+O`0`+````[N\!
M``D```#Z[P$`(P````3P`0`#````*/`!``8````L\`$`"@```#/P`0`"````
M/O`!``P```!!\`$`%0```$[P`0`+````9/`!`!D```!P\`$`(````(KP`0`7
M````J_`!``4```##\`$`"@```,GP`0`5````U/`!`!(```#J\`$`#0```/WP
M`0`)````"_$!``X````5\0$`#````"3Q`0`7````,?$!`%@```!)\0$`'0``
M`*+Q`0`T````P/$!`!0```#U\0$`#`````KR`0`%````%_(!``T````=\@$`
M#@```"OR`0`*````.O(!``D```!%\@$`$0```$_R`0`/````8?(!`"````!Q
M\@$`&````)+R`0`4````J_(!`!````#`\@$`(@```-'R`0`.````]/(!`"8`
M```#\P$`$````"KS`0`0````._,!`!L```!,\P$`D0```&CS`0`B````^O,!
M`!P````=]`$`'````#KT`0`Q````5_0!`"T```")]`$`,0```+?T`0`@````
MZ?0!`!H````*]0$`+````"7U`0`:````4O4!`",```!M]0$`%P```)'U`0`9
M````J?4!``\```##]0$`!P```-/U`0`(````V_4!``D```#D]0$`%@```.[U
M`0`,````!?8!`"H````2]@$`$@```#WV`0`6````4/8!``D```!G]@$`#```
M`''V`0![````?O8!`%0```#Z]@$`10```$_W`0!P````E?<!``T````&^`$`
M)0```!3X`0`L````.O@!``H```!G^`$`!P```'+X`0`5````>O@!`$(```"0
M^`$`!@```-/X`0`7````VO@!`%0```#R^`$`,````$?Y`0`8````>/D!`"(`
M``"1^0$`(@```+3Y`0`2````U_D!`"4```#J^0$`*@```!#Z`0`O````._H!
M`"D```!K^@$`+P```)7Z`0`E````Q?H!`!4```#K^@$`!P````'[`0`,````
M"?L!``X````6^P$`%P```"7[`0`+````/?L!`#T```!)^P$`#````(?[`0`,
M````E/L!``@```"A^P$`$P```*K[`0`(````OOL!``4```#'^P$`'0```,W[
M`0`(````Z_L!``D```#T^P$`!@```/[[`0`-````!?P!``T````3_`$`$@``
M`"'\`0`4````-/P!``P```!)_`$`&````%;\`0`-````;_P!``@```!]_`$`
M$0```(;\`0`8````F/P!`!@```"Q_`$`'@```,K\`0`0````Z?P!``D```#Z
M_`$`&@````3]`0`L````'_T!`!,```!,_0$`+0```&#]`0`M````COT!``T`
M``"\_0$`!P```,K]`0`(````TOT!``<```#;_0$`!````./]`0`5````Z/T!
M``P```#^_0$`#0````O^`0`,````&?X!``4````F_@$`"0```"S^`0`(````
M-OX!``D````__@$`"0```$G^`0`8````4_X!``8```!L_@$`#@```'/^`0`&
M````@OX!``\```")_@$`#````)G^`0`@````IOX!``H```#'_@$``@```-+^
M`0`E````U?X!``<```#[_@$`"@````/_`0"*````#O\!``P```"9_P$`!@``
M`*;_`0`C````K?\!`#0```#1_P$`(`````8``@`@````)P`"`%<```!(``(`
M(P```*```@`Q````Q``"`#0```#V``(`(P```"L!`@`@````3P$"``4```!P
M`0(`#P```'8!`@`-````A@$"``\```"4`0(`!@```*0!`@`-````JP$"`!,`
M``"Y`0(`#P```,T!`@`/````W0$"`!$```#M`0(`#````/\!`@`'````#`("
M``<````4`@(`"````!P"`@`6````)0("``D````\`@(`"````$8"`@`'````
M3P("`!P```!7`@(`!@```'0"`@`=````>P("`!D```"9`@(`"````+,"`@`3
M````O`("``@```#0`@(`#0```-D"`@`)````YP("`!4```#Q`@(`!P````<#
M`@`5````#P,"``8````E`P(`&P```"P#`@`-````2`,"`!P```!6`P(`!0``
M`',#`@`(````>0,"``T```""`P(`'P```)`#`@`*````L`,"``P```"[`P(`
M*0```,@#`@`<````\@,"`!(````/!`(`!````"($`@`(````)P0"``L````P
M!`(`"0```#P$`@`"````1@0"`!8```!)!`(`"````&`$`@`F````:00"`"8`
M``"0!`(`/@```+<$`@`O````]@0"`#0````F!0(`.@```%L%`@!O````E@4"
M``D````&!@(`;````!`&`@`[````?08"`%,```"Y!@(`<@````T'`@`I````
M@`<"`$<```"J!P(`+P```/('`@`Q````(@@"`#0```!4"`(`'P```(D(`@`^
M````J0@"`.@!``#H"`(`(@```-$*`@`)````]`H"`$D```#^"@(`J````$@+
M`@`K````\0L"`!D````=#`(`-````#<,`@`C````;`P"`",```"0#`(`)@``
M`+0,`@`U````VPP"`$,````1#0(`=@```%4-`@!(````S`T"`$(````5#@(`
M%````%@.`@`*````;0X"`#T```!X#@(`'P```+8.`@`B````U@X"`#````#Y
M#@(`*@```"H/`@`I````50\"`%````!_#P(`$@```-`/`@`(````XP\"`$@`
M``#L#P(`-P```#40`@`J````;1`"`"<```"8$`(`)@```,`0`@`K````YQ`"
M`&@````3$0(`0P```'P1`@!&````P!$"`$(````'$@(`.P```$H2`@!0````
MAA("`&T```#7$@(`6````$43`@!!````GA,"`#T```#@$P(`.0```!X4`@!`
M````6!0"`#P```"9%`(`9@```-84`@!X````/14"`#4```"V%0(`-P```.P5
M`@!P````)!8"`'````"5%@(`/P````87`@`Y````1A<"`#@```"`%P(`+@``
M`+D7`@`N````Z!<"`#`````7&`(`@P```$@8`@!X````S!@"`'\```!%&0(`
MTP```,49`@`:````F1H"`"P```"T&@(`-@```.$:`@`K````&!L"`%@```!$
M&P(`+0```)T;`@!7````RQL"`"H````C'`(`*@```$X<`@`,````>1P"`+X`
M``"&'`(`70```$4=`@`C````HQT"`#@```#''0(`)P`````>`@`@````*!X"
M`$,```!)'@(`!@```(T>`@`'````E!X"``0```"<'@(`#0```*$>`@`*````
MKQX"``L```"Z'@(`"P```,8>`@`%````TAX"`!````#8'@(``@```.D>`@!?
M````[!X"``4```!,'P(`'````%(?`@`$````;Q\"``<```!T'P(`!@```'P?
M`@`%````@Q\"`#H```")'P(`!````,0?`@`7````R1\"``T```#A'P(`$P``
M`.\?`@`0`````R`"``(````4(`(`"````!<@`@`&````("`"`!4````G(`(`
M#````#T@`@`7````2B`"``8```!B(`(`#@```&D@`@`*````>"`"``@```"#
M(`(`+@```(P@`@`(````NR`"``8```#$(`(`!P```,L@`@`X````TR`"`%P`
M```,(0(`2````&DA`@!)````LB$"`#(```#\(0(`,````"\B`@`S````8"("
M`#@```"4(@(`+P```,TB`@`J````_2("`#8````H(P(`,0```%\C`@`K````
MD2,"`#8```"](P(`+0```/0C`@`M````(B0"`$(```!0)`(`(P```),D`@`D
M````MR0"`#\```#<)`(`.@```!PE`@`Q````5R4"`#4```"))0(`,````+\E
M`@`K````\"4"`#8````<)@(`,@```%,F`@`V````AB8"`#4```"])@(`*P``
M`/,F`@`M````'R<"`#````!-)P(`.P```'XG`@`K````NB<"`"@```#F)P(`
M1@````\H`@!)````5B@"`"<```"@*`(`-````,@H`@!/````_2@"`#(```!-
M*0(`-@```(`I`@`Q````MRD"`#(```#I*0(`+````!PJ`@`I````22H"`"X`
M``!S*@(`,P```*(J`@!&````UBH"`"\````=*P(`8````$TK`@`-````KBL"
M`!P```"\*P(`'````-DK`@`B````]BL"`$$````9+`(`)0```%LL`@`0````
M@2P"``\```"2+`(`'````*(L`@`6````ORP"`!(```#6+`(`)````.DL`@`)
M````#BT"``D````8+0(`)0```"(M`@`H````2"T"`"<```!Q+0(`)P```)DM
M`@`D````P2T"``D```#F+0(``P$``/`M`@`2````]"X"`"(````'+P(`'0``
M`"HO`@`.````2"\"`!````!7+P(`%@```&@O`@`8````?R\"`!\```"8+P(`
M"0```+@O`@!.````PB\"`!H````1,`(`$P```"PP`@`'````0#`"`!4```!(
M,`(`#````%XP`@!9````:S`"``@```#%,`(`*0```,XP`@`2````^#`"`!4`
M```+,0(`%0```"$Q`@`^````-S$"`!P```!V,0(`#````),Q`@`H````H#$"
M``T```#),0(`#@```-<Q`@`5````YC$"``H```#\,0(`)`````<R`@`+````
M+#("`!D````X,@(`"@```%(R`@`=````73("`"T```![,@(`!0```*DR`@`G
M````KS("``<```#7,@(`!P```-\R`@`)````YS("`$P```#Q,@(`!P```#XS
M`@`1````1C,"``L```!8,P(`%P```&0S`@`)````?#,"``D```"&,P(`!P``
M`)`S`@`6````F#,"``L```"O,P(`'@```+LS`@`/````VC,"`!@```#J,P(`
M'`````,T`@`%````(#0"``<````F-`(`&0```"XT`@`'````2#0"`#$```!0
M-`(`#0```((T`@`1````D#0"``<```"B-`(``@```*HT`@`0````K30"``\`
M``"^-`(`"P```,XT`@`#````VC0"``<```#>-`(`"P```.8T`@`*````\C0"
M`!$```#]-`(`#@````\U`@`;````'C4"`!P````Z-0(`"@```%<U`@`V````
M8C4"`"0```"9-0(`*@```+XU`@`7````Z34"`#P````!-@(`#0```#XV`@`^
M````3#8"``8```"+-@(`%P```)(V`@!`````JC8"``X```#K-@(`!P```/HV
M`@`'`````C<"``0````*-P(`!`````\W`@`)````%#<"`!X````>-P(`!0``
M`#TW`@`&````0S<"``@```!*-P(`#````%,W`@`&````8#<"`!0```!G-P(`
M%````'PW`@!`````D3<"`#0```#2-P(`+@````<X`@`,````-C@"`!X```!#
M.`(`(0```&(X`@`O````A#@"`"D```"T.`(`%````-XX`@`"````\S@"``0`
M``#V.`(`#````/LX`@`(````"#D"``4````1.0(``@```!<Y`@`1````&CD"
M`&$````L.0(`+@```(XY`@`O````O3D"`!H```#M.0(`.@````@Z`@`O````
M0SH"`%X```!S.@(`00```-(Z`@`6````%#L"`'T````K.P(`*0```*D[`@!6
M````TSL"`"D````J/`(`0````%0\`@`^````E3P"`#(```#4/`(`-0````<]
M`@!,````/3T"`#4```"*/0(`-P```,`]`@`Y````^#T"`!\````R/@(`+@``
M`%(^`@`R````@3X"`$````"T/@(`$@```/4^`@`2````"#\"``P````;/P(`
MB0```"@_`@`(````LC\"`,8```"[/P(`<0```()``@"+````]$`"`"T```"`
M00(`90```*Y!`@`7````%$("`"8````L0@(`%P```%-"`@`8````:T("`!<`
M``"$0@(`&@```)Q"`@`D````MT("`!$```#<0@(`0P```.Y"`@`F````,D,"
M`"````!90P(`:P```'I#`@`<````YD,"``P````#1`(`"P```!!$`@`%````
M'$0"``8````B1`(`"````"E$`@`%````,D0"`!8````X1`(`$````$]$`@`5
M````8$0"`"````!V1`(`$0```)=$`@`/````J40"`!8```"Y1`(`#0```-!$
M`@`*````WD0"``D```#I1`(`"````/-$`@`.````_$0"``L````+10(`#```
M`!=%`@`(````)$4"``8````M10(`%0```#1%`@`.````2D4"`!$```!910(`
M"0```&M%`@`)````=44"`!,```!_10(`$@```)-%`@`+````ID4"``X```"R
M10(`!P```,%%`@`(````R44"`!(```#210(`!@```.5%`@`.````[$4"`!D`
M``#[10(`"0```!5&`@`*````'T8"`!(````J1@(`"````#U&`@`)````1D8"
M`"D```!01@(`(@```'I&`@`0````G48"`"4```"N1@(`%````-1&`@`;````
MZ48"`!$````%1P(`"@```!='`@`6````(D<"``<````Y1P(`!0```$%'`@`5
M````1T<"``0```!=1P(``@```&)'`@`"````94<"`!(```!H1P(`!@```'M'
M`@`&````@D<"`!(```")1P(`%P```)Q'`@`'````M$<"`#H```"\1P(``@``
M`/='`@`$````^D<"`!,```#_1P(`&````!-(`@`*````+$@"``L````W2`(`
M!P```$-(`@`2````2T@"``4```!>2`(`&0```&1(`@`(````?D@"`!<```"'
M2`(`%0```)](`@`3````M4@"``(```#)2`(`#@```,Q(`@`,````VT@"``T`
M``#H2`(`%@```/9(`@`Z````#4D"``<```!(20(`"0```%!)`@`1````6DD"
M``4```!L20(`!0```'))`@`"````>$D"``L```![20(``0```*P'``"J!```
MZ0$```@"``"B!0``%0,```````!U`@``F`(```````!6`@```````$4"````
M````TP$``,,'``!(````K@8``*D%``#Z!```0@0``!D!``#,````S`4`````
M``````````````('````````K@$``````````````````(,'```B!0``.@0`
M`*P!``"F`P``W0(```````"P!@``YP8```````!)!```E08````````:`0``
MU@4```P'````````9@$```````!@!````````$`#``#J`@```````&0&```%
M`@``'`$``,0#````````````````````````"@<```````!D`P```````'<%
M``"7!P``I04``!,`````````)P4``,$#``!O!`````````<$``!*`@``T`(`
M`+X#``"3!0``*0,```````"Q`P``H@```/,!``!T`@``QP<```````"?`P``
MO````````````0``W@8``%8#``!3````H04``!D"``"F`@```````-X!``"#
M````(@<``((```#?`0``5`0``%4&````!```Y`4``*L%``"E`0``>@,`````
M``!J!P``:@(``#H!````````:@$```(#``#I!0``7`<```````#I`P``R`<`
M`-H$``!;`P```````,H'``#\`0``PP```!D&``"4`0`````````````Z````
M[`0``/$%``!-!0``*0$``&T```"`!```RP$```````#Y!0``-P0``.0'````
M````O`(``%D&```A`0``,0,``-@&`````````````(@```"[!```80<``)4`
M``"'`P```````,$!````````K`0```````!I`@``U`4```````"T````+0<`
M`-X"``"(!P``C@,``&$%``"G`@``Z@<``+$'``#H!```Q@4``)0%``";!@``
M1@8``,@"``"3!@``T@4```````````````````````".`0``+P,``)L#``"I
M!@```````-@!```/`@```````!('``````````````````#:!0``\@,`````
M``!L``````````X%``!9!```0P8```````"R!0``^0````````#'`0``P@8`
M`#$!``"6`P``MP8``.T"``#T`P``)P0``*0```#W`P``TP```)4'``#Z!0``
MF`0``"`'````````0P0``)$'``"T!0``P`4``#\`````````50````````"[
M`P``JP,``!`#```"!0``-08```````!I!```H`0``"T"``"A!P``NP8``$<!
M```\`P``2`,``!T%```,`P``P@<`````````````=`,```````!7!P``3@<`
M`````````````````-\"````!@``:@0```````"Q!```:```````````````
M`````-0```"3!```E````#D#``!@````DP```*D!``#\`P``T`<``&8&``#O
M`@``'`<```````!;````[@,``&X&```?!````````*,#```R`@```````%$&
M``#6`````````&L'```Q!0```````$<&``"A!```)`0``',```"X````/0(`
M`#\%``"U`0```````/$'``!<````4@8``(H$````````%0$````````8!P``
M"P0``&$#``":!0``<P4``%(%`````````````.$#``#``P``?P8``*0#``"`
M!0``>P4``+4"````````R`8``&4#```#`````````.X'`````````````*`!
M``!=`````````)\!```#`0```````+4$``#%`P``)P````````",!P``````
M`&<!``"Y!P``Q`8``-0'````````Y0```&D````````````````````$`0``
M(@8``$8'````````'@4``#0&````````G````/`!``#``@```````"@%````
M````^@<``$$&``````````````````#S!P``O`,``+`%``!E`0``!0<``'0'
M``#<`P````````````"_!P``V0```````````````````)T!``!Y!0``````
M``````!0!P```````+`#``"B`0``EP(``*H'`````````````&P"``"E`@``
MI`8``/`'```<````_`(```````!7`P``>0,``#$$```I!P``CP4```L&````
M````^P```%0&``##`@``$P4``(P`````````+`(``%8```#L!0``8P0``/L'
M```B`0```P,``-<&``#U`0``````````````````BP<```````#I!```````
M`*`'`````````````!8#````````Y@$``'`"``!D`0``?@0``%,$``!(!```
M+`$``/\!``!"`@``(P8``-,%``#)!0``_@8```````#D`0``(`8````````8
M`P``>00`````````````)@$``!,#`````````08``(T&``!@!0``Q`$``"P#
M``!G!@``#@<``$4&```)`0``!`(``%H```!0!0``(P<`````````````G`(`
M`%0````<!0``4P(``*<```#`!```:0<``-L#````````F@<``*@%````````
M'00```X$``!)!@```@$``(4`````````7`$``'$%``"Q`````````%4"``#F
M!0``!P,``$L!``!\!@``2`4``.H```"?!P``-P8``#T'````````UP,``!T"
M```O````X````*X$``!!`P``'@8``.X"```*`P``L`0``#8#``#*!0``300`
M`+@"```0`````````/T!``##!````````*,$```)`P```````)0$``!Q`@``
M=04``*H&``!X`0````````D%```A!0```````(4$````````XP````$#``"[
M!0``$0,``.$````@!```F0,``'$&```B`@``Y@<``(H'```9!0``F@,```\`
M````````)P<````````'`@``@@0``&8%``"F!```5P(``(4&``"F!P``M@(`
M`'($``"2!@```````+("```A`P``)`4``%0!``")````ZP4``+L"````````
MQ@````````"P!P```````#0%``"M````#`8``````````````````"8'```?
M!P``I`0`````````````F`````````!-````%P8``+$!``!J!0``80$``&P&
M``#T!@``W````#0!```&`P``R````*X"``"]`0``)@8```````!M!@``]P``
M`,L%``#9!0```````/L%``!\`P`````````````Y!@``=`8``,(```!(!P``
M40$``"P```"-!```XP(``(`````.!@``90```"8%``!Z````R@0```````!*
M!````````%\"``!0`P``O0````````#B`0``U`,```````!J!@```````.,%
M``#K!@``!@$``)<$````````Z@0````````*`@``J0(``$0!```S!@``Q0``
M`$X"``#!`@``I@```+0&``!H!P``3`0``-\$``#!!P``700``+4&``!>!P``
M```````````E!P```````-L```!G!```_P0``%4!``!;!P``,`(``,$%``#T
M`0``7`8``-8!````````I08``.P&````````;0(``$T#````````D`4``"\!
M``#2`P``Q`0``-8"```,!0``AP````````"4`P``4P8```````!`!0``5`,`
M`'\$```S!P``%P,``,L#```:!0```````*\"``#R!P``@04`````````````
M````````````````)`(``,<$``"K!````````!\"````````/`0``&D&````
M``````````````#6!```!0$``&("``"+!@```````(\``````````````'8#
M``"2!P``/@4``%P#``"9!0``5@0``+P!``!7!@``V0(``-T`````````PP,`
M`"$&```A````[0,`````````````'0<``(0#``"&!@``````````````````
MK@4``)`&```-!0```````&@"````````1`,``````````````````',&````
M````+@0``%T'``"Z!0``!`````,"``":`@``?P(```````"2`0```````*`"
M````````%P<````````:!````````"8#``#+`@```````'`&```'````CP8`
M`-0$```K`P``Q04``#X'``!H!@``V0$``-H'```````````````````I!@``
M,`,```````#:!@``6`4`````````````C0$``"H"```\!P``B@8`````````
M``````````````!N`0``````````````````J````!P$``#%!```*04``-('
M``!;`0```````%\'```6!P```````-@"``#K!P``1````*L&```A!P``````
M``````#K`P``?00````````Y!0```````$H'```O!0``I0<``!\#``#1!@``
M`````,\!``!A!```%0(``````````````````*<$``"5!````````&8'````
M``````````````#1`P``%0```'L$``"'`0``<P<``"0'``#+!P``FP$`````
M``````````````````#)!P``Z08``.@"``#*`0``1@4``%@$````````%@0`
M`)T"``"0`0``R`4``*\$``!B````$@4``/H&``!^````````````````````
M6@$`````````````B08```("```N`@``=@0``.`$``#R````-@<```L#````
M````@0````X!``#1`@```````"H$``#8`P````````````"=!P``$@0``'4$
M````````(`4```````";!P```````'8'``"C`@``A@<``-8#``!B!P``````
M``````"Z!P``>`<``/T````R!P``U0<``+D&````````Y0<``"L&````````
M`````#X&````````5P0``/<&``"&!0```````",#````````.`4``%<````U
M!P``X@8``)0"``#J!@``A@```!@%```E`0``^`(```````!C`P``;P$`````
M``#O!0``P08``%0'``"M!0``]@<``'X'``#E!0```````"H!````````````
M`+(```#N`0``C04``.,$``!K!0``'`(``"H```#8!````````!X```!'`P``
M004```````"$`0``/P0``,P'```4`@```````"$"``!-`0``6@0``%$#``#G
M!P``>0<``*P```"?!@``L@0``)T$``#Y`P``P`<``-P'```+`````````#<"
M````````FP4``"X#``!8````P@$````````F!```F0<``$4```!K!```<@8`
M``````"Z`P``9@````````"!!```'08````````,`@``F08``-,&``#&!```
M,@8```````#,`0``_P(``````````````````'P```"G!0``U0$``/@#````
M`````````!0&````````P@,```````"-`@``U@8``*<&```:`P```````,`&
M```I!```\0(``,T`````````#`$``.<#``!/`0````````````#-!0``,P$`
M`(D#``![!P``,08``/P'``!U!@``]`(``````````````````%T&```O!@``
M``````````!/`P``1P0``/X"``!!!```W@4``.P!```%!@``.@<``","``#[
M!@``O@$``$,'``!3!P```````+<#```O!```8P```)8&```)!```D````)T#
M``!M`P``\`,``/D'``"2!````````*`#```^`0``W0$```````"]!```F`,`
M`+D!```6!0```````$$!``#Y`@``-04```````!#`0``V@````````"9`@``
M`````,P$``"U`P``0P4``/(!``#U!@``G@4``,\%````````$`0```````#E
M!```-@(```L!``!/!0``Y`(``%4%``"@````ZP(```````#[`P```````*P%
M````````A`<```@#``"P`0``T`,``+,!``"+````+0````````"M`@``WP8`
M```````H`@``!@```)X$``#P!@```````%D'``")!````````#`!``!"````
M`````````````````````-4#``"S!```````````````````UP0``#X`````
M````@P0````````3!@```````'$'``!>`0``?P<``!$$````````!P<``$,`
M``#D!```0@<``",$````````$@```)@!````````,0```'$!```D````!`<`
M``````!.````Y0(``"@#```Z!@```````!,"``"[````Q`4``%(```!:!@``
M)`8``+X"``#'````#0$```````!#`@``,`0``(,"```G!@``EP,`````````
M````A`0```T```"^````K08``'P"`````P``T04``$P%``!:`@``P`$`````
M``#@!@``7@```+\%`````````````&$&``"5`@``E`<``/`$```1````````
M`"<!````````````````````````<@,````````E!@``C`$``-D$``"8!@``
MVP8``*0'``"I!```(`(```````!%!```'`,``&@%````````````````````
M````+`0```````![`P``"@0``)@%``#Y!@``@P$``'T%````````Y@8``-$!
M````````W`8``.(#````````X`$``$`!``#.`@``.`<``&P$``#H`0``!04`
M`"P'````````RP```!4$``!-!P```````%X$```*!@```````*D#``!D`@``
MU@<``*H#````````HP8``/D$````````70,``!\&``"L!@````````````!I
M`P```@0``/(%``#T!```;`<``#L$``";```````````````4!0``)@(`````
M`````````````'8!``!N`P``KP4``!P&``#F!```?@$``(@$````````2@$`
M``````#O`P```````)<&````````6P(``/@'```J!0``SP,``#4!``!T!0``
M`````#`'``"$!0``[08`````````````.00``"4#``#R`@``J`$``/<!``"P
M`````````"````#X!0``E@```%$"``#,!@``)P(``"(#```6`0``.0$``$X&
M``!N````S@```!8&```^`@``Z0<``%0"``"9`0```````-X```"\!```M0``
M`/@```#.`0``$04``-X'`````````````#8```":!@``,0<``&,!``![!@``
M;P```!X'``!?!@```````(@"```\`0``P````#,%```$!```XP8```````#U
M`@``BP(````````E````1@(``'$````[!@``_`0`````````````[00``%,!
M```.````TP(```````"B!```6P4``)0&``"<!P````````````!D!0``!`,`
M``````#9!P```````'H!```'!0````````````"V!0```````#P&``!'!0``
M`````.X%``#M!0```````'4'```M!@`````````'``"$````OP$``&4$```;
M!0``500``+@&``#K`0```````-(```![`0``?0(``&T$``")!0```````.P"
M``"!!P``Q0$``#8$``!8`@``^@$``*@#``!'`@``+@$```````":!```=0,`
M`)$```![````Q```````````````R0````````"<!0````````````#/`@``
M`````'````#A!P``_P```"X&``!2`0``YP(``'T&````````J@$``.\$```_
M!P```````/($``!1!```G@```(T#``"^!0```````+P'````````@0,``-X$
M``"0`P```````,H```#E!@````````````!P`0``<P(````````0`0``````
M`',!``"B!P``H`8``)P!````````;P4``)4#``#;!```N00````````Y````
M?@4``)X"``!Z!````````/L$`````````````+D#```K!```,`4````````'
M!@``.`,``"X````$!@``8`(``$L&```U!````````/4%````````Y@,``+T#
M````````:04``%`````+`@``P@(``)8$``!H`P``00(``&<#````````70(`
M`+0!``!+!0```````$\``````````````(P$``"3`P```````,8#``!'!P``
M4`8``#8&``!>!@``*`0``'T'``!9````4P,``.L$``#M````MP```.<!````
M````C@0```````!`!P``0`8``%X"```B````````````````````````````
M```:````L@<``"T#``!W!P```````$0"```3!```PP4``"8```#P!0``O`8`
M`),'```X`0``]00``,L&```W!0``U0````4$``#Q`P``9`0```````#<`0``
M`````)X!```E`@``40```)8!````````T00``!\!``!W````I@4```````!.
M!0```````'@%````````;@<````````C````S0,```````!6`0``EP4``/8"
M````````@P,``'8%````````_0(``+T"``#J`P````````````#.!P``9P(`
M`+<'```@`0``*P4``$0'``"Y````[P<``+@%``!.`P``W08``-X#``"K````
M[@```!0#```%`P``?@(```L%````````%P```*X#``#%`@```````+<!````
M`````````"L"``#7!0``WP,``(4#``"*`P``X@0```````#H````D04```8'
M``#Z`@``3`8```8$````````LP```$L"``!Y!@``2P0```````!J````4P4`
M``````"7````1@$``#(``````````````+\&````````DP$``$\'``!Z!0``
MX`(``.8`````````YP0```````"?````-0(``-,'````````_08``%\!``#0
M!```KP8``"@'```9!P``N@0``!8"``"Y`@``\00```````"!!@``.@,`````
M``"I!P``WP4``!(&````````V````-P$````````20```/T%```!!```-P<`
M`%<%```B!```/P,``%D#````````YP4``,\&``":````)`$``!H"```)!P``
M.`0``'8`````````%`$``#(#``"*`0`````````````N!0```````$0%``#.
M!```````````````````H08``'@$``"!`@```````````````````````/,#
M``!O`@``I0,``"H#``!+````20(``.$!````````I00``!`"``")`0``$@,`
M`/,$```W`P``L0(````````>`@``TP,``%\$``"K`@``K@````````!B!@``
MFP(``*D```!S!````````$H%``#;!P```````-H#`````````````*,'````
M````GP0`````````````#P8``-<```#O````K`,``,0"```-!```HP```-4&
M``#T`````````+P%```>`P```````-`%````````````````````````BP,`
M``````"%!P```````$D%``!@`P``8`$``$0$``"1`P`````````````I````
MV08``&(!``!`````80(``/L"``#B!P``4@(``)`'``"-!P``I@$``,@#````
M``````(````````X!@```````'$#```2`0``60(``"X'``"T!```G@,``-L!
M``#T!0``50<``&@$`````````````/<'``!M!P``?@8``(`'```C`0``]0,`
M`!H&```X````K0<``#L"``#;!0``R`0````````#!0``308``$T"``!U`0``
MUP<``((%``"6!P```````/,"```S!````````!<"``"^!```8P8````````&
M!0``G08``(8#``!O!@``0`0``.(%```8!@``Y@(``(('``#]`P``]@```&4'
M``"(!@``G`,``'(!``#/!```.P$``(\#``"K!P``;@4``#,#```[!0``M@<`
M`,T"```/!0``E@4``/,`````````J@````````"'!P``T`8``-\'``"/!```
MF00``,4&``#O!@``MP4``'8&``"U!P``[0$```\'```G`P``X`<``%@#``!"
M!@``&00``!4%``"$!@``&0,``%`"```*`0``8@4``*$!``#4`0``10<``,@!
M``"#!@``]@$```````"@!0``^`8``"L```!)`P``K`(``)(#``!X````GP(`
M`/X!````````\`````<!````````[@8``*<#``!*`P``#@,``&L```##`0``
ML@$```\#``#W!0``-`0````````(`0``&P(`````````````Z@$```````",
M`P``E0$``(L!```````````````````I`@``/P8```````#,`@``AP0`````
M````````B@```*T#````````;04``%D%``"J!0```````#T```#A!@``````
M``````#C`P```````/P%```;`P`````````````S````L@,``%H'````````
M90(````````:!P``N@(```````"2````3`(````````;`````````(,%```.
M`@``,`8``,<&``#;`@``9`<```````#-!P```````'`#````````9@(``+X'
M``#W`@``?0```)$!````````+P<``!@$``!)`0``A0$``&\'````````;`$`
M`$X!````````UP$`````````````QP4``/@!``"$`@````````````#)`P``
M`````&4%``"G`0``&P$``&<'``#/````*@<`````````````"08``+8&````
M````H0,``%8'``"D!0``XP$``&,'```-`P``W00```````#K````5@4`````
M`````````````%\#```*`````````#($``!R````A@(``*("````````T@8`
M````````````"`8```````!W`0```````%P$``!I`0``N`,``,H#```;!@``
MO0<``$$```!%!0``&````/4```#7`@``J`(``$\&``#A!```5P$``#H"```4
M````Z0(``%0%````````^0$``"@`````````S08``"4%````````X@```#(%
M``"1!```:@,``'X#```8`0```````!0$``"_`P``I`$``+H!````````=0``
M`-T#``!(`@``00<`````````````[`````````"&!```]P0``,<"````````
MF@$``+D%``".!0``.P<``&X"``````````````T'``"B!@``>P(``&L&``"8
M!P``M@0```````#&!@```````*\'``"-````T@$```````!N!```8@0`````
M````````3@0```````#N!```JP$````````"````>`(``(`&``!Z`@``````
M``````#H!P``Y0$``(@!``"5!0``P@4``"T$``!>`P``"`0``)D````]!0``
M`````!$!``">!@``8`<``#T$``!Y`````````&0````?````N`<``$0&``"A
M`@``_@4``!<%``#U!P``-P```%P"``!W!```M@,``(8!``"Q!@```````+`"
M````````0`(``#D"````````[`,```````!H`0``?0$```@```!/`@``>@8`
M``````!2!```C@(``'8"````````OP0``-$````\`@``3`<``$4!````````
MN@````````#\````#P$```0%``!F`P``'P4``#T&``#5!0``6`<``*8&````
M````G`8``#L#``"A````Q@$``!T#```"!@````````````""`0```````/8#
M``!)!P``>@<```````#E`P``=P8```````#.`P``_`8``%('````````Y```
M```````3`0``1P```/\#```;!```/`````D``````````````*@&``##!@``
MS@8``"P&`````````````%`$``#2`@```````,H"```X`@```````(\'````
M````Q0<``/L!````````7P`````````@`P```````"L!````````````````
M```7!```H@,``$@!``!]`P``:P(```````"+!0``V@$``$L'````````[P$`
M``````"W!````````.<```!C`@````````````!:`P``Z`,``-@'``""`@``
M]@4```````"H!```$08````````M`0```````"4$````````?P,``+H&``"U
M!0``=```````````````$`4``#,"```T`P````````````!B`P``I0```#X#
M```K!P``7@4```@%``!,`0``M@$``*X'````````<@(```````!?!0``````
M`#0"``!&````Z`8``&4&``#Q!@````````````!<!0````````````",`@``
M````````````````XP<``,D$``!F!````````(D"``"]!0``%`<``+@!```-
M!@``;`,``(X'````````<00````````H!@```````/@$``".````E@(``,D&
M````````````````````````@@8```````"S!@```````(H%````````D@4`
M`((#``#&`@```````/`"``"S`P``=`0``%8&``#5`@``D08``-H"````````
MDP(```8"```!`0``]@0```````#D!@``G@<``'P%``"=!0``<@4``(`#```)
M`@``HP4``,H&``#/!P``+04``+\```#D`P```````!$"``".!@```````'\!
M``#Q`0``/P(``#4#``````````````````"=````?`0``$@&``!5`P``@0$`
M``````!#`P``#````+<"``!\!P``````````````````9P4``'\`````````
MW04``*H"````````LP<`````````````V0,``(@%``!X!@```````-0"``#]
M!```K00``#\!```[````'0```'('``!P!```N`0``+L'```Y!P``D0(``#<!
M````````W`4```````"T`@```````(<%``#V!@``(P4``(`"``"H!P``````
M``,'``"S`@``&0```-$'````````80```!<!````````)`,````````>`0``
M+`4``,X%```5!@``X04````````V!0```````#P%``#J!0``'0$`````````
M````X0(``(4%``!,`P``HP$``#````!"!0``>0(``-`!``#H!0``>`,``.P'
M````````6@4``$\$``"^!@``/0$`````````````_@```&,%```6````````
M`,$$```R`0``Q`<``,8'```T!P``6P8`````````````"`<````````%````
MTP0``"H&````````O08``-0&``"_`@``M@```&L#```8`@``^@,``&P%``"M
M`0``1@0``/0'````````S`,`````````````KP```#$"```A!```W0<``%T!
M```0!P``D`0``'D!``!*!@```````.T'``!2`P``/@0``',#```2`@``0@,`
M``````#<`@``IP<``$L#``!W`@`````````````1!P``^@```,T$````````
M\P4``%L$`````````````#H%``"%`@```````'<#``!*````R0$```P$``!8
M`0``P@0`````````````@`$``.D```#!`````0<```$%``#^!```I`(``'0!
M``!9`0``704``!X$``#+!```T````-($````````U00``)("``!0`0``````
M`#8!``!1!P``L@8``%$%``#B`@``$P<``&`&``!P!P``_@,``(\!``"/`@``
MQP,``,D"```+!P````````T"``#@!0``V`4``'P!``"Q!0``<`4``#4````*
M!0```````*\!``#R!@``+P(``(P%```;!P``3````)L$``!8!@``#P0`````
M```0!@``AP(``"@!```!`@``:P$``&T!``#_!@``GP4``/,&``"+!```!@8`
M`*\#``#Q````?P4```````!&`P``D`(``&<```"S!0``_P4``$(!``",!@``
MX`,```,&``"*`@``-````+L!``"(`P```````-\`````````EP$```````"T
M!P``G`0``,T!``")!P``/0,``$4#````!0``;P,`````````````M`,``!4'
M``"'!@````````,$````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I
M`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D
M87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S
M(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W
M960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+@`E9"!N;W1E<P`E9"UD87D@9F]R96-A<W0`)7,@
M+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@8VAA<F%C=&5R<P`E<R!F:6QE('-U8V-E<W-F=6QL>2!I
M;7!O<G1E9``E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R
M(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES
M('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD
M+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N
M9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI
M<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B
M92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@
M<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M
M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,2!N;W1E`#$R($AO=7(@1F]R
M;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B
M87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!
M32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E
M<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B
M<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!
M8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N`$%C8V5S<R!D96YI960@;6]V
M:6YG('1H92!N;W1E+@!!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E('1O("5S
M+@!!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<P!!8V-O=6YT($EN9F]R
M;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U
M;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO
M;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`
M061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C871E9V]R>0!!9&0@
M8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`
M061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!!($YE=R!.;W1E`$%D9&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M
M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!
M;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5
M<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E
M<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-
M4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-
M4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E
M('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@
M:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R
M(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO
M=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D
M80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES
M(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI
M;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E
M($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R
M;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`
M07)T`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R
M=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT
M(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I
M8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@
M<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE
M9"X`079A:6QA8FQE($-A=&5G;W)I97,Z`$%V86EL86)L92!F:65L9',Z`$%Z
M97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VL@=&\@3F]T97!A9`!"86-K('1O
M($YO=&5P860@3W!T:6]N<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N
M`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T
M(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC
M871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y
M<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K
M;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T
M<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I
M80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL(%!R;W!E<G1I97,N
M+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L
M;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@
M;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S
M(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#
M:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D
M:7-P;&%Y(&]P=&EO;G,N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN
M+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#
M:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T
M;R!L:7-T(&EN('1H92!S=6UM87)Y('9I97<N`$-H;V]S92!Y;W5R(&1E9F%U
M;'0@3F]T97!A9"X`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@1F]R;0!#;&5A<B!-4T]F
M9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A
M<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O
M($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L
M;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA
M;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB
M:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`
M0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O
M;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#
M;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@
M;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P
M>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC
M80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E
M.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-
M24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE
M<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E
M<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N
M;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A
M+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C
M;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O
M<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T
M(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O
M=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@
M=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@
M04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E
M=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T
M(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H
M92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y
M(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A
M<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#
M;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L
M9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R
M<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E
M871E('-U8B!F;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#
M<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S
M97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@
M:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD
M:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y
M<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S
M97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E
M;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N
M=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`
M1&5F875L="!)9&5N=&ET>0!$969A=6QT($YO=&5P860`1&5F875L="!3:&5L
M;`!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D
M:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE
M=&4@0V]N9FER;6%T:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T
M92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E
M(&)U='1O;B!B96AA=FEO=7(`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$
M96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S
M86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI
M<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE
M=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O
M;&1E<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U
M<G)E;G0@<F]W`$1E;&5T92!T:&ES(&YO=&4`1&5L971E9"!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8V5N
M9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$97-C<FEP
M=&EO;CH`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I
M;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W
M86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\`1&]E<R!T:&4@9FER
M<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K
M('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@
M:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E
M<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R
M:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3
M(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T
M:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="`B)7,B`$5D:70@
M0FQO8VL`161I="!'<F]U<`!%9&ET($YO=&4`161I="!097)M:7-S:6]N`$5D
M:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!C
M871E9V]R:65S(&%N9"!C;VQO<G,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%
M9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%
M;6]T:6-O;G,`16UP='D@3F]T90!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U
M;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG
M:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O
M<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E
M(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE
M(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A
M=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L
M;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@
M9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@
M)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO
M<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@
M)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`
M17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@3F]T97,`
M1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&7W5L;"!497AT`$9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T
M;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@
M)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L
M86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI
M:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`
M1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`
M1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S
M`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U
M<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN
M;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``
M1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-
M;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;0!'86QL97)Y.@!'86UB:6$`1V5N97)A;"!/<'1I;VYS`$=E;F5R871E("5S
M($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY
M`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O
M`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'
M<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R
M;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`
M1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'
M=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@
M:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE
M861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y
M(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE
M;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I
M<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(
M;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I
M;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O
M;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y
M<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S
M<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G
M<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N
M<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R
M964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V
M92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L
M86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO
M;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F
M86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)
M4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L
M86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)
M9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C
M=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O
M;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO
M=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@
M=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@
M:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@
M9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA
M9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R
M;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@3F]T97,L
M(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T97,`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2
M;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E
M8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N
M97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!)
M;G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E
M9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E
M('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A
M9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!)
M;G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A
M<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@
M<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO
M9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F
M:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A
M;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN
M=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI
M9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R
M=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C
M;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J
M96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D
M871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E
M9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A
M`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`
M2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I
M9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N
M`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N
M`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G
M90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+
M=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G
M<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T($UO9&EF:65D
M`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T
M960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S
M="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V
M86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H
M:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`
M3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3
M:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H
M="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,
M:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE
M;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O
M<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M
M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5
M;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN
M9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@
M`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I
M;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO
M9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@
M=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T
M97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@
M;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]4
M1`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-
M86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?
M:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C
M871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T
M;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G
M<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE
M;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E
M<B!O9B!.;W1E<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA
M>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365M
M;R!497AT`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D
M+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A
M<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N
M;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G
M92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G
M92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES
M<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I
M9FEE9"!$871E`$UO9&EF>2!54DP`36]D:69Y:6YG("5S`$UO9'5L=7,`36]L
M9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y
M96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD
M<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O
M8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U9'D@
M86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO
M=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E
M`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``
M375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O
M<FUA=&EO;@!->2!.;W1E<P!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!-
M>6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`
M3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A
M<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P
M92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T
M92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O
M<GD`3F5W($UO;VX`3F5W($YO=&4`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`
M3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X
M<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I
M;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA
M<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I
M80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E
M+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.
M;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I
M;&4@=7!L;V%D960`3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+@!.;R!I
M8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P
M<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I
M960N`$YO(&YO=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+@!.;R!N
M;W1E<P!.;R!N;W1E<R!M871C:"!T:&4@8W5R<F5N="!C<FET97)I82X`3F\@
M;F]T97,@=&\@9&ES<&QA>0!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E
M;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN
M9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O
M<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO7W1E`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET
M*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R
M;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`
M3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L
M96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E($-A=&5G;W)Y
M`$YO=&4@1&5T86EL<P!.;W1E($QI<W1S`$YO=&4@5&5X=`!.;W1E(%]497AT
M`$YO=&4@;F]T(&9O=6YD+@!.;W1E7W!A9`!.;W1E<&%D)W,@;F%M93H`3F]T
M97!A9',`3F]T97!A9',@;75S="!H879E(&$@;F%M92X`3F]T97,`3F]T97,@
M4W5M;6%R>0!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`
M3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@
M0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P
M87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M
M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@
M82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#
M;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T
M+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3
M>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I
M;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2
M.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R
M>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E
M9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A
M:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`
M4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3
M:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I
M=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U
M87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U
M8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I
M<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M
M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E
M;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N
M86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E
M;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`
M4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS
M`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N
M=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI
M<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0
M;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V
M86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO
M;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL
M;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@
M=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0
M;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E
M8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@
M<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O
M8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO
M;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@
M06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP
M86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0
M=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME
M>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A
M:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO
M=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A
M;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5A;&QY(&1E;&5T92!T:&ES(&YO=&4_`%)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H($QI<W0`4F5F<F5S
M:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L
M;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`
M4F5M;W9E(&-A=&5G;W)Y`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I
M;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@
M4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E
M<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W
M;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT
M('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T
M92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S
M`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R
M('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN
M="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I
M;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3
M875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO
M;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E
M9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H
M`%-E87)C:"!%;F=I;F5S`%-E87)C:"!297-U;'1S`%-E87)C:"!38V]P90!3
M96%R8V@@7U1E>'0`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T
M(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!N
M;W1E<&%D`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!3
M96QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@
M86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!N;W1E<&%D<R!T;R!D:7-P
M;&%Y.@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!E>'!O<G0@
M9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE
M(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@:61E;G1I
M='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&5C=&5D($-A=&5G;W)I97,Z
M`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z
M(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB
M97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO
M;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@
M;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I
M9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I
M;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C
M97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W
M(&%C=&EO;B!B=71T;VYS/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`
M4VAO=R!N;W1E<&%D(&YA;64_`%-H;W<@;F]T97,@9G)O;2!T:&5S92!C871E
M9V]R:65S`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K
M97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S
M`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@
M=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I
M>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N
M;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO
M=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E
M;7,`4V]R="!B>2!#871E9V]R>0!3;W)T(&)Y($YO=&4@5&5X=`!3;W)T(&]R
M9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I
M;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S
M`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T
M92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D
M9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G
M(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B
M<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S
M(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN
M`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"`B)7,B+@!3=6-C
M97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@
M)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I
M<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3
M=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y
M;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N
M9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L
M92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A
M;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N
M92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M
M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI
M;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B
M;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN
M:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D
M+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G90!4:&4@;F]T92!W87,@9&5L971E9"X`5&AE(&YO=&5P
M860@(B5S(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E<P!4:&4@;F]T97!A9"`B
M)7,B(&AA<R!B965N(&-R96%T960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M
M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`
M5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M
M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I
M960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER
M96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@
M9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.;W1E(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@
M<V%V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<P!4:&5R92!W97)E(&YO
M(&UE;6]S('1O(&5X<&]R="X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6
M;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT
M86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E
M>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P
M<&]R=&5D+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T
M+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@
M8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F
M;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S
M92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N
M8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG
M`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE
M`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E
M`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@;6%N>2!I;G9A;&ED
M(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P`%1O<"!F<F%M
M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U
M92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U
M.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U
M=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!5
M9V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I
M9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@
M(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D
M96QE=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA
M8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O
M(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O
M=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5
M;F1O(&-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D
M92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M
M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)
M<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA
M;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N
M;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O
M;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII
M;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O
M<G1E9"!#;VYT96YT+51Y<&4Z("5S`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5
M<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G
M<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I
M;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R
M<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T
M:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T
M(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N
M`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z
M8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I
M;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@
M9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`
M5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M
M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`
M5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``
M5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T
M:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E
M`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S
M=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E
M<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L
M:6$@;6%P`%=H:6-H($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E
M9"!T;S\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N
M:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED
M=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E
M9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU
M;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@
M;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A
M9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9
M`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U
M(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W
M:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!N;W1E<RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AE(&YO=&5P860@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N
M`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO
M=7(@9&5F875L="!N;W1E<&%D.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I
M;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E
M<P!9;W5R(&YO=&5P861S.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R
M<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI
M9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D
M(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E
M<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"86-K('1O($YO=&5P860`7T-,
M20!?0V%T96=O<GD`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2;W<`7T5D
M:70`7T9I<G-T($QI;F4`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?26UP;W)T+T5X<&]R=`!?3&ES="!.;W1E<P!?3&]G(&EN`%],;V<@
M;W5T`%]-;V1I9GD@3&EN:RXN+@!?37D@3F]T97!A9',`7TYE=R!.;W1E`%]/
M<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK+BXN`%]3
M96%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R
M97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K
M(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M
M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R
M`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R
M(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@:6UP;&5M
M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`&YO=&5S+F-S=@!P
M97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@
M:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D
M:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E
M;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E
M<B!S96QE8W0`=D-A<F0`=DYO=&4`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)
M9"U697)S:6]N.B!-;F5M;R`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V
M+3`S+3`V(#$R.C0W*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-CHT.2LP,C`P"DQA<W0M5')A;G-L871O<CH@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*3&%N9W5A9V4M5&5A;3H@1V5R;6%N(#QD979`:&]R
M9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET"@`@*'9O<B`E<R!486=E;BD`("A:=6=R:69F<W1A<W1E
M("5S*0`@*&EN("5S(%1A9V5N*0`@*&AE=71E*0`@*&UO<F=E;BD`("AG97-T
M97)N*0`@;6ET(``B)7,B(&ES="!K96EN(%9E<GIE:6-H;FES+@`B)7,B(&ES
M="!K96EN92!G_&QT:6=E($%U<W=A:&PN`"(E<R(@:7-T(&EN(&1E<B!(;W)D
M92!296=I<W1R>2!N:6-H="!K;VYF:6=U<FEE<G0N`$1E<B!"875M+5)E;F1E
M<F5R(&;\<B`B)7,B('=U<F1E(&YI8VAT(&=E9G5N9&5N+@`B)7,B('=U<F1E
M('IU;2!'<G5P<&5N<WES=&5M(&AI;GIU9V5F_&=T+@`B)7,B('=U<F1E('IU
M;2!296-H=&5S>7-T96T@:&EN>G5G96;\9W0N`"(E<R(@=W5R9&4@;FEC:'0@
M97)S=&5L;'0Z("5S+@`E+C)F34(@*"4S)"XR9B4E*2!V;VX@)3(D+C)F34(@
M97)L875B=&5N('9E<F)R875C:'0`)60@)7,@=6YD("5S`$EN("5D(%1A9V5N
M('=I<F0@26AR(%!A<W-W;W)T('5N9_QL=&EG+@`E9"!.;W1I>F5N`"5D+51A
M9V4M5F]R:&5R<V%G90`E<R`M($AI;G=E:7,`)7,@1FEN9V5R86)D<G5C:P`E
M<R!+0@`E<R!787)T=6YG<V%R8F5I=&5N("T@0F5S=.1T:6=U;F<`)7,M2V]N
M9FEG=7)A=&EO;@`E<R!296=I<W1R:65R=6YG`"5S($YU='IU;F=S8F5D:6YG
M=6YG96X`)7,@97AI<W1I97)T(&)E<F5I=',N`"5S(&UI="`E<R`E<P`E<R!:
M96EC:&5N`$1I92`E<RU$871E:2!W=7)D92!E<F9O;&=R96EC:"!I;7!O<G1I
M97)T`"5S('=I<F0@9&EE(%=A<G1U;F=S87)B96ET96X@9'5R8VAF_&AR96XL
M(&1I92!U;G1E;B!M87)K:65R="!S:6YD+B!-87)K:65R96X@4VEE(&%L;&4@
M075F9V%B96XL(&1I92!J971Z="!D=7)C:&=E9OQH<G0@=V5R9&5N('-O;&QE
M;BX`)7,@:7-T(&YO='=E;F1I9P`E<R!-:6YU=&5N`"5S(&YI8VAT(&=E9G5N
M9&5N+@`E<R!B:7,@)7,@=F]N("5S`"5S<R!!9')E<W-B=6-H`"5S<R!+86QE
M;F1E<@`E<W,@3F]T:7IB;&]C:P`E<W,@075F9V%B96YL:7-T90`E<SH@)7,`
M)7,Z($1I97-E($YA8VAR:6-H="!S=&%M;70@=6YT97(@56US=.1N9&5N(&YI
M8VAT('9O;B!D96T@86YG96=E8F5N96X@06)S96YD97(N($9O;&=E;B!3:64@
M:V5I;F5N($QI;FMS(&EN(&1I97-E<B!.86-H<FEC:'0@=6YD(&C\=&5N(%-I
M92!S:6-H(&1A=F]R+"!D96T@06)S96YD97(@<&5R<_9N;&EC:&4@1&%T96X@
M<')E:7-Z=6=E8F5N+@`L(&+V:6<@`"P@8FEG("5S("5S`"P@<V-H=V%N:V5N
M9"!V;VX@)7,@8FES("5S`"TM($%U<W?D:&QE;B`M+0`Q($YO=&EZ`#$R+5-T
M=6YD96XM1F]R;6%T`#(T+5-T=6YD96XM1F]R;6%T`#(T(%-T=6YD96X`/%IU
M<OQC:P!&<B!D:65S96X@0FQO8VL@=VER9"!E:6YE($1A=&5N8F%N:R!B96YT
M:6=T+@!%:6X@<V-H=V5R97(@1F5H;&5R(&ES="!A=69G971R971E;CH`16EN
M(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L('=I<F0@9OQR(&1I92!697)S
M8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+@!%:6X@]F9F
M96YT;&EC:&5R(%!'4"U38VAL_'-S96P@=VER9"!F_'(@9&EE(-QB97)P<OQF
M=6YG(&5I;F5R('5N=&5R>F5I8VAN971E;B!.86-H<FEC:'0@8F5N]G1I9W0N
M`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!01U`M4V-H;/QS
M<V5L('-O=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D:64@16YT<V-H;/QS
M<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI
M8VAE<B!U;F0@96EN('!R:79A=&5R(%!'4"U38VAL_'-S96P@<V]W:64@96EN
M(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.
M86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P
M<FEV871E<B!3+TU)344M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R="!W
M:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B
M96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%,O
M34E-12U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I
M92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I
M;B#V9F9E;G1L:6-H97(@4R]-24U%+5-C:&S\<W-E;"!W:7)D(&;\<B!D:64@
M5F5R<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`5F]R
M;6ET=&%G<R!7;VQK96X`5F]R;6ET=&%G<R!L96EC:'1E<B!296=E;@!6;W)M
M:71T86=S(%)E9V5N`%9O<FUI='1A9W,@4V-H875E<@!6;W)M:71T86=S(%-C
M:&YE97-C:&%U97(`04TO4$T`05!)($E$`-QB97(@9&EE<V5N($5D:71O<@!)
M;F9O+BXN`$%B<V]L=70@56YT96X`06)S;VQU="!-:71T90!:=6=R:69F('9E
M<G=E:6=E<G0@8F5I;2!!;FQE9V5N(&1E<R!61E,M5F5R>F5I8VAN:7-S97,N
M`%IU9W)I9F8@=F5R=V5I9V5R="!B96EM($%N;&5G96X@9&5R(%9&4RU$871E
M:2X`6G5G<FEF9B!V97)W96EG97)T(&)E:6T@3/9S8VAE;B!D97(@3F]T:7HN
M`%IU9W)I9F8@=F5R=V5I9V5R="!B96EM(%9E<G-C:&EE8F5N(&1E<B!.;W1I
M>BX`3F]T:7H@:V]N;G1E(&YI8VAT(&YA8V@@)7,@9V5S<&5I8VAE<G0@=V5R
M9&5N+B!:=6=R:69F('9E<G=E:6=E<G0N`%IU9W)I9F8@=F5R=V5I9V5R="!B
M96EM(%-P96EC:&5R;B!D97(@3F]T:7HZ("5S`$MO;G1O:6YF;W)M871I;VYE
M;@!+;VYT;W!A<W-W;W)T`$MO;G1O(&5I;F=E9G)O<F5N+@!"=6-H:&%L='5N
M9P!(:6YZ=6;\9V5N`$YE=64@56YT97)G<G5P<&4@:&EN>G5F_&=E;@!.975E
M(%5N=&5R<F5C:'1E(&AI;GIU9OQG96X`2&EE<B!H:6YZ=6;\9V5N.@!.975E
M($=R=7!P92!H:6YZ=6;\9V5N`$YE=64@4F5C:'1E(&AI;GIU9OQG96X`56YT
M97)G<G5P<&4@>G4@(B5S(B!H:6YZ=6;\9V5N`%5N=&5R<F5C:'1E('IU("(E
M<R(@:&EN>G5F_&=E;@!&_&=E;B!3:64@96EN96X@;F5U96X@0F5N=71Z97(@
M:&EN>G4Z`$MA=&5G;W)I92!H:6YZ=6;\9V5N`%-P86QT92!H:6YZ=6;\9V5N
M`$YE=64@36ET9VQI961E<B!H:6YZ=6;\9V5N`%!A87(@:&EN>G5F_&=E;@!$
M87,@)7,M365N_"!Z=7(@36]Z:6QL82!3:61E8F%R(&AI;GIU9OQG96X`6G5M
M($%D<F5S<V)U8V@@:&EN>G5F_&=E;CH`6G4@;65I;F5M($%D<F5S<V)U8V@@
M:&EN>G5F_&=E;@!"96YU='IE<B!H:6YZ=6;\9V5N`"(E<R(@=W5R9&4@>G5M
M(%-Y<W1E;2!H:6YZ=6=E9OQG="P@86)E<B!D:64@>G5SY'1Z;&EC:&5N(%)E
M9VES=')I97)U;F=S:6YF;W)M871I;VYE;B!K;VYN=&5N(&YI8VAT(&=E<W!E
M:6-H97)T('=E<F1E;CH@)7,N`"(E<R(@=W5R9&4@>G5M(%-Y<W1E;2!H:6YZ
M=6=E9OQG="X@4VEE(&OV;FYE;B!S:6-H(&IE='IT(&%N;65L9&5N+@!%:6YE
M(&YE=64@3F]T:7H@:&EN>G5F_&=E;@!$87,@2&EN>G5F_&=E;B!V;VX@0F5N
M=71Z97)N(&ES="!N:6-H="!M]F=L:6-H+@!!9')E<W-E`$%D<F5S<V)U8V@`
M5F5R=V%L=&5N("T@4F5C:'1E(&;\<B!A;F1E<F4@0F5N=71Z97(@9F5S=&QE
M9V5N`$%D;6EN:7-T<F%T:6]N`%=E<F)U;F<`069G:&%N:7-T86X`06QB86YI
M96X`06QG97)I96X`4W!I='IN86UE`$%U<W)I8VAT=6YG`$%U<W)I8VAT=6YG
M.@!!;&QE`$%N9V5M96QD971E($)E;G5T>F5R`$%L;&4@1W)U<'!E;@!!;&QE
M(%)E8VAT90!!;&QE('9I97(@4V5I=&5N`$UE:')E<F4@061R97-S96X@97)L
M875B96X`1F]R;6%T('9O;B!N=6UM97)I97)T96X@3&ES=&5N(.1N9&5R;C\`
M17AI<W1I97)T(&)E<F5I=',`06QT97)N871I=F4@24U34"U!;FUE;&1U;F<`
M06QT97)N871I=F5S($E-4U`M4&%S<W=O<G0`06QT97)N871I=F5R($E-4U`M
M0F5N=71Z97)N86UE`$%L=&5R;F%T:79E($5M86EL861R97-S90!!;'1E<FYA
M=&EV92!6;W)L86=E;@!!;'1E<FYA=&EV97(@5&5X=#H`06UE<FEK86YI<V-H
M+5-A;6]A`$5S('=U<F1E(&5I;B!U;F?\;'1I9V5R(%=E<G0@86YG96=E8F5N
M+@!%:6X@=6YB96MA;FYT97(@1F5H;&5R(&ES="!A=69G971R971E;BX`06YD
M;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM97(@4')O>'D`06YT=V]R=`!!
M;G1A<FMT:7,`06YT:6=U82!U;F0@0F%R8G5D80!!;G=E;F1U;F<`06YW96YD
M=6YG<VQI<W1E`$%N=V5N9'5N9R!I<W0@8F5R96ET+@!!=68@56YT97)R96-H
M=&4@86YW96YD96X`0F5S=.1T:6=E;@!5;F=E9N1H<F4@1W+VWV4`07!R:6P`
M07)A8FES8V@@*%=I;F1O=W,M,3(U-BD`07)C:&EV9W+VWV4`07)C:&EV;F%M
M90!3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I92!296=I<W1R:65R=6YG
M<V%N9G)A9V4@=F]N("5S(&SV<V-H96X@;?9C:'1E;C\`4VEN9"!3:64@<VEC
M:&5R+"!D87-S(%-I92`B)7,B('5N9"!A;&QE(%5N=&5R9W)U<'!E;B!L]G-C
M:&5N(&WV8VAT96X_`$%R9V5N=&EN:65N`$%R;65N:65N`$%R;65N:7-C:"`H
M05)-4T-)22TX*0!+=6YS=`!!<G5B80!!=69S=&5I9V5N9`!!<V-E;G-I;VXM
M26YS96QN`$%30TE)+4MU;G-T`$%S:65N+U!A>FEF:7-C:&4@4F5G:6]N`$%N
M<W1E:&5N9&4@5V%R='5N9W-A<F)E:71E;B!B97-TY'1I9V5N(&QA<W-E;C\`
M6G5O<F1N=6YG<V9E;&1E<@!%<R!W=7)D92!V97)S=6-H="P@96EN92!N:6-H
M="!E>&ES=&EE<F5N9&4@1W)U<'!E('IU(&SV<V-H96XN`$5S('=U<F1E('9E
M<G-U8VAT+"!E:6X@;FEC:'0@97AI<W1I97)E;F1E<R!296-H="!Z=2!L]G-C
M:&5N+@!%<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T:65R96YD
M97,@4F5C:'0@>G4@8F5A<F)E:71E;BX`17,@=W5R9&4@=F5R<W5C:'0L(&5I
M;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E87)B96ET96XN`$%T
M=')I8G5T90!!=6=U<W0`075S=')A;&EE;@#6<W1E<G)E:6-H`$%U=&A?8WER
M<W%L.B!$:64@8F5N]G1I9W1E($E-05`M17)W96ET97)U;F<@=W5R9&4@;FEC
M:'0@9V5F=6YD96XN`$%U=&A?8WER=7,Z($1A<R!"86-K96YD(&AA="!N:6-H
M="!D:64@8F5N]G1I9W1E;B!&Y&AI9VME:71E;BX`075T:%]C>7)U<SH@1&EE
M(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N
M9&5N+@!!=71H7V9T<#H@1&EE(&)E;O9T:6=T92!&5%`M17)W96ET97)U;F<@
M=W5R9&4@;FEC:'0@9V5F=6YD96XN($MO;7!I;&EE<F5N(%-I92!02%`@;6ET
M(&1E;2`M+65N86)L92UF='`@4&%R86UE=&5R+@!!=71H7VEM87`Z($1I92!B
M96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E
M;BX`075T:%]K<F(U.B!$:64@8F5N]G1I9W1E($ME<F)E<F]S+45R=V5I=&5R
M=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7VQD87`Z($1A<R!(:6YZ
M=6;\9V5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@06-T:79E($1I<F5C=&]R
M>2!N:6-H="!U;G1E<G-T_'1Z=`!!=71H7VQD87`Z($1A<R!,]G-C:&5N('9O
M;B!"96YU='IE<FX@=VER9"!F_'(@06-T:79E($1I<F5C=&]R>2!N:6-H="!U
M;G1E<G-T_'1Z=`!!=71H7VQD87`Z($1I92!B96[V=&EG=&4@3$1!4"U%<G=E
M:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]L9&%P.B!$97(@
M0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&AI;GIU9V5F_&=T('=E<F1E;BX@
M365L9'5N9R!D97,@4V5R=F5R<SH@`$%U=&A?;&1A<#H@0F5N=71Z97(@)7,@
M:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;@!!=71H7VQD87`Z($)E;G5T
M>F5R("5S(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N`$%U=&A?
M;&1A<#H@1&%S($%K='5A;&ES:65R96X@=F]N($)E;G5T>F5R;B!W:7)D(&;\
M<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT('5N=&5R<W3\='IT+@!!=71H7VUC
M86PZ($1I92!B96[V=&EG=&4@34-!3"U%<G=E:71E<G5N9R!W=7)D92!N:6-H
M="!G969U;F1E;BX`075T:%]S;6)A=71H.B!$:64@8F5N]G1I9W1E(%-A;6)A
M+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!;FUE;&1U;F<@
M8F5I;2!)34%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`075T:&5N=&EF:7II
M97)U;F<@9F5H;&=E<V-H;&%G96X`06YM96QD=6YG(&9E:&QG97-C:&QA9V5N
M+B`E<P!$:64@075T:&5N=&EF:7II97)U;F<@=W5R9&4@=F]M(%)!1$E54RU3
M97)V97(@>G5R_&-K9V5W:65S96XN`$%N;65L9'5N9R!B96EM($944"U397)V
M97(@9F5H;&=E<V-H;&%G96XN`$%N;65L9'5N9R!B96EM(%--0BU397)V97(@
M9F5H;&=E<V-H;&%G96XN`%9E<F;\9V)A<F4@2V%T96=O<FEE;CH`5F5R9OQG
M8F%R92!&96QD97(Z`$%S97)B86ED<V-H86X`0D]&2"U!=7-R961E;@!:=7+\
M8VL@>G5M($YO=&EZ8FQO8VL`6G5R_&-K('IU<B!.;W1I>F)L;V-K=F5R=V%L
M='5N9P!(:6YT97)G<G5N9`!(:6YT97)G<G5N9&9A<F)E`$9A;'-C:&5S($ME
M<F)E<F]S+5!A<W-W;W)T+@!&86QS8VAE<B!+97)B97)O<RU"96YU='IE<FYA
M;64N`$)A:&%M87,`0F%H<F5I;@!"86QT:7-C:"`H25-/+3@X-3DM,3,I`$)A
M;F=L861E<V-H`$)A<F)A9&]S`$)A<VES+4)I;&1E<BU697)Z96EC:&YI<R`B
M)7,B(&YI8VAT(&=E9G5N9&5N+@!'<G5N9&QI;FEE`%=E:=]R=6QA;F0`0F5L
M9VEE;@!"96QI>F4`0F5N:6X`0F5R;75D87,`0FAU=&%N`$=E8G5R='-T86<`
M0FQO8VL@(B5S(B!D97(@06YW96YD=6YG("(E<R(@;FEC:'0@9V5F=6YD96XN
M`$)L;V-K96EN<W1E;&QU;F=E;@!";&]C:W1Y<`!&971T`$)O;&EV:65N`$QE
M<V5Z96EC:&5N`%)A;F0`4F%H;65N9&EC:V4Z`%+D;F1E<@!";W-N:65N+4AE
M<GIE9V]W:6YA`$)E:61E<P!";W1S=V%N80!5;G1E;@!";W5V971I;G-E;`!"
M<F%S:6QI96X`0G)I=&ES8VAE<R!497)R:71O<FEU;2!I;2!);F1I<V-H96X@
M3WIE86X`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:65N`%5N;G5M;65R:65R
M=&4@3&ES=&4`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES
M=')I8G5T:6]N<W-T96QL90!#4U8`7UIE;&QE;F5I9V5N<V-H869T96XN+BX`
M1&5R(%IW:7-C:&5N<W!E:6-H97(@:V]N;G1E(&YI8VAT(&EN:71I86QI<VEE
M<G0@=V5R9&5N+@!+86QE;F1E<@!7:6YD<W1I;&P`2V%M8F]D<V-H80!+86UE
M<G5N`%!A<W-W;W)T(&MA;FX@;FEC:'0@875T;VUA=&ES8V@@>G5R_&-K9V5S
M971Z="!W97)D96XL(&)I='1E('=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!!
M9&UI;FES=')A=&]R+@!$:64@1&%T96D@(B5S(B!K86YN(&YI8VAT(&=E<W!E
M:6-H97)T('=E<F1E;@!%>'1E<FYE(%-E<W-I;VXM2&%N9&QE<B!K]FYN96X@
M;FEC:'0@861M:6YI<W1R:65R="!W97)D96XN`%9E<F)I;F1U;F<@>G5M($E-
M05`M4V5R=F5R(&MA;FX@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N.B`E<P!$
M:64@1&%T96D@(B5S(B!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX`2V%N
M861A`$%B8G)E8VAE;@!0<F]B;&5M8F5R:6-H="!A8F)R96-H96X`1&EE($1A
M=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`2V5I;B!T
M96UP;W+D<F5S(%9E<GIE:6-H;FES(&=E9G5N9&5N+@!&;W)T<V5T>G5N9R!O
M:&YE(")T87)G971&:6QE(BU087)A;65T97(@;FEC:'0@;?9G;&EC:"X`1&%S
M(%9E<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E
M;BX`2V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;BP@)60@2VEN9&5R(&5X
M:7-T:65R96XN`%5M<V]R=&EE<F5N(&YI8VAT(&WV9VQI8V@N($1I92!!;GIA
M:&P@9&5R($5I;G1RY&=E+"!D:64@=6US;W)T:65R="!W97)D96X@<V]L;&5N
M+"!S=&EM;70@;FEC:'0@;6ET(&1E<B!!;GIA:&P@9&5R(&=E<W!E:6-H97)T
M96X@16EN='+D9V4@_&)E<F5I;BX`1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC
M:'0@86X@9&EE(&%N9V5G96)E($YU;6UE<B!W96ET97)G96QE:71E="!W97)D
M96XN`$MA<"!697)D90#<8F5R<V-H<FEF=`!0<F]V:61E<@!+871E9V]R:65N
M('5N9"!"97-C:')I9G1U;F=E;@!+871E9V]R:64`0V%Y;6%N+4EN<V5L;@!-
M;V)I;'1E;&5F;VX`6F5L;&5N96EG96YS8VAA9G1E;@!);FYE;F%B<W1A;F0Z
M`%IE;&QE;F5I9V5N<V-H869T96X`6F5L;&5N86)S=&%N9#H`36]B:6QT96QE
M9F]N`$ME;'1I<V-H("A)4T\M.#@U.2TQ-"D`6F5N=')I97)T`%IE;G1R86QA
M9G)I:V%N:7-C:&4@4F5P=6)L:6L`36ET=&5L975R;W#D:7-C:"`H25-/+3@X
M-3DM,BD`6F5R=&EF:6MA=&1E=&%I;',`6F5R=&EF:6MA=&)E<VET>F5R`%IE
M<G1I9FEK871R:6-H=&QI;FEE;@!4<V-H860`Q&YD97)N`,1N9&5R;B!3:64@
M26AR(%!A<W-W;W)T`,1N9&5R;B!3:64@9&5N($YA;65N(&]D97(@9&EE($5M
M86EL861R97-S92P@9&EE(&1I92!%;7!FY&YG97(@26AR97(@16UA:6QS('-E
M:&5N+"!W96YN(&1I97-E($EH<F4@16UA:6QS(&QE<V5N(&]D97(@9&%R875F
M(&%N=V]R=&5N+@#$;F1E<FX@4VEE(&1I92!3;W)T:65R<F5I:&5N9F]L9V4@
M=6YD(&%N9&5R92!!;GIE:6=E96EN<W1E;&QU;F=E;BX`1&%S(,1N9&5R;B!)
M:')E<R!087-S=V]R=',@=VER9"!V;VX@9&EE<V5M(%-Y<W1E;2!Z=7(@6F5I
M="!N:6-H="!U;G1E<G-T_'1Z="X@0FET=&4@=V5N9&5N(%-I92!S:6-H(&%N
M($EH<F5N($%D;6EN:7-T<F%T;W(N`%IE:6-H96X`3&EN:R#\8F5R7W!R_&9E
M;BXN+@!#:&EL90!#:&EN80!#:&EN97-I<V-H('9E<F5I;F9A8VAT("A'0C(S
M,3(I`$-H:6YE<VES8V@@=')A9&ET:6]N96QL("A":6<U*0!!;G=E;F1U;F<@
M875S=^1H;&5N.@!7Y&AL96X@4VEE(&5I;B!087-S=V]R=`!7Y&AL96X@4VEE
M(&5I;F5N($)E;G5T>F5R;F%M96X`3&5G96X@4VEE(&9E<W0L('=I92!D87,@
M1&%T=6T@86YG97IE:6=T('=E<F1E;B!S;VQL.@!,:7-T96YF;W)M870@875S
M=^1H;&5N("AF_'(@;G5M;65R:65R=&4@3&ES=&5N*0!7Y&AL96X@4VEE(&1I
M92!.;W1I>F5N:V%T96=O<FEE;B!A=7,L(&1I92!I;2!0;W)T86P@86YG97IE
M:6=T('=E<F1E;B!S;VQL96XN`%?D:&QE;B!3:64@26AR96X@4W1A;F1A<F0M
M3F]T:7IB;&]C:R!A=7,N`%=E:6AN86-H='-I;G-E;`!+;&%S<V5N9&5F:6YI
M=&EO;B!F_'(@)7,@;FEC:'0@9V5F=6YD96XN`$AE:71E<@!&;W)M=6QA<B!Z
M=7+\8VMS971Z96X`35,M3V9F:6-E+51A9W,@96YT9F5R;F5N`$%B9G)A9V4@
M>G5R_&-K<V5T>F5N`$)E;G5T>F5R9&%T96X@;/9S8VAE;CH@)7,`0F5N=71Z
M97)D871E;B!L]G-C:&5N`$)E;G5T>F5R9&%T96X@;/9S8VAE;@!3<.1T97(@
M075F:VQA<F5N9`!&;W)T9F%H<F5N`$-L:6-K871E;&P@<&5R($A45%``1F5N
M<W1E<B!S8VAL:67?96X`5V]L:V5N`$9R_&@@5V]L:V5N`$)E=_9L:W0`2V]K
M;W-I;G-E;&X`365N_"!E:6YF86AR96X`6G5S86UM96YHY&YG96YD92!286AM
M96X`2V]L=6UB:65N`$9A<F)E`$9A<F)A=7-W86AL`$9A<F)W86AL`%-P86QT
M96XZ`%-P86QT96[\8F5R<V-H<FEF=&5N`$-O;6EC<P!"969E:&P`0F5F96AL
M<WIE:6QE`$MO;6UE;G1A<@!%:6YD975T:6=E<B!.86UE`$MO;6]R96X`1FER
M;6$`0V]M<'5T97(`0F5D:6YG=6YG96X`0F5D:6YG=6YG96X`2V]N9FEG=7)A
M=&EO;G-U;G1E<G-C:&EE9&4`2V]N9FEG=7)A=&EO;B!D97(@4WEN8VAR;VYI
M>F%T:6]N(&UI="!01$%S+"!3;6%R='!H;VYE<R!U;F0@3W5T;&]O:RX`1&EE
M($MO;F9I9W5R871I;VX@;75S<R!A:W1U86QI<VEE<G0@=V5R9&5N+@`E<R!K
M;VYF:6=U<FEE<F5N`%!A<W-W;W)T(&)E<W3D=&EG96X`2V]N9V\`1&5M;VMR
M871I<V-H92!297!U8FQI8R!+;VYG;P!697)B:6YD=6YG(&9E:&QG97-C:&QA
M9V5N+@!697)B:6YD=6YG(&9E:&QG97-C:&QA9V5N.B``5F5R8FEN9'5N9R!Z
M=6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E;'-E<G9E<B!W=7)D92!A8F=E=VEE
M<V5N+@!697)B:6YD=6YG('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R
M=F5R('=U<F1E(&%B9V5W:65S96XN($=R=6YD.B`E<R`H)7,I`%9E<F)I;F1U
M;F<@>G5M($944"U397)V97(@9F5H;&=E<V-H;&%G96X`2V]N=&%K=&4`1&EE
M($MO;G1A:W1E('=U<F1E;B!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B=6-H
M(&AI;GIU9V5F_&=T+@!);FAA;'1S='EP(&1E<B!K;VUP<FEM:65R=&5N($1A
M=&5I.B``26YH86QT('9O;B`B)7,B`%=E:71E<@!#;V]K+4EN<V5L;@!#;V]K
M:64`2V]P:65R96X`2V]P:65R96X@9F5H;&=E<V-H;&%G96XZ("5S`$%U<W=A
M:&P@:V]P:65R96X`2V]S=&5N+4E$`$-O<W1A(%)I8V$`16QF96YB96EN:_QS
M=&4`1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!V97)S8VAL
M_'-S96QT('=E<F1E;CH@`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI
M="!01U`@=6YT97)Z96EC:&YE="!W97)D96XZ(`!$:64@3F%C:')I8VAT(&MO
M;FYT92!N:6-H="!M:70@4R]-24U%('9E<G-C:&S\<W-E;'0@=V5R9&5N+@!$
M:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@4R]-24U%('5N=&5R>F5I
M8VAN970@=V5R9&5N+@!+;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R
M="!W97)D96XN("5S`%9E<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&9E:&QG
M97-C:&QA9V5N+@!+;VYT;W-T86YD(&MO;FYT92!N:6-H="#\8F5R<'+\9G0@
M=V5R9&5N+B`E<P!697)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!F96AL9V5S
M8VAL86=E;BX`1E10+59E<F)I;F1U;F<@>G5M(%-E<G9E<B`B)7,B(&MO;FYT
M92!N:6-H="!H97)G97-T96QL="!W97)D96XZ("5S`%9E<G1E:6QE<FQI<W1E
M(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96XN("5S`%!'4"U$871E;B!K
M;VYN=&5N(&YI8VAT(&5N='-C:&S\<W-E;'0@=V5R9&5N.B``4R]-24U%+41A
M=&5N(&MO;FYT96X@;FEC:'0@96YT<V-H;/QS<V5L="!W97)D96XN`$MO;G1A
M:W0@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX@)7,`5F5R=&5I;&5R
M;&ES=&4@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX@)7,`1&%S($%K
M='5A;&ES:65R=6YG<W-K<FEP="`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H
M="!W97)D96XN`$1I92!%;6%I;&%D<F5S<V4@9&5S($5M<&;D;F=E<G,@:V]N
M;G1E(&YI8VAT(&5R;6ET=&5L="!W97)D96XN`$1A<R!!9')E<W-B=6-H(&MO
M;FYT92!N:6-H="!K;VUP;&5T="!G96QE<V5N('=E<F1E;BX`5F5R=&5I;&5R
M;&ES=&4@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<P!,:7-T
M92!D97(@5F5R=&5I;&5R;&ES=&5N(&MO;FYT92!N:6-H="!A=7-G96QE<V5N
M('=E<F1E;BX`1&EE(%-T<F%T96=I92`B)7,B(&MO;FYT92!N:6-H="!G96QA
M9&5N('=E<F1E;BX`1&%S(%9E<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT
M(&%N9V5L96=T('=E<F1E;BX`UF9F96YT;&EC:&5R(%-C:&S\<W-E;"!K;VYN
M=&4@;FEC:'0@=F]M(%-C:&S\<W-E;'-E<G9E<B!G96AO;'0@=V5R9&5N+@`B
M)7,B(&MO;FYT92!N:6-H="!Z=6T@4V-H<F5I8F5N(&=E]F9F;F5T('=E<F1E
M;BX`)7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N+@!$87,@36%I;G1E
M;F%N8V5?5&%S:R!-;V1U;"`E<R!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R
M9&5N`%9E<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E
M<F1E;BX`5F5R8FEN9'5N9R!Z=6T@3$1!4"U397)V97(@:V]N;G1E(&YI8VAT
M(&AE<F=E<W1E;&QT('=E<F1E;BX`)7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@
M=V5R9&5N+@!$87,@4&%S<W=O<G0@9OQR(&1E;B!A;F=E9V5B96YE;B!"96YU
M='IE<B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S971Z="!W97)D96XL('=E:6P@
M96EN:6=E($%N9V%B96X@;FEC:'0@<FEC:'1I9R!W87)E;BX@5F5R<W5C:&5N
M(%-I92!E<R!E<FYE=70@;V1E<B!W96YD96X@4VEE('-I8V@@86X@26AR96X@
M061M:6YI<W1R871O<BP@=V5N;B!3:64@=V5I=&5R92!(:6QF92!B96[V=&EG
M96XN`$%#3"!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96X`1&%S($%D<F5S
M<V)U8V@@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N+B`E<P!697)T96EL
M97)L:7-T92!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN("5S`%9E
M<G1E:6QE<FQI<W1E;B!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN
M("5S`$1I92!397)V97)FY&AI9VME:71E;B!K;VYN=&5N(&YI8VAT(&%U<V=E
M;&5S96X@=V5R9&5N`$MO;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT('IU<OQC
M:V=E<V5T>G0@=V5R9&5N+@!697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H
M="!G96SV<V-H="!W97)D96XN`"5S+4MO;F9I9W5R871I;VX@:V]N;G1E(&YI
M8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T
M:6]N(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN`$)A8VMU<"!D
M97(@2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N.B`E<P!$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T(&MO;FYT92!N:6-H
M="!N86-H("(E<R(@9V5S<&5I8VAE<G0@=V5R9&5N+@!"86-K=7`@9&5R($MO
M;F9I9W5R871I;VX@)7,@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E
M;BX`1&EE($MO;F9I9W5R871I;VX@)7,@:V]N;G1E(&YI8VAT(&=E<W!E:6-H
M97)T('=E<F1E;BX@4VEE(&OV;FYE;B!E;G1W961E<B!E:6YE(&1E<B!-]F=L
M:6-H:V5I=&5N('5N=&5R("5S('9E<G=E;F1E;BP@=6T@9&5N($-O9&4@>G4@
M<W!E:6-H97)N+"!O9&5R(&1E;B!U;G1E;G-T96AE;F1E;B!#;V1E(&UA;G5E
M;&P@;F%C:"`E<R!K;W!I97)E;BX`1&5R($Q$05`M4V5R=F5R(&MO;FYT92!N
M:6-H="!D=7)C:'-U8VAT('=E<F1E;BX`(B5S(B!K;VYN=&4@;FEC:'0@9V5L
M]G-C:'0@=V5R9&5N+@!$97(@2V]N=&%K="!K;VYN=&4@;FEC:'0@9V5S<&5I
M8VAE<G0@=V5R9&5N+B`E<P!697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@
M86MT=6%L:7-I97)T('=E<F1E;BX@)7,`1&EE($MO;F9I9W5R871I;VX@9OQR
M("(E<R(@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;CH@)7,`1&EE
M($UO>FEL;&$@4VED96)A<B!K;VYN=&4@;FEC:'0@9V5F=6YD96X@=V5R9&5N
M+B!3=&5L;&5N(%-I92!S:6-H97(L(&1A<W,@9&EE(%-I9&5B87(@9V7V9F9N
M970@:7-T+@!$96T@0F5N=71Z97(@(B5S(B!K;VYN=&5N(&1I92!F;VQG96YD
M92!296-H=&4@9OQR(&1E;B!/<F1N97(@(B5S(B!N:6-H="!Z=6=E=VEE<V5N
M('=E<F1E;CH@)7,`1V5ZY&AL=&5R(%1E>'0`3&%N9`!+=7)S90!%<G-T96QL
M96X`3&EN:R!E<G-T96QL96X`3F5U92!)9&5N=&ETY'0@86YL96=E;@!5;G1E
M<F]R9&YE<B!E<G-T96QL96X`17)S=&5L;'0`17)S=&5L;&5R<F5C:'1E`$MR
M961I=&MA<G1E;FYU;6UE<@!+<F]A=&EE;@!+=6)A`$%K='5E;&QE(#0@4&AA
M<V5N`$%K='5E;&QE(%-E<W-I;VYS`$%K='5E;&QE(%IE:70`06MT=65L;&4@
M55),(&ES=`!!:W1U96QL92!"96YU='IE<@!!:W1U96QL97,@5V5T=&5R`$1E
M<GIE:71I9V4@0F5D:6YG=6YG96XZ(`!!:W1U96QL97(@4W1I;`!,96=E;B!3
M:64@9F5S="P@=V5L8VAE($%U9F=A8F5N(&YA8V@@9&5R($%N;65L9'5N9R!B
M96D@)7,@97)L961I9W0@=V5R9&5N('-O;&QE;BX`075S<V-H;F5I9&5N`$%U
M<W=A:&P@875S<V-H;F5I9&5N`%IY<&5R;@!+>7)I;&QI<V-H("A+3TDX+5(I
M`$MY<FEL;&ES8V@@*%=I;F1O=W,M,3(U,2D`2WER:6QL:7-C:"]5:W)A:6YI
M<V-H("A+3TDX+54I`%1S8VAE8VAI<V-H92!297!U8FQI:P!45`!$4TX@*'-I
M96AE(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`5.1G;&EC:`!$871A5')E92!"<F]W
M<V5R`$1A=&5N8F%N:V%B9G)A9V4`1&%T=6T`16UP9F%N9W-D871U;0!$871U
M;7-A=7-W86AL`%1A9P!3<&%L=&4@7VSV<V-H96X`1&5Z96UB97(`6F%H;&5N
M`$5I;GIU9R!V97)R:6YG97)N`%-T86YD87)D`%-T86YD87)D9F%R8F4`4W1A
M;F1A<F1I9&5N=&ETY'0`4W1A;F1A<F0M3F]T:7IB;&]C:P!3=&%N9&%R9'-H
M96QL`%-O<G1I97)R96EH96YF;VQG93H`4V]R=&EE<G)I8VAT=6YG.@!$969I
M;FET:6]N96X`3/9S8VAE;@!:96QL92!L]G-C:&5N`$SV<V-H8F5S=.1T:6=U
M;F<`1W)U<'!E(&SV<V-H96X`3&]G(&SV<V-H96X`4F5C:'1E(&SV<V-H96X`
M3F%C:')I8VAT96X@;/9S8VAE;B!U;F0@96YT9F5R;F5N`%9E<FAA;'1E;B!B
M96EM($SV<V-H96XN`%IE;&QE(&SV<V-H96X`4W!A;'1E(&SV<V-H96X`0F5S
M=&5H96YD92!A;'1E<FYA=&EV92!6;W)L86=E(&SV<V-H96X`3F%C:')I8VAT
M96X@;/9S8VAE;@!296-H=&4@9OQR("(E<R(@;/9S8VAE;@!296-H=&4@9OQR
M("(E<R(@=6YD(&%L;&4@56YT97)R96-H=&4@;/9S8VAE;C\`6F5I;&4@;/9S
M8VAE;@!!=7-G97?D:&QT92!)9&5N=&ETY'0@;/9S8VAE;@!5;G1E<F]R9&YE
M<B!L]G-C:&5N`$1I92!A:W1U96QL92!3<&%L=&4@;/9S8VAE;@!$:64@86MT
M=65L;&4@6F5I;&4@;/9S8VAE;@!$:65S92!.;W1I>B!L]G-C:&5N`$1A<R!!
M:W1U86QI<VEE<G5N9W-S:W)I<'0@(B5S(B!W=7)D92!G96SV<V-H="X`075S
M;&EE9F5R=6YG<WIE:70`1.1N96UA<FL`06)S=&5I9V5N9`!"97-C:')E:6)E
M;B!3:64@9&%S(%!R;V)L96T`0F5S8VAR96EB=6YG`$)E<V-H<F5I8G5N9SH`
M1&5T86EL<R`H875C:"!I;B!(;W)D97,@3&]G9&%T96DI.@!$971A:6QS('=U
M<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET9V5L;V=G="X`16YT=VEC
M:VQU;F<`5&%U<'5N:W0`5&%U<'5N:W0@9&5R(&QE='IT96X@4W1U;F1E.B``
M5&%U<'5N:W0Z(`!6;VX@;&EN:W,@;F%C:"!R96-H=',`5F]N(')E8VAT<R!N
M86-H(&QI;FMS`%9E<GIE:6-H;FES`%IE:70@:6T@,C0M4W1U;F1E;BU&;W)M
M870@86YZ96EG96X_`$%N>F5I9V4M16EN<W1E;&QU;F=E;@!$971A:6QI97)T
M92!6;W)H97)S86=E(&%N>F5I9V5N`%9O<FAE<G-A9V4@*%1!1BD@86YZ96EG
M96X`06YZ96EG969O<FUA=`!%;7!F86YG<V)E<W3D=&EG=6YG`$1S8VAI8G5T
M:0!.:6-H="!L]G-C:&5N`$=R96EF96X@4VEE(&YI8VAT(&1I<F5K="!A=68@
M;6%I;G1E;F%N8V4N<&AP('IU`$WV8VAT96X@4VEE(&1A<R!,]G-C:&5N('9O
M;B!%:6YT<N1G96X@8F5S=.1T:6=E;C\`16YT:.1L="!D:64@97)S=&4@6F5I
M;&4@9&EE($9E;&1N86UE;C\@5V5N;B!J82P@9&EE<V5S($%U<W=A:&QKY'-T
M8VAE;B!M87)K:65R96XZ`$1O;6EN:6-A`$1O;6EN:6MA;FES8VAE(%)E<'5B
M;&EK`$YO8V@@:V5I;F5N(%IU9V%N9S\@2&EE<B!A;FUE;&1E;BX`2&5R=6YT
M97)L861E;@`E<R!(97)U;G1E<FQA9&5N`$5R>F5U9W1E($MO;F9I9W5R871I
M;VX@86QS(%!(4"U3:W)I<'0@:&5R=6YT97)L861E;BX`075S=V%H;&QI<W1E
M`$1R;V=E;@!%;6%I;`!%;6%I;"UN86-H+5--4RUG871E=V%Y(&;\<B!0<F]V
M:61E<BP@9&EE(&5I;F5N('-O;&-H96X@1&EE;G-T('5N=&5R<W3\='IE;BX`
M1D5(3$52`$5C=6%D;W(`0F5A<F)E:71E;@`B)7,B(&)E87)B96ET96X`0FQO
M8VL@8F5A<F)E:71E;@!'<G5P<&4@8F5A<F)E:71E;@!.;W1I>B!B96%R8F5I
M=&5N`%)E8VAT92!B96%R8F5I=&5N`%)E8VAT92!B96%R8F5I=&5N`%)E8VAT
M92!F_'(@)R5S)R!B96%R8F5I=&5N`$MA=&5G;W)I96X@=6YD($9A<F)E;B!B
M96%R8F5I=&5N`$5I;G-T96QL=6YG96X@8F5A<F)E:71E;B!F_'(Z`%)E8VAT
M92!F_'(@(B5S(B!B96%R8F5I=&5N`%)E8VAT92!F_'(@)7,@8F5A<F)E:71E
M;@!":6QD=6YG`,1G>7!T96X`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%
M;6%I;`!%;6%I;&%D<F5S<V4`1&EE($5M86EL861R97-S96X@;?QS<V5N(&=L
M96EC:"!S96EN+@!%;6%I;"!M:70@0F5S=.1T:6=U;F<`16UA:6PM;F%C:"U3
M35,M1V%T97=A>0!3;6EL97ES`$QE97)E($YO=&EZ`$QE97)E($YA8VAR:6-H
M="X`3&5E<F5S($5R9V5B;FES+@!3=6-H8F5G<FEF9F4@;/9S8VAE;@!%:6YF
M_&=E;B!V;VX@0FEL9&5R;B!A=7,@1F]T;V=A;&5R:65N(&EN(&1E;B!497AT
M(&5R;&%U8F5N/P!+;VYT97AT;65N_"!B96D@4F5C:'1S:VQI8VL@86MT:79I
M97)E;C\`16YD:F%H<@!%9&ET;W(@=F5R9W+VWV5R;@!'96)E;B!3:64@96EN
M92!3:6-H97)H96ET<V9R86=E(&5I;BP@9&EE($EH;F5N(&=E<W1E;&QT('=I
M<F0L('=E;FX@4VEE($EH<B!087-S=V]R="!Z=7+\8VMS971Z96X@;?9C:'1E
M;BP@>BX@0BX@(E=I92!L875T970@9&5R($YA;64@26AR97,@2&%U<W1I97)S
M/R(Z`$AI97(@9&EE($)I;&0M55),(&%N9V5B96X`1V5B96X@<VEE(&1I92!"
M=6-H<W1A8F5N('5N=&5N(&5I;CH`Q'%U871O<FEA;"U'=6EN96$`17)I=')E
M80!&96AL97(`1F5H;&5R(&)E:6T@17)S=&5L;&5N(&5I;F5S($)L;V-K<SH@
M)7,`1F5H;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N<V%N
M:V5R<SH@)7,`1F5H;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T
M:6]N<VQO9W,Z("5S`$9E:&QE<B!B96EM($5R>F5U9V5N(&1E<R!);FAA;'1S
M.B`E<P!&96AL97(@8F5I;2#$;F1E<FX@9&5S(%!A<W-W;W)T<SH@)7,`1F5H
M;&5R(&EN(&1E<B!%;6%I;&YA8VAR:6-H="X`1F5H;&5R(&)E:6T@4V-H<F5I
M8F5N('9O;B`B)7,B+@!%<W1L86YD`,1T:&EO<&EE;@!%=&YI<V-H97,`175R
M;W!A`$%L;&4@,34@36EN=71E;@!!;&QE(#(@36EN=71E;@!!;&QE(#,P(%-E
M:W5N9&5N`$%L;&4@-2!-:6YU=&5N`$)E:2!J961E<B!!;FUE;&1U;F<`06QL
M92!H86QB92!3='5N9&4`06QL92`V,"!396MU;F1E;@!"96ES<&EE;'=E<G1E
M.@!!=7-F_&AR96X`5F5R9W+VWV5R;@!-96[\(&%U<V9A:')E;@`G*2<@97)W
M87)T970`16EN>F5L;F5S(%=O<G0@;V1E<B!3=6-H8F5G<FEF9B!I;B!!;F;\
M:')U;F=S>F5I8VAE;B!E<G=A<G1E=`!697)F86QL<V1A='5M`$5X<&]N96YT
M`$5X<&]R=&EE<F5N`$YO=&EZ96X@97AP;W)T:65R96X`5F]R9&5R9W)U;F1F
M87)B90!(;V-H;&%D96X@9&5R($MO;F9I9W5R871I;VX@<&5R($944`!?5F]L
M;'1E>'0`0F5N=71Z97)E:6YS=&5L;'5N9V5N(&MO;FYT96X@;FEC:'0@9V5L
M861E;B!W97)D96XN`%9E<F)I;F1U;F<@>G5M($Q$05`@4V5R=F5R(&=E<V-H
M96ET97)T+@!697)B:6YD=6YG('IU;2!334(M4V5R=F5R(&=E<V-H96ET97)T
M+@!%<R!K;VYN=&4@:V5I;F4@2V]P:64@=F]N("(E<R(@97)S=&5L;'0@=V5R
M9&5N+@!%<R!K;VYN=&4@;FEC:'0@;F%C:"`B)7,B(&MO<&EE<G0@=V5R9&5N
M+@!!=69B874@96EN96X@;F5U96X@4T%33"U697)B:6YD=6YG(&ES="!F96AL
M9V5S8VAL86=E;BX`17,@:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!V97)S8VAO
M8F5N('=E<F1E;BX`1F5H;&5R(&)E:6T@3&5S96XZ("5S`$AE:71E<@!&86QK
M;&%N9&EN<V5L;@!&87+V97(`4V-H=V5R97(@1F5H;&5R.@!&87@`1F%X90!&
M96)R=6%R`$=E9OQH;'1E(%1E;7!E<F%T=7(`1V5F_&AL=&4@5&5M<&5R871U
M<CH@`%9E<F5I;GIE;'1E(%-C:&%U97(`5F5R96EN>F5L=&4@4V-H;F5E<V-H
M875E<@!&96QD;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="U&;VYT`$9I
M9'-C:&D`1&%T96D`06YZ86AL.B`E<R!$871E:0!!;GIA:&PZ("5S($1A=&5I
M96X`1&%T96EM86YA9V5R`$1A=&5I;F%M90!$871E:6%U<W=A:&P`1&%T96DM
M2&]C:&QA9&5N`$1A<R!(;V-H;&%D96X@=F]N($1A=&5I96X@=VER9"!N:6-H
M="!U;G1E<G-T_'1Z="X`1FEL=&5R`$9I;FYL86YD`$5R<W1E($CD;&9T90!%
M<G-T97,@5FEE<G1E;`!697)HY&QT;FES('IU<OQC:W-E='IE;@!5;61R96AE
M;@!497AT9FQUWP!.96)E;`!$87,@5F5R>F5I8VAN:7,@)7,@97AI<W1I97)T
M(&YI8VAT`%-C:')I9G1F87)B90!%<W-E;@!&_'(@0G)O=W-E<BP@9&EE(&ME
M:6YE($)I;&1E<B!U;G1E<G-T_'1Z96X`5F]R:&5R<V%G92`H5$%&*0!6;W)H
M97)G97-A9W1E(%1A9V4@*%9O<FAE<G-A9V5N(&5N=&AA;'1E;B!486=E('5N
M9"!.Y&-H=&4L(&5I;B!H;VAE<B!797)T(&MA;FX@>G4@96EN96T@<V5H<B!G
M<F_?96X@0FQO8VL@9OQH<F5N*0!087-S=V]R="!V97)G97-S96X_`$9O<FUU
M;&%R90!';/QC:W-K96MS`$=L_&-K<VME:W-T>7``1VS\8VMS:V5K<V4`1VS\
M8VMS:V5K<V4@,@!&;W)E;@!796ET97)L96ET=6YG`$9R`%)A:&UE;@!&<F%N
M:W)E:6-H`$5U<F]PY&ES8VAE<R!&<F%N:W)E:6-H`$9R86YZ]G-I<V-H+4=U
M87EA;F$`1G)A;GKV<VES8V@M4&]L>6YE<VEE;@!&<F%N>O9S:7-C:&4@1V5B
M:65T92!I;2!S_&1L:6-H96X@26YD:7-C:&5N($]Z96%N`%9O;@!!=7,@`%9O
M;&QS=.1N9&EG92!"97-C:')E:6)U;F<`5F]L;&UO;F0`5F]L;'-TY&YD:6=E
M<B!.86UE`$=A8G5N`$)I;&1E<B!A=7,@9&EE<V5R($=A;&5R:64`1V%L97)I
M93H`1V%M8FEA`$%L;&=E;65I;F4@16EN<W1E;&QU;F=E;@`E<RU+;VYF:6=U
M<F%T:6]N(&5R>F5U9V5N`$5R>F5U9W1E<B!#;V1E`$=E;W)G:65N`$1E=71S
M8VAL86YD`$=H86YA`$=I8G)A;'1A<@!6;W)N86UE`$%L;&=E;65I;F4@16EN
M<W1E;&QU;F=E;@!,;W,`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!3=6-H
M90!'<F%U<W1U9F5N`$=R:65C:&5N;&%N9`!'<FEE8VAI<V-H("A)4T\M.#@U
M.2TW*0!'<O9N;&%N9`!'<F5N861A`$=R=7!P96YV97)W86QT=6YG`$=R=7!P
M96YN86UE;B!D_')F96X@;FEC:'0@;&5E<B!S96EN`$=R;W5P7VQD87`Z($1I
M92!'<G5P<&4@)7,@:V]N;G1E(&YI8VAT(&AI;GIU9V5F_&=T('=E<F1E;BX@
M365L9'5N9R!D97,@4V5R=F5R<SH@`$=R;W5P7VQD87`Z($1I92!'<G5P<&4@
M)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;@!'<F]U<%]L9&%P.B!$
M:64@1W)U<'!E("5S(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N
M`$=R=7!P96X`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'
M87-T<F5C:'1E`$?D<W1E8G5C:`!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA
M;F$`2%1-3`!$97(@161I=&]R(&MA;FX@9&EE(&QE='IT92!:96QL92!E:6YE
M<B!:96EL92!N:6-H="!L]G-C:&5N+@!$97(@161I=&]R(&MA;FX@9&EE(&QE
M='IT92!3<&%L=&4@96EN97(@5&%B96QL92!N:6-H="!L]G-C:&5N+@!$97(@
M161I=&]R(&MA;FX@9&EE(&QE='IT92!:96EL92!E:6YE<B!486)E;&QE(&YI
M8VAT(&SV<V-H96XN`$A45%`M075T:&5N=&EF:7II97)U;F<@;FEC:'0@9V5F
M=6YD96XN`$AA:71I`$AA<V@M06QG;W)I=&AM=7,`1&EE<VEG`-QB97)S8VAR
M:69T`$MO<&9E:6YT<N1G90!(96%R9"T@=6YD($UC1&]N86QD:6YS96QN`%-C
M:'=E<F4@1V5W:71T97(`2&5B<N1I<V-H("A)4T\M.#@U.2TX+4DI`$CV:&4`
M2&EL9F4`161I=&]R:&EL9F4`2&EL9F4`2&5M:7-P:&5R90!$:65S(&ES="!D
M97(@0F5G:6YN(&1E<B!$871E:3H`2&]C:`!?4W1A<G1S96ET90!6871I:V%N
M<W1A9'0`4W1A<G1S96ET90!!9')E<W-E('!R:79A=`!(96EM=F5R>F5I8VAN
M:7,`5&5L969O;B!P<FEV870`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!5;F?\;'1I9V4@)7,M6$U,+41A=&5N(&EN($YA8VAR:6-H
M="`E<P!(;W)D92]+;VQA8CH@17,@<&%S<W0@:V5I;F4@3F%C:')I8VAT('IU
M;2!/8FIE:W0@)7,`2&]R9&4O2V]L86(Z($ME:6X@3V)J96MT('9O;2!4>7`@
M)7,@:6X@3F%C:')I8VAT("5S(&=E9G5N9&5N`$AO<F1E+TMO;&%B.B`E<R`B
M)7,B('=U<F1E(&5R9F]L9W)E:6-H(&5N=&9E<FYT`$AO<F1E+TMO;&%B.B!$
M:64@26YT96=R871I;VYS9G5N:W1I;VYE;B!B96[V=&EG96X@9&EE(")D;VUX
M;6PB(%!(4"U%<G=E:71E<G5N9P!(;W)D92]+;VQA8CH@1OQR(&1A<R!/8FIE
M:W0@)7,@:V]N;G1E(&ME:6X@;F5U97(@6$U,+4)A=6T@97)Z975G="!W97)D
M96X`2&]R9&4O2V]L86(Z("5S("(E<R(@:V]N;G1E(&YI8VAT(&5N=&9E<FYT
M('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z($1I92!-24U%+4E$(&1E<R!!8G-C
M:&YI='1S('9O;2!4>7`@)7,@:V]N;G1E(&YI8VAT(&AE<F%U<V=E9G5N9&5N
M('=E<F1E;BX`2&]R9&4O2V]L86(Z("5S("(E<R(@:V]N;G1E(&YI8VAT('-Y
M;F-H<F]N:7-I97)T('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z($1I92!G96UE
M:6YS86UE;B!/8FIE:W1E(&MO;FYT96X@;FEC:'0@<WEN8VAR;VYI<VEE<G0@
M=V5R9&5N.B`E<P!(;W)D92]+;VQA8CH@56YB96MA;FYT97,@9V5M96EN<V%M
M97,@3V)J96MT("(E<R(`2&]R:7IO;G1A;&4@3&EN:64`2&]R:7IO;G1A;&5R
M($EN;F5N86)S=&%N9`!(;W)I>F]N=&%L.@!7:64@<VEN9"!3:64@:&EE<FAE
M<F=E;&%N9W0_($)I='1E(&%N(&1I92!%;G1W:6-K;&5R('IU<OQC:VUE;&1E
M;B$I`%=I92!V:65L92!3<&%L=&5N('-O;&QE;B!Z=7-A;6UE;F=E9OQG="!W
M97)D96X_`%=I979I96QE($9E;&1E<B`H4W!A;'1E;BD@9VEB="!E<S\`5VEE
M('9I96QE(%IE:6QE;B!S;VQL96X@>G5S86UM96YG96;\9W0@=V5R9&5N/P!,
M=69T9F5U8VAT:6=K96ET`$QU9G1F975C:'1I9VME:70Z(`!+;VUI:V5R`%5N
M9V%R;@!!;FQE9V5N(&1E<R!)34%0+5!O<W1F86-H<R!I<W0@9F5H;&=E<V-H
M;&%G96XZ("5S`$SV<V-H96X@9&5S($E-05`M4&]S=&9A8VAS(&ES="!F96AL
M9V5S8VAL86=E;CH@)7,`1F5S=&QE9V5N(&1E<B!)34%0+5!O<W1F86-H+5%U
M;W1A(&ES="!F96AL9V5S8VAL86=E;CH@)7,`25`M061R97-S90!)4"U!9')E
M<W-E(&YI8VAT('9E<F;\9V)A<BX`25`M061R97-S92!N:6-H="!I;2!E<FQA
M=6)T96X@0TE$4BU";&]C:RX`5F5R;&5T>G5N9R!D97(@9F5S=&=E;&5G=&5N
M($E0+@!:96EL92!E:6YF_&=E;B!?=F]R`$ES;&%N9`!.=7(@0FEL9&5R`$EC
M;VYS(&;\<B`E<P!":6QD97(@=6YD(%1E>'0`0F5Z96EC:&YU;F<@9&5R($ED
M96YT:73D=`!796YN('-I92!N:6-H="!K;W)R96MT(&%N9V5Z96EG="!W:7)D
M+"`E<RP@=6T@<VEE(&EN(&5I;F5M(&YE=65N($9E;G-T97(@86YG97IE:6=T
M('IU(&)E:V]M;65N+@!796YN(%-I92!M:70@9&5M($EN=&5R;F5T($5X<&QO
M<F5R(&ME:6YE(%-Y;6)O;&4@<V5H96XL(&W\<W-E;B!3:64@9&EE<V5S($OD
M<W1C:&5N(&UA<FMI97)E;BP@=6T@4$Y'+51R86YP87)E;GH@875S>G5S=&5L
M;&5N+@!796YN(%-I92!D:65S92!.86-H<FEC:'0@86X@4W1E;&QE(&5I;F4@
M0FEL9&5S('-E:&5N+"!K86YN($EH<B!"<F]W<V5R(&1A<R!":6QD+"!D87,@
M4VEE(&AO8VAL861E;B!M]F-H=&5N(&YI8VAT(&%N>F5I9V5N+@!":6QD=F]R
M<V-H874Z`$)I;&0M55),`$)I;&0M55),.@!":6QD('9O;B!'86QE<FEE`$)I
M;&0@=F]N($=A;&5R:64Z`$)I;&0M2&]C:&QA9&5N`$)I;&1E<@!.;W1I>F5N
M(&EM<&]R=&EE<F5N+"!38VAR:71T("5D`$EM<&]R=&EE<F5N+"!38VAR:71T
M("5D`$YO=&EZ96X@26UP;W)T+T5X<&]R=`!);7!O<G1I97)T97,@1F5L9#H@
M)7,`26UP;W)T:65R=&4@1F5L9&5R.@!:96EL92!E:6YF_&=E;B!?;F%C:`!5
M;F?\;'1I9V4@06MT:6]N(&%N9V5G96)E;BX`56YG_&QT:6=E<B!"96YU='IE
M<FYA;64@=6YD+V]D97(@4&%S<W=O<G0N`$9A;'-C:&5R($)E;G5T>F5R;F%M
M92!O9&5R($5M86EL861R97-S92X@5F5R<W5C:&5N(%-I92!E<R!E<FYE=70@
M;V1E<B!W96YD96X@4VEE('-I8V@@86X@26AR96X@4WES=&5M861M:6YI<W1R
M871O<BP@=V5N;B!3:64@=V5I=&5R92!(:6QF92!B96[V=&EG96XN`$5I;GIU
M9R!V97)G<O;?97)N`$EN9&EE;@!%:6YZ96QN92!"96YU='IE<@!);F1O;F5S
M:65N`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N96X`26YF;W)M871I;VYE;B!N
M:6-H="!M96AR('9E<F;\9V)A<BX`7U-P86QT92!D879O<B!E:6YF_&=E;@!"
M:6QD(&AI;GIU9OQG96X`5&%B96QL92!E:6YF_&=E;@!,:6YK(&5I;F;\9V5N
M`%-?<&%L=&4@9&%N86-H(&5I;F;\9V5N`$5I;F4@;F5U92!3<&%L=&4@;F%C
M:"!D97(@86MT=65L;&5N(&5I;F;\9V5N`$5I;F4@;F5U92!3<&%L=&4@=F]R
M(&1E<B!A:W1U96QL96X@96EN9OQG96X`16EN92!N975E(%IE:6QE(&YA8V@@
M9&5R(&%K='5E;&QE;B!E:6YF_&=E;@!%:6YE(&YE=64@6F5I;&4@=F]R(&1E
M<B!A:W1U96QL96X@96EN9OQG96X`16EN96X@;F5U96X@06)S871Z(&YA8V@@
M9&5M(&%K='5E;&QE;B!%;&5M96YT(&5I;F;\9V5N`$5I;F5N(&YE=65N($%B
M<V%T>B!V;W(@9&5M(&%K='5E;&QE;B!%;&5M96YT(&5I;F;\9V5N`$%L=&5R
M;F%T:79E(%9O<FQA9V4@96EN9OQG96X`1V5B96X@4VEE(&5I;F4@16UA:6QA
M9')E<W-E(&%N+"!A;B!D:64@9&%S(&YE=64@4&%S<W=O<G0@9V5S8VAI8VMT
M('=E<F1E;B!S;VQL.@!:96QL92!D86YA8V@@96EN9OQG96X`6F5L;&4@9&%V
M;W(@96EN9OQG96X`4W!A;'1E(&1A;F%C:"!E:6YF_&=E;@!3<&%L=&4@9&%V
M;W(@96EN9OQG96X`3F%C:')I8VAT96X@:&EN>G5F_&=E;@!!8G-A='H@9&%N
M86-H(&5I;F;\9V5N`$%B<V%T>B!D879O<B!E:6YF_&=E;@!:96EL92!D86YA
M8V@@96EN9OQG96X`6F5I;&4@9&%V;W(@96EN9OQG96X`1V5B96X@4VEE(&1I
M92!!;G1W;W)T(&%U9B!D:64@4VEC:&5R:&5I='-F<F%G92!E:6XZ`$)I;&0@
M96EN9OQG96XO8F5A<F)E:71E;@!,:6YK(&5I;F;\9V5N+V)E87)B96ET96X`
M6G4@=V5N:6<@1W5T:&%B96XL('5M(&%N(&1I92!697)T96EL97)L:7-T92!Z
M=2!V97)S8VAI8VME;BX`6G4@=V5N:6<@1W5T:&%B96XN`$=A;GIZ86AL`$QI
M<W1E('9O;B!'86YZ>F%H;&5N`%5N9_QL=&EG97(@541(+B`H57-E<B!$871A
M($AE861E<BDN`%5N9_QL=&EG92!:25`M1&%T96XN`%5N9_QL=&EG92!!;G=E
M;F1U;F<N`%5N9_QL=&EG92!"871C:"U)1"X`56YG_&QT:6=E($1A=&5N(&5I
M;F=E8F5N+@!5;F?\;'1I9V4@6FEE;&%D<F5S<V4N`%5N9_QL=&EG97,@1&%T
M96EF;W)M870`56YG_&QT:6=E<B!,:7IE;GIS8VAL_'-S96PN`%5N9_QL=&EG
M97(@3W)T(&%N9V5G96)E;BX`56YG_&QT:6=E<B!M<V=?='EP92X`56YG_&QT
M:6=E(&]D97(@9F5H;&5N9&4@87!I7VED+@!5;F?\;'1I9V4@;V1E<B!F96AL
M96YD92!087)A;65T97(N`%5N9_QL=&EG97,@W&)E<G)E8VAT+@!5;F?\;'1I
M9V4@4&%R=&YE<BU)1"X`56YG_&QT:6=E<B!0<F]D=6MT8V]D92X`56YG_&QT
M:6=E<R!0<F]T;VMO;&PN`%5N9_QL=&EG97(@16UP9N1N9V5R.B`B)7,B`%5N
M9_QL=&EG97,@9V5M96EN<V%M97,@3V)J96MT`%5N9_QL=&EG92!5<G-P<G5N
M9W-A9')E<W-E+@!5;F?\;'1I9V4@56YI8V]D92U$871E;BX`26YV96YT87(`
M075S=V%H;"!U;6ME:')E;@!)<VQA;6ES8VAE(%)E<'5B;&EK($ER86X`27)A
M:P!)<FQA;F0`27-L92!O9B!-86X`5F5R96EN>F5L=&4@1V5W:71T97(`27-R
M865L`$%U<W-T96QL97(`2W5R<VEV`$ET86QI96X`2F%M86EK80!*86YU87(`
M2F%P86X`2F%P86YI<V-H("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE
M;@!*=6QI`$IU;FD`0FQO8VMS871Z`%IE;G1R:65R96X`0FQO8VMS871Z`$QI
M;FMS(&%U<W)I8VAT96X`4F5C:'1S(&%U<W)I8VAT96X`2V%S86-H<W1A;@!/
M<FEG:6YA;"!B96EB96AA;'1E;C\`2V5N:6$`2V5R8F5R;W,M4V5R=F5R(&AA
M="!!=71H96YT:69I>FEE<G5N9R!Z=7+\8VMG97=I97-E;BX`2V5R;F5L+4YE
M=6QI;F=E`%-C:&S\<W-E;&5R>F5U9W5N9P!&:6YG97)A8F1R=6-K(&1E<R!3
M8VAL_'-S96QS`%-C:&S\<W-E;&SD;F=E`%-C:&S\<W-E;'1Y<`!38VAL_'-S
M96QZ=V5C:P!$97(@4V-H;/QS<V5L(&)E9FEN9&5T('-I8V@@8F5R96ET<R!A
M=68@9&5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(N`$MI;F1E<@!+
M:7)I8F%T:0!$96UO:W)A=&ES8VAE(%9O;&MS<F5P=6)L:6,@2V]R96$`4F5P
M=6)L:6L@2V]R96$`2V]R96%N:7-C:"`H155#+4M2*0!+=7=A:70`2VER9VES
M:7-T86X`06Y?<&%S<V5N`%-P<F%C:&4`3&%O<P!,971Z=&4@2.1L9G1E`$QE
M='IT92#$;F1E<G5N9P!,971Z=&4@4&%S<W=O<G3D;F1E<G5N9P!,971Z=&5S
M(%9I97)T96P`3&5T>G1E($%K='5A;&ES:65R=6YG.@!,971Z=&4@06YM96QD
M=6YG.B`E<P!,971Z=&4@06YM96QD=6YG.B`E<R!V;VX@)7,`3&5T>G1E($%N
M;65L9'5N9SH@3F]C:"!N:64`3&5T=&QA;F0`1V5S971Z`$9O<FUA=`!,965R
M(&QA<W-E;B!F_'(@:V5I;F5N(%)A:&UE;@!,:6)A;F]N`$QI;FMS`$QI;FME
M(-QB97)S8VAR:69T`$QI;FME(%=E<G1E`$QE<V]T:&\`16)E;F4`3&EB97)I
M80!,:6)Y96X`3&EE8VAT96YS=&5I;@!3<'+\:')E9V5N`$QE:6-H=&5R(%)E
M9V5N`$9R_&@@;&5I8VAT97(@4F5G96X`4W#D=&5R($QE:6-H=&5R(%)E9V5N
M`$QE:6-H=&4@4F5G96YS8VAA=65R`$QE:6-H=&5R(%)E9V5N(&UI="!'97=I
M='1E<@!,96EC:'1E<B!38VAN965F86QL`$QE:6-H=&4@4V-H;F5E<V-H875E
M<@!,:6UE<FEC:P!,:6YK`$QI;FL@=F5R=V5I<W0@875F.@!%;6%I;&%D<F5S
M<V4@=F5R;&EN:V5N/P!,:6YK<P!,:6YU>"U';/QC:W-K96MS90!,:7-T("T@
M0F5N=71Z97(@:V%N;B!D96X@3W)D;F5R('-E:&5N`$1A=&5N8F%N:V5N(&%N
M>F5I9V5N`$AI;&9E96EN='+D9V4@86YZ96EG96X`5&%B96QL96X@86YZ96EG
M96X`3&ES=&5N+4%R8VAI=@!,:7-T96XM2&EL9F4`3&ES=&5N+4ED`$QI<W1E
M;BU"97-I='IE<@!,:7-T96XM061R97-S90!,:7-T96XM06YM96QD=6YG`$QI
M<W1E;BU!8FUE;&1U;F<`1&%S($%N>F5I9V5N(&1E<B!397-S:6]N<R!I<W0@
M9F5H;&=E<V-H;&%G96XZ("5S`$1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@
M:7-T(&9E:&QG97-C:&QA9V5N.B`E<P!$87,@06YZ96EG96X@9&5R($)E;G5T
M>F5R(&ES="!N:6-H="!M]F=L:6-H+@!,:71E<F%T=7(`3&ET875E;@!,861E
M+BXN`$QO:V%L92!5:')Z96ET.B``4W!R86-H92!U;F0@6F5I=`!/<G0`06YM
M96QD96X`3&]G(&1E<B!L971Z=&5N(%-Y;F-H<F]N:7-A=&EO;BX`06)M96QD
M96X`06YM96QD96X`06YM96QD96%U9F=A8F5N`$1I92!!;FUE;&1U;F<@:7-T
M(&9E:&QG97-C:&QA9V5N+"!W96EL(%-I92!):')E;B!"96YU='IE<FYA;65N
M(&]D97(@26AR(%!A<W-W;W)T(&9A;'-C:"!E:6YG96=E8F5N(&AA8F5N+@!!
M;FUE;&1U;F<@9F5H;&=E<V-H;&%G96XN`$QA;F=E<B!497AT`$QI96)E`$YI
M961R:6<`2VPN(&=R:65C:&ES8VAE($)U8VAS=&%B96X`2VPN(&QA=&5I;FES
M8VAE($)U8VAS=&%B96X`2VPN('+V;6ES8VAE(%IA:&QE;@!,=7AE;6)U<F<`
M34T`34]41`!-4RU43D5&+4%N:&%N9R!E;G1H:65L="!K96EN92!$871E;BX`
M2$E.5T5)4P!-86-A;P!$:64@96AE;6%L:6=E($IU9V]S;&%W:7-C:&4@4F5P
M=6)L:6L@36%Z961O;FEE;@!-861A9V%S:V%R`$UA9VEE`%=E8FUA:6P`16UA
M:6P@061M:6YI<W1R871I;VX`3&EN:R!?86YL96=E;BXN+@!-86QA=VD`36%L
M87ES:6$`36%L:61I=F5N`$UA;&D`36%L=&$`5F5R=V%L=&5N(%-I92!D:64@
M2V%T96=O<FEE;BP@;6ET(&1E;F5N(%-I92!%;&5M96YT92!U;F0@16EN='+D
M9V4@:V5N;GIE:6-H;F5N(&OV;FYE;BP@<V]W:64@9&EE('IU9V5H]G)I9V5N
M($9A<F)E;BX`36%P,C0M2V%R=&4`36%P475E<W0M2V%R=&4`6G5O<F1N=6YG
M96X@9V5S<&5I8VAE<G0N`$WD<GH`077?96YA8G-T86YD`$UI="!'96QE<V5N
M+2]5;F=E;&5S96XM4W1A='5S('9E<G-E:&5N`$UI="!A;F1E<F5M(%-T871U
M<R!V97)S96AE;B`H>BY"+B!7:6-H=&EG+T)E86YW;W)T970I`$UA<G-H86QL
M:6YS96QN`$UA<G1I;FEQ=64`6G5G96]R9&YE=&4@1F5L9&5R`$UA=7)E=&%N
M:65N`$UA=7)I=&EU<P!-87AI;6%L(&5R;&%U8G1E<B!+<F5D:70N`$UA>&EM
M86QE($YA8VAT:6-H=&5N=&5I;&4@_&)E<G-C:')I='1E;BX`2/9C:'-T=&5M
M<&5R871U<B!D97(@;&5T>G1E;B`R-"!3='5N9&5N.B``2/9C:'-T=&5M<&5R
M871U<B!D97(@;&5T>G1E;B`V(%-T=6YD96XZ(`!-87AI;6%L92!!;GIA:&P@
M86X@3F]T:7IE;@!-87AI;6%L92!!;GIA:&P@86X@4&]R=&%L8FSV8VME;@!-
M87AI;6%L92!,Y&YG90!-86D`36%Y;W1T92!)<VQA;F0`365D:7II;@!-:71G
M;&EE9&5R`$YO=&EZ96YT97AT`$UE;OQM;V1U<SH`6F5L;&5N('IU<V%M;65N
M9OQG96X`3F%C:')I8VAT`$1I92!.86-H<FEC:'0@:V]N;G1E(&5R9F]L9W)E
M:6-H(/QB97)P<OQF="!W97)D96X@86)E<B!N:6-H="!D87,@6F5R=&EF:6MA
M="!D97,@06)S96YD97)S+@!.86-H<FEC:'0@;FEC:'0@;65H<B!G_&QT:6<N
M`$YA8VAR:6-H=&5N='EP`$UE=&%R(%=E='1E<@!-971A<F)L;V-K(&YI8VAT
M('9E<F;\9V)A<BX`365T87)B;&]C:R!N:6-H="!V97)F_&=B87(N($1E=&%I
M;',@=W5R9&5N(&;\<B!D96X@061M:6YI<W1R871O<B!M:71G96QO9V=T+@!+
M96EN92!697)B:6YD=6YG('IU<B!-971A<D1"+@!-971H;V1E`$1I92!-971H
M;V1E("(E<R(@:7-T(&YI8VAT(&1E9FEN:65R=`!-971H;V1E(&YI8VAT(&1E
M9FEN:65R="X@075F9V5R=69E;F4@365T:&]D93H@)7,`365T<FES8V@`365X
M:6MO`$;V9&5R:65R=&4@4W1A871E;B!V;VX@36EK<F]N97-I96X`36ET=&4`
M36EM971Y<`!4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T=6YD
M96XZ(`!4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#8@4W1U;F1E;CH@
M`$1A<R!M:6YI;6%L92!087-S=V]R=&%L=&5R(&ES="!N;V-H(&YI8VAT(&%B
M9V5L875F96X`4W!I96=E;&X`5F5R<V-H:65D96YE<P!014%2+5!A:V5T($A4
M5%!?4F5Q=65S="!F96AL="X`1F5H;&5N9&4@2V]N9FEG=7)A=&EO;BX@4VEE
M(&W\<W-E;B!D:65S92!J971Z="!E<GIE=6=E;BP@=V5N;B!3:64@9&EE($%N
M=V5N9'5N9R!V97)W96YD96X@;?9C:'1E;BX`1F5H;&5N9&4@3F%C:')I8VAT
M96XM240N`%!%05(M4&%K970@36%I;"!F96AL="X`1F5H;&5N9&4@4VET>G5N
M9W,M240N`$UO`$5M86EL($UO8FEL`$WDWVEG`,1N9&5R=6YG<V1A='5M`%52
M3"!B96%R8F5I=&5N`"5S(&)E87)B96ET96X`36]D=6QU<P!297!U8FQI:R!-
M;VQD874`36]N86-O`$UO;F=O;&5I`$UO;F%T('5N9"!*86AR`$UO;F%T;&EC
M:`!-;VYT<V5R<F%T`$UO;F1P:&%S96X`365H<B!&96QD97(@:6X@6F5I;&4@
M)60@86QS(&1I92!E<G=A<G1E=&5N("5D(&=E9G5N9&5N+@!-87)O:VMO`-QB
M97)W:65G96YD(&AE:71E<@#<8F5R=VEE9V5N9"!"97?V;&MT`-QB97)W:65G
M96YD($)E=_9L:W0@=6YD(%=I;F1I9P#<8F5R=VEE9V5N9"!3;VYN:6<`3F%C
M:"!U;G1E;@!.86-H(&QI;FMS`$YA8V@@<F5C:'1S`$YA8V@@;V)E;@!.86-H
M('5N=&5N`$YA8V@@;V)E;@!-;W-A;6)I:P!!=7-W86AL;&ES=&4@:6X@;65H
M<F5R96X@16)E;F5N`$UU;'1I;6%P+55++4MA<G1E`$UE:')F86-H875S=V%H
M;`!-96EN($MO;G1O`$UE:6X@2V]N=&\`365I;F4@3F]T:7IE;@!-96EN(%!O
M<G1A;`!-96EN(%!O<G1A;&QA>6]U=`!"=7)M80!.14E.+"!I8V@@<W1I;6UE
M($Y)0TA4('IU`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.:65D97)L86YD
M90!.:65D97)LY&YD:7-C:&4@06YT:6QL96X`3F5T<V-A<&4M0F%S:7,M55),
M`$YE='-C87!E+4-!+5-P97)R=6YG<RU54DP`3F5T<V-A<&4M0T$M4FEC:'1L
M:6YI96XM55),`$YE='-C87!E+5IE=&EF:6MA='-E<FYE=65R=6YG<RU54DP`
M3F5T<V-A<&4M4W!E<G)U;F=S+5523`!.971S8V%P92U34TPM4V5R=F5R;F%M
M90!.971S8V%P92U+;VUM96YT87(`3F5T<V-A<&4M6F5R=&EF:6MA='1Y<`!.
M971Z=V5R:P!.:64`3F5U:V%L961O;FEE;@!.975E($MA=&5G;W)I90!.975M
M;VYD`$YE=64@3F]T:7H`3F5U97(@0F5N=71Z97)N86UE("AO<'1I;VYA;"D`
M3F5U<V5E;&%N9`!.975E<R!087-S=V]R=`!$87,@;F5U92!087-S=V]R9"!W
M:7)D(&%M("5X(&%B;&%U9F5N+@!$:64@;F5U96X@4&%S<W?V<G1E<B!S=&EM
M;65N(&YI8VAT(/QB97)E:6XN`$YE=65S($9E;G-T97(@*%]B;&%N:RD`3F%C
M:')I8VAT96X`3F5W<V=R=7!P96X`5V5I=&5R`$[D8VAS=&4@-"!0:&%S96X`
M3N1C:'-T92!%:6YS=&5L;'5N9V5N`%=E:71E<CX`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3F%C:'1S`$YI=64`3F5I;@!+96EN92!+;VYF:6=U<F%T:6]N
M<V1A=&5N('9E<F;\9V)A<BP@=6T@56YT97)S8VAI961E(&%N>G5Z96EG96XN
M`$ME:6YE(%-T<F%T96=I92!Z=6T@17)S=&5L;&5N('9O;B!)4T\M06)B:6QD
M97)N('9E<F;\9V)A<BX`2V5I;F4@0F%T8V@M5F]R;&%G92X`17,@97AI<W1I
M97)T(&ME:6X@0FQO8VL@86X@9&5R(&%N9V5G96)E;F5N(%!O<VET:6]N`$ME
M:6X@2V%L96YD97)N86UE(&;\<B!D:64@34-!3"U!=71H96YT:69I>FEE<G5N
M9R!A;F=E9V5B96XN`$ME:6YE(,1N9&5R=6YG96XN`%5N=&5R:&%L8B!D:65S
M97(@16)E;F4@:_9N;F5N(&ME:6YE('=E:71E<F5N(%5N=&5R<F5C:'1E(&AI
M;GIU9V5F_&=T('=E<F1E;BX`1OQR("5S('=U<F1E;B!K96EN92!+;VYF:6=U
M<F%T:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+@!&_'(@9&5N($944"U6
M1E,M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA
M=&EO;F5N(&%N9V5G96)E;BX`1OQR(&1E;B!344PM5D93+51R96EB97(@=W5R
M9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B
M96XN`$;\<B!D96X@4U%,+41A=&5I+59&4RU4<F5I8F5R('=U<F1E;B!K96EN
M92!+;VYF:6=U<F%T:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+@!+96EN
M($MR961I="!M96AR(/QB<FEG+@!+96EN($5M<&;D;F=E<B!A;F=E9V5B96XN
M`$ME:6YE($1A=&5I(&AO8VAG96QA9&5N`$5S('=U<F1E;B!K96EN92!I0V%L
M96YD87(M1&%T96X@9V5F=6YD96XN`$ME:6YE($EC;VYS(&=E9G5N9&5N+@!%
M<R!W=7)D92!K96EN($]R="!F97-T9V5L96=T+@!+96EN($]R="!A;F=E9V5B
M96XN`$ME:6YE($YA8VAR:6-H="!A;F=E9V5B96XN`$ME:6X@3F%M92!A;F=E
M9V5B96XN`$5S('-I;F0@:V5I;F4@3F]T:7IB;/9C:V4@9OQR($?D<W1E('9E
M<F;\9V)A<BX`2V5I;F4@3F]T:7IE;@!+96EN92!.;W1I>F5N(&5N='-P<F5C
M:&5N(&1E;B!3=6-H:W)I=&5R:65N+@!+96EN92!.;W1I>F5N`$ME:6YE($YU
M;6UE<B!A;F=E9V5B96XN`$ME:6YE(&%N<W3VWVEG96X@1VS\8VMS:V5K<V4`
M2V5I;B!087-S=V]R="!F_'(@9&EE($A45%`M075T:&5N=&EF:7II97)U;F<@
M86YG96=E8F5N+@!+96EN(%!A<W-W;W)T(&;\<B!D:64@24U!4"U!=71H96YT
M:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!+
M97)B97)O<RU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S
M<W=O<G0@9OQR(&1I92!,;V=I;BU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B
M96XN`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!005-35T0M075T:&5N=&EF:7II
M97)U;F<@86YG96=E8F5N+@!+96EN(%!A<W-W;W)T(&;\<B!D:64@4TU"+4%U
M=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!09F%D('IU;2!/<&5N
M4U-,+5!R;V=R86UM(&%N9V5G96)E;BX@1&%S($]P96Y34TPM4')O9W)A;6T@
M=VER9"!B96[V=&EG="P@=6T@4$M#4RTQ,BU$871E;B!V97)A<F)E:71E;B!Z
M=2!K]FYN96XN`$ME:6YE(&%U<W-T96AE;F1E;B!296=I<W1R:65R=6YG96XN
M`$ME:6X@4W!E:6-H97)P;&%T>BU+;VYT:6YG96YT(&9E<W1G96QE9W0N`$ME
M:6YE(%)A:&UE;@!+96EN(%1R96YN>F5I8VAE;B!A;F=E9V5B96XN`$ME:6YE
M(%-E:71E;@!$871E:2!N:6-H="!G969U;F1E;@!+96EN92!T96UP;W+D<F5S
M(%9E<GIE:6-H;FES(&;\<B!D96X@0V%C:&4@9V5F=6YD96XN`$ME:6X@0F5N
M=71Z97)N86UE('5N9"]O9&5R(%!A<W-W;W)T(&%N9V5B96XN`$5S('=U<F1E
M;B!K96EN92!G_&QT:6=E;B!834PM1&%T96X@>G5R_&-K9V5G96)E;@!+96EN
M92!797)T90!+96EN92!697)S:6]N<VYU;6UE<B!I;B!D97(@3W)I9VEN86QK
M;VYF:6=U<F%T:6]N(&=E9G5N9&5N+B!%<FYE=65R;B!3:64@26AR92!+;VYF
M:6=U<F%T:6]N+@!+96EN92!697)S:6]N<VYU;6UE<B!I;B!):')E<B!+;VYF
M:6=U<F%T:6]N(&=E9G5N9&5N+B!%<FYE=65R;B!3:64@26AR92!+;VYF:6=U
M<F%T:6]N+@!.;U]T:7H`2V5I;F4`2V5I;G,@*%-T86YD87)D(&)E;G5T>F5N
M*0!.;W)D:7-C:"`H25-/+3@X-3DM,3`I`$YO<F9O;&MI;G-E;`!.]G)D;&EC
M:&4@2&5M:7-P:&5R90!.]G)D;&EC:&4@36%R:6%N96X`3F]R=V5G96X`1_QL
M=&EG(&)I<P!'_&QT:6<@86(`2V5I;B!697)Z96EC:&YI<P!.:6-H="!I;7!L
M96UE;G1I97)T+@!.:6-H="!F97-T9V5L96=T`$YI8VAT('5N=&5R<W3\='IT
M+@!.;W1I>FMA=&5G;W)I90!.;W1I>F1E=&%I;',`3F]T:7II<W1E;@!.;W1I
M>G1E>'0`3F]T:7I?=&5X=`!.;W1I>B!N:6-H="!G969U;F1E;BX`3F]T:7I?
M8FQO8VL`3F]T:7IB;&]C:VYA;64Z`$YO=&EZ8FSV8VME`$YO=&EZ8FSV8VME
M(&W\<W-E;B!E:6YE;B!.86UE;B!H86)E;BX`3F]T:7IE;@!.;W1I>F5N+5IU
M<V%M;65N9F%S<W5N9P!.:6-H=',@86YZ=7IE:6=E;BP@8FET=&4@>G5R_&-K
M9V5H96XN`$YO=F5M8F5R`%IA:&P`06YZ86AL(&1E<B!:96EC:&5N`$%N>F%H
M;"!D97(@4W!A;'1E;@!!;GIA:&P@9&5R(%IE:6QE;@!+96EN92!.=6UM97)N
M(&;\<B!D:64@5F5R=&5I;&5R;&ES=&4@86YG96=E8F5N+@!/2P!/8FIE:W0`
M3V)J96MT97)S=&5L;&5R`$]K=&%L>F%H;`!/:W1O8F5R`$9I;'1E<B!F_'(@
M86YS=/;?:6=E($EN:&%L=&4`0OQR;P!):'(@;F5U97,@4&%S<W=O<G0@;75S
M<R!S:6-H('9O;B!):')E;2!A;'1E;B!U;G1E<G-C:&5I9&5N+@!!;'1E<R!0
M87-S=V]R=`!&86QS8VAE<R!A;'1E<R!087-S=V]R="X`3VUA;@!.=7(@24U!
M4"U397)V97(@=6YT97)S=/QT>F5N(&=E;65I;G-A;64@3W)D;F5R+@!.=7(@
M86YS=/;?:6=E($=L_&-K<VME:W-E`$YU<B!E:6YE($5M86EL+4%D<F5S<V4@
M97)L875B="X`3G5R(&1E<B!"97-I='IE<B!O9&5R(&1E<B!3>7-T96UA9&UI
M;FES=')A=&]R(&MA;FX@9&5N($)E<VET>F5R(&]D97(@9&EE($)E<VET>F5R
M<F5C:'1E(.1N9&5R;@!);B!N975E;2!&96YS=&5R(/9F9FYE;@!/<&5N4U-,
M+49E:&QE<CH@4VEG;FEE<G1E(%,O34E-12U$871E;B!K;VYN=&5N(&YI8VAT
M(&5X=')A:&EE<G0@=V5R9&5N+@!$:65S96X@3&EN:R!I;B!E:6YE;2!N975E
M;2!&96YS=&5R(/9F9FYE;@!"971R:65B<WES=&5M`$5I;G-T96QL=6YG96X`
M16EN<W1E;&QU;F=E;B!F_'(@)7,`3G5M;65R:65R=&4@3&ES=&4`3W)G86YI
M<V%T:6]N`$]R9V%N:7-A=&EO;G-A8G1E:6QU;F<`3W)G86YI<VEE<F5N`$]R
M:6=I;F%L=F]R;&%G92!D97(@06YW96YD=6YG`$]R:6=I;F%L=F]R;&%G92!I
M;B`E<SH`4V]N<W1I9V4`06YD97)E($EN9F]R;6%T:6]N96X`0F5S:71Z97)R
M96-H=&4`4$%-+4%U=&AE;G1I9FEZ:65R=6YG(&ES="!N:6-H="!V97)F_&=B
M87(N`%!%05(Z.DUA:6PM0F%C:V5N9`!$:6=I=&%L92!01U`M56YT97)S8VAR
M:69T`%!'4"UV97)S8VAL_'-S96QT92!$871E;@#69F9E;G1L:6-H97(@4$=0
M+5-C:&S\<W-E;`!-:70@4$=0('5N=&5R>F5I8VAN971E+W9E<G-C:&S\<W-E
M;'1E($1A=&5N`%!(4"!#;V1E`%!(4"!3:&5L;`!6;W)M:71T86=S(&QE:6-H
M=&5R(%)E9V5N`$YA8VAM:71T86=S(%)E9V5N`$YA8VAM:71T86=S(%-C:&%U
M97(`3F%C:&UI='1A9W,@4V-H;F5E`$YA8VAM:71T86=S(%-C:&YE97-C:&%U
M97(`3F%C:&UI='1A9W,@4V]N;F4`3F%C:&UI='1A9W,@1V5W:71T97(`1&EE
M(%!/4TE8+45R=V5I=&5R=6YG(&9E:&QT`%]02%`@4VAE;&P`26YN96YA8G-T
M86YD`%!A:VES=&%N`%!A;&%U`$)E<V5T>G1E(%!A;.1S=&EN96YS:7-C:&4@
M1V5B:65T90!086YA;6$`4&%P=6$M3F5U9W5I;F5A`%!A<F%G=6%Y`%1E:6QW
M96ES92!"97?V;&MT`%!A<W-W;W)T`%!A<W-W;W)T(&5R9F]L9W)E:6-H(&=E
MY&YD97)T+@!&86QS8VAE<R!087-S=V]R=`!+96EN(%!A<W-W;W)T(&;\<B!D
M:64@4D%$2553+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`4&%S<W=O
M<G0@;6ET($)E<W3D=&EG=6YG`%!A<W-W;W)T.@!087-S=V]R=#H@`$1I92!0
M87-S=_9R=&5R(&W\<W-E;B!G;&5I8V@@<V5I;BX`16EN9OQG96X`5F]N(&1E
M<B!:=VES8VAE;F%B;&%G92!E:6YF_&=E;@!09F%D`$%U<W-T96AE;F1E(%)E
M9VES=')I97)U;F=E;CH`4&5R<V]N96X`4')O>F5N=`!787)T=6YG<V%R8F5I
M=&5N(&1U<F-H9OQH<F5N`%=A<G1U;F=S87)B96ET96X@;F%C:"!D97(@06YM
M96QD=6YG(&1U<F-H9OQH<F5N/P!296-H=&4`4F5C:'0@(B5S(B!W=7)D92!N
M:6-H="!G96SV<V-H="X`6G5G<FEF9B!V97)W96EG97)T`%)E8VAT90!296-H
M=&5V97)W86QT=6YG`%!E<G/V;FQI8VAE($%N9V%B96X`4&5R=0!(875S=&EE
M<F4`4&AI;&EP<&EN96X`5&5L969O;@!&;W1O<P!0:71C86ER;@!0:7AE;`!0
M;&%T=&AE:71E;@!":71T92!K;&EC:V5N(%-I92!I;B!E:6YE(%IE;&QE`$)I
M='1E(&)E<W3D=&EG96X@4VEE+"!D87-S(%-I92!D:65S97,@16QE;65N="!L
M]G-C:&5N(&WV8VAT96XZ`$)I='1E(&)E=.1T:6=E;B!3:64L(&1A<W,@4VEE
M(&1E;B!,:6YK('9O;B!D:65S96T@16QE;65N="!E;G1F97)N96X@;?9C:'1E
M;BX`0FET=&4@96EN96X@36]N870@=6YD(&5I;B!*86AR(&%N9V5B96XN`$)I
M='1E(&=E8F5N(%-I92!E:6YE;B!.86UE;B!F_'(@9&EE(&YE=64@2V%T96=O
M<FEE(&%N.@!":71T92!E:6YE(&?\;'1I9V4@25`M061R97-S92!E:6YG96)E
M;BX`0FET=&4@9V5B96X@4VEE(&5I;B!G_&QT:6=E<R!$871U;2!A;CL@_&)E
M<G!R_&9E;B!3:64@9&EE(%IA:&P@9&5R(%1A9V4@:6X@9&5M($UO;F%T+@!"
M:71T92!E:6YE;B!G_&QT:6=E;B!:96ET=V5R="!E:6YG96)E;BX`0FET=&4@
M9V5B96X@4VEE(&5I;F4@6G5S86UM96YF87-S=6YG($EH<F5S(%!R;V)L96US
M(&%N+@!":71T92!G96)E;B!3:64@26AR96X@0F5N=71Z97)N86UE;B!U;F0@
M26AR(%!A<W-W;W)T(&%N`$)I='1E(&QE<V5N(%-I92!S:6-H(&1E;B!F;VQG
M96YD96X@5&5X="!S;W)G9N1L=&EG(&1U<F-H+B!3:64@3=Q34T5.(&1I97-E
M;B!"961I;F=U;F=E;B!Z=7-T:6UM96XL('=E;FX@4VEE(&1I97-E<R!3>7-T
M96T@8F5N=71Z96X@;?9C:'1E;BX`0FET=&4@9&5N(&YE=65N($MA=&5G;W)I
M96YA;65N(&5I;F=E8F5N.@!0;VQE;@!0;VQI=&EK`%5M9G)A9V5N`%!O<G1U
M9V%L`%!O<VET:6]N:65R=6YG(&1I97-E($)I;&1E<P!0;W-I=&EO;FEE<G5N
M9R!D:65S97(@5&%B96QL90!396YD96X@86X@9&EE<V5N($]R9&YE<B`H;FEC
M:'0@9'5R8V@@24U!4"D`3FEE9&5R<V-H;&%G(&EN(&1E;B!L971Z=&5N("5S
M(%-T=6YD92AN*3H@`$YI961E<G-C:&QA9W,M/&)R("\^=V%H<G-C:&5I;FQI
M8VAK96ET`%!R969S7VQD87`Z($1I92!B96[V=&EG=&4@3$1!4"U%<G=E:71E
M<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`4')E9G-?<V5S<VEO;CH@1&EE
M(&)E;O9T:6=T92!397-S:6]N+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E
M9G5N9&5N+@!,=69T9')U8VL`3'5F=&1R=6-K(&%U9B!3965H]FAE.B``3'5F
M=&1R=6-K.B``5F]R<V-H874`16EN92!6;W)S8VAA=2!D97,@0FEL9&5S(&EN
M(&5I;F5M(&YE=65M($9E;G-T97(@86YZ96EG96X`5F]H97)I9V4@16EN<W1E
M;&QU;F=E;@!$;VMU;65N="!D<G5C:V5N`%!R:79A=&5R(%-C:&S\<W-E;`!0
M<F]B;&5M90!0<F]B;&5M8F5S8VAR96EB=6YG`%!R;VIE:W1E`$YA8VAF<F%G
M971E>'0`UF9F96YT;&EC:&5R(%-C:&S\<W-E;`!!;&=O<FET:&UU<R!D97,@
M]F9F96YT;&EC:&5N(%-C:&S\<W-E;',`26YF;W)M871I;VYE;B!Z=6T@]F9F
M96YT;&EC:&5N(%-C:&S\<W-E;`!$87,@]F9F96YT;&EC:&4O<')I=F%T92!3
M8VAL_'-S96QP86%R(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96XN`%!U
M97)T;R!2:6-O`$YA8VAR:6-H=&5N(&5N9&?\;'1I9R!L]G-C:&5N`$MA=&%R
M`$%B9G)A9V4`4W!E:6-H97)P;&%T>BU+;VYT:6YG96YT`-9F9F5N=&QI8VAE
M<B!24T$@4V-H;/QS<V5L("@E9"!":70I`$%U<W=A:&QK;F]P9@!296=E;@!&
M<OQH(%)E9V5N`%-PY'1E<B!296=E;@!296=E;G-C:&%U97(`4V-H;F5E<F5G
M96X`4F5G96X@:6X@4V-H;F5E(/QB97)G96AE;F0`1VS\8VMS:V5K<P!697)H
MY&QT;FES`$QE<V5N`$YA8VAR:6-H=&5N(&QE<V5N`"5S('=I<FML:6-H(&SV
M<V-H96X_($1I97-E<B!6;W)G86YG(&MA;FX@;FEC:'0@<OQC:V?D;F=I9R!G
M96UA8VAT('=E<F1E;BX`1&EE<V4@3F]T:7H@=VER:VQI8V@@;/9S8VAE;C\`
M1&%T96X@9&5S($)E;G5T>F5R<R`E<R!W:7)K;&EC:"!L]G-C:&5N/R!$:65S
M97(@5F]R9V%N9R!K86YN(&YI8VAT('+\8VMGY&YG:6<@9V5M86-H="!W97)D
M96XN`$;\:')T(&QE='IT92!!:W1I;VX@97)N975T(&%U<P!!:W1U86QI<VEE
M<F4`1'EN86UI<V-H92!-96[\96QE;65N=&4@86MT=6%L:7-I97)E;CH`3&ES
M=&4@86MT=6%L:7-I97)E;@!0;W)T86QA;G-I8VAT(&%K='5A;&ES:65R96XZ
M`%)E9W5LY')E<B!!=7-D<G5C:P!697)B:6YD=6YG<RU"<F]W<V5R`$%K='5A
M;&ES:65R96X`0F5M97)K=6YG96X`16YT9F5R;G1E(%-E<G9E<@!397)V97)A
M9')E<W-E("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`16YT9F5R
M;F5N`$)L;V-K(&SV<V-H96X`2V%T96=O<FEE(&5N=&9E<FYE;@!3<&%L=&4@
M;/9S8VAE;@!&;W)M871I97)U;F<@96YT9F5R;F5N`%!A87(@;/9S8VAE;@!'
M97-P96EC:&5R=&5S(%-K<FEP="!A=7,@9&5M('1E;7!O<N1R96X@5F5R>F5I
M8VAN:7,@96YT9F5R;F5N+@!%;G1F97)N90!$:65S97,@16QE;65N="!A=7,@
M9&5M($1O:W5M96YT(&5N=&9E<FYE;@!"96YU='IE<B!L]G-C:&5N`$)E;G5T
M>F5R(&SV<V-H96XZ("5S`$%N9G)A9V4@:V]N;G1E(&YI8VAT(&)E86YT=V]R
M=&5T('=E<F1E;BX@6G5R_&-K9V5G96)E;F5R($9E:&QE<F-O9&4Z(`!$97(@
M9V5W_&YS8VAT92!$:65N<W0@:V]N;G1E(&YI8VAT(&=E9G5N9&5N('=E<F1E
M;BX`(B5S(B!W=7)D92!I;B!D97(@2V]N9FEG=7)A=&EO;B!F_'(@)7,@;FEC
M:'0@86YG96=E8F5N+@`B)7,B('=U<F1E(&EN(&1E<B!61E,M2V]N9FEG=7)A
M=&EO;B!N:6-H="!A;F=E9V5B96XN`"(E<R(@=W5R9&4@:6X@9&5R($MO;F9I
M9W5R871I;VX@;FEC:'0@86YG96=E8F5N+@!.;W1W96YD:6=E<R!&96QD`%IU
M<OQC:W-E='IE;@!087-S=V]R="!Z=7+\8VMS971Z96X`4V5T>F5N(%-I92!)
M:'(@4&%S<W=O<G0@>G5R_&-K`$QE='IT92!!8F9R86=E(&5I;F;\9V5N`$5R
M9V5B;FES<V4`6G5R_&-K('IU($5I;G-T96QL=6YG96X`3F5U97,@4&%S<W=O
M<G0@97)N975T(&5I;F=E8F5N`%+I=6YI;VX`2V]N9FEG=7)A=&EO;B!Z=7+\
M8VMS971Z96X`5UE325=91RU%9&ET;W(@16EN<W1E;&QU;F=E;@!2Y'1S96P`
M4F5C:'1S`%)E8VAT92#<8F5R<V-H<FEF=`!296-H=&4@5V5R=&4`7UIE:6QE
M;F5I9V5N<V-H869T96XN+BX`4F]L;&4`4G5MY&YI96X`56T@,3@PL"!D<F5H
M96X`3F%C:"!L:6YK<R!D<F5H96X`3F%C:"!R96-H=',@9')E:&5N`%IE:6QE
M;F5I9V5N<V-H869T96X`6F5I;&5N96EG96YS8VAA9G1E;@!:96EL96XZ`%)E
M9V5L;@!286AM96X@>G=I<V-H96X@86QL96X@6F5I;&5N('5N9"!3<&%L=&5N
M`%)A:&UE;B!N=7(@>G=I<V-H96X@4W!A;'1E;@!286AM96X@;G5R('IW:7-C
M:&5N(%IE:6QE;@!3=&%R=&5N`%)U<W-I<V-H92!&]G)D97)A=&EO;@!2=6%N
M9&$`4R]-24U%(&MR>71O9W)A<&AI<V-H92!5;G1E<G-C:')I9G0`36ET(%,O
M34E-12!V97)S8VAL_'-S96QT92!.86-H<FEC:'0`4T%33"U!=71H96YT:69I
M>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!335,M5F5R<V%N9`!344P@
M4VAE;&P`4U%,+4%N=V5I<W5N9R!Z=7(@06)F<F%G92!D97(@5V5R=&4`4U-(
M`$521D],1P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T
M<R!U;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E('5N9"!-:7%U
M96QO;@!386EN="!6:6YC96YT('5N9"!D:64@1W)E;F%D:6YE;@!';&5I8VAE
M<B!286AM96X@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE('5N
M9"!0<FEN8VEP90!3871E;&QI=&5N<')O=FED97(`4V%U9&DM07)A8FEE;@!3
M<&5I8VAE<FX`(B5S(B!S<&5I8VAE<FX`)7,@<W!E:6-H97)N`$5I;G-T96QL
M=6YG96X@<W!E:6-H97)N`$5R>F5U9W1E($MO;F9I9W5R871I;VX@86QS(%!(
M4"U3:W)I<'0@:6T@=&5M<&]RY')E;B!697)Z96EC:&YI<R!):')E<R!397)V
M97)S('-P96EC:&5R;BX`)7,M2V]N9FEG=7)A=&EO;B!G97-P96EC:&5R="X`
M1&%S($%K='5A;&ES:65R=6YG<W-K<FEP="!W=7)D92!I;B`B)7,B(&=E<W!E
M:6-H97)T+@!697)E:6YZ96QT92!'97=I='1E<@!7:7-S96YS8VAA9G0`4W5C
M:&4`4W5C:&UA<V-H:6YE;@!3=6-H97)G96)N:7-S90!3=6-H9F5L9&5R`%-U
M8VA?=&5X=`!$871E:65N(&%U<W?D:&QE;@!$871U;2!A=7-WY&AL96X`2&EN
M>G5Z=6;\9V5N9&4@1W)U<'!E;B!A=7-WY&AL96X`3F5U96X@0F5S:71Z97(@
M875S=^1H;&5N`$YO=&EZ8FQO8VL@875S=^1H;&5N`%-E<G9E<B!A=7-WY&AL
M96X`2&EN>G5Z=6;\9V5N9&5N($)E;G5T>F5R(&%U<W?D:&QE;@!!;&QE(&%U
M<W?D:&QE;@!,96=E;B!3:64@86QL92!$871U;7-K;VUP;VYE;G1E;B!F97-T
M+@!/8FIE:W0@875S=^1H;&5N`$ME:6YE;B!A=7-WY&AL96X`5^1H;&5N(%-I
M92!.;W1I>F)L]F-K92!A=7,Z`%?D:&QE;B!3:64@9&EE(&)E;O9T:6=T96X@
M6F5I8VAE;B!A=7,@9&5N(&IE=V5I;&EG96X@1F5L9&5R;B!A=7,N($1A;FX@
M:_9N;F5N(%-I92!D:65S92!A=7,@9&5M(%1E>'1F96QD(&MO<&EE<F5N('5N
M9"!I;B!):')E($YA8VAR:6-H="!E:6YF_&=E;BX`5^1H;&5N(%-I92!D87,@
M1&%T=6US=')E;FYZ96EC:&5N.@!7Y&AL96X@4VEE(&1A<R!$871U;7-F;W)M
M870Z`%?D:&QE;B!3:64@9&%S($5X<&]R=&9O<FUA=#H`5^1H;&5N(%-I92!D
M:64@1&%T96DL(&1I92!I;7!O<G1I97)T('=E<F1E;B!S;VQL.@!7Y&AL96X@
M4VEE(&1A<R!&;W)M870@9&5R(&EM<&]R=&EE<G1E;B!$871E:3H`5^1H;&5N
M(%-I92!D:64@261E;G1I=.1T+"!D:64@4VEE(.1N9&5R;B!M]F-H=&5N.@!7
MY&AL96X@4VEE(&1A<R!:96ET=')E;FYZ96EC:&5N.@!7Y&AL96X@4VEE(&1A
M<R!:96ET9F]R;6%T.@!7Y&AL96X@4VEE('IW96D@>G5S86UM96YG96CV<FEG
M92!&96QD97(@875S+@!7Y&AL96X@4VEE(&5I;B!&87)B<V-H96UA+@!7Y&AL
M96X@4VEE($EH<F4@8F5V;W)Z=6=T92!3<')A8VAE.@!!=7-G97?D:&QT92!+
M871E9V]R:65N.@!0<F]B;&5M8F5R:6-H="!A8G-C:&EC:V5N`%--4R!V97)S
M8VAI8VME;@!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:65N('5N
M9"!-;VYT96YE9W)O`%-E<FEE;FYU;6UE<@!397)V97)D871E;B!U;F?\;'1I
M9R!O9&5R(&YI8VAT('9E<F;\9V)A<BX`4V5S<W-I;VYV97)W86QT=6YG`%-E
M<W-I;VXM240@86)G96QA=69E;BX`4VET>G5N9V5N`$%U<W=A:&PM4V%T>@!,
M96=E;B!3:64@9&EE($5I;G-T96QL=6YG96X@9F5S="P@9&EE(&5S($EH;F5N
M(&5R;&%U8F5N($EH<B!087-S=V]R="!Z=7+\8VMZ=7-E='IE;BP@9F%L;',@
M<VEE(&5S(&5I;FUA;"!V97)G97-S96X@<V]L;'1E;BX`3&5G96X@4VEE(&5N
M=&9E<FYT92!397)V97(@9F5S="P@875F(&1I92!3:64@=F]N($EH<F5M(%!O
M<G1A;"!A=7,@>G5G<F5I9F5N(&WV8VAT96XN`%?D:&QE;B!3:64@26AR92!B
M979O<GIU9W1E(%-P<F%C:&4L(%IE:71Z;VYE('5N9"!$871U;7-E:6YS=&5L
M;'5N9V5N+@!,96=E;B!3:64@9&%S(&1I92!3=&%R=&%N=V5N9'5N9RP@9&%S
M($9A<F)S8VAE;6$L(&1I92!396ET96YA:W1U86QI<VEE<G5N9R!U;F0@86YD
M97)E($%N>F5I9V5E:6YS=&5L;'5N9V5N(&9E<W0N`$MO;F9I9W5R871I;VX`
M06MT=6%L:7-I97)U;F=S<VMR:7!T92!S:6YD('9E<F;\9V)A<@!-96AR97)E
M('!A<W-E;F1E($]R=&4@;6ET(&1I97-E;2!087)A;65T97(Z(`!397EC:&5L
M;&5N`$5I;FMA=68`2W5R>F4@6G5S86UM96YF87-S=6YG`%-O;&QE;B!487-T
M96YK;VUB:6YA=&EO;F5N(&;\<B!D:64@;65I<W1E;B!,:6YK<R!A:W1I=FEE
M<G0@=V5R9&5N/P!:96EG96X`06MT:6]N<VMN]G!F92!A;GIE:6=E;C\`56YT
M97)S8VAI961E('IW:7-C:&5N(&1E<B!A:W1U96QL96X@=6YD(&1E<B!G97)A
M9&4@97)Z975G=&5N($MO;F9I9W5R871I;VX@86YZ96EG96XN`$%N>F5I9V5N
M+"!W86YN(&1I92!L971Z=&4@06YM96QD=6YG(&5R9F]L9W0@:7-T/P!.;W1I
M>F)L;V-K;F%M92!A;GIE:6=E;C\`3F]T:7IE;B!D:65S97(@2V%T96=O<FEE
M;B!A;GIE:6=E;@!%<FAA;'1E;B!D97,@3W)I9VEN86QS(&5R;?9G;&EC:&5N
M`$%U<W?D:&QE<B!A;GIE:6=E;@!797)K>F5U9VQE:7-T92!F_'(@5&%B96QL
M96X@86YZ96EG96X_`$1A<R`E<RU-96[\(&%U9B!D97(@;&EN:V5N(%-E:71E
M(&%N>F5I9V5N/P!$:6%L;V<@9OQR(%1A8F5L;&5N>F5L;&5N96EG96YS8VAA
M9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR(%1A8F5L;&5N96EG96YS8VAA9G1E
M;B!A;GIE:6=E;@!$:6%L;V<@9OQR(%1A8F5L;&5N>F5I;&5N96EG96YS8VAA
M9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR($)I;&1E:6=E;G-C:&%F=&5N(&%N
M>F5I9V5N`$AO8VAL861E;B!E<FWV9VQI8VAE;@!38VAA=65R`$9R_&@@4V-H
M875E<@!3<.1T97(@4V-H875E<@!38VAA=65R(&EN(&1E<B!5;6=E8G5N9P!6
M97)K;&5I;F5R;@!697)K;&5I;F5R;B!O9&5R('9E<G-C:&EE8F5N(%-I92!E
M<G-T(&1I92!B96YA8VAB87)T96X@0FSV8VME`%-I97)R82!,96]N90!296=I
M<W1R:65R96X`4VEG;F%T=7(`4VEG;F%T=7)A;&=O<FET:&UU<P!3:6YG87!U
M<@!'<O;?90!787)T=6YG<V%R8F5I=&5N(/QB97)S<')I;F=E;@!3;&]W86ME
M:0!3;&]W96YI96X`4V-H;F5E`%-C:&YE97-C:&%U97(`4V-H;F5E<V-H875E
M<@!&<OQH(%-C:&YE97-C:&%U97(`4W#D=&5R(%-C:&YE97-C:&%U97(`4V-H
M;F5E:/9H93H@`%-C:&YE96UE;F=E(&%L<R!787-S97(Z(`!3;VQO;6]N:6YS
M96QN`%-O;6%L:65N`$QI961E<B`F($=E9&EC:'1E`%-O<G1I97)E;B!N86-H
M($MA=&5G;W)I90!3;W)T:65R96X@;F%C:"!.;W1I>G1E>'0`075S=V%H;"!D
M97(@4V]R=&EE<G)E:6AE;F9O;&=E`%5R<W!R=6YG<V%D<F5S<V4`4_QD869R
M:6MA`%/\9&5U<F]PY&ES8V@@*$E33RTX.#4Y+3,I`%/\9&=E;W)G:65N('5N
M9"!D:64@4_QD;&EC:&5N(%-A;F1W:6-H:6YS96QN`%/\9&QI8VAE($AE;6ES
M<&AE<F4`06)S=&%N9"!Z=VES8VAE;B!A=69E:6YA;F1E<B!F;VQG96YD96X@
M6F5L;&5N`$%B<W1A;F0@>G=I<V-H96X@26YH86QT('5N9"!286AM96X@=F]N
M(%IE;&QE;@!!8G-T86YD:&%L=&5R`$%B<W1A;F0`06)S=.1N9&4`4W!A;FEE
M;@!3<&%M`%-O;F1E<GIE:6-H96XM16EN9V%B90!:96QL92!T96EL96X`4W!A
M;'1E('1E:6QE;@!:96EL92!T96EL96X`4W!O<G0`4W)I($QA;FMA`%-T86YD
M87)D`%-T87(@5')E:P!3=&%R=&IA:'(`0G5N9&5S<W1A870@;V1E<B!0<F]V
M:6YZ`%-T871U<P!3<&5I8VAE<F9O<FUA=`!3=')AWV4`1'5R8VAG97-T<FEC
M:&5N`%IE:6-H96YL:7-T90!$;VUA:6X@875S(&1E<B!!9')E<W-E(&5N=&9E
M<FYE;@!3=&EL(%M#4U-=`%-O`%5N=&5R=F5R>F5I8VAN:7,@(B5S(B!N:6-H
M="!G969U;F1E;BX`0F5T<F5F9@!!8G-C:&EC:V5N`$1I92!296=I<W1R:65R
M=6YG<V%N9G)A9V4@9OQR("(E<R(@=W5R9&4@86)G97-C:&EC:W0N(%-I92!K
M]FYN96X@<VEC:"!N;V-H(&YI8VAT(&%N;65L9&5N+"!S;VQA;F=E(&1I92!!
M;F9R86=E(&YO8V@@;FEC:'0@8F5S=.1T:6=T('=U<F1E+@!4:65F9V5S=&5L
M;'0`17)F;VQG`"(E<R(@=W5R9&4@97)F;VQG<F5I8V@@:&EN>G5G96;\9W0N
M`$1A=&5N(&1E<R!"96YU='IE<G,@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G
M96SV<V-H="X`(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="X`(B5S
M(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="X`2V]N9FEG=7)A=&EO;B!E
M<F9O;&=R96EC:"!Z=7+\8VMG97-E='IT+B!396ET92!N974@;&%D96XL('5M
M(&1I92#$;F1E<G5N9V5N(&%N>G5Z96EG96XN`"(E<R(@=W5R9&4@97)F;VQG
M<F5I8V@@9V5S<&5I8VAE<G0N`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B!E
M<F9O;&=R96EC:"!G97-P96EC:&5R="X`0F%C:W5P(&1E<B!+;VYF:6=U<F%T
M:6]N("5S(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+@`B)7,B('=U<F1E(&5R
M9F]L9W)E:6-H(&%K='5A;&ES:65R=``E<R!W=7)D92!E<F9O;&=R96EC:"!G
M97-P96EC:&5R=`!3=61A;@!:=7-A;6UE;F9A<W-U;F<`4V]N;F5N875F9V%N
M9P!3;VYN96YU;G1E<F=A;F<`4V]N;FEG`%-O;FYE;F%U9F=A;F<`4V]N;F5N
M875F+W5N=&5R9V%N9P!3;VYN96YA=69G86YG.B``4V]N;F5N=6YT97)G86YG
M`%-O;FYE;G5N=&5R9V%N9SH@`$AO8VAG97-T96QL=`!3=7!P;W)T`%-U<FEN
M86T`3F%C:&YA;64`4W9A;&)A<F0@=6YD($IA;B!-87EE;@!3=V%S:6QA;F0`
M4V-H=V5D96X`4V-H=V5I>@!3>6YC:')O;FEZ871I;VYS;&]G(&=E;/9S8VAT
M`%-Y;F--3`!&;W)M871F96AL97(@:6X@4W5C:&)E9W)I9F9E;@!!<F%B:7-C
M:&4@4F5P=6)L:6L@4WER:65N`$=E=VET=&5R`$=E=VET=&5R('5N9"!7:6YD
M:6<`1V5W:71T97(`1G+\:"!'97=I='1E<@!44U8M1&%T96D`5&%B96QL96YE
M:6=E;G-C:&%F=&5N`%1A8F5L;&4`5&%B96QL96YE:6=E;G-C:&%F=&5N`%1A
M:7=A;@!486EW86XL(&-H:6YE<VES8VAE(%!R;W9I;GH`5&%D<V-H:6MI<W1A
M;@!697)E:6YI9W1E(%)E<'5B;&EK(%1A;G-A;FEA`%II96PZ`$%U9F=A8F5N
M`%1E;&5F;VYN=6UM97(`5&5M<&5R871U<B!D97(@;&5T>G1E;B!3='5N9&4Z
M(`!496UP97)A='5R`%1E;7!E<F%T=7(Z(`!496UP97)A='5R/&)R("\^*"5S
M36%X)7,O)7--:6XE<RD@)F1E9SLE<P!6;W)L86=E("(E<R(@;FEC:'0@9V5F
M=6YD96XN`%9O<FQA9V5N=F5R=V%L='5N9P!497AT`$YU<B!497AT`$%U<W)I
M8VAT=6YG`%1E>'0@3V)E;@!$;P!4:&%I;.1N9&ES8V@@*%1)4RTV,C`I`%1H
M86EL86YD`$1I92!&5%`M17AT96YS:6]N(&ES="!N:6-H="!V97)F_&=B87(N
M`$1I92!#:')O;FEK('-T96AT(&YI8VAT('IU<B!697)F_&=U;F<N`$1I92!(
M;W)D92]+;VQA8B!);G1E9W)A=&EO;G-F=6YK=&EO;F5N('5N=&5R<W3\='IE
M;B`B)7,B(&YI8VAT`$1I92!)35-0+4QO9V1A=&5I(&MO;FYT92!N:6-H="!E
M<G-T96QL="!W97)D96XN`$1I92!-86EN=&5N86YC93HZ($ML87-S92!K;VYN
M=&4@;FEC:'0@9V5L861E;B!W97)D96X`1&%S($5I;G-T96QL=6YG96XM1F5N
M<W1E<B!I<W0@9V5S8VAL;W-S96X@=V]R9&5N+B!!8F)R=6-H+@!$97(@061M
M:6YI<W1R871O<B!M=7-S(&5I;B!P97)M86YE;G1E<R!296-H=&4M0F%C:V5N
M9"!E:6YR:6-H=&5N+"!W96YN(%-I92!D:64@4F5C:'1E=F5R=V%L='5N9R!N
M=71Z96X@;?9C:'1E;BX`3G5R('5N=&5N`$1I92!)1"U.=6UM97(@9&5S($MO
M;G1A:W1S('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D97(@:V]N
M;G1E(&EN(&1E<B!$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@=V5R9&5N+@!$
M97(@2V]N=&%K="!W=7)D92!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B=6-H
M(&AI;GIU9V5F_&=T+@!$97(@4$=0+5-I9VYA='5R8FQO8VL@=VER9"!B96[V
M=&EG="P@=6T@9&EE('5N=&5R>F5I8VAN971E($YA8VAR:6-H="!Z=2#\8F5R
M<'+\9F5N+@!$:64@240M3G5M;65R(&1E<B!697)T96EL97)L:7-T92!W=7)D
M92!N:6-H="!A;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92!I;B!D97(@
M1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`1&EE(%9E<G1E:6QE
M<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5G96)E;BX`1&EE(%9E<G-C:&S\<W-E
M;'5N9W-F=6YK=&EO;F5N(&)E;O9T:6=E;B!E:6YE('-I8VAE<F4@4V5R=F5R
M=F5R8FEN9'5N9RX`1&EE($1A=&5I("5S('-O;&QT92!E:6YE;B`E<R!%:6YT
M<F%G(&5N=&AA;'1E;BX`1&EE($1A=&5I("5S('-O;&QT92!E:6YI9V4@)7,@
M16EN='+D9V4@96YT:&%L=&5N+@!$:64@1&%T96D@:V%N;B!N:6-H="!A=68@
M<VEC:"!S96QB<W0@:V]P:65R="!W97)D96XN`$1I92!$871E:2!E;G1H:65L
M="!K96EN92!$871E;BX`2&EE<B!S:6YD(&1I92!+;W!F96EN='+D9V4@9OQR
M(&1I97-E(&UE<W-A9V4O<F9C.#(R($YA8VAR:6-H="X`1&5R(%9O;&QB:6QD
M;6]D=7,@=F5R=7)S86-H="!A=68@1W)U;F0@=F]N($9E:&QE<FX@:6T@26YT
M97)N970@17AP;&]R97(@8F5K86YN=&5R;6'?96X@4')O8FQE;64@;6ET(&1I
M97-E;2!"<F]W<V5R+"!D:64@=VER(&YI8VAT('5M9V5H96X@:_9N;F5N+B!5
M;G1E<B!5;7-TY&YD96X@97)H86QT96X@4VEE(&5I;F4@9F5H;&5R:&%F=&4@
M06YZ96EG92P@9F5H;&5N($5D:71O<F9U;FMT:6]N96XL(&]D97(@9&5R($)R
M;W=S97(@<W3\<GIT(&%B+B!!=68@96EN96T@5VEN9&]W(#EX(%-Y<W1E;2!W
M97)D96X@4VEE('9E<FUU=&QI8V@@96EN92`G06QL9V5M96EN92!38VAU='IV
M97)L971Z=6YG)R!E<FAA;'1E;B!U;F0@;?QS<V5N(&1E;B!296-H;F5R(&YE
M=2!S=&%R=&5N+EQN7&Y3:64@=W5R9&5N(&=E=V%R;G0N($)I='1E(&1R_&-K
M96X@4VEE(&%U9B!/2RP@=V5N;B!3:64@;F]C:"!I;6UE<B!D96X@5F]L;&)I
M;&1M;V1U<R!V97)W96YD96X@;?9C:'1E;BX`1&EE($ED96YT:73D="`B)7,B
M('=U<F1E(&=E;/9S8VAT+@!.=7(@;&EN:W,`1&5R($]R="!D97,@1VYU4$<M
M4')O9W)A;6US(&UU<W,@9&5R($-R>7!T7W!G<#HZ($ML87-S92#\8F5R9V5B
M96X@=V5R9&5N+@!$:64@3F%C:')I8VAT(&UI="!D96T@0F5T<F5F9B`B)3,D
M<R(L(&1I92!A;2`E,21S(&%N("4R)',@9V5S8VAI8VMT('=U<F1E+"!I<W0@
M86YG97IE:6=T('=O<F1E;BX*1&%S(&AE:=]T(&YI8VAT+"!D87-S(&1I92!.
M86-H<FEC:'0@875C:"!G96QE<V5N(&]D97(@=F5R<W1A;F1E;B!W=7)D92X`
M3F%M92!F_'(@9&5N($QI;FL@>G5R($YA8VAR:6-H=&5N97)S=&5L;'5N9P!$
M:64@3F]T:7H@=W5R9&4@9V5L]G-C:'0N`$1E<B!.;W1I>F)L;V-K("(E<R(@
M:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E;CH@)7,`1&5R($YO=&EZ8FQO
M8VL@(B5S(B!W=7)D92!E<G-T96QL="X`1&5R($YO=&EZ8FQO8VL@(B5S(B!W
M=7)D92!G96SV<V-H="X`1&5R($YO=&EZ8FQO8VL@(B5S(B!W=7)D92!G97-P
M96EC:&5R="X`1&EE($%N>F%H;"!D97(@1F5L9&5R(&UU<W,@86QS(%IA:&P@
M86YG96=E8F5N('=E<F1E;BX`1&%S($]P96Y34TPM36]D=6P@=VER9"!F_'(@
M9&EE($AO<F1E7T-R>7!T7W-M:6UE.CH@2VQA<W-E(&)E;O9T:6=T+@!$:64@
M0F5N=71Z97)E:6YS=&5L;'5N9R`B)7,B(&MO;FYT92!N:6-H="!G97-P96EC
M:&5R="!W97)D96XL('=E:6P@:6AR92!$871E;B!D:64@;6%X:6UA;"!E<FQA
M=6)T92!'<O;?92#\8F5R<V-H<F5I=&5N`$1A<R!0<F]G<F%M;2!F_'(@9&EE
M($%N>F5I9V4@9&EE<V5S($1A=&5I='EP<R`H)7,I('=U<F1E(&YI8VAT(&=E
M9G5N9&5N+@!$87,@06YF_&AR=6YG<WIE:6-H96X@;75S<R!A;',@96EN>F5L
M;F5S(%IE:6-H96X@86YG96=E8F5N('=E<F1E;BX`3G5R(&QI;FMS('5N9"!R
M96-H=',`3G5R(')E8VAT<P!$87,@5')E;FYZ96EC:&5N(&UU<W,@86QS(&5I
M;GIE;&YE<R!:96EC:&5N(&%N9V5G96)E;B!W97)D96XN`$1E<B!397)V97(@
M(B5S(B!W=7)D92!E;G1F97)N="X`1&5R(%-E<G9E<B`B)7,B('=U<F1E(&=E
M<W!E:6-H97)T+@!$:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!W
M=7)D92!E;G1F97)N="X`1&EE(&%N9V5G96)E;F4@6F5I;&4@*"5D*2!E>&ES
M=&EE<G0@;FEC:'0N`$1I92!T96UP;W+D<F4@1&%T96D@(B5S(B!E>&ES=&EE
M<G0@;FEC:'0N`$1E<B!497AT+"!D96X@4VEE(&%N9V5G96)E;B!H86)E;BP@
M96YT<W!R:6-H="!N:6-H="!D96T@5&5X="!A=68@9&5M($)I;&1S8VAI<FTN
M`$YU<B!O8F5N('5N9"!U;G1E;@!.=7(@;V)E;@!$:64@:&]C:&=E;&%D96YE
M;B!$871E;B!S:6YD(&YA8V@@9&5M(&QE='IT96X@4V-H<FET="!V97)L;W)E
M;B!G96=A;F=E;BX`1&EE(&AO8VAG96QA9&5N92!$871E:2!K;VYN=&4@;FEC
M:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$97(@=V5A=&AE<BYC;VT@0FQO8VL@
M:7-T(&YI8VAT('9E<F;\9V)A<BX`5&AE;65N+59E<GIE:6-H;FES("(E<R(@
M;FEC:'0@9V5F=6YD96XN`$5S('-I;F0@:V5I;F4@16EN<W1E;&QU;F=E;B!V
M97)F_&=B87(N`$5S(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@3F%C:')I8VAT
M96YT96EL92X`1&EE<V5S($9E;&0@96YT:.1L="!Z=2!V:65L92!:96EC:&5N
M+B!3:64@:&%B96X@)7,@6F5I8VAE;B!A;F=E9V5B96X[(%-I92!M_'-S96X@
M=V5N:6=E<B!A;',@)7,@86YG96)E;BX`0F5I;2!(:6YZ=6;\9V5N('9O;B`B
M)7,B('IU;2!3>7-T96T@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B`E
M<P!"96EM($SV<V-H96X@9&5R($1A=&5N('9O;B!"96YU='IE<B`B)7,B(&ES
M="!E:6X@4')O8FQE;2!A=69G971R971E;CH@`$)E:6T@3/9S8VAE;B!V;VX@
M(B5S(B!A=7,@9&5M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T
M96XZ(`!"96EM($%K='5A;&ES:65R96X@=F]N("(E<R(@:7-T(&5I;B!0<F]B
M;&5M(&%U9F=E=')E=&5N.B`E<P!"96EM($AO8VAL861E;B!D97(@1&%T96D@
M:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN("5S('=U<F1E(&YI8VAT(&AO
M8VAG96QA9&5N+@!"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&
M96AL97(@875F9V5T<F5T96XN("5S('=A<B!G<O;?97(@86QS(&1I92!M87AI
M;6%L(&5R;&%U8G1E($=R]M]E("@E9"!">71E<RDN`$)E:6T@2&]C:&QA9&5N
M(&1E<B!$871E:2!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@)7,@=W5R
M9&4@;G5R('1E:6QW96ES92!H;V-H9V5L861E;BX`0F5I;2!!;GIE:6=E;B!D
M:65S97,@3F%C:')I8VAT96YT96EL<R!I<W0@96EN($9E:&QE<B!A=69G971R
M971E;BX`0F5I;2!);7!O<G1I97)E;B!D97(@2V]N=&%K=&1A=&5N(&ES="!E
M:6X@1F5H;&5R(&%U9F=E=')E=&5N+@!"96EM($EM<&]R=&EE<F5N(&1E<B!$
M871E;B!I<W0@96EN($9E:&QE<B!A=69G971R971E;CH@)7,`0F5I;2!);7!O
M<G1I97)E;B!D97(@:4-A;&5N9&%R+41A=&5N(&ES="!E:6X@1F5H;&5R(&%U
M9F=E=')E=&5N+@!"96EM($EM<&]R=&EE<F5N(&1E<B!V3F]T92U$871E;B!I
M<W0@96EN($9E:&QE<B!A=69G971R971E;BX`1&%S($MO;F9I9W5R871I;VYS
M+49O<FUU;&%R(&5N=&AI96QT(&5I;F5N($9E:&QE<BX@5FEE;&QE:6-H="!H
M86)E;B!3:64@96EN(%!F;&EC:'1F96QD(&QE97(@9V5L87-S96XN`$)E:6T@
M075S9OQH<F5N(&1E<B!A;F=E9V5B96YE;B!!9')E<W-B=6-H9G5N:W1I;VX@
M:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3
M:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+@!"96EM($SV<V-H96X@9&5R($YO
M=&EZ(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N.B`E<P!"96EM(%-P96EC
M:&5R;B!D97(@3F]T:7H@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XZ("5S
M`$)E:2!D97(@06MT=6%L:7-I97)U;F<@9&5R($MO;G1A:W1D971A:6QS(&ES
M="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92!V97)S=6-H96X@4VEE
M(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`0F5I(&1E<B!!:W1U86QI<VEE<G5N
M9R!D97(@5F5R=&5I;&5R;&ES=&4@:7-T(&5I;B!&96AL97(@875F9V5T<F5T
M96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L
M+@!"96EM($%N>F5I9V5N(&1I97-E<R!.;W1I>F)L;V-K<R!I<W0@96EN($9E
M:&QE<B!A=69G971R971E;CH@)7,`17,@:V]N;G1E;B!K96EN92!497)M:6YE
M('IU;2!%>'!O<G1I97)E;B!G969U;F1E;B!W97)D96XN`$1I97-E<B!)34%0
M+5-E<G9E<B!U;G1E<G-T_'1Z="!K96EN92!G96UE:6YS86UE;B!/<F1N97(N
M`$1I97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%)!4BU!<F-H:78@>G4@<V5I
M;BX`1&EE<R!S8VAE:6YT(&ME:6X@9_QL=&EG97,@6DE0+4%R8VAI=B!Z=2!S
M96EN+@!$:65S('-C:&5I;G0@:V5I;F4@9_QL=&EG92!+87)T96YN=6UM97(@
M>G4@<V5I;BX`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K
M96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!#;&EC:V%T96QL+4=A=&5W
M87D@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@;6ET($AI;&9E(&1E<B!(5%10
M+4%022X`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@
M=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!724XM1V%T97=A>2`H:'1T<#HO
M+W=I;G!L8RYC;VTI(&UI="!(:6QF92!D97(@2%144"U!4$DN`$1I97-E<B!4
M<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E
M;B!D=7)C:"!D96X@<VUS,FUA:6PM1V%T97=A>2`H:'1T<#HO+W-M<S)M86EL
M+F-O;2D@;6ET($AI;&9E(&1E<B!(5%10+4%022X`1&EE<V5R(%1R96EB97(@
M97)L875B="!D87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N('!E<B!3
M3510(&1U<F-H(&1E;B!6;V1A9F]N92U)=&%L:65N+4=A=&5W87D@875S<V-H
M;&EEWVQI8V@@86X@5F]D869O;F4M3G5M;65R;BX@1&%F_'(@=VER9"!E:6X@
M16UA:6QK;VYT;R!B96D@5F]D869O;F4@271A;&EE;B`H:'1T<#HO+W=W=RXQ
M.3`N:70I(&)E;O9T:6=T+@!$:65S97,@1F5L9"!I<W0@;F]T=V5N9&EG+@!$
M:65S97,@1F5L9"!D87)F(&YU<B!G86YZ92!:86AL96X@96YT:&%L=&5N+@!$
M:65S97,@1F5L9"!D87)F(&YU<B!:86AL96X@=6YD(&5I;F5N(%!U;FMT(&5N
M=&AA;'1E;BX`1&EE<V5S($9E;&0@9&%R9B!N=7(@3VMT86QZ86AL96X@96YT
M:&%L=&5N+@!$:65S97,@1F5L9"!M=7-S(&5I;F4@:V]M;6$M(&]D97(@;&5E
M<GIE:6-H96YG971R96YN=&4@3&ES=&4@=F]N(&=A;GIE;B!:86AL96X@96YT
M:&%L=&5N`$1I97-E<R!&96QD(&UU<W,@96EN92!G_&QT:6=E(%IA:&P@96YT
M:&%L=&5N+@!$:65S97,@1F5L9"!M=7-S(&5I;F5N($9A<F)W97)T(&EM(&AE
M>&%D97II;6%L96X@4D="+49O<FUA="!E;G1H86QT96XL('HN($(N("<C,3(S
M-&%F)RX`1&EE<V5S($1A=&5I9F]R;6%T('=I<F0@;FEC:'0@=6YT97)S=/QT
M>G0N`$1I97-E<R!&;W)M=6QA<B!W=7)D92!B97)E:71S('9E<F%R8F5I=&5T
M+@!$:65S(&ES="`E<RX`1&EE(&ES="!E:6X@2V]L86(M1W)O=7!W87)E+4]B
M:F5K="X@56T@9&EE<V5S($]B:F5K="!A;GIU>F5I9V5N+"!B96[V=&EG96X@
M4VEE(&5I;B!%;6%I;'!R;V=R86UM+"!D87,@9&%S($MO;&%B+4=R;W5P=V%R
M92U&;W)M870@=6YT97)S=/QT>G0N($5I;F4@3&ES=&4@<V]L8VAE<B!0<F]G
M<F%M;64@9FEN9&5N(%-I92!U;G1E<B`E<P!$:65S92!.86-H<FEC:'0@=W5R
M9&4@:6X@96EN96T@6F5I8VAE;G-A='H@*"5S*2!E<G-T96QL="P@9&5R(&YI
M8VAT($EH<F5M(&5I9V5N96X@96YT<W!R:6-H="X`1&EE<V4@6F%H;"!M=7-S
M(#$@;V1E<B!G<O;?97(@<V5I;BX`1&EE<V5R(%-E<G9E<B!K86YN(%I)4"T@
M=6YD($=:25`M1&%T96EN(&YI8VAT(&5N='!A8VME;BX`1&EE<V5S(%-Y<W1E
M;2!I<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0N`$1I97-E<B!797)T(&UU<W,@
M96EN92!:86AL('-E:6XN`$1I97-E<R!&96YS=&5R(&UU<W,@=F]N(&5I;F5M
M($5I;G-T96QL=6YG96XM1F5N<W1E<B!G9?9F9FYE="!W97)D96X`1&]N;F5R
M`%1I8VME=',`6F5I=`!:96ET97)F87-S=6YG`%IE:71F;W)M870`6F5I=&%U
M<W=A:&P`5&EM;W(M3&5S=&4`5&ET96P`5&ET96P@*%1O;VQT:7`I.@!!;@!(
M86QT96X@4VEE(&)E:6T@2VQI8VME;B!3=')G(&)Z=RX@*%!#*2!#;VUM86YD
M("A-86,I(&=E9'+\8VMT+"!U;2!M96AR97)E($5I;G1RY&=E(&%U<WIU=^1H
M;&5N+@!(975T90!:=2!(5$U,+5%U96QL8V]D92!U;7-C:&%L=&5N`%1O9V\`
M5&]K96QA=0!-;W)G96X`5&]N9V$`6G4@=FEE;&4@=6YG_&QT:6=E($%N;65L
M9&5V97)S=6-H92!I;B!D96X@;&5T>G1E;B!-:6YU=&5N+@!/8F5N`,1UWV5R
M<W1E<B!286AM96X@*%]T;W`I`-QB97)S971Z=6YG96X`5')I;FED860@=6YD
M(%1O8F%G;P!786AR(&]D97(@9F%L<V-H`$1I`%1U;F5S:65N`%3\<FME:0!4
M_')K:7-C:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS+2!U;F0@
M0V%I8V]S:6YS96QN`%1U=F%L=0!):')E($%U<W=A:&PZ(`!55BU);F1E>#H@
M`$AO;65P86=E`%523"!):')E<R!3:W)I<'1S(&;\<B!D96X@5F5R<V%N9'-T
M871U<V)E<FEC:'0`061R97-S93H`56=A;F1A`%5K<F%I;F4`075F(&1A<R!6
M1E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('IU9V5G<FEF9F5N('=E<F1E
M;BX`1&EE('IU<^1T>FQI8VAE;B!"96YU='IE<FEN9F]R;6%T:6]N96X@:V]N
M;G1E;B!B96D@9&5R(%)E9VES=')I97)U;F<@;FEC:'0@:&EN>G5F_&=T('=E
M<F1E;BX`1&EE(%IU9W)I9F9S<F5C:'1E(&;\<B!D:64@5D93+41A=&5I("(E
M<R(@:V]N;G1E;B!N:6-H="!G9>1N9&5R="!W97)D96XN`$1I92!:=6=R:69F
M<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`E<R\E<R!K;VYN=&5N(&YI8VAT
M(&=EY&YD97)T('=E<F1E;BX`17,@:V%N;B!N:6-H="!I;B!697)Z96EC:&YI
M<R`E<R!G97=E8VAS96QT('=E<F1E;BX`1&EE($=R]M]E('9O;B`B)7,B(&MO
M;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN`$1I92!'<O;?92!V;VX@(B5S
M+R5S(B!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!697)B:6YD=6YG
M('IU;2!344P@4V5R=F5R(&MA;FX@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N
M+@!34TPM5F5R8FEN9'5N9R!K;VYN=&4@;FEC:'0@:&5R9V5S=&5L;'0@=V5R
M9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!K;W!I97)T('=E<F1E
M;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!A;F=E
M;&5G="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT
M(&%N9V5L96=T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@
M86YG96QE9W0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES("(E<R(@:V]N
M;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`3&5E<F4@5D93+41A=&5I(&MO
M;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$1I92!$871E;B!K;VYN=&5N
M(&YI8VAT(&1E:V]M<')I;6EE<G0@=V5R9&5N+@`B)7,B(&MO;FYT92!N:6-H
M="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC:'0@
M;&5E<BX`(B5S(B!K86YN(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,`(B5S
M(B!K86YN(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N`"5S(&MO;FYT92!N
M:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC
M:'0@;&5E<@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!R96MU
M<G-I=B!G96SV<V-H="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N
M;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI
M<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N.B`E<RX`1&EE(%9&4RU$
M871E:2`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1I92!6
M1E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`1&%S(%9&
M4RU697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D
M96XN`$1A<R!61E,@:V]N;G1E(&YI8VAT(')E:W5R<VEV(&=E;/9S8VAT('=E
M<F1E;CH@)7,N`$1A<R!A:W1U96QL92!697)Z96EC:&YI<R!K;VYN=&4@;FEC
M:'0@8F5S=&EM;70@=V5R9&5N+@!$:64@6F5R=&EF:6MA=&1E=&%I;',@:V]N
M;G1E;B!N:6-H="!A=7-G96QE<V5N('=E<F1E;@!$97(@)7,M5')E:6)E<B!K
M;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96XN`$1I92!61E,M1&%T96D@:V]N
M;G1E(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N+@!$:64@5D93+41A=&5I("(E
M<R(@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX`1&EE(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@>G5M($)E<V-H<F5I8F5N(&=E]F9F;F5T('=E<F1E
M;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N
M+@!$87,@07)C:&EV(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN`$1I
M92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N("AF:6QE
M<VEZ92@I(&9E:&QG97-C:&QA9V5N*2X`1&EE(%9&4RU$871E:2!K;VYN=&4@
M;FEC:'0@9V5L97-E;B!W97)D96X@*&=E=$9I;&53:7IE*"D@9F5H;&=E<V-H
M;&%G96XI+@!$:64@1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N
M.B``1&%S('9F<W)O;W0M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;&5S
M96X@=V5R9&5N+@`E<R!K;VYN=&4@;FEC:'0@;F%C:"`E<R!U;6)E;F%N;G0@
M=V5R9&5N.B!$87,@6FEE;'9E<GIE:6-H;FES(&5X:7-T:65R="!B97)E:71S
M`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W
M97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('5M8F5N
M86YN="!W97)D96XZ("5S+@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI
M8VAT('5M8F5N86YN="!W97)D96XN`$1I92!61E,M1&%T96D@)7,O)7,@:V]N
M;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N
M;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XN`")M:VES;V9S(B!K;VYN=&4@
M;FEC:'0@875S9V5F_&AR="!W97)D96XN`$1I97-E<R!7;W)D+41O:W5M96YT
M(&SD<W-T('-I8V@@;FEC:'0@86YZ96EG96X`1&EE(%9&4RU$871E:2`B)7,B
M(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN`$1I92!61E,M1&%T
M96D@:V]N;G1E(&YI8VAT(&=E<V-H<FEE8F5N('=E<F1E;B`H8V]P>2@I(&9E
M:&QG97-C:&QA9V5N*2X`1&EE(%9&4RU$871E;B!K;VYN=&5N(&YI8VAT(&=E
M<V-H<FEE8F5N('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@
M9V5S8VAR:65B96X@=V5R9&5N+"!D87,@4W!E:6-H97)P;&%T>BU+;VYT:6YG
M96YT('?\<F1E(/QB97)S8VAR:71T96XN`%5N=&5R<W1R:6-H96X`Q&YD97)U
M;F=E;B!R_&-K9^1N9VEG(&UA8VAE;@#$;F1E<G5N9V5N('+\8VMGY&YG:6<@
M;6%C:&5N`$UA8VAT(&1I92!L971Z=&4@06MT:6]N('+\8VMGY&YG:6<`56YG
M_&QT:6=E(%+\8VMM96QD=6YG('9O;2!397)V97(@8F5I;2!(97)S=&5L;&5N
M(&1E<B!697)B:6YD=6YG.B``56YE<G=A<G1E=&4@06YT=V]R="!D97,@4V5R
M=F5R<R!A=68Z(`!.:6-H="!Z=6=E;W)D;F5T`%5N:6-O9&4@*%541BTX*0!6
M97)E:6YI9W1E($%R86)I<V-H92!%;6ER871E`%9E<F5I;FEG=&5S($OV;FEG
M<F5I8V@`5F5R96EN:6=T92!3=&%A=&5N`$ML96EN97)E($%M97)I:V%N:7-C
M:&4@W&)E<G-E96EN<V5L;@!%:6YH96ET96X`56YB96MA;FYT`%5N8F5K86YN
M=&4@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YB96MA;FYT92!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!%<R!W=7)D92!E:6X@=6YB96MA
M;FYT97(@3W)T(&%N9V5G96)E;BX`56YB96MA;FYT97(@0F5N=71Z97)N86UE
M(&]D97(@4&%S<W=O<G0N`$QI;FL@=F]M(&%K='5E;&QE;B!%;&5M96YT(&5N
M=&9E<FYE;@!5;F)E;F%N;G0`075S(%-I8VAE<FAE:71S9W+\;F1E;B!D_')F
M96X@=6YA=71O<FES:65R=&4@4VMR:7!T92!N:6-H="!A=7-C:&YE:61E;BP@
M:V]P:65R96X@=6YD(&5I;F;\9V5N+B!+;&EC:V5N(%-I92!A=68@3TLL('5M
M(&5I;F5N($AI;G=E:7,@875F(&UO>FEL;&$N;W)G(&%N9V5Z96EG="!Z=2!B
M96MO;6UE;BP@9&5R(&)E<V-H<F5I8G0L('=I92!3:64@96EN96T@4VMR:7!T
M(&1E;B!:=6=R:69F(&%U9B!D:64@6G=I<V-H96YA8FQA9V4@97)L875B96X@
M:_9N;F5N+@!&87)B92!Z=7+\8VMS971Z96X`3FEC:'0@=6YT97)S=/QT>G1E
M<B!);FAA;'1S='EP.B`E<P!%<G=E:71E<G5N9R!N:6-H="!U;G1E<G-T_'1Z
M=`!!:W1U86QI<VEE<G5N9P`E<R!A:W1U86QI<VEE<F5N`$)E;G5T>F5R(&%K
M='5A;&ES:65R96X`(B5S(B!W=7)D92!A:W1U86QI<VEE<G0N`$%K='5A;&ES
M:65R=6YG<W-K<FEP="!G96SV<V-H="X`2&]C:&QA9&5N`$1I92!+;VYF:6=U
M<F%T:6]N<V1A=&5I96X@86QL97(@06YW96YD=6YG96X@=W5R9&5N(&%U9B!D
M96X@4V5R=F5R(&AO8VAG96QA9&5N+@!'<BX@;&%T96EN:7-C:&4@0G5C:'-T
M86)E;@!'<BX@<O9M:7-C:&4@6F%H;&5N`%5R=6=U87D`06MT=65L;&4@8F5N
M=71Z96XZ("5S`%-33"!B96YU='IE;@!":71T92!A=7-F_&QL96XL('=E;FX@
M4VEE(&5I;F5N(&%N9&5R96X@0F5N=71Z97)N86UE;B]087-S=V]R="!F_'(@
M9&5N($E-4U`M4V5R=F5R(&AA8F5N+@!"96YU='IE<@!"96YU='IE<B`E<R!I
M<W0@9OQR("5S(&YI8VAT(&%U=&]R:7-I97)T+@!"96YU='IE<G9E<G=A;'1U
M;F<`0F5N=71Z97)E:6YS=&5L;'5N9V5N`$)E;G5T>F5R<F5G:7-T<FEE<G5N
M9P!$:64@0F5N=71Z97)R96=I<W1R:65R=6YG('=U<F1E(&%U9B!D:65S96T@
M4WES=&5M(&1E86MT:79I97)T+@!"96YU='IE<FMO;G1O(&YI8VAT(&=E9G5N
M9&5N`$)E;G5T>F5R;F%M90!$97(@0F5N=71Z97)N86UE("(E<R(@97AI<W1I
M97)T(&)E<F5I=',N`$)E;G5T>F5R;F%M93H`0F5N=71Z97)N86UE.B``0F5N
M=71Z97(@9&5S(%-Y<W1E;7,Z`%5S8F5K:7-T86X`1&%S(%9&4RU697)Z96EC
M:&YI<R!E>&ES=&EE<G0@;FEC:'0N`$%B=V5S96YH96ET`%!A<W-E;F1E(&=E
M9G5N9&5N92!/<G1E.B``1_QL=&EG:V5I=`!797)T(&EN($UI;G5T96X@=F]N
M(&IE='IT(&%N+@!$97(@5V5R="!I<W0@_&)E<B!D97(@;6%X:6UA;&5N($SD
M;F=E('9O;B`E<RX`5V5R=&4`5V5R=&4L(&%U<R!D96YE;B!A=7-G97?D:&QT
M('=E<F1E;B!K86YN`%9A;G5A='4`1')E:&5N9`!696YE>G5E;&$`W&)E<G!R
M_&9U;F<@9F5H;&=E<V-H;&%G96X@+2!D:65S92!.86-H<FEC:'0@:_9N;G1E
M(&UA;FEP=6QI97)T('=O<F1E;B!S96EN+@!697)S:6]N`%9E<G-I;VYS:V]N
M=')O;&QE`$%U<W)I8VAT=6YG`%9E<G1I:V%L97(@26YN96YA8G-T86YD`%9E
M<G1I:V%L.@!396AR($AO8V@`5FEE=&YA;0!6:65T;F%M97-I<V-H("A625-#
M24DI`"5S(&%N>F5I9V5N`$5I;F4@97AT97)N92!796)S96ET92!A;GIE:6=E
M;@!!;GIE:6=E;B!A;',@)7,`0G)I=&ES8VAE($IU;F=F97)N:6YS96QN`$%M
M97)I:V%N:7-C:&4@2G5N9V9E<FYI;G-E;&X`4VEC:'0`4VEC:'0Z(`!6;V1A
M9F]N92!)=&%L:65N('!E<B!33510`%=!4DY53D<`5T%23E5.1R$A(2!,UE-#
M2$5.(%-)12!$05,@4TM225!4($U!3E5%3$P@0553("5S+@!724X@_&)E<B!(
M5%10`%=A;&QI<R!U;F0@1G5T=6YA`%=A<FYU;F<`36D`5V5T=&5R=F]R:&5R
M<V%G90!7971T97)D871E;B!V;VX`5V5A=&AE<BYC;VT`5V5B`%=E8G-I=&4`
M5_9C:&5N=&QI8V@`5VEL;&MO;6UE;@!7:6QL:V]M;65N(&)E:2`E<P!7:6QL
M:V]M;65N+"`E<P!797-T975R;W#D:7-C:"`H25-/+3@X-3DM,2D`5V5S=&5U
M<F]PY&ES8V@@*$E33RTX.#4Y+3$U*0!797-T<V%H87)A`%=E;&-H92!!;G=E
M;F1U;F<@<V]L;"`E<R!N86-H(&1E;2!!;FUE;&1E;B!A;F=E>F5I9V5N/P!7
M96QC:&5S(%1R96YN>F5I8VAE;B!W:7)D('9E<G=E;F1E=#\`5V5L8VAE($%N
M9OQH<G5N9W-Z96EC:&5N('=E<F1E;B!V97)W96YD970_`%=H97)E:7,M075S
M=')A;&EA+4MA<G1E`%IU('=E;&-H96T@3F]T:7IB;&]C:R!S;VQL96X@9&EE
M($YO=&EZ96X@:&EN>G5G96;\9W0@=V5R9&5N/P!796QC:&4@4&AA<V5N`%=E
M;&-H92!0;'5G:6YS(&;\<B!D96X@5UE325=91RU%9&ET;W(@<V]L;&5N(&%K
M=&EV:65R="!W97)D96X_`$)R96ET90!"<F5I=&4@:6X@0U-3+45I;FAE:71E
M;@!"<F5I=&4@9&5S("5S+4UE;OQS(&QI;FMS("AW:7)K<V%M(&YA8V@@9&5R
M(&[D8VAS=&5N($%N;65L9'5N9RDZ`%1A8F5L;&5N8G)E:71E`$5I;FAE:70`
M0G)E:71E.@!7:6MI`%=I;F0`1G+\:"!7:6YD`%=I;F1G97-C:'=I;F1I9W1K
M96ET(&EN($MN;W1E;@!7:6YD.@!7:6YD.B``5V5I<VAE:70`5W5N<V-H>F5T
M=&5L`$%R8F5I=`!!9')E<W-E(&=E<V-HY&9T;&EC:`!496QE9F]N(&=E<V-H
MY&9T;&EC:`!&86QS8VAE($%N>F%H;"!A;B!&96QD97)N(&EN(%IE:6QE("5D
M+B`E9"!E<G=A<G1E="P@)60@9V5F=6YD96XN`$9A;'-C:&4@06YZ86AL(&%N
M($9E;&1E<FXN("5D(&5R=V%R=&5T+"`E9"!G969U;F1E;BX`56YG_&QT:6=E
M<B!/9F9S970@)60@8F5I;2!,97-E;B!D97(@5D93+41A=&5I+@!1=65R=F5R
M=V5I<V4`6#4P.78S($=E;F5R96QL92!%:6YS8VARY&YK=6YG`%@U,#EV,R!%
M<G=E:71E<G1E<B!38VAL_'-S96QZ=V5C:P!8-3`Y=C,@06QT97)N871I=F5R
M($YA;64@9&5S(%IE<G1I9FEK871I;FAA8F5R<P!8-3`Y=C,@261E;G1I=.1T
M(&1E<R!:97)T:69I:V%T<V-H;/QS<V5L<P!8-3`Y=C,@17)W96ET97)U;F=E
M;@!*2@!*2DI*`%EA:&]O(2!+87)T90!*Y&AR;&EC:`!*96UE;@!*80!*82P@
M:6-H('-T:6UM92!Z=0!3:64@8F5F:6YD96X@<VEC:"!I;2!497AT;6]D=7,N
M($)E;G5T>F5N(%-I92!D96X@6SP^72!+;F]P9BP@=6T@:6X@9&5N(%=94TE7
M24<M36]D=7,@>G4@=V5C:'-E;&XN`%-I92!D_')F96X@;FEC:'0@;65H<B!A
M;',@)60@0FSV8VME(&5R<W1E;&QE;BX`4VEE(&3\<F9E;B!N:6-H="!M96AR
M(&%L<R`E9"!.;W1I>F5N(&5R<W1E;&QE;BX`4VEE('-I;F0@;FEC:'0@86YG
M96UE;&1E="X`4VEE(&3\<F9E;B!D87,@6F5I8VAE;B`G7"<@;FEC:'0@:6X@
M26AR96T@3F%M96X@=F5R=V5N9&5N+@!3:64@:&%B96X@:V5I;F4@9_QL=&EG
M92!%;6%I;&%D<F5S<V4@86YG96=E8F5N+@!3:64@:&%B96X@:V5I;F4@1F5L
M9&5R(&%U<R!D96X@:6UP;W)T:65R=&5N($1A=&5N(&1E;B!E;G1S<')E8VAE
M;F1E;B!&96QD97)N(&EN("5S('IU9V5O<F1N970N`%-I92!H86)E;B!N:6-H
M="!G96[\9V5N9"!296-H=&4L('5M(&1E;B!.;W1I>F)L;V-K("5S(&%N>G5Z
M96EG96XN`%-I92!W=7)D96X@86)G96UE;&1E="X`4VEE(&W\<W-E;B!E:6YE
M(&?\;'1I9V4@36]B:6QT96QE9F]N;G5M;65R(&%N9V5B96XL(&YU<B!A=7,@
M6F%H;&5N('5N9"!G9V8N(&5I;F5M("(K(B!F_'(@:6YT97)N871I;VYA;&4@
M5F]R=V%H;&5N(&)E<W1E:&5N9"X`4VEE(&W\<W-E;B!E:6YE;B!G_&QT:6=E
M;B!797)T(&%N9V5G96)E;BX`4VEE(&W\<W-E;B!E:6X@1&%T851R964M0F%C
M:V5N9"!K;VYF:6=U<FEE<F5N+"!U;2!296=I<W1R:65R=6YG96X@=F5R=V5N
M9&5N('IU(&OV;FYE;BX`4VEE(&W\<W-E;B!E:6X@5D93+4)A8VME;F0@:V]N
M9FEG=7)I97)E;BX`4VEE(&W\<W-E;B!D87,@4')O8FQE;2!B97-C:')E:6)E
M;BP@=6T@9&5N($)E<FEC:'0@86)Z=7-C:&EC:V5N+@!3:64@;?QS<V5N(&1I
M92!54DP@86YG96)E;BP@875F(&1I92!D:65S97(@3&EN:R!V97)W96ES96X@
M<V]L;`!3:64@;?QS<V5N(&1E;B!Z=2!L]G-C:&5N9&5N($YO=&EZ8FQO8VL@
M875S=^1H;&5N+@!3:64@;?QS<V5N(&5R<W0@9&5N('IU(&5N=&9E<FYE;F1E
M;B!397)V97(@875S=^1H;&5N+@!3:64@;?QS<V5N(&5I;F5N($)E;G5T>F5R
M;F%M96X@86YG96)E;BP@9&5S<V5N($1A=&5N(&=E;/9S8VAT('=E<F1E;B!S
M;VQL96XN`%-I92!M_'-S96X@96EN96X@>G4@;/9S8VAE;F1E;B!"96YU='IE
M<FYA;65N(&%N9V5B96XN`%-I92!M_'-S96X@96EN96X@:&EN>G5Z=6;\9V5N
M9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BX`4VEE(&W\<W-E;B!D96X@>G4@
M86MT=6%L:7-I97)E;F1E;B!"96YU='IE<FYA;65N(&%N9V5B96XN`%-I92!M
M_'-S96X@96EN92!!:W1I;VX@86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE;B!N
M975E;B!+871E9V]R:65N86UE;B!A;F=E8F5N+@!3:64@;?QS<V5N(&5I;F4@
M271A;&EE;FES8VAE(%1E;&5F;VYN=6UM97(@86YG96)E;@!):')E("5S+5-E
M<W-I;VX@:7-T(&%B9V5L875F96XN($)I='1E(&UE;&1E;B!3:64@<VEC:"!E
M<FYE=70@86XN`$EH<F4@16UA:6PM061R97-S90!):')E(%9O;CH@061R97-S
M93H`26AR92!!;F=A8F5N`$EH<F4@26YT97)N971A9')E<W-E(&AA="!S:6-H
M(&=EY&YD97)T+"!S96ET(%-I92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B!H
M86)E;BX@6G5M(%-C:'5T>B!):')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@
M<VEC:"!N974@86YM96QD96XN`$EH<B!.86UE`$EH<B!!=71H96YT:69I>FEE
M<G5N9W-S>7-T96T@97)L875B="!K96EN($AI;GIU9OQG96X@=F]N(&YE=65N
M($)E;G5T>F5R;BX@5V5N;B!3:64@2&]R9&4@8F5N=71Z96X@;?9C:'1E;BP@
M=6T@26AR92!"96YU='IE<B!Z=2!V97)W86QT96XL(&W\<W-E;B!3:64@96EN
M96X@86YD97)E;B!!=71H96YT:69I>FEE<G5N9W-T<F5I8F5R(&)E;G5T>F5N
M+@!):'(@075T:&5N=&EF:7II97)U;F=S<WES=&5M(&5R;&%U8G0@9&%S($%N
M>F5I9V5N(&1E<B!"96YU='IE<B!N:6-H="P@;V1E<B!D:65S92!-]F=L:6-H
M:V5I="!W=7)D92!A=7-G97-C:&%L=&5T+@!):'(@0G)O=W-E<B!H870@<VEC
M:"!A;G-C:&5I;F5N9"!G9>1N9&5R="!S96ET(%-I92!D:64@)7,M4VET>G5N
M9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C:'5T>B!):')E<B!3:6-H97)H96ET
M(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN`$EH<B!"<F]W<V5R('5N
M=&5R<W3\='IT(&1I97-E($9U;FMT:6]N(&YI8VAT+@!):'(@0G)O=W-E<B!U
M;G1E<G-T_'1Z="!D:65S92!$<G5C:V9U;FMT:6]N(&YI8VAT+B!":71T92!D
M<OQC:V5N(%-I92!3=')G+TMO;6UA;F1O("L@4"!U;2!Z=2!D<G5C:V5N+@!)
M:')E(&%K='5E;&QE(%IE:71Z;VYE.@!):')E(%-T86YD87)D:61E;G1I=.1T
M('=U<F1E(&=EY&YD97)T+@!):')E(%-T86YD87)D:61E;G1I=.1T.@!):'(@
M4W1A;F1A<F0M3F]T:7IB;&]C:SH`26AR('9O;&QS=.1N9&EG97(@3F%M93H`
M26AR(%IU9V%N9R!I<W0@86)G96QA=69E;BX`26AR(&YE=65S(%!A<W-W;W)T
M(&;\<B`E<R!L875T970Z("5S`$EH<F4@3F]T:7IB;/9C:V4Z`$EH<F4@16EN
M<W1E;&QU;F=E;B!W=7)D96X@9OQR(&1I92!$875E<B!D:65S97(@4VET>G5N
M9R!G97-P96EC:&5R="X`26AR92!%:6YS=&5L;'5N9V5N('=U<F1E;B!G97-P
M96EC:&5R="X`26AR(%!A<W-W;W)T('=U<F1E('IU<OQC:V=E<V5T>G0`26AR
M(%!A<W-W;W)T('=U<F1E('IU<OQC:V=E<V5T>G0N(%)U9F5N(%-I92!):')E
M($5M86EL<R!A8B!U;F0@;65L9&5N(%-I92!S:6-H(&UI="!):')E;2!N975E
M;B!087-S=V]R="!A;BX`26AR(%!A<W-W;W)T(&ES="!A8F=E;&%U9F5N+@!)
M:')E(%-E<G9E<CH`2G5G;W-L87=I96X`6F%I<F4`4V%M8FEA`%-I;6)A8G=E
M`%II<'!Y`%M::71A='1E>'0@=F5R<W1E8VME;ET`6U!R;V)L96UB97)I8VAT
M70!;6FET871T97AT(&%N>F5I9V5N("T`6UII=&%T=&5X="!A;GIE:6=E;B`M
M("5S(%IE:6QE;ET`6UIE:6QE("5S('9O;B`E<UT`7T%D;6EN:7-T<F%T:6]N
M`%]:=7+\8VL@>G5M($YO=&EZ8FQO8VL`0F5?9F5H;'-Z96EL90!?2V%T96=O
M<FEE`%]$871A5')E90!?3/9S8VAE;@!:96EL92!?;/9S8VAE;@!?0F5A<F)E
M:71E;@!%<G-T92!?6F5I;&4`7T=R=7!P96X`7TAI;&9E`%]":6QD96EG96YS
M8VAA9G1E;BXN+@!?26UP;W)T+T5X<&]R=`!.;W1I>F5N(%]A;GIE:6=E;@!!
M;E]M96QD96X`06)?;65L9&5N`$QI;FL@7V)E87)B96ET96XN+BX`7TUE:6YE
M($YO=&EZ8FSV8VME`%].975E($YO=&EZ`%]%:6YS=&5L;'5N9V5N`%]296-H
M=&4`7T1R=6-K96X`3&EN:R!?96YT9F5R;F5N+BXN`%]3=6-H90!?2V]N9FEG
M=7)A=&EO;@!?5&%B96QL96YE:6=E;G-C:&%F=&5N+BXN`%]"96YU='IE<@!!
M9')E<W-B=6-H`$%D<F5S<V%T('5N8F5K86YN=`!+86QE;F1E<@!W:6YD<W1I
M;&P`075S9V%B961A=&5I(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96X`
M16EN9V%B92!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E;@!K;&EC:V5N(%-I
M92!H:65R`%5N9_QL=&EG92!"96YU='IU;F<@9&5R($MO;6UA;F1O>F5I;&4`
M2V]N9FEG=7)A=&EO;G-F96AL97(`2W)I=&ES8VAE(%-Y<W1E;61A=&5I(&9E
M:&QT`$1A=&5N9F]R;6%T9F5H;&5R`&)E87)B96ET96X`16EN=')A9R!N:6-H
M="!G969U;F1E;@!F86QL96YD`$1A=&5I`&%U<R`E<R`H)7,I(&UI="`E<R`E
M<P!B]FEG`&@Z`&AH`$AO<W1N86UE('5N8F5K86YN=`!S;V9O<G0`26YL:6YE
M`$5I;BTO075S9V%B969E:&QE<@!);G1E<FYE<B!3;V9T=V%R969E:&QE<@!:
M96EL96Y=`&UK:7-O9G,M1F5H;&5R8V]D92`E9"!B96D@9&5R($5R<W1E;&QU
M;F<@9&5S($E33RU!8F)I;&1E<RX`;6T`3F%M90!N:6-H="!I;7!L96UE;G1I
M97)T`$YO8V@@;FEC:'0@:6UP;&5M96YT:65R=`!.;W1I>F)L;V-K`&YO=&EZ
M96XN8W-V`%!R;WIE;G0`6G5G<FEF9B!V97)W96EG97)T`%!I>&5L`%)E;6]T
M969E:&QE<B!I;2!0<F]T;VMO;&P`<W1E:6=E;F0`4V5R=FEC92!N:6-H="!V
M97)F_&=B87(`56YT97)S8VAI961E(&%N>F5I9V5N`'-M<S)E;6%I;"#\8F5R
M($A45%``<W,`9VQE:6-H8FQE:6)E;F0`4WES=&5M9F5H;&5R`$%U9F=A8F5N
M;&ES=&4`5F]R_&)E<F=E:&5N9&5R($9E:&QE<@!G96)E;B!3:64@9&%S(%!A
M<W-W;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@0F5S=.1T:6=U;F<@96EN`'5N
M:69I960`=6YB96YA;FYT`&)E;G5T>F5R9&5F:6YI97)T`'9#87)D`'9.;W1E
M`&(Z`'=E871H97(N8V]M````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]D95]$
M12]H96QP+GAM;```````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4R
M-#,`,3`T,3<S-C(W-#0`,#(Q-#$Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I
M;F<](FES;RTX.#4Y+3$B/SX*/"$M+2`D2&]R9&4Z(&UN96UO+VQO8V%L92]D
M95]$12]H96QP+GAM;"QV(#$N,R`R,#`T+S$R+S`S(#`R.C`S.C$V(&IA;B!%
M>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)/=F5R=FEE=R(@;60U/2(U
M,&5E-S8Q,SAF8C`X8C`T8C`R.3`P-C`U,V)B861B8R(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93[<8F5R<VEC:'0\+W1I=&QE/@H@("`@/&AE861I
M;F<^16EN9OQH<G5N9SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("`\:3Y.
M;W1I>F5N/"]I/B!I<W0@<V\@971W87,@=VEE(&5I;B!.;W1I>F)L;V-K(&EM
M($-O;7!U=&5R+B!3:64@:_9N;F5N"B`@("`@($YO=&EZ96X@97)S=&5L;&5N
M+"!B96%R8F5I=&5N+"!L]G-C:&5N('5N9"!D<G5C:V5N+B!3:64@:_9N;F5N
M($EH<F4*("`@("`@3F]T:7IE;B!A==]E<F1E;2!D=7)C:'-U8VAE;BP@=6T@
M26YF;W)M871I;VYE;B!W:65D97)Z=69I;F1E;BX@077?97)D96T*("`@("`@
M:_9N;F5N(%-I92!):')E($YO=&EZ96X@:6TM('5N9"!E>'!O<G1I97)E;BX*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("!!;F1E<G,@86QS(&)E:2!E
M:6YE;2!E8VAT96X@3F]T:7IB;&]C:R!K]FYN96X@4VEE($EH<F4@3F]T:7IE
M;B!M:70*("`@("`@86YD97)E;B!097)S;VYE;B!A;B!A;F1E<F5N($]R=&5N
M('1E:6QE;BX@3F]T:7IE;B!K]FYN96X@:6X@3F]T:7IB;/9C:V5N"B`@("`@
M('IU<V%M;65N9V5F87-S="!U;F0@2V%T96=O<FEE;B!Z=6=E;W)D;F5T('=E
M<F1E;BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;&ES
M="UA8W1I;VYS(B!M9#4](C9D-3DR9C$U,V)F8C5C,CDV9&4U9&9E8F(T,CAE
M,6)A(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DYO=&EZ8FQO8VLZ
M($%K=&EO;F5N/"]T:71L93X*("`@(#QH96%D:6YG/D%K=&EO;F5N/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("`@(#QI/DYO=&EZ(&SV<V-H96X\+VD^(&SV
M<V-H="!D:64@875S9V5WY&AL=&4@3F]T:7H@96YD9_QL=&EG+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("`@($UI="`\:3Y.;W1I>B!B96%R8F5I=&5N
M/"]I/B!K]FYN96X@4VEE(&5I;F4@8F5S=&5H96YD92!.;W1I>B!B96%R8F5I
M=&5N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(#QI/EIU<OQC:R!Z
M=6T@3F]T:7IB;&]C:SPO:3X@9OQH<G0@4VEE('9O;B!D97(@3F]T:7IA;G-I
M8VAT('IU<OQC:R!Z=6T*("`@("`@3F]T:7IB;&]C:RX*("`@(#PO<&%R83X*
M("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UA8W1I;VYS(B!M9#4](C<Q
M-6$X-3-D.3-C9#,S,S!E-&0W,S!B.3$Q,F,X83@R(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/DUE;OQP=6YK=&4\+W1I=&QE/@H@("`@/&AE861I
M;F<^365N_'!U;FMT93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("`\:3Y.
M;W1I>F5N(&%N>F5I9V5N/"]I/B!Z96EG="!E:6YE($QI<W1E(&%L;&5R($YO
M=&EZ96X@86XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@36ET(#QI
M/DYE=64@3F]T:7H\+VD^(&OV;FYE;B!3:64@;F5U92!.;W1I>F5N(&EM($YO
M=&EZ8FQO8VL@97)S=&5L;&5N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("`@(%5N=&5R(#QI/E-U8VAE/"]I/B!K]FYN96X@4VEE($EH<F4@3F]T:7IE
M;B!N86-H(&5I;F5M(%1E>'0*("`@("`@9'5R8VAS=6-H96XN(%-I92!K]FYN
M96X@:6T@0F5S8VAR96EB=6YG<V9E;&0@;V1E<B!I;2!G97-A;71E;B!497AT
M(&1E<@H@("`@("!.;W1I>F5N('-U8VAE;BX*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@("`\:3Y);7!O<G0O17AP;W)T/"]I/B!E<FQA=6)T($EH;F5N
M(&1A<R!);2T@=6YD($5X<&]R=&EE<F5N('9O;@H@("`@("!.;W1I>F5N+B!:
M=7(@6F5I="!W97)D96X@:V]M;6%G971R96YN=&4@*$-35BD@=6YD('9.;W1E
M+41A=&5I96X*("`@("`@=6YT97)S=/QT>G0N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@("`@/&D^1')U8VME;CPO:3X@]F9F;F5T(&5I;B!N975E<R!&
M96YS=&5R+"!M:70@9&5M(%-I92!E:6YE($YO=&EZ"B`@("`@(&%U<V1R=6-K
M96X@:_9N;F5N+B!$97(@/&D^1')U8VME;CPO:3XM16EN=')A9R!W:7)D(&YU
M<B!I;B!D97(*("`@("`@3F]T:7IE;F%N<VEC:'0@86YG97IE:6=T+@H@("`@
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)S;W)T:6YG(B!M9#4]
M(F-C83-B,60Q8SEE9#!E8S5A8C,X-68X,C0V.61D8SAF(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/D5I;G1RY&=E('-O<G1I97)E;CPO=&ET;&4^
M"B`@("`\:&5A9&EN9SY%:6YT<N1G92!S;W)T:65R96X\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@("`@5V5N;B!3:64@<VEC:"!E:6YE($QI<W1E(&UI="!%
M:6YT<N1G96X@86YZ96EG96X@;&%S<V5N+"!K]FYN96X@4VEE(&1I90H@("`@
M("!%:6YT<N1G92!N86-H(&IE9&5R(&)E;&EE8FEG96X@4W!A;'1E('-O<G1I
M97)E;BP@:6YD96T@4VEE(&%U9B!D:64*("`@("`@:F5W96EL:6=E(%-P86QT
M96[\8F5R<V-H<FEF="!K;&EC:V5N+B!796YN(%-I92!D:64@4V]R=&EE<G)E
M:6AE;F9O;&=E"B`@("`@('5M<V-H86QT96X@;?9C:'1E;BP@:VQI8VME;B!3
M:64@875F(&1A<R!09F5I;'-Y;6)O;"!I;B!D97(*("`@("`@4W!A;'1E;OQB
M97)S8VAR:69T+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"CPO:&5L<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+V-S7T-:+P``````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P
M,3<W-S<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O8W-?
M0UHO3$-?34534T%'15,O````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S0T`#`R,34V-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VUN96UO+VQO8V%L92]C<U]#6B],0U]-15-304=%4R]M;F5M;RYM;P``````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`S-3(U,C4`,3`T,3<S-C(W-#0`,#(S,C0U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
M_08``!P````$.```50D``.QO````````0)4```X```!!E0``#P```%"5```-
M````8)4```@```!NE0``"P```'>5```,````@Y4```0```"0E0``#````)65
M```(````HI4```\```"KE0``"P```+N5```.````QY4```4```#6E0``*```
M`-R5```(````!98```H````.E@``%0```!F6```2````+Y8```L```!"E@``
M'0```$Z6```.````;)8```H```![E@``#0```(:6```.````E)8``!$```"C
ME@``#0```+66```,````PY8```T```#0E@``!@```-Z6```/````Y98``!@`
M``#UE@``#`````Z7```&````&Y<```X````BEP``#@```#&7```(````0)<`
M`"X```!)EP``&@```'B7```R````DY<``#@```#&EP``5````/^7``!1````
M5)@``%H```"FF```5P````&9```T````69D```<```".F0``"@```):9```/
M````H9D```4```"QF0``!@```+>9```1````OID```@```#0F0``"0```-F9
M```)````XYD``"4```#MF0``(````!.:```<````-)H``!X```!1F@``(```
M`'":```=````D9H``!````"OF@``#P```,":```*````T)H```,```#;F@``
M#P```-^:```4````[YH```D````$FP``#0````Z;```2````')L```\````O
MFP``#````#^;```*````3)L```\```!7FP``"````&>;```D````<)L``!0`
M``"5FP``%@```*J;```(````P9L``!$```#*FP``&0```-R;```'````]IL`
M``P```#^FP``+`````N<```.````.)P```,```!'G```"P```$N<```'````
M5YP```<```!?G```!0```&><```%````;9P```H```!SG````P```'Z<```7
M````@IP```H```":G```#P```*6<```.````M9P``!@```#$G```(P```-V<
M```.`````9T``!0````0G0``%P```"6=```7````/9T``!<```!5G0``$P``
M`&V=```/````@9T```X```"1G0``'P```*"=```'````P)T```8```#(G0``
M"````,^=```/````V)T```8```#HG0``"@```.^=```3````^IT```L````.
MG@``$````!J>```5````*YX``!4```!!G@``!P```%>>```0````7YX```4`
M``!PG@``%0```':>```1````C)X```P```">G@``.P```*N>```)````YYX`
M``<```#QG@``%````/F>```#````#I\```4````2GP``"0```!B?```0````
M(I\```D````SGP``$P```#V?```Y````49\``!(```"+GP``)P```)Z?```L
M````QI\``"H```#SGP``)0```!Z@```*````1*````8```!/H```"0```%:@
M```'````8*```"\```!HH```-P```)B@```N````T*```%4```#_H```+0``
M`%6A```M````@Z$``"T```"QH0``0````-^A```C````(*(``",```!$H@``
M+0```&BB```S````EJ(``!4```#*H@``&0```."B```I````^J(``"0````D
MHP``%0```$FC```1````7Z,```H```!QHP``#````'RC```/````B:,``!<`
M``"9HP``"@```+&C```0````O*,``!8```#-HP``%@```.2C```'````^Z,`
M``<````#I```%`````ND```*````(*0```@````KI```"````#2D```'````
M/:0```<```!%I```!@```$VD```%````5*0```<```!:I```!@```&*D```(
M````::0``"D```!RI```#@```)RD```*````JZ0```0```"VI```!P```+ND
M```)````PZ0```8```#-I```$0```-2D```'````YJ0``!8```#NI```!```
M``6E```(````"J4```8````3I0``#0```!JE```&````**4``!X````OI0``
M$0```$ZE```(````8*4```T```!II0``#````'>E```'````A*4```,```",
MI0```P```)"E```7````E*4```,```"LI0``$P```+"E```(````Q*4```0`
M``#-I0``"````-*E```(````VZ4``$$```#DI0``(````":F```&````1Z8`
M``8```!.I@``%0```%6F```8````:Z8``"(```"$I@``+@```*>F```=````
MUJ8``"$```#TI@``5````!:G```I````:Z<```H```"5IP``!P```*"G```5
M````J*<```@```"^IP``#@```,>G```*````UJ<```\```#AIP``#0```/&G
M```/````_Z<```T````/J```"0```!VH```4````)Z@```8````\J```&```
M`$.H```=````7*@``!,```!ZJ```%````(ZH```$````HZ@```8```"HJ```
M5````*^H```M````!*D```0````RJ0``#@```#>I```%````1JD```4```!,
MJ0``&P```%*I```:````;JD``!$```")J0``$0```)NI```<````K:D``"H`
M``#*J0``-P```/6I```<````+:H``!````!*J@``(0```%NJ```%````?:H`
M``H```"#J@``$P```(ZJ```2````HJH```H```"UJ@``#P```,"J```1````
MT*H``!,```#BJ@``#````/:J```&`````ZL```8````*JP``%P```!&K```0
M````*:L``!$````ZJP``"````$RK```%````5:L```P```!;JP``$````&BK
M```%````>:L```T```!_JP``!@```(VK```'````E*L```T```"<JP``!P``
M`*JK```+````LJL```<```"^JP``!P```,:K```)````SJL```H```#8JP``
M&0```..K```,````_:L``!`````*K```!0```!NL```E````(:P``!(```!'
MK```$P```%JL```K````;JP``#L```":K```(````-:L```V````]ZP```@`
M```NK0``#````#>M```&````1*T```0```!+K0``#@```%"M```*````7ZT`
M``T```!JK0``'@```'BM```;````EZT``"$```"SK0``'@```-6M```9````
M]*T``!X````.K@``&P```"VN```F````2:X``!L```!PK@``'@```(RN```<
M````JZX``"8```#(K@``,P```.^N```F````(Z\``"L```!*KP``.````':O
M```O````KZ\``!(```#?KP``*0```/*O```2````'+```*(````OL```%@``
M`-*P```C````Z;```"@````-L0``*0```#:Q```H````8+$``!\```")L0``
M(````*FQ```E````RK$``#````#PL0``(0```"&R```<````0[(``"8```!@
ML@``00```(>R```,````R;(```<```#6L@``!P```-ZR```&````YK(```T`
M``#ML@``$````/NR```2````#+,```<````?LP``$P```">S```2````.[,`
M``<```!.LP``!````%:S```,````6[,```X```!HLP``#P```'>S```3````
MA[,```T```";LP``*````*FS```#````TK,```T```#6LP``!@```.2S```1
M````Z[,``!<```#]LP``&P```!6T```.````,;0```(```!`M```!0```$.T
M```0````2;0```0```!:M```#0```%^T```.````;;0```,```!\M```#@``
M`("T```(````C[0```\```"8M```#P```*BT```'````N+0```T```#`M```
M$````,ZT```/````W[0``!D```#OM```&@````FU```+````)+4```8````P
MM0``#````#>U```1````1+4``!D```!6M0``"P```'"U```-````?+4``"(`
M``"*M0``"@```*VU```8````N+4``!D```#1M0``%@```.NU```-`````K8`
M``<````0M@``"@```!BV```4````([8```L````XM@``#````$2V```B````
M4;8``"\```!TM@``"P```*2V```)````L+8``!D```"ZM@``"P```-2V```7
M````X+8``!<```#XM@``"0```!"W```6````&K<```\````QMP``%@```$&W
M```.````6+<``!@```!GMP``"````("W```-````B;<``"8```"7MP``0P``
M`+ZW```(`````K@``!(````+N```"````!ZX```+````)[@``"\````SN```
M#@```&.X```%````<K@```8```!XN````P```'^X```'````@[@```0```"+
MN```"@```)"X```*````F[@```D```"FN```#P```+"X```0````P+@``!<`
M``#1N```$0```.FX```7````^[@```D````3N0``!0```!VY```+````([D`
M``H````ON0```@```#JY```%````/;D```T```!#N0``&P```%&Y```7````
M;;D```D```"%N0``"@```(^Y```.````FKD```T```"IN0``$@```+>Y```X
M````RKD``"`````#N@``"````"2Z```.````+;H``'L````\N@``&````+BZ
M```1````T;H```<```#CN@``!0```.NZ```9````\;H```<````+NP``"```
M`!.[```&````'+L```8````CNP``$````"J[```/````.[L``!````!+NP``
M#P```%R[```+````;+L```\```!XNP``#````(B[```/````E;L```<```"E
MNP``!@```*V[```.````M+L```P```##NP``*````-"[```/````^;L```@`
M```)O```!@```!*\```,````&;P```@````FO```$P```"^\```*````0[P`
M`!X```!.O```(0```&V\```@````C[P``!D```"PO```%P```,J\```E````
MXKP``!<````(O0``!````""]```;````);T```T```!!O0``#````$^]```#
M````7+T```@```!@O0``"@```&F]```,````=+T```L```"!O0``$````(V]
M```,````GKT```0```"KO0``$P```+"]```4````Q+T```P```#9O0``"0``
M`.:]```.````\+T```L```#_O0``&P````N^```'````)[X```<````OO@``
M"@```#>^```-````0KX```D```!0O@``!````%J^```%````7[X```,```!E
MO@``&````&F^```*````@KX```0```"-O@``)@```)*^```.````N;X``'P`
M``#(O@``%0```$6_```%````6[\```<```!AOP``#````&F_```(````=K\`
M``H```!_OP``!@```(J_```(````D;\```(```":OP``!@```)V_```&````
MI+\``!0```"KOP``#0```,"_```0````SK\``!L```#?OP``!````/N_```)
M`````,```!`````*P```"0```!O````)````)<````4````OP```&@```#7`
M```(````4,````8```!9P```&0```&#````.````>L````<```")P```!P``
M`)'````%````F<````D```"?P```"@```*G````"````M,````8```"WP```
M#0```+[````)````S,````8```#6P```$@```-W````)````\,````<```#Z
MP```%`````+!```=````%\$```8````UP0``"@```#S!```$````1\$```D`
M``!,P0``"````%;!```1````7\$```D```!QP0``!@```'O!```-````@L$`
M``8```"0P0``!````)?!```Y````G,$``#T```#6P0``.@```!3"```>````
M3\(```4```!NP@``#@```'3"```$````@\(```8```"(P@``(0```(_"```5
M````L<(```8```#'P@``!````,["```1````T\(```8```#EP@``"@```.S"
M```B````]\(```0````:PP``!0```!_#```=````)<,```0```!#PP``#```
M`$C#```*````5<,```@```!@PP``"0```&G#```%````<\,``#H```!YPP``
M,````+3#```U````Y<,``"D````;Q```1P```$7$```X````C<0``"D```#&
MQ```/P```/#$```N````,,4``"T```!?Q0``'P```(W%```/````K<4``!(`
M``"]Q0``"P```-#%```F````W,4``"D````#Q@``)````"W&```F````4L8`
M``@```!YQ@``"@```(+&```)````C<8```<```"7Q@``(````)_&```@````
MP,8``"8```#AQ@``"@````C'```9````$\<``"D````MQP``%@```%?'```2
M````;L<```<```"!QP``"@```(G'```,````E,<```\```"AQP``$````+''
M``!`````PL<``'`````#R```9@```'3(```.````V\@```D```#JR```"@``
M`/3(```2````_\@``!,````2R0``#````";)```&````,\D``!4````ZR0``
M#P```%#)```3````8,D``!(```!TR0``$````(?)```1````F,D``!P```"J
MR0``(P```,?)``!J````Z\D```\```!6R@``!0```&;*```0````;,H```D`
M``!]R@``!````(?*```+````C,H``!0```"8R@``#````*W*```,````NLH`
M``\```#'R@``%0```-?*```I````[<H``"H````7RP``)@```$++```G````
M:<L``"D```"1RP``*@```+O+```9````YLL``$(`````S```$0```$/,```2
M````5<P``!,```!HS```%````'S,```/````D<P``!8```"AS```%P```+C,
M```0````T,P``!$```#AS```-````//,```3````*,T``!(````\S0``-0``
M`$_-```4````A<T```<```":S0``#````*+-```@````K\T``!0```#0S0``
M$0```.7-```7````]\T``!P````/S@``$P```"S.```1````0,X``!H```!2
MS@``'@```&W.```:````C,X``!$```"GS@``%````+G.```7````SLX``!4`
M``#FS@``"0```/S.```9````!L\```0````@SP``!P```"7/```+````+<\`
M`!$````YSP``!@```$O/```&````4L\```8```!9SP``!0```&#/```'````
M9L\```<```!NSP``!0```';/```6````?,\```8```"3SP``!@```)K/```$
M````H<\```0```"FSP``!P```*O/```.````L\\```P```#"SP``#````,_/
M```-````W,\```H```#JSP``#@```/7/```%````!-```"@````*T```#@``
M`#/0```,````0M````\```!/T```"@```%_0```(````:M````D```!ST```
M*P```'W0```$````J=````@```"NT```)@```+?0```2````WM````\```#Q
MT```!@````'1```*````"-$```<````3T0``"````!O1```@````)-$```D`
M``!%T0``#0```$_1```,````7=$```T```!JT0``#@```'C1```6````A]$`
M`!$```">T0``!@```+#1```#````M]$```8```"[T0``&0```,+1```'````
MW-$```0```#DT0``"P```.G1```+````]=$```<````!T@``!P````G2```6
M````$=(```T````HT@``#0```#;2```*````1-(``!````!/T@``#P```&#2
M```1````<-(``!<```""T@``"@```)K2```1````I=(```@```"WT@``!```
M`,#2```/````Q=(``#H```#5T@``!0```!#3```,````%M,``!X````CTP``
M#@```$+3```0````4=,```L```!BTP``#````&[3```)````>],```<```"%
MTP``"@```(W3```)````F-,```X```"BTP``$````+'3```:````PM,```H`
M``#=TP``"0```.C3```*````\M,```P```#]TP``#P````K4```(````&M0`
M``8````CU```!P```"K4```+````,M0``$<````^U```#0```(;4```)````
ME-0```0```">U````P```*/4```3````I]0``!,```"[U```$P```,_4```*
M````X]0```(```#NU```!````/'4```E````]M0```,````<U0``!0```"#5
M```J````)M4```H```!1U0``!0```%S5```$````8M4```H```!GU0``#0``
M`'+5```&````@-4```@```"'U0``"````)#5```$````F=4```4```">U0``
M:````*35```)````#=8```P````7U@``!0```"36```&````*M8``!L````Q
MU@``+P```$W6```0````?=8```H```".U@``#P```)G6```*````J=8```D`
M``"TU@``$P```+[6```;````TM8``!@```#NU@``%P````?7```.````']<`
M``,````NUP``!P```#+7```(````.M<```<```!#UP``"0```$O7```*````
M5=<```L```!@UP``!P```&S7``!1````=-<``!````#&UP``#````-?7```-
M````Y-<``!H```#RUP``2@````W8```&````6-@```8```!?V```!@```&;8
M```?````;=@```8```"-V```"0```)38```8````GM@``!<```"WV```!@``
M`,_8```-````UM@``"(```#DV```5P````?9```3````7]D``",```!SV0``
M$P```)?9```"````J]D```L```"NV0``"````+K9```-````P]D```H```#1
MV0``#````-S9```'````Z=D``!0```#QV0``!@````;:```(````#=H```X`
M```6V@``!P```"7:```*````+=H```L````XV@``!P```$3:```,````3-H`
M``T```!9V@``#````&?:```)````=-H```D```!^V@``"@```(C:```'````
MD]H```D```";V@``!P```*7:```*````K=H``!L```"XV@``$@```-3:```*
M````Y]H```@```#RV@``"0```/O:```0````!=L```<````6VP``$@```![;
M```$````,=L```<````VVP``!0```#[;```%````1-L```L```!*VP``%```
M`%;;```1````:]L``!H```!]VP``%@```)C;```4````K]L``!<```#$VP``
M&````-S;```<````]=L``!D````2W```!P```"S<```%````--P```T````Z
MW```#````$C<```(````5=P```@```!>W```%P```&?<```+````?]P``!,`
M``"+W```!````)_<```*````I-P```0```"OW```#````+3<```)````P=P`
M``4```#+W```!P```-'<```%````V=P```0```#?W````@```.3<```X````
MY]P``"P````@W0``$@```$W=```I````8-T``#(```"*W0``"@```+W=```L
M````R-T``"X```#UW0``,P```"3>```S````6-X``#@```",W@``#P```,7>
M```8````U=X``!````#NW@``#P```/_>```3````#]\``!0````CWP``$@``
M`#C?```D````2]\```@```!PWP``)````'G?```3````GM\``!0```"RWP``
M%0```,??```M````W=\``"T````+X```,0```#G@```N````:^```"\```":
MX```+````,K@``!B````]^```!,```!:X0``"````&[A```(````=^$``"L`
M``"`X0``(0```*SA```:````SN$```D```#IX0``10```//A``!!````.>(`
M``4```![X@``!````('B```3````AN(``!0```":X@``#@```*_B```3````
MON(``!@```#2X@``!@```.OB```)````\N(```H```#\X@``#P````?C```0
M````%^,```<````HXP``#@```##C```-````/^,```P```!-XP``"@```%KC
M```)````9>,```H```!OXP``#P```'KC```(````BN,```\```"3XP``"```
M`*/C```:````K.,```4```#'XP``#0```,WC```;````V^,```@```#WXP``
M!@````#D```4````!^0``!$````<Y```#@```"[D```X````/>0```(```!V
MY```!@```'GD```.````@.0```4```"/Y```!P```)7D```.````G>0```8`
M``"LY```!````+/D```I````N.0``!<```#BY```'P```/KD``!<````&N4`
M`!0```!WY0``/@```(SE```?````R^4``!````#KY0``!P```/SE```.````
M!.8```P````3Y@``#````"#F```3````+>8```H```!!Y@``'0```$SF```9
M````:N8```4```"$Y@``$0```(KF```-````G.8``!$```"JY@``)````+SF
M```5````X>8``!(```#WY@``#@````KG```9````&><```@````SYP``"0``
M`#SG```-````1N<```H```!4YP``!P```%_G```/````9^<```L```!WYP``
M"@```(/G```'````CN<```@```"6YP``!0```)_G```?````I><```8```#%
MYP``$````,SG```(````W><```T```#FYP``"````/3G```2````_><``"P`
M```0Z```&@```#WH```)````6.@```H```!BZ```%0```&WH```%````@^@`
M`!0```")Z```!````)[H```0````H^@```8```"TZ```!P```+OH```>````
MP^@``"@```#BZ```"@````OI```1````%ND```L````HZ0``&@```#3I```4
M````3^D```0```!DZ0``!````&GI```+````;ND```4```!ZZ0``!@```(#I
M```(````A^D```8```"0Z0``"@```)?I```;````HND``#0```"^Z0``-```
M`//I```@````*.H``"D```!)Z@``(````'/J``!!````E.H``!H```#6Z@``
M*````/'J```I````&NL``"(```!$ZP``!@```&?K```(````;NL```4```!W
MZP``"````'WK```9````ANL``!D```"@ZP``*@```+KK```C````Y>L``"X`
M```)[```-````#CL```(````;>P``!<```!V[```"@```([L```'````F>P`
M`"$```"A[```$````,/L```.````U.P```L```#C[```!P```._L```3````
M]^P```@````+[0``"P```!3M```*````(.T``!0````K[0``,@```$#M```+
M````<^T```4```!_[0``!0```(7M```7````B^T```\```"C[0``!````+/M
M```*````N.T```D```##[0``"P```,WM```-````V>T```P```#G[0``#@``
M`/3M```%`````^X```0````)[@``#0````[N```R````'.X``$4```!/[@``
M%P```)7N```>````K>X```P```#,[@``%````-GN```%````[NX``!0```#T
M[@``!P````GO```.````$>\``"H````@[P``!@```$OO```,````4N\```\`
M``!?[P``#0```&_O```1````?>\```L```"/[P``-@```)OO```*````TN\`
M`"(```#=[P``"P````#P```/````#/```#(````<\```#@```$_P```%````
M7O````X```!D\```$P```'/P```'````A_```!$```"/\```!P```*'P```4
M````J?```!@```"^\```!P```-?P```%````W_````P```#E\```#````/+P
M```2````__````0````2\0``!P```!?Q```*````'_$```L````J\0``#```
M`#;Q```.````0_$```X```!2\0``!0```&'Q```%````9_$``"X```!M\0``
M)@```)SQ```C````P_$```,```#G\0``$@```.OQ```&````_O$``!X````%
M\@``&````"3R```E````/?(```T```!C\@``"0```''R```#````>_(```<`
M``!_\@``"@```(?R```"````DO(```P```"5\@``%0```*+R```+````N/(`
M`!D```#$\@``(````-[R```2````__(```4````2\P``"@```!CS```5````
M(_,``!(````Y\P``#````$SS```$````6?,```<```!>\P``#````&;S``!2
M````<_,``!<```#&\P``!P```-[S```&````YO,```X```#M\P``#@```/SS
M```,````"_0```P````8]```#````"7T```-````,O0``!4```!`]```$@``
M`%;T```0````:?0```\```!Z]```%````(KT```;````G_0``!````"[]```
M:0```,ST```:````-O4``!<```!1]0``&0```&GU```:````@_4``"4```">
M]0``)P```,3U```:````[/4``!<````']@``&P```!_V```9````._8``!\`
M``!5]@``%````'7V```3````BO8```@```">]@``!P```*?V```(````K_8`
M``D```"X]@``%0```,+V```-````V/8``!,```#F]@```P```/KV``!&````
M_O8``#\```!%]P``-P```(7W``!7````O?<```4````5^```'P```!OX```O
M````._@```H```!K^```"````';X```-````?_@``"T```"-^```!````+OX
M```4````P/@``$\```#5^```)0```"7Y```2````2_D``"````!>^0``'```
M`'_Y```+````G/D``!\```"H^0``'0```,CY```E````YOD``"`````,^@``
M)````"WZ```@````4OH```L```!S^@``!P```'_Z```-````A_H```P```"5
M^@``%P```*+Z```&````NOH``#D```#!^@``#````/OZ```'````"/L```D`
M```0^P``$P```!K[```)````+OL```0````X^P``$````#W[```(````3OL`
M``@```!7^P``!````&#[```+````9?L```P```!Q^P``$@```'[[```1````
MD?L```P```"C^P``&@```+#[```/````R_L```<```#;^P``#0```./[```0
M````\?L``!$````"_```%````!3\```.````*?P```P````X_```&P```$7\
M```L````8?P``!,```"._```'````*+\```H````O_P```8```#H_```!P``
M`._\```3````]_P```4````+_0``!````!']```7````%OT```H````N_0``
M#````#G]```)````1OT```8```!0_0``"0```%?]```(````8?T```D```!J
M_0``"@```'3]```1````?_T```8```"1_0``#@```)C]```.````I_T```T`
M``"V_0``"P```,3]```=````T/T```L```#N_0```@```/K]```'````_?T`
M``8````%_@``"0````S^```'````%OX``#L````>_@``*````%K^```T````
M@_X``!4```"X_@``!0```,[^```'````U/X```@```#<_@``!P```.7^```%
M````[?X```<```#S_@``#@```/O^```)````"O\```8````4_P``"````!O_
M```+````)/\```<````P_P``"````#C_```'````0?\``!8```!)_P``"0``
M`&#_```&````:O\```L```!Q_P``'````'W_```4````FO\```<```"O_P``
M"````+?_```(````P/\```4```#)_P``$````,__```0````X/\```8```#Q
M_P``&0```/C_```*````$@`!`!P````=``$`!P```#H``0`%````0@`!`!``
M``!(``$`%````%D``0`+````;@`!``T```!Z``$`%P```(@``0`$````H``!
M``D```"E``$`"@```*\``0`'````N@`!``(```#"``$`#@```,4``0`(````
MU``!`!\```#=``$`(P```/T``0`X````(0$!`#$```!:`0$`)P```(P!`0!D
M````M`$!`!0````9`@$`50```"X"`0`X````A`(!`$H```"]`@$`6P````@#
M`0`H````9`,!`#@```"-`P$`*````,8#`0`L````[P,!`"<````<!`$`&P``
M`$0$`0`^````8`0!`*D!``"?!`$`(P```$D&`0`7````;08!`$@```"%!@$`
MA0```,X&`0`P````5`<!`!4```"%!P$`*````)L'`0`B````Q`<!`"(```#G
M!P$`(`````H(`0!!````*P@!`%L```!M"`$`20```,D(`0`=````$PD!`!@`
M```Q"0$`(0```$H)`0`?````;`D!`"L```","0$`(0```+@)`0`G````V@D!
M`!T````""@$`$0```"`*`0`S````,@H!`"4```!F"@$`)P```(P*`0`?````
MM`H!`#````#4"@$`:0````4+`0`]````;PL!`&4```"M"P$`30```!,,`0`O
M````80P!`"X```"1#`$`*0```,`,`0`L````Z@P!`%0````7#0$`6@```&P-
M`0`H````QPT!`"8```#P#0$`2````!<.`0!*````8`X!`"L```"K#@$`'@``
M`-<.`0`R````]@X!`"\````I#P$`+````%D/`0`M````A@\!`'$```"T#P$`
M;P```"80`0"S````EA`!`!<```!*$0$`)0```&(1`0`R````B!$!`"D```"[
M$0$`/@```.41`0`B````)!(!`%(```!'$@$`(@```)H2`0`E````O1(!``L`
M``#C$@$`L0```.\2`0!%````H1,!`"$```#G$P$`,`````D4`0`E````.A0!
M`!P```!@%`$`,0```'T4`0`'````KQ0!``<```"W%`$`!````+\4`0`-````
MQ!0!``L```#2%`$`#@```-X4`0`+````[10!``4```#Y%`$`$````/\4`0`"
M````$!4!`%D````3%0$`!0```&T5`0`2````<Q4!``0```"&%0$`!P```(L5
M`0`(````DQ4!``4```"<%0$``P```*(5`0`0````IA4!``P```"W%0$`$P``
M`,05`0`-````V!4!``(```#F%0$`!P```.D5`0`&````\14!`!0```#X%0$`
M#`````T6`0`8````&A8!``8````S%@$`$@```#H6`0`,````318!``,```!:
M%@$`*@```%X6`0`$````B18!``8```".%@$`!P```)46`0`?````G18!`#4`
M``"]%@$`+@```/,6`0`O````(A<!`!<```!2%P$`(````&H7`0`;````BQ<!
M`!@```"G%P$`)````,`7`0`?````Y1<!`!H````%&`$`(````"`8`0`:````
M01@!`#(```!<&`$`&0```(\8`0`O````J1@!`"L```#9&`$`'P````49`0`C
M````)1D!`!\```!)&0$`&@```&D9`0`E````A!D!`"8```"J&0$`)0```-$9
M`0`D````]QD!`!@````<&@$`'0```#4:`0`D````4QH!`!@```!X&@$`(@``
M`)$:`0`E````M!H!`#P```#:&@$`'P```!<;`0`C````-QL!`!\```!;&P$`
M(````'L;`0`:````G!L!`!@```"W&P$`)@```-`;`0`>````]QL!`"D````6
M'`$`'@```$`<`0`)````7QP!``P```!I'`$`%P```'8<`0`O````CAP!`"0`
M``"^'`$`!P```.,<`0`/````ZQP!`!0```#['`$`#@```!`=`0`-````'QT!
M`"0````M'0$`!0```%(=`0`'````6!T!`"(```!@'0$`)0```(,=`0`=````
MJ1T!`!H```#''0$`!P```.(=`0#'````ZAT!``L```"R'@$`%0```+X>`0`&
M````U!X!``D```#;'@$`"P```.4>`0`7````\1X!``8````)'P$`,P```!`?
M`0`3````1!\!`!,```!8'P$`!P```&P?`0`/````=!\!``<```"$'P$`,@``
M`(P?`0`A````OQ\!`!,```#A'P$`#````/4?`0`1`````B`!`#(````4(`$`
M"````$<@`0`)````4"`!``H```!:(`$`%````&4@`0`*````>B`!`!T```"%
M(`$`"````*,@`0`?````K"`!``@```#,(`$`&@```-4@`0`&````\"`!`!4`
M``#W(`$`!P````TA`0`(````%2$!``D````>(0$`/P```"@A`0`'````:"$!
M``\```!P(0$`#@```(`A`0`0````CR$!``D```"@(0$`"0```*HA`0`(````
MM"$!`!,```"](0$`!P```-$A`0`9````V2$!``H```#S(0$`%P```/XA`0`4
M````%B(!``H````K(@$`#````#8B`0`7````0R(!``0```!;(@$`*@```&`B
M`0`1````BR(!``<```"=(@$``@```*4B`0`0````J"(!`!@```"Y(@$`"P``
M`-(B`0`#````WB(!``@```#B(@$`!@```.LB`0`'````\B(!``T```#Z(@$`
M"P````@C`0`4````%",!`!4````I(P$`#@```#\C`0`O````3B,!`"````!^
M(P$`'````)\C`0`K````O",!``P```#H(P$`,0```/4C`0`%````)R0!`!(`
M```M)`$`/P```$`D`0`2````@"0!``H```"3)`$`!@```)XD`0`$````I20!
M``0```"J)`$`"@```*\D`0`3````NB0!``4```#.)`$`!@```-0D`0`&````
MVR0!``0```#B)`$`#````.<D`0`*````]"0!``4```#_)`$`&`````4E`0`9
M````'B4!`!\````X)0$`'0```%@E`0`1````=B4!``(```"()0$`!````(LE
M`0`*````D"4!``8```";)0$`!0```*(E`0`#````J"4!``P```"L)0$`10``
M`+DE`0`:````_R4!`#4````:)@$`*````%`F`0!3````>28!`#(```#-)@$`
M&0`````G`0!R````&B<!`"````"-)P$`-0```*XG`0`A````Y"<!`$4````&
M*`$`,````$PH`0`H````?2@!`"@```"F*`$`*0```,\H`0`F````^2@!`"4`
M```@*0$`*````$8I`0`H````;RD!`"(```"8*0$`,````+LI`0`2````["D!
M`!,```#_*0$`$````!,J`0!Y````)"H!``D```">*@$`<P```*@J`0!\````
M'"L!`"L```"9*P$`%P```,4K`0`6````W2L!`!4```#T*P$`#P````HL`0`?
M````&BP!``X````Z+`$`0````$DL`0`?````BBP!`!P```"J+`$`40```,<L
M`0`4````&2T!``H````N+0$`!0```#DM`0`&````/RT!``@```!&+0$`!0``
M`$\M`0`2````52T!`!````!H+0$`$P```'DM`0`=````C2T!``\```"K+0$`
M#P```+LM`0`0````RRT!``0```#<+0$`"0```.$M`0`)````ZRT!``<```#U
M+0$`"P```/TM`0`%````"2X!``L````/+@$`!P```!LN`0`%````(RX!`!0`
M```I+@$`#@```#XN`0`+````32X!``<```!9+@$`"````&$N`0`/````:BX!
M``P```!Z+@$`"0```(<N`0`(````D2X!``P```":+@$`!@```*<N`0`/````
MKBX!``<```"^+@$`!@```,8N`0`4````S2X!``8```#B+@$`#````.DN`0`(
M````]BX!``0```#_+@$`"@````0O`0`'````#R\!``0````7+P$`&0```!PO
M`0`"````-B\!``D````Y+P$`!@```$,O`0`&````2B\!`"<```!1+P$`!```
M`'DO`0`/````?B\!`!,```".+P$`!P```*(O`0`)````JB\!``<```"T+P$`
M!@```+PO`0`&````PR\!`!````#*+P$`$@```-LO`0`&````[B\!``D```#U
M+P$`(@```/\O`0`'````(C`!``<````J,`$`"P```#(P`0`%````/C`!``4`
M``!$,`$``@```$HP`0`+````33`!`,T!``!9,`$`#@```"<R`0`5````-C(!
M``T```!,,@$`!P```%HR`0`(````8C(!``@```!K,@$`"@```'0R`0`*````
M?S(!``L```"*,@$`$@```)8R`0`-````J3(!``@```"W,@$`!0```,`R`0`=
M````QC(!``P```#D,@$`#0```/$R`0`5````_S(!`!`````5,P$`"P```"8S
M`0`@````,C,!`!````!3,P$`"````&0S`0`3````;3,!``T```"!,P$`"@``
M`(\S`0`+````FC,!``T```"F,P$`#P```+0S`0`&````Q#,!`!````#+,P$`
M%@```-PS`0`+````\S,!``H```#_,P$`$@````HT`0`2````'30!``@````P
M-`$`+0```#DT`0`9````9S0!`#@```"!-`$`00```+HT`0!3````_#0!`%$`
M``!0-0$`60```*(U`0!7````_#4!`#L```!4-@$`"@```)`V`0`.````FS8!
M`!8```"J-@$`!0```,$V`0`&````QS8!`!D```#.-@$`#````.@V`0`4````
M]38!`!<````*-P$`)P```"(W`0`F````2C<!`"$```!Q-P$`(P```),W`0`G
M````MS<!`"0```#?-P$`$0````0X`0`?````%C@!``\````V.`$`!````$8X
M`0`1````2S@!`!````!=.`$`!P```&XX`0`4````=C@!`!$```"+.`$`&```
M`)TX`0`0````MC@!``X```#'.`$`$0```-8X`0`*````Z#@!`"D```#S.`$`
M$P```!TY`0`7````,3D!`!````!).0$`%0```%HY`0`C````<#D!``8```"4
M.0$`!P```)LY`0!*````HSD!``P```#N.0$`"````/LY`0`+````!#H!``<`
M```0.@$`"````!@Z`0`/````(3H!``@````Q.@$`"@```#HZ`0`#````13H!
M`!D```!).@$`#P```&,Z`0`9````<SH!`!0```"-.@$`$@```*(Z`0`H````
MM3H!``P```#>.@$`)P```.LZ`0`7````$SL!`",````K.P$`'0```$\[`0`2
M````;3L!`!(```"`.P$`#@```),[`0`?````HCL!``8```#".P$`!@```,D[
M`0`(````T#L!``X```#9.P$`!P```.@[`0`*````\#L!`!$```#[.P$`"```
M``T\`0`/````%CP!`!8````F/`$`&@```#T\`0`(````6#P!`!(```!A/`$`
M!0```'0\`0`6````>CP!`!X```"1/`$`#0```+`\`0`P````OCP!``D```#O
M/`$`!P```/D\`0`4`````3T!``4````6/0$`!0```!P]`0`)````(CT!`!``
M```L/0$`"P```#T]`0`:````23T!`#,```!D/0$`#P```)@]`0`F````J#T!
M`#,```#//0$`,0````,^`0`P````-3X!``@```!F/@$`!0```&\^`0`)````
M=3X!``@```!_/@$`.0```(@^`0`M````PCX!`#@```#P/@$`4P```"D_`0`W
M````?3\!`#<```"U/P$`-@```.T_`0`W````)$`!`"4```!<0`$`*@```()`
M`0`W````K4`!`#T```#E0`$`#P```"-!`0`3````,T$!`"<```!'00$`'```
M`&]!`0`3````C$$!``X```"@00$`"P```*]!`0`,````NT$!`!$```#(00$`
M'0```-I!`0`&````^$$!``P```#_00$`&@````Q"`0`F````)T(!``8```!.
M0@$`!P```%5"`0`6````74(!``D```!T0@$`"````'Y"`0`&````AT(!``D`
M``".0@$`!@```)A"`0`%````GT(!``4```"E0@$`!P```*M"`0`&````LT(!
M``H```"Z0@$`)0```,5"`0`/````ZT(!``D```#[0@$`!0````5#`0`'````
M"T,!``<````30P$`!0```!M#`0`-````(4,!``8````O0P$`$P```#9#`0`#
M````2D,!``@```!.0P$`"@```%=#`0`-````8D,!``@```!P0P$`(P```'E#
M`0`1````G4,!``D```"O0P$`$@```+E#`0`,````S$,!``<```#90P$``P``
M`.%#`0`#````Y4,!`!0```#I0P$``P```/Y#`0`4`````D0!``@````71`$`
M"````"!$`0`(````*40!``<````R1`$`5P```#I$`0`D````DD0!``8```"W
M1`$`!@```+Y$`0`7````Q40!`!H```#=1`$`'````/A$`0`L````%44!`!L`
M``!"10$`+@```%Y%`0!R````C44!`"4`````1@$`"@```"9&`0`'````,48!
M`!(````Y1@$`"0```$Q&`0`1````5D8!``\```!H1@$`#@```'A&`0`4````
MAT8!`!````"<1@$`%````*U&`0`/````PD8!`!4```#21@$`!0```.A&`0`7
M````[D8!`!L````&1P$`%P```")'`0`4````.D<!``,```!/1P$`!@```%-'
M`0!H````6D<!`"L```##1P$`!````.]'`0`6````]$<!``4````+2`$`!```
M`!%(`0`>````%D@!`!@````U2`$`#````$Y(`0`8````6T@!`!@```!T2`$`
M+0```(U(`0`^````NT@!`!L```#Z2`$`#@```!9)`0`B````)4D!``@```!(
M20$`$0```%%)`0`:````8TD!`!@```!^20$`$P```)=)`0`<````JTD!`!@`
M``#(20$`%````.%)`0`+````]DD!``@````"2@$`!P````M*`0`0````$TH!
M`!4````D2@$`$````#I*`0`(````2TH!``4```!42@$`"P```%I*`0`,````
M9DH!``@```!S2@$`#0```'Q*`0`'````BDH!``8```"22@$`$0```)E*`0`(
M````JTH!``P```"T2@$`!P```,%*`0`%````R4H!``@```#/2@$`"````-A*
M`0`3````X4H!``L```#U2@$`#@````%+`0`%````$$L!`!T````62P$`$```
M`#1+`0`1````14L!`#0```!72P$`1````(Q+`0`?````T4L!`#$```#Q2P$`
M"@```"-,`0`/````+DP!``<````^3`$`"0```$9,`0`/````4$P!``D```!@
M3`$`$0```&I,`0`A````?$P!`"$```">3`$`)````,!,`0`D````Y4P!`!@`
M```*30$`(0```"--`0`;````14T!`"4```!A30$`&@```(=-`0`=````HDT!
M`!@```#`30$`(P```-E-`0`I````_4T!`!L````G3@$`)@```$-.`0`P````
M:DX!`"X```";3@$`$0```,I.`0`I````W$X!``X````&3P$`L````!5/`0`0
M````QD\!`!@```#73P$`(P```/!/`0`D````%%`!`!\````Y4`$`&P```%E0
M`0`@````=5`!`"$```"64`$`+@```+A0`0`<````YU`!`!X````$40$`*0``
M`"-1`0!+````35$!``\```"940$`!````*E1`0`2````KE$!``@```#!40$`
M#@```,I1`0`.````V5$!`!(```#H40$`"0```/M1`0`+````!5(!`!0````1
M4@$`"@```"92`0`$````,5(!``P````V4@$`#P```$-2`0`/````4U(!`!,`
M``!C4@$`#````'=2`0`Q````A%(!``L```"V4@$`$0```,)2`0`$````U%(!
M``\```#94@$`%0```.E2`0`8````_U(!``\````84P$``@```"A3`0`%````
M*U,!`!(````Q4P$`!0```$13`0`+````2E,!``P```!64P$``P```&-3`0`/
M````9U,!``@```!W4P$`&````(!3`0`0````F5,!``H```"J4P$`$````+53
M`0`3````QE,!`!0```#:4P$`'````.]3`0`8````#%0!``@````E5`$`!@``
M`"Y4`0`.````-50!``P```!$5`$`&````%%4`0`,````:E0!``X```!W5`$`
M(P```(94`0`,````JE0!`!X```"W5`$`%P```-94`0`5````[E0!``P````$
M50$`!@```!%5`0`(````&%4!``X````A50$`!0```#!5`0`&````-E4!`"<`
M```]50$`/P```&55`0`%````I54!``D```"K50$`'@```+55`0`+````U%4!
M`!,```#@50$`$P```/15`0`'````"%8!`!D````05@$`$@```"I6`0`8````
M/58!`!````!65@$`%0```&=6`0`(````?58!``@```"&5@$`)@```(]6`0!(
M````ME8!``@```#_5@$`%@````A7`0`'````'U<!``H````G5P$`,0```#)7
M`0`/````9%<!``4```!T5P$`!@```'I7`0`#````@5<!``<```"%5P$`!P``
M`(U7`0`,````E5<!``\```"B5P$`$````+)7`0`-````PU<!``T```#15P$`
M%````-]7`0`5````]%<!`!0````*6`$`!0```!]8`0`%````)5@!``L````K
M6`$`"````#=8`0`"````0%@!``4```!#6`$`#P```$E8`0`A````65@!`!(`
M``![6`$`$````(Y8`0`0````GU@!``\```"P6`$`$0```,!8`0`>````TE@!
M`#$```#Q6`$`+0```"-9`0`*````45D!``X```!<60$`BP```&M9`0`6````
M]UD!`!`````.6@$`!P```!]:`0`%````)UH!`"$````M6@$`"````$]:`0`'
M````6%H!``<```!@6@$`!@```&A:`0`0````;UH!``X```"`6@$`$0```(]:
M`0`/````H5H!`!L```"Q6@$`$0```,U:`0`-````WUH!`!<```#M6@$`!P``
M``5;`0`)````#5L!`!0````76P$`#0```"Q;`0`[````.EL!`!D```!V6P$`
M"````)!;`0`*````F5L!`!,```"D6P$`#0```+A;`0`=````QEL!``L```#D
M6P$`&0```/!;`0`A````"EP!`"`````L7`$`&@```$U<`0`;````:%P!`"4`
M``"$7`$`&@```*I<`0`%````Q5P!`!T```#+7`$`$````.E<`0`.````^EP!
M``,````)70$`!`````U=`0`-````$ET!``X````@70$`#P```"]=`0`7````
M/UT!``L```!770$`!````&-=`0`8````:%T!`!D```"!70$`#P```)M=`0`-
M````JUT!``T```"Y70$`#@```,==`0`?````UET!``8```#V70$`!@```/U=
M`0`.````!%X!``X````37@$`#0```")>`0`(````,%X!``@````Y7@$`!```
M`$)>`0`4````1UX!``L```!<7@$`!0```&A>`0`D````;EX!``\```"37@$`
M:P```*->`0`:````#U\!``D````J7P$`!@```#1?`0`*````.U\!``8```!&
M7P$`"````$U?`0`$````5E\!``H```!;7P$``@```&9?`0`$````:5\!``<`
M``!N7P$`%0```'9?`0`2````C%\!`!0```"?7P$`&@```+1?`0`"````SU\!
M``(```#27P$`#@```-5?`0`&````Y%\!``H```#K7P$`!0```/9?`0`9````
M_%\!``@````68`$`!@```!]@`0`7````)F`!`!`````^8`$`"0```$]@`0`'
M````66`!``4```!A8`$`"0```&=@`0`-````<6`!``8```!_8`$`!@```(9@
M`0`9````C6`!``L```"G8`$`!0```+-@`0`2````N6`!``<```#,8`$`!P``
M`-1@`0`8````W&`!`!T```#U8`$`!P```!-A`0`*````&V$!``0````F80$`
M"0```"MA`0`(````-6$!``L````^80$`"P```$IA`0`&````5F$!``T```!=
M80$`!@```&MA`0`$````<F$!`#<```!W80$`00```*]A`0`X````\6$!`"8`
M```J8@$`!0```%%B`0`/````5V(!``8```!G8@$`"````&YB`0`?````=V(!
M`!H```"78@$`!0```+)B`0`(````N&(!`!,```#!8@$`"````-5B`0`)````
MWF(!`!<```#H8@$`!@````!C`0`&````!V,!`!4````.8P$`!0```"1C`0`+
M````*F,!``P````V8P$`"````$-C`0`)````3&,!``4```!68P$`+@```%QC
M`0`T````BV,!`#P```#`8P$`)P```/UC`0`^````)60!`#@```!D9`$`*```
M`)UD`0`R````QF0!`"T```#Y9`$`-0```"=E`0`H````764!`!(```"&90$`
M$P```)EE`0`-````K64!`#$```"[90$`'````.UE`0`<````"F8!`!H````G
M9@$`!P```$)F`0`(````2F8!``<```!39@$`"````%MF`0`F````9&8!`"0`
M``"+9@$`,0```+!F`0`)````XF8!`!@```#L9@$`*`````5G`0`6````+F<!
M`!(```!%9P$`!@```%AG`0`+````7V<!``P```!K9P$`#@```'AG`0`/````
MAV<!`#@```"79P$`@````-!G`0!F````46@!``\```"X:`$`"P```,AH`0`,
M````U&@!`!$```#A:`$`$@```/-H`0`.````!FD!``<````5:0$`'````!UI
M`0`/````.FD!`!X```!*:0$`%````&EI`0`1````?FD!``\```"0:0$`'@``
M`*!I`0`P````OVD!`'T```#P:0$`$````&YJ`0`%````?VH!`!0```"%:@$`
M"0```)IJ`0`)````I&H!``D```"N:@$`$@```+AJ`0`.````RVH!``X```#:
M:@$`$P```.EJ`0`5````_6H!`!\````3:P$`(0```#-K`0`=````56L!`!\`
M``!S:P$`(````)-K`0`B````M&L!`!@```#7:P$`-P```/!K`0`/````*&P!
M`!$````X;`$`$0```$IL`0`3````7&P!``T```!P;`$`$@```'YL`0`4````
MD6P!``\```"F;`$`$0```+9L`0`R````R&P!`!8```#[;`$`%````!)M`0`\
M````)VT!`!0```!D;0$`"@```'EM`0`3````A&T!`"(```"8;0$`$@```+MM
M`0`H````SFT!`!D```#W;0$`&0```!%N`0`7````*VX!`!(```!#;@$`'P``
M`%9N`0`B````=FX!`!H```"9;@$`$@```+1N`0`7````QVX!`!P```#?;@$`
M%@```/QN`0`(````$V\!`!@````<;P$`!````#5O`0`%````.F\!``L```!`
M;P$`$````$QO`0`&````76\!``P```!D;P$`!P```'%O`0`&````>6\!``<`
M``"`;P$`!0```(AO`0`(````CF\!`!@```"7;P$`!@```+!O`0`)````MV\!
M``@```#!;P$`!@```,IO`0`(````T6\!`!$```#:;P$`$@```.QO`0`/````
M_V\!`!`````/<`$`"@```"!P`0`1````*W`!``0````]<`$`(0```$)P`0`/
M````9'`!``\```!T<`$`%@```(1P`0`+````FW`!``D```"G<`$`"P```+%P
M`0`O````O7`!``0```#M<`$`"````/)P`0`$````^W`!``4`````<0$`$0``
M``9Q`0`&````&'$!``H````?<0$`"@```"IQ`0`%````-7$!`",````[<0$`
M#@```%]Q`0`1````;G$!`!$```"`<0$`%0```))Q`0`7````J'$!`!P```#`
M<0$`&@```-UQ`0`%````^'$!``4```#^<0$`"0````1R`0`9````#G(!``<`
M```H<@$`!@```#!R`0`-````-W(!``X```!%<@$`!P```%1R`0`'````7'(!
M``4```!D<@$`#P```&IR`0`.````>G(!``H```")<@$`$````)1R`0`2````
MI7(!`!0```"X<@$`%````,UR`0`-````XG(!`!8```#P<@$`"`````=S`0`%
M````$',!`!(````6<P$`2````"ES`0`&````<G,!``\```!Y<P$`(P```(ES
M`0`/````K7,!`!4```"]<P$`#@```--S`0`-````XG,!``\```#P<P$`"0``
M``!T`0`/````"G0!``\````:=`$`$0```"IT`0`0````/'0!`!X```!-=`$`
M"@```&QT`0`(````=W0!``P```"`=`$`#````(UT`0`,````FG0!``4```"G
M=`$`#````*UT`0`)````NG0!`!X```#$=`$`9P```.-T`0`3````2W4!``L`
M``!?=0$`!0```&MU`0`%````<74!`!(```!W=0$`%````(IU`0`3````GW4!
M``L```"S=0$``@```+]U`0`*````PG4!`"\```#-=0$``P```/UU`0`%````
M`78!`"8````'=@$`"@```"YV`0`%````.78!``4````_=@$`$P```$5V`0`2
M````678!``8```!L=@$`"````'-V`0`'````?'8!``0```"$=@$`!0```(EV
M`0!N````CW8!``H```#^=@$`#0````EW`0`&````%W<!``4````>=P$`*0``
M`"1W`0`R````3G<!`!$```"!=P$`"@```)-W`0`1````GG<!``H```"P=P$`
M"0```+MW`0`9````Q7<!`"<```#?=P$`*0````=X`0`H````,7@!``\```!:
M>`$`!@```&IX`0`'````<7@!``@```!Y>`$`!P```()X`0`-````BG@!``X`
M``"8>`$`#````*=X`0`&````M'@!`$4```"[>`$`$`````%Y`0`*````$GD!
M``8````=>0$`'````"1Y`0!A````07D!``8```"C>0$`"````*IY`0`&````
MLWD!`!0```"Z>0$`"0```,]Y`0`(````V7D!`"D```#B>0$`*`````QZ`0`)
M````-7H!``4````_>@$`*P```$5Z`0!G````<7H!`"D```#9>@$`+@````-[
M`0`8````,GL!``(```!+>P$`#0```$Y[`0`%````7'L!`!0```!B>P$`"@``
M`'=[`0`-````@GL!``4```"0>P$`"````)9[`0`&````GWL!``D```"F>P$`
M"P```+![`0`'````O'L!``@```#$>P$`"P```,U[`0`&````V7L!``X```#@
M>P$`$````.][`0`1`````'P!``T````2?`$`#P```"!\`0`0````,'P!``\`
M``!!?`$`#0```%%\`0`/````7WP!``@```!O?`$`'@```'A\`0`3````EWP!
M``@```"K?`$`#0```+1\`0`*````PGP!`!8```#-?`$`!P```.1\`0`/````
M['P!``4```#\?`$`!P````)]`0`%````"GT!``4````0?0$`"````!9]`0`1
M````'WT!`!$````Q?0$`&@```$-]`0`6````7GT!`!0```!U?0$`%P```(I]
M`0`:````HGT!`!\```"]?0$`&````-U]`0`#````]GT!``4```#Z?0$`#@``
M``!^`0`.````#WX!`!8````>?@$`#0```#5^`0`B````0WX!``L```!F?@$`
M%````')^`0`'````AWX!``H```"/?@$`!0```)I^`0`.````H'X!``D```"O
M?@$`!0```+E^`0`'````OWX!``,```#'?@$`!````,M^`0`"````T'X!`#X`
M``#3?@$`-````!)_`0`4````1W\!`"H```!<?P$`10```(=_`0`*````S7\!
M`"P```#8?P$`,P````6``0`X````.8`!`#@```!R@`$`/0```*N``0`4````
MZ8`!`!H```#^@`$`&P```!F!`0`<````-8$!`!L```!2@0$`'P```&Z!`0`;
M````CH$!`"L```"J@0$`#@```-:!`0`S````Y8$!`!P````9@@$`&P```#:"
M`0`.````4H(!`#````!A@@$`,````)*"`0`T````PX(!`#T```#X@@$`,@``
M`#:#`0`O````:8,!`'(```"9@P$`)@````R$`0`,````,X0!``H```!`A`$`
M,P```$N$`0`U````?X0!`"<```"UA`$`#0```-V$`0!$````ZX0!`#\````P
MA0$`"0```'"%`0`%````>H4!`!L```"`A0$`%@```)R%`0`2````LX4!`!$`
M``#&A0$`&0```-B%`0`&````\H4!``<```#YA0$`"0````&&`0`.````"X8!
M`!0````:A@$`#@```"^&`0`1````/H8!``X```!0A@$`%````%^&`0`/````
M=(8!``T```"$A@$`#@```)*&`0`9````H88!``D```"[A@$`$````,6&`0`)
M````UH8!`!@```#@A@$`"````/F&`0`0`````H<!`!X````3AP$`"````#*'
M`0`%````.X<!``L```!!AP$`#0```$V'`0`+````6X<!`#H```!GAP$``@``
M`**'`0`&````I8<!``X```"LAP$`"0```+N'`0`%````Q8<!`!(```#+AP$`
M"````-Z'`0`$````YX<!`#,```#LAP$`#@```""(`0`I````+X@!`%````!9
MB`$`%0```*J(`0`Z````P(@!`"````#[B`$`#P```!R)`0`(````+(D!``\`
M```UB0$`#P```$6)`0`*````58D!`!0```!@B0$`#````'6)`0`:````@HD!
M`!4```"=B0$`!P```+.)`0`1````NXD!``X```#-B0$`$0```-R)`0`A````
M[HD!`!0````0B@$`$@```"6*`0`0````.(H!`",```!)B@$`!P```&V*`0`+
M````=8H!`!0```"!B@$`$@```):*`0`1````J8H!`!H```"[B@$`$````-:*
M`0`,````YXH!``<```#TB@$`"````/R*`0`%````!8L!`"$````+BP$`!@``
M`"V+`0`1````-(L!``@```!&BP$`#@```$^+`0`%````7HL!``\```!DBP$`
M+P```'2+`0`2````I(L!``8```"WBP$`!P```+Z+`0`7````QHL!``8```#>
MBP$`$@```.6+`0`%````^(L!`!4```#^BP$`!````!2,`0`'````&8P!`!8`
M```AC`$`,0```#B,`0`%````:HP!`!(```!PC`$`!0```(.,`0`3````B8P!
M`!````"=C`$`!````*Z,`0`.````LXP!``@```#"C`$`!P```,N,`0`*````
MTXP!``@```#>C`$`!@```.>,`0`%````[HP!`"````#TC`$`-0```!6-`0`U
M````2XT!`!L```"!C0$`)````)V-`0`C````PHT!`#\```#FC0$`&P```":.
M`0`F````0HX!`"T```!IC@$`)````)>.`0`&````O(X!``@```##C@$`"0``
M`,R.`0`+````UHX!`!<```#BC@$`$````/J.`0`N````"X\!`"0````ZCP$`
M-````%^/`0`X````E(\!`!$```#-CP$`(@```-^/`0`2`````I`!``8````5
MD`$`&P```!R0`0`2````.)`!`!$```!+D`$`#0```%V0`0`'````:Y`!``X`
M``!SD`$`"````(*0`0`+````BY`!``P```"7D`$`&P```*20`0`T````P)`!
M``D```#UD`$`!0```/^0`0`)````!9$!`!H````/D0$`$0```"J1`0`$````
M/)$!``H```!!D0$`"P```$R1`0`0````6)$!``X```!ID0$`#````'B1`0`6
M````A9$!``4```"<D0$`!0```**1`0`/````J)$!`"P```"XD0$`2P```.61
M`0`6````,9(!`!T```!(D@$`#@```&:2`0`:````=9(!``4```"0D@$`$```
M`):2`0`'````IY(!`!$```"OD@$`+````,&2`0`)````[I(!``X```#XD@$`
M$P````>3`0`1````&Y,!`!4````MDP$`#0```$.3`0`Y````49,!``D```"+
MDP$`'0```)63`0`3````LY,!`!<```#'DP$`+P```-^3`0`/````#Y0!``@`
M```?E`$`%P```"B4`0`>````0)0!``@```!?E`$`$@```&B4`0`'````>Y0!
M`!0```"#E`$`&@```)B4`0`'````LY0!``<```"[E`$`$````,.4`0`/````
MU)0!`!$```#DE`$`!0```/:4`0`(````_)0!``T````%E0$`#0```!.5`0`.
M````(94!`!`````PE0$`$````$&5`0`&````4I4!``@```!9E0$`+@```&*5
M`0`F````D94!`"0```"XE0$`!P```-V5`0`.````Y94!``8```#TE0$`%P``
M`/N5`0`7````$Y8!`"(````KE@$`"@```$Z6`0`+````698!``,```!EE@$`
M!@```&F6`0`,````<)8!``(```!]E@$`#````("6`0`3````C98!``L```"A
ME@$`&0```*V6`0`@````QY8!`!(```#HE@$`!0```/N6`0`*`````9<!`!4`
M```,EP$`$0```"*7`0`.````-)<!``8```!#EP$`"0```$J7`0`0````5)<!
M`$H```!EEP$`%P```+"7`0`$````R)<!``@```#-EP$`%````-:7`0`4````
MZY<!`!4`````F`$`#0```!:8`0`.````))@!``P````SF`$`(@```$"8`0`7
M````8Y@!``\```![F`$`#0```(N8`0`C````F9@!`!P```"]F`$`#0```-J8
M`0!B````Z)@!`"(```!+F0$`%@```&Z9`0`6````A9D!`!P```"<F0$`(0``
M`+F9`0`K````VYD!`"`````'F@$`%````"B:`0`>````/9H!`!8```!<F@$`
M'P```'.:`0`2````DYH!`!@```"FF@$`"@```+^:`0`'````RIH!``<```#2
MF@$`!````-J:`0`3````WYH!``T```#SF@$`$0````&;`0`(````$YL!`$$`
M```<FP$`/````%Z;`0!"````FYL!`&````#>FP$`"0```#^<`0`^````29P!
M`"\```"(G`$`"@```+B<`0`*````PYP!``X```#.G`$`.P```-V<`0`(````
M&9T!`!@````BG0$`.````#N=`0`N````=)T!`!D```"CG0$`)@```+V=`0`B
M````Y)T!``\````'G@$`*0```!>>`0`8````09X!`#````!:G@$`(@```(N>
M`0`H````KIX!`"(```#7G@$`#P```/J>`0`(````"I\!``X````3GP$`#P``
M`"*?`0`0````,I\!``<```!#GP$`/0```$N?`0`,````B9\!``X```"6GP$`
M!@```*6?`0`5````K)\!``@```#"GP$`"````,N?`0`/````U)\!``D```#D
MGP$`"0```.Z?`0`'````^)\!`!``````H`$`$````!&@`0`6````(J`!`!<`
M```YH`$`$0```%&@`0`;````8Z`!`!,```!_H`$`"````).@`0`-````G*`!
M`!@```"JH`$`'0```,.@`0`,````X:`!``\```#NH`$`#````/Z@`0`9````
M"Z$!`"P````EH0$`#P```%*A`0`?````8J$!`"@```""H0$`"````*NA`0`&
M````M*$!`!````"[H0$`"0```,RA`0`$````UJ$!`!@```#;H0$`#@```/2A
M`0`0`````Z(!``X````4H@$`!0```".B`0`)````*:(!``@````SH@$`"0``
M`#RB`0`+````1J(!`!$```!2H@$`!````&2B`0`.````::(!``4```!XH@$`
M"P```'ZB`0`.````BJ(!`"$```"9H@$`"@```+NB`0`"````QJ(!``<```#)
MH@$`!0```-&B`0`+````UZ(!``<```#CH@$`,@```.NB`0`D````'J,!`#$`
M``!#HP$`%P```'6C`0`%````C:,!``<```"3HP$`!P```)NC`0`,````HZ,!
M``@```"PHP$`#0```+FC`0`3````QZ,!``\```#;HP$`#````.NC`0`.````
M^*,!``L````'I`$`!P```!.D`0`(````&Z0!``@````DI`$`%@```"VD`0`)
M````1*0!``<```!.I`$`"0```%:D`0`@````8*0!``4```"!I`$`!@```(>D
M`0`&````CJ0!``H```"5I`$`!P```*"D`0`2````J*0!`!(```"[I`$`!@``
M`,ZD`0`6````U:0!``L```#LI`$`&P```/BD`0`$````%*4!``4````9I0$`
M#P```!^E`0`<````+Z4!``<```!,I0$`"0```%2E`0`5````7J4!``0```!T
MI0$`"@```'FE`0`/````A*4!``H```"4I0$``@```)^E`0`1````HJ4!``<`
M``"TI0$`'@```+RE`0`>````VZ4!`#,```#ZI0$`)0```"ZF`0`I````5*8!
M`%T```!^I@$`$P```-RF`0!4````\*8!`"X```!%IP$`00```'2G`0!>````
MMJ<!`"`````5J`$`2@```#:H`0`H````@:@!`#(```"JJ`$`(P```-VH`0`=
M`````:D!`"P````?J0$`[@$``$RI`0`;````.ZL!`!0```!7JP$`1@```&RK
M`0"%````LZL!`#\````YK`$`%P```'FL`0`@````D:P!`!L```"RK`$`&0``
M`,ZL`0`9````Z*P!`#$````"K0$`2P```#2M`0`X````@*T!`!P```"YK0$`
M%0```-:M`0`8````[*T!`!<````%K@$`*P```!VN`0`<````2:X!`!\```!F
MK@$`$P```(:N`0`,````FJX!`"\```"GK@$`'@```->N`0`?````]JX!`"$`
M```6KP$`0@```#BO`0!0````>Z\!`#4```#,KP$`80````*P`0!&````9+`!
M`"\```"KL`$`)P```-NP`0`F`````[$!`"@````JL0$`1P```%.Q`0!0````
MF[$!`"L```#LL0$`)@```!BR`0!!````/[(!`$X```"!L@$`*@```-"R`0`I
M````^[(!`"T````ELP$`)0```%.S`0`E````>;,!`"8```"?LP$`:@```,:S
M`0!H````,;0!`*X```":M`$`&P```$FU`0`J````9;4!`#8```"0M0$`+P``
M`,>U`0!%````][4!`"`````]M@$`40```%ZV`0`B````L+8!`"$```#3M@$`
M"P```/6V`0"U`````;<!`#P```"WMP$`(@```/2W`0`J````%[@!`"L```!"
MN`$`'````&ZX`0`O````B[@!``8```"[N`$`!@```,*X`0`#````R;@!``X`
M``#-N`$`"P```-RX`0`*````Z+@!``L```#SN`$`!0```/^X`0`,````!;D!
M``0````2N0$`;@```!>Y`0`$````AKD!`!8```"+N0$`!````**Y`0`'````
MI[D!``4```"ON0$`!0```+6Y`0`$````N[D!`!````#`N0$`"````-&Y`0`1
M````VKD!`!,```#LN0$``@````"Z`0`'`````[H!``<````+N@$`%````!.Z
M`0`,````*+H!`!8````UN@$`!@```$RZ`0`3````4[H!``P```!GN@$``P``
M`'2Z`0`H````>+H!``0```"AN@$`!@```*:Z`0`(````K;H!`!L```"VN@$`
M-````-*Z`0`G````![L!`"@````ONP$`$P```%B[`0`@````;+L!`!T```"-
MNP$`&P```*N[`0`@````Q[L!`!L```#HNP$`&@````2\`0`B````'[P!`!0`
M``!"O`$`,0```%>\`0`6````B;P!`"\```"@O`$`)@```-"\`0`:````][P!
M`!X````2O0$`'@```#&]`0`9````4+T!`",```!JO0$`'0```(Z]`0`H````
MK+T!`!H```#5O0$`&P```/"]`0`@````#+X!`",````MO@$`&0```%&^`0`A
M````:[X!`!X```"-O@$`-@```*R^`0`>````X[X!`"(````"OP$`(@```"6_
M`0`C````2+\!`!T```!LOP$`&````(J_`0`B````H[\!`"$```#&OP$`,@``
M`.B_`0`@````&\`!``H````\P`$`"P```$?``0`6````4\`!`"@```!JP`$`
M'0```)/``0`*````L<`!``\```"\P`$`%P```,S``0`.````Y,`!`!8```#S
MP`$`(0````K!`0`(````+,$!``<````UP0$`(@```#W!`0`E````8,$!`"4`
M``"&P0$`%@```*S!`0`*````P\$!`-P```#.P0$`$0```*O"`0`5````O<(!
M``P```#3P@$`#P```.#"`0`6````\,(!`",````'PP$`!@```"O#`0!`````
M,L,!`!4```!SPP$`%````(G#`0`'````GL,!`!,```"FPP$`"@```+K#`0`W
M````Q<,!`"D```#]PP$`%@```"?$`0`4````/L0!`!0```!3Q`$`,0```&C$
M`0`1````FL0!`!(```"LQ`$`$P```+_$`0`1````T\0!``H```#EQ`$`%P``
M`/#$`0`(````",4!`"`````1Q0$`"````#+%`0`3````.\4!``<```!/Q0$`
M$0```%?%`0`'````:<4!``@```!QQ0$`"0```'K%`0`V````A,4!``4```"[
MQ0$`#P```,'%`0`4````T<4!`!$```#FQ0$`"P```/C%`0`,````!,8!``<`
M```1Q@$`$P```!G&`0`+````+<8!`!L````YQ@$`$````%7&`0`:````9L8!
M`!<```"!Q@$`"P```)G&`0`,````I<8!`!@```"RQ@$`"0```,O&`0`J````
MU<8!`!$`````QP$`"@```!+'`0`"````'<<!`!`````@QP$`%P```#''`0`+
M````2<<!``,```!5QP$`"@```%G'`0`%````9,<!``<```!JQP$`#````'+'
M`0`+````?\<!`!0```"+QP$`%0```*#'`0`.````ML<!`#@```#%QP$`&```
M`/['`0`8````%\@!`"X````PR`$`"@```%_(`0`E````:L@!``4```"0R`$`
M%@```);(`0`\````K<@!``T```#JR`$`#@```/C(`0`&````!\D!``0````.
MR0$`!````!/)`0`*````&,D!`!<````CR0$`!0```#O)`0`&````0<D!``@`
M``!(R0$`!0```%')`0`4````5\D!`!4```!LR0$`!0```(+)`0`7````B,D!
M`!X```"@R0$`'P```+_)`0`:````W\D!`!````#ZR0$``@````O*`0`$````
M#LH!``L````3R@$`!0```!_*`0`%````)<H!``,````KR@$`#@```"_*`0!,
M````/LH!`!P```"+R@$`*@```*C*`0`F````T\H!`$X```#ZR@$`+P```$G+
M`0`?````><L!`%T```"9RP$`'0```/?+`0!'````%<P!`"````!=S`$`,0``
M`'[,`0`S````L,P!`#````#DS`$`*````!7-`0`T````/LT!`#8```!SS0$`
M-````*K-`0`P````W\T!`"@````0S@$`(@```#G.`0`X````7,X!`!0```"5
MS@$`%0```*K.`0`.````P,X!`&$```#/S@$`"@```#'/`0!C````/,\!`&D`
M``"@SP$`)P````K0`0`;````,M`!`!@```!.T`$`&````&?0`0`1````@-`!
M`!T```"2T`$`#P```+#0`0`Y````P-`!`"(```#ZT`$`&P```!W1`0!J````
M.=$!`!8```"DT0$`"@```+O1`0`$````QM$!``8```#+T0$`"````-+1`0`%
M````V]$!`!4```#AT0$`$@```/?1`0`9````"M(!`",````DT@$`#P```$C2
M`0`-````6-(!`!$```!FT@$`!````'C2`0`*````?=(!``D```"(T@$`!P``
M`)+2`0`-````FM(!``@```"HT@$`#````+'2`0`(````OM(!``D```#'T@$`
M%@```-'2`0`6````Z-(!`!````#_T@$`"P```!#3`0`*````'-,!`!4````G
MTP$`"0```#W3`0`.````1],!``D```!6TP$`!@```&#3`0`%````9],!`!,`
M``!MTP$`"0```('3`0`*````B],!`!8```"6TP$`"@```*W3`0`'````N-,!
M``@```#`TP$`"````,G3`0`,````TM,!``8```#?TP$`!@```.;3`0`9````
M[=,!``(````'U`$`"`````K4`0`&````$]0!``8````:U`$`*0```"'4`0`%
M````2]0!`!,```!1U`$`&0```&74`0`(````?]0!``P```"(U`$`!P```)74
M`0`&````G=0!``H```"DU`$`$````*_4`0`9````P-0!``@```#:U`$`#```
M`./4`0`C````\-0!``H````4U0$`"0```!_5`0`0````*=4!``4````ZU0$`
M!0```$#5`0`"````1M4!``L```!)U0$``0````````!<``````````````!L
M!@``=@,``.@```!@`P``T`(``/<!````````?P0``,8!```P````5@$`````
M```P!0``$P(```````"*`````````!0%````````XP8``-@&``!^`P``````
M`&D!````````K0```&<%``#T`@``_@4``*H%``#5`0```````"8#``"\`0``
M]P4``#0`````````GP8``!T$``#L!@``QP,`````````````.@8``,8%````
M````D`8``!\"``#Z`0``^P,````````-`@``<@4``"8%````````8P```)D&
M``#>````E`(``*\&``!J`@``+08````&``#;`@``7`,```@"``!3````%0``
M```````I`P``````````````````&04``)(```#V!0``!P,```````"+````
M````````````````U````,<```"6!0```````*T$``"1`@``3P(``-<#``"Q
M!0``I`(``%4$``#'!```=@(``'X"``#@`@```````#`$````````R@4``"\"
M```\!0``W0````````!E`P``I08```````!/!@``8@(``(@%````````````
M``@```#3!0``[````&(#```P`0``Q`0``(\&```E`P```````*(#````!0``
M%@(``-\%``#P`P``Y04`````````````'`8``*@&``"F`0```0(``-`!```\
M`@``(@,``,4"``#+````Y````,`&````````.@,```````"P````00$``$H%
M````````)`8``,(#``!'!```:0````````"^`0```````%@````2`@``X@$`
M```````U!@``[`(``(0%``##!0``ZP8``)H$````````J`(```<&````````
M@@,``,8"````````YP$``"@````P`P`````````````)!``````````````3
M````-0,``"$&``"C!@```````,@#````````P08````````1!```<P,`````
M````````>0$``)(!``"9`0``7P4``#,$``#_!0``H04``*L%``#U`@``8P,`
M`-0$````````C0(``+0&````````60$``&(&``#I!@``]@```&@&``#>`0``
MBP4``````````````````'\&````````%P(``%@%``![!@```````/H&```:
M````$P$``'H`````````R`0``)T&``#2````9P```!D"````````````````
M``#3`0``2P0``$H&``"]`P```````+@``````````````+L```"'`P``$@``
M`,`#``#-!0``200``$8&```^`0``7P(``/D!``!:!```:P(``+<#``#'!0``
M'`,``!D&````````=0(``+\&``!7`@``UP0``'H$``!3`P``\`0``+X`````
M````"`8```@!````````S08```````#1`@``[@```/``````````"`0``'0%
M``!Y!```E`,```````!G`@````,``)T"``#9`P``@0(`````````````_0$`
M``4$``!*!```O`4``-`%```K`0``L@0``.L%```6!```#@````````"3!```
M`````%0%```L!0``9@0``%("``"!`P``(@0``.(&````````[0,``)<#``#A
M`0``JP$``#8%``"=````EP0````````E````>`````````"Y`0``*P``````
M````````20$`````````````:@$``,$"``!0````P04``$P$``!U`0``^0``
M`,@&````````E08``-P%``#^`@``'0(``'\```!\!@```````%D#````````
MR`(``"(```"(`@``9@4``%<!```F`@```````+H#``!4````Q@```'L"```<
M!```FP$``*P````B`@```````&`"```L`@``\0(``/(&``!_`@``*@8``(`"
M``"*!@```````+@&``"9`````````%T"``!W!0``%P4``#<#````````[P$`
M`&L$``#D!0``Y08``.D!``"/`@```````.D%````````Y@,``/P$```%!0``
M`P0````````E!```B08``.$"```D`0``F@$```0```#2!```:P8``(<```!K
M!0``10(``*H```"R```````````````Z!0``:P,``$\$```3!```(`,``-D`
M````````E0$``+<!``#F`0```````*L$``!P!```_@$``#T#``#]!@``G`$`
M`+L%```+````OP$``!L!````````-P8`````````````6P,``.X#``"S!@``
M`````*<```#H`@``/08``*4$``"Y!@```````*,"````````A0(```````!\
M!0``A08``-4"``"`````W00``(<$``!X!0``,P(``'H&```Y`@``G`0```8$
M``"[`P``.@```'\!``"$`@``*@4``.<&```X`0``JP8``),!``#+`@``908`
M`!`&``!P`@``\P$``.(%``#8````U08``),#``!)!0``5`,``*8"```O!@``
M`````%H!``"(!```VP$``!`%``"_!0``]`$``#D!````````C@$```````!#
M!````````'4```"2!0```@0``#P#````````I@```'\#```'!0``U`,``.4`
M``!W`@``/@4``,L!```Q`P``(P````````""!@``````````````````T04`
M`#L$``!>`P``=`,``.`&``#*`P``A`$``%D"``!!`@``<`,``)`!``!-````
MW@4``%H```!]`````@8``)X#``"P!0``````````````````U@```)P```!=
M`P```````($```!A`0``M`(``!X!````````9`$```````":!@``1````%\#
M``#&!@```````*D"``!E````^P4``-T"``"'`0``9`8``$,&````````CP``
M`-$!``#A!```2P8``"$!``!6!@``;0(``',$``!+````J00``"@!``"U````
M?@0``',&``"5`P``B0(`````````````>`,``+H"````````E`8```````#:
M!0``````````````````H0````````!D`@``=`(``'(&```"`0``)P0`````
M```&!0```````$X#```_!@``2`$``+H!`````````````$T$``#?`P``J08`
M`&$`````````-0(`````````````S0````8"```````````````````J!```
ME04``,T$``!;`````````)T#````````804``)D$``"H!```LP0```$%``!H
M`P``?0$````````!`0``XP0```0"``!M!@```````%$&``#X!```G@4``!8!
M````````/P4``-<````D`P``!`4``$,%````````B````'T$``"X!0```P$`
M`'<#```G`@``1@,``"<!``!%````2````&`````6````T00``#4%````````
MPP,``````````````````'L!```(`P``4P0````````X````T@8``)8!```6
M!@```````.$```#2`P``"P0``&,%``"$`P``"0(``(<"``"`!0``)08````"
M``"=`0```````*4%``!I`@````````````#,`0``@P0``'H#```<````C@(`
M`'<`````````Y@8``!P"``!,`P``IP8```8&``#H!```O04``"<```#Z````
MYP(````````*`@``)`(```````#.!0``9P,``#0%```%!@```````/$$``"Y
M!0``3@$``,$$````````9`0`````````````#@0``(<&``"U`@``MP```($&
M``#M!````````%X%``"P`P``^P```/(```!O!@``GP(``)(&``#5````6`8`
M````````````'0,``&T```#_!```I`0``&0%``!(!@``?`$``.X$``#:!```
MX`$``#P`````````808``.0$``#B````LP(``'D%``!&!````````&<!``!<
M!0``8@$``$T&``!;`0```````$D```!``@``#0```*8&``#X!0``````````
M``#)!```CP,``"P!``!,````]0```.<```!*`P``9````(,"``#3`P``%`,`
M````````````\P,``*\%```C!```_0`````````@`0`````````````X`@``
MPP8``,`"``")`P``UP8``#X"``!V!```N@`````````'`@``O@8``"X#``#*
M`@``Y@0``%L"``!B!````````"X```!9!0``H@8`````````````=@8`````
M``!&`@``X`0``!0&````````````````````````M`$``%,&````````````
M`!$!````````F@```.\#````````9@$```````#,````B00``/$&````````
MQ`$``/X````T!```````````````````S@$``"T#````````*`8``+L"``!$
M!```O@(``(<%``"5`@``708``.4!````````4`4``!\&````````K`0``.8%
M``!T!@```````)D%```;!0``W`(````````````````````````+`0``90$`
M``````"H`0``)P,```P!``"]!```/@````````"E````7`(``!H!```.!0``
ME````,(`````````F`$```P`````````,@0```````"%`0``+@4``,8$````
M````B`,```(%````````SP$``#D%```:`@``\P4``"\!````````X`4`````
M``"7!@``6@,``)$$````````-@,``)`#````````#`8```$&``"E`@``5P4`
M```````$`0```````#\```#K!`````````````!H`@``9P0``(0&````````
M,P````````#H!@``K08``&(```#$````"08```````#D`P``O`,``%4"````
M````D`(``&0#````````208``-$#``#/`P``*P4``*4#````````V@```(("
M``!Z!0``VP4```````#8!0``D@0````````)!0``Z@4``'T#``#8`P``I`8`
M`-H&``"N!@``30(``*0!``"J!```A@4``#8```#4`0``\@4``.$#```B`0``
MM@,``)<!``"%````R0(``+T```";````H````+8"``````````````````!8
M!`````````P%``#@`P``````````````````!@```'D&``#^!```Z`$``.H&
M````````(0,``%,"`````0````````````#[`@``0@(``,`%``!\`P``````
M`#L%``!\`````````&8&```5`P``OP0``+`!``"``P```````*<$````````
M5`(``,X&```````````````````J`0``"@4``$($``""!0``FP4```````!J
M!@``KP,``+X$```O!0``!`0``(D`````````)04``%T!````````#P,`````
M```<`0``````````````````800``/T$````````9P8``"L&``#W!```]@8`
M`'0$`````````````!\!````````]@(````````'````WP0```````"5!```
MJ`4``)X"``"R!@``10,``+P$``"0`````````"<&``!)`P``FP0``"X&````
M````\0$```````#=`0``OP(``%`!```2!```#04``!8%````````````````
M``"``0``G@$````````1`P``:@0```````!.!0```P4``#H"``"G!0``````
M`.0&```\!@````````````#%`P``V0(``-`&```>`P``M@0``,D```"N!0``
M`````-P!````````+00````````/!@```````````````````P(`````````
M````'`4``'(```"I!0``1`,``.H$``"-!0``````````````````B@4``%8$
M```V!@```````$@%``"*!```<````"D$````````T`0``%@!````````;P,`
M`-(%````````MP(``'`!```C!0``VP0``!<```"J!@``X04```````!N`0``
M]`4``&T$````````104```````#)`0``PP$``-0"``#0`P``?0(``'L%``!T
M`0``$````*H!``"Q`0```````.H`````````_@,````````W!```0P```!(%
M````````$P,``````````````````(T$````````@P,``*,````*`P``F0,`
M``````#,!0``6@(``$`%``#8`@``K`$``"`$````````OP```$4!````````
M4@0``$`&`````````````!@```"X`@``;`4``#\"`````````````'8`````
M````G@8`````````````M@$``&X`````````J@,``$@"``#+!```3`$`````
M``!9````IP$``!@"```#`P``C````!(#``#T`P```````$\```!1!```O`8`
M`$,#```Z!```1`4````````%`@``W04```````#M!@```````$T%``"-````
M````````````````0@,``,H!``!+`P``;`$```````#O`@```````#T"``"B
M!```]P```.,%````````(04``.L```"3````5`$```````!Q!@``$`,``/0$
M``"L`P```````#4`````````<P```)0!````````W@,```````!5!@``````
M`"T%````````L`0```H&``"I`0``6@8``#,!```Y`P``SP4``%4````%`P``
MBP8``$L"```'!```'04``(,&``#V`P``FP8``+,```"I````GP$``"\#``"K
M`@``*0$```````"8!@``_0(```````#5`P``&@0``/0&```T`@```````/H#
M``"(!@``>0```*\$```A`@``.08``$`!``"]!@``H`4``*8%```;!@``_```
M`-4$```\`0``>`$``"8```"&`P```````/@#``![`P``#@(```````!M`P``
MV@$``.\%``"(`0```````.,```"T````X@0``-X"``!$`0``F`(``&$#```R
M`@`````````````Q`0``K@,``'`&```8`P``K0(``#T````N!````````)\`
M````````UP(```````#U!@``;@8``!$"```1````@P4``(P"``!`!```$P8`
M`"@$``"/!0``Z`4``'X%`````````````!\%``!F`P``J0,``%X"``!R`@``
M3P,``!L#````````!0$````````7`P``_`4`````````````R04``/4%````
M````Y0,``!L````W`@``1@```````````````````*@#``#B`@``C@0``)$#
M``!U!0``1P`````````X!@```````)\%``!>!@``M04``*P%``"T`P``M@``
M`$(%``!N!```PP(``&P```#P!@````````````"`!```Q08``.X%``#3!```
M`````%<```#M`@```````!\$``!W!```3@(``%4#``"P`@``\`4``.$&``"U
M`P``,`8``*$$``",`0```````"$$``!C!@`````````````L!@``LP$``',"
M``!3!0``8`0``"0````.`0``004`````````````PP0```````".!@``6@4`
M``````"8`P```````/4$``#%!0``[`$``!D`````````'0$``,T"```8!@``
MZ00``(($``!Q`@``:`4``!0`````````(@8``!\#``#8`0``,P8`````````
M````6P0```````!@!@``Z0,``.4$```/`@``;@4``(8!`````````````"X!
M``"%!0``]@$``*(%`````````````)T$``#6`@``OP,``"@%``"A!@``W08`
M`'\%````````G`8```````#`````8P(``)0$```L````*0(``#D````[`P``
M`````-L#``!=!````````&\````U!```3P4``.0"```/!`````````````#4
M!0``_`8``.L"``!I!```5@(``/P!```2!@``%@,``#L&``#8!```D`4``!4!
M```#````*`(``($%``!M!0``I````$4$``#S`@``&`$``)T%````````````
M`-````!%!@``B@,``!`"````````F@,``&P#``!T````7`0```````!U`P``
MP@(`````````````1P,``&H#````````S`,```8!`````````````!$&``!,
M!@``MP4``+L$``"N!```5P,``(D!````````J`````````";`P``#0$``,@!
M````````Z0```&P$``"K````Q`8``.P#``!Y`P``.`4```````#$`@``````
M`$@#``#Q`P``[0$```````!'`0``^@(``(H!````````:@4`````````````
MHP$``-\"``!-`0``00```)<"```E`@``2@````````````````````````!.
M````%08````````'`0``SP0`````````````5@````@%``#<````D0$`````
M``#?`0``ZP$``%(#````````^P0``*,#``"1````[@$``","````````YP4`
M`%$"``!1````S@(``"`"``"O`@````````````#.!```4`8``!\```#/`@``
M_0,````````*`0``[P0``!D#```,`@``GP,```````!I`P```````%P!````
M````2@(````````!!````````&H``````````````+T"````````HP4`````
M````````EP```(P#````````A@0``/L!``",!@``````````````````````
M``````#T````8P$`````````````7`8``%\!``!F`@``B04``"D&````````
MQ0```.8```!1!0``:04``/@```"!`0``Q0$```````",!`````````````!\
M!```904``$(!```_!```?04`````````````C`4``$D"`````````````.H#
M``![````/@8``!<!``"6`@``%P0``+L&``#@````I@,``(L$````````````
M``````#K`P``BP,``#(```#?!@``$@$``,X````-`P````````````"S`P``
MW`,``#H!``#S!@``H`,``%T````O!```]0$``,$````C!@``L@4`````````
M`````````'$!``#&`P``8`$``"L$``"L`@``^00``.T```!L`@``E@,``$@$
M````````^04``*T#````````]P,``!@$```^!```:P```"H```"A`P``30,`
M`*<"````````EP4`````````````3`4```````"%!```U@,``%@#````````
M008``.,"``#W`@``\`(``$````#"!0```````,0#```A``````````````"K
M`P````````````#/````+`,``"`%````````%0(``,T!`````````````&\!
M```W````\@$```````````````````````#_`@``_P```/H$```@````\0``
M```````:!0``'08``)4```"<`@```````&`%```4`@```````*X!``#X!@``
MKP$``/\#``#G`P``,08``-$`````````90(``"8&`````````````-D$``#[
M!@``FP(``$<%``"#`0``G@0```````#>!@``@@```&8```#R`@``M@4`````
M``!X`@``A@`````````T`0````````````!&`0``N@8``'(!``#I`@``#`0`
M`%(&``!*`0``?@$``(\!``#6!@``;0$``-P$```C`P``F`0``/($````````
ML@$``,T#``"U`0``HP0``+0$```V!```N00``-D%````````U@0``.4"```,
M`P``[@(````````K`P``Q00``+8&``"Y````@P``````````````/00```\!
M``"O````F`4``)0%`````````````!`!``!7!```<P$``&@!````````NP$`
M`,L%```+`P``L0````````!"````G`,``#`"``"Z!````````"8!``"1!@``
M%00``%`$````````M`4``)`$``!B!0``<0,``+D"````````;@,``$0&``".
M!0``````````````````!@,``````````````@,``#T%````````)0$``(T&
M``!C!````````!`$``"\`````````&\%``!?````2P4``"H"``!Z`@``<P4`
M``````"A`0``P@0``)8&``#3`@``>P0``#<%`````````````"8$``"W!```
MS`(```````!;!0``80(````````*!```R@```*T%```9!````````,<"``"@
M!````````%X$```)`0```````-$&````````UP4``#@#````````QP$``%(%
M``#``0``[`0``#(#````````W`8``$L!``!X!@```@(``-D&``!!`P``=08`
M````````````S`8``````````````````%\&``#X`@```````+$"````````
M````````````````.00```T&````````R@8``!X&``"B`````````.T%``!O
M`@``(@4``'($`````````````"T"`````````````),%```D!````````,`$
M``````````````````#)!@`````````````)`P```````&\$``#\`@``````
M``````"Y`P``R@0``-\```"@`0``O0$``(8"``!9!```>@$``,(&``"/!```
M5`0```````":`@```````"X"``#V!```@`8```````!1`0```````.P%````
M````^0,``$X&``"+`@```````",!````````#@8``,X#``":!0```````!X`
M``##````704``*(!```/!0``K`8```0&``"^!0```````"D%``#D`0``L@(`
M```````+`@``MP8``#(&``#3!@``(`8``*X```#J`0``U@4```````!H````
M+`0```````"R`P``:`0```````!&!0``SP8```L%```_`0``=00``-L&``!`
M`P```````*4!``"\`@``D@,````$``"-`0``7P0```````!^`````````#(!
M```Q`@``.`0``-L````>!`````````````"Z!0``4@````````!N`@``````
M```````.`P```````*X"```\!```.P```(X#``!8`@``'0```)@```#\`P``
M`````(4#``"U!```P@$``)D"``!E!```_P$``'$````+!@``M08``-H"```V
M`0``S`0``!X%``#7`0``>0(``#,#````````<04``'`%``!0`P```````)8`
M````````Y@(````````S!0``=P$``!H#````````DP(``*$"```_`P``````
M`%$#````````P0$`````````````Q`4````````3!0``&@8```````#!`P``
MG`4``,L&``!7!@``H`8````````5!0``)P4``/D"````````]P8`````````
M````A@8``&L!```[`0```````%8#``">``````````````!2`0``^@4``$<&
M``#H`P``-0$```(`````````A`0```````""`0```````%X!```W`0``````
M`#T!```>`@```````$X$``!'`@``,00``"H#``!R`P``IP,``$\!``#2`0``
M\`$```````!;!@``YP0``"@#````````L0,```0#```!`P``N`,``-,```"@
M`@`````````````#!@``*P(```\````4!```A`````H```#X`0```````.H"
M``!0`@``\04``%X```#'!@``LP4``(T#```;`@```````/,````R!0``%P8`
M`"\```"!!```-@(``!L$```%````[P`````````Q````#00````````9`0``
M[P8``%4!````````W@0``!$%``!I!@``B@(``*T!````````[@8``(X`````
M````608````````[`@``H@(``,D#````````]0,``,@%``"2`@``GP0`````
M````````L00``/D&``!X!````````+@$`````````````/(#````````V@,`
M```````T!@``?@8``$$$``#9`0```````.(#```Q!0``3`(``)8$````````
M%`$``"T```#S!```J@(``*0#````````U`8``)$%````````_04```````#C
M`P``*0````````!V!0``I`4``-T#``!]!@``0@8``#0#``!6!0```````-("
M```8!0``=@$``'<&``!5!0``BP$``+$&``#C`0``L`8``"0%``!#`0``````
M`-8!````````DP8``"T!``#(````4P$``+X#```^`P``0P(``'$$````````
MI@0``,L#``#5!0```````+@!``!$`@```````'P"``!4!@``"0`````@*"5S
M(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O
M9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``E9"`E<R!A;F0@
M)7,`)60@;F]T97,`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I
M;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!
M9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&9I
M;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E<75I<F5D`"5S(&UI
M;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E
M<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML
M:7-T`"5S.B`E<P`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S
M('1O("5S`"TM('-E;&5C="`M+0`Q(&YO=&4`,3(@2&]U<B!&;W)M870`,C0@
M2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD(&ES(')E
M<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3
M:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN
M+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92X`06-C97-S(&1E;FEE9"!D96QE=&EN9R!N;W1E+@!!8V-E<W,@9&5N:65D
M(&UO=FEN9R!T:&4@;F]T92X`06-C97-S(&1E;FEE9"!S879I;F<@;F]T92!T
M;R`E<RX`06-C97-S(&1E;FEE9"!S879I;F<@;F]T93H@)7,`06-C;W5N="!0
M87-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H
M:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@
M3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`
M061D(&-A=&5G;W)Y`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P
M86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@
M=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U
M<V5R`$%D9&EN9R!!($YE=R!.;W1E`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F
M9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE
M;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L
M;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`
M06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E
M($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N
M871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA
M=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@
M4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!
M<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E
M861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T
M92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I
M;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT:6YA
M`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N
M9&EN9P!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@
M4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN
M=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U
M<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q
M=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I
M=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I
M<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T
M:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T
M:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!
M=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE($-A
M=&5G;W)I97,Z`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%
M>&-U<V5S`$)A8VL@=&\@3F]T97!A9`!"86-K('1O($YO=&5P860@3W!T:6]N
M<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I
M;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A
M<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!"
M:'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B
M(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O
M;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D
M97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T
M;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@
M5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D
M($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<P!#4U8`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A
M<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O
M<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC
M96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B
M)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO
M="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N
M;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@
M8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT
M<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB
M97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@
M;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B
M96QS`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0
M<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@
M<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E
M<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D
M:7-P;&%Y(&]P=&EO;G,N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI
M;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N
M86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@;65M
M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RX`0VAO
M;W-E('EO=7(@9&5F875L="!.;W1E<&%D+@!#:')I<W1M87,@27-L86YD`$-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!&
M;W)M`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L
M96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L
M:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL
M87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L
M;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM
M86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S
M`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG
M;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE
M8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E
M<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y('-E;&5C
M=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T
M(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D
M9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN
M`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D
M("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N
M=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK
M`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T960`
M0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I
M80!#=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E
M871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S
M96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C
M:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T
M92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`
M1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A
M=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT($YO
M=&5P860`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I
M;F<@9&ER96-T:6]N.@!$969I;FET:6]N<P!$96QE=&4`1&5L971E($=R;W5P
M`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C
M=7)R96YT(')O=P!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8V5N9&EN9P!$
M97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$97-C<FEP=&EO;CH`
M1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P
M;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@
M<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$
M:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y
M(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@
M;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M
M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A
M;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@
M;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K
M`$5D:70@1W)O=7``161I="!.;W1E`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E
M<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N
M<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP
M=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E
M<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N
M9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!.;W1E`$5M<'1Y(&UE<W-A9V4N
M`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N
M;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G
M.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17%U871O<FEA;"!'=6EN96$`
M17)I=')E80!%<G)O<@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R
M="!.;W1E<P!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9?=6QL(%1E
M>'0`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T
M;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N
M;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I<@!&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O
M<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3
M:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL
M92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA
M;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER
M<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O
M9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE
M<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D
M($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.
M86UE`$=O`$=O961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`
M1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D
M;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R
M;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T
M(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'
M=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET
M:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H
M=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S
M<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N
M(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@
M240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P
M861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E
M/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI
M9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!
M9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K
M9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC
M;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET
M>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E
M92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@
M;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P
M87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L
M('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),
M`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L
M;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@3F]T97,L(%-T97`@
M)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T97,`26UP;W)T
M960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T
M97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@
M86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E
M87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!)
M;F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!)
M;6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L
M=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT
M97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@
M8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A
M9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS
M97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!)
M;G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS
M97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`
M26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E
M9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@
M9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A
M<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED
M('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED
M('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O
M<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R
M>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`
M2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL
M`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O
M<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I
M;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+
M:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+
M>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S="!1
M=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA
M>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,
M969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N
M($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`
M3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,
M:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H
M="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P
M;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,
M:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T
M+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C
M<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM
M93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,
M;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F
M86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S
M`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE
M;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D
M;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA
M;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA
M<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`
M36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@
M;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA
M>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365M;R!497AT`$UE;G4@;6]D
M93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`
M365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE>&EC
M;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE
M(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN
M9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N
M($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO
M9&EF>2!54DP`36]D:69Y:6YG("5S`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L
M:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`
M36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-
M;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T
M`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I
M<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE
M8W1I;VX`37D@06-C;W5N=`!->2!.;W1E<P!->2!0;W)T86P`37D@4&]R=&%L
M($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB
M:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL
M97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!5
M4DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%52
M3`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R
M(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C
M97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.
M97<@0V%T96=O<GD`3F5W($UO;VX`3F5W($YO=&4`3F5W(%5S97)N86UE("AO
M<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S
M`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T
M96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO
M;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF
M:65D+@!.;R!N;W1E<&%D<R!A<F4@879A:6QA8FQE('1O(&=U97-T<RX`3F\@
M;F]T97,`3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N`$YO
M(&YO=&5S('1O(&1I<W!L87D`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F
M96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME
M<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P
M96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@
M;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I
M;F<@<VEG;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`
M3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;U]T90!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R
M9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M
M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!
M9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT
M960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T92!#871E9V]R>0!.;W1E
M($1E=&%I;',`3F]T92!,:7-T<P!.;W1E(%1E>'0`3F]T92!?5&5X=`!.;W1E
M(&YO="!F;W5N9"X`3F]T95]P860`3F]T97!A9"=S(&YA;64Z`$YO=&5P861S
M`$YO=&5P861S(&UU<W0@:&%V92!A(&YA;64N`$YO=&5S`$YO=&5S(%-U;6UA
M<GD`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E
M<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB
M97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T
M;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z
M($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A
M<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG
M(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/
M<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@3W!T:6]N
M<P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T
M960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$
M871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E
M<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@5"U3=&]R;7,`4%](4"!3
M:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I
M=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U
M87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D
M.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI
M<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I
M;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE
M<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE
M87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT
M97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`
M4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E
M`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T
M:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME
M>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A
M<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I
M;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN
M(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-
M96YU($5L96UE;G1S.@!2969R97-H($QI<W0`4F5F<F5S:"!0;W)T86P@5FEE
M=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UO=&4@
M4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V%T96=O<GD`4F5M
M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U
M:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2979E
M<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED
M9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O
M<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F
M=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`
M4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M
M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2
M=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A
M<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN
M9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(
M96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D
M:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R
M871I;VXN`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!2
M97-U;'1S`%-E87)C:"!38V]P90!396%R8V@@7U1E>'0`4V5L96-T($9I;&5S
M`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A
M(&YE=R!O=VYE<@!396QE8W0@82!N;W1E<&%D`%-E;&5C="!A('-E<G9E<@!3
M96QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP
M;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E
M;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&5C
M=&5D($-A=&5G;W)I97,Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`
M4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE
M9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T
M(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@
M:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@
M=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O
M<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S
M8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T
M:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO
M=R!A8W1I;VX@8G5T=&]N<S\`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U
M<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M`%-H;W<@;F]T97!A9"!N86UE/P!3:&]W(&YO=&5S(&9R;VT@=&AE<V4@8V%T
M96=O<FEE<P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC
M:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R
M<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6
M:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L
M;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N
M('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3
M:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3
M;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N
M;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@
M:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O
M96US`%-O<G0@8GD@0V%T96=O<GD`4V]R="!B>2!.;W1E(%1E>'0`4V]R="!O
M<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E
M`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C
M:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T
M<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A
M=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!
M9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN
M(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3=6)M
M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N
M<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R
M;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`
M4W=I='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I
M86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FUS`%135B!F:6QE`%1A
M8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@
M3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E
M<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL
M86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($UA
M:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4
M:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I
M;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB
M97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S
M<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@
M;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S
M(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H
M92!N;W1E('=A<R!D96QE=&5D+@!4:&4@;F]T97!A9"`B)7,B(&-O=6QD;B=T
M(&)E(&-R96%T960Z("5S`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@8W)E
M871E9"X`5&AE(&YO=&5P860@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;F]T97!A9"`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@;W!E;G-S;"!M;V1U
M;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L
M87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B
M96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L
M92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP
M92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY
M`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N
M;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I
M9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<P!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!V3F]T92!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F
M="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E
M<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!R
M96UO=FEN9R!T:&4@;F]T93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN
M9R!T:&4@;F]T93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!V:65W:6YG('1H:7,@;F]T97!A9#H@)7,`5&AE<F4@=V5R92!N;R!M96UO
M<R!T;R!E>'!O<G0N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P
M.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`
M5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T
M960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R
M`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@
M<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`
M5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN
M9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO
M<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`
M5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`
M5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z
M(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O
M<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B
M)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D
M96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L
M92!T;R!D96QE=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX
M*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@
M4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5
M;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN
M;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U
M<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO
M=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO
M=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L
M;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D
M871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U
M9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5
M<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I
M;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`
M57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB
M96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO
M;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A
M;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L
M96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L
M:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T
M($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET
M:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET
M>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T
M=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@
M<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!7
M96QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/
M+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A
M`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@
M=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@3F]T97!A9"!S:&]U;&0@=&AE
M(&YO=&5S(&)E(&%D9&5D('1O/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN
M<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7
M:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE
M(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F
M('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%
M87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`
M5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8+5)E9@!8-3`Y=C,@0F%S
M:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME
M>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A
M(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN
M(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A
M8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U
M(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@
M;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S
M+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A
M;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@
M<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@82!N;W1E
M<&%D('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@
M=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R
M97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9&5F875L="!N;W1E<&%D.@!9;W5R(&9U;&P@;F%M
M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&YO=&5P
M861S.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@
M<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;
M;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"86-K('1O($YO=&5P
M860`7T-,20!?0V%T96=O<GD`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2
M;W<`7T5D:70`7T9I<G-T($QI;F4`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O
M<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&ES="!.;W1E<P!?3&]G(&EN
M`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?37D@3F]T97!A9',`7TYE=R!.
M;W1E`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK
M+BXN`%]396%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R
M<P!A9&1R97-S(&)O;VL`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E`&9A;&QI
M;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z`&EM;65D:6%T
M90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE
M;65N=&5D`&YO=&5P860`;F]T97,N8W-V`'!E<F-E;G0`<&EX96QS`')I<VEN
M9P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`
M=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'9.;W1E`'<Z`'=E
M871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@36YE;6\@,BXP+6-V<PI2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#0M,3$M,C$@,#DZ,#(M,#@P,`I,87-T+51R86YS;&%T
M;W(Z(%!A=F5L($-H>71I;"`\<&%V96Q`8VAY=&EL+G1K/@I,86YG=6%G92U4
M96%M.B!#>F5C:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO
M;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M
M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU<F%L
M+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]/3$@)B8@;B4Q,#`A
M/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@;B4Q,#P]-"`F)B`H;B4Q,#`\,3`@?'P@
M;B4Q,#`^/3(P*2`_(#$@.B`R*3L*`"`H</AE9"`E<R!D;GDI`"`H4/CM<W1U
M<&]V_2!K;.WH("5S*0`@*'8@)7,@9&YE8V@I`"`H9&YE<RD`("AZ[71R82D`
M("AVZ&5R82D`(')Y8VAL;W-T(``E9"`E<R!A("5S`"5D('!O>F[A;65K`"5D
M+61E;F[M('#X961P;W;L[P`E<R`M(&]Z;N%M96[M`"5S(&]T:7-K`"5S($M"
M`"5S(&]P97)A8V4@^F1ROF)Y("T@<&]T=G)Z96[M`"5S(&YA<W1A=F5N[0`E
M<R!R96=I<W1R86-E`"5S('!O9&WM;FMY('!O=;[M=N%N[0`E<R!J:;X@97AI
M<W1U:F4N`"5S(&YA("5S("5S`'-O=6)O<B`E<R!B>6P@^G-P[+EN["!I;7!O
M<G1O=N%N`"5S(&IE('!OOF%D;W;A;F\`)7,@;6EN=70`)7,@;F5B>6QO(&YA
M;&5Z96YO+@`E<R!AOB`E<R!Z("5S`"5S(&%D<F5SX?@`)7,@:V%L96YDX?@`
M)7,G<R!:X7!I<V[M:P`E<R!S97IN86T@^FMO;/D`)7,Z("5S`"P@;N%R87IO
M=OT@)7,@)7,`+"!P<F]M[&YNX2!O9"`E<R!D;R`E<P`M+2!V_6+L<B`M+0`Q
M('!O>F[A;6MA`#$R(&AO9&EN;W;](&9O<FWA=``R-"!H;V1I;F]V_2!F;W)M
MX70`,C0@:&]D:6X`4')O('1E;G1O(&)L;VL@:F4@=GF^861O=N%N(&1A=&%B
MX7IO=OT@>F1R;VHN`%9Y<VMY=&QA('-E('KA=F&^;N$@8VAY8F$`4')O('IA
MN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@
M:VSMZ"X`4')O('9E<FEF:6MA8VD@<&]D97!S86[I('IP<N%V>2!J92!N=71N
M;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"X`4')O(&1EN6EF<F]VX6[M('IP
M<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"P@<')I=N%T
M;NT@4$=0(&ML[>@@82!H97-L;RX`4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@
M;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'4"!K
M;.WH(&$@:&5S;&\N`%!R;R!D9;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@
M<&]UONUT('9E^&5J;OT@4R]-24U%(&ML[>@L('!R:7;A=&[M(%,O34E-12!K
M;.WH(&$@:&5S;&\N`%!R;R!P;V1E<'/A;NT@>G!RX79Y(&IE(&YU=&YO('!O
M=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEVX71N[2!3+TU)344@:VSM
MZ"!A(&AE<VQO+@!0<F\@>F&Y:69R;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O
M=;[M="!V9?AE:F[](%,O34E-12!K;.WH+@!286YN[2!DZ;F[`%)A;F[M('#X
M96CA\FMY`%)A;F[M('-N[&AO=ND@</AE:.'R:WD`04TO4$T`05!)($E$`$EN
M9F]R;6%C92!O('1O;71O(&5D:71O<G4`26YF;W)M86-E+BXN`%1E>'0@9&]L
M^2!D;R!O8G+A>FMU`%1E>'0@9&]P<F]S=/AE9"!O8G+A>FMU`%9Y='9O^&5N
M[2!61E,@861R87/A^&4@;F5B>6QO('!O=F]L96YO+@!6>71V;_AE;NT@5D93
M('-O=6)O<G4@;F5B>6QO('!O=F]L96YO+@!3;6%ZX6[M('!O>F[A;6MY(&YE
M8GEL;R!P;W9O;&5N;RX`4/AE<W5N=73M('!O>F[A;6MY(&YE8GEL;R!P;W9O
M;&5N;RX`3F5B>6QO('!O=F]L96YO('5L;[YE;NT@<&]Z;N%M:WD@9&\@)7,N
M`$YE8GEL;R!P;W9O;&5N;R!U;&^^96[M('!O>F[A;6MY.B`E<P!5OFEV871E
M;'-KZ2!H97-L;P!5OFEV871E;&O](/KH970@8GEL('IA8FQO:V]VX6XN`%6^
M:79A=&5L:^D@^NAT>0!6;&^^`%#X:61A="!P;V1S:W5P:6YU`%#X:61A="!P
M;V0M<'+A=F$`4/AI9&%T.@!0^&ED870@;F]V;W4@<VMU<&EN=0!0^&ED870@
M;F]VX2!P<N%V80!0^&ED870@;F]VZ6AO('6^:79A=&5L93H`4/AI9&%T(&MA
M=&5G;W)I:0!0^&ED870@<VQO=7!E8P!0^&ED870@;F]VZ2#H;&5N>0!0^&ED
M870@<.%R`%#X:61A="`E<R!M96YU(&IA:V\@8F_H;NT@<VQO=7!E8R!-;WII
M;&QY`%#X:61A="!D;R!A9')E<^'X93H`4/AI9&%T(&1O(&WI:&\@861R97/A
M^&4`4/AI9&%T('6^:79A=&5L90!0^&EDX70@3F]V;W4@4&]Z;N%M:W4`4/AI
M9.%VX6[M('6^:79A=&5L^2!J92!Z86)L;VMO=N%N;RX`061R97-A`$%D<F5S
MX?@`5GEK;V[A=F%T(&%D;6EN:7-T<F%C:2`M(&YA<W1A=F5N[2!P^.US='5P
M;W;]8V@@<'+A=B!P<F\@;W-T871N[2!UOFEV871E;&4`061M:6YI<W1R86-E
M`$EN>F5RX71Y`$%F9VCA;FES=.%N`$%L8N%N:64`06R^[7)S:V\`4/AE>F3M
M=FMA+T%L:6%S`%IA<F]V;F%T`%IA<F]V;N%N[3H`5KEE`%:Y:6-H;FD@;W;L
M^&5N[2!UOFEV871E;.D`5KEE8VAN>2!S:W5P:6YY`%:Y96-H;F$@=;YI=F%T
M96QS:^$@<'+A=F$`5KEE8VAN>2#H='GX:2!S=')A;GD`4&]V;VQI="!V[6-E
M(&%D<F5S`%!O=F]L:70@;F%S=&%V96[M('1Y<'4@<V5T^.UD[&[]('-E>FYA
M;3\`2FF^(&5X:7-T=6IE`$%L=&5R;F%T:79N[2!)35-0('#X:6ALX;EE;NT@
M9&\@<WES=.EM=0!!;'1E<FYA=&EV;NT@24U34"!H97-L;P!!;'1E<FYA=&EV
M;NT@24U34"!UOFEV871E;'-KZ2!J;>EN;P!!;'1E<FYA=&EV;NT@92UM86EL
M;W;A(&%D<F5S80!!;'1E<FYA=&EV;NT@=GIO<GD`06QT97)N871I=F[M('1E
M>'0Z`$%M97)I8VOA(%-A;6]A`$)Y;&$@>F%DX6YA(&YE<&]V;VQE;N$@:&]D
M;F]T82X`06YD;W)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UN[2!P<F]X>0!/
M9'!O=NSO`$%N=&%R:W1I:V$`06YT:6=U82!A($)A<F)U9&$`07!L:6MA8V4`
M4V5Z;F%M(&%P;&EK86/M`$%P;&EK86-E(&IE('#X:7!R879E;F$`4&]UONUT
M('!R;R!D[&1IZ&[I('-D[6QE;NT`4V-H=N%L:70`4/AI8FQIOF[A('9E;&EK
M;W-T`$1U8F5N`$%R86)S:WD@*%=I;F1O=W,M,3(U-BD`5F5L:6MO<W0@87)C
M:&EV;W9A;NEH;R!S;W5B;W)U`$IMZ6YO(&%R8VAI=G4`57+H:73L(&-H8V5T
M92!V>6UA>F%T(+[A9&]S="!O('#X:6ALX;EE;NT@9&\@)7,_`$%R9V5N=&EN
M80!!<FWI;FEE`$%R;>EN<VO]("A!4DU30TE)+3@I`%5M[&[M`$%R=6)A`%9Z
M97-T=7!N[`!!<V-E;G-I;VX@27-L86YD`$%S8VEI('5M[&[M`$%S:64O<F5G
M:6]N(%1I8VCI:&\@;V-EX6YU`%!OON%D870@;R!P;W1V<GIE;NT@</AE9"!P
M<F]V961E;NUM(&]P97)A8^T@^F1ROF)Y/P!3;&]U<&-E(',@^FMO;'D`4&]K
M=7,@;R!V>6UA>N%N[2!N965X:7-T=6KM8^T@<VMU<&EN>2X`4&]K=7,@;R!V
M>6UA>N%N[2!N965X:7-T=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N`%!O
M:W5S(&\@^G!R879U(&YE97AI<W1U:NUC[6-H('6^:79A=&5L<VO]8V@@<'+A
M=BX`4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J[6/M:&\@<V3M;&5NZ6AO(&]B
M:F5K='4N`$%T<FEB=71Y`%-R<&5N`$%U<W1RX6QI90!286MO=7-K;P!!=71H
M7V-Y<G-Q;#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P
M<F\@:6UA<"X`075T:%]C>7)U<SH@6F1R;VH@;F5MX2!P;[YA9&]V86[I('-C
M:&]P;F]S=&DN`$%U=&A?8WER=7,Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V
M86[A('#X[7!O;F$@<')O(&EM87`N`$%U=&A?9G1P.B!.96)Y;&$@;F%L97IE
M;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!F='`N($MO;7!I;'5J=&4@4$A0
M(',@+2UE;F%B;&4M9G1P`$%U=&A?:6UA<#H@3F5B>6QA(&YA;&5Z96YA('!O
MOF%D;W9A;N$@</CM<&]N82!P<F\@24U!4"X`075T:%]K<F(U.B!.96)Y;&$@
M;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!K<F(U+@!!=71H7VQD
M87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O($Q$
M05``075T:%]L9&%P.B!.96QZ92!P^&ED870@=;YI=F%T96QE("5S+B!(;.&Y
M96[M('-E<G9E<G4Z(`!!=71H7VQD87`Z($YE;'IE('9Y;6%Z870@=;YI=F%T
M96QE("5S`$%U=&A?;&1A<#H@3F5L>F4@86MT=6%L:7IO=F%T('6^:79A=&5L
M92`E<P!!=71H7VUC86PZ($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X
M[7!O;F$@<')O($U#04PN`$%U=&A?<VUB875T:#H@3F5B>6QA(&YA;&5Z96YA
M('!OOF%D;W9A;N$@</CM<&]N82!P<F\@<VUB875T:"X`3W;L^&5N[2!S96QH
M86QO`$]V[/AE;NT@<V5L:&%L;RX@)7,`3W;L^&5N[2!B>6QO('IA;>UT;G5T
M;R!2041)55,@<V5R=F5R96TN`%-E;&AA;&\@;W;L^&5N[2!&5%`@<V5V97)E
M;2X`1&]S='5P;ND@2V%T96=O<FEE.@!$;W-T=7!NX2!P;VQE.@!!>F5R8F%J
M9+[A;@!"3T9((';];6QU=GD`6G#L="!D;R!:X7!I<V[M:W4`6G#L="!D;R!-
M;[YN;W-T[2!P<F\@6N%P:7-N[6L`4&]Z863M`$)A<G9A('!O>F%D[0"I<&%T
M;ND@:&5S;&\@<')O(&ME<F)E<F]S+@"I<&%T;ND@=;YI=F%T96QS:^D@:FWI
M;F\@<')O(&ME<F)E<F]S+@!"86AA;7D`0F%H<F%I;@!"86QT:6-KZ2`H25-/
M+3@X-3DM,3,I`$)A;F=L863IN0!"87)B861O<P!:X6ML860`0NQL;W)U<VMO
M`$)E;&=I90!"96QI>@!"96YI;@!"97)M=61Y`$)H^G3A;@!.87)O>F5N:6YY
M`$YE;'IE(&YA;.EZ="#HX7-T("(E<R(@87!L:6MA8V4@(B5S(BX`3F%S=&%V
M96[M(&)L;VMU`%1Y<"!B;&]K=0!4=>AN[`!";VSM=FEE`%KA;&^^:WD`3VMR
M86H`J>WX:V$@;VMR86IE.@!/:W)A:F4`0F]S;F$@82!(97)C96=O=FEN80!/
M8F$`0F]T<W=A;F$`1&]L;NT@Z.%S=`!";W5V970@27-L86YD`$)R87KM;&EE
M`$)R:71S:^$@=&5R:71O<FEA('8@26YD:6-KZ6T@;V-EX6[L`$)R=6YE:2!$
M87)U<W-A;&%M`$)U;&AA<G-K;P!397IN86T@<R!O9'+AOFMA;6D`0G5R:VEN
M82!&87-O`$)U<G5N9&$`0TU3`$-20P!#4DP@9&ES=')I8G7H;NT@8F]D>0!#
M4U8`5FQA<W1N;W-T:2!B7W7R:WDN+BX`2V%L96YDX?@`0F5Z=NQT^.T`2V%M
M8F]DOF$`2V%M97)U;@!(97-L;R!N96QZ92!N87-T879I="!A=71O;6%T:6-K
M>2P@<')O<^UM(&MO;G1A:W1U:G1E(%9AN65H;R!S>7-TZ6UO=NEH;R!A9&UI
M;FES='+A=&]R82X`3F5L>F4@<V4@</AI<&]J:70@:R!)34%0('-E<G9E<G4Z
M("5S`$MA;F%D80!3=&]R;F\`4W1O<FYO(&ALX;EE;NT@<')O8FSI;74`3F5L
M>F4@=GEM87IA="!S;W5B;W(@(B5S(BX`3F5L>F4@;F%J[70@9&_H87-N_2!A
M9')E<^'X+@!.96QZ92!P;VMR8>AO=F%T(&)E>B!P87)A;65T<G4@)W1A<F=E
M=$9I;&4G+@!.96QZ92!V>6UA>F%T(&%D<F5SX?@@(B5S(BX`3F5L>F4@=GEM
M87IA="P@<')O=&^^92!E>&ES='5J[2!P;V1S:W5P:6YY("5D+@!.96QZ92!P
M<F]VZ7-T('IM[&YU('5S<&_XX63A;NTL('!OZ&5T('!O<VMY=&YU=/UC:"!P
M;VQOOF5K('!R;R!N;W;I('5S<&_XX63A;NT@;F5O9'!O=NUDX2!P;^AT=2!U
M;&^^96[]8V@@<&]L;[YE:RX`3F5L>F4@>F%S;&%T('IP<N%V=2!N82!Z861A
M;ND@Z.US;&\N(`!#87!E(%9E<F1E`%1I='5L:WD`2V%T96=O<FEE(&$@>FYA
MZ&MY`$MA=&5G;W)I90!+86IM86YS:^D@;W-T<F]V>0!-;V)I;&[M('1E;&5F
M;VX`36^^;F]S=&D@8G7R:WD`3V1S='5P(&UE>FD@8G7R:V%M:3H`5FQA<W1N
M;W-T:2!B=?)K>0!-97IE<GD@;65Z:2!B=?)K86UI.@!-;V)I;&[M('1E;&5F
M;VX`2V5L='-K_2`H25-/+3@X-3DM,30I`%-T^&5D`%-T^&5D;V%F<FEC:^$@
M<F5P=6)L:6MA`%-T^&5D;V5V<F]P<VO]("A)4T\M.#@U.2TR*0!0;V1R;V)N
M;W-T:2!C97)T:69I:^%T=0!0;V1M[6YK>2!C97)T:69I:^%T=0#(860`6FWL
M;FET`$YA<W1A=F5N[2!J;>EN82!A(&5M86EL;W;I(&%D<F5S>2X@5'ET;R!P
M;VQOOFMY(&QI9.D@=79I9.TL(&MD>;X@<VD@Z'1O=2!N96)O(&]D<&]V[61A
M:NT@;F$@5F&Y92!Z<'+A=GDN`%IM[/(@;6^^;F]S=&D@=/CM9&5N[2!A('IO
M8G)A>F5N[2!P;WINX6UE:RX`6FYA:P!::V]N=%]R;VQO=F%T(&]D:V%Z+BXN
M`$-H:6QE`,CM;F$`R.UNN71I;F$@>FIE9&YO9'6Y96[A("A'0C(S,3(I`%1R
M861IZ&[M(.CM;KET:6YA("A":6<U*0!:=F]L=&4@:&5S;&\`6G9O;'1E('6^
M:79A=&5L<VOI(&IMZ6YO`%9Y8G)A="!Z;V)R87IE;NT@9&%T=6UU.@!6>6)R
M870@='EP('-T>6QU('-E>FYA;74@*'!R;R#X87IE;ND@<V5Z;F%M>2D`5GEB
M97)T92!K871E9V]R:64@<&]Z;N%M96L@<')O('-E>FYA;2!V('#X96AL961O
M=NEM('IO8G)A>F5N[2X`6G9O;&ET(&EM<&QI8VET;NT@>N%P:7-N[6LZ`%;A
M;F_H;NT@;W-T<F]V`$YE8GEL82!N86QE>F5N82!D969I;FEC92!T^.UD>2`E
M<RX`5GGH:7-T:70`5GGH:7-T:70@1F]R;75LX?@`5GGH:7-T:70@>FYAZ&MY
M('H@35-/9F9I8V4`3V1S=')A;NQN[2!UOFEV871E;&4Z("5S`$]D<W1R86YI
M="!UOFEV871E;&4`3V1S=')A;NQN[2#Z9&%J^2!O('6^:79A=&5L:0!+;&EK
M;NQT92!P<F\@<&]K<F'H;W;A;NT`0VQI8VMA=&5L;"!P^&5S($A45%``6F%V
M^.UT(&]K;F\`6F%T8;YE;F\`3V)L8>AN;P!+;VMO<V]VZ2!O<W1R;W9Y`%-K
M;&%P;F]U="!B;^AN[2!L:;ET=0!3:VQA<&YO=70@;VMR86IE`$MO;'5M8FEE
M`$)A<G9A`%;]8NQR(&)A<F5V`%!A;&5T82!B87)E=@!3;&]U<&-E.@!.X7IV
M>2!S;&]U<&-E`$MO;6EK<WD`4/CM:V%Z`%#X[6MA>F]VX2!K;VYZ;VQA`%!O
M>F[A;6MA`$]B96-NZ2!J;>EN;P!+;VUO<F]S`$9I<FUA`%!OZ.UT8>AE`%!O
M9&WM;FMY`%)O>F3M;'D@=B!N87-T879E;NT`3F%S=&%V:70@)7,`4&]T=G)D
M:70@:&5S;&\`2V]N9V\`2V]N9V\L($1E;6]K<F%T:6-KX2!R97!U8FQI:V$`
M4W!O:F5N[2!S96QH86QO+@!3<&]J96[M('-E;&AA;&\Z(`!">6QO('IA;>UT
M;G5T;R!S<&]J96[M(',@=F7X96IN_6T@:VSMZ&]V_6T@<V5R=F5R96TN`$)Y
M;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE:F[];2!K;.WH;W;];2!S97)V
M97)E;2X@1/EV;V0@.B`E<R`H)7,I`%-E;&AA;&\@<W!O:F5N[2!S($944"!S
M97)V97)E;2X`2V]N=&%K='D@8GEL>2#Z<W#LN6[L('#X:63A;GD@9&\@5F&Y
M96AO(&%D<F5SX?AE+@!0;VMR8>AO=F%T`$-O;VMO=GD@;W-T<F]V>0!+;VSA
MZ&5K`$MO<.UR;W9A=`!+;W#M<F]V870@=OUB['(`2V]S=&%R:6MA`%!O8OAE
MONT@<VQO;F]V:6YY`%IP<N%V=2!N96QZ92"Y:69R;W9A="!P;VUO8^T@4$=0
M+@!:<'+A=G4@;F5L>F4@<&]D97!S870@<&]M;V/M(%!'4"X`6G!RX79U(&YE
M;'IE(+EI9G)O=F%T('!O;6]C[2!3+TU)344N`%IP<N%V=2!N96QZ92!P;V1E
M<'-A="!P;VUO8^T@4R]-24U%+@!.96QZ92!P^&ED870@:V]N=&%K="X@)7,`
M3F5L>F4@<V4@</AI<&]J:70@:R!,1$%0('-E<G9E<G4N`$YE;'IE('IK;VYT
M<F]L;W9A="#ZZ&5T+B`E<P!.96QZ92!V>71V;_AI="!D:7-T<FEB=>AN[2!S
M97IN86TN("5S`$YE;'IE(&1EN6EF<F]V870@4$=0(&1A=&$N`$YE;'IE(&1E
MN6EF<F]V870@4R]-24U%(&1A=&$N`$YE;'IE('-M87IA="!K;VYT86MT+B`E
M<P!.96QZ92!S;6%Z870@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!Z
M:FES=&ET(&4M;6%I;&]V;W4@861R97-U('#X[6IE;6-E+@!.96QZ92!Z[7-K
M870@^G!L;OT@861R97/A^"X`3F5L>F4@>NUS:V%T(/IP;&[](&1I<W1R:6)U
MZ&[M('-E>FYA;2X`3F5L>F4@>NUS:V%T(/IP;&[]('-E>FYA;2!D:7-T<FEB
M=>AN[6-H('-E>FYA;?DN`$YE;'IE('KM<VMA="!V9?AE:F[](&ML[>@@>B!K
M;.WH;W;I:&\@<V5R=F5R=2X`3F5L>F4@;W1E=OCM="`E<RX`3F5L>F4@<')O
M=NES="!O<&5R86-E(/ID<KYB>2!P<F\@;6]D=6P@)7,`3F5L>F4@Z.US="`E
M<RX`3F5L>F4@<F5S971O=F%T(&AE<VQO('!R;R!D86[I:&\@=;YI=F%T96QE
M+B!6N65C:&YY(&YE8F\@;NQK=&5RZ2!Z('!O9')O8FYO<W3M(&YE8GEL>2!S
M<'+A=F[L('IA9.%N>2X@6FMU<W1E('1O('IN;W9U(&YE8F\@<&]K=60@<&]T
M^&5B=6IE=&4@<&]M;V,L(&MO;G1A:W1U:G1E('-P<N%V8V4@<WES=.EM=2X`
M3F5L>F4@>NUS:V%T($%#3`!.96QZ92!Z[7-K870@861R97/A^"X@)7,`3F5L
M>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,`3F5L>F4@>NUS:V%T
M(&1I<W1R:6)UZ&[M('-E>FYA;7DN("5S`$YE;'IE('KM<VMA="!S8VAO<&YO
M<W1I('-E<G9E<G4`3F5L>F4@</AE<&YO=70@:V]N9FEG=7)A8VDN`$YE;'IE
M('5L;[YI="!K;VYF:6=U<F%C:2!P<F\@)7,N`$YE;'IE('5L;[YI="!ZX6QO
MOF[M(&MO;F9I9W5R86-I+@!.96QZ92!U;&^^:70@>N%L;VAU(&MO;F9I9W5R
M8>AN[6AO('-O=6)O<G4@)7,N`$YE;'IE(&AL961A="!V($Q$05`@<V5R=F5R
M=2X`3F5L>F4@86MT=6%L:7IO=F%T(&MO;G1A:W0N("5S`$YE;'IE(&%K='5A
M;&EZ;W9A="!D:7-T<FEB=>AN[2!S97IN86TN("5S`$YE;'IE(&YA;.EZ="!B
M;^AN[2!L:;ET=2!P<F\@36]Z:6QL=2X@4')O<^UM('#X97-V[&3H=&4@<V4L
M(+YE(&IE(&]T97;X96[A+@!/9'!OZ.UT86[]('1E>'0`6F5M[`!6>77H;W9A
M8^T@</AE9&WL='D`5GET=F_X:70`5GET=F_X:70@;V1K87H`5GET=F_X:70@
M;F]V;W4`5GET=F_X:70@<&]D<VQOOFMY`%9Y='9O^&5N;P!4=OER8V4@<'+A
M=@#([7-L;R!K<F5D:71N[2!K87)T>0!#:&]R=F%T<VMO`$MU8F$`06MT=>%L
M;NT@Z&%S`$%K='7A;&[M(%523"!J90!!:W1UX6QN[2!P;^AA<^T`06MT=>%L
M;NT@<&]D;>UN:WDZ(`!.>6[L:KGM('-T>6P`3F%S=&%V96[M(/IK;VSY('!R
M;W;A9.QN_6-H('#X:2!P^&EH;.&Y96[M(&1O("5S+@!6>7-T^&EH;F]U=`!6
M>7-T^&EH;F]U="!V_6+L<@!+>7!R`$%Z8G5K82`H2T])."U2*0!!>F)U:V$@
M*%=I;F1O=W,M,3(U,2D`07IB=6MA+U5K<F%J:6YA("A+3TDX+54I`,AE<VOA
M(')E<'5B;&EK80!$1`!$96YN[`!$871A5')E92!P<F]H;.V^9>@`1&%T=6T`
M4/AI:F%T;R!D;F4`5OUB['(@9&%T=6UU`$1E;@!3;6%?>F%T('-L;W5P96,`
M4')O<VEN96,`R.US;&$@9&5S[71K;W;I('-O=7-T879Y`%IM96ZY:70@;V1S
M87IE;NT`26UP;&EC:71N[0!);7!L:6-I=&[M(&)A<G9A`$EM<&QI8VET;NT@
M:61E;G1I=&$`26UP;&EC:71N[2!:X7!I<V[M:SH`26UP;&EC:71N[2!T^.UD
M[6/M(&MR:73I<FEA.@!);7!L:6-I=&[M('-M['(@=/CM9.QN[3H`1&5F:6YI
M8V4`4VUA>F%T`%-M87IA="!S:W5P:6YU`%-M87IA="!P<N%V80!3;6%Z870@
M82!V>>AI<W1I="!Z<'+A=GD`4VUA>F%T(&)U\FMU`%-M87IA="!S;&]U<&5C
M`%-M87IA="!E>&ES='5J[6/M(&%L=&5R;F%T:79N[2!V>F]R`%-M87IA="#X
MX61E:P!3;6%Z870@=GEB<F%N;W4HZ2D@:61E;G1I='4H>2D`4VUA>F%T('-O
M=>AA<V[]('-L;W5P96,`4VUA>F%T('-O=>AA<V[](/CA9&5K`,AA<R!D;W)U
MZ&5N[0!$X6YS:V\`4V5S='5P;NP`4&]P<V%T('!R;V)LZ6T`4&]P:7,`4&]P
M:7,Z`%!O9')O8FYO<W1I("AT86OI('8@;&]G('-O=6)O<G4@2&]R9&4I.@!0
M;V1R;V)N;W-T:2!B>6QY('IA>FYA;65NX6YY(&1O(&QO9R!S;W5B;W)U('!R
M;R!A9&UI;FES='+A=&]R82X`5OUV;VH`4F]S;OT@8F]D`%)O<V[](&)O9"!Z
M82!P;W-L961N[2!H;V1I;G4Z(`!2;W-N_2!B;V0Z(`!3;>QR('H@;&5V82!D
M;W!R879A`%-M['(@>B!P<F%V82!D;VQE=F$`061R97/A^`!:;V)R87II="`R
M-"UH;V1I;F]V_2#H87,_`$UOOFYO<W1I(%IO8G)A>F5N[0!:;V)R87II="!P
M^&5D<&]V[.\@*%1!1BD`1F]R;>%T('IO8G)A>F5N[0!$:7-P;WIIZ&[M('5P
M;WIO<F[L;NT`1&II8F]U=&D`3F5S;6%Z870`3F5P^&ES='5P;W9A="!P^.UM
M;R!D;R!M86EN=&5N86YC92YP:'``3V)S86AU:F4@<')V;NT@^.%D96L@;N%Z
M978@<VQO=7!C^3\@4&]K=60@86YO+"!Z8;EK<G1N['1E('1E;G1O('+A;67H
M96LZ`$1O;6EN:6MA`$1O;6EN:6OA;G-KX2!R97!U8FQI:V$`4W1AOF5N[0!3
M=&&^96[M("5S`%-T86AN;W5T(&=E;F5R;W9A;F]U(&MO;F9I9W5R86-I(&IA
M:V\@4$A0('-K<FEP="X`4F]L971O=OT@<V5Z;F%M`$1R;V=Y`$4M;6%I;`!%
M4E(`16MVX61O<@!5<')A=FET`%5P<F%V:70@8FQO:P!5<')A=FET('-K=7!I
M;G4`57!R879I="!0;WINX6UK=0!5<')A=FET('!RX79A`%5P<F%V:70@<'+A
M=F$`57!R879I="!P<N%V82!P<F\@)7,`57!R879I="!M;[YN;W-T:2!P<F\Z
M`%5P<F%V:70@<'+A=F$@<')O("5S`%;]=6MA`$5G>7!T`$5L(%-A;'9A9&]R
M`%!R=F5K+BXN`$5M`$5M86EL`$5M86EL;W;A(&%D<F5S80!%;6%I;&]VZ2!A
M9')E<WD@<V4@;75S[2!S:&]D;W9A="X`16UA:6P@<R!P;W1V<GIE;NUM`$EK
M;VYK>2!S(&5M;V-E;6D`4'+A>F1NX2!0;WINX6UK80!0<N%Z9&[A('IP<N%V
M82X`4'+A>F1N_2!V_7-L961E:RX`4'+A>F1N_2!T97)M[6X@<')O('9Y:&QE
M9.%VX6[M`%!O=F]L:70@=FMLX63A;NT@;V)R87IK^2!Z(&9O=&\@9V%L97)I
M[2!D;R!T97AT=3\`06MT:79O=F%T('!R87;I(&ML:6MN=73M('!R;R!K;VYT
M97AT;W;I(&UE;G4_`$MO;F5C(')O:W4`6G;L=+EI="!E9&ET;W(`6F%D96IT
M92!B97IP9>AN;W-T;NT@;W3A>FMU+"!N82!K=&5R;W4@8G5D971E(&UU<V5T
M(&]D<&]V[&3L="!P;VMU9"!S:2!B=61E=&4@8VAT[70@<F5S971O=F%T('-V
MZ2!H97-L;RP@;F%P^"X@)TIA:^D@:F4@:FWI;F\@5F&Y96AO('!S83\G.@!:
M9&4@=FQOOFET(%523"!O8G+A>FMU`%)O=F[M:V]VX2!'=6EN96$`17)I=')E
M80!#:'EB80!.87-T86QA(&-H>6)A(',@<&^Y=&]V;NT@>G!RX79O=2X`17-T
M;VYS:V\`171I;W!I90!%=&YI8VOI`$5V<F]P80!+8;YD_6-H(#$U(&UI;G5T
M`$MAOF3I(#(@;6EN=71Y`$MAOF3]8V@@,S`@<V5K=6YD`$MAOF3]8V@@-2!M
M:6YU=`!+8;YDZ2!P^&EH;.&Y96[M(&1O('-Y<W3I;74`2V&^9&]U('#Y;"!H
M;V1I;G4`2V&^9&]U(&UI;G5T=0!6>F]R;W;]('#X[6ML860@:&]D;F]T.@!0
M<F]VZ7-T`%)O>G9I;F]U=`!2;WIB86QI="!B;^AN[2!L:;ET=0!/Z&5KX7;A
M;F$@)RDG`$_H96OA=N%N;R!S86UO<W1A=&[I('-L;W9O(&YE8F\@:&QE9&%N
M_2!T97)M[6X@=B!U=F]Z;W9KX6-H`$1A='5M('!R;R!K;VYE8R!P;&%T;F]S
M=&D`17AP;VYE;G0`17AP;W)T;W9A=`!%>'!O<G1O=F%T(%!O>F[A;6MY`$)A
M<G9A('!O</AE9.T`4/AE;F]S(&MO;F9I9W5R86-E('!O;6]C[2!&5%``VE]P
M;&[](%1E>'0`4V5L:&%L;R!Z[7-KX6[M(&UOOFYO<W3M+@!.96QZ92!S92!P
M^&EP;VII="!K($Q$05`@<V5R=F5R=2X`3F5L>F4@<V4@</AI<&]J:70@:R!3
M34(@<V5R=F5R=2X`4V5L:&%L;R!K;W#M<F]VX6[M('H@(B5S(BX`4V5L:&%L
M;R!K;W#M<F]VX6[M(&1O("(E<R(N`%-E;&AA;&\@>F%L;[YE;NT@;F]VZ6AO
M(%-!4TP@<W!O:F5N[2X`4V5L:&%L;R!P^&5S=6YU=.T@9&\@(B5S(BX`1&]B
M<ND`1F%L:VQA;F1S:^D@;W-T<F]V>2`H36%L=FEN>2D`1F%R:6IS:^D@;W-T
M<F]V>0!:X79AOF[A(&-H>6)A.@!&87@`VFYO<@!#[71I="!S92!J86MO`$/M
M=&ET('-E(&IA:V\Z`$1R;V)NZ2!P^&5HX?)K>0!$<F]B;ND@<V[L:&]VZ2!P
M^&5HX?)K>0!-871I8V4@<&]L90!&:6II`%!OZ&5T('-O=6)O<ODZ("5S('-O
M=6)O<@!0;^AE="!S;W5B;W+Y.B`E<R!S;W5B;W+Y`%-P<N%V8V4@<V]U8F]R
M^0!.X7IE=B!S;W5B;W)U`%;]8NQR('-O=6)O<G4`4/AE;NES="!S;W5B;W(`
M4/AE;F]S('-O=6)O<OD@;F5N[2!P;V1P;W)O=N%N+@!&:6QT<GD`1FEN<VMO
M`%!R=F[M('!O;&]V:6YA`%!R=F[M(.AT=G)T:6YA`%!E=F[I(&WL^.UT:V\`
M4/AE:&]D:70`4&QO=F]U8^T`36QH80!3;&^^:V$@)7,@;F5E>&ES='5J90!"
M87)V82!P[7-M80!*[61L;P!0<F\@<')O:&SMOF7H92!N97!O9'!O<G5J[6/M
M(&]B<N%Z:WD`4/AE9'!O=NSO("A4048I`%#X961P;W;L[R!P;^AA<^T@<')O
M(&1N>2`H<&]Z;N%M:V$Z('#X961P;W;L[R!J92!P<F\@9&YY(&D@;F]C:3L@
M=&]T;R!M^;YE('9Y='9O^&ET('!O;>QR;NP@;V)SX6AL_2!S97IN86TN`%IA
M<&]M;NQL:2!J<W1E(%9AN64@:&5S;&\_`$9O<FUU;.'X90"I=.QS=.T`5'EP
M(+ET['-T[0"I=.QS=.T`J73L<W3M(#(`1O-R80!0^&5P;W-LX6[M`%#A`%+A
M;7D`1G)A;F-I90!&<F%N8VEE+"!M971R;W!O;&ET;NT`1G)A;F-O=7-KX2!'
M=6%IX6YA`$9R86YC;W5S:^$@4&]L>6[I<VEE`$9R86YC;W5S:^$@:FF^;NT@
M=&5R:71O<FEA`$]D`$]D`%!O9')O8F[]('!O<&ES`-IP;&[L:P!#96SI(&IM
MZ6YO`$=A8F]N`$=A;&5R:64@<')O(';]8NQR(&]B<N%Z:_D`1V%L97)I93H`
M1V%M8FEE`%9Y='9O^&ET("5S(&MO;F9I9W5R86-I`%9Y9V5N97)O=F%N_2!K
M\V0`1W)U>NUN<VMO`$[L;65C:V\`1VAA;F$`1VEB<F%L=&%R`$OX97-T;NT@
M:FWI;F\`2F1I(&YA`$=O961E;`!6>6AL963A=N%N[2!P;VUO8^T@1V]O9VQU
M`%-T=7!N[""Y961I`-AE8VMO`-AE8VOI("A)4T\M.#@U.2TW*0!'<O-N<VMO
M`$=R96YA9&$`061M:6YI<W1R86-E('!R;R!S:W5P:6YY`$UU<^T@8OUT('IA
M9.%N;R!J;>EN;R!S:W5P:6YY`%-K=7!I;GD`1W5A9&5L;W5P90!'=6%M`$=U
M871E;6%L80!'=65R;G-E>0!0<N%V82!H;W-T^0!+;FEH82!H;W-T^0!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!Z8F%B[&QE
M(&]D;>UTX2!S;6%Z870@<&]S;&5D;NT@8G7R:W4@;F$@^.%D:W4N`$A434Q!
M<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P;W-L961N[2!B=?)K=2!V92!S
M;&]U<&-I('1A8G5L:WDN`$A434Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA
M="!P;W-L961N[2#XX61E:R!V('1A8G5L8V4N`$]V[/AO=N%N[2!P;VUO8^T@
M2%144"!N96)Y;&\@;F%L97IE;F\N`$AA:71I`$AA<V@M86QG;W)I=&UU<P!-
M;&AA=F\`2&QA=FGH:V$`2&5A<F0@27-L86YD(&$@36-$;VYA;&0@27-L86YD
M<P!(96)R96JY=&EN82`H25-/+3@X-3DM."U)*0!6_;EK80!.X7!O=NQD80!.
MX7!O=NQD82!P<F\@961I=&]R`%!O;6]C;NUK`$AE;6ES9NER80!:9&4@:F4@
M>F'HX71E:R!S;W5B;W)U.@!6>7-O:^$`7TAO<F1E`%-V873I($WL<W1O("A6
M871I:^%N*0!(;W)D90!!9')E<V$@9&]M^0!496QE9F]N(&1O;?D`2&]N9'5R
M87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!.97!L871NZ2`E<R!8
M34P@9&%T82!V92!Z<'+A=NP@)7,`2&]R9&4O2V]L86(Z(*[A9&[A('IP<N%V
M82!S92!N97-H;V1U:F4@<R!O8FIE:W1E;2`E<P!(;W)D92]+;VQA8CH@3F5B
M>6P@;F%L97IE;B"^X61N_2!O8FIE:W0@='EP=2`E<R!V92!Z<'+A=NP@)7,`
M2&]R9&4O2V]L86(Z(-IS<.RY;ND@;V1S=')A;NQN[2`E<R`B)7,B`$AO<F1E
M+TMO;&%B.B!);G1E9W)AZ&[M(&[A<W1R;VH@<&]T^&5B=6IE(%!(4"!P^.UP
M;VYU("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!.96QZ92!V>71V;_AI="!N;W;]
M('-T<F]M(%A-3"!P<F\@;V)J96MT("5S`$AO<F1E+TMO;&%B.B!.96QZ92!O
M9'-T<F%N:70@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YE;'IE('KM<VMA
M="!-24U%($E$('!R;R#HX7-T('1Y<'4@)7,`2&]R9&4O2V]L86(Z($YE;'IE
M('-Y;F-H<F]N:7IO=F%T("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.96QZ
M92!S>6YC:')O;FEZ;W9A="!S9.UL96[I(&]B:F5K='DZ("5S`$AO<F1E+TMO
M;&%B.B!.97INX6W]('-D[6QE;OT@;V)J96MT("(E<R(`5F]D;W)O=F[I('!R
M87;M=&MO`$AO<FEZ;VYTX6QN[2!O9'-T=7``2&]R:7IO;G3A;&[M.@!*86L@
M:G-T92!S92!S96T@9&]S=&%L:3\@*%IAN6QE=&4@<')O<^UM('IP<N%V=2$I
M`$MO;&EK('-L;W5P8_D@8VAC971E('-P;VII=#\`2V]L:6L@:F4@=&%M('!O
M;.T@*'-L;W5P8_DI/P!+;VQI:R#XX61K^2!C:&-E=&4@<W!O:FET/P!6;&AK
M;W-T`%9L:&MO<W0Z`$AU;6]R;ND`36'O87)S:V\`4V5L:&%L;R!V>71V;_AE
M;NT@24U!4&]VZ2!S8VARX6YK>3H@)7,`4V5L:&%L;R!S;6%ZX6[M($E-05!O
M=ND@<V-H<N%N:WDZ("5S`%-E;&AA;&\@;F%S=&%V96[M(&MV\W1Y('!R;R!)
M34%0;W9O=2!S8VARX6YK=3H@)7,`25`@861R97-A`$E0(&%D<F5S82!N96[M
M(&1O<W1U<&[A+@!)4"!A9')E<V$@;F5N[2!V('!O=F]L96[I;2!#2412(')O
M>G-A:'4N`%!O<G6Y96[M(&EN=&5G<FET>2!)4"X`5E]L;[YT92#XX61E:R!P
M^&5D`$ES;&%N9`!0;W5Z92!I:V]N>0!):V]N>2!P<F\@)7,`26MO;GD@<R!T
M97AT96T`3N%Z978@:61E;G1I='DZ`%!O:W5D('IO8G)A>F5N[2!N96[M('8@
M<&_XX61K=2P@)7,@;W1E=OCM="!V(&YO=NEM(&]K;NPN`%!O:W5D('!O=;[M
M=N%T92!);G1E<FYE="!%>'!L;W)E<B!A(&YE=FED[71E(+[A9&[I(&EK;VYY
M+"!Z^&5J;>P@<&]T^&5B=6IE=&4@;WIN8>AI="!T96YT;R!RX6UEZ&5K('!R
M;R!V>7!N=73M(%!.1R!T<F%N<W!A<F5N8V4N`%!O:W5D('9I9.UT92!T=71O
M('IP<N%V=2!M[7-T;R!O8G+A>FMU+"!O8G+A>F5K(&MT97+](&-H8V5T92!P
M^&5NZ7-T(&YE;'IE(%9AN>UM('!R;VAL[;YEZ&5M('IO8G)A>FET+@!.X6AL
M960@;V)RX7IK=3H`55),(&]B<N%Z:W4`55),(&]B<N%Z:W4Z`$]B<N%Z96L@
M>B!G86QE<FEE`$]B<N%Z96L@>B!G86QE<FEE.@!0^&5N;W,@;V)RX7IK=0!/
M8G+A>FMY`$EM<&]R=&]V870@4&]Z;N%M:W4L($MR;VL@)60`26UP;W)T+"!K
M<F]K("5D`$EM<&]R=&]V870O17AP;W)T;W9A="!0;WINX6UK>0!);7!O<G1O
M=F%NZ2!P;VQE.B`E<P!);7!O<G1O=F%NX2!P;VQE.@!6;&^^:70@^.%D:W4@
M>F$`0GEL('IA9.%N(&YE<W!RX79N_2!A:^AN[2!K\V0N`$YE<W!RX79N["!Z
M861A;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+@!.97-P<N%V
M;ND@=;YI=F%T96QS:^D@:FWI;F\@;F5B;R!A;'1E<FYA=&EV;NT@861R97-A
M+B!::W5S=&4@:F6Y=.P@:F5D;F]U(&YE8F\@:V]N=&%K='5J=&4@5F&Y96AO
M('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T;W)A+@!:=NQTN6ET(&]D<V%Z96[M
M`$EN9&EE`$IE9&YO=&QI=NT@=;YI=F%T96SI`$EN9&]NZ7-I90!);F9O<FUA
M8V4`26YF;W)M86-E`%9L;[YI="!S7VQO=7!E8R!Z80!6;&^^:70@;V)RX7IE
M:P!6;&^^:70@=&%B=6QK=0!6;&^^:70@=V5B;W;](&]D:V%Z`%9L;[YI="!?
M<VQO=7!E8R!P^&5D(`!6;&^^:70@;F]V_2!S;&]U<&5C('IA('-O=>AA<V[]
M`%9L;[YI="!N;W;]('-L;W5P96,@</AE9"!S;W7H87-N_0!6;&^^:70@;F]V
M_2#XX61E:R!Z82!S;W7H87-N_0!6;&^^:70@;F]V_2#XX61E:R!P^&5D('-O
M=>AA<V[]`%9L;[YI="!O9'-T879E8R!Z82!S;W7H87-N_2!U>F5L`%9L;[YI
M="!O9'-T879E8R!P^&5D('-O=>AA<V[]('5Z96P`5FQOOFET(&%L=&5R;F%T
M:79N[2!V>F]R`%9L;[YT92!E;6%I;&]V;W4@861R97-U+"!N82!K=&5R;W4@
M;V)D<K[M=&4@;F]VZ2!H97-L;SH`5FQOOFET(&)U\FMU('IA`%9L;[YI="!B
M=?)K=2!P^&5D`%9L;[YI="!S;&]U<&5C('IA`%9L;[YI="!S;&]U<&5C('#X
M960`5FQOOFET('IP<N%V>0!6;&^^:70@;V1S=&%V96,@>F$`5FQOOFET(&]D
M<W1A=F5C('#X960`5FQOOFET(/CA9&5K('IA`%9L;[YI="#XX61E:R!P^&5D
M`%9L;[YT92!P;[YA9&]V86YO=2!O9'!O=NSO(&YA(&)E>G!EZ&YO<W1N[2!O
M=.%Z:W4Z`%9L;[YI="]U<')A=FET(&]B<N%Z96L`5FQOOFET+W5P<F%V:70@
M;V1K87H`3F5D;W-T871EZ&[](&MR961I="!K(&]D97-LX6[M('IP<N%V>2!N
M82!D:7-T<FEB=>AN[2!S97IN86TN`$YE9&]S=&%T9>AN_2!K<F5D:70N`$-E
M;.D@Z.US;&\`4V5Z;F%M(&-E;/UC:"#H[7-E;`!.97-P<N%V;ND@541(+B`H
M57-E<B!$871A($AE861E<BDN`$YE<&QA=&[A(&%P;&EK86-E+@!.97!L871N
MZ2!I9&5N=&EF:6MAZ&[M(.CM<VQO("A)1"D@9.%V:WDN`$)Y;&$@>F%DX6YA
M(&YE<&QA=&[A(&1A=&$`3F5P;&%T;N$@861R97-A('#X[6IE;6-E+@!.97!L
M871N_2!F;W)MX70@<V]U8F]R=0!.97!L871N_2!M<V=?='EP92X`3F5P;&%T
M;ND@;F5B;R!C:'EB[&KM8^T@87!I7VED+@!.97!L871NZ2!N96)O(&-H>6+L
M:NUC[2!P87)A;65T<GDN`$YE<&QA=&[A('9L87-T;FEC:^$@<'+A=F$N`$YE
M<&QA=&[]('!R;W1O:V]L+@!.97!L871N_2!S9.UL96[](&]B:F5K=`!.97!L
M871NX2!A9')E<V$@;V1E<^UL871E;&4N`$YE<&QA=&[A(&1A=&$@=6YI8V]D
M92X`26YV96YTX?@`S7+A;BP@27-LX6US:^$@<F5P=6)L:6MA`$ERX6L`27)S
M:V\`3W-T<F]V(&UUOF4`3VIE9&EN[&SI(&)O=?AK>0!)<W)A96P`4&]S:WET
M;W9A=&5L`$MU<GKM=F$`273A;&EE`$IA;6%J:V$`3&5D96X`2F%P;VYS:V\`
M2F%P;VZY=&EN82`H25-/+3(P,C(M2E`I`%1R:6MO=`!*;W)DX6YS:V\`R&5R
M=F5N96,`R&5R=F5N`%IA<F]V;F%T`%IA<F]V;F%T(&YA('-T^&5D`%IA<F]V
M;F%T('9Y<&QN[&[M;0!:87)O=FYA="!D;VQE=F$`6F%R;W9N870@9&]P<F%V
M80!+87IA8VAS=.%N`%5C:&]V870@;W)I9VENX6P_`$ME\F$`2V5R8F5R;W,@
M<V5R=F5R('IA;>UT;G5L(&]V[/AE;NTN`$YO=N'H8VD@:V5R;F5L=0!6>71V
M;_AE;NT@:VSMZ&4`5GET=F_X96[M(&]T:7-K=2!K;.WH90!$Z6QK82!K;.WH
M90!4>7`@:VSMZ&4`5;YI=.T@:VSMZ&4`2VSMZ"!J:;X@97AI<W1U:F4@;F$@
M=F7X96INZ6T@:VSMZ&]VZ6T@<V5R=F5R=2X`1.QT:0!+:7)I8F%T:0!+3$12
M`$MO<F5A`$MO<F5J<VMY("A%54,M2U(I`$MU=F%J=`!+>7)G:7IS=.%N`%]2
M;WIL;[YE;NT`2F%Z>6L`3&%O<RP@3&ED;W;L($1E;6]K<F%T:6-K82!297!U
M8FQI:V$`1')U:.$@<&]L;W9I;F$`3F%P;W-L961Y(%IM[&[L;F\`4&]S;&5D
M;NT@Z'1V<G1I;F$`4&]S;&5D;NT@86MT=6%L:7IA8V4Z`%!O<VQE9&[M('#X
M:6ALX;EE;NTZ("5S`%!O<VQE9&[M('#X:6ALX;EE;NTZ("5S('H@)7,`4&]S
M;&5D;NT@</AI:&SAN65N[3H@3FEK9'D`3&ET=F$`4'+A=F\`4F]Z;&^^96[M
M`$YE8VAA="!P<N%Z9&[I(&)E>B!O:W)A:F4`3&EB86YO;@!$;VQE=F$`3&5V
MX2!H;&%V:>AK80!(;V1N;W1Y(&YA;&5V;P!,97-O=&AO`$QI8NER:64`3&EB
M:64`3&EC:'1E;KET96IN<VMO`$QE:&OI(&UR:&]L96[M`$QE:&O](&3IN;L`
M0G)Z:_T@;&5H:_T@9.FYNP!0;WID[&II(&QE:&O](&3IN;L`3&5H:^D@9&6Y
MNV]VZ2!S<N&^:WD`3&5H:_T@9.FYNR!S(&CX;>QN[6T`3&5H:^D@<V[LOF5N
M[0!,96AKZ2!S;NQH;W;I('#X96CA\FMY`$QI;65R:6-K`$]D:V%Z`$]D:V%Z
M>2!U:V%Z=6KM(&YA.@!0;W6^[70@;V1K87IY(&YA(&5M86EL;W;I(&%D<F5S
M>2!P^&D@>F]B<F%Z;W;A;NT@<W1RX6YK>2!P<F\@<'-A;NT@>G!RX78`3V1K
M87IY`$QI;G5X;W;I(&-O;VMI90!397IN86T@+2!UOFEV871E;"!M^;YE('9I
M9.QT('-L;[YK=0!397IN86T@9&%T86+A>NT`4V5Z;F%M('3I;6%T(&[A<&]V
M[&1Y`%-E>FYA;2!T86)U;&5K`%-E>FYA;2U!<F-H:78`4V5Z;F%M+4[A<&]V
M[&1A`%-E>FYA;2U)9`!397IN86TM5FQA<W1N[6L`4V5Z;F%M+4]D97-LX6[M
M`%-E>FYA;2U0^&EH;.&Y96[M`%-E>FYA;2U/9&ALX;EE;NT`5OUP:7,@=;YI
M=F%T96SY(&YE;NT@9&]S='5P;OTN`$QI=&5R871U<F$`3&]T>;ES:V\`3F%H
M<N%VX6[M+BXN`$WM<W1N[2#H87,Z(`!,;V-A;&4@82#H87,`3>US=&\`4/AI
M:&SA<VET('-E`$]D:&SAN65N[0#::V]L>2!P<F]VX63L;ND@</AI('#X:6AL
MX;EE;NT`4V5L:&%L;R!P^&EH;.&Y96[M(&1O('-Y<W3I;74N(%!R879D['!O
M9&]B;NP@5F&Y92!UOFEV871E;'-KZ2!J;>EN;R!A+VYE8F\@:&5S;&\@;F5B
M>6QO('-P<N%V;NP@>F%DX6YO+@!0^&EH;.&Y96[M('-E;&AA;&\N`$1L;W5H
M_2!T97AT`$SA<VMA`$[M>FOA`$UA;.$@^&5C:^$@<.US;65N80!-86SA('1I
M<VMA8^T@<.US;65N80!-86SI(/CM;7-KZ2#H[7-L:6-E`$QU8V5M8G5R<VMO
M`$U-`%IP<N%V82!D;F4`4/AI<&]J96[]('-O=6)O<B!-4RU.5$5&(&YE;V)S
M86AU:F4@ON%D;N$@9&%T82X`35-'`$UA:V%O`$UA:V5D;VYI92P@8OUV86SA
M(%)E<'5B;&EK82!*=6=O<VSA=FEE`$UA9&%G87-K87(`36%G:64`4&^Y=&$`
M061M:6YI<W1RX71O<B!P;[ET>0!6>71V;_AI="!O9%]K87HN+BX`36%L87=I
M`$UA;&%J<VEE`$UA;&1I=GD`36%L:0!-86QT80!0<F\@=6UOOF[L;NT@;W9L
MX63A;NT@:V%T96=O<FGM(&IE('IA<&]T^&5B[2!O>FYAZ&ET('!O;&^^:WD@
M8F%R=F%M:2P@:W1E<ND@:G-O=2!P^&GX87IE;GD@:R!T[&UT;R!K871E9V]R
M:>UM+@!-87!A($UA<#(T`$UA<&$@36%P475E<W0`0OAE>F5N`$]K<F%J`$]Z
M;F'H:70@>FYAZ&MO=2!0<F]H;.ED;G5T;R].97!R;VALZ61N=71O`$]Z;F'H
M:70@:FEN_6UI('IN8>AK86UI("AJ86MO($3Y;&6^:73I+T]D<&]V['IE;NDI
M`$UA<KEA;'-KZ2!/<W1R;W9Y`$UA<G1I;FEQ=64`4VAO9'5J[6/M('-E('!O
M;&4`36%U<F5TX6YI90!-875R:6-I=7,`36%X:6UA;&[M('!O=F]L96[](&MR
M961I=`!">6QA('#X96MR;^AE;F$@;6%X:6UA;&[M(&3I;&MA('IP<N%V>2X`
M3F5J=GFYN>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``3F5J
M=GFYN>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!-87AI;>%L
M;NT@9.EL:V$`2W;L=&5N`$UA>6]T=&4`365D:6/M;F$`R&QE;F]VZ0!497AT
M(%!O>F[A;6MY`$WS9'D@<')O(&UE;G4Z`%-P;VII="!B=?)K>0!:<'+A=F$`
M6G!RX79A(&)Y;&$@;W;L^&5N82!V('!O^.%D:W4L(&%L92!N96QZ92!O=NSX
M:70@<&]D<&ES;W;](&-E<G1I9FEKX70N`%IP<N%V82!P<F]P861L82X`5'EP
M('IP<N%V>0!0;^AA<^T`0FQO:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]+@!"
M;&]K(&\@<&_H87/M(&YE;NT@9&]S='5P;OTN(%!O9')O8FYO<W1I(&)Y;'D@
M>F%Z;F%M96[A;GD@<')O('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T;W)A(&1O
M(&QO9W4N`$UE=&]D80!-971R:6-K_0!-97AI:V\`36EK<F]NZ7-I92P@1F5D
M97)A8V4`57!R;W-T^&5D`%1Y<"!-:6UE`$YE:FYIOKGM('1E<&QO=&$@>F$@
M<&]S;&5D;NUC:"`R-"!H;V1I;CH@`$YE:FYIOKGM('1E<&QO=&$@>F$@<&]S
M;&5D;NUC:"`V(&AO9&EN.B``6G)C861L;W;L`%+Y>F[I`%!R;V=R86UO=OT@
M8F%L[6L@2%144%]297%U97-T(&-H>6+M('8@4$5!4BX`0VAY8NQJ[6/M(&MO
M;F9I9W5R86-E+B!0;VMU9"!S:2!P^&5J971E('!O=;[M=F%T('1U=&\@87!L
M:6MA8VDL(&UU<^UT92!V>6=E;F5R;W9A="!K;VYF:6=U<F'H;NT@<V]U8F]R
M+@!#:'EB[&KM8^T@240@>G!RX79Y("AI9&5N=&EF:6MAZ&[M(.CM<VQO*0!0
M;[YA9&]V86[]('!R;V=R86UO=OT@8F%L[6L@36%I;"!C:'EB[2!V(%!%05(N
M`$-H>6+L:NUC[2!)1"!P<F\@<F5L86-I+@!0;P!-;V)I;&[M('!ON71A`$WM
M<F[]`$1A='5M('!O<VQE9&[M('IM[&YY`%IM[/)I="!54DP`57!R879O=N%N
M[2`E<P!-;V1U;`!-;VQDX79I90!-;VYA:V\`36]N9V]L<VMO`$WL<^UC(&$@
M<F]K`$WL<^WH;NP`36]N<V5R870`1N%Z92!-['/M8V4`36%R;VMO`%#X97;A
MOF[L(&IA<VYO`%#X97;AOF[L(&]B;&'H;F\`4/AE=N&^;NP@<VQU;F7H;F\`
M4&]S=6YO=70@9&]L^0!0;W-U;F]U="!D;VQE=F$`4&]S=6YO=70@9&]P<F%V
M80!0;W-U;F]U="!N86AO<G4`4&]S=6YO=70@9&]L^0!0;W-U;F]U="!N86AO
M<G4`36]S86UB:6L`5NUC92WZ<F]V\F]VZ2!R;VQE=&]VZ2!S97IN86UY`%;M
M8V5NX7-O8F[A('-E;&5K8V4`3?EJ(/KH970`36]J92!0;WINX6UK>0!-^6H@
M<&]R=.%L`$UO:F4@<F]Z;&^^96[M('!O<G3A;'4`37EA;FUA<@!.12P@3D53
M3U5(3$%3S4T`2FWI;F\`3F%M:6)I90!.875R=0!.97#A;`!.:7IO>F5M[0!.
M:7IO>F5M<VOI($%N=&EL>0!.971S8V%P92!"87-E(%523`!.971S8V%P92!#
M02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C
M87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$IMZ6YO
M($YE='-C87!E(%-33"!S97)V97)U`%!O>F[A;6MA(&L@8V5R=&EF:6OA='4@
M3F5T<V-A<'4`5'EP(&-E<G1I9FEKX71U($YE='-C87!U`%/MNP!.:6MD>0!.
M;W;A($MA;&5D;VYI90!.;W;A(&MA=&5G;W)I90!-['/M8R!V('!R=F[M(.AT
M=G)T:6[L`$YO=N$@4&]Z;N%M:V$`3F]VZ2!UOFEV871E;'-KZ2!J;>EN;R`H
M;F5P;W9I;F[I*0!.;W;](%KI;&%N9`!.;W;I(&]K;F\@*%]P<N%Z9&[I*0!.
M;W9I;FMY`$YE=W-G<F]U<',`1&%LN>T`1&%LN>T@;6^^;F]S=&D`3FEK87)A
M9W5A`$YI9V5R`$YI9^ER:64`3F]C`$YI=64`3F4`KF%D;N$@:V]N9FEG=7)A
MZ&[M(&1A=&$@;F5J<V]U(&1O<W1U<&[A('!R;R!Z;V)R87IE;NT@<F]Z9.UL
M^2X`3F5N[2!D;W-T=7!NX2"^X61NX2!S=')A=&5G:64@<')O('1V;W)B=2!)
M4T\@;V)R87KY+@!"97H@9.%V:V]VZ6AO('9Z;W)U+@!.82!P;[YA9&]V86[I
M('!O>FEC:2!N965X:7-T=6IE(+[A9&[](&)L;VL`3F5B>6QO('!O<VMY=&YU
M=&\@ON%D;ND@:FWI;F\@<')O(&MA;&5N9.'X('#X:2!O=NSX;W;A;NT@<&]M
M;V/M($U#04PN`$)E>B!Z;>QN>2X`3F5L>F4@</AI9&%T(+[A9&[A('!O9"UP
M<N%V82!K('3L;71O('!RX7;Y;2X`3F5B>6QY('5V961E;GD@ON%D;ND@:V]N
M9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@)7,N`$YE8GEL>2!U=F5D96YY(+[A
M9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O($944"!61E,N`$YE8GEL
M>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O(%-1
M3"!61E,N`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O
M<FUA8V4@<')O(%-13"U&:6QE(%9&4RX`3F5MX71E(+[A9&[](&MR961I="X`
M3F5B>6P@<&]S:WET;G5T(+[A9&[](&/M;"X`KN%D;OT@<V]U8F]R(&YE8GEL
M('#X96YE<V5N`$YE8GEL>2!N86QE>F5N>2"^X61NZ2!I:V]N>2X`3F5B>6QO
M('9Y8G+A;F\@ON%D;ND@;>US=&\N`$YE8GEL>2!P;W-K>71N=71Y(+[A9&[I
M('IP<N%V>2X`3F5B>6QO('5V961E;F\@ON%D;ND@:FWI;F\N`*[A9&[]('IE
M('KA<&ES;NUK^2!N96[M(&1O<W1U<&[]('!R;R!H;W-T>2X`KN%D;ND@4&]Z
M;N%M:WD`KN%D;ND@<&]Z;N%M:WD@<V4@;F5S:&]D=6KM('-E('-O=>AA<V[]
M;2!K<FETZ7)I96TN`*[A9&[I('!O>F[A;6MY('!R;R!Z;V)R87IE;NT`3F5B
M>6QO('5V961E;F\@ON%D;ND@Z.US;&\N`$)E>B!N97-L=;EN_6-H`$YE8GEL
M;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!(5%10+@!.
M96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@24U!
M4"X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M
M($ME<F)E<F]S+@!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N
M[2!P^&EH;.&Y96[M('-E(&1O('-Y<W3I;74N`$YE8GEL;R!P;W-K>71N=71O
M(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!005-35T0N`$YE8GEL;R!P;W-K
M>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!334(N`$YE8GEL82!P
M;W-K>71N=71A(&-E<W1A(&L@8FENX7)N[6UU('-O=6)O<G4@3W!E;E-33"X@
M0FENX7)N[2!S;W5B;W(@3W!E;E-33"!J92!Z87!O=/AE8NT@<')O('!RX6-I
M(',@4$M#4R`Q,B!D871Y+@"NX61NZ2!N979Y^.UZ96[I(+[A9&]S=&D@;R!P
M^&EH;.&Y96[M+@!"97H@<')A=FED96P`0F5Z(&]K<F%J^0"NX61N_2!Z(&1O
MZ&%S;OUC:"!A9')E<^'X^2!N96[M(&1O<W1U<&[]('!R;R!C86-H92X`3F5B
M>6QO(&]D97-LX6YO(+[A9&[I('6^:79A=&5L<VOI(&IMZ6YO(&$O;F5B;R!H
M97-L;RX`3F5B>6QA(&YA=G+A8V5N82"^X61NX2!P;&%T;N$@6$U,(&1A=&$N
M`*[A9&[I(&AO9&YO='D`5B!O<FEG:6[A;&[M(&MO;F9I9W5R86-I(&YE8GEL
M82!N86QE>F5N82!V97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C:2X`5F4@5F&Y
M[2!K;VYF:6=U<F%C:2!N96)Y;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V=&4@
M:V]N9FEG=7)A8VDN`%!O7WINX6UK80"NX61N_0"NX61N_2`H<&]UOFEJ=&4@
M:6UP;&EC:71N[2D`4V5V97)S:_T@*$E33RTX.#4Y+3$P*0!.;W)F;VQK<VOI
M(&]S=')O=GD`4V5V97)N[2!P;VQO:V]U;&4`4V5V97)N[2!-87)IX6YS:^D@
M;W-T<F]V>0!.;W)S:V\`3F5N[2!P;P!.96[M('#X960`3F5N[2!A9')E<^'X
M96T`3F5N[2!I;7!L96UE;G1O=N%N;RX`3F5N[2!N87-T879E;F\`3F5N[2!P
M;V1P;W)O=N%N;RX`3F]VX2!+871E9V]R:64`1&5T86EL>2!P<F\@4&]Z;N%M
M:W4`4V5Z;F%M(%!O>F[A;65K`%1E>'0@4&]Z;N%M:WD`7U1E>'0@4&]Z;N%M
M:WD`4&]Z;N%M:V$@;F5B>6QA(&YA;&5Z96YA+@!:X7!I<U]N[6L`3N%Z978@
M6N%P:7-N[6MU.@!:X7!I<V[M:WD`6N%P:7-N[6L@;75S[2!M[70@;N%Z978N
M`%!O>F[A;6MA`%-H<FYU=.T@4&]Z;N%M96L`3FEC(&L@<')O:&SI9&YU=.TL
M(&+LOG1E('IP['0N`$QI<W1O<&%D`,CM<VQO`%!OZ&5T('IN86OY`%!OZ&5T
M('-L;W5P8_D`4&_H970@^.%D:_D`3F5B>6QA('IA9.%N82#H[7-L82!P<F\@
M86MT=6%L:7IA8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+@!/2P!/8FIE:W0`
M5';Y<F-E(&]B:F5K=/D`3W-M:>AK;W;]`-CM:F5N`$9I;'1R;W9A="!N97-L
M=;ENZ0!+86YC96SA^`!/;>%N`%-D[6QE;ND@<VQOOFMY(&IS;W4@<&]S:WET
M;W;A;GD@<&]U>F4@24U!4"!S97)V97)Y+@!0;W5Z92!N97-L=;ENZ0!*92!P
M;W9O;&5N82!P;W5Z92!J961N82!E+6UA:6QO=N$@861R97-A+@!0;W5Z92!V
M;&%S=&[M:R!N96)O('-Y<W3I;6]V_2!A9&UI;FES='+A=&]R(&WYOF4@;>QN
M:70@<'+A=F$@<')O('-D[6QE;OT@;V)J96MT+@!/=&5V^.UT('8@;F]VZ6T@
M;VMN["X`0VAY8F$@3W!E;E-33#H@3F5L>F4@>NUS:V%T(&1A=&$@>B!P;V1E
M<'-A;ND@Z.%S=&D@4R]-24U%+@!/=&5V^.UT('1E;G1O(&]D:V%Z('8@;F]V
MZ6T@;VMN[`!/<&5R8>AN[2!S>7-TZ6T`36^^;F]S=&D`36^^;F]S=&D@<')O
M("5S`%-E^&%Z96[]('-E>FYA;0!/<F=A;FEZ86-E`$]R9V%N:7IAZ&[M(&IE
M9&YO=&MA`$]R9V%N:7IO=N%N[0!/<FEG:6[A;&[M('9Z;W(@<')O(+[A9&]S
M=`!/<FEG:6[A;&[M('9Z;W(@=B`E<SH`3W-T871N[0!/<W1A=&[M(&EN9F]R
M;6%C90!$86RY[2!-;[YN;W-T:0!5OFEV871E;'-KX2!P<N%V80!/=NSX96[M
M('!O;6]C[2!004T@;F5N[2!D;W-T=7!NZ2X`4$=0(&1I9VETX6QN[2!P;V1P
M:7,`4$=0(+EI9G)O=F%NX2!D871A`%9E^&5J;OT@4$=0(&ML[>@`1&%T82!P
M;V1E<'-A;N$ON6EF<F]V86[A('!O;6]C[2!01U``4$A0(&OS9`!02%`@:V]N
M>F]L80!/9'!O;&5D;NT@;&5H:_T@9.FYNP!/9'!O;&5D;NT@</AE:.'R:WD`
M3V1P;VQE9&[M('-N[+YE;NT`3V1P;VQE9&[M('-N[&AO=ND@</AE:.'R:WD`
M3V1P;VQE9&[M(&)O=?AK>0!07TA0(&MO;GIO;&$`3V1S='5P>0!0X6MI<W3A
M;@!086QA=0!086QE<W1I;G-KZ2!T97)I=&]R:75M+"!O:W5P;W9A;ND`4&%N
M86UA`%!A<'5A($YO=N$@1W5I;F5A`%!A<F%G=6%Y`$WM<W1Y('IA=&&^96YO
M`$AE<VQO`$YE<W!RX79NZ2!H97-L;P!0<F\@;W;L^&5N[2!P;VUO8^T@4D%$
M54E3(&IE(&YU=&YO('IA9&%T(&AE<VQO+@!(97-L;R!S('!O='9R>F5N[6T`
M2&5S;&\Z`$AE<VQO.B``2&5S;&$@<V4@;75S[2!S:&]D;W9A="X`5FQOOFET
M`%9L;[YI="!Z92!S8VARX6YK>0!#97-T80"NX61O<W1I(&\@</AI:&SAN65N
M[3H`3&EDZ0!0<F]C96YT`%!R;W;I<W0@;W!E<F%C92#Z9'*^8GD`4')O=NES
M="!O<&5R86-E(/ID<KYB>2!P^&D@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!0
M<N%V80!.97!O=F]L96[]('#X[7-T=7``4'+A=F$`061M:6YI<W1R8>AN[2!P
M<N%V80!/<V]B;NT@:6YF;W)M86-E`%!E<G4`1&]MX6/M('IV[?AA=&$`1FEL
M:7#M;GD`5&5L969O;@!&;W1O9W)A9FEE`%!I=&-A:7)N`%!I>&5L^0!&<N%Z
M90!0<F]S[6T@:VQI:V[L=&4@;F$@;NQJ86MO=2!B=?)K=0!0<F]S[6T@<&]T
M=G+O=&4L(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E;G1O('!R=F5K.@!0
M<F]S[6T@<&]T=G+O=&4L(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E;G1O
M('!R=F5K+@!0<F]S[6T@>F%D96IT92!M['/M8R!A(')O:RX`4')O<^UM('IA
M9&5J=&4@;N%Z978@;F]VZ2!K871E9V]R:64Z`%!R;W/M;2!Z861E:G1E('-P
M<N%V;F]U($E0(&%D<F5S=2XN`%!R;W/M;2!Z861E:G1E('-P<N%V;OT@9&%T
M=6T@82!Z:V]N=')O;'5J=&4@<&_H970@9&[M('8@;>QS[6-I+@!0<F]S[6T@
M>F%D96IT92!S<'+A=F[](.AA<RX`4')O<^UM('5V9>]T92!S:')N=73M(%9A
MN65H;R!P<F]B;.EM=2X`4')O<^UM('IA9&5J=&4@5F&Y92!UOFEV871E;'-K
MZ2!J;>EN;R!A(&AE<VQO`%!R;W/M;2!Z861E:G1E(&YO=OT@;N%Z978@:V%T
M96=O<FEE.@!0;VQS:V\`4&]L:71I:V$`2&QA<V]VX6[M`%!O<G1U9V%L<VMO
M`%5M[7-T[&[M('1O:&]T;R!O8G+A>FMU`%5M[7-T[&[M('1A8G5L:WD`6F%S
M;&%T(&1O('3I=&\@<VQOOFMY("AN96[M('!O<VMY=&YU=&\@24U!4&5M*0!3
M<N&^:WD@>F$@<&]S;&5D;NTH8V@I("5S(&AO9&EN*'4I.B``4')E9G-?;&1A
M<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!,1$%0+@!0
M<F5F<U]S97-S:6]N.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP
M;VYA('-E:V-E+@!"87)O;65T<FEC:_T@=&QA:P!"87)O;65T<FEC:_T@=&QA
M:R!N82#Z<F]V;FD@;6_X93H@`$)A<F]M971R:6-K_2!T;&%K.@!.X6AL960`
M3N%H;&5D(&]B<N%Z:W4@=B!N;W;I;2!O:V[L`%#X961C:&]Z[2!M;[YN;W-T
M:0!4:7-K;F]U="!D;VMU;65N=`!0<FEVX71N[2!K;.WH`%!R;V)LZ6T`4&]P
M:7,@<')O8FSI;74`4')O:F5K='D`4')O;7!T('1E>'0`5F7X96IN_2!K;.WH
M`$%L9V]R:71M=7,@<')O('9E^&5J;OT@:VSMZ`!69?AE:F[]+W!R:7;A=&[M
M(&ML[>AO=OT@<.%R(&YE8GEL(/IS<.RY;NP@=GET=F_X96XN`%!O<G1O<FEK
M;P!+871A<@!6>6AL963A;NT`4E-!('9E^&5J;OT@:VSMZ"`H)60@8FET^2D`
M4W#X8;YE;ND@=&QAZ.UT:V\`1.FYNP!"<GIK_2!DZ;F[`%!O>F1N[2!DZ;F[
M`$1EN;MO=ND@</AE:.'R:WD`1.FYNR!S92!S;NQH96T`1.FYNR!AOB!S;NUH
M`$[A:&]D;NP@=GEB<F%NZ2"Y=.QS=.T`4&]M['(`R'1E8^T`4/AEZ'1E;ND@
M>G!RX79Y`$]P<F%V9'4@<VUA>F%T("5S/R!4871O(&]P97)A8V4@:F4@;F5V
M<F%T;N$N`$]P<F%V9'4@<VUA>F%T('6^:79A=&5L<VOA(&1A=&$@<')O('6^
M:79A=&5L92`E<S\@5&%T;R!O<&5R86-E(&IE(&YE=G)A=&[A+@!/<&%K;W9A
M="!P;W-L961N[2!A:V-I`$]B;F]V:70@9'EN86UI8VOI('!R=FMY(&UE;G4Z
M`$]B;F]V:70@4V5Z;F%M`$]B;F]V82!Z;V)R87IE;NT@<&]R=.%L=3H@`%)E
M9V5X`%!R;VAL[;YEZ"!V>G1A:/D`2&]D;F]T>0!6>F3A;&5NZ2!S97)V97)Y
M+@!6>F3A;&5NX2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.@!/9'-T<F%N:70`3V1S=')A;FET(&)L;VL`3V1S=')A;FET(&MA=&5G;W)I
M:0!/9'-T<F%N:70@<VQO=7!E8P!/9'-T<F%N:70@9F]R;>%T;W;A;NT`3V1S
M=')A;FET('#A<@!/9'-T<F%T:70@=6QOOF5N_2!S:W)I<'0@>B!D;^AA<V[I
M:&\@861R97/A^&4@;F$@<V5R=F5R=2X`3V1S=')A;FET`$]D<W1R86YI="!T
M=71O(.CA<W0@9&]K=6UE;G1U`$]D<W1R86YI="!UOFEV871E;&4`3V1S=')A
M;FET('6^:79A=&5L93H@)7,`3F5L>F4@;V1P;W;L9.QT(&YA('!OOF%D879E
M:RX@0VAY8F]VZ2!H;.&Y96[M.B``4&^^861O=F%NZ2!P;VQE`%9YZ&ES=&ET
M`%;]8VAO>NT@;F%S=&%V96[M(&AE<VQA`%;]8VAO>NT@;F%S=&%V96[M(%9A
MN65H;R!H97-L80!6_7-L961K>0!.X79R870@9&\@;6^^;F]S=.T`4F5U;FEO
M;@!0^&5P;F]U="!K;VYF:6=U<F%C:0!-;[YN;W-T:2!2:6-H(%1E>'0@961I
M=&]R=0!(X61A;FMY`$1O<')A=F$`2&QA=FGH:V$@;F%P<F%V;P!(;V1N;W1Y
M(&YA<')A=F\`5FQA<W1N;W-T:2#XX5]D:W4`VFQO:&$`4G5M=6YS:V\`3W1O
MZ&ET(&\@,3@PL`!/=&_H:70@9&]L979A`$]T;^AI="!D;W!R879A`%9L87-T
M;F]S=&D@^.%D:W4`5FQA<W1N;W-T:2#XX61K=0#8X61K>3H`4')A=FED;&$`
M4')A=FED;&$@<V4@=7!L871N[2!M97II(':Y96UI(/CA9&MY(&$@<VQO=7!C
M:0!0<F%V:61L82!S92!U<&QA=&[M('!O=7IE(&UE>FD@<VQO=7!C:0!0<F%V
M:61L82!S92!U<&QA=&[M('!O=7IE(&UE>FD@^.%D:WD`4')O=NES=`!2=7-K
MX2!F961E<F%C90!2=V%N9&$`4R]-24U%(+EI9G)O=F%N_2!P;V1P:7,`4R]-
M24U%(+EI9G)O=F%NX2!Z<'+A=F$`3W;L^&5N[2!P;VUO8^T@4T%33"!N96[M
M(&1O<W1U<&[I+@!335,@>G!RX79Y`%-13"!K;VYZ;VQA`%-32`#:4U#,0T@`
M4U]13"!K;VYZ;VQA`%-O`%-V873A($AE;&5N80!3=F%T_2!+:71T<R!A($YE
M=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4W1E:F[]('+A;2`H7W-E
M;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%9L
M87-T;NUK('-A=&5L:71U`%-A=61S:^$@07+A8FEE`%5L;[YI=`!5;&^^:70@
M)7,`56QOOF5N[2!M;[YN;W-T[0!5;&^^:70@=GET=F_X96[](&MO;F9I9W5R
M8>AN[2!02%`@<VMR:7!T(&1O(&1OZ&%S;NEH;R!A9')E<^'X92!N82!S97)V
M97)U+@!+;VYF:6=U<F%C92`E<R!U;&^^96YA+@!6[&1A`%9Y:&QE9&%T`%9Y
M:&QE9.%V86/M(&[A<W1R;VIE`%;]<VQE9&MY(%9Y:&QE9.%VX6[M`%9Y:&QE
M9.%VX6[M('8@3V)L87-T:0!(;&5D86[](%]497AT`%9Y8G)A="!S;W5B;W)Y
M`%9Y8G)A="!D871U;0!6>6)R870@<VMU<&EN=2P@:W1E<N$@8G5D92!P^&ED
MX6YA`%9Y8G)A="!N;W;I:&\@=FQA<W1N[6MA`%9Y8G)A="!ZX7!I<V[M:P!6
M>6)R870@<V5R=F5R`%9Y8G)A="!UOFEV871E;&4L(&MT97+](&)U9&4@</AI
M9.%N`%9Y8G)A="!VN65C:&YY(.CA<W1I(&1A='5M=2X`5GEB<F%T(&]B:F5K
M=`!6>6)E<G1E('!O=/AE8F[I('IN86MY('H@;NV^92!U=F5D96[]8V@@8F]X
M^2X@4&]TZ2!J92!M^;YE=&4@:V]P[7)O=F%T(&$@=FQOOFET('H@=&5X=&]V
MZ2!O8FQA<W1I+@!6>6)E<G1E(&]D9.QL;W9A8^T@>FYA:R!P<F\@9&%T=6TZ
M`%9Y8F5R=&4@9F]R;>%T(&1A='5M=3H`5GEB<F%T(&9O<FWA="!E>'!O<G1U
M.@!6>6)R870@<V]U8F]R(&L@:6UP;W)T;W;A;NTZ`%9Y8G)A="!F;W)MX70@
M>F1R;VIO=NEH;R!S;W5B;W)U.@!6>6)E<G1E(&ED96YT:71U+"!K=&5R;W4@
M<VD@</AE:F5T92!Z;>QN:70Z`%9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R
M;R#H87,Z`%9Y8F5R=&4@9F]R;>%T(.AA<W4Z`%9Y8F5R=&4@9';L(&]D<&]V
M[61A:NUC[2!P;VQE+@!6>6)E<G1E(&)A<F5V;OT@;6]T:78N`%9Y8F5R=&4@
M5N%M:2!P<F5F97)O=F%N_2!J87IY:SH`5GEB<F%NZ2!+871E9V]R:64Z`%!O
M<VQA="!Z<'+A=G4@;R!P<F]B;.EM=0!0;W-L870@4TU3`%-E;F5G86P`4V5N
M<V]R.@!:X?CM`%-R8G-K;R!A(,AE<F[A($AO<F$`4^ER:6]VZ2#H[7-L;P!)
M1"!S96MC92!Z86YI:VQO+@!.87-T879I=`!.87-T879I="!M;[YN;W-T:2!P
M<F\@<&]V;VQE;NT@<F5S971U(&AE<VQA+"!P;VMU9"!H;R!Z87!O;65N971E
M+@!.87-T879I="!V>F3A;&5NZ2!S97)V97)Y('1A:RP@OF4@8G5D;W4@</CM
M<W1U<&[I('H@<&]R=.%L=2X`3F%S=&%V96[M(%;A;6D@<')E9F5R;W9A;NEH
M;R!J87IY:V$L(.AA<V]VZ6AO('#A<VUA(&$@='EP=2!D871U;74N`$YA<W1A
M=F5N[2!P;^CA=&7H;NT@87!L:6MA8V4L(&)A<F5V;NEH;R!M;W1I=G4L(&]B
M;F]V;W;A;NT@<W1RX6YE:R!A(&1A;+GM8V@@;6^^;F]S=.T@>F]B<F%Z96[M
M+@!.87-T879E;NT`3F%S=&%V;W9A8^T@:V]N9FEG=7)AZ&[M('-K<FEP='D@
M<')O(&%K='5A;&EZ86-I(&IS;W4@9&]S='5P;ND`3NQK=&5RX2!M[7-T82!L
M>F4@;F%S=&%V:70@<R!T[6UT;R!P87)A;65T<F5M.B``4V5Y8VAE;&QE<P!.
M86MU<&]VX6[M`$MRX71KZ2!S:')N=73M`$WL;'D@8GD@8OUT('#X[7-T=7!O
M=ND@:VSMZ&4@9&5F:6YO=N%N>2!P<F\@=NQTN6EN=2!O9&MA>OD_`%IO8G)A
M>FET`%IO8G)A>FET(&%KZ&[M('1L8>CM=&MA/P!:;V)R87II="!R;WID[6QY
M(&UE>FD@<V]UZ&%S;F]U(&$@</AE9&-H;WKM(&MO;F9I9W5R86/M+@!:;V)R
M87II="#H87,@<&]S;&5D;NUH;R!P^&EH;.&Y96[M(&1O('-Y<W3I;74_`%IO
M8G)A>FET(&[A>F5V('KA<&ES;NUK=3\`6F]B<F%Z:70@<&]Z;N%M:WD@=B!T
M[&-H=&\@:V%T96=O<FGM8V@`6F]B<F%Z:70@;6^^;F]S="!U9'*^96[M(&]R
M:6=I;N%L=0!:;V)R87II="!S8NQR8>@`6F]B<F%Z:70@;65N=2!O<&5R8>AN
M[2!L:;ET=2!P<F\@=&%B=6QK>3\`6F]B<F%Z:70@)7,@;65N=2!N86QE=F\_
M`%IO8G)A>FET(&1I86QO9R!P<F\@=FQA<W1N;W-T:2!B=6[L:R!V('1A8G5L
M:^%C:`!:;V)R87II="!D:6%L;V<@=FQA<W1N;W-T[2!T86)U;&5K`%IO8G)A
M>FET(&1I86QO9R!V;&%S=&YO<W3M(/CA9&5K('1A8G5L96L`6F]B<F%Z:70@
M9&EA;&]G('9L87-T;F]S=.T@;V)RX7IK^0!:;V)R87II="!P^&5N;W,`4/AE
M:.'R:WD`0G)Z:^D@</AE:.'R:WD`4&]Z9&[M('#X96CA\FMY`%#X96CA\FMY
M('8@;VMO;.T`6FUE;KEI=`!:;65NN6ET(&YE8F\@<&]S=6YO=70@9&\@<V]U
M<V5D;NUH;R!B;&]K=2CY*2P@>B!C97-T>2!P<G9N[6UU`%-I97)R82!,96]N
M90!296=I<W1R;W9A="!S90!0;V1P:7,`06QG;W)I=&UU<R!P<F\@<&]D<&ES
M`%-I;F=A<'5R`%9E;&EK;W-T`%9Y;F5C:&%T(/ID<KYB=0!3;&]V96YS:V\`
M4VQO=FEN<VMO`%-N[+YE;NT`4V[L:&]VX2!P^&5HX?)K80!3;NQH;W;I('#X
M96CA\FMY`%)A;F[M('-N[&AO=ND@</AE:.'R:WD`4&]Z9&[M('-N[&AO=ND@
M</AE:.'R:WD`4V[L:&]VX2!P;VMR_79K83H`5F]D;NT@96MV:79A;&5N="!P
M<F\@<V[M:#H@`*EA;&%M;W5N;W9Y(&]S=')O=GD`4V]MX6QS:V\`4.US;NP@
M82!BX7-N[`!3973X[61I="!P;V1L92!+871E9V]R:>T`4V5T^.UD:70@<&]D
M;&4@5&5X='4@4&]Z;N%M96L`4VWL<B!T^.UD[&[M`%ID<F]J;W;A(&%D<F5S
M80!*:;YN[2!!9G)I:V$`2FEH;V5V<F]P<VO]("A)4T\M.#@U.2TS*0!3;W5T
M:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!*:;YN
M[2!P;VQO:V]U;&4`4')O<W1O<B!M97II('-O=7-E9&[M;6D@8G7R:V%M:0!0
M<F]S=&]R(&UE>FD@;V)S86AE;2!A(&AR86YI8V5M:2!V(&)U\F-E`$UE>F5R
M;NUK`$UE>F5R>0!/9'-T=7!Y(&$@;65Z97)Y`*EP86[L;'-K;P!3<&%M`%9S
M='5P('!R;R!Z=FSAN71N[2!Z;F%K>0!2;WID[&QI="!B=?)K=0!2;WID[&QI
M="!S;&]U<&5C`%)O>F3L;&ET(/CA9&5K`%-P;W)T`%-R:2!,86YK80!3=&%N
M9&%R9`!3=&%R(%1R96L`4F]K('IAZ.%T:W4`4W3A="#H:2!P<F]V:6YC:64`
M4W1A=@!&;W)MX70@=6QOOF5N[0!5;&EC90!0^&6Y:W)T;G5T_0!397IN86T@
M^&5T['IC90!/9'-T<F%N:70@9&]MZ6YO=ND@:FWI;F\@>B!A9')E<WD`4W1Y
M;"!;0U-370!.90!0^&5D;>QT`%!O9&%T`$1O;&[M(&EN9&5X`-IS<.RY;NP`
M2V]N9FEG=7)A8V4@8GEL82#Z<W#LN6[L('IM[&[L;F$N($]B;F]V=&4@<W1R
MX6YK=2X`VG-P[+ENZ2!U;&^^96[M('KA;&^^;NT@:V]N9FEG=7)A8V4N`-IS
M<.RY;ND@=6QOOF5N[2!ZX6QO:'D@:V]N9FEG=7)AZ&[M:&\@<V]U8F]R=2`E
M<RX`)7,@8GEL;R#Z<W#LN6[L('IA<'/A;F\`4W5DX6X`4VAR;G5T[0!3=NUT
MX6[M`%KA<&%D(%-L=6YC90!3;'5N9>AN;P!6_6-H;V0@4VQU;F-E`%;]8VAO
M9"]ZX7!A9"!3;'5N8V4`5OUC:&]D(%-L=6YC93H@`%KA<&%D(%-L=6YC90!:
MX7!A9"!3;'5N8V4Z(`!(;W)N[2!I;F1E>`!0;V1P;W)A`%-U<FEN86UE`%#X
M[6IM96[M`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL<VMO`*EVZ61S
M:V\`J7;]8V%R<VMO`%-Y;G1A>&]VX2!C:'EB82!V(&AL961A;NEM('1E>'1U
M`%/]<FEE`$)O=?AK80!";W7X:WD`5%-6('-O=6)O<@!486)U;&MA`%9L87-T
M;F]S=&D@=&%B=6QK>0!6;&%S=&YO<W1I('1A8G5L:WD`5&%I=V%N`%1A:7=A
M;BP@<')O=FEN8VEE(,CM;GD`5&%DOFEK:7-TX6X`5&%N>N%N:64L(%-P;VIE
M;N$@<F5P=6)L:6MA`$/M;#H`VFMO;'D`5&5L969O;F[M(.CM<VQO`%1E<&QO
M=&$@>F$@<&]S;&5D;NT@:&]D:6YU.B``5&5P;&]T80!497!L;W1A.B``5GIO
M<B!P<F\@861M:6YI<W1R86-I`%1E>'0`4&]U>F4@=&5X=`!:87)O=F[A;NT@
M=&5X='4`5G)C:"!T97AT=0#(=`!4:&%J<VMY("A425,M-C(P*0!4:&%J<VMO
M`$3L:W5J96UE('IA('!O=;[M=N%N[2!S>7-TZ6UU+@!0^.UP;VYA('!R;R!&
M5%`@;F5N[2!D;W-T=7!NX2X`26YT96=R8>AN[2!A;&=O<FET;7D@=B!(;W)D
M92]+;VQA8B!N97!O9'!O<G5J[2`B)7,B`$YE^G-P[+ENZ2!N8>AT96[M('3X
M[61Y($UA:6YT96YA;F-E.CH`0GEL;R!U>F%V^&5N;R!O:VYO(',@;6^^;F]S
M=&UI+B!5:V]NZ&5N;RX`061M:6YI<W1R[71O<B!P;W3X96)U:F4@;F%K;VYF
M:6=U<F]V870@=')V86SA('!RX79A('8@<WES=.EM=2P@<&]K=60@<VD@</AE
M:F5T92!P;W6^[70@<'+A=F$N`%!O=7IE('-P;V1N[2!S=')A;F$`3F5B>6QO
M('5V961E;F\@240@<')O(&MO;G1A:W0L(&YE8GEL;R!N86QE>F5N;R!V(&1A
M=&%BX7II(&YE8F\@8GEL;R#Z<&QN["!V>6YE8VCA;F\N`$MO;G1A:W0@8GEL
M(/IS<.RY;NP@</AI9.%N(&1O(%9AN65H;R!A9')E<^'X92X`2R!O=NSX96[M
M('!O9&5P<V%NZ2!Z<'+A=GD@:F4@=/AE8F$@;V1D[&QE;OT@8FQO:R!S(%!'
M4"!P;V1P:7-E;2X`3F5B>6QO('5V961E;F\@240@9&ES=')I8G7H;NUH;R!S
M97IN86UU+"!N96)Y;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O(&)Y;&\@
M^G!L;NP@=GEN96-HX6YO+@!.96)Y;"!U=F5D96X@9&ES=')I8G7H;NT@<V5Z
M;F%M+@"I:69R;W9A8^T@;6^^;F]S=&D@;'IE('9Y=;[M="!P;W5Z92!P^&D@
M8F5Z<&7H;NEM('-P;VIE;NT@<R!W96)E;2`H:'1T<',I+@!3;W5B;W(@)7,@
M8GD@;>QL(&]B<V%H;W9A="!N87-T879E;NT@)7,N`%-O=6)O<B`E<R!B>2!M
M[&P@;V)S86AO=F%T(&[L:W1E<N$@>B!N87-T879E;NT@)7,N`%-O=6)O<B!N
M96QZ92!K;W#M<F]V870@<^%M(&1O('-E8F4N`%-O=6)O<B!N96]B<V%H=6IE
M(+[A9&[A(&1A=&$N`$[A<VQE9'5J[2!H;&%V:>AK>2!P<F\@;65S<V%G92]R
M9F,X,C(@>G!RX79U`$IE('INX6WI+""^92!M\V0@</AE<R!C96QO=2!O8G)A
M>F]V:W4@=B!);G1E<FYE="!%>'!L;W)E<G4@</ES;V+M('!R;V)LZ6UY+"!P
M<F]T;[YE('-E('8@;NQM('9Y<VMY='5J92!C:'EB82P@:W1E<ND@<V4@;F5L
M>F4@=GEH;F]U="X@2F%K;R!NX7-L961E:R!M^;YE(&+]="!NX6AO9&[I('IH
M<F]U8V5N[2!T;VAO=&\@<')O9W)A;74L(&-H>6+L:NUC[2!F=6YK8V4@961I
M=&]R=2!N96)O(&YE<W!RX79NZ2!Z;V)R87IO=N%N[2X@4&]K=60@:F4@5N&Y
M('-Y<W1E;>EM(%=I;F]D=W,@.7@L(&IE('9E;&UI('!R879D['!O9&]B;NDL
M(+YE('-E(&]B:F5V[2!C:'EB;W;I(&ALX;EE;NT@)T=E;F5R86P@4')O=&5C
M=&EO;B!&875L="<@82!B=61E=&4@;75S970@<F5S=&%R=&]V870@<&_H[71A
MZ"Y<;EQN0GEL:2!J<W1E('9A<F]VX6YI+B!0<F]S[6T@<W1I<VMN['1E($]+
M('!O:W5D('-I('#X96IE=&4@<&]K<F'H;W9A="!V(&WS9'4@</AE<R!C96QO
M=2!O8G)A>F]V:W4N`$ED96YT:71A("(E<R(@8GEL82!S;6%ZX6YA+@!0;W5Z
M92!N82!L97;I('-T<F%N[`!5;>US=.QN[2!B:6[A<F[M:&\@<V]U8F]R=2!'
M;G501R!M=7/M(&+]="!Z863A;F\@9&\@=/CM9'D@0W)Y<'1?<&=P.CHN`%IP
M<N%V82!Z87-L86[A('8@)7,@:R`E<R!S('#X961M['1E;2`B)7,B(&)Y;&$@
M>F]B<F%Z96YA+@I4;W1O(&YE>F%R=>AU:F4L(+YE('IP<N%V82!B>6QA('#X
M9>AT96YA(&YE8F\@OF4@:NT@861R97/A="AK82D@<F]Z=6WL;"AA*2X`3N%Z
M978L(&MT97+](&)U9&4@<&]UOFET('#X:2!O9&MA>F]VX6[M(&YA('-T<N%N
M8V4@='9O<F)Y('IP<N%V`%!O>F[A;6MA(&)Y;&$@=GEM87KA;F$N`$YE;'IE
M('9Y='9O^&ET('KA<&ES;NUK("(E<R(Z("5S`%KA<&ES;NUK("(E<R(@8GEL
M('9Y='9O^&5N+@!:X7!I<V[M:R`B)7,B(&)Y;"!S;6%ZX6XN`%KA<&ES;NUK
M("(E<R(@8GEL('5L;[YE;BX`5/CM9&$@2&]R9&5?0W)Y<'1?<VUI;64Z.B!V
M>;YA9'5J92!M;V1U;"!O<&5N<W-L+@!.96QZ92!U;&^^:70@;F%S=&%V96[M
M("(E<R(L('!R;W1OOF4@:F5H;R!V96QI:V]S="!P^&5SX6AL82!P;W9O;&5N
M_2!L:6UI="X`3F5B>6QA(&YA;&5Z96YA(&%P;&EK86-E('!R;R#H=&5N[2!T
M;VAO=&\@='EP=2!D870@*"5S*2X`4&]U>F4@;F$@<')A=ND@82!L97;I('-T
M<F%N[`!0;W5Z92!N82!P<F%VZ2!S=')A;NP`4V5R=F5R("(E<R(@8GEL('9Y
M;6%ZX6XN`%-E<G9E<B`B)7,B(&)Y;"!U;&^^96XN`$)Y;&$@;V1S=')A;NQN
M82"^X61O<W0@;R!P^&EH;.&Y96[M('!R;R`E<RX`4&^^861O=F%N_2#XX61E
M:R!N965X:7-T=6IE+@!$;^AA<V[]('-O=6)O<B`B)7,B(&YE97AI<W1U:F4N
M`%!O=7IE(&YA:&_X92!A(&1O;&4`4&]U>F4@;F%H;_AE`%IT<F%T:6QA('-E
M('#X96YE<V5NX2!D871A('H@</AE9&-H;WKM:&\@:W)O:W4N`%#X96YE<V5N
M_2!S;W5B;W(@;F5L>F4@=6QOOFET+@!";&]K('=E871H97(N8V]M(&YE;NT@
M9&]S='5P;OTN`*[A9&[I('H@;6^^;F]S=.T@;F5J<V]U(&1O<W1U<&[I+@!.
M96)Y;'D@;F%L97IE;GD@ON%D;ND@Z.%S=&DL(&MT97+I(&)Y(&)Y;&\@;6^^
M;F\@>F]B<F%Z:70@=B#XX61K=2X`4/CM;&FY(&UN;VAO('IN86OY('8@<&]L
M:2X@6F%D86QI(&IS=&4@)7,@>FYA:_D[(&UU<^UT92!Z861A="!MZ6[L(&YE
MOB`E<R!Z;F%K^2X`3F%S=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U
M.B`E<R!N96)Y;"!P^&5N97-E;BX`3F%S=&%L82!C:'EB82!P^&D@</AE;F]S
M=2!S;W5B;W)U+B`E<R!N96WYOF4@8OUT(';L=+GM(&YEOB!M87AI;>%L;NT@
M<&]V;VQE;N$@=F5L:6MO<W0@*"5D(&)Y=/DI+@!.87-T86QA(&-H>6)A('#X
M:2!P^&5N;W-U('-O=6)O<G4Z(&)Y;&$@</AE;F5S96YA(&IE;B#HX7-T('-O
M=6)O<G4@)7,N`$1ON6QO(&L@8VAY8NP@</AI('IO8G)A>F]VX6[M('3I=&\@
MZ.%S=&D@>G!RX79Y`$YA<W1A;&$@8VAY8F$@</AI(&EM<&]R=&]VX6[M(&MO
M;G1A:W1U+@!.87-T86QA(&-H>6)A('#X:2!I;7!O<G1O=N%N[2!D870Z("5S
M+@!.87-T86QA(&-H>6)A('#X:2!I;7!O<G1O=N%N[2!V3F]T92!D870N`$-H
M>6)A('8@:V]N9FEG=7)AZ&[M;2!F;W)M=6SA^&DN(%KX96IM["!J<W1E('9Y
M;F5C:&%L:2!P;[YA9&]V86[I('!O;&4N`$YA<W1A;&$@8VAY8F$@</AI('!R
M;W;A9.QN[2!Z861A;ND@;W!E<F%C92!V(&%D<F5SX?AI+B!0<F]S[6T@>FMU
M<W1E('1O('!O>F3L:FDN`$YA<W1A;&$@8VAY8F$@</AI(&]D<W1R8?)O=N%N
M[2!P;WINX6UK>3H@)7,`3F%S=&%L82!C:'EB82!P^&D@=6MLX61N[2!P;WIN
MX6UK>3H@)7,`3F%S=&%L82!C:'EB82!P^&D@86MT=6%L:7IA8VD@:V]N=&%K
M='4N(%!R;W/M;2!Z:W5S=&4@=&\@<&]Z9.QJ:2X`3F%S=&%L82!C:'EB82!P
M^&D@86MT=6%L:7IA8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+B!0<F]S[6T@
M>FMU<W1E('1O('!O>F3L:FDN`$YA<W1A;&$@8VAY8F$@</AI('!R;VAL[;YE
M;NT@>N%P:7-N[6MU.B`E<P!.96QJ;W5S('ID92"^X61NZ2!P;WINX6UK>2!K
M(&5X<&]R=&]VX6[M+@!496YT;R!)34%0('-E<G9E<B!N97!O9'!O<G5J92!S
M9.UL96[M('-L;[YE:RX`5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!R87(@
M87)C:&EV+@!4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[]('II<"!S;W5B;W(N
M`%1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T;ND@Z.US;&\@:V%R='DN`%1E;G1O
M(&]V;&%D8>@@=6UOOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M($-L:6-K
M871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@8G+A;GD@</AI('!O=;YI
M=.T@2%144"!!4$D`5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z
M<'+A=B!P;VUO8^T@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@
M8G+A;GD@</AI('!O=;YI=.T@2%144"!!4$D`5&5N=&\@;W9L861AZ"!U;6^^
M\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO8^T@4TU44"!D;R!6;V1A9F]N92!)
M=&%L>2!B<N%N>2!P;W5Z92!P<F\@Z.US;&$@<&]S:WET;G5TZ2!6;V1A9F]N
M96TN($UU<^UT92!M[70@96UA:6QO=OT@^NAE="!U(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`%1O=&\@<&]L92!J92!N=71NZ2!V>7!L
M;FET+@!4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L
M82X`5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&-E;.$@Z.US;&$@
M82!D=F]J=&7H:W4N`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!O
M<VUIZ&MO=ND@Z.US;&$N`%1O=&\@<&]L92!M=7/M(&+]="!S97IN86T@8V5L
M_6-H(.CM<V5L(&]D9.QL96[]8V@@Z.%R:V]U(&YE8F\@;65Z97)O=0!4;W1O
M('!O;&4@;75S[2!B_70@<&QA=&[I(.CM<VQO+@!4;W1O('!O;&4@;75S[2!P
M8G-A:&]V870@8F%R979N_2!K\V0@=B"Y97-T;N%C:V]VZ6T@4D="(&9O<FWA
M='4L(&YA</@N("<C,3(S-&%F)RX`5&5N=&\@9F]R;>%T('-O=6)O<G4@;F5L
M>F4@<&]UONUT+@!496YT;R!F;W)M=6SA^"!J:;X@8GEL('IP<F%C;W;A;BX`
M5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE:W0@2V]L86(@1W)O=7!W87)U+B!+
M('IH;.ED;G5T[2!T;VAO=&\@;V)J96MT=2!J92!Z87!O=/AE8NT@;>UT('!O
MN71O=F[M:&\@:VQI96YT82P@:W1E<OT@<F]Z=6WM(&9O<FWA='4@2V]L86(@
M1W)O=7!W87)U+B!0<F\@<V5Z;F%M('1A:V]V_6-H(&ML:65N=/D@<')O<^UM
M(&YA=KET:79T92`E<P!4871O('IP<N%V82!B>6QA(&YA<'/A;F$@=B!J:6[I
M('IN86MO=ND@<V%D["`H)7,I(&YEOB!68;GM+B``5&]T;R#H[7-L;R!M=7/M
M(&+]="!N96IMZ6[L(&IE9&YA+@!397)V97(@;F5M^;YE(')O>F)A;&ET('II
M<"!A(&=Z:7`@<V]U8F]R>2X`5&5N=&\@<WES=.EM(&IE('8@<V]UZ&%S;F]S
M=&D@9&5A:W1I=F]V86[]+@!4871O(&AO9&YO=&$@;75S[2!B_70@Z.US;&\N
M`%1O=&\@;VMN;R!M=;YE(&+]="!V;VSA;F\@<&]U>F4@>B!O:VYA(&UOOFYO
M<W3M`$CX;>QN[0!,[7-T:WD`R&%S`%-L961O=N%N[2#H87-U`$9O<FWA="#H
M87-U`%;]8NQR(.AA<W4`5&EM;W(M3&5S=&4`5&ET=6P`5&ET=6P@*'1I<"DZ
M`$MO;74`4&]K=60@<VD@</AE:F5T92!V>6)R870@=NUC92!P;VQOOF5K+"!Z
M;>'H:V[L=&4@:VSA=F5S=2!#;VYT<F]L("A00RD@;F5B;R!#;VUM86YD("A-
M86,I(&$@:VQI:V[L=&4@;F$@<&]L;[YK=2X`1&YE<P!0^&5P;F]U="!N82!(
M5$U,('ID<F]J`%1O9V\`5&]K96QA=0!:[71R80!4;VYG80!6<F-H`$AO<F[M
M('+A;2`H7W1O<"D`4/AE:VQA9'D`5')I;FED860@82!4;V)A9V\`4W!RX79N
M["!N96)O(+EP871N[`#:=`!4=6YI<VMO`%1U<F5C:V\`5'5R96-K>2`H25-/
M+3@X-3DM.2D`5'5R:VUE;FES=.%N`%1U<FMS(&$@0V%I8V]S(&]S=')O=GD`
M5'5V86QU`$YA<&FY=&4@5F&Y:2!V;VQB=3H`52Y6+B!I;F1E>#H@`%523`!5
M4DP@<')O('IP<N%V=2!O('-T879U('IA<VQA;NEH;R!S:W)I<'1U`%523#H`
M56=A;F1A`%5K<F%J:6YA`%9&4R!A9')E<^'X(&IE(&YE</CM<W1U<&[]+@!0
M^&D@<F5G:7-T<F%C:2!N96QZ92!P^&ED870@97AT<F$@=;YI=F%T96QS:^D@
M^F1A:F4N`$YE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O<B`B)7,B
M+@!.96QZ92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@)7,O)7,N`$YE
M;'IE('IM[&YI="!N82`E<RX`3F5L>F4@<V4@</AI<&]J:70@:R!344P@<V5R
M=F5R=2X`3F5L>F4@<V4@</AI<&]J:70@<&]M;V/M(%-33"X`3F5L>F4@:V]P
M[7)O=F%T(%9&4R!S;W5B;W(N`$YE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X
M("(E<R(N`$YE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X+@!.96QZ92!V>71V
M;_AI="!61E,@<V]U8F]R+@!.96QZ92!V>71V;_AI="!P<N%Z9&[](%9&4R!S
M;W5B;W(N`$YE;'IE(')O>F)A;&ET(&1A=&$N`$YE;'IE('9Y;6%Z870@(B5S
M(BP@<')O=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2X`3F5L>F4@<VUA>F%T
M("(E<R(Z("5S+@!.96QZ92!V>6UA>F%T("5S+"!P<F]T;[YE(&%D<F5SX?@@
M;F5N[2!P<N%Z9&[]+@!.96QZ92!R96MU<GII=NP@;V1S=')A;FET(%9&4R!A
M9')E<^'X+@!.96QZ92!V>6UA>F%T(%9&4R!A9')E<^'X+@!.96QZ92!V>6UA
M>F%T(%9&4R!A9')E<^'X.B`E<RX`3F5L>F4@=GEM87IA="!61E,@<V]U8F]R
M("(E<R(N`$YE;'IE('9Y;6%Z870@5D93('-O=6)O<BX`3F5L>F4@<F5K=7)Z
M:79N["!O9'-T<F%N:70@5D93.B`E<RX`3F5L>F4@=7+H:70@86MT=>%L;NT@
M861R97/A^"X`3F5L>F4@>FII<W1I="!P;V1R;V)N;W-T:2!O(&-E<G1I9FEK
MX71U+@!$969I;FEC92`E<R!N96[M(&1O<W1U<&[A+@!.96QZ92!P^&5S=6YO
M=70@5D93('-O=6)O<BX`3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(@(B5S
M(BX`5D93('-O=6)O<B!N96QZ92!O=&5V^.UT('!R;R!ZX7!I<RX`3F5L>F4@
M;W1E=OCM="!61E,@<V]U8F]R+@!.96QZ92!O=&5V^.UT(&%R8VAI=F]V86[]
M('-O=6)O<BX`3F5L>F4@Z.US="!Z('9F<W)O;W0@861R97/A^&4N`$YE;'IE
M('#X96IM96YO=F%T("5S(&YA("5S.B!C[6QO=N$@<VQOOFMA(&IIOB!E>&ES
M='5J90!61E,@861R97/A^"!N96QZ92!P^&5J;65N;W9A="X`5D93(&%D<F5S
MX?@@;F5L>F4@</AE:FUE;F]V870Z("5S+@!.96QZ92!P^&5J;65N;W9A="!6
M1E,@<V]U8F]R("(E<R(N`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(@
M)7,O)7,N`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(N`$YE;'IE('!R
M;W;I<W0@)VUK:7-O9G,G+@!496YT;R!D;VMU;65N="!7;W)D(&YE;'IE('#X
M96QOOFET`$YE;'IE('IA<'-A="!D;R!61E,@<V]U8F]R=2`B)7,B+@!.96QZ
M92!Z87!S870@9&%T82!D;R!61E,@<V]U8F]R=2`H<V5L:&%L;R!C;W!Y*"DI
M+@!.96QZ92!Z87!S870@9&%T82!D;R!61E,@<V]U8F]R=0!0;V1T<FAN=73I
M`%-T;W)N;R!Z;>QN`%-T;W)N;W9A="!P;W-L96[M(&%K8VD`3F5OZ&5KX79A
M;N$@;V1P;W;L[R!S97)V97)U(&YA('-P;VIE;NTZ(`!.96_H96OA=F%NX2!O
M9'!O=NSO('-E<G9E<G4Z(`!.979Y<&QN[&YO`%5N:6-O9&4@*%541BTX*0!3
M<&]J96[I($%R86)S:^D@16UI<N%T>0!696QKX2!"<FETX6YI90!3<&]J96[I
M(%-TX71Y($%M97)I8VOI`%-P;VIE;ND@4W3A='D@365NN6EN;W;]8V@@;W-T
M<F]V^0!*961N;W1K>0!.97INX6WI`$YE>F[A;>D@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2X`3F5Z;N%MZ2!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+@!.97INX6WI('6^:79A=&5L<VOI(&IMZ6YO(&YE8F\@:&5S;&\N`$]D
M<&]J:70@<V]UZ&%S;OT@<')V96L`0F5Z92!J;>EN80!.97!R:79I;&5G;W9A
M;ND@<VMR:7!T>2!N96UO:&]U('9Y=;[M=F%T(&9U;FMC82!6>6IM;W5T+TMO
M<.UR;W9A="]6;&^^('H@8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y+B!+;&EK;NQT
M92!N82!/2R!A8GES=&4@=FED[&QI('1E8VAN:6-K;W4@>G!RX79U('H@;6]Z
M:6QL82YO<F<L(&MT97+A('9Y<W;L=&QU:F4L(&IA:R!N87-T879I="!S:W)I
M<'0@<')O('#X[7-T=7`@:V4@<V-H<N%N8V4N`$YE;F%S=&%V96[A(&)A<G9A
M`$YE<&]D<&]R;W9A;N$@</CM<&]N80!!:W1U86QI>F]V870`06MT=6%L:7IO
M=F%T("5S`$%K='5A;&EZ;W9A="!UOFEV871E;&4`4VMR:7!T('!R;R!A:W1U
M86QI>F%C:2!B>6P@=GEM87KA;BX`4/AE;F]S`%:Y96-H;GD@<V]U8F]R>2!P
M<F\@;F%S=&%V96[M(&%P;&EK86/M(&)Y;'D@</AE;F5S96YY(&YA('-E<G9E
M<BX`5F5L:^$@=&ES:V%C[2!P[7-M96YA`%9E;&OI(/CM;7-KZ2#H[7-L:6-E
M`%5R=6=U87D`4&]UONUT(&%K='7A;&[M.B`E<P!0;W6^[70@4U-,`%!O=;[M
M="!P;VMU9"!J;>EN;R]H97-L;R!J<V]U(&II;ND@;F6^('!R;R!)35-0('-E
M<G9E<BX`5;YI=F%T96P@)7,@;F5N[2!O<'+A=F[L;B!K('!O=;[M=N%N[2`E
M<RX`061M:6YI<W1R86-E('6^:79A=&5L^0!5OFEV871E;'-KZ2!M;[YN;W-T
M:0!296=I<W1R86-E('6^:79A=&5L^0!.82!T;VUT;R!S97)V97)U(&YE;NT@
M;6^^;N$@<F5G:7-T<F%C92!UOFEV871E;/DN`%6^:79A=&5L<VOI(&IMZ6YO
M`%6^:79A=&5L<VOI(&IMZ6YO.@!5OFEV871E;'-KZ2!J;>EN;SH@`%-E>FYA
M;2!UOFEV871E;/DZ`%5Z8F5K:7-TX6X`5D93(&%D<F5SX?@@;F5E>&ES='5J
M92X`1&]V;VQE;N$`3F%L97IE;N$@<&QA=&[A(&WM<W1A('IA:')N=6KM.B``
M4&QA=&YO<W0`2&]D;F]T82!V(&UI;G5TX6-H+@!(;V1N;W1Y`%9Y8G)A;ND@
M:&]D;F]T>2!Z`%9A;G5A='4`4')O;>QN;ND`5F5N97IU96QA`%-E;&AA;&$@
M=F5R:69I:V%C92`M('1A=&\@>G!RX79A(&UO:&QA(&+]="!Z9F%LN6]VX6YA
M+@!697)Z90!697)S:6]N($-O;G1R;VP`5F5R=&EKX6QN[2!Z87)O=F[A;NT`
M5F5R=&EKX6QN[2!O9'-T=7``5F5R=&EKX6QN[3H`5F5L;6D@=GES;VOA`%9I
M971N86T`5FEE=&YA;7-K>2`H5DE30TE)*0!:;V)R87II="`E<P!:;V)R87II
M="!E>'1E<F[M('=E8G-T<N%N:W4`6F]B<F%Z:70@:F%K;R`E<P!086YN96YS
M:^D@3W-T<F]V>2P@0G)I='-KZ0!086YN96YS:^D@3W-T<F]V>2P@52Y3+@!6
M:61I=&5L;F]S=`!6:61I=&5L;F]S=#H`5F]D869O;F4@271A;'D@</AE<R!3
M3510`%503UI/4DY)5`!54$]:3U).S$[-(2$A($]$4U120=)412!32U))4%0@
M4E7(3LP@6B`E<RX`5V%L;&ES(&%N9"!&=71U;F$`57!O>F]R;NQN[0!3=`!0
M^&5D<&]V[.\@<&_H87/M`$1A=&$@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H
M97(N8V]M`%=E8@!796(@<V5R=F5R`%3]9&[L`%;M=&5J=&4`5NUT96IT92!V
M("5S`%;M=&5J=&4L("5S`%KA<&%D;NT@*$E33RTX.#4Y+3$I`%KA<&%D;NT@
M*$E33RTX.#4Y+3$U*0!:X7!A9&[M(%-A:&%R80!+=&5R;W4@87!L:6MA8VD@
M;>$@)7,@>F]B<F%Z:70@<&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!*86O]
M(&IE(&]D9.QL;W9A8^T@>FYA:S\`2F%K_2!J92!Z;F%K('!R;R!C:71A8VD_
M`$1O(&MT97+I:&\@6N%P:7-N[6MU('-E(&UA:NT@<&]Z;N%M:WD@=6MLX61A
M=#\`2W1E<ND@9N%Z90!6;VQB82!R;WJY[?AE;NT@<')O(%)I8V@@5&5X="!E
M9&ET;W(N`*GM^&MA`*GM^&MA('8@0U-3(&IE9&YO=&OA8V@`J>WX:V$@)7,@
M;65N=2!V;&5V;R`H>FWL;F$@<V4@;V)J97;M('#X:2!D86RY[6T@</AI:&SA
MN65N[2DZ`*GM^&MA('1A8G5L:WD`2F5D;F]T:V$@N>WX:WD`J>WX:V$Z`%=I
M:VD`5NUT<@!286YN[2!V[71R`%)Y8VAL;W-T(';L=')U('8@=7IL96-H`%;M
M='(Z`%;M='(Z(`!-;W5D<F]S=`!0<N%C90!!9')E<V$@9&\@>F%M['-T;N%N
M[0!496QE9F]N(&1O('IA;>QS=&[A;NT`6"U2968`6#4P.78S('KA:VQA9&[M
M(&]M97IE;NT`6#4P.78S(')O>KGM^&5NZ2!P;W6^:73M(&ML[>AE`%@U,#EV
M,R!A;'1E<FYA=&EV;NT@:FWI;F\@;W-O8GD`6#4P.78S(&ED96YT:69I:^%T
M;W(@:VSMZ&4`6#4P.78S(')O>KGM^&5N[0!24@!24E)2`$UA<&$@66%H;V\A
M`%)OZ&[L`$IE;65N`$%N;P!!;F\L('-O=6AL87/M;0!*<W1E('8@5$585$]6
MR4T@3=-$52X@4&]UOFEJ=&4@6SP^72!T;&'H[71K82!K('IP['1NZ6UU('#X
M97!N=73M(&1O(%=94TE764<N`$YE8GEL:2!J<W1E('-P<N%V;NP@;W;L^&5N
M:2X`6FYA:R`G7"<@;F5M^;YE(&+]="!S;W7HX7-T[2!68;EE:&\@:FWI;F$N
M`$)Y;&$@>F%DX6YA(&YE<&QA=&[A(&4M;6%I;&]VX2!A9')E<V$N`$YE;6%P
M;W9A;&D@:G-T92"^X61NX2!P;VQE('H@:6UP;W)T;W9A;NEH;R!S;W5B;W)U
M(&L@;V1P;W;M9&%J[6/M;2!P;VSM;2!V("5S+@!.961O<W1A=&7H;N$@<'+A
M=F$@<')O('!R;VAL[;YE;NT@>N%P:7-N[6MU("5S+@!">6QI(&IS=&4@;V1H
M;.&Y96YI('IE('-Y<W3I;74N`%9L;[YT92#H[7-L;R!M;V)I;&[M:&\@=&5L
M969O;G4L('!O=;YI:G1E(&IE;B#H[7-L:6,@;F5B;R!P^.UP861N["`G*R<@
M<')O(&UE>FENX7)O9&[M(.AI<VQA+@!-=7/M=&4@>F%D870@<&QA=&YO=2!H
M;V1N;W1U+@!-=7/M=&4@:V]N9FEG=7)O=F%T(&1A=&%BX7II(&1A="P@<&]K
M=60@<VD@</AE:F5T92!P;W6^[79A="!296=I<W1R86-E+@!-=7/M=&4@:V]N
M9FEG=7)O=F%T(%9&4R!B86-K96YD+@!-=7/M=&4@;F5J9/CM=F4@<&]P<V%T
M('!R;V)LZ6T@82!P;W3I(&AO(&]D97-L870N`$UU<^UT92!Z861A="!54DP@
M;F$@:W1E<ND@8G5D92!T96YT;R!O9&MA>B!U:V%Z;W9A=`!-=7/M=&4@=GEB
M<F%T('KA<&ES;NUK+"!K=&5R_2!S:2!P^&5J971E('-M87IA="X`375S[71E
M('9Y8G)A="!S97)V97(L(&MT97+](&)U9&4@<VUA>N%N+@!-=7/M=&4@=GEB
M<F%T('6^:79A=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B=61E('-M87KA;F\N`$UU
M<^UT92!Z861A="!UOFEV871E;'-KZ2!J;>EN;RP@:W1E<ND@8G5D92!O9'-T
M<F%N[&YO+@!.975V961L:2!J<W1E('6^:79A=&5L<VOI(&IMZ6YO+"!K=&5R
MZ2!B=61E('#X:63A;F\N`$YE=79E9&QI(&IS=&4@=;YI=F%T96QS:^D@:FWI
M;F\@<')O(&%K='5A;&EZ86-I+@!-=7/M=&4@>F%D870@86MC:2P@:W1E<N$@
M8G5D92!P<F]V961E;F$N`$UU<^UT92!Z861A="!J;>EN;R!N;W;I(&MA=&5G
M;W)I92X`5F&Y92`E<R!R96QA8V4@8GEL82!U:V]NZ&5N82X@3W#L="!S92!P
M^&EH;&&Y=&4L('!R;W/M;2X`5F&Y92!E;6%I;&]VX2!A9')E<V$`5F&Y92!/
M9"UK;VAO.B!A9')E<V$Z`%9AN64@:6YF;W)M86-E`%8@<F5L86-I("5S('-E
M('IM[&YI;&$@5F&Y92!I;G1E<FYE=&]VX2!A9')E<V$N(%H@8F5Z<&7H;F]S
M=&[M8V@@9/EV;V3Y('-E(&UU<^UT92!O<.QT('#X:6ALX7-I="X`5F&Y92!J
M;>EN;P!6X;D@;W;L^&]V86/M('-Y<W3I;2!N97!O9'!O<G5J92!V_7!I<R!U
MOFEV871E;/D@86YE8F\@=&%T;R!M;[YN;W-T(&YE;NT@</CM<W1U<&[A('H@
M:FEN_6-H(&3Y=F]D^2X`6F3A('-E+""^92!V('!R^6+L:'4@<F5L86-E("5S
M('-E('IM[&YI;"!6X;D@<')O:&SMOF7H+B!:(&)E>G!EZ&YO<W1N[6-H(&3Y
M=F]D^2!S92!M=7/M=&4@;W#L="!P^&EH;.%S:70N`%;AN2!P<F]H;.V^9>@@
M;F5P;V1P;W)U:F4@='5T;R!M;[YN;W-T+@!68;EE('-O=>AA<V[I(.AA<V]V
MZ2!PX7-M;SH`5F&Y92!I;7!L:6-I=&[M(&ED96YT:71A`%;AN2!I;7!L:6-I
M=&[M('KA<&ES;NUK.@!68;EE(/IP;&[I(&IMZ6YO.@!68;EE(&YO=ND@:&5S
M;&\@<')O("5S(&IE.B`E<P!68;EE('KA<&ES;NUK>3H`5F&Y92!N87-T879E
M;NT@8GEL;R!A:W1U86QI>F]VX6YO('!R;R!T<G;A;NT@=.ET;R!R96QA8V4N
M`%9AN64@;F%S=&%V96[M(&)Y;&\@86MT=6%L:7IO=N%N;RX`5F&Y92!H97-L
M;R!B>6QO(')E<V5T;W;A;F\N`%9AN64@:&5S;&\@8GEL;R!R97-E=&]VX6YO
M+"!Z:V]N=')O;'5J=&4@<VD@>G!RX79Y(&5L96MT<F]N:6-KZ2!P;[ET>2!A
M('#X:6AL8;ET92!S92!S(%9AN>UM(&YO=OUM(&AE<VQE;2X`5F&Y92!V>F3A
M;&5NZ2!S97)V97)Y.@!*=6=O<VSA=FEE`%IA:7(`6F%M8FEE`%II;6)A8G9E
M`%II<'!Y`%M5:W+]="!C:71O=F%N_2!T97AT70!;2&SAN65N[2!P<F]B;.EM
M=5T`6UIO8G)A>FET(&-I=&]V86[]('1E>'0@+0!;6F]B<F%Z:70@8VET;W9A
M;OT@=&5X="`M("5S(/CA9&OY70!;^.%D96L@)7,@>B`E<UT`7T%D;6EN:7-T
M<F%C90!?6G#L="!K(%KA<&ES;NUK=0!?0TQ)`%]+871E9V]R:64`7T1A=&%4
M<F5E`%]3;6%Z870`7U-M87IA="#XX61E:P!?57!R879I=`!?4')V;NT@V.%D
M96L`7U-K=7!I;GD`7T[A<&]V[&1A`%]6;&%S=&YO<W1I(&]B<N%Z:W4N+BX`
M7TEM<&]R=&]V870O17AP;W)T;W9A=`!?4V5Z;F%M(%!O>F[A;65K`%]0^&EH
M;.&Y96[M`%]/9&ALX;EE;NT`7TUO9&EF:6MO=F%T(&]D:V%Z+BXN`%]0;WIN
MX6UK>0!?3F]VX2!0;WINX6UK80!?36^^;F]S=&D`7U!RX79A`%]4:7-K`%]/
M9'-T<F%N:70@;V1K87HN+BX`7U9Y:&QE9&%T`%].87-T879E;NT`7U9L87-T
M;F]S=&D@=&%B=6QK>2XN+@!?5;YI=F%T96SI`&%D<F5SX?@`:V%L96YDX?@`
M8F5Z=NQT^.T`:VQI:VYO=70@>F1E`'-RX;YK>0!S;W5B;W(`>B`E<R`H)7,I
M(')Y8VAL;W-T[2`E<R`E<P!H.@!O:V%MOFET[`!V(/AA9.P`^.%D:_E=`&-H
M>6)O=OT@:_-D(&UK:7-O9G,@)60@</AI('9Y=';A^&5N[2!)4T\N`&IMZ6YO
M`&YE;NT@:6UP;&5M96YT;W;A;F\`;F5N[2!D;W-U9"!I;7!L96UE;G1O=N%N
M;P!ZX7!I<V[M:P!P;WIN86UK>2YC=G,`<')O8V5N=`!P:7AE;/D`<W1O=7!A
M:NUC[0!Z;V)R87II="!R;WID[6QY`'-M<S)E;6%I;"!Z82!P;W6^:73M($A4
M5%``=GET<G9A;.D`<V5Z;F%M(/IK;VSY`'!R;R!P;W1V<GIE;NT@;F%P:;ET
M92!H97-L;R!D=F%K<N%T`'-J961N;V-E;OT`8F5Z(&[A>G9U`'9Y8G)A="!U
MOFEV871E;&4`=D-A<F0`=DYO=&4`=SH`=V5A=&AE<BYC;VT`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]M;F5M;R]L;V-A;&4O96Q?1U(O````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`Q-S<V
M-@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]E;%]'4B],
M0U]-15-304=%4R\`````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-#0`,#(Q-34S`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE
M;6\O;&]C86QE+V5L7T=2+TQ#7TU%4U-!1T53+VUN96UO+FUO````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q-C(P-P`Q,#0Q-S,V,C<T-``P,C,R,C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````WA($E0````!W````
M'````-0#``"C````C`<````````8"@``*````!D*```(````0@H```4```!+
M"@``"````%$*```'````6@H```P```!B"@``!0```&\*```?````=0H```D`
M``"5"@``$0```)\*```(````L0H```@```"Z"@``%0```,,*```(````V0H`
M``H```#B"@``"@```.T*```,````^`H```<````%"P```@````T+```%````
M$`L``!`````6"P``&0```"<+```:````00L```H```!<"P``%````&<+```O
M````?`L```\```"L"P``)@```+P+```%````XPL```T```#I"P``!0```/<+
M```0````_0L``!`````.#```#P```!\,```+````+PP```\````[#```#```
M`$L,```/````6`P``!X```!H#```(0```(<,```#````J0P```0```"M#```
M#````+(,```*````OPP```4```#*#```"@```-`,```/````VPP``!(```#K
M#```$````/X,```(````#PT``!`````8#0``!@```"D-```'````,`T```(`
M```X#0``!````#L-```/````0`T```D```!0#0``"@```%H-```'````90T`
M``P```!M#0``!P```'H-```$````@@T```4```"'#0``!0```(T-```'````
MDPT``!$```";#0``#0```*T-```(````NPT``!X```#$#0``!0```.,-```H
M````Z0T``"D````2#@``$P```#P.```,````4`X```L```!=#@``$0```&D.
M```$````>PX```P```"`#@``!@```(T.```.````E`X```P```"C#@``&@``
M`+`.```7````RPX``!<```#C#@``&P```/L.```?````%P\``!,````W#P``
M$````$L/```0````7`\``!<```!M#P``!P```(4/```%````C0\```D```"3
M#P``(0```)T/```<````OP\```4```#<#P```P```.(/```@````Y@\``"8`
M```'$```#````"X0```'````.Q````P```!#$```"````%`0```'````61``
M``8```!A$```#0```&@0```+````=A````P```""$```"@```(\0```"````
MFA````8```"=$```10```*00```P````ZA```!`````;$0``'P```"P1```0
M````3!$```\```!=$0``!0```&T1``!L`0``<Q$``"<```#@$@``"P````@3
M```%````%!,``!`````:$P``"0```"L3```0````-1,```D```!&$P``(@``
M`%`3```'````<Q,``!````![$P``"````(P3```*````E1,``!P```"@$P``
M"0```+T3```/````QQ,``!$```#7$P``$@```.D3```'````_!,```(````$
M%```"`````<4```7````$!0``",````H%```)0```$P4```(````<A0``!D`
M``![%```-0```)44```2````RQ0``$````#>%```#````!\5```>````+!4`
M``4```!+%0``#0```%$5```4````7Q4```P```!T%0``)````($5```-````
MIA4```H```"T%0``%@```+\5```W````UA4``"P````.%@```P```#L6```'
M````/Q8``!$```!'%@``$````%D6```-````:A8```X```!X%@``%0```(<6
M```5````G18``!4```"S%@``!@```,D6```6````T!8```<```#G%@``!@``
M`.\6```"````]A8```P```#Y%@``%`````87```2````&Q<``!`````N%P``
M!@```#\7```2````1A<```<```!9%P``!0```&$7```$````9Q<```H```!L
M%P``"````'<7```1````@!<```X```"2%P``!P```*$7```?````J1<```@`
M``#)%P``+````-(7```Q````_Q<``!4````Q&```#P```$<8```0````5Q@`
M`!<```!H&```!0```(`8```3````AA@```D```":&```%P```*08```B````
MO!@``",```#?&```+`````,9```E````,!D``"(```!6&0``%P```'D9```=
M````D1D``!(```"O&0``&0```,(9```;````W!D```@```#X&0``"`````$:
M```,````"AH``#`````7&@``)````$@:```&````;1H``!4```!T&@``+@``
M`(H:```O````N1H```\```#I&@``%````/D:```/````#AL```P````>&P``
M#0```"L;```+````.1L``!$```!%&P``#P```%<;```2````9QL``!$```!Z
M&P```@```(P;```&````CQL``$$```"6&P``00```-@;```2````&AP``"(`
M```M'```%0```%`<```2````9AP```T```!Y'````0```",````1````+P``
M`%\````W````"``````````$````$@````H````D`````````'4```!-````
M%````&T```!1````2````$X```!"````!0````\`````````70````<`````
M``````````````!L`````````"L````G`````````%8```!P````"P```!<`
M```X`````````$8```!,````,0```!`````;`````````&\`````````,@``
M````````````````````````````5````#H```!T````"0```&8```!I````
M1`````````!S````*0````P```!R````4@```&@````Y````8@``````````
M````8P```$<````````````````````.````/``````````S````<0``````
M```^````90```#4`````````4P`````````P`````````"````!0`````P``
M``````!N````'@```$\```!;````'P````````!J````)0```#0`````````
M`````$L`````````=P```&<```!)````$P```!8```!A````!@```"(````_
M```````````````9````0````!@```!#`````````"@`````````.P```&L`
M``!9```````````````N````-@````(````:````/0```'8```!7````)@``
M``````!D````8``````````A````*@```$$`````````50```"P````<````
M%0```$H`````````6````!T````M````#0```%P``````````````%H```!%
M````7@`````E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T
M:6]N`#(T(&AO=7)S`$%-+U!-`$%D9"!P86ER`$%D9')E<W,`061D<F5S<R!"
M;V]K`$%L:6%S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07-C
M96YD:6YG`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A
M;F-E;"!0<F]B;&5M(%)E<&]R=`!#871E9V]R>0!#96QL(%!H;VYE`$-L96%R
M($9O<FT`0VQO<V4@5VEN9&]W`$-O;7!A;GD`1$0`1&%I;'D`1&5F875L="!)
M9&5N=&ET>0!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R
M=&EN9R!D:7)E8W1I;VXZ`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L
M96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@
M;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E
M<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!(96QP`$AO
M;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EC;VYS($]N;'D`26-O;G,@
M=VET:"!T97AT`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z
M`$QA;F=U86=E`$QI<W0@2&5L<"!4;W!I8W,`3&]G(&EN`$QO9R!O=70`34T`
M36%I;`!-871C:&EN9R!F:65L9',`365M;R!497AT`$UE;G4@;6]D93H`365S
M<V%G90!-;V1I9GEI;F<@)7,`36]N=&AL>0!.86UE`$YE=F5R`$YO=&5S`$]P
M=&EO;G,`3W1H97(@26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!087-S=V]R
M9`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R
M:7!T:6]N`%)E9G)E<V@@3&ES=`!296UO=F4@<&%I<@!2971U<FX@=&\@3W!T
M:6]N<P!2;VQE`%-A=F4@3W!T:6]N<P!396%R8V@`4V5A<F-H(%)E<W5L=',`
M4V5A<F-H(%-C;W!E`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4VMI<"!-86EN=&5N
M86YC90!3;W)T(&)Y($-A=&5G;W)Y`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-U8V-E<W,`5&%S:W,`5&5X="!/;FQY`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I
M=&QE`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG
M97,`56YF:6QE9`!5<V5R($]P=&EO;G,`57-E<FYA;64`5V%R;FEN9P!7965K
M;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L
M96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`=D-A<F0`
M4')O:F5C="U)9"U697)S:6]N.B!-;F5M;SH@,2XQ+6-V<PI297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#(M,3$M,3(@,3(Z,3(K,#(P,`I,87-T+51R86YS;&%T;W(Z(%-T969A
M;F]S($DN($1I;6ET<FEO=2`\<W5P<&]R=%]W96)M86EL0'1E:6%T:"YG<CX*
M3&%N9W5A9V4M5&5A;3H@1W)E96L@/&1E=D!L:7-T<RYH;W)D92YO<F<^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#UI<V\M.#@U.2TW"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M
M8FET"@`E<R#+Y>GT[_7QX]_E\B#3]>WTWO'G\^?R("T@Q?#IXN7BX=_Y\^<`
M,C3^\><@[._Q]MX`T,POS,P`T/'O\^C>ZN<@YN7]X^_U\@#$Z>7]Z/7M\^<`
MQ.GE]>CU[?/I[^/QW/;O\@#8Y?7D_NWU[.\`S_'?\_3GZN4@[-_A(.SG(.7P
MZ?3QY?#\[.7MYR#TZ>S>+@#!_>[O]?/A`,3IX>C=\^GLX2#0Y>3?X3H`P^7M
MW>CKZ>$`Q^SE\>_K_./I[P#!ZOWQ^?/G(,'MX?;O\=SR(-#Q[^+KWNSA]._R
M`,KA].?C[_'?X0#*Z>WG]/P@U.?KW?;Y[>\`RN'HX?'I\^S\\B#V_/'LX?(`
MRNOEW_/I[.\@T.'QW.CU\>_U`,7TX>GQW^$`1$0`Q^SE\=[SZ>$`T/'OY?#I
MZ^7C[-WMYR#4X?7T_/3G].$`T/'OY?#IZ^7C[-WM[R#J\>GTWO'I[R#TX>[I
M[?SLY_/G\CH`T/'OY?#IZ^7C[-WMYR#JX?3E_>CU[?/G(/3A[NGM_.SG\^?R
M.@#6Z-_M[_7SX0#0Y?'IX_'A]MX@]._U(-#Q[^+KWNSA]._R`,_I(.OE\/3O
M[-WQY>GE\B#=]^_U[2#JX?3AX_'A]N7?(./IX2#T[^T@Y.GA]^7I\>GS]-XN
M`,7PZ>OOX]WR(,7L]MSMZ?/G\@#,Y^T@Y?#I]^7I\=[SY?3E(.WA(.'M[]_N
MY?3E(.'PY?7HY=_A\B#T[R#A\??EW^\@;6%I;G1E;F%N8V4N<&AP`,'KZ^?K
M[^/QX?;?X0#$Y>T@Y?#I\_3QW/;GZN'M(,'P[_3EZ]WS[.'TX2X`R]SH[_(`
MRMSHY2`Q-2#KY?#TW`#*W.CE(#,P(.3E]?3E\?SKY?#TX0#*W.CE(#4@Z^7P
M]-P`RMSHY2#V[_'<(/#O]2#L\.'?[>7TY2#S].?M(/7PY_'E\]_A`,K<Z.4@
M[.GSWB#^\>$`RMSHY2#KY?#T_`#0X?'AY.7IX^SA].GJW?(@].GLW?(Z`,'P
M[_3U]]_A(.KA]-P@].?M(/#Q[_/PW.CEZ>$@X>W<ZO3G\^?R(/3Y[2#P\>_T
MZ>S>\^7Y[2X`P?#O]/7WW^$@\_WMY.7SY_(@\_3O[2#DZ>'J[^SI\_3>(,KA
M].'K_./O]2X`UL'.`,+OWNCEZ>$`Q.GE_>CU[?/G(-/PZ?3I[_T`U.?KW?;Y
M[>\@T_#I].GO_0#!\??IZMX@T^7KW^3A`,S\[>\@Q>GJ[^W?Y.GA`,7IZN_M
MW^3IX2#JX>D@RN7?[.7M[P#0Y>3?[R#P[_4@Y>GSWO?HYSH@)7,`T.7DW^$@
M\._U(.7I\][WZ.?SX>TZ`,/K_O/SX0#+W_/TX2#HY>S<]/GM(,+OWNCEZ>'R
M`,7?\^_D[_(`N.[OY._R`,S,`,'KZ^?K[^/QX?;?X0#0Y>3?X2#P[_4@].'I
M\>G<YN_U[0#*Y=_LY>WO(-/G[.7I_O/E^>T`RN'TW//TX?/G(,SE[>_].@#,
MWNWU[.$`Q?#E[N7QX^'SW^$@]._U("5S`,SG[>GAW^$`O.WO[.$`T._TW0#3
MY^SEZ?[SY>GR`,7PZ>OOX]WR`,'KZ^7R(-#KY_'O]N_QW^7R`,'KZ^7R(,7P
MZ>OOX]WR`,KYY.GJ_/(`Q>KTW>OE\^<@R^7I]._U\>/I_NT@T_7M]-[QY_/G
M\@#4Y^O=]OGM[P#0X?'AZN'K_B#D_O/TY2#LW^$@\.7QW^OG^.<@]._U(/#Q
M[^+KWNSA]._R+@#0X?'AZN'K_B#D_O/TY2#T[R"\[>_LX2#7\=[S].<@ZN'I
M(/3O[2#J^>3IZOP@\^'R`-#E\>GC\>'VWB#0\>_BZ][LX?3O\@#![>'MW?GS
MYR#+W_/TX?(`P?;AW_'E\^<@YN7]X^_U\@#%\.GS]/'O]MX@\_3I\B#%\.GK
M[^/=\@#1_.OO\@#!\._HWNKE]?/G(,7PZ>OOX_[M`,'MX>;>].?SYP#!\._T
MY>O=\^SA].$@P>WAYM[TY_/G\@#0Y>3?X2#S].$@[_#OW^$@Z.$@X]_MY>D@
MX>WAYM[TY_/G`,7PZ>OOX]X@]._U(.3IX??Y\>GS]-X@Y^SE\>_LY^W?X?(Z
M`,7PZ>OOX]X@].?R(.SO\?;>\B#P[_4@Z.$@W??EZ2#G(.?LY?'O[.?MW^$Z
M`,7PZ>OOX]X@].?R(.SO\?;>\B#P[_4@Z.$@W??EZ2#G(/[QX3H`Q?#IZ]WN
M].4@Y/WO(/#EY-_A(/#O]2#TX>GQZ=SF[_7M+@#%\.GKW>[TY2#TYR#CZ_[S
M\^$@\^'R.@#!\._S]._KWB#![>'V[_'<\B#0\>_BZ][LX?3O\@#!ZOWQ^?/G
M(-/U[?3>\>?SY_(`U.'NZ>W\[.?SYR#JX?3<(,KA].?C[_'?X0#%Z?/AX_GC
MWB#%Z>3IZO[M(-?A\>'J]-[Q^>T`Q?#I]/7WW^$`Q?'CX?/?Y?(`S/SM[R#*
MY=_LY>WO`,'U]/SR(.\@X?'IZ.S\\B#P\=WPY>D@[>$@Y=_MX>D@]._UZ]SW
MZ?/T[^T@W>WA+@#!]?3>(.<@].GLWB#P\=WPY>D@[>$@Y=_MX>D@X?'IZ.S\
M\BX`U-_TZ^_R`,?KY>KT\>_MZ>K>(,3IY?WH]>WSYP#$Y>T@Y=_MX>D@Y/7M
MX?3>(.<@\_WMY.7SYR#S].\@Y.GAZN_LZ?/TWB!344PN`,3E[2#L\/SQY?/E
M(.WA(.SE].'V\>'S].7?(.'U]/P@].\@W>/C\>'V[R!7;W)D`,'J_?'Y\^<@
MP>OKX>/^[0#,YR#*X?3GX^_QZ>_P[^GG[-WM[P#%\.GK[^/=\B#7\=[S].<`
MO.WO[.$@U_'>\_3G`-#Q[^7IY._P[]_G\^<`Q>+D[^SAY.GAW^$`RN'K^?/>
M\>CE\B#S].\@)7,`RN'K_O(@WNOHY?(L("5S`,3IY?WH]>WSYR#%\>/A\]_A
M\@#4Y^O=]OGM[R#%\>/A\]_A\@!960#%]-[SZ>$`T/'=\.7I(.WA(/#E\>GC
M\=SXY?3E(/3O(/#Q_.+KY^SA(/#QZ>T@\_3EW^OE].4@X>WA]N_QW"#CZ>$@
MX?7T_"X`QR#S_>WDY?/G(//A\B`E<R#DZ>'J_/#GZN4N(-#A\>'JX>O^(.3O
MZNGLW//TY2#MX2#NX>WA\_7MY.7HY=_TY2X`S^D@T.OG\>_V[_'?Y?(@\^'R
M`,_I(.7PZ>OOX]WR(//A\B#=]^_U[2#A\._HY^KE]?3EWRX`6\'MX?;O\=P@
MT/'OXNO>[.'T[_)=`%OC\>'L[-X@)7,@X?#\("5S70#8Y_;IX>K>(,K<\?3A
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M
M;F5M;R]L;V-A;&4O96Y?55,O````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,#`P-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]E;E]54R]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R-S4`,3`T,3<S-C(W
M-#0`,#(Q-#8V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_>&UL('9E<G-I;VX])S$N,"<_/@H\(2TM("1(;W)D93H@;6YE
M;6\O;&]C86QE+V5N7U53+VAE;'`N>&UL+'8@,2XV(#(P,#0O,3$O,S`@,C(Z
M,C4Z-#,@:F%N($5X<"`D("TM/@H\:&5L<#X*"CQE;G1R>2!I9#TB3W9E<G9I
M97<B/@H@("`@/'1I=&QE/D]V97)V:65W/"]T:71L93X*("`@(#QH96%D:6YG
M/DEN=')O9'5C=&EO;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@/&D^3F]T
M97,\+VD^(&ES(&%N(&%P<&QI8V%T:6]N('=H:6-H(&%L;&]W<R!Y;W4@=&\@
M8W)E871E('1H92!C;VUP=71E<B!E<75I=F%L96YT(&]F('-T:6-K>2!N;W1E
M<RX@($YO=&5S(&-A;B!B92!C<F5A=&5D+"!M;V1I9FEE9"P@9&5L971E9"P@
M86YD('!R:6YT960N("!9;W4@8V%N(&%L<V\@<V5A<F-H(&]N('EO=7(@;F]T
M97,@=&\@;&]C871E(&EN9F]R;6%T:6]N+B`@(%-U<'!O<G0@9F]R(&EM<&]R
M=&EN9R!A;F0@97AP;W)T:6YG(&YO=&5S(&ES(&%L<V\@879A:6QA8FQE+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!5;FQI:V4@<F5A;"!S=&EC:WD@
M;F]T97,L('EO=7(@8V]M<'5T97(@;F]T97,@8V%N(&)E('-H87)E9"!W:71H
M(&]T:&5R<R!I;B!D:69F97)E;G0@<&AY<VEC86P@;&]C871I;VYS+B`@3F]T
M97,@8V%N(&)E(&]R9V%N:7IE9"!I;G1O(&1I9F9E<F5N="!N;W1E<&%D<RP@
M86YD(&%S<VEG;F5D(&-A=&5G;W)I97,N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"@H\96YT<GD@:60](FQI<W0M86-T:6]N<R(^"B`@("`\=&ET;&4^3F]T97,@
M3&ES=#H@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY!8W1I;VYS/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("`\:3Y$96QE=&4@3F]T93PO:3X@<&5R
M;6%N96YT;'D@9&5L971E<R!T:&4@<V5L96-T960@;F]T92X*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@/&D^36]D:69Y($YO=&4\+VD^(&%L;&]W<R!Y
M;W4@=&\@;6]D:69Y(&%N(&5X:7-T:6YG(&YO=&4N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@(#QI/D)A8VL@=&\@3F]T97!A9#PO:3X@=&%K97,@>6]U
M(&)A8VL@9G)O;2!N;W1E('9I97<@=&\@=&AE(&YO=&5P860@=&AA="!C;VYT
M86EN<R!T:&4@8W5R<F5N="!N;W1E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*
M/&5N=')Y(&ED/2)M96YU+6%C=&EO;G,B/@H@("`@/'1I=&QE/DUE;G4@271E
M;7,\+W1I=&QE/@H@("`@/&AE861I;F<^365N=2!)=&5M<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@/&D^3&ES="!.;W1E<SPO:3X@;&ES=',@86QL('1H
M92!N;W1E<R!I;B!T:&4@8W5R<F5N="!N;W1E<&%D+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("`\:3Y.97<@3F]T93PO:3X@86QL;W=S('EO=2!T;R!C
M<F5A=&4@82!N97<@;F]T92!I;B!T:&4@8W5R<F5N="!N;W1E<&%D+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("`\:3Y396%R8V@\+VD^(&%L;&]W<R!Y
M;W4@=&\@<V5A<F-H(&9O<B!T97AT(&EN('EO=7(@;F]T97,N("!9;W4@8V%N
M('-E87)C:"!T:&4@9&5S8W)I<'1I;VX@9FEE;&0@;VYL>2P@;W(@=&AE(&9U
M;&P@=&5X="!O9B!T:&4@;F]T97,N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@(#QI/DEM<&]R="]%>'!O<G0\+VD^(&%L;&]W<R!Y;W4@=&\@:6UP;W)T
M(&]R(&5X<&]R="!N;W1E<RX@($-U<G)E;G1L>2!#4U8*("`@(&9O<FUA='1E
M9"!A;F0@=DYO=&4@9FEL97,@87)E('-U<'!O<G1E9"X*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@/&D^4')I;G0\+VD^(&%L;&]W<R!Y;W4@=&\@<')I
M;G0@82!N;W1E+B`@5&AE(#QI/E!R:6YT/"]I/B!I8V]N<R!I<R!O;FQY(&EN
M('1H92!M96YU(&)A<B!W:&5N(&$@;F]T92!I<R!B96EN9R!V:65W960N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"@H*/&5N=')Y(&ED/2)S;W)T:6YG(CX*("`@
M(#QT:71L93Y3;W)T:6YG($5N=')I97,\+W1I=&QE/@H@("`@/&AE861I;F<^
M4V]R=&EN9R!%;G1R:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!7:&5N
M('9I97=I;F<@82!L:7-T(&]F(&5N=')I97,L('EO=2!C86X@<V]R="!T:&4@
M96YT<FEE<R!B>2!A;GD@8V]L=6UN(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R
M;W!R:6%T92!C;VQU;6X@:&5A9&EN9R!T:71L92X@(%1O('-W:71C:"!A(&-O
M;'5M;B!B971W965N(&%S8V5N9&EN9R!A;F0@9&5S8V5N9&EN9R!S;W)T:6YG
M(&]R9&5R+"!C;&EC:R!O;B!T:&4@87)R;W<@:6-O;B!I;B!T:&4@8V]L=6UN
M(&AE861I;F<N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]E<U]%
M4R\`````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-#0`,#$W-S<T`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;6YE;6\O;&]C86QE+V5S7T53+TQ#7TU%4U-!1T53+P``````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P,C$U-C$`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O97-?15,O3$-?34534T%'
M15,O;6YE;6\N;6\`````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#0P,S(W`#$P-#$W,S8R
M-S0T`#`R,S(T,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````/P'```<````_#\``*D*``#<?P```````("J```.
M````@:H```\```"0J@``#0```*"J```(````KJH```L```"WJ@``#````,.J
M```$````T*H``!@```#5J@``&P```.ZJ```M````"JL``!T````XJP``)```
M`%:K```I````>ZL``!D```"EJP``)@```+^K```,````YJL``"0```#SJP``
M"````!BL```/````(:P```L````QK```#@```#VL```%````3*P``"@```!2
MK```"````'NL```*````A*P``!4```"/K```$@```*6L```+````N*P```T`
M``#$K```'0```-*L``"%````\*P```X```!VK0``"@```(6M```-````D*T`
M``X```">K0``$0```*VM```-````OZT```P```#-K0``#0```-JM```&````
MZ*T``)0```#OK0``"@```(2N```/````CZX``!@```"?K@``#````+BN```&
M````Q:X```X```#,K@``#@```-NN```(````ZJX```D```#SK@``+@```/VN
M```:````+*\``#(```!'KP``.````'JO``!4````LZ\``%$````(L```6@``
M`%JP``!7````M;```#0````-L0``"0```$*Q```-````3+$```<```!:L0``
M"@```&*Q```/````;;$```4```!]L0``!@```(.Q```1````BK$```@```"<
ML0``"0```*6Q```)````K[$``"4```"YL0``(````-^Q```<`````+(``!X`
M```=L@``(````#RR```=````7;(``!,```![L@``$````(^R```/````H+(`
M``H```"PL@```P```+NR```/````O[(``!0```#/L@``"0```.2R```-````
M[K(``!(```#\L@``&0````^S```>````*;,```\```!(LP``#````%BS```*
M````9;,```\```!PLP``"````("S```D````B;,``!0```"NLP``%@```,.S
M```(````VK,``$X```#CLP``+0```#*T```1````8+0``!D```!RM```!P``
M`(RT```,````E+0``"P```"AM```#@```,ZT```#````W;0```L```#AM```
M!P```.VT```'````];0```4```#]M```!0````.U```*````";4```,````4
MM0``%P```!BU```*````,+4```\````[M0``#@```$NU```8````6K4``",`
M``!SM0``#@```)>U```4````IK4``!<```"[M0``%P```-.U```7````Z[4`
M`!,````#M@``#P```!>V```.````)[8``!\````VM@``'0```%:V```'````
M=+8```8```!\M@``"````(.V```/````C+8```8```"<M@``"@```*.V```3
M````KK8```L```#"M@``$````,ZV```5````W[8``!4```#UM@``!P````NW
M```0````$[<```4````DMP``%0```"JW```1````0+<```P```!2MP``.P``
M`%^W```X````F[<```D```#4MP``!P```-ZW```4````YK<```,```#[MP``
M!0```/^W```)````!;@``!`````/N```"0```""X```3````*K@``#D````^
MN```$@```'BX```G````B[@``"P```"SN```*@```."X```E````"[D```H`
M```QN0``!@```#RY```)````0[D```<```!-N0``+P```%6Y```W````A;D`
M`"X```"]N0``50```.RY```M````0KH``"T```!PN@``/0```)ZZ```_````
MW+H``"T````<NP``0````$J[```C````B[L``",```"ONP``0````-.[```M
M````%+P``#,```!"O```)0```':\```5````G+P``!D```"RO```*0```,R\
M```D````]KP``"@````;O0``%0```$2]```1````6KT```H```!LO0``#```
M`'>]```/````A+T``!<```"4O0``"@```*R]```0````M[T``!8```#(O0``
M%@```-^]```'````]KT```<```#^O0``%`````:^```*````&[X```@````F
MO@``)P```"^^```(````5[X```<```!@O@``!P```&B^```&````<+X```4`
M``!WO@``!P```'V^```&````A;X```@```",O@``*0```)6^```.````O[X`
M``H```#.O@``!````-F^```'````WKX```D```#FO@``!@```/"^```1````
M][X```<````)OP``%@```!&_```$````*+\```@````MOP``!@```#:_```-
M````/;\```8```!+OP``'@```%*_```1````<;\```@```"#OP``#0```(R_
M```,````FK\```<```"GOP```P```*^_```#````L[\``!<```"WOP```P``
M`,^_```3````T[\``!T```#GOP``"`````7````$````#L````@````3P```
M"````!S```!!````)<```!H```!GP```*P```(+````@````KL```!4```#/
MP```!@```.7````&````[,```!4```#SP```&`````G!```B````(L$``"X`
M``!%P0``'0```'3!```A````DL$``%0```"TP0``*0````G"```*````,\(`
M``<````^P@``!P```$;"```5````3L(```@```!DP@``#@```&W"```*````
M?,(```\```"'P@``#0```)?"```/````I<(```T```"UP@``"0```,/"```4
M````S<(```8```#BP@``&````.G"```=`````L,``!,````@PP``$0```#3#
M```4````1L,```0```!;PP``!@```&##```4````9\,``%0```!\PP``+0``
M`-'#``!D````_\,```0```!DQ```#@```&G$```%````>,0```4```!^Q```
M&P```(3$```:````H,0``!,```"[Q```$0```,_$```1````X<0``!P```#S
MQ```*@```!#%```W````.\4``!P```!SQ0``$````)#%```A````H<4```4`
M``##Q0``"@```,G%```3````U,4```L```#HQ0``$@```/3%```*````!\8`
M``\````2Q@``#0```"+&```1````,,8``!,```!"Q@``#````%;&```&````
M8\8```P```!JQ@``!@```'?&```7````?L8``!````"6Q@``$0```*?&```(
M````N<8```4```#"Q@``#````,C&```0````U<8```4```#FQ@``#0```.S&
M```&````^L8```<````!QP``#0````G'```'````%\<```L````?QP``!P``
M`"O'```'````,\<```D````[QP``"0```$7'```*````3\<``!D```!:QP``
M/0```'3'```=````LL<```P```#0QP``$````-W'```%````[L<``"4```#T
MQP``$@```!K(```3````+<@``"L```!!R```.P```&W(```@````J<@```@`
M``#*R```-@```-/(```A````"LD``!`````LR0``"````#W)```,````1LD`
M``8```!3R0``!````%K)```/````7\D```X```!OR0``!P```'[)```*````
MALD```T```"1R0``'P```)_)```<````O\D``"$```#<R0``'@```/[)```9
M````'<H``!X````WR@``&P```%;*```A````<LH``"X```"4R@``)@```,/*
M```<````ZLH``!X````'RP``'````";+```F````0\L``"L```!JRP``,P``
M`);+```F````RLL``"L```#QRP``.````!W,```=````5LP``!4```!TS```
M+P```(K,```@````NLP``!(```#;S```*0```.[,```>````&,T``"`````W
MS0``$@```%C-``"B````:\T``!8````.S@``(P```"7.```H````2<X``"D`
M``!RS@``*````)S.```?````Q<X``!4```#ES@``(````/O.```E````',\`
M`"@```!"SP``+0```&O/```P````F<\``)(```#*SP``(0```%W0```6````
M?]```!P```"6T```)@```+/0```J````VM```$$````%T0``1````$?1```,
M````C-$```<```"9T0``!P```*'1```&````J=$```T```"PT0``$````+[1
M```2````S]$```<```#BT0``$P```.K1```2````_M$```<````1T@``!```
M`!G2```0````'M(``!`````OT@``#````$#2```.````3=(```T```!<T@``
M#P```&K2```3````>M(```T```".T@``*````)S2```#````Q=(```T```#)
MT@``!@```-?2```1````WM(``!<```#PT@``&P````C3```.````)-,```(`
M```STP``20```#;3```%````@-,``!````"&TP``#P```)?3```$````I],`
M``T```"LTP``#@```+K3```#````R=,```X```#-TP``"````-S3```/````
MY=,```\```#UTP``!P````74```-````#=0``!`````;U```#P```"S4```-
M````/-0``!D```!*U```&@```&34```+````?]0```8```"+U```"P```)+4
M```3````GM0```P```"RU```"@```+_4```1````RM0``!D```#<U```%P``
M`/;4```+````#M4```T````:U0``(@```"C5```/````2]4``!L```!;U0``
M-````'?5```*````K-4``!@```"WU0``$@```-#5```9````X]4``!8```#]
MU0``$````!36```B````)=8```T```!(U@``!P```%;6```*````7M8``!0`
M``!IU@``"P```'[6```,````BM8``"(```"7U@``+P```+K6```+````ZM8`
M``D```#VU@``&0````#7```+````&M<``!<````FUP``%P```#[7```)````
M5M<``!8```!@UP``#P```'?7```9````A]<``!8```"AUP``#@```+C7```8
M````Q]<```@```#@UP``#0```.G7```F````]]<``"@````>V```0P```$?8
M```(````B]@``!(```"4V```'P```*?8```(````Q]@```L```#0V```+P``
M`-S8```.````#-D```4````;V0``!@```"'9``!%````*-D```,```!NV0``
M!P```'+9```$````>MD```D```!_V0``"@```(G9```*````E-D```D```"?
MV0``#P```*G9```0````N=D``!<```#*V0``&@```.+9```1````_=D``!D`
M```/V@``%P```"G:```)````0=H```4```!+V@``"P```%':```*````7=H`
M``(```!HV@``!0```&O:```-````<=H``!L```!_V@``%P```)O:```4````
ML]H```D```#(V@``"@```-+:```.````W=H```T```#LV@``$@```/K:```X
M````#=L``"````!&VP``"````&?;```.````<-L``'L```!_VP``&````/O;
M```8````%-P``!$````MW```!P```#_<```%````1]P``!@```!-W```'@``
M`&;<```;````A=P``!D```"AW```&P```+O<```9````U]P``!,```#QW```
M!P````7=```(````#=T```8````6W0``!@```!W=```0````)-T```\````U
MW0``$````$7=```/````5MT```L```!FW0``#P```'+=```,````@MT```\`
M``"/W0``!P```)_=```&````I]T```X```"NW0``#````+W=```H````RMT`
M``\```#SW0``"`````/>```&````#-X```P````3W@``"````"#>```3````
M*=X```H````]W@``'@```$C>```A````9]X``"````")W@``&0```*K>```7
M````Q-X``"4```#<W@``%P````+?```6````&M\```0````QWP``&P```#;?
M```-````4M\```P```!@WP```P```&W?```%````<=\```@```!WWP``"@``
M`(#?```,````B]\```L```"8WP``$````*3?```,````M=\```X```#"WP``
M"P```-'?```$````W=\```0```#BWP``$P```.??```4````^]\```P````0
MX```"0```!W@```.````)^````L````VX```&P```$+@```'````7N````<`
M``!FX```"@```&[@```-````>>````D```"'X```!````)'@```%````EN``
M``,```"<X```&````*#@```*````N>````0```#$X```)@```,G@```.````
M\.```'P```#_X```%0```'SA```%````DN$```<```"8X0``#````*#A```(
M````K>$```H```"VX0``!@```,'A```(````R.$```(```#1X0``!@```-3A
M```&````V^$``!0```#BX0``#0```/?A```0````!>(``!L````6X@``!```
M`#+B```)````-^(``!````!!X@``"0```%+B```)````7.(```4```!FX@``
M&@```&SB```(````A^(```8```"0X@``#P```)?B```9````I^(```X```#!
MX@``!P```-#B```'````V.(```4```#@X@``"0```.;B```*````\.(```X`
M``#[X@```@````KC```&````#>,```L````4XP``#0```"#C```)````+N,`
M``8````XXP``$@```#_C```)````4N,```<```!<XP``%````&3C```=````
M>>,``$(```"7XP``)0```-KC```E`````.0```8````FY```"@```"WD```$
M````..0```D````]Y```"````$?D```1````4.0```D```!BY```!@```&SD
M```-````<^0```8```"!Y```!````(CD```Y````C>0``#T```#'Y```.@``
M``7E```>````0.4```4```!?Y0``#@```&7E```$````=.4```8```!YY0``
M!P```(#E```A````B.4```T```"JY0``%0```+CE```&````SN4```0```#5
MY0``$0```-KE```&````[.4```H```#SY0``(@```/[E```$````(>8```4`
M```FY@``'0```"SF```$````2N8```P```!/Y@``#@```%SF```*````:^8`
M``@```!VY@``"0```'_F```%````B>8``#H```"/Y@``,````,KF```U````
M^^8``"D````QYP``1P```%OG```X````H^<``"D```#<YP``/P````;H```N
M````1N@``"T```!UZ```'P```*/H```/````P^@``!(```#3Z```"P```.;H
M```F````\N@``"D````9Z0``)````$/I```F````:.D```@```"/Z0``"@``
M`)CI```)````H^D```<```"MZ0``(````+7I```@````UND``"8```#WZ0``
M"@```![J```9````*>H``"D```!#Z@``%@```&WJ```2````A.H```<```"7
MZ@``"@```)_J```,````JNH```\```"WZ@``$````,?J``!`````V.H``'``
M```9ZP``9@```(KK```.````\>L```D`````[```"@````KL```2````%>P`
M`!,````H[```#````#SL```&````2>P``!4```!0[```#P```&;L```3````
M=NP``!(```"*[```$````)WL```1````KNP``!P```#`[```(P```-WL``!J
M`````>T```\```!L[0``!0```'SM```0````@NT```D```"3[0``!````)WM
M```+````HNT``"````"N[0``%````,_M```,````Y.T```P```#Q[0``#P``
M`/[M```5````#NX``"D````D[@``*@```$[N```F````>>X``"<```"@[@``
M*0```,CN```J````\NX``!D````=[P``0@```#?O```1````>N\``!(```",
M[P``$P```)_O```4````L^\```\```#([P``%@```-CO```7````[^\``!``
M```'\```$0```!CP```T````*O```!,```!?\```$@```'/P```U````AO``
M`!0```"\\```!P```-'P```,````V?```"````#F\```$`````?Q```4````
M&/$``!$````M\0``%P```#_Q```<````5_$``!,```!T\0``%````(CQ```:
M````G?$``!$```"X\0``&@```,KQ```>````Y?$``!H````$\@``$P```!_R
M```5````,_(``!$```!)\@``%P```%OR```4````<_(``!<```"(\@``%0``
M`*#R```)````MO(``!````#`\@``&0```-'R```$````Z_(```<```#P\@``
M"P```/CR```1````!/,```8````6\P``!@```!WS```&````)/,```4````K
M\P``!P```#'S```'````.?,```4```!!\P``%@```$?S```&````7O,```8`
M``!E\P``!````&SS```$````<?,```<```!V\P``#@```'[S```,````C?,`
M``P```":\P``#0```*?S```*````M?,```X```#`\P``!0```,_S```H````
MU?,```X```#^\P``#`````WT```/````&O0```H````J]```"````#7T```)
M````/O0``"L```!(]```!````'3T```(````>?0``"8```""]```$@```*GT
M```/````O/0```8```#,]```"@```-/T```'````WO0```@```#F]```(```
M`._T```)````$/4```T````:]0``%````"CU```,````/?4```T```!*]0``
M#@```%CU```6````9_4``!$```!^]0``!@```)#U```#````E_4```8```";
M]0``&0```*+U```'````O/4```0```#$]0``"P```,GU```+````U?4```<`
M``#A]0``!0```.GU```'````[_4``!8```#W]0``#0````[V```-````'/8`
M``H````J]@``$````#7V```/````1O8``!$```!6]@``%P```&CV```*````
M@/8``!$```"+]@``"````)WV```$````IO8```\```"K]@``.@```+OV```%
M````]O8```P```#\]@``'@````GW```.````*/<``!`````W]P``"P```$CW
M```,````5/<```D```!A]P``!P```&OW```*````<_<```D```!^]P``#@``
M`(CW```0````E_<``!L```"H]P``&````,3W```:````W?<```H```#X]P``
M"0````/X```*````#?@```P````8^```#P```"7X```(````-?@```8````^
M^```'````$7X```'````8O@```4```!J^```"P```'#X``!'````?/@```T`
M``#$^```"0```-+X```$````W/@```,```#A^```$P```.7X```3````^?@`
M`!,````-^0``"@```"'Y```"````+/D```0````O^0``)0```#3Y```#````
M6OD```4```!>^0``*@```&3Y```*````C_D```4```":^0``!````*#Y```*
M````I?D```T```"P^0``!@```+[Y```(````Q?D```@```#.^0``!````-?Y
M```%````W/D``&@```#B^0``"0```$OZ```,````5?H``!````!B^@``!0``
M`'/Z```&````>?H``!L```"`^@``+P```)SZ```0````S/H```H```#=^@``
M#P```.CZ```*````^/H```D````#^P``$P````W[```;````(?L``!@````]
M^P``%P```%;[```7````;OL``!\```"&^P``#@```*;[```#````M?L```<`
M``"Y^P``"````,'[```'````ROL```D```#2^P``"@```-S[```+````Y_L`
M``<```#S^P``40```/O[```0````3?P```P```!>_```#0```&O\```:````
M>?P``$H```"4_```&0```-_\```&````^?P``!H`````_0``)0```!O]```&
M````0?T```8```!(_0``'P```$_]```&````;_T```D```!V_0``&````(#]
M```7````F?T``"@```"Q_0``!@```-K]```-````X?T``"(```#O_0``5P``
M`!+^```3````:OX``",```!^_@``$P```*+^```"````MOX```L```"Y_@``
M"````,7^```-````SOX```H```#<_@``#````.?^```'````]/X``!0```#\
M_@``!@```!'_```(````&/\```X````A_P``!P```##_```*````./\```L`
M``!#_P``,@```$__```'````@O\```P```"*_P``#0```)?_```,````I?\`
M``D```"R_P``"0```+S_```*````QO\```<```#1_P``"0```-G_```'````
MX_\```H```#K_P``&P```/;_```/````$@`!`!(````B``$`"@```#4``0`6
M````0``!``@```!7``$`"0```&```0`0````:@`!``<```![``$`$@```(,`
M`0`$````E@`!``<```";``$`!0```*,``0`%````J0`!``L```"O``$`%```
M`+L``0`1````T``!`!H```#B``$`%@```/T``0`4````%`$!`!<````I`0$`
M&````$$!`0`<````6@$!`!D```!W`0$`!P```)$!`0`%````F0$!``T```"?
M`0$`#````*T!`0`1````N@$!``@```#,`0$`"````-4!`0`7````W@$!``L`
M``#V`0$`#`````("`0`?````#P(!`!H````O`@$`$P```$H"`0`$````7@(!
M``H```!C`@$`!````&X"`0`-````<P(!``P```"!`@$`!0```(X"`0`)````
ME`(!``4```">`@$`!P```*0"`0`%````K`(!``0```"R`@$``@```+<"`0`X
M````N@(!`"P```#S`@$`$@```"`#`0`I````,P,!`#(```!=`P$`"@```)`#
M`0`L````FP,!`"X```#(`P$`,P```/<#`0`S````*P0!`#@```!?!`$`#P``
M`)@$`0`8````J`0!`!````#!!`$`'````-($`0`/````[P0!`!,```#_!`$`
M%0```!,%`0`4````*04!`!(````^!0$`)````%$%`0`(````=@4!`"0```!_
M!0$`$P```*0%`0`4````N`4!`!4```#-!0$`+0```.,%`0`M````$08!`#$`
M```_!@$`+@```'$&`0`O````H`8!`"P```#0!@$`8@```/T&`0`3````8`<!
M``T```!T!P$`"````(('`0`7````BP<!``@```"C!P$`#````*P'`0`K````
MN0<!`"$```#E!P$`&@````<(`0`)````(@@!`$4````L"`$`00```'((`0`%
M````M`@!``0```"Z"`$`$P```+\(`0`4````TP@!``X```#H"`$`$P```/<(
M`0`8````"PD!``8````D"0$`"0```"L)`0`*````-0D!``\```!`"0$`$```
M`%`)`0`'````80D!``X```!I"0$`#0```'@)`0`,````A@D!``H```"3"0$`
M"0```)X)`0`*````J`D!``\```"S"0$`"````,,)`0`/````S`D!``@```#<
M"0$`&@```.4)`0`%``````H!``T````&"@$`&P```!0*`0`(````,`H!``8`
M```Y"@$`%````$`*`0`1````50H!``X```!G"@$`.````'8*`0`"````KPH!
M``8```"R"@$`#@```+D*`0`%````R`H!``<```#."@$`#@```-8*`0`&````
MY0H!`"@```#L"@$`#````!4+`0`<````(@L!``0````_"P$`*0```$0+`0`7
M````;@L!`!\```"&"P$`7````*8+`0`4`````PP!`#X````8#`$`'P```%<,
M`0`0````=PP!``<```"(#`$`#@```)`,`0`,````GPP!``P```"L#`$`$P``
M`+D,`0`*````S0P!`!T```#8#`$`&0```/8,`0`%````$`T!`!$````6#0$`
M$0```"@-`0`D````.@T!`!(```!?#0$`%0```'(-`0`2````B`T!``X```";
M#0$`&0```*H-`0`(````Q`T!``D```#-#0$`#0```-<-`0`'````Y0T!``H`
M``#M#0$`!P```/@-`0`/``````X!``8````0#@$`"P```!<.`0`:````(PX!
M``H````^#@$`!P```$D.`0`(````40X!``4```!:#@$`'P```&`.`0`&````
M@`X!`!````"'#@$`"````)@.`0`-````H0X!``@```"O#@$`'@```+@.`0`2
M````UPX!`"P```#J#@$`&@```!</`0`)````,@\!``H````\#P$`%0```$</
M`0`%````70\!`!0```!C#P$`!````'@/`0`0````?0\!``8```".#P$`!P``
M`)4/`0`>````G0\!`"@```"\#P$`"@```.4/`0`<````\`\!`!$````-$`$`
M"P```!\0`0`:````*Q`!`!0```!&$`$`!````%L0`0`$````8!`!``L```!E
M$`$`!0```'$0`0`&````=Q`!``@```!^$`$`!@```(<0`0`*````CA`!`!L`
M``"9$`$`-````+40`0`T````ZA`!`"`````?$0$`*0```$`1`0`@````:A$!
M`$$```"+$0$`&@```,T1`0`H````Z!$!`"D````1$@$`4````#L2`0`B````
MC!(!``8```"O$@$`"````+82`0`%````OQ(!``@```#%$@$`&0```,X2`0`9
M````Z!(!`"H````"$P$`(P```"T3`0`9````41,!`"X```!K$P$`-````)H3
M`0`(````SQ,!`!<```#8$P$`"@```/`3`0`'````^Q,!`"$````#%`$`$```
M`"44`0`.````-A0!``L```!%%`$`!P```%$4`0`3````610!``@```!M%`$`
M"P```'84`0`*````@A0!`!0```"-%`$`#P```*(4`0`R````LA0!``L```#E
M%`$`#@```/$4`0`%`````!4!``4````&%0$`!0````P5`0`7````$A4!``\`
M```J%0$`!````#H5`0`*````/Q4!``D```!*%0$`"P```%05`0`-````8!4!
M``P```!N%0$`#@```'L5`0`%````BA4!``0```"0%0$`#0```)45`0`R````
MHQ4!`!@```#6%0$`10```.\5`0`7````-18!``<```!-%@$`'@```%46`0`,
M````=!8!`!0```"!%@$`!0```)86`0`4````G!8!``8```"Q%@$`!P```+@6
M`0`.````P!8!`"H```#/%@$`!@```/H6`0`,`````1<!``\````.%P$`#0``
M`!X7`0`1````+!<!``L````^%P$`-@```$H7`0`*````@1<!`"(```",%P$`
M"P```*\7`0`/````NQ<!`#(```#+%P$`)0```/X7`0`P````)!@!`#$```!5
M&`$`+0```(<8`0`.````M1@!``4```#$&`$`#@```,H8`0`3````V1@!`!(`
M``#M&`$`!P`````9`0`1````"!D!`!,````:&0$`!P```"X9`0`4````-AD!
M`!@```!+&0$`!P```&09`0`%````;!D!``P```!R&0$`#````'\9`0`2````
MC!D!``0```"?&0$`!P```*09`0`*````K!D!``L```"W&0$`#````,,9`0`.
M````T!D!``X```#?&0$`!0```.X9`0`%````]!D!`"X```#Z&0$`)@```"D:
M`0`C````4!H!``,```!T&@$`$@```'@:`0`&````BQH!`!X```"2&@$`&```
M`+$:`0`E````RAH!``T```#P&@$`"0```/X:`0`?````"!L!``,````H&P$`
M!P```"P;`0`*````-!L!``(````_&P$`#````$(;`0`5````3QL!``L```!E
M&P$`&0```'$;`0`@````BQL!`!(```"L&P$`!0```+\;`0`*````Q1L!`!4`
M``#0&P$`$@```.8;`0`,````^1L!``0````&'`$`"0````L<`0`'````%1P!
M``P````='`$`4@```"H<`0`7````?1P!`"0```"5'`$`$@```+H<`0`'````
MS1P!``8```#5'`$`#@```-P<`0`.````ZQP!``P```#Z'`$`#`````<=`0`,
M````%!T!``T````A'0$`%0```"\=`0`2````11T!`!````!8'0$`#P```&D=
M`0`4````>1T!``H```".'0$`&P```)D=`0`0````M1T!``L```#&'0$`&P``
M`-(=`0!I````[AT!`!H```!8'@$`%P```',>`0`9````BQX!`!H```"E'@$`
M)0```,`>`0`G````YAX!`!H````.'P$`%P```"D?`0`;````01\!`!D```!=
M'P$`'P```'<?`0`4````EQ\!`!,```"L'P$`"````,`?`0`'````R1\!``@`
M``#1'P$`"0```-H?`0`5````Y!\!``T```#Z'P$`(P````@@`0`-````+"`!
M`!,````Z(`$`"````$X@`0`#````5R`!`$8```!;(`$`/P```*(@`0`W````
MXB`!`%<````:(0$`!0```'(A`0`?````>"$!`"\```"8(0$`"@```,@A`0`(
M````TR$!``T```#<(0$`+0```.HA`0`$````&"(!`!0````=(@$`3P```#(B
M`0`E````@B(!`!(```"H(@$`(````+LB`0`<````W"(!``L```#Y(@$`'P``
M``4C`0`=````)2,!`"4```!#(P$`(````&DC`0`D````BB,!`"````"O(P$`
M"P```-`C`0`'````W",!``T```#D(P$`#````/(C`0`7````_R,!``8````7
M)`$`.0```!XD`0`,````6"0!``<```!E)`$`"0```&TD`0`3````=R0!``D`
M``"+)`$`!````)4D`0`0````FB0!``@```"K)`$`"````+0D`0`$````O20!
M``L```#")`$`#````,XD`0`2````VR0!`!$```#N)`$`#``````E`0`:````
M#24!``\````H)0$`!P```#@E`0`-````0"4!`!````!.)0$`$0```%\E`0`4
M````<24!``X```"&)0$`#````)4E`0`;````HB4!`"P```"^)0$`$P```.LE
M`0`<````_R4!`"@````<)@$`!@```$4F`0`'````3"8!`!,```!4)@$`!0``
M`&@F`0`$````;B8!`!<```!S)@$`"@```(LF`0`,````EB8!``D```"C)@$`
M!@```*TF`0`)````M"8!``@```"^)@$`"0```,<F`0`*````T28!`!$```#<
M)@$`!@```.XF`0`.````]28!``X````$)P$`#0```!,G`0`+````(2<!`!T`
M```M)P$`"P```$LG`0`"````5R<!`!P```!:)P$`!P```'<G`0`&````?R<!
M`&0```"&)P$`"0```.LG`0`'````]2<!`"8```#])P$`.````"0H`0`:````
M72@!`"H```!X*`$`.P```*,H`0`8````WR@!`"@```#X*`$`-````"$I`0`9
M````5BD!`!4```!P*0$`!0```(8I`0`'````C"D!``@```"4*0$`!P```)TI
M`0`%````I2D!``<```"K*0$`#@```+,I`0`)````PBD!``8```#,*0$`"```
M`-,I`0`+````W"D!``<```#H*0$`"````/`I`0`'````^2D!`!8````!*@$`
M"0```!@J`0`&````(BH!``L````I*@$`$````#4J`0`&````1BH!`!P```!-
M*@$`%````&HJ`0`'````?RH!`!$```"'*@$`"````)DJ`0`.````HBH!``@`
M``"Q*@$`!0```+HJ`0`0````P"H!``D```#1*@$`$````-LJ`0`&````["H!
M`!D```#S*@$`"@````TK`0`<````&"L!``<````U*P$`!0```#TK`0`0````
M0RL!`!0```!4*P$`"P```&DK`0`-````=2L!`"@```"#*P$`&````*PK`0`7
M````Q2L!``0```#=*P$`"0```.(K`0`*````["L!``<```#W*P$``@```/\K
M`0`.`````BP!``@````1+`$`(P```!HL`0`?````/BP!`#@```!>+`$`)@``
M`)<L`0`Q````OBP!`"<```#P+`$`9````!@M`0`4````?2T!`%4```"2+0$`
M.````.@M`0!*````(2X!`%L```!L+@$`*````,@N`0`X````\2X!`"@````J
M+P$`+````%,O`0`F````@"\!`!L```"G+P$`/@```,,O`0"I`0```C`!`",`
M``"L,0$`%P```-`Q`0!(````Z#$!`(4````Q,@$`,````+<R`0`5````Z#(!
M`"@```#^,@$`(@```"<S`0`B````2C,!`"````!M,P$`)0```(XS`0!!````
MM#,!`%L```#V,P$`20```%(T`0`Q````G#0!`!T```#.-`$`&````.PT`0`K
M````!34!`"$````Q-0$`'P```%,U`0`K````<S4!`"8```"?-0$`)P```,8U
M`0`Z````[C4!`!T````I-@$`$0```$<V`0`S````638!`"4```"--@$`)P``
M`+,V`0`@````VS8!`!\```#\-@$`,````!PW`0!I````33<!`#$```"W-P$`
M00```.DW`0`S````*S@!`"4```!?.`$`/0```(4X`0!E````PS@!`$T````I
M.0$`+P```'<Y`0`N````ISD!`"D```#6.0$`,``````Z`0`L````,3H!`%0`
M``!>.@$`6@```+,Z`0`H````#CL!`"8````W.P$`2````%X[`0!*````ISL!
M`"L```#R.P$`'@```!X\`0`R````/3P!`"\```!P/`$`+````*`\`0`M````
MS3P!`'$```#[/`$`9@```&T]`0!O````U#T!`+,```!$/@$`%P```/@^`0`E
M````$#\!`#(````V/P$`*0```&D_`0`^````DS\!`"(```#2/P$`4@```/4_
M`0`B````2$`!`"4```!K0`$`"P```)%``0"Q````G4`!`$4```!/00$`(0``
M`)5!`0`P````MT$!`"4```#H00$`'`````Y"`0`Q````*T(!``<```!=0@$`
M!P```&5"`0`$````;4(!``T```!R0@$`"P```(!"`0`.````C$(!``L```";
M0@$`!0```*="`0`0````K4(!``(```"^0@$`60```,%"`0`%````&T,!`!(`
M```A0P$`!````#1#`0`'````.4,!``@```!!0P$`!0```$I#`0`#````4$,!
M`!````!40P$`#````&5#`0`3````<D,!``T```"&0P$``@```)1#`0`'````
MET,!``8```"?0P$`%````*9#`0`,````NT,!`!@```#(0P$`!@```.%#`0`2
M````Z$,!``P```#[0P$``P````A$`0`J````#$0!``0````W1`$`!@```#Q$
M`0`'````0T0!`!\```!+1`$`-0```&M$`0`N````H40!`"\```#01`$`%P``
M``!%`0`B````&$4!`"4````[10$`(````&%%`0`;````@D4!`!@```">10$`
M)````+=%`0`?````W$4!`!H```#\10$`(0```!=&`0`@````.48!`!H```!:
M1@$`,@```'5&`0`9````J$8!`!H```#"1@$`+P```-U&`0`K````#4<!`!\`
M```Y1P$`(P```%E'`0`?````?4<!`!H```"=1P$`(0```+A'`0`E````VD<!
M`"8`````2`$`)0```"=(`0`D````34@!`!@```!R2`$`'0```(M(`0`D````
MJ4@!`!@```#.2`$`(@```.=(`0`L````"DD!`"\````W20$`%0```&=)`0`E
M````?4D!`#P```"C20$`'P```.!)`0`C`````$H!`!\````D2@$`(````$1*
M`0`:````94H!`!@```"`2@$`)@```)E*`0`>````P$H!`"D```#?2@$`'@``
M``E+`0`Q````*$L!``D```!:2P$`#````&1+`0`,````<4L!`!<```!^2P$`
M+P```)9+`0`D````QDL!``<```#K2P$`#P```/-+`0`4`````TP!``X````8
M3`$`#0```"=,`0`D````-4P!``4```!:3`$`!P```&!,`0`B````:$P!`"4`
M``"+3`$`&@```+%,`0`=````S$P!`!H```#J3`$`!P````5-`0#'````#4T!
M``L```#530$`'````.%-`0`5````_DT!``8````43@$`"0```!M.`0`+````
M)4X!``T````Q3@$`%P```#].`0`&````5TX!`#,```!>3@$`$P```)).`0`3
M````IDX!``<```"Z3@$`#P```,).`0`'````TDX!`#(```#:3@$`!`````U/
M`0`A````$D\!`!,````T3P$`#````$A/`0`1````54\!`#(```!G3P$`%@``
M`)I/`0`(````L4\!`!T```"Z3P$`"0```-A/`0`*````XD\!`!0```#M3P$`
M"@````)0`0`=````#5`!``@````K4`$`'P```#10`0`(````5%`!`!H```!=
M4`$`)P```'A0`0`&````H%`!`!4```"G4`$`!P```+U0`0`(````Q5`!``D`
M``#.4`$`/P```-A0`0`'````&%$!``\````@40$`#@```#!1`0`0````/U$!
M``D```!040$`"0```%I1`0`(````9%$!`!,```!M40$`!P```(%1`0`9````
MB5$!``H```"C40$`%P```*Y1`0`4````QE$!``H```#;40$`#````.91`0`7
M````\U$!``0````+4@$`*@```!!2`0`,````.U(!`!$```!(4@$`!P```%I2
M`0`"````8E(!`!````!E4@$`&````'92`0`+````CU(!``,```";4@$`"```
M`)]2`0`&````J%(!``<```"O4@$`#0```+=2`0`+````Q5(!`!0```#14@$`
M%0```.92`0`.````_%(!`"\````+4P$`(````#M3`0`<````7%,!`!4```!Y
M4P$`*P```(]3`0`,````NU,!`#$```#(4P$`!0```/I3`0`2`````%0!`#\`
M```35`$`$@```%-4`0`*````9E0!``8```!Q5`$`!````'A4`0`$````?50!
M``H```""5`$`$P```(U4`0`%````H50!``8```"G5`$`!@```*Y4`0`(````
MM50!``0```"^5`$`#````,-4`0`*````T%0!`#D```#;5`$`+@```!55`0`I
M````1%4!``4```!N50$`&````'15`0`9````C54!`!\```"G50$`'0```,=5
M`0`1````Y54!``(```#W50$`!````/I5`0`*````_U4!``8````*5@$`!0``
M`!%6`0`#````%U8!``P````;5@$`10```"A6`0`R````;E8!`#$```"A5@$`
M&@```--6`0`T````[E8!`"@````C5P$`4P```$Q7`0`R````H%<!`!D```#3
M5P$`<@```.U7`0`@````8%@!`#4```"!6`$`(0```+=8`0!%````V5@!`#``
M```?60$`*````%!9`0`H````>5D!`"D```"B60$`)@```,Q9`0`E````\UD!
M`"@````96@$`*````$):`0`B````:UH!`"L```".6@$`,````+I:`0`2````
MZUH!`!,```#^6@$`$````!);`0!Y````(UL!``D```"=6P$`H0```*=;`0!S
M````25P!`'P```"]7`$`*P```#I=`0!4````9ET!`!<```"[70$`)P```--=
M`0`6````^UT!`!4````27@$`#P```"A>`0`7````.%X!`!\```!07@$`#@``
M`'!>`0!`````?UX!`!\```#`7@$`'````.!>`0!1````_5X!`!H```!/7P$`
M%````&I?`0`*````?U\!``4```"*7P$`!@```)!?`0`(````EU\!``4```"@
M7P$`$@```*9?`0`0````N5\!`!,```#*7P$`'0```-Y?`0`/````_%\!``\`
M```,8`$`$````!Q@`0`$````+6`!``D````R8`$`"0```#Q@`0`'````1F`!
M``L```!.8`$`!0```%I@`0`+````8&`!``<```!L8`$`!0```'1@`0`4````
M>F`!``X```"/8`$`"P```)Y@`0`'````JF`!``@```"R8`$`#P```+M@`0`,
M````RV`!``D```#88`$`"````.)@`0`,````ZV`!``8```#X8`$`#P```/]@
M`0`'````#V$!``8````780$`%````!YA`0`&````,V$!``P````Z80$`$0``
M`$=A`0`(````66$!``0```!B80$`&0```&=A`0`1````@6$!``H```"380$`
M&````)YA`0`3````MV$!`!P```#+80$`$0```.AA`0`$````^F$!``\```#_
M80$`!P````]B`0`$````%V(!`!D````<8@$`!P```#9B`0`"````/F(!``(`
M``!!8@$`$0```$1B`0`)````5F(!``8```!@8@$`$@```&=B`0`7````>F(!
M``8```"28@$`)P```)EB`0`"````P6(!``0```#$8@$`#P```,EB`0`3````
MV6(!``<```#M8@$`"0```/5B`0`'````_V(!`!$````'8P$`!@```!EC`0`8
M````(&,!``8````Y8P$`$P```$!C`0`0````5&,!`!(```!E8P$``@```'AC
M`0`&````>V,!``P```""8P$`"0```(]C`0`1````F6,!`"(```"K8P$`!P``
M`,YC`0`'````UF,!``L```#>8P$`!0```.IC`0`%````\&,!``(```#V8P$`
M"P```/EC`0!]`0``!60!``\```"#90$`$@```)-E`0`-````IF4!``8```"T
M90$`"0```+ME`0`'````Q64!``,```#-90$`&0```-%E`0`?````ZV4!`#(`
M```+9@$`+P```#YF`0`H````;F8!`"T```"79@$`&0```,5F`0`K````WV8!
M``H````+9P$`+@```!9G`0`(````16<!`!8```!.9P$`"@```&5G`0`4````
M<&<!``4```"%9P$`+@```(MG`0`3````NF<!``L```#.9P$`&@```-IG`0`-
M````]6<!``X````#:`$`#0```!)H`0`P````(&@!`)D```!1:`$`#0```.MH
M`0`*````^6@!`!<````$:0$`#@```!QI`0`1````*VD!``P````]:0$`#0``
M`$II`0`,````6&D!``8```!E:0$`G0```&QI`0`*````"FH!``\````5:@$`
M%0```"5J`0`1````.VH!``8```!-:@$`$P```%1J`0`3````:&H!``@```!\
M:@$`"0```(5J`0`V````CVH!`"0```#&:@$`.````.MJ`0!#````)&L!`&4`
M``!H:P$`8@```,YK`0!K````,6P!`&@```"=;`$`.@````9M`0`/````06T!
M`!4```!1;0$`#@```&=M`0`3````=FT!`!D```"*;0$`!0```*1M`0`)````
MJFT!`!$```"T;0$`#````,9M`0`-````TVT!``T```#A;0$`-````.]M`0`Q
M````)&X!`"\```!6;@$`,````(9N`0`T````MVX!`#$```#L;@$`"0```!YO
M`0`4````*&\!`!0````];P$`#````%)O`0`&````7V\!`!D```!F;P$`'@``
M`(!O`0`,````GV\!``P```"L;P$`$0```+EO`0`C````RV\!`"@```#O;P$`
M$@```!AP`0`0````*W`!``X````\<`$`#P```$MP`0`*````6W`!`"\```!F
M<`$`&0```)9P`0`9````L'`!``X```#*<`$`7````-EP`0`Z````-G$!`!(`
M``!Q<0$`*@```(1Q`0`)````KW$!``L```"Y<0$`-````,5Q`0`.````^G$!
M``@````)<@$`"@```!)R`0`'````'7(!``<````E<@$`!0```"UR`0`'````
M,W(!``L````[<@$`!0```$=R`0`A````37(!`!````!O<@$`%0```(!R`0`/
M````EG(!`!L```"F<@$`-````,)R`0`)````]W(!`!<````!<P$`%@```!ES
M`0`8````,',!`"$```!)<P$`%P```&MS`0`1````@W,!``\```"5<P$`'P``
M`*5S`0`E````Q7,!``<```#K<P$`!@```/-S`0`'````^G,!``T````"=`$`
M"0```!!T`0`)````&G0!`!(````D=`$`"@```#=T`0`5````0G0!`!D```!8
M=`$`+````')T`0`'````GW0!`!$```"G=`$`!0```+ET`0`6````OW0!`!(`
M``#6=`$`$@```.ET`0`^````_'0!`#X````[=0$`"0```'IU`0`'````A'4!
M`!,```",=0$`!````*!U`0`%````I74!``H```"K=0$`#@```+9U`0`.````
MQ74!`!<```#4=0$`1P```.QU`0`6````-'8!`"8```!+=@$`*P```')V`0`L
M````GG8!`#0```#+=@$`"0````!W`0`&````"G<!``D````1=P$`!P```!MW
M`0`X````(W<!`#H```!<=P$`-P```)=W`0!<````SW<!`#8````L>`$`-@``
M`&-X`0!'````FG@!`$L```#B>`$`-@```"YY`0!.````97D!`"P```"T>0$`
M+@```.%Y`0!-````$'H!`#8```!>>@$`/````)5Z`0`N````TGH!`!@````!
M>P$`'````!I[`0`S````-WL!`"T```!K>P$`+0```)E[`0`7````QWL!`!,`
M``#?>P$`"@```/-[`0`,````_GL!`!4````+?`$`(0```"%\`0`%````0WP!
M``X```!)?`$`'P```%A\`0`F````>'P!``<```"??`$`!P```*=\`0`5````
MKWP!``H```#%?`$`"````-!\`0`S````V7P!``H````-?0$`!P```!A]`0`'
M````('T!``8````H?0$`!0```"]]`0`(````-7T!``8````^?0$`"@```$5]
M`0`T````4'T!`!(```"%?0$`#@```)A]`0`'````IWT!``<```"O?0$`"@``
M`+=]`0`%````PGT!`!$```#(?0$`!@```-I]`0`2````X7T!``4```#T?0$`
M"````/I]`0`(`````WX!``X````,?@$`!@```!M^`0`I````(GX!`!$```!,
M?@$`"````%Y^`0`1````9WX!``P```!Y?@$`!P```(9^`0`#````CGX!``,`
M``"2?@$`&@```)9^`0`#````L7X!`!@```"U?@$`*@```,Y^`0`&````^7X!
M``4`````?P$`!P````9_`0`'````#G\!`&4````6?P$`)P```'Q_`0`X````
MI'\!`"D```#=?P$`(@````>``0`&````*H`!``@````Q@`$`'0```#J``0`E
M````6(`!`"<```!^@`$`-````*:``0`H````VX`!`"T````$@0$`8@```#*!
M`0`V````E8$!``H```#,@0$`"0```->!`0`)````X8$!`!8```#K@0$`"0``
M``*"`0`,````#((!``X````9@@$`%````"B"`0`0````/8(!`!0```!.@@$`
M$P```&."`0`.````=X(!`!4```"&@@$`!P```)R"`0`8````I((!`!L```"]
M@@$`&````-F"`0`;````\H(!`!D````.@P$`!````"B#`0`'````+8,!`!0`
M```U@P$`6````$J#`0`X````HX,!`'(```#<@P$`!P```$^$`0`5````5X0!
M``4```!MA`$`!0```'.$`0`;````>80!`!@```"5A`$`"P```*Z$`0`4````
MNH0!`!H```#/A`$`'@```.J$`0`[````"84!`#L```!%A0$`'0```(&%`0`.
M````GX4!`"P```"NA0$`!P```-N%`0`2````XX4!`!L```#VA0$`#P```!*&
M`0`2````(H8!``X````UA@$`&````$2&`0`0````788!`!8```!NA@$`$P``
M`(6&`0`.````F88!``4```"HA@$`#P```*Z&`0`&````OH8!`!@```#%A@$`
M%0```-Z&`0`/````](8!``@````$AP$`!0````V'`0`1````$X<!`!(````E
MAP$`"0```#B'`0`7````0H<!``8```!:AP$`!P```&&'`0`1````:8<!``H`
M``![AP$`#````(:'`0`'````DX<!``@```";AP$`"P```*2'`0`)````L(<!
M``L```"ZAP$`'P```,:'`0!)````YH<!`"4````PB`$`#0```%:(`0`4````
M9(@!``4```!YB`$`(````'^(`0`2````H(@!`!,```"SB`$`.@```,>(`0!*
M`````HD!`"<```!-B0$`"0```'6)`0`\````?XD!`"H```"\B0$`$0```.>)
M`0`)````^8D!``H````#B@$`!@````Z*`0`&````%8H!`!(````<B@$`$```
M`"^*`0`+````0(H!``H```!,B@$`#P```%>*`0`L````9XH!`"P```"4B@$`
M+0```,&*`0`N````[XH!`"(````>BP$`)0```$&+`0`B````9XL!`"8```"*
MBP$`-@```+&+`0`N````Z(L!`"8````7C`$`*````#Z,`0`D````9XP!`#$`
M``",C`$`10```+Z,`0!`````!(T!`#4```!%C0$`-````'N-`0`^````L(T!
M`"8```#OC0$`)0```!:.`0`\````/(X!`"4```!YC@$`%0```)^.`0`Y````
MM8X!`"4```#OC@$`)P```!6/`0`4````/8\!`,H```!2CP$`&P```!V0`0`Q
M````.9`!`#````!KD`$`,P```)R0`0`Q````T)`!`"<````"D0$`*````"J1
M`0`K````4Y$!`#(```!_D0$`-0```+*1`0!+````Z)$!`#0````TD@$`I```
M`&F2`0`G````#I,!`!T````VDP$`)@```%23`0`S````>Y,!`#$```"ODP$`
M3@```.&3`0!5````,)0!``T```"&E`$`!````)24`0`&````F90!``4```"@
ME`$`#P```*:4`0`%````MI0!`!$```"\E`$`!@```,Z4`0`6````U90!`!P`
M``#LE`$`!P````F5`0`$````$94!`!`````6E0$`$0```">5`0`+````.94!
M``H```!%E0$`$0```%"5`0`-````8I4!`!(```!PE0$`#0```(.5`0`Z````
MD94!``8```#,E0$`$````-.5`0`&````Y)4!`!$```#KE0$`%P```/V5`0`;
M````%98!``\````QE@$``@```$&6`0!)````1)8!``L```".E@$`#````)J6
M`0`<````IY8!``4```#$E@$`%P```,J6`0`2````XI8!``,```#UE@$`$0``
M`/F6`0`)````"Y<!`!$````5EP$`$````">7`0`+````.)<!`!$```!$EP$`
M%0```%:7`0`4````;)<!`!$```"!EP$`)@```).7`0`E````NI<!``P```#@
MEP$`"````.V7`0`.````]I<!`!L````%F`$`#@```"&8`0`1````,)@!`!,`
M``!"F`$`&@```%:8`0`A````<9@!``X```"3F`$`$````**8`0`K````LY@!
M`!$```#?F`$`'````/&8`0!$````#ID!``T```!3F0$`'P```&&9`0`4````
M@9D!`!D```"6F0$`%@```+"9`0`-````QYD!`$,```#5F0$`$````!F:`0`)
M````*IH!``L````TF@$`%````$":`0`+````59H!``P```!AF@$`-@```&Z:
M`0`U````I9H!``H```#;F@$`%0```.::`0`I````_)H!`!<````FFP$`%@``
M`#Z;`0`6````59L!``H```!LFP$`(````'>;`0`9````F)L!`!P```"RFP$`
M&````,^;`0`9````Z)L!`!@````"G`$`"````!N<`0`+````))P!`"D````P
MG`$`,````%J<`0!8````BYP!``@```#DG`$`%````.V<`0`B`````IT!``D`
M```EG0$`#````"^=`0`V````/)T!`!$```!SG0$`!@```(6=`0`&````C)T!
M`%4```"3G0$``P```.F=`0`'````[9T!``D```#UG0$`#@```/^=`0`0````
M#IX!``\````?G@$`#@```"^>`0`4````/IX!`!4```!3G@$`&P```&F>`0`F
M````A9X!`!8```"LG@$`'0```,.>`0`;````X9X!``D```#]G@$`!@````>?
M`0`+````#I\!``L````:GP$``@```":?`0`&````*9\!`!,````PGP$`+P``
M`$2?`0`7````=)\!`!4```",GP$`"@```**?`0`+````K9\!`!$```"YGP$`
M%````,N?`0`<````X)\!`#D```#]GP$`-P```#>@`0`2````;Z`!``\```""
MH`$`A@```)*@`0`C````&:$!`"`````]H0$`$0```%ZA`0`'````<*$!``4`
M``!XH0$`'````'ZA`0`M````FZ$!`#,```#)H0$`'P```/VA`0`E````':(!
M`!\```!#H@$`%P```&.B`0`'````>Z(!``<```"#H@$`!@```(NB`0`&````
MDJ(!``\```"9H@$`#@```*FB`0`0````N*(!``X```#)H@$`%0```-BB`0`/
M````[J(!``L```#^H@$`$P````JC`0`(````'J,!``@````GHP$`%0```#"C
M`0`/````1J,!`$4```!6HP$`%````)RC`0`)````L:,!``@```"[HP$`#@``
M`,2C`0`.````TZ,!`!\```#BHP$`#P````*D`0`@````$J0!`"<````SI`$`
M)@```%ND`0`8````@J0!`!<```";I`$`(````+.D`0`8````U*0!`!8```#M
MI`$`"0````2E`0`9````#J4!``L````HI0$`%````#2E`0`#````2:4!``4`
M``!-I0$`!P```%.E`0`.````6Z4!`!````!JI0$`#0```'NE`0`8````B:4!
M`!````"BI0$`$0```+.E`0`/````Q:4!``0```#5I0$`!P```-JE`0`:````
MXJ4!`!L```#]I0$`"````!FF`0`1````(J8!`!0````TI@$`#@```$FF`0`G
M````6*8!``<```"`I@$`"0```(BF`0`0````DJ8!`!````"CI@$`"@```+2F
M`0`'````OZ8!``L```#'I@$`!@```-.F`0`8````VJ8!``X```#SI@$`!@``
M``*G`0`H````":<!`!`````RIP$`FP```$.G`0`;````WZ<!``L```#[IP$`
M!P````>H`0`/````#Z@!``@````?J`$`"@```"BH`0`%````,Z@!``@````Y
MJ`$``P```$*H`0`&````1J@!``<```!-J`$`%@```%6H`0`0````;*@!`!(`
M``!]J`$`'0```)"H`0`"````KJ@!``0```"QJ`$`%````+:H`0`*````RZ@!
M``\```#6J`$`!0```.:H`0`C````[*@!``@````0J0$`!@```!FI`0`2````
M(*D!`!L````SJ0$`#P```$^I`0`'````7ZD!``@```!GJ0$`!0```'"I`0`)
M````=JD!``\```"`J0$`$0```)"I`0`"````HJD!``8```"EJ0$`#P```*RI
M`0`2````O*D!`!````#/J0$`!@```."I`0`3````YZD!``L```#[J0$`!P``
M``>J`0`8````#ZH!`#`````HJ@$`30```%FJ`0`K````IZH!`"T```#3J@$`
M!@````&K`0`)````"*L!``0````2JP$`"0```!>K`0`)````(:L!`!<````K
MJP$`#````$.K`0`&````4*L!``T```!7JP$`!P```&6K`0`$````;:L!`$$`
M``!RJP$`2````+2K`0!!````_:L!`"<````_K`$`!0```&>L`0`-````;:P!
M``<```![K`$`"````(.L`0`)````C*P!`!L```"6K`$`&0```+*L`0`5````
MS*P!``8```#BK`$`!0```.FL`0`0````[ZP!``@`````K0$`"@````FM`0`C
M````%*T!``0````XK0$`!P```#VM`0`G````1:T!``8```!MK0$`"0```'2M
M`0`3````?JT!`!,```"2K0$`"````*:M`0`)````KZT!``4```"YK0$`1P``
M`+^M`0`T````!ZX!`$$````\K@$`,@```'ZN`0!)````L:X!`#L```#[K@$`
M+````#>O`0`^````9*\!`"\```"CKP$`/0```-.O`0`Q````$;`!`!````!#
ML`$`$0```%2P`0`+````9K`!`#(```!RL`$`(0```*6P`0`?````Q[`!`!X`
M``#GL`$`!P````:Q`0`)````#K$!``H````8L0$`!P```".Q`0`I````*[$!
M`"P```!5L0$`/0```(*Q`0`,````P+$!`",```#-L0$`-@```/&Q`0`6````
M*+(!`!4````_L@$`"````%6R`0`+````7K(!``P```!JL@$`$````'>R`0`7
M````B+(!`$4```"@L@$`?````.:R`0!G````8[,!``T```#+LP$`$````-FS
M`0`1````ZK,!`!0```#\LP$`%0```!&T`0`7````)[0!``@````_M`$`%P``
M`$BT`0`1````8+0!`!<```!RM`$`$P```(JT`0`2````GK0!`!4```"QM`$`
M+@```,>T`0`M````]K0!`)<````DM0$`$0```+RU`0`%````SK4!`!4```#4
MM0$`"0```.JU`0`+````]+4!``L`````M@$`)0````RV`0`8````,K8!``\`
M``!+M@$`#@```%NV`0`4````:K8!`!D```!_M@$`+0```)FV`0`N````Q[8!
M`"H```#VM@$`*@```"&W`0`F````3+<!`"@```!SMP$`'@```)RW`0!!````
MN[<!`!4```#]MP$`%````!.X`0`7````*+@!`!8```!`N`$`$0```%>X`0`7
M````:;@!`!8```"!N`$`%````)BX`0`4````K;@!`#L```#"N`$`&0```/ZX
M`0`:````&+D!`#H````SN0$`$P```&ZY`0`&````@KD!`!````")N0$`+0``
M`)JY`0`4````R+D!`!4```#=N0$`%0```/.Y`0`@````";H!`!X````JN@$`
M'````$FZ`0`<````9KH!`"<```"#N@$`$P```*NZ`0`@````O[H!`"8```#@
MN@$`(`````>[`0`9````*+L!`!T```!"NP$`%````&"[`0`<````=;L!`!P`
M``"2NP$`(0```*^[`0`9````T;L!``H```#KNP$`$@```/:[`0`;````";P!
M``0````EO`$`!P```"J\`0`+````,KP!`!(````^O`$`!@```%&\`0`&````
M6+P!``<```!?O`$`!@```&>\`0`'````;KP!``4```!VO`$`!0```'R\`0`5
M````@KP!``8```"8O`$`!@```)^\`0`%````IKP!``4```"LO`$`"@```+*\
M`0`1````O;P!``H```#/O`$`%@```-J\`0`4````\;P!``H````&O0$`%P``
M`!&]`0`%````*;T!`#4````OO0$`$@```&6]`0`1````>+T!`!H```"*O0$`
M#P```*6]`0`-````M;T!`!````##O0$`-````-2]`0`%````";X!``@````/
MO@$`)P```!B^`0`3````0+X!`!````!4O@$`!@```&6^`0`*````;+X!``T`
M``!WO@$`!@```(6^`0`B````C+X!`!````"OO@$`$P```,"^`0`;````U+X!
M`!````#PO@$`%0````&_`0`1````%[\!`!H````IOP$`%````$2_`0`&````
M6;\!``4```!@OP$`#````&:_`0`F````<[\!``<```":OP$`"0```**_`0`2
M````K+\!`!<```"_OP$`!P```->_`0`%````W[\!``<```#EOP$`%@```.V_
M`0`-````!,`!``\````2P`$`#0```"+``0`6````,,`!`!@```!'P`$`#P``
M`&#``0`1````<,`!``P```""P`$`&````(_``0`,````J,`!``<```"UP`$`
M%````+W``0!"````TL`!``@````5P0$`#````![!`0`M````*\$!`!4```!9
MP0$`%0```&_!`0`-````A<$!``P```"3P0$`"0```*#!`0`'````JL$!``H`
M``"RP0$`"0```+W!`0`.````Q\$!`!````#6P0$`*0```.?!`0`E````$<(!
M`"H````WP@$`"@```&+"`0`(````;<(!``H```!VP@$`#````('"`0`-````
MCL(!``D```"<P@$`#@```*;"`0`U````M<(!``4```#KP@$`#@```/'"`0`:
M`````,,!`%T````;PP$`&@```'G#`0`.````E,,!``0```"CPP$`!````*C#
M`0`:````K<,!`!H```#(PP$`&@```./#`0`*````_L,!``(````)Q`$`!```
M``S$`0`E````$<0!``,````WQ`$`!0```#O$`0`I````0<0!``H```!KQ`$`
M!0```';$`0`&````?,0!``L```"#Q`$`$0```(_$`0`&````H<0!``<```"H
MQ`$`"````+#$`0`$````N<0!``4```"^Q`$`:P```,3$`0`*````,,4!``T`
M```[Q0$`'0```$G%`0`%````9\4!``8```!MQ0$`*0```'3%`0`V````GL4!
M``X```#5Q0$`"0```.3%`0`3````[L4!``H````"Q@$`"`````W&`0`7````
M%L8!`#@````NQ@$`'P```&?&`0`>````A\8!`!8```"FQ@$`(P```+W&`0`/
M````X<8!``0```#QQ@$`!P```/;&`0`(````_L8!``@````'QP$`$````!#'
M`0`1````(<<!``\````SQP$`!P```$/'`0!A````2\<!`!$```"MQP$`#P``
M`+_'`0`/````S\<!`!L```#?QP$`40```/O'`0`<````3<@!``8```!JR`$`
M'P```''(`0`F````D<@!``<```"XR`$`!@```,#(`0`@````Q\@!``@```#H
MR`$`"0```/'(`0`A````^\@!`"`````=R0$`/````#[)`0`(````>\D!``H`
M``"$R0$`)P```(_)`0!4````M\D!`!L````,R@$`'P```"C*`0`:````2,H!
M``,```!CR@$`#````&?*`0`(````=,H!`!D```!]R@$`#0```)?*`0`.````
MI<H!``8```"TR@$`%@```+O*`0`&````TLH!``@```#9R@$`"0```.+*`0`,
M````[,H!``H```#YR@$`$`````3+`0!!````%<L!``D```!7RP$`&@```&'+
M`0`7````?,L!`!@```"4RP$`%0```*W+`0`8````P\L!`!8```#<RP$`%@``
M`//+`0`5````"LP!`!8````@S`$`"@```#?,`0`?````0LP!`!````!BS`$`
M$@```'/,`0`)````ALP!``P```"0S`$`"0```)W,`0`)````I\P!`!D```"Q
MS`$`!P```,O,`0`7````T\P!``8```#KS`$`!P```/+,`0`%````^LP!``4`
M````S0$`!P````;-`0`3````#LT!`!0````BS0$`(@```#?-`0`B````6LT!
M`!T```!]S0$`'````)O-`0`B````N,T!`"8```#;S0$`'P````+.`0`#````
M(LX!``4````FS@$`#P```"S.`0`/````/,X!`!,```!,S@$`"@```&#.`0`*
M````:\X!`"(```!VS@$`#0```)G.`0`0````I\X!`",```"XS@$`'0```-S.
M`0`6````^LX!``@````1SP$`#@```!K/`0`)````*<\!`!`````SSP$`$P``
M`$3/`0`*````6,\!``D```!CSP$`!0```&W/`0`'````<\\!``4```![SP$`
M!````('/`0`"````AL\!`#<```")SP$`.P```,'/`0`9````_<\!`"8````7
MT`$`1@```#[0`0`,````A=`!`#0```"2T`$`.P```,?0`0!$`````]$!`$0`
M``!(T0$`3````(W1`0`/````VM$!`"````#JT0$`'P````O2`0`E````*](!
M`!P```!1T@$`'P```&[2`0`?````CM(!`"````"NT@$`(````,_2`0`L````
M\-(!``D````=TP$`-@```"?3`0`2````7M,!`"````!QTP$`#````)+3`0!!
M````G],!`$$```#ATP$`10```"/4`0!&````:=0!`$,```"PU`$`0````/34
M`0!Y````-=4!`!4```"OU0$`$````,75`0`)````UM4!`",```#@U0$`!P``
M``36`0`4````#-8!`#H````AU@$`.````%S6`0`D````E=8!``L```"ZU@$`
M4P```,;6`0!*````&M<!``4```!EUP$`!P```&O7`0`7````<]<!`!4```"+
MUP$`#P```*'7`0`0````L=<!`!@```#"UP$`!P```-O7`0`*````X]<!``@`
M``#NUP$`$P```/?7`0`0````"]@!``X````<V`$`$@```"O8`0`4````/M@!
M`!,```!3V`$`$````&?8`0`0````>-@!`!$```")V`$`%P```)O8`0`(````
ML]@!`!4```"\V`$`"````-+8`0`H````V]@!``4````$V0$`$`````K9`0`D
M````&]D!``D```!`V0$`!@```$K9`0`4````4=D!`!(```!FV0$`#P```'G9
M`0!(````B=D!``<```#2V0$`!@```-K9`0`2````X=D!``4```#TV0$`!P``
M`/K9`0`/`````MH!``<````2V@$`-0```!K:`0`2````4-H!`"4```!CV@$`
M!````(G:`0`[````CMH!``X```#*V@$`*````-G:`0"'`````ML!`!H```"*
MVP$`10```*7;`0`G````Z]L!`!$````3W`$`"````"7<`0`.````+MP!``X`
M```]W`$`#````$S<`0`3````6=P!``P```!MW`$`(````'K<`0`<````F]P!
M``0```"XW`$`$````+W<`0`;````SMP!`"H```#JW`$`%0```!7=`0`1````
M*]T!`!8````]W0$`$0```%3=`0`?````9MT!``H```"&W0$`#````)'=`0`3
M````GMT!`!$```"RW0$`%P```,3=`0`0````W-T!`!P```#MW0$`#@````K>
M`0`5````&=X!`"(````OW@$`#0```%+>`0`&````8-X!``@```!GW@$`!0``
M`'#>`0`@````=MX!``8```"7W@$`$@```)[>`0`(````L=X!`!,```"ZW@$`
M"@```,[>`0`H````V=X!`!4````"WP$`00```!C?`0`;````6M\!``L```!V
MWP$`#````(+?`0`E````C]\!``4```"UWP$`%@```+O?`0`#````TM\!`!$`
M``#6WP$`!0```.C?`0`*````[M\!`"4```#YWP$`.0```!_@`0`*````6>`!
M`"8```!DX`$`$````(O@`0`+````G.`!`!T```"HX`$`%````,;@`0`$````
MV^`!``@```#@X`$`"0```.G@`0`(````\^`!``L```#\X`$`"`````CA`0`'
M````$>$!``<````9X0$`$@```"'A`0`J````-.$!`#<```!?X0$`&P```)?A
M`0`K````L^$!`",```#?X0$`00````/B`0`;````1>(!`"0```!AX@$`+0``
M`(;B`0!,````M.(!`"@````!XP$`!P```"KC`0`(````,N,!``D````[XP$`
M"````$7C`0`5````3N,!`!0```!DXP$`+````'GC`0`O````IN,!`"(```#6
MXP$`-P```/GC`0`_````,>0!``<```!QY`$`&@```'GD`0`)````E.0!``P`
M``">Y`$`+@```*OD`0`3````VN0!`!(```#NY`$`#0````'E`0`+````#^4!
M`!@````;Y0$`"0```#3E`0`2````/N4!`!$```!1Y0$`&@```&/E`0`<````
M?N4!`#D```";Y0$`"P```-7E`0`0````X>4!``4```#RY0$`"````/CE`0`%
M`````>8!`!H````'Y@$`#P```"+F`0`&````,N8!``\````YY@$`$0```$GF
M`0`(````6^8!``X```!DY@$`#@```'/F`0`3````@N8!``4```"6Y@$`$```
M`)SF`0`-````K>8!`#P```"[Y@$`)````/CF`0!2````'><!`"(```!PYP$`
M"@```)/G`0`G````GN<!`!````#&YP$`&P```-?G`0`%````\^<!`!<```#Y
MYP$`"0```!'H`0`-````&^@!`!(````IZ`$`*@```#SH`0`&````9^@!``T`
M``!NZ`$`$````'SH`0`.````C>@!`!````"<Z`$`"@```*WH`0`]````N.@!
M``D```#VZ`$`(`````#I`0`0````(>D!`!0````RZ0$`0````$?I`0`F````
MB.D!`$(```"OZ0$`0P```/+I`0`\````-NH!``\```!SZ@$`!P```(/J`0`2
M````B^H!`!(```">Z@$`&0```+'J`0`*````R^H!`!,```#6Z@$`&P```.KJ
M`0`'````!NL!`!<````.ZP$`*````";K`0`&````3^L!``<```!6ZP$`$```
M`%[K`0`5````;^L!`!<```"%ZP$`!P```)WK`0`'````I>L!``D```"MZP$`
M%````+?K`0`2````S.L!`!,```#?ZP$`$P```//K`0`&````!^P!``4````.
M[`$`,0```!3L`0`H````1NP!`"4```!O[`$`"````)7L`0`/````GNP!``8`
M``"N[`$`&@```+7L`0`9````T.P!`"L```#J[`$`"0```!;M`0`,````(.T!
M`"<````M[0$``P```%7M`0`%````6>T!``T```!?[0$``P```&WM`0`,````
M<>T!`!,```!^[0$`"P```)+M`0`7````GNT!`!@```"V[0$`$P```,_M`0`%
M````X^T!``H```#I[0$`%@```/3M`0`5````"^X!``X````A[@$`!P```##N
M`0`,````..X!``H```!%[@$`$````%#N`0!=````8>X!`"8```"_[@$`/```
M`.;N`0`2````(^\!``<````V[P$`!@```#[O`0`+````1>\!`!D```!1[P$`
M%0```&OO`0`-````@>\!`!0```"/[P$`%````*3O`0`<````N>\!`!\```#6
M[P$`%@```/;O`0`6````#?`!`!X````D\`$`$````$/P`0`M````5/`!`!4`
M``""\`$`#0```)CP`0`@````IO`!`&X```#'\`$`)````#;Q`0`@````6_$!
M`"4```!\\0$`(0```*+Q`0`I````Q/$!`"L```#N\0$`(P```!KR`0`?````
M/O(!`",```!>\@$`)0```(+R`0`?````J/(!`!D```#(\@$`&P```.+R`0`*
M````_O(!``<````)\P$`"````!'S`0`*````&O,!`!,````E\P$`#P```#GS
M`0`M````2?,!`!@```!W\P$`'````)#S`0`(````K?,!``H```"V\P$`4@``
M`,'S`0!%````%/0!`$````!:]`$`>````)OT`0`-````%/4!`#`````B]0$`
M,0```%/U`0`*````A?4!``<```"0]0$`#0```)CU`0`Z````IO4!`!,```#A
M]0$`&P```/7U`0!$````$?8!`"T```!6]@$`(0```(3V`0`G````IO8!`"<`
M``#.]@$`$````/;V`0`R````!_<!`",````Z]P$`,P```%[W`0`J````DO<!
M`#(```"]]P$`*P```/#W`0`-````'/@!``D````J^`$`$0```#3X`0`3````
M1O@!`!@```!:^`$`!P```'/X`0`W````>_@!``P```"S^`$`!````,#X`0`%
M````Q?@!`!(```#+^`$`"````-[X`0`&````Y_@!`!0```#N^`$`"@````/Y
M`0`)````#OD!``4````8^0$`$0```![Y`0`1````,/D!`!H```!"^0$`'```
M`%WY`0`5````>OD!`"$```"0^0$`#0```++Y`0`'````P/D!`!(```#(^0$`
M%0```-OY`0`@````\?D!`"D````2^@$`"0```#SZ`0`)````1OH!`!L```!0
M^@$`*````&SZ`0`.````E?H!`"$```"D^@$`-````,;Z`0`)````^_H!``D`
M```%^P$`$@````_[`0`&````(OL!``0````I^P$`(@```"[[`0`-````4?L!
M``\```!?^P$`#````&_[`0`(````?/L!``D```"%^P$`"````(_[`0`)````
MF/L!``T```"B^P$`$@```+#[`0`&````P_L!`!D```#*^P$`%0```.3[`0`'
M````^OL!`!`````"_`$`(````!/\`0`,````-/P!``,```!!_`$`)0```$7\
M`0`&````:_P!``8```!R_`$`>P```'G\`0`)````]?P!``4```#__`$`+```
M``7]`0!&````,OT!`",```!Y_0$`+P```)W]`0!0````S?T!`"(````>_@$`
M.@```$'^`0`]````?/X!`"0```"Z_@$`(````-_^`0`%`````/\!``<````&
M_P$`"`````[_`0`)````%_\!``<````A_P$`"````"G_`0`2````,O\!``H`
M``!%_P$`"0```%#_`0`+````6O\!``L```!F_P$`!P```'+_`0`'````>O\!
M``@```""_P$`%````(O_`0`+````H/\!``8```"L_P$`!0```+/_`0`D````
MN?\!``8```#>_P$`+0```.7_`0`8````$P`"``@````L``(`%````#4``@`)
M````2@`"`!,```!4``(`"P```&@``@`%````=``"`!0```!Z``(`!0```(\`
M`@`4````E0`"``8```"J``(`&@```+$``@`*````S``"`!P```#7``(`"```
M`/0``@`&````_0`"`!(````$`0(`)````!<!`@`+````/`$"``T```!(`0(`
M*@```%8!`@`A````@0$"`!P```"C`0(`!0```,`!`@`*````Q@$"`!,```#1
M`0(`&````.4!`@`#````_@$"`!,````"`@(`"0```!8"`@`D````(`("`"@`
M``!%`@(`,P```&X"`@`H````H@("`#4```#+`@(`+P````$#`@!D````,0,"
M`!8```"6`P(`7````*T#`@`Z````"@0"`$D```!%!`(`:P```(\$`@`J````
M^P0"`$$````F!0(`,0```&@%`@`W````F@4"`"T```#2!0(`'0`````&`@!"
M````'@8"`-,!``!A!@(`(@```#4(`@`7````6`@"`$P```!P"`(`@````+T(
M`@`W````/@D"`!,```!V"0(`)````(H)`@`=````KPD"`"````#-"0(`'P``
M`.X)`@`L````#@H"`#\````["@(`7@```'L*`@!*````V@H"`"H````E"P(`
M(@```%`+`@`4````<PL"`!\```"("P(`(0```*@+`@`@````R@L"`"L```#K
M"P(`)````!<,`@`C````/`P"`#X```!@#`(`(@```)\,`@`5````P@P"`#<`
M``#8#`(`)@```!`-`@`L````-PT"`"L```!D#0(`&@```)`-`@`M````JPT"
M`&D```#9#0(`-@```$,.`@!)````>@X"`#<```#$#@(`+0```/P.`@!`````
M*@\"`'````!K#P(`4@```-P/`@`U````+Q`"`#<```!E$`(`+0```)T0`@`T
M````RQ`"`#``````$0(`:P```#$1`@!S````G1$"`"L````1$@(`*@```#T2
M`@!:````:!("`%D```##$@(`*P```!T3`@`>````21,"`#<```!H$P(`*0``
M`*`3`@`I````RA,"`"\```#T$P(`>0```"04`@!N````GA0"`'<````-%0(`
MQ````(45`@`6````2A8"`"<```!A%@(`.````(D6`@`O````PA8"`$T```#R
M%@(`*@```$`7`@!C````:Q<"`"H```#/%P(`(P```/H7`@`+````'A@"`*@`
M```J&`(`2@```-,8`@`I````'AD"`#@```!(&0(`*@```($9`@`C````K!D"
M`#T```#0&0(`!@````X:`@`+````%1H"``0````A&@(`"@```"8:`@`/````
M,1H"`!$```!!&@(`"P```%,:`@`&````7QH"`!$```!F&@(`!````'@:`@!F
M````?1H"``,```#D&@(`%````.@:`@`$````_1H"``<````"&P(`!@````H;
M`@`%````$1L"``@````7&P(`%0```"`;`@`,````-AL"`!$```!#&P(`$0``
M`%4;`@`#````9QL"``4```!K&P(`!P```'$;`@`2````>1L"``P```",&P(`
M%````)D;`@`&````KAL"`!4```"U&P(`#0```,L;`@`#````V1L"`"X```#=
M&P(`!`````P<`@`&````$1P"``<````8'`(`)0```"`<`@!'````1AP"`#@`
M``".'`(`.0```,<<`@`8`````1T"`"<````:'0(`*@```$(=`@`F````;1T"
M`!P```"4'0(`(0```+$=`@`H````TQT"`",```#\'0(`(````"`>`@`D````
M01X"`"8```!F'@(`(@```(T>`@`V````L!X"`!P```#G'@(`'0````0?`@`S
M````(A\"`#D```!6'P(`)@```)`?`@`J````MQ\"`"@```#B'P(`(P````L@
M`@`H````+R`"`#(```!8(`(`*P```(L@`@`P````MR`"`"8```#H(`(`)```
M``\A`@`E````-"$"`"X```!:(0(`(````(DA`@`G````JB$"`#<```#2(0(`
M.@````HB`@`<````12("`"8```!B(@(`/0```(DB`@`G````QR("`"L```#O
M(@(`*````!LC`@`J````1","`"0```!O(P(`'@```)0C`@`K````LR,"`"@`
M``#?(P(`-P````@D`@`N````0"0"`#D```!O)`(`"0```*DD`@`0````LR0"
M`!````#$)`(`&````-4D`@`R````[B0"`"4````A)0(`#0```$<E`@`/````
M524"`!8```!E)0(`"@```'PE`@`.````AR4"`"H```"6)0(`"````,$E`@`+
M````RB4"`"\```#6)0(`,0````8F`@`I````."8"`"(```!B)@(`)````(4F
M`@`*````JB8"`.P```"U)@(`#````*(G`@`B````KR<"`!8```#2)P(`"@``
M`.DG`@`-````]"<"`!(````"*`(`%P```!4H`@`J````+2@"``8```!8*`(`
M4@```%\H`@`:````LB@"`!H```#-*`(`!P```.@H`@`/````\"@"``@`````
M*0(`0@````DI`@`'````3"D"`"T```!4*0(`&@```((I`@`3````G2D"`!0`
M``"Q*0(`-````,8I`@`@````^RD"``<````<*@(`)````"0J`@`(````22H"
M``D```!2*@(`%P```%PJ`@`*````="H"`!P```!_*@(`"````)PJ`@`N````
MI2H"``<```#4*@(`(P```-PJ`@`G`````"L"``<````H*P(`%0```#`K`@`'
M````1BL"``@```!.*P(`"0```%<K`@!`````82L"``<```"B*P(`#````*HK
M`@`3````MRL"``\```#+*P(`"0```-LK`@`(````Y2L"``<```#N*P(`$P``
M`/8K`@`&````"BP"`!H````1+`(`"P```"PL`@`:````."P"`!0```!3+`(`
M"P```&@L`@`-````="P"`"````""+`(`!0```*,L`@`U````J2P"``P```#?
M+`(`#P```.PL`@`+````_"P"``,````(+0(`%`````PM`@`B````(2T"``L`
M``!$+0(``P```%`M`@`(````5"T"``P```!=+0(`"@```&HM`@`0````=2T"
M``X```"&+0(`$@```)4M`@`3````J"T"`!$```"\+0(`.````,XM`@`A````
M!RX"`!\````I+@(`(0```$DN`@`H````:RX"``D```"4+@(`-````)XN`@`'
M````TRX"`!<```#;+@(`0````/,N`@`3````-"\"`!,```!(+P(`"````%PO
M`@`$````92\"``8```!J+P(`#P```'$O`@`=````@2\"``<```"?+P(`"```
M`*<O`@`)````L"\"``8```"Z+P(`!@```,$O`@`5````R"\"`!0```#>+P(`
M0@```/,O`@`S````-C`"`"D```!J,`(`!0```)0P`@`;````FC`"`!T```"V
M,`(`(P```-0P`@`G````^#`"`!(````@,0(``@```#,Q`@`$````-C$"``\`
M```[,0(`"@```$LQ`@`%````5C$"``(```!<,0(`#0```%\Q`@!(````;3$"
M`#<```"V,0(`-0```.XQ`@`6````)#("`#<````[,@(`+````',R`@!:````
MH#("`#$```#[,@(`%P```"TS`@"#````13,"`"4```#),P(`.@```.\S`@`B
M````*C0"`#8```!--`(`.````(0T`@`M````O30"`"T```#K-`(`+````!DU
M`@`L````1C4"`"H```!S-0(`+@```)XU`@`N````S34"`#(```#\-0(`,P``
M`"\V`@`R````8S8"`!8```"6-@(`#0```*TV`@`.````NS8"`(8```#*-@(`
M"0```%$W`@"M````6S<"`'$````).`(`A0```'LX`@`K`````3D"`%P````M
M.0(`%````(HY`@`H````GSD"`!8```#(.0(`%P```-\Y`@`0````]SD"`"0`
M```(.@(`(@```"TZ`@`-````4#H"`$(```!>.@(`(````*$Z`@`>````PCH"
M`%P```#A.@(`&@```#X[`@`3````63L"``H```!M.P(`!0```'@[`@`&````
M?CL"``@```"%.P(`!0```(X[`@`6````E#L"`!4```"K.P(`%P```,$[`@`B
M````V3L"`!````#\.P(`#P````T\`@`6````'3P"``0````T/`(`"@```#D\
M`@`,````1#P"``D```!1/`(`#@```%L\`@`*````:CP"``X```!U/`(`!P``
M`(0\`@`&````C#P"`!D```"3/`(`$@```*T\`@`'````P#P"``\```#(/`(`
M!@```-@\`@`5````WSP"``T```#U/`(`!P````,]`@`)````"ST"``P````5
M/0(`"0```"(]`@`4````+#T"``<```!!/0(`#````$D]`@`8````5CT"``D`
M``!O/0(`"P```'D]`@`8````A3T"``8```">/0(`!0```*4]`@`G````JST"
M`!L```#3/0(`"@```.\]`@`9````^CT"`!8````4/@(`)````"L^`@`9````
M4#X"``D```!J/@(`%0```'0^`@`(````BCX"``<```"3/@(`%P```)L^`@`'
M````LSX"``(```"[/@(``@```+X^`@`?````P3X"``X```#A/@(`"````/`^
M`@`7````^3X"`!D````1/P(`!P```"L_`@`K````,S\"``(```!?/P(`!@``
M`&(_`@`/````:3\"`!D```!Y/P(`!0```),_`@`)````F3\"``H```"C/P(`
M$P```*X_`@`'````PC\"`!D```#*/P(`"@```.0_`@`7````[S\"`!,````'
M0`(`$@```!M``@`"````+D`"``<````Q0`(`$0```#E``@`&````2T`"``X`
M``!20`(`,````&%``@`)````DD`"``H```"<0`(`%````*=``@`%````O$`"
M``4```#"0`(``@```,A``@`+````RT`"``$```"L!P``J@0``.D!```(`@``
MH@4``!4#````````=0(``)@"````````5@(```````!%`@```````-,!``##
M!P``2````*X&``"I!0``^@0``$($```9`0``S````,P%````````````````
M```"!P```````*X!``````````````````"#!P``(@4``#H$``"L`0``I@,`
M`-T"````````L`8``.<&````````200``)8&````````&@$``-8%```,!P``
M`````&8!````````8`0```````!``P``Z@(```````!E!@``!0(``!P!``#$
M`P````````````````````````H'````````9`,```````!W!0``EP<``*4%
M```3`````````"<%``#!`P``;P0````````&!```2@(``-`"``"^`P``DP4`
M`"D#````````L0,``*(```#S`0``=`(``,<'````````GP,``+P`````````
M``$``-X&``!6`P``4P```*$%```9`@``I@(```````#>`0``@P```"('``""
M````WP$``%0$``!6!@````0``.0%``"K!0``I0$``'H#````````:@<``&H"
M```Z`0```````&H!```"`P``Z04``%P'````````Z0,``,@'``#:!```6P,`
M``````#*!P``_`$``,,````:!@``E`$`````````````.@```.P$``#Q!0``
M304``"D!``!M````@`0``,L!````````^04``#<$``#D!P```````+P"``!:
M!@``(0$``#$#``#8!@````````````"(````NP0``&$'``"5````AP,`````
M``#!`0```````*P$````````:0(``-0%````````M````"T'``#>`@``B`<`
M`(X#``!A!0``IP(``.H'``"Q!P``Z`0``,8%``"4!0``G`8``$<&``#(`@``
ME`8``-(%```9!@``````````````````C@$``"\#``";`P``J08```````#8
M`0``#P(````````2!P``````````````````V@4``/(#````````;```````
M```.!0``600``$0&````````L@4``/D`````````QP$``,(&```Q`0``E@,`
M`+<&``#M`@``]`,``"<$``"D````]P,``-,```"5!P``^@4``)@$```@!P``
M`````$,$``"1!P``M`4``,`%```_`````````%4`````````NP,``*L#```0
M`P```@4``#8&````````:00``*`$```M`@``H0<``+L&``!'`0``/`,``$@#
M```=!0``#`,``,('`````````````'0#````````5P<``$X'````````````
M``````#?`@````8``&H$````````L00``&@```````````````````#4````
MDP0``)0````Y`P``8````),```"I`0``_`,``-`'``!G!@``[P(``!P'````
M````6P```.X#``!O!@``'@0```````"C`P``,@(```````!2!@``U@``````
M``!K!P``,04```````!(!@``H00``",$``!S````N````#T"```_!0``M0$`
M``````#Q!P``7````%,&``"*!````````!4!````````&`<```H$``!A`P``
MF@4``',%``!2!0````````````#A`P``P`,``(`&``"D`P``@`4``'L%``"U
M`@```````,@&``!E`P```P````````#N!P````````````"@`0``70``````
M``"?`0```P$```````"U!```Q0,``"<`````````C`<```````!G`0``N0<`
M`,0&``#4!P```````.4```!I````````````````````!`$``",&``!&!P``
M`````!X%```U!@```````)P```#P`0``P`(````````H!0```````/H'``!"
M!@``````````````````\P<``+P#``"P!0``90$```4'``!T!P``W`,`````
M````````OP<``-D```````````````````"=`0``>04`````````````4`<`
M``````"P`P``H@$``)<"``"J!P````````````!L`@``I0(``*0&``#P!P``
M'````/P"````````5P,``'D#```Q!```*0<``(\%```+!@```````/L```!5
M!@``PP(``!,%``",`````````"P"``!6````[`4``&,$``#[!P``(@$```,#
M``#7!@``]0$``````````````````(L'````````Z00```````"@!P``````
M```````6`P```````.8!``!P`@``9`$``'X$``!3!```2`0``"P!``#_`0``
M0@(``"0&``#3!0``R04``/X&````````Y`$``"$&````````&`,``'D$````
M`````````"8!```3`P````````$&``".!@``8`4``,0!```L`P``:`8```X'
M``!&!@``"0$```0"``!:````4`4``",'`````````````)P"``!4````'`4`
M`%,"``"G````P`0``&D'``#;`P```````)H'``"H!0```````!P$```-!```
M2@8```(!``"%`````````%P!``!Q!0``L0````````!5`@``Y@4```<#``!+
M`0``?08``$@%``#J````GP<``#@&```]!P```````-<#```=`@``+P```.``
M``"N!```00,``!\&``#N`@``"@,``+`$```V`P``R@4``$T$``"X`@``$```
M``````#]`0``PP0```````"C!```"0,```````"4!```<0(``'4%``"J!@``
M>`$````````)!0``(04```````"%!````````.,````!`P``NP4``!$#``#A
M````'P0``)D#``!R!@``(@(``.8'``"*!P``&04``)H#```/`````````"<'
M````````!P(``(($``!F!0``I@0``%<"``"&!@``I@<``+8"``!R!```DP8`
M``````"R`@``(0,``"0%``!4`0``B0```.L%``"[`@```````,8`````````
ML`<````````T!0``K0````P&```````````````````F!P``'P<``*0$````
M`````````)@`````````30```!<&``"Q`0``:@4``&$!``!M!@``]`8``-P`
M```T`0``!@,``,@```"N`@``O0$``"<&````````;@8``/<```#+!0``V04`
M``````#[!0``?`,`````````````.@8``'4&``#"````2`<``%$!```L````
MC00``.,"``"`````#@8``&4````F!0``>@```,H$````````2@0```````!?
M`@``4`,``+T`````````X@$``-0#````````:P8```````#C!0``ZP8```8!
M``"7!````````.H$````````"@(``*D"``!$`0``-`8``,4```!.`@``P0(`
M`*8```"T!@``:`<``$P$``#?!```P0<``%T$``"U!@``7@<`````````````
M)0<```````#;````9P0``/\$``!5`0``6P<``#`"``#!!0``]`$``%T&``#6
M`0```````*4&``#L!@```````&T"``!-`P```````)`%```O`0``T@,``,0$
M``#6`@``#`4``(<`````````E`,``%0&````````0`4``%0#``!_!```,P<`
M`!<#``#+`P``&@4```````"O`@``\@<``($%````````````````````````
M`````"0"``#'!```JP0````````?`@```````#P$``!J!@``````````````
M````U@0```4!``!B`@``C`8```````"/``````````````!V`P``D@<``#X%
M``!<`P``F04``%8$``"\`0``6`8``-D"``#=`````````,,#```B!@``(0``
M`.T#`````````````!T'``"$`P``AP8``````````````````*X%``"1!@``
M#04```````!H`@```````$0#``````````````````!T!@```````"X$``!=
M!P``N@4```0````#`@``F@(``'\"````````D@$```````"@`@```````!<'
M````````&00````````F`P``RP(```````!Q!@``!P```)`&``#4!```*P,`
M`,4%```^!P``:08``-D!``#:!P``````````````````*@8``#`#````````
MV@8``%@%`````````````(T!```J`@``/`<``(L&````````````````````
M````;@$``````````````````*@````;!```Q00``"D%``#2!P``6P$`````
M``!?!P``%@<```````#8`@``ZP<``$0```"K!@``(0<`````````````ZP,`
M`'T$````````.04```````!*!P``+P4``*4'```?`P``T08```````#/`0``
M800``!4"``````````````````"G!```E00```````!F!P``````````````
M````T0,``!4```![!```AP$``','```D!P``RP<``)L!````````````````
M````````R0<``.D&``#H`@``R@$``$8%``!8!````````!4$``"=`@``D`$`
M`,@%``"O!```8@```!(%``#Z!@``?@```````````````````%H!````````
M`````(H&```"`@``+@(``'8$``#@!```\@```#8'```+`P```````($````.
M`0``T0(````````J!```V`,`````````````G0<``!$$``!U!````````"`%
M````````FP<```````!V!P``HP(``(8'``#6`P``8@<`````````````N@<`
M`'@'``#]````,@<``-4'``"Y!@```````.4'```L!@`````````````_!@``
M`````%<$``#W!@``A@4````````C`P```````#@%``!7````-0<``.(&``"4
M`@``Z@8``(8````8!0``)0$``/@"````````8P,``&\!````````[P4``,$&
M``!4!P``K04``/8'``!^!P``Y04````````J`0````````````"R````[@$`
M`(T%``#C!```:P4``!P"```J````V`0````````>````1P,``$$%````````
MA`$``#\$``#,!P``%`(````````A`@``30$``%H$``!1`P``YP<``'D'``"L
M````H`8``+($``"=!```^0,``,`'``#<!P``"P`````````W`@```````)L%
M```N`P``6````,(!````````)@0``)D'``!%````:P0``',&````````N@,`
M`&8`````````@00``!X&````````#`(``)H&``#3!@``Q@0``#,&````````
MS`$``/\"``````````````````!\````IP4``-4!``#X`P`````````````4
M!@```````,(#````````C0(``-8&``"G!@``&@,```````#`!@``*00``/$"
M``#-``````````P!``#G`P``3P$`````````````S04``#,!``")`P``>P<`
M`#(&``#\!P``=@8``/0"``````````````````!>!@``,`8`````````````
M3P,``$<$``#^`@``000``-X%``#L`0``!08``#H'```C`@``^P8``+X!``!#
M!P``4P<```````"W`P``+P0``&,```"7!@``"`0``)````"=`P``;0,``/`#
M``#Y!P``D@0```````"@`P``/@$``-T!````````O00``)@#``"Y`0``%@4`
M``````!!`0``^0(``#4%````````0P$``-H`````````F0(```````#,!```
MM0,``$,%``#R`0``]08``)X%``#/!0````````\$````````Y00``#8"```+
M`0``3P4``.0"``!5!0``H````.L"````````^P,```````"L!0```````(0'
M```(`P``L`$``-`#``"S`0``BP```"T`````````K0(``-\&````````*`(`
M``8```">!```\`8```````!9!P``B00````````P`0``0@``````````````
M``````````#5`P``LP0``````````````````-<$```^`````````(,$````
M````$P8```````!Q!P``7@$``'\'```0!`````````<'``!#````Y`0``$('
M```B!````````!(```"8`0```````#$```!Q`0``)`````0'````````3@``
M`.4"```H`P``.P8````````3`@``NP```,0%``!2````6P8``"4&``"^`@``
MQP````T!````````0P(``#`$``"#`@``*`8``)<#`````````````(0$```-
M````O@```*T&``!\`@````,``-$%``!,!0``6@(``,`!````````X`8``%X`
M``"_!0````````````!B!@``E0(``)0'``#P!```$0`````````G`0``````
M`````````````````'(#````````)@8``(P!``#9!```F08``-L&``"D!P``
MJ00``"`"````````100``!P#``!H!0```````````````````````"P$````
M````>P,```D$``"8!0``^08``(,!``!]!0```````.8&``#1`0```````-P&
M``#B`P```````.`!``!``0``S@(``#@'``!L!```Z`$```4%```L!P``````
M`,L````4!```30<```````!>!```"@8```````"I`P``9`(``-8'``"J`P``
M``````````#Y!````````%T#```@!@``K`8`````````````:0,```$$``#R
M!0``]`0``&P'```[!```FP``````````````%`4``"8"````````````````
M``!V`0``;@,``*\%```=!@``Y@0``'X!``"(!````````$H!````````[P,`
M``````"8!@```````%L"``#X!P``*@4``,\#```U`0``=`4````````P!P``
MA`4``.T&`````````````#D$```E`P``\@(``*@!``#W`0``L``````````@
M````^`4``)8```!1`@``S`8``"<"```B`P``%@$``#D!``!/!@``;@```,X`
M```6!@``/@(``.D'``!4`@``F0$```````#>````O`0``+4```#X````S@$`
M`!$%``#>!P`````````````V````FP8``#$'``!C`0``?`8``&\````>!P``
M8`8```````"(`@``/`$``,`````S!0```P0``.,&````````]0(``(L"````
M````)0```$8"``!Q````/`8``/P$````````)00``.T$``!3`0``#@```-,"
M````````H@0``%L%``"5!@``G`<`````````````9`4```0#````````V0<`
M``````!Z`0``!P4`````````````M@4````````]!@``1P4```````#N!0``
M[04```````!U!P``+@8`````````!P``A````+\!``!E!```&P4``%4$``"X
M!@``ZP$```````#2````>P$``'T"``!M!```B04```````#L`@``@0<``,4!
M```V!```6`(``/H!``"H`P``1P(``"X!````````F@0``'4#``"1````>P``
M`,0``````````````,D`````````G`4`````````````SP(```````!P````
MX0<``/\````O!@``4@$``.<"``!^!@```````*H!``#O!```/P<```````#R
M!```400``)X```"-`P``O@4```````"\!P```````($#``#>!```D`,`````
M``#*````Y08`````````````<`$``',"````````$`$```````!S`0``H@<`
M`*$&``"<`0```````&\%``"5`P``VP0``+D$````````.0```'X%``">`@``
M>@0```````#[!`````````````"Y`P``*P0``#`%````````!P8``#@#```N
M````!`8``&`"``!,!@``-00```````#U!0```````.8#``"]`P```````&D%
M``!0````"P(``,("``"6!```:`,``$$"``!G`P```````%T"``"T`0``2P4`
M``````!/``````````````",!```DP,```````#&`P``1P<``%$&```W!@``
M7P8``"@$``!]!P``60```%,#``#K!```[0```+<```#G`0```````(X$````
M````0`<``$$&``!>`@``(@``````````````````````````````&@```+('
M```M`P``=P<```````!$`@``$@0``,,%```F````\`4``+P&``"3!P``.`$`
M`/4$``#+!@``-P4``-4````$!```\0,``&0$````````W`$```````">`0``
M)0(``%$```"6`0```````-$$```?`0``=P```*8%````````3@4```````!X
M!0```````&X'````````(P```,T#````````5@$``)<%``#V`@```````(,#
M``!V!0```````/T"``"]`@``Z@,`````````````S@<``&<"``"W!P``(`$`
M`"L%``!$!P``N0```.\'``"X!0``3@,``-T&``#>`P``JP```.X````4`P``
M!0,``'X"```+!0```````!<```"N`P``Q0(```````"W`0`````````````K
M`@``UP4``-\#``"%`P``B@,``.($````````Z````)$%```&!P``^@(``$T&
M```%!````````+,```!+`@``>@8``$L$````````:@```%,%````````EP``
M`$8!```R``````````````"_!@```````),!``!/!P``>@4``.`"``#F````
M`````.<$````````GP```#4"``#3!P```````/T&``!?`0``T`0``*\&```H
M!P``&0<``+H$```6`@``N0(``/$$````````@@8``#H#````````J0<``-\%
M```2!@```````-@```#<!````````$D```#]!0```````#<'``!7!0``(00`
M`#\#``!9`P```````.<%``#/!@``F@```"0!```:`@``"0<``#@$``!V````
M`````!0!```R`P``B@$`````````````+@4```````!$!0``S@0`````````
M`````````*(&``!X!```@0(```````````````````````#S`P``;P(``*4#
M```J`P``2P```$D"``#A`0```````*4$```0`@``B0$``!(#``#S!```-P,`
M`+$"````````'@(``-,#``!?!```JP(``*X`````````8P8``)L"``"I````
M<P0```````!*!0``VP<```````#:`P````````````"C!P```````)\$````
M``````````\&``#7````[P```*P#``#$`@``#`0``*,```#5!@``]```````
M``"\!0``'@,```````#0!0```````````````````````(L#````````A0<`
M``````!)!0``8`,``&`!``!$!```D0,`````````````*0```-D&``!B`0``
M0````&$"``#[`@``X@<``%("``"0!P``C0<``*8!``#(`P`````````"````
M````.08```````!Q`P``$@$``%D"```N!P``M`0``)X#``#;`0``]`4``%4'
M``!H!`````````````#W!P``;0<``'\&``"`!P``(P$``/4#```;!@``.```
M`*T'```[`@``VP4``,@$`````````P4``$X&``!-`@``=0$``-<'``""!0``
ME@<```````#S`@``,P0````````7`@``O@0``&0&````````!@4``)X&``"&
M`P``<`8``$`$``#B!0``&`8``.8"``""!P``_0,``/8```!E!P``B08``)P#
M``!R`0``SP0``#L!``"/`P``JP<``&X%```S`P``.P4``+8'``#-`@``#P4`
M`)8%``#S`````````*H`````````AP<``-`&``#?!P``CP0``)D$``#%!@``
M[P8``+<%``!W!@``M0<``.T!```/!P``)P,``.`'``!8`P``0P8``!@$```5
M!0``A08``!D#``!0`@``"@$``&(%``"A`0``U`$``$4'``#(`0``A`8``/8!
M````````H`4``/@&```K````20,``*P"``"2`P``>````)\"``#^`0``````
M`/`````'`0```````.X&``"G`P``2@,```X#``!K````PP$``+(!```/`P``
M]P4``#0$````````"`$``!L"`````````````.H!````````C`,``)4!``"+
M`0``````````````````*0(``$`&````````S`(``(<$`````````````(H`
M``"M`P```````&T%``!9!0``J@4````````]````X08`````````````XP,`
M``````#\!0``&P,`````````````,P```+(#``!:!P```````&4"````````
M&@<``+H"````````D@```$P"````````&P````````"#!0``#@(``#$&``#'
M!@``VP(``&0'````````S0<```````!P`P```````&8"``"^!P``]P(``'T`
M``"1`0```````"\'```7!```20$``(4!``!O!P```````&P!``!.`0``````
M`-<!`````````````,<%``#X`0``A`(`````````````R0,```````!E!0``
MIP$``!L!``!G!P``SP```"H'``````````````D&``"V!@```````*$#``!6
M!P``I`4``.,!``!C!P``#0,``-T$````````ZP```%8%````````````````
M``!?`P``"@`````````R!```<@```(8"``"B`@```````-(&````````````
M``@&````````=P$```````!<!```:0$``+@#``#*`P``'`8``+T'``!!````
M104``!@```#U````UP(``*@"``!0!@``X00``%<!```Z`@``%````.D"``!4
M!0```````/D!```H`````````,T&```E!0```````.(````R!0``D00``&H#
M``!^`P``&`$````````3!```OP,``*0!``"Z`0```````'4```#=`P``2`(`
M`$$'`````````````.P`````````A@0``/<$``#'`@```````)H!``"Y!0``
MC@4``#L'``!N`@`````````````-!P``HP8``'L"``!L!@``F`<``+8$````
M````Q@8```````"O!P``C0```-(!````````;@0``&($`````````````$X$
M````````[@0``*L!`````````@```'@"``"!!@``>@(`````````````Z`<`
M`.4!``"(`0``E04``,(%```M!```7@,```<$``"9````/04````````1`0``
MGP8``&`'```]!```>0````````!D````'P```+@'``!%!@``H0(``/X%```7
M!0``]0<``#<```!<`@``=P0``+8#``"&`0``L08```````"P`@```````$`"
M```Y`@```````.P#````````:`$``'T!```(````3P(``'L&````````4@0`
M`(X"``!V`@```````+\$``#1````/`(``$P'``!%`0```````+H`````````
M_`````\!```$!0``9@,``!\%```^!@``U04``%@'``"F!@```````)T&```[
M`P``H0```,8!```=`P```@8`````````````@@$```````#V`P``20<``'H'
M````````Y0,``'@&````````S@,``/P&``!2!P```````.0`````````$P$`
M`$<```#_`P``&@0``#P````)``````````````"H!@``PP8``,X&```M!@``
M``````````!0!```T@(```````#*`@``.`(```````"/!P```````,4'``#[
M`0```````%\`````````(`,````````K`0``````````````````%@0``*(#
M``!(`0``?0,``&L"````````BP4``-H!``!+!P```````.\!````````MP0`
M``````#G````8P(`````````````6@,``.@#``#8!P``@@(``/8%````````
MJ`0``!$&````````+0$````````D!````````'\#``"Z!@``M04``'0`````
M`````````!`%```S`@``-`,`````````````8@,``*4````^`P``*P<``%X%
M```(!0``3`$``+8!``"N!P```````'("````````7P4````````T`@``1@``
M`.@&``!F!@``\08`````````````7`4`````````````C`(`````````````
M`````.,'``#)!```9@0```````")`@``O04``!0'``"X`0``#08``&P#``".
M!P```````'$$````````*08```````#X!```C@```)8"``#)!@``````````
M`````````````(,&````````LP8```````"*!0```````)(%``""`P``Q@(`
M``````#P`@``LP,``'0$``!7!@``U0(``)(&``#:`@```````),"```&`@``
M`0$``/8$````````Y`8``)X'``!\!0``G04``'(%``"``P``"0(``*,%``#*
M!@``SP<``"T%``"_````Y`,````````1`@``CP8```````!_`0``\0$``#\"
M```U`P``````````````````G0```'P$``!)!@``50,``($!````````0P,`
M``P```"W`@``?`<``````````````````&<%``!_`````````-T%``"J`@``
M`````+,'`````````````-D#``"(!0``>08```````#4`@``_00``*T$```_
M`0``.P```!T```!R!P``<`0``+@$``"[!P``.0<``)$"```W`0```````-P%
M````````M`(```````"'!0``]@8``",%``"``@``J`<````````#!P``LP(`
M`!D```#1!P```````&$````7`0```````"0#````````'@$``"P%``#.!0``
M%08``.$%````````-@4````````\!0``Z@4``!T!`````````````.$"``"%
M!0``3`,``*,!```P````0@4``'D"``#0`0``Z`4``'@#``#L!P```````%H%
M``!/!```O@8``#T!`````````````/X```!C!0``%@````````#!!```,@$`
M`,0'``#&!P``-`<``%P&``````````````@'````````!0```-,$```K!@``
M`````+T&``#4!@``OP(``+8```!K`P``&`(``/H#``!L!0``K0$``$8$``#T
M!P```````,P#`````````````*\````Q`@``(`0``-T'``!=`0``$`<``)`$
M``!Y`0``2P8```````#M!P``4@,``#X$``!S`P``$@(``$(#````````W`(`
M`*<'``!+`P``=P(`````````````$0<``/H```#-!````````/,%``!;!```
M```````````Z!0``A0(```````!W`P``2@```,D!```+!```6`$``,($````
M`````````(`!``#I````P0````$'```!!0``_@0``*0"``!T`0``60$``%T%
M```=!```RP0``-````#2!````````-4$``"2`@``4`$````````V`0``40<`
M`+(&``!1!0``X@(``!,'``!A!@``<`<``/X#``"/`0``CP(``,<#``#)`@``
M"P<````````-`@``X`4``-@%``!\`0``L04``'`%```U````"@4```````"O
M`0``\@8``"\"``",!0``&P<``$P```";!```608```X$````````$`8``(<"
M```H`0```0(``&L!``!M`0``_P8``)\%``#S!@``BP0```8&``"O`P``\0``
M`'\%````````1@,``)`"``!G````LP4``/\%``!"`0``C08``.`#```#!@``
MB@(``#0```"[`0``B`,```````#?`````````)<!````````M`<``)P$``#-
M`0``B0<``#T#``!%`P````4``&\#`````````````+0#```5!P``B`8`````
M```"!````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S
M(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@
M`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED
M(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E
M9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E
M871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F
M)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@
M97AP:7)E<RX`)60@;F]T97,`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E
M`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M
M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S
M`"5S(&-H87)A8W1E<G,`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E
M<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@
M)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S
M($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G
M92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R
M92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN
M9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L
M(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,`+2T@<V5L96-T("TM`#$@;F]T90`Q,B!(;W5R($9O<FUA=``R-"!(
M;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@
M4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-
M`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`
M06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C97-S(&1E
M;FEE9"!D96QE=&EN9R!N;W1E+@!!8V-E<W,@9&5N:65D(&UO=FEN9R!T:&4@
M;F]T92X`06-C97-S(&1E;FEE9"!S879I;F<@;F]T92!T;R`E<RX`06-C97-S
M(&1E;FEE9"!S879I;F<@;F]T93H@)7,`06-C;W5N="!);F9O<FUA=&EO;@!!
M8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D
M9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE
M<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H
M:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B
M)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V%T96=O<GD`061D(&-O;'5M;@!!
M9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M
M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES
M=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O
M<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+@!!9&1I;F<@02!.97<@3F]T90!!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T
M:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI
M9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL
M($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@
M;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN
M`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N
M86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T
M97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C
M=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY
M`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC
M871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`
M07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ
M90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I
M>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B
M80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]0
M86-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS
M`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U
M9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F
M='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE
M(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L
M92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D
M871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F
M86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL
M86)L92!#871E9V]R:65S.@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N
M`$)/1D@@17AC=7-E<P!"86-K('1O($YO=&5P860`0F%C:R!T;R!.;W1E<&%D
M($]P=&EO;G,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B
M97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S
M`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B
M861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A
M`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E
M<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`
M0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O
M<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O
M='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T
M960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S`$-35@!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE
M(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D
M:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A
M;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET
M92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S
M:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L
M:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N
M`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A
M<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L
M<P!#871E9V]R>0!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O
M<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P
M86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N
M97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO
M=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@
M<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E
M;6%I;',N`$-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O
M<'1I;VYS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T
M960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`
M0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@
M<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E
M9"!L:7-T<RD`0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I
M;B!T:&4@<W5M;6%R>2!V:65W+@!#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P
M860N`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N`$-L96%R`$-L96%R($9O<FT`0VQE87(@35-/9F9I8V4@=&%G
M<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#
M;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU
M90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO
M=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL
M87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R
M`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T
M:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O
M;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N
M`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U
M<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD
M($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I
M9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M
M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O
M;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N
M="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`
M0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D
M.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D
M)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R
M>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#
M;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T
M('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0
M(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@
M;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A
M9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP
M:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T
M<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@
M;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N
M;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`
M0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U
M;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T
M:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@
M<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O
M;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L
M9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S
M97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N
M<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL
M>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F
M;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R
M+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV
M92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD
M97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A
M=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@
M9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A
M<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E
M;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E
M;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``
M0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H
M2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B
M87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`
M1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$
M96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@
M261E;G1I='D`1&5F875L="!.;W1E<&%D`$1E9F%U;'0@4VAE;&P`1&5F875L
M="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N
M.@!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($-O;F9I
M<FUA=&EO;@!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES
M<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!B=71T;VX@
M8F5H879I;W5R`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E
M;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O
M=P!$96QE=&4@=&AI<R!N;W1E`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-E;F1I;F<`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5S8W)I<'1I;VXZ`$1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE
M;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O
M:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES
M<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA
M>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!C
M;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@=&AE(&9I<G-T(')O=R!C
M;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O
M>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO
M860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O
M<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y
M(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V
M:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@(B5S(@!%9&ET($)L;V-K`$5D
M:70@1W)O=7``161I="!.;W1E`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI
M<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@8V%T96=O<FEE
M<R!A;F0@8V]L;W)S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N
M`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@
M061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET
M:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS
M`$5M<'1Y($YO=&4`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T
M>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!5
M4DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'
M=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`
M17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R
M('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN
M:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I
M;VX@1&%T90!%>'!O;F5N=`!%>'!O<G0`17AP;W)T($YO=&5S`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1E]U;&P@5&5X=`!&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE
M9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`
M1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@
M=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T
M86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS
M(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA
M=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA
M;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER
M<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O
M9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE
M<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V%M8FEA`$=E;F5R86P@3W!T:6]N<P!'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!'
M:6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`
M1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R
M965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI
M;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T
M92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P
M("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y
M`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I
M<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE
M+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD
M+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE
M87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M
M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG
M(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI
M;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@
M0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`
M2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E
M;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$
M(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN
M;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D
M9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I
M='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N
M<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG
M<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@
M86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE
M960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!)
M;6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE
M<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T($YO=&5S+"!3=&5P("5D
M`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($YO=&5S`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R
M`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S
M92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF
M;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A
M8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS
M97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O
M;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@
M869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E
M<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA
M9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@
M<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C
M<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E
M<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI
M='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I
M;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!)
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N
M`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A
M;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A
M;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV
M96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R
M;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y
M`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*
M=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`
M2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R
M:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN
M9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI
M<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY
M<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!-;V1I9FEE9`!,87-T(%!A
M<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T
M(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ
M($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE
M<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI
M96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A
M:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3
M:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES
M="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M
M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I
M8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@
M9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T
M=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@
M86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC
M('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E
M`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`
M3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%
M1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G
M87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA
M<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W
M:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R
M<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R
M:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S
M86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@3F]T
M97,`36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE
M;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;6\@5&5X=`!-
M96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G
M92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN
M960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R
M:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED
M9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E
M;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO
M="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S
M<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T
M90!-;V1I9GD@55),`$UO9&EF>6EN9R`E<P!-;V1U;'5S`$UO;&1O=F$L(%)E
M<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT
M:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@
M:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T
M;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N
M`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@
M=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L
M=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY
M($%C8V]U;G0@26YF;W)M871I;VX`37D@3F]T97,`37D@4&]R=&%L`$UY(%!O
M<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.
M86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N
M=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I
M;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A
M;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N
M:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE
M=R!.;W1E`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE
M=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`
M3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO
M;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.
M;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E
M+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N
M`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO
M(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"X`3F\@:6-O;G,@9F]U;F0N`$YO
M(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE
M<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N;W1E<&%D
M<R!A<F4@879A:6QA8FQE('1O(&=U97-T<RX`3F\@;F]T97,`3F\@;F]T97,@
M;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N`$YO(&YO=&5S('1O(&1I<W!L
M87D`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@
M<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.
M;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S
M`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;U]T90!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M
M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.
M;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@
M0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S
M970`3F]T('-U<'!O<G1E9"X`3F]T92!#871E9V]R>0!.;W1E($1E=&%I;',`
M3F]T92!,:7-T<P!.;W1E(%1E>'0`3F]T92!?5&5X=`!.;W1E(&YO="!F;W5N
M9"X`3F]T95]P860`3F]T97!A9"=S(&YA;64Z`$YO=&5P861S`$YO=&5P861S
M(&UU<W0@:&%V92!A(&YA;64N`$YO=&5S`$YO=&5S(%-U;6UA<GD`3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@
M;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W
M<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`
M3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S
M<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S
M('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U
M;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@
M;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE
M<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I
M;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A
M8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L
M:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`
M3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A
M;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I
M;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/
M=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD
M`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0
M(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D
M90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`
M4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!0
M86MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U
M9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A
M<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!0
M87-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S
M:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN
M97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO
M=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M
M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0
M;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R
M97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E
M($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O
M;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L
M:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`
M46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D
M:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3
M:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U
M;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!D96QE
M=&4@=&AI<R!N;W1E/P!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!,:7-T`%)E9G)E<V@@4&]R=&%L(%9I97<Z
M`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E
M;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C871E9V]R
M>0!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER
M`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T
M(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T
M=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E
M=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2
M:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0
M<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,
M969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE
M<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R
M;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L
M=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY
M`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G
M:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S
M`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT
M($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD
M($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A
M;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N
M9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A
M=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C
M871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE
M<P!396%R8V@@4F5S=6QT<P!396%R8V@@4V-O<&4`4V5A<F-H(%]497AT`%-E
M;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D
M9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@;F]T97!A9`!396QE8W0@
M82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE
M8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE
M8W0@;F]N90!396QE8W0@;F]T97!A9',@=&\@9&ES<&QA>3H`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T
M('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F;W)M870@;V8@=&AE
M('-O=7)C92!F:6QE.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396QE8W1E9"!#871E9V]R:65S.@!396YD(%!R;V)L96T@
M4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E
M<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO
M;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T
M;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U
M<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F
M<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T
M=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N
M<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H
M;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E
M9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!A8W1I;VX@8G5T=&]N
M<S\`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;F]T97!A9"!N
M86UE/P!3:&]W(&YO=&5S(&9R;VT@=&AE<V4@8V%T96=O<FEE<P!3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY
M`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3
M:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E
M;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W
M(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E
M`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO
M;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@8GD@0V%T
M96=O<GD`4V]R="!B>2!.;W1E(%1E>'0`4V]R="!O<F1E<B!S96QE8W1I;VX`
M4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D
M97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG
M`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L
M;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A
M;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`
M4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H
M<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E
M<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD
M+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S
M`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL
M>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+@!3=6-C97-S9G5L;'D@<V%V960@(B5S(BX`4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U
M<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA
M<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N
M<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P
M<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`
M4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D
M`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!
M<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R
M;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R
M=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N
M+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R
M`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E
M.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!4
M96UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I
M;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@
M*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE
M($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P
M;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN
M9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C
M="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H
M92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O
M('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@
M;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T
M=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A
M;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+
M(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I
M=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4`5&AE(&YO=&4@=V%S(&1E;&5T960N`%1H92!N;W1E<&%D("(E<R(@
M8V]U;&1N)W0@8F4@8W)E871E9#H@)7,`5&AE(&YO=&5P860@(B5S(B!H87,@
M8F5E;B!C<F5A=&5D+@!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H
M)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D
M;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M
M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T
M;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC
M;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B
M)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M
M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@
M)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!V3F]T92!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O
M=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!R96UO
M=FEN9R!T:&4@;F]T93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T
M:&4@;F]T93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C
M;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!V
M:65W:6YG('1H:7,@;F]T97!A9#H@)7,`5&AE<F4@=V5R92!N;R!M96UO<R!T
M;R!E>'!O<G0N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A
M('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@
M;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O
M9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E
M9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD
M('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O
M;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G
M(S$R,S1A9B<N`%1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"X`
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES
M("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T
M:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&
M;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O
M<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H
M=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI
M;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O
M:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A
M;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4
M=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO
M=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN
M90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A
M9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N
M`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D
M96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@
M)7,`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O(&-H86YG97,`
M56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@
M;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O
M<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!#;VYT96YT
M+51Y<&4Z("5S`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E
M("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@
M9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U
M<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P
M<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E
M(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-
M4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E
M9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N
M86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5
M<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U
M`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@
M*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I
M97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N
M9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A
M;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.
M54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA
M`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O
M=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC
M;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X
M-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H
M($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\`5VAI8V@@
M<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T
M:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7
M:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L
M9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O
M;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``
M665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4
M($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O
M(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!N;W1E<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D
M9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N
M`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P
M860@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA
M;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A
M(&YO=&5P860@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%N('-E
M<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@
M;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R
M;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@
M061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI
M<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@
M875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R
M97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9&5F875L="!N
M;W1E<&%D.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E
M9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&YO=&5P
M861S.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I
M80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E
M>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO
M=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D
M;6EN:7-T<F%T:6]N`%]"86-K('1O($YO=&5P860`7T-,20!?0V%T96=O<GD`
M7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2;W<`7T5D:70`7T9I<G-T($QI
M;F4`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T
M+T5X<&]R=`!?3&ES="!.;W1E<P!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@
M3&EN:RXN+@!?37D@3F]T97!A9',`7TYE=R!.;W1E`%]/<'1I;VYS`%]097)M
M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK+BXN`%]396%R8V@`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D
M<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U
M='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N
M9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E9&ET
M`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S
M*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM
M;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O
M9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI
M;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE
M="!I;7!L96UE;G1E9`!N;W1E<&%D`&YO=&5S+F-S=@!P97)C96YT`'!E<FUI
M<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`
M<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S
M;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K
M(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A
M<F0`=DYO=&4`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!-
M;F5M;R`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3`R(#$Q.C4Q
M*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTP,B`Q,3HU,2LP,3`P
M"DQA<W0M5')A;G-L871O<CH@36%N=65L(%`N($%Y86QA(#QM87EA;&%`=6YE
M>"YE<SX*3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-
M12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3L*
M`"`H:&%C92`E<R!D[6%S*0`@*$%C8V5D:65N9&\@82`E<RD`("AE;B`E<R!D
M[6%S*0`@*&AO>2D`("AM8?%A;F$I`"`H87EE<BD`96X@`"(E<R(@;F\@97,@
M=6X@9&ER96-T;W)I;RX`(B5S(B!N;R!E<R!U;F$@96QE8V-I\VX@=N%L:61A
M+@!.;R!S92!H82!C;VYF:6=U<F%D;R`B)7,B(&5N(&5L(')E9VES=')O(&1E
M($AO<F1E+@!.;R!S92!E;F-O;G1R\R!E;"!G96YE<F%D;W(@9&4@X7)B;VQE
M<R!D92`B)7,B+@!392!H82!A\6%D:61O("(E<R(@86P@<VES=&5M82!D92!G
M<G5P;W,N`%-E(&AA(&'Q861I9&\@(B5S(B!A;"!S:7-T96UA(&1E('!R:79I
M;&5G:6]S+@!.;R!S92!H82!C<F5A9&\@(B5S(CH@)7,N`%5S861O<R`E+C)F
M34(@9&4@)2XR9DU"('!E<FUI=&ED;W,@*"4N,F8E)2D`)60@)7,@>2`E<P!1
M=65D86X@)60@9.UA<R!H87-T82!Q=64@97AP:7)E(&QA(&-O;G1R87-E\6$N
M`"5D(&YO=&%S`"5D('!R;V[S<W1I8V]S(&1I87)I;W,`)7,@+2!!=FES;P!(
M=65L;&$@9&EG:71A;"!D92`E<P`E<R!+0@`E<R!O<&5R86-I;VYE<R!D92!M
M86YT96YI;6EE;G1O("T@0V]N9FER;6%C:?-N`$-O;F9I9W5R86-I\VX@9&4@
M)7,`1FER;6$@9&4@)7,`06-U97)D;W,@9&4@;&EC96YC:6$@9&4@)7,`66$@
M97AI<W1E("5S+@`E<R!A(&QA<R`E<R`E<P`E<R!C87)A8W1E<F5S`$5L(&%R
M8VAI=F\@)7,@<V4@:&$@:6UP;W)T861O('-A=&ES9F%C=&]R:6%M96YT90`E
M<R!E<W3A('!R97!A<F%D;R!P87)A(')E86QI>F%R(&QA<R!O<&5R86-I;VYE
M<R!D92!M86YT96YI;6EE;G1O('-E;&5C8VEO;F%D87,N06-T:79E(&QA<R!C
M87-I;&QA<R!D92!L87,@;W!E<F%C:6]N97,@<75E(&1E<V5A(&5J96-U=&%R
M(&5N(&5S=&$@;V-A<VGS;BX`2&%C92!F86QT82`E<P`E<R!M:6YU=&]S`$YO
M('-E(&AA(&5N8V]N=')A9&\@)7,N`"5S(&%L("5S(&1E("5S`$1I<F5C8VEO
M;F5S(&1E("5S`$%G96YD82!D92`E<P!,:6)R971A(&1E("5S`%1A<F5A<R!D
M92`E<P`E<SH@)7,`)7,Z($5S=&4@;65N<V%J92!P=65D92!Q=64@;F\@<')O
M8V5D82!D92!Q=6EE;B!P87)E8V4@<V5R+B!%=FET92!S96=U:7(@8W5A;'%U
M:65R(';M;F-U;&\@:6YC;'7M9&\@;R!S=6UI;FES=')A<B!C=6%L<75I97(@
M:6YF;W)M86-I\VX@<&5R<V]N86P@86P@<F5M:71E;G1E+@`L('9E;G1O<V\@
M`"P@=F5N=&]S;R`E<R`E<P`L('9A<FEA8FQE(&1E("5S(&$@)7,`+2T@<V5L
M96-C:6]N87(@+2T`,2!N;W1A`$9O<FUA=&\@9&4@,3(@:&]R87,`1F]R;6%T
M;R!D92`R-"!H;W)A<P`R-"!H;W)A<P`\06YT97)I;W(`4&%R82!E<W1E(&)L
M;W%U92!H86-E(&9A;'1A('5N(&UO=&]R(&1E(&)A<V4@9&4@9&%T;W,N`%-E
M(&AA('!R;V1U8VED;R!U;B!E<G)O<B!I<G)E<&%R86)L90!(86-E(&9A;'1A
M('5N82!C;&%V92!01U`@</IB;&EC82!P87)A(&-I9G)A<B!U;B!M96YS86IE
M+@!(86-E(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82!P87)A(&-O;7!R
M;V)A<B!U;B!M96YS86IE(&9I<FUA9&\N`$AA8V5N(&9A;'1A('5N82!C;&%V
M92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R
M87-E(&-L879E('!A<F$@9&5S8VEF<F%R('5N(&UE;G-A:F4N`$AA8V5N(&9A
M;'1A('5N82!C;&%V92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV
M861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9FER;6%R('5N(&UE;G-A:F4N
M`$AA8V5N(&9A;'1A('5N82!C;&%V92!3+TU)344@</IB;&EC82P@=6YA(&-L
M879E(%,O34E-12!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9&5S
M8VEF<F%R('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V92!3+TU)
M344@</IB;&EC82P@=6YA(&-L879E(%,O34E-12!P<FEV861A('D@=6YA(&9R
M87-E(&-L879E('!A<F$@9FER;6%R('5N(&UE;G-A:F4N`$AA8V4@9F%L=&$@
M=6YA(&-L879E(%--24U%('#Z8FQI8V$@<&%R82!C:69R87(@=6X@;65N<V%J
M92X`3G5B97,@;6%T:6YA;&5S`$QI9V5R82!L;'5V:6$@;6%T:6YA;`!,;'5V
M:6$@;6%T:6YA;`!!9W5A8V5R;W,@;6%T:6YA;&5S`$%G=6%C97)O(&UA=&EN
M86P@9&4@;FEE=F4`04TO4$T`240@9&4@05!)`$%C97)C82!D96P@961I=&]R
M`$%C97)C82!D92XN+@!);F9E<FEO<B!!8G,N`$5N(&UE9&EO($%B<RX`4V4@
M:&$@9&5N96=A9&\@96P@86-C97-O(&%L(&-R96%R(&5L(&1I<F5C=&]R:6\@
M5D93+@!392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@96P@87)C
M:&EV;R!61E,N`%-E(&AA(&1E;F5G861O(&5L(&%C8V5S;R!P87)A(&5L:6UI
M;F%R(&QA(&YO=&$N`%-E(&AA(&1E;F5G861O(&5L(&%C8V5S;R!P87)A('1R
M87-L861A<B!L82!N;W1A+@!392!H82!D96YE9V%D;R!E;"!A8V-E<V\@<&%R
M82!G=6%R9&%R(&QA(&YO=&$@96X@)7,N`%-E(&AA(&1E;F5G861O(&5L(&%C
M8V5S;R!P87)A(&=U87)D87(@;&$@;F]T83H@)7,`261E;G1I9&%D`$-O;G1R
M87-E\6$@9&4@86-C97-O`$ED96YT:61A9"!B;&]Q=65A9&$N`$-O;G1A8FEL
M:61A9`!!\6%D:7(`0?%A9&ER(&=R=7!O(&1E<V-E;F1I96YT90!!\6%D:7(@
M<')I=FEL96=I;R!D97-C96YD:65N=&4`0?%A9&ER(&%Q=>TZ`$'Q861I<B!G
M<G5P;P!!\6%D:7(@<')I=FEL96=I;P!!\6%D:7(@82`B)7,B('5N(&=R=7!O
M(&1E<V-E;F1I96YT90!!\6%D:7(@82`B)7,B('5N('!R:79I;&5G:6\@9&5S
M8V5N9&EE;G1E`$'Q861I<B!U;B!U<W5A<FEO.@!!\6%D:7(@8V%T96=O<NUA
M`$'Q861I<B!C;VQU;6YA`$'Q861I<B!M:65M8G)O<P!!\6%D:7(@<&%R`$'Q
M861I<B!E;"!M96[Z("5S(&-O;6\@<&%N96P@;&%T97)A;"!D92!-;WII;&QA
M`$'Q861I<B!A(&QA<R!D:7)E8V-I;VYE<SH`0?%A9&ER(&$@;&%S(&1I<F5C
M8VEO;F5S.@!!\6%D:7(@=7-U87)I;P!392!H82!A\6%D:61O("(E<R(@86P@
M<VES=&5M82P@<&5R;R!N;R!S92!P=65D92!A\6%D:7(@;&$@:6YF;W)M86-I
M\VX@861I8VEO;F%L(&1E(&%L=&$Z("5S+@!392!H82!A\6%D:61O("(E<R(@
M86P@<VES=&5M82X@66$@<'5E9&4@:6YI8VEA<B!L82!S97-I\VXN`$'Q861I
M96YD;R!U;F$@;F]T80!,82!A9&EC:?-N(&1E('5S=6%R:6]S(&5S=.$@9&5S
M:&%B:6QI=&%D82X`1&ER96-C:?-N`$1I<F5C8VEO;F5S`$%D;6EN:7-T<F%D
M;W(@+2!D969I;F4@<')I=FEL96=I;W,@9&4@;W1R;W,@=7-U87)I;W,`061M
M:6YI<W1R86-I\VX`06YU;F-I;W,`069G86YI<W3A;@!!;&)A;FEA`$%R9V5L
M:6$`06QI87,`06QI;F5A<@!!;&EN96%C:?-N.@!4;V1O<P!4;V1O<R!L;W,@
M=7-U87)I;W,@875T96YT:69I8V%D;W,`5&]D;W,@;&]S(&=R=7!O<P!4;V1O
M<R!L;W,@<')I=FEL96=I;W,`5&]D;W,@;&]S(&QA9&]S`%!E<FUI=&ER('9A
M<FEA<R!D:7)E8V-I;VYE<P"_4&5R;6ET:7(@8V]N9FEG=7)A8VGS;B!D92!T
M:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_`%EA(&5X:7-T90!!8V-E<V\@24U3
M4"!A;'1E<FYA=&EV;P!#;&%V92!)35-0(&%L=&5R;F%T:79A`%5S=6%R:6\@
M24U04R!A;'1E<FYA=&EV;P!$:7)E8V-I\VX@96QE8W1R\VYI8V$@86QT97)N
M871I=F$`4&QA;G1I;&QA<R!A;'1E<FYA=&EV87,`5&5X=&\@86QT97)N871I
M=F\`4V%M;V$@06UE<FEC86YA`%-E(&AA(&EN9&EC861O('5N('9A;&]R(&EL
M96=A;"X`4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&1E<V-O;F]C:61O+@!!
M;F1O<G)A`$%N9V]L80!!;F=U:6QA`%!R;WAY(&%N\VYI;6\`4F5S<'5E<W1A
M`$%N=.%R=&ED80!!;G1I9W5A('D@0F%R8F%D;W,`07!L:6-A8VGS;@!,:7-T
M82!D92!A<&QI8V%C:6]N97,`3&$@87!L:6-A8VGS;B!E<W3A(&QI<W1A+@!!
M<&QI8V%R(&$@<F5C=7)S;W,@8V]M<&%R=&ED;W,@9&5S8V5N9&EE;G1E<P!!
M<')O8F%R`%1A;6'Q;R!A<')O>&EM861O`$%B<FEL`$%RX6)I9V\@*%=I;F1O
M=W,M,3(U-BD`5&%M8?%O(&1E;"!A<F-H:79O`$YO;6)R92!D96P@87)C:&EV
M;P"_17-T82!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&QA('-O;&EC
M:71U9"!D92!A;'1A(&1E("5S/P"_17-TX2!S96=U<F\@9&4@<75E(&1E<V5A
M(&5L:6UI;F%R("(E<R(@>2!T;V1O<R!S=7,@<W5B9W)U<&]S/P!!<F=E;G1I
M;F$`07)M96YI80!!<FUE;FEO("A!4DU30TE)+3@I`$%R=&4`07)U8F$`07-C
M96YD96YT90!)<VQA($%S8V5N<VGS;@!'<N%F:6-O<R!!<V-I:0!296=I\VX@
M9&4@07-I82]086/M9FEC;P"_4V]L:6-I=&%R(&-O;F9I<FUA8VGS;B!A;G1E
M<R!D92!R96%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O/P!#
M;VQU;6YA<R!D92!A<VEG;F%C:?-N`$EN=&5N=&$@96QI;6EN87(@=6X@9W)U
M<&\@:6YE>&ES=&5N=&4N`$EN=&5N=&$@96QI;6EN87(@=6X@<')I=FEL96=I
M;R!I;F5X:7-T96YT92X`26YT96YT82!M;V1I9FEC87(@=6X@<')I=FEL96=I
M;R!I;F5X:7-T96YT92X`26YT96YT82!M;V1I9FEC87(@=6X@<F5C=7)S;R!C
M;VUP87)T:61O(&EN97AI<W1E;G1E+@!!=')I8G5T;W,`06=O<W1O`$%U<W1R
M86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!.;R!S92!E;F-O;G1R\R!L82!E
M>'1E;G-I\VX@:6UA<"!N96-E<V%R:6$N`$%U=&A?8WER=7,Z($5L(&UO=&]R
M(&-A<F5C92!D92!L87,@8V%P86-I9&%D97,@;F5C97-A<FEA<RX`075T:%]C
M>7)U<SH@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&EM87`@;F5C97-A
M<FEA+@!!=71H7V9T<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N($94
M4"!N96-E<V%R:6$N($-O;7!I;&4@4$A0(&-O;B!L82!O<&-I\VX@+2UE;F%B
M;&4M9G1P+@!!=71H7VEM87`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS
M;B!)34%0(&YE8V5S87)I82X`075T:%]K<F(U.B!.;R!S92!E;F-O;G1R\R!L
M82!E>'1E;G-I\VX@:W)B-2!N96-E<V%R:6$N`$%U=&A?;&1A<#H@3F\@97-T
MX2!S;W!O<G1A9&$@;&$@861I8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@
M1&ER96-T;W)Y`$%U=&A?;&1A<#H@3F\@97-TX2!S;W!O<G1A9&$@;&$@96QI
M;6EN86-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!,1$%0(&YE8V5S
M87)I82X`075T:%]L9&%P.B!.;R!S92!P=65D92!A\6%D:7(@96P@=7-U87)I
M;R`E<RX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<CH@`$%U=&A?
M;&1A<#H@26YC87!A>B!D92!E;&EM:6YA<B!E;"!U<W5A<FEO("5S`$%U=&A?
M;&1A<#H@26YC87!A>B!D92!A8W1U86QI>F%R(&5L('5S=6%R:6\@)7,`075T
M:%]L9&%P.B!.;R!E<W3A('-O<&]R=&%D82!L82!A8W1U86QI>F%C:?-N(&1E
M('5S=6%R:6]S(&1E($%C=&EV92!$:7)E8W1O<GD`075T:%]M8V%L.B!.;R!S
M92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@34-!3"!N96-E<V%R:6$N`$%U=&A?
M<VUB875T:#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N('-M8F%U=&@@
M;F5C97-A<FEA+@!&86QL\R!L82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E
M<G9I9&]R($E-05`N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;@!&86QL\R!L
M82!A=71E;G1I9FEC86-I\VXN("5S`$5L('-E<G9I9&]R(%)!1$E54R!H82!R
M96-H87IA9&\@;&$@875T96YT:69I8V%C:?-N+@!&86QL\R!L82!A=71E;G1I
M9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R($944"X`1F%L;/,@;&$@875T96YT
M:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!334(N`$-A=&5G;W+M87,@9&ES
M<&]N:6)L97,Z`$-A;7!O<R!D:7-P;VYI8FQE<SH`07IE<F)A:6IA;@!%>&-U
M<V%S($)/1D@`4F5G<F5S87(@82!L82!L:6)R971A`%)E9W)E<V%R(&$@;W!C
M:6]N97,@9&4@;&$@;&EB<F5T80!&;VYD;P!#;VQO<B!D92!F;VYD;P!#;VYT
M<F%S9?%A(&ME<F)E<F]S(&EN8V]R<F5C=&$N`$YO;6)R92!D92!U<W5A<FEO
M(&ME<F)E<F]S(&EN8V]R<F5C=&\N`$)A:&%M87,`0F%H<F%I;@!"X6QT:6-O
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!.;R!S92!E;F-O
M;G1R\R!E;"!D:7)E8W1O<FEO(&)A<V4@9&4@:6WA9V5N97,@(B5S(BX`3.UN
M96$@8F%S90!"96QA<G5S`$+I;&=I8V$`0F5L:7IE`$)E;FEN`$)E<FUU9&%S
M`$)H=71A;@!#=6UP;&5A\6]S`$YO('-E(&5N8V]N='+S(&5L(&)L;W%U92`B
M)7,B(&1E(&QA(&%P;&EC86-I\VX@(B5S(BX`3W!C:6]N97,@9&4@8FQO<75E
M`%1I<&\@9&4@8FQO<75E`$YE9W)I=&$`0F]L:79I80!-87)C861O<F5S`$)O
M<F1E`$=R;W-O<B!D96P@8F]R9&4Z`$)O<F1E<P!";W-N:6$@2&5R>F5G;W9I
M;F$`06UB;W,`0F]T<W=A;F$`26YF97)I;W(`27-L82!D92!";W5V970`0G)A
M<VEL`%1E<G)I=&]R:6\@;V-EX6YI8V\@9&4@;&$@26YD:6$@8G)I=.%N:6-A
M`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$QI<W1A(&1E<V]R9&5N861A
M`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`4'5N=&]S(&1E(&1I<W1R
M:6)U8VGS;B!#4D,`0U-6`%!R;W!I961A9&5S(&1E(%]C96QD82XN+@!.;R!S
M92!H82!F:6YA;&EZ861O(&5L(&EN:6-I;R!D92!L82!C86-HZ2X`06=E;F1A
M`$-A;&UA`$-A;6)O>6$`0V%M97+Z;@!.;R!S92!P=65D92!R96%J=7-T87(@
M;&$@8VQA=F4@875T;VWA=&EC86UE;G1E+"!P\VYG87-E(&5N(&-O;G1A8W1O
M(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA+@!.;R!S92!P=65D
M92!E<V-R:6)I<B!E;B!E;"!A<F-H:79O("(E<R(`3F\@<V4@<'5E9&5N(&%D
M;6EN:7-T<F%R(&UA;F5J861O<F5S(&1E('-E<VGS;B!E>'1E<FYO<RX`3F\@
M<V4@<'5E9&4@8V]N96-T87(@86P@<V5R=FED;W(@24U!4#H@)7,`3F\@<V4@
M<'5E9&4@86)R:7(@96P@87)C:&EV;R`B)7,B+@!#86YA9.$`0V%N8V5L87(`
M0V%N8V5L87(@:6YF;W)M92!D92!P<F]B;&5M87,`3F\@<V4@<'5E9&4@96QI
M;6EN87(@96P@87)C:&EV;R`B)7,B+@!.;R!S92!E;F-U96YT<F$@=6X@9&ER
M96-T;W)I;R!T96UP;W)A;"X`3F\@<V4@<'5E9&4@8V]N=&EN=6%R('-I;B!E
M;"!P87+A;65T<F\@)W1A<F=E=$9I;&4G+@!.;R!S92!P=65D92!E;&EM:6YA
M<B!E;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&5L:6UI;F%R+"!T
M:65N92`E9"!D97-C96YD:65N=&5S+@!.;R!S92!P=65D92!R96]R9&5N87(L
M(&5L(&[Z;65R;R!D92!E;G1R861A<R!Q=64@<V4@9&5S96$@;W)D96YA<B!N
M;R!C;VEN8VED92!C;VX@;&%S(&%L;6%C96YA9&%S+@!.;R!S92!P=65D92!D
M:7)I9VER(&5L(&UE;G-A:F4@86P@;OIM97)O(&5S<&5C:69I8V%D;RX`0V%B
M;R!697)D90!3=6)T[71U;&\`4')O=F5E9&]R`$-A=&5G;W+M87,@>2!E=&EQ
M=65T87,`0V%T96=O<NUA`$ES;&%S($-A:6WA;@!496SI9F]N;R!M\W9I;`!0
M<F]P:65D861E<R!D92!C96QD80!-87)G96X@9&4@8V5L9&$Z`%!R;W!I961A
M9&5S(&1E(&-E;&1A`$5S<&%C:6%D;R!D92!C96QD83H`5&5LZ69O;F\@;?-V
M:6P`0^EL=&EC;R`H25-/+3@X-3DM,30I`$-E;G1R87(`4F5P^F)L:6-A($-E
M;G1R;V%F<FEC86YA`$5U<F]P82!#96YT<F%L("A)4T\M.#@U.2TR*0!$971A
M;&QE<R!D96P@8V5R=&EF:6-A9&\`4')O<&EE=&%R:6\@9&5L(&-E<G1I9FEC
M861O`%!O;.UT:6-A<R!D96P@8V5R=&EF:6-A9&\`0VAA9`!#86UB:6%R`$-A
M;6)I92!L82!C;VYT<F%S9?%A`$-A;6)I82!E;"!N;VUB<F4@>2!L82!D:7)E
M8V-I\VX@96QE8W1R\VYI8V$@=FES:6)L97,@86P@;&5E<B!O(')E<W!O;F1E
M<B!A('-U<R!M96YS86IE<RX`0V%M8FEA<B!O<&-I;VYE<R!D92!O<F1E;F%C
M:?-N('D@=FES=6%L:7IA8VGS;B!D92!N;W1A<RX`3&$@8V]N9FEG=7)A8VGS
M;B!A8W1U86P@;F\@<V]P;W)T82!E;"!C86UB:6\@9&4@8V]N=')A<V7Q87,N
M(%#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@9&5L
M('-I<W1E;6$N`$=RX69I8V\`5F5R:69I8V%R(%]V[6YC=6QO+BXN`$-H:6QE
M`$-H:6YA`$-H:6YO('-I;7!L:69I8V%D;R`H1T(R,S$R*0!#:&EN;R!T<F%D
M:6-I;VYA;"`H0FEG-2D`07!L:6-A8VGS;CH`16QI:F$@=6YA(&-O;G1R87-E
M\6$`16QI:F$@=6X@;F]M8G)E(&1E('5S=6%R:6\`16QI:F$@8_-M;R!M;W-T
M<F%R(&QA<R!F96-H87,Z`%-E;&5C8VEO;F%R('1I<&\@9&4@97-T:6QO(&1E
M(&QI<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D87,I`$5L:6IA(&QA<R!C871E
M9V]R[6%S(&1E(&YO=&%S(&QI<W1A9&%S(&5N(&QA('9I<W1A(')E<W5M96XN
M`$5L:6IA('-U(&QI8G)E=&$@<&]R(&]M:7-I\VXN`$ES;&$@9&4@4&%S8W5A
M`$YO('-E(&5N8V]N='+S(&QA(&1E9FEN:6-I\VX@9&4@8VQA<V4@9&4@)7,N
M`$QI;7!I87(`3&EM<&EA<B!F;W)M=6QA<FEO`$5L:6UI;F%R(&5T:7%U971A
M<R!-4T]F9FEC90!";W)R87(@8V]N<W5L=&$`0F]R<F%R('5S=6%R:6\Z("5S
M`$)O<G)A<B!U<W5A<FEO`$)O<G)A<B!D871O<R!D96P@=7-U87)I;P!$97-P
M96IA9&\@=&%R9.UO`$AA9V$@8VQI8VL@<&%R82!S96=U:7(`0VQI8VMA=&5L
M;"!P;W(@2%144`!#97)R87(@=F5N=&%N80!.=6)E<P!.=6)E<R!T96UP<F%N
M87,`;G5B;W-O`$ES;&%S(&1E(&-O8V]S("A+965L:6YG*0!/8W5L=&%R(&)A
M<G)A(&QA=&5R86P`0V]L87!S87(@8F]R9&5S`$-O;&]M8FEA`$-O;&]R`%-E
M;&5C=&]R(&1E(&-O;&]R`%-E;&5C8VGS;B!D92!C;VQO<@!#;VQU;6YA<SH`
M5.UT=6QO<R!D92!L87,@8V]L=6UN87,`0_-M:6-S`$-O;6%N9&\`26YTZ7)P
M<BX@8V]M86YD;W,`0V]M96YT87)I;P!.;VUB<F4@8V]M^FX`0V]M;W)O<P!#
M;VUP8?'M80!/<F1E;F%D;W)E<P!#;VYD:6-I\VX`0V]N9&EC:6]N97,`1&EF
M97)E;F-I87,@9&4@;&$@8V]N9FEG=7)A8VGS;@!#;VYF:6=U<F%C:?-N('!A
M<F$@<VEN8W)O;FEZ86-I\VX@8V]N(%!$07,L($WS=FEL97,@8V]N(&%G96YD
M82!Y($]U=&QO;VLN`$QA(&-O;F9I9W5R86-I\VX@97-TX2!D97-A8W1U86QI
M>F%D82X`0V]N9FEG=7)A<B`E<P!#;VYF:7)M87(@8V]N=')A<V7Q80!#;VYG
M;P!#;VYG;RP@4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1E;`!&86QL\R!L82!C
M;VYE>&GS;BX`1F%L;/,@;&$@8V]N97AI\VXZ(`!392!H82!R96-H87IA9&\@
M;&$@8V]N97AI\VX@86P@<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N`%-E
M(&AA(')E8VAA>F%D;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!D92!C;&%V
M97,@</IB;&EC;RX@36]T:79O.B`E<R`H)7,I`$AA(&9A;&QA9&\@;&$@8V]N
M97AI\VX@86P@<V5R=FED;W(@1E10+@!#;VYT86-T;W,`4V4@:&%N(&'Q861I
M9&\@8V]R<F5C=&%M96YT92!L;W,@8V]N=&%C=&]S(&$@<W5S(&1I<F5C8VEO
M;F5S`%1I<&\@9&4@8V]N=&5N:61O(&1E;"!A<F-H:79O(&-O;7!R:6UI9&\Z
M(`!#;VYT96YI9&\@9&4@(B5S(@!#;VYT:6YU87(`27-L87,@0V]O:P!#;V]K
M:64`0V]P:6%R`$9A;&SS(&QA(&-O<&EA.B`E<P!#;W!I87(@<V5L96-C:?-N
M`$E$(&1E(&-O<W1E`$-O<W1A(%)I8V$`0V]S=&$@9&4@36%R9FEL`$YO('-E
M('!U961E(&-I9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E
M('!U961E(&9I<FUA<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E
M('!U961E(&-I9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%,O34E-10!.;R!S
M92!P=65D92!F:7)M87(@96P@;65N<V%J92!M961I86YT92`@4R]-24U%`$YO
M('-E('!U961E(&'Q861I<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@
M96YL87IA<B!A;"!S97)V:61O<B!,1$%0+@!.;R!S92!P=65D92!C;VUP<F]B
M87(@96P@<V%L9&\N("5S`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I
M9&]R($Q$05`N`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R("(E
M<R(@;65D:6%N=&4@1E10.B`E<P!.;R!S92!P=65D92!C<F5A<B!L82!L:7-T
M82!D92!D:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E;B!D97-C:69R87(@
M;&]S(&1A=&]S(%!'4#H@`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A
M=&]S(%,O34E-12X`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@8V]N=&%C=&\N
M("5S`$YO('-E('!U961E(&5L:6UI;F%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U
M8VGS;BX@)7,`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9W5I\VX@9&4@86-T
M=6%L:7IA8VGS;B!D92!C;VYF:6=U<F%C:?-N("(E<R(N`$YO('-E('!U961E
M(&1E=&5R;6EN87)A(&QA(&1I<F5C8VGS;B!D92!C;W)R96\@9&5L(&1E<W1I
M;F%T87)I;RX`3F\@<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T82!D92!D:7)E
M8V-I;VYE<R!C;VUP;&5T82X`3F\@<V4@<'5E9&4@=')A97(@;&$@;&ES=&$@
M9&4@9&ES=')I8G5C:?-N(&-O;7!L971A+@!.;R!S92!P=65D92!T<F%E<B!L
M82!L:7-T82!C;VUP;&5T82!D92!L:7-T87,@9&4@9&ES=')I8G5C:?-N+@!.
M;R!S92!P=65D92!C87)G87(@;&$@97-T<F%T96=I82`B)7,B+@!.;R!S92!P
M=65D92!C<F5A<B!E;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&]B
M=&5N97(@;&$@8VQA=F4@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=F5S
M+@!.;R!S92!P=65D92!A8G)I<B`B)7,B('!A<F$@97-C<FEB:7(N`$YO('-E
M('!U961E(&%B<FER("5S+@!.;R!S92!P=65D92!A8G)I<B!E;"!M\V1U;&\@
M9&4@=&%R96%S(&1E(&UA;G1E;FEM:65N=&\@)7,`3F\@<V4@<'5E9&4@86)R
M:7(@96P@9&ER96-T;W)I;R`B)7,B+@!.;R!S92!P=65D92!L;V-A;&EZ87(@
M96P@<V5R=FED;W(@3$1!4"X`3F\@<V4@<'5E9&4@;&5E<B`E<RX`3F\@<V4@
M<'5E9&4@<F5S=&%B;&5C97(@;&$@8V]N=')A<V7Q82!D96P@=7-U87)I;R!S
M;VQI8VET861O+B!087)T92!D92!L;W,@9&5T86QL97,@;R!T;V1O<RP@<V]N
M(&EN8V]R<F5C=&]S+B!0<G5E8F4@;W1R82!V97H@;R!P\VYG87-E(&5N(&-O
M;G1A8W1O(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA('!A<F$@
M;>%S(&EN9F]R;6%C:?-N+@!.;R!S92!P=65D92!O8G1E;F5R(&QA($%#3"X`
M3F\@<V4@<'5E9&4@;V)T96YE<B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S
M+B`E<P!.;R!S92!P=65D92!O8G1E;F5R(&QA(&QI<W1A(&1E(&1I<W1R:6)U
M8VGS;BX@)7,`3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S(&QI<W1A<R!D92!D
M:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E;B!O8G1E;F5R(&QA<R!C87!A
M8VED861E<R!D96P@<V5R=FED;W(`3F\@<V4@<'5E9&4@<F5S=&%U<F%R(&QA
M(&-O;F9I9W5R86-I\VXN`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C
M=&]R:6\@(B5S(BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;VYF:6=U<F%C
M:?-N(&1E("5S+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L
M82!C;VYF:6=U<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I
M82!D92!L82!C;VYF:6=U<F%C:?-N.B`E<P!.;R!S92!P=65D92!G=6%R9&%R
M(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS
M;B!E;CH@(B5S(BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;W!I82`E<R!D
M92!L82!C;VYF:6=U<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R(&5L(&%R
M8VAI=F\@)7,@9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@=71I;&EZ87(@=6YA
M(&1E(&QA<R!O<&-I;VYE<R!P87)A(')E<W1A=7)A<B!E;"!C\V1I9V\@9&4@
M)7,@;R!C;W!I87(@;6%N=6%L;65N=&4@82`E<R!E;"!C\V1I9V\@<VEG=6EE
M;G1E+@!.;R!S92!P=65D92!B=7-C87(@96X@96P@<V5R=FED;W(@3$1!4"X`
M3F\@<V4@<'5E9&4@9&5S=FEN8W5L87(@(B5S(BX`3F\@<V4@<'5E9&4@86-T
M=6%L:7IA<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@86-T=6%L:7IA
M<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E(&5S
M8W)I8FER(&QA(&-O;F9I9W5R86-I\VX@9&4@(B5S(CH@)7,`3F\@<V4@<'5E
M9&4@;&]C86QI>F%R(&5L('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL82X@0V]M
M<')U96)E('%U92!E<W3I(&%B:65R=&\N`$YO('-E('!U961E;B!O=&]R9V%R
M(&%L('5S=6%R:6\@(B5S(B!L;W,@<VEG=6EE;G1E<R!D97)E8VAO<R!P87)A
M(&QA(&-A<G!E=&$@(B5S(CH@)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O
M<P!#<F5A<@!#<F5A('5N(';M;F-U;&\`0W)E87(`0W)E87(@<W5B8V%R<&5T
M87,`0W)E861O`%!R:79I;&5G:6]S(&1E(&-R96%D;W(`3OIM97)O(&1E('1A
M<FIE=&$@9&4@8W+I9&ET;P!#<F]A8VEA`$-U8F$`-"!&87-E<R!A8W1U86QE
M<P!397-I;VYE<R!A8W1U86QE<P!(;W)A(&%C='5A;`!54DP@86-T=6%L`%5S
M=6%R:6]S(&%C='5A;&5S`%1I96UP;R!A8W1U86P`0V]N9&EC:?-N(&%C='5A
M;#H@`$5S=&EL;R!A8W1U86P`4&5R<V]N86QI>F$@;&%S('1A<F5A<R!A(&5J
M96-U=&%R(&%L(&EN:6-I87(@<V5S:?-N(&5N("5S+@!#;W)T87(`0V]R=&%R
M('-E;&5C8VGS;@!#:&EP<F4`0VER[6QI8V\@*$M/23@M4BD`0VER[6QI8V\@
M*%=I;F1O=W,M,3(U,2D`0VER[6QI8V\O56-R86YI86YO("A+3TDX+54I`%)E
M</IB;&EC82!#:&5C80!$1`!$4TX@*'9E82!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E<R]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M`$1I87)I86UE;G1E`,%R7V)O;"!D871O<P!#;VYS=6QT82!D92!L82!B87-E
M(&1E(&1A=&]S`$9E8VAA`%-E(&AA(')E8VEB:61O(&QA(&9E8VAA`%-E;&5C
M8VGS;B!D92!F96-H80!$[6$`15]L:6UI;F%R(&-O;'5M;F$`1&EC:65M8G)E
M`$[Z;65R;W,@9&5C:6UA;&5S`%)E9'5C:7(@<V%N9W)A9&\`4&]R(&]M:7-I
M\VX`0V]L;W(@<&]R(&]M:7-I\VX`261E;G1I9&%D('!O<B!O;6ES:?-N`$QI
M8G)E=&$@<&]R(&]M:7-I\VXZ`%-H96QL('!O<B!O;6ES:?-N`$-R:71E<FEO
M(&1E(&-L87-I9FEC86-I\VX@<&]R(&]M:7-I\VXZ`%-E;G1I9&\@9&4@8VQA
M<VEF:6-A8VGS;B!P;W(@;VUI<VGS;CH`1&5F:6YI8VEO;F5S`$5L:6UI;F%R
M`$5L:6UI;F%R(&-E;&1A`$-O;F9I<FUA8VGS;B!D92!E;&EM:6YA8VGS;@!%
M;&EM:6YA<B!G<G5P;P!%;&EM:6YA<B!R96=I<W1R;P!%;&EM:6YA<B!P<FEV
M:6QE9VEO`$5L:6UI;F%R('D@=F%C:6%R(&UE;G-A:F5S`$-O;7!O<G1A;6EE
M;G1O(&1E;"!B;W3S;B!%;&EM:6YA<@!%;&EM:6YA<B!C96QD80!%;&EM:6YA
M<B!C;VQU;6YA`$5L:6UI;F%R('!L86YT:6QL87,@86QT97)N871I=F%S(&5X
M:7-T96YT97,`16QI;6EN87(@;65N<V%J97,`16QI;6EN87(@<')I=FEL96=I
M;W,@9&4@(B5S(@"_16QI;6EN87(@<')I=FEL96=I;W,@<&%R82`B)7,B('D@
M8W5A;'%U:65R('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E/P!%;&EM:6YA<B!F
M:6QA`$5L:6UI;F%R(&ED96YT:61A9"!S96QE8V-I;VYA9&$`16QI;6EN87(@
M<W5B8V%R<&5T87,`16QI;6EN82!L82!C;VQU;6YA(&%C='5A;`!%;&EM:6YA
M(&QA(&9I;&$@86-T=6%L`$5L:6UI;F%R(&YO=&$`4V4@:&$@96QI;6EN861O
M(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS
M;B`B)7,B+@!(;W)A(&1E(&5N=')E9V$Z`$1I;F%M87)C80!$97-C96YD96YT
M90!$97-C<FEB82!E;"!P<F]B;&5M80!$97-C<FEP8VGS;@!$97-C<FEP8VGS
M;CH`1&5T86QL97,@*'1A;6)IZ6X@96X@96P@87)C:&EV;R!D92!R96=I<W1R
M;R!D92!(;W)D92DZ`%-E(&AA;B!R96=I<W1R861O(&QO<R!D971A;&QE<R!P
M87)A(&5L(&%D;6EN:7-T<F%D;W(N`$1E<V%R<F]L;&\`4'5N=&\@9&4@8V]N
M9&5N<V%C:?-N`%!U;G1O(&1E(&-O;F1E;G-A8VGS;B!D92!L82#Z;'1I;6$@
M:&]R83H@`%!U;G1O(&1E(&-O;F1E;G-A8VGS;CH@`$1E(&EZ<75I97)D82!A
M(&1E<F5C:&$`1&4@9&5R96-H82!A(&EZ<75I97)D80!$:7)E8W1O<FEO`+]-
M;W-T<F%R(&5N(&9O<FUA=&\@9&4@,C0M:&]R87,_`$]P8VEO;F5S(&1E(%9I
M<W5A;&EZ86-I\VX`36]S=')A<B!P<F]N\W-T:6-O(&1E=&%L;&%D;P!-;W-T
M<F%R('!R;V[S<W1I8V\@*%1!1BD`1F]R;6%T;R!D92!V:7-U>F%L:7IA8VGS
M;@!.;W1I9FEC86-I\VX@9&4@8V]N<W5L=&$`1&II8F]U=&D`3F\@96QI;6EN
M87(`3F\@86-C961E<B!D:7)E8W1A;65N=&4@82!M86EN=&5N86YC92YP:'``
MOT1E<V5A(&-O;F9I<FUA<B!L82!E;&EM:6YA8VGS;B!D92!L87,@96YT<F%D
M87,_`+]#;VYT:65N92!L82!P<FEM97)A(&9I;&$@;&]S(&YO;6)R97,@9&4@
M;&]S(&-A;7!O<S\@4VD@97,@87/M+"!S96QE8V-I;VYE(&5S=&$@8V%S:6QL
M83H`1&]M:6YI8V$`4F5P^F)L:6-A($1O;6EN:6-A;F$`OTYO(&1I<W!O;F4@
M9&4@8W5E;G1A/R!3;VQI8^UT96QA+@!$97-C87)G87(`1&5S8V%R9V%R("5S
M`$1E<V-A<F=A<B!L82!C;VYF:6=U<F%C:?-N(&=E;F5R861A(&-O;6\@=6X@
M9W5I\VX@4$A0+@!,:7-T82!D97-P;&5G86)L90!$<F]G87,`0V]R<F5O`$-O
M;G1R;VQA9&]R(&1E('!A<V%R96QA($-O<G)E;RUA+5--4R!P87)A('!R;W9E
M961O<F5S('%U92!P<F]P;W)C:6]N96X@97-T92!S97)V:6-I;RX`15)2`$5C
M=6%D;W(`36]D:69I8V%R`$UO9&EF:6-A<B`B)7,B`$UO9&EF:6-A<B!B;&]Q
M=64`36]D:69I8V%R(&=R=7!O`$UO9&EF:6-A<B!N;W1A`$UO9&EF:6-A<B!P
M<FEV:6QE9VEO`$UO9&EF:6-A<B!P<FEV:6QE9VEO<P!-;V1I9FEC87(@<')I
M=FEL96=I;W,@9&4@)7,`36]D:69I8V%R(&QA<R!C871E9V]R[6%S('D@<W5S
M(&-O;&]R97,`36]D:69I8V%R(&]P8VEO;F5S(&1E.@!-;V1I9FEC87(@<')I
M=FEL96=I;W,@9&4@(B5S(@!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,`
M161U8V%C:?-N`$5G:7!T;P!%;"!386QV861O<@!%;&5M96YT;RXN+@!%;0!#
M;W)R96\`1&ER96-C:?-N(&1E(&-O<G)E;P!,87,@9&ER96-C:6]N97,@9&4@
M8V]R<F5O('1I96YE;B!Q=64@8V]I;F-I9&ER+@!#;W)R96\@8V]N(&-O;F9I
M<FUA8VGS;@!087-A<F5L82!#;W)R96\M82U335,`16UO=&EC;VYE<P!686-I
M87(@;F]T80!-96YS86IE(&5N(&)L86YC;P!297-U;'1A9&\@96X@8FQA;F-O
M+@!,:6UP:6%R('3I<FUI;F]S(&1E(&+Z<W%U961A`+]097)M:71I<B!I;G-E
M<F-I\VX@9&4@:6WA9V5N97,@9&4@;&%S($=A;&5R[6%S(&1E(&9O=&]S/P"_
M4&5R;6ET:7(@;65N^B!D92!C;VYT97AT;R!D96P@8F]T\VX@9&5R96-H;R!D
M96P@<F%T\VX_`$'Q;R!D92!T97)M:6YA8VGS;@!!9W)A;F1A<B!E9&ET;W(`
M26YT<F]D=7IC82!U;F$@<')E9W5N=&$@9&4@<V5G=7)I9&%D('%U92!S92!L
M92!F;W)M=6QA<N$@<VD@<')E8VES82!R96%J=7-T87(@;&$@8V]N=')A<V7Q
M82P@<"YE+B`GOT-UX6P@97,@96P@;F]M8G)E(&1E('-U(&UA<V-O=&$_)SH`
M26YT<F]D=7IC82!A<77M(&QA(%523"!D92!L82!I;6%G96X`26YT<F]D=7IC
M82!L87,@;&5T<F%S(&1E(&1E8F%J;SH`1W5I;F5A($5C=6%T;W)I86P`17)I
M=')E80!%<G)O<@!%<G)O<B!A;"!C<F5A<B!E;"!B;&]Q=64Z("5S`$5R<F]R
M(&%L(&5L:6UI;F%R(&%N8VQA(&1E('-I;F-R;VYI>F%C:?-N.B`E<P!%<G)O
M<B!A;"!E;&EM:6YA<B!E;"!R96=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;CH@
M)7,`17)R;W(@86P@;V)T96YE<B!C;VYT96YI9&]S.B`E<P!%<G)O<B!A;"!A
M8W1U86QI>F%R(&QA(&-O;G1R87-E\6$Z("5S`$5R<F]R(&-O;B!E;"!M96YS
M86IE(&1E(&-O<G)E;RX`17)R;W(@86P@97-C<FEB:7(@(B5S(BX`17-T;VYI
M80!%=&EO<.UA`,ET;FEC;P!%=7)O<&$`0V%D82`Q-2!M:6YU=&]S`$-A9&$@
M,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI;G5T;W,`0V%D
M82!I;FEC:6\@9&4@<V5S:?-N`$-A9&$@;65D:6$@:&]R80!#861A(&UI;G5T
M;P!686QO<F5S(&1E(&5J96UP;&\Z`$5J96-U=&%R`$5X<&%N9&ER`$UO<W1R
M87(@8F%R<F$@;&%T97)A;`!S92!E<W!E<F%B82`G*2<`4V4@97-P97)A8F$@
M=6YA(/IN:6-A('!A;&%B<F$@;R!U;B!TZ7)M:6YO(&1E(&+Z<W%U961A(&5N
M=')E8V]M:6QL861O`$9E8VAA(&1E('9E;F-I;6EE;G1O`$5X<&]N96YT90!%
M>'!O<G1A<@!%>'!O<G1A<B!N;W1A<P!#;VQO<B!D92!L971R80!#87)G87(@
M;&$@8V]N9FEG=7)A8VGS;B!P;W(@1E10`%1E7WAT;R!C;VUP;&5T;P!&86QL
M;R!A;"!T<F%E<B!L87,@<')E9F5R96YC:6%S+@!);F-A<&%Z(&1E(&-O;F5C
M=&%R<V4@86P@<V5R=FED;W(@3$1!4"X`26YC87!A>B!D92!C;VYE8W1A<G-E
M(&%L('-E<G9I9&]R(%--0BX`1F%L;&\@86P@8V]P:6%R(&1E("(E<R(N`$9A
M;&QO(&%L(&-O<&EA<B!A("(E<R(N`$9A;&QO(&%L(&-R96%R('5N82!C;VYE
M>&GS;B!305-,`$9A;&QO(&%L('1R87-L861A<B`B)7,B+@!&86QL;R!A;"!R
M96-U<&5R87(Z("5S`$1E<W!E:F%D;P!)<VQA<R!-86QV:6YA<R`H1F%L:VQA
M;F0I`$ES;&%S($9A<F]E`$5R<F]R(&ER<F5C=7!E<F%B;&4Z`$9A>`!&87AE
M<P!&96)R97)O`%-E('-I96YT92!C;VUO`%-E('-I96YT92!C;VUO.B``4&]C
M87,@;&QU=FEA<P!%<V-A<V\@86=U86-E<F\@9&4@;FEE=F4`36%T<FEZ(&1E
M(&-A;7!O<P!#05!40TA!(&1E($9I9VQE=`!,971R82!D92!&:6=L970`1FEJ
M:0!!<F-H:79O`$ZZ(&1E(&%R8VAI=F]S.B`E<R!A<F-H:79O`$ZZ(&1E(&%R
M8VAI=F]S.B`E<R!A<F-H:79O<P!!<F-H:79O<P!.;VUB<F4@9&4@87)C:&EV
M;P!396QE8V-I\VX@9&4@87)C:&EV;P!#87)G87(@87)C:&EV;P!,82!C87)G
M82!D92!A<F-H:79O<R!N;R!E<W3A('-O<&]R=&%D82X`1FEL=')O<P!&:6YL
M86YD:6$`0W5A<G1O(&-R96-I96YT90!#=6%R=&\@8W)E8VEE;G1E`%)A>O-N
M(&9I:F$`5F]L=&5A<@!$:7-P;W-I8VGS;@!.:65B;&$`3&$@8V%R<&5T82`E
M<R!N;R!E>&ES=&4N`$-O;&]R(&1E(&QE=')A`$-O;6ED80!087)A(&YA=F5G
M861O<F5S('%U92!N;R!A9&UI=&%N(&EMX6=E;F5S`%!R;V[S<W1I8V\@*%1!
M1BD`1.UA<R!D96P@<')O;O-S=&EC;R`H=&5N9V$@96X@8W5E;G1A('%U92!E
M;"!P<F]N\W-T:6-O(&9A8VEL:71A9&\@:6YC;'5Y92!T86YT;R!E;"!D[6$@
M8V]M;R!L82!N;V-H93L@=6X@;OIM97)O(&=R86YD92!S92!T<F%D=6-I<N$@
M96X@=6X@8FQO<75E(&UU>2!A;F-H;RD`OTAA(&]L=FED861O(&QA(&-O;G1R
M87-E\6$_`$9O<FUU;&%R:6]S`$9O<G1U;F$`5&EP;R!D92!F;W)T=6YA`$9O
M<G1U;F%S`$9O<G1U;F%S(#(`1F]R;W,`4F5E;G;M;W,`5FEE`$9R86UE<P!&
M<F%N8VEA`$9R86YC:6$L($UE=')O<&]L:71A;F$`1W5A>6%N82!F<F%N8V5S
M80!0;VQI;F5S:6$@9G)A;F-E<V$`5&5R<FET;W)I;W,@9G)A;F-E<V5S(&1E
M;"!S=7(`1&4`1&5L(`!$97-C<FEP8VGS;B!C;VUP;&5T80!,=6YA(&QL96YA
M`$YO;6)R92!C;VUP;&5T;P!'86+S;@!'86QE<NUA(&1E(&QA('%U92!O8G1E
M;F5R(&QA(&EM86=E;@!'86QE<NUA.@!'86UB:6$`3W!C:6]N97,@9V5N97)A
M;&5S`$=E;F5R87(@8V]N9FEG=7)A8VGS;B!D92`E<P!#\V1I9V\@9V5N97)A
M9&\`1V5O<F=I80!!;&5M86YI80!':&%N80!':6)R86QT87(`3F]M8G)E(&EN
M9&EC861O`$]P8VEO;F5S(&=L;V)A;&5S`$ER`$=O961E;`!-87!A<R!D92!'
M;V]G;&4`0OIS<75E9&$@96X@1V]O9VQE`$5S8V%L82!D92!G<FES97,`1W)E
M8VEA`$=R:65G;R`H25-/+3@X-3DM-RD`1W)O96YL86YD:6$`1W)A;F%D80!!
M9&UI;FES=')A8VGS;B!D92!G<G5P;W,`3&]S(&YO;6)R97,@9&4@9W)U<&\@
M;F\@<'5E9&5N(&1E:F%R<V4@96X@8FQA;F-O`$=R;W5P7VQD87`Z($YO('-E
M('!U961E(&'Q861I<B!E;"!G<G5P;R`E<RX@R7-T;R!E<R!L;R!Q=64@9&EJ
M;R!E;"!S97)V:61O<CH@`$=R;W5P7VQD87`Z($EN8V%P87H@9&4@96QI;6EN
M87(@96P@9W)U<&\@)7,`1W)O=7!?;&1A<#H@26YC87!A>B!D92!A8W1U86QI
M>F%R(&5L(&=R=7!O("5S`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!'=6%T96UA
M;&$`1W5E<FYE<V5Y`%!R:79I;&5G:6]S(&1E(&EN=FET861O`$PN(&EN=FET
M861O<P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=6%Y86YA`$A434P`2%1-3"!S
M92!N:65G82!C;V)A<F1E;65N=&4@82!E;&EM:6YA<B!L82#Z;'1I;6$@8V5L
M9&$@9&4@;&$@9FEL82X`2%1-3$%R96$@<V4@;FEE9V$@8V]B87)D96UE;G1E
M(&$@96QI;6EN87(@;&$@^FQT:6UA(&-O;'5M;F$@9&4@;&$@=&%B;&$N`$A4
M34P@<V4@;FEE9V$@8V]B87)D96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA
M(&9I;&$@9&4@;&$@=&%B;&$N`$YO('-E(&5N8V]N='+S(&QA(&%U=&5N=&EF
M:6-A8VGS;B!(5%10+@!(86ET[0!!;&=O<FEM;R!(87-H`$YE8FQI;F$`0V%B
M96-E<F$`0V%B96-E<F%S`$ES;&$@2&5A<F0@92!)<VQA<R!-8T1O;F%L9`!4
M;W)M96YT82!T<F]P:6-A;"!I;G1E;G-A`$AE8G)E;R`H25-/+3@X-3DM."U)
M*0!!;'1U<F$`07EU9&$`07EU9&$@9&5L(&5D:71O<@!!>75D86YT90!(96UI
M<V9E<FEO`$%Q=>T@=&EE;F4@96P@8V]M:65N>F\@9&5L(&%R8VAI=F\Z`$%L
M=&$`7TEN:6-I;P!386YT82!3961E("A#:75D860M17-T861O(&1E;"!6871I
M8V%N;RD`26YI8VEO`$1O;6EC:6QI;P!$:7)E8W1O<FEO('!E<G-O;F%L`%1E
M;.EF;VYO('!A<G1I8W5L87(`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!392!H86X@96YC;VYT<F%D;R!D871O<R!834P@)7,@;F\@
M=N%L:61O<R!E;B!E;"!M96YS86IE("5S`$AO<F1E+TMO;&%B.B!.:6YG^FX@
M;65N<V%J92!C;W)R97-P;VYD92!A;"!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z
M($YO('-E(&5N8V]N='+S('5N(&]B:F5T;R!D92!T:7!O("5S(&5N(&5L(&UE
M;G-A:F4@)7,`2&]R9&4O2V]L86(Z(%-E(&AA(&5L:6UI;F%D;R!C;W)R96-T
M86UE;G1E("5S("(E<R(`2&]R9&4O2V]L86(Z($5L(&UO=&]R(&1E(&EN=&5G
M<F%C:?-N('!R96-I<V$@9&4@;&$@97AT96YS:?-N(%!(4"`G9&]M>&UL)P!(
M;W)D92]+;VQA8CH@26YC87!A>B!D92!C<F5A<B!N=65V;R#A<F)O;"!834P@
M9&5L(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@26YC87!A>B!D92!E;&EM:6YA
M<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26YC87!A>B!D92!O8G1E;F5R
M($E$($U)344@9&4@;&$@<&%R=&4@9&4@=&EP;R`E<P!(;W)D92]+;VQA8CH@
M26YC87!A>B!D92!S:6YC<F]N:7IA<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@26YC87!A>B!D92!S:6YC<F]N:7IA<B!E;&5M96YT;W,@8V]M<&%R=&ED
M;W,Z("5S`$AO<F1E+TMO;&%B.B!%;&5M96YT;R!C;VUP87)T:61O(&1E<V-O
M;F]C:61O("(E<R(`3.UN96$@:&]R:7IO;G1A;`!-87)G96X@:&]R:7IO;G1A
M;`!(;W)I>F]N=&%L.@"_0_-M;R!L;&5G\R!H87-T82!A<77M/R`HH4-O;75N
M[7%U96QO+"!P;W(@9F%V;W(A*0"_0W5A;G1A<R!C;VQU;6YA<R!D97-E82!C
M;VUB:6YA<C\`OT-UX6YT;W,@8V%M<&]S("AC;VQU;6YA<RD@:&%Y/P"_0W5A
M;G1A<R!F:6QA<R!D97-E82!C;VUB:6YA<C\`2'5M961A9`!(=6UE9&%D.B``
M2'5M;W)I<W1A<P!(=6YG<NUA`$AA(&9A;&QA9&\@;&$@8W)E86-I\VX@9&5L
M(&)U>O-N($E-05`Z("5S`$AA(&9A;&QA9&\@;&$@96QI;6EN86-I\VX@9&5L
M(&)U>O-N($E-05`Z("5S`$AA(&9A;&QA9&\@;&$@8W)E86-I\VX@9&4@97-P
M86-I;R!A<VEG;F%D;R!D96P@8G5Z\VX@24U!4#H@)7,`1&ER96-C:?-N($E0
M`$QA(&1I<F5C8VGS;B!)4"!N;R!E<W3A(&1I<W!O;FEB;&4N`$QA(&1I<F5C
M8VGS;B!)4"!N;R!E<W3A(&5N=')E(&)L;W%U97,@0TE$4B!P97)M:71I9&]S
M+@!6:6]L86-I\VX@;&]C:V1O=VX@25`N`$E?;G-E<G1A<B!F:6QA(&5N8VEM
M80!)<VQA;F1I80!3\VQO(&EC;VYO<P!)8V]N;W,@9&4@)7,`26-O;F]S(&-O
M;B!T97AT;P!.;VUB<F4@9&4@;&$@:61E;G1I9&%D.@!3:2!N;R!S92!M=65S
M=')A(&-O<G)E8W1A;65N=&4L("5S('!A<F$@86)R:7)L;R!E;B!U;F$@=F5N
M=&%N82!N=65V82X`4VD@;F\@=F4@;FEN9_IN(&EC;VYO(&UE9&EA;G1E($EN
M=&5R;F5T($5X<&QO<F5R+"!P=65D92!T96YE<B!Q=64@86-T:79A<B!E<W1A
M(&-A<VEL;&$@<&%R82!D97-A8W1I=F%R(&QA('1R86YS<&%R96YC:6$@4$Y'
M+@!3:2!V92!E<W1E(&UE;G-A:F4@<VEN(&YI;F=U;F$@:6UA9V5N+"!L82!I
M;6%G96X@<75E('%U:65R92!C87)G87(@;F\@<V4@<'5E9&4@;6]S=')A<B!E
M;B!S=2!N879E9V%D;W(N`%9I<W1A('!R979I83H`55),(&1E(&QA(&EM86=E
M;@!54DP@9&4@;&$@:6UA9V5N.@!);6%G96X@9&4@;&$@9V%L97+M80!);6%G
M96X@9&4@;&$@9V%L97+M83H`4V4@:&$@8V%R9V%D;R!L82!I;6%G96X`26WA
M9V5N97,`26UP;W)T87(@;F]T87,N(%!A<V\@)60`26UP;W)T87(L('!A<V\@
M)60`26UP;W)T87(O17AP;W)T87(@;F]T87,`0V%M<&\@:6UP;W)T861O.B`E
M<P!#86UP;W,@:6UP;W)T861O<SH`26Y?<V5R=&%R(&9I;&$@9&5B86IO`%-E
M(&AA(&EN9&EC861O('5N(&/S9&EG;R!D92!A8V-I\VX@:6YC;W)R96-T;RX`
M3F]M8G)E(&1E('5S=6%R:6\@>2]O(&-O;G1R87-E\6$@:6YC;W)R96-T;W,N
M`$YO;6)R92!D92!U<W5A<FEO(&\@9&ER96-C:?-N(&%L=&5R;F%T:79A(&EN
M8V]R<F5C=&]S+B!6=65L=F$@82!I;G1E;G1A<FQO(&\@</-N9V%S92!E;B!C
M;VYT86-T;R!C;VX@96P@861M:6YI<W1R861O<B!D92!S:7-T96UA<R!P87)A
M(&WA<R!I;F9O<FUA8VGS;BX`075M96YT87(@<V%N9W)A9&\`26YD:6$`57-U
M87)I;W,@:6YD:79I9'5A;&5S`$EN9&]N97-I80!);F9O<FUA8VGS;@!);F9O
M<FUA8VGS;@!,82!I;F9O<FUA8VGS;B!Y82!N;R!E<W3A(&1I<W!O;FEB;&4N
M`$EN<V5R=&%R(&-?;VQU;6YA(&1E='+A<P!);G-E<G1A<B!I;6%G96X`26YS
M97)T87(@=&%B;&$`26YS97)T87(@=NUN8W5L;R!796(`26YS97)T87(@7V-O
M;'5M;F$@9&5L86YT90!);G-E<G1A('5N82!N=65V82!C;VQU;6YA(&1E='+A
M<R!D92!L82!A8W1U86P`26YS97)T82!U;F$@;G5E=F$@8V]L=6UN82!D96QA
M;G1E(&1E(&QA(&%C='5A;`!);G-E<G1A('5N82!F:6QA(&YU979A(&1E8F%J
M;R!D92!L82!A8W1U86P`26YS97)T82!U;F$@9FEL82!N=65V82!E;F-I;6$@
M9&4@;&$@86-T=6%L`$EN<V5R=&$@=6X@<.%R<F%F;R!T<F%S(&5L(&YO9&\@
M86-T=6%L`$EN<V5R=&$@=6X@<.%R<F%F;R!A;G1E<R!D96P@;F]D;R!A8W1U
M86P`26YS97)T87(@<&QA;G1I;&QA(&%L=&5R;F%T:79A`$EN<V5R=&%R('5N
M82!D:7)E8V-I\VX@9&4@8V]R<F5O(&5N(&QA('%U92!R96-I8FER(&QA(&-O
M;G1R87-E\6$Z`$EN<V5R=&%R(&-E;&1A(&1E='+A<P!);G-E<G1A<B!C96QD
M82!A;G1E<P!);G-E<G1A<B!C;VQU;6YA(&1E='+A<P!);G-E<G1A<B!C;VQU
M;6YA(&%N=&5S`$EN<V5R=&%R(&UE;G-A:F5S`$EN<V5R=&%R('#A<G)A9F\@
M9&5T<N%S`$EN<V5R=&%R('#A<G)A9F\@86YT97,`26YS97)T87(@9FEL82!D
M96)A:F\`26YS97)T87(@9FEL82!E;F-I;6$`26YS97)T87(@;&$@<F5S<'5E
M<W1A(&YE8V5S87)I82!A(&QA('!R96=U;G1A(&1E('-E9W5R:61A9#H`26YS
M97)T87(O36]D:69I8V%R(&EM86=E;@!);G-E<G1A<B]-;V1I9FEC87(@=NUN
M8W5L;P!386QD;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I87(@82!L82!L:7-T
M82!D92!D:7-T<FEB=6-I\VXN`%-A;&1O(&EN<W5F:6-I96YT92X`16YT97)O
M`$QI<W1A(&1E(&5N=&5R;W,`541(("A#86)E8V5R82!D92!$871O<R!D92!5
M<W5A<FEO*2!N;R!VX6QI9&$N`$1A=&]S(%I)4"!N;R!VX6QI9&]S`$%P;&EC
M86-I\VX@;F\@=N%L:61A+@!)1"!D92!L;W1E(&YO(';A;&ED;RX`4V4@:&%N
M(&5N=FEA9&\@9&%T;W,@;F\@=N%L:61O<RX`1&ER96-C:?-N(&1E(&-O<G)E
M;R!N;R!VX6QI9&$N`$9O<FUA=&\@9&4@87)C:&EV;R!N;R!VX6QI9&\`0VQA
M=F4@9&4@;&EC96YC:6$@;F\@=N%L:61A+@!392!H82!I;F1I8V%D;R!U;F$@
M=6)I8V%C:?-N(&YO(';A;&ED82X`;7-G7W1Y<&4@;F\@=N%L:61O+@!A<&E?
M:60@;F\@=N%L:61O(&\@9&5S87!A<F5C:61O+@!087+A;65T<F]S(&YO(';A
M;&ED;W,@;R!D97-A<&%R96-I9&]S+@!0<FEV:6QE9VEO(&1E;"!P861R92!N
M;R!VX6QI9&]S+@!)1"!D92!A<V]C:6%D;R!N;R!VX6QI9&\N`$/S9&EG;R!D
M92!P<F]D=6-T;R!N;R!VX6QI9&\N`%!R;W1O8V]L;R!N;R!VX6QI9&\N`$1E
M<W1I;F%T87)I;R!N;R!VX6QI9&\Z("(E<R(`3V)J971O(&-O;7!A<G1I9&\@
M;F\@=N%L:61O+@!$:7)E8V-I\VX@9&5L(')E;6ET96YT92!N;R!VX6QI9&$`
M1&%T;W,@=6YI8V]D92!N;R!VX6QI9&]S+@!);G9E;G1A<FEO`$EN=F5R=&ER
M('-E;&5C8VGS;@!)<N%N+"!297#Z8FQI8V$@27-LX6UI8V$@9&4`27)A<0!)
M<FQA;F1A`$ES;&$@9&4@36%N`$)O<G)A<V-A<R!A:7-L861A<P!)<W)A96P`
M16UI<V]R`$-U<G-I=F$`271A;&EA`$IA;6%I8V$`16YE<F\`2F%P\VX`2F%P
M;V[I<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)DX6X`2G5L:6\`2G5N:6\`
M2G5S=&EF:6-A<@!!;&EN96%R(&%L(&-E;G1R;P!*=7-T:69I8V%R`$%L:6YE
M87(@82!L82!I>G%U:65R9&$`06QI;F5A<B!A(&QA(&1E<F5C:&$`2V%Z86MH
M<W1A;@"_0V]N<V5R=F%R(&5L(&]R:6=I;F%L/P!+96YY80!%;"!S97)V:61O
M<B!+97)B97)O<R!H82!R96-H87IA9&\@;&$@875T96YT:69I8V%C:?-N+@!.
M;W9A=&]S(&1E;"!+97)N96P`0W)E86-I\VX@9&4@8VQA=F4`2'5E;&QA(&1I
M9VET86P@9&4@;&$@8VQA=F4`5&%M8?%O(&1E(&-L879E`%1I<&\@9&4@8VQA
M=F4`57-O(&1E(&QA(&-L879E.@!,82!C;&%V92!Y82!E>&ES=&4@96X@96P@
M<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N`$YI\6]S`$MI<FEB871I`$-O
M<F5A+"!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D90!#;W)E82P@
M4F5P^F)L:6-A(&1E`$-O<F5A;F\@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T
M86X`7T1I<W1R:6)U8VGS;@!)9&EO;6$`3&%O+"!297#Z8FQI8V$@1&5M;V-R
MX71I8V$@4&]P=6QA<@!#=6%R=&\@;65N9W5A;G1E`-IL=&EM82!M;V1I9FEC
M86-I\VX`VFQT:6UO(&-A;6)I;R!D92!C;VYT<F%S9?%A`$-U87)T;R!M96YG
M=6%N=&4`VFQT:6UA(&%C='5A;&EZ86-I\VXZ`-IL=&EM82!S97-I\VXZ("5S
M`-IL=&EM82!S97-I\VXZ("5S(&1E<V1E("5S`-IL=&EM82!S97-I\VXZ($YU
M;F-A`$QA='9I80!,97EE<P!$:7-T<FEB=6-I\VX`1&5J87(@96X@8FQA;F-O
M('!A<F$@96QI;6EN87(@96P@8F]R9&4`3&5B86YO;@!)>G%U:65R9&$`0V%B
M96-E<F$@:7IQ=6EE<F1A`%9A;&]R97,@9&4@;&$@:7IQ=6EE<F1A`$QE<V]T
M:&\`3FEV96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H
M=&5N<W1E:6X`3&EG97)A(&QL;W9I>FYA`$QL=79I82!L:6=E<F$`3&QU=FEA
M(&QI9V5R82!M871U=&EN80!,;'5V:6$@;&EG97)A('9E<W!E<G1I;F$`06=U
M86-E<F\@;&EG97)O`$QL=79I87,@>2!T<G5E;F]S`$YE=F%D82!S=6%V90!,
M:6=E<F\@86=U86-E<F\@9&4@;FEE=F4`0VAA<V-A<G)I;&QO`%;M;F-U;&\`
M16P@=NUN8W5L;R!A<'5N=&$@83H`5FEN8W5L87(@9&ER96-C:?-N(&1E(&-O
M<G)E;R!A(&QA('#A9VEN82!D92!C;VUP;W-I8VGS;B!A;"!M;W-T<F%R`%;M
M;F-U;&]S`$-O;VMI92!,:6YU>`!,:7-T87(@+2!E;"!U<W5A<FEO('!U961E
M(&5X86UI;F%R(&QA(&-A<G!E=&$`3&ES=&%R(&)A<V5S(&1E(&1A=&]S`$QI
M<W1A<B!T96UA<R!D92!A>75D80!,:7-T87(@=&%B;&%S`$QI<W0M07)C:&EV
M90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T
M+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$AA(&9A;&QA9&\@96P@;&ES
M=&%D;R!D92!L87,@<V5S:6]N97,Z("5S`$AA(&9A;&QA9&\@96P@;&ES=&%D
M;R!D92!U<W5A<FEO<SH@)7,`16P@;&ES=&%D;R!D92!U<W5A<FEO<R!E<W3A
M(&1E<VAA8FEL:71A9&\N`$QI=&5R871U<F$`3&ET=6%N:6$`3&5Y96YD;RXN
M+@!(;W)A(&QO8V%L.B``261I;VUA('D@:&]R80!58FEC86-I\VX`26YI8VEA
M<B!S97-I\VX`4F5G:7-T<F\@9&4@;&%S('-E<VEO;F5S(&1E('-I;F-R;VYI
M>F%C:?-N(&%N=&5R:6]R97,`4V%L:7(`26YI8VEA<B!S97-I\VX`5&%R96%S
M(&1E(&EN:6-I;R!D92!S97-I\VX`1F%L;/,@96P@:6YI8VEO(&1E('-E<VGS
M;B!P;W)Q=64@:6YT<F]D=6IO(&EN8V]R<F5C=&%M96YT92!S=2!N;VUB<F4@
M9&4@=7-U87)I;R!O(&-O;G1R87-E\6$N`$9A;&SS(&5L(&EN:6-I;R!D92!S
M97-I\VXN`%1E>'1O(&-O;7!L971O`$%M;W(`0F%J80!!;&9A8F5T;R!G<FEE
M9V\@96X@;6EN^G-C+@!!;&9A8F5T;R!L871I;F\@96X@;6EN^G-C+@!.^FUE
M<F]S(')O;6%N;W,@96X@;6EN^G-C+@!,=7AE;6)U<F=O`$U-`$U/5$0`16P@
M861J=6YT;R!-4RU43D5&(&YO(&-O;G1E;NUA(&1A=&]S+@!-4T<`36%C86\`
M36%C961O;FEA+"!!;G1I9W5A(%)E</IB;&EC82!9=6=O<VQA=F$@9&4`36%D
M86=A<V-A<@!-86=I80!#;W)R96\`061M+B!C;W)R96\`0W)E87(@7W;M;F-U
M;&\N+BX`36%L87=I`$UA;&%S:6$`36%L9&EV87,`36%L:0!-86QT80!'97-T
M:6]N82!L82!L:7-T82!D92!C871E9V]R[6%S(&-O;B!L82!Q=64@971I<75E
M=&%R(&5L96UE;G1O<R!Y(&QO<R!C;VQO<F5S(&%S;V-I861O<R!A(&1I8VAA
M<R!C871E9V]R[6%S+@!-87!A(&UA<#(T`$UA<&$@;6%P<75E<W0`0V]R<F5S
M<&]N9&5N8VEA<R!A;&UA8V5N861A<RX`36%R>F\`36%R9V5N`$UA<F-A<B!C
M;VX@;&%S(&)A;F1E<F%S(&1E($QE[61O+U-I;B!L965R`$UA<F-A<B!C;VX@
M;W1R87(@8F%N9&5R87,@*'`N92X@26UP;W)T86YT92]297-P;VYD:61O*0!)
M<VQA<R!-87)S:&%L;`!-87)T:6YI8V$`0V%M<&]S(&-O:6YC:61E;G1E<P!-
M875R:71A;FEA`$UA=7)I8VEO`%-A;&1O(&WA>&EM;R!P97)M:71I9&\N`%-E
M(&AA('-O8G)E<&%S861O(&5L(&[Z;65R;R!MX7AI;6\@9&4@<&%R=&5S(&1E
M(&UE;G-A:F4N`%1E;7`N(&WA>&EM82#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M
M<"X@;>%X:6UA(/IL=&EM87,@-B!H;W)A<SH@`$[Z;65R;R!MX7AI;6\@9&4@
M;F]T87,`3OIM97)O(&WA>&EM;R!D92!B;&]Q=65S(&1E;"!P;W)T86P`3&]N
M9VET=60@;>%X:6UA`$UA>6\`36%Y;W1T90!-961I8VEN80!-:65M8G)O<P!4
M97AT;R!D92!L82!N;W1A`$9O<FUA=&\@9&5L(&UE;OHZ`$-O;6)I;F%R(&-E
M;&1A<P!-96YS86IE`%-E(&AA(&-O;7!R;V)A9&\@8V]R<F5C=&%M96YT92!E
M;"!M96YS86IE('!E<F\@;F\@<V4@<'5E9&4@=F5R:69I8V%R(&5L(&-E<G1I
M9FEC861O(&1E;"!F:7)M86YT92X`365N<V%J92!C861U8V%D;RX`5&EP;R!D
M92!M96YS86IE`%1I96UP;R!D92!-971A<@!";&]Q=64@365T87(@;F\@9&ES
M<&]N:6)L92X`0FQO<75E($UE=&%R(&YO(&1I<W!O;FEB;&4N(%-E(&AA;B!R
M96=I<W1R861O(&QO<R!D971A;&QE<R!P87)A(&5L(&%D;6EN:7-T<F%D;W(N
M`$YO(&5S=.$@8V]N96-T861A(&QA($UE=&%R1$(`3>ET;V1O`$5L(&WI=&]D
M;R`B)7,B(&YO(&5S=.$@9&5F:6YI9&\`3>ET;V1O(&YO(&1E9FEN:61O+B!-
MZ71O9&\@;&QA;6%D;SH@)7,`3>ET<FEC;P!-Z6II8V\`36EC<F]N97-I82P@
M17-T861O<R!&961E<F%D;W,@9&4`16X@;65D:6\`5&EP;R!-:6UE`%1E;7`N
M(&WM;BX@;&%S(/IL=&EM87,@,C0@:&]R87,Z(`!496UP+B!M[6XN(&QA<R#Z
M;'1I;6%S(#8@:&]R87,Z(`!4;V1A=NUA(&YO(&AA(&5X<&ER861O(&QA(&%N
M=&EG_&5D860@;>UN:6UA(&1E(&QA(&-O;G1R87-E\6$`4F5F;&5J87(`36ES
M8V5LX6YE80!087%U971E(%!%05(@2%144%]297%U97-T(&1E<V%P87)E8VED
M;RX`1F%L=&$@;&$@8V]N9FEG=7)A8VGS;BX@5&EE;F4@<75E(&=E;F5R87)L
M82!A:&]R82!S:2!D97-E82!U=&EL:7IA<B!E<W1A(&%P;&EC86-I\VXN`$E$
M(&1E(&UE;G-A:F4@9&5S87!A<F5C:61O+@!087%U971E(%!%05(@36%I;"!D
M97-A<&%R96-I9&\N`$E$(&1E('-E<VGS;B!D97-A<&%R96-I9&\N`$QU;@!#
M;W)R96\@;?-V:6P`36]D97)A9&\`4V4@:&$@;6]D:69I8V%D;R!L82!F96-H
M80!-;V1I9FEC87(@55),`$UO9&EF:6-A;F1O("5S`$WS9'5L;P!-;VQD879I
M82P@4F5P^F)L:6-A(&1E`$WS;F%C;P!-;VYG;VQI80!-97,@>2!A\6\`365N
M<W5A;&UE;G1E`$UO;G1S97)R870`1F%S97,@9&4@;&$@;'5N80!392!H86X@
M96YC;VYT<F%D;R!MX7,@8V%M<&]S(&5N(&QA(&SM;F5A("5D('%U92!L;W,@
M)60@97-P97)A9&]S+@!-87)R=65C;W,`1G5N9&%M96YT86QM96YT92!D97-P
M96IA9&\`1G5N9&%M96YT86QM96YT92!N=6)O<V\`1G5N9&%M96YT86QM96YT
M92!S;VQE861O`$1E<W!L87IA<B!H86-I82!A8F%J;P!$97-P;&%Z87(@82!L
M82!I>G%U:65R9&$`1&5S<&QA>F%R(&$@;&$@9&5R96-H80!$97-P;&%Z87(@
M:&%C:6$@87)R:6)A`$1E<W!L87IA<B!H86-I82!A8F%J;P!$97-P;&%Z87(@
M:&%C:6$@87)R:6)A`$UO>F%M8FEQ=64`3&ES=&%S(&1E<W!L96=A8FQE<R!M
M=6QT:2UN:79E;`!-87!A(%5+(&WZ;'1I<&QE`%-E;&5C8VGS;B!M^FQT:7!L
M90!)9&5N=&ED860`36D@:61E;G1I9&%D`$UI<R!N;W1A<P!-:2!P;W)T86P`
M1&ES=')I8G5C:?-N(&1E(&UI('!O<G1A;`!->6%N;6%R`$Y/+"!.3R!E<W1O
M>2!D92!A8W5E<F1O`$YO;6)R90!.86UI8FEA`$YA=7)U`$YE<&%L`$AO;&%N
M9&$`06YT:6QL87,@2&]L86YD97-A<P!54DP@8F%S92!D92!.971S8V%P90!5
M4DP@9&4@86YU;&%C:?-N(&1E($-!(&1E($YE='-C87!E`%523"!D92!P;VSM
M=&EC87,@9&4@0T$@9&4@3F5T<V-A<&4`55),(&1E(')E;F]V86-I\VX@9&4@
M3F5T<V-A<&4`55),(&1E(&%N=6QA8VGS;B!D92!.971S8V%P90!.;VUB<F4@
M9&4@<V5R=FED;W(@4U-,(&1E($YE='-C87!E`$-O;65N=&%R:6\@9&5L(&-E
M<G1I9FEC861O(&1E($YE='-C87!E`%1I<&\@9&4@8V5R=&EF:6-A9&\@9&4@
M3F5T<V-A<&4`4F5D`$YU;F-A`$YU979A($-A;&5D;VYI80!.=65V82!C871E
M9V]R[6$`16YV:6%R(&UE;G-A:F4@82`E<P!,=6YA(&YU979A`$YU979A(&YO
M=&$`3G5E=F\@;F]M8G)E(&1E('5S=6%R:6\@*&]P8VEO;F%L*0!.=65V82!:
M96QA;F1A`$-O;G1R87-E\6$@;G5E=F$`3&$@;G5E=F$@8V]N=')A<V7Q82!E
M>'!I<F%RX2!E;"`E>"X`3&%S(&-O;G1R87-E\6%S(&YO(&-O:6YC:61E;BX`
M3G5E=F$@=F5N=&%N82`H7V)L86YK*0!.;W1I8VEA<P!'+B!D92!N;W1I8VEA
M<P!3:6=U:65N=&4`4'+S>&EM87,@-"!F87-E<P!/<&-I;VYE<R!S:6=U:65N
M=&5S`%-I9W5I96YT93X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3F]C:&4`
M3FEU90!.;P!.;R!H87D@9&%T;W,@9&4@8V]N9FEG=7)A8VGS;B!P87)A(&UO
M<W1R87(@9&EF97)E;F-I87,N`$YO('-E(&1I<W!O;F4@9&4@97-T<F%T96=I
M82!D92!E;&%B;W)A8VGS;B!D92!I;>%G96YE<R!)4T\N`$YO(&AA>2!P;&%N
M=&EL;&$@9&4@;&]T97,`3F\@:&%Y(&)L;W%U97,@96X@;&$@<&]S:6-I\VX@
M:6YD:6-A9&$`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@;F]M8G)E(&1E(&%G
M96YD82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!-0T%,+@!3:6X@8V%M8FEO
M<RX`3F\@<V4@<'5E9&5N(&'Q861I<B!D97-C96YD:65N=&5S(&$@97-T92!P
M<FEV:6QE9VEO+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@
M9&4@8V]N9FEG=7)A8VGS;B!P87)A("5S+@!.;R!S92!H82!E<W!E8VEF:6-A
M9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@
M1E10+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N
M9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@4U%,+@!.;R!S92!H82!E<W!E8VEF
M:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P
M;W(@87)C:&EV;R!344PN`$YO('%U961A('-A;&1O+@!.;R!S92!H82!I;G1R
M;V1U8VED;R!E;"!D97-T:6YO+@!.;R!S92!H82!C87)G861O(&YI;F?Z;B!A
M<F-H:79O`$YO('-E(&AA;B!E;F-O;G1R861O(&1A=&]S(&E#86QE;F1A<BX`
M3F\@<V4@:&%N(&5N8V]N=')A9&\@:6-O;F]S+@!.;R!S92!H82!D969I;FED
M;R!L82!U8FEC86-I\VXN`$YO('-E(&AA(&1E9FEN:61O(&QA('5B:6-A8VGS
M;BX`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@;65N<V%J92X`3F\@<V4@:&$@
M97-P96-I9FEC861O('5N(&YO;6)R92X`4VEN(&QI8G)E=&%S(&1I<W!O;FEB
M;&5S('!A<F$@;&]S(&EN=FET861O<RX`4VEN(&YO=&%S`$YO(&AA>2!N;W1A
M<R!Q=64@8V]I;F-I9&%N(&-O;B!L;W,@8W)I=&5R:6]S(&%C='5A;&5S+@!3
M:6X@;F]T87,@=FES:6)L97,`3F\@<V4@:&$@97-P96-I9FEC861O('5N(&[Z
M;65R;RX`3F\@;V9E;G-I=F%S`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C
M;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N($A45%`N`$YO('-E
M(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT
M:69I8V%C:?-N($E-05`N`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT
M<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N($ME<F)E<F]S+@!.;R!S
M92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N
M=&EF:6-A8VGS;B!D92!I;FEC:6\N`$YO('-E(&AA(&EN=')O9'5C:61O('5N
M82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N(%!!4U-71"X`
M3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A
M=71E;G1I9FEC86-I\VX@4TU"+@!.;R!S92!H82!I;F1I8V%D;R!V[6$@9&4@
M86-C97-O(&$@;&]S(&)I;F%R:6]S($]P96Y34TPN(%!A<F$@=')A8F%J87(@
M8V]N(&1A=&]S(%!+0U,@,3(@:&%C96X@9F%L=&$@;&]S(&)I;F%R:6]S($]P
M96Y34TPN`%-I;B!A;'1A<R!P96YD:65N=&5S+@!#87)E8V4@9&4@<75O=&$N
M`%-I;B!R87EA<P!.;R!S92!H82!E<W!E8VEF:6-A9&\@=6X@<V5P87)A9&]R
M+@!.:6YG=6YO`$YO(&5X:7-T92!E;"!A<F-H:79O`$YO('-E(&1I<W!O;F4@
M9&4@=6X@9&ER96-T;W)I;R!D92!A;&UA8V5N86UI96YT;R!T96UP;W)A;"X`
M3F\@<V4@:&$@96YV:6%D;R!E;"!N;VUB<F4@9&4@=7-U87)I;R!Y+V\@;&$@
M8V]N=')A<V7Q82X`3F\@<V4@:&%N(&1E=G5E;'1O(&1A=&]S(%A-3"!VX6QI
M9&]S`%-I;B!V86QO<F5S`$YO('-E(&5N8V]N='+S(&QA('9E<G-I\VX@96X@
M;&$@8V]N9FEG=7)A8VGS;B!O<FEG:6YA;"X@4F5G96YE<F%R(&QA(&-O;F9I
M9W5R86-I\VXN`$YO('-E(&5N8V]N='+S(&QA('9E<G-I\VX@96X@;&$@8V]N
M9FEG=7)A8VGS;BX@4F5G96YE<F%R(&QA(&-O;F9I9W5R86-I\VXN`%].;W1A
M`$YI;F=U;F$`3FEN9W5N;R`H=7-O(&EM<&SM8VET;RD`3O-R9&EC;R`H25-/
M+3@X-3DM,3`I`$ES;&$@9&4@3F]R9F]L:P!(96UI<V9E<FEO(&YO<G1E`$ES
M;&%S($UA<FEA;F%S(&1E;"!.;W)T90!.;W)U96=A`$YO(&1E<W!UZ7,`3F\@
M86YT97,`3F\@97,@=6X@9&ER96-T;W)I;P!3:6X@9&5S87)R;VQL87(N`%-I
M;B!E<W1A8FQE8V5R`$YO(&5S=.$@<V]P;W)T861O+@!#871E9V]R[6$@9&4@
M;&$@;F]T80!$971A;&QE<R!D92!L82!N;W1A`$QI<W1A9&\@9&4@;F]T87,`
M5&5X=&\@9&4@;&$@;F]T80!?5&5X=&\@9&4@;&$@;F]T80!.;R!S92!E;F-O
M;G1R\R!L82!N;W1A+@!?3&EB<F5T80!.;VUB<F4@9&4@;&$@;&EB<F5T83H`
M3&EB<F5T87,`3&%S(&QI8G)E=&%S('1I96YE;B!Q=64@=&5N97(@=6X@;F]M
M8G)E+@!.;W1A<P!297-U;65N(&1E(&YO=&%S`$YO(&AA>2!N861A('9I<W5A
M;&EZ86)L92P@<F5T<F]C961A+@!.;W9I96UB<F4`3OIM97)O`$[Z;65R;R!D
M92!C87)A8W1E<F5S`$[Z;65R;R!D92!C;VQU;6YA<P!.^FUE<F\@9&4@9FEL
M87,`3F\@<V4@:&%N(&5S<&5C:69I8V%D;R!N^FUE<F]S(&$@86-T=6%L:7IA
M<B!E;B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN`$%C97!T87(`3V)J971O
M`$-R96%D;W(@9&4@;V)J971O<P!/8W1A;`!/8W1U8G)E`$9I;'1R87(@;V9E
M;G-A<P!/9FEC:6YA`$QA(&-O;G1R87-E\6$@86YT:6=U82!Y(&QA(&YU979A
M(&1E8F5N('-E<B!D:7-T:6YT87,N`$-O;G1R87-E\6$@86YT:6=U80!,82!C
M;VYT<F%S9?%A(&%N=&EG=6$@;F\@97,@8V]R<F5C=&$N`$]MX6X`4_-L;R!L
M;W,@<V5R=FED;W)E<R!)34%0('-O<&]R=&%N(&QA<R!C87)P971A<R!C;VUP
M87)T:61A<RX`4_-L;R!O9F5N<VEV87,`4_-L;R!S92!P97)M:71E('5N82!D
M:7)E8V-I\VX@9&4@8V]R<F5O+@!3\VQO(&5L('!R;W!I971A<FEO(&\@=6X@
M861M:6YI<W1R861O<B!D92!S:7-T96UA<R!P=65D92!C86UB:6%R(&QA('!R
M;W!I961A9"!O(&QO<R!P<FEV:6QE9VEO<R!D92!P<F]P:65T87)I;R!D92!U
M;B!R96-U<G-O(&-O;7!A<G1I9&\`06)R:7(@96X@=6YA(&YU979A('9E;G1A
M;F$`17)R;W(@3W!E;E-33#H@3F\@<V4@<'5E9&5N(&5X=')A97(@9&%T;W,@
M9&4@;&$@<&%R=&4@4R]-24U%(&9I<FUA9&$N`$%B<FER(&5S=&4@=NUN8W5L
M;R!E;B!U;F$@=F5N=&%N82!N=65V80!3:7-T96UA(&]P97)A=&EV;P!/<&-I
M;VYE<P!/<&-I;VYE<R!D92`E<P!,:7-T82!O<F1E;F%D80!/<F=A;FEZ86-I
M\VX`56YI9&%D(&]R9V%N:7IA=&EV80!/<F=A;FEZ86-I\VX`4&QA;G1I;&QA
M(&1E(&%P;&EC86-I\VX@;W)I9VEN86P`4&QA;G1I;&QA<R!O<FEG:6YA;&5S
M(&5N("5S.@!/=')O`$]T<F$@:6YF;W)M86-I\VX`4')I=FEL96=I;W,@9&5L
M('!R;W!I971A<FEO`$QA(&%U=&5N=&EF:6-A8VGS;B!004T@;F\@97-TX2!D
M:7-P;VYI8FQE+@!014%2.CI-;W1O<B!D92!C;W)R96\`1FER;6$@9&EG:71A
M;"!01U``1&%T;W,@8VEF<F%D;W,@8V]N(%!'4`!#;&%V92!01U`@</IB;&EC
M80!$871O<R!F:7)M861O<R]C:69R861O<R!C;VX@4$=0`$/S9&EG;R!02%``
M26YTZ7)P<BX@4$A0`$QL;W9I>FYA('9E<W!E<G1I;F$`3&QU=FEA('9E<W!E
M<G1I;F$`0VAA<&%R<F]N97,@=F5S<&5R=&EN;W,`3FEE=F4@=F5S<&5R=&EN
M80!!9W5A8V5R;R!D92!N:65V92!V97-P97)T:6YO`%-O;"!V97-P97)T:6YO
M`$)O<G)A<V-A<R!V97-P97)T:6YA<P!.;R!S92!E;F-U96YT<F$@;&$@97AT
M96YS:?-N(%!/4TE8`$EN=.ER<'(N(%!?2%``36%R9V5N`%!A:VES=.%N`%!A
M;&%U`%!A;&5S=&EN;W,L(%1E<G)I=&]R:6]S($]C=7!A9&]S`%!A;F%MX0!0
M87#Z82!.=65V82!'=6EN96$`4&%R86=U87D`4&%R8VEA;&UE;G1E(&YU8F]S
M;P!#;VYT<F%S9?%A`$QA(&-O;G1R87-E\6$@<V4@8V%M8FEA9&\@8V]R<F5C
M=&%M96YT92X`0V]N=')A<V7Q82!I;F-O<G)E8W1A`$AA>2!Q=64@:6YT<F]D
M=6-I<B!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!2
M041)55,N`$-O;G1R87-E\6$@8V]N(&-O;F9I<FUA8VGS;@!#;VYT<F%S9?%A
M.@!#;VYT<F%S9?%A.B``3&%S(&-O;G1R87-E\6%S('1I96YE;B!Q=64@8V]I
M;F-I9&ER+@!096=A<@!096=A<B!D96P@<&]R=&%P87!E;&5S`%;M80!!;'1A
M<R!P96YD:65N=&5S.@!'96YT90!0;W)C96YT86IE`%)E86QI>F%R(&]P97)A
M8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\`OU)E86QI>F%R(&]P97)A8VEO;F5S
M(&1E(&UA;G1E;FEM:65N=&\@86P@:6YI8VEA<B!S97-I\VX_`%!R:79I;&5G
M:6\`3F\@<V4@:&$@96QI;6EN861O(&5L('!R:79I;&5G:6\@(B5S(BX`4&5R
M;6ES;R!D96YE9V%D;P!0<FEV:6QE9VEO<P!!9&UI;FES=')A8VGS;B!D92!P
M<FEV:6QE9VEO<P!);F9O<FUA8VGS;B!P97)S;VYA;`!097+Z`$UA<V-O=&%S
M`$9I;&EP:6YA<P!496SI9F]N;P!&;W1O9W)A9NUA<P!0:71C86ER;@!0[7AE
M;&5S`%3S<&EC;W,`4'5L<V4@96X@=6YA(&-E;&1A`$-O;F9I<FUE('%U92!D
M97-E82!E;&EM:6YA<B!E<W1E(&5L96UE;G1O.@!#;VYF:7)M92!Q=64@9&5S
M96$@96QI;6EN87(@96P@=NUN8W5L;R!A(&5S=&4@96QE;65N=&\N`$EN=')O
M9'5Z8V$@=6X@;65S('D@=6X@8?%O+@!);G1R;V1U>F-A(&5L(&YO;6)R92!D
M92!L82!N=65V82!C871E9V]R[6$Z`$EN=')O9'5Z8V$@=6YA(&1I<F5C8VGS
M;B!)4"!VX6QI9&$N`$EN=')O9'5Z8V$@=6YA(&9E8VAA(';A;&ED82P@8V]M
M<')U96)E(&5L(&[Z;65R;R!D92!D[6%S(&1E;"!M97,N`$EN=')O9'5Z8V$@
M=6YA(&AO<F$@=N%L:61A+@!0<F]P;W)C:6]N92!U;B!R97-U;65N(&1E;"!P
M<F]B;&5M82X`26YT<F]D=7IC82!S=2!N;VUB<F4@9&4@=7-U87)I;R!Y(&-O
M;G1R87-E\6$N`$QE82!E;"!T97AT;R!S:6=U:65N=&4N($1%0D4@86-E<'1A
M<B!L;W,@=.ER;6EN;W,@<VD@<75I97)E('5S87(@96P@<VES=&5M82X`26YT
M<F]D=7IC82!E;"!N=65V;R!N;VUB<F4@9&4@8V%T96=O<NUA.@!0;VQO;FEA
M`%!O;.UT:6-A`$5N8W5E<W1A<P!0;W)T=6=A;`!0;W-I8VGS;B!D92!L82!I
M;6%G96X`4&]S:6-I\VX@9&4@;&$@=&%B;&$`16YV:6%R(&$@97-T82!C87)P
M971A("AN;R!O8FQI9V%D;R!P;W(@24U!4"D`4')E8VEP:71A8VEO;F5S(&1E
M(&QA*',I(/IL=&EM82AS*2`E<R!H;W)A*',I.B``4')O8F%B:6QI9&%D/&)R
M("\^9&4@<')E8VEP:71A8VGS;@!0<F5F<U]L9&%P.B!N;R!S92!E;F-O;G1R
M\R!L82!E>'1E;G-I\VX@3$1!4"!R97%U97)I9&$N`%!R969S7W-E<W-I;VXZ
M(&YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!D92!S97-I\VX@<F5Q=65R
M:61A+@!0<F5S:?-N`%!R97-I\VX@86P@;FEV96P@9&5L(&UA<CH@`%!R97-I
M\VXZ(`!6:7-T82!P<F5V:6$`5FES=&$@<')E=FEA(&1E(&QA(&EM86=E;B!E
M;B!U;F$@;G5E=F$@=F5N=&%N80!/<&-I;VYE<R!A;G1E<FEO<F5S`$EM<')I
M;6ER(&1O8W5M96YT;P!#;&%V92!P<FEV861A`+]0<F]B;&5M87,_`$1E<V-R
M:7!C:?-N(&1E;"!P<F]B;&5M80!0<F]Y96-T;W,`5&5X=&\@9&5L(&EN9'5C
M=&]R`$-L879E(%!'4"!P^F)L:6-A`$%L9V]R:71M;R!D92!C;&%V92!P^F)L
M:6-A`$EN9F]R;6%C:?-N(&1E(&-L879E('#Z8FQI8V$`3F\@<V4@9V5N97)A
M<F]N(&-O<G)E8W1A;65N=&4@;&%S(&-L879E<R!0^F)L:6-A+U!R:79A9&$N
M`%!U97)T;R!2:6-O`$QI;7!I87(@;65N<V%J97,`46%T87(`0V]N<W5L=&$`
M475O=&$`0VQA=F4@4E-!('#Z8FQI8V$@*"5D(&)I="D`0F]T\VX@9&4@;W!C
M:?-N`$QL=79I80!,;'5V:6$@;6%T=71I;F$`3&QU=FEA('9E<W!E<G1I;F$`
M06=U86-E<F\`3&QU=FEA('D@3FEE=F4`3&QU=FEA(&$@3FEE=F4`4G5E9&$@
M9&4@;&$@9F]R='5N80!287KS;@`F;F)S<#M,965R)FYB<W`[`$QE97(@;65N
M<V%J97,`OT5L:6UI;F%R(')E86QM96YT92`E<S\@17-T82!O<&5R86-I\VX@
M;F\@<V4@<'5E9&4@9&5S:&%C97(N`+]396=U<F\@<75E('%U:65R92!B;W)R
M87(@97-T82!N;W1A/P"_16QI;6EN87(@<F5A;&UE;G1E(&QO<R!D871O<R!D
M96P@=7-U87)I;R`E<S\@17-T82!O<&5R86-I\VX@;F\@<V4@<'5E9&4@9&5S
M:&%C97(N`%9U96QV92!A(')E86QI>F%R(&QA(/IL=&EM82!A8V-I\VX`06-T
M=6%L:7IA<@!!8W1U86QI>F%R(&5L96UE;G1O<R!D92!M96[Z(&1I;N%M:6-O
M<SH`06-T=6%L:7IA<B!L:7-T80!!8W1U86QI>F%R('9I<W1A(&1E;"!P;W)T
M86P`4F5G97@`3F%V96=A9&]R(&1E(')E;&%C:6]N97,`4F5F<F5S8V%R`$]B
M<V5R=F%C:6]N97,`4V5R=FED;W)E<R!R96UO=&]S`%523"!R96UO=&$@*&AT
M='`Z+R]W=W<N96IE;7!L;RYC;VTO:&]R9&4I.@!1=6ET87(`475I=&%R(&)L
M;W%U90!1=6ET87(@8V%T96=O<NUA`%%U:71A<B!C;VQU;6YA`$5L:6UI;F%R
M(&9O<FUA=&\`475I=&%R('!A<@!%;&EM:6YA<B!G=6GS;B!G=6%R9&%D;R!D
M96P@9&ER96-T;W)I;R!T96UP;W)A;"!D96P@<V5R=FED;W(N`$5L:6UI;F%R
M(`!%;&EM:6YA<B!E<W1E(&YO9&\@9&5L(&1O8W5M96YT;P!%;&EM:6YA<B!U
M<W5A<FEO`$5L:6UI;F%R('5S=6%R:6\Z("5S`$YO('-E('!U961E(')E<W!O
M;F1E<B!A(&QA('-O;&EC:71U9"X@0_-D:6=O(&1E(&5R<F]R(&1E=G5E;'1O
M.B``3F\@<V4@96YC;VYT<O,@96P@<V5R=FEC:6\@<V]L:6-I=&%D;RX`3F\@
M<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA(&-O
M;F9I9W5R86-I\VX@9&4@)7,N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!E;"`B
M)7,B(')E<75E<FED;R!E;B!L82!C;VYF:6=U<F%C:?-N(&1E(%9&4RX`3F\@
M<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA(&-O
M;F9I9W5R86-I\VXN`$-A;7!O(&YE8V5S87)I;P!,:6UP:6%R`$QI;7!I87(@
M8V]N=')A<V7Q80!,:6UP:6%R(&-O;G1R87-E\6$`4F5S=&%U<F%R(/IL=&EM
M82!C;VYS=6QT80!297-U;'1A9&]S`%)E9W)E<V%R(&$@;W!C:6]N97,`4F5E
M<V-R:6)I<B!C;VYT<F%S9?%A(&YU979A`%)E=6YI\VX`4F5S=&%U<F%R(&-O
M;F9I9W5R86-I\VX`3W!C:6]N97,@9&4@961I8VGS;B!D92!T97AT;R!E;G)I
M<75E8VED;P!#<FEB87,`1&5R96-H80!#86)E8V5R82!D97)E8VAA`%9A;&]R
M97,@9&4@;&$@9&5R96-H80!0<F]P:65D861E<R!D92!?9FEL82XN+@!&=6YC
M:?-N`%)U;6%N[6$`1VER87(@,3@P`$=I<F%R(&$@;&$@:7IQ=6EE<F1A`$=I
M<F%R(&$@;&$@9&5R96-H80!0<F]P:65D861E<R!D92!F:6QA`%!R;W!I961A
M9&5S(&1E(&9I;&$`1FEL87,Z`%)A>6%S`$%P87)E8V5RX6X@<F%Y87,@96YT
M<F4@=&]D87,@;&%S(&9I;&%S('D@8V]L=6UN87,`07!A<F5C97+A;B!R87EA
M<R!S\VQO(&5N=')E(&QA<R!C;VQU;6YA<P!!<&%R96-E<N%N(')A>6%S('/S
M;&\@96YT<F4@;&%S(&9I;&%S`$5J96-U=&%R`$9E9&5R86-I\VX@4G5S80!2
M=6%N9&$`1FER;6$@8W)I<'1O9W+A9FEC82!3+TU)344`365N<V%J92!C:69R
M861O(&5N(%,O34E-10!.;R!E<W3A(&1I<W!O;FEB;&4@;&$@875T96YT:69I
M8V%C:?-N(%-!4TPN`$UE;G,N(%--4P!);G3I<G!R+B!344P`4V5N=&5N8VEA
M(%-13"!P87)A(&-O;G-U;'1A<R!D92!V86QO<F5S`%-32`#)6$E43P!);G3I
M<G!R+B!37U%,`%-A8@!386YT82!(96QE;F$`4V%I;G0@2VET=',@>2!.979I
M<P!386YT82!,=6/M80!386EN="!0:65R<F4@>2!-:7%U96QO;@!386X@5FEC
M96YT92!Y($=R86YA9&EN87,`36ES;6\@9G)A;64@*%]S96QF*0!386UO80!3
M86X@36%R:6YO`%-A;G1O(%1O;>%S('D@4'+M;F-I<&4`4')O=F5E9&]R(&1E
M('-A=.EL:71E`$%R86)I82!3875D:71A`$=U87)D87(`1W5A<F1A<B`B)7,B
M`$=U87)D87(@)7,`1W5A<F1A<B!O<&-I;VYE<P!'=6%R9&%R(&QA(&-O;F9I
M9W5R86-I\VX@9V5N97)A9&$@8V]M;R!U;B!G=6GS;B!02%`@96X@96P@9&ER
M96-T;W)I;R!T96UP;W)A;"!D92!S=2!S97)V:61O<BX`4V4@:&$@9W5A<F1A
M9&\@;&$@8V]N9FEG=7)A8VGS;B!D92`E<RX`1W5A<F1A<B!G=6GS;B!D92!A
M8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX@96XZ("(E<R(N`$)O
M<G)A<V-A<R!A:7-L861A<P!#:65N8VEA`$)U<V-A<@!-+B!B^G-Q=65D80!2
M97-U;'1A9&]S(&1E(&QA(&+Z<W%U961A`,%M8FET;R!D92!L82!B^G-Q=65D
M80!"=7-C87(@7W1E>'1O`%-E;&5C8VEO;F%R(&%R8VAI=F]S`%-E;&5C8VEO
M;F4@=6YA(&9E8VAA`%-E;&5C8VEO;F4@96P@9W)U<&\@82!A\6%D:7(`4V5L
M96-C:6]N92!U;B!N=65V;R!P<F]P:65T87)I;P!396QE8V-I;VYE('5N82!L
M:6)R971A`%-E;&5C8VEO;F4@=6X@<V5R=FED;W(`4V5L96-C:6]N92!E;"!U
M<W5A<FEO(&$@8?%A9&ER`%-E;&5C8VEO;F%R('1O9&\`4V5L96-C:6]N92!T
M;V1O<R!L;W,@8V]M<&]N96YT97,@9&4@;&$@9F5C:&$N`%-E;&5C8VEO;F%R
M('5N(&]B:F5T;P!3:6X@<V5L96-C:?-N`%-E;&5C8VEO;F4@;&%S(&QI8G)E
M=&%S('9I<VEB;&5S`%-E;&5C8VEO;F4@;&]S(&-A<N%C=&5R97,@<75E(&YE
M8V5S:71E(&1E(&QA<R!C87-I;&QA<R!D92!A8F%J;RX@4'5E9&4@8V]P:6%R
M;&]S('D@<&5G87)L;W,@9&5L(.%R96$@9&4@=&5X=&\N`%-E;&5C8VEO;F4@
M96P@9&5L:6UI=&%D;W(@9&4@9F5C:&%S.@!396QE8V-I;VYE(&5L(&9O<FUA
M=&\@9&4@9F5C:&%S.@!396QE8V-I;VYE(&5L(&9O<FUA=&\@9&4@97AP;W)T
M86-I\VXZ`%-E;&5C8VEO;F4@96P@87)C:&EV;R!A(&EM<&]R=&%R.@!396QE
M8V-I;VYE(&5L(&9O<FUA=&\@9&5L(&%R8VAI=F\@;W)I9V5N.@!396QE8V-I
M;VYE(&QA(&ED96YT:61A9"!Q=64@<75I97)A(&-A;6)I87(Z`%-E;&5C8VEO
M;F4@96P@9&5L:6UI=&%D;W(@9&4@:&]R87,Z`%-E;&5C8VEO;F4@96P@9F]R
M;6%T;R!D92!H;W)A<SH`4V5L96-C:6]N92!D;W,@8V%M<&]S(&-O:6YC:61E
M;G1E<RX`4V5L96-C:6]N92!S=2!C;VUB:6YA8VGS;B!D92!C;VQO<F5S+@!3
M96QE8V-I;VYE('-U(&ED:6]M82!P<F5F97)I9&\Z`$-A=&5G;W+M87,@<V5L
M96-C:6]N861A<SH`16YV:6%R(&EN9F]R;64@9&4@<')O8FQE;6%S`$5N=FEA
M<B!335,`4V5N96=A;`!396YS;W(Z(`!397!T:65M8G)E`%-E<F)I82!Y($UO
M;G1E;F5G<F\`3OIM97)O(&1E('-E<FEE`$1A=&]S(&1E;"!S97)V:61O<B!E
M<G+S;F5O<R!O(&YO(&1I<W!O;FEB;&5S+@!!9&UI;FES=')A8VGS;B!D92!S
M97-I\VX`2&$@8V%D=6-A9&\@96P@240@9&4@<V5S:?-N+@!397-I;VYE<P!%
M<W1A8FQE8V5R`$5S=&%B;&5C92!O<&-I;VYE<R!Q=64@;&4@<&5R;6ET96X@
M<F5A:G5S=&%R('-U(&-O;G1R87-E\6$@<VD@;&QE9V%R82!A(&]L=FED87)L
M82X`0V]N9FEG=7)A('-E<G9I9&]R97,@<F5M;W1O<R!A(&QO<R!Q=64@9&5S
M964@86-C961E<B!D97-D92!E;"!P;W)T86PN`$1E9FEN92!L87,@;W!C:6]N
M97,@<')E9F5R:61A<R!D92!I9&EO;6$L('IO;F$@:&]R87)I82!Y(&9E8VAA
M<RX`1&5F:6YE(&QA(&%P;&EC86-I\VX@9&4@:6YI8VEO+"!L82!C;VUB:6YA
M8VGS;B!D92!C;VQO<F5S+"!L82!A8W1U86QI>F%C:?-N(&1E('#A9VEN82!Y
M(&]T<F%S(&]P8VEO;F5S(&1E('9I<W5A;&EZ86-I\VXN`$-O;F9I9W5R86-I
M\VX`2&%Y(&=U:6]N97,@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U
M<F%C:?-N`%9A<FEA<R!U8FEC86-I;VYE<R!D:7-P;VYI8FQE<R!C;VX@96P@
M<&%RX6UE=')O.B``4V5Y8VAE;&QE<P!#;VUP<F%S`%)E<W5M96X@8V]R=&\`
MOT1E9FEN:7(@8VQA=F5S(&1E(&%C8V5S;R!P87)A(&QA(&UA>6]R[6$@9&4@
M;&]S(';M;F-U;&]S/P`F;F)S<#M-;W-T<F%R)FYB<W`[`+]-;W-T<F%R(&)O
M=&]N97,@9&4@86-C:?-N/P!-=65S=')A(&QA<R!D:69E<F5N8VEA<R!E;G1R
M92!L82!N=65V82!C;VYF:6=U<F%C:?-N('D@;&$@86QM86-E;F%D80"_36]S
M=')A<B!H;W)A(&1E(&QA(/IL=&EM82!S97-I\VX@86P@:6YI8VEA<C\`OTUO
M<W1R87(@96P@;F]M8G)E(&1E(&QA(&QI8G)E=&$_`+]-;W-T<F%R(&QA<R!N
M;W1A<R!D92!E<W1A<R!C871E9V]R[6%S/P!-;W-T<F%R(&]P8VGS;B!D92!C
M;VYS97)V87(@96P@;W)I9VEN86P`36]S=')A<B!S96QE8W1O<@"_36]S=')A
M<B!L82!B87)R82!D92!M96[Z(&1E(&]P97)A8VEO;F5S(&1E('1A8FQA/P"_
M36]S=')A<B!E;"!M96[Z("5S(&$@;&$@:7IQ=6EE<F1A/P!-=65S=')A(&5L
M(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@8V5L9&$@9&4@=&%B;&$`375E
M<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E('1A8FQA`$UU97-T
M<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!F:6QA(&1E('1A8FQA
M`$UU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!I;6%G96X`
M36]S=')A<B!C87)G80!!9W5A8V5R;W,`3&QU=FEA<R!M871U=&EN87,`3&QU
M=FEA<R!V97-P97)T:6YA<P!!9W5A8V5R;W,@96X@;&$@=F5C:6YD860`4F5D
M=6-I<@!0<FEM97)O(')E9'5Z8V$@;R!Q=6ET92!D92!E;FUE9&EO(&QO<R!B
M;&]Q=65S(&-E<F-A;F]S`%-I97)R82!,96]N80!!;'1A`$9I<FUA`$%L9V]R
M:71M;R!D92!F:7)M80!3:6YG87!U<@!486UA\6\`3VUI=&ER(&UA;G1E;FEM
M:65N=&\`17-L;W9A<75I80!%<VQO=F5N:6$`3FEE=F4`06=U86-E<F\@9&4@
M;FEE=F4`06=U86-E<F\@9&4@;FEE=F4`06=U86-E<F\@9&4@;FEE=F4@;6%T
M=71I;F\`06=U86-E<F\@9&4@;FEE=F4@=F5S<&5R=&EN;P!%<W!E<V]R(&1E
M(&QA(&YI979E.B``17%U:79A;&5N=&4@9&4@;&$@;FEE=F4@96X@86=U83H@
M`$ES;&%S(%-A;&]M\VX`4V]M86QI80!#86YC:6]N97,@)B!0;V5M87,`3W)D
M96YA<B!P;W(@8V%T96=O<NUA`$]R9&5N87(@<&]R('1E>'1O(&1E;"!C;VUE
M;G1A<FEO`%-E;&5C8VGS;B!D96P@<V5N=&ED;R!D92!L82!C;&%S:69I8V%C
M:?-N`%)E;6ET96YT90!3=63A9G)I8V$`175R;W!A(&1E;"!S=7(@*$E33RTX
M.#4Y+3,I`$=E;W)G:6$@9&5L(%-U<B!E($ES;&%S(%-A;F1W:6-H(&1E;"!3
M=7(`2&5M:7-F97)I;R!S=7(`17-P86-I861O(&5N=')E(&-E;&1A<R!A9'EA
M8V5N=&5S`$5S<&%C:6%D;R!E;G1R92!E;"!C;VYT96YI9&\@>2!E;"!B;W)D
M92!D92!U;F$@8V5L9&$`4V5P87)A9&]R`$5S<&%C:6%D;P!%<W!A8VEA9&\@
M>2!M87)G96X`17-P8?%A`%-P86T`17-C<FET=7)A(&1E(&-A<F%C=&5R97,@
M97-P96-I86QE<P!$:79I9&ER(&-E;&1A`$1I=FED:7(@8V]L=6UN80!$:79I
M9&ER(&9I;&$`1&5P;W)T97,`4W)I($QA;FMA`$5S=.%N9&%R`%-T87(@5')E
M:P!!\6\@9&4@:6YI8VEO`$5S=&%D;R!O('!R;W9I;F-I80!%<W1A9&\`1F]R
M;6%T;R!D92!A;&UA8V5N86UI96YT;P!$:7)E8V-I\VX@9&4@;&$@8V%L;&4`
M5&%C:&%D80!,:7-T82!D92!C861E;F%S`$5L:6UI;F%R(&1O;6EN:6\@9&4@
M;&$@9&ER96-C:?-N`$5S=&EL;R!;0U-370!$;VT`3F\@<V4@96YC;VYT<O,@
M96P@<W5B9&ER96-T;W)I;R`B)7,B+@!!<W5N=&\`16YV:6%R`%-E(&AA(&5N
M=FEA9&\@=6YA('-O;&EC:71U9"!D92!A;'1A(&1E("(E<R(@96X@96P@<VES
M=&5M82X@3F\@<&]D<N$@:6YI8VEA<B!S97-I\VX@:&%S=&$@<75E('-E(&AA
M>6$@87!R;V)A9&\@;&$@<V]L:6-I='5D+@!3=6+M;F1I8V4`R7AI=&\`4V4@
M:&$@8?%A9&ED;R!C;W)R96-T86UE;G1E("(E<R(@86P@<VES=&5M82X`4V4@
M:&%N(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E(&QO<R!D871O<R!D96P@=7-U
M87)I;R`B)7,B(&1E;"!S:7-T96UA+@!392!H82!E;&EM:6YA9&\@8V]R<F5C
M=&%M96YT92`B)7,B+@!392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`B
M)7,B(&1E;"!S:7-T96UA+@!392!H82!R97-T875R861O(&-O<G)E8W1A;65N
M=&4@;&$@8V]N9FEG=7)A8VGS;BX@4F5F<F5S<75E('!A<F$@=F5R(&QO<R!C
M86UB:6]S+@!392!H82!G=6%R9&%D;R!C;W)R96-T86UE;G1E("(E<R(N`%-E
M(&AA(&=U87)D861O(&-O<G)E8W1A;65N=&$@;&$@8V]P:6$@9&4@;&$@8V]N
M9FEG=7)A8VGS;BX`4V4@:&$@9W5A<F1A9&\@8V]R<F5C=&%M96YT92!L82!C
M;W!I82`E<R!D92!L82!C;VYF:6=U<F%C:?-N+@!392!H82!A8W1U86QI>F%D
M;R!C;W)R96-T86UE;G1E("(E<R(`4V4@:&$@97-C<FET;R!C;W)R96-T86UE
M;G1E("<E<R<`4W5DX6X`4F5S=6UE;@!!;6%N96-E<@!!=&%R9&5C97(`4V]L
M96%D;P!!;6%N96-E<@!!;6%N96-E<B]!=&%R9&5C97(`06UA;F5C97(Z(`!!
M=&%R9&5C97(`071A<F1E8V5R.B``4W5P97+M;F1I8V4`4V]P;W)T90!3=7)I
M;F%M`$%P96QL:61O`%-V86QB87)D('D@2F%N($UA>65N`%-W87II;&%N9&EA
M`%-U96-I80!3=6EZ80!296=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;B!E;&EM
M:6YA9&\`4WEN8TU,`$5R<F]R(&1E('-I;G1A>&ES(&5N(&QO<R!TZ7)M:6YO
M<R!D92!B^G-Q=65D80!297#Z8FQI8V$@P7)A8F4@9&4@4VER:6$`0VAU8F%S
M8V\`0F]R<F%S8V]S;R!Y('9E;G1O<V\`0F]R<F%S8V%S`$)O<G)A<V-A<R!M
M871U=&EN87,`07)C:&EV;R!44U8`5&%B;&$`4')O<&EE9&%D97,@9&4@=&%B
M;&$`5&%B;&$`4')O<&EE9&%D97,@9&4@=&%B;&$`5&%I=^%N`%1A:7?A;BP@
M4')O=FEN8VEA(&1E($-H:6YA`%1A>6EK:7-TX6X`5&%N>F%N:6$L(%)E</IB
M;&EC82!5;FED82!D90!$97-T:6YO.@!487)E87,`3OIM97)O(&1E('1E;.EF
M;VYO`%1E;7!E<F%T=7)A(&1U<F%N=&4@;&$@^FQT:6UA(&AO<F$Z(`!496UP
M97)A='5R80!496UP97)A='5R83H@`%1E;7!E<F%T=7)A/&)R("\^*"5S3>%X
M)7,O)7--[6XE<RD@)F1E9SLE<P!.;R!S92!E;F-O;G1R\R!L82!P;&%N=&EL
M;&$@(B5S(BX`061M:6YI<W1R86-I\VX@9&4@<&QA;G1I;&QA<P!497AT;P!3
M\VQO('1E>'1O`$%L:6YE86-I\VX@9&4@=&5X=&\`0F]R9&4@<W5P97)I;W(@
M9&5L('1E>'1O`$IU90!486EL86YDZ7,@*%1)4RTV,C`I`%1A:6QA;F1I80!.
M;R!E<W3A(&1I<W!O;FEB;&4@;&$@97AT96YS:?-N($944"X`16P@<VES=&5M
M82!H:7-T\W)I8V\@97-TX2!D97-H86)I;&ET861O+@!%;"!M;W1O<B!D92!I
M;G1E9W)A8VGS;B!(;W)D92]+;VQA8B!N;R!S;W!O<G1A("(E<R(`3F\@<V4@
M<'5E9&4@:6YI8VEA<B!E;"!R96=I<W1R;R!D92!)35-0+@!.;R!S92!H82!C
M87)G861O(&-O<G)E8W1A;65N=&4@;&$@8VQA<V4@36%I;G1E;F%N8V4Z.@!3
M92!H82!C97)R861O(&QA('9E;G1A;F$@9&4@;W!C:6]N97,N(%-A;&EE;F1O
M+@!3:2!D97-E82!U=&EL:7IA<B!P97)M:7-O<RP@96P@861M:6YI<W1R861O
M<B!T:65N92!Q=64@8V]N9FEG=7)A<B!U;B!S;W!O<G1E(&1E('!E<FUI<V]S
M('!E<FUA;F5N=&4N`%/S;&\@96P@8F]R9&4@:6YF97)I;W(`16P@240@9&5L
M(&-O;G1A8W1O(&YO('-E(&5S<&5C:69I8_,L('-E(&1E:O,@96X@8FQA;F-O
M(&\@;F\@<V4@96YC;VYT<O,@96X@;&$@8F%S92!D92!D871O<RX`4V4@:&$@
M8?%A9&ED;R!C;W)R96-T86UE;G1E(&5L(&-O;G1A8W1O(&$@<W5S(&1I<F5C
M8VEO;F5S+@!087)A(&-O;7!R;V)A<B!E;"!M96YS86IE(&9I<FUA9&\@:&%C
M92!F86QT82!E;"!B;&]Q=64@9&4@9FER;6$@<V5P87)A9&\N`$5L($E$(&1E
M(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;B!N;R!S92!E<W!E8VEF:6/S+"!S
M92!D96KS(&5N(&)L86YC;R!O(&YO('-E(&5N8V]N='+S(&5N(&QA(&)A<V4@
M9&4@9&%T;W,N`$YO('-E(&5S<&5C:69I8_,@;&$@;&ES=&$@9&4@9&ES=')I
M8G5C:?-N+@!,87,@8V%R86-T97+M<W1I8V%S(&1E(&-I9G)A9&\@;F5C97-I
M=&%N('5N82!C;VYE>&GS;B!W96(@<V5G=7)A+@!%;"!A<F-H:79O("5S('1E
M;F1R[6$@<75E(&-O;G1E;F5R('5N82!O<&-I\VX@)7,N`$5L(&%R8VAI=F\@
M)7,@=&5N9'+M82!Q=64@8V]N=&5N97(@86QG=6YA<R!O<&-I;VYE<R`E<RX`
M3F\@<V4@<'5E9&4@8V]P:6%R(&5L(&%R8VAI=F\@<V]B<F4@<^T@;6ES;6\N
M`$5L(&%R8VAI=F\@;F\@8V]N=&EE;F4@9&%T;W,N`$$@8V]N=&EN=6%C:?-N
M('1I96YE(&QA<R!C86)E8V5R87,@9&4@97-T92!M96YS86IE(&UE<W-A9V4O
M<F9C.#(R+@!392!S86)E('%U92!E;"!M;V1O(&1E('!A;G1A;&QA(&-O;7!L
M971A(&1A('!R;V)L96UA<R!C;VX@26YT97)N970@17AP;&]R97(@9&5B:61O
M(&$@9F%L;&]S(&1E;"!N879E9V%D;W(@<75E(&YO(&AE;6]S('!O9&ED;R!S
M;W-L87EA<BX@4'5E9&4@<W5F<FER('9I<W5A;&EZ86-I\VX@9&4@8F%S=7)A
M+"!PZ7)D:61A(&1E(&9U;F-I;VYE<R!D96P@961I=&]R('DO;R!C=65L9W5E
M<R!A;&5A=&]R:6]S(&1E;"!N879E9V%D;W(N(%-I('-U('-I<W1E;6$@;W!E
M<F%T:79O(&5S(%=I;F1O=W,@.7@L(&5S(&UU>2!P<F]B86)L92!Q=64@<W5F
M<F$@=6X@9F%L;&\@9&4@<')O=&5C8VGS;B!G96YE<F%L('D@=&5N9V$@<75E
M(')E:6YI8VEA<B!E;"!E<75I<&\N7&Y<;EEA(&5S=.$@879I<V%D;RX@4'5L
M<V4@06-E<'1A<B!S:2!A^FX@9&5S96$@<')O8F%R(&5L(&5D:71O<B!E;B!M
M;V1O(&1E('!A;G1A;&QA(&-O;7!L971A+@!392!H82!E;&EM:6YA9&\@;&$@
M:61E;G1I9&%D("(E<R(N`%/S;&\@96P@8F]R9&4@:7IQ=6EE<F1O`$AA>2!Q
M=64@:6YD:6-A<FQE(&$@;&$@8VQA<V4@0W)Y<'1?<&=P.CH@;&$@=6)I8V%C
M:?-N(&1E(&QO<R!B:6YA<FEO<R!';G501RX`4V4@:&$@;6]S=')A9&\@96P@
M;65N<V%J92!E;G9I861O(&5L("5S(&$@)7,@8V]N(&5L(&%S=6YT;R`B)7,B
M+@K)<W1O(&YO(&=A<F%N=&EZ82!Q=64@96P@;65N<V%J92!H87EA('-I9&\@
M;&5I9&\@;R!C;VUP<F5N9&ED;RX`3F]M8G)E('5T:6QI>F%D;R!A;"!V:6YC
M=6QA<B!A(&QA('#A9VEN82!D92!C;VUP;W-I8VGS;@!392!E;&EM:6[S(&QA
M(&YO=&$N`$YO('-E('!U9&\@8W)E87(@;&$@;&EB<F5T82`B)7,B.B`E<P!3
M92!H82!C<F5A9&\@;&$@;&EB<F5T82`B)7,B+@!392!H82!E;&EM:6YA9&\@
M;&$@;&EB<F5T82`B)7,B+@!392!H82!G=6%R9&%D;R!L82!L:6)R971A("(E
M<R(N`$5L(&[Z;65R;R!D92!C86UP;W,@=&EE;F4@<75E('-E<B!U;B!N^FUE
M<F\N`$AA8V4@9F%L=&$@96P@;?-D=6QO(&]P96YS<VP@<&%R82!L82!C;&%S
M92!(;W)D95]#<GEP=%]S;6EM93HZ+@!.;R!S92!P=65D92!G=6%R9&%R(&QA
M('!R969E<F5N8VEA("(E<R(@<&]R<75E('-U<R!D871O<R!S;V)R97!A<V%N
M(&5L('1A;6'Q;R!MX7AI;6\@<&5R;6ET:61O`$YO('-E(&5N8V]N='+S(&5N
M(&5L('-I<W1E;6$@96P@<')O9W)A;6$@<&%R82!V97(@97-T92!T:7!O(&1E
M(&1A=&]S("@E<RDN`$5L(&-A<N%C=&5R(&1E(&-I=&$@9&5B92!S97(@<V5R
M('/S;&\@=6YO+@!3\VQO(&QO<R!L861O<R!I>G%U:65R9&\@>2!D97)E8VAO
M`%/S;&\@96P@;&%D;R!D97)E8VAO`$5L('-E<&%R861O<B!D96)E('-E<B!S
M\VQO('5N;RX`4V4@:&$@96QI;6EN861O(&5L('-E<G9I9&]R("(E<R(N`%-E
M(&AA(&=U87)D861O(&5L('-E<G9I9&]R("(E<R(N`%-E(&AA(&5L:6UI;F%D
M;R!L82!S;VQI8VET=60@9&4@86QT82!D92`E<RX`3&$@9FEL82!E<W!E8VEF
M:6-A9&$@*"5D*2!N;R!E>&ES=&4N`$5L(&%R8VAI=F\@=&5M<&]R86P@(B5S
M(B!N;R!E>&ES=&4N`$5L('1E>'1O('%U92!H82!I;G1R;V1U8VED;R!N;R!C
M;VEN8VED92!C;VX@96P@9&4@;&$@<&%N=&%L;&$N`%/S;&\@;&]S(&QA9&]S
M('-U<&5R:6]R(&4@:6YF97)I;W(`4_-L;R!E;"!L861O('-U<&5R:6]R`%-E
M('!E<F1I97)O;B!L;W,@9&%T;W,@8V%R9V%D;W,@9&5S9&4@96P@<&%S;R!A
M;G1E<FEO<BX`3F\@<V4@<'5D;R!G=6%R9&%R(&5L(&%R8VAI=F\@8V%R9V%D
M;RX`3F\@97-TX2!D:7-P;VYI8FQE(&5L(&)L;W%U92!D92!W96%T:&5R+F-O
M;2X`3F\@<V4@96YC;VYT<O,@96P@9&ER96-T;W)I;R!D92!496UA<R`B)7,B
M+@!.;R!S92!D:7-P;VYE(&1E(&]P8VEO;F5S+@!.;R!H87D@<&%R=&5S('%U
M92!S92!P=65D86X@;6]S=')A<B!E;B!L[6YE82X`16X@97-T92!C86UP;R!H
M87D@9&5M87-I861O<R!C87)A8W1E<F5S+B!(82!I;G1R;V1U8VED;R`E<R!C
M87)A8W1E<F5S('D@=&EE;F4@<75E(&EN=')O9'5C:7(@;65N;W,@9&4@)7,N
M`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A9&ER(&$@(B5S(B!A;"!S
M:7-T96UA.B`E<P!392!P<F]D=6IO('5N('!R;V)L96UA(&%L(&)O<G)A<B!L
M;W,@9&%T;W,@9&5L('5S=6%R:6\@(B5S(B!D96P@<VES=&5M83H@`%-E('!R
M;V1U:F\@=6X@<')O8FQE;6$@86P@96QI;6EN87(@82`B)7,B(&1E;"!S:7-T
M96UA.B``4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A8W1U86QI>F%R("(E
M<R(Z("5S`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@8V]N(&QA(&-A<F=A(&1E
M;"!A<F-H:79O.B!.;R!S92!C87)G\R`E<RX`4V4@<')O9'5J;R!U;B!P<F]B
M;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N($5L("5S(&5R82!MX7,@
M9W)A;F1E('%U92!E;"!T86UA\6\@;>%X:6UO('!E<FUI=&ED;R`H)60@8GET
M97,I+@!392!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D96P@
M87)C:&EV;RX@4_-L;R!S92!C87)G\R!P87)C:6%L;65N=&4@96P@)7,N`%-E
M('!R;V1U:F\@=6X@97)R;W(@86P@;6]S=')A<B!E<W1A('!A<G1E(&1E;"!M
M96YS86IE`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S(&1A
M=&]S(&1E;"!C;VYT86-T;RX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I;7!O
M<G1A<B!L;W,@9&%T;W,Z("5S`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP
M;W)T87(@;&]S(&1A=&]S(&E#86QE;F1A<BX`4V4@<')O9'5J;R!U;B!E<G)O
M<B!A;"!I;7!O<G1A<B!L;W,@9&%T;W,@=DYO=&4N`%-E('!R;V1U:F\@=6X@
M97)R;W(@96X@96P@9F]R;75L87)I;R!D92!C;VYF:6=U<F%C:?-N+B!0=65D
M92!Q=64@:&%Y82!O;'9I9&%D;R!R96QL96YA<B!U;B!C86UP;R!N96-E<V%R
M:6\N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@96IE8W5T87(@;&$@9G5N8VGS
M;B!E<W!E8VEF:6-A9&$@9&4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RX@
M5G5E;'9A(&$@<')O8F%R(&WA<R!A9&5L86YT92X`4V4@<')O9'5J;R!U;B!E
M<G)O<B!A;"!E;&EM:6YA<B!L82!N;W1A.B`E<P!392!P<F]D=6IO('5N(&5R
M<F]R(&%L(&=U87)D87(@;&$@;F]T83H@)7,`4V4@<')O9'5J;R!U;B!E<G)O
M<B!A;"!A8W1U86QI>F%R(&QO<R!D971A;&QE<R!D96P@8V]N=&%C=&\N(%9U
M96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N`%-E('!R;V1U:F\@=6X@97)R
M;W(@86P@86-T=6%L:7IA<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN(%9U
M96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N`%-E('!R;V1U:F\@=6X@97)R
M;W(@86P@=F5R(&5S=&$@;&EB<F5T83H@)7,`3F\@:'5B;R!M96UO<F%N9&]S
M(&$@97AP;W)T87(N`$5S=&4@<V5R=FED;W(@24U!4"!N;R!S;W!O<G1A(&QA
M<R!C87)P971A<R!C;VUP87)T:61A<RX`R7-T92!N;R!P87)E8V4@<V5R('5N
M(&%R8VAI=F\@<F%R(';A;&ED;RX`R7-T92!N;R!P87)E8V4@<V5R('5N(&%R
M8VAI=F\@>FEP(';A;&ED;RX`R7-T92!N;R!P87)E8V4@<V5R('5N(&[Z;65R
M;R!D92!T87)J971A(';A;&ED;RX`17-T92!C;VYT<F]L861O<B!P97)M:71E
M(&5N=FEA<B!M96YS86IE<R!A('1R87;I<R!D92!L82!P87-A<F5L82!#;&EC
M:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI+"!M961I86YT92!L82!!
M4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A
M:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI+"!M961I86YT92!L82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R
M('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R
M96QA('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!M961I86YT
M92!L82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R
M(&UE;G-A:F5S('9I82!33510(&$@=')A=NES(&1E(&QA('!A<V%R96QA(&1E
M(%9O9&%F;VYE(&1E($ET86QI82P@<_-L;R!A(&[Z;65R;W,@5F]D869O;F4N
M($AA8V4@9F%L=&$@=6YA(&-U96YT82!D92!C;W)R96\@9&4@5F]D869O;F4@
M9&4@271A;&EA("AH='1P.B\O=W=W+C$Y,"YI="DN`$AA8V4@9F%L=&$@97-T
M92!C86UP;RX`17-T92!C86UP;R!S\VQO('!U961E(&-O;G1E;F5R(&5N=&5R
M;W,N`$5S=&4@8V%M<&\@<_-L;R!P=65D92!C;VYT96YE<B!N^FUE<F]S('D@
M;&]S(&1O<R!P=6YT;W,N`$5S=&4@8V%M<&\@<_-L;R!P=65D92!C;VYT96YE
M<B!V86QO<F5S(&]C=&%L97,N`$5S=&4@8V%M<&\@=&EE;F4@<75E('-E<B!U
M;F$@;&ES=&$@9&4@96YT97)O<R!S97!A<F%D;W,@<&]R(&-O;6%S(&\@97-P
M86-I;W,N`$5S=&4@8V%M<&\@=&EE;F4@<75E('-E<B!U;B!N^FUE<F\@=N%L
M:61O+@!%<W1E(&-A;7!O('1I96YE('%U92!C;VYT96YE<B!U;B!C\V1I9F\@
M9&4@8V]L;W(@96X@9F]R;6%T;R!21T(@2&5X861E8VEM86PL('!O<B!E:F5M
M<&QO("<C,3(S-&%F)RX`17-T92!F;W)M871O(&1E(&%R8VAI=F\@;F\@97-T
MX2!S;W!O<G1A9&\N`%EA('-E(&AA('!R;V-E<V%D;R!E<W1E(&9O<FUU;&%R
M:6\N`$5S=&\@97,@)7,N`,ES=&\@97,@=6X@;V)J971O(&1E($MO;&%B($=R
M;W5P=V%R92X@4&%R82!V97)L;R!N96-E<VET82!U;B!C;&EE;G1E(&1E(&-O
M<G)E;R`@<75E(&5N=&EE;F1A(&5L(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E
M+B!087)A('9E<B!U;F$@;&ES=&$@9&4@9&EC:&]S(&-L:65N=&5S('9I<VET
M92`E<P!%<W1E(&UE;G-A:F4@<V4@97-C<FEB:?,@8V]N('5N(&IU96=O(&1E
M(&-A<F%C=&5R97,@*"5S*2!D:7-T:6YT;R!A;"!S=7EO+@!%<W1E(&[Z;65R
M;R!D96)E('-E<B!P;W(@;&\@;65N;W,@=6X@=6YO+@!%<W1E('-E<G9I9&]R
M(&YO('!U961E(&1E<V-O;7!R:6UI<B!A<F-H:79O<R!Z:7`@>2!G>FEP+@!%
M<W1E('-I<W1E;6$@86-T=6%L;65N=&4@97-TX2!D97-A8W1I=F%D;RX`17-T
M92!V86QO<B!T:65N92!Q=64@<V5R('5N(&[Z;65R;RX`17-T82!V96YT86YA
M('/S;&\@<'5E9&4@86)R:7)S92!D97-D92!U;F$@=F5N=&%N82!D92!O<&-I
M;VYE<P!4<G5E;F\`26YC:61E;F-I87,`2&]R80!#+B!T:65M<&]S`$9O<FUA
M=&\@:&]R87)I;P!396QE8V-I\VX@9&4@:&]R80!4:6UO<BU,97-T90!4[71U
M;&\`5.UT=6QO("AC;VYS96IO*3H`4&%R80!087)A('-E;&5C8VEO;F%R('9A
M<FEO<R!C86UP;W,L(&UA;G1E;F=A('!U;'-A9&$@;&$@=&5C;&$@0V]N=')O
M;"`H4$,I(&\@0V]M86YD;R`H36%C*2!A;"!H86-E<B!C;&EC:RX`2&]Y`$-O
M;FUU=&%R(&]R:6=E;B!(5$U,`%1O9V\`5&]K96QA=0!-8?%A;F$`5&]N9V$`
M4W5P97)I;W(`1G)A;64@<W5P97)I;W(@*%]T;W`I`%1R861U8V-I;VYE<P!4
M<FEN:61A9"!Y(%1O8F%G;P!697)D861E<F\@;R!F86QS;P!-87(`5/IN97H`
M5'5R<77M80!4=7)C;R`H25-/+3@X-3DM.2D`5'5R:VUE;FES=.%N`$ES;&%S
M(%1U<FMS('D@0V%I8V]S`%1U=F%L=0!%<V-R:6)A('-U(&5L96-C:?-N.B``
MS6YD:6-E(%4N5BXZ(`!54DP`55),(&1E('-U(&EN9F]R;64@9&4@97-T861O
M(&1E(&5N=NUO(&1E;"!G=6GS;@!54DPZ`%5G86YD80!58W)A;FEA`$EN8V%P
M87H@9&4@86-C961E<B!A;"!D:7)E8W1O<FEO(%9&4RX`26YC87!A>B!D92!A
M\6%D:7(@:6YF;W)M86-I\VX@9&4@=7-U87)I;R!A9&EC:6]N86P@86P@<F5A
M;&EZ87(@96P@86QT82X`26YC87!A>B!D92!C86UB:6%R(&QO<R!P<FEV:6QE
M9VEO<R!D96P@87)C:&EV;R!61E,@(B5S(BX`26YC87!A>B!D92!C86UB:6%R
M(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C:&EV;R!61E,@)7,O)7,N`$EN8V%P
M87H@9&4@8V%M8FEA<B!A("5S+@!);F-A<&%Z(&1E(&-O;7!R;V)A<B!E;"!T
M86UA\6\@9&4@(B5S(BX`26YC87!A>B!D92!C;VUP<F]B87(@96P@=&%M8?%O
M(&1E("(E<R\E<R(N`$EN8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O
M<B!344PN`$EN8V%P87H@9&4@8V]N96-T87(@8V]N(%-33"X`26YC87!A>B!D
M92!C;W!I87(@96P@87)C:&EV;R!61E,N`$EN8V%P87H@9&4@8W)E87(@96P@
M9&ER96-T;W)I;R!61E,@(B5S(BX`26YC87!A>B!D92!C<F5A<B!E;"!D:7)E
M8W1O<FEO(%9&4RX`26YC87!A>B!D92!C<F5A<B!E;"!A<F-H:79O(%9&4RX`
M26YC87!A>B!D92!C<F5A<B!L82!C87)P971A(%9&4R`B)7,B`$EN8V%P87H@
M9&4@8W)E87(@=6X@87)C:&EV;R!61E,@=F%C[6\N`$EN8V%P87H@9&4@9&5S
M8V]M<')I;6ER(&QO<R!D871O<RX`26YC87!A>B!D92!E;&EM:6YA<B`B)7,B
M+"!E;"!D:7)E8W1O<FEO(&YO(&5S=.$@=F%C[6\N`$EN8V%P87H@9&4@96QI
M;6EN87(@(B5S(CH@)7,`26YC87!A>B!D92!E;&EM:6YA<B`B)7,B.B`E<RX`
M26YC87!A>B!D92!E;&EM:6YA<B`E<RP@96P@9&ER96-T;W)I;R!N;R!E<W3A
M('9A8^UO`$EN8V%P87H@9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,@
M9&4@9F]R;6$@<F5C=7)S:79A+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I
M<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R
M:6\@5D93.B`E<RX`26YC87!A>B!D92!E;&EM:6YA<B!E;"!A<F-H:79O(%9&
M4R`B)7,B+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&%R8VAI=F\@5D93+@!)
M;F-A<&%Z(&1E(&5L:6UI;F%R(&QA(&-A<G!E=&$@5D93("(E<R(N`$EN8V%P
M87H@9&4@96QI;6EN87(@96P@5D93(&1E(&9O<FUA(')E8W5R<VEV83H@)7,N
M`$EN8V%P87H@9&4@9&5T97)M:6YA<B!E;"!D:7)E8W1O<FEO(&%C='5A;"X`
M26YC87!A>B!D92!E>'1R865R(&QO<R!D971A;&QE<R!D96P@8V5R=&EF:6-A
M9&\N`$EN8V%P87H@9&4@8V%R9V%R(&QA(&1E9FEN:6-I\VX@9&4@)7,N`$EN
M8V%P87H@9&4@=')A<VQA9&%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E
M(&%B<FER(&5L(&%R8VAI=F\@5D93("(E<R(N`$EN8V%P87H@9&4@86)R:7(@
M96P@87)C:&EV;R!61E,@<&%R82!E<V-R:6)I<BX`26YC87!A>B!D92!A8G)I
M<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O
M(&-O;7!R:6UI9&\N`$EN8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O(%9&4R`H
M:&$@9F%L;&%D;R!F:6QE<VEZ92@I*2X`26YC87!A>B!D92!L965R('5N(&%R
M8VAI=F\@5D93("AH82!F86QL861O(&=E=$9I;&53:7IE*"DI+@!);F-A<&%Z
M(&1E(&QE97(@=6X@87)C:&EV;SH@`$EN8V%P87H@9&4@;&5E<B!E;"!D:7)E
M8W1O<FEO('9F<W)O;W0N`$EN8V%P87H@9&4@<F5N;VUB<F%R("5S(&-O;6\@
M)7,Z(&QA(&-A<G!E=&$@9&5S=&EN;R!Y82!E>&ES=&4`26YC87!A>B!D92!R
M96YO;6)R87(@96P@9&ER96-T;W)I;R!61E,N`$EN8V%P87H@9&4@<F5N;VUB
M<F%R(&5L(&1I<F5C=&]R:6\@5D93.B`E<RX`26YC87!A>B!D92!R96YO;6)R
M87(@96P@87)C:&EV;R!61E,@(B5S(@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E
M;"!A<F-H:79O(%9&4R`E<R\E<RX`26YC87!A>B!D92!R96YO;6)R87(@96P@
M87)C:&EV;R!61E,N`$EN8V%P87H@9&4@96IE8W5T87(@)VUK:7-O9G,G+@!.
M;R!S92!P=65D92!T<F%D=6-I<B!E<W1E(&1O8W5M96YT;R!D92!7;W)D`$EN
M8V%P87H@9&4@97-C<FEB:7(@96P@87)C:&EV;R!61E,@(B5S(BX`26YC87!A
M>B!D92!E<V-R:6)I<B!U;B!A<F-H:79O(%9&4R`H:&$@9F%L;&%D;R!C;W!Y
M*"DI+@!);F-A<&%Z(&1E(&5S8W)I8FER(&QO<R!D871O<R!D96P@87)C:&EV
M;R!61E,N`$EN8V%P87H@9&4@97-C<FEB:7(@=6X@87)C:&EV;R!61E,L('-E
M('-U<&5R87+A(&QA('%U;W1A+@!3=6)R87EA9&$`1&5S:&%C97(@8V%M8FEO
M<P!$97-H86-E<B!C86UB:6]S`$1E<VAA8V4@;&$@^FQT:6UA(&%C8VGS;@!2
M97-P=65S=&$@:6YE<W!E<F%D82!D96P@<V5R=FED;W(@96X@;&$@8V]N97AI
M\VXZ(`!297-P=65S=&$@:6YE<W!E<F%D82!D96P@<V5R=FED;W(@83H@`%-I
M;B!C871E9V]R[6$`56YI8V]D92`H551&+3@I`$5M:7)A=&]S(,%R86)E<R!5
M;FED;W,`26YG;&%T97)R80!%<W1A9&]S(%5N:61O<P!%<W1A9&]S(%5N:61O
M<R!M96YO<R!L87,@:7-L87,@<&5R:6;I<FEC87,`56YI9&%D97,`1&5S8V]N
M;V-I9&\`07!I;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E(&UE;G-A:F4@9&4@
M;&$@05!)*2X`0VQI;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E(&UE;G-A:F4@
M9&5L(&-L:65N=&4I+@!392!H82!D969I;FED;R!U;F$@=6)I8V%C:?-N(&1E
M<V-O;F]C:61A+@!5<W5A<FEO(&\@8V]N=')A<V7Q82!D97-C;VYO8VED;W,N
M`$5L:6UI;F%R(';M;F-U;&\@9&5L(&5L96UE;G1O(&%C='5A;`!3:6X@;F]M
M8G)E`$QO<R!G=6EO;F5S('-I;B!P<FEV:6QE9VEO<R!N;R!P=65D96X@86-C
M961E<B!D92!F;W)M82!P<F]G<F%MX71I8V$@82!#;W)T87(O0V]P:6%R+U!E
M9V%R('!O<B!R87IO;F5S(&1E('-E9W5R:61A9"X@4'5L<V4@06-E<'1A<B!P
M87)A('9E<B!E;B!M;WII;&QA+F]R9R!U;F$@;F]T82!TZ6-N:6-A('%U92!L
M92!M=65S=')E(&/S;6\@<&5R;6ET:7(@<75E('5N(&=U:?-N(&%C8V5D82!A
M;"!P;W)T87!A<&5L97,N`$%N=6QA<B!C;VQO<@!4:7!O(&1E(&-O;G1E;FED
M;R!N;R!S;W!O<G1A9&\Z("5S`$5X=&5N<VGS;B!N;R!S;W!O<G1A9&$`06-T
M=6%L:7IA<@!!8W1U86QI>F%R("5S`$%C='5A;&EZ87(@=7-U87)I;P!392!H
M82!A8W1U86QI>F%D;R`B)7,B+@!392!H82!E;&EM:6YA9&\@96P@9W5I\VX@
M9&4@86-T=6%L:7IA8VGS;BX`0V%R9V%R`%-E(&AA;B!C87)G861O(&5N(&5L
M('-E<G9I9&]R('1O9&]S(&QO<R!A<F-H:79O<R!D92!C;VYF:6=U<F%C:?-N
M(&1E(&%P;&EC86-I;VYE<RX`06QF86)E=&\@;&%T:6YO(&5N(&UA>?IS8RX`
M3OIM97)O<R!R;VUA;F]S(&5N(&UA>?IS8RX`57)U9W5A>0!5<V%R(&%C='5A
M;#H@)7,`57-A<B!34TP`4V4@=7-A('-I(&5L('5S=6%R:6\O8V]N=')A<V7Q
M82!S;VX@9&ES=&EN=&]S(&5N(&5L('-E<G9I9&]R($E-4U`N`%5S=6%R:6\`
M16P@=7-U87)I;R`E<R!C87)E8V4@9&4@875T;W)I>F%C:?-N('!A<F$@)7,N
M`$%D;6EN:7-T<F%C:?-N(&1E('5S=6%R:6]S`$]P8VEO;F5S(&1E('5S=6%R
M:6\`4F5G:7-T<F\@9&4@=7-U87)I;W,`17-T82!S961E('1I96YE(&1E<V%C
M=&EV861O(&5L(')E9VES=')O(&1E('5S=6%R:6]S+@!.;R!S92!H82!E;F-O
M;G1R861O(&QA(&ED96YT:61A9`!5<W5A<FEO`%EA(&5X:7-T92!E;"!N;VUB
M<F4@9&4@=7-U87)I;R`B)7,B+@!5<W5A<FEO.@!5<W5A<FEO.B``57-U87)I
M;W,@96X@96P@<VES=&5M83H`57IB96MI<W3A;@!.;R!E>&ES=&4@96P@9&ER
M96-T;W)I;R!61E,N`$%U<V5N8VEA`$QA<R!U8FEC86-I;VYE<R!VX6QI9&%S
M(&5N8V]N=')A9&%S(&EN8VQU>65N.B``5F%L:61E>@!686QO<B!E;B!M:6YU
M=&]S(&$@<&%R=&ER(&1E(&%H;W)A+@!%;"!V86QO<B!E>&-E9&4@96P@=&%M
M8?%O(&WA>&EM;R!D92`E<RX`5F%L;W)E<P!686QO<F5S(&$@<V5L96-C:6]N
M87(`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`2&$@9F%L;&%D;R!L82!C
M;VUP<F]B86-I\VX@+2!E<W1E(&UE;G-A:F4@<'5E9&4@:&%B97)S92!F;W)Z
M861O+@!697)S:?-N`$,N('9E<G-I;VYE<P!!;&EN96%C:?-N('9E<G1I8V%L
M`$UA<F=E;B!V97)T:6-A;`!697)T:6-A;#H`375Y(&%L=&$`5FEE=&YA;0!6
M:65T;F%M:71A("A625-#24DI`%9E<B`E<P!697(@=6YA('#A9VEN82!W96(@
M97AT97)N80!697(@8V]M;R`E<P!)<VQA<R!6[7)G96YE<RP@0G)I=.%N:6-A
M<P!)<VQA<R!6[7)G96YE<RP@52Y3+@!6:7-I8FEL:61A9`!6:7-I8FEL:61A
M9#H@`%9O9&%F;VYE(&1E($ET86QI82!M961I86YT92!33510`$%625-/`*&A
MH4%$5D525$5.0TE!(2$A($5,24U)3D4@34%.54%,345.5$4@14P@1U5)TTX@
M1$4@)7,N`%=)3B!P;W(@2%144`!786QL:7,@>2!&=71U;F$`061V97)T96YC
M:6$`36EE`%!R979I<VGS;B!D96P@=&EE;7!O`$1A=&]S(&1E;"!T:65M<&\@
M<W5M:6YI<W1R861O<R!P;W(`5V5A=&AE<BYC;VT`5V5B`%-E9&4@5V5B`%-E
M;6%N86QM96YT90!":65N=F5N:61O`$)I96YV96YI9&]S(&$@)7,`0FEE;G9E
M;FED;RP@)7,`3V5S=&4@*$E33RTX.#4Y+3$I`$]E<W1E("A)4T\M.#@U.2TQ
M-2D`4^%H87)A($]C8VED96YT86P`OU%UZ2!A<&QI8V%C:?-N(&1E8F5R[6$@
M;6]S=')A<B`E<R!A;"!I;FEC:6%R(&QA('-E<VGS;C\`OT-UX6P@97,@96P@
M8V%RX6-T97(@9&5L:6UI=&%D;W(_`+]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E
M(&-I=&%D;S\`36%P82!D92!L;V-A;&EZ86-I\VX@9&4@075S=')A;&EA`+]!
M('%UZ2!L:6)R971A(&AA>2!Q=64@8?%A9&ER(&QA<R!N;W1A<S\`477I(&9A
M<V5S`%!L=6=I;G,@:&%B:6QI=&%D;W,@9&5L(&5D:71O<B!D92!T97AT;R!E
M;G)I<75E8VED;RX`06YC:'5R80!!;F-H=7)A(&5N('5N:61A9&5S($-34P!!
M;F-H=7)A(&1E;"!M96[Z("5S(&EZ<75I97)D;R`H9&ES<&]N:6)L92!E;B!L
M82!P<O-X:6UA('-E<VGS;BDZ`$%N8VAU<F$@9&4@;&$@=&%B;&$`56YI9&%D
M97,@9&4@86YC:'5R80!!;F-H=7)A.@!7:6MI`%9I96YT;P!6:65N=&\@;6%T
M=71I;F$`5F5L;V-I9&%D(&1E;"!V:65N=&\@96X@;G5D;W,`5FEE;G1O.@!6
M:65N=&\Z(`!386)I9'5R[6$`1&5S96]S`$5M<&QE;P!$:7)E8V-I\VX@9&5L
M('1R86)A:F\`5&5LZ69O;F\@9&5L('1R86)A:F\`3OIM97)O(&5R<O-N96\@
M9&4@8V%M<&]S(&5N(&QA(&SM;F5A("5D+B!392!E<W!E<F%B86X@)60@>2!H
M87D@)60N`$[Z;65R;R!E<G+S;F5O(&1E(&-A;7!O<RX@4V4@97-P97)A8F%N
M("5D('D@:&%Y("5D+@!/9F9S970@)60@97)R\VYE;R!A;"!L965R('5N(&%R
M8VAI=F\@5D93+@!8+5)E9@!,:6UI=&%C:6]N97,@8N%S:6-A<R!8-3`Y=C,`
M57-O(&1E(&-L879E(&5X=&5N9&ED82!8-3`Y=C,`3F]M8G)E(&%L=&5R;F%T
M:79O(&1E(&%S=6YT;R!8-3`Y=C,`261E;G1I9FEC861O<B!D92!C;&%V92!D
M92!A<W5N=&\@6#4P.78S`$5X=&5N<VEO;F5S(%@U,#EV,P!!00!!04%!`*%-
M87!A(&1E(%EA:&]O(0!!;G5A;&UE;G1E`%EE;65N`%/M`%/M+"!L;R!A8V5P
M=&\`17-TX2!E;B!-3T1/(%1%6%1/+B!5=&EL:6-E(&5L(&)O=/-N(%L\/ET@
M<&%R82!R96=R97-A<B!A;"!M;V1O(%=94TE764<N`$YO(&1I<W!O;F4@9&4@
M<')I=FEL96=I;W,@<&%R82!C<F5A<B!MX7,@9&4@)60@8FQO<75E<RX`3F\@
M9&ES<&]N92!D92!P<FEV:6QE9V]I<R!P87)A(&-R96%R(&WA<R!D92`E9"!N
M;W1A<RX`3F\@97-TX2!A=71E;G1I9FEC861O+@!.;R!P=65D92!I;F-L=6ER
M(&5L(&-A<N%C=&5R(")<(B!E;B!E;"!N;VUB<F4@8V]M<&QE=&\N`$YO(&EN
M=')O9'5J;R!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;R!VX6QI9&$N`$YO(&%S
M;V-I\R!N:6YG=6YO(&1E(&QO<R!C86UP;W,@9&5L(&%R8VAI=F\@:6UP;W)T
M861O(&$@;&]S(&-A;7!O<R!C;W)R97-P;VYD:65N=&5S(&1E("5S+@!.;R!D
M:7-P;VYE(&1E('!R:79I;&5G:6]S('!A<F$@=F5R(&QA(&QI8G)E=&$@)7,N
M`$AA('-A;&ED;R!D92!L82!S97-I\VXN`%1I96YE('%U92!I;G1R;V1U8VER
M('5N(&[Z;65R;R!D92!T96SI9F]N;R!M\W9I;"!VX6QI9&\L('/S;&\@9.UG
M:71O<R!C;VX@=6X@)RLG(&]P8VEO;F%L('!A<F$@96P@<')E9FEJ;R!D92!L
M;&%M861A(&EN=&5R;F%C:6]N86PN`%1I96YE('%U92!I;G1R;V1U8VER('5N
M('9A;&]R(';A;&ED;RX`4&%R82!U<V%R($%L=&%S('1I96YE('%U92!C;VYF
M:6=U<F%R('5N(&UO=&]R(&1E($1A=&%4<F5E+@!4:65N92!Q=64@8V]N9FEG
M=7)A<B!U;B!M;W1O<B!61E,N`$1E8F4@9&5S8W)I8FER(&5L('!R;V)L96UA
M(&%N=&5S(&1E(&5N=FEA<B!E;"!I;F9O<FUE+@!4:65N92!Q=64@:6YT<F]D
M=6-I<B!L82!54DP@82!L82!Q=64@87!U;G1A(&5S=&4@=NUN8W5L;P!4:65N
M92!Q=64@<V5L96-C:6]N87(@=6YA(&QI8G)E=&$@82!E;&EM:6YA<BX`5&EE
M;F4@<75E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R(&$@96QI;6EN87(N`%1I
M96YE('%U92!E<W!E8VEF:6-A<B!U;B!U<W5A<FEO(&$@96QI;6EN87(N`%1I
M96YE('%U92!E<W!E8VEF:6-A<B!U;B!U<W5A<FEO(&$@96QI;6EN87(N`%1I
M96YE('%U92!E<W!E8VEF:6-A<B!E;"!U<W5A<FEO(&$@8?%A9&ER+@!4:65N
M92!Q=64@97-P96-I9FEC87(@96P@=7-U87)I;R!A(&%C='5A;&EZ87(N`%1I
M96YE('%U92!E<W!E8VEF:6-A<B!Q=>D@86-C:?-N('-E(&5J96-U=&%RX2X`
M5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@;G5E=F\@;F]M8G)E(&1E(&-A=&5G
M;W+M82X`5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@;OIM97)O(&1E('1E;.EF
M;VYO(&ET86QI86YO`$AA(&5X<&ER861O('-U('-E<VGS;B`E<RX@5G5E;'9A
M(&$@:6YI8VEA<B!S97-I\VXN`%-U(&1I<F5C8VGS;B!D92!C;W)R96\`1&ER
M96-C:?-N($1E.@!3=2!I;F9O<FUA8VGS;@!(82!C86UB:6%D;R!S=2!D:7)E
M8V-I\VX@9&4@26YT97)N970@9&5S9&4@96P@8V]M:65N>F\@9&4@<W4@<V5S
M:?-N("5S+B!0;W(@<F%Z;VYE<R!D92!S96=U<FED860@=&EE;F4@<75E('9O
M;'9E<B!A(&EN:6-I87(@;&$@<V5S:?-N+@!3=2!N;VUB<F4`4W4@;6]T;W(@
M9&4@875T96YT:69I8V%C:?-N(&YO('!E<FUI=&4@8?%A9&ER('5S=6%R:6]S
M+B!3:2!Q=6ES:65R82!U<V%R($AO<F1E('!A<F$@861M:6YI<W1R87(@8W5E
M;G1A<R!D92!U<W5A<FEO+"!T96YD<N$@<75E('5T:6QI>F%R('5N(&UO=&]R
M(&1E(&%U=&5N=&EF:6-A8VGS;B!D:7-T:6YT;RX`4W4@;6]T;W(@9&4@875T
M96YT:69I8V%C:?-N(&YO('!E<FUI=&4@;&ES=&%R('5S=6%R:6]S+"!O('-E
M(&AA(&1E<VAA8FEL:71A9&\@;&$@8V%R86-T97+M<W1I8V$@<&]R(&%L9_IN
M(&UO=&EV;RX`4&%R96-E('%U92!H82!C86UB:6%D;R!S=2!N879E9V%D;W(@
M9&5S9&4@96P@8V]M:65N>F\@9&4@<W4@<V5S:?-N("5S+B!0;W(@<F%Z;VYE
M<R!D92!S96=U<FED860@=&EE;F4@<75E('9O;'9E<B!A(&EN:6-I87(@;&$@
M<V5S:?-N+@!3=2!N879E9V%D;W(@;F\@861M:71E(&5S=&$@8V%R86-T97+M
M<W1I8V$N`$5L(&YA=F5G861O<B!N;R!A9&UI=&4@97-T82!O<&-I\VX@9&4@
M:6UP<F5S:?-N+B!0<F5S:6]N92!#;VYT<F]L+T-O;6%N9&\@*R!0('!A<F$@
M:6UP<FEM:7(N`%IO;F$@:&]R87)I82!A8W1U86PZ`%-E(&AA(&-A;6)I861O
M('-U(&ED96YT:61A9"!P;W(@;VUI<VGS;BX`261E;G1I9&%D('!O<B!O;6ES
M:?-N.@!3=2!L:6)R971A('!O<B!O;6ES:?-N.@!.;VUB<F4@8V]M<&QE=&\Z
M`%-E(&AA(&%G;W1A9&\@<W4@=&EE;7!O(&1E(&-O;F5X:?-N+@!,82!N=65V
M82!C;VYT<F%S9?%A('!A<F$@)7,@97,Z("5S`%-U<R!L:6)R971A<SH`4V4@
M:&%N(&%C='5A;&EZ861O('-U<R!O<&-I;VYE<R!S\VQO('!O<B!L82!D=7)A
M8VGS;B!D92!L82!S97-I\VXN`%-E(&AA;B!A8W1U86QI>F%D;R!S=7,@;W!C
M:6]N97,N`%-E(&AA(')E86IU<W1A9&\@<W4@8V]N=')A<V7Q80!392!H82!R
M96%J=7-T861O('-U(&-O;G1R87-E\6$L(&-O;7!R=65B92!E;"!C;W)R96\@
M92!I;FEC:64@<V5S:?-N(&-O;B!S=2!N=65V82!C;VYT<F%S9?%A+@!,82!C
M;VYT<F%S9?%A(&AA(&5X<&ER861O+@!397)V:61O<F5S(')E;6]T;W,Z`%EU
M9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M/8W5L=&%R
M('1E>'1O(&-I=&%D;UT`6TEN9F]R;64@9&4@<')O8FQE;6%=`%M-;W-T<F%R
M('1E>'1O(&-I=&%D;R`M`%M-;W-T<F%R('1E>'1O(&-I=&%D;R`M("5S(&SM
M;F5A<UT`6VSM;F5A("5S(&1E("5S70!?061M:6YI<W1R86-I\VX`7U)E9W)E
M<V%R(&$@;&$@;&EB<F5T80!?0TQ)`%]#871E9V]R[6$`P7)?8F]L(&1A=&]S
M`%]%;&EM:6YA<@!%7VQI;6EN87(@9FEL80!-;U]D:69I8V%R`%!?<FEM97)A
M(&SM;F5A`%]'<G5P;W,`05]Y=61A`%!R;W!I961A9&5S(&1E(%]I;6%G96XN
M+BX`7TEM<&]R=&%R+T5X<&]R=&%R`%],:7-T87(`7TEN:6-I87(@<V5S:?-N
M`%]386QI<@!-;V1I9FEC87(@7W;M;F-U;&\N+BX`7TUI<R!L:6)R971A<P!?
M0?%A9&ER`%]/<&-I;VYE<P!?4')I=FEL96=I;W,`26U?<')I;6ER`%]%;&EM
M:6YA<B!V[6YC=6QO+BXN`%]"=7-C87(`0V]N7V9I9W5R86,N`%!R;W!I961A
M9&5S(&1E(%]T86)L82XN+@!?57-U87)I;W,`9&ER96-C:6]N97,`9&5S=&EN
M871A<FEO(&1E<V-O;F]C:61O`&%G96YD80!C86QM80!N;R!S92!P=65D92!C
M<F5A<B!E;"!A<F-H:79O(&1E(&1E<W1I;F\`;F\@<V4@<'5E9&4@86)R:7(@
M96P@;W)I9V5N`'!U;'-E(&%Q=>T`97)R;W(@9&4@;.UN96$@9&4@8V]M86YD
M;P!E<G)O<B!D92!C;VYF:6=U<F%C:?-N`&9A;'1A('5N(&%R8VAI=F\@8W+M
M=&EC;R!D96P@<VES=&5M80!E<G)O<B!D92!F;W)M871O(&1E(&1A=&]S`&UO
M9&EF:6-A<@!E;G1R861A(&YO(&5N8V]N=')A9&$`9&5S8V5N<V\`87)C:&EV
M;P!D96P@)7,@*"5S*2!A(&QA<R`E<R`E<P!V96YT;W-O`&@Z`&AH`&YO;6)R
M92!D92!A;F9I=')I\VX@9&5S8V]N;V-I9&\`:6YM961I871A;65N=&4`96X@
M;.UN96$`97)R;W(@9&4@96YT<F%D82]S86QI9&$`97)R;W(@9&4@<V]F='=A
M<F4@:6YT97)N;P!L[6YE87-=`&/S9&EG;R!D92!E<G)O<B!M:VES;V9S("5D
M(&%L(')E86QI>F%R($E33RX`;6T`;F]M8G)E`'-I;B!D97-A<G)O;&QA<@!A
M^FX@;F\@<V4@:&$@9&5S87)R;VQL861O`&YO=&%S`&YO=&%S+F-S=@!P;W)C
M96YT86IE`'!R:79I;&5G:6\@9&5N96=A9&\`<.UX96QE<P!E<G)O<B!R96UO
M=&\@9&4@<')O=&]C;VQO`&5N(&%U;65N=&\`<V5R=FEC:6\@;F\@9&ES<&]N
M:6)L92X`;6]S=')A<B!D:69E<F5N8VEA<P!S;7,R96UA:6P@<&]R($A45%``
M<W,`97-T86)L90!E<G)O<B!D96P@<VES=&5M80!T87)E87,`9F%L;&\@=&5M
M<&]R86P`97-C<FEB82!D;W,@=F5C97,@;&$@8V]N=')A<V7Q82!P87)A(&-O
M;F9I<FUA<FQA`'5N:69I8V%D;P!S:6X@;F]M8G)E`'5S=6%R:6\@<V5L96-C
M:6]N861O`'9#87)D`'9.;W1E`'<Z`'=E871H97(N8V]M````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE
M;6\O;&]C86QE+V5S7T53+VAE;'`N>&UL````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-3,U,P`Q,#0Q-S,V,C<T-``P,C$T-3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]X;6P@=F5R<VEO
M;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!M;F5M;R]L;V-A;&4O97-?15,O:&5L
M<"YX;6PL=B`Q+C$@,C`P-"\Q,B\Q,2`Q,3HU-3HU-B!J86X@17AP("0@+2T^
M"CQH96QP/@H*/&5N=')Y(&ED/2)/=F5R=FEE=R(@;60U/2(U,&5E-S8Q,SAF
M8C`X8C`T8C`R.3`P-C`U,V)B861B8R(@<W1A=&4](G5P=&]D871E(CX*("`@
M(#QT:71L93Y);G1R;V1U8V-I)B-X1C,[;CPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY);G1R;V1U8V-I)B-X1C,[;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M/&D^3F]T87,\+VD^(&5S('5N82!A<&QI8V%C:28C>$8S.VX@<75E(&QE('!E
M<FUI=&4@8W)E87(@96X@96P@;W)D96YA9&]R(&5L(&5Q=6EV86QE;G1E(&$@
M;&%S(&YO=&%S(&%D:&5S:79A<RX@3&%S(&YO=&%S('-E('!U961E;B!C<F5A
M<BP@;6]D:69I8V%R+"!E;&EM:6YA<B!E(&EM<')I;6ER+B!486UB:28C>$4Y
M.VX@<'5E9&4@8G5S8V%R(&5N(&5L;&%S('!A<F$@;&]C86QI>F%R(&EN9F]R
M;6%C:28C>$8S.VXN(%-E(&1I<W!O;F4@:6=U86QM96YT92!D92!S;W!O<G1E
M('!A<F$@;&$@:6UP;W)T86-I)B-X1C,[;B!Y(&5X<&]R=&%C:28C>$8S.VX@
M9&4@;&%S(&YO=&%S+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!(&1I
M9F5R96YC:6$@9&4@;&%S(&YO=&%S(&%D:&5S:79A<R!R96%L97,L(&QA<R!D
M96P@;W)D96YA9&]R('!U961E;B!C;VUP87)T:7)S92!C;VX@;W1R;W,@=7-U
M87)I;W,@96X@9&ES=&EN=&%S('5B:6-A8VEO;F5S(&8F(WA%1#MS:6-A<RX@
M3&%S(&YO=&%S('!U961E;B!O<F=A;FEZ87)S92!E;B!D:7-T:6YT87,@;&EB
M<F5T87,@>2!S92!L97,@<'5E9&4@87-I9VYA<B!C871E9V]R)B-X140[87,N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](FQI<W0M86-T:6]N
M<R(@;60U/2(V9#4Y,F8Q-3-B9F(U8S(Y-F1E-61F96)B-#(X93%B82(@<W1A
M=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y6:7-T82!D92!N;W1A<SH@06-C
M:6]N97,\+W1I=&QE/@H@("`@/&AE861I;F<^06-C:6]N97,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(#QI/D5L:6UI;F%R/"]I/B!S=7!R:6UE(&1E(&9O
M<FUA('!E<FUA;F5N=&4@;&$@;F]T82!S96QE8V-I;VYA9&$N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@(#QI/DUO9&EF:6-A<CPO:3X@;&4@<&5R;6ET
M92!M;V1I9FEC87(@=6YA(&YO=&$@97AI<W1E;G1E+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("`\:3Y296=R97-A<B!A(&QA(&QI8G)E=&$\+VD^(&QE
M(&1E=G5E;'9E(&1E<V1E(&QA('9I<W1A(&1E(&YO=&%S(&$@;&$@=FES=&$@
M9&4@;&$@;&EB<F5T82!Q=64@8V]N=&5N9V$@;&$@;F]T82!A8W1U86PN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](FUE;G4M86-T:6]N<R(@
M;60U/2(W,35A.#4S9#DS8V0S,S,P931D-S,P8CDQ,3)C.&$X,B(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93Y%;&5M96YT;W,@9&5L(&UE;B8C>$9!
M.SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%;&5M96YT;W,@9&5L(&UE;B8C>$9!
M.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@/&D^3&ES=&%R/"]I/B!M=65S
M=')A('1O9&%S(&QA<R!N;W1A<R!D92!L82!L:6)R971A(&%C='5A;"X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@/&D^028C>$8Q.V%D:7(\+VD^(&QE
M('!E<FUI=&4@8W)E87(@=6YA(&YO=&$@96X@;&$@;&EB<F5T82!A8W1U86PN
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#QI/D)U<V-A<CPO:3X@;&4@
M<&5R;6ET92!B=7-C87(@=&5X=&\@96X@;&%S(&YO=&%S+B!0=65D92!B=7-C
M87(@<R8C>$8S.VQO('!O<B!E;"!C86UP;R!D97-C<FEP8VDF(WA&,SMN(&\@
M96X@96P@=&5X=&\@8V]M<&QE=&\@9&4@;&%S(&YO=&%S+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("`\:3Y);7!O<G1A<B]%>'!O<G1A<CPO:3X@;&4@
M<&5R;6ET92!I;7!O<G1A<B!O(&5X<&]R=&%R(&YO=&%S+B!!8W1U86QM96YT
M92!E<W0F(WA%,3MN('-O<&]R=&%D;W,@;&]S(&9O<FUA=&]S(&1E(&%R8VAI
M=F\@0U-6('D@=DYO=&4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#QI
M/DEM<')I;6ER/"]I/B!L92!P97)M:71E(&EM<')I;6ER('5N82!N;W1A+B!%
M;"!I8V]N;R`\:3Y);7!R:6UI<CPO:3X@<R8C>$8S.VQO('-E<B8C>$4Q.R!V
M:7-I8FQE(&5N(&QA(&)A<G)A(&1E;"!M96XF(WA&03L@8W5A;F1O('-E(&5S
M="8C>$4Y.R!V:7-U86QI>F%N9&\@=6YA(&YO=&$N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"@H*/&5N=')Y(&ED/2)S;W)T:6YG(B!M9#4](F-C83-B,60Q8SEE
M9#!E8S5A8C,X-68X,C0V.61D8SAF(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@
M/'1I=&QE/D]R9&5N86-I)B-X1C,[;B!D92!E;G1R861A<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY/<F1E;F%C:28C>$8S.VX@9&4@96YT<F%D87,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($%L('9I<W5A;&EZ87(@=6X@;&ES=&%D;R!D
M92!E;G1R861A<RP@<'5E9&4@;W)D96YA<FQA<R!P;W(@8W5A;'%U:65R82!D
M92!L87,@8V]L=6UN87,@<'5L<V%N9&\@96X@96P@="8C>$5$.W1U;&\@9&4@
M;&$@8V%B96-E<F$@9&4@;&$@8V]L=6UN82!A<')O<&EA9&$N(%!A<F$@8V]N
M;75T87(@96P@<V5N=&ED;R!D92!L82!C;&%S:69I8V%C:28C>$8S.VX@9&4@
M=6YA(&-O;'5M;F$@96YT<F4@87-C96YD96YT92!Y(&1E<V-E;F1E;G1E+"!P
M=6QS92!E;"!I8V]N;R!D92!F;&5C:&$@9&4@;&$@8V%B96-E<F$@9&4@;&$@
M8V]L=6UN82X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O9FE?1DDO
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S0T`#`Q-S<U,@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN
M96UO+VQO8V%L92]F:5]&22],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(Q-3,W`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+V9I7T9)+TQ#7TU%4U-!1T53
M+VUN96UO+FUO```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0S,34W,0`Q,#0Q-S,V,C<T
M-``P,C,R,3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````#]!P``'`````1```"I"@``['\```````"0J@``#@``
M`)&J```/````H*H```T```"PJ@``"````+ZJ```+````QZH```P```#3J@``
M!````."J```8````Y:H``!L```#^J@``+0```!JK```=````2*L``"0```!F
MJP``*0```(NK```9````M:L``"8```#/JP``#````/:K```D`````ZP```@`
M```HK```#P```#&L```+````0:P```X```!-K```!0```%RL```H````8JP`
M``@```"+K```"@```)2L```5````GZP``!(```"UK```"P```,BL```-````
MU*P``!T```#BK```A0````"M```.````AJT```H```"5K0``#0```*"M```.
M````KJT``!$```"]K0``#0```,^M```,````W:T```T```#JK0``!@```/BM
M``"4````_ZT```H```"4K@``#P```)^N```8````KZX```P```#(K@``!@``
M`-6N```.````W*X```X```#KK@``"````/JN```)`````Z\``"X````-KP``
M&@```#RO```R````5Z\``#@```"*KP``5````,.O``!1````&+```%H```!J
ML```5P```,6P```T````';$```D```!2L0``#0```%RQ```'````:K$```H`
M``!RL0``#P```'VQ```%````C;$```8```"3L0``$0```)JQ```(````K+$`
M``D```"UL0``"0```+^Q```E````R;$``"````#OL0``'````!"R```>````
M+;(``"````!,L@``'0```&VR```3````B[(``!````"?L@``#P```+"R```*
M````P+(```,```#+L@``#P```,^R```4````W[(```D```#TL@``#0```/ZR
M```2````#+,``!D````?LP``'@```#FS```/````6+,```P```!HLP``"@``
M`'6S```/````@+,```@```"0LP``)````)FS```4````OK,``!8```#3LP``
M"````.JS``!.````\[,``"T```!"M```$0```'"T```9````@K0```<```"<
MM```#````*2T```L````L;0```X```#>M````P```.VT```+````\;0```<`
M``#]M```!P````6U```%````#;4```4````3M0``"@```!FU```#````)+4`
M`!<````HM0``"@```$"U```/````2[4```X```!;M0``&````&JU```C````
M@[4```X```"GM0``%````+:U```7````R[4``!<```#CM0``%P```/NU```3
M````$[8```\````GM@``#@```#>V```?````1K8``!T```!FM@``!P```(2V
M```&````C+8```@```"3M@``#P```)RV```&````K+8```H```"SM@``$P``
M`+ZV```+````TK8``!````#>M@``%0```.^V```5````!;<```<````;MP``
M$````".W```%````-+<``!4````ZMP``$0```%"W```,````8K<``#L```!O
MMP``.````*NW```)````Y+<```<```#NMP``%````/:W```#````"[@```4`
M```/N```"0```!6X```0````'[@```D````PN```$P```#JX```Y````3K@`
M`!(```"(N```)P```)NX```L````P[@``"H```#PN```)0```!NY```*````
M0;D```8```!,N0``"0```%.Y```'````7;D``"\```!EN0``-P```)6Y```N
M````S;D``%4```#\N0``+0```%*Z```M````@+H``#T```"NN@``/P```.RZ
M```M````++L``$````!:NP``(P```)N[```C````O[L``$````#CNP``+0``
M`"2\```S````4KP``"4```"&O```%0```*R\```9````PKP``"D```#<O```
M)`````:]```H````*[T``!4```!4O0``$0```&J]```*````?+T```P```"'
MO0``#P```)2]```7````I+T```H```"\O0``$````,>]```6````V+T``!8`
M``#OO0``!P````:^```'````#KX``!0````6O@``"@```"N^```(````-KX`
M`"<````_O@``"````&>^```'````<+X```<```!XO@``!@```("^```%````
MA[X```<```"-O@``!@```)6^```(````G+X``"D```"EO@``#@```,^^```*
M````WKX```0```#IO@``!P```.Z^```)````]KX```8`````OP``$0````>_
M```'````&;\``!8````AOP``!````#B_```(````/;\```8```!&OP``#0``
M`$V_```&````6[\``!X```!BOP``$0```(&_```(````D[\```T```"<OP``
M#````*J_```'````M[\```,```"_OP```P```,._```7````Q[\```,```#?
MOP``$P```.._```=````][\```@````5P```!````![````(````(\````@`
M```LP```00```#7````:````=\```"L```"2P```(````+[````5````W\``
M``8```#UP```!@```/S````5`````\$``!@````9P0``(@```#+!```N````
M5<$``!T```"$P0``(0```*+!``!4````Q,$``"D````9P@``"@```$/"```'
M````3L(```<```!6P@``%0```%["```(````=,(```X```!]P@``"@```(S"
M```/````E\(```T```"GP@``#P```+7"```-````Q<(```D```#3P@``%```
M`-W"```&````\L(``!@```#YP@``'0```!+#```3````,,,``!$```!$PP``
M%````%;#```$````:\,```8```!PPP``%````'?#``!4````C,,``"T```#A
MPP``9`````_$```$````=,0```X```!YQ```!0```(C$```%````CL0``!L`
M``"4Q```&@```+#$```3````R\0``!$```#?Q```$0```/'$```<`````\4`
M`"H````@Q0``-P```$O%```<````@\4``!````"@Q0``(0```+'%```%````
MT\4```H```#9Q0``$P```.3%```+````^,4``!(````$Q@``"@```!?&```/
M````(L8```T````RQ@``$0```$#&```3````4L8```P```!FQ@``!@```'/&
M```,````>L8```8```"'Q@``%P```([&```0````IL8``!$```"WQ@``"```
M`,G&```%````TL8```P```#8Q@``$````.7&```%````]L8```T```#\Q@``
M!@````K'```'````$<<```T````9QP``!P```"?'```+````+\<```<````[
MQP``!P```$/'```)````2\<```D```!5QP``"@```%_'```9````:L<``#T`
M``"$QP``'0```,+'```,````X,<``!````#MQP``!0```/['```E````!,@`
M`!(````JR```$P```#W(```K````4<@``#L```!]R```(````+G(```(````
MVL@``#8```#CR```(0```!K)```0````/,D```@```!-R0``#````%;)```&
M````8\D```0```!JR0``#P```&_)```.````?\D```<```".R0``"@```);)
M```-````H<D``!\```"OR0``'````,_)```A````[,D``!X````.R@``&0``
M`"W*```>````1\H``!L```!FR@``(0```(+*```N````I,H``"8```#3R@``
M'````/K*```>````%\L``!P````VRP``)@```%/+```K````>LL``#,```"F
MRP``)@```-K+```K`````<P``#@````MS```'0```&;,```5````A,P``"\`
M``":S```(````,K,```2````Z\P``"D```#^S```'@```"C-```@````1\T`
M`!(```!HS0``H@```'O-```6````'LX``",````US@``*````%G.```I````
M@LX``"@```"LS@``'P```-7.```5````]<X``"`````+SP``)0```"S/```H
M````4L\``"T```![SP``,````*G/``"2````VL\``"$```!MT```%@```(_0
M```<````IM```"8```##T```*@```.K0``!!````%=$``$0```!7T0``#```
M`)S1```'````J=$```<```"QT0``!@```+G1```-````P-$``!````#.T0``
M$@```-_1```'````\M$``!,```#ZT0``$@````[2```'````(=(```0````I
MT@``$````"[2```0````/](```P```!0T@``#@```%W2```-````;-(```\`
M``!ZT@``$P```(K2```-````GM(``"@```"LT@```P```-72```-````V=(`
M``8```#GT@``$0```.[2```7`````-,``!L````8TP``#@```#33```"````
M0],``$D```!&TP``!0```)#3```0````EM,```\```"GTP``!````+?3```-
M````O-,```X```#*TP```P```-G3```.````W=,```@```#LTP``#P```/73
M```/````!=0```<````5U```#0```!W4```0````*]0```\````\U```#0``
M`$S4```9````6M0``!H```!TU```"P```(_4```&````F]0```L```"BU```
M$P```*[4```,````PM0```H```#/U```$0```-K4```9````[-0``!<````&
MU0``"P```![5```-````*M4``"(````XU0``#P```%O5```;````:]4``#0`
M``"'U0``"@```+S5```8````Q]4``!(```#@U0``&0```//5```6````#=8`
M`!`````DU@``(@```#76```-````6-8```<```!FU@``"@```&[6```4````
M>=8```L```".U@``#````)K6```B````I]8``"\```#*U@``"P```/K6```)
M````!M<``!D````0UP``"P```"K7```7````-M<``!<```!.UP``"0```&;7
M```6````<-<```\```"'UP``&0```)?7```6````L=<```X```#(UP``&```
M`-?7```(````\-<```T```#YUP``)@````?8```H````+M@``$,```!7V```
M"````)O8```2````I-@``!\```"WV```"````-?8```+````X-@``"\```#L
MV```#@```!S9```%````*]D```8````QV0``10```#C9```#````?MD```<`
M``""V0``!````(K9```)````C]D```H```"9V0``"@```*39```)````K]D`
M``\```"YV0``$````,G9```7````VMD``!H```#RV0``$0````W:```9````
M']H``!<````YV@``"0```%':```%````6]H```L```!AV@``"@```&W:```"
M````>-H```4```![V@``#0```(':```;````C]H``!<```"KV@``%````,/:
M```)````V-H```H```#BV@``#@```.W:```-````_-H``!(````*VP``.```
M`!W;```@````5ML```@```!WVP``#@```(#;``![````C]L``!@````+W```
M&````"3<```1````/=P```<```!/W```!0```%?<```8````7=P``!X```!V
MW```&P```)7<```9````L=P``!L```#+W```&0```.?<```3`````=T```<`
M```5W0``"````!W=```&````)MT```8````MW0``$````#3=```/````1=T`
M`!````!5W0``#P```&;=```+````=MT```\```""W0``#````)+=```/````
MG]T```<```"OW0``!@```+?=```.````OMT```P```#-W0``*````-K=```/
M`````]X```@````3W@``!@```!S>```,````(]X```@````PW@``$P```#G>
M```*````3=X``!X```!8W@``(0```'?>```@````F=X``!D```"ZW@``%P``
M`-3>```E````[-X``!<````2WP``%@```"K?```$````0=\``!L```!&WP``
M#0```&+?```,````<-\```,```!]WP``!0```('?```(````A]\```H```"0
MWP``#````)O?```+````J-\``!````"TWP``#````,7?```.````TM\```L`
M``#AWP``!````.W?```$````\M\``!,```#WWP``%`````O@```,````(.``
M``D````MX```#@```#?@```+````1N```!L```!2X```!P```&[@```'````
M=N````H```!^X```#0```(G@```)````E^````0```"AX```!0```*;@```#
M````K.```!@```"PX```"@```,G@```$````U.```"8```#9X```#@````#A
M``!\````#^$``!4```",X0``!0```*+A```'````J.$```P```"PX0``"```
M`+WA```*````QN$```8```#1X0``"````-CA```"````X>$```8```#DX0``
M!@```.OA```4````\N$```T````'X@``$````!7B```;````)N(```0```!"
MX@``"0```$?B```0````4>(```D```!BX@``"0```&SB```%````=N(``!H`
M``!\X@``"````)?B```&````H.(```\```"GX@``&0```+?B```.````T>(`
M``<```#@X@``!P```.CB```%````\.(```D```#VX@``"@````#C```.````
M"^,```(````:XP``!@```!WC```+````).,```T````PXP``"0```#[C```&
M````2.,``!(```!/XP``"0```&+C```'````;.,``!0```!TXP``'0```(GC
M``!"````I^,``"4```#JXP``)0```!#D```&````-N0```H````]Y```!```
M`$CD```)````3>0```@```!7Y```$0```&#D```)````<N0```8```!\Y```
M#0```(/D```&````D>0```0```"8Y```.0```)WD```]````U^0``#H````5
MY0``'@```%#E```%````;^4```X```!UY0``!````(3E```&````B>4```<`
M``"0Y0``(0```)CE```-````NN4``!4```#(Y0``!@```-[E```$````Y>4`
M`!$```#JY0``!@```/SE```*`````^8``"(````.Y@``!````#'F```%````
M-N8``!T````\Y@``!````%KF```,````7^8```X```!LY@``"@```'OF```(
M````AN8```D```"/Y@``!0```)GF```Z````G^8``#````#:Y@``-0````OG
M```I````0><``$<```!KYP``.````+/G```I````[.<``#\````6Z```+@``
M`%;H```M````A>@``!\```"SZ```#P```-/H```2````X^@```L```#VZ```
M)@````+I```I````*>D``"0```!3Z0``)@```'CI```(````G^D```H```"H
MZ0``"0```+/I```'````O>D``"````#%Z0``(````.;I```F````!^H```H`
M```NZ@``&0```#GJ```I````4^H``!8```!]Z@``$@```)3J```'````I^H`
M``H```"OZ@``#````+KJ```/````Q^H``!````#7Z@``0````.CJ``!P````
M*>L``&8```":ZP``#@````'L```)````$.P```H````:[```$@```"7L```3
M````..P```P```!,[```!@```%GL```5````8.P```\```!V[```$P```(;L
M```2````FNP``!````"M[```$0```+[L```<````T.P``",```#M[```:@``
M`!'M```/````?.T```4```",[0``$````)+M```)````H^T```0```"M[0``
M"P```++M```@````ONT``!0```#?[0``#````/3M```,`````>X```\````.
M[@``%0```![N```I````-.X``"H```!>[@``)@```(GN```G````L.X``"D`
M``#8[@``*@````+O```9````+>\``$(```!'[P``$0```(KO```2````G.\`
M`!,```"O[P``%````,/O```/````V.\``!8```#H[P``%P```/_O```0````
M%_```!$````H\```-````#KP```3````;_```!(```"#\```-0```);P```4
M````S/````<```#A\```#````.GP```@````]O```!`````7\0``%````"CQ
M```1````/?$``!<```!/\0``'````&?Q```3````A/$``!0```"8\0``&@``
M`*WQ```1````R/$``!H```#:\0``'@```/7Q```:````%/(``!,````O\@``
M%0```$/R```1````6?(``!<```!K\@``%````(/R```7````F/(``!4```"P
M\@``"0```,;R```0````T/(``!D```#A\@``!````/OR```'`````/,```L`
M```(\P``$0```!3S```&````)O,```8````M\P``!@```#3S```%````._,`
M``<```!!\P``!P```$GS```%````4?,``!8```!7\P``!@```&[S```&````
M=?,```0```!\\P``!````('S```'````AO,```X```".\P``#````)WS```,
M````JO,```T```"W\P``"@```,7S```.````T/,```4```#?\P``*````.7S
M```.````#O0```P````=]```#P```"KT```*````.O0```@```!%]```"0``
M`$[T```K````6/0```0```"$]```"````(GT```F````DO0``!(```"Y]```
M#P```,ST```&````W/0```H```#C]```!P```.[T```(````]O0``"````#_
M]```"0```"#U```-````*O4``!0````X]0``#````$WU```-````6O4```X`
M``!H]0``%@```'?U```1````CO4```8```"@]0```P```*?U```&````J_4`
M`!D```"R]0``!P```,SU```$````U/4```L```#9]0``"P```.7U```'````
M\?4```4```#Y]0``!P```/_U```6````!_8```T````>]@``#0```"SV```*
M````.O8``!````!%]@``#P```%;V```1````9O8``!<```!X]@``"@```)#V
M```1````F_8```@```"M]@``!````+;V```/````N_8``#H```#+]@``!0``
M``;W```,````#/<``!X````9]P``#@```#CW```0````1_<```L```!8]P``
M#````&3W```)````<?<```<```![]P``"@```(/W```)````CO<```X```"8
M]P``$````*?W```;````N/<``!@```#4]P``&@```.WW```*````"/@```D`
M```3^```"@```!WX```,````*/@```\````U^```"````$7X```&````3O@`
M`!P```!5^```!P```'+X```%````>O@```L```"`^```1P```(SX```-````
MU/@```D```#B^```!````.SX```#````\?@``!,```#U^```$P````GY```3
M````'?D```H````Q^0```@```#SY```$````/_D``"4```!$^0```P```&KY
M```%````;OD``"H```!T^0``"@```)_Y```%````JOD```0```"P^0``"@``
M`+7Y```-````P/D```8```#.^0``"````-7Y```(````WOD```0```#G^0``
M!0```.SY``!H````\OD```D```!;^@``#````&7Z```0````<OH```4```"#
M^@``!@```(GZ```;````D/H``"\```"L^@``$````-SZ```*````[?H```\`
M``#X^@``"@````C[```)````$_L``!,````=^P``&P```#'[```8````3?L`
M`!<```!F^P``%P```'[[```?````EOL```X```"V^P```P```,7[```'````
MR?L```@```#1^P``!P```-K[```)````XOL```H```#L^P``"P```/?[```'
M`````_P``%$````+_```$````%W\```,````;OP```T```![_```&@```(G\
M``!*````I/P``!D```#O_```!@````G]```:````$/T``"4````K_0``!@``
M`%']```&````6/T``!\```!?_0``!@```'_]```)````AOT``!@```"0_0``
M%P```*G]```H````P?T```8```#J_0``#0```/']```B````__T``%<````B
M_@``$P```'K^```C````COX``!,```"R_@```@```,;^```+````R?X```@`
M``#5_@``#0```-[^```*````[/X```P```#W_@``!P````3_```4````#/\`
M``8````A_P``"````"C_```.````,?\```<```!`_P``"@```$C_```+````
M4_\``#(```!?_P``!P```)+_```,````FO\```T```"G_P``%P```+7_```,
M````S?\```D```#:_P``"0```.3_```*````[O\```<```#Y_P``"0````$`
M`0`'````"P`!``H````3``$`&P```!X``0`/````.@`!`!(```!*``$`"@``
M`%T``0`6````:``!``@```!_``$`"0```(@``0`0````D@`!``<```"C``$`
M$@```*L``0`$````O@`!``<```##``$`!0```,L``0`%````T0`!``L```#7
M``$`%````.,``0`1````^``!`!H````*`0$`%@```"4!`0`4````/`$!`!<`
M``!1`0$`&````&D!`0`<````@@$!`!D```"?`0$`!P```+D!`0`%````P0$!
M``T```#'`0$`#````-4!`0`(````X@$!``@```#K`0$`%P```/0!`0`+````
M#`(!``P````8`@$`'P```"4"`0`:````10(!`!,```!@`@$`!````'0"`0`*
M````>0(!``0```"$`@$`#0```(D"`0`,````EP(!``4```"D`@$`"0```*H"
M`0`%````M`(!``<```"Z`@$`!0```,("`0`$````R`(!``(```#-`@$`.```
M`-`"`0`L````"0,!`!(````V`P$`*0```$D#`0`R````<P,!``H```"F`P$`
M+````+$#`0`N````W@,!`#,````-!`$`,P```$$$`0`X````=00!``\```"N
M!`$`&````+X$`0`0````UP0!`!P```#H!`$`#P````4%`0`3````%04!`!4`
M```I!0$`%````#\%`0`2````5`4!`"0```!G!0$`"````(P%`0`D````E04!
M`!,```"Z!0$`%````,X%`0`5````XP4!`"T```#Y!0$`+0```"<&`0`Q````
M508!`"X```"'!@$`+P```+8&`0`L````Y@8!`&(````3!P$`$P```'8'`0`-
M````B@<!``@```"8!P$`%P```*$'`0`(````N0<!``P```#"!P$`*P```,\'
M`0`A````^P<!`!H````="`$`"0```#@(`0!%````0@@!`$$```"("`$`!0``
M`,H(`0`$````T`@!`!,```#5"`$`%````.D(`0`.````_@@!`!,````-"0$`
M&````"$)`0`&````.@D!``D```!!"0$`"@```$L)`0`/````5@D!`!````!F
M"0$`!P```'<)`0`.````?PD!``T```"."0$`#````)P)`0`*````J0D!``D`
M``"T"0$`"@```+X)`0`/````R0D!``@```#9"0$`#P```.()`0`(````\@D!
M`!H```#["0$`!0```!8*`0`-````'`H!`!L````J"@$`"````$8*`0`&````
M3PH!`!0```!6"@$`$0```&L*`0`.````?0H!`#@```","@$``@```,4*`0`&
M````R`H!``X```#/"@$`!0```-X*`0`'````Y`H!``X```#L"@$`!@```/L*
M`0`H`````@L!``P````K"P$`'````#@+`0`$````50L!`"D```!:"P$`%P``
M`(0+`0`?````G`L!`%P```"\"P$`%````!D,`0`^````+@P!`!\```!M#`$`
M$````(T,`0`'````G@P!``X```"F#`$`#````+4,`0`,````P@P!`!,```#/
M#`$`"@```.,,`0`=````[@P!`!D````,#0$`!0```"8-`0`1````+`T!`!$`
M```^#0$`)````%`-`0`2````=0T!`!4```"(#0$`$@```)X-`0`.````L0T!
M`!D```#`#0$`"````-H-`0`)````XPT!``T```#M#0$`!P```/L-`0`*````
M`PX!``<````.#@$`#P```!8.`0`&````)@X!``L````M#@$`&@```#D.`0`*
M````5`X!``<```!?#@$`"````&<.`0`%````<`X!`!\```!V#@$`!@```)8.
M`0`0````G0X!``@```"N#@$`#0```+<.`0`(````Q0X!`!X```#.#@$`$@``
M`.T.`0`L``````\!`!H````M#P$`"0```$@/`0`*````4@\!`!4```!=#P$`
M!0```',/`0`4````>0\!``0```".#P$`$````),/`0`&````I`\!``<```"K
M#P$`'@```+,/`0`H````T@\!``H```#[#P$`'`````80`0`1````(Q`!``L`
M```U$`$`&@```$$0`0`4````7!`!``0```!Q$`$`!````'80`0`+````>Q`!
M``4```"'$`$`!@```(T0`0`(````E!`!``8```"=$`$`"@```*00`0`;````
MKQ`!`#0```#+$`$`-``````1`0`@````-1$!`"D```!6$0$`(````(`1`0!!
M````H1$!`!H```#C$0$`*````/X1`0`I````)Q(!`%````!1$@$`(@```*(2
M`0`&````Q1(!``@```#,$@$`!0```-42`0`(````VQ(!`!D```#D$@$`&0``
M`/X2`0`J````&!,!`",```!#$P$`&0```&<3`0`N````@1,!`#0```"P$P$`
M"````.43`0`7````[A,!``H````&%`$`!P```!$4`0`A````&10!`!`````[
M%`$`#@```$P4`0`+````6Q0!``<```!G%`$`$P```&\4`0`(````@Q0!``L`
M``",%`$`"@```)@4`0`4````HQ0!``\```"X%`$`,@```,@4`0`+````^Q0!
M``X````'%0$`!0```!85`0`%````'!4!``4````B%0$`%P```"@5`0`/````
M0!4!``0```!0%0$`"@```%45`0`)````8!4!``L```!J%0$`#0```'85`0`,
M````A!4!``X```"1%0$`!0```*`5`0`$````IA4!``T```"K%0$`,@```+D5
M`0`8````[!4!`$4````%%@$`%P```$L6`0`'````8Q8!`!X```!K%@$`#```
M`(H6`0`4````EQ8!``4```"L%@$`%````+(6`0`&````QQ8!``<```#.%@$`
M#@```-86`0`J````Y18!``8````0%P$`#````!<7`0`/````)!<!``T````T
M%P$`$0```$(7`0`+````5!<!`#8```!@%P$`"@```)<7`0`B````HA<!``L`
M``#%%P$`#P```-$7`0`R````X1<!`"4````4&`$`,````#H8`0`Q````:Q@!
M`"T```"=&`$`#@```,L8`0`%````VA@!``X```#@&`$`$P```.\8`0`2````
M`QD!``<````6&0$`$0```!X9`0`3````,!D!``<```!$&0$`%````$P9`0`8
M````81D!``<```!Z&0$`!0```((9`0`,````B!D!``P```"5&0$`$@```*(9
M`0`$````M1D!``<```"Z&0$`"@```,(9`0`+````S1D!``P```#9&0$`#@``
M`.89`0`.````]1D!``4````$&@$`!0````H:`0`N````$!H!`"8````_&@$`
M(P```&8:`0`#````BAH!`!(```".&@$`!@```*$:`0`>````J!H!`!@```#'
M&@$`)0```.`:`0`-````!AL!``D````4&P$`'P```!X;`0`#````/AL!``<`
M``!"&P$`"@```$H;`0`"````51L!``P```!8&P$`%0```&4;`0`+````>QL!
M`!D```"'&P$`(````*$;`0`2````PAL!``4```#5&P$`"@```-L;`0`5````
MYAL!`!(```#\&P$`#`````\<`0`$````'!P!``D````A'`$`!P```"L<`0`,
M````,QP!`%(```!`'`$`%P```),<`0`D````JQP!`!(```#0'`$`!P```.,<
M`0`&````ZQP!``X```#R'`$`#@````$=`0`,````$!T!``P````='0$`#```
M`"H=`0`-````-QT!`!4```!%'0$`$@```%L=`0`0````;AT!``\```!_'0$`
M%````(\=`0`*````I!T!`!L```"O'0$`$````,L=`0`+````W!T!`!L```#H
M'0$`:0````0>`0`:````;AX!`!<```")'@$`&0```*$>`0`:````NQX!`"4`
M``#6'@$`)P```/P>`0`:````)!\!`!<````_'P$`&P```%<?`0`9````<Q\!
M`!\```"-'P$`%````*T?`0`3````PA\!``@```#6'P$`!P```-\?`0`(````
MYQ\!``D```#P'P$`%0```/H?`0`-````$"`!`",````>(`$`#0```$(@`0`3
M````4"`!``@```!D(`$``P```&T@`0!&````<2`!`#\```"X(`$`-P```/@@
M`0!7````,"$!``4```"((0$`'P```(XA`0`O````KB$!``H```#>(0$`"```
M`.DA`0`-````\B$!`"T`````(@$`!````"XB`0`4````,R(!`$\```!((@$`
M)0```)@B`0`2````OB(!`"````#1(@$`'````/(B`0`+````#R,!`!\````;
M(P$`'0```#LC`0`E````62,!`"````!_(P$`)````*`C`0`@````Q2,!``L`
M``#F(P$`!P```/(C`0`-````^B,!``P````()`$`%P```!4D`0`&````+20!
M`#D````T)`$`#````&XD`0`'````>R0!``D```"#)`$`$P```(TD`0`)````
MH20!``0```"K)`$`$````+`D`0`(````P20!``@```#*)`$`!````-,D`0`+
M````V"0!``P```#D)`$`$@```/$D`0`1````!"4!``P````6)0$`&@```",E
M`0`/````/B4!``<```!.)0$`#0```%8E`0`0````9"4!`!$```!U)0$`%```
M`(<E`0`.````G"4!``P```"K)0$`&P```+@E`0`L````U"4!`!,````!)@$`
M'````!4F`0`H````,B8!``8```!;)@$`!P```&(F`0`3````:B8!``4```!^
M)@$`!````(0F`0`7````B28!``H```"A)@$`#````*PF`0`)````N28!``8`
M``##)@$`"0```,HF`0`(````U"8!``D```#=)@$`"@```.<F`0`1````\B8!
M``8````$)P$`#@````LG`0`.````&B<!``T````I)P$`"P```#<G`0`=````
M0R<!``L```!A)P$``@```&TG`0`<````<"<!``<```"-)P$`!@```)4G`0!D
M````G"<!``D````!*`$`!P````LH`0`F````$R@!`#@````Z*`$`&@```',H
M`0`J````CB@!`#L```"Y*`$`&````/4H`0`H````#BD!`#0````W*0$`&0``
M`&PI`0`5````ABD!``4```"<*0$`!P```*(I`0`(````JBD!``<```"S*0$`
M!0```+LI`0`'````P2D!``X```#)*0$`"0```-@I`0`&````XBD!``@```#I
M*0$`"P```/(I`0`'````_BD!``@````&*@$`!P````\J`0`6````%RH!``D`
M```N*@$`!@```#@J`0`+````/RH!`!````!+*@$`!@```%PJ`0`<````8RH!
M`!0```"`*@$`!P```)4J`0`1````G2H!``@```"O*@$`#@```+@J`0`(````
MQRH!``4```#0*@$`$````-8J`0`)````YRH!`!````#Q*@$`!@````(K`0`9
M````"2L!``H````C*P$`'````"XK`0`'````2RL!``4```!3*P$`$````%DK
M`0`4````:BL!``L```!_*P$`#0```(LK`0`H````F2L!`!@```#"*P$`%P``
M`-LK`0`$````\RL!``D```#X*P$`"@````(L`0`'````#2P!``(````5+`$`
M#@```!@L`0`(````)RP!`",````P+`$`'P```%0L`0`X````="P!`"8```"M
M+`$`,0```-0L`0`G````!BT!`&0````N+0$`%````),M`0!5````J"T!`#@`
M``#^+0$`2@```#<N`0!;````@BX!`"@```#>+@$`.`````<O`0`H````0"\!
M`"P```!I+P$`)@```)8O`0`;````O2\!`#X```#9+P$`J0$``!@P`0`C````
MPC$!`!<```#F,0$`2````/XQ`0"%````1S(!`#````#-,@$`%0```/XR`0`H
M````%#,!`"(````],P$`(@```&`S`0`@````@S,!`"4```"D,P$`00```,HS
M`0!;````##0!`$D```!H-`$`,0```+(T`0`=````Y#0!`!@````"-0$`*P``
M`!LU`0`A````1S4!`!\```!I-0$`*P```(DU`0`F````M34!`"<```#<-0$`
M.@````0V`0`=````/S8!`!$```!=-@$`,P```&\V`0`E````HS8!`"<```#)
M-@$`(````/$V`0`?````$C<!`#`````R-P$`:0```&,W`0`Q````S3<!`$$`
M``#_-P$`,P```$$X`0`E````=3@!`#T```";.`$`90```-DX`0!-````/SD!
M`"\```"-.0$`+@```+TY`0`I````[#D!`#`````6.@$`+````$<Z`0!4````
M=#H!`%H```#).@$`*````"0[`0`F````33L!`$@```!T.P$`2@```+T[`0`K
M````"#P!`!X````T/`$`,@```%,\`0`O````ACP!`"P```"V/`$`+0```.,\
M`0!Q````$3T!`&8```"#/0$`;P```.H]`0"S````6CX!`!<````./P$`)0``
M`"8_`0`R````3#\!`"D```!_/P$`/@```*D_`0`B````Z#\!`%(````+0`$`
M(@```%Y``0`E````@4`!``L```"G0`$`L0```+-``0!%````94$!`"$```"K
M00$`,````,U!`0`E````_D$!`!P````D0@$`,0```$%"`0`'````<T(!``<`
M``![0@$`!````(-"`0`-````B$(!``L```"60@$`#@```*)"`0`+````L4(!
M``4```"]0@$`$````,-"`0`"````U$(!`%D```#70@$`!0```#%#`0`2````
M-T,!``0```!*0P$`!P```$]#`0`(````5T,!``4```!@0P$`,````&9#`0`#
M````ET,!`!````";0P$`#````*Q#`0`3````N4,!``T```#-0P$``@```-M#
M`0`'````WD,!``8```#F0P$`%````.U#`0`,`````D0!`!@````/1`$`!@``
M`"A$`0`2````+T0!``P```!"1`$``P```$]$`0`J````4T0!``0```!^1`$`
M!@```(-$`0`'````BD0!`!\```"21`$`-0```+)$`0`N````Z$0!`"\````7
M10$`%P```$=%`0`B````7T4!`"4```""10$`(````*A%`0`;````R44!`!@`
M``#E10$`)````/Y%`0`?````(T8!`!H```!#1@$`(0```%Y&`0`@````@$8!
M`!H```"A1@$`,@```+Q&`0`9````[T8!`!H````)1P$`+P```"1'`0`K````
M5$<!`!\```"`1P$`(P```*!'`0`?````Q$<!`!H```#D1P$`(0```/]'`0`E
M````(4@!`"8```!'2`$`)0```&Y(`0`D````E$@!`!@```"Y2`$`'0```-)(
M`0`D````\$@!`!@````520$`(@```"Y)`0`L````44D!`"\```!^20$`%0``
M`*Y)`0`E````Q$D!`#P```#J20$`'P```"=*`0`C````1TH!`!\```!K2@$`
M(````(M*`0`:````K$H!`!@```#'2@$`)@```.!*`0`>````!TL!`"D````F
M2P$`'@```%!+`0`Q````;TL!``D```"A2P$`#````*M+`0`,````N$L!`!<`
M``#%2P$`+P```-U+`0`D````#4P!``<````R3`$`#P```#I,`0`4````2DP!
M``X```!?3`$`#0```&Y,`0`D````?$P!``4```"A3`$`!P```*=,`0`B````
MKTP!`"4```#23`$`&@```/A,`0`=````$TT!`!H````Q30$`!P```$Q-`0#'
M````5$T!``L````<3@$`'````"A.`0`5````14X!``8```!;3@$`"0```&).
M`0`+````;$X!``T```!X3@$`%P```(9.`0`&````GDX!`#,```"E3@$`$P``
M`-E.`0`3````[4X!``<````!3P$`#P````E/`0`'````&4\!`#(````A3P$`
M!````%1/`0`A````64\!`!,```![3P$`#````(]/`0`1````G$\!`#(```"N
M3P$`%@```.%/`0`(````^$\!`!T````!4`$`"0```!]0`0`*````*5`!`!0`
M```T4`$`"@```$E0`0`=````5%`!``@```!R4`$`'P```'M0`0`(````FU`!
M`!H```"D4`$`)P```+]0`0`&````YU`!`!4```#N4`$`!P````11`0`(````
M#%$!``D````540$`/P```!]1`0`'````7U$!``\```!G40$`#@```'=1`0`0
M````AE$!``D```"740$`"0```*%1`0`(````JU$!`!,```"T40$`!P```,A1
M`0`9````T%$!``H```#J40$`%P```/51`0`4````#5(!``H````B4@$`#```
M`"U2`0`7````.E(!``0```!24@$`*@```%=2`0`,````@E(!`!$```"/4@$`
M!P```*%2`0`"````J5(!`!````"L4@$`&````+U2`0`+````UE(!``,```#B
M4@$`"````.92`0`&````[U(!``<```#V4@$`#0```/Y2`0`+````#%,!`!0`
M```84P$`%0```"U3`0`.````0U,!`"\```!24P$`(````()3`0`<````HU,!
M`!4```#`4P$`*P```-93`0`,`````E0!`#$````/5`$`!0```$%4`0`2````
M1U0!`#\```!:5`$`$@```)I4`0`*````K50!``8```"X5`$`!````+]4`0`$
M````Q%0!``H```#)5`$`$P```-14`0`%````Z%0!``8```#N5`$`!@```/54
M`0`(````_%0!``0````%50$`#`````I5`0`*````%U4!`#D````B50$`+@``
M`%Q5`0`I````BU4!``4```"U50$`&````+M5`0`9````U%4!`!\```#N50$`
M'0````Y6`0`1````+%8!``(````^5@$`!````$%6`0`*````1E8!``8```!1
M5@$`!0```%A6`0`#````7E8!``P```!B5@$`10```&]6`0`R````M58!`#$`
M``#H5@$`&@```!I7`0`T````-5<!`"@```!J5P$`4P```)-7`0`R````YU<!
M`!D````:6`$`<@```#18`0`@````IU@!`#4```#(6`$`(0```/Y8`0!%````
M(%D!`#````!F60$`*````)=9`0`H````P%D!`"D```#I60$`)@```!-:`0`E
M````.EH!`"@```!@6@$`*````(E:`0`B````LEH!`"L```#56@$`,`````%;
M`0`2````,EL!`!,```!%6P$`$````%E;`0!Y````:EL!``D```#D6P$`H0``
M`.Y;`0!S````D%P!`'P````$70$`*P```(%=`0!4````K5T!`!<````"7@$`
M)P```!I>`0`6````0EX!`!4```!97@$`#P```&]>`0`7````?UX!`!\```"7
M7@$`#@```+=>`0!`````QEX!`!\````'7P$`'````"=?`0!1````1%\!`!H`
M``"67P$`%````+%?`0`*````QE\!``4```#17P$`!@```-=?`0`(````WE\!
M``4```#G7P$`$@```.U?`0`0`````&`!`!,````18`$`'0```"5@`0`/````
M0V`!``\```!38`$`$````&-@`0`$````=&`!``D```!Y8`$`"0```(-@`0`'
M````C6`!``L```"58`$`!0```*%@`0`+````IV`!``<```"S8`$`!0```+M@
M`0`4````P6`!``X```#68`$`"P```.5@`0`'````\6`!``@```#Y8`$`#P``
M``)A`0`,````$F$!``D````?80$`"````"EA`0`,````,F$!``8````_80$`
M#P```$9A`0`'````5F$!``8```!>80$`%````&5A`0`&````>F$!``P```"!
M80$`$0```(YA`0`(````H&$!``0```"I80$`&0```*YA`0`1````R&$!``H`
M``#:80$`&````.5A`0`3````_F$!`!P````28@$`$0```"]B`0`$````06(!
M``\```!&8@$`!P```%9B`0`$````7F(!`!D```!C8@$`!P```'UB`0`"````
MA6(!``(```"(8@$`$0```(MB`0`)````G6(!``8```"G8@$`$@```*YB`0`7
M````P6(!``8```#98@$`)P```.!B`0`"````"&,!``0````+8P$`#P```!!C
M`0`3````(&,!``<````T8P$`"0```#QC`0`'````1F,!`!$```!.8P$`!@``
M`&!C`0`8````9V,!``8```"`8P$`$P```(=C`0`0````FV,!`!(```"L8P$`
M`@```+]C`0`&````PF,!``P```#)8P$`"0```-9C`0`1````X&,!`"(```#R
M8P$`!P```!5D`0`'````'60!``L````E9`$`!0```#%D`0`%````-V0!``(`
M```]9`$`"P```$!D`0!7`0``3&0!`!,```"D90$`$0```+AE`0`.````RF4!
M``D```#990$`"P```.-E`0`(````[V4!``$```#X90$`%0```/IE`0`:````
M$&8!`"H````K9@$`(0```%9F`0`B````>&8!`!H```";9@$`$@```+9F`0`J
M````R68!``L```#T9@$`)@````!G`0`0````)V<!`!(````X9P$`#0```$MG
M`0`.````66<!``4```!H9P$`(P```&YG`0`*````DF<!`!````"=9P$`#@``
M`*YG`0`2````O6<!``\```#09P$`"@```.!G`0`<````ZV<!`&4````(:`$`
M$````&YH`0`,````?V@!``\```",:`$`#````)QH`0`0````J6@!``X```"Z
M:`$`$````,EH`0`1````VF@!``8```#L:`$`P@```/-H`0`/````MFD!`!4`
M``#&:0$`%0```-QI`0`-````\FD!``X`````:@$`%0````]J`0`5````)6H!
M``D````[:@$`"@```$5J`0`\````4&H!`!4```"-:@$`,````*-J`0!#````
MU&H!`%X````8:P$`8````'=K`0!<````V&L!`&8````U;`$`,@```)QL`0`)
M````SVP!`!(```#9;`$`!P```.QL`0`*````]&P!``X```#_;`$`!0````YM
M`0`&````%&T!`!(````;;0$`"@```"YM`0`)````.6T!``T```!#;0$`+@``
M`%%M`0`M````@&T!`"\```"N;0$`+P```-YM`0`T````#FX!`#0```!#;@$`
M&````'AN`0`:````D6X!`!8```"L;@$`"@```,-N`0`%````SFX!``X```#4
M;@$`#P```.-N`0`,````\VX!`!``````;P$`$0```!%O`0`;````(V\!`!8`
M```_;P$`%````%9O`0`.````:V\!``P```!Z;P$`$P```(=O`0`*````FV\!
M`"@```"F;P$`%````,]O`0`5````Y&\!``X```#Z;P$`6P````EP`0`X````
M97`!`!P```"><`$`(0```+MP`0`&````W7`!``L```#D<`$`.0```/!P`0`(
M````*G$!``D````S<0$`"@```#UQ`0`'````2'$!``<```!0<0$`!0```%AQ
M`0`%````7G$!``<```!D<0$`!@```&QQ`0`>````<W$!``T```"2<0$`#P``
M`*!Q`0`9````L'$!`!4```#*<0$`)P```.!Q`0`.````"'(!`"<````7<@$`
M'````#]R`0`B````7'(!`"(```!_<@$`%0```*)R`0`6````N'(!`!(```#/
M<@$`%P```.)R`0`:````^G(!``<````5<P$`!@```!US`0`(````)',!``X`
M```M<P$`!P```#QS`0`)````1',!`!(```!.<P$`!P```&%S`0`,````:7,!
M`!(```!V<P$`(0```(ES`0`'````JW,!``T```"S<P$`"````,%S`0`5````
MRG,!``P```#@<P$`#````.US`0`_````^G,!`#\````Z=`$`"0```'IT`0`'
M````A'0!`!,```",=`$`!0```*!T`0`%````IG0!``<```"L=`$`$````+1T
M`0`+````Q70!`!8```#1=`$`-P```.AT`0`0````('4!`"4````Q=0$`)P``
M`%=U`0`G````?W4!`"0```"G=0$`#P```,QU`0`&````W'4!``D```#C=0$`
M"````.UU`0`V````]G4!`#\````M=@$`-0```&UV`0!=````HW8!`#0````!
M=P$`-````#9W`0!!````:W<!`$,```"M=P$`-````/%W`0!'````)G@!`"@`
M``!N>`$`*@```)=X`0!%````PG@!`#0````(>0$`.@```#UY`0`L````>'D!
M`!D```"E>0$`'0```+]Y`0`N````W7D!`"L````,>@$`*P```#AZ`0`A````
M9'H!`!L```"&>@$`"P```*)Z`0`/````KGH!`!8```"^>@$`(````-5Z`0`&
M````]GH!``H```#]>@$`&`````A[`0`>````(7L!``8```!`>P$`!P```$=[
M`0`4````3WL!``H```!D>P$`"````&][`0`N````>'L!``H```"G>P$`#```
M`+)[`0`&````OWL!``8```#&>P$`!0```,U[`0`'````TWL!``8```#;>P$`
M#````.)[`0`H````[WL!``\````8?`$`#````"A\`0`)````-7P!``<````_
M?`$`#````$=\`0`%````5'P!``\```!:?`$`!@```&I\`0`2````<7P!``@`
M``"$?`$`"````(U\`0`$````EGP!``T```";?`$`"````*E\`0`G````LGP!
M`!````#:?`$`"````.M\`0`-````]'P!``P````"?0$`!P````]]`0`#````
M%WT!``,````;?0$`$P```!]]`0`#````,WT!`!`````W?0$`(P```$A]`0`)
M````;'T!``4```!V?0$`"0```'Q]`0`'````AGT!`$8```".?0$`(0```-5]
M`0`Z````]WT!`"8````R?@$`'````%E^`0`&````=GX!``0```!]?@$`$@``
M`()^`0`@````E7X!`"$```"V?@$`+P```-A^`0`A````"'\!`"@````J?P$`
M80```%-_`0`I````M7\!``D```#??P$`"@```.E_`0`0````]'\!`!4````%
M@`$`"0```!N``0`-````)8`!``P````S@`$`#````$"``0`,````38`!``P`
M``!:@`$`#````&>``0`,````=(`!`!0```"!@`$`"@```):``0`7````H8`!
M`!L```"Y@`$`$0```-6``0`3````YX`!`!4```#[@`$`!````!&!`0`%````
M%H$!`!$````<@0$`2P```"Z!`0`\````>H$!`%,```"W@0$`!@````N"`0`3
M````$H(!``4````F@@$`!0```"R"`0`@````,H(!`!@```!3@@$`#P```&R"
M`0`0````?((!`!8```"-@@$`'P```*2"`0`P````Q((!`$````#U@@$`(```
M`#:#`0`+````5X,!`"````!C@P$`!@```(2#`0`/````BX,!`!4```";@P$`
M#0```+&#`0`3````OX,!``\```#3@P$`%P```..#`0`2````^X,!`!0````.
MA`$`%P```".$`0`,````.X0!``8```!(A`$`$0```$^$`0`(````880!`!<`
M``!JA`$`%````(*$`0`2````EX0!``@```"JA`$`!````+.$`0`,````N(0!
M``L```#%A`$`!@```-&$`0`3````V(0!``H```#LA`$`!P```/>$`0`-````
M_X0!``D````-A0$`#````!>%`0`'````)(4!``8````LA0$`"P```#.%`0`(
M````/X4!``H```!(A0$`#P```%.%`0!#````8X4!`!H```"GA0$`$@```,*%
M`0`J````U84!``4`````A@$`'P````:&`0`3````)H8!`!0````ZA@$`,P``
M`$^&`0!"````@X8!`"0```#&A@$`#````.N&`0`F````^(8!`!T````?AP$`
M#@```#V'`0`%````3(<!``L```!2AP$`!@```%Z'`0`&````98<!`!D```!L
MAP$`#@```(:'`0`'````E8<!``H```"=AP$`$0```*B'`0`E````NH<!`#$`
M``#@AP$`)P```!*(`0`S````.H@!`!L```!NB`$`,````(J(`0`=````NX@!
M`",```#9B`$`.0```/V(`0`?````-XD!`"<```!7B0$`*0```'^)`0`A````
MJ8D!`"$```#+B0$`)P```.V)`0!"````%8H!`"$```!8B@$`(0```'J*`0`K
M````G(H!`!\```#(B@$`'P```.B*`0`Z````"(L!`"(```!#BP$`%0```&:+
M`0`G````?(L!`"````"DBP$`*P```,6+`0`5````\8L!`)(````'C`$`&@``
M`)J,`0`?````M8P!`!\```#5C`$`(````/6,`0`N````%HT!`!T```!%C0$`
M'P```&.-`0`@````@XT!`"P```"DC0$`+@```-&-`0`P`````(X!`"\````Q
MC@$`H0```&&.`0`K`````X\!`"`````OCP$`)````%"/`0`C````=8\!`"P`
M``"9CP$`0````,:/`0!$````!Y`!``\```!,D`$``P```%R0`0`'````8)`!
M``,```!HD`$`#P```&R0`0`(````?)`!`!D```"%D`$`!0```)^0`0`2````
MI9`!`!(```"XD`$`!P```,N0`0`%````TY`!`!@```#9D`$`%@```/*0`0`9
M````"9$!`!0````CD0$`%P```#B1`0`1````4)$!`!0```!BD0$`$P```'>1
M`0!.````BY$!``<```#:D0$`#P```.*1`0`&````\I$!`!,```#YD0$`&0``
M``V2`0`;````)Y(!`!````!#D@$``@```%22`0!0````5Y(!``H```"HD@$`
M#P```+.2`0`.````PY(!``<```#2D@$`&````-J2`0`3````\Y(!``4````'
MDP$`#@````V3`0`(````'),!`!`````EDP$`$P```#:3`0`&````2I,!``H`
M``!1DP$`#@```%R3`0`1````:Y,!`!0```!]DP$`$````)*3`0`:````HY,!
M``L```"^DP$`!@```,J3`0`+````T9,!`!$```#=DP$`#````.^3`0`+````
M_),!``T````(E`$`*@```!:4`0`H````090!``L```!JE`$`#0```':4`0`K
M````A)0!`!0```"PE`$`%P```,64`0!!````W90!``L````?E0$`%P```"N5
M`0`9````0Y4!`!4```!=E0$`$P```'.5`0`8````AY4!`!\```"@E0$`#```
M`,"5`0`&````S94!``<```#4E0$`#P```-R5`0`&````[)4!``<```#SE0$`
M.0```/N5`0`X````-98!``<```!NE@$`#````':6`0`?````@Y8!``X```"C
ME@$`&@```+*6`0`:````S98!``D```#HE@$`'0```/*6`0`1````$)<!`"0`
M```BEP$`'````$>7`0`*````9)<!`!,```!OEP$`"````(.7`0`.````C)<!
M`"0```";EP$`,@```,"7`0!`````\Y<!``X````TF`$`&````$.8`0`P````
M7)@!``@```"-F`$`"P```):8`0`D````HI@!``\```#'F`$`!P```->8`0`0
M````WY@!`%8```#PF`$`!0```$>9`0`'````39D!``<```!5F0$`#````%V9
M`0`.````:ID!``X```!YF0$`%0```(B9`0`0````GID!`!$```"OF0$`&```
M`,&9`0`>````VID!`!(```#YF0$`&`````R:`0`6````)9H!``@````\F@$`
M!@```$6:`0`+````3)H!``P```!8F@$``@```&6:`0`*````:)H!`!````!S
MF@$`)P```(2:`0`9````K)H!`!0```#&F@$`!@```-N:`0`2````XIH!``T`
M``#UF@$`#@````.;`0`/````$IL!`#H````BFP$`+0```%V;`0`.````BYL!
M`!$```":FP$`9P```*R;`0`4````%)P!`!0````IG`$`%@```#Z<`0`'````
M59P!``4```!=G`$`'P```&.<`0`L````@YP!`"(```"PG`$`'@```-.<`0`B
M````\IP!`!H````5G0$`&P```#"=`0`%````3)T!``<```!2G0$`!P```%J=
M`0`(````8IT!`!(```!KG0$`$0```'Z=`0`2````D)T!`!$```"CG0$`(```
M`+6=`0`4````UIT!``\```#KG0$`#P```/N=`0`'````"YX!``@````3G@$`
M%````!R>`0`6````,9X!`#````!(G@$`#P```'F>`0`+````B9X!``,```"5
MG@$`$0```)F>`0`'````JYX!`"````"SG@$`&0```-2>`0`;````[IX!`"0`
M```*GP$`(P```"^?`0`?````4Y\!`!\```!SGP$`*0```).?`0`<````O9\!
M`!8```#:GP$`!@```/&?`0`<````^)\!``H````5H`$`#0```""@`0`%````
M+J`!``8````TH`$`"````#N@`0`+````1*`!``T```!0H`$`$````%Z@`0`4
M````;Z`!``X```"$H`$`#@```).@`0`/````HJ`!``4```"RH`$`"````+B@
M`0`B````P:`!`",```#DH`$`%0````BA`0`.````'J$!`!$````MH0$`$```
M`#^A`0`H````4*$!``L```!YH0$`!0```(6A`0`4````BZ$!`!4```"@H0$`
M#````+:A`0`-````PZ$!``<```#1H0$`!````-FA`0`<````WJ$!``\```#[
MH0$`!0````NB`0`A````$:(!``T````SH@$`DP```$&B`0`5````U:(!``D`
M``#KH@$`"@```/6B`0`3`````*,!``P````4HP$`#@```"&C`0`(````,*,!
M`!(````YHP$``@```$RC`0`(````3Z,!``8```!8HP$`$0```%^C`0`.````
M<:,!`!$```"`HP$`'0```)*C`0`)````L*,!``H```"ZHP$`#P```,6C`0`(
M````U:,!``D```#>HP$`!0```.BC`0`<````[J,!``D````+I`$`!@```!6D
M`0`1````'*0!`!`````NI`$`#P```#^D`0`'````3Z0!``4```!7I`$`!0``
M`%VD`0`)````8Z0!``<```!MI`$`$0```'6D`0`$````AZ0!``4```",I`$`
M#0```)*D`0`+````H*0!``H```"LI`$`!P```+>D`0`4````OZ0!``D```#4
MI`$`!P```-ZD`0`/````YJ0!`",```#VI`$`2````!JE`0`K````8Z4!`"L`
M``"/I0$`!@```+NE`0`*````PJ4!``0```#-I0$`"0```-*E`0`(````W*4!
M`!0```#EI0$`"P```/JE`0`&````!J8!``T````-I@$`!@```!NF`0`$````
M(J8!`$8````GI@$`3P```&ZF`0!+````OJ8!`"`````*IP$`!0```"NG`0`.
M````,:<!``0```!`IP$`!@```$6G`0`&````3*<!`!@```!3IP$`%````&RG
M`0`5````@:<!``<```"7IP$`!````)^G`0`6````I*<!``0```"[IP$`#P``
M`,"G`0`;````T*<!``8```#LIP$`!0```/.G`0`G````^:<!``0````AJ`$`
M"@```":H`0`-````,:@!``X````_J`$`"````$ZH`0`)````5Z@!``4```!A
MJ`$`,````&>H`0`R````F*@!`#H```#+J`$`(`````:I`0!)````)ZD!`#D`
M``!QJ0$`*0```*NI`0`X````U:D!`"H````.J@$`+````#FJ`0`A````9JH!
M`!$```"(J@$`$````)JJ`0`+````JZH!`"4```"WJ@$`)P```-VJ`0`A````
M!:L!`",````GJP$`!P```$NK`0`)````4ZL!``H```!=JP$`!@```&BK`0`I
M````;ZL!`"D```"9JP$`,@```,.K`0`)````]JL!`!\`````K`$`+0```""L
M`0`6````3JP!`!$```!EK`$`!P```'>L`0`+````?ZP!``T```"+K`$`$```
M`)FL`0`/````JJP!`$````"ZK`$`C0```/NL`0!D````B:T!`!$```#NK0$`
M"`````"N`0`)````":X!`!`````3K@$`$0```"2N`0`,````-JX!``4```!#
MK@$`&0```$FN`0`0````8ZX!`!4```!TK@$`$````(JN`0`.````FZX!`!,`
M``"JK@$`'````+ZN`0`F````VZX!`'0````"KP$`$````'>O`0`%````B*\!
M`!4```".KP$`"0```*2O`0`$````KJ\!``L```"SKP$`'@```+^O`0`5````
MWJ\!``H```#TKP$`#@```/^O`0`0````#K`!`!,````?L`$`(@```#.P`0`@
M````5K`!`"````!WL`$`'@```)BP`0`D````M[`!`"(```#<L`$`&@```/^P
M`0`U````&K$!`!(```!0L0$`$````&.Q`0`2````=+$!`!(```"'L0$`%```
M`)JQ`0`5````K[$!`!,```#%L0$`$````-FQ`0`2````ZK$!`"D```#]L0$`
M$P```">R`0`5````.[(!`$H```!1L@$`'````)RR`0`,````N;(!`!$```#&
ML@$`(0```-BR`0`5````^K(!`!$````0LP$`$@```"*S`0`=````-;,!`!\`
M``!3LP$`%@```'.S`0`7````BK,!`!4```"BLP$`$P```+BS`0`=````S+,!
M`"````#JLP$`)0````NT`0`3````,;0!`!0```!%M`$`%````%JT`0`<````
M;[0!`!4```",M`$`%0```**T`0`9````N+0!``L```#2M`$`&P```-ZT`0`<
M````^K0!``0````7M0$`!P```!RU`0`)````)+4!`!<````NM0$`!@```$:U
M`0`1````3;4!``H```!?M0$`!@```&JU`0`'````<;4!``@```!YM0$`!@``
M`(*U`0`4````B;4!``8```">M0$`"````*6U`0`(````KK4!``<```"WM0$`
M!P```+^U`0`0````Q[4!``X```#8M0$`$@```.>U`0`0````^K4!``D````+
MM@$`%0```!6V`0`%````*[8!`#`````QM@$`$P```&*V`0`.````=K8!`!``
M``"%M@$`#@```):V`0`.````I;8!``X```"TM@$`*P```,.V`0`&````[[8!
M``@```#VM@$`-0```/^V`0`>````-;<!``X```!4MP$`!@```&.W`0`)````
M:K<!``D```!TMP$`!0```'ZW`0`D````A+<!`!4```"IMP$`$0```+^W`0`9
M````T;<!`!8```#KMP$`%`````*X`0`A````%[@!`"4````YN`$`+0```%^X
M`0`&````C;@!``0```"4N`$`"````)FX`0`<````HK@!``<```"_N`$`!0``
M`,>X`0`,````S;@!``L```#:N`$`!@```.:X`0`$````[;@!``<```#RN`$`
M%0```/JX`0`,````$+D!``X````=N0$`#P```"RY`0`8````/+D!`!D```!5
MN0$`$P```&^Y`0`=````@[D!`!,```"AN0$`$P```+6Y`0`)````R;D!``8`
M``#3N0$`$````-JY`0`_````Z[D!``8````KN@$`#P```#*Z`0`>````0KH!
M`!$```!AN@$`%0```'.Z`0`,````B;H!``X```"6N@$`"P```*6Z`0`)````
ML;H!``\```"[N@$`#````,NZ`0`-````V+H!`!T```#FN@$`(@````2[`0`B
M````)[L!`"@```!*NP$`#````'.[`0`'````@+L!``L```"(NP$`$P```)2[
M`0`4````J+L!``8```"]NP$`#P```,2[`0`B````U+L!``T```#WNP$`#P``
M``6\`0`>````%;P!`&4````TO`$`(````)J\`0`,````N[P!``<```#(O`$`
M!@```-"\`0`>````U[P!`!T```#VO`$`&@```!2]`0`)````+[T!``(````Y
MO0$`!````#R]`0`@````0;T!``8```!BO0$`!0```&F]`0`J````;[T!``H`
M``":O0$`!P```*6]`0`*````K;T!``\```"XO0$`#@```,B]`0`&````U[T!
M``<```#>O0$`"@```.:]`0`%````\;T!``4```#WO0$`@P```/V]`0`,````
M@;X!``\```".O@$`&````)Z^`0`)````M[X!``H```#!O@$`'@```,R^`0`L
M````Z[X!``\````8OP$`"@```"B_`0`0````,[\!``H```!$OP$`"0```$^_
M`0`:````6;\!`"D```!TOP$`)P```)Z_`0`F````QK\!`!T```#MOP$`'@``
M``O``0`6````*L`!``@```!!P`$`"0```$K``0`*````5,`!``<```!?P`$`
M%````&?``0`,````?,`!``T```")P`$`!@```)?``0!2````GL`!``\```#Q
MP`$`#@````'!`0`)````$,$!`"`````:P0$`60```#O!`0`:````E<$!``8`
M``"PP0$`'@```+?!`0`M````UL$!``@````$P@$`!P````W"`0`?````%<(!
M``@````UP@$`"P```#["`0`G````2L(!`"8```!RP@$`)0```)G"`0`)````
MO\(!``H```#)P@$`(@```-3"`0!<````]\(!`!0```!4PP$`)@```&G#`0`4
M````D,,!``(```"EPP$`$0```*C#`0`+````NL,!`!8```#&PP$`#@```-W#
M`0`,````[,,!``<```#YPP$`$@````'$`0`&````%,0!``@````;Q`$`$0``
M`"3$`0`-````-L0!``H```!$Q`$`#````$_$`0`S````7,0!``<```"0Q`$`
M$0```)C$`0`2````JL0!`"````"]Q`$`%P```-[$`0`/````]L0!`!$````&
MQ0$`#P```!C%`0`/````*,4!``\````XQ0$`#P```$C%`0`(````6,4!`!P`
M``!AQ0$`'@```'[%`0`+````G<4!`!(```"IQ0$`'0```+S%`0`2````VL4!
M``P```#MQ0$`%P```/K%`0`/````$L8!``T````BQ@$`!````##&`0`'````
M-<8!``4````]Q@$`!0```$/&`0`*````2<8!`!4```!4Q@$`$0```&K&`0`:
M````?,8!`!8```"7Q@$`%````*[&`0`7````P\8!`!X```#;Q@$`'0```/K&
M`0`:````&,<!``8````SQP$`"@```#K'`0`.````1<<!``T```!4QP$`!P``
M`&+'`0`1````:L<!`",```!\QP$`#0```*#'`0`-````KL<!`!H```"\QP$`
M)@```-?'`0`4````_L<!``<````3R`$`$````!O(`0`(````+,@!`!0````U
MR`$`$P```$K(`0`)````7L@!``D```!HR`$`!0```'+(`0`'````>,@!``(`
M``"`R`$`!````(/(`0`"````B,@!`$0```"+R`$`0P```-#(`0`-````%,D!
M`"(````BR0$`-@```$7)`0`,````?,D!`"D```")R0$`'0```+/)`0`B````
MT<D!`"(```#TR0$`)P```!?*`0`0````/\H!`!0```!0R@$`'@```&7*`0`>
M````A,H!`!4```"CR@$`&````+G*`0`7````TLH!`!,```#JR@$`%P```/[*
M`0`X````%LL!`!$```!/RP$`+P```&'+`0`?````D<L!`!P```"QRP$`&@``
M`,[+`0`O````Z<L!`"\````9S`$`,P```$G,`0`P````?<P!`#$```"NS`$`
M+@```.#,`0!K````#\T!`"4```![S0$`&0```*'-`0`+````N\T!`!L```#'
MS0$`"@```./-`0`5````[LT!`"H````$S@$`+````"_.`0`H````7,X!``D`
M``"%S@$`6P```(_.`0!-````Z\X!``T````YSP$`"0```$?/`0`@````4<\!
M`"8```!RSP$`#@```)G/`0`8````J,\!`!L```#!SP$`!0```-W/`0`*````
MX\\!``@```#NSP$`$````/?/`0`2````"-`!``L````;T`$`"@```"?0`0`6
M````,M`!`!P```!)T`$`$@```&;0`0`4````>=`!`!4```".T`$`&@```*30
M`0`,````O]`!`!(```#,T`$`#````-_0`0`?````[-`!``T````,T0$`&@``
M`!K1`0`E````-=$!``D```!;T0$`"0```&71`0`2````;]$!`!4```""T0$`
M$````)C1`0`Y````J=$!``(```#CT0$`!P```.;1`0`.````[M$!``<```#]
MT0$`!P````72`0`3````#=(!``@````AT@$`.````"K2`0`.````8](!`!D`
M``!RT@$`!````(S2`0`P````D=(!`!P```#"T@$`+````-_2`0!5````#-,!
M`!8```!BTP$`1P```'G3`0`C````P=,!`!$```#ETP$`"0```/?3`0`0````
M`=0!`!$````2U`$`#````"34`0`3````,=0!``P```!%U`$`&P```%+4`0`;
M````;M0!``,```"*U`$`"P```([4`0`2````FM0!`"@```"MU`$`'````-;4
M`0`>````\]0!`!,````2U0$`$@```";5`0`G````.=4!``D```!AU0$`$0``
M`&O5`0`2````?=4!``<```"0U0$`"@```)C5`0`'````H]4!``X```"KU0$`
M!P```+K5`0`0````PM4!`!P```#3U0$`$@```/#5`0`%`````]8!``@````)
MU@$`!0```!+6`0`<````&-8!``8````UU@$`$0```#S6`0`(````3M8!`!$`
M``!7U@$`"````&G6`0`:````<M8!``X```"-U@$`*P```)S6`0`7````R-8!
M``D```#@U@$`"@```.K6`0`=````]=8!``4````3UP$`$P```!G7`0`%````
M+=<!`"@````SUP$`!P```%S7`0`)````9-<!`!P```!NUP$`/````(O7`0`&
M````R-<!`!L```#/UP$`$````.O7`0`(````_-<!`!,````%V`$`"P```!G8
M`0`$````)=@!``@````JV`$`"P```#/8`0`'````/]@!``D```!'V`$`"```
M`%'8`0`'````6M@!``<```!BV`$`%0```&K8`0`M````@-@!`#L```"NV`$`
M%P```.K8`0`@`````MD!`!4````CV0$`/@```#G9`0`<````>-D!`!T```"5
MV0$`)0```+/9`0!8````V=D!`"`````RV@$`!0```%/:`0`*````6=H!``<`
M``!DV@$`"0```&S:`0`2````=MH!`!4```")V@$`.````)_:`0`C````V-H!
M`!\```#\V@$`-0```!S;`0`Z````4ML!``H```"-VP$`&@```)C;`0`,````
ML]L!``H```#`VP$`(0```,O;`0`3````[=L!`!(````!W`$`#@```!3<`0`'
M````(]P!``\````KW`$`"0```#O<`0`0````1=P!``X```!6W`$`&@```&7<
M`0`7````@-P!`#````"8W`$`"P```,G<`0`?````U=P!``4```#UW`$`!@``
M`/O<`0`'`````MT!`!X````*W0$`#````"G=`0`$````-MT!`!`````[W0$`
M#P```$S=`0`)````7-T!``P```!FW0$`#@```'/=`0`6````@MT!``4```"9
MW0$`!````)_=`0`2````I-T!`#$```"WW0$`'P```.G=`0!$````"=X!`!<`
M``!.W@$`!P```&;>`0`C````;MX!``T```"2W@$`&````*#>`0`4````N=X!
M``X```#.W@$`#P```-W>`0`-````[=X!``T```#[W@$`+P````G?`0`&````
M.=\!``L```!`WP$`#P```$S?`0`-````7-\!``\```!JWP$`"P```'K?`0`\
M````AM\!``8```##WP$`'@```,K?`0`/````Z=\!`!,```#YWP$`)P````W@
M`0`?````->`!`#L```!5X`$`/````)'@`0`X````SN`!`!$````'X0$`"```
M`!GA`0`1````(N$!`!,````TX0$`&````$CA`0`(````8>$!`!````!JX0$`
M%@```'OA`0`'````DN$!`!$```":X0$`'````*SA`0`+````R>$!``4```#5
MX0$`#````-OA`0`+````Z.$!`!````#TX0$`!0````7B`0`'````"^(!``H`
M```3X@$`$P```![B`0`3````,N(!``P```!&X@$`#````%/B`0`&````8.(!
M``D```!GX@$`-@```''B`0`H````J.(!`",```#1X@$`!P```/7B`0`@````
M_>(!``8````>XP$`)````"7C`0`5````2N,!`"@```!@XP$`$0```(GC`0`1
M````F^,!`!P```"MXP$``P```,KC`0`(````SN,!`!(```#7XP$``@```.KC
M`0`,````[>,!`!0```#ZXP$`"P````_D`0`8````&^0!`!P````TY`$`&```
M`%'D`0`%````:N0!``H```!PY`$`%````'OD`0`<````D.0!``T```"MY`$`
M!P```+OD`0`,````P^0!``H```#0Y`$`$0```-OD`0!*````[>0!`!P````X
MY0$`-P```%7E`0`8````C>4!``4```"FY0$`!````*SE`0`*````L>4!``T`
M``"\Y0$`#@```,KE`0`,````V>4!`!$```#FY0$`$@```/CE`0`7````"^8!
M`!4````CY@$`$P```#GF`0`0````3>8!`!H```!>Y@$`#@```'GF`0`D````
MB.8!``\```"MY@$`$````+WF`0`A````SN8!`&L```#PY@$`(````%SG`0`>
M````?><!`",```"<YP$`*````,#G`0`=````Z><!`!P````'Z`$`(````"3H
M`0`8````1>@!`"0```!>Z`$`$@```(/H`0`9````EN@!`!0```"PZ`$`%```
M`,7H`0`*````VN@!``<```#EZ`$`"P```.WH`0`'````^>@!`!0````!Z0$`
M"P```!;I`0`Z````(ND!`!,```!=Z0$`&@```''I`0`(````C.D!``4```"5
MZ0$`2@```)OI`0!/````YND!`$T````VZ@$`9````(3J`0`'````Z>H!`"@`
M``#QZ@$`+````!KK`0`*````1^L!``@```!2ZP$`#0```%OK`0`R````:>L!
M``4```"<ZP$`&0```*+K`0!2````O.L!`"P````/[`$`%P```#SL`0`H````
M5.P!`"0```!][`$`#@```*+L`0`@````L>P!`!P```#2[`$`(P```._L`0`=
M````$^T!`",````Q[0$`&@```%7M`0`,````<.T!``<```!][0$`$````(7M
M`0`1````ENT!`!0```"H[0$`"````+WM`0!`````QNT!``P````'[@$`"```
M`!3N`0`-````'>X!`!H````K[@$`"0```$;N`0`$````4.X!`!8```!5[@$`
M"````&SN`0`(````=>X!``0```!^[@$`"P```(/N`0`+````C^X!`!0```";
M[@$`$P```+#N`0`.````Q.X!`!0```#3[@$`#@```.CN`0`'````]^X!`!``
M``#_[@$`&P```!#O`0`D````+.\!`!P```!1[P$`"P```&[O`0`-````>N\!
M`!L```"([P$`*@```*3O`0`8````S^\!`!X```#H[P$`*@````?P`0`$````
M,O`!``0````W\`$`#0```#SP`0`'````2O`!``H```!2\`$`%@```%WP`0`(
M````=/`!``H```!]\`$`"````(CP`0`'````D?`!``D```"9\`$`"0```*/P
M`0`)````K?`!``P```"W\`$`#@```,3P`0`$````T_`!``X```#8\`$`"@``
M`.?P`0`*````\O`!``\```#]\`$`'`````WQ`0`+````*O$!``(````V\0$`
M'P```#GQ`0`'````6?$!``8```!A\0$`:````&CQ`0`,````T?$!``@```#>
M\0$`*````.?Q`0!$````$/(!`!\```!5\@$`+0```'7R`0!8````H_(!`!D`
M``#\\@$`)@```!;S`0`I````/?,!`!@```!G\P$`'0```(#S`0`%````GO,!
M``H```"D\P$`#0```*_S`0`-````O?,!``L```#+\P$`#0```-?S`0`5````
MY?,!``\```#[\P$`#0````OT`0`/````&?0!``\````I]`$`!````#GT`0`'
M````/O0!``@```!&]`$`&0```$_T`0`(````:?0!``8```!R]`$`!P```'GT
M`0`3````@?0!``8```"5]`$`&P```)ST`0`6````N/0!``L```#/]`$`&0``
M`-OT`0`,````]?0!`!8````"]0$`#````!GU`0`(````)O4!``\````O]0$`
M$@```#_U`0`/````4O4!``8```!B]0$`%P```&GU`0`+````@?4!`!X```"-
M]0$`!@```*SU`0`(````L_4!``T```"\]0$`(````,KU`0`)````Z_4!``L`
M``#U]0$`)@````'V`0`8````*/8!`!````!!]@$`!@```%+V`0`+````6?8!
M``X```!E]@$`"0```'3V`0`"````?O8!``X```"!]@$`!P```)#V`0`F````
MF/8!`"D```"_]@$`*P```.GV`0`<````%?<!`"P````R]P$`*0```%_W`0!:
M````B?<!``T```#D]P$`30```/+W`0`T````0/@!`%,```!U^`$`3````,GX
M`0`A````%OD!`#,````X^0$`)@```&SY`0`R````D_D!`"L```#&^0$`$P``
M`/+Y`0`]````!OH!`)@"``!$^@$`&@```-W\`0`0````^/P!`#\````)_0$`
MA0```$G]`0`N````S_T!`!H```#^_0$`)````!G^`0`:````/OX!`!X```!9
M_@$`'P```'C^`0`E````F/X!`$0```"^_@$`3P````/_`0!*````4_\!`"P`
M``">_P$`&0```,O_`0`0````Y?\!`"4```#V_P$`&P```!P``@`<````.``"
M`"@```!5``(`)P```'X``@`J````I@`"`#````#1``(`&0````(!`@`-````
M'`$"`"L````J`0(`)````%8!`@`H````>P$"`"$```"D`0(`'````,8!`@`Z
M````XP$"`&4````>`@(`-0```(0"`@!+````N@("`#4````&`P(`*````#P#
M`@`V````90,"`%P```"<`P(`.@```/D#`@`O````-`0"`"@```!D!`(`(P``
M`(T$`@`K````L00"`"<```#=!`(`5P````4%`@!6````704"`"X```"T!0(`
M+@```.,%`@!'````$@8"`$4```!:!@(`*@```*`&`@`=````RP8"`"\```#I
M!@(`*0```!D'`@`I````0P<"`"D```!M!P(`:````)<'`@!B``````@"`&L`
M``!C"`(`NP```,\(`@`:````BPD"`"X```"F"0(`-P```-4)`@`H````#0H"
M`&0````V"@(`&````)L*`@!8````M`H"`"$````-"P(`'````"\+`@`+````
M3`L"`,P```!8"P(`3P```"4,`@`B````=0P"`#P```"8#`(`(````-4,`@`8
M````]@P"`#,````/#0(`!@```$,-`@`'````2@T"``0```!2#0(`#````%<-
M`@`0````9`T"``P```!U#0(`"P```((-`@`'````C@T"`!(```"6#0(`#0``
M`*D-`@""````MPT"``8````Z#@(`%0```$$.`@`$````5PX"``<```!<#@(`
M"````&0.`@`%````;0X"`%(```!S#@(`!````,8.`@`9````RPX"``H```#E
M#@(`$@```/`.`@`0`````P\"``(````4#P(`!P```!</`@`&````'P\"`!,`
M```F#P(`#````#H/`@`6````1P\"``8```!>#P(`%````&4/`@`/````>@\"
M``,```"*#P(`+@```(X/`@`$````O0\"``8```#"#P(`!P```,D/`@`>````
MT0\"`#P```#P#P(`+@```"T0`@`O````7!`"`!8```",$`(`*````*,0`@`P
M````S!`"`"(```#]$`(`*@```"`1`@`@````2Q$"`",```!L$0(`'@```)`1
M`@`<````KQ$"`"P```#,$0(`)````/D1`@`:````'A("`"X````Y$@(`&0``
M`&@2`@`:````@A("`"P```"=$@(`,````,H2`@`@````^Q("`"0````<$P(`
M)````$$3`@`?````9A,"`",```"&$P(`+````*H3`@`G````UQ,"`"<```#_
M$P(`)0```"<4`@`?````310"`"0```!M%`(`,````)(4`@`=````PQ0"`"H`
M``#A%`(`-@````P5`@`Y````0Q4"`!H```!]%0(`)P```)@5`@!-````P!4"
M`"D````.%@(`+0```#@6`@`M````9A8"`"X```"4%@(`*````,,6`@`F````
M[!8"`"$````3%P(`)P```#47`@`X````71<"`"H```"6%P(`-0```,$7`@`,
M````]Q<"``X````$&`(`#@```!,8`@`@````(A@"`"H```!#&`(`(0```&X8
M`@`/````D!@"``\```"@&`(`&@```+`8`@`:````RQ@"``L```#F&`(`)P``
M`/(8`@`,````&AD"``H````G&0(`)0```#(9`@`H````6!D"`"(```"!&0(`
M)P```*09`@`B````S!D"``<```#O&0(`W````/<9`@`+````U!H"`!H```#@
M&@(`$P```/L:`@`'````#QL"``H````7&P(`$````"(;`@`2````,QL"`!P`
M``!&&P(``P```&,;`@`S````9QL"`!L```";&P(`&````+<;`@`'````T!L"
M`!(```#8&P(`$@```.L;`@`S````_AL"``@````R'`(`*0```#L<`@`3````
M91P"`!,```!Y'`(`&0```(T<`@`S````IQP"`!T```#;'`(`#@```/D<`@`C
M````"!T"``\````L'0(`$````#P=`@`7````31T"``H```!E'0(`'P```'`=
M`@`/````D!T"`!T```"@'0(`#P```+X=`@`>````SAT"`"8```#M'0(`!0``
M`!0>`@`0````&AX"``<````K'@(`"P```#,>`@`)````/QX"`#@```!)'@(`
M!@```((>`@`/````B1X"`!$```"9'@(`$````*L>`@`+````O!X"``\```#(
M'@(`!P```-@>`@`0````X!X"``@```#Q'@(`&P```/H>`@`(````%A\"`!L`
M```?'P(`&P```#L?`@`+````5Q\"``T```!C'P(`'````'$?`@`(````CA\"
M`#$```"7'P(`$0```,D?`@`0````VQ\"``@```#L'P(``@```/4?`@`*````
M^!\"`!@````#(`(`"P```!P@`@`#````*"`"``L````L(`(`"P```#@@`@`*
M````1"`"`!<```!/(`(`#@```&<@`@`8````=B`"`!X```"/(`(`#````*X@
M`@`Y````NR`"`"(```#U(`(`(P```!@A`@`9````/"$"`"L```!6(0(`#0``
M`((A`@!%````D"$"``8```#6(0(`&@```-TA`@!6````^"$"``\```!/(@(`
M$````%\B`@`'````<"("``0```!X(@(`!0```'TB`@`1````@R("`!8```"5
M(@(`!@```*PB`@`'````LR("``<```"[(@(`"P```,,B`@`#````SR("``P`
M``#3(@(`#0```.`B`@`Y````[B("`"X````H(P(`+````%<C`@`%````A","
M`!8```"*(P(`)0```*$C`@`B````QR,"`!\```#J(P(`$P````HD`@`"````
M'B0"``0````A)`(`#0```"8D`@`*````-"0"``4````_)`(`!0```$4D`@`/
M````2R0"`$T```!;)`(`)````*DD`@`S````SB0"`!<````")0(`(@```!HE
M`@`P````/24"`$X```!N)0(`,````+TE`@`6````[B4"`'X````%)@(`'@``
M`(0F`@!9````HR8"`"H```#])@(`3P```"@G`@`P````>"<"`"L```"I)P(`
M*````-4G`@`M````_B<"`"T````L*`(`*P```%HH`@`N````AB@"`"D```"U
M*`(`*````-\H`@`L````""D"`#<````U*0(`%````&TI`@`:````@BD"``P`
M``"=*0(`J````*HI`@`&````4RH"`+D```!:*@(`A0```!0K`@"@````FBL"
M`"`````[+`(`5P```%PL`@`0````M"P"`!T```#%+`(`$0```.,L`@`4````
M]2P"``<````*+0(`&0```!(M`@`>````+"T"``X```!++0(`00```%HM`@`9
M````G"T"`!8```"V+0(`5P```,TM`@`:````)2X"``\```!`+@(`"@```%`N
M`@`%````6RX"``8```!A+@(`"````&@N`@`%````<2X"`!D```!W+@(`"0``
M`)$N`@`8````FRX"`"(```"T+@(`#P```-<N`@`)````YRX"`!<```#Q+@(`
M#@````DO`@`*````&"\"``D````C+P(`!P```"TO`@`,````-2\"``@```!"
M+P(`$0```$LO`@`'````72\"``4```!E+P(`$````&LO`@`(````?"\"`!4`
M``"%+P(`$````)LO`@`.````K"\"`!````"[+P(`$P```,PO`@`2````X"\"
M``H```#S+P(`"0```/XO`@`(````"#`"`!`````1,`(`!0```"(P`@`(````
M*#`"`!,````Q,`(`"@```$4P`@`+````4#`"`!@```!<,`(`"0```'4P`@`&
M````?S`"`!L```"&,`(`&````*(P`@`.````NS`"`!0```#*,`(`"P```-\P
M`@`F````ZS`"`!0````2,0(`!P```"<Q`@`5````+S$"``<```!%,0(`"```
M`$TQ`@`B````5C$"``L```!Y,0(``@```(4Q`@`"````B#$"`!H```"+,0(`
M#````*8Q`@`&````LS$"``@```"Z,0(`&@```,,Q`@`&````WC$"`"4```#E
M,0(``@````LR`@`$````#C("`!$````3,@(`%P```"4R`@`+````/3("``D`
M``!),@(`"0```%,R`@`0````73("``H```!N,@(`%@```'DR`@`'````D#("
M`!P```"8,@(`"@```+4R`@`7````P#("``(```#8,@(`!0```-LR`@`0````
MX3("``P```#R,@(`$@```/\R`@`I````$C,"``<````\,P(`!P```$0S`@`1
M````3#,"``4```!>,P(`!0```&0S`@`"````:C,"``L```!M,P(``0```*T'
M``"J!```Z0$```@"``"B!0``%0,```````!U`@``F`(```````!6`@``````
M`$4"````````TP$``,0'``!(````KP8``*D%``#Z!```0@0``!D!``#,````
MS`4```````````````````,'````````K@$``````````````````(0'```B
M!0``.@0``*P!``"F`P``W0(```````"Q!@``Z`8```````!)!```E@8`````
M```:`0``U@4```T'````````9@$```````!@!````````$`#``#J`@``````
M`&4&```%`@``'`$``,0#````````````````````````"P<```````!D`P``
M`````'<%``"8!P``I04``!,`````````)P4``,$#``!O!`````````<$``!*
M`@``T`(``+X#``"3!0``*0,```````"Q`P``H@```/,!``!T`@``R`<`````
M``"?`P``O````````````0``WP8``%8#``!3````H04``!D"``"F`@``````
M`-X!``"#````(P<``((```#?`0``5`0``%8&````!```Y`4``*L%``"E`0``
M>@,```````!K!P``:@(``#H!````````:@$```(#``#I!0``70<```````#I
M`P``R0<``-H$``!;`P```````,L'``#\`0``PP```!H&``"4`0``````````
M```Z````[`0``/$%``!-!0``*0$``&T```"`!```RP$```````#Y!0``-P0`
M`.4'````````O`(``%H&```A`0``,0,``-D&`````````````(@```"[!```
M8@<``)4```"'`P```````,$!````````K`0```````!I`@``U`4```````"T
M````+@<``-X"``")!P``C@,``&$%``"G`@``ZP<``+('``#H!```Q@4``)0%
M``"<!@``1P8``,@"``"4!@``T@4``!D&``````````````````".`0``+P,`
M`)L#``"J!@```````-@!```/`@```````!,'``````````````````#:!0``
M\@,```````!L``````````X%``!9!```1`8```````"R!0``^0````````#'
M`0``PP8``#$!``"6`P``N`8``.T"``#T`P``)P0``*0```#W`P``TP```)8'
M``#Z!0``F`0``"$'````````0P0``)('``"T!0``P`4``#\`````````50``
M``````"[`P``JP,``!`#```"!0``-@8```````!I!```H`0``"T"``"B!P``
MO`8``$<!```\`P``2`,``!T%```,`P``PP<`````````````=`,```````!8
M!P``3P<``````````````````-\"````!@``:@0```````"Q!```:```````
M`````````````-0```"3!```E````#D#``!@````DP```*D!``#\`P``T0<`
M`&<&``#O`@``'0<```````!;````[@,``&\&```?!````````*,#```R`@``
M`````%(&``#6`````````&P'```Q!0```````$@&``"A!```)`0``',```"X
M````/0(``#\%``"U`0```````/('``!<````4P8``(H$````````%0$`````
M```9!P``"P0``&$#``":!0``<P4``%(%`````````````.$#``#``P``@`8`
M`*0#``"`!0``>P4``+4"````````R08``&4#```#`````````.\'````````
M`````*`!``!=`````````)\!```#`0```````+4$``#%`P``)P````````"-
M!P```````&<!``"Z!P``Q08``-4'````````Y0```&D`````````````````
M```$`0``(P8``$<'````````'@4``#4&````````G````/`!``#``@``````
M`"@%````````^P<``$(&``````````````````#T!P``O`,``+`%``!E`0``
M!@<``'4'``#<`P````````````#`!P``V0```````````````````)T!``!Y
M!0````````````!1!P```````+`#``"B`0``EP(``*L'`````````````&P"
M``"E`@``I08``/$'```<````_`(```````!7`P``>0,``#$$```J!P``CP4`
M``L&````````^P```%4&``##`@``$P4``(P`````````+`(``%8```#L!0``
M8P0``/P'```B`0```P,``-@&``#U`0``````````````````C`<```````#I
M!````````*$'`````````````!8#````````Y@$``'`"``!D`0``?@0``%,$
M``!(!```+`$``/\!``!"`@``)`8``-,%``#)!0``_P8```````#D`0``(08`
M```````8`P``>00`````````````)@$``!,#`````````08``(X&``!@!0``
MQ`$``"P#``!H!@``#P<``$8&```)`0``!`(``%H```!0!0``)`<`````````
M````G`(``%0````<!0``4P(``*<```#`!```:@<``-L#````````FP<``*@%
M````````'00```X$``!*!@```@$``(4`````````7`$``'$%``"Q````````
M`%4"``#F!0``!P,``$L!``!]!@``2`4``.H```"@!P``.`8``#X'````````
MUP,``!T"```O````X````*X$``!!`P``'P8``.X"```*`P``L`0``#8#``#*
M!0``300``+@"```0`````````/T!``##!````````*,$```)`P```````)0$
M``!Q`@``=04``*L&``!X`0````````D%```A!0```````(4$````````XP``
M``$#``"[!0``$0,``.$````@!```F0,``'(&```B`@``YP<``(L'```9!0``
MF@,```\`````````*`<````````'`@``@@0``&8%``"F!```5P(``(8&``"G
M!P``M@(``'($``"3!@```````+("```A`P``)`4``%0!``")````ZP4``+L"
M````````Q@````````"Q!P```````#0%``"M````#`8`````````````````
M`"<'```@!P``I`0`````````````F`````````!-````%P8``+$!``!J!0``
M80$``&T&``#U!@``W````#0!```&`P``R````*X"``"]`0``)P8```````!N
M!@``]P```,L%``#9!0```````/L%``!\`P`````````````Z!@``=08``,(`
M``!)!P``40$``"P```"-!```XP(``(`````.!@``90```"8%``!Z````R@0`
M``````!*!````````%\"``!0`P``O0````````#B`0``U`,```````!K!@``
M`````.,%``#L!@``!@$``)<$````````Z@0````````*`@``J0(``$0!```T
M!@``Q0```$X"``#!`@``I@```+4&``!I!P``3`0``-\$``#"!P``700``+8&
M``!?!P`````````````F!P```````-L```!G!```_P0``%4!``!<!P``,`(`
M`,$%``#T`0``708``-8!````````I@8``.T&````````;0(``$T#````````
MD`4``"\!``#2`P``Q`0``-8"```,!0``AP````````"4`P``5`8```````!`
M!0``5`,``'\$```T!P``%P,``,L#```:!0```````*\"``#S!P``@04`````
M````````````````````````)`(``,<$``"K!````````!\"````````/`0`
M`&H&``````````````````#6!```!0$``&("``",!@```````(\`````````
M`````'8#``"3!P``/@4``%P#``"9!0``5@0``+P!``!8!@``V0(``-T`````
M````PP,``"(&```A````[0,`````````````'@<``(0#``"'!@``````````
M````````K@4``)$&```-!0```````&@"````````1`,`````````````````
M`'0&````````+@0``%X'``"Z!0``!`````,"``":`@``?P(```````"2`0``
M`````*`"````````&`<````````:!````````"8#``#+`@```````'$&```'
M````D`8``-0$```K`P``Q04``#\'``!I!@``V0$``-L'````````````````
M```J!@``,`,```````#;!@``6`4`````````````C0$``"H"```]!P``BP8`
M``````````````````````!N`0``````````````````J````!P$``#%!```
M*04``-,'``!;`0```````&`'```7!P```````-@"``#L!P``1````*P&```B
M!P````````````#K`P``?00````````Y!0```````$L'```O!0``I@<``!\#
M``#2!@```````,\!``!A!```%0(``````````````````*<$``"5!```````
M`&<'``````````````````#1`P``%0```'L$``"'`0``=`<``"4'``#,!P``
MFP$```````````````````````#*!P``Z@8``.@"``#*`0``1@4``%@$````
M````%@0``)T"``"0`0``R`4``*\$``!B````$@4``/L&``!^````````````
M````````6@$`````````````B@8```("```N`@``=@0``.`$``#R````-P<`
M``L#````````@0````X!``#1`@```````"H$``#8`P````````````">!P``
M$@0``'4$````````(`4```````"<!P```````'<'``"C`@``AP<``-8#``!C
M!P````````````"[!P``>0<``/T````S!P``U@<``+H&````````Y@<``"P&
M`````````````#\&````````5P0``/@&``"&!0```````",#````````.`4`
M`%<````V!P``XP8``)0"``#K!@``A@```!@%```E`0``^`(```````!C`P``
M;P$```````#O!0``P@8``%4'``"M!0``]P<``'\'``#E!0```````"H!````
M`````````+(```#N`0``C04``.,$``!K!0``'`(``"H```#8!````````!X`
M``!'`P``004```````"$`0``/P0``,T'```4`@```````"$"``!-`0``6@0`
M`%$#``#H!P``>@<``*P```"@!@``L@0``)T$``#Y`P``P0<``-T'```+````
M`````#<"````````FP4``"X#``!8````P@$````````F!```F@<``$4```!K
M!```<P8```````"Z`P``9@````````"!!```'@8````````,`@``F@8``-0&
M``#&!```,P8```````#,`0``_P(``````````````````'P```"G!0``U0$`
M`/@#`````````````!0&````````P@,```````"-`@``UP8``*@&```:`P``
M`````,$&```I!```\0(``,T`````````#`$``.<#``!/`0````````````#-
M!0``,P$``(D#``!\!P``,@8``/T'``!V!@``]`(``````````````````%X&
M```P!@````````````!/`P``1P0``/X"``!!!```W@4``.P!```%!@``.P<`
M`","``#\!@``O@$``$0'``!4!P```````+<#```O!```8P```)<&```)!```
MD````)T#``!M`P``\`,``/H'``"2!````````*`#```^`0``W0$```````"]
M!```F`,``+D!```6!0```````$$!``#Y`@``-04```````!#`0``V@``````
M``"9`@```````,P$``"U`P``0P4``/(!``#V!@``G@4``,\%````````$`0`
M``````#E!```-@(```L!``!/!0``Y`(``%4%``"@````ZP(```````#[`P``
M`````*P%````````A0<```@#``"P`0``T`,``+,!``"+````+0````````"M
M`@``X`8````````H`@``!@```)X$``#Q!@```````%H'``")!````````#`!
M``!"`````````````````````````-4#``"S!```````````````````UP0`
M`#X`````````@P0````````3!@```````'('``!>`0``@`<``!$$````````
M"`<``$,```#D!```0P<``",$````````$@```)@!````````,0```'$!```D
M````!0<```````!.````Y0(``"@#```[!@```````!,"``"[````Q`4``%(`
M``!;!@``)08``+X"``#'````#0$```````!#`@``,`0``(,"```H!@``EP,`
M````````````A`0```T```"^````K@8``'P"`````P``T04``$P%``!:`@``
MP`$```````#A!@``7@```+\%`````````````&(&``"5`@``E0<``/`$```1
M`````````"<!````````````````````````<@,````````F!@``C`$``-D$
M``"9!@``W`8``*4'``"I!```(`(```````!%!```'`,``&@%````````````
M````````````+`0```````![`P``"@0``)@%``#Z!@``@P$``'T%````````
MYP8``-$!````````W08``.(#````````X`$``$`!``#.`@``.0<``&P$``#H
M`0``!04``"T'````````RP```!4$``!.!P```````%X$```*!@```````*D#
M``!D`@``UP<``*H#````````I`8``/D$````````70,``"`&``"M!@``````
M``````!I`P```@0``/(%``#T!```;0<``#L$``";```````````````4!0``
M)@(``````````````````'8!``!N`P``KP4``!T&``#F!```?@$``(@$````
M````2@$```````#O`P```````)@&````````6P(``/D'```J!0``SP,``#4!
M``!T!0```````#$'``"$!0``[@8`````````````.00``"4#``#R`@``J`$`
M`/<!``"P`````````"````#X!0``E@```%$"``#-!@``)P(``"(#```6`0``
M.0$``$\&``!N````S@```!8&```^`@``Z@<``%0"``"9`0```````-X```"\
M!```M0```/@```#.`0``$04``-\'`````````````#8```";!@``,@<``&,!
M``!\!@``;P```!\'``!@!@```````(@"```\`0``P````#,%```$!```Y`8`
M``````#U`@``BP(````````E````1@(``'$````\!@``_`0`````````````
M[00``%,!```.````TP(```````"B!```6P4``)4&``"=!P````````````!D
M!0``!`,```````#:!P```````'H!```'!0````````````"V!0```````#T&
M``!'!0```````.X%``#M!0```````'8'```N!@````````$'``"$````OP$`
M`&4$```;!0``500``+D&``#K`0```````-(```![`0``?0(``&T$``")!0``
M`````.P"``""!P``Q0$``#8$``!8`@``^@$``*@#``!'`@``+@$```````":
M!```=0,``)$```![````Q```````````````R0````````"<!0``````````
M``#/`@```````'````#B!P``_P```"\&``!2`0``YP(``'X&````````J@$`
M`.\$``!`!P```````/($``!1!```G@```(T#``"^!0```````+T'````````
M@0,``-X$``"0`P```````,H```#F!@````````````!P`0``<P(````````0
M`0```````',!``"C!P``H08``)P!````````;P4``)4#``#;!```N00`````
M```Y````?@4``)X"``!Z!````````/L$`````````````+D#```K!```,`4`
M```````'!@``.`,``"X````$!@``8`(``$P&```U!````````/4%````````
MY@,``+T#````````:04``%`````+`@``P@(``)8$``!H`P``00(``&<#````
M````70(``+0!``!+!0```````$\``````````````(P$``"3`P```````,8#
M``!(!P``408``#<&``!?!@``*`0``'X'``!9````4P,``.L$``#M````MP``
M`.<!````````C@0```````!!!P``008``%X"```B````````````````````
M```````````:````LP<``"T#``!X!P```````$0"```3!```PP4``"8```#P
M!0``O08``)0'```X`0``]00``,P&```W!0``U0````4$``#Q`P``9`0`````
M``#<`0```````)X!```E`@``40```)8!````````T00``!\!``!W````I@4`
M``````!.!0```````'@%````````;P<````````C````S0,```````!6`0``
MEP4``/8"````````@P,``'8%````````_0(``+T"``#J`P````````````#/
M!P``9P(``+@'```@`0``*P4``$4'``"Y````\`<``+@%``!.`P``W@8``-X#
M``"K````[@```!0#```%`P``?@(```L%````````%P```*X#``#%`@``````
M`+<!`````````````"L"``#7!0``WP,``(4#``"*`P``X@0```````#H````
MD04```<'``#Z`@``308```8$````````LP```$L"``!Z!@``2P0```````!J
M````4P4```````"7````1@$``#(``````````````,`&````````DP$``%`'
M``!Z!0``X`(``.8`````````YP0```````"?````-0(``-0'````````_@8`
M`%\!``#0!```L`8``"D'```:!P``N@0``!8"``"Y`@``\00```````""!@``
M.@,```````"J!P``WP4``!(&````````V````-P$````````20```/T%```!
M!```.`<``%<%```B!```/P,``%D#````````YP4``-`&``":````)`$``!H"
M```*!P``.`0``'8`````````%`$``#(#``"*`0`````````````N!0``````
M`$0%``#.!```````````````````H@8``'@$``"!`@``````````````````
M`````/,#``!O`@``I0,``"H#``!+````20(``.$!````````I00``!`"``")
M`0``$@,``/,$```W`P``L0(````````>`@``TP,``%\$``"K`@``K@``````
M``!C!@``FP(``*D```!S!````````$H%``#<!P```````-H#````````````
M`*0'````````GP0`````````````#P8``-<```#O````K`,``,0"```-!```
MHP```-8&``#T`````````+P%```>`P```````-`%````````````````````
M````BP,```````"&!P```````$D%``!@`P``8`$``$0$``"1`P``````````
M```I````V@8``&(!``!`````80(``/L"``#C!P``4@(``)$'``".!P``I@$`
M`,@#``````````(````````Y!@```````'$#```2`0``60(``"\'``"T!```
MG@,``-L!``#T!0``5@<``&@$`````````````/@'``!N!P``?P8``($'```C
M`0``]0,``!L&```X````K@<``#L"``#;!0``R`0````````#!0``3@8``$T"
M``!U`0``V`<``((%``"7!P```````/,"```S!````````!<"``"^!```9`8`
M```````&!0``G@8``(8#``!P!@``0`0``.(%```8!@``Y@(``(,'``#]`P``
M]@```&8'``")!@``G`,``'(!``#/!```.P$``(\#``"L!P``;@4``#,#```[
M!0``MP<``,T"```/!0``E@4``/,`````````J@````````"(!P``T08``.`'
M``"/!```F00``,8&``#P!@``MP4``'<&``"V!P``[0$``!`'```G`P``X0<`
M`%@#``!#!@``&00``!4%``"%!@``&0,``%`"```*`0``8@4``*$!``#4`0``
M1@<``,@!``"$!@``]@$```````"@!0``^08``"L```!)`P``K`(``)(#``!X
M````GP(``/X!````````\`````<!````````[P8``*<#``!*`P``#@,``&L`
M``##`0``L@$```\#``#W!0``-`0````````(`0``&P(`````````````Z@$`
M``````",`P``E0$``(L!```````````````````I`@``0`8```````#,`@``
MAP0`````````````B@```*T#````````;04``%D%``"J!0```````#T```#B
M!@````````````#C`P```````/P%```;`P`````````````S````L@,``%L'
M````````90(````````;!P``N@(```````"2````3`(````````;````````
M`(,%```.`@``,08``,@&``#;`@``90<```````#.!P```````'`#````````
M9@(``+\'``#W`@``?0```)$!````````,`<``!@$``!)`0``A0$``'`'````
M````;`$``$X!````````UP$`````````````QP4``/@!``"$`@``````````
M``#)`P```````&4%``"G`0``&P$``&@'``#/````*P<`````````````"08`
M`+<&````````H0,``%<'``"D!0``XP$``&0'```-`P``W00```````#K````
M5@4``````````````````%\#```*`````````#($``!R````A@(``*("````
M````TP8`````````````"`8```````!W`0```````%P$``!I`0``N`,``,H#
M```<!@``O@<``$$```!%!0``&````/4```#7`@``J`(``%`&``#A!```5P$`
M`#H"```4````Z0(``%0%````````^0$``"@`````````S@8``"4%````````
MX@```#(%``"1!```:@,``'X#```8`0```````!0$``"_`P``I`$``+H!````
M````=0```-T#``!(`@``0@<`````````````[`````````"&!```]P0``,<"
M````````F@$``+D%``".!0``/`<``&X"``````````````X'``"C!@``>P(`
M`&P&``"9!P``M@0```````#'!@```````+`'``"-````T@$```````!N!```
M8@0`````````````3@0```````#N!```JP$````````"````>`(``($&``!Z
M`@````````````#I!P``Y0$``(@!``"5!0``P@4``"T$``!>`P``"`0``)D`
M```]!0```````!$!``"?!@``80<``#T$``!Y`````````&0````?````N0<`
M`$4&``"A`@``_@4``!<%``#V!P``-P```%P"``!W!```M@,``(8!``"R!@``
M`````+`"````````0`(``#D"````````[`,```````!H`0``?0$```@```!/
M`@``>P8```````!2!```C@(``'8"````````OP0``-$````\`@``30<``$4!
M````````N@````````#\````#P$```0%``!F`P``'P4``#X&``#5!0``60<`
M`*<&````````G08``#L#``"A````Q@$``!T#```"!@````````````""`0``
M`````/8#``!*!P``>P<```````#E`P``>`8```````#.`P``_08``%,'````
M````Y``````````3`0``1P```/\#```;!```/`````D``````````````*D&
M``#$!@``SP8``"T&`````````````%`$``#2`@```````,H"```X`@``````
M`)`'````````Q@<``/L!````````7P`````````@`P```````"L!````````
M```````````7!```H@,``$@!``!]`P``:P(```````"+!0``V@$``$P'````
M````[P$```````"W!````````.<```!C`@````````````!:`P``Z`,``-D'
M``""`@``]@4```````"H!```$08````````M`0```````"4$````````?P,`
M`+L&``"U!0``=```````````````$`4``#,"```T`P````````````!B`P``
MI0```#X#```L!P``7@4```@%``!,`0``M@$``*\'````````<@(```````!?
M!0```````#0"``!&````Z08``&8&``#R!@````````````!<!0``````````
M``",`@``````````````````Y`<``,D$``!F!````````(D"``"]!0``%0<`
M`+@!```-!@``;`,``(\'````````<00````````I!@```````/@$``".````
ME@(``,H&````````````````````````@P8```````"T!@```````(H%````
M````D@4``((#``#&`@```````/`"``"S`P``=`0``%<&``#5`@``D@8``-H"
M````````DP(```8"```!`0``]@0```````#E!@``GP<``'P%``"=!0``<@4`
M`(`#```)`@``HP4``,L&``#0!P``+04``+\```#D`P```````!$"``"/!@``
M`````'\!``#Q`0``/P(``#4#``````````````````"=````?`0``$D&``!5
M`P``@0$```````!#`P``#````+<"``!]!P``````````````````9P4``'\`
M````````W04``*H"````````M`<`````````````V0,``(@%``!Y!@``````
M`-0"``#]!```K00``#\!```[````'0```','``!P!```N`0``+P'```Z!P``
MD0(``#<!````````W`4```````"T`@```````(<%``#W!@``(P4``(`"``"I
M!P````````0'``"S`@``&0```-('````````80```!<!````````)`,`````
M```>`0``+`4``,X%```5!@``X04````````V!0```````#P%``#J!0``'0$`
M````````````X0(``(4%``!,`P``HP$``#````!"!0``>0(``-`!``#H!0``
M>`,``.T'````````6@4``$\$``"_!@``/0$`````````````_@```&,%```6
M`````````,$$```R`0``Q0<``,<'```U!P``7`8`````````````"0<`````
M```%````TP0``"L&````````O@8``-4&``"_`@``M@```&L#```8`@``^@,`
M`&P%``"M`0``1@0``/4'````````S`,`````````````KP```#$"```A!```
MW@<``%T!```1!P``D`0``'D!``!+!@```````.X'``!2`P``/@0``',#```2
M`@``0@,```````#<`@``J`<``$L#``!W`@`````````````2!P``^@```,T$
M````````\P4``%L$`````````````#H%``"%`@```````'<#``!*````R0$`
M``P$``!8`0``P@0`````````````@`$``.D```#!`````@<```$%``#^!```
MI`(``'0!``!9`0``704``!X$``#+!```T````-($````````U00``)("``!0
M`0```````#8!``!2!P``LP8``%$%``#B`@``%`<``&$&``!Q!P``_@,``(\!
M``"/`@``QP,``,D"```,!P````````T"``#@!0``V`4``'P!``"Q!0``<`4`
M`#4````*!0```````*\!``#S!@``+P(``(P%```<!P``3````)L$``!9!@``
M#P0````````0!@``AP(``"@!```!`@``:P$``&T!````!P``GP4``/0&``"+
M!```!@8``*\#``#Q````?P4```````!&`P``D`(``&<```"S!0``_P4``$(!
M``"-!@``X`,```,&``"*`@``-````+L!``"(`P```````-\`````````EP$`
M``````"U!P``G`0``,T!``"*!P``/0,``$4#````!0``;P,`````````````
MM`,``!8'``"(!@````````,$````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E
M<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@
M>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"!N;W1E<P`E9"UD87D@9F]R96-A
M<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3
M:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T
M<RX`)7,@870@)7,@)7,`)7,@8VAA<F%C=&5R<P`E<R!F:6QE('-U8V-E<W-F
M=6QL>2!I;7!O<G1E9``E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN
M=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T
M(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S
M($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E
M<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM
M<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@
M;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@
M:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R
M:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,2!N;W1E`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L
M;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W
M(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T
M+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+@!!8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N`$%C8V5S<R!D96YI
M960@;6]V:6YG('1H92!N;W1E+@!!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E
M('1O("5S+@!!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<P!!8V-O=6YT
M($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN
M`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R
M;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI
M<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C871E9V]R
M>0!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE
M("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@
M8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B
M)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!!($YE=R!.;W1E
M`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O
M;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E
M<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG
M97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC
M871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U
M<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M
M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!
M;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@
M0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T
M:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!
M<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!
M<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@
M<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#
M24DM."D`07)T`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I;VX@27-L86YD`$%S
M8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I
M9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`
M075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S
M;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T
M($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R
M(&9A:6QE9"X`079A:6QA8FQE($-A=&5G;W)I97,Z`$%V86EL86)L92!F:65L
M9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VL@=&\@3F]T97!A9`!"
M86-K('1O($YO=&5P860@3W!T:6]N<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@
M0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E
M<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@
M87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L
M;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R
M('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O
M=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"
M=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--
M4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL(%!R;W!E
M<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD
M87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R
M(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@
M24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`
M0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I
M;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#
M86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N
M`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L
M("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F
M(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@
M;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O
M<FEE<R!A;F0@3&%B96QS`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H
M86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG
M(&%N9"!D:7-P;&%Y(&]P=&EO;G,N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@
M3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q
M,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T
M:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y
M<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=&AE(&UE;6\@8V%T96=O
M<FEE<R!T;R!L:7-T(&EN('1H92!S=6UM87)Y('9I97<N`$-H;V]S92!Y;W5R
M(&1E9F%U;'0@3F]T97!A9"X`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@1F]R;0!#;&5A
M<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E
M<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L
M:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN
M9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG
M*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`
M0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H
M96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U
M=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3
M;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T
M:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O
M;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N
M=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O
M<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S
M=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA
M;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#
M;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E
M<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD
M(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U
M;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@
M)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#
M;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O
M<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B
M)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U
M<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-
M;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N
M+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT
M<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R
M>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O
M;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S
M:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@
M-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N
M="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N
M="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP
M<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$
M1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E
M($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$
M871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C
M:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT($YO=&5P860`1&5F875L
M="!3:&5L;`!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R
M=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L
M;`!$96QE=&4@0V]N9FER;6%T:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G
M`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L971E(&)U='1O;B!B96AA=FEO=7(`1&5L971E(&-E;&P`1&5L971E(&-O
M;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T
M92!M97-S86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@
M<W5B(&9O;&1E<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES(&YO=&4`1&5L971E9"!S971U
M<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`
M1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$
M97-C<FEP=&EO;CH`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F
M;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T
M`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\`1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`
M1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM
M=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O
M=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="`B)7,B
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET($YO=&4`161I="!097)M:7-S
M:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`
M161I="!C871E9V]R:65S(&%N9"!C;VQO<G,`161I="!O<'1I;VYS(&9O<CH`
M161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O
M<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%
M;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T
M97=A>0!%;6]T:6-O;G,`16UP='D@3F]T90!%;7!T>2!M97-S86=E+@!%;7!T
M>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N
M(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B
M;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E
M($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT
M97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W
M.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T
M:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`
M17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N
M=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA
M`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`
M179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M
M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP
M96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@
M3F]T97,`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&7W5L;"!497AT
M`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@
M8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE
M8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R
M:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R
M;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E
M96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H
M;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT
M`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`
M1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E
M<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO
M`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT
M($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&
M<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`
M1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A;"!/<'1I;VYS`$=E;F5R
M871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'
M97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I
M;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES
M8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N
M861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T
M96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U
M:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A
M9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(
M96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(
M;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(
M;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O
M<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE
M(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0
M(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`
M2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E
M="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y
M`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A
M:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R
M90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@
M=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE
M=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM
M86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@
M3F]T97,L(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@
M3F]T97,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?
M<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!)
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S
M`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO
M;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!)
M;6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L
M=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT
M97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@
M8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A
M9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS
M97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!)
M;G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS
M97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`
M26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T
M80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A
M;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`
M26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L
M:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@
M<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA
M<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI
M8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)
M<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*
M86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*
M97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R
M`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA
M:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R
M96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME
M>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE
M)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#
M+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!0
M96]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T($UO
M9&EF:65D`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T
M(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@
M96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`
M3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B
M($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT
M(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@
M4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO
M=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S
M('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(
M96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP
M`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`
M3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`
M3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@
M=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F
M('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A
M<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`
M3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@
M;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`
M34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N
M`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K
M92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT
M80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I
M;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT
M+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI
M;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R
M961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M
M($YU;6)E<B!O9B!.;W1E<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO
M8VMS`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E
M<G,`365M;R!497AT`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E
M>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S
M(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE
M;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN
M9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@
M:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@
M;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T
M90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D:69Y:6YG("5S`$UO9'5L
M=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#
M;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,
M969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA
M;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!5
M2R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N
M="!);F9O<FUA=&EO;@!->2!.;W1E<P!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`
M3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`
M3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.
M971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA
M;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T
M:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@
M0V%T96=O<GD`3F5W($UO;VX`3F5W($YO=&4`3F5W(%5S97)N86UE("AO<'1I
M;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W
M:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`
M3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT
M(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`
M3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T
M:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E
M;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E
M9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M`$YO(&9I;&4@=7!L;V%D960`3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD
M+@!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A
M=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S
M<&5C:69I960N`$YO(&YO=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S
M+@!.;R!N;W1E<P!.;R!N;W1E<R!M871C:"!T:&4@8W5R<F5N="!C<FET97)I
M82X`3F\@;F]T97,@=&\@9&ES<&QA>0!.;R!N=6UB97(@<W!E8VEF:65D+@!.
M;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T
M:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R
M>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@
M<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E
M<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T
M96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T
M82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG
M:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO7W1E`$YO;F4`3F]N92`H=7-E(&EM
M<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.
M;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.
M;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO
M="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E($-A
M=&5G;W)Y`$YO=&4@1&5T86EL<P!.;W1E($QI<W1S`$YO=&4@5&5X=`!.;W1E
M(%]497AT`$YO=&4@;F]T(&9O=6YD+@!.;W1E7W!A9`!.;W1E<&%D)W,@;F%M
M93H`3F]T97!A9',`3F]T97!A9',@;75S="!H879E(&$@;F%M92X`3F]T97,`
M3F]T97,@4W5M;6%R>0!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V
M96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C
M;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/
M8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F
M9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N
M`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M
M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R
M871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N
M<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R
M<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-
M12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A
M=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI
M<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN
M9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E
M<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'
M4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN
M`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!0
M32!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`
M4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`
M4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N
M9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W
M;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0
M871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@
M;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N
M`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`
M4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@
M96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI
M;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y
M.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT
M97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@
M=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H
M92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R
M;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T
M96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O
M<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T
M86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!
M4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP
M:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D
M('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U
M<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R
M:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C
M<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI
M8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T
M92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@
M4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B
M;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A
M<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@
M=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G
M97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5A;&QY(&1E;&5T92!T:&ES(&YO=&4_`%)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H
M`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H($QI<W0`
M4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S
M97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@
M0FQO8VL`4F5M;W9E(&-A=&5G;W)Y`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!2
M96UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@
M;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`
M4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA
M<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W
M('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R
M`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA
M`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P
M97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2
M=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%
M;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE
M;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!3
M80!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A
M;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V
M:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E
M($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`
M4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!297-U;'1S`%-E87)C:"!3
M8V]P90!396%R8V@@7U1E>'0`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!N;W1E<&%D`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O
M(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!3
M96QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!N;W1E<&%D<R!T
M;R!D:7-P;&%Y.@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!E
M>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE
M8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@
M:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&5C=&5D($-A=&5G
M;W)I97,Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!3
M96YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA
M;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`
M4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E
M=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA
M>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO
M=P!3:&]W(&%C=&EO;B!B=71T;VYS/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\`4VAO=R!N;W1E<&%D(&YA;64_`%-H;W<@;F]T97,@9G)O;2!T:&5S
M92!C871E9V]R:65S`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO
M=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3
M:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I
M;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE
M`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P
M;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3
M;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R
M;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S
M("8@4&]E;7,`4V]R="!B>2!#871E9V]R>0!3;W)T(&)Y($YO=&4@5&5X=`!3
M;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I
M8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@
M86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES
M<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W
M965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG
M`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A
M8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`
M4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A
M<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R
M965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E
M8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN
M;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@
M=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T
M960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"`B)7,B
M+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U
M8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@
M=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY
M`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS
M970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A
M;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L
M86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S
M96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T
M;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL
M90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P
M97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK
M:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A
M<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M
M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI
M)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!4
M96UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L
M:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES
M=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L
M;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@
M=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S
M('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*
M5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E
M;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI
M;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;F]T92!W87,@9&5L971E
M9"X`5&AE(&YO=&5P860@(B5S(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E<P!4
M:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&-R96%T960N`%1H92!N;W1E<&%D
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!H87,@
M8F5E;B!S879E9"X`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE
M<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(
M;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B
M(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D
M('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL
M>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D
M+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N
M`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T
M96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y
M;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E
M96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED
M92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P
M<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@
M8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S
M(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O
M8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.;W1E(&1A=&$N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M
M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R
M92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E
M<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE
M<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<P!4
M:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="X`5&AI<R!)34%0('-E<G9E
M<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A
M>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E
M;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F:6QE(&9O<FUA
M="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C
M;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4
M:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R
M+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU
M;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#
M;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE
M($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@
M;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`
M5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N
M9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K
M:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O
M<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E
M>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R
M97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T
M;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L
M92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`B
M)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T
M;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R
M;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R
M=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO
M;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O
M<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@
M9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@
M9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F
M:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L
M92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@
M5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O(&-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I
M;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N
M9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N
M:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO
M<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N
M:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T
M(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E
M8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@
M;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L
M;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C
M;VQO<@!5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S`%5N<W5P<&]R=&5D
M($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T
M960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U
M9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T
M:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R
M(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR
M96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H
M92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E
M>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z
M(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I
M<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E
M<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R
M=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(
M:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W
M(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N
M9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6
M:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I
M82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&
M;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`
M5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X
M-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE
M<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H($YO=&5P860@<VAO=6QD('1H92!N
M;W1E<R!B92!A9&1E9"!T;S\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED
M=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T
M:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R
M;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I
M<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS
M:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L
M($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!N;W1E<RX`
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H
M92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@:&%V92!P97)M
M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@)7,N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES
M:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N
M9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9&5F875L="!N;W1E<&%D.@!9;W5R(&9U;&P@;F%M
M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@
M9F]R("5S(&ES.B`E<P!9;W5R(&YO=&5P861S.@!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I
M;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R
M96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B
M=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`
M6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI
M;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"86-K('1O
M($YO=&5P860`7T-,20!?0V%T96=O<GD`7T1A=&%4<F5E`%]$96QE=&4`7T1E
M;&5T92!2;W<`7T5D:70`7T9I<G-T($QI;F4`7T=R;W5P<P!?2&5L<`!?26UA
M9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&ES="!.;W1E<P!?
M3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?37D@3F]T97!A9',`
M7TYE=R!.;W1E`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V
M92!,:6YK+BXN`%]396%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN
M`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD
M87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N
M(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O
M;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL
M:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z
M`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O
M;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M
M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`&YO=&5S+F-S=@!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I
M;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`
M<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU
M<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=DYO=&4`=SH`=V5A=&AE<BYC
M;VT`4')O:F5C="U)9"U697)S:6]N.B!-;F5M;R`R+C$M8W9S"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`R+3$X(#$X.C4R*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-BTP,BTQ,R`Q,CHU.2LP,C`P"DQA<W0M5')A;G-L871O<CH@3&5E
M;F$@2&5I;F\@/&QI:6YU0'5T82YF:3X*3&%N9W5A9V4M5&5A;3H@1FEN;FES
M:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`@*"5S('#D:7;DY"!S
M:71T96XI`"`H4&EK86[D<'#D:6X@)7,I`"`H)7,@<.1I=N1S<^0I`"`H=.1N
MY.1N*0`@*&AU;VUE;FYA*0`@*&5I;&5N*0`@`"(E<R(@96D@;VQE(&AA:V5M
M:7-T;P`B)7,B(&5I(&ME;'!A82!V86QI;FYA:W-I+@`B)7,B(&5I(&]L92!A
M<V5N;F5T='4@2&]R9&5N(')E:VES=&5R:7-SY"X`(B5S(B!P=6ED96X@:W5V
M86%J86$@96D@;/9Y='EN>70N`"(E<R(@;&ESY'1T:6EN(')Y:&WD:N1R:F5S
M=&5L;>3D;BX`(B5S(B!L:7/D='1I:6X@;VEK975K<VEI;BX`(B5S(B!E:2!L
M=6]T=3H@)7,N`"4N,F9-0B!KY'ET971T>2`E+C)F34(@<V%L;&ET=7-T82`H
M)2XR9B4E*0`E9"`E<R!J82`E<P!386QA<V%N87-I('9A;FAE;G1U=2`E9"!P
MY&EVY&X@<.3D<W3D+@`E9"!M=6ES=&EI;G!A;F]A`"5D('#D:7;D;B!E;FYU
M<W1U<P`E<R`M($EL;6]I='5S`"5S(%-O<FUE;FKD;&MI`"5S($M"`"5S(%EL
M;.1P:71O=&]I;65N<&ET965T("T@5F%R;6ES='5S`"5S(&%S96YN=7,`)7,@
M:VER:F%U='5M:6YE;@`E<R!KY'ET=/9E:&1O=``E<R!O;B!J;R!O;&5M87-S
M82X`)7,@<W5U;G1A("5S("5S`"5S(&UE<FMK:>0`)7,@=&EE9&]S=&]N('1U
M;VYT:2!O;FYI<W1U:0`E<R!O;B!V86QM:7,@<W5O<FET=&%M86%N('EL;.1P
M:71O=&]I;65N<&ET96ETY"X@5F%L:71S92!V86QI;G1A<G5U9'5I<W1A('-U
M;W)I=&5T=&%V870@=&]I;65N<&ET965T+@`E<R!O;B!P86MO;&QI;F5N`"5S
M(&UI;G5U='1I80`E<R!E:2!L]GET>6YY="X`)7,@+2`E<R`O("5S`"5S.FX@
M;W-O:71E:VER:F$`)7,Z;B!K86QE;G1E<FD`)7,Z;B!M=6ES=&EL:7-T80`E
M<SIN('1E:'3D=N1L:7-T80`E<SH@)7,`)7,@.B!4Y&WD('9I97-T:2!E:2!O
M;&4@=N1L='3D;>1T=.0@<VEL=.0@;.1H971TY&KD;'3D+"!J;VMA(&]N(&UE
M<FMI='1Y(&SD:&5T=.1JY&MS:2X@4W5H=&%U9'4@=F%R875K<V5L;&$@=FEE
M<W1I<W/D(&]L979I:6X@;&EN:VME:6AI;B!J82!V87)O(&%N=&%M87-T82!L
MY&AE='3D:N1L;&4@;6ETY.1N('EK<VEL]FEV:>0@=&EE=&]J82X`+"!P=75S
M:VET=&%I<W1A`"P@<'5U<VMI='1A:7-T82`E<R`E<P`L('9A:6AT96QE=F%A
M("5S("T@)7,`+2T@=F%L:71S92`M+0`Q(&UU:7-T:6EN<&%N;P`Q,BUT=6YN
M:6X@:N1R:F5S=&5L;>0`,C0M='5N;FEN(&KD<FIE<W1E;&WD`#(T('1U;G1I
M80`\161E;&QI;F5N`%1I971O:V%N=&%T875S=&%JY')J97-T96QMY.0@96D@
M;VQE(&WDY')I=&5L='D@=.1L;&4@;W-I;VQL90!487!A:'1U:2!V86MA=F$@
M=FER:&4`5FEE<W1I;B!S86QA=6MS965N('1A<G9I=&%A;B!J=6QK:6YE;B!0
M1U`M879A:6XN`$%L;&5K:7)J;VET971U;B!V:65S=&EN('1A<FMI<W1U:W-E
M96X@=&%R=FET86%N(&IU;&MI;F5N(%!'4"UA=F%I;BX`4V%L871U;B!V:65S
M=&EN(&%V86%M:7-E96X@=&%R=FET86%N(&IU;&MI;F5N(%!'4"UA=F%I;BP@
M<V%L86EN96X@4$=0+6%V86EN(&IA('-A;&%S86YA=&5K<W1I+@!6:65S=&EN
M(&%L;&5K:7)J;VET=&%M:7-E:W-I('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M
M879A:6XL('-A;&%I;F5N(%!'4"UA=F%I;B!J82!S86QA<V%N871E:W-T:2X`
M5FEE<W1I;B!A=F%A;6ES965N('1A<G9I=&%A;B!J=6QK:6YE;B!3+TU)344M
M879A:6XL('-A;&%I;F5N(%,O34E-12UA=F%I;B!J82!S86QA<V%N871E:W-T
M:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A;6ES96MS:2!T87)V:71A86X@:G5L
M:VEN96X@4R]-24U%+6%V86EN+"!S86QA:6YE;B!3+TU)344M879A:6X@:F$@
M<V%L87-A;F%T96MS=&DN`%9I97-T:6X@<V%L875K<V5E;B!T87)V:71A86X@
M:G5L:VEN96X@4TU)344M879A:6XN`$%-(%!I;'9IY`!!32!K979Y='3D('-A
M9&5T=&$`04T@<V%D90!!32!S871E:71A`$%-(&QU;6ES871E:71A`$%-+U!-
M`$%022!)1`!4:65T;VIA(&5D:71O<FES=&$`5&EE=&]J82XN+@!!8G,N(&%L
M:6X`06)S+B!K97-K96QLY`!3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@;'5O
M9&$@5D93+6AA:V5M:7-T;V$N`%-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!L
M=6]D82!61E,M=&EE9&]S=&]A+@!3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@
M<&]I<W1A82!M=6ES=&EI;G!A;F]A+@!3:6YU;&QA(&5I(&]L92!O:6ME=6MS
M:6$@<&]I<W1A82!M=6ES=&EI;G!A;F]A+@!3:6YU;&QA(&5I(&]L92!O:6ME
M=6MS:6$@=&%L;&5T=&%A(&UU:7-T:6QI<W1A86X@)7,N`%-I;G5L;&$@96D@
M;VQE(&]I:V5U:W-I82!T86QL971T86$@;75I<W1I;&ES=&%A;B`E<RX`2^1Y
M='3D:N1T=6YN=6MS96X@=&EE9&]T`$OD>71TY&KD='5N;G5K<V5N('-A;&%S
M86YA`$OD>71TY&KD=&EL:2!S=6QJ971T=2X`2VER:F%N<&ET;P!,:7/DY`!,
M:7/DY"!A;&ER>6AMY`!,:7/DY"!A;&EO:6ME=7,`3&ESY.0@=.1HY&XZ`$QI
M<^3D('5U<VD@<GEH;>0`3&ESY.0@=75S:2!O:6ME=7,`3&ESY.0@86QI<GEH
M;>0@<GEH;>3D;B`B)7,B`$QI<^3D(&%L:6]I:V5U9&5T("(E<R(`3&ESY.0@
M=75S:2!KY'ET=.1JY#H`3&ESY.0@;'5O:VET=7,`3&ESY.0@<V%R86ME`$QI
M<^3D('5U<VEA(&KD<V5N:>0`3&ESY.0@<&%R:0!,:7/DY"`E<R!V86QI:VMO
M($UO>FEL;&%N(%-I9&5B87(@;W-I;V]N`$QI<^3D(&]S;VET96MI<FIA86XZ
M`$QI<^3D(&]S;VET96MI<FIA86YI.@!,:7/DY"!KY'ET=.1JY`!,:7/D='1I
M:6X@(B5S(B!JY')J97-T96QMY.1N+"!M=71T82!E:2!V;VD@;&ESY'3D('-I
M<^3D;FMI<FIA=71U;6ES<'EY;F[V;B!L:7/D=&EE=&]J83H@)7,N`$QI<^1T
M=&EI;B`B)7,B(&KD<FIE<W1E;&WDY&XN(%9O:70@;GET(&MI<FIA=71U82!S
M:7/DY&XN`$QI<^1TY.1N('5U='1A(&UU:7-T:6EN<&%N;V$`2^1Y='3D:FEE
M;B!L:7/DY&UI;F5N(&]N(&5S=&5T='DN`$]S;VET90!/<V]I=&5K:7)J80!6
M;VD@87-E='1A82!T86D@;>3D<FET96QLY"!O:6ME=6MS:6$@=&]I<VEL;&4@
M:^1Y='3D:FEL;&4`66QLY'!I=&\`36%I;F]K<V5T`$%F9V%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`%1A<V%A`%1A<V%U<SH`2V%I:VMI`$MA:6MK
M:2!A=71E;G1I:V]I9'5T(&OD>71TY&KD=`!+86EK:VD@<GEH;>1T`$MA:6MK
M:2!O:6ME=61E=`!+86EK:6QT82!N96QJY&QTY"!S:79U;'1A`%-A;&QI(&UO
M;F5T(&]S;VET=&5E=`!386QL:2!JY')J97-T971Y;B!L:7-T86X@='EY<&EN
M(&%S971U<RX`3VX@:F\@;VQE;6%S<V$`5F%I:'1O96AT;VEN96X@24U34"US
M:7/DY&YK:7)J875T=6UI;F5N`%9A:6AT;V5H=&]I;F5N($E-4U`M<V%L87-A
M;F$`5F%I:'1O96AT;VEN96X@24U34"UKY'ET=.1JY'1U;FYU<P!686EH=&]E
M:'1O:7-E="!SY&AK]G!O<W1I;W-O:71T965T`%9A:6AT;V5H=&]I<V5T(&UA
M;&QI=`!686EH=&]E:'1O:6YE;B!T96MS=&DZ`%EH9'ES=F%L=&%I;B!386UO
M80!!;FYE='1U(&%R=F\@96D@:V5L<&%A+@!T87!A:'1U:2!T=6YT96UA=&]N
M('9I<FAE+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>7EM:2!P<F]X
M>0!687-T875S`$%N=&%R:W1I<P!!;G1I9W5A(&IA($)A<F)U9&$`3VAJ96QM
M80!/:&IE;&UA;&ES=&$`3VAJ96QM82!O;B!V86QM:7,N`$QA:71A(&OD>71T
M]O9N(&MA:6MK:2!A;&EJ86MO:6AI;@!(>7;D:W-Y`$%R=FEO:71U(&MO:V\`
M:'5H=&EK=74`07)A8FEA("A7:6YD;W=S+3$R-38I`%!A:V5T:6X@:V]K;P!0
M86ME=&EN(&YI;6D`3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!P;VES=&%A
M('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V;B`E<R`_`$]L971K;R!V87)M82P@
M971TY"!H86QU870@<&]I<W1A82`B)7,B(&IA(&MA:6MK:2!S96X@86QI<GEH
M;>1T/P!!9V5N=&EI;F$`07)M96YI80!!<FUE;FEA("A!4DU30TE)+3@I`%1A
M:61E`$%R=6)A`$YO=7-E=F$`07-C96YS:6]N('-A87)E=`!!<V-I:2UT86ED
M90!!<VEA;B]4>7EN96YM97)E;B!A;'5E`$MY<WD@=F%R;6ES='5S(&5N;F5N
M(&MU:6X@=&5H9.3D;B!Y;&SD<&ET;W1O:6UE;G!I=&5E="X`5&5H=.1VY'-A
M<F%K:V5E=`!9<FET971T:6EN('!O:7-T86$@;VQE;6%T;VYT82!R>6AMY.0N
M`%ER:71E='1I:6X@<&]I<W1A82!O;&5M871O;G1A(&]I:V5U='1A+@!9<FET
M971T:6EN(&UU;VMA=&$@;VQE;6%T;VYT82!O:6ME=71T82X`67)I=&5T=&EI
M;B!M=6]K871A(&]L96UA=&]N=&$@:F%K;V$N`$QI<^1MY.1R:71Y:W-E=`!E
M;&]K=74`075S=')A;&EA`$ETY'9A;'1A`$%U=&A?8WER<W%L.B!487)V:71T
M879A82!)34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7V-Y<G5S
M.B!4875S=&%JY')J97-T96QMY"!E:2!T=64@=&%R=FET=&%V:6$@;VUI;F%I
M<W5U:W-I82X`075T:%]C>7)U<SH@5&%R=FET=&%V86$@24U!4"UL86%J96YN
M=7-T82!E:2!L]GET>6YY="X`075T:%]F='`Z('1A<G9I='1A=F%A($944"UL
M86%J96YN=7-T82!E:2!L]GET>6YY="X@2^3D;F[D(%!(4"!KY'ET=.1E;B`M
M+65N86)L92UF='`@87-E='5S=&$N`$%U=&A?:6UA<#H@5&%R=FET=&%V86$@
M24U!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T:%]K<F(U.B!487)V
M:71T879A82!K<F(U+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7VQD
M87`Z(&OD>71TY&II96X@;&ESY.1M:6YE;B!!8W1I=F4@1&ER96-T;W)Y>6X@
M96D@;VQE('1U971T=0!!=71H7VQD87`Z($OD>71TY&II96X@<&]I<W1A;6EE
M;FX@06-T:79E($1I<F5C=&]R>7-TY"!E:2!O;&4@='5E='1U`$%U=&A?;&1A
M<#H@5&%R=FET=&%V86$@3$1!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`
M075T:%]L9&%P.B!%:2!V;VED82!L:7/D=.0@:^1Y='3D:N3D("5S+B!086QV
M96QI;65N('9I<FAE:6QM;VET=7,@;VQI.B``075T:%]L9&%P.B!%:2!V;VED
M82!P;VES=&%A(&OD>71TY&KDY"`E<P!!=71H7VQD87`Z($5I('9O:61A('#D
M:7;D='3DY"!KY'ET=.1JY.0@)7,`075T:%]L9&%P.B!+Y'ET=.1J:65N('#D
M:79I='3D;6EN96X@06-T:79E($1I<F5C=&]R>7EN(&5I(&]L92!T=65T='4N
M`$%U=&A?;6-A;#H@5&%R=FET=&%V86$@34-!3"UL86%J96YN=7-T82!E:2!L
M]GET>6YY="X`075T:%]S;6)A=71H.B!487)V:71T879A82!S;6)A=71H+6QA
M86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71E;G1I:V]I;G1I($E-05`M<&%L
M=F5L:6UE;&QE(&5PY&]N;FES='5I+@!!=71E;G1I:V]I;G1I(&5PY&]N;FES
M='5I`$%U=&5N=&EK;VEN=&D@97#D;VYN:7-T=6DN("5S`$%U=&5N=&EK;VEN
M=&D@4D%$2553+7!A;'9E;&EM96QT82!E<.1O;FYI<W1U:2X`075T96YT:6MO
M:6YT:2!&5%`M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!!=71E;G1I:V]I
M;G1I(%--0BUP86QV96QI;65L;&4@97#D;VYN:7-T=6DN`$OD>71E='3D=FES
M<^0@;VQE=F%T(&QU;VMI='5K<V5T.@!+Y'ET971TY'9I<W/D;VQE=F%T(&ME
M;G3D=#H`07IE<F)A:7ID86X`0D]&2"!S96QI='EK<V5T`%1A:V%I<VEN(&UU
M:7-T:6QI<W1A86X`5&%K86ES:6X@;75I<W1I;&ES=&%N(&%S971U:W-I:6X`
M5&%U<W1A`%1A=7-T87;D<FD`5N3D<N0@:V5R8F5R;W,@<V%L87-A;F$N`%;D
MY'+D(&ME<F)E<F]S(&OD>71TY&KD='5N;G5S+@!"86AA;6$`0F%H<F%I;@!"
M86QT:6$@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$=R869I
M:6MO:61E;B!P97)U<VAA:V5M:7-T;V$@(B5S(B!E:2!L]GET>6YY="X`4&5R
M=7-V:6EV80!686QK;RU696[D:N0`0F5L9VEA`$)E;&EZ90!"96YI;@!"97)M
M=61A`$)H=71A;@!3>6YT>6WD<.1I=N0`3W-I;W1A("(E<R(@;VAJ96QM86QL
M92`B)7,B(&5I(&SV>71Y;GET+@!/<VEO;B!A<V5T=6MS970`3W-I;VX@='EY
M<'!I`$QI:&%V;VET=0!";VQI=FEA`$MI<FIA;FUE<FMI=`!2975N80!2975N
M86X@=F%H=G5U<SH`4F5U;F%T`$)O<VYI82!(97)Z96=O=FEN80!-;VQE;6UA
M=`!";W1S=V%N80!!;&EN`$)O=79E="!S86%R970`0G)A<VEL:6$`0G)I=&%N
M;FEA;B!);G1I86X@=F%L=&%M97)E;B!T97)R:71O<FEO`$)R=6YE:2!$87)U
M<V%L86T`0G5L9V%R:6$`4&%L;'5K:V%L:7-T80!"=7)K:6YA($9A<V\`0G5R
M=6YD:0!#35,`0U)#`$-23"UJ86ME;'5O<V]I='1E970`0U-6`%-?;VQU;B!T
M:65D;W0N+BX`5N1L:6UU:7-T:6X@86QU<W1U<R!E:2!V86QM:7-T=6YU="X`
M2V%L96YT97)I`%1Y>6YI`$MA;7!U='-E80!+86UE<G5N`%-A;&%S86YA82!E
M:2!V;VD@='EH:F5N=.3D(&%U=&]M86%T=&ES97-T:2P@;W1A('EH=&5Y='3D
M('EL;.1P:73D:N3D;BX`16D@=F]I(&MI<FIO:71T86$@=&EE9&]S=&]O;B`B
M)7,B`%5L:V]I<VEA(&ES='5N=&]KY'-I='1E;&EJ]FETY"!E:2!O;&4@;6%H
M9&]L;&ES=&$@:&%L;&ET82X`24U!4"UP86QV96QI;65E;B!E:2!S86%T=2!Y
M:'1E>71TY#H@)7,`16D@=F]I(&%V871A('1I961O<W1O82`B)7,B+@!+86YA
M9&$`4&5R=0!097)U(&]N9V5L;6%V:65S=&D`16D@=F]I9&$@<&]I<W1A82!T
M:65D;W-T;V$@(B5S(BX`5N1L:6%I:V%I<VAA:V5M:7-T;V$@96D@;/9Y='EN
M>70N`$5I('9O:61A(&IA=&MA82!I;&UA;B`G=&%R9V5T1FEL92<@+7!A<F%M
M971R:6$N`$5I('9O:61A('!O:7-T86$@:&%K96UI<W1O82`B)7,B+@!%:2!V
M;VED82!P;VES=&%A+"`E9"!A;&ET87-O:F$@;VQE;6%S<V$N`$5I('9O:2!U
M=61E;&QE96YJY')J97-TY.0L(&%N;F5T='5J96X@=&EE='5E:61E;B!MY.1R
MY"!E:2!V87-T86$@=&%L;&5T971T=6IE;B!T:65T=65I9&5N(&WDY'+DY"X`
M16D@=F]I(&]H:F%T82!V:65S=&GD(&%N;F5T='5U;B!N=6UE<F]O;BX`2V%P
M(%9E<F1E`$MU=F%T96MS=&D`4&%L=F5L=6YT87)J;V%J80!+871E9V]R:6%T
M(&IA(&]T<VEK;W0`2V%T96=O<FEA`$-A>6UA;B!S86%R970`4'5H96QI;BA'
M4TTI`%-O;'5N('1I961O=`!3;VQU;B!TY'ET93H`4V]L=6X@=&EE9&]T`%-O
M;'5N(';D;'ES.@!-871K87!U:&5L:6X`2V5L='1I("A)4T\M.#@U.2TQ-"D`
M2V5S:VET971T>0!+97-K:2U!9G)I:V%N('1A<V%V86QT80!+97-K:2U%=7)O
M;W!P82`H25-/+3@X-3DM,BD`5F%R;65N=&5E;B!T:65D;W0`5F%R;65N=&5E
M;B!O;6ES=&%J80!687)M96YT965N('!O;&ET:6EK870`5'-A9`!-=75T80!6
M86EH9&$@<V%L87-A;F%S:0!6;VET(&UU=71T86$@;.1H971TY&UI<W/D<VD@
M<^1H:_9P;W-T96ES<V$@;N1K>79IY"!N:6UI+2!T86D@;W-O:71E=&EE=&]J
M82X`5F]I="!M=75T=&%A(&UU:7-T:6EN<&%N;VIE;B!JY')J97-T96QY+2!J
M82!NY'ET=/9A<V5T=6MS:6$N`%-A;&%S86YA;B!V86EH=&\@96D@;VQE(&OD
M>73V<W/D(&YY:WEI<VEL;.0@87-E='5K<VEL;&$N($]T82!Y:'1E>71TY"!Y
M;&SD<&ETY&II:6XN`$UE<FMK:0!487)K:7-T7V$@;&EN:VMI+BXN`$-H:6QE
M`$MI:6YA`$MI:6YA('EK<VEN:V5R=&%I<W1E='1U("A'0C(S,3(I`$MI:6YA
M('!E<FEN=&5I;F5N("A":6<U*0!686QI='-E(&]H:F5L;6$`5F%L:71S92!S
M86QA<V%N80!686QI='-E(&OD>71TY&KD='5N;G5S`%9A;&ET<V4@<.1I=N1M
MY.1R:65N(&5S:71Y<V%S=3H`5F%L:71S92!L:7-T86X@='EY<'!I("AJY')J
M97-T971Y:6QL92!L:7-T;VEL;&4I`%9A;&ET<V4@>6AT965N=F5T;V[D:WEM
MY'-SY"!NY'ET971TY';D="!M=6ES=&EI;G!A;F]L=6]K:71U:W-E="X`5F]I
M="!V86QI=&$@;VQE='5S;75I<W1I;&ES=&%S:2X`2F]U;'5S86%R970`3'5O
M:VMA;>3D<FET>7-TY"`E<R!E:2!L]GET>6YY="X`4V5L:V7D`%1Y:&IE;F[D
M(&QO;6%K90!0;VES=&$@35-/9F9I8V4@=&%G:70`4&]I<W1A(&MY<V5L>0!0
M;VES=&$@:^1Y='3D:N0Z("5S`%!O:7-T82!KY'ET=.1JY`!0;VES=&$@:^1Y
M='3D:N1N('1I961O=`!396QK96YE=N3D(&UY]FCDY&X`3F%P<V%U=&$@:F%T
M:V%A:W-E<VD`0VQI:V%T96QL($A45%`Z;B!K875T=&$`4W5L:F4@:6MK=6YA
M`%!I;'9IY`!0:6QV:6YE;B!A:6MA:7-I;@!0:6QV:6YE;@!+;V]K;W,@*$ME
M96QI;F<I('-A87)E=`!0:65N96YNY"!S:79U=F%L:6MK;P!0:65N96YN971Y
M="!R975N870`2V]L=6UB:6$`5N1R:0!6Y')I=F%L:71S:6X`5N1R:79A;&EN
M=&$`4V%R86LZ`%-A<F%K:V5I9&5N(&]T<VEK;W0`4V%R:F%K=79A=`!+;VUE
M;G1O`$MO;65N=&]T=6QK:VD`2V]M;65N='1I`%EL96EN96X@;FEM:0!+;VUO
M<FET`%ER:71Y<P!4:65T;VMO;F5E=`!/;&]S=6AD90!/;&]S=6AT965T`$%S
M971U:W-I96X@97)O=`!!<V5T=6MS970@4$1!+6QA:71T96ED96XL(.1L>7!U
M:&5L:6UI96X@:F$@3W5T;&]O:VEN('-Y;FMR;VYO:71I:6XN`$%S971U:W-I
M82!P:73DY"!PY&EV:71TY.0N`$%S971A(&%S971U:W-E="`E<P!686AV:7-T
M82!K:7)J;VET=&%M86QL82!S86QA<V%N82!U=61E<W1A86X`2V]N9V\`2V]N
M9V]N(&1E;6]K<F%A='1I;F5N('1A<V%V86QT80!9:'1E>7,@97#D;VYN:7-T
M=6DN`%EH=&5Y<R!E<.1O;FYI<W1U:3H@`%EH=&5Y<R!J=6QK:7-T96X@879A
M:6YT96X@<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!9:'1E>7,@:G5L:VES
M=&5N(&%V86EN=&5N('!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X@5FER:&4Z
M("5S("@E<RD`66AT97ES(&9T<"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN
M`%EH=&5Y<W1I961O=`!9:'1E>7-T:65D;W0@;&ESY'1T:6EN(&]S;VET96MI
M<FIA87-I+@!4:6EV:7-T971Y;B!T:65D;W-T;VX@='EY<'!I.@`B)7,B.FX@
M<VESY&QT]@!*871K80!#;V]K('-A87)E=`!%=N1S=&4`2V]P:6]I`$MO<&EO
M:6YT:2!E<.1O;FYI<W1U:3H@)7,`2V]P:6]I('9A;&EN=&$`0V]S="!)1`!#
M;W-T82!2:6-A`$YO<G-U;FQU=7)A;FYI:VMO`%9I97-T:6X@4$=0+7-A;&%U
M<W1A(&5I('9O:71U('1E:&3D.B``5FEE<W1I:6X@96D@=F]I='4@;75O9&]S
M=&%A(%!'4"UA;&QE:VER:F]I='5S=&$Z(`!6:65S=&EN(%,O34E-12US86QA
M=7-T82!E:2!V;VET=2!T96ADY"X`5FEE<W1I:6X@96D@=F]I='4@;75O9&]S
M=&%A(%,O34E-12UA;&QE:VER:F]I='5S=&$N`$5I('9O:71U(&]T=&%A('EH
M=&5Y='3D+B`E<P!,9&%P+7!A;'9E;&EM965N(&5I('-A871U(&%U=&]R:7-O
M:71U82!Y:'1E>71TY"X`16D@=F]I='4@=&%R:VES=&%A('-A;&1O82X@)7,`
M3$1!4"UP86QV96QI;65E;B!E:2!S86%T=2!Y:'1E>71TY"X`16D@=F]I='4@
M;W1T86$@>6AT97ET=.0@<&%L=F5L:6UE96X@(B5S(B!KY'ET=.1E;B!&5%`Z
M("5S`$5I('9O:71U(&QU;V1A(&IA:V5L=6QI<W1A82X@)7,`4$=0+7-A;&%T
M='5A('1I971O82!E:2!V;VET=2!A=6MA:7-T83H@`%,O34E-12US86QA='1U
M82!T:65T;V$@96D@=F]I='4@875K86ES=&$N`$5I('9O:71U('!O:7-T86$@
M>6AT97ES=&EE=&]A+B`E<P!%:2!V;VET=2!P;VES=&%A(&IA:V5L=6QI<W1A
M82X@)7,`16D@=F]I='4@<&]I<W1A82!PY&EV:71Y<W-K<FEP=&GD("(E<R(N
M`%9I97-T:6X@;.1H971TY&KD;B!SY&AK]G!O<W1I;W-O:71E='1A(&5I('!Y
M<W1Y='1Y(&WDY')I='1E;&5MY.1N+@!%:2!V;VET=2!H86ME82!K;VMO(&]S
M;VET96MI<FIA82X`16D@=F]I='4@:&%K96$@:V]K;R!J86ME;'5L:7-T86$N
M`$5I('9O:71U(&AA:V5A(&MO:V\@;&ES=&%A(&IA:V5L=6QI<W1O:7-T82X`
M16D@=F]I='4@;'5K96$@<W1R871E9VEA82`B)7,B+@!+;VUE;G1O(&UK9&ER
M("(E<R(@97#D;VYN:7-T=6DN`$IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI
M;65L=&$@96D@<V%A='4@:G5L:VES=&$@879A:6YT82X`5&EE9&]S=&]O;B`B
M)7,B(&5I('9O:2!K:7)J;VET=&%A+@!%:2!V;VET=2!A=6MA:7-T82`E<RX`
M66QLY'!I=&]M;V1U=6QI;B`E<R!A=6MA:7-U(&5PY&]N;FES='5I`$5I('9O
M:2!A=6MA:7-T82!H86ME;6ES=&]A("(E<R(N`$Q$05`M<&%L=F5L:6UE;'1A
M(&5I(&]L92!M86AD;VQL:7-T82!E='-IY"X`)7,ZY.0@96D@=F]I='4@;'5K
M96$N`$OD>71TY&KD;B!S86QA<V%N86$@96D@=F]I='4@;F]L;&%T82X@2F]T
M:W5T('1A<G9I='1A=F%T('1I961O="!O=F%T(';DY')I;BX@67)I=.0@=75D
M97-T86%N('1A:2!O=&$@>6AT97ET=.0@>6QLY'!I=&]O;B!J;W,@=&%R=FET
M<V5T(&QI<^3D(&%P=6$N`$5I('9O:71U(&AA:V5A($%#3"UT:65T;VIA`$5I
M('9O:71U(&AA:V5A(&]S;VET96MI<FIA82X@)7,`16D@=F]I='4@:&%K96$@
M:F%K96QU;&ES=&%A+B`E<P!%:2!V;VET=2!H86ME82!J86ME;'5L:7-T;VIA
M+B`E<P!%:2!V;VET=2!H86ME82!T:65T;VIA('!A;'9E;&EM96X@=&]I;6EN
M;F]I<W1A`$5I('9O:71U('!A;&%U='1A82!A<V5T=6MS:6$N`$MO;65N=&\@
M<FUD:7(@(B5S(B!E<.1O;FYI<W1U:2X`16D@=F]I='4@=&%L;&5T=&%A("5S
M(&%S971U:W-I82X`16D@=F]I='4@=&%L;&5T=&%A(&%S971U<W1E;B!V87)M
M=75S:V]P:6]T82X`16D@=F]I='4@=&%L;&5T=&%A(&%S971U<W1E;B!V87)M
M=75S:V]P:6]T82`E<P!%:2!V;VET=2!T86QL971T86$@87-E='5S<.1I=FET
M>7-S:W)I<'1IY#H@(B5S(BX`16D@=F]I='4@=&%L;&5T=&%A(&%S971U<W1E
M;B!V87)M=75S:V]P:6]T82`E<RX`07-E='5S=&EE9&]S=&]N("5S('1A;&QE
M='5S(&5PY&]N;FES='5I+B!6;VET(&OD>71TY.0@:F]T86MI;B!A<V5T=7-T
M82!T86QL971T86%K<V5S:2!K;V]D:6X@=&%K86ES:6X@)7,@=&%I('1A:2!K
M;W!I;VED82!KY'-I;B!A;&QA(&]L979A;B!K;V]D:6X@=&EE9&]S=&]O;B`E
M<RX`3$1!4"UP86QV96QI;65L=&$@96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD
M+@!+;VUE;G1O('5N;&EN:R`B)7,B(&5PY&]N;FES='5I+@!%:2!V;VET=2!P
MY&EV:71TY.0@>6AT97ES=&EE=&]J82X@)7,`16D@=F]I='4@<.1I=FET=.3D
M(&IA:V5L=6QI<W1A82X@)7,`5FEE<W1E:N0@96D@=F]I='4@<&]I<W1A82!K
M86YS:6]S=&$@(B5S(CH@)7,`36]Z:6QL82!3:61E8F%R(&5I(&SV>71Y;GET
M+B!687)M:7-T82!E='3D(%-I9&5B87(@;W-I;R!O;B!A=6MI+@!+Y'ET=.1J
MY&QL92`B)7,B(&5I('9O:71U(&%N=&%A('-E=7)A879I82!O:6ME=7-I82!K
M86YS:6]O;B`B)7,B.B`E<P!,87-K971T=2!T96MS=&D`36%A`$MU<G-S:70`
M3'5O`$QU;R!U=7-I(&QI;FMK:0!,=6\@=75S:0!6;VD@;'5O9&$@=75S:6$@
M:V%N<VEO:71A`$QU;W1U`$]I:V5U9&5T('1E:VEJY&QLY`!,=6]T=&]K;W)T
M:6YN=6UE<F\`2W)O871I80!+=75B80!4Y&WD;FAE=&MI;F5N(#0@=F%I:&5T
M=&$`5.1MY&YH971K:7-E="!I<W1U;FYO=`!+96QL;VYA:6MA('3D;&SD(&AE
M=&ME;&SD`%3D;>1N:&5T:VEN96X@55),(&]N`%3D;>1N:&5T:VES970@:^1Y
M='3D:N1T`%3D;>1N:&5T:VEN96X@<^3D`%3D;>1N:&5T:VEN96X@=&EL83H@
M`%3D;>1N:&5T:VEN96X@='EY;&D`5F]I="!M=6]K871A('1E:'3D=FGD+"!J
M;W1K82!S=6]R:71E=&%A;B!K=6X@:VER:F%U9'5T86%N('-I<^3D;B!O:&IE
M;&UA86X@)7,N`$QE:6MK86$`3&5I:VMA82!V86QI='1U`$MY<')O<P!+>7)I
M;&QI;F5N("A+3TDX+5(I`$MY<FEL;&EN96X@*%=I;F1O=W,M,3(U,2D`2WER
M:6QL:6YE;B]5:W)A:6YA("A+3TDX+54I`%1S96MI;B!T87-A=F%L=&$`4%``
M1%-.("AL:7/D=&EE=&]A(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N
M+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`4.1I=FET=.1I
M;@!$871A5')E92US96QA:6X`5&EE=&]K86YT86AA:W4`4.1I=N1Y<P!0Y&EV
MY&WDY'+D('9A<W1A86YO=&5T='4`4.1I=N1MY.1RY&X@=F%L:6YT80!0Y&EV
MY`!0;U]I<W1A('-A<F%K90!J;W5L=6MU=0!$97-I;6%A;&EN=6UE<F]T`%!I
M96YE;F[D('-I<V5N;GES=.0`3VQE='5S`$]L971U<W;D<FD`3VQE='5S<')O
M9FEI;&D`3VQE='5S;75I<W1I;&ES=&$`3VQE='5S(&MO;65N=&]T=6QK:VD`
M3VQE='5S:N1R:F5S='ES.@!/;&5T=7-JY')J97-T>6MS96X@<W5U;G1A.@!-
MY.1R:71E;&WD=`!0;VES=&$`4&]I<W1A('-O;'4`4&]I<W1O;B!V87)M:7-T
M=7,`4&]I<W1A(')Y:&WD`%!O:7-T82!L;VMI`%!O:7-T82!O:6ME=7,`5F]I
M('!O:7-T86$@:F$@='5H;W1A('!O:7-T971T=6IA('9I97-T96KD`%9O:70@
M;75U='1A82!0;VES=&$@<&%I;FEK:V5E;B!T;VEM:6YT86$`4&]I<W1A('-O
M;'4`4&]I<W1A('-A<F%K90!0;VES=&$@;VQE;6%S<V$@;VQE=F%T('9A:6AT
M;V5H=&]I;F5N(&UA;&QI`%9O:2!P;VES=&%A('9I97-T96KD`%!O:7-T82`B
M)7,B.FX@;VEK975K<VEA`$]L971K;R!V87)M82P@971TY"!H86QU870@<&]I
M<W1A82`B)7,B(&IA(&MA:6MK:2!S96X@86QI;VEK975D970_`%!O:7-T82!R
M:79I`%!O:7-T82!V86QI='1U('!R;V9I:6QI`%9O:2!L=6]D82!U=7-I82!K
M86YS:6]I=&$`4&]I<W1A('9A;&ET='4@<V%R86ME`%!O:7-T82!V86QI='1U
M(')I=FD`4&]I<W1A('3D;>0@;75I<W1I:6YP86YO`%!O:7-T971T=2!PY&EV
M:71Y<W-K<FEP=&D@(B5S(BX`5&]I;6ET=7-A:6MA`%1A;G-K80!,87-K979A
M`$]N9V5L;6%N(&MU=F%U<P!+=79A=7,`2W5V875S.@!487)K96UM870@=&EE
M9&]T("AL]GET>7;D="!M>?9S($AO<F1E.FX@;&]K:71I961O<W1O<W1A*3H`
M5&%R:V5M;6%T('1I961O="!O;B!T86QL971E='1U('EL;.1P:61O;B!KY'-I
M=&5L=.1VY&MS:2X`2V5H:71Y<P!+;W-T975S<&ES=&4`161E;&QI<V5N('1U
M;FYI;B!K;W-T975S<&ES=&4Z(`!+;W-T975S<&ES=&4Z(`!3=75N=&$@=F%S
M96UM86QT82!O:6ME86QL90!3=75N=&$@;VEK96%L=&$@=F%S96UM86QL90!(
M86ME;6ES=&\`2^1Y=.0@,C0M='5N;FEN(&%I:V%E<VET>7-TY"X`3N1K>6WD
M;B!A<V5T=6MS970`17-I='ES=&%P82!Y:W-I='EI<VMO:'1A:6YE;B!E;FYU
M<W1E`$5S:71Y<W1A<&$@96YN=7-T965L;&4@*%1!1BD`17-I='ES=&%P80!0
M97)I;&QE;65N;VEL;6]I='5S`$1J:6)O=71I`$5I('-A82!P;VES=&%A`,1L
MY"!KY'ETY"!S=6]R86%N(&UA:6YT96YA;F-E+G!H<#ITY`!(86QU871K;R!V
M87)M:7-T=6MS96X@<&]I<W1E='1A=FES=&$@;65R:VEN;O9I<W3D/P!*;W,@
M96YS:6UMY&EN96X@<FEV:2!S:7/D;'3DY"!S87)A:VME:61E;B!O='-I:V]T
M+"!N:6EN('9A;&ET<V4Z`$1O;6EN:6MA86YI;F5N`$1O;6EN:6MA86YI;F5N
M('1A<V%V86QT80!%:6OV(&]L92!KY'ET=.1JY'1U;FYU<W1A/R!+:7)J875D
M=2!KY'ET=.1JY&MS:2X`5&%L;&5N;F$`5&%L;&5N;F$@)7,`5&%L;&5N;F$@
M;'5O='4@87-E='5S(%!(4"US:W)I<'1I;N0N`$%L87-V971O=F%L:6MK;P!(
M=75M965T`%/D:&OV<&]S=&EO<V]I=&4`14UA:6PM=&\M4TU3(&=A=&5W87D@
M86IU<FDL(&YI:6QL92!P86QV96QU;G1A<FIO86II;&QE+"!J;W1K82!T87)J
M;V%V870@=.1TY"!P86QV96QU82X`5DE22$4`16-U861O<@!-=6]K:V%A`$UU
M;VMK86$@(B5S(@!-=6]K:V%A(&]S:6]T80!-=6]K:V%A(')Y:&WDY`!-=6]K
M:V%A(&UU:7-T:6EN<&%N;V$`375O:VMA82!O:6ME=71T80!-=6]K:V%A(&]I
M:V5U:W-I80!-=6]K:V%A("<E<R<Z;B!O:6ME=6MS:6$`375O:VMA82!K871E
M9V]R:6]I=&$@:F$@=N1R96KD`$UU;VMK86$@87-E='5K<VEA.@!-=6]K:V%A
M("(E<R(Z;B!O:6ME=6MS:6$`375O:VMA82`E<SIN(&]I:V5U:W-I80!+;W5L
M=71U<P!%9WEP=&D`16P@4V%L=F%D;W(`16QE;65N='1I+BXN`$5M`%/D:&OV
M<&]S=&D`4^1H:_9P;W-T:6]S;VET90!3Y&AK]G!O<W1I;W-O:71T96ED96X@
M<&ETY.0@;VQL82!S86UA="X`4^1H:_9P;W-T:2!V87)M:7-T=6MS96QL80!%
M;6%I;"UT;RU335,@1V%T97=A>0!(>6UI]G0`5'EH:N0@;75I<W1I:6YP86YO
M`%1Y:&KD('9I97-T:2X`5'EH:N0@=F%S=&%U<RX`5'EH:N0@:&%K=71E<FUI
M`%-A;&QI(&MU=FEE;B!L86ET=&%M:6YE;B!K=79A9V%L;&5R:6%S=&$@=&5K
M<W1I;B!J;W5K:V]O;BX`3&%I=&$@<.3D;&QE(&]I:V5A;B!P86EN:6MK965N
M(&MO;G1E:W-T:6UE;G4N`%#DY'1T>6UI<W9U;W-I`%-U=7)E;FYA(&5D:71O
M<FEA`$%N;F$@:WES>6UY<R!J;VMA(&MY<WETY.1N+"!J;W,@<V%L87-A;F%S
M:2!J;W5D=71A86X@;F]L;&%A;6%A;B!E<VEM97)K:6MS:2`G;6EKY"!O;B!L
M96UM:6MK:7-I(&YI;6D_)SH`3&%I=&$@:W5V82!54DP@=.1HY&X`06YN82!K
M:7)J86EM970@86QL93H`16MV871O<FEA86QI;F5N($=U:6YE80!%<FET<F5A
M`%9I<FAE`%9I<FAE('#D:79I=&5T=.1E<W/D(&]S:6]T83H@)7,`5FER:&4@
M<.1I=FET971TY&5S<^0@<WEN8R!A;F-H;W(@+71I971O83H@)7,`5FER:&4@
M<&]I<W1E='1A97-S82!S>6YC(&QO:VEA.B`E<P!6:7)H92!H865T=&%E<W-A
M('-I<^1L=/;D.B`E<RX`5FER:&4@<.1I=FET971TY&5S<^0@<V%L87-A;F%A
M.B`E<P!6:7)H92!SY&AK]G!O<W1I=FEE<W1I<W/D+@!6:7)H92!K:7)J;VET
M971T865S<V$@(B5S(BX`165S=&D`171I;W!I80!%=&YI;F5N`$5U<F]O<'!A
M`#$U(&UI;G5U=&EN(';D;&5I;@`R(&UI;G5U=&EN(';D;&5I;@`S,"!S96MU
M;FYI;B!VY&QE:6X`-2!M:6YU=71I;B!VY&QE:6X`2F]K86ES96QL82!S:7/D
MY&YK:7)J875T=6UI<V5L;&$`4'5O;&5N('1U;FYI;B!VY&QE:6X`36EN=75T
M:6X@=N1L96EN`$5S:6UE<FMK:6%R=F]T.@!3=6]R:71A`$QA86IE;FYA`$QA
M86IE;FYA('-I=G5V86QI:VMO`$]D;W1E='1I:6X@;65R:VMIY"`G*2<`4V%N
M82!S96QL86ES96YA86X@=&%I(&AA:W5T97)M:2!L86EN875S;65R:V5I<W/D
M`$QO<'!U<.1I=N1MY.1RY`!%:W-P;VYE;G1T:0!6:64`5FEE(&UU:7-T:6EN
M<&%N;W0`1D<@=N1R:0!!<V5T=7-T:65D;W-T;VIE;B!T=6]N=&D@1E10.FQL
MY`!47V5K<W1I(&MO:V]N86ES=75D97-S86%N`$%S971U<W1E;B!H86MU(&5P
MY&]N;FES='5I+@!9:'1E>7,@3$1!4"UP86QV96QI;65E;B!E<.1O;FYI<W1U
M:2X`66AT97ES(%--0BUP86QV96QI;65E;B!E<.1O;FYI<W1U:2X`2V]P:6]I
M;G1I("(E<R(Z;'3D(&5PY&]N;FES='5I+@!+;W!I;VEN=&D@(B5S(CIL;&4@
M97#D;VYN:7-T=6DN`%5U9&5N(%-!4TPM>6AT97ED96X@;'5O;6EN96X@97#D
M;VYN:7-T=6DN`%-I:7)T;R`B)7,B.N3D;B!E<.1O;FYI<W1U:2X`4VEI<G1O
M(&5PY&]N;FES='5I.B`E<P!+875N:7,`1F%L:VQA;F1I;B!S86%R970@*$UA
M;'9I;F%S*0!&Y'(@<V%A<F5T`%9A:V%V82!V:7)H93H`1F%K<VD`1F%K<VET
M`&AE;&UI:W5U`%1U;G1U=2!K=6EN`%1U;G1U=2!K=6EN.B``375U=&%M:6$@
M<V%T96ET80!-=75T86UI82!L=6UI<V%T96ET80!+96YT=.1M871R:6ES:0!&
M:6=L970@0T%05$-(00!&:6=L970@:VER:F%S:6X`1FED>FD`5&EE9&]S=&\`
M5&EE9&]S=&]J96X@;'5K=6WDY'+D.B`E<R!T:65D;W-T;P!4:65D;W-T;VIE
M;B!L=6MU;>3D<N0Z("5S('1I961O<W1O80!4:65D;W-T;VIE;B!KY'-I='1E
M;'D`5&EE9&]S=&]N(&YI;6D`5&EE9&]S=&]N('9A;&EN=&$`5&EE9&]S=&]N
M('1U;VYT:0!4:65D;W-T;VIE;B!T=6]N=&D@96D@;VQE(&OD>71E='3D=FES
M<^0N`%-U;V1A='1I;65T`%-U;VUI`$5N<VEM;>1I;F5N('!U;VQI<VMO`$5N
M<VEM;>1I;F5N(&YE;&KD;FYE<P!+;W)J86$@<W5H9&4`2^3D;F[D('EM<.1R
M:0!+96QL=79A`%-U;74`2V%N<VEO=&$@)7,@96D@;VQE(&]L96UA<W-A+@!+
M:7)J87-I;65N(';D<FD`4G5O:V$`4V5L86EM:6QL92P@:F]T:V$@96EVY'0@
M='5E(&MU=FEA`$5N;G5S=&4@*%1!1BD`16YN=7-T971T879A="!V=6]R;VMA
M=61E="`H2'5O;6%A=&AA;B!E='3D(&5N;G5S='5K<V5S<V$@;VX@=&EE9&]T
M('-E:^0@<.1I=FES=.0@971TY"#V:7-TY"P@:F]T96X@<W5U<FD@;>3D<N0@
M<.1I=FGD(&%I:&5U='1A82!L:6EA;B!L979EY&X@;W-I;VXI`%5N;VAD:71K
M;R!S86QA<V%N87-I/P!,;VUA:VME970`36EE=&5L875S90!-:65T96QA=7-E
M96X@='EY<'!I`$UI971E;&%U<V5E=`!-:65T96QA=7-E970@,@!&;V]R=6UI
M=`!5=61E;&QE96YO:&IA=6MS970`<&4`2V5H>6MS970`4F%N<VMA`%)A;G-K
M82P@365T<F]P;VQI`%)A;G-K86X@1W5Y86YA`%)A;G-K86X@4&]L>6YE<VEA
M`%)A;G-K86X@971E;.1I<V5T('1E<G)I=&]R:6]T`$SD:&5T=.1JY`!3=75N
M;F%S=&$@`%!I9&5M<&D@:W5V875S.@!4Y'ES:6MU=0!+;VMO(&YI;6D`1V%B
M;VX`1V%L;&5R:6$L(&IO<W1A(&MU=F$@;W1E=&%A;@!'86QL97)I83H`1V%M
M8FEA`%EL96ES970@87-E='5K<V5T`%1E92`E<R!A<V5T=6MS970`1V5N97)O
M:71U(&MO;V1I`$=E;W)G:6$`4V%K<V$`1VAA;F$`1VEB<F%L=&%R`$5T=6YI
M;6D`66QE:7-E="!A<V5T=6MS970`365N90!']F1E;`!';V]G;&4@2V%R=&%T
M`$=O;V=L92!H86MU`$AA<FUA87/D=GD`2W)E:6MK80!+<F5I:VMA("A)4T\M
M.#@U.2TW*0!'<O9N;&%N=&D`1W)E;F%D80!2>6AMY&X@>6QLY'!I=&\`4GEH
M;6EE;B!N:6UE="!E:7;D="!S86$@;VQL82!T>6AJ:>0`1W)O=7!?;&1A<#H@
M16D@=F]I9&$@;&ESY'3D(&OD>71TY&KDY"`E<RX@4&%L=F5L:6UE;B!V:7)H
M96EL;6]I='5S(&]L:3H@`$=R;W5P7VQD87`Z($5I('9O:61A('#D:7;D='3D
MY"!KY'ET=.1JY.0@)7,`1W)O=7!?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D
M(&OD>71TY&KDY"`E<P!2>6AMY'0`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L
M80!'=65R;G-E>0!6:65R86EL:6IA;B!O:6ME=61E=`!6:65R87-K:7)J80!'
M=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!P96QK
M=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!R:79I;B!V:6EM
M96ES=.0@<V]L=6$N`$A434Q!<F5A('!E;&MU<FEM86ES97-T:2!K:65L=.1Y
M='EY('!O:7-T86UA<W1A('9I:6UE:7-TY"!S87)A:V5T=&$@=&%U;'5K;W-T
M82X`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET>7D@<&]I<W1A
M;6%S=&$@=FEI;65I<W3D(')I=FGD('1A=6QU:V]S=&$N`$A45%`M875T96YT
M:6MO:6YT:6$@96D@;/9Y='EN>70N`$AA:71I`$AA<V@M86QG;W)I=&UI`%5S
M=F$`3W1S86ME`$]T<V%K90!(96%R9"!J82!-8T1O;F%L9"!S86%R970`5F]I
M;6%K87,@=6MK;W-M>7)S:WD`2&5P<F5A("A)4T\M.#@U.2TX+4DI`$MO<FME
M=7,`3VAJ90!!<'5A(&5D:71O<FEN(&OD>71T]O9N`$]H:F4`4&%L;&]N<'5O
M;&ES:V\Z`%3D<W/D(&]N('1I961O<W1O;B!A;&MU;W-A.@!+;W)K96$`2V]?
M=&D`4'EHY"!I<W1U:6X@*%9A=&EK86%N:6X@:V%U<'5N:VEV86QT:6\I`$MO
M=&D`2V]T:6]S;VET90!+;W1I:&%K96UI<W1O`%!U:&5L:6X@*&MO=&DI`$AO
M;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@17#D:V5L<&]A
M("5S(%A-3"UD871A82!V:65S=&ES<^0@)7,`2&]R9&4O2V]L86(Z(%EK<VEK
MY.1N('9I97-T:2!E:2!V87-T86$@;V)J96MT:6$@)7,`2&]R9&4O2V]L86(Z
M(%EH=.1KY.1N(&]B:F5K=&EA("5S(&5I(&SV>71Y;GET('9I97-T:7-TY"`E
M<P!(;W)D92]+;VQA8CH@4&]I<W1E='1I:6X@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@26YT96=R86%T:6]K;VYE('9A871I:2!T;VEM:6%K<V5E;B`G9&]M>&UL
M)R!02%`M;&%A:F5N;G5K<V5N`$AO<F1E+TMO;&%B.B!%:2!V;VED82!L=6]D
M82!U=71T82!834PM<'5U=&$@;V)J96MT:6QL92`E<P!(;W)D92]+;VQA8CH@
M16D@=F]I='4@<&]I<W1A82`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@16D@
M=F]I9&$@:&%K96$@34E-12!)1#KD(&]S:6]L;&4@='EY<'!IY"`E<P!(;W)D
M92]+;VQA8CH@16D@=F]I('-Y:W)O;F]I9&$@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z($5I('9O:61A('-Y;FMR;VYO:61A(&IA:V]J83H@)7,`2&]R9&4O
M2V]L86(Z(%1U;G1E;6%T;VX@:F%K;R`B)7,B`%9A86MA<W5O<F$@<^3D;G3V
M`%9A86MA<W5O<F$@=.1Y=&4`5F%A:V%S=6]R83H`36ET96X@='5L:70@=.1N
M;F4_("A287!O<G1O:2!K:6ET;W,A*0!+=6EN:V$@;6]N=&$@<V%R86ME='1A
M(&AA;'5A="!Y:&1I<W3DY#\`2V5N='1I96X@*'-A<F%K:V5I9&5N*2!L=6MU
M;>3D<N0N`$MU:6YK82!M;VYT82!R:79IY"!H86QU870@>6AD:7-TY.0_`$MO
M<W1E=7,`2V]S=&5U<SH@`$AU;6]R:7-T:70`56YK87)I`$E-05`M<&]S=&EL
M86%T:6MO;B!L=6]N=&D@97#D;VYN:7-T=6DZ("5S`$E-05`M<&]S=&EL86%T
M:6MO;B!P;VES=&\@97#D;VYN:7-T=6DZ("5S`$E-05`M<&]S=&EL86%T:6MO
M;B!K:6EN=&GV;B!L=6]N=&D@97#D;VYN:7-T=6DZ("5S`$E0+6]S;VET90!)
M4"UO<V]I=&4@96D@;VQE(&OD>71E='3D=FES<^0N`$E0+6]S;VET92!E:2!O
M;&4@<V%L;&ET=6X@0TE$4BUB;&]K:6X@<VESY&QLY`!)4"USY.1N;O9S=/9N
M(')I:VMO;75S`$Q?86ET82!R:79I(&5N;F5N`$ES;&%N=&D`5F%I;B!I:V]N
M:70`26MO;FET("5S.FQL90!):V]N:70@:F$@=&5K<W1I`%!R;V9I:6QI;B!N
M:6UI.@!*;W,@<VEV=2!E:2!NY'D@:W5N;F]L;&$L(&YI:6X@875K86ES92`E
M<R!E<FEL;&ES97-SY"!I:VMU;F%S<V$N`$IO<R!E="!NY&4@:6MO;F5I=&$@
M:^1Y='3D97-SY'-I($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;G1A+"!N:6EN
M('-I;G5N('!I=.3D(&]T=&%A('!O:7,@<.3D;'3D(%!.1R!LY'!I;N1K>79Y
M>7,@<F%S=&ET=&%M86QL82!TY&WD(&QA871I:VMO+@!*;W,@;N1E="!TY&WD
M;B!V:65S=&EN+"!M=71T82!E="!K=79A82P@;FEI;B!T=6]M86%S:2!K=79A
M82!E:2!V;VD@;N1Y='3DY"!KY'ET=.1MY'-SY'-I('-E;&%I;65S<V$N`$MU
M=FEE;B!E<VEK871S96QU`$MU=F$@55),`$MU=F$@55),.@!+=79A(&=A;&QE
M<FEA<W1A`$MU=F$@9V%L;&5R:6%S=&$Z`$MU=F%N('9I96YT:0!+=79A=`!6
M:65S=&EE;B!T=6]N=&DL(&%S:V5L("5D`%1U;VYT:2P@87-K96P@)60`5'5O
M+U9I92!M=6ES=&EI;G!A;F]T`%1U;W1U(&ME;G1TY#H@)7,`5'5O9'5T(&ME
M;G3D=#H`3&%?:71A(')I=FD@:N1L:V5E;@!6Y.1RY"!T;VEM:6YT;VMO;V1I
M(&%N;F5T='4N`$OD>71TY&KD='5N;G5S('1A:2!S86QA<V%N82!O;B!VY.1R
M:6XN`%;DY'+D(&OD>71TY&KD='5N;G5S('1A:2!V86EH=&]E:'1O:6YE;B!O
M<V]I=&4N(%ER:73D('5U9&5S=&%A;B!J82!O=&$@>6AT97ET=.0@>6QLY'!I
M=&]O;B!J;W,@=&%R=FET<V5T(&QI<^3D(&%P=6$N`$QI<^3D('-I<V5N;GES
M=.0`26YT:6$`66MS:71TY&ES970@:^1Y='3D:N1T`$EN9&]N97-I80!);F9O
M`$EN9F]R;6%A=&EO`%1I971O82!E:2!O;&4@96[DY"!S86%T879I;&QA+@!,
M86ET82!S7V%R86ME(&KD;&ME96X`3&%I=&$@:W5V80!,86ET82!T875L=6MK
M;P!,86ET82!W=W<M;&EN:VMI`$QA:71A(%]S87)A:V4@96YN96X`3&%I=&$@
M=75S:2!S87)A:V4@;GEK>6ES96X@:N1L:V5E;@!,86ET82!U=7-I('-A<F%K
M92!E;FYE;B!N>6MY:7-TY`!,86ET82!U=7-I(')I=FD@;GEK>6ES96X@:N1L
M:V5E;@!,86ET82!U=7-I(')I=FD@96YN96X@;GEK>6ES=.0`3&%I=&$@:V%P
M<&%L92!N>6MY:7-E;B!N;V1E;B!JY&QK965N`$QA:71A(&MA<'!A;&4@96YN
M96X@;GEK>6ES=.0@;F]D96$`3&%I=&$@=F%I:'1O96AT;VEN96X@;6%L;&D`
M06YN82!SY&AK]G!O<W1I;W-O:71E(&IO:&]N('5U<VD@<V%L87-A;F$@;.1H
M971E=.3D;CH`3&%I=&$@<V]L=2!JY&QK965N`$QA:71A('-O;'4@96YN96X`
M3&%I=&$@<V]L=2!JY&QK965N`$QA:71A('-A<F%K92!E;FYE;@!6;VD@;&%I
M='1A82!V:65S=&5JY`!,86ET82!K87!P86QE(&KD;&ME96X`3&%I=&$@:V%P
M<&%L92!E;FYE;@!,86ET82!R:79I(&5N;F5N`$QA:71A(')I=FD@:N1L:V5E
M;@!!;FYA('9A861I='1A=F$@=F%S=&%U<R!T=7)V86MY<WEM>6MS965N.@!,
M:6ETY"]-=6]K:V%A(&MU=FEA`$QI:73D+TUU;VMK86$@;&EN:VMIY`!3:6YU
M;&QA(&5I(&]L92!T87)P965K<VD@:W)E9&EI='1E:N0@;.1H971TY.1K<V5S
M:2!V:65S=&EN(&IA:V5L=6QI<W1A;&QE+@!2:6ET=.1MY'1T]FWD<W1I(&MR
M961I:71T96KD`$MO:V]N86ES;'5K=0!+;VMO;F%I<VQU:W5L:7-T80!%<.1K
M96QP;R`@541(("A5<V5R($1A=&$@2&5A9&5R*2X`17#D:V5L<&]A(%I)4"UT
M:65T;V$N`$5PY&ME;'!O(&]H:F5L;6$N`$5PY&ME;'!O(&)A=&-H($E$+@!,
MY&AE=&5T=&EI;B!E<.1K96QP;V$@=&EE=&]A+@!%<.1K96QP;R!V87-T86%N
M;W1T86IA;B!O<V]I=&4N`$5PY&ME;'!O('1I961O<W1O;75O=&\`17#D:V5L
M<&\@;&ES96YS<VEA=F%I;BX`17#D:V5L<&\@<&%I:VMA=&EE=&\N`$5PY&ME
M;'!O(&US9U]T>7!E("X`17#D:V5L<&\@=&%I('!U=71T=79A(&%P:5]I9"X`
M17#D:V5L<&\@=&%I('!U=71T=79A('!A<F%M971R:2X`17#D:V5L=F]T(&]I
M:V5U9&5T('EL96UMY&QLY"!T87-O;&QA+@!%<.1K96QP;R!P87)N97(@:60N
M`$5PY&ME;'!O('1U;W1E:V]O9&DN`$5PY&ME;'!O('!R;W1O:V]L;&$N`$5P
MY&ME;'!O('9A<W1A86YO='1A:F$Z("(E<R(`17#D:V5L<&\@:F%K;RUO8FIE
M:W1I`$5PY&ME;'!O(&SD:&1E;W-O:71E+@!%<.1K96QP;V$@=6YI8V]D92UT
M:65T;V$N`$EN=F5N=&%A<FEO`$ODY&YNY"!V86QI;G1A(&ODY&YT96ES96MS
M:0!)<F%N+"!)<VQA;6EL86EN96X@=&%S879A;'1A`$ER86L`27)L86YT:0!-
M86XM<V%A<FD`17)I;&QI<VGD(%5K:V]S;7ER<VMY:N0`27-R865L`$QI:6MK
M965L;&5L87-K:6IA`$MU<G-I=F]I='4`271A;&EA`$IA;6%I:V$`=&%M;6EK
M=74`2F%P86YI`$IA<&%N:2`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YI
M80!H96ENY&MU=0!K97/D:W5U`$ME<VMI=.0`2V5S:VETY"!K97-K96QL90!+
M97-K:73D('3D>7-I;@!+97-K:73D('9A<V5M;6%L;&4`2V5S:VETY"!O:6ME
M86QL90!+87IA:W-T86X`4^1I;'ETY"!A;&MU<&5RY&EN96X_`$ME;FEA`$%U
M=&5N=&EK;VEN=&D@97#D;VYN:7-T=6D@2V5R8F5R;W,M<&%L=F5L:6UE;&QE
M+@!+97)N96P@86QO:71T96QI:F%T`$%V86EM96X@;'5O;G1I`$%V86EM96X@
M='5N;FES=&4`079A:6UE;B!P:71U=7,`079A:6UE;B!T>7EP<&D`079A:6UE
M;B!KY'ET=/8`079A:6X@;VX@:F\@:G5L:VES=&5N(&%V86EN=&5N('!A;'9E
M;&EM96QL80!,87!S970`2VER:6)A=&D`2V]R96$L(&1E;6]K<F%A='1I;F5N
M(&MA;G-A;G1A<V%V86QT82`H4&]H:F]I<RU+;W)E82D`2V]R96$L('1A<V%V
M86QT82`H171E;.0M2V]R96$I`$MO<F5A("A%54,M2U(I`$MU=V%I=`!+:7)G
M:7-T86X`07-?971T96QU`$MI96QI`$QA;W,L(&1E;6]K<F%A='1I;F5N(&MA
M;G-A;G1A<V%V86QT80!*Y&QK:6UMY&EN96X@<'5O;&ES:V\`375O:V%T='4@
M=FEI;65K<VD`161E;&QI;F5N('-A;&%S86YA;G9A:6AT;P!*Y&QK:6UMY&EN
M96X@;F5L:N1N;F5S`%#D:79I=&5T='D@=FEI;65K<VDZ`$5D96QL:6YE;B!S
M:7/DY&YK:7)J875T=6UI;F5N.B`E<P!%9&5L;&EN96X@<VESY.1N:VER:F%U
M='5M:6YE;CH@)7,L("5S`$5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI;F5N
M.B!%:2!M:6QL;VEN:V%A;@!,871V:6$`3&%K:0!!<V5T=&5L=0!*Y'3D('1Y
M:&KD:W-I(&IO<R!E:2!R975N;VIA`$QI8F%N;VX`5F%S96X`5F%S96X@;W1S
M86ME`%9A<V5N(&%R=F]T`$QE<V]T;P!487-O`$QI8F5R:6$`3&EB>6$@07)A
M8B!*86UA:&ER:7EA`$QI8VAT96YS=&%I;@!+979Y='3D('+D;G3DY`!+:7)J
M875D=2!S:7/DY&X`2V5V>71TY"!S861E='1A(&%I:V%I<VEN`$ME=GET=.0@
M<V%D971T82!M>?9H96UM:6X`2V5V>6ETY"!S861E:W5U<F]J80!+979Y='3D
M('-A9&5T=&$@:F$@;7ER<VMY:7-TY`!+979Y='3D(&QU;6ES861E='1A`$ME
M=GEI=.0@;'5M:6MU=7)O:F$`3&EM97)I:VET`$QI;FMK:0!,:6YK:VD@;W-O
M:71T86$Z`$QI;FMI=.0@<^1H:_9P;W-T:6]S;VET92!K:7)J;VET82!U=7-I
M('9I97-T:2!S:79U;&QE(&[D:WEMY'-SY`!,:6YK:70`3&EN=7@@<&EP87)E
M:71A`%9O:2!L:7-T875K<V5S<V$@;N1H9.0@:V%N<VEO;@!.Y'ETY"!T:65T
M;VMA;FYA=`!.Y'ETY"!O:&IE:61E;B!A:6AE970`3N1Y=.0@=&%U;'5T`$QI
M<W1A;BU!<FMI<W1O`$QI<W1A;BU/:&IE`$QI<W1A;BU)9`!,:7-T86XM3VUI
M<W1A:F$`3&ES=&$M=FEE<W1I`$QI<W1A;BU4:6QA=7,`3&ES=&%N+51I;&%U
M:W-E;BUL;W!E='1A;6EN96X`27-T=6YT;VIE;B!L:7-T875S(&5PY&]N;FES
M='5I.B`E<P!+Y'ET=.1J:65N(&QI<W1A=7,@97#D;VYN:7-T=6DZ("5S`$OD
M>71TY&KD=&EE=&]J96X@;N1Y='3D;6EN96X@;VX@97-T971T>2X`2VER:F%L
M;&ES=75S`$QI971T=6$`3&%D871A86XN+BX`4&%I:V%L;&ES=&$@86EK86$Z
M(`!,;VMA;&ES86%T:6\@:F$@86EK80!086EK:V$`2VER:F%U9'4@<VESY.1N
M`$5D96QL:7-E;B!S>6YK<F]N;VEN=&ES97-S:6]N(&QO:VD`2VER:F%U9'4@
M=6QO<P!+:7)J875D=2!S:7/DY&X`5&5H=.1VY'0@<VESY.1N:VER:F%U='5M
M:7-E<W-A`%-I<^3D;FMI<FIA=71U;6ES97-I(&5PY&]N;FES='5I+B!4;V1E
M;F[D:_9I<V5S=&D@:VER:F]I=&ET(';DY')I;B!KY'ET=.1JY'1U;FYU:W-E
M<VD@=&%I('-A;&%S86YA<VDN`%-I<^3D;FMI<FIA=71U;6EN96X@97#D;VYN
M:7-T=6DN`%!I=&OD('1E:W-T:0!286MK875S`$UA=&%L80!0:65N970@:W)E
M:6MK86QA:7-E="!K:7)J86EM970`4&EE;F5T(&QA=&EN86QA:7-E="!K:7)J
M86EM970`4&EE;F5T(')O;VUA;&%I<V5T(&YU;65R;W0`3'5X96UB=7)G`$M+
M`$U/5$0`35,M5$Y%1B!L:6ET971I961O<W1O(&]L:2!T>6AJY"X`5DE%4U1)
M`$UA8V%O`$UA:V5D;VYI82P@16YT:6YE;B!*=6=O<VQA=FEA;B!T87-A=F%L
M;&%N+@!-861A9V%S:V%R`%1A:6MU=7,`4^1H:_9P;W-T:0!0;W-T:6X@>6QL
MY'!I=&\`5&5E(&QI;FM?:VDN+BX`36%L87=I`$UA;&5S:6$`36%L961I:79I
M=`!0;W-T:0!-86QT80!6;VET(&AA;&QI;FYO:61A(&QI<W1A82!K871E9V]R
M:6]I<W1A+"!J;VED96X@879U;&QA('9O:70@;&EI='3DY"!A<VEO:71A('EH
M=&5E;B!S86UO:F5N(&]T<V%K:V5I9&5N(&%L;&4@:F$@;&EI='3DY"!N:6EH
M:6X@=N1R96KD+@!-87`R-"!K87)T=&$`36%P475E<W0@:V%R='1A`%9A<W1A
M879U=61E="!T86QL971E='1U+@!M86%L:7-K=74`36%R9VEN86%L:0!6;VD@
M;65R:VETY"!686YH82]5=7-I('1I971O:F$`5F]I(&UE<FMI=.0@=FEE<W1E
M:N0@*&5S:6TN(%3D<FMEY"]687-T871T=2D`36%R<VAA;&P@<V%A<F5T`$UA
M<G1I;FEQ=64`5.1S;>3D=N1T(&ME;G3D=`!-875R:71A;FEA`$UA=7)I=&EU
M<P!3=75R:6X@<V%L;&ET='D@:W)E9&EI='1I+@!3=75R:6X@<V%L;&ET='4@
M=FEE<W1I;W-I;VWDY'+D('EL:71E='1Y+@!%9&5L;&ES96X@,C0@='5N;FEN
M(&MO<FME:6X@;.1M</9T:6QA.B``161E;&QI<V5N(#8@='5N;FEN(&MO<FME
M:6X@;.1M</9T:6QA.B``375I<W1I:6YP86YO:F5N(&5N:6UMY&ES;>3D<N0`
M4&]R=&%A;&EO<VEO:61E;B!E;FEM;>1I<VWDY'+D`%-U=7)I;B!S86QL:71T
M=2!P:71U=7,`=&]U:V]K=74`36%Y;VYE='1E`$SDY&ME=&EE9&4`2N1S96YE
M=`!-=6ES=&EI;G!A;F]N('1E:W-T:0!-96YU;B!M=6]T;SH`66AD:7-TY"!S
M;VQU=`!6:65S=&D`5FEE<W1I;B!T87)K:7-T=7,@;VYN:7-T=6DL(&UU='1A
M(&%L;&5K:7)J;VET=&%J86X@=F%R;65N;F5T=&$@96D@=F]I='4@=&%R:VES
M=&%A+@!6:65S=&D@=F%N:&5N:2X`5FEE<W1I;B!T>7EP<&D`365T87(@<^3D
M`$UE=&%R+6]S:6\@96D@;VQE(&OD>71E='3D=FES<^0N`$UE=&%R+6]S:6\@
M96D@;VQE(&OD>71E='3D=FES<^0N(%1A<FME;6UA="!T:65D;W0@;VX@=&%L
M;&5T971T=2!Y;&SD<&ED;VX@:^1S:71E;'3D=N1K<VDN`$UE=&%R1$(@96D@
M;VQE('EH9&ES=&5T='DN`$UE=&]D:0!-971O9&EA("(E<R(@96D@;VQE(&WD
MY')I=&5L='D`365T;V1I82!E:2!O;&4@;>3D<FET96QT>2X@2W5T<W5V82!M
M971O9&DZ("5S`$UE=')I;F5N`$UE:W-I:V\`36EK<F]N97-I82P@66AD:7-T
M>6YE970@=F%L=&EO=`!+97-K96QLY`!-:6UE+71Y>7!P:0!%9&5L;&ES96X@
M,C0@='5N;FEN(&UA=&%L:6X@;.1M</9T:6QA.B``161E;&QI<V5N(#8@='5N
M;FEN(&UA=&%L:6X@;.1M</9T:6QA.B``4V%L87-A;F$@96D@;VQE('9I96SD
M('1A<G!E96MS:2!V86YH80!096EL:6MU=F$`4V5K86QA:7-E=`!014%2+7!A
M:V5T=&D@2%144%]297%U97-T('!U=71T=74N`%!U=71T=79A="!A<V5T=7-T
M:65D;W-T;RX@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5S=&EE9&]S=&\@:F]S
M(&AA;'5A="!KY'ET=.3D('3D=.0@;VAJ96QM86$N`%!U=71T=79A(&UE<W-A
M9V4@240N`%;D;'1TY&WD=/9N(%!%05(M<&%K971T:2!-86EL('!U=71T=74N
M`%!U=71T=79A('-E<W-I;VX@240N`&UA`$UO8FEI;&ESY&AK]G!O<W1I`$MO
M:'1A;&%I;F5N`$UU;VMK875K<V5N('#D:7;D;>3D<N0`375O:VMA82!54DPZ
M:6$`375O:V%T86%N("5S`$ME<G)O:6X`36]L9&]V82P@=&%S879A;'1A`$UO
M;F%C;P!-;VYG;VQI80!K=75K875S:2!J82!V=6]S:0!+=75K875S:71T86EN
M`$UO;G1S97)R870`2W5U;B!V86EH965T`%)I=FEL=.0@)60@;/9Y='EI(&5N
M96UMY&X@:V5N='1IY"!K=6EN(&]D;W1E='1U("5D+@!-87)O:VMO`$5N:6UM
MY&MS:2!S96QK9>3D`$5N:6UMY&MS:2!P:6QV:7-TY`!%;FEM;>1K<V5E;B!P
M:6QV:7-TY"!J82!T=75L:7-T80!%;FEM;>1K<V5E;B!A=7)I;FMO:7-T80!3
M:6ER<N0@86QA<W#D:6X`4VEI<G+D('9A<V5M;6%L;&4`4VEI<G+D(&]I:V5A
M;&QE`%-I:7)RY"!Y;/9S<.1I;@!3:6ER<N0@86QA<W#D:6X`4VEI<G+D('EL
M]G-PY&EN`$UO<V%M8FEK`$UO;FET87-O:6YE;B!A;&%S=F5T;W9A;&EK:V\`
M375L=&EM87`@27-O+4)R:71A;FYI86X@:V%R='1A`$UO;FEV86QI;G1A`$OD
M>71TY&KD='5N;G5K<V5N:0!/;6%N(&OD>71TY&KD='5N;G5K<V5N('1I961O
M=`!/;6$@;75I<W1I:6YP86YO;FD`3VUA('!O<G1A86QI`$]M86X@<&]R=&%A
M;&EN(&%S971T96QU`$UY86YM87(@*$)U<FUA*0!%22P@14X@<W5O<W1U`$YI
M;6D`3F%M:6)I80!.875R=0!.97!A;`!!;&%N:V]M86%T`$%L86YK;VUA:61E
M;B!!;G1I;&QI=`!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O
M8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E
M;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-3
M3"UP86QV96QI;65N(&]S;VET90!.971S8V%P92!V87)M96YT965N(&MO;6UE
M;G1T:0!.971S8V%P92!V87)M96YT965N('1Y>7!P:0!697)K:V\`16D@:V]S
M:V%A;@!5=7-I+4MA;&5D;VYI80!5=7-I(&QU;VMI='5S`%5U<VEK=74`575S
M:2!M=6ES=&EI;G!A;F\`575S:2!KY'ET=.1JY'1U;FYU<R`H=F%P86%E:'1O
M:6YE;BD`575S:2U3965L86YT:0!5=7-I('-A;&%S86YA`%5U<VD@<V%L87-A
M;F$@=F%N:&5N964@)7@N`$%N=&%M87-I('5U9&5T('-A;&%S86YA="!E:7;D
M="!TY'-MY.0N`%5U<VD@:6MK=6YA("A?8FQA;FLI`%5U=&ES970`2V5S:W5S
M=&5L=7)Y:&WD=`!3975R86%V80!3975R86%V870@-"!V86EH971T80!3975R
M86%V870@87-E='5K<V5T`%-E=7)A879A/@!.:6-A<F%G=6$`3FEG97(`3FEG
M97)I80!9]@!.:75E`$5I`$%S971U<W1I971O:F$@96D@;VQE('-A871A=FEL
M;&$L(&IO<W1A('9O:7-I(&[D>71TY.0@97)O879A:7-U=6MS:6$N`$5I(&]L
M92!S86%T879I;&QA('-U=6YN:71E;&UA82!)4T\@;&5V>6MU=F%T:65D;W-T
M;VIE;B!T96ME;6ES96MS:2X`16D@97+D;6%L;&EA+@!/<VEO=&$@96D@;VQE
M('!Y>61E='ES<^0@<&%I:V%S<V$N`$MA;&5N=&5R:6X@;FEM9>0@96D@;VQE
M(&%N;F5T='4@34-!3"UA=71E;G1I:V]I;FYI;&QE+@!%:2!M=75T;W-T82X`
M06QI=&%S;VIA(&5I('9O:2!L:7/D=.0@=.1L;&4@;VEK975D96QL92X`07-E
M='5K<VEA(&5I(&SV>71Y;GET("5S.FQL92X`07-E='5K<VEA(&5I(&SV>71Y
M;GET($944"!61E,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@4U%,(%9&
M4SIL;&4N`$%S971U:W-I82!E:2!L]GET>6YY="!344PM1FEL92!61E,Z;&QE
M+@!+<F5D:6ET:70@;&]P<'4N`$MO:&1E='1A(&5I(&%N;F5T='4N`$5I('1U
M;W1U(&%I;G5T=&%K86%N('1I961O<W1O80!I0V%L96YD87(@=&EE=&]J82!E
M:2!L]GET>6YY="X`26MO;F5I=&$@96D@;/9Y='EN>70N`%!A:6MK86$@96D@
M;VQE(&%S971E='1U+@!086EK:V%A(&5I(&]L92!A;FYE='1U+@!%:2!A;FYE
M='1U('9I97-T:>0N`$YI;67D(&5I(&]L;'5T(&%N;F5T='4N`%9I97)A:6QI
M:F]I;&QE(&5I(&]L92!S86QL:71T=2!A:6YU='1A:V%A;B!M=6ES=&EL:7-T
M86$N`$5I(&UU:7-T:6EN<&%N;VIA`%EK<VEKY.1N(&UU:7-T:6EN<&%N;R!E
M:2!V87-T86YN=70@:W)I=&5E<F5I=.0N`$5I(&UU:7-T:6EN<&%N;VIA(&[D
M>71E='3D=N1K<VD`3'5K=6WDY'+DY"!E:2!O;&QU="!A;FYE='1U+@!%:2!L
M;W5K:V%A=F%T(&UI971E;&%U<V5E=`!386QA<V%N86$@96D@;VQE(&%N;F5T
M='4@2%144"UA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE(&%N
M;F5T='4@24U!4"UA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE
M(&%N;F5T='4@2V5R8F5R;W,M875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A
M(&5I(&]L92!A;FYE='1U($QO9VEN(&%U=&5N=&EK;VEN;FES<V$N`%-A;&%S
M86YA82!E:2!O;&4@86YN971T=2!005-35T0M875T96YT:6MO:6YN:7-S82X`
M4V%L87-A;F%A(&5I(&]L92!A;FYE='1U(%--0BUA=71E;G1I:V]I;FYI<W-A
M+@!0;VQK=6$@3W!E;E-33"!K;VUE;G1O;VX@96D@;VQE(&WDY')I=&5L='DN
M($]P96Y34TP@<&ETY.0@;VQL82!KY'ET971TY'9I<W/D(&IO<R!KY'-I=&5L
M;.3D;B!02T-3(#$R(&1A=&%A+@!%:2!S:7/DY&YK:7)J875T=6UI<W!Y>6YT
M]FKD(&IO;F]S<V$N`$MI:6YT:?9TY"!E:2!O;&4@87-E=&5T='4`16D@<^3D
M;G3V:N0`17)O=&EN=&$@96D@;VQE(&WDY')I=&5L='DN`$5I(')E=6YO:F$`
M16D@;/9Y='EN>70@=&EE9&]S=&]A`%;D;&EM=6ES=&EL;&4@96D@;VQE(';D
M;&EA:6MA:7-H86ME;6ES=&]A+@!+Y'ET=.1JY'1U;FYU<W1A('1A:2!S86QA
M<V%N86$@96D@;.1H971E='1Y+@!+86EK:VD@<&%L875T=6YU="!834PM9&%T
M82!O;&D@97#D:V5L<&]A`$5I(&%R=F]J80!697)S:6]T:65T;VIA(&5I(&SV
M>71Y;GET(&%L:W5P97+D:7-I=.0@87-E='5K<VES=&$N(%-I;G5N('!I=.3D
M('1E:&3D(&%S971U:W-E="!U=61E<W1A86XN`%9E<G-I;W1I971O:F$@96D@
M;/9Y='EN>70@87-E='5K<VES=&$N(%-I;G5N('!I=.3D('1E:&3D(&%S971U
M:W-E="!U=61E<W1A86XN`$UU7VES=&EI;G!A;F\`16D@;6ETY.1N`$5I(&UI
M=.3D;B`H2^1Y=.0@:6UP;&ES:6ET=&ES=.0I`$QA<'!I+U!O:&IO:7-M86%T
M+T5S:VEM;R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@<V%A<F5T`%!O:&IO:6YE
M;B!P86QL;VYP=6]L:7-K;P!0;VAJ;VES970@36%R:6%A;FEE;B!S86%R970`
M3F]R:F$`16D@:N1L:V5E;@!%:2!E;FYE;@!%:2!O;&4@:&%K96UI<W1O`$5I
M(&]L92!T;W1E=71E='1U+@!%:2!A<V5T971T=0!%:2!T=65T='4N`$UU:7-T
M:6EN<&%N;VX@;'5O:VET=7,`375I<W1I:6YP86YO;B!Y:W-I='EI<VMO:&1A
M=`!-=6ES=&EI;G!A;F]L:7-T870`375I<W1I:6YP86YO;B!T96MS=&D`375I
M<W1I:6YP86YO;B!?=&5K<W1I`$UU:7-T:6EN<&%N;V$@96D@;/9Y='EN>70N
M`$UU:7-T:5]L:7-T80!-=6ES=&EL:7-T86X@;FEM:3H`375I<W1I;&ES=&%T
M`$UU:7-T:6QI<W1A;&QA('!I=.3D(&]L;&$@;FEM:2X`375I<W1I:6YP86YO
M=`!-=6ES=&EI;G!A;F]J96X@>6AT965N=F5T;P!%:2!M:73DY&X@<V5L871T
M879A82P@<&%L86$@=&%K86ES:6XN`&UA<G)A<VMU=0!,=6MU;>3D<N0`365R
M:VMI96X@;'5K=6WDY'+D`%-A<F%K:V5I9&5N(&QU:W5MY.1RY`!2:79I96X@
M;'5K=6WDY'+D`$IA:V5L=6QI<W1A;B!N=6UE<F]I=&$@96D@;VQE(&WDY')I
M=&5L='D@<.1I=FET971TY';D:W-I+@!/2P!/8FIE:W1I`$]B:F5K=&EN(&QU
M;VIA`$]K=&%A;&D`;&]K86MU=0!,;W5K:V%A=G5U<W-U;V1A=&EN`%1O:6UI
M<W1O`%5U<VD@<V%L87-A;F$@96D@<V%A(&]L;&$@<V%M82!K=6EN(&YY:WEI
M;F5N('-A;&%S86YA<VDN`%9A;FAA('-A;&%S86YA`%9A;FAA('-A;&%S86YA
M(&]N(';DY')I;BX`3VUA;@!686EN($E-05`M<&%L=F5L:6UE="!T=6ME=F%T
M(&IA971T=6IA(&MA;G-I;VET82X`5F%I;B!L;W5K:V%A=F%T(&UI971E;&%U
M<V5E=`!6;VET(&QA:71T86$@=F%I;B!Y:&1E;B!SY&AK]G!O<W1I;W-O:71T
M965N+@!686EN(&]M:7-T86IA('1A:2!JY')J97-T96QMY&X@>6QLY'!I=.1J
MY"!V;VD@;75U='1A82!J86MO:F5N(&]M:7-T86II82!T86D@;VEK975K<VEA
M`$%V86$@=75D97-S82!I:VMU;F%S<V$`3W!E;E-33"!V:7)H93H@5&EE=&]J
M82!E:2!S86%T=2!E<VEL;&4@86QL96MI<FIO:71E='5S=&$@4R]-24U%+6]S
M87-T82X`079A82!TY&WD;B!L:6YK:6X@=75D97-S82!I:VMU;F%S<V$`2^1Y
M='3V:N1R:F5S=&5L;>0`07-E='5K<V5T`$%S971U:W-E="`E<SIL;&4`2N1R
M:F5S=&5T='D@;&ES=&$`3W)G86YI<V%A=&EO`$]R9V%N:7-A871I;WEK<VEK
M:_8`3W)G86YI<V]I;G1I`$%L:W5P97+D:6YE;B!O:&IE;&UA;B!M86QL:0!!
M;&MU<&5RY&ES970@;6%L;&ET("5S.G-SY#H`375U`$UU=70@=&EE9&]T`$]M
M:7-T86IA;B!O:6ME=61E=`!004TM875T96YT:6MO:6YT:6$@96D@;VQE(&OD
M>71E='3D=FES<^0N`%!%05(Z.DUA:6P@=&%U<W1A:N1R:F5S=&5L;>0`1&EG
M:71A86QI;F5N(%!'4"UA;&QE:VER:F]I='5S`%!'4"US86QA='1U82!T:65T
M;V$`2G5L:VEN96X@4$=0+6%V86EN`%!'4"UA;&QE:VER:F]I=&5T='5A(&IA
M('-A;&%T='5A('1I971O80!02%`M:V]O9&D`4$A0+6MO;65N=&]T=6QK:VD`
M4$T@:V5V>71TY"!S861E='1A`%!-('-A9&4`4$T@:W5U<F]J80!032!L=6UI
M`%!-(&QU;6ES871E:71A`%!-(&QU;6D`4$T@=6MK;W-M>7)S:WEJY`!03U-)
M6"UL86%J96YN=6MS970@<'5U='1U=F%T`%!?2%`M:V]M96YT;W1U;&MK:0!4
MY'ET90!086MI<W1A;@!086QA=0!086QE<W1I:6YA("AM:65H:71E='1Y(&%L
M=64I`%!A;F%M80!087!U82!5=7-I+4=U:6YE80!087)A9W5A>0!/<VET=&%I
M;B!P:6QV:7-TY`!386QA<V%N80!386QA<V%N86X@=F%I:'1O(&]N;FES='5I
M+@!6Y.1RY"!S86QA<V%N80!386QA<V%N86$@=&%R=FET86%N(%)!1$E54RUA
M=71E;G1I:V]I;G1I:6XN`%-A;&%S86YA('9A<FUI<W1U:W-E;&QA`%-A;&%S
M86YA.@!386QA<V%N83H@`%-A;&%S86YO:F5N('!I=.3D(&]L;&$@<V%M870N
M`$QI:73D`$QI:73D(&QE:6ME</9Y9.1L=.0`4&]L:W4`2F]N;W-S82!O;&5V
M870@<VESY.1N:VER:F%U='5M:7-P>7EN;O9T.@!):&UI<V5T`%!R;W-E;G1T
M:0!3=6]R:71A('EL;.1P:71O=&]I;65N<&ET965T`%-U;W)I=&$@>6QLY'!I
M=&]T;VEM96YP:71E970@<VESY.1N:VER:F%U='5M:7-E;B!Y:'1E>61E<W/D
M+@!/:6ME=7,`3VEK975T=&$@(B5S(B!E:2!P;VES=&5T='4N`$OD>71T]B!K
M:65L;&5T='D`3VEK975D970`3VEK975K<VEE;B!Y;&SD<&ET;P!/;6%T('1I
M961O=`!097)U`$QE;6UI:VET`$9I;&EP<&EI;FET`%!U:&5L:6X`5F%L;VMU
M=F%T`%!I=&-A:7)N`%!I:W-E;&D`2VQI<V5E=`!.87!S875T82!J;W1A:6X@
M<V]L=6$`5F%R;6ES=&$@971TY"!H86QU870@<&]I<W1A82!TY&WD;B!E;&5M
M96YT:6XZ`%9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T86$@;&EN:VET>6MS
M96X@=.1HY&X@96QE;65N='1I:6XN`$%N;F$@:W5U:V%U<VD@:F$@=G5O<VDN
M`$%N;F$@;FEM:2!U=61E;&QE(&QU;VMI='5K<V5L;&4Z`$%N;F$@;VEK96$@
M25`M;W-O:71E+@!!;FYA(&]I:V5A('#D:7;D;>3D<N0[(%1A<FMI<W1A('#D
M:79I96X@;'5K=6WDY'+D(&MU=6MA=61E<W-A+@!!;FYA(&%I:V$@;VEK96%S
M<V$@;75O9&]S<V$N`$%N;F$@;'EH>70@:W5V875S(&]N9V5L;6%S=&$N`$%N
M;F$@:^1Y='3D:N1T=6YN=6MS97-I(&IA('-A;&%S86YA<VD`3'5E('-E=7)A
M879A('1E:W-T:2X@4VEN=6X@4$E4Q,0@<W5O<W1U82!KY'ET=/9E:'1O:6AI
M;B!V;VED86MS97-I(&OD>71TY.0@:N1R:F5S=&5L;>3D+@!!;FYA(&YI;6D@
M=75D96QL92!L=6]K:71U:W-E;&QE.@!0=6]L80!0;VQI=&EI:VMA`$MY<V5L
M>70`4&]R='5G86QI`%3D;>1N(&MU=F%N('!A:6MK80!4Y&WD;B!T875L=6MO
M;B!P86EK:V$`5F]I(&SD:&5T=.3D('9I97-T96KD(&MA;G-I;V]N("AE:2!K
M;W-K92!)34%0('EH=&5Y:W-IY"D`4V%D96WDY'+D(&5D96QL:7-I;&QE("5S
M('1U;FYI;&QE.B``2&%I:'1U=G5U<R`\8G(@+SYT;V1E;F[D:_9I<WEY<P!0
M<F5F<U]L9&%P.B!487)V:71T879A82!,1$%0+6QA86IE;FYU<W1A(&5I(&SV
M>71Y;GET+@!0<F5F<U]S97-S:6]N.B!487)V:71T879A82!S97-S:6]N+6QA
M86IE;FYU<W1A(&5I(&SV>71Y;GET`$EL;6%N<&%I;F4`26QM86YP86EN92!M
M97)E;G!I;FYA<W-A.B``26QM86YP86EN93H@`$5S:6MA='-E;'4`17-I:V%T
M<V5L92!K=79A('5U9&5S<V$@:6MK=6YA<W-A`$5D96QL:7-E="!A<V5T=6MS
M970`5'5L;W-T82!D;VMU;65N='1I`%-A;&%I;F5N(&%V86EN`$]N9V5L;6$`
M3VYG96QM86X@:W5V875S`%!R;VIE:W1I=`!+96AO='1E96X@=&5K<W1I`$IU
M;&MI;F5N(&%V86EN`$IU;&MI<V5N(&%V86EM96X@86QG;W)I=&UI`$IU;&MI
M<V5N(&%V86EM96X@=&EE9&]T`$IU;&MI<V5N+W-A;&%I<V5N(&%V86EN<&%R
M:6X@;'5O;G1I(&5PY&]N;FES='5I+@!0=65R=&\@4FEC;P!6;VD@='5H;W1A
M('!O:7-T971T=6IA('9I97-T96KD`%%A=&%R`$MY<V5L90!+:6EN=&GV`%)3
M02!*=6QK:6YE;B!A=F%I;B`H)60@8FET=&GD*0!2861I;W!A:6YI:V4`4V%D
M90!3861E='1A(&%I:V%I<VEN`%-A9&5T=&$@;7GV:.3D;@!3861E:W5U<F\`
M5F5S:2!J82!L=6UI`%9E9&5S=.0@;'5M965N`%-A='5N;F%I;F5N(&UI971E
M;&%U<V4`4W5H9&4`3'5K=0!6;VD@;'5K96$@=FEE<W1E:N0`4&]I<W1E=&%A
M;FMO("5S/R!4Y'3D('1O:6UI;G1O82!E:2!V;VD@<&5R=75T=&%A+@!0;VES
M=&5T86%N:V\@=.1MY"!M=6ES=&EI;G!A;F\_`%!O:7-T971A86YK;R!T:65D
M;W0@:^1Y='3D:N1S=.0@)7,_(%3D=.0@=&]I;6EN=&]A(&5I('9O:2!P97)U
M=71T86$N`%1E92!M=75T;VMS970@=75D97-T86%N`%#D:79I=.0`4.1I=N1T
M(&1Y;F%A;6ES970@=F%L:6MK;V5L96UE;G1I=#H`4.1I=FETY"!L:7-T80!0
MY&EV:73D('!O<G1A86QI;N1K>6WDY#H`4^3D;F[V;&QI;F5N(&QA=7-E:V4`
M4F5L86%T:6]S96QA:6X`3&%T86$@=75D96QL965N`$UU:7-T:6EN<&%N;W0`
M173D<&%L=F5L:6UE=`!%=.1P86QV96QU;B!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!0;VES=&$`4&]I<W1A(&]S:6\`4&]I<W1A(&QU
M;VMI='5S`%!O:7-T82!S87)A:V4`4&]I<W1A(&UU;W1O:6QU`%!O:7-T82!P
M87)I`%!O:7-T82!T86QL971E='1U('-K<FEP=&D@<&%L=F5L:6UE;B!VY&QI
M86EK86ES:&%K96UI<W1O<W1A+@!0;VES=&$`4&]I<W1A('3D;>0@;F]O9&D@
M9&]K=6UE;G1I<W1A`%!O:7-T82!KY'ET=.1JY`!0;VES=&$@:^1Y='3D:N0Z
M("5S`%!Y>6YT]O9N(&5I('9O:71U('9A<W1A=&$N(%9I<FAE:V]O9&DZ(`!0
M>7ED971T>>0@<&%L=F5L=6$@96D@;/9Y='EN>70N`%1A<G9I='1A=F%A("(E
M<R(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@)7,@87-E='5K<VES<V$N
M`%1A<G9I='1A=F%A("(E<R(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@
M5D93(&%S971U:W-I<W-A+@!487)V:71T879A82`B)7,B+71I971O82!E:2!O
M;&QU="!MY.1R:71E;'1Y(&%S971U:W-I<W-A+@!086MO;&QI;F5N(&ME;G1T
MY`!4>6AJ96YNY`!4>6AJ96YNY"!S86QA<V%N80!4>6AJ96YNY"!S86QA<V%N
M87-I`%!A;&%U=&$@961E;&QI;F5N(&MY<V5L>0!4=6QO:W-E=`!086QA82!A
M<V5T=6MS:6EN`%9A:'9I<W1A('5U<VD@<V%L87-A;F$`4F5U;FEO;@!086QA
M=71A(&%S971U:W-E=`!2:6-H(%1E>'0@161I=&]R:6X@87-E='5K<V5T`$%R
M=F]I='5K<V5T`$]I:V5A`$]I:V5A(&]T<V%K90!/:6ME82!A<G9O=`!2:79I
M7VX@=&EE9&]T+BXN`%)O;VQI`%)O;6%N:6$`2^3D;F[D(#$X,`!+Y.1N;N0@
M=F%S=&%PY&EVY.1N`$ODY&YNY"!M>?9TY'#D:7;DY&X`4FEV:6X@=&EE9&]T
M`%)I=FEN('1I961O=`!2:79I=#H`5FEI=F]I=&EN`%9I:79O:71I;B!NY&MY
M>2!K86EK:VEE;B!R:79I96X@:F$@<V%R86MK96ED96X@=N1L:6QLY`!6:6EV
M;VET:6X@;N1K>7D@=F%I;B!S87)A:VME:61E;B!VY&QI;&SD`%9I:79O:71I
M;B!NY&MY>2!V86EN(')I=FEE;B!VY&QI;&SD`%-U;W)I=&$`5F5NY&KD;B!&
M961E<F%T:6EV:6YE;B!T87-A=F%L=&$`4G5A;F1A`%,O34E-12!K<GEP=&]G
M<F%A9FEN96X@86QL96MI<FIO:71U<P!3+TU)344@<V%L871T=2!V:65S=&D`
M4T%33"UA=71E;G1I:V]I;G1I(&5I(&]L92!KY'ET971TY'9I<W/D+@!335,@
M5&5K<W1I=FEE<W1I=`!344PM:V]M96YT;W1U;&MK:0!344PM;&%U<V4@87)V
M;VIE;B!H86ME;6ES965N`%-32`!/3DY)4U1520!37U%,+6MO;65N=&]T=6QK
M:VD`;&$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&IA($YE=FES`%-A:6YT
M($QU8VEA`%-A:6YT(%!I97)R92!J82!-:7%U96QO;@!386EN="!6:6YC96YT
M(&IA($=R96YA9&EI;FET`%-A;6%A;B!K96AY:W-E96X@*%]S96QF*0!386UO
M80!386X@36%R:6YO`%-A;R!4;VUE(&IA(%!R:6YC:7!E`%-A=&5L;&EI='1I
M('!A;'9E;'5N=&%R:F]A:F$`4V%U9&EA($%R86)I80!486QL971A`%1A;&QE
M=&$@(B5S(@!486QL971A("5S`%1A;&QE=&$@87-E='5K<V5T`%1A;&QE=&$@
M;'5O9'5T(&%S971U:W-E="!02%`M<VMR:7!T:6[D('!A;'9E;&EM97-I(';D
M;&EA:6MA:7-H86ME;6ES=&]O;BX@`%1A;&QE=&5T=&EI;B`E<SIN(&%S971U
M:W-E="X`07-E='5S=&5N('#D:79I='ES<VMR:7!T:2!O;B!T86QL971E='1U
M('!A:6MK86%N.B`B)7,B+@!(86IA;F%I<VEA('5K:V]S;7ER<VMY:N0`5&EE
M9&4`2&%K=0!(86MU:V]N965T`$AA=6X@='5L;VMS970`2&%U;B!K;VAD:7-T
M=7,`2&%E(%]T96MS=&GD`%9A;&ET<V4@=&EE9&]S=&]T`%9A;&ET<V4@<.1I
M=N1MY.1RY`!686QI='-E(&QI<^1T=.1VY"!R>6AMY`!686QI='-E('5U<VD@
M;VUI<W1A:F$`5F%L:71S92!M=6ES=&EL:7-T80!686QI='-E('!A;'9E;&EN
M`%9A;&ET<V4@;&ESY'1TY';D(&OD>71TY&KD`%9A;&ET<V4@:V%I:VMI`%9A
M;&ET<V4@:V%I:VMI('#D:7;D;>3D<N1K;VUP;VYE;G1I=`!686QI='-E(&]B
M:F5K=&D`5'EH:F5N;N0@=F%L:6YT80!686QI='-E(&[D>71E='3D=N1T(&UU
M:7-T:6QI<W1A=#H`5F%L:71S92!T87)V:71T879A="!M97)K:70@86QL82!O
M;&5V:7-T82!V86QI:V]I<W1A+B!6;VET('-E;B!JY&QK965N(&MO<&EO:61A
M(&IA(&QI:71TY.0@;65R:VET('1E:W-T:6ES:2X`5F%L:71S92!PY&EVY'EK
M<V5N(&5R;W1I;FUE<FMK:3H`5F%L:71S92!PY&EVY'EK<V5N(&5S:71Y<W1A
M<&$Z`%9A;&ET<V4@=FEE;FYI<W/D(&OD>71E='3D=N0@;75O=&\Z`%9A;&ET
M<V4@=&EE9&]S=&\L(&IO<W1A('1U;V1A86X@=&EE=&]J83H`5F%L:71S92!L
MY&AD971I961O<W1O;B!M=6]T;SH`5F%L:71S92!M=75T971T879A('!R;V9I
M:6QI.@!686QI='-E(&ME;&QO;F%J86X@97)O=&EN;65R:VMI.@!686QI='-E
M(&%J86X@97-I='ES=&%P83H`5F%L:71S92!K86MS:2!Y:'1E96YS;W!I=F%A
M(&ME;G1TY.0N`%9A;&ET<V4@=N1R:71E96UA+@!686QI='-E(&OD>71E='3D
M=N0@:VEE;&DZ`%9A;&ET=70@;'5O:VET=6MS970Z`$SD:&5TY"!O;F=E;&UA
M=FEE<W1I`$SD:&5TY"!335,`4V5N96=A;`!4=6YN:7-T:6XZ(`!S>7ES:W5U
M`%-E<F)I82!J82!-;VYT96YE9W)O`%-A<FIA;G5M97)O`%!A;'9E;&EM96X@
M=&EE9&]T(&]V870@=N3D<FGD('1A:2!E:7;D="!O;&4@:^1Y=&5T=.1V:7-S
MY"X`27-T=6YT;VIE;B!H86QL:6YT80!397-S:6]N($E$(&]N('9A;FAE;G1U
M;G5T+@!)<W1U;FYO=`!!<V5T80!386QA<V%N86X@<F5S971O:6YT:6EN(&QI
M:71T>79IY"!A<V5T=6MS:6$L(&IO<R!J;W-K=7,@=6YO:&1A="!S86QA<V%N
M87-I+@!6;VET(&%S971T86$@=6QK;VES=&5N('!A;'9E;&EM:65N(&%S971U
M:W-E="P@:F]I=&$@:&%L=6%T(&OD>71TY.0@<&]R=&%A;&ES<V$N`%9O:70@
M87-E='1A82!KY'ET971TY';D;B!K:65L96XL(&%I:V%V>?9H>6MK965N(&IA
M(&UU:71A('#D:7;D;>3D<N1A<V5T=6MS:6$N`%9O:70@87-E='1A82!A;&]I
M='5S;VAJ96QM86XL(';D<FET965M86XL(&[D:WEMY&X@<.1I=FET>6MS96X@
M:F$@;75I=&$@;N1K>6WDY&X@;&EI='1Y=FGD(&%S971U:W-I82X`07-E;FYU
M<P!!<V5N;G5K<V5N('#D:79I='ES<VMR:7!T:2!O;B!S86%T879I;&QA`%5S
M96%T('!A:6MA="!S;W!I=F%T(&%N;F5T='5U;B!P87)A;65T<FEI;CH@`%-E
M>6-H96QL:70`3W-T;VMS970`3'EH>70@:W5V875S.@!!<V5T971A('!I:V%V
M86QI;G1A;N1P<.1I;65T('5S96EM;6EL;&4@;&EN:V5I;&QE+@!.Y'ETY`!.
MY'ETY"!T;VEM:6YT;W!A:6YI:VME970N`$[D>73D(&5R;V%V86ES=75D970@
M87-E='5K<VEE;B!T86QL971E='5S<V$@:F$@=75D97-S82!J=75R:2!M=6]K
M871U<W-A('9E<G-I;W-S82X`3N1Y=.0@961E;&QI<V5N('-I<^3D;FMI<FIA
M=71U;6ES96X@<.1I=N1Y<RX`3N1Y=.0@;75I<W1I;&ES=&%N;FEM:2X`3N1Y
M=.0@;75I<W1I:6YP86YO="!NY&ES=.0@:V%T96=O<FEO:7-T80!.Y'ETY"!A
M<V5T=7,@<&ETY.1K<V5S:2!A;&MU<&5RY&ES96X`3N1Y=.0@=F%L:71S:6X`
M3N1Y=.0@=&%U;'5K:V]T;VEM:6YN;W0@=F%L:6MK;RX`3N1Y=.0@=F%S96UM
M86QL82`E<R!V86QI:VMO+@!.Y'ETY"!T875L=6MO;B!S;VQU;B!T:65D;W0@
M9&EA;&]G:0!.Y'ETY"!T875L=6MO;B!T:65D;W0@9&EA;&]G:0!.Y'ETY"!T
M875L=6MO;B!R:79I;B!T:65D;W0@9&EA;&]G:0!.Y'ETY"!K=79A;B!T:65D
M;W0@9&EA;&]G:0!.Y'ETY"!T=6]N=&D`4V%T96ET80!3871E:71A(&%I:V%I
M<VEN`%-A=&5I=&$@;7GV:&5M;6EN`%-A=&5I=&$@;.1H971T>79I;&QA`%!I
M96YE;F[D`%!I96YE;F[D('1A:2!S:6ER<N0@=FEE<F5I<VGD(&]S:6]I=&$L
M(&IO='1A(&YE(&5I=N1T(&]L92!T:65L;.0`4VEE<G)A($QE;VYE`$MI<FIA
M=61U`$%L;&5K:7)J;VET=7,`06QL96MI<FIO:71U:W-E;B!A;&=O<FET;6D`
M4VEN9V%P;W)E`$MO:V\`3VAI=&$@>6QLY'!I=&]T96ATY';D=`!3;&]V86MI
M80!3;&]V96YI80!,=6UI`$QU;6ES861E='1A`$QU;6ES871E:71A`$QU;6ES
M871E:71A(&%I:V%I<VEN`$QU;6ES871E:71A(&UY]FCDY&X`3'5M96X@<WEV
M>7ES.B``3'5M96X@;>3D<N0@=F5T96[D.B``4V%L;VUO;B!S86%R970`4V]M
M86QI80!,875L=70@:F$@4G5N;W5S`$KD<FIE<W3D(&QU;VMI='5K<V5N(&UU
M:V%A;@!*Y')J97-TY"!M=6ES=&EI;G!A;F]N('1E:W-T:2!M=6MA86X`2N1R
M:F5S='EK<V5N('-U=6YN86X@=F%L:6YT80!,Y&AD96]S;VET90!%=&5LY"U!
M9G)I:VMA`$5T96SD+45U<F]O<'!A("A)4T\M.#@U.2TS*0!%=&5LY"U'96]R
M9VEA(&IA(&5T96SD:7-E="!386YD=VEC:"!S86%R970`171E;.1I;F5N('!A
M;&QO;G!U;VQI<VMO`%;D;&D@=FEE<F5I<V5T('-O;'5J96X@=N1L:7-SY`!6
MY&QI('-O;'5N(&QE:7#D=&5K<W1I;B!J82!R975N86X@=N1L:7-SY"``5N1L
M:0!6Y&QI`%;D;&D@:F$@=.1Y=&4`17-P86YJ80!2;W-K87!O<W1I`$5R:6MO
M:7-M97)K:VEE;B!S>?9T=/8`2F%A('-O;'4`2F%A('-A<F%K90!*86$@<FEV
M:0!5<FAE:6QU`%-R:2!,86YK80!3=&%N9&%R9&D`4W1A<B!4<F5K`$%L:V%M
M:7-V=6]S:0!,Y.1N:2!T86D@86QU90!4:6QA`%1A;&QE;FYU<VUU;W1O`$MA
M='5O<V]I=&4`3.1P:6QY]FYT:0!-97)K:VEJ;VYO;&ES=&$`4&]I<W1A('1O
M:6UI86QU92!O<V]I='1E97-T80!4>7EL:2!;0U-370!S=0!!;&EH86ME;6ES
M=&]A("(E<R(@96D@;/9Y='EN>70N`$]T<VEK:V\`3.1H973D`$SD:&5T971T
M:6EN("(E<R(Z;B!L:7/D>7-P>7EN=/8N($5T('9O:2!K:7)J875T=6$@<VES
MY.1N(&5N;F5N(&MU:6X@<'EY;G3V<VD@;VX@:^1S:71E;'1Y(&IA(&AY=N1K
M<WET='DN`$%L:6MI<FIO:71U<P!/;FYI<W1U:0`B)7,B.B!L:7/DY&UI;F5N
M(&KD<FIE<W1E;&WDY&X@;VYN:7-T=6DN`$OD>71TY&KD;B`B)7,B(&OD>71T
MY&KD=&EE=&]J96X@<&]I<W1A;6EN96X@:N1R:F5S=&5L;>1S=.0@;VYN:7-T
M=6DN`"(E<R(@<&]I<W1E='1I:6X@;VYN:7-T=6YE97-T:2X`(B5S(CH@;VYN
M:7-T=71T:6EN('!O:7-T86UA86X@:N1R:F5S=&5L;>1S=.0N`%!A;&%T=&EI
M;B!O;FYI<W1U;F5E<W1I('9A;FAO:6AI;B!A<V5T=6MS:6EN+B!,871A82!S
M:79U('5U9&5S=&%A;B!NY&ADY&MS97-I(&UU=71O:W-E="X`)R5S)SIN('1A
M;&QE='5S(&]N;FES='5I+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R
M;75U<VMO<&EO+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U<VMO
M<&EO("5S+@`G)7,G.B!PY&EV:71Y<R!O;FYI<W1U:2X`)7,Z;B!K:7)J;VET
M=&%M:6YE;B!O;FYI<W1U:2X`4W5D86X`66AT965N=F5T;P!!=7)I;F=O;FYO
M=7-U`$%U<FEN9V]N;&%S:W4`075R:6YK;VEN96X`075R:6YG;VYN;W5S=0!!
M=7)I;FMO(&YO=7-E92]L87-K964`075R:6YG;VYN;W5S=3H@`$%U<FEN9V]N
M;&%S:W4`075R:6YG;VYL87-K=3H@`%#DY&QL96MI<FIO:71U<P!4=6MI`%-U
M<FEN86T`4W5K=6YI;6D`2'5I<'!U=G5O<F5T(&IA($IA;B!-87EE;@!3=V%Z
M:6UA80!2=6]T<VD`4W9E:71S:0!3>6YC(&QO:VD@<&]I<W1E='1U`%-Y;F--
M3`!3>6YT86MS:79I<FAE(&AA:W5T97)M96ES<^0`4WEY<FEA+"!A<F%B:71A
M<V%V86QT80!5:VMO<VUY<G-K>0!5:VMO<VUY<G-K>6KD(&IA('1U=6QI<W1A
M`%5K:V]S;7ER<VMY=`!5:VMO<VUY<G-K>6KD(&%I:V%I<VEN`%135BUT:65D
M;W-T;P!4875L=6MK;P!4875L=6MO;B!T:65D;W0`5&%U;'5K;VX@87-E='5K
M<V5T`%1A=6QU:V]N('1I961O=`!486EW86X`5&%I=V%N+"!+:6EN86X@;6%A
M:W5N=&$`5&%D>FEK:7-T86X`5&%N>F%N:6$L(%EH9&ES='EN>70@=&%S879A
M;'1A`$MO:&1E.@!496ATY';D=`!0=6AE;&EN;G5M97)O`$SD;7#V=&EL82!E
M9&5L;&ES96QL92!T=6YN:6QL93H@`$SD;7#V=&EL80!,Y&UP]G1I;&$Z(`!,
MY&UP]G1I;&$\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!-86QL:6$@
M(B5S(B!E:2!L]GET>6YY="X`36%L;&EE;B!H86QL:6YT80!496MS=&D`5F%I
M;B!T96MS=&D`5&5K<W1I;B!T87-A=7,`5&5K<W1I=&]P`'1O`%1H86D@*%1)
M4RTV,C`I`%1H86EM86$`1E10+6QI<^1T;VEM:6YT;R!E:2!O;&4@:^1Y=&5T
M=.1V:7-SY"X`2&ES=&]R>2!JY')J97-T96QMY"!E:2!O;&4@:^1Y=&5T=.1V
M:7-SY"X`2&]R9&4O2V]L86(@:6YT96=R;VEN=&EM;V]T=&]R:2!E:2!T=64@
M(B5S(@!)35-0(&QO:VEA(&5I('9O:71U(&%L=7-T86$N`$UA:6YT96YA;F-E
M.CH@+6QU;VMA;B!L871A86UI;F5N(&5PY&]N;FES='5I`$%S971U:W-E="!I
M:VMU;F$@;VX@<W5L:F5T='4N(%!O:7-T=71A86XN`%EL;.1P:61O;B!P:73D
MY"!O='1A82!KY'ET=/;V;B!P>7-Y=N0@=&%L;&5T=7-T>7EP<&D@4&5R;6ES
M<VEO;BP@:F]S(&AA;'5A="!KY'ET=.3D(&YI:73D+@!686EN(&%L87!U;VQI
M`$-O;G1A8W0@:60@;G5M97)O82!E:2!O;&4@;>3D<FET96QT>2P@;VX@='EH
M:N0@=&%I(&5I(&SV>71Y;GET('1I971O:V%N;F%S=&$N`%EH=&5Y<W1I961O
M="!L:7/D='1I:6X@;VYN:7-T=6YE97-T:2!O<V]I=&5K:7)J86%S:2X`5FEE
M<W1I;B!A;&QE:VER:F]I='5K<V5N('1A<FMI<W1A;6ES965N('1A<G9I=&%A
M;B!E<FEL;&EN96X@4$=0+6%L;&5K:7)J;VET=7-L;VAK;RX`2F%K96QU;&ES
M=&%N($E$(&5I(&]L;'5T(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L
M]GET>6YY="!T:65T;VMA;FYA<W1A+@!*86ME;'5L:7-T86$@96D@;VQL=70@
M;>3D<FET96QT>2X`4V%L875S=&]I;6EN;F]N(&OD>71T]B!V86%T:2!S86QA
M='1U82!75U<M>6AT97ET=.0N`%1I961O<W1O<W-A("5S('!I=.1I<VD@;VQL
M82`E<R!A<V5T=7,N`%1I961O<W1O<W-A("5S('!I=.1I<VD@;VQL82!J;VET
M86MI;B`E<R!A<V5T=6MS:6$N`%1I961O<W1O82!E:2!V;VED82!K;W!I;VED
M82!I='-E;G/D('#DY&QL92X`5&EE9&]S=&\@;VQI('1Y:&KD+@!3975R86%V
M87-S82!O;B!O='-I:VMO=&EE9&]T('3D<W3D(&UE<W-A9V4O<F9C.#(R("UV
M:65S=&ES=.0N`$MO:V]R=75D=6X@;N1Y='3V=&EL82!A:6AE=71T86$@;VYG
M96QM:6$@:F]I;&QA:VEN($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;65N(&OD
M>71TY&II;&SD+B!686QI=&5T=&%V87-T:2!K>7-E:6YE;B!S96QA:6X@<VES
MY&QTY.0@<&EI<G1E:73D(&IA('9I<FAE:73D(&IO:6AI;B!E:2!O;&4@;/9Y
M='EN>70@:V]R:F%U<W1A('1A:2!K96EN;V$@:VEE<G3DY"!O;F=E;&UA+B!(
M=6]M86%T:&%N(&5T=.0@:F]S(&OD>73D="!TY'3D(&[D>71T]G1I;&%A(&IA
M($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;G1A+"!N:6EN(&[D>71T]B!S86%T
M=&%A(&UE;F[D('-E:V%I<VEN+"!J;W1K=70@=&]I;6EN;F]T(&5I=N1T('1O
M:6UI('1A:2!S96QA:6X@<V%A='1A82!K86%T=6$N($IO<R!KY'ETY'0@5VEN
M9&]W<R`Y>"!T86D@344@=F5R<VEO=&$L(&YI:6X@;VX@;6%H9&]L;&ES=&$@
M971TY"!KY'ET=/9JY')J97-T96QMY"!K86%T=74@;G,N("='96YE<F%L(%!R
M;W1E8W1I;VX@1F%U;'0G("UV:7)H965S965N(&IA('-I;G5N('!I=.3D(&OD
M>6YN:7-TY.0@:V]N92!U=61E<W1A86XN7&Y<;B!-=6ES=&$@971TY"!S:6YU
M82!O;B!V87)O:71E='1U+B!.87!S875T82!/2RUN87!P=6QA82!J;W,@:&%L
M=6%T(&MO:V5I;&QE(&5D:71O<FEN(&MO:V]R=75T=2!NY'ET=/9T:6QA82X`
M4&]I<W1E='1I:6X@<')O9FEI;&D@(B5S(BX`5F%I;B!V87-E;B!P=6]L:0!'
M;G501R!O:&IE;&UA;B!S:6IA:6YT:2!P:73DY"!MY.1R:71E;&SD($-R>7!T
M7W!G<#HZ("UL=6]K87-S82X`5FEE<W1I(&SD:&5T971T>2`E<R!V87-T86%N
M;W1T86IA;&QE("5S(&]T<VEK:V]N82`B)7,B(&]N(&[D>71E='1Y+@I%:2!O
M;&4@;6ETY.1N('1A:V5I=&$@<VEI=.0@971TY"!V:65S=&D@;VX@;'5E='1U
M('1A:2!Y;6WD<G)E='1Y+@!.:6UI(&IO=&$@:^1Y=&5TY.1N(&QI;FMI=&5T
M=.1E<W-A(&QU;R!S:79U;&QE`$UU:7-T:6EN<&%N;R!O;B!P;VES=&5T='4N
M`$UU:7-T:6QI<W1A82`B)7,B(&5I('9O:71U(&QU;V1A.B`E<P!-=6ES=&EL
M:7-T82`B)7,B(&]N(&QU;W1U+@!-=6ES=&EL:7-T82`B)7,B(&]N('!O:7-T
M971T=2X`375I<W1I;&ES=&$@(B5S(B!O;B!T86QL971E='1U+@!+96YT=&EE
M;B!MY.1RY"!P:73DY"!A;G1A82!N=6UE<F]I;F$N`$UO9'5U;&D@;W!E;G-S
M;"!T87)V:71A86X@2&]R9&5?0W)Y<'1?<VUI;64Z.B`M;'5O:V%N(&OD>71T
MY&UI<V5K<VDN`$%S971U<W1A("(E<R(@:V]S:V$@<V5N('1I961O="!Y;&ET
M=&EVY'0@=&%L;&5T=7-T879A;B!S=75R:6UM86X@<V%L;&ET=6X@<F%J86X`
M3VAJ96QM86$L(&IO;&QA('9O:2!K871S;V$@=FEE<W1I='EY<'!IY"`H)7,I
M+"!E:2!L]GET>6YY="!JY')J97-T96QMY'-TY"X`3&%I;F%U<VUE<FMK:2!P
M:73DY"!O;&QA('EK<VET=.1I;F5N(&UE<FMK:2X`5F%I;B!O:6ME82!J82!V
M87-E;B!P=6]L:0!686EN(&]I:V5A('!U;VQI`$5R;W1I;B!P:73DY"!O;&QA
M('EK<VET=.1I;F5N(&UE<FMK:2X`4&%L=F5L:6X@(B5S(B!O;B!P;VES=&5T
M='4N`%!A;'9E;&EN("(E<R(@;VX@=&%L;&5T971T=2X`4VESY.1N:VER:F%U
M='5M:7-P>7EN=/8@)7,@;VX@<&]I<W1E='1U+@!-Y.1R:71E;'1YY"!R:79I
MY"`H)60I(&5I(&]L92!O;&5M87-S82X`5F%L:>1A:6MA:7-T:65D;W-T;V$@
M(B5S(B!E:2!O;&4@;VQE;6%S<V$N`$MI<FIO:71T86UA<VD@=&5K<W1I(&5I
M('9A<W1A82!T96MS=&GD(')U=61U;&QA+@!686EN('ELY'!U;VQI(&IA(&%L
M87!U;VQI`%9A:6X@>6SD<'5O;&D`5'5O='4@=&EE=&\@:.1V:7-I(&5D96QL
M:7-E;B!K;VAD86X@86EK86YA+@!4=6]T=6$@=&EE9&]S=&]A(&5I('9O:71U
M('1A;&QE='1A82X`3W-I;W1A('=E871H97(N8V]M(&5I(&]L92!KY'ET971T
MY'9I<W/D+@!4965M86AA:V5M:7-T;V$@(B5S(B!E:2!L]GET>6YY="X`07-E
M='5K<VEA(&5I(&]L92!S86%T879I;&QA+@!%:2!O;&4@;W-I;VET82P@:F]T
M:V$@=F]I9&%A;B!NY'ET=.3D('9I97-T:65N('EH=&5Y9&5S<^0N`%3D<W/D
M(&ME;G3D<W/D(&]N(&QI:6%N(&UO;G1A(&UE<FMK:>0N($%N;F]I="`E<R!M
M97)K:VGD.R!S:6YU;B!P:73DY"!A;G1A82!VY&AE;6WD;B!K=6EN("5S(&UE
M<FMK:>0N`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@;&ESY.1M:7-E<W/D(&KD
M<FIE<W1E;&WDY&XZ("5S`$OD>71TY&KD;B`B)7,B(&OD>71TY&KD=&EE=&]J
M96X@<&]I<W1A;6ES97-S82!JY')J97-T96QMY'-SY"!O;&D@;VYG96QM:6$Z
M(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('!O:7-T86UI<V5S<V$@:N1R:F5S
M=&5L;>1S=.0Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('#D:79I='EK<V5S
M<^0Z("5S`%1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L;6EA+B!9:'3D
MY&X@)7,Z82!E:2!T=6]T=0!4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O;F=E
M;&UI82X@)7,@:V]K;R!O;&D@<W5U<F5M<&D@:W5I;B!S=75R:6X@<V%L;&ET
M='4@:V]K;R`H)60@=&%V=6$I+@!4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O
M;F=E;&UI82X@)7,@;&%T875T=6D@=F%I;B!O<V%K<VDN`%1A<&%H='5I('9I
M<FAE(&[D>71E='3D97-SY"!V:65S=&EN('3D=.0@;W-I;W1A`%EH=&5Y<W1I
M971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`5&%P86AT=6D@=FER
M:&4@='5O=&%E<W-A('1I971O83H@)7,`5&%P86AT=6D@=FER:&4@='5O=&%E
M<W-A(&E#86QE;F1A<B!T:65T;VIA+@!487!A:'1U:2!V:7)H92!T=6]T865S
M<V$@=DYO=&4@=&EE=&]J82X`07-E='5S=&EE=&]L;VUA:VME97-S82!O;B!J
M;VMI;B!V:7)H92X@16AKY"!JY'1I="!J;VYK=6X@<&%K;VQL:7-E;B!K;VAD
M86X@=.1Y='3D;>1T=.0N`%1A<&%H='5I('9I<FAE('ER:71E='3D97-SY"!S
M=6]R:71T86$@;W-O:71E:VER:F%T;VEM:6YT;V$N(%ER:73D(&UY]FAE;6UI
M;B!U=61E<W1A86XN`$UU:7-T:6EN<&%N;VX@<&]I<W1A;6ES97-S82!T87!A
M:'1U:2!V:7)H93H@)7,`375I<W1I:6YP86YO;B!T86QL971U:W-E<W-A('1A
M<&%H='5I('9I<FAE.B`E<P!9:'1E>7-T:65T;VIE;B!PY&EV:71Y:W-E<W/D
M('1A<&%H='5I('9I<FAE+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N+@!*
M86ME;'5L:7-T86X@<.1I=FET>6MS97-SY"!T87!A:'1U:2!V:7)H92X@67)I
M=.0@;7GV:&5M;6EN('5U9&5S=&%A;BX`375I<W1I;&ES=&%N(&MA='-E;'5S
M<V$@=&%P86AT=6D@=FER:&4Z("5S`$5I(&UU:7-T:6EN<&%N;VIA('9I973D
M=N1K<VDN`%3D;>0@24U!4"!P86QV96QI;B!E:2!T=64@:V%N<VEO:61E;B!J
M86MA;6ES=&$N`%3D;>0@=&EE9&]S=&\@96D@=F%I:W5T82!R87(M=&EE9&]S
M=&]L=&$N`%3D;>0@=&EE9&]S=&\@96D@=F%I:W5T82!Z:7`M=&EE9&]S=&]L
M=&$N`%3D;>0@96D@=F%I:W5T82!O:6ME86QT82!K;W)T=&EN=6UE<F]L=&$N
M`%3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!#;&EC:V%T
M96QL:6X@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2!P86QV96QU
M82!(5%10($%023IL;&$N`%3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V
M:65S=&5JY"!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y('!A;'9E
M;'5N(&MA=71T82!(5%10($%023IL;&$N`%3D;&SD(&%J=7)I;&QA('9O:2!L
MY&AE='3DY"!V:65S=&5JY"!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN
M8V]M*2!G871E=V%Y('!A;'9E;'5N(&MA=71T82!(5%10($%023IL;&$N`%3D
M;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!6;V1A9F]N96X@
M;G5M97)O:6AI;B!33510.FQLY"!KY'ET=.1E;B!6;V1A9F]N92!)=&%L>2!G
M871E=V%Y('!A;'9E;'5A+B!4Y'3D('!A;'9E;'5A('9O:2!KY'ET=.3D('9A
M:6X@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!T=6YN=6MS
M:6QL82X`5.1MY"!K96YT=.0@;VX@<&%K;VQL:6YE;BX`5.1S<^0@:V5N=.1S
M<^0@<&ETY.0@;VQL82!V86EN(&MO:V]N86ES;'5K=6IA+@!4Y'-SY"!K96YT
MY'-SY"!P:73DY"!O;&QA(&YU;65R;VET82!J82!P:6QK:W4M;65R:VME:N0N
M`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@;VMT86%L:6QU:W5J82X`5.1S
M<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!L:7-T82!K;VMO;F%I<VQU:W5J82P@
M:F]T:V$@<&ETY.0@;VQL82!E<F]T971T=2!P:6QK=6QL82!T86D@=N1L:6QY
M]FYN:6QLY`!!<G9O;B!P:73DY"!O;&QA(&YU;65R;RX`5.1S<^0@:V5N=.1S
M<^0@;VX@=N1R:6WDY')I='ES+"!J;VYK82!P:73DY"!O;&QA(%)'0B!(97@@
M;75O9&]S<RP@97-I;65R:VEK<VD@)R,Q,C,T868G+@!4Y&WD('1I961O<W1O
M;75O=&\@96D@;VQE('1U971T=2X`5.1MY"!L;VUA:V4@;VX@:F\@:^1S:71E
M;'1Y+@!4Y&WD(&]N("5S+@!4Y&WD(&]N($MO;&%B($=R;W5P=V%R92!O8FIE
M:W1I+B!+871S;V%K<V5S:2!TY&WD;B!O8FIE:W1I;B!S:6YU;&QA('!I=.3D
M(&]L;&$@<^1H:_9P;W-T:6]H:F5L;6$L(&IO:V$@>6UMY')TY.0@2V]L86(@
M1W)O=7!W87)E(&9O<FUA871T:6$N($QI<W1A('EH=&5E;G-O<&EV:7-T82!S
MY&AK]G!O<W1I;VAJ96QM:7-T82!L]GET>7D@;W-O:71T965S=&$@)7,`5.1M
MY"!V:65S=&D@;VX@:VER:F]I=&5T='4@97)I(&UE<FMI<W3V;&SD("@E<RD@
M:W5I;B!M:6OD('-I;G5L;&$@;VX@:^1Y=/9S<^0N(`!.=6UE<F]N('!I=.3D
M(&]L;&$@=N1H:6YTY.1N('EK<VDN`%3D;&SD('!A;'9E;&EM96QL82!E:2!V
M;VD@875K86ES=&$@>FEP+2!T86D@9WII<"UT:65D;W-T;VIA+@!4Y&WD(&KD
M<FIE<W1E;&WD(&]N('!O:7,@<.3D;'3D+@!!<G9O;B!P:73DY"!O;&QA(&YU
M;65R;RX`5.1MY&X@:6MK=6YA;B!V;VD@875K86ES=&$@=F%I;B!!<V5T=6MS
M970@:6MK=6YA<W1A`$UY<G-K>0!4:6ME=&ET`$%I:V$`06IA;G-E=7)A;G1A
M`$%J86X@97-I='ES;75O=&\`06IA;B!V86QI;G1A`%1I;6]R+4QE<W1E`%1I
M='1E;&D`3W1S:6MK;R`H=&]O;'1I<"DZ`%9A<W1A86YO='1A:F$`5F]I9&%K
M<V5S:2!V86QI=&$@=7-E86UP:6$@=F%I:'1O96AT;VIA+"!P:63D($-O;G1R
M;VPM("A00RD@=&%I($-O;6UA;F0M("A-86,I(&[D<'#D:6YTY"!P;VAJ87-S
M82!K=6X@;F%P<V%U=&%T(&AI:7)E;B!P86EN:6ME='1A+@!4Y&[DY&X`3N1Y
M=.0@2%1-3"ULY&AD96MO;V1I`%1O9V\`5&]K96QA=0!(=6]M96YN80!4;VYG
M80!,:6EA;B!M;VYT82!E<.1O;FYI<W1U;G5T=&$@:VER:F%U='5M:7-Y<FET
M>7-TY"!V:6EM96ES:6UP:65N(&UI;G5U='1I96X@:W5L=65S<V$N`%EL]G,`
M66QI;7#DY&X@:V5H>6MS965N("A?=&]P*0!+Y.1N;O9K<V5T`%1R:6YI9&%D
M(&IA(%1O8F%G;P!4;W-I('9A:2!E<.1T;W-I`'1I`%1U;FES:6$`5'5R:VMI
M`%1U<FMK:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&IA($-A
M:6-O<R!S86%R970`5'5V86QU`$MI<FIO:71A('9A;&EN=&%S:3H@`%4N5BX@
M+6EN9&5K<VDZ(`!54DP`55),(&IO:&]N('!A;&%U=&5T86%N('-K<FEP=&EN
M('-T871U<R!R87!O<G1T:0!54DPZ`%5G86YD80!5:W)A:6YA`%9&4RUH86ME
M;6ES=&]A(&5I('9O:71U(&QU:V5A+@!+Y'ET=.1JY&X@;&ESY'1I971O:F5N
M(&QI<^1Y<R!E:2!O;FYI<W1U;G5T(&MI<FIA=71U;6ES97-S82X`16D@=F]I
M('9A:6AT86$@;VEK975K<VEA(%9&4RUT:65D;W-T;VQL92`B)7,B+@!%:2!V
M;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE("5S+R5S+@!%
M:2!V;VED82!V86EH=&%A("5S.FXN`%1I961O<W1O;B`B)7,B(&MO:V]A(&5I
M('9O:71U('1A<FMI<W1A82X`16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!6
M1E,M=&EE9&]S=&]A("(E<R\E<R(N`%-13"UP86QV96QI;65E;B!E:2!S86%D
M82!Y:'1E>71TY"X`66AT97ET=.0@96D@=F]I9&$@;75O9&]S=&%A(%-33"US
M86QA='1U;F$N`%9&4RUT:65D;W-T;V$@96D@=F]I9&$@:V]P:6]I9&$N`$5I
M('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A("(E<R(N`$5I('9O:61A(&QU
M;V1A(%9&4RUH86ME;6ES=&]A+@!%:2!V;VET=2!L=6]D82!61E,M=&EE9&]S
M=&]A`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+6MA;G-I;W1A("(E
M<R(N`$5I('9O:71U(&QU;V1A('1Y:&KDY"!61E,M=&EE9&]S=&]A+@!4:65T
M;V$@96D@=F]I9&$@;&%A:F5N=&%A+@!%:2!V;VED82!P;VES=&%A("(E<R(L
M(&AA:V5M:7-T;R!E:2!O;&4@='EH:N0N`$5I('9O:61A('!O:7-T86$@(B5S
M(CH@)7,`16D@=F]I9&$@<&]I<W1A82`B)7,B.B`E<RX`16D@=F]I9&$@<&]I
M<W1A82`E<RP@:&%K96UI<W1O(&5I(&]L92!T>6AJY"X`16D@=F]I9&$@<&]I
M<W1A82!61E,M:&%K96UI<W1O82!R96MU<G-I:79I<V5S=&DN`$5I('9O:61A
M('!O:7-T86$@5D93+6AA:V5M:7-T;V$N`$5I('9O:61A('!O:7-T86$@5D93
M+6AA:V5M:7-T;V$Z("5S+@!%:2!V;VED82!P;VES=&%A(%9&4RUT:65D;W-T
M;V$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A+@!%:2!V
M;VED82!P;VES=&%A(%9&4RUK86YS:6]T82`B)7,B+@!%:2!V;VED82!P;VES
M=&%A(%9&4SKDY"!R96MU<G-I:79I<V5S=&DZ("5S+@!.>6MY:7-TY"!H86ME
M;6ES=&]A(&5I('9O:71U('-E;'9I='3DY"X`5F%R;65N=&5E;B!T:65T;VIA
M(&5I('9O:61A(&5X=')A:W1O:61A`$WDY')I='EK<V5N("5S(&QU:V5M:6YE
M;B!E<.1O;FYI<W1U:2X`16D@=F]I9&$@<VEI<G3DY"!61E,M=&EE9&]S=&]A
M+@!%:2!V;VED82!P;VES=&%A(%9&4RUT:65D;W-T;V$@(B5S(BX`16D@=F]I
M9&$@879A=&$@5D93+71I961O<W1O82!K:7)J;VET=7-T82!V87)T96XN`$5I
M('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$N`%1I:79I<W1E='EN('1I961O
M<W1O;B!A=6MA:7-U(&5PY&]N;FES='5I+@!%:2!V;VET=2!L=6ME82!61E,M
M=&EE9&]S=&]A("AF:6QE<VEZ92@I(&5PY&]N;FES='5I*2X`16D@=F]I9&$@
M;'5K96$@5D93+71I961O<W1O82`H9V5T1FEL95-I>F4H*2!E<.1O;FYI<W1U
M:2DN`$5I('9O:71U(&QU:V5A('1I961O<W1O83H@`'9F<W)O;W0@:G5U<FEH
M86ME;6ES=&]A(&5I('9O:71U(&QU:V5A+@!5=61E;&QE96YN:6UEY&UI;F5N
M("5S("5S.FMS:2!E<.1O;FYI<W1U:2!K;W-K82!K;VAD96AA:V5M:7-T;R!O
M;B!J;R!O;&5M87-S80!%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&4RUH
M86ME;6ES=&]A+@!%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&4RUH86ME
M;6ES=&]A.B`E<RX`16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M=&EE
M9&]S=&]A("(E<R(N`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I
M961O<W1O82`E<R\E<RX`16D@=F]I='4@;FEM973D('5U9&5L;&5E;B!61E,M
M=&EE9&]S=&]A+@!%:2!V;VED82!S=6]R:71T86$@:V]M96YT;V$@)VUK:7-O
M9G,G+@!7;W)D+61O:W5M96YT=&EA(&5I('9O:71U(&ODY&YTY.0`16D@=F]I
M9&$@:VER:F]I='1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&MI
M<FIO:71T86$@5D93+71I961O<W1O;VX@*&-O<'DH*2!E<.1O;FYI<W1U:2DN
M`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O<W1O;B!T:65T;VIA+@!%
M:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T;V$L(&MI:6YT:?8@;VX@
M=.1Y;F[D+@!!;&QE=FEI=F%T='4`4&5R=2!M=75T;VMS970`4&5R=2!M=75T
M;VMS970`4&5R=75T=&%A(&5D96QL:7-E;B!T;VEM96YP:71E96X`5'5N=&5M
M871O;B!V87-T875S('!A;'9E;&EM96QT82!Y:'1E>71E96XZ`%1U;G1E;6%T
M;VX@=F%S=&%U<R!P86QV96QI;65L=&$Z(`!,=6]K:71T96QE;6%T;VX`56YI
M8V]D92`H551&+3@I`%EH9&ES='EN965T(&%R86)I96UI<F%A=&ET`%EH9&ES
M='EN965T(&MU;FEN9V%S:W5N;F%T`%EH9'ES=F%L;&%T`%EH9'ES=F%L=&]J
M96X@5'EY;F5N;65R96X@97)I;&QI<W-A87)E=`!-:71T87EK<VEK]G0`5'5N
M=&5M871O;@!4=6YT96UA=&]N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M`%1U;G1E;6%T;VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`06YN
M971T=2!P86EK:V%T:65T;R!O;B!T=6YT96UA=&]N+@!4=6YT96UA=&]N(&OD
M>71TY&KD='5N;G5S('1A:2!S86QA<V%N82X`4&]I<W1A(&YY:WEI<V5N(&5L
M96UE;G1I;B!L:6YK:71Y<P!.:6UE=/9N`%1I971O='5R=F%S>6ES=.0@96DM
M<')I=FEL965G:7-E="!S:W)I<'1I="!E:7;D="!V;VD@:W5T<W5A($QE:6MK
M86$O2V]P:6]I+TQI:73D('1O:6UI;G1O:F$N($YA<'-A=71A($]++6YA<'!U
M;&%A(&[D:&3D:W-E<VD@;6]Z:6QL82YO<F<@<VEV=6EL;&$@;VQE=F%N(&]H
M:F5E;BP@:F]S<V$@;F5U=F]T86%N(&UI=&5N('-K<FEP=&ES:2!V;VEV870@
M:^1Y='3DY"!L96EK97#V>73DY"X`4&]I<W1A(';D<FD`16D@='5E='1U($-O
M;G1E;G0M5'EP93H@)7,`16DM='5E='1U(&QA86IE;FYU<P!0Y&EV:73D`%#D
M:79I=.0@)7,`4.1I=FETY"!KY'ET=.1JY`!0Y&EV:71E='1I:6X@(B5S(BX`
M4.1I=FET>7-S:W)I<'1I('!O:7-T971T:6EN+@!4=6\`='5O(&MA:6MK:2!O
M:&IE;&UI96X@87-E;FYU<W1I961O<W1O="!P86QV96QI;65L;&4N`$ES;W0@
M;&%T:6YA;&%I<V5T(&MI<FIA:6UE=`!)<V]T(')O;VUA;&%I<V5T(&YU;65R
M;W0`57)U9W5A>0!+Y'ETY"!N>6MY:7-TY#H@)7,`2^1Y=.0@4U-,+7-A;&%U
M<W1A`$OD>73D(&IO<R!T=6YN=7,O<V%L87-A;F$@;VX@97)I($E-4U`M<&%L
M=F5L:6UE;&QE+@!+Y'ET=.1JY`!+Y'ET=.1JY&QLY"`E<R!E:2!O;&4@;VEK
M975K<VEA('1E:&3D("5S+@!+Y'ET=.1J:65N('EL;.1P:71O`$OD>71TY&KD
M;B!A<V5T=6MS970`2^1Y='3D:N1N(')E:VES=&5R]FEM:6YE;@!4Y'-SY"!J
MY')J97-T96QMY'-SY"!E:2!V;VD@<F5K:7-T97+V:63D(&OD>71TY&IIY"X`
M2^1Y='3D:N1T=6YN=7-T82!E:2!L]GET>6YY="X`2^1Y='3D:N1T=6YN=7,`
M2^1Y='3D:N1T=6YN=7,@(B5S(B!O;B!J;R!O;&5M87-S82X`2^1Y='3D:N1T
M=6YN=7,Z`$OD>71TY&KD='5N;G5S.B``2N1R:F5S=&5L;>1N(&OD>71TY&KD
M=#H`57IB96MI<W1A;@!61E,M:&%K96UI<W1O82!E:2!O;&4@;VQE;6%S<V$N
M`%!O:7-S86]L;W9I97-T:0!086EK:V]J82!L]GET>6D@97-I;65R:VEK<VDZ
M(`!6;VEM87-S86]L;V%I:V$`07)V;R!M:6YU=71E:7-S82!N>6MY:&5T:V5S
M=.0N`$%R=F\@;VX@>6QI('!I='5U9&5N(&UA:W-I;6EA<G9O;B`E<RX\`$%R
M=F]T`%9A;&ET=&%V870@87)V;W0`5F%N=6%T=0!686EH=&5L979A80!696YE
M>G5E;&$`5&%R:VES='5S(&5PY&]N;FES='5I("T@5.1TY"!V:65S=&GD(&]N
M('9O:71U(&OD<VET96QLY"X`5F5R<VEO`%9E<G-I;VYH86QL:6YT80!0>7-T
M>7-U;W)A('1A<V%U<P!0>7-T>7-U;W)A('3D>71E`%!Y<W1Y<W5O<F$Z`$5R
M:71TY&EN(&MO<FME80!6:65T;F%M`%9I971N86T@*%9)4T-)22D`3N1Y=.0@
M)7,`3N1Y=.0@97)I;&QI<V5NY"!W=W<M<VEV=6YA`$[D>73D("5S`$YE:71S
M>71S86%R970L($)R:71T:6SD:6YE;@!.96ET<WET<V%A<F5T+"!9:&1Y<W9A
M;'1A:6X`3N1K>7;D:7-Y>7,`3N1K>7;D:7-Y>7,Z(`!6;V1A9F]N92!)=&%L
M>2!33510.FX@879U;&QA`%9!4D])5%53`%9!4D])5%53(2$A(%!/25-402!3
M2U))4%1)($OD4TE.(%!!3%9%3$E-14Q402`E<RX`5TE.($A45%`Z;B!A=G5L
M;&$`5V%L;&ES(&IA($9U='5N80!687)O:71U<P!K90!3Y.1E;FYU<W1E`%/D
MY'1I961O="!O;B!T;VEM:71T86YU=`!796%T:&5R+F-O;0!75U<`5U=7+7-I
M=G5S=&\`5FEI:V]I='1A:6X`5&5R=F5T=6QO80!497)V971U;&]A(&]H:F5L
M;6%A;B`E<P!497)V971U;&]A+"`E<P!,Y&YS:6UA:6YE;B`H25-/+3@X-3DM
M,2D`3.1N<VEM86EN96XO175R;R`H25-/+3@X-3DM,34I`$SD;G-I+5-A:&%R
M80!-:6YKY"!O:&IE;&UA;B`E<R!KY'EN;FES=.3D('-I<^3D;FMI<FIA=71U
M;6ES96X@:N1L:V5E;BX`36ETY"!M97)K:VGD(&OD>71E=.3D;B!E<F]T=&EM
M96YA/P!-:73D(&UE<FMK:>0@:^1Y=&5TY.1N(&QA:6YA=6MS965N/P!7:&5R
M96ES($%U<W1R86QI86X@:V%R='1A`$UI:&EN(&UU:7-T:6QI<W1A86X@;75I
M<W1I:6YP86YO="!L:7/D=.3D;C\`36ET:^0@=F%I:&5E=`!6;VET(&WDY')I
M=&5L;.0@;&ESY'1O:6UI;G1O:F$@;&%I=&5T86%N('#DY&QL92!2:6-H(%1E
M>'0@961I=&]R:7-S82X`3&5V97ES`$QE=F5Y<R!#4U,@;6ET=&%Y:W-I:VOV
M:6[D`%9A<V5M;6%L;&$@;VQE=F%N("5S('9A;&EK;VX@;&5V97ES("AT=6QE
M92!V;VEM86%N('-E=7)A879A;&QA('-I<^3D;FMI<FIA=71U;6ES96QL82DZ
M`%1A=6QU:V]N(&QE=F5Y<P!,979E>61E;B!Y:W-I:VOV`$QE=F5Y<SH`5VEK
M:0!4=75L:0!4=75L:7-T82!A:6MA:7-I;@!4=75L96YN;W!E=7,@<V]L;75I
M<W-A`%1U=6QI.@!4=75L:3H@`%9I:7-A=7,`5&]I=F5L:7-T870`5'GV`$]S
M;VET92`H='GV*0!0=6AE;&EN("AT>?8I`%;DY'+D(&WDY'+D(&ME;G1T:>0@
M<FEV:6QLY"`E9"X@3V1O=&5T=&EI;B`E9"P@;/9Y='EI("5D+@!6Y.1RY"!M
MY.1RY"!K96YT=&GD+B!/9&]T971T:6EN("5D+"!L]GET>6D@)60N`%;DY'+D
M('!O:6MK96%M82`E9"!L=65T=&%E<W-A(%9&4RUT:65D;W-T;V$N`%@M4F5F
M`%@U,#EV,R!P97)U<W)A:F]I='1E970`6#4P.78S(&QI<^1T;VEM:6YN;W0@
M879A:6UE;B!KY'ET]FQL90!8-3`Y=C,@2V]H=&5E;B!V86EH=&]E:'1O:6YE
M;B!N:6UI`%@U,#EV,R!+;VAT965N(&%V86EM96X@='5N;FES=&4`6#4P.78S
M+6QA86IE;FYU:W-E=`!65@!65E96`%EA:&]O(2!K87)T=&$`5G5O<VET=&%I
M;@!*96UE;@!+>6QLY`!+>6QLY"P@<W5O<W1U;BX`2^1Y=.1T(%1%2U-4251)
M3$%!+B!+Y'ETY"!;/#Y=(&YA<'!U;&%A('9A:6AT86%K<V5S:2!T86MA:7-I
M;B!765-)5UE'+71I;&%A;BX`170@=F]I('1E:&3D(&5N96UPY.0@:W5I;B`E
M9"!O<VEO=&$N`%-I;G5L;&$@96D@<V%A(&]L;&$@:W5I;B!E;FEN=.3D;B`E
M9"!M=6ES=&EI;G!A;F]A+@!%="!O;&4@875T96YT:6MO:71U;G5T+@!.:6UE
M<W/D<VD@96D@<V%A(&]L;&$@)UPG+6UE<FMK:>0N`$5T(&%N=&%N=70@;VEK
M96%N(&UU;W1O:7-T82!SY&AK]G!O<W1I;W-O:71E='1A+@!%="!MY.1R:71E
M;&QY="!M:71KY"!T=6]D=6X@=&EE9&]S=&]N(&ME;G3D="!V87-T86%V870@
M;6ETY&MI;B!K96YT=&GD("5S.G-SY"X`4VEN=6QL82!E:2!O;&4@;VEK975K
M<VEA('-E;&%T82!M=6ES=&EL:7-T86$@)7,N`$]L970@:VER:F%U='5N=70@
M=6QO<RX`4VEN=6X@<&ETY.0@86YT86$@;VEK96$@;6%T:V%P=6AE;&EN;G5M
M97)O+"!V86EN(&YU;65R;VET82!J82!M86AD;VQL:7-E<W1I("<K)R!J;W,@
M:^1Y=.1T(&MA;G-A:6YVY&QI<W3D('!U:&5L:6YN=6UE<F]M=6]T;V$N`%-I
M;G5N('3D>71Y>2!A;G1A82!O:6ME82!A<G9O+@!3:6YU;B!P:73DY"!A<V5N
M=&%A($1A=&%4<F5E+71A=7-T86KD<FIE<W1E;&WD(&5N;F5N(&MU:6X@=F]I
M="!KY'ET=.3D(%-I9VYU<"UT;VEM:6YT;VIA+@!3:6YU;B!P:73DY"!A<V5N
M=&%A(%9&4RUT875S=&%JY')J97-T96QMY"X`4VEN=6X@='5L964@:W5V86EL
M;&$@;VYG96QM871I;&%N;F5T=&$@96YN96X@:W5I;B!V;VET(&SD:&5T=.3D
M(&]N9V5L;6%V:65S=&EN+@!3:6YU;B!P:73DY"!A;G1A82!54DP@;6EH:6X@
M=.1MY"!L:6YK:VD@;W-O:71T86$`4VEN=6X@<&ETY.0@=F%L:71A('!O:7-T
M971T879A(&UU:7-T:6QI<W1A+@!3:6YU;B!P:73DY"!V86QI=&$@<&]I<W1E
M='1A=F$@<&%L=F5L:6XN`%-I;G5N('!I=.3D(&%N=&%A('!O:7-T971T879A
M(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!A;G1A82!P;VES=&5T=&%V
M82!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@;&ESY'1TY';D
M(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!A;G1A82!PY&EV:71E='3D
M=N0@:^1Y='3D:N1T=6YN=7,N`%-I;G5N('!I=.3D('9A;&ET82!S=6]R:71E
M='1A=F$@=&]I;6EN=&\N`%-I;G5N('!I=.3D(&%N=&%A('5U9&5N(&MA=&5G
M;W)I86X@;FEM:2X`4VEN=6X@<&ETY.0@86YT86$@:71A;&EA;&%I;F5N('!U
M:&5L:6YN=6UE<F\`27-T=6YT;W-I("5S(&]N('9A;FAE;G1U;G5T+B!+:7)J
M875D=2!U=61E;&QE96X@<VESY.1N+@!3Y&AK]G!O<W1I;W-O:71T965S:0!3
M:6YU;B!LY&AE='3D:N1O<V]I='1E97-I.@!/;6%T('1I971O<VD`4VEN=6X@
M=&EE=&]K;VYE97-I(&OD>71TY&WD('1I971O=F5R:VMO+6]S;VET92!O;B!M
M=75T='5N=70@<V5N(&KD;&ME96X@:W5N(&]L970@86QO:71T86YU="`E<R!I
M<W1U;FYO;BX@5&EE=&]T=7)V87-Y:7-TY"!S:6YU;B!P:73DY"!K:7)J875T
M=6$@=75D97-T86%N(&KD<FIE<W1E;&WDY&XN`$YI;65S:0!+Y'ET=.1MY'-I
M(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WD(&5I('1U92!KY'ET
M=.1J:65N(&QI<^3D;6ES=.0N($IO<R!H86QU870@:&%L;&EN;F]I9&$@:^1Y
M='3D:N1T=6YN=6MS:6$L('-I;G5N('!I=.3D(&OD>71TY.0@:F]T86MI;B!T
M;VES=&$@875T:&5N=&EC871I;VX@=&%U<W1A:N1R:F5S=&5L;>3D+@!+Y'ET
M=.1MY'-I(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WD(&5I('1U
M92!KY'ET=.1JY'1I971O:F5N(&[D>71TY&UI<W3D('1A:2!TY&WD('!I:7)R
M92!E:2!O;&4@:F]S=&%K:6X@<WEY<W3D(&OD>71E='3D=FES<^0N`%-I;G5N
M(&OD>71TY&WD<VD@=W=W+7-E;&%I;B!NY'ET=.3D(&]L979A;B!M=75T='5N
M=70@<V5N(&KD;&ME96X@:W5N(&]L970@86QO:71T86YU="`E<R!I<W1U;FYO
M;BX@5&EE=&]T=7)V87-Y:7-TY"!S:6YU;B!P:73DY"!K:7)J875T=6$@=75D
M97-T86%N:N1R:F5S=&5L;>3D;BX`4V5L86EM97-I(&5I('1U92!TY'3D('1O
M:6UI;G1O82X`4V5L86EM97-I(&5I('1U92!T87)V:71T879A82!T=6QO<W1U
M<W1O:6UI;G1O82X@4&%I;F$@0V]N=')O;"]/<'1I;VX@*R!0('1U;&]S=&%A
M:W-E<VDN`$%I:V%V>?9H>6MK965S:3H`3VQE='5S<')O9FEI;&ES:2!O;B!M
M=75T971T=2X`3VQE='5S<')O9FEI;&ES:3H`3VQE='5S;75I<W1I;&ES=&%S
M:3H`3FEM97-I.@!)<W1U;G1O<VD@;VX@=F%N:&5N='5N=70N`%-I;G5N('-A
M;&%S86YA<VD@)7,Z;&QE(&]N.B`E<P!-=6ES=&EL:7-T87-I.@!!<V5T=6MS
M97-I(&]N('#D:79I=&5T='D@:F$@;F4@;W9A="!V;VEM87-S82!TY&WD;B!I
M<W1U;FYO;B!A:F%N+@!!<V5T=6MS97-I(&]N('#D:79I=&5T='DN`%-A;&%S
M86YA<VD@;VX@;F]L;&%T='4`4V%L87-A;F%S:2!O;B!N;VQL871T=2P@=&%R
M:VES=&$@<^1H:_9P;W-T:7-I(&IA(&MI<FIA=61U('-I<^3D;B!U=61E;&QA
M('-A;&%S86YA;&QA<VDN`%-A;&%S86YA<VD@;VX@=F%N:&5N='5N=70N`$5T
MY'!A;'9E;&EM97-I.@!*=6=O<VQA=FEA`%IA:7)E`%-A;6)I80!::6UB86)W
M90!::7!P>0!;4&EI;&]T82!L86EN871T=2!T96MS=&E=`%M/;F=E;&UA70!;
M3N1Y=.0@;&%I;F%T='4@=&5K<W1I("T`6T[D>73D(&QA:6YA='1U('1E:W-T
M:2`M("5S(')I=FGD70!;<FEV:6QLY"`E<R\E<UT`7UEL;.1P:71O`%]486MA
M:7-I;B!M=6ES=&EL:7-T86%N`%]+;VUE;G1O='5L:VMI`%]+871E9V]R:6$`
M7T1A=&%4<F5E`%]0;VES=&$`7U!O:7-T82!R:79I`%]-=6]K:V%A`%]%;G-I
M;6WD:6YE;B!R:79I`%]2>6AMY'0`7T]H:F4`7TMU=F%N('1I961O="XN+@!?
M5'5O+U9I90!?3&ES=&%A(&UU:7-T:6EN<&%N;W0`7TMI<FIA=61U('-I<^3D
M;@!?2VER:F%U9'4@=6QO<P!?375O:VMA82!L:6YK:VGD`%]/;6%T(&UU:7-T
M:6QI<W1A;FD`7U5U<VD@;75I<W1I:6YP86YO`%]!<V5T=6MS970`7T]I:V5U
M9&5T`%]4=6QO<W1A`%!O:7-T82!L:6YK:VDN+BX`7TAA:W4`7T%S96YN=7,`
M7U1A=6QU:V]N('1I961O="XN+@!?2^1Y='3D:N1T`&]S;VET96MI<FIA`'9A
M<W1A86YO='1A:F$@='5N=&5M871O;@!K86QE;G1E<FD`='EY;G3D`&5I('9O
M:2!L=6]D82!T=6QO<W1I961O<W1O80!E:2!V;VD@875K86ES=&$@;.1H9&5T
M=.0`;F%P<V%U=&$@=.1S=.0`=FER:&4@:V]M96YT;W)I=FEL;.0`87-E='5S
M=FER:&4`:W)I:71T:6YE;B!JY')J97-T96QMY'1I961O<W1O('!U=71T=74`
M;75O=&]V:7)H92!T:65D;VES<V$`;75O:VMA80!T:65T=65T=&$@96D@;/9Y
M='EN>70`;&%S:V5V80!T:65D;W-T;P!S=75N;F%S=&$@)7,@*"5S*2!N;W!E
M=61E;&QA("5S("5S`'!U=7-K:71T86EN`&@Z`&AH`'1U;G1E;6%T;VX@<&%L
M=F5L:6UE;B!N:6UI`';D;&ET=/9MY'-T:0!I;FQI;F4`:6\M=FER:&4`;VAJ
M96QM:7-T;VX@<VESY&EN96X@=FER:&4`<FEV:71=`&UK:7-O9G,@=FER:&5K
M;V]D:2`E9"!)4T\Z82!T96AD97-SY"X`;6T`;FEM:0!E:2!O;&4@=&]T975T
M971T=0!E:2!O;&4@=FEE;.0@=&]T975T971T=0!M=6ES=&EL:7-T80!N;W1E
M<RYC<W8`<')O<V5N='1I`&OD>71T]B!K:65L;&5T='D`<&EK<V5L96ETY`!E
M=.1V:7)H92!P<F]T;VMO;&QA<W-A`&YO=7-E=F$`<&%L=F5L=2!E:2!O;&4@
M:^1Y=&5T=.1V:7-SY`!NY'ETY"!E<F]T`'-M<S)E;6%I;"!(5%10.FX@879U
M;&QA`'-S`'9A:V%A`&KD<FIE<W1E;&WD=FER:&4`=&5H=.1VY&QI<W1A`';D
M;&EA:6MA:6YE;B!V:7)H90!V87)M:7-T86%K<V5S:2!K:7)J;VET82!S86QA
M<V%N82!K86AD97-T:0!U;FEF:65D`&YI;65T]FX`:^1Y='3D:N1N('9A;&EN
M=&$`=D-A<F0`=DYO=&4`=SH`=V5A=&AE<BYC;VT`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O9FE?1DDO:&5L<"YX;6P`````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,C4U`#$P-#$W,S8R-S0T`#`R
M,30S,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&UN96UO+VQO
M8V%L92]F:5]&22]H96QP+GAM;"QV(#$N-"XQ,BXS(#(P,#8O,#(O,C`@,3$Z
M,C`Z,SD@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](D]V97)V
M:65W(B!M9#4](C4P964W-C$S.&9B,#AB,#1B,#(Y,#`V,#4S8F)A9&)C(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/EEL96ES:W5V83PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY%<VET=&5L>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@/&D^375I<W1I:6YP86YO=#PO:3X@;VX@;VAJ96QM82P@:F]L;&$@=F]I
M="!T96AD)B-X130[(&UU:7-T:6EN<&%N;VIA"B`@("!T:65T;VMO;F5E;&QE
M+"!S)B-X130[:&LF(WA&-CMI;F5N('9A<W1I;F4@;75I<W1I;&%P=6QL92X@
M375I<W1I:6YP86YO:F$@=F]I"B`@("!L=6]D82P@;75O:V%T82P@<&]I<W1A
M82!J82!T=6QO<W1A82X@5F]I="!M>28C>$8V.W,@971S:28C>$4T.R!T:65T
M;VIA"B`@("!M=6ES=&EI;G!A;F]I<W1A<VDN($UU:7-T:6EN<&%N;VIA('9O
M:2!M>28C>$8V.W,@=FEE9"8C>$4T.R!J82!T=6]D82X*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@5&]I<VEN(&MU:6X@=&%V86QL:7-I<W-A(&UU:7-T
M:6EN<&%N;VES<V$L('9O:70@:F%K86$*("`@('1I971O:V]N965L;&$@;VQE
M=F%T(&UU:7-T:6EN<&%N;W0@=&]I<VEL;&4@:6AM:7-I;&QE+"!V86EK82!N
M)B-X130[;28C>$4T.PH@("`@;VQI<VEV870@9GEY<VES97-T:2!E<FD@<&%I
M:V]I<W-A+B!6;VET(&UY)B-X1C8[<R!J)B-X130[<FIE<W0F(WA%-#LF(WA%
M-#L@;75I<W1I:6YP86YO=`H@("`@97)I(&MA=&5G;W)I;VEH:6XN"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)L:7-T+6%C=&EO;G,B(&UD
M-3TB-F0U.3)F,34S8F9B-6,R.39D935D9F5B8C0R.&4Q8F$B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^3&ES=&%A(&UU:7-T:6EN<&%N;W0Z(%1O
M:6UI;FYO=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY4;VEM:6YN;W0\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(#QI/E!O:7-T82!M=6ES=&EI;G!A;F\\+VD^
M('!O:7-T86$@<'ES>78F(WA%-#MS=&D@=F%L:71U;B!M=6ES=&EI;G!A;F]N
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`\:3Y-=6]K:V%A(&UU:7-T
M:6EN<&%N;V$\+VD^(&UA:&1O;&QI<W1A82!O;&5M87-S86]L979A;B`@;75I
M<W1I:6YP86YO;B!M=6]K:V%A;6ES96XN"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@(#QI/E1A:V%I<VEN(&UU:7-T:6QI<W1A86X\+VD^('!A;&%A('1A
M:V%I<VEN('-I:6AE;B!M=6ES=&EL:7-T86%N+"!J;VAO;B!V86QI='1U(&UU
M:7-T:6EN<&%N;R!K=75L=74N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)M96YU+6%C=&EO;G,B(&UD-3TB-S$U83@U,V0Y,V-D,S,S,&4T
M9#<S,&(Y,3$R8SAA.#(B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^
M5F%L:6MO;B!T;VEM:6YN;W0\+W1I=&QE/@H@("`@/&AE861I;F<^5F%L:6MO
M;B!T;VEM:6YN;W0\+VAE861I;F<^"B`@("`\<&%R83X*("`@(#QI/DQI<W1A
M82!M=6ES=&EI;G!A;F]T/"]I/B!N)B-X130[>71T)B-X130[)B-X130[(&QI
M<W1A;F$@:V%I:VMI(&UU:7-T:6MI<FIA;B!M=6ES=&EI;G!A;F]T+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("`\:3Y5=7-I(&UU:7-T:6EN<&%N;SPO
M:3X@=F]I="!L=6]D82!U=61E;B!M=6ES=&EI;G!A;F]N('9A;&ET='5U;B!M
M=6ES=&EK:7)J86%N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`\:3Y(
M86MU/"]I/B!V;VET(&AA:V5A('1I971O:F$@;75I<W1I:6YP86YO:7-T82X@
M5F]I="!H86ME82!K=79A=7-K96YT)B-X130[;B!P97)U<W1E96QL82!T86D@
M:&%K96$@=&EE=&]J82!M=6ES=&EI;G!A;F]N(&MO:V\@=&5K<W1I<W0F(WA%
M-#LN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#QI/E1U;R]6:64\+VD^
M('9O:70@='5O9&$@=&%I('9I960F(WA%-#L@;75I<W1I:6YP86YO:F$N(%0F
M(WA%-#ML;"8C>$4T.R!H971K96QL)B-X130[('1U971T=6EN82!O=F%T($-3
M5BT@:F$@=DYO=&4M;75O9&]T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("`\:3Y4=6QO<W1A/"]I/B!V;VET('1U;&]S=&%A(&UU:7-T:6EN<&%N;VXN
M(#QI/E1U;&]S=&$\+VD^("UI:V]N:2!O;B!N)B-X130[:WEV:7-S)B-X130[
M('9A:6X@:W5N(&]L970@:V%T<V]M87-S82!Y:W-I='0F(WA%-#MI<W0F(WA%
M-#L@;75I<W1I:6YP86YO82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G-O<G1I;F<B(&UD-3TB8V-A,V(Q9#%C.65D,&5C-6%B,S@U9C@R
M-#8Y9&1C.&8B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^365R:VEN
M="8C>$8V.VIE;B!L86II='1E;'4\+W1I=&QE/@H@("`@/&AE861I;F<^365R
M:VEN="8C>$8V.VIE;B!L86II='1E;'4\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($UU:7-T:6EN<&%N;VIE;B!L:7-T86$@;VX@;6%H9&]L;&ES=&$@;&%J
M:71E;&QA(&UI;FLF(WA%-#L@=&%H86YS82!S87)A:VME96X@;75K86%N(&YA
M<'-A=71T86UA;&QA('-A<F%K:V5E;B!O='-I:VMO82X@5F]I="!M=75T=&%A
M(&QA:FET=&5L=6$@;F]U<V5V86MS:2!T86D@;&%S:V5V86MS:2!N87!S875T
M=&%M86QL82!O='-I:V]N('9I97)E<W,F(WA%-#L@;VQE=F%A(&YU;VQI(&EK
M;VYI82X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO
M+VQO8V%L92]F<E]&4B\`````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#$W-S<T`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+V9R7T92+TQ#7TU%4U-!1T53+P``
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P
M,C$U-C$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O9G)?
M1E(O3$-?34534T%'15,O;6YE;6\N;6\`````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#0Q
M,C$R`#$P-#$W,S8R-S0T`#`R,S(S,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````.('```<````+#\``(4*```\
M?@```````%"H```.````4:@```\```!@J```#0```'"H```(````?J@```L`
M``"'J```#````).H```$````H*@``!@```"EJ```&P```+ZH```M````VJ@`
M`!T````(J0``)````":I```I````2ZD``!D```!UJ0``)@```(^I```,````
MMJD``"0```##J0``"````.BI```/````\:D```L````!J@``#@````VJ```%
M````'*H``"@````BJ@``"````$NJ```*````5*H``!4```!?J@``$@```'6J
M```+````B*H``!T```"4J@``A0```+*J```.````.*L```H```!'JP``#0``
M`%*K```.````8*L``!$```!OJP``#0```(&K```,````CZL```T```"<JP``
M!@```*JK``"4````L:L```H```!&K```#P```%&L```8````8:P```P```!Z
MK```!@```(>L```.````CJP```X```"=K```"````*RL```)````M:P``"X`
M``"_K```&@```.ZL```R````":T``#@````\K0``5````'6M``!1````RJT`
M`%H````<K@``5P```'>N```T````SZX```D````$KP``#0````ZO```'````
M'*\```H````DKP``#P```"^O```%````/Z\```8```!%KP``$0```$RO```(
M````7J\```D```!GKP``"0```'&O```E````>Z\``"````"AKP``'````,*O
M```>````WZ\``"````#^KP``$P```!^P```0````,[````\```!$L```"@``
M`%2P```#````7[````\```!CL```%````'.P```)````B+````T```"2L```
M$@```*"P```9````L[```!X```#-L```#P```.RP```,````_+````H````)
ML0``#P```!2Q```(````)+$``"0````ML0``%````%*Q```6````9[$```@`
M``!^L0``3@```(>Q```M````UK$``!$````$L@``&0```!:R```'````,+(`
M``P````XL@``+````$6R```.````<K(```,```"!L@``"P```(6R```'````
MD;(```<```"9L@``!0```*&R```%````I[(```H```"ML@```P```+BR```7
M````O+(```H```#4L@``#P```-^R```.````[[(``!@```#^L@``(P```!>S
M```.````.[,``!0```!*LP``%P```%^S```7````=[,``!<```"/LP``$P``
M`*>S```/````N[,```X```#+LP``'P```-JS```=````^K,```<````8M```
M!@```""T```(````)[0```\````PM```!@```$"T```*````1[0``!,```!2
MM```"P```&:T```0````<K0``!4```"#M```%0```)FT```'````K[0``!``
M``"WM```!0```,BT```5````SK0``!$```#DM```#````/:T```[`````[4`
M`#@````_M0``"0```'BU```'````@K4``!0```"*M0```P```)^U```%````
MH[4```D```"IM0``$````+.U```)````Q+4``!,```#.M0``.0```.*U```2
M````'+8``"<````OM@``+````%>V```J````A+8``"4```"OM@``"@```-6V
M```&````X+8```D```#GM@``!P```/&V```O````^;8``#<````IMP``+@``
M`&&W``!5````D+<``"T```#FMP``+0```!2X```]````0K@``#\```"`N```
M+0```,"X``!`````[K@``",````ON0``(P```%.Y``!`````=[D``"T```"X
MN0``,P```.:Y```E````&KH``!4```!`N@``&0```%:Z```I````<+H``"0`
M``":N@``*````+^Z```5````Z+H``!$```#^N@``"@```!"[```,````&[L`
M``\````HNP``%P```#B[```*````4+L``!````!;NP``%@```&R[```6````
M@[L```<```":NP``!P```**[```4````JKL```H```"_NP``"````,J[```G
M````T[L```@```#[NP``!P````2\```'````#+P```8````4O```!0```!N\
M```'````(;P```8````IO```"````#"\```I````.;P```X```!CO```"@``
M`'*\```$````?;P```<```""O```"0```(J\```&````E+P``!$```";O```
M!P```*V\```6````M;P```0```#,O```"````-&\```&````VKP```T```#A
MO```!@```.^\```>````]KP``!$````5O0``"````">]```-````,+T```P`
M```^O0``!P```$N]```#````4[T```,```!7O0``%P```%N]```#````<[T`
M`!,```!WO0``'0```(N]```(````J;T```0```"RO0``"````+>]```(````
MP+T``$$```#)O0``&@````N^```K````)KX``"````!2O@``%0```'.^```&
M````B;X```8```"0O@``%0```)>^```8````K;X``"(```#&O@``+@```.F^
M```=````&+\``"$````VOP``5````%B_```I````K;\```H```#7OP``!P``
M`.*_```'````ZK\``!4```#ROP``"`````C````.````$<````H````@P```
M#P```"O````-````.\````\```!)P```#0```%G````)````9\```!0```!Q
MP```!@```(;````8````C<```!T```"FP```$P```,3````1````V,```!0`
M``#JP```!````/_````&````!,$``!0````+P0``5````"#!```M````=<$`
M`&0```"CP0``!`````C"```.````#<(```4````<P@``!0```"+"```;````
M*,(``!H```!$P@``$P```%_"```1````<\(``!$```"%P@``'````)?"```J
M````M,(``#<```#?P@``$````!?#```A````*,,```4```!*PP``"@```%##
M```3````6\,```L```!OPP``$@```'O#```*````CL,```\```"9PP``#0``
M`*G#```1````M\,``!,```#)PP``#````-W#```&````ZL,```P```#QPP``
M!@```/[#```7````!<0``!`````=Q```$0```"[$```(````0,0```4```!)
MQ```#````$_$```0````7,0```4```!MQ```#0```'/$```&````@<0```<`
M``"(Q```#0```)#$```'````GL0```L```"FQ```!P```++$```'````NL0`
M``D```#"Q```"0```,S$```*````UL0``!D```#AQ```/0```/O$```=````
M.<4```P```!7Q0``$````&3%```%````=<4``"4```![Q0``$@```*'%```3
M````M,4``"L```#(Q0``.P```/3%```@````,,8```@```!1Q@``-@```%K&
M```A````D<8``!````"SQ@``"````,3&```,````S<8```8```#:Q@``!```
M`.'&```/````YL8```X```#VQ@``!P````7'```*````#<<```T````8QP``
M'P```";'```<````1L<``"$```!CQP``'@```(7'```9````I,<``!X```"^
MQP``'0```-W'```;````^\<``"`````7R```+@```#C(```F````9\@``!P`
M``".R```'@```*O(```<````RL@``"8```#GR```*P````[)```S````.LD`
M`"8```!NR0``*P```)7)```X````P<D``!T```#ZR0``%0```!C*```O````
M+LH``"````!>R@``$@```'_*```I````DLH``!X```"\R@``(````-O*```2
M````_,H``*(````/RP``%@```+++```C````R<L``"@```#MRP``*0```!;,
M```H````0,P``!\```!IS```%0```(G,```@````G\P``"4```#`S```*```
M`.;,```M````#\T``#`````]S0``D@```&[-```A`````<X``!8````CS@``
M'````#K.```F````5\X``"H```!^S@``00```*G.``!$````Z\X```P````P
MSP``!P```#W/```'````1<\```8```!-SP``#0```%3/```0````8L\``!(`
M``!SSP``!P```(;/```3````CL\``!(```"BSP``!P```+7/```$````O<\`
M`!````#"SP``$````-//```,````Y,\```X```#QSP``#0````#0```/````
M#M```!,````>T```#0```#+0```H````0-````,```!IT```#0```&W0```&
M````>]```!$```""T```%P```)30```;````K-````X```#(T````@```-?0
M``!)````VM````4````DT0``$````"K1```/````.]$```0```!+T0``#0``
M`%#1```.````7M$```,```!MT0``#@```''1```(````@-$```\```")T0``
M#P```)G1```'````J=$```T```"QT0``$````+_1```-````T-$``!D```#>
MT0``&@```/C1```+````$](```8````?T@``"P```";2```,````,M(```H`
M```_T@``$0```$K2```9````7-(```L```!VT@``#0```(+2```B````D-(`
M`!L```"ST@``-````,_2```*````!-,``!@````/TP``&0```"C3```6````
M0M,``"(```!9TP``#0```'S3```'````BM,```H```"2TP``%````)W3```+
M````LM,```P```"^TP``(@```,O3```O````[M,```L````>U```"0```"K4
M```9````--0```L```!.U```%P```%K4```7````<M0```D```"*U```%@``
M`)34```/````J]0``!D```"[U```%@```-74```.````[-0``!@```#[U```
M"````!35```-````'=4``"8````KU0``0P```%+5```(````EM4``!(```"?
MU0``'P```++5```(````TM4```L```#;U0``+P```.?5```.````%]8```4`
M```FU@``!@```"S6``!%````,]8```,```!YU@``!P```'W6```$````A=8`
M``H```"*U@``"@```)76```)````H-8```\```"JU@``$````+K6```7````
MR]8``!$```#CU@``&0```/76```7````#]<```D````GUP``!0```#'7```+
M````-]<```H```!#UP```@```$[7```%````4=<```T```!7UP``&P```&77
M```7````@=<``!0```"9UP``"0```*[7```*````N-<```X```##UP``#0``
M`-+7```2````X-<``#@```#SUP``(````"S8```(````3=@```X```!6V```
M>P```&78```8````X=@``!@```#ZV```$0```!/9```'````)=D```4````M
MV0``&````#/9```>````3-D``!L```!KV0``&0```(?9```;````H=D``!D`
M``"]V0``$P```-?9```'````Z]D```@```#SV0``!@```/S9```&`````]H`
M`!`````*V@``#P```!O:```0````*]H```\````\V@``"P```$S:```/````
M6-H```P```!HV@``#P```'7:```'````A=H```8```"-V@``#@```)3:```,
M````H]H``"@```"PV@``#P```-G:```(````Z=H```8```#RV@``#````/G:
M```(````!ML``!,````/VP``"@```"/;```>````+ML``"$```!-VP``(```
M`&_;```9````D-L``!<```"JVP``)0```,+;```7````Z-L``!8`````W```
M!````!?<```;````'-P```T````XW```#````$;<```#````4]P```4```!7
MW```"````%W<```*````9MP```P```!QW```"P```'[<```0````BMP```P`
M``";W```#@```*C<```+````M]P```0```##W```!````,C<```3````S=P`
M`!0```#AW```#````/;<```)`````]T```X````-W0``"P```!S=```;````
M*-T```<```!$W0``!P```$S=```*````5-T```T```!?W0``"0```&W=```$
M````=]T```4```!\W0```P```(+=```8````AMT```H```"?W0``!````*K=
M```F````K]T```X```#6W0``?````.7=```5````8MX```4```!XW@``!P``
M`'[>```,````AMX```@```"3W@``"@```)S>```&````I]X```@```"NW@``
M`@```+?>```&````NMX```8```#!W@``%````,C>```-````W=X``!````#K
MW@``&P```/S>```$````&-\```D````=WP``$````"??```)````.-\```D`
M``!"WP``!0```$S?```:````4M\```@```!MWP``!@```';?```9````?=\`
M``X```"7WP``!P```*;?```'````KM\```4```"VWP``"0```+S?```*````
MQM\```(```#1WP``!@```-3?```+````V]\```T```#GWP``"0```/7?```&
M````_]\``!(````&X```"0```!G@```'````(^```!0````KX```'0```$#@
M``!"````7N```"4```"AX```)0```,?@```&````[>````H```#TX```!```
M`/_@```)````!.$```@````.X0``$0```!?A```)````*>$```8````SX0``
M#0```#KA```&````2.$```0```!/X0``.0```%3A```]````CN$``#H```#,
MX0``'@````?B```%````)N(```X````LX@``!````#OB```&````0.(```<`
M``!'X@``(0```$_B```-````<>(``!4```!_X@``!@```)7B```$````G.(`
M`!$```"AX@``!@```+/B```*````NN(``"(```#%X@``!````.CB```%````
M[>(``!T```#SX@``!````!'C```,````%N,```X````CXP``"@```#+C```(
M````/>,```D```!&XP``!0```%#C```Z````5N,``#````"1XP``-0```,+C
M```I````^.,``$<````BY```.````&KD```I````H^0``#\```#-Y```+@``
M``WE```M````/.4``!\```!JY0``#P```(KE```2````FN4```L```"MY0``
M)@```+GE```I````X.4``"0````*Y@``)@```"_F```(````5N8```H```!?
MY@``"0```&KF```'````=.8``"````!\Y@``(````)WF```F````ON8```H`
M``#EY@``&0```/#F```I````"N<``!8````TYP``$@```$OG```'````7N<`
M``H```!FYP``#````''G```/````?N<``!````".YP``0````)_G``!P````
MX.<``&8```!1Z```#@```+CH```)````Q^@```H```#1Z```$@```-SH```3
M````[^@```P````#Z0``!@```!#I```5````%^D```\````MZ0``$P```#WI
M```2````4>D``!````!DZ0``$0```'7I```<````A^D``",```"DZ0``:@``
M`,CI```/````,^H```4```!#Z@``$````$GJ```)````6NH```0```!DZ@``
M"P```&GJ```@````=>H``!0```"6Z@``#````*OJ```,````N.H```\```#%
MZ@``%0```-7J```I````Z^H``"H````5ZP``)@```$#K```G````9^L``"D`
M``"/ZP``*@```+GK```9````Y.L``$(```#^ZP``$0```$'L```2````4^P`
M`!,```!F[```%````'KL```/````C^P``!8```"?[```%P```+;L```0````
MSNP``!$```#?[```-````/'L```3````)NT``!(````Z[0``-0```$WM```4
M````@^T```<```"8[0``#````*#M```@````K>T``!````#.[0``%````-_M
M```1````].T``!<````&[@``'````![N```3````.^X``!0```!/[@``&@``
M`&3N```1````?^X``!H```"1[@``'@```*SN```:````R^X``!,```#F[@``
M%0```/KN```1````$.\``!<````B[P``%````#KO```7````3^\``!4```!G
M[P``"0```'WO```0````A^\``!D```"8[P``!````++O```'````M^\```L`
M``"_[P``$0```,OO```&````W>\```8```#D[P``!@```.OO```%````\N\`
M``<```#X[P``!P````#P```%````"/```!8````.\```!@```"7P```&````
M+/````0````S\```!````#CP```'````/?````X```!%\```#````%3P```,
M````8?````T```!N\```"@```'SP```.````A_````4```"6\```*````)SP
M```.````Q?````P```#4\```#P```.'P```*````\?````@```#\\```"0``
M``7Q```K````#_$```0````[\0``"````$#Q```F````2?$``!(```!P\0``
M#P```(/Q```&````D_$```H```":\0``!P```*7Q```(````K?$``"````"V
M\0``"0```-?Q```-````X?$``!0```#O\0``#`````3R```-````$?(```X`
M```?\@``%@```"[R```1````1?(```8```!7\@```P```%[R```&````8O(`
M`!D```!I\@``!P```(/R```$````B_(```L```"0\@``"P```)SR```'````
MJ/(```4```"P\@``!P```+;R```6````OO(```T```#5\@``#0```./R```*
M````\?(``!````#\\@``#P````WS```1````'?,``!<````O\P``"@```$?S
M```1````4O,```@```!D\P``!````&WS```/````<O,``#H```""\P``!0``
M`+WS```,````P_,``!X```#0\P``#@```._S```0````_O,```L````/]```
M#````!OT```)````*/0```<````R]```"@```#KT```)````1?0```X```!/
M]```$````%[T```;````;_0``!@```"+]```&@```*3T```*````O_0```D`
M``#*]```"@```-3T```,````W_0```\```#L]```"````/ST```&````!?4`
M`!P````,]0``!P```"GU```%````,?4```L````W]0``1P```$/U```-````
MB_4```D```"9]0``!````*/U```#````J/4``!,```"L]0``$P```,#U```3
M````U/4```H```#H]0```@```//U```$````]O4``"4```#[]0```P```"'V
M```%````)?8``"H````K]@``"@```%;V```%````8?8```0```!G]@``"@``
M`&SV```-````=_8```8```"%]@``"````(SV```(````E?8```0```">]@``
M!0```*/V``!H````J?8```D````2]P``#````!SW```0````*?<```4````Z
M]P``!@```$#W```;````1_<``"\```!C]P``$````)/W```*````I/<```\`
M``"O]P``"@```+_W```)````RO<``!,```#4]P``&P```.CW```8````!/@`
M`!<````=^```'P```#7X```.````5?@```,```!D^```!P```&CX```(````
M</@```<```!Y^```"0```('X```*````B_@```L```"6^```!P```*+X``!1
M````JO@``!````#\^```#`````WY```-````&OD``!H````H^0``2@```$/Y
M```9````COD```8```"H^0``&@```*_Y```E````ROD```8```#P^0``!@``
M`/?Y```?````_OD```8````>^@``"0```"7Z```8````+_H``!<```!(^@``
M*````&#Z```&````B?H```T```"0^@``(@```)[Z``!7````P?H``!,````9
M^P``(P```"W[```3````4?L```(```!E^P``"P```&C[```(````=/L```T`
M``!]^P``"@```(O[```,````EOL```<```"C^P``%````*O[```&````P/L`
M``@```#'^P``#@```-#[```'````W_L```H```#G^P``"P```/+[```R````
M_OL```<````Q_```#````#G\```-````1OP```P```!4_```"0```&'\```)
M````:_P```H```!U_```!P```(#\```)````B/P```<```"2_```"@```)K\
M```;````I?P```\```#!_```$@```-'\```*````Y/P``!8```#O_```"```
M``;]```)````#_T``!`````9_0``!P```"K]```2````,OT```0```!%_0``
M!P```$K]```%````4OT```4```!8_0``"P```%[]```4````:OT``!$```!_
M_0``&@```)']```6````K/T``!0```##_0``%P```-C]```8````\/T``!P`
M```)_@``&0```";^```'````0/X```4```!(_@``#0```$[^```,````7/X`
M`!$```!I_@``"````'O^```(````A/X``!<```"-_@``"P```*7^```,````
ML?X``!\```"^_@``&@```-[^```3````^?X```0````-_P``"@```!+_```$
M````'?\```T````B_P``#````##_```%````/?\```D```!#_P``!0```$W_
M```'````4_\```4```!;_P``!````&'_```"````9O\``#@```!I_P``+```
M`*+_```2````S_\``"D```#B_P``,@````P``0`*````/P`!`"P```!*``$`
M+@```'<``0`S````I@`!`#,```#:``$`.`````X!`0`/````1P$!`!@```!7
M`0$`$````'`!`0`/````@0$!`!,```"1`0$`%0```*4!`0`4````NP$!`!(`
M``#0`0$`)````.,!`0`(````"`(!`"0````1`@$`$P```#8"`0`4````2@(!
M`!4```!?`@$`+0```'4"`0`M````HP(!`#$```#1`@$`+@````,#`0`O````
M,@,!`"P```!B`P$`8@```(\#`0`3````\@,!``T````&!`$`"````!0$`0`7
M````'00!``@````U!`$`#````#X$`0`K````2P0!`"$```!W!`$`&@```)D$
M`0`)````M`0!`$4```"^!`$`00````0%`0`%````1@4!``0```!,!0$`$P``
M`%$%`0`4````904!``X```!Z!0$`$P```(D%`0`8````G04!``8```"V!0$`
M"0```+T%`0`*````QP4!``\```#2!0$`$````.(%`0`'````\P4!``X```#[
M!0$`#0````H&`0`,````&`8!``H````E!@$`"0```#`&`0`*````.@8!``\`
M``!%!@$`"````%4&`0`/````7@8!``@```!N!@$`!0```'<&`0`-````?08!
M`!L```"+!@$`"````*<&`0`&````L`8!`!0```"W!@$`$0```,P&`0`.````
MW@8!`#@```#M!@$``@```"8'`0`&````*0<!``X````P!P$`!0```#\'`0`'
M````10<!``X```!-!P$`!@```%P'`0`H````8P<!``P```",!P$`'````)D'
M`0`$````M@<!`"D```"[!P$`%P```.4'`0`?````_0<!`%P````="`$`%```
M`'H(`0`^````CP@!`!\```#."`$`$````.X(`0`'````_P@!``X````'"0$`
M#````!8)`0`,````(PD!`!,````P"0$`"@```$0)`0`=````3PD!`!D```!M
M"0$`!0```(<)`0`1````C0D!``T```"?"0$`$0```*T)`0`D````OPD!`!(`
M``#D"0$`%0```/<)`0`2````#0H!``X````@"@$`&0```"\*`0`(````20H!
M``D```!2"@$`#0```%P*`0`*````:@H!``<```!U"@$`#P```'T*`0`&````
MC0H!``L```"4"@$`&@```*`*`0`*````NPH!``<```#&"@$`"````,X*`0`%
M````UPH!`!\```#="@$`!@```/T*`0`0````!`L!``@````5"P$`#0```!X+
M`0`(````+`L!`!X````U"P$`$@```%0+`0`L````9PL!`!H```"4"P$`"0``
M`*\+`0`*````N0L!`!4```#$"P$`!0```-H+`0`4````X`L!``0```#U"P$`
M$````/H+`0`&````"PP!``<````2#`$`'@```!H,`0`H````.0P!``H```!B
M#`$`'````&T,`0`1````B@P!``L```"<#`$`&@```*@,`0`4````PPP!``0`
M``#8#`$`!````-T,`0`+````X@P!``4```#N#`$`!@```/0,`0`(````^PP!
M``8````$#0$`"@````L-`0`;````%@T!`#0````R#0$`-````&<-`0`@````
MG`T!`"D```"]#0$`(````.<-`0!!````"`X!`!H```!*#@$`*````&4.`0`I
M````C@X!`%````"X#@$`(@````D/`0`&````+`\!``@````S#P$`!0```#P/
M`0`(````0@\!`!D```!+#P$`&0```&4/`0`J````?P\!`",```"J#P$`&0``
M`,X/`0`N````Z`\!`#0````7$`$`"````$P0`0`7````51`!``H```!M$`$`
M!P```'@0`0`A````@!`!`!````"B$`$`#@```+,0`0`+````PA`!``<```#.
M$`$`$P```-80`0`(````ZA`!``L```#S$`$`"@```/\0`0`4````"A$!``\`
M```?$0$`,@```"\1`0`+````8A$!``4```!N$0$`!0```'01`0`%````>A$!
M`!<```"`$0$`#P```)@1`0`$````J!$!``H```"M$0$`"0```+@1`0`+````
MPA$!``T```#.$0$`#````-P1`0`.````Z1$!``4```#X$0$`!````/X1`0`-
M`````Q(!`#(````1$@$`10```$02`0`7````BA(!``<```"B$@$`'@```*H2
M`0`,````R1(!`!0```#6$@$`!0```.L2`0`4````\1(!``8````&$P$`!P``
M``T3`0`.````%1,!`"H````D$P$`!@```$\3`0`,````5A,!``\```!C$P$`
M#0```',3`0`1````@1,!``L```"3$P$`-@```)\3`0`*````UA,!`"(```#A
M$P$`"P````04`0`/````$!0!`#(````@%`$`)0```%,4`0`P````>10!`#$`
M``"J%`$`+0```-P4`0`.````"A4!``4````9%0$`#@```!\5`0`3````+A4!
M`!(```!"%0$`!P```%45`0`1````714!`!,```!O%0$`!P```(,5`0`4````
MBQ4!`!@```"@%0$`!P```+D5`0`%````P14!``P```#'%0$`#````-05`0`2
M````X14!``0```#T%0$`!P```/D5`0`*`````18!``L````,%@$`#````!@6
M`0`.````)18!``X````T%@$`!0```$,6`0`%````218!`"X```!/%@$`)@``
M`'X6`0`C````I18!``,```#)%@$`$@```,T6`0`&````X!8!`!X```#G%@$`
M&`````87`0`E````'Q<!``T```!%%P$`"0```%,7`0`?````71<!``,```!]
M%P$`!P```($7`0`*````B1<!``(```"4%P$`#````)<7`0`5````I!<!``L`
M``"Z%P$`&0```,87`0`@````X!<!`!(````!&`$`!0```!08`0`*````&A@!
M`!4````E&`$`$@```#L8`0`,````3A@!``0```!;&`$`"0```&`8`0`'````
M:A@!``P```!R&`$`4@```'\8`0`7````TA@!`"0```#J&`$`$@````\9`0`'
M````(AD!``8````J&0$`#@```#$9`0`.````0!D!``P```!/&0$`#````%P9
M`0`,````:1D!``T```!V&0$`%0```(09`0`2````FAD!`!````"M&0$`#P``
M`+X9`0`4````SAD!``H```#C&0$`&P```.X9`0`0````"AH!``L````;&@$`
M:0```"<:`0`:````D1H!`!<```"L&@$`&0```,0:`0`:````WAH!`"4```#Y
M&@$`)P```!\;`0`:````1QL!`!<```!B&P$`&P```'H;`0`9````EAL!`!\`
M``"P&P$`%````-`;`0`3````Y1L!``@```#Y&P$`!P````(<`0`(````"AP!
M``D````3'`$`%0```!T<`0`-````,QP!`",```!!'`$`#0```&4<`0`3````
M<QP!``@```"''`$``P```)`<`0!&````E!P!`#\```#;'`$`-P```!L=`0!7
M````4QT!``4```"K'0$`'P```+$=`0`O````T1T!``H````!'@$`"`````P>
M`0`-````%1X!`"T````C'@$`!````%$>`0`4````5AX!`$\```!K'@$`)0``
M`+L>`0`2````X1X!`"````#T'@$`'````!4?`0`+````,A\!`!\````^'P$`
M'0```%X?`0`E````?!\!`"````"B'P$`)````,,?`0`@````Z!\!``L````)
M(`$`!P```!4@`0`-````'2`!``P````K(`$`%P```#@@`0`&````4"`!`#D`
M``!7(`$`#````)$@`0`'````GB`!``D```"F(`$`$P```+`@`0`)````Q"`!
M``0```#.(`$`$````-,@`0`(````Y"`!``@```#M(`$`!````/8@`0`+````
M^R`!``P````'(0$`$@```!0A`0`1````)R$!``P````Y(0$`&@```$8A`0`/
M````82$!``<```!Q(0$`#0```'DA`0`0````AR$!`!$```"8(0$`%````*HA
M`0`.````OR$!``P```#.(0$`&P```-LA`0`L````]R$!`!,````D(@$`'```
M`#@B`0`H````52(!``8```!^(@$`!P```(4B`0`3````C2(!``4```"A(@$`
M!````*<B`0`7````K"(!``H```#$(@$`#````,\B`0`)````W"(!``8```#F
M(@$`"0```.TB`0`(````]R(!``D`````(P$`"@````HC`0`1````%2,!``8`
M```G(P$`#@```"XC`0`.````/2,!``T```!,(P$`"P```%HC`0`=````9B,!
M``L```"$(P$``@```)`C`0`<````DR,!``<```"P(P$`!@```+@C`0!D````
MOR,!``D````D)`$`!P```"XD`0`F````-B0!`#@```!=)`$`&@```)8D`0`J
M````L20!`#L```#<)`$`*````!@E`0`T````024!`!D```!V)0$`%0```)`E
M`0`%````IB4!``<```"L)0$`"````+0E`0`'````O24!``4```#%)0$`!P``
M`,LE`0`.````TR4!``D```#B)0$`!@```.PE`0`(````\R4!``L```#\)0$`
M!P````@F`0`(````$"8!``<````9)@$`%@```"$F`0`)````."8!``8```!"
M)@$`"P```$DF`0`0````528!``8```!F)@$`'````&TF`0`4````BB8!``<`
M``"?)@$`$0```*<F`0`(````N28!``X```#")@$`"````-$F`0`%````VB8!
M`!````#@)@$`"0```/$F`0`0````^R8!``8````,)P$`&0```!,G`0`*````
M+2<!`!P````X)P$`!P```%4G`0`%````72<!`!````!C)P$`%````'0G`0`+
M````B2<!``T```"5)P$`*````*,G`0`8````S"<!`!<```#E)P$`!````/TG
M`0`)`````B@!``H````,*`$`!P```!<H`0`"````'R@!``X````B*`$`"```
M`#$H`0`C````.B@!`#@```!>*`$`)@```)<H`0`Q````OB@!`"<```#P*`$`
M9````!@I`0`4````?2D!`%4```"2*0$`.````.@I`0!*````(2H!`%L```!L
M*@$`*````,@J`0`X````\2H!`"@````J*P$`+````%,K`0`F````@"L!`!L`
M``"G*P$`/@```,,K`0"I`0```BP!`",```"L+0$`%P```-`M`0!(````Z"T!
M`(4````Q+@$`,````+<N`0`5````Z"X!`"@```#^+@$`(@```"<O`0`B````
M2B\!`"````!M+P$`)0```(XO`0!!````M"\!`%L```#V+P$`20```%(P`0`Q
M````G#`!`!T```#.,`$`&````.PP`0`K````!3$!`"$````Q,0$`'P```%,Q
M`0`K````<S$!`"$```"?,0$`)P```,$Q`0`Z````Z3$!`!T````D,@$`$0``
M`$(R`0`S````5#(!`"4```"(,@$`)P```*XR`0`@````UC(!`!\```#W,@$`
M,````!<S`0!I````2#,!`#$```"R,P$`00```.0S`0`S````)C0!`"4```!:
M-`$`/0```(`T`0!E````OC0!`$T````D-0$`+P```'(U`0`N````HC4!`"D`
M``#1-0$`+````/LU`0!4````*#8!`%H```!]-@$`*````-@V`0`F`````3<!
M`$@````H-P$`2@```'$W`0`K````O#<!`!X```#H-P$`,@````<X`0`O````
M.C@!`"P```!J.`$`+0```)<X`0!Q````Q3@!`&8````W.0$`;P```)XY`0"S
M````#CH!`!<```#".@$`)0```-HZ`0`R`````#L!`"D````S.P$`/@```%T[
M`0`B````G#L!`%(```"_.P$`(@```!(\`0`E````-3P!``L```!;/`$`L0``
M`&<\`0!%````&3T!`"$```!?/0$`,````($]`0`E````LCT!`!P```#8/0$`
M,0```/4]`0`'````)SX!``<````O/@$`!````#<^`0`-````/#X!``L```!*
M/@$`#@```%8^`0`+````93X!``4```!Q/@$`$````'<^`0`"````B#X!`%D`
M``"+/@$`!0```.4^`0`2````ZSX!``0```#^/@$`!P````,_`0`(````"S\!
M``4````4/P$``P```!H_`0`0````'C\!``P````O/P$`$P```#P_`0`-````
M4#\!``(```!>/P$`!P```&$_`0`&````:3\!`!0```!P/P$`#````(4_`0`8
M````DC\!``8```"K/P$`$@```+(_`0`,````Q3\!``,```#2/P$`*@```-8_
M`0`$`````4`!``8````&0`$`!P````U``0`?````%4`!`#4````U0`$`+@``
M`&M``0`O````FD`!`!<```#*0`$`(@```.)``0`E````!4$!`"`````K00$`
M&P```$Q!`0`8````:$$!`"0```"!00$`'P```*9!`0`:````QD$!`"$```#A
M00$`(`````-"`0`:````)$(!`#(````_0@$`&0```')"`0`:````C$(!`"\`
M``"G0@$`*P```-="`0`?`````T,!`",````C0P$`'P```$=#`0`:````9T,!
M`"$```""0P$`)0```*1#`0`F````RD,!`"4```#Q0P$`)````!=$`0`8````
M/$0!`!T```!51`$`)````'-$`0`8````F$0!`"(```"Q1`$`+````-1$`0`O
M`````44!`!4````Q10$`)0```$=%`0`\````;44!`!\```"J10$`(P```,I%
M`0`?````[D4!`"`````.1@$`&@```"]&`0`8````2D8!`"8```!C1@$`'@``
M`(I&`0`I````J48!`!X```#31@$`,0```/)&`0`)````)$<!``P````N1P$`
M%P```#M'`0`O````4T<!`"0```"#1P$`!P```*A'`0`/````L$<!`!0```#`
M1P$`#@```-5'`0`-````Y$<!`"0```#R1P$`!0```!=(`0`'````'4@!`"(`
M```E2`$`)0```$A(`0`:````;D@!`!T```")2`$`&@```*=(`0`'````PD@!
M`,<```#*2`$`"P```)))`0`5````GDD!``8```"T20$`"0```+M)`0`+````
MQ4D!``T```#120$`%P```-])`0`&````]TD!`#,```#^20$`$P```#)*`0`3
M````1DH!``<```!:2@$`#P```&)*`0`'````<DH!`#(```!Z2@$`!````*U*
M`0`A````LDH!`!,```#42@$`#````.A*`0`1````]4H!`#(````'2P$`%@``
M`#I+`0`(````44L!`!T```!:2P$`"0```'A+`0`*````@DL!`!0```"-2P$`
M"@```*)+`0`=````K4L!``@```#+2P$`'P```-1+`0`(````]$L!`!H```#]
M2P$`)P```!A,`0`&````0$P!`!4```!'3`$`!P```%U,`0`(````94P!``D`
M``!N3`$`/P```'A,`0`'````N$P!``\```#`3`$`#@```-!,`0`0````WTP!
M``D```#P3`$`"0```/I,`0`(````!$T!`!,````-30$`!P```"%-`0`9````
M*4T!``H```!#30$`%P```$Y-`0`4````9DT!``H```![30$`#````(9-`0`7
M````DTT!``0```"K30$`*@```+!-`0`,````VTT!`!$```#H30$`!P```/I-
M`0`"`````DX!`!`````%3@$`&````!9.`0`+````+TX!``,````[3@$`"```
M`#].`0`&````2$X!``<```!/3@$`#0```%=.`0`+````94X!`!0```!Q3@$`
M%0```(9.`0`.````G$X!`"\```"K3@$`(````-M.`0`<````_$X!`!4````9
M3P$`*P```"]/`0`,````6T\!`#$```!H3P$`!0```)I/`0`2````H$\!`#\`
M``"S3P$`$@```/-/`0`*````!E`!``8````14`$`!````!A0`0`$````'5`!
M``H````B4`$`$P```"U0`0`%````05`!``8```!'4`$`!@```$Y0`0`(````
M55`!``0```!>4`$`#````&-0`0`*````<%`!`#D```![4`$`+@```+50`0`I
M````Y%`!``4````.40$`&````!11`0`9````+5$!`!\```!'40$`'0```&=1
M`0`1````A5$!``(```"740$`!````)I1`0`*````GU$!``8```"J40$`!0``
M`+%1`0`#````MU$!``P```"[40$`10```,A1`0`R````#E(!`!H```!!4@$`
M-````%Q2`0`H````D5(!`%,```"Z4@$`,@````Y3`0`9````05,!`'(```!;
M4P$`(````,Y3`0`U````[U,!`"$````E5`$`10```$=4`0`P````C50!`"@`
M``"^5`$`*````.=4`0`I````$%4!`"8````Z50$`)0```&%5`0`H````AU4!
M`"@```"P50$`(@```-E5`0`K````_%4!`#`````H5@$`$@```%E6`0`3````
M;%8!`!````"`5@$`>0```)%6`0`)````"U<!`*$````55P$`<P```+=7`0!\
M````*U@!`"L```"H6`$`5````-18`0`7````*5D!`"<```!!60$`%@```&E9
M`0`5````@%D!``\```"660$`%P```*99`0`?````OED!``X```#>60$`0```
M`.U9`0`?````+EH!`!P```!.6@$`40```&M:`0`:````O5H!`!0```#86@$`
M"@```.U:`0`%````^%H!``8```#^6@$`"`````5;`0`%````#EL!`!(````4
M6P$`$````"=;`0`3````.%L!`!T```!,6P$`#P```&I;`0`/````>EL!`!``
M``"*6P$`!````)M;`0`)````H%L!``D```"J6P$`!P```+1;`0`+````O%L!
M``4```#(6P$`"P```,Y;`0`'````VEL!``4```#B6P$`%````.A;`0`.````
M_5L!``L````,7`$`!P```!A<`0`(````(%P!``\````I7`$`#````#E<`0`)
M````1EP!``@```!07`$`#````%E<`0`&````9EP!``\```!M7`$`!P```'U<
M`0`&````A5P!`!0```",7`$`!@```*%<`0`,````J%P!`!$```"U7`$`"```
M`,=<`0`$````T%P!`!D```#57`$`$0```.]<`0`*`````5T!`!@````,70$`
M$P```"5=`0`<````.5T!`!$```!670$`#P```&A=`0`'````>%T!``0```"`
M70$`&0```(5=`0`'````GUT!``(```"G70$``@```*I=`0`1````K5T!``D`
M``"_70$`!@```,E=`0`2````T%T!`!<```#C70$`!@```/M=`0`G`````EX!
M``(````J7@$`!````"U>`0`/````,EX!`!,```!"7@$`!P```%9>`0`)````
M7EX!``<```!H7@$`$0```'!>`0`&````@EX!`!@```")7@$`!@```*)>`0`3
M````J5X!`!````"]7@$`$@```,Y>`0`"````X5X!``8```#D7@$`#````.M>
M`0`)````^%X!`!$````"7P$`(@```!1?`0`'````-U\!``<````_7P$`"P``
M`$=?`0`%````4U\!``4```!97P$``@```%]?`0`+````8E\!`*$!``!N7P$`
M$@```!!A`0`;````(V$!`!`````_80$`#@```%!A`0`)````7V$!``<```!I
M80$``P```'%A`0`;````=6$!`"$```"180$`-0```+-A`0`Q````Z6$!`"L`
M```;8@$`+P```$=B`0`=````=V(!`"T```"58@$`"P```,-B`0`R````SV(!
M``@````"8P$`%`````MC`0`+````(&,!`!,````L8P$`!0```$!C`0`Q````
M1F,!`!````!X8P$`$0```(EC`0`>````FV,!``\```"Z8P$`"P```,IC`0`@
M````UF,!`)8```#W8P$`$@```(YD`0`*````H60!``T```"L9`$`#0```+ID
M`0`7````R&0!``P```#@9`$`$````.UD`0`5````_F0!``<````490$`G0``
M`!QE`0`,````NF4!``P```#'90$`%````-1E`0`2````Z64!``8```#\90$`
M$`````-F`0`0````%&8!``D````E9@$`"@```"]F`0!$````.F8!`"````!_
M9@$`/@```*!F`0!-````WV8!`&X````M9P$`:@```)QG`0!T````!V@!`'``
M``!\:`$`00```.UH`0`/````+VD!`!4````_:0$`#@```%5I`0`0````9&D!
M`!@```!U:0$`!0```(YI`0`&````E&D!`!<```";:0$`"P```+-I`0`*````
MOVD!``T```#*:0$`-````-AI`0`P````#6H!`"$````^:@$`(@```&!J`0`K
M````@VH!`!0```"O:@$`%@```,1J`0`.````VVH!``<```#J:@$`!P```/)J
M`0`6````^FH!`"0````1:P$`#0```#9K`0`9````1&L!`!\```!>:P$`'P``
M`'YK`0`E````GFL!`!\```#$:P$`%0```.1K`0`3````^FL!`!L````.;`$`
M$0```"IL`0`H````/&P!`!X```!E;`$`'P```(1L`0`6````I&P!`&$```"[
M;`$`,````!UM`0`9````3FT!`#(```!H;0$`!P```)MM`0`1````HVT!`$,`
M``"U;0$`#@```/EM`0`$````"&X!``L````-;@$`!P```!EN`0`'````(6X!
M``4````I;@$`!P```"]N`0`,````-VX!``0```!$;@$`(@```$EN`0`0````
M;&X!`!8```!];@$`$````)1N`0`L````I6X!`#$```#2;@$`"P````1O`0`A
M````$&\!`!P````R;P$`(0```$]O`0`?````<6\!``X```"1;P$`$@```*!O
M`0`/````LV\!`"0```##;P$`(P```.AO`0`'````#'`!``8````4<`$`"```
M`!MP`0`-````)'`!``<````R<`$`"P```#IP`0`2````1G`!``L```!9<`$`
M%````&5P`0`7````>G`!`!L```"2<`$`"````*YP`0`4````MW`!``4```#,
M<`$`%````-)P`0`9````YW`!`!`````!<0$`30```!)Q`0!!````8'$!``D`
M``"B<0$`!P```*QQ`0`4````M'$!``,```#)<0$`!0```,UQ`0`)````TW$!
M``\```#=<0$`"0```.UQ`0`5````]W$!`$D````-<@$`$P```%=R`0`N````
M:W(!`#4```":<@$`-P```-!R`0`R````"',!``H````[<P$`!````$9S`0`)
M````2W,!``@```!5<P$`,````%YS`0`W````CW,!`"\```#'<P$`7@```/=S
M`0`O````5G0!`"\```"&=`$`2P```+9T`0!.`````G4!`"\```!1=0$`5```
M`(%U`0`T````UG4!`#<````+=@$`5P```$-V`0`O````FW8!`#4```#+=@$`
M+`````%W`0`;````+G<!`!X```!*=P$`+@```&EW`0`K````F'<!`"L```#$
M=P$`&````/!W`0`4````"7@!``L````>>`$`#````"IX`0`5````-W@!`"``
M``!->`$`#P```&YX`0`/````?G@!`!T```".>`$`(0```*QX`0`'````SG@!
M``<```#6>`$`$P```-YX`0`*````\G@!``<```#]>`$`+`````5Y`0`-````
M,GD!``<```!`>0$`"````$AY`0`&````47D!``4```!8>0$`"````%YY`0`'
M````9WD!``P```!O>0$`*@```'QY`0`3````IWD!``P```"[>0$`!````,AY
M`0`'````S7D!``<```#5>0$`!P```-UY`0`9````Y7D!``4```#_>0$`$@``
M``5Z`0`(````&'H!``@````A>@$``P```"IZ`0`&````+GH!``8````U>@$`
M*@```#QZ`0`2````9WH!``@```!Z>@$`#0```(-Z`0`,````D7H!``<```">
M>@$`$@```*9Z`0`#````N7H!`$$```"]>@$``P```/]Z`0`9`````WL!`#``
M```=>P$`!@```$Y[`0`%````57L!``@```!;>P$`"````&1[`0!D````;7L!
M`"H```#2>P$`/P```/U[`0`J````/7P!`"8```!H?`$`!@```(]\`0`'````
MEGP!`!X```">?`$`*@```+U\`0`N````Z'P!`#<````7?0$`+0```$]]`0`W
M````?7T!`&\```"U?0$`,P```"5^`0`(````67X!``<```!B?@$`#````&I^
M`0`8````=WX!``D```"0?@$`"P```)I^`0`4````IGX!`!@```"[?@$`(@``
M`-1^`0`8````]WX!`!H````0?P$`%0```"M_`0`3````07\!``<```!5?P$`
M&0```%U_`0`=````=W\!`!4```"5?P$`&@```*M_`0`:````QG\!``4```#A
M?P$`"````.=_`0`;````\'\!`'(````,@`$`.````'^``0!Y````N(`!``0`
M```R@0$`$0```#>!`0`%````28$!``4```!/@0$`&@```%6!`0`;````<($!
M`!<```",@0$`%P```*2!`0`;````O($!`"<```#8@0$`-@````""`0!`````
M-X(!``X```!X@@$`*@```(>"`0`'````LH(!`!4```"Z@@$`'@```-""`0`2
M````[X(!`!D````"@P$`%0```!R#`0`D````,H,!`!\```!7@P$`%P```'>#
M`0`3````CX,!`!$```"C@P$`!@```+6#`0`/````O(,!``<```#,@P$`"@``
M`-2#`0`8````WX,!`!$```#X@P$`"`````J$`0`'````$X0!`!,````;A`$`
M%P```"^$`0`&````1X0!`!$```!.A`$`!````&"$`0`(````980!``X```!N
MA`$`"P```'V$`0`)````B80!``<```"3A`$`!P```)N$`0`+````HX0!``D`
M``"OA`$`"@```+F$`0`<````Q(0!`$D```#AA`$`(@```"N%`0`-````3H4!
M`!D```!<A0$`!0```':%`0`@````?(4!`!4```"=A0$`&````+.%`0`M````
MS(4!`#\```#ZA0$`)````#J&`0`(````7X8!`#P```!HA@$`)P```*6&`0`1
M````S88!``H```#?A@$`"0```.J&`0`/````](8!``8````$AP$`%@````N'
M`0`5````(H<!``@````XAP$`"@```$&'`0`-````3(<!`"0```!:AP$`)@``
M`'^'`0`N````IH<!`"<```#5AP$`(````/V'`0`E````'H@!`"0```!$B`$`
M*@```&F(`0`E````E(@!`#0```"ZB`$`,````.^(`0`K````((D!`"P```!,
MB0$`(P```'F)`0`Q````G8D!`#8```#/B0$`-@````:*`0`K````/8H!`#$`
M``!IB@$`00```)N*`0`J````W8H!`"D````(BP$`0P```#*+`0`K````=HL!
M`!L```"BBP$`,0```+Z+`0`G````\(L!`"<````8C`$`&@```$",`0"S````
M6XP!`!\````/C0$`*@```"^-`0`N````6HT!`#````")C0$`+0```+J-`0`R
M````Z(T!`"D````;C@$`*P```$6.`0`[````<8X!`#L```"MC@$`0````.F.
M`0!"````*H\!`+(```!MCP$`)P```""0`0`A````2)`!`"4```!JD`$`,@``
M`)"0`0`Y````PY`!`$8```#]D`$`3P```$21`0`,````E)$!``0```"AD0$`
M!0```*:1`0`%````K)$!``T```"RD0$`$````,"1`0`5````T9$!``0```#G
MD0$`%P```.R1`0`9````!)(!``<````>D@$`!````":2`0`2````*Y(!`!$`
M```^D@$`#@```%"2`0`:````7Y(!`!0```!ZD@$`%@```(^2`0`5````II(!
M``T```"\D@$`.0```,J2`0`&````!),!`!,````+DP$`!@```!^3`0`3````
M)I,!`!D````ZDP$`'0```%23`0`2````<I,!``(```"%DP$`20```(B3`0`+
M````TI,!`!8```#>DP$`$````/63`0`$````!I0!`!$````+E`$`%````!V4
M`0`$````,I0!`!4````WE`$`"````$V4`0`0````5I0!`!8```!GE`$`!@``
M`'Z4`0`2````A90!`!,```"8E`$`(P```*R4`0`;````T)0!`!@```#LE`$`
M"P````65`0`)````$94!`!(````;E0$`$P```"Z5`0`0````0I4!`!@```!3
ME0$`(````&R5`0`2````C94!`!(```"@E0$`(@```+.5`0`E````UI4!`$4`
M``#\E0$`$0```$*6`0`A````5)8!`!L```!VE@$`&@```)*6`0`W````K98!
M`!(```#EE@$`"````/B6`0`+`````9<!`!,````-EP$`"P```"&7`0`-````
M+9<!`#0````[EP$`-````'"7`0`-````I9<!``X```"SEP$`*````,*7`0`1
M````ZY<!`!(```#]EP$`$@```!"8`0`*````(Y@!`!@````NF`$`$P```$>8
M`0`?````6Y@!`!L```![F`$`$@```)>8`0`1````JI@!``@```"\F`$`$```
M`,68`0`L````UI@!`&(````#F0$`"0```&:9`0`6````<)D!`"T```"'F0$`
M"P```+69`0`.````P9D!`#@```#0F0$`$`````F:`0`'````&IH!`!4````B
MF@$`20```#B:`0`#````@IH!``@```"&F@$`"````(^:`0`.````F)H!`!``
M``"GF@$`$````+B:`0`5````R9H!`!8```#?F@$`(@```/::`0`9````&9L!
M`"(````SFP$`'@```%:;`0`)````=9L!``8```!_FP$`"````(:;`0`*````
MCYL!``(```":FP$`%````)V;`0`4````LIL!`#````#'FP$`&@```/B;`0`9
M````$YP!``H````MG`$`#0```#B<`0`-````1IP!``X```!4G`$`&````&.<
M`0!%````?)P!`"\```#"G`$`#@```/*<`0`2`````9T!`*`````4G0$`)@``
M`+6=`0`?````W)T!`!(```#\G0$`"`````^>`0`&````&)X!`"<````?G@$`
M0````$>>`0!`````B)X!`"X```#)G@$`,@```/B>`0`7````*Y\!`"H```!#
MGP$`!P```&Z?`0`(````=I\!``@```!_GP$`!@```(B?`0`9````CY\!`!0`
M``"IGP$`%@```+Z?`0`4````U9\!`!(```#JGP$`&@```/V?`0`2````&*`!
M`!0````KH`$`"````$"@`0`*````2:`!`!@```!4H`$`#@```&V@`0`S````
M?*`!`!$```"PH`$`#````,*@`0`(````SZ`!`!(```#8H`$`%````.N@`0`Z
M`````*$!``\````[H0$`(P```$NA`0`F````;Z$!`"4```"6H0$`(````+RA
M`0`?````W:$!`"\```#]H0$`(0```"VB`0`B````3Z(!``0```!RH@$`&0``
M`'>B`0`*````D:(!``\```"<H@$``P```*RB`0`*````L*(!``<```"[H@$`
M%0```,.B`0`8````V:(!`!````#RH@$`&`````.C`0`2````'*,!``X````O
MHP$`&@```#ZC`0`%````6:,!``<```!?HP$`%P```&>C`0`7````?Z,!`!@`
M``"7HP$`#@```+"C`0`0````OZ,!`!D```#0HP$`+0```.JC`0`'````&*0!
M``@````@I`$`#@```"FD`0`0````.*0!``X```!)I`$`"0```%BD`0`(````
M8J0!``H```!KI`$`%@```':D`0`1````C:0!``H```"?I`$`,0```*JD`0`/
M````W*0!`(0```#LI`$`)0```'&E`0`+````EZ4!``@```"CI0$`$````*RE
M`0`)````O:4!``L```#'I0$`!@```-.E`0`+````VJ4!``(```#FI0$`!@``
M`.FE`0`&````\*4!`!4```#WI0$`$`````VF`0`3````'J8!`"L````RI@$`
M`@```%ZF`0`#````8:8!`!0```!EI@$`"P```'JF`0`+````AJ8!``4```"2
MI@$`&@```)BF`0`'````LZ8!``8```"[I@$`'@```,*F`0`+````X:8!``<`
M``#MI@$`"0```/6F`0`%````_Z8!``D````%IP$`!@````^G`0`%````%J<!
M``8````<IP$`#0```".G`0`0````,:<!``X```!"IP$`!0```%&G`0`1````
M5Z<!``D```!IIP$`!P```'.G`0`:````>Z<!`"P```"6IP$`4````,.G`0`P
M````%*@!`#$```!%J`$`!P```'>H`0`*````?Z@!``0```"*J`$`"0```(^H
M`0`)````F:@!`!<```"CJ`$`"@```+NH`0`&````QJ@!``T```#-J`$`!@``
M`-NH`0`$````XJ@!`$8```#GJ`$`1````"ZI`0!#````<ZD!`"(```"WJ0$`
M!0```-JI`0`5````X*D!``L```#VJ0$`!P````*J`0`(````"JH!`!8````3
MJ@$`#P```"JJ`0`5````.JH!``<```!0J@$`!````%BJ`0`3````7:H!``0`
M``!QJ@$`"@```':J`0`;````@:H!``4```"=J@$`"````*.J`0`/````K*H!
M``<```"\J@$`$P```,2J`0`4````V*H!`!,```#MJ@$`"`````&K`0`)````
M"JL!``4````4JP$`1````!JK`0`U````7ZL!`#X```"5JP$`+````-2K`0!+
M`````:P!`$4```!-K`$`,0```).L`0!2````Q:P!`#<````8K0$`.@```%"M
M`0`D````BZT!`!$```"PK0$`%@```,*M`0`,````V:T!`#,```#FK0$`*P``
M`!JN`0`G````1JX!`"H```!NK@$`"````)FN`0`+````HJX!``H```"NK@$`
M!P```+FN`0`O````P:X!`#(```#QK@$`.0```"2O`0`*````7J\!`!H```!I
MKP$`)````(2O`0`8````J:\!`!4```#"KP$`!P```-BO`0`0````X*\!``X`
M``#QKP$`$0````"P`0`/````$K`!`$T````BL`$`BP```'"P`0!W````_+`!
M`!,```!TL0$`%@```(BQ`0`8````G[$!`!````"XL0$`$@```,FQ`0`7````
MW+$!``8```#TL0$`'P```/NQ`0`5````&[(!`!L````QL@$`$@```$VR`0`1
M````8+(!`!4```!RL@$`&````(BR`0`U````H;(!`'@```#7L@$`%P```%"S
M`0`$````:+,!`!@```!MLP$`"0```(:S`0`$````D+,!``P```"5LP$`)```
M`**S`0`6````Q[,!``T```#>LP$`$@```.RS`0`3````_[,!`!8````3M`$`
M-@```"JT`0`V````8;0!`#0```"8M`$`-````,VT`0`P`````K4!`#`````S
MM0$`%P```&2U`0!4````?+4!`!4```#1M0$`%0```.>U`0`5````_;4!`!4`
M```3M@$`%````"FV`0`8````/K8!`!@```!7M@$`%````'"V`0`4````A;8!
M`#````":M@$`&@```,NV`0`<````YK8!`#L````#MP$`$P```#^W`0`&````
M4[<!``X```!:MP$`'P```&FW`0`4````B;<!`!4```">MP$`$P```+2W`0`;
M````R+<!`"````#DMP$`&P````6X`0`9````(;@!`!T````[N`$`%````%FX
M`0`>````;K@!`"(```"-N`$`%````+"X`0`;````Q;@!`!D```#AN`$`$P``
M`/NX`0`>````#[D!`!D````NN0$`&````$BY`0`8````8;D!``H```!ZN0$`
M%0```(6Y`0`$````F[D!``0```"@N0$`!P```*6Y`0`*````K;D!`!````"X
MN0$`!@```,FY`0`(````T+D!``@```#9N0$`!@```.*Y`0`(````Z;D!``<`
M``#RN0$`!0```/JY`0`6`````+H!``8````7N@$`"````!ZZ`0`'````)[H!
M``0````ON@$`"0```#2Z`0`'````/KH!``D```!&N@$`$````%"Z`0`0````
M8;H!``H```!RN@$`$P```'VZ`0`%````D;H!`#````"7N@$`$@```,BZ`0`0
M````V[H!`!0```#LN@$`$P````&[`0`,````%;L!`!8````BNP$`-@```#F[
M`0`'````<+L!``@```!XNP$`#0```(&[`0`,````C[L!``\```"<NP$`!@``
M`*R[`0`,````L[L!``T```#`NP$`!@```,Z[`0`$````U;L!``X```#:NP$`
M%0```.F[`0`E````_[L!`!`````EO`$`%@```#:\`0`7````3;P!`"8```!E
MO`$`&P```(R\`0`(````J+P!``,```"QO`$`#````+6\`0`I````PKP!``4`
M``#LO`$`!@```/*\`0`-````^;P!`!$````'O0$`!P```!F]`0`&````(;T!
M``<````HO0$`!0```#"]`0`-````-KT!``T```!$O0$`#````%*]`0`@````
M7[T!`!$```"`O0$`#P```)*]`0`:````HKT!`!,```"]O0$`%@```-&]`0`%
M````Z+T!``0```#NO0$`%0```/.]`0!,````";X!``4```!6O@$`#0```%R^
M`0`H````:KX!`!H```"3O@$`#P```*Z^`0`3````OKX!`!0```#2O@$`$```
M`.>^`0`/````^+X!`!@````(OP$`$````"&_`0`5````,K\!`!D```!(OP$`
M(P```&*_`0`G````AK\!`#<```"NOP$`"P```.:_`0`(````\K\!``T```#[
MOP$`#P````G``0`/````&<`!``0````IP`$`"0```"[``0`O````.,`!``L`
M``!HP`$`"0```'3``0`3````?L`!`&L```"2P`$`$P```/[``0`*````$L$!
M``4````=P0$`!@```"/!`0`:````*L$!`!D```!%P0$`&0```%_!`0`*````
M><$!``(```"$P0$`%@```(?!`0`S````GL$!``,```#2P0$`!0```-;!`0`7
M````W,$!``H```#TP0$`!0```/_!`0`(````!<(!`!H````.P@$`#@```"G"
M`0`&````.,(!``@````_P@$`"````$C"`0`$````4<(!``4```!6P@$`2@``
M`%S"`0`/````I\(!`!(```"WP@$`'0```,K"`0`$````Z,(!``4```#MP@$`
M)0```//"`0`Y````&<,!``T```!3PP$`"@```&'#`0`1````;,,!``H```!^
MPP$`"P```(G#`0`6````E<,!`!L```"LPP$`+P```,C#`0`N````^,,!`"(`
M```GQ`$`$````$K$`0`#````6\0!``<```!?Q`$`"@```&?$`0`'````<L0!
M`!````!ZQ`$`#@```(O$`0`6````FL0!``<```"QQ`$`6@```+G$`0`/````
M%,4!``\````DQ0$`"P```#3%`0`G````0,4!`%T```!HQ0$`&P```,;%`0`'
M````XL4!`",```#JQ0$`*0````[&`0`(````.,8!``<```!!Q@$`&P```$G&
M`0`&````9<8!``D```!LQ@$`+@```';&`0`M````I<8!`#<```#3Q@$`!@``
M``O'`0`&````$L<!`"P````9QP$`9@```$;'`0`7````K<<!`"0```#%QP$`
M%P```.K'`0`"`````L@!`!$````%R`$`!@```!?(`0`4````'L@!``X````S
MR`$`$@```$+(`0`&````5<@!``@```!<R`$`!@```&7(`0`(````;,@!``T`
M``!UR`$`#0```(/(`0`*````D<@!`!$```"<R`$`.P```*[(`0`%````ZL@!
M`!<```#PR`$`%`````C)`0`7````'<D!``L````UR0$`$0```$')`0`1````
M4\D!``P```!ER0$`"P```'+)`0`,````?LD!``H```"+R0$`(````);)`0`5
M````M\D!`!(```#-R0$`%0```.#)`0`8````]LD!``D````/R@$`"P```!G*
M`0`;````)<H!``@```!!R@$`%0```$K*`0`#````8,H!``<```!DR@$`!0``
M`&S*`0`%````<LH!``@```!XR@$`%@```('*`0`7````F,H!`"0```"PR@$`
M(P```-7*`0`>````^<H!`!H````8RP$`&P```#/+`0`B````3\L!`!L```!R
MRP$`!@```([+`0`&````E<L!`!(```"<RP$`$@```*_+`0`4````PLL!``T`
M``#7RP$`#0```.7+`0`E````\\L!`!`````9S`$`%````"K,`0`G````/\P!
M`"4```!GS`$`&0```(W,`0`)````I\P!``8```"QS`$`!P```+C,`0`2````
MP,P!`!$```#3S`$`"````.7,`0`)````[LP!``4```#XS`$`!P```/[,`0`$
M````!LT!``0````+S0$``P```!#-`0!(````%,T!`#8```!=S0$`)0```)3-
M`0`J````NLT!`$$```#ES0$`#````"?.`0!`````-,X!`#8```!US@$`.0``
M`*S.`0`Y````YLX!`#X````@SP$`&````%_/`0`;````>,\!`!0```"4SP$`
M$P```*G/`0`<````O<\!`"````#:SP$`%````/O/`0`3````$-`!`#,````D
MT`$`"P```%C0`0`M````9-`!`!8```"2T`$`%@```*G0`0`:````P-`!`#L`
M``#;T`$`.P```!?1`0`_````4]$!`#0```"3T0$`.P```,C1`0`X````!-(!
M`'L````]T@$`'@```+G2`0`8````V-(!``T```#QT@$`&@```/_2`0`,````
M&M,!`!(````GTP$`.````#K3`0`S````<],!`"H```"GTP$`#0```-+3`0!3
M````X-,!`$P````TU`$`!0```('4`0`%````A]0!`!X```"-U`$`%@```*S4
M`0`+````P]0!``\```#/U`$`%@```-_4`0`'````]M0!``D```#^U`$`"0``
M``C5`0`.````$M4!``\````AU0$`!P```#'5`0`3````.=4!`!$```!-U0$`
M$@```%_5`0`/````<M4!`!````""U0$`$0```)/5`0`0````I=4!``L```"V
MU0$`$P```,+5`0`+````UM4!``4```#BU0$`$@```.C5`0`F````^]4!``@`
M```BU@$`!@```"O6`0`4````,M8!`!(```!'U@$`$0```%K6`0!$````;-8!
M``(```"QU@$`!0```+36`0`0````NM8!``4```#+U@$`!P```-'6`0`5````
MV=8!``8```#OU@$`/0```/;6`0`3````--<!`",```!(UP$`!````&S7`0`X
M````<=<!`"8```"JUP$`)@```-'7`0!=````^-<!`"````!6V`$`30```'?8
M`0`J````Q=@!`!8```#PV`$`!P````?9`0`/````#]D!``\````?V0$`#```
M`"_9`0`7````/-D!``P```!4V0$`'0```&'9`0`;````?]D!``4```";V0$`
M$P```*'9`0`.````M=D!`!L```#$V0$`+````.#9`0`1````#=H!`!<````?
MV@$`%0```#?:`0`1````3=H!`!T```!?V@$`"````'W:`0`0````AMH!`!D`
M``"7V@$`%````+':`0`2````QMH!`!P```#9V@$`$P```/;:`0`3````"ML!
M`!<````>VP$`$0```#;;`0`+````2-L!``@```!4VP$`!0```%W;`0`=````
M8]L!``8```"!VP$`&0```(C;`0`(````HML!`!4```"KVP$`#````,';`0`D
M````SML!`!8```#SVP$`,P````K<`0`>````/MP!``X```!=W`$`#P```&S<
M`0`J````?-P!``8```"GW`$`'P```*[<`0`&````SMP!`!H```#5W`$`"0``
M`/#<`0`+````^MP!`"<````&W0$`.````"[=`0`*````9]T!`"D```!RW0$`
M#````)S=`0`.````J=T!`!X```"XW0$`%````-?=`0`%````[-T!``<```#R
MW0$`"P```/K=`0`)````!MX!``8````0W@$`"````!?>`0`&````(-X!``H`
M```GW@$`'````#+>`0`M````3]X!`#$```!]W@$`)0```*_>`0`S````U=X!
M`"8````)WP$`1P```##?`0`A````>-\!`"<```":WP$`/@```,+?`0!<````
M`>`!`#````!>X`$`!P```(_@`0`)````E^`!``@```"AX`$`"````*K@`0`7
M````L^`!`!8```#+X`$`+````.+@`0`N````#^$!`!D````^X0$`,````%CA
M`0`Z````B>$!``@```#$X0$`'P```,WA`0`+````[>$!``8```#YX0$`*P``
M``#B`0`3````+.(!`!0```!`X@$`"P```%7B`0`(````8>(!`!<```!JX@$`
M!P```(+B`0`+````BN(!``T```"6X@$`&P```*3B`0`A````P.(!`#P```#B
MX@$`"@```!_C`0`%````*N,!``<````PXP$`!0```#CC`0`;````/N,!``\`
M``!:XP$`!0```&KC`0`2````<.,!`!H```"#XP$`!P```)[C`0`.````IN,!
M`!````"UXP$`$P```,;C`0`$````VN,!``0```#?XP$`#````.3C`0`>````
M\>,!`%H````0Y`$`'P```&OD`0`*````B^0!`"L```"6Y`$`$P```,+D`0`@
M````UN0!`!8```#WY`$`%@````[E`0`)````)>4!``D````OY0$`$0```#GE
M`0`N````2^4!``<```!ZY0$`#P```(+E`0`4````DN4!`!(```"GY0$`%```
M`+KE`0`0````S^4!`$$```#@Y0$`"@```"+F`0`<````+>8!`!4```!*Y@$`
M&@```&#F`0`Y````>^8!`",```"UY@$`3````-GF`0!0````)N<!`$D```!W
MYP$`$0```,'G`0`#````T^<!`!T```#7YP$`(@```/7G`0`=````&.@!``D`
M```VZ`$`$P```$#H`0`A````5.@!``<```!VZ`$`)0```'[H`0`>````I.@!
M``H```##Z`$`!@```,[H`0`0````U>@!`!$```#FZ`$`'````/CH`0`$````
M%>D!``@````:Z0$`"P```"/I`0`0````+^D!`!````!`Z0$`%P```%'I`0`7
M````:>D!``D```"!Z0$`!@```(OI`0!`````DND!`#0```#3Z0$`,P````CJ
M`0`&````/.H!``8```!#Z@$`!@```$KJ`0`=````4>H!`!8```!OZ@$`+```
M`(;J`0`.````L^H!`!````#"Z@$`)````-/J`0`#````^.H!``8```#\Z@$`
M$0````/K`0`"````%>L!``T````8ZP$`&@```";K`0`,````0>L!`!@```!.
MZP$`'P```&?K`0`2````A^L!`!(```":ZP$`"P```*WK`0`4````N>L!`!4`
M``#.ZP$`#P```.3K`0`+````].L!`!(`````[`$`#@```!/L`0`7````(NP!
M`&@````Z[`$`(@```*/L`0`_````QNP!``T````&[0$`!P```!3M`0`)````
M'.T!`!0````F[0$`&0```#OM`0`7````5>T!`!````!M[0$`%P```'[M`0`5
M````ENT!`"````"L[0$`)````,WM`0`:````\NT!`!<````-[@$`)0```"7N
M`0`1````2^X!`"\```!=[@$`$P```(WN`0`5````H>X!`)````"W[@$`)```
M`$CO`0`@````;>\!`"@```".[P$`(@```+?O`0`I````VN\!`#$````$\`$`
M)````#;P`0`C````6_`!`"0```!_\`$`)0```*3P`0`D````RO`!`!H```#O
M\`$`'0````KQ`0`+````*/$!``<````T\0$`"````#SQ`0`)````1?$!`!0`
M``!/\0$`#P```&3Q`0`W````=/$!`!L```"L\0$`%@```,CQ`0`(````W_$!
M``P```#H\0$`:@```/7Q`0!"````8/(!`$H```"C\@$`@````.[R`0`-````
M;_,!`#$```!]\P$`,0```*_S`0`*````X?,!``4```#L\P$`!@```/+S`0!%
M````^?,!``@````_]`$`&P```$CT`0!F````9/0!`#4```#+]`$`(0````'U
M`0`D````(_4!`"@```!(]0$`%````''U`0`G````AO4!`!X```"N]0$`+0``
M`,WU`0`W````^_4!`$0````S]@$`-P```'CV`0`;````L/8!``<```#,]@$`
M&P```-3V`0`7````\/8!`!4````(]P$`"0```![W`0`T````*/<!``P```!=
M]P$`"@```&KW`0`)````=?<!`!<```!_]P$`"0```)?W`0`&````H?<!`!8`
M``"H]P$`"0```+_W`0`(````R?<!``4```#2]P$`#P```-CW`0`0````Z/<!
M`"0```#Y]P$`(````![X`0`3````/_@!`#0```!3^`$`#````(CX`0`'````
ME?@!`!(```"=^`$`%@```+#X`0`=````Q_@!`!L```#E^`$`#@````'Y`0`.
M````$/D!`!D````?^0$`)@```#GY`0`.````8/D!`"````!O^0$`-@```)#Y
M`0`(````Q_D!``H```#0^0$`&0```-OY`0`'````]?D!``@```#]^0$`$P``
M``;Z`0`2````&OH!`!(````M^@$`$0```$#Z`0`&````4OH!``D```!9^@$`
M"````&/Z`0`)````;/H!``X```!V^@$`$````(7Z`0`&````EOH!`!0```"=
M^@$``P```++Z`0`%````MOH!`!````"\^@$`'P```,WZ`0`+````[?H!``(`
M``#Y^@$`(0```/SZ`0`%````'OL!``4````D^P$`<@```"K[`0`&````G?L!
M``8```"D^P$`'````*O[`0!&````R/L!`!X````/_`$`'````"[\`0!;````
M2_P!`#L```"G_`$`3P```./\`0`@````,_T!`!4```!4_0$`!@```&K]`0`(
M````<?T!``\```!Z_0$`$0```(K]`0`*````G/T!``\```"G_0$`%P```+?]
M`0`1````S_T!`!$```#A_0$`%````//]`0`(````"/X!``H````1_@$`'0``
M`!S^`0`.````.OX!`!H```!)_@$`"0```&3^`0`%````;OX!``8```!T_@$`
M(P```'O^`0`&````G_X!`"X```"F_@$`!0```-7^`0`&````V_X!``T```#B
M_@$`!@```/#^`0`/````]_X!``L````'_P$`!P```!/_`0`5````&_\!`!(`
M```Q_P$`%0```$3_`0`&````6O\!`!D```!A_P$`"@```'O_`0`(````AO\!
M``<```"/_P$`!@```)?_`0`3````GO\!`"4```"R_P$`"P```-C_`0`.````
MY/\!`"@```#S_P$`&````!P``@`:````-0`"``4```!0``(`"@```%8``@`3
M````80`"``T```!U``(``@```(,``@`.````A@`"``D```"5``(`)0```)\`
M`@`Z````Q0`"`"L``````0(`.````"P!`@`L````90$"`&<```"2`0(`&P``
M`/H!`@!@````%@("`#@```!W`@(`2@```+`"`@!9````^P("`"\```!5`P(`
M,0```(4#`@`K````MP,"`#$```#C`P(`+P```!4$`@`F````100"`#T```!L
M!`(`(@(``*H$`@`C````S08"`!@```#Q!@(`2@````H'`@"!````50<"`#,`
M``#7!P(`&`````L(`@`M````)`@"`"````!2"`(`)````',(`@`F````F`@"
M`"\```"_"`(`0````.\(`@!:````,`D"`%````"+"0(`.0```-P)`@`C````
M%@H"`!<````Z"@(`+````%(*`@`A````?PH"`",```"A"@(`,P```,4*`@`?
M````^0H"`"H````9"P(`-@```$0+`@`;````>PL"`!$```"7"P(`5````*D+
M`@`K````_@L"`"T````J#`(`)P```%@,`@`B````@`P"`"T```"C#`(`60``
M`-$,`@`U````*PT"`%0```!A#0(`.@```+8-`@`\````\0T"`$X````N#@(`
M;P```'T.`@!8````[0X"`$<```!&#P(`2@```(X/`@`]````V0\"`$(````7
M$`(`:P```%H0`@!U````QA`"`#8````\$0(`00```',1`@!I````M1$"`&8`
M```?$@(`/0```(82`@`G````Q!("`#\```#L$@(`+0```"P3`@`L````6A,"
M`#````"'$P(`=P```+@3`@!F````,!0"`'4```"7%`(`P`````T5`@`9````
MSA4"`"H```#H%0(`/0```!,6`@`R````418"`%(```"$%@(`)````-<6`@!;
M````_!8"`"X```!8%P(`(````(<7`@`)````J!<"`+T```"R%P(`2@```'`8
M`@`C````NQ@"`#T```#?&`(`)@```!T9`@`A````1!D"`#X```!F&0(`"```
M`*49`@`'````KAD"``4```"V&0(`#0```+P9`@`.````RAD"`!0```#9&0(`
M#@```.X9`@`%````_1D"`!,````#&@(``0```!<:`@!Y````&1H"``L```"3
M&@(`$P```)\:`@`$````LQH"``<```"X&@(`!@```,`:`@`%````QQH"``0`
M``#-&@(`%````-(:`@`+````YQH"`!$```#S&@(`#`````4;`@`"````$AL"
M``<````5&P(`!P```!T;`@`1````)1L"``P````W&P(`%P```$0;`@`&````
M7!L"`!4```!C&P(`#````'D;`@`#````AAL"`"T```"*&P(`!````+@;`@`'
M````O1L"``<```#%&P(`*0```,T;`@!&````]QL"`$(````^'`(`00```($<
M`@`>````PQP"`#8```#B'`(`.0```!D=`@`D````4QT"`!L```!X'0(`)```
M`)0=`@`M````N1T"`"8```#G'0(`(P````X>`@`M````,AX"`"D```!@'@(`
M+@```(H>`@`\````N1X"`"4```#V'@(`)@```!P?`@`W````0Q\"`#````![
M'P(`*0```*P?`@`O````UA\"`"T````&(`(`)@```#0@`@`P````6R`"`"H`
M``",(`(`+````+<@`@`O````Y"`"`"H````4(0(`)@```#\A`@`J````9B$"
M`"\```"1(0(`(P```,$A`@`M````Y2$"`#@````3(@(`.P```$PB`@`@````
MB"("`"P```"I(@(`/@```-8B`@`I````%2,"`"X````_(P(`+0```&XC`@`L
M````G","`"8```#)(P(`(````/`C`@`H````$20"`"H````Z)`(`0P```&4D
M`@`O````J20"`#P```#9)`(`"0```!8E`@`7````("4"`!P````X)0(`-0``
M`%4E`@`B````BR4"``X```"N)0(`#P```+TE`@`3````S24"``L```#A)0(`
M"@```.TE`@`?````^"4"``8````8)@(`!P```!\F`@`B````)R8"`"4```!*
M)@(`(````'`F`@`J````D28"`!@```"\)@(`"````-4F`@#X````WB8"`!H`
M``#7)P(`'0```/(G`@`(````$"@"``L````9*`(`%@```"4H`@`6````/"@"
M`"4```!3*`(`!P```'DH`@!3````@2@"`!H```#5*`(`&@```/`H`@`'````
M"RD"`!D````3*0(`#````"TI`@!,````.BD"``L```"'*0(`,````),I`@`?
M````Q"D"`!@```#D*0(`'P```/TI`@`\````'2H"`!T```!:*@(`$0```'@J
M`@`G````BBH"`!,```"R*@(`%````,8J`@`6````VRH"``L```#R*@(`&@``
M`/XJ`@`(````&2L"`"P````B*P(`"````$\K`@`I````6"L"`"\```""*P(`
M!P```+(K`@`9````NBL"``<```#4*P(`"````-PK`@`)````Y2L"`$4```#O
M*P(`!P```#4L`@`3````/2P"`!,```!1+`(`%````&4L`@`*````>BP"``H`
M``"%+`(`!P```)`L`@`4````F"P"``<```"M+`(`&0```+4L`@`-````SRP"
M`!D```#=+`(`&P```/<L`@`*````$RT"``T````>+0(`%P```"PM`@`&````
M1"T"`#0```!++0(`#````(`M`@`0````C2T"``D```">+0(``@```*@M`@`0
M````JRT"`!H```"\+0(`"P```-<M`@`#````XRT"``@```#G+0(`#@```/`M
M`@`)````_RT"``X````)+@(`#0```!@N`@`7````)BX"`!@````^+@(`$0``
M`%<N`@`\````:2X"`"4```"F+@(`(P```,PN`@`7````\"X"`"H````(+P(`
M#@```#,O`@`T````0B\"``<```!W+P(`%0```'\O`@!9````E2\"`!(```#O
M+P(`$`````(P`@`)````$S`"``0````=,`(`!````"(P`@`1````)S`"`!X`
M```Y,`(`!@```%@P`@`'````7S`"``<```!G,`(`$P```&\P`@`'````@S`"
M`!<```"+,`(`%P```*,P`@!"````NS`"`#0```#^,`(`.````#,Q`@`%````
M;#$"`!L```!R,0(`(0```(XQ`@`9````L#$"`"(```#*,0(`$0```.TQ`@`"
M````_S$"``0````",@(`$0````<R`@`,````&3("``4````F,@(``P```"PR
M`@`.````,#("`%8````_,@(`,@```)8R`@`<````R3("`$$```#F,@(`-@``
M`"@S`@!8````7S,"`#8```"X,P(`&0```.\S`@!Y````"30"`"@```"#-`(`
M2````*PT`@`D````]30"`$<````:-0(`+````&(U`@`W````CS4"`"P```#'
M-0(`+P```/0U`@`N````)#8"`"X```!3-@(`.````((V`@`L````NS8"`#0`
M``#H-@(`+0```!TW`@`U````2S<"`!D```"!-P(`(P```)LW`@`8````OS<"
M`'H```#8-P(`"0```%,X`@#+````73@"`)`````I.0(`?````+HY`@`M````
M-SH"`&X```!E.@(`'0```-0Z`@`F````\CH"`!,````9.P(`'0```"T[`@`3
M````2SL"`!8```!?.P(`*@```'8[`@`1````H3L"`$````"S.P(`(0```/0[
M`@`E````%CP"`'$````\/`(`'````*X\`@`7````RSP"``L```#C/`(`!0``
M`.\\`@`&````]3P"``@```#\/`(`!0````4]`@`6````"ST"`!4````B/0(`
M&0```#@]`@`D````4CT"`!````!W/0(`#P```(@]`@`0````F#T"`!(```"I
M/0(`"@```+P]`@`)````QST"``H```#1/0(`%````-P]`@`)````\3T"``\`
M``#[/0(`"`````L^`@`%````%#X"`!D````:/@(`$@```#0^`@`3````1SX"
M``H```!;/@(`#````&8^`@`8````<SX"``\```",/@(`#@```)P^`@`(````
MJSX"``P```"T/@(`"0```,$^`@`0````RSX"``H```#</@(`#@```.<^`@`6
M````]CX"``T````-/P(`$0```!L_`@`4````+3\"``8```!"/P(`!0```$D_
M`@`H````3S\"`!P```!X/P(`"P```)4_`@`L````H3\"`!<```#./P(`)0``
M`.8_`@`:````#$`"`!$````G0`(`!P```#E``@`'````04`"`!D```!)0`(`
M"0```&-``@`#````;4`"``(```!Q0`(`$@```'1``@`-````AT`"``H```"5
M0`(`%@```*!``@`9````MT`"``<```#10`(`)@```-E``@`"`````$$"``,`
M```#00(`$@````=!`@`9````&D$"``H````T00(`"0```#]!`@`+````24$"
M`!(```!500(`!@```&A!`@`A````;T$"``D```"100(`%P```)M!`@`7````
MLT$"`!(```#+00(``@```-Y!`@`$````X4$"``X```#F00(`#P```/5!`@`0
M````!4("`"\````60@(`!@```$9"`@`(````34("`!<```!60@(`!0```&Y"
M`@`%````=$("``,```!Z0@(`"P```'Y"`@`!````70,`````````````````
M`%<&``!,`P``F@(``.<#``"B`0``4@,``+,```"X!0````````````!X`@``
M``````(%````````!0```*0!```.!0``LP,``,@"```:!0``9@```.<````;
M!0```````#4&``"]`P``Q@0```P"``!]````ZP(``)0#``!6!````````*H$
M```X`0``(P8``,8%``!-!P``+@0``+P!```J`0``P0$``!T```#@`0``/P(`
M``````#'````/0(```````#$`P``(P,```<```!^!@```````*\#````````
M%@,``!(````U!```*@,`````````````G04``)0!```%`0``S`0```````#=
M!P````````````#C`0``OP(``,$%``![!```I00``+,!``"S!@```````-L%
M``!>!@``X`(````````(!P```````"`&``!I!P``/`<```4"``!2!```````
M`'T&``!6`0```````&<```#V!@``TP0``)\&````````@`<``)$!``"J!P``
MCP4```````"[`P``4@````````!8!0``;P$``"P`````````0@<```````#M
M!```>08````````:`@``004````````)!```SP$```````!A!P``%P,``'T%
M``"K!P``)P$``+<$````````!`$`````````````9`,``)(!``#L`0``````
M``````!M!P``A0$``+0&````````:@````````"I`@``"0<``-H"``#'!@``
M000``,\$```Q!0``W`(```````#@````^P$``'8!``!B`P``D0```&L%``"G
M!P````````````!;!@``AP<``,4"``!V!@``1P(``&P%```Y`0```````%L`
M````````(@<``&`#```(!``````````````G!0```````/,"``#/!@``````
M`&<$``!Y!0``'0<``.X&`````````````%L!``#@!@```````+8'````````
M(@,``(T!``#:!0```````%<!``#Z!@``````````````````TP8```````#X
M`0``J04```````!O!@```````%`'```0`@``]P```/T$``!P!````````,L"
M```P!P```P$``(8'``#9`@```````$D"```B!```VP8``(<%``!<`0``\@0`
M`+D!````````Q`8```````#L!0``K0,```````#I`0``)@0``!4&````````
M'00```````"H`````````"T#````````T0<``)X$``#=!@``'`(`````````
M````+`,``%@```!^!P``@P(``*4#`````````````/,#````````QP4``&H#
M``"!`0````````````!?````U`0``&`$``!+!P``;P```*\&```\!```*`(`
M`'$%``"F!P``0@(```\```"4!0```````%$&``!'!0````````````#,````
M0P4```T"``#"````J@$``````````````04```````#2````L08````````O
M!0```````'0"``"<````ZP8``((%````````$@8``*D&```P!0``A`8``*$&
M``!;!0``ZP0``-D$``"U!P``C`<`````````````0P(``#L'````````````
M`%("```V`P``%@8``"X%``#A!@``L@```,D#`````````````.L!``!C````
MP@4``"@#````````4P<``&\%````````5`0``!@$``"8!P``3@<``%H"``!I
M!@``%P$``#0#````````I`(``*L#``!3`@```````+H$``!Q`0``+`0``(T&
M```7`@``?````$D$````````>@````<#``"?!P``GP4``&X#``"]`0``I@8`
M`/<"````````N`(``.<"``!^`0``K@````````"$`0``(P$```0&``#<!```
MKP$``#$"`````````````+0%```Y!P``[`(```````"S`@``````````````
M````&P(```L!``#=`@``:`````````#,`0``R00``$,```"5`@``+`$``!L#
M```P`P``I@$`````````````G@,``#0%``#N````]0(``'H&```U`P``R0``
M`!P$````````N@$```````"/!`````````````#*!P`````````````F!0``
M,P0``(H$````````/P<```````!S`0``#`$```H$```M`0``#`<``/`$``#&
M!P``H@8``(8````/!0``YP4```@#````````Q````*`%```3`P``>````/(%
M````````T@8```````"I!P``N04``'4%````````&@,``%T!``#/!P``L`(`
M`-$```#!!```+@<`````````````!`(``!P!``````````````````"E````
MD08```````!&!@``7@,``.8$```'!P``O@````````"X`````````/0&```9
M!```4P4``/$&``![`P``U@<``-@````?`@``/P```/T"``"8`@```````)0"
M```8!0``(00```````!0`P``VP<``%0%````````K@<```````")!0``````
M`'8"``#2!```5@8``!8'``!C!@``H0(``"X!`````````````",$``#M`0``
MD`<``,T'````````!````,L'```T````30$``$@%``!M`0``D`0``+@!``!&
M`````````%@&````````#04``"L"``"`````H`8``!,%`````````````,4$
M``!P`0``)`(``'("``#I!@```````+H`````````EP$``%D#``#;`@``0@,`
M```````S!P```````"T'``")!@``@00```````#Y`P``0`<`````````````
M\@8```````"Y`````````,,$````````@P8``+D#````````C`8``-,!``!U
M`@``2P4``%<"``"(!@``$0,`````````````KP0``!P'``#\!```H@<``-H$
M``!]`0```````-`!``"1`@``\`$``,@```#T````N`,````````V!0``)0<`
M`+8```#2`0``500`````````````$````&`!``!``@```````(D`````````
MG`$```````"Z`@``C`(```````"D!0``508```````#(`0```````"H&```[
M`P``/00``.($````````/@4``!,'````````````````````````]@,`````
M``!%!0```````!4#``"&`P```````!('```"!P``AP```$H!```S!@``L00`
M````````````````````````````B@```.X!``#D!0````````````"!`@``
M``````4'``"O`@``,````"L&````````@P,```````"W```````````&``"&
M`0``.P8``(L%`````````````/8`````````:0(```````!!`0``I0(``"8!
M``!\!@``C@4``$8$``#4!P``2@0``,,%``#K`P``^P8``(@!``#3!P``````
M`"4"```Y`P``>0(``+8$`````````````.,#````````/P$``),"``#.`P``
M9P$``"P&`````````````$H#``#6!0```````#(%``"9!0``V`<``(D!``"_
M!0``/@8``.T&`````````````%H!```Y`@``"@4``/L"``"C!P``H`0`````
M````````E@(``.0&````````,`8`````````````D@0``+`!```&`P``````
M`+0!``"[!@``,P4``%H&````````.@<``,4#``#_!@``N`8``+\#```Q`P``
M`````$,#```:!```E@4```````"H`0``O@4```````"I!````````'$$``#G
M!```$`<``)H$```G!P``M0$``+\'``#(!````````-\```"`!```````````
M```=!0``X`<`````````````K04``'4$``!J!P``A`0``-H```#_`@``````
M`)H```"E!@``&@<```````"C`P``[0(``#L!``#;````3P<``&<&````````
ML@8````````I`@``/@$``'0'``"<`@```````!`#``!>`0``R@``````````
M````'P0``/4&``#W`0``40<``'<%````````&0(``*@"````````10(``/0$
M````````C@<```````#[!```;@$`````````````HP4``#8"```=`@``6@``
M``H```!:!0``70````````"P!````````,8````?`````````%<%````````
M`````'\$``"A!P``[`8``&,$````````B@$```````"U!```QP,```<%``!L
M!P``@@(``*P&``#4`0````````````!T!@``W@4``-8#````````/`4``%L#
M``"A`````````!$'``#6!@``)`,``,$#```A!@``5P,```````"B````````
M`%0"````````(0$``.P#``!'`0``````````````````$`4``"H"``!U`P``
M`````%@'```Z`P``=@<```````#)!P``]00``+P`````````,P$``/H!```?
M!@``UP(```````!-!```900``-,```"\!@``UP$`````````````````````
M````````````````````````'0$``.,"```W````E`8````````K`P``D04`
M`%8'````````GP,``!X%```J!0```````*4'```I!```E@$````````X!0``
M``````````"6!P```````$D&``#S!0```````&4````.!@```````!X!```#
M!0``10<``.L`````````=P```'0!``#8!```F0```-D&``!L`P``8@4`````
M```D!@````````````!>!0``>0,``"H$```&!@``!@0```````!B`@``:@$`
M`-0%`````````````-4```!I!```"08``$H%``!N!@``1`(``+@$```E!0``
M\0$``*<&````````]0$``#4"``!E!0``Y04``/<%``!U!@``U`(``,0$``!0
M!@``,P,```````!*!P``40```$<#``!C`@``S@$``-$#```O````B0(``+(%
M``#S````/0,```````!R!P```````*<!````````W`,`````````````%`4`
M`"D&````````@@0``.(&````````G@(``(L&``#(`P``!@$``/\```#A!P``
M``````````"V`0``K`,``/0%``#@!0``V0$``.(```!@`@``E04```X```")
M!```)00``"$%``!D````20<``!8$```L!0````````````!S````1`8`````
M`````````````%4"``"8!@``=P0``%`"``""!@``(`<```H!````````1`<`
M`$H&``!<!@``J`<``%,&``"``P``QP$`````````````J`8``!$"``!G`@``
M.04```````!9!@``OP8``&(```!S!@``#@<``",`````````)`<````````R
M`@``_@,``(P%````````%`,``+L!``#Y`0``K`$``,\````>!@```````/L#
M````````;`0``-(#``!N!```$04``/(!```@`0``J`4``+`%```$`P``````
M``P```"3````>@<``.,$```9`0``*`<``%,````5`0``'````-`#``"2`P``
M%@$``#D```#X!```7P,``)D'``"W!P``G0(```\'``#T`@``'`4``!L!````
M````H0,``)X%````````2P8``,4&``#$!P``9@<```8```!<!P``L0<`````
M``"R`P``E````/,!``!B!````````#0'````````V04``$X&```B!@``/`8`
M`%T$`````````````'D'```B````OP```%D%``#W!```C04````$``!@!@``
M``````````!;!````````"$#```_!@```````(8"```M!```````````````
M````RP,``&@'``!_!@``L0$``$\!```W`0``/@,``+L$``#?!0``9`0``/@#
M``"2!P``;P(``````````````````-L!````!0```````&8!```K!P``````
M````````````FP0``$8'`````````````/,$``#2`@```````*L```#Q!```
M``````````#4`P````````H&````````50,``(L'``#8!0```````&\'``#6
M````Z`(``/4%````````L04``-,#````````*`0```````"[````2P```%4'
M``"``0``#@0``!X````A`@``"`(``*L$````````3P(``.D$``"-`@``30,`
M``````!X`P``_0,``#8```"T````PP<````````D`0``T08``#,```#>!@``
M``````L`````````<0(``*D#``"=`P``RP8``&P!````````*`$``)T```"S
M!0``````````````````8@<``(@"````````[@0``.8"``!1!0```````$4#
M``!.````&P<``'$#``"\`@``%P4```````#V`@``R@0``/8$``"Y!P``````
M`-P&``"%`P````````D%````````S`4``.<!````````RP4```D!``#_!```
MMP,````#````````F0,``$P'``"#!```#P0```````!]!`````````````!<
M````5`,````````8`````````%,!``"R!P````````````#J`0``DP0``%0`
M``#;`P``T04``&````!I`0``%`<````````Q!P``SP,`````````````JP$`
M`-D#```N`P``#@$``!<&``#.`@``3`0``.\%``````````````````!!`P``
M`````,$```#C````*P$``,,&``"G`P``D@```.4"``#&!@``IP(``*($```P
M!```"@<``%$$```[`@``D`````````#J!```>`0``#$`````````9@0``.$#
M````````U0(``$(```"(!```-P(``.\&``#5!0``,0$``$D!``#Z!0```@,`
M`"4!``!5````\`(``(H'```K!```R`4``"X`````````P@$``.T````Q!```
M?P4``&$$````````@04``%<$``"U````NP4``&0!``#&`@```````,\"``!W
M!@``3P,``)X&`````````````!@'```]`0``^`8````````8`0``_04``.8%
M``"P!P```````)L%`````````````+,'```G`@``FP8``/D"````````G0$`
M```````L`@``Z@4``!X$``!?!```6@<``$,$``#5!```\@,``+<!``"K!0``
MK00``&L```"D`P``3@0``$H```#P`P```````)4`````````<08``%`%``""
M`P``B````!`!``!)!0``OP$``+X#``!^````WP(``#T%````````(P(``'L'
M``#\`@```````(8%``!0!````````#<$`````````````(P$````````````
M`(L!```C!P``M@,``!H&```0!@```````'X$``"Q````N0(``,`&``"&!@``
M<`8``%$!```L!P``$P$``-T!```%!````````*H"``":`0``W0,``.@#``"/
M`0````````````#\````,`(```D#```Z``````````L"``#`````%04```T'
M```%!@``C`,``$P"``!8`0```````'(%```<!@``R@4``"H'```_!```````
M`"<&```*`@``.@8``-\&```I`P``GP$``"<#``!(`@```````,X$``"(`P``
M0`$```````!S`P```````#(!``!9`0``TP4``````````````````'H%```)
M````O00``*("``"?`@```````$P&``"T!````````#@```#*`P```````.4!
M````````Z@(``)4#``!6!0``DP,``$8"````````CP(``#T'````````````
M`-X#`````````````&@!``"*`@``!`4```````#2!P``"@,``)L!````````
MEP0``"D```#X````'P,``.4#``````````````````"K!@``F@4```````"A
M`0``HP8``$`&```2`@``\@```&,!``"\!```5@(```L%```T!```!P8``!4"
M``#:!P``G@$``,H!```A````T`4``!,"```]!@```````&T#```2`P``````
M``````!>!P```````%\'`````````````/$```"$````M0,``'L!``#1`@``
M`````%$"```G````?@4``/P%``![!@``?P$```@`````````1P<``*D```#!
M!P``_`,``)P&``!;`@``M@8``-T```!$`0``-P4``%T'``!B!@``Q0<``,X'
M``#`!```E`<``/X!``"^`@``008```````"$!0```````'P'````````DP$`
M`.<&```"!```&0,`````````````R04``&\#``#Z!```W@(```4%``!N`@``
MCP<```````!#!@``#@(`````````````Z````(4'``">````IP0``'\#``!Q
M!P``<@$``"L```#0!```2`8`````````````^04`````````````UP```)<'
M``"=!@``704``&L!``#Z````804``$<````?`0``;04````````V!```=@4`
M``````"<!```<P<``-$$``"'`@```````"\&````````#`,``'`#``#^!```
M304``(\&``!Q````S00``$X!```H!@```````&8%``#0`@``A08````````6
M!0``P@8``%(!````````````````````````&`(```````#B!P``E@8``'8#
M```1!```)@```$,!``!/!0```````)L#```9!@``'08``"4#``#-`P``TP(`
M`#4%```/`P``(`,``%D```"N!0``_`8``.D"``#U`P``.`,``#H$```N!@``
M8@$``*,"``""`0``S0(``%P"``"U!@``````````````````E08``(,%``"?
M!````````,,#``"@`0``IP4```````"D!P``^P4``%\"``!8`@``<P4``+X'
M```-!@``708``+H%``"P!@``A04```L&``#D`P``Q`$```<$``#J`P``2`<`
M```````"`@```````)X'``#T`0``PP(````````O!P``2P$``"\$``#,`P``
M3`4``)D$``!X!0```````!H```!Y!```1`,``!D`````````6@,```P&````
M````%`0``(`"``"W!@````````\"``"]`@``W@```&<'````````8P,``&L"
M``!_!P```````&P`````````````````````````_0$`````````````RP$`
M`(X``````````````-4&``"9`0``Y08``/`&``#(!@```````(T$``"Z!@``
M`````.\```#E````I@0``+D&````````9`8``)L`````````_@8``,T```!6
M`P``K@(``!L$``!W`@``.P0``)P#``#9!P```````"T%``#J!@``'@(``!H!
M``#2!0``UP4````````^!```=0````````"7!0``_@(``&T```".!@``/P,`
M``````!E!P``K0$``,@'``"#````0@8``)@!````````H00```````#F`P``
MF@,``&8#``!.`P``7@````````!3!`````````````!8`P``V@8```````"3
M!P``D`8``&$#```T`0``+P$``.(!`````````0<````````V`0``_P,``&<#
M``"]!P``U@0``/$#```8`P``X@4``#('``"5!P``1`4``/8!``!]`P``````
M`#T```!<!```9`4``!$`````````5`$``"4```!\!0```````#P"````````
M8`4```````"O````(@$``$@!````````40,``+0'``#D`@``;@<``*T'``!V
M````:P8``($`````````W00``$8#``"T`@````````````!L`@``F@<``'`%
M``#C!0```````&4"```D!0```````&$!```5````UP0``%L'``!N````X0$`
M`"(%````````P0(``-@!``#@`P```````($'````````Q0$``)T$``"\!P``
M````````````````E@,``.\"`````````````,L$``!7!P``(P4```````"R
M`0``B`4```8"````````WP,``'<'``"3!0```````%\%``"O!0``P@,``&4&
M```I!P``QP0``(8$``"0!0``\P8``!`$``#)!@````````\!``"=!P``P`4`
M`,4``````````````(P```!H`@``\`4``%D'``"G````^00``#@&``!\`P``
M.`0``!8```!W`P``V`,``&@%``!%!@``>@$```````"$!P``?`0``#<&``"J
M````S`<`````````````P08```````"V`@````````````#>!```@@<``/X%
M``"S!```S08``.@!``#"`@``808``"T```",`0```0$``*T&``":!@``$@$`
M`%('``!+`P``^@(``-4'``#_`0``9@8``-<&````````PP``````````````
MM`,``)$$``#<````K@,````````[````X04``/0#````````\@(``-$!```Y
M!```30```'X#``"_!```'@,``.0!``"2!0``?P(``*X$``#A!```[P0```(!
M``!+!```&0<```````"\`P``/@<```````"M`@```````-X!``!8!```(@(`
M`.("``#I!0``M04``,D"```3!@``^P```(<&````````60(``*H&``!6````
M`````/D````;!@``AP0```````"#`0``NP<``/T````(`0```````,('````
M````<@,``!\'```T!@```````)@$``"`!@``600```````"W!0``A00``&4#
M``"`!0````````````#-!0```````.8!``#W`P``<@0`````````````'0,`
M``````"4!```WP0`````````````I04```````"O!P``K`0````````1!@``
M=P$```,``````````````,<'``"J!0```P(````````P`0``K@8``(\````8
M!@``L````,4%```F`P``0`,``-H!``#?!P````````````"]!@```````$D`
M``"3!@``%`(``.,&`````````````+D$```<`P``:P,``-H#``"5!```````
M``````#*!@``$@0```````!5!0``+P,``-4!``"P`P``X0```&8"``"@````
MD0<``(X$``#P`````````,8!````````4```````````````I0$``#H"``#*
M`@``Q`(``%`!````````_@```'D```"^`0``8P4``#P#````````:0````T$
M```3````0`0``'T'``"9!@``1@$``'H#````````>`8``%(&``#W!@``2@(`
M`(T```!H!@```````(\#``"C!```HP$`````````````/@```"T&``!<`P``
M>P(``)L'```F!@```````$8%``!H`P```````#4'```Z!0``V0```.P$````
M`````````&H%``#+````!P$``)4!```3!```[0,``(H%```@!0``(`(``-P%
M````````U@(```D"````````QP(``"8"```/!@`````````````1`0``````
M`'0`````````P`(``+$"````````H`,`````````````V`(``&@$``!N!0``
M1````*(%``#7`P``-P,``.\#```A!P``20,``/P!``"R`@``2P(``!<```!<
M!0``I@,```<"``"Q`P```````"0$``#N`@```````*8```"\!0````````T`
M``#;!```"`8``"@```"!!@```````&T&````````/`$``',"``!"!````@``
M`&H"````````!0,```````#4!@``/```````````````'@<``.D```!,````
MS@4```(&````````1P8``#($````````=`0``'``````````L@0```````"8
M`P``X@,``!<$``"J`P```````&L'````````>P```'8$``#E!```W`$`````
M```5!P```````!\%``!`!0````````````"8!0``)`````````"?````3@4`
M`$(!``".`@``4@4``*@$``"9`@``?P```!0!```;````I@4`````````````
M7@(``+T````!!@``N@,``````````````````'`'```F!P``M0(``(D#````
M````?`(``(@'``!Z!```D@(``.\!``#J````H@,``$4$``#`!P``U@$``"D%
M``"H`P``````````````````EP,``"X"``"W`@``Q@,``%0'```#!@``````
M``````#``0``U0,``*,`````````I`8``#(&``"@!P``JP(```0$```G!```
M`````+@'````````*P4``(0#```J````K`<``.P````U````;`8``,X&``#0
M````.`<````````E!@``I`````````#8!@``.08``&<%````````EP``````
M```````````````````5!````````*0$``!M`@``FP(``%4!``#)`0``Z`8`
M````````!P``3P0``(4```!J!```-@<```````!!````%@(``)(&````````
M^`4````````[!0``;P0``$$'``"-!P```````%\&``#Q!0``>@(```````!M
M!```"P0``$P!``#D!````P<``/H#``"0`0``5`8``+8%````````_08`````
M``!%`0``S`8```````#4````BP(``(T#``!R!@```````(,'``!`````3P8`
M`#4!``#-`0``8`<``)`#```!`@````(```````!/````>`<``)`"``!-`@``
M`````&,'``!U`0``A0(``,($``"L````6@0```````!K!```@@```(H#``![
M!0`````````````X`@``0@4```````!^`@``^`(`````````````K0``````
M``#M!0``:@8``*P"````````80(`````````````O@0``(D'```R`P``````
M`)8$````````%````.X#``"<!0````````P%``##`0```````,`#````````
M/@(```$#```@`````````-\!``#K!0``.@$``'4'``"[`@``2````*X!````
M`````00``#(```!!`@``7@0``/$"``#/!0```````/D&```-`0```````.@$
M``!-!@``BP```&$```!P`@``F`````8%``"+!```Y@```%\!```9!0``````
M`)$#``!7````1`0``',$``!'!```````````````````?0(``-T%````````
MN@<```````"'`P```P0``.8&```+!P````````X#````````T`<```8'``!.
M`@``AP$```````#>!P``+P(````````#`P```````(0"``"!`P``G`<``!(%
M``#U````B@8````````Q!@``2`,```````#0!@``#`0``-<'``"7!@``70(`
M``0'``!X`0``[@4```````"F`@``BP,``.$"`````````````#\%````````
MQ`4``+X&``"]!0```````"D!```T`@``=`4```@%``!R````9`(``*D!``".
M`0``-@8``$,'```7!P````````T#``"@`@``4P,``.`$```W!P``H04``.D#
M``!E`0``+0(``/\%``#D````K`4```````#H!0```````````````0``(`0`
M`/8%````````:0,``$@$``!I!0``*`4``&0'``````````````````"6````
M%`8``'0#``#,`@``10````````#.`````````-P'````````?`$````````S
M`@``EP(`````````````C@,```L#`````````````'D!```````````````@
M*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@
M*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES
M(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N
M`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y
M+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE
M('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S
M+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E
M<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N
M`"5D(&YO=&5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!F:6QE
M('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I<R!R96%D>2!T;R!P97)F;W)M
M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H
M96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@
M0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T
M`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M
M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN
M:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@
M<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S
M("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,2!N
M;W1E`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0
M<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R
M<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I
M=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!F:6QE+@!!8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N`$%C
M8V5S<R!D96YI960@;6]V:6YG('1H92!N;W1E+@!!8V-E<W,@9&5N:65D('-A
M=FEN9R!N;W1E('1O("5S+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@
M4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#
M:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D
M($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O
M=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D
M(&$@;F5W('5S97(Z`$%D9"!C871E9V]R>0!!9&0@8V]L=6UN`$%D9"!N97<@
M;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E
M<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U
M="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N
M.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N`$%D9&EN9R!!($YE=R!.;W1E`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S
M`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E
M<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!
M;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R
M`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!
M<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T
M;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL
M`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H
M:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA
M`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N
M9&EN9P!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@
M4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN
M=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U
M<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q
M=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I
M=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I
M<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D
M9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`
M075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I
M8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE($-A
M=&5G;W)I97,Z`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%
M>&-U<V5S`$)A8VL@=&\@3F]T97!A9`!"86-K('1O($YO=&5P860@3W!T:6]N
M<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I
M;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN
M90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N
M`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@
M9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA
M`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!"
M;W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O
M=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I
M=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T
M`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO
M;B!0;VEN=',`0U-6`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W
M87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE
M<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I
M;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N
M9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T
M(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M
M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@
M82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D
M90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A=&5G
M;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S
M`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`
M0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T
M:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S
M=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`
M0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P;&%Y(&]P=&EO;G,N
M`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H
M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R
M9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*0!#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T;R!L:7-T(&EN('1H92!S
M=6UM87)Y('9I97<N`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($9O<FT`0VQE87(@35-/
M9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE
M87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T
M;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#
M;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M
M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z
M`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#
M;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`
M0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F
M86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN
M96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S
M(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O
M<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I
M8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O
M34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B
M:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E
M<G9E<@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R
M=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@
M`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L
M971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R
M97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N
M("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N
M`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B
M.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@
M(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B
M.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A
M=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S
M`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S
M:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R
M<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT
M('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I
M`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O
M:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?
M;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E
M($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT(%-H96QL`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F
M875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L971E`$1E
M;&5T92!#96QL`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M
M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`
M1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T
M92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E
M='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R
M:P!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N
M`$1E<V-R:7!T:6]N.@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL
M92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA
M<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT
M`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D
M(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M
M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D
M96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P
M=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A
M9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I
M="!";&]C:P!%9&ET($=R;W5P`$5D:70@3F]T90!%9&ET(%!E<FUI<W-I;VX`
M161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET
M(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O
M<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M
M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!.;W1E`$5M<'1Y
M(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N
M86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S
M(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N
M9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y
M;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE
M(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R
M;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R
M;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG
M("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A
M;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`
M17AP;W)T`$5X<&]R="!.;W1E<P!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E
M='5P`$9?=6QL(%1E>'0`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E
M<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`
M1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X
M97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E
M<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#
M2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`
M1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&
M:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A
M<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D
M;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD
M(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D
M/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE
M<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@
M365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&
M<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L
M;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R
M;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O
M9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K
M("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES
M=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S
M`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U
M97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A
M=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R
M;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(
M86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE
M8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D
M:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M
M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`
M2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/
M;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G
M92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ
M`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T($YO=&5S+"!3=&5P("5D`$EM
M<&]R="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($YO=&5S`$EM<&]R=&5D(&9I
M96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R
M;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!)
M;F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!)
M;F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!)
M;G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE
M`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T
M97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!)
M;G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I
M=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T
M(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M
M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T
M97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!)
M;G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`
M26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N
M9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D
M:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E
M9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@
M9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@
M<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN
M=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED
M(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED
M('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT
M;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`
M27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA
M<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY
M`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S
M=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I
M;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC
M871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R
M<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB
M871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO
M<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y
M>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I
M8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!-;V1I9FEE9`!,87-T(%!A<W-W
M;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO
M9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE
M=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T
M:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H
M=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@
M16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W
M97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA
M:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN
M9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@
M9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!4
M86)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N
M97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I
M;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E
M`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD
M(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E
M<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO
M=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W
M97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!
M='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O
M;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C
M87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I
M`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T
M(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@
M86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`
M36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H
M`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA
M;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A
M;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E
M('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X
M('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L
M($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-
M96UB97)S`$UE;6\@5&5X=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A
M9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N
M97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A
M9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D
M("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L
M;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI
M<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@
M;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S
M:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D
M97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9&EF>6EN9R`E<P!-
M;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-
M;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`
M36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E
M9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T
M;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@
M57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D
M<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C
M=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@3F]T
M97,`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$
M;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA
M;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE
M='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!5
M4DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC
M871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K
M`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E
M('1O("5S`$YE=R!-;V]N`$YE=R!.;W1E`$YE=R!5<V5R;F%M92`H;W!T:6]N
M86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE
M=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T
M(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP
M;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.
M;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I
M<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L
M:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;F]T97!A9',@87)E(&%V86EL
M86)L92!T;R!G=65S=',N`$YO(&YO=&5S`$YO(&YO=&5S(&UA=&-H('1H92!C
M=7)R96YT(&-R:71E<FEA+@!.;R!N;W1E<R!T;R!D:7-P;&%Y`$YO(&YU;6)E
M<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE
M($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`
M3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@
M<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]?=&4`3F]N
M90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO
M<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@
M82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P
M;W)T960N`$YO=&4@0V%T96=O<GD`3F]T92!$971A:6QS`$YO=&4@3&ES=',`
M3F]T92!497AT`$YO=&4@7U1E>'0`3F]T92!N;W0@9F]U;F0N`$YO=&5?<&%D
M`$YO=&5P860G<R!N86UE.@!.;W1E<&%D<P!.;W1E<P!.;W1E<R!3=6UM87)Y
M`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`
M3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R
M(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R
M`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D
M`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO
M="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/
M<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I
M;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`
M3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!/=VYE<B!0
M97)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!0
M1U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I
M;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!0
M32!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H
M96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C
M8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N
M9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L
M971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`
M4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO
M=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U
M<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N
M86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI
M;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O
M<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C
M:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N
M/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S
M96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C
M=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N
M`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!
M;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A
M=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO
M('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO
M=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE
M`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!,:7-T`%)E
M9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R
M`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L
M;V-K`%)E;6]V92!C871E9V]R>0!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M
M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M
M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO
M="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E
M<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T
M(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P
M87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X
M="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2
M:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2
M;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R
M=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A
M;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT
M(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`
M4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I
M80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@
M36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED
M97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/
M<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E
M87)C:`!396%R8V@@16YG:6YE<P!396%R8V@@4F5S=6QT<P!396%R8V@@4V-O
M<&4`4V5A<F-H(%]497AT`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E
M;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T
M(&$@;F]T97!A9`!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A
M9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L
M96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!3
M96QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R
M;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z
M`%-E;&5C=&5D($-A=&5G;W)I97,Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N
M9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-
M;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@
M;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER
M960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L
M('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO
M<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\`4VAO=P!3:&]W(&%C=&EO;B!B=71T;VYS/P!3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!N;W1E<&%D(&YA;64_`%-H;W<@
M;F]T97,@9G)O;2!T:&5S92!C871E9V]R:65S`%-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO
M9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,
M871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!
M;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V
M86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3
M;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T
M:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD
M<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!B>2!#871E9V]R>0!3;W)T
M(&)Y($YO=&4@5&5X=`!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D
M<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A
M;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O
M;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R
M(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O
M<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I
M;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;
M0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`
M4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S
M>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U
M;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C
M97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3
M=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3
M=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R
M<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@
M2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L
M;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I
M;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A
M8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I
M=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H
M;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!4
M96UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D
M;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O
M<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I
M;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@
M8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I
M;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N
M965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C
M:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T
M;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D
M871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U
M<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S
M<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A
M=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I
M960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N
M("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE
M9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;F]T92!W87,@9&5L
M971E9"X`5&AE(&YO=&5P860@(B5S(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E
M<P!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&-R96%T960N`%1H92!N;W1E
M<&%D("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!H
M87,@8F5E;B!S879E9"X`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N
M=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B
M)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E
M9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@
M;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M
M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U
M(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N
M+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@
M;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A
M=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`
M5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`
M5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET
M97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.;W1E(&1A=&$N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S
M(&%N(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@
M97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<P!4:&5R92!W
M97)E(&YO(&UE;6]S('1O(&5X<&]R="X`5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K
M871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F:6QE(&9O<FUA="!I<R!N
M;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C
M97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@
M96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S
M('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A
M;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E
M;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A
M;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R
M86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E
M`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@
M4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R
M86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4
M<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX
M.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`
M5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%52
M3"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ
M`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL
M92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T
M92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O
M(&1E;&5T92`B)7,B.B`E<P!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E
M;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE
M<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&
M:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G
M;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M
M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q
M=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S
M`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5
M;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A
M=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET
M<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`
M56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N
M(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W
M;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@
M3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI
M8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@
M=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS
M:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B
M+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL
M(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R
M(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S
M92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N
M;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E
M<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N
M(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N
M="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X
M:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E
M;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!6
M86-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED
M:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@
M=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E
M;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A
M;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE
M="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT
M97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI
M='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``
M5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T
M`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B
M(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E
M<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`
M5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U
M<W1R86QI82!M87``5VAI8V@@3F]T97!A9"!S:&]U;&0@=&AE(&YO=&5S(&)E
M(&%D9&5D('1O/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B
M;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#
M4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A
M:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L
M90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD
M('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`
M5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7
M<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E
M9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME
M>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV
M,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9
M`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E
M90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E
M9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AE(&YO=&5P860@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N
M`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO
M=7(@9&5F875L="!N;W1E<&%D.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I
M;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E
M<P!9;W5R(&YO=&5P861S.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R
M<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI
M9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D
M(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E
M<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"86-K('1O($YO=&5P860`7T-,
M20!?0V%T96=O<GD`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2;W<`7T5D
M:70`7T9I<G-T($QI;F4`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?26UP;W)T+T5X<&]R=`!?3&ES="!.;W1E<P!?3&]G(&EN`%],;V<@
M;W5T`%]-;V1I9GD@3&EN:RXN+@!?37D@3F]T97!A9',`7TYE=R!.;W1E`%]/
M<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK+BXN`%]3
M96%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R
M97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K
M(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK
M;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E
M<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D
M`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!N;W1E<RYC<W8`<&5R8V5N
M=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R
M;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R
M96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R
M;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L
M96-T`'9#87)D`'9.;W1E`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R
M<VEO;CH@9G)?1E(*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`T+3$R+3`W(#$U.C(P+3`U,#`*
M3&%S="U4<F%N<VQA=&]R.B!"96YO:70@4W0M06YD<F4@/&)E;D!B96YO:71S
M="UA;F1R92YN970^"DQA;F=U86=E+51E86TZ($9R86YC86ES(#QI,3AN0&QI
M<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([
M('!L=7)A;#TH;B`^(#$I.PI8+4=E;F5R871O<CH@2T)A8F5L(#$N,RXQ"@`@
M*&EL('D@82`E<R!J;W5R<RD`("A4;W5C:&4@9"=A8V/H<R!R87!I9&4@)7,I
M`"`H9&%N<R`E<R!J;W5R<RD`("AA=6IO=7)D)VAU:2D`("AD96UA:6XI`"`H
M:&EE<BD`(.`@`*N@)7.@NR!N)V5S="!P87,@=6X@9&]S<VEE<@"KH"5SH+L@
M;B=E<W0@<&%S('5N(&-H;VEX('9A;&ED92X`JZ`E<Z"[(&XG97-T('!A<R!C
M;VYF:6=U<ND@9&%N<R!L92!R96=I<W1R92!D92!(;W)D92X`3"=I;G1E<G!R
MZ71E=7(@9"=A<F)R92"KH"5SH+L@;B=A('!A<R#I=.D@=')O=7;I+@"KH"5S
MH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64@9&5S(&=R;W5P97,N`*N@)7.@
MNR!A(.ETZ2!A:F]U=.D@874@<WES=.AM92!D97,@<&5R;6ES<VEO;G,N`*N@
M)7.@NR!N)V$@<&%S(.ETZ2!C<NGIH#H@)7,N`"4N,F:@36\@=71I;&ESZ7,@
M<W5R("4N,F:@36\@<&5R;6ES("@E+C)FH"4E*0`E9"`E<R!E="`E<P`E9"!J
M;W5R<R!A=F%N="!L)V5X<&ER871I;VX@9&4@=F]T<F4@;6]T(&1E('!A<W-E
M+@`E9"!N;W1E<P`E9"UP<NEV:7-I;VX@9'4@:F]U<@`E<R`M($YO=&EC90!%
M;7!R96EN=&4@4$=0(&1E("5S`"5SH$MO`"5S(&]PZ7)A=&EO;G,@9&4@;6%I
M;G1E;F%N8V4@)FYD87-H.R!#;VYF:7)M871I;VX`0V]N9FEG=7)A=&EO;B`E
M<P!);G-C<FEP=&EO;B!D92`E<P!#;VYD:71I;VYS(&0G=71I;&ES871I;VX@
M9&4@)7,`)7,@97AI<W1E(&3I:N`N`"`E<Z#@("5S("5S`"5S(&9I8VAI97)S
M(&EM<&]R=.ES(&%V96,@<W5C8^AS`"5S(&5S="!P<NIT(.`@969F96-T=65R
M(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E(&-O8VCI97,@8VDM9&5S
M<V]U<RX@4^EL96-T:6]N;F5Z(&QA(&]U(&QE<R!O<.ER871I;VXH<RD@<75E
M('9O=7,@=F]U;&5Z(&5F9F5C='5E<B!C971T92!F;VES+6-I+@`E<R!E<W0@
M;V)L:6=A=&]I<F4`)7,@;6EN=71E<P`E<R!N;VX@=')O=7;I`"5SH.`@)7,@
M9&4@)7,`0V%R;F5T(&0G861R97-S97,@9&4@)7,`06=E;F1A(&1E("5S`$)L
M;V,M;F]T97,@9&4@)7,`3&ES=&4@9&4@=.)C:&5S(&1E("5S`"5SH#H@)7,`
M)7.@.B!L)^EM971T975R(&1E(&-E(&UE<W-A9V4@82!P=2#J=')E(&9A;'-I
M9FGI+B!!='1E;G1I;VX@96X@<W5I=F%N="!L97,@;&EE;G,@<74G:6P@8V]N
M=&EE;G0@;W4@96X@9F]U<FYI<W-A;G0@9&5S(&EN9F]R;6%T:6]N<R!P97)S
M;VYN96QL97,@X"!L)^EM971T975R+@`L(&5N(')A9F%L92``<F%F86QE("5S
M("5S`'9A<FEA8FQE(&1U("5S(&%U("5S`"TM(%/I;&5C=&EO;FYE<B`M+0`Q
M(&YO=&4`1F]R;6%T(#$R(&AE=7)E<P!&;W)M870@,C0@:&5U<F5S`#(T(&AE
M=7)E<P`\4'+I8^ED96YT`%5N92!B87-E(&1E(&1O;F[I97,@<')I;F-I<&%L
M92`H8F%C:V5N9"D@97-T(&[I8V5S<V%I<F4@<&]U<B!C92!B;&]C`%5N92!E
M<G)E=7(@9F%T86QE(',G97-T('!R;V1U:71E`%5N92!C;&5F('!U8FQI<75E
M(%!'4"!E<W0@;NEC97-S86ER92!P;W5R(&-H:69F<F5R('5N(&UE<W-A9V4N
M`%5N92!C;&5F('!U8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P;W5R(';I
M<FEF:65R(&QA('-I9VYA='5R92!D)W5N(&UE<W-A9V4N`%5N92!C;&5F('!U
M8FQI<75E(%!'4"P@=6YE(&-L968@<')I=NEE(%!'4"P@970@=6YE('!H<F%S
M92!S96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U<B!DZ6-H:69F<F5R('5N
M(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%!'4"P@=6YE(&-L968@<')I
M=NEE(%!'4"P@970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@;NEC97-S86ER
M97,@<&]U<B!S:6=N97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@
M4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@<&AR87-E
M('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E<R!P;W5R(&3I8VAI9F9R97(@=6X@
M;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P
M<FEVZ64@4R]-24U%+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E
M<W-A:7)E<R!P;W5R('-I9VYE<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L
M:7%U92!3+TU)344@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF9G)E<B!U;B!M
M97-S86=E+@!.=6%G97,@;&4@;6%T:6X`4&QU:64@;.EGZ')E(&QE(&UA=&EN
M`%!L=6EE(&QE(&UA=&EN`$%V97)S97,@;&4@;6%T:6X`0VAU=&5S(&1E(&YE
M:6=E(&QE(&UA=&EN`$%-+U!-`$%022!)1`#`('!R;W!O<R!D92!C970@Z61I
M=&5U<@#`('!R;W!O<RXN+@!"87,@86)S;VQU`$UI;&EE=2!A8G-O;'4`06-C
MZ',@<F5F=7/I(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@<NEP97)T;VER92!6
M1E,@+@!!8V/H<R!R969U<^D@;&]R<R!D92!L82!C<NEA=&EO;B!D92!F:6-H
M:65R(%9&4RX`4W5P<')E<W-I;VX@9&4@;&$@;F]T92!I;G1E<F1I=&4N`$%C
M8^AS(')E9G5SZ2!E;B!DZ7!L8>=A;G0@;&$@;F]T92X`26YT97)D:6-T:6]N
M(&0G96YR96=I<W1R97(@;&$@;F]T92!V97)S("5S+@!$;VYNZ65S('!E<G-O
M;FYE;&QE<P!-;W0@9&4@<&%S<V4@9'4@8V]M<'1E`$-O;7!T92!I;F%C=&EF
M`$-O;7!T97,`06IO=71E<@!!:F]U=&5R('5N('-O=7,M9W)O=7!E`$%J;W5T
M97(@=6YE(&YO=79E;&QE('-O=7,M<&5R;6ES<VEO;@!!:F]U=&5R(&EC::`Z
M`$%J;W5T97(@=6X@;F]U=F5A=2!G<F]U<&4`06IO=71E<B!U;F4@;F]U=F5L
M;&4@<&5R;6ES<VEO;@!!:F]U=&5R('5N(&=R;W5P92!F:6QS(.`@JZ`E<Z"[
M`$%J;W5T97(@=6YE('!E<FUI<W-I;VX@9FEL;&4@X""KH"5SH+L`06IO=71E
M<B!U;B!N;W5V96P@=71I;&ES871E=7*@.@!!:F]U=&5R('5N92!C873I9V]R
M:64`06IO=71E<B!U;F4@8V]L;VYN90!!:F]U=&5R(&1E(&YO=79E875X(&UE
M;6)R97,`06IO=71E<B!U;F4@<&%I<F4`06IO=71E<B!L92!M96YU("5S(.`@
M;&$@8F%R<F4@9&4@36]Z:6QL80!!:F]U=&5R(&%U(&-A<FYE="!D)V%D<F5S
M<V5SH#H`06IO=71E<B#@(&UO;B!C87)N970@9"=A9')E<W-E<P!!:F]U=&5R
M('5N('5T:6QI<V%T975R`*N@)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM
M92P@;6%I<R!L)V%J;W5T(&0G:6YF;W)M871I;VX@<W5P<&SI;65N=&%I<F5S
M("5S(&XG97-T('!A<R!P;W-S:6)L92X`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2X@
M5F]U<R!P;W5V97H@=F]U<R!C;VYN96-T97(N`$%J;W5T(&0G=6YE(&YO=79E
M;&QE(&YO=&4`3&$@9F]N8W1I;VX@9"=A:F]U="!D)W5T:6QI<V%T975R<R!E
M<W0@9.ES86-T:7;I92X`061R97-S90!#87)N970@9"=A9')E<W-E<P!!9&UI
M;FES=')A=&5U<B`M(&%J=7-T97(@;&5S('!E<FUI<W-I;VYS('!O=7(@9"=A
M=71R97,@=71I;&ES871E=7)S`$%D;6EN:7-T<F%T:6]N`%!U8G,`069G:&%N
M:7-T86X`06QB86YI90!!;&?I<FEE`$%L:6%S`$%L:6=N97(`06QI9VYE;65N
M=*`Z`%1O=70`5&]U<R!L97,@<&%R=&EC:7!A;G1S(&%U=&AE;G1I9FGI<P!4
M;W5S(&QE<R!G<F]U<&5S`%1O=71E<R!L97,@<&5R;6ES<VEO;G,`3&5S('%U
M871R92!C]'3I<P!097)M971T<F4@9&5S(&%D<F5S<V5S(&1E(&-O=7)R:65L
M(&UU;'1I<&QE<P!!=71O<FES97(@;&$@;6ES92!E;B!P;&%C92!D92!L:7-T
M97,@;G5MZ7)O=.EE<Z`_`$5X:7-T92!DZ6K@`$YO;2!D)W5T:6QI<V%T975R
M($E-4U`@86QT97)N871I9@!-;W0@9&4@<&%S<V4@24U34"!A;'1E<FYA=&EF
M`$YO;2!D)W5T:6QI<V%T975R($E-4U`@86QT97)N871I9@!!9')E<W-E(&1E
M(&-O=7)R:65L(&%L=&5R;F%T:79E`$%U=')E<R!M;V3H;&5S`%1E>'1E(&%L
M=&5R;F%T:6:@.@!386UO82!!;>ER:6-A:6X`56YE('9A;&5U<B!I;&SI9V%L
M92!A(.ETZ2!S<.EC:69IZ64N`%5N92!E<G)E=7(@:6YC;VYN=64@<R=E<W0@
M<')O9'5I=&4N`$%N9&]R<F4`06YG;VQA`$%N9W5I;&QA`%!R;WAY(&%N;VYY
M;64`4NEP;VYS90!!;G1A<F-T:7%U90!!;G1I9W5A+65T+4)A<F)U9&$`07!P
M;&EC871I;VX`3&ES=&4@9"=A<'!L:6-A=&EO;G,`3"=A<'!L:6-A=&EO;B!E
M<W0@<'+J=&4`07!P;&EQ=65R(&%U>"!P87)T86=E<R!F:6QS`$%P<')O=7;I
M`%1A:6QL92!A<'!R;WAI;6%T:79E`$%V<FEL`$%R86)E("A7:6YD;W=S+3$R
M-38I`%1A:6QL92!D=2!F:6-H:65R(&%R8VAI=F4`3F]M(&1E(&PG87)C:&EV
M90#*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER('-U<'!R:6UE<B!C971T
M92!R97%UZG1E(&0G:6YS8W)I<'1I;VX@('!O=7(@)7.@/P#*=&5S+79O=7,@
M8V5R=&%I;B!D92!V;W5L;VER(&5F9F%C97(@JZ`E<Z"[(&5T('-E<R!S;W5S
M+6=R;W5P97.@/P!!<F=E;G1I;F4`07)MZ6YI90!!<FWI;FEE;B`H05)-4T-)
M22TX*0!!<G0`07)U8F$`0W)O:7-S86YT`$%S8V5N<VEO;B`HSFQE*0!!<G0@
M05-#24D`4NEG:6]N($%S:64O4&%C:69I<75E`$1E;6%N9&5R('5N92!C;VYF
M:7)M871I;VX@879A;G0@9&4@;&%N8V5R(&QE<R!O<.ER871I;VYS(&1E(&UA
M:6YT96YA;F-EH#\`0V]L;VYN97,@9&5S('3B8VAE<P!496YT871I=F4@9"=E
M9F9A8V5M96YT(&0G=6X@9W)O=7!E(&EN97AI<W1A;G0N`%1E;G1A=&EV92`@
M9"=E9F9A8V5M96YT(&0G=6YE('!E<FUI<W-I;VX@:6YE>&ES=&%N=&4N`%1E
M;G1A=&EV92!D92!M;V1I9FEC871I;VX@9"=U;F4@<&5R;6ES<VEO;B!I;F5X
M:7-T86YT92X`5&5N=&%T:79E(&1E(&UO9&EF:6-A=&EO;B!D)W5N('!A<G1A
M9V4@:6YE>&ES=&%N="X`4')O<')IZ73I<P!!;_MT`$%U<W1R86QI90!!=71R
M:6-H90!!=71H7V-Y<G5SH#H@17AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@
M=')O=7;I92X`075T:%]C>7)U<Z`Z(&QE(&)A8VME;F0@;B=A('!A<R!L97,@
M8V%P86-I=.ES(')E<75I<V5S+@!!=71H7V-Y<G5SH#H@97AT96YS:6]N(')E
M<75I<V4@24U!4"!N;VX@=')O=7;I90!!=71H7V9T<*`Z(&5X=&5N<VEO;B!R
M97%U:7-E($944"!N;VX@=')O=7;I92X@26P@9F%U="!C;VUP:6QE<B!02%`@
M879E8R!L)V]P=&EO;B`M+65N86)L92UF='`N`$%U=&A?:6UA<*`Z(&5X=&5N
M<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64N`$%U=&A?:W)B-:`Z(&5X
M=&5N<VEO;B!R97%U:7-E(&MR8C4@;F]N('1R;W5VZ64N`$%U=&A?;&1A<*`Z
M(&PG86IO=70@9"=U=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U<'!O<G3I(&%V
M96,@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87"@.B!L92!R971R86ET(&0G
M=71I;&ES871E=7)S(&XG97-T('!A<R!S=7!P;W)TZ2!A=F5C($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%PH#H@97AT96YS:6]N(')E<75I<V4@3$1!4"!N
M;VX@=')O=7;I92X`075T:%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@
M;"=U=&EL:7-A=&5U<B`E<RX@0V5C:2!E<W0@;&$@<NEP;VYS92!D=2!S97)V
M975RH#H@`$%U=&A?;&1A<*`Z(&EM<&]S<VEB;&4@9&4@<W5P<')I;65R(&PG
M=71I;&ES871E=7(@)7,`075T:%]L9&%PH#H@;6]D:69I8V%T:6]N(&EM<&]S
M<VEB;&4@9&4@;"=U=&EL:7-A=&5U<B`E<P!!=71H7VQD87"@.B!L82!M;V1I
M9FEC871I;VX@9&5S('5T:6QI<V%T975R<R!N)V5S="!P87,@<W5P<&]R=.EE
M(&%V96,@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%LH#H@97AT96YS:6]N
M(')E<75I<V4@34-!3"!N;VX@=')O=7;I92X`075T:%]S;6)A=71HH#H@97AT
M96YS:6]N(')E<75I<V4@<VUB875T:"!N;VX@=')O=7;I92X`R6-H96,@9&4@
M;"=A=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@24U!4"X`R6-H96,@9&4@
M;"=A=71H96YT:69I8V%T:6]N`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO
M;B`E<P!,92!S97)V975R(%)!1$E54R!A(')E:F5TZ2!L)V%U=&AE;G1I9FEC
M871I;VXN`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO;B!A=2!S97)V975R
M($944"X`R6-H96,@9&4@;"=A=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@
M4TU"+@!#873I9V]R:65S(&1I<W!O;FEB;&5SH#H`0VAA;7!S(&1I<W!O;FEB
M;&5SH#H`07IE<F)A[V1J86X`17AC=7-E<R!"3T9(`%)E=F5N:7(@874@8FQO
M8RUN;W1E<P!2971O=7(@875X(&]P=&EO;G,@9&4@0FQO8RUN;W1E<P!#;W5L
M975R(&1E(&9O;F0`0V]U;&5U<B!D92!F;VYD`$UO="!D92!P87-S92!+97)B
M97)O<R!E<G)O;NDN`$YO;2!D92!C;VYN97AI;VX@2V5R8F5R;W,@97)R;V[I
M+@!"86AA;6%S`$)A:')E[VX`0F%L=&4@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&4`4NEP97)T;VER92!D97,@9W)A<&AI<75E<R"KH"5SH+L@
M;F]N('1R;W5VZ2X`3&EG;F4@9&4@8F%S90!"Z6QA<G5S`$)E;&=I<75E`$)E
M;&EZ90!"Z6YI;@!"97)M=61E<P!":&]U=&%N`$%N;FEV97)S86ER90!";&]C
M(*LE<R"[(&1E(&PG87!P;&EC871I;VX@JZ`E<Z"[(&EN8V]N;G4`4'+I9NER
M96YC97,@9&4@8FQO8P!4>7!E(&1E(&)L;V,`1W)A<P!";VQI=FEE`%-I9VYE
M=',`0F]R9'5R90#)<&%I<W-E=7(@9&4@;&$@8F]R9'5R9:`Z`$)O<F1S`$)O
M<VYI92U(97)ZZ6=O=FEN90!,97,@9&5U>`!";W1S=V%N80!"87,`0F]U=F5T
M`$)RZ7-I;`!497)R:71O:7)E<R!B<FET86YN:7%U97,@9&4@;"=/8^EA;B!)
M;F1I96X`4W5L=&%N870@9'4@0G)U;NEI`$)U;&=A<FEE`$QI<W1E(.`@<'5C
M97,`0G5R:VEN82!&87-O`$)U<G5N9&D`1V5S=&EO;B!D92!C;VYT96YU`$-2
M0P!$:7-T<FEB=71I;VX@9&5S('!O:6YT<R!,4D,@*$QI<W1E(&1E('+I=F]C
M871I;VX@9&5S(&-E<G1I9FEC871S*0!#4U8`4')O<')IZ73I<R!D92!L82!#
M7V5L;'5L90!,)VEN:71I86QI<V%T:6]N(&1U(&-A8VAE(&YE(',G97-T('!A
M<R!T97)M:6[I92X`06=E;F1A`$-A;&UE`$-A;6)O9&=E`$-A;65R;W5N`$EM
M<&]S<VEB;&4@9&4@<NEI;FET:6%L:7-E<B!L92!M;W0@9&4@<&%S<V4@875T
M;VUA=&EQ=65M96YT+"!C;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E=7(@
M<WES=.AM92X`26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@9FEC:&EE<B"K
MH"5SH+LN`$EM<&]S<VEB;&4@9"=A9&UI;FES=')E<B!D97,@9V5S=&EO;FYA
M:7)E<R!D92!S97-S:6]N(&5X=&5R;F5S+@#)8VAE8R!D92!L82!C;VYN97AI
M;VX@874@<V5R=F5U<B!)34%0H#H@)7,`26UP;W-S:6)L92!D)V]U=G)I<B!L
M92!F:6-H:65R(*N@)7.@NRX`0V%N861A`$%N;G5L97(`06YN=6QE<B!L92!R
M87!P;W)T(&1U('!R;V)LZ&UE`$EM<&]S<VEB;&4@9&4@<W5P<')I;65R(&QE
M(&9I8VAI97(@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E('1R;W5V97(@=6X@<NEP
M97)T;VER92!T96UP;W)A:7)E`$EM<&]S<VEB;&4@9&4@<')O8^ED97(@<V%N
M<R!L92!P87)A;>AT<F4@JR!T87)G971&:6QE(+L`26UP;W-S:6)L92!D92!S
M=7!P<FEM97(@;&4@<NEP97)T;VER92"KH"5SH+LN`%-U<'!R97-S:6]N(&EM
M<&]S<VEB;&4L(&EL('D@82`E9"!E;G)E9VES=')E;65N=',@9FEL<RX`26UP
M;W-S:6)L92!D92!RZ6]R9&]N;F5R+"!L92!N;VUB<F4@9"?I;.EM96YT<R#@
M('+I;W)D;VYN97(@;F4@8V]R<F5S<&]N9"!P87,@874@;F]M8G)E(&0GZ6SI
M;65N=',@96YR96=I<W1RZ7,N`$YE('!E=70@9&ER:6=E<B!L92!M97-S86=E
M('9E<G,@;&4@;F]M8G)E('-PZ6-I9FGI+@!#87`M5F5R=`!,Z6=E;F1E`%1R
M86YS<&]R=&5U<@!#873I9V]R:65S(&5T(,ET:7%U971T97,`0V%TZ6=O<FEE
M`,YL97,@0V'O;6%N`%3I;.EP:&]N92!C96QL=6QA:7)E`%!R;W!R:>ETZ7,@
M9&4@;&$@8V5L;'5L90!296UP;&ES<V%G92!A=71O=7(@9&4@;&$@8V5L;'5L
M9:`Z`%!R;W!R:>ETZ7,@9&4@;&$@8V5L;'5L90!%<W!A8V5M96YT(&1E(&QA
M(&-E;&QU;&6@.@!4Z6SI<&AO;F4@8V5L;'5L86ER92``0V5L=&4@*$E33RTX
M.#4Y+3$T*0!#96YT<F5R`%+I<'5B;&EQ=64@8V5N=')A9G)I8V%I;F4`175R
M;W#I96X@8V5N=')A;"`H25-/+3@X-3DM,BD`1.ET86EL<R!D=2!C97)T:69I
M8V%T`%!R;W!R:>ET86ER92!D=2!C97)T:69I8V%T`%!O;&ET:7%U92!D92!C
M97)T:69I8V%T:6]N`%1C:&%D`$UO9&EF:65R`$UO9&EF:65R('9O=')E(&UO
M="!D92!P87-S90!#:&%N9V5R(&QE(&YO;2P@;"=A9')E<W-E(&5T(&QA('-I
M9VYA='5R92!Q=64@;&5S('!E<G-O;FYE<R!V;VEE;G0@<75A;F0@96QL97,@
M;&ES96YT(&5T('+I<&]N9&5N="#@('9O<R!M97-S86=E<RX`36]D:69I97(@
M;&4@=')I(&1E('9O<R!N;W1E<R!E="!L97,@;W!T:6]N<R!D)V%F9FEC:&%G
M92X`3&$@;6]D:69I8V%T:6]N(&1E('9O=')E(&UO="!D92!P87-S92!N)V5S
M="!P87,@<W5P<&]R=.EE(&%V96,@;&$@8V]N9FEG=7)A=&EO;B!A8W1U96QL
M92X@0V]N=&%C=&5Z('9O=')E(&%D;6EN:7-T<F%T975R+@!#:&%R`%;I7W)I
M9FEE<B!L92!L:65N`$-H:6QI`$-H:6YE`$-H:6YO:7,@<VEM<&QI9FGI("A'
M0C(S,3(I`$-H:6YO:7,@=')A9&ET:6]N;F5L("A":6<U*0!#:&]I<VER(&PG
M87!P;&EC871I;VZ@.@!#:&]I<VER('5N(&UO="!D92!P87-S90!#:&]I<VER
M('5N(&YO;2!D92!C;VYN97AI;VX`0VAO:7-I<B!L92!M;V1E(&0G869F:6-H
M86=E(&1E<R!D871E<Z`Z`$-H;VES:7(@;&4@<W1Y;&4@9&4@;&ES=&4@*'!O
M=7(@;&5S(&QI<W1E<R!N=6WI<FEQ=65S*0!#:&]I<VES<V5Z(&QE<R!C873I
M9V]R:65S(&1E(&YO=&5S(.`@<'+I<V5N=&5R(&1A;G,@;&4@<V]M;6%I<F4N
M`,YL97,@0VAR:7-T;6%S`$3I9FEN:71I;VX@9&4@;&$@8VQA<W-E(&1E("5S
M(&YO;B!T<F]U=NEE+@!%9F9A8V5R`$5F9F%C97(@;&4@9F]R;75L86ER90!.
M971T;WEE<B!L97,@8F%L:7-E<R!-4RU/9F9I8V4`169F86-E<B!L82!R97%U
MZG1E`%)E=&ER97(@;"=U=&EL:7-A=&5U<CH@)7,`169F86-E<B!L)W5T:6QI
M<V%T975R`$5F9F%C97(@;&5S(&1O;F[I97,@9&4@;"=U=&EL:7-A=&5U<@#)
M8VQA:7)C:65S('1A<F0@9&%N<R!L82!J;W5R;NEE`$-L:7%U97(@<&]U<B!P
M;W5R<W5I=G)E`$-L:6-K871E;&P@=FEA($A45%``1F5R;65R(&QA(&9E;NIT
M<F4`3G5A9V5S`$YU86=E<R!M871I;F%U>`!.=6%G975X`,YL97,@0V]C;W,`
M4F5P;&EE<B!L82!B87)R92!D92!C]'3I`%+I9'5I<F4@;&5S(&)O<F1S`$-O
M;&]M8FEE`$-O=6QE=7(`4&%L971T92!D92!C;W5L975R<P!3Z6QE8W1I;VX@
M9"=U;F4@8V]U;&5U<@!#;VQSH#H`5&ET<F5S(&1E(&-O;&]N;F4`0BY$+@!#
M;VUM86YD90!#;VUM86YD92!S:&5L;`!#;VUM96YT86ER90!.;VT@=7-U96P`
M0V]M;W)E<P!3;V-IZ73I`$]R9&EN871E=7)S`$-O;F1I=&EO;@!#;VYD:71I
M;VYS`$1I9F;I<F5N8V5S(&1E(&-O;F9I9W5R871I;VX`4WEN8VAR;VYI<V%T
M:6]N(&1E<R!A<W-I<W1A;G1S('!E<G-O;FYE;',L(#Q)/G-M87)T<&AO;F5S
M/"])/B!E="!/=71L;V]K+@!,82!C;VYF:6=U<F%T:6]N(&XG97-T('!A<R#@
M(&IO=7(N`$-O;F9I9W5R97(@)7,`0V]N9FER;65R(&QE(&UO="!D92!P87-S
M90!#;VYG;P!2Z7!U8FQI<75E(&3I;6]C<F%T:7%U92!D=2!#;VYG;P#)8VAE
M8R!D92!L82!C;VYN97AI;VX`R6-H96,@9&4@;&$@8V]N;F5X:6]NH#H@`$-O
M;FYE>&EO;B!A=2!S97)V975R(&1E(&-L969S('!U8FQI8R!R969U<^EE+@!#
M;VYN97AI;VX@874@<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@<F5F=7/I92X@
M4F%I<V]NH#H@("5S("@E<RD`R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E
M<G9E=7(@1E10`$-O;G1A8W1S`$-E<R!C;VYT86-T<R!O;G0@8FEE;B#I=.D@
M86IO=73I<R#@('9O=')E(&-A<FYE="!D)V%D<F5S<V5S+@!4>7!E(&1E(&-O
M;G1E;G4@9'4@9FEC:&EE<B!C;VUP<F5S<^F@.B``0V]N=&5N=2!D92"KH"5S
MH+L`4&]U<G-U:79R90#.;&5S($-O;VL`5.EM;VEN("AC;V]K:64I`$-O<&EE
M<@#)8VAE8R!D92!L82!C;W!I9:`Z("5S`%/I;&5C=&EO;B!D)W5N92!C;W!I
M90!)9"X@8V_[=`!#;W-T82!2:6-A`$/T=&4@9"=)=F]I<F4`26UP;W-S:6)L
M92!D92!C:&EF9G)E<B!L92!M97-S86=EH#H@`%-I9VYA='5R92!01U`@9'4@
M;65S<V%G92!I;7!O<W-I8FQEH#H@`$EM<&]S<VEB;&4@9&4@8VAI9F9R97(@
M;&4@;65S<V%G92!A=F5C(%,O34E-12X`4VEG;F%T=7)E(%,O34E-12!D=2!M
M97-S86=E(&EM<&]S<VEB;&4N`$%J;W5T(&1U(&-O;G1A8W0@)7,@:6UP;W-S
M:6)L92X@`$YE('!E=70@<V4@8V]N;F5C=&5R(&%U('-E<G9E=7(@3$1!4"X`
M3F4@<&5U="!S92!C;VYN96-T97(@874@<V5R=F5U<B!,1$%0`%;I<FEF:6-A
M=&EO;B!D92!L82!B86QA;F-E("5S(&EM<&]S<VEB;&4N(`#)8VAE8R!D92!L
M82!C;VYN97AI;VX@874@<V5R=F5U<B!,1$%0`,EC:&5C(&1E(&QA(&-O;FYE
M>&EO;B!A=2!S97)V975R(*N@)7.@NR!V:6$@1E10H#H@)7,`0W+I871I;VX@
M9&4@;&ES=&4@9&4@9&ES=')I8G5T:6]N(&EM<&]S<VEB;&4N("5S`$EM<&]S
M<VEB;&4@9&4@9.EC:&EF9G)E<B!L97,@9&]N;NEE<R!01U"@.B``26UP;W-S
M:6)L92!D92!DZ6-H:69F<F5R(&QE<R!D;VYNZ65S(%,O34E-12X`3F4@<&5U
M="!P87,@<W5P<')I;65R(&QE(&-O;G1A8W0@)7,`3F4@<&5U="!P87,@<W5P
M<')I;65R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B`E<P!.92!P975T('!A
M<R!S=7!P<FEM97(@;&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(*N@)7.@NRX`
M1.ET97)M:6YA=&EO;B!D92!L)V%D<F5S<V4@9'4@9&5S=&EN871A:7)E(&EM
M<&]S<VEB;&4N`$YE('!E=70@<NEC=7#I<F5R('1O=70@;&4@8V%R;F5T(&0G
M861R97-S92X`3F4@<&5U="!RZ6-U<.ER97(@=&]U=&4@;&$@;&ES=&4@9&4@
M9&ES=')I8G5T:6]N+@!.)V$@<&%S('!U('+I8W5PZ7)E<B!L82!L:7-T92!C
M;VUP;.AT92!D92!L:7-T97,@9&4@9&ES=')I8G5T:6]N+@!);7!O<W-I8FQE
M(&1E(&-H87)G97(@;&$@<W1R873I9VEE(*N@)7.@NRX`26UP;W-S:6)L92!D
M92!C<NEE<B!L92!RZ7!E<G1O:7)E(*N@)7.@NRX`26UP;W-S:6)L92!D)V]B
M=&5N:7(@;&$@8VQE9B!P=6)L:7%U92#@('!A<G1I<B!D=2!S97)V975R(&1E
M(&-L969S+@!/=79E<G1U<F4@9&4@JZ`E<Z"[(&EM<&]S<VEB;&4@96X@Z6-R
M:71U<F4N`$]U=F5R='5R92!D92`E<R!I;7!O<W-I8FQE+@!);7!O<W-I8FQE
M(&0G;W5V<FER(&QE(&UO9'5L92!-86EN=&5N86YC95]487-K("5S`$]U=F5R
M='5R92!D=2!D;W-S:65R(*N@)7.@NR!I;7!O<W-I8FQE+@!);7!O<W-I8FQE
M(&0G871T96EN9')E(&QE('-E<G9E=7(@3$1!4"X`3&5C='5R92!D92`E<R!I
M;7!O<W-I8FQE+B``3B=A('!U(')E;65T=')E(.`@>NER;R!L92!M;W0@9&4@
M<&%S<V4@<&]U<B!L)W5T:6QI<V%T975R(&1E;6%N9.DN($-E<G1A:6YS("AO
M=2!T;W5S*2!L97,@9.ET86EL<R!N92!S;VYT('!A<R!C;W)R96-T<RX@4NEE
M<W-A>65Z(&]U(&-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U<B!P;W5R
M(&1E(&PG86ED92X`4NEC=7#I<F%T:6]N(&1E<R!!0TP@:6UP;W-S:6)L90!.
M92!P975T('+I8W5PZ7)E<B!L92!C87)N970@9"=A9')E<W-E<RX@)7,`3F4@
M<&5U="!RZ6-U<.ER97(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<P!.
M92!P975T('+I8W5PZ7)E<B!L97,@;&ES=&5S(&1E(&1I<W1R:6)U=&EO;BX@
M)7,`3F4@<&5U="!RZ6-U<.ER97(@;&5S('!O<W-I8FEL:73I<R!D=2!S97)V
M975R`$YE('!E=70@<&%S(')E=F5N:7(@X"!L82!C;VYF:6=U<F%T:6]N('!R
MZ6/I9&5N=&4N`$5F9F%C96UE;G0@9'4@9&]S<VEE<B"KH"5SH+L@:6UP;W-S
M:6)L92X@`$YE('!E=70@<&%S(&5N<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I
M;VX@)7,`3F4@<&5U="!P87,@96YR96=I<W1R97(@=6YE('-A=79E9V%R9&4@
M9&4@;&$@8V]N9FEG=7)A=&EO;BX`26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R
M('5N92!C;W!I92!D92!L82!C;VYF:6=U<F%T:6]NH#H@)7,`26UP;W-S:6)L
M92!D)V5N<F5G:7-T<F5R(&QE('-C<FEP="!D92!M:7-E(.`@:F]U<B!D86YS
MH#H@JZ`E<Z"[+@!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@=6YE(&-O<&EE
M(&1U(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RX`26UP;W-S:6)L92!D
M)V5N<F5G:7-T<F5R(&QE(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RX@
M5F]U<R!P;W5V97H@<V]I="!U=&EL:7-E<B!U;F4@9&5S(&]P=&EO;G,@<&]U
M<B!S875V97(@;&4@8V]D92!S=7(@)7,@<V]I="!C;W!I97(@;6%N=65L;&5M
M96YT(&QE(&-O9&4@8VDM9&5S<V]U<R!D86YS("5S+@!.92!P975T('!A<R!R
M96-H97)C:&5R(&QE('-E<G9E=7(@3$1!4"X`4W5P<')E<W-I;VX@9&4@JZ`E
M<Z"[(&EM<&]S<VEB;&4N`$UI<V4@X"!J;W5R(&1U(&-O;G1A8W0@:6UP;W-S
M:6)L92X@)7,`3F4@<&5U="!M971T<F4@X"!J;W5R(&QA(&QI<W1E(&1E(&1I
M<W1R:6)U=&EO;BX@)7,`3F4@<&5U="!P87,@96YR96=I<W1R97(@;&$@8V]N
M9FEG=7)A=&EO;B!P;W5R(*N@)7.@NZ`Z("5S`$YE('!E=70@=')O=79E<B!L
M82!B87)R92!D92!-;WII;&QA+B`@07-S=7)E>BUV;W5S('%U)V5L;&4@97-T
M(&%C=&EV92X`3F4@<&5U="!A='1R:6)U97(@8V5S(&1R;VET<R#@(&PG=71I
M;&ES871E=7(@JZ`E<Z"[("!S=7(@;&4@9&]S<VEE<B"KH"5SH+N@.B`E<P!4
M97AT92!C;VUP=.D`4&%Y<P!#;W5R<P!#<NEE<@!#<NEE<B!U;B!L:65N`$-R
MZ65R('5N(&YO=79E874`0W+I97(@=6X@<V]U<RUD;W-S:65R`$-RZ>D`4&5R
M;6ES<VEO;G,@1&4@0W+I871E=7(`3G5MZ7)O(&1E(&-A<G1E(&1E(&-RZ61I
M=`!#<F]A=&EE`$-U8F$`-"!P:&%S97,@8V]U<F%N=&5S`%-E<W-I;VYS(&5N
M(&-O=7)S`$AE=7)E(&%C='5E;&QE`$PG861R97-S92!54DP@86-T=65L;&4@
M97-T`%5T:6QI<V%T975R<R!A8W1U96QS`$]B<V5R=F%T:6]N<R!A8W1U96QL
M97,`0V]N9&ET:6]N(&%C='5E;&QEH#H@`%-T>6QE(&-O=7)A;G0`1.EF:6YI
M<B!L97,@=.)C:&5S(.`@969F96-T=65R(&QO<G,@9&4@;&$@8V]N;F5X:6]N
M(.`@)7,N`$-O=7!E<@!#;W5P97(@;&$@<^EL96-T:6]N`$-H>7!R90!#>7)I
M;&QI<75E("A+3TDX+5(I`$-Y<FEL;&EQ=64@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:7%U92]5:W)A:6YI96X@*$M/23@M52D`4NEP=6)L:7%U92!48VCH<75E
M`$I*`$133B`H0V8N(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A
M8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`0VAA<75E(&IO=7(`
M3F%V:6=A=&5U<B!D92!$871A5')E90!!;&EA<R!D92!L82!B87-E`$1A=&4`
M1&%T92!D92!RZ6-E<'1I;VX`4^EL96-T:6]N(&0G=6YE(&1A=&4`2F]U<@!3
M=7!P<FEM97(@7VQA(&-O;&]N;F4`1.EC96UB<F4`3F]M8G)E<R!DZ6-I;6%U
M>`!$:6UI;G5E<B!L)VEN9&5N=&%T:6]N`$3I9F%U=`!#;W5L975R('!A<B!D
MZ69A=70`261E;G1I=.D@<&%R(&3I9F%U=`!);G1E<G!RZ71E=7(@9&4@8V]M
M;6%N9&4@<&%R(&3I9F%U=`!#<FETZ')E(&1E('1R:2!P87(@9.EF875TH#H`
M4V5N<R!D=2!T<FD@<&%R(&3I9F%U=*`Z`$3I9FEN:71I;VYS`%-U<'!R:6UE
M<@!%9F9A8V5R(&QA(&-E;&QU;&4`4W5P<')I;65R('5N(&=R;W5P90!%9F9A
M8V5R(&QA('1R86-E`%-U<'!R:6UE<B!U;F4@<&5R;6ES<VEO;@!3=7!P<FEM
M97(@970@<'5R9V5R(&QE<R!M97-S86=E<P!%9F9A8V5R(&QA(&-E;&QU;&4`
M169F86-E<B!L82!C;VQO;FYE`%-U<'!R:6UE<B!U;B!A=71R92!M;V3H;&4@
M97AI<W1A;G0`4W5P<')I;65R(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@
MNP#*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER(&5F9F%C97(@JZ`E<Z"[
M(&5T('-E<R!S;W5S+7!E<FUI<W-I;VYSH#\`169F86-E<B!L82!R86YGZ64`
M4W5P<')I;65R(&PG:61E;G1I=.D@<^EL96-T:6]N;NEE`$5F9F%C97(@;&$@
M8V]L;VYN92!A8W1U96QL90!%9F9A8V5R(&QA(')A;F?I92!A8W1U96QL90!3
M8W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E(.`@:F]U<B!S=7!P<FEM
MZ2"KH"5SH+LN`$AE=7)E(&1E(&QI=G)A:7-O;@!$86YE;6%R:P!$Z6-R;VES
M<V%N=`!$Z6-R:7)E(&QE('!R;V)LZ&UE`$1E<V-R:7!T:6]N`$1E<V-R:7!T
M:6]NH#H`1.ET86EL<R`H875S<VD@9&%N<R!L92!F:6-H:65R(&1E('1R86-E
M<R!D92!(;W)D92F@.@!,97,@9.ET86EL<R!O;G0@Z73I(&-O;G-I9V[I<R!P
M;W5R(&PG861M:6YI<W1R871E=7(N`$3I=F5L;W!P96UE;G0`4&]I;G0@9&4@
M<F]SZ64`4&]I;G0@9&4@<F]SZ64@<&]U<B!L82!D97)N:>AR92!H975R9:`Z
M(`!0;VEN="!D92!R;W/I9:`Z(`!$92!G875C:&4@X"!D<F]I=&4`1&4@9')O
M:71E(.`@9V%U8VAE`%+I<&5R=&]I<F4`069F:6-H97(@<W5R(#(T(&AE=7)E
M<Z`_`$]P=&EO;G,@9"=A9F9I8VAA9V4`069F:6-H97(@;&$@<'+I=FES:6]N
M(&3I=&%I;&SI90!!9F9I8VAE<B!L82!P<NEV:7-I;VX@*%1!1BD`1F]R;6%T
M(&0G869F:6-H86=E`$%V:7,@9&4@;&EV<F%I<V]N`$1J:6)O=71I`$YE('!A
M<R!S=7!P<FEM97(`3F4@<&%S(&%C8^ED97(@9&ER96-T96UE;G0@X"!M86EN
M=&5N86YC92YP:'``3&4@<')E;6EE<B!E;G)E9VES=')E;65N="!C;VYT:65N
M="UI;"!L92!N;VT@9&5S(&-H86UP<Z`_($1A;G,@;"=A9F9I<FUA=&EV92P@
M8V]C:&5Z(&-E='1E(&)O[G1EH#H`1&]M:6YI<75E`%+I<'5B;&EQ=64@9&]M
M:6YI8V%I;F4`5F]U<R!N)V%V97H@<&%S(&1E(&-O;7!T9:`_($5N<F5G:7-T
M<F5Z+79O=7,N`%3I;.EC:&%R9V5R`%3I;.EC:&%R9V5R("5S`%3I;.EC:&%R
M9V5R(&QA(&-O;F9I9W5R871I;VX@9^ENZ7+I92!C;VUM92!U;B!S8W)I<'0@
M4$A0`$QI<W1E(&3I<F]U;&%N=&4`1')O9W5E<P!#;W5R<FEE<B#I;&5C=')O
M;FEQ=64`4&EL;W1E(&1E('!A<W-E<F5L;&4@8V]U<G)I97(@+R!335,L('!O
M=7(@;&5S(&9O=7)N:7-S975R<R!D92!C92!S97)V:6-E+@!%4E(`R7%U871E
M=7(`36]D:69I97(`R61I=&5R(&QE(&)L;V,`R61I=&5R('5N(&=R;W5P90!-
M;V1I9FEE<B!L82!N;W1E`,ED:71E<B!U;F4@<&5R;6ES<VEO;@#)9&ET97(@
M;&5S('!E<FUI<W-I;VYS`,ED:71E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"K
MH"5SH+L`R61I=&5R(&QE<R!O<'1I;VYS('!O=7*@.@#)9&ET97(@;&5S('!E
M<FUI<W-I;VYS('!O=7(@JZ`E<Z"[`,ED:71E<B!L97,@<&5R;6ES<VEO;G,@
M<&]U<B`E<P#)9'5C871I;VX`R6=Y<'1E`%-A;'9A9&]R`,ELZ6UE;G0N+BX`
M16T`061R97-S92#I;&5C=')O;FEQ=64`061R97-S92#I;&5C=')O;FEQ=64`
M3&5S(&%D<F5S<V5S(.EL96-T<F]N:7%U97,@9&]I=F5N="!C;W)R97-P;VYD
M<F4N`$-O=7)R:65R(&%V96,@8V]N9FER;6%T:6]N`%!A<W-E<F5L;&4@8V]U
M<G)I97(@+R!335,`R6UO=&EC]&YE<P!6:61E<B!L82!N;W1E`$UE<W-A9V4@
M=FED92X`4NES=6QT870@=FED92X`5&5R;65S(&1E(')E8VAE<F-H92!V:61E
M`$%C=&EV97(@;"=I;G-E<G1I;VX@9"=I;6%G97,@=F5N86YT(&1E<R!A;&)U
M;7,@<&AO=&]S(&1A;G,@;&4@=&5X=&6@/P!!8W1I=F5R(&QE(&UE;G4@8V]N
M=&5X='5E;"!A=F5C('5N(&-L:6,@9')O:72@/P!&:6X@9&4@;"=A;F[I90!!
M9W)A;F1I<B!L)^ED:71E=7(`R6-R:79E>B!U;F4@<75E<W1I;VX@9&4@<^EC
M=7)I=.D@<74G;VX@=F]U<R!P;W-E<F$@<VD@=F]U<R!D979E>B!R96UE='1R
M92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E+"!P87(@97AE;7!L92"K(%%U
M96P@97-T(&QE(&YO;2!D92!V;W1R92!A;FEM86P@<'+I9NERZ:`_H+N@.@!)
M;G-C<FEV97H@;"=A9')E<W-E(%523"!D92!L)VEM86=E(&EC:0!%;G1R97H@
M;&5S(&QE='1R97,@8VDM9&5S<V]U<Z`Z`$=U:6[I92#I<75A=&]R:6%L90#)
M<GET:'+I90!%<G)E=7(`17)R975R(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@
M8FQO8Z`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E(&PG
M86YC<F4@9&4@<WEN8VAR;VYI<V%T:6]NH#H@)7,`17)R975R(&QO<G,@9&4@
M;&$@<W5P<')E<W-I;VX@9'4@:F]U<FYA;"!D92!S>6YC:')O;FES871I;VZ@
M.B`E<P!%<G)E=7(@;&]R<R!D92!L82!RZ6-U<.ER871I;VX@9'4@8V]N=&5N
M=:`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1U(&UO="!D
M92!P87-S9:`Z("5S`$5R<F5U<B!A=F5C(&QE(&UE<W-A9V4N`$5R<F5U<B!L
M;W)S(&1E(&PG96YR96=I<W1R96UE;G0@9&4@JZ`E<Z"[+@!%<W1O;FEE`,ET
M:&EO<&EE`$5T:&YI<75E`$5U<F]P90!4;W5S(&QE<R`F9G)A8S$T.R!D)VAE
M=7)E`%1O=71E<R!L97,@,B!M:6YU=&5S`%1O=71E<R!L97,@,S`@<V5C;VYD
M97,`5&]U=&5S(&QE<R`U(&UI;G5T97,`P"!C:&%Q=64@8V]N;F5X:6]N`%1O
M=71E<R!L97,@)F9R86,Q,CL@:&5U<F5S`%1O=71E<R!L97,@;6EN=71E<P!%
M>&5M<&QE(&1E('9A;&5U<G.@.@!%>.EC=71E<@!$Z79E;&]P<&5R`$3I<&QI
M97(@;&$@8F%R<F4@9&4@8_1TZ0"K("D@NR!A='1E;F1U90!5;B!S975L(&UO
M="!O=2!E>'!R97-S:6]N(&5N=')E(&=U:6QL96UE=',@871T96YD=7,`1&%T
M92!D)V5X<&ER871I;VX`4F5P<NES96YT86YT`$5X<&]R=&5R`$5X<&]R=&5R
M(&1E<R!N;W1E<P!#;W5L975R(&0G879A;G0M<&QA;@!4Z6SI8VAA<F=E;65N
M="!V97)S(&QE('-E<G9E=7(@9&4@;&$@8V]N9FEG=7)A=&EO;B!P87(@1E10
M`%1E>'1E(&EN=.E?9W)A;`!,96-T=7)E(&1E<R!P<NEFZ7)E;F-E<R!I;7!O
M<W-I8FQE+@#)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!,1$%0
M+@#)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!334(N`,EC:&5C
M(&1E(&QA(&-O<&EE(&1E<'5I<R"KH"5SH+LN`,EC:&5C(&1E(&QA(&-O<&EE
M('9E<G,@(*N@)7.@NRX`26UP;W-S:6)L92!D92!C<NEE<B!U;F4@;F]U=F5L
M;&4@8V]N;F5X:6]N(%-!4TP`R6-H96,@9'4@9.EP;&%C96UE;G0@=F5R<R"K
MH"5SH+LN`,EC:&5C(&QO<G,@9&4@;&$@<NEC=7#I<F%T:6]NH#H@)7,`0F5A
M=0#.;&5S($9A;&ML86YD("A-86QO=6EN97,I`,YL97,@1NER;^D`17)R975R
M(&9A=&%L9:`Z`$9A>`!4Z6SI8V]P:65S`$;I=G)I97(`5&5M<.ER871U<F4@
M<F5S<V5N=&EE`%1E;7#I<F%T=7)E(')E<W-E;G1I9:`Z(`!1=65L<75E<R!A
M=F5R<V5S`%%U96QQ=65S(&-H=71E<R!D92!N96EG90!-871R:6-E(&1E<R!C
M:&%M<',`1FEG;&5T($-!4%1#2$$`4&]L:6-E(&1E(&QA(#Q)/F9I9VQE=#PO
M23X`1FED:FD`1FEC:&EE<@!.;VUB<F4@9&4@9FEC:&EE<G.@.B`E<P!.;VUB
M<F4@9&4@9FEC:&EE<G.@.B`E<P!'97-T:6]N;F%I<F4@9&4@9FEC:&EE<G,`
M3F]M(&1U(&9I8VAI97(`0VAO:7@@9&4@9FEC:&EE<@!4Z6SI8VAA<F=E;65N
M="!D92!F:6-H:65R`$PG96YV;VD@9&4@9FEC:&EE<G,@;B=E<W0@<&%S('!R
M:7,@96X@8V]M<'1E+@!&:6QT<F5S`$9I;FQA;F1E`%!R96UIZ')E(&1E;6EE
M`%!R96UI97(@<75A<G1I97(`1FEX97(@;&4@<F%T:6\`4F5T;W5R;F5R`$9L
M;W1T86YT`$)R;W5I;&QA<F0`1&]S<VEE<B`E<R!I;F5X:7-T86YT+@!#;W5L
M975R(&1E('!O;&EC90!.;W5R<FET=7)E`%!O=7(@;&5S(&YA=FEG871E=7)S
M(&YE('-U<'!O<G1A;G0@<&%S(&QE<R!I;6%G97,`4'+I=FES:6]N("A4048I
M`$IO=7)S(&1E('!RZ79I<VEO;B`H;F]T97H@<75E(&QE<R!P<NEV:7-I;VYS
M(&9O=7)N:65S(&1O;FYE;G0@;&4@:F]U<B!E="!L82!N=6ETH#L@=6X@9W)A
M;F0@;F]M8G)E(&EC:2!P975T(&9A:7)E('5N(&)L;V,@='+H<R!L87)G90!6
M;W5S(&%V97H@;W5B;&GI('9O=')E(&UO="!D92!P87-S9:`_`$9O<FUU;&%I
M<F5S`$-I=&%T:6]N`%1Y<&4@9&4@8VET871I;VX`0VET871I;VYS`$-I=&%T
M:6]N<R`R`$9O<G5M<P!2961I<F5C=&EO;@!690!#861R97,`1G)A;F-E`$9R
M86YC92!MZ71R;W!O;&ET86EN90!'=7EA;F4@9G)A;N=A:7-E`%!O;'ENZ7-I
M92!F<F%NYV%I<V4`5&5R<F5S(&%U<W1R86QE<R!E="!A;G1A<F-T:7%U97,@
M9G)A;N=A:7-E<P!$90!$=2``1&5S8W)I<'1I;VX@8V]M<&SH=&4`4&QE:6YE
M(&QU;F4`3F]M(&-O;7!L970`1V%B;VX`06QB=6T@9"=O<FEG:6YE(&1E(&PG
M:6UA9V4`06QB=6V@.@!'86UB:64`1^ENZ7)E<B!L82!C;VYF:6=U<F%T:6]N
M(&1E("5S`$-O9&4@9^ENZ7+I`$?I;W)G:64`06QL96UA9VYE`$=H86YA`$=I
M8G)A;'1A<@!0<NEN;VT`06QL97(`1V]E9&5L`$-A<G1E<R!';V]G;&4`4F5C
M:&5R8VAE($=O;V=L90!.:79E874@9&4@9W)I<P!'<NAC90!'<F5C("A)4T\M
M.#@U.2TW*0!'<F_K;FQA;F0`1W)E;F%D90!!9&UI;FES=')A=&EO;B!D97,@
M9W)O=7!E<P!,97,@;F]M<R!D92!G<F]U<&4@;F4@<&5U=F5N="!P87,@ZG1R
M92!V:61E<P!'<F]U<%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@;&4@
M9W)O=7!E("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U('-E<G9E=7*@.@!'
M<F]U<%]L9&%PH#H@<W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!G<F]U<&4@
M)7,`1W)O=7!?;&1A<*`Z(&UO9&EF:6-A=&EO;B!I;7!O<W-I8FQE(&1U(&=R
M;W5P92`E<P!'<F]U<&5S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E
M<FYE<V5Y`%!E<FUI<W-I;VYS(&1E<R!I;G9I=.ES`$QI=G)E(&0G;W(`1W5I
M;NEE`$=U:6[I92U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@<F5F=7-E
M(&+J=&5M96YT(&1E('-U<'!R:6UE<B!L82!D97)N:>AR92!C96QL=6QE(&1E
M(&QA(')A;F?I90!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I
M;65R(&QA(&1E<FYIZ')E(&-O;&]N;F4@9'4@=&%B;&5A=0!(5$U,07)E82!R
M969U<V4@8NIT96UE;G0@9&4@<W5P<')I;65R(&QA(&1E<FYIZ')E(')A;F?I
M92!D=2!T86)L96%U`$%U=&AE;G1I9FEC871I;VX@2%144"!N;VX@=')O=7;I
M92X`2&'O=&D`06QG;W)I=&AM92!D92!H86-H86=E`$)R=6UE('/H8VAE`$5N
M+73J=&4`16XM=.IT97,`SFQE<R!(96%R9"!E="!-8T1O;F%L9`!/<F%G97,@
M=FEO;&5N=',`2.EB<F5U("A)4T\M.#@U.2TX+4DI`$AA=71E=7(`06ED90!!
M:61E('!O=7(@;"?I9&ET975R`$%I9&4`2.EM:7-P:.AR90!6;VEC:2!L92!D
MZ6)U="!D=2!F:6-H:65RH#H`2&%U=&4`05]C8W5E:6P`0VETZ2!D=2!6871I
M8V%N`$%C8W5E:6P`061R97-S92!P97)S;VYN96QL90!2Z7!E<G1O:7)E('!E
M<G-O;FYE;`!4Z6SI<&AO;F4@<&5R<V]N;F5L`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92]+;VQA8J`Z(&1O;F[I97,@6$U,("5S(&EN=F%L:61E
M<R!R971R;W5VZ65S(&1A;G,@;&4@;65S<V%G92`E<P!(;W)D92]+;VQA8J`Z
M(&%U8W5N(&UE<W-A9V4@;F4@8V]R<F5S<&]N9"!A=2!S=6IE="`E<P!(;W)D
M92]+;VQA8J`Z('!A<R!D)V]B:F5T(&1E('1Y<&4@)7,@=')O=7;I(&1A;G,@
M;&4@;65S<V%G92`E<P!(;W)D92]+;VQA8J`Z("5S('-U<'!R:6WI(*N@)7.@
MNR!A=F5C('-U8V/H<P!(;W)D92]+;VQA8J`Z(&QE(&UO=&5U<B!D)VEN=.EG
M<F%T:6]N(&[I8V5S<VET92!L)V5X=&5N<VEO;B`G9&]M>&UL)R!D92!02%``
M2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E(&-RZ65R('5N(&YO=79E;"!A
M<F)R92!834P@<&]U<B!L)V]B:F5T("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S
M:6)L92!D)V5N;&5V97(@)7,@JZ`E<Z"[H#H@)7,`2&]R9&4O2V]L86*@.B!I
M;7!O<W-I8FQE(&1E('+I8W5PZ7)E<B!L)VED96YT:69I86YT($U)344@<&]U
M<B!L82!P87)T:64@9&4@='EP92`E<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB
M;&4@9&4@<WEN8VAR;VYI<V5R("5S(*N@)7.@NZ`Z("5S`$AO<F1E+TMO;&%B
MH#H@:6UP;W-S:6)L92!D92!S>6YC:')O;FES97(@;&5S('!A<G1A9V5SH#H@
M)7,`2&]R9&4O2V]L86*@.B!P87)T86=E(&EN8V]N;G4@JZ`E<Z"[`$QI9VYE
M(&AO<FEZ;VYT86QE`%)E;7!L:7-S86=E(&AO<FEZ;VYT86P`2&]R:7IO;G1A
M;*`Z`$-O;6UE;G0@ZG1E<RUV;W5S(&%R<FEVZ2!I8VF@/R`H4U90(')A<'!O
M<G1E>BUL9:`A*0!#;VUB:65N(&1E(&-O;&]N;F5S('9O=6QE>BUV;W5S(&9U
M<VEO;FYE<J`_`$-O;6)I96X@9&4@8VAA;7!S("AC;VQO;FYE<RD@>2!A+70M
M:6R@/P!#;VUB:65N(&1E(')A;F?I97,@=F]U;&5Z+79O=7,@9G5S:6]N;F5R
MH#\`2'5M:61I=.D`2'5M:61I=.F@.B``2'5M;W)I<W1E<P!(;VYG<FEE`,EC
M:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S
M`,EC:&5C(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;&$@8F_N=&4@24U!
M4*`Z("5S`,EC:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@<75O=&$@<W5R
M(&QA(&)O[G1E($E-05"@.B`E<P!!9')E<W-E($E0`$%D<F5S<V4@25`@;F]N
M(&1I<W!O;FEB;&4N`$%D<F5S<V4@25`@:&]R<R!D=2!B;&]C($-)1%(@86QL
M;W7I+@!6:6]L871I;VX@9&4@8FQO8V%G92!)4"X`25]N<^ER97(@<F%N9^EE
M(&%V86YT`$ES;&%N9&4`26/T;F5S('-E=6QE;65N=`!)8_1N97,@<&]U<B`E
M<P!)8_1N97,@<&QU<R!T97AT90!.;VT@9'4@8V]M<'1EH#H`4VD@;"=A9F9I
M8VAA9V4@;B=E<W0@<&%S(&-O<G)E8W0L("5S('!O=7(@;"=O=79R:7(@9&%N
M<R!U;F4@;F]U=F5L;&4@9F5NZG1R92X`4VD@=F]U<R!N92!V;WEE>B!A=6-U
M;B!I8_1N92!E;B!U=&EL:7-A;G0@26YT97)N970@17AP;&]R97(L('9O=7,@
M<&]U=F5Z(&%V;VER(.`@8V]C:&5R(&-E='1E(&-A<V4@<&]U<B!DZ7-A8W1I
M=F5R(&QA('1R86YS<&%R96YC92!D97,@4$Y'+@!3:2!V;W5S('9O>65Z(&-E
M(&UE<W-A9V4@;6%I<R!A=6-U;F4@:6UA9V4L(&PG:6UA9V4@<75E('9O=7,@
M=F]U;&5Z(&5N=F]Y97(@;F4@<&5U="#J=')E(&%F9FEC:.EE('!A<B!V;W1R
M92!N879I9V%T975R+@!!<&5RYW4@9&4@;"=I;6%G9:`Z`$%D<F5S<V4@55),
M(&1E(&PG:6UA9V4`061R97-S92!54DP@9&4@;"=I;6%G9:`Z`$EM86=E(&1E
M(&PG86QB=6T`26UA9V4@9&4@;"=A;&)U;:`Z`%3I;.EC:&%R9V5M96YT(&0G
M:6UA9V5S`$EM86=E<P!);7!O<G1A=&EO;B!D97,@;F]T97,L(.ET87!E("5D
M`$EM<&]R=&%T:6]N+"#I=&%P92`E9`!);7!O<G1E<B]%>'!O<G1E<B!D97,@
M;F]T97,`0VAA;7`@:6UP;W)TZ:`Z("5S`$-H86UP<R!I;7!O<G3I<Z`Z`$EN
M7W/I<F5R(')A;F?I92!A<'+H<P!#;V1E(&0G86-T:6]N(&EN8V]R<F5C="X`
M3F]M(&0G=71I;&ES871E=7(@970O;W4@=F]T<F4@;6]T(&1E('!A<W-E(&EN
M8V]R<F5C="X`3F]M(&0G=71I;&ES871E=7(@;W4@861R97-S92!A;'1E<FYA
M=&EV92!I;F-O<G)E8W0N("!2Z65S<V%Y97H@;W4@8V]N=&%C=&5Z('9O=')E
M(&%D;6EN:7-T<F%T975R('-Y<W3H;64@<&]U<B!D92!L)V%I9&4N`$%U9VUE
M;G1E<B!L)VEN9&5N=&%T:6]N`$EN9&4`571I;&ES871E=7)S(&EN9&EV:61U
M96QS`$EN9&]NZ7-I90!);F9O`$EN9F]R;6%T:6]N<P!,)VEN9F]R;6%T:6]N
M(&XG97-T('!L=7,@9&ES<&]N:6)L92X`26YSZ7)E<B!C7V]L;VYN92!A<'+H
M<P!);G/I<F5R(&EM86=E`$EN<^ER97(@=6X@=&%B;&5A=0!);G/I<F5R('5N
M(&QI96X@=V5B`$EN<^ER97(@7V-O;&]N;F4@879A;G0`26YSZ7)E<B!U;F4@
M;F]U=F5L;&4@8V]L;VYN92!A<'+H<R!L82!C;VQO;FYE(&%C='5E;&QE`$EN
M<^ER97(@=6YE(&YO=79E;&QE(&-O;&]N;F4@879A;G0@;&$@8V]L;VYN92!A
M8W1U96QL90!);G/I<F5R('5N92!N;W5V96QL92!R86YGZ64@87!RZ',@;&$@
M<F%N9^EE(&%C='5E;&QE`$EN<^ER97(@=6YE(&YO=79E;&QE(')A;F?I92!A
M=F%N="!L82!R86YGZ64@86-T=65L;&4`26YSZ7)E<B!U;B!P87)A9W)A<&AE
M(&%P<NAS(&QE(&XF;V5L:6<[=60@86-T=65L`$EN<^ER97(@=6X@<&%R86=R
M87!H92!A=F%N="!L92!N)F]E;&EG.W5D(&%C='5E;`!);G/I<F5R('5N(&%U
M=')E(&UO9.AL90!);G-C<FEV97H@=6YE(&%D<F5S<V4@9&4@8V]U<G)I97(@
MX"!L87%U96QL92!V;W5S(')E8V5V<F5Z(&QE(&YO=79E874@;6]T(&1E('!A
M<W-EH#H`26YSZ7)E<B!C96QL=6QE(&%P<NAS`$EN<^ER97(@8V5L;'5L92!A
M=F%N=`!);G/I<F5R(&-O;&]N;F4@87!RZ',`26YSZ7)E<B!C;VQO;FYE(&%V
M86YT`$EN<^ER97(@;&5S(&UE<W-A9V5S`$EN<^ER97(@<&%R86=R87!H92!A
M<'+H<P!);G/I<F5R('!A<F%G<F%P:&4@879A;G0`26YSZ7)E<B!R86YGZ64@
M87!RZ',`26YSZ7)E<B!R86YGZ64@879A;G0`26YS8W)I=F5Z(&QA('+I<&]N
M<V4@X"!L82!Q=65S=&EO;B!D92!SZ6-U<FETZ:`Z`$EN<^ER97(O36]D:69I
M97(@=6YE(&EM86=E`$EN<^ER97(O36]D:69I97(@=6X@;&EE;B!W96(`0W+I
M9&ET(&EN<W5F9FES86YT('!O=7(@96YV;WEE<B#@(&QA(&QI<W1E(&1E(&1I
M<W1R:6)U=&EO;BX`0W+I9&ET(&EN<W5F9FES86YT+@!%;G1I97(`3&ES=&4@
M8V]M<&SH=&4`541(("A5<V5R($1A=&$@2&5A9&5R*2!I;G9A;&ED90!$;VYN
MZ64@6DE0(&EN=F%L:61E+@!!<'!L:6-A=&EO;B!I;G9A;&ED92X`1W)O=7!E
M($E$(&EN=F%L:61E+@!%;G9O:2!D92!D;VYNZ65S(&EN=F%L:61E<RX`061R
M97-S92!D92!D97-T:6YA=&EO;B!I;G9A;&ED92X`1F]R;6%T(&1E(&9I8VAI
M97(@:6YV86QI9&4N`$-L968@9&4@;&EC96YC92!I;G9A;&ED92X`16UP;&%C
M96UE;G0@:6YD:7%UZ2!I;G9A;&ED92X`JVUS9U]T>7!ENR!I;G9A;&ED92X`
MJV%P:5]I9+L@:6YV86QI9&4@;W4@;6%N<75A;G0N`%!A<F%MZ'1R97,@:6YV
M86QI9&5S(&]U(&UA;G%U86YT<RX`4&5R;6ES<VEO;B!I;G9A;&ED92X`260N
M(&1E('!A<G1E;F%I<F4@:6YV86QI9&4N`$-O9&4@9&4@<')O9'5I="!I;G9A
M;&ED92X`4')O=&]C;VQE(&EN=F%L:61E+@!$97-T:6YA=&%I<F4@:6YV86QI
M9&6@.B"KH"5SH+L`3V)J970@9&4@<&%R=&%G92!I;G9A;&ED90!!9')E<W-E
M('-O=7)C92!I;G9A;&ED92X`1&]N;NEE(%5N:6-O9&4@:6YV86QI9&4N`$EN
M=F5N=&%I<F4`26YV97)S97(@;&$@<^EL96-T:6]N`$ER86X`27)A:P!)<FQA
M;F1E`,YL92!D92!-86X`5&5M<.IT97,@:7-O;.EE<P!)<W)AZVP`R6UE='1E
M=7(`271A;&EQ=64`271A;&EE`$IA;6'O<75E`$IA;G9I97(`2F%P;VX`2F%P
M;VYA:7,@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:64`2G5I;&QE=`!*
M=6EN`$IU<W1I9FEE<@!#96YT<F5R`$IU<W1I9FEE<@!!;&EG;F5R(.`@9V%U
M8VAE`$%L:6=N97(@X"!D<F]I=&4`2V%Z86MH<W1A;@!'87)D97(@;"=O<FEG
M:6YA;*`_`$ME;GEA`$QE('-E<G9E=7(@2V5R8F5R;W,@82!R96IE=.D@;"=A
M=71H96YT:69I8V%T:6]N+@!$Z6)U=&%N=',@9'4@;F]Y874`0W+I871I;VX@
M9&4@8VQE9@!%;7!R96EN=&4@9&4@;&$@8VQE9@!,;VYG=65U<B!D92!L82!C
M;&5F`%1Y<&4@9&4@8VQE9@!5=&EL:7-A=&EO;B!D92!L82!C;&5F`$QA(&-L
M968@<V4@=')O=79E(&3I:N`@<W5R(&QE('-E<G9E=7(@9&4@8VQE9G,@<'5B
M;&EC+@!%;F9A;G1S`$MI<FEB871I`$-O<NEE(&1U($YO<F0`0V]RZ64@9'4@
M4W5D`$-O<NEE;B`H155#+4M2*0!+;W=E[W0`2VER9VAI>FES=&%N`%!RZ5]S
M96YT871I;VX`3&%N9W5E`$QA;W,`1&5R;FGH<F4@9&5M:64`1&5R;FGH<F4@
M;6]D:69I8V%T:6]N`$1E<FYIZ')E(&UO9&EF:6-A=&EO;B!D=2!M;W0@9&4@
M<&%S<V4`1&5R;FEE<B!Q=6%R=&EE<@!$97)N:>AR92!M:7-E(.`@:F]U<J`Z
M`$1E<FYIZ')E(&-O;FYE>&EO;J`Z("5S`$1E<FYIZ')E(&-O;FYE>&EO;J`Z
M("5S(.`@<&%R=&ER(&1E("5S`$1E<FYIZ')E(&-O;FYE>&EO;J`Z(&IA;6%I
M<P!,971T;VYI90!,;VD`4'+I<V5N=&%T:6]N`$QA:7-S97(@=FED92!P;W5R
M(&YE('!A<R!A=F]I<B!D92!B;W)D=7)E`$QI8F%N`$=A=6-H90!%;G3J=&4@
M9V%U8VAE`%9A;&5U<G,@9&4@9V%U8VAE`$QE<V]T:&\`3FEV96%U`$QI8NER
M:6$`3&EB>64`3&EE8VAT96YS=&5I;@!"<G5I;F4@;.EGZ')E`%!L=6EE(&SI
M9^AR90!0;'5I92!LZ6?H<F4@=/1T(&1A;G,@;&$@:F]U<F[I90!0;'5I92!L
MZ6?H<F4@=&%R9`!!=F5R<V5S(&SI9^AR97,`4&QU:64@;.EGZ')E(&%V96,@
M=&]N;F5R<F4`3F5I9V4@:6YT97)M:71T96YT90!!=F5R<V4@9&4@;F5I9V4@
M;.EGZ')E`%)I;65S`$QI96X`3&4@;&EE;B!P;VEN=&4@=F5R<Z`Z`$QI92!L
M)V%D<F5S<V4@9&4@8V]U<G)I96P@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N
M(&1U(&UE<W-A9V4@96X@;"=A9F9I8VAA;G0`3&EE;G,`0FES8W5I="!,:6YU
M>`!,:7-T92`M('5T:6QI<V%T975R('!E=70@=F]I<B!L92!D;W-S:65R`$QI
M<W1E(&1E<R!B87-E<R!D92!D;VYNZ65S`$EN9&5X(&1E(&PG86ED90!!9F9I
M8VAE<B!L97,@=&%B;&5S`$%R8VAI=F5S(&1E(&QA(&QI<W1E`$%I9&4@9&4@
M;&$@;&ES=&4`260N(&1E(&QA(&QI<W1E`%!R;W!R:>ET86ER92!D92!L82!L
M:7-T90!%;G9O:2#@(&QA(&QI<W1E`$%B;VYN96UE;G0@X"!L82!L:7-T90!$
MZ7-A8F]N;F5M96YT(&1E(&QA(&QI<W1E`,EC:&5C(&1E(&QA(&QI<W1E(&1E
M<R!S97-S:6]N<Z`Z("5S`,EC:&5C(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A
M=&5U<G.@.B`E<P!,)V%F9FEC:&%G92!D92!L82!L:7-T92!D97,@=71I;&ES
M871E=7)S(&5S="!DZ7-A8W1I=NDN`$QI='3I<F%T=7)E`$QI='5A;FEE`$-H
M87)G96UE;G0N+BX`2&5U<F4@;&]C86QEH#H@`$AE=7)E(&5T(&QO8V%L90!,
M:65U`$-O;FYE>&EO;@!4<F%C92!D92!L82!D97)N:>AR92!S97-S:6]N(&1E
M('-Y;F-H<F]N:7-A=&EO;@!$Z6-O;FYE>&EO;@!#;VYN97AI;VX`5.)C:&5S
M(&1E(&-O;FYE>&EO;@!,82!C;VYN97AI;VX@97-T(')E9G5SZ64N($EL(&5S
M="!P<F]B86)L92!Q=64@=F]T<F4@;F]M(&0G=71I;&ES871E=7(@;W4@=F]T
M<F4@;6]T(&1E('!A<W-E(&$@Z73I(&UA;"!S86ES:0#)8VAE8R!D92!C;VYN
M97AI;VXN`%1E>'1E(&QO;F<`06UO=7(`1F%I8FQE`$QE='1R92!G<F5C<75E
M<R!M:6YU<V-U;&5S`$QE='1R92!L871I;F5S(&UI;G5S8W5L97,`3F]M8G)E
M(')O;6%I;G,@;6EN=7-C=6QE<P!,=7AE;6)O=7)G`$U-`$UE<W-A9V4@9'4@
M:F]U<B`H34]41"D`3&$@<&GH8V4@:F]I;G1E($U3+51.148@;F4@8V]N=&5N
M86ET(&%U8W5N92!D;VYNZ64N`$U31P!-86-A;P!2Z7!U8FQI<75E(&1E($UA
M8^ED;VEN90!-861A9V%S8V%R`$UA9VEE`$-O=7)R:65R`$%D;6EN:7-T<F%T
M:6]N(&1U(&-O=7)R:65L`$9A:7)E('5N(&QI95]N`$UA;&%W:0!-86QA:7-I
M90!-86QD:79E<P!-86QI`$UA;'1E`$%D;6EN:7-T<F5Z(&QA(&QI<W1E(&1E
M(&-A=.EG;W)I97,@970@;&5S(&-O=6QE=7)S(&QIZ65S(.`@8V5S(&-A=.EG
M;W)I97,N`$-A<G1E(*L@36%P,C0@NP!#87)T92"K($UA<'%U97-T(+L`0V]R
M<F5S<&]N9&%N8V5S(&5N<F5G:7-T<NEE<RX`36%R<P!-87)G90!-87)Q=65R
M(&%V96,@9&5S(.ET:7%U971T97,@5G4O3F]N('9U`$UA<G%U97(@879E8R!D
M)V%U=')E<R#I=&EQ=65T=&5S("AE>"XZ($EM<&]R=&%N="]2Z7!O;F1U*0#.
M;&5S($UA<G-H86QL`$UA<G1I;FEQ=64`0VAA;7!S(&%P<&%R96YTZ7,`36%U
M<FET86YI90#.;&4@36%U<FEC90!#<NED:70@;6%X:6UU;2!A;&QO=>DN`$QI
M;6ET92!D=2!M97-S86=E(&3I<&%S<^EE+@!496UPZ7)A='5R92!M87AI;6%L
M92!D97,@,C0@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!496UPZ7)A='5R92!M87AI
M;6%L92!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@`$YO;6)R92!M87AI;75M
M(&1E(&)L;V-S(&1U('!O<G1A:6P`3&]N9W5E=7(@;6%X:6UU;0!-86D`36%Y
M;W1T90!-Z61I8V%M96YT`$UE;6)R97,`5&5X=&4@9&4@;&$@;F]T90!4>7!E
M(&1E(&UE;G6@.@!&=7-I;VYN97(@;&5S(&-E;&QU;&5S`$UE<W-A9V4`5NER
M:69I8V%T:6]N(&1U(&UE<W-A9V4@<NEU<W-I92P@;6%I<R!L92!C97)T:69I
M8V%T(&1U('-I9VYA=&%I<F4@;B=A('!A<R!P=2#J=')E(';I<FEF:>DN`$UE
M<W-A9V4@97AP:7+I+@!4>7!E(&1E(&UE<W-A9V4`3>ETZ6\@365T87(`3&4@
M8FQO8R"K($UE=&%R(+L@;B=E<W0@<&%S(&1I<W!O;FEB;&4N`$QE(&)L;V,@
MJR!-971A<B"[(&XG97-T('!A<R!D:7-P;VYI8FQE+B`@3&5S(&3I=&%I;',@
M;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L)V%D;6EN:7-T<F%T975R+@!-971A
M<D1"(&XG97-T('!A<R!C;VYN96-TZ2X`3>ET:&]D90!,82!MZ71H;V1E(*N@
M)7.@NR!N)V5S="!P87,@9.EF:6YI90!-Z71H;V1E(&YO;B!DZ69I;FEE+B!-
MZ71H;V1E(&%P<&5LZ66@.B`E<P!-Z71R:7%U90!-97AI<75E`,ET871S(&;I
M9.ERZ7,@9&4@36EC<F]NZ7-I90!-:6QI974`5'EP92!-24U%`%1E;7#I<F%T
M=7)E(&UI;FEM=6T@9&5S(#(T(&1E<FYIZ')E<R!H975R97.@.B``5&5M<.ER
M871U<F4@;6EN:6UU;2!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@`$QA(&1U
M<NEE(&UI;FEM86QE(&1U(&UO="!D92!P87-S92!N)V$@<&%S(&5N8V]R92!E
M>'!I<ND`36ER;VER`%9A<FGI<P!,92!P87%U971A9V4@2%144%]R97%U97-T
M(%!%05(@97-T(&UA;G%U86YT+@!#;VYF:6=U<F%T:6]N(&EN97AI<W1A;G1E
M+B!6;W5S(&1E=F5Z(&QA(&?I;NER97(@;6%I;G1E;F%N="!S:2!V;W5S('9O
M=6QE>B!U=&EL:7-E<B!C971T92!A<'!L:6-A=&EO;BX`240@9'4@;65S<V%G
M92!M86YQ=6%N="X`3&4@<&%Q=65T86=E(%!%05(@36%I;"!E<W0@;6%N<75A
M;G0N`$E$(&1E('-E<W-I;VX@;6%N<75A;G0N`$QU`$-O=7)R:65L('-A;G,@
M9FEL`$UO9.ERZ0!$871E(&1E(&UO9&EF:6-A=&EO;@!-;V1I9FEE<B!L)U52
M3`!-;V1I9FEC871I;VX@9&4@)7,`36]D=6QO`$UO;&1A=FEE`$UO;F%C;P!-
M;VYG;VQI90!-;VES(&5T(&%N;NEE`$UE;G-U96QL96UE;G0`36]N='-E<G)A
M=`!0:&%S97,@9&4@;&$@;'5N90!#:&%M<',@<W5P<&SI;65N=&%I<F5S('1R
M;W5VZ7,@X"!L82!L:6=N92`E9"`H871T96YD=7,@)60I+@!-87)O8P!'Z6[I
M<F%L96UE;G0@96YS;VQE:6QLZ0!'Z6[I<F%L96UE;G0@;G5A9V5U>`!'Z6[I
M<F%L96UE;G0@96YS;VQE:6QLZ0!697)S(&QE(&)A<P!$Z7!L86-E<B#@(&=A
M=6-H90!$Z7!L86-E<B#@(&1R;VET90!697)S(&QE(&AA=70`5F5R<R!L92!B
M87,`5F5R<R!L92!H875T`$UO>F%M8FEQ=64`3&ES=&5S(&3I<F]U;&%N=&5S
M(&UU;'1I+6YI=F5A=7@`0V%R=&4@JZ!-=6QT:6UA<"!52Z"[`%/I;&5C=&EO
M;B!M=6QT:7!L90!087)A;>ET<F%G92!D=2!C;VUP=&4`365S(&1O;F[I97,@
M<&5R<V]N;F5L;&5S`$UE<R!N;W1E<P!-;VX@<&]R=&%I;`!0<NES96YT871I
M;VX@9&4@;6]N('!O<G1A:6P`0FER;6%N:64`3D].+"!J92!N)V%C8V5P=&4@
M<&%S`$YO;0!.86UI8FEE`$YA=7)U`$[I<&%L`%!A>7,M0F%S`$%N=&EL;&5S
M(&[I97)L86YD86ES97,`55),(&1E(&)A<V4@9&4@3F5T<V-A<&4`55),(&1E
M('+I=F]C871I;VX@9&4@;"=!+D,N($YE='-C87!E`%523"!D92!L82!P;VQI
M=&EQ=64@9"=!+D,N($YE='-C87!E`%523"!D92!R96YO=79E;&QE;65N="!.
M971S8V%P90!54DP@9&4@<NEV;V-A=&EO;B!.971S8V%P90!.;VT@9'4@<V5R
M=F5U<B!34TP@3F5T<V-A<&4`0V]M;65N=&%I<F4@9'4@8V5R=&EF:6-A="!.
M971S8V%P90!4>7!E(&1U(&-E<G1I9FEC870@3F5T<V-A<&4`4NES96%U`$IA
M;6%I<P!.;W5V96QL92U#86SI9&]N:64`3F]U=F5L;&4@8V%TZ6=O<FEE`$YO
M=79E874@;65S<V%G92#@("5S`$YO=79E;&QE(&QU;F4`3F]U=F5L;&4@;F]T
M90!.;W5V96%U(&YO;2!D92!C;VYN97AI;VX@*&9A8W5L=&%T:68I`$YO=79E
M;&QE+5KI;&%N9&4`3F]U=F5A=2!M;W0@9&4@<&%S<V4`3&4@;F]U=F5A=2!M
M;W0@9&4@<&%S<V4@97AP:7)E<F$@;&4@)7@N`$QE<R!N;W5V96%U>"!M;W1S
M(&1E('!A<W-E(&1I9F;H<F5N="X`3F]U=F5L;&4@9F5NZG1R92`H7V)L86YK
M*0!.;W5V96QL97,`1F]R=6US`%-U:79A;G0`-"!P:&%S97,@<W5I=F%N=&5S
M`$]P=&EO;G,@<W5I=F%N=&5S`%-U:79A;G0^`$YI8V%R86=U80!.:6=E<@!.
M:6=E<FEA`$YU:70`3FEU90!.;VX`4&%S(&1E(&1O;F[I97,@9&4@8V]N9FEG
M=7)A=&EO;B!P;W5R(&QE<W%U96QL97,@;6]N=')E<B!L97,@9&EF9NER96YC
M97,N`%!A<R!D92!S=')A=.EG:64@9&ES<&]N:6)L92!P;W5R(&9A:7)E(&1E
M<R!I;6%G97,@25-/+@!087,@9&4@9V%B87)I="!E;B!T<F%I=&5M96YT('!A
M<B!L;W0N`$%U8W5N(&)L;V,@;B=E>&ES=&4@X"!L82!P;W-I=&EO;B!D96UA
M;F3I90!087,@9&4@;F]M(&1E(&-A;&5N9')I97(@9F]U<FYI('!O=7(@;"=A
M=71H96YT:69I8V%T:6]N('!A<B!-0T%,+@!.;VX@;6]D:69IZ2X`075C=6YE
M('-O=7,M<&5R;6ES<VEO;B!N)V$@8F5S;VEN(&0GZG1R92!A:F]U=.EE('-O
M=7,@8V4@;FEV96%U+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A
M=&EO;B!S<.EC:69IZ64@<&]U<B`E<RX`075C=6YE(&EN9F]R;6%T:6]N(&1E
M(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R($944"!61E,N`$%U8W5N92!I
M;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N:64@<&]U<B!344P@
M5D93+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R
M;FEE('!O=7(@4U%,+49I;&4@5D93+@!!=6-U;B!C<NED:70@9&ES<&]N:6)L
M92X`075C=6YE(&1E<W1I;F%T:6]N('1R;W5VZ64N`$%U8W5N(&9I8VAI97(@
M96YV;WGI`$%U8W5N(&EC]&YE('1R;W5VZ2X`075C=6X@;&EE=2!N)V5S="!S
MZ6QE8W1I;VYNZ0!!=6-U;B!E;7!L86-E;65N="!N)V5S="!I;F1I<77I+@!!
M=6-U;B!M97-S86=E(&9O=7)N:0!!=6-U;B!N;VT@<W#I8VEF:>DN`$%U8W5N
M(&)L;V,M;F]T97,@;B=E<W0@9&ES<&]N:6)L92!P;W5R(&QE<R!I;G9I=.ES
M+@!!=6-U;F4@;F]T90!!=6-U;F4@;F]T92!N92!C;W)R97-P;VYD(&%U('!R
MZ7-E;G0@8W)I=.AR92X`075C=6YE(&YO=&4@X"!A9F9I8VAE<@!!=6-U;B!N
M;VUB<F4@<W#I8VEF:>DN`%!A<R!D)V%P:&]R:7-M97,@8VAO<75A;G1S`$%U
M8W5N(&UO="!D92!P87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I
M;VX@<&%R($A45%`N`$%U8W5N(&UO="!D92!P87-S92!F;W5R;FD@<&]U<B!L
M)V%U=&AE;G1I9FEC871I;VX@<&%R($E-05`N`$%U8W5N(&UO="!D92!P87-S
M92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($ME<F)E<F]S
M+@!!=6-U;B!M;W0@9&4@<&%S<V4@<W#I8VEF:>D@<&]U<B!L)V%U=&AE;G1I
M9FEC871I;VXN`$%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P;W5R(&PG
M875T:&5N=&EF:6-A=&EO;B!005-35T0N`$%U8W5N(&UO="!D92!P87-S92!S
M<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!334(N`$%U8W5N(&-H
M96UI;B!V97)S(&QE(&)I;F%I<F4@3W!E;E-33"!F;W5R;FDN($QE(&)I;F%I
M<F4@9"=/<&5N4U-,(&5S="!NZ6-E<W-A:7)E('!O=7(@9F]N8W1I;VYN97(@
M879E8R!D97,@9&]N;NEE<R!02T-3(#$R+@!!=6-U;F4@8V]N9FER;6%T:6]N
M(&5N(&%T=&5N=&4`4&%S(&1E('%U;W1A('!O<VET:6]N;NDN`%!A<R!D92!R
MZ&=L97,`075C=6X@<^EP87)A=&5U<B!S<.EC:69IZ2X`4&%S(&1E(&/T=.ES
M`$9I8VAI97(@:6YE>&ES=&%N=`!!=6-U;B!RZ7!E<G1O:7)E('1E;7!O<F%I
M<F4@97-T(&1I<W!O;FEB;&4@<&]U<B!L82!C86-H90!!=6-U;B!N;VT@9"=U
M=&EL:7-A=&5U<B!E="`O;W4@;6]T(&1E('!A<W-E(&5N=F]YZ2X`075C=6YE
M(&1O;F[I92!834P@=F%L:61E(&XG82#I=.D@<F5T;W5R;NEE`%!A<R!D92!V
M86QE=7(`4&%S(&1E('9E<G-I;VX@=')O=7;I92!D86YS(&QA(&-O;F9I9W5R
M871I;VX@;W)I9VEN86QE+B!2Z6?I;NER97H@;&$@8V]N9FEG=7)A=&EO;BX`
M4&%S(&1E('9E<G-I;VX@=')O=7;I92!D86YS('9O=')E(&-O;F9I9W5R871I
M;VXN(%+I9^ENZ7)E>B!L82!C;VYF:6=U<F%T:6]N+@!.;U]T90!!=6-U;@!!
M=6-U;B`H=71I;&ES97(@:6UP;&EC:71E;65N="D`3F]R9&EQ=64@*$E33RTX
M.#4Y+3$P*0#.;&4@3F]R9F]L:P!(Z6UI<W!HZ')E($YO<F0`SFQE<R!-87)I
M86YN97,@9'4@;F]R9`!.;W)VZ&=E`%!A<R!A<'+H<P!087,@879A;G0`4&%S
M('5N(&1O<W-I97(`3F]N(&EM<&SI;65N=.DN`$EN86-T:68`3F]N('!R:7,@
M96X@8V]M<'1E+@!#873I9V]R:64@9&4@;F]T90!$Z71A:6QS(&1E(&QA(&YO
M=&4`3&ES=&5S(&1E(&YO=&5S`%1E>'1E(&1E(&QA(&YO=&4`7U1E>'1E(&1E
M(&QA(&YO=&4`3F]T92!N;VX@=')O=7;I90!?0FQO8RUN;W1E<P!.;VT@9'4@
M8FQO8RUN;W1E<Z`Z`$)L;V-S+6YO=&5S`$YO=&5S`%-O;6UA:7)E(&1E<R!N
M;W1E<P!2:65N(.`@;F%V:6=U97(L(')E=&]U<FYE>B!E;B!A<G)IZ')E+@!.
M;W9E;6)R90!.;VUB<F4`3F]M8G)E(&1E(&-A<F%C=.AR97,`3F]M8G)E(&1E
M(&-O;&]N;F5S`$YO;6)R92!D92!R86YGZ65S`$YO;6)R92!N;VX@<W#I8VEF
M:>D@<&]U<B!L82!M:7-E(.`@:F]U<B!D92!L82!L:7-T92!D92!D:7-T<FEB
M=71I;VXN`$]+`$]B:F5T`$-RZ6%T975R(&0G;V)J970`3V-T86P`3V-T;V)R
M90!&:6QT<F4@86YT:2UO9F9E;G-A;G0`0G5R96%U`$PG86YC:65N(&5T(&QE
M(&YO=79E874@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@9&EF9NER96YT
M<RX`06YC:65N(&UO="!D92!P87-S90!,)V%N8VEE;B!M;W0@9&4@<&%S<V4@
M97-T(&EN8V]R<F5C=`!/;6%N`%-E=6P@;&5S('-E<G9E=7)S($E-05`@<W5P
M<&]R=&5N="!L97,@9&]S<VEE<G,@<&%R=&%GZ7,N`%-E=6QE;65N="!L97,@
MJZ!F;W)T=6YE<Z"[(&]F9F5N<V%N=&5S`%5N92!S975L92!A9')E<W-E(&1E
M(&-O=7)R:65L('!E<FUI<V4N`%-E=6QS(&QE('!R;W!R:>ET86ER92!O=2!L
M)V%D;6EN:7-T<F%T975R('-Y<W3H;64@<&5U="!M;V1I9FEE<B!L97,@<&5R
M;6ES<VEO;G,@9"=U;B!P87)T86=E+@!/=79R:7(@9&%N<R!U;F4@;F]U=F5L
M;&4@9F5NZG1R90!%<G)E=7(@3W!E;E-33*`Z(&EM<&]S<VEB;&4@9"=E>'1R
M86ER92!L97,@9&]N;NEE<R!D92!L82!P87)T:64@<VEG;NEE(%,O34E-10!/
M=79R:7(@;&5S(&QI96YS(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`4WES
M=.AM92!D)V5X<&QO:71A=&EO;@!/<'1I;VYS`$]P=&EO;G,@<&]U<B`E<P!,
M:7-T92!N=6WI<F]TZ64`3W)G86YI<V%T:6]N`%5N:73I(&]R9V%N:7-A=&EO
M;FYE;&QE`$]R9V%N:7-A=&EO;@!-;V3H;&4@;W)I9VEN86P@9"=A<'!L:6-A
M=&EO;@!-;V3H;&5S(&]R:6=I;F%U>"!D86YS("5SH#H`075T<F4`075T<F5S
M(&EN9F]R;6%T:6]N<P!!=71R97,@;W!T:6]N<P!097)M:7-S:6]N<R!D=2!P
M<F]P<FGI=&%I<F4`3"=A=71H96YT:69I8V%T:6]N(%!!32!N)V5S="!P87,@
M9&ES<&]N:6)L92X`36]D=6QE(%!%05(Z.DUA:6P`4VEG;F%T=7)E(&YU;>ER
M:7%U92!01U``1&]N;NEE<R!01U`@8VAI9F9RZ65S`$-L968@<'5B;&EQ=64@
M4$=0`$1O;F[I97,@4$=0('-I9V[I97,O8VAI9F9RZ65S`$-O9&4@4$A0`$EN
M=&5R<'+I=&5U<B!02%``4&QU:64@;.EGZ')E(&PG87!RZ',M;6ED:0!!=F5R
M<V5S(&PG87!RZ',M;6ED:0!.96EG92!L)V%P<NAS+6UI9&D`0VAU=&5S(&1E
M(&YE:6=E(&PG87!RZ',M;6ED:0!3;VQE:6P@;"=A<'+H<RUM:61I`$]R86=E
M<R!L)V%P<NAS+6UI9&D`17AT96YS:6]N(%!/4TE8(&%B<V5N=&4`26YT97)P
M<NET975R(%!?2%``4F5M<&QI<W-A9V4`4&%K:7-T86X`0F5L874`4&%L97-T
M:6YE("AT97)R:71O:7)E(&]C8W5PZ2D`4&%N86UA`%!A<&]U87-I92U.;W5V
M96QL92U'=6ENZ64`4&%R86=U87D`4&%R=&EE;&QE;65N="!N=6%G975X`$UO
M="!D92!P87-S90!#:&%N9V5M96YT(&1U(&UO="!D92!P87-S92!E9F9E8W1U
MZ2X`36]T(&1E('!A<W-E(&EN8V]R<F5C=`!-;W0@9&4@<&%S<V4@<F5Q=6ES
M('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%)!1$E54RX`36]T(&1E('!A<W-E
M(&%V96,@8V]N9FER;6%T:6]N`$UO="!D92!P87-S9:`Z`$UO="!D92!P87-S
M9:`Z(`!,97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@:61E;G1I<75E
M<RX`0V]L;&5R`$-O;&QE<B!D97!U:7,@;&4@<')E<W-E+7!A<&EE<G,`0VAE
M;6EN`$-O;F9I<FUA=&EO;G,@96X@871T96YT9:`Z`%!E<G-O;FYE<P!0;W5R
M8V5N=&%G90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N
M8V4`169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E(.`@
M;&$@8V]N;F5X:6]NH#\`4&5R;6ES<VEO;@!,82!P97)M:7-S:6]N(*N@)7.@
MNR!N)V5S="!P87,@<W5P<')I;>EE+@!!8V/H<R!R969U<^D`1')O:71S(&0G
M86-CZ',`061M:6YI<W1R871I;VX@9&5S('!E<FUI<W-I;VYS`$1O;F[I97,@
M<&5R<V]N;F5L;&5S`%#I<F]U`$%N:6UA=7@`4&AI;&EP<&EN97,`5.ELZ7!H
M;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!35E`@8VQI
M<75E>B!D86YS('5N92!C96QL=6QE`%-64"!C;VYF:7)M97H@;&$@<W5P<')E
M<W-I;VX@9&4@8V5T(.ELZ6UE;G2@.@!35E`@8V]N9FER;65Z('%U92!V;W5S
M('9O=6QE>B!DZ6QI97(@8V5T(.ELZ6UE;G0N`%9E=6EL;&5Z('-A:7-I<B!U
M;B!M;VES(&5T('5N92!A;F[I92X`5F5U:6QL97H@<V%I<VER('5N(&YO;2!P
M;W5R(&QA(&YO=79E;&QE(&-A=.EG;W)I9:`Z`%9E=6EL;&5Z(&5N=')E<B!U
M;F4@861R97-S92!)4"!V86QI9&4N`%9E=6EL;&5Z(&5N=')E<B!U;F4@9&%T
M92!V86QI9&6@.R!VZ7)I9FEE>B!L92!N;VUB<F4@9&4@:F]U<G,@9'4@;6]I
M<RX@`%9E=6EL;&5Z(&5N=')E<B!U;F4@:&5U<F4@=F%L:61E+@!6975I;&QE
M>B!F;W5R;FER('5N('+I<W5MZ2!D=2!P<F]B;.AM92X`5F5U:6QL97H@9F]U
M<FYI<B!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!E="!V;W1R92!M;W0@9&4@
M<&%S<V4`5F5U:6QL97H@;&ER92!L92!T97AT92!S=6EV86YT+B!6;W5S(&1E
M=F5Z(&%C8V5P=&5R(&QE<R!C;VYD:71I;VYS('!O=7(@=71I;&ES97(@;&4@
M<WES=.AM92X`5F5U:6QL97H@96YT<F5R(&QE(&YO=79E874@;F]MH&1E(&QA
M(&-A=.EG;W)I9:`Z`%!O;&]G;F4`4&]L:71I<75E`%-C<G5T:6YS`%!O<G1U
M9V%L`%!O<VET:6]N(&1E(&-E='1E(&EM86=E`%!O<VET:6]N(&1E(&-E('1A
M8FQE874`16YV;WEE<B#@(&-E(&1O<W-I97(@*&YO;B!A<'!L:7%UZ2!P87(@
M24U!4"D`4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@9&5R;FGH<F5S(&AE
M=7)E<Z`Z(`!0<F]B86)I;&ETZ3QB<B`O/F1E('!L=6EE`%!R969S7VQD87"@
M.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE+@!0<F5F<U]S
M97-S:6]NH#H@97AT96YS:6]N(')E<75I<V4@JZ!S97-S:6]NH+L@;F]N('1R
M;W5VZ64N`%!R97-S:6]N`%!R97-S:6]N(&%U(&YI=F5A=2!D92!L82!M97*@
M.B``4')E<W-I;VZ@.B``07!E<N=U`$%P97+G=2!D92!L)VEM86=E(&1A;G,@
M=6YE(&YO=79E;&QE(&9E;NIT<F4`3W!T:6]N<R!P<NECZ61E;G1E<P!);7!R
M:6UE<B!L92!D;V-U;65N=`!#;&5F('!R:7;I90!0<F]B;.AM90!$97-C<FEP
M=&EO;B!D=2!P<F]B;.AM90!0<F]J971S`%1E>'1E(&-O=7)T`$-L968@<'5B
M;&EQ=64`06QG;W)I=&AM92!D92!C;&5F('!U8FQI<75E`$EN9F]R;6%T:6]N
M<R!S=7(@;&$@8VQE9B!P=6)L:7%U90#)8VAE8R!D92!L82!GZ6[I<F%T:6]N
M(&1E(&QA('!A:7)E(&1E(&-L969S('!U8FQI<75E+W!R:7;I92X`4&]R=&\@
M4FEC;P!1871A<@!297%UZG1E`%%U;W1A`$-L968@<'5B;&EQ=64@4E-!("@E
M9"!B:71S*0!3Z6QE8W1I;VX@<F%D:6\`4&QU:64`4&QU:64@=/1T(&QE(&UA
M=&EN`%!L=6EE('1A<F0@9&%N<R!L82!J;W5R;NEE`$%V97)S97,`4&QU:64@
M970@;F5I9V4`4&QU:64@<'5I<R!N96EG90!!<&AO<FES;64@874@:&%S87)D
M`%1A=7@`3&ER90!-97-S86=E<R!L=7,`4W5P<')E<W-I;VX@9.EF:6YI=&EV
M92!D92`E<Z`_`%-U<'!R97-S:6]N(&3I9FEN:71I=F4@9&5S(&1O;F[I97,@
M<&]U<B!L)W5T:6QI<V%T975R("5SH#\@0V5T=&4@;W#I<F%T:6]N(&5S="!D
MZ69I;FET:79E+@!297!R96YD<F4@=F]T<F4@9&5R;FGH<F4@86-T:6]N`%)A
M9G)A[F-H:7(`4F%F<F'N8VAI<B!L97,@Z6SI;65N=',@9'4@;65N=2!D>6YA
M;6EQ=66@.@!2869R8>YC:&ER(&QA(&QI<W1E`%)A9G)A[F-H:7(@;"?I8W)A
M;B!D=2!S;VUM86ER9:`Z`$5X<')E<W-I;VX@<F%T:6]N;F5L;&4`3F%V:6=A
M=&5U<B!R96QA=&EO;FYE;`!296-H87)G97(`4F5M87)Q=65S`%-E<G9E=7)S
M(&1I<W1A;G1S`%523"!D:7-T86YT92`H:'1T<#HO+W=W=RYE>&5M<&QE+F-O
M;2]H;W)D92\IH#H`4F5T:7)E<@!2971I<F5R(&QE(&)L;V,`4F5T:7)E<B!L
M82!C873I9V]R:64`4F5T:7)E<B!L82!C;VQO;FYE`%)E=&ER97(@;&4@9F]R
M;6%T86=E`%)E=&ER97(@;&$@<&%I<F4`16YL979E<B!L92!S8W)I<'0@96YR
M96=I<W1RZ2!D=2!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@9'4@<V5R=F5U<BX`
M4F5T:7)E<B!L90!2971I<F5R(&-E(&YO975D(&1U(&1O8W5M96YT`%)E=&ER
M97(@;"=U=&EL:7-A=&5U<@!2971I<F5R(&PG=71I;&ES871E=7*@.B`E<P!!
M=6-U;F4@<NEP;VYS92#@('9O=')E(')E<77J=&4N($-O9&4@9"=E<G)E=7(@
M<F5T;W5R;NF@.B``3&4@<V5R=FEC92!D96UA;F3I(&5S="!I;G1R;W5V86)L
M92X`3&4@<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@
M<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N("5S+@!,92!P87)A;>AT
M<F4@;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS
M(&QA(&-O;F9I9W5R871I;VX@9'4@5D93+@!,92!P87)A;>AT<F4@;V)L:6=A
M=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA(&-O;F9I
M9W5R871I;VXN`$-H86UP(&]B;&EG871O:7)E`%+`6@!296UI<V4@X"!ZZ7)O
M(&1U(&UO="!D92!P87-S90!296UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E
M('!A<W-E`%)E=F5N:7(@X"!L82!D97)N:>AR92!R97%UZG1E`%+I<W5L=&%T
M<P!2979E;FER(&%U>"!O<'1I;VYS`%+I+65N=')E<B!L92!N;W5V96%U(&UO
M="!D92!P87-S90!2Z75N:6]N`%)E=F5N:7(@X"!L82!C;VYF:6=U<F%T:6]N
M('!RZ6/I9&5N=&4`3W!T:6]N<R!D92!L)^ED:71E=7(@4FEC:"!497AT`$1E
M=FEN971T97,`1')O:71E`$5N=.IT92!D92!D<F]I=&4`5F%L975R<R!C;W)R
M96-T97,`4')O<')IZ73I<R!D92!L82!R86Y?9^EE("XN+@!2]&QE`%)O=6UA
M;FEE`%!I=F]T97(@,3@P`%!I=F]T97(@X"!G875C:&4`4&EV;W1E<B#@(&1R
M;VET90!0<F]P<FGI=.ES(&1E(&QA(')A;F?I90!0<F]P<FGI=.ES(&1E(&QA
M(')A;F?I90!286YGZ65SH#H`4NAG;&5S`$1E<R!F:6QE=',@87!P87)A[G1R
M;VYT(&5N=')E('1O=71E<R!L97,@<F%N9^EE<R!E="!L97,@8V]L;VYN97,`
M1&5S(&9I;&5T<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(&-O;&]N;F5S('-E
M=6QE;65N=`!$97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!L97,@<F%N
M9^EE<R!S975L96UE;G0`3&%N8V5R`%)U<W-I90!2=V%N9&$`4VEG;F%T=7)E
M(.EL96-T<F]N:7%U92!3+TU)344`365S<V%G92!C:&EF9G+I(%,O34E-10!,
M)V%U=&AE;G1I9FEC871I;VX@4T%33"!N)V5S="!P87,@9&ES<&]N:6)L90!-
M97-S86=E<FEE(%--4P!);G1E<G!RZ71E=7(@4U%,`$]R9')E(%-13"!P;W5R
M(')E=&]U<FYE<B!L97,@=F%L975R<P!34T@`4U5#0\A3`$EN=&5R<'+I=&5U
M<B!37U%,`%-A`%-A:6YT92U(Z6SH;F4`4V%I;G0M0VAR:7-T;W!H92UE="U.
M:>EVZ',`4V%I;G1E+4QU8VEE`%-A:6YT+5!I97)R92!E="!-:7%U96QO;@!3
M86EN="U6:6YC96YT+65T+6QE<R!'<F5N861I;F5S`$WJ;64@8V%D<F4@*%]S
M96QF*0!386UO82!O8V-I9&5N=&%L97,`4V%I;G0M36%R:6X`4V%O+51O;>DM
M970M4')I;F-I<&4`1F]U<FYI<W-E=7(@<V%T96QL:71E`$%R86)I92!386]U
M9&ET90!%;G)E9VES=')E<@!%;G)E9VES=')E<B"KH"5SH+L`16YR96=I<W1R
M97(@)7,`16YR96=I<W1R97(@;&5S(&]P=&EO;G,`16YR96=I<W1R97(@;&$@
M8V]N9FEG=7)A=&EO;B!GZ6[I<NEE(&-O;6UE('5N('-C<FEP="!02%`@9&%N
M<R!L92!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@9&4@=F]T<F4@<V5R=F5U<BX`
M16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!38W)I<'0@9&4@
M;6ES92#@(&IO=7(@9&4@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I('-O=7.@
M.B"K("5SH+L`3W)A9V5S(&ES;VSI<P!38VEE;F-E`%)E8VAE<F-H90!-;W1E
M=7)S(&1E(')E8VAE<F-H90!2Z7-U;'1A=',@9&4@;&$@<F5C:&5R8VAE`,ET
M96YD=64@9&4@;&$@<F5C:&5R8VAE`%]497AT92!R96-H97)C:.D`0VAO:7-I
M<W-E>B!L97,@9FEC:&EE<G,`4^EL96-T:6]N;F5Z('5N92!D871E`%/I;&5C
M=&EO;FYE>B!U;B!G<F]U<&4@X"!A:F]U=&5R`%/I;&5C=&EO;FYE>B!U;B!N
M;W5V96%U('!R;W!R:>ET86ER90!3Z6QE8W1I;VYN97H@=6X@8FQO8RUN;W1E
M<P!3Z6QE8W1I;VYN97H@=6X@<V5R=F5U<@!3Z6QE8W1I;VYN97H@=6X@=71I
M;&ES871E=7(@X"!A:F]U=&5R`%1O=70@<^EL96-T:6]N;F5R`%/I;&5C=&EO
M;FYE>B!T;W5T97,@;&5S(&-O;7!O<V%N=&5S(&1E(&QA(&1A=&4N`$-H;VES
M:7-S97H@=6X@;V)J970`3F4@<^EL96-T:6]N;F5R(&%U8W5N`%/I;&5C=&EO
M;FYE>B!L97,@8V%R86-TZ')E<R!D;VYT('9O=7,@879E>B!B97-O:6X@X"!L
M)V%I9&4@9&4@;"=O=71I;"!C:2UD97-S;W5S+B!6;W5S('!O=79E>B!E;G-U
M:71E(&QE<R!C;W!I97(@970@;&5S(&-O;&QE<B!D86YS('9O=')E('1E>'1E
M+@!3Z6QE8W1I;VYN97H@;&4@9.EL:6UI=&5U<B!D92!D871EH#H`4^EL96-T
M:6]N;F5Z(&QE(&9O<FUA="!D92!D871EH#H`4^EL96-T:6]N;F5Z(&QE(&9O
M<FUA="!D92!L)V5X<&]R=&%T:6]N.@!#:&]I<VES<V5Z(&QE(&9I8VAI97(@
MX"!I;7!O<G1E<J`Z`%/I;&5C=&EO;FYE>B!L92!F;W)M870@9'4@9FEC:&EE
M<B!S;W5R8V4Z`%/I;&5C=&EO;FYE<B!L92!P<F]F:6P@<75E('9O=7,@9.ES
M:7)E>B!M;V1I9FEE<CH`4^EL96-T:6]N;F5Z(&QE(&3I;&EM:71E=7(@9"=H
M975R9:`Z`%/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@;"=H975R9:`Z`%/I
M;&5C=&EO;FYE>B!D975X(&-H86UP<R!A<'!A<F5N=.ES+@!3Z6QE8W1I;VYN
M97H@=F]T<F4@=&CH;64@9&4@8V]U;&5U<G,N`%/I;&5C=&EO;FYE>B!V;W1R
M92!L86YG=64@<'+I9NERZ66@.@!#873I9V]R:65S('/I;&5C=&EO;F[I97.@
M.@!%;G9O>65R(&QE(')A<'!O<G0@9"=A;F]M86QI90!%;G9O>65R(%--4P!3
MZ6[I9V%L`%-O;F1EH#H@`%-E<'1E;6)R90!397)B:64@970@36]N=&5N96=R
M;P!.=6WI<F\@9&4@<^ER:64`3&5S(&1O;F[I97,@9'4@<V5R=F5U<B!S;VYT
M(&9A=7-S97,@;W4@;F]N(&1I<W!O;FEB;&5S+@!!9&UI;FES=')A=&EO;B!D
M97,@<V5S<VEO;G,`260N(&1E('-E<W-I;VX@97AP:7+I+@!397-S:6]N<P!3
MZ6QE8W1I;VYN97(`0V]N9FEG=7)E<B!L97,@;W!T:6]N<R!P;W5R('9O=7,@
M<&5R;65T=')E(&1E(')E;65T=')E(.`@>NER;R!V;W1R92!M;W0@9&4@<&%S
M<V4@<VD@:F%M86ES('9O=7,@;"=O=6)L:65Z+@!#;VYF:6=U<F5R(&QE<R!S
M97)V975R<R!D:7-T86YT<R!A8V-E<W-I8FQE<R!D97!U:7,@=F]T<F4@<&]R
M=&%I;"X`4^EL96-T:6]N;F5Z('9O=')E(&QA;F=U92!P<NEFZ7+I92P@9G5S
M96%U(&AO<F%I<F4@970@;&5S(&]P=&EO;G,@9&4@9&%T92X`1.EF:6YI<W-E
M>B!L82!P<F5M:>AR92!A<'!L:6-A=&EO;B!L86YCZ64L(&QE('1HZ&UE(&1E
M(&-O=6QE=7)S+"!L92!R869R8>YC:&ES<V5M96YT(&1E<R!P86=E<RP@970@
M9"=A=71R97,@;W!T:6]N<R!D)V%F9FEC:&%G92X`0V]N9FEG=7)A=&EO;@!3
M8W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E(.`@:F]U<B!D:7-P;VYI
M8FQE`%!L=7-I975R<R!E;F1R;VET<R!P;W-S:6)L97,@879E8R!L92!P87)A
M;>AT<F6@.B``4V5Y8VAE;&QE<P!!8VAA=`!2Z7-U;>D`1&]I="UO;B!DZ69I
M;FER(&1E<R!T;W5C:&5S(&1E(')A8V-O=7)C:7,@<&]U<B!L82!P;'5P87)T
M(&1E<R!L:65N<Z`_`$%F9FEC:&5R`$%F9FEC:&5R(&)O=71O;G,@9"=A8W1I
M;VX@/P!-;VYT<F5R(&QE<R!D:69FZ7)E;F-E<R!E;G1R92!L82!C;VYF:6=U
M<F%T:6]N(&5N<F5G:7-T<NEE(&%C='5E;&QE;65N="!E="!C96QL92!N;W5V
M96QL96UE;G0@9^ENZ7+I92X`36]N=')E<B!L)VAE=7)E(&1E(&QA(&1E<FYI
MZ')E(&-O;FYE>&EO;B#@(&PG96YT<NEEH#\`069F:6-H97(@;&4@;F]M(&1U
M(&)L;V,M;F]T97,@/Z`Z`$%F9FEC:&5R(&QE<R!N;W1E<R!D92!C97,@8V%T
MZ6=O<FEE<P!-;VYT<F5R(&PG;W!T:6]N(&1E(&-O;G-E<G9E<B!L)V]R:6=I
M;F%L`$UO;G1R97(@;&4@<^EL96-T975R`$%F9FEC:&5R(&QA(&)A<G)E(&1E
M(&UE;G4@9&4@=&%B;&5A=7B@/P!!9F9I8VAE<B!L92!M96YU("5S(.`@9V%U
M8VAEH#\`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@=&%B;&5A=2!C
M96QL=6QE`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P<F]P
M<FGI=.ES(&1U('1A8FQE874`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G
M=64@9&5S('!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE(&1U('1A8FQE874`069F
M:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ETZ7,@9&4@
M;"=I;6%G90!!9F9I8VAE<B!L)V5N=F]I(&1E(&9I8VAI97(`079E<G-E<P!!
M=F5R<V5S('3T="!D86YS(&QA(&IO=7)NZ64`079E<G-E<R!T87)D(&5N(&IO
M=7)NZ64`079E<G-E<R!A=7@@86QE;G1O=7)S`%)E<W-E<G)E<@!297-S97)R
M97(@;W4@9.EG86=E<B!D)V%B;W)D(&QE*',I(&)L;V,H<RD@=F]I<VEN*',I
M`%-I97)R82!,96]N90!3)VEN<V-R:7)E`%-I9VYA='5R90!!;&=O<FET:&UE
M(&1E('-I9VYA='5R90!3:6YG87!O=7(`5&%I;&QE`$%N;G5L97(@;&$@;6%I
M;G1E;F%N8V4`4VQO=F%Q=6EE`%-L;W;I;FEE`$YE:6=E`$%V97)S92!D92!N
M96EG90!!=F5R<V5S(&1E(&YE:6=E`$%V97)S97,@9&4@;F5I9V4@=/1T(&1A
M;G,@;&$@:F]U<F[I90!!=F5R<V5S(&1E(&YE:6=E('1A<F0@96X@:F]U<F[I
M90!(875T975R(&1E(&YE:6=EH#H@`%%U86YT:73I(&0G96%U(.EQ=6EV86QE
M;G1E(.`@;&$@<75A;G1I=.D@9&4@;F5I9V6@.B``SFQE<R!386QO;6]N`%-O
M;6%L:64`0VAA;G-O;G,@970@<&_H;65S`%1R:2!S96QO;B!L82!C873I9V]R
M:64`5')I('-E;&]N(&QE('1E>'1E(&1E(&QA(&YO=&4`4^EL96-T:6]N(&1E
M(&PG;W)D<F4@9&4@=')I`$%D<F5S<V4@<V]U<F-E`$%F<FEQ=64@9'4@<W5D
M`%-U9"UE=7)O<.EE;B`H25-/+3@X-3DM,RD`1^EO<F=I92UD=2US=60@970@
M[FQE<R!386YD=VEC:"UD=2US=60`2.EM:7-P:.AR92!3=60`17-P86-E(&5N
M=')E(&-E;&QU;&5S(&%D:F%C96YT97,`17-P86-E(&5N=')E(&QE(&-O;G1E
M;G4@970@;&$@8F]R9'5R92!D86YS('5N92!C96QL=6QE`$5S<&%C975R`$5S
M<&%C96UE;G0`17-P86-E;65N="!E="!R96UP;&ES<V%G90!%<W!A9VYE`%!O
M=7)R:65L`$-A<F%C=.AR97,@<W#I8VEA=7@`4V-I;F1E<B!L82!C96QL=6QE
M`%-C:6YD97(@;&$@8V]L;VYN90!38VEN9&5R(&QA(')A;F?I90!3<&]R=',`
M4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!!;F[I92!D92!DZ6)U=`#)
M=&%T(&]U('!R;W9I;F-E`%-T871U=`!&;W)M870@9&4@<V%U=F5G87)D90!2
M=64`0F%R<ND`3&ES=&4@9&4@8VAA[FYE<P!2971I<F5R(&QE(&1O;6%I;F4@
M9&4@;"=A9')E<W-E`%-T>6QE(%M#4U-=`$1I`%-O=7,M<NEP97)T;VER92"K
MH"5SH+L@;F]N('1R;W5VZ0!3=6IE=`!%;G9O:0!,82!D96UA;F1E(&0G86IO
M=70@9&4@JZ`E<Z"[(&%U('-Y<W3H;64@82#I=.D@<V]U;6ES92X@5F]U<R!N
M92!P;W5R<F5Z('!A<R!V;W5S(&-O;FYE8W1E<B!J=7-Q=2?@('-O;B!A<'!R
M;V)A=&EO;BX`26YD:6-E`%-U8V/H<P"KH"5SH+L@82!B:65N(.ETZ2!A:F]U
M=.DH92DN`$QE<R!D;VYNZ65S(&1E(&PG=71I;&ES871E=7(@JZ`E<Z"[(&]N
M="!B:65N(.ETZ2!R971I<NEE<R!D=2!S>7-TZ&UE+BX`JZ`E<Z"[(&$@8FEE
M;B#I=.D@<W5P<')I;>DH92DN`*N@)7.@NR!A(&)I96X@Z73I(')E=&ERZ2AE
M*2X`4F5T;W5R(.`@;&$@8V]N9FEG=7)A=&EO;B!I;FET:6%L92!RZ75S<VDN
M("!2869R8>YC:&ER(&QA('!A9V4@<&]U<B!V;VER(&QE<R!M;V1I9FEC871I
M;VYS+@!%;G)E9VES=')E;65N="!D92!L82!C;VYF:6=U<F%T:6]N(&1E(&QA
M('-A=79E9V%R9&4@<NEU<W-I+@!%;G)E9VES=')E;65N="!RZ75S<VD@9&4@
M;&$@8V]P:64@9&4@<V%U=F5G87)D92!D=2!F:6-H:65R(&1E(&-O;F9I9W5R
M871I;VX@)7,N`*N@)7.@NR!A(&)I96X@Z73I(&UI<RAE*2#@(&IO=7(N`,EC
M<FET=7)E(&1E("5S('+I=7-S:0!3;W5D86X`4V]M;6%I<F4`3&5V97(@9'4@
M4V]L96EL`$-O=6-H97(@9'4@4V]L96EL`$5N<V]L96EL;.D`3&5V97(@9'4@
M4V]L96EL`$QE=F5R+T-O=6-H97(@9'4@4V]L96EL`$QE=F5R(&1U(%-O;&5I
M;#H@`$-O=6-H97(@9'4@4V]L96EL`$-O=6-H97(@9'4@4V]L96ELH#H@`$5X
M<&]S86YT`$%S<VES=&%N8V4`4W5R:6YA;2!O=2!'=7EA;F4@:&]L;&%N9&%I
M<V4`3F]M(&1E(&9A;6EL;&4`SFQE<R!3=F%L8F%R9"!E="!*86X@36%Y96X`
M4W=A>FEL86YD`%-UZ&1E`%-U:7-S90!*;W5R;F%L(&1E('-Y;F-H<F]N:7-A
M=&EO;B!S=7!P<FEMZ0!3>6YC34P`17)R975R(&1E('-Y;G1A>&4@9&%N<R!L
M97,@=&5R;65S(&1E(')E8VAE<F-H90!3>7)I90!/<F%G97,`3W)A9V4@970@
M=F5N=`!/<F%G97,`3W)A9V5S(&UA=&EN875X`$9I8VAI97(@5%-6`%1A8FQE
M874`4')O<')IZ73I<R!D=2!T86)L96%U`%1A8FQE874@9&4@=F%L975R<P!0
M<F]P<FGI=.ES(&1U('1A8FQE874`5&'O=V%N`%1A[W=A;BP@<')O=FEN8V4@
M9&4@0VAI;F4`5&%J:6MI<W1A;@!486YZ86YI90!#:6)L9:`Z`%3B8VAE<P!.
M=6WI<F\@9&4@=.ELZ7!H;VYE`%1E;7#I<F%T=7)E('!O=7(@;&$@9&5R;FGH
M<F4@:&5U<F6@.B``5&5M<.ER871U<F4`5&5M<.ER871U<F6@.B``5&5M<.ER
M871U<F4\8G(@+SXH)7-(825S+R5S0F$E<RD@)F1E9SLE<P!0<F]F:6P@JZ`E
M<Z"[(&YO;B!T<F]U=ND`061M:6YI<W1R871I;VX@9&5S(&UO9.AL97,`5&5X
M=&4`5&5X=&4@<V5U;`!!;&EG;F5M96YT(&1U('1E>'1E`%1E>'1E(&5N(&AA
M=70`2F4`5&AA[R`H5$E3+38R,"D`5&AA[VQA;F1E`$PG97AT96YS:6]N($94
M4"!N)V5S="!P87,@9&ES<&]N:6)L92X`3&4@;6]T975R(&0G:6YTZ6=R871I
M;VX@2&]R9&4O2V]L86(@;F4@<W5P<&]R=&4@<&%S(*N@)7.@NP!,92!J;W5R
M;F%L($E-4U`@;B=A('!A<R!P=2#J=')E(&EN:71I86QI<^DN`$QA(&-L87-S
M92!-86EN=&5N86YC93HZ(&XG82!P87,@Z73I(&-H87)GZ64@8V]R<F5C=&5M
M96YT`$QA(&9E;NIT<F4@9&5S(&]P=&EO;G,@<R=E<W0@9F5R;>EE+B!3;W)T
M:64N`$PG861M:6YI<W1R871E=7(@9&]I="!C;VYF:6=U<F5R('5N(&)A8VME
M;F0@<&5R;6%N96YT('!O=7(@;&5S('!E<FUI<W-I;VYS('-I('9O=7,@=F]U
M;&5Z(&QE<R!E;7!L;WEE<BX`3&$@8F]R9'5R92!D=2!B87,@<V5U;&5M96YT
M`$PG240@9'4@8V]N=&%C="!N)V$@<&%S(.ETZ2!S<.EC:69IZ2P@;&%I<W/I
M('9I9&4@;W4@;B=A('!A<R#I=.D@=')O=7;I(&1A;G,@;&$@8F%S92!D92!D
M;VYNZ65S+@!#92!C;VYT86-T(&$@8FEE;B#I=.D@86IO=73I(.`@=F]T<F4@
M8V%R;F5T(&0G861R97-S97,N(`!,92!B;&]C(&1E('-I9VYA='5R92!01U`@
M<^EP87+I(&5S="!NZ6-E<W-A:7)E('!O=7(@=NER:69I97(@;&$@<VEG;F%T
M=7)E+@!,)TE$(&1E(&QA(&QI<W1E(&XG82!P87,@Z73I('-PZ6-I9FGI+"!L
M86ES<^D@=FED92!O=2!N;VX@=')O=7;I(&1A;G,@;&$@8F%S92!D92!D;VYN
MZ65S+@!,82!L:7-T92!D92!D:7-T<FEB=71I;VX@;B=A('!A<R#I=.D@<W#I
M8VEF:>EE+@!,92!C:&EF9G)E;65N="!NZ6-E<W-I=&4@=6YE(&-O;FYE>&EO
M;B!SZ6-U<FESZ64N`$QE(&9I8VAI97(@)7,@9&]I="!C;VYT96YI<B!L97,@
M;W!T:6]N<R`E<RX`3&4@9FEC:&EE<B`E<R!D;VET(&-O;G1E;FER(&-E<G1A
M:6YE<R!O<'1I;VYS("5S+@!,92!F:6-H:65R(&YE('!E=70@<&%S(.IT<F4@
M8V]P:>D@<W5R(&QU:2UMZFUE+@!,92!F:6-H:65R(&YE(&-O;G1E;F%I="!A
M=6-U;F4@9&]N;NEE+@!#92!Q=6D@<W5I="!S;VYT(&QE<R!E;BUTZG1E<R!P
M;W5R(&-E(&UE<W-A9V4@;65S<V%G92]21D,X,C(N`$QE(&UO9&4@<&QE:6X@
MZ6-R86X@8V%U<V4@9&5S('!R;V)LZ&UE<R!A=F5C($EN=&5R;F5T($5X<&QO
M<F5R(&3[(.`@9&5S(&)O9W5E<R!D=2!N879I9V%T975R('%U:2!N)V]N="!P
M=2#J=')E(&-O;G1O=7)NZ7,N(%9O=7,@<&]U=F5Z(.IT<F4@8V]N9G)O;G3I
M<R#@(&1E(&PG869F:6-H86=E(&1E(&-A<F%C=.AR97,@Z71R86YG97,L(&%U
M(&YO;BUF;VYC=&EO;FYE;65N="!D97,@8V5R=&%I;F5S(&9O;F-T:6]N<R!E
M="]O=2!A=2!P;&%N=&%G92!A;.EA=&]I<F4@9'4@;F%V:6=A=&5U<BX@4VD@
M=F]T<F4@<WES=.AM92!E<W0@=6X@5VEN9&]W<R`Y>"P@:6P@97-T('1RZ',@
M<&]S<VEB;&4@<75E('9O=7,@875R97H@=6YE("=&875T92!GZ6[I<F%L92!D
M92!P<F]T96-T:6]N)R!E="!Q=64@=F]U<R!D979R97H@<F5DZ6UA<G)E<B!V
M;W1R92!O<F1I;F%T975R+EQN7&Y6;W5S(&%V97H@Z73I('!RZ79E;G5S+B!3
M5E`@87!P=7EE>B!S=7(@3TL@<VD@=F]U<R!V;W5L97H@=&]U:F]U<G,@97-S
M87EE<B!L92!M;V1E('!L96EN(.EC<F%N(&1E(&PGZ61I=&5U<@!,)VED96YT
M:73I(*N@)7.@NR`@82#I=.D@<W5P<')I;>EE+@!,92!C]'3I(&=A=6-H92!S
M975L96UE;G0`3"=E;7!L86-E;65N="!D=2!P<F]G<F%M;64@1VYU4$<@9&]I
M="#J=')E(&9O=7)N:2#@(&QA(&-L87-S92!#<GEP=%]P9W`Z.BX`3&4@;65S
M<V%G92!E;G9O>>D@;&4@)7,@X"`E<R!A=F5C(&-O;6UE('-U:F5T(*N@)7.@
MNR!A(.ETZ2!A9F9I8VCI+B`*26P@;B=Y(&$@875C=6YE(&=A<F%N=&EE('%U
M92!C92!M97-S86=E(&$@Z73I(&QU(&]U(&-O;7!R:7,N`$QE(&YO;2#@('5T
M:6QI<V5R(&5N(&QI86YT(.`@;&$@<&%G92!D92!C;VUP;W-I=&EO;@!,82!N
M;W1E(&$@Z73I('-U<'!R:6WI92X`0W+I871I;VX@:6UP;W-S:6)L92!D=2!B
M;&]C+6YO=&5S(*N@)7.@NZ`Z("5S`$QE(&)L;V,M;F]T97,@JZ`E<Z"[(&$@
MZ73I(&-RZ>DN`$QE(&)L;V,M;F]T97,@JZ`E<Z"[(&$@Z73I('-U<'!R:6WI
M+@!,92!B;&]C+6YO=&5S(*N@)7.@NR!A(.ETZ2!E;G)E9VES='+I+@!,92!N
M;VUB<F4@9&4@8VAA;7!S(&1O:70@ZG1R92!U;B!N;VUB<F4@=F%L:61E+@!,
M92!M;V1U;&4@3W!E;E-33"!E<W0@<F5Q=6ES('!O=7(@;&$@8VQA<W-E($AO
M<F1E7T-R>7!T7W-M:6UE.CHN`$QA('!RZ6;I<F5N8V4@JZ`E<Z"[(&XG82!P
M87,@<'4@ZG1R92!E;G)E9VES='+I92!C87(@<V$@=&%I;&QE(&3I<&%S<V4@
M;&4@;6%X:6UU;2!A=71O<FESZ0!,92!P<F]G<F%M;64@=71I;&ESZ2!P;W5R
M('9I<W5A;&ES97(@8V4@='EP92!D92!D;VYNZ65S("@E<RD@;B=A('!A<R#I
M=.D@=')O=7;I+@!,92!C87)A8W3H<F4@9&4@<')O=&5C=&EO;B!D;VET(.IT
M<F4@=6X@8V%R86-TZ')E('5N:7%U92X`3&5S(&/T=.ES(&=A=6-H92!E="!D
M<F]I="!S975L96UE;G0`3&4@8_1TZ2!D<F]I="!S975L96UE;G0`3&4@<^EP
M87)A=&5U<B!D;VET(.IT<F4@=6X@8V%R86-TZ')E('5N:7%U92X`3&4@<V5R
M=F5U<B"KH"5SH+L@82#I=.D@<W5P<')I;>DN`$QE('-E<G9E=7(@JZ`E<Z"[
M(&$@Z73I(&5N<F5G:7-T<NDN`$QA(')E<77J=&4@9"=E;G)E9VES=')E;65N
M="!P;W5R("5S(&$@Z73I(&3I<&QA8^EE+@!,82!L:6=N92!D96UA;F3I92!N
M)V5X:7-T92!P87,N`$QE(&9I8VAI97(@=&5M<&]R86ER92"K("5SH+L@;B=E
M>&ES=&4@<&%S+@!,92!T97AT92!E;G1RZ2!N92!C;W)R97-P;VYD('!A<R!A
M=2!T97AT92!S=7(@;"?I8W)A;BX`3&4@:&%U="!E="!L92!B87,@<V5U;&5M
M96YT`$QE(&AA=70@<V5U;&5M96YT`$QE<R!D;VYNZ65S('3I;.EC:&%R9^EE
M<R!V97)S(&QE('-E<G9E=7(@;VYT(.ETZ2!P97)D=65S(&1E<'5I<R!L)^ET
M87!E('!RZ6/I9&5N=&4N(`!,92!F:6-H:65R(.EM:7,@;B=A('!A<R!P=2#J
M=')E(&5N<F5G:7-T<NDN`$QE(&)L;V,@JZ!W96%T:&5R+F-O;:"[(&XG97-T
M('!A<R!D:7-P;VYI8FQE+@!2Z7!E<G1O:7)E(&1E<R!T:.AM97,@JZ`E<Z"[
M(&YO;B!T<F]U=ND`26P@;B=Y(&$@<&%S(&0G;W!T:6]N<R!D:7-P;VYI8FQE
M<P!!=6-U;F4@<&%R=&EE(&YE('!E=70@ZG1R92!A9F9I8VCI92!E;B!L:6=N
M92X`26P@>2`@82!T<F]P(&1E(&-A<F%C=.AR97,@9&%N<R!C92!C:&%M<"X@
M5F]U<R!E;B!A=F5Z(&5N='+I("5SH#L@:6P@96X@9F%U="!M;VEN<R!D92`E
M<RX`56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&PG86IO=70@9&4@
MJZ`E<Z"[H#H@)7,`56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA
M('-U<'!R97-S:6]N(&1E<R!D;VYNZ65S(&1E(&PG=71I;&ES871E=7(@JZ`E
M<Z"[H#H@`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P
M<F5S<VEO;B!D92"KH"5SH+N@.B``56X@<')O8FSH;64@97-T(&%P<&%R=2!L
M;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1E(*N@)7.@NZ`Z("5S`%5N('!R;V)L
MZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!A
M=6-U;B`E<R!N)V$@Z73I('1R86YS;6ES+@!5;F4@97)R975R(&5S="!S=7)V
M96YU92!L;W)S(&1E(&PG96YV;VD@9'4@9FEC:&EE<J`Z(&QE("5S(.ET86ET
M('!L=7,@9W)O<R!Q=64@;&4@;6%X:6UU;2!A=71O<FESZ2`H)60@;V-T971S
M*2X`56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U
M(&9I8VAI97*@.B!L92`E<R!A(.ETZ2!T<F%N<VUI<R!P87)T:65L;&5M96YT
M+@!5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=A9F9I8VAA
M9V4@9&4@8V5T=&4@<&%R=&4@9'4@;65S<V%G90!5;F4@97)R975R(',G97-T
M('!R;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE<R!D
M92!C92!C;VYT86-T+@!5;F4@97)R975R(&5S="!A<'!A<G5E(&QO<G,@9&4@
M;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE<Z`Z("5S`%5N92!E<G)E=7(@<R=E
M<W0@<')O9'5I=&4@;&]R<R!D92!L)VEM<&]R=&%T:6]N(&1E<R!D;VYNZ65S
M('9.;W1E+@!);"!Y(&%V86ET('5N92!E<G)E=7(@9&%N<R!L92!F;W)M=6QA
M:7)E(&1E(&-O;F9I9W5R871I;VXN(%!E=70MZG1R92!A=F5Z+79O=7,@;&%I
M<W/I('5N(&-H86UP(')E<75I<R!V:61E+@!5;F4@97)R975R(',G97-T('!R
M;V1U:71E(&QO<G,@9&4@;"=E>.EC=71I;VX@9&4@8V5T=&4@9F]N8W1I;VX@
M9'4@8V%R;F5T(&0G861R97-S92X@4U90(&5S<V%Y97(@X"!N;W5V96%U('!L
M=7,@=&%R9"X`56YE(&5R<F5U<B!E<W0@87!P87)U92!L;W)S(&1U(')E=')A
M:70@9&4@;&$@;F]T92`Z("5S`%5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@
M;&]R<R!D92!L)V5N<F5G:7-T<F5M96YT(&1E(&QA(&YO=&4Z("5S`$EL('D@
M82!E=2!U;F4@97)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@9&5S(&EN
M9F]R;6%T:6]N<R!S=7(@;&4@8V]N=&%C="X@(%9E=6EL;&5Z(&5S<V%Y97(@
MX"!N;W5V96%U+@!);"!Y(&$@974@=6YE(&5R<F5U<B!L;W)S(&1E(&QA(&UI
M<V4@X"!J;W5R(&1E(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@(%9E=6EL
M;&5Z(&5S<V%Y97(@9&4@;F]U=F5A=2X`26P@>2!A(&5U('5N92!E<G)E=7(@
M;&]R<R!D92!L)V]U=F5R='5R92!D92!C92!B;&]C+6YO=&5S.B`E<P!!=6-U
M;F4@;F]T92#@(&5X<&]R=&5R(&XG82#I=.D@=')O=7;I92X`3&4@<'+I<V5N
M="!S97)V975R($E-05`@;F4@<W5P<&]R=&4@<&%S(&QE('!A<G1A9V4@9&4@
M9&]S<VEE<G,N`,=A(&YE('-E;6)L92!P87,@ZG1R92!U;F4@87)C:&EV92!2
M05(@=F%L:61E+@#'82!N92!S96UB;&4@<&%S(.IT<F4@=6X@9FEC:&EE<B!:
M25`@=F%L:61E+@#'82!N92!S96UB;&4@<&%S(.IT<F4@=6X@;G5MZ7)O(&1E
M(&-A<G1E('9A;&ED92X`0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE
M<W-A9V5S(.`@=')A=F5R<R!L82!P87-S97)E;&QE($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%``
M0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('9I82!L82!P
M87-S97)E;&QE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&5N('5T:6QI<V%N
M="!L)T%022!(5%10`$-E('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S
M86=E<R#@('1R879E<G,@;&$@<&%S<V5R96QL92!S;7,R96UA:6P@*&AT='`Z
M+R]S;7,R96UA:6PN8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144`!#92!P
M:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G97,@<&%R(%--5%`@X"!T
M<F%V97)S(&QA('!A<W-E<F5L;&4@5F]D869O;F4@271A;&EE+"!S975L96UE
M;G0@875X(&YU;>ER;W,@5F]D869O;F4N($-E;&$@;NEC97-S:71E('5N(&-O
M;7!T92!D92!C;W5R<FEE;"!6;V1A9F]N92!)=&%L:64@*&AT='`Z+R]W=W<N
M,3DP+FET*2X`0V4@8VAA;7`@97-T(&]B;&EG871O:7)E+@!#92!C:&%M<"!N
M92!D;VET(&-O;G1E;FER('%U92!D97,@96YT:65R<RX`0V4@8VAA;7`@;F4@
M9&]I="!C;VYT96YI<B!Q=64@9&5S(&YO;6)R97,@970@;&5S(&1E=7@M<&]I
M;G1S+@!#92!C:&%M<"!N92!D;VET(&-O;G1E;FER('%U92!D97,@=F%L975R
M<R!O8W1A;&5S+@!#92!C:&%M<"!D;VET(&-O;G1E;FER('5N92!L:7-T92!D
M)V5N=&EE<G,@<^EP87+I<R!P87(@9&5S('9I<F=U;&5S(&]U(&1E<R!E<W!A
M8V5S`$-E(&-H86UP(&1O:70@ZG1R92!U;B!N;VUB<F4@=F%L:61E+@!#92!C
M:&%M<"!D;VET(&-O;G1E;FER('5N(&-O9&4@9&4@8V]U;&5U<B!A=2!F;W)M
M870@4D="(&AE>&%DZ6-I;6%L+"!P87(@97AE;7!L92`G(S$R,S1A9B<N`$-E
M(&9O<FUA="!D92!F:6-H:65R(&XG97-T('!A<R!P<FES(&5N(&-O;7!T92X`
M0V4@9F]R;75L86ER92!A(&3I:N`@Z73I('1R86ETZ2X`0R=E<W0@)7,N`$-E
M8VD@97-T('5N(&]B:F5T($MO;&%B($=R;W5P=V%R92X@4&]U<B!V;VER(&-E
M="!O8FIE="P@=F]U<R!D979R97H@879O:7(@=6X@8VQI96YT(&1E(&-O=7)R
M:65L('%U:2!C;VUP<F5N9"!L92!F;W)M870@2V]L86(@1W)O=7!W87)E+B!0
M;W5R('5N92!L:7-T92!D92!C97,@8VQI96YT<R!D92!C;W5R<FEE;"P@=FES
M:71E>B`E<P!#92!M97-S86=E(&$@Z73I(.EC<FET(&1A;G,@=6X@8V]D92!D
M92!C87)A8W3H<F5S("@E<RD@875T<F4@<75E(&QE(';T=')E+@!#92!N;VUB
M<F4@9&]I="#J=')E('-U<.ER:65U<B#@('5N+@!#92!S97)V975R(&YE('!E
M=70@<&%S(&3I8V]M<')E<W-E<B!L97,@9FEC:&EE<G,@6DE0(&5T(&=Z:7`N
M`$-E('-Y<W3H;64@97-T('!RZ7-E;G1E;65N="!DZ7-A8W1I=NDN`$-E='1E
M('9A;&5U<B!D;VET(.IT<F4@=6X@;F]M8G)E+@!#971T92!F96[J=')E(&1O
M:70@ZG1R92!A<'!E;.EE(&1E<'5I<R!U;F4@9F5NZG1R92!D97,@;W!T:6]N
M<P!4;VYN97)R90!4:6-K971S`$AE=7)E`%-U:79I(&AO<F%I<F4`1F]R;6%T
M(&0G:&5U<F4`4^EL96-T:6]N(&1E(&PG:&5U<F4`5&EM;W(@;W)I96YT86P`
M5&ET<F4`5&ET<F4@*&EN9F]B=6QL92F@.@#``%!O=7(@<^EL96-T:6]N;F5R
M('!L=7-I975R<R!I=&5M<R#@(&QA(&9O:7,L(&UA:6YT96YE>B!E;F9O;F/I
M(&QE(&)O=71O;B"KH$-T<FR@NR`H4$,I(&]U(*N@0V]M;6%N9&6@NR`H36%C
M*2!E;B!C;&EQ=6%N="X`075J;W5R9"=H=6D`5F]I<B!L82!S;W5R8V4@2%1-
M3`!4;V=O`%1O:V5L874`1&5M86EN`%1O;F=A`$AA=70`0V%D<F4@9'4@:&%U
M="`H7W1O<"D`5')A9'5C=&EO;G,`5')I;FETZ2UE="U4;V)A9V\`5G)A:2!O
M=2!F875X`$UA`%1U;FES:64`5'5R<75I90!4=7)C("A)4T\M.#@U.2TY*0!4
M=7)K;>EN:7-T86X`SFQE<R!4=7)Q=65S(&5T($-A[W%U97,`5'5V86QU`$5N
M=')E>B!V;W1R92!C:&]I>*`Z(`!);F1I8V4@55:@.B``55),`%523"!P;W5R
M('9O=')E(')A<'!O<G0@9&4@;&EV<F%I<V]N(&1U('-C<FEP=`!54DPZ`$]U
M9V%N9&$`56MR86EN90!);7!O<W-I8FQE(&0G871T96EN9')E(&QE('+I<&5R
M=&]I<F4@5D93+@!);7!O<W-I8FQE(&0G86IO=71E<B!D97,@:6YF;W)M871I
M;VYS(&-O;7!LZ6UE;G1A:7)E<R#@(&PG:6YS8W)I<'1I;VXN`$EM<&]S<VEB
M;&4@9&4@;6]D:69I97(@;&5S('!E<FUI<W-I;VYS('!O=7(@;&4@9FEC:&EE
M<B!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(&UO9&EF:65R(&QE<R!P97)M
M:7-S:6]N<R!P;W5R(&QE(&9I8VAI97(@5D93("5S+R5S+@!);7!O<W-I8FQE
M(&1E(&-H86YG97(@<&]U<B`E<RX`26UP;W-S:6)L92!D92!VZ7)I9FEE<B!L
M82!T86EL;&4@9'4@9FEC:&EE<B!D92"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@
M=NER:69I97(@;&$@=&%I;&QE(&1U(&9I8VAI97(@9&4@JR`E<R\E<R"[+@!#
M;VYN97AI;VX@:6UP;W-S:6)L92!A=2!S97)V975R(%-13"X`0V]N;F5X:6]N
M(&EM<&]S<VEB;&4@96X@4U-,`$EM<&]S<VEB;&4@9&4@8V]P:65R('5N(&9I
M8VAI97(@5D93+@!);7!O<W-I8FQE(&1E(&-RZ65R('5N('+I<&5R=&]I<F4@
M5D93(*N@)7.@NRX`26UP;W-S:6)L92!D92!C<NEE<B!U;B!RZ7!E<G1O:7)E
M(%9&4RX`26UP;W-S:6)L92!D92!C<NEE<B!L92!F:6-H:65R(%9&4RX`26UP
M;W-S:6)L92!D92!C<NEE<B!L92!RZ7!E<G1O:7)E(%9&4R"KH"5SH+LN`$EM
M<&]S<VEB;&4@9&4@8W+I97(@=6X@9FEC:&EE<B!61E,@=FED92X@`$]U=F5R
M='5R92!I;7!O<W-I8FQE(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE+B``4W5P
M<')E<W-I;VX@:6UP;W-S:6)L92!D92"KH"5SH+LL(&QE(&1O<W-I97(@;B=E
M<W0@<&%S('9I9&4N`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@JZ`E<Z"[
MH#H@)7,`4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92"KH"5SH+N@.B`E<RX`
M4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92`E<RP@;&4@9&]S<VEE<B!N)V5S
M="!P87,@=FED90!3=7!P<F5S<VEO;B!RZ6-U<G-I=F4@9'4@9&]S<VEE<B!6
M1E,@:6UP;W-S:6)L92X`4W5P<')E<W-I;VX@9'4@<NEP97)T;VER92!61E,@
M:6UP;W-S:6)L92X`26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@<NEP97)T
M;VER92!61E.@.B`E<RX`4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!F:6-H
M:65R(%9&4R"KH"5SH+LN`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@9FEC
M:&EE<B!61E,N`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@<NEP97)T;VER
M92!61E,@JZ`E<Z"[+@!3=7!P<F5S<VEO;B!61E,@<NEC=7)S:79E(&EM<&]S
M<VEB;&6@.B`E<RX`26UP;W-S:6)L92!D92!DZ71E<FUI;F5R(&QE(&1O<W-I
M97(@8V]U<F%N="X`26UP;W-S:6)L92!D)V5X=')A:7)E(&QE<R!DZ71A:6QS
M(&1U(&-E<G1I9FEC870`26UP;W-S:6)L92!D92!C:&%R9V5R(&QA(&3I9FEN
M:71I;VX@9&4@)7,N`$EM<&]S<VEB;&4@9&4@9.EP;&%C97(@;&4@9FEC:&EE
M<B!61E,N`$EM<&]S<VEB;&4@9"=O=79R:7(@;&4@9FEC:&EE<B!61E,@JZ`E
M<Z"[+@!);7!O<W-I8FQE(&0G;W5V<FER('5N(&9I8VAI97(@5D93(&5N(.EC
M<FET=7)E+@!);7!O<W-I8FQE(&0G;W5V<FER('5N(&9I8VAI97(@5D93+@!/
M=79E<G1U<F4@:6UP;W-S:6)L92!D92!L)V%R8VAI=F4@8V]M<')E<W/I92X`
M26UP;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97(@5D93("CI8VAE8R!D92!F
M:6QE<VEZ92@I*2X`26UP;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97(@5D93
M("CI8VAE8R!D92!G971&:6QE4VEZ92@I*2X`26UP;W-S:6)L92!D92!L:7)E
M(&QE(&9I8VAI97*@.B``3&5C='5R92!D=2!RZ7!E<G1O:7)E(')A8VEN92!6
M1E,@:6UP;W-S:6)L92X`26UP;W-S:6)L92!D92!R96YO;6UE<B`E<R!E;B`E
M<Z`Z(&QE(&1O<W-I97(@8VEB;&4@97AI<W1E(&3I:N``26UP;W-S:6)L92!D
M92!R96YO;6UE<B!L92!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S:6)L92!D92!R
M96YO;6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z("5S+@!);7!O<W-I8FQE(&1E
M(')E;F]M;65R(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D
M92!R96YO;6UE<B!L92!F:6-H:65R(%9&4R`E<R\E<RX`26UP;W-S:6)L92!D
M92!R96YO;6UE<B!L92!F:6-H:65R(%9&4RX`26UP;W-S:6)L92!D)V5XZ6-U
M=&5R("=M:VES;V9S)RX`26UP;W-S:6)L92!D92!T<F%D=6ER92!C92!D;V-U
M;65N="!7;W)D+@!);7!O<W-I8FQE(&0GZ6-R:7)E(&QE(&9I8VAI97(@5D93
M(*N@)7.@NRX`26UP;W-S:6)L92!D)^EC<FER92!L97,@9&]N;NEE<R!D=2!F
M:6-H:65R(%9&4R`H8V]P>2@I(&EM<&]S<VEB;&4I+@!);7!O<W-I8FQE(&0G
MZ6-R:7)E(&QE<R!D;VYNZ65S(&1U(&9I8VAI97(@5D93+@!);7!O<W-I8FQE
M(&0GZ6-R:7)E(&QE(&9I8VAI97(@5D93+"!L92!Q=6]T82!S97)A:70@9.EP
M87-SZ2X`4V]U;&EG;F5R`$%N;G5L97(@;&5S(&-H86YG96UE;G1S`$%N;G5L
M92!V;W1R92!D97)N:>AR92!A8W1I;VX`4NEP;VYS92!I;F%T=&5N9'5E(&1U
M('-E<G9E=7(@;&]R<R!D92!L82!C;VYN97AI;VZ@.B``4NEP;VYS92!I;F%T
M=&5N9'5E(&1U('-E<G9E=7(@X*`Z(`!(;W)S(&-A=.EG;W)I90!5;FEC;V1E
M("A55$8M."D`R6UI<F%T<R!!<F%B97,@56YI<P!2;WEA=6UE+55N:0#)=&%T
M<RU5;FES`,YL97,@97ATZ7)I975R97,@9&5S(,ET871S+55N:7,`56YI=.ES
M`$EN8V]N;G4`87!I;7-G:60@:6YC;VYN=2`H05!)($UE<W-A9V4@240I+@!C
M;&EM<V=I9"!I;F-O;FYU("A#;&EE;G0@365S<V%G92!)1"DN`$5M<&QA8V5M
M96YT('/I;&5C=&EO;F[I(&EN8V]N;G4N`$YO;2!D)W5T:6QI<V%T975R(&]U
M(&UO="!D92!P87-S92!I;F-O;FYU+@!$Z6QI97(@;"?I;.EM96YT(&-O=7)A
M;G0`4V%N<R!N;VT`3&5S('-C<FEP=',@;F]N+7!R:79I;.EG:>ES(&YE('!E
M=79E;G0@86-CZ61E<B!A=7@@9F]N8W1I;VYS(&-O=7!E<B]C;W!I97(O8V]L
M;&5R('!O=7(@9&5S(')A:7-O;G,@9&4@<^EC=7)I=.DN($%P<'5Y97H@<W5R
M($]+('!O=7(@=F]I<B!U;F4@;F]T92!T96-H;FEQ=64@<W5R(&UO>FEL;&$N
M;W)G('%U:2!V;W5S(&5X<&QI<75E<F$@8V]M;65N="!A=71O<FES97(@=6X@
M<V-R:7!T(.`@=71I;&ES97(@;&4@<')E<W-E+7!A<&EE<G,`4F5M971T<F4@
M;&$@8V]U;&5U<B#@('KI<F\`17AT96YS:6]N(&YO;B!P<FES92!E;B!C;VUP
M=&4`36]D:69I97(`36]D:69I97(@)7,`36]D:69I97(@;"=U=&EL:7-A=&5U
M<@!-:7-E(.`@:F]U<B!D92"KH"5SH+LN`$QE('-C<FEP="!D92!M:7-E(.`@
M:F]U<B!E<W0@<W5P<')I;>D`0VAA<F=E<@!4;W5S(&QE<R!F:6-H:65R<R!D
M92!C;VYF:6=U<F%T:6]N(&1E<R!A<'!L:6-A=&EO;G,@;VYT(.ETZ2!E;G9O
M>>ES('-U<B!L92!S97)V975R+@!,971T<F5S(&QA=&EN97,@;6%J=7-C=6QE
M<P!.;VUB<F5S(')O;6%I;G,@;6%J=7-C=6QE<P!5<G5G=6%Y`$5M<&QO>>D@
M86-T=65L;&5M96YTH#H@)7,`571I;&ES97(@4U-,`%5T:6QI<V5R('-I(&QE
M(&YO;2!D)W5T:6QI<V%T975R+VUO="!D92!P87-S92!E<W0@9&EF9NER96YT
M(&1U('-E<G9E=7(@24U34"X`571I;&ES871E=7(`3"=U=&EL:7-A=&5U<B`E
M<R!N)V$@<&%S(&PG875T;W)I<V%T:6]N('!O=7(@)7,N`$%D;6EN:7-T<F%T
M:6]N(&1E<R!U=&EL:7-A=&5U<G,`4'+I9NER96YC97,@<&5R<V]N;F5L;&5S
M`$5N<F5G:7-T<F5M96YT(&1E<R!U=&EL:7-A=&5U<G,`3"=E;G)E9VES=')E
M;65N="!D)W5T:6QI<V%T975R(&5S="!DZ7-A8W1I=ND@<W5R(&-E('-Y<W3H
M;64N`$-O;7!T92!U=&EL:7-A=&5U<B!N;VX@=')O=7;I`$YO;2!D)W5T:6QI
M<V%T975R`$QE(&YO;2!D92!C;VYN97AI;VX@JZ`E<Z"[(&5X:7-T92!DZ6K@
M+@!.;VT@9"=U=&EL:7-A=&5U<J`Z`$YO;2!D)W5T:6QI<V%T975RH#H@`%5T
M:6QI<V%T975R<R!DZ69I;FESH#H`3W5Z8NEK:7-T86X`4NEP97)T;VER92!6
M1E,@:6YE>&ES=&%N="X`06)S96YC97,`3&5S(&5M<&QA8V5M96YT<R!V86QI
M9&5S('1R;W5VZ7,@:6YC;'5E;G2@.B``5F%L:61I=.D`5F%L975R(&5N(&UI
M;G5T97,@X"!P87)T:7(@9&4@;6%I;G1E;F%N="X`5F%L975R('-U<.ER:65U
M<F4@X"!L82!L;VYG=65U<B!M87AI;6%L92!D92`E<RX`5F%L975R<P!686QE
M=7)S(.`@<^EL96-T:6]N;F5R(&1E`%9A;G5A='4`5F%R:6%B;&4`5NENZ7IU
M96QA`,EC:&5C(&1E(&QA(';I<FEF:6-A=&EO;B`F;61A<V@[(&-E(&UE<W-A
M9V4@82!P975T+>IT<F4@Z73I(&9A;'-I9FGI+@!697)S:6]N`$-O;G1R]&QE
M(&1E('9E<G-I;VX`06QI9VYE;65N="!V97)T:6-A;`!296UP;&ES<V%G92!V
M97)T:6-A;`!697)T:6-A;*`Z`%1RZ',@:&%U=&4`5FEE=&YA;0!6:>IT+6YA
M;6EE;B`H5DE30TE)*0!6;VER("5S`%9O:7(@=6YE('!A9V4@=V5B(&5X=&5R
M;F4`5F]I<B!C;VUM92`E<P#.;&5S(%9I97)G97,@8G)I=&%N;FEQ=65S`,YL
M97,@5FEE<F=E<R!D97,@R71A=',M56YI<P!6:7-I8FEL:73I`%9I<VEB:6QI
M=.F@.B``5F]D869O;F4@271A;'D@=FEA(%--5%``3D]424-%`$%45$5.5$E/
M3B$A(2`@4U504%))3452($Q%(%-#4DE05"!-04Y514Q,14U%3E0@1$4@)7,`
M5TE.('9I82!(5%10`%=A;&QI<R!E="!&=71U;F$`071T96YT:6]N`$UE`%!R
MZ79I<VEO;G,@;>ETZ6\`1&]N;NEE<R!MZ73I;R!F;W5R;FEE<R!P87(`5V5A
M=&AE<BYC;VT`5V5B`%-I=&4@=V5B`$-H87%U92!S96UA:6YE`$)I96YV96YU
M90!":65N=F5N=64@X"`E<P!":65N=F5N=64L("5S`$]C8VED96YT86P@*$E3
M3RTX.#4Y+3$I`$]C8VED96YT86P@*$E33RTX.#4Y+3$U*0!386AA<F$@3V-C
M:61E;G1A;`!1=65L;&4@87!P;&EC871I;VX@)7,@9&]I="UI;"!P<NES96YT
M97(@87!RZ',@;&$@8V]N;F5X:6]NH#\`475E;"!E<W0@;&4@8V%R86-TZ')E
M(&1E('/I<&%R871I;VZ@/P!1=65L(&5S="!L92!C87)A8W3H<F4@9&4@8VET
M871I;VZ@/P!#87)T92!7:&5R96ES($%U<W1R86QI90#`('%U96P@8V%L97!I
M;B!F875T+6EL(&%J;W5T97(@;&5S(&YO=&5SH#\`475E;&QE<R!P:&%S97,`
M475E;&QE<R!E>'1E;G-I;VYS(&%C=&EV97(@<&]U<B!L)^ED:71E=7(@4FEC
M:"!497AT+@!,87)G975R`$QA<F=E=7(@96X@=6YI=.ES($-34P!,87)G975R
M(&1U(&UE;G4@9&4@9V%U8VAE("5S("`H;&$@8V]N9FEG=7)A=&EO;B!P<F5N
M9')A(&5F9F5T(.`@;&$@<')O8VAA:6YE(&-O;FYE>&EO;BF@.@!,87)G975R
M(&1U('1A8FQE874`56YI=.D@9&4@;&%R9V5U<@!,87)G975RH#H`5VEK:0!6
M96YT`%9E;G0@=/1T(&QE(&UA=&EN`%9I=&5S<V4@9'4@=F5N="!E;B!N)F]E
M;&EG.W5D<P!696YTH#H`5F5N=*`Z(`!386=E<W-E`$QI<W1E(&1E('8F;V5L
M:6<[=7@`5')A=F%I;`!!9')E<W-E('!R;V9E<W-I;VYN96QL90!4Z6SI<&AO
M;F4@<')O9F5S<VEO;FYE;`!.;VUB<F4@9&4@8VAA;7!S(&EN8V]R<F5C="#@
M(&QA(&QI9VYE("5D+B`E9"!A='1E;F1U<RP@)60@=')O=7;I<RX`3F]M8G)E
M(&1E(&-H86UP<R!I;F-O<G)E8W0N("5D(&%T=&5N9'5S+"`E9"!T<F]U=NES
M+@!$Z6-A;&%G92`E9"!I;F-O<G)E8W0@;&]R<R!D92!L82!L96-T=7)E(&1E
M(&9I8VAI97(@5D93+@!8+5)E9@!#;VYT<F%I;G1E<R!B87-I<75E<R!8-3`Y
M=C,`571I;&ES871I;VX@9&4@8VSI(.ET96YD=64@6#4P.78S`$%U=')E(&YO
M;2!D=2!S=6IE="!8-3`Y=C,`261E;G1I9FEA;G0@9&4@8VSI(&1U('-U:F5T
M(%@U,#EV,P!%>'1E;G-I;VYS(%@U,#EV,P!!00!!04%!`$-A<G1E(*N@66%H
M;V^@(:"[`$%N;G5E;&QE;65N=`!9Z6UE;@!/=6D`3W5I+"!J)V%C8V5P=&4`
M5F]U<R#J=&5S(&5N(&UO9&4@JZ!497AT9:"[+B!5=&EL:7-E>B!L92!B;W5T
M;VX@6SP^72!P;W5R(')E=F5N:7(@874@;6]D92"KH%=94TE764>@NRX`5F]U
M<R!N)^IT97,@<&%S(&%U=&]R:7/I(.`@8W+I97(@<&QU<R!D92`E9"!B;&]C
M<RX`5F]U<R!N)^IT97,@<&%S(&%U=&AE;G1I9FGI+@!6;W5S(&YE('!O=79E
M>B!P87,@879O:7(@;&4@8V%R86-TZ')E(*M<NR!D86YS('9O=')E(&YO;2!C
M;VUP;&5T+@!6;W5S(&XG879E>B!P87,@<V%I<VD@=6YE(&%D<F5S<V4@Z6QE
M8W1R;VYI<75E('9A;&ED92X`5F]U<R!N)V%V97H@<&%S(&%S<V]C:>D@;&5S
M(&-H86UP<R!D=2!F:6-H:65R(&EM<&]R=.D@875X(&-H86UP<R!C;W)R97-P
M;VYD86YT<R!D86YS("5S+@!6;W5S(&XGZG1E<R!P87,@875T;W)I<^D@X"!C
M;VYS=6QT97(@;&4@8FQO8RUN;W1E<R`E<RX`5F]U<R!A=F5Z(.ETZ2!DZ6-O
M;FYE8W3I+@!6;W5S(&1E=F5Z(&EN<V-R:7)E('5N(&YU;>ER;R!D92!C96QL
M=6QA:7)E('9A;&ED92P@<V5U;',@9&5S(&YO;6)R97,@970@=6X@JRN[(&]P
M=&EO;FYE;"!P;W5R(&QE<R!A<'!E;',@:6YT97)N871I;VYA=7@N`%9O=7,@
M;B=A=F5Z('!A<R!S86ES:2!U;F4@96YT<NEE('9A;&ED92X`5F]U<R!D979E
M>B!C;VYF:6=U<F5R('5N(&)A8VME;F0@1&%T851R964@<&]U<B!U=&EL:7-E
M<B!L97,@:6YS8W)I<'1I;VYS`%9O=7,@9&5V97H@8V]N9FEG=7)E<B!U;B!M
M;V1U;&4@5D93+@!6;W5S(&1E=F5Z(&3I8W)I<F4@;&4@<')O8FSH;64@879A
M;G0@9&4@;F]U<R!F86ER92!P87)V96YI<B!L92!R87!P;W)T+@!6;W5S(&1E
M=F5Z(&5N=')E<B!U;F4@55),(&_Y('!O:6YT92!D92!L:65N+@!);"!F875T
M(&0G86)O<F0@<^EL96-T:6]N;F5R(&QE(&)L;V,M;F]T97,@X"!S=7!P<FEM
M97(N`$EL(&9A=70@<^EL96-T:6]N;F5R('5N('-E<G9E=7(@X"!S=7!P<FEM
M97(N`%9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T:6QI<V%T975R(.`@<F5T
M:7)E<BX@`%9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T:6QI<V%T975R(.`@
M<F5T:7)E<BX`5F]U<R!D979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@
MX"!A:F]U=&5R+@!6;W5S(&1E=F5Z('-PZ6-I9FEE<B!L92!N;VT@9&4@;"=U
M=&EL:7-A=&5U<B#@(&UO9&EF:65R+@!6;W5S(&1E=F5Z(&EN9&EQ=65R('%U
M96QL92!A8W1I;VX@86-C;VUP;&ER+@!6;W5S(&1E=F5Z(.EC<FER92!U;B!N
M;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R:64N`%9O=7,@9&5V97H@9F]U
M<FYI<B!U;B!NL"!D92!TZ6SI<&AO;F4@:71A;&EE;@!6;W1R92!S97-S:6]N
M("5S(&$@97AP:7+I+B!6975I;&QE>B!V;W5S(')E8V]N;F5C=&5R+@!6;W1R
M92!A9')E<W-E(&1E(&-O=7)R:65L`%9O=')E(&%D<F5S<V4@9&4@8V]U<G)I
M96P@JR!$93H@NZ`Z`%9O<R!D;VYNZ65S('!E<G-O;FYE;&QE<P!6;W1R92!A
M9')E<W-E($EN=&5R;F5T(&$@8VAA;F?I(&1E<'5I<R!L)V]U=F5R='5R92!D
M92!V;W1R92!S97-S:6]N("5S+B`@4&]U<B!V;W1R92!SZ6-U<FETZ2P@=F]U
M<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+@!6;W1R92!N;VT`5F]T<F4@;6]D
M=6QE(&0G875T:&5N=&EF:6-A=&EO;B!N92!S=7!P;W)T92!P87,@;"=A:F]U
M="!D)W5T:6QI<V%T975R<RP@4VD@=F]U<R!S;W5H86ET97H@=71I;&ES97H@
M2&]R9&4@<&]U<B!A9&UI;FES=')E<B!L97,@8V]M<'1E<R!U=&EL:7-A=&5U
M<G,L('9O=7,@9&5V97H@=71I;&ES97(@=6X@875T<F4@;6]D=6QE(&0G875T
M:&5N=&EF:6-A=&EO;BX`5F]T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO
M;B!N)V5S="!P87,@96X@;65S=7)E(&0GZ71A8FQI<B!U;F4@;&ES=&4@9&5S
M('5T:6QI<V%T975R<RP@;W4@8V5T=&4@9F]N8W1I;VX@82#I=.D@<F5T:7+I
M92!P;W5R('5N92!A=71R92!R86ES;VXN`%9O=')E(&YA=FEG871E=7(@<V5M
M8FQE(&%V;VER(&-H86YGZ2!D97!U:7,@;&4@9.EB=70@9&4@=F]T<F4@<V5S
M<VEO;B`E<RX@(%!O=7(@=F]T<F4@<^EC=7)I=.DL('9O=7,@9&5V97H@=F]U
M<R!R96-O;FYE8W1E<BX`5F]T<F4@;F%V:6=A=&5U<B!N92!S=7!P;W)T92!P
M87,@8V5T=&4@;W!T:6]N`%9O=')E(&YA=FEG871E=7(@;F4@<')E;F0@<&%S
M(&5N(&-O;7!T92!C971T92!O<'1I;VX@9"=I;7!R97-S:6]N+B!0<F5S<V5Z
M($-O;G1R]&QE+T-O;6UA;F1E("L@4"!P;W5R(&EM<')I;65R`%9O=')E(&9U
M<V5A=2!H;W)A:7)E(&%C='5E;*`Z`%9O=')E('!R;V9I;"!P87(@9.EF875T
M(&$@Z73I(&UO9&EF:>DN`%!R;V9I;"!P87(@9.EF875TH#H`5F]T<F4@8FQO
M8RUN;W1E<R!P87(@9.EF875TH#H`5F]T<F4@;F]M(&-O;7!L972@.@!6;W1R
M92!C;VUP=&4@82!E>'!I<NDN`%9O=')E(&YO=79E874@;6]T(&1E('!A<W-E
M('!O=7(@)7,@97-TH#HE<P!6;W,@8FQO8W,M;F]T97.@.@!6;W,@;W!T:6]N
M<R!O;G0@Z73I(&UI<V5S(.`@:F]U<B!P;W5R(&QA(&1U<NEE(&1E(&-E='1E
M('-E<W-I;VXN`%9O<R!O<'1I;VYS(&]N="#I=.D@;6ES97,@X"!J;W5R+@!6
M;W1R92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@X"!ZZ7)O`%9O=')E(&UO
M="!D92!P87-S92!A(.ETZ2!R96UI<R#@('KI<F\L(';I<FEF:65R('9O=')E
M(&-O=7)R:65R(&5T(&-O;FYE8W1E>BUV;W5S(&%V97H@=F]T<F4@;F]U=F5A
M=2!M;W0@9&4@<&%S<V4N`%9O=')E(&UO="!D92!P87-S92!A(&5X<&ERZ2X`
M5F]S('-E<G9E=7)S(&1I<W1A;G1SH#H`66]U9V]S;&%V:64`6F'O<F4`6F%M
M8FEE`%II;6)A8G=E`%II<'!Y`%M#86-H97(@;&5S(&-I=&%T:6]N<UT`6U)A
M<'!O<G0@9&4@<')O8FSH;65=`%M!9F9I8VAE<B!L92!T97AT92!C:73I("T`
M6T%F9FEC:&5R(&QE('1E>'1E(&-I=.D@+2`E<R!L:6=N97-=`%ML:6=N92`E
M<R!D92`E<UT`7T%D;6EN:7-T<F%T:6]N`%)E=F5N:7(@X"!?3F]T97,`3&EG
M;F4@9&4@7V-O;6UA;F1E`%]#873I9V]R:64`7T1A=&%4<F5E`%]3=7!P<FEM
M97(`4W5P<')I;65R(&QA(%]R86YGZ64`36]D:69I7V5R`%]0<F5M:>AR92!L
M:6=N90!?1W)O=7!E<P!?06ED90!0<F]P<E]IZ73I<R!D92!L)VEM86=E+BXN
M`%]);7!O<G1E<B]%>'!O<G1E<@!!9F9I8VAE<B!?;&5S(&YO=&5S`%]#;VYN
M97AI;VX`7T3I8V]N;F5X:6]N`%]-;V1I9FEE<B!U;B!L:65N('=E8BXN+@!?
M365S(&)L;V,M;F]T97,`7TYO=79E;&QE(&YO=&4`7T]P=&EO;G,`7U!E<FUI
M<W-I;VYS`$EM7W!R:6UE<@!?4F5T:7)E<B!U;B!L:65N`%]296-H97)C:&4`
M7T-O;F9I9W5R871I;VX`4')O<')IZ73I<R!D=2!?=&%B;&5A=0!?571I;&ES
M871E=7)S`&-A<FYE="!D)V%D<F5S<V5S`&1E<W1I;F%T86ER92!I;F-O;FYU
M`&%G96YD80!C86QM90!I;7!O<W-I8FQE(&1E(&-RZ65R(&QE(&9I8VAI97(@
M9&4@<V]R=&EE`&EM<&]S<VEB;&4@9"=O=79R:7(@;"=E;G1RZ64`8VQI<75E
M>B!I8VD`97)R975R(&0G=71I;&ES871I;VX@9&4@;&$@;&EG;F4@9&4@8V]M
M;6%N9&4`97)R975R(&1E(&-O;F9I9W5R871I;VX`86)S96YC92!C<FET:7%U
M92!D)W5N(&9I8VAI97(@<WES=.AM90!E<G)E=7(@9&4@9F]R;6%T(&1E(&1O
M;F[I90!E;G1RZ64@;F]N('1R;W5VZ0!T;VUB86YT`&9I8VAI97(`9&5P=6ES
M(&QE("5S("@E<RD@X"`E<R`E<P!E;B!R869A;&4`:*`Z`&AH`&YO;2!D)VCT
M=&4@:6YC;VYN=0!I;6WI9&EA=&5M96YT`&EN8V]R<&]RZ64`97)R975R(&0G
M96YT<NEE+W-O<G1I90!E<G)E=7(@;&]G:6-I96QL92!I;G1E<FYE`&QI9VYE
M<UT`97)R975R(&UK:7-O9G,@8V]D92`E9"!E;B!C<NEA;G0@;"=)4T\`;6T`
M;F]M`&YO;B!P<FES(&5N(&-O;7!T90!P87,@96YC;W)E('!R:7,@96X@8V]M
M<'1E`&)L;V,M;F]T97,`;F]T97,N8W-V`'!O=7)C96YT86=E`'!E<FUI<W-I
M;VX@<F5F=7/I90!P:7AE;',`97)R975R(&1I<W1A;G1E(&1A;G,@;&4@<')O
M=&]C;VQE`',GZ6QE=F%N=`!S97)V:6-E(&YO;B!D:7-P;VYI8FQE+@!M;VYT
M<F5R(&QE<R!D:69FZ7)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`9FEX
M90!E<G)E=7(@<WES=.AM90!L:7-T92!D92!TXF-H97,`Z6-H96,@=&5M<&]R
M86ER90!E;G1R97H@;&4@;6]T(&1E('!A<W-E(&1E=7@@9F]I<R!P;W5R(&-O
M;F9I<FUE<@!U;FEF:>D`<V%N<R!N;VT`4^EL96-T:6]N(&0G=71I;&ES871E
M=7(`=D-A<F0`=DYO=&4`;*`Z`'=E871H97(N8V]M````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O:'5?2%4O
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S0T`#`R,#`P-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN
M96UO+VQO8V%L92]H=5](52],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(Q-3<S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+VAU7TA5+TQ#7TU%4U-!1T53
M+VUN96UO+FUO```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0T,S`P,``Q,#0Q-S,V,C<T
M-``P,C,R-#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````#D!P``'````#P_``"%"@``7'X```````!PJ```#@``
M`'&H```/````@*@```T```"0J```"````)ZH```+````IZ@```P```"SJ```
M!````,"H```8````Q:@``!L```#>J```+0```/JH```=````**D``"0```!&
MJ0``*0```&NI```9````E:D``"8```"OJ0``#````-:I```D````XZD```@`
M```(J@``#P```!&J```+````(:H```X````MJ@``*````#RJ```(````9:H`
M``H```!NJ@``%0```'FJ```2````CZH```L```"BJ@``#0```*ZJ```=````
MO*H``(4```#:J@``#@```&"K```*````;ZL```T```!ZJP``#@```(BK```1
M````EZL```T```"IJP``#````+>K```-````Q*L``)0```#2JP``"@```&>L
M```/````<JP``!@```""K```#````)NL```&````J*P```X```"OK```#@``
M`+ZL```(````S:P```D```#6K```+@```."L```:````#ZT``#(````JK0``
M.````%VM``!4````EJT``%$```#KK0``6@```#VN``!7````F*X``#0```#P
MK@``"0```"6O```-````+Z\```<````]KP``"@```$6O```/````4*\```4`
M``!@KP``!@```&:O```1````;:\```@```!_KP``"0```(BO```)````DJ\`
M`"4```"<KP``(````,*O```<````XZ\``!X`````L```(````!^P```=````
M0+```!,```!>L```$````'*P```/````@[````H```"3L````P```)ZP```/
M````HK```!0```"RL```"0```,>P```-````T;```!(```#?L```&0```/*P
M```>````#+$```\````KL0``#````#NQ```*````2+$```\```!3L0``"```
M`&.Q```D````;+$``!0```"1L0``%@```*:Q```(````O;$``$X```#&L0``
M+0```!6R```1````0[(``!D```!5L@``!P```&^R```,````=[(``"P```"$
ML@``#@```+&R```#````P+(```L```#$L@``!P```-"R```'````V+(```4`
M``#@L@``!0```.:R```*````[+(```,```#WL@``%P```/NR```*````$[,`
M``\````>LP``#@```"ZS```8````/;,``",```!6LP``#@```'JS```4````
MB;,``!<```">LP``%P```+:S```7````SK,``!,```#FLP``#P```/JS```.
M````"K0``!\````9M```'0```#FT```'````5[0```8```!?M```"````&:T
M```/````;[0```8```!_M```"@```(:T```3````D;0```L```"EM```$```
M`+&T```5````PK0``!4```#8M```!P```.ZT```0````]K0```4````'M0``
M%0````VU```1````([4```P````UM0``.P```$*U```X````?K4```D```"W
MM0``!P```,&U```4````R;4```,```#>M0``!0```.*U```)````Z+4``!``
M``#RM0``"0````.V```3````#;8``#D````AM@``$@```%NV```G````;K8`
M`"P```"6M@``*@```,.V```E````[K8```H````4MP``!@```!^W```)````
M)K<```<````PMP``+P```#BW```W````:+<``"X```"@MP``50```,^W```M
M````);@``"T```!3N```/0```(&X```_````O[@``"T```#_N```0````"VY
M```C````;KD``",```"2N0``0````+:Y```M````][D``#,````EN@``)0``
M`%FZ```5````?[H``!D```"5N@``*0```*^Z```D````V;H``"@```#^N@``
M%0```">[```1````/;L```H```!/NP``#````%J[```/````9[L``!<```!W
MNP``"@```(^[```0````FKL``!8```"KNP``%@```,*[```'````V;L```<`
M``#ANP``%````.F[```*````_KL```@````)O```)P```!*\```(````.KP`
M``<```!#O```!P```$N\```&````4[P```4```!:O```!P```&"\```&````
M:+P```@```!OO```*0```'B\```.````HKP```H```"QO```!````+R\```'
M````P;P```D```#)O```!@```-.\```1````VKP```<```#LO```%@```/2\
M```$````"[T```@````0O0``!@```!F]```-````(+T```8````NO0``'@``
M`#6]```1````5+T```@```!FO0``#0```&^]```,````?;T```<```"*O0``
M`P```)*]```#````EKT``!<```":O0```P```+*]```3````MKT``!T```#*
MO0``"````.B]```$````\;T```@```#VO0``"````/^]``!!````"+X``!H`
M``!*O@``*P```&6^```@````D;X``!4```"RO@``!@```,B^```&````S[X`
M`!4```#6O@``&````.R^```B````!;\``"X````HOP``'0```%>_```A````
M=;\``%0```"7OP``*0```.R_```*````%L````<````AP```!P```"G````5
M````,<````@```!'P```#@```%#````*````7\````\```!JP```#0```'K`
M```/````B,````T```"8P```"0```*;````4````L,````8```#%P```&```
M`,S````=````Y<```!,````#P0``$0```!?!```4````*<$```0````^P0``
M!@```$/!```4````2L$``%0```!?P0``+0```+3!``!D````XL$```0```!'
MP@``#@```$S"```%````6\(```4```!AP@``&P```&?"```:````@\(``!,`
M``">P@``$0```++"```1````Q,(``!P```#6P@``*@```//"```W````'L,`
M`!P```!6PP``$````'/#```A````A,,```4```"FPP``"@```*S#```3````
MM\,```L```#+PP``$@```-?#```*````ZL,```\```#UPP``#0````7$```1
M````$\0``!,````EQ```#````#G$```&````1L0```P```!-Q```!@```%K$
M```7````8<0``!````!YQ```$0```(K$```(````G,0```4```"EQ```#```
M`*O$```0````N,0```4```#)Q```#0```,_$```&````W<0```<```#DQ```
M#0```.S$```'````^L0```L````"Q0``!P````[%```'````%L4```D````>
MQ0``"0```"C%```*````,L4``!D````]Q0``/0```%?%```=````E<4```P`
M``"SQ0``$````,#%```%````T<4``"4```#7Q0``$@```/W%```3````$,8`
M`"L````DQ@``.P```%#&```@````C,8```@```"MQ@``-@```+;&```A````
M[<8``!`````/QP``"````"#'```,````*<<```8````VQP``!````#W'```/
M````0L<```X```!2QP``!P```&''```*````:<<```T```!TQP``'P```(+'
M```<````HL<``"$```"_QP``'@```.''```9`````,@``!X````:R```&P``
M`#G(```A````5<@``"X```!WR```)@```*;(```<````S<@``!X```#JR```
M'`````G)```F````)LD``"L```!-R0``,P```'G)```F````K<D``"L```#4
MR0``.`````#*```=````.<H``!4```!7R@``+P```&W*```@````G<H``!(`
M``"^R@``*0```-'*```>````^\H``"`````:RP``$@```#O+``"B````3LL`
M`!8```#QRP``(P````C,```H````+,P``"D```!5S```*````'_,```?````
MJ,P``!4```#(S```(````-[,```E````_\P``"@````ES0``+0```$[-```P
M````?,T``)(```"MS0``(0```$#.```6````8LX``!P```!YS@``)@```);.
M```J````O<X``$$```#HS@``1````"K/```,````;\\```<```!\SP``!P``
M`(3/```&````C,\```T```"3SP``$````*'/```2````LL\```<```#%SP``
M$P```,W/```2````X<\```<```#TSP``!````/S/```0`````=```!`````2
MT```#````"/0```.````,-````T````_T```#P```$W0```3````7=````T`
M``!QT```*````'_0```#````J-````T```"LT```!@```+K0```1````P=``
M`!<```#3T```&P```.O0```.````!]$```(````6T0``20```!G1```%````
M8]$``!````!IT0``#P```'K1```$````BM$```T```"/T0``#@```)W1```#
M````K-$```X```"PT0``"````+_1```/````R-$```\```#8T0``!P```.C1
M```-````\-$``!````#^T0``#P````_2```-````'](``!D````MT@``&@``
M`$?2```+````8M(```8```!NT@``"P```'72```3````@=(```P```"5T@``
M"@```*+2```1````K=(``!D```"_T@``%P```-G2```+````\=(```T```#]
MT@``(@````O3```/````+M,``!L````^TP``-````%K3```*````C],``!@`
M``":TP``$@```+/3```9````QM,``!8```#@TP``$````/?3```B````"-0`
M``T````KU```!P```#G4```*````0=0``!0```!,U```"P```&'4```,````
M;=0``"(```!ZU```+P```)W4```+````S=0```D```#9U```&0```./4```+
M````_=0``!<````)U0``%P```"'5```)````.=4``!8```!#U0``#P```%K5
M```9````:M4``!8```"$U0``#@```)O5```8````JM4```@```##U0``#0``
M`,S5```F````VM4``"@````!U@``0P```"K6```(````;M8``!(```!WU@``
M'P```(K6```(````JM8```L```"SU@``+P```+_6```.````[]8```4```#^
MU@``!@````37``!%````"]<```,```!1UP``!P```%77```$````7=<```D`
M``!BUP``"@```&S7```*````=]<```D```""UP``#P```(S7```0````G-<`
M`!<```"MUP``&@```,77```1````X-<``!D```#RUP``%P````S8```)````
M)-@```4````NV```"P```#38```*````0-@```(```!+V```!0```$[8```-
M````5-@``!L```!BV```%P```'[8```4````EM@```D```"KV```"@```+78
M```.````P-@```T```#/V```$@```-W8```X````\-@``"`````IV0``"```
M`$K9```.````4]D``'L```!BV0``&````-[9```8````]]D``!$````0V@``
M!P```"+:```%````*MH``!@````PV@``'@```$G:```;````:-H``!D```"$
MV@``&P```)[:```9````NMH``!,```#4V@``!P```.C:```(````\-H```8`
M``#YV@``!@````#;```0````!]L```\````8VP``$````"C;```/````.=L`
M``L```!)VP``#P```%7;```,````9=L```\```!RVP``!P```(+;```&````
MBML```X```"1VP``#````*#;```H````K=L```\```#6VP``"````.;;```&
M````[]L```P```#VVP``"`````/<```3````#-P```H````@W```'@```"O<
M```A````2MP``"````!LW```&0```(W<```7````I]P``"4```"_W```%P``
M`.7<```6````_=P```0````4W0``&P```!G=```-````-=T```P```!#W0``
M`P```%#=```%````5-T```@```!:W0``"@```&/=```,````;MT```L```![
MW0``$````(?=```,````F-T```X```"EW0``!````+3=```$````N=T``!,`
M``"^W0``%````-+=```,````Y]T```D```#TW0``#@```/[=```+````#=X`
M`!L````9W@``!P```#7>```'````/=X```H```!%W@``#0```%#>```)````
M7MX```0```!HW@```P```&W>```8````<=X```H```"*W@``!````)7>```F
M````FMX```X```#!W@``?````-#>```5````3=\```4```!CWP``!P```&G?
M```,````<=\```@```!^WP``"@```(??```&````DM\```@```"9WP```@``
M`*+?```&````I=\```8```"LWP``%````+/?```-````R-\``!````#6WP``
M&P```.??```$`````^````D````(X```$````!+@```)````(^````D````M
MX```!0```#?@```:````/>````@```!8X```!@```&'@```/````:.```!D`
M``!XX```#@```)+@```'````H>````<```"IX```!0```+'@```)````M^``
M``H```#!X```#@```,S@```"````V^````8```#>X```"P```.7@```-````
M\>````D```#_X```!@````GA```2````$.$```D````CX0``!P```"WA```4
M````->$``!T```!*X0``0@```&CA```E````J^$``"4```#1X0``!@```/?A
M```*````_N$```0````)X@``"0````[B```(````&.(``!$````AX@``"0``
M`#/B```&````/>(```T```!$X@``!@```%+B```Y````6>(``#T```"3X@``
M.@```-'B```>````#.,```4````KXP``#@```#'C```$````0.,```8```!%
MXP``!P```$SC```A````5.,```T```!VXP``%0```(3C```&````FN,```0`
M``"AXP``$0```*;C```&````N.,```H```"_XP``(@```,KC```$````[>,`
M``4```#RXP``'0```/CC```$````%N0```P````;Y```#@```"CD```*````
M-^0```@```!"Y```"0```$OD```%````5>0``#H```!;Y```,````);D```U
M````Q^0``"D```#]Y```1P```"?E```X````;^4``"D```"HY0``/P```-+E
M```N````$N8``"T```!!Y@``'P```&_F```/````C^8``!(```"?Y@``"P``
M`++F```F````ON8``"D```#EY@``)`````_G```F````-.<```@```!;YP``
M"@```&3G```)````;^<```<```!YYP``(````('G```@````HN<``"8```##
MYP``"@```.KG```9````]><``"D````/Z```%@```#GH```2````4.@```<`
M``!CZ```"@```&OH```,````=N@```\```"#Z```$````)/H``!`````I.@`
M`'````#EZ```9@```%;I```.````O>D```D```#,Z0``"@```-;I```2````
MX>D``!,```#TZ0``#`````CJ```&````%>H``!4````<Z@``#P```#+J```3
M````0NH``!(```!6Z@``$````&GJ```1````>NH``!P```",Z@``(P```*GJ
M``!J````S>H```\````XZP``!0```$CK```0````3NL```D```!?ZP``!```
M`&GK```+````;NL``"````!ZZP``%````)OK```,````L.L```P```"]ZP``
M#P```,KK```5````VNL``"D```#PZP``*@```!KL```F````1>P``"<```!L
M[```*0```)3L```J````ONP``!D```#I[```0@````/M```1````1NT``!(`
M``!8[0``$P```&OM```4````?^T```\```"4[0``%@```*3M```7````N^T`
M`!````#3[0``$0```.3M```T````]NT``!,````K[@``$@```#_N```U````
M4NX``!0```"([@``!P```)WN```,````I>X``"````"R[@``$````-/N```4
M````Y.X``!$```#Y[@``%P````OO```<````(^\``!,```!`[P``%````%3O
M```:````:>\``!$```"$[P``&@```);O```>````L>\``!H```#0[P``$P``
M`.OO```5````_^\``!$````5\```%P```"?P```4````/_```!<```!4\```
M%0```&SP```)````@O```!````",\```&0```)WP```$````M_````<```"\
M\```"P```,3P```1````T/````8```#B\```!@```.GP```&````\/````4`
M``#W\```!P```/WP```'````!?$```4````-\0``%@```!/Q```&````*O$`
M``8````Q\0``!````#CQ```$````/?$```<```!"\0``#@```$KQ```,````
M6?$```P```!F\0``#0```'/Q```*````@?$```X```",\0``!0```)OQ```H
M````H?$```X```#*\0``#````-GQ```/````YO$```H```#V\0``"`````'R
M```)````"O(``"L````4\@``!````$#R```(````1?(``"8```!.\@``$@``
M`'7R```/````B/(```8```"8\@``"@```)_R```'````JO(```@```"R\@``
M(````+OR```)````W/(```T```#F\@``%````/3R```,````"?,```T````6
M\P``#@```"3S```6````,_,``!$```!*\P``!@```%SS```#````8_,```8`
M``!G\P``&0```&[S```'````B/,```0```"0\P``"P```)7S```+````H?,`
M``<```"M\P``!0```+7S```'````N_,``!8```##\P``#0```-KS```-````
MZ/,```H```#V\P``$`````'T```/````$O0``!$````B]```%P```#3T```*
M````3/0``!$```!7]```!````&GT```/````;O0``#H```!^]```!0```+GT
M```,````O_0``!X```#,]```#@```.OT```0````^O0```L````+]0``#```
M`!?U```)````)/4```<````N]0``"@```#;U```)````0?4```X```!+]0``
M$````%KU```;````:_4``!@```"']0``&@```*#U```*````N_4```D```#&
M]0``"@```-#U```,````V_4```\```#H]0``"````/CU```&`````?8``!P`
M```(]@``!P```"7V```%````+?8```L````S]@``1P```#_V```-````A_8`
M``D```"5]@``!````)_V```#````I/8``!,```"H]@``$P```+SV```3````
MT/8```H```#D]@```@```._V```$````\O8``"4```#W]@```P```!WW```%
M````(?<``"H````G]P``"@```%+W```%````7?<```0```!C]P``"@```&CW
M```-````<_<```8```"!]P``"````(CW```(````D?<```0```":]P``!0``
M`)_W``!H````I?<```D````.^```#````!CX```0````)?@```4````V^```
M!@```#SX```;````0_@``"\```!?^```$````(_X```*````H/@```\```"K
M^```"@```+OX```)````QO@``!,```#0^```&P```.3X```8`````/D``!<`
M```9^0``%P```#'Y```?````2?D```X```!I^0```P```'CY```'````?/D`
M``@```"$^0``!P```(WY```)````E?D```H```"?^0``"P```*KY```'````
MMOD``%$```"^^0``$````!#Z```,````(?H```T````N^@``&@```#SZ``!*
M````5_H``!D```"B^@``!@```+SZ```:````P_H``"4```#>^@``!@````3[
M```&````"_L``!\````2^P``!@```#+[```)````.?L``!@```!#^P``%P``
M`%S[```H````=/L```8```"=^P``#0```*3[```B````LOL``%<```#5^P``
M$P```"W\```C````0?P``!,```!E_````@```'G\```+````?/P```@```"(
M_```#0```)'\```*````G_P```P```"J_```!P```+?\```4````O_P```8`
M``#4_```"````-O\```.````Y/P```<```#S_```"@```/O\```+````!OT`
M`#(````2_0``!P```$7]```,````3?T```T```!:_0``#````&C]```)````
M=?T```D```!__0``"@```(G]```'````E/T```D```"<_0``!P```*;]```*
M````KOT``!L```"Y_0``#P```-7]```2````Y?T```H```#X_0``%@````/^
M```(````&OX```D````C_@``$````"W^```'````/OX``!(```!&_@``!```
M`%G^```'````7OX```4```!F_@``!0```&S^```+````<OX``!0```!^_@``
M$0```)/^```:````I?X``!8```#`_@``%````-?^```7````[/X``!@````$
M_P``'````!W_```9````.O\```<```!4_P``!0```%S_```-````8O\```P`
M``!P_P``$0```'W_```(````C_\```@```"8_P``%P```*'_```+````N?\`
M``P```#%_P``'P```-+_```:````\O\``!,````-``$`!````"$``0`*````
M)@`!``0````Q``$`#0```#8``0`,````1``!``4```!1``$`"0```%<``0`%
M````80`!``<```!G``$`!0```&\``0`$````=0`!``(```!Z``$`.````'T`
M`0`L````M@`!`!(```#C``$`*0```/8``0`R````(`$!``H```!3`0$`+```
M`%X!`0`N````BP$!`#,```"Z`0$`,P```.X!`0`X````(@(!``\```!;`@$`
M&````&L"`0`0````A`(!`!P```"5`@$`#P```+("`0`3````P@(!`!4```#6
M`@$`%````.P"`0`2`````0,!`"0````4`P$`"````#D#`0`D````0@,!`!,`
M``!G`P$`%````'L#`0`5````D`,!`"T```"F`P$`+0```-0#`0`Q`````@0!
M`"X````T!`$`+P```&,$`0`L````DP0!`&(```#`!`$`$P```",%`0`-````
M-P4!``@```!%!0$`%P```$X%`0`(````9@4!``P```!O!0$`*P```'P%`0`A
M````J`4!`!H```#*!0$`"0```.4%`0!%````[P4!`$$````U!@$`!0```'<&
M`0`$````?08!`!,```""!@$`%````)8&`0`.````JP8!`!,```"Z!@$`&```
M`,X&`0`&````YP8!``D```#N!@$`"@```/@&`0`/`````P<!`!`````3!P$`
M!P```"0'`0`.````+`<!``T````[!P$`#````$D'`0`*````5@<!``D```!A
M!P$`"@```&L'`0`/````=@<!``@```"&!P$`#P```(\'`0`(````GP<!`!H`
M``"H!P$`!0```,,'`0`-````R0<!`!L```#7!P$`"````/,'`0`&````_`<!
M`!0````#"`$`$0```!@(`0`.````*@@!`#@````Y"`$``@```'((`0`&````
M=0@!``X```!\"`$`!0```(L(`0`'````D0@!``X```"9"`$`!@```*@(`0`H
M````KP@!``P```#8"`$`'````.4(`0`$`````@D!`"D````'"0$`%P```#$)
M`0`?````20D!`%P```!I"0$`%````,8)`0`^````VPD!`!\````:"@$`$```
M`#H*`0`'````2PH!``X```!3"@$`#````&(*`0`,````;PH!`!,```!\"@$`
M"@```)`*`0`=````FPH!`!D```"Y"@$`!0```-,*`0`1````V0H!`!$```#K
M"@$`)````/T*`0`2````(@L!`!4````U"P$`$@```$L+`0`.````7@L!`!D`
M``!M"P$`"````(<+`0`-````D`L!``<```">"P$`"@```*8+`0`'````L0L!
M``\```"Y"P$`!@```,D+`0`+````T`L!`!H```#<"P$`!P```/<+`0`(````
M_PL!``4````(#`$`'P````X,`0`&````+@P!`!`````U#`$`"````$8,`0`-
M````3PP!``@```!=#`$`'@```&8,`0`2````A0P!`"P```"8#`$`&@```,4,
M`0`)````X`P!``H```#J#`$`%0```/4,`0`%````"PT!`!0````1#0$`!```
M`"8-`0`0````*PT!``8````\#0$`!P```$,-`0`>````2PT!`"@```!J#0$`
M"@```),-`0`<````G@T!`!$```"[#0$`"P```,T-`0`:````V0T!`!0```#T
M#0$`!`````D.`0`$````#@X!``L````3#@$`!0```!\.`0`&````)0X!``@`
M```L#@$`!@```#4.`0`*````/`X!`!L```!'#@$`-````&,.`0`T````F`X!
M`"````#-#@$`*0```.X.`0`@````&`\!`$$````Y#P$`&@```'L/`0`H````
ME@\!`"D```"_#P$`4````.D/`0`B````.A`!``8```!=$`$`"````&00`0`%
M````;1`!``@```!S$`$`&0```'P0`0`9````EA`!`"H```"P$`$`(P```-L0
M`0`9````_Q`!`"X````9$0$`-````$@1`0`(````?1$!`!<```"&$0$`"@``
M`)X1`0`'````J1$!`"$```"Q$0$`$````-,1`0`.````Y!$!``L```#S$0$`
M!P```/\1`0`3````!Q(!``@````;$@$`"P```"02`0`*````,!(!`!0````[
M$@$`#P```%`2`0`R````8!(!``L```"3$@$`#@```)\2`0`%````KA(!``4`
M``"T$@$`!0```+H2`0`7````P!(!``\```#8$@$`!````.@2`0`*````[1(!
M``D```#X$@$`"P````(3`0`-````#A,!``P````<$P$`#@```"D3`0`%````
M.!,!``0````^$P$`#0```$,3`0`R````41,!`!@```"$$P$`10```)T3`0`7
M````XQ,!``<```#[$P$`'@````,4`0`,````(A0!`!0````O%`$`%````$04
M`0`&````610!``<```!@%`$`#@```&@4`0`J````=Q0!``8```"B%`$`#```
M`*D4`0`/````MA0!``T```#&%`$`$0```-04`0`+````YA0!`#8```#R%`$`
M"@```"D5`0`B````-!4!``L```!7%0$`#P```&,5`0`R````<Q4!`"4```"F
M%0$`,````,P5`0`Q````_14!`"T````O%@$`#@```%T6`0`%````;!8!``X`
M``!R%@$`$P```($6`0`2````E18!``<```"H%@$`$0```+`6`0`3````PA8!
M``<```#6%@$`%````-X6`0`8````\Q8!``<````,%P$`!0```!07`0`,````
M&A<!``P````G%P$`$@```#07`0`$````1Q<!``<```!,%P$`"@```%07`0`+
M````7Q<!``P```!K%P$`#@```'@7`0`.````AQ<!``4```"6%P$`!0```)P7
M`0`N````HA<!`"8```#1%P$`(P```/@7`0`#````'!@!`!(````@&`$`!@``
M`#,8`0`>````.A@!`!@```!9&`$`)0```'(8`0`-````F!@!`!\```"F&`$`
M`P```,88`0`'````RA@!``(```#2&`$`#````-48`0`5````XA@!``L```#X
M&`$`&0````09`0`@````'AD!`!(````_&0$`!0```%(9`0`*````6!D!`!4`
M``!C&0$`$@```'D9`0`,````C!D!``0```"9&0$`"0```)X9`0`'````J!D!
M``P```"P&0$`4@```+T9`0`7````$!H!`"0````H&@$`$@```$T:`0`'````
M8!H!``8```!H&@$`#@```&\:`0`.````?AH!``P```"-&@$`#````)H:`0`,
M````IQH!``T```"T&@$`%0```,(:`0`2````V!H!`!````#K&@$`#P```/P:
M`0`4````#!L!``H````A&P$`&P```"P;`0`0````2!L!``L```!9&P$`&P``
M`&4;`0!I````@1L!`!H```#K&P$`%P````8<`0`9````'AP!`!H````X'`$`
M)0```%,<`0`G````>1P!`!H```"A'`$`%P```+P<`0`;````U!P!`!D```#P
M'`$`'P````H=`0`4````*AT!`!,````_'0$`"````%,=`0`'````7!T!``@`
M``!D'0$`"0```&T=`0`5````=QT!``T```"-'0$`(P```)L=`0`-````OQT!
M`!,```#-'0$`"````.$=`0`#````ZAT!`$8```#N'0$`/P```#4>`0`W````
M=1X!`%<```"M'@$`!0````4?`0`?````"Q\!`"\````K'P$`"@```%L?`0`(
M````9A\!``T```!O'P$`+0```'T?`0`$````JQ\!`!0```"P'P$`3P```,4?
M`0`E````%2`!`!(````[(`$`(````$X@`0`<````;R`!``L```",(`$`'P``
M`)@@`0`=````N"`!`"4```#6(`$`(````/P@`0`D````'2$!`"````!"(0$`
M"P```&,A`0`'````;R$!``T```!W(0$`#````(4A`0`7````DB$!``8```"J
M(0$`.0```+$A`0`,````ZR$!``<```#X(0$`"0`````B`0`3````"B(!``D`
M```>(@$`!````"@B`0`0````+2(!``@````^(@$`"````$<B`0`$````4"(!
M``L```!5(@$`#````&$B`0`2````;B(!`!$```"!(@$`#````),B`0`:````
MH"(!``\```"[(@$`!P```,LB`0`-````TR(!`!````#A(@$`$0```/(B`0`4
M````!",!``X````9(P$`#````"@C`0`;````-2,!`"P```!1(P$`$P```'XC
M`0`<````DB,!`"@```"O(P$`!@```-@C`0`'````WR,!`!,```#G(P$`!0``
M`/LC`0`$`````20!`!<````&)`$`"@```!XD`0`,````*20!``D````V)`$`
M!@```$`D`0`)````1R0!``@```!1)`$`"0```%HD`0`*````9"0!`!$```!O
M)`$`!@```($D`0`.````B"0!``X```"7)`$`#0```*8D`0`+````M"0!`!T`
M``#`)`$`"P```-XD`0`"````ZB0!`!P```#M)`$`!P````HE`0`&````$B4!
M`&0````9)0$`"0```'XE`0`'````B"4!`"8```"0)0$`.````+<E`0`:````
M\"4!`"H````+)@$`.P```#8F`0`8````<B8!`"@```"+)@$`-````+0F`0`9
M````Z28!`!4````#)P$`!0```!DG`0`'````'R<!``@````G)P$`!P```#`G
M`0`%````."<!``<````^)P$`#@```$8G`0`)````52<!``8```!?)P$`"```
M`&8G`0`+````;R<!``<```![)P$`"````(,G`0`'````C"<!`!8```"4)P$`
M"0```*LG`0`&````M2<!``L```"\)P$`$````,@G`0`<````V2<!`!0```#V
M)P$`!P````LH`0`1````$R@!``@````E*`$`#@```"XH`0`(````/2@!``4`
M``!&*`$`$````$PH`0`0````72@!``8```!N*`$`&0```'4H`0`*````CR@!
M`!P```":*`$`!P```+<H`0`%````OR@!`!````#%*`$`%````-8H`0`+````
MZR@!``T```#W*`$`*`````4I`0`8````+BD!`!<```!'*0$`!````%\I`0`)
M````9"D!``H```!N*0$`!P```'DI`0`"````@2D!``X```"$*0$`"````),I
M`0`C````G"D!`!\```#`*0$`.````.`I`0`F````&2H!`#$```!`*@$`)P``
M`'(J`0!D````FBH!`!0```#_*@$`50```!0K`0`X````:BL!`$H```"C*P$`
M6P```.XK`0`H````2BP!`#@```!S+`$`*````*PL`0`L````U2P!`"8````"
M+0$`&P```"DM`0`^````12T!`*D!``"$+0$`(P```"XO`0`7````4B\!`$@`
M``!J+P$`A0```+,O`0`P````.3`!`!4```!J,`$`*````(`P`0`B````J3`!
M`"(```#,,`$`(````.\P`0`E````$#$!`$$````V,0$`6P```'@Q`0!)````
MU#$!`#$````>,@$`'0```%`R`0`8````;C(!`"L```"',@$`(0```+,R`0`?
M````U3(!`"L```#U,@$`)@```"$S`0`G````2#,!`#H```!P,P$`'0```*LS
M`0`1````R3,!`#,```#;,P$`)0````\T`0`G````-30!`"````!=-`$`'P``
M`'XT`0`P````GC0!`&D```#/-`$`,0```#DU`0!!````:S4!`#,```"M-0$`
M)0```.$U`0`]````!S8!`&4```!%-@$`30```*LV`0`O````^38!`"X````I
M-P$`*0```%@W`0`P````@C<!`"P```"S-P$`5````.`W`0!:````-3@!`"@`
M``"0.`$`)@```+DX`0!(````X#@!`$H````I.0$`*P```'0Y`0`>````H#D!
M`#(```"_.0$`+P```/(Y`0`L````(CH!`"T```!/.@$`<0```'TZ`0!F````
M[SH!`&\```!6.P$`LP```,8[`0`7````>CP!`"4```"2/`$`,@```+@\`0`I
M````ZSP!`#X````5/0$`(@```%0]`0!2````=ST!`"(```#*/0$`)0```.T]
M`0`+````$SX!`+$````?/@$`10```-$^`0`A````%S\!`#`````Y/P$`)0``
M`&H_`0`<````D#\!`#$```"M/P$`!P```-\_`0`'````YS\!``0```#O/P$`
M#0```/0_`0`+`````D`!``X````.0`$`"P```!U``0`%````*4`!`!`````O
M0`$``@```$!``0!9````0T`!``4```"=0`$`$@```*-``0`$````MD`!``<`
M``"[0`$`"````,-``0`%````S$`!``,```#20`$`$````-9``0`,````YT`!
M`!,```#T0`$`#0````A!`0`"````%D$!``<````900$`!@```"%!`0`4````
M*$$!``P````]00$`&````$I!`0`&````8T$!`!(```!J00$`#````'U!`0`#
M````BD$!`"H```".00$`!````+E!`0`&````OD$!``<```#%00$`'P```,U!
M`0`U````[4$!`"X````C0@$`+P```%)"`0`7````@D(!`"(```":0@$`)0``
M`+U"`0`@````XT(!`!L````$0P$`&````"!#`0`D````.4,!`!\```!>0P$`
M&@```'Y#`0`A````F4,!`"````"[0P$`&@```-Q#`0`R````]T,!`!D````J
M1`$`&@```$1$`0`O````7T0!`"L```"/1`$`'P```+M$`0`C````VT0!`!\`
M``#_1`$`&@```!]%`0`A````.D4!`"4```!<10$`)@```()%`0`E````J44!
M`"0```#/10$`&````/1%`0`=````#48!`"0````K1@$`&````%!&`0`B````
M:48!`"P```",1@$`+P```+E&`0`5````Z48!`"4```#_1@$`/````"5'`0`?
M````8D<!`",```""1P$`'P```*9'`0`@````QD<!`!H```#G1P$`&`````)(
M`0`F````&T@!`!X```!"2`$`*0```&%(`0`>````BT@!`#$```"J2`$`"0``
M`-Q(`0`,````YD@!``P```#S2`$`%P````!)`0`O````&$D!`"0```!(20$`
M!P```&U)`0`/````=4D!`!0```"%20$`#@```)I)`0`-````J4D!`"0```"W
M20$`!0```-Q)`0`'````XDD!`"(```#J20$`)0````U*`0`:````,TH!`!T`
M``!.2@$`&@```&Q*`0`'````ATH!`,<```"/2@$`"P```%=+`0`<````8TL!
M`!4```"`2P$`!@```)9+`0`)````G4L!``L```"G2P$`#0```+-+`0`7````
MP4L!``8```#92P$`,P```.!+`0`3````%$P!`!,````H3`$`!P```#Q,`0`/
M````1$P!``<```!43`$`,@```%Q,`0`$````CTP!`"$```"43`$`$P```+9,
M`0`,````RDP!`!$```#73`$`,@```.E,`0`6````'$T!``@````S30$`'0``
M`#Q-`0`)````6DT!``H```!D30$`%````&]-`0`*````A$T!`!T```"/30$`
M"````*U-`0`?````MDT!``@```#630$`&@```-]-`0`G````^DT!``8````B
M3@$`%0```"E.`0`'````/TX!``@```!'3@$`"0```%!.`0`_````6DX!``<`
M``":3@$`#P```*).`0`.````LDX!`!````#!3@$`"0```-).`0`)````W$X!
M``@```#F3@$`$P```.].`0`'`````T\!`!D````+3P$`"@```"5/`0`7````
M,$\!`!0```!(3P$`"@```%U/`0`,````:$\!`!<```!U3P$`!````(U/`0`J
M````DD\!``P```"]3P$`$0```,I/`0`'````W$\!``(```#D3P$`$````.=/
M`0`8````^$\!``,````14`$`"````!50`0`&````'E`!``<````E4`$`#0``
M`"U0`0`+````.U`!`!0```!'4`$`%0```%Q0`0`.````<E`!`"\```"!4`$`
M(````+%0`0`<````TE`!`!4```#O4`$`*P````51`0`,````,5$!`#$````^
M40$`!0```'!1`0`2````=E$!`#\```")40$`$@```,E1`0`*````W%$!``8`
M``#G40$`!````.Y1`0`$````\U$!``H```#X40$`$P````-2`0`%````%U(!
M``8````=4@$`!@```"12`0`(````*U(!``0````T4@$`#````#E2`0`*````
M1E(!`#D```!14@$`+@```(M2`0`I````NE(!``4```#D4@$`&````.I2`0`9
M`````U,!`!\````=4P$`'0```#U3`0`1````6U,!``(```!M4P$`!````'!3
M`0`*````=5,!``8```"`4P$`!0```(=3`0`#````C5,!``P```"14P$`10``
M`)Y3`0`R````Y%,!`#$````75`$`&@```$E4`0`T````9%0!`"@```"95`$`
M4P```,)4`0`R````%E4!`!D```!)50$`<@```&-5`0`@````UE4!`#4```#W
M50$`(0```"U6`0!%````3U8!`#````"55@$`*````,96`0`H````[U8!`"D`
M```85P$`)@```$)7`0`E````:5<!`"@```"/5P$`*````+A7`0`B````X5<!
M`"L````$6`$`,````#!8`0`2````85@!`!,```!T6`$`$````(A8`0!Y````
MF5@!``D````360$`H0```!U9`0!S````OUD!`'P````S6@$`*P```+!:`0!4
M````W%H!`!<````Q6P$`)P```$E;`0`6````<5L!`!4```"(6P$`#P```)Y;
M`0`7````KEL!`!\```#&6P$`#@```.9;`0!`````]5L!`!\````V7`$`'```
M`%9<`0!1````<UP!`!H```#%7`$`%````.!<`0`*````]5P!``4`````70$`
M!@````9=`0`(````#5T!`!(````670$`$````"E=`0`3````.ET!`!T```!.
M70$`#P```&Q=`0`/````?%T!`!````",70$`!````)U=`0`)````HET!``<`
M``"L70$`"P```+1=`0`%````P%T!``L```#&70$`!P```-)=`0`%````VET!
M`!0```#@70$`#@```/5=`0`+````!%X!``<````07@$`"````!A>`0`/````
M(5X!``P````Q7@$`"0```#Y>`0`(````2%X!``P```!17@$`!@```%Y>`0`/
M````95X!``<```!U7@$`!@```'U>`0`4````A%X!``8```"97@$`#````*!>
M`0`1````K5X!``@```"_7@$`!````,A>`0`9````S5X!`!$```#G7@$`"@``
M`/E>`0`8````!%\!`!,````=7P$`'````#%?`0`1````3E\!``0```!@7P$`
M#P```&5?`0`'````=5\!``0```!]7P$`&0```()?`0`'````G%\!``(```"D
M7P$`$0```*=?`0`)````N5\!`!(```##7P$`%P```-9?`0`&````[E\!`"<`
M``#U7P$`!````!U@`0`/````(F`!`!,````R8`$`!P```$9@`0`'````3F`!
M`!$```!68`$`!@```&A@`0`8````;V`!``8```"(8`$`$P```(]@`0`0````
MHV`!`!(```"T8`$`!@```,=@`0`,````SF`!``D```#;8`$`$0```.5@`0`B
M````]V`!``<````:80$`"P```")A`0`%````+F$!``(````T80$`8P$``#=A
M`0`4````FV(!`!,```"P8@$`#P```,1B`0`%````U&(!``D```#:8@$`"0``
M`.1B`0`#````[F(!`!0```#R8@$`'`````=C`0`L````)&,!`"L```!18P$`
M(0```'UC`0`M````GV,!`!P```#-8P$`,P```.IC`0`+````'F0!`"P````J
M9`$`#0```%=D`0`4````960!`!,```!Z9`$`"P```(YD`0`H````FF0!``P`
M``##9`$`%0```-!D`0`;````YF0!`"$````"90$`"@```"1E`0`+````+V4!
M`"H````[90$`@P```&9E`0`6````ZF4!``<````!9@$`$0````EF`0`5````
M&V8!``X````Q9@$`"@```$!F`0`/````2V8!`!$```!;9@$`F@```&UF`0`-
M````"&<!`!4````69P$`&0```"QG`0`/````1F<!``P```!69P$`$````&-G
M`0`0````=&<!``8```"%9P$`!@```(QG`0`\````DV<!`!X```#09P$`.0``
M`.]G`0!,````*6@!`&L```!V:`$`9P```.)H`0!Q````2FD!`&T```"\:0$`
M/````"IJ`0`2````9VH!`!,```!Z:@$`#````(YJ`0`1````FVH!`!(```"M
M:@$`!0```,!J`0`K````QFH!`!(```#R:@$`"@````5K`0`)````$&L!``H`
M```::P$`,P```"5K`0`M````66L!`"L```"':P$`+P```+-K`0`Y````XVL!
M`#$````=;`$`&0```$]L`0`&````:6P!`"$```!P;`$`"0```))L`0`'````
MG&P!`!4```"D;`$`(@```+IL`0`1````W6P!`!8```#O;`$`&@````9M`0`=
M````(6T!`"H````_;0$`&P```&IM`0`4````AFT!`!0```";;0$`$@```+!M
M`0`1````PVT!`"X```#5;0$`'`````1N`0`=````(6X!`!D````_;@$`90``
M`%EN`0!"````OVX!`!<````";P$`,````!IO`0`#````2V\!``H```!/;P$`
M/````%IO`0`.````EV\!``H```"F;P$`"P```+%O`0`'````O6\!``<```#%
M;P$`!0```,UO`0`*````TV\!``D```#>;P$`"P```.AO`0`=````]&\!``X`
M```2<`$`$@```"%P`0`@````-'`!`!L```!5<`$`,P```'%P`0`+````I7`!
M`!\```"Q<`$`$@```-%P`0`>````Y'`!``\````#<0$`$P```!-Q`0`2````
M)W$!``\````Z<0$`(@```$IQ`0`8````;7$!``<```"&<0$`!@```(YQ`0`(
M````E7$!`"@```"><0$`!@```,=Q`0`*````SG$!`!(```#9<0$`"@```.QQ
M`0`4````]W$!`!,````,<@$`+0```"!R`0`*````3G(!`!$```!9<@$`!P``
M`&MR`0`3````<W(!`!P```"'<@$`&@```*1R`0`]````OW(!`#H```#]<@$`
M"0```#AS`0`,````0G,!`!(```!/<P$`"````&)S`0`%````:W,!``<```!Q
M<P$`!P```'ES`0`,````@7,!`!H```".<P$`20```*ES`0`7````\W,!`"D`
M```+=`$`+0```#5T`0`T````8W0!`#D```"8=`$`#0```-)T`0`)````X'0!
M``H```#J=`$`"````/5T`0`T````_G0!`$@````S=0$`,P```'QU`0!>````
ML'4!`#(````/=@$`,@```$)V`0!%````=78!`#X```"[=@$`,@```/IV`0!&
M````+7<!`"X```!T=P$`.P```*-W`0!"````WW<!`#(````B>`$`.````%5X
M`0`Z````CG@!`"4```#)>`$`*````.]X`0`Y````&'D!`#H```!2>0$`.0``
M`(UY`0`@````QWD!`!L```#H>0$`#`````1Z`0`@````$7H!`!@````R>@$`
M)````$MZ`0`&````<'H!``L```!W>@$`'@```(-Z`0`F````HGH!``<```#)
M>@$`!P```-%Z`0`3````V7H!``D```#M>@$`"````/=Z`0`U`````'L!``L`
M```V>P$`$````$)[`0`'````4WL!``8```!;>P$`!0```&)[`0`'````:'L!
M``8```!P>P$`"P```'=[`0`M````@WL!`!8```"Q>P$`$@```,A[`0`(````
MVWL!``<```#D>P$`$````.Q[`0`%````_7L!``\````#?`$`!P```!-\`0`3
M````&WP!``D````O?`$`"````#E\`0`$````0GP!``T```!'?`$`"````%5\
M`0`:````7GP!`!$```!Y?`$`"````(M\`0`*````E'P!``P```"??`$`!P``
M`*Q\`0`5````M'P!``,```#*?`$`+````,Y\`0`#````^WP!`!,```#_?`$`
M*0```!-]`0`&````/7T!``<```!$?0$`"0```$Q]`0`'````5GT!`$````!>
M?0$`'@```)]]`0`[````OGT!`"H```#Z?0$`)````"5^`0`&````2GX!``4`
M``!1?@$`&@```%=^`0`A````<GX!`#\```"4?@$`.P```-1^`0`C````$'\!
M`"(````T?P$`5P```%=_`0`L````KW\!`!(```#<?P$`"@```.]_`0`+````
M^G\!`!<````&@`$`"0```!Z``0`/````*(`!``T````X@`$`$@```$:``0`2
M````68`!`!(```!L@`$`$P```'^``0`-````DX`!`!,```"A@`$`!0```+6`
M`0`9````NX`!`!H```#5@`$`%P```/"``0`9````"($!`"0````B@0$`!```
M`$>!`0`+````3($!`!,```!8@0$`1````&R!`0!$````L8$!`%P```#V@0$`
M"````%."`0`2````7((!``4```!O@@$`!````'6"`0`>````>H(!`!D```"9
M@@$`'0```+."`0`1````T8(!`!X```#C@@$`+0````*#`0`V````,(,!`$T`
M``!G@P$`.0```+6#`0`2````[X,!`"@````"A`$`!@```"N$`0`/````,H0!
M`!D```!"A`$`%````%R$`0`6````<80!`!4```"(A`$`'P```)Z$`0`0````
MOH0!`"0```#/A`$`*````/2$`0`1````'84!``D````OA0$`$0```#F%`0`*
M````2X4!``\```!6A0$`'0```&:%`0`1````A(4!``@```"6A0$`!````)^%
M`0`,````I(4!``T```"QA0$`"0```+^%`0`1````R84!``8```#;A0$`!P``
M`.*%`0`0````ZH4!``H```#[A0$`#@````:&`0`/````%88!``,````EA@$`
M#````"F&`0`1````-H8!`!$```!(A@$`'0```%J&`0!8````>(8!`"````#1
MA@$`$0```/*&`0`5````!(<!``4````:AP$`'P```""'`0`7````0(<!`!@`
M``!8AP$`-@```'&'`0!#````J(<!`"P```#LAP$`"0```!F(`0`T````(X@!
M`!X```!8B`$`#0```'>(`0`)````A8@!``T```"/B`$`!````)V(`0`+````
MHH@!`!H```"NB`$`&````,F(`0`4````XH@!``H```#WB`$`$`````*)`0`L
M````$XD!`"\```!`B0$`/@```'")`0`Q````KXD!`"P```#AB0$`'@````Z*
M`0!$````+8H!`"P```!RB@$`/@```)^*`0`L````WHH!`#T````+BP$`/P``
M`$F+`0`B````B8L!`"@```"LBP$`-P```-6+`0`Q````#8P!`"T````_C`$`
M+P```&V,`0`\````G8P!`"(```#:C`$`)P```/V,`0`_````)8T!`"L```!E
MC0$`'````)&-`0`I````KHT!`"8```#8C0$`'@```/^-`0`1````'HX!`,0`
M```PC@$`.@```/6.`0`I````,(\!`"L```!:CP$`+0```(:/`0`O````M(\!
M`#4```#DCP$`(P```!J0`0`H````/I`!`"X```!GD`$`,0```):0`0`Y````
MR)`!`#0````"D0$`D````#>1`0`T````R)$!`!@```#]D0$`+0```!:2`0`K
M````1)(!`"\```!PD@$`1````*"2`0!*````Y9(!``\````PDP$`!@```$"3
M`0`*````1Y,!``H```!2DP$`$````%V3`0`.````;I,!`!0```!]DP$`"@``
M`)*3`0`H````G9,!``\```#&DP$`#````-:3`0`$````XY,!`!$```#HDP$`
M(@```/J3`0`*````'90!``\````HE`$`%@```#B4`0`2````3Y0!`!X```!B
ME`$`$````(&4`0!+````DI0!``<```#>E`$`&````.:4`0`&````_Y0!``\`
M```&E0$`%0```!:5`0`5````+)4!`!````!"E0$``@```%.5`0!=````5I4!
M``<```"TE0$`$0```+R5`0`9````SI4!``4```#HE0$`$0```.Z5`0`2````
M`)8!``8````3E@$`#@```!J6`0`(````*98!``8````RE@$`$````#F6`0`/
M````2I8!`!\```!:E@$`(0```'J6`0`K````G)8!`!4```#(E@$`,P```-Z6
M`0`O````$I<!``H```!"EP$`!@```$V7`0`/````5)<!`!4```!DEP$`$0``
M`'J7`0`7````C)<!`!4```"DEP$`#P```+J7`0`9````RI<!``\```#DEP$`
M$0```/27`0`H````!I@!`!$````OF`$`'0```$&8`0`^````7Y@!``T```">
MF`$`(````*R8`0`3````S9@!`!H```#AF`$`%P```/R8`0`:````%)D!`"L`
M```OF0$`$@```%N9`0`%````;ID!``@```!TF0$`&P```'V9`0`&````F9D!
M``<```"@F0$`+P```*B9`0!!````V)D!``H````:F@$`"@```"6:`0`5````
M,)H!``P```!&F@$`$@```%.:`0`2````9IH!``8```!YF@$`,@```(":`0`9
M````LYH!`"4```#-F@$`)@```/.:`0`6````&IL!`"8````QFP$`"````%B;
M`0`+````89L!`"P```!MFP$`/0```)J;`0!`````V)L!``@````9G`$`%0``
M`"*<`0`G````.)P!``@```!@G`$`#P```&F<`0`]````>9P!``\```"WG`$`
M#````,><`0`%````U)P!`%$```#:G`$`!````"R=`0`'````,9T!``D````Y
MG0$`#P```$.=`0`/````4YT!`!$```!CG0$`%P```'6=`0`5````C9T!`!@`
M``"CG0$`'@```+R=`0`B````VYT!`!T```#^G0$`(````!R>`0`>````/9X!
M``<```!<G@$`"````&2>`0`(````;9X!``<```!VG@$`%@```'Z>`0`%````
ME9X!``D```";G@$`(0```*6>`0`7````QYX!`!````#?G@$`#@```/">`0`1
M````_YX!``P````1GP$`#````!Z?`0`9````*Y\!`$,```!%GP$`-@```(F?
M`0`,````P)\!`!8```#-GP$`>@```.2?`0`:````7Z`!`!H```!ZH`$`$0``
M`)6@`0`'````IZ`!``0```"OH`$`)P```+2@`0`V````W*`!`#T````3H0$`
M(@```%&A`0`L````=*$!`!@```"AH0$`)P```+JA`0`*````XJ$!``<```#M
MH0$`#````/6A`0`&`````J(!``T````)H@$`#````!>B`0`2````)*(!``P`
M```WH@$`%P```$2B`0`+````7*(!``H```!HH@$`#@```'.B`0`+````@J(!
M``P```".H@$`'P```)NB`0`;````NZ(!`$T```#7H@$`%P```"6C`0`&````
M/:,!``H```!$HP$`&0```$^C`0`$````::,!`"<```!NHP$`#0```):C`0`Q
M````I*,!`!X```#6HP$`'0```/6C`0`K````$Z0!`"H````_I`$`+````&JD
M`0`M````EZ0!`!P```#%I`$`!@```.*D`0`<````Z:0!``X````&I0$`%P``
M`!6E`0`#````+:4!``,````QI0$`!P```#6E`0`0````/:4!`!(```!.I0$`
M#0```&&E`0`6````;Z4!``L```"&I0$`)@```)*E`0`&````N:4!``0```#`
MI0$`$@```,6E`0`2````V*4!``X```#KI0$`!P```/JE`0`.`````J8!``\`
M```1I@$`(0```"&F`0`&````0Z8!``H```!*I@$`"````%6F`0`+````7J8!
M`!8```!JI@$`$0```(&F`0`#````DZ8!`!0```"7I@$`"````*RF`0`&````
MM:8!`#D```"\I@$`&````/:F`0",````#Z<!`!D```"<IP$`#````+:G`0`&
M````PZ<!``X```#*IP$`"````-FG`0`*````XJ<!``<```#MIP$`#````/6G
M`0`"`````J@!``@````%J`$`#0````ZH`0`-````'*@!``X````JJ`$`$0``
M`#FH`0`6````2Z@!``8```!BJ`$`!P```&FH`0`0````<:@!``@```""J`$`
M"@```(NH`0`%````EJ@!`"````"<J`$`"P```+VH`0`&````R:@!`!4```#0
MJ`$`)````.:H`0`1````"ZD!``8````=J0$`"P```"2I`0`%````,*D!``D`
M```VJ0$`"@```$"I`0`4````2ZD!``4```!@J0$`!0```&:I`0`-````;*D!
M``X```!ZJ0$`#````(FI`0`+````EJD!`!(```"BJ0$`"````+6I`0`'````
MOJD!`!8```#&J0$`'````-VI`0!#````^JD!`"L````^J@$`.````&JJ`0`)
M````HZH!``H```"MJ@$`!````+BJ`0`)````O:H!``@```#'J@$`%````-"J
M`0`+````Y:H!``8```#QJ@$`#0```/BJ`0`&````!JL!`$`````-JP$`10``
M`$ZK`0!"````E*L!`"L```#7JP$`!0````.L`0`/````":P!``,````9K`$`
M!@```!VL`0`&````)*P!`!L````KK`$`#````$>L`0`4````5*P!``@```!I
MK`$`"````'*L`0`C````>ZP!``@```"?K`$`!P```*BL`0`0````L*P!``0`
M``#!K`$`"````,:L`0`,````SZP!``@```#<K`$`"P```.6L`0`4````\:P!
M``\````&K0$`"````!:M`0`(````'ZT!``4````HK0$`-````"ZM`0`W````
M8ZT!`#<```";K0$`+````-.M`0!%`````*X!`$,```!&K@$`+P```(JN`0!8
M````NJX!`#0````3KP$`2@```$BO`0`M````DZ\!`!````#!KP$`$````-*O
M`0`+````XZ\!`",```#OKP$`)````!.P`0`7````.+`!`"````!0L`$`#```
M`'&P`0`.````?K`!``H```"-L`$`#````)BP`0`N````I;`!`"H```#4L`$`
M/P```/^P`0`&````/[$!`!X```!&L0$`,````&6Q`0`<````EK$!`!8```"S
ML0$`!@```,JQ`0`+````T;$!``H```#=L0$`$````.BQ`0`E````^;$!`$8`
M```?L@$`D0```&:R`0!T````^+(!``\```!MLP$`#````'VS`0`-````BK,!
M`!L```"8LP$`%P```+2S`0`.````S+,!``4```#;LP$`(P```.&S`0`5````
M!;0!`"$````;M`$`%0```#VT`0`3````4[0!`!8```!GM`$`%P```'ZT`0`T
M````EK0!`(T```#+M`$`$````%FU`0`%````:K4!`!(```!PM0$`"0```(.U
M`0`*````C;4!``H```"8M0$`*````*.U`0`7````S+4!`!````#DM0$`%0``
M`/6U`0`0````"[8!`!8````<M@$`%P```#.V`0`6````2[8!`!,```!BM@$`
M$P```':V`0`<````BK8!`!L```"GM@$`(````,.V`0`_````Y+8!`!D````D
MMP$`&````#ZW`0`7````5[<!`!8```!OMP$`$@```(:W`0`<````F;<!`!L`
M``"VMP$`$P```-*W`0`3````YK<!`#````#ZMP$`&P```"NX`0`<````1[@!
M`$(```!DN`$`'P```*>X`0`%````Q[@!`!0```#-N`$`+0```.*X`0`C````
M$+D!`"$````TN0$`)@```%:Y`0`E````?;D!`!T```"CN0$`(P```,&Y`0`C
M````Y;D!`!P````)N@$`(@```":Z`0!!````2;H!`"(```"+N@$`)P```*ZZ
M`0`G````UKH!`"````#^N@$`(````!^[`0`C````0+L!`"D```!DNP$`(@``
M`(Z[`0`C````L;L!``T```#5NP$`%P```..[`0`8````^[L!``0````4O`$`
M"````!F\`0`*````(KP!`!0````MO`$`!@```$*\`0`5````2;P!``0```!?
MO`$`"P```&2\`0`'````<+P!``8```!XO`$`!0```'^\`0`3````A;P!``8`
M``"9O`$`"````*"\`0`&````J;P!``8```"PO`$`"@```+>\`0`0````PKP!
M`!H```#3O`$`$````.Z\`0`1````_[P!``H````1O0$`&````!R]`0`%````
M-;T!`#D````[O0$`%@```'6]`0`1````C+T!`!$```">O0$`#@```+"]`0`+
M````O[T!`!(```#+O0$`+P```-Z]`0`(````#KX!``@````7O@$`)````""^
M`0`2````1;X!``\```!8O@$`!@```&B^`0`,````;[X!``D```!\O@$`!0``
M`(:^`0`D````C+X!``H```"QO@$`$````+R^`0`6````S;X!``T```#DO@$`
M$P```/*^`0`8````!K\!`",````?OP$`)P```$._`0`*````:[\!``,```!V
MOP$`"@```'J_`0`B````A;\!``<```"HOP$``P```+"_`0`1````M+\!`!(`
M``#&OP$`!P```-F_`0`%````X;\!``<```#GOP$`*@```.^_`0`-````&L`!
M`!(````HP`$`"@```#O``0`3````1L`!`!<```!:P`$`#````'+``0`.````
M?\`!``X```".P`$`#@```)W``0`$````K,`!`!$```"QP`$`0P```,/``0`&
M````!\$!``4````.P0$`)P```!3!`0`6````/,$!`#0```!3P0$`%0```(C!
M`0`.````GL$!`!,```"MP0$`#P```,'!`0`0````T<$!``\```#BP0$`'@``
M`/+!`0`?````$<(!`#4````QP@$`*P```&?"`0`F````D\(!``@```"ZP@$`
M"````,/"`0`+````S,(!``L```#8P@$`$0```.3"`0`$````]L(!``T```#[
MP@$`*@````G#`0`-````-,,!``T```!"PP$`)@```%##`0!1````=\,!`!T`
M``#)PP$`#0```.?#`0`(````]<,!``@```#^PP$`#@````?$`0`.````%L0!
M`!4````EQ`$`"0```#O$`0`"````1<0!``T```!(Q`$`(P```%;$`0`&````
M>L0!``4```"!Q`$`"0```(?$`0`+````D<0!``D```"=Q`$`"0```*?$`0`4
M````L<0!``X```#&Q`$`!@```-7$`0`(````W,0!``\```#EQ`$`!````/7$
M`0`%````^L0!`&L`````Q0$`#````&S%`0`/````><4!`"````")Q0$`!P``
M`*K%`0`%````LL4!`"H```"XQ0$`,0```./%`0`1````%<8!``H````GQ@$`
M&0```#+&`0`*````3,8!``D```!7Q@$`*@```&'&`0`>````C,8!`"D```"K
MQ@$`*````-7&`0`>````_L8!`"L````=QP$`#P```$G'`0`%````6<<!``<`
M``!?QP$`#0```&?'`0`%````=<<!`!0```![QP$`$P```)#'`0`6````I,<!
M``8```"[QP$`60```,+'`0`>````',@!`!`````[R`$`%@```$S(`0`D````
M8\@!`&8```"(R`$`&````._(`0`'````",D!`!\````0R0$`,````##)`0`(
M````8<D!``8```!JR0$`'@```'')`0`%````D,D!``H```"6R0$`+@```*')
M`0`M````T,D!`#L```#^R0$`$P```#K*`0`&````3LH!`"0```!5R@$`5@``
M`'K*`0`?````T<H!`!P```#QR@$`.0````[+`0`"````2,L!`!D```!+RP$`
M!P```&7+`0`2````;<L!`!$```"`RP$`#P```)++`0`'````HLL!`!0```"J
MRP$`!@```+_+`0`(````QLL!``L```#/RP$`!P```-O+`0`*````X\L!``L`
M``#NRP$`+````/K+`0`'````)\P!`!`````OS`$`$````$#,`0`/````4<P!
M``D```!AS`$`#````&O,`0`-````>,P!``H```"&S`$`"0```)',`0`*````
MF\P!``@```"FS`$`&P```*_,`0`>````R\P!`!0```#JS`$`&@```/_,`0`6
M````&LT!``\````QS0$`%@```$'-`0`@````6,T!``<```!YS0$`%@```('-
M`0`#````F,T!``<```"<S0$`!0```*3-`0`%````JLT!``D```"PS0$`$```
M`+K-`0`2````R\T!`#,```#>S0$`+@```!+.`0`B````0<X!`"0```!DS@$`
M%P```(G.`0`?````H<X!`!D```#!S@$`!P```-O.`0`$````X\X!``P```#H
MS@$`#````/7.`0`1`````L\!``8````4SP$`#0```!O/`0`>````*<\!``D`
M``!(SP$`"0```%+/`0`K````7,\!`"4```"(SP$`#P```*[/`0`%````OL\!
M``P```#$SP$`"0```-'/`0`1````V\\!`!````#MSP$`"@```/[/`0`)````
M"=`!``4````3T`$`!P```!G0`0`'````(=`!``0````IT`$``P```"[0`0!9
M````,M`!`"T```",T`$`1````+K0`0`;````_]`!`#T````;T0$`#P```%G1
M`0!`````:=$!`"D```"JT0$`'@```-31`0`>````\]$!`",````2T@$`-@``
M`#;2`0`-````;=(!`#````![T@$`'0```*S2`0`9````RM(!`!4```#DT@$`
M%0```/K2`0`/````$-,!`!0````@TP$`0````#73`0`8````=M,!`"L```"/
MTP$`'P```+O3`0`5````V],!`"$```#QTP$`/0```!/4`0`^````4=0!`$$`
M``"0U`$`/@```-+4`0`_````$=4!`#T```!1U0$`;0```(_5`0`>````_=4!
M`!8````<U@$`&@```#/6`0`E````3M8!``\```!TU@$`$````(36`0`[````
ME=8!`"L```#1U@$`+0```/W6`0`*````*]<!`"D````VUP$`*P```&#7`0`*
M````C-<!``4```"7UP$`)@```)W7`0`6````Q-<!``X```#;UP$`#@```.K7
M`0`7````^=<!``@````1V`$`"@```!K8`0`,````)=@!``X````RV`$`+P``
M`$'8`0`/````<=@!``\```"!V`$`&````)'8`0`8````JM@!`!0```##V`$`
M%````-C8`0`4````[=@!`!L````"V0$`"P```![9`0`3````*MD!``T````^
MV0$`(0```$S9`0`,````;MD!`!P```![V0$`)@```)C9`0`(````O]D!``0`
M``#(V0$`$````,W9`0`.````WMD!``L```#MV0$`-0```/G9`0`"````+]H!
M``@````RV@$`%P```#O:`0`,````4]H!``<```!@V@$`!@```&C:`0`1````
M;]H!`"L```"!V@$`#0```*W:`0`<````N]H!``0```#8V@$`-P```-W:`0`C
M````%=L!`!X````YVP$`=P```%C;`0`7````T-L!`$@```#HVP$`)P```#'<
M`0`2````6=P!``8```!LW`$`#@```'/<`0`4````@MP!``D```"7W`$`$0``
M`*'<`0`.````L]P!`!X```#"W`$`%0```.'<`0`%````]]P!`!````#]W`$`
M&@````[=`0`R````*=T!`!4```!<W0$`%0```'+=`0`8````B-T!`!,```"A
MW0$`'P```+7=`0`'````U=T!`!<```#=W0$`"P```/7=`0`4`````=X!`!0`
M```6W@$`%@```"O>`0`0````0MX!`!8```!3W@$`&````&K>`0`+````@]X!
M``D```"/W@$`!0```)G>`0`=````G]X!``8```"]W@$`#P```,3>`0`(````
MU-X!`!(```#=W@$`!@```/#>`0`D````]]X!`!0````<WP$`,P```#'?`0`5
M````9=\!``<```![WP$`"````(/?`0`>````C-\!``L```"KWP$`&P```+??
M`0`'````T]\!`",```#;WP$`!P```/_?`0`(````!^`!`"0````0X`$`.P``
M`#7@`0`+````<>`!`"4```!]X`$`)P```*/@`0`-````R^`!`!H```#9X`$`
M$````/3@`0`$````!>$!``X````*X0$`#@```!GA`0`'````*.$!``X````P
MX0$`"````#_A`0`%````2.$!``D```!.X0$`'0```%CA`0`F````=N$!`#\`
M``"=X0$`*````-WA`0`E````!N(!`!\````LX@$`.P```$SB`0`>````B.(!
M`"H```"GX@$`,@```-+B`0!=````!>,!`"4```!CXP$`#0```(GC`0`(````
ME^,!``H```"@XP$`"@```*OC`0`1````MN,!`!8```#(XP$`1P```-_C`0`E
M````)^0!`!H```!-Y`$`.````&CD`0!`````H>0!``D```#BY`$`)@```.SD
M`0`+````$^4!`!0````?Y0$`)P```#3E`0`,````7.4!`!D```!IY0$`#```
M`(/E`0`.````D.4!``X```"?Y0$`#P```*[E`0`0````ON4!``\```#/Y0$`
M&P```-_E`0`:````^^4!`#4````6Y@$`"P```$SF`0`:````6.8!``4```!S
MY@$`%0```'GF`0`%````C^8!`!X```"5Y@$`%P```+3F`0`#````S.8!``P`
M``#0Y@$`$````-WF`0`%````[N8!``X```#TY@$`"`````/G`0`/````#.<!
M``4````<YP$`!P```"+G`0`0````*N<!`$D````[YP$`*@```(7G`0!0````
ML.<!`"<````!Z`$`"0```"GH`0`R````,^@!`!(```!FZ`$`*P```'GH`0`1
M````I>@!``D```"WZ`$`#````,'H`0`0````SN@!`#(```#?Z`$`!@```!+I
M`0`-````&>D!`!,````GZ0$`#@```#OI`0`5````2ND!``T```!@Z0$`7```
M`&[I`0`*````R^D!`"4```#6Z0$`%0```/SI`0`6````$NH!`"P````IZ@$`
M)@```%;J`0`^````?>H!`$$```"\Z@$`.P```/[J`0`.````.NL!``4```!)
MZP$`$P```$_K`0`<````8^L!`"````"`ZP$`"````*'K`0`3````JNL!`!L`
M``"^ZP$`!P```-KK`0`?````XNL!`!<````"[`$`$````!KL`0`$````*^P!
M`!(````P[`$`$P```$/L`0`4````5^P!``8```!L[`$`!P```'/L`0`3````
M>^P!``X```"/[`$`#P```)[L`0`1````KNP!`!$```#`[`$`!@```-+L`0`'
M````V>P!`"@```#A[`$`)`````KM`0`@````+^T!``@```!0[0$`#P```%GM
M`0`&````:>T!`!@```!P[0$`*0```(GM`0`I````L^T!``H```#=[0$`&```
M`.CM`0`#`````>X!``@````%[@$``P````[N`0`2````$NX!`!0````E[@$`
M"P```#KN`0`8````1NX!`",```!?[@$`%P```(/N`0`&````F^X!``H```"B
M[@$`%````*WN`0`7````PNX!``P```#:[@$`!@```.?N`0`,````[NX!``H`
M``#[[@$`%0````;O`0!Y````'.\!`!\```"6[P$`+P```+;O`0`4````YN\!
M``@```#[[P$`!P````3P`0`7````#/`!`!,````D\`$`$0```#CP`0`3````
M2O`!`!<```!>\`$`&````';P`0`B````C_`!`!T```"R\`$`'@```-#P`0`2
M````[_`!`"4````"\0$`$0```"CQ`0`F````.O$!`!@```!A\0$`%P```'KQ
M`0`M````DO$!`(,```#`\0$`*````$3R`0`?````;?(!`"4```"-\@$`(@``
M`+/R`0`\````UO(!`#@````3\P$`)P```$SS`0`>````=/,!`"L```"3\P$`
M(P```+_S`0`G````X_,!`!H````+]`$`%````";T`0`+````._0!``@```!'
M]`$`"0```%#T`0`*````6O0!`!4```!E]`$`"P```'OT`0`[````A_0!`"D`
M``##]`$`-P```.WT`0`6````)?4!``8````\]0$`10```$/U`0!5````B?4!
M`#0```#?]0$`G````!3V`0`+````L?8!`#<```"]]@$`+P```/7V`0`2````
M)?<!``@````X]P$`$P```$'W`0!$````5?<!``P```":]P$`)0```*?W`0!8
M````S?<!`$@````F^`$`'0```&_X`0`U````C?@!`"@```##^`$`%````.SX
M`0`B`````?D!`"(````D^0$`+````$?Y`0`B````=/D!`"L```"7^0$`'P``
M`,/Y`0`5````X_D!``<```#Y^0$`$`````'Z`0`4````$OH!``T````G^@$`
M"P```#7Z`0!1````0?H!``P```"3^@$`'@```*#Z`0`1````O_H!`!\```#1
M^@$`"0```/'Z`0`%````^_H!`!@````!^P$`"0```!K[`0`)````)/L!``<`
M```N^P$`!P```#;[`0`)````/OL!`!(```!(^P$`'````%O[`0`/````>/L!
M`!\```"(^P$`$````*C[`0`(````N?L!``T```#"^P$`&@```-#[`0`:````
MZ_L!`"8````&_`$`"P```"W\`0`*````.?P!`!@```!$_`$`)@```%W\`0`,
M````A/P!`"(```"1_`$`*P```+3\`0`+````X/P!``@```#L_`$`(0```/7\
M`0`-````%_T!`!D````E_0$`&P```#_]`0`4````6_T!`!8```!P_0$`$@``
M`(?]`0`%````FOT!``D```"@_0$`"````*K]`0`)````L_T!``H```"]_0$`
M%````,C]`0`'````W?T!`!````#E_0$`"@```/;]`0`(`````?X!``P````*
M_@$`(0```!?^`0`,````.?X!``(```!&_@$`(P```$G^`0`%````;?X!``H`
M``!S_@$`>@```'[^`0`*````^?X!``@````$_P$`*@````W_`0`Z````./\!
M`!H```!S_P$`+@```([_`0!=````O?\!`!T````;``(`(P```#D``@`S````
M70`"`"\```"1``(`)0```,$``@`&````YP`"``T```#N``(`"````/P``@`)
M````!0$"``4````/`0(`"````!4!`@`2````'@$"``H````Q`0(`"0```#P!
M`@`+````1@$"``L```!2`0(`&@```%X!`@`(````>0$"``D```""`0(`%0``
M`(P!`@`*````H@$"``H```"M`0(`!0```+@!`@`N````O@$"`"8```#M`0(`
M&````!0"`@`'````+0("`!(````U`@(`"0```$@"`@`/````4@("`#,```!B
M`@(`"````)8"`@`8````GP("`!@```"X`@(`!@```-$"`@`&````V`("``T`
M``#?`@(`'````.T"`@`&````"@,"``D````1`P(`"P```!L#`@`<````)P,"
M``L```!$`P(`#0```%`#`@`J````7@,"`!\```")`P(`&````*D#`@`&````
MP@,"``L```#)`P(`$````-4#`@`-````Y@,"``,```#T`P(`#@```/@#`@`(
M````!P0"`!T````0!`(`+P```"X$`@`P````7@0"`"H```"/!`(`+@```+H$
M`@`N````Z00"`(X````8!0(`%@```*<%`@!C````O@4"`#@````B!@(`80``
M`%L&`@!I````O08"`"$````G!P(`30```$D'`@`\````EP<"`$<```#4!P(`
M'@```!P(`@`8````.P@"`",```!4"`(`_0$``'@(`@`=````=@H"`!T```"4
M"@(`20```+(*`@"@````_`H"`#0```"="P(`&@```-(+`@`S````[0L"`"0`
M```A#`(`(P```$8,`@`D````:@P"`"D```"/#`(`1P```+D,`@!:`````0T"
M`&0```!<#0(`,@```,$-`@`@````]`T"`!X````5#@(`-````#0.`@`<````
M:0X"`!\```"&#@(`)````*8.`@`@````RPX"`"8```#L#@(`+P```!,/`@`:
M````0P\"`!8```!>#P(`,0```'4/`@`J````IP\"`"0```#2#P(`/````/</
M`@`:````-!`"`#(```!/$`(`<0```((0`@`[````]!`"`#H````P$0(`,@``
M`&L1`@`I````GA$"`$<```#($0(`;0```!`2`@!?````?A("`#````#>$@(`
M,`````\3`@`D````0!,"`#,```!E$P(`+@```)D3`@!.````R!,"`&8````7
M%`(`*P```'X4`@`M````JA0"`$T```#8%`(`4P```"85`@`N````>A4"`"$`
M``"I%0(`20```,L5`@`G````%18"`"<````]%@(`)````&46`@!X````BA8"
M`&T````#%P(`=P```'$7`@#.````Z1<"`!P```"X&`(`+````-48`@`V````
M`AD"`"X````Y&0(`4````&@9`@`<````N1D"`$````#6&0(`&````!<:`@`_
M````,!H"``4```!P&@(`R````'8:`@!&````/QL"`"(```"&&P(`/@```*D;
M`@`G````Z!L"`!P````0'`(`+````"T<`@`)````6AP"`!8```!D'`(``P``
M`'L<`@`6````?QP"``P```"6'`(`#0```*,<`@`+````L1P"``<```"]'`(`
M#0```,4<`@`'````TQP"`'4```#;'`(``@```%$=`@`6````5!T"``0```!K
M'0(`!P```'`=`@`&````>!T"``4```!_'0(`!0```(4=`@`5````BQT"``H`
M``"A'0(`$@```*P=`@`/````OQT"``(```#/'0(`!P```-(=`@`+````VAT"
M`!(```#F'0(`#0```/D=`@`9````!QX"``8````A'@(`&0```"@>`@`*````
M0AX"``,```!-'@(`6P```%$>`@`$````K1X"``8```"R'@(`!P```+D>`@`G
M````P1X"`$P```#I'@(`1@```#8?`@!'````?1\"`"H```#%'P(`+@```/`?
M`@`Q````'R`"`!T```!1(`(`(@```&\@`@`<````DB`"`#(```"O(`(`*@``
M`.(@`@`D````#2$"`"8````R(0(`)P```%DA`@`N````@2$"`"L```"P(0(`
M'P```-PA`@`>````_"$"`"D````;(@(`*@```$4B`@`?````<"("`",```"0
M(@(`(0```+0B`@`9````UB("`"(```#P(@(`+````!,C`@`R````0","`#,`
M``!S(P(`)P```*<C`@`=````SR,"`"0```#M(P(`*0```!(D`@`=````/"0"
M`"<```!:)`(`.````((D`@`[````NR0"`!D```#W)`(`(P```!$E`@`Z````
M-24"`"(```!P)0(`)@```),E`@`D````NB4"`"4```#?)0(`'`````4F`@`D
M````(B8"`#````!')@(`'@```'@F`@`Q````ER8"`"$```#))@(`-@```.LF
M`@`)````(B<"`!`````L)P(`$````#TG`@`B````3B<"`$<```!Q)P(`+```
M`+DG`@`,````YB<"``\```#S)P(`%P````,H`@`2````&R@"`!`````N*`(`
M)P```#\H`@`&````9R@"``H```!N*`(`)0```'DH`@`H````GR@"`!L```#(
M*`(`*````.0H`@`<````#2D"``\````J*0(`]````#HI`@`5````+RH"`"``
M``!%*@(`%P```&8J`@`)````?BH"`!<```"(*@(`(@```*`J`@`=````PRH"
M`!X```#A*@(`"0`````K`@`^````"BL"``\```!)*P(`%@```%DK`@`'````
M<"L"`!L```!X*P(`$0```)0K`@!.````IBL"`!````#U*P(`(@````8L`@`<
M````*2P"`!@```!&+`(`(P```%\L`@!A````@RP"`"<```#E+`(`$`````TM
M`@`G````'BT"`!$```!&+0(`$@```%@M`@`8````:RT"``L```"$+0(`'0``
M`)`M`@`I````KBT"`!\```#8+0(`"P```/@M`@`S````!"X"`#T````X+@(`
M!P```'8N`@`3````?BX"``<```"2+@(`!P```)HN`@`)````HBX"`$D```"L
M+@(`!@```/8N`@`-````_2X"`!`````++P(`%@```!PO`@`+````,R\"``P`
M```_+P(`!P```$PO`@`1````5"\"``\```!F+P(`'````'8O`@`7````DR\"
M`!0```"K+P(`&````,`O`@`,````V2\"``X```#F+P(`+````/4O`@`.````
M(C`"`#8````Q,`(`&@```&@P`@`0````@S`"``X```"4,`(``P```*,P`@`4
M````IS`"`!L```"\,`(``P```-@P`@`)````W#`"``<```#F,`(`"@```.XP
M`@`.````^3`"``X````(,0(`&P```!<Q`@`<````,S$"``X```!0,0(`-```
M`%\Q`@`:````E#$"`!4```"O,0(`&0```,4Q`@`T````WS$"``T````4,@(`
M,@```"(R`@`)````53("`!<```!?,@(`5@```'<R`@`5````SC("`!D```#D
M,@(`"@```/XR`@`$````"3,"``0````.,P(`%@```!,S`@`5````*C,"``4`
M``!`,P(`!@```$8S`@`*````33,"``T```!8,P(`!0```&8S`@`.````;#,"
M`!(```![,P(`/P```(XS`@`R````SC,"`"D````!-`(`(````"LT`@`<````
M3#0"`",```!I-`(`*````(TT`@`@````MC0"`!4```#7-`(``@```.TT`@`$
M````\#0"``T```#U-`(`!@````,U`@`%````"C4"``0````0-0(`$0```!4U
M`@!X````)S4"`"0```"@-0(`*P```,4U`@`M````\34"`"\````?-@(`(P``
M`$\V`@!(````<S8"`#$```"\-@(`&0```.XV`@".````"#<"`"(```"7-P(`
M5````+HW`@`A````#S@"`%<````Q.`(`+@```(DX`@`U````N#@"`"D```#N
M.`(`0````!@Y`@`S````63D"`"\```"-.0(`/P```+TY`@`=````_3D"`"4`
M```;.@(`*````$$Z`@!-````:CH"`!````"X.@(`&P```,DZ`@`4````Y3H"
M`'4```#Z.@(`"@```'`[`@#6````>SL"`(4```!2/`(`?@```-@\`@`X````
M5ST"`'H```"0/0(`'`````L^`@`W````*#X"`"H```!@/@(`+````(L^`@`2
M````N#X"`"4```#+/@(`)````/$^`@`5````%C\"`$8````L/P(`(@```',_
M`@`<````EC\"`%D```"S/P(`+P````U``@`F````/4`"``L```!D0`(`!0``
M`'!``@`&````=D`"``@```!]0`(`(@```(9``@`.````J4`"`"````"X0`(`
M*````-E``@`+`````D$"``\````.00(`&````!Y!`@`+````-T$"``D```!#
M00(`!@```$U!`@`)````5$$"``D```!>00(`"````&A!`@`*````<4$"``D`
M``!\00(`%@```(9!`@`.````G4$"``8```"L00(`#0```+-!`@`.````P4$"
M`!0```#000(`$````.5!`@`.````]D$"``<````%0@(`#@````U"`@`*````
M'$("`!$````G0@(`"````#E"`@`,````0D("`!8```!/0@(`#0```&9"`@`*
M````=$("`!0```!_0@(`!@```)1"`@`'````FT("`"4```"C0@(`(@```,E"
M`@`.````[$("`!````#[0@(`$@````Q#`@`D````'T,"`!$```!$0P(`"0``
M`%9#`@`5````8$,"``<```!V0P(`!````'Y#`@`C````@T,"``L```"G0P(`
M`@```+-#`@`5````MD,"``@```#,0P(`$0```-5#`@`1````YT,"``0```#Y
M0P(`20```/Y#`@`#````2$0"`"\```!,1`(`+P```'Q$`@`+````K$0"``@`
M``"X1`(`'````,%$`@`%````WD0"`!T```#D1`(`"0````)%`@`D````#$4"
M`!H````Q10(`(````$Q%`@`+````;44"``P```!Y10(`#````(9%`@`-````
MDT4"`"D```"A10(`"@```,M%`@`?````UD4"``4```#V10(``P```/Q%`@`!
M````90,``````````````````%\&``!4`P``HP(``.\#``"B`0``6@,``+,`
M``#`!0````````````!_`@``````````````````!0```*0!```7!0``N@,`
M`-`"```C!0``9@```.<````D!0```````#T&``#$`P``S@0``!4"``!]````
M\P(``)L#``!?!````````+($```Y`0``*P8``,X%``!7!P``-@0``+P!```K
M`0``P@$``!P```#F`0``2`(```````#'````1@(```````#,`P``*P,```<`
M``"'!@```````+8#````````'@,``!(````]!```,@,`````````````I04`
M`)0!```%`0``U`0```````#A!P````````````#I`0``QP(``,D%``"%!```
MK@0``+,!``"\!@```````.,%``!G!@``Z`(````````3!P```````"@&``!T
M!P``1@<```X"``!;!````````(8&``!7`0```````&<````!!P``VP0``*@&
M````````BP<``)$!``"S!P``EP4```````#"`P``4@````````!?!0``;P$`
M`"L`````````3`<```D"``#U!```@@8````````C`@``2@4````````1!```
MTP$```````!L!P``'P,``(4%``"T!P``*`$``+\$````````!`$`````````
M````;`,``)(!``#R`0``0@0``&`%``!X!P``A0$``+T&````````:@``````
M``"Q`@``%`<``.("``#0!@``2@0``-D!```Z!0``Y`(```````#@`````P(`
M`'8!``!J`P``D0```'(%``"P!P````````````!D!@``D@<``,T"``!_!@``
M4`(``',%```Z`0```````%L`````````+0<``&@#```0!``````````````P
M!0```````/L"``#8!@```````'`$``"!!0``*`<``/D&``#S`0```````%P!
M``#J!@```````+\'````````*@,``(T!``#B!0```````%@!```%!P``````
M````````````%`8```````#_`0``L04```````!X!@```````%H'```9`@``
M]P````8%``!Z!````````-,"```Z!P```P$``)$'``#A`@```````%("```J
M!```Y08``(\%``!=`0``^@0``+D!````````S08```````#U!0``M`,`````
M``#O`0``+@0``!P&````````)00```````"H`````````#4#````````UP<`
M``T&``#G!@``)0(`````````````-`,``%@```")!P``BP(``*P#````````
M`````/L#````````SP4``'(#``"!`0````````````!?````W`0``&D$``!5
M!P``;P```+@&``!%!```,0(``'D%``"O!P``2P(```\```"<!0```````%D&
M``!/!0````````````#,````3`4``!8"``#"````J@$`````````````"@4`
M``````#2````N@8````````X!0```````'L"``"<````]@8``(H%````````
M&08``+(&```Y!0``C08``*H&``!B!0``\P0``.$$``"^!P``EP<`````````
M````3`(``$4'`````````````%H"```^`P``'08``#<%``#K!@``L@```-$#
M`````````````/$!``!C````R@4``#`#````````70<``'<%````````700`
M`"`$````````6`<``&("``!R!@``%P$``#P#````````K`(``+(#``!;`@``
M`````,($``!Q`0``-`0``)8&```@`@``?````%($````````>@```(@"``"H
M!P``IP4``'8#``"]`0``KP8``/\"````````P`(``.\"``!^`0``K@```-<$
M``"$`0``(P$```P&```/`P``KP$``#H"`````````````+P%``!#!P``]`(`
M``````"[`@``````````````````)`(```L!``#E`@``:`````````#/`0``
MT00``$(```">`@``+0$``",#```X`P``I@$`````````````I0,``#T%``#N
M````_0(``(,&```]`P``R0```"0$````````N@$```````"9!```I`<``*`'
M``#1!P`````````````O!0``.P0``)0$``````````````````!S`0``#`$`
M`!($```N`0``%P<``/@$``#.!P``JP8``(8````8!0``\`4``!`#````````
MQ````*@%```;`P``>````/L%````````VP8```````"R!P``P04``'T%````
M````(@,``%X!``#5!P``N`(``-$```#)!```.`<`````````````#0(``!P!
M``````````````````"E````F@8```````!.!@``9@,``.X$```2!P``O@``
M``````"X````2P```/\&```A!```6@4``/P&``""`P```````-@````H`@``
M/@````4#``"A`@```````)T"```A!0``*00```````!8`P``X`<``%L%````
M````MP<```````"1!0```````'T"``#:!```7@8``"$'``!L!@``J0(``"\!
M`````````````"L$``#T`0``F@<`````````````!````-('```S````3@$`
M``````!M`0``F@0``+@!``!%`````````&`&``!-!@``%@4``#0"``"`````
MJ08``!P%`````````````,T$``!P`0``+0(``'D"``#T!@```````+H`````
M````EP$``&$#``#C`@``2@,````````]!P```````#<'``"2!@``BP0`````
M```!!```2@<`````````````_08```````"Y`````````,L$````````C`8`
M`,`#````````E08``-@!``!\`@``4@4``%\"``"1!@``&0,`````````````
MMP0``"<'```%!0```````.($``!]`0```````-0!``":`@``]P$``,@```#T
M````OP,````````_!0``,`<``+8```#7`0``7@0`````````````$````&$!
M``!)`@```````(D`````````G`$```````#"`@``E0(```````"L!0``708`
M``````#*`0```````#(&``!#`P``1@0``.H$````````1P4``!X'````````
M````````````````_@,```````!-!0```````!T#``"-`P````````X%```-
M!P``AP```$L!```[!@``N00`````````````````````````````B@```/4!
M``#L!0````````````")`@```````.<%``"W`@``+P```#,&````````B@,`
M``````"W``````````@&``"&`0``0P8``),%`````````````/8`````````
M<`(```````!"`0``K0(``"8!``"%!@``E@4``$\$``#:!P``4P0``,L%``#S
M`P``!@<``(@!``#9!P```````"X"``!!`P``@`(``+X$``#<!@```````.L#
M````````0`$``)P"``#6`P``:`$``#0&`````````````%(#``#>!0``````
M`#L%``"A!0``W0<``(D!``#'!0``1@8``/@&`````````````%L!``!"`@``
M%`4```,#``"L!P``J00`````````````GP(``.X&````````.`8`````````
M````G`0``+`!```.`P```````+0!``#$!@``/`4``&(&````````1`<``,T#
M```*!P``P08``,<#```Y`P```````$L#```B!```G@4```````"H`0``Q@4`
M``````"Q!````````'L$``#O!```&P<``*,$```R!P``M0$``,D'``#0!```
M`````-\```"*!``````````````F!0```````&8'````````M04``!T```!U
M!P``C@0``-H````'`P```````)H```"N!@``)0<```````"J`P``]0(``#P!
M``#;````60<``'`&````````NP8````````R`@``/P$``'\'``"E`@``````
M`!@#``!?`0``R@``````````````)P0````'``#^`0``6P<``'\%````````
M(@(``+`"````````3@(``/P$`````````````!`'```$!0``;@$`````````
M````JP4``#\"```F`@``6@````H```!A!0``70````````"X!````````,8`
M```?`````````%X%`````````````(D$``"J!P``]P8``&P$````````B@$`
M``````"]!````````!$%``!W!P``B@(``+4&``#:`0````````````!]!@``
MY@4``-X#````````104``&,#``"A`````````!P'``#@!@``+`,``,D#```I
M!@``7P,```````"B`````````%P"````````(0$``/0#``!(`0``8P8`````
M````````&04``#,"`````````````&('``!"`P``@0<```````#?!@``_@0`
M`+P`````````-`$```$"```G!@``WP(```````!6!```;@0``-,```#%!@``
MW0$```````````````````````````````````````#%`P``'0$``.L"```V
M````G08````````S`P``F04``&`'````````I@,``"<%```S!0```````*X'
M```Q!```E@$```````!!!0````````````#(`0```````%$&``#\!0``G@<`
M`&4````5!@```````!X!```,!0``3P<``.L`````````=P```'0!``#@!```
MF0```.,&``!T`P``:04````````L!@```````.0$``!E!0``@`,``#($``#&
M!@``#@0```````!I`@``:@$``-P%`````````````-4```!R!```$`8``%$%
M``!W!@``30(``,`$```N!0``^`$``+`&````````_`$``#X"``!L!0``[04`
M```&``!^!@``W`(``,P$``!8!@``.P,```````!4!P``40```$\#``!J`@``
MT@$``-D#```N````D@(``+H%``#S````10,```````!]!P```````*<!````
M````Y`,```````#-`0``'04``#$&````````C`0``*\%````````IP(``)0&
M``#0`P``!@$``/\```#D!P````````````"V`0``LP,``/T%``#H!0``WP$`
M`.(```!H`@``G04```X```"3!```+00``"H%``!D````4P<``!X$```U!0``
M``````````!S````3`8``````````````````%T"``"A!@``@00``%D"``"0
M`@``*P<```H!````````3@<``%(&``!E!@``L0<``%L&``"'`P``R0$`````
M````````L08``!H"``!N`@``0@4```````!A!@``R`8``&(```!\!@``&0<`
M`",`````````+P<````````[`@``!@0``)0%````````'`,``+L!`````@``
MK`$``,\````F!@````````,$````````=00``-H#``!W!```&@4``/D!```@
M`0``L`4``+@%```,`P````````P```"3````A0<``.L$```9`0```````%,`
M```5`0``&P```-@#``"9`P``%@$``#@````!!0``9P,``*('``#`!P``I@(`
M`!H'``#\`@``)04``!L!````````J`,``*8%````````4P8``,X&``#,!P``
M<0<```8```!G!P``N@<```````"Y`P``E````/H!``!K!````````#X'````
M````X04``%8&```J!@``1`8``&8$`````````````(0'```B````OP```/0$
M``!X!```E04```@$``!I!@````````````!D!````````"D#``!'!@``````
M`(X"```U!````````(`'````````TP,``','``"(!@``L0$``%`!```X`0``
M1@,``,,$``#1`0``;00````$``"<!P``=@(``````````````````.$!```)
M!0```````&<!```U!P``````````````````I`0``%`'`````````````/L$
M``#:`@```````*L```#Y!`````````````#<`P```````!$&````````70,`
M`)8'``#@!0```````'H'``#6````\`(``/X%``#!`0``N04``-L#````````
M,`0```````"[````2@```%\'``"``0``%@0``!X````J`@``$0(``+,$````
M````6`(``/$$``"6`@``50,```````!_`P``!00``#4```"T````````````
M```D`0``V@8``#(```#H!@````````L`````````>`(``+`#``"D`P``U`8`
M`&P!````````*0$``)T```"[!0``````````````````;0<``)$"````````
M]@0``.X"``!8!0```````$T#``!.````)@<``'D#``#$`@``(`4```````#^
M`@``T@0``/\$``#S!@```````.8&``",`P```````!,%````````U`4``.T!
M````````TP4```D!```(!0``O@,```@#````````H`,``%8'``"-!```%P0`
M``````"'!`````````````!<````7`,````%```7`````````%0!``"[!P``
M``````````#P`0``G00``%0```#C`P``V04``&``````````'P<````````[
M!P``UP,`````````````JP$``.$#```V`P``#@$``!X&``#6`@``500``/@%
M``````````````````!)`P```````,$```#C````+`$``,P&``"N`P``D@``
M`.T"``#/!@``KP(``*L$```X!```%0<``%H$``!$`@``D`````````#R!```
M@@0``#``````````;P0``.D#``#"!P``W0(``$$```"2!```0`(``/H&``#=
M!0``,@$``$H!```#!@``"@,``"4!``!5````^`(``)4'```S!```T`4``"T`
M````````PP$``.T````Y!```AP4``&H$````````B04``&`$``"U````PP4`
M`&4!``#.`@```````-<"``"`!@``5P,``*<&`````````````",'```^`0``
M`P<````````8`0```````.\%``"Y!P```````*,%`````````````+P'```P
M`@``I`8```$#````````G0$````````U`@``\P4``"8$``!H!```9`<``$P$
M``#=!```^@,``+<!``"S!0``M00``&L```"K`P``5P0``$D```#X`P``````
M`)4`````````>@8``%<%``")`P``B````!`!``!0!0``OP$``,8#``!^````
MYP(``$8%````````+`(``(8'```$`P```````(X%``!9!````````#\$````
M`````````)8$`````````````(L!```N!P``O0,``"$&```7!@```````(@$
M``"Q````P0(``,D&``"/!@``>08``%(!```V!P``$P$``.,!```-!```````
M`+("``":`0``Y0,``/`#``"/`0````````````#\````.0(``!$#```Y````
M`````!0"``#`````'@4``!@'````````DP,``%4"``!9`0```````'H%```C
M!@``T@4``#0'``!(!````````"\&```3`@``0@8``.D&```Q`P``GP$``"\#
M``!1`@```````-8$``"/`P``00$```````![`P```````#,!``!:`0``VP4`
M`````````````````((%```)````Q00``*H"``"H`@```````%0&``"\!```
M`````#<```#2`P```````.L!````````\@(``)P#``!=!0``F@,``$\"````
M````F`(``$<'`````````````.8#`````````````&D!``"3`@``K04`````
M``#8!P``$@,``)L!````````H`0``"@```#X````)P,``.T#````````````
M``````"T!@``H@4```````"A`0``K`8``$@&```;`@``\@```&0!``#$!```
M7@(````````\!```W@8``!X"``#?!P``G@$``,P!```A````V`4``!P"``!%
M!@```````'4#```:`P````````````!I!P```````&H'`````````````/$`
M``"$````O`,``'L!``#9`@```````,\#```G````A@4```4&``"$!@``?P$`
M``@`````````40<``*D```#*!P``!`0``*4&``!C`@``OP8``-T```!%`0``
M0`4``&@'``!K!@``S0<``-0'``#(!```:P$```8"``#&`@``208```````",
M!0```````(<'````````DP$``/$&```*!```(0,`````````````T04``'<#
M```#!0``Y@(```\%``!U`@``F0<```````!+!@``%P(`````````````Z```
M`)`'``">````KP0``(8#``!\!P``<@$``"H```#8!```4`8`````````````
M`@8`````````````UP```*$'``"F!@``9`4```X&``#Z````:`4``$8````?
M`0``=`4````````^!```?@4```````"E!```?@<``-D$``"/`@```````#<&
M````````%`,``'@#```'!0``5`4``)@&``!Q````U00``$\!```P!@``````
M`&T%``#8`@``C@8````````?!0``RP8``%,!``#]!```````````````````
M(0(`````````````GP8``'T#```9!```)@```$0!``!6!0```````*(#```@
M!@``)`8``"T#``#5`P``VP(``#X%```7`P``*`,``%D```"V!0``!P<``/$"
M``#]`P``0`,``$,$```V!@``8P$``*L"``""`0``U0(``&0"``"^!@``````
M````````````G@8``(L%``"G!```BP8``,L#``"@`0```@(```````"M!P``
M!`8``&<"``!@`@``>P4``,@'``#6`0``9@8``,(%``"Y!@``C04``!(&``#L
M`P``Q0$```\$``#R`P``4@<````````+`@```````*<'``#[`0``RP(`````
M```Y!P``3`$``#<$``#4`P``4P4``*($``"`!0```````!D```"#!```3`,`
M`!@`````````8@,``!,&````````'`0``(<"``#`!@```````!@"``#%`@``
MW@```'('````````:P,``'("``"*!P```````&P`````````````````````
M````!0(`````````````S@$``(X`````````T`<```````"9`0``[P8``/L&
M``#1!@```````)<$``##!@```````.\```#E````#04``,(&````````;08`
M`)L`````````"0<``,T```!>`P``M@(``",$``!^`@``1`0``*,#``#>!P``
M`````#8%``#U!@``)P(``!H!``#:!0``WP4```````!'!```=0````````"?
M!0``!@,``&T```"7!@``1P,```````!P!P``K0$```````"#````2@8``)@!
M````````J@0```````#N`P``H0,``&X#``!6`P``7@````````!<!```````
M``````!@`P``Y`8```````"=!P``F08````````U`0``,`$``.@!````````
M#`<````````W`0``!P0``&\#``#'!P``W@0``/D#```@`P``Z@4``#P'``"?
M!P```````/T!``"$`P```````#P```!E!```:P4``!$`````````50$``"4`
M``"$!0```````$4"````````9P4```````"O````(@$``$D!````````60,`
M`+T'``#L`@``>0<``+8'``!V````=`8``($`````````Y00``$X#``"\`@``
M``````````!S`@``HP<``'@%``#K!0```````&P"```M!0```````&(!```5
M````WP0``&4'``!N````YP$``"L%````````R0(``-X!``#H`P```````(P'
M````````Q@$``*8$``#&!P``````````````````G0,``/<"````````````
M`-,$``!A!P``+`4```````"R`0``D`4```\"````````YP,``(('``";!0``
M`````&8%``"W!0``R@,``&X&```S!P``SP0``)`$``"8!0``_@8``!@$``#2
M!@````````\!``"F!P``R`4``,4```#L!@```````(P```!O`@``^04``&,'
M``"G`````@4``$`&``"#`P``0`0``!8```!^`P``X`,``&\%````````>@$`
M``````"/!P``A@0``#\&``"J````TP<`````````````R@8```````"^`@``
M``````````#F!```C0<```8&``"[!```U@8``.X!``#*`@``:@8``"P```",
M`0```0$``+8&``"C!@``$@$``%P'``!3`P```@,``-L'```'`@``;P8``.$&
M````````PP``````````````NP,``)L$``#<````M0,````````Z````Z04`
M`/P#````````^@(``-4!``!!!```30```(4#``#'!```)@,``.H!``":!0``
MA@(``+8$``#I!```]P0```(!``!4!```)`<```````##`P``2`<``"4&``"U
M`@```````.0!``!A!```*P(``.H"``#R!0``O04``-$"```:!@``^P```)`&
M````````80(``+,&``!6`````````/D````B!@``D00```````"#`0``Q0<`
M`/T````(`0```````,L'````````>@,``"H'```\!@```````*$$``")!@``
M8@0```````"_!0``CP0``&T#``"(!0````````````#5!0```````.P!``#_
M`P``?`0`````````````)0,```````">!```YP0`````````````UP8`````
M``"X!P``M`0````````8!@``=P$```,```##!P```````,\'``"R!0``#`(`
M```````Q`0``MP8``(\````?!@``L````,T%```N`P``2`,``.`!``#C!P``
M`````````````````````$@```"<!@``'0(``.T&`````````````,$$```D
M`P``<P,``.(#``````````````````#3!@``&@0```````!<!0``-P,``-L!
M``"W`P``X0```&T"``"@````FP<``)@$``#P`````````,<!````````4```
M````````````I0$``$,"``#2`@``S`(``%$!````````_@```'D```"^`0``
M:@4``$0#````````:0```!4$```3````200``(@'``"B!@``1P$``($#````
M````@08``%H&```"!P``4P(``(T```!Q!@```````)8#``"L!```HP$`````
M````````/0```#4&``!D`P``@@(``'4%```N!@```````$X%``!P`P``````
M`#\'``!#!0``V0```#H$`````````````'$%``#+````!P$``)4!```;!```
M]0,``)(%```I!0``*0(``.0%````````W@(``!("````````SP(``"\"```6
M!@`````````````1`0```````'0`````````R`(``+D"````````IP,`````
M````````X`(``'$$``!V!0``0P```*H%``#?`P``/P,``/<#```L!P``40,`
M``0"``"Z`@``5`(``&D#``!C!0``K0,``!`"``"X`P```````"P$``#V`@``
M`````*8```#$!0````````T```#C!```#P8``*L'``"*!@```````'8&````
M````/0$``'H"``!+!````@```'$"````````#0,```````#=!@``.P``````
M````````*0<``.D```!,````U@4```H&````````3P8``"<!````````?@0`
M`'``````````N@0```````"?`P``Z@,``!\$``"Q`P```````'8'````````
M>P```(`$``#M!```X@$````````@!P```````"@%``!)!0````````````"@
M!0``)`````````"?````504``$,!``"7`@``604``+`$``"B`@``?P```!0!
M```:````K@4`````````````9@(``+T````)!@``P0,`````````````````
M`'L'```Q!P``O0(``)`#````````@P(``),'``"$!```FP(``/8!``#J````
MJ0,``$X$``"H!```W`$``#(%``"O`P``````````````````G@,``#<"``"_
M`@``S@,``%X'```+!@````````````#``0``W0,``*,`````````K08``#H&
M``"I!P``LP(```P$```O!````````,$'````````-`4``(L#```I````M0<`
M`.P````T````=08```````#0````0@<````````M!@``I`````````#B!@``
M008``&X%````````EP`````````````````````````=!````````*T$``!T
M`@``I`(``%8!``#+`0``\@8````````+!P``6`0``(4```!S!```0`<`````
M``!`````'P(``)L&`````````08```````!$!0``>00``$L'``"8!P``````
M`&@&``#Z!0``@0(```````!V!```$P0``$T!``#L!```#@<```($``"0`0``
M7`8``+X%````````"`<``.X%``!&`0``U08```````#4````E`(``)0#``![
M!@```````(X'```_````5P8``#8!``#0`0``:P<``)<#```*`@``"`(`````
M``!/````@P<``)D"``!6`@```````&X'``!U`0``C0(``,H$``"L````8P0`
M``````!T!```@@```)$#``"#!0````````````!!`@``2P4```````"%`@``
M``,`````````````K0````````#V!0``<P8``+0"````````"P4`````````
M````Q@0``)0'```Z`P```````)\$````````%````/8#``"D!0```````!4%
M``#$`0```````,@#````````1P(```D#```@`````````.4!``#T!0``.P$`
M`'\$``##`@``1P```*X!````````"00``#$```!*`@``9P0``/D"``#7!0``
M``````0'```-`0```````/`$``!5!@``BP```&$```!W`@``F````!`%``"5
M!```Y@```&`!```B!0```````)@#``!7````300``'T$``!0!```'0<`````
M````````A`(``.4%````````Q`<```````".`P``"P0``/`&```6!P``````
M`!8#````````U@<``!$'``!7`@``AP$```````#B!P``.`(````````+`P``
M`````(P"``"(`P``I0<``!L%``#U````DP8````````Y!@``4`,```````#9
M!@``%`0``-P'``"@!@``90(```\'``!X`0``]P4```````"N`@``D@,``.D"
M`````````````$@%````````S`4``,<&``#%!0```````"H!```]`@``?`4`
M`!(%``!R````:P(``*D!``".`0``/@8``$T'```B!P```````!4#``!)!P``
M6P,``.@$``!!!P``J04``/$#``!F`0``-@(```<&``#D````M`4```````#Q
M!0```````````````0``*`0``/\%````````<0,``%$$``!P!0``,04``&\'
M``````````````````"6````&P8``'P#``#4`@``1`````````#.````````
M````````````?`$````````\`@``H`(`````````````E0,``!,#````````
M`````'D!```````````````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E
M<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E
M<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N
M;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@
M=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O
M=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W
M87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL
M;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R
M('!A<W-W;W)D(&5X<&ER97,N`"5D(&YO=&5S`"5D+61A>2!F;W)E8V%S=``E
M<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@
M5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E
M<R`E<P`E<R!C:&%R86-T97)S`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R
M=&5D`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S
M('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`
M)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z(%1H:7,@;65S<V%G92!M
M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O
M9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T
M:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U
M<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,`+2T@<V5L96-T("TM`#$@;F]T90`Q,B!(;W5R($9O<FUA=``R-"!(;W5R
M($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I
M;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%0
M22!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S
M;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C97-S(&1E;FEE
M9"!D96QE=&EN9R!N;W1E+@!!8V-E<W,@9&5N:65D(&UO=FEN9R!T:&4@;F]T
M92X`06-C97-S(&1E;FEE9"!S879I;F<@;F]T92!T;R`E<RX`06-C97-S(&1E
M;FEE9"!S879I;F<@;F]T93H@)7,`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O
M=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!
M9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z
M`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD
M(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B
M`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V%T96=O<GD`061D(&-O;'5M;@!!9&0@
M;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A
M9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+@!!9&1I;F<@02!.97<@3F]T90!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N
M`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`
M06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R
M;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L
M=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE
M`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`
M06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E
M9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N
M<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!
M<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`
M07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N
M=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!
M<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I
M9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S
M=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T
M;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL
M960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL
M960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H
M96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L
M92!#871E9V]R:65S.@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/
M1D@@17AC=7-E<P!"86-K('1O($YO=&5P860`0F%C:R!T;R!.;W1E<&%D($]P
M=&EO;G,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O
M<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A
M:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O
M<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S
M96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H
M=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@
M;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L
M:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E
M<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O
M;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!4
M97)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@
M3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S`$-35@!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`
M0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T
M;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N
M(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#
M86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F
M:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A
M;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@
M5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#
M871E9V]R>0!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R
M=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I
M;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX
M.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`
M0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@
M4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I
M;VYS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI
M;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L
M:7-T<RD`0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T
M:&4@<W5M;6%R>2!V:65W+@!#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N
M`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N`$-L96%R`$-L96%R($9O<FT`0VQE87(@35-/9F9I8V4@=&%G<P!#
M;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A
M<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#
M;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S
M($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S
M92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O
M;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L
M97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO
M;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O
M;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T
M:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U
M=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R
M92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE
M8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T
M>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N
M=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E
M<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV
M;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O
M('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T
M(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@
M<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES
M="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T
M86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@
M;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@
M;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N
M;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V
M97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P
M9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U
M<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`
M0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L
M9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@
M;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@
M4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@
M57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R
M<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])
M."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E
M($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y
M`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R
M96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E
M;G1I='D`1&5F875L="!.;W1E<&%D`$1E9F%U;'0@4VAE;&P`1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$
M969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($-O;F9I<FUA
M=&EO;@!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO
M;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!B=71T;VX@8F5H
M879I;W5R`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$
M96QE=&4@=&AI<R!N;W1E`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-E;F1I;F<`1&5S8W)I
M8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5S8W)I<'1I;VXZ`$1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`
M1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT
M.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O
M(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA
M>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F
M;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I
M9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!C;VYF
M:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`
M1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D
M;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+@!%4E(`16-U861O<@!%9&ET`$5D:70@(B5S(@!%9&ET($)L;V-K`$5D:70@
M1W)O=7``161I="!.;W1E`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I
M;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@8V%T96=O<FEE<R!A
M;F0@8V]L;W)S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G
M>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D
M<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C
M;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M
M<'1Y($YO=&4`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S
M96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O
M;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S
M96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y
M;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES
M('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@
M:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN
M96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P
M9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`
M175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y
M(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y
M(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U
M=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E
M9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@
M1&%T90!%>'!O;F5N=`!%>'!O<G0`17AP;W)T($YO=&5S`$9'($-O;&]R`$94
M4"!U<&QO860@;V8@<V5T=7``1E]U;&P@5&5X=`!&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T
M;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@
M;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L
M:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@
M17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI
M:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I
M>`!&:6=L970@0T%05$-(00!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL
M90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE
M`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@
M<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1
M=6%R=&5R`$9I>"!R871I;P!&;&EP`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O
M<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`
M1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R
M;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC
M:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E
M<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@3W!T
M:6]N<P!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E
M`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!'
M;&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E
M87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E
M;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D
M(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E
M`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U
M97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R
M;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z
M90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES
M;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I
M9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`
M2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE
M`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R
M97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N
M8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A
M9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O
M8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL
M)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E
M<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@
M4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y
M;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU
M;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO
M="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@
M0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@
M=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L
M87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W
M+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U
M<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S
M86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A
M9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0
M<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE
M<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM
M<&]R="!.;W1E<RP@4W1E<"`E9`!);7!O<G0L(%-T97`@)60`26UP;W)T+T5X
M<&]R="!.;W1E<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R
M<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@
M57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@
M;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS
M97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T
M(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@
M=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN
M<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L
M=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E
M<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F
M;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U
M9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES
M=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)
M4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N
M`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@
M:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T
M>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`
M26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV
M86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI
M9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI
M9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@
M36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET
M86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M
M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#
M96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT
M`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+
M97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y
M<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N
M("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`
M3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA
M<W0@36]D:69I960`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R
M`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,
M96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE
M861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N
M($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`
M3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,
M:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H
M="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;FL`3&EN:R!P;VEN=',@=&\Z
M`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W
M:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@
M5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES
M="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T
M+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE
M.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E
M=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG
M('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I
M;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-
M3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'
M`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI
M;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@
M<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L
M86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS
M=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F
M:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET
M+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M
M8F5R(&]F($YO=&5S`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`
M36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-
M96UO(%1E>'0`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A
M9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R
M=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER
M960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE
M=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES
M(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-
M:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1I9GEI;F<@)7,`36]D=6QU<P!-
M;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD
M('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE
M;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO
M<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@
M9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N
M(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@
M06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY($YO=&5S`$UY(%!O
M<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G
M<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H
M97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#
M02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C
M87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C
M87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.
M97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@365S<V%G92!T;R`E<P!.
M97<@36]O;@!.97<@3F]T90!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@
M6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W
M("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`
M3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI
M9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R
M961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U
M<&QO861E9`!.;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N`$YO(&EC;VYS
M(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I
M9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`
M3F\@;F]T97!A9',@87)E(&%V86EL86)L92!T;R!G=65S=',N`$YO(&YO=&5S
M`$YO(&YO=&5S(&UA=&-H('1H92!C=7)R96YT(&-R:71E<FEA+@!.;R!N;W1E
M<R!T;R!D:7-P;&%Y`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV
M92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO
M9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,
M(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S
M<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I
M9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P
M96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D
M:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D
M`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BX`3F]?=&4`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO
M<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE
M;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@
M069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N
M=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&4@0V%T96=O<GD`3F]T
M92!$971A:6QS`$YO=&4@3&ES=',`3F]T92!497AT`$YO=&4@7U1E>'0`3F]T
M92!N;W0@9F]U;F0N`$YO=&5?<&%D`$YO=&5P860G<R!N86UE.@!.;W1E<&%D
M<P!.;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE+@!.;W1E<P!.;W1E<R!3=6UM
M87)Y`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB
M97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M
M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A
M=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A
M;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W
M;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C
M:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E
M;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES
M871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA
M:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E
M9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$`4$A0($-O9&4`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`
M4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!A9&1I;F<`4&%K:7-T86X`4&%L
M874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P
M=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D
M`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O
M<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A
M=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A
M<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R
M;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R
M8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E
M<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`
M4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N
M86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H
M;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R
M979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I
M;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE
M;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U
M8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O
M`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y
M`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO
M;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@
M86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E
M860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@9&5L971E('1H:7,@;F]T
M93\`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M`%)E9G)E<V@@3&ES=`!2969R97-H(%!O<G1A;"!6:65W.@!296QA=&EO;G-H
M:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E
M`%)E;6]V92!";&]C:P!296UO=F4@8V%T96=O<GD`4F5M;W9E(&-O;'5M;@!2
M96UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E
M('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V
M92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC
M92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I
M9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S
M<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L
M9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E
M<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E
M='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO
M;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H
M="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE
M`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`
M4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E
M<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@<W1A=&5M96YT
M(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-A`%-A:6YT($AE;&5N
M80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE
M<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@
M5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R
M86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O
M;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5A<F-H(%)E<W5L=',`4V5A<F-H(%-C;W!E`%-E87)C:"!?
M5&5X=`!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U
M<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A(&YO=&5P860`
M4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A
M;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE
M8W0`4V5L96-T(&YO;F4`4V5L96-T(&YO=&5P861S('1O(&1I<W!L87DZ`%-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F;W)M870Z
M`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9F]R;6%T
M(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@
M=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5L96-T960@0V%T96=O<FEE<SH`4V5N9"!0
M<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE
M;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@86-T:6]N
M(&)U='1O;G,_`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&YO
M=&5P860@;F%M93\`4VAO=R!N;W1E<R!F<F]M('1H97-E(&-A=&5G;W)I97,`
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E
M('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R
M<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`
M4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N
M871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP
M($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W
M97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E
M<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R
M.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T
M(&)Y($-A=&5G;W)Y`%-O<G0@8GD@3F]T92!497AT`%-O<G0@;W)D97(@<V5L
M96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@
M<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P
M;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA
M;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R
M;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3
M=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H
M92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO
M="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@
M861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT
M:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`
M4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M
M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O
M;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@
M8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D("(E<R(N`%-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A
M=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S
M9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A
M;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR
M:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R
M:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@
M9&5L971E9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!
M<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R
M;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R
M=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@
M;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E
M<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`
M5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`
M5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4
M:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES
M<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@
M8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T
M:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I
M9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@
M<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B
M965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@
M;F]T92!W87,@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!C;W5L9&XG="!B
M92!C<F5A=&5D.B`E<P!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&-R96%T
M960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO
M=&5P860@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&YU;6)E<B!O9B!F:65L
M9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@
M<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N
M;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T
M97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O
M;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL
M92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T
M;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG
M(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@
M=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL
M;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE('9.;W1E(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I
M<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@
M<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N
M;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E
M<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T
M86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@=&AI
M<R!N;W1E<&%D.B`E<P!4:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="X`
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R
M9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H
M:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`
M5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T
M960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R
M`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@
M<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`
M5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN
M9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO
M<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`
M5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`
M5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z
M(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<P!5;F%B;&4@
M=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L
M92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5
M;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&\@8VAA;F=E<P!5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@
M16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P
M<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,`
M56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E
M('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5
M<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@
M;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA
M;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``
M57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y
M(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!6
M86QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@
M0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I
M8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6
M:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6
M:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!7
M90!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!7
M96(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC
M;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U
M.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@
M)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R
M96ES($%U<W1R86QI82!M87``5VAI8V@@3F]T97!A9"!S:&]U;&0@=&AE(&YO
M=&5S(&)E(&%D9&5D('1O/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T
M;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T
M:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE
M9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H
M92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L
M>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES
M:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE
M+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&YO=&5S+@!9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E<FUI
M<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A9"`E<RX`66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N
M92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\`66]U(&UU<W0@<V5L96-T(&$@;F]T97!A9"!T;R!B92!D96QE=&5D
M+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@
M86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O
M<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L
M;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D
M<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H
M('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD
M+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@
M4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A
M=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I
M9&5N=&ET>3H`66]U<B!D969A=6QT(&YO=&5P860Z`%EO=7(@9G5L;"!N86UE
M.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F
M;W(@)7,@:7,Z("5S`%EO=7(@;F]T97!A9',Z`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E
M;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W
M90!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1
M=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML
M:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T)A8VL@=&\@3F]T97!A
M9`!?0TQ)`%]#871E9V]R>0!?1&5L971E`%]$96QE=&4@4F]W`%]%9&ET`%]&
M:7)S="!,:6YE`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TEM<&]R="]%>'!O<G0`7TQI<W0@3F]T97,`7TQO9R!I;@!?3&]G(&]U=`!?
M36]D:69Y($QI;FLN+BX`7TUY($YO=&5P861S`%].97<@3F]T90!?3W!T:6]N
M<P!?4&5R;6ES<VEO;G,`7U!R:6YT`%]296UO=F4@3&EN:RXN+@!?4V5A<F-H
M`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B
M;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R
M96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E
M`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R
M`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R
M;W(`961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H;W-T(&YA;64@=6YK;F]W
M;@!I;6UE9&EA=&4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W
M87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@
M;6%K:6YG($E33RX`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L
M96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX
M96QS`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U
M;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%14
M4`!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I
M;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N;F%M
M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`4')O:F5C="U)9"U697)S:6]N.B!-
M;F5M;R`R+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,3<@,3`Z,#`K,#$P
M,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$W(#$R.C$U*S`R,#`*3&%S
M="U4<F%N<VQA=&]R.B!,87-Z;&\@3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI
M82YS;W1E+FAU/@I,86YG=6%G92U496%M.B!(=6YG87)I86X@/&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,@I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@`@*"5S(&YA<'!A;"!E>F5L]71T*0`@*$%L
M="UB:6QL96YT>?L@)7,I`"`H)7,@;F%P(&WZ;'9A*0`@*&UA*0`@*&AO;&YA
M<"D`("AT96=N87`I`"`Z(``B)7,B(&YE;2!A;&OV;GEV=.%R+@`B)7,B(&YE
M;2#I<G;I;GEE<R!VX6QA<WITX7,N`"(E<R(@;FEN8W,@:V]N9FEG=7+A;'9A
M(&$@2&]R9&4@4F5G:7-T<GEB96XN`"(E<R(@9F%S=')U:W3Z<F$M;65G:F5L
M96[M=/4@;F5M('1A;.%L:&%T\RX`(B5S(BUT(&AO>GKA861T=6L@82!C<V]P
M;W)T;VMH;WHN`"(E<R(M="!H;WIZX6%D='5K(&$@:F]G;W-U;'1SX6=I(')E
M;F1S>F5R:&5Z+@`B)7,B+70@;F5M(&AO>G1U:R!LZ71R93H@)7,N`"4N,F9-
M0B!F96QH87-Z;N%L="!A("4N,F9-0B!M96=E;F=E9&5T=&+U;"`H)2XR9B4E
M*0`E9"`E<R#I<R`E<P`E9"!N87`@;?IL=F$@;&5JX7(@:F5L<WIA=N%N86L@
MZ7)VZ6YY97-SZ6=E+@`E9"!F96QJ96=Y>NES`"5D(&YA<&]S(&5L]7)E:F5L
M>NES`"5S("T@1FEG>65L;65Z=&5TZ7,`)7,@;&5N>6]M870`)7,@:V%R8F%N
M=&%R=.%S:2!F96QA9&%T;VL@+2!M96=E<O5S[73I<P`E<R!B9>%L;.UTX7,`
M)7,@;&]G:6X@;NEV(&EGZ6YY;.ES`"5S('-Z;VQGX6QT873A<VD@9F5L=.ET
M96QE:P!!("(E<R(@;F5V^R#A;&QO;>%N>2!MX7(@;.ET97II:RX`)7,@.B`E
M<R`E<P`E<R!K87)A:W1E<@!!("5S(&;A:FP@:6UP;W)TX6SA<V$@<VEK97)E
M<V5N(&UE9W3V<G3I;G0`02AZ*2`E<R!KZ7-Z96X@X6QL(&%Z(&%LX6)B:2!K
M87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<^ER92Y*96SV;&IE(&MI
M(&%Z;VMA="!A(&9E;&%D871O*&MA*70L(&%M:2AK92ET(&UO<W0@96P@:^UV
MX6X@=NEG97IN:2X`)7,@:VET]FQTZ7-E('-Z_&MSZ6=E<P`E<R!P97)C`"5S
M(&YE;2!T86SA;&AA=/,N`"5S("T@)7,@*/9S<WIE<V5N("5S*0`E<R!C[6UJ
M96=Y>NEK90`E<R!N87!TX7)A`"5S(&9E;&IE9WEZZ7-E:0`E<R!F96QA9&%T
M;&ES=.%J80`E<SH@3&5H971SZ6=E<RP@:&]G>2!E>B!A(&QE=NEL('9A;/-J
MX6)A;B!N96T@82!M96=A9&]T="!F96QA9/-T\VP@<WKA<FUA>FEK+B!';VYD
M;VQJ82!M96<L(&UI96SU='0@<N%K871T:6YT('9A;&%M:7)E+"!V86=Y('-Z
M96WI;'EE<R!I;F9O<FWA8VGS="!A9"!M96<N`"P@<WKI;&SV:^ES96L`+"`E
M<R`E<RUS('-ZZ6QL]FOI<V5K`"P@=N%L=&]Z\R`E<R#I<R`E<R!K]GKV='0`
M+2T@=N%L87-S>F]N("TM`#$@9F5L:F5G>7KI<P`Q,B#S<N%S(&9O<FWA='5M
M`#(T(/-RX7,@9F]R;>%T=6T`,C0@\W)A`#Q%;/5Z]0!%>F5N(&)L;VMK(&AA
M<WINX6QA=.%H;WH@96=Y(&%D871BX7II<R!A;')E;F1S>F5R('-Z_&MSZ6=E
M<RX`2&5L>7)E:&]Z:&%T871L86X@:&EB82!T]G)TZ6YT`$$@;&5VZ6P@=&ET
M:V]S[73A<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,@<WK\:W/I9V5S
M+@!!(&1I9VETX6QI<V%N(&%LX>UR="!L97;I;"!E;&QE;O5R>NESZ6AE>B!E
M9WD@;GEI;';A;F]S(%!'4"!K=6QC<R!S>OQK<^EG97,N`$$@=&ET:V]S[71O
M='0@;&5VZ6P@9&5K\V1O;.%SX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC
M<RP@96=Y('1I=&MO<R!01U`@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK
M<^EG97,N`$$@;&5VZ6P@9&EG:73A;&ES(&%LX>URX7/A:&]Z(&5G>2!N>6EL
M=N%N;W,@4$=0(&MU;&-S+"!E9WD@=&ET:V]S(%!'4"!K=6QC<R#I<R!E9WD@
M:F5L;6]N9&%T('-Z_&MSZ6=E<RX`02!T:71K;W/M=&]T="!L97;I;"!D96OS
M9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU;&-S+"!E9WD@=&ET
M:V]S(%,O34E-12!K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z_&MSZ6=E<RX`
M02!L97;I;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y(&YY:6QVX6YO<R!3
M+TU)344@:W5L8W,L(&5G>2!T:71K;W,@4R]-24U%(&MU;&-S(.ES(&5G>2!J
M96QM;VYD870@<WK\:W/I9V5S+@!!(&QE=NEL('1I=&MO<^UTX7/A:&]Z(&5G
M>2!N>6EL=N%N;W,@4R]-24U%(&MU;&-S('-Z_&MSZ6=E<RX`1.EL96SU='0@
M8F]R=6QT(.EG`$3I;&5L]71T(&=Y96YG92!E<_4`1.EL96SU='0@97/U`$3I
M;&5L]71T:2!ZX7!O<F]K`$3I;&5L]71T(&CS>N%P;W)O:P!D92]D=0!!4$D@
M240@*&$@<')O9W)A;6]ZX7-I(&9E;/QL970@87IO;F]S[73S:F$I`$5R<O5L
M(&%Z(&5D:71O<G+S;`!.Z79J96=Y+BXN`&%B<WH@86QU;`!A8G-Z(&OV>NEP
M`$YI;F-S(&IO9V]S=6QT<^%G82!A(%9&4R!A;&OV;GEV=.%R(&SI=')E:&]Z
MX7/A:&]Z+@!.:6YC<R!J;V=O<W5L='/A9V$@82!61E,@9N%J;"!LZ71R96AO
M>N%SX6AO>BX`3FEN8W,@:F]G;W-U;'1SX6=A(&$@9F5L:F5G>7KI<R!T]G)L
MZ7/I:&5Z+@!.:6YC<R!J;V=O<W5L='/A9V$@82!F96QJ96=Y>NES(.%T:&5L
M>65ZZ7/I:&5Z+@!.:6YC<R!J;V=O<W5L='/A9V$@82!F96QJ96=Y>NES("5S
M+6)E('3V<G3I;O4@;65N=.ESZ6AE>BX`3FEN8W,@:F]G;W-U;'1SX6=A(&$@
M9F5L:F5G>7KI<R!E;&UE;G3I<^EH97HZ("5S+@!"96IE;&5N=&ME>NES:2!I
M;F9O<FWA8VGS`$IE;'-Z\P!!(&IO9V]S=6QT<^%G(&9E;"!V86X@9OQG9V5S
M>G1V92X`4.EN>OQG>65K`$)E=FET96P`06QC<V]P;W)T(&SI=')E:&]ZX7-A
M`$IO9V]S=6QT<^%G:2!A;&-S;W!O<G0@;.ET<F5H;WKA<V$`061D:G5K(&AO
M>GKA(&ET=#H`VFH@8W-O<&]R="!LZ71R96AO>N%S80#::B!J;V=O<W5L='/A
M9R!LZ71R96AO>N%S80!!;&-S;W!O<G0@:&]Z>N%A9.%S82`B)7,B+6AE>@!*
M;V=O<W5L='/A9VD@86QC<V]P;W)T(&AO>GKA863A<V$@(B5S(BUH97H`VFH@
M9F5L:&%S>F[A;/,@;.ET<F5H;WKA<V$Z`$MA=&5G\W)I82!H;WIZX6%DX7-A
M`-IJ(&]S>FQO<"!H;WIZX6%DX7-A`-IJ('1A9V]K(&9E;';I=&5L90#::B!P
MX7(@:&]Z>N%A9.%S80!!*'HI("5S(&UE;OQT(&%D:G5K(&AO>GKA(&$@36]Z
M:6QL82!M96[\<V]R:&]Z`$%D:G5K(&AO>GKA(&$@8^UM:F5G>7KI:VAE>CH`
M061J=6L@:&]Z>N$@82!C[6UJ96=Y>NEK96UH97H`VFH@9F5L:&%S>F[A;/,@
M:&]Z>N%A9.%S80`B)7,B(&9E;&AA<WINX6SS="!H;WIZX6%D='5K(&$@<F5N
M9'-Z97)H97HL(&1E(&YE;2!S:6ME<OQL="!A('3V8F)I(&)E:F5L96YT:V5Z
MZ7-I(&%D870@=.%R;VSA<V$Z("5S+@`B)7,B(&9E;&AA<WINX6SS="!F96QV
M971TZ6L@82!R96YD<WIE<F)E+B!-;W-T(&WA<B!B96IE;&5N=&ME>FAE="X`
MVFH@9F5L:F5G>7KI<R!KZ7-Z[73I<V4`02!R96YD<WIE<FAE>B!N96T@861H
M873S:R!H;WIZX2#Z:B!F96QH87-Z;N%L\VLN`$/M;0!#[6UJ96=Y>NEK`$%D
M;6EN:7-Z='+A8VGS("T@:F]G;W-U;'1SX6=O:R!A9.%S82!T;W;A8F)I(&9E
M;&AA<WINX6SS:VYA:P!!9&UI;FES>G1RX6-I\P!(:7)D973I<V5K`$%F9V%N
M:7-Z=.%N`$%L8N%N:6$`06QGZ7)I80!!;&EA<P!%;&AE;'EE>NES`%)E;F1E
M>NES.@!A>B#V<W-Z97-E=`!-:6YD96X@;F5M('9E;F3I9R!F96QH87-Z;N%L
M\P!-:6YD96X@8W-O<&]R=`!-:6YD96X@:F]G;W-U;'1SX6<`36EN9"!A(&[I
M9WD@;VQD86QO;B!L96=Y96X@:V5R970`16YG961J_&YK(&UE9R!T]F)B(&/M
M;65T(&ES`$$@<V]R<WKA;6]S(&9E;'-O<F]LX7,@=.UP=7-A(';A;'1O>G1A
M=&AA=/,@;&5G>65N/P!-X7(@;.ET97II:P!)35-0(&)E:F5L96YT:V5ZZ7-I
M('!A<F%MZ71E<F5K`$WA<VEK+"!)35-0(&IE;'-Z\P!-X7-I:RP@24U34"!B
M96IE;&5N=&ME>NES:2!NZ78`3>%S:6L@96UA:6P@8^UM`$%L=&5R;F%T[78@
M<V%B;&]N;VL`06QT97)N873M=B!S>O9V96<Z`$%M97)I:V%I(%-Z86UO80!!
M(&UE9V%D;W1T(.ER=.EK(&YE;2!F;V=A9&AA=/,@96PN`$ES;65R971L96X@
M:&EB82!T]G)TZ6YT+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N:6T@
M<')O>'EN(&ME<F5S>G3\;&D@:6YT97)N970@96SI<NES`%;A;&%S>@!!;G1A
M<FMT:7-Z`$%N=&EG=6$@Z7,@0F%R8G5D80!!;&MA;&UA>N%S`$%L:V%L;6%Z
MX7-O:R!L:7-TX6IA`$%Z(&%L:V%L;6%ZX7,@:^ES>BX`02!K]GKV<R!TX7)T
M97+\;&5T(&%L8W-O<&]R=&IA:7)A(&ES(.ER=NEN>65S`$KS=N%H86=YX7,`
M2_9R_&QB96S\;&D@;>ER970`X7!R:6QI<P!A<F%B("A7:6YD;W=S+3$R-38I
M`$$@=/9M]G+M=&5T="#A;&QO;>%N>2!MZ7)E=&4`02!T]FWV<NUT971T(.%L
M;&]MX6YY(&YE=F4`0FEZ=&]S(&)E;FYE+"!H;V=Y('3V<O9L;FD@:^UVX6YJ
M82`E<R!B96IE;&5N=&ME>NES:2!I9^EN>>ET/P!":7IT;W,L(&AO9WD@=/9R
M]FQN:2!A:V%R:F$@(B5S(BUT(&%L8W-O<&]R=&IA:79A;"!E9WG\='0_`$%R
M9V5N=.UN80#6<FWI;GEO<G-ZX6<`]G)MZ6YY("A!4DU30TE)+3@I`$W[=NES
M>F5T`$%R=6)A`&[V=F5K=O4`4&]H;G!E:0!!<V-I:2!R86IZ;VL`P7IS:6$O
M0W-E;F1E<RWS8V7A;FD@<NEG:?,`2^ER:F5N(&$@<F5N9'-Z97(@;65G97+U
M<^UTZ7-T(&$@:V%R8F%N=&%R=.%S:2!F96QA9&%T;VL@96QVZ6=ZZ7-E(&5L
M]71T/P!(;WIZX7)E;F1E;.ES:2!O<WIL;W!O:P!.96ULZ71E>O4@8W-O<&]R
M=&]T(&OM<^ER96QT(&UE9R!T]G+V;&YI+@!.96ULZ71E>O4@:F]G;W-U;'1S
MX6=O="!K[7/I<F5L="!M96<@=/9R]FQN:2X`3F5M;.ET97KU(&IO9V]S=6QT
M<^%G;W0@:^USZ7)E;'0@;65G(&UE9W;A;'1O>G1A=&YI+@!.96ULZ71E>O4@
M:_9Z]G,@=.%R=&5R_&QE=&5T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT871N
M:2X`5'5L86ID;VYSX6=O:P!A=6=U<WIT=7,`075S>G1RX6QI80!!=7-Z=')I
M80!!=71H7V-Y<G-Q;#H@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T
M86SA;&AA=/,N`$%U=&A?8WER=7,Z(&$@:.%T=.ER<WIO;&?A;'1A=.%S(&YE
M;2!R96YD96QK97II:R!A(&OM=N%N="!KZ7!E<W/I9V5K:V5L+@!!=71H7V-Y
M<G5S.B!A('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`
M075T:%]F='`Z(&$@<WK\:W/I9V5S(&9T<"!B]7;M=.ES(&YE;2!T86SA;&AA
M=/,N($9O<F3M='-A(&QE(&$@4$A0+70@87H@+2UE;F%B;&4M9G1P(&]P8VGS
M=F%L+@!!=71H7VEM87`Z(&$@<WK\:W/I9V5S(&EM87`@8O5V[73I<R!N96T@
M=&%LX6QH873S+@!!=71H7VMR8C4Z(&$@<WK\:W/I9V5S(&MR8C4@8O5V[73I
M<R!N96T@=&%LX6QH873S+@!!=71H7VQD87`Z(&YE;2!H;WIH873S:R!LZ71R
M92#Z:B!F96QH87-Z;N%L\VL@06-T:79E($1I<F5C=&]R>2!E<V5TZ6X`075T
M:%]L9&%P.B!F96QH87-Z;N%L\VL@;F5M('3V<O9L:&5T]6L@06-T:79E($1I
M<F5C=&]R>2!E<V5TZ6X`075T:%]L9&%P.B!A('-Z_&MSZ6=E<R!,1$%0(&+U
M=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]L9&%P.B`E<R!F96QH87-Z;N%L
M\R!H;WIZX6%DX7-A(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R(';A;&%S>F$Z
M(`!!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS('3V<FSI<V4@;F5M('-I:V5R
M_&QT`$%U=&A?;&1A<#H@)7,@9F5L:&%S>F[A;/,@861A=&%I;F%K(&UE9_IJ
M[73A<V$@;F5M('-I:V5R_&QT`$%U=&A?;&1A<#H@82!F96QH87-Z;N%L\VL@
M;F5M(&WS9&]S[71H873S:R!!8W1I=F4@1&ER96-T;W)Y(&5S973I;@!!=71H
M7VUC86PZ(&$@<WK\:W/I9V5S($U#04P@8O5V[73I<R!N96T@=&%LX6QH873S
M+@!!=71H7W-M8F%U=&@Z(&$@<WK\:W/I9V5S('-M8F%U=&@@8O5V[73I<R!N
M96T@=&%LX6QH873S+@!.96T@<VEK97+\;'0@87H@24U!4"!S>F5R=F5R96X@
M=F%L\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N`$$@9F5L:&%S>F[A;/-A>F]N
M;W/M=.%S(&YE;2!S:6ME<OQL="X`02!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@
M;F5M('-I:V5R_&QT+B`E<P!!(&9E;&AA<WINX6SS(&%Z;VYO<^UTX7/A="!A
M(%)!1$E54R!S>F5R=F5R(&5L=71A<^UT;W1T82X`3F5M('-I:V5R_&QT(&%Z
M($944"!S>F5R=F5R:&5Z('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S+@!.
M96T@<VEK97+\;'0@87H@4TU"('-Z97)V97)E;B!V86SS(&9E;&AA<WINX6SS
M87IO;F]S[73A<RX`02!R96YD96QK97KI<W)E(.%L;/,@:V%T96?S<FGA:SH`
M02!R96YD96QK97KI<W)E(.%L;/,@;65Z]6LZ`$%Z97)B86ID>G/A;@!!(&=O
M;F]S>B!R96YD<WIE<F=A>F1A(&UE;G1SZ6=E:0!6:7-S>F$@82!F96QJ96=Y
M>NES96MH97H`5FES<WIA(&$@9F5L:F5G>7KI<V5K(&)EX6QL[73A<V%I:&]Z
M`$CA='3I<@!(X71TZ7(@<WKM;@!.96T@;65G9F5L96SU(&ME<F)E<F]S(&IE
M;'-Z\RX`3F5M(&UE9V9E;&5L]2!K97)B97)O<R!F96QH87-Z;N%L\V[I=BX`
M0F%H86WA:P!"86AR96EN`&)A;'1I("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M`$)A<F)A9&]S`$$@9W)A9FEK=7,@X6QL;VWA;GEO:R`B)7,B(&%L:_9N>79T
MX7)A(&YE;2!T86SA;&AA=/,N`&%L87!V;VYA;&]N`$9E:.ER;W)O<WIO<G-Z
MX6<`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5TX6X`4WK\;&5T
MZ7-N87``02`B)7,B(&)L;VMK(&$@(B5S(B!P<F]G<F%M;6%L(&YE;2!T86SA
M;&AA=/,N`$OI<&5R;GGU<NES>B!B9>%L;.UTX7,`2^EP97)N>?5RZ7-Z('3M
M<'5S`&;I;&OV=NER`$)O;.UV:6$`2V5D=F5N8R!W96)C[6UE:P!+97)E=`!+
M97)E='9A<W1A9W/A9SH`2V5R971E:P!";W-Z;FEA+4AE<F-E9V]V:6YA`$UI
M;F1K971T]0!";W1S=V%N80!A;'5L`$)O=79E="US>FEG970`0G)A>NUL:6$`
M0G)I="!);F1I86DM\V-EX6YI(%1E<OQL970`0G)U;F5I($1A<G5S<V%L86T`
M0G5L9^%R:6$`1F5L<V]R;VSA<P!"=7)K:6YA($9A<V\`0G5R=6YD:0!796)O
M;&1A;"!K87)B86YT87)TX7,`0U)#`$$@=&%N^G/M=';A;GEV:7-S>F%V;V[A
M<VD@;&ES=.%K("A#4DPI(&/M;65I`$-35@!#96QL82!T=6QA:F1O;G/A9V]K
M`$$@8V%C:&4@:6YI8VEA;&EZX6SA<V$@;F5M(&9E:F5Z]63V='0@8F4N`$YA
M<'3A<@!.>75G;V1T`$MA;6)O9'IS80!+86UE<G5N`$YE;2!S:6ME<OQL="!A
M(&IE;'-Z\W0@X73A;&SM=&%N:2P@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87ID
MX6AO>BX`02AZ*2`B)7,B(.%L;&]MX6YY(&YE;2#M<FAA=/,N`$$@:_QL<_4@
M9F5L:&%S>F[A;/-K87!C<V]L870M:V5Z96SU:R!N96T@861M:6YI<WIT<N%L
M:&%T\VLN`$$@:_9V971K97KU($E-05`@<WIE<G9E<B!N96T@Z7)H973U(&5L
M.B`E<P!!*'HI("(E<R(@X6QL;VWA;GD@;F5M(&YY:71H873S(&UE9RX`2V%N
M861A`$WI9W-E`$WI9W-E(&O\;&3V:R!H:6)A:F5L96YTZ7-T`$$H>BD@(B5S
M(B#A;&QO;>%N>2!N96T@=/9R]FQH973U+@!.96T@=&%LX6QH873S(&%Z(&ED
M96EG;&5N97,@X6QL;VWA;GEO:V%T('1A<G1A;&UA>O,@86QK]FYY=G3A<BX`
M02`G=&%R9V5T1FEL92<@<&%R86WI=&5R(&UE9V%DX7-A(&[I;&O\;"!N96T@
M9F]L>71A=&AA=&IU:RX`02AZ*2`B)7,B(&%L:_9N>79TX7(@;F5M('3V<O9L
M:&5T]2X`3F5M('3V<O9L:&5T]2P@)60@86QC<V]P;W)T:F$@=F%N+@!!>B#Z
M:B!S;W)B87)E;F1E>NES(&YE;2!L96AE='/I9V5S+"!A(&UE9V%D;W1T(&%D
M871O:R!S>N%M82!N96T@96=Y97II:R!A('3A<F]L=&%KZ79A;"X`02!M96=A
M9&]T="!S>N%M<F$@;F5M(&O\;&1H973U(&5L(&%Z(/QZ96YE="X`6O9L9"UF
M;VMI+7-Z:6=E=&5K`,%B<F%S>O9V96<`4WIO;&?A;'1A=/,`2V%T96?S<FGA
M:R#I<R!J96SV;.ES_&L`2V%T96?S<FEA`$MA:FWA;BUS>FEG971E:P!-;V)I
M;"!T96QE9F]N`$-E;&QA='5L86ID;VYSX6=O:P!#96QL82!B96QS]2!M87)G
M\SH`0V5L;&%T=6QA:F1O;G/A9V]K`$-E;&SA:R!K]GKV='1I('+I<SH`36]B
M:6P@=&5L969O;@!K96QT82`H25-/+3@X-3DM,30I`&OV>NEP`$OV>NEP+6%F
M<FEK86D@2_9Z=.%R<V%SX6<`:V5L970M975R\W!A:2`H25-/+3@X-3DM,BD`
M02!T86[Z<^UT=N%N>2!RZ7-Z;&5T96D`02!T86[Z<^UT=N%N>2!T=6QA:F1O
M;F]S80!486[Z<^UT=N%N>2!F96QH87-Z;N%LX7-I(&ERX6YY96QV96L`0W/A
M9`!6X6QT;WIT873A<P!!(&IE;'-Z\R#A=.%L;.UTX7-A`$%Z(-9N(.%L=&%L
M(&5L:_QL9/9T="!L979E;&5K96X@<WIE<F5P;/4@;NEV(.ES(&/M;2!M96=V
MX6QT;WIT873A<V$N`$$@<V]R<F5N9')E(.ES(&UE9VIE;&5N[73I<W)E('9O
M;F%T:V]Z\R!B9>%L;.UTX7-O:R!M96=VX6QT;WIT873A<V$N`$$@:F5L96X@
M:V]N9FEG=7+A8VGS8F%N(&YE;2!L96AE='/I9V5S(&$@:F5L<WIA=F%K(&WS
M9&]S[73A<V$N($9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN`$MA<F%K
M=&5R`$QI;E]K96QL96[U<GKI<RXN+@!#:&EL90!+[6YA`&OM;F%I+"!E9WES
M>F5R^W/M=&5T="`H1T(R,S$R*0!K[6YA:2P@:&%G>6]MX6YY;W,@*$)I9S4I
M`%;A;&%S<WIO;B!K:2!E9WD@86QK86QM87KA<W0Z`%;A;&%S<WIO;B!J96QS
M>O-T`%;A;&%S<WIO;B!E9WD@9F5L:&%S>F[A;/-N979E=`!6X6QA<W-Z82!K
M:2!A(&3A='5M;VL@;65G:F5L96[M=.ES:2!F;W)MX6KA=#H`5N%L87-S>F$@
M:VD@82!F96QS;W)O;.%S('3M<'5SX70@*'-ZX6UO>F]T="!L:7-TX6MNX6PI
M`%;A;&%S<WIA(&MI+"!M96QY(&MA=&5G\W)IX6KZ(&9E;&IE9WEZZ7-E:R!J
M96QE;FIE;F5K(&UE9R!A>B#V<W-Z969O9VQA;/-B86XN`%;A;&%S<WIA(&MI
M(&%Z(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&IE9WEZ971T]FUB:NET
M+@!+87+A8W-O;GDM<WII9V5T96L`02AZ*2`E<R!C;&%S<R!D969I;NUC:?-J
M82!N96T@=&%LX6QH873S+@!$97+\;'0`02!M97KU:R!T]G)LZ7-E`%3V<FQI
M(&%Z($U33V9F:6-E('1A9V5K970`02!L96OI<F1E>NES('3V<FSI<V4`)7,@
M9F5L:&%S>F[A;/,@=/9R;.ES90!!(&9E;&AA<WINX6SS('3V<FSI<V4`02!F
M96QH87-Z;N%L\R!A9&%T86EN86L@=/9R;.ES90!%<W3I<F4@9&5R_&QT(.EG
M`$$@9F]L>71A=.%S:&]Z(&MA='1I;G1S;VX@87H@96?I<G)E;`!#;&EC:V%T
M96QL('-Z;VQGX6QT873A<R!(5%10+6X@:V5R97-Z=/QL`$%Z(&%B;&%K(&)E
M>N%RX7-A`$)O<G5L="#I9P!296=G96P@9F5L:/5S(&ED]0!&96QH]7,@:63U
M`$OS:W5S>BUS>FEG971E:P!4_&YT97-S_&L@96P@87H@;VQD86QS\R!M96[\
M=`#6<W-Z97KA<G0@:V5R971E:P!+;VQU;6)I80!3>NUN`%-Z[6YVX6QA<WIT
M\P!3>NUN=N%L87-Z=.%S`$]S>FQO<&]K.@!!>B!O<WIL;W!O:R!C[6UE:0!6
M:6-C96L`4&%R86YC<P!087)A;F-SZ7)T96QM97KU`$UE9VIE9WEZZ7,`3NEV
M+"!E;&YE=F5ZZ7,`0V]M;W)E+7-Z:6=E=&5K`$/I9P!3>N%M[73S9^EP96L`
M263U:N%RX7-I(&AE;'EZ970`263U:N%RX7-I(&AE;'EZ970`2_QL]FYB<^EG
M96L@82!K;VYF:6=U<N%C:?-B86X`2^EZ:7-ZX6WM=/-GZ7!E:VME;"P@;VMO
M<W1E;&5F;VYO:VMA;"P@3W5T;&]O:VMA;"!V86SS(&%D871S>FEN:W)O;FEZ
MX6SA<R!K;VYF:6=U<N%C:?-J80!!(&MO;F9I9W5RX6-I\R!MX7(@;F5M(.ER
M=NEN>65S+@`E<R!K;VYF:6=U<N%C:?-J80!!(&IE;'-Z\R!M96=E<O5S[73I
M<V4`2V]N9_,`2V]N9_-I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9P!3:6ME
M<G1E;&5N(&$@:V%P8W-O;&%T+@!3:6ME<G1E;&5N(&$@:V%P8W-O;&%T.B``
M02!N>6EL=N%N;W,@:W5L8W-O:R!S>F5R=F5R92!E;'5T87/M=&IA(&$@:V%P
M8W-O;&%T;W0N`$$@;GEI;';A;F]S(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S
M[71J82!A(&MA<&-S;VQA=&]T+B!/:V$Z("5S("@E<RD`4VEK97)T96QE;B!A
M>B!&5%`@<WIE<G9E<G)E;"!V86SS(&MA<&-S;VQA="X`4&%R=&YE<F5K`$$@
M<&%R=&YE<F5K970@<VEK97)E<V5N(&AO>GKA861T=6L@82!C[6UJ96=Y>NEK
MZ6AE>BX`02!T]FWV<NUT971T(.%L;&]MX6YY('3M<'5S83H@`"(E<R(@=&%R
M=&%L;6$`1F]L>71A=.%S`$-O;VLM<WII9V5T96L`4_QT:0!-X7-O;&IU:R#A
M=`!!(&WA<V]LX7,@;F5M('-I:V5R_&QT.B`E<P!!(&MI:F5L]FQT('+I<WH@
M;>%S;VSA<V$`4WKA;6SA>N%S:2!A>F]N;W/M=/,`0V]S=&$@4FEC80!%;&5F
MX6YT8W-O;G1P87)T`$YE;2!S:6ME<OQL="!01U`M=F5L('1I=&MO<^UT86YI
M(&$@;&5V96QE=#H@`$$@;&5V96QE="!N96T@<VEK97+\;'0@4$=0(&%LX>UR
MX7-S86P@96QLX71N:3H@`$$@;&5V96QE="!N96T@<VEK97+\;'0@87H@4R]-
M24U%('-Z86)VX6YY('-Z97)I;G0@=&ET:V]S[71A;FDN`$$@;&5V96QE="!N
M96T@<VEK97+\;'0@4R]-24U%(&%LX>URX7-S86P@96QLX71N:2X`02!P87)T
M;F5R(&%D871A:70@;F5M('-I:V5R_&QT(&5L=.%R;VQN:2X@)7,`07H@3$1!
M4"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN`$YE;2!S:6ME<OQL="!E;&QE;O5R
M:7IN:2!A('-ZX6ULX6KA;B!R96YD96QK97KI<W)E(.%L;/,@]G-S>F5G970N
M("5S`$YE;2!S:6ME<OQL="!A>B!,1$%0('-Z97)V97)H97H@:V%P8W-O;/-D
M;FDN`$YE;2!S:6ME<OQL="!A*'HI("(E<R(@<WIE<G9E<G)E;"!&5%`@:V%P
M8W-O;&%T;W0@9F5L=F5N;FDZ("5S`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI
M(&$@:_9R;&5VZ6QL:7-TX70N("5S`$%Z(&%D871O:R!01U`@=&ET:V]S[73A
M<V+S;"!T]G)TZ6[U(&1E:_-D;VSA<V$@;F5M('-I:V5R_&QT.B``07H@861A
M=&]K(%,O34E-12!T:71K;W/M=.%S8O-L('3V<G3I;O4@9&5K\V1O;.%S82!N
M96T@<VEK97+\;'0N`$$@<&%R=&YE<B!T]G)LZ7-E(&YE;2!S:6ME<OQL="X@
M)7,`02!K]G)L97;I;&QI<W1A('3V<FSI<V4@;F5M('-I:V5R_&QT+B`E<P!.
M96T@<VEK97+\;'0@=/9R]FQN:2!A*'HI("(E<R(@<V5T=7`@=7!G<F%D92!P
M<F]G<F%M;W0N`$YE;2!S:6ME<OQL="!M96?A;&QA<.UT86YI(&$@8^UM>F5T
M="!E;6%I;"!C[6WI="X`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A('1E;&IE
M<R!C[6UJ96=Y>NEK970N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!T96QJ
M97,@:_9R;&5VZ6QL:7-TX70N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K
M]G)L97;I;&QI<W3A:R!T96QJ97,@9F5L<V]R;VSA<^%T+@!!*'HI("(E<R(@
M<W1R873I9VEA(&YE;2!T86SA;&AA=/,N`$$H>BD@(B5S(B!A;&OV;GEV=.%R
M(&YE;2!H;WIH873S(&SI=')E+@!!(&YY:6QVX6YO<R!K=6QC<V]T(&YE;2!S
M:6ME<OQL="!M96=S>F5R97IN:2!A(&MU;&-S<WIE<G9E<G+U;"X`3F5M('-I
M:V5R_&QT("(E<R(M="#M<N%S:2!CZ6QL86P@;65G;GEI=&YI+@!.96T@<VEK
M97+\;'0@)7,M="!M96=N>6ET;FDN`$$@)7,@:V%R8F%N=&%R=.%S:2!M;V1U
M;"!N96T@;GEI=&AA=/,@;65G`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!N
M>6ET:&%T\R!M96<N`$%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+@`E
M<R!N96T@;VQV87-H873S+@!.96T@<VEK97+\;'0@82!K[7;A;G0@9F5L:&%S
M>F[A;/,@:F5L<WIA=N%T(.%TX6QL[71A;FDN($%Z(&UE9V%D;W1T(&%D871O
M:R!N96T@=F%G>2!N96T@=&5L:F5S96X@9F5L96QN96L@;65G+B!0<O-BX6QJ
M82#Z:G)A+"!V86=Y(&AA('1O=N%B8FD@<V5G[71SZ6=R92!V86X@<WK\:W/I
M9V4L(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN`$YE;2!S:6ME<OQL
M="!M96=H873A<F]Z;FD@87H@96SI<NES:2!J;V=O<W5L='/A9V]K870@*$%#
M3"D`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&/M;6IE9WEZZ6ME="X@)7,`
M3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV<FQE=NEL;&ES=.%T+B`E<P!.
M96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5VZ6QL:7-TX6MA="X@)7,`
M3F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A('-Z97)V97(@:^EP97-SZ6=E
M:70`3F5M('-I:V5R_&QT('9I<W-Z8>%L;.UT86YI(&5Z(&5R961E=&D@:V]N
M9FEG=7+A8VGS="X`02AZ*2`B)7,B(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T
M]2X`3F5M('-I:V5R_&QT(&5L;65N=&5N:2`E<R!K;VYF:6=U<N%C:?-T+@!.
M96T@<VEK97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I\W0N
M`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82!B86-K=7`@:V]N9FEG=7+A8VGS
M=#H@)7,`3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A*'HI("(E<R(@<V5T=7`@
M=7!G<F%D92!P<F]G<F%M;W0N`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82AZ
M*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="X`02AZ*2`E<R!K;VYF:6=U<N%C
M:?-S(.%L;&]MX6YY="!N96T@<VEK97+\;'0@96QM96YT96YI+B!686=Y(&AA
M<WINX6QJ82!A("5S(&]L9&%L;VX@;&5V]2!L96AE=/5SZ6=E:V5T+"!V86=Y
M(&WA<V]L:F$@X70@87H@86SA8F)I(&OS9&]T(&ED93H@)7,N`$%Z($Q$05`@
M<WIE<G9E<F5N(&YE;2!S:6ME<OQL="!E;';I9V5Z;FD@82!K97)E<^ES="X`
M(B5S(B!N96T@=F]L="!T]G+V;&AE=/4N`$$@<&%R=&YE<B!A9&%T86ET(&YE
M;2!S:6ME<OQL="!M\V1O<^UT86YI+B`E<P!.96T@<VEK97+\;'0@82!K]G)L
M97;I;&QI<W1A(&WS9&]S[73A<V$N("5S`$YE;2!S:6ME<OQL="!E;&UE;G1E
M;FD@(B5S(B!K;VYF:6=U<N%C:?-JX70Z("5S`$$@36]Z:6QL82!M96[\<V]R
M(&YE;2!T86SA;&AA=/,N($5L;&5N]7)I>GIE+"!H;V=Y(&UE9R!V86XM92!N
M>6ET=F$N`$YE;2!S:6ME<OQL="`B)7,B(&9E;&AA<WINX6SS;F%K(&IO9V]S
M=6QT<^%G;W0@861N:2!A*'HI("(E<R(@;6%P<.%H;WHZ("5S`$MO<FSA=&]S
M('-Z]G9E9P!/<G-ZX6<`5.%V;VMT873A<P!,Z71R96AO>N%S`$QI;FL@;.ET
M<F5H;WKA<V$`VFH@;.ET<F5H;WKA<V$`06QM87!PX6L@;.ET<F5H;WKA<V$`
M3.ET<F5H;WIV80!!>B!O8FIE:W1U;2!LZ71R96AO>O-JX6YA:R!J;V=O<W5L
M='/A9V%I`$AI=&5L:^%R='EA<WKA;0!(;W)VX71O<G-ZX6<`2W5B80!*96QE
M;FQE9VD@-"!FX7II<P!!(&IE;&5N;&5G:2!F96QH87-Z;N%L\VMA<&-S;VQA
M=&]K`%!O;G1O<R!I9/4`02!J96QE;FQE9VD@55),`$IE;&5N;&5G:2!F96QH
M87-Z;N%L\VL`2F5L96YL96=I(&ED]6KA<N%S`$$@:F5L96YL96=I(&ED]6KA
M<N%S:2!H96QY>F5T.@!*96QE;FQE9VD@<W3M;'5S`$UI;'EE;B!P87)A;F-S
M;VL@9G5S<V%N86L@;&4@875T;VUA=&EK=7-A;B!A("5S8F4@=/9R=.EN]2!B
M96IE;&5N=&ME>NES:V]R+@!+:7;A9^%S`$$@:VEJ96SV;'0@<NES>B!K:7;A
M9^%S80!#:7!R=7,`8VER:6QL("A+3TDX+5(I`&-I<FEL;"`H5VEN9&]W<RTQ
M,C4Q*0!C:7)I;&PM=6MRX6X@*$M/23@M52D`0W-E:"!+]GITX7)S87/A9P!$
M1`!$4TX@*&%D871F;W)RX7-L9>UR\R`M(&SA<V0Z(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"D`;F%P;VYT80!$871A5')E92!B]FYGZ7-Z]0!!9&%T8N%Z:7-B86X@
M=F%L\R!K97)E<^ES`$3A='5M`$$@8F7I<FME>NES(&YA<&IA`$3A='5M(&MI
M=N%L87-Z=.%S80!N87!P86P`3W-Z;&]P('3V<FSI<V4`9&5C96UB97(`<WKA
M;6]K`$)E:V5Z9.ES(&MI:FIE8F(`06QA<.ER=&5L;65Z971T`$%Z(&%L87#I
M<G1E;&UE>NES('-Z97)I;G1I('-Z[6X`06QA<.ER=&5L;65ZZ7,@<WIE<FEN
M=&D@87IO;F]S[73S`$%Z(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&IE
M9WEZ971T]FUB:F4`06QA<.ER=&5L;65Z971T('-H96QL`$$@<V]R8F%R96YD
M97KI<R!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!S>F5M<&]N=&IA.@!!('-O
M<F)A<F5N9&5ZZ7,@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@:7+A;GEA.@!$
M969I;NUC:?-K`%3V<FSI<P!!(&-E;&QA('3V<FSI<V4`02!T]G)LZ7,@;65G
M97+U<^UTZ7-E`$$@8W-O<&]R="!T]G)LZ7-E`$$@;F%P;//A;&QO;>%N>2!T
M]G)LZ7-E`$$@:F]G;W-U;'1SX6<@=/9R;.ES90!,979E;&5K('3V<FSI<V4`
M02!T]G)LZ7,@9V]M8B!V:7-E;&ME9.ES90!!(&-E;&QA('3V<FSI<V4`07H@
M;W-Z;&]P('3V<FSI<V4`5/9R]FQJ_&L@:VD@82!M96=LZ7;U(&%L=&5R;F%T
M[78@<V%B;&]N=`!!(&QE=F5L96L@=/9R;.ES90`B)7,B(&IO9V]S=6QT<^%G
M86EN86L@=/9R;.ES90!4]G+V;&K\:R`B)7,B(&IO9V]S=6QT<^%G86ET(.ES
M(&5N;F5K(&5S971L96=E<R!A;&-S;W!O<G1J86ET/P!!('-O<B!T]G)LZ7-E
M`$$@:VEVX6QA<WIT;W1T(&%Z;VYO<^UT\R!T]G)LZ7-E`$%Z(&%L;6%P<.%K
M('3V<FSI<V4`02!J96QE;FQE9VD@;W-Z;&]P('3V<FSI<V4`02!J96QE;FQE
M9VD@<V]R('3V<FSI<V4`5/9R]FQJ_&L@97IT(&$@9F5L:F5G>7KI<W0`5/9R
M]FQT_&L@82AZ*2`B)7,B('-E='5P('5P9W)A9&4@<')O9W)A;6]T+@!!(&OI
M>F)E<^UTZ7,@:61E:F4`1.%N:6$`8W/V:VME;O4`061J;VX@;&7M<N%S="!A
M('!R;V)LZ6WA<O-L`$QE[7+A<P!,9>URX7,Z`%+I<WIL971E:R`H82!(;W)D
M92!L;V=FX6IL8F%N(&ES(&UE9W1A;.%L:&%T\RDZ`$$@<NES>FQE=&5K(&$@
M<F5N9'-Z97)G87ID82!S>N%MX7)A(&OI<WK\;/4@;F%P;/-FX6IL8F$@:V5R
M_&QT96LN`$9E:FQE<WITZ7,`2&%R;6%T<&]N=`!(87)M871P;VYT(&IE;&5N
M;&5G.B``2&%R;6%T<&]N=#H@`&)A;'+S;"!J;V)B<F$@[7+A<P!J;V)B<O-L
M(&)A;')A(.URX7,`0^UM=.%R`$%Z(&ED]7!O;G1O:V%T(#(T(/-RX7,@9F]R
M;>%T=6UB86X@:F5L96[M='/\:R!M96<_`$UE9VIE;&5N[73I<VD@8F7A;&SM
M=.%S;VL`02!RZ7-Z;&5T97,@96SU<F5J96QZZ7,@;65G:F5L96[M=.ES90!%
M;/5R96IE;'KI<R!M96=J96QE;NUTZ7-E("AR97#\;/5TZ7)I*0!-96=J96QE
M;NUTZ7-I(&9O<FWA='5M`,ER=&5S[73I<R!A(&OI>F)E<^UT971T(&QE=NEL
M('-O<G/A<O-L`$1Z<VEB=71I`$YE('3V<O9L:OQK`$$@;6%I;G1E;F%N8V4N
M<&AP(&YE;2#I<FAE=/4@96P@:_9Z=F5T;&5N_&PN`$%Z(&%D871O:R!T]G)L
MZ7/I="!M96=E;/5Z]65N(/-H86IT+64@96=Y(&UE9V5R]7/M=/4@:^ER9.ES
M=#\`07H@96QS]2!S;W(@82!M97KU:R!N979E:70@=&%R=&%L;6%Z>F$_($AA
M(&EG96XL(&IE;/9L:F4@:VD@97IT.@!$;VUI;FEK80!$;VUI;FEK86D@2_9Z
M=.%R<V%SX6<`3FEN8W,@;>EG(&QO9VEN(&YE=F4_($EGZ6YY96QJ96X@96=Y
M970N`$QE=/9L=.ES`%3V;'1S_&L@;&4@)7,M=`!4]FQT<_QK(&QE(%!(4"!P
M<F]G<F%M(&9O<FWA:N%B86X@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0N
M`$QE9_9R9/QL]2!L:7-T80!+X6+M=/-S>F5R96L`96UA:6P`16UA:6QB]6P@
M4TU3+6O\;&3U(&UE9VAA:G3S+"!H82!A('1E;&5F;VYTX7)S87/A9R!B:7IT
M;W/M=&IA(&5Z="!A('-Z;VQGX6QT873A<W0N`$A)0D$`16-U861O<@!-\V1O
M<^UTX7,`(B5S(B!M\V1O<^UTX7-A`$)L;VMK(&WS9&]S[73A<P!#<V]P;W)T
M(&WS9&]S[73A<P!!(&9E;&IE9WEZZ7,@;?-D;W/M=.%S80!*;V=O<W5L='/A
M9R!M\V1O<^UTX7,`2F]G;W-U;'1SX6=O:R!M\V1O<^UTX7-A`"5S(&IO9V]S
M=6QT<^%G86EN86L@;?-D;W/M=.%S80!+871E9_-R:>%K(.ES('-Z[6YE:6L@
M=N%L=&]Z=&%TX7-A`$UE;'EI:R!O<&-I\VMA="!VX6QT;WIT87-S=6LZ`"(E
M<R(@:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A`"5S(&IO9V]S=6QT<^%G
M86EN86L@;?-D;W/M=.%S80!/:W1A=.%S`$5G>6EP=&]M`%-A;'9A9&]R`$5L
M96TN+BX`87H@)VTG(&)E=/L@<WKI;&5S<^EG90!%;6%I;`!%;6%I;"!C[6T`
M07H@96UA:6P@8^UM96MN96L@96=Y97IN:?QK(&ME;&PN`$5M86EL('9I<W-Z
M86EG87IO;.%S<V%L`$5M86EL+5--4R#A=&KA<O,`2&%N9W5L871I:V]N;VL`
M02!F96QJ96=Y>NES(/QR97,`W')E<R#\>F5N970N`$YI;F-S(&EL>65N+@!4
M]G+V;&K\:R!K:2!A(&ME<F5SZ7-E:V5T`$5N9V5D:OQK(&UE9RP@:&]G>2!K
MZ7!E:V5T(&EL;&5S<WK\;FL@82!S>O9V96=B92!A($9O=/-G86SI<FGA:V+S
M;#\`3&5G>65N(&IO8F(@96?I<F=O;6)B86P@96SI<FAE=/4L(&MO;G1E>'1U
M<V;\9V?U(&UE;OP_`$%Z('5T;VQS\R#I=@#!=';A;'3A<R!K_&SV;B!A8FQA
M:W)A`$%D:F$@;65G(&%Z="!A(&)I>G1O;G/A9VD@:^ER9.ES="P@86UE;'ER
M92!M86ID(';A;&%S>F]L;FEA(&ME;&P@:F5L<WIA=N%N86L@X73A;&SM=.%S
MX6AO>BP@<&PN("=H;V=Y(&CM=FKA:R!A(&MU='GA:N%T/R<Z`$%D:F$@;65G
M(&$@:^EP(%523"UJZ70@:71T`,UR:F$@8F4@87H@86SA8F)I(&)E=/MK970Z
M`$5G>65N;.UT]6DM1W5I;F5A`$5R:71R96$`2&EB80!(:6)A('3V<G3I;G0@
M82!B;&]K:R!LZ71R96AO>N%S86MO<CH@)7,`2&EB82!T]G)TZ6YT(&%Z(&%D
M871S>FEN:W)O;FEZX6-I\W,@:F5L('3V<FSI<V5K;W(Z("5S`$%Z(&%D871S
M>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>2!T]G)LZ7-E(&YE;2!S:6ME
M<OQL=#H@)7,`2&EB82!T]G)TZ6YT(&%Z(&%D871L96OI<NES8F5N.B`E<P!(
M:6)A('3V<G3I;G0@82!J96QS>O,@;65G=N%L=&]Z=&%TX7-A:V]R.B`E<P!(
M:6)A(&%Z(&5M86EL(/QZ96YE=&)E;BX`02AZ*2`B)7,B(.%L;&]MX6YY<F$@
M;F5M('-I:V5R_&QT(.UR;FDN`,ES>G1O<G-ZX6<`171I\W!I80!.96UZ971I
M<^EG96L`175R\W!A`#$U('!E<F-E;FOI;G0`,B!P97)C96YKZ6YT`#,P(&WA
M<V]D<&5R8V5N:^EN=``U('!E<F-E;FOI;G0`;6EN9&5N(&)E:F5L96YT:V5Z
MZ7-K;W(`9NEL\W+A;FOI;G0`<&5R8V5N:^EN=`!0Z6QD82#I<G3I:V5K.@!6
MZ6=R96AA:G3A<P!.>6ES<W5K('-ZZ70`2F5L96[M='/\:R!M96<@87H@;VQD
M86QS\R!M96[\=`!)='0@)RDG(&ME;&QE;F4@:_9V971K97IZ96X`271T(&-S
M=7!A<WH@<WKS;F%K('9A9WD@:63I>O5J96QB96X@;&5V]2!K97)E<^ES:2!K
M:69E:F5ZZ7-N96L@:V5L;&5N92!L96YN:64`07H@Z7)VZ6YY97-SZ6<@;&5J
MX7)A=&$`2VET97;U`$5X<&]R=.%LX7,`2F5G>7IE='3V;6+V:R!E>'!O<G3A
M;.%S80!3>NUN`$$@:V]N9FEG=7+A8VGS($944"UN(.%T('9A;/,@9F5L=/9L
M=.ES90!496QJ97,@<WKV=F5G`$$@<WIE;>EL>65S(&)EX6QL[73A<V]K870@
M;F5M('-I:V5R_&QT(&)E;VQV87-N:2X`07H@3$1!4"!S>F5R=F5R(&YE;2#I
M<FAE=/4@96PN`$%Z(%--0B!S>F5R=F5R(&YE;2#I<FAE=/4@96PN`$YE;2!S
M:6ME<OQL="!A*'HI("(E<R(M8O5L('3V<G3I;O4@;>%S;VSA<RX`3F5M('-I
M:V5R_&QT(&$H>BD@(B5S(BUB92!T]G)TZ6[U(&WA<V]LX7,N`$YE;2!S:6ME
M<OQL="#Z:B!305-,(&MA<&-S;VQA=&]T(&SI=')E:&]Z;FDN`$YE;2!S:6ME
M<OQL="!A*'HI("(E<R(M8F4@=/9R=.EN]2#A=&AE;'EE>NES+@#!;&QO;>%N
M>6AO>GKA9NERZ7-I(&AI8F$Z("5S`%1I<WIT80!&86QK;&%N9"US>FEG971E
M:R`H36%L=FEN87,I`$9A<F]E+7-Z:6=E=&5K`$AE;'ER96AO>FAA=&%T;&%N
M(&AI8F$Z`$9A>`!&87@`9F5B<G7A<@!(]6WI<G/I:VQE=.ER>F5T`$CU;>ER
M<^EK;&5TZ7)Z970Z(`!%9WDM96=Y('KA<&]R`%-Z\W)VX6YY;W-A;B!H\WKA
M<&]R;VL`365Z]2!MX71R:7@`1FEG;&5T($-!4%1#2$$@*&)E=/MK:7)A:_,@
M:'5MX6YT97-Z="D`1FED>G-I`$;A:FP`02!FX6IL;VL@<WKA;6$Z("5S`$$@
M9N%J;&]K('-ZX6UA.B`E<P!&X6IL(&UE;F5D>G-E<@!&X6IL;NEV`$;A:FP@
M:VEJ96SV;.ES`$;A:FP@9F5L=/9L=.ES90!&X6IL;VL@9F5L=/9L=.ES92!N
M96T@;&5H971SZ6=E<RX`4WK[<O5K`$9I;FYO<G-ZX6<`96QS]2!FZ6P`96QS
M]2!N96=Y960`5N%L=&]Z871L86X@;>ER971A<N%N>0!4_&MR]GKI<R`H9O9L
M+VQE*0!+]F0`)7,@;6%P<&$@;F5M(&SI=&5Z:6L`0F5T^W-Z[6X`R71E;&5K
M`$]L>6%N(&+V;F?I<WKU:R!S>N%MX7)A+"!A;6EK(&YE;2!J96QE;NUT:6L@
M;65G(&$@:^EP96ME=`!%;/5R96IE;'KI<R`H<F5P_&SU=.ER:2D`07H@96SU
M<F5J96QZZ7,@:63U=&%R=&%M82!N87!O:V)A;B`H87H@96SU<F5J96QZZ7,@
M;F%P<&%L:2#I<R#I:G-Z86MA:2!A9&%T;VMA="!T87)T86QM87HL(&5ZZ7)T
M(&$@;F%G>2!S>N%M;VL@<WKI;&5S(&)L;VMK;W0@97)E9&WI;GEE>FYE:RD`
M16QF96QE:G1E='1E(&$@:F5L<WIA=N%T/P#;<FQA<&ME>F5LZ7,`263I>F5T
M`$EDZ7IE="!F86ITX6IA`$EDZ7IE=&5K`$EDZ7IE=&5K(#(`1O-R=6UO:P!4
M;W;A8F+M=.%S;VL`4.D`1G)A;64M96L`1G)A;F-I86]R<WKA9P!&<F%N8VEA
M;W)S>N%G`$9R86YC:6$@1W5Y86YA`$9R86YC:6$@4&]L:6[I>FEA`$9R86YC
M:6$@1.EL:2!497+\;&5T96L`1F5L863S`$ERX6YY.B``4NES>FQE=&5S(&QE
M[7+A<P!T96QI:&]L9`!496QJ97,@;NEV`$=A8F]N`$UE;'EI:R!G86SI<FGA
M8O-L('9E9WG\:R!A(&OI<&5T`$OI<&=A;.ER:6$Z`$=A;6)I80#!;'1A;.%N
M;W,@8F7A;&SM=.%S;VL`2&]Z>G5K(&SI=')E(&$H>BD@)7,@:V]N9FEG=7+A
M8VGS:N%T`$$@:V5L971K97IE='0@:_-D`$=R^GII80!.Z6UE=&]R<WKA9P!'
M:.%N80!':6)R86QTX7(`2V5R97-Z=&[I=@!';&]BX6QI<R!B9>%L;.UTX7-O
M:P!-96AE=`!']F1E;`!';V]G;&4@=.ER:^EP`$=O;V=L92!K97)E<^ES`$9E
M:V5T92]F96CI<@!']G+V9V]R<WKA9P!G]G+V9R`H25-/+3@X-3DM-RD`1W+V
M;FQA;F0`1W)E;F%D80!#<V]P;W)T(&%D;6EN:7-Z='+A8VGS`$$@8W-O<&]R
M=&[I=B!M87)A9&AA="#\<F5S96X`1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!H
M;WIZX6%DX7-A(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R(';A;&%S>F$Z(`!'
M<F]U<%]L9&%P.B`E<R!C<V]P;W)T('3V<FSI<V4@;F5M('-I:V5R_&QT`$=R
M;W5P7VQD87`Z("5S(&-S;W!O<G0@861A=&%I;F%K(&UE9_IJ[73A<V$@;F5M
M('-I:V5R_&QT`$-S;W!O<G1O:P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA
M`$=U97)N<V5Y`%9E;F3I9R!J;V=O<W5L='/A9V]K`%9E;F3I9VOV;GEV`$=U
M:6YE80!":7-S874M1W5I;F5A`$=U>6%N80!(5$U,07)E82!G>>%V87/A9V+S
M;"!N96T@:&%J;&%N9/,@82!S;W(@=71O;'/S(&-E;&SA:N%T('3V<O9L;FDN
M`$A434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A('3A8FSA>F%T
M('5T;VQS\R!O<WIL;W#A="!T]G+V;&YI+@!(5$U,07)E82!G>>%V87/A9V+S
M;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA="!U=&]L<_,@<V]RX70@=/9R]FQN
M:2X`02!(5%10(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@=&%LX6QH873S
M+@!(86ET:0!(87-H(&%L9V]R:71M=7,`2_9D`$9E:FSI8P!&96ILZ6,`2&5A
M<F0M(.ES($UC1&]N86QD+7-Z:6=E=&5K`$5R]7,@>FEV871A<@!HZ6)E<B`H
M25-/+3@X-3DM."U)*0!-86=A<W/A9P!396?M='/I9P!396?M='/I9R!A('-Z
M97)K97-Z=/4@:&%S>F[A;&%TX6AO>@!396?M='/I9P!&Z6QT96ME`$5Z(&$@
M9N%J;"!E;&5J93H`;F%G>0!+97ID]6QA<`!6871I:^%N=N%R;W,`2V5Z9/5L
M87``3W1T:&]N:2!C[6T`4WIE;>EL>65S(&%L:_9N>79TX7(`3W1T:&]N:2!T
M96QE9F]N`$AO;F1U<F%S`$AO;F=K;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!H
M:6+A<R`E<R!834P@861A="!V86X@82AZ*2`E<R#\>F5N971B96X`2&]R9&4O
M2V]L86(Z(&YI;F-S(&$H>BD@)7,@;V)J96MT=6UN86L@;65G9F5L96SU(/QZ
M96YE=`!(;W)D92]+;VQA8CH@;FEN8W,@)7,@=.UP=7/Z(&]B:F5K='5M(&$H
M>BD@)7,@_'IE;F5T8F5N`$AO<F1E+TMO;&%B.B!3:6ME<F5S96X@=/9R]FQT
M_&L@97IT.B`E<R`B)7,B`$AO<F1E+TMO;&%B.B!A>B!I;G1E9W+A;/,@<')O
M9W)A;6AO>B!S>OQK<^EG97,@82`G9&]M>&UL)R!02%`@8O5V[73I<P!(;W)D
M92]+;VQA8CH@;F5M('-I:V5R_&QT(/IJ(%A-3"!FX70@;.ET<F5H;WIN:2!A
M*'HI("5S(&]B:F5K='5M:&]Z`$AO<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@
M=/9R]FQN:2`E<RUT("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!N96T@<VEK97+\
M;'0@;65G:&%TX7)O>FYI(&$@34E-12!)1"UJX70@82!K]G9E=&ME>O4@=.UP
M=7/Z(&UE;&SI:VQE=&YE:SH@)7,`2&]R9&4O2V]L86(Z($YE;2!S:6ME<OQL
M="!S>FEN:W)O;FEZX6QN:2`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@3F5M
M('-I:V5R_&QT(&$@:_9V971K97KU(&OV>O9S('3A<G1E<OQL970@<WII;FMR
M;VYI>N%LX7-A.B`E<P!(;W)D92]+;VQA8CH@:7-M97)E=&QE;B!K]GKV<R!T
MX7)T97+\;&5T("(E<R(`5NUZ<WII;G1E<R!V;VYA;`!6[7IS>FEN=&5S(&UA
M<F?S`%;M>G-Z:6YT97,Z`$AO9WD@:G5T;W1T(&ED93\@*$OI<FK\:R#M<FIA
M(&UE9R$I`$CA;GD@;W-Z;&]P;W0@:^UVX6X@]G-S>F5O;'9A<WIT86YI/P!(
MX6YY(&UE>O4@*&]S>FQO<"D@=F%N/P!(X6YY('-O<G0@:^UVX6X@]G-S>F5O
M;'9A<WIT86YI/P!0X7)A=&%R=&%L;VT`4.%R871A<G1A;&]M.B``2'5M;W)I
M<W3A:P!-86=Y87)O<G-ZX6<`07H@24U!4"!L97;I;&SA9&$@;.ET<F5H;WKA
M<V$@;F5M('-I:V5R_&QT.B`E<P!!>B!)34%0(&QE=NEL;.%D82!T]G)LZ7-E
M(&YE;2!S:6ME<OQL=#H@)7,`07H@24U!4"!L97;I;&SA9.%H;WH@=&%R=&]Z
M\R!K=O-T82!LZ71R96AO>N%S82!N96T@<VEK97+\;'0Z("5S`$E0(&/M;0!!
M>B!)4"!C[6T@;F5M(&AA=.%R;WIH873S(&UE9RX`07H@25`@8^UM(&YI;F-S
M(&$@;65G96YG961E='0@0TE$4B!T87)T;VWA;GEB86XN`%1I;'1O='0O;65G
M=N%L=&]Z;W1T($E0(&/M;2X`4V]R(&)E:6QL97-Z=.ES92!E9O9LZ0!)>FQA
M;F0`8W-A:R!I:V]N;VL`)7,@:6MO;FIA:0!I:V]N;VL@Z7,@<WKV=F5G`$%Z
M(&%Z;VYO<^UT\VAO>B!VX6QA<WIT;W1T(&5L;F5V97KI<SH`2&$@82!M96=J
M96QE;NUTZ7,@;F5M(&UE9V9E;&5L]2P@)7,@96=Y(/IJ(&%B;&%K8F%N('9A
M;/,@;65G;GEI=.%S:&]Z+@!(82#6;B!);G1E<FYE="!%>'!L;W)E<G0@:&%S
M>F[A;"P@Z7,@;F5M(&IE;&5N;F5K(&UE9R!A>B!I:V]N;VLL(&%K:V]R(';A
M;&%S<WIA(&5Z="!A>B!O<&-I\W0L(&UE;&QY96P@:VEK87!C<V]L:F$@82!0
M3D<@:^EP96L@=')A;G-Z<&%R96YC:>%JX70N`$AA(&SA=&IA(&5Z="!A('-Z
M]G9E9V5T+"!D92!A(&OI<&5T(&YE;2P@86MK;W(@8O9N9^ES>O5P<F]G<F%M
M:F$@;F5M(&OI<&5S(&UE9VIE;&5N[71E;FD@82!S>F5R=F5R<F4@:_QL9&5N
M9/4@:^EP970N`$5L]7IE=&5S(&[I>F5T.@!!(&OI<"!54DPM:F4`02!KZ7`@
M55),+6IE.@!-96QY:6L@9V%LZ7)IX6+S;"!V86X@82!KZ7``2^EP(&5B8O5L
M(&$@9V%LZ7)IX6+S;#H`2^EP(&9E;'3V;'3I<V4`2^EP96L`1F5L:F5G>7KI
M<V5K(&EM<&]R=.%LX7-A+"`E9"X@;.EPZ7,`26UP;W)TX6SA<RP@)60N(&SI
M<.ES`$9E;&IE9WEZZ7-E:R!I;7!O<G3A;.%S82]E>'!O<G1J80!!>B!I;7!O
M<G3A;'0@;65Z]3H@)7,`07H@:6UP;W)TX6QT(&UE>O5K.@!3;W(@8F5I;&QE
M<WITZ7-E(&5Z86SA`$AI8N%S('!A<F%N8W-P87)A;>ET97(N`$YE;2!M96=F
M96QE;/4@82!B96IE;&5N=&ME>NES:2!NZ78@Z7,O=F%G>2!A(&IE;'-Z\RX`
M3F5M(&UE9V9E;&5L]2!A(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!A>B!A;'1E
M<FYA=.UV(&/M;2X@4'+S8N%L:F$@^FIR82!V86=Y(&9O<F1U;&IO;B!A(')E
M;F1S>F5R9V%Z9.%H;WHL(&AA('1O=N%B8FD@<V5G[71SZ6=R92!V86X@<WK\
M:W/I9V4N`$)E:V5Z9.ES(&)E;&IE8F(`26YD:6$`16=Y97,@9F5L:&%S>F[A
M;/-K`$EN9&]NZ7II80!);F9O<FWA8VGS`$EN9F]R;>%C:?,`07H@:6YF;W)M
MX6-I\R!MX7(@;F5M(.%L;"!R96YD96QK97KI<W)E+@!/<WIL;W`@8F5S>OIR
MX7-A(&5Z=73A;@!+Z7`@8F5I;&QE<WITZ7-E`%3A8FSA>F%T(&)E:6QL97-Z
M=.ES90!,:6YK(&SI=')E:&]ZX7-A`$]S>FQO<"!B97-Z^G+A<V$@97IE;.D`
M3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6X`3W-Z;&]P(&)E<WKZ<N%S82!E>F5L
MZ0!3;W(@8F5S>OIRX7-A(&5Z86SA`%-O<B!B97-Z^G+A<V$@96;V;.D`0F5K
M97IDZ7,@8F5I;&QE<WITZ7-E(&5Z=73A;@!"96ME>F3I<R!B96EL;&5S>G3I
M<V4@97IE;.D`2&]Z>G5N:R!LZ71R92!A;'1E<FYA=.UV('-A8FQO;G0`061J
M;VX@;65G(&5G>2!E;6%I;"!C[6UE="P@;65L>7)E(&5L:_QL9&AE=/4@87H@
MUFX@^FH@:F5L<WIA=F$Z`$-E;&QA(&)E:6QL97-Z=.ES92!E>G5TX6X`0V5L
M;&$@8F5I;&QE<WITZ7-E(&5Z96SI`$]S>FQO<"!B97-Z^G+A<V$@97IU=.%N
M`$]S>FQO<"!B97-Z^G+A<V$@97IE;.D`3&5V96QE:R!B96WA<V]LX7-A`$)E
M:V5Z9.ES(&)E:6QL97-Z=.ES92!E>G5TX6X`0F5K97IDZ7,@8F5I;&QE<WIT
MZ7-E(&5Z96SI`%-O<B!B97-Z^G+A<V$@97IA;.$`4V]R(&)E<WKZ<N%S82!E
M9O9LZ0!!9&IA(&UE9R!A(&OM=N%N="!VX6QA<WIT(&$@8FEZ=&]N<^%G:2!K
MZ7)DZ7-R93H`2^EP(&)E:6QL97-Z=.ES92]M\V1O<^UTX7-A`$QI;FL@8F5I
M;&QE<WITZ7-E+VWS9&]S[73A<V$`02!S>N%M;.%JX6X@;FEN8W,@96SI9R!F
M961E>F5T(/QZ96YE=&5T(&O\;&1E;FD@82!K]G)L97;I;&QI<W3A<F$N`$$@
M<WKA;6SA:N%N(&YI;F-S(&5LZ6<@9F5D97IE="X`16?I<WH`16?I<WH@<WKA
M;6]K(&QI<W3A:F$`2&EBX7,O96QF;V=A9&AA=&%T;&%N(%5$2"`H57-E<B!$
M871A($AE861E<BDN`$AI8N%S+V5L9F]G861H871A=&QA;B!:25`@=/9M]G+M
M=.ES`$AI8N%S+V5L9F]G861H871A=&QA;B!A;&MA;&UA>N%S+@!(:6+A<R]E
M;&9O9V%D:&%T871L86X@8F%T8V@@87IO;F]S[73S+@!!(&O\;&3V='0@861A
M="!H:6+A<R]E;&9O9V%D:&%T871L86XN`$AI8N%S+V5L9F]G861H871A=&QA
M;B!C[6UZZ7,N`$AI8N%S+V5L9F]G861H871A=&QA;B!FX6IL(&9O<FWA='5M
M`$AI8N%S+V5L9F]G861H871A=&QA;B!L:6-E;G-Z:W5L8W,N`$AI8N%S+V5L
M9F]G861H871A=&QA;B!VX7)O<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(/QZ
M96YE='3M<'5S+@!(:6+A<R]E;&9O9V%D:&%T871L86X@=F%G>2!H:>%N>7KS
M('!R;V=R86UO>N%S:69E;/QL970M87IO;F]S[73S+@!(:6+A<R]E;&9O9V%D
M:&%T871L86X@<&%R86WI=&5R96LN`$AI8N%S(&%Z(&]B:F5K='5M(&5LZ7+I
M<VD@:F]G;W-U;'1SX6=A+@!(:6+A<R]E;&9O9V%D:&%T871L86X@<&%R=&YE
M<F%Z;VYO<^UT\RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N('1E<FWI:VOS9"X`
M2&EBX7,O96QF;V=A9&AA=&%T;&%N('!R;W1O:V]L;"X`2&EBX7,O96QF;V=A
M9&AA=&%T;&%N(&/M;7IE='0Z("(E<R(`2&EBX7,O96QF;V=A9&AA=&%T;&%N
M(&UE9V]S>G1O='0@;V)J96MT=6T`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&9E
M;&%D\VD@8^UM+@!(:6+A<R]E;&9O9V%D:&%T871L86X@=6YI8V]D92!A9&%T
M+@!.>6EL=N%N=&%R=.%S`$$@:VEJ96SV;.ES(&EN=F5R=.%LX7-A`$ERX6YI
M($ES>FSA;2!+]GITX7)S87/A9P!)<F%K`,UR;W)S>N%G`$UA;BUS>FEG970`
M4WKS<G;A;GEO<R!Z:79A=&%R;VL`27IR865L`$$@=&%N^G/M=';A;GD@:VEA
M9/-J80!D]6QT`$]L87-Z;W)S>N%G`$IA;6%I8V$`:F%N=>%R`$IA<.%N`&IA
M<.%N("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F3A;FEA`&KZ;&EU<P!J^FYI
M=7,`4V]R:VEZX7+A<P!K]GKI<')E(')E;F1E>NES`'-O<FMI>N%RX7,@;6EN
M9&OI="!O;&1A;')A`'-O<FMI>N%RX7,@8F%L<F$`<V]R:VEZX7+A<R!J;V)B
M<F$`2V%Z86AS>G3A;@!487)T<W5K(&UE9R!A>B!E<F5D971I=#\`2V5N>6$`
M02!K97)B97)O<R!S>F5R=F5R(&5L=71A<^UT;W1T82!A(&9E;&AA<WINX6SS
M87IO;F]S[73A<W0N`$ME>F3U(&ME<FYE;&9E:FQE<WIT]6L`2W5L8W,@;.ET
M<F5H;WKA<V$`02!K=6QC<R!L96YY;VUA=&$`2W5L8W-H;W-S>OISX6<`2W5L
M8W,@=.UP=7,`02!K=6QC<R!H87-Z;N%L871A`$$@:W5L8W,@;>%R(&SI=&5Z
M:6L@82!N>6EL=N%N;W,@:W5L8W-S>F5R=F5R96XN`$=Y97)E:V5K`$MI<FEB
M871I`$MO<F5A:2!.Z7!I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9P!+;W)E
M86D@2_9Z=.%R<V%SX6<`:V]R96%I("A%54,M2U(I`$MU=F%I=`!+:7)G:7II
M<WITX6X`7U1E<G9E>NES`$YY96QV`$QA;W-Z:2!.Z7!I($1E;6]K<F%T:6MU
M<R!+]GITX7)S87/A9P!U=&]L<_,@9NEL`%5T;VQS\R!M\V1O<^UTX7,`07H@
M=71O;'/S(&IE;'-Z\W;A;'3A<P!U=&]L<_,@;F5G>65D`%5T;VQS\R!VX6QT
M;WIT873A<SH`571O;'/S(&)E:F5L96YT:V5ZZ7,Z("5S`%5T;VQS\R!B96IE
M;&5N=&ME>NES.B`E<RP@)7,@8^UM<O5L`%5T;VQS\R!B96IE;&5N=&ME>NES
M.B!MZ6<@<V]H82!N96T@=F]L=`!,971T;W)S>N%G`$IO9P!%;&AE;'EE>NES
M`$AA9WEJ82#\<F5S96XL(&AA(&YE;2!A:V%R(&ME<F5T970`3&EB86YO;@!B
M86P`0F%L(&]L9&%L:2!F96ILZ6,`0F%L(&]L9&%L:2#I<G3I:V5K`$QE<V]T
M:&\`4WII;G0`3&EBZ7)I80!,[6)I86D@07)A8B!3>F]C:6%L:7-T82!.86=Y
M($[I<&D@2_9Z]G-SZ6<`3&EE8VAT96YS=&5I;@!'>65N9V4@<WII=.%L\R!E
M<_4`1WEE;F=E(&5S]0!$Z6QE;/5T="!G>65N9V4@97/U`$3I;'5TX6XO97-T
M92!G>65N9V4@97/U`$=Y96YG92!ZX7!O<@!'>65N9V4@>FEV871A<@!'>65N
M9V4@:&%V87KA<P!'>65N9V4@:/-ZX7!O<@!,:6YK`$$@;&EN:R!I9&4@;75T
M870Z`$UE9VIE;&5N[73I<VMO<B!M=71A<W-O;B!E9WD@;&EN:R!A(&QE=NEL
M8^UM<O5L(&$@;&5VZ6SM<O,@86)L86MH;WH`3&EN:V5K`$QI;G5X`$QI<W3A
M>N%S("T@82!F96QH87-Z;N%L\R!LX71J82!A(&UA<'#A=`!!>B!A9&%T8N%Z
M:7-O:R!L:7-TX6IA`$%Z;VMN86L@82!TZ6WA:VYA:R!A(&QI<W3A:F$@86UI
M<O5L('-E9^UT<^EG(&MA<&AA=/,`07H@861A='3A8FSA:R!L:7-TX6IA`$QI
M<W1A(&%R8VCM=G5M`$QI<W1A('-E9^UT<^EG:^ERZ7,`3&ES=&$@87IO;F]S
M[73S`$QI<W1A('1U;&%J9&]N;W,`3&ES=&$@;&5VZ6SM<N%S`$QI<W1A(&9E
M;&ER871K;WKA<R`H<W5B<V-R:6)E*0!,:7-T82!L96ER871K;WKA<R`H=6YS
M=6)S8W)I8F4I`$$@9F5L:&%S>F[A;/-K87!C<V]L871O:R!K:6QI<W3A>N%S
M82!N96T@<VEK97+\;'0Z("5S`$$@9F5L:&%S>F[A;/-K(&MI;&ES=.%ZX7-A
M(&YE;2!S:6ME<OQL=#H@)7,`02!F96QH87-Z;N%L\VL@:VEL:7-TX7KA<V$@
M=&EL='9A('9A;BX`27)O9&%L;VT`3&ET=N%N:6$`3&5T]FQTZ7,N+BX`2&5L
M>6D@:63U.B``3GEE;'8L(&3A='5M+"!I9/4`2&5L>0!"96IE;&5N=&ME>NES
M`$%Z(&5L]7KU(&%D871S>FEN:W)O;FEZX6-I\R!N87!L\^%L;&]MX6YY80!+
M:6IE;&5N=&ME>NES`$)E:F5L96YT:V5ZZ7,`0F5J96QE;G1K97KI<W-E;"!K
M87!C<V]L871O<R!F96QA9&%T;VL`02!B96IE;&5N=&ME>NES(&YE;2!S:6ME
M<OQL="P@;65R="!R;W-S>B!F96QH87-Z;N%L\VYE=F5T('9A9WD@:F5L<WKS
M="!A9&]T="!M96<N`$$@8F5J96QE;G1K97KI<R!N96T@<VEK97+\;'0N`$AO
M<W-Z^B!S>O9V96<`4WIE<F5L96T`86QA8W-O;GD`9_9R]F<@:VES8F5T^VL`
M;&%T:6X@:VES8F5T^VL`:VES8F5T^W,@<O-M86D@<WKA;6]K`$QU>&5M8G5R
M9P!-30!.87!I(/QZ96YE=&5K`$%Z($U3+51.148@;65L;.EK;&5T8F5N(&YI
M;F-S(&%D870N`-Q:14Y%5`!-86MA\P!-86ME9/-N:6$`36%D86=A<WIKX7(`
M5F%RX7IS;&%T`$QE=F5L97KI<P!%;6%I;"!D;VUA:6X@:V5Z96SI<P!,:6YK
M(&OI<WKM=.ES90!-86QA=VD`36%L86IZ:6$`36%L9.UV+7-Z:6=E=&5K`$UA
M;&D`3>%L=&$`061A=&%I="!K871E9_-R:>%K8F$@<V]R;VQH871J82X@17IE
M:R!I='0@9&5F:6YIX6QH873S:RP@;?-D;W/M=&AA=/-K+"!T;W;A8F+A('-Z
M[6YE:R!R96YD96QH973U:R!H;WIZX6IU:RX`36%P,C0@=.ER:^EP`$UA<%%U
M97-T('3I<FOI<`!!(&AO>GKA<F5N9&5LZ7-E:V5T(&5L;65N=&5T=/QK+@!M
MX7)C:75S`$UA<F?S`$%Z($]L=F%S;W1T+T]L=F%S871L86X@:F5L>F5T96L@
M:&%S>F[A;&%T80!-X7,@:F5L>F5T96L@*'!L+B!&;VYT;W,O365G=N%L87-Z
M;VQT*2!H87-Z;N%L871A`$UA<G-H86QL+7-Z:6=E=&5K`$UA<G1I;FEQ=64`
M16=Y;>%S;F%K(&UE9V9E;&5L]2!M97KU:P!-875R:73A;FEA`$UA=7)I=&EU
M<P!-87AI;>%L:7,@<F5N9&5L:V5ZZ7-R92#A;&SS('-ZX6UL8?9S<WIE9RX`
M07H@_'IE;F5T('3Z;"!S;VL@<NES>F+U;"#A;&PN`$%Z(&5L;?IL="`R-"#S
M<F$@;6%X:6WA;&ES(&CU;>ER<^EK;&5T93H@`$%Z(&5L;?IL="`V(/-R82!M
M87AI;>%L:7,@:/5MZ7)SZ6ML971E.B``02!F96QJ96=Y>NES96L@;6%X:6WA
M;&ES('-ZX6UA`$%Z(/9S<WIE9_5O;&1A;"!B;&]K:VIA:6YA:R!M87AI;>%L
M:7,@<WKA;6$`36%X:6WA;&ES(&AO<W-Z`&WA:G5S`$UA>6]T=&4`3W)V;W-T
M=61O;>%N>0!486=O:P!!(&9E;&IE9WEZZ7,@<WKV=F5G90!!(&UE;OP@;65G
M:F5L96[I<V4Z`$-E;&SA:R!E9WEB96]L=F%S>G3A<V$`W'IE;F5T`$$@9&EG
M:73A;&ES86X@86SA[7)T(/QZ96YE="!H:71E;&5S+"!D92!A>B!A;.'M<O,@
M=&%N^G/M=';A;GGA="!N96T@<VEK97+\;'0@96QL96[U<FEZ;FDN`$QE:N%R
M="!A>B#\>F5N970@Z7)VZ6YY97-SZ6=E+@!!>B#\>F5N970@=.UP=7-A`$UE
M=&%R(&ED]6KA<N%S:F5L96YTZ7,`02!-971A<B!B;&]K:R!N96T@X6QL(')E
M;F1E;&ME>NES<F4N`$$@365T87(@8FQO:VL@;F5M(.%L;"!R96YD96QK97KI
M<W)E+B!!('+I<WIL971E:R!A(')E;F1S>F5R9V%Z9&$@<WKA;>%R82!KZ7-Z
M_&SU(&YA<&SS9N%J;&)A(&ME<OQL=&5K+@!!($UE=&%R1$(@;F5M(.ER:&5T
M]2!E;"X`3?-D<WIE<@!!*'HI("(E<R(@;?-D<WIE<B!D969I;FGA;&%T;&%N
M`$$@;?-D<WIE<B!D969I;FGA;&%T;&%N+B!!(&UE9VCM=F]T="!M\V1S>F5R
M.B`E<P!-971R:6MU<P!-97AI:_,`36EK<F]NZ7II86D@4WKV=F5T<^EG:2#!
M;&QA;6]K`&OV>NEP`$U)344@=.UP=7,`07H@96QM^FQT(#(T(/-R82!L96=A
M;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z(`!!>B!E;&WZ;'0@-B#S<F$@;&5G
M86QA8W-O;GEA8F(@:/5MZ7)SZ6ML971E.B``3>EG(&YE;2!T96QT(&5L(&$@
M;6EN:6WA;&ES(&ED]2!A(&IE;'-Z\R!M96=VX6QT;WIT873A<^%H;WH`5/QK
M<O9ZZ7,@*&IO8F(O8F%L*0!696=Y97,`2&GA;GEZ:6L@82!(5%107U)E<75E
M<W0@4$5!4B!C<V]M86<N`$MO;F9I9W5RX6-I\R!S>OQK<^EG97,N($5Z="!M
M;W-T(&ME;&P@;.ET<F5H;WIN:6$L(&AA(&AA<WINX6QN:2!A:V%R:F$@87H@
M86QK86QM87KA<W0N`$AIX6YY>FEK(&%Z(/QZ96YE="!A>F]N;W/M=/-J82X`
M2&GA;GEZ:6L@82!-86EL(%!%05(@8W-O;6%G+@!(:>%N>7II:R!A(&9E;&AA
M<WINX6SS:V%P8W-O;&%T(&%Z;VYO<^UT\VIA("AS97-S:6]N($E$*2X`2.D`
M3&5V96QE>NES(&UO8FEL=&5L969O;G+S;`!+]GIE<&5S`$$@;?-D;W/M=.%S
M(&3A='5M80!!>B!54DP@;?-D;W/M=.%S80`E<R!VX6QT;WIT873A<V$`36]D
M=6QU<P!-;VQD;W9A:2!+]GITX7)S87/A9P!-;VYA8V\`36]N9_-L:6$`2/-N
M87`@Z7,@Z78`:&%V;VYT80!-;VYT<V5R<F%T`$AO;&1FX7II<V]K`$$@)60N
M('-O<F)A;B!T]F)B(&UE>O4@=F]L="P@;6EN="!A(';A<G0@)60N`$UA<F]K
M:_,`5/9B8FYY:7)E(&1E<OQL=`!4]F)B;GEI<F4@8F]R=6QT`%3V8F)N>6ER
M92!N87!O<P!V:6=Y_&L@;&4`=FEG>?QK(&)A;')A`'9I9WG\:R!J;V)B<F$`
M=FEG>?QK(&;V;`!V:6=Y_&L@;&4`=FEG>?QK(&;V;`!-;WIA;6)I:P!4]F)B
M<WII;G3[(&QE9_9R9/QL]2!L:7-TX6L`375L=&EM87`@3F%G>2U"<FET86YN
M:6$@=.ER:^EP`%3V8F)S>O9R]G,@=N%L87-Z=.%S`$)E:F5L96YT:V5ZZ7-I
M(&)EX6QL[73A<V]K`$)E:F5L96YT:V5ZZ7-I(&%D871A:6T`2F5G>7IE='3V
M;6)J96EM`%-A:N%T(/9S<WIE9WKU(&]L9&%L86T`4V%JX70@]G-S>F5G>O4@
M;VQD86QA;2!T97)V97KI<V4`36EA;FUA<@!.14TL(&YE;2!E9WEE>F5M(&)E
M;&4N`$[I=@!.86WM8FEA`$YA=7)U`$YE<.%L`$AO;&QA;F1I80!(;VQL86YD
M($%N=&EL;.%K`$YE='-C87!E(&+A>FES+5523`!.971S8V%P92!T86[Z<^UT
M=N%N>6MI863A<VEJ;V<H0T$I+79I<W-Z879O;N%S:2!54DP`3F5T<V-A<&4@
M=&%N^G/M=';A;GEF96QH87-Z;N%LX7-I(&ERX6YY96QV(%523`!.971S8V%P
M92!T86[Z<^UT=N%N>6UE9_IJ[73A<VD@55),`$YE='-C87!E('1A;OIS[71V
MX6YY=FES<WIA=F]NX7-I(%523`!.971S8V%P92!34TP@<WIE<G9E<F[I=@!.
M971S8V%P92!T86[Z<^UT=N%N>2!M96=J96=Y>NES`$YE='-C87!E('1A;OIS
M[71VX6YY=.UP=7,`2.%L\WIA=`!S;VAA`-IJ+4MA;&5D\VYI80#::B!K871E
M9_-R:6$`VFH@;&5VZ6P@)7,@8^UM<F4`^FIH;VQD`-IJ(&9E;&IE9WEZZ7,`
MVFH@9F5L:&%S>F[A;/-NZ78@*&]P8VEO;N%L:7,I`-IJ+5KI;&%N9`#::B!J
M96QS>O,`07H@^FH@:F5L<WKS(.ER=NEN>65S<^EG92!E:VMO<B!JX7(@;&4Z
M("5X+@!!(&UE9V%D;W1T(/IJ(&IE;'-Z879A:R!N96T@96=Y97IN96LN`-IJ
M(&%B;&%K("C\<F5S*0!([7)E:P!([7)C<V]P;W)T;VL`2_9V971K97KU`$OV
M=F5T:V5Z]2`T(&;A>FES`$OV=F5T:V5Z]2!O<&-I\VL`2_9V971K97KU/@!.
M:6-A<F%G=6$`3FEG97(`3FEGZ7)I80#I:G-Z86MA`$YI=64`3F5M`$YI;F-S
M(')E;F1E;&ME>NES<F4@X6QL\R!K;VYF:6=U<N%C:?,L(&%M:6AE>B!KZ7!E
M<W0@82!K_&SV;F)SZ6=E:V5T(&UE9R!L96AE=&YE(&UU=&%T;FDN`$YI;F-S
M(&QE:&5T]7/I9R!)4T\@X6QL;VWA;GEO:R!LZ71R96AO>N%SX7)A+@!(:>%N
M>7II:R!A(&OV=&5G96QT(&9E;&1O;&=O>N%S:&]Z('-Z_&MSZ6=E<R!M:6YT
M82`H8F%T8V@@=&5M<&QA=&4I+@!!(&OM=N%N="!H96QY96X@;FEN8W,@8FQO
M:VL`07H@34-!3"!F96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@;FEN8W,@;65G
M861V82!A(&YA<'3A<B!N979E+@!.:6YC<R!VX6QT;WKA<RX`16AH97H@82!J
M;V=O<W5L='/A9VAO>B!N96T@:&]Z:&%T\R!LZ71R92!J;V=O<W5L='/A9VD@
M86QC<V]P;W)T+@!(:>%N>6]Z;F%K(&$@:V]N9FEG=7+A8VGS<R!A9&%T;VL@
M)7,M:&5Z+@!!>B!&5%`@5D93(&YI;F-S(&MO;F9I9W5RX6QV82X`07H@4U%,
M(%9&4R!N:6YC<R!K;VYF:6=U<N%L=F$N`$%Z(%-13"U&:6QE(%9&4R!N:6YC
M<R!K;VYF:6=U<N%L=F$N`$%Z(-9N('-ZX6ULX6KA;B!E;&9O9WEO='0@82!R
M96YD96QK97KI<W)E(.%L;/,@]G-S>F5G+@!.:6YC<R!C[6UZZ7,N`$$@<WIE
M<G9E<G)E(&YE;2!T]FQT]63V='0@9F5L('-E;6UI;'EE;B#A;&QO;>%N>0!.
M96T@=&%LX6QH873S(&E#86QE;F1A<B!A9&%T+@!!>B!I:V]N;VL@;F5M('1A
M;.%L:&%T\VLN`$YI;F-S(&UE9V%D=F$@82!H96QY+@!.:6YC<R!M96=A9'9A
M(&$@:&5L>2X`07H@_'IE;F5T(/QR97,N`$YI;F-S(&UE9V%D=F$@82!NZ78N
M`$$@=F5N9.EG(&9E;&AA<WINX6SS:R!RZ7-ZZ7)E(&YE;2#A;&P@<F5N9&5L
M:V5ZZ7-R92!J96=Y>F5T=/9M8BX`3FEN8W,@96=Y(&9E;&IE9WEZZ7,@<V5M
M`$YI;F-S(&$@9F5L=.ET96QE:VYE:R!M96=F96QE;/4@9F5L:F5G>7KI<RX`
M3FEN8W,@;65G:F5L96[M=&AE=/4@9F5L:F5G>7KI<P!.:6YC<R!M96=A9'9A
M(&$@<WKA;2X`3F4@;&5G>65N(&UE9V)O='+A;FMO>G1A=/,@:63I>F5T`$YI
M;F-S(&IE;'-Z\R!M96=A9'9A(&$@2%144"!A;&%P^B!F96QH87-Z;N%L\VD@
M87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@87H@24U!4"!A
M;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS
M(&UE9V%D=F$@82!+97)B97)O<R!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S
M[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!,;V=I;B!A;&%P^B!F
M96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D
M=F$@82!005-35T0@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN
M`$YI;F-S(&IE;'-Z\R!M96=A9'9A(&%Z(%--0B!A;&%P^B!F96QH87-Z;N%L
M\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@;65G861V82!A>B!/<&5N4U-,('!R
M;V=R86T@96SI<NES:2#Z='9O;F%L82X@07H@3W!E;E-33"!P<F]G<F%M('-Z
M_&MSZ6=E<R!A(%!+0U,@,3(@861A=&]K(&ME>F5LZ7/I:&5Z+@!.:6YC<R#Z
M:B!B96IE;&5N=&ME>NES:2!I9^EN>2X`3FEN8W,@:W;S=&$@8F7A;&SM='9A
M+@!.92!L96=Y96YE:R!V;VYA;&%K('-E:&]L+@!.:6YC<R!D969I;FGA;'9A
M(&5L=N%L87-Z=/,@:V%R86MT97(N`$YE(&QE9WEE;B!K97)E=`!.:6YC<R!I
M;'EE;B!FX6IL`$YI;F-S(&ED96EG;&5N97,@X6QL;VWA;GEO:R!TX7)O;.%S
MX7)A('-Z;VQGX6SS(&%L:_9N>79TX7(N`$AIX6YY>FEK(&$@9F5L:&%S>F[A
M;/-NZ78@Z7,O=F%G>2!A(&IE;'-Z\RX`02!V:7-S>F%K87!O='0@861A=&]K
M(&YE;2#I<G;I;GEE<R!834P@861A=&]K`$YI;F-S(&%D870`3FEN8W,@;>EG
M(&MO;F9I9W5RX6-I\RP@9V5N97+A;&IO;B!E9WEE="X`3FEN8W,@;>EG(&MO
M;F9I9W5RX6-I\VIA+"!G96YE<N%L:F]N(&5G>65T+@!&96QJ96=Y>NES`&YI
M;F-S`&YI;F-S(&UE9V%D=F$@*&QE9WEE;B!A;&%PZ7)T96QM97IE='0I`&YO
M<F1I:W5S("A)4T\M.#@U.2TQ,"D`3F]R9F]L:RUS>FEG970`R7-Z86MI(&;I
M;'1E:V4`R7-Z86MI+4UA<FEA;F$M<WII9V5T96L`3F]R=NEG:6$`3F5M(&OI
M<_5B8@!.96T@:V]RX6)B86X`3F5M(&%L:_9N>79TX7(`02!P<F]G<F%M;F%K
M(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE9W9A;/-S[71V82X`3FEN8W,@8F7A
M;&SM='9A`$YE;2!TX6UO9V%T;W1T+@!!(&9E;&IE9WEZZ7,@:V%T96?S<FGA
M:F$`02!F96QJ96=Y>NES('+I<WIL971E<V5N`$9E;&IE9WEZZ7-E:R!L:7-T
MX6IA`$$@9F5L:F5G>7KI<R!S>O9V96=E`$$@9F5L:F5G>7KI<R!S>O9V96=E
M`$$@9F5L:F5G>7KI<R!N96T@=&%LX6QH873S+@!*96=Y>F5T=/9M8@!!(&IE
M9WEZ971T]FUB(&YE=F4Z`$IE9WEZ971T]FUB]FL`02!J96=Y>F5T=/9M8FYE
M:R!N979E="!K96QL(&%D;FDN`$9E;&IE9WEZZ7-E:P#6<W-Z969O9VQA;.%S
M(&$@:F5G>7IE=&5K<O5L`$YI;F-S(&+V;F?I<WIH973U(&%D870L('3I<FIE
M;B!V:7-S>F$N`&YO=F5M8F5R`%-ZX6T`2V%R86MT97)E:R!S>N%M80!/<WIL
M;W!O:R!S>N%M80!3;W)O:R!S>N%M80!!(&OV<FQE=NEL;&ES=&$@;?-D;W/M
M=.%SX6AO>B!N96T@861O='0@;65G('-ZX6UO:V%T+@!/2P!/8FIE:W1U;0!!
M>B!O8FIE:W1U;2!LZ71R96AO>O-J80!/:W3A;&ES('-ZX6T`;VMT\V)E<@!3
M>OMRZ7,`2&EV871A;"]M=6YK86AE;'D`02!RZ6=I(.ES(&%Z(/IJ(&IE;'-Z
M\VYA:R!K_&SV;F+V>FYI92!K96QL+@!!('+I9VD@:F5L<WKS`$$@<NEG:2!J
M96QS>O,@;F5M(&UE9V9E;&5L]2X`3VWA;@!#<V%K(&%Z($E-05`@<WIE<G9E
M<F5K('3A;6]G871JX6L@82!M87!PX6L@;65G;W-Z=.%SX70N`$-S86L@;65G
M8F]T<N%N:V]Z=&%T\R!I9.EZ970@;&5G>65N`$-S86L@96=Y(&5M86EL(&/M
M;2!A9&AA=/,@;65G+@!#<V%K(&$@='5L86ID;VYO<R!V86=Y(&$@<F5N9'-Z
M97)G87ID82!VX6QT;WIT871H871J82!M96<@96=Y(&OV>O9S('3A<G1E<OQL
M970@='5L86ID;VYO<^%T('9A9WD@96SI<NES:2!J;V=O<W5L='/A9V%I=`!.
M>6ES<W5K(&UE9R#Z:B!A8FQA:V)A;@!/<&5N4U-,(&AI8F$Z($YE;2!S:6ME
M<OQL="!K:6YY97)N:2!A>B!A9&%T;VMA="!A>B!A;.'M<G0@4R]-24U%('+I
M<WIB]6P`3GEI<W-U:R!M96<@97IT(&$@8^UM970@96=Y(/IJ(&%B;&%K8F%N
M`$]P97+A8VGS<R!R96YD<WIE<@!/<&-I\VL`)7,@8F7A;&SM=.%S86D`4V]R
M<WKA;6]S(&9E;'-O<F]LX7,`4WIE<G9E>F5T`%-Z97)V97IE=&D@96=Y<^EG
M`$UU;FMA<WIE<G9E>NES`$%Z(&%L:V%L;6%ZX7,@97)E9&5T:2!S86)L;VYJ
M80`E<R!E<F5D971I('-A8FQO;FIA:3H`16=YZ6(`16=YZ6(@:6YF;W)MX6-I
M\P!!('1U;&%J9&]N;W,@:F]G;W-U;'1SX6=A:0!!(%!!32!F96QH87-Z;N%L
M\V%Z;VYO<^UTX7,@;F5M(.%L;"!R96YD96QK97KI<W)E+@!014%2.CI-86EL
M(&%L<F5N9'-Z97(`4$=0(&1I9VETX6QI<R!A;.'M<N%S`%!'4"UV96P@=&ET
M:V]S[71O='0@861A=`!01U`@;GEI;';A;F]S(&MU;&-S`%!'4"UV96P@86SA
M[7)T+W1I=&MO<^UT;W1T(&%D870`4$A0(&OS9`!$Z6QU=.%N+V5S=&4@9WEE
M;F=E(&5S]0!$Z6QU=.%N(&5S]0!$Z6QU=.%N+V5S=&4@>N%P;W)O:P!$Z6QU
M=.%N+V5S=&4@:&%V87KA<P!$Z6QU=.%N+V5S=&4@:/-ZX7!O<F]K`$3I;'5T
MX6X@;F%P<_QTZ7,`1.EL=73A;B]E<W1E('II=F%T87)O:P!(:>%N>7II:R!A
M(%!/4TE8(&+U=NUTZ7,`8F5L<_4@;6%R9_,`4&%K:7-Z=.%N`%!A;&%U`%!A
M;&5S>G1I;B!497+\;&5T("AM96=S>N%L;'0I`%!A;F%M80!0X7!U82#::BU'
M=6EN96$`4&%R86=U87D`3>ER<^EK96QT96X@8F]R=6QT`$IE;'-Z\P!!(&IE
M;'-Z\W0@<VEK97)E<V5N(&UE9W;A;'1O>G1A='1U:RX`3F5M(&UE9V9E;&5L
M]2!J96QS>O,`02!2041)55,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S:&]Z(&IE
M;'-Z\R!S>OQK<^EG97,N`$IE;'-Z\R!M96=E<O5S[73I<W-E;`!*96QS>O,Z
M`$IE;'-Z\SH@`$$@:F5L<WIA=F%K;F%K(&5G>65Z;FG\:R!K96QL+@!"96EL
M;&5S>G3I<P!"96EL;&5S>G3A<R!A(';A9_-A<WIT86QR\VP`VG1V;VYA;`#:
M:B!F96QH87-Z;N%L\VYA:R!B96IE;&5N=&ME>F5T=&5K.@!%;6)E<F5K`'-Z
MX7IA;.EK`$MA<F)A;G1A<G3A<VD@9F5L861A=&]K(';I9W)E:&%J=.%S80!"
M96IE;&5N=&ME>NES:V]R(&AA:G1S=6L@=NEG<F4@82!K87)B86YT87)TX7-I
M(&9E;&%D871O:V%T/P!*;V=O<W5L='/A9P!!*'HI("(E<R(@:F]G;W-U;'1S
MX6=O="!N96T@=/9R]FQT_&LN`-9N;F5K(&YI;F-S(&5H:&5Z(&5L96=E;F3U
M(&IO9V]S=6QT<^%G80!*;V=O<W5L='/A9V]K`$IO9V]S=6QT<^%G(&%D;6EN
M:7-Z='+A8VGS`%-Z96WI;'EE<R!A9&%T;VL`4&5R=0#!;&QA=&ME9'9E;F-E
M:P!&_&SV<"US>FEG971E:P!496QE9F]N`$;I;GEKZ7!G86SI<FEA`%!I=&-A
M:7)N`'!I>&5L`$OV>FAE;'EE:P!+871T:6YT<V]N('9A;&%M96QY:6L@8V5L
M;.%R80!":7IT;W-A;B!T]G+V;&YI(&%K87)J82!E>G0@87H@96QE;65T.@!+
MZ7)E;2!E<O5S[71S92!M96<L(&AO9WD@=F%L\V)A;B!T]G+V;&YI(&OM=N%N
M:F$@97IT(&%Z(&5L96UE="X`2^ER96T@861J;VX@;65G(&5G>2!H\VYA<&]T
M(.ES(&5G>2#I=F5T+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E9_-R:6$@
M;F5VZ70Z`$OI<F5M('9A;/-S($E0(&/M;65T(&%D:F]N(&UE9RX`2^ER96T@
M=F%L\W,@9.%T=6UO="!A9&IO;B!M96<L(&5L;&5N]7)I>GIE(&$@:/-N87`@
M;F%P:F%I="X`2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<N`$OI<F5M
M('+V=FED96X@[7)J82!L92!A('!R;V)LZ6UA(&SI;GEE9^ET+@!+Z7)E;2!A
M9&IA(&UE9R!A(&)E:F5L96YT:V5ZZ7-I(&YE=NET(.ES(&IE;'-Z87;A=`!+
MZ7)E;2!O;'9A<W-A(&5L(&$@:_9V971K97KU('-Z]G9E9V5T+B!!(')E;F1S
M>F5R(&AA<WINX6QA=.%N86L@9F5L=.ET96QE:70@96P@2T5,3"!F;V=A9&YI
M82X`2^ER96T@861J82!M96<@87H@^FH@:V%T96?S<FEA(&YE=NET.@!,96YG
M>65L;W)S>N%G`%!O;&ET:6MA`%-Z879A>N%S;VL`4&]R='5GX6QI80!!(&OI
M<"!E;&AE;'EE>NES90!!('3A8FSA>F%T(&5L:&5L>65ZZ7-E`$OV>G9E=&QE
M;B!L97;I;&O\;&3I<R!E8F)E(&$@;6%P<.%B82`H24U!4"!N96T@;6EN9&EG
M('9E<WII(&9I9WEE;&5M8F4I`$%Z(&5L;?IL="`E<R#S<F$@8W-A<&%DZ6MM
M96YN>6ESZ6=E.B``0W-A<&%DZ6L\8G(@+SYV86SS<WKM;OMSZ6<`4')E9G-?
M;&1A<#H@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E<R!,1$%0(&MI=&5R:F5S
M>G3I<RX`4')E9G-?<V5S<VEO;CH@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E
M<R`H<V5S<VEO;BD@:VET97)J97-Z=.ES+@!,Z6=N>6]MX7,`02!T96YG97)S
M>FEN=&YE:R!M96=F96QE;/4@;.EG;GEO;>%S.B``3.EG;GEO;>%S.B``16SU
M>F5T97,@;65G=&5K:6YTZ7,`02!KZ7`@96SU>F5T97,@;65G=&5K:6YTZ7-E
M(/IJ(&%B;&%K8F%N`$5L]7KU(&]P8VGS:P!!(&1O:W5M96YT=6T@:VEN>6]M
M=&%TX7-A`%1I=&MO<R!K=6QC<P!(:6)A8F5J96QE;G3I<P!!(&AI8F$@;&7M
M<N%S80!0<F]J96MT(&ME>F5LZ7,`02!P<F]M<'0@<WKV=F5G90!.>6EL=N%N
M;W,@:W5L8W,`3GEI;';A;F]S(&MU;&-S^B!A;&=O<FET;75S`$YY:6QVX6YO
M<R!K=6QC<R!I;F9O<FWA8VGS`$$@;GEI;';A;F]S+W1I=&MO<R!K=6QC<W#A
M<G0@;F5M('-I:V5R_&QT(&SI=')E:&]Z;FDN`%!U97)T;R!2:6-O`$$@;&5V
M96QE:R!VZ6=L96=E<R!T]G)LZ7-E`$MA=&%R`$ME<F5S]2]P87)A;F-S('-T
M<FEN9P!+=O-T80!24T$@;GEI;';A;F]S(&MU;&-S("@E9"!B:71E<RD`4N%D
M:?-G;VUB;W,@:VEVX6QA<WITX7,`17/U`$5S]2!DZ6QE;/5T=`!%<_4@9.EL
M=73A;B]E<W1E`%KA<&]R`$5S]2#I<R!H879A>N%S`$AA=F%S97/U`%;I;&5T
M;&5N(&EDZ7IE=`!!<N%N>0!/;'9A<^%S`$QE=F5L96L@;VQV87/A<V$`5.EN
M>6QE9R!T]G+V;&K\:R`E<R!F96QH87-Z;N%L\W0_($5Z(&$@=N%L=&]Z=&%T
MX7,@;F5M(&9O<F3M=&AA=/,@=FES<WIA+@!686SS8F%N('3V<O9L;FD@:^UV
MX6YJ82!E>G0@82!F96QJ96=Y>NES=#\`5.EN>6QE9R!T]G+V;&K\:R`E<R!F
M96QH87-Z;N%L\R!A9&%T86ET/R!%>B!A(';A;'1O>G1A=.%S(&YE;2!F;W)D
M[71H873S('9I<W-Z82X`VFIR82!VZ6=R96AA:G1J82!A>B!U=&]L<_,@=N%L
M=&]Z=&%TX7-T`$9R:7-S[73I<P!!(&UE;OP@9&EN86UI:W5S(&5L96UE:6YE
M:R!F<FES<^UTZ7-I(&=Y86MO<FESX6=A.@!!(&QI<W1A(&9R:7-S[73I<V4`
M07H@]G-S>F5G>O5O;&1A;"!F<FES<^UTZ7/I;F5K(&=Y86MO<FESX6=A.@!/
M8FIE:W1U;2!B]FYGZ7-Z]0!&<FES<^UTZ7,`365G:F5G>7KI<V5K`%3A=F]L
M:2!S>F5R=F5R96L`02!TX79O;&D@55),("AP;"X@:'1T<#HO+W=W=RYV86QA
M;6DN:'4O;65G=F%L86UI*3H`5/9R;.ES`$)L;VMK('3V<FSI<V4`02!K871E
M9_-R:6$@=/9R;.ES90!/<WIL;W`@=/9R;.ES90!!(&9O<FUA='3A;.%S('3V
M<FSI<V4`02!PX7(@=/9R;.ES90!4]G+V;&K\:R!A>B!E;&UE;G1E='0@<')O
M9W)A;6]T(&$@<WIE<G9E<B!I9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T87)T
M86QM87KS(&%L:_9N>79TX7+A8O-L+@!696=Y_&L@:VD@`%9E9WG\:R!K:2!E
M>G0@82!RZ7-Z="!A(&1O:W5M96YT=6UB\VP`02!F96QH87-Z;N%L\R!T]G)L
MZ7-E`"5S(&9E;&AA<WINX6SS('3V<FSI<V4`02!KZ7+I<R!N96T@=&5L:F5S
M[71H973U+B!!(&MA<&]T="!H:6)A:_-D.B``02!K97)E<V5T="!S>F]L9^%L
M=&%TX7,@;F5M('1A;.%L:&%T\RX`02!K]G1E;&5Z]65N(&UE9V%D86YD\R`B
M)7,B(&YE;2!S>F5R97!E;"`E<R!K;VYF:6=U<N%C:?-JX6)A;BX`02!K]G1E
M;&5Z]65N(&UE9V%D86YD\R`B)7,B(&YE;2!S>F5R97!E;"!A(%9&4R!K;VYF
M:6=U<N%C:?-JX6)A;BX`02!K]G1E;&5Z]65N(&UE9V%D86YD\R`B)7,B(&YE
M;2!S>F5R97!E;"!A(&MO;F9I9W5RX6-I\V)A;BX`4WK\:W/I9V5S(&UE>O4`
M4F5S970`02!J96QS>O,@X73A;&SM=.%S80!!>B#6;B!J96QS>F%VX6YA:R#A
M=.%L;.UTX7-A`$%Z('5T;VQS\R!K97)E<^ES('9I<W-Z8>%L;.UTX7-A`$5R
M961MZ6YY`%9I<W-Z82!A>B!O<&-I\VMH;WH`07H@^FH@:F5L<WKS="#M<FIA
M(&)E(&ES;>ET`%+I=6YI;VX`P6QL[71S=6L@=FES<WIA(&$@:V]N9FEG=7+A
M8VGS=`!2:6-H(%1E>'0@161I=&]R(&]P8VGS:P!486SA;/-S(&OI<F3I<V5K
M`&IO8F(`2F]B8B!O;&1A;&D@9F5J;.EC`$IO8F(@;VQD86QI(.ER=.EK96L`
M4V]R('1U;&%J9&]N<^%G;VLN+BX`4WIE<F5P`%)O;>%N:6$`1F]R9V%TX7,@
M,3@P(&9O:VMA;`!"86QR82!F;W)G873A<P!*;V)B<F$@9F]R9V%TX7,`4V]R
M('1U;&%J9&]N<^%G;VL`4V]R('1U;&%J9&]N<^%G;VL`4V]R;VLZ`%9O;F%L
M86L`36EN9&5N('-O<B#I<R!O<WIL;W`@:_9Z]G1T(&QE9WEE;B!V;VYA;`!#
M<V%K(&%Z(&]S>FQO<&]K(&OV>O9T="!L96=Y96X@=F]N86P`0W-A:R!A('-O
M<F]K(&OV>O9T="!L96=Y96X@=F]N86P`1G5T=&%TX7,`3W)O<WH@1O9D97+A
M8VGS`%)U86YD80!3+TU)344@9&EG:73A;&ES(&%LX>URX7,`4R]-24U%('-Z
M86)VX6YY('-Z97)I;G0@=&ET:V]S[71O='0@;&5VZ6P`4T%33"!F96QH87-Z
M;N%L\V%Z;VYO<^UTX7,@;F5M('1A;.%L:&%T\RX`4TU3(&O\;&3I<P!344P@
M<&%R86YC<R!A(&ME<F5SZ7-H97H`4U-(`%-)2T52W$Q4`%-Z;P!3>F5N="!)
M;&]N82US>FEG970`4V%I;G0@2VET=',@Z7,@3F5V:7,`4V%I;G0@3'5C:6$`
M4V%I;G0@4&EE<G)E(.ES($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@Z7,@1W)E
M;F%D:6YE+7-Z:6=E=&5K`%5G>6%N87H@82!F<F%M92`H7W-E;&8I`%-Z86UO
M80!386X@36%R:6YO`%-A;R!4;VWI(.ES(%!R[6YC:7!E`$W[:&]L9&%S(&EN
M=&5R;F5T96SI<NES`%-Z8?ID+4%RX6)I80!-96YTZ7,`(B5S(B!M96YTZ7-E
M`"5S(&UE;G3I<V4`02!B9>%L;.UTX7-O:R!M96YTZ7-E`$UE;G1S_&L@96P@
M87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0@4$A0('!R;V=R86T@9F]R;>%J
MX6)A;B!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N>6]K870@=&%R=&%L
M;6%Z\R!A;&OV;GEV=.%RX6)A;BX`)7,@:V]N9FEG=7+A8VGS:N%T(&5L;65N
M=&5T=/QK+@!%;&UE;G1E='3\:R!A('-E='5P('5P9W)A9&4@<')O9W)A;6]T
M(&ED93H@(B5S(@!3>O-R=N%N>6]S('II=F%T87)O:P!4=61O;>%N>0!+97)E
M<^ES`$ME<F5SZ7-I('-Z;VQGX6QT873A<V]K`$$@:V5R97/I<R!E<F5D;>EN
M>64`02!K97)E<^ES(&AA=.%R86D`2V5R97/I<R!A('-Z]G9E9V)E;@#!;&QO
M;>%N>6]K(&MI=N%L87-Z=.%S80!6X6QA<W-Z;VX@:VD@96=Y(&3A='5M;W0`
M365L>6EK(&-S;W!O<G1O="!K[7;A;FIA(&AO>GKA861N:0!6X6QA<W-Z82!K
M:2!A>B#Z:B!T=6QA:F1O;F]S=`!6X6QA<W-Z;VX@:VD@96=Y(&IE9WEZ971T
M]FUB]G0`5N%L87-S>F]N('-Z97)V97)T`$UE;'EI:R!F96QH87-Z;N%L\W0@
M:^UVX6YJ82!H;WIZX6%D;FD`36EN9&5T(&MI:F5L]FQJ_&L`5N%L87-S>F$@
M:VD@87H@]G-S>F5S(&3A='5M]G-S>F5T97;U="X`5N%L87-S>F]N(&5G>2!O
M8FIE:W1U;6]T`$5G>2!S92!L96=Y96X@:VEJ96SV;'9E`%;A;&%S<WIA(&MI
M(&$@;65G:F5L96[M=&5N9/4@:F5G>7IE='3V;6+V:V5T.@!6X6QA<W-Z82!K
M:2!A(&OM=N%N="!K87)A:W1E<BAE:V4I="!A>B!A;.%B8FD@;&5H973U<^EG
M96L@:_9Z_&PN($5Z=73A;B`B8V]P>2]P87-T92(@;?-D<WIE<G)E;"!A(&UE
M9V9E;&5L]2!H96QY<F4@;>%S;VQH871J82#U:V5T+@!6X6QA<W-Z82!K:2!A
M(&3A='5M96QVX6QA<WIT\R!K87)A:W1E<G0Z`%;A;&%S<WIA(&MI(&$@9.%T
M=6T@9F]R;>%T=6WA=#H`5N%L87-S>F$@:VD@87H@97AP;W)TX6SA<R!F;W)M
MX71U;>%T.@!6X6QA<W-Z82!K:2!A>B!I;7!O<G3A;&%N9/,@9N%J;'0Z`%;A
M;&%S<WIA(&MI+"!H;V=Y(&UI;'EE;B!F;W)MX71U;?H@9N%J;&+S;"!K[7;A
M;B!I;7!O<G3A;&YI.@!6X6QA<W-Z82!K:2P@;65L>6EK(&%Z;VYO<^UT\VKA
M="!K[7;A;FIA(&UE9W;A;'1O>G1A=&YI.@!6X6QA<W-Z82!K:2!A>B!I9/5E
M;';A;&%S>G3S(&MA<F%K=&5R=#H`5N%L87-S>F$@:VD@87H@:63U(&9O<FWA
M='5MX70Z`%;A;&%S<WIO;B!K:2!KZ70@96=Y;>%S;F%K(&UE9V9E;&5L]2!M
M97KU="X`5N%L87-S>F$@:VD@82!K[7;A;G0@<WKM;F5G>?QT=&5S="X`5N%L
M87-S>F$@:VD@87H@UFYN96L@;65G9F5L96SU(&YY96QV970Z`$$@:VEVX6QA
M<WIT;W1T(&MA=&5G\W)IX6LZ`$AI8F%J96QE;G3I<R!K_&QDZ7-E`%--4R!K
M_&QDZ7-E`%-Z96YE9^%L`%-Z96YZ;W(Z(`!S>F5P=&5M8F5R`%-Z97)B:6$@
MZ7,@36]N=&5N96=R\P!3;W)O>F%T<WKA;0!!('-Z97)V97)T]6P@:V%P;W1T
M(&%D870@:&EBX7,L('9A9WD@;F5M(.%L;"!R96YD96QK97KI<W)E+@!!(&9E
M;&AA<WINX6SS:V%P8W-O;&%T;VL@861M:6YI<WIT<N%C:?-J80!,96KA<G0@
M82!F96QH87-Z;N%L\VMA<&-S;VQA="!A>F]N;W/M=/-J82`H<V5S<VEO;B!)
M1"DN`$9E;&AA<WINX6SS:V%P8W-O;&%T;VL`2&%L;6%Z`$QE:&5T]7/I9R!J
M96QS>F%VX6YA:R#A=.%L;.UTX7/A<F$L(&%B8F%N(&%Z(&5S971B96XL(&AA
M(&5L9F5L96IT96[I+@!4X79O;&D@<WIE<G9E<F5K(&5LZ7+I<V4@X6QL[71H
M873S(&)E+"!M96QY96ME="!A>B!I;F1U;/-O;&1A;.%N(&OM=N%N(&UE9VIE
M;&5N[71E;FDN`$$@:^UVX6YT(&YY96QV+"!I9/5Z\VYA(.ES(&3A='5M9F]R
M;>%T=6T@8F7A;&SM=.%S82X`0F7A;&SM=&AA=/,L(&AO9WD@;65L>6EK(&%L
M:V%L;6%ZX7,@:F5L96YJ96X@;65G(&$@8F5J96QE;G1K97KI<R!U=.%N+"!M
M:6QY96X@<WKM;F5G>?QT=&5S="P@;VQD86QF<FES<^UTZ7-I(&=Y86MO<FES
MX6=O="!I;&PN(&5G>>EB(&)EX6QL[73A<V]K870@<WIE<F5T;F4N`$)EX6QL
M[73A<V]K`$$@8F7A;&SM=.%S;VMA="!M96?Z:NUT\R!P<F]G<F%M;VL@X6QL
M;F%K(')E;F1E;&ME>NES<F4`02!M96=A9&]T="!P87)A;>ET97(@=/9B8B!H
M96QY970@:7,@:F5L96YT:&5T.B``4V5Y8VAE;&QE+7-Z:6=E=&5K`%;A<^%R
M;.%S`%+V=FED(/9S<WIE9F]G;&%LX7,`16P@:^UVX6YJ82#I<FYI(&%Z(&5G
M>65S(&9U;FMC:?-K870@06QT+6)I;&QE;G1Y^RUK;VUB:6[A8VGS:VMA;"!I
M<S\`365G:F5L96[M=.ES`$QE9WEE;F5K(&9U;FMC:?-V86P@96QLX71O='0@
M:6MO;F]K/R``375T87-S=6L@;65G(&$@:_QL]FYB<^EG96ME="!A>B!E;&UE
M;G1E='0@Z7,@87H@^FIO;FYA;B!LZ71R96AO>F]T="!K;VYF:6=U<N%C:?,@
M:_9Z]G1T+@!-:6YD96X@8F5J96QE;G1K97KI<VMO<B#M<O-D:NEK(&MI(&$@
M:V]RX6)B:2!U=&]L<_,@8F5J96QE;G1K97KI<R!I9&5J93\`375T87-S=6L@
M82!J96=Y>F5T=/9M8B!N97;I=#\`02!K]G9E=&ME>O4@:V%T96?S<FGA:OH@
M9F5L:F5G>7KI<V5K970@:F5L96[M='/\:R!M96<`5N%L87-Z=&AA=/,@;&5G
M>65N(&%Z(&5R961E=&D@;65G=&%R=.%S80!,96=Y96X@9.%T=6UVX6QA<WIT
M\P!,96=Y96X@96=Y('3A8FSA>F%T:V5Z96SU(&UE;OQS;W(_`$UU=&%S<W5K
M(&$@)7,@;65N_'0@82!B86P@;VQD86QO;C\`3NEZ>OQK(&UE9R!TX6)LX7IA
M="!C96QLX6EN86L@='5L86ID;VYSX6=A:70`3NEZ>OQK(&UE9R!TX6)LX7IA
M="!T=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G('3A8FSA>F%T('-O<F%I;F%K
M('1U;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@82!KZ7`@='5L86ID;VYSX6=A
M:70`375T87-S=6L@82!F96QT]FQTZ7-T`%KA<&]R;VL`6N%P;W)O:R!DZ6QE
M;/5T=`!:X7!O<F]K(&3I;'5TX6XO97-T90!(96QY:2!ZX7!O<F]K`$MI8W-I
M;GGM=.ES`$5L]7-Z]G(@:VEC<VEN>>UT96YI92!K96QL+"!V86=Y(&5L(&ME
M;&P@;6]Z9.UT86YI82!A(&AE;'EE="!E;&9O9VQA;/,@8FQO:VMO:V%T+@!3
M:65R<F$@3&5O;F4`VFH@9F5L:&%S>F[A;/-K(&)E:F5L96YT:V5ZZ7-E`$1I
M9VETX6QI<R!A;.'M<N%S`$$@9&EG:73A;&ES(&%LX>URX7,@86QG;W)I=&UU
M<V$`4WII;F=A</IR`$WI<F5T`$$@:V%R8F%N=&%R=.%S(&MI:&%G>>%S80!3
M>FQO=N%K:6$`4WIL;W;I;FEA`$AA=F%ZX7,`2/-ZX7!O<@!(\WKA<&]R;VL`
M2/-ZX7!O<F]K(&3I;&5L]71T`$OI<_4@9.EL=73A;FDO97-T:2!H\WKA<&]R
M;VL`02!H\R!MZ6QY<^EG93H@`$CS(';M>FUE;FYY:7/I9V5B96X@:VEF96IE
M>G9E.B``4V%L86UO;BUS>FEG971E:P!3>F]MX6QI80!$86QO:RP@=F5R<V5K
M`$MA=&5G\W)I82!S>F5R:6YT:2!S;W)R96YD`$5L;F5V97KI<R!S>F5R:6YT
M:2!S;W)R96YD`$$@<V]R8F%R96YD97KI<R!I<N%N>>%N86L@:VEVX6QA<WIT
MX7-A`$9E;&%D\VD@8^UM`$3I;"U!9G)I:V$`9.EL+65U<O-P86D@*$E33RTX
M.#4Y+3,I`$3I;&DM1V5O<F=I82#I<R!$Z6QI(%-A;F1W:6-H+7-Z:6=E=&5K
M`$3I;&D@9NEL=&5K90!3>F]M<WKI9&]S(&-E;&SA:R!K]GKV='1I('3A=F]L
M<^%G`$$@8V5L;&$@=&%R=&%L;6$@Z7,@:V5R971E(&OV>O9T=&D@=.%V;VQS
MX6<`2&5L>6MI=/9L=/4`5.%V;VQSX6<`5.%V;VQSX6<@Z7,@8F5L<_4@;6%R
M9_,@8F7A;&SM=.%S`%-P86YY;VQO<G-ZX6<`4W!A;6%S<V%S<VEN92!B9>%L
M;.UTX7-O:P!3<&5C:>%L:7,@:V%R86MT97(@8F5V:71E;&4`02!C96QL82!K
M971TZ6)O;G3A<V$`07H@;W-Z;&]P(&ME='3I8F]N=.%S80!!('-O<B!K971T
MZ6)O;G3A<V$`4W!O<G0`4W+M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!!
M>B!E;'/U(.EV`,%L;&%M('9A9WD@=&%R=&]MX6YY`,%L;&%P;W0`365N=.ES
M:2!F;W)MX71U;0!#[6T@*'5T8V$I`.%T:/IZ;W1T`%-T<FEN9R!L:7-T80!4
M]G+V;&K\:R!A(&/M;6+U;"!A($`@=73A;FD@<NES>G0`4W3M;'5S(%M#4U-=
M`%9A`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T86SA;&AA=/,N`%3A<F=Y
M`$O\;&1J_&L@96P`(B5S(B#Z:B!F96QH87-Z;N%L\R!B96IE;&5N=&ME>NES
M:2!KZ7)E;&WI="!T;W;A8F+M=&]T='5K+B#6;B!C<V%K(&OI<F5L;>EN96L@
M96QF;V=A9.%SX70@:_9V973U96X@='5D(&UA:F0@8F5J96QE;G1K97IN:2X`
M86QS\R!I;F1E>`!3:6ME<OQL=`!3:6ME<F5S96X@:&]Z>N%A9'1U:R`B)7,B
M+70@82!R96YD<WIE<FAE>BX`(B5S(B!F96QH87-Z;N%L\R!A9&%T86ET('-I
M:V5R97-E;B!T]G+V;'3\:R!A(')E;F1S>F5R8O5L+@!3:6ME<F5S96X@=/9R
M]FQT_&L@(B5S(BUT+@!3:6ME<F5S96X@96QTX79O;.UT;W1T=6L@(B5S(BUT
M(&$@<F5N9'-Z97)B]6PN`$$@:V]N9FEG=7+A8VGS="!S:6ME<F5S96X@=FES
M<WIAX6QL[71O='1U:RX@02!VX6QT;WKA<V]K(&UE9W1E:VEN=.ESZ6AE>B!F
M<FES<^UT<V4@87H@;VQD86QT+@!3:6ME<F5S96X@96QM96YT971T_&L@(B5S
M(BUT+@!!(&)A8VMU<"!K;VYF:6=U<N%C:?-T(&5L;65N=&5T=/QK+@!3:6ME
M<F5S96X@96QM96YT971T_&L@82AZ*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS
M="X`(B5S(B!A9&%T86EN86L@;?-D;W/M=.%S82!S:6ME<F5S96X@;65G=/9R
M=.EN="X`4VEK97)E<V5N(&5L;65N=&5T=/QK(&$@)7,@X6QL;VWA;GET+@!3
M>G5DX6X`UG-S>F5F;V=L86SA<P!.87!K96QT90!.87!N>75G=&$`;F%P;W,`
M3F%P:V5L=&4`3F%P:V5L=&4O;F%P;GEU9W1A`$YA<&ME;'1E.B``3F%P;GEU
M9W1A`$YA<&YY=6=T83H@`&9E;'/U(&EN9&5X`$]N;&EN92!K;VUM=6YI:^%C
M:?,@*&-H870I`%-U<FEN86UE`$-S86SA9&[I=@!3=F%L8F%R9"#I<R!*86X@
M36%Y96X`4WIVX7II9O9L9`!3=NED;W)S>N%G`%-VX6IC`$%Z(&%D871S>FEN
M:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>70@=/9R]FQT_&L`4WII;G1A:W1I
M:V%I(&AI8F$@82!K97)E<_5K:69E:F5ZZ7-B96X`4WKM<FEA:2!!<F%B($OV
M>G3A<G-A<^%G`%II=F%T87(`6FEV871A<BP@97+U<R!S>NEL`%II=F%T87)O
M:P!+;W)A:2!Z:79A=&%R;VL`5%-6("A404(@:V%R86MT97)R96P@96QVX6QA
M<WIT;W1T(.ER=.EK96LI(.%L;&]MX6YY`%3A8FSA>F%T`$$@=.%B;.%Z870@
M='5L86ID;VYSX6=A:0!!('3A8FSA>F%T('1U;&%J9&]N<^%G86D`5&%J=F%N
M`%1A:G9A;@!4861Z<VEK:7-Z=.%N`%1A;GKA;FEA:2!%9WEE<_QL="!+:7+A
M;'ESX6<`02!CZ6PZ`$9E;&%D871O:P!496QE9F]N<WKA;0!!>B!E;&WZ;'0@
M\W)A(&CU;>ER<^EK;&5T93H@`$CU;>ER<^EK;&5T`$CU;>ER<^EK;&5T.B``
M2/5MZ7)SZ6ML970\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S`$$H
M>BD@(B5S(B!S86)L;VX@;F5M('1A;.%L:&%T\RX`4V%B;&]N;VL@861M:6YI
M<WITX6-I\VIA`%-Z]G9E9P!C<V%K('-Z]G9E9P!3>O9V96=E;&AE;'EE>NES
M`'-Z]G9E9R!T971E:F4`0W/\`'1H86D@*%1)4RTV,C`I`%1H86EF]FQD`$%Z
M(&9T<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$$@2&ES=&]R>2!R96YD<WIE
M<B!M^VOV9.ES92!N:6YC<R!E;F=E9.EL>65Z=F4N`$$@2&]R9&4O2V]L86(@
M:6YT96=RX6-I\R!E>G0@;F5M('3A;6]G871J83H@(B5S(@!!>B!)35-0(&YA
M<&SS>N%S="!N96T@<VEK97+\;'0@;65G:V5Z9&5N:2X`02!-86EN=&5N86YC
M93HZ(&]S>G3A;'D@8F5T]FQTZ7-E(&YE;2!S:6ME<OQL=`!!>B!/<&-I\R!A
M8FQA:R!B97KA<F]D;W1T+B!+:6SI<.ES(&OV=F5T:V5Z:6LN`$$@2F]G;W-U
M;'1SX6=O:R!H87-Z;N%L873A;F%K(&5L]69E;'3I=&5L92P@:&]G>2!A(')E
M;F1S>F5R9V%Z9&$@:V]N9FEG=7+A;&IO;B!E9WD@82!J;V=O<W5L='/A9VD@
M861A=&]K870@=&%R=/-S86X@=.%R;VQN:2!KZ7!E<R!A;')E;F1S>F5R="X`
M0W-A:R!A;'5L(&QE9WEE;B!K97)E=`!!('!A<G1N97(@87IO;F]S[73S<WKA
M;6$@;F5M('9O;'0@;65G861V82_\<F5S96X@;6%R861T('9A9WD@87H@861A
M=&+A>FES8F%N(&YE;2!V;VQT(&UE9W1A;.%L:&%T\RX`02!P87)T;F5R(&%D
M871A:70@<VEK97)E<V5N(&AO>GKA861T=6L@82!C[6UJ96=Y>NEKZ6AE>BX`
M2_QL]F[A;&SS(%!'4"!A;.'M<N%S:2!B;&]K:R!S>OQK<^EG97,@82!D:6=I
M=.%L:7-A;B!A;.'M<G0@_'IE;F5T(&AI=&5L97-SZ6?I;F5K(&5L;&5N]7)Z
MZ7/I:&5Z+@!!(&OV<FQE=NEL;&ES=&$@87IO;F]S[73S<WKA;6$@;F5M('9O
M;'0@;65G861V82_\<F5S96X@;6%R861T('9A9WD@87H@861A=&+A>FES8F%N
M(&YE;2!V;VQT(&UE9W1A;.%L:&%T\RX`02!K]G)L97;I;&QI<W1A(&YE;2!V
M;VQT(&UE9V%D=F$N`$$@=&ET:V]S[73A<VD@<WIO;&?A;'1A=.%S;VMH;WH@
M8FEZ=&]N<^%G;W,@*'1I=&MO<^UT;W1T*2!W96(@:V%P8W-O;&%T(&ME;&PN
M`$$H>BD@)7,@X6QL;VWA;GEB86X@<WIE<F5P96QN:64@:V5L;&5N92!E9WD@
M)7,@8F7A;&SM=.%S;F%K+@!!*'HI("5S(.%L;&]MX6YY8F%N('-Z97)E<&5L
M;FEE(&ME;&QE;F4@=F%L86UI;'EE;B`E<R!B9>%L;.UTX7,H;VLI;F%K+@!!
M(&;A:FP@;F5M(&WA<V]L:&%T\R#V;FUA9^%R82X`02!FX6IL8F%N(&YE;2!V
M;VQT(&%D870N`$%Z(/QZ96YE="!F96ILZ6-S;W)A:2!A(&OV=F5T:V5Z]6LN
M`$$@=&5L:F5S(&OI<&5R;GGU<R#\>F5M;?-D('!R;V)LZ6WA:V%T(&]K;WIH
M870@87H@26YT97)N970@17AP;&]R97(@:&%S>F[A;&%T82!E<V5TZ6XL(&UE
M<G0@96)B96X@;VQY86X@<')O9W)A;6AI8N%K('9A;FYA:RP@86UI:V5T(&YE
M;2!T=61T=6YK(&UE9VME<OQL;FDN($$@:^EP97)N>?5J92!O;'9A<VAA=&%T
M;&%N;N$@=N%L:&%T+"!B:7IO;GEO<R!E9&ET;W(@9G5N:V-I\VL@:&GA;GEO
M>FAA=&YA:R#I<R]V86=Y(';A<F%T;&%N=6P@;&5F86=Y:&%T(&$@8O9N9^ES
M>O5P<F]G<F%M+B!7:6YD;W=S(#EX(&AA<WINX6QA=&$@97-E=.EN(&YA9WEO
M;B!V86SS<WKM;OLL(&AO9WD@)T=E;F5R86P@<')O=&5C=&EO;B!F875L="<@
M:&EB82!M:6%T="#Z:G)A(&ME;&P@:6YD[71A;FEA(&UA:F0@82!GZ7#I="Y<
M;EQN1FEG>65L;65Z=&5T=/QK(2!+871T:6YT<V]N(&%Z($]+(&=O;6)R82P@
M:&$@;>EG:7,@;65G(&OM=N%N:F$@:^USZ7)E;&YI(&$@=&5L:F5S(&OI<&5R
M;GGU<R#\>F5M;?-D;W0N`$$@(B5S(B!A>F]N;W/M=/-T(&MI=/9R]FQT_&LN
M`$-S86L@8F%L(&]L9&%L;VX@;&5G>65N(&ME<F5T`$$@1VYU4$<@<')O9W)A
M;2!H96QYZ70@;65G(&ME;&P@861N:2!A($-R>7!T7W!G<#HZ(&]S>G3A;'D@
M:&%S>F[A;&%TX6AO>BX`02!L97;I;"P@;65L>65T("5S(&YA<&KA;B!K_&QD
M]G1T("5S(&/M;7IE='1N96L@(B5S(B!TX7)G>6)A;BP@82!C[6UZ971T('-Z
MX6WM=/-GZ7#I;B!M96=J96QE;G0N($%R<F$@;FEN8W,@9V%R86YC:6$L(&AO
M9WD@96P@:7,@;VQV87-TX6L@:6QL+B!H;V=Y(&UE9^ER=&5T=.EK+@!-:2!L
M96=Y96X@82!L97;I;.UR\R!A8FQA:VAO>B!M=71A=/,@;&EN:R!E;&YE=F5Z
MZ7-E`$%Z(&9E;&IE9WEZZ7-T(&MI=/9R]FQT_&LN`$$H>BD@(B5S(B!J96=Y
M>F5T=/9M8O9T(&YE;2!S:6ME<OQL="!LZ71R96AO>FYI.B`E<P!,Z71R96AO
M>G1U:R!A*'HI("(E<R(@:F5G>7IE='3V;6+V="X`02AZ*2`B)7,B(&IE9WEZ
M971T]FUB]G0@:VET]G+V;'3\:RX`02AZ*2`B)7,B(&IE9WEZ971T]FUB]G0@
M96QM96YT971T_&LN`$$@;65Z]6L@<WKA;6$@8W-A:R!N=6UE<FEK=7,@Z7)T
MZ6L@;&5H970N`$%Z(&]P96YS<VP@;6]D=6P@<WK\:W/I9V5S(&$@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!O<WITX6QY(&AA<WINX6QA=.%H;WHN`$$@(B5S(B!S
M>F5MZ6QY97,@8F7A;&SM=.%S(&YE;2!M96YT:&5T]2!E;"P@;65R="!MZ7)E
M=&4@;65G:&%L861J82!A(&UE9V5N9V5D971T(&UA>&EM=6UO=`!.96T@=&%L
MX6QH873S(&%Z(&$@<')O9W)A;2!A('-Z97)V97)E;BP@86UI('-Z_&MSZ6=E
M<R!E;FYE:R!A>B!A9&%T=.UP=7-N86L@*"5S*2!A(&UE9VIE;&5N[73I<^EH
M97HN`$%Z(&EDZ7KU:F5L(&MA<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT
M97(@;&5H970N`$IO8F(@Z7,@8F%L(&]L9&%L;VX@;&5G>65N(&ME<F5T`$-S
M86L@:F]B8B!O;&1A;&]N(&QE9WEE;B!K97)E=`!!>B!E;';A;&%S>G3S(&MA
M<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT97(@;&5H970N`$$H>BD@(B5S
M(B!S>F5R=F5R="!T]G+V;'3\:RX`02AZ*2`B)7,B('-Z97)V97)T(&5L;65N
M=&5T=/QK+@`E<R!B96IE;&5N=&ME>NES:2!KZ7)E;&WI="!T]G+V;'3\:RX`
M02!M96=A9&]T="!S;W(@*"5D*2!N96T@;.ET97II:RX`02AZ*2`B)7,B(&ED
M96EG;&5N97,@9N%J;"!N96T@;.ET97II:RX`02!B9>UR="!S>O9V96<@;F5M
M(&5G>65Z:6L@82!KZ7!E<FYY]6X@;&5V]79E;"X`06QU;"#I<R!F]FS\;"!L
M96=Y96X@:V5R970`0W-A:R!F96YT(&QE9WEE;B!K97)E=`!!(&9E;'3V;'3V
M='0@861A=&]K(&%Z(&5L]7KU(&SI<.ES(/-T82!E;'9E<WIT96LN`$$@9F5L
M=/9L=/9T="!FX6IL="!N96T@<VEK97+\;'0@96QM96YT96YI+@!!('=E871H
M97(N8V]M(&)L;VMK(&YE;2!H87-Z;N%L:&%T\RX`02!M96=J96QE;NES:2!S
M=.UL=7,@*'1H96UE<RD@86QK]FYY=G3A<B`B)7,B(&YE;2!T86SA;&AA=/,N
M`$YI;F-S96X@=N%L87-Z=&AA=/,@;W!C:?,N`$YI;F-S(&$@;&5VZ6P@8F5L
M<V5JZ6)E;B!M96=J96QE;NUT:&5T]2!M96QLZ6ML970N`%3Z;"!S;VL@:V%R
M86MT97(@=F%N(&5B8F5N(&$@;65Z]6)E;BX@UFX@)7,@:V%R86MT97)T(&%D
M;W1T(&UE9SL@82!M87AI;>%L:7-A;B!M96=A9&AA=/,@<&5D:6<@:V5V97-E
M8F(L(&UI;G0@)7,N`"(E<R(@9F5L:&%S>F[A;/-N86L@82!R96YD<WIE<FAE
M>B!A9.%S86MO<B!H:6)A('3V<G3I;G0N("5S`"(E<R(@9F5L:&%S>F[A;/,@
M861A=&%I;F%K('3V<FSI<V4@<V]RX6X@:&EB82!LZ7!E='0@9F5L.B``(B5S
M(B!R96YD<WIE<F+U;"!V86SS('3V<FSI<V5K;W(@:&EB82!LZ7!E='0@9F5L
M.B``(B5S(B!M\V1O<^UTX7-A('-O<N%N(&AI8F$@;.EP971T(&9E;#H@)7,`
M07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT
M96YI+B`E<R!N96T@=/9L=/5D]G1T(&9E;"X`07H@X6QL;VWA;GET(&YE;2!S
M:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI+B`E<R!N86=Y;V)B+"!M
M:6YT(&$@;6%X:6WA;&ES86X@;65G96YG961E='0@;>ER970@*"5D(&+A:G0I
M+@!!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@<WIE<G9E<G)E(&9E;'3V
M;'1E;FDN($$H>BD@)7,@9N%J;&YA:R!C<V%K(&5G>2!RZ7-Z92!T]FQT]63V
M='0@9O9L+@!!(&QE=NEL(&4@<NES>NEN96L@;65G:F5L96[M=.ES96MO<B!H
M:6)A('3V<G3I;G0`02!P87)T;F5R(&%D871O:R!I;7!O<G3A;.%S82!S;W+A
M;B!H:6)A('3V<G3I;G0N`$%Z(&EM<&]R=.%LX7,@<V]RX6X@:&EB82!T]G)T
MZ6YT.B`E<P!!>B!I0V%L96YD87(@861A=&]K(&EM<&]R=.%LX7-A('-O<N%N
M(&AI8F$@=/9R=.EN="X`02!V3F]T92!A9&%T;VL@:6UP;W)TX6SA<V$@<V]R
MX6X@:&EB82!T]G)TZ6YT+@!(:6+A<R!A(&UE9V%D;W1T(&MO;F9I9W5RX6-I
M\RX@3&5H970L(&AO9WD@;F5M('3V;'3V='0@:VD@96=Y('-Z_&MSZ6=E<R!M
M97KU="X`02!P87)T;F5R:F5G>7KI:VME;"!K87!C<V]L871O<R!F96QA9&%T
M(';I9W)E:&%J=.%S82!S;W+A;B!H:6)A(&SI<&5T="!F96PN($OI<F5M('!R
M\V+A;&IA(&UE9R!KZ7/U8F(N`$AI8F$@=/9R=.EN="!A(&9E;&IE9WEZZ7,@
M=/9R;.ES92!S;W+A;CH@)7,`2&EB82!T]G)TZ6YT(&$@9F5L:F5G>7KI<R!E
M;&UE;G3I<V4@<V]RX6XZ("5S`$AI8F$@=/9R=.EN="!A('!A<G1N97(@861A
M=&%I;F%K(&9R:7-S[73I<V4@<V]RX6XN($OI<F5M('!R\V+A;&IA(&UE9R!K
MZ7/U8F(N`$$@:_9R;&5VZ6QL:7-T82!A9&%T86EN86L@9G)I<W/M=.ES92!S
M;W+A;B!H:6)A('3V<G3I;G0N($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N
M`$AI8F$@=/9R=.EN="!A(&9E;&IE9WEZZ7,@;65G:F5L96[M=.ES96MO<CH@
M)7,`3F5M('9O;'0@97AP;W)TX6QH873S(&9E;&IE9WEZZ7,N`$5Z(&%Z($E-
M05`@<WIE<G9E<B!N96T@=.%M;V=A=&IA(&$@;6%P<.%K:&]Z('9A;/,@:&]Z
M>N%FZ7+I<R!M96=O<WITX7/A="X`17H@;F5M('3[;FEK('-Z86+A;'EO<R!R
M87(@X6QL;VWA;GEN86LN`$5Z(&YE;2!T^VYI:R!S>F%BX6QY;W,@>FEP(.%L
M;&]MX6YY;F%K+@!%>B!N96T@=/MN:6L@Z7)VZ6YY97,@:^%R='EA<WKA;6YA
M:RX`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA
M<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&$@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!S>F]L9^%L=&%T\VX@X70N`$5Z(&$@;65G:&%J
M=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M
M="!K_&QD:OQN:R!A(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI('-Z;VQGX6QT
M873S;B#A="X`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(
M5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&%Z('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI('-Z;VQGX6QT873S;B#A="X`17H@82!M
M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!33510+6MA<&-S;VQA=&]N
M(%--4RUT(&O\;&1J_&YK(%9O9&%F;VYE('-ZX6UO:W)A(&$@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!S>F]L9^%L=&%T\VX@X70N($$@
M<WIO;&?A;'1A=.%S(&EGZ6YY8F5VZ71E;.EH97H@5F]D869O;F4@271A;'D@
M96UA:6P@8^UM('-Z_&MSZ6=E<RX`17H@82!M97KU(&YE;2!M87)A9&AA="#\
M<F5S+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@X6QL:&%T
M;F%K+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@Z7,@:V5T
M=/5S<&]N="!L96AE="X`16)B96X@82!M97KU8F5N(&-S86L@;VMTX6QI<R!S
M>N%M;VL@X6QL:&%T;F%K+@!%>B!A(&UE>O4@8W-A:R!V97-S>O5V96P@=F%G
M>2!S>O-K]GIZ96P@96QVX6QA<WIT;W1T(&5GZ7-Z('-ZX6UO:V%T('1A<G1A
M;&UA>FAA=`!%>B!A>B#I<G3I:R!C<V%K('-ZX6T@;&5H970N`$5B8F5N(&$@
M;65Z]6)E;B!H97AA9&5C:6WA;&ES(%)'0B!S>NUN:_-D(.%L;&AA="P@<&PN
M("<C,3(S-&%F)RX`27-M97)E=&QE;B!FX6IL9F]R;>%T=6TN`$5Z96X@861A
M=&]K:V%L(&MA<&-S;VQA=&]S(&9E;&%D871O:V%T(&$@<WIE<G9E<B!MX7(@
M96QVZ6=E>G1E+@!%>B`E<P!%>B!E9WD@2V]L86(@1W)O=7!W87)E(&]B:F5K
M='5M+B!!>B!I;'EE;B!O8FIE:W1U;2!M96=J96QE;NUTZ7/I:&5Z(&]L>6%N
M(&5M86EL(&ML:65N<W!R;V=R86T@<WK\:W/I9V5S+"!A;65L>2!KZ7!E<R!A
M($MO;&%B($=R;W5P=V%R92!F;W)MX71U;2!K97IE;.ESZ7)E+B!);'EE;B!E
M;6%I;"!K;&EE;G-E:R!L:7-TX6IA(&SA=&AA=/,@:71T.B`E<P!%>G0@82!L
M979E;&5T(&WA<R!K87)A:W1E<FOI<WIL971T96P@*"5S*2#M<G3A:RP@;6EN
M="!A;6ET(-9N(&AA<WINX6PN`$5Z(&$@<WKA;2!N96T@;&5H970@96=Y;NEL
M(&MI<V5B8BX`17H@82!S>F5R=F5R(&YE;2!KZ7!E<R!K:6)O;G1A;FD@82!Z
M:7`@:6QL+B!G>FEP(.%L;&]MX6YY;VMA="X`17H@82!R96YD<WIE<B!J96QE
M;FQE9R!I;F%K=&EVX6QV82!V86XN`$5Z(&%Z(.ER=.EK(&-S86L@<WKA;2!L
M96AE="X`17IT(&%Z(&%B;&%K(&-S86L@87H@3W!C:?-K(&%B;&%K8O-L(&CM
M=FAA=/,`5FEL;.%M;.%S`$AI8F%B96IE;&5N=.ES+6ME>F5LZ7,`263U`$UU
M;FMA:63U+6YY:6QVX6YT87)TX7,`263U(&9O<FWA='5M`$ED]2!VX6QA<WIT
MX7,`2V5L970M5&EM;W(`5&ET=6QU<P!#[6T@*'1O;VQT:7`I`$/M;7IE='0`
M2&$@=/9B8B!E;&5M970@:7,@:VD@86MA<B!J96SV;&YI+"!T87)T<V$@;&5N
M>6]M=F$@82!#;VYT<F]L("A00RD@=F%G>2!A($-O;6UA;F0@*$UA8RD@8FEL
M;&5N='G[="!A(&MA='1I;G3A<R!K]GIB96XN`$UA`$A434P@9F]R<N%S;NEZ
M970@:VDO8F4`5&]G;P!4;VME;&%U`$AO;&YA<`!4;VYG80!F]FS\;`!,96=F
M96QS]2!F<F%M92`H7W1O<"D`1F]R9.UTX7-O:P!4<FEN:61A9"#I<R!4;V)A
M9V\`26=A>B!V86=Y(&AA;6ES`$ME`%1U;NEZ:6$`5/9R]FMO<G-ZX6<`=/9R
M]FL@*$E33RTX.#4Y+3DI`%3\<FMM96YI<WITX6X`5'5R:W,M(.ES($-A:6-O
M<RUS>FEG971E:P!4=79A;'4`S7)J82!B92P@;6ET(';A;&%S>G1O='0Z(`!5
M5B!I;F1E>#H@`%523`!54DPL(&UE;'EE;B!E9WD@<')O9W)A;2!E;&9O9V%D
M:F$@82!S>F]L9^%L=&%T\R#A;'1A;"!K_&QD]G1T(&O\;&3V='0@:^EZ8F5S
M[73I<VD@:F5L96YTZ7-T`%523#H`56=A;F1A`%5K<F%J;F$`3F5M('-I:V5R
M_&QT(&$@5D93(&%L:_9N>73A<F)A(&)E;.EP;FDN`$$@8F5J96QE;G1K97KI
M<VD@:F]G;W-U;'1SX6<@:6?I;GELZ7-E:V]R(&YE;2!S:6ME<OQL="!A>B!A
M9&%T;VL@96QTX7)O;.%S82X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(B!61E,@
M9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET(&UE9W;A;'1O>G1A=&YI+@!.
M96T@<VEK97+\;'0@82AZ*2`E<R\E<R!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S
M=6QT<^%G86ET(&UE9W;A;'1O>G1A=&YI+@!.96T@<VEK97+\;'0@82AZ*2`E
M<R!A;&OV;GEV=.%R8F$@8F5LZ7!N:2X`02AZ*2`B)7,B(.%L;&]MX6YY(&WI
M<F5T92!N96T@X6QL87#M=&AA=/,@;65G+@!!*'HI("(E<R\E<R(@X6QL;VWA
M;GD@;>ER971E(&YE;2#A;&QA<.UT:&%T\R!M96<N`$%Z(%-13"!S>F5R=F5R
M(&YE;2#I<FAE=/4@96PN`$%Z(%-33"!K87!C<V]L870@;F5M(.EP[71H973U
M(&9E;"X`02!61E,@9N%J;"!N96T@;>%S;VQH873S(.%T+@!.96T@<VEK97+\
M;'0@82AZ*2`B)7,B(%9&4R!A;&OV;GEV=.%R="!LZ71R96AO>FYI+@!.96T@
M<VEK97+\;'0@;.ET<F5H;WIN:2!A(%9&4R!A;&OV;GEV=.%R="X`3F5M('-I
M:V5R_&QT(&SI=')E:&]Z;FD@82!61E,@9N%J;'0N`$$H>BD@(B5S(B!61E,@
M;6%P<&$@;F5M(&AO>FAA=/,@;.ET<F4N`$YE;2!S:6ME<OQL="!LZ71R96AO
M>FYI(/QR97,@5D93(&;A:FQT+@!!('3V;?9R[71E='0@X6QL;VWA;GET(&YE
M;2!S:6ME<OQL="!K:6)O;G1A;FDN`"(E<R(@;F5M('3V<O9L:&5T]2P@87H@
M86QK]FYY=G3A<B!N96T@_')E<RX`3F5M('-I:V5R_&QT("(E<R(M="!T]G+V
M;&YI.B`E<P`B)7,B('3V<FSI<V4@;F5M('-I:V5R_&QT.B`E<RX`)7,@;F5M
M('3V<O9L:&5T]2P@87H@86QK]FYY=G3A<B!N96T@_')E<RX`02!61E,@86QK
M]FYY=G3A<B!N96T@=/9R]FQH973U(')E:W5R>NUV86XN`$$@5D93(&%L:_9N
M>79TX7(@;F5M('3V<O9L:&5T]2X`02!61E,@86QK]FYY=G3A<B!N96T@=/9R
M]FQH973U.B`E<RX`02AZ*2`B)7,B(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N
M`$$@5D93(&;A:FP@;F5M('3V<O9L:&5T]2X`02AZ*2`B)7,B(%9&4R!M87!P
M82!N96T@=/9R]FQH973U+@!.96T@=NEG97IH973S(')E:W5R>NUV('3V<FSI
M<R!A(%9&4RUB96XZ("5S+@!.96T@:&%TX7)O>FAA=/,@;65G(&$@:F5L96YL
M96<@Z7)VZ6YY97,@86QK]FYY=.%R+@!!('1A;OIS[71VX6YY('+I<WIL971E
M<R!A9&%T86D@;F5M(&AA=.%R;WIH873S:R!M96<`3F5M('-I:V5R_&QT(&)E
M;VQV87-N:2`E<R!D969I;NUC:?-JX70N`$$@5D93(&;A:FP@;F5M(&AE;'EE
M>FAE=/,@X70N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G
M+@!!(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M96<@[7+A<VD@8^EL;&%L+@!!
M(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M96<@+@!!('3V;?9R[71E='0@X6QL
M;VWA;GD@;F5M(&YY:71H873S(&UE9RX`02!61E,@9N%J;"!N96T@;VQV87-H
M873S("AA(&9I;&5S:7IE*"D@<VEK97)T96QE;B!V;VQT*2X`02!61E,@9N%J
M;"!N96T@;VQV87-H873S("AA(&=E=$9I;&53:7IE*"D@<VEK97)T96QE;B!V
M;VQT*2X`17H@82!FX6IL(&YE;2!O;'9A<VAA=/,Z(`!!('9F<W)O;W0@86QK
M]FYY=G3A<B!N96T@;VQV87-H873S+@`E<R!N96T@;F5V97IH973U(.%T("5S
M(&[I=G)E.B!MX7(@;.ET97II:R!I;'EE;B!N97;[(&UA<'!A`$$@5D93(&%L
M:_9N>79TX7(@;F5M(&YE=F5Z:&5T]2#A="X`02!61E,@86QK]FYY=G3A<B!N
M96T@;F5V97IH973U(.%T.B`E<RX`02AZ*2`B)7,B(%9&4R!FX6IL(&YE;2!N
M979E>FAE=/4@X70N`$$H>BD@)7,O)7,@5D93(&;A:FP@;F5M(&YE=F5Z:&5T
M]2#A="X`02!61E,@9N%J;"!N96T@;F5V97IH973U(.%T+@!!>B`G;6MI<V]F
M<R<@<')O9W)A;2!N96T@9G5T=&%T:&%T\RX`3F5M('-I:V5R_&QT(&QE9F]R
M9.UT86YI(&5Z="!A(%=O<F0@9&]K=6UE;G1U;6]T`$$H>BD@(B5S(B!61E,@
M9N%J;"!N96T@[7)H873S+@!!(%9&4R!FX6IL(&YE;2#M<FAA=/,@*&$@8V]P
M>2@I('-I:V5R=&5L96X@=F]L="DN`$$@5D93(&;A:FP@861A=&%I(&YE;2#M
M<FAA=/-K(&MI+@!!(%9&4R!FX6IL(.URX7-A(&MV\W1A=/IL;.EPZ7,@;6EA
M='0@;F5M(&9E:F5Z:&5T]2!B92X`86SA:/IZ;W1T`$WI9W-E(&UE;G1S_&L@
M96P`3>EG<V4@;65N='/\:R!E;`!6:7-S>F%V;VYJ82!A>B!U=&]L<_,@=N%L
M=&]Z=&%TX7-T`$$@:V%P8W-O;&%T(&9E;';I=&5LZ70@:_9V973U96X@=N%R
M871L86X@=N%L87-Z(.ER:V5Z971T(&$@<WIE<G9E<G3U;#H@`%;A<F%T;&%N
M(';A;&%S>B#I<FME>F5T="!A('-Z97)V97)T]6P@97)R93H@`$)E<V]R;VQA
M=&QA;@!5;FEC;V1E("A55$8M."D`16=Y97/\;'0@07)A8B!%;>UR<^EG96L`
M16=Y97/\;'0@2VERX6QY<^%G`$5G>65S_&QT(,%L;&%M;VL`16=Y97/\;'0@
MP6QL86UO:RP@:VES96)B(&O\;'/U('-Z:6=E=&5K`&5G>7/I9P!)<VUE<F5T
M;&5N`$ES;65R971L96X@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`27-M
M97)E=&QE;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!!(&UE9V%D
M;W1T(&AE;'D@:7-M97)E=&QE;BX`27-M97)E=&QE;B!F96QH87-Z;N%L\VD@
M;NEV('9A9WD@:F5L<WKS+@!4X79O;.UT<W5K(&5L(&EN;F5N(&$@;&EN:V5T
M`$YI;F-S(&5L;F5V97IV90!":7IT;VYSX6=I(&]K;VMB\VP@82!F96QH87-Z
M;N%L\VD@<')O9W)A;6]K(&YE;2!H87-Z;N%L:&%T:N%K(&$@2VEVX6?A<R]-
MX7-O;.%S+T)E:6QL97-Z=.ES(&WS9'-Z97)T+B!+871T:6YT<V]N(&%Z($]+
M(&=O;6)R82P@:&$@82!M;WII;&QA+F]R9R!W96)O;&1A;&]N(&5L(&OM=N%N
M:F$@;VQV87-N:2!A('1E8VAN:6MA:2!L9>URX7-T(&UE;'D@;65G861J82P@
M:&]G>6%N(&QE:&5T(&5Z="!MZ6=I<R!E;F=E9.EL>65Z;FDN`$$@<WKM;B!V
M:7-S>F'A;&SM=.%S80!.96T@=.%M;V=A=&]T="!T87)T86QO;73M<'5S.B`E
M<P!.96T@=.%M;V=A=&]T="!E>'1E;GII\P!-\V1O<^UTX7,`)7,@861A=&%I
M;F%K(&WS9&]S[73A<V$`02!F96QH87-Z;N%L\R!A9&%T86EN86L@;?-D;W/M
M=.%S80`B)7,B(';A;'1O>N%S86ET(&5L;65N=&5T=/QK+@!!>B!U<&=R861E
M('!R;V=R86UO="!T]G+V;'3\:RX`1F5L=/9L=.ES`$%Z(/9S<WIE<R!A;&MA
M;&UA>N%S(&MO;F9I9W5RX6-I\VKA="!F96QT]FQT]G1T_&L@82!S>F5R=F5R
M<F4N`&QA=&EN(&YA9WEB973[:P!N86=Y8F5T^W,@<O-M86D@<WKA;6]K`%5R
M=6=U87D`2&%S>F[A;&IU:R!A(&IE;&5N;&5G:70Z("5S`$AA<WINX6QJ=6YK
M(%-33"UT`$%K:V]R(&AA<WINX6QJ=6LL(&AA(&%Z($E-4U`@<WIE<G9E<F5N
M(&WA<R!A(&)E:F5L96YT:V5ZZ7-I(&YE=OQN:R]J96QS>F%V=6YK+@!&96QH
M87-Z;N%L\VD@;NEV`"5S(&9E;&AA<WINX6SS(&YE;2!J;V=O<W5L="`E<RUR
M92X`1F5L:&%S>F[A;/-K(&%D;6EN:7-Z='+A;.%S80!&96QH87-Z;N%L\VD@
M8F7A;&SM=.%S;VL`0F5J96QE;G1K97KI<R!J;V=O<W5L='/A9R!I9^EN>6SI
M<V4`17IE;B!A(')E;F1S>F5R96X@;FEN8W,@96YG963I;'EE>G9E(&%Z(/IJ
M(&9E;&AA<WINX6SS:R!B96IE;&5N=&ME>NES:2!J;V=O<W5L='/A9^%N86L@
M:6?I;GELZ7-E+@!!>B!F96QH87-Z;N%L\VD@87IO;F]S[73S(&YE;2!T86SA
M;&AA=/,`1F5L:&%S>F[A;/-I(&[I=@!!*'HI("(E<R(@9F5L:&%S>F[A;/-I
M(&[I=B!MX7(@;.ET97II:RX`1F5L:&%S>F[A;/-I(&[I=CH`1F5L:&%S>F[A
M;/-I(&[I=CH@`$$@<F5N9'-Z97(@9F5L:&%S>F[A;/-I.@#<>F)E9VES>G3A
M;@!!(%9&4R!A;&OV;GEV=.%R(&YE;2!LZ71E>FEK+@!3>F%B861SX6<@86QA
M='1I(&%U=&]M871I:W5S(&5M86EL+7;A;&%S>@!!(&OV=F5T:V5Z]2!H96QY
M96ME="!T86SA;'1U:SH@`,ER=NEN>65S<^EG`$%Z(.ER=.EK96ME="!P97)C
M8F5N(&%D:G5K(&UE9RP@;6]S=&%N=/-L('-ZX6WM='9A+@!!(.ER=.EK(&YA
M9WEO8F(L(&UI;G0@82!L96=N86=Y;V)B(&UE9V5N9V5D971T(&AO<W-Z^G/A
M9SH@)7,N`,ER=.EK96L`5N%L87-Z=&AA=/,@Z7)TZ6ME:P!686YU871U`';A
M;'1O>O,`5F5N97IU96QA`$$@:&ET96QE<^UTZ7,@;F5M('-I:V5R_&QT("T@
M;&5H970L(&AO9WD@82!L979E;&5T('9A;&%K:2!M96=VX6QT;WIT871T82X`
M5F5R>FGS`%9E<GII\VOV=F5TZ7,`1OQG9RX@96QH96QY97KI<P!&_&=G]6QE
M9V5S(&)E;'/U(&UA<F?S`&;\9V?U;&5G97,Z`&YA9WEO;B!M86=A<P!6:65T
M;F%M`'9I971N86UI("A625-#24DI`"5S(&UE9W1E:VEN=.ES90!+_&QS]2!W
M96)O;&1A;"!M96=J96QE;NUTZ7-E`$IE;&5N[71S_&L@;65G+"!M:6YT("5S
M`$)R:70@5FER9VEN+7-Z:6=E=&5K`$%M97)I:V%I(%9I<F=I;BUS>FEG971E
M:P!,X73S=.%V;VQSX6<`3.%T\W3A=F]L<^%G.B``5F]D869O;F4@271A;'D@
M<WIO;&?A;'1A=.%S(%--5%`M;B!K97)E<WIT_&P`1DE'645,345:5$54R5,`
M1DE'645,345:5$54R5,A($O)6EI%3"!4P59/3,U44T$@14P@02!30U))4%1%
M5"`E<RU2U4PN`%=)3B!S>F]L9^%L=&%TX7,@2%144"UN(.%T`%=A;&QI<R#I
M<R!&=71U;F$`1FEG>65L;65Z=&5TZ7,`4WIE`$ED]6KA<N%S(&5L]7)E:F5L
M>NES`$%Z(&ED]6KA<N%S:2!A9&%T;VL@9F]R<N%S80!796(`5V5B:&5L>65K
M`&AE=&5N=&4`W&1V]GKV;&K\:P#<9';V>O9L:OQK.B`E<P#<9';V>O9L:OQK
M+"`E<P!N>75G870M975R\W!A:2`H25-/+3@X-3DM,2D`;GEU9V%T+65U<O-P
M86D@*$E33RTX.#4Y+3$U*0!.>75G870M4WIA:&%R80!-:6QY96X@86QK86QM
M87KA<W0@;75T87-S;VX@)7,@82!B96IE;&5N=&ME>NES('5TX6X_`$UI(&%Z
M(&5L=N%L87-Z=/,@:V%R86MT97(_`$UI(&%Z(&EDZ7IE=&MA<F%K=&5R/P!7
M:&5R96ES($%U<WIT<N%L:6$@=.ER:^EP`$UE;'EI:R!J96=Y>F5T=/9M8F)E
M(&OM=N%N:F$@82!F96QJ96=Y>NES96ME="!T96YN:3\`365L>6EK(&-I:VQU
M<P!-96QY:6L@;6]D=6QO:V%T(&%K=&EVX6QJ=6L@82!2:6-H(%1E>'0@961I
M=&]R8F%N/P!3>NEL97-SZ6<`4WKI;&5S<^EG($-34R!E9WESZ6=B96X`02`E
M<R!M96[\('-ZZ6QE<W/I9V4@82!B86P@;VQD86QO;B`H82!K]G9E=&ME>O4@
M8F5J96QE;G1K97KI<W0@:_9V973U96X@;&5S>B#I<G;I;GEE<RD`02!TX6)L
MX7IA="!S>NEL97-SZ6=E`$$@<WKI;&5S<^EG(&WI<G3I:V5G>7/I9V4`4WKI
M;&5S<^EG.@!7:6MI`%-ZZ6P`4WKI;"!A(')E9V=E;&D@\W+A:V)A;@!3>NEL
M<V5B97-SZ6<@8W-O;?-B86X`4WKI;#H`4WKI;#H@`$+V;&-S97-SZ6<`2^UV
MX6YSX6=L:7-T80!-=6YK80!-=6YK86AE;'EI(&/M;0!-=6YK86AE;'EI('1E
M;&5F;VX`02`E9"X@<V]R8F%N(&YE;2!M96=F96QE;/4@82!M97KU:R!S>N%M
M82X@5N%R=#H@)60L('1A;.%L=#H@)60N`$YE;2!M96=F96QE;/4@82!M97KU
M:R!S>N%M82X@5N%R=#H@)60L('1A;.%L=#H@)60N`$AI8N%S(&]F9G-E="`H
M)60I(&$@5D93(&;A:FP@;VQV87/A<V%K;W(N`$QI;G5X(&9O<G+A<VOS9"!K
M97)E<WIR969E<F5N8VEA`%@U,#EV,R!A;&%P=F5T]2!K;W)LX71O>N%S;VL`
M6#4P.78S(&MI=&5R:F5S>G1E='0@:W5L8W-H87-Z;N%L870`6#4P.78S('1U
M;&%J9&]N;W,@86QT97)N873M=B!M96=N979E>NES90!8-3`Y=C,@='5L86ID
M;VYO<R!K=6QC<V%Z;VYO<^UT\P!8-3`Y=C,@:VET97)J97-Z=.ES96L`65D`
M65E960!986AO;R$@=.ER:^EP`.EV96YT90!*96UE;@!)9V5N`$EG96XL(&)E
M;&5G>65Z96TN`$UO<W0@2%1-3"!415A4(&WS9&)A;B!V86XN($AA<WINX6QJ
M82!A(%L\/ET@9V]M8F]T+"!H82!V:7-S>F$@86MA<B!VX6QT86YI(&$@<WIO
M:^%S;W,@9W)A9FEK=7,@*%=94TE764<I(&UE9VIE;&5N[73I<W)E+@!.96T@
M:&]Z:&%T(&SI=')E("5D(&)L;VMK;N%L('3V8F)E="X`3F5M(&AO>FAA="!L
MZ71R92!T]F)B+"!M:6YT("5D(&9E;&IE9WEZZ7-T+@!!>B#6;B!F96QH87-Z
M;N%L\V%Z;VYO<^UTX7-A(&YE;2!T]G)TZ6YT(&UE9RX`02!T96QJ97,@;NEV
M8F5N(&YE;2!S>F5R97!E;&AE="!A("=<)R!K87)A:W1E<BX`3F5M(&%D;W1T
M(&UE9R#I<G;I;GEE<R!E;6%I;"!C[6UE="X`3F5M(&%D=&$@;65G(&$@;65G
M9F5L96QT973I<W0@87H@:6UP;W)TX6QT(&;A:FP@Z7,@82AZ*2`E<R!M97KU
M:2!K]GKV='0N`-9N(&YE;2!J;V=O<W5L="!A*'HI("5S(&IE9WEZ971T]FUB
M(&AA<WINX6QA=.%R82X`4VEK97)E<V5N(&MI:F5L96YT:V5Z971T+@!%9WD@
M;6]B:6QT96QE9F]N<WKA;6]T(&ME;&P@;65G861N:6$L(&-S86L@82!S>N%M
M:F5G>65K970L(&5S971L96<@96=Y("<K)R!K87)A:W1E<G)E;"!K97ID=F4L
M(&AA(&YE;7IE=&OV>FD@=.%R8W/A>N%S:2!M\V1O="!K[7;A;B!H87-Z;N%L
M;FDN`$5L9F]G861H873S(.ER=.EK970@:V5L;"!M96=A9&YI82X`02!$871A
M5')E92!A;')E;F1S>F5R="!B92!K96QL(.%L;.UT86YI(&$@8F5J96QE;G1K
M97KI<VD@:F]G;W-U;'1SX6=O:R!I9^EN>6SI<^EH97HN`$$@5D93(&%L<F5N
M9'-Z97(@;FEN8W,@8F7A;&SM='9A+@!%;/5B8B!L92!K96QL(.UR;FEA+"!H
M;V=Y(&UI;'EE;B!P<F]B;.EMX70@=&%P87-Z=&%L="P@;6EE;/5T="!E;&O\
M;&1I(&$@:&EB86IE;&5N=.ES="X`365G(&ME;&P@861N:2!E9WD@55),+70L
M(&%H;W9A(&5Z(&$@;&EN:R!M=71A=`!%;/5S>O9R(&MI(&ME;&P@=N%L87-Z
M=&%N:6$@82!T]G)L96YD]2!J96=Y>F5T=/9M8O9T+@!+:2!K96QL(';A;&%S
M>G1A;FD@96=Y('3V<FQE;F3U('-Z97)V97)T+@!-96<@:V5L;"!A9&YI82P@
M:&]G>2!M96QY:6L@9F5L:&%S>F[A;/,@861A=&%I="!K[7;A;FIA('3V<O9L
M;FDN`$UE9R!K96QL(&%D;FEA(&%Z(&5L=.%V;VSM=&%N9/,@9F5L:&%S>F[A
M;/-I(&YE=F5T+@!-96<@:V5L;"!A9&YI82!A(&AO>GKA861A;F3S(&9E;&AA
M<WINX6SS(&YE=NET+@!-96<@:V5L;"!A9&YI82P@:&]G>2!M96QY:6L@9F5L
M:&%S>F[A;/,@861A=&%I="!K[7;A;FIA(.%T[7)N:2X`365G(&ME;&P@861N
M:6$@96=Y('!A<F%N8W-O="X`365G(&ME;&P@861N:6$@87H@^FH@:V%T96?S
M<FEA(&YE=NET+@!/;&%S>F]R<WKA9VD@=&5L969O;G-ZX6UO="!K96QL(&UE
M9V%D;FEA`$%Z(-9N("5S(&MA<&-S;VQA=&$@:63U=/IL;.EPZ7,@;6EA='0@
M;65G<WIA:V%D="X@2^ER96T@:F5L96YT:V5Z>F5N(&)E(/IJ<F$N`$%Z(-9N
M(&5M86EL(&/M;64`07H@UFX@9F5L863S:2`H1G)O;3HI(&/M;64Z`%-Z96WI
M;'EE<R!I;F9O<FWA8VGS`$%Z(-9N("5S(&MA<&-S;VQA=.%N86L@:V5Z9&5T
M92#S=&$@;65G=N%L=&]Z;W1T(&%Z(&EN=&5R;F5T(&/M;64N($)I>G1O;G/A
M9^%N86L@Z7)D96OI8F5N(&ES;>ET(&)E(&ME;&P@:F5L96YT:V5Z;FEE+@!!
M>B#6;B!N979E`$%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z
M97)E(&YE;2!T97-Z:2!L96AE=/5VZ2!A>B#Z:B!F96QH87-Z;N%L\VL@;.ET
M<F5H;WKA<^%T+B!(82!A($AO<F1E(')E;F1S>F5R<F5L(&OM=N%N:F$@:V5Z
M96QN:2!A(&9E;&AA<WINX6SS:2!A9&%T;VMA="P@86MK;W(@;>%S:6L@9F5L
M:&%S>F[A;/-A>F]N;W/M=/,@86QR96YD<WIE<G)E('9A;B!S>OQK<^EG92X`
M07H@UFX@9F5L:&%S>F[A;/-A>F]N;W/M=/,@86QR96YD<WIE<F4@;F5M('1E
M<WII(&QE:&5T]7;I(&$@9F5L:&%S>F[A;/-K(&QI<W3A>N%SX70L('9A9WD@
M=F%L86UI(&]K8O-L(&QE=&EL=&]T=.%K(&5Z="!A(&QE:&5T]7/I9V5T+@!!
M>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82!M96=VX6QT;WIO='0@87H@UFX@)7,@
M;75N:V%K87!C<V]L873A;F%K(&ME>F1E=&4@\W1A+B!":7IT;VYSX6=A(.ER
M9&5KZ6)E;B!I<VWI="!B92!K96QL(&IE;&5N=&ME>FYI92X`07H@UFX@8O9N
M9^ES>O5P<F]G<F%M:F$@;F5M('3A;6]G871J82!E>G0@82!L96AE=/5SZ6=E
M="X`07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;F5M('3A;6]G871J82!E>G0@
M82!N>6]M=&%TX7-I(&]P8VGS="X@4'+S8N%L:F]N(&$@0W1R;"U0("AV86=Y
M($-O;6UA;F0M4"D@;&5N>6]MX7/A=F%L(&YY;VUT871N:2X`02!J96QE;FQE
M9R#I<G;I;GEE<R!I9/5Z\VYA.@!!>B#6;B!A;&%PZ7)T96QM97KI<R!S>F5R
M:6YT:2!A>F]N;W/M=/-J82!M96=VX6QT;WIO='0N`$%Z(-9N(&%L87#I<G1E
M;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\VIA.@!!>B#6;B!A;&%PZ7)T96QM
M97KI<R!S>F5R:6YT:2!J96=Y>F5T=/9M8FIE.@!!>B#6;B!T96QJ97,@;F5V
M93H`3&5JX7)T(&$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6=A+@!!>B#6
M;B`E<RUR92!H87-Z;N%L="#Z:B!J96QS>F%V83H@)7,`07H@UFX@:F5G>7IE
M='3V;6)J96DZ`$%Z(-9N(/IJ(&)EX6QL[73A<V%I="#I<G;I;GEE<^UT971T
M_&L@82!M;W-T86YI(&)E:F5L96YT:V5ZZ7,@:61E:NER92X`07H@UFX@^FH@
M8F7A;&SM=.%S86ET(&5L;65N=&5T=/QK+@!!>B#6;B!J96QS>F%VX70@X73A
M;&SM=&]T='5K`$%Z(-9N(&IE;'-Z87;A="#A=.%L;.UT;W1T=6LL(&[I>GIE
M(&UE9R!A(&QE=F5L96ET+"!M86ID(&IE;&5N=&ME>GIE;B!B92!A>B#Z:B!J
M96QS>O-V86PN`$%Z(-9N(&IE;'-Z87;A;F%K(&QE:N%R="!A>B#I<G;I;GEE
M<W/I9VD@:61E:F4N`$%Z(-9N(.%L=&%L(&AA<WINX6QT('3A=F]L:2!S>F5R
M=F5R96LZ`$IU9V]S>FSA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;3F4@
M;75T87-S=6L@82!B96EDZ7IE='0@<WKV=F5G971=`%M(:6)A:F5L96YTZ7-=
M`%M-=71A<W-U:R!A(&)E:63I>F5T="!S>O9V96=E="`M`%M-=71A<W-U:R!A
M(&)E:63I>F5T="!S>O9V96=E="`M("5S('-O<ET`6R5S+R5S('-O<ET`7T%D
M;6EN:7-Z='+A8VGS`%9I<W-Z82!A($9E;&IE9WEZZ7-E:VAE>@!?4&%R86YC
M<W-O<@!+871E9_-R:6$`5/9R;.ES`%-O<G3V<FSI<P!-\V1O<^UTX7,`16QS
M]2!S;W(`7T-S;W!O<G1O:P!395]G[71SZ6<`02!KZ7`@='5L86ID;VYSX6=A
M:2XN+@!);7!O<G0O7T5X<&]R=`!?3&ES=&$`0F5J96QE;G1K97KI<P!?2VEJ
M96QE;G1K97KI<P!!(&QI;FL@;?-D;W/M=.%S82XN+@!*96=Y>F5T=/9M8FIE
M:5]M`-I?:B!F96QJ96=Y>NES`%]/<&-I\VL`7TIO9V]S=6QT<^%G;VL`7TYY
M;VUT873A<P!!(&QI;FL@=/9R;.ES92XN+@!+97)E7W/I<P!?0F7A;&SM=.%S
M;VL`5.%B;.%Z870@='5L86ID;VYSX6=O:P!?1F5L:&%S>F[A;/-K`&/M;6IE
M9WEZZ6L`82!C[6UZ971T(&ES;65R971L96X`;F%P=.%R`&YY=6=O9'0`82!K
M:6UE;F5T:2#A;&QO;>%N>2!N96T@:&]Z:&%T\R!LZ71R90!A(&)E;65N]2#A
M;&QO;>%N>2!N96T@;GEI=&AA=/,@;65G`&MA='1I;G1S;VX@:61E`'!A<F%N
M8W-S;W)I(&AI8F$`:V]N9FEG=7+A8VGS<R!H:6)A`&AIX6YY>FEK(&5G>2!F
M;VYT;W,@<F5N9'-Z97+A;&QO;>%N>0!A9&%T9F]R;>%T=6T@:&EB80!M\V1O
M<^UTX7,`87H@861A="!N96T@=&%LX6QH873S`&-S]FMK96X`9N%J;``E<R`H
M)7,I(&ERX6YY8O-L+"`E<R`E<R!S96)E<W/I9V=E;`!S>NEL;/9KZ7-E:P!M
M.@!A(&?I<"!N979E(&YE;2!I<VUE<G0`87IO;FYA;&D`:6YP=70O;W5T<'5T
M(&AI8F$`8F5L<_4@<')O9W)A;6AI8F$`<V]R70!!>B!M:W-I;V9S('!R;V=R
M86T@)60@:&EB86OS9&1A;"!L9>%L;'0@87H@25-/(.%L;&]MX6YY(&OI<WKM
M=.ES92!K]GIB96XN`&[I=@!!('!R;V=R86UN86L@97H@82!RZ7-Z92!MZ6<@
M;FEN8W,@;65G=F%L\W/M='9A+@!!('!R;V=R86UN86L@97H@82!RZ7-Z92!M
MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!J96=Y>F5T=/9M8@!S>N%Z86SI:P!N
M:6YC<R!M96=F96QE;/4@:F]G;W-U;'1SX6=A`'!I>&5L`&%D873A='9I=&5L
M:2`H<')O=&]K;VQL*2!H:6)A`&5M96QK961I:P!A('-Z;VQGX6QT873A<R!N
M96T@X6QL(')E;F1E;&ME>NES<F4`;NEZ>OQK(&UE9R!A(&O\;/9N8G/I9V5K
M970`<VUS,F5M86EL('-Z;VQGX6QT873A<R!(5%10+6X@X70`=N%L=&]Z871L
M86X`<F5N9'-Z97)H:6)A`&9E;&%D871L:7-T80#A=&UE;F5T:2!H:6)A`&UE
M9V5R]7/M=.ES:^EN="!KZ71S>F5R(.UR:F$@8F4@82!J96QS>O-T`&[I=B!N
MZ6QK_&P`82!F96QH87-Z;N%L\R#A;'1A;"!VX6QA<WIT:&%T\P!V0V%R9`!S
M>CH`+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O:'5?
M2%4O:&5L<"YX;6P`````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U
M-3`Q`#$P-#$W,S8R-S0T`#`R,30U-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D
M:6YG/2)I<V\M.#@U.2TR(C\^"CPA+2T@36YE;6\@,BXQ(&AE;'`Z(&AU7TA5
M("1(;W)D93H@;6YE;6\O;&]C86QE+VAU7TA5+VAE;'`N>&UL+'8@,2XR+C$R
M+C$@,C`P-B\P,R\P,R`Q,SHT-#HQ,"!J86X@17AP("0@+2T^"CQH96QP/@H@
M(#QE;G1R>2!I9#TB3W9E<G9I97<B('-T871E/2)U<'1O9&%T92(@;60U/2(U
M,&5E-S8Q,SAF8C`X8C`T8C`R.3`P-C`U,V)B861B8R(^"B`@("`\=&ET;&4^
MP71T96MI;G3I<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY"979E>F5TZ7,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($$@/&D^3F]T97,@*$9E;&IE9WEZZ7-E
M:RD\+VD^('!R;V=R86T@;&5H973U=ND@=&5S>FDL(&AO9WD@<WKA;>UT\V?I
M</QN:_9N"B`@("!A(&MI<F%G87-Z=&AA=/,@<&%P[7)L87!O:W)A(.UR=&%K
M:&]Z(&AA<V]N;/,@;?-D;VX@:^ES>NUT<_QN:R`*("`@(&9E;&IE9WEZZ7-E
M:V5T+B!!(&IE9WEZ971E:R!TX7)O;&AA=/-K+"!M\V1O<^UT:&%T\VLL('3V
M<O9L:&5T]6L@Z7,@"B`@("!K:6YY;VUT871H873S:RX@2V5R97-N:2!I<R!L
M96AE="!A(&9E;&IE9WEZZ7-E:R!T87)T86QMX6)A;BX@02!J96=Y>F5T96L@
M"B`@("!I;7!O<G3A;&AA=/-K(.ES(&5X<&]R=.%L:&%T\VL@:7,N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@($$@=F%L\V1I(&MI<F%G87-Z=&AA=/,@
M<&%P[7)L87!O:W3S;"!E;'3I<O5E;B!A>F]N8F%N+"!A('-ZX6WM=/-GZ7!E
M;@H@("`@=.%R;VQT(&9E;&IE9WEZZ7-E:70@;65G;W-Z=&AA=&IA(&WA<V]K
M:V%L+"!O;'EA;F]K:V%L(&ES+"!A:VEK(&5GZ7-Z96X*("`@(&WA<VAO;"!T
M87)T\WIK;V1N86LN($$@9F5L:F5G>7KI<V5K(&O\;/9N8O9Z]2!J96=Y>F5T
M=/9M8O9K8F4@:&5L>65Z:&5T]6LL"B`@("#I<R!K871E9_-R:>%K8F$@:7,@
M<F5N9&5Z:&5T]6LN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*"B`@/&5N=')Y
M(&ED/2)L:7-T+6%C=&EO;G,B('-T871E/2)U<'1O9&%T92(@;60U/2(V9#4Y
M,F8Q-3-B9F(U8S(Y-F1E-61F96)B-#(X93%B82(^"B`@("`\=&ET;&4^1G5N
M:V-I\VQI<W1A/"]T:71L93X*("`@(#QH96%D:6YG/D9U;FMC:?-K/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("`\:3Y!(&9E;&IE9WEZZ7,@=/9R;.ES93PO
M:3XN(%;I9VQE9R!T]G)L:2!A(&MI=N%L87-Z=&]T="!F96QJ96=Y>NES="X*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@/&D^02!F96QJ96=Y>NES(&WS
M9&]S[73A<V$\+VD^+B!,96AE=/5VZ2!T97-Z:2!E9WD@:V]RX6)B86X@[7)T
M(`H@("`@("`@9F5L:F5G>7KI<R!M\V1O<^UTX7/A="X*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@/&D^5FES<WIA(&$@9F5L:F5G>7KI<V5K(&QI<W3A
M:N%H;WH\+VD^+B!!(&9E;&IE9WEZZ7,@;65G=&5K:6YTZ7/I=/5L(`H@("`@
M("`@=FES<WIA=FES>B!A>B#A='1E:VEN=/4@;VQD86QR82X*("`@(#PO<&%R
M83X*("`\+V5N=')Y/@H*("`\96YT<GD@:60](FUE;G4M86-T:6]N<R(@<W1A
M=&4](G5P=&]D871E(B!M9#4](C<Q-6$X-3-D.3-C9#,S,S!E-&0W,S!B.3$Q
M,F,X83@R(CX*("`@(#QT:71L93Y!(&UE;OQP;VYT;VL\+W1I=&QE/@H@("`@
M/&AE861I;F<^02!M96[\<&]N=&]K/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("`\:3Y,:7-T83PO:3XN($9E;'-O<F]L:F$@87H@86MT=>%L:7,@:F5G>7IE
M='3V;6)B96X@;&5V]2!F96QJ96=Y>NES96EN:V5T+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("`\:3[::B!F96QJ96=Y>NES/"]I/BX@17IZ96P@:^ES
M>NUT:&5T_&YK(/IJ(&9E;&IE9WEZZ7-T(&%Z(&%K='7A;&ES(`H@("`@("`@
M:F5G>7IE='3V;6)B96XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#QI
M/DME<F5SZ7,\+VD^+B!,96AE=/5VZ2!T97-Z:2!A(&9E;&IE9WEZZ7-E:R!K
M]GKV='1I(&ME<F5SZ7-T+B!+97)E<VAE=/QN:PH@("`@("`@82!L9>UR\R!M
M97KU:R!T87)T86QMX6)A;BP@=F%G>2!A('1E;&IE<R!S>O9V96=B96X@:7,N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#QI/DEM<&]R="]%>'!O<G0\
M+VD^+B!,96AE=/5VZ2!T97-Z:2!A(&9E;&IE9WEZZ7-E:R!I;7!O<G3A;.%S
MX70@:6QL+@H@("`@("`@97AP;W)TX6SA<^%T+B!*96QE;FQE9R!A($-35B`H
M=F5S<WKU=F5L(&5L=N%L87-Z=&]T="#I<G3I:V5K*2!I;&PN(`H@("`@("`@
M=DYO=&4@9F]R;>%T=6WZ(.%L;&]MX6YY;VL@=F%N;F%K('3A;6]G871V82X*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@/&D^3GEO;71A=.%S/"]I/BX@
M3&5H973U=ND@=&5S>FD@82!F96QJ96=Y>NES(&MI;GEO;71A=.%SX70N($$@
M"B`@("`@("`\:3Y.>6]M=&%TX7,\+VD^(&EK;VX@8W-A:R!E9WD@861O='0@
M9F5L:F5G>7KI<R!M96=T96MI;G3I<V5K;W(@"B`@("`@("!J96QE;FEK(&UE
M9R!A(&UE;OQS;W)B86XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*"B`@/&5N
M=')Y(&ED/2)S;W)T:6YG(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB8V-A,V(Q
M9#%C.65D,&5C-6%B,S@U9C@R-#8Y9&1C.&8B/@H@("`@/'1I=&QE/E-O<F)A
M<F5N9&5ZZ7,\+W1I=&QE/@H@("`@/&AE861I;F<^4V]R8F%R96YD97KI<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1F5L:F5G>7KI<V5K(&MI;&ES=.%Z
MX7-A:V]R(&+A<FUE;'D@;W-Z;&]P('-Z97)I;G0@<V]R8F$@<F5N9&5Z:&5T
M:OQK"B`@("!A>B!A9&%T;VMA="P@:&$@82!KZ7)DZ7-E<R!O<WIL;W`@9F5J
M;.ECZ7)E(&MA='1I;G1U;FLN($AA(&$@<V]R8F%R96YD97KI<PH@("`@:7+A
M;GGA="!A:V%R:G5K(.%TX6QL[71A;FDL(&%K:V]R(&$@9F5J;.EC8F5N(&QE
M=O4@:VES(&YY[6QR82!K96QL"B`@("!K871T:6YT86YI+@H@("`@/"]P87)A
M/@H@(#PO96YT<GD^"CPO:&5L<#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]J85]*4"\`````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`
M,#$W-S8Q`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+VIA
M7TI0+TQ#7TU%4U-!1T53+P``````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<T-``P,C$U-#8`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]M;F5M;R]L;V-A;&4O:F%?2E`O3$-?34534T%'15,O;6YE;6\N;6\`````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,3<T-3,Q`#$P-#$W,S8R-S0T`#`R,S(R-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`(D#```<````9!P``+T$``"L.````````*!+```.````H4L```\```"P2P``
M"````,!+```,````R4L```@```#62P``"P```-]+```.````ZTL```4```#Z
M2P``*`````!,```*````*4P``!4````T3```$@```$I,```=````74P```X`
M``![3```"@```(I,```-````E4P``!$```"C3```#0```+5,```,````PTP`
M``T```#03```#````-Y,```&````ZTP```X```#R3```#@````%-```(````
M$$T``"X````930``&@```$A-```R````8TT``#@```"630``5````,]-``!1
M````)$X``%H```!V3@``5P```-%.```T````*4\```4```!>3P``$0```&1/
M```E````=D\``"````"<3P``'````+U/```>````VD\``"````#Y3P``'0``
M`!I0```0````.%````\```!)4````P```%E0```/````75```!0```!M4```
M"0```()0```-````C%```!(```":4```#P```*U0```,````O5````H```#*
M4```#P```-50```(````Y5```"0```#N4```%````!-1```6````*%$```@`
M```_40``$0```$A1```9````6E$```<```!T40``#````'Q1```.````B5$`
M``,```"840``!0```)Q1```7````HE$```H```"Z40``#P```,51```C````
MU5$```X```#Y40``%`````A2```7````'5(``!<````U4@``%P```$U2```3
M````95(``!\```!Y4@``#P```)E2```+````J5(``!4```"U4@``!P```,M2
M```%````TU(``!$```#94@``#````.M2```[````^%(```D````T4P``.0``
M`#Y3```G````>%,``"P```"@4P``*@```,U3```E````^%,```H````>5```
M!@```"E4```O````,%0``#<```!@5```+@```)A4``!5````QU0``"T````=
M50``+0```$M5```M````>54``$````"G50``(P```.A5```C````#%8``"T`
M```P5@``,P```%Y6```5````DE8``!D```"H5@``*0```,)6```D````[%8`
M`!4````15P``$0```"=7```/````.5<``!<```!)5P``"@```&%7```0````
M;%<``!8```!]5P``%@```)17```(````JU<```H```"T5P``!````+]7```)
M````Q%<```8```#.5P``$0```-57```'````YU<```T```#O5P```P```/U7
M```#`````5@``!<````%6```"````!U8```@````)E@```8```!'6```%0``
M`$Y8```8````9%@``"(```!]6```'0```*!8```A````OE@``%0```#@6```
M*0```#59```'````7UD``!4```!G60``"````'U9```*````AED```\```"1
M60``#0```*%9```/````KUD```T```"_60``"0```,U9```&````UUD``!,`
M``#>60``%````/)9```&````!UH``%0````.6@``+0```&-:```1````D5H`
M`!$```"C6@``'````+5:```W````TEH``!P````*6P``(0```"=;```*````
M25L``!(```!46P``"@```&=;```1````<EL```P```"$6P``!0```)%;```,
M````EUL``!````"D6P``!0```+5;```-````NUL```8```#)6P``!P```-!;
M```-````V%L```<```#F6P``"P```.Y;```'````^EL``!D````"7```#```
M`!Q<```0````*5P``!(````Z7```*P```$U<```[````>5P``"````"U7```
M-@```-9<```$````#5T```X````270``'@```"%=```;````0%T``"$```!<
M70``'@```'Y=```9````G5T``!X```"W70``&P```-9=```F````\ET``!L`
M```97@``'@```#5>```<````5%X``"8```!Q7@``,P```)A>```F````S%X`
M`"L```#S7@``.````!]?```O````6%\``!(```"(7P``*0```)M?```2````
MQ5\``",```#87P``*````/Q?```I````)6```!\```!/8```(````&]@```E
M````D&```"$```"V8```'````-A@```F````]6```$$````<80``!P```%YA
M```&````9F$``!````!M80``$@```'YA```'````D6$``!,```"980``$@``
M`*UA```,````P&$``"@```#-80```P```/9A```-````^F$```(````(8@``
M!0````MB```0````$6(```T````B8@``#@```#!B```(````/V(```\```!(
M8@``#P```%AB```-````:&(``!````!V8@``#P```(=B```9````EV(``!H`
M``"Q8@``!@```,QB```,````TV(``!$```#@8@``"P```/)B```-````_F(`
M`"(````,8P``"@```"]C```8````.F,``!D```!38P``%@```&UC```-````
MA&,```H```"28P``%````)UC```+````LF,```P```"^8P``+P```,MC```+
M````^V,``!<````'9```%P```!]D```6````-V0```\```!.9```#0```%YD
M```F````;&0``$,```"39```"````-=D```+````X&0``"\```#L9```!@``
M`!QE```$````(V4```H````H90``"@```#-E```)````/F4```\```!(90``
M$````%AE```7````:64``!$```"!90``%P```)-E```%````JV4```T```"Q
M90``&P```+]E```*````VV4```X```#F90``#0```/5E```X`````V8``"``
M```\9@``#@```%UF```%````;&8``!D```!R9@``$````(QF```/````G68`
M`!````"M9@``#P```+YF```+````SF8```\```#:9@``#````.IF```/````
M]V8```<````'9P``!@````]G```/````%F<```@````F9P``!@```"]G```,
M````-F<```@```!#9P``$P```$QG```*````8&<``!X```!K9P``(0```(IG
M```@````K&<``!D```#-9P``%P```.=G```E````_V<``!<````E:```"```
M`#UH```3````1F@``!0```!::```#````&]H```)````?&@```X```"&:```
M"P```)5H```;````H6@```<```"]:```"@```,5H```%````T&@```8```#6
M:````@```-UH```&````X&@``!````#G:```"0```/AH```9`````FD```X`
M```<:0``"@```"MI```4````-FD``!T```!+:0``!@```&EI```1````<&D`
M``D```"":0``'@```(QI```.````JVD```8```"Z:0``!@```,%I```$````
MR&D```0```#-:0``#````-)I```*````WVD```4```#J:0``#P```/!I```I
M`````&H``"0````J:@``)@```$]J```@````=FH``"````"7:@``)@```+AJ
M```I````WVH``!8````):P``"@```"!K```/````*VL``!`````[:P``0```
M`$QK``!P````C6L```X```#^:P``"0````UL```*````%VP```8````B;```
M%0```"EL```/````/VP``!,```!/;```$@```&-L```0````=FP``!P```"'
M;```(P```*1L```/````R&P``!````#8;```"P```.EL```4````]6P```P`
M```*;0``#````!=M```/````)&T``!4````T;0``*0```$IM```J````=&T`
M`"8```"?;0``)P```,9M```I````[FT``"H````8;@``&0```$-N```1````
M76X``!(```!O;@``$P```()N```4````EFX``!8```"K;@``%P```,)N```0
M````VFX``!$```#K;@``$P```/UN```2````$6\``#4````D;P``%````%IO
M```4````;V\``!<```"$;P``'````)QO```:````N6\``!<```#4;P``%0``
M`.QO```&`````G````8````)<```!P```!!P```$````&'````0````=<```
M!P```")P```.````*G````P````Y<```#````$9P```-````4W```"@```!A
M<```#````(IP```/````EW````H```"G<```"````+)P```K````NW````@`
M``#G<```#0```/!P```.````_G```!8````-<0``$0```"1Q```&````-G$`
M``X````]<0``$````$QQ```+````77$``!H```!I<0``#P```(1Q```(````
ME'$```8```"=<0``!P```*1Q```+````K'$``$<```"X<0``#0````!R```3
M````#G(``!,````B<@``$P```#9R```"````2G(``"4```!-<@``!````'-R
M``!H````>'(```4```#A<@``#P```.=R```#````]W(```<```#[<@``"0``
M``-S```*````#7,```L````8<P``!P```"1S``!1````+',```8```!^<P``
M"0```(5S``!7````CW,```(```#G<P``"P```.IS```-````]G,```P````$
M=```!P```!%T```)````&70```D````C=```"@```"UT```'````.'0```D`
M``!`=```!P```$IT```*````4G0```@```!==```$@```&9T```$````>70`
M``<```!^=```!0```(9T```,````C'0```@```"9=```%P```*)T```$````
MNG0``#@```"_=```"@```/AT```L`````W4``#,````P=0``,P```&1U```X
M````F'4```\```#1=0``&````.%U```4````^G4``!(````/=@``)````")V
M```(````1W8``"0```!0=@``$P```'5V```4````B78``"T```">=@``+0``
M`,QV```Q````^G8``"X````L=P``+P```%MW```L````BW<``&(```"X=P``
M$P```!MX```A````+W@``!H```!1>```"0```&QX``!%````=G@``$$```"\
M>```!0```/YX```$````!'D```D````)>0``"@```!-Y```-````'GD```P`
M```L>0``"@```#EY```)````1'D```H```!.>0``#P```%EY```(````:7D`
M``\```!R>0``"````()Y```:````BWD```4```"F>0``#0```*QY```(````
MNGD``#@```##>0```@```/QY```&````_WD```X````&>@``!P```!5Z```&
M````'7H``"D````D>@``'P```$YZ``!<````;GH``!0```#+>@``/@```.!Z
M```'````'WL```X````G>P``#````#9[```,````0WL``!,```!0>P``"@``
M`&1[```=````;WL``!$```"->P``#0```)][```1````K7L``"0```"_>P``
M%0```.1[```2````^GL```X````-?```&0```!Q\```(````-GP```D````_
M?```!P```$E\```(````47P``!(```!:?```+````&U\```:````FGP```D`
M``"U?```"@```+]\```5````RGP```4```#@?```%````.9\```0````^WP`
M``<````,?0``'@```!1]```H````,WT```H```!<?0``$0```&=]```+````
M>7T``!H```"%?0``%````*!]```%````M7T```8```"[?0``(````,)]```I
M````XWT``$$````-?@``*````$]^```I````>'X```4```"B?@``+@```*A^
M```T````UWX```<````,?P``(0```!1_```.````-G\```L```!%?P``!P``
M`%%_```3````67\```H```!M?P``%````'A_```R````C7\```4```#`?P``
M%P```,9_```%````WG\```0```#D?P``,@```.E_``!%````'(```!<```!B
M@```'@```'J````,````F8```!0```"F@```#@```+N````J````RH````8`
M``#U@```#````/R````/````"8$```L````9@0``"P```"6!```/````,8$`
M`#(```!!@0``!0```'2!```'````>H$``!$```""@0``%````)2!```8````
MJ8$```0```#"@0``#@```,>!```.````UH$```4```#E@0```P```.N!```>
M````[X$``!@````.@@``)0```">"```)````38(```,```!7@@```@```%N"
M```$````7H(```<```!C@@``#````&N"```7````>((```8```"0@@``#@``
M`)>"```,````IH(```P```"S@@``#0```,""```5````SH(``!(```#D@@``
M$````/>"```/````"(,``!0````8@P``:0```"V#```:````EX,``!<```"R
M@P``&0```,J#```:````Y(,``"4```#_@P``)P```"6$```:````380``!<`
M``!HA```&P```("$```9````G(0``!\```"VA```%````-:$```3````ZX0`
M``@```#_A```"0````B%```-````$H4``#\````@A0``-P```&"%``!7````
MF(4```T```#PA0``+0```/Z%```$````+(8``!0````QA@``)0```$:&```2
M````;(8``"````!_A@``'P```*"&```=````P(8```8```#>A@``.0```.6&
M```'````'X<```D````GAP``$P```#&'```$````18<``!````!*AP``$```
M`%N'```1````;(<```X```!^AP``!P```(V'```3````E8<``!<```"IAP``
M$0```,&'```&````TX<```X```#:AP``#0```.F'```+````]X<```(````#
MB```!@````:(```)````#8@```<````7B```%0```!^(```'````-8@```L`
M```]B```!P```$F(```(````48@```4```!:B```$````&"(```0````<8@`
M``4```""B```$````(B(```)````F8@```H```"CB````@```*Z(```?````
ML8@``",```#1B```,0```/6(```G````)XD``&0```!/B0``50```+2)``!*
M````"HH``%L```!5B@``*````+&*```X````VHH``!L````3BP``J0$``"^+
M```C````V8P``$@```#]C```%0```$:-```H````7(T``"(```"%C0``(@``
M`*B-```@````RXT``$$```#LC0``6P```"Z.``!)````BHX``"$```#4C@``
M'P```/:.```S````%H\``"4```!*CP``,````'"/``!I````H8\``#T````+
MD```90```$F0``!-````KY```"X```#]D```*0```"R1```L````5I$``%H`
M``"#D0``*````-Z1```F````!Y(``$@````ND@``2@```'>2```K````PI(`
M`!X```#ND@``,@````V3```O````0),``"P```!PDP``+0```)V3```7````
MRY,``"4```#CDP``,@````F4```I````/)0``#X```!FE```4@```*64```B
M````^)0``"4````;E0``10```$&5```A````AY4``#````"IE0``)0```-J5
M```<`````)8``#$````=E@``#0```$^6```%````798``%D```!CE@```@``
M`+V6```#````P)8``"X```#$E@``+P```/.6```7````(Y<``"`````[EP``
M&P```%R7```8````>)<``"0```"1EP``'P```+:7```:````UI<``"````#Q
MEP``&@```!*8```R````+9@``!D```!@F```+P```'J8```E````JI@``"(`
M``#0F```)0```/.8```F````&9D```D```!`F0``#````$J9```7````5YD`
M``<```!OF0``!P```'>9```'````?YD``!4```"'F0``!@```)V9```)````
MI)D```L```"NF0``$P```+J9```3````SID```\```#BF0``,@```/*9```3
M````)9H```P````YF@``$0```$::```(````6)H```D```!AF@``"@```&N:
M```4````=IH```@```"+F@``"````)2:```_````G9H```<```#=F@``!P``
M`.6:```'````[9H```(```#UF@``!@```/B:```'````_YH```T````'FP``
M"P```!6;```O````(9L``"````!1FP``'````'*;```K````CYL``#$```"[
MFP``!0```.V;```_````\YL``!(````SG```#````$:<```*````4YP``!@`
M``!>G```&0```'><```?````D9P``!T```"QG```$0```,^<```"````X9P`
M``0```#DG```!@```.F<```#````\)P```P```#TG```10````&=```:````
M1YT``#4```!BG0``*````)B=``!3````P9T``#(````5G@``&0```$B>```@
M````8IX``#4```"#G@``10```+F>```P````_YX``"@````PGP``*````%F?
M```I````@I\``"8```"LGP``)0```-.?```H````^9\``"@````BH```(@``
M`$N@```P````;J```!(```"?H```$P```+*@```0````QJ```'D```#7H```
M"0```%&A``!S````6Z$``'P```#/H0``%P```$RB```6````9*(``!4```![
MH@``#P```)&B```.````H:(``!\```"PH@``%````-"B```0````Y:(```\`
M``#VH@``#P````:C```0````%J,```D````GHP``!P```#&C```+````.:,`
M``4```!%HP``"P```$NC```'````5Z,```4```!?HP``%````&6C```.````
M>J,```L```")HP``!P```)6C```(````G:,```\```"FHP``#````+:C```)
M````PZ,```@```#-HP``#````-:C```&````XZ,```\```#JHP``!P```/JC
M```&`````J0``!0````)I```!@```!ZD```,````):0```@````RI```"@``
M`#ND```$````1J0``!,```!+I```!P```%^D```&````9Z0``"(```!NI```
M!P```)&D```%````F:0``%8!``"?I```"@```/:E```/`````:8```<````1
MI@``!P```!FF```'````(:8```D````II@``"P```#.F```%````/Z8``!$`
M``!%I@``#P```%>F```+````9Z8``!4```!SI@``(@```(FF```,````K*8`
M``4```"YI@``$0```+^F```/````T:8```L```#AI@``"P```.VF```1````
M^:8```H````+IP``!@```!:G```*````':<```H````HIP``!P```#.G```F
M````.Z<``!P```!BIP``*0```'^G```Q````J:<``$H```#;IP``1````":H
M``!0````:Z@``$H```"\J```+`````>I```%````-*D``!8````ZJ0``+P``
M`%&I```K````@:D``"0```"MJ0``)````-*I```L````]ZD``"8````DJ@``
M%@```$NJ```>````8JH```0```"!J@``$@```(:J```4````F:H```L```"N
MJ@``%````+JJ```6````SZH``!(```#FJ@``"@```/FJ```,````!*L``!(`
M```1JP``"@```"2K```L````+ZL``!$```!<JP``%@```&ZK```,````A:L`
M``X```"2JP``)@```*&K```$````R*L```H```#-JP``!````-BK```#````
MW:L```0```#AJP``#````.:K```.````\ZL``!`````"K```*@```!.L```.
M````/JP``!0```!-K```%@```&*L```4````>:P``!0```".K```$@```*.L
M```:````MJP```X```#1K```$````."L```6````\:P```0````(K0``!```
M``VM```8````$JT```P````KK0``,0```#BM```$````:JT``"X```!OK0``
M*@```)ZM```L````R:T``"P```#VK0``)@```".N```$````2JX```0```!/
MK@``,0```%2N```V````AJX``"X```"]K@``:@```.RN```I````5Z\``"D`
M``"!KP``*0```*NO```U````U:\``"4````+L```)0```#&P```I````5[``
M`"\```"!L```$@```+&P```6````Q+```"@```#;L```%P````2Q```0````
M'+$``!8````ML0``#````$2Q```8````4;$```0```!JL0``!@```&^Q```@
M````=K$``!X```"7L0``!@```+:Q```.````O;$```0```#,L0``#````-&Q
M```"````WK$```H```#AL0```@```.RQ```(````[[$```,```#XL0```P``
M`/RQ```0`````+(```8````1L@``)0```!BR```*````/K(``!P```!)L@``
M(````&:R```B````A[(``"8```"JL@``)@```-&R``!(````^+(``#(```!!
MLP``!````'2S```,````>;,```0```"&LP``"````(NS```(````E+,```H`
M``"=LP``"````*BS```*````L;,```@```"\LP``!````,6S```,````RK,`
M``X```#7LP``!````.:S```P````Z[,``"@````<M```$````$6T```.````
M5K0```X```!EM```(@```'2T```D````E[0``"````"\M```"@```-VT```0
M````Z+0```H```#YM```$@````2U```2````%[4```(````JM0``!@```"VU
M```&````-+4```0````[M0``"@```$"U```*````2[4```@```!6M0``#@``
M`%^U```(````;K4```8```!WM0``!````'ZU```*````@[4```T```".M0``
M$````)RU```*````K;4``"8```"XM0``,P```-^U```A````$[8``"0````U
MM@``!@```%JV```&````8;8``"L```!HM@``*0```)2V```N````OK8``"P`
M``#MM@``(````!JW```G````.[<``!X```!CMP``)@```(*W```F````J;<`
M`"D```#0MP``(````/JW```F````&[@``#(```!"N```*@```'6X```L````
MH+@``"P```#-N```*@```/JX```?````);D``"H```!%N0``%0```'"Y```D
M````AKD``"8```"KN0``)@```-*Y```<````^;D``!\````6N@``*@```#:Z
M```=````8;H``"````!_N@``)@```*"Z``!`````Q[H```(````(NP``!```
M``N[```(````$+L``!(````9NP``#@```"R[```2````.[L``!0```!.NP``
M"@```&.[```O````;KL```@```">NP``"````*>[```"````L+L```0```"S
MNP``#0```+B[```*````QKL```H```#1NP``!````-R[```&````X;L```P`
M``#HNP``#````/6[```-`````KP``!(````0O```%@```".\```6````.KP`
M``0```!1O```#@```%:\```.````9;P```@```!TO```"````'V\```6````
MAKP```@```"=O```$````*:\```2````M[P``!(```#*O```"````-V\```$
M````YKP```X```#KO```!````/J\```&````_[P``"0````&O0``!````"N]
M```*````,+T```H````[O0``"@```$:]```.````4;T```H```!@O0``+@``
M`&N]``!%````FKT```P```#@O0``$0```.V]```W````_[T```H````WO@``
M!````$*^```.````1[X```X```!6O@``"@```&6^```0````<+X``!````"!
MO@``%0```)*^```2````J+X``!4```"[O@``"@```-&^```/````W+X``"L`
M``#LO@``"````!B_```2````(;\``!0````TOP``+@```$F_```D````>+\`
M`!8```"=OP``!@```+2_```<````N[\```8```#8OP``!0```-^_```&````
MY;\```4```#LOP``"@```/*_```&````_;\```4````$P```"@````K````$
M````%<````0````:P```"````!_````$````*,````P````MP```$@```#K`
M```&````3<```!T```!4P```!@```'+````D````><```",```">P```(@``
M`,+````A````Y<```!\````'P0``(````"?!```=````2,$```0```!FP0``
M%P```&O!```7````@\$``!(```";P0``"@```*[!```,````N<$``!0```#&
MP0``+@```-O!```(````"L(```8````3P@``"````!K"```*````(\(```(`
M```NP@```@```#'"```*````-,(```0````_P@``%0```$3"```0````6L(`
M``(```!KP@``#````&["```<````>\(```@```"8P@``$````*'"```,````
MLL(``!L```"_P@``%````-O"```&````\,(```0```#WP@``!@```/S"```&
M`````\,```H````*PP``#@```!7#```%````),,```0````JPP``&@```"_#
M```B````2L,``!H```!MPP``*P```(C#```K````M,,``#,```#@PP``,@``
M`!3$```0````1\0```P```!8Q```$@```&7$```(````>,0``$4```"!Q```
M60```,?$```.````(<4```@````PQ0``"0```#G%```$````0\4``!T```!(
MQ0``%P```&;%```>````?L4``!\```"=Q0``'````+W%```L````VL4``"@`
M```'Q@``#````##&```*````/<8``!(```!(Q@``$````%O&```*````;,8`
M``@```!WQ@``#````(#&```.````C<8``!@```"<Q@``%@```+7&```8````
MS,8``!8```#EQ@``&@```/S&```8````%\<``!8````PQP``$````$?'```.
M````6,<```X```!GQP``#@```';'```0````A<<```X```"6QP``#@```*7'
M```,````M,<``!````#!QP``$@```-+'```H````Y<<``!`````.R```'```
M`!_(```=````/,@``!P```!:R```'````'?(```8````E,@``!D```"MR```
M!@```,?(```$````SL@```0```#3R```!````-C(```$````W<@```8```#B
MR```"````.G(```(````\L@```8```#[R```!@````+)```C````"<D```@`
M```MR0``!@```#;)```$````/<D```8```!"R0``*````$G)```$````<LD`
M``H```!WR0``$@```(+)```>````E<D``!0```"TR0``"@```,G)```0````
MU,D``!0```#ER0``"````/K)```D`````\H```H````HR@``!````#/*```(
M````.,H```H```!!R@``#P```$S*```^````7,H``!@```";R@``%@```+3*
M```4````R\H``!0```#@R@```@```/7*```M````^,H```H````FRP``,```
M`#'+```$````8LL``!P```!GRP``!````(3+```&````B<L```H```"0RP``
M#@```)O+```(````JLL```0```"SRP``0@```+C+```(````^\L```D````$
MS```5@````[,```"````9<P```H```!HS```!@```'/,```)````>LP```0`
M``"$S```!````(G,```$````CLP```0```"3S```!````)C,```$````G<P`
M``0```"BS```"@```*?,```(````LLP```P```"[S```!````,C,```,````
MS<P```0```#:S```"````-_,```(````Z,P``!0```#QS````@````;-```F
M````"<T```H````PS0``,@```#O-```H````;LT``"@```"7S0``+````,#-
M```2````[<T``!P`````S@``(````!W.```:````/LX``!X```!9S@``"```
M`'C.```F````@<X``!H```"HS@``&@```,/.```C````WLX``",````"SP``
M)P```";/```G````3L\``"4```!VSP``*````)S/``!=````Q<\``!@````C
MT```*@```#S0```;````9]````8```"#T```.````(K0```\````P]````8`
M````T0``!`````?1```*````#-$```H````7T0``"@```"+1```*````+=$`
M``@````XT0``"@```$'1```,````3-$``!8```!9T0``"````'#1```.````
M>=$```8```"(T0``&@```(_1```&````JM$```@```"QT0``!````+K1```T
M````O]$```(```#TT0``#````/?1```2````!-(```0````7T@``"````!S2
M```R````)=(``"D```!8T@``0@```(+2```4````Q=(``$D```#:T@``"@``
M`"33```-````+],```P````]TP``!````$K3```$````3],```0```!4TP``
M(````%G3```6````>M,``!(```"1TP``$@```*33```:````M],```P```#2
MTP``"@```-_3```*````ZM,``!<```#UTP``"0````W4```)````%]0```0`
M```AU```"@```";4```<````,=0``",```!.U```$````'+4```+````@]0`
M``P```"/U```&@```)S4```(````M]0```@```#`U```%@```,G4```*````
MX-0``!(```#KU```)````/[4```*````(]4```P````NU0``"@```#O5```0
M````1M4```@```!7U0``!````&#5```(````9=4``!H```!NU0``(0```(G5
M```^````J]4``"(```#JU0``*`````W6```&````-M8``#`````]U@``,P``
M`&[6```*````HM8``!P```"MU@``!````,K6```&````S]8```0```#6U@``
M#@```-O6```&````ZM8``!(```#QU@``)0````37```(````*M<``!,````S
MUP```@```$?7```$````2M<``#0```!/UP``0P```(37```(````R-<``!D`
M``#1UP``!@```.O7```0````\M<``!`````#V```+````!38```$````0=@`
M``X```!&V```"@```%78```*````8-@```P```!KV```$````'C8```6````
MB=@```@```"@V```!````*G8```0````KM@```X```"_V```'@```,[8```$
M````[=@```8```#RV```!@```/G8```$`````-D```0````%V0``#P````K9
M```-````&MD``!L````HV0``"@```$39```#````3]D```(```!3V0``!```
M`%;9```)````6]D``!````!EV0``%P```';9```$````CMD```@```"3V0``
M"````)S9```,````I=D``!@```"RV0``(@```,O9```>````[MD```P````-
MV@``&````!K:```@````,]H``%(```!4V@``)````*?:```>````S-H``!H`
M``#KV@``'@````;;```<````)=L``!,```!"VP``)````%;;```>````>]L`
M`"H```":VP``%P```,7;```7````W=L``!````#UVP``%@````;<```(````
M'=P```0````FW```!````"O<```R````,-P``"````!CW```5P```(3<```,
M````W-P``#P```#IW```!````";=```2````*]T``"X````^W0``%````&W=
M```4````@MT``!X```"7W0``)````+;=```$````V]T``#(```#@W0``#```
M`!/>```(````(-X``!0````IW@``!@```#[>```2````1=X```X```!8W@``
M#@```&?>```.````=MX```0```"%W@``"@```(K>```.````E=X```H```"D
MW@``!````*_>```(````M-X```@```"]W@``#@```,;>```"````U=X```0`
M``#8W@``!@```-W>```$````Y-X``!4```#IW@``!````/_>```&````!-\`
M``(````+WP``"P````[?```"````&M\```8````=WP``!@```"3?```&````
M*]\```@````RWP``#````#O?```(````2-\```(```!1WP``'@```%3?```6
M````<]\``#(```"*WP``+@```+W?``!,````[-\``%P````YX```/````);@
M``!<````T^```"0````PX0``)@```%7A```B````?.$``.0```"?X0``&@``
M`(3B``!'````G^(``!8```#GX@``)0```/[B```<````).,``!P```!!XP``
M'````%[C```X````>^,``$<```"TXP``2@```/SC```>````1^0``!X```!F
MY```,@```(7D```J````N.0``"8```#CY```7@````KE``!+````:>4``%\`
M``"UY0``3P```!7F```R````9>8``"X```"8Y@``+````,?F``!.````].8`
M`"8```!#YP``)@```&KG``!&````D><``$8```#8YP``)@```!_H```B````
M1N@``#8```!IZ```*P```*#H```I````S.@``"@```#VZ```&@```!_I```J
M````.ND``#(```!EZ0``*P```)CI``!.````Q.D``$8````3Z@``(@```%KJ
M```D````?>H``$P```"BZ@``*0```._J```Q````&>L``"H```!+ZP``(@``
M`';K``!"````F>L```P```#<ZP``"````.GK``!;````\NL```(```!.[```
M`P```%'L```P````5>P``#$```"&[```%0```+CL```<````SNP``!8```#K
M[```(`````+M```H````(^T``"(```!,[0``'@```&_M```C````CNT``!@`
M``"R[0``-@```,OM```7`````NX``#0````:[@``'````$_N```>````;.X`
M`"(```"+[@``(````*[N```$````S^X```X```#4[@``"````./N```&````
M[.X```0```#S[@``!````/CN```<````_>X```0````:[P``#P```!_O```0
M````+^\``!0```!`[P``%````%7O```2````:N\``#L```!][P``"@```+GO
M```0````Q.\```H```#5[P``"````.#O```)````Z>\```H```#S[P``%```
M`/[O```$````$_````8````8\```,P```!_P```"````4_````D```!6\```
M!````&#P```"````9?````0```!H\```"````&WP```-````=O```!$```"$
M\```,````);P```6````Q_```!0```#>\```&@```//P```L````#O$```(`
M```[\0``,0```#[Q```&````</$```P```!W\0``$````(3Q```/````E?$`
M``\```"E\0``$P```+7Q```7````R?$```\```#A\0```@```/'Q```"````
M]/$```0```#W\0``!````/SQ```*`````?(``#T````,\@``'````$KR```G
M````9_(``"@```"/\@``40```+CR```V````"O,``!,```!!\P``&@```%7S
M``!-````</,``#H```"^\P``(P```/GS```@````'?0``"(````^]```)```
M`&'T```D````AO0``"0```"K]```)````-#T```F````]?0``!X````<]0``
M/P```#OU```2````>_4``!<```".]0``&@```*;U``!H````P?4```P````J
M]@``=@```#?V``!H````KO8```X````7]P``%0```";W```<````//<```P`
M``!9]P``$````&;W```8````=_<```\```"0]P``$````*#W```*````L?<`
M``8```"\]P``#@```,/W```&````TO<```8```#9]P``"@```.#W```&````
MZ_<```H```#R]P``"@```/WW```(````"/@``!,````1^```#0```"7X```*
M````,_@```H````^^```#````$GX```,````5O@```P```!C^```"@```'#X
M```,````>_@```P```"(^```!@```)7X```,````G/@```8```"I^```#@``
M`+#X```(````O_@```@```#(^```"@```-'X```&````W/@```X```#C^```
M"````/+X```6````^_@```H````2^0``"````!WY```E````)OD```8```!,
M^0``!0```%/Y```!``````````````#H`0``T@(``'$"````````7`,``"L#
M``````````````````!M`P``)P$``+D"``!B`P``7@,``+X"```F`0``````
M`,8"``!%`0```````%\"```6`P```````'`````U`P```````","``!S````
M?@````P#``#``@```````!P#``!R`0``;````!,"``!F`@``>@```+@```#J
M`@``]`$`````````````E````)`"``!``0``\@(````#`````````````&P"
M````````0P```(T!``"Q`0``Z0```*8`````````<P(``.P"````````6@$`
M`%$#```\````J0```%L#``!$`P``[P$``&D"```[`P``IP$``,8````.`0``
M!0$```````#X````50```$X#``!6`P``AP$````````*`P```````-D!```Q
M`0``#0(```X````,``````````````"V```````````````G````%0```&<!
M````````@0$``/P"``".`0````````````!=`0``40```,D```!N`P``M0(`
M`````````````````(0!``#!`0``<0```,L"``"7`0``K@$``)8"``#P`@``
M`````"4#````````!P$``!("``#*`0``*`,```````"8`0``]0```((#``")
M`0````````````"T````LP````````#7`0``@@```$X```!F````6P(``'0!
M``"O`@``+@````````!.`0``XP```)\"````````TP```)("``!(`0``.@,`
M`/\!``"!`@``T`$``&<#```5`0``0@```!<"````````=`(``.4`````````
MJ`$```````#J`0``J`(``*@````4`P``E`(``&\"````````OP``````````
M`````````"(#````````PP(``"`#``#``0``D````%$"``#?`@``O`$``'X#
M````````5@(```````#(`@``90```&4#```)````_0`````````2````^`(`
M`)@```!,`0``PP$``-D`````````*0```/H!````````(@```"T```!5`P``
M`````%,"````````50(`````````````2@$```````"%`P```````$("```I
M`0``%@$``-H`````````+0,``````````````````"@!``!A`P``>P```)`!
M``"&`@``O`(``-\!``#R`````````%,!``#$````/@````````#K`0``````
M``````"1`0```````/L"````````<0$```````"2````J@```%P!```+`@``
M`````!````!)`0``=@$``%<`````````.0,``,@!``"?````60(```````!/
M````L`(```H```!C`P``<@(``'\```!@`P```````&,````K`0``&@(``)4`
M``"P`0``S@```/8!``!\`0```````!T`````````T`(``'D"````````K@``
M`.("``"B````7@(``#0#``"X`0``B@$``(D```"]`@``>````#X#``!U`0``
M)`(````````!`0``R0(``%0"``!Z`0``S`(```````#;`0``?P(````````I
M`P````````````!-`@``L@(``%(!``#U`0``!`,``(`!````````)P(```\"
M``#D`0````````````!,`@``U`(``(,!``"$`P``!@(``#H```"'`@``G@``
M``````"``````````$L#``!U````*`(```````#2`````P$```````!J````
M`````-$```#S`@``*@(``+X!```Z`0``%0,```4"`````````````&(```!U
M`P``F@```*4````!`@`````````!``!9`0``YP$```````!<`@``2@,`````
M`````````````*4!``!(`P``;@```!`"``!=````G0(```````"[`0``YP``
M``P!``#;`@``'@(``````````````````*\!````````'@```#X!``!]`P``
M`````),```!0`P``Z````.4"````````'@$```````"F`@``F0```$T````P
M`@``^`$`````````````4@(``'H#````````0````,X!```$`@``?P$``,<"
M``"M`@```````/L!``"D````SP$`````````````G0```&4!``"#`@``"0,`
M`%0#```@`@``;@(``.$"````````%P``````````````50$``%D#``!J`0``
M'P````````!X`P``'0$``)<"```.`@``LP$``%````!K`P``````````````
M`@``&0(``(@!````````-0(``&T"``!#`0``0`(`````````````!@```,(!
M```J````U@$``!$```"L````-P``````````````30,``,8!``"$`@``````
M`(T"````````/`$``,\"``#!`@``0P(``````````````````'<"```+````
MG`$```X#``#W`@````````L!``"W`@``F0(```````"Q`@``6@```$`#```<
M`@``9`,``(4```#C`0```````(8#``"[`@```````)H!``#'````V@$``*,"
M````````&`,``.4!``!7`P```````.X"``#B`0``V`(```````"Q````````
M``````!R`P``AP,``!8"`````````````'P```"X`@``>P(``($`````````
MUP(``-4```````````````````"(````I@$``````````````````&D!```[
M`@``K@(``.T"````````>0,``'`!```2`P```````,0!```'`@```@,`````
M````````'`$``#$```"I`0``\@$``#\"``#L````CP(```@#``"%`@``-`$`
M`````````````````/8"```F`````````+D!`````````````'\#````````
M80$````````/````=P,``(<```#F`0``'@,``+<!```*`@``:0,`````````
M````FP$``#L!```@````'P(``#0```!P`@```````',#``"J`@```````$H"
M``#Z`@`````````````R`P``)0$``#4````]`P``_P(``%`!```J`P``%P$`
M``````!J`@```````!\!``":`@``-P(``&L!``#0``````````````!2````
MO``````````J`0``O0```#,````O`@```````%T"`````````````&0!``!)
M`P``6P$``,$`````````)P,``*$!```L````&`$``(P"``"$````U0(`````
M````````FP(``+`````]````+0$``(\!``!C`0``S`$``(P```"*````````
M`%H#```/`0``(P```$L```#[````;P```%X```````````````````"E`@``
M+P```$T!````````?@(```````!>`0```````!0```!3````+P$``",!```;
M`0``V0(``(8!``!C`@``@`(```T#``#S`0``TP(``!H#```A````Q0$``#8!
M```S`@``1@$``)P```!W````6@(``&`````S`P``U`````````!/`@``%0(`
M`%\!``!G`@``)0(``'(``````````````'8#``"L`@``9````$$"```8````
MN@(``#@"```\`P````````T!```Q`@```````$4#``#N````5@$``-<`````
M``````````````"8`@``M0```*T```"*`@``3`````````!^`0``80(``(@"
M```V````W@$``+8"`````````````*0!``"2`0``&P(``%\````V`@``G@(`
M`*`"``#3`0```````+(!``#Z`````0,``$<#```D`0``&P````````#+````
M:`$``'@"``#=`0``S````-P```#L`0``\0```$8"````````]``````````%
M`````````(P!``!6````!P,`````````````I`(```````#(````)@(``"X"
M```L`@``_`$```````!(````W`(``````````````````$4"````````IP(`
M`+\"`````````````&`"```P`0`````````````_`P``Y@```%@```">`0``
M``````L#``!=`P```@```/4"````````K0$``%\#````````20(``"D"``!/
M`P``$0(```````!,`P``>`$```,#```%`P``6`$```````!;`````````$$#
M```Y`@``S0````````#?`````````$0!```X`0```````!T"```6````_0(`
M`.`"``#;````_@````````#W````B0(``!<#`````````````)L```"!`P``
M`````&`!``"9`0``10```&\#``#6`@``-`(``,D!``"_`0``B0,``"X!```S
M`0``V`$````````R`@````````\#``"K`@``SP```"0#```4`0``,@````0`
M``"=`0``5P(```@"``!F`0``<`,``,("````````[P``````````````Q0``
M``````"(`P```````+,"```^`@```````)8!``!"`0```````%@#``!'`@``
MH0````````"I`@``]`(``(L"````````1`````8!````````6`(```````"T
M`0````````````"@````[@$``!,!``#*````-@,``!D#``"Z````W@```.L`
M``!#`P``<0,``.$!```:`````````%,#``!E`@``Y@(``#\`````````?0(`
M``````!Y`0```````-H"``#.`@``*``````````#````:P(```D"````````
M=`,``,T"```E````1@`````````A`P``T0$``!\#``!L`0``;P$```<```"^
M`````````,L!``#B````_@(``&X!``"3`@``@P```-@```!B`0``+@,``*L`
M``!7`0``$P```#(!``#H`@``.`,``"\#`````````````$L!``#<`0``E0$`
M``````#1`@``BP```(T```!Y````2@```.\"``!.`@```````$<```""`0``
M,`,``/,`````````'0,````````4`@```````-4!``!H````80````````#G
M`@`````````````,`@``3P$``&P#````````<P$````````K`@```````%P`
M``!\`@```````+4!````````(@$``&0"``#_````NP```.````!9````W0``
M`(X"```;`P``D0(`````````````@@(``&T``````````````(L!``#V````
M.`````````#I`@```````",#`````````````!P```#4`0``;0$````````Y
M````>P$```("``"B`0``1@,``.,"````````:@,``+8!```&`P``=````.D!
M``"J`0```````.$`````````W@(```````#Q`@``.@(``"$!````````$`,`
M`"0```!B`@``"````-T"````````D0```/`!``"@`0``!`$``'T!````````
M/`(``#L```#`````&0$``!$!```1`P``&@$``$(#``!4`0``````````````
M`````P(````````P`````````),!`````````````"$"```"`0``ZP(`````
M``"K`0``_@$`````````````_0$``(X```!4````@`,``*$"````````N0``
M`$$````W`P``=@(``#<!``!H`@``[0```*,!``"#`P``4@,``)<`````````
M`````+<````2`0``IP```-8```!$`@```````%`"````````P@```$<!````
M````:`,``.`!```M`@``=0(``,0"``##````K`$```T```#M`0``G`(``#$#
M```3`P```````/<!``![`P``/P$````````(`0``=P$``%$!```8`@``Z@``
M`+T!``#'`0``&0```*("```L`0``A@````````!Z`@``/0(``/$!``#Y`0``
MY````'P#````````N@$``#4!``!+`@```````*,```#*`@``\````$@"``"O
M````T@$``$$!``"/````"@$``+(```!I`````````!`!``!]````.0$``,4"
M```@`0``````````````````"0$``&8#``#D`@``E@````````"4`0``A0$`
M`/D````B`@``)@,``/P```#Y`@``E0(```````!K````*P````````!V````
M````````````````M`(```````!)`````````#T!``!G````+`,``)\!``#-
M`0```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@
M*'EE<W1E<F1A>2D`)60@;F]T97,`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I
M;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E
M861Y(&5X:7-T<RX`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@
M:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S)W,@061D
M<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S
M:VQI<W0`+2T@<V5L96-T("TM`#$@;F]T90`Q,B!(;W5R($9O<FUA=``R-"!(
M;W5R($9O<FUA=``R-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q
M=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92X`06-C97-S(&1E;FEE9"!D96QE=&EN9R!N
M;W1E+@!!8V-E<W,@9&5N:65D(&UO=FEN9R!T:&4@;F]T92X`06-C97-S(&1E
M;FEE9"!S879I;F<@;F]T92!T;R`E<RX`06-C97-S(&1E;FEE9"!S879I;F<@
M;F]T93H@)7,`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`061D
M`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R
M93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W
M('5S97(Z`$%D9"!C871E9V]R>0!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O
M:P!!9&0@=7-E<@!!9&1I;F<@02!.97<@3F]T90!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N
M`$%D<P!!;&EA<P!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!
M;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M
M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S
M`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YO;GEM;W5S(%!R
M;WAY`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!R;W9E
M`$%P<FEL`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/P!!<V-E;F1I;F<`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!#871E9V]R:65S.@!!=F%I;&%B;&4@9FEE;&1S
M.@!"86-K('1O($YO=&5P860`0F%C:R!T;R!.;W1E<&%D($]P=&EO;G,`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!":7)T:&1A>0!";&]C:R!4>7!E
M`$)O;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D
M97)S`$)U;&QE=&5D($QI<W0`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<P!#86QE;F1A<@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<P!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L
M("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F
M(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@
M;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BX`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%T
M96=O<GD`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG
M.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5N
M=&5R`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`
M0VAA;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS
M+@!#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@86YD(&1I<W!L87D@;W!T:6]N
M<RX`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@=&AE(&UE;6\@8V%T96=O
M<FEE<R!T;R!L:7-T(&EN('1H92!S=6UM87)Y('9I97<N`$-H;V]S92!Y;W5R
M(&1E9F%U;'0@3F]T97!A9"X`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N`$-L96%R($9O<FT`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S
M97(`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-O;&]R`$-O;&]R
M(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`
M0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.
M86UE`$-O;7!A;GD`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U
M<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@4$=0(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K
M(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@
M9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#
M;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T
M:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@
M)7,N`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT<GD`0W)E
M871E`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T
M960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W5R
M<F5N="!4:6UE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`1$0`1&%I;'D`1&%T851R964@0G)O
M=W-E<@!$871E(%)E8V5I=F5D`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E
M8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L="!#;VQO<@!$
M969A=6QT($ED96YT:71Y`$1E9F%U;'0@3F]T97!A9`!$969A=6QT('-O<G1I
M;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T
M90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&-E;&P`
M1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$
M96QI=F5R>2!T:6UE`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5S8W)I<'1I;VXZ`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1I<F5C
M=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D
M96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!%+4UA:6P`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!.;W1E
M`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M<'1Y($YO=&4`16UP='D@;65S<V%G92X`16UP='D@
M<F5S=6QT+@!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O
M($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/P!%;FQA<F=E($5D:71O<@!%<G)O<@!%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M96-U=&4`17AP86YD`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!%>'!O<G0`
M17AP;W)T($YO=&5S`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1E]U
M;&P@5&5X=`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I
M;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%3
M3"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&96)R=6%R
M>0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I
M;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO
M860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1F]N="!#
M;VQO<@!&;W)M<P!&;W)U;7,`1G(`1G)A;65S`$9U;&P@1&5S8W)I<'1I;VX`
M1G5L;"!.86UE`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D
M($-O9&4`1VEV96X@3F%M90!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5E<W0@4&5R;6ES<VEO
M;G,`1W5E<W1B;V]K`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(
M87-H+4%L9V]R:71H;0!(96%D97(`2&5I9VAT`$AE;'``2&]M90!(;VUE($%D
M9')E<W,`2&]M92!0:&]N90!(;W)D90!(;W)I>F]N=&%L(%)U;&4`2&]W(&UA
M;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N
M('9I;VQA=&EO;BX`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I
M='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S
M964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y
M(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS
M<&%R96YC>2X`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`
M26UA9V5S`$EM<&]R="!.;W1E<RP@4W1E<"`E9`!);7!O<G0L(%-T97`@)60`
M26UP;W)T+T5X<&]R="!.;W1E<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T
M960@9FEE;&1S.@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R
M<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8W)E87-E($EN9&5N
M=`!);F1I=FED=6%L(%5S97)S`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN
M($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,
M:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!C96QL(&%F
M=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN
M<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@
M3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G9A;&ED(&%P
M<&QI8V%T:6]N+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A
M+@!)<W-U97(`271A;&EC`$IA;G5A<GD`2G5L>0!*=6YE`$IU<W1I9GD`2G5S
M=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y
M(%)I9VAT`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO
M;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME
M>2!4>7!E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`3&%N9W5A9V4`3&%S="!-;V1I9FEE9`!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA>6]U
M=`!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S
M`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$U-`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`36%I
M;`!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+@!-87)C:`!-871C:&EN9R!F:65L9',`36%Y`$UE
M;6)E<G,`365M;R!497AT`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G
M90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365T:&]D
M`$UI;64@5'EP90!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36\`36]B:6QE($UA:6P`36]D:69I960@1&%T90!-;V1I9GEI
M;F<@)7,`36]N=&AL>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`
M36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!->2!!8V-O=6YT`$UY($YO=&5S
M`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YE='=O<FL`3F5V97(`3F5W($-A
M=&5G;W)Y`$YE=R!.;W1E`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE>'0`
M3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E
M<F5N8V5S(&9O<BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!6
M1E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`
M3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YO
M=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+@!.;R!N;W1E<P!.;R!N
M;W1E<R!M871C:"!T:&4@8W5R<F5N="!C<FET97)I82X`3F\@;F]T97,@=&\@
M9&ES<&QA>0!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y3
M4TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D
M871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V
M86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO7W1E`$YO;F4`3F]T($%F=&5R`$YO="!"969O<F4`3F]T92!#
M871E9V]R>0!.;W1E($1E=&%I;',`3F]T92!,:7-T<P!.;W1E(%1E>'0`3F]T
M92!?5&5X=`!.;W1E(&YO="!F;W5N9"X`3F]T95]P860`3F]T97!A9"=S(&YA
M;64Z`$YO=&5P861S`$YO=&5P861S(&UU<W0@:&%V92!A(&YA;64N`$YO=&5S
M`$YO=&5S(%-U;6UA<GD`3F]V96UB97(`3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T
M`$]B:F5C="!#<F5A=&]R`$]C=&]B97(`3V9F:6-E`$]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="X`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI
M<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN
M9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/=&AE<B!);F9O<FUA
M=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N
M871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!A9&1I
M;F<`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I
M<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M
M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!096YD:6YG
M(%-I9VYU<',Z`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6ES<VEO;@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M
M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!0
M:&]N90!0:7AE;',`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE
M87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D
M87ES(&EN('1H92!M;VYT:"X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0;VQL<P!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E
M<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E=FEE=P!0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')I;G0@9&]C=6UE;G0`4')I=F%T
M92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!U8FQI8R!+97D`
M4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`475E<GD`4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="D`4F%T:6\`4F5A9`!296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@3&ES=`!2969R97-H(%!O<G1A
M;"!6:65W.@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO
M=F4@8V%T96=O<GD`4F5M;W9E('!A:7(`4F5M;W9E('5S97(`4F5M;W9E('5S
M97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@`%)E<V5T`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`
M4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M`%)O;&4`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5N
M`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!344P@4VAE;&P`4U-(`%-A`%-A=F4`4V%V92`E<P!3879E($]P=&EO
M;G,`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V5A<F-H`%-E87)C:"!297-U
M;'1S`%-E87)C:"!38V]P90!396%R8V@@7U1E>'0`4V5L96-T(&$@9&%T90!3
M96QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C
M="!A(&YO=&5P860`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@
M861D`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F
M;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@
M9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@0V%T96=O<FEE<SH`
M4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!397!T96UB97(`4V5R:6%L
M($YU;6)E<@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T
M;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U
M<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F
M<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4VAO<G0@4W5M
M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\`4VAO=P!3:&]W(&%C=&EO;B!B=71T;VYS/P!3:&]W(&QA<W0@;&]G
M:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;F]T97!A9"!N86UE/P!3
M:&]W(&YO=&5S(&9R;VT@=&AE<V4@8V%T96=O<FEE<P!3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4V]R="!B
M>2!#871E9V]R>0!3;W)T(&)Y($YO=&4@5&5X=`!3;W5R8V4@861D<F5S<P!3
M<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T<F5E="!!9&1R97-S
M`%-T<FEK971H<F]U9V@`4W1Y;&4@6T-34UT`4W4`4W5B;6ET`%-U8G-C<FEP
M=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6UM87)Y`%-U<&5R
M<V-R:7!T`%-U<FYA;64`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE
M<P!486)L92!P<F]P97)T:65S`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5X
M="!/;FQY`%1E>'0@86QI9VX`5&@`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@
M<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+
M(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I
M=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&YO=&4@=V%S(&1E;&5T960N
M`%1H92!N;W1E<&%D("(E<R(@8V]U;&1N)W0@8F4@8W)E871E9#H@)7,`5&AE
M(&YO=&5P860@(B5S(B!H87,@8F5E;B!C<F5A=&5D+@!4:&4@;F]T97!A9"`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E
M("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&5R92!A
M<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<P!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!V3F]T92!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@
M<V%V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<P!4:&5R92!W97)E(&YO
M(&UE;6]S('1O(&5X<&]R="X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@)R,Q,C,T868G+@!4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T
M960N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A
M;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&EM
M92!4<F%C:VEN9P!4:71L90!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4=0!54DP`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<P!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD97)L:6YE`%5N9&\@
M0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F9I;&5D`%5N:VYO
M=VX`56YN86UE9`!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T
M92`E<P!5<&1A=&4@=7-E<@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O
M;6%N(&YU;6)E<G,`57-E($-U<G)E;G0Z("5S`%5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@061M:6YI
M<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N
M86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ
M`%9A8V%T:6]N`%9A;&ED:71Y`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N
M`%9I97<@)7,`5V%R;FEN9P!790!7965K;'D`5V5L8V]M90!796QC;VUE('1O
M("5S`%=E;&-O;64L("5S`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@3F]T
M97!A9"!S:&]U;&0@=&AE(&YO=&5S(&)E(&%D9&5D('1O/P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H
M`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5V]R:R!!
M9&1R97-S`%=O<FL@4&AO;F4`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N
M871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y
M=C,@97AT96YS:6]N<P!960!965E9`%EE87)L>0!997,`665S+"!)($%G<F5E
M`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T
M;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M:6X@)7,N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE
M(&YO=&5P860@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@82!N;W1E<&%D
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@
M8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L
M96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP
M92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S
M`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M
M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BX`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED
M96YT:71Y.@!9;W5R(&1E9F%U;'0@;F]T97!A9#H`66]U<B!F=6QL(&YA;64Z
M`%EO=7(@;F]T97!A9',Z`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`6U!R;V)L96T@4F5P;W)T70!;;&EN
M92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"86-K('1O($YO=&5P860`
M7T-A=&5G;W)Y`%]$96QE=&4`7T1E;&5T92!2;W<`7T5D:70`7T9I<G-T($QI
M;F4`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T
M+T5X<&]R=`!?3&ES="!.;W1E<P!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@
M3&EN:RXN+@!?37D@3F]T97!A9',`7TYE=R!.;W1E`%]/<'1I;VYS`%]097)M
M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK+BXN`%]396%R8V@`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L
M96YD87(`8VQI8VL@:&5R90!F:6QE`&YO="!Y970@:6UP;&5M96YT960`<&5R
M8V5N=`!P:7AE;',`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER
M;0!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@36YE;6\@,BXP
M+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2
M979I<VEO;BU$871E.B`R,#`U+3`R+3(Q(#$R.C`P*S`Y,#`*3&%S="U4<F%N
M<VQA=&]R.B!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N
M:G`*3&%N9W5A9V4M5&5A;3H@2F%P86YE<V4@/$Q,0&QI+F]R9SX*34E-12U6
M97)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/5-(24947TI)4PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@
M*"5S()/ZD4\I`(-!@TZ#6H-8@TR#0R`E<P`@*(VAD_HI`"`HC?"3^BD`)60@
M@X&#@@"2RI)M("T@)7,`)7,@DV2.<8YWEN0`)7,@2T(`)7,@E=N.YY&`C>R"
MS(IME$8`)7,@@U2#0X.3@T&#8H-V`"5S().OB-./\(V``"5S((+-BOF"R9&V
MC=V"M8+<@K>!0@"#=(-`@T.#BR`E<R""S8-#@Y.#?(%;@V>"LX+J@MR"M8*]
M`"5S@JJ52Y=V@L6"MP`E<R"5J@`E<R""JH*@@NB"W(*Y@O&!0@`E<R""S(-!
M@VB#C(-8DJ``)7,@@LR77)+HE5P`)7,@@LR#@8."DJ``)7,@@LR#7H-8@TZ#
MBH-8@V<`+2T@D4F1\"`M+0`Q((.!@X(`,3*.GHK4C&".K@`R-(Z>BM2,8(ZN
M`#(T((Z>BM0`@K&"S(-U@XV#8H-.@LV#9H%;@UZ#>(%;@UB"JI5+EW:"Q8*W
M@4(`DG:6O9-)@LB#1X.)@5N"JI2MD+:"M8+<@K6"O0!01U",]HI*C*Z"JH.!
M@V*#6H%;@U>"S(C#C8:)NX+)E4N7=H+%@K>!0@!01U",]HI*C*Z"JH^0EKR"
MLX+J@KV#@8-B@UJ!6X-7@LR,GX_8@LF52Y=V@L6"MX%"`%!'4(SVBDJ,KH%!
M4$=0E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7
M@LR5G(V&@LF52Y=V@L6"MX%"`%!'4(SVBDJ,KH%!4$=0E.F6IXRN@JB"YH+1
M@W"#6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/D):\@LF52Y=V@L6"MX%"`%,O
M34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ(
MPXV&B;N#@8-B@UJ!6X-7@LR5G(V&@LF52Y=V@L6"MX%"`%,O34E-18SVBDJ,
MKH%!4R]-24U%E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7
M@LR/D):\@LF52Y=V@L6"MX%"`%,O34E-18SVBDJ,KH*J@X&#8H-:@5N#5X+,
MB,.-AHF[@LF52Y=V@L6"MX%"`$%-+U!-`(*Q@LR#1X-F@T*#7H%;@LF"PH*B
M@L0`5D93@V:#0H.,@TZ#9X.*@LR-[)"L@LV#08-.@UJ#6(N1E-N"LX+J@MR"
MM8*]@4(`5D93@W2#0(-#@XN"S(WLD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U
M@KV!0@"#@8."@LR-[8^<@LV#08-.@UJ#6(N1E-N"LX+J@MR"M8*]@4(`@X&#
M@H+,B-J3KH+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"`(.!@X*"S"`E<R""
MUH+,E=N1MH+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"`(.!@X*"S)7;D;:"
MS8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!1B5S`(-!@TJ#18.3@V>"S(-P@UB#
MCX%;@V@`@T&#2H-%@Y.#9X+-DX",BX*S@NJ"Q(*B@MR"MX%"`)+'B<$`@U2#
M=8-/@XN!6X-V@O"2QXG!`(-4@W6#08-.@UJ#6(R@@O"2QXG!`(*Q@K&"R9+'
MB<$Z`)!6@K6"HH-/@XN!6X-V@O"2QXG!`)!6@K6"HH+P@T&#3H-:@UB,H)+'
MB<$`D%:+2X.&@5N#58+PDL>)P8%&`)6JE]Z"\)+'B<$`@U*#B8.`@O"2QXG!
M`)!6BTN#@8.3@V^"\)+'B<&!1@"#>8-!@O"2QXG!`"5S((.!@VJ#A8%;@O`@
M36]Z:6QL82""S(-4@T.#:(-O@5N"R9+'B<&"MX+I`(-!@VB#C(-8DJ""R9+'
MB<$Z`(Z$@LR"S(-!@VB#C(-8DJ""R9+'B<$`@X:!6X-5@O"2QXG!`)!6BTN#
M@8."@O"2QXG!`(.&@5N#58+,DL>)P8^(EYV"S9:SC/B"R8+(@L&"Q(*B@MR"
MMX%"`(]:CXH`@T&#:(.,@UB2H`"*QY>=`$%D<P"5RI:\`)%3E$:/V(.&@5N#
M50"14X+$@LR#3X.+@5N#=@"14X+$@LR#08-.@UJ#6(R@`)34C8:5=(*K@XJ#
M6(-G@O"0W9+H@L6"JX+I@N:"I(+)@K6"W(*W@JF!2`"*^8+)D;:-W8*U@MR"
MMP"1XY'6@LP@24U34""#C8-/@T.#DP"1XY'6@LP@24U34""#<(-8@X^!6X-H
M`)'CD=:"S"!)35-0((.&@5N#59:\`)'CD=:"S(.!@5N#BX-!@VB#C(-8`)'C
MD=:"S(-E@Y.#=H.,@5N#9P"5<Y"S@LB2;(*JCG>2Z(*S@NJ"Q(*B@MR"MP"3
MO9:\@W:#C8-,@U:!6P"#08-V@XJ#4(%;@U:#AX.3`(-!@W:#BH-0@5N#5H.'
M@Y..9Y=PB<(`C[.41@""4XR.`(-!@5N#2H-#@W6#=(-`@T.#BX-4@T.#60"#
M08%;@TJ#0X-UEKP`)7,@@LR#5(-#@Y.#08-B@W:7=HN!@O"6>Y.6@LF-[8^<
M@K6"Q(*B@J*"Q8*W@JF!2`"/N(^'`)7;CN>-[(O&@LR.P(USD4^"R8IME$:"
M\(N!@M^"Z8+F@J2"R8*U@MR"MX*I@4@`D;:-W8*U@LB"HH-/@XN!6X-V@O"-
M[8^<@K6"YH*D@L:"M8+<@K6"O8%"`)&VC=V"M8+(@J*#08-.@UJ#6(R@@O"-
M[8^<@K6"YH*D@L:"M8+<@K6"O8%"`)&VC=V"M8+(@J*#08-.@UJ#6(R@@O"5
MTH]7@K6"YH*D@L:"M8+<@K6"O8%"`)&VC=V"M8+(@J*+I)=,@O"5TH]7@K6"
MYH*D@L:"M8+<@K6"O8%"`)&ND*L`@E>,C@!!=71H7V-Y<G-Q;#H@E4N7=H+(
M24U!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?8WER=7,Z((-O
M@V*#3H-'@Y.#:(+-E4N7=H+(E%R7S8+PETR"M8+$@J*"W(*Y@O&!0@!!=71H
M7V-Y<G5S.B"7=HN!@K>"Z6EM87"*9Y*C@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U
M=&A?9G1P.B!&5%"*9Y*CBT"47(*J@MV"PH*I@NB"W(*Y@O$N(%!(4(+P("TM
M96YA8FQE+69T<""#28-V@U:#AX.3@O""PH*O@L2#4H.3@W"#0X.+@K6"R(*H
M@K6"Q(*M@KZ"LX*B@4(`075T:%]I;6%P.B!)34%0BF>2HXM`E%R"JHRI@L*"
MJ8+H@MR"N8+Q@4(`075T:%]K<F(U.B!K<F(UBF>2HXM`E%R"JHRI@L*"J8+H
M@MR"N8+Q@4(`075T:%]L9&%P.B!,1$%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"
MN8+Q@4(`075T:%]L9&%P.B"#AH%;@U4@)7,@@O"2QXG!@L6"JX+<@KF"\8%"
M@U2!6X-O@LR)GI.:.B``075T:%]L9&%P.B"#AH%;@U4@)7,@@O"-[8^<@L6"
MJX+<@KF"\0!!=71H7VQD87`Z((.&@5N#52`E<R""\(U8D%:"Q8*K@MR"N8+Q
M`$%U=&A?;6-A;#H@34-!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U
M=&A?<VUB875T:#H@<VUB875T:(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"
M`)1&C]B"R8ZXE'."M8+<@K6"O0"41H_8@LF.N)1S@K6"W(*U@KV!0B5S`%)!
M1$E54X-4@5N#;X+)@N:"Z)1&C]B"JHN1E-N"LX+J@MR"M8*]@4(`1E10@U2!
M6X-O@LR41H_8@LF.N)1S@4(`CF>7<(G"E%R"R)6JE]Z!1@".9Y=PB<*47(+(
M@W2#0H%;@XN#:(%&`(.!@X*2H(+)EM^"Z0"#@8."DJ""S(-)@W:#5H.'@Y."
MR9;?@ND`E'>,:0"4=XQID$8`2V5R;V)E<F]S((-P@UB#CX%;@VB"JI:SC/B"
MQ8*W@4(`2V5R;V)E<F]S((.&@5N#59:\@JJ6LXSX@L6"MX%"`))AD+:3^@"#
M=8.-@V*#3H->@T.#=@"1OHZ:`(-U@V*#3H-]@5N#3@")CP")CX+,D;Z"LX%&
M`(F/`(G3C_"/D8*K`$--4P!#4D,`0U),()1ZE7J#?(-#@Y.#9P"77)+HE5P`
M24U!4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"M8*].B`E<P"#3(.#@Y.#
M6H.+`(_ABE&#C(-\@5N#9X+P@TR#@X.3@UJ#BX*W@ND`@W2#0(-#@XL@(B5S
M(B""\(WMCYR"Q8*K@MR"N8+Q@4(`C>R+QH-F@T*#C(-.@V>#BH*JC*F5=(*I
M@NB"W(*Y@O&!0@"#9H-"@XR#3H-G@XJ!6R`B)7,B((+PC>V/G(+%@JN"W(*Y
M@O&!0@"-[8^<@L6"JX+<@KF"\8%"CG&1MX*J("5D()&VC=V"M8+<@K>!0@"5
MP(+7D=:"IH+,D<Z/VX+,D)2"JI7;D;:"LX+J@L2"HH+ID)2"QHV'@NV"R(*B
M@LR"Q97`@M>1UH*F@JJ"Q8*K@MR"N8+Q@4(`CG>2Z(*S@NJ"O934C8:"R8.!
M@V*#6H%;@U>"\)1ZD9>"Q8*K@MR"N8+Q@L6"M8*]@4(`E5R1Z`"5JI?>@L:#
MB8-X@XL`E:J7W@",9Y'1DV288@"#6H.+D:Z0JP"#6H.+EH21D(%&`(-:@XN1
MKI"K`(-:@XN77922@48`C&>1T9-DF&(`DH:)FP"/V):^CY&"S(_:C=<`C]B6
MOH^1@WR#BH-6@5L`E<^-6`"39(YQ@X&#0X.+@LF.9Y=P@K>"Z9:\D4^"QH-!
M@VB#C(-8@O"5SXU8@K6"W(*W@4(`@X&#@H+,E<""T8^'@L:57(ZF@TF#=H-6
M@X>#DX+PE<^-6(*W@NF!0@"#<(-8@X^!6X-H@O"129'P`(.&@5N#59:\@O"1
M29'P`)/ZE7257(ZFC&".KH%&`(I4EW:57(ZF@L6"S)6JE]Z"\)%)D?""M8+$
MB;J"LX*B@4(`@V:#=(-(@XN#9X+,@X&#@I*@@O"129'P@K6"Q(FZ@K."HH%"
M`(-.@XF#6)+HBV`@)7,@@JJ,J95T@JF"Z(+<@KF"\8%"`)/\E\V.YH_!@K4`
M@X:!6X-5@LR1WHN.@48E<P"#AH%;@U6/P8N.`(-.@XJ#8H-.@K>"Z8+&CI^"
MU@"#18-"@Y.#:(-%@O"5PH*V@ND`D$8`D$:129'P`)!&D4F1\`"7\8%&`)?Q
M@UZ#0X-G@XL`@U*#?H-B@TZ#6`"#4H-]@Y.#:`"#4H-]@Y.#:(-6@T:#BP"#
M4H.!@Y.#9P"+I)+*EKP`B>^.T`"0W9+H@LR-MY6J`"5S((+PD-V2Z(*W@ND`
M@W"#6(./@5N#:(+PBFV41@"0VI&QCKB4<X%"`(SVCT^,KH-4@5N#;X+6@LR0
MVI&Q@JJ+D93;@K."ZH+<@K6"O8%"`(SVBDJ,KH-4@5N#;X+6@LR0VI&Q@JJ+
MD93;@K."ZH+<@K6"O8%"EYV74H%&)7,@*"5S*0!&5%"#5(%;@V^"UH+,D-J1
ML8+)CKB4<X*U@MR"M8*]@4(`F$&7C9#F@LV#08-H@XR#6)*@@LF2QXG!@K."
MZH+<@K6"O8%"`(-2@W.!6P"#4H-S@5L`@X&#8H-:@5N#5X+,(%!'4""(PXV&
MB;N"JH+%@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@4$=0((^0EKR"
MJH+%@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@4R]-24U%((C#C8:)
MNX*J@L6"JX+<@KF"\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!3+TU)344@CY"6
MO(*J@L6"JX+<@KF"\8+%@K6"O8%"`)A!EXV0YH+PDL>)P8+%@JN"W(*Y@O&"
MQ8*U@KV!0B5S`$Q$05`@@U2!6X-O@LF#;X-#@Y.#:(+%@JN"W(*Y@O&"Q8*U
M@KV!0@".8XV"@JJ*;91&@L6"JX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#
M6(-G@JJ-[)"L@L6"JX+<@KF"\8+%@K6"O8%")7,`4$=0((-F@5N#7H+,E9R-
MAHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(`4R]-24U%((-F@5N#7H+,E9R-AHF[
M@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(`F$&7C9#F@JJ-[8^<@L6"JX+<@KF"\8+%
M@K6"O8%")7,`D9>039#F@XJ#6(-G@JJ-[8^<@L6"JX+<@KF"\8+%@K6"O8%"
M)7,`CO.038[2@LR39(YQ@X&!6X.+@T&#:(.,@UB"JHIMDNB"Q8*K@MR"N8+Q
M@L6"M8*]@4(`@T&#:(.,@UB2H(*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%
M@K6"O8%"`)&7D$V0YH.*@UB#9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%
M@K6"O8%"`)&7D$V0YH.*@UB#9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%
M@K6"O8%"`(SVBDJ,KH+PC*Z#5(%;@V^"J8+GCN:3OH+%@JN"W(*Y@O&"Q8*U
M@KV!0@`E<R""\(-)@5N#=H.3@L6"JX+<@KF"\8+%@K6"O8%"`)7;CN>-[(O&
M@X*#5X.%@5N#BR`E<R""\(I*@J^"W(*Y@O&"Q8*U@KV!0@`E<R""JI/'@MV/
M;X*Y@MR"N8+Q@4(`@T&#:(.,@UB2H(+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!
M0B5S`)&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7
MD$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)#=DNB"\(RS
M@LF6WX*Y@MR"N8+Q@L6"M8*]@4(`)7,@D-V2Z(+PE=N1MH+%@JN"W(*Y@O&"
MQ8*U@KV!0@"0W9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"Q8*K@MR"N8+Q@L6"
MM8*]@4(`3$1!4""#5(%;@V^"JHR?C?6"Q8*K@MR"N8+Q@4(`F$&7C9#F@O"-
M6)!6@L6"JX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#6(-G@O"-6)!6@L6"
MJX+<@KF"\8+%@K6"O8%")7,`36]Z:6QL82""S(-4@T.#:(-O@5N"JHRIE72"
MJ8+H@MR"N8+Q@4*#5(-#@VB#;X%;@O"*2H*B@L2)NH*S@J*!0@"-D0"-[)"L
M`)!6BTN-[)"L`(-4@W6#=(-(@XN#7X+PC>R0K`"-[)"L@K."ZH+<@K6"O0"-
M[)"LCM*"S(-!@TZ#6H-8C*``@TZ#C(-7@V*#9X-*@5N#:)34C88`C+N-W8+,
MCIZ*U``E<R""UH+,@XV#3X-)@Y..GH+)CL"-<X*W@NF#7H-8@TZ"\)#=DNB"
MM8+<@K>!0@"0V(+HCN:"Z`"0V(+HCN:"Z`"3^@"6B)/Z`$1A=&%4<F5E((E[
MEY<`@V:!6X->CO.030!?3)?Q@LR-[8^<`#$RC(X`CUR0:9"4`))IB;J"L(+P
MD/."K0"#9H-T@TB#BX-GD$8`@V:#=(-(@XN#9R!)1`"#9H-T@TB#BX-G@LR#
M@8."DJ``@V:#=(-(@XN#9X+,E<""T8KNCX"!1@"#9H-T@TB#BX-G@LR5P(+1
ME?N,_(%&`(WMCYP`@T^#BX%;@W:"\(WMCYP`@T&#3H-:@UB,H(WMCYP`@UJ#
MBXWMCYP`E_&"S(WMCYP`D>.1UH-E@Y.#=H.,@5N#9X+,C>V/G`"-<X+,C>V/
MG`"129'P@K6"O4E$@O"-[8^<`(R[C=V(RI)U@LR7\8+PC>V/G`",NXW=B,J2
M=8+,C7."\(WMCYP`E'J1EXZ>BM0`C7Z/AP"/X8I1D^"798+,D."6O@"0X):^
M`)#@EKZ!1@"/VHW7@JJ*QY>=CM*"S(*]@M^"R8M,F%Z"LX+J@MR"M8*]@4(`
MBDJ4K0"-MH*I@N>)18+6`(E%@JF"YXVV@M8`,C2.GHK4E5R.I@"57(ZF@TF#
M=H-6@X>#DP"-[8^<@K6"R(*B`&UA:6YT96YA;F-E+G!H<"""R9*\D-J#08-.
M@UJ#6(*U@LB"HH+%@JV"OH*S@J(`C<6/B8+,E_&"JH-T@T*!6X.+@VB6O(+P
MBMR"\8+%@J*"W(*W@JD_((*[@J2"R(+G@V"#1H-B@TZ"M8+$@JV"OH*S@J(N
M`(-?@T6#DX.-@5N#:``E<R""S(-?@T6#DX.-@5N#:`"0MI"L@K6"O9#=DNB"
M\"!02%`@@UB#3H.*@W:#9X+P@L:"M8+$@U^#18.3@XV!6X-H@K>"Z8%"`)-D
MCG&#@8%;@XL`E=*/5P"#=8.-@V*#3H+,E=*/5P"#3X.+@5N#=H+,E=*/5P"#
M@8."@LR5TH]7`(-!@TZ#6H-8C*""S)72CU<`@T&#3H-:@UB,H(+,E=*/5P`E
M<R""S(-!@TZ#6H-8C*""S)72CU<`@TF#=H-6@X>#DX+,E=*/5X%&`"5S((+,
M@T&#3H-:@UB,H(+,E=*/5P"39(YQ@X&!6X.+`$6#@8%;@XN#08-H@XR#6`!%
M@X&!6X.+@T&#:(.,@UB"JHCJDG:"M8+(@J^"ZH+.@J*"KX+<@KF"\8%"`(OS
M@LR#@8."`(OS@X&#8H-:@5N#5X+%@K>!0@")O8+@C*F"PH*I@NB"W(*Y@O&!
M0@"#38.#@XF#BH%;@JF"YXGFD9R"\)%]D_R"Q8*K@NF"YH*D@LF"M8+<@K>"
MJ8%(`(E%@TZ#BH-B@TZ"Q8.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2`"#1X-F
M@T*#7H%;B>:6RH+PD>6"JX*M`(-'@XF!6P"#@8%;@XN#08-H@XR#6(+,@T>#
MB8%;@L6"MX%"`#$UE:J6B``RE:J6B``S,)6JEH@`-96JEH@`@XV#3X-#@Y.6
MB``S,)6JEH@`,96JEH@`CG>2Z))L@LR7X0".P(US`)-7BDH`ETR,^(KZC,``
MCG>0E`"#1X-.@UB#?(%;@V<`@X&#@H+,@T>#3H-8@WR!6X-G`)%/C&F01@"0
MW9+H@O`@1E10((+%@T&#8H-V@XV!6X-H@K>"Z0!?59%3E;8`@W:#C(-T@T"#
MC(.3@UB0W9+H@O".YI.^@L6"JX+<@KF"\8%"`$Q$05`@@U2!6X-O@LF0VI&Q
M@L6"JX+<@KF"\8+%@K6"O8%"`%--0B"#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q
M@L6"M8*]@4(`(B5S(B""J8+G@LR#4H-S@5N"R8ZXE'."M8+<@K6"O8%"`"(E
M<R(@@M:"S(-2@W.!6X+)CKB4<X*U@MR"M8*]@4(`D%:+2X+,(%-!4TP@D-J1
ML8+)CKB4<X*U@MR"M8*]@4(`(B5S(B""UH+,B-J3KH+)CKB4<X*U@MR"M8*]
M@4(`@E&,C@"#=(-`@T.#BY"4.B`E<R"#=(-`@T.#BP"#=(-`@T.#BY"4.B`E
M<R"#=(-`@T.#BP"#=(-`@T.#BX-]@VR!6X-7@X,`@W2#0(-#@XN6O`"#=(-`
M@T.#BY%)D?``@W2#0(-#@XN#08-B@W:#C8%;@V@`@W2#0(-#@XN#08-B@W:#
MC8%;@VB"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!0@"#=(-"@XN#7@"5MHZ:
MD$8`@W2#2(%;@X``@W2#2(%;@XF#@`"+X`"89P"/VH*U@J*0X):^`(Z!EKP`
M)7,@C5R0K(_NE?&"\)"VD*R"MX+I`)"VD*R"LX+J@KV#4H%;@V@`D*D`@T^#
MBX%;@W:*QY>=`(-/@XN!6X-VEKR"S8OSE)*"Q8+-@LB"HH*Q@L8`@T^#BX%;
M@W8`@U&#6(-G@T&#3H-:@UB,H`"#48-8@V>#=8-B@TX`2%144""41H_8@JJ"
MW8+"@JF"Z(+<@KF"\8%"`(-N@V*#5H.%@T&#BX-3@XJ#68.``(-W@V*#7P"-
M@H*S`(-W@XN#=@"#>H%;@X``CJF1[H+,CUJ/B@".J9'N@LR39)ABE-2-A@!(
M;W)D90")H9#\`(*B@JV"PH+,E_&"\(R+C8>"M8+<@K>"J8%(`(-T@T*!6X.+
M@V@HC7,I@LR0E(+-@J*"K8+"@L6"MX*I@4@`@J*"K8+"@LR-<X+PC(N-AX*U
M@MR"MX*I@4@`24U!4""#@8%;@XN#>X-B@TZ#6(+,C>R0K(+)CKB4<X*U@MR"
MM8*].B`E<P!)34%0((.!@5N#BX-[@V*#3H-8@LR-[8^<@LF.N)1S@K6"W(*U
M@KTZ("5S`$E-05`@@X&!6X.+@WN#8H-.@UB#3H-(@5N#7H+,C>R0K(+)CKB4
M<X*U@MR"M8*].B`E<P!)4(-!@VB#C(-8@JJ+EHG"@K."ZH*]0TE$4H-U@XV#
M8H-.D^""R8*@@NB"W(*Y@O&!0@!)4)65C;V(X92]@L6"MX%"`(-!@T.#4H.3
M@LR"W0"#08-#@U*#DX+&@V6#3(-8@V<`242"S):\D4\`@N""M8+@D+."M8*M
ME5R.IH*S@NJ"R(*B@LB"YX%!)7,@@K6"Q)!6@K6"HH-%@T.#DX-H@5N"\(I*
M@J*"Q(FZ@K."HH%"`(+@@K6"X"!);G1E<FYE="!%>'!L;W)E<B""\(YG@L&"
MQ(*B@L2!08-!@T.#4H.3@JJ57(ZF@K."ZH+(@J*"R(+G@4&"L8*Q@O"129'P
M@K6"Q(FZ@K."HH%"`(GFD9R#=H.,@W*#A8%;`(GFD9P@55),`(GFD9P@55),
M.@")YI&<`(.!@X*"S(-#@Y.#?(%;@V>!08-8@V6#8H-V("5D`(-#@Y.#?(%;
M@V>!08-8@V6#8H-V("5D`(.!@X*"S(-#@Y.#?(%;@V>!7H-'@TZ#6(-\@5N#
M9P"#0X.3@WR!6X-G@K."ZH*]@W2#0H%;@XN#:(%&("5S`(-#@Y.#?(%;@V>"
MLX+J@KV#=(-"@5N#BX-H@48`BM2(X8+!@KV#08-.@U:#AX.3@U*!6X-H@JJ7
M7H*F@N>"ZH+$@J*"W(*W@4(`@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI"S@K6"
MK8*@@NB"W(*Y@O&!0@"2:8FZ@K""\)!;@JT`C,*5RH.&@5N#50"#0X.3@W2#
M2(.!@5N#5H.'@Y,`7T^,XX+K@LF7\8+PD7V3_`")YI&<@O"1?9/\`)5<@O"1
M?9/\`(.*@Y.#3H+PD7V3_`!?0Y%/@LF7\8+PD7V3_`",NXW=B,J2=8+,C.."
MZX+)E_&"\)%]D_P`C+N-W8C*DG6"S)%/@LF7\8+PD7V3_`",NXW=B,J2=8+,
MC.."ZX+)C7."\)%]D_P`C+N-W8C*DG6"S)%/@LF-<X+PD7V3_`",NXW=B,J2
M=8+,C.."ZX+)DFF7CH+PD7V3_`",NXW=B,J2=8+,D4^"R9)IEXZ"\)%]D_P`
MD>.1UH-E@Y.#=H.,@5N#9X+,D7V3_`",XX+K@LF#6H.+@O"1?9/\`)%/@LF#
M6H.+@O"1?9/\`(SC@NN"R9?Q@O"1?9/\`)%/@LF#6H.+@O"1?9/\`(SC@NN"
MR9)IEXZ"\)%]D_P`D4^"R9)IEXZ"\)%]D_P`C.."ZX+)C7."\)%]D_P`D4^"
MR8US@O"1?9/\`(GFD9R"S)%]D_R!7I7/C5@`@XJ#DX-.@LR1?9/\@5Z5SXU8
M`)&7D$V0YH+)D9>"Z8*]@M^"S(YCC8*"JI5SD:N"M8+$@J*"W(*W@4(`CF.-
M@H*JE7.1JX+%@K>!0@"5<Y"S@LB#08-V@XJ#4(%;@U:#AX.3@L6"MX%"`):S
MC/B"R(-F@5N#7H*JDO&/;X*S@NJ"W(*U@KTN`)&7@NB0YH+,@T&#:(.,@UB"
MJI5SD+."Q8*W@4(`C^.(RH+,@T&#3H-:@UB,H(*JE7.0LX+%@K>!0@",LX+,
M@T&#:(.,@UB"JI5SD+."Q8*W@4(`E7.0LX+(=6YI8V]D98-F@5N#7H+%@K>!
M0@"4K8USCM(`CLZ1S`""4(R.`()6C(X`@E6,C@"1M8*F@ND`DH:)FY&U@J8`
ME[R26Y&U@J8`C;:1M8*F`(E%D;6"I@!+97)B97)O<R"#5(%;@V^"JI1&C]B+
MD93;@K6"W(*U@KV!0@",KHWLD*R3^@",KHYWEN0`C*Z2MP",KH[ME]X`DV2.
M<8RN@JJ"MX+%@LF,]H]/C*Z#5(%;@V^"R9&VC=V"M8+<@K>!0@",OHSJ`(W%
MCTF5SXU8D_H`D4^)\8+,@XV#3X-#@Y,Z("5S`)%/B?&"S(.-@T^#0X.3.B`E
M,B1S((*I@N<@)3$D<P"13XGQ@LR#C8-/@T.#DSH@@LB"M0"#C(-#@T&#18-G
M`(-F@5N#7H-X@5N#6(CJEY<`@W>#BX-VC8"6VH+PE5R.IH*W@ND`E5R"S(CJ
MEY<`@X:!6X-5@LR#BH-8@V>"S9:SC/B"R8+(@L&"Q(*B@MR"MX%"`))NB.:"
MQHZ>BM0`C^J/B@"#C8-/@T.#DP"#C8-/@T&#18-G`(.-@T^#0X.3((->@UB#
M3@"#AH%;@U66O(*I@W"#6(./@5N#:(*JD+."M8*M@LB"HH*]@M^"R8.-@T^#
M0X.3@LF.N)1S@K6"W(*U@KV!0@"#C8-/@T.#DX+)CKB4<X*U@MR"M8*]@4(`
M@TV#BH-6@X.5MHZ:@6F/K)6VCIJ!:@"#B8-E@Y.5MHZ:@6F/K)6VCIJ!:@"#
MC8%;@WV0E(Z:@6F/K)6VCIJ!:@",C@"3695T@K."ZH*]($U3+51.148@@LV#
M9H%;@UZ"\(K<@O&"Q8*B@MR"N8+Q@4(`DV2.<8.!@5N#BP"01I5T@J^"LX+J
M@KV#B8-X@XN"\)'.B9Z"LX*Y@L25JI?>@O"*QY>=@K6"W(*W@4(`@E*,C@"#
M=(-"@5N#BX-H@O"(ZI)V@K."N8+$@J*"W(*W`()4C(X`@X&#DX-O`(.!@X*"
MS)/@EV4`@X&#:H.%@5N#@H%;@V@`@UJ#BXR+C8<`EGN5M@"#@8-B@UJ!6X-7
M@LV,GX_8@L6"JX+<@K6"O8*J@4&/D):\CM*"S)!GC+."S8R?C]B"Q8*K@MR"
MN8+Q@L6"M8*]@4(`@X&#7(-B@V@`36EM92!4>7!E`)#=DNB"JH*@@NB"W(*Y
M@O&!0H*Q@LR#08-V@XJ#4(%;@U:#AX.3@O".9Y=P@K>"Z8*]@M^"R8+-D-V2
MZ(+PC>R0K(*W@NF52Y=V@JJ"H(+H@MR"MX%"`(R.`(QGD=&#@8%;@XL`CT.0
MLY/Z`"5S()7/C5B2A@"6B(R.`(FZ@M8`C;:"U@")18+6`(_C@M8`B;J"U@"/
MXX+6`(-!@TJ#18.3@V<`CH2"S(.!@X(`DZ^(TX*U@MR"N8+Q`):\D4\`@VR#
M8H-G@X^!6X-.`(+(@K4`D%:+2Y6JE]X`D%:+2X.!@X(`D%:"M8*B@X:!6X-5
MEKPHE$.(TRD`CI\`C;>5JH+PE5R.IH*W@NF"O8+?@LR0W9+H@JJ"H(+H@MR"
MN8+Q@4(`E<^-6(+(@K6!0@""L8+,@T&#3H-:@UB,H(+)@LV#5(-U@T&#3H-:
M@UB,H(+-DL>)P8+%@JN"W(*Y@O&!0@!&5%`@5D93((+,C5R0K(_NE?&"JHYW
MDNB"LX+J@L2"HH+<@KF"\8%"`%-13"!61E,@@LR-7)"LC^Z5\8*JCG>2Z(*S
M@NJ"Q(*B@MR"N8+Q@4(`4U%,((-*@V6#4X.*@LR-7)"LC^Z5\8*JCG>2Z(*S
M@NJ"Q(*B@MR"N8+Q@4(`CF.-@H*J@J""Z(+<@KF"\8%"`)&7D$V0YH*JCG>2
MZ(*S@NJ"Q(*B@MR"N8+Q@4(`@X&#8H-:@5N#5X*JCG>2Z(*S@NJ"Q(*B@MR"
MN8+Q@4(`EKR13X*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`@U&#6(-GEW""S(.!
M@X*2H(+-@J""Z(+<@KF"\8%"`(.!@X*"R(*U`(R[C=V"S(KNCX""R8CJDG:"
MMX+I@X&#@H+-@J""Z(+<@KF"\8%"`)5<CJ:"MX+I@X&#@H+-@J""Z(+<@KF"
M\8%"`)34C8:"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`$A45%`@E$:/V(+,@W"#
M6(./@5N#:(*J@J""Z(+<@KF"\8%"`$E-05`@E$:/V(+,@W"#6(./@5N#:(*J
M@J""Z(+<@KF"\8%"`$ME<F)E<F]S()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"
MW(*Y@O&!0@"#C8-/@T.#DR"41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q
M@4(`4$%34U=$()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@!334(@
ME$:/V(+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`$]P96Y34TP@
M@W:#C8-/@XF#@(+,@W"#6(*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4)/<&5N4U-,
M((+-(%!+0U,@,3(@@LR#9H%;@UZ"\(BU@J2"S(+)E4N7=H+%@K>!0@"5VY>O
M@LR#5(-#@Y.#08-B@W:"R(*U@4(`@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI&7
M@N>"ZH+<@KF"\8+%@K6"O8%"`):SC/B"S%A-3(-F@5N#7H*JE=2"Z(+<@K6"
MO0"2;(+(@K4`C+."S)#=DNB"R8-O@5N#5X.'@Y."JH*@@NB"W(*Y@O&!0HW$
MDWB0W9+H@O"0MI"L@K6"W(*W@4(`@J""R(*]@LR0W9+H@LF#;X%;@U>#AX.3
M@JJ"H(+H@MR"N8+Q@4*-Q)-XD-V2Z(+PD+:0K(*U@MR"MX%"`%]4@X&#@@""
MR(*U`(*Q@NJ"YH+HD4\`@K&"ZH+F@NB,XP"#@8."@LR5JI?>`(.!@X*"S(_:
MC=<`@X&#@HCJEY<`@X&#@H+,D^"790!?5(.!@X*"S)/@EV4`@X&#@H*JC*F5
M=(*I@NB"W(*Y@O&!0@!?4(.!@X*2H`"#@8."DJ""S):\D4^!1@"#@8."DJ``
M@X&#@I*@@LF"S9:\D4^"JI5+EW:"Q8*W@4(`@VV!6X-G`(.!@X**5)=V`#$Q
MC(X`D9>039#F@XJ#6(-G@O"-6)!6@KV"WX+,E-2-AH*JCG>2Z(*S@NJ"W(*Y
M@O&"Q8*U@KV!0@!/2P"#28-U@U>#1H-.@V<`@TF#=8-7@T:#3H-GC>R0K([2
M`#$PC(X`@TF#=(-"@U@`BZ273(-T@TB#BX-?@LT@24U!4""#5(%;@V^"OH*O
M@JJ#5(-\@5N#9X+%@JN"W(*W@4(`DV2.<8.!@5N#BX-!@VB#C(-8@LTQ@L*"
MOH*OCG>2Z(+%@JN"W(*W@4(`CXJ73([2@JF#5H-8@V6#@(K'EYV.TH*^@J^"
MJHNDETR"S(^*ETR,H(+&@T&#3H-:@UB,H(+PE<^-6(+%@JN"W(*W`)!6BTN#
M18-#@Y.#:(%;@LF57(ZF`$]P96Y34TP@@T>#B8%;@493+TU)344@CY"6O(*S
M@NJ"O8-P@5N#9X*I@N>#9H%;@UZ"\([F@NB/;X*Y@MR"N8+Q@L6"M8*]@4(`
M@TF#=H-6@X>#DP`E<R"#28-V@U:#AX.3`(^'CYB5=(.*@UB#9P"19Y!$`)64
MCY``D*Z7G0",LX+,@T&#=H.*@U"!6X-6@X>#DX-E@Y.#=H.,@5N#9P"1O(+,
M@T.#DX-T@TB#@8%;@U:#AX.3`(*[@LR1O(+,@TF#=H-6@X>#DP"/BI=,CM*"
MS(-!@TZ#6H-8C*``4$%-()1&C]B"S8YGEW""Q8*K@MR"N8+Q@4(`4$=0()-D
MCG&/D):\`%!'4""(PXV&E;8`4$=0((SVBDJ,K@!01U`@CY"6O(W/+XC#C8:)
MNX-F@5N#7@!02%"#4H%;@V@`4$A0@U:#1H.+`):$D9``@W"#6(./@5N#:`"#
M<(-8@X^!6X-H@JJ0LX*U@JV"H(+H@MR"N8+Q`%)!1$E54R"41H_8@LR#<(-8
M@X^!6X-H@JJ52Y=V@L6"MX%"`(-P@UB#CX%;@VB"S(IME$8`@W"#6(./@5N#
M:#H`@W"#6(./@5N#:#H@`(-P@UB#CX%;@VB"JHCJDG:"M8+<@KF"\8%"`)-<
M@NB5=(*O`)-<@NB5=(*O`)7;EZ^2AH+,@U2#0X.3@T&#8H-V@48`@W"!6X-:
M@Y.#9P"5VX[GD8"-[(+PCL"-<X*W@ND`@XV#3X-#@Y..GH+)E=N.YY&`C>R"
M\([`C7."M8+<@K>"J8%(`(-!@TZ#6H-8C*``@T&#3H-:@UB+D93;`(-!@TZ#
M6H-8C*``@T&#3H-:@UB,H(+,BL>7G0",PI!LC^Z5\0"39)AB`(-S@TZ#6H.+
M`(R.@L:43H+PD_R7S8*U@L2"K8*^@K."HH%"`)!6@K6"HI6JE]Z"S):\D4^"
M\)/\E\V"M8+$B;J"LX*B.@"0LX*U@J*3^I5T@O"3_)?-@K6"Q(*M@KZ"LX*B
M+B",CH+,D_J0E(+P@V"#1H-B@TZ"M8+$@JV"OH*S@J*!0@"/X8I1D^"798+P
MEW:6\8*U@L2"LHM,D_R"K8*^@K."HH%"`(.&@5N#59:\@L:#<(-8@X^!6X-H
M@O"3_)?-@K6"Q(*M@KZ"LX*B@4(`DXJ56Y"4`%!R969S7VQD87`Z()5+EW:"
MR$Q$05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!0<F5F<U]L9&%P.B"5
M2Y=V@LAS97-S:6]NBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`@W:#C(-R
M@X6!6P"05H*U@J*#18-#@Y.#:(%;@LF)YI&<@O"57(ZF`(CSC?P`E.F6IXRN
M`(_ABE$`C^&*49/@EV6"S)#@EKX`C/:*2HRN`(SVCT^,KH-!@XN#4X.*@UF#
M@`",]H]/C*XOE.F6IXRN@JJ0MI"L@L6"JX+<@KF"\8+%@K6"O8%"`(-.@T>#
MBH%;`%)308SVCT^,KB@E9(-R@V*#9RD`E.0`D\>"W@"6>Y.6@LD@)7,@@O"-
M[8^<@K6"W(*W@JD_((*Q@LR1@(WL@LV,LX+)EM^"N8+<@KF"\8%"`)9[DY:"
MR8.&@5N#52`E<R""S(-F@5N#7H+PC>V/G(*U@MR"MX*I@4@@@K&"S)&`C>R"
MS8[F@NB/P8*Y@MR"N8+Q@4(`@N*"Z)*\@K<`DZZ328.!@VJ#A8%;@LR-Q)5<
MCJ:*U(IU.@"-Q)5<CJ8`@WR!6X->@XN"S(W$E5R.I@"#BH."@5N#9X-4@5N#
M<H-8`(.*@X*!6X-G55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H@`(WMCYP`@W6#C8-B@TZ"\(WMCYP`E:J7WH+,C>V/G`"#>8-!@O"-[8^<
M`(.&@5N#58+PC>V/G`"#AH%;@U6"\(WMCYPZ("5S`)=VBX&"R974DYJ"Q8*K
M@MR"N8+Q.B``@XJ#6H-B@V<`C(N)R@"#28-V@U:#AX.3@LF6WX+I`(RS@LR-
M7)"L@LF6WX*W`(-E@TR#6(-G@T>#9H-"@UZ!6X+,@TF#=H-6@X>#DP"6\(J$
M`(USD:Z0JP"-<Y&ND*L`C7.!1@".P(US`%,O34E-12"(PXV&CY"6O`!3+TU)
M344@B,.-AI6V`%-!4TP@E$:/V(+-CF>7<(+%@JN"W(*Y@O&!0@!344P@@U:#
M1H.+`%-32`"3>0"5VY&V`"5S((+PE=N1M@"#28-V@U:#AX.3@O"5VY&V`"5S
M()#=DNB"\)7;D;:"M8+<@K6"O8%"`(R?C?4`C)^-]8R+B<H`C)^-]93-B,T`
M7U2,GXWUE;:.FI?Q`)/ZE72"\(YWDNB"M8+$@JV"OH*S@J*!1@"2QXG!@K>"
MZ8-/@XN!6X-V@O"129'P@K6"Q(*M@KZ"LX*B`)!6@K6"HH^*CIV.TH+PD4F1
M\(*U@L2"K8*^@K."H@"#@8."DJ""S)%)D?``@U2!6X-O@O"129'P@K6"Q(*M
M@KZ"LX*B`)+'B<&"MX+I@X:!6X-5@O"129'P@K6"Q(*M@KZ"LX*B`)5+EW:"
MR)6VCIJ"\(FZ@LR#>X-B@TZ#6(*I@N>128+Q@L6#4H-S@5N"MX+I@L:!08-E
M@TR#6(-G@T>#BH-!@M:#>8%;@UB#9X+%@JN"W(*W@4(`D_J5=(+,B^:0V(+H
ME;:.FH+PCG>2Z(*U@L2"K8*^@K."HH%&`)/ZE72"S(Q@CJZ"\(YWDNB"M8+$
M@JV"OH*S@J*!1@"#1X-.@UB#?(%;@V>"S(Q@CJZ"\)%)D?"!1@"#0X.3@WR!
M6X-G@K>"Z8-T@T"#0X.+@O"129'P@48`@UR!6X-8@W2#0(-#@XN"S(Q@CJZ"
M\)%)D?"!1@"5SXU8@K6"O8*B242"\)%)D?`Z`(Z>C8^"S(OFD-B"Z)6VCIJ"
M\(YWDNB"M8+$@JV"OH*S@J*!1@".GHV/@LR,8(ZN@O".=Y+H@K6"Q(*M@KZ"
MLX*B@48`B.J2=H*W@NF"48+"@LR#=(-"@5N#BX-H@O"128+Q@L6"K8*^@K."
MHH%"`)!&DK*"\)%)D?""M8+$@JV"OH*S@J(N`(R^C.J"\)%)D?""M8+$@JV"
MOH*S@J(Z`)%)D?""LX+J@KV5JI?>@48`C^&*48.,@WR!6X-G@O"1EY!-@K>"
MZ0!335,@D9>030""6(R.`)+*E-0`@WR!6X->@XN"Q8-!@TZ#6H-8@K>"Z8.*
M@X*!6X-G@U2!6X-O@O"0W9+H@K6"W(*W@4(`C+Z,ZH%!CIZ*U)'1@4&3^I5T
M@O"0W9+H@K6"W(*W@4(`BDJ.;HZ>@LR#08-V@XJ#4(%;@U:#AX.3@4&01I*R
M@4&#>8%;@U>-Q)5<CJ:!08*[@LR1O(+,E5R.IH-)@W:#5H.'@Y."\)%)D?""
MM8+$@JV"OH*S@J(N`(K(DE""R)=VEO&!1@"!:8.!@VJ#A8%;@LB"QX+%@6J#
M5H.'@5N#9X-*@V*#9X-,@5N"JHYG@J:"Z8+F@J2"R8*U@MR"MX*I@4@`E5R.
MI@"3KHWL@WN#7H.3@O"57(ZF@4@`@XV#3X-#@Y..GH+)D4^)\8+,@XV#3X-#
M@Y..GHK4@O"57(ZF@K6"W(*W@JF!2`"#@8."DJ""S):\D4^"\)5<CJ:!2`""
ML8+,E:J7WH+,@X&#@H+PE5R.I@"57)&`C>R#@8-J@X6!6X+PE5R.IH*U@MR"
MMX*I@4@`B>:6RHVV@LD@)7,@@X&#:H.%@5N"\)5<CJ:"M8+<@K>"J8%(`(]K
MCZP`@MR"N)?7@NB"S(-U@XV#8H-.@O"/:X^L@MR"O8+-B-J3KH*S@KF"Q(*M
M@KZ"LX*B@4(`@U2#0X.3@T&#8H-V`)-DCG&/D):\`)-DCG&/D):\@T&#BX-3
M@XJ#68.``(-4@T.#60"5VX[G@O"#6(-,@V*#=H*W@ND`E:J7WH+%E<""T9'6
M@J8`D^"798+%E<""T9'6@J8`D9>038RS@T&#:(.,@U@`EUV4D@"77922@L:6
MA)&0`)/!CNJ5MHZ:@LR3_)?-`(]"@MR"O8+-C*<`C_.1U`"/6H^*E-22;@".
MYH_!@K60_`"#6(->@T.#BR!;0U-370"3^@".P(US`(FZE72"JP"0K(SW`"5S
M((+-CY&"JXV>@MR"ZH+<@K6"O0"*5)=V`(_CE72"JP"0J0!44U:#=(-`@T.#
MBP"57`"57)&ND*L`E5R1KI"K`(->@UB#3@"39)ABE-2-A@"#98-,@UB#9X+,
M@MT`E;:.FI1ZDG4`EM@`@K*7F)=P@J""Z(*J@L:"I(*R@K2"HH+<@K6"O8%"
M`$944""*9Y*C@JJ"H(+H@MR"N8+Q@4(`36%I;G1E;F%N8V4@@TZ#B8-8@LR3
MQXV>@MV"JI"SC^V"R8US@J:"W(*Y@O&"Q8*U@KT`@TF#=H-6@X>#DX-%@T*#
MDX-H@T6"\)7"@K:"W(*U@KV!0H])E[F"M8+<@K>!0@"#08-.@UJ#6(R@@O"7
M3(SX@LF"MX+I@LF"S8K'EYV.TH*J@KN"S(-O@V*#3H-'@Y.#:(+PD-V2Z(*W
M@NF"L8+&@JJ52Y=V@L6"MX%"`)A!EXV0YDE$E-2-AH*JCG>2Z(*S@NJ"R(*I
M@L&"O8*I@4&+\X*^@L&"O8*I@4&"H(+I@J*"S8-F@5N#7H-X@5N#6)*&@LF,
MJ95T@JF"Z(+<@KF"\8+%@K6"O8%"`)-DCG&/D):\@K."ZH*]@X&#8H-:@5N#
M5X+PC)^/V(*W@NF"R8+-@4%01U`@CY"6O(*JE4N7=H+%@K>!0@"1EY!-D.9)
M1)34C8:"JHYWDNB"LX+J@LB"J8+!@KV"J8%!B_."OH+!@KV"J8%!@J""Z8*B
M@LV#9H%;@UZ#>(%;@UB2AH+)C*F5=(*I@NB"W(*Y@O&"Q8*U@KV!0@"1EY!-
MD.9)1)34C8:"JHYWDNB"LX+J@MR"N8+Q@L6"M8*]@4(`B,.-AHF[@LF"S8C`
MD5."R(-%@T:#=9#:D;&"JI5+EW:"Q8*W@4(`@W2#0(-#@XN"JH-F@5N#7H+P
MBMR"\8+%@J*"W(*Y@O&!0@"2C8C3@4D@@W2#BX-8@TZ#BH%;@Y.#@H%;@VB"
MS2!);G1E<FYE="!%>'!L;W)E<B""Q8+-EN*1Z(*JE*V0MH*W@NF"L8+&@JJ"
MH(+H@MR"MX%I@W6#B8-%@U6"S(-O@T^"Q8*W@6J!0HGFELJ"R8-3@WZ"JI5<
MCJ:"LX+J@KV"Z(%!5VEN9&]W<R""JH-.@XF#8H-6@X6"M8*]@NB"MX+I@JF"
MX(*U@NJ"W(*Y@O&!0EQN@W2#BX-8@TZ#BH%;@Y.#@H%;@VB"R8*W@NF"R(+G
M($]+((+PB9^"M8+$B;J"LX*B@4(`240@(B5S(B""S8WMCYR"LX+J@MR"M8*]
M@4(`1VYU4$<@@V^#0X-I@XJ"S(-P@UB"JB!#<GEP=%]P9W`@@TZ#B8-8@LF0
MW9+H@K."ZH+$@J*"Z95+EW:"JH*@@NB"W(*W@4(`@X&#@H+-C>V/G(*S@NJ"
MW(*U@KV!0@"#@8."("(E<R(@@LV-[)"L@L6"JX+<@KF"\8+%@K6"O8%&("5S
M`(.!@X(@(B5S(B""S8WLD*R"LX+J@MR"M8*]@4(`@X&#@B`B)7,B((+-C>V/
MG(*S@NJ"W(*U@KV!0@"#@8."("(E<R(@@LV5VY&V@K."ZH+<@K6"O8%"`$AO
M<F1E7T-R>7!T7W-M:6UE@TZ#B8-8@LF"S6]P96YS<VR#@H-7@X6!6X.+@JJ5
M2Y=V@L6"MX%"`(-V@XR#=(-`@XR#DX-8(B5S(H+-@V:!6X->@JJ#5(-#@UF0
MIXS`@O")>H*F@KV"O8+?E=N1MH+%@JN"W(*Y@O&"Q8*U@KTN`(*Q@LR#9H%;
M@UZ,7B@E<RF"\)5<CJ:"MX+I@KV"WX+,@W:#C8-/@XF#@(*J@K&"S(-6@UB#
M98.`@LF"W8+"@JF"Z(+<@KF"\8%"`(-4@5N#;R`B)7,B((+-C>V/G(*S@NJ"
MW(*U@KV!0@"#5(%;@V\@(B5S(B""S97;D;:"LX+J@MR"M8*]@4(`@T&#8H-V
M@XV!6X-H@V:!6X->@JJ2O)%/@LR#6(-E@V*#=H+%C\&.N(*U@MR"M8*]@4(`
M@T&#8H-V@XV!6X-H@V:!6X->@O"5VY&V@L6"JX+<@KF"\8+%@K6"O8%"`(-#
M@Y.#B8-#@Y.57(ZF@L6"JX+IE925JH+-@J""Z(+<@KF"\8%"`)6VCIJ0E(*J
M@K&"S(-T@T*!6X.+@VB"R9&]B=^"K(+<@K<N("5S((+,E;:.FH*JD_R7S8*S
M@NJ"Q(*B@MR"MRX@)7,@B,B)NH+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(`@W2#
M0(-#@XN#08-B@W:#C8%;@VB"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,@@LV#
M08-B@W:#C8%;@VB"LX+J@L2"HH+<@KF"\8%"`(-T@T"#0X.+@T&#8H-V@XV!
M6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S((+-@W2#0(-#@XN"S(-4@T.#
M69"GC,"2;"@E9(-O@T.#9RF"\(EZ@J:"Q(*B@MR"MX%"`(-T@T"#0X.+@T&#
M8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S((+-B.J5E(+,@MV#
M08-B@W:#C8%;@VB"LX+J@MR"M8*]@4(`F$&7C9#F@V:!6X->@LR#0X.3@WR!
M6X-GDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4(`@V:!6X->@LR#0X.3@WR!
M6X-GDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@48E<P!V3F]T92""S(-#@Y.#
M?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0@".=Y+H@K."ZH*]@T&#
M:(.,@UB2H(+,D8"-[)*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"C.."Q8W$
MDWB.P(US@K6"Q(*M@KZ"LX*B@4(`@X&#@H+,C>V/G)*&@LF#1X.)@5N"JI2M
MD+:"M8+<@K6"O8%&)7,`@X&#@H+,E=N1MI*&@LF#1X.)@5N"JI2MD+:"M8+<
M@K6"O8%&)7,`F$&7C9#F@LR/VHW7@O"-6)!6DH:"R8-'@XF!6X*JE*V0MH*U
M@MR"M8*]@4*,XX+%C<23>([`C7."M8+$@JV"OH*S@J*!0@"1EY!-D.:#BH-8
M@V>"S(U8D%:2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0HSC@L6-Q)-XCL"-
M<X*U@L2"K8*^@K."HH%"`(.!@X*"S)5<CJ:2AH+)@T>#B8%;@JJ4K9"V@K6"
MW(*U@KV!1B5S`(-'@TZ#6(-\@5N#9X*W@NF#@8."@JJ"H(+H@MR"N8+Q@4(`
M@K&"S"!)34%0((-4@5N#;X+-BZ273(-T@TB#BX-?@O"#5(-\@5N#9X*U@L2"
MHH+<@KF"\8%"`(*Q@NJ"S9=,C/B"R')A<H-!@5N#2H-#@W6"Q8+-@LB"HH+F
M@J2"Q8*W@4(`@K&"ZH+-ETR,^(+(>FEP@W2#0(-#@XN"Q8+-@LB"HH+F@J2"
MQ8*W@4(`@K&"ZH+-ETR,^(+(@TJ!6X-HE-2-AH+%@LV"R(*B@N:"I(+%@K>!
M0@""L8+,@W2#0H%;@XN#:(+-E4N0>X+%@K>!0@""L8+,@W2#0H%;@XN#:(+-
MD*Z0E(+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S9"4
MCIJ"QH-2@XV#DX+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+
M@VB"S3B0:9"4@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0@""L8+,@W2#0H%;@XN#
M:(+-@U*#DX-]@MR"O8+-B_.4DH+%B^:0V(+G@NJ"O9"ND)2"S(.*@UB#9X+%
M@LB"K8+$@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S3$VD&E21T*5
M7(M,@LR01H-2@5N#:(+(@JV"Q(+-@J*"KX+<@KF"\8%"E^$Z)R,Q,C,T868G
M+@""L8+,C&".KH+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\8%"`(*Q@LR#=(-(
M@5N#@(+-BOF"R8^(EYV"LX+J@L2"HH+<@K>!0@""L8+,@X&#8H-:@5N#5X+-
M@J""R(*]@JJ.9Y=P@K>"Z8+,@L:(V8+(@NF5MHZ:@UJ#8H-G@6DE<X%J@L6/
MD8*I@NJ"Q(*B@MR"MX%"`(*Q@LR4U(V&@LV-Q8^L@L6"X#&"Q8+(@JV"Q(+-
M@J*"KX+<@KF"\8%"`(*Q@LR#5(%;@V^"Q8+->FEP@L9G>FEP@W2#0(-#@XN"
M\)-7BDJ"Q8*K@MR"N8+Q@4(`@K&"S(-6@UB#98.`@LV(ZHZ>DTF"R9:SC/B"
MR8+(@L&"Q(*B@MR"MX%"`(*Q@LR2;(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"
MN8+Q@4(`@K&"S(-%@T*#DX-H@T6"S8-)@W:#5H.'@Y.#18-"@Y.#:(-%@JF"
MYXS$CV^"LX+J@NF52Y=V@JJ"H(+H@MR"MX%"`(->@T.#@(-6@5N#9P"#7H-#
M@V>#BP"5H9"4@LR-@);:@O"129'P@K>"Z8+)@LV!05!#@L6"S4-O;G1R;VR#
M3(-#@4%-86."R(+G0V]M;6%N9(-,@T."\(F?@K6"R(*J@N>#3H.*@V*#3H*U
M@MR"MX%"`(G.`%523`!61E,@@W2#0(-#@XL@(B5S(B""S(-!@TZ#6H-8C*""
MS97/C5B"Q8*K@MR"N8+Q@4(`5D93((-T@T"#0X.+("5S+R5S((+,@T&#3H-:
M@UB,H(+-E<^-6(+%@JN"W(*Y@O&!0@`E<R""R97/C5B"Q8*K@MR"N8+Q@4(`
M4U%,((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!0@!34TP@@L60VI&Q@L6"JX+<
M@KF"\8%"`%9&4R"#=(-`@T.#BX+P@U*#<X%;@L6"JX+<@KF"\8%"`%9&4R"#
M9H-"@XR#3H-G@XH@(B5S(B""\(WLD*R"Q8*K@MR"N8+Q@4(`5D93((-F@T*#
MC(-.@V>#BH+PC>R0K(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XN"\(WLD*R"
MQ8*K@MR"N8+Q@4(`B_."S"!61E,@@W2#0(-#@XN"\(WLD*R"Q8*K@MR"N8+Q
M@4(`@V:!6X->@O"(LX]K@L6"JX+<@KF"\8%"`"(E<R*"\(WMCYR"Q8*K@MR"
MN8+Q+B"#9H-"@XR#3H-G@XJ"JHOS@L6"S8*@@NB"W(*Y@O&!0@"-[8^<@L6"
MJX+<@KF"\2`B)7,B.B`E<P`E<X+PC>V/G(+%@JN"W(*Y@O$N((-F@T*#C(-.
M@V>#BH*JB_."Q8+-@J""Z(+<@KF"\8%"`(_8EKZ/D8+,C]J-UX*JCN:"Z(]O
M@KF"W(*Y@O$`B+./:X^1C,F#=(-`@T.#BX+PBDJ"KX+<@KF"\8%"`'9F<W)O
M;W0@@V:#0H.,@TZ#9X.*@O"3QX+?@MR"N8+Q@4(`@K&"S"!7;W)D()6VCY&"
M\)9\EO."Q8*K@MR"N8+Q@4(`B;J0_`"5SXU8@O".YH+HC\&"MP",LX+)EM^"
MMP"6HI"NEYT`E7.6O@"6LY:\`(-4@WR!6X-G@K6"Q(*B@LB"HHIGDJ..<8+%
M@K<`C5B05@`E<R""\(U8D%:"MX+I@4(`@X:!6X-5@O"-6)!6@K>"Z0"#B8-E
M@Y.5MHZ:@6F1Y96VCIJ!:@"#C8%;@WV0E(Z:@6F1Y96VCIJ!:@",NXW=@LR2
M;(+PCF>7<(%&)7,`24U34""#5(%;@V^"S(.&@5N#59:\@5Z#<(-8@X^!6X-H
M@JJ(V8+(@NF/ZHV'@LF.9Y=P@K6"W(*W@4(`@X:!6X-5BL>7G0"#AH%;@U6#
M28-V@U:#AX.3`(.&@5N#59-OF%X`@X:!6X-5EKP`@X:!6X-5EKPZ`(.&@5N#
M59:\.B``@U:#6(-E@X"2AH+,@X:!6X-5@48`BWB)R0"73(SXD*L`C)^/V(ZX
ME',@+2""L8+,@X&#8H-:@5N#5X+-B?SB@H*S@NJ"Q(*B@NF"YH*D@L6"MX%"
M`)3%`"5S((+PC*F"Z0",>(V0`)"%`):(CU0`@N:"I(*Q@KL`)7,@@LF"YH*D
M@K&"NP`E<R""LX+Q@4&"YH*D@K&"NP`E<X.-@T^#0X.3C.."QX+,@T&#=H.*
M@U"!6X-6@X>#DX+PE5R.IH*U@MR"MX*I@4@`B^:0V(+HE;:.FH+-B;V"Q8*W
M@JF!2`"(^)=PE;:.FH+-B;V"Q8*W@JF!2`""QX+,@X&#@I*@@LF2QXG!@K6"
MW(*W@JF!2`"#98-,@UB#9X-'@V:#0H->@5N"S(-V@XF#3X-#@Y."\)%)D?""
MM8+<@K>!0@"5G0"-MH+)DG6"K25S@X&#:H.%@5N"S)6=@6F.GXGQ@LR#C8-/
M@T.#DX*I@N>73(SX@6HZ`)5<@LR5G0"+SI:QD.:"S(]:CXH`B\Z6L9#F@LR3
M9)ABE-2-A@!8-3`Y=C,@BNZ6>Y"GC,``6#4P.78S((RNCF>7<)9``%@U,#EV
M,R".Y9',CM*"S)7*EKP`6#4P.78S(([ED<R.TH+,C*Z.KY7*CG$`6#4P.78S
M((IGDJ.+0)1<`)1.`)1.`):(E$X`@LV"H@"3KXC3@K6"W(*W`(VA@LV#98-,
M@UB#9X."@5N#:(+%@K>!0EL\/EV#>X->@Y."Q4=528."@5N#:(+)E<^-6(+%
M@JN"W(*W@4(`@J""R(*]@LV41H_8@K."ZH+$@J*"W(*Y@O&!0@"6O)%/@LR2
MAH+)("=<)R""QH*B@J25MHZ:@LV.9X*F@MR"N8+Q@4(`ETR,^(+(DV2.<8.!
M@5N#BX-!@VB#C(-8@L6"S8*@@NB"W(*Y@O&!0@"#0X.3@WR!6X-G@K."ZH*]
M@W2#0(-#@XN"S(-T@T*!6X.+@VB"\"5SD^""S)'.B9Z"MX+I@W2#0H%;@XN#
M:(+)@WV#8H-V@K6"Q(+<@KF"\2X`@J""R(*]@LF"S8.!@X*2H"`E<R""\)5<
MCJ:"MX+I@T&#3H-:@UB,H(*J@J""Z(+<@KF"\8%"`(.-@T^#08-%@V>"M8+<
M@K6"O2X`D+."M8*BDFR"\)/\E\V"M8+$B;J"LX*B@4(`@U2#0X.3@T&#8H-V
M@O"7F)=P@K>"Z8*]@M^"R8+-($1A=&%4<F5E((-O@V*#3H-'@Y.#:(+PD-V2
MZ(*W@NF52Y=V@JJ"H(+H@MR"MRX`C^&*48+,D^"798+PBTR/<8*U@L2"J8+G
M@4&/X8I1@XR#?(%;@V>"\)&7D$V"M8+$@JV"OH*S@J*!0@""L8*Q@LF#BH.3
M@TZ"MX+I55),@O"3_)?-@K6"Q(FZ@K."H@"-[8^<@K>"Z8.!@X*2H(+PD4F1
M\(*U@L2)NH*S@J*!0@"-[8^<@K>"Z8-4@5N#;X+PCG>2Z(*U@L2"K8*^@K."
MHH%"`(_!BXZ"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0@"-[8^<
M@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`DL>)P8*W@NF#AH%;
M@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"`(U8D%:"MX+I@X:!6X-5EKR"\(YW
MDNB"M8+$@JV"OH*S@J*!0@".P(US@K>"Z8-!@TZ#5H.'@Y."\(YWDNB"M8+$
M@JV"OH*S@J*!0@"05H*U@J*5JI?>EKR"\)/\E\V"M8+$B;J"LX*B@4(`)7,@
M@UJ#8H-6@X>#DX+,ETR,^(KZC,""JI#8@NJ"Q(*B@MR"MX%"C<2#C8-/@T.#
MDX*U@L2"K8*^@K."HH%"`)-DCG&#@8%;@XN#08-H@XR#6`""H(+(@KV"S"!&
M<F]M.B"#08-H@XR#6`""H(+(@KV"S(-#@Y.#=(-(@X&!6X-6@X>#DP"#6H-B
M@U:#AX.3("5S((+,BM2"R8*@@LB"O8+,@T&#:(.,@UB"JI7/C5B"LX+J@MR"
MM8*]@4*#6H-,@X6#BH-E@T*!6Y7;C.R"S(*]@M^"R8.-@T^#0X.3@K62O(*W
M@M>"JX+%@K>!0@""H(+(@KV"S):\D4\`@K&"S)1&C]B#;X-B@TZ#1X.3@VB"
MQ8+-@4&#AH%;@U6"S(.*@UB#9X*J@U2#?(%;@V>"LX+J@L2"HH+(@J*"J8%!
M@J""Z8*B@LV)O8+G@JF"S)>=EU*"Q8*Q@LR+0)1<@JJ6LXSX@LF"R(+!@L2"
MHH+<@K>!0@"#6H-B@U:#AX.3("5S((+,BM2"R8*@@LB"O8+,@W6#B8-%@U6"
MJI7/C5B"LX+J@MR"M8*]@4*#6H-,@X6#BH-E@T*!6Y7;C.R"S(*]@M^"R8.-
M@T^#0X.3@K62O(*W@M>"JX+%@K>!0@"#7H-#@X"#78%;@Y.!1@""H(+(@KV"
MS(-F@W2#2(.+@V=)1#H`@J""R(*]@LR#9H-T@TB#BX-G@LR#@8."DJ"!1@""
MH(+(@KV"S(Z!EKP`@J""R(*]@LR#@8."DJ"!1@"#28-V@U:#AX.3@O"-6)!6
M@K6"W(*U@KT`@XJ#@H%;@V>#5(%;@V\Z`(%MC^&*48.,@WR!6X-G@6X`6XUS
M.B5S+R5S70!?08K'EYT`7T*#@8."DJ""R9;?@ND`7T.5JI?>`%]$C>V/G`!?
M1(US@O"-[8^<`%]%E=*/5P!?1HW%CXF"S(US`%]'@T^#BX%;@W8`7TB#=X.+
M@W8`7TF)YI&<@W:#C8-P@V6#0BXN+@!?28-#@Y,O@T&#18-G`%],@X&#@HCJ
MEY<`7TR#C8-/@T.#DP!?3(.-@T^#08-%@V<`7TV#BH.3@TZ5SXU8`%]-CH2"
MS(.!@X*2H`!?3I!6BTN#@8."`%]/@TF#=H-6@X>#DP!?4(-!@TZ#6H-8C*``
M7U"(\XW\`%]2@XJ#DX-.C>V/G`!?4XR?C?4`7U.#6H-B@V>#08-B@W8`7U25
M7)&ND*L`7U6#AH%;@U4`@T&#:(.,@UB2H`"77)+HE5P`@K&"L8+P@TZ#BH-B
M@TX`@W2#0(-#@XL`@MR"OH[`D96"LX+J@L2"HH+<@KF"\0"#<(%;@UJ#DX-G
M`(-S@TZ#6H.+`(IME$:"S(*]@M^#<(-8@X^!6X-H,I-XD_R7S8*U@L2)NH*S
M@J(`EKR6LX*U`'9#87)D````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O:71?
M250O````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S0T`#`R,#`P-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VUN96UO+VQO8V%L92]I=%])5"],0U]-15-304=%4R\`````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(Q-3<S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+VET7TE4+TQ#7TU%4U-!
M1T53+VUN96UO+FUO````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$Q-S<P,P`Q,#0Q-S,V
M,C<T-``P,C,R-3$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````"M`@``'````(05``"7`P``["H```````!(.0``
M!````$DY```,````3CD```@```!;.0``"P```&0Y```H````<#D``!4```"9
M.0``"P```*\Y```=````NSD```H```#9.0``#0```.0Y```.````\CD```P`
M```!.@``#P````XZ```8````'CH```8````W.@``#@```#XZ```.````33H`
M``@```!<.@``"@```&4Z```%````<#H```D```!V.@``"0```(`Z```<````
MBCH``!X```"G.@``(````,8Z```=````YSH``!`````%.P``"@```!8[```#
M````(3L```\````E.P``"0```#4[```-````/SL```\```!-.P``#````%T[
M```/````:CL```@```!Z.P``"````(,[```1````C#L``!D```">.P``#```
M`+@[```.````Q3L```,```#4.P``!0```-@[```*````WCL``!<```#I.P``
M"@````$\```/````##P```X````</```%P```"L\```7````0SP``!,```!;
M/```#P```&\\```&````?SP```L```"&/```%0```)(\```%````J#P``#L`
M``"N/```"0```.H\```Y````]#P``"<````N/0``+````%8]```J````@ST`
M`"4```"N/0``!@```-0]```5````VST``!$```#Q/0``#P````,^```7````
M$SX```H````K/@``"````#8^```.````/SX```H```!./@``!````%D^```)
M````7CX```8```!H/@``!P```&\^```&````=SX```,```!^/@```P```((^
M```3````ACX```@```":/@``!````*,^```&````J#X``!4```"O/@``!P``
M`,4^```5````S3X```@```#C/@``#P```.P^```-````_#X```\````*/P``
M#0```!H_```&````*#\```8````O/P``5````#8_```M````BS\```0```"Y
M/P``#@```+X_```<````S3\``#<```#J/P``'````")````*````/T```!(`
M``!*0```"@```%U````/````:$```!$```!X0```#````(I````&````ET``
M``8```">0```$0```*5````%````MT````P```"]0```!0```,I````&````
MT$````<```#70```#0```-]````*````[4````P```#X0```$`````5!```(
M````%D$```0````?00``#@```"1!```?````,T$``"````!300``)0```'1!
M```'````FD$```8```"B00``#0```*E!```0````MT$```<```#(00``$P``
M`-!!```,````Y$$```X```#Q00``#P````!"```3````$$(```T````D0@``
M*````#)"```#````6T(```T```!?0@```@```&U"```0````<$(```T```"!
M0@```P```(]"```.````DT(```@```"B0@``#P```*M"```-````NT(```\`
M``#)0@``&0```-E"```:````\T(```8````.0P``#````!5#```+````(D,`
M``T````N0P``(@```#Q#```*````7T,``!@```!J0P``&0```(-#```6````
MG4,```H```"T0P``%````+]#```+````U$,```P```#@0P``"P```.U#```)
M````^4,```D````#1```%@````U$```/````)$0```T````T1```)@```$)$
M``!#````:40``"\```"M1```!````-U$```*````XD0```H```#M1```"0``
M`/A$```0`````D4``!<````310``$0```"M%```7````/44```T```!510``
M"@```&-%```%````;D4``!````!T10``#P```(5%```0````E44```\```"F
M10``#P```+9%```,````QD4```\```#310``!P```.-%```&````ZT4```P`
M``#R10``"````/]%```3````"$8```H````<1@``!````"=&```(````+$8`
M``H````U1@``#````$!&```+````348```P```!91@``!P```&9&```*````
M;D8```T```!Y1@``!0```(=&```*````C48``"8```"81@``%0```+]&```%
M````U48```<```#;1@``#````.-&```(````\$8```8```#Y1@``"`````!'
M```"````"4<```8````,1P``"0```!-'```0````'4<```D````N1P``"0``
M`#A'```9````0D<```X```!<1P```@```&M'```-````;D<``!0```!\1P``
M!@```)%'```1````F$<```8```"J1P``!````+%'```*````MD<```0```#!
M1P``!0```,9'```%````S$<``!(```#21P``"P```.5'```I````\4<``"0`
M```;2```)@```$!(```(````9T@``!(```!P2```"@```(-(```/````CD@`
M`!````">2```#@```*](```)````OD@```H```#(2```!@```--(```5````
MVD@```\```#P2```$P````!)```2````%$D``!`````G20``$0```#A)```0
M````2DD```L```!;20``%````&=)```,````?$D```P```")20``#P```)9)
M```5````IDD``"D```"\20``*@```.9)```F````$4H``"<````X2@``&0``
M`&!*```1````>DH``!(```",2@``$P```)]*```4````LTH``!8```#(2@``
M%P```-]*```0````]TH``!$````(2P``$P```!I+```4````+DL``!H```!#
M2P``"0```%Y+```&````:$L```<```!O2P``%@```'=+```$````CDL```0`
M``"32P``!P```)A+```'````H$L```@```"H2P``#0```+%+```,````OTL`
M``T```#,2P``#@```-I+```6````Z4L``!$`````3```!@```!),```$````
M&4P```H````>3```$````"E,```:````.DP```H```!53```#````&!,```/
M````;4P```@```!]3```!@```(9,```'````C4P```L```"53````P```*%,
M```3````I4P```(```"Y3```!````+Q,```*````P4P``&@```#,3```!0``
M`#5-```&````.TT```\```!"30```P```%)-```'````5DT```D```!>30``
M"P```&A-```-````=$T``!H```""30``2@```)U-```&````Z$T```8```#O
M30```@```/9-```+````^4T```@````%3@``"@````Y.```,````&4X```P`
M```F3@``"@```#-.```(````/DX```D```!'3@``$````%%.```2````8DX`
M``<```!U3@``!0```'U.```,````@TX```@```"03@``%P```)E.```$````
ML4X```H```"V3@``!````,%.```%````QDX``"P```#,3@``)````/E.```(
M````'D\``"0````G3P``$P```$Q/```3````8$\```@```!T3P``"````'U/
M```K````AD\``$4```"R3P``00```/A/```%````.E````0```!`4```!P``
M`$50```-````35````P```!;4```"@```&A0```)````<U````H```!]4```
M#P```(A0```(````F%````\```"A4```"````+%0```:````NE````4```#5
M4```#0```-M0```(````Z5```!$```#R4```#@````11```"````$U$```X`
M```640``!P```"51```&````+5$``!0````T40``'P```$E1```'````:5$`
M``X```!Q40``"@```(!1```=````BU$```4```"I40``$0```*]1```-````
MP5$``!$```#/40``"````.%1```-````ZE$```@```#X40``"0````%2```*
M````"U(``!4````64@``!0```"Q2```$````,E(``!`````W4@``!P```$A2
M```>````4%(``"@```!O4@``"@```)A2```1````HU(```L```"U4@``&@``
M`,%2```4````W%(```8```#Q4@``!@```/A2```T````_U(``#0````T4P``
M*0```&E3```I````DU,```4```"]4P``&0```,-3```9````W5,```@```#W
M4P``%P````!4```*````&%0```<````C5```(0```"M4```.````350```<`
M``!<5```$P```&14```(````>%0```4```"!5```!````(=4```*````C%0`
M``D```"75```#@```*%4```$````L%0``#(```"U5```10```.A4```,````
M+E4``!0````[50``!P```%!5```.````6%4``"H```!G50``!@```))5```,
M````F54```\```"F50``$0```+95```+````R%4```H```#450``"P```-]5
M```/````ZU4```4```#[50``#@````%6```3````$%8```<````D5@``$0``
M`"Q6```4````/E8``!@```!35@``!P```&Q6```%````=%8``!(```!Z5@``
M#@```(U6```.````G%8```4```"K5@``!0```+%6```#````MU8```T```"[
M5@```@```,E6```$````S%8```<```#15@``#````-E6``!2````YE8``!<`
M```Y5P``!@```%%7```.````6%<```X```!G5P``#````'97```,````@U<`
M`!4```"05P``$@```*97```0````N5<```\```#*5P``%````-I7``!I````
M[U<``!H```!96```%P```'18```9````C%@``!H```"F6```)0```,%8```:
M````YU@``!<````"60``&P```!I9```9````-ED``!\```!060``%````'!9
M```3````A5D```@```"960``"0```*)9```_````K%D``#<```#L60``5P``
M`"1:```?````?%H```@```"<6@``#0```*5:```M````LUH```0```#A6@``
M%````.9:```E````^UH``!(````A6P``(````#1;```?````55L``!T```!U
M6P``)0```)-;```@````N5L``"0```#:6P``!P```/];```-````!UP```P`
M```57```$````")<```,````,UP``!````!`7```$0```%%<```'````8UP`
M``0```!K7```%P```'!<```*````B%P```P```"37```"0```*!<```(````
MJEP```8```"S7````@```+I<```)````O5P```<```#'7```*````,]<```5
M````^%P```<````.70``"````!9=```'````'UT```<````G70``#@```"]=
M```)````/ET```8```!(70``"````$]=```+````6%T```<```!D70``!P``
M`&Q=```(````=%T``!````!]70``$````(Y=```'````GUT```4```"G70``
M%````*U=```+````PET```T```#.70``%P```-Q=```)````]%T```H```#^
M70``!P````E>```"````$5X``!\````47@``(P```#1>```5````6%X``"@`
M``!N7@``(@```)=>```B````NEX``"````#=7@``(0```/Y>```?````(%\`
M`"L```!`7P``)P```&Q?```I````E%\``"P```"^7P``*````.M?```F````
M%&```"L````[8```'@```&=@```B````AF````L```"I8```!P```+5@```'
M````O6````T```#%8```"P```--@```%````WV````4```#E8```"````.M@
M```#````]&````(```#X8````P```/M@```$````_V```!D````$80``"0``
M`!YA```,````*&$```<````U80``!0```#UA```:````0V$```L```!>80``
M!@```&IA```)````<6$```L```![80``%P```(=A```&````GV$``!,```"F
M80``$P```+IA```1````SF$``#(```#@80``"````!-B```)````'&(```H`
M```F8@``%````#%B```(````1F(```@```!/8@``#P```%AB```.````:&(`
M`!````!W8@``"0```(AB```)````DF(``!D```"<8@``"@```+9B```,````
MP6(```(```#.8@``$````-%B```#````XF(```<```#F8@``#0```.YB```+
M````_&(``"\````(8P``(````#AC```<````66,``"L```!V8P``!0```*)C
M```2````J&,```H```"[8P``!@```,9C```%````S6,```8```#38P```@``
M`-IC```,````W6,``#(```#J8P``&0```!UD```H````-V0``"@```!@9```
M*0```(ED```F````LV0``"4```#:9```*`````!E```2````*64``!,````\
M90``$````%!E```)````864``',```!K90``*P```-]E```7````"V8``!8`
M```C9@``%0```#IF```/````4&8```X```!@9@``%````&]F```0````A&8`
M`!,```"59@``#P```*EF```0````N68```D```#*9@``"0```-1F```'````
MWF8```L```#F9@``!0```/)F```+````^&8```<````$9P``!0````QG```4
M````$F<```X````G9P``"P```#9G```(````0F<```\```!+9P``#````%MG
M```)````:&<```@```!R9P``#````'MG```&````B&<```\```"/9P``!P``
M`)]G```4````IV<```8```"\9P``!````,-G```9````R&<```8```#B9P``
M!````.EG```)````[F<```<```#X9P``!@````!H```&````!V@```8````.
M:```(@```!5H```%````.&@```L````^:```:0$``$IH```&````M&D```H`
M``"[:0``"@```,9I```/````T6D``"@```#A:0``$`````IJ```*````&VH`
M`!X````F:@``"0```$5J```/````3VH```T```!?:@``$P```&UJ```)````
M@6H``!8```"+:@``"0```*)J```.````K&H```X```"[:@``!@```,IJ```)
M````T6H```4```#;:@``!0```.%J```&````YVH``"@```#N:@``(0```!=K
M```O````.6L``"\```!I:P``$````)EK```,````JFL```@```"W:P``%0``
M`,!K```-````UFL``!4```#D:P``&0```/IK```2````%&P``!@````G;```
M#0```$!L```/````3FP``!D```!>;```+````'AL```'````I6P```\```"M
M;```"@```+UL```,````R&P```T```#5;```'````.-L```.`````&T``!``
M```/;0``%````"!M```7````-6T``!L```!-;0``%P```&EM```2````@6T`
M``@```"4;0``#````)UM```7````JFT```8```#";0``0````,EM```)````
M"FX``#P````4;@``-````%%N```U````AFX``#````"\;@``,````.UN```&
M````'F\``!8````E;P``$@```#QO```7````3V\``!<```!G;P``!@```']O
M```(````AF\``!,```"/;P``#@```*-O```)````LF\```D```"\;P``!P``
M`,9O```'````SF\```4```#6;P```P```-QO```#````X&\``!D```#D;P``
M"@```/YO```%````"7````@````/<```'````!AP```'````-7```!4````]
M<```"0```%-P```5````77````\```!S<```%0```(-P```-````F7````8`
M``"G<```"````*YP``!T````MW```#P````L<0``!````&EQ```1````;G$`
M`"0```"`<0``.````*5Q```:````WG$```L```#Y<0``$@````5R```.````
M&'(``",````G<@``%0```$MR```2````87(```8```!T<@``!@```'MR```2
M````@G(```8```"5<@``$````)QR```(````K7(```@```"V<@``!P```+]R
M```0````QW(```H```#8<@``#````.-R```1````\'(```@````"<P``!0``
M``MS```2````$7,``"@````D<P``*0```$US```\````=W,```4```"T<P``
M!````+IS```4````OW,``!````#4<P``!@```.5S```4````[',```L````!
M=```$`````UT```-````'G0``!0````L=```#0```$%T```U````3W0```8`
M``"%=```$````(QT```"````G70``!````"@=```#0```+%T```&````OW0`
M`!````#&=```"````-=T```/````X'0``!$```#P=```&@````)U```C````
M'74``"0```!!=0``!P```&9U```-````;G4```T```!\=0``#P```(IU```7
M````FG4```L```"R=0``'@```+YU```;````W74``!@```#Y=0``"P```!)V
M```4````'G8```L````S=@``#````#]V```(````3'8``!````!5=@``"```
M`&9V```>````;W8``!H```".=@``#0```*EV```K````MW8``$X```#C=@``
M,P```#)W```(````9G<```\```!O=P``#P```']W```1````CW<``!$```"A
M=P``&````+-W```5````S'<``!@```#B=P``$@```/MW```,````#G@```8`
M```;>```#@```")X```-````,7@```\````_>```#0```$]X```-````77@`
M``L```!K>```$@```'=X```*````BG@```<```"5>```#P```)UX```)````
MK7@``"D```"W>```#@```.%X```&````\'@```@```#W>```#0````!Y```/
M````#GD``!`````>>0``#````"]Y```&````/'D```L```!#>0``#P```$]Y
M```%````7WD```L```!E>0``*@```'%Y```@````G'D```8```"]>0``"```
M`,1Y```,````S7D```@```#:>0``!0```.-Y```'````Z7D```,```#Q>0``
M!@```/5Y```$````_'D``!0````!>@``"@```!9Z```-````(7H``!D````O
M>@``#P```$EZ```%````67H```X```!?>@``%@```&YZ```&````A7H```\`
M``",>@``!P```)QZ```%````I'H```@```"J>@``!````+-Z```&````N'H`
M``4```"_>@``%P```,5Z```,````W7H``!H```#J>@``'P````5[```8````
M)7L```<````^>P``&````$9[```*````7WL```\```!J>P``$P```'I[```2
M````CGL```P```"A>P``#````*Y[```(````NWL``!X```#$>P``$0```.-[
M```7````]7L``!,````-?```$````"%\```8````,GP``!(```!+?```#```
M`%Y\```;````:WP``!4```"'?```$0```)U\```:````KWP``!@```#*?```
M,````.-\```T````%'T``"T```!)?0``,0```'=]```A````J7T``!0```#+
M?0``%0```.!]```5````]GT``!<````,?@``&````"1^```9````/7X``!,`
M``!7?@``%````&M^```;````@'X``!8```"<?@``$````+-^```*````Q'X`
M``<```#/?@``!P```-=^```8````WWX```8```#X?@``!@```/]^```,````
M!G\```@````3?P``!@```!Q_```/````(W\```T````S?P``%0```$%_```2
M````5W\``!@```!J?P``$P```(-_```'````EW\```@```"??P``#P```*A_
M```=````N'\``"H```#6?P``"@````&````,````#(````P````9@```!0``
M`":````%````+(````0````R@```&@```#>````%````4H```!<```!8@```
M`@```'"````%````<X```!@```!Y@```5@```)*````%````Z8````<```#O
M@```%````/>````&````#($```8````3@0``#0```!J!```,````*($```T`
M```U@0``%@```$.!```E````6H$```<```"`@0``!@```(B!```#````CX$`
M``L```"3@0``"````)^!```,````J($``!0```"U@0``%0```,J!```+````
MX($```X```#L@0``"P```/N!```7````!X(``!<````?@@``!````#>"```#
M````/((```\```!`@@``#0```%""```=````7H(```<```!\@@``$0```(2"
M```*````EH(```4```"A@@``*````*>"```Q````T((```X````"@P``,```
M`!&#```>````0H,``"````!A@P``#@```(*#```+````D8,``#8```"=@P``
M5````-2#``!.````*80```4```!XA```!P```'Z$```-````AH0``!$```"4
MA```$````*:$```-````MX0```T```#%A```#0```-.$```9````X80```X`
M``#[A```%`````J%```/````'X4``!0````OA0``!````$2%```0````284`
M``@```!:A0``$0```&.%```/````=84```(```"%A0``#````(B%```'````
ME84```<```"=A0``%@```*6%```J````O(4```<```#GA0``#@```.^%```)
M````_H4``!0````(A@``!0```!V&```2````(X8```T````VA@``&0```$2&
M```*````7H8``!(```!IA@``"````'R&```)````A88```H```"/A@``(0``
M`)J&```'````O(8```@```#$A@``&````,V&```+````YH8``"0```#RA@``
M+@```!>'```(````1H<```\```!/AP``"````%^'```<````:(<``!8```"%
MAP``!````)R'```%````H8<``"<```"GAP``(P```,^'```I````\X<``"X`
M```=B```"````$R(```B````58@``"````!XB```"0```)F(```>````HX@`
M``L```#"B```"0```,Z(```I````V(@``!$````"B0``"````!2)```8````
M'8D```@````VB0``!P```#^)```'````1XD```X```!/B0``#0```%Z)```/
M````;(D```4```!\B0``0P```(*)``!.````QHD```X````5B@``)````"2*
M```$````28H```T```!.B@``*@```%R*```'````AXH```X```"/B@``$0``
M`)Z*```5````L(H```P```#&B@``"@```-.*```.````WHH``!(```#MB@``
M!P````"+```0````"(L``!<````9BP``"0```#&+```3````.XL``!D```!/
MBP``&````&F+```'````@HL```8```"*BP``&````)&+```4````JHL``!0`
M``"_BP``!@```-2+```&````VXL```8```#BBP``#````.F+```#````]HL`
M``4```#ZBP``"`````",```-````"8P``%H````7C```'0```'*,```%````
MD(P``!$```"6C```$0```*B,```0````NHP```T```#+C```(````-F,```?
M````^HP``!L````:C0``$P```#:-```A````2HT``',```!LC0``(@```."-
M```?`````XX``"(````CC@``'P```$:.```I````9HX``",```"0C@``&P``
M`+2.```C````T(X``!\```#TC@``(P```!2/```4````.(\``!P```!-CP``
M"0```&J/```)````=(\``#\```!^CP``+P```+Z/``!>````[H\``"T```!-
MD```"````'N0```/````A)```"T```"4D```!@```,*0```/````R9```"(`
M``#9D```%P```/R0```?````%)$``"\````TD0``(0```&21```A````AI$`
M`!L```"HD0``(````,21```*````Y9$``!(```#PD0``$`````.2```2````
M%)(``!4````GD@``%````#V2```;````4I(```H```!ND@``!````'F2```2
M````?I(```P```"1D@``#@```)Z2```+````K9(```@```"YD@``!0```,*2
M```#````R)(```L```#,D@``"````-B2```:````X9(``!<```#\D@``"0``
M`!23```$````'I,```@````CDP``!````"R3```-````,9,```8````_DP``
M"````$:3```*````3Y,```L```!:DP``"````&:3```*````;Y,```H```!Z
MDP``$0```(63```1````EY,```T```"IDP``"````+>3```8````P),```L`
M``#9DP``#0```.63```8````\Y,```H````,E```$@```!>4```-````*I0`
M``,````XE```(````#R4```C````790``!P```"!E```+@```)Z4```F````
MS90``"D```#TE```)P```!Z5```B````1I4``"````!IE0``-P```(J5```H
M````PI4``"4```#KE0``(@```!&6```G````-)8``"<```!<E@``00```(26
M```A````QI8``!\```#HE@``#0````B7```%````%I<```8````<EP``$@``
M`".7```+````-I<```8```!"EP``!````$F7```&````3I<```0```!5EP``
M`P```%J7```#````7I<```0```!BEP``'@```&>7```*````AI<``!0```"1
MEP``$````*:7```%````MY<``!D```"]EP``#@```->7```(````YI<```L`
M``#OEP``#P```/N7```B````"Y@```@````NF```$0```#>8```6````29@`
M`!0```!@F```.````'68```+````KI@```P```"ZF```#````,>8```3````
MU)@```<```#HF```"0```/"8```2````^I@```P````-F0``%0```!J9```*
M````,)D```H````[F0``(0```$:9```*````:)D```P```!SF0```P```("9
M```0````A)D```,```"5F0``"0```)F9```.````HYD```T```"RF0``,```
M`,"9```>````\9D``"`````0F@``+@```#&:```)````8)H``!8```!JF@``
M#P```(&:```*````D9H```8```"<F@``!P```*.:```"````JYH``!(```"N
MF@``.0```,&:```>````^YH``#`````:FP``*````$N;```J````=)L``"H`
M``"?FP``*P```,J;```K````]IL``!,````BG```$P```#:<```3````2IP`
M``L```!>G```AP```&J<```I````\IP``!L````<G0``$P```#B=```:````
M3)T```P```!GG0``%P```'2=```5````C)T``"<```"BG0``%P```,J=```0
M````XIT``!<```#SG0``"0````N>```)````%9X```@````?G@``#0```"B>
M```)````-IX```H```!`G@``!P```$N>```&````4YX``!L```!:G@``$```
M`':>```-````AYX```X```"5G@``$@```*2>```/````MYX```X```#'G@``
M"````-:>```)````WYX```8```#IG@``$````/">```&`````9\``!@````(
MGP``!P```"&?```%````*9\``!@````OGP``!@```$B?```$````3Y\```L`
M``!4GP``"````&"?```&````:9\```L```!PGP``"````'R?```K````A9\`
M``4```"QGP``"P```+>?```!````4P(````````L`0``!@$``&````#$`0``
M`````$`````8`0``K`(``*L````H````?0(``)(!```K`0``#0(``#`!````
M````BP$``(L```!G`````````*<!```K`@``U0$``$,"```N`@``L@``````
M``!8`0``2@$``+L!```2````_@$``&L```"'`@````````````#F````K0(`
M```````G`0```````"$!``!E````A@$``!D!````````R`$`````````````
M`````,<!```5`````````&H```"0`@``?0```$D`````````V`$``+P!``";
M````6@$``%(````_````2@`````````-````J@(``+4````P````,@``````
M````````F@(```````"`````N0$``(X!``!"`0``S0$``"@!``#+`0``/`(`
M`.X```!/````J`(``.$!```6`0``%`$``*$!````````'0```$4```#*`0``
MD`$``*D"``!W`0```````&P!``">`0``L`$``#8!````````2`$``*P!``!$
M`0``2````$$```"@`@``?`$``!$````T`0``IP(``*<```"D`@``^P$`````
M``"7`0``Y`$```````#K````\0```%X````C````M````#4```"<`0``I```
M``````!!`0``3P(``(,!``##`0``#P`````````_`@``30``````````````
MA`$``!````!V````%`(``(\!``#[`````````,<`````````(`$```````#>
M`0``S`$``$`!```.`0``H@$```````"*`0``L@$``+H!`````````````#X"
M``!<`@``_@```.T!``"?`0```````/T!``#$````.0```$("````````O@``
M``````"6`0``,P```-`!``!+`0```````)D!````````50(```````!0````
M`````%H```#``0``,0(```("````````G@```'P````%`@````````````#9
M`0```````$L"````````"P```%`!````````K@$``,(!``!'`@``````````
M``#R`0``1@`````````,`@``,0$``!4!``!\`@``I@(``(8"``!A`@``AP$`
M``````!,`@``@0(``#L"``!X`0``A0(``(4````,````9P(``,$!``!I````
M&P(``)T!````````S`````````",```````````````#````ZP$``"\```!W
M````+0(``)``````````\````#H!``!/`0````````````!#````N0```&`!
M````````C`$``)H```"4`@``6`(```8"````````;P$``&H!``#X`0``3```
M````````````<P$```````#2`0``90$``````````````````!<"``"E`@``
M`````&X`````````-```````````````(@(``.<!`````0``<P```*8```!-
M`0``7P$```0"``#Q`0``N```````````````!````)<"```&`````````'(!
M``!Q`@``$0(```````!=`0``7`$``/,````!`@``3@(```````#:````\@``
M``````"8`````````&L"``#8`````````*T```")````!0$``(H"````````
M"@```"X!```6````AP````````!]`0``X`````````!R````A0$```````!5
M`````````%8!````````+0```#`"``#2``````````````"N````)@(``%D`
M``![`0``=`(``/0!``"C`@```````#H`````````O````$T"````````\P$`
M`.\````5`@```````$,!```0`@```````)\"``#\`0``;P(``-$````7`0``
M`````,L```".````X@$``&$````R`@```0$``'@````;``````````````#W
M````)`$``%L"``#;`0``9`(``'H"`````````````%<!````````J0$```T!
M```'`0``!0```*("```E`0``HP````<`````````````````````````8P(`
M`&@``````````````.(```!I`@``[`$```````"F`0``H0(``%P```"=`@``
M````````````````C0(``*T!``!``@``KP```"D"``!T`0``%@(``.$```!D
M`0``MP``````````````>0$``$8"````````P````%\"`````````````+0!
M````````J0```"D!```<`@``JP$``(@!````````````````````````$P``
M`!P````*`@``TP```````````````````*H!```D`@```````$X!````````
M@0$```\"```#`0```````-\!``!V`@``P0````````#/`0``*@(``&8!```\
M`````````-P!```D````FP$`````````````````````````````D0(``,@`
M`````@``/0(``/0```!0`@``=````````````````````"D```#Y`0``````
M`#T```"5`@``O0$``)H!``!^`0``:`$`````````````F0```.`!``"B````
M<0$``(X"```)````(0```+,```"S`0```````+X!``!!`@```````%<"``"2
M````````````````````B`(````````T`@``40```%D!```\`0``/P$``'4`
M``!F`@``O0```/<!``!B````E````!,!``"_`0```````#4!```9`@``````
M``````!2`@``A````!T"``!6`@``60(``"P"```9`````````&,!``""````
M@`(```````#5````.@(````````[````$@$``'`"``"V`````````,\```!M
M`0``F0(``-8!````````XP$``*P```!U`@``0@```)\```"@`0``_````.0`
M`````````````'D```"$`@``)0`````````Q````&@(```````#F`0``Q0$`
M`!\"``!S`@````````````!%`@``_P$``-<!``!3````=0$``!H!``"P````
M;@$``(L"``!R`@``%P````````!>`0``#@```)("``#>`````P(``)$!````
M````I0$```````!I`0``.0(``(,````W`@``]@```'\!``#I`0``B0(``!L!
M```O`0``[0```,4```"4`0``Q@```!H````^````.````!$!``#)````:`(`
M`&(!`````````````*,!``#I````#`$```````"<````&`(``'<"``!_````
M/@$`````````````;``````````.`@```@```,X!````````;0```(8`````
M````:P$``(\"``#X````(@```(,"```V`@```````'@"```]`0``(P(``(`!
M``#E`0```````%X"````````PP````D"````````40(``/4!``"-`0``-@``
M``````!+````;0(``"4"`````````````-T!````````F`(```````![`@``
MW0````````#6`````````!@`````````1P$``%8````3`@``#P$```````#1
M`0```````&$!````````'P$``#<```"=````"`(``(\```"Q````VP```.,`
M``"5````KP$``)L"``!D````1P```/T```!Z`0``+P(``((!```G`@``DP$`
M`-\```!(`@``.`$````````S`@``>0(``+H```#V`0``MP$`````````````
M70```!X!``!=`@``;P```)P"``"3``````````````!4````J`$```````!Q
M`````````!\```#G````;@(``$8!```4`````````"H`````````=@$`````
M``!J`@``B````)4!```L````E@```.H````)`0``UP``````````````B@``
M`$X`````````.`(``%H"``!;`0````````````"H````V@$``'````"@````
M``````````"V`0``)P`````````(`0``,@$```````"X`0``F`$``/H!```S
M`0``3`$``#4"``"K`@```````.\!``!E`@``$`$```````"!````````````
M```'`@``Z`$``"@"````````?P(```````"U`0``L0$```@```#0````1`(`
M`.X!``!1`0``20$``&("``#L````TP$```````#J`0``5`(``*H````2`@``
MZ````(T````=`0````````````#4````2@(`````````````1``````````@
M`@``4@$``&,`````````````````````````;`(``-P```"6`@```````"(!
M```Y`0```````$D"````````^@```"8!````````R@```.4`````````OP``
M`"````![````I`$``!P!``!4`0``"P$``#<!``"A`````````,8!``!P`0``
M]0```(D!``#"`````````)<````F`````````'X"``#4`0``NP```&8```!8
M````V0```#L!``#_````S@`````````>````S0```````````````````"T!
M``"3`@``D0```/`!``!?````+@```'X`````````*@$````````K````G@(`
M``(!````````@@(``'H```!3`0``10$``!X"```+`@``!`$````````*`0``
M(0(``",!``"E````9P$``&`"````````C`(``/D```#)`0``5P```%4!``!;
M`````"!A="``)60@)7,@86YD("5S`"5D(&YO=&5S`"5S("T@3F]T:6-E`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@5&5R
M;7,@;V8@06=R965M96YT`"5S(&%T("5S("5S`"5S(&9I;&4@<W5C8V5S<V9U
M;&QY(&EM<&]R=&5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E
M<R!O9B`E<P`E<R=S($YO=&5P860`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B
M;&4@9G)O;2`E<R!T;R`E<P`Q(&YO=&4`,3(@2&]U<B!&;W)M870`,C0@2&]U
M<B!&;W)M870`,C0@:&]U<G,`04T@4VAO=V5R<P!!32]030!!8G-B;W1T;VT`
M06)S;6ED9&QE`$%C8V5S<R!D96YI960@9&5L971I;F<@;F]T92X`06-C97-S
M(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N`$%C8V5S<R!D96YI960@<V%V:6YG
M(&YO=&4@=&\@)7,N`$%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4Z("5S`$%C
M8V]U;G0@4&%S<W=O<F0`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!A(&YE=R!U<V5R.@!!9&0@
M8V%T96=O<GD`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!U<V5R`$%D
M9&EN9R!!($YE=R!.;W1E`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%D<P!!;&EG;@!!;&EG;FUE;G0Z
M`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI
M<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L=&5R;F%T92!)35-0(%5S97)N86UE
M`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`
M06QT97)N871E('1E>'0Z`$%N<W=E<@!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO
M;B!I<R!R96%D>2X`07!R:6P`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07-C96YD:6YG`$%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`075G
M=7-T`$%V86EL86)L92!#871E9V]R:65S.@!!=F%I;&%B;&4@9FEE;&1S.@!"
M86-K('1O($YO=&5P860`0F%C:R!T;R!.;W1E<&%D($]P=&EO;G,`0F%C:V=R
M;W5N9`!"87-E;&EN90!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`
M0F]O:VUA<FMS`$)O<F1E<@!";W)D97)S`$)O='1O;0!#35,`0U-6`$-?96QL
M(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A
M=&5G;W)Y`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O
M<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;G1E<@!#:&%N9V4`0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG92!Y;W5R(&YO
M=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS+@!#:&%R`$-H96-?:R!,
M:6YK+BXN`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E('1H
M92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T:&4@<W5M;6%R>2!V:65W
M+@!#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N`$-L96%R($9O<FT`0VQE
M87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L
M:6-K('1O($-O;G1I;G5E`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O
M;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQS.@!#;VUI
M8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;F1I=&EO;G,`0V]N9FEG=7)E
M("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N=&EN=64`0V]P>0!#;W!Y('-E;&5C
M=&EO;@!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BX`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN
M:P!#<F5A=&4@82!N97<@;VYE`$-R96%T960`0W)E871O<B!097)M:7-S:6]N
M<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$1$`$1A=&%4<F5E($)R;W=S97(`1&%T92!296-E:79E9`!$87D`1&5?
M;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!.;W1E<&%D`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I
M83H`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5L971E`$1E;&5T92!'
M<F]U<`!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(')O=P!$96QE=&4@<V5L96-T
M960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L
M96T`1&5S8W)I<'1I;VX`1&5S8W)I<'1I;VXZ`$1E=F5L;W!M96YT`$1E=R!0
M;VEN=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y
M($]P=&EO;G,`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$5D
M:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@3F]T90!%9&ET(%!E<FUI
M<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F
M;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5M86EL($%D9')E<W,`16UP
M='D@3F]T90!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E
M<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M<&]R=`!%>'!O<G0@3F]T97,`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U
M<`!&7W5L;"!497AT`$9A:7(`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L
M:6ME.B``1F5W(%-H;W=E<G,`1FEL92!-86YA9V5R`$9I;'1E<G,`1FER<W0@
M2&%L9@!&:7)S="!1=6%R=&5R`$9L;V%T`$9O;G0@0V]L;W(`1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O
M<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)O;2!T:&4@`$9U;&P@1&5S8W)I
M<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N`$=E;F5R871E9"!#;V1E`$=O`$=O;V=L92!396%R8V@`1W)O=7`@
M061M:6YI<W1R871I;VX`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$AE:6=H
M=`!(96QP`$AE;6ES<&AE<F4`2&EG:`!(;U]M90!(;W)D90!(;W)I>F]N=&%L
M('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AU;6ED:71Y`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N<R!/;FQY`$EC
M;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EM86=E(%!R979I97<Z
M`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E<P!);7!O<G0@3F]T97,L(%-T
M97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T97,`26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@
M069T97(`26YD:79I9'5A;"!5<V5R<P!);F9O<FUA=&EO;@!);G-E<G0@0U]O
M;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!7
M96(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T
M97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H
M92!C=7)R96YT(&]N90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R
M="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN
M(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@
M869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E
M<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN=F%L
M:60@87!P;&EC871I;VXN`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN
M=F5N=&]R>0!)=&%L:6,`2F%N=6%R>0!*87!A;F5S92`H25-/+3(P,C(M2E`I
M`$IU;'D`2G5N90!*=7-T:69Y`$QA7WEO=70`3&%N9W5A9V4`3&%S="!-;V1I
M9FEE9`!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E
M<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA
M>6]U=`!,969T`$QI9VAT(%)A:6X`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG
M('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QO8V%L('1I;64Z(`!,
M;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@
M5&%S:W,`3&]W`$QO=V5R(')O;6%N(&YU;6)E<G,`34T`36%I;`!-86EL($%D
M;6EN`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N`$UA<F-H`$UA<F=I;@!-871C:&EN9R!F:65L
M9',`36%Y`$UE;6)E<G,`365M;R!497AT`$UE<F=E(&-E;&QS`$UE=&%R(%=E
M871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`365T<FEC`$UI9&1L90!-;P!-;V)I;&4@36%I
M;`!-;V1E<F%T90!-;V1I9GD@55),`$UO9&EF>6EN9R`E<P!-;W-T;'D@0VQE
M87(`37D@06-C;W5N=`!->2!.;W1E<P!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!.3RP@22!$;R!.3U0@06=R964`3F5T=V]R:P!.979E<@!.97<@0V%T
M96=O<GD`3F5W($YO=&4`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W<P!.
M97=S9W)O=7!S`$YE>'0`3FEG:'0`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@;F]T97!A9',@87)E(&%V86EL86)L
M92!T;R!G=65S=',N`$YO(&YO=&5S`$YO(&YO=&5S(&UA=&-H('1H92!C=7)R
M96YT(&-R:71E<FEA+@!.;R!N;W1E<R!T;R!D:7-P;&%Y`$YO('!E;F1I;F<@
M<VEG;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C
M=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]?=&4`3F]N90!.;W0@<V5T
M`$YO=&4@0V%T96=O<GD`3F]T92!$971A:6QS`$YO=&4@3&ES=',`3F]T92!4
M97AT`$YO=&4@7U1E>'0`3F]T92!N;W0@9F]U;F0N`$YO=&5?<&%D`$YO=&5P
M860G<R!N86UE.@!.;W1E<&%D<P!.;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE
M+@!.;W1E<P!.;W1E<R!3=6UM87)Y`$YO=F5M8F5R`$YU;6)E<B!O9B!C;VQU
M;6YS`$YU;6)E<B!O9B!R;W=S`$]+`$]B:F5C="!#<F5A=&]R`$]C=&]B97(`
M3V9F:6-E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A;FEZ
M:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]T:&5R`$]T:&5R
M($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`
M4$A0($-O9&4`4$T@3&EG:'0@4F%I;@!087-S=V]R9`!087-S=V]R9#H`4&%S
M<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%T:`!096YD
M:6YG(%-I9VYU<',Z`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!0
M97)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO
M;@!0:&]T;W,`4&EX96QS`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;VQL<P!0;W-I=&EO;FEN9R!O
M9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4')E<W-U
M<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W
M`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<FEN="!D;V-U
M;65N=`!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`475E
M<GD`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286YD;VT@1F]R='5N90!2
M96%D`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2969R97-H($QI
M<W0`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M87)K<P!296UO=&4@4V5R=F5R
M<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`
M4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V%T96=O<GD`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('1H90!296UO=F4@=7-E<@!2
M96UO=F4@=7-E<CH@)7,`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=F5R="!#
M;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S
M`%)I9VAT`%)O7W<@4')O<&5R=&EE<RXN+@!2;W<@4')O<&5R=&EE<P!2;W<@
M<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6X`4TU3($UE<W-A9VEN9P!380!3
M879E`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V5A
M<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!297-U;'1S`%-E87)C:"!38V]P
M90!396%R8V@@7U1E>'0`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A
M(&YE=R!O=VYE<@!396QE8W0@82!N;W1E<&%D`%-E;&5C="!A('-E<G9E<@!3
M96QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP
M;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E
M;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M
M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`
M4V5L96-T960@0V%T96=O<FEE<SH`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YS
M;W(Z(`!397!T96UB97(`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W(&%C=&EO;B!B=71T;VYS/P!3:&]W(&QA<W0@
M;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;F]T97!A9"!N86UE
M/P!3:&]W(&YO=&5S(&9R;VT@=&AE<V4@8V%T96=O<FEE<P!3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W=E<G,`4VAO=V5R<R!%87)L
M>0!3:&]W97)S($QA=&4`4VMI<"!-86EN=&5N86YC90!3;F]W(&1E<'1H.B``
M4V]R="!B>2!#871E9V]R>0!3;W)T(&)Y($YO=&4@5&5X=`!3<&%C:6YG`%-P
M86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C
M;VQU;6X`4W!L:70@<F]W`%-T86YD87)D`%-T871U<P!3=0!3=6)S8W)I<'0`
M4W5C8V5S<P!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6UM87)Y`%-U;B!2:7-E`%-U
M;B!3970`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T
M`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`5"U3=&]R;0!4+5-T;W)M
M<P!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%R9V5T.@!4
M87-K<P!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A
M='5R93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0@3VYL>0!497AT
M(&%L:6=N`%1E>'1T;W``5&@`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;F]T92!W87,@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!C;W5L9&XG="!B
M92!C<F5A=&5D.B`E<P!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&-R96%T
M960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO
M=&5P860@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-E<G9E<B`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E
M9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D
M+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=DYO=&4@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@
M86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@97)R
M;W(@=FEE=VEN9R!T:&ES(&YO=&5P860Z("5S`%1H97)E('=E<F4@;F\@;65M
M;W,@=&\@97AP;W)T+@!4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T
M960N`%1H:7,@:7,@)7,N`%1H=6YD97(`5&EC:V5T<P!4:6UE(%1R86-K:6YG
M`%1I;64@9F]R;6%T`%1I=&QE`%1O9&%Y`%1O;6]R<F]W`%1O<`!4=0!54DP`
M55),.@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S`%5N9&5R;&EN90!5;F1O
M($-H86YG97,`56YF:6QE9`!5;FET<P!5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N=`!5;G-E="!C;VQO<@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R
M`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5S97(@061M:6YI<W1R871I;VX`57-E<B!296=I<W1R871I;VX`
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92X`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@
M=&AE('-Y<W1E;3H`5F%C871I;VX`5F%R:6%B;&4`5F5R<VEO;B!#;VYT<F]L
M`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E
M<GD@2&EG:`!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I<VEB:6QI='D`
M5FES:6)I;&ET>3H@`%=E`%=E871H97(@1F]R96-A<W0`5V5B`%=E;&-O;64`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H:6-H($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\`
M5VED=&@`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I
M;F0Z`%=I;F0Z(`!960!997,L($D@06=R964`66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A9"`E<RX`66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+@!9;W4@;75S="!S96QE8W0@82!N;W1E<&%D('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=7(@16UA:6P@061D
M<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U
M<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9&5F875L
M="!N;W1E<&%D.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N;W1E<&%D<SH`66]U
M<B!R96UO=&4@<V5R=F5R<SH`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T
M960@5&5X="`M`%]!9&UI;FES=')A=&EO;@!?0F%C:R!T;R!.;W1E<&%D`%]#
M871E9V]R>0!?1&%T851R964`7T1E;&5T90!?1&5L971E(%)O=P!?161I=`!?
M1FER<W0@3&EN90!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN
M`%]);7!O<G0O17AP;W)T`%],:7-T($YO=&5S`%],;V<@;W5T`%]-;V1I9GD@
M3&EN:RXN+@!?37D@3F]T97!A9',`7TYE=R!.;W1E`%]/<'1I;VYS`%]097)M
M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK+BXN`%]396%R8V@`7U1A8FQE
M(%!R;W!E<G1I97,N+BX`7U5S97)S`&-A;&T`9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<P!L:6YE<UT`;F%M90!N;W1E<RYC<W8`<&5R8V5N=`!P:7AE;',`
M<FES:6YG`'-T96%D>0!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M`'9.;W1E`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@36YE
M;6\@,BXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#(M,C,@,3@Z,30K,#$P,`I,
M87-T+51R86YS;&%T;W(Z($UA<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O=F%N
M;T!U;FEB;V-C;VYI+FET/@I,86YG=6%G92U496%M.B!)=&%L:6%N(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`(&%L;&4@`"5D("5S(&4@)7,`)60@
M87!P=6YT:0`E<R`M($%T=&5N>FEO;F4`)7,@3W!E<F%Z:6]N:2!D:2!-86YU
M=&5N>FEO;F4@+2!#;VYF97)M80`E<R!497)M:6YI(&0G57-O`"5S(&$@)7,@
M)7,`1FEL92`E<R!I;7!O<G1A=&\@8V]N('-U8V-E<W-O`"5S(&UI;G5T:0`E
M<R!N;VX@=')O=F%T;RX`)7,@82`E<R!D:2`E<P`E<R=S($)L;V-C;R!!<'!U
M;G1I`"P@82`E<R`E<P`L('9A<FEA8FEL92!D82`E<R!A("5S`#$@87!P=6YT
M;P!&;W)M871O(#$R(&]R90!&;W)M871O(#(T(&]R90`R-"!O<F4`36]S=')A
M($%-`$%-+U!-`%9A:2!A`%)E9V]L90!!8V-E<W-O(&YE9V%T;R!P97(@96QI
M;6EN87II;VYE(&%P<'5N=&\N`$%C8V5S<V\@;F5G871O(')I;6]Z:6]N92!A
M<'!U;G1O+@!!8V-E<W-O(&YE9V%T;R!A;"!S86QV871A9V=I;R!D:2!A<'!U
M;G1O(&EN("5S+@!!8V-E<W-O(&YE9V%T;R!A;"!S86QV871A9V=I;R!D:2!A
M<'!U;G1O(&EN("5S+@!!8V-O=6YT(%!A<W-W;W)D`$-O;G1A8FEL:71A)P!!
M9V=I=6YG:0!!9V=I=6YG:2!3;W1T;R!'<G5P<&\`06=G:75N9VD@<75I.@!!
M9V=I=6YG:2!.=6]V;R!5=&5N=&4`06=G:75N9VD@=6X@;G5O=F\@=71E;G1E
M.@!!9V=I=6YG:2!C871E9V]R:6$`06=G:75N9VD@=6X@;G5O=F\@;65M8G)O
M`$%G9VEU;F=I('!A:6\`06=G:75N9VD@=71E;G1E`$%G9VEU;F=I(%5N($YU
M;W9O($%P<'5N=&\`3&$@9G5N>FEO;F4@9&D@86=G:75N=&$@=71E;G1I(&YO
M;B#H(&%T=&EV82X`4G5B<FEC80!!;6UI;FES=')A>FEO;F4`4'5B8FQI8VET
MX`!!;&QI;F5A;65N=&\`06QL:6YE86UE;G1O.@!4=71T:2!G;&D@571E;G1I
M($%U=&5N=&EC871I`%1U='1I(&D@1W)U<'!I`%1U='1I(&D@4&5R;65S<VD`
M5'5T=&D@:2!Q=6%T=')O(&QA=&D`571E;GIA($E-4U`@86QT97)N871I=F$`
M26YD:7)I>GIO(&5M86EL(&%L=&5R;F%T:79O`$%V=FES82!S=2!A9V=I;W)N
M86UE;G1I`%1E<W1O(&%L=&5R;F%T:79O.@!2:7-P;W-T80!!<'!L:6-A>FEO
M;F4`07!P;&EC87II;VYE(&4G('!R;VYT82X`07!R:6QE`%-E:2!S:6-U<F\@
M9&D@=F]L97(@96QI;6EN87)E(&QA(')I8VAI97-T82!D:2!I<V-R:7II;VYE
M('!E<B`E<S\`0W)E<V-E;G1E`$-H:65D:2!C;VYF97)M82!P<FEM82!D:2!E
M<V5G=6ER92!O<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N90!496YT871I=F\@
M9&D@8V%N8V5L;&%Z:6]N92!D:2!U;B!G<G5P<&\@:6YE<VES=&5N=&4N`%1E
M;G1A=&EV;R!D:2!E;&EM:6YA>FEO;F4@9&D@=6X@<&5R;65S<V\@:6YE<VES
M=&5N=&4N`%1E;G1A=&EV;R!D:2!M;V1I9FEC82!D:2!U;B!P97)M97-S;R!I
M;F5S:7-T96YT90!496YT871I=F\@9&D@;6]D:69I8V$@9&D@=6X@<&5R;65S
M<V\@:6YE<VES=&5N=&4`06=O<W1O`$-A=&5G;W)I92!$:7-P;VYI8FEL:3H`
M0V%M<&D@9&ES<&]N:6)I;&DZ`%1O<FYA(&%L($)L;V-C;R!!<'!U;G1I`%1O
M<FYA(&%L($)L;V-C;R!!<'!U;G1I`%-F;VYD;P!"87-E;&EN90!);7!O<W1A
M>FEO;FD@0FQO8V-O`%1I<&\@9&D@0FQO8V-O`$=R87-S971T;P!0<F5F97)I
M=&D`36%R9VEN90!-87)G:6YI`$)A<W-O`$--4P!#4U8`4')O<')I973@(&1E
M;&QE($-?96QL92XN+@!#86QE;F1A<FEO`$-A;&UO`$-A;F-E;&QA`$5L:6UI
M;F$@4F%P<&]R=&\@9&D@4')O8FQE;6$`3W!Z:6]N:0!#871E9V]R:64@92!%
M=&EC:&5T=&4`0V%T96=O<FEA`%!R;W!R:65TX"!D96QL92!C96QL90!3<&5S
M<V]R92!C96QL93H`4')O<')I973@(&1E;&QE(&-E;&QE`%-P87II;R!C96QL
M93H`0V5N=')A`$UO9&EF:6-A`$UO9&EF:6-A(&YO;64L(&EN9&ER:7IZ;R!E
M(&9I<FUA(&-H92!V97)R86YN;R!V:7-U86QI>GIA=&D@9&%L;&4@<&5R<V]N
M92!C:&4@;&5G9V]N;R!E(')I<W!O;F1O;F\@86ET('1U;VD@;65S<V%G9VDN
M`$UO9&EF:6-A(&EM<&]S=&%Z:6]N:2!V:7-U86QI>GIA>FEO;F4@92!O<F1I
M;F%M96YT;R!!<'!U;G1I+@!#:6%D`%9E<FEF:5]C82!,:6YK+BXN`%-E;&5Z
M:6]N82!C;VUE('9I<W5A;&EZ>F%R92!L92!D871E.@!38V5G;&D@;&4@8V%T
M96=O<FEE(&1I($%P<'5N=&D@9&$@;6]S=')A<F4@;F5L('-O;6UA<FEO+@!"
M;&]C8V\@87!P=6YT:2!D:2!D969A=6QT.@!#<F5A($UO9'5L;P!%;&EM:6YA
M('5T96YT93H@)7,`16QI;6EN82!U=&5N=&4`16QI;6EN82!L92!I;F9O<FUA
M>FEO;FD@9&5L;"=U=&5N=&4`0VQI8V-A('!E<B!#;VYT:6YU87)E`$-H:75D
M:2!L82!&:6YE<W1R80!.=79O;&4`3G5V;VQE`$UA<F=I;FD@8V]L;&%S<V%T
M:0!#;VQO<F4`4V5L97II;VYA($-O;&]R90!#;VQO;FYE.@!6:6=N971T90!#
M;VUA;F1O`%-H96QL(&1I($-O;6%N9&D`0V]N9&EZ:6]N:0!#;VYF:6=U<F$@
M)7,`0V]N9F5R;6$@4&%S<W=O<F0`0V]N=&EN=6$`0V]P:6$`4V5L97II;VYE
M(&QA(&-O<&EA`$EM<&]S<VEB:6QE(&EN=F5R=&ER92!L82!C;VYF:6=U<F%Z
M:6]N92X`26UP;W-S:6)I;&4@<V%L=F%R92!L82!C;VYF:6=U<F%Z:6]N92`E
M<RX`26UP;W-S:6)I;&4@<V%L=F%R92!U;F$@8V]P:6$@9&D@<V-O<G1A(&1E
M;&QA(&-O;F9I9W5R87II;VYE`$-O<G-I`$-R96$`0W)E82!U;B!C;VQL96=A
M;65N=&\`0W)E86YE('5N;R!N=6]V;P!#<F5A=&\`4&5R;65S<VD@9&D@0W)E
M871O<F4`3W)A(&%T='5A;&4`3&$@55),(&%T='5A;&4@Z`!-971E;R!!='1U
M86QE`$-O;F1I>FEO;FD@871T=6%L:3H@`%-T:6QE(&%T='5A;&4`26UP;W-T
M82!L92!O<&5R87II;VYI(&1A(&5S96=U:7)E('%U86YD;R!E;G1R:2!I;B`E
M<RX`5&%G;&EA`%-E;&5Z:6]N92!486=L:6$`1T<`0G)O=W-E<B!$871A5')E
M90!$871A(%)I8V5V=71O`$=I;W)N;P!%7VQI;6EN82!#;VQO;FYA`$1I8V5M
M8G)E`$YU;65R;R!D96-I;6%L90!#;VQO<F4@9&D@1&5F875L=`!";&]C8V\@
M87!P=6YT:2!D:2!D969A=6QT.@!#<FET97)I;R!D:2!O<F1I;F%M96YT;R!D
M:2!D969A=6QT.@!$:7)E>FEO;F4@9&D@;W)D:6YA;65N=&\@9&D@9&5F875L
M=#H`16QI;6EN80!%;&UI;F$@1W)U<'!O`$5L:6UI;F$@8V5L;&$`16QI;6EN
M82!C;VQO;FYA`$%V=FES82!S=2!A9V=I;W)N86UE;G1I`$5L;6EN82!R:6=A
M`$5L:6UI;F$@;"=I9&5N=&ETX"!S96QE>FEO;F%T80!%;&EM:6YA(&QA(&-O
M;&]N;F$@8V]R<F5N=&4`16QI;6EN82!L82!R:6=A(&-O<G)E;G1E`$1I<V-E
M;F1E;G1E`$1E<V-R:79I(&EL(%!R;V)L96UA`$1E<V-R:7II;VYE`$1E<V-R
M:7II;VYE.@!3=FEL=7!P;P!0=6YT;R!D:2!2=6=I861A`$-A<G1E;&QA`%9I
M<W5A;&EZ>F$@;F5L(&9O<FUA=&\@,C0@;W)E/P!/<'II;VYI(&1I(%9I<W5A
M;&EZ>F%Z:6]N90!.;VX@96QI;6EN87)E`$YO;B!A8V-E9&5R92!D:7)E='1A
M;65N=&4@82!M86EN=&5N86YC92YP:'``3&$@<')I;6$@<FEG82!C;VYT:65N
M92!L92!E=&EC:&5T=&4@9&D@8V%M<&\_($UA<F-A('-E('-I+"!L87-C:6$@
M=G5O=&$@<V4@;F\Z`%-C87)I8V$@;&$@8V]N9FEG=7)A>FEO;F4@9V5N97)A
M=&$@8V]M92!S8W)I<'0@4$A0+@!-;V1I9FEC80!-;V1I9FEC82!";&]C8V\`
M36]D:69I8V$@1W)U<'!O`$UO9&EF:6-A($%R=&EC;VQO`$UO9&EF:6-A(%!E
M<FUE<W-I`$UO9&EF:6-A('!E<FUE<W-I('!E<B`E<P!-;V1I9FEC82!O<'II
M;VYI('!E<CH`36]D:69I8V$@<&5R;65S<VD@<&5R("5S`$EN9&ER:7IZ;R!D
M:2!0;W-T80!#:&EA=F4@=G5O=&\`17)R;W)E`$]G;FD@,34@;6EN=71I`$]G
M;FD@,B!M:6YU=&D`3V=N:2`S,"!S96-O;F1I`$]G;FD@-2!M:6YU=&D`3V=N
M:2!-97IZ)V]R80!/9VYI(&UI;G5T;P!686QO<FD@9&D@97-E;7!I;SH`17-E
M8W5Z:6]N90!%<W!O<G1A`$5S<&]R=&$@07!P=6YT:0!#;VQO<F4@1D<`57!L
M;V%D("A#87)I8V%M96YT;RD@9FEL92!N;VX@<W5P<&]R=&%T;RX`5&5S=&\@
M0V]M<&QE=&\`1VEU<W1O`$9E8F)R86EO`%-I('-E;G1E(&-O;64`4VD@<V5N
M=&4@8V]M93H@`%!O8VAI($%C<75A>GIO;FD`1FEL92!-86YA9V5R`$9I;'1R
M:0!0<FEM82!-971A)P!0<FEM;R!4<FEM97-T<F4`1FQO870`0V]L;W)E($9O
M;G0`4&5R(&)R;W=S97(@8VAE(&YO;B!S;W!P;W)T86YO(&QE(&EM;6%G:6YI
M`$AA:2!D:6UE;G1I8V%T;R!L82!T=6$@<&%S<W=O<F0_`$UO9'5L:0!);F1O
M=FEN;P!&;W)T=6YE(%1Y<&4`1F]R='5N97,`1F]R=6T`26YO;'1R:0!696X`
M1G)A;65S`$1A;"``1&5S8W)I>FEO;F4@0V]M<&QE=&$`3'5N82!0:65N80!.
M;VUE($-O;7!L971O`$=E;F5R82!#;VYF:6=U<F%Z:6]N92`E<R``0V]D:6-E
M($=E;F5R871O`%9A:2!A`%)I8V5R8V$@1V]O9VQE`$%M;6EN:7-T<F%Z:6]N
M92!'<G5P<&D`1W)U<'!I`%!E<FUE<W-I($]S<&ET:0!!;'1E>GIA`$%I=71O
M`$5M:7-F97)O`$%L=&$`2&]?<F1E`$AO<F1E`%)I96UP:6UE;G1O($]R:7IZ
M;VYT86QE`$]R:7IZ;VYT86QE.@!1=6%N=&4@8V]L;VYN92!V=6]I('5N:7)E
M/P!1=6%N=&D@8V%M<&D@*&-O;&]N;F4I(&-I('-O;F\_`%%U86YT92!R:6=H
M92!V=6]I('5N:7)E/P!5;6ED:73@`$E?;G-E<FES8VD@;&$@<FEG82!P<FEM
M80!3;VQO($EC;VYE`$EC;VYE(&-O;B!497-T;P!.;VUE(&1E;&PG261E;G1I
M=.`Z`$%N=&5P<FEM92!);6UA9VEN90!54DP@26UM86=I;F4`55),($EM;6%G
M:6YE`$EM;6%G:6YI`$EM<&]R=&%Z:6]N92!!<'!U;G1I+"!087-S;R`E9`!)
M;7!O<G1A+"!087-S;R`E9`!);7!O<G1A+T5S<&]R=&$@07!P=6YT:0!#86UP
M;R!I;7!O<G1A=&\Z("5S`$-A;7!I(&EM<&]R=&%T:3H`26Y?<V5R:7-C:2!U
M;F$@<FEG82!D;W!O`%5T96YT:2!);F1I=FED=6%L:0!);F9O<FUA>FEO;F4`
M26YS97)I<V-I('5N82!#7V]L;VYN82!D;W!O`$EN<V5R:7-C:2!U;B=I;6UA
M9VEN90!);G-E<FES8VD@5&%B96QL80!);G-E<FES8VD@0V]L;&5G86UE;G1O
M(%=E8@!);G-E<FES8VD@7V-O;&]N;F$@4')I;6$`26YS97)I<V-I('5N82!N
M=6]V82!C;VQO;FYA(&1O<&\@<75E;&QA(&-O<G)E;G1E`$EN<V5R:7-C:2!U
M;F$@;G5O=F$@8V]L;VYN82!P<FEM82!D:2!Q=65L;&$@8V]R<F5N=&4`26YS
M97)I<V-I('5N82!N=6]V82!R:6=A(&1O<&\@<75E;&QA(&-O<G)E;G1E`$EN
M<V5R:7-C:2!U;F$@;G5O=F$@<FEG82!P<FEM82!D:2!Q=65L;&$@8V]R<F5N
M=&4`26YS97)I<V-I('5N('1E;7!L871E(&%L=&5R;F%T:79O`$EN<V5R:7-C
M:2!C96QL82!D;W!O`$EN<V5R:7-C:2!C96QL82!P<FEM80!!9V=I=6YG:2!C
M;VQO;FYA(&1O<&\`26YS97)I<V-I(&-O;&]N;F$@<')I;6$`26YS97)I<V-I
M('!A<F%G<F%F;R!D;W!O`$EN<V5R:7-C:2!P87)A9W)A9F\@<')I;6$`26YS
M97)I<V-I(')I9V$@9&]P;P!);G-E<FES8VD@<FEG82!P<FEM80!);G-E<FES
M8VDO36]D:69I8V$@26UM86=I;F4`07!P;&EC87II;VYE(&EN=F%L:61A+@!$
M871O(&YO;B!V86QI9&\N`$EN=F5N=&%R:6\`0V]R<VEV;P!'96YN86EO`$=I
M87!P;VYE<V4@*$E33RTR,#(R+4I0*0!,=6=L:6\`1VEU9VYO`$=I=7-T:69I
M8V%T;P!?1F]R;6%T;P!,:6YG=6$`56QT:6UA($UO9&EF:6-A`%5L=&EM;R!1
M=6%R=&\`56QT:6UO($%G9VEO<FYA;65N=&\Z`%5L=&EM;R!A8V-E<W-O.B`E
M<P!5;'1I;6\@86-C97-S;SH@)7,@9&$@)7,`56QT:6UO(&%C8V5S<V\Z($UA
M:0!&;W)M871O`'-I;FES=')A`%!I;V=G:6$@3&5G9V5R80!%;&5N8V$@9VQI
M(&%R9V]M96YT:2!D:2!!:75T;P!.;VX@Z"!A='1I=F$@;&$@9G5N>FEO;F4@
M9&D@96QE;F-O('5T96YT:2X`3&ET97)A='5R80!/<F$@;&]C86QE.B``3&EN
M9W5A(&4@3W)A`$QU;V=O`$5N=')A`$5S8VD`0V]M<&ET:2!D:2!I;FEZ:6\@
M<V5S<VEO;F4`0F%S<V$`;G5M97)I(')O;6%N:2!P:?D@8F%S<VD`34T`4&]S
M=&$`26YD:7)I>GIO($%M;6EN:7-T<F%T;W)E`$=E<W1I<V-I(&QA(&QI<W1A
M(&1E;&QE(&-A=&5G;W)I92!D86YD;R!L;W)O('5N)V5T:6-H971T82!E(&%S
M<V]C:6%N9&\@;&]R;R!U;B!C;VQO<F4N`$UA<GIO`$UA<F=I;F4`0V%M<&D@
M8V]R<FES<&]N9&5N=&D`36%G9VEO`$UE;6)R:0!497-T;R!!<'!U;G1I`%5N
M:7-C:2!#96QL90!-971E;R!!='1U86QE`$)L;V-K(&YO;B!D:7-P;VYI8FEL
M92X`1&5T=&%G;&D@;&]G9V%T:2!P97(@;"=A;6UI;FES=')A=&]R90!M971R
M:6-O`$-E;G1R;P!,=6X`36]B:6QE($UA:6P`36]D97)A=&\`36]D:69I8V$@
M55),`$UO9&EF:6-A(&EN(&-O<G-O("5S`%!R:6YC:7!A;&UE;G1E(%-E<F5N
M;P!-:6\@06-C;W5N=`!";&]C8V\@07!P=6YT:0!-:6\@4&]R=&%L90!&;W)M
M871O(&1E;"!-:6\@4&]R=&%L90!.3RP@3D].(%-O;F\@9"=!8V-O<F1O+@!2
M971E`$UA:0!.=6]V82!#871E9V]R:6$`3G5O=F\@07!P=6YT;P!.=6]V;R!.
M;VUE(%5T96YT92`H3W!Z:6]N86QE*0!.;W1I>FEE`$=R=7!P:2!D:2!N;W1I
M>FEE`%-U8V-E<W-I=F\`3F]T=&4`3F]N('!U;VD@8W)E87)E(&9I9VQI(&$@
M<75E<W1O('!E<FUE<W-O+@!.97-S=6X@8FQO8V-O(&%P<'5N=&D@9&ES<&]N
M:6)I;&4@<&5R(&=L:2!O<W!I=&DN`$YE<W-U;B!A<'!U;G1O`$YE<W-U;B!A
M<'!U;G1O(&-O<G)I<W!O;F1E(&%L(&-R:71E<FEO(&-O<G)E;G1E+@!.97-S
M=6X@87!P=6YT;R!D82!V:7-U86QI>GIA<F4`3F5S<W5N82!R96=I<W1R87II
M;VYE(&EN(&%T=&5S82X`3F5S<W5N82!R96=O;&$`3F5S<W5N(&QA=&\`3F5S
M<W5N(&1I<F5T=&]R:6\@=&5M<&]R86YE;R!D:7-P;VYI8FEL92!P97(@;&$@
M8V%C:&4N`$YE<W-U;F$@=F5R<VEO;F4@=')O=F%T82!N96QL82!C;VYF:6=U
M<F%Z:6]N92!O<FEG:6YA;&4N(%)E9V5N97)A(&QA(&-O;F9I9W5R87II;VYE
M+@!.97-S=6YA('9E<G-I;VYE('1R;W9A=&$@;F5L;&$@='5A(&-O;F9I9W5R
M87II;VYE+B!296=E;F5R82!L82!C;VYF:6=U<F%Z:6]N92X`3F]?=&4`3F5S
M<W5N;P!.;VX@:6UP;W-T871O`$-A=&5G;W)I82!!<'!U;G1O`$1E='1A9VQI
M($%P<'5N=&\`3&ES=&$@07!P=6YT:0!497-T;R!!<'!U;G1O`%1E<W1O($%P
M<'5N=&\`1FEL92!D:2!F;VYT(&YO;B!T<F]V871O+@!";&]C8V\@07!P=6YT
M;P!.;VUE($)L;V-C;R!!<'!U;G1I.@!";&]C8VAI($%P<'5N=&D`3F]M92!"
M;&]C8V\@07!P=6YT:3H`3F]T90!3;VUM87)I;R!!<'!U;G1I`$YO=F5M8G)E
M`$YU;65R;R!D:2!C;VQO;FYE`$YU;65R;R!D:2!R:6=H90!/2P!0<F]P<FEE
M=&%R:6\`3W1T;V)R90!59F9I8VEO`$%P<FD@:6X@;G5O=F$@9FEN97-T<F$`
M07!R:2!Q=65S=&\@8V]L;&5G86UE;G1O(&EN(&YU;W9A(&9I;F5S=')A`$]P
M>FEO;FD`3W!Z:6]N:2!F;W(@)7,`1W)O=7!787)E`&%P<&QI8V%Z:6]N92!I
M;G1E<FYA`$%L=')O`$%L=')E($EN9F]R;6%Z:6]N:0!!;'1R92!/<'II;VYI
M`%!E<FUE<W-I(&1E;"!0<F]P<FEE=&%R:6\`0V]D:6-E(%!(4`!032!0:6]G
M9VEA($QE9V=E<F$`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``3&4@
M<&%S<W=O<F0@9&5V;VYO(&-O<G)I<W!O;F1E<F4N`$EN8V]L;&$`4&5R8V]R
M<V\`4F5G:7-T<F%Z:6]N:2!I;B!!='1E<V$Z`%!E<F-E;G1U86QE`$5S96=U
M:2!L92!/<&5R87II;VYI(&1I($UA;G5T96YZ:6]N90!%<V5G=6D@;&4@;W!E
M<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4@86P@;&]G:6X_`%!E<FUE<W-I`%!E
M<FUE<W-O($YE9V%T;P!097)M97-S:0!!;6UI;FES=')A>FEO;F4@9&5I(%!E
M<FUE<W-I`$EN9F]R;6%Z:6]N:2!097)S;VYA;&D`1F]T;P!0:7AE;`!0<F5G
M;R!C;VYF97)M87)E(&5L:6UI;F%Z:6]N92!E;&5M96YT;SH`4')E9V\@8V]N
M9F5R;6%R92!E;&EM:6YA>FEO;F4@;&EN:SH`26YS97)I<V-I('5N(&YO;64@
M<&5R(&QA(&YU;W9A(&-A=&5G;W)I83H`1&5V:2!I;G-E<FER92!I;"!T=6\@
M;F]M92!U=&5N=&4@92!L82!P87-S=V]R9`!3;VYD86=G:0!0;W-I>FEO;F%M
M96YT;R!D:2!Q=65S=&$@:6UM86=I;F4N`%!O<VEZ:6]N86UE;G1O(&1I('%U
M97-T82!T86)E;&QA`%!R97-S:6]N90!0<F5S<VEO;F4@86P@;&EV96QL;R!D
M:2!M87)E.B``4')E<W-I;VYE.B``06YT97!R:6UA`$%N=&5P<FEM82!D96QL
M)VEM;6%G:6YE(&EN(&YU;W9A(&9I;F5S=')A`%-T86UP82!D;V-U;65N=&\@
M`%!R;V)L96UA`$1E<V-R:7II;VYE(&1E;"!P<F]B;&5M80!0<F]G971T:0!$
M;VUA;F1A`%!I;V=G:6$`4&EO9V=I82!0<F5S=&\`4&EO9V=I82!487)D:0!&
M;W)T=6YA($-A<W5A;&4`3&5G9VD`4VEC=7)O(&1I('9O;&5R(&5L:6UI8V%R
M925S/R!,)V]P97)A>FEO;F4@;F]N('!U;R<@97-S97)E(&%N;G5L;&%T80!3
M:6-U<F\@9&D@=F]L97(@96QI;6EN87)E(&D@9&%T:2!D:2`E<S\@3"=O<&5R
M87II;VYE(&YO;B!P=6\G(&5S<V5R92!A;FYU;&QA=&$`06=G:6]R;F$@3&ES
M=&$`06=G:6]R;F$@;&$@=FES=6%L:7IZ87II;VYE(%!O<G1A;&4Z`$YO=&4`
M4V5R=F5R(%)E;6]T:0!54DP@<F5M;W1A("AH='1P.B\O=W=W+F5S96UP:6\N
M8V]M+VAO<F1E*3H`16QI;6EN80!%;&EM:6YA(&)L;V-C;P!2:6UU;W9I($-A
M=&5G;W)I80!2:6UU;W9I($9O<FUA='1A>FEO;F4`16QI;6EN82!P86EO`$5L
M:6UI;F$@:6P`16QI;6EN82!U=&5N=&4`16QI;6EN82!U=&5N=&4Z("5S`$%N
M;G5L;&$`06YN=6QL82!087-S=V]R9`!!;FYU;&QA(&QA('1U82!087-S=V]R
M9`!2:7-U;'1A=&D`5&]R;F$@86QL92!/<'II;VYI+@!);G9E<G1I(&QA($-O
M;F9I9W5R87II;VYE`$]P>FEO;FD@161I=&]R(%)I8V@@5&5X=`!2:61D;&5S
M`$1E<W1R80!0<F]P<FEE=.`@9&5L;&$@4E]I9V$N+BX`4')O<')I971A(&1E
M;&QA(')I9V$`4')O<')I973@(&1E;&QA(')I9V$`4FEG:&4Z`%)E9V]L90!%
M<V5G=6D`365S<V%G9VD@4TU3`%-A8@!386QV80!386QV82`E<P!386QV82!/
M<'II;VYI`%-A;'9A(&QA(&-O;F9I9W5R87II;VYE(&=E;F5R871E(&-O;64@
M<V-R:7!T(%!(4"!S=6QL82!C87)T96QL82!T96UP;W)A;F5A(&1E;"!T=6\@
M<V5R=F5R+@!386QV871O(&QA(&-O;F9I9W5R87II;VYE("5S+@!#97)C80!-
M;W1O<F4@9&D@<FEC97)C80!2:7-U;'1A=&D@4FEC97)C80!!;7!I97IZ82!2
M:6-E<F-A`%)I8V5R8V$@5&5S=&\`4VQE>FEO;F$@=6X@9W)U<'!O(&1A(&%G
M9VEU;F=E<F4`4V5L97II;VYA('5N(&YU;W9O('!R;W!R:65T87)I;P!396QE
M>FEO;F$@=6X@8FQO8V-O(&%P<'5N=&D`4V5L97II;VYA('5N('-E<G9E<@!3
M96QE>FEO;F$@=6X@=71E;G1E(&1A(&%G9VEU;F=E<F4`4V5L97II;VYA(&D@
M8V%R871T97)I(&1I(&-U:2!H86D@8FES;V=N;R!D86QL92!C87-E;&QE('%U
M:2!S;W1T;RX@4'5O:2!Q=6EN9&D@8V]P:6%R;&4@92!I;F-O;&QA<FQE(&1A
M;&QA('1E>'1A<F5A+@!396QE>FEO;F$@:6P@9&5L:6UI=&%T;W)E(&1I(&1A
M=&$Z`%-E<V-E9VQI(&EL(&9O<FUA=&\@9&5L;&$@9&%T83H`4V5L97II;VYA
M(&EL(&9O<FUA=&\@<&5R(&5S<&]R=&%R90!396QE>FEO;F$@:6P@9FEL92!D
M82!I;7!O<G1A<F4Z`%-E;&5Z:6]N82!I;"!F;W)M871O('9E<G-O(&-U:2!E
M<W!O<G1A<F4Z`%-E;&5Z:6]N82!I;"!D96QI;6ET871O<F4@9&5L;"=O<F$Z
M`%-C96=L:2!I;"!F;W)M871O(&1E;&PG;W)A.@!396QE>FEO;F$@9'5E(&-A
M;7!I(&-O<G)I<W!O;F1E;G1I+@!396QE>FEO;F$@:6P@='5O('-C:&5M82!C
M;VQO<FDN`%-E;&5Z:6]N82!L82!L:6YG=6$@8VAE('!R969E<FES8VDZ`%-E
M;&5Z:6]N82!#871E9V]R:64Z`$EN=FEA(&EL(')E<&]R="!D96P@<')O8FQE
M;6$`4V5N<V]R93H@`%-E='1E;6)R90!);7!O<W1I(&D@<V5R=F5R(')E;6]T
M:2!A:2!Q=6%L:2!V=6]I(&%C8V5D97)E(&1A;"!T=6\@<&]R=&%L92X`4V5L
M97II;VYA(&QA(&QI;F=U82!P<F5F97)I=&$@92!I;"!F=7-O(&]R87)I;RX`
M36]D:69I8V$@;&$@='5A(&%P<&QI8V%Z:6]N92!D:2!A=G9I;RP@9VQI('-C
M:&5M:2!C;VQO<F4L(&5D(&%L=')E(&]P>FEO;FD@9&D@=FES=6%L:7IZ87II
M;VYE+@!38W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96P@<V5T=7`@9&ES<&]N
M:6)I;&4`4VAO<'!I;F<`0G)E=F4@4FEA<W-U;G1O`$1E9FEN:6%M;R!G;&D@
M86-C97-S:2!D82!T87-T:65R82!P97(@:2!L:6YK/P!-;W-T<F$`36]S=')A
M($-O;G1A='1I`$UO<W1R82!L)W5L=&EM;R!L;V=I;B!A;&PG86-C97-S;S\`
M36]S=')A($)L;V-C:&D@07!P=6YT:3H`36]S=')A(&YO=&4@9&$@<75E<W1E
M(&-A=&5G;W)I90!-;W-T<F$@=&%B96QL82!O<&5R87II;VYI(&YE;&QA(&)A
M<G)A(&1E;"!M96YU/P!-;W-T<F$@:6P@)7,@365N;R!S=6QL82!S:6YI<W1R
M83\`36]S=')A(&QE(%!R;W!R:65TX"!486)E;&QA($-E;&QA`$UO<W1R82!L
M92!0<F]P<FEE=.`@5&%B96QL80!-;W-T<F$@;&4@4')O<')I973@(%1A8F5L
M;&$@4FEG80!!8W%U87IZ;VYI`$%C<75A>GIO;FD@82!"<F5V90!!8W%U87IZ
M;VYI(%1A<F1I`%-A;'1A($UA;G5T96YZ:6]N90!0<F]F;VYD:71A)R!D:2!N
M979E.B``3W)D:6YA('!E<B!#871E9V]R:6$`3W)D:6YA('!E<B!497-T;R!D
M:2!!<'!U;G1O`%-P87II871U<F$`4W!A;0!#87)A='1E<F4@4W!E8VEA;&4`
M1&EV:61I($-E;&QA`$1I=FED:2!C;VQO;FYA`$1I=FED:2!2:6=A`%-T86YD
M87)D`%-T871O`$1O;0!3;W1T;W-C<FEV:0!3=6-C97-S;P!386QV871O(&QA
M(&-O;F9I9W5R87II;VYE+@!38W)I='1O(&-O;B!S=6-C97-S;R`E<P!2:6%S
M<W5N=&\`06QB80!4<F%M;VYT;P!!;&)A`$%L8F$O5')A;6]N=&\`06QB83H@
M`%1R86UO;G1O`%1R86UO;G1O.B``4W5P97)S8W)I<'0`4W5P<&]R=&\`5"U4
M96UP97-T80!4+51E;7!E<W1E`%!R;W!R:65TX"!486)E;&QA`%!R;W!R:65T
MX"!486)E;&QA`$1E<W1I;F%Z:6]N93H`071T:79I=.``5&5M<&5R871U<F$@
M=6QT:6UA(&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``06UM:6YI
M<W1R87II;VYE(%1E;7!L871E`%-O;&\@5&5S=&\`06QL:6YE86UE;G1O('1E
M<W1O`%1E<W1O(&EN(&%L=&\`1VEO`$=R87II92!D:2!A=F5R('5S871O(&EL
M('-I<W1E;6$N`$PG:61E;G1I=.`@(B5S(B!E)R!S=&%T82!E;&EM:6YA=&$N
M`$PG07!P=6YT;R#H('-T871O(&5L:6UI;F%T;RX`26P@0FQO8V-O($%P<'5N
M=&D@(B5S(B!N;VX@Z"!S=&%T;R!C<F5A=&\Z("5S(`!);"!";&]C8V\@07!P
M=6YT:2`B)7,B(.@@<W1A=&\@8W)E871O+@!);"!B;&]C8V\@87!P=6YT:2`B
M)7,B(.@@<W1A=&\@96QI;6EN871O+@!);"!B;&]C8V\@87!P=6YT:2`B)7,B
M(.@@<W1A=&\@<V%L=F%T;RX`26P@<V5R=F5R("(E<R(@92<@<W1A=&\@96QI
M;6EN871O+@!);"!S97)V97(@(B5S(B!E)R!S=&%T;R!S86QV871O+@!,82!R
M:6-H:65S=&$@9&D@<F5G:7-T<F%Z:6]N92!P97(@)7,@Z"!S=&%T82!E;&EM
M:6YA=&$N`$EL(&UO9'5L;R!W96%T:&5R+F-O;2!N;VX@Z"!D:7-P;VYI8FEL
M92X`17)R;W)E(&YE;&PG:6UP;W)T87II;VYE(&1E:2!D871I.B`E<P!%<G)O
M<F4@;F5L;"=I;7!O<G1A>FEO;F4@9&5I(&1A=&DN`$5R<F]R92!N96QL82!R
M:6UO>FEO;F4@9&5L;"=A<'!U;G1O.B`E<P!%<G)O<F4@;F5L('-A;'9A=&%G
M9VEO(&1E;&PG87!P=6YT;SH@)7,`0R=E<F$@=6X@97)R;W)E(&YE;&PG87!E
M<G1U<F$@9&D@<75E<W1O('%U97-T;R!B;&]C8V\@87!P=6YT:3H@)7,`3F]N
M('9I(&5R86YO(&%P<'5N=&D@9&$@97-P;W)T87)E`%%U97-T;R!F;W)M871O
M(&YO;B#H('-U<'!O<G1A=&\`475E<W1O(&4G("5S+@!4=6]N;P!4:6-K970`
M1V5S=&EO;F4@9&5L(%1E;7!O`$9O<FUA=&\@3W)A`%1I=&]L;P!/9V=I`$1O
M;6%N:0!!;'1O`$UA<@!54DP`55),.@!);7!O<W-I8FEL92!E;&EM:6YA<F4@
M(B5S(CH@)7,`4V]T=&]L:6YE80!!;FYU;&QA(&QE($UO9&EF:6-H90!.;VX@
M8VQA<W-I9FEC871O`%5N:73@`$5L:6UI;F$@16QE;65N=&\@0V]R<F5N=&4`
M16QI;6EN82!#;VQO<F4`06=G:6]R;F$`06=G:6]R;F$@)7,`06=G:6]R;F$@
M=71E;G1E`%-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&5L:6UI;F%T;RX`06=G
M:6]R;F$`3G5M97(@<F]M86YI(&%L=&D`06UM:6YI<W1R87II;VYE(%5T96YT
M:0!296=I<W1R87II;VYE(%5T96YT90!)<V-R:7II;VYE(%5T96YT92!E)R!S
M=&%T;R!D:7-A8FEL:71A=&\@<&5R('%U97-T;R!S:71O+@!.;VUE(%5T96YT
M90!.;VUE(%5T96YT93H`3F]M92!5=&5N=&4Z`%5T96YT:2!N96P@<VES=&5M
M83H`5F%C86YZ90!687)I86)I;&4`0V]N=')O;&QO(%9E<G-I;VYE`$%L;&EN
M96%M96YT;P!2:65M<&EM96YT;R!697)T:6-A;&4`5F5R=&EC86QE.@!-;VQT
M;R!!;'1O`%9I<W5A;&EZ>F$@=6YA('!A9VEN82!W96(@97-T97)N80!6:7-I
M8FEL:73@`%9I<VEB:6QI=.`Z(`!-97(`4')E=FES:6]N92!-971E;P!796(`
M0F5N=F5N=71O`$)E;G9E;G5T;R!A("5S`$)E;G9E;G5T;RP@)7,`0VAE(&%P
M<&QI8V%Z:6]N92`E<R!D979E(&UO<W1R87)E(&1O<&\@:6P@;&]G:6X_`$-O
M<V$@92<@8V%R871T97)E(&1E;&EM:71A=&]R90!#;W-A(&4G(&EL(&-A<F%T
M=&5R92!V:7)G;VQE='1E/P!!('%U86QE($)L;V-C;R!!<'!U;G1I(&%G9VEU
M;F=E<F4@9VQI(&%P<'5N=&D_`$QA<F=H97IZ80!!;7!I97IZ82!D96QL82!T
M86)E;&QA`%5N:73@($QA<F=H97IZ80!,87)G:&5Z>F$Z`%9E;G1O.@!696YT
M;SH@`$%!`%-I+"!S;VYO(&0G86-C;W)D;P!.;VX@:&%I(&EL('!E<FUE<W-O
M(&1I('9I<W5A;&EZ>F%R92!I;"!B;&]C8V\@87!P=6YT:2`E<RX`3&$@<V5S
M<VEO;F4@Z"!S=&%T82!T97)M:6YA=&$N`$1E=FD@<V5L97II;VYA<F4@=6X@
M8FQO8V-O(&%P<'5N=&D@9&$@96QI;6EN87)E+@!$979I('-P96-I9FEC87)E
M(&EL('-E<G9E<B!D82!E;&EM:6YA<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@
M=7-E<FYA;64@9&$@<FEM=6]V97)E+@!$979I('-P96-I9FEC87)E(&QO('5S
M97)N86UE(&1A(')I;75O=F5R92X`1&5V:2!S<&5C:69I8V%R92!L;R!U<V5R
M;F%M92!D82!A9V=I=6YG97)E+@!$979I('-P96-I9FEC87)E(&QO('5S97)N
M86UE(&1A(&%G9VEO<FYA<F4N`%1U;R!);F1I<FEZ>F\@16UA:6P`5'5O($EN
M9&ER:7IZ;R!%;6%I;`!6;W-T<F$@:6YF;W)M87II;VYE`$EL('1U;R!N;VUE
M`$EL('1U;R!B86-K96YD(&1I(&%U=&5N=&EC87II;VYE(&YO;B!S=7!P;W)T
M82!L82!E;&5N8V%Z:6]N92!D96=L:2!U=&5N=&DL(&\@;&$@8V%R871T97)I
M<W1I8V$@Z"!S=&%T82!D:7-A8FEL:71A=&$@<&5R('%U86QC:&4@;6]T:79O
M+@!);"!T=6\@8G)O=W-E<B!N;VX@:&$@<75E<W1A(&-A<&%B:6QI=&$G+@!)
M;"!T=6\@9G5S;R!O<F%R:6\@871T=6%L93H`261E;G1I=.`@9&D@1&5F875L
M=`!";&]C8V\@87!P=6YT:2!D:2!D969A=6QT.@!);"!T=6\@;F]M93H`22!T
M=6]I(&)L;V-C:&D@87!P=6YT:3H`22!T=6]I('-E<G9E<B!R96UO=&DZ`%M$
M;V-U;65N=&\@9&D@9&5S8W)I>FEO;F4@9&5L('!R;V)L96UA70!;36]S=')A
M(%1E<W1O('%U;W1A=&\@+0!?06UM:6YI<W1R87II;VYE`%1O<FYA(&%L($)L
M;V-C;R!!<'!U;G1I`$-A=&5G;W)I80!?1&%T851R964`7T5L:6UI;F$`7T5L
M:6UI;F$@4FEG80!?36]D:69I8V$`4')I;6$@4FEG80!?1W)U<'!I`%]!:75T
M;P!0<F]P<FEE=.`@9&5L;"=?26UM86=I;F4N+BX`7TEM<&]R=&$O17-P;W)T
M80!,:7-T82!!<'!U;G1I`%]&:6YE('-E<W-I;VYE`%]-;V1I9FEC82!,:6YK
M+BXN.@!?0FQO8V-O($%P<'5N=&D`7TYU;W9O($%P<'5N=&\`7T]P>FEO;FD`
M7U!E<FUE<W-I`%-T86UP80!?16QI;6EN82!,:6YK+BXN`%]#97)C80!0<F]P
M<FEE=.`@9&5L;&$@7U1A8F5L;&$`7U5T96YT:0!C86QM;P!D86QL92`E<R`H
M)7,I(&%L;&4@)7,@)7,`;&EN965=`&YO;64`87!P=6YT:2YC<W8`<&5R8V5N
M=&\`<&EX96QS`&%U;65N=&%N9&\G`&-O<W1A;G1E`&1I9VET82!L82!P87-S
M=V]R9"!D=64@=F]L=&4@<&5R(&-O;F9E<FUA<F4`=DYO=&4`=V5A=&AE<BYC
M;VT`````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;6YE;6\O;&]C86QE+VET7TE4+VAE;'`N>&UL````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#8W,``Q,#0Q-S,V,C<T-``P,C$T-C0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]X;6P@=F5R
M<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,2(_/@H\(2TM("1(;W)D
M93H@;6YE;6\O;&]C86QE+VET7TE4+VAE;'`N>&UL+'8@,2XS(#(P,#,O,#<O
M,#0@,C`Z-3$Z-#4@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60]
M(D]V97)V:65W(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-3!E93<V,3,X9F(P
M.&(P-&(P,CDP,#8P-3-B8F%D8F,B/@H@("`@/'1I=&QE/D]V97)V:65W/"]T
M:71L93X*("`@(#QH96%D:6YG/DEN=')O9'5C=&EO;CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@/&D^07!P=6YT:3PO:3X@Z"!U;B!P<F]G<F%M;6$@8VAE
M('1I('!E<FUE='1E(&1I(&-R96%R92!G;&D@97%U:79A;&5N=&D@:6YF;W)M
M871I8VD@9&5I(%!O<W0M272N+B!';&D@87!P=6YT:2!P;W-S;VYO(&5S<V5R
M92!C<F5A=&DL(&UO9&EF:6-A=&DL(&5L:6UI;F%T:2!E('-T86UP871I+B!)
M;F]L=')E+"!P=6]I(&9A<F4@9&5L;&4@<FEC97)C:&4@<W5I('1U;VD@87!P
M=6YT:2!P97(@=')O=F%R92!L)VEN9F]R;6%Z:6]N:2X@12<@9&ES<&]N:6)I
M;&4@86YC:&4@:6P@<W5P<&]R=&\@<&5R(&PG:6UP;W)T87II;VYE(&4@;"=E
M<W!O<G1A>FEO;F4@9&5G;&D@87!P=6YT:2X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@06P@8V]N=')A<FEO(&1E:2!0;W-T+4ETKBP@:2!T=6]I(&%P
M<'5N=&D@:6YF;W)M871I8VD@<&]S<V]N;R!E<W-E<F4@8V]N9&EV:7-I(&-O
M;B!G;&D@86QT<FD@;F5I(&1I=F5R<VD@;'5O9VAI(&=E;V=R869I8VDN($=L
M:2!A<'!U;G1I('-I('!O<W-O;F\@;W)G86YI>GIA<F4@:6X@9&EV97)S:2!B
M;&]C8VAI(&%P<'5N=&D@92!D:79I9&5R92!I;B!C871E9V]R:64N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)L:7-T+6%C=&EO;G,B('-T
M871E/2)U<'1O9&%T92(@;60U/2(V9#4Y,F8Q-3-B9F(U8S(Y-F1E-61F96)B
M-#(X93%B82(^"B`@("`\=&ET;&4^3&ES=&$@3F]T93H@07II;VYI/"]T:71L
M93X*("`@(#QH96%D:6YG/D%Z:6]N:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@/&D^0V%N8V5L;&$@3F]T83PO:3X@96QI;6EN82!I;B!M;V1O('!E<FUA
M;F5N=&4@;&$@;F]T82!S96QE>FEO;F%T82X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@/&D^36]D:69I8V$@3F]T83PO:3X@<&5R;65T=&4@9&D@;6]D
M:69I8V%R92!U;F$@;F]T82!E<VES=&5N=&4N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@(#QI/E1O<FYA(&%L($)L;V-C;R!.;W1E/"]I/B!T;W)N82!I
M;F1I971R;R!D86QL82!V:7-T82!N;W1E(&%L(&)L;V-C;R!N;W1E+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UA8W1I;VYS(B!S
M=&%T93TB=7!T;V1A=&4B(&UD-3TB,S,R-6,Y8F4X-&,Y.#8W-3-D,V9D93`V
M,3(V-F0Y,S0B/@H@("`@/'1I=&QE/D]P>FEO;FD@365N=3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY/<'II;VYI($UE;G4\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(#QI/DQI<W1A($YO=&4\+VD^(&5L96YC82!T=71T92!L92!N;W1E('!R
M97-E;G1I(&YE;"!B;&]C8V\@;F]T92X*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@/&D^3G5O=F$@3F]T83PO:3X@<&5R;65T=&4@9&D@8W)E87)E('5N
M82!N=6]V82!N;W1A(&YE;"!B;&]C8V\@;F]T92X*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@/&D^4FEC97)C83PO:3X@<&5R;65T=&4@9&D@<FEC97)C
M87)E('5N('1E<W1O(&YE;&QE(&YO=&4N($4G('!O<W-O8FEL92!F87)E(')I
M8V5R8V$@;F5L(&-A;7!O($1E<V-R:7II;VYE(&\@;F5L('1E<W1O(&-O;7!L
M971O(&1E;&QE(&YO=&4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#QI
M/E-T86UP83PO:3X@<&5R;65T=&4@9&D@<W1A;7!A<F4@=6YA(&YO=&$N($PG
M:6-O;F$@/&D^4W1A;7!A/"]I/B#H('!R97-E;G1E(&YE;"!M96YU('-O;&\@
M<75A;F1O('-I('-T82!V:7-U86QI>GIA;F1O('5N82!N;W1A+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V]R=&EN9R(@<W1A=&4](G5P
M=&]D871E(B!M9#4](F-C83-B,60Q8SEE9#!E8S5A8C,X-68X,C0V.61D8SAF
M(CX*("`@(#QT:71L93Y/<F1I;F%M96YT;R!6;V-I/"]T:71L93X*("`@(#QH
M96%D:6YG/D]R9&EN86UE;G1O(%9O8VD\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%%U86YD:2!V:65N92!V:7-U86QI>GIA=&\@=6X@96QE;F-O(&1I('9O
M8VDL(&4G('!O<W-I8FEL92!F87)N92!L)V]R9&EN86UE;G1O('!E<B!C;VQO
M;FYA+"!A;F1A;F1O(&$@<V5L97II;VYA<F4@:6P@=&ET;VQO(&1E;&QA(&-O
M;&]N;F$@87!P<F]P<FEA=&$N(%!E<B!P87-S87)E(&1A('5N(&]R9&EN86UE
M;G1O(&-R97-C96YT92!A9"!U;F\@9&5C<F5S8V5N=&4@Z"!S=69F:6-I96YT
M92!C;&EC8V%R92!S=6QL)VEC;VYA(&9R96-C:6$@<')E<V5N=&4@;F5L('1I
M=&]L;R!D96QL82!C;VQO;FYA+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE
M;'`^"@``````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+VQT7TQ4+P``````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P
M,C`P,30`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O;'1?
M3%0O3$-?34534T%'15,O````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S0T`#`R,38P,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VUN96UO+VQO8V%L92]L=%],5"],0U]-15-304=%4R]M;F5M;RYM;P``````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`S-#8R,S$`,3`T,3<S-C(W-#0`,#(S,C4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
MU08``!P```#$-@``'0D``&QM````````X)$```X```#AD0``#P```/"1```(
M`````)(```P````)D@``!````!:2```,````&Y(```@````HD@``#P```#&2
M```+````09(```X```!-D@``!0```%R2```H````8I(```H```"+D@``%0``
M`):2```2````K)(```L```"_D@``'0```,N2```.````Z9(```H```#XD@``
M#0````.3```.````$9,``!$````@DP``#0```#*3```,````0),```T```!-
MDP``!@```%N3```/````8I,``!@```!RDP``#````(N3```&````F),```X`
M``"?DP``#@```*Z3```(````O9,``"X```#&DP``&@```/63```R````$)0`
M`#@```!#E```5````'R4``!1````T90``%H````CE0``5P```'Z5```T````
MUI4```H````+E@``!0```!:6```&````')8``!$````CE@``"````#66```)
M````/I8```D```!(E@``)0```%*6```@````>)8``!P```"9E@``'@```+:6
M```@````U98``!T```#VE@``$````!27```/````)9<```H````UEP```P``
M`$"7```/````1)<``!0```!4EP``"0```&F7```-````<Y<``!(```"!EP``
M#P```)27```,````I)<```H```"QEP``#P```+R7```(````S)<``"0```#5
MEP``%````/J7```6````#Y@```@````FF```$0```"^8```9````09@```<`
M``!;F```#````&.8```L````<)@```X```"=F````P```*R8```+````L)@`
M``<```"\F```!P```,28```%````S)@```4```#2F```"@```-B8```#````
MXY@``!<```#GF```"@```/^8```/````"ID```X````:F0``&````"F9```C
M````0ID```X```!FF0``%````'69```7````BID``!<```"BF0``%P```+J9
M```3````TID```\```#FF0``#@```/:9```?````!9H```<````EF@``!@``
M`"V:```(````-)H```\````]F@``!@```$V:```*````5)H``!,```!?F@``
M"P```'.:```5````?YH``!4```"5F@``!P```*N:```%````LYH``!4```"Y
MF@``$0```,^:```,````X9H``#L```#NF@``"0```"J;```'````-)L``!0`
M```\FP```P```%&;```%````59L```D```!;FP``$````&6;```)````=IL`
M`!,```"`FP``.0```)2;```2````SIL``"<```#AFP``+`````F<```J````
M-IP``"4```!AG```"@```(><```&````DIP```D```"9G```!P```*.<```O
M````JYP``#<```#;G```+@```!.=``!5````0IT``"T```"8G0``+0```,:=
M```M````])T``$`````BG@``(P```&.>```C````AYX``"T```"KG@``,P``
M`-F>```5````#9\``!D````CGP``*0```#V?```D````9Y\``!4```",GP``
M$0```**?```*````M)\```P```"_GP``#P```,R?```7````W)\```H```#T
MGP``$````/^?```6````$*```!8````GH```!P```#Z@```'````1J```!0`
M``!.H```"@```&.@```(````;J````@```!WH```!P```("@```'````B*``
M``8```"0H```!0```)>@```'````G:````8```"EH```"````*R@```.````
MM:````H```#$H```!````,^@```'````U*````D```#<H```!@```.:@```1
M````[:````<```#_H```%@````>A```$````'J$```@````CH0``!@```"RA
M```-````,Z$```8```!!H0``'@```$BA```1````9Z$```@```!YH0``#0``
M`(*A```,````D*$```<```"=H0```P```*6A```#````J:$``!<```"MH0``
M`P```,6A```3````R:$```@```#=H0``!````.:A```(````ZZ$```@```#T
MH0``00```/VA```@````/Z(```8```!@H@``!@```&>B```5````;J(``!@`
M``"$H@``(@```)VB```N````P*(``!T```#OH@``(0````VC``!4````+Z,`
M`"D```"$HP``"@```*ZC```'````N:,``!4```#!HP``"````->C```.````
MX*,```H```#OHP``#P```/JC```-````"J0```\````8I```#0```"BD```)
M````-J0``!0```!`I```!@```%6D```8````7*0``!T```!UI```$P```).D
M```4````IZ0```0```"\I```!@```,&D``!4````R*0``"T````=I0``!```
M`$NE```.````4*4```4```!?I0``!0```&6E```;````:Z4``!H```"'I0``
M$0```**E```1````M*4``!P```#&I0``*@```..E```W````#J8``!````!&
MI@``(0```%>F```%````>:8```H```!_I@``$P```(JF```2````GJ8```H`
M``"QI@``#P```+RF```1````S*8``!,```#>I@``#````/*F```&````_Z8`
M``8````&IP``%P````VG```1````):<```@````WIP``!0```$"G```,````
M1J<``!````!3IP``!0```&2G```-````:J<```8```!XIP``!P```'^G```-
M````AZ<```<```"5IP``"P```)VG```'````J:<```<```"QIP``"0```+FG
M```*````PZ<``!D```#.IP``#````.BG```0````]:<```4````&J```)0``
M``RH```2````,J@``!,```!%J```*P```%FH```[````A:@``"````#!J```
M-@```.*H```(````&:D```P````BJ0``!@```"^I```$````-JD```X````[
MJ0``"@```$JI```-````5:D``!X```!CJ0``&P```(*I```A````GJD``!X`
M``#`J0``&0```-^I```>````^:D``!L````8J@``)@```#2J```;````6ZH`
M`!X```!WJ@``'````):J```F````LZH``#,```#:J@``)@````ZK```K````
M-:L``#@```!AJP``+P```)JK```2````RJL``"D```#=JP``$@````>L``"B
M````&JP``!8```"]K```(P```-2L```H````^*P``"D````AK0``*````$NM
M```?````=*T``"````"4K0``)0```+6M```A````VZT``!P```#]K0``)@``
M`!JN``!!````0:X```P```"#K@``!P```)"N```'````F*X```8```"@K@``
M#0```*>N```0````M:X``!(```#&K@``!P```-FN```3````X:X``!(```#U
MK@``!P````BO```$````$*\```P````5KP``#@```"*O```/````,:\``!,`
M``!!KP``#0```%6O```H````8Z\```,```",KP``#0```)"O```&````GJ\`
M`!$```"EKP``%P```+>O```;````SZ\```X```#KKP```@```/JO```%````
M_:\``!`````#L```!````!2P```-````&;````X````GL````P```#:P```.
M````.K````@```!)L```#P```%*P```/````8K````T```!RL```$````("P
M```9````D;```!H```"KL```"P```,:P```&````TK````P```#9L```$0``
M`.:P```9````^+````L````2L0``#0```!ZQ```B````++$```H```!/L0``
M&````%JQ```9````<[$``!8```"-L0``#0```*2Q```'````LK$```H```"Z
ML0``%````,6Q```+````VK$```P```#FL0``(@```/.Q```O````%K(```L`
M``!&L@``"0```%*R```9````7+(```L```!VL@``%P```(*R```7````FK(`
M``D```"RL@``%@```+RR```/````T[(``!8```#CL@``#@```/JR```8````
M";,```@````BLP``#0```"NS```F````.;,``$,```!@LP``"````*2S```2
M````K;,```@```#`LP``"P```,FS```O````U;,```X````%M```!0```!2T
M```&````&K0```,````AM```!P```"6T```$````+;0```H````RM```"@``
M`#VT```)````2+0```\```!2M```$````&*T```7````<[0``!$```"+M```
M%P```)VT```)````M;0```4```"_M```"P```,6T```*````T;0```(```#<
MM```!0```-^T```-````Y;0``!L```#SM```%P````^U```)````)[4```H`
M```QM0``#@```#RU```-````2[4``!(```!9M0``.````&RU```@````I;4`
M``@```#&M0``#@```,^U``![````WK4``!@```!:M@``$0```'.V```'````
MA;8```4```"-M@``&0```).V```'````K;8```@```"UM@``!@```+ZV```&
M````Q;8``!````#,M@``#P```-VV```0````[;8```\```#^M@``"P````ZW
M```/````&K<```P````JMP``#P```#>W```'````1[<```8```!/MP``#```
M`%:W```H````8[<```\```",MP``"````)RW```&````I;<```P```"LMP``
M"````+FW```3````PK<```H```#6MP``'@```.&W```A`````+@``"`````B
MN```&0```$.X```7````7;@``"4```!UN```%P```)NX```$````L[@``!L`
M``"XN```#0```-2X```#````XK@```@```#FN```"@```.^X```,````^K@`
M``L````'N0``!````!.Y```3````&+D``!0````LN0``#````$&Y```)````
M3KD```X```!8N0``"P```&>Y```;````<[D```<```"/N0``!P```)>Y```*
M````G[D```T```"JN0``"0```+BY```$````PKD```4```#'N0```P```,VY
M```8````T;D```H```#JN0``!````/6Y```F````^KD```X````AN@``?```
M`#"Z```5````K;H```4```##N@``!P```,FZ```,````T;H```@```#>N@``
M"@```.>Z```&````\KH```@```#YN@```@````*[```&````!;L```8````,
MNP``%````!.[```-````*+L``!`````VNP``&P```$>[```$````8[L```D`
M``!HNP``$````'*[```)````@[L```D```"-NP``!0```)>[```:````G;L`
M``@```"XNP``!@```,&[```9````R+L```X```#BNP``!P```/&[```'````
M^;L```4````!O```"0````>\```*````$;P```(````<O```!@```!^\```-
M````)KP```D````TO```!@```#Z\```2````1;P```D```!8O```!P```&*\
M```4````:KP``!T```!_O```!@```)V\```*````I+P```0```"OO```"0``
M`+2\```(````OKP``!$```#'O```"0```-F\```&````X[P```T```#JO```
M!@```/B\```$````_[P``#D````$O0``/0```#Z]```Z````?+T``!X```"W
MO0``!0```-:]```.````W+T```0```#KO0``!@```/"]```A````][T``!4`
M```9O@``!@```"^^```$````-KX``!$````[O@``!@```$V^```*````5+X`
M`"(```!?O@``!````(*^```%````A[X``!T```"-O@``!````*N^```,````
ML+X```H```"]O@``"````,B^```)````T;X```4```#;O@``.@```.&^```P
M````'+\``#4```!-OP``*0```(._``!'````K;\``#@```#UOP``*0```"[`
M```_````6,```"X```"8P```+0```,?````?````]<````\````5P0``$@``
M`"7!```+````.,$``"8```!$P0``*0```&O!```D````E<$``"8```"ZP0``
M"````.'!```*````ZL$```D```#UP0``!P```/_!```@````!\(``"`````H
MP@``)@```$G"```*````<,(``!D```![P@``*0```)7"```6````O\(``!(`
M``#6P@``!P```.G"```*````\<(```\```#\P@``$`````S#``!`````'<,`
M`&8```!>PP``#@```,7#```)````U,,```H```#>PP``$@```.G#```3````
M_,,```P````0Q```!@```!W$```5````),0```\````ZQ```$P```$K$```2
M````7L0``!````!QQ```$0```(+$```<````E,0``",```"QQ```:@```-7$
M```/````0,4```4```!0Q0``$````%;%```)````9\4```0```!QQ0``"P``
M`';%```4````@L4```P```"7Q0``#````*3%```/````L<4``!4```#!Q0``
M*0```-?%```J`````<8``"8````LQ@``)P```%/&```I````>\8``"H```"E
MQ@``&0```-#&``!"````ZL8``!$````MQP``$@```#_'```3````4L<``!0`
M``!FQP``#P```'O'```6````B\<``!<```"BQP``$````+K'```1````R\<`
M`#0```#=QP``$P```!+(```2````)L@``#4````YR```%````&_(```'````
MA,@```P```",R```(````)G(```4````NL@``!$```#/R```%P```.'(```<
M````^<@``!,````6R0``$0```"K)```:````/,D``!X```!7R0``&@```';)
M```1````D<D``!0```"CR0``%P```+C)```5````T,D```D```#FR0``&0``
M`/#)```$````"LH```<````/R@``"P```!?*```1````(\H```8````UR@``
M!@```#S*```&````0\H```4```!*R@``!P```%#*```'````6,H```4```!@
MR@``%@```&;*```&````?<H```8```"$R@``!````(O*```$````D,H```<`
M``"5R@``#@```)W*```,````K,H```P```"YR@``#0```,;*```*````U,H`
M``X```#?R@``!0```.[*```H````],H```X````=RP``#````"S+```/````
M.<L```H```!)RP``"````%3+```)````7<L``"L```!GRP``!````)/+```(
M````F,L``"8```"ARP``$@```,C+```/````V\L```8```#KRP``"@```/++
M```'````_<L```@````%S```(`````[,```)````+\P```T````YS```#```
M`$?,```-````5,P```X```!BS```%@```'',```1````B,P```8```":S```
M`P```*',```&````I<P``!D```"LS```!P```,;,```$````SLP```L```#3
MS```"P```-_,```'````Z\P```<```#SS```%@```/O,```-````$LT```T`
M```@S0``"@```"[-```0````.<T```\```!*S0``$0```%K-```7````;,T`
M``H```"$S0``$0```(_-```(````H<T```0```"JS0``#P```*_-```Z````
MO\T```4```#ZS0``#`````#.```>````#<X```X````LS@``$````#O.```+
M````3,X```P```!8S@``"0```&7.```'````;\X```H```!WS@``"0```(+.
M```.````C,X``!````";S@``&@```*S.```*````Q\X```D```#2S@``"@``
M`-S.```,````Y\X```\```#TS@``"`````3/```&````#<\```<````4SP``
M"P```!S/``!'````*,\```T```!PSP``"0```'[/```$````B,\```,```"-
MSP``$P```)'/```3````I<\``!,```"YSP``"@```,W/```"````V,\```0`
M``#;SP``)0```.#/```#````!M````4````*T```*@```!#0```*````.]``
M``4```!&T```!````$S0```*````4=````T```!<T```!@```&K0```(````
M<=````@```!ZT```!````(/0```%````B-```&@```".T```"0```/?0```,
M`````=$```4````.T0``!@```!31```;````&]$``"\````WT0``$````&?1
M```*````>-$```\```"#T0``"@```)/1```)````GM$``!,```"HT0``&P``
M`+S1```8````V-$``!<```#QT0``#@````G2```#````&-(```<````<T@``
M"````"32```'````+=(```D````UT@``"@```#_2```+````2M(```<```!6
MT@``40```%[2```0````L-(```P```#!T@``#0```,[2```:````W-(``$H`
M``#WT@``!@```$+3```&````2=,```8```!0TP``'P```%?3```&````=],`
M``D```!^TP``&````(C3```7````H=,```8```"YTP``#0```,#3```B````
MSM,``%<```#QTP``$P```$G4```C````7=0``!,```"!U````@```)74```+
M````F-0```@```"DU```#0```*W4```*````N]0```P```#&U```!P```-/4
M```4````V]0```8```#PU```"````/?4```.`````-4```<````/U0``"@``
M`!?5```+````(M4```<````NU0``#````#;5```-````0]4```P```!1U0``
M"0```%[5```)````:-4```H```!RU0``!P```'W5```)````A=4```<```"/
MU0``"@```)?5```;````HM4``!(```"^U0``"@```-'5```(````W-4```D`
M``#EU0``$````._5```'`````-8``!(````(U@``!````!O6```'````(-8`
M``4````HU@``!0```"[6```+````--8``!0```!`U@``$0```%76```:````
M9]8``!8```""U@``%````)G6```7````KM8``!@```#&U@``'````-_6```9
M````_-8```<````6UP``!0```![7```-````)-<```P````RUP``"````#_7
M```(````2-<``!<```!1UP``"P```&G7```3````==<```0```")UP``"@``
M`([7```$````F=<```P```">UP``"0```*O7```%````M=<```<```"[UP``
M!0```,/7```$````R=<```(```#.UP``.````-'7```L````"M@``!(````W
MV```*0```$K8```R````=-@```H```"GV```+````++8```N````W]@``#,`
M```.V0``,P```$+9```X````=MD```\```"OV0``&````+_9```0````V-D`
M`!,```#IV0``%````/W9```2````$MH``"0````EV@``"````$K:```D````
M4]H``!,```!XV@``%````(S:```5````H=H``"T```"WV@``+0```.7:```Q
M````$]L``"X```!%VP``+P```'3;```L````I-L``&(```#1VP``$P```#3<
M```(````2-P```@```!1W```*P```%K<```A````AMP``!H```"HW```"0``
M`,/<``!%````S=P``$$````3W0``!0```%7=```$````6]T``!,```!@W0``
M%````'3=```.````B=T``!,```"8W0``&````*S=```&````Q=T```D```#,
MW0``"@```-;=```/````X=T``!````#QW0``!P````+>```.````"MX```T`
M```9W@``#````"?>```*````--X```D````_W@``"@```$G>```/````5-X`
M``@```!DW@``#P```&W>```(````?=X```4```"&W@``#0```(S>```;````
MFMX```@```"VW@``!@```+_>```4````QMX``!$```#;W@``#@```.W>```X
M````_-X```(````UWP``!@```#C?```.````/]\```4```!.WP``!P```%3?
M```.````7-\```8```!KWP``!````'+?```I````=]\``!<```"AWP``'P``
M`+G?``!<````V=\``!0````VX```'P```$O@```0````:^````<```!\X```
M#@```(3@```,````D^````P```"@X```$P```*W@```*````P>```!T```#,
MX```&0```.K@```%````!.$``!$````*X0``#0```!SA```1````*N$``"0`
M```\X0``%0```&'A```2````=^$```X```"*X0``&0```)GA```(````L^$`
M``D```"\X0``#0```,;A```*````U.$```L```#?X0``"@```.OA```'````
M]N$```@```#^X0``!0````?B```?````#>(```8````MX@``$````#3B```(
M````1>(```T```!.X@``"````%SB```2````9>(``"P```!XX@``&@```*7B
M```)````P.(```H```#*X@``%0```-7B```%````Z^(``!0```#QX@``!```
M``;C```0````"^,```8````<XP``!P```"/C```>````*^,``"@```!*XP``
M"@```'/C```1````?N,```L```"0XP``&@```)SC```4````M^,```0```#,
MXP``!````-'C```+````UN,```4```#BXP``!@```.CC```(````[^,```8`
M``#XXP``"@```/_C```;````"N0``#0````FY```-````%OD```@````D.0`
M`"D```"QY```(````-OD``!!````_.0``!H````^Y0``*````%GE```I````
M@N4``"(```"LY0``!@```,_E```(````UN4```4```#?Y0``"````.7E```9
M````[N4``!D````(Y@``*@```"+F```C````3>8``"X```!QY@``-````*#F
M```(````U>8``!<```#>Y@``"@```/;F```'`````><``"$````)YP``$```
M`"OG```.````/.<```L```!+YP``!P```%?G```3````7^<```@```!SYP``
M"P```'SG```*````B.<``!0```"3YP``,@```*CG```+````V^<```4```#G
MYP``!0```.WG```7````\^<```\````+Z```!````!OH```*````(.@```D`
M```KZ```"P```#7H```.````0>@```4```!0Z```!````%;H```-````6^@`
M`#(```!IZ```10```)SH```7````XN@``!X```#ZZ```#````!GI```4````
M)ND```4````[Z0``%````$'I```'````5ND```X```!>Z0``*@```&WI```&
M````F.D```P```"?Z0``#P```*SI```-````O.D``!$```#*Z0``"P```-SI
M```V````Z.D```H````?Z@``(@```"KJ```+````3>H```\```!9Z@``,@``
M`&GJ```%````G.H```X```"BZ@``$P```+'J```'````Q>H``!$```#-Z@``
M!P```-_J```4````Y^H``!@```#\Z@``!P```!7K```%````'>L```P````C
MZP``#````##K```2````/>L```0```!0ZP``!P```%7K```*````7>L```L`
M``!HZP``#````'3K```.````@>L```X```"0ZP``!0```)_K```%````I>L`
M`"X```"KZP``)@```-KK```C`````>P```,````E[```$@```"GL```&````
M/.P``!X```!#[```&````&+L```E````>^P```T```"A[```"0```*_L```#
M````N>P```<```"][```"@```,7L```"````T.P```P```#3[```%0```.#L
M```+````]NP``!D````"[0``(````!SM```2````/>T```4```!0[0``"@``
M`%;M```5````8>T``!(```!W[0``#````(KM```$````E^T```<```"<[0``
M#````*3M``!2````L>T``!<````$[@``!P```!SN```&````).X```X````K
M[@``#@```#KN```,````2>X```P```!6[@``#````&/N```-````<.X``!4`
M``!^[@``$@```)3N```0````I^X```\```"X[@``%````,CN```;````W>X`
M`!````#Y[@``:0````KO```:````=.\``!<```"/[P``&0```*?O```:````
MP>\``"4```#<[P``)P````+P```:````*O```!<```!%\```&P```%WP```9
M````>?```!\```"3\```%````+/P```3````R/````@```#<\```!P```.7P
M```(````[?````D```#V\```%0````#Q```-````%O$``!,````D\0```P``
M`#CQ``!&````//$``#\```"#\0``-P```,/Q``!7````^_$``!\```!3\@``
M+P```'/R```*````H_(```@```"N\@``#0```+?R```M````Q?(```0```#S
M\@``%````/CR``!/````#?,``"4```!=\P``$@```(/S```@````EO,``!P`
M``"W\P``"P```-3S```?````X/,``!T`````]```)0```![T```@````1/0`
M`"0```!E]```(````(KT```+````J_0```<```"W]```#0```+_T```,````
MS?0```8```#:]```.0```.'T```,````&_4```<````H]0``"0```##U```3
M````.O4```D```!.]0``!````%CU```0````7?4```@```!N]0``"````'?U
M```+````@/4```P```",]0``&@```)GU```/````M/4```<```#$]0``#0``
M`,SU```0````VO4``!$```#K]0``%````/WU```.````$O8```P````A]@``
M&P```"[V```L````2O8``!,```!W]@``'````(OV```H````J/8```8```#1
M]@``!P```-CV```3````X/8```4```#T]@``!````/KV```7````__8```H`
M```7]P``#````"+W```)````+_<```8````Y]P``"0```$#W```(````2O<`
M``D```!3]P``"@```%WW```1````:/<```8```!Z]P``#@```('W```.````
MD/<```T```"?]P``"P```*WW```=````N?<```L```#7]P```@```./W```'
M````YO<```8```#N]P``"0```/7W```'````__<``#L````'^```*````$/X
M```5````;/@```4```""^```!P```(CX```(````D/@```<```"9^```!0``
M`*'X```'````I_@```X```"O^```"0```+[X```&````R/@```@```#/^```
M"P```-CX```'````Y/@```@```#L^```!P```/7X```6````_?@```D````4
M^0``!@```![Y```+````)?D``!P````Q^0``%````$[Y```'````8_D```@`
M``!K^0``"````'3Y```%````??D``!````"#^0``$````)3Y```&````I?D`
M`!D```"L^0``"@```,;Y```<````T?D```<```#N^0``!0```/;Y```0````
M_/D``!0````-^@``"P```"+Z```-````+OH``!<````\^@``!````%3Z```)
M````6?H```H```!C^@``!P```&[Z```"````=OH```X```!Y^@``"````(CZ
M```?````D?H``",```"Q^@``.````-7Z```Q````#OL``"<```!`^P``9```
M`&C[```4````S?L``%4```#B^P``.````#C\``!*````<?P``%L```"\_```
M*````!C]```X````0?T``"@```!Z_0``+````*/]```G````T/T``!L```#X
M_0``/@```!3^``"I`0``4_X``",```#]_P``%P```"$``0!(````.0`!`(4`
M``""``$`,`````@!`0`5````.0$!`"@```!/`0$`(@```'@!`0`B````FP$!
M`"````"^`0$`00```-\!`0!;````(0(!`$D```!]`@$`'0```,<"`0`8````
MY0(!`"$```#^`@$`'P```"`#`0`K````0`,!`"$```!L`P$`'0```(X#`0`1
M````K`,!`#,```"^`P$`)0```/(#`0`G````&`0!`!\```!`!`$`,````&`$
M`0!I````D00!`#T```#[!`$`90```#D%`0!-````GP4!`"\```#M!0$`+@``
M`!T&`0`I````3`8!`"P```!V!@$`5````*,&`0!:````^`8!`"@```!3!P$`
M)@```'P'`0!(````HP<!`$H```#L!P$`*P```#<(`0`>````8P@!`#(```""
M"`$`+P```+4(`0`L````Y0@!`"T````2"0$`<0```$`)`0!O````L@D!`+,`
M```B"@$`%P```-8*`0`E````[@H!`#(````4"P$`*0```$<+`0`^````<0L!
M`"(```"P"P$`4@```-,+`0`B````)@P!`"4```!)#`$`"P```&\,`0"Q````
M>PP!`$4````M#0$`(0```',-`0`P````E0T!`"4```#&#0$`'````.P-`0`Q
M````"0X!``<````[#@$`!P```$,.`0`$````2PX!``T```!0#@$`"P```%X.
M`0`.````:@X!``L```!Y#@$`!0```(4.`0`0````BPX!``(```"<#@$`60``
M`)\.`0`%````^0X!`!(```#_#@$`!````!(/`0`'````%P\!``@````?#P$`
M!0```"@/`0`#````+@\!`!`````R#P$`#````$,/`0`3````4`\!``T```!D
M#P$``@```'(/`0`'````=0\!``8```!]#P$`%````(0/`0`,````F0\!`!@`
M``"F#P$`!@```+\/`0`2````Q@\!``P```#9#P$``P```.8/`0`J````Z@\!
M``0````5$`$`!@```!H0`0`'````(1`!`!\````I$`$`-0```$D0`0`N````
M?Q`!`"\```"N$`$`%P```-X0`0`@````]A`!`!L````7$0$`&````#,1`0`D
M````3!$!`!\```!Q$0$`&@```)$1`0`@````K!$!`!H```#-$0$`,@```.@1
M`0`9````&Q(!`"\````U$@$`*P```&42`0`?````D1(!`",```"Q$@$`'P``
M`-42`0`:````]1(!`"4````0$P$`)@```#83`0`E````71,!`"0```"#$P$`
M&````*@3`0`=````P1,!`"0```#?$P$`&`````04`0`B````'10!`"4```!`
M%`$`/````&84`0`?````HQ0!`",```##%`$`'P```.<4`0`@````!Q4!`!H`
M```H%0$`&````$,5`0`F````7!4!`!X```"#%0$`*0```*(5`0`>````S!4!
M``D```#K%0$`#````/45`0`7`````A8!`"\````:%@$`)````$H6`0`'````
M;Q8!``\```!W%@$`%````(<6`0`.````G!8!``T```"K%@$`)````+D6`0`%
M````WA8!``<```#D%@$`(@```.P6`0`E````#Q<!`!T````U%P$`&@```%,7
M`0`'````;A<!`,<```!V%P$`"P```#X8`0`5````2A@!``8```!@&`$`"0``
M`&<8`0`+````<1@!`!<```!]&`$`!@```)48`0`S````G!@!`!,```#0&`$`
M$P```.08`0`'````^!@!``\`````&0$`!P```!`9`0`R````&!D!`"$```!+
M&0$`$P```&T9`0`,````@1D!`!$```".&0$`,@```*`9`0`(````TQD!``D`
M``#<&0$`"@```.89`0`4````\1D!``H````&&@$`'0```!$:`0`(````+QH!
M`!\````X&@$`"````%@:`0`:````81H!``8```!\&@$`%0```(,:`0`'````
MF1H!``@```"A&@$`"0```*H:`0`_````M!H!``<```#T&@$`#P```/P:`0`.
M````#!L!`!`````;&P$`"0```"P;`0`)````-AL!``@```!`&P$`$P```$D;
M`0`'````71L!`!D```!E&P$`"@```'\;`0`7````BAL!`!0```"B&P$`"@``
M`+<;`0`,````PAL!`!<```#/&P$`!````.<;`0`J````[!L!`!$````7'`$`
M!P```"D<`0`"````,1P!`!`````T'`$`&````$4<`0`+````7AP!``,```!J
M'`$`"````&X<`0`&````=QP!``<```!^'`$`#0```(8<`0`+````E!P!`!0`
M``"@'`$`%0```+4<`0`.````RQP!`"\```#:'`$`(`````H=`0`<````*QT!
M`"L```!('0$`#````'0=`0`Q````@1T!``4```"S'0$`$@```+D=`0`_````
MS!T!`!(````,'@$`"@```!\>`0`&````*AX!``0````Q'@$`$P```#8>`0`%
M````2AX!``8```!0'@$`!@```%<>`0`$````7AX!``P```!C'@$`"@```'`>
M`0`%````>QX!`!@```"!'@$`&0```)H>`0`?````M!X!`!T```#4'@$`$0``
M`/(>`0`"````!!\!``0````''P$`"@````P?`0`&````%Q\!``4````>'P$`
M`P```"0?`0`,````*!\!`$4````U'P$`&@```'L?`0`U````EA\!`"@```#,
M'P$`4P```/4?`0`R````22`!`!D```!\(`$`<@```)8@`0`@````"2$!`#4`
M```J(0$`10```&`A`0`P````IB$!`"@```#7(0$`*``````B`0`I````*2(!
M`"8```!3(@$`)0```'HB`0`H````H"(!`"@```#)(@$`(@```/(B`0`P````
M%2,!`!(```!&(P$`$P```%DC`0`0````;2,!`'D```!^(P$`"0```/@C`0!S
M`````B0!`'P```!V)`$`*P```/,D`0`7````'R4!`!8````W)0$`%0```$XE
M`0`/````9"4!`!\```!T)0$`#@```)0E`0`?````HR4!`!P```##)0$`40``
M`.`E`0`4````,B8!``H```!')@$`!0```%(F`0`&````6"8!``@```!?)@$`
M!0```&@F`0`2````;B8!`!````"!)@$`$P```)(F`0`=````IB8!``\```#$
M)@$`#P```-0F`0`0````Y"8!``0```#U)@$`"0```/HF`0`)````!"<!``<`
M```.)P$`"P```!8G`0`%````(B<!``L````H)P$`!P```#0G`0`%````/"<!
M`!0```!")P$`#@```%<G`0`+````9B<!``<```!R)P$`"````'HG`0`/````
M@R<!``D```"3)P$`"````)TG`0`,````IB<!``8```"S)P$`#P```+HG`0`'
M````RB<!``8```#2)P$`%````-DG`0`&````[B<!``P```#U)P$`"`````(H
M`0`$````"R@!``H````0*`$`!P```!LH`0`$````(R@!`!D````H*`$``@``
M`$(H`0`)````12@!``8```!/*`$`!@```%8H`0`G````72@!``0```"%*`$`
M#P```(HH`0`3````FB@!``<```"N*`$`"0```+8H`0`'````P"@!``8```#(
M*`$`!@```,\H`0`0````UB@!`!(```#G*`$`!@```/HH`0`)`````2D!`"(`
M```+*0$`!P```"XI`0`'````-BD!``L````^*0$`!0```$HI`0`%````4"D!
M``(```!6*0$`"P```%DI`0!7`0``92D!`!(```"]*@$`#@```-`J`0`+````
MWRH!``@```#K*@$``0```/0J`0`+````]BH!``H````"*P$`$0````TK`0`,
M````'RL!``T````L*P$`!0```#HK`0`I````0"L!``\```!J*P$`#````'HK
M`0`2````ARL!``@```":*P$`&P```*,K`0`1````ORL!``H```#1*P$`#```
M`-PK`0`3````Z2L!`!$```#]*P$`#@````\L`0`1````'BP!`!`````P+`$`
M!@```$$L`0`.````2"P!`!4```!7+`$`$0```&TL`0`)````?RP!`!,```")
M+`$`$P```)TL`0`+````L2P!`"P```"]+`$`$@```.HL`0`]````_2P!`$D`
M```[+0$`90```(4M`0!F````ZRT!`&@```!2+@$`:0```+LN`0!`````)2\!
M``H```!F+P$`!0```'$O`0`&````=R\!`!(```!^+P$`!P```)$O`0`1````
MF2\!`!,```"K+P$`*P```+\O`0`H````ZR\!`"`````4,`$`(````#4P`0`F
M````5C`!`"4```!],`$`"P```*,P`0`3````KS`!``@```##,`$`!P```,PP
M`0`/````U#`!`!````#D,`$`$````/4P`0`3````!C$!`!4````:,0$`&@``
M`#`Q`0`2````2S$!`!````!>,0$`%@```&\Q`0`,````AC$!`"T```"3,0$`
M&@```,$Q`0`?````W#$!`!$```#\,0$`%`````XR`0`<````(S(!``<```!`
M,@$`!P```$@R`0`Y````4#(!``@```"*,@$`"````),R`0`,````G#(!``@`
M``"I,@$`!P```+(R`0`(````NC(!``@```##,@$`"P```,PR`0`%````V#(!
M`!H```#>,@$`#````/DR`0`,````!C,!`!0````3,P$`%````"@S`0`A````
M/3,!``X```!?,P$`'P```&XS`0`=````CC,!`"(```"L,P$`'@```,\S`0`5
M````[C,!`!0````$-`$`#@```!DT`0`;````*#0!``8```!$-`$`!@```$LT
M`0`'````4C0!`!D```!:-`$`"0```'0T`0`*````?C0!`!(```")-`$`!P``
M`)PT`0`5````I#0!`!<```"Z-`$`"P```-(T`0`(````WC0!`!<```#G-`$`
M$P```/\T`0`9````$S4!`#,````M-0$`"0```&$U`0`(````:S4!`!4```!T
M-0$`!0```(HU`0`%````D#4!``\```"6-0$`'0```*8U`0`+````Q#4!`"``
M``#0-0$`+@```/$U`0`5````(#8!`"@````V-@$`*@```%\V`0`K````BC8!
M`"L```"V-@$`"0```.(V`0`)````[#8!``H```#V-@$`"`````$W`0`O````
M"C<!`"P````Z-P$`+@```&<W`0!0````EC<!`"T```#G-P$`+0```!4X`0`M
M````0S@!`#\```!Q.`$`*0```+$X`0`K````VS@!`"T````'.0$`,P```#4Y
M`0`4````:3D!`!@```!^.0$`*@```)<Y`0`G````PCD!`!0```#J.0$`#@``
M`/\Y`0`-````#CH!`!$````<.@$`%P```"XZ`0`C````1CH!``4```!J.@$`
M"P```'`Z`0`A````?#H!`"8```">.@$`!P```,4Z`0`)````S3H!`!8```#7
M.@$`"@```.XZ`0`*````^3H!``X````$.P$`"P```!,[`0`'````'SL!``<`
M```G.P$`!P```"\[`0`(````-SL!``<```!`.P$`"P```$@[`0`0````5#L!
M``L```!E.P$`"@```'$[`0`(````?#L!``<```"%.P$`!P```(T[`0`0````
ME3L!``<```"F.P$`%@```*X[`0`%````Q3L!``@```#+.P$`"````-0[`0`*
M````W3L!``D```#H.P$`(````/([`0`5````$SP!``D````I/`$`$0```#,\
M`0`.````13P!``D```!4/`$``P```%X\`0`#````8CP!`!<```!F/`$``P``
M`'X\`0`4````@CP!``L```"7/`$`!````*,\`0`(````J#P!``D```"Q/`$`
M3P```+L\`0`J````"ST!``8````V/0$`"````#T]`0`<````1CT!`!P```!C
M/0$`(0```(`]`0`H````HCT!`!\```#+/0$`*0```.L]`0!8````%3X!`"P`
M``!N/@$`"@```)L^`0`+````ICX!``L```"R/@$`"@```+X^`0`-````R3X!
M`!$```#7/@$`$````.D^`0`.````^CX!`!`````)/P$`$@```!H_`0`3````
M+3\!`!,```!!/P$`!@```%4_`0`<````7#\!`!X```!Y/P$`$P```)@_`0`2
M````K#\!``4```"_/P$`!@```,4_`0!B````S#\!`"X````O0`$`"````%Y`
M`0`6````9T`!``0```!^0`$`!@```(-``0`<````BD`!`!L```"G0`$`%@``
M`,-``0`;````VD`!`"$```#V0`$`)````!A!`0`T````/4$!``L```!R00$`
M#P```'Y!`0`&````CD$!``@```"500$`&````)Y!`0`=````MT$!`!L```#5
M00$`&P```/%!`0`%````#4(!`!,````30@$`#@```"="`0`)````-D(!``D`
M``!`0@$`%@```$I"`0`;````84(!``D```!]0@$`!@```(="`0`2````CD(!
M`!0```"A0@$`"P```+9"`0`5````PD(!``@```#80@$`!P```.%"`0`0````
MZ4(!``H```#Z0@$`#@````5#`0`'````%$,!``D````<0P$`#````"9#`0`'
M````,T,!`!0````[0P$`#P```%!#`0`5````8$,!``8```!V0P$`'````'U#
M`0`5````FD,!`!8```"P0P$`,0```,=#`0`^````^4,!`"<````X1`$`,@``
M`&!$`0`%````DT0!``H```"91`$`#@```*1$`0`)````LT0!`!4```"]1`$`
M"@```--$`0`6````WD0!`!X```#U1`$`'P```!1%`0`A````-$4!`"(```!6
M10$`'0```'E%`0`H````ET4!`!\```#`10$`*0```.!%`0`?````"D8!`"(`
M```J1@$`'@```$U&`0`J````;$8!`"L```"71@$`(P```,-&`0`I````YT8!
M`#`````11P$`+P```$)'`0`6````<D<!`"X```")1P$`%0```+A'`0"W````
MSD<!`!(```"&2`$`(@```)E(`0`G````O$@!`"<```#D2`$`)0````Q)`0`<
M````,DD!`"````!/20$`+P```'!)`0`@````H$D!`"````#!20$`+````.))
M`0!'````#TH!``\```!72@$`"````&=*`0`&````<$H!``<```!W2@$`#P``
M`']*`0`4````CTH!`!0```"D2@$`!P```+E*`0`0````P4H!`!L```#22@$`
M"````.Y*`0`$````]TH!`!$```#\2@$`$0````Y+`0`6````($L!`!0````W
M2P$`$@```$Q+`0`S````7TL!``@```"32P$`%````)Q+`0`&````L4L!`!$`
M``"X2P$`%P```,I+`0`?````XDL!`!(````"3`$``@```!5,`0`'````&$P!
M`!<````@3`$`!````#A,`0`%````/4P!`!(```!#3`$`!0```%9,`0`2````
M7$P!``<```!O3`$`%0```'=,`0`5````C4P!`!(```"C3`$`%````+9,`0`/
M````RTP!``D```#;3`$`"P```.5,`0`(````\4P!``X```#Z3`$`#@````E-
M`0`9````&$T!``T````R30$`$0```$!-`0`J````4DT!``\```!]30$`&@``
M`(U-`0`4````J$T!`!,```"]30$`$0```-%-`0`&````XTT!``\```#J30$`
M$P```/I-`0`)````#DX!``H````83@$`+@```"-.`0`M````4DX!``@```"`
M3@$`"0```(E.`0`=````DTX!``L```"Q3@$`&@```+U.`0`:````V$X!``D`
M``#S3@$`&@```/U.`0`5````&$\!`!4````N3P$`$P```$1/`0`<````6$\!
M``@```!U3P$`"````'Y/`0`J````AT\!`"(```"R3P$`"````-5/`0`4````
MWD\!``H```#S3P$`#0```/Y/`0`T````#%`!`!D```!!4`$`!P```%M0`0`1
M````8U`!``,```!U4`$`"0```'E0`0`)````@U`!`!<```"-4`$`#P```*50
M`0`0````M5`!`!````#&4`$`$````-=0`0`5````Z%`!`!(```#^4`$`%0``
M`!%1`0`'````)U$!``<````O40$`"@```#=1`0`,````0E$!``(```!/40$`
M"@```%)1`0`1````75$!`!\```!O40$`(0```(]1`0`*````L5$!``\```"\
M40$`#@```,Q1`0`3````VU$!`!L```#O40$`.P````M2`0`F````1U(!``X`
M``!N4@$`$P```'U2`0!R````D5(!`!D````$4P$`$@```!Y3`0`(````,5,!
M``8````Z4P$`#@```$%3`0`&````4%,!``@```!74P$`!P```&!3`0`&````
M:%,!``X```!O4P$`#0```'Y3`0`0````C%,!``T```"=4P$`&P```*M3`0`.
M````QU,!``H```#64P$`"P```.%3`0`'````[5,!``H```#U4P$`#P````!4
M`0`\````$%0!``X```!-5`$`"@```%Q4`0`'````9U0!``\```!O5`$`#0``
M`']4`0`<````C50!``X```"J5`$`'0```+E4`0`H````UU0!`"<`````50$`
M'0```"A5`0`<````1E4!`"(```!C50$`&0```(95`0`'````H%4!`!H```"H
M50$`#````,-5`0`&````T%4!``<```#750$`"@```-]5`0`,````ZE4!`!,`
M``#W50$`!@````M6`0`9````$E8!`!P````L5@$`#P```$E6`0`1````658!
M`!(```!K5@$`#P```'Y6`0`B````CE8!``<```"Q5@$`!P```+E6`0`,````
MP58!`!(```#.5@$`%P```.%6`0`+````^58!``H````%5P$`!0```!!7`0`9
M````%E<!``T````P5P$`!P```#Y7`0`I````1E<!`!(```!P5P$`AP```(-7
M`0`:````"U@!``8````F6`$`!0```"U8`0`,````,U@!``8```!`6`$`"```
M`$=8`0`*````4%@!``P```!;6`$`!0```&A8`0`)````;E@!``H```!X6`$`
M%@```(-8`0`2````FE@!`!8```"M6`$`(````,18`0`#````Y5@!``0```#I
M6`$`$````.Y8`0`(````_U@!``T````(60$`!P```!99`0`U````'ED!``D`
M``!460$`!P```%Y9`0`7````9ED!`!(```!^60$`!P```)%9`0`)````F5D!
M``0```"C60$`"P```*A9`0`&````M%D!``8```"[60$`!P```,)9`0`.````
MRED!``L```#960$`"````.59`0`6````[ED!``L````%6@$`!P```!%:`0`6
M````&5H!`"$````P6@$`!@```%):`0`)````65H!``4```!C6@$`"0```&E:
M`0`'````<UH!``T```![6@$`#````(E:`0`'````EEH!``X```">6@$`!@``
M`*U:`0`$````M%H!`#,```"Y6@$`-P```.U:`0`V````)5L!`"````!<6P$`
M!@```'U;`0`/````A%L!``4```"46P$`"````)I;`0`>````HUL!`!8```#"
M6P$`!P```-E;`0`'````X5L!`"````#I6P$`#0````I<`0`)````&%P!`!L`
M```B7`$`!@```#Y<`0`)````15P!`"0```!/7`$`"````'1<`0`,````?5P!
M``X```"*7`$`"````)E<`0`)````HEP!``@```"L7`$`,P```+5<`0`O````
MZ5P!`#(````970$`)@```$Q=`0!&````<UT!`#H```"Z70$`*@```/5=`0`R
M````(%X!`#(```!37@$`,P```(9>`0`E````NEX!`!(```#@7@$`$P```/->
M`0`.````!U\!`"`````67P$`'P```#=?`0`?````5U\!`!T```!W7P$`"0``
M`)5?`0`+````GU\!``H```"K7P$`"````+9?`0`G````OU\!`"@```#G7P$`
M,````!!@`0`*````06`!`!D```!,8`$`(P```&9@`0`.````BF`!`!<```"9
M8`$`"0```+%@`0`/````NV`!`!4```#+8`$`$P```.%@`0`H````]6`!`&D`
M```>80$`%0```(AA`0`0````GF$!`!$```"O80$`&0```,%A`0`:````VV$!
M`!4```#V80$`!P````QB`0`?````%&(!`!4````T8@$`%@```$IB`0`2````
M86(!``X```!T8@$`&````(-B`0`:````G&(!`#$```"W8@$`HP```.EB`0`5
M````C6,!``8```"C8P$`%P```*IC`0`*````PF,!``L```#-8P$`"P```-EC
M`0`;````Y6,!`!,````!9`$`#P```!5D`0`/````)60!`!D````U9`$`+P``
M`$]D`0`N````?V0!`"P```"N9`$`*P```-MD`0`C````!V4!`"(````K90$`
M&P```$YE`0!!````:F4!`!(```"L90$`%@```+]E`0`9````UF4!`!@```#P
M90$`#P````EF`0`7````&68!`!L````Q9@$`%````$UF`0`8````8F8!`"\`
M``![9@$`'0```*MF`0`9````R68!`#$```#C9@$`$@```!5G`0`(````*&<!
M``\````Q9P$`)````$%G`0`4````9F<!``\```![9P$`&P```(MG`0`4````
MIV<!`!H```"\9P$`%0```-=G`0`=````[6<!`",````+:`$`'@```"]H`0`7
M````3F@!`!0```!F:`$`'0```'MH`0`<````F6@!``L```"V:`$`&@```,)H
M`0`&````W6@!``8```#D:`$`"0```.MH`0`3````]6@!``@````):0$`"0``
M`!)I`0`(````'&D!``<````E:0$`!P```"UI`0`&````-6D!``@````\:0$`
M%P```$5I`0`'````76D!``D```!E:0$`!0```&]I`0`(````=6D!``8```!^
M:0$`#P```(5I`0`.````E6D!`!````"D:0$`$0```+5I`0`+````QVD!`!0`
M``#3:0$`!@```.AI`0`L````[VD!`!,````<:@$`#0```#!J`0`/````/FH!
M``L```!.:@$`"P```%IJ`0`2````9FH!`"<```!Y:@$`!@```*%J`0`)````
MJ&H!`"<```"R:@$`$@```-IJ`0`5````[6H!``@````#:P$`"0````QK`0`+
M````%FL!``4````B:P$`)0```"AK`0`*````3FL!`!D```!9:P$`%````'-K
M`0`+````B&L!`!P```"4:P$`*0```+%K`0`8````VVL!``<```#T:P$`!0``
M`/QK`0`*`````FP!`#`````-;`$`!P```#YL`0`'````1FP!`!$```!.;`$`
M$P```&!L`0`'````=&P!``@```!\;`$`%@```(5L`0`.````G&P!``X```"K
M;`$`$````+IL`0`5````RVP!`!<```#A;`$`#P```/EL`0`=````"6T!`!$`
M```G;0$`$@```#EM`0`)````3&T!``<```!6;0$`"@```%YM`0`Y````:6T!
M``@```"C;0$`%````*QM`0`O````P6T!`!L```#Q;0$`%0````UN`0`6````
M(VX!`!8````Z;@$`%0```%%N`0`0````9VX!`!@```!X;@$`%0```)%N`0`>
M````IVX!`!P```#&;@$`'0```.-N`0`*`````6\!``<````,;P$`"0```!1O
M`0`1````'F\!`!`````P;P$`!0```$%O`0`+````1V\!``H```!3;P$`$P``
M`%YO`0!4````<F\!`!4```#';P$`#0```-UO`0`%````ZV\!``@```#Q;P$`
M&@```/IO`0`:````%7`!`!H````P<`$`#0```$MP`0`"````67`!``0```!<
M<`$`*````&%P`0`#````BG`!``4```".<`$`"@```)1P`0`,````GW`!``8`
M``"L<`$`!@```+-P`0`.````NG`!`!,```#)<`$`!P```-UP`0`)````Y7`!
M``@```#O<`$`!0```/AP`0`%````_G`!`%<````$<0$`#P```%QQ`0`2````
M;'$!``4```!_<0$`!P```(5Q`0`C````C7$!`#$```"Q<0$`#0```.-Q`0`)
M````\7$!``\```#[<0$`"P````MR`0`*````%W(!`!0````B<@$`*P```#=R
M`0`:````8W(!`!D```!^<@$`$````)AR`0`&````J7(!``8```"P<@$`"```
M`+=R`0`&````P'(!``X```#'<@$`#@```-9R`0`.````Y7(!``8```#T<@$`
M3````/MR`0`2````2',!``T```!;<P$`"P```&ES`0`6````=7,!`$0```",
M<P$`!P```-%S`0`%````V7,!``<```#?<P$`(@```.=S`0`(````"G0!``H`
M```3=`$`&0```!YT`0`:````.'0!``D```!3=`$`!0```%UT`0`C````8W0!
M`$D```"'=`$`$````-%T`0`G````XG0!`!`````*=0$`!0```!MU`0`.````
M(74!``D````P=0$`#P```#IU`0`*````2G4!``\```!5=0$`!P```&5U`0`3
M````;74!``<```"!=0$`"0```(EU`0`1````DW4!``H```"E=0$`"@```+!U
M`0`-````NW4!``<```#)=0$`$0```-%U`0`4````XW4!`!(```#X=0$`#P``
M``MV`0`0````&W8!`!$````L=@$`$0```#YV`0`0````4'8!`!(```!A=@$`
M"@```'1V`0`F````?W8!`!,```"F=@$`#0```+IV`0`,````R'8!``T```#5
M=@$`%P```.-V`0`)````^W8!``T````%=P$`!@```!-W`0`(````&G<!``8`
M```C=P$`!P```"IW`0`+````,G<!`!(````^=P$`%0```%%W`0`A````9W<!
M`!\```")=P$`&````*EW`0`6````PG<!`!P```#9=P$`'@```/9W`0`:````
M%7@!``<````P>`$`!P```#AX`0`2````0'@!`!````!3>`$`#@```&1X`0`.
M````<W@!`",```"">`$`$0```*9X`0`6````N'@!``D```#/>`$`#P```-EX
M`0`(````Z7@!`!,```#R>`$`"0````9Y`0`'````$'D!``@````8>0$`!@``
M`"%Y`0`%````*'D!``(````N>0$`)0```#%Y`0`B````5WD!`!<```!Z>0$`
M(````))Y`0`T````LWD!``X```#H>0$`(P```/=Y`0`H````&WH!`"T```!$
M>@$`+0```')Z`0`R````H'H!`!0```#3>@$`$@```.AZ`0`2````^WH!`!0`
M```.>P$`$@```"-[`0`0````-GL!`!X```!'>P$`"P```&9[`0`N````<GL!
M``L```"A>P$`$@```*U[`0`<````P'L!`"T```#=>P$`+0````M\`0`Q````
M.7P!`"X```!K?`$`+P```)I\`0`L````RGP!`&````#W?`$`(````%A]`0`2
M````>7T!`!$```",?0$`)````)Y]`0`Q````PWT!`!D```#U?0$`#0````]^
M`0!`````'7X!`$````!>?@$`"````)]^`0`*````J'X!``0```"S?@$`%0``
M`+A^`0`.````SGX!`!(```#=?@$`&````/!^`0`)````"7\!``@````3?P$`
M#````!Q_`0`,````*7\!``T````V?P$`"@```$1_`0`-````3W\!`!$```!=
M?P$`$````&]_`0`.````@'\!``X```"/?P$`#P```)Y_`0`2````KG\!``\`
M``#!?P$`'````-%_`0`/````[G\!``<```#^?P$`$`````:``0`A````%X`!
M``D````Y@`$`!P```$.``0`1````2X`!`!(```!=@`$`$````'"``0`S````
M@8`!``(```"U@`$`"````+B``0`2````P8`!``L```#4@`$`!@```."``0`0
M````YX`!``8```#X@`$`!@```/^``0`O````!H$!`!@````V@0$`*````$^!
M`0!6````>($!`!<```#/@0$`(P```.>!`0`2````"X(!``H````>@@$`#0``
M`"F"`0`3````-X(!``P```!+@@$`"0```%B"`0`,````8H(!`!\```!O@@$`
M%P```(^"`0`$````IX(!`!````"L@@$`#P```+V"`0`1````S8(!`"4```#?
M@@$`&`````6#`0`9````'H,!`!,````X@P$`(0```$R#`0`)````;H,!``<`
M``!X@P$`$0```("#`0`)````DH,!``H```"<@P$`"````*>#`0`-````L(,!
M``H```"^@P$`!0```,F#`0`>````SX,!``8```#N@P$`%0```/6#`0`*````
M"X0!`!$````6A`$`"P```"B$`0`7````-(0!`"P```!,A`$`&P```'F$`0`,
M````E80!``T```"BA`$`&P```+"$`0`&````S(0!`"L```#3A`$`!@```/^$
M`0`=````!H4!``8````DA0$`"0```"N%`0`?````-84!`#4```!5A0$`!@``
M`(N%`0`0````DH4!``8```"CA0$`%@```*J%`0`4````P84!``0```#6A0$`
M!P```-N%`0`)````XX4!``D```#MA0$`"@```/>%`0`)`````H8!``D````,
MA@$`"0```!:&`0`;````((8!`#4````\A@$`/@```'*&`0`9````L88!`"<`
M``#+A@$`'````/.&`0`\````$(<!`!@```!-AP$`%````&:'`0`N````>X<!
M`"8```"JAP$`!P```-&'`0`)````V8<!``H```#CAP$`"P```.Z'`0`5````
M^H<!`!$````0B`$`*0```"*(`0`@````3(@!`"X```!MB`$`,P```)R(`0`&
M````T(@!`!4```#7B`$`"````.V(`0`(````]H@!`"0```#_B`$`%````"2)
M`0`6````.8D!`!````!0B0$`"````&&)`0`3````:HD!``D```!^B0$`$```
M`(B)`0`/````F8D!`!@```"IB0$`*@```,*)`0`,````[8D!``<```#ZB0$`
M!P````**`0`>````"HH!`!0````IB@$`!@```#Z*`0`+````18H!``T```!1
MB@$`!@```%^*`0`1````9HH!``@```!XB@$`"````(&*`0`3````BHH!`#``
M``">B@$`0P```,^*`0`;````$XL!`"0````OBP$`$0```%2+`0`:````9HL!
M``4```"!BP$`$````(>+`0`(````F(L!`!````"ABP$`+````+*+`0`(````
MWXL!``\```#HBP$`$P```/B+`0`3````#(P!`!8````@C`$`#0```#>,`0`\
M````18P!``D```""C`$`(@```(R,`0`2````KXP!`!8```#"C`$`+````-F,
M`0`(````!HT!`!,````/C0$`%0```".-`0`*````.8T!`!,```!$C0$`"```
M`%B-`0`7````88T!`!P```!YC0$`!@```):-`0`(````G8T!`!(```"FC0$`
M%````+F-`0`6````SHT!``0```#EC0$`"````.J-`0`+````\XT!``X```#_
MC0$`#P````Z.`0`2````'HX!`!(````QC@$`"````$2.`0`)````38X!`"@`
M``!7C@$`'````(".`0`:````G8X!``<```"XC@$`$@```,".`0`&````TXX!
M``X```#:C@$`&0```.F.`0`F`````X\!``L````JCP$`!P```#:/`0`#````
M/H\!``8```!"CP$`"````$F/`0`%````4H\!``\```!8CP$`%P```&B/`0`-
M````@(\!`!T```".CP$`'0```*R/`0`:````RH\!``4```#ECP$`"P```.N/
M`0`4````]X\!``D````,D`$`#0```!:0`0`)````))`!``P````ND`$`%```
M`#N0`0!6````4)`!`!@```"GD`$`!P```,"0`0`'````R)`!``<```#0D`$`
M$P```-B0`0`'````[)`!``\```#TD`$`$@````21`0`0````%Y$!`!$````H
MD0$`&P```#J1`0`:````5I$!`!,```!QD0$`%0```(61`0`D````FY$!`!,`
M``#`D0$`8@```-21`0`;````-Y(!`!H```!3D@$`'0```&Z2`0`;````C)(!
M`",```"HD@$`*0```,R2`0`;````]I(!`!H````2DP$`)````"V3`0`:````
M4I,!`!D```!MDP$`&````(>3`0`:````H),!``H```"[DP$`"0```,:3`0`+
M````T),!``@```#<DP$`%@```.63`0`/````_),!`!4````,E`$`"````"*4
M`0!0````*Y0!`$$```!\E`$`*````+Z4`0!/````YY0!`!L````WE0$`*P``
M`%.5`0`(````?Y4!``H```"(E0$`$0```).5`0`I````I94!``8```#/E0$`
M$````-:5`0!-````YY4!`"4````UE@$`(@```%N6`0`@````?I8!`"$```"?
ME@$`$@```,&6`0`@````U)8!`!@```#UE@$`'`````Z7`0`?````*Y<!`!X`
M``!+EP$`(P```&J7`0`4````CI<!``8```"CEP$`"P```*J7`0`-````MI<!
M``D```#$EP$`*@```,Z7`0`+````^9<!``P````%F`$`!P```!*8`0`1````
M&I@!``H````LF`$`!0```#>8`0`6````/9@!``D```!4F`$`"0```%Z8`0`$
M````:)@!``X```!MF`$`&````'R8`0`.````E9@!``<```"DF`$`%0```*R8
M`0`9````PI@!`!P```#<F`$`'@```/F8`0`0````&)D!``P````IF0$`&@``
M`#:9`0`H````49D!`!$```!ZF0$`$0```(R9`0`F````GID!``8```#%F0$`
M$0```,R9`0`&````WID!``@```#EF0$`!@```.Z9`0`=````]9D!``X````3
MF@$`$@```"*:`0`0````-9H!``<```!&F@$`"0```$Z:`0`*````6)H!``P`
M``!CF@$`#P```'":`0`7````@)H!``8```"8F@$`$@```)^:`0`.````LIH!
M``D```#!F@$`#@```,N:`0`8````VIH!``T```#SF@$`!0````&;`0`$````
M!YL!``8````,FP$`"````!.;`0`(````')L!`%0````EFP$`-````'J;`0`9
M````KYL!``<```#)FP$`!P```-&;`0`*````V9L!``H```#DFP$`!P```.^;
M`0`*````]YL!`!4````"G`$`#````!B<`0`*````)9P!``P````PG`$`"```
M`#V<`0`,````1IP!``D```!3G`$`!P```%V<`0`8````99P!``L```!^G`$`
M!P```(J<`0`*````DIP!`"4```"=G`$`&````,.<`0`'````W)P!``@```#D
MG`$`"@```.V<`0`'````^)P!`!,`````G0$`$P```!2=`0`(````*)T!`!P`
M```QG0$`#0```$Z=`0`>````7)T!``D```![G0$`!@```(6=`0`0````C)T!
M`!4```"=G0$`"P```+.=`0`-````OYT!`!<```#-G0$`!P```.6=`0`+````
M[9T!``\```#YG0$`#@````F>`0`%````&)X!`!@````>G@$`"0```#>>`0`<
M````09X!`!$```!>G@$`,P```'">`0`F````I)X!`",```#+G@$`>P```.^>
M`0`4````:Y\!`#\```"`GP$`-````,"?`0!%````]9\!`$,````[H`$`'P``
M`'^@`0!D````GZ`!`"8````$H0$`,P```"NA`0`J````7Z$!`!,```"*H0$`
M&````)ZA`0!]`0``MZ$!`!<````UHP$`$@```$VC`0`X````8*,!`($```"9
MHP$`/````!ND`0`2````6*0!`"D```!KI`$`'````)6D`0`=````LJ0!`!X`
M``#0I`$`-P```.^D`0!)````)Z4!`$0```!QI0$`'@```+:E`0`3````U:4!
M`!@```#II0$`&0````*F`0`D````'*8!`!T```!!I@$`(P```%^F`0`4````
M@Z8!`!L```"8I@$`(0```+2F`0`7````UJ8!``\```#NI@$`,````/ZF`0!;
M````+Z<!`"P```"+IP$`4@```+BG`0`Y````"Z@!`",```!%J`$`)@```&FH
M`0`<````D*@!`!\```"MJ`$`1P```,VH`0!'````%:D!`!L```!=J0$`'```
M`'FI`0`]````EJD!`#P```#4J0$`*````!&J`0`6````.JH!`#````!1J@$`
M*@```(*J`0`J````K:H!`"T```#8J@$`9P````:K`0!E````;JL!`*L```#4
MJP$`%@```("L`0`M````EZP!`#$```#%K`$`,````/>L`0!)````**T!`!X`
M``!RK0$`3@```)&M`0`<````X*T!`!8```#]K0$`!P```!2N`0"Q````'*X!
M`$4```#.K@$`*````!2O`0`S````/:\!`!H```!QKP$`'@```(RO`0`N````
MJZ\!``D```#:KP$`"````.2O`0`&````[:\!``X```#TKP$`#@````.P`0`2
M````$K`!``H````EL`$`"````#"P`0`,````.;`!``,```!&L`$`;````$JP
M`0`(````M[`!`!````#`L`$`!0```-&P`0`'````U[`!``4```#?L`$`!0``
M`.6P`0`'````Z[`!`!D```#SL`$`"`````VQ`0`5````%K$!``P````LL0$`
M!0```#FQ`0`'````/[$!``<```!'L0$`%0```$^Q`0`*````9;$!`!<```!P
ML0$`!@```(BQ`0`;````C[$!``\```"KL0$``P```+NQ`0`F````O[$!``0`
M``#FL0$`!@```.NQ`0`'````\K$!`"(```#ZL0$`00```!VR`0`H````7[(!
M`"H```"(L@$`%@```+.R`0`G````RK(!`"````#RL@$`'P```!.S`0`C````
M,[,!`!X```!7LP$`&P```':S`0`B````DK,!`!X```"ULP$`*P```-2S`0`9
M`````+0!`"D````:M`$`*P```$2T`0`?````<+0!`",```"0M`$`(0```+2T
M`0`<````UK0!`"8```#SM`$`)P```!JU`0`C````0K4!`!X```!FM0$`'```
M`(6U`0`B````HK4!`"4```#%M0$`'0```.NU`0`E````";8!`"8````OM@$`
M.@```%:V`0`A````D;8!`"4```"SM@$`(P```-FV`0`D````_;8!`!X````B
MMP$`'````$&W`0`D````7K<!`"````"#MP$`*P```*2W`0`C````T+<!``D`
M``#TMP$`$P```/ZW`0`:````$K@!`!H````MN`$`&@```$BX`0`*````8[@!
M`!````!NN`$`&0```'^X`0`2````F;@!`!,```"LN`$`(@```,"X`0`(````
MX[@!``D```#LN`$`)````/:X`0`G````&[D!`"\```!#N0$`(0```'.Y`0`,
M````E;D!`/H```"BN0$`$0```)VZ`0`5````K[H!``H```#%N@$`#0```-"Z
M`0`4````WKH!`!\```#SN@$`"````!.[`0`Q````'+L!`!P```!.NP$`&@``
M`&N[`0`)````AKL!`!4```"0NP$`"P```*:[`0!%````LKL!`"\```#XNP$`
M&0```"B\`0`4````0KP!`!8```!7O`$`(````&Z\`0`0````C[P!`!$```"@
MO`$`$@```+*\`0`;````Q;P!``P```#AO`$`&P```.Z\`0`)````"KT!`!L`
M```4O0$`"@```#"]`0`<````.[T!``@```!8O0$`(P```&&]`0`'````A;T!
M``D```"-O0$`"0```)>]`0`Q````H;T!``<```#3O0$`$````-N]`0`4````
M[+T!`!$````!O@$`"P```!.^`0`-````'[X!``D````MO@$`%P```#>^`0`-
M````3[X!`!8```!=O@$`$@```'2^`0`7````A[X!`!4```"?O@$`"0```+6^
M`0`+````O[X!`!D```#+O@$`!````.6^`0`J````ZKX!``\````5OP$`!P``
M`"6_`0`%````+;\!``P````SOP$`$@```$"_`0`+````4[\!``,```!?OP$`
M#````&._`0`+````<+\!``8```!\OP$`$@```(._`0`)````EK\!`!,```"@
MOP$`%````+2_`0`.````R;\!`"L```#8OP$`%P````3``0`6````',`!`"L`
M```SP`$`#````%_``0`D````;,`!``8```"1P`$`$0```)C``0!&````JL`!
M``\```#QP`$`#`````'!`0`'````#L$!``0````6P0$`%````!O!`0`&````
M,,$!``<````WP0$`"````#_!`0`&````2,$!``T```!/P0$`#P```%W!`0`%
M````;<$!`!X```!SP0$`(@```)+!`0`:````M<$!`!T```#0P0$`#P```.[!
M`0`"````_L$!``0````!P@$`$`````;"`0`&````%\(!``<````>P@$`!```
M`";"`0`0````*\(!`$<````\P@$`$0```(3"`0`I````EL(!`"0```#`P@$`
M1````.7"`0`N````*L,!`!````!9PP$`90```&K#`0`;````T,,!`%@```#L
MPP$`+@```$7$`0`6````=,0!`#$```"+Q`$`,````+W$`0`S````[L0!`"0`
M```BQ0$`(P```$?%`0`G````:\4!`!,```"3Q0$`,````*?%`0`P````V,4!
M`!<````)Q@$`$@```"'&`0`4````-,8!`$\```!)Q@$`$P```)G&`0!M````
MK<8!`%0````;QP$`)P```'#'`0`2````F,<!`!H```"KQP$`'P```,;'`0`4
M````YL<!`"(```#[QP$`%0```![(`0`;````-,@!`!H```!0R`$`7````&O(
M`0`6````R,@!``L```#?R`$`!@```.O(`0`'````\L@!``@```#ZR`$`"@``
M``/)`0`;````#LD!`!8````JR0$`&@```$')`0`F````7,D!`!$```"#R0$`
M"0```)7)`0`8````G\D!``0```"XR0$`"P```+W)`0`.````R<D!``D```#8
MR0$`$````.+)`0`*````\\D!`!$```#^R0$`!P```!#*`0`(````&,H!`!L`
M```AR@$`#P```#W*`0`/````3<H!``P```!=R@$`"P```&K*`0`1````=LH!
M``\```"(R@$`"P```)C*`0`'````I,H!``L```"LR@$`%````+C*`0`(````
MS<H!``X```#6R@$`%P```.7*`0`+````_<H!``X````)RP$`"P```!C+`0`%
M````),L!``T````JRP$`!@```#C+`0`&````/\L!`!$```!&RP$``@```%C+
M`0`*````6\L!``@```!FRP$`"````&_+`0`F````>,L!``8```"?RP$`#```
M`*;+`0`0````L\L!``X```#$RP$`"P```-/+`0`)````W\L!``D```#IRP$`
M!````//+`0`0````^,L!`!(````)S`$`!P```!S,`0`-````),P!`",````R
MS`$`"@```%;,`0`%````8<P!`!8```!GS`$`!0```'[,`0`%````A,P!``(`
M``"*S`$`"P```(W,`0`!````R@4``(D%``#F!0``204``#P&````````TP4`
M`!0&````````3@(``$L#```/!0``D`(```P#```A`0```````)\!````````
M)0,```````!&````BP8``*4```",`@``4P0``(T```#?!```,`(```````#Q
M!```````````````````-````/H$```:````WP4``*D%``!(!@``M0(`````
M``!H!```D08```````#N`@``_0(``'0%``!M`0``-P8``"4```!/`P``^`0`
M`$<#``#9`0``&08``#@"``#M`P``,@,```````#\`0``=`(``-,!``"O!0``
MO0(``"D````8!```X@```"(#``"D````J00``.4$``!D`@``?@4``-L%``"5
M````;`,``%@&````````3`4``)4!````````50(``/H!``!J````N`0``$P!
M``````````````````#C`@``@00`````````````KP$``%D%``"H!0``QP4`
M``````!C`P``>0````````#-`0``$0```%8&``!0!0``^04````````-!@``
M0@8```````"'!0``W`4``&H#```?`P``E`$``-(%``!_!```(0,``,0$````
M````$P8`````````````ZP````````"%`0``CP``````````````Y0(``*X!
M``!Y`0``V0,```````!G`P``3P0``",$``!]`P``Z@$``#,"``!,`P``DP(`
M``````#,````LP0``*0$``!,````^P,``#D!```8`@``2`0``%`&``#1!0``
M:0$``.L%````````E0(```````````````````````"X`@``````````````
M````,````/0!``````````````````"V````XP0``$("``!@`@``00$``+X#
M````````[0(``%8!``#2`0``%`(``````````````````-$"````````````
M`,H"````````!04```0$``"C!0```````.`%```F````"P8``.T$``!J!```
MH@4```D```"U`0``[@,``#D"```0`@```````,D%``#3!````````#`!``#\
M!```QP,``'(&``#&`0````````````!B!0``-0```$\`````````'@4``!(%
M``!*!```````````````````6@(``.<%``!A`````````!L&``!%````T08`
M`'$$````````(P4``"D#````````"@$``.@```"6!0``=@8```````!2!```
M`````#8%````````_`(``.4#``#+!@``0@0``-0%```[!@``!````)4&````
M````500``-("``#"!```<@0``&@&````````208``!<$````````R@0``&X#
M````````#@,``)P!``"/!0````````\````A`@``$`8``$D#```0`0``````
M`/$"``"T`@``\0,``+$```"C!@``WP```&<$``#5`P``B@8``/($```[!0``
M*`(``%\$````````C`8``&`#````````:08``-`%``!^`0``O`0``/8"````
M````8````!,$``#/!@``3`0`````````````_@(``.("``#T!0``QP0``+8%
M```M`0``[`$``+@!`````````````,4$``!U!```"P0``!8!``"N`P``BP,`
M`/8```#)!```E@0``'\!``#[!```T````$X#````````DP4`````````````
M;04``!@!```A````0@4````````G!0``F04```````#:!0```````%P!``#.
M`P``A@,```````#6`P``*08```````#2!@``"@(``!4"``"M`````````%@#
M``"4````@P4``(@!```2`@``8P0`````````````MP$``#D%```5!0``NP,`
M`$@%``#^!```K@```!,%```Z`P``X0(``,@"`````````````)H%````````
M:P(``+P&````````M`$``'H!``!B!@```````*4%````````/0,```0#````
M`````````/,!``#A!```H`$``+T&```S!@```````'<#`````````````#0"
M``"4!``````````````(`@``P`,``&X```!_```````````````,!@``````
M`````````````````*P%``!K`0``GP,``"H&````````,`,``"L"``"F`@``
M``````````!7`0``A`4``)P%```I!````P4```````""`@``YP```"<$````
M````,@(`````````````100````````8``````````````"J````,P0``)8`
M```7!@``-`,``+L$````````?0(```````"U!@``MP0``+P!``"K!0``````
M``````#X!0``408`````````````KP0``*8&``#,!@``W0```'L!``"5!0``
M`````#T&``!S!```[@4``#H!``!L````1@$``%X!``#N!```"@````````#T
M````*@0``)(`````````=`0``````````````````,,%````````Q````#0$
M``#$`0``\@,``*@&`````````````%0``````````````+T#```.`@``S04`
M`&4%```N!````P,``$,```#2`P``I00`````````````^0$```````!#!@``
M6P8``-0```#L!0``<04``-\!`````````````/\"```D!``````````````9
M!0``,P```)<!``"<!```Z`4```D"``#\`P````````````"Q`P``V@``````
M``#_!0``K`8``*P!``##`P``?00``)X"````````D00```T%````````>0,`
M``$#```)!@``P@(```("``#%````?`,``%`#``"+`0``]0,``),#``!;!0``
M8P8``*,$``#%`P``O0```#8!``"A!@```````!X!``#.`@``ZP(``*,"``!F
M`P``T`8```````!S`@```````(H#````````@`0```8"``!/!0``6P0`````
M``!R`0```````%$#``#0!```%0$``-P"``!J!0```````&P$``#>!```L`(`
M`&D#````````````````````````H04```````"E`P```````&\!```$!@``
M'@```%H$``!%!@``7@```,<!``#R`0``"`8``+\%``#M!0``@08``/<%``#I
M`@``<0,``(P$``"P`````````'0````^!@``J0(``.(%``#0`@``(08``!L%
M``"3````1P8``'`$```R!0````````````!5!0``/0(```````!/!@``'P4`
M``````"'````\P,`````````````8@0``'L%```@!````````"H%```A!0``
M[`,```````"_`@``V0```-L#```^`@```````$$&````````0P(``#4%````
M```````````````6`````````,4!``#7`P``!00``$X!````````-@8``"4"
M````````````````````````:P4``*P#``#8````2`(``"D%``#G!```````
M``````#J`@``'P```(<!``"O`P``L@(``-T"``">!0``-@(```````!3````
M%@8``&D```"N`@``L`0````````#!@``D@8``!$%``"7!```(P(```````#0
M`0``+`$``"T$````````-P(``/(%``"W!0``4@(``.0%```2`P```````!,!
M```Q!````````'@&`````````````"\&``"+`@``X0$``"X%````````%P,`
M````````````IP,````````9`P```````!,"``"K`P``AP0``.``````````
MN@0`````````````"`,```````"3`0``#````$0$````````)`,```4````=
M!```E`8`````````````,@$``,L#```C`0``5P0``'X#````````H0,``*H&
M```=````B`8``&T&````````]@,```````"&!@`````````````@!0``:@(`
M``````"U!0````````````!Q`0``9P```'(%``#4!```@`(``#H&``!`!@``
M>@,``&8```#,`P``X0,``+<"``````````````````!N!@``_0,``-P!``"Z
M!@``<P8``(`%```#!```GP(``((!``!:`0``"@,``$@!```B`0``800`````
M``!G!0``"P````````#C!0```````*0%``!*`@``*````!4$``#]!0``````
M`!\"``"X`P``-P$``#D```````````````0!``#!`P```````!P$``#^`0``
M`````````````````````"L!``````````````````"K!```=P```)8#``"6
M!@``W`,``(8"````````8P(``+P"```C`P``4P8``'L$```?`0``W@4`````
M``#4!@``'P0``,$%````````2@,``*(#``!\`0``Y@$``"4$``"E`0``````
M``````!Z!@``FP(``*$$``#J`P``KP8``,L$``#+`@``+@8``#\```!O!0``
MU08``+4#````````A`````````!6!```G0```"P"``"=`@``E`(``(0$````
M````1@(``)$!````````F`0``)D```#B`P``9@(```````!'!```?`0`````
M``#S!```@`,```````!``0``=@(```````#M`0``LP(``*("````````9P8`
M`#X!`````````````"L$```[`P``+P(``/`$```L!@``P`0``/4```#W`P``
MV0(``/`"```K````1@,``'`&``":````X`$``(<"```S`0``Y`$``!P&````
M``````0``.\$``#J!0```````!D!````````OP8``+,&``"``0``````````
M`````````````*H$``!@`0``5`4``'H```#=`0``G@,``"8$``!*!0``````
M`(P#````````W@$``!0```!H!0``@0```+(%```B!````````"(%``#``@``
M]P```*<!``##!```U`$``,H#````````=`,```````!V!0````````````#8
M!0```````*P``````````````+L!``"J!0``YP(``)@&``"K`0``.0,``,`&
M``#F`P``7P(``'H$````````^P(``-,```"(!0``Y04`````````````EP8`
M`&`&`````````````"\!```.!```<`(``%<%``#"````]0(``)@%``!R````
M/`0``'@!``!K!@```````%<```"3!@```````!$"``!S!0``5P8```````#"
M`0``+04```4&``!-`P``V@,``!0!````````J`0``%D````*!0```````*`#
M``![`@```````&X%``#>````Y`0``'4````N`0``I`(``&("``"@````````
M`&@#``"W!@``)@4``!H!````````"@8````````O!```I@$``+@&``!T!@``
MZ0,``,````"#````40(``($%`````````````#@$``!V!````````.@#``!W
M`@``%`4```````#$!@``,@0``(H$```W````VP$``'@"````````Y0$``!T#
M``!D`0```````)P&`````````````,0"```6`P``:P```(X````>!@``U@(`
M```````'`P``D`4````````[`0``````````````````:@$``%P````F`P``
M$````%D!```"````.08``/<$````````\@(```````#7`0``/`(`````````
M````L`8``&4#````````8@$``)<#``#Y!```B0(``,\!`````````````)8"
M``!7`@``K@4``+(````;`@``908``!\&``"2`@``3@``````````````````
M`(T"```;!```^`$``&0%```0!0``IP8``#T$``")````-08`````````````
M400``*T"``#E````!`(``/`!``!.!```@0(``*D```!;````U`(``&,`````
M````90$``&4`````````V04``(@$``#-`P``P@8``/T`````````F0,``,T"
M```'!@```````.,```#8`0``&P$``',!``!0!```F@(````````=`0``$P,`
M`$`"``!P!0``4P$```````#B`0``)`(```````!/`@``3`8```````!$!@``
MZ@```/D"```-````5@(``)L&```@!@````````````!Q`@``7`,``.($``"G
M`@``I@4``$$"``"3!```C@4``/8!````````L@$``````````````P$`````
M``!Y!0``30$``!H%````````D0(``&@````````````````#``"(`@``T0,`
M`"<"``#X`P``HP```/X#```J`@``=@$````````E!@```````+0$``"+!0``
M!P(`````````````0P$``,D"`````````````,`!`````````````$<!``!B
M`P``/P0``!X"``!K`P```````%X&``!<!```I`8``.P$``"F````````````
M````````5P,``"8&````````F0$`````````````608``/P%````````5@4`
M`'<$``````````````````":!@``,@````````!A`@``M`4````"````````
MJP8``,T&````````80$```````!#!````````,$"``!W!0``S00``,D!``"%
M!0``W`0```<%`````````````#<%``!@!0``^0,``%0!````````````````
M``!*````.`,````````#````A0(`````````````'`,``/$%``!2````D`$`
M```````8!@``P`4``#`$````````6P$```````#7!0``^``````````M!@``
MZP$```````"G!0``M`,``%\``````````````)4$``#Z`@``YP,``$D!````
M````Q`4``,\%```3````SP````L#``"V!```Z@0``*4"``"M`0``/0```"D"
M``#,`0```````$0!``!_!@```````'4!``!$`````````)`&``"[!@``!0$`
M`"4!``";`P``9P(``,8#```X`0``*@`````````/!````````+H#``"U!```
M0`````````"T!@``<`````$"````````"04``%T&``",!0``_P,``(<#``"Y
M`@```````$$```#/`@``_P0```\!``"1`P``[`(``$T"``"_`0``"`$`````
M```G!@``U`,``!D```#O`0``B`,``)@`````````"@0``"D!```H!@``V@(`
M```````_`0```````/,"``!E!```7@,``$D$``#Q`````````(``````````
M?````*`$```:`P``@@```(8$````````$@0``)X$```;`P``H`(``#$#``";
M`0``6`4``"````#.!0``U@4``'X"````````,04```<$```/!@``````````
M``#T!```J0$``"H#```>`P``,P4``#X$```O`P``-@```!P%````````````
M`$T%``#A``````````````!P`P``LP,``/,%```(!````````-<"```-`0``
M!@8``)<"``"[!0``;`(````````(!0``;@$```8#``!`!0``$00```L!````
M````)P$``*X$```Z!0``C0$````````0!```#@$``(X"``#F````6@4```8`
M``!M````MP,``)@!``"<````;P8```````#-````1`(``-T$````````LP4`
M`&\$``"H`0````````P"```4!```)`4``$T$``#T`@````````4"````````
M``$``+$!```Q`0``)P```%@"``"]`0````````````!.!0``B`````````!?
M!0```````+$%`````````````.D````T!0``\0$```````##`0```````#`%
M``#H`0``7`8``/X%``"+!```$@```#P!````````]0$``%,%``!5`P``I@0`
M```````8!0``!@0``!P````7`0``2P(``$`$``"V!@```````,X```#]!```
M#`$``&P%``!_!0``RP$``#$&````````8`0``,L```"/!@``T00``/@"````
M````K`0```@```!M`@``%@0``%(!``"G````C@8``-4```#^````2@$``'D"
M``!G`0``?`(``"`"``!5`0``+0(``!<````6!0``5`0``*T&``#\````P@,`
M`.0#`````````````$4%````````!@$``.0"```T`0``?@8``#L"```Y!```
M!P$``#(&``#P!0``TP8``#8$````````J@(``%`!``#8`P``-P,``*4&```1
M!@```````(,&`````````````.<!`````````````(\!``#Z````1`4``+@%
M``"O````ZP,``)X&```C````D`0```````````````````````!:!@``-`8`
M`*T%```0`P``VP````````!*!@``[P,``,D&``#[``````````P%````````
M6P,``&D%``#)`P```````,(%````````J@,```````#&`@``0P,`````````
M````;P```,X$````````U00``/`#`````````````,L%``!\!0``O@8``,H&
M``"B`````````"L%````````@0,``,4%``"\`P``L`,``+D!```B`@``000`
M`(L`````````@`8````````"!@``.@```#X#`````````````#`&```X!0``
M`````,8$``#C`P``T0````````"*````]@0``'T```!<!0``>@4```($``#C
M`0``.`8``/D```!:`P``?P(``+H"````````2`,```````"]!```]04`````
M``!A!@``O@4``$8%``"C`0`````````````]!0``N````$<```!U`P``#00`
M`$L```#!`0``,0(```,"``!.!@``G04``,$$``"Q!```8@```'`!``!(````
M`````````````````````"\%```2!@```````(,!``````````````0%```-
M`P``G0,``#\%``!J!@```````(D!``"Z````F@,```````#@`P``'04``.P`
M``!2!@````````L"````````:P0```````"U```````````````B!@``(00`
M``<```!5````\``````````.````<@(``!<%```&!0``;@(``,,&``!8!```
MS`4``($!``#_````UP0``)@#``!&!@``ZP0```\"``!N!```R`````````!O
M`P``70$``%H`````````V@0``",&```````````````````E!0```````.D%
M``!$`P``CP,``(T%```H!```?`8``+\```"$`0``WP,``(<&````````4@4`
M````````````20````````#&!0``G`,``%@!``#N````B08```````"Y````
MN04``'L&```U`@``=P8``'T%``#F`@``5`,``&@"````````'0(``%D"``";
M``````````````"?!@``````````````````<0```-`#``"?``````````D#
M```4`P`````````````Z!```C0,`````````````7P8``!P!```L!0``K0,`
M`&8!``!=`P``5@`````````H`0``LP$```$&``"&````;0,``)``````````
MD@0``/H%``!Z`@``J0,``,$&``"Y`P```````,@#`````````04```````#A
M!0``60,``"@#``"9!@``.P```.D!``#D````*P8``*P"``"R`P``9`,``+X"
M```,!```U@$``%0"``"%`````````*X&``!&!````````)P"```"`0``````
M`"P`````````40$``/4$````````$0$``+8#````````%0,``-\"````````
M<P````````!L!@```````*L```!6`P```````&0$``"_`P``4@,``%T```"Y
M!```=04```(%````````<08```````"P!0``20(```````#;`@``<@,``$(!
M``!-!@``-0$``-8```")`P``'`(``(H!``"\````C@$``(T&```5````I`$`
M`"T```"9!````````&D$```8`P``H`8``+X!```%`P``&@(```````!Y!@``
M30```#X```"T````C````.`$````````9`8``/L%```M`P``QP8``(,"```N
M`@``2P8``+$&````````-@,```````"@!0``X`(``.@"````````F@$``)(%
M``".!```;`$``+P%``"$!@``U@0```````"V`0``=@,``#\#````````80,`
M`*H!```X````KP(``)<```"%!@``U0(``"@%`````````````$<"````````
M.P0``'@```#;!```R`4``(4#````````Z00``)(!``#2!```FP0``#P`````
M````;00``,H!``!^!`````````````"-!````@,```````":!```````````
M```L!```7P,``%$```"6`0```````&@!``#W`0``U04``-T#```5!@``````
M`)$```"D`P```````-4!``!'!0``G08``"`#````````N08``$$%```Z`@``
M`````-X#````````'08``*(&``!=!0``/0$`````````````PP(```````";
M!0``*@$``/L!``#V!0``>P,``/\!``!U!@``7@4``"8!``"B`0``70(`````
M````````O@```%`````1`P``-0,``)\%``!X`P``&P````````"Q`@``S`0`
M`$,%``"2`P``:0(``%L"``!?`0```````,,```"I!@```````'T!``"[````
M404``````````````````$L!``",`0``7@(``(X#``````````````D!``"1
M!0```````&8%``!<`@``J`````````"A`````````$\!``!F!```/@4``)4#
M``````````````````#.!@```````+<`````````[P4```````!E`@``Q@8`
M`"0&``#H!````````````````````````%T$```D``````````````"#!```
M,P,``%`"``#&````F`(`````````````````````````````#@4``(H%``!8
M`````00```T"``">`0``H@0``+(&``"H`P``NP(``&\"``#/`P``N@$`````
M``">````E`,``#4$``#1`0``=@```"(````6`@````````````!4!@``J`(`
M`,X!``""!```7@0``/<"``!T`0``=0(```L%``#8!```9````,@$``"9`@``
M+P```/T!``#(!@``L`$``+X$``!W`0````````\#`````````````!H$``!%
M`0``TP,``(8!````````H0$``*L"``!%`P``8P4``,<"``"F`P``QP```'X`
M``!Y!```K00``(H"````````V00```$!``!"`P````````X&```:!@``A`,`
M`+\$```@`0``10(``((#````````/`4``#<$``#*`````````'@$``!9!```
ME`4``$`#``#2````,0``````````````&0(``*,#```>!```8P$``-P```#)
M````>`4``$P"``"0`P``V@$``%,#``"V`@```````*<$``#8`@```````$$#
M``"&!0```````'L````D`0``[@$``,P"``"=`0``GP0````%``!+!0``CP0`
M`)<%````````N@4```````#O`@``Q08``,0#``"/`@``%P(``,4"``#(`0``
M+@,```````"]!0``)P,``$L$```L`P``[P```+,```"%!````````,\$```\
M`P``$@$``-X"````````*P,```````"A`@``+@```-<````_`@```````(0"
M``!3`@``@P,``,$```#F!```[0```/(````)!```/P8``$(```!]!@``````
M```````9!````````+($``""!@``TP(``-T%````````?P,``/H#``!F!@``
M`````&$%````````]`,````````F`@```````((%``````````````````#S
M````B00````&````````508``)T$````````<P,````@*"5S(&1A>7,@86=O
M*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AY97-T97)D87DI`"!A="``
M)60@)7,@86YD("5S`"5D(&YO=&5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO
M=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@
M06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!F
M:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I<R!R97%U:7)E9``E<R!M
M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R
M97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K
M;&ES=``E<SH@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E
M<R!T;R`E<P`M+2!S96QE8W0@+2T`,2!N;W1E`#$R($AO=7(@1F]R;6%T`#(T
M($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T@4VAO=V5R<P!!32]030!!4$D@240`06)O
M=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D96YI960@9&5L971I
M;F<@;F]T92X`06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N`$%C8V5S
M<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N`$%C8V5S<R!D96YI960@<V%V
M:6YG(&YO=&4Z("5S`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN
M`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R
M;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI
M<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C871E9V]R>0!!9&0@8V]L=6UN
M`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@
M82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O
M(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1I;F<@02!.97<@3F]T90!!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K
M`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R
M:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T
M960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@
M<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A
M`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O
M;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A
M`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@
M:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<FEL
M`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H
M:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N:6$`07)M
M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I
M;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T
M<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F
M86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE($-A=&5G;W)I97,Z`$%V
M86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VL@
M=&\@3F]T97!A9`!"86-K('1O($YO=&5P860@3W!T:6]N<P!"86-K9W)O=6YD
M`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@
M:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E3
M3RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V5L:6YE`$)E;&%R
M=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD
M87D`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O
M:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T
M($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R
M:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<P!#4U8`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A
M;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L
M(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V
M92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@
M97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D
M+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#
M87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A=&5G
M;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S
M`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`
M0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#
M:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M
M86EL<RX`0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P;&%Y(&]P
M=&EO;G,N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I
M9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@;65M;R!C871E9V]R
M:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RX`0VAR:7-T;6%S($ES
M;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`
M0VQE87(@1F]R;0!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R
M.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT
M:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`
M0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E9"!B;W)D
M97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T
M:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N
M9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#
M;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL
M960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&EN=64`
M0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<W1A
M(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@
M;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N
M("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R
M=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R;6ES
M<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT
M(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@
M8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U
M<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#
M>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`
M1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T
M92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM
M86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L="!#;VQO<@!$969A
M=6QT($ED96YT:71Y`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T
M92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE
M<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T
M92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-E
M;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5S8W)I
M<'1I;VXZ`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`
M1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O
M=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$
M;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO
M860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O
M<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I
M="!";&]C:P!%9&ET($=R;W5P`$5D:70@3F]T90!%9&ET(%!E<FUI<W-I;VX`
M161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET
M(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I
M;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I
M;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@3F]T90!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@
M>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N
M('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@
M1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN
M=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U
M(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI
M;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP96-T960@
M)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`
M17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@3F]T97,`
M1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&7W5L;"!497AT`$9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T
M;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y`$9E96QS
M($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9I:FD`1FEL92!#;W5N
M=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`
M1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L
M9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD
M97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W
M<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I
M`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A
M<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO
M=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U
M;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N
M8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@
M4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R
M;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`
M1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M
M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`
M1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O
M`$=O961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@
M*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T
M<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'
M=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI
M<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`
M2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B
M;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H
M+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP
M`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE
M(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@
M:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V
M960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG
M`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E
M<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(
M=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0
M($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V
M:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N
M;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@
M55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@
M9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@3F]T97,L(%-T
M97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T97,`26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@
M069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN
M8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I
M80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R
M="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?
M0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E
M<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M
M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`
M26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R
M90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T
M:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`
M26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI
M='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A
M;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A
M;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M
M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N
M=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D
M86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&
M=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E
M<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U
M=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y
M($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED
M<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I
M=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S
M="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W
M`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F
M=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB
M>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ
M;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T
M90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,
M:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN
M:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE
M`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E
M<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@
M=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U
M=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I
M;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T
M97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,
M=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL
M($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S
M`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T
M(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L
M9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H
M`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365M;R!497AT`$UE;G4@
M;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y
M<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE
M>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-
M:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA
M<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!
M4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N
M+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@
M=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES
M<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S
M:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E
M`$UO9&EF>2!54DP`36]D:69Y:6YG("5S`$UO9'5L=7,`36]L9&]V82P@4F5P
M=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H
M;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A
M<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,
M969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA
M;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S
M96QE8W1I;VX`37D@06-C;W5N=`!->2!.;W1E<P!->2!0;W)T86P`37D@4&]R
M=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA
M;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT
M:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L
M(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R
M=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P
M92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI
M80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W($YO=&4`3F5W(%5S97)N86UE
M("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.
M97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI
M9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG
M=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C
M:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A
M=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@
M861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YO=&5P
M861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+@!.;R!N;W1E<P!.;R!N;W1E
M<R!M871C:"!T:&4@8W5R<F5N="!C<FET97)I82X`3F\@;F]T97,@=&\@9&ES
M<&QA>0!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N
M97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.
M;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S
M96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U
M<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M7W1E`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y
M+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H
M97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O
M<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.
M;W0@<W5P<&]R=&5D+@!.;W1E($-A=&5G;W)Y`$YO=&4@1&5T86EL<P!.;W1E
M($QI<W1S`$YO=&4@5&5X=`!.;W1E(%]497AT`$YO=&4@;F]T(&9O=6YD+@!.
M;W1E7W!A9`!.;W1E<&%D)W,@;F%M93H`3F]T97!A9',`3F]T97,`3F]T97,@
M4W5M;6%R>0!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`
M3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@
M0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/
M;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E
M<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI
M<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!0
M1U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0
M=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`
M4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!4+5-T;W)M
M<P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE
M80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN
M8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`
M4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@
M9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!0
M97)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`
M4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H
M:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET
M=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A
M=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0
M<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V
M:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L
M96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0
M=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2
M:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO
M('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO
M=V5R`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E
M<V@@3&ES=`!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H
M:7`@0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E
M($)L;V-K`%)E;6]V92!C871E9V]R>0!296UO=F4@8V]L=6UN`%)E;6]V92!F
M;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`
M4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N
M(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E
M<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2
M975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU
M97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P
M`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@
M<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-
M12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE
M<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!3
M35,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL
M`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@
M3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`
M4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R
M;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@)7,`4V%V92!/<'1I;VYS
M`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T
M('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@
M)7,@8V]N9FEG=7)A=&EO;BX`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN
M97,`4V5A<F-H(%)E<W5L=',`4V5A<F-H(%-C;W!E`%-E87)C:"!?5&5X=`!3
M96QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A
M9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A(&YO=&5P860`4V5L96-T
M(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T:&4@8VAA
M<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A
M;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E;&5C="!T:&4@
M9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R
M8V4@9FEL93H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM
M92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93H`4V5L96-T960@0V%T96=O<FEE<SH`4V5N9"!0<F]B;&5M(%)E<&]R
M=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@
M86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER
M960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I
M;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+@!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO
M=P!3:&]W(&%C=&EO;B!B=71T;VYS/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\`4VAO=R!N;W1E<&%D(&YA;64_`%-H;W<@;F]T97,@9G)O;2!T:&5S
M92!C871E9V]R:65S`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO
M=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3
M:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H<FEN:P!3:')I
M;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W
M87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA
M='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC
M90!3;&]V86MI80!3;&]V96YI80!3;F]W(%-H;W=E<@!3;F]W(&1E<'1H.B``
M4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O
M;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&)Y($-A=&5G;W)Y`%-O<G0@8GD@
M3F]T92!497AT`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S
M`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U
M=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A
M8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN
M`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E
M:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E
M(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L
M:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=
M`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I
M<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I
M<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I
M;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD
M`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;7,`5%-6
M(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S
M`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E
M;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U
M<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S
M(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S
M<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N
M(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+
M(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I
M=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4`5&AE(&YO=&4@=V%S(&1E;&5T960N`%1H92!N;W1E<&%D("(E<R(@
M8V]U;&1N)W0@8F4@8W)E871E9#H@)7,`5&AE(&YO=&5P860@(B5S(B!H87,@
M8F5E;B!C<F5A=&5D+@!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@
M86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O
M=R!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N
M;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES
M(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=DYO=&4@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E
M<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A
M<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B
M;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W
M87,@86X@97)R;W(@<F5M;W9I;F<@=&AE(&YO=&4Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!S879I;F<@=&AE(&YO=&4Z("5S`%1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R
M92!W87,@86X@97)R;W(@=FEE=VEN9R!T:&ES(&YO=&5P860Z("5S`%1H97)E
M('=E<F4@;F\@;65M;W,@=&\@97AP;W)T+@!4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@
M;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M
M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U
M9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE
M;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I
M;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C
M=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A
M8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T
M(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E
M9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES
M(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE
M(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`
M5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS
M90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K
M;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E
M('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S`%5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L
M:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5
M;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`
M57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA
M;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M
M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S
M97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I
M=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H
M92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E
M>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z
M(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`
M5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU
M96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O
M;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!6
M97)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S
M`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL
M:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).
M`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!7
M86QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@
M4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7
M97-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H($YO=&5P
M860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\`5VAI8V@@<&AA<V5S
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK
M:0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8+5)E9@!8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)
M9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA
M<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S+@!9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C
M="!A(&YO=&5P860@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%N
M('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T
M92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M
M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T
M:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@
M9&5F875L="!I9&5N=&ET>3H`66]U<B!D969A=6QT(&YO=&5P860Z`%EO=7(@
M9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO
M=7(@;F]T97!A9',Z`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G
M;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O
M=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@
M+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E
M<UT`7T%D;6EN:7-T<F%T:6]N`%]"86-K('1O($YO=&5P860`7T-,20!?0V%T
M96=O<GD`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2;W<`7T5D:70`7T9I
M<G-T($QI;F4`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?
M26UP;W)T+T5X<&]R=`!?3&ES="!.;W1E<P!?3&]G(&EN`%],;V<@;W5T`%]-
M;V1I9GD@3&EN:RXN+@!?3F5W($YO=&4`7T]P=&EO;G,`7U!E<FUI<W-I;VYS
M`%]0<FEN=`!?4F5M;W9E($QI;FLN+BX`7U-E87)C:`!?4V5T=7``7U1A8FQE
M(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C
M86QM`&-L:6-K(&AE<F4`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@
M870@)7,@)7,`:#H`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE
M;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!N;W1E<RYC<W8`
M<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M
M86EL('9I82!(5%10`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE
M8W0`=D-A<F0`=DYO=&4`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!-;F5M;R`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,2TS,"`Q.#HU
M,"LP,C`P"DQA<W0M5')A;G-L871O<CH@5FEL:75S(%-U;7-K87,@/'9I;&EU
M<T!L;FLN;'0^"DQA;F=U86=E+51E86TZ($QI=&AU86YI86X@/'9I;&EU<T!L
M;FLN;'0^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ,PI#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET"@`@*'!R:67P("5S(&1I96YA<RD`("AM>6=T=6MA<R`E
M<RD`("CP:6%N9&EE;BD`("AV86MA<BD`(``E9"`E<R!I<B`E<P`E9"!U_G)A
M\&%I`"5D+61I96[X('!R;V=N;WKK`"5S("T@<&%S=&%B80`E<R!A;G1S<&%U
M9&%S`"5S($M"`"5S('!R;V9I;&%K=&EK;W,@=F5I:W-M86D@+2!P871V:7)T
M:6YI;6%S`"5S(')E9VES=')A8VEJ80`E<R!N=6]S=&%T;W,`)7,@:F%U(&5G
M>FES='5O:F$N`"5S("5S("5S`"5S(&9A:6QA<R!SZVMM:6YG86D@X6ME;'1A
M<P`E<R!Y<F$@<')I=F%L;VUA<P`E<R!M:6YU=.MS`"5S(&YE<F%S=&%S+@!N
M=6\@)7,@:6MI("5S(&GP("5S`"5S(&%D<F5S^"!K;GEG96SK`"5S(&MA;&5N
M9&]R:75S`"5S('7^<F'P^"!K;GEG96SK`"5S(&1A<F+X('/@<F'P87,`)7,Z
M("5S`"P@9_MS:6%I("5S("5S`"P@:VEN=&$@;G5O("5S(&EK:2`E<P`M+2!P
M87-I<FEN:VET92`M+0`Q('7^<F'P87,`,3(@=F%L86YD^"!F;W)M871A<P`R
M-"!V86QA;F3X(&9O<FUA=&%S`#(T('9A;&%N9&]S`-!I86T@8FQO:W5I(')E
M:6MA;&EN9V$@=FEE=&$@9'5O;65N^"!B87KK:F4N`,%V>6MO(')I;71A(&ML
M86ED80!.;W+K9&%M:2!U_FMO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K
M=&D@=FEE\.!JX2!01U`@<F%K=.`N`$YO<NMD86UI('!A=&EK<FEN=&D@<&%S
M:7)A\'ETX"!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%!'4"!R
M86MTX"X`3F]RZV1A;6D@871K;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5R
MZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4$=0(')A:W1U<RP@8F5I(/YI;F]T
M:2!S;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@<&%S:7)A\'ET:2!L86GP:^`@
M<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%!'4"!R86MT
M=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N`$YO<NMD86UI(&%T:V]D
M=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!T
MX&KA(%,O34E-12!R86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N
M`$YO<NMD86UI('!A<VER8?!Y=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@
M=FEE\.!JX2!I<B!S;&%P=.!JX2!3+TU)344@<F%K='5S+"!B96D@_FEN;W1I
M('-L87!TX&K@(&9R87KF+@!.;W+K9&%M:2!U_FMO9'5O=&D@;&%I\&O@('!R
M:79A;&]T92!T=7+K=&D@=FEE\.!JX2!3+TU)344@<F%K=.`N`$%-(')O9'EM
M87,`04TO4$T`05!)($E$`$%P:64@\.$@<F5D86MT;W)I^`!!<&EE+BXN`%9I
M<VGP:V%I(&%P8>AI;VIE`%9I<VGP:V%I('!E<B!V:61U<N$`4VES=&5M82!N
M971U<FD@=&5I<VGX('-U:W5R=&D@5D93(&MA=&%L;V?@+@!3:7-T96UA(&YE
M='5R:2!T96ES:?@@<W5K=7)T:2!61E,@9F%I;.`N`$YE='5R:71E('1E:7-I
M^"!I\'1R:6YT:2!U_G)A\&\N`$YE='5R:71E('1E:7-I^"!P97)K96QT:2!U
M_G)A\&\N`$YE='5R:71E('1E:7-I^"!I\'-A=6=O=&D@=?YR8?#@(.$@)7,N
M`$YE='5R:71E('1E:7-I^"!I\'-A=6=O=&D@=?YR8?#@.B`E<RX`4VQA<'1A
M_F]D:7,`4^!S:V%I=&$@=?[P86QD>71A+@!!<'-K86ET80!3=6MU<G1I`%-U
M:W5R=&D@<&]G<G5PX0!3=6MU<G1I('!O=&5I<V5S`$)L;VMO(.%T97)P:6UA
M<SH`4W5K=7)T:2!N875JX"!G<G5PY@!3=6MU<G1I(&YA=6IA<R!T96ES97,`
M3F%U:F\@=F%R=&]T;VIO('-U:_MR:6UA<SH`4W5K=7)T:2!K871E9V]R:6K@
M`%!R:63K=&D@<W1U;'!E;.$`3F%U:O@@;F%R:?@@<')I9.MJ:6UA<P!3=6MU
M<G1I('!O<N``4')I9.MT:2`E<R!M96YI=2!P<FEE($UO>FEL;W,@X7)A;FMI
M^"!J=6]S=&]S`,%T<F%U:W1I(.$@861R97/X(&MN>6=E;.8Z`,%T<F%U:W1I
M(.$@;6%N;R!A9')E<_@@:VYY9V5LYCH`4W5K=7)T:2!V87)T;W1O:N``3F%U
M:F\@=?YR8?!O(&O[<FEM87,`5F%R=&]T;VKX(&O[<FEM87,@:?!J=6YG=&%S
M+@!!9')E<V%S`$%D<F5S86D`061M:6YI<W1R=6]T:2`M(&=A;&D@;G5S=&%T
M>71I('1E:7-E<R!K:71I96US('9A<G1O=&]J86US`%9A;&1Y;6%S`$)A;F5R
M:6%I`$%F9V%N:7-T86YA<P!!;&)A;FEJ80!!;/YY<F%S`%!R879A<F3K`$QY
M9VEU;W1I`$QY9VEA=FEM87,Z`%9I<V]S`%9I<VD@<')I<VEJ=6YGYB!V87)T
M;W1O:F%I`%9I<V]S(&=R=7#K<P!6:7-O<R!T96ESZW,`5FES;W,@:V5T=7)I
M;W,@<'5SZW,`3&5I<W1I(&ME;&5TX"!A9')E<_@`3&5I<W1I(&YA=61O=&D@
M<W5R^_!I=6]TX"!SX')A\.`_`$IA=2!E9WII<W1U;VIA`$%L=&5R;F%T>79U
M<R!)35-0('!R:7-I:G5N9VEM87,`06QT97)N871Y=G5S($E-4U`@<VQA<'1A
M_F]D:7,`06QT97)N871Y=G5S($E-4U`@=F%R=&]T;VIO('9A<F1A<P!!;'1E
M<FYA='EV=7,@96PN('!A\'1O(&%D<F5S87,`06QT97)N871Y=OMS(/!A8FQO
M;F%I`$%L=&5R;F%T>79U<R!T96MS=&%S`$%M97)I:V]S(%-A;6]A`,%V963K
M=&4@;F5L96ES=&ENX"!R96EK\&WF+@!!;F1O<F$`06YG;VQA`$%N9VEL86D`
M06YO;FEM:6YI<R!P<F]X>2!S97)V97)I<P!!='-A:WEM87,`06YT87)K=&ED
M80!!;G1I9W5A(&ER($)A<F)U9&$`36]D=6QI<P!-;V1U;&ES('9E:6MI82!G
M97)A:2X`4')I=&%I:WET:2!I<B!P;_!A:VEA;7,`4&%T=FER=&EN=&D`0F%L
M86YD:7,`07)A8FGP:V$@*%=I;F1O=W,M,3(U-BD`07)C:'EV;R!F86EL;R!D
M>61I<P!!<F-H>79O(&9A:6QO('!A=F%D:6YI;6%S`$%R('1I:W)A:2!N;W)I
M=&4@:?!T<FEN=&D@)7,@<F5G:7-T<F%C:6IO<R!P<F'P>6W@/P!!<F=E;G1I
M;F$`07)MZVYI:F$`07)MZVYI\&MA("A!4DU30TE)+3@I`$UE;F%S`$%R=6)A
M`$1I9.MJ:6UO('1V87)K80!+<FES=&%U<R#^96YG:6UO(.$@9&%N9_@@<V%L
M80!!8W-I:2!M96YA<P!!>FEJ82]286UI;VIO('9A;F1E;GEN;R!R96=I;VYA
M<P!!<B!P<F'P>71I('!A='9I<G1I;G1I('!R;V9I;&%K=&EK;W,@=F5I:W-M
M=7,_`%!R:7-K>7)I;6\@<W1U;'!E;&EA:0!"86YD;W1E(&GP=')I;G1I(&YE
M96=Z:7-T=6]J86[H:>`@9W)U<.8N`$)A;F1O=&4@:?!T<FEN=&D@;F5E9WII
M<W1U;VIA;NAI87,@=&5I<V5S+@!"86YD;W1E(')E9&%G=6]T:2!N965G>FES
M='5O:F%NZ&EA<R!T96ES97,N`$)A;F1O=&4@<F5D86=U;W1I(&YE96=Z:7-T
M=6]J86YTX2!E;&5M96YTX"X`071R:6)U=&%I`%)U9W!J^W1I<P!!=7-T<F%L
M:6IA`$%U<W1R:6IA`$%U=&A?8WER<W%L.B!N97)A<W1A<R!R96EK86QI;F=A
M<R!)34%0(&UO9'5L:7,N`$%U=&A?8WER=7,Z(&-Y<G5S(&YE='5R:2!R96EK
M:6%M^"!G86QI;7EB:?@N`$%U=&A?8WER=7,Z(&YE<F%S=&%S(')E:6MA;&EN
M9V%S($E-05`@;6]D=6QI<RX`075T:%]F='`Z(&YE<F%S=&%S(')E:6MA;&EN
M9V%S($944"!M;V1U;&ES+B!3=6MO;7!I;&EU;VMI=&4@4$A0('-U("TM96YA
M8FQE+69T<"X`075T:%]I;6%P.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0
M(&UO9'5L:7,N`$%U=&A?:W)B-3H@;F5R87-T87,@<F5I:V%L:6YG87,@:W)B
M-2!M;V1U;&ES+@!!=71H7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($Q$
M05`@;6]D=6QI<RX`075T:%]L9&%P.B!S=6MU<G1I('9A<G1O=&]JX"`E<R!N
M97!A=GEK;RX@4V5R=F5R:6\@<')A;F7P:6UA<SH@`$%U=&A?;&1A<#H@:?!T
M<FEN=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO`$%U=&A?;&1A<#H@871N875J
M:6YT:2!V87)T;W1O:N`@)7,@;F5P879Y:V\`075T:%]M8V%L.B!N97)A<W1A
M<R!R96EK86QI;F=A<R!-0T%,(&UO9'5L:7,N`$%U=&A?<VUB875T:#H@;F5R
M87-T87,@<F5I:V%L:6YG87,@<VUB875T:"!M;V1U;&ES+@!0<FES:6IU;F=T
M:2!N97!A=GEK;P!0<FES:6IU;F=T:2!N97!A=GEK;RX@)7,`4D%$2553('-E
M<G9E<FES(&YE;&5I9/YI82!A=71E;G1I9FEK=6]T:7,N`%!R:7-I:G5N9W1I
M('!R:64@1E10('-E<G9E<FEO(&YE<&%V>6MO+@!'86QI;6]S(&MA=&5G;W)I
M:F]S.@!'86QI;6D@;&%U:V%I.@!!>F5R8F%I9/YA;F%S`$)/1D@@871S:7!R
M8?!Y;6%I`$=RX?YT:2#A('7^<F'P^"!K;GEG96SF`$=RX?YT:2#A('7^<F'P
M^"!K;GEG96SK<R!N=7-T871Y;75S`$9O;F%S`$9O;F\@<W!A;'9A`$YE=&5I
M<VEN9V%S(&ME<F)E<F]S('-L87!T8?YO9&ES+@!.971E:7-I;F=A<R!K97)B
M97)O<R!V87)T;W1O:F\@=F%R9&%S+@!"86AA;6%I`$)A:')E:6YA<P!"86QT
M:?!K82`H25-/+3@X-3DM,3,I`$)A9VQA9&7P87,`0F%R8F%D;W-A<P!086=R
M+B!L:6YI:F]J90!"86QT87)U<VEJ80!"96QG:6IA`$)E;&EZ87,`0F5N:6YA
M<P!"97)M=61A:0!"=71A;F%S`$=I;71A9&EE;FES`$)L;VMO('!A<F%M971R
M86D`0FQO:V\@=&EP87,`4&%S=&]R:6YT:0!";VQI=FEJ80!!=/YY;6]S`$MR
M8?!T87,`2W)A\'1O('-T;W)U;6%S.@!+<F'P=&%I`$)O<VYI:F$@:7(@2&5R
M8V5G;W9I;F$`5FES;W,`0F]T<W9A;F$`07!AZ&EO:F4`0G5V970@<V%L80!"
M<F%Z:6QI:F$`0G)I=/@@26YD:6IO<R!V86YD96YY;F\@=&5R:71O:F$`0G)U
M;NMJ875S(&1A<G5S86QE;6%S`$)U;&=A<FEJ80!3=?YY;>MT87,@<^!R8?!A
M<P!"=7)K:6YA<R!&87-A<P!"=7)U;F1I:F$`5%93`$-20P!#4DP@<&%S:VER
M<W1Y;6\@<'5N:W1A:0!#4U8`7T-E;.MS(&YU<W1A='EM86DN+BX`2V%L96YD
M;W)I=7,`4F%M=0!+86UB;V3^80!+86UE<OMN87,`3F5V96EK:6$@875T;VUA
M=&EN:7,@<VQA<'1A_F]D_FEO('!A:V5I=&EM87,L('-U<VES:65K:71E('-U
M(&%D;6EN:7-T<F%T;W)I=6UI+@!.96=A;&EU('!R:7-I:G5N9W1I('!R:64@
M24U!4"!S97)V97)I;SH@)7,`2V%N861A`$%T\&%U:W1I`$%T\&%U:W1I('!R
M;V)L96UO<R!P<F%N9?!I;>``3F5G86QI=2!I\'1R:6YT:2!F86EL;R`B)7,B
M+@!.96=A;&EU(')A<W1I(&QA:6MI;F]J;R!K871A;&]G;RX`3F5G86QI=2!A
M<&1O<F]T:2`G=&%R9V5T1FEL92<@<&%R86UE=')O+@!.96=A;&EU(&GP=')I
M;G1I(&MA=&%L;V=O("(E<R(N`$YE9V%L:74@:?!T<FEN=&DN($5G>FES='5O
M:F$@)60@<&_P86MI86DN`$YE9V%L:74@<&5R<OOP:75O=&DN(,%V97-T87,@
MX7)A\/@@<VMA:>AI=7,@;F5S=71A;7!A('-U(.%R8?#X('-K86GH:75M:2!D
M=6]M96[X(&)A>NMJ92X`3F5G86QI=2!N=6MR96EP=&D@_FEN=73K<R#A(&YU
M<F]D>73@(&YU;65RX2X`2V5I<'9E<F1I<P!0879A9&EN:6UA<P!+871E9V]R
M:6IO<P!+871E9V]R:6IA`$MA:6UA;O@@<V%L;W,`36]B:6QU<R!T96QE9F]N
M87,`0V5LZW,@;G5S=&%T>6UA:0!487)P86D@8V5LZW-E.@!#96SK<R!N=7-T
M871Y;6%I`%1A<G!A:2!T87)P(&-E;&GX.@!-;V)I;'5S:7,@=&5L969O;F%S
M`$ME;'3X("A)4T\M.#@U.2TQ-"D`0V5N=')E`$-E;G1R:6[K<R!!9G)I:V]S
M(%)E<W!U8FQI:V$`0V5N=')I;NMS($5U<F]P;W,@*$E33RTX.#4Y+3(I`%-E
M<G1I9FEK871O(&1E=&%LZW,`4V5R=&EF:6MA=&\@=&5I<^MS`,AA9&%S`$ME
M:7-T:0!*^W/X('9A<F1O(&ER(&%D<F5S;RP@:W5R:75O<R!M871Y<R#^;6]N
MZW,L('-K86ET86YT>7,@:7(@871S86MI;NMJ86YT>7,@X2!*^W/X(&QA:?!K
M=7,L(&ME:71I;6%S+@!+96ES=&D@=?YR8?#X('+[\&EA=FEMX"!B96D@<F]D
M>6UO(&YU<W1A='EM=7,N`%-I;6)O;&ES`%!A7W1I:W)I;G1I(&YU;W)O9.`N
M+BX`R&ELZP!+:6YI:F$`2VEN:65T:?!K82!P87!R87-T82`H1T(R,S$R*0!+
M:6YI971I\&MA('1R861I8VENZR`H0FEG-2D`4&%S:7)I;FMI=&4@<VQA<'1A
M_F]DX0!087-I<FEN:VET92!V87)T;W1O:F\@=F%R9.``4&%S:7)I;FMI=&4@
M:V%I<"!V86EZ9'5O=&D@9&%T87,Z`%!A<VER:6YK:71E('-U<OOP:75O=&\@
M<^!R8?!O('-T:6QI^`!087-I<FEN:VET92!K=7)I87,@=?YR8?#X(&MA=&5G
M;W)I:F%S(')O9'ET:2!SX')A\&4N`$MA;.MD^"!S86QA`$ML87/K<R`E<R!N
MZW)A+@!':65D<F$`2?!V86QY=&D`2?!T<FEN=&D@35,@3V9F:6-E(/YY;65S
M`%9A<G1O=&]J;R!D=6]M96[X('9A;'EM87,Z("5S`$GP=F%L>71I('9A<G1O
M=&]J;R!D=6]M96YI<P!)\'9A;'ET:2!V87)T;W1O:F\@9'5O;65N:7,`5.9S
M=&D`0VQI8VMA=&5L;"!P97(@2%144`!5_F1A<GET:2!L86YGX`!$96)E<W5O
M=&$`1&5B97-U;W1A`$MO:V]S;R`H2WEL:6YG;RD@<V%L;W,`5'7PZ&GX(&-E
M;&GX(&MR8?!T^"!R;V1Y;6%S`$MO;'5M8FEJ80!3<&%L=F$`4&%S:7)I;FMI
M=&4@<W!A;';@`%-P86QV;W,@<&%S:7)I;FMI;6%S`%-T=6QP96QI86DZ`%-T
M=6QP96QI^"!P879A9&EN:6UA:0!+;VUI:W-A:0!+;VUA;F1A`$MO;6%N9&EN
MZR!E:6QU=.L`2V]M96YT87)A<P!687)D87,O<&%V87)DZP!+;VUO<F%I`$MO
M;7!A;FEJ80!+;VUP:75T97)I86D`4^!L>6=O<P!.=7-T871Y;?@@<&%K96ET
M:6UA:0!+;VYF:6?[<G5O=&D@)7,`4VQA<'1A_F]D:7,@9&%R(&MA<G3@`$MO
M;F=A<P!$96UO:W)A=&ENZR!+;VYG;R!297-P=6)L:6MA`%!R:7-I:G5N9W1I
M(&YE<&%V>6MO+@!0<FES:6IU;F=T:2!N97!A=GEK;SH@`%!R:7-I:G5N9W1I
M('!R:64@=FEE\/AJ^"!R86MT^"!S97)V97)I;R!N97!A=GEK;RX`4')I<VEJ
M=6YG=&D@<')I92!V:67P^&KX(')A:W3X('-E<G9E<FEO(&YE<&%V>6MO+"!N
M97,Z("5S("@E<RD`4')I<VEJ=6YG=&D@<')I92!&5%`@<V5R=F5R:6\@;F5P
M879Y:V\N`$MO;FMA:W1A:2!SZVMM:6YG86D@X71R875K=&D@X2!*^W/X(&%D
M<F5S^"!K;GEG96SF`%3F<W1I`$MU:V\@<V%L;W,`3&%I;>MS(/YI;G5TZW,`
M2V]P:6IU;W1I`$MO<&EJ=6]T:2!P87-I<FEN:VEMX`!+;W-T82!2:6MA`$1R
M86UB;&EO($MA=6QO($MR86YT87,`3F5P879Y:V\@=?YK;V1U;W1I(%!'4"!L
M86GP:V\N`$YE<&%V>6MO('!A<VER8?!Y=&D@4$=0(&QA:?!K;RX`3F5P879Y
M:V\@=?YK;V1U;W1I(%,O34E-12!L86GP:V\N`$YE<&%V>6MO('!A<VER8?!Y
M=&D@4R]-24U%(&QA:?!K;RX`3F5P879Y:V\@<')I9.MT:2!K;VYT86MT;RX@
M)7,`3F5P879Y:V\@875T96YT:69I:W5O=&ES(.$@3$1!4"!S97)V97+A+@!.
M97!A=GEK;R!P871I:W)I;G1I(&)A;&%N<V\N("5S`$YE<&%V>6MO('-U:W5R
M=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO(&%T:V]D=6]T
M:2!01U`@9'5O;65N^"X`3F5P879Y:V\@871K;V1U;W1I(%,O34E-12!D=6]M
M96[X+@!.97!A=GEK;R!I\'1R:6YT:2!K;VYT86MT;RX@)7,`3F5P879Y:V\@
M:?!T<FEN=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO(&YU
M<W1A='ET:2!G87;K:F\@96PN('!A\'1O(&%D<F5S;RX`4&%V>6MO(&=A=71I
M('9I<V]S(&%D<F5S^"!K;GEG96SK<RX`3F5P879Y:V\@9V%U=&D@=FES;R!D
M:7-T<FEB=6-I:F]S('/@<F'P;RX`3F5P879Y:V\@9V%U=&D@=FES;R!D:7-T
M<FEB=6-I:F]S('/@<F'P^"!SX')A\&\N`$YE<&%V>6MO(&=A=71I('9I9?!O
M:F\@<F%K=&\@:?`@<F%K=/@@<V5R=F5R:6\N`$YE<&%V>6MO(&%T:61A<GET
M:2`E<RX`3F5P879Y:V\@871I9&%R>71I($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QI;R`E<P!.97!A=GEK;R!S:V%I='ET:2`E<RX`3F5P879Y:V\@<&%K96ES
M=&D@<VQA<'1A_F]D_FEO(/!I86T@=F%R=&]T;VIU:2X@2V%I(&MU<FD@87)B
M82!V:7-A(&EN9F]R;6%C:6IA('ER82!N971I:W-L:2X@4&%B86YD>6MI=&4@
M9&%R(&MA<G3@(&%R8F$@<W5S:7-I96MI=&4@<W4@<V%V;R!A9&UI;FES=')A
M=&]R:75M:2!J96EG=2!R96EK86QI;F=A('!A9V%L8F$N`$YE<&%V>6MO(&=A
M=71I($%#3`!.97!A=GEK;R!G875T:2!A9')E<_@@:VYY9V5LZW,N("5S`$YE
M<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<P!.97!A=GEK
M;R!G875T:2!D:7-T<FEB=6-I:F]S('/@<F'P^"X@)7,`3F5P879Y:V\@;G5S
M=&%T>71I('-E<G9E<FEO(&=A;&EM>6)I^`!.97!A=GEK;R!A=&ME:7-T:2!N
M=7-T871Y;?@N`$YE<&%V>6MO(&GP<V%U9V]T:2`E<R!N=7-T871Y;?@N`$YE
M<&%V>6MO('!A9&%R>71I(&%T<V%R9VENZW,@;G5S=&%T>6WX(&MO<&EJ;W,N
M`$YE<&%V>6MO('!A:67P:V$@3$1!4"!S97)V97)Y:F4N`$YE<&%V>6MO(&%T
M;F%U:FEN=&D@:V]N=&%K=&\N("5S`$YE<&%V>6MO(&%T;F%U:FEN=&D@9&ES
M=')I8G5C:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO(')A<W1I($UO>FEL;W,@
MX7)A;FMI^"!J=6]S=&]S+B#!<VET:6MI;FMI=&4L(&MA9"!J:2!A=&ED87)Y
M=&$N`%)I8F]T87,@=&5K<W1A<P!686QS='EBZP!+=7)S86D`4W5K=7)T:0!3
M=6MU<G1I(&YU;W)O9.``4W5K=7)T:2!N875JX"!A<')A\.``4W5K=7)T:2!P
M86MA=&%L;V=I=7,`4W5K=7)T80!3879I;FEN:V\@=&5I<^MS`$MR961I=&EN
MZW,@:V]R=&5LZW,@;G5M97)I<P!+<F]A=&EJ80!+=6)A`$1A8F%R=&EN:7,@
M;&%I:V%S`-!I=6\@;65T=2!54DP@>7)A`$1A8F%R=&ENZW,@;W)O('/@;'EG
M;W,`1&%B87)T:6[K<R!SX&QY9V]S.B``1&%B87)T:6YI<R!S=&EL:75S`%9E
M:6MS;?@L(&%T;&EE:V%M^"!P<FES:6IU;F=U<R!P<FEE("5S+"!N=7-T871Y
M;6%S+@!097)K96QT:0!097)K96QT:2!P87-I<FEN:VEMX`!+:7!R87,`2VER
M:6QI8V$@*$M/23@M4BD`2VER:6QI8V$@*%=I;F1O=W,M,3(U,2D`2VER:6QI
M8V$O56MR86EN:65T:?!K82`H2T])."U5*0#(96MI:F]S(%)E<W!U8FQI:V$`
M1$0`2V%S9&EE;@!$=6]M96[X(&UE9/YI;R!N87+P>6MLZP!$871A`$=A=71A
M`$1A=&]S('!A<VER:6YK:6UA<P!$:65N80!)\'1R:6YT:2!?<W1U;'!E;.$`
M1W)U;V1I<P!$9?!I;71A:6YI86D@<VMA:>AI86D`4W5M8?YI;G1I(&%T:71R
M875K:6W@`%-T86YD87)T:6[K('-P86QV80!3=&%N9&%R=&EN:7,@87!R8?!A
M<P!2^_!I=6]T:2!P86=A;#H`4OOP:75O=&DZ`$%P:6)RZ_YI;6%I`$GP=')I
M;G1I`$GP=')I;G1I(&=R=7#F`$GP=')I;G1I('1E:7/F`%9I<VGP:V%I(&GP
M=')I;G1I(&QA:?!K=7,`2?!T<FEN=&D@8V5LY@!)\'1R:6YT:2!S='5L<&5L
MX0!)\'1R:6YT:2!E9WII<W1U;VIA;G3A(&%L=&5R;F%T>7;X(/!A8FQO;N``
M2?!T<FEN=&D@96EL=73F`$GP=')I;G1I('!A<VER:6YK=.`@87!R8?#@`$GP
M=')I;G1I(/#A('-T=6QP96SA`$GP=')I;G1I(/!IX"!E:6QU=.8`4')I<W1A
M='EM;R!L86EK87,`1&%N:6IA`$UA_NMJ:6UO('1V87)K80!0<F]B;&5M;W,@
M87!R8?!Y;6%S`$%P<F'P>6UA<P!!<')A\'EM87,Z`$1E=&%L:6%U("AT86EP
M('!A="#^:?MRZVMI=&4@2&]R9&4@;&]G(&9A:6QE*3H`061M:6YI<W1R871O
M<FEU:2!I\'-I^'-T87,@9&5T86QU<R!A<')A\'EM87,N`%9Y<W1Y;6%S`$1R
MZV=N=6UA<P!$<NMG;G5M87,@<&%S:W5T:6[F('9A;&%N9.`Z(`!$<NMG;G5M
M87,Z(`!+<GEP=&ES(&GP(&MA:7+K<R#A(&1E\&ENY@!+<GEP=&ES(&GP(&1E
M\&ENZW,@X2!K86ERY@!+871A;&]G87,`4F]D>71I(#(T+6GX('9A;"X@9F]R
M;6%TX#\`5F%I>F1A=FEM;R!N=7-T871Y;6%I`%)O9'ET:2!P<F]G<F]NYB`H
M5$%&*0!686EZ9&%V:6UO(&9O<FUA=&%S`$QA:?!K;R!P<FES=&%T>6UO('!R
M86YE\&EM86D`1/YI8G5T:7,`3F5T<FEN=&D`3F5S:6MR96EP:VET92!T:65S
M:6]G:6%I(.$@;6%I;G1E;F%N8V4N<&AP`$%R('!I<FUA<R#A<F'P87,@>7)A
M(&QA=6MO('9A<F1A:3\`1&]M:6YI:V$`1&]M:6YI:V]S(%)E<W!U8FQI:V$`
M071S:7-I^'-T:0!!='-I<VGX<W1I("5S`$%T<VES:?AS=&D@<W5G96YE<G5O
M='5S(&YU<W1A='EM=7,@:V%I<"!02%`@<VMR:7!TX"X`2?!S:7-K;&5I9/YI
M86YT:7,@<^!R8?!A<P!686ES=&%I`$5L+B!P8?!T;R!A9')E<V%S`$524@!%
M:W9A9&]R87,`4F5D86=U;W1I`$ME:7-T:2!B;&]K;R!P87)A;65T<G5S`%)E
M9&%G=6]T:2!G<G5PY@!2961A9W5O=&D@=?YR8?#@`%)E9&%G=6]T:2!T96ES
M97,`4F5D86=U;W1I('1E:7-E<P`E<R!T96ES:?@@<F5D86=A=FEM87,`2V5I
M<W1I(&YU<W1A='EM=7,Z`"5S('1E:7-I^"!R961A9V%V:6UA<P!59V1Y;6%S
M`$5G:7!T87,`4V%L=F%D;W)A<P!%;&5M96YT87,N+BX`16T`16PN('!A\'1A
M<P!%;"X@<&'P=&\@861R97-A<P!%;"X@<&'P=&\@861R97-A:2!T=7)I('-U
M=&%P=&DN`$5L+B!P8?!T;R!A9')E<V%S('-U('!A='9I<G1I;FEM=0#0>7!S
M96[K;.MS`%1U\.AI87,@=?YR8?!A<P#>:6YU=.L@='7PZ&EA+@!297IU;'1A
M=&%S('1U\.AI87,N`$YE;G5R;V3K=&4@<&%I9?!K;W,@=&5R;6EN^`!,96ES
M=&D@=&5K<W1E(.%T97)P=&D@<&%V96EK<VSK;&EU<R!I\"!.=6]T<F%U:_@@
M9V%L97)I:F]S/P#!:G5N9W1I(&1E\&EN:6]J;R!P96SK<R!M>6=T=6MO(&UE
M;FEU/P!'86QI;FEA:2!M971A:0!)\'!LZW-T:2!R961A:W1O<FGX`,%R8?!Y
M:VET92!K;&%U<VEMX"P@:W5R:7,@:G5M<R!B=7,@=?YD=6]T87,@:F5I9W4@
M<&%M:7+P:71E('-A=F\@<VQA<'1A_F]DX2P@<'9Z+CH@)VMO:W,@>7)A($K[
M<_@@9WEV^VYO('9A<F1A<S\G.@#!=F5S:VET92!P879E:6MS;.ML:6\@55),
M`$5K=F%T;W)I;NL@1W9I;NMJ80!%<FET<NMJ80!+;&%I9&$`2VQA:61A(&QA
M:?!K92X`17-T:6IA`$5T:6]P:6IA`$5T;FENZW,`175R;W!A`$MA<R`Q-2!M
M:6YUZ&GX`$MA<R`R(&UI;G5T97,`2V%S(#,P('-E:W5N9/YI^`!+87,@-2!M
M:6YU=&5S`$MI96MV:65N;R!P<FES:6IU;F=I;6\@;65T=0!+87,@<'5S=F%L
M86YDX0!+87,@;6EN=73F`%!A=GEZ9/YI=6DZ`%9Y:V1Y=&D`2?!S:VQE:7-T
M:0!296EK86QI;F=A<R`G*2<`4F5I:V%L:6YG87,@_F]D:7,@87)B82!K86)U
M=.MS92#A<F'P>71A<R!P86EE\&MO<R!K<FET97)I:G5S`$=A;&EO:FEM;R!D
M871A`$5K<W!O;F5N=.L`2?!K96QT:0!)\&ME;'1I('7^<F'P=7,`5&5K<W1O
M('-P86QV80!.=7-T871Y;?@@<VEU;G1I;6%S('!E<B!&5%`N`%9I<V%M92!?
M=&5K<W1E`$ML86ED82!N=7-K86ET86YT(&YU<W1A='EM=7,N`$YE<&%V>6MO
M('!R:7-I:G5N9W1I('!R:64@3$1!4"!S97)V97)I;RX`3F5P879Y:V\@<')I
M<VEJ=6YG=&D@<')I92!334(@<V5R=F5R:6\N`$YE<&%V>6MO(&YU:V]P:6IU
M;W1I(&GP("(E<R(N`$YE<&%V>6MO(&YU:V]P:6IU;W1I(.$@(B5S(BX`3F5P
M879Y:V\@<W5K=7)T:2!N875J;R!305-,(')Y\&EO+@!.97!A=GEK;R!P97)K
M96QT:2#A("(E<R(N`-!V96QN=7,`1F]L:VQA;F3X('-A;&]S("A-86QV:6YA
M:2D`1F%R97+X('-A;&]S`$9A:W-A<P!687-A<FES`$%T<F]D;R!L>6<`071R
M;V1O(&QY9SH@`%1R=6UP86QA:6MI<R!L:65T=7,`1FED_FES`$9A:6SX('-K
M86GH:75S.B`E<R!F86EL87,`1F%I;/@@<VMA:>AI=7,Z("5S(&9A:6QA:2CX
M*0!&86EL^"!T=F%R:WEM87,`1F%I;&\@<&%V861I;FEM87,`1F%I;&\@<&%S
M:7)I;FMI;6%S`$9A:6QO('-I=6YT:6UA<P!.87+P>6MLZR!N97!A;&%I:V\@
M9F%I;/@@<VEU;G1I;6\N`$9I;'1R86D`4W5O;6EJ80!0:7)M;VII('!U<^L`
M4&ER;6%S:7,@:V5T=FER=&ES`$YU<W1A='ET87,@:V]E9FEC:65N=&%S`$%T
M=FER:_#H:6%S`$GP9.MS='EM87,`4OMK87,`2V%T86QO9V%S("5S(&YE96=Z
M:7-T=6]J80!496MS=&\@<W!A;'9A`$UA:7-T87,`3F%R\'EK;.MM<RP@:W5R
M:6]S(&YE<&%L86EK;R!P879E:6MS;.ML:?@`3W+X('!R;V=N;WKK("A4048I
M`$]R^"!P<F]G;F]ZZW,@87!I;71I<R`HX7-I9.MMZVMI=&4L(&MA9"#P:2!F
M=6YK8VEJ82!G<F'^:6YA(&ER(&1I96YO<R!I<B!N86MT:65S('!R;V=N;WKF
M.R!P97(@9&ED96QI<R!S:V%IZ&EU<R!G86QI('-U9&%R:WET:2!D:7IA:6[@
M*0!086UI<O!O=&4@<V%V;R!S;&%P=&'^;V3A/P!&;W)M;W,`1G)A>NL`1G)A
M>FGX('1I<&%S`$9R87KK<P!&<F%ZZW,@,@!$:7-K=7-I:F]S`%!E<G-I=6YT
M:6UA:0!096YK+@!+<F'P=&ENZW,`4')A;F/[>FEJ80!0<F%N8_MZ:6IA+"!-
M971R;W!O;&ES`%!R86YC^WII:F]S($=V:6%N80!0<F%N8_MZ:6IO<R!0;VQI
M;F5Z:6IA`%!R86YC^WII:F]S('!I971I;NMS('1E<FET;W)I:F]S`$YU;P!.
M=6\@`%!I;&YA<R!A<')A\'EM87,`4&EL;F%T:7,`4&EL;F%S('9A<F1A<P!'
M86)O;F%S`$=A;&5R:6IA(&GP(&MU<FEO<R!I\"!K=7)I;W,@8G5S(')O9&]M
M87,@<&%V96EK<VSK;&ES`$=A;&5R:6IA.@!'86UB:6IA`$=E;F5R=6]T:2`E
M<R!N=7-T871Y;75S`%-U9V5N97)U;W1A<R!K;V1A<P!'<G5Z:6IA`%9O:VEE
M=&EJ80!'86YA`$=I8G)A;'1A<F%S`%9A<F1A<P!2;V1Y=&D`1V%D96QI<P!'
M;V]G;&4@<&%I9?!K80!.97-P86QV;W1A<P!'<F%I:VEJ80!'<F%I:VGP:V$@
M*$E33RTX.#4Y+3<I`$=R96YL86YD:6IA`$=R96YA9&$`1W)U<&GX(&%D;6EN
M:7-T<F%V:6UA<P!'<G5PZW,@=F%R9&%S('1U<FD@8OMT:2!N971U\.AI87,`
M1W)U<.MS`$=V861E;'5PZP!'=6%M80!'=F%T96UA;&$`1V5R;G-I<P!3=F7H
M:?@@=&5I<^MS`%-V9>AI^"!K;GEG80!'=FENZVIA`$)I<W-A=2U'=FENZVIA
M`$=A:F%N80!(5$U,`$A434Q!<F5A(&YE9V%L:2!I\'1R:6YT:2!P87-K=71I
M;NMS(&-E;.MS(&5I;'5TZVIE+@!(5$U,07)E82!N96=A;&D@:?!R:6YT:2!P
M87-K=71I;FEO('-T=6QP96QI;R!L96YT96SK:F4N`$A434Q!<F5A(&YE9V%L
M:2!I\'1R:6YT:2!P87-K=71I;NMS(&5I;'5TZW,@;&5N=&5LZVIE+@!296EK
M86QI;F=A($A45%`@875T96YT:69I:V%C:6IA+@!(86ET:7,`2&%S:"U!;&=O
M<FET;6%S`$UI9VQA`$%N=')A\'3K`$AE<F1O('-A;&$@:7(@36%K9&]N86QD
M;R!S86QO<P!(96)R86KX("A)4T\M.#@U.2TX+4DI`$%U:_!T:7,`4&%G86QB
M80!2961A:W1O<FEA=7,@;F%U9&]J:6UO<VD@<&%G86QB80!086=A;&)I;FEN
M:V%S`$AE;6ES9F5R80#0=&%I(.AI82!Y<F$@9F%I;&\@<')A9/YI83H`4W9A
M<F)U`%]0;W)T86QA<P#0=F5N=&%S:7,@4V]S=&%S("A6871I:V%N;R!V86QS
M=&EJ82D`4&]R=&%L87,`3F%M^"!A9')E<V%S`$YA;?@@=&5L969O;F%S`$AO
M;F3[<F%S`$AO;FMO;F=A<P!0;W)T86QA<P!(;W)D92]+;VQA8CH@;F5T96ES
M:6YG:2`E<R!834P@9'5O;65N>7,@_FEN=73K:F4@)7,`2&]R9&4O2V]L86(Z
M(&]B:F5K=&\@)7,@;F5A=&ET:6YK82!J;VMI82#^:6YU=.L`2&]R9&4O2V]L
M86(Z(&]B:F5K=&\@=&EP87,@)7,@;F5R87-T87,@_FEN=73K:F4@)7,`2&]R
M9&4O2V]L86(Z("5S("(E<R(@<^MK;6EN86D@:?!T<FEN=&$`2&]R9&4O2V]L
M86(Z(&EN=&5G<F%C:6IO<R!V87)I:VQI=6MU:2!R96EK86QI;F=A<R`G9&]M
M>&UL)R!02%`@;6]D=6QI<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@<W5K=7)T
M:2!N875J;R!834P@;65D_FEO(&]B:F5K='5I("5S`$AO<F1E+TMO;&%B.B!N
M97!A=GEK;R!I\'1R:6YT:2`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P
M879Y:V\@9V%U=&D@34E-12!)1"!D86QI86D@)7,@=&EP;P!(;W)D92]+;VQA
M8CH@;F5P879Y:V\@<W5S:6YC:')O;FEZ=6]T:2`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@;F5P879Y:V\@<W5S:6YC:')O;FEZ=6]T:2!E;&5M96YT^#H@
M)7,`2&]R9&4O2V]L86(Z(&YE_FEN;VUA<R!E;&5M96YT87,@(B5S(@!(;W)I
M>F]N=&%L:2!L:6YI:F$`2&]R:7IO;G1A;'5S('1A<G!A<P!(;W)I>F]N=&%L
M:6%I.@!+86EP(.AI82!P871E:V]T93\@*%!R86YE\&MI=&4A*0!+:65K('-T
M=6QP96QI^"!N;W)I=&4@<W5J=6YG=&D_`$MI96L@;&%U:_@@*'-T=6QP96QI
M^"D@=&5N('ER83\`2VEE:R!E:6QUZ&GX(&YO<FET92!S=6IU;F=T:3\`1'+K
M9VYU;6%S`$1RZV=N=6UA<SH@`$IU;6]R97-K;W,`5F5N9W)I:F$`3F5P879Y
M:V\@<W5K=7)T:2!)34%0('!A\'1O(&3K_G5TZW,Z("5S`$YE<&%V>6MO(&GP
M=')I;G1I($E-05`@<&'P=&\@9.O^=73K<SH@)7,`3F5P879Y:V\@;G5S=&%T
M>71I($E-05`@<&'P=&\@9.O^=73K<R!D>63^:6\Z("5S`$E0(&%D<F5S87,`
M3F5P879Y:V\@9V%U=&D@25`@861R97-O+@!)4"!A9')E<V%S(&YE=&5I<VEN
M9V%M92!#2412(&)L;VME+@!)4"!U_G)A:VEN=&%S+@!?P71E<G!T:2!E:6QU
M=.8@=FER\'5J90!)<VQA;F1I:F$`5&EK('!I:W1O9W)A;6]S`%!I:W1O9W)A
M;6]S('-U('1E:W-T=0!!<')A\&\@<&%V861I;FEM87,Z`$IE:2!N96=A;&ET
M92!P97)S:V%I='ET:2#P:6\@;&%I\&MO+"`E<RX`2F5I9W4@;6%T;W1E(/!I
MX"#^:6YU=.8@=FEE=&]J('!A=F5I:W-LZVQI;RP@:W5RX2!N;W)I=&4@X6ME
M;'1I+"!T86D@2OMS^"!N87+P>6MLZR!N96=A;&D@:F\@871V86EZ9'5O=&DN
M`%!A=F5I:W-LZVQI;R!P97+^:?MR80!0879E:6MS;.ML:6\@55),`%!A=F5I
M:W-LZVQI;R!54DPZ`%!A=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,`4&%V96EK
M<VSK;&ES(&GP(&=A;&5R:6IO<SH`4&%V96EK<VSK;&EO(.%KZVQI;6%S`%9A
M:7ID86D`5?YR8?#X(.%KZVQI;6%S+"`E9"UA<R#^:6YG<VYI<P#!:^ML:6UA
M<RP@)60@_FEN9W-N:7,`P6ME;'1I+TGP:V5L=&D@=?YR8?!U<P!,875K87,@
MX6ME;'1A<SH@)7,`P6ME;'1I(&QA=6MA:3H`P5]T97)P=&D@96EL=73F(&%P
M8>AI;VIE`$YE=&5I<VEN9V%S('9E:6MS;6\@:V]D87,N`$YE=&5I<VEN9V%S
M('9A<G1O=&]J;R!V87)D87,@:7(O87)B82!S;&%P=&'^;V1I<RX`3F5I=&5I
M<VEN9V%S('9A<G1O=&]J;R!V87)D87,@87)B82!A;'1E<FYA='EV=7,@96PN
M('!A\'1O(&%D<F5S87,N($)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S=7-I
M<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA
M;&EN9V$@=&]L97-NZR!P86=A;&)A+@!0861I9&EN=&D@871I=')A=6MI;>``
M26YD:6IA`$EN9&EV:61U86S[<R!V87)T;W1O:F%I`$EN9&]N97II:F$`26YF
M;W)M86-I:F$`26YF;W)M86-I:F$`P71R875K=&D@<W1U;'!E;.$@7V1E\&EN
MZVIE`,%T97)P=&D@<&%V96EK<VSK;.$`P71E<G!T:2!L96YT96SF`,%T97)P
M=&D@;G5O<F]DX`#!=&5R<'1I('-T=6QP96SA(%]K86ERZVIE`,%T97)P=&D@
M;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&1E\&ENZVIE`,%T97)P
M=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&MA:7+K:F4`P71E
M<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@87!AZ&EO:F4`P71E
M<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@=FER\'5J90#!=&5R
M<'1I('!A<F%G<F%FX"!E;&5M96YT;R!A<&'H:6]J90#!=&5R<'1I('!A<F%G
M<F%GX"!E;&5M96YT;R!V:7+P=6IE`,%T97)P=&D@86QT97)N871Y=O@@\&%B
M;&]NX`#!<F'P>6MI=&4@96PN('!A\'1O(&%D<F5SX"P@X2!K=7+A(&YO<FET
M92!G875T:2!N875JX"!S;&%P=&'^;V3A.@#!=&5R<'1I(&-E;.8@<&\@=&\`
MP71E<G!T:2!C96SF('!R:67P('1A:0#!=&5R<'1I('-T=6QP96SA(&1E\&EN
MZVIE`,%T97)P=&D@<W1U;'!E;.$@:V%I<NMJ90#!=&5R<'1I(&QA:?!K=7,`
MP71E<G!T:2!P87)A9W)A9N`@<&\@=&\`P71E<G!T:2!P87)A9W)A9N`@<')I
M9?`@=&%I`,%T97)P=&D@96EL=73F('!O('1O`,%T97)P=&D@96EL=73F('!R
M:67P('1A:0#!<F'P>6MI=&4@<F5I:VEA;>`@871S86MY;>`@X2!K;&%U<VEM
MX"!V:7+P=6IE.@#!=&5R<'1I+W)E9&%G=6]T:2!P879E:6MS;.MLX0#!=&5R
M<'1I+U)E9&%G=6]T:2!N=6]R;V3@`$1I<W1R:6)U8VEJ;W,@<^!R8?!U:2!N
M=7-I^'-T:2!N977^=&5N:V$@:W)E9&ET;RX`3F5U_G1E;FMA(&MR961I=&\N
M`%-K86GH:75S`%-K86GH:?@@<^!R8?!A<P!.971E:7-I;F=A<R!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2X`3F5T96ES:6YG87,@;6]D=6QI<RX`3F5T96ES
M:6YG87,@240N`,%V97-T:2!N971E:7-I;F=I(&1U;VUE;GES+@!.971E:7-I
M;F=A<R!A9')E<V%S+@!.971E:7-I;F=A<R!F86EL;R!F;W)M871A<P!.971E
M:7-I;F=A<R!M<V=?='EP92X`3F5T96ES:6YG87,@87)B82!NZW)A(&%P:5]I
M9"X`4&%R86UE=')A:2!N971E:7-I;F=I(&%R8F$@:O@@;NMR82X`3F5T96ES
M:6YG;W,@<&%V96QD:6UO<R!T96ESZW,N`$YE=&5I<VEN9V%S('!R;W1O:V]L
M87,N`$YE=&5I<VEN9V%S(&]B:F5K=&%S`$YE=&5I<VEN9V%S('-I=6YTZVIO
M(&%D<F5S87,N`$YE=&5I<VEN9VD@=6YI:V]D;R!D=6]M96YY<RX`26YV96YT
M;W)I=7,`27-L86UI\&MA($ER86YO(%)E<W!U8FQI:V$`27)A:V%S`$%I<FEJ
M80!-96YO('-A;&$`27IO;&EU;W1O<R!4+6%U9')O<P!)>G)A96QI<P!)\&1A
M=NMJ87,`2W5R<WEV87,`271A;&EJ80!*86UA:6MA`%-A=7-I<P!*87!O;FEJ
M80!*87!O;FGP:V$@*$E33RTR,#(R+4I0*0!$_F5R<VES`$IO<F1A;FEJ80!,
M:65P80!":7+^96QI<P!0:6QN86D`3'EG:75O=&D@8V5N=')E`$QY9W5O=&D@
M<&EL;F%I`$QY9VEU;W1I(&MA:7+K:F4`3'EG:75O=&D@9&7P:6[K:F4`2V%Z
M86MS=&%N87,`2?!S875G;W1I(&]R:6=I;F%LX#\`2V5N:6IA`$YE<&%V>6MO
M('!R:7-I:G5N9W1I('!R:64@2V5R8F5R;W,@<V5R=F5R:6\N`$)R86YD=6]L
M:6\@;F%U:F]K86D`4F%K=&\@:_MR:6UA<P!286MT;R!A='-P875D87,`4F%K
M=&\@:6QG:7,`4F%K=&\@=&EP87,`4F%K=&\@<&%N875D;VII;6%S`%)A:W1A
M<R!J874@>7)A('9I9?#X:O@@<F%K=/@@<V5R=F5R>6IE+@!686EK86D`2VER
M:6)A=&ES`$1E;6]K<F%T:6[K($MO<NMJ;W,@3&EA=61I97,@4F5S<'5B;&EK
M80!+;W+K:F]S(%)E<W!U8FQI:V$`2V]RZVII971I\&MA("A%54,M2U(I`$MU
M=F5I=&%S`$MI<F=I>FEJ80!?2?!DZW-T>6UA<P!+86QB80!,86]S;R!$96UO
M:W)A=&ENZR!,:6%U9&EE<R!297-P=6)L:6MA`$%N=')A('!U<^L`4&%S:W5T
M:6[A(&MA<G3@(')E9&%G=6]T80!087-K=71I;FES(&ME='9I<G1I<P!!=&YA
M=6II;G1A.@!087-K=71I;FES('!R:7-I:G5N9VEM87,Z("5S`%!A<VMU=&EN
M:7,@<')I<VEJ=6YG:6UA<SH@)7,@:?`@861R97-O("5S`%!R:7-I:G5N9^MT
M92!P:7)MX"!K87)TX`!,871V:6IA`%1E:7/K`$GP9.MS='EM87,`2F5I9W4@
M;F5N;W)I=&4@;F5N875D;W1I(&MR8?!T^"P@<&%L:6MI=&4@='7PZ&G@`$QI
M8F%N87,`2V%I<NMJ90!+86ER:6]J:2!A;G1R8?!TZP!+86ER:6]S:6]S(')E
M:6OP;>MS`$QE<V]T87,`3&EB97)I:F$`3&EB:6IO<R!!<F%B^"!%;7ER871A
M:0!,:6-H=&5N\'1E:6YA<P!3;75L:W5S(&QI971U<P!.961I9&5L:7,@;&EE
M='5S`$YE9&ED96QI<R!L:65T=7,@<GET90!.961I9&5L:7,@;&EE='5S('9A
M:V%R90!.961I9&5LZR!L:?MT:7,`3F5D:61E;&ES(&QI971U<R!S=2!P97)K
M^VYI:F$`3F5D:61E;&ES('-N:65G87,`3F5D:61E;.L@\&QA<&1R:6)A`$QI
M;65R:6MA<P!.=6]R;V1A`$YU;W)O9&$@X3H`4&%D87)Y=&D@96PN('!A\'1O
M(&%D<F5SX"!N=6]R;V1A(.$@;&%I\&MO(')A\'EM;R!P=7-L87#A`$YU;W)O
M9&]S`$QI;G5X(&QA:6WK<R#^:6YU=.MS`%)O9'ET:2`M('9A<G1O=&]J87,@
M9V%L:2!M871Y=&D@:V%T86QO9V\@='5R:6[A`%)O9'ET:2!D=6]M96[X(&)A
M>FGX('/@<F'PX`!2;V1Y=&D@<&%G86QB;W,@=&5M87,`4F]D>71I(&QE;G1E
M;&GX('/@<F'PX`!+;VYF97)E;F-I:F]S(&%R8VAY=F%S`$MO;F9E<F5N8VEJ
M;W,@<&%G86QB80!+;VYF97)E;F-I:F]S($E$`$MO;F9E<F5N8VEJ;W,@<V%V
M:6YI;FMA<P!28?!Y=&D@X2!K;VYF97)E;F-I:N``4')I<VEJ=6YG=&D@<')I
M92!K;VYF97)E;F-I:F]S`$%T<VEJ=6YG=&D@;G5O(&MO;F9E<F5N8VEJ;W,`
M5F%R=&]T;VKX('/@<F'P87,@=?YD<F%U<W1A<RX`3&ET97)A=/MR80!,:65T
M=79A`$MR875N82XN+@!6:65T:6YI<R!L86EK87,Z(`!,;VMA;.L@:7(@;&%I
M:V%S`%9I971A`%!R:7-I:G5N9W1I`$%T<VEJ=6YG=&D`4')I<VEJ=6YG:6UO
M(&1A<F)A:0!0<FES:6IU;F=T:2!N97!A=GEK;RX@3F5T96ES:6YG87,@2OMS
M^"!N=7)O9'ET87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<B!S;&%P=&'^;V1I
M<RX`4')I<VEJ=6YG=&D@;F5P879Y:V\N`$EL9V%S('1E:W-T87,`365I;.L`
M3F5S=F%R8G4`36'^;W-I;W,@9W)A:6MI\&MO<R!R86EDZW,`36'^;W-I;W,@
M;&]T>6YI\&MO<R!R86EDZW,`36'^:65J:2!R;VWK;FGP:VD@<VMA:>AI86D`
M3&EU:W-E;6)U<F=A<P!-30!-3U1$`%!R:6MA8FEN=&%M92!-4RU43D5&(&9A
M:6QE(&[K<F$@9'5O;>MN^"X`35-'`$UA:V%O`$UA:V5D;VYI:F$`36%D86=A
M<VMA<F%S`$UA9VEJ80!08?!T87,`4&'P=&\@=F%L9'EM87,`4W5K=7)T:2!?
M;G5O<F]DX"XN+@!-86QA=FES`$UA;&%I>FEJ80!-86QD>79A:0!-86QI<P!-
M86QT80!+871E9V]R:6KX('/@<F'P;RP@:W5R:6]M<R!P<FES:VER:6%M:2!O
M8FIE:W1A:2P@:7(@<W4@:F]M:7,@<W5S:6IU<VGX('-P86QV^"!K96ET:6UA
M<RX`36%P,C0@_F5MZVQA<&ES`$UA<%%U97-T(/YE;>ML87!I<P!+;W9A<P!0
M87)A\'3K`%!A_GEMZW1I(&MA:7`@<VMA:71Y='5S+VYE<VMA:71Y='5S`%!A
M_GEMZW1I(&MI=&%I<R!A=')I8G5T86ES("AP=GHN('-V87)B=2]A='-A:WET
M82D`36%R\&%L;R!S86QO<P!-87)T:6YI:V$`4W5J=6YG=&D@;&%U:V%I`$UA
M=7)I=&%N:6IA`$UA=7)I8VEJ=7,`36%K<VEM86QU<R!K<F5D:71A<RX`36%K
M<VEM86QU<R#^:6YUZ&GX(&1A;&GX(&MI96MI<R!I\&5I:W9O=&%S+@!-86MS
M+B!T96UP+B!P87-K+B`R-"!V86PZ(`!-86MS+B!T96UP+B!P87-K+B`V('9A
M;#H@`$UA:W-I;6%L=7,@:6QG:7,`1V5G=?[K`$UO:F]TZP!-961I8VEN80!.
M87)I86D`5?YR8?!O('1E:W-T87,`365N:74@<F7^:6UA<SH`4W5J=6YG=&D@
M8V5L97,`WFEN=73K`$QA:?!K87,@<&%V:7)T:6YT87,L('1AZ&EA=2!N97!A
M='9I<G1I;G1A<R!P87-I<F'P:75S:6\@87-M96YS('-E<G1I9FEK871A<RX`
MWFEN=73K(&YE:?!S:?AS=&$N`-YI;G5TZW,@=&EP87,`3W)O('-A;'EG;W,`
M3W)O('/@;'EG^"!B;&]K;R!NZW)A+@!/<F\@<^!L>6?X(&)L;VMO(&[K<F$N
M($%D;6EN:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L=7,@87!R8?!Y;6%S
M+@!-971O9&%S`$UA=&%I`$UE:W-I:V$`36EK<F]N97II:F]S($9E9&5R86-I
M;NMS(%9A;'-T:6IO<P!6:61U<GEJ90!-24U%('1I<&%S`$UI;BX@=&5M<"X@
M<&%S:RX@,C0@=F%L.B``36EN+B!T96UP+B!P87-K+B`V(&AO=7)S.B``071S
M<&EN9'ES`$MI=&]S`$YE<F%S=&%S(%!%05(@2%144%]297%U97-T('!A:V5T
M87,N`$YU<W1A='EM^"!NZW)A+B!*96EG=2!N;W)I=&4@;F%U9&]T:2#PX2!M
M;V1U;.$L('1U<FET92!JX2!S=6MO;F9I9_MR=6]T:2X`3NMR82#^:6YU=.MS
M($E$+@!.97)A<W1A<R!R96EK86QI;F=A<R!014%2($UA:6P@<&%K971A<RX`
M3NMR82!S97-I:F]S($E$+@!0:7)M+@!-;V)I;'5S('!A\'1A<P!6:61U=&EN
M:7,`4F5D86=A=FEM;R!D871A`$ME:7-T:2!54DP`4F5D86=U;VIA;6%S("5S
M`$UO9'5L:7,`36]L9&]V;W,@4F5S<'5B;&EK80!-;VYA:V%S`$UO;F=O;&EJ
M80!-ZVYE<VEA:2!I<B!M971A:0!+87,@;>MN97/A`$UO;G-E<F%T87,`3>MN
M=6QI;R!F87KK<P!-87)O:V%S`$1A=6=I875S:6$@9VEE9')A`$1A=6=I875S
M:6$@87!S:6YA=6OF`$1A=6=I875S:6$@<V%U;.MT80!097)K96QT:2#^96UI
M874`4&5R:V5L=&D@:V%I<FEA=0!097)K96QT:2!D9?!I;FEA=0!097)K96QT
M:2!A=6OPZ&EA=0!097)KZVQI;6%S(/YE;7EN`%!E<FOK;&EM87,@875K\'1Y
M;@!-;WIA;6)I:V%S`$ME;&5T;R!L>6=I^"!I\'-I<VML96ED_FEA;G1I<R!S
MX')A\&%S`$ME;&5T87,@<&%S:7)I;FMI;?@`36%N;R!SX'-K86ET80!-86YO
M('7^<F'P86D`36%N;R!P;W)T86QA<P!-86YO('!O<G1A;&\@:?!DZW-T>6UA
M<P!-86EN;6%R87,`3D4L($Y%4U5424Y+50!687)D87,`3F%M:6)I:F$`3F%U
M<F%S`$YE<&%L87,`3GED97)L86YD86D`3GED97)L86YD^"!!;G1I;&%I`$YE
M='-C<&%P92!B87II;FES(%523`!.971S8W!A92!S97)I9FEK871O(&%T\&%U
M:VEM;R!54DP`3F5T<V-P864@<V5R=&EF:6MA=&\@=&5I<VGX(%523`!.971S
M8V%P92!A=&YA=6II;F]M;R!54DP`3F5T<V-A<&4@873P875K:6UO(%523`!.
M971S8V%P92!34TP@<V5R=F5R:6\@=F%R9&%S`$YE='-C87!E('-E<G1I9FEK
M871O(&%P<F'P>6UA<P!.971S8V%P92!S97)T:69I:V%T;R!T:7!A<P!4:6YK
M;&%S`$YI96MA9&$`3F%U:F]J:2!+86QE9&]N:6IA`$YA=6IA(&MA=&5G;W)I
M:F$`3F%U:F%S(&WK;G5L:7,`3F%U:F%S('7^<F'P87,`3F%U:F%S('9A<G1O
M=&]J;R!V87)D87,@*&YE8OMT:6YA<RD`3F%U:F]J:2!:96QA;F1I:F$`3F%U
M:F%M92!L86YG92`H7V)L86YK*0!.875J:65N;W,`3F%U:FEE;O@@9W)U<.MS
M`%-E:V%N=&ES`%-E:V%N='ES(&YU<W1A='EM86D`3FEK87)A9W9A`$YI9V5R
M:7,`3FEG97)I:F$`3F%K=&ES`$YI=6KK`$YE`$YE=?YT96YK82!D=6]M96[X
M('-K:7)T=6WX('!A<F]D>6UU:2X`3F5N=7)O9'ET82!S=')A=&5G:6IA($E3
M3R!R8?!Y;75I+@!.ZW)A('-U9.MT:6YI;R#P86)L;VYO+@!.=7)O9'ET;VIE
M('!O>FEC:6IO:F4@8FQO:V\@;NMR80!.9>%V963K=&4@:V%L96YD;W)I875S
M('9A<F1O($U#04P@875T96YT:69I:V%C:6IO:F4N`%-K:7)T=6WX(&[K<F$N
M`-!I;W,@=&5I<^MS(&YE9V%L:2!T=7+K=&D@<&]T96ES:?@N`$[K<F$@:6YF
M;W)M86-I:F]S(&%P:64@)7,@:V]N9FEG^W)A8VEJX"X`3NMR82!I;F9O<FUA
M8VEJ;W,@87!I92!&5%`@5D93(&MO;F9I9_MR86-I:N`N`$[K<F$@:6YF;W)M
M86-I:F]S(&%P:64@4U%,(%9&4R!K;VYF:6?[<F%C:6K@+@!.ZW)A(&EN9F]R
M;6%C:6IO<R!A<&EE(%-13"U&:6QE(%9&4R!K;VYF:6?[<F%C:6K@+@!+<F5D
M:71A<R!I\&5I:W9O=&%S+@!.9>%V97-T87,@9V%VZVIA<RX`1F%I;&%S(&YE
M;G5S:?AS=&%S`$YE;G5S=&%T>71A('9I971O=NLN`$YEX7)A\.MT92#^:6YU
M=.MS+@!.9>%R8?#K=&4@=F%R9&\N`%7^<F'P^"!K;GEG96QI^"!S=F7H:6%M
M<R!NZW)A+@!5_G)A\/@@;NMR80!*;VMI92!U_G)A\&%I(&YE871I=&EN:V$@
M<&%I9?!K;W,@:W)I=&5R:6IA=7,N`%7^<F'P^"!NZW)A`$YEX7)A\.MT92!N
M=6UE<FEO+@!.97)O9'ET:2#A_F5I9/YI86[H:?@@9G)A>FGX`$YEX79E9.MT
M92!S;&%P=&'^;V3^:6\@2%144"!A=71E;G1I9FEK86-I:F%I+@!.9>%V963K
M=&4@<VQA<'1A_F]D_FEO($E-05`@875T96YT:69I:V%C:6IA:2X`3F7A=F5D
MZW1E('-L87!T8?YO9/YI;R!+97)B97)O<R!A=71E;G1I9FEK86-I:F%I+@!.
M9>%V963K=&4@<VQA<'1A_F]D_FEO($QO9VEN(&%U=&5N=&EF:6MA8VEJ86DN
M`$YEX79E9.MT92!S;&%P=&'^;V3^:6\@4$%34U=$(&%U=&5N=&EF:6MA8VEJ
M86DN`$YEX79E9.MT92!S;&%P=&'^;V3^:6\@4TU"(&%U=&5N=&EF:6MA8VEJ
M86DN`$YEX79E<W1A<R!K96QI87,@:6MI($]P96Y34TP@<&%G<FEN9&EN:?@@
M9F%I;/@N($]P96Y34TP@<F5I:V%L:6YG82!D87)B=6D@<W4@4$M#4R`Q,B!D
M=6]M96YI;6ES+@!.97!A='9I<G1I;G3X(')E9VES=')A8VEJ^"!NZW)A+@!.
M96YA=61O=&D@<VMI<G1U:_@`3NL@=FEE;F]J92!P=7/K:F4`4W!A<G1I;FEM
M=6D@;NMR82!L86EK:6YO:F\@:V%T86QO9V\N`%9A<G1O=&]J;R!V87)D87,@
M:7(O87)B82!S;&%P=&'^;V1I<R!N96YU<VGX<W1A<RX`5&5I<VEN9_@@6$U,
M(&1U;VUE;O@@;NMR80!.ZW)A(')E:6OP;6GX`$MO;F9I9_MR86-I;FEA;64@
M9F%I;&4@;NMR82!V97)S:6IO<RX@4&5R9V5N97)U;VMI=&4@;G5S=&%T>6UU
M<RX`2V]N9FEG^W)A8VEN:6%M92!F86EL92!NZW)A('9E<G-I:F]S+B!097)G
M96YE<G5O:VET92!N=7-T871Y;75S+@!5_G)?8?!A<P!.96YU<F]D>71A`$[K
M<F$`T&EA=7+K<R`H25-/+3@X-3DM,3`I`$YO<F9O;&MO('-A;&]S`-!I875R
M:6[K(&AE;6ES9F5R80#0:6%U<FENZW,@36%R:6IA;O@@<V%L;W,`3F]R=F5G
M:6IA`$YE('!O('1O`$YE('!R:67P('1A:0!.92!K871A;&]G87,`3F5R96%L
M:7IU;W1A+@!.96YU<F]D>71A`$YE<&%L86EK;VUA<RX`5?YR8?!O(&MA=&5G
M;W)I:F$`5?YR8?!O(&%P<F'P>6UA<P!5_G)A\/@@<^!R8?!A:0!5_G)A\&\@
M=&5K<W1A<P!5_G)A\&\@7W1E:W-T87,`5&]K:6\@=?YR8?!O(&[K<F$N`%7^
M<F'P^"!K;E]Y9V5LZP!5_G)A\/@@:VYY9V5LZW,@<&%V861I;FEM87,Z`%7^
M<F'P^"!K;GEG96SK<P!5_G)A\&%I`%7^<F'P^"!S86YT<G5M<&$`3NMR82!K
MX"!P97+^:?MRZW1I+"!E:6MI=&4@871G86PN`$QA<&MR:71I<P!.=6UE<FES
M`%-I;6)O;&GX('-K86GH:75S`%-T=6QP96QI^"!S:V%IZ&EU<P!%:6QUZ&GX
M('-K86GH:75S`$YEX79E<W1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O(&%T;F%U
M:FEN:6UO('-K86GH:6%I+@!/2P!/8FIE:W1A<P!/8FIE:W1O('-A=FEN:6YK
M87,`0?!T=6YT86EN:7,`4W!A;&ES`-YI875R=6UO(&9I;'1R87,`3V9I<V%S
M`$]M86YA<P!+871A;&]G^"!D86QI:FEMX'-I('!A;&%I:V\@=&EK($E-05`@
M<V5R=F5R:6%I+@!4:6L@X?YE:63^:6%NZ&EO<R!F<F%ZZW,`3&5I9/YI86UA
M<R!T:6L@=FEE;F%S(&5L+B!P8?!T;R!A9')E<V%S+@!%;&5M96YT;R!S879I
M;FEN:V\@=&5I<V5S(&=A;&D@:V5I<W1I('1I:R!J;R!S879I;FEN:V%S(&%R
M8F$@<VES=&5M;W,@861M:6YI<W1R871O<FEU<P!!=&ED87)Y=&D@;F%U:F%M
M92!L86YG90!!=&ED87)Y=&D@\&G@(&YU;W)O9.`@;F%U:F%M92!L86YG90!/
M<')A8VENZW,@<VES=&5M;W,`3G5S=&%T>6UA:0`E<R!N=7-T871Y;6%I`%-U
M<OOP:75O=&%S('/@<F'P87,`3W)G86YI>F%C:6IA`%!A9&%L:6YY<P!3:7-T
M96UI;FEM87,`3W)I9VEN86QU<R!A<&QI:V%C:6IO<R#P86)L;VYA<P!/<FEG
M:6YA;/AS(/!A8FQO;F%I("5S.@!+:71A`$MI=&$@:6YF;W)M86-I:F$`2VET
M:2!N=7-T871Y;6%I`%-A=FEN:6YI:V\@=&5I<^MS`$[K<F$@4$%-(&%U=&5N
M=&EF:6MA8VEJ;W,@;65C:&%N:7IM;RX`4$=0('-K86ET;65N:6YI<R!P87)A
M\&%S`%!'4"!U_FMO9'5O=&$@:6YF;W)M86-I:F$`4$=0('9I9?!A<VES(')A
M:W1A<P!01U`@<&%S:7)A\'ET:2]U_FMO9'5O=&D@9'5O;65N>7,`4$A0(&MO
M9&%S`%!(4"!#3$D`4$T@;&5N9W9A<R!L:65T=7,`4$T@;&G[=&ES`%!-(%0M
M875D<F$`4%](4"!#3$D`5&%R<&%I(&-E;.MS90!086MI<W1A;F%S`%!A;&%U
M`%7^:6UT;VII(%!A;&5S=&EN;W,@=&5R:71O<FEJ80!086YA;6$`4&%P=6$@
M3F%U:F]J:2!'=FENZVIA`%!A<F%G=F%J=7,`1&%L:6YA:2!D96)E<W5O=&$`
M4VQA<'1A_F]D:7,`4VQA<'1A_F]D:7,@;F5T96ES:6YG87,`4D%$2553(&%U
M=&5N=&EF:6MA8VEJ86D@<F5I:VEA('-L87!T8?YO9/YI;RX`4VQA<'1A_F]D
M:7,@<W4@<&%T=FER=&EN:6UU`%-L87!T8?YO9&ES.@!3;&%P=&'^;V1I<SH@
M`%-L87!T8?YO9/YI86D@='5R:2!S=71A<'1I+@#!:V5L=&D`P6ME;'1I(&GP
M(&QA:6MI;F]S:6]S('-A=6=Y:VQO<R`H8VQI<&)O87)D*0!+96QI87,`3F5P
M871V:7)T:6YT;W,@<F5G:7-T<F%C:6IO<SH`WFUO;NMS`%!R;V-E;G1A:0!!
M=&QI:W1I('!R;V9I;&%K=&EN:75S('9E:6MS;75S`$%R(&%T;&EK=&D@<')O
M9FEL86MT:6YI=7,@=F5I:W-M=7,@<')I<VEJ=6YG:6UO(&UE='4_`%1E:7/K
M<P!.977^=&5N:V$@=&5I<VGX`%1E:7/K<P!496ES:?@@861M:6YI<W1R879I
M;6%S`$%S;65N:6[K(&EN9F]R;6%C:6IA`%!E<G4`1WEV^VYA:0!&:6QI<&EN
M86D`5&5L969O;F%S`$YU;W1R875K;W,`4&ET:W)A;F%S`%!I:W-E;&EA:0!"
M86YA;'EBZW,`2?!S:7)I;FMI=&4@:W5R:>`@;F]R<R!C96SF`%!A='9I<G1I
M;FMI=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\.$@96QE;65N=.`Z
M`%!A='9I<G1I;FMI=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\&EO
M(&5L96UE;G1O(&YU;W)O9.`N`,%V97-K:71E(&WK;F5SX2!I<B!M971U<RX`
MP79E<VMI=&4@;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z`,%V97-K
M:71E('1E:7-I;F?@($E0(&%D<F5SX"X`P79E<VMI=&4@=&5I<VEN9^`@9&%T
MX"P@<&%T:6MR:6YK:71E(&1I96[X('-K86GH:?@@;>MN97-Y:F4N`,%V97-K
M:71E('1E:7-I;F?@(&QA:6O@+@!!<')A\'EK:71E('!R;V)L96W@+@!.=7)O
M9'EK:71E('-A=F\@=F%R=&]T;VIO('9A<F3@(&)E:2!S;&%P=&'^;V3A`,%V
M97-K:71E(&YA=6K@(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z`$QE;FMI:F$`
M4&]L:71I:V%I`$)A;'-A=FEM86D`4&]R='5G86QI:F$`4&%V96EK<VSK;&EO
M('!O>FEC:6IA`$QE;G1E;.MS('!O>FEC:6IA`$GP<V%U9V]T:2#P:6%M92!K
M871A;&]G92`H;F5G86QI;VIA($E-05`I`$MR:71U;&EA:2!P87-K+B`E<R!V
M86QA;F3@*&%S*3H@`%!R969S7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S
M($Q$05`@;6]D=6QI<RX`4')E9G-?<V5S<VEO;CH@;F5R87-T87,@<F5I:V%L
M:6YG87,@<V5S:6KX(&UO9'5L:7,N`%-LZV=I<P!3;.MG:7,@:OMR;W,@;'EG
M>6IE.B``4VSK9VES.B``4&5R_FG[<F$`4&5R_FG[<NMT:2!P879E:6MS;.ML
MX2!N875J86UE(&QA;F=E`$%N:W-T97-N:2!N=7-T871Y;6%I`$%T<W!A=7-D
M:6YT:2!D;VMU;65N=.``4VQA<'1A<VES(')A:W1A<P!0<F]B;&5M80!0<F]B
M;&5M;W,@87!R8?!Y;6%S`%!R;VIE:W1A:0!0<F'P>6UA<R!T96MS='5I`%9I
M9?!A<VES(')A:W1A<P!6:67P;VIO(')A:W1O(&%L9V]R:71M87,`5FEE\&]J
M;R]S;&%P=&]J;R!R86MT^"!P;W)A(&YE<W5G96YE<G5O=&$N`%!U97)T;R!2
M:6MA<P!+871A<F%S`%-A:VEN>7,`4E-!('9I9?!A<VES(')A:W1A<R`H)60@
M8FET86DI`"=2861I;R<@<&%S:7)I;FMI;6%S`$QI971U<P!,:65T=7,@<GET
M90!,:65T=7,@=F%K87)E`$QI^W1I<P!!='-I=&EK=&ENZR!F<F%ZZP!386YT
M>6MI<P!3:V%I='ET:0!097)S:V%I='ET:2!L86GP:V%I`%1I:W)A:2!I\'1R
M:6YT:2`E<S\@1W)A_FEN=&D@871G86P@;F5B96=A;.MS:71E+@!4:6MR86D@
M:?!T<FEN=&D@=F%R=&]T;VIO("5S(&1U;VUE;FES/R!'<F'^:6YT:2!A=&=A
M;"!N96)E9V%LZW-I=&4N`%!A:V%R=&]T:2!A;FMS=&5S;N$@=F5I:W-MX`!!
M=&YA=6II;G1I(&MA:7)I;VIO(&UE;FEU(&5L96UE;G1U<SH`071N875J:6YT
M:2!SX')A\.``071N875J:6YT:2!P;W)T86QO('9A:7IDX#H`4F5G97@`4^!R
M>?!I^"!N87+P>6MLZP!087-T86)O<P!.=71O;.8@<V5R=F5R:6%I`$YU=&]L
MYG,@55),("AH='1P.B\O=W=W+G!A=GEZ9'ES+F-O;2]H;W)D92DZ`$GP=')I
M;G1I`%!A\&%L:6YT:2!B;&]KX`!)\'1R:6YT:2!K871E9V]R:6K@`%!A;F%I
M:VEN=&D@<W1U;'!E;.$`4&%N86EK:6YT:2!F;W)M871A=FEMX`!)\'1R:6YT
M:2!P;W+@`$GP=')I;G1I(&%T;F%U:FEN:6UO('-K<FEP=.`@:?`@<V5R=F5R
M:6\@;&%I:VEN;VIO(&MA=&%L;V=O+@!08?!A;&EN=&D`4&'P86QI;G1I(/#A
M(&5L96UE;G3@(&GP(&1O:W5M96YT;P!)\'1R:6YT:2!V87)T;W1O:N``5F%R
M=&]T;VIO('1R>6YI;6%S.B`E<P!.96=A;&EU(&%T<V%K>71I(.$@=?YK;&%U
M<^`N($ML86ED;W,@:V]D87,Z(`!)\'9A;'ET:0!086ME:7-T:2!S;&%P=&'^
M;V3A`%-L87!T8?YO9/YI;R!K96ET:6UA<P!297IU;'1A=&%I`$=RX?YT:2#A
M(&YU<W1A='EM=7,`4F5J^VYI:F$`071S=&%T>71I(&MO;F9I9_MR86-I:N``
M2%1-3"!R961A:W1O<FEA=7,@;G5S=&%T>6UA:0!-X7-LZW,`1&7P:6[K:F4`
M1&7P:6YI;VII(&%N=')A\'3K`$1E\&EN:6]S:6]S(')E:6OP;>MS`%]%:6QU
M=.MS(&YU<W1A='EM86DN+BX`4F]LZP!2=6UU;FEJ80!087-U:W1I(#$X,`!0
M87-U:W1I(&MA:7+K;@!087-U:W1I(&1E\&ENZVX`16EL=73K<R!N=7-T871Y
M;6%I`$5I;'5TZW,@;G5S=&%T>6UA:0!%:6QU=.MS.@!3:VER='5K86D`4VMI
M<G1U:V%I('1A<G`@=FES^"!E:6QUZ&GX(&ER('-T=6QP96QI^`!3:VER='5K
M86D@=&EK('1A<G`@<W1U;'!E;&GX`%-K:7)T=6MA:2!T:6L@=&%R<"!E:6QU
MZ&GX`%9Y:V1Y=&D`4G5S:6IO<R!&961E<F%C:6IA`%)U86YD80!3+TU)344@
M<&%R8?!A<P!3+TU)344@=?YK;V1U;W1A<R!L86GP:V%S`$[K<F$@4T%33"!A
M=71E;G1I9FEK86-I:F]S(&UE8VAA;FEZ;6\N`%--4R#^:6YU=.MS`%-13"!#
M3$D`4U-(`%!!5EE+3P!37U%,($-,20#09?!T+@#0=F5N=&]J:2!(96QE;F$`
M4V%I;G0@2VET<V%S(&ER($YE=FES87,`4V%I;G0@3&EU8VEJ80#0=F5N=&%S
M:7,@4&5T<F%S(&ER($UI9V5L;VYA<P!386EN="!6:6YC96YT87,@:7(@1W)E
M;F%D:6YA:0!486UE('!AZ&EA;64@;&%N9V4@*%]S96QF*0!386UO80!386X@
M36%R:6YA<P!386\@5&]M92!I<B!0<FEN8VEPZP!086QY9&]V87,`4V%U9&\@
M07)A8FEJ80!)\'-A=6=O=&D`2?!S875G;W1I("5S`$GP<V%U9V]T:2!N=7-T
M871Y;75S`$GP<V%U9V]T:2!S=6=E;F5R=6]T=7,@;G5S=&%T>6UU<R!K86EP
M(%!(4"!S:W)I<'3@(&K[<_@@<V5R=F5R:6\@;&%I:VEN86IA;64@:V%T86QO
M9V4N`"5S(&YU<W1A='EM86D@:?!S875G;W1I+@!-;VMS;&%S`$EE\&MO=&D`
M4&%I9?!K80!086EE\&MO<R!R97IU;'1A=&%I`$EE\&MO=&D`7TEE\&MO=&D@
M=&5K<W1O`%!A<VER:6YK:71E(&9A:6QU<P!087-I<FEN:VET92!D873@`%!A
M<VER:6YK:71E(&=R=7#F`%!A<VER:6YK:71E(&YA=6K@('-A=FEN:6YKX`!0
M87-I<FEN:VET92!U_G)A\/@@:VYY9V5LY@!087-I<FEN:VET92!S97)V97+A
M`%!A<VER:6YK:71E('9A<G1O=&]JX`!087-I<FEN:VET92!V:7-U<R!D871O
M<R!K;VUP;VYE;G1U<RX`4&%S:7)I;FMI=&4@;V)J96MTX`!)\"#^96UI874@
M97-A;NAI^"!SX')A\/@@<&%S:7)I;FMI=&4@<F5I:VEA;75S('-I;6)O;&EU
M<RX@5NML:6%U(&=A;&ET92!J=6]S(&YU:V]P:6IU;W1I(.$@;&%I\&O@+@!0
M87-I<FEN:VET92!D871O<R!S:VER='5KX#H`4&%S:7)I;FMI=&4@9&%T;W,@
M9F]R;6%TX#H`4&%S:7)I;FMI=&4@:?!KZVQI;6\@9F]R;6%TX#H`4&%S:7)I
M;FMI=&4@X6ME;&EA;>`@9F%I;.`Z`%!A<VER:6YK:71E(.%KZVQI86UO(&9A
M:6QO(&9O<FUA=.`Z`%!A<VER:6YK:71E(&%P<F'PX"!K=7+A(&YO<FET92!R
M961A9W5O=&DZ`%!A<VER:6YK:71E(&QA:6MO('-K:7)T=6O@.@!087-I<FEN
M:VET92!L86EK;R!F;W)M873@.@!087-I<FEN:VET92!D=2!A=&ET:6YK86[H
M:75S(&QA=6MU<RX`4&%S:7)I;FMI=&4@<W!A;';X(&1E<FENX2X`4&%S:7)I
M;FMI=&4@;F]R:6W@(&MA;&+@.@!087-I<FEN:W1O<R!K871E9V]R:6IO<SH`
M4VGX<W1I('!R;V)L96UO<R!P<F%N9?!I;>``4VGX<W1I(%--4P!396YE9V%L
M87,`4V5N<V]R:75S.B``4G5G<^MJ:7,`4V5R8FEJ82!I<B!-;VYT96YE9W)A
M<P!397)I:F]S(&YU;65R:7,`4V5S:6IO<R!)1"!P87-I8F%I9^LN`%)I;FMI
M;GES`$YU<W1A='EM86D@;&5I9/YI86YT>7,@2G5M<R!P87-I:V5I<W1I('-L
M87!T8?YO9.$L(&IE:6=U(&KA(&MA9&$@;F]R<R!P86UI<O!I=&4N`$YU=&]L
M=7-I^"!S97)V97)I^"P@:W5R:75O<R!N;W)I=&4@;6%T>71I(&GP('!O<G1A
M;&\L(&YU<W1A='EM86DN`$MA;&)O<RP@;&%I:V\@>F]N;W,@:7(@9&%T;W,@
M;G5S=&%T>6UA:2X`4'5S;&%P:6\@<W!A;';X+"!A='-I;F%U:FEN:6UO(&1A
M_FYU;6\@:7(@:VET^"!V86EZ9&%V:6UO('!A<F%M971R^"!N=7-T871Y;6%I
M+@!287-T87,@871N875J:6YI;6\@<VMR:7!T87,`4W4@\&EU;R!P87)A;65T
M<G4@9V%L:6UO<R!K96QI;W,@=FEE=&]VZW,Z(`!396GP96QA:0!087)D=6]T
M=7;K`%1R=6UP87,@87!R8?!Y;6%S`$%R(&YA=61O=&D@:VQA=FEA=/MR;W,@
M;7EG='5K=7,@=F%L9'EM=6D_`%)O9'ET:0!2;V1Y=&D@;7EG='5K=7,_`%!A
M<F]D>71I('-K:7)T=6UU<R!T87)P(&GP<V%U9V]T;R!I<B!KX"!T:6L@<W5G
M96YE<G5O=&\@:V]N9FEG^W)A8VEN:6\@9F%I;&\N`%)O9'ET:2!P87-K=71I
M;FEO('!R:7-I:G5N9VEM;R!L86EKX#\`4F]D>71I('7^<F'P^"!K;GEG96SK
M<R!P879A9&EN:6W@/P!2;V1Y=&D@=?YR8?!U<R!I\"#P:?@@:V%T96=O<FEJ
M^`!2;V1Y=&D@9V%L:6UY8N8@<&%L:6MT:2!O<FEG:6YA;.``4F]D>71I('!A
M<FES:6YK:6W@`%)O9'ET:2!L96YT96SK<R!O<&5R86-I:O@@;65N:74_`%)O
M9'ET:2`E<R!M96YI=2!K86ERZVIE/P!2;V1Y=&D@8V5LZW,@;G5S=&%T>6WX
M(&QA;F?@`%)O9'ET:2!L96YT96SK<R!N=7-T871Y;?@@;&%N9^``4F]D>71I
M(&5I;'5TZW,@;G5S=&%T>6WX(&QA;F?@`%)O9'ET:2!P879E:6MS;.ML:6\@
M;G5S=&%T>6WX(&QA;F?@`%)O9'ET:2!F86EL^"#A:^ML:6W@`$QI^W1I<P!,
M:?MT:7,@<GET90!,:?MT:7,@=F%K87)E`%-U;6'^:6YT:0!3=6UA_FEN=&D@
M87)B82!P87-T=6UT:2!K86EM>6YI;FEU<R!B;&]K=7,`4VEE<F$@3&5O;NL`
M4F5G:7-T<F%C:6IA`%!A<F'P87,`4&%R8?!O(&%L9V]R:71M87,`4VEN9V%P
M^W)A<P!$>61I<P!0<F%L96ES=&D@<')O9FEL86MT:6O@`%-L;W9A:VEJ80!3
M;&]VZVYI:F$`4/MG80!3;FEE9V\@9WEL:7,Z(`!3;FEE9V\@:VEE:VES('9A
M;F1E;FEU.B``4V]L;VUO;F\@<V%L;W,`4V]M86QI80!$86EN;W,@:7(@16EL
MZW)A\.AI86D`4OOP:75O=&D@<&%G86P@:V%T96=O<FEJX`!2^_!I=6]T:2!P
M86=A;"!U_G)A\&\@=&5K<W3@`%+[\&EA=FEM;R!T=F%R:V]S('!A<VER:6YK
M:6UA<P!3:75N=.MJ;R!A9')E<V%S`%!I973X($%F<FEK80!0:65T^"!%=7)O
M<&]S("A)4T\M.#@U.2TS*0!0:65T^"!$_F]R9/YI:F]S(&ER(%!I973X(%-A
M;F1V:>AO('-A;&]S`%!I971I;NL@:&5M:7-F97)A`%1A<G!A<R!T87)P(&-E
M;&GX`%1A<G!A<R!T87)P(&-E;.MS('1U<FEN:6\@:7(@:W)A\'1I;NMS`%1A
M<G!A<P!487)P86D@=&%R<"!C96QI^`!487)P86D`27-P86YI:F$`4W!A;6%S
M`%-P96-I9FEN:?@@<VEM8F]L:?@@X71E<G!I;6%S`%!E<G-K96QT:2!C96SF
M`%!E<G-K96QT:2!S='5L<&5LX0!097)S:V5L=&D@96EL=73F`%-P;W)T87,`
MT')I($QA;FMA`%-T86YD87)T87,`4W1A<B!4<F5K)V%S`%!R861I;FEA:2!M
M971A:0!286IO;F%S(&%R8F$@<')O=FEN8VEJ80!"^W-E;F$`4V%U9V]J:6UO
M(&9O<FUA=&%S`$=A=';K<R!A9')E<V%S`%7^8G)A=6MT:0#>;V3^:?@@<^!R
M8?!A<P!.=6EM=&D@9&]M96[@(&YU;R!A9')E<V\`4W1I;&EU<R!;0U-370!3
M96MM+@!496UA`,%V97-T:0!);F1E:W-A<P!3ZVMM:6YG80!+;VYF:6?[<F%C
M:6IA(&%T<W1A='ET82!SZVMM:6YG86DN(%!E<FMR875K:71E('!U<VQA<.$L
M(&MA9"!P86UA='ET=6WK=&4@<&%K96ET=6UU<RX`071S87)G:6[K(&MO;F9I
M9_MR86-I:F]S(&MO<&EJ82!SZVMM:6YG86D@:?!S875G;W1A+@`G)7,G('/K
M:VUI;F=A:2!U_G)A\'ET87,N`%-U9&%N87,`5'5R:6YY<P!3875LZW1E:VES
M`%-A=6SK;'EG:7,`4V%U;.MT80!3875LZW1E:VES`%-A=6SK=&5K:7,O4V%U
M;.ML>61I<P!3875LZW1E:VES.B``4V%U;.ML>6=I<P!3875LZVQY9VES.B``
M3&%I<'-N:7,`07!T87)N879I;6%S`%-U<FEN86UA<P!0879A<F3K`%-V86QB
M87)D87,@:7(@1/YA;FUA:6YA<P!3=F%Z:6QA;F1A<P#0=F5D:6IA`-!V96EC
M87)I:F$`4VEN=&%K<^MS(&ML86ED82!P86EE\&MO<R!K<FET97)I:G5J90!3
M:7)I:F]S($%R86+X(%)E<W!U8FQI:V$`5"UA=61R80!4+6%U9')O<P!44U8@
M9F%I;&%S`$QE;G1E;.L`3&5N=&5LZW,@;G5S=&%T>6UA:0!,96YT96SK<R!N
M=7-T871Y;6%I`%1A:79A;F%S`%1A:79A;F%S+"!+:6YI:F]S('!R;W9I;F-I
M:F$`5&%D_FEK:7-T86YA<P!*=6YG=&ENZR!486YZ86YI:F]S(%)E<W!U8FQI
M:V$`5&%I:VEN>7,Z`$1A<F)A:0!496QE9F]N;R!N=6UE<FES`%1E;7`N('!A
M<VLN('9A;&%N9.`Z(`!496UP97)A=/MR80!496UP97)A=/MR83H@`-!A8FQO
M;O@@861M:6YI<W1R879I;6%S`%1E:W-T87,`5&EK('1E:W-T87,`3'EG:75O
M=&D@=&5K<W3@`%1E:W-T;R!V:7+P=6IE`$ME='8N`%1A:6QA;F1I971I\&MA
M("A425,M-C(P*0!486EL86YD87,`0>AI^R!K860@;F%U9&]J873K<R!S:7-T
M96UA+@!.ZW)A($944"!M;V1U;&EO+@!(;W)D92]+;VQA8B!I;G1E9W)A8VEJ
M;W,@=F%R:6ML:75K87,@;F5P86QA:6MO("(E<R(`3F5P879Y:V\@=?YK<F%U
M=&D@36%I;G1E;F%N8V4Z.B!K;&%SZW,`3G5S=&%T>6WX(&QA;F=A<R!U_F1A
M<GET87,N($GP96EN=2X`2F5I9W4@;F]R:71E(&YA=61O=&D@;G5S=&%T>6UU
M<RP@<&%P<F'P>6MI=&4@:V%D(&%D;6EN:7-T<F%T;W)I=7,@<W5K;VYF:6?[
M<G5O=/@@<&%S=&]V:>`@9'5O;65N^"!B87KF(&YU<W1A='EM86US('-A=6=O
M=&DN`%1I:R!A<&%T:6[K:F4@<'5SZVIE`$YEX7)A\.MT92!C;VYT86MT;R!)
M1"!N=6UE<FEO(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+@!+
M;VYT86MT87,@<^MK;6EN9V%I(.%T<F%U:W1A<R#A($K[<_@@861R97/X(&MN
M>6=E;.8N`$YO<NMD86UI('!A=&EK<FEN=&D@;&%I\&O@('!R:79A;&]T92!T
M=7+K=&D@871S:VERX"!01U`@<&%R8?!O(&)L;VO@+@!.9>%R8?#K=&4@9&ES
M=')I8G5C:6IO<R!SX')A\&\@240@87)B82!J:7,@;F5R87-T87,@9'5O;65N
M^"!B87KK:F4N`$YEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P;RX`4$=0
M('7^:V]D879I;6\@9V%L:6UY8NL@<F5I:V%L875J82!S875G875S('!R:7-I
M:G5N9VEM;RX@0F%N9'EK:71E(')A\'ET:2!H='1P<SHO+R!A9')E<V\@<')A
M9/YI;VIE+@!&86EL87,@)7,@<')I=F%L;R!T=7+K=&D@)7,@<&%R86UE='+@
M+@!&86EL87,@)7,@<')I=F%L;R!T=7+K=&D@:V%I(&MU<FEU;W,@)7,@<&%R
M86UE=')U<RX`1F%I;&%S(&YE9V%L:2!B^W1I(&YU:V]P:6IU;W1A<R!A;G0@
M<V%VYG,N`$9A:6QE(&[K<F$@9'5O;65N^"X`4D9#.#@R(&QA:?!K;R!A;G1R
M8?!TZW,N`$IE:6=U(&1I<F)A=&4@26YT97)N970@17AP;&]R97(@;F%R\'EK
M;&4L('!I;&YA96MR86YI<R!R961A:W1O<FEA=7,@<F7^:6UA<R!G86QI('-U
M:V5L=&D@<')O8FQE;?@L(&3K;"#P:6]S(&YA<O!Y:VSK<R!K;&%I9/@N($=A
M;&ET92!N96UA='ET:2!K86D@:W5R:?@@<F5D86MT;W)I875S(&5L96UE;G3X
M+B!*96EG=2!N875D;VIA=&4@5VEN9&]W<R`Y>"!/4R!G<F5IZ&EA=7-I86D@
M:OMS^"!K;VUP:75T97)I<R!P87!R8?#H:6%U<VEA:2!N=6QU\"!P87-K96QB
M9&%M87,@87!I92!P86=R:6YD:6[F(&ML86EDX"Y<;EQN2OMS(&)U=F]T92!P
M97)S<.MT87,N($IE:6=U('9I<W1I96L@;F]R:71E(&GP8F%N9'ET:2!P:6QN
M865K<F%NX2!R9?YI;>`@<W!A=7-K:71E($]++@!!<')A\&%S("(E<R(@:?!T
M<FEN=&%S+@!4:6L@:V%I<NMJ92!P=7/K:F4`0W)Y<'1?<'%P.CH@:VQA<V5I
M(')E:6MI82!N=7)O9'ET:2!K=7(@>7)A($=N=5!'(&9A:6QA:2X`3&%I\&MA
M<R!I\'-I^'-T87,@)7,@861R97-A='5I("5S('1E;6$@(B5S(B!B=79O('!A
M<F]D>71A<RX*5&'H:6%U('1A:2!N96=A<F%N='5O:F$@:V%D(&QA:?!K87,@
M8G5V;R!P97)S:V%I='ET87,@87)B82!S=7!R87-T87,N`%!A=F%D:6YI;6%S
M(&MU<N$@;F%U9&]S:71E(&YU;W)O9&]J92#A(&QA:?!K;R!R8?!Y;6\@<'5S
M;&%PX0!5_G)A\&%S(&GP=')I;G1A<RX`3F5P879Y:V\@<W5K=7)T:2!U_G)A
M\/@@:VYY9V5LZW,@(B5S(CH@)7,`5?YR8?#X(&MN>6=E;.L@(B5S(B!S=6MU
M<G1A+@!5_G)A\/@@:VYY9V5LZR`B)7,B(&GP=')I;G1A+@!5_G)A\/@@:VYY
M9V5LZR`B)7,B(&GP<V%U9V]T82X`2&]R9&5?0W)Y<'1?<VUI;64Z.B!K;&%S
M96D@<F5I:V%L:6YG87,@3W!E;E-33"!M;V1U;&ES+@!.96=A;&EU(&GP<V%U
M9V]T:2!N=7-T871Y;6\@(B5S(BP@;F5S(&1U;VUE;O@@9'ED:7,@=FER\'EJ
M82!L96ES=&ENX"!R:6+@`%!R;V=R86UA+"!S:VER=&$@<&5R_FG[<NMT:2#P
MX2!D=6]M96[X('1I<.`@*"5S*2P@;F5R87-T82!S:7-T96UO:F4N`%1I:R!K
M86ERZVIE(&ER(&1E\&ENZVIE('!U<^MS90!4:6L@9&7P:6[K:F4@<'5SZVIE
M`%-E<G9E<FES("(E<R(@:?!T<FEN=&%S+@!397)V97)I<R`B)7,B(&GP<V%U
M9V]T87,N`"5S(')E9VES=')A8VEJ;W,@<')A\'EM87,@:?!T<FEN=&%S+@!.
M=7)O9'ET82!E:6QU=.L@;F5E9WII<W1U;VIA+@!4:6L@=FER\'5T:6[K:F4@
M:7(@87!A=&ENZVIE('!U<^MS90!4:6L@87!A=&ENZVIE('!U<^MJ90!.=7-I
M^'-T:2!D=6]M96YY<R!P<F%R87-T:2X`3F5G86QI=2!I\'-A=6=O=&D@;G5S
M:?AS=&\@9F%I;&\N`%=E871H97(N8V]M(&)L;VMO(&[K<F$N`$YU<W1A='EM
M^"!NZW)A+@!$86QI^"P@:W5R:6%S(&=A;&EM82!R;V1Y=&D@;&%I\&MO('1E
M:W-T92P@;NMR82X`T&EA;64@;&%U:V4@X79E<W1A('!E<B!D875G('-I;6)O
M;&GX+B!*^W,@X79E9.MT92`E<RP@;R!M86MS:6UA;'5S('-K86GH:75S("T@
M)7,@<VEM8F]L:6%I+@!0<F]B;&5M;W,@<W4@9F%I;/@@<VEU;G1I;74Z("5S
M(&YE;G5S:?AS=&%S+@!.=7-I^'-T:2!F86EL;R!N97!A=GEK;RX@1F%I;&%S
M("5S('ER82!D:61E<VYI<R!N96=U(&QE:63^:6%M87,@9'ED:7,@*"5D(&)A
M:71A:2DN`$YU<VGX<W1I(&9A:6QO(&YE<&%V>6MO+B!&86EL87,@)7,@=&EK
M(&1A;&EN86D@;G5S:?AS=&%S+@!.96=A;&EU('!A<F]D>71I(/!I;W,@;&%I
M\&MO(&1A;&EE<P!+;&%I9&$@X6ME;&EA;G0@:V]N=&%K=&EN:75S(&1U;VUE
M;FES+@!+;&%I9&$@X6ME;&EA;G0@9'5O;65N:7,Z("5S`$ML86ED82#A:V5L
M:6%N="!V3F]T92!D=6]M96YI<RX`2VQA:61A(&MO;F9I9_MR86-I:F]S(&9O
M<FUO:F4N($=R96GH:6%U<VEA:2!N977^<&EL9.MT92!R96EK:6%M^"!L875K
M^"X`2VQA:61A(&%T;&EE:V%N="!N=7)O9'ETX"!A9')E<_@@:VYY9V5LZW,@
M9G5N:V-I:N`N(%!A8F%N9'EK:71E(';K;&EA=2X`2VQA:61A(&GP=')I;F%N
M="!U_G)A\.`Z("5S`$ML86ED82!I\'-A=6=A;G0@=?YR8?#@.B`E<RX`2VQA
M:61A(&%T;F%U:FEN86YT(&MO;G1A:W1I;FEU<R!D=6]M96YI<RX@4&%B86YD
M>6MI=&4@=NML:6%U+@!+;&%I9&$@871N875J:6YA;G0@9&ES=')I8G5C:6IO
M<R!SX')A\.`N(%!A8F%N9'EK:71E(';K;&EA=2X`2VQA:61A('!E<OYI^W)I
M;G0@\&G@('7^<F'P^"!K;GEG96SF.B`E<P!5_G)A\/@@:?!KZVQI;75I(&[K
M<F$N`-!I<R!)34%0('-E<G9E<FES(&YE<&%L86EK;R!K871A;&]G^"!D86QI
M:FEM;W-I+@!!=')O9&\L(&MA9"!T86D@;F5T=F%R:VEN9V%S(%)!4B!A<F-H
M>79A<RX`071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!:25`@87)C:'EV
M87,N`$%T<F]D;RP@:V%D('1A:2!N971E:7-I;F=A<R!K;W)T96SK<R!N=6UE
M<FES+@#0:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!P97(@
M0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!P87-I;F%U9&]J
M86YT($A45%`@<')O=&]K;VQU`-!I('1V87)K>6MLZR!L96ED_FEA('-I^'-T
M:2#^:6YU=&5S('!E<B!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M
M*2!P87-I;F%U9&]J86YT($A45%`@<')O=&]K;VQU`-!I('1V87)K>6MLZR!L
M96ED_FEA('-I^'-T:2#^:6YU=&5S(%--5%`@<')O=&]K;VQU('!E<B!6;V1A
M9F]N92!)=&%L:6IO<R!V87)T=7,L('1I:R!6;V1A9F]N92!N=6UE<FEA;7,N
M($II(')E:6MA;&%U:F$@96PN('!A\'1O(&%D<F5S;R!6;V1A9F]N92!)=&%L
M>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@#0:7,@;&%U:V%S('!R:79A;&]M87,N
M`-!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@<W9E:6MI96II('-K86GH:6%I
M+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-K86GH:6%I(&ER(&1V:71A
M\&MI86DN`-!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@8?!T=6YT86EN:6%I
M('-K86GH:6%I+@#0:6%M92!L875K92!T=7)I(&+[=&D@:V%B;&5L:6%I<R!A
M<F)A('1A<G!A:7,@871S:VER=&D@<W9E:6MI96II('-K86GH:6%I`-!I(')E
M:6OP;>L@='5R:2!B^W1I('-K86GH:75S+@#0:6%M92!L875K92!G86QI(&+[
M=&D@=&EK('-P86QV;W,@:V]D87,@4D="($AE>"!F;W)M871E+"!P879Y>F3^
M:75I("<C,3(S-$%&)RX`1F%I;&\@9F]R;6%T87,@;F5P86QA:6MO;6%S+@#0
M:2!F;W)M82!J874@87!D;W)O=&$N`%1A:2`E<RX`5&%I($MO;&%B($=R;W5P
M=V%R92!O8FIE:W1A<RX@3F]RZV1A;6D@<&5R_FG[<NMT:2!O8FIE:W3@('!R
M:79A;&]T92!T=7+K=&D@96PN('!A\'1O(&ML:65N=.`L(&MU<FES('-U<')A
M;G3@(/#A(&9O<FUA=.`N(%1O:VGX(&5L+B!P8?!T;R!K;&EE;G3X('/@<F'P
MX"!G86QI=&4@<F%S=&D@87!S:6QA;FOF("5S`-!I<R!L86GP:V%S(&)U=F\@
M<&%R8?!Y=&%S("5S(&MO9'5O=&4N($K[<R!N875D;VIA=&4@:VET;VMIX"!K
M;V1U;W3F+@#0:7,@<VMA:>AI=7,@='5R:2!B^W1I(&1I9&5S;FES('7^(&YU
M;.$N`-!I<R!S97)V97)I<R!N96=A;&D@:?!A<F-H>79U;W1I('II<"!I<B!G
M>FEP(&9A:6SX+@#0:2!S:7-T96UA(&1A8F%R(&GP:G5N9W1A+@#0:2!R96EK
M\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RX`T.$@;&%N9^`@<F5I:VEA(&%T:61A
M<FENZW1I(&GP(&YU<W1A='EM^"!L86YG;P!097)K^VYI:F$`0FEL:65T86D`
M3&%I:V%S`$QA:6MO(&%P<VMA:71A`$QA:6MO(&9O<FUA=&%S`$QA:6MO('!A
M<VER:6YK:6UA<P!4:6UO<FQE<W3K`%!A<F5I9V]S`%!A=F%D:6YI;6%S.@!+
M86T`3F]RZV1A;6D@<&%S:7)I;FMT:2!K96QE=.`@96QE;65N=/@L(&QA:6MY
M:VET92!#;VYT<F]L("A00RD@87)B82!#;VUM;F%D("A-86,I(&ML879I\.`L
M(&ER('!A<VER:6YK:71E('!E;&4N`-!I86YD:65N`%)O9'ET:2!(5$U,(&MO
M9.``5&]G87,`5&]K96QA=0!2>71O:@!4;VYG80!6:7+P=6IE`%9I<O!U=&EN
M:6%M92!L86YG92`H7W1O<"D`5F5R=&EM86D`5')I;FED861A<R!I<B!4;V)A
M9V%S`%1A:7`@87)B82!N90!!;G1R+@!4=6YI<V%S`%1U<FMI:F$`5'5R:VGP
M:V$@*$E33RTX.#4Y+3DI`%1U<FMMZVYI:F$`5'5R:W-O(&ER($MA:6MO<V\@
M<V%L;W,`5'5V86QU`,%V97-K:71E('-A=F\@<&%S:7)I;FMI;>`Z(`!5+E8N
M(&EN9&5K<V%S.B``55),`%-K<FEP=&\@<')I<W1A='EM;R!S=&%T=7-O(')A
M<&]R=&\@55),`%523#H`56=A;F1A`%5K<F%I;F$`3F5P879Y:V\@<&5R<VMA
M:71Y=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!P<FEDZW1I('!A<&EL9&]M
M;W,@=F%R=&]T;VIO(')E9VES=')A8VEJ;W,@:6YF;W)M86-I:F]S+@!.97!A
M=GEK;R!P86ME:7-T:2!61E,@9F%I;&\@(B5S(B!T96ES:?@N`$YE<&%V>6MO
M('!A:V5I<W1I('1E:7-I^"!61E,@9F%I;'5I("5S+R5S+@!.97!A=GEK;R!P
M97)E:71I(.$@)7,N`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4U%,('-E
M<G9E<FEO+@!.97!A=GEK;R!P<FES:6IU;F=T:2!34TP@<F7^:6UU+@!.97!A
M=GEK;R!N=6MO<&EJ=6]T:2!61E,@9F%I;&\N`$YE<&%V>6MO('-U:W5R=&D@
M5D93(&MA=&%L;V=O("(E<R(N`$YE<&%V>6MO('-U:W5R=&D@5D93(&MA=&%L
M;V=O+@!.97!A=GEK;R!S=6MU<G1I(%9&4R!F86EL;RX`3F5P879Y:V\@<W5K
M=7)T:2!T=?#H:6\@5D93(&9A:6QO+@!.97!A=GEK;R!I\&%R8VAY=G5O=&D@
M9'5O;65N^"X`3F5P879Y:V\@:?!T<FEN=&D@(B5S(BP@:V%T86QO9V%S(&YE
M='7PZ&EA<P!.96=A;&EU(&GP=')I;G1I("(E<R(Z("5S`$YE<&%V>6MO(&GP
M=')I;G1I("5S+"!K871A;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO(')E:W5R
M<VGP:V%I(&GP=')I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@:?!T<FEN
M=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T86QO
M9V\Z("5S+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\@(B5S(BX`3F5P
M879Y:V\@:?!T<FEN=&D@5D93(&9A:6QO+@!.97!A=GEK;R!R96MU<G-I\&MA
M:2!I\'1R:6YT:2!61E,Z("5S+@!.97!A=GEK;R!N=7-T871Y=&D@9&%B87)T
M:6YI;R!K871A;&]G;RX`3F5P879Y:V\@9V%U=&D@<V5R=&EF:6MA=&\@87!R
M8?!Y;6\`3F5P879Y:V\@=?YK<F%U=&D@)7,@87!R8?!Y;6\N`$YE<&%V>6MO
M('!E<FME;'1I(%9&4R!F86EL;RX`3F5P879Y:V\@871I9&%R>71I(%9&4R!F
M86EL;R`B)7,B+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO(')A\'EM
M=6DN`$YE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\N`$YE<&%V>6MO(&%T
M:61A<GET:2!S=7-P875S=&\@87)C:'EV;RX`3F5P879Y:V\@<&5R<VMA:71Y
M=&D@=F9S<F]O="!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT:2`E<R#A
M("5S.B!T;VMS(&MA=&%L;V=A<R!J874@96=Z:7-T=6]J80!.97!A=GEK;R!P
M97)V861I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT:2!6
M1E,@:V%T86QO9V\Z("5S+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL
M;R`B)7,B+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`E<R\E<RX`
M3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\N`$YE<&%V>6MO('!A;&5I
M<W1I("=M:VES;V9S)RX`3F5P879Y:V\@:?!V97)S=&D@\&EO(%=O<F0@9&]K
M=6UE;G1O`$YE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("(E<R(N`$YE<&%V
M>6MO(.%R8?!Y=&D@5D93(&9A:6QO("AC;W!Y*"D@:VQA:61A*2X`3F5P879Y
M:V\@X7)A\'ET:2!61E,@9F%I;&\@9'5O;65N^"X`4&%B<F%U:W1I`$%T\&%U
M:W1I('!A:V5I=&EM=7,`073P875K=&D@86YK<W1E<V[A('9E:6MS;>``3F5T
M:6OK=&$@<V5R=F5R:6\@:VQA:61A.B``3F5T:6OK=&$@<V5R=F5R:6\@:VQA
M:61A.B``3F5N=7)O9'ET80!5;FEK;V1A<R`H551&+3@I`$IU;F=T:6YI86D@
M07)A8O@@16UY<F%T86D`2G5N9W1I;NL@2V%R86QY<W3K`$IU;F=T:6[K<R!6
M86QS=&EJ;W,`2G5N9W1I;FGX(%9A;'-T>6KX($%T;VME<V[K<R!S86QO<P!6
M:65N971A:0!.9?YI;F]M87,`3F7^:6YO;6%S(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`$YE_FEN;VUA<R!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+@!.9?YI;F]M87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T
M8?YO9&ES+@!086YA:6MI;G1I(&YU;W)O9.`@\&EA;2!E;&5M96YT=6D`3F7A
M=F%R9&EN=&%S`%-A=6=U;6\@<W5M971I;6%I<R!N97!R:79I;&5G:6IU;W1I
M('-K<FEP=&%I(&YE9V%L:2!A=&QI:W1I(%!E<FOK;&EM;R]+;W!I:F%V:6UO
M+\%KZVQI;6\@<')O9W)A;6GP:V%I+B!.;W+K9&%M:2!P97+^:?MRZW1I('1E
M8VAN:6YE<R!D971A;&5S(&UO>FEL;&$N;W)G('1I;FML87!Y:F4L(&ER('-U
M_FEN;W1I(&MA:7`@<VMR:7!T86US(&QE:7-T:2!P<FEE:71I('!R:64@;&%I
M:VEN;W-I;W,@<V%U9WEK;&]S+"!P87-P875S:VET92!/2RX`3F5N875D;W1I
M('-P86QV;W,`4&SK=&EN>7,@;F5P86QA:6MO;6%S`$%T;F%U:FEN=&D`071N
M875J:6YT:2`E<P!!=&YA=6II;G1I('9A<G1O=&]JX`!!=&YA=6II;FEM;R!S
M:W)I<'1A<R!I\'1R:6YT87,N`$YU<VGX<W1I`%9I<VD@;6]D=6QI^"!A=&YA
M=6II;FEM;R!F86EL86D@X6ME;'1I(.$@<V5R=F5RX2X`1&ED_FEO<VEO<R!L
M;W1I;FGP:V]S(')A:63K<P!$:61I96II(')O;>MN:?!K:2!S:V%IZ&EA:0!5
M<G5G=F%J=7,`3F%U9&]T:2!D86)A<G1I;N8Z("5S`$YA=61O=&D@4U-,`$YA
M=61O=&D@:F5I9W4@=F%R=&]T;VIO('9A<F1A<R]S;&%P=&'^;V1I<R!)35-0
M('-E<G9E<FEU:2!Y<F$@:VET;VMS+@!687)T;W1O:F%S("5S(&YE875T;W)I
M>G5O=&%S('!R:>MJ:6UU:2!P<FEE("5S+@!687)T;W1O:O@@861M:6YI<W1R
M879I;6%S`%9A<G1O=&]J;R!N=7-T871Y;6%I`%9A<G1O=&]J^"!R96=I<W1R
M86-I:F$`5F%R=&]T;VKX(')E9VES=')A8VEJ82!I\&IU;F=T82X`5F%R=&]T
M;VIO('9A<F1A<P!687)T;W1O:F\@=F%R9&%S.@!687)T;W1O:F\@=F%R9&%S
M.B``5F%R=&]T;VIA:2#P:6]J92!S:7-T96UO:F4Z`%5Z8F5K:7-T86YA<P!6
M1E,@:V%T86QO9V%S(&YE96=Z:7-T=6]J82X`071O<W1O9V]S`%)A<W1O<R!T
M96ES:6YG;W,@=FEE=&]VZW,Z(`!'86QI;VII;6%S`%)E:6OP;>L@;6EN=73K
M;6ES(&YU;R!D86)A<BX`4F5I:_!MZW,`4F5I:_!MZW,@:?`@:W5R:?@@9V%L
M:6UA('!A<VER:6YK=&D`5F%N=6%T=0!+:6YT86YT:7,`5F5N97-U96QA`%!A
M='9I<G1I;FEM87,@;F5B86EG=&%S("T@\&ES(&QA:?!K87,@<W5G861I;G1A
M<RX`5F5R<VEJ80!697)S:6KX(&MO;G1R;VSK`$QY9VEU;W1I('9E<G1I:V%L
M:6%I`%9E<G1I:V%L=7,@=&%R<&%S`%9E<G1I:V%L=7,Z`$QA8F%I(&1I9&5L
M:7,`5FEE=&YA;6%S`%9I971N86UI971I\&MA("A625-#24DI`%!E<OYI^W+K
M=&D@)7,`4F]D>71I(&GP;W)I;N$@<'5S;&%PX0!097+^:?MRZW1I(&MA:7`@
M)7,`0G)I=/@@5FER9/YI;FEJ;W,@<V%L;W,`2D%6(%9I<F3^:6YI:F]S('-A
M;&]S`$UA=&]M=6UA<P!-871O;75M87,Z(`!6;V1A9F]N92!)=&%L:6IA('!E
M<B!33510`%=!4DX`1,M-15-)3R$A(2!005194R!)T%1224Y+251%(%-+4DE0
M5,`@2=`@)7,N`%9A;&ES(&ER($9U='5N80!$ZVUE<VEO`%1R9>@N`$]R^"!P
M<F]G;F]ZZP!/<O@@<')O9VYO>NL@<&%G86P`5V5A=&AE<BYC;VT`5U=7`%=7
M5R!P=7-L87!I<P!+87,@<V%V86ETY@!3=F5I:VD`4W9E:6MI(&%T=GEKYB#A
M("5S`$QA8F%S+"`E<P!686MA<O@@*$E33RTX.#4Y+3$I`%9A:V%R^"`H25-/
M+3@X-3DM,34I`%9A:V%R^"!386-H87)A`$MO:^$@;6]D=6SA("5S('1U<FD@
M<F]D>71I('!O('!R:7-I:G5N9VEM;S\`2V]K<R!S:VER='5K;R!S:6UB;VQI
M<S\`2V]K<R!K86)UZ&GX('-I;6)O;&ES/P!0<FEE(&MU<FEO<R!U_G)A\/@@
M:VYY9V5LZW,@<')I9.MT:2!D87)B=7,_`$MU<FEO<R!F87KK<P!(5$U,(')E
M9&%K=&]R:6%U<R!M;V1U;&GX(.%J=6YG:6UA<RX`4&QO=&ES`%!L;W1I<R!#
M4U,@;6%T86ES`"5S(&MA:7)I;VIO(&UE;FEU('!L;W1I<R`H<&%K96ET:6UA
M:2!B=7,@;6%T>71I('!O(&MI=&\@<')I<VEJ=6YG:6UO*3H`3&5N=&5LZW,@
M<&QO=&ES`%!L;^AI;R!M871A<P!0;&]T:7,Z`%=I:VD`5NMJ;R!G<F5I=&ES
M(&UA>F=A:7,`5NMJ87,Z`%;K:F%S.B``2?!M:6YT:7,`1&%R8F%S`$1A<F)O
M(&%D<F5S87,`1&%R8F\@=&5L969O;F%S`%@M4F5F`%@U,#EV,R!P86=R:6YD
M:6YI86D@;G5S=&%T>6UA:0!8-3`Y=C,@:?!P;.MS=&\@<F%K=&\@<&%N875D
M;VII;6%S`%@U,#EV,R!A;'1E<FYA='EV=7,@=F%R9&%S`%@U,#EV,R!R86MT
M;R!I9&5N=&EF:6MA=&]R:75S`%@U,#EV,R!M;V1U;&EA:0!960!965E9`%EA
M:&]O(2#^96WK;&%P:7,`2V%S;65T`$IE;65N87,`5&%I<`!486EP+"!A\"!S
M=71I;FMU`$K[<R!E<V%T92!414M35$E.24%-12!21=Y)344N($YO<NMD86UI
M(&=RX?YT:2#A(%=94TE764<@<W!A=7-K:71E(%L\/ETN`$K[<R!N97!R:7-I
M:G5N9^8N`%-A=F\@=F%R9&4@;F5G86QI=&4@;F%U9&]T:2!S:6UB;VQI;R`G
M7"<N`,%V963K=&4@;F5T96ES:6YGX"!E;"X@<&'P=&\@861R97/@+@!.97!R
M:6IU;F?K=&4@:F]K:?@@;&%U:_@@:?`@X6ME;&EA;6\@9F%I;&\@<')I92`E
M<R!A=&ET:6YK86WX(&QA=6OX+@!.971U<FET92!T96ES:?@@<&5R_FG[<NMT
M:2!U_G)A\/@@:VYY9V5LZW,@)7,N`$K[<R!A='-I:G5N9^MT92X`5'5R:71E
M(.%V97-T:2!T96ES:6YGX"!T96QE9F]N;R!N=6UE<N$@*'1I:R!S:V%IZ&EU
M<R!I<B`G*R<L(&IE:6=U(&YO<FET92!N=7)O9'ET:2!T87)P=&%U=&ENX2!K
M;V3@*2X`P79E9.MT92!N971E:7-I;F?@(')E:6OP;>8N`$YO<NMD86UI(&YA
M=6=O=&ES(')E9VES=')A8VEJ;W,@<VES=&5M82P@='5R:71E('-U:V]N9FEG
M^W)U;W1I(&1U;VUE;O@@;65D_FEO('!O<VES=&5MYBX`4')I9?`@<VGX<V1A
M;6D@<')A;F7P:6W@+"!A<')A\'EK:71E('!R;V)L96W@+@#!<F'P>6MI=&4@
M;G5O<F]D;W,@55),`$YU<F]D>6MI=&4@=?YR8?#X(&MN>6=E;.8L(&MU<FG@
M(&YO<FET92!I\'1R:6YT:2X`5'5R:71E('!A<VER:6YK=&D@<V5R=F5RX2P@
M:W5RX2!N;W)I=&4@:?!T<FEN=&DN`$YU<F]D>6MI=&4@=F%R=&]T;VIO('9A
M<F3@+"!K=7)I;R!D=6]M96YI<R!T<FEN871E+@!.=7)O9'EK:71E('9A<G1O
M=&]J;R!V87)DX"!T<GEN:6UU:2X`3G5R;V1Y:VET92!K=7)I86UO('9A<G1O
M=&]J;R!V87)DX"X`3G5R;V1Y:VET92!A=&YA=6II;F%M;R!V87)T;W1O:F\@
M=F%R9.`N`$YU<F]D>6MI=&4@=F5I:W-MX"X`2OMS('1U<FET92#A=F5S=&D@
M;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`N`"5S('-E<VEJ82!B86EG
MZW-I+B!0<F'P;VUE('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X(&5L+B!P
M8?!T;R!A9')E<V%S.@!%;"X@<&'P=&\@861R97-A<SH`26YF;W)M86-I:F$@
M87!I92!*=7,`3G5O("5S('-E<VEJ;W,@<')A9/YI;W,@:OMS^"!)4"!A9')E
M<V%S('!A<VEK96ETZRX@5'5R:71E('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*
M^W/X('9A<F1A<R]P879A<F3K`$K[<_@@875T96YT:69I:V%V:6UO('-I<W1E
M;6$@;F5P86QA:6MO('9A<G1O=&]J^"!SX')A\&\L(&%R8F$@\&D@9G5N:V-I
M:F$@=?YD<F%U<W1A(&3K;"!T86T@=&EK<O@@<')I9?YA<^AI^"X`3G5O("5S
M('-E<VEJ;W,@<')A9/YI;W,@:OMS^"!N87+P>6MLZW,@=&EP87,@<&%S:6ME
M:73K+B!4=7)I=&4@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@;F%R\'EK
M;.L@;F5P86QA:6MO(/!I;W,@9V%L:6UY8NMS+@!*^W/X(&QA:6MO(&IU;W-T
M83H`2OMS^"!S=&%N9&%R=&EN:7,@87!R8?!A<SH`2OMS^"!P86=R:6YD:6[K
M('7^<F'P^"!K;GEG96SK.@!*^W/X('9A<F1A<R]P879A<F3K.@!*^W/X(&YA
M=6IA<R`E<R!S;&%P=&'^;V1I<R!Y<F$Z("5S`$K[<_@@=?YR8?#X(&MN>6=E
M;.MS.@!*^W/X(&YU<W1A='EM86D@871N875J:6YT:2X`2OMS^"!S;&%P=&'^
M;V1I<R!P86ME:7-T87,`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,N(%!A
M<VET:6MR:6YK:71E('-A=F\@<&'P=.`@:7(@<')I<VEJ=6YK:71E('-U(&YA
M=6IU('-L87!T8?YO9/YI=2X`2OMS^"!N=71O;.8@<V5R=F5R:6%I.@!*=6=O
M<VQA=FEJ80!:86ER87,`6F%M8FEJ80!::6UB86)VZP!%;F5R9VEN9V]S`%M0
M87-LZW!T:2!C:71U;VIA;>`@=&5K<W3@70!;4')O8FQE;6]S('!R86YE\&EM
M87-=`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M`%M2;V1Y=&D@8VET=6]J
M86W@('1E:W-TX"`M("5S(&5I;'5T97-=`%ME:6QU=.L@)7,@:?`@)7-=`%]6
M86QD>6UA<P!?1W+A_G1I(.$@=?YR8?#X(&MN>6=E;.8`7T-,20!?2V%T96=O
M<FEJ80!?1'5O;65N^"!M961I<P!?2?!T<FEN=&D`7TGP=')I;G1I(&5I;'5T
MY@!?4F5D86=U;W1I`%!I<FUO:F4@7V5I;'5TZVIE`$=?<G5PZW,`4&%?9V%L
M8F$`7U!A=F5I:W-LZVQI;R!N=7-T871Y;6%I+BXN`%_!:V5L=&DO2?!K96QT
M:0!?5?YR8?#X('/@<F'P87,`4')I<VE?:G5N9W1I`$%T<VE?:G5N9W1I`%]+
M96ES=&D@;G5O<F]DX"XN`%].875J87,@=?YR8?!A<P!?3G5S=&%T>6UA:0!?
M5&5I<^MS`%]3<&%U<V1I;G1I`%])\'1R:6YT:2!N=6]R;V3@+BXN`$EE\&M?
M;W1I`%]+;VYF:6?[<F%C:6IA`%],96YT96SK<R!N=7-T871Y;6%I+BXN`%9?
M87)T;W1O:F%I`&%D<F5S^"!K;GEG96SK`$MA;&5N9&]R:75S`')A;75S`'-P
M875S:VET92#H:6$`:W)E;G1A`&9A:6QA<P!N=6\@)7,@*"5S*2`E<R`E<P!A
M.@!T=6]J874@<&%T`'!A<')A<W1I`&5I;'5T97-=`&UK:7-O9G,@:VQA:61O
M<R!K;V1A<R`E9"!B961A<F%N="!)4T\N`'9A<F1A<P!N97)E86QI>G5O=&$`
M9&%R(&YE<F5A;&EZ=6]T80!U_G)A\/@@:VYY9V5LZP!U>G)A<V%I+F-S=@!P
M<F]C96YT86D`<&EK<V5L:6%I`&MY;&$`<F]D>71I('-K:7)T=6UU<P!S;7,R
M96UA:6P@<&5R($A45%``<W1A8FEL:0!D87)B^"!SX')A\&%S`'-L87!T8?YO
M9.$@='5R:71E(.%R8?!Y=&D@9'4@:V%R='5S`'5N:69I:W5O=&D`9&%L:7,`
M=F%R=&]T;VIO('!A<VER:6YK:6UA<P!V0V%R9`!V3F]T90!P.@!W96%T:&5R
M+F-O;0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+VQV
M7TQ6+P``````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<T-``P,C`P,C``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]M;F5M;R]L;V-A;&4O;'9?3%8O3$-?34534T%'15,O````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0T`#`R,38P-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]L=E],5B],0U]-15-3
M04=%4R]M;F5M;RYM;P``````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38W,#(`,3`T,3<S
M-C(W-#0`,#(S,C8P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````@P```!P````T!```LP```$P(````````&`L`
M``@````9"P``*````"(+```&````2PL```@```!2"P``!0```%L+```(````
M80L``!$```!J"P``!P```'P+```%````A`L``!\```"*"P``"0```*H+```1
M````M`L```\```#&"P``"````-8+```(````WPL``!4```#H"P``"````/X+
M```*````!PP```8````2#```+0```!D,```,````1PP```<```!4#```*0``
M`%P,```&````A@P```(```"-#```!0```)`,```0````E@P``!D```"G#```
M&@```,$,```&````W`P```H```#C#```%````.X,```O`````PT```\````S
M#0``)@```$,-```%````:@T```H```!P#0``#0```'L-```%````B0T``!``
M``"/#0``$````*`-```/````L0T```L```#!#0``#P```,T-```,````W0T`
M``\```#J#0``!@```/H-```>`````0X``"$````@#@```P```$(.```$````
M1@X```P```!+#@``"@```%@.```%````8PX``!(```!I#@``$````'P.```(
M````C0X``!````"6#@``!@```*<.```'````K@X```(```"V#@``!````+D.
M```/````O@X```<```#.#@``#````-8.```'````XPX```0```#K#@``!0``
M`/`.```(````]@X```0```#_#@``"`````0/```-````#0\```P````;#P``
M"0```"@/```%````,@\```<````X#P``$0```$`/```-````4@\```@```!@
M#P``'@```&D/```%````B`\``"@```".#P``*0```+</```3````X0\```P`
M``#U#P``"P````(0```%````#A```!$````4$```!````"80```$````*Q``
M``P````P$```!@```#T0```.````1!````P```!3$```&@```&`0```7````
M>Q```!<```"3$```&P```*L0```?````QQ```!,```#G$```$````/L0```0
M````#!$``!<````=$0``!P```#41```%````/1$``"$```!#$0``'````&41
M```%````@A$```,```"($0``(````(P1```F````K1$```P```#4$0``!P``
M`.$1```,````Z1$```@```#V$0``!P```/\1```&````!Q(```T````.$@``
M"P```!P2```,````*!(```H````U$@```@```$`2```&````0Q(``$4```!*
M$@``,````)`2```0````P1(``!\```#2$@``$````/(2```/`````Q,```4`
M```3$P``E`$``!D3```+````KA0``"H```"Z%```"0```.44```*````[Q0`
M``4```#Z%```#@`````5```9````#Q4```8````I%0``#````#`5```9````
M/14```8```!7%0``$````%X5```3````;Q4```\```"#%0``"0```),5```;
M````G14```H```"Y%0``$0```,05```&````UA4``#(```#=%0``#````!`6
M```(````'18``"L````F%@``"````%(6```"````6Q8```@```!>%@``$@``
M`&<6```A````>A8``!T```"<%@``!0```+H6```(````P!8``!,```#)%@``
M+P```-T6```2````#1<``"(````@%P``!P```$,7```-````2Q<``!````!9
M%P``!0```&H7```1````<!<``!(```""%P``$````)47```8````IA<```\`
M``"_%P``#````,\7```.````W!<```D```#K%P``'@```/47```D````%!@`
M``4````Y&```"0```#\8```,````21@```X```!6&```!0```&48```4````
M:Q@``!````"`&```!@```)$8```:````F!@```L```"S&```!0```+\8```"
M````Q1@```4```#(&```$````,X8```$````WQ@```H```#D&```#````.\8
M```%````_!@```4````"&0``#0````@9```(````%AD```P````?&0``$P``
M`"P9```/````0!D```\```!0&0``"````&`9```'````:1D``!````!Q&0``
M#0```((9```&````D!D``!\```"7&0``"````+<9```C````P!D``"T```#D
M&0``$@```!(:```5````)1H```P````[&@``"P```$@:```7````5!H```0`
M``!L&@``"````'$:```0````>AH```8```"+&@``%````)(:```1````IQH`
M`!X```"Y&@``&P```-@:```:````]!H``",````/&P``$P```#,;```<````
M1QL``!(```!D&P``%@```'<;```4````CAL```<```"C&P``"````*L;```?
M````M!L``!\```#4&P``"@```/0;```#````_QL``"<````#'```*P```"L<
M```/````5QP```T```!G'```$0```'4<```/````AQP```L```"7'```#```
M`*,<```0````L!P``!````#!'```#````-(<```.````WQP```(```#N'```
M"@```/$<```O````_!P``#P````L'0``$````&D=```;````>AT``!0```"6
M'0``$````*L=```%````O!T```$```!<`````````````````````````"<`
M``!1```````````````1````<0````0``````````````#L```!/````+P``
M`%L```!%````#@```$H```!D````>````$,```"`````'@````````!!````
M.````'T`````````0````!4`````````(@````````!\`````````%,````K
M`````````#H```!C````%````'`````D````!0````````!G````-````"H`
M``!R`````````!P````+````/@```"D```````````````````!-````6@``
M`"$`````````=P```#<```!8`````````",````=```````````````E````
M,@```%D``````````````%<````6````#P```#,````:````-@```&@````;
M`````````'8```!>````$P```$(```````````````````!0````-0```&L`
M```"````.0```&$```!4````9@```%4````9````8@```%8````N````````
M````````````1````&H``````````````$P```![`````````&`````#````
M`````$<````)````/P```'D````@`````````"@```"#````"````%T```!(
M````<P```'X````,````3@````8````Q````7P```!`````\````@@``````
M``!U````"@```!<````-````20``````````````90```&D````?````)@``
M`&P```!&````+0```&X`````````,````&T`````````+```````````````
M/0```%(`````````>@```($```!O````!P```$L`````````?P```!@`````
M`````````'0````2`````"5D(&YO=&5S`"5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VX`,2!N;W1E`#(T(&AO=7)S`$%-+U!-`$%D
M9"!P86ER`$%D9&EN9R!!($YE=R!.;W1E`$%D9')E<W,`06QI87,`06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!<V-E;F1I;F<`079A:6QA8FQE
M(&9I96QD<SH`0F%C:R!T;R!.;W1E<&%D`$)I<G1H9&%Y`$-A;&5N9&%R`$-A
M;F-E;"!0<F]B;&5M(%)E<&]R=`!#871E9V]R>0!#96QL(%!H;VYE`$-H86YG
M90!#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@86YD(&1I<W!L87D@;W!T:6]N
M<RX`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,`0W)E871E`$1$`$1A:6QY`$1E9F%U;'0@
M261E;G1I='D`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O
M<G1I;F<@9&ER96-T:6]N.@!$96QE=&4`1&5S8V5N9&EN9P!$97-C<FEB92!T
M:&4@4')O8FQE;0!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!$:7-P;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'``16UA:6P`16UP='D@3F]T90!%;7!T
M>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C
M;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AP;W)T`$9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BX`1F%X`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO
M;F4`2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`
M3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC<P!,;V<@:6X`3&]G(&]U=`!-30!-
M86EL`$UA=&-H:6YG(&9I96QD<P!-97-S86=E`$UO9&EF>6EN9R`E<P!-;VYT
M:&QY`$YA;64`3F5V97(`3F5W($YO=&4`3F5X=`!.;R!N;W1E<P!.;W1E($-A
M=&5G;W)Y`$YO=&4@1&5T86EL<P!.;W1E(%1E>'0`3F]T97,`3W!T:6]N<P!/
M=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`%!A<W-W;W)D`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4F5F<F5S:"!,:7-T`%)E;6]V92!P86ER`%)E<V5T`%)E='5R;B!T;R!/<'1I
M;VYS`%)O;&4`4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E87)C:"!297-U
M;'1S`%-E87)C:"!38V]P90!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-K:7`@36%I
M;G1E;F%N8V4`4V]R="!B>2!#871E9V]R>0!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3=6-C97-S`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%52
M3`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`56YF
M:6QE9`!5<V5R($]P=&EO;G,`57-E<FYA;64`5V%R;FEN9P!7965K;'D`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F
M;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`
M6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`=D-A<F0`4')O:F5C
M="U)9"U697)S:6]N.B!-;F5M;R`Q+C$N,@I297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,3$M
M,3D@,34Z-3`K,#(P,`I,87-T+51R86YS;&%T;W(Z($IA;FES($5I<V%K<R`\
M:F%N8W-`9'8N;'8^"DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U#4#$R-3<*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3,[('!L=7)A;#TH;B4Q,#T]
M,2`F)B!N)3$P,"$],3$@/R`P(#H@;B`A/2`P(#\@,2`Z(#(I.PH`)60@<&EE
M>NYM97,`)7,@57IT=7+G\&%N87,@;W!E<N)C:6IA<R`M(&%P<W1I<')I;N)J
M=6US`#$@<&EE>NYM90`R-"!S='5N9&%S`$%-+U!-`%!I979I96YO="!PXG)I
M`%!I979I96YO:F%M(&IA=6YU('!I97KN;6D`061R97-E`$%I>G-TXFIVXG)D
M<P!.;W+B9.YT82!N961E<NYG82!VYW)T[F)A`$%U9V_P:0!0:65E:F%M:64@
M;&%U:VDZ`$%T<&%K8>\@=7H@<V%R86MS='4`1'II;?!A;F%S(&1I96YA`$MA
M;&5N9.)R<P!!=&-E;'0@<')O8FSG;6%S('!I971E:6MU;74`2V%T96=O<FEJ
M80!-;V)I;&%I<R!TXFQR=6YI<P!-86EN[G0`36%I;NYT('!I97KN;6IU(/#M
M:7)O\&%N87,@=6X@96MRXFYA(&EE<W1A=.YJ=6UU<RX`06EZ=N=R="!L;V=U
M`%5Z\N=M=6US`$YE:7ID97;B<R!A=';G<G0@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&D@)7,`27IV96ED;W0`1$0`26MD:65N87,`4&%R87-TXB!I9&5N=&ET
MXG1E`$YO:VQU<^=T86ES(/#M:7)O\&%N87,@:W)I=.=R:6IS.@!.;VML=7/G
M=.(@\.UI<F_P86YA<R!KXG)T[F)A.@!$>N=S=`!$:6QS=&_P:0!!<')A:W-T
M:65T('!R;V)LYVUU`%/N:^)K82!I;F9O<FWB8VEJ82!I<B!N;W/[=.YT82!A
M9&UI;FES=')A=&]R86TN`$5K<N)N82!I97-T873N:G5M:0!.878@=&EE\&%S
M('!I965J87,@;6%I;G1E;F%N8V4N<&AP`$4M<&%S=',`5'5K\&$@<&EE>NYM
M90!4=6OP<R!R97IU;'3B=',N`$OO^V1A`$MA=')A<R`Q-2!M:6[[=&5S`$MA
M=')A<R`S,"!S96MU;F1E<P!+871R87,@-2!M:6[[=&5S`$MA='+B('!I97-L
MYV?P86[B<R!R96EZYP!+871R=2!P=7-S='5N9'4`2V%T<G4@;6EN^W1I`%!A
M<F%U9W;G<G3N8F%S`$5K<W!O<G3G=`!.96EZ9&5VXG,@<V'R96UT(&EE<W1A
M=.YJ=6UU<RX`3F5I>F1E=N)S('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN
M`$9A:W-S`%!A;.YD>NYB80!-XFIA<R!A9')E<V4`3>)J87,@=&5L969O;G,`
M2&]R9&4`265LXF3G=&%I<R!L875K<SH@)7,`265LXF3G=&EE(&QA=6MI.@!6
M86QO9&$`4&%RXF3N="!P86SN9'KN8F%S('1E;6%T=7,`4&EE<VSG9W1I97,`
M27II970`34T`4&%S=',`4V%S:V%N;_!I92!L875K:0!::?)A`$QA8F]J86T@
M)7,`2V%T<G4@;>=N97-I`%;B<F1S`$YE:V%D`$IA=6YA('!I97KN;64`3N)K
M86UA:7,`4&EE>NYM:G4@;F%V`%!I97KN;65S(&MA=&5G;W)I:F$`4&EE>NYM
M97,@<V%T=7)S`%!I97KN;65S('1E:W-T<P!0:65Z[FUE<P!/<&-I:F%S`$-I
M=&$@:6YF;W)MXF-I:F$`0VET87,@;W!C:6IA<P!087)O;&4`27IP:6QD[G0@
M=7IT=7+G\&%N87,@;W!E<N)C:6IA<P!4XFQR=6YI<P!,^V1Z=2!N;W+B9&EE
M="!P<F]B;.=M87,@86YO=.)C:6IU+@!,^V1Z=2!N;W+B9&EE="!S879U(&QI
M971O=.)J82!VXG)D=2!U;B!P87)O;&D`4')O8FSG;6%S(&%P<F%K<W1S`$%T
M<W9A:61Z:6[B="!S87)A:W-T=0!)>F1ZYW-T('#B<FD`1'KG<W0@=FES=7,`
M071G<FEE>G1I97,@<&EE(&]P8VEJXFT`3&]M80!386=L86+B=`!386=L86+B
M="!O<&-I:F%S`$UE:VSG=`!-96MLY_!A;F%S(')E>G5L=.)T:0!-96MLY_!A
M;F%S(&%P:F]M<P!)>G;G;&EE=&EE<R!D871U;6$@871D86SN=.)J=3H`27IV
MYVQI971I97,@9&%T=6UA(&9O<FWB='4Z`$EZ=N=L:65T:65S(&QA:6MA(&9O
M<FWB='4Z`$EZ=N=L:65T:65S(&1I=G5S('-A9&5R[F=U<R!L875K=7,N`$EZ
M=N=L:65T:65S('9A;&]D=3H`3F]S^W3N="!P<F]B;.=M87,@<&EE=&5I:W5M
M=0!)>FQA:7-T('5Z='5RY_!A;G4`T.UI<F]T('#G8R!K871E9V]R:6KB;0#.
M<&'P;R!S:6UB;VQU(&EE=F%D90!696EK<VUE`%5Z9&5V=6UI`-!I;2!S:V%I
M=&QI;2!I<B!JXF+[="!V:7-M87H@,2X`T&%I(';G<G3N8F%I(&ER(&KB8OMT
M('-K86ET;&EM+@!6:7)S<F%K<W1S`%523`!.878@:65S<.=J86US('!I97-L
MYV=T:65S(%-13"!S97)V97)I;2X`3F%V(&EE<W#G:F%M<R!I;G1E<G!R973G
M="#P;R!7;W)D(&1O:W5M96YT=0!!=&-E;'0@:7IM86GR87,`3F5K;&%S:69I
M8^=T<P!,:65T;W3B:F$@;W!C:6IA<P!,:65T;W3B:F$@=N)R9',`0G+N9&EN
MXFIU;7,`2V%T<G4@;F5DY^]U`$QA:7!N:2!L^V1Z86T@)7,`3&%I<&YI(&S[
M9'IM+"`E<P!$87)B82!A9')E<V4`1&%R8F$@=.)L<G5N:7,`1T<`2V%T<G4@
M9V%D=0!!<')A:W-T:65T('!R;V)LYVUU('!I<FUS('!I971E:6MU;6$@<_MT
M[O!A;F%S+@!*^W-U("5S('-E<VEJ82!I<B!B96EG=7-I97,N($S[9'IU('!I
M97-LYV1Z:65T:65S(&%T:^)R=&]T:2X`2OMS=2!I;F9O<FWB8VEJ80!*^W-U
M(&]P8VEJ87,@:7(@<V%G;&%BXG1A<RX`6U!R;V)LYVUA<R!Z:?)O:G5M<UT`
M6W)I;F1A("5S(&YO("5S70!V0V%R9```````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+VQV7TQ6+VAE;'`N
M>&UL````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8V,P`Q,#0Q
M-S,V,C<T-``P,C$T-S<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O
M+3@X-3DM,2(_/@H\(2TM("1(;W)D93H@;6YE;6\O;&]C86QE+VQV7TQ6+VAE
M;'`N>&UL+'8@,2XR(#(P,#0O,3$O,C0@,34Z,C@Z,CD@:F%N($5X<"`D("TM
M/@H\:&5L<#X*"CQE;G1R>2!I9#TB3W9E<G9I97<B(&UD-3TB,39D,V(Q.#AC
M8V9F.#0S-C1F-F8Q-3$T9&4V-C4U8C`B('-T871E/2)U<'1O9&%T92(^"B`@
M("`\=&ET;&4^4.)R<VMA=',\+W1I=&QE/@H@("`@/&AE861I;F<^265V861S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!;4&EE>NYM97-=(&ER(&%P;&EK
MXF-I:F$L(&MA<R#O875J(')A9.YT(&SN;6QA<&GR=2!D871O<FEZYW1U(&5K
M=FEV86QE;G1U+B!0:65Z[FUE<R!V87(@:65R86MS=.YT+"!L86)O="P@9'KG
M<W0@=6X@9')U:^)T+B!"97H@=&%M(&ER(&EE<W#G:F%M<R!M96MLYW0@<&EE
M>NYMYW,@;F5P:65C:67P86UO(&EN9F]R;>)C:6IU('5N(&ML87-I9FECYW0@
M=.)S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)L:7-T+6%C
M=&EO;G,B(&UD-3TB8S)A,S@Y,#=C,#AE,68Y-SDT839E,V,Y,F(U83`S9C$B
M('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4&EE>NYM:G4@<V%R86MS
M=',Z($1A<F+N8F%S/"]T:71L93X*("`@(#QH96%D:6YG/D1A<F+N8F%S/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!;1'KG<W1=(.]A=6H@:7ID>N=S="!I
M>G;G;.=T;R!P:65Z[FUI+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!;
M3&%B;W1=(.]A=6H@;&%B;W0@:7IVYVSG=&\@<&EE>NYM:2X*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@6T%T9W)I97IT:65S($=RXFUA=.)=(.]A=6H@
M871G<FEE>G1I97,@;F\@<&EE>NYM97,@87!S:V%T97,@4&EE>NYM:G4@9W+B
M;6%TXBX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB;65N=2UA
M8W1I;VYS(B!M9#4](F(X8C@U9&0T,F8X,S-A93$W,C@P-65D9&8R,S=D9#$R
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E+N:W4@:F]S;&$\+W1I
M=&QE/@H@("`@/&AE861I;F<^4NYK=2!J;W-L83PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@6U!A<N)D[G1=('!A<N)D82!V:7-A<R!P:65Z[FUE<R!P:65Z
M[FUJ=2!G<N)M873B+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!;4F%K
M<W3N=%T@[V%U:B!I97)A:W-T[G0@:F%U;F%S('!I97KN;65S('!I97KN;6IU
M(&=RXFUA=.(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%M-96MLYW1=
M(.]A=6H@;65K;.=T('1E:W-T=2!P:65Z[FWG<RX@27(@:65S<.=J86US(&UE
M:VSG="!T:6MA:2!A<')A:W-T82!L875KXB!V86D@87+N(&EZ9&%R[G0@<&EL
M;F\@;65K;.?P86YU('!I97KN;6IU('1E:W-TXBX*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@6T1R=6OB=%T@[V%U:B!I>F1R=6OB="!P:65Z[FUI+B!;
M1')U:^)T72!I:V]N82!I<B!R961Z86UA('+N:W4@:F]S;.(@=&EK86D@<&EE
M>NYM97,@87!S:V%T97,@;&%I:^(N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H*
M/&5N=')Y(&ED/2)S;W)T:6YG(B!M9#4](F-C83-B,60Q8SEE9#!E8S5A8C,X
M-68X,C0V.61D8SAF(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DEE
M<F%K<W1U(/#M:7)O\&%N83PO=&ET;&4^"B`@("`\:&5A9&EN9SY)97)A:W-T
M=2#P[6ER;_!A;F$\+VAE861I;F<^"B`@("`\<&%R83X*("`@($%P<VMA=&]T
M(&EE<F%K<W1U('5Z<VMA:73N:G5M=2!I<B!I97-PYVIA;7,@\.UI<F]T(&EE
M<F%K<W1U<R!PYV,@:F5B:W5R87,@:V]L;VYN87,L('5Z:VQI:_#M:6YO="!A
M=&)I;'-T;_#B('-T86)I\F$@;F]S875K=6UA;2X@3&%I('#B<G-LYV=T;W,@
M;F\@875G;_#B<R!U>B!D:6QS=&_P;R#P[6ER;_!A;F%S(&OB<G3N8G4L('5Z
M:VQI:_#M:6YI970@8G5L=&%S(&EK;VYA:2!B;&%K=7,@871B:6QS=&_PXB!S
M=&%B:?)A(&YO<V%U:W5M86TN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]N8E].3R\`````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-#0`,#$W-S<Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE
M+VYB7TY/+TQ#7TU%4U-!1T53+P``````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<T-``P,C$U-38`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]M;F5M;R]L;V-A;&4O;F)?3D\O3$-?34534T%'15,O;6YE;6\N;6\`
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$V,S<S`#$P-#$W,S8R-S0T`#`R,S(S-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#>$@25
M`````(8````<````3`0``+,```!\"````````$@+```H````20L```@```!R
M"P``!0```'L+```(````@0L```<```"*"P``#````)(+```%````GPL``!\`
M``"E"P``"0```,4+```1````SPL```@```#A"P``"````.H+```5````\PL`
M``@````)#```"@```!(,```*````'0P```P````H#```!P```#4,```I````
M/0P```(```!G#```!0```&H,```0````<`P``!D```"!#```&@```)L,```*
M````M@P``!0```#!#```+P```-8,```/````!@T``"8````6#0``!0```#T-
M```-````0PT```4```!1#0``$````%<-```0````:`T```\```!Y#0``"P``
M`(D-```/````E0T```P```"E#0``#P```+(-```>````P@T``"$```#A#0``
M`P````,.```'````!PX```0````/#@``!0```!0.```,````&@X```H````G
M#@``!0```#(.```*````.`X```\```!##@``$@```%,.```0````9@X```<`
M``!W#@``"````'\.```)````B`X```P```"2#@``#0```)\.```.````K0X`
M`!8```"\#@``$0```-,.```0````Y0X```8```#V#@``!P```/T.```"````
M!0\```0````(#P``#P````T/```)````'0\```H````G#P``!P```#(/```,
M````.@\```<```!'#P``!````$\/```%````5`\```0```!:#P``!0```%\/
M```'````90\```H```!M#P``$0```'@/```-````B@\```@```"8#P``'@``
M`*$/```%````P`\``"@```#&#P``*0```.\/```3````&1````P````M$```
M"P```#H0```1````1A````0```!8$```#````%T0```&````:A````X```!Q
M$```#````(`0```:````C1```!<```"H$```%P```,`0```;````V!```!\`
M``#T$```$P```!01```0````*!$``!`````Y$0``%P```$H1```'````8A$`
M``4```!J$0``"0```'`1```A````>A$``!P```"<$0``!0```+D1```#````
MOQ$``"````##$0``)@```.01```,````"Q(```<````8$@``#````"`2```(
M````+1(```<````V$@``!@```#X2```-````11(```L```!3$@``#````%\2
M```*````;!(```(```!W$@``!@```'H2``!%````@1(``#````#'$@``$```
M`/@2```?````"1,``!`````I$P``#P```#H3```%````2A,```@```!0$P``
M"````%D3```%````8A,``&\!``!H$P``*````-@4```(`````14```4````*
M%0``#````!`5```'````'14```L````E%0``!0```#$5```=````-Q4```@`
M``!5%0``$P```%X5```'````<A4```@```!Z%0``%0```(,5```(````F14`
M``P```"B%0``$````*\5```*````P!4```4```#+%0``*0```-$5```"````
M^Q4```8```#^%0``$0````46```=````%Q8``!\````U%@``"````%46```1
M````7A8``"X```!P%@``$0```)\6```?````L18```4```#1%@``#@```-<6
M```$````YA8``!````#K%@``$````/P6```/````#1<```\````=%P``#0``
M`"T7```,````.Q<``!````!(%P``'0```%D7```B````=Q<```,```":%P``
M!@```)X7```%````I1<```0```"K%P``#0```+`7```.````OA<```4```#-
M%P``"@```-,7```0````WA<``!,```#O%P``$`````,8```(````%!@```4`
M```=&```#0```",8```-````,1@``!(````_&```%````%(8```;````9Q@`
M`!<```"#&```#0```)L8```(````J1@```<```"R&````@```+H8```$````
MO1@``!````#"&```"@```-,8```*````WA@```<```#I&```"0```/$8```)
M````^Q@```0````%&0``!0````H9```'````$!D```<````8&0``!````"`9
M```,````)1D``!$````R&0``$````$09```'````51D``!T```!=&0``!P``
M`'L9```H````@QD``"@```"L&0``$@```-49```/````Z!D```D```#X&0``
M$`````(:```%````$QH```H````9&@```P```"0:```,````*!H```H````U
M&@``%````$`:```/````51H``!````!E&@``&0```'8:```2````D!H``!,`
M``"C&@``%0```+<:```5````S1H``!4```#C&@``!P```/D:```(`````1L`
M``D````*&P``'0```!0;```6````,AL```8```!)&P```P```%`;```?````
M5!L``"@```!T&P``#P```)T;```)````K1L```H```"W&P``"@```,(;```(
M````S1L```@```#6&P``#0```-\;```-````[1L```P```#[&P``#`````@<
M```"````%1P```4````8'```/````!X<```V````6QP```\```"2'```'0``
M`*(<```0````P!P``!````#1'```!0```.(<```'````Z!P```0```#P'```
M!0```/4<```!````6P```&H```!Z```````````````@````4@``````````
M````#@```'$```!T```````````````^````4````"@```!U````2@``````
M``"&````8P```'@````Y````@````!D`````````1@```#0```!]````,P``
M`$,``````````````!P`````````+````$@````N````)````&@````W````
M8@```(0```!P````'@````,`````````/0```"T````C````<@`````````7
M````"0```$$````B````?P``````````````30```%H````;`````````'<`
M```Q```````````````=````&```````````````'P```"H```!$````````
M``````!8````$@````P````K````%0```#````!G````%@````````!V````
M70```!````!'``````````````!9````40```"\```""`````````#4```!@
M````50````<```!6````2P```&$```!7````)P```````````````````#@`
M``!I````@P```%0```!,````>P````````!?`````@``````````````!@``
M`$(```!Y````&@`````````A`````````&L```!<````;P```',```!^````
M"@```$\````$````*0```%X````-````/P````````````````````@````3
M````"P```!$`````````/````&0```!E`````````%,```!L````3@```"8`
M``!N````A0```$D```!M`````````"4`````````9@```$````!\````````
M`#(```"!``````````4````Z````-@```$4````4```````````````[````
M#P`````E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M`#(T(&AO=7)S`$%-+U!-`$%D9"!P86ER`$%D9')E<W,`061D<F5S<R!";V]K
M`$%L:6%S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07-C96YD
M:6YG`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E
M;"!0<F]B;&5M(%)E<&]R=`!#871E9V]R>0!#96QL(%!H;VYE`$-L96%R($9O
M<FT`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D
M:7)E8W1I;VXZ`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&:6QT97)S`$AE;'``
M2&]?;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`26-O;G,@3VYL
M>0!)8V]N<R!W:71H('1E>'0`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D
M(&9I96QD<SH`3&%?>6]U=`!,86YG=6%G90!,87-T($AA;&8`3&%S="!1=6%R
M=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,:7-T($AE;'`@5&]P:6-S
M`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE;6\@
M5&5X=`!-96YU(&UO9&4Z`$UE<W-A9V4`36]D:69Y:6YG("5S`$UO;G1H;'D`
M3F%M90!.979E<@!.97=S`$YO=&5S`$]P=&EO;G,`3W)G86YI>FEN9P!/=&AE
M<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`%!A<W-W;W)D`%!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5F
M<F5S:"!,:7-T`%)E;6]V92!P86ER`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`
M4V%V92!/<'1I;VYS`%-E87)C:`!396%R8V@@4F5S=6QT<P!396%R8V@@4V-O
M<&4`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3:VEP($UA:6YT96YA;F-E`%-O<G0@
M8GD@0V%T96=O<GD`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5C8V5S<P!4
M87-K<P!497AT($]N;'D`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET;&4`55),`%5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F9I;&5D
M`%5S97(@3W!T:6]N<P!5<V5R;F%M90!787)N:6YG`%=E96ML>0!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9
M`%EE87)L>0!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@26YF
M;W)M871I;VX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O
M8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!?2&5L<`!?3&]G(&]U=`!?
M3W!T:6]N<P!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($UN96UO(#(N,"UC
M=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2
M979I<VEO;BU$871E.B`R,#`R+3`V+3`U(#$Q.C0U*S`Q,#`*3&%S="U4<F%N
M<VQA=&]R.B!4;W)S=&5I;B!3+B!(86YS96X@/&AU;&5B;V5R0'1E8VAB964N
M;F\^"DQA;F=U86=E+51E86TZ($YO<G=E9VEA;B`H0F]K;6%L*2`\:3$X;D!L
M:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:70*`"5S('9E9&QI:V5H;VQD<V]P97)A<VIO
M;F5R("T@0F5K<F5F=&5L<V4`,C0@=&EM97(`04TO4$T`3&5G9R!T:6P@<&%R
M`$%D<F5S<V4`061R97-S92!";VL`06QI87,`16X@=6QO=FQI9R!V97)D:2!V
M87(@;W!P9VET="X`4W1I9V%N9&4`5&EL9VIE;F=E;&EG92!F96QT.@!"=7)S
M9&%G`$MA;&5N9&5R`$%V8G)Y="!P<F]B;&5M<F%P<&]R=`!+871E9V]R:0!-
M;V)I;'1E;&5F;VX`3G5L;'-T:6QL('-K:F5M80!,=6MK('9I;F1U`$9I<FUA
M`$MA;B!I:VME(.5P;F4@36%I;G1E;F%N8V5?5&%S:RUM;V1U;&5T("5S`$1$
M`$1A9VQI9P!3=&%N9&%R9&ED96YT:71E=`!3=&%N9&%R9"!S;W)T97)I;F=S
M:W)I=&5R:75M.@!3=&%N9&%R9"!S;W)T97)I;F=S<F5K:V5F^&QG:F4Z`%-Y
M;FMA;F1E`$)E<VMR:78@<')O8FQE;65T`$1E=&%L:F5R(&AA<B!B;&ET="!L
M;V=G970@9F]R(&%D;6EN:7-T<F%T;W)E;BX`5FES:6YG<V%L=&5R;F%T:78`
M26MK92#E<&X@;6%I;F5N86YC92YP:'`@9&ER96MT90!E<&]S=`!4;VUT(')E
M<W5L=&%T+@!&96EL`$AV97)T(#$U+B!M:6YU='0`2'9E<G0@,S`N('-E:W5N
M9`!(=F5R="`U+B!M:6YU='0`2'9E<B!I;FYL;V=G:6YG`$AV97(@:&%L=G1I
M;64`2'9E<G0@;6EN=71T`$5K<V5M<&5L=F5R9&EE<CH`2V%N(&EK:V4@96YD
M<F4@:6YS=&EL;&5I;F=E<BX`5&EL:V]B;&EN9R!T:6P@3$1!4"US97)V97(@
M9F5I;&5T+@!&87@`1FEL=&5R`$AJ96QP`$AJ96T`2&IE;6UE861R97-S90!4
M96QE9F]N(&AJ96UM90!(;W)D90!+=6X@:6MO;F5R`$EK;VYE<B!M960@=&5K
M<W0`26UP;W)T97)T92!F96QT.B`E<P!);7!O<G1E<G1E(&9E;'0Z`%5T<V5E
M;F1E`%-P<N5K`%-I<W1E(&AA;'1I;64`4VES=&4@:W9A<G1E<@!3:7-T92!O
M<'!D871E<FEN9SH`4VES=&4@:6YN;&]G9VEN9SH@)7,`4VES=&4@:6YN;&]G
M9VEN9SH@)7,@9G)A("5S`%-I<W1E(&EN;FQO9V=I;F<Z($%L9')I`$5M;F5R
M(&D@2&IE;'``3&]G9R!I;FX`3&]G9R!U=`!-30!0;W-T`%-A;7-V87)E;F1E
M(&9E;'0`3F]T871T96MS=`!-96YY;6]D=7,Z`$UE;&1I;F<`16YD<F%R("5S
M`$WE;F5D=&QI9P!.879N`$%L9')I`$YY:&5T97(`3F]T871E<@!686QG`$]R
M9V%N:7-E<FEN9P!!;FYE;B!I;F9O<FUA<VIO;@!!;F1R92!A;'1E<FYA=&EV
M`%!A<W-O<F0`571F^'(@=F5D;&EK96AO;&1S;W!E<F%S:F]N97(`5&5L969O
M;@!696YN;&EG<W0@9VD@970@<V%M;65N9')A9R!A=B!P<F]B;&5M970N`%9E
M;FYL:7-T('-K<FEV(&EN;B!B<G5K97)N879N(&]G('!A<W-O<F0`4')O8FQE
M;6)E<VMR:79E;'-E`$9R:7-K(&]P<"!L:7-T90!&:F5R;B!P87(`5&EL8F%K
M92!T:6P@5F%L9P!2;VQL90!,86=R92!686QG`%/X:P!3^&ME<F5S=6QT870`
M4_AK96]M<N5D90!696QG(&1A=&]S:VEL;&5T96=N.@!696QG(&1A=&]F;W)M
M870`5F5L9R!T:61S9F]R;6%T.@!696QG('1O('-A;7-V87)E;F1E(&9E;'0N
M`%9E;&<@^&YS:V5T('-P<N5K.@!396YD('!R;V)L96UR87!P;W)T`$AO<'`@
M;W9E<B!V961L:6ME:&]L9`!3;W)T97(@971T97(@:V%T96=O<FD`4W!E<VEA
M;'1E9VYI;FYT87-T:6YG`%-U:W-E<W,`3W!P9V%V97(`2W5N('1E:W-T`$1E
M='1E('1A;&QE="!MY2!VYG)E(&UI;G-T(#$N`$1E='1E(&WE(';F<F4@970@
M=&%L;"X`5&ET=&5L`%523`!+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R
M96XN`$MA;B!I:VME(&]V97)S971T92!D971T92!7;W)D+61O:W5M96YT970`
M06YG<F4@96YD<FEN9V5R`%5A<FMI=F5R=`!,86=R92!686QG`$)R=6ME<FYA
M=FX`061V87)S96P`56ME;G1L:6<`5F5L:V]M;65N+"`E<P!696QK;VUM96XL
M("5S`$9I<FUA861R97-S90!&:7)M871E;&5F;VX`Y>4`Y7)L:6<`1'4@;>4@
M8F5S:W)I=F4@<')O8FQE;65T(&;X<B!D=2!K86X@<V5N9&4@96X@<')O8FQE
M;7)A<'!O<G0N`$1I;B`E<R!T:6QK;V)I;F<@:&%R(&?E='0@=70N(%9E;FYL
M:6=S="!L;V<@:6YN(&EG:F5N+@!$:6X@:6YF;W)M87-J;VX`1&EN92!V86QG
M(&AA<B!B;&ET="!O<'!D871E<G0`6U!R;V)L96UR87!P;W)T70!;;&EN:F4@
M)7,@878@)7-=`$AJ96QP`$QO9V<@=70`5F%L9P!V0V%R9```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VUN96UO+VQO8V%L92]N;%].3"\`````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(P,#`P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+VYL7TY,+TQ#
M7TU%4U-!1T53+P``````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<T-``P,C$U-C4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M
M;R]L;V-A;&4O;FQ?3DPO3$-?34534T%'15,O;6YE;6\N;6\`````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,S4T-S<U`#$P-#$W,S8R-S0T`#`R,S(U-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#>$@25`````-\&```<
M````%#<``"L)```,;@```````+B2```.````N9(```\```#(D@``"````-B2
M```,````X9(```0```#ND@``#````/.2```(`````),```\````)DP``"P``
M`!F3```.````)9,```4````TDP``*````#J3```*````8Y,``!4```!NDP``
M$@```(23```+````EY,``!T```"CDP``#@```,&3```*````T),```T```#;
MDP``#@```.F3```1````^),```T````*E```#````!B4```-````)90```8`
M```SE```#P```#J4```8````2I0```P```!CE```!@```'"4```.````=Y0`
M``X```"&E```"````)64```N````GI0``!H```#-E```,@```.B4```X````
M&Y4``%0```!4E0``40```*F5``!:````^Y4``%<```!6E@``-````*Z6```*
M````XY8```4```#NE@``!@```/26```1````^Y8```@````-EP``"0```!:7
M```)````()<``"4````JEP``(````%"7```<````<9<``!X```".EP``(```
M`*V7```=````SI<``!````#LEP``#P```/V7```*````#9@```,````8F```
M#P```!R8```4````+)@```D```!!F```#0```$N8```2````69@```\```!L
MF```#````'R8```*````B9@```\```"4F```"````*28```D````K9@``!0`
M``#2F```%@```.>8```(````_I@``!$````'F0``&0```!F9```'````,YD`
M``P````[F0``+````$B9```.````=9D```,```"$F0``"P```(B9```'````
ME)D```<```"<F0``!0```*29```%````JID```H```"PF0```P```+N9```7
M````OYD```H```#7F0``#P```.*9```.````\ID``!@````!F@``(P```!J:
M```.````/IH``!0```!-F@``%P```&*:```7````>IH``!<```"2F@``$P``
M`*J:```/````OIH```X```#.F@``'P```-V:```'````_9H```8````%FP``
M"`````R;```/````%9L```8````EFP``"@```"R;```3````-YL```L```!+
MFP``%0```%>;```5````;9L```<```"#FP``!0```(N;```5````D9L``!$`
M``"GFP``#````+F;```[````QIL```D````"G```!P````R<```4````%)P`
M``,````IG```!0```"V<```)````,YP``!`````]G```"0```$Z<```3````
M6)P``#D```!LG```$@```*:<```G````N9P``"P```#AG```*@````Z=```E
M````.9T```H```!?G0``!@```&J=```)````<9T```<```![G0``+P```(.=
M```W````LYT``"X```#KG0``50```!J>```M````<)X``"T```">G@``+0``
M`,R>``!`````^IX``",````[GP``(P```%^?```M````@Y\``#,```"QGP``
M%0```.6?```9````^Y\``"D````5H```)````#^@```5````9*```!$```!Z
MH```"@```(R@```,````EZ````\```"DH```%P```+2@```*````S*```!``
M``#7H```%@```.B@```6````_Z````<````6H0``!P```!ZA```4````)J$`
M``H````[H0``"````$:A```(````3Z$```<```!8H0``!P```&"A```&````
M:*$```4```!OH0``!P```'6A```&````?:$```@```"$H0``*0```(VA```.
M````MZ$```H```#&H0``!````-&A```'````UJ$```D```#>H0``!@```.BA
M```1````[Z$```<````!H@``%@````FB```$````(*(```@````EH@``!@``
M`"ZB```-````-:(```8```!#H@``'@```$JB```1````::(```@```![H@``
M#0```(2B```,````DJ(```<```"?H@```P```*>B```#````JZ(``!<```"O
MH@```P```,>B```3````RZ(```@```#?H@``!````.BB```(````[:(```@`
M``#VH@``00```/^B```@````0:,```8```!BHP``!@```&FC```5````<*,`
M`!@```"&HP``(@```)^C```N````PJ,``!T```#QHP``(0````^D``!4````
M,:0``"D```"&I```"@```+"D```'````NZ0``!4```##I```"````-FD```.
M````XJ0```H```#QI```#P```/RD```-````#*4```\````:I0``#0```"JE
M```)````.*4``!0```!"I0``!@```%>E```8````7J4``!T```!WI0``$P``
M`)6E```4````J:4```0```"^I0``!@```,.E``!4````RJ4``"T````?I@``
M!````$VF```.````4J8```4```!AI@``!0```&>F```;````;:8``!H```")
MI@``$0```*2F```1````MJ8``!P```#(I@``*@```.6F```W````$*<``!P`
M``!(IP``$````&6G```A````=J<```4```"8IP``"@```)ZG```3````J:<`
M`!(```"]IP``"@```-"G```/````VZ<``!$```#KIP``$P```/VG```,````
M$:@```8````>J```!@```"6H```7````+*@``!$```!$J```"````%:H```%
M````7Z@```P```!EJ```$````'*H```%````@Z@```T```")J```!@```)>H
M```'````GJ@```T```"FJ```!P```+2H```+````O*@```<```#(J```!P``
M`-"H```)````V*@```H```#BJ```&0```.VH```,````!ZD``!`````4J0``
M!0```"6I```E````*ZD``!(```!1J0``$P```&2I```K````>*D``#L```"D
MJ0``(````."I```V`````:H```@````XJ@``#````$&J```&````3JH```0`
M``!5J@``#@```%JJ```*````::H```T```!TJ@``'@```(*J```;````H:H`
M`"$```"]J@``'@```-^J```9````_JH``!X````8JP``&P```#>K```F````
M4ZL``!L```!ZJP``'@```):K```<````M:L``"8```#2JP``,P```/FK```F
M````+:P``"L```!4K```.````("L```O````N:P``!(```#IK```*0```/RL
M```2````)JT``*(````YK0``%@```-RM```C````\ZT``"@````7K@``*0``
M`$"N```H````:JX``!\```"3K@``(````+.N```E````U*X``"$```#ZK@``
M'````!RO```F````.:\``$$```!@KP``#````**O```'````KZ\```<```"W
MKP``!@```+^O```-````QJ\``!````#4KP``$@```.6O```'````^*\``!,`
M````L```$@```!2P```'````)[````0````OL```#````#2P```.````0;``
M``\```!0L```$P```&"P```-````=+```"@```""L````P```*NP```-````
MK[````8```"]L```$0```,2P```7````UK```!L```#NL```#@````JQ```"
M````&;$```4````<L0``$````"*Q```$````,[$```T````XL0``#@```$:Q
M```#````5;$```X```!9L0``"````&BQ```/````<;$```\```"!L0``#0``
M`)&Q```0````G[$```\```"PL0``&0```,"Q```:````VK$```L```#UL0``
M!@````&R```,````"+(``!$````5L@``&0```">R```+````0;(```T```!-
ML@``(@```%NR```*````?K(``!@```")L@``&0```**R```6````O+(```T`
M``#3L@``!P```.&R```*````Z;(``!0```#TL@``"P````FS```,````%;,`
M`"(````BLP``+P```$6S```+````=;,```D```"!LP``&0```(NS```+````
MI;,``!<```"QLP``%P```,FS```)````X;,``!8```#KLP``#P````*T```6
M````$K0```X````IM```&````#BT```(````4;0```T```!:M```)@```&BT
M``!#````C[0```@```#3M```$@```-RT```(````[[0```L```#XM```+P``
M``2U```.````-+4```4```!#M0``!@```$FU```#````4+4```<```!4M0``
M!````%RU```*````8;4```H```!LM0``"0```'>U```/````@;4``!````"1
MM0``%P```**U```1````NK4``!<```#,M0``"0```.2U```%````[K4```L`
M``#TM0``"@````"V```"````"[8```4````.M@``#0```!2V```;````(K8`
M`!<````^M@``"0```%:V```*````8+8```X```!KM@``#0```'JV```2````
MB+8``#@```";M@``(````-2V```(````];8```X```#^M@``>P````VW```8
M````B;<``!$```"BMP``!P```+2W```%````O+<``!D```#"MP``!P```-RW
M```(````Y+<```8```#MMP``!@```/2W```0````^[<```\````,N```$```
M`!RX```/````+;@```L````]N```#P```$FX```,````6;@```\```!FN```
M!P```':X```&````?K@```P```"%N```*````)*X```/````N[@```@```#+
MN```!@```-2X```,````V[@```@```#HN```$P```/&X```*````!;D``!X`
M```0N0``(0```"^Y```@````4;D``!D```!RN0``%P```(RY```E````I+D`
M`!<```#*N0``!````.*Y```;````Y[D```T````#N@```P```!&Z```(````
M%;H```H````>N@``#````"FZ```+````-KH```0```!"N@``$P```$>Z```4
M````6[H```P```!PN@``"0```'VZ```.````A[H```L```"6N@``&P```**Z
M```'````OKH```<```#&N@``"@```,ZZ```-````V;H```D```#GN@``!```
M`/&Z```%````]KH```,```#\N@``&`````"[```*````&;L```0````DNP``
M)@```"F[```.````4+L``'P```!?NP``%0```-R[```%````\KL```<```#X
MNP``#`````"\```(````#;P```H````6O```!@```"&\```(````*+P```(`
M```QO```!@```#2\```&````.[P``!0```!"O```#0```%>\```0````9;P`
M`!L```!VO```!````)*\```)````E[P``!````"AO```"0```+*\```)````
MO+P```4```#&O```&@```,R\```(````Y[P```8```#PO```&0```/>\```.
M````$;T```<````@O0``!P```"B]```%````,+T```D````VO0``"@```$"]
M```"````2[T```8```!.O0``#0```%6]```)````8[T```8```!MO0``$@``
M`'2]```)````A[T```<```"1O0``%````)F]```=````KKT```8```#,O0``
M"@```-.]```$````WKT```D```#CO0``"````.V]```1````]KT```D````(
MO@``!@```!*^```-````&;X```8````GO@``!````"Z^```Y````,[X``#T`
M``!MO@``.@```*N^```>````YKX```4````%OP``#@````N_```$````&K\`
M``8````?OP``(0```":_```5````2+\```8```!>OP``!````&6_```1````
M:K\```8```!\OP``"@```(._```B````CK\```0```"QOP``!0```+:_```=
M````O+\```0```#:OP``#````-^_```*````[+\```@```#WOP``"0````#`
M```%````"L```#H````0P```,````$O````U````?,```"D```"RP```1P``
M`-S````X````),$``"D```!=P0``/P```(?!```N````Q\$``"T```#VP0``
M'P```"3"```/````1,(``!(```!4P@``"P```&?"```F````<\(``"D```":
MP@``)````,3"```F````Z<(```@````0PP``"@```!G#```)````),,```<`
M```NPP``(````#;#```@````5\,``"8```!XPP``"@```)_#```9````JL,`
M`"D```#$PP``%@```.[#```2````!<0```<````8Q```"@```"#$```/````
M*\0``!`````[Q```0````$S$``!P````C<0``&8```#^Q```#@```&7%```)
M````=,4```H```!^Q0``$@```(G%```3````G,4```P```"PQ0``!@```+W%
M```5````Q,4```\```#:Q0``$P```.K%```2````_L4``!`````1Q@``$0``
M`"+&```<````-,8``",```!1Q@``:@```'7&```/````X,8```4```#PQ@``
M$````/;&```)````!\<```0````1QP``"P```!;'```4````(L<```P````W
MQP``#````$3'```/````4<<``!4```!AQP``*0```'?'```J````H<<``"8`
M``#,QP``)P```//'```I````&\@``"H```!%R```&0```'#(``!"````BL@`
M`!$```#-R```$@```-_(```3````\L@``!0````&R0``#P```!O)```6````
M*\D``!<```!"R0``$````%K)```1````:\D``#0```!]R0``$P```++)```2
M````QLD``#4```#9R0``%`````_*```'````),H```P````LR@``(````#G*
M```4````6LH``!$```!OR@``%P```('*```<````F<H``!,```"VR@``$0``
M`,K*```:````W,H``!X```#WR@``&@```!;+```1````,<L``!0```!#RP``
M%P```%C+```5````<,L```D```"&RP``&0```)#+```$````JLL```<```"O
MRP``"P```+?+```1````P\L```8```#5RP``!@```-S+```&````X\L```4`
M``#JRP``!P```/#+```'````^,L```4`````S```%@````;,```&````'<P`
M``8````DS```!````"O,```$````,,P```<````US```#@```#W,```,````
M3,P```P```!9S```#0```&;,```*````=,P```X```!_S```!0```([,```H
M````E,P```X```"]S```#````,S,```/````V<P```H```#IS```"````/3,
M```)````_<P``"L````'S0``!````#/-```(````.,T``"8```!!S0``$@``
M`&C-```/````>\T```8```"+S0``"@```)+-```'````G<T```@```"ES0``
M(````*[-```)````S\T```T```#9S0``#````.?-```-````],T```X````"
MS@``%@```!'.```1````*,X```8````ZS@```P```$'.```&````1<X``!D`
M``!,S@``!P```&;.```$````;LX```L```!SS@``"P```'_.```'````B\X`
M``<```"3S@``%@```)O.```-````LLX```T```#`S@``"@```,[.```0````
MV<X```\```#JS@``$0```/K.```7````#,\```H````DSP``$0```"_/```(
M````0<\```0```!*SP``#P```$_/```Z````7\\```4```":SP``#````*#/
M```>````K<\```X```#,SP``$````-O/```+````[,\```P```#XSP``"0``
M``70```'````#]````H````7T```"0```"+0```.````+-```!`````[T```
M&@```$S0```*````9]````D```!RT```"@```'S0```,````A]````\```"4
MT```"````*30```&````K=````<```"TT```"P```+S0``!'````R-````T`
M```0T0``"0```![1```$````*-$```,````MT0``$P```#'1```3````1=$`
M`!,```!9T0``"@```&W1```"````>-$```0```![T0``)0```(#1```#````
MIM$```4```"JT0``*@```+#1```*````V]$```4```#FT0``!````.S1```*
M````\=$```T```#\T0``!@````K2```(````$=(```@````:T@``!````"/2
M```%````*-(``&@````NT@``"0```)?2```,````H=(```4```"NT@``!@``
M`+32```;````N](``"\```#7T@``$`````?3```*````&-,```\````CTP``
M"@```#/3```)````/M,``!,```!(TP``&P```%S3```8````>-,``!<```"1
MTP``#@```*G3```#````N-,```<```"\TP``"````,33```'````S=,```D`
M``#5TP``"@```-_3```+````ZM,```<```#VTP``40```/[3```0````4-0`
M``P```!AU```#0```&[4```:````?-0``$H```"7U```!@```.+4```&````
MZ=0```8```#PU```'P```/?4```&````%]4```D````>U0``&````"C5```7
M````0=4```8```!9U0``#0```&#5```B````;M4``%<```"1U0``$P```.G5
M```C````_=4``!,````AU@```@```#76```+````.-8```@```!$U@``#0``
M`$W6```*````6]8```P```!FU@``!P```'/6```4````>]8```8```"0U@``
M"````)?6```.````H-8```<```"OU@``"@```+?6```+````PM8```<```#.
MU@``#````-;6```-````X]8```P```#QU@``"0```/[6```)````"-<```H`
M```2UP``!P```!W7```)````)=<```<````OUP``"@```#?7```;````0M<`
M`!(```!>UP``"@```''7```(````?-<```D```"%UP``$````(_7```'````
MH-<``!(```"HUP``!````+O7```'````P-<```4```#(UP``!0```,[7```+
M````U-<``!0```#@UP``$0```/77```:````!]@``!8````BV```%````#G8
M```7````3M@``!@```!FV```'````'_8```9````G-@```<```"VV```!0``
M`+[8```-````Q-@```P```#2V```"````-_8```(````Z-@``!<```#QV```
M"P````G9```3````%=D```0````IV0``"@```"[9```$````.=D```P````^
MV0``"0```$O9```%````5=D```<```!;V0``!0```&/9```$````:=D```(`
M``!NV0``.````''9```L````JMD``!(```#7V0``*0```.K9```R````%-H`
M``H```!'V@``+````%+:```N````?]H``#,```"NV@``,P```.+:```X````
M%ML```\```!/VP``&````%_;```0````>-L``!,```")VP``%````)W;```2
M````LML``"0```#%VP``"````.K;```D````\]L``!,````8W```%````"S<
M```5````0=P``"T```!7W```+0```(7<```Q````L]P``"X```#EW```+P``
M`!3=```L````1-T``&(```!QW0``$P```-3=```(````Z-T```@```#QW0``
M*P```/K=```A````)MX``!H```!(W@``"0```&/>``!%````;=X``$$```"S
MW@``!0```/7>```$````^]X``!,`````WP``%````!3?```.````*=\``!,`
M```XWP``&````$S?```&````9=\```D```!LWP``"@```';?```/````@=\`
M`!````"1WP``!P```*+?```.````JM\```T```"YWP``#````,??```*````
MU-\```D```#?WP``"@```.G?```/````]-\```@````$X```#P````W@```(
M````'>````4````FX```#0```"S@```;````.N````@```!6X```!@```%_@
M```4````9N```!$```![X```#@```(W@```X````G.````(```#5X```!@``
M`-C@```.````W^````4```#NX```!P```/3@```.````_.````8````+X0``
M!````!+A```I````%^$``!<```!!X0``'P```%GA``!<````>>$``!0```#6
MX0``/@```.OA```?````*N(``!````!*X@``!P```%OB```.````8^(```P`
M``!RX@``#````'_B```3````C.(```H```"@X@``'0```*OB```9````R>(`
M``4```#CX@``$0```.GB```-````^^(``!$````)XP``)````!OC```5````
M0.,``!(```!6XP``#@```&GC```9````>.,```@```"2XP``"0```)OC```-
M````I>,```H```"SXP``"P```+[C```*````RN,```<```#5XP``"````-WC
M```%````YN,``!\```#LXP``!@````SD```0````$^0```@````DY```#0``
M`"WD```(````.^0``!(```!$Y```+````%?D```:````A.0```D```"?Y```
M"@```*GD```5````M.0```4```#*Y```%````-#D```$````Y>0``!````#J
MY```!@```/OD```'`````N4``!X````*Y0``*````"GE```*````4N4``!$`
M``!=Y0``"P```&_E```:````>^4``!0```"6Y0``!````*OE```$````L.4`
M``L```"UY0``!0```,'E```&````Q^4```@```#.Y0``!@```-?E```*````
MWN4``!L```#IY0``-`````7F```T````.N8``"````!OY@``*0```)#F```@
M````NN8``$$```#;Y@``&@```!WG```H````..<``"D```!AYP``(@```(OG
M```&````KN<```@```"UYP``!0```+[G```(````Q.<``!D```#-YP``&0``
M`.?G```J`````>@``",````LZ```+@```%#H```T````?^@```@```"TZ```
M%P```+WH```*````U>@```<```#@Z```(0```.CH```0````"ND```X````;
MZ0``"P```"KI```'````-ND``!,````^Z0``"````%+I```+````6^D```H`
M``!GZ0``%````'+I```R````A^D```L```"ZZ0``!0```,;I```%````S.D`
M`!<```#2Z0``#P```.KI```$````^ND```H```#_Z0``"0````KJ```+````
M%.H```X````@Z@``!0```"_J```$````->H```T````ZZ@``,@```$CJ``!%
M````>^H``!<```#!Z@``'@```-GJ```,````^.H``!0````%ZP``!0```!KK
M```4````(.L```<````UZP``#@```#WK```J````3.L```8```!WZP``#```
M`'[K```/````B^L```T```";ZP``$0```*GK```+````N^L``#8```#'ZP``
M"@```/[K```B````">P```L````L[```#P```#CL```R````2.P```4```![
M[```#@```('L```3````D.P```<```"D[```$0```*SL```'````ONP``!0`
M``#&[```&````-OL```'````].P```4```#\[```#`````+M```,````#^T`
M`!(````<[0``!````"_M```'````-.T```H````\[0``"P```$?M```,````
M4^T```X```!@[0``#@```&_M```%````?NT```4```"$[0``+@```(KM```F
M````N>T``",```#@[0```P````3N```2````".X```8````;[@``'@```"+N
M```8````0>X``"4```!:[@``#0```(#N```)````CNX```,```"8[@``!P``
M`)SN```*````I.X```(```"O[@``#````++N```5````O^X```L```#5[@``
M&0```.'N```@````^^X``!(````<[P``!0```"_O```*````->\``!4```!`
M[P``$@```%;O```,````:>\```0```!V[P``!P```'OO```,````@^\``%(`
M``"0[P``%P```./O```'````^^\```8````#\```#@````KP```.````&?``
M``P````H\```#````#7P```,````0O````T```!/\```%0```%WP```2````
M<_```!````"&\```#P```)?P```4````I_```!L```"\\```$````-CP``!I
M````Z?```!H```!3\0``%P```&[Q```9````AO$``!H```"@\0``)0```+OQ
M```G````X?$``!H````)\@``%P```"3R```;````//(``!D```!8\@``'P``
M`'+R```4````DO(``!,```"G\@``"````+OR```'````Q/(```@```#,\@``
M"0```-7R```5````W_(```T```#U\@``$P````/S```#````%_,``$8````;
M\P``/P```&+S```W````HO,``%<```#:\P``'P```#+T```O````4O0```H`
M``""]```"````(WT```-````EO0``"T```"D]```!````-+T```4````U_0`
M`$\```#L]```)0```#SU```2````8O4``"````!U]0``'````);U```+````
ML_4``!\```"_]0``'0```-_U```E````_?4``"`````C]@``)````$3V```@
M````:?8```L```"*]@``!P```);V```-````GO8```P```"L]@``!@```+GV
M```Y````P/8```P```#Z]@``!P````?W```)````#_<``!,````9]P``"0``
M`"WW```$````-_<``!`````\]P``"````$WW```(````5O<```0```!?]P``
M"P```&3W```,````</<``!$```!]]P``#````(_W```:````G/<```\```"W
M]P``!P```,?W```-````S_<``!````#=]P``$0```.[W```4`````/@```X`
M```5^```#````"3X```;````,?@``"P```!-^```$P```'KX```<````CO@`
M`"@```"K^```!@```-3X```'````V_@``!,```#C^```!0```/?X```$````
M_?@``!<````"^0``"@```!KY```,````)?D```D````R^0``!@```#SY```)
M````0_D```@```!-^0``"0```%;Y```*````8/D``!$```!K^0``!@```'WY
M```.````A/D```X```"3^0``#0```*+Y```+````L/D``!T```"\^0``"P``
M`-KY```"````YOD```<```#I^0``!@```/'Y```)````^/D```<````"^@``
M.P````KZ```H````1OH``!4```!O^@``!0```(7Z```'````B_H```@```"3
M^@``!P```)SZ```%````I/H```<```"J^@``#@```++Z```)````P?H```8`
M``#+^@``"````-+Z```+````V_H```<```#G^@``"````._Z```'````^/H`
M`!8`````^P``"0```!?[```&````(?L```L````H^P``'````#3[```4````
M4?L```<```!F^P``"````&[[```(````=_L```4```"`^P``$````(;[```0
M````E_L```8```"H^P``&0```*_[```*````R?L``!P```#4^P``!P```/'[
M```%````^?L``!````#_^P``%````!#\```+````)?P```T````Q_```%P``
M`#_\```$````5_P```D```!<_```"@```&;\```'````<?P```(```!Y_```
M#@```'S\```(````B_P``!\```"4_```(P```+3\```X````V/P``#$````1
M_0``)P```$/]``!D````:_T``!0```#0_0``50```.7]```X````._X``$H`
M``!T_@``6P```+_^```H````&_\``#@```!$_P``*````'W_```L````IO\`
M`"<```#3_P``&P```/O_```^````%P`!`*D!``!6``$`(P`````"`0`7````
M)`(!`$@````\`@$`A0```(4"`0`P````"P,!`!4````\`P$`*````%(#`0`B
M````>P,!`"(```">`P$`(````,$#`0!!````X@,!`%L````D!`$`20```(`$
M`0`=````R@0!`!@```#H!`$`(0````$%`0`?````(P4!`"L```!#!0$`(0``
M`&\%`0`=````D04!`!$```"O!0$`,P```,$%`0`E````]04!`"<````;!@$`
M'P```$,&`0`P````8P8!`&D```"4!@$`/0```/X&`0!E````/`<!`$T```"B
M!P$`+P```/`'`0`N````(`@!`"D```!/"`$`+````'D(`0!4````I@@!`%H`
M``#["`$`*````%8)`0`F````?PD!`$@```"F"0$`2@```.\)`0`K````.@H!
M`!X```!F"@$`,@```(4*`0`O````N`H!`"P```#H"@$`+0```!4+`0!Q````
M0PL!`&\```"U"P$`LP```"4,`0`7````V0P!`"4```#Q#`$`,@```!<-`0`I
M````2@T!`#X```!T#0$`(@```+,-`0!2````U@T!`"(````I#@$`)0```$P.
M`0`+````<@X!`+$```!^#@$`10```#`/`0`A````=@\!`#````"8#P$`)0``
M`,D/`0`<````[P\!`#$````,$`$`!P```#X0`0`'````1A`!``0```!.$`$`
M#0```%,0`0`+````81`!``X```!M$`$`"P```'P0`0`%````B!`!`!````".
M$`$``@```)\0`0!9````HA`!``4```#\$`$`$@````(1`0`$````%1$!``<`
M```:$0$`"````"(1`0`%````*Q$!``,````Q$0$`$````#41`0`,````1A$!
M`!,```!3$0$`#0```&<1`0`"````=1$!``<```!X$0$`!@```(`1`0`4````
MAQ$!``P```"<$0$`&````*D1`0`&````PA$!`!(```#)$0$`#````-P1`0`#
M````Z1$!`"H```#M$0$`!````!@2`0`&````'1(!``<````D$@$`'P```"P2
M`0`U````3!(!`"X```""$@$`+P```+$2`0`7````X1(!`"````#Y$@$`&P``
M`!H3`0`8````-A,!`"0```!/$P$`'P```'03`0`:````E!,!`"````"O$P$`
M&@```-`3`0`R````ZQ,!`!D````>%`$`+P```#@4`0`K````:!0!`!\```"4
M%`$`(P```+04`0`?````V!0!`!H```#X%`$`)0```!,5`0`F````.14!`"4`
M``!@%0$`)````(85`0`8````JQ4!`!T```#$%0$`)````.(5`0`8````!Q8!
M`"(````@%@$`)0```$,6`0`\````:18!`!\```"F%@$`(P```,86`0`?````
MZA8!`"`````*%P$`&@```"L7`0`8````1A<!`"8```!?%P$`'@```(87`0`I
M````I1<!`!X```#/%P$`"0```.X7`0`,````^!<!`!<````%&`$`+P```!T8
M`0`D````31@!``<```!R&`$`#P```'H8`0`4````BA@!``X```"?&`$`#0``
M`*X8`0`D````O!@!``4```#A&`$`!P```.<8`0`B````[Q@!`"4````2&0$`
M'0```#@9`0`:````5AD!``<```!Q&0$`QP```'D9`0`+````01H!`!4```!-
M&@$`!@```&,:`0`)````:AH!``L```!T&@$`%P```(`:`0`&````F!H!`#,`
M``"?&@$`$P```-,:`0`3````YQH!``<```#[&@$`#P````,;`0`'````$QL!
M`#(````;&P$`(0```$X;`0`3````<!L!``P```"$&P$`$0```)$;`0`R````
MHQL!``@```#6&P$`"0```-\;`0`*````Z1L!`!0```#T&P$`"@````D<`0`=
M````%!P!``@````R'`$`'P```#L<`0`(````6QP!`!H```!D'`$`!@```'\<
M`0`5````AAP!``<```"<'`$`"````*0<`0`)````K1P!`#\```"W'`$`!P``
M`/<<`0`/````_QP!``X````/'0$`$````!X=`0`)````+QT!``D````Y'0$`
M"````$,=`0`3````3!T!``<```!@'0$`&0```&@=`0`*````@AT!`!<```"-
M'0$`%````*4=`0`*````NAT!``P```#%'0$`%P```-(=`0`$````ZAT!`"H`
M``#O'0$`$0```!H>`0`'````+!X!``(````T'@$`$````#<>`0`8````2!X!
M``L```!A'@$``P```&T>`0`(````<1X!``8```!Z'@$`!P```($>`0`-````
MB1X!``L```"7'@$`%````*,>`0`5````N!X!``X```#.'@$`+P```-T>`0`@
M````#1\!`!P````N'P$`*P```$L?`0`,````=Q\!`#$```"$'P$`!0```+8?
M`0`2````O!\!`#\```#/'P$`$@````\@`0`*````(B`!``8````M(`$`!```
M`#0@`0`$````.2`!`!,````^(`$`!0```%(@`0`&````6"`!``8```!?(`$`
M!````&8@`0`,````:R`!``H```!X(`$`!0```(,@`0`8````B2`!`!D```"B
M(`$`'P```+P@`0`=````W"`!`!$```#Z(`$``@````PA`0`$````#R$!``H`
M```4(0$`!@```!\A`0`%````)B$!``,````L(0$`#````#`A`0!%````/2$!
M`!H```"#(0$`-0```)XA`0`H````U"$!`%,```#](0$`,@```%$B`0`9````
MA"(!`'(```">(@$`(````!$C`0`U````,B,!`$4```!H(P$`,````*XC`0`H
M````WR,!`"@````()`$`*0```#$D`0`F````6R0!`"4```"")`$`*````*@D
M`0`H````T20!`"(```#Z)`$`,````!TE`0`2````3B4!`!,```!A)0$`$```
M`'4E`0!Y````AB4!``D`````)@$`<P````HF`0!\````?B8!`"L```#[)@$`
M%P```"<G`0`6````/R<!`!4```!6)P$`#P```&PG`0`?````?"<!``X```"<
M)P$`'P```*LG`0`<````RR<!`%$```#H)P$`%````#HH`0`*````3R@!``4`
M``!:*`$`!@```&`H`0`(````9R@!``4```!P*`$`$@```'8H`0`0````B2@!
M`!,```":*`$`'0```*XH`0`/````S"@!``\```#<*`$`$````.PH`0`$````
M_2@!``D````"*0$`"0````PI`0`'````%BD!``L````>*0$`!0```"HI`0`+
M````,"D!``<````\*0$`!0```$0I`0`4````2BD!``X```!?*0$`"P```&XI
M`0`'````>BD!``@```""*0$`#P```(LI`0`,````FRD!``D```"H*0$`"```
M`+(I`0`,````NRD!``8```#(*0$`#P```,\I`0`'````WRD!``8```#G*0$`
M%````.XI`0`&`````RH!``P````**@$`"````!<J`0`$````("H!``H````E
M*@$`!P```#`J`0`$````."H!`!D````]*@$``@```%<J`0`)````6BH!``8`
M``!D*@$`!@```&LJ`0`G````<BH!``0```":*@$`#P```)\J`0`3````KRH!
M``<```##*@$`"0```,LJ`0`'````U2H!``8```#=*@$`!@```.0J`0`0````
MZRH!`!(```#\*@$`!@````\K`0`)````%BL!`"(````@*P$`!P```$,K`0`'
M````2RL!``L```!3*P$`!0```%\K`0`%````92L!``(```!K*P$`"P```&XK
M`0!C`0``>BL!`!,```#>+`$`#P```/(L`0`*`````BT!``L````-+0$`!```
M`!DM`0`+````'BT!``L````J+0$`$P```#8M`0`.````2BT!``\```!9+0$`
M!0```&DM`0`H````;RT!``X```"8+0$`&0```*<M`0`.````P2T!``L```#0
M+0$`(@```-PM`0`-````_RT!``H````-+@$`$0```!@N`0`0````*BX!``X`
M```[+@$`"P```$HN`0`0````5BX!``\```!G+@$`!@```'<N`0`2````?BX!
M`!@```"1+@$`$````*HN`0`)````NRX!``\```#%+@$`#P```-4N`0`'````
MY2X!`"X```#M+@$`*````!PO`0`^````12\!`$T```"$+P$`:````-(O`0!K
M````.S`!`&X```"G,`$`<0```!8Q`0!`````B#$!`!0```#),0$`!0```-XQ
M`0`&````Y#$!`!````#K,0$`!P```/PQ`0`)````!#(!``D````.,@$`,@``
M`!@R`0`P````2S(!`"X```!\,@$`,0```*LR`0`P````W3(!`"T````.,P$`
M$0```#PS`0`1````3C,!``X```!@,P$`"0```&\S`0`5````>3,!`!4```"/
M,P$`#P```*4S`0`6````M3,!`!4```#,,P$`&P```.(S`0`3````_C,!``\`
M```2-`$`%@```"(T`0`.````.30!`"T```!(-`$`%P```'8T`0`;````CC0!
M`!,```"J-`$`'````+XT`0`J````VS0!``4````&-0$`"0````PU`0`Q````
M%C4!``8```!(-0$`#````$\U`0`*````7#4!``<```!G-0$`"````&\U`0`%
M````>#4!``D```!^-0$`"P```(@U`0`$````E#4!`"````"9-0$`#````+HU
M`0`,````QS4!`!````#4-0$`&@```.4U`0`L`````#8!``H````M-@$`'```
M`#@V`0`;````538!`"````!Q-@$`%P```)(V`0`6````JC8!`!,```#!-@$`
M$````-4V`0`?````YC8!``<````&-P$`!@````XW`0`(````%3<!``X````>
M-P$`"````"TW`0`*````-C<!`!(```!!-P$`"@```%0W`0`5````7S<!`!@`
M``!U-P$`"@```(XW`0`%````F3<!`!<```"?-P$`%@```+<W`0`+````SC<!
M`$(```#:-P$`"@```!TX`0`'````*#@!`!,````P.`$`!0```$0X`0`%````
M2C@!``D```!0.`$`$````%HX`0`+````:S@!`!4```!W.`$`10```(TX`0`1
M````TS@!`#(```#E.`$`,0```!@Y`0`N````2CD!`"\```!Y.0$`"@```*DY
M`0`(````M#D!``D```"].0$`"@```,<Y`0`R````TCD!`#@````%.@$`,0``
M`#XZ`0!7````<#H!`#````#(.@$`,````/DZ`0`P````*CL!`$8```!;.P$`
M-````*([`0`S````USL!`#`````+/`$`-@```#P\`0`5````<SP!`!D```")
M/`$`+@```*,\`0`D````TCP!`!@```#W/`$`$P```!`]`0`,````)#T!``P`
M```Q/0$`%@```#X]`0`?````53T!``L```!U/0$`$````($]`0`8````DCT!
M`!T```"K/0$`!P```,D]`0`'````T3T!`!8```#9/0$`"@```/`]`0`(````
M^ST!``D````$/@$`"P````X^`0`&````&CX!``8````A/@$`!0```"@^`0`'
M````+CX!``8````V/@$`"@```#T^`0`L````2#X!`!````!U/@$`"````(8^
M`0`#````CSX!``<```"3/@$`"0```)L^`0`$````I3X!``H```"J/@$`!@``
M`+4^`0`5````O#X!``8```#2/@$`"````-D^`0`)````XCX!``T```#L/@$`
M"````/H^`0`A`````S\!`!$````E/P$`"0```#<_`0`1````03\!``P```!3
M/P$`!P```&`_`0`#````:#\!``,```!L/P$`%0```'`_`0`#````AC\!`!0`
M``"*/P$`!@```)\_`0`$````IC\!``@```"K/P$`"````+0_`0!2````O3\!
M`"8````00`$`!@```#=``0`(````/D`!`!@```!'0`$`(@```&!``0`E````
M@T`!`#````"I0`$`)````-I``0`J````_T`!`'H````J00$`-0```*5!`0`*
M````VT$!``D```#F00$`%0```/!!`0`)````!D(!``\````00@$`#0```"!"
M`0`0````+D(!`!$````_0@$`$````%%"`0`.````8D(!``T```!Q0@$`%@``
M`']"`0`&````ED(!`!T```"=0@$`'@```+M"`0`2````VD(!`!$```#M0@$`
M!@```/]"`0`(````!D,!`&$````/0P$`+0```'%#`0`(````GT,!`!,```"H
M0P$`!0```+Q#`0`%````PD,!`!X```#(0P$`&P```.=#`0`3`````T0!`!<`
M```71`$`$P```"]$`0`L````0T0!`$\```!P1`$`&P```,!$`0`0````W$0!
M`"0```#M1`$`!@```!)%`0`-````&44!`!0````G10$`$0```#Q%`0`-````
M3D4!`!(```!<10$`%@```&]%`0`3````AD4!``P```":10$`!@```*=%`0`'
M````KD4!`!@```"V10$`$0```,]%`0`(````X44!``4```#J10$`#0```/!%
M`0`-````_D4!``D````,1@$`"P```!9&`0`&````(D8!``@````I1@$`#0``
M`#)&`0`)````0$8!``T```!*1@$`!P```%A&`0`'````8$8!``D```!H1@$`
M"0```')&`0`;````?$8!``\```"81@$`$P```*A&`0`%````O$8!`"@```#"
M1@$`$P```.M&`0`4````_T8!`#@````41P$`1P```$U'`0`B````E4<!`#4`
M``"X1P$`"````.Y'`0`-````]T<!``8````%2`$`"`````Q(`0`0````%4@!
M``H````F2`$`"0```#%(`0`=````.T@!`"(```!92`$`(````'Q(`0`E````
MG4@!`!P```##2`$`+0```.!(`0`?````#DD!`",````N20$`'````%))`0`?
M````;TD!`!X```"/20$`*0```*Y)`0`R````V$D!`"0````+2@$`*P```#!*
M`0`W````7$H!`#T```"42@$`$P```-)*`0`H````YDH!`!(````/2P$`Q```
M`")+`0`4````YTL!`!X```#\2P$`)0```!M,`0`G````04P!`",```!I3`$`
M(@```(U,`0`A````L$P!`"0```#23`$`(P```/=,`0`<````&TT!`"<````X
M30$`1P```&!-`0`-````J$T!``0```"V30$`"0```+M-`0`%````Q4T!``T`
M``#+30$`#P```-E-`0`.````Z4T!``<```#X30$`#P````!.`0`0````$$X!
M``<````A3@$`!````"E.`0`,````+DX!``X````[3@$`"P```$I.`0`2````
M5DX!``T```!I3@$`+@```'=.`0`'````IDX!`!````"N3@$`!@```+].`0`3
M````QDX!`!D```#:3@$`&P```/1.`0`5````$$\!``(````F3P$`"0```"E/
M`0`0````,T\!``4```!$3P$`#P```$I/`0`.````6D\!``,```!I3P$`$```
M`&U/`0`(````?D\!`!$```"'3P$`%0```)E/`0`/````KT\!`!0```"_3P$`
M%0```-1/`0`:````ZD\!`!H````%4`$`"@```"!0`0`+````*U`!`!$````W
M4`$`$0```$E0`0`:````6U`!``T```!V4`$`#P```(10`0`I````E%`!``T`
M``"^4`$`)````,Q0`0`:````\5`!`!@````,40$`"P```"51`0`*````,5$!
M``@````\40$`%@```$51`0`,````7%$!``T```!I40$`)````'=1`0`M````
MG%$!``P```#*40$`"````-=1`0`A````X%$!``H````"4@$`&0````U2`0`:
M````)U(!``D```!"4@$`%0```$Q2`0`.````8E(!`!T```!Q4@$`#P```(]2
M`0`9````GU(!``@```"Y4@$`$````,)2`0`F````TU(!`#T```#Z4@$`"```
M`#A3`0`6````05,!``H```!84P$`#0```&-3`0`R````<5,!``\```"D4P$`
M!0```+13`0`&````NE,!``,```#!4P$`!P```,53`0`(````S5,!``T```#6
M4P$`#@```.13`0`0````\U,!``X````$5`$`$````!-4`0`9````)%0!`!4`
M```^5`$`%P```%14`0`)````;%0!``8```!V5`$`"P```'U4`0`*````B50!
M``(```"45`$`!@```)=4`0`+````GE0!`",```"J5`$`%@```,Y4`0`)````
MY50!``P```#O5`$`#0```/Q4`0`/````"E4!``\````:50$`/@```"I5`0`F
M````:54!``@```"050$`#P```)E5`0"+````J54!`!X````U5@$`$@```%16
M`0`'````9U8!``0```!O5@$`%P```'16`0`'````C%8!``@```"45@$`!P``
M`)U6`0`&````I58!``\```"L5@$`#@```+Q6`0`0````RU8!``X```#<5@$`
M#P```.M6`0`,````^U8!``L````(5P$`$0```!17`0`)````)E<!``H````P
M5P$`#@```#M7`0`N````2E<!``L```!Y5P$`"````(57`0`*````CE<!`!,`
M``"95P$`#@```*U7`0`4````O%<!`!````#15P$`)@```.)7`0`I````"5@!
M`"@````S6`$`'0```%Q8`0`>````>E@!`"P```"96`$`(0```,98`0`$````
MZ%@!`!P```#M6`$`#P````I9`0`#````&ED!``@````>60$`"0```"=9`0`+
M````,5D!``P````]60$`!````$I9`0`<````3UD!`!X```!L60$`#0```(M9
M`0`,````F5D!``X```"F60$`#0```+59`0`G````PUD!``<```#K60$`!P``
M`/-9`0`,````^UD!``\````(6@$`%0```!A:`0`'````+EH!``<````V6@$`
M!````#Y:`0`3````0UH!``D```!76@$`!P```&%:`0`P````:5H!`!<```":
M6@$`@@```+):`0`7````-5L!``L```!-6P$`!P```%E;`0`+````85L!``@`
M``!M6P$`"@```'9;`0`&````@5L!``H```"(6P$``@```)-;`0`&````EEL!
M``D```"=6P$`&0```*=;`0`,````P5L!``\```#.6P$`'````-Y;`0`#````
M^UL!``<```#_6P$`%@````=<`0`*````'EP!``X````I7`$`!0```#A<`0`S
M````/EP!``8```!R7`$`!@```'E<`0`8````@%P!`!$```"97`$`!P```*M<
M`0`)````LUP!``4```"]7`$`"0```,-<`0`(````S5P!``(```#67`$`!@``
M`-E<`0`-````X%P!``L```#N7`$`"P```/I<`0`3````!ET!``D````:70$`
M!P```"1=`0`,````+%T!`!\````Y70$`!P```%E=`0`*````85T!``0```!L
M70$`"0```'%=`0`(````>UT!``P```"$70$`"@```)%=`0`&````G%T!``T`
M``"C70$`!@```+%=`0`$````N%T!`$````"]70$`1````/Y=`0!"````0UX!
M`"$```"&7@$`!0```*A>`0`/````KEX!``4```"^7@$``P```,1>`0`A````
MR%X!`!@```#J7@$`!@````-?`0`$````"E\!`!L````/7P$`!@```"M?`0`(
M````,E\!`"(````[7P$`!````%Y?`0`%````8U\!`!<```!I7P$`!````(%?
M`0`-````AE\!``\```"47P$`"````*1?`0`)````K5\!``4```"W7P$`/0``
M`+U?`0`V````^U\!`#L````R8`$`*@```&Y@`0`X````F6`!`#H```#28`$`
M+0````UA`0!2````.V$!`#````".80$`.0```+]A`0`I````^6$!`!`````C
M8@$`&````#1B`0`,````36(!`"0```!:8@$`)````']B`0`B````I&(!`"$`
M``#'8@$`"P```.EB`0`-````]6(!``H````#8P$`"0````YC`0`B````&&,!
M`"@````[8P$`*````&1C`0`(````C6,!`!H```"68P$`,P```+%C`0`8````
MY6,!`!(```#^8P$`!P```!%D`0`3````&60!`!8````M9`$`$````$1D`0!1
M````560!`)$```"G9`$`A````#EE`0`7````OF4!``X```#690$`#P```.5E
M`0`4````]64!`!4````*9@$`$0```"!F`0`,````,F8!`!P````_9@$`$P``
M`%QF`0`>````<&8!`!4```"/9@$`%0```*5F`0`/````NV8!`"(```#+9@$`
M*0```.YF`0"-````&&<!`!0```"F9P$`!0```+MG`0`6````P6<!``D```#8
M9P$`!````.)G`0`*````YV<!`!$```#R9P$`$P````1H`0`.````&&@!`!``
M```G:`$`%````#AH`0`G````36@!`"D```!U:`$`)0```)]H`0`E````Q6@!
M`#````#K:`$`,````!QI`0`=````36D!`$4```!K:0$`#P```+%I`0`1````
MP6D!`!$```#3:0$`$P```.5I`0`2````^6D!`!4````,:@$`%P```")J`0`/
M````.FH!`!$```!*:@$`.0```%QJ`0`=````EFH!`!<```"T:@$`.@```,QJ
M`0`3````!VL!``<````;:P$`#0```"-K`0`B````,6L!`!4```!4:P$`$@``
M`&IK`0`9````?6L!`!D```"7:P$`%````+%K`0`2````QFL!`!X```#9:P$`
M)````/AK`0`6````'6P!`!(````T;`$`%P```$=L`0`3````7VP!`!<```!S
M;`$`"@```(ML`0`@````EFP!``0```"W;`$`!P```+QL`0`*````Q&P!`!@`
M``#/;`$`!@```.AL`0`(````[VP!``<```#X;`$`!@````!M`0`'````!VT!
M``<````/;0$`!0```!=M`0`4````'6T!``8````R;0$`"````#EM`0`$````
M0FT!``0```!';0$`"0```$QM`0`5````5FT!`!(```!L;0$`#P```']M`0`0
M````CVT!``H```"@;0$`$P```*MM`0`%````OVT!`"<```#%;0$`#@```.UM
M`0`-````_&T!`!,````*;@$`#0```!YN`0`+````+&X!``X````X;@$`,P``
M`$=N`0`(````>VX!``@```"$;@$`)P```(UN`0`4````M6X!`!$```#*;@$`
M!P```-QN`0`)````Y&X!``<```#N;@$`!````/9N`0`@````^VX!``T````<
M;P$`$````"IO`0`0````.V\!`!(```!,;P$`%@```%]O`0`=````=F\!`!D`
M``"4;P$`!P```*YO`0`'````MF\!``8```"^;P$`&````,5O`0`'````WF\!
M``4```#F;P$`"@```.QO`0`.````]V\!``<````&<`$`!P````YP`0`=````
M%G`!``T````T<`$`#````$)P`0`,````3W`!`!(```!<<`$`#````&]P`0`/
M````?'`!`!<```",<`$`#0```*1P`0`0````LG`!``@```##<`$`!````,QP
M`0`0````T7`!`$$```#B<`$`!0```"1Q`0`,````*G$!`"$````W<0$`#0``
M`%EQ`0`9````9W$!``H```"!<0$`#0```(QQ`0`*````FG$!``@```"E<0$`
M#@```*YQ`0`*````O7$!`!$```#(<0$`$@```-IQ`0`O````[7$!``H````=
M<@$`"````"AR`0`(````,7(!``P````Z<@$`%@```$=R`0`'````7G(!``D`
M``!F<@$`"````'!R`0`,````>7(!`$X```"&<@$`$P```-5R`0`+````Z7(!
M``8```#U<@$`!````/QR`0`6`````7,!`!<````8<P$`&````#!S`0`)````
M27,!``(```!3<P$`!````%9S`0`B````6W,!``,```!^<P$`!0```()S`0`S
M````B',!``H```"\<P$`!0```,=S`0`&````S7,!``T```#4<P$`#0```.)S
M`0`&````\',!``@```#W<P$`"0````!T`0`$````"G0!``4````/=`$`8@``
M`!5T`0`+````>'0!``T```"$=`$`!0```))T`0`%````F'0!`"8```">=`$`
M-P```,5T`0`1````_70!``H````/=0$`%0```!IU`0`*````,'4!``D````[
M=0$`'````$5U`0`G````8G4!`"T```"*=0$`+````+AU`0`/````Y74!``,`
M``#U=0$`!P```/EU`0`+`````78!``4````-=@$`#````!-V`0`*````('8!
M`!(````K=@$`!P```#YV`0!I````1G8!`!$```"P=@$`"P```,)V`0`*````
MSG8!`!\```#9=@$`30```/EV`0`'````1W<!``@```!/=P$`!@```%AW`0`?
M````7W<!``8```!_=P$`"0```(9W`0`M````D'<!`"P```"^=P$`!@```.MW
M`0`*````\G<!`"4```#]=P$`80```"-X`0`6````A7@!`"@```"<>`$`%0``
M`,5X`0`"````VW@!``X```#>>`$`"0```.UX`0`/````]W@!``H````'>0$`
M"P```!)Y`0`'````'GD!`!<````F>0$`!@```#YY`0`(````17D!``T```!.
M>0$`"P```%QY`0`*````:'D!``D```!S>0$`!P```'UY`0`6````A7D!`!0`
M``"<>0$`$P```+%Y`0`,````Q7D!``H```#2>0$`"P```-UY`0`*````Z7D!
M``P```#T>0$`"@````%Z`0`*````#'H!`!T````7>@$`%````#5Z`0`,````
M2GH!``T```!7>@$`#````&5Z`0`2````<GH!``4```"%>@$`)0```(MZ`0`$
M````L7H!``<```"V>@$`!0```+YZ`0`%````Q'H!``D```#*>@$`$P```-1Z
M`0`2````Z'H!`!H```#[>@$`%@```!9[`0`8````+7L!`!<```!&>P$`%P``
M`%Y[`0`>````=GL!`!@```"5>P$`!P```*Y[`0`%````MGL!``\```"\>P$`
M$````,Q[`0`+````W7L!``X```#I>P$`(0```/A[`0`-````&GP!`!4````H
M?`$`!@```#Y\`0`-````17P!``@```!3?`$`#P```%Q\`0`)````;'P!``4`
M``!V?`$`!P```'Q\`0`%````A'P!``0```"*?`$``P```(]\`0`_````DWP!
M`#D```#3?`$`$P````U]`0`L````(7T!`#(```!.?0$`$0```(%]`0`Z````
MDWT!`"X```#.?0$`,P```/U]`0`S````,7X!`#L```!E?@$`$@```*%^`0`:
M````M'X!`!4```#/?@$`'0```.5^`0`6`````W\!`!0````:?P$`*P```"]_
M`0`-````6W\!`#@```!I?P$`&P```*)_`0`5````OG\!`!D```#4?P$`,@``
M`.Y_`0`R````(8`!`#4```!4@`$`,P```(J``0`T````OH`!`#$```#S@`$`
M:P```"6!`0`=````D8$!``X```"O@0$`"P```+Z!`0`P````RH$!`"\```#[
M@0$`(P```"N"`0`,````3X(!`$D```!<@@$`0@```*:"`0`(````Z8(!``0`
M``#R@@$`$````/>"`0`<````"(,!``X````E@P$`$P```#2#`0`(````2(,!
M``D```!1@P$`!P```%N#`0`)````8X,!``X```!M@P$`%0```'R#`0`.````
MDH,!`!$```"A@P$`$````+.#`0`.````Q(,!``X```#3@P$`#````.*#`0`-
M````[X,!`!8```#]@P$`#````!2$`0`0````(80!``T````RA`$`"````$"$
M`0`3````280!`!P```!=A`$`"````'J$`0`%````@X0!`!````")A`$`#P``
M`)J$`0`,````JH0!`#\```"WA`$``@```/>$`0`&````^H0!``X````!A0$`
M!@```!"%`0`'````%X4!`!`````?A0$`!P```#"%`0`$````.(4!`#$````]
MA0$`&P```&^%`0`B````BX4!`%@```"NA0$`&`````>&`0!(````((8!`",`
M``!IA@$`$````(V&`0`&````GH8!``X```"EA@$`#P```+2&`0`,````Q(8!
M`!,```#1A@$`"P```.6&`0`=````\88!`!H````/AP$`!@```"J'`0`1````
M,8<!``T```!#AP$`#P```%&'`0`F````88<!`!D```"(AP$`$P```**'`0`4
M````MH<!`"````#+AP$`"````.R'`0`)````]8<!`!D```#_AP$`$@```!F(
M`0`9````+(@!``H```!&B`$`#````%&(`0`(````7H@!``4```!GB`$`'0``
M`&V(`0`&````BX@!`!(```"2B`$`"````*6(`0`4````KH@!``H```##B`$`
M$@```,Z(`0`P````X8@!`!H````2B0$`"P```"V)`0`,````.8D!`"$```!&
MB0$`!P```&B)`0`6````<(D!``,```"'B0$`&````(N)`0`&````I(D!``<`
M``"KB0$`(0```+.)`0`Q````U8D!``4````'B@$`$0````V*`0`'````'XH!
M``T````GB@$`%P```#6*`0`$````38H!``H```!2B@$`#````%V*`0`(````
M:HH!``8```!SB@$`"````'J*`0`&````@XH!``H```"*B@$`%P```)6*`0`T
M````K8H!`#0```#BB@$`(@```!>+`0`S````.HL!`"````!NBP$`1P```(^+
M`0`=````UXL!`"X```#UBP$`+````"2,`0`E````48P!``4```!WC`$`"```
M`'V,`0`)````AHP!``@```"0C`$`(0```)F,`0`<````NXP!`#````#8C`$`
M(P````F-`0`Q````+8T!`#8```!?C0$`"0```):-`0`8````H(T!``L```"Y
MC0$`"@```,6-`0`K````T(T!``T```#\C0$`$@````J.`0`-````'8X!``@`
M```KC@$`%````#2.`0`)````28X!``P```!3C@$`$````&".`0`;````<8X!
M`"P```"-C@$`"P```+J.`0`&````QHX!``4```#-C@$`'0```-..`0`4````
M\8X!``4````&CP$`"P````R/`0`*````&(\!``@````CCP$`#@```"R/`0`*
M````.X\!``4```!&CP$`#@```$R/`0!%````6X\!`&(```"ACP$`'`````20
M`0`C````(9`!``\```!%D`$`&0```%60`0`%````;Y`!`!0```!UD`$`"P``
M`(J0`0`2````EI`!`"X```"ID`$`"P```-B0`0`0````Y)`!`!4```#UD`$`
M$0````N1`0`2````'9$!`!`````PD0$`20```$&1`0`,````BY$!`"0```"8
MD0$`%0```+V1`0`7````TY$!`#T```#KD0$`"@```"F2`0`0````-)(!`!,`
M``!%D@$`"@```%F2`0`1````9)(!``<```!VD@$`&````'Z2`0`7````EY(!
M``@```"OD@$`!@```+B2`0`+````OY(!``\```#+D@$`%````-N2`0`#````
M\)(!``@```#TD@$`"P```/V2`0`2````"9,!`!,````<DP$`$0```#"3`0`1
M````0I,!``8```!4DP$`"0```%N3`0`W````99,!`#````"=DP$`+0```,Z3
M`0`'````_),!`!,````$E`$`!@```!B4`0`C````'Y0!`!@```!#E`$`)P``
M`%R4`0`-````A)0!``D```"2E`$``P```)R4`0`&````H)0!``H```"GE`$`
M`@```+*4`0`)````M90!`!$```"_E`$`"````-&4`0`5````VI0!`!L```#P
ME`$`%`````R5`0`%````(94!``H````GE0$`%````#*5`0`1````1Y4!``P`
M``!9E0$`!P```&:5`0`*````;I4!``X```!YE0$`70```(B5`0`:````YI4!
M``H````!E@$`!@````R6`0`,````$Y8!``X````@E@$`"@```"^6`0`-````
M.I8!``X```!(E@$`$P```%>6`0`D````:Y8!`!T```"0E@$`&0```*Z6`0`4
M````R)8!`"@```#=E@$`(`````:7`0`4````)Y<!`'0````\EP$`(P```+&7
M`0`;````U9<!`!P```#QEP$`'`````Z8`0`J````*Y@!`"P```!6F`$`(@``
M`(.8`0`;````II@!`"4```#"F`$`&0```.B8`0`;`````ID!`!H````>F0$`
M&0```#F9`0`+````4YD!``<```!?F0$`"````&>9`0`)````<)D!`!0```!Z
MF0$`"P```(^9`0`3````FYD!``D```"OF0$`7@```+F9`0!'````&)H!`#@`
M``!@F@$`6P```)F:`0`A````]9H!`#(````7FP$`"@```$J;`0`(````59L!
M`!(```!>FP$`/P```'&;`0`)````L9L!`!P```"[FP$`:````-B;`0`P````
M09P!`!L```!RG`$`)P```(Z<`0`G````MIP!`!````#>G`$`(@```.^<`0`D
M````$IT!`"X````WG0$`*P```&:=`0`N````DIT!`#$```#!G0$`$````/.=
M`0`%````!)X!``L````*G@$`"@```!:>`0`*````(9X!`"P````LG@$`#```
M`%F>`0`)````9IX!``P```!PG@$`%P```'V>`0`)````E9X!``<```"?G@$`
M$P```*>>`0`)````NYX!``@```#%G@$`!@```,Z>`0`+````U9X!``L```#A
MG@$`$````.V>`0`.````_IX!`!L````-GP$`$````"F?`0`'````.I\!`!4`
M``!"GP$`%0```%B?`0`8````;I\!`!@```"'GP$`"0```*"?`0`+````JI\!
M`!H```"VGP$`*0```-&?`0`2````^Y\!`"4````.H`$`)P```#2@`0`/````
M7*`!``H```!LH`$`&@```'>@`0`&````DJ`!``0```"9H`$`&````)Z@`0`.
M````MZ`!`!````#&H`$`#@```->@`0`%````YJ`!``D```#LH`$`"0```/:@
M`0`)`````*$!``D````*H0$`$@```!2A`0`&````)Z$!``T````NH0$`!0``
M`#RA`0`)````0J$!``L```!,H0$`&@```%BA`0`+````<Z$!``(```!_H0$`
M"0```(*A`0`*````C*$!``D```"7H0$`!@```*&A`0!$````J*$!`"H```#M
MH0$`&````!BB`0`&````,:(!``P````XH@$`"@```$6B`0`-````4*(!``8`
M``!>H@$`"@```&6B`0`8````<*(!``P```")H@$`#0```):B`0`/````I*(!
M``L```"TH@$`#0```,"B`0`(````SJ(!``H```#7H@$`&````.*B`0`)````
M^Z(!``8````%HP$`"P````RC`0`8````&*,!`!P````QHP$`"@```$ZC`0`,
M````6:,!``L```!FHP$`!0```'*C`0`2````>*,!`!(```"+HP$`!@```)ZC
M`0`;````I:,!``P```#!HP$`(0```,ZC`0`%````\*,!``4```#VHP$`#@``
M`/RC`0`C````"Z0!``L````OI`$`#0```#ND`0`.````2:0!``4```!8I`$`
M#````%ZD`0`/````:Z0!``X```![I`$``@```(JD`0`/````C:0!``@```"=
MI`$`*P```*:D`0`D````TJ0!`"\```#WI`$`*````">E`0`H````4*4!`%T`
M``!YI0$`$P```->E`0!9````ZZ4!`#0```!%I@$`7@```'JF`0!;````V:8!
M`"8````UIP$`/0```%RG`0`S````FJ<!`#<```#.IP$`-0````:H`0`>````
M/*@!`#L```!;J`$`Y`$``)>H`0`A````?*H!`!0```">J@$`5````+.J`0""
M````"*L!`$(```"+JP$`&0```,ZK`0`S````Z*L!`",````<K`$`(P```$"L
M`0`C````9*P!`#\```"(K`$`<@```,BL`0!2````.ZT!`"````".K0$`%0``
M`*^M`0`=````Q:T!`!T```#CK0$`+0````&N`0`>````+ZX!`!T```!.K@$`
M$P```&RN`0`Z````@*X!`"@```"[K@$`*0```.2N`0`8````#J\!`$`````G
MKP$`:0```&BO`0`Z````TJ\!`&,````-L`$`3````'&P`0`R````OK`!`"T`
M``#QL`$`*P```!^Q`0`N````2[$!`%0```!ZL0$`6P```,^Q`0`S````*[(!
M`"\```!?L@$`30```(^R`0!1````W;(!`#4````OLP$`*````&6S`0`T````
MCK,!`"X```##LP$`+@```/*S`0`N````(;0!`(@```!0M`$`A@```-FT`0#0
M````8+4!`!,````QM@$`)@```$6V`0`Y````;+8!`"P```"FM@$`2````-.V
M`0`K````'+<!`$P```!(MP$`*P```)6W`0`@````P;<!``H```#BMP$`P0``
M`.VW`0!'````K[@!`"8```#WN`$`-0```!ZY`0`G````5+D!`"0```!\N0$`
M/@```*&Y`0`&````X+D!``<```#GN0$`!````.^Y`0`,````]+D!``L````!
MN@$`#`````VZ`0`+````&KH!``4````FN@$`$````"RZ`0`#````/;H!`&<`
M``!!N@$`!P```*FZ`0`5````L;H!``0```#'N@$`!P```,RZ`0`&````U+H!
M``4```#;N@$`"0```.&Z`0`5````Z[H!``L````!NP$`$@````V[`0`-````
M(+L!``(````NNP$`!P```#&[`0`'````.;L!`!(```!!NP$`#````%2[`0`8
M````8;L!``8```!ZNP$`#@```(&[`0`,````D+L!``,```"=NP$`*P```*&[
M`0`$````S;L!``<```#2NP$`"````-J[`0`K````X[L!`$<````/O`$`.@``
M`%>\`0`[````DKP!`"(```#.O`$`+0```/&\`0`C````'[T!`"8```!#O0$`
M*@```&J]`0`E````E;T!`",```"[O0$`+````-^]`0`A````#+X!`#P````N
MO@$`*````&N^`0`Z````E+X!`#4```#/O@$`*P````6_`0`N````,;\!`"X`
M``!@OP$`*0```(^_`0`N````N;\!`"L```#HOP$`,````!3``0`N````1<`!
M`"D```!TP`$`*0```)[``0`S````R,`!`"0```#\P`$`+@```"'!`0`J````
M4,$!`$,```![P0$`*0```+_!`0`L````Z<$!`"P````6P@$`+0```$/"`0`G
M````<<(!`!T```"9P@$`*P```+?"`0`L````X\(!`#<````0PP$`+````$C#
M`0`,````=<,!`!,```""PP$`(````);#`0`Q````M\,!`"0```#IPP$`"0``
M``[$`0`/````&,0!`!P````HQ`$`%````$7$`0`0````6L0!`#$```!KQ`$`
M"````)W$`0`(````IL0!`",```"OQ`$`)@```-/$`0`G````^L0!`!\````B
MQ0$`"0```$+%`0#A````3,4!`!(````NQ@$`&@```$'&`0`)````7,8!``P`
M``!FQ@$`%````'/&`0`:````B,8!``8```"CQ@$`-P```*K&`0`5````XL8!
M`!<```#XQ@$`!P```!#'`0`3````&,<!``L````LQP$`/````#C'`0`K````
M=<<!`!````"AQP$`$````++'`0`5````P\<!`#0```#9QP$`#@````[(`0`/
M````'<@!`!`````MR`$`&@```#[(`0`+````6<@!`!L```!ER`$`"P```('(
M`0`D````C<@!``H```"RR`$`&P```+W(`0`'````V<@!`"<```#AR`$`!P``
M``G)`0`)````$<D!``D````;R0$`.P```"7)`0`&````8<D!``X```!HR0$`
M$P```'?)`0`6````B\D!``H```"BR0$`"````*W)`0`'````MLD!`!,```"^
MR0$`"P```-+)`0`<````WLD!``\```#[R0$`&`````O*`0`6````),H!``4`
M```[R@$`!P```$'*`0`7````2<H!``0```!AR@$`,P```&;*`0`0````FLH!
M``P```"KR@$``@```+C*`0`1````N\H!`"(```#-R@$`"P```/#*`0`#````
M_,H!``<`````RP$`"0````C+`0`&````$LL!``T````9RP$`"@```"?+`0`4
M````,LL!`!4```!'RP$`$0```%W+`0`V````;\L!`!X```"FRP$`&@```,7+
M`0`]````X,L!``L````>S`$`,P```"K,`0`'````7LP!`!<```!FS`$`2P``
M`'[,`0`4````RLP!``\```#?S`$`"````._,`0`$````^,P!``0```#]S`$`
M%@````+-`0`%````&<T!``8````?S0$`"````";-`0`$````+\T!``D````T
MS0$`#@```#[-`0`%````3<T!`!<```!3S0$`(````&O-`0`A````C,T!`"4`
M``"NS0$`$````-3-`0`"````Y<T!``0```#HS0$`"@```.W-`0`)````^,T!
M``4````"S@$``@````C.`0`?````"\X!`$X````KS@$`'@```'K.`0`S````
MF<X!`"H```#-S@$`8````/C.`0`U````6<\!`!````"/SP$`?````*#/`0`G
M````'=`!`%,```!%T`$`4@```)G0`0`X````[-`!`#@````ET0$`,P```%[1
M`0`T````DM$!`#D```#'T0$`.`````'2`0`_````.M(!`#\```!ZT@$`+0``
M`+K2`0`S````Z-(!``X````<TP$`#@```"O3`0`-````.M,!`(,```!(TP$`
M"````,S3`0"-````U=,!`(@```!CU`$`+@```.S4`0`4````&]4!`!@````P
MU0$`&0```$G5`0`2````8]4!`",```!VU0$`$0```)K5`0`:````K-4!`!@`
M``#'U0$`5@```.#5`0`6````-]8!``L```!.U@$`!0```%K6`0`&````8-8!
M``@```!GU@$`!0```'#6`0`;````=M8!`!$```"2U@$`'@```*36`0`?````
MP]8!`!$```#CU@$`!P```/76`0`7````_=8!``0````5UP$`"@```!K7`0`)
M````)=<!``P````OUP$`#@```#S7`0`)````2]<!``T```!5UP$`"````&/7
M`0`%````;-<!`!P```!RUP$`#@```(_7`0`3````GM<!``H```"RUP$`"0``
M`+W7`0`/````Q]<!`!,```#7UP$`#P```.O7`0`'````^]<!``@````#V`$`
M"@````S8`0`2````%]@!``<````JV`$`"@```#+8`0`6````/=@!``L```!4
MV`$`"0```&#8`0`(````:M@!``0```!SV`$`"0```'C8`0`&````@M@!``<`
M``")V`$`%P```)'8`0`"````J=@!``L```"LV`$`!@```+C8`0`'````O]@!
M`"T```#'V`$`!````/78`0`3````^M@!`!<````.V0$`"P```";9`0`)````
M,MD!``<````\V0$`!@```$39`0`(````2]D!`!````!4V0$`$@```&79`0`'
M````>-D!``H```"`V0$`,@```(O9`0`'````OMD!``D```#&V0$`$0```-#9
M`0`%````XMD!``4```#HV0$``@```.[9`0`+````\=D!``$```"H!@``^P(`
M``````#0````J@(```````"6`P``<P(``.4`````````708``-@$````````
M<P,``"L```#P!0``````````````````````````````````Q0```)@#``!Y
M!@```````.D"```K!@```@$```````!$`````````#,"``!F`@```````$``
M````````F`(``&D$``#3!0``)00``&0!``!^!@````````````#<`@``L@,`
M`"P$``#'`@``B0$``(,$``"V`P``)@4```T&```\!````````)\"``!+!```
M-`,``/$"``!``P``R`,``,<$``#_!0``-@8``$$"``"+`@```````(T%```V
M!0``XP```,\!``"Q`@``\`,``'<!```Z`0``PP,``!P"``"W!```$04``'X"
M```````````````````O!```@0```'<"``!J!```\@(```````"%`@``+`4`
M`#D$``!C!0````````X%````````$`8``(8$``!X`````````#4&```S!@``
M>P(```````!(!0``.`4``+0%``!K!0``NP$``!`!````````N`0``*0%```.
M!```?P``````````````3`,``*\"``">````JP```"\`````````U`(``*$%
M``"4!0``*@(``+<#``"@!0``BP$``,H"``!8!0``!`4``#`!``"K!```````
M`-0!``!Z`0``^04``,0```!`!```W`$``*(&````````GP8```````!]`@``
M[0```)T!```[!@```@8```````#N`P``3````&H&``!R````@`4``!P%````
M`````````&4#```'`P``M0```/\```!.!```_@$`````````````S````$T!
M```M!@``B`$``%`"``#I!0``J0,``*T```"L!```L@4``.H#````````C0,`
M`#0```!?!@``Q`,```````"[`@``_04```````````````````````"9`P``
M(@4```````!4!@``7P4``,(%``"?!```M04```````"<`@``504``$D#``#Q
M!0```````&H!``#K`P```````+8`````````=`4``&8$``!W!@``OP```*4!
M````````V`8``"8"````````EP(``/@#``!A!0``>0$``%$"````````N```
M`!L#``#!````*@8```$"``!#!@``A00``!T#````````+0```&<````]`P``
M``(``````````````````"D"`````````````.0````;!0``A0,````````?
M!0``+`,```````#^````B0(````%```N`@```````"P```#W!0``&0(``(H#
M``!Y````"@0``````````````````.,%``!B````"@````````!9`@``````
M`!8!````````9`(``)````!@`P```````(,"``"H`````````*,!``"2`P``
MC`$````````!!```````````````````U@0``-D&``!,`0``T`,``(<"``!0
M`0``O````'$!```H!````````%8%``!L!0``X@$``%L```"R!```;0$``.8%
M````````E0(```````!Y`P``]@`````````E`@``AP4```("````````RP8`
M`#X"``!=`@``+`(``-D"``!0!```@`0``*$```"`!@````````````#1!@``
MZ`4```````"(`@``YP,``)@%````````0`(``$,$``#,!```>`$``*D!``#2
M!```.04``.$!``"2!@``O0````````!O!@``/P0```````#1!0``9@4``-`%
M```^!````````*D$``#]`````````"D&```I!0``0`8``+D%``#N`@``W0``
M``````!@`0``JP(``.@#``!F!@```````(\"``!"`0``!0(``%@"``"P`P``
M?P$``+$```"4````7`0``)$"``!@!0```````$@$```8!0``4@,``/(```#Y
M`P``9@$```T!```````````````````&`0```````!$&````````^@``````
M```^````KP8``!T!``!;!@``70$``%,!``"(!````````+H`````````9P4`
M`!(&```]!``````````````Z!```3@```,D&``"Z!@```````'8&``"!`@``
M`````/P%````````,P$```X&```4`@``[P````````"=````LP0```````!.
M`0``M@(``%D`````````,`0``````````````````(X!``#W`@```````(4!
M``#-`0``&@0```````"E`P``X`,``-4%````````#`,````````%`0``````
M`!\$``"0!0``?@0``````````P````````````"/!@```````'@#``"3`0``
MP0$``&H```!<!@```````(P&```U!0``X0(``.0$``!*`````````"X$``#A
M!0```````.<```"[!@``SP4``*0"``#S!```ZP0``'4"```=!0``;P0``'0`
M```5`P``IP4``.4#``!0````_P0``*`$````!@``(08``!(#``"J`P``(P0`
M`)P!```$`@``!P0``%<!````````C0$``)X$`````````````&\"``!:`0``
M``````````"O`P``;``````````3````!P8``'8`````````>@,``.T%```<
M`0``+@$``&D"```$`````````'<%``#"`@``R0$``+H"``!Q!```Q@,`````
M```/!0```````,$%``#N!```1@4````````4`P```````&$"``#L`P``````
M``8```!"`````````*L!```H`@``:P$``&X%``"Q`P``?@4``$($``"X`0``
M@@0``)L#``!?`0```````%(%````````Q0$```````#J!0```````'X#``"[
M````-P```-(%```_!@``^P,``)4$``"\!0``0P4``)@&``#2`0``"00``&`"
M````````]@0``'````!F````LP8```````!*!0``8@$``/<````/!@``Q00`
M`-8#``#$`@``^0```/0#``"M`@``2P(``(4&``#J!````````-8!````````
M20````````"X!0```````,,$````````PP```.(```!Z!```@00`````````
M````7@8``%<````(`P``WP$``(H$``"#`P``;P,``*$$````````!08``,@&
M````````Q@$``'0"```M!```7P(``&\```````````````````#A`P``````
M`$X#``#E`0``K`(``"("````````"P(```````"#!0``0`4``(X%``!_!0``
M;@,```P%``"1!```^`$``)8```!]!@``908``#H%``"S`0```````-X$```Q
M!@``=P0``!<#`````````````%\````"!```````````````````````````
M```#`P```````($&`````````P8```````"^`P```````)0&``"[`P``+@4`
M``````#"`0``V@(``+("````````KP0``#L$``#-````I@0``(\#``!/!@``
M10,``!4%``#F`P``@````-H%````````B0,``-L```#E`@``RP$``$@"``")
M!0```````)D!``"R!@``=@4```X"``"_!@``SP8``((&```:!0```````(8&
M``"\!```H0$```````!;!0``&@,```H!``"2!0``=08``/$$``!0!0``W@``
M`(L&```+`P``MP$``&X&``"/`0```````&@!``"Y````#0(``%H````G````
M`P````````!N`0```````$,`````````Q04```````#.`P```````%@&````
M`````````````````````````'H"```"!0``W`,``.\$```3!````````/4%
M`````````````)X!``#>`@``'@0``.4%``````````````````!6`@``5`4`
M`!X!``"1`0``V@8``````````````````/,%```````````````````3!@``
M'P```&@"```6`@``B08``'P%``"7!```-@,``+P#``"^!@``4P,```8%```A
M`0``4P```-@```"*`0``I@$``$,"``""`@``2P```)0$```E!@``#`8`````
M```0!```508``,\````C````C00``!D&``!'`@``O`8``.,"````````X`$`
M`#$%``"D`0``J`(``.<!``"^`@``O0(``&\%```8`0```````%H#```M`0``
M00,``/<#``#<!`````````````!Q`P``X@(```````!/`P```````$X"``"Y
M`0```````/`$``#M`0``IP$``)4``````````````%D&``#;!```L`$``,8`
M``!6`P``#`(``/0$```]`````````*D"``!>`0```````,`!``!8`0``00``
M`%X%`````````````+H!``!1`P``Q`0``#H`````````WP8`````````````
M`````%0```!%`0``.`````````#+`@``F@(``.@"``!E!0``500``#4"``#1
M`@```````$$!````````EP```.,$``!,!0``K`4``,X"``!T!```+0(``&4"
M``"D!@``)`8``)H%```R`P``'`,````````$!```)P8``$@#````````]`$`
M`.P!``";`@```````#(!``````````````````"F!@``!0```#\!````````
M`````-,$``!B!@```````$(#`````````````/L```!P`P``(00`````````
M`````````````````````````-$#``!H!```[0(```````!&`0``O@``````
M```?`0``3P$``%D!```4!@``Z````"<%``!$!```$0(```````"#!@``A@$`
M`%`#``"G`@``@P$``(<&``!/!0``Z`$``.L!`````````````,`$``"P!0``
MO@$``/X$````````F````'$&````````#04````````?`P``;@(``(0&````
M````B@4`````````````U0,`````````````R@8``````````````````(\$
M``!L`P``8@0``"@!``">`P``(P$```````"U`0```````)4!````````)@$`
M`%P```"Y`P```````.P%```_!0``*P(``.H"``"H`0``R0,``#<&``#D`@``
M'@(``*X$``!@!@``O`$``!T```"C!```@`$``*@#``!/`@``#`0``#4#```7
M!@``]0`````````:!@``@@,```````"P!@``5P0``/L!``!X!@``5`$`````
M``!.!@``$00``.4$```F!@``BP```'P```"-!@``R@,``!<$``!"!@``````
M`#D!````````5@$``&D```#6````$@```+L$``!R!@``0@4````````C!@``
M!P(```\#``"``@``H@,``-0$``!U!0``<P8``%L$``"I``````````````#>
M`0``D0```&X$``"N`0``8`0```````"Z!0``P0,```````"7`0``,0(``"0"
M````````S`,``%L"```3`@```````$T#``#:!```-0```"H$``!*`@``FP8`
M`&<&````````L08``!<!``#Z`@``-`8```````!Q`````````)8"``"U`P``
M_P,``!8%```=`@``*@$``,<&```8`@``A0```-\"``!2``````````D"``#8
M`@``,@0``-\````=!@``M00``"L$```[`0``^@4``!4"``#K!0``HP(``*\!
M````````F@,``````````````````/4"```\!@``A@(``!4&``#\`0``%@``
M`'H```#]`P``404``/0%``#)!0```````/,#`````````````#$#``";`0``
MD@$``/($``"T`P``K00``!`%``#V`0``+`8``#@&``"+`P``U@4```````#]
M`0``^0(``","```S``````````````!G`0```````#0%``#W!````````+D&
M``"9`@```````#D"``"$!```T@(```````"@`0```````)L`````````D08`
M``````"!!0``4`8``-<%``#!!```_@4``)`"``#3!@``U`4``%X$``#"!@``
M,P0``#<%``"K!0``7`,```````"A`P`````````````1`0``'@4``&P!``#D
M`0``H@4`````````````[00``,4"``"A`@``M`8```,!``#7!```HP8``+D"
M``#*`0``/P,``$$&``#,`@``S@$``&@#``"R`0``"@,```````#4`P``4P(`
M`)T%```!`0```````"X```#Z`P``?@````````"C`P``#P$``%H%``"E!0``
M_`(``-@!````````<`(``/,!``##`0```````&<#```=!`````````````![
M!@``GP````````"C`````````&T$``#Y`0``(0(`````````````.`$``,\#
M```S`P```````,$"`````````````"@&``!K`P````````D#````````LP(`
M`(`#``!B!0```````!\&``"=`P```````-T$`````````````/(%``#7````
M`````#`"``!K````MP(```````!<`@``UP8``,L%``#O!0``=P,````````3
M!0``%0$``$D"```A````-P(``"0!`````````````*X&``"(!@``XP$```@$
M``"9!````````!<%``!\`P``9P0``$<$``!,!````````*X"````````````
M`*T&```@`P``S08``-`&````````7@(``*`#``!R!0``&`8``-0&``"L`0``
M<04```````"_!```$P$``"4#```\`@``)P$```````".!```0P,``$\$``#6
M!@``304``"<"``".!@``_`0`````````````=`,``'8"``"T`0``K0,``&D!
M``"]!0``7@,```````"/!0``:P(`````````````=`$``,D"``!X!0```P(`
M`.0%``#"````*`4````````*`@```````)\#``!A````OP$``#L%``#5`@``
MIP,``*8"``"B!```.`(```````!D!0``'`0```````"*````U00``+``````
M````,0```)("`````````````.P```!]`P``&P$``,\"``!%`````````-L!
M````````/08``````````````````)$%``"L````1`$`````````````\P``
M`/4#``"A!@``R`(``%D#```]!0``EP,``)0#````````8P8``"$#```6!@``
M7@```'("````````:@,``*(!``#$!@``G0(````````>`P```````,P%``!?
M`P``L@```&````#_`0``I00``/0````!`P``A@,``,L#````````)@,````$
M``#@`@``50$``$<!`````````````*<$``!C`````````.8$``#B`P``6@0`
M`,T%````````)`4``"8````V````B````&,#```X`P``"````+0$```8`P``
M^00``+8%````````70```-(``````````````,``````````,`4``'P$``!2
M!`````````````#.!```W````#D&```(!@``=`8``*D&````````G@8`````
M````````Y@``````````````_@(``%H&``!$!0``F`$```````"W!0``!P4`
M``````"X`@```````-\$```@`0``#`$````````4!```E08```````!!!0``
M`````.\!```^!0``I0`````````8````%````"(#````````.@,``&T```#M
M`P``&P0``"D```"?!0``B0````````!_!```D0,```````#0`0``WP4`````
M````````Q08```````";!```T`0``*<&`````````````.8!````````;P$`
M`/@"``"B````5P,``!D!``#`!@``IP```)P&``!J!0``RP```$8#````````
M^P0```````!_`@``704``$0"```+````50```(H"```K!0```````#4$````
M````?0```!$`````````]`(``*@%``"K`P````````````!D!@``AP``````
M````````#@````````!U!```.@8````````D!```A04````````.`P``9`0`
M`````````````````',!````````<P```%L#```+`0``$@$````````#!0``
MW`8``-T"````````5`0``$`!```>````4P8``#X!````````````````````
M````L00``&P$```)!@```````-L"``!%!```X@4```````#@!```PP(``'($
M````````Z`0`````````````P`4````````X!```2`8`````````````!@8`
M`,@!``!V!```E`(```@"``"J!```M`(``'4`````````Z0````````!X`@``
M`````(P#``#(!0``VP4``,(#``!&!@```````%8```!&!```Q@(``,0%``"J
M!@``_@,````!``#K``````````````"W````W`4`````````````G@(`````
M````````?`8``+\#```)`0``4@8``/P```!F`P``C`4````````<````N`,`
M`-$$``!]!0``"P8```@!``":!@````````````!E````A@4``&@`````````
M[@$``!<````'`0``5@0`````````````M@8``+H$```M`P``I08``,<%````
M````I`,``$8```"9````YP(```````!S!```*`,``(0#``#N!0```````#0$
M````````C0```$T"``#Q`0``F08``($!``"3`@```````$4&``!_`P``````
M`)`$```2!````````#D```!V`0``,@4``!4`````````)P,``)T$```$`P``
M`````.H!``"'`0``"0```'@$``"]`P``PP4``+X$`````````````%<&``#7
M`0``6`,``-T%``!M!@``)````+$%``!9!```+@,```````!S!0``^`0``/P#
M```2`@``]0$``#(&````````H`(``"4```!,`@``308``)P$````````/0$`
M`(0"```@`@``ZP(``(0!```6!```70,``-8"`````````````"`$```;`@``
MM08``(P"``""````[P(``)8&``"W!@``\@,``"`%```````````````````M
M!0```````*@$``#4````300``````````````````#4!```9`P``C`0``"\!
M``!'!@```````)8!````````;`(```````!K!``````````````:`@``!0,`
M``````#X````/@,``(X```#O`P``M@$```````!+!0``K@4``#`#``#9````
M:@(```````#"!```=P```&("``"E`@``@@4``$D$```2!0``+P(```````!/
M``````````L$``#J````3@4``+4"``!M!0``:04```````"K!@``\`(``)X%
M``"S`P```````%0#``!9!0``R00``*("``!E`0``!04``$H&``#9!```QP,`
M``````!3!```<`8``),$```B!@``"`4`````````````!`8``!L`````````
MG`4``*\`````````W0,``"P!``"(!0``#0,``)D%````````G08````````N
M!@``808``````````````````%$&```H````O`(``-4````Q!```-P$``'\&
M``#V`@```````(X#````````80$``-H```!Z!@``?@$```8$``!]!```K`8`
M``````!U`P``C````$H!``#1`0``&@```"``````````M@0``+D$``#L!```
M7`4``)4%``"3`P``!@(``*`&````````"@4``#P```!,!@`````````````*
M!@``I@4````````Y`P``30```)(`````````9`,``'4!``#D`P```````%$`
M``!'`P``&00```````!8!````````'T!````````O08```````"$!0``````
M`$8"```/````L`(```````!A!```R@0``#,%``#R`0```````,X%``"*!@``
M,````/```````````````#\````]`@``'@8```(#````````Q@8```X!``#N
M`````````-X&``"O!0``A@````````"J!0``+P8``)L%```/!````````,,&
M````````2``````````C!0``-`$``"$%``"[!0``T@,``+`$```!!0``>@4`
M`(D$```@!@``YP4``*0$``#U!```T`(``#$!``#.`````````%T$````````
MBP4``"<$``"J````TP```"D!``!R`P```````&D#```-!`````````````"T
M````TP,``"H#````````[`(`````````````_00``-H#``#9`0``I````-<#
M```0`P``UP(``-4&``"8!```5P4``!0!```"````B`,``)\!````````E@0`
M```````\`0``S`$``&4$```3`P```````&L&```\`P```````&D&``#'````
M/P(``!`````R````C@(``-4!``#9`P```````"4!``!8````&@$``),```!7
M`@``C0(``#<#````````XP,````````B`````````,P&```B!```,@(```\"
M```[`P```````-L&``"@``````````````!5`P``J@$``(0`````````````
M``````#+!```S0(``$L#```6`P````````````":`0``)`,```````#F`@``
MOP(```````"6!0``K`,```````!P`0``"04```P```#W`0``@0,``(\`````
M````>0(```````#*!0````````````!H!0``R````!\"````````;0(``'`$
M``#;`P`````````````^!@```````,T$``!D`````````.D$``#$`0``20$`
M`/H$```W!```<@$``/L%``!P!0``400``#8"``#V`P``80,``$D&````````
M<0(``-X%````````_0(``.````!)!0``L0$``$L&``#*````````````````
M````Z0,``!@$`````````````-@#``!3!0```````(<#``!!!```-@$``'L`
M``!5`@``1P```*T%`````````````#0"````````F@```&<"``#B!```````
M``````!C!```*@4```````#=`0```````*8#``"S!0```````)4#``#&!0``
MW08``)<%``!*`P``!`$``%P!``#&!```N`8``-X#``!:`@``X00```<````-
M````*@```/H!``!?!```D`$``#P%```E!0````````````!L!@``5@8`````
M```K`0``X0``````````````!00``(L$``!B`P``D@0``),&``#:`0``;0,`
M`/@%``!Y!````````#8$``!$`P``O0$````````+!0``G````(,`````````
M%`4``)P#```[`````````!$#```[`@`````````````F!```T@8``,$&``"I
M!0``>04``%0"``"N`P``$`(```````"_!0```````&@&````````\0,``,\$
M``#``@``10(``.D!```5!```Q0,`````````````@@$`````````````R0``
M`````````````````'L!``"7!@```````"D#``#3`0``P`,``'L$``"4`0``
MLP```*X```"M`0``;@````````"^!0``T0```"\%``#'`0``?`(```````#9
M!0``DP4`````````````]@4```````!*!```.@(``$L!``!'!0```````-,"
M``!1`0``&P8````````<!@```````!D````I!```0P$``&,!``"Z`P``&04`
M`.<$``#(!```?`$``+T$```!!@````````8#``#P`0``\0```$4%```7`@``
M`````%(!````````,`8``/\"``#?`P``2`$``*,%```#!```4@(``&,"````
M````6P$```````#.!@``>P,``)H$``#@!0```````"\#``!$!@``*P,``"(!
M``"'!````````/,"```C`P``D`,``'L%``#8!0```````,T#``"F````0@(`
M``````!V`P``D`8`````````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@
M)7,I`"`H=&]D87DI`"`H>65S=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E
M9"!N;W1E<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R
M<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A
M;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@9FEL92!S=6-C97-S9G5L
M;'D@:6UP;W)T960`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@
M9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@
M0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@
M9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L
M96-T("TM`#$@;F]T90`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R
M-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N`$%-(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+@!!8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N`$%C8V5S
M<R!D96YI960@;6]V:6YG('1H92!N;W1E+@!!8V-E<W,@9&5N:65D('-A=FEN
M9R!N;W1E('1O("5S+@!!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<P!!
M8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D
M9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE
M<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V%T96=O<GD`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E
M<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O
M;VL`061D('5S97(`061D:6YG($$@3F5W($YO=&4`061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@
M<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO
M;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N
M`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'
M<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!
M;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M
M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S
M`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N
M;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"
M87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L
M>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O
M=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)
M+3@I`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I
M:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N
M;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!
M='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!#871E9V]R:65S.@!!=F%I;&%B;&4@9FEE;&1S
M.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K('1O($YO=&5P860`0F%C
M:R!T;R!.;W1E<&%D($]P=&EO;G,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O
M;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N
M86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N
M9VQA9&5S:`!"87)B861O<P!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L
M:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@
M;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S
M`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R
M9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA
M`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA
M;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL(%!R
M;W!E<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&
M:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N
M`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O
M<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@
M9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE
M<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N
M`$-A=&5G;W)I97,@86YD($QA8F5L<P!#871E9V]R>0!#87EM86X@27-L86YD
M<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E
M;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@
M*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E
M=&%I;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG92!Y;W5R
M(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS+@!#:&%R`$-H96-?
M:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S
M=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*0!#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T;R!L:7-T(&EN('1H
M92!S=6UM87)Y('9I97<N`$-H;V]S92!Y;W5R(&1E9F%U;'0@3F]T97!A9"X`
M0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F
M;W5N9"X`0VQE87(`0VQE87(@1F]R;0!#;&5A<B!-4T]F9FEC92!T86=S`$-L
M96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I
M;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O
M;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#
M;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O
M;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R
M;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O
M;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N
M;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@
M*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L
M96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H
M96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N
M;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I
M8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E
M860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@
M<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3
M:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E
M9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#
M<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T
M:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI
M>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L
M96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@
M4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@
M4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E
M8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L
M="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@3F]T97!A9`!$969A
M=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I
M;VXZ`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E
M<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L
M;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C96YD:6YG`$1E<V-R:6)E('1H
M92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E<V-R:7!T:6]N.@!$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0
M;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I
M<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T
M`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T
M:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E
M`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S
M`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U
M<`!%9&ET($YO=&4`161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`
M161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I
M="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A
M9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A
M9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`
M16UO=&EC;VYS`$5M<'1Y($YO=&4`16UP='D@;65S<V%G92X`16UP='D@<F5S
M=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I
M;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET
M;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H
M92!I;6%G92!54DP@:&5R90!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17-T;VYI80!%=&AI;W!I
M80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$5X96-U=&4`17AP86YD`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E
M('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%
M>'!O;F5N=`!%>'!O<G0`17AP;W)T($YO=&5S`$9'($-O;&]R`$944"!U<&QO
M860@;V8@<V5T=7``1E]U;&P@5&5X=`!&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y
M(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T
M;R`B)7,B+@!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O
M92!)<VQA;F1S`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z
M(`!&97<@4VAO=V5R<P!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#
M;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E
M;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&
M:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M
M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O
M<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P
M;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C
M<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!'
M:&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE(%-E
M87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E
M;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U
M871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`
M1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(
M96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E
M=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O
M<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(
M;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O
M2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D
M;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO
M;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L
M9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES
M=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E
M<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T
M(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X
M=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R
M<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`
M26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E
M(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@3F]T
M97,L(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T
M97,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R
M="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O
M<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E
M<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN
M9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R
M`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN
M<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T
M(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S
M<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H
M(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN
M<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S
M=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`
M26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I
M;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R
M(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI
M9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A
M('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A
M;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L
M+@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA
M=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I
M8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E
M>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S
M=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T
M86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I
M;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S
M86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!2
M97!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I
M`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L
M92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@36]D:69I
M960`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`
M3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V
M:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N
M;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R
M:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT
M($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A
M:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU
M;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI
M;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@
M0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A
M=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C
M:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,
M:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`
M3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`
M3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I
M;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN
M9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E
M9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@
M;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365M;R!497AT
M`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S
M86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T
M<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI
M9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I
M;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U
M<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A
M;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)
M1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN
M9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE
M9"!$871E`$UO9&EF>2!54DP`36]D:69Y:6YG("5S`$UO9'5L=7,`36]L9&]V
M82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R
M`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L
M>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`
M36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U
M<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT
M:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!.;W1E<P!->2!0;W)T86P`
M37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.
M86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N
M9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!2
M96YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!3
M4TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.
M971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A
M;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W($YO=&4`3F5W(%5S
M97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L
M86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A
M9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.
M;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.
M;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U
M97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&
M4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N
M('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%T:6]N(&ES('-E
M="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO
M(&YO=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+@!.;R!N;W1E<P!.
M;R!N;W1E<R!M871C:"!T:&4@8W5R<F5N="!C<FET97)I82X`3F\@;F]T97,@
M=&\@9&ES<&QA>0!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@
M9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!
M4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N
M=7!S+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU
M97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO7W1E`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO
M="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T
M('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E($-A=&5G;W)Y`$YO=&4@1&5T86EL
M<P!.;W1E($QI<W1S`$YO=&4@5&5X=`!.;W1E(%]497AT`$YO=&4@;F]T(&9O
M=6YD+@!.;W1E7W!A9`!.;W1E<&%D)W,@;F%M93H`3F]T97!A9',`3F]T97,`
M3F]T97,@4W5M;6%R>0!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V
M96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C
M;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/
M8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F
M9FEC90!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL
M(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R
M;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E
M;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE
M9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D
M97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R
M9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/
M=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`
M4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O
M16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A
M:6X`4$T@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`
M4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO
M=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U
M:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@
M;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0
M96YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B!$96YI960`4&5R
M;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@
M26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O
M<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE
M87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I
M8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@
M<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O
M8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO
M;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@
M06QG;W)I=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0
M=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@
M16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A;F1O;2!&;W)T=6YE`%)A
M=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@3&ES=`!2969R97-H(%!O<G1A
M;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E
M;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C871E9V]R
M>0!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER
M`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S
M=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R="!#;VYF:6=U
M<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT
M`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN
M`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2
M:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU
M;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N
M($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA
M='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L
M;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN
M="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!3
M86UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A
M;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3
M879E`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V-I
M96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H(%)E<W5L=',`4V5A
M<F-H(%-C;W!E`%-E87)C:"!?5&5X=`!396QE8W0@1FEL97,`4V5L96-T(&$@
M9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R
M`%-E;&5C="!A(&YO=&5P860`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S
M97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@
M86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X
M<&]R="!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C
M="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@0V%T96=O
M<FEE<SH`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E
M;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L
M($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W
M86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E
M="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO
M<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&%C=&EO;B!B=71T;VYS
M/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N
M9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!N;W1E<&%D(&YA
M;64_`%-H;W<@;F]T97,@9G)O;2!T:&5S92!C871E9V]R:65S`%-H;W<@;W!T
M:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`
M4VAO=V5R<R!,871E`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I
M;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE
M`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P
M;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3
M;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@3&%T
M90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L
M;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&)Y($-A
M=&5G;W)Y`%-O<G0@8GD@3F]T92!497AT`%-O<G0@;W)D97(@<V5L96-T:6]N
M`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN
M9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E
M;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E
M`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T
M:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R
M97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3
M=6-C97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K
M=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N
M`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I
M<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I
M<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@
M36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R
M;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O
M<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!4
M86)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H
M:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!4
M87)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H
M;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI
M;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN
M9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA
M8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@
M;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@
M8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O
M;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`
M5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E
M;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN
M9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG
M<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H
M92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T
M:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4
M:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M
M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S
M('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG
M:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R
M(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF
M('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T
M:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A
M;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@
M4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@
M9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I
M;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#
M<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E
M<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@
M:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A
M9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG
M('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YO=&4@=V%S(&1E;&5T960N`%1H
M92!N;W1E<&%D("(E<R(@8V]U;&1N)W0@8F4@8W)E871E9#H@)7,`5&AE(&YO
M=&5P860@(B5S(B!H87,@8F5E;B!C<F5A=&5D+@!4:&4@;F]T97!A9"`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@
M<V%V960N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E
M<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4
M:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@
M8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A
M9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H
M92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H
M97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N
M(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R
M86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA
M<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@
M=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL
M;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M=DYO=&4@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@
M9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C
M:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@=&AE(&YO=&4Z
M("5S`%1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AE(&YO=&4Z("5S`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=FEE=VEN9R!T:&ES(&YO
M=&5P860Z("5S`%1H97)E('=E<F4@;F\@;65M;W,@=&\@97AP;W)T+@!4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F
M:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL
M("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F;W)M870@
M:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@
M<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W
M87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D
M(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'
M<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI
M96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N
M(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R
M;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM
M92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,
M97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(
M5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O
M<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A
M9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)
M4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%52
M3`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`
M55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W
M:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z
M("5S`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI
M<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A
M=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G
M:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L
M:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G
M('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X
M=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@
M<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I
M;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T
M=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z
M("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F
M;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@
M4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!T:&ES('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M
M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C
M=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS
M(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R
M;VT@;F]W+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`
M5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N
M`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D
M:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H
M5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE
M=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD
M<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E
M871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H
M97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O
M("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@
M*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D
M96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T
M97(_`%=H:6-H($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T
M;S\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S
M`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@
M=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE
M`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`
M6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO
M;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)
M($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A
M=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AE(&YO=&5P860@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\`66]U(&UU<W0@<V5L96-T(&$@;F]T97!A9"!T;R!B92!D96QE=&5D
M+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@
M86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O
M<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R
M96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&1E
M9F%U;'0@;F]T97!A9#H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!N;W1E<&%D<SH`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R
M(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB
M86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T
M70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T)A8VL@
M=&\@3F]T97!A9`!?0TQ)`%]#871E9V]R>0!?1&%T851R964`7T1E;&5T90!?
M1&5L971E(%)O=P!?161I=`!?1FER<W0@3&EN90!?1W)O=7!S`%](96QP`%])
M;6%G92!0<F]P97)T:65S+BXN`%]);7!O<G0O17AP;W)T`%],:7-T($YO=&5S
M`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]->2!.;W1E<&%D
M<P!?3F5W($YO=&4`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]0<FEN=`!?4F5M
M;W9E($QI;FLN+BX`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N
M+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86QM`&-L:6-K(&AE
M<F4`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`
M:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D
M('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y
M970@:6UP;&5M96YT960`;F]T97!A9`!N;W1E<RYC<W8`<&5R8V5N=`!P:7AE
M;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10
M`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@
M8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=DYO
M=&4`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!-;F5N;R`R
M+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,BTP.2`P.#HU,BLP,3`P"DQA<W0M
M5')A;G-L871O<CH@2F%N($MU:7!E<G,@/&IR:W5I<&5R<T!L875W97)S8V]L
M;&5G92YN;#X*3&%N9W5A9V4M5&5A;3H@1'5T8V@@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET"@`@*"5S(&1A9V5N(&=E;&5D96XI`"`H4VYE;'1O971S
M("5S*0`@*'9A;F1A86<I`"`H9VES=&5R96XI`"!O<"``)60@)7,@96X@)7,`
M)60@;F]T:71I97,`)60M9&%G('9O;W)U:71Z:6-H=``E<R`M($]P;65R:VEN
M9P`E<R!V:6YG97)A9F1R=6L`)7,@2T(`)7,@3VYD97)H;W5D<W=E<FMZ86%M
M:&5D96X@+2!"979E<W1I9VEN9P`E<R!I;G-C:')I:G9E;@`E<R!G96)R=6EK
M97)S;W9E<F5E;FMO;7-T`"5S(&)E<W1A870@86PN`"5S(&]P("5S("5S`"5S
M(&)E<W1A;F0@;65T('-U8V-E<R!G96EM<&]R=&5E<F0`)7,@:7,@=F5R96ES
M=``E<R!M:6YU=&5N`"5S(&YI970@9V5V;VYD96XN`"5S('1O="`E<R!V86X@
M)7,`)7,G<R!A9')E<V)O96L`)7,G<R!A9V5N9&$`)7,G<R!N;W1I=&EE8F]E
M:P`E<R=S('1A:V5N;&EJ<W0`)7,Z("5S`"P@=VEN9'9L86=E;B`E<R`E<P`L
M('9A<FEA8F5L('9A;B`E<R!T;W0@)7,`+2T@<V5L96-T97)E;B`M+0`Q(&YO
M=&ET:64`,3(@=75R<W=E97)G879E`#(T('5U<G-W965R9V%V90`R-"!U=7)S
M`$5E;B!D871A8F%S92!B86-K96YD(&ES('9E<F5I<W0@=F]O<B!D:70@8FQO
M:RX`17(@:&5E9G0@>FEC:"!E96X@9F%T86QE(&9O=70@=F]O<F=E9&%A;@!%
M96X@;W!E;F)A<F4@4$=0('-L975T96P@:7,@=F5R96ES="!O;2!E96X@8F5R
M:6-H="!T92!C;V1E<F5N+@!%96X@;W!E;F)A<F4@4$=0('-L975T96P@:7,@
M=F5R96ES="!O;2!E96X@;VYD97)T96ME;F0@8F5R:6-H="!T92!V97)I9FGK
M<F5N+@!%96X@;W!E;F)A<F4@4$=0('-L975T96PL('!R:7;I(%!'4"!S;&5U
M=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@;VT@965N(&)E
M<FEC:'0@=&4@9&5C;V1E<F5N+@!%96X@;W!E;F)A<F4@4$=0('-L975T96PL
M('!R:7;I(%!'4"!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E
M<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@;VYD97)T96ME;F5N+@!%96X@;W!E
M;F)A<F4@4R]-24U%('-L975T96PL('!R:7;I(%,O34E-12!S;&5U=&5L(&5N
M('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@;VT@965N(&)E<FEC:'0@
M=&4@9&5C;V1E<F5N+@!%96X@;W!E;F)A<F4@4R]-24U%('-L975T96PL('!R
M:7;I(%,O34E-12!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E
M<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@;VYD97)T96ME;F5N+@!%96X@;W!E
M;F)A<F4@4TU)344@<VQE=71E;"!I<R!V97)E:7-T(&]M(&5E;B!B97)I8VAT
M('1E(&-O9&5R96XN`$)U:65N('9O;W(@,3(N,#`@=75R`$%-+U!-`$%022!)
M1`!/=F5R(&1E>F4@961I=&]R`$]V97(N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A;B!61E,@9&ER
M96-T;W)Y+@!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A;B!6
M1E,@8F5S=&%N9"X`5&]E9V%N9R!G97=E:6=E<F0@8FEJ('9E<G=I:F1E<F5N
M('9A;B!N;W1I=&EE+@!4;V5G86YG(&=E=V5I9V5R9"!B:6H@=F5R<&QA871S
M96X@=F%N(&1E(&YO=&ET:64N`%1O96=A;F<@9V5W96EG97)D(&)I:B!O<'-L
M86%N('9A;B!N;W1I=&EE(&EN("5S+@!4;V5G86YG(&=E=V5I9V5R9"!B:6H@
M;W!S;&%A;B!V86X@;F]T:71I93H@)7,`06-C;W5N='=A8VAT=V]O<F0`06-C
M;W5N="!B979R;W)E;BX`5F5R86YT=V]O<F1I;F<`5&]E=F]E9V5N`$-H:6QD
M(&=R;V5P('1O979O96=E;@!#:&EL9"!R96-H="!T;V5V;V5G96X`2&EE<B!T
M;V5V;V5G96XZ`$YI975W92!G<F]E<"!T;V5V;V5G96X`3FEE=7<@<F5C:'0@
M=&]E=F]E9V5N`$YI975W92!G96)R=6EK97(@=&]E=F]E9V5N.@!#871E9V]R
M:64@=&]E=F]E9V5N`$MO;&]M('1O979O96=E;@!.:65U=V4@;&5D96X@=&]E
M=F]E9V5N`%!A87(@=&]E=F]E9V5N`$AE="`E<R!M96YU('1O979O96=E;B!A
M;',@965N($UO>FEL;&$@4VED96)A<@!6;V5G('1O92!A86X@861R97-B;V5K
M.@!6;V5G('1O92!A86X@;6EJ;B!A9')E<V)O96L`1V5B<G5I:V5R('1O979O
M96=E;@!%96X@;FEE=7=E(&YO=&ET:64@=&]E=F]E9V5N`%1O979O96=E;B!V
M86X@9V5B<G5I:V5R<R!I<R!U:71G97-C:&%K96QD+@!!9')E<P!!9')E<V)O
M96L`0F5H965R("T@<F5C:'1E;B!V;V]R(&%N9&5R92!G96)R=6EK97)S(&EN
M<W1E;&QE;@!"96AE97(`061V97)T96YT:65S`$%F9V%N:7-T86X`06QB86YI
MZP!!;&=E<FEJ90!!;&EA<P!5:71L:6IN96X`56ET;&EJ;FEN9SH`06QL90!!
M;&QE(&=E875T:&5N=&EC965R9&4@9V5B<G5I:V5R<P!!;&QE(&=R;V5P96X`
M06QL92!R96-H=&5N`$%L;&4@=FEE<B!Z:6ID96X`365E<F1E<F4@861R97-S
M96X@=&]E<W1A86X`26YS=&5L;&5N('9A;B!G96]R9&5N9&4@;&EJ<W0@='EP
M92!T;V5S=&%A;C\`0F5S=&%A="!A;`!!;'1E<FYA=&EE=F4@24U34"!A86YM
M96QD:6YG`$%L=&5R;F%T:65F($E-4U`@=V%C:'1W;V]R9`!!;'1E<FYA=&EE
M=F4@24U34"!G96)R=6EK97)S;F%A;0!!;'1E<FYA=&EE9B!E+6UA:6QA9')E
M<P!!;'1E<FYA=&EE=F4@<VIA8FQO;F5N`$%L=&5R;F%T:65V92!T96MS=#H`
M06UE<FEK86%N<R!386UO80!%96X@;VYG96QD:6=E('=A87)D92!O<&=E9V5V
M96XN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI96UE('!R;WAY`$%N
M='=O;W)D`$%N=&%R8W1I8V$`06YT:6=U82!E;B!"87)B=61A`%1O97!A<W-I
M;F<`5&]E<&%S<VEN9R!I<R!G97)E960N`$]P(&-H:6QD<VAA<F5S('1O97!A
M<W-E;@!';V5D:V5U<F5N`$%P<FEL`$%R86)I<V-H("A7:6YD;W=S+3$R-38I
M`$%R8VAI969B97-T86YD<V=R;V]T=&4`07)C:&EE9FYA86T`5V5E="!U('IE
M:V5R(&1A="!U(&AE="!A86YM96QD:6YG<W9E<GIO96L@=F%N("5S('=I;'0@
M=F5R=VEJ9&5R96X_`$%R9V5N=&EN:>L`07)M96YIZP!!<FUE96YS("A!4DU3
M0TE)+3@I`$MU;G-T`$%R=6)A`%1O96YE;65N9`!!<V-E;G-I;VX@96EL86YD
M`$%S8VEI(&MU;G-T`$%Z:>LO4&%C:69I<V-H92!296=I;P!/;2!B979E<W1I
M9VEN9R!V<F%G96X@=F]O<B!H970@=6ET=F]E<F5N('9A;B!O;F1E<FAO=61S
M=V5R:WIA86UH961E;C\`3W!D<F%C:'0@:V]L;VUM96X`4&]G:6YG(&]M(&5E
M;B!N:65T(&)E<W1A86YD92!G<F]E<"!T92!V97)W:6ID97)E;BX`4&]G:6YG
M(&]M(&5E;B!N:65T(&)E<W1A86YD(')E8VAT('1E('9E<G=I:F1E<F5N+@!0
M;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@8F5W97)K96XN
M`%!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9&4@<VAA<F4@=&4@8F5W97)K
M96XN`$%T=')I8G5T96X`075G=7-T=7,`075S=')A;&GK`$]O<W1E;G)I:FL`
M075T:%]C>7)S<6PZ('9E<F5I<W1E(&EM87`@97AT96YT:64@;FEE="!G979O
M;F1E;BX`075T:%]C>7)U<SH@8F%C:V5N9"!H965F="!N:65T(&1E('9E<F5I
M<W1E(&)E:W=A86UH961E;BX`075T:%]C>7)U<SH@=F5R96ES=&4@:6UA<"!E
M>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7V9T<#H@=F5R96ES=&4@1E10
M(&5X=&5N=&EE(&YI970@9V5V;VYD96XN($-O;7!I;&5E<B!02%`@;65T(&1E
M("TM96YA8FQE+69T<"!O<'1I92X`075T:%]I;6%P.B!V97)E:7-T92!)34%0
M(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?:W)B-3H@=F5R96ES=&4@
M:W)B-2!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7VQD87`Z('9E<F5I
M<W1E($Q$05`@97AT96YT:64@;FEE="!G979O;F1E;BX`075T:%]L9&%P.B!.
M:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!T;V4@=&4@=F]E9V5N+B!$92!S
M97)V97(@;65L9'0Z(`!!=71H7VQD87`Z($YI970@:6X@<W1A870@9V5B<G5I
M:V5R("5S('1E('9E<G=I:F1E<F5N`$%U=&A?;&1A<#H@3FEE="!I;B!S=&%A
M="!G96)R=6EK97(@)7,@8FEJ('1E('=E<FME;@!!=71H7VUC86PZ('9E<F5I
M<W1E($U#04P@97AT96YT:64@;FEE="!G979O;F1E;BX`075T:%]S;6)A=71H
M.B!V97)E:7-T92!S;6)A=71H(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U
M=&AE;G1I8V%T:64@;6ES;'5K=`!!=71H96YT:6-A=&EE(&UI<VQU:W0N("5S
M`$%U=&AE;G1I8V%T:64@9V5W96EG97)D(&1O;W(@9&4@4D%$2553('-E<G9E
M<BX`075T:&5N=&EC871I92!O<"!&5%`@<V5R=F5R(&UI<VQU:W0N`$)E<V-H
M:6MB87)E(&-A=&5G;W)I965N.@!"97-C:&EK8F%R92!V96QD96XZ`$%Z97)B
M86ED>FIA;@!"3T9(($5X8W5S97,`5&5R=6<@;F%A<B!N;W1I=&EE8F]E:P!4
M97)U9R!N86%R(&1E(&YO=&ET:65B;V5K;W!T:65S`$%C:'1E<F=R;VYD`$%C
M:'1E<F=R;VYD:VQE=7(`1F]U="!K97)B97)O<W=A8VAT=V]O<F0N`$9O=71E
M(&ME<F)E<F]S9V5B<G5I:V5R<VYA86TN`$)A:&%M87,`0F%H<F5I;@!"86QT
M:7-C:"`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S:7-L
M:6IN`%=I="!R=7-L86YD`$)E;&=IZP!"96QI>F4`0F5N:6X`0F5R;75D80!"
M:'5T86X`5F5R:F%A<F1A9P!";&]K("(E<R(@=F%N('1O97!A<W-I;F<@(B5S
M(B!N:65T(&=E=F]N9&5N+@!";&]K:6YS=&5L;&EN9V5N`$)L;VMT>7!E`%9E
M=`!";VQI=FEA`$)O;VMM87)K<P!286YD`%)A;F1D:6MT93H`4F%N9&5N`$)O
M<VYIZR!E;B!(97)Z96=O=FEN80!"96ED96X`0F]T<W=A;F$`3VYD97)K86YT
M`$)O=79E="!E:6QA;F0`0G)A>FEL:>L`0G)I=',@26YD:7-C:&4@3V-E86%N
M(%1E<G)I=&]R:75M`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEJ90!/;F=E
M;W)D96YD92!L:6IS=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-2
M3"!$:7-T<FEB=71I97!U;G1E;@!#4U8`0U]E;&5I9V5N<V-H87!P96XN+BX`
M06=E;F1A`$MA;&T`0V%M8F]D:F$`2V%M97)O96X`2V%N('=A8VAT=V]O<F0@
M;FEE="!A=71O;6%T:7-C:"!R97-E='1E;BP@;F5E;2!C;VYT86-T(&]P(&UE
M="!D92!S>7-T965M8F5H965R9&5R+@!+86X@;FEE="!V97)B:6YD96X@;65T
M($E-05`@<V5R=F5R.B`E<P!#86YA9&$`069B<F5K96X`4')O8FQE96UR87!P
M;W)T(&%F8G)E:V5N`$MA;B!B97-T86YD("(E<R(@;FEE="!V97)W:6ID97)E
M;BX`2V%N(&=E96X@=&EJ9&5L:6IK92!D:7)E8W1O<GD@=FEN9&5N+@!+86X@
M;FEE="!D;V]R9V%A;B!Z;VYD97(@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M2V%N(&1I<F5C=&]R>2`B)7,B(&YI970@=F5R=VEJ9&5R96XN`$MA;B!N:65T
M('9E<G=I:F1E<F5N.R`E9"!C:&EL9')E;B!B97-T86%N+@!+86X@;FEE="!O
M<&YI975W(')A;F=S8VAI:VME;BP@:&5T(&%A;G1A;"!I;G9O97)E;B!O;2!O
M<&YI975W('1E(')A;F=S8VAI:VME;B!K;VUT(&YI970@;W9E<F5E;B!M970@
M:&5T(&]P9V5S;&%G96X@86%N=&%L+@!+86X@8F5R:6-H="!N:65T(&YA87(@
M:&5T(&]P9V5G979E;B!N=6UM97(@=F5R<W1U<F5N+@!+86%P(%9E<F1E`$]P
M<V-H<FEF=`!#871E9V]R:67K;B!E;B!L86)E;',`0V%T96=O<FEE`$-A>6UA
M;B!E:6QA;F1E;@!496PN;G(N;6]B:65L`$-E;&5I9V5N<V-H87!P96X`0V5L
M('9R:6IE(')U:6UT93H`0V5L96EG96YS8VAA<'!E;@!#96QS<&%T:>MR:6YG
M.@!496PN;G(N;6]B:65L`$ME;'1I<V-H("A)4T\M.#@U.2TQ-"D`36ED9&5N
M`$-E;G1R86%L($%F<FEK86%N<V4@4F5P=6)L:65K`$-E;G1R86%L($5U<F]P
M965S("A)4T\M.#@U.2TR*0!#97)T:69I8V%A=&1E=&%I;',`0V5R=&EF:6-A
M871B96QE:60`5'-J86%D`%=I:GII9V5N`%=I:GII9R!D92!N86%M+"!A9')E
M<R!E;B!O;F1E<G1E:V5N:6YG(&1I92!M96X@>FEE="!B:6H@:&5T(&QE>F5N
M(&5N(&)E86YT=V]O<F1E;B!V86X@=7<@92UM86EL<RX`5VEJ>FEG('5W(&YO
M=&ET:64@<V]R=&5E<BT@96X@=V5E<F=A=F5O<'1I97,N`$MA<F%K=&5R`$-O
M;G1?<F]L965R(&QI;FLN+BX`0VAI;&D`0VAI;F$`0VAI;F5E<R!V97)E96YV
M;W5D:6=D("A'0C(S,3(I`$-H:6YE97,@=')A9&ET:6]N965L("A":6<U*0!+
M:65S(&5E;B!W86-H='=O;W)D`$MI97,@965N(&=E8G)U:6ME<G-N86%M`$MI
M97,@9&%T=6UW965R9V%V93H`2VEE<R!L:6IS='-T:6IL='EP92`H=F]O<B!G
M96]R9&5N9&4@;&EJ<W1E;BD`2VEE<R!D92!N;W1I=&EE8V%T96=O<FEE96X@
M9&EE(&EN(&1E('-A;65N=F%T=&EN9R!D:65N96X@=&4@=V]R9&5N('=E97)G
M96=E=F5N+@!+:65S('-T86YD86%R9"!N;W1I=&EE8F]E:RX`0VAR:7-T;6%S
M(&5I;&%N9`!#;&%S<V1E9FEN:71I92!V86X@)7,@;FEE="!G979O;F1E;BX`
M2&5L9&5R`%=I<R!F;W)M=6QI97(`35-/9F9I8V4@=&%G<R!W:7-S96X`5VES
M(&=E8G)U:6ME<CH@)7,`5VES(&=E8G)U:6ME<@!7:7,@9V5B<G5I:V5R<V1A
M=&$`2VQI:R!O;2!V97)D97(@=&4@9V%A;@!#;&EC:V%T96QL('9I82!(5%10
M`%-L=6ET('-C:&5R;0!7;VQK96X`0F5W;VQK=`!#;V-O<R`H2V5E;&EN9RD@
M96EL86YD96X`26YG96ML87!T92!R86YD96X`0V]L;VUB:6$`2VQE=7(`2VQE
M=7)E;FMI97IE<@!+;&5U<G-E;&5C=&EE`$MO;&]M;65N.@!+;VQO;71I=&5L
M<P!3=')I<',`3W!D<F%C:'0`3W!D<F%C:'1S:&5L;`!/<&UE<FMI;F<`06QG
M96UE;F4@;F%A;0!#;VUO<F5N`$)E9')I:F8`0V]M<'5T97)S`$-O;F1I=&EE
M<P!697)S8VAI;&QE;B!I;B!C;VYF:6=U<F%T:64`)7,@8V]N9FEG=7)E<F5N
M`$)E=F5S=&EG('=A8VAT=V]O<F0`2V]N9V\`2V]N9V\L($1E($1E;6]C<F%T
M:7-C:&4@4F5P=6)L:65K('9A;B!D90!697)B:6YD:6YG(&UI<VQU:W0N`%9E
M<F)I;F1I;F<@;6ES;'5K=#H@`%9E<F)I;F1I;F<L(&UE="!D92!O<&5N8F%R
M92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E:6=E<F0N`%9E<F)I;F1I;F<L(&UE
M="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E:6=E<F0N(%)E
M9&5N.B`E<R`H)7,I`%9E<F)I;F1I;F<@;65T($944"!S97)V97(@;6ES;'5K
M="X`061R97-S96X@>FEJ;B!M970@<W5C8V5S(&%A;B!U=R!A9')E<V)O96L@
M=&]E9V5V;V5G9"X`1&]O<F=A86X`0V]O:R!E:6QA;F1E;@!#;V]K:64`2V]P
M:>MR96X`2V]P:65E<B!S96QE8W1I90!#;W-T82!2:6-A`$EV;V]R:W5S=`!+
M;VX@4$=0(&)E<FEC:'0@;FEE="!C;V1E<F5N+@!+;VX@4$=0(&)E<FEC:'0@
M;FEE="!O;F1E<G1E:V5N96XN`$MO;B!B97)I8VAT(&YI970@4R]-24U%(&-O
M9&5R96XN`$MO;B!B97)I8VAT(&YI970@4R]-24U%(&]N9&5R=&5K96YE;BX`
M2V]N(&%D<F5S("5S(&YI970@=&]E=F]E9V5N+@!+;VX@9V5E;B!V97)B:6YD
M:6YG(&UE="!D92!,1$%0+7-E<G9E<B!M86ME;BX`2V]N('1E9V]E9"`E<R!N
M:65T(&-O;G1R;VQE<F5N+@!+;VX@9V5E;B!D:7-T<FEB=71I96QI:G-T("5S
M(&UA:V5N+@!+;VX@4$=0(&1A=&$@;FEE="!D96-O9&5R96XN`$MO;B!3+TU)
M344@9&%T82!N:65T(&1E8V]D97)E;BX`2V]N(&%D<F5S("5S(&YI970@=F5R
M=VEJ9&5R96XN`$MO;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@=F5R=VEJ
M9&5R96XN`$MO;B!H970@92UM86EL861R97,@=F%N(&1E(&]N='9A;F=E<B!N
M:65T(&)E<&%L96XN`$MO;B!C;VUP;&5T92!A9')E<V)O96L@;FEE="!O<&AA
M;&5N+@!+;VX@8V]M<&QE=&4@9&ES=')I8G5T:65L:6IS="!N:65T(&]P:&%L
M96XN`$MO;B!C;VUP;&5T92!L:6IS="!V86X@9&ES=')I8G5T:65L:6IS=&5N
M(&YI970@;W!H86QE;BX`2V]N(&1E(&]P96YB87)E('-L975T96P@;FEE="!V
M97)K<FEJ9V5N('9A;B!D92!S;&5U=&5L<V5R=F5R+@!+;VX@)7,@;FEE="!O
M<&5N96XN`$MO;B!O;F1E<FAO=61S=&%K96YM;V1U;&4@)7,@;FEE="!O<&5N
M96X`2V]N("5S(&YI970@;&5Z96XN`$MO;B!H970@=V%C:'1W;V]R9"!V86X@
M9&4@9V5W96YS=&4@9V5B<G5I:V5R(&YI970@<F5S971T96XN(%-O;6UI9V4@
M;V8@86QL92!D971A:6QS('II:FX@;FEE="!J=6ES="X@4')O8F5E<B!O<&YI
M975W(&]F(&YE96T@8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E
M<BP@=V%N;F5E<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H965F="X`2V]N($%#
M3"!N:65T(&]P:&%L96X`2V]N(&%D<F5S8F]E:R`E<R!N:65T(&]P:&%L96XN
M`$MO;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@;W!H86QE;BX`2V]N(&1I
M<W1R:6)U=&EE;&EJ<W1E;B`E<R!N:65T(&]P:&%L96XN`$MO;B!S97)V97)B
M96MW86%M:&5D96X@;FEE="!O<&AA;&5N`$MO;B!C;VYF:6=U<F%T:64@;FEE
M="!T97)U9WIE='1E;BX`2V]N(&-O;F9I9W5R871I92`E<R!N:65T(&]P<VQA
M86XN`$MO;B!G965N(&)A8VMU<&-O;F9I9W5R871I92!O<'-L86%N+@!+;VX@
M9&4@3$1!4"US97)V97(@;FEE="!D;V]R>F]E:V5N+@!+;VX@861R97,@)7,@
M;FEE="!B:6IW97)K96XN`$MO;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@
M8FEJ=V5R:V5N+@!+;VX@9&4@36]Z:6QL82!3:61E8F%R(&YI970@=FEN9&5N
M+B!:;W)G(&5R=F]O<B!D870@9&4@<VED96)A<B!O<&5N(&ES+@!'971E;&1E
M('1E:W-T`$QA;F0`0W5R<W5S<V5N`$UA:V5N`$UA86L@965N(&QI;FL`36%A
M:R!E96X@;FEE=7=E`$UA86L@<W5B;6%P<&5N`$=E;6%A:W0`16EG96YA87)R
M96-H=&5N`$-R961I=&-A<F1N=6UM97(`2W)O871IZP!#=6)A`$AU:61I9V4@
M=&EJ9`!(=6ED:6=E(%523"!I<P!(=6ED:6<@=V5E<@!(=6ED:6=E(&-O;F1I
M=&EE.B``2'5I9&EG92!S=&EJ;`!!86YP87-S96X@=F%N('1A:V5N('1I:F1E
M;G,@86%N;65L9&EN9R!B:6H@)7,N`$MN:7!P96X`4V5L96-T:64@:VYI<'!E
M;@!#>7!R=7,`0WER:6QL:7-C:"`H2T])."U2*0!#>7)I;&QI<V-H("A7:6YD
M;W=S+3$R-3$I`$-Y<FEL;&ES8V@O56MR86EN<R`H2T])."U5*0!4<VIE8VAI
M<V-H92!297!U8FQI96L`1$0`1&%G96QI:FMS`$1A=&%4<F5E(&)R;W=S97(`
M1&%T=6T`1&%T=6T@3VYT=F%N9V5N`$1A='5M('-E;&5C=&EE`$1A9P!697)?
M=VEJ9&5R(&MO;&]M`$1E8V5M8F5R`$1E8VEM86QE(&=E=&%L;&5N`$EN<W!R
M:6YG96X@=F5R:VQE:6YE;@!3=&%N9&%A<F0@:VQE=7(`4W1A;F1A87)D(&ED
M96YT:71E:70`4W1A;F1A87)D(&YO=&ET:65B;V5K`%-T86YD86%R9"!S;W)T
M965R8W)I=&5R:6$Z`%-T86YD86%R9"!S;W)T965R=F]L9V]R9&4Z`$1E9FEN
M:71I97,`5F5R=VEJ9&5R96X`1W)O97`@=F5R=VEJ9&5R96X`4F5C:'0@=F5R
M=VEJ9&5R96X`5F5R=VEJ9&5R(&5N('=I<R!B97)I8VAT96X`5F5R=VEJ9&5R
M(&-E;`!697)W:6ID97(@:V]L;VT`0F5S=&%A;F0@86QT97)N871I968@<VIA
M8FQO;VX@=F5R=VEJ9&5R96X`5F5R=VEJ9&5R(')I:@!'97-E;&5C=&5E<F1E
M(&ED96YT:71E:70@=F5R=VEJ9&5R96X`5F5R=VEJ9&5R(&1E(&AU:61I9V4@
M:V]L;VT`5F5R=VEJ9&5R(&1E(&AU:61I9V4@<FEJ`$%F;&5V97)T:6ID`$1E
M;F5M87)K96X`069N96UE;F0`0F5S8VAR:6IF(&AE="!P<F]B;&5E;0!"97-C
M:')I:G9I;F<`0F5S8VAR:6IV:6YG.@!$971A:6QS("AO;VL@:6X@2&]R9&4G
M<R!L;V=B97-T86YD*3H`1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y
M<W1E96UB96AE97)D97(N`$]N='=I:VME;&EN9P!$875W<'5N=`!$875W<'5N
M="!V;V]R(&AE="!A9F=E;&]P96X@=75R.B``1&%U=W!U;G0Z(`!2:6-H=&EN
M9R!L:6YK<R!N86%R(')E8VAT`%)I8VAT:6YG(')E8VAT<R!N86%R(&QI;FMS
M`$1I<F5C=&]R>0`R-"UU=7)S('1I:F1W965R9V%V93\`5V5E<F=A=F5O<'1I
M97,`5V5E<G-V;V]R<W!E;&QI;F<@=&]N96X@*%1!1BD`5V5E<F=A=F5F;W)M
M86%T`%9O;W)B97)E:61I;F=S;F]T:69I8V%T:64`1&II8F]U=&D`3FEE="!V
M97)W:6ID97)E;@!M86EN=&5N86YC92YP:'`@;FEE="!D:7)E8W0@86%N<W!R
M96ME;@!"979A="!D92!E97)S=&4@<FEJ(&1E('9E;&1N86UE;C\@6F\@:F$L
M(&1I="!H;VMJ92!A86YV:6YK96XZ`$1O;6EN:6-A`$1O;6EN:6-A86YS92!2
M97!U8FQI96L`1&]W;FQO861E;@`E<R!D;W=N;&]A9&5N`$1O=VYL;V%D(&=E
M9V5N97)E97)D92!C;VYF:6=U<F%T:64@86QS(%!(4"!S8W)I<'0N`$1R;W`@
M9&]W;B!L:6IS=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`0F5W97)K96X`
M0FQO:R!B97=E<FME;@!'<F]E<"!B97=E<FME;@!.;W1I=&EE(&)E=V5R:V5N
M`%)E8VAT(&)E=V5R:V5N`%)E8VAT96X@8F5W97)K96X`4F5C:'1E;B!V86X@
M)R5S)R!B97=E<FME;@!/<'1I97,@8F5W97)K96X@=F]O<CH`4F5C:'1E;B!V
M86X@)7,@8F5W97)K96X`3VYD97)W:6IS`$5G>7!T90!%;"!386QV861O<@!%
M;&5M96YT+BXN`$5M`$4M;6%I;`!%+6UA:6QA9')E<P!%+6UA:6QA9')E<W-E
M;B!M;V5T96X@;W9E<F5E;FMO;65N+@!%+6UA:6P@;65T(&)E=F5S=&EG:6YG
M`$5M;W1I8V]N<P!,96=E(&YO=&ET:64`3&5E9R!B97)I8VAT+@!'965N(')E
M<W5L=&%A="X`3&5G92!Z;V5K=&5R;65N`$EN=F]E9V5N('9A;B!A9F)E96QD
M:6YG96X@=6ET(&9O=&]A;&)U;7,@:6X@=&5K<W0@:6YS8VAA:V5L96X_`%)E
M8VAT:VQI:VME;B!C;VYT97AT(&UE;G4@:6YS8VAA:V5L96X_`$5I;F1J86%R
M`%9E<F=R;V]T(&5D:71O<@!'965F(&5E;B!B979E:6QI9VEN9W-V<F%A9R!D
M:64@=2!G979R86%G9"!W;W)D="P@=V%N;F5E<B!H970@;F]D:6<@:7,@;VT@
M=7<@=V%C:'1W;V]R9"!T92!R97-E='1E;BP@8BYV+B`G=V%T(&ES(&1E(&YA
M86T@=F%N('5W(&AU:7-D:65R/R<Z`%9O97(@9&4@869B965L9&EN9R!54DP@
M:&EE<B!I;@!%<75A=&]R:6%A;"!'=6EN964`17)I=')E80!&;W5T`$9O=70@
M;65T(&4M;6%I;&)E<FEC:'0N`$5S=&QA;F0`171H:6]P:>L`171N:7-C:`!%
M=7)O<&$`16QK92`Q-2!M:6YU=&5N`$5L:V4@,B!M:6YU=&5N`$5L:V4@,S`@
M<V5C;VYD96X`16QK92`U(&UI;G5T96X`16QK92!A86YM96QD:6YG`$5L:R!H
M86QF('5U<@!%;&ME(&UI;G5U=`!6;V]R8F5E;&1W86%R9&5N.@!5:71V;V5R
M96X`56ET:VQA<'!E;@!697)W86-H='1E("<I)P!697)W86-H='1E(&5N:V5L
M('=O;W)D(&]F(&%A;F=E:&%A;&1E('IO96MT97)M`%9E<G9A;&1A='5M`$5X
M<&]N96YT`$5X<&]R=&5R96X`3F]T:71I97,@97AP;W)T97)E;@!6;V]R9W)O
M;F1K;&5U<@!&5%`@=7!L;V%D('9A;B!S971U<`!?5F]L;&5D:6=E('1E:W-T
M`$]P:&%L96X@=F]O<FME=7)S:6YS=&5L;&EN9V5N(&UI<VQU:W0N`%9E<F)I
M;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&ES(&UI<VQU:W0N`%9E<F)I;F1I
M;F<@;65T(&1E(%--0BUS97)V97(@:7,@;6ES;'5K="X`2V]P:>MR96X@=6ET
M("(E<R(@:7,@;6ES;'5K="X`2V]P:>MR96X@;F%A<B`B)7,B(&ES(&UI<VQU
M:W0N`$UA:V5N('9A;B!N:65U=V4@4T%33"!V97)B:6YD:6YG(&ES(&UI<VQU
M:W0N`%9E<G!L86%T<V5N(&YA87(@(B5S(B!I<R!M:7-L=6MT+@!-;V]I`$9A
M;&ML86YD(&5I;&%N9&5N("A-86QV:6YA<RD`1F%R;^MR(&5I;&%N9&5N`$9A
M>`!&96)R=6%R:0!6;V5L="!A;',`5F]E;'0@86QS.B``16YK96QE(&)U:65N
M`$9I:FD`06%N=&%L(&)E<W1A;F1E;CH@)7,@8F5S=&%N9`!!86YT86P@8F5S
M=&%N9&5N.B`E<R!B97-T86YD96X`0F5S=&%N9&)E:&5E<@!"97-T86YD<VYA
M86T`0F5S=&%N9"!K:65Z96X`0F5S=&%N9'5P;&]A9`!"97-T86YD=7!L;V%D
M<R!W;W)D96X@;FEE="!O;F1E<G-T975N9"X`1FEL=&5R<P!&:6YL86YD`$5E
M<G-T92!H96QF=`!%97)S=&4@:W=A<G1A86P`5F5R:&]U9&EN9R!H97)S=&5L
M;&5N`$]M:V5R96X`1')I:G9E;@!-:7-T`$UA<"`E<R!B97-T86%T(&YI970`
M1F]N=&ML975R`%9O961S96P`5F]O<B!B<F]W<V5R<R!D:64@9V5E;B!A9F)E
M96QD:6YG96X@;VYD97)S=&5U;F5N`%=E97)S=F]O<G-P96QL:6YG("A4048I
M`%9O;W)U:71Z:6-H=&1A9V5N("AM97)K(&]P(&1A="!H970@9V5G979E;B!V
M;V]R=6ET>FEC:'0@9&%G96X@96X@;F%C:'1E;B!G965F=#L@965N(&=R;V]T
M(&%A;G1A;"!K86X@<F5S=6QT97)E;B!I;B!E96X@8G)E960@8FQO:RD`57<@
M=V%C:'1W;V]R9"!V97)G971E;C\`1F]R;75L:65R96X`1F]R='5N90!&;W)T
M=6YE='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!$;V]R<W1U<F5N
M`%9R`$9R86UE<P!&<F%N:W)I:FL`1G)A;FMR:6IK+"!(;V]F9'-T961E;&EJ
M:P!&<F%N<R!'=7EA;F$`1G)A;G,@4&]L>6YE<VGK`$9R86YS92!:=6ED96QI
M:FME(%1E<G)I=&]R:6$`5F%N`%9A;B!D92``5F]L;&5D:6=E(&)E<V-H<FEJ
M=FEN9P!6;VQL92!M86%N`%9O;&QE9&EG92!N86%M`$=A8F]N`$%L8G5M('=A
M87)U:70@9&4@869B965L9&EN9R!G96AA86QD(&1I96YT('1E('=O<F1E;@!!
M;&)U;3H`1V%M8FEA`$=E;F5R965R("5S(&-O;F9I9W5R871I90!'96=E;F5R
M965R9&4@8V]D90!'96]R9VGK`$1U:71S;&%N9`!':&%N80!':6)R86QT87(`
M5F]O<FYA86T`1V$`1V]E9&5L`$=O;V=L92!Z;V5K96X`1W)I:G-S8VAA86P`
M1W)I96ME;FQA;F0`1W)I96MS("A)4T\M.#@U.2TW*0!'<F]E;FQA;F0`1W)E
M;F%D80!'<F]E<'-B96AE97(`1W)O97!N86UE;B!M;V=E;B!N:65T(&QE96<@
M>FEJ;@!'<F]E<&5N`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS
M97D`1V%S="!R96-H=&5N`$=A<W1E;F)O96L`1W5I;F5E`$=U:6YE92U":7-S
M874`1W5Y86YA`$A434P`2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@;&%A
M='-T92!C96P@:6X@9&4@<FEJ('1E('9E<G=I:F1E<F5N+@!(5$U,07)E82!W
M96EG97)T(&QA9B!O;2!D92!L86%T<W1E(&MO;&]M(&EN(&1E('1A8F5L('1E
M('9E<G=I:F1E<F5N+@!(5$U,07)E82!W96EG97)T(&QA9B!O;2!D92!L86%T
M<W1E(')I:B!I;B!D92!T86)E;"!T92!V97)W:6ID97)E;BX`2%144"!A=71H
M96YT:6-A=&EE(&YI970@9V5V;VYD96XN`$AA:71I`$AA<V@M86QG;W)I=&AM
M90!.979E;`!+;W``2&5A<F0@96EL86YD(&5N($UC1&]N86QD(&5I;&%N9&5N
M`$AE8G)E975W<R`H25-/+3@X-3DM."U)*0!(;V]G=&4`2&5L<`!(96QP(&)I
M:B!G96)R=6EK('9A;B!E9&ET;W(`2&5L<&5R`$AA;&9R;VYD`$AI97(@:7,@
M:&5T(&)E9VEN('9A;B!H970@8F5S=&%N9#H`2&]O9P!(;U]M90!(;VQY(%-E
M92`H5F%T:6-A86YS=&%D*0!(;VUE`$%D<F5S("AP<FEVZ2D`5&5L+FYR+B`H
M<')I=NDI`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@
M3VYG96QD:6=E("5S(%A-3"!D871A('1E9V5N9V5K;VUE;B!I;B!B97)I8VAT
M("5S`$AO<F1E+TMO;&%B.B!'965N(&)E<FEC:'0@8V]R<F5S<&]N9&5E<G0@
M;65T(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@1V5E;B!O8FIE8W0@=F%N('1Y
M<&4@)7,@9V5V;VYD96X@:6X@8F5R:6-H="`E<P!(;W)D92]+;VQA8CH@)7,@
M;65T('-U8V-E<R!V97)W:6ID97)D("(E<R(`2&]R9&4O2V]L86(Z($1E(&EN
M=&5R9W)A=&EE('9E<F5I<W0@9&4@)V1O;7AM;"<@97AT96YS:64`2&]R9&4O
M2V]L86(Z($MA;B!G965N(&YI975W92!834P@8F]O;2!M86ME;B!V;V]R(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@2V%N("5S("(E<R(@;FEE="!V97)W:6ID
M97)E;CH@)7,`2&]R9&4O2V]L86(Z($YI970@:6X@<W1A870@:&5T($U)344@
M240L('9O;W(@:&5T(&=E9&5E;'1E(&UE="!T>7!E("5S+"!O<"!T92!H86QE
M;@!(;W)D92]+;VQA8CH@2V%N("5S("(E<R(@;FEE="!S>6YC:')O;FES97)E
M;CH@)7,`2&]R9&4O2V]L86(Z($MA;B!G961E96QD92!B<F]N;F5N(&YI970@
M<WEN8VAR;VYI<V5R96XZ("5S`$AO<F1E+TMO;&%B.B!/;F)E:V5N9&4@9V5D
M965L9&4@8G)O;B`B)7,B`$AO<FEZ;VYT86QE(&QI:FX`2&]R:7IO;G1A;&4@
M=G)I:F4@<G5I;71E`$AO<FEZ;VYT86%L.@!(;V4@:W=A;2!U(&AI97(_("A'
M<F%A9R!R87!P;W)T86=E(2D`2&]E=F5E;"!K;VQO;6UE;B!W:6QT('4@<V%M
M96YV;V5G96X_`$AO979E96P@=F5L9&5N("AK;VQO;6UE;BD@>FEJ;B!E<C\`
M2&]E=F5E;"!R:6IE;B!W:6QT('4@<V%M96YV;V5G96X_`%9O8VAT:6=H96ED
M`%9O8VAT:6=H96ED.B``2'5M;W)I<W1E;@!(;VYG87)I:F4`36%K96X@=F%N
M($E-05`@;6%I;&)O>"!M:7-L=6MT.B`E<P!697)W:6ID97)E;B!V86X@24U!
M4"!M86EL8F]X(&UI<VQU:W0Z("5S`$UA:V5N('9A;B!)34%0(&UA:6QB;W@@
M<75O=&$@;6ES;'5K=#H@)7,`25`@061R97,`25`@861R97,@;FEE="!B97-C
M:&EK8F%A<BX`25`@861R97,@=F%L="!N:65T(&)I;FYE;B!H970@=&]E9V5S
M=&%N92!#2412(&)L;VLN`$E0(&QO8VMD;W=N(&]V97)T<F5D:6YG+@!2:6H@
M:5]N=F]E9V5N('9O;W(`24IS;&%N9`!!;&QE96X@<&EC=&]G<F%M;65N`%!I
M8W1O9W)A;6UE;B!M970@=&5K<W0`261E;G1I=&5I='-N86%M.@!786YN965R
M(&AE="!N:65T(&=O960@=V]R9'0@=V5E<F=E9V5V96XL("5S(&]M(&AE="!I
M;B!E96X@;FEE=7<@<V-H97)M('1E(&]P96YE;BX`06QS('4@9V5E;B!P:6-T
M;V=R86UM96X@>FEE="P@8FEJ(&=E8G)U:6L@=F%N($EN=&5R;F5T($5X<&QO
M<F5R+"!K86X@:&5T(&YO9&EG('II:FX@9&ET('9A:VIE(&%A;B!T92!V:6YK
M96X@;VT@4$Y'('1R86YS<&%R871I92!U:70@=&4@<V-H86ME;&5N+@!786YN
M965R('4@9&ET(&)E<FEC:'0@>FEE="P@;6%A<B!G965N(&%F8F5E;&1I;F<L
M(&1A;B!K86X@9&4@869B965L9&EN9R!D:64@=2!W:6QT('5P;&]A9&5N(&YI
M970@9&]O<B!U=R!B<F]W<V5R('=O<F1E;B!W965R9V5G979E;BX`069B965L
M9&EN9W-B96]O<F1E;&EN9SH`069B965L9&EN9R!54DP`069B965L9&EN9R!5
M4DPZ`$%F8F5E;&1I;F<@=6ET(&%L8G5M`$%F8F5E;&1I;F<@=6ET(&%L8G5M
M.@!!9F)E96QD:6YG<W5P;&]A9`!!9F)E96QD:6YG96X`3F]T:71I97,@:6UP
M;W)T97)E;BP@<W1A<"`E9`!);7!O<G1E<F5N+"!S=&%P("5D`$YO=&ET:65S
M(&EM<&]R=&5R96XO97AP;W)T97)E;@!'96EM<&]R=&5E<F0@=F5L9#H@)7,`
M1V5I;7!O<G1E97)D92!V96QD96XZ`%)I:B!I;G9O96=E;B!N80!/;FIU:7-T
M92!B97=E<FMI;F=S8V]D92!O<&=E9V5V96XN`$]N:G5I<W1E(&=E8G)U:6ME
M<G-N86%M(&5N+V]F('=A8VAT=V]O<F0N`$]N:G5I<W1E(&=E8G)U:6ME<G-N
M86%M(&]F(&%L=&5R;F%T:65F(&%D<F5S+B!0<F]B965R(&]P;FEE=7<@;V8@
M;F5E;2!C;VYT86-T(&]P(&UE="!D92!S>7-T965M8F5H965R9&5R+"!W86YN
M965R('4@=F5R9&5R92!H=6QP(&YO9&EG(&AE969T+@!697)G<F]O="!I;G-P
M<FEN9VEN9P!);F1I80!);F1I=FED=65L92!G96)R=6EK97)S`$EN9&]N97-I
MZP!);F9O`$EN9F]R;6%T:64`2V]L;VT@:6YV;V5G96X@;F$`069B965L9&EN
M9R!I;G9O96=E;@!486)E;"!I;G9O96=E;@!796)L:6YK(&EN=F]E9V5N`%]+
M;VQO;2!I;G9O96=E;B!V;V]R`$5E;B!N:65U=V4@:V]L;VT@:6YV;V5G96X@
M;F$@9&4@:'5I9&EG90!%96X@;FEE=7=E(&MO;&]M(&EN=F]E9V5N('9O;W(@
M9&4@:'5I9&EG90!%96X@;FEE=7=E(')I:B!I;G9O96=E;B!N82!D92!H=6ED
M:6=E`$5E;B!N:65U=V4@<FEJ(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4`165N
M(&YI975W92!P87)A9W)A868@:6YV;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E
M`$5E;B!N:65U=V4@<&%R86=R86%F(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4@
M;F]D90!!;'1E<FYA=&EE9B!S:F%B;&]O;B!I;G9O96=E;@!%96X@92UM86EL
M861R97,@:6YV;V5G96XL('=A87(@=2!H970@;FEE=7=E('=A8VAT=V]O<F0@
M:V%N(&]N='9A;F=E;CH`0V5L(&EN=F]E9V5N(&YA`$-E;"!I;G9O96=E;B!V
M;V]R`$MO;&]M(&EN=F]E9V5N(&YA`$MO;&]M(&EN=F]E9V5N('9O;W(`0F5R
M:6-H=&5N(&EN=F]E9V5N`%!A<F%G<F%A9B!I;G9O96=E;B!N80!087)A9W)A
M868@:6YV;V5G96X@=F]O<@!2:6H@:6YV;V5G96X@;F$`4FEJ(&EN=F]E9V5N
M('9O;W(`2&5T(&=E=V5N<W1E(&%N='=O;W)D('9O;W(@9&4@8F5V96EL:6=I
M;F=S=G)A86<@:6YV;V5G96XZ`$%F8F5E;&1I;F<@:6YV;V5G96XO86%N<&%S
M<V5N`$QI;FL@:6YV;V5G96XO86%N<&%S<V5N`$]N=F]L9&]E;F1E(&MR961I
M970@;VT@;F%A<B!D92!D:7-T<FEB=71I96QI:G-T('1E('IE;F1E;BX`3VYV
M;VQD;V5N9&4@:W)E9&EE=`!);G1E9V5R`$EN=&5G97(@;&EJ<W0`3VYG96QD
M:6=E(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!/;F=E;&1I9V4@=&]E<&%S
M<VEN9RX`3VYG96QD:6<@8F%T8V@@240N`$]N9V5L9&EG92!D871A(&]P9V5G
M979E;BX`3VYG96QD:6<@8F5S=&5M;6EN9V%D<F5S+@!/;F=E;&1I9R!T:6ID
M9F]R;6%A=`!/;F=E;&1I9R!M<V=?='EP92X`3VYG96QD:6<@;V8@;VYT8G)E
M:V5N9"!A<&E?:60N`$]N9V5L9&EG92!O9B!O;G1B<F5K96YD92!P87)A;65T
M97)S+@!/;F=E;&1I9R!P87)E;G0@<F5C:'0N`$]N9V5L9&EG('!R;W1O8V]L
M+@!/;F=E;&1I9V4@9V5D965L9&4@8G)O;@!/;F=E;&1I9R!B<F]N861R97,N
M`$]N9V5L9&EG92!U;FEC;V1E(&1A=&$N`$EN=F5N=&%R:7,`27)A;BP@27-L
M86UI=&ES8VAE(%)E<'5B;&EE:R!V86X`27)A:P!)97)L86YD`$5I;&%N9"!-
M86X`1V5I<V]L965R9&4@;VYW965R<V)U:65N`$ES<F'K;`!5:71G979E<@!#
M=7)S:65F`$ET86QIZP!*86UA:6-A`$IA;G5A<FD`2F%P86X`2F%P86YS("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FGK`$IU;&D`2G5N:0!U:71L:6IN
M96X`1V5C96YT<F5E<F0@=6ET;&EJ;F5N`%9O;&QE9&EG('5I=&QI:FYE;@!,
M:6YK<R!U:71L:6IN96X`4F5C:'1S('5I=&QI:FYE;@!+87IA8VAS=&%N`$]R
M:6=I;F5E;"!B96AO=61E;C\`2V5N:6$`2V5R8F5R;W,@<V5R=F5R('=E:6=E
M<F1E(&%U=&AE;G1I8V%T:64N`$ME<FYE;"!.97=B:65S`%-L975T96P@;6%K
M96X`4VQE=71E;'9I;F=E<F%F9')U:P!3;&5U=&5L;&5N9W1E`%-L975T96QT
M>7!E`%-L975T96QG96)R=6EK`$1E('-L975T96P@8F5S=&%A="!A;"!O<"!D
M92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+@!+:6YD97)E;@!+:7)I8F%T:0!+
M;W)E82P@1&5M;V-R871I<V-H92!6;VQK<W)E<'5B;&EE:R!V86X`2V]R96$L
M(%)E<'5B;&EE:R!V86X`2V]R96%A;G,@*$550RU+4BD`2V]E=V5I=`!+>7)G
M:65S:>L`3U]P;6%A:P!486%L`$1E;6]C<F%T:7-C:&4@5F]L:W-R97!U8FQI
M96L@3&%O`$QA871S=&4@:&5L9G0`3&%A='-T(&=E=VEJ>FEG9`!,86%T<W1E
M(&MW87)T:65R`$QA871S="!B:6IG97=E<FMT.@!,86%T<W1E(&%A;FUE;&1I
M;F<Z("5S`$QA871S=&4@86%N;65L9&EN9SH@)7,@=F%N("5S`$QA871S=&4@
M86%N;65L9&EN9SH@3F]O:70`3&5T;&%N9`!296-H=&5N`$]P;6%A:P!,86%T
M(&QE96<@=F]O<B!G965N(')A;F0`3&EB86YO;@!,:6YK<P!,:6YK<V4@:V]P
M`$QI;FMS92!W86%R9&5N`$QE<V]T:&\`3&EB97)I80!,:6)I<V-H92!!<F%B
M:7-C:&4@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`%IA8VAT(&)U:71J90!,
M:6-H=&4@<F5G96X`5G)O96<@;&EC:'1E(')E9V5N`$QI8VAT92!R96=E;@!,
M:6-H=&4@<F5G96YB=6D`3&EC:'1E(')E9V5N(&UE="!O;G=E97(`3&EC:'1E
M('-N965U=P!,:6-H=&4@<VYE975W8G5I`$QI;65R:6-K`$QI;FL`3&EN:R!W
M:6IS="!N86%R.@!,:6YK(&AE="!E+6UA:6QA9')E<R!A86X@9&4@;FEE=7<@
M8F5R:6-H="!P86=I;F$@=&EJ9&5N<R!W965R9V%V90!,:6YK<P!,:6YU>"!#
M;V]K:64`3&EJ<W0@+2!G96)R=6EK97(@:V%N(&1E(&UA<"!Z:65N`$1A=&%B
M87-E;&EJ<W0`3&EJ<W0@=F%N(&AE;'`@;VYD97)D96QE;@!486)E;&QI:G-T
M`$QI:G-T+4%R8VAI968`3&EJ<W0M2&5L<`!,:6IS="U)9`!,:6IS="U%:6=E
M;F%A<@!,:6IS="U0;W-T`$QI:G-T+4EN<V-H<FEJ=F5N`$QI:G-T+55I='-C
M:')I:G9E;@!7965R9V5V96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!U:71G
M97-C:&%K96QD+@!,:71E<F%T=75R`$QI=&]U=V5N`$QA9&5N+BXN`$QO:V%L
M92!T:6ID.@!,86YD:6YS=&5L;&EN9R!E;B!T:6ID`$QO8V%T:64`06%N;65L
M9&5N`$%F;65L9&5N`$%A;FUE;&1T86ME;@!!86YM96QD:6YG(&UI<VQU:W0@
M;VUD870@=7<@9V5B<G5I:V5R<VYA86T@;V8@=V%C:'1W;V]R9"!O;FIU:7-T
M(&ES(&EN9V5V;V5R9"X`06%N;65L9&EN9R!M:7-L=6MT+@!,86YG92!T96MS
M=`!,:65F9&4`3&%A9P!'<FEE:W-E(&ML96EN92!L971T97)S`$QA=&EJ;G-E
M(&ML96EN92!L971T97)S`$ML96EN92!2;VUE:6YS92!G971A;&QE;@!,=7AE
M;6)U<F<`34T`34]41`!-4RU43D5&(&)I:FQA9V4@8F5V871T92!G965N(&1A
M=&$N`$U31P!-86-A;P!-86-E9&]N:>LL($1E('9R;V5G97)E($IO96=O<VQA
M=FES8VAE(%)E<'5B;&EE:R!V86X`36%D86=A<V-A<@!-86=I90!%+6UA:6P`
M36%I;&)E:&5E<F1E<@!-86%K(&QI;E]K+BXN`$UA;&%W:0!-86QE:7-IZP!-
M86QA9&EV96X`36%L:0!-86QT80!"96AE97(@=7<@;&EJ<W0@;65T(&-A=&5G
M;W)I9>MN(&5N(&1E(&-O<G)E<W!O;F1E<F5N9&4@:VQE=7)E;BP@=V%A<FUE
M92!O;F1E<F1E;&5N('=O<F1E;B!G96QA8F5L9`!-87`R-"!K86%R=`!-87!1
M=65S=&MA87)T`$UA87)T`$UA<F=E`$UA<FME97(@;65T($=E>FEE;B].:65T
M($=E>FEE;B!V;&%G9V5N`$UA<FME97(@;65T(&%N9&5R92!V;&%G9V5N("AB
M+G8N($)E;&%N9W)I:FLO0F5A;G1W;V]R9"D`36%R8VAA;&P@96EL86YD96X`
M36%R=&EN:7%U90!/=F5R965N:V]M96YD92!V96QD96X`36%U<F5T86YIZP!-
M875R:71I=7,`36%X:6UA86P@=&]E9V5S=&%A;B!K<F5D:65T+@!-87AI;75M
M(&)E<FEC:'1O;F1E<F1E;&5N(&]V97)S8VAR961E;BX`36%X:6UU;2!T96UP
M97)A='5U<B!V86X@9&4@869G96QO<&5N(#(T('5U<CH@`$UA>&EM=6T@=&5M
M<&5R871U=7(@=F%N(&1E(&%F9V5L;W!E;B`V('5U<CH@`$UA>&EM86QE(&QE
M;F=T90!-96D`36%Y;W1T90!'96YE97-K=6YD90!,961E;@!.;W1I=&EE=&5K
M<W0`365N=2!M;V1E.@!#96QL96X@<V%M96YV;V5G96X`0F5R:6-H=`!"97)I
M8VAT(&UE="!S=6-C97,@9V5V97)I9FEE97)D+"!M86%R(&AE="!C97)T:69I
M8V%A="!V86X@9&4@;VYD97)G971E:V5N9&4@:V]N(&YI970@=V]R9&5N(&=E
M=F5R:69I965R9"X`0F5R:6-H="!V97)L;W!E;BX`0F5R:6-H='1Y<&4`365T
M87(@5V5E<@!-151!4B!B;&]K(&ES(&YI970@8F5S8VAI:V)A87(N`$U%5$%2
M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX@1&5T86EL<R!Z:6IN(&=E;&]G
M9"!V;V]R(&1E('-Y<W1E96UB96AE97)D97(N`$UE=&AO9&4`365T<FES8V@`
M365X:6-O`$UI8W)O;F5S:>LL($9E9&5R86QE(%-T871E;B!V86X`36ED9&5N
M`$UI;64@='EP90!-:6YI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P
M96X@,C0@=75R.B``36EN:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO
M<&5N(#8@=75R.B``36ER<F]R`$%L;&5R:&%N9&4`3VYT8G)E:V5N9&4@4$5!
M4B!M;V1U;&4@2%144%]297%U97-T+@!/;G1B<F5K96YD92!C;VYF:6=U<F%T
M:64N(%4@9&EE;G0@9&5Z92!N=2!T92!G96YE<F5R96XL('=A;FYE97(@=2!D
M97IE('1O97!A<W-I;F<@=VEL="!G96)R=6EK96XN`$]N=&)R96ME;F0@8F5R
M:6-H="!)1"X`3VYT8G)E:V5N9&4L('9E<F5I<W1E+"!014%2(&UO9'5L92!-
M86EL+@!/;G1B<F5K96YD('-E<W-I92!)1"X`36$`36]B:65L92!E+6UA:6P`
M1V5M:61D96QD`%=I:GII9VEN9W-D871U;0!7:6IZ:6<@55),`"5S(&)E=V5R
M:V5N`$UO9'5L=7,`36]L9&%V:>LL(%)E<'5B;&EE:R!V86X`36]N86-O`$UO
M;F=O;&GK`$UA86YD(&5N(&IA87(`36%A;F1E;&EJ:W,`36]N='-E<G)A=`!-
M86%N9F%S96X`36%R;VMK;P!6;V]R;F%M96QI:FL@;VYB97=O;&MT`%9O;W)N
M86UE;&EJ:R!B97=O;&MT`%9O;W)N86UE;&EJ:R!Z;VYN:6<`3F%A<B!B96YE
M9&5N`$YA87(@;&EN:W,`3F%A<B!R96-H=',`3F%A<B!B;W9E;@!.86%R(&)E
M;F5D96X`3F%A<B!B;W9E;@!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:6IS=&5N`$UE97)V;W5D:6=E('-E;&5C=&EE`$UI:FX@86-C;W5N
M=`!-:6IN(&YO=&ET:65S`$UI:FX@<&]R=&%A;`!-:6IN('!O<G1A86QL87EO
M=70`0FER;6$`3F5E+"!I:R!A8V-E<'1E97(@9&4@=F]O<G=A87)D96X@3DE%
M5`!.86%M`$YA;6EB:>L`3F%U<G4`3F5P86P`3F5D97)L86YD`$YE9&5R;&%N
M9',@06YT:6QL96X`3F5T<V-A<&4@0F%S:7,@55),`$YE='-C87!E($-!(&EN
M=')E:VMI;F<@55),`$YE='-C87!E($-!(&)E;&5I9"!54DP`3F5T<V-A<&4@
M=F5R;FEE=7=I;F<@55),`$YE='-C87!E(&EN=')E:VMI;F<@55),`$YE='-C
M87!E(%-33"!S97)V97)N86%M`$YE='-C87!E(&-E<G1I9FEC86%T8V]M;65N
M=&%A<@!.971S8V%P92!C97)T:69I8V%A='1Y<&4`3F5T=V5R:P!.;V]I=`!.
M:65U=R!#86QE9&]N:>L`3FEE=7=E(&-A=&5G;W)I90!.:65U=V4@;6%A;@!.
M:65U=V4@;F]T:71I90!.:65U=V4@9V5B<G5I:V5R<VYA86T@*&]P=&EO;F5E
M;"D`3FEE=7<@6F5E;&%N9`!.:65U=R!S8VAE<FT@*%]B;&%N:RD`3FEE=7=S
M`$YI975W<V=R;V5P96X`5F]L9V5N9&4`5F]L9V5N9&4@;W!T:65S`$YI8V%R
M86=U80!.:6=E<@!.:6=E<FEA`$YA8VAT`$YI=64`3F5E`$=E96X@8F5S8VAI
M:V)A<F4@8V]N9FEG=7)A=&EE9&%T82!O;2!V97)S8VAI;&QE;B!T92!L871E
M;B!Z:65N+@!'965N(&)E<V-H:6MB87)E('-T<F%T96=I92!V;V]R(&AE="!M
M86ME;B!V86X@25-/(&EM86=E<RX`1V5E;B!B871C:'-J86)L;V]N+@!%<B!B
M97-T86%T(&=E96X@8FQO:R!O<"!D92!G979R86%G9&4@<&]S:71I90!'965N
M(&%G96YD86YA86T@;W!G96=E=F5N('9O;W(@34-!3"!A=71H96YT:6-A=&EE
M+@!'965N('=I:GII9VEN9V5N+@!!86X@9&ET(')E8VAT(&MU;FYE;B!G965N
M(&-H:6QD(')E8VAT96X@=V]R9&5N('1O96=E=F]E9V0N`$=E96X@8V]N9FEG
M=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B`E<RX`1V5E;B!C;VYF
M:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R($944"!61E,N`$=E
M96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!344P@
M5D93+@!'965N(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O
M;W(@4U%,+6)E<W1A;F0@5D93+@!'965N(&MR961I970@;65E<BX`1V5E;B!B
M97-T96UM:6YG(&]P9V5G979E;BX`1V5E;B!B97-T86YD('5P;&]A9&5D`$5R
M(&ES(&=E96X@;&]C871I92!I;F=E<W1E;&0N`$=E96X@8F5R:6-H="!G96QE
M=F5R9"X`1V5E;B!N86%M(&]P9V5G979E;BX`1V5E;B!N;W1I=&EE8F]E:V5N
M(&)E<V-H:6MB86%R('9O;W(@9V%S=&5N+@!'965N(&YO=&ET:65S`$=E96X@
M;F]T:71I97,@9&EE(&]V97)E96X@:V]M96X@;65T(&1E(&AU:61I9V4@8W)I
M=&5R:6$N`$=E96X@;F]T:71I97,@=V5E<B!T92!G979E;@!'965N(&=E=&%L
M(&]P9V5G979E;BX`1V5E;B!B96QE9&EG96YD92!F;W)T=6YE<P!'965N('=A
M8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@2%144"!A=71H96YT:6-A=&EE+@!'
M965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@24U!4"!A=71H96YT:6-A
M=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9A;B!+97)B97)O<R!A
M=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@
M3&]G:6X@875T:&5N=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E
M;B!V;V]R(%!!4U-71"!A=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@
M;W!G96=E=F5N('9O;W(@4TU"(&%U=&AE;G1I8V%T:64N`$=E96X@<&%D(&YA
M87(@9&4@3W!E;E-33"!B:6YA<GD@;W!G96=E=F5N+B!$92!/<&5N4U-,(&)I
M;F%R>2!I<R!N;V1I9R!O;2!T92!K=6YN96X@=V5R:V5N(&UE="!02T-3(#$R
M(&1A=&$N`$=E96X@:&%N9V5N9&4@:6YS8VAR:6IV:6YG96XN`$=E96X@;&EN
M:>MR:6YG`$=E96X@>FEJ9&5N`$=E96X@=&EJ9&5L:6IK(&1I<F5C=&]R>2!B
M97-C:&EK8F%A<B!V;V]R(&-A8VAE+@!'965N(&=E8G)U:6ME<G-N86%M(&5N
M+V]F('=A8VAT=V]O<F0@=F5R>F]N9&5N+@!'965N(&=E;&1I9V4@6$U,(&1A
M=&$@=&5R=6=G97-T=75R9`!'965N('=A87)D96X`1V5E;B!V97)S:64@9V5V
M;VYD96X@:6X@;W)I9VEN96QE(&-O;F9I9W5R871I92X@2&5R9V5N97)E97(@
M8V]N9FEG=7)A=&EE+@!'965N('9E<G-I92!G979O;F1E;B!I;B!U=R!C;VYF
M:6=U<F%T:64N($AE<F=E;F5R965R(&-O;F9I9W5R871I92X`3F]?=&ET:64`
M1V5E;@!'965N("AV97)P;&EC:'0I`$YO;W)D($5U<F]P965S("A)4T\M.#@U
M.2TQ,"D`3F]R9F]L:R!E:6QA;F0`3F]O<F1E;&EJ:R!H86QF<F]N9`!-87)I
M86YE;@!.;V]R=V5G96X`3FEE="!N80!.:65T('9O;W(`1V5E;B!D:7)E8W1O
M<GD`3FEE="!G96EM<&QE;65N=&5E<F0N`$YI970@:6YG97-T96QD`$YI970@
M;VYD97)S=&5U;F0N`$YO=&ET:65C871E9V]R:64`3F]T:71I961E=&%I;',`
M3F]T:71I96QI:G-T96X`3F]T:71I971E:W-T`$YO=&ET:65T7V5K<W0`3F]T
M:71I92!N:65T(&=E=F]N9&5N+@!.;W1I=&EE7V)O96L`3F]T:71I96)O96MN
M86%M.@!.;W1I=&EE8F]E:V5N`$YO=&ET:65S`$YO=&ET:65S86UE;G9A='1I
M;F<`3FEE=',@=&4@8FQA9&5R96XL(&=A('1E<G5G+@!.;W9E;6)E<@!'971A
M;`!!86YT86P@:V%R86MT97)S`$%A;G1A;"!K;VQO;6UE;@!!86YT86P@<FEJ
M96X`1V5T86QL96X@;FEE="!O<&=E9V5V96X@=F]O<B!B:6IW97)K96X@:6X@
M965N(&1I<W1R:6)U=&EE;&EJ<W0N`$]+`$]B:F5C=`!/8FIE8W1E:6=E;F%A
M<@!/8W1A86P`3VMT;V)E<@!"96QE9&EG:6YG9FEL=&5R`$MA;G1O;W(`3VUA
M;@!!;&QE96X@24U!4"!S97)V97)S(&]N9&5R<W1E=6YE;B!G961E96QD92!M
M87!P96XN`$%L;&5E;B!B96QE9&EG96YD92!F;W)T=6YE<P!3;&5C:'0@Z>EN
M(&4M;6%I;&%D<F5S('1O96=E<W1A86XN`$%L;&5E;B!D92!E:6=E;F%A<B!O
M9B!E96X@<WES=&5E;6)E:&5E<F1E<B!M86<@9&4@96EG96YA87)R96-H=&5N
M('9A;B!E96X@<VAA<F4@=VEJ>FEG96X`3W!E;B!I;B!E96X@;FEE=7<@<V-H
M97)M`$]P96Y34TP@9F]U=#H@:V]N(&=E96X@9&%T82!U:70@:&5T(&]N9&5R
M=&5K96YD92!3+TU)344@;VYD97)D965L(&AA;&5N+@!/<&5N="!D97IE(&QI
M;FL@:6X@965N(&YI975W('-C:&5R;0!"97-T=7)I;F=S<WET965M`$]P=&EE
M<P!/<'1I97,@=F]O<B`E<P!'96]R9&5N9&4@;&EJ<W0`3W)G86YI<W1A=&EE
M`$]R9V%N:7-A=&EE(&5E;FAE:60`3W)G86YI<V5R96X`3W)I9VEN965L('1O
M97!A<W-I;F=S<VIA8FQO;VX`3W)I9VEN96QE('-J86)L;VYE;B!I;B`E<SH`
M06YD97)E`$%N9&5R92!I;F9O<FUA=&EE`$%N9&5R92!O<'1I97,`16EG96YA
M87)R96-H=&5N`%!!32!A=71H96YT:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A
M87(N`$1I9VET86QE(%!'4"!H86YD=&5K96YI;F<`1V5C;V1E97)D92!01U`@
M9&%T80!/<&5N8F%R92!01U`@<VQE=71E;`!/;F1E<G1E:V5N9&4O9V5C;V1E
M97)D92!01U`@9&%T80!02%`@8V]D90!02%`@<VAE;&P`3&EC:'1E(')E9V5N
M(&YA(#$R+C`P('5U<@!"=6EE;B!N82`Q,BXP,"!U=7(`3VYW965R<V)U:65N
M(&YA(#$R+C`P('5U<@!02%`@7U-H96QL`%9R:6IE(')U:6UT90!086MI<W1A
M;@!086QA=0!086QE<W1I:FYS(%1E<G)I=&]R:75M+"!"97IE=`!086YA;6$`
M4&%P=6$@3FEE=7<@1W5I;F5A`%!A<F%G=6%Y`$=E9&5E;'1E;&EJ:R!B97=O
M;&MT`%=A8VAT=V]O<F0`5V%C:'1W;V]R9"!O;FIU:7-T`%=A8VAT=V]O<F0@
M:7,@=F5R96ES="!V;V]R(%)!1$E54R!A=71H96YT:6-A=&EE+@!786-H='=O
M;W)D(&UE="!B979E<W1I9VEN9P!786-H='=O;W)D.@!786-H='=O;W)D.B``
M5V%C:'1W;V]R9&5N(&UO971E;B!O=F5R965N:V]M96XN`%!L86MK96X`4&QA
M:VME;B!V86YA9B!P<FEK8F]R9`!0860`2&%N9V5N9&4@:6YS8VAR:6IV:6YG
M96XZ`$UE;G-E;@!0<F]C96YT`$]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I
M='9O97)E;@!/;F1E<FAO=61S=V5R:WIA86UH961E;B!U:71V;V5R96X@8FEJ
M(&%A;FUE;&1I;F<_`%)E8VAT`%1O96=A;F<@9V5W96EG97)D`%)E8VAT96X`
M4F5C:'1E;F)E:&5E<@!097)S;V]N;&EJ:V4@:6YF;W)M871I90!097)U`$AU
M:7-D:65R96X`4&AI;&EP<&EJ;F5N`%1E;&5F;V]N`$9O=&\G<P!0:71C86ER
M;@!0:7AE;',`4&QA=&ET=61E<P!+;&EK(&EN(&5E;B!C96PL(&$N=2YB+@!"
M979E<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!V97)W:6ID97)E;BP@
M82YU+F(Z`$)E=F5S=&EG+"!D870@=2!D:70@96QE;65N="!W:6QT(&QO<VMO
M<'!E;&5N+"!A+G4N8BX`1V5E9B!E96X@;6%A;F0@96X@965N(&IA87(L(&$N
M=2YB+@!%96X@;F%A;2!V;V]R(&1E(&YI975W92!C871E9V]R:64@:6YV;V5R
M96XL(&$N=2YB+CH`1V5E9B!E96X@9V5L9&EG($E0(&%D<F5S+"!A+G4N8BX`
M1V5E9B!E96X@9V5L9&EG92!D871U;2!A+G4N8BXL(&-O;G1R;VQE97(@:&5T
M(&%A;G1A;"!D86=E;B!I;B!D92!M86%N9"X`1V5E9B!E96X@9V5L9&EG92!T
M:6ID+"!A+G4N8BX`1V5E9B!E96X@<V%M96YV871T:6YG('9A;B!H970@<')O
M8FQE96TL(&$N=2YB+@!'965F('5W(&=E8G)U:6ME<G-N86%M(&5N('=A8VAT
M=V]O<F0L(&$N=2YB+@!'965F(&1E(&YI975W92!C871E9V]R:65N86%M+"!A
M+G4N8BXZ`%!O;&5N`%!O;&ET:65K`%!E:6QI;F=E;@!0;W)T=6=A;`!0;W-I
M=&EO;F5R:6YG('9A;B!D97IE(&%F8F5E;&1I;F<`4&]S:71I;VYE<FEN9R!V
M86X@9&5Z92!T86)E;`!3='5U<B!N86%R(&1E>F4@;6%P("AN:65T(&%F9V5D
M=V]N9V5N(&1O;W(@24U!4"D`3F5E<G-L86<@=F%N(&1E(&%F9V5L;W!E;B`E
M<R!U<F5N.B``4')E9G-?;&1A<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N
M:65T(&=E=F]N9&5N+@!0<F5F<U]S97-S:6]N.B!V97)E:7-T92!S97-S:64@
M97AT96YT:64@;FEE="!G979O;F1E;BX`3'5C:'1D<G5K`$QU8VAT9')U:R!O
M<"!Z965N:79E874Z(`!,=6-H=&1R=6LZ(`!"96]O<F1E;&5N`$)E;V]R9&5E
M;"!D92!A9F)E96QD:6YG(&EN(&5E;B!N:65U=R!S8VAE<FT`5F]R:6=E(&]P
M=&EE<P!$;V-U;65N="!A9F1R=6MK96X`4')I=F4@<VQE=71E;`!0<F]B;&5E
M;0!0<F]B;&5E;6)E<V-H<FEJ=FEN9P!0<F]J96-T96X`4')O;7!T('1E:W-T
M`$]P96YB87)E('-L975T96P`3W!E;F)A<F4@<VQE=71E;"!A;&=O<FET:&UE
M`$]P96YB86%R+U!R:79E('-L975T96QP86%R(&YI970@9V5G96YE<F5E<F0N
M`%!U97)T;R!2:6-O`%%U871A<@!1=65R>0!24T$@;W!E;F)A<F4@<VQE=71E
M;"`H)60@8FET*0!+975Z97)O;F1J92!S96QE8W1I90!296=E;@!6<F]E9R!R
M96=E;@!,86%T(')E9V5N`%)E9V5N8G5I`%)A;F1O;2!&;W)T=6YE`%9E<FAO
M=61I;F<`3&5Z96X`3&5E<R!B97)I8VAT96X`)7,@96-H="!V97)W:6ID97)E
M;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@;VYG961A86X@9V5M86%K="!W
M;W)D96XN`$=E8G)U:6ME<G-D871A('9A;B!G96)R=6EK97(@)7,@96-H="!V
M97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@;VYG961A86X@
M9V5M86%K="!W;W)D96XN`$AE<FAA86QT('5W('9O<FEG92!B97=E<FMI;F<`
M5F5R=F5R<R!D>6YA;6ES8VAE(&UE;G4@;VYD97)D96QE;CH`3&EJ<W0@=F5R
M=F5R<V5N`%!O<G1A;'=E97)G879E('9E<G9E<G-E;CH`4F5G97@`0F5T<F5K
M:VEN9V5N(&)R;W=S97(`3W!M97)K:6YG96X`4V5R=F5R<R!O<"!A9G-T86YD
M`%523"!O<"!A9G-T86YD("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H`5F5R=VEJ9&5R96X`0FQO:R!V97)W:6ID97)E;@!#871E9V]R:64@=F5R
M=VEJ9&5R96X`2V]L;VT@=F5R=VEJ9&5R96X`3W!M86%K('9E<G=I:F1E<F5N
M`%!A87(@=F5R=VEJ9&5R96X`5F5R=VEJ9&5R(&AE="!O<&=E<VQA9V5N('-C
M<FEP="!U:70@9&4@=&EJ9&5L:6IK92!D:7)E8W1O<GD@;W`@9&4@<V5R=F5R
M+@!697)W:6ID97(@9&4`5F5R=VEJ9&5R(&1E>F4@;F]D92!U:70@:&5T(&1O
M8W5M96YT`$=E8G)U:6ME<B!V97)W:6ID97)E;@!697)W:6ID97(@9V5B<G5I
M:V5R.B`E<P!697)Z;V5K(&MO;B!N:65T('=O<F1E;B!B96%N='=O;W)D+B!'
M97)E=&]U<FYE97)D92!F;W5T8V]D93H@`$AE<G-T96QL96X`4F5S970@=V%C
M:'1W;V]R9`!297-E="!U=R!W86-H='=O;W)D`%)E<W5L=&%T96X`5&5R=6<@
M;F%A<B!O<'1I97,`4F5U;FEO;@!#;VYF:6=U<F%T:64@=&5R=6=Z971T96X`
M4FEC:"!497AT($5D:71O<B!O<'1I97,`4F%A9'-E;',`4F5C:'1S`%)E8VAT
M<V4@:V]P`%)E8VAT<V4@=V%A<F1E;@!2:5]J96EG96YS8VAA<'!E;BXN+@!2
M;VP`4F]E;65N:>L`,3@P(&1R86%I96X`3F%A<B!L:6YK<R!D<F%A:65N`$YA
M87(@<F5C:'1S(&1R86%I96X`4FEJ(&5I9V5N<V-H87!P96X`4FEJ(&5I9V5N
M<V-H87!P96X`4FEJ96XZ`$QI;FGK<FEN9P!,:6YIZW)I;F<@>F%L('9E<G-C
M:&EJ;F5N('1U<W-E;B!A;&QE(')I:F5N(&5N(&MO;&]M;65N`$QI;FGK<FEN
M9R!Z86P@86QL965N('1U<W-E;B!K;VQO;6UE;B!V97)S8VAI:FYE;@!,:6YI
MZW)I;F<@>F%L(&%L;&5E;B!T=7-S96X@<FEJ96X@=F5R<V-H:6IN96X`4W1A
M<G1E;@!2=7-S:7-C:&4@1F5D97)A=&EE`%)W86YD80!#<GEP=&]G<F%F:7-C
M:&4@4R]-24U%(&AA;F1T96ME;FEN9P!3+TU)344@9V5C;V1E97)D(&)E<FEC
M:'0`4T%33"!A=71H96YT:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`%--
M4R!V97)S='5R96X`4U%,('-H96QL`%-32`!354-#15,`4U]13"!S:&5L;`!:
M80!3="!(96QE;F$`4W0@2VET=',@96X@3F5V:7,`4W0@3'5C:6$`4W0@4&EE
M<G)E(&5N($UI<75E;&]N`%-T(%9I;F-E;G0@96X@9&4@1W)E;F%D:6YE<P!:
M96QF9&4@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&5N(%!R:6YC:7!E`%-A=&5L;&EE='!R;W9I9&5R`%-A=61I($%R86)IZP!/
M<'-L86%N`"5S(&]P<VQA86X`3W!T:65S(&]P<VQA86X`1V5G96YE<F5E<F1E
M(&-O;F9I9W5R871I92!A;',@4$A0('-C<FEP="!O<&=E<VQA9V5N(&EN(&1E
M('1I:F1E;&EJ:V4@9&ER96-T;W)Y('9A;B!U=R!S97)V97(N`"5S(&-O;F9I
M9W5R871I92!O<&=E<VQA9V5N`%=E=&5N<V-H87``6F]E:V5N`%IO96MM86-H
M:6YE<P!:;V5K<F5S=6QT871E;@!:;V5K9V5B:65D`%1E:W-T(%]Z;V5K96X`
M2VEE<R!B97-T86YD96X`4V5L96-T965R(&5E;B!D871U;0!396QE8W1E97(@
M965N(&=R;V5P(&]M('1O92!T92!V;V5G96X`4V5L96-T965R(&5E;B!N:65U
M=V4@96EG96YA87(`4V5L96-T965R(&5E;B!N;W1I=&EE8F]E:P!396QE8W1E
M97(@965N('-E<G9E<@!396QE8W1E97(@965N(&=E8G)U:6ME<B!O;2!T;V4@
M=&4@=F]E9V5N`%-E;&5C=&5E<B!A;&QE(&1A='5M8V]M<&]N96YT96XN`%-E
M;&5C=&5E<B!E96X@;V)J96-T`%-E;&5C=&5E<B!D92!B96YO9&EG9&4@:V%R
M86MT97)S('5I="!D92!O;F1E<G-T86%N9&4@=F%K:F5S+B!5(&MU;G0@9&5Z
M92!D86X@:V]P:>MR96X@96X@<&QA:VME;B!I;B!H970@=&5K<W1G96)I960N
M`%-E;&5C=&5E<B!H970@9&%T=6US8VAE:61I;F=S=&5K96XZ`%-E;&5C=&5E
M<B!H970@9&%T=6UF;W)M86%T.@!396QE8W1E97(@:&5T(&5X<&]R=&9O<FUA
M870Z`%-E;&5C=&5E<B!H970@:6UP;W)T8F5S=&%N9#H`4V5L96-T965R(&AE
M="!F;W)M86%T('9A;B!H970@8G)O;F)E<W1A;F0Z`%-E;&5C=&5E<B!D92!I
M9&5N=&ET96ET(&1I92!U('=I;'0@=VEJ>FEG96XZ`%-E;&5C=&5E<B!H970@
M=&EJ9'-C:&5I9&EN9W-T96ME;CH`4V5L96-T965R(&AE="!T:6ID<V9O<FUA
M870Z`%-E;&5C=&5E<B!T=V5E(&]V97)E96YK;VUE;F1E('9E;&1E;BX`4V5L
M96-T965R('5W(&ML975R<V-H96UA+@!396QE8W1E97(@=7<@9V5W96YS=&4@
M=&%A;#H`1V5S96QE8W1E97)D92!C871E9V]R:65E;CH`4')O8FQE96UR87!P
M;W)T('9E<GIE;F1E;@!697)Z96YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E
M<'1E;6)E<@!397)V:>L@96X@36]N=&5N96=R;P!397)I96YU;6UE<@!397-S
M:64@240@=F5R;&]P96XN`$EN<W1E;&QE;@!);G-T96QL96X@=F%N(&]P=&EE
M<R!O;2!U('1O92!T92!S=&%A;B!U=R!W86-H='=O;W)D('1E(')E<V5T=&5N
M+"!W86YN965R('4@9&ET(&)E;G0@=F5R9V5T96XN`$EN<W1E;&QE;B!V86X@
M<V5R=F5R<R!O<"!A9G-T86YD(&1I92!U('=I;'0@8F5N861E<F5N('9A;G5I
M="!U=R!P;W)T86PN`$EN<W1E;&QE;B!V86X@=7<@9V5W96YS=&4@=&%A;"P@
M=&EJ9'IO;F4@96X@9&%T=6UO<'1I97,N`$EN<W1E;&QE;B!V86X@=7<@;W!S
M=&%R='1O97!A<W-I;F<L(&ML975R<V-H96UA+"!P86=I;F%V97)V97)S:6YG
M(&5N(&%N9&5R92!W965R9V%V96]P=&EE<RX`4V5T=7`@=7!G<F%D92!S8W)I
M<'1S(&)E<V-H:6MB86%R`%9E<G-C:&EL;&5N9&4@;&]C871I97,@;6]G96QI
M:FL@;65T(&1E('!A<F%M871E<CH@`%-E>6-H96QL96X`5VEN:V5L96X`2V]R
M=&4@<V%M96YV871T:6YG`$1I96YE;B!S;F5L=&]E='-E;B!V;V]R(&1E(&UE
M97-T92!L:6YK<R!G961E9FEN:65E<F0@=&4@=V]R9&5N/P!7965R9V5V96X`
M0F5W97)K:6YG<VMN;W!P96X@=V5E<F=E=F5N/P!697)S8VAI;&QE;B!L871E
M;B!Z:65N('1U<W-E;B!D92!H=6ED:6=E(&]P9V5S;&%G96X@8V]N9FEG=7)A
M=&EE(&5N(&1E(&YI975W92!G96=E;F5R965R9&4@8V]N9FEG=7)A=&EE+@!,
M86%T<W1E(&%A;FUE;&1I;F=S=&EJ9"!W965R9V5V96X@8FEJ(&%A;FUE;&1E
M;C\`3F]T:71I96)O96MN86UE;B!W965R9V5V96X_`$YO=&ET:65S('9A;B!D
M97IE(&-A=&5G;W)I965N('=E97)G979E;@!/<'1I92!W965R9V5V96X@;VT@
M;W)I9VEN965L('1E(&)E=V%R96X`2VEE>F5R('=E97)G979E;@!486)E;&)E
M=V5R:VEN9W-T86%K8F%L:R!W965R9V5V96X_`"5S(&UE;G4@86%N(&1E(&QI
M;FME<FMA;G0@=V5E<F=E=F5N/P!486)E;&-E;&5I9V5N<V-H87!P96X@9&EA
M;&]O9W9E;G-T97(@=V5E<F=E=F5N`%1A8F5L96EG96YS8VAA<'!E;B!D:6%L
M;V]G=F5N<W1E<B!W965R9V5V96X`5&%B96QR:6IE:6=E;G-C:&%P<&5N(&1I
M86QO;V=V96YS=&5R('=E97)G979E;@!!9F)E96QD:6YG<V5I9V5N<V-H87!P
M96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N`%5P;&]A9"!W965R9V5V96X`
M0G5I96X`0G5I96X@=G)O96<`0G5I96X@;&%A=`!697)K;&5I;F5N`%9E<FML
M96EN(&]F('9E<G!L86%T<R!N86)U<FEG92!B;&]K:V5N(&5E<G-T`%-I97)R
M82!,96]N90!);G1E:V5N96X`2&%N9'1E:V5N:6YG`$AA;F1T96ME;FEN9R!A
M;&=O<FET:&UE`%-I;F=A<&]R90!'<F]O='1E`$]N9&5R:&]U9"!O=F5R<VQA
M86X`4VQO=V%K:6IE`%-L;W9E;FGK`%-N965U=P!3;F5E=7=V;&%A9P!3;F5E
M=7=B=6EE;@!3;F5E=7=B=6EE;B!L86%T`%-N965U=V1I97!T93H@`%-N965U
M=V5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N(&5I;&%N9&5N`%-O;6%L
M:>L`3&EE9&5R96X@96X@9V5D:6-H=&5N`%-O<G1E<F5N(&]P(&-A=&5G;W)I
M90!3;W)T97)E;B!O<"!N;W1I=&EE=&5K<W0`4V]R=&5E<G9O;&=O<F1E('-E
M;&5C=&EE`$)R;VYA9')E<P!:=6ED($%F<FEK80!:=6ED($5U<F]P965S("A)
M4T\M.#@U.2TS*0!:=6ED($=E;W)G:>L@96X@9&4@6G5I9"!386YD=VEC:"!E
M:6QA;F1E;@!:=6ED96QI:FL@:&%L9G)O;F0`4W!A=&GK<FEN9R!T=7-S96X@
M86%N9W)E;GIE;F1E(&-E;&QE;@!3<&%T:>MR:6YG('1U<W-E;B!I;FAO=60@
M96X@<F%N9"!I;B!C96P`4V-H96ED:6YG<W1E:V5N`%-P871IZW)I;F<`4W!A
M=&GK<FEN9R!E;B!V<FEJ92!R=6EM=&4`4W!A;FIE`%-P86T`4W!E8VEA86P@
M:V%R86MT97(@:6YV;V5R`$-E;"!O<'-P;&ET<V5N`$MO;&]M(&]P<W!L:71S
M96X`4FEJ(&]P<W!L:71S96X`4W!O<G0`4W)I($QA;FMA`%-T86YD86%R9`!3
M=&%R(%1R96L`4W1A<G1J86%R`%-T86%T(&]F('!R;W9I;F-I90!3=&%T=7,`
M3W!S;&%G9F]R;6%A=`!!9')E<P!$;V]R:&%L96X`4W1R:6YG;&EJ<W0`4W1R
M:7`@9&]M96EN('9A;B!H970@861R97,`4W1I:FP@6T-34UT`6F\`3VYD97)W
M97)P`$)E=F5S=&EG96X`4W5B<V-R:7!T`%-U8V-E<P!#;VYF:6=U<F%T:64@
M;65T('-U8V-E<R!T97)U9V=E>F5T+B!697)N:65U=R!O;2!W:6IZ:6=I;F=E
M;B!T92!Z:65N+@!"86-K=7!C;VYF:6=U<F%T:64@;65T('-U8V-E<W,@;W!G
M97-L86=E;BX`)7,@;65T('-U8V-E<R!G97-C:')E=F5N`%-O961A;@!386UE
M;G9A='1I;F<`6F]N<V]P9V%N9P!:;VYS;VYD97)G86YG`%IO;FYI9P!:;VYS
M;W!G86YG`%IO;G-O<&=A;F<O6F]N<V]N9&5R9V%N9P!:;VYS;W!G86YG.B``
M6F]N<V]N9&5R9V%N9P!:;VYS;VYD97)G86YG.B``4W5P97)S8W)I<'0`3VYD
M97)S=&5U;FEN9P!3=7)I;F%M90!!8VAT97)N86%M`%-P:71S8F5R9V5N(&5N
M($IA;B!-87EE;@!3=V%Z:6QA;F0`6G=E9&5N`%IW:71S97)L86YD`%-Y;G1A
M>&9O=70@:6X@>F]E:W1E<FUE;@!3>7)I<V-H92!!<F%B:7-C:&4@4F5P=6)L
M:65K`$]N=V5E<G-B=6D`3VYW965R<V)U:65N`%135B!B97-T86YD`%1A8F5L
M`%1A8F5L96EG96YS8VAA<'!E;@!486)E;&5I9V5N<V-H87!P96X`5&%I=V%N
M`%1A:7=A;BP@4')O=FEN8VEE('9A;B!#:&EN80!4861Z:FEK:7-T86X`5&%N
M>F%N:6$L(%9E<F5N:6=D92!297!U8FQI96L@=F%N`$1O96PZ`%1A:V5N`%1E
M;&5F;V]N;G5M;65R`%1E;7!E<F%T=75R('9A;B!H970@869G96QO<&5N('5U
M<CH@`%1E;7!E<F%T=75R`%1E;7!E<F%T=75R.B``4VIA8FQO;VYB96AE97(`
M5&5K<W0`06QL965N('1E:W-T`%1E:W-T('5I=&QI:FYE;@!496MS=&)O=F5N
M:V%N=`!$;P!4:&%I<R`H5$E3+38R,"D`5&AA:6QA;F0`0F5D86YK="!V;V]R
M(&AE="!G96)R=6EK96X@=F%N(&AE="!S>7-T965M+@!$92!&5%`@97AT96YT
M:64@:7,@;FEE="!B97-C:&EK8F%A<BX`1&4@2&]R9&4O2V]L86(@:6YT96=R
M871I92!O;F1E<G-T975N="`B)7,B(&YI970`1&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!W97)D(&YI970@9V5L861E;@!(970@3W!T:65S<V-H97)M(&ES(&=E
M<VQO=&5N+B!!9G-L=6ET96XN`$1E(&)E:&5E<F1E<B!D:65N="!E96X@<&5R
M;6%N96YT(')E8VAT96YB86-K96YD('1E(&-O;F9I9W5R97)E;B!A;',@=2!R
M96-H=&5N('=I;'0@9V5B<G5I:V5N+@!!;&QE96X@9&4@;VYD97)K86YT`$AE
M="!C;VYT86-T($E$(&YU;6UE<B!I<R!N:65T(&]P9V5G979E;BP@;&5E9R!G
M96QA=&5N(&]F(&ES(&YI970@9V5V;VYD96X@:6X@9&4@9&%T86)A<V4N`$AE
M="!A9')E<R!I<R!M970@<W5C8V5S(&%A;B!U=R!A9')E<V)O96L@=&]E9V5V
M;V5G9"X`2&5T(&QO<V=E:V]P<&5L9&4@4$=0(&]N9&5R=&5K96YI;F=S8FQO
M:R!I<R!V97)E:7-T(&]M(&AE="!O;F1E<G1E:V5N9&4@8F5R:6-H="!T92!V
M97)I9FGK<F5N+@!(970@9&ES=')U8G5T:65L:6IS="!)1"!I<R!N:65T(&]P
M9V5G979E;BP@;&5E9R!G96QA=&5N(&]F(&ES(&YI970@9V5V;VYD96X@:6X@
M9&4@9&%T86)A<V4N`$1E(&1I<W1R:6)U=&EE;&EJ<W0@:7,@;FEE="!O<&=E
M9V5V96XN`$1E(&-O9&5E<FUO9V5L:6IK:&5D96X@=F5R96ES96X@965N(&)E
M=F5I;&EG9&4@=V5B=F5R8FEN9&EN9RX`2&5T(&)E<W1A;F0@)7,@9&EE;G0@
M965N("5S(&EN<W1E;&QI;F<@=&4@8F5V871T96XN`$AE="!B97-T86YD("5S
M(&1I96YT(&5N:6=E("5S(&EN<W1E;&QI;F=E;B!T92!B979A='1E;BX`2&5T
M(&)E<W1A;F0@:V%N(&YI970@;F%A<B!Z:6-H>F5L9B!G96MO<&EE97)D('=O
M<F1E;BX`2&5T(&)E<W1A;F0@8F5V871T92!G965N(&1A=&$N`$AE="!V;VQG
M96YD92!Z:6IN(&1E(&MO<'!E;B!V86X@9&ET(&UE<W-A9V4O<F9C.#(R(&)E
M<FEC:'0N`%9A;B!D92!V;VQL961I9R!S8VAE<FT@;6]D92!I<R!B96ME;F0L
M(&1A="!D:70@<')O8FQE;65N(&MA;B!V97)O;W)Z86ME;B!M970@26YT97)N
M970@17AP;&]R97(L('9A;G=E9V4@8G)O=W-E<F)U9W,@=V%A<B!W:6H@;FEE
M="!O;6AE96X@:W5N;F5N+B!(970@:7,@;6]G96QI:FL@9&%T('4@<F]M;65L
M(&EN(&AE="!B965L9'-C:&5R;2P@9V5B<F5K(&%A;B!E9&ET;W)F=6YC=&EE
M<R!E;B]O9B!R86YD;VT@8G)O=W-E<BT@8W)A<VAE<R!E<G9A87)T+B!786YN
M965R('5W('-Y<W1E96T@5VEN9&]W<R`Y>"!I<RP@:7,@:&5T('=A87)S8VAI
M:FYL:6IK(&1A="!U(&5E;B`G06QG96UE;F4@0F5V96EL:6=I;F=S($9O=70G
M(&MR:6IG="P@96X@;W!N:65U=R!D:65N="!T92!H97)S=&%R=&5N+EQN7&Y5
M(&)E;G0@9V5W86%R<V-H=7=D+B!$<G5K(&]P($]+('=A;FYE97(@=2!T;V-H
M(&1E('9O;&QE9&EG('-C:&5R;2!E9&ET;W(@=VEL="!P<F]B97)E;BX`1&4@
M:61E;G1I=&5I="`B)7,B(&ES('9E<G=I:F1E<F0N`$%L;&5E;B!D92!L:6YK
M97)K86YT`$1E('!L86%T<R!V86X@:&5T($=N=5!'('!R;V=R86UM82!D:65N
M="!O<&=E9V5V96X@=&4@=V]R9&5N(&EN(&1E($-R>7!T7W!G<#HZ(&-L87-S
M+@!(970@8F5R:6-H="!V97)S='5U<F0@;W`@)7,@86%N("5S(&UE="!O;F1E
M<G=E<G`@(B5S(B!I<R!W965R9V5G979E;BX*1&ET(&ES(&=E96X@9V%R86YT
M:64@9&%T(&AE="!B97)I8VAT(&ES(&=E;&5Z96X@;V8@8F5G<F5P96XN`$1E
M(&YA86T@9&EE(&=E8G)U:6MT('=O<F1T(&)I:B!L:6YK96X@;F%A<B!D92!N
M:65U=R!B97)I8VAT('!A9VEN80!$92!N;W1I=&EE(&ES('9E<G=I:F1E<F0N
M`$AE="!N;W1I=&EE8F]E:R`B)7,B(&MO;B!N:65T('=O<F1E;B!A86YG96UA
M86MT.B`E<P!(970@;F]T:71I96)O96L@(B5S(B!I<R!A86YG96UA86MT+@!(
M970@;F]T:71I96)O96L@(B5S(B!I<R!V97)W:6ID97)D+@!(970@;F]T:71I
M96)O96L@(B5S(B!I<R!O<&=E<VQA9V5N+@!$92!O<&5N<W-L(&UO9'5L92!I
M<R!V97)E:7-T('9O;W(@9&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`
M1&4@=F]O<FME=7)S:6YS=&5L;&EN9R`B)7,B(&MO;B!N:65T('=O<F1E;B!O
M<&=E<VQA9V5N+"!O;61A="!D92!D871A(&1E(&UA>&EM=6T@=&]E;&%A=&)A
M<F4@9W)O;W1T92!O=F5R<V-H<FEJ9'0N`$AE="!P<F]G<F%M;6$@;VT@9&ET
M(&1A=&%T>7!E("@E<RD@=&4@8F5K:6IK96XL('=E<F0@;FEE="!O<"!H970@
M<WES=&5E;2!G979O;F1E;BX`06QL965N(&1E(')E8VAT97(M(&5N(&QI;FME
M<FMA;G0`06QL965N(&1E(')E8VAT97)K86YT`$1E('-E<G9E<B`B)7,B(&ES
M('9E<G=I:F1E<F0N`$1E('-E<G9E<B`B)7,B(&ES(&]P9V5S;&%G96XN`$AE
M="!A86YM96QD:6YG<W9E<GIO96L@=F]O<B`E<R!I<R!V97)W:6ID97)D+@!$
M92!O<&=E9V5V96X@<FEJ(&)E<W1A870@;FEE="X`06QL965N(&1E(&)O=F5N
M+2!E;B!O;F1E<FMA;G0`06QL965N(&1E(&)O=F5N:V%N=`!$92!U<&QO861E
M9"!D871A(&ES(&YA(&1E('9O;W)G86%N9&4@<W1A<"!V97)L;W)E;B!G96=A
M86XN`$AE="!U<&QO861E9"!B97-T86YD(&ES(&YI970@;W!G97-L86=E;BX`
M2&5T('=E871H97(N8V]M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX`1V5E
M;B!O<'1I97,@8F5S8VAI:V)A87(N`$5R('II:FX@9V5E;B!O;F1E<F1E;&5N
M+"!W96QK92!I;FQI;F4@=V5E<F=E9V5V96X@:W5N;F5N('=O<F1E;BX`17(@
M>FEJ;B!T92!V965L(&MA<F%K=&5R<R!I;B!D:70@=F5L9"X@52!H965F="`E
M<R!K87)A:W1E<G,@;W!G96=E=F5N.R!U(&1I96YT(&UI;F1E<B!D86X@)7,@
M;W`@=&4@9V5V96XN`$5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO
M860Z($=E96X@)7,@=V5R9"!G975P;&]A9"X`165N('!R;V)L965M(&UE="!D
M92!B97-T86YD<W5P;&]A9#H@2&5T("5S(&ES(&=R;W1E<B!D86X@9&4@;6%X
M:6UU;2!T;V5L86%T8F%R92!G<F]O='1E("@E9"!B>71E<RDN`$5E;B!P<F]B
M;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($AE="`E<R!I<R!S;&5C:'1S
M(&=E9&5E;'1E;&EJ:R!G975P;&]A9"X`165N(&9O=70@8FEJ(&AE="!B96MI
M:FME;B!V86X@9&ET(&)E<FEC:'1O;F1E<F1E96P`165N(&9O=70@8FEJ(&AE
M="!I;7!O<G1E<F5N('9A;B!D92!A9')E<V1A=&$N`$5E;B!F;W5T(&)I:B!H
M970@:6UP;W)T97)E;B!V86X@9&4@9&%T83H@)7,`165N(&9O=70@8FEJ(&AE
M="!I;7!O<G1E<F5N('9A;B!D92!V3F]T92!D871A+@!%96X@9F]U="!I;B!H
M970@8V]N9FEG=7)A=&EE9F]R;75L:65R+B!-:7-S8VAI96X@8F5N="!U(&5E
M;B!V97)P;&EC:'0@=F5L9"!V97)G971E;BX`165N(&9O=70@8FEJ(&AE="!U
M:71V;V5R96X@=F%N(&1E(&]P9V5G979E;B!A9')E<V)O96MF=6YC=&EE+B!0
M<F]B965R(&QA=&5R(&]P;FEE=7<L(&$N=2YB+@!%96X@<')O8FQE96T@8FEJ
M(&AE="!V97)W:6ID97)E;B!V86X@9&4@;F]T:71I93H@)7,`165N('!R;V)L
M965M(&)I:B!H970@;W!S;&%A;B!V86X@9&4@;F]T:71I93H@)7,`165N(&9O
M=70@;65T(&AE="!B:6IW97)K96X@=F%N(&1E(&%D<F5S9&5T86EL<RX@4')O
M8F5E<B!L871E<B!O<&YI975W+"!A+G4N8BX`165N(&9O=70@;65T(&AE="!B
M:6IW97)K96X@=F%N(&1E(&1I<W1R:6)U=&EE;&EJ<W0N(%!R;V)E97(@;&%T
M97(@;W!N:65U=RP@82YU+F(N`$5E;B!P<F]B;&5E;2!B:6H@:&5T(&)E:VEJ
M:V5N('9A;B!D:70@;F]T:71I96)O96LZ("5S`$5R('=A<F5N(&=E96X@;F]T
M:71I97,@;VT@=&4@97AP;W)T97)E;BX`1&5Z92!)34%0('-E<G9E<B!O;F1E
M<G-T975N="!G965N(&1E;&EN9R!V86X@;6%P<&5N+@!$:70@;&EJ:W0@;FEE
M="!E96X@9V5L9&EG(')A<B!B97-T86YD('1E('II:FXN`$1I="!L:6IK="!N
M:65T(&5E;B!G96QD:6<@>FEP(&)E<W1A;F0@=&4@>FEJ;BX`1&ET(&QI:FMT
M(&YI970@965N(&=E;&1I9R!K86%R=&YU;6UE<B!T92!Z:6IN+@!$:70@<W1U
M=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E
M;B!V:6$@9&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G
M871E=V%Y('1E('9E<GIE;F1E;BP@9"YM+G8N(&1E($A45%`@05!)`$1I="!S
M='5U<G!R;V=R86UM82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H
M=&5N('9I82!D92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y('1E('9E<GIE;F1E;BP@9"YM+G8N(&1E($A45%`@05!)`$1I="!S
M='5U<G!R;V=R86UM82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H
M=&5N('9I82!33510(&0N;2YV+B!D92!6;V1A9F]N92!)=&%L>2!G871E=V%Y
M('1E('9E<GIE;F1E;B!N86%R(%9O9&%F;VYE(&YU;6UE<G,N($AI97)V;V]R
M(&ES(&5E;B!6;V1A9F]N92!)=&%L>2!E+6UA:6QA9')E<R`H:'1T<#HO+W=W
M=RXQ.3`N:70I(&YO;V1Z86ME;&EJ:RX`1&ET('9E;&0@:7,@=F5R96ES=`!$
M:70@=F5L9"!M86<@86QL965N(&EN=&5G97)S(&)E=F%T=&5N+@!$:70@=F5L
M9"!M86<@86QL965N(&=E=&%L;&5N(&5N(&1E(&1U8F)E;&4@<'5N="!B979A
M='1E;BX`1&ET('9E;&0@;6%G(&%L;&5E;B!O8W1A86P@=V%A<F1E;B!B979A
M='1E;BX`1&ET('9E;&0@9&EE;G0@965N(&MO;6UA(&]F('-P871I92!G97-C
M:&5I9&5N(&QI:G-T(&UE="!I;G1E9V5R<R!T92!Z:6IN`$1E>F4@=V%A<F1E
M(&1I96YT(&5E;B!G96QD:6<@9V5T86P@=&4@>FEJ;BX`1&ET('9E;&0@9&EE
M;G0@965N(&ML975R8V]D92!I;B!21T(@2$58+69O<FUA870@=&4@8F5V871T
M96XL(&(N=BX@)R,Q,C,T868G+@!$:70@8F5S=&%N9'-F;W)M86%T('=O<F1T
M(&YI970@;VYD97)S=&5U;F0N`$1I="!F;W)M=6QI97(@:7,@<F5E9',@=F5R
M=V5R:W0N`$1I="!I<R`E<RX`1&ET(&ES(&5E;B!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!/;2!D:70@;V)J96-T('=E97(@=&4@9V5V96X@:&5E9G0@=2!E
M96X@92UM86EL(&-L:65N="!N;V1I9R!D:64@:&5T($MO;&%B($=R;W5P=V%R
M92!F;W)M86%T(&)E9W)I:G!T+B!6;V]R(&5E;B!L:6IS="!M970@9&5Z92!E
M+6UA:6QC;&EE;G1S+"!B97IO96L@)7,L(&$N=2YB+@!$:70@8F5R:6-H="!I
M<R!I;B!E96X@86YD97)E(&MA<F%K=&5R<V5T("@E<RD@9V5S8VAR979E;BP@
M9&%N('5W(&5I9V5N+@!$:70@9V5T86P@9&EE;G0@=&5N;6EN<W1E(.GI;B!T
M92!Z:6IN+@!$97IE('-E<G9E<B!K86X@9V5E;B!Z:7`@96X@9WII<"!B97-T
M86YD96X@=6ET<&%K:V5N+@!(970@<WES=&5E;2!I<R!M;VUE;G1E96P@=6ET
M9V5S8VAA:V5L9"X`1&5Z92!W86%R9&4@9&EE;G0@965N(&=E=&%L('1E('II
M:FXN`$1I="!S8VAE<FT@9&EE;G0@86%N9V5R;V5P96X@=&4@=V]R9&5N('9A
M;G5I="!E96X@3W!T:65S<V-H97)M`$]N=V5E<@!4:6-K971S`%1I:F0`5&EJ
M9'!L86YN:6YG`%1I:F1F;W)M86%T`%1I:F1S96QE8W1I90!4:6UO<BU,97-T
M90!4:71E;`!4:71E;"`H=&]O;'1I<"DZ`$%A;@!/;2!M965R9&5R92!O;F1E
M<F1E;&5N('1E('-E;&5C=&5R96XL(&AO=60@9&4@0V]N=')O;"`H4$,I(&]F
M($-O;6UA;F0@*$UA8RD@=&]E=',@=F%S="!T:6ID96YS(&ML:6MK96XN`%9A
M;F1A86<`2%1-3"!B<F]N(&]M<V-H86ME;&5N`%1O9V\`5&]K96QA=0!-;W)G
M96X`5&]N9V$`0F]V96YK86YT`$)O=F5N<W1E(&9R86UE("A?=&]P*0!697)T
M86QI;F=E;@!4<FEN:61A9"!E;B!4;V)A9V\`5')U92!O9B!F86QS90!$:0!4
M=6YE<VGK`%1U<FMI:F4`5'5R:W,@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A
M;@!4=7)K<R!E;B!#86EC;W,@96EL86YD96X`5'5V86QU`%1Y<"!U=R!K975Z
M93H@`%4N5BX@:6YD97@Z(`!54DP`55),('9O;W(@=7<@869L979E<FEN9W-S
M=&%T=7-R87!P;W)T('-C<FEP=`!54DPZ`$]E9V%N9&$`3V5K<F'O;F4`3FEE
M="!I;B!S=&%A="!61E,@9&ER96-T;W)Y(&%A;B!T92!S<')E:V5N+@!.:65T
M(&EN('-T86%T(&5X=')A(&=E8G)U:6ME<G-I;F9O<FUA=&EE('1O92!T92!V
M;V5G96X@8FEJ(&EN<V-H<FEJ=F5N+@!.:65T(&EN('-T86%T(&1E(')E8VAT
M96X@=F%N(%9&4R!B97-T86YD("(E<R(@=&4@=VEJ>FEG96XN`$YI970@:6X@
M<W1A870@9&4@<F5C:'1E;B!V86X@5D93(&)E<W1A;F0@)7,O)7,@=&4@=VEJ
M>FEG96XN`$YI970@:6X@<W1A870@=&4@=VEJ>FEG96X@;F%A<B`E<RX`3FEE
M="!I;B!S=&%A="!M970@9&4@4U%,('-E<G9E<B!T92!V97)B:6YD96XN`$YI
M970@:6X@<W1A870@;65T(%-33"!T92!V97)B:6YD96XN`$YI970@:6X@<W1A
M870@5D93(&)E<W1A;F0@=&4@:V]P:>MR96XN`$YI970@:6X@<W1A870@5D93
M(&1I<F5C=&]R>2`B)7,B('1E(&UA:V5N+@!.:65T(&EN('-T86%T(%9&4R!D
M:7)E8W1O<GD@=&4@;6%K96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M=&4@;6%K96XN`$YI970@:6X@<W1A870@965N(&QE96<@5D93(&)E<W1A;F0@
M=&4@;6%K96XN`$YI970@:6X@<W1A870@9&%T82!U:70@=&4@<&%K:V5N+@!.
M:65T(&EN('-T86%T("(E<R(@=&4@=F5R=VEJ9&5R96XL(&1E(&1I<F5C=&]R
M>2!I<R!N:65T(&QE96<`3FEE="!I;B!S=&%A="!O;2`B)7,B.B`E<R!T92!V
M97)W:6ID97)E;@!.:65T(&EN('-T86%T("5S('1E('9E<G=I:F1E<F5N+"!D
M92!D:7)E8W1O<GD@:7,@;FEE="!L965G`$YI970@:6X@<W1A870@5D93(&1I
M<F5C=&]R>2!R96-U<G-I968@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A
M870@5D93(&1I<F5C=&]R>2!T92!V97)W:6ID97)E;BX`3FEE="!I;B!S=&%A
M="!61E,@9&ER96-T;W)Y("5S('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T
M86%T(%9&4R!B97-T86YD("(E<R(@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A
M870@5D93("5S(')E8W5R<VEE9B!T92!V97)W:6ID97)E;BX`3FEE="!I;B!S
M=&%A="!H=6ED:6=E(&1I<F5C=&]R>2!T92!B97!A;&5N+@!.:65T(&EN('-T
M86%T(&-E<G1I9FEC86%T9&5T86EL<R!U:70@=&4@9FEL=&5R96X`3FEE="!I
M;B!S=&%A="!O;2!D92!D969I;FET:64@=F%N("5S('1E(&QA9&5N+@!.:65T
M(&EN('-T86%T(%9&4R!B97-T86YD('1E('9E<G!L86%T<V5N+@!.:65T(&EN
M('-T86%T(%9&4R!B97-T86YD("(E<R(@=&4@;W!E;F5N+@!.:65T(&EN('-T
M86%T(%9&4R!B97-T86YD('1E(&]P96YE;B!V;V]R('-C:')I:G9E;BX`3FEE
M="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!O<&5N96XN`$YI970@:6X@<W1A
M870@:&5T(&EN9V5P86MT92!B97-T86YD('1E(&]P96YE;BX`3FEE="!I;B!S
M=&%A="!V9G-R;V]T(&1I<F5C=&]R>2!T92!O<&5N96XN`$YI970@:6X@<W1A
M870@;VT@)7,@=&4@:&5R;F]E;65N(&YA87(@)7,Z(&)E<W1E;6UI;F=S;6%P
M(&)E<W1A870@86P`3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E(&AE
M<FYO96UE;BX`3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y("5S('1E(&AE
M<FYO96UE;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"`B)7,B('1E(&AE
M<FYO96UE;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"`E<R\E<R!T92!H
M97)N;V5M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@:&5R;F]E
M;65N+@!+86X@)VUK:7-O9G,G(&YI970@=6ET=F]E<F5N+@!.:65T(&EN('-T
M86%T(&1I="!7;W)D(&1O8W5M96YT('1E('9E<G1A;&5N`$YI970@:6X@<W1A
M870@5D93(&)E<W1A;F0@(B5S(B!T92!S8VAR:6IV96XN`$YI970@:6X@<W1A
M870@5D93(&)E<W1A;F0@=&4@<V-H<FEJ=F5N("AC;W!Y*"D@9F%I;&5D*2X`
M3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9'-D871A('1E('-C:')I:G9E;BX`
M3VYD97)S=')E<&5N`$AE<G-T96P@=VEJ>FEG:6YG96X`1&]E="!U=R!L86%T
M<W1E(&)E=V5R:VEN9R!T96YI970`3VYV97)W86-H="!A;G1W;V]R9"!V86X@
M9&4@<V5R=F5R(&]P('9E<F)I;F1I;F<Z(`!/;G9E<G=A8VAT(&%N='=O;W)D
M('9A;B!S97)V97(@86%N.B``3VYB96YO96UD`%5N:6-O9&4@*%541BTX*0!6
M97)E;FEG9&4@07)A8FES8VAE($5M:7)A=&5N`%9E<F5N:6=D($MO;FEN9VMR
M:6IK`%9E<F5N:6=D92!3=&%T96X`5F5R96YI9V1E(%-T871E;BP@:VQE:6YE
M(&)U:71E;B!L:6=G96YD92!E:6QA;F1E;@!%96YH961E;@!/;F)E:V5N9`!/
M;F)E:V5N9"!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!/;F)E:V5N9"!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!/;F)E:V5N9&4@9V5B<G5I
M:V5R<VYA86T@;V8@=V%C:'1W;V]R9"X`2&5T(&AU:61I9V4@96QE;65N="!L
M;W-K;W!P96QE;@!/;F)E;F]E;60`3FEE="!G97)E8VAT:6=D92!S8W)I<'1S
M(&MU;FYE;B!P<F]G<F%M;6%M871I9R!N:65T($MN:7!P96XO2V]P:>MR96XO
M4&QA:VME;BP@=F%N=V5G92!B979E:6QI9VEN9W-R961E;F5N+B!+;&EK(&]P
M($]+(&]M(&5E;B!T96-H;FES8VAE(&]P;65R:VEN9R!O<"!M;WII;&QA+F]R
M9R!T92!B96MI:FME;B!H;V4@=2!E96X@<V-R:7!T('1O97-T86%T(&AE="!P
M<FEK8F]R9"!T92!B96YA9&5R96XN`$ML975R('1E<G5G<W1E;&QE;@!.:65T
M(&]N9&5R<W1E=6YD92!E>'1E;G1I90!":6IW97)K96X`)7,@8FEJ=V5R:V5N
M`$=E8G)U:6ME<B!B:6IW97)K96XN`%5P9W)A9&4@<V-R:7!T('9E<G=I:F1E
M<F0N`%5P;&]A9`!!;&QE('1O97!A<W-I;F<@<V5T=7!B97-T86YD96X@;F%A
M<B!D92!S97)V97(@9V5U<&QO860N`$QA=&EJ;G-E(&AO;V9D;&5T=&5R<P!'
M<F]T92!2;VUE:6YS92!G971A;&QE;@!5<G5G=6%Y`$=E8G)U:6L@:'5I9&EG
M93H@)7,`1V5B<G5I:R!34TP`1V5B<G5I:V5N('=A;FYE97(@;F%A;2]W86-H
M='=O;W)D('9E<G-C:&EL="!M970@24U34"!S97)V97(N`$=E8G)U:6ME<B`E
M<R!I<R!N:65T(&=E875T;W)I<V5E<F0@=F]O<B`E<RX`1V5B<G5I:V5R<V)E
M:&5E<@!'96)R=6EK97)S;W!T:65S`$=E8G)U:6ME<G-R96=I<W1R871I90!'
M96)R=6EK97)S<F5G:7-T<F%T:64@:7,@=6ET9V5S8VAA:V5L9"!O<"!D97IE
M('-I=&4N`$=E8G)U:6ME<G-N86%M`$=E8G)U:6ME<G-N86%M.@!'96)R=6EK
M97)S;F%A;3H@`$=E8G)U:6ME<G,@:6X@:&5T('-Y<W1E96TZ`$]E>F)E:VES
M=&%N`%9&4R!D:7)E8W1O<GD@8F5S=&%A="!N:65T+@!!9G=E>FEG:&5I9`!'
M979O;F1E;B!G96QD:6=E(&QO8V%T:65S(&)E=F%T=&5N.B``1V5L9&EG:&5I
M9`!786%R9&4@:6X@;6EN=71E;B!V86YA9B!N=2X`5V%A<F1E;@!786%R9&5N
M('=A87)U:70@9V5S96QE8W1E97)D(&MA;B!W;W)D96X`5F%N=6%T=0!687)I
M86)E;&4`5F5N97IU96QA`%9E<FEF:6-A=&EE(&UI<VQU:W0@+2!E<B!K86X@
M;65T(&1I="!B97)I8VAT(&=E:VYO96ED('II:FXN`%9E<G-I90!697)S:65C
M;VYT<F]L90!697)T:6MA86P@=6ET;&EJ;F5N`%9E<G1I:V%L92!V<FEJ92!R
M=6EM=&4`5F5R=&EK86%L.@!%<F<@:&]O9P!6:65T;F%M`%9I971N86UE97,@
M*%9)4T-)22D`)7,@8F5K:6IK96X`0F5K:6IK(&5E;B!E>'1E<FYE('=E8G!A
M9VEN80!"96MI:FME;B!A;',@)7,`36%A9V1E;B!E:6QA;F1E;BP@0G)I='-E
M`$UA86=D96X@96EL86YD96XL(%8N4RX`6FEC:'0`6FEC:'0Z(`!6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44`!705).`%=!05)30TA55TE.1R$A(2`@5D525TE*
M1$52(%-#4DE05"!(04Y$34%424<@54E4("5S+@!786QL:7,@96X@1G5T=6YA
M`%=A87)S8VAU=VEN9P!7;P!7965R<W9O;W)U:71Z:6-H=`!7965R8F5R:6-H
M="!G96=E=F5N<R!G96QE=F5R9"!D;V]R`%=E871H97(N8V]M`%=E8@!796)S
M:71E`%=E:V5L:6IK<P!796QK;VT`5V5L:V]M(&)I:B`E<P!796QK;VTL("5S
M`%=E<W1E<G,@*$E33RTX.#4Y+3$I`%=E<W1E<G,@*$E33RTX.#4Y+3$U*0!7
M97-T96QI:FME(%-A:&%R80!796QK92!T;V5P87-S:6YG(&1I96YT("5S('=E
M97(@=&4@9V5V96X@;F$@86%N;65L9&EN9S\`5V%T(&ES(&AE="!S8VAE:61I
M;F=S:V%R86MT97(_`%=A="!I<R!H970@8VET86%T:V%R86MT97(_`$%A;B!W
M96QK(&YO=&ET:65B;V5K(&1I96YE;B!D92!N;W1I=&EE<R!T;V5G979O96=D
M('1E('=O<F1E;C\`5V5L:V4@9F%S96X`5V5L:V4@<&QU9VEN<R!V;V]R(&1E
M(%)I8V@@5&5X="!E9&ET;W(@:6YS8VAA:V5L96XN`$)R965D=&4`0G)E961T
M92!I;B!#4U,@965N:&5D96X`0G)E961T92!V86X@:&5T("5S(&UE;G4@86%N
M(&1E(&QI;FME<FMA;G0@*&%K=&EE9B!B:6H@=F]L9V5N9&4@86%N;65L9&EN
M9RDZ`$)R965D=&4@=F%N(&1E('1A8F5L`$)R965D=&4@965N:&5I9`!"<F5E
M9'1E.@!7:6MI`%=I;F0`5VEN9'-N96QH96ED(&EN(&MN;W!E;@!7:6YD.@!7
M:6YD.B``5VEJ<VAE:60`5V5R:P!797)K861R97,`5&5L+FYR+B`H=V5R:RD`
M6"U2968`6#4P.78S(&)A<VES8F5P97)K:6YG96X`6#4P.78S('5I=&=E8G)E
M:60@<VQE=71E;&=E8G)U:6L`6#4P.78S(&%L=&5R;F%T:65V92!O;F1E<G=E
M<G!N86%M`%@U,#EV,R!O;F1E<G=E<G`@<VQE=71E;&ED96YT:69I8V%T;W(`
M6#4P.78S(&5X=&5N=&EE<P!*2@!*2DI*`%EA:&]O(2!M87``2F%A<FQI:FMS
M`$IE;65N`$IA`$IA+"!I:R!A8V-E<'1E97(@9&4@=F]O<G=A87)D96X`52!B
M96YT(&EN(%1%2U-4($U/1$4N($=E8G)U:6L@9&4@6SP^72!K;F]P(&]M(&YA
M87(@5UE325=91R!T97)U9R!T92!S8VAA:V5L96XN`%4@8F5N="!N:65T(&=E
M875T:&5N=&EF:6-E97)D+@!5(&MU;G0@9V5E;B`G7"<@:V%R86MT97(@:6X@
M=7<@=F]L;&5G92!N86%M(&AE8F)E;BX`52!H965F="!G965N(&=E;&1I9R!E
M+6UA:6QA9')E<R!O<&=E9V5V96XN`%4@:&5E9G0@9V5E;B!V96QD96X@=6ET
M(&AE="!G96EM<&]R=&5E<F1E(&)E<W1A;F0@9V5K;W!P96QD(&UE="!D92!O
M=F5R965N:V]M<W1I9V4@=F5L9&5N(&EN("5S+@!5(&AE969T(&=E96X@<F5C
M:'0@;VT@:&5T(&YO=&ET:65B;V5K("5S('1E(&)E:VEJ:V5N+@!5(&)E;G0@
M869G96UE;&0N`%4@9&EE;G0@965N(&=E;&1I9R!M;V)I96P@;G5M;65R(&EN
M('1E('9O97)E;BP@86QL965N(&-I:F9E<G,@;65T(&5E;B!O<'1I;VYE;&4@
M)RLG('9O;W(@:&5T(&EN=&5R;F%T:6]N86QE(&MI97-V;V]R=F]E9W-E;"X`
M52!D:65N="!E96X@9V5L9&EG92!W86%R9&4@;W`@=&4@9V5V96XN`%4@9&EE
M;G0@965N($1A=&%4<F5E(&)A8VME;F0@=&4@8V]N9FEG=7)E<F5N(&]M(&EN
M<V-H<FEJ=FEN9V5N('1E(&MU;FYE;B!G96)R=6EK96XN`%4@9&EE;G0@:&5T
M('!R;V)L965M('1E(&)E<V-H<FEJ=F5N+"!V;V]R9&%T('4@:&5T('!R;V)L
M965M<F%P<&]R="!K=6YT('9E<GIE;F1E;BX`52!D:65N="!E96X@55),(&EN
M('1E('9O97)E;B!W86%R;F%A<B!D97IE(&QI;FL@=F5R=VEJ<W0`52!D:65N
M="!E96X@;F]T:71I96)O96L@=&4@<V5L96-T97)E;B!O;2!T92!V97)W:6ID
M97)E;BX`52!D:65N="!E96X@<V5R=F5R('1E('-E;&5C=&5R96X@;VT@=&4@
M=F5R=VEJ9&5R96XN`%4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E
M(&=E=F5N(&]M('1E('=I<W-E;BX`52!D:65N="!E96X@9V5B<G5I:V5R<VYA
M86T@;W`@=&4@9V5V96X@;VT@=&4@=F5R=VEJ9&5R96XN`%4@9&EE;G0@965N
M(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M('1O92!T92!V;V5G96XN
M`%4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M(&)I
M:B!T92!K=6YN96X@=V5R:V5N+@!5(&1I96YT(&5E;B!B97=E<FMI;F<@;W`@
M=&4@9V5V96X@=V5L:V4@=6ET9V5V;V5R9"!M;V5T('=O<F1E;BX`52!D:65N
M="!E96X@;FEE=7=E(&-A=&5G;W)I96YA86T@;W`@=&4@9V5V96XN`%5W("5S
M('-E<W-I92!I<R!V97)L;W!E;BX@3W!N:65U=R!A86YM96QD96XL(&$N=2YB
M+@!5=R!E+6UA:6QA9')E<P!5=R!686XZ(&%D<F5S.@!5=R!I;F9O<FUA=&EE
M`%5W(&EN=&5R;F5T861R97,@:7,@9V5W:6IZ:6=D('-I;F1S(&AE="!B96=I
M;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U=R!V96EL:6=H96ED('1E(&)E<V-H
M97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T92!M96QD96XN`%5W
M(&YA86TZ`$AE="!W965R9V5V96X@=F%N(&5E;B!G96)R=6EK97)S;&EJ<W0@
M=V]R9'0@;FEE="!O;F1E<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T:64@
M8F%C:V5N9"P@;V8@9&5Z92!O<'1I92!I<R!O;2!A;F1E<F4@<F5D96YE;B!U
M:71G97-C:&%K96QD+@!5=R!B<F]W<V5R(&QI:FMT('1E('II:FX@9V5W:6IZ
M:6=D('-I;F1S(&AE="!B96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U=R!V
M96EL:6=H96ED('1E(&)E<V-H97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W
M(&%A;B!T92!M96QD96XN`%5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z92!M
M;V=E;&EJ:VAE:60@;FEE="X`57<@:'5I9&EG92!T:6ID>F]N93H`57<@<W1A
M;F1A87)D(&ED96YT:71E:70Z`%5W('-T86YD86%R9"!N;W1I=&EE8F]E:SH`
M57<@=F]L;&5D:6=E(&YA86TZ`%5W(&YI975W92!W86-H='=O;W)D('9O;W(@
M)7,@:7,Z("5S`%5W(&YO=&ET:65B;V5K96XZ`%5W(&]P=&EE<R!Z:6IN(&)I
M:F=E=V5R:W0N`%5W('=A8VAT=V]O<F0@:7,@9V5R97-E=`!5=R!W86-H='=O
M;W)D(&ES('9E<FYI975W9"P@8V]N=')O;&5E<B!U=R!E+6UA:6P@96X@;65L
M9"!A86X@;65T('5W(&YI975W92!W86-H='=O;W)D+@!5=R!S97)V97)S(&]P
M(&%F<W1A;F0Z`$IO96=O<VQA=FGK`%IA[W)E`%IA;6)I80!::6UB86)W90!:
M:7!P>0!;5F5R8F5R9R!A86YG96AA86QD92!T96MS=%T`6U!R;V)L965M<F%P
M<&]R=%T`6T%A;F=E:&%A;&1E('1E:W-T('=E97)G979E;B`M`%M!86YG96AA
M86QD92!T96MS="`M("5S(')E9V5L<UT`6W)E9V5L("5S('9A;B`E<UT`0E]E
M:&5E<@!495]R=6<@;F%A<B!N;W1I=&EE8F]E:P!?0TQ)`%]#871E9V]R:64`
M7T1A=&%4<F5E`%9E<E]W:6ID97)E;@!697)?=VEJ9&5R(')I:@!?0F5W97)K
M96X`165R7W-T92!R96=E;`!?1W)O97!E;@!?2&5L<`!?069B965L9&EN9W-E
M:6=E;G-C:&%P<&5N+BXN`%]);7!O<G0O17AP;W)T`$YO=&ET:65S('=E97)?
M9V5V96X`7T%A;FUE;&1E;@!?069M96QD96X`7U=I:GII9R!L:6YK+BXN`%]-
M:6IN(&YO=&ET:65B;V5K96X`7TYI975W92!N;W1I=&EE`%]/<'1I97,`7U)E
M8VAT96X`05]F9')U:VME;@!?5F5R=VEJ9&5R(&QI;FLN+BX`7UIO96ME;@!?
M26YS=&5L;&5N`%]486)E;&5I9V5N<V-H87!P96XN+BX`1V5?8G)U:6ME<G,`
M061R97-B;V5K`$MA;&5N9&5R`$MA;&T`2VQI:R!H:65R`&1A;&5N9`!B97-T
M86YD`'9A;B!D92`E<R`H)7,I(&]P("5S("5S`&@Z`&]N;6ED9&5L:6IK`&EN
M;&EN90!R96=E;'-=`&UK:7-O9G,@9F]U=&-O9&4@)60@8FEJ(&AE="!A86YM
M86ME;B!V86X@25-/+@!N86%M`&YI970@=F%N('1O97!A<W-I;F<`3F]G(&YI
M970@=F%N('1O97!A<W-I;F<`;F]T:71I96)O96L`;F]T97,N8W-V`'!R;V-E
M;G0`<&EX96QS`'-T:6IG96YD`'1O;VX@=F5R<V-H:6QL96X`<VUS,F5M86EL
M('9I82!(5%10`'-T86)I96P`=&%K96YL:6IS=`!6;V5R+"!T97(@8F5V97-T
M:6=I;F<L(&AE="!W86-H='=O;W)D('1W964@;6%A;"!I;@!U;FEF:65D`&]N
M8F5N;V5M9`!'96)R=6EK97)S96QE8W1I90!V0V%R9`!V3F]T90!W.@!W96%T
M:&5R+F-O;0`````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO
M8V%L92]N;E].3R\`````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(P,#`U`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;6YE;6\O;&]C86QE+VYN7TY/+TQ#7TU%4U-!1T53+P``````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P,C$U
M-S(`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O;FY?3D\O
M3$-?34534T%'15,O;6YE;6\N;6\`````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(T,S$T
M`#$P-#$W,S8R-S0T`#`R,S(T,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#>$@25`````*0````<````/`4``-\```!<"@``
M`````-@-```+````V0T``"@```#E#0``%0````X.```(````)`X```4````M
M#@```P```#,.```/````-PX```@```!'#@``"````%`.```9````60X```<`
M``!S#@``#````'L.```.````B`X```4```"7#@``'P```)T.```)````O0X`
M`#D```#'#@``)P````$/```L````*0\``"H```!6#P``$0```($/```(````
MDP\```@```"<#P``!@```*4/```5````K`\```@```#"#P``"@```,L/```*
M````U@\``!$```#A#P``#````/,/```'`````!```!`````($```*P```!D0
M```>````11```!L```!D$```&P```(`0```S````G!```"\```#0$```*0``
M```1```"````*A$```4````M$0``$````#,1```9````1!$``!H```!>$0``
M"@```'D1```4````A!$``"\```"9$0``#P```,D1```F````V1$```4`````
M$@``#0````82```%````%!(``!`````:$@``$````"L2```/````/!(```L`
M``!,$@``#P```%@2```,````:!(```\```!U$@``'@```(42```A````I!(`
M``,```#&$@``#````,H2```4````UQ(```8```#L$@``!````/,2```,````
M^!(```H````%$P``!0```!`3```2````%A,``!`````I$P``"````#H3```0
M````0Q,``!H```!4$P``!@```&\3```'````=A,```(```!^$P``)0```($3
M```$````IQ,```\```"L$P``!P```+P3```)````Q!,```<```#.$P``"0``
M`-83```,````X!,```<```#M$P``$@```/43```$````"!0```<````-%```
M!0```!44```S````&Q0``!H```!/%```!0```&H4```'````<!0``!$```!X
M%```#0```(H4```(````F!0``!4```"A%```'@```+<4```H````UA0``!H`
M``#_%```!0```!H5```H````(!4``"D```!)%0``$P```',5```R````AQ4`
M``0```"Z%0``#````+\5```&````S!4```L```#3%0``$0```-\5```$````
M\14```P```#V%0``!@````,6```.````"A8```P````9%@``&@```"86```7
M````018``!<```!9%@``&P```'$6```9````C18``!\```"G%@``$P```,<6
M```$````VQ8``!````#@%@``$````/$6```7`````A<```<````:%P``!0``
M`"(7```Q````*!<``#@```!:%P``(0```),7```<````M1<```4```#2%P``
M`P```-@7```@````W!<``"8```#]%P``#````"08```'````,1@```8````Y
M&```$P```$`8```,````5!@```@```!A&```%````&H8```'````?Q@```8`
M``"'&```#0```(X8```+````G!@```P```"H&```"@```+48```"````P!@`
M``8```##&```#````,H8``!%````UQ@``"8````=&0``)0```$09```P````
M:AD``!````";&0``<P```*P9```?````(!H``!````!`&@``#P```%$:```%
M````81H``&(!``!G&@``"@```,H;```H````U1L``!0```#^&P``"````!,<
M```%````'!P```@````B'```$P```"L<```,````/QP```\```!,'```'@``
M`%P<```'````>QP```H```"#'```#@```(X<```%````G1P``",```"C'```
M"````,<<```[````T!P``"T````,'0``+P```#H=```N````:AT``!,```"9
M'0``!P```*T=```(````M1T```8```"^'0``%0```,4=```(````VQT```P`
M``#D'0``$````/$=```6`````AX```X````9'@``!0```"@>```0````+AX`
M`"L````_'@``'0```&L>```@````B1X``!P```"J'@``,````,<>```V````
M^!X``"P````O'P```@```%P?```&````7Q\``!$```!F'P``'0```'@?```?
M````EA\```@```"V'P``$0```+\?```F````T1\``!$```#X'P``(P````H@
M```&````+B````X````U(```!````$0@```0````22```!````!:(```#P``
M`&L@```/````>R````\```"+(```#````)L@```0````J"```!\```"Y(```
M(P```-D@```$````_2````T````"(0``%````!`A```'````)2$```4````M
M(0``#P```#,A```/````0R$```4```!3(0``$P```%DA```0````;2$```4`
M``!^(0``$@```(0A```@````ER$```@```"X(0``!P```,$A```"````R2$`
M`"4```#,(0``!@```/(A```0````^2$```D````*(@``"@```!0B```'````
M'R(```D````G(@``"0```#$B```(````.R(``!4```!$(@``!````%HB```(
M````7R(```4```!H(@``.````&XB```@````IR(```<```#((@``"@```-`B
M```1````VR(``!````#M(@``!P```/XB```5````!B,``!P````<(P``+```
M`#DC```6````9B,```<```!](P``)0```(4C```D````JR,``!8```#0(P``
M+P```.<C```#````%R0```\````;)```!0```"LD```)````,20``!8````[
M)```!0```%(D```0````6"0```,```!I)```#````&TD```*````>B0``!D`
M``"%)```#P```)\D```/````KR0``!@```"_)```$````-@D```0````Z20`
M`!,```#Z)````P````XE```5````$B4``!4````H)0``&@```#XE```'````
M624```@```!A)0``*0```&HE```U````E"4``!X```#*)0``'@```.DE```&
M````""8```,````/)@``'@```!,F```H````,B8```\```!;)@``"0```&LF
M```(````=28``!0```!^)@``$````),F```*````I"8``!0```"O)@``"```
M`,0F```)````S28```\```#7)@``#````.<F```/````]"8```\````$)P``
M`@```!0G```%````%R<```X````=)P``.@```"PG```J````9R<``"T```"2
M)P``,@```,`G```/````\R<``'D````#*```)@```'TH```0````I"@``!``
M``"U*```!0```,8H```!``````````T````Y````)P````````!T````@P``
M`$8```"/````B0```&4```!`````;P```)0``````````````&,`````````
M1P````````"?````-@````````"3`````P`````````^````>0```%,````Z
M`````````#0````/````&@```#\```"-`````````(P```"2````C@```"D`
M````````(0```!T```!7````30```&L`````````-0```%$`````````>P``
M`"@````'`````````"(`````````$P```%L````Q````!0```$$`````````
M`````'<```"9`````````#@```!9````4@```)X```!*````/0````````"7
M````(P```&@````[`````````$4```"$````(````'4````7````>@```)L`
M``!R``````````````!V````,P```!````!Q`````````&8````"````@0``
M````````````'````"8```!+````!````*$```!>````7P``````````````
M'@```)8```!S````6````!0```"+````%@```&D```!P`````````!D```"=
M````+@```'@```!@````*P````````!)````*@```!(``````````````&H`
M``"C`````````*``````````#@```&<````\````3````#<```"1````````
M````````````"@```$\```!5`````````&(```!#````?````&X```!0````
M'P```"\````````````````````8````+````%8``````````````"0`````
M````7````&T```"&````A0```&P````;````?0````8````E````F````$X`
M``"*````AP```(@```"<`````````!$`````````"0````@```!A````E0``
M``````!4``````````L```"D````#````!4`````````H@````````"`````
M`````)H```````````````````!D````,@````````!=````1````$@```!"
M`````````)``````````6@```((`````````+0```#````!^`````````'\`
M`````````"5S("T@3F]T:6-E`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VX`)7,@5&5R;7,@;V8@06=R965M96YT`#(T(&AO=7)S
M`$%-+U!-`$%D9`!!9&0@82!N97<@=7-E<CH`061D('!A:7(`061D('5S97(`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=')A=&EO;@!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N`$%S8V5N9&EN9P!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!=F%I;&%B;&4@9FEE;&1S.@!"
M:7)T:&1A>0!#86QE;F1A<@!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-A=&5G;W)Y`$-E;&P@4&AO;F4`0VQE87(@1F]R;0!#;&EC:R!T;R!#;VYT
M:6YU90!#;&]S92!7:6YD;W<`0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG
M;B!M97-S86=E+@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V
M97(N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5F875L="!S;W)T:6YG(&-R
M:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$97-C96YD:6YG
M`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%;6%I;`!%;7!T
M>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C
M;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!&87@`1FEL92!-86YA9V5R`$=R;W5P($%D;6EN:7-T<F%T:6]N
M`$=R;W5P<P!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM
M<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI
M<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]G
M(&EN`$QO9R!O=70`34T`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+@!-86EL`$UA=&-H:6YG(&9I96QD<P!-96UB97)S`$UE;6\@5&5X
M=`!-97-S86=E`$UI;64@5'EP90!-;V1I9GEI;F<@)7,`36]N=&AL>0!.3RP@
M22!$;R!.3U0@06=R964`3F%M90!.971W;W)K`$YE=F5R`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!V
M86QI9"!834P@9&%T82!R971U<FYE9`!.;W1E<P!/<'1I;VYS`$]T:&5R($EN
M9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`4&%S<W=O<F0`4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0`4')O8FQE;2!$97-C<FEP=&EO;@!0=6)L:6,O
M4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!2
M96%D`%)E9G)E<V@@3&ES=`!296UO=F4`4F5M;W9E('!A:7(`4F5T=7)N('1O
M($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5A<F-H`%-E87)C:"!297-U
M;'1S`%-E87)C:"!38V]P90!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;F0@4')O8FQE;2!297!O<G0`4VAO=P!3:VEP($UA:6YT96YA;F-E`%-O<G0@
M8GD@0V%T96=O<GD`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5C8V5S<P!4
M87-K<P!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE
M`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`
M56YF:6QE9`!5<&1A=&4`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO
M;G,`57-E<FYA;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN9P!7965K
M;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!960!996%R;'D`665S+"!)($%G<F5E`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O
M<G1=`%ML:6YE("5S(&]F("5S70!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ
M($UN96UO(#(N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`V+3`X(#(R.C0R*S`Q
M,#`*3&%S="U4<F%N<VQA=&]R.B!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T
M82YO<F<^"DQA;F=U86=E+51E86TZ($YO<G=E9VEA;B!.>6YO<G-K(#QN>6YO
M<G-K0&]R<W1A+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`H`)7,@+2!.;W1I<P`E<R!V961L:6ME:&%L
M9'-O<&5R87-J;VYA<B`M(%-T861F97-T:6YG`"5S(%9I;&OE<B!F;W(@879T
M86QE`#(T('1I;6%R`$%-+U!-`$QE9V<@=&EL`$QE9V<@=&EL(&YY(&)R=6MA
M<CH`3&5G9R!T:6P@<&%R`$QE9V<@=&EL(&)R=6MA<@!,96=G('1I;"!B<G5K
M87)A<B!E<B!S;.5T="!A=BX`061R97-S90!!9')E<W-E8F]K`$%D;6EN:7-T
M<F5R:6YG`$%L:6%S`$5I;B!U;&]V;&5G('9E<F1I('9A<G0@<W!E<VEF:7-E
M<G0N`%-T:6=A;F1E`%-P^'(@;VT@<W1A9&9E<W1I;F<@9OAR(&OX>7)I;F<@
M878@=F5D;&EK96AA;&1S;W!E<F%S:F]N87(_`%!R^'9D92#E('-L971T92!E
M:2!I:VMJ92UE:W-I<W1E<F%N9&4@9W)U<'!E+@!0<OAV9&4@Y2!S;&5T=&4@
M96EN(&EK:VIE+65K<VES=&5R86YD92!T:6QG86YG+@!0<OAV9&4@Y2!E;F1R
M92!E:6X@:6MK:F4M96MS:7-T97)A;F1E('1I;&=A;F<N`%1I;&=J96YG96QE
M9V4@9F5L=#H`0G5R<V1A9P!+86QE;F1E<@!!=F)R>70`079B<GET('!R;V)L
M96UR87!P;W)T`$MA=&5G;W)I`$UO8FEL=&5L969O;@!.=6QL<W1I;&P@<VMJ
M96UA`$ML:6MK(&9O<B#E(&AA;&1E(&9R86T`3'5K:R!V:6YD875G970`1FER
M;6$`4W1A9&9E<W0@<&%S<V]R9`!/<'!K;W!L:6YG(&UO="!O9F9E;G1L96<@
M;OAK:V5L=&5N87(@;F5K=&$N`$MU;FYE(&EK:VIE(%!'4"UK;V1E(&UE;&1I
M;F<N`$MU;FYE(&EK:VIE(%!'4"US:6=N97)E(&UE;&1I;F<N`$MU;FYE(&EK
M:VIE(&1E:V]D92!01U`M9&%T82X`2W5N;F4@:6MK:F4@879G:F5R92!M;W1T
M86MA<F5N('-I(&4M<&]S=&%D<F5S<V4N`$MU;FYE(&EK:VIE('-K869F92!O
M9F9E;G1L96<@;OAK:V5L(&9RY2!N^&MK96QT96YA<F5N+@!+=6YN92!I:VMJ
M92!O<&YE($UA:6YT96YA;F-E7U1A<VLM;6]D=6QE;B`E<P!$1`!$86=L96<`
M4W1A;F1A<F1I9&5N=&ET970`4W1A;F1A<F0@<V]R=&5R:6YG<VMR:71E<FEU
M;3H`4W1A;F1A<F0@<V]R=&5R:6YG<W)E:VME9OAL9VIE.@!3>6YK86YD90!3
M:VEL9')E('!R;V)L96UE=`!$971A;&IA<B!E<B!L;V=G82!F;W(@861M:6YI
M<W1R871O<F5N+@!6:7-I;F=S86QT97)N871I=@!):VMJ92!B<G5K(&UA:6YT
M96YA;F-E+G!H<"!D:7)E:W1E+@!%+7!O<W0`5&]M="!R97-U;'1A="X`1F5I
M;`!+=F%R="`Q-2X@;6EN=71T`$MV87)T(#,P+B!S96MU;F0`2W9A<G0@-2X@
M;6EN=71T`$MV87(@:6YN;&]G9VEN9P!+=F%R(&AA;'9E('1I;64`2W9A<G0@
M;6EN=71T`$5K<V5M<&5L=F5R9&EA<CH`2W5N;F4@:6MK:F4@:&5N=&4@:6YN
M<W1I;&QI;F=A<@!+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N
M+@!&86MS`$9I;&AA;F1S86UI;F<`1W)U<'!E861M:6YI<W1R97)I;F<`1W)U
M<'!E<@!(:F5L<`!!9')E<W-E+"!P<FEV870`5&5L969O;BP@<')I=F%T`$AO
M<F1E`$EM<&]R=&5R=&4@9F5L=#H@)7,`26UP;W)T97)T92!F96QT.@!3<'+E
M:P!6:7,@96UN92!F<N4@2&IE;'``3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S
M;.5T="!A=BX`3&]G9R!I;FX`3&]G9R!U=`!-30!-4RU43D5&+79E9&QE9V<@
M:6YN96AE;&1T(&EN9V5N(&1A=&$N`$4M<&]S=`!386US=F%R86YD92!F96QT
M`$UE9&QE;6UA<@!.;W1A='1E:W-T`$UE;&1I;F<`34E-12UT>7!E`$5N9')A
M<B`E<P!-Y6YA9&QE9P!.14DL(&5G(&5R($E+2TI%('-A;60`3F%M;@!.971T
M=F5R:P!!;&1R:0!);F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P
M97-I9FES97)T(&9O<B!344P@5D93+@!);F=E;B!G>6QD:6=E(%A-3"UD871A
M(')E='5R;F5R=`!.;W1A=&%R`$%L=&5R;F%T:78`06YN86X@:6YF;W)M87-J
M;VX`06YD<F4@86QT97)N871I=@!087-S;W)D`%!A<W-O<F1A(&WE('-A;7-V
M87)E+@!+^'ER('9E9&QI:V5H86QD<V]P97)A<VIO;F%R`$OX>7(@=F5D;&EK
M96AA;&1S;W!E<F%S:F]N87(@=F5D(&EN;FQO9V=I;F<_`%1I;&=A;F=S861M
M:6YI<W1R97)I;F<`5&5L969O;@!3:W)I=B!I;FX@96ET('-A;6%N9')A9R!A
M=B!P<F]B;&5M970N`%-K<FEV(&EN;B!D:71T(&)R=6MA<FYA;6X@;V<@<&%S
M<V]R9`!3:VEL9')I;F<@878@<')O8FQE;65T`$]F9F5N=&QE9R]P<FEV870@
M;OAK:V5L<&%R('9A<G0@:6MK:F4@9V5N97)E<G0N`$QE<P!&<FES:R!O<'`@
M;&ES=&4`1FIE<FX`1FIE<FX@<&%R`%1I;&)A:V4@=&EL(&%L=&5R;F%T:78`
M4F]L;&4`3&%G<F4@86QT97)N871I=@!3^&L`4_AK97)E<W5L=&%T`%/X:V5O
M;7+E9&4`5F5L('-K:6QJ971E:6MN(&9O<B!D871O.@!696P@9&%T;V9O<FUA
M=#H`5F5L('1I9'-F;W)M870Z`%9E;"!T;R!S86US=F%R86YD92!F96QT+@!6
M96P@9F%R9V5S:VIE;6$N`%9E;"#X;G-K82!S<'+E:SH`4V5N9"!P<F]B;&5M
M<F%P<&]R=`!6:7,`2&]P<"!O=F5R('9E9&QI:V5H86QD`%-O<G1E<B!E='1E
M<B!K871E9V]R:0!);FYT87-T:6YG(&%V('-P97-I86QT96EK;@!3=6MS97-S
M`$]P<&?E=F5R`$ML87-S82!-86EN=&5N86YC93HZ('9A<G0@:6MK:F4@;&%S
M=&$@:6YN`$MR>7!T97)I;F=S9G5N:W-J;VYA;F4@:W)E=B!E:2!S:6MK97(@
M;F5T=&]P<&MO<&QI;F<N`$1E='1E('1A;&5T(&WE('9E<F4@;6EN<W0@96EN
M+@!$96YN92!V97)D:65N(&WE('9E<F4@96ET('1A;"X`5&ET=&5L`%523`!+
M86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BX`2V%N(&EK:VIE(&]M<V5T
M:F4@9&5T=&4@5V]R9"UD;VMU;65N=&5T+@!!;F=R92!E;F1R:6YG87(`56%R
M:VEV97)T`$]P<&1A=&5R`$)R=6MA<F%D;6EN:7-T<F5R:6YG`$)R=6MA<F%L
M=&5R;F%T:78`0G)U:V%R;F%M;@!"<G5K87)A<B!I('-Y<W1E;65T.@#%='9A
M<FEN9P!+=F%R('9E:V4`5F5L:V]M96X@=&EL("5S`%9E;&MO;65N+"`E<P!!
M9')E<W-E+"!A<F)E:60`5&5L969O;BP@87)B96ED`,7%`,5R;&5G`$IA+"!E
M9R!E<B!S86UD`$1U(&WE('-K:6QD<F4@<')O8FQE;65T(&;X<B!D=2!K86X@
M<V5N9&4@<')O8FQE;7)A<'!O<G1E;BX`1'4@;>4@<W!E<VEF:7-E<F4@96ET
M(&)R=6MA<FYA;6X@Y2!F:F5R;F4N`$1U(&WE('-P97-I9FES97)E(&5I="!B
M<G5K87)N86UN(.4@;&5G9V4@=&EL+@#8:W1A(&1I("@E<RD@:&%R(&?E='0@
M=70@<.4@=&ED+B!,;V=G(&EN;B!PY2!N>71T+@!$:6X@:6YF;W)M87-J;VX`
M3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!I:VMJ92!S=/AT=&$@878@8F%K<F4@
M875T96YT:7-E<FEN9RP@96QL97(@9G5N:W-J;VYE;B!H87(@878@96EN(&5L
M;&5R(&%N;F%N(&=R=6YN(&)L:71T('-LY71T(&%V+@!!;'1E<FYA=&EV82!D
M:6YE(&AA<B!B;&ET="!O<'!D871E<G1E+@!;4')O8FQE;7)A<'!O<G1=`%ML
M:6YJ92`E<R!A=B`E<UT`=D-A<F0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO
M+VQO8V%L92]P;%]03"\`````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(P,#`T`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+W!L7U!,+TQ#7TU%4U-!1T53+P``
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-``P
M,C$U-S$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O<&Q?
M4$PO3$-?34534T%'15,O;6YE;6\N;6\`````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,34U
M,S0Q`#$P-#$W,S8R-S0T`#`R,S(T-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````*4#```<````1!T``.$$``!L
M.@```````/!-``!(````\4T```X````Z3@``#P```$E.```-````64X```@`
M``!G3@``"P```'!.```,````?$X``!L```")3@``+0```*5.```D````TTX`
M`"D```#X3@``&0```")/```,````/$\```@```!)3P``"P```%)/```1````
M7D\```X```!P3P``!0```']/```H````A4\```@```"N3P``"@```+=/```2
M````PD\``!T```#53P``#@```/-/```*`````E````T````-4```#@```!M0
M```1````*E````T````\4```#````$I0```-````5U````8```!E4```#```
M`&Q0```&````>5````X```"`4```#@```(]0```(````GE````D```"G4```
M&@```+%0```R````S%```#@```#_4```5````#A1``!1````C5$``%H```#?
M40``5P```#I2```T````DE(```4```#'4@``$0```,U2```(````WU(``!P`
M``#H4@``'@````53```@````)%,``!T```!%4P``$````&-3```/````=%,`
M``H```"$4P```P```(]3```)````DU,```T```"=4P``$@```*M3```/````
MOE,```P```#.4P``"@```-M3```/````YE,```@```#V4P``)````/]3```4
M````)%0``!8````Y5```"````%!4```M````650``!$```"'5```&0```)E4
M```'````LU0```P```"[5```#@```,A4```#````UU0```L```#;5```!P``
M`.=4```'````[U0```4```#W5````P```/U4```7`````54```H````950``
M#P```"15```8````-%4```X```!-50``%````%Q5```7````<54``!<```")
M50``%P```*%5```/````N54``!\```#)50``!P```.E5```&````\54```@`
M``#X50``#P````%6```&````$58```H````85@``"P```"-6```5````+U8`
M``<```!%5@``!0```$U6```1````4U8```P```!E5@``"0```')6```'````
M?%8```4```"$5@``"0```(I6```Y````E%8```H```#.5@``!@```-E6```)
M````X%8```<```#J5@``+P```/)6```N````(E<``%4```!15P``+0```*=7
M```M````U5<``"T````#6```(P```#%8```C````55@``"T```!Y6```,P``
M`*=8```5````VU@``!D```#Q6```*0````M9```D````-5D``!4```!:60``
M$0```'!9```*````@ED```P```"-60``#P```)I9```7````JED```H```#"
M60``$````,U9```6````WED``!8```#U60``!P````Q:```'````%%H``!0`
M```<6@``"@```#%:```'````/%H```<```!$6@``!@```$Q:```%````4UH`
M``<```!96@``!@```&%:```(````:%H```X```!Q6@``"@```(!:```'````
MBUH```D```"36@``%@```)U:```$````M%H```8```"Y6@``"````,!:```#
M````R5H```,```#-6@```P```-%:```3````U5H```@```#I6@``"````/):
M```(````^UH``$$````$6P``(````$9;```&````9UL```8```!N6P``%0``
M`'5;```8````BUL``"(```"D6P``'0```,=;```*````Y5L``!4```#P6P``
M"`````9<```*````#UP```\````:7```#P```"I<```)````.EP``!0```!$
M7```&````%E<```=````<EP``!,```"07```$0```*1<```$````MEP```8`
M``"[7```5````,)<```M````%UT```X```!%70``1````%1=```%````F5T`
M``4```"?70``$0```*5=```1````MUT``!P```#)70``-P```.9=```<````
M'EX``!`````[7@``"@```$Q>```1````5UX```P```!I7@``%P```'9>```0
M````CEX```@```"?7@``!0```*A>```,````KEX``!````"[7@``#0```,Q>
M```'````VEX```T```#B7@``!P```/!>```'````^%X```<`````7P``%```
M``A?```)````'5\```H````G7P``#````#)?```0````/U\```4```!07P``
M)0```%9?```2````?%\``!,```"/7P``*P```*-?```[````SU\``"`````+
M8```-@```"Q@```0````8V````@```!T8```#````'U@```$````BF````X`
M``"/8```'@```)Y@```;````O6```"$```#98```'@```/M@```>````&F$`
M`"X````Y80``&P```&AA```>````A&$``#,```"C80``+P```-=A```@````
M!V(``!(````H8@``*0```#MB```>````96(``!8```"$8@``00```)MB```'
M````W6(```8```#E8@``#0```.QB```0````^F(```<````+8P``$@```!-C
M```'````)F,```0````N8P``#````#-C```H````0&,```,```!I8P``!@``
M`&UC```.````=&,```(```"#8P``!0```(9C```$````C&,```X```"18P``
M"````*!C```-````J6,``!````"W8P``#P```,AC```3````V&,``!,```#L
M8P``&0````!D```:````&F0```8````U9```#````#QD```1````260``!D`
M``!;9```"P```'5D```-````@60``!L```"/9```-````*MD```*````X&0`
M`!@```#K9```&0````1E```6````'F4``"\````U90``!P```&5E```*````
M;64``!0```!X90``#````(UE```O````FF4```D```#*90``%@```-1E```/
M````ZV4```@```#[90``#0````1F```F````$F8```@````Y9@``$@```$)F
M```(````568```L```!>9@``!0```&IF```&````<&8```<```!W9@``!```
M`']F```*````A&8```D```"/9@``#P```)EF```0````J68``!<```"Z9@``
M$0```-)F```7````Y&8```4```#\9@``"P````)G```%````#F<```T````4
M9P``&P```")G```)````/F<```H```!(9P``#@```%-G```-````8F<``"``
M``!P9P``$0```)%G```'````HV<```4```"K9P``$P```+%G```'````Q6<`
M``@```#-9P``!@```-9G```0````W6<```\```#N9P``$````/YG```/````
M#V@```L````?:```#P```"MH```,````.V@```\```!(:```!P```%AH```&
M````8&@```X```!G:```!@```'9H```,````?6@```H```"*:```(0```)5H
M```9````MV@``!<```#1:```%P```.EH```;`````6D```T````=:0``#```
M`"MI```#````.&D```@````\:0``!````$5I```,````2FD```D```!7:0``
M#@```&%I```+````<&D``!L```!\:0``!P```)AI```'````H&D```0```"H
M:0``%0```*UI```&````PVD```T```#*:0``$````-AI```;````Z6D```0`
M```%:@``!0````IJ```&````$&H```<````7:@``!0```!]J```)````)6H`
M``(````O:@``#0```#)J```&````0&H```D```!':@``!P```%%J```&````
M66H```H```!@:@``!````&MJ```)````<&H```@```!Z:@``!@```(-J```-
M````BFH```8```"8:@``!````)]J```%````I&H``"$```"J:@``!````,QJ
M```$````T6H```4```#6:@``'0```-QJ```$````^FH```P```#_:@``"@``
M``QK```(````%VL```D````@:P``!0```"IK```I````,&L```<```!::P``
M!P```&)K```*````:FL```\```!U:P``$````(5K```&````EFL``!4```"=
M:P``$P```+-K```2````QVL``!````#::P``!0```.MK```)````\6L```0`
M``#[:P``#`````!L```7````#6P``!P````E;```$P```$)L```4````5FP`
M`!D```!K;```!````(5L```'````BFP```8```"2;```!@```)EL```%````
MH&P```<```"F;```!P```*YL```%````MFP```8```"\;```!````,-L```$
M````R&P```H```#-;```!0```-AL```,````WFP```\```#K;```"@```/ML
M```(````!FT``"L````/;0``!````#MM```(````0&T``"8```!);0``$@``
M`'!M```&````@VT```H```"*;0``!P```)5M```(````G6T``"````"F;0``
M#0```,=M```.````U6T``!8```#D;0``$0```/MM```&````#6X```<````4
M;@``!P```!QN```6````)&X```T````[;@``$````$EN```:````6FX```D`
M``!U;@``"@```']N```,````BFX```\```"7;@``!@```*=N```'````KFX`
M``L```"V;@``1P```,)N```-````"F\```,````8;P``"@```!QO```"````
M)V\```0````J;P```P```"]O```%````,V\``"H````Y;P``"@```&1O```$
M````;V\```8```!T;P``"````'MO```(````A&\```0```"-;P``!0```))O
M``!H````F&\```4````!<```!@````=P```0````#G````H````?<```#P``
M`"IP```*````.G````D```!%<````P```$]P```'````4W````D```!;<```
M"@```&5P```+````<'````<```!\<```&@```(1P``!*````GW````8```#J
M<```"0```/%P```-````^W````H````)<0``#````!1Q```'````(7$``!0`
M```I<0``!@```#YQ```(````17$```<```!.<0``"@```%9Q```+````87$`
M``<```!M<0``"0```'5Q```)````?W$```H```")<0``!P```)1Q```)````
MG'$```<```"F<0``"@```*YQ```*````N7$```@```#$<0``"0```,UQ```'
M````UW$```0```#?<0``!P```.1Q```%````['$```4```#R<0``"P```/AQ
M```4````!'(```<````9<@``!0```"%R```-````)W(```P````U<@``"```
M`$)R```+````2W(```0```!7<@``!````%QR```,````87(```D```!N<@``
M!0```'AR```'````?G(```0```"&<@``"@```(MR```N````EG(``!````#%
M<@``)````-9R```(````^W(``"0````$<P``$P```"ES```M````/7,``"T`
M``!K<P``,0```)ES```M````RW,``"X```#Y<P``+P```"AT```L````6'0`
M``4```"%=```!````(MT```.````D'0```8```"?=```$````*9T```'````
MMW0```X```"_=```#0```,YT```,````W'0```D```#I=```"@```/-T```/
M````_G0```@````.=0``#P```!=U```(````)W4```4````P=0``#0```#9U
M```&````1'4```@```!+=0``$0```%1U```.````9G4```(```!U=0``!P``
M`'AU```&````@'4```0```"'=0``'P```(QU```4````K'4```<```#!=0``
M#@```,EU```,````V'4``!,```#E=0``"@```/EU```%````!'8``!$````*
M=@``#0```!QV```1````*G8``"0````\=@``%0```&%V```2````=W8```X`
M``"*=@``&0```)EV```(````LW8```D```"\=@``"@```,9V```(````T78`
M``4```#:=@``!@```.!V```0````YW8```@```#X=@``"`````%W```2````
M"G<``!H````==P``"0```#AW```*````0G<``!4```!-=P``!0```&-W```4
M````:7<``!X```!^=P``*````)UW```*````QG<``!$```#1=P``"P```.-W
M```/````[W<``!0```#_=P``!````!1X```+````&7@```4````E>```"```
M`"MX```T````-'@``#0```!I>```(````)YX```:````OW@``"@```#:>```
M*0````-Y```&````+7D```@````T>0``!P```#UY```+````17D```<```!1
M>0``$P```%EY```*````;7D``!0```!X>0``#P```(UY```R````G7D```L`
M``#0>0``!0```-QY```%````XGD``!<```#H>0``'@````!Z```,````'WH`
M`!0````L>@``#@```$%Z```&````4'H```P```!7>@``#P```&1Z```-````
M='H```L```"">@``"@```(YZ```+````F7H```\```"E>@``!0```+5Z```.
M````NWH``!,```#*>@``!P```-YZ```1````YGH```<```#X>@``&`````![
M```$````&7L```<````>>P``"@```"9[```+````,7L```P````]>P``#@``
M`$I[```2````67L```8```!L>P``&````'-[```E````C'L```D```"R>P``
M`P```+Q[```*````P'L```P```#+>P``%0```-A[```+````[GL``!D```#Z
M>P``(````!1\```%````-7P```H````[?```#````$9\```$````4WP```D`
M``!8?```!P```&)\```,````:GP```8```!W?```#@```'Y\```,````C7P`
M``P```":?```#````*=\```0````M'P``!H```#%?```%P```.!\```9````
M^'P``!H````2?0``)0```"U]```G````4WT``!H```![?0``%P```)9]```;
M````KGT``!D```#*?0``'P```.1]```4````!'X``!,````9?@``!P```"U^
M```)````-7X```T````_?@```P```$U^```_````47X``#<```"1?@``5P``
M`,E^```%````(7\```H````G?P``#0```#)_```$````0'\``!0```!%?P``
M)0```%I_```2````@'\``"````"3?P``'0```+1_```,````TG\``!D```#?
M?P``"0```/E_```3`````X````D````7@```!````"&````0````)H````@`
M```W@```"````$"````/````28````<```!9@```$````&&````1````<H``
M``P```"$@```&P```)&````L````K8````4```#:@```!````."````7````
MY8````H```#]@```#`````B!```)````%8$```D````?@0``$0```"F!```&
M````.X$```X```!"@0``!P```%&!```&````68$```<```!@@0``)@```&B!
M```X````CX$``!H```#(@0``*@```..!```9````#H(```4````H@@``#@``
M`"Z"```(````/8(```D```!&@@``!@```%""```+````5X(``!0```!C@@``
M!@```'B"```9````?X(```H```"9@@``'````*2"```%````P8(``!````#'
M@@``"0```-B"```(````XH(``!\```#K@@``(P````N#```5````+X,``"@`
M``!%@P``(@```&Z#```B````D8,``"````"T@P``(0```-6#```?````]X,`
M`"<````7A```'P```#^$```Q````7X0``$$```"1A```,P```-.$```E````
M!X4``"\````MA0``*0```%V%```L````AX4``"@```"TA0``)@```-V%```K
M````!(8``!X````PA@``+P```$^&```L````?X8``!<```"LA@``(@```,2&
M```B````YX8``$4````*AP``,````%"'```$````@8<```L```"&AP``!0``
M`)*'```"````F(<``%D```";AP``!0```/6'```$````^X<```<`````B```
M"`````B(```%````$8@``!,````7B```#0```"N(```'````.8@```8```!!
MB```%````$B(```,````78@```8```!JB````P```'&(```$````=8@```8`
M``!ZB```!P```(&(```7````B8@``"````"AB```&@```,*(```9````W8@`
M`"8```#WB```#````!Z)```'````*XD``!0````SB0``#@```$B)```-````
M5XD```<```!EB0``!P```&V)```5````=8D```8```"+B0``!@```)*)```'
M````F8D```P```"AB0``$0```*Z)```(````P(D``!T```#)B0``"0```.>)
M```*````\8D``!0```#\B0``"@```!&*```(````'(H```<````EB@``"0``
M`"V*```'````-XH```@````_B@``!P```$B*```9````4(H```H```!JB@``
M%P```'6*```4````C8H``!$```"BB@``!P```+2*```#````O(H```8```#`
MB@``!P```,>*```-````SXH```L```#=B@``%````.F*```5````_HH```X`
M```4BP``+P```".+```K````4XL``#$```!_BP``/P```+&+```,````\8L`
M``H```#^BP```@````F,```$````#(P```8````1C```!0```!B,```#````
M'HP```P````BC```,@```"^,```9````8HP``$4```!\C```*````,*,```F
M````ZXP``"4````2C0``$@```#B-```3````2XT``!````!?C0``>0```'"-
M```)````ZHT``'(```#TC0``<P```&>.```7````VXX``!8```#SC@``%0``
M``J/```/````((\``!\````PCP``#@```%"/``!`````7X\``!\```"@CP``
M%````,"/```*````U8\```4```#@CP``!@```.:/```(````[8\``!````#V
MCP``#P````>0```0````%Y````0````HD```"0```"V0```'````-Y````L`
M```_D```!0```$N0```+````49````<```!=D```!0```&60```.````:Y``
M``L```!ZD```!P```(:0```(````CI````\```"7D```#````*>0```)````
MM)````@```"^D```#````,>0```&````U)````\```#;D```!P```.N0```&
M````\Y````8```#ZD```#`````&1```(````#I$```0````7D0``!````!R1
M```'````(9$```D````ID0``!P```#.1```%````.Y$```4```!!D0``80$`
M`$>1``!#````J9(```X```#MD@``$@```/R2```1````#Y,```<````ADP``
M"````"F3```*````,I,``"(````]DP``+P```&"3```=````D),``"(```"N
MDP``'@```-&3```*````\),```H```#[DP``"@````:4```0````$90```\`
M```BE```!0```#*4```G````.)0```\```!@E```#@```'"4```0````?Y0`
M`"$```"0E```$````+*4```(````PY0``!$```#,E```#0```-Z4```3````
M[)0```P`````E0``"P````V5```.````&94```8````HE0``#0```"^5```)
M````/94``!(```!'E0``$@```%J5```(````;94```H```!VE0``%P```(&5
M```_````F94``$@```#9E0``7````"*6``!9````?Y8``&(```#9E@``7P``
M`#R7``!!````G)<```4```#>EP``#@```.27```.````\Y<``"0````"F```
M)P```">8```L````3Y@``"D```!\F```#@```*:8```2````M9@```4```#(
MF```!0```,Z8```,````U)@``!````#AF```%@```/*8```9````"9D```\`
M```CF0``#0```#.9```5````09D```H```!7F0``'@```&*9```;````@9D`
M`"````"=F0``$0```+Z9```M````T)D``!(```#^F0``)@```!&:```%````
M.)H``!`````^F@``#0```$^:```'````79H```H```!EF@``!P```'":```(
M````>)H```4```"!F@``"````(>:```C````D)H```\```"TF@``%0```,2:
M```7````VIH```P```#RF@``%P```/^:```7````%YL``",````OFP``&```
M`%.;```3````;)L``"4```"`FP``!@```*:;```&````K9L```@```"TFP``
M#P```+V;```)````S9L```H```#7FP``"0```.*;```0````[)L```D```#]
MFP``"`````><```1````$)P```X````BG```"0```#&<```'````.YP```4`
M``!#G```!P```$F<```]````49P```@```"/G```"````)B<```)````H9P`
M``<```"KG```.````+.<```X````[)P``%L````EG0``-P```(&=```W````
MN9T``#<```#QG0``+@```"F>```R````6)X``#<```"+G@``/0```,.>```A
M`````9\``"4````CGP``+P```$F?```Q````>9\``!,```"KGP``#@```+^?
M```+````SI\```P```#:GP``$0```.>?```7````^9\```,````1H```"0``
M`!6@```4````'Z```!\````TH```#````%2@```'````8:```!8```!IH```
M"@```("@```(````BZ````8```"4H```!@```)N@```%````HJ````<```"H
MH```!@```+"@```.````MZ```!````#&H```"0```->@```'````X:````@`
M``#IH```%````/*@```#````!Z$```@````+H0``"````!2A```#````':$`
M``,````AH0```P```"6A```;````*:$```D```!%H0``"````$^A```'````
M6*$``$\```!@H0``+0```+"A```&````WJ$```8```#EH0``&0```.RA```=
M````!J(``"P````DH@``(````%&B```9````<J(``!8```",H@``"0```*.B
M```)````K:(``!,```"WH@``$P```,NB```)````WZ(``!8```#IH@``&@``
M``"C```?````&Z,``!4````[HP``%@```%&C```$````:*,```8```!MHP``
M1@```'2C```[````NZ,```\```#WHP``,P````>D```%````.Z0```4```!!
MI```"P```$>D```7````4Z0``"````!KI```.0```(RD```9````QJ0``!<`
M``#@I```$0```/BD```6````"J4```P````AI0``&0```"ZE```-````2*4`
M``@```!6I0``!0```%^E```-````9:4```P```!SI0``#0```("E```'````
MCJ4```<```"6I0``"0```)ZE```&````J*4```4```"OI0``%0```+6E```)
M````RZ4```<```#5I0``#@```-VE```/````[*4```4```#\I0``'0````*F
M```<````(*8``!T````]I@``+````%NF```[````B*8``"D```#$I@``/@``
M`.ZF```.````+:<```@````\IP``"P```$6G```'````4:<```T```!9IP``
M*P```&>G```H````DZ<``"X```"\IP``*P```.NG```J````%Z@``#D```!"
MJ```)0```'RH```H````HJ@``"T```#+J```,P```/FH```F````+:D``!8`
M``!4J0``+0```&NI```@````F:D``"(```"ZJ0``10```-VI```$````(ZH`
M``4````HJ@``"P```"ZJ```+````.JH```D```!&J@``%@```%"J```)````
M9ZH```0```!QJ@``"P```':J```W````@JH```8```"ZJ@``!````,&J```/
M````QJH```(```#6J@``"@```-FJ```$````Y*H```T```#IJ@``"````/>J
M```.`````*L``!(````/JP``$0```"*K```4````-*L``!0```!)JP``'@``
M`%ZK```;````?:L```0```"9JP``"@```)ZK```0````J:L``!D```"ZJP``
M#````-2K```,````X:L``!L```#NJP``.@````JL```+````1:P``!@```!1
MK```%0```&JL```4````@*P``#0```"5K```!0```,JL```(````T*P```T`
M``#9K```!````.>L```P````[*P```<````=K0``)@```"6M```2````3*T`
M``<```!?K0``"0```&>M```N````<:T``!T```"@K0``(P```+ZM```(````
MXJT```L```#KK0``"0```/>M```&`````:X```<````(K@``!@```!"N```*
M````%ZX```P````BK@``$0```"^N```1````0:X``!@```!3K@``%0```&RN
M```8````@JX```4```";K@``"````*&N```%````JJX```L```"PK@``)0``
M`+RN```)````XJX```L```#LK@``$````/BN```0````":\``#8````:KP``
M$````%&O```'````8J\```0```!JKP``%P```&^O```'````AZ\```<```"/
MKP``!@```)>O```1````GJ\``!$```"PKP``$@```,*O```0````U:\``!0`
M``#FKP``%````/NO```/````$+```!4````@L```!P```#:P```&````/K``
M``P```!%L```!P```%*P```/````6K````\```!JL```*@```'JP```?````
MI;```"````#%L```(@```.:P```3````";$```L````=L0``$````"FQ```$
M````.K$```0````_L0``!0```$2Q```/````2K$```L```!:L0``"P```&:Q
M```/````<K$``"8```""L0``!@```*FQ```)````L+$```@```"ZL0``$@``
M`,.Q```'````UK$``!````#>L0``$P```.^Q```N`````[(```(````RL@``
M!0```#6R```&````.[(```8```!"L@``!0```$FR```)````3[(```,```!9
ML@``$P```%VR```&````<;(```H```!XL@``!P```(.R```0````B[(```D`
M``"<L@``!````*:R```)````J[(```@```"UL@``!@```+ZR```-````Q;(`
M``8```#3L@``!````-JR```%````W[(``!<```#EL@``!0```/VR```&````
M`[,```8````*LP``'````!&S```(````+K,```P````WLP``"0```$2S```(
M````3K,```@```!7LP``!0```&"S```E````9K,```4```",LP``"````)*S
M```+````F[,```\```"GLP``$0```+>S```'````R;,``!T```#1LP``%0``
M`.^S```4````!;0``!$````:M```!0```"RT```)````,K0```0````\M```
M#0```$&T```;````3[0``!T```!KM```&@```(FT```=````I+0```0```#"
MM```!````,>T```(````S+0```8```#5M```!P```-RT```&````Y+0```<`
M``#KM```!P```/.T```'````^[0```8````#M0``!@````JU```(````$;4`
M``H````:M0``!0```"6U```0````*[4```T````\M0``#@```$JU```*````
M6;4``#$```!DM0``!@```):U```(````G;4``"@```"FM0``#P```,^U```&
M````W[4```D```#FM0``"P```/"U```%````_+4```0````"M@``%`````>V
M```6````'+8``!L````SM@``&0```$^V```%````:;8```<```!OM@``!P``
M`'>V```%````?[8```T```"%M@``%@```).V```G````JK8```4```#2M@``
M#````-BV```.````Y;8``!D```#TM@``!P````ZW```'````%K<``!8````>
MMP``5P```#6W```;````C;<```4```"IMP``"@```*^W```"````NK<```0`
M``"]MP```P```,*W```%````QK<```D```#,MP``"@```-:W```&````X;<`
M``8```#HMP``!P```.^W```(````][<```0`````N```!0````6X``!;````
M"[@```8```!GN```"````&ZX```/````=[@```D```"'N```#0```)&X```*
M````G[@```D```"JN````P```+2X```'````N+@```T```#`N```"@```,ZX
M```.````V;@```D```#HN```'P```/*X``!:````$KD```8```!MN0``"```
M`'2Y```4````?;D```H```"2N0``"0```)VY```(````I[D``!(```"PN0``
M!@```,.Y```(````RKD```H```#3N0``"@```-ZY```-````Z;D```8```#W
MN0``#0```/ZY```.````#+H```\````;N@``#@```"NZ```.````.KH```X`
M``!)N@``"````%BZ```%````8;H```P```!GN@``"@```'2Z```%````?[H`
M``@```"%N@``!P```(ZZ```%````EKH```4```"<N@``"````**Z```3````
MJ[H```0```"_N@``!0```,2Z```.````RKH```X```#9N@``#````.BZ```-
M````];H```H````#NP``"`````Z[```.````%[L```D````FNP``!0```#"[
M```'````-KL```0````^NP``"@```$.[```9````3KL``!````!HNP``(```
M`'F[```,````FKL``"X```"GNP``'````-:[```K````\[L``"L````?O```
M+P```$N\```K````>[P``"P```"GO```+0```-2\```J`````KT```@````M
MO0``!0```#:]```'````/+T```@```!$O0``%0```$V]```,````8[T```X`
M``!PO0``$0```'^]```1````D;T```T```"CO0``#@```+&]```6````P+T`
M``T```#7O0``$````.6]```)````]KT```4`````O@``$`````:^```%````
M%[X```@````=O@``#0```":^```.````-+X```(```!#O@``"P```$:^```%
M````4KX```0```!8O@``)P```%V^```4````A;X```4```":O@``"````*"^
M```+````J;X``!<```"UO@``"P```,V^```$````V;X```\```#>O@``"@``
M`.Z^```0````^;X``"<````*OP``$@```#*_```:````1;\``!,```!@OP``
M+````'2_```'````H;\```L```"IOP``#````+6_```(````PK\```4```#+
MOP``!@```-&_```1````V+\```@```#JOP``!0```/._```3````^;\``!8`
M```-P```!@```"3````'````*\```!,````SP```!0```$?````0````3<``
M`!H```!>P```+0```'G````+````I\````P```"SP```"P```,#````/````
MS,```!,```#<P```!````/#````(````]<````<```#^P```"`````;!```D
M````#\$``"`````TP0``'P```%7!```;````=<$``!8```"1P0``)@```*C!
M```&````S\$```H```#6P0``!P```.'!```.````Z<$```<```#XP0``#0``
M``#"```/````#L(``!L````>P@``'@```#K"```Z````6<(```D```"4P@``
M!0```)["```)````I,(``!X```"NP@``(0```,W"```-````[\(``!8```#]
MP@``#@```!3#```$````(\,```D````HPP``#@```#+#```,````0<,```D`
M``!.PP``!````%C#```0````7<,``!8```!NPP``!0```(7#```-````B\,`
M`!,```"9PP``!@```*W#```/````M,,```<```#$PP``&0```,S#```*````
MYL,```<```#QPP``$@```/G#```,````#,0```T````9Q```'````"?$```%
M````1,0```8```!*Q```'0```%'$```H````;\0```L```"8Q````P```*3$
M```,````J,0```T```"UQ```$P```,/$```+````U\0``!<```#CQ```&0``
M`/O$```%````%<4```H````;Q0``$````";%```&````-\4```L````^Q0``
M"0```$K%```,````5,4```8```!AQ0``$P```&C%```/````?,4```X```",
MQ0``#0```)O%```0````J<4``!L```"ZQ0``%````-;%```D````Z\4``!\`
M```0Q@``(````##&```<````4<8``!L```!NQ@``%0```(K&```:````H,8`
M`!@```"[Q@``'P```-3&```2````],8``!D````'QP``!P```"''```(````
M*<<```T````RQP``!0```$#'```^````1L<``#4```"%QP``5@```+O'```,
M````$L@```@````?R```"P```"C(```%````-,@``!H````ZR```,P```%7(
M```;````B<@``"$```"ER```%P```,?(```,````W\@``#````#LR```!@``
M`!W)```0````),D```@````UR0``"````#[)```8````1\D```@```!@R0``
M"````&G)```.````<LD```<```"!R0``$P```(G)```9````G<D``!$```"W
MR0``(0```,G)```2````Z\D```D```#^R0``!`````C*```9````#<H```\`
M```GR@``#P```#?*```.````1\H```D```!6R@``%````&#*```&````=<H`
M``P```!\R@``!0```(G*```&````C\H```H```"6R@``(````*'*```@````
MPLH``!8```#CR@``(````/K*```9````&\L```4````URP``%````#O+```'
M````4,L```4```!8RP``!P```%[+```*````9LL```4```!QRP``!@```'?+
M```&````?LL```L```"%RP``"````)'+```'````FLL```X```"BRP``"P``
M`+'+```)````O<L``"0```#'RP``(````.S+```9````#<P``"L````GS```
M'P```%/,```>````<\P``!X```"2S```'````+',```<````SLP``",```#K
MS```(`````_-```S````,,T``$<```!DS0``+@```*S-```L````V\T``#@`
M```(S@``+0```$'.```P````;\X``"H```"@S@``+0```,O.```T````^<X`
M`!P````NSP``*@```$O/```J````=L\``!8```"ASP``(0```+C/```A````
MVL\``$(```#\SP``.````#_0```$````>-````P```!]T```!0```(K0```"
M````D-```%X```"3T```!````/+0```$````]]````<```#\T```!0````31
M```%````"M$``!$````0T0``$````"+1```'````,]$```8````[T0``%```
M`$+1```,````5]$```8```!DT0```P```&O1```$````;]$```8```!TT0``
M!P```'O1```:````@]$``"D```">T0``(P```,C1```8````[-$``"T````%
MT@``#0```#/2```(````0=(``!P```!*T@``#P```&?2```#````=](```@`
M``![T@``"0```(32```;````CM(```H```"JT@``!P```+72```'````O=(`
M`!$```#%T@``%P```-?2```1````[](``"8````!TP``$@```"C3```3````
M.],``!<```!/TP``"@```&?3```'````<M,```<```!ZTP``"0```(+3```&
M````C-,```<```"3TP``"````)O3```0````I-,```T```"UTP``&@```,/3
M```D````WM,```\````#U```"P```!/4```#````']0```H````CU```!@``
M`"[4```+````-=0```H```!!U```%0```$S4```6````8M0``!````!YU```
M,P```(K4```C````OM0``#<```#BU```3P```!K5```.````:M4```T```!Y
MU0```@```(?5```$````BM4```8```"/U0``!0```);5```#````G-4``!``
M``"@U0``*````+'5```0````VM4``"<```#KU0``)````!/6```S````.-8`
M`#(```!LU@``$0```)_6```.````L=8``!````#`U@``@0```-'6```*````
M4]<``%T```!>UP``7@```+S7```<````&]@``!,````XV```%@```$S8```<
M````8]@``"````"`V```$````*'8``!`````LM@``"8```#SV```%0```!K9
M```*````,-D```0````[V0``!@```$#9```(````1]D``!0```!0V0``#@``
M`&79```6````=-D```0```"+V0``#@```)#9```)````G]D```P```"IV0``
M!P```+;9```3````OMD```8```#2V0``!@```-G9```/````X-D```X```#P
MV0``"````/_9```(````"-H```T````1V@``#P```!_:```-````+]H```8`
M```]V@``#````$3:```+````4=H```P```!=V@``!P```&K:```-````<MH`
M``P```"`V@``$````(W:```)````GMH```0```"HV@``"````*W:```(````
MMMH```L```"_V@``"0```,O:```%````U=H```4```#;V@```0```"0!``#T
M`0```````/4```#F`````````'H"````````^`(```8"``#<````*```````
M``!*````@@```,@!``#"`0``RP(``/\!``!P````%`,``'$`````````@@(`
M``\#``!'`P``K@```*P```"R`@``9@```&L"``#)`@```````.H"````````
M``````,"``!+````D0````````"A`0``3@(```````#_````*0(```,````*
M`0``?`(``(H"`````P``4`(``/H!``"%`0``#@````````"V`0``A@,``(@`
M``",`0``L0````P!````````'P$``+T!````````7`$``-X!``""`P``````
M`````````````````)X#````````?0(``.$!``"``0``;@```+\!````````
M#````%X#```B````H@,``#@#```Y`@``PP(``'8```#@`0``/0(``#<"``#$
M`@``1P(``#H#``!C`P``D`,````````'`P````````````````````````,#
M````````?@(```````#;`@``]P$``&P#````````]@$````````P`@``U0``
M`!T"`````````@```-$!``"@`P``6P(``#T```!X`P``TP$```````#F`@``
M#P(``%,!``!R````\`(```````#'````%0(``.D`````````5`(``%,```#4
M`0``````````````````$P(`````````````]P```$,"``"``P``DP$```8!
M```Q````)P```!`!``#G`0``I`$``*,!``!<`@``$P```&\!```4`@``````
M`),"````````/@$```````"8`@``X@(``)X"``"T`0``7@```/("``!8`@``
M"`````````"K`0```````(D```"``@```0$``)<!```=````*@(``'4!``"G
M`@``0`(```````"L`0``#@,``'L!``!#`P``SP```!(!```!`@``!P(``/\"
M``"=`@``&P,``.8!``!M`P``AP(``"\"``"-`@``.0$````````.`@``O`(`
M```````@`P``!`$````````A`0```````-T!``#W`@``(0```$("````````
M``````````!%````Y````&4"```[````R@```$\```!/`0``K0$```````"&
M`@``W0(``)T`````````7@(``,T"``#>`@``10(``&`"``"4`@``T0(`````
M``#Q`0``D@,``&P"``!J````A0``````````````5@(``(0"````````$0$`
M`````````````````(@"```2`P``!0``````````````20$``,T````)````
M``````````!V`P``9`,``````````````````#`!````````3@```$0!```T
M`0``5`,``'X#```?`````````"X#`````````````*\"```Y````D0,`````
M``!X`0``J0$``*4"``"W`@``````````````````L````&,!``!``P``````
M`&L#`````````````,,````*`P``70,``*T"`````````````#0````5`0``
M/0,``'P!````````[P(`````````````$0```#X"```8````B@,``(,"```I
M````*@,``*`!``````````````````#C`@``+0$```````!U`@```````'@"
M``!R`0``HP(``#4"``!"`````````!T!````````Z0$``'H```#3`@``3P,`
M`)(`````````,P$``$$````H`P``)@````````!+`P``5P$``$P#``!$`P``
M)0,``&0````:`P``YP```%4!````````F@$``&@#`````````````,D!```'
M`0```````#X```".````A`$``'`"````````40$``)4!`````````````!H"
M``"L`@``1P$``)4````^`P``8@```!@"````````GP$``$@"``!<`P``6P,`
M`!`"```Q`P``[`(``&4!`````````````&,"``"P`@``IP```"P!``!$````
M`````'X!````````<0,`````````````N@(``'L"```:`0``^P```+$"``"+
M`0````````````!#````DP```-H!``"U`0```````,4"``!W`0``````````
M```S`P``B@```*H!``#N`@```````)L!``!?`0``]0$``"4!``"C````````
M``````!U````6@,``(@!``!Z`0````````````"<````O@$``!<!```2`@``
M(@(``/8````M````4`$``,P"``#4`@``T@(``&D"``">`0``N0``````````
M````;0(```````#8`0``"`$```````!&`0````````````!)````3@$`````
M````````8@,``#<````_`P```````)@!```````````````````+`0``@P$`
M``````!G`@``O`$``($!``"7`P``(`(``%@```!?````````````````````
M`````&\"``"2`@```````!@#```.`0``_````#\"```[`@``^0```$\"```<
M`0``$P$``&X#`````````````,X"```S`@``M@(``/,"``!*`P``JP(``)D`
M``#Y`0``>0```"D#````````B`,``/,````B`0``$P,``-H`````````8@$`
M`$@#````````'0,``&H#``![`P``60,````````A`P``#`(``#$"``!*`@``
MD`$``%T!``!F`P``?0$``$D"``".`@```````-(``````````````-P!``"^
M````;@$``.@"``#6``````````T!``!8`P``5@,``"P```"A`P```````(X#
M````````E`,``'H#``"+`@``=P(``"\!``"F`@``X@```,$!``#K`@``'`,`
M`&$```!G`P````````````!A`@``R@(``,$"``#H``````````````!R`@``
M/`$``%H"````````=@(```````!:`0```````%8`````````'@(```````!0
M````3`$``(,#```C`0``Z0(``-H"``"+````/0$``#4!``!\`P``X`(``&P!
M```V`@``@0,``/T!``#M`@``!P```!\#``!2`P``?````!0!``"D````J`$`
M`,`"``!'`````````+D"``#M`0```````,P!``"T``````````````#P````
M=P,``&L!``"S`0``50,``(\!``!"`P```````/(````K`@``)@,```````"E
M`0``EP(``&\#```N````,@$``.$"``````````(``-L```!!`0``-P$``%D"
M``!)`P``XP$``/T"`````````````/8"``#6`@``FP,```````!@`0``````
M`&4```"8`P````````````!U`P``90,````````A`@``8`,``"`!```M`@``
M!@,``#@````+`@``O0(``&8!``#.`0````````````#N`````@,``!$"``#"
M````%0,``(T```#0`@```````(<!``"Q`0``LP(``%0```",`@``/`(``+L!
M``".`0```````(4"``"&````0@$``.L````7`@``EP``````````````)@$`
M``````"I````&0```)(!```P``````````````#S`0``70```!\"```9`P``
MV0(``#P#``":`P``'@$```````#D`@```````#L#``"$````WP$``%\#``!T
M`@``!`(``-,```!A`P``G`(``%L`````````N`$``$L!``")`0``#P$`````
M``"_````&@````H"``"^`@```````/P!```X`0```````)X````R````D```
M`"<#``!8`0``F@``````````````R0```&D!```/````T``````````4````
M,@(``+L"````````$0,``%(```!H`@``P`````````![```````````````;
M`@``K0```.<"```M`P``H@$```````#U`@`````````````;`````````%`#
M``!+`@``4@(``)`"````````Y0$``%D!``!<``````````````!3`@``E@$`
M`($```"5`@``40```.X!``#7`@```````!P"```2````&P$``#,`````````
M*0$`````````````+`(``#L!```J`0```````',```!7`P``8P```","````
M````"P````````#%`0``.0,``-T```!H````?P```!8````O````.@(``-X`
M````````Q@(``)T#``#7`0``E@```%4````9`0``;0```(\`````````F0(`
M``@"``!K````40(```````!O``````````(!``!&`P``M`(``$H!``#(````
MT`$``($"``#-`0````````````!M`0```````/P"```Z````WP(``#(#``!>
M`0``*P````````#5`0``Q@$``)H"```5``````````````!G````SP$``*0#
M``!-````9`(``*("```-`P```````(0#````````<`,`````````````K@$`
M`",`````````B0,``&<!``"*`0```````.P!````````"`,`````````````
M`````#`#``!:``````````D#````````O`````````"A`````````$4!``#9
M``````````````"F``````````````"6`P``]````*$"``#P`0``5@$``.$`
M``!S`0````````````!1`P``Z@$``'\"```<````K@(``!@!``"1`@``<0(`
M`!<#```O`P``8````'8!``#Q````SP(``(T#``"H````T0```,`!``"K````
M3@,````````N`0``````````````````I0,``$$"``!]`P``C`,``,X```#[
M`@```````,8```#^````C````)L```"]````P0```/D"````````1`(``+@`
M````````;`````````!_`0``%@(``'D#````````QP$``#0#```H`@``.`(`
M`&D```#[`0``HP,``*<!``"%`P``!0(`````````````E`$``/X!``!,`@``
M)`````````"`````UP```((!````````/P$``)\#```K`0``2````.0!```L
M`P``50(``/H````!`P``E@(``&D#```6`0```````-P"``"9`0```````)4#
M``"H`@````````````#J`````````+4"``"U````V````.,````U`P``\@$`
M`&@!```0`P```````-0`````````9`$````````@``````$``"0#``"Y`0``
M-@```+8```"S````?0```.4"```B`P``30(``,("``"/`@``V0$``)\"``!4
M`0``"0$``.(!````````)P$```D"```6`P``)0```)\```"/`P``1@``````
M``!X`````````````````````````*D"``!R`P``)@(```````##`0``<`$`
M`'0```#(`@```````%D```"'````DP,``&$!``!=`@``30$``/0"```\````
M^````.````!B`@```````(8!````````*@``````````````H`````````"B
M``````````L#``!Q`0``9@(``)D#```````````````````%`P``````````
M``#%`````````)@`````````L`$``-(!``"_`@``=P````````"Z````_@(`
M`,0!``#X`0``,0$``"X"``"D`@```P$````````V`P```````.\`````````
M[0```*\!````````&0(``%(!``#,````6P$``*`"``"4`````````$4#``#*
M`0``00,``%\"``#L``````````````#5`@``L@$``'X```!&`@``*`$``"4"
M``"E`````````+<!```V`0````````````!7````5P(``"<"````````3```
M`+H!```Z`0``J@```',#``!#`0````````4!``!3`P``````````````````
M-P,``(,````D`@``RP```*H"``#8`@````````0````T`@``VP$``&H!``"+
M`P``2`$`````````````WP`````````$`P```````,0````"`@``D0$``$`!
M````````_0````````#K`0```````!X#``#E````NP```.\!````````````
M``````";`@``30,```8````-`@``?P,```P#``"-`0``:@(`````````````
M$````!X````C`P```````)P!`````````````,<"````````\0(`````````
M````AP,``'0#``#6`0``*P,``#\`````````<P(``/H"``!`````KP```&X"
M``"<`P```````!<```"W````-0```,L!``"X`@``L@```'D"````````````
M``H`````````>0$``(D"``"=`0``#0```.@!``!T`0``I@$````@)B,Q-3$[
M("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A
M=&5D.B`E<RX`)60@)7,@86YD("5S`"5D(&YO=&5S`"5S("T@3F]T:6-E`"5S
M($%D;6EN:7-T<F%T:6]N`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@
M4VEG;B!5<``E<R!A;')E861Y(&5X:7-T<RX`)7,@9FEL92!S=6-C97-S9G5L
M;'D@:6UP;W)T960`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@
M9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@
M0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"TM
M('-E;&5C="`M+0`Q(&YO=&4`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M
M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T
M+BXN`$%C8V5S<R!D96YI960@9&5L971I;F<@;F]T92X`06-C97-S(&1E;FEE
M9"!M;W9I;F<@=&AE(&YO=&4N`$%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@
M=&\@)7,N`$%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4Z("5S`$%C8V]U;G0@
M4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!(
M97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N
M97<@=7-E<CH`061D(&-A=&5G;W)Y`$%D9"!C;VQU;6X`061D(&YE=R!M96UB
M97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B
M;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+@!!9&1I;F<@02!.97<@3F]T90!!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T
M:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QL
M`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI
M<W-I;VYS`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;')E861Y(&5X:7-T
M<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R
M9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D
M<F5S<P!!;'1E<FYA=&4@=&5X=#H`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O
M>'D`06YS=V5R`$%N=&%R8W1I8V$`07!P;&EC871I;VX`07!P;&EC871I;VX@
M:7,@<F5A9'DN`$%P<')O=F4`07!R:6P`07)C:&EV92!&:6QE(%-I>F4`07)C
M:&EV92!.86UE`$%R9V5N=&EN80!!<FUE;FEA`$%R=6)A`$%S8V5N9&EN9P!!
M<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<S\`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R
M:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@
M4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL86)L92!#
M871E9V]R:65S.@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@
M17AC=7-E<P!"86-K('1O($YO=&5P860`0F%C:R!T;R!.;W1E<&%D($]P=&EO
M;G,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P
M87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A
M:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"96QA<G5S`$)E
M;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L
M;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L:79I80!";V]K;6%R:W,`0F]S
M;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)R87II;`!"=6QG87)I80!#35,`
M0U)#`$-35@!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;6)O9&EA
M`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@
M=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y("(E<R(N`$-A<&4@5F5R9&4`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A
M=&5G;W)Y`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<')O<&5R
M=&EE<P!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=')A;"!!
M9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0VAA9`!#
M:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N
M`$-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS
M+@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T
M:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&EL
M90!#:&EN80!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#
M:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!T:&4@;65M;R!C
M871E9V]R:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RX`0VAO;W-E
M('EO=7(@9&5F875L="!.;W1E<&%D+@!#:')I<W1M87,@27-L86YD`$-L96%R
M($9O<FT`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;VUB:6$`0V]L
M;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L=6UN('1I=&QE
M<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUO<F]S`$-O;7!A
M;GD`0V]M<&]S92!-97-S86=E("@E<RD`0V]M<'5T97)S`$-O;F1I=&EO;G,`
M0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H
M92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE
M9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT<R!O
M9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;W!Y`$-O<'D@<V5L96-T
M:6]N`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R
M=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N
M;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD
M(&YO="!U;FQI;FL@(B5S(BX`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3
M:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1R
M>0!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T
M960`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%1I
M;64`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#
M=70`0WEP<G5S`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&4`1&5?;&5T
M92!#;VQU;6X`1&5C96UB97(`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT
M:71Y`$1E9F%U;'0@3F]T97!A9`!$969A=6QT(%!E<FUI<W-I;VYS`$1E9F%U
M;'0@<&5R;6ES<VEO;G,`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A
M=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$96QE=&4`1&5L971E($=R;W5P`$1E
M;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L
M971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B
M+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R
M<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5N;6%R:P!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E<V-R:7!T:6]N.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&II8F]U=&D`1&\@;F]T(&1E
M;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$
M;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO860@
M)7,`1')U9W,`12U-86EL`$5C=6%D;W(`161I=`!%9&ET($=R;W5P`$5D:70@
M3F]T90!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI
M<W-I;VYS(&9O<B`E<P!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%;6%I;"!!
M9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6]T:6-O;G,`
M16UP='D@3F]T90!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5Q=6%T;W)I86P@1W5I;F5A
M`$5R:71R96$`17)R;W(`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T
M:&EO<&EA`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E
M<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I
M;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S
M.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!O<G0`17AP;W)T
M($YO=&5S`$9?=6QL(%1E>'0`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O
M<'D@=&\@(B5S(BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z
M`$9A>`!&96)R=6%R>0!&:6II`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL
M92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&;V]D`$9O<F=O="!Y;W5R('!A<W-W
M;W)D/P!&<F%N8V4`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$=A8F]N`$=A;6)I80!'
M97)M86YY`$=H86YA`$=I8G)A;'1A<@!';P!';V]G;&4@4V5A<F-H`$=R965C
M90!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U
M871E;6%L80!'=65R;G-E>0!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`
M2%1-3`!(86ET:0!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`
M2&5L<`!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I
M`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R`B)7,B`$AU;F=A<GD`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@
M=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EM86=E<P!);7!O<G0@3F]T97,L(%-T
M97`@)60`26UP;W)T+T5X<&]R="!.;W1E<P!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);F1I80!);F1O;F5S:6$`26YF;P!);G-E<G0@
M26UA9V4`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC
M96YS92!K97DN`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L
M86YD`$ES<F%E;`!)<W-U97(`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N
M`$IO<F1A;@!*=6QY`$IU;F4`2V%Z86MH<W1A;@!+96YY80!+97D@0W)E871I
M;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI
M<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M`$MO<F5A+"!297!U8FQI8R!O9@!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T
M`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA
M<W0@36]D:69I960`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&5S;W1H;P!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:7-T($AE
M;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&AU86YI
M80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]G
M(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2X`3&]G:6X@9F%I;&5D+@!,;W<`3'5X96UB;W5R9P!-30!-3U1$`$U3
M1P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8`36%D86=A<V-A<@!-86EL`$UA;&%W:0!-86QA>7-I80!-86QD:79E
M<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO
M=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I
M871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<F-H`$UA<F=I;@!-87)S
M:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I
M=&%N:6$`36%U<FET:75S`$UA>0!-87EO='1E`$UE;6\@5&5X=`!-96YU(&UO
M9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365X:6-O`$UI
M;64@5'EP90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D:69Y:6YG("5S
M`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA
M`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO=F4@
M1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-
M;W9E('5P`$UO>F%M8FEQ=64`37D@06-C;W5N=`!->2!.;W1E<P!->2!0;W)T
M86P`37EA;FUA<@!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N
M9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T=V]R:P!.979E<@!.97<@0V%L
M961O;FEA`$YE=R!#871E9V]R>0!.97<@3F]T90!.97<@6F5A;&%N9`!.97=S
M`$YE>'0`3F5X="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI
M=64`3F\@8VAA;F=E+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@)7,N`$YO(&9I;&4@=7!L;V%D960`3F\@;F]T97!A9',@
M87)E(&%V86EL86)L92!T;R!G=65S=',N`$YO(&YO=&5S`$YO(&YO=&5S(&UA
M=&-H('1H92!C=7)R96YT(&-R:71E<FEA+@!.;R!N;W1E<R!T;R!D:7-P;&%Y
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3$1!4"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+@!.;U]T90!.;VYE`$YO<F9O;&L@27-L86YD`$YO<G=A
M>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T
M92!#871E9V]R>0!.;W1E($1E=&%I;',`3F]T92!497AT`$YO=&4@7U1E>'0`
M3F]T92!N;W0@9F]U;F0N`$YO=&5?<&%D`$YO=&5P860G<R!N86UE.@!.;W1E
M<&%D<P!.;W1E<P!.;W1E<R!3=6UM87)Y`$YO=&EC90!.;W9E;6)E<@!.=6UB
M97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!/2P!/8W1O8F5R`$]F9FEC
M90!/;6%N`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3W!E;B!I
M;B!A(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A;FES
M871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO
M;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$
M:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI
M8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@
M4VAE;&P`4%](4"!3:&5L;`!086MI<W1A;@!086QA=0!086YA;6$`4&%P=6$@
M3F5W($=U:6YE80!087)A9W5A>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E
M8W0`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I
M;VX`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@
M9F]R`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`4&AO
M;F4`4&ET8V%I<FX`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&]L86YD`%!O
M<G1U9V%L`%!R979I97<`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E
M<V-R:7!T:6]N`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B
M;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R
M871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)3
M02!0=6)L:6,@2V5Y("@E9"!B:70I`%)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.@!2969R97-H($QI<W0`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M
M;W1E(%-E<G9E<G,`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V%T96=O
M<GD`4F5M;W9E(&-O;'5M;@!296UO=F4@<&%I<@!296UO=F4@=&AE`%)E;6]V
M92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297-E=`!297-E="!087-S=V]R9`!2
M97-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`
M4F5U;FEO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4F]L90!2;VUA;FEA
M`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!P<F]P
M97)T:65S`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4U%,(%-H96QL`%-32`!37U%,(%-H96QL`%-A:6YT($AE;&5N80!3
M86EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<P!386UO80!386X@36%R:6YO`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S
M(@!3879E("5S`%-A=F4@3W!T:6]N<P!396%R8V@`4V5A<F-H(%)E<W5L=',`
M4V5A<F-H(%-C;W!E`%-E87)C:"!?5&5X=`!396QE8W0@1FEL97,`4V5L96-T
M(&$@;F]T97!A9`!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E
M;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9F]R;6%T(&]F
M('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5L96-T960@0V%T96=O<FEE<SH`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!396YE9V%L`%-E<'1E;6)E<@!397)I86P@3G5M8F5R`%-E
M=`!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5Y8VAE;&QE
M<P!3:&]R="!3=6UM87)Y`%-H;W<`4VAO=R!A8W1I;VX@8G5T=&]N<S\`4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&YO=&5P
M860@;F%M93\`4VAO=R!N;W1E<R!F<F]M('1H97-E(&-A=&5G;W)I97,`4VAO
M=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VEE<G)A($QE;VYE`%-I9VX@
M=7`@:68@;F]T(')E9VES=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O
M<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI
M80!3;&]V96YI80!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;W)T(&)Y($-A
M=&5G;W)Y`%-O<G0@8GD@3F]T92!497AT`%-O=71H($%F<FEC80!3;W5T:"!%
M=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A
M8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`
M4W)I($QA;FMA`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=')E970@061D
M<F5S<P!3=6)J96-T`%-U8FUI=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E
M9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A
M=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL
M>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O
M;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U9&%N
M`%-U;G)I<V4O4W5N<V5T`%-U<FEN86UE`%-W87II;&%N9`!3=V5D96X`4W=I
M='IE<FQA;F0`4WER:6%N($%R86(@4F5P=6)L:6,`5&%I=V%N`%1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5X="!/;FQY
M`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO=&4@=V%S
M(&1E;&5T960N`%1H92!N;W1E<&%D("(E<R(@8V]U;&1N)W0@8F4@8W)E871E
M9#H@)7,`5&AE(&YO=&5P860@(B5S(B!H87,@8F5E;B!C<F5A=&5D+@!4:&4@
M;F]T97!A9"`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!N;W1E<&%D("(E
M<R(@:&%S(&)E96X@<V%V960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M
M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@
M)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E
M('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@
M)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=DYO=&4@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<P!4
M:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@=FEE=VEN9R!T:&ES(&YO=&5P860Z("5S`%1H97)E('=E
M<F4@;F\@;65M;W,@=&\@97AP;W)T+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&9I96QD(&ES(')E<75I
M<F5D+@!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@
M9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!M97-S86=E('=A
M<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@
M>6]U<B!O=VXN`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N
M9"!G>FEP(&9I;&5S+@!4:6UE`%1I;64@9F]R;6%T`%1I=&QE`%1O`%1O('-E
M;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A0
M0RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y
M`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4<FEN:61A9"!A;F0@5&]B
M86=O`%1R=64@;W(@9F%L<V4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/
M+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U=F%L=0!54DP`55),.@!59V%N9&$`
M56MR86EN90!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S`%5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YK;F]W;@!5;FYA;65D`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A
M=&4`57!L;V%D`%5R=6=U87D`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T
M:6]N`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S
M97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K
M:7-T86X`5F%C871I;VX`5F%N=6%T=0!696YE>G5E;&$`5F5R<VEO;@!6:65T
M($YA;0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A
M<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@
M52Y3+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E8@!7965K;'D`5V5L
M8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX
M.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/P!7:&EC:"!.;W1E<&%D('-H;W5L9"!T:&4@;F]T97,@8F4@861D960@=&\_
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=O<FL@061D<F5S<P!7;W)K(%!H
M;VYE`%E9`%E965D`665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U
M(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A9"`E
M<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="X`66]U(&UU<W0@<V5L96-T(&$@;F]T97!A9"!T;R!B92!D96QE
M=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@16UA
M:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I
M;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M861D:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED
M96YT:71Y.@!9;W5R(&1E9F%U;'0@;F]T97!A9#H`66]U<B!F=6QL(&YA;64Z
M`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!N;W1E<&%D
M<SH`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I
M<F4`6F%M8FEA`%II;6)A8G=E`%M0<F]B;&5M(%)E<&]R=%T`7T%D;6EN:7-T
M<F%T:6]N`%]"86-K('1O($YO=&5P860`7T-,20!?0V%T96=O<GD`7T1E;&5T
M90!?1&5L971E(%)O=P!?161I=`!?1FER<W0@3&EN90!?1W)O=7!S`%](96QP
M`%]);7!O<G0O17AP;W)T`%],:7-T($YO=&5S`%],;V<@:6X`7TQO9R!O=70`
M7TUO9&EF>2!,:6YK+BXN`%]->2!.;W1E<&%D<P!?3F5W($YO=&4`7T]P=&EO
M;G,`7U!E<FUI<W-I;VYS`%]0<FEN=`!?4F5M;W9E($QI;FLN+BX`7U-E87)C
M:`!?4V5T=7``7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!F:6QE`&YA
M;64`;F]T97!A9`!N;W1E<RYC<W8`=6YN86UE9`!V0V%R9`!V3F]T90!0<F]J
M96-T+4ED+59E<G-I;VXZ($UN96UO+6@S+3(N,`I297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@
M,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M
M,#$M,S$@,C$Z-#$K,#(P,`I,87-T+51R86YS;&%T;W(Z($UA=&5U<WH@2V%M
M:6YS:VD@/&UA=&EP;$!P;&0M;&EN=7@N;W)G/@I,86YG=6%G92U496%M.B!0
M;VQI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM
M,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`E<R`M(&=O=&]W
M>2!D;R!W>6MO;F%N:6$@8WEK;&EC>FYY8V@@;W!E<F%C:FD@>F%Z;F%C>F]N
M>6-H('!O;FF_96HN`"`H)7,@9&YI('1E;74I`"AK;'5C>B!D;W-TZG!U("5S
M*0`@*'<@8VFQ9W4@)7,@9&YI*0`@*&1Z:;8I`"`H:G5T<F\I`"`H=V-Z;W)A
M:BD`(B5S(B!N:64@:F5S="!P<F%W:62S;W=Y;2!W>6)O<F5M+@`B)7,B(&YI
M92!J97-T('-K;VYF:6=U<F]W86YY('<@<F5J97-T<GIE($AO<F1E+@!59&&S
M;R!S:>H@9&]D8>8@(B5S(B!D;R!G<G5P+@!59&&S;R!S:>H@9&]D8>8@(B5S
M(B!D;R!U<')A=VYI9?$N`"(E<R(@;FEE('IO<W1ALR!U='=O<GIO;GDZ("5S
M+@`E9"`E<R!I("5S`"5D(&YO=&%T96L`)7,@+2!5=V%G80!!9&UI;FES=')A
M8VIA("5S`"5S(&]D8VES:R!P86QC80`E<R!K0@`E<R`M(&]P97)A8VIE(&-Y
M:VQI8WIN92`M('!O='=I97)D>F5N:64`2V]N9FEG=7)A8VIA("5S`%)E:F5S
M=')A8VIA("5S`"5S(&IUOR!I<W1N:65J92X`)7,@<&QI:_-W('IA:6UP;W)T
M;W=A;GD@<&]M>;9L;FEE`"5S(&IE<W0@=WEM86=A;GD`)7,@;6EN=70`)7,@
M;FEE>FYA;&5Z:6]N>2X`)7,@9&\@)7,@>B`E<P!+<VFQOVMA(&%D<F5S;W=A
M("5S`$MA;&5N9&%R>B`E<P!.;W1A=&YI:R`E<P!,:7-T82!Z861A\2`E<P`E
M<SH@)7,`+2T@=WEB:65R>B`M+0`Q(&YO=&%T:V$`,3(M9V]D>FEN;GD@9F]R
M;6%T`#(T+6=O9'II;FYY(&9O<FUA=``R-"!G;V1Z+@`\4&]P<GIE9&YI`$YA
M<W2Q<&FS(&*SL60@:W)Y='EC>FYY`%!O=')Z96)N>2!J97-T(&ML=6-Z('!U
M8FQI8WIN>2!01U`@9&\@>F%S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!0;W1R
M>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4$=0(&1O('-P<F%W9'IE;FEA
M('!O9'!I<V%N96H@=VEA9&]M;[9C:2X`4&]T<GIE8FYE('.Q(&ML=6-Z('!U
M8FQI8WIN>2!01U`L(&ML=6-Z('!R>7=A=&YY(%!'4"!O<F%Z(&AA<[-O(&1O
M(&]D<WIY9G)O=V%N:6$@=VEA9&]M;[9C:2X`4&]T<GIE8FYE('.Q(&ML=6-Z
M('!U8FQI8WIN>2!01U`L(&ML=6-Z('!R>7=A=&YY(%!'4"!O<F%Z(&AA<[-O
M(&1O('!O9'!I<V%N:6$@=VEA9&]M;[9C:2X`4&]T<GIE8FYE('.Q(&ML=6-Z
M('!U8FQI8WIN>2!3+TU)344L(&ML=6-Z('!R>7=A=&YY(%,O34E-12!O<F%Z
M(&AA<[-O(&1O(&]D<WIY9G)O=V%N:6$@=VEA9&]M;[9C:2X`4&]T<GIE8FYE
M('.Q(&ML=6-Z('!U8FQI8WIN>2!3+TU)344L(&ML=6-Z('!R>7=A=&YY(%,O
M34E-12!O<F%Z(&AA<[-O(&1O('!O9'!I<V%N:6$@=VEA9&]M;[9C:2X`4&]T
M<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%--24U%(&1O('IA<WIY9G)O
M=V%N:6$@=VEA9&]M;[9C:2X`04TO4$T`3R!T>6T@961Y=&]R>F4`3R!P<F]G
M<F%M:64N+BX`3FEE(&UA<WH@9&]S=.IP=2P@86)Y('5S=6ZQYB!N;W1A=&OJ
M`$YI92!M87-Z(&1O<W3J<'4L(&%B>2!P<GIE;FEEMN8@;F]T871KZ@!.:64@
M;6%S>B!D;W-TZG!U+"!A8GD@>F%P:7-AYB!N;W1A=&OJ(&1O("5S+@!.:64@
M;6%S>B!D;W-TZG!U+"!A8GD@>F%P:7-AYB!N;W1A=&OJ.B`E<P!(87.S;R!D
M;R!K;VYT80!+;VYT;R!Z86)L;VMO=V%N92X`2V]N=&$`1&]D86H`1&]D86H@
M='5T86HZ`$1O9&%J(&YO=[$@9W)U<.H`1&]D86H@;F]W92!U<')A=VYI96YI
M90!$;V1A:B!N;W=E9V\@=;]Y=&MO=VYI:V$Z`$1O9&%J(&MA=&5G;W)IZ@!$
M;V1A:B!K;VQU;6[J`$1O9&%J(&YO=WEC:"!C>K-O;FOS=P!$;V1A:B!P87+J
M`$1O9&%J(&UE;G4@)7,@9&\@<&%S:V$@36]Z:6QL:0!$;V1A:B!D;R!K<VFQ
MOVMI(&%D<F5S;W=E:CH`1&]D86H@9&\@;6]J96H@:W-IL7IK:2!A9')E<V]W
M96H`1&]D86H@=;]Y=&MO=VYI:V$`1&]D86YO("(E<R(@9&\@<WES=&5M=2X@
M36^_97-Z('-IZB!Z86QO9V]W8>8N`$1O9&%J(&YO=[$@;F]T871KZ@!$;V1A
M=V%N:64@=;]Y=&MO=VYI:_-W(&IE<W0@=WFS86-Z;VYE+@!!9')E<P!+<VFQ
MOVMA(&%D<F5S;W=A`$%D;6EN:7-T<F%C:F$`4F5K;&%M>0!!9F=A;FES=&%N
M`$%L8F%N:6$`06QG:65R:6$`06QI87,`5W-Z>7-T:V\`5W-Z>7-C>2!U=VEE
M<GIY=&5L;FEE;FD@=;]Y=&MO=VYI8WD`5W-Z>7-T:VEE(&=R=7!Y`%=S>GES
M=&MI92!U<')A=VYI96YI80!0;WIW\VP@;F$@=VEE;&4@861R97/S=P!*=;\@
M:7-T;FEE:F4`06QT97)N871Y=VYY(&QO9VEN($E-4U``06QT97)N871Y=VYY
M(&AA<[-O($E-4U``06QT97)N871Y=VYA(&YA>G=A('6_>71K;W=N:6MA($E-
M4U``06QT97)N871Y=VYY(&%D<F5S(&5M86EL`$%L=&5R;F%T>7=N>2!T96MS
M=#H`6F]S=&&S82!P;V1A;F$@;FEE<')A=VEDLV]W82!W87)T;[;F+@!!;F1O
M<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;6]W92!0<F]X>0!/9'!O=VEE9+P`
M06YT87)K='ED80!!<&QI:V%C:F$`07!L:6MA8VIA(&=O=&]W80!:871W:65R
M9+P`2W=I96-I9?$`5VEE;&MOMN8@87)C:&EW=6T`3F%Z=V$@87)C:&EW=6T`
M07)G96YT>6YA`$%R;65N:6$`07)U8F$`4F]S;K%C;P!0;W!R;[8@;R!P;W1W
M:65R9'IE;FEE('!R>F5D('=Y:V]N86YI96T@;W!E<F%C:FD@8WEK;&EC>FYY
M8V@_`$%T<GEB=71Y`%-I97)P:67Q`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?
M8WER=7,Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA
M(&EM87`N`$%U=&A?8WER=7,Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@
M<F]Z<WIE<GIE;FEA(&EM87`N`$%U=&A?9G1P.B!.:64@>FYA;&5Z:6]N;R!W
M>6UA9V%N96=O(')O>G-Z97)Z96YI82!&5%`N(%-K;VUP:6QU:B!02%`@>B!P
M87)A;65T<F5M("TM96YA8FQE("X`075T:%]I;6%P.B!.:64@>FYA;&5Z:6]N
M;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!)34%0+@!!=71H7VMR8C4Z($YI
M92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&MR8C4N`$%U
M=&A?;&1A<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N
M:6$@3$1!4"X`075T:%]L9&%P.B!.:64@=61ALV\@<VGJ('5S=6ZQYB!UOWET
M:V]W;FEK82`E<P!!=71H7VQD87`Z($YI92!U9&&S;R!S:>H@=6%K='5A;&YI
MYB!UOWET:V]W;FEK82`E<P!!=71H7VUC86PZ($YI92!Z;F%L97II;VYO('=Y
M;6%G86YE9V\@<F]Z<WIE<GIE;FEA($U#04PN`$%U=&A?<VUB875T:#H@3FEE
M('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@<VUB875T:"X`
M57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ`%5W:65R>GET96QN
M:65N:64@;FEE('!O=VEO9+-O('-IZBX@)7,`57=I97)Z>71E;&YI96YI92!O
M9')Z=6-O;F4@<')Z97H@<V5R=V5R(%)!1$E54RX`57=I97)Z>71E;&YI96YI
M92!D;R!S97)W97)A($944"!N:64@<&]W:6]DLV\@<VGJ+@!$;W-TZG!N92!K
M871E9V]R:64Z`$1O<W3J<&YE('!O;&$Z`$%Z97)B96IDOV%N`%=Y;?-W:VD@
M0D]&2`!7<O/F(&1O($YO=&%T;FEK80!7<O/F(&1O(&]P8VII($YO=&%T;FEK
M80!4LV\`2V]L;W(@=+-A`%JS92!H87.S;R!+97)B97)O<V$N`%JS82!N87IW
M82!UOWET:V]W;FEK82!+97)B97)O<V$`5WES<'D@0F%H86UA`$)A:')A:FX`
M0F&S='EC:VD@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-Z`$)I8;-O<G6V`$)E
M;&=I80!"96QI>F4`0F5N:6X`0F5R;75D>0!":'5T86X`1&%T82!U<F]D>F5N
M:6$`57-T87=I96YI82!B;&]K=0!4>7`@8FQO:W4`0F]L:7=I80!:86NS861K
M:0!";[9N:6$@:2!(97)C96=O=VEN80!/8F$`0G)A>GEL:6$`0G6S9V%R:6$`
M0TU3`$-20P!#4U8`5[-AMF-I=V^V8VD@:V]M\W)K:2XN+B`H7V,I`$MA;&5N
M9&%R>@!+86UB;V2_80!+86UE<G5N`$YI92!U9&&S;R!S:>H@>G)E<V5T;W=A
MYB!H87.S82!A=71O;6%T>6-Z;FEE+"!S:V]N=&%K='5J('-IZB!Z(&%D;6EN
M:7-T<F%T;W)E;2X`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E
M<F5M($E-05`Z("5S`$MA;F%D80!!;G5L=6H`06YU;'5J(')A<&]R="!O('!R
M;V)L96UI90!.:64@;6^_;F$@<VMA<V]W8>8@<&QI:W4@(B5S(@!.:64@=61A
MLV\@<VGJ('IN86QEO.8@:V%T86QO9W4@='EM8WIA<V]W96=O+@!.:64@;6^_
M;F$@<VMA<V]W8>8@:V%T86QO9W4@(B5S(@!7>7-P>2!::65L;VYE9V\@4')Z
M>6RQ9&MA`$MA=&5G;W)I92!I(&]Z;F%C>F5N:6$`2V%T96=O<FEA`%1E;"X@
M:V]M+@!7LV&V8VEW;[9C:2!K;VWS<FMI`%>S8;9C:7=OMF-I(&MO;?-R:VD`
M5&5L+B!K;VTN`$-E;'1Y8VMI("A)4T\M.#@U.2TQ-"D`4F5P=6)L:6MA(*9R
M;V1K;W=E:B!!9G)Y:VD`IG)O9&MO=V]E=7)O<&5J<VMI("A)4T\M.#@U.2TR
M*0!3>F-Z96?SLWD@8V5R='EF:6MA='4`5[-AMF-I8VEE;"!C97)T>69I:V%T
M=0!#>F%D`%IM:6%N80!:;6EE\2!I;6GJ+"!N87IW:7-K;R!I(&%D<F5S+"!K
M=/-R>2!I;FYI('=I9'JQ('<@5'=O:6-H(&QI<W1A8V@@96UA:6PN`%IM:67Q
M('-O<G1O=V%N:64@='=O:6-H(&YO=&%T96L@;W)A>B!P87)A;65T<GD@=WFV
M=VEE=&QA;FEA`%-P<F%W9+P@;&EN:RXN+@!:87IN86-Z('!O>GEC:NH@9&QA
M(&MT\W)E:B!C:&-E<WH@=WEK;VYAYB!O<&5R86-JZBX`0VAI;&4`0VAI;GD`
M4&]D86H@:&%SLV\`4&]D86H@;F%Z=^H@=;]Y=&MO=VYI:V$`5WEB:65R>B!S
M<&]S\V(@=WFV=VEE=&QA;FEA(&1A=#H`5WEB:65R>B!Z(&QI<W1Y(&MA=&5G
M;W)IZB!N;W1A=&MI('<@<VMR\V-O;GEM('!O9&=LL61Z:64N`%=Y8FEE<GH@
M9&]M>;9L;GD@;F]T871N:6L`5WES<&$@0F^_96=O($YA<F]D>F5N:6$`5WEC
M>GFVYB!F;W)M=6QA<GH`2VQI:VYI:B!B>2!K;VYT>6YU;W=AY@!:86UK;FEJ
M(&]K;F\`5WES<'D@2V]K;W-O=V4@*$ME96QI;F=A*0!38VAO=V%J('!A<V5K
M`$MO;'5M8FEA`$MO;&]R`%=Y8FEE<GH@:V]L;W(`5WEB\W(@:V]L;W)U`%1Y
M='6S>2!K;VQU;6X`2V]M96YD80!0;W>S;VMA`$MO;65N=&%R>@!+;VUO<GD`
M1FER;6$`4W1W\W)Z('=I861O;6^VYB`H)7,I`$MO;7!U=&5R>0!787)U;FMI
M`%-K;VYF:6=U<G5J("5S`%!O='=I97)DO"!H87.S;P!+;VYG;P!$96UO:W)A
M='EC>FYA(%)E<'5B;&EK82!+;VYG;P!0;[.Q8WIE;FEE(&YI92!P;W=I;V2S
M;R!S:>HN`%!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-IZCH@`$]D;?-W:6]N
M;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E<G=E<F$N`$]D;?-W:6]N
M;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E<G=E<F$N(%!O=_-D.B`E
M<R`H)7,I`$*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!&
M5%`N`$MO;G1A:W1Y('IO<W1ALWD@<&]M>;9L;FEE(&1O9&%N92!D;R!4=V]J
M96H@:W-IL;]K:2!A9')E<V]W96HN`%IA=V%R=&^VYB`B)7,B`$MO;GEN=75J
M`%=Y<W!Y($-O;VMA`%-K;W!I=6H`4VMO<&EU:B!W>6+S<@!.:64@=61ALV\@
M<VGJ('IA<WIY9G)O=V'F("A01U`I('=I861O;6^V8VDN`$YI92!U9&&S;R!S
M:>H@<&]D<&ES8>8@*%!'4"D@=VEA9&]M;[9C:2X`3FEE('5D8;-O('-IZB!Z
M87-Z>69R;W=AYB`H4R]-24U%*2!W:6%D;VUOMF-I+@!.:64@=61ALV\@<VGJ
M('!O9'!I<V'F("A3+TU)344I('=I861O;6^V8VDN`$*SL60@<&]D8WIA<R"S
ML6-Z96YI82!S:>H@>B!S97)W97)E;2!,1$%0+@!"L[%D('!O9&-Z87,@L[%C
M>F5N:6$@<VGJ('H@<V5R=V5R96T@(B5S(B!P;W!R>F5Z($944#H@)7,`3FEE
M('5D8;-O('-IZB!O9'-Z>69R;W=AYB!D86YY8V@@4$=0+@!.:64@=61ALV\@
M<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!3+TU)344N`$YI92!U9&&S;R!S:>H@
M=7-T86QIYB!A9')E<W4@92UM86EL(&]D8FEO<F-Y+@!.:64@=61ALV\@<VGJ
M('5Z>7-K8>8@>B!S97)W97)A(&ML=6-Z82!P8G5L:6-Z;F5G;RX`3FEE('5D
M8;-O('-IZB!O='=O<GIYYB`B)7,B(&1O('IA<&ES=2X`3FEE(&UOOVYA(&]T
M=V]R>GGF("5S+@!.:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA
M;F-E7U1A<VL@)7,`3FEE(&UOOVYA(&]T=V]R>GGF(&MA=&%L;V=U("(E<R(`
M3FEE('5D8;-O('-IZB!S:V%S;W=AYB!P;&EK=2`B)7,B+@!.:64@=61ALV\@
M<VGJ('IN86QEO.8@<&%S:V$@36]Z:6QL:2X@57!E=VYI:B!S:>HL(+]E(&IE
M<W0@;VX@;W1W87)T>2X`2W)A:@!4=_-R>@!3='?S<GH@;&EN:P!3='?S<GH@
M;F]WL0!5='=O<GIO;F\`3G5M97(@:V%R='D@:W)E9'ET;W=E:@!#:&]R=V%C
M:F$`2W5B80!/8F5C;GD@8WIA<P!3<&5R<V]N86QI>G5J('IA9&%N:6$@=7)U
M8VAA;6EA;F4@<')Z>2!L;V=O=V%N:74@9&\@)7,N`%=Y=&YI:@!#>7!R`%)E
M<'5B;&EK82!#>F5C:`!$1`!#;V1Z:65N;FEE`$1A=&$`7U5S=?$@:V]L=6UN
MZ@!'<G5D>FEE\0!$;VUYMFQN>2!K;VQO<@!$;VUYMFQN82!T;[]S86UOMN8`
M1&]M>;9L;GD@;F]T871N:6L`1&]M>;9L;F4@=7!R87=N:65N:6$`1&]M>;9L
M;F4@=7!R87=N:65N:6$`1&]M>;9L;F4@:W)Y=&5R:75M('-O<G1O=V%N:6$Z
M`$1O;7FV;&YY('-P;W/S8B!S;W)T;W=A;FEA.@!5<W7Q`%5S=?$@1W)U<.H`
M57-U\2!U<')A=VYI96YI80!5<W7Q(&D@=WEC>GFVYB!W:6%D;VUOMF-I`%5S
M=?$@:V]M\W)KZ@!5<W7Q(&MO;'5M;NH`4VMA<W5J('5P<F%W;FEE;FEA(&1L
M82`B)7,B`%-K87-O=V'F('5P<F%W;FEE;FEA(&1L82`B)7,B(&D@=W-Z>7-T
M:VEE('!O9"UU<')A=VYI96YI83\`57-U\2!W:65R<WH`4VMA<W5J('=Y8G)A
M;K$@=&^_<V%M;[;F`%5S=?$@86MT=6%L;K$@:V]L=6UNZ@!5<W7Q(&%K='5A
M;&YY('=I97)S>@!3:V%S;W=AYB!T;R!U<')A=VYI96YI92!I('=S>GES=&MI
M92!P;V0M=7!R87=N:65N:6$_`$1A;FEA`$UA;&5JL6-O`$]P:7-Z('!R;V)L
M96T`3W!I<P!3>F-Z96?SLWD@>F]S=&&S>2!Z86QO9V]W86YE(&1L82!A9&UI
M;FES=')A=&]R82X`2V%T86QO9P!7>;9W:65T;"!C>F%S('<@9F]R;6%C:64@
M,C0M9V]D>FEN;GEM/P!/<&-J92!W>;9W:65T;&%N:6$`1+]I8G5T:0!.:64@
M:V%S=6H`0G)A:R!B97IP;[9R961N:65G;R!D;W-TZG!U(&1O(&UA:6YT96YA
M;F-E+G!H<`!$;VUI;FEK82`H5W-P\VQN;W1A($1O;6EN:6MI*0!$;VUI;FEK
M86YA("A297!U8FQI:V$@1&]M:6YI:V'Q<VMA*0"F8VFQ9VYI:@"F8VFQ9VYI
M:B`E<P!.87)K;W1Y:VD`12UM86EL`$5K=V%D;W(`161Y='5J`%5S=?$@1W)U
M<.H`161Y='5J(&YO=&OJ`%IM:67Q('5P<F%W;FEE;FEE`%IM:67Q('5P<F%W
M;FEE;FEA`%IM:67Q('5P<F%W;FEE;FEA(&1L82`E<P!:;6EE\2!U<W1A=VEE
M;FEA(&1L83H`6FUI9?$@=7!R87=N:65N:6$@9&QA("5S`$5G:7!T`%-A;'=A
M9&]R`$5M86EL`$%D<F5S(&5M86EL`$%D<F5S>2!E;6%I;"!M=7-ZL2!D;R!S
M:65B:64@<&%S;W=AYBX`16UO=&EK;VYY`%!U<W1A(&YO=&MA`%!U<W1A('=I
M861O;6^VYBX`0G)A:R!R97IU;'1A=/-W+@!7L[%C>GGF(&UE;G4@:V]N=&5K
M<W1O=V4@<&]D('!R87=Y;2!P<GIY8VES:VEE;2!M>7-Z>3\`1W=I;F5A(%+S
M=VYI:V]W80!%<GET<F5A`$*SL60`0K.Q9"!P<GIY('IA<&ES:64@(B5S(BX`
M17-T;VYI80!%=&EO<&EA`$5U<F]P80!#;R!K8;]D92`Q-2!M:6YU=`!#;R!K
M8;]D92`R(&UI;G5T>0!#;R!K8;]D92`S,"!S96MU;F0`0V\@:V&_9&4@-2!M
M:6YU=`!#;R!K8;]D92!Z86QO9V]W86YI90!#;R!K8;]D92!P\[,@9V]D>FEN
M>0!#;R!K8;]DL2!M:6YU=.H`4')Z>6NS861O=V4@=V%R=&^V8VDZ`%=Y:V]N
M86H`4F]Z=VGQ`%)O>G=I\2!P87-E:P!%:W-P;W)T`$5K<W!O<G0@;F]T871E
M:P!#8;-Y('1E:W-T("A?=2D`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z
M('-E<G=E<F5M($Q$05`N`$*SL60@<&]D8WIA<R!K;W!I;W=A;FEA('H@(B5S
M(BX`0K.Q9"!P;V1C>F%S(&MO<&EO=V%N:6$@9&\@(B5S(BX`0K.Q9"!P;V1C
M>F%S('!R>F5N;W-Z96YI82!D;R`B)7,B+@!&86QK;&%N9'D@*$UA;'=I;GDI
M`%=Y<W!Y($]W8WIE`$*SL60@:W)Y='EC>FYY.B``1F%K<P!,=71Y`$9I9+]I
M`$UE;F5DOV5R('!L:6OS=P!.87IW82!P;&EK=0!7>6+S<B!P;&EK=0!79W)Y
M=V%N:64@<&QI:W4`5V=R>7=A;FEE('!L:6OS=R!N:64@:F5S="!O8G.S=6=I
M=V%N92X`1FEL=')Y`$9I;FQA;F1I80!*961Z96YI90!:87!O;6YI8;-EMB!H
M87.S83\`1G)A;F-J80!'=6IA;F$@1G)A;F-U<VMA`%!O;&EN97IJ82!&<F%N
M8W5S:V$`1G)A;F-U<VMI92!497)Y=&]R:6$@4&^S=61N:6]W92!I($%N=&%R
M:W1Y8WIN90!/9`!'86)O;@!'86UB:6$`3FEE;6-Y`$=H86YA`$=I8G)A;'1A
M<@!)9+P`5WES>G5K:7=A<FMA($=O;V=L90!'<F5C:F$`1W)E;FQA;F1I80!'
M<F5N861A`$=R=7!Y(&1Y<VMU<WEJ;F4`1W=A9&5L=7!A`$=U86T`1W=A=&5M
M86QA`$=U97)N<V5Y`$=W:6YE80!'=VEN96$@0FES<V%U`$=U:F%N80!(5$U,
M`$AA:71I`%=Y<W!Y($AE87)D(&D@36-$;VYA;&1A`%!O;6]C`%=Y<V]K:0!?
M4W1A<G0`5V%T>6MA;B`H4W1O;&EC82!!<&]S=&]L<VMA*0!0;V-ZL71E:P!!
M9')E<R!D;VUO=WD`5&5L+B!D;VTN`$AO;F1U<F%S`$AO;F=+;VYG`$AO<F1E
M`$AO<F1E+TMO;&%B.B!59&&S;R!S:>H@=7-U;K'F("5S("(E<R(`5^IG<GD`
M27-L86YD:6$`5'EL:V\@:6MO;GD`26MO;GD@>B!T96MS=&5M`$YA>G=A('1O
MOW-A;6^V8VDZ`$=R869I:V$`26UP;W)T;W=A;FEE(&YO=&%T96LL(&MR;VL@
M)60`26UO<G0O16MS<&]R="!N;W1A=&5K`$EM<&]R=&]W86YE('!O;&4Z("5S
M`$EM<&]R=&]W86YE('!O;&$Z`$EN9&EE`$EN9&]N97IJ80!);F9O`%=K;&5J
M(&]B<F%Z96L`5WESLV%N92!N:65P<F%W:62S;W=E(&1A;F4N`$YI97!R87=I
M9+-O=WD@861R97,@9&]C96QO=WDN`$YI97!R87=I9+-O=WD@9F]R;6%T('!L
M:6MU`$YI97!R87=I9+-O=WD@:VQU8WH@;&EC96YC:FDN`$ER86X`27)A:P!)
M<FQA;F1I80!)>G)A96P`5WED87=C80!7LV]C:'D`2F%M86IK80!3='EC>F7Q
M`$IA<&]N:6$`2F]R9&%N`$QI<&EE8P!#>F5R=VEE8P!+87IA8VAS=&%N`$ME
M;FEA`%1W;W)Z96YI92!K;'5C>F$`3V1C:7-K(&ML=6-Z80!$LW5G;[;F(&ML
M=6-Z80!4>7`@:VQU8WIA`$ML=6-Z(&IUOR!I<W1N:65J92!N82!P=6)L:6-Z
M;GEM('-E<G=E<GIE(&ML=6-Z>2X`1'II96-I`$MI<FEB871I`$MO<F5A\7-K
M82!297!U8FQI:V$@3'5D;W=O+41E;6]K<F%T>6-Z;F$`4F5P=6)L:6MA($MO
M<F5I`$MU=V5J=`!+:7)G:7-T86X`5WEG;+%D("A?>2D`2NIZ>6L`3&%O<P!/
M<W1A=&YI82!M;V1Y9FEK86-J80!/<W1A=&YI92!L;V=O=V%N:64Z("5S`$]S
M=&%T;FEE(&QO9V]W86YI93H@)7,@>B`E<P!/<W1A=&YI92!L;V=O=V%N:64Z
M(&YI9V1Y`*-O='=A`$QE<V]T:&\`3&EB97)I80!,:6)I80!,:65C:'1E;G-T
M96EN`%=YMG=I971L('1E;6%T>2!P;VUO8WD`3&ES=&]W86YI92!UOWET:V]W
M;FEK\W<@:F5S="!W>;.Q8WIO;F4N`$QI='=A`*-A9&]W86YI92XN+@!#>F%S
M(&QO:V%L;GDZ(`!5<W1A=VEE;FEA(&QO:V%L;F4@:2!C>F%S`%IA;&]G=6H`
M5WEL;V=U:@!:861A;FEA('!R>GD@;&]G;W=A;FEU`$QO9V]W86YI92!N:64@
M<&]W:6]DLV\@<VGJ+"!P;VYI97=AOR!P;V1ALV6V(&YI97!R87=I9+-O=V4@
M:&%SLV\@;'5B(&YA>G?J('6_>71K;W=N:6MA+@!,;V=O=V%N:64@;FEE('!O
M=VEO9+-O('-IZBX`3FES:VD`3'5K<V5M8G5R9P!-30!-3U1$`$U31P!-86MA
M=0!-86-E9&]N:6$`36%D86=A<VMA<@!0;V-Z=&$`36%L87=I`$UA;&5Z:F$`
M36%L961I=WD`36%L:0!-86QT80!:87)ZL61Z86H@;&ES=+$@:V%T96=O<FEI
M+"!K=/-R>6UI(&+J9'II97-Z(&]Z;F%C>F&S('!O>GEC:F4L(&D@:V]L;W)A
M;6D@>B!N:6UI('IW:;%Z86YY;6DN`$UA<GIE8P!-87)G:6YE<P!7>7-P>2!-
M87)S:&%L;&$`36%R='EN:6MA`%!A<W5JL6-E('!O;&$`36%U<F5T86YI80!-
M875R:71I=7,`36%J`$UA:F]T=&$`5&5K<W0@;F]T871K:0!4<GEB(&UE;G4Z
M`%!OL[%C>B!K;VWS<FMI`%=I861O;6^VY@!";&]K(")-971A<B(@;FEE(&IE
M<W0@9&]S=.IP;GDN`$)L;VL@(DUE=&%R(B!N:64@:F5S="!D;W-TZG!N>2X@
M4WIC>F5G\[-Y('ID87)Z96YI82!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D
M;6EN:7-T<F%T;W)A+@!-96MS>6L`5'EP($UI;64`3W-T871N:6$@;6]D>69I
M:V%C:F$`6FUI9?$@;&EN:P!%9'EC:F$@)7,`36^S9&%W:6$`4F5P=6)L:6MA
M($UOLV1A=VEI`$UO;F%K;P!-;VYG;VQI80!#;R!M:65S:;%C`$UO;G1S97)R
M870`1F%Z>2!K<VGJOWEC80!-87)O:V\`4')Z97-U\2!W(&3SLP!0<GIE<W7Q
M('<@;&5W;P!0<GIE<W7Q('<@<')A=V\`4')Z97-U\2!W(&?S<NH`4')Z96YI
M9;8@=R!D\[,`4')Z97-U\2!W(&?S<NH`36]Z86UB:6L`2V]N=&\`36]J92!N
M;W1A=&MI`$WS:B!P;W)T86P`0FER;6$`3F%Z=VES:V\`3F%M:6)I80!.875R
M=0!.97!A;`!(;VQA;F1I80!!;G1Y;&4@2&]L96YD97)S:VEE`%-I9>8`3FEG
M9'D`3F]W82!+86QE9&]N:6$`3F]W82!K871E9V]R:6$`3F]W82!N;W1A=&MA
M`$YO=V$@6F5L86YD:6$`5VEA9&]M;[9C:0!.87-TZG!N90!.87-TZG!N92!O
M<&-J90!.:6MA<F%G=6$`3FEG97(`3FEG97)I80!.:75E`$)E>B!Z;6EA;BX`
M0G)A:R!K;VYF:6=U<F%C:FD@9&QA("5S+@!.:64@=V=R86YO('!L:6MU`$YI
M961O<W3J<&YE(&YO=&%T;FEK:2!D;&$@9V^V8VDN`$)R86L@;F]T871E:P"O
M861N92!N;W1A=&MI(&YI92!S<&6S;FEA:K$@;V)E8VYE9V\@:W)Y=&5R:75M
M`$)R86L@;F]T871E:R!D;R!W>;9W:65T;&5N:6$`3FEE('!O9&%N;R!H87.S
M82!D;&$@=7=I97)Z>71E;&YI96YI82!(5%10+@!.:64@<&]D86YO(&AA<[-A
M(&1L82!U=VEE<GIY=&5L;FEE;FEA($E-05`N`$YI92!P;V1A;F\@:&%SLV$@
M9&QA('5W:65R>GET96QN:65N:6$@2V5R8F5R;W,N`$YI92!P;V1A;F\@:&%S
MLV$@9&QA('5W:65R>GET96QN:65N:6$@3$1!4"X`3FEE('!O9&%N;R!H87.S
M82!D;&$@=7=I97)Z>71E;&YI96YI82!,3T=)3BX`3FEE('!O9&%N;R!H87.S
M82!D;&$@=7=I97)Z>71E;&YI96YI82!005-35T0N`$YI92!P;V1A;F\@:&%S
MLV$@9&QA('5W:65R>GET96QN:65N:6$@4TU"+@!.;U]T871K80"O861N80!.
M;W)F;VQK`$YO<G=E9VEA`$YI92!Z86EM<&QE;65N=&]W86YO+@!.:65U<W1A
M=VEO;F4`3FEE;V)SLW5G:7=A;F4`2V%T96=O<FEA(&YO=&%T:VD`4WIC>F5G
M\[-Y(&YO=&%T:VD`5&5K<W0@;F]T871K:0!?5&5K<W0@;F]T871K:0!.;W1A
M=&MA(&YI97IN86QE>FEO;F$N`$YO=&%T;FEK("A?<"D`3F%Z=V$@;F]T871N
M:6MA.@!.;W1A=&YI:VD`57=A9VD`4VMR\V-O;F4@;F]T871K:0!5=V%G80!,
M:7-T;W!A9`!,:6-Z8F$@:V]L=6UN`$QI8WIB82!W:65R<WIY`$]+`%!AO&1Z
M:65R;FEK`$)I=7)O`$]M86X`5'?S:B!J961E;B!A9')E<R!E+6UA:6P@:F5S
M="!D;WIW;VQO;GDN`$]T=_-R>B!W(&YO=WEM(&]K;FEE`$]P8VIE`$]P8VIE
M("5S`$]R9V%N:7IA8VIA`$IE9&YO<W1K82!O<F=A;FEZ86-Y:FYA`$]R9V%N
M:7IA=&]R`$EN;F4`26YN92!I;F9O<FUA8VIE`$EN;F4@;W!C:F4`26YN92!U
M<')A=VYI96YI80!5=VEE<GIY=&5L;FEE;FEE(%!!32!N:64@:F5S="!D;W-T
MZG!N92X`0WEF<F]W>2!P;V1P:7,@4$=0`%=I861O;6^VYB!Z87-Z>69R;W=A
M;F$@4$=0`$ML=6-Z('!U8FQI8WIN>2!01U``5VEA9&]M;[;F('IA<WIY9G)O
M=V%N82]P;V1P:7-A;F$@:VQU8WIE;2!01U``2V]D(%!(4`!0;W>S;VMA(%!(
M4`!0;W>S;VMA(%!?2%``4&%K:7-T86X`4&%L874`4&%N86UA`%!A<'5A+4YO
M=V$@1W=I;F5A`%!A<F%G=V%J`$AA<[-O`$AA<[-O(&YI97!R87=I9+-O=V4`
M2&%SLV\@>B!P;W1W:65R9'IE;FEE;0!(87.S;SH`2&%SLV\Z(`!(87.S;R!M
M=7-I('!A<V]W8>8N`%=K;&5J`%=K;&5J('IE('-C:&]W:V$`5WEK;VYA:B!C
M>6ML:6-Z;F4@;W!E<F%C:F4`5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4@
M<&]D8WIA<R!L;V=O=V%N:6$_`%5P<F%W;FEE;FEE`$)R86L@9&]S=.IP=0!5
M<')A=VYI96YI80!5<')A=VYI96YI82!D;&$`26YF;W)M86-J92!O<V]B:7-T
M90!097)U`$9I;&EP:6YY`%1E;&5F;VX`4&ET8V%I<FX`3F$@<&5W;F\@=7-U
M;K'F('1E;B!W>6)R86YY(&5L96UE;G0Z`$YA('!E=VYO('5S=6ZQYB!W>6)R
M86YY(&5L96UE;G0Z`%!R;W-ZZB!P;V1AYB!P;W!R87=N>2!A9')E<R!)4"X`
M4')O<WKJ('!O9&'F('!O<')A=VYY(&-Z87,N`%!R;W-ZZB!O<&ES8>8@<')O
M8FQE;2X`4')O<WKJ('!O9&'F(&YA>G?J('6_>71K;W=N:6MA(&D@:&%SLV\`
M4&]L<VMA`%!O<G1U9V%L:6$`4&]D9VRQ9`!+;'5C>B!P<GEW871N>0!0<F]B
M;&5M`$]P:7,@<')O8FQE;74`2VQU8WH@<'5B;&EC>FYY`$%L9V]R>71M(&ML
M=6-Z82!P=6)L:6-Z;F5G;P!);F9O<FUA8VIE(&\@:VQU8WIU('!U8FQI8WIN
M>6T`4&%R82!K;'5C>GD@;W-O8FES='EC:"!N:64@>F]S=&&S82!W>6=E;F5R
M;W=A;F$@<&]M>;9L;FEE+@!0;W)T;W)Y:V\`2V%T87(`6F%P>71A;FEE`$ML
M=6-Z('!U8FQI8WIN>2!24T$@*"5D(&)I=/-W*0!/9+9W:66_(&1Y;F%M:6-Z
M;F4@96QE;65N='D@;65N=3H`3V2V=VEEOR!L:7-TZ@!/9+9W:66_('=I9&]K
M('-E<G=I<W4Z`%ID86QN92!S97)W97)Y`%5S=?$`57-U\2!B;&]K`%5S=?$@
M:V%T96=O<FGJ`%5S=?$@:V]L=6UNZ@!5<W7Q('!A<NH`57-U\0!5<W7Q('6_
M>71K;W=N:6MA`%ID86QN92!UOWET:V]W;FEK83H@)7,`4F5S970`5WEC>GFV
MYB!H87.S;P!7>6-Z>;;F(%1W;VIE(&AA<[-O`%=Y;FEK:0!0;W=R\W0@9&\@
M;W!C:FD`4F5U;FEO;@!2;WIB=61O=V%N>2!E9'ET;W(@=&5K<W1U`%-T86YO
M=VES:V\`4G5M=6YI80!/8G+SYB!O(#$X,"!S=&]P;FD`3V)R\^8@=R!L97=O
M`$]B<O/F('<@<')A=V\`5[-AMF-I=V^V8VD@<GKJ9'4@4')O<&5R=&EE<P!2
M;W-J80!2=6%N9&$`5VEA9&]M;[;F('IA<WIY9G)O=V%N82!3+TU)344`57=I
M97)Z>71E;&YI96YI92!305-,(&YI92!J97-T(&1O<W3J<&YE+@!0;W=L;VMA
M(%-13`!34T@`4&]WLV]K82!37U%,`*9W:>IT82!(96QE;F$`4V%I;G0@2VET
M=',@:2!.979I<P!386EN="!,=6-I80!386EN="U0:65R<F4@:2!-:7%U96QO
M;@!386EN="!6:6YC96YT(&D@1W)E;F%D>6YY`%-A;6]A`%-A;B!-87)I;F\`
M07)A8FEA(%-A=61Y:G-K80!:87!I<WH`6F%P:7-Z("(E<R(`6F%P:7-Z("5S
M`%IA<&ES>B!O<&-J90!3>G5K86H`5WEN:6MI('=Y<WIU:VEW86YI80!:86MR
M97,@<WIU:V%N:6$`4WIU:V%N>2!?=&5K<W0`5WEB:65R>B!P;&EK:0!7>6)I
M97)Z(&YO=&%T;FEK`%=Y8FEE<GH@>FYA:R!P;V1Z:6&S=2!D871Y.@!7>6)I
M97)Z(&9O<FUA="!D871Y.@!7>6)I97)Z(&9O<FUA="!P;&EK=2!E:W-P;W)T
M;W=A;F5G;SH`5WEB:65R>B!P;&EK(&1O('IA:6UP;W)T;W=A;FEA.@!7>6)I
M97)Z(&9O<FUA="!P;&EK=2"\<O-DLV]W96=O.@!7>6)I97)Z('1OOW-A;6^V
MYB!D;R!Z;6EA;GDZ`%=Y8FEE<GH@>FYA:R!P;V1Z:6&S=2!D871Y.@!7>6)I
M97)Z(&9O<FUA="!C>F%S=3H`5WEB:65R>B!D=V$@<&%S=6JQ8V4@<&]L82X`
M5WEB:65R>B!S8VAE;6%T(&MO;&]R\W<N`%=Y8FEE<GH@='?S:B!P<F5F97)O
M=V%N>2!JZGIY:SH`5WEB<F%N82!K871E9V]R:6$Z`%=YMFQI:B!R87!O<G0@
M;R!P<F]B;&5M:64`4V5N96=A;`!7<GIE<VEE\0!.=6UE<B!S97)Y:FYY`%5S
M=&%W`%5S=&%W('ID86QN92!S97)W97)Y+"!D;R!K=/-R>6-H(&-H8V5S>B!M
M:67F(&1O<W3J<"!Z('-E<G=I<W4N`%5S=&%W('!R969E<F]W86YY(&KJ>GEK
M+"!S=')E9NH@8WIA<V]WL2!I(&]P8VIE(&1A='DN`%5S=&%W('5SLW5GZB!P
M;V-ZL71K;W>Q+"!S8VAE;6%T(&MO;&]R\W<L(&]DMG=I9;]A;FEE('-T<F]N
M>2!I(&EN;F4@;W!C:F4@=WFV=VEE=&QA;FEA`$MO;F9I9W5R86-J80!3>F5S
M>F5L90!+<O-T:VD@;W!I<P!0;VMAOP!7>;9W:65T;&'F('!R>GEC:7-K(&%K
M8VII/P!0;VMA>GEW8>8@8WIA<R!O<W1A=&YI96=O('IA;&]G;W=A;FEA('!O
M(&QO9V]W86YI=3\`5WFV=VEE=&QAYB!N87IWZB!N;W1A=&YI:V$_`%!O:V%Z
M>7=AYB!N;W1A=&MI('H@=&5J(&MA=&5G;W)I:0!0;VMAOR!M96YU("5S('!O
M(&QE=V5J/P!3:65R<F$@3&5O;F4`6F%R96IE<W1R=6H@<VGJ+"!J9;9L:2!J
M97-Z8WIE('1E9V\@;FEE('IR;V)ILV6V`%!O9'!I<P!!;&=O<GET;2!P;V1P
M:7-U`%-I;F=A<'5R`%=I96QK;[;F`%!O;6GQ(&]P97)A8VIE(&-Y:VQI8WIN
M90!3LV]W86-J80!3LV]W96YI80!7>7-P>2!386QO;6]N80!3;VUA;&EA`%-O
M<G1U:B!P;R!K871E9V]R:6D`4V]R='5J('!O('1E:[9C:64@;F]T871K:0!0
M;[-U9&YI;W=A($%F<GEK80!0;[-U9&YI;W=O975R;W!E:G-K:2`H25-/+3@X
M-3DM,RD`1V5O<F=I82!0;[-U9&YI;W=A`$AI<WIP86YI80!3<&%M`$5D>6-J
M82!Z;F%K\W<@<W!E8VIA;&YY8V@`4&]D>FEE;"!K;VWS<FOJ`%!O9'II96P@
M:V]L=6UNZ@!0;V1Z:65L('=I97)S>@!3<FD@3&%N:V$`5V]J97?S9+QT=V\@
M;'5B('-T86X`4W1A='5S`$%D<F5S(&1O;6]W>0!496UA=`!7>;9L:6H`4&]W
M;V1Z96YI90!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!S>7-T96UU+@!59&&S
M;R!S:>H@=7-U;K'F("(E<R(@>B!S>7-T96UU+@!59&&S;R!S:>H@=7-U;K'F
M("(E<R(N`%5D8;-O('-IZB!U<W5NL>8@(B5S(B!Z('-Y<W1E;74N`%5D8;-O
M('-IZB!U86MT=6%L;FGF("(E<R(`4W5D86X`5W-C:/-D+WIA8VCS9"!SLV_Q
M8V$`4W5R:6YA;0!3=6%Z:0!3>G=E8VIA`%-Z=V%J8V%R:6$`4WER:6$`5&%J
M=V%N`%1A:G=A;@!4862_>6MI<W1A;@!486YZ86YI80!:861A;FEA`$YU;65R
M('1E;&5F;VYU`%1Y;&MO('1E:W-T`%1A:FQA;F1I80!$>FGJ:W5J96UY('IA
M(&MO<GIY<W1A;FEE('H@<V5R=VES=2X`5&^_<V%M;[;F("(E<R(@>F]S=&&S
M82!U<W5N:>IT82X`3F]T871K82!Z;W-T8;-A('5S=6YIZG1A+@!.;W1A=&YI
M:R`B)7,B(&YI92!M;[]E('IO<W1AYB!U='=O<GIO;GDZ("5S`$YO=&%T;FEK
M("(E<R(@>F]S=&&S('5T=V]R>F]N>2X`3F]T871N:6L@(B5S(B!Z;W-T8;,@
M=7-U;FGJ='DN`$YO=&%T;FEK("(E<R(@>F]S=&&S('IA<&ES86YY+@!397)W
M97(@(B5S(B!Z;W-T8;,@=7-U;FGJ='DN`%-E<G=E<B`B)7,B('IO<W1ALR!Z
M87!I<V%N>2X`0FQO:R!W96%T:&5R+F-O;2!N:64@:F5S="!D;W-TZG!N>2X`
M3FEE(&UA(+]A9&YY8V@@9&]S=.IP;GEC:"!O<&-J:2X`5WES=+%P:;,@<')O
M8FQE;2!P<GIY(&1O9&%W86YI=2`B)7,B(&1O('-Y<W1E;74Z("5S`%=Y<W2Q
M<&FS('!R;V)L96T@<')Z>2!U<W5W86YI=2!D86YY8V@@9&QA('6_>71K;W=N
M:6MA("(E<R(@=R!S>7-T96UI93H@`%=Y<W2Q<&FS('!R;V)L96T@<')Z>2!U
M<W5W86YI=2`B)7,B('H@<WES=&5M=2X`5WES=+%P:;,@<')O8FQE;2!P<GIY
M('5A:W1U86QN:6%N:74@(B5S(CH@)7,`5WES=+%P:;,@8K.Q9"!P;V1C>F%S
M('=YMG=I971L86YI82!T96H@8WKJMF-I('=I861O;6^V8VD`5WES=+%P:;,@
M8K.Q9"!P;V1C>F%S(&EM<&]R=&]W86YI82!D86YY8V@Z("5S`%=Y<W2Q<&FS
M(&*SL60@<&]D8WIA<R!I;7!O<G1O=V%N:6$@9&%N>6-H('9.;W1E+@!7>7-T
ML7!ILR!BL[%D('!O9&-Z87,@=7-U=V%N:6$@;F]T871K:3H@)7,`5WES=+%P
M:;,@8K.Q9"!P;V1C>F%S('IA<&ES>7=A;FEA(&YO=&%T:VDZ("5S`%=Y<W2Q
M<&FS(&*SL60@<&]D8WIA<R!P;V1G;+%D86YI82!T96=O(&YO=&%T;FEK83H@
M)7,`0G)A:R!N;W1E:R!D;R!E:W-P;W)T;W=A;FEA+@!0;&EK(&YI92!W>6=L
ML61A(&YA('!O<')A=VYE(&%R8VAI=W5M(%)!4BX`4&QI:R!N:64@=WEG;+%D
M82!N82!P;W!R87=N92!A<F-H:7=U;2!:25`N`%1O('!O;&4@:F5S="!W>6UA
M9V%N92X`5&\@<&]L92!M=7-I(&)YYB!P;W!R87=NL2!L:6-Z8K$N`$9O<FUA
M="!P;&EK=2!J97-T(&YI96]B<[-U9VEW86YY+@!7:6%D;VUOMN8@>F]S=&&S
M82!N87!I<V%N82!W(&EN;F5J(&YIOR!T=V]J82!S=')O;FEE(&MO9&]W96H@
M*"5S*2X`5&5N('-E<G=E<B!N:64@<&]T<F%F:2!R;WIP86MO=WEW8>8@87)C
M:&EW\W<@>FEP(&D@9WII<"X`0WIA<P!&;W)M870@8WIA<W4`5'ET=;,`1&\`
M06)Y('=Y8G)AYB!W:65L;VMR;W1N92!P;VQA('!R>GET<GIY;6%J('!R>GEC
M:7-K($-T<FP@*%!#*2!L=6(@0V]M;6%N9"`H36%C*2!P;V1C>F%S(&ML:6MA
M;FEA+@!$>FFV`%1O9V\`5&]K96QA=0!*=71R;P!4;VYG80!4<GEN:61A9"!I
M(%1O8F%G;P!0<F%W9&$@;'5B(&9ALW-Z`%1U;F5Z:F$`5'5R8VIA`%1U<F5C
M:VD@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=79A;'4`55),`%523#H`
M56=A;F1A`%5K<F%I;F$`0K.Q9"!P;V1C>F%S('IM:6%N>2!D;R`E<RX`0K.Q
M9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"X`0K.Q9"!P
M;V1C>F%S(')O>G!A:V]W>7=A;FEA(&1A;GEC:"X`3FEE(&UO9^H@=7-U;K'F
M("(E<R(Z("5S`$YI92!M;[]N82!P<GIE=+-U;6%C>GGF('1E9V\@9&]K=6UE
M;G1U(%=O<F0M80!#;V9N:6H@>FUI86YY`$YI97IN86YA`%IJ961N;V-Z;VYE
M($5M:7)A='D@07)A8G-K:64`5VEE;&MA($)R>71A;FEA`%5300!.:65Z;F%N
M90!"97H@;F%Z=WD`3FEE;V)SLW5G:7=A;F4@<F]Z<WIE<GIE;FEE`%5A:W1U
M86QN:6H`6F&S861U:@!5<G5G=V%J`$]P8VIE('6_>71K;W=N:6MA`%)E:F5S
M=')A8VIA('6_>71K;W=N:6MA`$YA>G=A('6_>71K;W=N:6MA`%6_>71K;W=N
M:6L@;R!N87IW:64@(B5S(B!J=;\@:7-T;FEE:F4N`$YA>G=A('6_>71K;W=N
M:6MA.@!.87IW82!UOWET:V]W;FEK83H@`%6_>71K;W=N:6-Y('<@<WES=&5M
M:64Z`%5Z8F5K:7-T86X`5V%K86-J90!686YU871U`%=E;F5Z=65L80!797)S
M:F$`5VEE=&YA;0!7:61O:R`E<P!0;VMAOR!S=')O;NH@5U=7`%!O:V&_(&IA
M:V\@)7,`0G)Y='EJ<VMI92!7>7-P>2!$>FEE=VEC>F4`5WES<'D@1'II97=I
M8WIE(%-T86[S=R!::F5D;F]C>F]N>6-H`%=A;&QI<R!I($9U='5N80!/<W1R
M>F6_96YI90!75U<`0V\@='ED>FEE\0!7:71A;7D`5VET86UY('<@)7,`5VET
M86UY+"`E<P!:86-H;V1N:2`H25-/+3@X-3DM,2D`6F%C:&]D;FD@*$E33RTX
M.#4Y+3$U*0!386AA<F$@6F%C:&]D;FEA`$IA:[$@87!L:6MA8VKJ(&UA("5S
M('=YMG=I971L8>8@<&\@>F%L;V=O=V%N:74@<VGJ/P!$;R!K=/-R96=O(&YO
M=&%T;FEK82!D;V1AYB!N;W1A=&MI/P!*86MI92!W='EC>FMI(&%K='EW;W=A
MYB!W(%)O>F)U9&]W86YY;2!E9'ET;W)Z92!T96MS='4N`%-Z97)O:V^VYB!L
M97=E9V\@;65N=2`E<R`H>FUI86YA('IA8WIN:64@;V)O=VFQ>GEW8>8@<')Z
M>2!N87-TZG!N>6T@;&]G;W=A;FEU*3H`061R97,@9&\@<')A8WD`5&5L+B!D
M;R!P<F%C>0!24@!24E)2`$-O(')O:P!*96UE;@!486L`5&%K+"!Z9V%D>F%M
M('-IZ@!.:64@;6%S>B!P<F%W+"!A8GD@>F]B86-Z>>8@;F]T871N:6L@)7,N
M`%=Y;&]G;W=ALV6V('-IZBX`375S:7-Z(&]P:7-AYB!P<F]B;&5M('IA;FEM
M(&=O('=YMFQE<WHN`$UU<VES>B!W>6)R8>8@;F]T871N:6L@9&\@=7-U;FGJ
M8VEA+@!-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC
M97-Z('5S=6ZQYBX`375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R
M96=O(&-H8V5S>B!D;V1AYBX`5'?S:B!A9')E<R!E+6UA:6P`5'?S:B!A9')E
M<R!/9#H`5'=O:F4@:6YF;W)M86-J90!4=_-J(&%D<F5S(&EN=&5R;F5T;W=Y
M('-IZB!Z;6EE;FFS(&]D('!O8WJQ=&MU('-E<VII("5S+B!7('IW:;%Z:W4@
M>B!B97IP:65C>F7Q<W1W96T@5'=O:F5G;R!K;VYT82!M=7-I<WH@>F%L;V=O
M=V'F('-IZB!P;VYO=VYI92X`5'=O:F4@:6UIZ@!496X@<WES=&5M(&%U=&5N
M='EK86-J:2!N:64@;V)SLW5G=6IE(&1O9&%W86YI82!UOWET:V]W;FEK\W<L
M(&QU8B!T82!O<&-J82!Z;W-T8;-A('=YL[%C>F]N82X`5&5N('-Y<W1E;2!A
M=71E;G1Y:V%C:FD@;FEE(&]B<[-U9W5J92!L:7-T;W=A;FEA('6_>71K;W=N
M:6OS=RP@;'5B('1A(&]P8VIA('IO<W1ALV$@=WFSL6-Z;VYA+@!4=V]J82!O
M8F5C;F$@<W1R969A(&-Z87-O=V$Z`$1O;7FV;&YA('1OOW-A;6^VYCH`5'?S
M:B!D;VUYMFQN>2!N;W1A=&YI:P!4=V]J92!P9;-N92!I;6GJ(&D@;F%Z=VES
M:V\Z`%1W;VEM(&YO=WEM(&AA<[-E;2!W("5S(&IE<W0Z("5S`%1W;VIE(&YO
M=&%T;FEK:3H`5'=O:F4@=7-T87=I96YI82!Z;W-T8;-Y('5A:W1U86QN:6]N
M92!N82!C>F%S('1R=V%N:6$@=&5J('-E<VII+@!4=V]J92!U<W1A=VEE;FEA
M('IO<W1ALWD@=6%K='5A;&YI;VYE+@!4=V]J92!Z9&%L;F4@<V5R=V5R>3H`
M2G5G;W.S87=I80!:86ER`%IA;6)I80!::6UB86)W90!;4F%P;W)T(&\@<')O
M8FQE;6EE70!?061M:6YI<W1R86-J80!7<O/F(&1O(&YO=&%T;FEK82`H7V(I
M`%]#3$D`2V%T96=O<FEA("A?8RD`57-U\2`H7V0I`%]5<W7Q('=I97)S>@!?
M161Y='5J`%!I97)W<WIA(&QI;FEA("A?9BD`7T=R=7!Y`%]0;VUO8P!?26UP
M;W)T+T5K<W!O<G0`7TQI<W1A(&YO=&%T96L`7UIA;&]G=6H`7U=Y;&]G=6H`
M6FUI9?$@;&EN:RXN+@!?36]J92!N;W1A=&YI:VD`7TYO=V$@;F]T871K80!?
M3W!C:F4`7U5P<F%W;FEE;FEA`$1R=6MU:B`H7W`I`%5S=?$@;&EN:RXN+@!?
M4WIU:V%J`%]+;VYF:6=U<F%C:F$`7U6_>71K;W=N:6-Y`&MS:;&_:V$@861R
M97-O=V$`:V%L96YD87)Z`'!L:6L`3F%Z=VES:V\`;F]T871N:6L`;F]T871K
M:2YC<W8`8F5Z(&YA>G=Y`'9#87)D`'9.;W1E````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O<'1?0E(O
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S0T`#`R,#`P-``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN
M96UO+VQO8V%L92]P=%]"4B],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#0`,#(Q-3<Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+W!T7T)2+TQ#7TU%4U-!1T53
M+VUN96UO+FUO```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0S-#0W-0`Q,#0Q-S,V,C<T
M-``P,C,R-3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````#Y!P``'````.0_``"I"@``K'\```````!0J@``#@``
M`%&J```/````8*H```T```!PJ@``"````'ZJ```+````AZH```P```"3J@``
M!````*"J```8````I:H``!L```"^J@``+0```-JJ```=````"*L``"0````F
MJP``*0```$NK```9````=:L``"8```"/JP``#````+:K```D````PZL```@`
M``#HJP``#P```/&K```+`````:P```X````-K```!0```!RL```H````(JP`
M``@```!+K```"@```%2L```5````7ZP``!(```!UK```"P```(BL```-````
ME*P``!T```"BK```A0```,"L```.````1JT```H```!5K0``#0```&"M```.
M````;JT``!$```!]K0``#0```(^M```,````G:T```T```"JK0``!@```+BM
M``"4````OZT```H```!4K@``#P```%^N```8````;ZX```P```"(K@``!@``
M`)6N```.````G*X```X```"KK@``"````+JN```)````PZX``"X```#-K@``
M&@```/RN```R````%Z\``#@```!*KP``5````(.O``!1````V*\``%H````J
ML```5P```(6P```T````W;````D````2L0``#0```!RQ```'````*K$```H`
M```RL0``#P```#VQ```%````3;$```8```!3L0``$0```%JQ```(````;+$`
M``D```!UL0``"0```'^Q```E````B;$``"````"OL0``'````-"Q```>````
M[;$``"`````,L@``'0```"VR```3````2[(``!````!?L@``#P```'"R```*
M````@+(```,```"+L@``#P```(^R```4````G[(```D```"TL@``#0```+ZR
M```2````S+(``!D```#?L@``'@```/FR```/````&+,```P````HLP``"@``
M`#6S```/````0+,```@```!0LP``)````%FS```4````?K,``!8```"3LP``
M"````*JS``!.````L[,``"T````"M```$0```#"T```9````0K0```<```!<
MM```#````&2T```L````<;0```X```">M````P```*VT```+````L;0```<`
M``"]M```!P```,6T```%````S;0```4```#3M```"@```-FT```#````Y+0`
M`!<```#HM```"@````"U```/````"[4```X````;M0``&````"JU```C````
M0[4```X```!GM0``%````':U```7````B[4``!<```"CM0``%P```+NU```3
M````T[4```\```#GM0``#@```/>U```?````!K8``!T````FM@``!P```$2V
M```&````3+8```@```!3M@``#P```%RV```&````;+8```H```!SM@``$P``
M`'ZV```+````DK8``!````">M@``%0```*^V```5````Q;8```<```#;M@``
M$````..V```%````]+8``!4```#ZM@``$0```!"W```,````(K<``#L````O
MMP``.````&NW```)````I+<```<```"NMP``%````+:W```#````R[<```4`
M``#/MP``"0```-6W```0````W[<```D```#PMP``$P```/JW```Y````#K@`
M`!(```!(N```)P```%NX```L````@[@``"H```"PN```)0```-NX```*````
M`;D```8````,N0``"0```!.Y```'````';D``"\````EN0``-P```%6Y```N
M````C;D``%4```"\N0``+0```!*Z```M````0+H``#T```!NN@``/P```*RZ
M```M````[+H``$`````:NP``(P```%N[```C````?[L``$````"CNP``+0``
M`.2[```S````$KP``"4```!&O```%0```&R\```9````@KP``"D```"<O```
M)````,:\```H````Z[P``!4````4O0``$0```"J]```*````/+T```P```!'
MO0``#P```%2]```7````9+T```H```!\O0``$````(>]```6````F+T``!8`
M``"OO0``!P```,:]```'````SKT``!0```#6O0``"@```.N]```(````]KT`
M`"<```#_O0``"````">^```'````,+X```<````XO@``!@```$"^```%````
M1[X```<```!-O@``!@```%6^```(````7+X``"D```!EO@``#@```(^^```*
M````GKX```0```"IO@``!P```*Z^```)````MKX```8```#`O@``$0```,>^
M```'````V;X``!8```#AO@``!````/B^```(````_;X```8````&OP``#0``
M``V_```&````&[\``!X````BOP``$0```$&_```(````4[\```T```!<OP``
M#````&J_```'````=[\```,```!_OP```P```(._```7````A[\```,```"?
MOP``$P```*._```=````M[\```@```#5OP``!````-Z_```(````X[\```@`
M``#LOP``00```/6_```:````-\```"L```!2P```(````'[````5````G\``
M``8```"UP```!@```+S````5````P\```!@```#9P```(@```/+````N````
M%<$``!T```!$P0``(0```&+!``!4````A,$``"D```#9P0``"@````/"```'
M````#L(```<````6P@``%0```!["```(````-,(```X````]P@``"@```$S"
M```/````5\(```T```!GP@``#P```'7"```-````A<(```D```"3P@``%```
M`)W"```&````LL(``!@```"YP@``'0```-+"```3````\,(``!$````$PP``
M%````!;#```$````*\,```8````PPP``%````#?#``!4````3,,``"T```"A
MPP``9````,_#```$````-,0```X````YQ```!0```$C$```%````3L0``!L`
M``!4Q```&@```'#$```3````B\0``!$```"?Q```$0```+'$```<````P\0`
M`"H```#@Q```-P````O%```<````0\4``!````!@Q0``(0```''%```%````
MD\4```H```"9Q0``$P```*3%```+````N,4``!(```#$Q0``"@```-?%```/
M````XL4```T```#RQ0``$0````#&```3````$L8```P````FQ@``!@```#/&
M```,````.L8```8```!'Q@``%P```$[&```0````9L8``!$```!WQ@``"```
M`(G&```%````DL8```P```"8Q@``$````*7&```%````ML8```T```"\Q@``
M!@```,K&```'````T<8```T```#9Q@``!P```.?&```+````[\8```<```#[
MQ@``!P````/'```)````"\<```D````5QP``"@```!_'```9````*L<``#T`
M``!$QP``'0```(+'```,````H,<``!````"MQP``!0```+['```E````Q,<`
M`!(```#JQP``$P```/W'```K````$<@``#L````]R```(````'G(```(````
MFL@``#8```"CR```(0```-K(```0````_,@```@````-R0``#````!;)```&
M````(\D```0````JR0``#P```"_)```.````/\D```<```!.R0``"@```%;)
M```-````8<D``!\```!OR0``'````(_)```A````K,D``!X```#.R0``&0``
M`.W)```>````!\H``!L````FR@``(0```$+*```N````9,H``"8```"3R@``
M'````+K*```>````U\H``!P```#VR@``)@```!/+```K````.LL``#,```!F
MRP``)@```)K+```K````P<L``#@```#MRP``'0```";,```5````1,P``"\`
M``!:S```(````(K,```2````J\P``"D```"^S```'@```.C,```@````!\T`
M`!(````HS0``H@```#O-```6````WLT``",```#US0``*````!G.```I````
M0LX``"@```!LS@``'P```)7.```5````M<X``"````#+S@``)0```.S.```H
M````$L\``"T````[SP``,````&G/``"2````FL\``"$````MT```%@```$_0
M```<````9M```"8```"#T```*@```*K0``!!````U=```$0````7T0``#```
M`%S1```'````:=$```<```!QT0``!@```'G1```-````@-$``!````".T0``
M$@```)_1```'````LM$``!,```"ZT0``$@```,[1```'````X=$```0```#I
MT0``$````.[1```0````_]$```P````0T@``#@```!W2```-````+-(```\`
M```ZT@``$P```$K2```-````7M(``"@```!LT@```P```)72```-````F=(`
M``8```"GT@``$0```*[2```7````P-(``!L```#8T@``#@```/32```"````
M`],``$D````&TP``!0```%#3```0````5M,```\```!GTP``!````'?3```-
M````?-,```X```"*TP```P```)G3```.````G=,```@```"LTP``#P```+73
M```/````Q=,```<```#5TP``#0```-W3```0````Z],```\```#\TP``#0``
M``S4```9````&M0``!H````TU```"P```$_4```&````6]0```L```!BU```
M$P```&[4```,````@M0```H```"/U```$0```)K4```9````K-0``!<```#&
MU```"P```-[4```-````ZM0``"(```#XU```&P```!O5```T````-]4```H`
M``!LU0``&````'?5```9````D-4``!8```"JU0``$````,'5```B````TM4`
M``T```#UU0``!P````/6```*````"]8``!0````6U@``"P```"O6```,````
M-]8``"(```!$U@``+P```&?6```+````E]8```D```"CU@``&0```*W6```+
M````Q]8``!<```#3U@``%P```.O6```)`````]<``!8````-UP``#P```"37
M```9````--<``!8```!.UP``#@```&77```8````=-<```@```"-UP``#0``
M`);7```F````I-<``"@```#+UP``0P```/37```(````.-@``!(```!!V```
M'P```%38```(````=-@```L```!]V```+P```(G8```.````N=@```4```#(
MV```!@```,[8``!%````U=@```,````;V0``!P```!_9```$````)]D```D`
M```LV0``"@```#;9```*````0=D```D```!,V0``#P```%;9```0````9MD`
M`!<```!WV0``&@```(_9```1````JMD``!D```"\V0``%P```-;9```)````
M[MD```4```#XV0``"P```/[9```*````"MH```(````5V@``!0```!C:```-
M````'MH``!L````LV@``%P```$C:```4````8-H```D```!UV@``"@```'_:
M```.````BMH```T```"9V@``$@```*?:```X````NMH``"````#SV@``"```
M`!3;```.````'=L``'L````LVP``&````*C;```8````P=L``!$```#:VP``
M!P```.S;```%````]-L``!@```#ZVP``'@```!/<```;````,MP``!D```!.
MW```&P```&C<```9````A-P``!,```">W```!P```++<```(````NMP```8`
M``##W```!@```,K<```0````T=P```\```#BW```$````/+<```/`````]T`
M``L````3W0``#P```!_=```,````+]T```\````\W0``!P```$S=```&````
M5-T```X```!;W0``#````&K=```H````=]T```\```"@W0``"````+#=```&
M````N=T```P```#`W0``"````,W=```3````UMT```H```#JW0``'@```/7=
M```A````%-X``"`````VW@``&0```%?>```7````<=X``"4```")W@``%P``
M`*_>```6````Q]X```0```#>W@``&P```./>```-````_]X```P````-WP``
M`P```!K?```%````'M\```@````DWP``"@```"W?```,````.-\```L```!%
MWP``$````%'?```,````8M\```X```!OWP``"P```'[?```$````BM\```0`
M``"/WP``$P```)3?```4````J-\```P```"]WP``"0```,K?```.````U-\`
M``L```#CWP``&P```._?```'````"^````<````3X```"@```!O@```-````
M)N````D````TX```!````#[@```%````0^````,```!)X```&````$W@```*
M````9N````0```!QX```)@```';@```.````G>```'P```"LX```%0```"GA
M```%````/^$```<```!%X0``#````$WA```(````6N$```H```!CX0``!@``
M`&[A```(````=>$```(```!^X0``!@```('A```&````B.$``!0```"/X0``
M#0```*3A```0````LN$``!L```##X0``!````-_A```)````Y.$``!````#N
MX0``"0```/_A```)````">(```4````3X@``&@```!GB```(````-.(```8`
M```]X@``#P```$3B```9````5.(```X```!NX@``!P```'WB```'````A>(`
M``4```"-X@``"0```)/B```*````G>(```X```"HX@```@```+?B```&````
MNN(```L```#!X@``#0```,WB```)````V^(```8```#EX@``$@```.SB```)
M````_^(```<````)XP``%````!'C```=````)N,``$(```!$XP``)0```(?C
M```E````K>,```8```#3XP``"@```-KC```$````Y>,```D```#JXP``"```
M`/3C```1````_>,```D````/Y```!@```!GD```-````(.0```8````NY```
M!````#7D```Y````.N0``#T```!TY```.@```++D```>````[>0```4````,
MY0``#@```!+E```$````(>4```8````FY0``!P```"WE```A````->4```T`
M``!7Y0``%0```&7E```&````>^4```0```""Y0``$0```(?E```&````F>4`
M``H```"@Y0``(@```*OE```$````SN4```4```#3Y0``'0```-GE```$````
M]^4```P```#\Y0``#@````GF```*````&.8```@````CY@``"0```"SF```%
M````-N8``#H````\Y@``,````'?F```U````J.8``"D```#>Y@``1P````CG
M```X````4.<``"D```")YP``/P```+/G```N````\^<``"T````BZ```'P``
M`%#H```/````<.@``!(```"`Z```"P```)/H```F````G^@``"D```#&Z```
M)````/#H```F````%>D```@````\Z0``"@```$7I```)````4.D```<```!:
MZ0``(````&+I```@````@^D``"8```"DZ0``"@```,OI```9````UND``"D`
M``#PZ0``%@```!KJ```2````,>H```<```!$Z@``"@```$SJ```,````5^H`
M``\```!DZ@``$````'3J``!`````A>H``'````#&Z@``9@```#?K```.````
MGNL```D```"MZP``"@```+?K```2````PNL``!,```#5ZP``#````.GK```&
M````]NL``!4```#]ZP``#P```!/L```3````(^P``!(````W[```$````$KL
M```1````6^P``!P```!M[```(P```(KL``!J````KNP```\````9[0``!0``
M`"GM```0````+^T```D```!`[0``!````$KM```+````3^T``"````!;[0``
M%````'SM```,````D>T```P```">[0``#P```*OM```5````N^T``"D```#1
M[0``*@```/OM```F````)NX``"<```!-[@``*0```'7N```J````G^X``!D`
M``#*[@``0@```.3N```1````)^\``!(````Y[P``$P```$SO```4````8.\`
M``\```!U[P``%@```(7O```7````G.\``!````"T[P``$0```,7O```T````
MU^\``!,````,\```$@```"#P```U````,_```!0```!I\```!P```'[P```,
M````AO```"````"3\```$````+3P```4````Q?```!$```#:\```%P```.SP
M```<````!/$``!,````A\0``%````#7Q```:````2O$``!$```!E\0``&@``
M`'?Q```>````DO$``!H```"Q\0``$P```,SQ```5````X/$``!$```#V\0``
M%P````CR```4````(/(``!<````U\@``%0```$WR```)````8_(``!````!M
M\@``&0```'[R```$````F/(```<```"=\@``"P```*7R```1````L?(```8`
M``##\@``!@```,KR```&````T?(```4```#8\@``!P```-[R```'````YO(`
M``4```#N\@``%@```/3R```&````"_,```8````2\P``!````!GS```$````
M'O,```<````C\P``#@```"OS```,````.O,```P```!'\P``#0```%3S```*
M````8O,```X```!M\P``!0```'SS```H````@O,```X```"K\P``#````+KS
M```/````Q_,```H```#7\P``"````.+S```)````Z_,``"L```#U\P``!```
M`"'T```(````)O0``"8````O]```$@```%;T```/````:?0```8```!Y]```
M"@```(#T```'````B_0```@```"3]```(````)ST```)````O?0```T```#'
M]```%````-7T```,````ZO0```T```#W]```#@````7U```6````%/4``!$`
M```K]0``!@```#WU```#````1/4```8```!(]0``&0```$_U```'````:?4`
M``0```!Q]0``"P```';U```+````@O4```<```".]0``!0```);U```'````
MG/4``!8```"D]0``#0```+OU```-````R?4```H```#7]0``$````.+U```/
M````\_4``!$````#]@``%P```!7V```*````+?8``!$````X]@``"````$KV
M```$````4_8```\```!8]@``.@```&CV```%````H_8```P```"I]@``'@``
M`+;V```.````U?8``!````#D]@``"P```/7V```,`````?<```D````.]P``
M!P```!CW```*````(/<```D````K]P``#@```#7W```0````1/<``!L```!5
M]P``&````''W```:````BO<```H```"E]P``"0```+#W```*````NO<```P`
M``#%]P``#P```-+W```(````XO<```8```#K]P``'````/+W```'````#_@`
M``4````7^```"P```!WX``!'````*?@```T```!Q^```"0```'_X```$````
MB?@```,```".^```$P```)+X```3````IO@``!,```"Z^```"@```,[X```"
M````V?@```0```#<^```)0```.'X```#````!_D```4````+^0``*@```!'Y
M```*````//D```4```!'^0``!````$WY```*````4OD```T```!=^0``!@``
M`&OY```(````<OD```@```![^0``!````(3Y```%````B?D``&@```"/^0``
M"0```/CY```,`````OH``!`````/^@``!0```"#Z```&````)OH``!L````M
M^@``+P```$GZ```0````>?H```H```"*^@``#P```)7Z```*````I?H```D`
M``"P^@``$P```+KZ```;````SOH``!@```#J^@``%P````/[```7````&_L`
M`!\````S^P``#@```%/[```#````8OL```<```!F^P``"````&[[```'````
M=_L```D```!_^P``"@```(G[```+````E/L```<```"@^P``40```*C[```0
M````^OL```P````+_```#0```!C\```:````)OP``$H```!!_```&0```(S\
M```&````IOP``!H```"M_```)0```,C\```&````[OP```8```#U_```'P``
M`/S\```&````'/T```D````C_0``&````"W]```7````1OT``"@```!>_0``
M!@```(?]```-````COT``"(```"<_0``5P```+_]```3````%_X``",````K
M_@``$P```$_^```"````8_X```L```!F_@``"````'+^```-````>_X```H`
M``")_@``#````)3^```'````H?X``!0```"I_@``!@```+[^```(````Q?X`
M``X```#._@``!P```-W^```*````Y?X```L```#P_@``,@```/S^```'````
M+_\```P````W_P``#0```$3_```,````4O\```D```!?_P``"0```&G_```*
M````<_\```<```!^_P``"0```(;_```'````D/\```H```"8_P``&P```*/_
M```/````O_\``!(```#/_P``"@```.+_```6````[?\```@````$``$`"0``
M``T``0`0````%P`!``<````H``$`$@```#```0`$````0P`!``<```!(``$`
M!0```%```0`%````5@`!``L```!<``$`%````&@``0`1````?0`!`!H```"/
M``$`%@```*H``0`4````P0`!`!<```#6``$`&````.X``0`<````!P$!`!D`
M```D`0$`!P```#X!`0`%````1@$!``T```!,`0$`#````%H!`0`1````9P$!
M``@```!Y`0$`"````((!`0`7````BP$!``L```"C`0$`#````*\!`0`?````
MO`$!`!H```#<`0$`$P```/<!`0`$````"P(!``H````0`@$`!````!L"`0`-
M````(`(!``P````N`@$`!0```#L"`0`)````00(!``4```!+`@$`!P```%$"
M`0`%````60(!``0```!?`@$``@```&0"`0`X````9P(!`"P```"@`@$`$@``
M`,T"`0`I````X`(!`#(````*`P$`"@```#T#`0`L````2`,!`"X```!U`P$`
M,P```*0#`0`S````V`,!`#@````,!`$`#P```$4$`0`8````500!`!````!N
M!`$`'````'\$`0`/````G`0!`!,```"L!`$`%0```,`$`0`4````U@0!`!(`
M``#K!`$`)````/X$`0`(````(P4!`"0````L!0$`$P```%$%`0`4````904!
M`!4```!Z!0$`+0```)`%`0`M````O@4!`#$```#L!0$`+@```!X&`0`O````
M308!`"P```!]!@$`8@```*H&`0`3````#0<!``T````A!P$`"````"\'`0`7
M````.`<!``@```!0!P$`#````%D'`0`K````9@<!`"$```"2!P$`&@```+0'
M`0`)````SP<!`$4```#9!P$`00```!\(`0`%````80@!``0```!G"`$`$P``
M`&P(`0`4````@`@!``X```"5"`$`$P```*0(`0`8````N`@!``8```#1"`$`
M"0```-@(`0`*````X@@!``\```#M"`$`$````/T(`0`'````#@D!``X````6
M"0$`#0```"4)`0`,````,PD!``H```!`"0$`"0```$L)`0`*````50D!``\`
M``!@"0$`"````'`)`0`/````>0D!``@```")"0$`&@```)()`0`%````K0D!
M``T```"S"0$`&P```,$)`0`(````W0D!``8```#F"0$`%````.T)`0`1````
M`@H!``X````4"@$`.````",*`0`"````7`H!``8```!?"@$`#@```&8*`0`%
M````=0H!``<```!["@$`#@```(,*`0`&````D@H!`"@```"9"@$`#````,(*
M`0`<````SPH!``0```#L"@$`*0```/$*`0`7````&PL!`!\````S"P$`7```
M`%,+`0`4````L`L!`#X```#%"P$`'P````0,`0`0````)`P!``<````U#`$`
M#@```#T,`0`,````3`P!``P```!9#`$`$P```&8,`0`*````>@P!`!T```"%
M#`$`&0```*,,`0`%````O0P!`!$```###`$`$0```-4,`0`D````YPP!`!(`
M```,#0$`%0```!\-`0`2````-0T!``X```!(#0$`&0```%<-`0`(````<0T!
M``D```!Z#0$`#0```(0-`0`'````D@T!``H```":#0$`!P```*4-`0`/````
MK0T!``8```"]#0$`"P```,0-`0`:````T`T!``H```#K#0$`!P```/8-`0`(
M````_@T!``4````'#@$`'P````T.`0`&````+0X!`!`````T#@$`"````$4.
M`0`-````3@X!``@```!<#@$`'@```&4.`0`2````A`X!`"P```"7#@$`&@``
M`,0.`0`)````WPX!``H```#I#@$`%0```/0.`0`%````"@\!`!0````0#P$`
M!````"4/`0`0````*@\!``8````[#P$`!P```$(/`0`>````2@\!`"@```!I
M#P$`"@```)(/`0`<````G0\!`!$```"Z#P$`"P```,P/`0`:````V`\!`!0`
M``#S#P$`!`````@0`0`$````#1`!``L````2$`$`!0```!X0`0`&````)!`!
M``@````K$`$`!@```#00`0`*````.Q`!`!L```!&$`$`-````&(0`0`T````
MEQ`!`"````#,$`$`*0```.T0`0`@````%Q$!`$$````X$0$`&@```'H1`0`H
M````E1$!`"D```"^$0$`4````.@1`0`B````.1(!``8```!<$@$`"````&,2
M`0`%````;!(!``@```!R$@$`&0```'L2`0`9````E1(!`"H```"O$@$`(P``
M`-H2`0`9````_A(!`"X````8$P$`-````$<3`0`(````?!,!`!<```"%$P$`
M"@```)T3`0`'````J!,!`"$```"P$P$`$````-(3`0`.````XQ,!``L```#R
M$P$`!P```/X3`0`3````!A0!``@````:%`$`"P```",4`0`*````+Q0!`!0`
M```Z%`$`#P```$\4`0`R````7Q0!``L```"2%`$`!0```)X4`0`%````I!0!
M``4```"J%`$`%P```+`4`0`/````R!0!``0```#8%`$`"@```-T4`0`)````
MZ!0!``L```#R%`$`#0```/X4`0`,````#!4!``X````9%0$`!0```"@5`0`$
M````+A4!``T````S%0$`,@```$$5`0`8````=!4!`$4```"-%0$`%P```-,5
M`0`'````ZQ4!`!X```#S%0$`#````!(6`0`4````'Q8!``4````T%@$`%```
M`#H6`0`&````3Q8!``<```!6%@$`#@```%X6`0`J````;18!``8```"8%@$`
M#````)\6`0`/````K!8!``T```"\%@$`$0```,H6`0`+````W!8!`#8```#H
M%@$`"@```!\7`0`B````*A<!``L```!-%P$`#P```%D7`0`R````:1<!`"4`
M``"<%P$`,````,(7`0`Q````\Q<!`"T````E&`$`#@```%,8`0`%````8A@!
M``X```!H&`$`$P```'<8`0`2````BQ@!``<```">&`$`$0```*88`0`3````
MN!@!``<```#,&`$`%````-08`0`8````Z1@!``<````"&0$`!0````H9`0`,
M````$!D!``P````=&0$`$@```"H9`0`$````/1D!``<```!"&0$`"@```$H9
M`0`+````51D!``P```!A&0$`#@```&X9`0`.````?1D!``4```",&0$`!0``
M`)(9`0`N````F!D!`"8```#'&0$`(P```.X9`0`#````$AH!`!(````6&@$`
M!@```"D:`0`>````,!H!`!@```!/&@$`)0```&@:`0`-````CAH!``D```"<
M&@$`'P```*8:`0`#````QAH!``<```#*&@$`"@```-(:`0`"````W1H!``P`
M``#@&@$`%0```.T:`0`+`````QL!`!D````/&P$`(````"D;`0`2````2AL!
M``4```!=&P$`"@```&,;`0`5````;AL!`!(```"$&P$`#````)<;`0`$````
MI!L!``D```"I&P$`!P```+,;`0`,````NQL!`%(```#(&P$`%P```!L<`0`D
M````,QP!`!(```!8'`$`!P```&L<`0`&````<QP!``X```!Z'`$`#@```(D<
M`0`,````F!P!``P```"E'`$`#````+(<`0`-````OQP!`!4```#-'`$`$@``
M`.,<`0`0````]AP!``\````''0$`%````!<=`0`*````+!T!`!L````W'0$`
M$````%,=`0`+````9!T!`!L```!P'0$`:0```(P=`0`:````]AT!`!<````1
M'@$`&0```"D>`0`:````0QX!`"4```!>'@$`)P```(0>`0`:````K!X!`!<`
M``#''@$`&P```-\>`0`9````^QX!`!\````5'P$`%````#4?`0`3````2A\!
M``@```!>'P$`!P```&<?`0`(````;Q\!``D```!X'P$`%0```((?`0`-````
MF!\!`",```"F'P$`#0```,H?`0`3````V!\!``@```#L'P$``P```/4?`0!&
M````^1\!`#\```!`(`$`-P```(`@`0!7````N"`!``4````0(0$`'P```!8A
M`0`O````-B$!``H```!F(0$`"````'$A`0`-````>B$!`"T```"((0$`!```
M`+8A`0`4````NR$!`$\```#0(0$`)0```"`B`0`2````1B(!`"````!9(@$`
M'````'HB`0`+````ER(!`!\```"C(@$`'0```,,B`0`E````X2(!`"`````'
M(P$`)````"@C`0`@````32,!``L```!N(P$`!P```'HC`0`-````@B,!``P`
M``"0(P$`%P```)TC`0`&````M2,!`#D```"\(P$`#````/8C`0`'`````R0!
M``D````+)`$`$P```!4D`0`)````*20!``0````S)`$`$````#@D`0`(````
M220!``@```!2)`$`!````%LD`0`+````8"0!``P```!L)`$`$@```'DD`0`1
M````C"0!``P```">)`$`&@```*LD`0`/````QB0!``<```#6)`$`#0```-XD
M`0`0````["0!`!$```#])`$`%`````\E`0`.````)"4!``P````S)0$`&P``
M`$`E`0`L````7"4!`!,```"))0$`'````)TE`0`H````NB4!``8```#C)0$`
M!P```.HE`0`3````\B4!``4````&)@$`!`````PF`0`7````$28!``H````I
M)@$`#````#0F`0`)````028!``8```!+)@$`"0```%(F`0`(````7"8!``D`
M``!E)@$`"@```&\F`0`1````>B8!``8```",)@$`#@```),F`0`.````HB8!
M``T```"Q)@$`"P```+\F`0`=````RR8!``L```#I)@$``@```/4F`0`<````
M^"8!``<````5)P$`!@```!TG`0!D````)"<!``D```"))P$`!P```),G`0`F
M````FR<!`#@```#")P$`&@```/LG`0`J````%B@!`#L```!!*`$`&````'TH
M`0`H````EB@!`#0```"_*`$`&0```/0H`0`5````#BD!``4````D*0$`!P``
M`"HI`0`(````,BD!``<````[*0$`!0```$,I`0`'````22D!``X```!1*0$`
M"0```&`I`0`&````:BD!``@```!Q*0$`"P```'HI`0`'````ABD!``@```".
M*0$`!P```)<I`0`6````GRD!``D```"V*0$`!@```,`I`0`+````QRD!`!``
M``#3*0$`!@```.0I`0`<````ZRD!`!0````(*@$`!P```!TJ`0`1````)2H!
M``@````W*@$`#@```$`J`0`(````3RH!``4```!8*@$`$````%XJ`0`)````
M;RH!`!````!Y*@$`!@```(HJ`0`9````D2H!``H```"K*@$`'````+8J`0`'
M````TRH!``4```#;*@$`$````.$J`0`4````\BH!``L````'*P$`#0```!,K
M`0`H````(2L!`!@```!**P$`%P```&,K`0`$````>RL!``D```"`*P$`"@``
M`(HK`0`'````E2L!``(```"=*P$`#@```*`K`0`(````KRL!`",```"X*P$`
M'P```-PK`0`X````_"L!`"8````U+`$`,0```%PL`0`G````CBP!`&0```"V
M+`$`%````!LM`0!5````,"T!`#@```"&+0$`2@```+\M`0!;````"BX!`"@`
M``!F+@$`.````(\N`0`H````R"X!`"P```#Q+@$`)@```!XO`0`;````12\!
M`#X```!A+P$`J0$``*`O`0`C````2C$!`!<```!N,0$`2````(8Q`0"%````
MSS$!`#````!5,@$`%0```(8R`0`H````G#(!`"(```#%,@$`(@```.@R`0`@
M````"S,!`"4````L,P$`00```%(S`0!;````E#,!`$D```#P,P$`,0```#HT
M`0`=````;#0!`!@```"*-`$`*P```*,T`0`A````SS0!`!\```#Q-`$`*P``
M`!$U`0`F````/34!`"<```!D-0$`.@```(PU`0`=````QS4!`!$```#E-0$`
M,P```/<U`0`E````*S8!`"<```!1-@$`(````'DV`0`?````FC8!`#````"Z
M-@$`:0```.LV`0`Q````53<!`$$```"'-P$`,P```,DW`0`E````_3<!`#T`
M```C.`$`90```&$X`0!-````QS@!`"\````5.0$`+@```$4Y`0`I````=#D!
M`#````">.0$`+````,\Y`0!4````_#D!`%H```!1.@$`*````*PZ`0`F````
MU3H!`$@```#\.@$`2@```$4[`0`K````D#L!`!X```"\.P$`,@```-L[`0`O
M````#CP!`"P````^/`$`+0```&L\`0!Q````F3P!`&8````+/0$`;P```'(]
M`0"S````XCT!`!<```"6/@$`)0```*X^`0`R````U#X!`"D````'/P$`/@``
M`#$_`0`B````<#\!`%(```"3/P$`(@```.8_`0`E````"4`!``L````O0`$`
ML0```#M``0!%````[4`!`"$````S00$`,````%5!`0`E````AD$!`!P```"L
M00$`,0```,E!`0`'````^T$!``<````#0@$`!`````M"`0`-````$$(!``L`
M```>0@$`#@```"I"`0`+````.4(!``4```!%0@$`$````$M"`0`"````7$(!
M`%D```!?0@$`!0```+E"`0`2````OT(!``0```#20@$`!P```-="`0`(````
MWT(!``4```#H0@$``P```.Y"`0`0````\D(!``P````#0P$`$P```!!#`0`-
M````)$,!``(````R0P$`!P```#5#`0`&````/4,!`!0```!$0P$`#````%E#
M`0`8````9D,!``8```!_0P$`$@```(9#`0`,````F4,!``,```"F0P$`*@``
M`*I#`0`$````U4,!``8```#:0P$`!P```.%#`0`?````Z4,!`#4````)1`$`
M+@```#]$`0`O````;D0!`!<```">1`$`(@```+9$`0`E````V40!`"````#_
M1`$`&P```"!%`0`8````/$4!`"0```!510$`'P```'I%`0`:````FD4!`"$`
M``"U10$`(````-=%`0`:````^$4!`#(````31@$`&0```$9&`0`:````8$8!
M`"\```![1@$`*P```*M&`0`?````UT8!`",```#W1@$`'P```!M'`0`:````
M.T<!`"$```!61P$`)0```'A'`0`F````GD<!`"4```#%1P$`)````.M'`0`8
M````$$@!`!T````I2`$`)````$=(`0`8````;$@!`"(```"%2`$`+````*A(
M`0`O````U4@!`!4````%20$`)0```!M)`0`\````04D!`!\```!^20$`(P``
M`)Y)`0`?````PDD!`"````#B20$`&@````-*`0`8````'DH!`"8````W2@$`
M'@```%Y*`0`I````?4H!`!X```"G2@$`,0```,9*`0`)````^$H!``P````"
M2P$`#`````]+`0`7````'$L!`"\````T2P$`)````&1+`0`'````B4L!``\`
M``"12P$`%````*%+`0`.````MDL!``T```#%2P$`)````--+`0`%````^$L!
M``<```#^2P$`(@````9,`0`E````*4P!`!H```!/3`$`'0```&I,`0`:````
MB$P!``<```"C3`$`QP```*M,`0`+````<TT!`!P```!_30$`%0```)Q-`0`&
M````LDT!``D```"Y30$`"P```,--`0`-````STT!`!<```#=30$`!@```/5-
M`0`S````_$T!`!,````P3@$`$P```$1.`0`'````6$X!``\```!@3@$`!P``
M`'!.`0`R````>$X!``0```"K3@$`(0```+!.`0`3````TDX!``P```#F3@$`
M$0```/-.`0`R````!4\!`!8````X3P$`"````$]/`0`=````6$\!``D```!V
M3P$`"@```(!/`0`4````BT\!``H```"@3P$`'0```*M/`0`(````R4\!`!\`
M``#23P$`"````/)/`0`:````^T\!`"<````64`$`!@```#Y0`0`5````15`!
M``<```!;4`$`"````&-0`0`)````;%`!`#\```!V4`$`!P```+90`0`/````
MOE`!``X```#.4`$`$````-U0`0`)````[E`!``D```#X4`$`"`````)1`0`3
M````"U$!``<````?40$`&0```"=1`0`*````05$!`!<```!,40$`%````&11
M`0`*````>5$!``P```"$40$`%P```)%1`0`$````J5$!`"H```"N40$`#```
M`-E1`0`1````YE$!``<```#X40$``@````!2`0`0`````U(!`!@````44@$`
M"P```"U2`0`#````.5(!``@````]4@$`!@```$92`0`'````35(!``T```!5
M4@$`"P```&-2`0`4````;U(!`!4```"$4@$`#@```)I2`0`O````J5(!`"``
M``#94@$`'````/I2`0`5````%U,!`"L````M4P$`#````%E3`0`Q````9E,!
M``4```"84P$`$@```)Y3`0`_````L5,!`!(```#Q4P$`"@````14`0`&````
M#U0!``0````65`$`!````!M4`0`*````(%0!`!,````K5`$`!0```#]4`0`&
M````150!``8```!,5`$`"````%-4`0`$````7%0!``P```!A5`$`"@```&Y4
M`0`Y````>50!`"X```"S5`$`*0```.)4`0`%````#%4!`!@````250$`&0``
M`"M5`0`?````154!`!T```!E50$`$0```(-5`0`"````E54!``0```"850$`
M"@```)U5`0`&````J%4!``4```"O50$``P```+55`0`,````N54!`$4```#&
M50$`,@````Q6`0`Q````/U8!`!H```!Q5@$`-````(Q6`0`H````P58!`%,`
M``#J5@$`,@```#Y7`0`9````<5<!`'(```"+5P$`(````/Y7`0`U````'U@!
M`"$```!56`$`10```'=8`0`P````O5@!`"@```#N6`$`*````!=9`0`I````
M0%D!`"8```!J60$`)0```)%9`0`H````MUD!`"@```#@60$`(@````E:`0`K
M````+%H!`#````!86@$`$@```(E:`0`3````G%H!`!````"P6@$`>0```,%:
M`0`)````.UL!`*$```!%6P$`<P```.=;`0!\````6UP!`"L```#87`$`5```
M``1=`0`7````65T!`"<```!Q70$`%@```)E=`0`5````L%T!``\```#&70$`
M%P```-9=`0`?````[ET!``X````.7@$`0````!U>`0`?````7EX!`!P```!^
M7@$`40```)M>`0`:````[5X!`!0````(7P$`"@```!U?`0`%````*%\!``8`
M```N7P$`"````#5?`0`%````/E\!`!(```!$7P$`$````%=?`0`3````:%\!
M`!T```!\7P$`#P```)I?`0`/````JE\!`!````"Z7P$`!````,M?`0`)````
MT%\!``D```#:7P$`!P```.1?`0`+````[%\!``4```#X7P$`"P```/Y?`0`'
M````"F`!``4````28`$`%````!A@`0`.````+6`!``L````\8`$`!P```$A@
M`0`(````4&`!``\```!98`$`#````&E@`0`)````=F`!``@```"`8`$`#```
M`(E@`0`&````EF`!``\```"=8`$`!P```*U@`0`&````M6`!`!0```"\8`$`
M!@```-%@`0`,````V&`!`!$```#E8`$`"````/=@`0`$`````&$!`!D````%
M80$`$0```!]A`0`*````,6$!`!@````\80$`$P```%5A`0`<````:6$!`!$`
M``"&80$`!````)AA`0`/````G6$!``<```"M80$`!````+5A`0`9````NF$!
M``<```#480$``@```-QA`0`"````WV$!`!$```#B80$`"0```/1A`0`&````
M_F$!`!(````%8@$`%P```!AB`0`&````,&(!`"<````W8@$``@```%]B`0`$
M````8F(!``\```!G8@$`$P```'=B`0`'````BV(!``D```"38@$`!P```)UB
M`0`1````I6(!``8```"W8@$`&````+YB`0`&````UV(!`!,```#>8@$`$```
M`/)B`0`2`````V,!``(````68P$`!@```!EC`0`,````(&,!``D````M8P$`
M$0```#=C`0`B````26,!``<```!L8P$`!P```'1C`0`+````?&,!``4```"(
M8P$`!0```(YC`0`"````E&,!``L```"78P$`I0$``*-C`0`0````264!`!4`
M``!:90$`#0```'!E`0`'````?F4!``D```"&90$`"````)!E`0`#````F64!
M`!@```"=90$`'@```+9E`0`O````U64!`"L````%9@$`*0```#%F`0`M````
M6V8!`!D```")9@$`*@```*-F`0`*````SF8!`!X```#99@$`#````/AF`0`2
M````!6<!``H````89P$`%P```"-G`0`%````.V<!`"@```!!9P$`$@```&IG
M`0`.````?6<!`!,```",9P$`#0```*!G`0`*````KF<!``T```"Y9P$`(```
M`,=G`0"2````Z&<!`!````![:`$`"@```(QH`0`2````EV@!``T```"J:`$`
M&P```+AH`0`,````U&@!``\```#A:`$`%@```/%H`0`&````"&D!`)D````/
M:0$`"````*EI`0`-````LFD!`!@```#`:0$`#P```-EI`0`*````Z6D!`!``
M``#T:0$`$`````5J`0`(````%FH!`!`````?:@$`/````#!J`0`5````;6H!
M`$,```"#:@$`20```,=J`0!5````$6L!`$T```!G:P$`<@```+5K`0!J````
M*&P!`$8```"3;`$`$````-IL`0`6````ZVP!``X````";0$`$````!%M`0`2
M````(FT!``4````U;0$`!@```#MM`0`1````0FT!``@```!4;0$`"0```%UM
M`0`)````9VT!`"4```!Q;0$`(P```)=M`0`B````NVT!`"(```#>;0$`*```
M``%N`0`C````*FX!`!````!.;@$`#@```%]N`0`1````;FX!``8```"`;@$`
M"0```(=N`0`;````D6X!`"$```"M;@$`#@```,]N`0`4````WFX!`!@```#S
M;@$`)0````QO`0`J````,F\!`!H```!=;P$`$P```'AO`0`0````C&\!`!<`
M``"=;P$`#0```+5O`0`U````PV\!`",```#Y;P$`)@```!UP`0`1````1'`!
M`%@```!6<`$`-@```*]P`0`=````YG`!`"4````$<0$`"````"IQ`0`5````
M,W$!`#<```!)<0$`#0```(%Q`0`(````CW$!``L```"8<0$`!P```*1Q`0`'
M````K'$!``<```"T<0$`!P```+QQ`0`,````Q'$!``4```#1<0$`&P```-=Q
M`0`,````\W$!`!``````<@$`$@```!%R`0`<````)'(!`"\```!!<@$`"0``
M`'%R`0`6````>W(!`!8```"2<@$`&````*ER`0`>````PG(!`!0```#A<@$`
M$@```/9R`0`/````"7,!`"$````9<P$`'0```#MS`0`'````67,!``8```!A
M<P$`"````&AS`0`-````<7,!``@```!_<P$`"0```(AS`0`2````DG,!``D`
M``"E<P$`$P```*]S`0`8````PW,!`"H```#<<P$`!P````=T`0`2````#W0!
M``4````B=`$`%@```"AT`0`2````/W0!``\```!2=`$`0@```&)T`0`Z````
MI70!``D```#@=`$`!P```.IT`0`3````\G0!``0````&=0$`!0````MU`0`*
M````$74!``T````<=0$`"@```"IU`0`7````-74!`$,```!-=0$`%0```)%U
M`0`D````IW4!`"L```#,=0$`*@```/AU`0`P````(W8!``D```!4=@$`!@``
M`%YV`0`)````978!``<```!O=@$`.P```'=V`0`]````LW8!`#H```#Q=@$`
M7P```"QW`0`Y````C'<!`#D```#&=P$`10````!X`0!%````1G@!`#D```",
M>`$`4@```,9X`0`J````&7D!`"P```!$>0$`20```'%Y`0`Y````NWD!`#\`
M``#U>0$`)0```#5Z`0`5````6WH!`!D```!Q>@$`+````(MZ`0`F````N'H!
M`"8```#?>@$`%P````9[`0`3````'GL!``H````R>P$`$0```#U[`0`8````
M3WL!`"(```!H>P$`!0```(M[`0`,````D7L!`!D```">>P$`&P```+A[`0`'
M````U'L!``<```#<>P$`%0```.1[`0`*````^GL!``@````%?`$`-`````Y\
M`0`0````0WP!``H```!4?`$`!P```%]\`0`&````9WP!``4```!N?`$`"```
M`'1\`0`%````?7P!``L```"#?`$`,@```(]\`0`6````PGP!``T```#9?`$`
M!P```.=\`0`'````[WP!``D```#W?`$`!0````%]`0`1````!WT!``8````9
M?0$`%````"!]`0`%````-7T!``@````[?0$`!@```$1]`0`+````2WT!``8`
M``!7?0$`(@```%Y]`0`&````@7T!``@```"(?0$`%````)%]`0`,````IGT!
M``<```"S?0$``P```+M]`0`#````OWT!`!H```##?0$``P```-Y]`0`:````
MXGT!`"T```#]?0$`!@```"M^`0`%````,GX!``@````X?@$`"````$%^`0!:
M````2GX!`"$```"E?@$`/````,=^`0`L````!'\!`"$````Q?P$`!@```%-_
M`0`(````6G\!`!X```!C?P$`)@```()_`0`Q````J7\!`#8```#;?P$`*```
M`!*``0`O````.X`!`&T```!K@`$`.@```-F``0`*````%($!``8````?@0$`
M"0```":!`0`2````,($!``D```!#@0$`#````$V!`0`0````6H$!`!8```!K
M@0$`$0```(*!`0`6````E($!`!8```"K@0$`$````,*!`0`5````TX$!``8`
M``#I@0$`&P```/"!`0`;````#((!`!<````H@@$`&P```$""`0`8````7((!
M``8```!U@@$`!P```'R"`0`0````A((!`%P```"5@@$`/@```/*"`0!@````
M,8,!``0```"2@P$`$@```)>#`0`%````JH,!``4```"P@P$`'````+:#`0`9
M````TX,!`!0```#M@P$`$0````*$`0`2````%(0!`!H````GA`$`.@```$*$
M`0!.````?80!`"(```#,A`$`#P```.^$`0`O````_X0!``8````OA0$`$0``
M`#:%`0`4````2(4!``\```!=A0$`$P```&V%`0`/````@84!`!@```"1A0$`
M$@```*J%`0`5````O84!`!,```#3A0$`#0```.>%`0`&````]84!`!(```#\
MA0$`!P````^&`0`.````%X8!`!8````FA@$`#P```#V&`0`(````388!``,`
M``!6A@$`$````%J&`0`.````:X8!``4```!ZA@$`$P```("&`0`*````E(8!
M``<```"?A@$`$````*>&`0`(````N(8!``0```#!A@$`!P```,:&`0`'````
MSH8!``P```#6A@$`"````..&`0`)````[(8!`!H```#VA@$`/@```!&'`0`F
M````4(<!``T```!WAP$`$````(6'`0`%````EH<!`!\```"<AP$`$0```+R'
M`0`2````SH<!`#(```#AAP$`0@```!2(`0`A````5X@!``@```!YB`$`1P``
M`(*(`0`H````RH@!`!````#SB`$`"0````2)`0`*````#HD!``8````9B0$`
M!@```"")`0`2````)XD!``X````ZB0$`"P```$F)`0`*````58D!``\```!@
MB0$`+````'")`0`G````G8D!`#0```#%B0$`+P```/J)`0`F````*HH!`"L`
M``!1B@$`)@```'V*`0`E````I(H!`#T```#*B@$`,@````B+`0`I````.XL!
M`"\```!EBP$`)@```)6+`0`T````O(L!`$8```#QBP$`00```#B,`0`]````
M>HP!`#T```"XC`$`1P```/:,`0`L````/HT!`"@```!KC0$`1@```)2-`0`J
M````VXT!`!H````&C@$`-0```"&.`0`H````5XX!`"P```"`C@$`&````*V.
M`0#)````QHX!`!P```"0CP$`,@```*V/`0`R````X(\!`#0````3D`$`,0``
M`$B0`0`I````>I`!`"H```"DD`$`*@```,^0`0`R````^I`!`#4````MD0$`
M20```&.1`0`[````K9$!`*D```#ID0$`+````).2`0`E````P)(!`"@```#F
MD@$`-@````^3`0`R````1I,!`%D```!YDP$`3@```-.3`0`-````(I0!``0`
M```PE`$`!@```#64`0`%````/)0!``T```!"E`$`#@```%"4`0`0````7Y0!
M``8```!PE`$`%0```'>4`0`;````C90!``<```"IE`$`!````+&4`0`.````
MMI0!``X```#%E`$`"@```-24`0`-````WY0!`!,```#ME`$`"P````&5`0`0
M````#94!``P````>E0$`-@```"N5`0`&````8I4!``X```!IE0$`!@```'B5
M`0`1````?Y4!`!<```"1E0$`&P```*F5`0`0````Q94!``(```#6E0$`2@``
M`-F5`0`+````))8!`!4````PE@$`&@```$:6`0`$````898!`!,```!FE@$`
M#P```'J6`0`#````BI8!``\```".E@$`"````)Z6`0`0````IY8!`!````"X
ME@$`!@```,F6`0`*````T)8!`!$```#;E@$`%0```.V6`0`,`````Y<!`!T`
M```0EP$`'````"Z7`0`*````2Y<!``<```!6EP$`#@```%Z7`0`4````;9<!
M``T```""EP$`"P```)"7`0`1````G)<!`!H```"NEP$`(@```,F7`0`.````
M[)<!``X```#[EP$`(P````J8`0`<````+I@!`#P```!+F`$`#0```(B8`0`>
M````EI@!`!8```"UF`$`%0```,R8`0`5````XI@!`#0```#XF`$`#P```"V9
M`0`)````/9D!``L```!'F0$`$P```%.9`0`)````9YD!``H```!QF0$`-0``
M`'R9`0`W````LID!``\```#JF0$`$````/J9`0`E````"YH!`!(````QF@$`
M(````$2:`0`@````99H!``D```"&F@$`&P```)":`0`2````K)H!`!D```"_
MF@$`%0```-F:`0`.````[YH!`!D```#^F@$`!P```!B;`0`+````()L!`"8`
M```LFP$`,@```%.;`0!(````AIL!``H```#/FP$`%````-J;`0`?````[YL!
M``8````/G`$`"0```!:<`0`P````()P!`!````!1G`$`!@```&*<`0`'````
M:9P!`%0```!QG`$``P```,:<`0`'````RIP!``8```#2G`$`"P```-F<`0`,
M````Y9P!``P```#RG`$`#P```/^<`0`0````#YT!`!$````@G0$`&0```#*=
M`0`9````3)T!`!$```!FG0$`&0```'B=`0`9````DIT!``@```"LG0$`!0``
M`+6=`0`+````NYT!``L```#'G0$``@```-.=`0`&````UIT!`!(```#=G0$`
M)P```/"=`0`8````&)X!`!D````QG@$`"0```$N>`0`2````59X!`!,```!H
MG@$`%````'R>`0`<````D9X!`$8```"NG@$`+P```/6>`0`,````)9\!``\`
M```RGP$`B@```$*?`0`<````S9\!`!@```#JGP$`$`````.@`0`(````%*`!
M``0````=H`$`%P```"*@`0`K````.J`!`"@```!FH`$`&@```(^@`0`=````
MJJ`!`!$```#(H`$`$P```-J@`0`'````[J`!``<```#VH`$`!@```/Z@`0`&
M````!:$!``\````,H0$`#@```!RA`0`0````*Z$!``X````\H0$`#````$NA
M`0`.````6*$!``L```!GH0$`$P```'.A`0`(````AZ$!``@```"0H0$`%@``
M`)FA`0`,````L*$!`#4```"]H0$`$0```/.A`0`(````!:(!``@````.H@$`
M$@```!>B`0`5````*J(!`"4```!`H@$`#P```&:B`0`;````=J(!`",```"2
MH@$`(@```+:B`0`8````V:(!`!H```#RH@$`)0````VC`0`9````,Z,!`!(`
M``!-HP$`!0```&"C`0`9````9J,!``L```"`HP$`"P```(RC`0`#````F*,!
M``4```"<HP$`"0```**C`0`0````K*,!`!(```"]HP$`$0```-"C`0`*````
MXJ,!``\```#MHP$`#@```/VC`0`,````#*0!``0````9I`$`!P```!ZD`0`@
M````)J0!`"$```!'I`$`%P```&FD`0`/````@:0!`!(```"1I`$`$````*2D
M`0`B````M:0!``<```#8I`$`"0```."D`0`/````ZJ0!``\```#ZI`$`"0``
M``JE`0`%````%*4!``H````:I0$`!0```"6E`0`3````*Z4!``P````_I0$`
M!@```$RE`0`I````4Z4!``X```!]I0$`@P```(RE`0`1````$*8!``L````B
MI@$`!0```"ZF`0`-````-*8!``8```!"I@$`"````$FF`0`&````4J8!`!$`
M``!9I@$``P```&NF`0`'````;Z8!``8```!WI@$`%````'ZF`0`/````DZ8!
M`!(```"CI@$`'````+:F`0`"````TZ8!``4```#6I@$`$@```-RF`0`)````
M[Z8!``T```#YI@$`!0````>G`0`@````#:<!``@````NIP$`!@```#>G`0`-
M````/J<!`!H```!,IP$`#0```&>G`0`'````=:<!``@```!]IP$`!````(:G
M`0`)````BZ<!``T```"5IP$`#@```*.G`0`"````LJ<!``8```"UIP$`#```
M`+RG`0`3````R:<!`!````#=IP$`!@```.ZG`0`2````]:<!``H````(J`$`
M!P```!.H`0`7````&Z@!`"D````SJ`$`2@```%VH`0`G````J*@!`"D```#0
MJ`$`!@```/JH`0`)`````:D!``0````+J0$`"0```!"I`0`(````&JD!`!<`
M```CJ0$`$````#NI`0`%````3*D!``P```!2J0$`!@```%^I`0`$````9JD!
M`$$```!KJ0$`0@```*VI`0!!````\*D!`"$````RJ@$`!0```%2J`0`.````
M6JH!``<```!IJ@$`"0```'&J`0`)````>ZH!`!L```"%J@$`$````*&J`0`5
M````LJH!``8```#(J@$`!0```,^J`0`/````U:H!``H```#EJ@$`"@```/"J
M`0`>````^ZH!``0````:JP$`!P```!^K`0`D````)ZL!``8```!,JP$`%```
M`%.K`0`1````:*L!`!````!ZJP$`"````(NK`0`)````E*L!``4```">JP$`
M.P```*2K`0`V````X*L!`$,````7K`$`*0```%NL`0!"````A:P!`$(```#(
MK`$`*P````NM`0!*````-ZT!`"\```""K0$`.0```+*M`0`O````[*T!`!``
M```<K@$`$0```"VN`0`+````/ZX!`"T```!+K@$`*0```'FN`0`A````HZX!
M`"@```#%K@$`!P```.ZN`0`)````]JX!``H`````KP$`!P````NO`0`D````
M$Z\!`"8````XKP$`+0```%^O`0`+````C:\!`!L```"9KP$`+0```+6O`0`8
M````XZ\!`!,```#\KP$`"````!"P`0`.````&;`!``X````HL`$`#@```#>P
M`0`3````1K`!`$0```!:L`$`?@```)^P`0!Q````'K$!`!L```"0L0$`#0``
M`*RQ`0`.````NK$!`!$```#)L0$`$@```-NQ`0`/````[K$!``<```#^L0$`
M'`````:R`0`2````([(!`!L````VL@$`$P```%*R`0`2````9K(!`!,```!Y
ML@$`*````(VR`0`>````MK(!`(0```#5L@$`$@```%JS`0`%````;;,!`!0`
M``!SLP$`"0```(BS`0`*````DK,!``H```"=LP$`'P```*BS`0`4````R+,!
M``X```#=LP$`#@```.RS`0`3````^[,!`!4````/M`$`)````"6T`0`F````
M2K0!`",```!QM`$`)0```)6T`0`A````N[0!`",```#=M`$`'0````&U`0!%
M````'[4!`!,```!EM0$`%````'FU`0`3````CK4!`!0```"BM0$`$0```+>U
M`0`6````R;4!`!<```#@M0$`$@```/BU`0`3````"[8!`#P````?M@$`%@``
M`%RV`0`4````<[8!`#X```"(M@$`%0```,>V`0`.````W;8!`!$```#LM@$`
M+0```/ZV`0`3````++<!`!,```!`MP$`(````%2W`0`=````=;<!`!\```"3
MMP$`'0```+.W`0`;````T;<!`"$```#MMP$`'`````^X`0`C````++@!`"$`
M``!0N`$`(````'*X`0`@````D[@!`!T```"TN`$`$P```-*X`0`;````YK@!
M`!T````"N0$`&P```""Y`0`8````/+D!``H```!5N0$`$````&"Y`0`:````
M<;D!``8```",N0$`!P```).Y`0`-````F[D!`!0```"IN0$`!@```+ZY`0`'
M````Q;D!``<```#-N0$`!@```-6Y`0`'````W+D!``<```#DN0$`!0```.RY
M`0`5````\KD!``8````(N@$`"`````^Z`0`%````&+H!``4````>N@$`"@``
M`"2Z`0`1````+[H!``H```!!N@$`$@```$RZ`0`1````7[H!``L```!QN@$`
M$@```'VZ`0`&````D+H!`"H```"7N@$`$0```,*Z`0`0````U+H!`!H```#E
MN@$`$`````"[`0`-````$;L!``P````?NP$`+P```"R[`0`(````7+L!``@`
M``!ENP$`*````&Z[`0`4````E[L!`!````"LNP$`!@```+V[`0`+````Q+L!
M``<```#0NP$`!@```-B[`0`A````W[L!``T````!O`$`$@````^\`0`0````
M(KP!``T````SO`$`$P```$&\`0`0````5;P!`!\```!FO`$`$P```(:\`0`'
M````FKP!``,```"BO`$`!@```*:\`0`?````K;P!``8```#-O`$`"````-2\
M`0`2````W;P!`!,```#PO`$`!@````2]`0`$````"[T!``<````0O0$`%@``
M`!B]`0`-````+[T!``T````]O0$`"P```$N]`0`4````5[T!`!8```!LO0$`
M%P```(.]`0`9````F[T!``H```"UO0$`#0```,"]`0`&````SKT!``0```#5
MO0$`$0```-J]`0`[````[+T!``4````HO@$`#P```"Z^`0`A````/KX!`!8`
M``!@O@$`%P```'>^`0`.````C[X!``P```">O@$`"0```*N^`0`'````M;X!
M``H```"]O@$`"0```,B^`0`.````TKX!`!````#AO@$`(````/*^`0`A````
M$[\!`"<````UOP$`"@```%V_`0`(````:+\!``T```!QOP$`#````'^_`0`2
M````C+\!``8```"?OP$`"````*:_`0`G````K[\!``L```#7OP$`"````.._
M`0`2````[+\!`#P```#_OP$`#P```#S``0`+````3,`!``0```!8P`$`!0``
M`%W``0`;````8\`!`!P```!_P`$`'````)S``0`*````N<`!``(```#$P`$`
M!````,?``0`A````S,`!``,```#NP`$`!0```/+``0`I````^,`!``H````B
MP0$`!@```"W!`0`'````-,$!`!@````\P0$`#@```%7!`0`&````9,$!``<`
M``!KP0$`"````'/!`0`$````?,$!``4```"!P0$`/````(?!`0`0````Q,$!
M`!,```#5P0$`%0```.G!`0`%````_\$!``8````%P@$`'@````S"`0`S````
M*\(!``X```!?P@$`"0```&["`0`6````>,(!``H```"/P@$`"````)K"`0`9
M````H\(!`"P```"]P@$`*0```.K"`0`H````%,,!`!H````]PP$`(0```%C#
M`0`.````>L,!``0```")PP$`!P```([#`0`(````EL,!``<```"?PP$`$@``
M`*?#`0`-````NL,!``\```#(PP$`"````-C#`0!7````X<,!`!(````YQ`$`
M$````$S$`0`+````7<0!`!L```!IQ`$`4````(7$`0`=````UL0!``8```#T
MQ`$`'0```/O$`0`G````&<4!``<```!!Q0$`!@```$G%`0`@````4,4!``0`
M``!QQ0$`"0```';%`0`I````@,4!`"@```"JQ0$`)P```-/%`0`'````^\4!
M``@````#Q@$`(@````S&`0!9````+\8!`!@```")Q@$`)@```*+&`0`6````
MR<8!``,```#@Q@$`#0```.3&`0`'````\L8!``\```#ZQ@$`"P````K'`0`,
M````%L<!``8````CQP$`%0```"K'`0`&````0,<!``@```!'QP$`"0```%#'
M`0`+````6L<!``H```!FQP$`#````'''`0`]````?L<!``@```"\QP$`$@``
M`,7'`0`4````V,<!`!<```#MQP$`#`````7(`0`0````$L@!``\````CR`$`
M"P```#/(`0`&````/\@!``4```!&R`$`"@```$S(`0`E````5\@!`!<```!]
MR`$`$````)7(`0`+````IL@!`!````"RR`$`$````,/(`0`*````U,@!`!0`
M``#?R`$`"````/3(`0`4````_<@!``0````2R0$`!P```!?)`0`%````'\D!
M``4````ER0$`!P```"O)`0`3````,\D!`!0```!'R0$`(@```%S)`0`B````
M?\D!`!P```"BR0$`'````+_)`0`@````W,D!`"4```#]R0$`'P```"/*`0`$
M````0\H!``4```!(R@$`#@```$[*`0`.````7<H!`!4```!LR@$`"````(+*
M`0`-````B\H!`!<```"9R@$`#0```+'*`0`*````O\H!`!H```#*R@$`'P``
M`.7*`0`4````!<L!``@````:RP$`$@```"/+`0`'````-LL!`!`````^RP$`
M#P```$_+`0`(````7\L!``D```!HRP$`!0```'++`0`'````>,L!``4```"`
MRP$`!````(;+`0`#````B\L!`$$```"/RP$`-0```-'+`0`7````!\P!`"D`
M```?S`$`.0```$G,`0`2````@\P!`#@```"6S`$`.````,_,`0`]````",T!
M`#T```!&S0$`0@```(3-`0`8````Q\T!`!D```#@S0$`%@```/K-`0`E````
M$<X!`!@````WS@$`(````%#.`0`@````<<X!`!L```"2S@$`&0```*[.`0`V
M````R,X!`!````#_S@$`+P```!#/`0`<````0,\!`!L```!=SP$`%````'G/
M`0`Q````CL\!`#$```#`SP$`-0```/+/`0`R````*-`!`#,```!;T`$`,```
M`(_0`0!W````P-`!`!D````XT0$`%@```%+1`0`*````:=$!`"(```!TT0$`
M"0```)?1`0`3````H=$!`#0```"UT0$`)0```.K1`0`@````$-(!``L````Q
MT@$`40```#W2`0!-````C](!``D```#=T@$`!P```.?2`0`7````[](!`!4`
M```'TP$`#````!W3`0`0````*M,!`!8````[TP$`!P```%+3`0`(````6M,!
M``D```!CTP$`$@```&W3`0`1````@-,!``\```"2TP$`#@```*+3`0`5````
ML=,!`!0```#'TP$`%0```-S3`0`1````\M,!`!(````$U`$`&````!?4`0`/
M````,-0!`!<```!`U`$`#P```%C4`0`F````:-0!``D```"/U`$`%````)G4
M`0`8````KM0!``@```#'U`$`!@```-#4`0`4````U]0!`!$```#LU`$`$```
M`/[4`0!"````#]4!``(```!2U0$`!@```%75`0`1````7-4!``4```!NU0$`
M!P```'35`0`/````?-4!``H```",U0$`*@```)?5`0`,````PM4!`!X```#/
MU0$``P```.[5`0`W````\M4!`!@````JU@$`*````$/6`0"&````;-8!`!@`
M``#SU@$`00````S7`0`A````3M<!`!,```!PUP$`!@```(37`0`,````B]<!
M``X```"8UP$`"P```*?7`0`6````L]<!``L```#*UP$`'````-;7`0`6````
M\]<!``4````*V`$`$@```!#8`0`:````(]@!`"4````^V`$`$P```&38`0`6
M````>-@!`!P```"/V`$`$0```*S8`0`F````OM@!``H```#EV`$`%````/#8
M`0`6````!=D!`!`````<V0$`$@```"W9`0`/````0-D!`!(```!0V0$`#P``
M`&/9`0`5````<]D!`!X```")V0$`%0```*C9`0`&````OMD!``D```#%V0$`
M!0```,_9`0`=````U=D!``8```#SV0$`$````/K9`0`(````"]H!`!0````4
MV@$`!0```"G:`0`;````+]H!``\```!+V@$`+0```%O:`0`5````B=H!``8`
M``"?V@$`!P```*;:`0`8````KMH!``4```#'V@$`'@```,W:`0`$````[-H!
M`!0```#QV@$`!P````;;`0`+````#ML!`"`````:VP$`+0```#O;`0`)````
M:=L!`!P```!SVP$`$````)#;`0`*````H=L!`!L```"LVP$`%````,C;`0`$
M````W=L!`!0```#BVP$`"0```/?;`0`(`````=P!``4````*W`$`"````!#<
M`0`&````&=P!``8````@W`$`(0```"?<`0`W````2=P!`#\```"!W`$`(@``
M`,'<`0`P````Y-P!`"@````5W0$`10```#[=`0`B````A-T!`"@```"GW0$`
M)0```-#=`0!5````]MT!`"H```!,W@$`!P```'?>`0`(````?]X!``<```"(
MW@$`"````)#>`0`4````F=X!`!0```"NW@$`,````,/>`0`M````]-X!`!@`
M```BWP$`-0```#O?`0`]````<=\!``<```"OWP$`&0```+??`0`)````T=\!
M`!````#;WP$`(@```.S?`0`1````#^`!`!(````AX`$`#0```#3@`0`(````
M0N`!`!4```!+X`$`"````&'@`0`+````:N`!``T```!VX`$`&@```(3@`0`-
M````G^`!`#P```"MX`$`"@```.K@`0`%````]>`!``D```#[X`$`!0````7A
M`0`:````"^$!`!$````FX0$`!0```#CA`0`.````/N$!`!````!-X0$`$0``
M`%[A`0`,````<.$!``\```!]X0$`#P```(WA`0`'````G>$!``,```"EX0$`
M#0```*GA`0`Z````M^$!`"````#RX0$`3@```!/B`0`5````8N(!``D```!X
MX@$`)@```(+B`0`/````J>(!`!T```"YX@$`!0```-?B`0`5````W>(!``,`
M``#SX@$`"P```/?B`0`2`````^,!`"H````6XP$`!P```$'C`0`-````2>,!
M`!$```!7XP$`#@```&GC`0`2````>.,!``L```"+XP$`.P```)?C`0`)````
MT^,!`!P```#=XP$`#P```/KC`0`3````"N0!`#\````>Y`$`+@```%[D`0`Y
M````C>0!`#H```#'Y`$`-@````+E`0`1````.>4!``8```!+Y0$`$````%+E
M`0`0````8^4!``T```!TY0$`"@```(+E`0`1````C>4!`!T```"?Y0$`!P``
M`+WE`0`5````Q>4!`!H```#;Y0$`"````/;E`0`'````_^4!`!$````'Y@$`
M$@```!GF`0`9````+.8!``8```!&Y@$`!P```$WF`0`/````5>8!`!4```!E
MY@$`%````'OF`0`5````D.8!`!4```"FY@$`!P```+SF`0`&````Q.8!`#$`
M``#+Y@$`)P```/WF`0`F````)><!``@```!,YP$`#P```%7G`0`&````9><!
M`!\```!LYP$`(0```(SG`0`F````KN<!``L```#5YP$`%````.'G`0`F````
M]N<!``,````=Z`$`!P```"'H`0`5````*>@!``,````_Z`$`#````$/H`0`1
M````4.@!``L```!BZ`$`%````&[H`0`8````@^@!`!0```"<Z`$`!0```+'H
M`0`*````M^@!`!,```#"Z`$`%````-;H`0`.````Z^@!``8```#ZZ`$`"0``
M``'I`0`)````"^D!``T````5Z0$`6@```"/I`0`6````?ND!`#4```"5Z0$`
M%````,OI`0`'````X.D!``D```#HZ0$`%````/+I`0`6````!^H!`!(````>
MZ@$`$````#'J`0`5````0NH!`!(```!8Z@$`(0```&OJ`0`8````C>H!`!L`
M``"FZ@$`%0```,+J`0`C````V.H!`!````#\Z@$`)P````WK`0`3````->L!
M`!4```!)ZP$`'0```%_K`0!P````?>L!`"$```#NZP$`'````!#L`0`B````
M+>P!`"(```!0[`$`*0```'/L`0`M````G>P!`"$```#+[`$`'````.WL`0`F
M````"NT!`!\````Q[0$`'P```%'M`0`8````<>T!`!P```"*[0$`"@```*?M
M`0`'````LNT!``@```"Z[0$`"````,/M`0`3````S.T!``\```#@[0$`+0``
M`/#M`0`7````'NX!`!4````V[@$`!P```$SN`0`'````5.X!`$\```!<[@$`
M20```*SN`0`^````]NX!`&8````U[P$`#````)SO`0`R````J>\!`#````#<
M[P$`"0````WP`0`'````%_`!``8````?\`$`0````";P`0`&````9_`!`!8`
M``!N\`$`0````(7P`0`T````QO`!`"````#[\`$`(@```!SQ`0`C````/_$!
M``X```!C\0$`+0```'+Q`0`<````H/$!`#,```"]\0$`*````/'Q`0`R````
M&O(!`"@```!-\@$`#0```';R`0`&````A/(!``\```"+\@$`$@```)OR`0`5
M````KO(!``<```#$\@$`0@```,SR`0`*````#_,!``D````:\P$`"@```"3S
M`0`7````+_,!``D```!'\P$`!P```%'S`0`2````6?,!``H```!L\P$`"0``
M`'?S`0`$````@?,!``<```"&\P$`"````([S`0`/````E_,!`!0```"G\P$`
M%@```+SS`0`=````T_,!``T```#Q\P$`!P```/_S`0`0````!_0!`!4````8
M]`$`'@```"[T`0`/````3?0!`!(```!=]`$`#0```'#T`0`8````?O0!`"@`
M``"7]`$`#@```,#T`0`?````S_0!`"D```#O]`$`"0```!GU`0`+````(_4!
M`!0````O]0$`!P```$3U`0`$````3/4!`!\```!1]0$`#@```''U`0`.````
M@/4!``T```"/]0$`"````)WU`0`)````IO4!``8```"P]0$`"0```+?U`0`+
M````P?4!`!,```#-]0$`"````.'U`0`8````ZO4!``L````#]@$`!P````_V
M`0`>````%_8!`"8````V]@$`#````%WV`0`#````:O8!`"$```!N]@$`!P``
M`)#V`0`&````F/8!`'0```"?]@$`"@```!3W`0`'````'_<!`"<````G]P$`
M0````$_W`0`:````D/<!`"4```"K]P$`1````-'W`0`;````%O@!`"D````R
M^`$`/0```%SX`0`;````FO@!`!8```"V^`$`!0```,WX`0`&````T_@!``D`
M``#:^`$`"@```.3X`0`*````[_@!``D```#Z^`$`%`````3Y`0`+````&?D!
M``H````E^0$`#````##Y`0`,````/?D!``<```!*^0$`"````%+Y`0`)````
M6_D!`!0```!E^0$`"P```'KY`0`&````AOD!``4```"-^0$`"P```)/Y`0`&
M````G_D!`"8```"F^0$`&````,WY`0`*````YOD!`!8```#Q^0$`"P````CZ
M`0`4````%/H!``L````I^@$`!@```#7Z`0`6````//H!``8```!3^@$`%@``
M`%KZ`0`&````<?H!`!H```!X^@$`"P```)/Z`0`6````G_H!``4```"V^@$`
M!P```+SZ`0`2````Q/H!`"````#7^@$`"P```/CZ`0`-````!/L!`"T````2
M^P$`&P```$#[`0`8````7/L!``4```!U^P$`#0```'O[`0`4````B?L!`!<`
M``">^P$``P```+;[`0`3````NOL!``D```#.^P$`(P```-C[`0`I````_/L!
M`#,````F_`$`)0```%K\`0`T````@/P!`"<```"U_`$`:0```-W\`0`7````
M1_T!`&<```!?_0$`0@```,?]`0!4````"OX!`&X```!?_@$`+0```,[^`0`[
M````_/X!`#,````X_P$`.````&S_`0`N````I?\!`!L```#4_P$`-````/#_
M`0#7`0``)0`"`!\```#]`0(`%P```!T"`@!*````-0("`'<```"``@(`,P``
M`/@"`@`8````+`,"`"T```!%`P(`(0```',#`@`C````E0,"`"````"Y`P(`
M)0```-H#`@!!``````0"`%P```!"!`(`6@```)\$`@`J````^@0"`",````E
M!0(`%@```$D%`@`H````8`4"`!T```")!0(`&@```*<%`@`M````P@4"`"4`
M``#P!0(`)0```!8&`@`Z````/`8"`",```!W!@(`%@```)L&`@`X````L@8"
M`"4```#K!@(`*@```!$'`@`M````/`<"`!\```!J!P(`.````(H'`@!M````
MPP<"`#$````Q"`(`0@```&,(`@`N````I@@"`"<```#5"`(`0````/T(`@!C
M````/@D"`$@```"B"0(`+@```.L)`@`N````&@H"`"8```!)"@(`*0```'`*
M`@`I````F@H"`%\```#$"@(`;P```"0+`@`G````E`L"`"8```"\"P(`6```
M`.,+`@!9````/`P"`#,```"6#`(`)````,H,`@`U````[PP"`"H````E#0(`
M*@```%`-`@`O````>PT"`&L```"K#0(`<0```!<.`@!Q````B0X"`+D```#[
M#@(`&0```+4/`@`O````SP\"`#````#_#P(`+0```#`0`@!2````7A`"`"4`
M``"Q$`(`4P```-<0`@`H````*Q$"`"(```!4$0(`"@```'<1`@#8````@A$"
M`%@```!;$@(`(P```+02`@`X````V!("`"@````1$P(`'@```#H3`@`Y````
M61,"``0```"3$P(`"````)@3`@`$````H1,"`!D```"F$P(`#P```,`3`@`/
M````T!,"``L```#@$P(`!@```.P3`@`/````\Q,"``0````#%`(`6`````@4
M`@`$````810"`!<```!F%`(`!````'X4`@`'````@Q0"``8```"+%`(`!0``
M`)(4`@`$````F!0"`!4```"=%`(`"0```+,4`@`1````O10"`!,```#/%`(`
M`P```.,4`@`'````YQ0"``<```#O%`(`$@```/<4`@`-````"A4"`!0````8
M%0(`!@```"T5`@`:````-!4"``T```!/%0(``P```%T5`@`K````814"``0`
M``"-%0(`!@```)(5`@`'````F14"`"$```"A%0(`0````,,5`@`Q````!!8"
M`#(````V%@(`&P```&D6`@`R````A18"`#4```"X%@(`)````.X6`@`C````
M$Q<"`!X````W%P(`)````%87`@`?````>Q<"`!T```";%P(`)0```+D7`@`C
M````WQ<"`!X````#&`(`-````"(8`@`;````5Q@"`!P```!S&`(`,0```)`8
M`@`R````PA@"`"$```#U&`(`)0```!<9`@`D````/1D"`!\```!B&0(`)```
M`((9`@`J````IQD"`"@```#2&0(`*@```/L9`@`F````)AH"`!\```!-&@(`
M(@```&T:`@`K````D!H"`!T```"\&@(`)````-H:`@`O````_QH"`#(````O
M&P(`&@```&(;`@`G````?1L"`#P```"E&P(`)````.(;`@`F````!QP"`"4`
M```N'`(`)@```%0<`@`@````>QP"`!X```"<'`(`)P```+L<`@`C````XQP"
M`"X````''0(`)P```#8=`@`N````7AT"``H```"-'0(`$P```)@=`@`3````
MK!T"`!8```#`'0(`,P```-<=`@`F````"QX"``T````R'@(`#P```$`>`@`6
M````4!X"``L```!G'@(`#@```',>`@`L````@AX"``@```"O'@(`#````+@>
M`@`G````Q1X"`"H```#M'@(`(````!@?`@`?````.1\"`!P```!9'P(`"```
M`'8?`@#4````?Q\"``T```!4(`(`'@```&(@`@`6````@2`"``D```"8(`(`
M#0```*(@`@`1````L"`"`!````#"(`(`'P```-,@`@`&````\R`"`$L```#Z
M(`(`'````$8A`@`<````8R$"``<```"`(0(`$@```(@A`@`,````FR$"`#8`
M``"H(0(`"````-\A`@`G````Z"$"`!D````0(@(`$@```"HB`@`4````/2("
M`#(```!2(@(`'P```(4B`@`'````I2("`!<```"M(@(`"````,4B`@`)````
MSB("`!0```#8(@(`"P```.TB`@`;````^2("``8````5(P(`*@```!PC`@`(
M````1R,"`",```!0(P(`*P```'0C`@`'````H","`!<```"H(P(`!P```,`C
M`@`(````R","``D```#1(P(`/@```-LC`@`&````&B0"`!(````A)`(`%```
M`#0D`@`/````220"``D```!9)`(`"@```&,D`@`&````;B0"`!,```!U)`(`
M!@```(DD`@`A````D"0"`!(```"R)`(`&0```,4D`@`5````WR0"``P```#U
M)`(`#@````(E`@`:````$24"``<````L)0(`+0```#0E`@`,````8B4"``\`
M``!O)0(`!P```'\E`@`#````AR4"`!$```"+)0(`'````)TE`@`+````NB4"
M``,```#&)0(`"````,HE`@`,````TR4"``D```#@)0(`#P```.HE`@`-````
M^B4"`!8````()@(`%P```!\F`@`0````-R8"`"\```!()@(`'0```'@F`@`<
M````EB8"`!H```"S)@(`/````,XF`@`+````"R<"`#`````7)P(`!P```$@G
M`@`7````4"<"`$4```!H)P(`$0```*XG`@`2````P"<"``@```#3)P(`!```
M`-PG`@`%````X2<"`!$```#G)P(`&@```/DG`@`&````%"@"``<````;*`(`
M"0```",H`@`0````+2@"``@````^*`(`$@```$<H`@`.````6B@"`$4```!I
M*`(`-@```*\H`@`I````YB@"``4````0*0(`&0```!8I`@`D````,"D"`"(`
M``!5*0(`*````'@I`@`0````H2D"``(```"R*0(`!````+4I`@`+````NBD"
M``H```#&*0(`!0```-$I`@`#````URD"`!````#;*0(`3P```.PI`@`S````
M/"H"`#(```!P*@(`&@```*,J`@`K````OBH"`"\```#J*@(`4P```!HK`@`^
M````;BL"`!8```"M*P(`A0```,0K`@`D````2BP"`$(```!O+`(`)0```+(L
M`@!'````V"P"`"L````@+0(`.0```$PM`@`S````ABT"`"X```"Z+0(`+@``
M`.DM`@`P````&"X"`#````!)+@(`+0```'HN`@`R````J"X"`#0```#;+@(`
M-P```!`O`@`6````2"\"`"````!?+P(`$````(`O`@!\````D2\"``@````.
M,`(`<````!<P`@!R````B#`"`(````#[,`(`)@```'PQ`@!>````HS$"`!<`
M```",@(`(P```!HR`@`6````/C("`!H```!5,@(`$@```'`R`@`4````@S("
M`!P```"8,@(`%0```+4R`@!`````RS("`!X````,,P(`&0```"LS`@!0````
M13,"`!(```"6,P(`&````*DS`@`*````PC,"``4```#-,P(`!@```-,S`@`(
M````VC,"``4```#C,P(`%@```.DS`@`7`````#0"`!8````8-`(`(0```"\T
M`@`0````430"``X```!B-`(`&0```'$T`@`$````BS0"``H```"0-`(`"0``
M`)LT`@`(````I30"``\```"N-`(`!P```+XT`@`/````QC0"``<```#6-`(`
M!@```-XT`@`:````Y30"`!(`````-0(`$0```!,U`@`)````)34"``P````O
M-0(`$````#PU`@`1````334"``X```!?-0(`!P```&XU`@`+````=C4"``D`
M``""-0(`$````(PU`@`*````G34"``L```"H-0(`&@```+0U`@`)````SS4"
M`!4```#9-0(`%0```.\U`@`&````!38"``4````,-@(`(P```!(V`@`9````
M-C8"``L```!0-@(`(P```%PV`@`4````@#8"`"L```"5-@(`&0```,$V`@`&
M````VS8"`!<```#B-@(`!0```/HV`@`'`````#<"`!L````(-P(`!0```"0W
M`@`"````*C<"``(````M-P(`&P```#`W`@`(````3#<"``L```!5-P(`%0``
M`&$W`@`8````=S<"``<```"0-P(`,P```)@W`@`"````S#<"``0```#/-P(`
M$````-0W`@`6````Y3<"``X```#\-P(`#0````LX`@`+````&3@"``D````E
M.`(`!@```"\X`@`8````-C@"``@```!/.`(`%````%@X`@`1````;3@"`!(`
M``!_.`(``@```)(X`@`'````E3@"``\```"=.`(`$````*TX`@`0````OC@"
M`"P```#/.`(`"0```/PX`@`(````!CD"`!(````/.0(`!0```"(Y`@`%````
M*#D"``(````N.0(`"P```#$Y`@`!````J0<``*@$``#G`0``!@(``)\%```3
M`P```````',"``"6`@```````%0"````````0P(`````````````P`<``$@`
M``"K!@``I@4``/@$``!`!```&0$``,P```#)!0``````````````````_P8`
M``````"N`0``````````````````@`<``!\%```X!```K`$``*0#``#;`@``
M`````*T&``#D!@```````$<$``"3!@```````!H!``#3!0``"0<```````!F
M`0```````%X$````````/@,``.@"````````8@8```,"```<`0``P@,`````
M```````````````````'!P```````&(#````````=`4``)0'``"B!0``$P``
M```````D!0``OP,``&T$````````!`0``$@"``#.`@``O`,``)`%```G`P``
M`````*\#``"B````\0$``'("``#$!P```````)T#``"\```````````!``#;
M!@``5`,``%,```">!0``%P(``*0"````````W`$``(,````?!P``@@```-T!
M``!2!```4P8``/X#``#A!0``J`4``*4!``!X`P```````&<'``!H`@``.@$`
M``````!J`0````,``.8%``!9!P```````.<#``#%!P``V`0``%D#````````
MQP<``/H!``##````%P8``)0!`````````````#H```#J!```[@4``$H%```I
M`0``;0```'X$``#+`0```````/8%```U!```X0<```````"Z`@``5P8``"$!
M```O`P``U08`````````````B````+D$``!>!P``E0```(4#````````P0$`
M``````"J!````````&<"``#1!0```````+0````J!P``W`(``(4'``",`P``
M7@4``*4"``#G!P``K@<``.8$``##!0``D04``)D&``!$!@``Q@(``)$&``#/
M!0``%@8``````````````````(X!```M`P``F0,``*8&````````:P,```T"
M````````#P<``````````````````-<%``#P`P```````&P`````````"P4`
M`%<$``!!!@```````*\%``#Y`````````,<!``"_!@``,0$``)0#``"T!@``
MZP(``/(#```E!```I````/4#``#3````D@<``/<%``"6!```'0<```````!!
M!```C@<``+$%``"]!0``/P````````!5`````````+D#``"I`P``#@,````%
M```S!@```````&<$``">!```*P(``)X'``"X!@``1P$``#H#``!&`P``&@4`
M``H#``"_!P````````````!R`P```````%0'``!+!P``````````````````
MW0(``/T%``!H!````````*\$``!H````````````````````U````)$$``"4
M````-P,``&````"3````J0$``/H#``#-!P``9`8``.T"```9!P```````%L`
M``#L`P``;`8``!P$````````H0,``#`"````````3P8``-8`````````:`<`
M`"X%````````108``)\$```A!```<P```+@````[`@``/`4``+4!````````
M[@<``%P```!0!@``B`0````````5`0```````!4'```(!```7P,``)<%``!P
M!0``3P4`````````````WP,``+X#``!]!@``H@,``'T%``!X!0``LP(`````
M``#%!@``8P,```,`````````ZP<`````````````H`$``%T`````````GP$`
M``,!````````LP0``,,#```G`````````(D'````````9P$``+8'``#!!@``
MT0<```````#E````:0````````````````````0!```@!@``0P<````````;
M!0``,@8```````"<````[@$``+X"````````)04```````#W!P``/P8`````
M`````````````/`'``"Z`P``K04``&4!```"!P``<0<``-H#````````````
M`+P'``#9````````````````````G0$``'8%`````````````$T'````````
MK@,``*(!``"5`@``IP<`````````````:@(``*,"``"A!@``[0<``!P```#Z
M`@```````%4#``!W`P``+P0``"8'``",!0``"`8```````#[````4@8``,$"
M```0!0``C``````````J`@``5@```.D%``!A!```^`<``"(!```!`P``U`8`
M`/,!``````````````````"(!P```````.<$````````G0<`````````````
M%`,```````#D`0``;@(``&0!``!\!```400``$8$```L`0``_0$``$`"```A
M!@``T`4``,8%``#[!@```````.(!```>!@```````!8#``!W!```````````
M```F`0``$0,```````#^!0``BP8``%T%``#$`0``*@,``&4&```+!P``0P8`
M``D!```"`@``6@```$T%```@!P````````````":`@``5````!D%``!1`@``
MIP```+X$``!F!P``V0,```````"7!P``I04````````:!```"P0``$<&```"
M`0``A0````````!<`0``;@4``+$`````````4P(``.,%```%`P``2P$``'H&
M``!%!0``Z@```)P'```U!@``.@<```````#5`P``&P(``"\```#@````K`0`
M`#\#```<!@``[`(```@#``"N!```-`,``,<%``!+!```M@(``!``````````
M^P$``,$$````````H00```<#````````D@0``&\"``!R!0``IP8``'@!````
M````!@4``!X%````````@P0```````#C````_P(``+@%```/`P``X0```!T$
M``"7`P``;P8``"`"``#C!P``AP<``!8%``"8`P``#P`````````D!P``````
M``4"``"`!```8P4``*0$``!5`@``@P8``*,'``"T`@``<`0``)`&````````
ML`(``!\#```A!0``5`$``(D```#H!0``N0(```````#&`````````*T'````
M````,04``*T````)!@``````````````````(P<``!P'``"B!```````````
M``"8`````````$T````4!@``L0$``&<%``!A`0``:@8``/$&``#<````-`$`
M``0#``#(````K`(``+T!```D!@```````&L&``#W````R`4``-8%````````
M^`4``'H#`````````````#<&``!R!@``P@```$4'``!1`0``+````(L$``#A
M`@``@`````L&``!E````(P4``'H```#(!````````$@$````````70(``$X#
M``"]`````````.`!``#2`P```````&@&````````X`4``.@&```&`0``E00`
M``````#H!`````````@"``"G`@``1`$``#$&``#%````3`(``+\"``"F````
ML08``&4'``!*!```W00``+X'``!;!```L@8``%L'`````````````"('````
M````VP```&4$``#]!```50$``%@'```N`@``O@4``/(!``!:!@``U0$`````
M``"B!@``Z08```````!K`@``2P,```````"-!0``+P$``-`#``#"!```U`(`
M``D%``"'`````````)(#``!1!@```````#T%``!2`P``?00``#`'```5`P``
MR0,``!<%````````K0(``.\'``!^!0`````````````````````````````B
M`@``Q00``*D$````````'0(````````Z!```9P8``````````````````-0$
M```%`0``8`(``(D&````````CP``````````````=`,``(\'```[!0``6@,`
M`)8%``!4!```O`$``%4&``#7`@``W0````````#!`P``'P8``"$```#K`P``
M```````````:!P``@@,``(0&``````````````````"K!0``C@8```H%````
M````9@(```````!"`P``````````````````<08````````L!```6@<``+<%
M```$`````0(``)@"``!]`@```````)(!````````G@(````````4!P``````
M`!<$````````)`,``,D"````````;@8```<```"-!@``T@0``"D#``#"!0``
M.P<``&8&``#7`0``UP<``````````````````"<&```N`P```````-<&``!5
M!0````````````"-`0``*`(``#D'``"(!@```````````````````````&X!
M``````````````````"H````&00``,,$```F!0``SP<``%L!````````7`<`
M`!,'````````U@(``.@'``!$````J`8``!X'`````````````.D#``![!```
M`````#8%````````1P<``"P%``"B!P``'0,``,X&````````SP$``%\$```3
M`@``````````````````I00``),$````````8P<``````````````````,\#
M```5````>00``(<!``!P!P``(0<``,@'``";`0``````````````````````
M`,8'``#F!@``Y@(``,H!``!#!0``5@0````````3!```FP(``)`!``#%!0``
MK00``&(````/!0``]P8``'X```````````````````!:`0````````````"'
M!@````(``"P"``!T!```W@0``/(````S!P``"0,```````"!````#@$``,\"
M````````*`0``-8#`````````````)H'```/!```<P0````````=!0``````
M`)@'````````<P<``*$"``"#!P``U`,``%\'`````````````+<'``!U!P``
M_0```"\'``#2!P``M@8```````#B!P``*08`````````````/`8```````!5
M!```]`8``(,%````````(0,````````U!0``5P```#('``#?!@``D@(``.<&
M``"&````%04``"4!``#V`@```````&$#``!O`0```````.P%``"^!@``40<`
M`*H%``#S!P``>P<``.(%````````*@$`````````````L@```.P!``"*!0``
MX00``&@%```:`@``*@```-8$````````'@```$4#```^!0```````(0!```]
M!```R0<``!("````````'P(``$T!``!8!```3P,``.0'``!V!P``K````)T&
M``"P!```FP0``/<#``"]!P``V0<```L`````````-0(```````"8!0``+`,`
M`%@```#"`0```````"0$``"6!P``10```&D$``!P!@```````+@#``!F````
M`````'\$```;!@````````H"``"7!@``T`8``,0$```P!@```````,P!``#]
M`@``````````````````?````*0%``#4`0``]@,`````````````$08`````
M``#``P```````(L"``#3!@``I`8``!@#````````O08``"<$``#O`@``S0``
M```````,`0``Y0,``$\!`````````````,H%```S`0``AP,``'@'```O!@``
M^0<``',&``#R`@``````````````````6P8``"T&`````````````$T#``!%
M!```_`(``#\$``#;!0``Z@$```(&```W!P``(0(``/@&``"^`0``0`<``%`'
M````````M0,``"T$``!C````E`8```8$``"0````FP,``'P&``#N`P``]@<`
M`)`$````````G@,``#X!``#;`0```````+L$``"6`P``N0$``!,%````````
M00$``/<"```R!0```````$,!``#:`````````)<"````````R@0``+,#``!`
M!0``\`$``/(&``";!0``S`4````````-!````````.,$```T`@``"P$``$P%
M``#B`@``4@4``*````#I`@```````/D#````````J04```````"!!P``!@,`
M`+`!``#.`P``LP$``(L````M`````````*L"``#<!@```````"8"```&````
MG`0``.T&````````5@<``(<$````````,`$``$(`````````````````````
M````TP,``+$$``````````````````#5!```/@````````"!!````````!`&
M````````;@<``%X!``!\!P``#@0````````$!P``0P```.($```_!P``(`0`
M```````2````F`$````````Q````<0$``"0````!!P```````$X```#C`@``
M)@,``#@&````````$0(``+L```#!!0``4@```%@&```B!@``O`(``,<````-
M`0```````$$"```N!```@0(``"4&``"5`P````````````""!```#0```+X`
M``"J!@``>@(``/X"``#.!0``204``%@"``#``0```````-T&``!>````O`4`
M````````````7P8``),"``"1!P``[@0``!$`````````)P$`````````````
M``````````!P`P```````",&``",`0``UP0``)8&``#8!@``H0<``*<$```>
M`@```````$,$```:`P``904````````````````````````J!````````'D#
M```'!```E04``/8&``"#`0``>@4```````#C!@``T0$```````#9!@``X`,`
M``````#>`0``0`$``,P"```U!P``:@0``.8!````````*0<```````#+````
M$@0``$H'````````7`0```<&````````IP,``&("``#3!P``J`,`````````
M````]P0```````!;`P``'08``*D&`````````````&<#``#_`P``[P4``/($
M``!I!P``.00``)L``````````````!$%```D`@``````````````````=@$`
M`&P#``"L!0``&@8``.0$``!^`0``A@0```````!*`0```````.T#````````
ME08```````!9`@``]0<``"<%``#-`P``-0$``'$%````````+0<``($%``#J
M!@`````````````W!```(P,``/`"``"H`0``]0$``+``````````(````/4%
M``"6````3P(``,D&```E`@``(`,``!8!```Y`0``3`8``&X```#.````$P8`
M`#P"``#F!P``4@(``)D!````````W@```+H$``"U````^````,X!```.!0``
MVP<`````````````-@```)@&```N!P``8P$``'D&``!O````&P<``%T&````
M````A@(``#P!``#`````,`4```$$``#@!@```````/,"``")`@```````"4`
M``!$`@``<0```#D&``#Z!````````",$``#K!```4P$```X```#1`@``````
M`*`$``!8!0``D@8``)D'`````````````&$%```"`P```````-8'````````
M>@$```0%`````````````+,%````````.@8``$0%````````ZP4``.H%````
M````<@<``"L&````````_08``(0```"_`0``8P0``!@%``!3!```M08``.D!
M````````T@```'L!``![`@``:P0``(8%````````Z@(``'X'``#%`0``-`0`
M`%8"``#X`0``I@,``$4"```N`0```````)@$``!S`P``D0```'L```#$````
M``````````#)`````````)D%`````````````,T"````````<````-X'``#_
M````+`8``%(!``#E`@``>P8```````"J`0``[00``#P'````````\`0``$\$
M``">````BP,``+L%````````N0<```````!_`P``W`0``(X#````````R@``
M`.(&`````````````'`!``!Q`@```````!`!````````<P$``)\'``">!@``
MG`$```````!L!0``DP,``-D$``"W!````````#D```![!0``G`(``'@$````
M````^00`````````````MP,``"D$```M!0````````0&```V`P``+@````$&
M``!>`@``208``#,$````````\@4```````#D`P``NP,```````!F!0``4```
M``D"``#``@``E`0``&8#```_`@``90,```````!;`@``M`$``$@%````````
M3P``````````````B@0``)$#````````Q`,``$0'``!.!@``-`8``%P&```F
M!```>@<``%D```!1`P``Z00``.T```"W````Y0$```````",!````````#T'
M```^!@``7`(``"(``````````````````````````````!H```"O!P``*P,`
M`'0'````````0@(``!`$``#`!0``)@```.T%``"Y!@``D`<``#@!``#S!```
MR`8``#0%``#5`````@0``.\#``!B!````````-H!````````G@$``","``!1
M````E@$```````#/!```'P$``'<```"C!0```````$L%````````=04`````
M``!K!P```````",```#+`P```````%8!``"4!0``]`(```````"!`P``<P4`
M``````#[`@``NP(``.@#`````````````,L'``!E`@``M`<``"`!```H!0``
M00<``+D```#L!P``M04``$P#``#:!@``W`,``*L```#N````$@,```,#``!\
M`@``"`4````````7````K`,``,,"````````MP$`````````````*0(``-0%
M``#=`P``@P,``(@#``#@!````````.@```".!0```P<``/@"``!*!@```P0`
M``````"S````20(``'<&``!)!````````&H```!0!0```````)<```!&`0``
M,@``````````````O`8```````"3`0``3`<``'<%``#>`@``Y@````````#E
M!````````)\````S`@``T`<```````#Z!@``7P$``,X$``"L!@``)0<``!8'
M``"X!```%`(``+<"``#O!````````'\&```X`P```````*8'``#<!0``#P8`
M``````#8````V@0```````!)````^@4````````T!P``5`4``!\$```]`P``
M5P,```````#D!0``S`8``)H````D`0``&`(```8'```V!```=@`````````4
M`0``,`,``(H!`````````````"L%````````004``,P$````````````````
M``"?!@``=@0``'\"````````````````````````\0,``&T"``"C`P``*`,`
M`$L```!'`@``WP$```````"C!```#@(``(D!```0`P``\00``#4#``"O`@``
M`````!P"``#1`P``700``*D"``"N`````````&`&``"9`@``J0```'$$````
M````1P4``-@'````````V`,`````````````H`<```````"=!```````````
M```,!@``UP```.\```"J`P``P@(```H$``"C````T@8``/0`````````N04`
M`!P#````````S04```````````````````````")`P```````(('````````
M1@4``%X#``!@`0``0@0``(\#`````````````"D```#6!@``8@$``$````!?
M`@``^0(``-\'``!0`@``C0<``(H'``"F`0``Q@,```````#^`0```````#8&
M````````;P,``!(!``!7`@``*P<``+($``"<`P``V0$``/$%``!2!P``9@0`
M````````````]`<``&H'``":!@``?0<``",!``#S`P``&`8``#@```"J!P``
M.0(``-@%``#&!`````````$%``!+!@``2P(``'4!``#4!P``?P4``),'````
M````\0(``#$$````````%0(``+P$``!A!@````````,%``";!@``A`,``&T&
M```^!```WP4``!4&``#D`@``?P<``/L#``#V````8@<``(8&``":`P``<@$`
M`,T$```[`0``C0,``*@'``!K!0``,0,``#@%``"S!P``RP(```P%``"3!0``
M\P````````"J`````````(0'``#-!@``W`<``(T$``"7!```P@8``.P&``"T
M!0``=`8``+('``#K`0``#`<``"4#``#=!P``5@,``$`&```6!```$@4``((&
M```7`P``3@(```H!``!?!0``H0$``-,!``!"!P``R`$``($&``#T`0``````
M`)T%``#U!@``*P```$<#``"J`@``D`,``'@```"=`@``_`$```````#P````
M!P$```````#K!@``I0,``$@#```,`P``:P```,,!``"R`0``#0,``/0%```R
M!`````````@!```9`@````````````#H`0```````(H#``"5`0``BP$`````
M`````````````"<"```]!@```````,H"``"%!`````````````"*````JP,`
M``````!J!0``5@4``*<%````````/0```-X&`````````````.$#````````
M^04``!D#`````````````#,```"P`P``5P<```````!C`@```````!<'``"X
M`@```````)(```!*`@```````!L`````````@`4```P"```N!@``Q`8``-D"
M``!A!P```````,H'````````;@,```````!D`@``NP<``/4"``!]````D0$`
M```````L!P``%00``$D!``"%`0``;`<```````!L`0``3@$```````#6`0``
M``````````#$!0``]@$``(("`````````````,<#````````8@4``*<!```;
M`0``9`<``,\````G!P`````````````&!@``LP8```````"?`P``4P<``*$%
M``#A`0``8`<```L#``#;!````````.L```!3!0``````````````````70,`
M``H`````````,`0``'(```"$`@``H`(```````#/!@`````````````%!@``
M`````'<!````````6@0``&D!``"V`P``R`,``!D&``"Z!P``00```$(%```8
M````]0```-4"``"F`@``308``-\$``!7`0``.`(``!0```#G`@``404`````
M``#W`0``*`````````#*!@``(@4```````#B````+P4``(\$``!H`P``?`,`
M`!@!````````$00``+T#``"D`0``N@$```````!U````VP,``$8"```^!P``
M``````````#L`````````(0$``#U!```Q0(```````":`0``M@4``(L%```X
M!P``;`(`````````````"@<``*`&``!Y`@``:08``)4'``"T!````````,,&
M````````K`<``(T```#2`0```````&P$``!@!`````````````!,!```````
M`.P$``"K`0````````(```!V`@``?@8``'@"`````````````.4'``#C`0``
MB`$``)(%``"_!0``*P0``%P#```%!```F0```#H%````````$0$``)P&``!=
M!P``.P0``'D`````````9````!\```"U!P``0@8``)\"``#[!0``%`4``/('
M```W````6@(``'4$``"T`P``A@$``*X&````````K@(````````^`@``-P(`
M``````#J`P```````&@!``!]`0``"````$T"``!X!@```````%`$``",`@``
M=`(```````"]!```T0```#H"``!)!P``10$```````"Z`````````/P````/
M`0```@4``&0#```<!0``.P8``-(%``!5!P``HP8`````````````.0,``*$`
M``#&`0``&P,``/\%`````````````((!````````]`,``$8'``!W!P``````
M`.,#``!U!@```````,P#``#Y!@``3P<```````#D`````````!,!``!'````
M_0,``!@$```\````"0``````````````I08``,`&``#+!@``*@8`````````
M````3@0``-`"````````R`(``#8"````````C`<```````#"!P``^0$`````
M``!?`````````!X#````````*P$``````````````````!0$``"@`P``2`$`
M`'L#``!I`@```````(@%``#8`0``2`<```````#M`0```````+4$````````
MYP```&$"`````````````%@#``#F`P``U0<``(`"``#S!0```````*8$```.
M!@```````"T!````````(@0```````!]`P``MP8``+(%``!T````````````
M```-!0``,0(``#(#`````````````&`#``"E````/`,``"@'``!;!0``!04`
M`$P!``"V`0``JP<```````!P`@```````%P%````````,@(``$8```#E!@``
M8P8``.X&`````````````%D%`````````````(H"``````````````````#@
M!P``QP0``&0$````````AP(``+H%```1!P``N`$```H&``!J`P``BP<`````
M``!O!````````"8&````````]@0``(X```"4`@``Q@8`````````````````
M``````"`!@```````+`&````````AP4```````"/!0``@`,``,0"````````
M[@(``+$#``!R!```5`8``-,"``"/!@``V`(```````"1`@``!`(```$!``#T
M!````````.$&``";!P``>04``)H%``!O!0``?@,```<"``"@!0``QP8``,P'
M```J!0``OP```.(#````````#P(``(P&````````?P$``.\!```]`@``,P,`
M`````````````````)T```!Z!```1@8``%,#``"!`0```````$$#```,````
MM0(``'D'``````````````````!D!0``?P````````#:!0``J`(```````"P
M!P````````````#7`P``A04``'8&````````T@(``/L$``"K!```/P$``#L`
M```=````;P<``&X$``"V!```N`<``#8'``"/`@``-P$```````#9!0``````
M`+("````````A`4``/,&```@!0``?@(``*4'``````````<``+$"```9````
MS@<```````!A````%P$````````B`P```````!X!```I!0``RP4``!(&``#>
M!0```````#,%````````.04``.<%```=`0````````````#?`@``@@4``$H#
M``"C`0``,````#\%``!W`@``T`$``.4%``!V`P``Z0<```````!7!0``300`
M`+L&```]`0````````````#^````8`4``!8`````````OP0``#(!``#!!P``
MPP<``#$'``!9!@`````````````%!P````````4```#1!```*`8```````"Z
M!@``T08``+T"``"V````:0,``!8"``#X`P``:04``*T!``!$!```\0<`````
M``#*`P````````````"O````+P(``!X$``#:!P``70$```T'``".!```>0$`
M`$@&````````Z@<``%`#```\!```<0,``!`"``!``P```````-H"``"D!P``
M20,``'4"``````````````X'``#Z````RP0```````#P!0``600`````````
M````-P4``(,"````````=0,``$H```#)`0``"00``%@!``#`!```````````
M``"``0``Z0```,$```#^!@``_P0``/P$``"B`@``=`$``%D!``!:!0``&P0`
M`,D$``#0````T`0```````#3!```D`(``%`!````````-@$``$X'``"O!@``
M3@4``.`"```0!P``7@8``&T'``#\`P``CP$``(T"``#%`P``QP(```@'````
M````"P(``-T%``#5!0``?`$``*X%``!M!0``-0````<%````````KP$``.\&
M```M`@``B04``!@'``!,````F00``%8&```,!`````````T&``"%`@``*`$`
M`/\!``!K`0``;0$``/P&``"<!0``\`8``(D$```#!@``K0,``/$```!\!0``
M`````$0#``".`@``9P```+`%``#\!0``0@$``(H&``#>`P````8``(@"```T
M````NP$``(8#````````WP````````"7`0```````+$'``":!```S0$``(8'
M```[`P``0P,``/X$``!M`P````````````"R`P``$@<``(4&``````````0`
M```@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES
M*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B
M(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I
M8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES
M=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z
M("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E
M9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER
M97,N`"5D(&YO=&5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&
M:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@
M06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!C
M:&%R86-T97)S`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES
M(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@
M<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F
M("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E
M<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y
M(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@
M9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T
M:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S
M`"TM('-E;&5C="`M+0`Q(&YO=&4`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&
M;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I
M<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`
M04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@
M240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI
M9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D96YI960@
M9&5L971I;F<@;F]T92X`06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N
M`$%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N`$%C8V5S<R!D96YI
M960@<V%V:6YG(&YO=&4Z("5S`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N
M="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D
M($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!
M9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G
M<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!
M9&0@82!N97<@=7-E<CH`061D(&-A=&5G;W)Y`$%D9"!C;VQU;6X`061D(&YE
M=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D
M<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RX`061D:6YG($$@3F5W($YO=&4`061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!
M9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L
M:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U
M<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T
M>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E
M<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!
M;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L
M=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N
M`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W
M97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N
M`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY
M('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R
M:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R
M8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I
M;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C
M96YD:6YG`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I
M8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`
M075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN
M`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@
M0V%T96=O<FEE<SH`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(
M($5X8W5S97,`0F%C:R!T;R!.;W1E<&%D`$)A8VL@=&\@3F]T97!A9"!/<'1I
M;VYS`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@
M<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR
M86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`
M0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L
M:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T
M86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO
M="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV
M:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S
M`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`
M0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI
M<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T
M:6]N(%!O:6YT<P!#4U8`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@
M9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H
M86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N
M)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N
M`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN
M;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E
M<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%T
M96=O<GD`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I
M97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG
M.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R
M86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E
M<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A
M<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS
M+@!#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@86YD(&1I<W!L87D@;W!T:6]N
M<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W
M;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I`$-H;V]S92!T:&4@;65M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE
M('-U;6UA<GD@=FEE=RX`0VAO;W-E('EO=7(@9&5F875L="!.;W1E<&%D+@!#
M:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O
M=6YD+@!#;&5A<@!#;&5A<B!&;W)M`$-L96%R($U33V9F:6-E('1A9W,`0VQE
M87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@
M=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI
M8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%
M87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO
M<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S
M`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@
M3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD
M:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO
M;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L
M;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@
M)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T
M:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T
M:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP
M92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I
M;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`
M0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I
M<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S
M97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C
M<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G
M>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P
M96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD
M(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO
M="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T
M(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R
M)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S
M(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E
M<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E
M<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E
M<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R
M96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E
M<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S
M97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E
M;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M
M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT
M<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,
M;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$
M95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A
M<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT
M:71Y`$1E9F%U;'0@3F]T97!A9`!$969A=6QT(%-H96QL`$1E9F%U;'0@<V]R
M=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5F
M:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!#;VYF:7)M871I
M;VX`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8G5T=&]N(&)E:&%V
M:6]U<@!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I
M='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W`$1E;&5T92!T:&ES(&YO=&4`1&5L971E9"!S971U<"!U<&=R861E
M('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8V5N9&EN
M9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$97-C<FEP=&EO
M;CH`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E
M;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$
M97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@
M<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S
M/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$
M:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT
M('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\`1&]E<R!T:&4@9FER<W0@
M<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H
M:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V
M92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A
M=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES
M('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="`B)7,B`$5D:70@0FQO
M8VL`161I="!'<F]U<`!%9&ET($YO=&4`161I="!097)M:7-S:6]N`$5D:70@
M4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!C871E
M9V]R:65S(&%N9"!C;VQO<G,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M
M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C
M871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%
M;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T
M:6-O;G,`16UP='D@3F]T90!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N
M`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM
M86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R
M:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K
M.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L
M971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA
M`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG
M`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP
M:7)A=&EO;B!$871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@3F]T97,`1D<@
M0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&7W5L;"!497AT`$9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`
M1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B
M)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A
M:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`
M1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD
M<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`
M1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE
M;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL
M90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I
M;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO
M860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N
M9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO
M870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O
M;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R
M96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L
M87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K
M*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE
M('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`
M1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I
M86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N
M`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'
M86QL97)Y.@!'86UB:6$`1V5N97)A;"!/<'1I;VYS`$=E;F5R871E("5S($-O
M;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H
M86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O
M961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E
M8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P
M($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E
M<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN
M96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@
M=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E
M<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M
M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@
M=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C
M=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T
M:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO
M;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A
M;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(
M=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL
M960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L
M;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD
M`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N
M=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@
M55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@
M9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@3F]T97,L(%-T
M97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T97,`26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@
M069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN
M8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I
M80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I
M;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E
M<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R
M90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E
M;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E
M<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E
M<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G
M<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W
M(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF
M>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I
M="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I
M96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED
M(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@
M<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L
M:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L
M;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O
M<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE
M<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN
M`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T
M`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A
M+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4
M+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA
M;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R
M9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@
M1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME
M97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME
M>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+
M97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI
M9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A
M:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$
M96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T($UO9&EF:65D`$QA
M<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z
M`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L
M;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU
M97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I
M>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG
M:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W
M97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3
M;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI
M=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S
M('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT
M`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T
M=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A
M;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`
M36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN
M+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E
M9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-
M87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D
M*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S
M`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O
M9B!.;W1E<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM
M=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365M;R!4
M97AT`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E
M<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC
M871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-
M97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"
M(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@
M9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S
M`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O
M9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-
M:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H
M87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I
M;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U
M<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A
M;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)
M1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN
M9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE
M9"!$871E`$UO9&EF>2!54DP`36]D:69Y:6YG("5S`$UO9'5L=7,`36]L9&]V
M82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R
M`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F
M;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O
M`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E
M($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`
M36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U
M;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!.;W1E<P!->2!0;W)T86P`
M37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.
M86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N
M9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!2
M96YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!3
M4TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.
M971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A
M;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO
M;VX`3F5W($YO=&4`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA
M;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E
M>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L
M86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@
M;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.
M:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C
M:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@
M;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D
M960`3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+@!.;R!I8V]N<R!F;W5N
M9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`
M3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YO
M=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+@!.;R!N;W1E<P!.;R!N
M;W1E<R!M871C:"!T:&4@8W5R<F5N="!C<FET97)I82X`3F\@;F]T97,@=&\@
M9&ES<&QA>0!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R
M='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I
M960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V
M86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO7W1E`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@
M*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H
M97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R
M`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`
M3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E($-A=&5G;W)Y`$YO=&4@1&5T
M86EL<P!.;W1E($QI<W1S`$YO=&4@5&5X=`!.;W1E(%]497AT`$YO=&4@;F]T
M(&9O=6YD+@!.;W1E7W!A9`!.;W1E<&%D)W,@;F%M93H`3F]T97!A9',`3F]T
M97!A9',@;75S="!H879E(&$@;F%M92X`3F]T97,`3F]T97,@4W5M;6%R>0!.
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU
M;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/
M8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E
M<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY
M('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E
M(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/
M<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@
M97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T
M:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N
M`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T
M:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A
M8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO
M=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R
M;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D
M:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY
M($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL
M>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H
M+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG
M;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E
M<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL
M:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D
M97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@
M82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E
M+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X
M="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S
M>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L
M86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R
M:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T
M<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM
M`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R
M>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I
M;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN
M(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(&1E;&5T92!T:&ES(&YO
M=&4_`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T
M(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H($QI<W0`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L
M871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E
M<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-A=&5G;W)Y`%)E;6]V92!C
M;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D
M('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T
M:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I
M9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG
M:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N
M+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E
M(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U
M;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O
M;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I
M86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG
M;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H
M96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%
M4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD
M($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H
M7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E
M`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E
M<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M
M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!2
M97-U;'1S`%-E87)C:"!38V]P90!396%R8V@@7U1E>'0`4V5L96-T($9I;&5S
M`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A
M(&YE=R!O=VYE<@!396QE8W0@82!N;W1E<&%D`%-E;&5C="!A('-E<G9E<@!3
M96QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E
M;&5C="!N;W1E<&%D<R!T;R!D:7-P;&%Y.@!396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!3
M96QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R
M;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z
M`%-E;&5C=&5D($-A=&5G;W)I97,Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N
M9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-
M;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@
M;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER
M960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L
M('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO
M<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\`4VAO=P!3:&]W(&%C=&EO;B!B=71T;VYS/P!3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!N;W1E<&%D(&YA;64_`%-H;W<@
M;F]T97,@9G)O;2!T:&5S92!C871E9V]R:65S`%-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO
M9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,
M871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!
M;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V
M86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3
M;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T
M:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD
M<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!B>2!#871E9V]R>0!3;W)T
M(&)Y($YO=&4@5&5X=`!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D
M<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A
M;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O
M;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R
M(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O
M<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I
M;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;
M0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`
M4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S
M>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U
M;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"`B)7,B+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O
M;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S
M(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES
M90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES
M93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN
M86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`
M4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y
M;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L
M:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M
M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE
M(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@
M;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E
M<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`
M5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`
M5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4
M:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES
M<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@
M8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T
M:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I
M9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@
M<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B
M965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@
M;F]T92!W87,@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!C;W5L9&XG="!B
M92!C<F5A=&5D.B`E<P!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&-R96%T
M960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO
M=&5P860@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&YU;6)E<B!O9B!F:65L
M9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@
M<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N
M;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T
M97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O
M;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL
M92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T
M;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG
M(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@
M=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL
M;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE('9.;W1E(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I
M<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@
M<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N
M;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E
M<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T
M86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@=&AI
M<R!N;W1E<&%D.B`E<P!4:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="X`
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R
M9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H
M:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`
M5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T
M960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R
M`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@
M<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`
M5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN
M9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO
M<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`
M5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`
M5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z
M(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<P!5;F%B;&4@
M=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L
M92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5
M;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&\@8VAA;F=E<P!5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@
M16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P
M<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,`
M56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E
M('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5
M<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@
M;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA
M;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``
M57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y
M(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!6
M86QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@
M0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I
M8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6
M:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6
M:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!7
M90!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!7
M96%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M
M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T
M97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A
M=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T
M:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA
M<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@3F]T97!A9"!S
M:&]U;&0@=&AE(&YO=&5S(&)E(&%D9&5D('1O/P!7:&EC:"!P:&%S97,`5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE
M;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ
M`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I
M;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z
M(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D
M("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN
M9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`
M6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U
M,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M
M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S
M92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L
M;V-K<RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&YO=&5S+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N
M;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A9"`E<RX`66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T
M:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@
M8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`
M66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@;F]T97!A9"!T
M;R!B92!D96QE=&5D+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)
M=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO
M=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@
M86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A
M=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N
M93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO
M=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!D969A=6QT(&YO=&5P860Z`%EO
M=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE
M=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;F]T97!A9',Z`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W
M:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I
M<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L
M96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T)A8VL@=&\@3F]T97!A9`!?0TQ)`%]#871E9V]R>0!?1&%T851R964`
M7T1E;&5T90!?1&5L971E(%)O=P!?161I=`!?1FER<W0@3&EN90!?1W)O=7!S
M`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%]);7!O<G0O17AP;W)T`%],
M:7-T($YO=&5S`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]-
M>2!.;W1E<&%D<P!?3F5W($YO=&4`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]0
M<FEN=`!?4F5M;W9E($QI;FLN+BX`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK
M;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`
M8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A
M9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@
M9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T
M(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN
M;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R
M;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@
M25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N
M=&5D`&YO=&5P860`;F]T97,N8W-V`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI
M960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R
M=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V
M:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP
M;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!V3F]T90!W
M.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($UN96UO"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-BTP,BTQ-2`Q.#HS-"TP,C`P"DQA<W0M5')A;G-L871O<CH@
M1F%B:6\@1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R/@I,86YG=6%G92U496%M
M.B!"<F%Z:6QI86X@4&]R='5G=65S92`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*6"U'96YE<F%T;W(Z($M"86)E;"`Q+C,N,0I0;'5R86PM1F]R;7,Z
M("!N<&QU<F%L<STR.R!P;'5R86P]*&X@/B`Q*3L*`"`H)7,@9&EA<R!A='+A
M<RD`("A496-L82!D92!!=&%L:&\@)7,I`"`H96T@)7,@9&EA<RD`("AH;VIE
M*0`@*&%M86YHXRD`("AO;G1E;2D`(&$@`"(E<R(@3N-O(.D@=6T@9&ER973S
M<FEO+@`G)7,G(&[C;R#I('5M82!E<V-O;&AA(';A;&ED82X`)R5S)R!NXV\@
M97-TX2!C;VYF:6=U<F%D;R!N;R!296=I<W1R;R!D;R!(;W)D92X`<F5N9&5R
M:7IA9&]R(&1E(.%R=F]R92`B)7,B(&[C;R!E;F-O;G1R861O+@`B)7,B(&9O
M:2!A9&EC:6]N861O(&%O('-I<W1E;6$@9&4@9W)U<&]S+@`B)7,B(&9O:2!A
M9&EC:6]N861O(&%O('-I<W1E;6$@9&4@<&5R;6ES<_5E<RX`(B<E<R(@;N-O
M(&9O:2!C<FEA9&\Z("5S+@`E+C)F34(@=7-A9&]S(&1E)2XR9DU"('!E<FUI
M=&ED;W,@*"4N,F8E)2D`)60@)7,@92`E<P`E9"!D:6%S(&%TZ2!S=6$@<V5N
M:&$@97AP:7)A<BX`)60@86YO=&'G]65S`"5D('!R979I<^-O(&1O(&1I80`E
M<R`M($%V:7-O`$EM<')E<W/C;R!$:6=I=&%L(&1E("5S`"5S($M"`"5S($]P
M97)AY_5E<R!D92!-86YU=&5NY^-O("T@0V]N9FER;6'GXV\`0V]N9FEG=7)A
MY^-O(&1E("5S`$-A9&%S=')O(&1E("5S`"5S(%1E<FUO<R!D;R!!8V]R9&\`
M)7,@:N$@97AI<W1E+@`E<R!A("5S("5S`"5S(&-A<F%C=&5R97,`07)Q=6EV
M;R`E<R!I;7!O<G1A9&\@8V]M('-U8V5S<V\`)7,@97-TX2!P<F]N=&\@<&%R
M82!E>&5C=71A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!M87)C861A
M<R!A8F%I>&\N($UA<G%U92!A(&-A:7AA('!A<F$@<75A;'%U97(@;W!E<F'G
MXV\@<75E('9O8^H@<75E:7)A(&5X96-U=&%R(&1E<W1A('9E>BX`)7,@Z2!O
M8G)I9V%T\W)I;P`E<R!M:6YU=&]S`"5S(&[C;R!E;F-O;G1R861O+@`E<R!A
M("5S(&1E("5S`$-A=.%L;V=O(&1E($5N9&5R9>=O<R!D92`E<P!!9V5N9&$@
M9&4@)7,`06YO=&'G]65S(&1E("5S`$QI<W1A(&1E(%1A<F5F87,@9&4@)7,`
M)7,Z("5S`"5S.B!%<W1A(&UE;G-A9V5M('!O9&4@;N-O('-E<B!D92!Q=65M
M(&5L82!D:7H@<V5R+B!4;VUE(&-U:61A9&\@8V]M('%U86QQ=65R(&QI;FL@
M<')E<V5N=&4@;F5L82!O=2!E;2!F;W)N96-E<B!A;R!R96UE=&5N=&4@<75A
M;'%U97(@:6YF;W)M8>?C;R!P97-S;V%L+@`L(&)R:7-A(``L(&)R:7-A("5S
M("5S`"P@=F%R:>%V96P@9&4@)7,@<&%R82`E<P`M+2!S96QE8VEO;F4@+2T`
M,2!A;F]T8>?C;P!&;W)M871O(#$R($AO<F%S`$9O<FUA=&\@,C0@2&]R87,`
M,C0@:&]R87,`/%#A9VEN82!!;G1E<FEO<@!5;2!C;VYE8W1O<B!D92!B86YC
M;R!D92!D861O<R#I(&]B<FEG873S<FEO('!A<F$@97-T92!B;&]C;RX`56T@
M97)R;R!F871A;"!O8V]R<F5U`%5M82!C:&%V92!P^F)L:6-A(%!'4"#I(&]B
M<FEG873S<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`56UA
M(&-H879E('#Z8FQI8V$@4$=0(.D@;V)R:6=A=/-R:6$@<&%R82!V97)I9FEC
M87(@=6UA(&UE;G-A9V5M(&%S<VEN861A+@!5;6$@8VAA=F4@<')I=F%D82!0
M1U`@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA<R!P87)A(&1E<V-R:7!T
M;V=R869A<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P<FEV861A(%!'4"!E
M('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA<B!U;6$@
M;65N<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E
M('!R:79A9&$@4R]-24U%(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I87,@
M<&%R82!D97-C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+@!5;6$@8VAA=F4@
M</IB;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M
M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA<B!U;6$@;65N
M<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12#I(&]B<FEG873S<FEA
M('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`3G5V96YS(&UA='5T
M:6YA<P!#:'5V82!&<F%C82!697-P97)T:6YA`$-H=79A(&UA='5T:6YA`$-H
M=79A<R!M871U=&EN87,`3F5V87-C87,@36%T=71I;F%S`$%-+U!-`$%022!)
M1`!3;V)R92!E<W1E(&5D:71O<@!3;V)R92XN+@!!8G-B;W1T;VT`06)S;6ED
M9&QE`$%C97-S;R!N96=A9&\@86\@8W)I87(@9&ER973S<FEO(%9&4RX`06-E
M<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O(%9&4RX`06-E<W-O(&YE9V%D
M;R!A;R!E>&-L=6ER(&%N;W1AY^-O+@!!8V5S<V\@;F5G861O(&%O(&UO=F5R
M(&$@86YO=&'GXV\N`$%C97-S;R!N96=A9&\@<V%L=F%N9&\@82!A;F]T8>?C
M;R!E;2`E<RX`06-E<W-O(&YE9V%D;R!S86QV86YD;R!A;F]T8>?C;SH@)7,`
M4W5A<R!);F9O<FUAY_5E<P!396YH82!D82!#;VYT80!#;VYT82!D97-A=&EV
M861A+@!#;VYT87,`061I8VEO;F%R`$%D:6-I;VYA<B!'<G5P;R!3=6)O<F1I
M;F%D;P!!9&EC:6]N87(@4&5R;6ES<_5E<R!3=6)O<F1I;F%D87,`061I8VEO
M;F4@07%U:3H`061I8VEO;F%R($YO=F\@1W)U<&\`061I8VEO;F%R($YO=F$@
M4&5R;6ES<^-O`$%D:6-I;VYA<B!U;2!G<G5P;R!S=6)O<F1I;F%D;R!A("<E
M<R<`061I8VEO;F%R('5M82!P97)M:7-SXV\@<W5B;W)D:6YA9&$@82`G)7,G
M`$%D:6-I;VYA<B!U;2!N;W9O('5S=>%R:6\Z`$%D:6-I;VYA<B!C871E9V]R
M:6$`061I8VEO;F%R(&-O;'5N80!!9&EC:6]N87(@;F]V;W,@;65M8G)O<P!!
M9&EC:6]N87(@<&%R`$%D:6-I;VYA<B!O($UE;G4@)7,@8V]M;R!U;6$@0F%R
M<F$@3&%T97)A;"!D;R!-;WII;&QA`$%D:6-I;VYA<B!A;R!C873A;&]G;R!D
M92!E;F1E<F7G;W,Z`$%D:6-I;VYA<B!A;R!M974@8V%TX6QO9V\@9&4@96YD
M97)EYV]S`$%D:6-I;VYA<B!U<W7A<FEO`"<E<R<@861I8VEO;F%D;R!A;R!S
M:7-T96UA+"!M87,@;N-O('!U9&4@:6YC;'5I<B!I;F9O<FUAY_5E<R!A9&EC
M:6]N86ES(&1O(&-A9&%S=')O.B`E<RX`)7,@861I8VEO;F%D;R!A;R!S:7-T
M96UA+B!6;V/J('!O9&4@<V4@8V]N96-T87(@86=O<F$N`$%D:6-I;VYA;F1O
M(%5M82!.;W9A($%N;W1AY^-O`$%D:>?C;R!D92!U<W7A<FEO<R!E<W3A(&1E
M<V%B:6QI=&%D82X`16YD97)EYV\`0V%TX6QO9V\@9&4@16YD97)EYV]S`$%D
M;6EN:7-T<F%R("T@8V]N9FEG=7)A('!E<FUI<W/U97,@<&%R82!O=71R;W,@
M=7-UX7)I;W,`061M:6YI<W1R8>?C;P!!;OIN8VEO<P!!9F5G86YI<W3C;P!!
M;&+B;FEA`$%R9^ER:6$`07!E;&ED;P!!;&EN:&%R`$%L:6YH86UE;G1O.@!4
M;V1O<P!4;V1O<R!5<W7A<FEO<R!!=71E;G1I8V%D;W,`5&]D;W,@1W)U<&]S
M`%1O9&%S(%!E<FUI<W/U97,`5&]D;W,@<75A=')O(&QA9&]S`%!E<FUI=&ER
M(&WZ;'1I<&QO<R!E;F1E<F7G;W,`4&5R;6ET:7(@8V]N9FEG=7)A<B!O('1I
M<&\@9&4@;&ES=&%S(&]R9&5N861A<S\`2N$@97AI<W1E`$QO9VEN($E-4U`@
M06QT97)N871I=F\`4V5N:&$@24U34"!!;'1E<FYA=&EV80!5<W7A<FEO($E-
M4U`@06QT97)N871I=F\`16YD97)EYV\@9&4@92UM86EL(&%L=&5R;F%T:79O
M`$UO9&5L;W,@86QT97)N871I=F]S`%1E>'1O(&%L=&5R;F%T:79O.@!386UO
M82!!;65R:6-A;F$`56T@=F%L;W(@:6QE9V%L(&9O:2!E<W!E8VEF:6-A9&\N
M`$]C;W)R974@=6T@97)R;R!D97-C;VYH96-I9&\N`$%N9&]R<F$`06YG;VQA
M`$%N9W5I;&QA`%!R;WAY(&%N]&YI;6\`4F5S<&]S=&$`06YTX7)T:61A`$%N
M=&EG=6$@92!"87)B861O<P!!<&QI8V'GXV\`3&ES=&$@9&4@07!L:6-AY_5E
M<P!!(&%P;&EC8>?C;R!E<W3A('!R;VYT82X`07!L:6-A<B!A;W,@0V]M<&%R
M=&EL:&%M96YT;W,@4W5B;W)D:6YA9&]S`$%P<F]V87(`5&%M86YH;R!!<')O
M>&EM861O`$%B<FEL`$%RX6)I8V\@*%=I;F1O=W,M,3(U-BD`5&%M86YH;R!D
M;R!!<G%U:79O`$YO;64@9&\@07)Q=6EV;P!6;V/J('1E;2!C97)T97IA('%U
M92!Q=65R(')E;6]V97(@82!S;VQI8VET8>?C;R!D92!C861A<W1R;R!D92`E
M<S\`5F]CZB!T96T@8V5R=&5Z82!Q=64@9&5S96IA(&5X8VQU:7(@)R5S)R!E
M('-E=7,@<W5B9W)U<&]S/P!!<F=E;G1I;F$`07)MZFYI80!!<FWJ;FEO("A!
M4DU30TE)+3@I`$%R=&4`07)U8F$`07-C96YD96YT90!);&AA($%S8V5N<^-O
M`$%R=&4@07-C:6D`P7-I82]296=IXV\@9&\@4&%C[69I8V\`4V]L:6-I=&%R
M(&-O;F9I<FUAY^-O(&%N=&5S(&1E(&5X96-U=&%R(&%S(&]P97)AY_5E<R!D
M92!M86YU=&5NY^-O/P!#;VQU;F%S(&1E(&1E<VEG;F'GXV\`5&5N=&]U(&5X
M8VQU:7(@=6T@9W)U<&\@:6YE>&ES=&5N=&4N`%1E;G1O=2!E>&-L=6ER('5M
M82!P97)M:7-SXV\@;N-O(&5X:7-T96YT92X`5&5N=&]U(&5D:71A<B!U;6$@
M<&5R;6ES<^-O(&[C;R!E>&ES=&5N=&4N`%1E;G1O=2!E9&ET87(@=6T@8V]M
M<&%R=&EL:&%M96YT;R!NXV\@97AI<W1E;G1E+@!!=')I8G5T;W,`06=O<W1O
M`$%U<W1RX6QI80#!=7-T<FEA`$%U=&A?8WER<W%L.B!.XV\@9F]I(&5N8V]N
M=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N`$%U=&A?8WER=7,Z
M($\@8V]N96-T;W(@;N-O('!O<W-U:2!A<R!C87!A8VED861E<R!N96-E<W/A
M<FEA<RX`075T:%]C>7)U<SH@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YS
MXV\@:6UA<"!N96-E<W/A<FEA+@!!=71H7V9T<#H@3N-O(&9O:2!E;F-O;G1R
M861A(&$@97AT96YSXV\@1E10(&YE8V5S<^%R:6$N($-O;7!I;&4@;R!02%`@
M8V]M(&$@;W#GXV\@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z($[C;R!F;VD@
M96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82X`075T:%]K
M<F(U.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!K<F(U(&YE8V5S
M<^%R:6$N`$%U=&A?;&1A<#H@26YC;'5SXV\@9&4@=7-UX7)I;W,@;N-O(.D@
M<W5P;W)T861A('!A<F$@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($5X
M8VQU<^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E
M>'1E;G/C;R!,1$%0(&YE8V5S<^%R:6$N`$%U=&A?;&1A<#H@26UP;W-S[79E
M;"!A9&EC:6]N87(@;R!U<W7A<FEO("5S+B!)<W1O(&9O:2!O('%U92!O('-E
M<G9I9&]R(')E<&]R=&]U.B``075T:%]L9&%P.B!);7!O<W/M=F5L(')E;6]V
M97(@;R!U<W7A<FEO("5S`$%U=&A?;&1A<#H@26UP;W-S[79E;"!A='5A;&EZ
M87(@;R!U<W7A<FEO("5S`$%U=&A?;&1A<#H@071U86QI>F'GXV\@9&4@=7-U
MX7)I;W,@;N-O(.D@<W5P;W)T861A('!A<F$@06-T:79E($1I<F5C=&]R>2X`
M075T:%]M8V%L.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!-0T%,
M(&YE8V5S<^%R:6$N`$%U=&A?<VUB875T:#H@3N-O(&9O:2!E;F-O;G1R861A
M(&$@97AT96YSXV\@<VUB875T:"!N96-E<W/A<FEA+@!!=71E;G1I8V'GXV\@
M;F\@<V5R=FED;W(@24U!4"!F86QH;W4N`$9A;&AA(&YA(&%U=&5N=&EC8>?C
M;P!&86QH82!N82!A=71E;G1I8V'GXV\Z("5S`$%U=&5N=&EC8>?C;R!R96IE
M:71A9&$@<&5L;R!S97)V:61O<B!2041)55,N`$$@875T96YT:6-AY^-O(&YO
M('-E<G9I9&]R($944"!F86QH;W4N`$$@875T96YT:6-AY^-O(&YO('-E<G9I
M9&]R(%--0B!F86QH;W4N`$-A=&5G;W)I87,@1&ES<&]N[79E:7,Z`$-A;7!O
M<R!D:7-P;V[M=F5I<SH`07IE<F)A:6KC;P!$97-C=6QP87,@9&\@0D]&2`!6
M;VQT87(@86\@0FQO8V\@9&4@3F]T87,`5F]L=&%R(.!S($]PY_5E<R!D;R!"
M;&]C;R!D92!.;W1A<P!&=6YD;P!#;W(@9&4@1G5N9&\`4V5N:&$@:V5R8F5R
M;W,@:6YC;W)R971A+@!5<W7A<FEO(&ME<F)E<F]S(&EN8V]R<F5T;RX`0F%H
M86UA<P!"86AR86EN`$+A;'1I8V\@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H
M`$)A<F)A9&]S`$[C;R!F;VD@96YC;VYT<F%D;R!O(&1I<F5T\W)I;R!B87-E
M(&1E(&EM86=E;G,@)R5S)RX`3&EN:&$@9&4@4&%R=&ED80!"96QO<OIS<VEA
M`$+I;&=I8V$`0F5L:7IE`$)E;FEN`$)E<FUU9&%S`$)U=.-O`$%N:79E<G/A
M<FEO`$[C;R!F;VD@96YC;VYT<F%D;R!O(&)L;V-O("(E<R(@9&$@87!L:6-A
MY^-O("(E<R(N`$-O;F9I9W5R8>?U97,@9&\@0FQO8V\`5&EP;R!D92!";&]C
M;P!.96=R:71O`$)O;.UV:6$`1F%V;W)I=&]S`$)O<F1A`$QA<F=U<F$@9&$@
M8F]R9&$Z`$)O<F1A<P!"\W-N:6$@92!(97)Z96=O=FEN80!!;6)O<P!";W1S
M=6%N80!2;V1A<.D`26QH82!";W5V970`0G)A<VEL`%1E<G)I=/-R:6\@9&\@
M3V-E86YO(,UN9&EC;R!);F=LZG,`0G)U;F5I`$)U;&?A<FEA`$QI<W1A(&-O
M;2!-87)C861O<F5S`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`4&]N
M=&]S(&1E($1I<W1R:6)U:>?C;R!#4DP`0U-6`%!R;W!R:65D861E<R!D82!#
MZ5]L=6QA+BXN`$$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P
M96-I9FEC861A+@!!9V5N9&$`0V%L;6\`0V%M8F]D:F$`0V%M87+U97,`3N-O
M(.D@<&]S<^UV96P@9V5R87(@=6UA(&YO=F$@<V5N:&$@875T;VUA=&EC86UE
M;G1E+"!E;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(N`$[C
M;R!C;VYS:6=O(&=R879A<B!O(&%R<75I=F\@(B5S(@!.XV\@Z2!P;W-S[79E
M;"!A9&UI;FES=')A<B!G97)E;F-I861O<F5S(&5X=&5R;F]S(&1E('-E<W/C
M;RX`3N-O(.D@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@24U!4#H@
M)7,`3N-O(&-O;G-I9V\@86)R:7(@;R!A<G%U:79O("(E<R(N`$-A;F%DX0!#
M86YC96QA<@!#86YC96QA<B!296QA=/-R:6\@9&4@4')O8FQE;6$`3N-O(.D@
M<&]S<^UV96P@97AC;'5I<B!O(&%R<75I=F\@(B5S(BX`3N-O(.D@<&]S<^UV
M96P@96YC;VYT<F%R('5M(&1I<F5T\W)I;R!T96UP;W+A<FEO+@!.XV\@Z2!P
M;W-S[79E;"!C;VYT:6YU87(@<V5M(&\@<&%RXFUE=')O("=T87)G971&:6QE
M)RX`3N-O(.D@<&]S<^UV96P@97AC;'5I<B!O(&1I<F5T\W)I;R`B)7,B+@!.
MXV\@Z2!P;W-S[79E;"!E>&-L=6ER+"`E9"!P;W-S=6D@<W5B;W)D:6YA9&]S
M+@!.XV\@Z2!P;W-S[79E;"!R96]R9&5N87(L(&[Z;65R;R!D92!R96=I<W1R
M;W,@9F]R;F5C:61O<R!P87)A(')E;W)D96YA<B!NXV\@8V]R<F5S<&]N9&4@
M86\@;OIM97)O(&%R;6%Z96YA9&\N`$[C;R#I('!O<W/M=F5L(')O=&5A<B!M
M96YS86=E;2!P87)A(&\@;OIM97)O(&5S<&5C:69I8V%D;RX`0V%B;R!697)D
M90!4[71U;&\`3W!E<F%D;W)A`$-A=&5G;W)I87,@92!.;VUE<P!#871E9V]R
M:6$`26QH87,@0V%Y;6%N`%1E;&5F;VYE($-E;'5L87(`4')O<')I961A9&5S
M(&1A($/I;'5L80!-87)G96T@9&$@8^EL=6QA.@!0<F]P<FEE9&%D97,@9&$@
M0^EL=6QA`$5S<&'G86UE;G1O(&1A(&/I;'5L83H`5&5L969O;F4@8V5L=6QA
M<@!#Z6QT:6-O("A)4T\M.#@U.2TQ-"D`0V5N=')O`%)E</IB;&EC82!D82#!
M9G)I8V$@0V5N=')A;`!%=7)O<&$@0V5N=')A;"`H25-/+3@X-3DM,BD`1&5T
M86QH97,@9&\@0V5R=&EF:6-A9&\`4')O<')I973A<FEO(&1O($-E<G1I9FEC
M861O`%!O;.UT:6-A<R!D;R!#97)T:69I8V%D;P!48VAA9&4`06QT97)A<@!!
M;'1E<F4@4W5A(%-E;FAA`$%L=&5R87(@;R!N;VUE(&4@;R!E;F1E<F7G;R!Q
M=64@87,@<&5S<V]A<R!VZF5M('%U86YD;R!E;&%S(&SJ96T@92!R97-P;VYD
M96T@<W5A<R!M96YS86=E;G,N`$%L=&5R82!A(&]R9&5N8>?C;R!D92!S=6%S
M(&%N;W1AY_5E<R!E(&]PY_5E<R!D92!V:7-U86QI>F'GXV\N`$%L=&5R8>?C
M;R!D92!S96YH82!NXV\@Z2!S=7!O<G1A9&$@;F$@8V]N9FEG=7)AY^-O(&%T
M=6%L+B`@16YT<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R+@!#
M:&%R`%9E<FEF:6-A<B!,:6Y?:RXN+@!#:&EL90!#:&EN80!#:&ENZG,@4VEM
M<&QI9FEC861O("A'0C(S,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2D`
M17-C;VQH82!A($%P;&EC8>?C;SH`17-C;VQH82!U;6$@<V5N:&$`17-C;VQH
M82!U;2!U<W7A<FEO`$5S8V]L:&$@8V]M;R!E>&EB:7(@9&%T87,Z`$5S8V]L
M:&$@;R!T:7!O(&1E(&5S=&EL;R!D92!L:7-T87,@*'!A<F$@;&ES=&%S(&]R
M9&5N861A<RD`17-C;VQH82!A<R!C871E9V]R:6%S(&1E(&UE;6]R86YD;W,@
M82!S97)E;2!L:7-T861A<R!N82!V:7-U86QI>F'GXV\@<F5S=6UI9&$N`$5S
M8V]L:&$@<V5U($)L;V-O(&1E($YO=&%S('!A9'+C;RX`26QH87,@0VAR:7-T
M;6%S`$[C;R!F;VD@96YC;VYT<F%D82!A(&1E9FEN:>?C;R!D92!C;&%S<V4@
M9&4@)7,N`$QI;7!A<@!,:6UP87(@1F]R;75LX7)I;P!,:6UP87(@=&%G<R!-
M4T]F9FEC90!%>&-L=6ER('5S=>%R:6\`17AC;'5I<B!U<W7A<FEO.B`E<P!%
M>&-L=6ER('5S=>%R:6\`17AC;'5I<B!D861O<R!D;R!U<W7A<FEO`$/I=2!A
M8F5R=&\@82!487)D90!#;&EQ=64@<&%R82!#;VYT:6YU87(`0VQI8VMA=&5L
M;"!V:6$@2%144`!&96-H87(@2F%N96QA`$YU=F5N<P!.=6)L861O('!E;&$@
M36%N:.,`3G5B;&%D;P!);&AA<R!D92!#;V-O<P!#;VYT<F%I<B!"87)R82!,
M871E<F%L`$-O;G1R86ER(&)O<F1A<P!#;VST;6)I80!#;W(`4&%L:&5T82!D
M92!#;W)E<P!396QEY^-O(&1E($-O<@!#;VQS.@!4[71U;&]S(&1A<R!#;VQU
M;F%S`%%U861R:6YH;W,`0V]M86YD;P!,:6YH82!D92!#;VUA;F1O`$-O;65N
M=&%R`$YO;64`0V]M;W)O<P!%;7!R97-A`$-O;7!U=&%D;W)E<P!#;VYD:>?C
M;P!#;VYD:>?U97,`1&EF97)E;N=A<R!D92!#;VYF:6=U<F'GXV\`0V]N9FEG
M=7)AY^-O(&1E('-I;F-R;VYI>F'GXV\@8V]M(%!$07,L(%-M87)T<&AO;F5S
M(&4@3W5T;&]O:RX`0V]N9FEG=7)AY^-O(&YE8V5S<VET82!D92!A='5A;&EZ
M8>?C;RX`0V]N9FEG=7)A<B`E<P!#;VYF:7)M92!A(%-E;FAA`$-O;F=O`$-O
M;F=O+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\`1F%L:&$@;F$@8V]N97CC
M;RX`1F%L:&$@;F$@8V]N97CC;SH@`$-O;F5XXV\@<F5C=7-A9&$@<&5L;R!S
M97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N`$-O;F5XXV\@<F5C=7-A9&$@
M<&5L;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N($UO=&EV;SH@)7,@
M*"5S*0!!(&-O;F5XXV\@86\@<V5R=FED;W(@1E10(&9A;&AO=2X`0V]N=&%T
M;W,`3W,@8V]N=&%T;W,@9F]R86T@861I8VEO;F%D;W,@8V]M('-U8V5S<V\@
M86\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RX`5&EP92!D92!C;VYT9?ID
M;R!D;R!A<G%U:79O(&-O;7!R:6UI9&\Z(`!#;VYT9?ID;R!D92`G)7,G`$-O
M;G1I;G5A<@!);&AA<R!#;V]K`$-O;VMI90!#;W!I87(`1F%L:&$@;F$@8_-P
M:6$Z("5S`$-O<&EA<B!S96QEY^-O`$E$(&1E($-U<W1O`$-O<W1A(%)I8V$`
M0V]S=&$@9&\@36%R9FEM`$EM<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@;65N
M<V%G96T@8V]M(%!'4#H@`$EM<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M
M(&-O;2!01U`Z(`!.XV\@9F]I('!O<W/M=F5L(&-R:7!T;V=R869A<B!A(&UE
M;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A
M(&UE;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@861I8VEO
M;F%R(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@
M<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!V97)I9FEC87(@;R!S
M86QD;RX@)7,`26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0
M+@!.XV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R("<E<R<@
M=71I;&EZ86YD;R!&5%`Z("5S`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!L
M:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$EM<&]S<^UV96P@9&5S8W)I<'1O
M9W)A9F%R(&]S(&1A9&]S(%!'4#H@`$[C;R!F;VD@<&]S<^UV96P@9&5S8W)I
M<'1O9W)A9F%R(&\@9&%D;R!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@97AC
M;'5I<B!O(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!A
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E
M>&-L=6ER(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C
M;R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@;R!E;F1E<F7G
M;R!D92!E+6UA:6P@9&\@9&5S=&EN873A<FEO+@!.XV\@9F]I('!O<W/M=F5L
M(&]B=&5R(&-O;7!L971A;65N=&4@;R!C873A;&]G;R!D92!E;F1E<F7G;W,N
M`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!A(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP
M;&5T86UE;G1E(&$@;&ES=&$@9&4@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX`
M3N-O(&9O:2!P;W-S[79E;"!C87)R96=A<B!A(&5S=')A=.EG:6$@)R5S)RX`
M3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!O(&1I<F5T\W)I;R`G)7,G+@!.XV\@
M9F]I('!O<W/M=F5L(&]B=&5R(&$@8VAA=F4@</IB;&EC82!A('!A<G1I<B!D
M;R!S97)V:61O<B!D92!C:&%V97,N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@
M)R5S)R!P87)A(&=R879AY^-O+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER("5S
M+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO("=-86EN=&5N86YC
M95]487-K)R`E<P!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@9&ER973S<FEO
M("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@<&5S<75I<V%R(&YO('-E<G9I9&]R
M($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@;&5R("5S+@!.XV\@9F]I('!O<W/M
M=F5L(&=E<F%R('5M82!N;W9A('-E;FAA('!A<F$@;R!U<W7A<FEO('-O;&EC
M:71A9&\N($%L9W5N<R!O=2!T;V1O<R!O<R!D971A;&AE<R!NXV\@97-TXV\@
M8V]R<F5T;W,N(%1E;G1E(&YO=F%M96YT92!O=2!E;G1R92!E;2!C;VYT871O
M(&-O;2!O(&%D;6EN:7-T<F%D;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@;6%I
M<R!A:G5D82X`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A($%#3`!.XV\@9F]I
M('!O<W/M=F5L(&]B=&5R(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S+B`E<P!.
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O
M+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&QI<W1A<R!D92!D:7-T
M<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@8V%P86-I
M9&%D97,@9&\@<V5R=FED;W(`3N-O(&9O:2!P;W-S[79E;"!R979E<G1E<B!A
M(&-O;F9I9W5R8>?C;RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@9&ER
M973S<FEO("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@<V%L=F%R(&$@8V]N9FEG
M=7)AY^-O("5S+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@
M9&$@8V]N9FEG=7)AY^-O+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B
M86-K=7`@9&$@8V]N9FEG=7)AY^-O.B`E<P!.XV\@9F]I('!O<W/M=F5L('-A
M;'9A<B!O('-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@
M96TZ("<E<R<N`$[C;R!C;VYS96=U:2!S86QV87(@;R!B86-K=7`@9&\@87)Q
M=6EV;R!D92!C;VYF:6=U<F'GXV\@)7,N`$[C;R!C;VYS96=U:2!S86QV87(@
M;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX@5F]CZB!P;V1E(&]U('5T
M:6QI>F%R('5M82!D87,@;W#G]65S('!A<F$@<V%L=F%R(&\@8_-D:6=O(&1E
M('9O;'1A(&5M("5S(&]U(&-O<&EA<B!M86YU86QM96YT92!O(&/S9&EG;R!A
M8F%I>&\@<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@;F\@
M<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@;&EN
M:R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&%T=6%L:7IA<B!O(&-O;G1A=&\N
M("5S`$[C;R!F;VD@<&]S<^UV96P@871U86QI>F%R(&$@;&ES=&$@9&4@9&ES
M=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&=R879A<B!A(&-O;F9I
M9W5R8>?C;R!D92`G)7,G.B`E<P!.XV\@9F]I('!O<W/M=F5L(&5N8V]N=')A
M<B!A($)A<G)A($QA=&5R86P@9&\@36]Z:6QL82X@0V5R=&EF:7%U92US92!Q
M=64@96QA(&5S=.$@86)E<G1A+@!.XV\@9F]I('!O<W/M=F5L(&1A<B!A;R!U
M<W7A<FEO("5S(&]S('-E9W5I;G1E<R!D:7)E:71O<R!P87)A(&$@<&%S=&$@
M)R5S)SH@)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O<P!#<FEA<@!#<FEA
M<B!U;2!L:6YK`$-R:6%R('5M82!N;W9A`$-R:6%R('-U8B!P87-T87,`0W)I
M861O`%!E<FUI<W/U97,@9&\@8W)I861O<@!.^FUE<F\@9&\@8V%R=.-O(&1E
M(&-RZ61I=&\`0W)OX6-I80!#=6)A`#0@1F%S97,@071U86ES`%-E<W/U97,@
M071U86ES`$AO<F$@071U86P`02!54DP@871U86P@Z0!5<W7A<FEO<R!N;R!M
M;VUE;G1O`$-L:6UA($%T=6%L`$-O;F1IY^-O(&%T=6%L.B``17-T:6QO(&%T
M=6%L`$-U<W1O;6EZ82!T87)E9F%S(&$@<V5R96T@97AE8W5T861A<R!A;R!C
M;VYE8W1A<B!A("5S+@!#;W)T87(`0V]R=&%R('-E;&7GXV\`0VAI<')E`$-I
M<NUL:6-O("A+3TDX+5(I`$-I<NUL:6-O("A7:6YD;W=S+3$R-3$I`$-I<NUL
M:6-O+U5C<F%N:6%N;R`H2T])."U5*0!297#Z8FQI8V$@5&-H96-A`$1$`$13
M3B`H=F5J82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E
M+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1I87)I86UE;G1E`$YA=F5G
M861O<B!D92!$871A5')E90!097-Q=6ES82!N;R!"86YC;R!D92!$861O<P!$
M871A`$1A=&$@9&4@4F5C96)I;65N=&\`4V5L9>?C;R!D92!D871A`$1I80!%
M7WAC;'5I<B!#;VQU;F$`1&5Z96UB<F\`3OIM97)O<R!D96-I;6%I<P!296-U
M87(@261E;G1AY^-O`%!A9'+C;P!#;W(@4&%D<N-O`$ED96YT:61A9&4@4&%D
M<N-O`$)L;V-O(&1E($YO=&%S(%!A9'+C;P!3:&5L;"!0861RXV\`0W)I=.ER
M:6\@<&%D<N-O(&1E(&]R9&5N8>?C;SH`1&ER9>?C;R!D92!O<F1E;F'GXV\@
M<&%D<N-O.@!$969I;FGG]65S`$5X8VQU:7(`17AC;'5I<B!CZ6QU;&$`0V]N
M9FER;6'GXV\@17AC;'7M9&$`17AC;'5I<B!'<G5P;P!%>&-L=6ER($QO9P!%
M>&-L=6ER(%!E<FUI<W/C;P!%>&-L=6ER(&4@<'5R9V%R(&UE;G-A9V5N<P!#
M;VUP;W)T86UE;G1O(&1O(&)O=.-O(&1E(&5X8VQU<^-O`$5X8VQU:7(@8^EL
M=6QA`$5X8VQU:7(@8V]L=6YA`$5X8VQU:7(@;6]D96QO('-U8G-T:71U=&\@
M97AI<W1E;G1E`$5X8VQU:7(@<&5R;6ES<_5E<R!P87)A("<E<R<`17AC;'5I
M<B!P97)M:7-S]65S('!A<F$@)R5S)R!E('%U86QQ=65R(&]U=')A('-U8BUP
M97)M:7-SXV\_`$5X8VQU:7(@;&EN:&$`17AC;'5I<B!I9&5N=&ED861E('-E
M;&5C:6]N861A`$5X8VQU:7(@82!C;VQU;F$@871U86P`17AC;'5I<B!A(&QI
M;FAA(&%T=6%L`$5X8VQU:7(@97-T82!A;F]T8>?C;P!38W)I<'0@9&4@871U
M86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O("<E<R<@97AC;'7M9&\N`$AO<F$@
M9&4@96YT<F5G80!$:6YA;6%R8V$`1&5S8V5N9&5N=&4`1&5S8W)E=F$@;R!P
M<F]B;&5M80!$97-C<FGGXV\`1&5S8W)IY^-O.@!$971A;&AE<R`H=&%M8NEM
M(&YO(')E9VES=')O(&1E(&%T:79I9&%D97,@9&\@2&]R9&4I.@!/<R!D971A
M;&AE<R!F;W)A;2!G<F%V861O<R!E;2!L;V<@<&%R82!O(&%D;6EN:7-T<F%D
M;W(N`$1E<V5N=F]L=FEM96YT;P!0;VYT;R!D92!/<G9A;&AO`%!O;G1O(&1E
M($]R=F%L:&\@<&%R82!A(/IL=&EM82!H;W)A.B``4&]N=&\@9&4@3W)V86QH
M;SH@`$1I<F7GXV\@9&$@97-Q=65R9&$@<&%R82!D:7)E:71A`$1I<F7GXV\@
M9&$@9&ER96ET82!P87)A(&5S<75E<F1A`$1I<F5T\W)I;P!%>&EB:7(@96T@
M9F]R;6%T;R`R-"!H;W)A<S\`3W#G]65S(&1E($5X:6)IY^-O`$5X:6)I<B!P
M<F5V:7/C;R!D971A;&AA9&$`17AI8FER('!R979I<^-O("A4048I`$5X:6)I
M<B!F;W)M871O`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.
MXV\@97AC;'5I<@!.XV\@86-E<W-E(&1I<F5T86UE;G1E(&UA:6YT96YA;F-E
M+G!H<`!6;V/J(&=O<W1A<FEA(&1E(&-O;F9I<FUA<B!A(&5X8VQU<^-O(&1E
M(')E9VES=')O/P!!('!R:6UE:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D
M;W,@8V%M<&]S/R!392!S:6TL(&-L:7%U92!N97-T82!C86EX83H`1&]M:6YI
M8V%N80!297#Z8FQI8V$@1&]M:6YI8V%N80!.XV\@=&5M('5M82!C;VYT83\@
M0V%D87-T<F4M<V4N`$)A:7AA<@!"86EX87(@)7,`0F%I>&%R(&$@8V]N9FEG
M=7)AY^-O(&=E<F%D82!C;VUO('5M('-C<FEP="!02%`N`$QI<W1A(&1E('-E
M;&7GXV\`1')O9V%S`$-O<G)E:6\`0V]N96-T;W(@9&\@9V%T97=A>2!%36%I
M;"UP87)A+5--4RP@<&%R82!O<&5R861O<F%S('%U92!D:7-P;VYI8FEL:7IA
M;2!E<W1E('-E<G9IYV\N`$524@!%<75A9&]R`$5D:71A<@!%9&ET87(@(B5S
M(@!%9&ET87(@0FQO8V\`161I=&%R($=R=7!O`$5D:71A<B!!;F]T8>?C;P!%
M9&ET87(@4&5R;6ES<^-O`$5D:71A<B!097)M:7-S]65S`$5D:71A<B!097)M
M:7-S]65S('!A<F$@)7,`161I=&%R(&-A=&5G;W)I87,@92!C;W)E<P!%9&ET
M87(@;W#G]65S(&1E.@!%9&ET87(@<&5R;6ES<_5E<R!P87)A("5S`$5D:71A
M<B!P97)M:7-S]65S('!A<F$@)7,`161U8V'GXV\`16=I=&\`16P@4V%L=F%D
M;W(`16QE;65N=&\N+BX`16T`12UM86EL`$5N9&5R9>=O(&1E($4M36%I;`!/
M(&5N9&5R9>=O(&1E(&4M;6%I;"!D979E(&-O<G)E<W!O;F1E<BX`365N<V%G
M96T@8V]M(&-O;F9I<FUAY^-O`$=A=&5W87D@9&4@14UA:6PM<&%R82U335,`
M16UO=&EC;VYS`$%N;W1AY^-O(&5M($)R86YC;P!-96YS86=E;2!E;2!B<F%N
M8V\N`%)E<W5L=&%D;R!E;2!B<F%N8V\N`%1E<FUO<R!D92!P97-Q=6ES82!E
M;2!B<F%N8V\`2&%B:6QI=&%R(&EN<V5RY^-O(&1E(&EM86=E;G,@82!P87)T
M:7(@9&$@1V%L97)I82!D92!);6%G96YS(&YO('1E>'1O/P!(86)I;&ET87(@
M;65N=2!D92!C;VYT97AT;R!C;VT@;R!B;W3C;R!D:7)E:71O/P!&:6YA;"!D
M;R!A;F\`075M96YT87(@161I=&]R`$9O<FYEYV$@=6UA('!E<F=U;G1A(&1E
M('-E9W5R86[G82!A('%U86P@=F]CZB!S97+A('!E<F=U;G1A9&\@<V4@=F]C
MZB!N96-E<W-I=&%R(&=E<F%R('5M82!N;W9A('-E;FAA+"!E>"X@)W%U86P@
M;R!N;VUE(&1O('-E=2!C86-H;W)R;S\G.@!&;W)N9>=A(&$@55),(&1A(&EM
M86=E;2!A<75I`$1I9VET92!A<R!L971R87,@86)A:7AO.@!'=6ENZ2!%<75A
M=&]R:6%L`$5R:71RZ6EA`$5R<F\`17)R;R!A;R!C<FEA<B!B;&]C;SH@)7,`
M17)R;R!A;R!E>&-L=6ER(.)N8V]R82!D92!S:6YC<F]N:7IAY^-O.B`E<P!%
M<G)O(&%O(&5X8VQU:7(@;&]G(&1E('-I;F-R;VYI>F'GXV\Z("5S`$5R<F\@
M86\@;V)T97(@8V]N=&7Z9&\Z("5S`$5R<F\@86\@871U86QI>F%R(&$@<V5N
M:&$Z("5S`$5R<F\@;F$@;65N<V%G96TN`$5R<F\@9W)A=F%N9&\@)R5S)RX`
M17-T]&YI80!%=&GS<&EA`,ET;FEC;P!%=7)O<&$`0V%D82`Q-2!M:6YU=&]S
M`$-A9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI;G5T
M;W,`0V%D82!#;VYE>.-O`$-A9&$@;65I82!H;W)A`$-A9&$@;6EN=71O`%9A
M;&]R97,@9&4@97AE;7!L;SH`17AE8W5T87(`17AP86YD:7(`17AP86YD:7(@
M0F%R<F$@3&%T97)A;`!%<W!E<F%D;R`G*2<`17-P97)A9&\@=6UA('!A;&%V
M<F$@;W4@=&5R;6\@9&4@<&5S<75I<V$@96YT<F4@87-P87,`1&%T82!D92!%
M>'!I<F'GXV\`17AP;V5N=&4`17AP;W)T87(`17AP;W)T87(@06YO=&'G]65S
M`$-O<B!D;R!P<FEM96ER;R!P;&%N;P!#;VYF:6=U<F'GXV\@9&4@96YV:6\@
M9&4@87)Q=6EV;W,@1E10`%1E>'1O(%]#;VUP;&5T;P!&86QH82!O8G1E;F1O
M('!R969E<NIN8VEA<RX`1F%L:&$@86\@8V]N96-T87(@86\@<V5R=FED;W(@
M3$1!4"X`1F%L:&$@86\@8V]N96-T87(@86\@<V5R=FED;W(@4TU"+@!&86QH
M82!A;R!C;W!I87(@9&4@(B5S(BX`1F%L:&$@86\@8V]P:6%R('!A<F$@(B5S
M(BX`1F%L:&$@86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!305-,+@!&86QH
M82!A;R!M;W9E<B!P87)A("(E<R(N`$9A;&AA(&%O(&]B=&5R.B`E<P!*=7-T
M;P!);&AA<R!&86QK;&%N9"`H36%L=FEN87,I`$EL:&%S($9A<F]E`$5R<F\@
M1F%T86PZ`$9A>`!&87AE<P!&979E<F5I<F\`4V5N<V'GXV\@5.ER;6EC80!3
M96YS8>?C;R!TZ7)M:6-A.B``4&%N8V%D87,@9&4@0VAU=F$`3F5V92!&<F%C
M80!-871R:7H@9&\@8V%M<&\`1FEG;&5T($-!4%1#2$$`1F]N=&4@1FEG;&5T
M`$9I:FD`87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV
M;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,`1V5R96YC:6%D
M;W(@9&4@07)Q=6EV;W,`3F]M92!D;R!!<G%U:79O`%-E;&7GXV\@9&4@87)Q
M=6EV;P!%;G9I;R!D92!A<G%U:79O`$5N=FEO(&1E(&%R<75I=F]S(&[C;R#I
M('-U<&]R=&%D;RX`1FEL=')O<P!&:6YLXFYD:6$`4')I;65I<F$@365T861E
M`%!R:6UE:7)O(%%U87)T;P!487AA(&9I>&$`1VER87(`1&ES<&]S:>?C;P!.
MZ79O80!087-T82`E<R!NXV\@97AI<W1E`$-O<B!D82!&;VYT90!#;VUI9&$`
M4&%R82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R=&%M(&EM86=E;G,`4')E
M=FESXV\@*%1!1BD`1&EA<R!0<F5V:7-T;W,@*$YO=&4@<75E(&$@<')E=FES
MXV\@<F5T;W)N861A(&5X:6)E(&%M8F]S(&1I82!E(&YO:71E.R!U;2!N^FUE
M<F\@;75I=&\@86QT;R!A<75I('!O9&4@<F5S=6QT87(@96T@=6T@8FQO8V\@
M97AT96YS;RD`17-Q=65C974@82!S96YH83\`1F]R;75LX7)I;W,`4V]R=&4`
M5&EP;R!D92!3;W)T90!3;W)T97,`4V]R=&5S(#(`1O-R=6YS`%)E9&ER96-I
M;VYA;65N=&]S`%-E>`!1=6%D<F]S`$9R86[G80!&<F%NYV$@365T<F]P;VQI
M=&%N80!'=6EA;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A`%1E<G)I
M=/-R:6]S($9R86YC97-E<R!D;R!3=6P`1&4`1&\H82D`1&5S8W)IY^-O($-O
M;7!L971A`$QU82!#:&5I80!.;VUE($-O;7!L971O`$=A8N-O`$=A;&5R:6$@
M9&4@;VYD92!O8G1E<B!A<R!I;6%G96YS`$=A;&5R:6$Z`$?B;6)I80!/<.?U
M97,@1V5R86ES`$=E<F%R(&$@0V]N9FEG=7)AY^-O(&1E("5S`$/S9&EG;R!'
M97)A9&\`1V7S<F=I80!!;&5M86YH80!'86YA`$=I8G)A;'1A<@!0<FEM96ER
M;R!.;VUE`$]PY_5E<R!';&]B86ES`$ER`$=O961E;`!';V]G;&4@36%P87,`
M4&5S<75I<V%R(&YO($=O;V=L90!%<V-A;&$@9&4@0VEN>F%S`$=RZ6-I80!'
M<F5G;R`H25-/+3@X-3DM-RD`1W)O96SB;F1I80!'<F%N861A`$%D;6EN:7-T
M<F'GXV\@9&4@1W)U<&]S`$YO;65S(&1E(&=R=7!O<R!NXV\@9&5V96T@97-T
M87(@96T@8G)A;F-O`$=R;W5P7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R
M(&=R=7!O("5S+B!)<W1O(.D@;R!Q=64@;R!S97)V:61O<B!D:7-S93H@`$=R
M;W5P7VQD87`Z($EM<&]S<^UV96P@97AC;'5I<B!G<G5P;R`E<P!'<F]U<%]L
M9&%P.B!);7!O<W/M=F5L(&%T=6%L:7IA<B!G<G5P;R`E<P!'<G5P;W,`1W5A
M9&%L=7!E`$=U86T`1W5A=&5L86UA`$=U97)N<V5Y`%!E<FUI<W/U97,@9&4@
M0V]N=FED861O`$QI=G)O(&1E(%9I<VET87,`1W5I;ND`1W5I;NDM0FES<V%U
M`$=U:6%N80!(5$U,`$A434Q!<F5A('-E(&YE9V$@8V]V87)D96UE;G1E(&$@
M97AC;'5I<B!A(/IL=&EM82!CZ6QU;&$@9&$@;&EN:&$N`$A434Q!<F5A('-E
M(&YE9V$@8V]V87)D96UE;G1E(&$@97AC;'5I<B!A(/IL=&EM82!C;VQU;F$@
M9&$@=&%B96QA+@!(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X
M8VQU:7(@82#Z;'1I;6$@;&EN:&$@9&$@=&%B96QA+@!!=71E;G1I8V'GXV\@
M2%144"!NXV\@96YC;VYT<F%D82X`2&%I=&D`06QG;W)I=&UO($AA<V@`3F5B
M;&EN80!#86)EYV%L:&\`0V%B9>=A;&AO`$EL:&$@2&5A<F0@92!);&AA<R!-
M8T1O;F%L9`!496UP97-T861E($9O<G1E`$AE8G)E=2`H25-/+3@X-3DM."U)
M*0!!;'1U<F$`06IU9&$`06IU9&$@9&\@961I=&]R`$%S<VES=&5N=&4`2&5M
M:7-FZ7)I;P!!<75I(&5S=.$@;R!I;NUC:6\@9&\@87)Q=6EV;SH`06QT80!)
M7V[M8VEO`%-A;G1A(%/I("A#:61A9&4M17-T861O(&1O(%9A=&EC86YO*0!)
M;NUC:6\`16YD97)EYV\@4F5S:61E;F-I86P`1&ER973S<FEO(%!E<W-O86P`
M1F]N92!297-I9&5N8VEA;`!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R
M9&4O2V]L86(Z($1A9&\@6$U,("5S(&EN=N%L:61O(&5N8V]N=')A9&\@;F$@
M;65N<V%G96T@)7,`2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G96T@8V]R
M<F5S<&]N9&4@86\@;V)J971O("5S`$AO<F1E+TMO;&%B.B!.96YH=6T@;V)J
M971O(&1O('1I<&\@)7,@9F]I(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,`
M2&]R9&4O2V]L86(Z(%)E;6]V:61O(&-O;2!S=6-E<W-O("5S("(E<R(`2&]R
M9&4O2V]L86(Z($$@96YG:6YE(&1E(&EN=&5G<F'GXV\@<F5Q=65R(&$@97AT
M96YSXV\@4$A0("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L(&-R
M:6%R('5M82!N;W9A(.%R=F]R92!834P@<&%R82!O(&]B:F5T;R`E<P!(;W)D
M92]+;VQA8CH@26UP;W-S[79E;"!R96UO=F5R("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!);7!O<W/M=F5L(&]B=&5R(&$@:61E;G1I9FEC8>?C;R!-24U%
M('!A<F$@82!P87)T92!D;R!T:7!O("5S`$AO<F1E+TMO;&%B.B!);7!O<W/M
M=F5L('-I;F-R;VYI>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!);7!O
M<W/M=F5L('-I;F-R;VYI>F%R(&-O;7!A<G1I;&AA;65N=&]S.B`E<P!(;W)D
M92]+;VQA8CH@0V]M<&%R=&EL:&%M96YT;R!D97-C;VYH96-I9&\@(B5S(@!,
M:6YH82!(;W)I>F]N=&%L`$UA<F=E;2!H;W)I>F]N=&%L`$AO<FEZ;VYT86PZ
M`$-O;6\@=F]CZB!C:&5G;W4@87%U:3\@*%!O<B!F879O<B!C;VUU;FEQ=64A
M*0!1=6%N=&%S(&-O;'5N87,@=F]CZB!G;W-T87)I82!D92!M97-C;&%R/P!1
M=6%N=&]S(&-A;7!O<R`H8V]L=6YA<RD@97AI<W1E;3\`475A;G1A<R!L:6YH
M87,@=F]CZB!G;W-T87)I82!D92!M97-C;&%R/P!5;6ED861E`%5M:61A9&4Z
M(`!(=6UO<FES=&%S`$AU;F=R[6$`1F%L:&$@86\@8W)I87(@8V%I>&$@<&]S
M=&%L($E-05`Z("5S`$9A;&AA(&%O(&5X8VQU:7(@8V%I>&$@<&]S=&%L($E-
M05`Z("5S`$9A;&AA(&%O(&-R:6%R('%U;W1A(&1A(&-A:7AA('!O<W1A;"!)
M34%0.B`E<P!%;F1E<F7G;R!)4`!%;F1E<F7G;R!)4"!NXV\@9&ES<&]N[79E
M;"X`16YD97)EYV\@25`@;N-O(&5S=.$@;F\@8FQO8V\@<&5R;6ET:61O($-)
M1%(N`%9I;VQAY^-O(&1O(&)L;W%U96EO($E0+@!)7VYS:7)A($QI;FAA($%N
M=&5S`$ES;.)N9&EA`%-O;65N=&4@S6-O;F5S`,UC;VYE<R!P87)A("5S`,UC
M;VYE<R!E('1E>'1O`$YO;64@9&$@:61E;G1I9&%D93H`4V4@;N-O(&9O<B!E
M>&EB:61O(&-O<G)E=&%M96YT92P@)7,@<&%R82!A8G+M+6QO(&5M('5M82!N
M;W9A(&IA;F5L82X`4V4@=F]CZB!NXV\@=NH@;F5N:'5M(.UC;VYE(&%O('5T
M:6QI>F%R(&\@26YT97)N970@17AP;&]R97(L('9O8^H@<&]D92!C:&5C87(@
M97-T82!C86EX82!P87)A(&1E<V%B:6QI=&%R(&$@=')A;G-P87+J;F-I82!0
M3D<N`%-E('9O8^H@=NH@97-T82!M96YS86=E;2!M87,@;N-O(&$@:6UA9V5M
M+"!A(&EM86=E;2!Q=64@=F]CZB!Q=65R(&5N=FEA<B!NXV\@<&]D92!S97(@
M97AI8FED82!P96QO('-E=2!N879E9V%D;W(N`%!RZ2UV:7-U86QI>F'GXV\@
M9&$@26UA9V5M.@!54DP@9&$@26UA9V5M`%523"!D82!);6%G96TZ`$EM86=E
M;2!D82!G86QE<FEA`$EM86=E;2!D82!G86QE<FEA.@!%;G9I;R!D92!);6%G
M96T`26UA9V5N<P!);7!O<G1A<B!!;F]T8>?U97,L(%!A<W-O("5D`$EM<&]R
M=&%R+"!087-S;R`E9`!);7!O<G1A<B]%>'!O<G1A<B!!;F]T8>?U97,`0V%M
M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@:6UP;W)T861O<SH`26Y?<V5R:7(@
M3&EN:&$@07#S<P!#\V1I9V\@9&4@8>?C;R!F;W)N96-I9&\@97-TX2!I;F-O
M<G)E=&\N`%5S=>%R:6\@92]O=2!S96YH82!I;F-O<G)E=&]S+@!5<W7A<FEO
M(&]U(&5N9&5R9>=O(&%L=&5R;F%T:79O(&EN8V]R<F5T;W,N(%1E;G1E(&YO
M=F%M96YT92!O=2!E;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D
M;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@;6%I<R!A:G5D82X`075M96YT87(@
M261E;G1AY^-O`,UN9&EA`%5S=>%R:6]S(&EN9&EV:61U86ES`$EN9&]NZ7-I
M80!);F9O<FUAY^-O`$EN9F]R;6'GXV\`3N-O(&5X:7-T96T@;W#G]65S(&1I
M<W!O;NUV96ES+@!);G-E<FER($-?;VQU;F$@07#S<P!);G-E<FER($EM86=E
M;0!);G-E<FER(%1A8F5L80!);G-E<FER($QI;FL@9&$@5V5B`$EN<V5R:7(@
M7T-O;'5N82!!;G1E<P!);G-E<FER('5M82!N;W9A(&-O;'5N82!A</-S(&$@
M871U86P`26YS97)I<B!U;6$@;F]V82!C;VQU;F$@86YT97,@9&$@871U86P`
M26YS97)I<B!U;6$@;F]V82!L:6YH82!A</-S(&$@871U86P`26YS97)I<B!U
M;6$@;F]V82!L:6YH82!A;G1E<R!D82!A='5A;`!);G-E<FER('5M('!A<N%G
M<F%F;R!A</-S(&\@871U86P`26YS97)I<B!U;2!P87+A9W)A9F\@86YT97,@
M9&\@871U86P`26YS97)I<B!U;2!M;V1E;&\@86QT97)N871I=F\`1F]R;F7G
M82!U;2!E;F1E<F7G;R!D92!E+6UA:6P@;F\@<75A;"!V;V/J('!O9&4@<F5C
M96)E<B!A(&YO=F$@<V5N:&$Z`$EN<V5R:7(@8^EL=6QA(&%P\W,`26YS97)I
M<B!CZ6QU;&$@86YT97,`26YS97)I<B!C;VQU;F$@87#S<P!);G-E<FER(&-O
M;'5N82!A;G1E<P!);G-E<FER(&UE;G-A9V5N<P!);G-E<FER('!A<N%G<F%F
M;R!A</-S`$EN<V5R:7(@<&%RX6=R869O(&%N=&5S`$EN<V5R:7(@;&EN:&$@
M87#S<P!);G-E<FER(&QI;FAA(&%N=&5S`$9O<FYEYV$@82!R97-P;W-T82!O
M8G)I9V%T\W)I82!P87)A(&$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A.@!);G-E
M<FER+T%L=&5R87(@26UA9V5M`$EN<V5R:7(O06QT97)A<B!,:6YK`$-RZ61I
M=&\@:6YS=69I8VEE;G1E('!A<F$@96YV:6%R('!A<F$@82!L:7-T82!D92!D
M:7-T<FEB=6GGXV\N`$-RZ61I=&\@:6YS=69I8VEE;G1E+@!.^FUE<F\@26YT
M96ER;P!,:7-T82!D92!);G1E:7)O<P!#1%4@*$-A8F7G86QH;R!D92!$861O
M<R!D92!5<W7A<FEO*2!I;G;A;&ED;RX`1&%D;W,@6DE0(&EN=N%L:61O<P!!
M<&QI8V'GXV\@:6YVX6QI9&$N`$ED96YT:69I8V'GXV\@9&\@8F%T8V@@:6YV
MX6QI9&$N`$1A9&]S(&5N=FEA9&]S('/C;R!I;G;A;&ED;W,N`$5N9&5R9>=O
M(&1E(&1E<W1I;F\@Z2!I;G;A;&ED;RX`1F]R;6%T;R!D;R!A<G%U:79O(.D@
M:6YVX6QI9&\`3OIM97)O(&1E(&QI8V5NYV$@:6YVX6QI9&\N`$QO8V%L:7IA
MY^-O(&9O<FYE8VED82#I(&EN=N%L:61A+@!4:7!O(&1A(&UE;G-A9V5M(.D@
M:6YVX6QI9&\N`$%P:5]I9"#I(&EN=N%L:61O(&]U(&5S=.$@9F%L=&%N9&\N
M`%!A<N)M971R;W,@:6YVX6QI9&]S(&]U(&9A;'1A;F1O+@!097)M:7-S]65S
M(&1O('!A:2!SXV\@:6YVX6QI9&%S+@!097)M:7-S]65S(&1O('!A:2!SXV\@
M:6YVX6QI9&%S+@!#\V1I9V\@9&\@<')O9'5T;R#I(&EN=N%L:61O+@!0<F]T
M;V-O;&\@:6YVX6QI9&\N`$1E<W1I;F%TX7)I;R!I;G;A;&ED;SH@)R5S)P!/
M8FIE=&\@8V]M<&%R=&EL:&%D;R!I;G;A;&ED;P!&;VYT92!D;R!E;F1E<F7G
M;R!I;G;A;&ED82X`1&%D;W,@=6YI8V]D92!I;G;A;&ED;W,N`$EN=F5N=.%R
M:6\`26YV97)T97(@<V5L9>?C;P!)<N,L(%)E</IB;&EC82!)<VSB;6EC82!D
M;P!)<F%Q=64`27)L86YD80!);&AA(&1O($AO;65M`%1E;7!E<W1A9&5S($ES
M;VQA9&%S`$ES<F%E;`!%;6ES<V]R`$ETX6QI8V\`273A;&EA`$IA;6%I8V$`
M2F%N96ER;P!*87#C;P!*87!O;NIS("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO
M<F3B;FEA`$IU;&AO`$IU;FAO`$IU<W1I9FEC87(`06QI;FAA<B!A;R!#96YT
M<F\`2G5S=&EF:6-A<@!!;&EN:&%R(.`@17-Q=65R9&$`06QI;FAA<B#@($1I
M<F5I=&$`0V%Z87%U:7-TXV\`36%N=&5R(&\@;W)I9VEN86P_`%%UZFYI80!3
M97)V:61O<B!K97)B97)O<R!R96IE:71O=2!A(&%U=&5N=&EC8>?C;RX`3F]V
M871O<R!D92!+97)N96P`0W)I8>?C;R!D92!#:&%V90!);7!R97-SXV\@1&EG
M:71A;"!D82!#:&%V90!486UA;FAO(&1A($-H879E`%1I<&\@9&$@0VAA=F4`
M57-O(&1A($-H879E`$-H879E(&KA(&5X:7-T92!N;R!S97)V:61O<B!D92!C
M:&%V97,@</IB;&EC87,N`$-R:6%NYV%S`$MI<FEB871I`$-O<NEI82P@4F5P
M^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@9&$`0V]RZ6EA+"!297#Z8FQI
M8V$@9&$`0V]R96%N;R`H155#+4M2*0!+=7=A:70`475I<F=U:7-TXV\`3&%?
M>6]U=`!)9&EO;6$`3&%O(%)E</IB;&EC82!$96UO8W+A=&EC82!0;W!U;&%R
M`-IL=&EM82!-971A9&4`VFQT:6UA($UO9&EF:6-AY^-O`$=E<F%R($YO=F$@
M4V5N:&$`VFQT:6UO(%%U87)T;P#:;'1I;6$@071U86QI>F'GXV\Z`-IL=&EM
M;R!L;V=I;CH@)7,`VFQT:6UO(&QO9VEN.B`E<R#@('!A<G1I<B!D92`E<P#:
M;'1I;6\@;&]G:6XZ($YU;F-A`$QE=/1N:6$`3&5I`$QA>6]U=`!$96EX82!V
M87II;R!S92!Q=6ES97(@<V5M(&)O<F1A`$SM8F%N;P!%<W%U97)D80!#86)E
MYV%L:&\@97-Q=65R9&\`5F%L;W)E<R!D82!E<W%U97)D80!,97-O=&\`06UO
M<@!,:6+I<FEA`$SM8FEA(,%R86)E($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I
M;@!#:&EV:7-C;T9R86-O`$-H=79A($9R86-A`$-H=79A($9R86-A($UA='5T
M:6YA`$-H=79A($9R86-A(%9E<W!E<G1I;F$`3&5V97,@4&%N8V%D87,@9&4@
M0VAU=F$`0VAU=F%S($9R86-A<R!C;VT@5')O=O5E<P!.979E($9R86-A`$)R
M979E($YE=F%S8V$`4&_J;6%S`$QI;FL`3&EN:R!A<&]N=&$@<&%R83H`3&EG
M87(@;R!E;F1E<F7G;R!D92!E+6UA:6P@X"!PX6=I;F$@9&4@8V]M<&]S:>?C
M;R!A;R!E>&EB:7(`3&EN:W,`0V]O:VEE(&1O($QI;G5X`$QI<W1A<B`M('5S
M=>%R:6\@<&]D92!V97(@82!P87-T80!,:7-T87(@0F%N8V]S(&1E($1A9&]S
M`$QI<W1A<B!4\W!I8V]S(&1E($%J=61A`$QI<W1A<B!486)E;&%S`$QI<W0M
M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S
M=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$$@;&ES=&%G96T@
M9&4@<V5S<_5E<R!F86QH;W4Z("5S`$$@;&ES=&%G96T@9&4@=7-UX7)I;W,@
M9F%L:&]U.B`E<P!,:7-T86=E;2!D92!U<W7A<FEO<R!E<W3A(&1E<V%B:6QI
M=&%D82X`3&ET97)A='5R80!,:71UXFYI80!#87)R96=A;F1O+BXN`$AO<F$@
M;&]C86PZ(`!,;V-A;&EZ8>?C;R!E($AO<F$`4F5G:>-O`$-O;F5C=&%R`$QO
M9R!D82!S97-SXV\@9&4@<VEN8W)O;FEZ8>?C;R!A;G1E<FEO<@!$97-C;VYE
M8W1A<@!#;VYE8W1A<@!487)E9F%S(&1E($-O;F5XXV\`3R!L;V=I;B!F86QH
M;W4@<&]R<75E('-E=2!U<W7A<FEO(&]U('-E;FAA(&5S=&%V82!I;F-O<G)E
M=&$N`$9A;&AA(&1E($QO9VEN+@!497AT;R!L;VYG;P!!;6]R`$)A:7AA`$%L
M9F%B971O(&=R96=O(&5M(&UI;OIS8W5L;P!!;&9A8F5T;R!L871I;F\@96T@
M;6EN^G-C=6QO`$[Z;65R;W,@<F]M86YO<R!E;2!M:6[Z<V-U;&\`3'5X96UB
M=7)G;P!-30!-3U1$`$\@86YE>&\@35,M5$Y%1B!NXV\@8V]N=.EM(&1A9&]S
M+@!-4T<`36%C86\`36%C961O;FEA+"!!;G1I9V$@4F5P^F)L:6-A($EU9V]S
M;.%V:6$@9&$`36%D86=A<V-A<@!-X6=I8V\`0V]R<F5I;P!!9&UI;FES=')A
M9&]R(&1O($-O<G)E:6\`0W)I87(@;&EN7VLN+BX`36%L87=I`$UA;.%S:6$`
M36%L9&EV87,`36%L:0!-86QT80!'97)E;F-I82!A(&QI<W1A(&1E(&-A=&5G
M;W)I87,@92!A<R!C;W)E<R!A<W-O8VEA9&%S(&$@96QA<RX`36%P96%M96YT
M;R!-87`R-`!-87!E86UE;G1O($UA<%%U97-T`$UA<&5A;65N=&]S(&=R879A
M9&]S+@!-87+G;P!-87)G96T`36%R8V%R(&-O;2!F;&%G<R!,:61A+T[C;R!,
M:61A`$UA<F-A<B!C;VT@;W5T<F]S(&9L86=S("AE>"X@26UP;W)T86YT92]2
M97-P;VYD:61A*0!);&AA<R!-87)S:&%L;`!-87)T:6YI8V$`0V%M<&]S(&-O
M<G)E<W!O;F1E;G1E<P!-875R:73B;FEA`$UA=7+M8VEO`$-RZ61I=&\@;>%X
M:6UO('!E<FUI=&ED;RX`3OIM97)O(&WA>&EM;R!D92!P87)T97,@9&$@;65N
M<V%G96T@97AC961E=2X`5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S
M(#(T(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S(#8@
M:&]R87,Z(`!.^FUE<F\@3>%X:6UO(&1E($%N;W1AY_5E<P!.^FUE<F\@3>%X
M:6UO(&1E($)L;V-O<R!D92!0;W)T86P`5&%M86YH;R!MX7AI;6\`36%I;P!-
M87EO='1E`$UE9&EC:6YA`$UE;6)R;W,`5&5X=&\@9&\@365M;W)A;F1O`$UO
M9&\@9&\@;65N=3H`365S8VQA<B!CZ6QU;&%S`$UE;G-A9V5M`$UE;G-A9V5M
M(%9E<FEF:6-A9&$@8V]M(%-U8V5S<V\@;6%S(&\@8V5R=&EF:6-A9&\@9&\@
M87-S:6YA;G1E(&[C;R!P]&1E('-E<B!V97)I9FEC861O+@!-96YS86=E;2!E
M>'!I<F%D82X`5&EP;R!D92!M96YS86=E;0!#;&EM82!-971A<@!";&]C;R!-
M971A<B!NXV\@9&ES<&]N[79E;"X`0FQO8V\@365T87(@;N-O(&1I<W!O;NUV
M96PN($1E=&%L:&5S(&9O<F%M(&=R879A9&]S(&5M(&QO9R!P87)A(&\@861M
M:6YI<W1R861O<BX`3R!-971A<D1"(&[C;R!E<W3A(&-O;F5C=&%D;RX`3>ET
M;V1O`$WI=&]D;R`G)7,G(&[C;R!E<W3A(&1E9FEN:61O`$WI=&]D;R!NXV\@
M9&5F:6YI9&\N($WI=&]D;R!C:&%M861O.B`E<P!-Z71R:6-A`$WI>&EC;P!-
M:6-R;V[I<VEA+"!%<W1A9&]S($9E9&5R861O<R!D80!-96EO`%1I<&\@36EM
M90!496UP97)A='5R82!M[6YI;6$@;F%S(/IL=&EM87,@,C0@:&]R87,Z(`!4
M96UP97)A='5R82!M[6YI;6$@;F%S(/IL=&EM87,@-B!H;W)A<SH@`$ED861E
M(&WM;FEM82!D82!S96YH82!A:6YD82!NXV\@97AP:7)O=0!%<W!E;&AO`$1I
M=F5R<V]S`%!A8V]T92!014%2($A45%!?4F5Q=65S="!F86QT86YD;RX`0V]N
M9FEG=7)AY^-O(&9A;'1A;F1O+B!6;V/J('1E;2!Q=64@9V5R87(@96QA(&%G
M;W)A('-E('9O8^H@<75E<B!U=&EL:7IA<B!E<W1A(&%P;&EC8>?C;RX`240@
M9&$@;65N<V%G96T@9F%L=&%N9&\N`%!A8V]T92!O8G)I9V%T\W)I;R!014%2
M($UA:6P@9F%L=&%N9&\N`$E$(&1A('-E<W/C;R!F86QT86YD;RX`4V5G`$-O
M<G)E:6\@3?-V96P`36]D97)A<@!$871A($UO9&EF:6-A9&$`06QT97)A<B!5
M4DP`06QT97)A;F1O("5S`$WS9'5L;P!-;VQD;W9A+"!297#Z8FQI8V$@9&$`
M3?1N86-O`$UO;F?S;&EA`$WJ<R!E(&%N;P!-96YS86QM96YT90!-;VYT<V5R
M<F%T`$9A<V5S(&1A($QU80!-86ES(&-A;7!O<R!E;F-O;G1R861O<R!N82!L
M:6YH82`E9"!Q=64@;R!N^FUE<F\@97-P97)A9&\@)60N`$UA<G)O8V]S`$=R
M86YD92!087)T92!,:6UP80!'<F%N9&4@4&%R=&4@3G5B;&%D;P!'<F%N9&4@
M4&%R=&4@16YS;VQA<F%D;P!-;W9E<B!!8F%I>&\`36]V97(@X"!%<W%U97)D
M80!-;W9E<B#@($1I<F5I=&$`36]V97(@06-I;6$`06)A:7AO`$%C:6UA`$UO
MYV%M8FEQ=64`3&ES=&%S(&1E('-E;&7GXV\@9&4@;?IL=&EP;&]S(&[M=F5I
M<P!-87!A<R!);F=L97-E<R!-=6QT:6UA<`!396QEY^-O(&WZ;'1I<&QA`$UI
M;FAA($-O;G1A`%-U87,@26YF;W)M8>?U97,`36EN:&%S($%N;W1AY_5E<P!-
M974@4&]R=&%L`$UE=2!,87EO=70@9&4@4&]R=&%L`$)I<FWB;FEA`$[#3RP@
M174@3L-/($-O;F-O<F1O`$YO;64`3F%M[6)I80!.875R=0!.97!A;`!(;VQA
M;F1A`$%N=&EL:&%S($AO;&%N9&5S87,`55),($)A<V4@9&\@3F5T<V-A<&4`
M55),(&1E(%)E=F]G8>?C;R!D92!#02!D;R!.971S8V%P90!54DP@9&4@<&]L
M[71I8V%S(&1E($-!(&1O($YE='-C87!E`%523"!D92!296YO=F'GXV\@9&\@
M3F5T<V-A<&4`55),(&1E(%)E=F]G8>?C;R!D;R!.971S8V%P90!.;VUE(&1O
M('-E<G9I9&]R(%-33"!D;R!.971S8V%P90!#;VUE;G3A<FEO(&1O(&-E<G1I
M9FEC861O(&1O($YE='-C87!E`%1I<&\@9&4@8V5R=&EF:6-A9&\@9&\@3F5T
M<V-A<&4`4F5D90!.=6YC80!.;W9A($-A;&5D]&YI80!.;W9A($-A=&5G;W)I
M80!.;W9A($UE;G-A9V5M('!A<F$@)7,`3'5A($YO=F$`3F]V82!!;F]T8>?C
M;P!.;W9O(%5S=>%R:6\@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA`$YO=F$@
M<V5N:&$`3F]V82!S96YH82!E>'!I<F%RX2!E;2`E>"X`07,@;F]V87,@<V5N
M:&%S(&[C;R!SXV\@:6=U86ES+@!.;W9A(&IA;F5L82`H7V)L86YK*0!.;W3M
M8VEA<P!'<G5P;W,@9&4@3F]T[6-I87,`4'+S>&EM80!0<O-X:6UA<R`T($9A
M<V5S`%!R\WAI;6%S(&]PY_5E<P!0<O-X:6UA/@!.:6-A<N%G=6$`3FEG97(`
M3FEGZ7)I80!.;VET90!.:75E`$[C;P!.96YH=6T@9&%D;R!D92!C;VYF:6=U
M<F'GXV\@9&ES<&]N[79E;"!P87)A(&5X:6)I<B!A<R!D:69E<F5NYV%S+@!.
M96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(&-R:6%R(&EM86=E
M;G,@25-/+@!.96YH=6T@;6]D96QO(&1E(&)A=&-H+@!.96YH=6T@8FQO8V\@
M97AI<W1E(&YA('!O<VGGXV\@<V]L:6-I=&%D80!.96YH=6T@;F]M92!D92!A
M9V5N9&$@9F]R;F5C:61O('!A<F$@82!A=71E;G1I8V'GXV\@34-!3"X`3F5N
M:'5M82!A;'1E<F'GXV\N`$YE;FAU;2!S=6)O<F1I;F%D;R!P;V1E('-E<B!A
M9&EC:6]N861O(&$@97-T82!P97)M:7-SXV\N`$YE;FAU;6$@:6YF;W)M8>?C
M;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@)7,N`$YE;FAU
M;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A
M<F$@1E10(%9&4RX`3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C
M;R!E<W!E8VEF:6-A9&$@<&%R82!344P@5D93+@!.96YH=6UA(&EN9F]R;6'G
MXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A(%-13"U&:6QE
M(%9&4RX`3F5N:'5M(&-RZ61I=&\@<F5S=&%N=&4N`$YE;FAU;2!D97-T:6YO
M(&9O<FYE8VED;RX`3F5N:'5M(&%R<75I=F\@96YV:6%D;P!.96YH=6T@9&%D
M;R!I0V%L96YD87(@9F]I(&5N8V]N=')A9&\N`$YE;FAU;2#M8V]N92!E;F-O
M;G1R861O+@!.96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+@!.96YH
M=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+@!.96YH=6UA(&UE;G-A9V5M
M(&9O<FYE8VED82X`3F5N:'5M(&YO;64@97-P96-I9FEC861O+@!.96YH=6T@
M8FQO8V\@9&4@;F]T87,@97-TX2!D:7-P;V[M=F5L('!A<F$@8V]N=FED861O
M<RX`3F5N:'5M82!A;F]T8>?C;P!.96YH=6UA(&%N;W1AY^-O(&-O<G)E<W!O
M;F1E(&%O(&-R:73I<FEO(&%T=6%L+@!.96YH=6UA(&%N;W1AY^-O('!A<F$@
M97AI8FER`$YE;FAU;2!N^FUE<F\@97-P96-I9FEC861O+@!396T@<V]R=&5S
M(&]F96YS:79A<P!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T
M96YT:6-AY^-O($A45%`N`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@
M82!A=71E;G1I8V'GXV\@24U!4"X`3F5N:'5M82!S96YH82!F;W)N96-I9&$@
M<&%R82!A(&%U=&5N=&EC8>?C;R!+97)B97)O<RX`3F5N:'5M82!S96YH82!F
M;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!,;V=I;BX`3F5N:'5M82!S
M96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!005-35T0N`$YE
M;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@4TU"
M+@!.96YH=6T@<&%T:"!P87)A(&\@8FENX7)I;R!D;R!/<&5N4U-,(&9O:2!F
M;W)N96-I9&\N($\@8FENX7)I;R!D;R!/<&5N4U-,(.D@;F5C97-SX7)I;R!P
M87)A(&UA;FEP=6QA<B!O<R!D861O<R!02T-3(#$R+@!.96YH=6T@8V%D87-T
M<F\@<&5N9&5N=&4N`%%U;W1A(&[C;R!C;VYF:6=U<F%D82X`4V5M(&QI;FAA
M<P!.96YH=6T@<V5P87)A9&]R(&9O:2!E<W!E8VEF:6-A9&\N`%-E;2!L861O
M<P!!<G%U:79O(&EN97AI<W1E;G1E`$YE;FAU;2!D:7)E=/-R:6\@=&5M<&]R
MX7)I;R!D:7-P;V[M=F5L('!A<F$@;R!C86-H92X`3F5N:'5M('5S=>%R:6\@
M92]O=2!S96YH82!F;W)N96-I9&]S+@!.96YH=6T@9&%D;R!834P@=N%L:61O
M(')E=&]R;F%D;P!396T@=F%L;W)E<P!.96YH=6T@=F5R<^-O(&5N8V]N=')A
M9&$@;F$@8V]N9FEG=7)AY^-O(&]R:6=I;F%L+B!'97)E(&YO=F%M96YT92!A
M(&-O;F9I9W5R8>?C;RX`3F5N:'5M82!V97)SXV\@96YC;VYT<F%D82!N82!S
M=6$@8V]N9FEG=7)AY^-O+B!'97)E(&YO=F%M96YT92!A(&-O;F9I9W5R8>?C
M;RX`06YO7W1AY^-O`$YE;FAU;6$`3F5N:'5M82`H=7-O(&EM<&SM8VET;RD`
M3O-R9&EC;R`H25-/+3@X-3DM,3`I`$EL:&$@3F]R9F]L:P!(96UI<V;I<FEO
M($YO<G1E`$EL:&%S($UA<FEA;F$@9&\@3F]R=&4`3F]R=65G80!.XV\@07#S
M<P!.XV\@06YT97,`3N-O(.D@=6T@9&ER973S<FEO`$[C;R!);7!L96UE;G1A
M9&\N`$[C;R!C;VYF:6=U<F%D;P!.XV\@<W5P;W)T861O+@!#871E9V]R:6$@
M9&$@06YO=&'GXV\`1&5T86QH97,@9&$@06YO=&'GXV\`3&ES=&%G96T@9&4@
M06YO=&'G]65S`%1E>'1O(&1A($%N;W1AY^-O`%]497AT;R!D82!!;F]T8>?C
M;P!!;F]T8>?C;R!NXV\@96YC;VYT<F%D82X`0FQO8V\@9&4@7TYO=&%S`$YO
M;64@9&\@8FQO8V\@9&4@;F]T87,Z`$)L;V-O<R!D92!N;W1A<P!";&]C;W,@
M9&4@;F]T87,@9&5V96T@<&]S<W5I<B!U;2!N;VUE+@!!;F]T8>?U97,`4F5S
M=6UO(&1A<R!!;F]T8>?U97,`3F%D82!P87)A(&5X:6)I<BP@=F]L=&4N`$YO
M=F5M8G)O`$[Z;65R;P!.^FUE<F\@9&4@8V%R86-T97)E<P!.^FUE<F\@9&4@
M8V]L=6YA<P!.^FUE<F\@9&4@;&EN:&%S`$[Z;65R;R!NXV\@97-P96-I9FEC
M861O('!A<F$@871U86QI>F'GXV\@;F$@;&ES=&$@9&4@9&ES=')I8G5IY^-O
M+@!/2P!/8FIE=&\`0W)I861O<B!D;R!/8FIE=&\`3V-T86P`3W5T=6)R;P!&
M:6QT<F\@;V9E;G-I=F\`17-C<FET\W)I;P!396YH87,@86YT:6=A(&4@;F]V
M82!D979E;2!S97(@9&EF97)E;G1E<RX`4V5N:&$@86YT:6=A`%-E;FAA(&%N
M=&EG82!NXV\@97-TX2!C;W)R971A+@!/;>,`4V]M96YT92!S97)V:61O<F5S
M($E-05`@<W5P;W)T86T@<&%S=&%S(&-O;7!A<G1I;&AA9&%S+@!3;VUE;G1E
M('-O<G1E<R!O9F5N<VEV87,`4V]M96YT92!U;2!E;F1E<F7G;R!D92!E+6UA
M:6P@<&5R;6ET:61O+@!3;VUE;G1E(&\@<')O<')I973A<FEO(&]U(&\@861M
M:6YI<W1R861O<B!D;R!S:7-T96UA('!O9&5M(&%L=&5R87(@87,@<&5R;6ES
M<_5E<R!D92!P<F]P<FEE9&%D92!O=2!P<F]P<FEE=.%R:6\@9&4@=6T@8V]M
M<&%R=&EL:&%M96YT;P!!8G)I<B!E;2!U;6$@;F]V82!J86YE;&$`17)R;R!D
M;R!/<&5N4U-,.B!.XV\@<'5D92!E>'1R86ER(&1A9&]S(&1A('!A<G1E(&%S
M<VEN861A(%,O34E-12X`06)R92!E<W1E(&QI;FL@96T@=6UA(&YO=F$@:F%N
M96QA`%-I<W1E;6$@3W!E<F%C:6]N86P`3W#G]65S`$]PY_5E<R!D92`E<P!,
M:7-T82!/<F1E;F%D80!/<F=A;FEZ8>?C;P!5;FED861E($]R9V%N:7IA8VEO
M;F%L`$]R9V%N:7IA;F1O`$UO9&5L;R!O<FEG:6YA;"!D92!A<&QI8V'GXV\`
M36]D96QO(&]R:6=I;F%L(&5M("5S.@!/=71R;P!/=71R87,@26YF;W)M8>?U
M97,`4&5R;6ES<_5E<R!D;R!0<F]P<FEE=.%R:6\`075T96YT:6-AY^-O(%!!
M32!NXV\@97-TX2!D:7-P;V[M=F5L+@!#;VYE8W1O<B!014%2.CI-86EL`$%S
M<VEN871U<F$@1&EG:71A;"!01U``1&%D;W,@0W)I<'1O9W)A9F%D;W,@8V]M
M(%!'4`!#:&%V92!0^F)L:6-A(%!'4`!$861O<R!!<W-I;F%D;W,O0W)I<'1O
M9W)A9F%D;W,@8V]M(%!'4`!#\V1I9V\@4$A0`$QI;FAA(&1E($-O;6%N9&\@
M4$A0`$-H=79A($9R86-A(%9E<W!E<G1I;F$`0VAU=F$@5F5S<&5R=&EN80!#
M:'5V87,@5F5S<&5R=&EN87,`3F5V92!697-P97)T:6YA`$YE=F%S8V$@5F5S
M<&5R=&EN80!.979E(%9E<W!E<G1I;F$`5')O=F]A9&%S(%9E<W!E<G1I;F%S
M`$5S=.$@9F%L=&%N9&\@82!E>'1E;G/C;R!03U-)6`!,:6YH82!D92!#;VUA
M;F1O(%!?2%``36%R9V5M`%!A<75I<W3C;P!086QA=0!086QE<W1I;F\L(%1E
M<G)I=/-R:6\@3V-U<&%D;P!086YA;>$`4.%P=6$@3F]V82!'=6ENZ0!087)A
M9W5A:0!087)C:6%L;65N=&4@3G5B;&%D;P!396YH80!396YH82!A;'1E<F%D
M82!C;VT@<W5C97-S;RX`4V5N:&$@:6YC;W)R971A`%-E;FAA(&]B<FEG873S
M<FEA('!A<F$@82!A=71E;G1I8V'GXV\@4D%$2553+@!396YH82!C;VT@8V]N
M9FER;6'GXV\`4V5N:&$Z`%-E;FAA.B``4V5N:&%S(&1E=F5M('-E<B!I9W5A
M:7,N`$-O;&%R`$-O;&%R(&1A(.%R96$@9&4@=')A;G-F97+J;F-I80!0871H
M`$-A9&%S=')O<R!096YD96YT97,Z`%!E<W-O87,`4&]R8V5N=&%G96T`17AE
M8W5T87(@3W!E<F'G]65S(&1E($UA;G5T96[GXV\`17AE8W5T87(@;W!E<F'G
M]65S(&1E(&UA;G5T96[GXV\@86\@8V]N96-T87(_`%!E<FUI<W/C;P!097)M
M:7-SXV\@(B5S(B!NXV\@97AC;'7M9&$N`%!E<FUI<W/C;R!.96=A9&$`4&5R
M;6ES<_5E<P!!9&UI;FES=')AY^-O(&1E(%!E<FUI<W/U97,`26YF;W)M8>?U
M97,@4&5S<V]A:7,`4&5R=0!!;FEM86ES(&1E($5S=&EM8>?C;P!&:6QI<&EN
M87,`5&5L969O;F4`1F]T;W,`4&ET8V%I<FX`4&EX96QS`$-L:6-HZ0!0;W(@
M9F%V;W(@8VQI<75E(&5M(&%L9W5M82!CZ6QU;&$`4&]R(&9A=F]R(&-O;F9I
M<FUE('%U92!V;V/J('%U97(@<F5M;W9E<B!E<W1E(&5L96UE;G1O.@!0;W(@
M9F%V;W(@8V]N9FER;64@<75E('9O8^H@<75E<B!R96UO=F5R(&\@;&EN:R!D
M97-T92!E;&5M96YT;RX`4&]R(&9A=F]R(&9O<FYEYV$@=6T@;>IS(&4@=6T@
M86YO+@!0;W(@9F%V;W(@9F]R;F7G82!U;2!N;VUE('!A<F$@82!N;W9A(&-A
M=&5G;W)I83H`4&]R(&9A=F]R(&9O<FYEYV$@=6T@96YD97)EYV\@25`@=N%L
M:61O+@!0;W(@9F%V;W(@9F]R;F7G82!U;6$@9&%T82!VX6QI9&$L('9E<FEF
M:7%U92!O(&[Z;65R;R!D92!D:6%S(&YO(&WJ<RX`4&]R(&9A=F]R(&9O<FYE
MYV$@=6UA(&AO<F$@=N%L:61A+@!0;W(@9F%V;W(@9F]R;F7G82!U;2!R97-U
M;6\@9&\@<')O8FQE;6$N`%!O<B!F879O<B!F;W)N9>=A('-E=2!U<W7A<FEO
M(&4@<V5N:&$`4&]R(&9A=F]R(&QE:6$@;R!T97AT;R!A('-E9W5I<BX@5F]C
MZB!$159%(&-O;F-O<F1A<B!C;VT@;W,@=&5R;6]S(&1E('5S;R!D;R!S:7-T
M96UA+@!0;W(@9F%V;W(@9&EG:71E(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I
M83H`4&]L]&YI80!0;VSM=&EC80!%;G%U971E`%!O<G1U9V%L`%!O<VGGXV\@
M9&5S=&$@:6UA9V5M`%!O<VGGXV\@9&5S=&$@=&%B96QA`$5N=FEE('!A<F$@
M97-T82!P87-T82`H;N-O(.D@;V)R:6=A9&\@<&5L;R!)34%0*0!0<F5C:7!I
M=&'GXV\@<&%R82!A*',I(/IL=&EM82AS*2`E<R!H;W)A*',I.B``4')E8VEP
M:71AY^-O/&)R("\^8VAA;F-E`%!R969S7VQD87`Z($5X=&5N<^-O($Q$05`@
M;V)R:6=A=/-R:6$@;N-O(&5N8V]N=')A9&$N`%!R969S7W-E<W-I;VXZ($5X
M=&5N<^-O(&1E('-E<W/C;R!O8G)I9V%T\W)I82!NXV\@96YC;VYT<F%D82X`
M4')E<W/C;P!0<F5S<^-O(&5M(&[M=F5L(&1O(&UA<CH@`%!R97-SXV\Z(`!0
M<NDM=FES=6%L:7IAY^-O`%!R979E<B!A(&EM86=E;2!E;2!U;6$@;F]V82!J
M86YE;&$`3W#G]65S(&%N=&5R:6]R97,`26UP<FEM:7(@9&]C=6UE;G1O`$-H
M879E(%!R:79A9&$`4')O8FQE;6$`1&5S8W)IY^-O(&1O(%!R;V)L96UA`%!R
M;VIE=&]S`%1E>'1O(&)R979E`$-H879E(%#Z8FQI8V$`06QG;W)I=&UO(&1A
M($-H879E(%#Z8FQI8V$`0VAA=F4@4/IB;&EC80!087(@9&4@8VAA=F5S(%#Z
M8FQI8V$O4')I=F%D82!NXV\@9F]R86T@9V5R861O<R!C;VT@<W5C97-S;RX`
M4&]R=&\@4FEC;P!1871A<@!#;VYS=6QT87(`46%T87(`0VAA=F4@4/IB;&EC
M82!24T$@*"5D(&)I="D`0F]T]65S(&1E('-E;&7GXV\`0VAU=F$`0VAU=F$@
M36%T=71I;F$`0VAU=F$@5F5S<&5R=&EN80!086YC861A<R!D92!#:'5V80!#
M:'5V82!E($YE=F4`0VAU=F$@<&%R82!.979E`%-O<G1E($%L96%T\W)I80!2
M96QAY^-O`$QE<@!,97(@;65N<V%G96YS`$5X8VQU:7(@<F5A;&UE;G1E("5S
M/R!%<W1A(&]P97)AY^-O(&[C;R!P;V1E('-E<B!D97-F96ET82X`17AC;'5I
M<B!R96%L;65N=&4@97-T82!A;F]T8>?C;S\`4F5M;W9E<B!R96%L;65N=&4@
M;W,@9&%D;W,@9&\@=7-UX7)I;R`E<S\@17-T82!O<&5R8>?C;R!NXV\@<&]D
M92!S97(@9&5S9F5I=&$N`%)E9F%Z('-U82#Z;'1I;6$@8>?C;P!!='5A;&EZ
M87(`071U86QI>F%R($UE;G4@9&4@16QE;65N=&]S($1I;N)M:6-O<SH`071U
M86QI>F%R($QI<W1A`$%T=6%L:7IA<B!%>&EB:>?C;R!D;R!0;W)T86PZ`%)E
M9V5X`$YA=F5G861O<B!D92!296QAY_5E<P!,97(`3V)S97)V8>?U97,`4V5R
M=FED;W)E<R!296UO=&]S`%523"!296UO=&$@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.@!296UO=F5R`%)E;6]V97(@0FQO8V\`4F5M;W9E<B!C
M871E9V]R:6$`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!F;W)M871AY^-O`%)E
M;6]V97(@<&%R`%)E;6]V97(@<V-R:7!T(&=R879A9&\@;F\@9&ER973S<FEO
M('1E;7!O<N%R:6\@9&\@<V5R=FED;W(N`%)E;6]V97(@;P!296UO=F5R(&5S
M=&4@;O,@9&\@9&]C=6UE;G1O`%)E;6]V97(@=7-UX7)I;P!296UO=F5R('5S
M=>%R:6\Z("5S`%-O;&EC:71AY^-O(&[C;R!P]&1E('-E<B!R97-P;VYD:61A
M+B!#\V1I9V\@9&4@97)R;R!R971O<FYA9&\Z(`!/('-E<G9IYV\@<F5Q=6ES
M:71A9&\@;N-O('!O9&4@<V5R(&5N8V]N=')A9&\N`"<E<R<@;V)R:6=A=/-R
M:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O("5S+@`G
M)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I
M9W5R8>?C;R!61E,N`"<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF
M:6-A9&\@;F$@8V]N9FEG=7)AY^-O+@!#86UP;R!/8G)I9V%T\W)I;P!,:6UP
M87(`1V5R87(@3F]V82!396YH80!'97)A<B!.;W9A(%-E;FAA`-IL=&EM;R!1
M=6%R=&\`4F5S=6QT861O<P!2971O<FYA<B#@($]PY_5E<P!$:6=I=&4@82!N
M;W9A('-E;FAA(&YO=F%M96YT90!2975N:>-O`%)E=F5R=&5R($-O;F9I9W5R
M8>?C;P!/<.?U97,@9&\@161I=&]R(%)I8V@@5&5X=`!#:&%R861A<P!$:7)E
M:71A`$-A8F7G86QH;R!D:7)E:71O`%9A;&]R97,@9&$@9&ER96ET80!0<F]P
M<FEE9&%D97,@9&$@7TQI;FAA+BXN`$9U;N?C;P!2;VWJ;FEA`$=I<F%R(#$X
M,"!G<F%U<P!':7)A<B!P87)A(&$@17-Q=65R9&$`1VER87(@<&%R82!A($1I
M<F5I=&$`4')O<')I961A9&5S(&1A($QI;FAA`%!R;W!R:65D861E<R!D82!L
M:6YH80!,:6YH87,Z`$QI;FAA<P!,:6YH87,@87!A<F5C97+C;R!E;G1R92!T
M;V1A<R!A<R!L:6YH87,@92!C;VQU;F%S`$QI;FAA<R!A<&%R96-E<N-O('-O
M;65N=&4@96YT<F4@8V]L=6YA<P!,:6YH87,@87!A<F5C97+C;R!S;VUE;G1E
M(&5N=')E(&QI;FAA<P!%>&5C=71A<@!&961E<F'GXV\@4G5S<V$`4G5A;F1A
M`$%S<VEN871U<F$@0W)I<'1O9W+A9FEC82!3+TU)344`365N<V%G96T@0W)I
M<'1O9W)A9F%D82!C;VT@4R]-24U%`$%U=&5N=&EC8>?C;R!305-,(&[C;R!E
M<W3A(&1I<W!O;NUV96PN`$-O<G)E:6\@4TU3`$QI;FAA(&1E(&-O;6%N9&\@
M4U%,`%-E;G1E;N=A(%-13"!P87)A('!E<W%U:7-A<R!D92!V86QO<F5S`%-3
M2`!354-%4U-/`$QI;FAA(&1E(&-O;6%N9&\@4U]13`!386(`4V%N=&$@2&5L
M96YA`%/C;R!+:71T<R!E($YE=FES`%-A;G1A($QU>FEA`%/C;R!0961R;R!E
M($UI<75E;&]N`%/C;R!6:6-E;G1E(&4@1W)A;F%D:6YA<P!-97-M;R!Q=6%D
M<F\@*%]S96QF*0!386UO80!386X@36%R:6YO`%/C;R!4;VWI(&4@4'+M;F-I
M<&4`4')O=F5D;W(@9&4@4V%TZ6QI=&4`07+A8FEA(%-A=61I=&$`4V%L=F%R
M`%-A;'9A<B`E<P!386QV87(@)7,`4V%L=F%R($]PY_5E<P!386QV87(@8V]N
M9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M('-C<FEP="!02%`@<&%R82!O(&1I
M<F5T\W)I;R!T96UP;W+A<FEO(&1O('-E=2!S97)V:61O<BX`0V]N9FEG=7)A
MY^-O("5S('-A;'9A+@!38W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG
M=7)AY^-O('-A;'9O(&5M.B`G)7,G+@!496UP97-T861E<R!)<V]L861A<P!#
M:>IN8VEA`%!E<W%U:7-A<@!%;F=I;F5S(&1E(%!E<W%U:7-A(`!297-U;'1A
M9&]S(&1A(%!E<W%U:7-A`$5S8V]P;R!D82!097-Q=6ES80!097-Q=6ES87(@
M7U1E>'1O`%-E;&5C:6]N92!O<R!!<G%U:79O<P!396QE8VEO;F4@=6UA(&1A
M=&$`4V5L96-I;VYE('5M(&=R=7!O('!A<F$@861I8VEO;F%R`%-E;&5C:6]N
M92!U;2!N;W9O(&UE;6)R;P!396QE8VEO;F4@=6T@8FQO8V\@9&4@;F]T87,`
M4V5L96-I;VYE('5M('-E<G9I9&]R`%-E;&5C:6]N92!U;2!U<W7A<FEO('!A
M<F$@861I8VEO;F%R`%-E;&5C:6]N87(@=&]D;W,`4V5L96-I;VYE('1O9&]S
M(&]S(&-O;7!O;F5N=&5S(&1E(&1A=&$N`%-E;&5C:6]N92!U;2!O8FIE=&\`
M3N-O('-E;&5C:6]N87(@;F5N:'5M`$YE;FAU;6$@86YO=&'GXV\@<&%R82!E
M>&EB:7(Z`%-E;&5C:6]N92!O<R!C87)A8W1E<F5S('%U92!V;V/J('!R96-I
M<V$@;F$@8V%I>&$@86)A:7AO+B!6;V/J('!O9&4@96YTXV\@8V]P:>$M;&]S
M(&4@8V]LX2UL;W,@;F$@X7)E82!D92!T97AT;RX`4V5L96-I;VYE('5M(&1E
M;&EM:71A9&]R(&1E(&1A=&$Z`%-E;&5C:6]N92!O(&9O<FUA=&\@9&4@9&%T
M83H`4V5L96-I;VYE(&\@9F]R;6%T;R!P87)A(&5X<&]R=&%R.@!396QE8VEO
M;F4@;R!A<G%U:79O('!A<F$@:6UP;W)T87(Z`%-E;&5C:6]N92!O(&9O<FUA
M=&\@9&\@87)Q=6EV;R!D92!O<FEG96TZ`%-E;&5C:6]N92!A(&ED96YT:61A
M9&4@<75E('9O8^H@<75E<B!A;'1E<F%R.@!396QE8VEO;F4@=6T@9&5L:6UI
M=&%D;W(@9&4@:&]R83H`4V5L96-I;VYE(&\@9F]R;6%T;R!D92!H;W)A.@!3
M96QE8VEO;F4@9&]I<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S+@!396QE8VEO
M;F4@<V5U(&5S<75E;6$@9&4@8V]R97,N`%-E;&5C:6]N92!S974@:61I;VUA
M('!R969E<FED;SH`0V%T96=O<FEA<R!396QE8VEO;F%D87,Z`$5N=FEA<B!2
M96QA=/-R:6\@9&4@4')O8FQE;6$`16YV:6%R(%--4P!396YE9V%L`%-E;G-O
M<CH@`%-E=&5M8G)O`%-E<G9I82!E($UO;G1E;F5G<F\`3OIM97)O(&1E(%/I
M<FEE`$1A9&]S(&1O('-E<G9I9&]R(&5R<F%D;W,@;W4@;N-O(&1I<W!O;NUV
M96ES+@!!9&UI;FES=')A9&]R(&1E(%-E<W/C;P!)1"!D82!397-SXV\@97AP
M:7)O=2X`4V5S<_5E<P!!:G5S=&%R`$-O;F9I9W5R82!A<R!O<.?U97,@<&%R
M82!P97)M:71I<B!V;V/J(&=E<F%R('5M82!N;W9A('-E;FAA('-E('9O8^H@
M97-Q=65CZBUL82X`0V]N9FEG=7)A(&]S('-E<G9I9&]R97,@<F5M;W1O<R!Q
M=64@=F]CZB!Q=65R(&%C97-S87(@X"!P87)T:7(@9&\@<&]R=&%L+@!#;VYF
M:6=U<F$@<V5U(&ED:6]M82!P<F5F97)I9&\L(&9U<V\@:&]RX7)I;R!E(&]P
MY_5E<R!D92!D871A+@!#;VYF:6=U<F$@<W5A(&%P;&EC8>?C;R!I;FEC:6%L
M+"!E<W%U96UA(&1E(&-O<F5S+"!A='5A;&EZ8>?C;R!D92!PX6=I;F%S(&4@
M;W5T<F%S(&]PY_5E<R!D92!E>&EB:>?C;RX`0V]N9FEG=7)AY^-O`%-C<FEP
M=',@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV96ES
M`$1I=F5R<V%S(&QO8V%L:61A9&5S('!O<W/M=F5I<R!C;VT@;R!P87+B;65T
M<F\Z(`!396EC:&5L97,`0V]M<')A<P!297-U;6\`5&5C;&%S(&1E(&%T86QH
M;R!D979E<N-O('-E<B!D969I;FED87,@<&%R82!A(&UA:6]R:6$@9&]S(&QI
M;FMS/P!%>&EB:7(`17AI8FER(&)O=/5E<R!D92!AY^-O/P!%>&EB:7(@87,@
M9&EF97)E;N=A<R!E;G1R92!A(&-O;F9I9W5R8>?C;R!A='5A;"!E(&$@;F]V
M82!G97)A9&$N`$5X:6)I<B!D871A(&4@:&]R82!D82#Z;'1I;6$@8V]N97CC
M;R!A;R!S92!C;VYE8W1A<C\`17AI8FER(&\@;F]M92!D;R!B;&]C;R!D92!N
M;W1A<S\`17AI8FER(&%N;W1AY_5E<R!D97-T87,@8V%T96=O<FEA<P!%>&EB
M:7(@82!O<.?C;R!D92!M86YT97(@;R!O<FEG:6YA;`!%>&EB:7(@<V5L971O
M<@!%>&EB:7(@8F%R<F$@9&4@;65N=2!C;VT@;W!E<F'G]65S(&1E('1A8F5L
M83\`17AI8FER(&\@365N=2`E<R#@(&5S<75E<F1A/P!%>&EB:7(@9&GA;&]G
M;R!D92!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D82!486)E;&$`17AI8FER
M(&1IX6QO9V\@9&4@4')O<')I961A9&5S(&1A(%1A8F5L80!%>&EB:7(@9&GA
M;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@3&EN:&%S(&1A(%1A8F5L80!%>&EB
M:7(@9&GA;&]G;R!D92!P<F]P<FEE9&%D97,@9&4@:6UA9V5M`$5X:6)I<B!U
M<&QO860`0VAU=F%S`$-H=79A<R!M871I;F%I<P!#:'5V87,@5F5S<&5R=&EN
M87,`0VAU=F%S(&YA<R!R961O;F1E>F%S`%)E9'5Z:7(`4')I;65I<F%M96YT
M92!R961U>F$@;W4@=&ER92!D;R!C86UI;FAO(&\H<RD@8FQO8V\H<RD@861J
M86-E;G1E*',I`%-E<G)A($QE;V$`4F5G:7-T<F%R`$%S<VEN871U<F$`06QG
M;W)I=&UO(&1A($%S<VEN871U<F$`0VEN9V%P=7)A`%1A;6%N:&\`26=N;W)A
M<B!-86YU=&5NY^-O`$5S;&]VX7%U:6$`17-L;W9E;FEA`$YE=F4`3F5V87-C
M80!.979A<V-A<P!#:'5V87,@;6%T:6YA:7,`3F5V87-C87,@5F5S<&5R=&EN
M87,`4')O9G5N9&ED861E(&1A($YE=F4Z(`!%<75I=F%L96YT92!D92!N979E
M(&5M(.%G=6$Z(`!);&AA<R!386QO;>-O`%-O;>%L:6$`0V%NY_5E<R`F(%!O
M96UA<P!/<F1E;F%R('!O<B!#871E9V]R:6$`3W)D96YA<B!P96QO('1E>'1O
M(&1A(&%N;W1AY^-O`$]R9&5N87(@<V5L9>?C;P!%;F1E<F7G;R!D92!O<FEG
M96T`P69R:6-A(&1O(%-U;`!3=6P@175R;W!E=2`H25-/+3@X-3DM,RD`4W5L
M(&1A($=E;W)G:6$@92!3=6P@9&%S($EL:&%S(%-A;F1U[6-H90!(96UI<V;I
M<FEO(%-U;`!%<W!AYV\@96YT<F4@8^EL=6QA<R!A9&IA8V5N=&5S`$5S<&'G
M;R!E;G1R92!O(&-O;G1E^F1O(&4@8F]R9&$@9&$@8^EL=6QA`$5S<&'G861O
M<@!%<W!AYV%M96YT;P!%<W!AYV%M96YT;R!E(&UA<F=E;0!%<W!A;FAA`%-P
M86T`16YT<F%D82!D92!#87)A8W1E<F5S($5S<&5C:6%I<P!$:79I9&ER(&/I
M;'5L80!$:79I9&ER(&-O;'5N80!$:79I9&ER(&QI;FAA`$5S<&]R=&5S`%-R
M:2!,86YK80!0861RXV\`4W1A<B!4<F5K`$%N;R!I;FEC:6%L`$5S=&%D;R!O
M=2!0<F]V[6YC:6$`4VET=6'GXV\`1F]R;6%T;R!D;R!A<FUA>F5N86UE;G1O
M`$YO;64@9&$@4G5A`%1R8>=A9&\`3&ES=&$@9&4@8V%D96EA<R!D92!C87)A
M8W1E<F5S`%)E=&ER87(@82!P87)T92!D;R!D;VWM;FEO(&1O(&5N9&5R9>=O
M`$5S=&EL;R!;0U-370!$;VT`4W5B9&ER973S<FEO("<E<R<@;N-O(&5N8V]N
M=')A9&\N`$%S<W5N=&\`16YV:6%R`$5N=FEA9&$@82!S;VQI8VET8>?C;R!D
M92!A9&EC:6]N87(@(B5S(B!A;R!S:7-T96UA+B!6;V/J(&[C;R!P;V1E(&-O
M;F5C=&%R+7-E(&%TZ2!Q=64@<W5A('-O;&EC:71AY^-O('-E:F$@87!R;W9A
M9&$N`%-U8G-C<F5V97(`4W5C97-S;P`G)7,G(&%D:6-I;VYA9&\@8V]M('-U
M8V5S<V\@86\@<VES=&5M82X`3W,@9&%D;W,@9&\@=7-UX7)I;R`G)7,G(&9O
M<F%M(')E;6]V:61O<R!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+@`G)7,G(&5X
M8VQU[61O(&-O;2!S=6-E<W-O+@!%>&-L=>UD;R`G)7,G(&1O('-I<W1E;6$@
M8V]M('-U8V5S<V\N`$-O;F9I9W5R8>?C;R!R979E<G1I9&$@8V]M('-U8V5S
M<V\N($%T=6%L:7IE('!A<F$@=F5R(&%S(&%L=&5R8>?U97,N`"(E<R(@9F]I
M('-A;'9O(&-O;2!S=6-E<W-O+@!"86-K=7`@9&$@8V]N9FEG=7)AY^-O('-A
M;'9A(&-O;2!S=6-E<W-O+@!/(&)A8VMU<"!D;R!A<G%U:79O(&1E(&-O;F9I
M9W5R8>?C;R`E<R!F;VD@<V%L=F\@8V]M('-U8V5S<V\N`"<E<R<@871U86QI
M>F%D;R!C;VT@<W5C97-S;P`E<R!G<F%V861O(&-O;2!S=6-E<W-O`%-U9.-O
M`%)E<W5M;P!!;6%N:&5C97(`4/1R+61O+5-O;`!%;G-O;&%R861O`$%M86YH
M96-E<@!!;6%N:&5C97(O4/1R+61O+5-O;`!!;6%N:&5C97(Z(`!0]'(M9&\M
M4V]L`%#T<BUD;RU3;VPZ(`!3;V)R97-C<F5V97(`4W5P;W)T90!3=7)I;F%M
M90!3;V)R96YO;64`4W9A;&)A<F0@92!*86X@36%Y96X`4W5A>FELXFYD:6$`
M4W7I8VEA`%-U[>=A`$[C;R!E>&-L=6ER`%-Y;F--3`!%<G)O(&1E('-I;G1A
M>&4@;F]S('1E<FUO<R!D82!P97-Q=6ES80!297#Z8FQI8V$@P7)A8F4@9&$@
M4^UR:6$`5&5M<&5S=&%D90!496UP97-T861E<R!E(%9E;G1A;FEA`%1E;7!E
M<W1A9&5S`%1E;7!E<W1A9&5S($UA=&EN86ES`$%R<75I=F\@5%-6`%1A8F5L
M80!0<F]P<FEE9&%D97,@9&$@5&%B96QA`%1A8F5L80!0<F]P<FEE9&%D97,@
M9&$@=&%B96QA`%1A:7=A;@!486EW86XL(%!R;W;M;F-I82!D82!#:&EN80!4
M86II<75I<W3C;P!486YZXFYI82P@4F5P^F)L:6-A(&1A`$%L=F\Z`%1A<F5F
M87,`3OIM97)O(&1E(%1E;&5F;VYE`%1E;7!E<F%T=7)A('!A<F$@82#Z;'1I
M;6$@:&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``5&5M<&5R871U
M<F$\8G(@+SXH)7-!;'1A)7,O)7-"86EX825S*2`F9&5G.R5S`$UO9&5L;R`G
M)7,G(&[C;R!E;F-O;G1R861O+@!!9&UI;FES=')AY^-O(&1E($UO9&5L;W,`
M5&5X=&\`4V]M96YT92!497AT;P!!;&EN:&%M96YT;R!D92!497AT;P!";W)D
M82!S=7!E<FEO<B!D;R!497AT;P!1=6D`5&%I;&%N9.IS("A425,M-C(P*0!4
M86ELXFYD:6$`02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N[79E;"X`
M3R!H:7-T\W)I8V\@9&\@<VES=&5M82!E<W3A(&1E<V%B:6QI=&%D;RX`02!E
M;F=I;F4@9&4@:6YT96=R8>?C;R!(;W)D92]+;VQA8B!NXV\@<W5P;W)T82`B
M)7,B`$\@;&]G($E-4U`@;N-O('!O9&4@<V5R(&EN:6-I86QI>F%D;RX`02!C
M;&%S<V4@(DUA:6YT96YA;F-E(B!NXV\@9F]I(&-A<G)E9V%D82!C;VT@<W5C
M97-S;P!!(&IA;F5L82!D92!/<.?U97,@9F]I(&9E8VAA9&$N(%-A:6YD;RX`
M3R!A9&UI;FES=')A9&]R('!R96-I<V$@8V]N9FEG=7)A<B!U;2!C;VYE8W1O
M<B!P97)M86YE;G1E(&1E(%!E<FUI<W/U97,@<V4@=F]CZB!Q=65R('5T:6QI
M>F%R(%!E<FUI<W/U97,N`%-O;65N=&4@;R!L861O(&1E(&)A:7AO`$\@;OIM
M97)O($E$(&1O(&-O;G1A=&\@;N-O(&9O:2!E<W!E8VEF:6-A9&\L(&1E:7AA
M9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@96YC;VYT<F%D;R!N;R!B86YC;R!D
M92!D861O<RX`3R!C;VYT871O(&9O:2!A9&EC:6]N861O(&-O;2!S=6-E<W-O
M(&%O('-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,N`%!A<F$@=F5R:69I8V%R
M(&$@;65N<V%G96T@87-S:6YA9&$@Z2!N96-E<W/A<FEO('5M(&)L;V-O('-E
M<&%R861O(&1A(&%S<VEN871U<F$@4$=0+@!/($E$(&1A(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@9&5I>&%D;R!E;2!B
M<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YO(&)A;F-O(&1E(&1A9&]S
M+@!!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D
M82X`07,@9G5NY_5E<R!D92!C<FEP=&]G<F%F:6$@<F5Q=65R96T@=6UA(&-O
M;F5XXV\@=V5B('-E9W5R82X`3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N=&5R
M('5M82!C;VYF:6=U<F'GXV\@9&4@)7,N`$\@87)Q=6EV;R`E<R!D979E<FEA
M(&-O;G1E<B!A;&=U;6%S(&-O;F9I9W5R8>?U97,@9&4@)7,N`$\@87)Q=6EV
M;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A(&5L92!M97-M;RX`3R!A<G%U
M:79O(&[C;R!C;VYTZ6T@9&%D;W,N`%-E9W5E;2!O<R!C86)EYV%L:&]S(&1E
M<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F8S@R,BX`R2!S86)I9&\@<75E(&\@
M;6]D;R!T96QA(&-H96EA(&-A=7-A('!R;V)L96UA<R!C;VT@;R!);G1E<FYE
M="!%>'!L;W)E<BP@96T@=FER='5D92!D92!B=6=S(&1O(&YA=F5G861O<B!Q
M=64@;O-S(&[C;R!E<W1A;6]S(&%P=&]S(&$@8V]N=&]R;F%R+B!6;V/J('!O
M9&4@;V)S97)V87(@97)R;W,@9&4@97AI8FGGXV\L(&9A;'1A(&1E(&9U;N?U
M97,@9&\@961I=&]R(&4O;W4@=')A=F%M96YT;W,@86QE873S<FEO<R!D;R!N
M879E9V%D;W(N(%-E('-E=2!S:7-T96UA(.D@5VEN9&]W<R`Y>"#I(&UU:71O
M('!R;W;A=F5L('%U92!V;V/J(')E8V5B82!U;2!E<G)O(&1E("=&86QH82!'
M97)A;"!D92!0<F]T9>?C;R<@92!P<F5C:7-A<N$@<F5I;FEC:6%R+B!<;EQN
M(%9O8^H@9F]I(&%V:7-A9&\N(%!O<B!F879O<B!P<F5S<VEO;F4@3TL@<V4@
M=F]CZB!A:6YD82!Q=65R('1E;G1A<B!U<V%R(&\@961I=&]R(&1E('1E;&$@
M8VAE:6$N`$$@:61E;G1I9&%D92`B)7,B(&9O:2!E>&-L=>UD82X`4V]M96YT
M92!O(&QA9&\@97-Q=65R9&\`02!L;V-A;&EZ8>?C;R!D;R!B:6[A<FEO(&1O
M($=N=5!'(&1E=F4@<V5R(&9O<FYE8VED82#@(&-L87-S92`B0W)Y<'1?<&=P
M(BX`02!M96YS86=E;2!E;G9I861A(&5M("5S('!A<F$@)7,@8V]M(&\@87-S
M=6YT;R`B)7,B(&9O:2!E>&EB:61A+@I)<W1O(&[C;R!G87)A;G1E('%U92!A
M(&UE;G-A9V5M(&9O:2!L:61A(&]U(&5N=&5N9&ED82X`3R!N;VUE('5T:6QI
M>F%D;R!A;R!V:6YC=6QA<B!A('#A9VEN82!D92!C;VUP;W-IY^-O`$$@86YO
M=&'GXV\@9F]I(&5X8VQU[61A+@!/(&)L;V-O(&1E(&YO=&%S("(E<R(@;N-O
M('#T9&4@<V5R(&-R:6%D;SH@)7,`3R!B;&]C;R!D92!N;W1A<R`B)7,B(&9O
M:2!C<FEA9&\N`$\@8FQO8V\@9&4@;F]T87,@(B5S(B!F;VD@97AC;'7M9&\N
M`$\@8FQO8V\@9&4@;F]T87,@(B5S(B!F;VD@<V%L=F\N`$\@;OIM97)O(&1E
M(&-A;7!O<R!D979E('-E<B!N=6WI<FEC;RX`3R!M\V1U;&\@;W!E;G-S;"#I
M(&]B<FEG873S<FEO('!A<F$@82!C;&%S<V4@(DAO<F1E7T-R>7!T7W-M:6UE
M(BX`02!P<F5F97+J;F-I82`B)7,B(&[C;R!P;V1E('-E<B!S86QV82!P;W)Q
M=64@<V5U<R!D861O<R!E>&-E9&5R86T@;R!T86UA;FAO(&WA>&EM;R!P97)M
M:71I9&\`3R!P<F]G<F%M82!U=&EL:7IA9&\@<&%R82!V:7-U86QI>F%R(&5S
M=&4@=&EP;R!D92!D861O("@E<RD@;N-O(&9O:2!E;F-O;G1R861O(&YO('-I
M<W1E;6$N`$\@8V%R86-T97)E('!A<F$@8VET8>?C;R!D92!S97(@87!E;F%S
M('5M+@!3;VUE;G1E(&]S(&QA9&]S(&1I<F5I=&\@92!E<W%U97)D;P!3;VUE
M;G1E(&\@;&%D;R!D:7)E:71O`$\@<V5P87)A9&]R(&1E=F4@<V5R('5M(/IN
M:6-O(&-A<F%C=&5R92X`3R!S97)V:61O<B`B)7,B(&9O:2!E>&-L=>UD;RX`
M3R!S97)V:61O<B`B)7,B(&9O:2!S86QV;RX`02!S;VQI8VET8>?C;R!D92!C
M861A<W1R;R!D92`E<R!F;VD@97AC;'7M9&$N`$$@;&EN:&$@97-P96-I9FEC
M861A("@E9"D@;N-O(&5X:7-T92X`3R!A<G%U:79O('1E;7!O<N%R:6\@(B5S
M(B!NXV\@97AI<W1E+@!/('1E>'1O('%U92!V;V/J(&1I9VET;W4@;N-O(&-O
M<G)E<W!O;F1E(&%O('1E>'1O(&YA('1E;&$N`%-O;65N=&4@;W,@;&%D;W,@
M9&4@8VEM82!E(&1E(&)A:7AO`%-O;65N=&4@;R!L861O(&1E(&-I;6$`3W,@
M9&%D;W,@96YV:6%D;W,@9F]R86T@<&5R9&ED;W,@9&5S9&4@;R!P87-S;R!A
M;G1E<FEO<BX`3R!A<G%U:79O(&5N=FEA9&\@;N-O('#T9&4@<V5R('-A;'9O
M+@!/(&)L;V-O(")W96%T:&5R+F-O;2(@;N-O(&5S=.$@9&ES<&]N[79E;"X`
M3R!D:7)E=/-R:6\@9&4@=&5M87,@)R5S)R!NXV\@9F]I(&5N8V]N=')A9&\N
M`$[C;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M=F5I<RX`3N-O(&5X:7-T96T@
M<&%R=&5S('%U92!P;W-S86T@<V5R(&5X:6)I9&%S(&EN8V]R<&]R861A<RX`
M17AI<W1E;2!M=6ET;W,@8V%R86-T97)E<R!N97-T92!C86UP;RX@5F]CZB!P
M<F5E;F-H974@8V]M("5S(&-A<F%C=&5R97,[('9O8^H@9&5V92!P<F5E;F-H
M97(@8V]M("5S(&]U(&UE;F]S+@!(;W5V92!U;2!P<F]B;&5M82!A9&EC:6]N
M86YD;R`G)7,G(&%O('-I<W1E;6$Z("5S`$AO=79E('5M('!R;V)L96UA(&%O
M(&5X8VQU:7(@9&\@<VES=&5M82!O<R!D861O<R!D;R!U<W7A<FEO("<E<R<Z
M(`!(;W5V92!U;2!P<F]B;&5M82!A;R!E>&-L=6ER("<E<R<@9&\@<VES=&5M
M83H@`$AO=79E('5M('!R;V)L96UA(&%O(&%T=6%L:7IA<B`G)7,G.B`E<P!(
M;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A<G%U:79O.B!.96YH
M=6T@)7,@9F]I(&5N=FEA9&\N`$AO=79E('5M('!R;V)L96UA(&-O;2!O(&5N
M=FEO(&1O(&%R<75I=F\N($\@)7,@97)A(&UA:6]R('%U92!O('1A;6%N:&\@
M;>%X:6UO('!E<FUI=&ED;R`H)60@8GET97,I+@!(;W5V92!U;2!P<F]B;&5M
M82!C;VT@;R!E;G9I;R!D;R!A<G%U:79O+B!/("5S(&9O:2!E;G9I861O('!A
M<F-I86QM96YT92X`2&]U=F4@=6T@97)R;R!A;R!E>&EB:7(@97-T82!P87)T
M92!D82!M96YS86=E;0!(;W5V92!U;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A
M9&]S(&1O(&-O;G1A=&\N`$AO=79E('5M(&5R<F\@86\@:6UP;W)T87(@;W,@
M9&%D;W,Z("5S`$AO=79E('5M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@
M=DYO=&4N`$AO=79E('5M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@=DYO
M=&4N`$AO=79E('5M(&5R<F\@;F\@9F]R;75LX7)I;R!D92!C;VYF:6=U<F'G
MXV\N(%1A;'9E>B!V;V/J(&1E:7AO=2!U;2!C86UP;R!O8G)I9V%T\W)I;R!E
M;2!B<F%N8V\N`$AO=79E('5M(&5R<F\@86\@97AE8W5T87(@82!F=6[GXV\@
M9&4@8V%TX6QO9V\@9&4@96YD97)EYV]S(&5S<&5C:69I8V%D82X@4&]R(&9A
M=F]R('1E;G1E(&YO=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O
M(&%O(')E;6]V97(@82!A;F]T8>?C;SH@)7,`2&]U=F4@=6T@97)R;R!A;R!S
M86QV87(@82!A;F]T8>?C;SH@)7,`2&]U=F4@=6T@97)R;R!A;R!A='5A;&EZ
M87(@;W,@9&5T86QH97,@9&\@8V]N=&%T;RX@4&]R(&9A=F]R('1E;G1E(&YO
M=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T=6%L:7IA
M<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E;G1E(&YO
M=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O('9I<W5A;&EZ
M87(@97-T92!B;&]C;R!D92!N;W1A<SH@)7,`3N-O(&AA=FEA;2!M96UO<F%N
M9&]S('!A<F$@97AP;W)T87(N`$5S=&4@<V5R=FED;W(@24U!4"!NXV\@<W5P
M;W)T82!P87-T87,@8V]M<&%R=&EL:&%D87,N`$5S=&4@;N-O('!A<F5C92!S
M97(@=6T@87)Q=6EV;R!R87(@=N%L:61O+@!%<W1E(&[C;R!P87)E8V4@<V5R
M('5M(&%R<75I=F\@>FEP(';A;&ED;RX`17-T92!NXV\@<&%R96-E('-E<B!U
M;2!N^FUE<F\@9&4@8V%R=.-O(';A;&ED;RX`17-T92!C;VYE8W1O<B!P97)M
M:71E(&5N=FEA<B!M96YS86=E;G,@871R87;I<R!D;R!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI+"!U=&EL:7IA;F1O(&$@05!)($A45%``
M17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R87;I
M<R!D;R!G871E=V%Y('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M+"!U=&EL:7IA;F1O(&\@05!)($A45%``17-T92!C;VYE8W1O<B!P97)M:71E
M(&5N=FEA<B!M96YS86=E;G,@871R87;I<R!D;R!G871E=V%Y('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!U=&EL:7IA;F1O(&\@05!)($A4
M5%``17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!U;6$@;65N<V%G96T@
M=FEA(%--5%`@871R87;I<R!D;R!6;V1A9F]N92!)=&%L:6%N;RP@<V]M96YT
M92!P87)A(&[Z;65R;W,@5F]D869O;F4N(,D@;V)R:6=A=/-R:6\@<&]S<W5I
M<B!U;6$@8V]N=&$@;F\@5F]D869O;F4@271A;&EA;F\@*&AT='`Z+R]W=W<N
M,3DP+FET*2X`17-T92!C86UP;R#I(&]B<FEG873S<FEO+@!%<W1E(&-A;7!O
M('!O9&4@8V]N=&5R(&%P96YA<R!N^FUE<F]S(&EN=&5I<F]S+@!%<W1E(&-A
M;7!O('!O9&4@8V]N=&5R(&%P96YA<R!N^FUE<F]S(&4@=NUR9W5L82X`17-T
M92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O8W1A:7,N`$5S
M=&4@8V%M<&\@9&5V92!S97(@=6UA(&QI<W1A(&1E(&[Z;65R;W,@:6YT96ER
M;W,@<V5P87)A9&$@<&]R(';M<F=U;&%S(&]U(&5S<&'G;W,`17-T92!C86UP
M;R!D979E('-E<B!U;2!N^FUE<F\@=N%L:61O+@!%<W1E(&-A;7!O(&1E=F4@
M8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@96T@9F]R;6%T;R!21T(@2&5X82P@
M<&]R(&5X96UP;&\@)R,Q,C,T868G+@!%<W1E(&9O<FUA=&\@9&4@87)Q=6EV
M;R!NXV\@Z2!S=7!O<G1A9&\N`$5S=&4@9F]R;75LX7)I;R!JX2!F;VD@<')O
M8V5S<V%D;RX`27-T;R#I("5S+@!%<W1E(.D@=6T@;V)J971O($MO;&%B($=R
M;W5P=V%R92X@4&%R82!V:7-U86QI>F%R(&5S=&4@;V)J971O('9O8^H@<')E
M8VES87+A(&1E('5M(&-L:65N=&4@9&4@8V]R<F5I;R!Q=64@96YT96YD82!O
M(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E+B!087)A('5M82!L:7-T82!D92!C
M;&EE;G1E<R!D92!C;W)R96EO(&-O;2!E<W1A<R!F=6[G]65S('!O<B!F879O
M<B!V:7-I=&4@)7,`17-T82!M96YS86=E;2!F;VD@97-C<FET82!E;2!U;2!C
M;VYJ=6YT;R!D92!C87)A8W1E<F5S("@E<RD@<75E(&[C;R#I(&\@;65S;6\@
M<75E(&\@<V5U+@!%<W1E(&[Z;65R;R!D979E('-E<B!P96QO(&UE;F]S('5M
M+@!%<W1E('-E<G9I9&]R(&[C;R!P;V1E(&1E<V-O;7!R:6UI<B!A<G%U:79O
M<R!Z:7`@92!G>FEP+@!%<W1E('-I<W1E;6$@97-TX2!A='5A;&UE;G1E(&1E
M<V%T:79A9&\N`$5S=&4@=F%L;W(@9&5V92!S97(@=6T@;OIM97)O+@!%<W1A
M(&IA;F5L82!D979E('-E<B!C:&%M861A(&$@<&%R=&ER(&1A(&IA;F5L82!D
M92!/<.?U97,`4F%I;P!":6QH971E<P!(;W)A`$%C;VUP86YH86UE;G1O(&1E
M($AO<N%R:6\`1F]R;6%T;R!D92!H;W)A`%-E;&7GXV\@9&4@:&]R80!4:6UO
M<B!,97-T90!4[71U;&\`07-S=6YT;R`H9&EC82DZ`%!A<F$`4&%R82!S96QE
M8VEO;F%R(&WZ;'1I<&QO<R#M=&5N<RP@<V5G=7)E(&$@=&5C;&$@0V]N=')O
M;"`H4$,I(&]U($-O;6UA;F0@*$UA8RD@86\@8VQI8V%R+@!(;VIE`%1R;V-A
M<B!P87)A(&/S9&EG;R!(5$U,`%1O9V\`5&]K96QA=0!!;6%N:.,`5&]N9V$`
M5&]P;P!1=6%D<F\@9&\@5&]P;R`H7W1O<"D`5')A9'7G]65S`%1R:6YD861E
M(&4@5&]B86=O`%9E<F1A9&5I<F\@;W4@9F%L<V\`5&5R`%1U;NUS:6$`5'5R
M<75I80!4=7)C;R`H25-/+3@X-3DM.2D`5'5R8V]M96YI<W3C;P!);&AA<R!4
M=7)K<R!E($-A:6-O<P!4=79A;'4`4')E96YC:&$@8V]M('-U82!E<V-O;&AA
M.B``S6YD:6-E(%4N5BXZ(`!54DP`55),(&1O('-E=2!R96QA=/-R:6\@9&4@
M<VET=6'GXV\@9&4@96YT<F5G80!54DPZ`%5G86YD80!58W+B;FEA`$EM<&]S
M<^UV96P@86-E<W-A<B!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(&%D:6-I
M;VYA<B!I;F9O<FUAY_5E<R!E>'1R87,@9&4@=7-UX7)I;R!A;R!R96=I<W1R
M87(N`$EM<&]S<^UV96P@86QT97)A<B!P97)M:7-SXV\@9&\@87)Q=6EV;R!6
M1E,@(B5S(BX`26UP;W-S[79E;"!A;'1E<F%R('!E<FUI<W/C;R!D;R!A<G%U
M:79O(%9&4R`E<R\E<RX`26UP;W-S[79E;"!A;'1E<F%R('!A<F$@)7,N`$EM
M<&]S<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D;R!A<G%U:79O(&1E("(E
M<R(N`$EM<&]S<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D;R!A<G%U:79O
M(&1E("(E<R\E<R(N`$EM<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@
M4U%,+@!);7!O<W/M=F5L(&-O;F5C=&%R('5T:6QI>F%N9&\@4U-,+@!);7!O
M<W/M=F5L(&-O<&EA<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!C<FEA<B!D
M:7)E=/-R:6\@5D93("(E<R(N`$EM<&]S<^UV96P@8W)I87(@9&ER973S<FEO
M(%9&4RX`26UP;W-S[79E;"!C<FEA<B!A<G%U:79O(%9&4RX`26UP;W-S[79E
M;"!R96YO;65A<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&-R:6%R
M(&%R<75I=F\@5D93('9A>FEO+@!);7!O<W/M=F5L(&1E<V-O;7!R:6UI<B!D
M861O<RX`26UP;W-S[79E;"!E>&-L=6ER("(E<R(L(&\@9&ER973S<FEO(&[C
M;R!E<W3A('9A>FEO+@!);7!O<W/M=F5L(&5X8VQU:7(@(B5S(CH@)7,`26UP
M;W-S[79E;"!E>&-L=6ER("(E<R(Z("5S+@!);7!O<W/M=F5L(&5X8VQU:7(@
M)7,L(&\@9&ER973S<FEO(&[C;R!E<W3A('9A>FEO`$EM<&]S<^UV96P@97AC
M;'5I<B!R96-U<G-I=F%M96YT92!O(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV
M96P@97AC;'5I<B!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@
M9&ER973S<FEO(%9&4SH@)7,N`$EM<&]S<^UV96P@97AC;'5I<B!A<G%U:79O
M(%9&4R`B)7,B+@!);7!O<W/M=F5L(&5X8VQU:7(@87)Q=6EV;R!61E,N`$EM
M<&]S<^UV96P@97AC;'5I<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L
M(&5X8VQU:7(@5D93(')E8W5R<VEV86UE;G1E.B`E<RX`26UP;W-S[79E;"!D
M971E<FUI;F%R(&\@9&ER973S<FEO(&%T=6%L+@!);7!O<W/M=F5L(&5X=')A
M:7(@9&5T86QH97,@9&\@8V5R=&EF:6-A9&\`26UP;W-S[79E;"!C87)R96=A
M<B!A(&1E9FEN:>?C;R!D92`E<RX`26UP;W-S[79E;"!M;W9E<B!O(&%R<75I
M=F\@5D93+@!);7!O<W/M=F5L(&%B<FER(&%R<75I=F\@5D93("(E<R(N`$EM
M<&]S<^UV96P@86)R:7(@87)Q=6EV;R!61E,@<&%R82!G<F%V8>?C;RX`26UP
M;W-S[79E;"!A8G)I<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!A8G)I<B!A
M<G%U:79O(&-O;7!R:6UI9&\N`$EM<&]S<^UV96P@;&5R(&%R<75I=F\@5D93
M("AF:6QE<VEZ92@I(&9A;&AO=2DN`$EM<&]S<^UV96P@;&5R(&%R<75I=F\@
M5D93("AG971&:6QE4VEZ92@I(&9A;&AO=2DN`$EM<&]S<^UV96P@;&5R(&\@
M87)Q=6EV;SH@`$EM<&]S<^UV96P@;&5R(&$@<F%I>B!D;R!D:7)E=/-R:6\@
M5D93+@!);7!O<W/M=F5L(')E;F]M96%R("5S('!A<F$@)7,Z(&$@<&%S=&$@
M9&4@9&5S=&EN;R!JX2!E>&ES=&4`26UP;W-S[79E;"!R96YO;65A<B!O(&1I
M<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@<F5N;VUE87(@9&ER973S<FEO(%9&
M4SH@)7,N`$EM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,@(B5S(BX`
M26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O(%9&4R`E<R\E<RX`26UP;W-S
M[79E;"!R96YO;65A<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!E>&5C=71A
M<B`G;6MI<V]F<R<N`$EM<&]S<^UV96P@=')A9'5Z:7(@97-T92!D;V-U;65N
M=&\@5V]R9`!);7!O<W/M=F5L(&=R879A<B!A<G%U:79O(%9&4R`B)7,B+@!)
M;7!O<W/M=F5L(&=R879A<B!A<G%U:79O(%9&4R`H8V]P>2@I(&9A;&AO=2DN
M`$EM<&]S<^UV96P@9W)A=F%R(&1A9&]S(&1O(&%R<75I=F\@5D93+@!);7!O
M<W/M=F5L(&=R879A<B!A<G%U:79O(%9&4RP@<75O=&$@97AC961E<N$N`%-U
M8FQI;FAA9&\`1&5S9F%Z97(@06QT97)AY_5E<P!$97-F87IE<B!A;'1E<F'G
M]65S`$1E<V9A>B!S=6$@^FQT:6UA(&'GXV\`4F5S<&]S=&$@:6YE<W!E<F%D
M82!D;R!S97)V:61O<B!D=7)A;G1E(&$@8V]N97CC;SH@`%)E<W!O<W1A(&EN
M97-P97)A9&$@9&\@<V5R=FED;W(@<&%R83H@`%-E;2!C871E9V]R:6$`56YI
M8V]D92`H551&+3@I`$5M:7)A9&]S(,%R86)E<R!5;FED;W,`4F5I;F\@56YI
M9&\`17-T861O<R!5;FED;W,`26QH87,@4&5R:6;I<FEC87,@365N;W)E<R!D
M;W,@17-T861O<R!5;FED;W,`56YI9&%D97,`1&5S8V]N:&5C:61O`&%P:6US
M9VED(&1E<V-O;FAE8VED;R`H05!)($UE<W-A9V4@240I+@!C;&EM<V=I9"!D
M97-C;VYH96-I9&\@*$-L:65N="!-97-S86=E($E$*2X`3F5N:'5M82!L;V-A
M;&EZ8>?C;R!C;VYF:6=U<F%D82X`57-UX7)I;R!O=2!S96YH82!D97-C;VYH
M96-I9&]S+@!$97-V:6YC=6QA<B!O(&5L96UE;G1O(&%T=6%L`%-E;2!.;VUE
M`%-C<FEP=',@;N-O('!R:79I;&5G:6%D;W,@;N-O('!O9&5M('5T:6QI>F%R
M($-O<G1A<B]#;W!I87(O0V]L87(@<&]R(')A>O5E<R!D92!S96=U<F%NYV$N
M($-L:7%U92!E;2!/2R!P87)A('9E<B!A(&YO=&$@=.EC;FEC82!E;2!M;WII
M;&QA+F]R9R!A('%U86P@96YS:6YA(&-O;6\@<&5R;6ET:7(@<V-R:7!T<R!A
M8V5S<V%R96T@82#A<F5A(&1E('1R86YS9F5RZFYC:6$N`$1E<VUA<F-A<B!C
M;W(`0V]N=&5N="U4>7!E(&[C;R!S=7!O<G1A9&\Z("5S`$5X=&5N<^-O($[C
M;R!3=7!O<G1A9&$`071U86QI>F%R`"5S(&%T=6%L:7IA9&\`071U86QI>F%R
M('5S=>%R:6\`)R5S)R!A='5A;&EZ861O+@!38W)I<'0@9&4@871U86QI>F'G
MXV\@<F5M;W9I9&\N`$5N=FEA<@!4;V1O<R!A<G%U:79O<R!D92`@8V]N9FEG
M=7)AY_5E<R!D87,@87!L:6-AY_5E<R!F;W)A;2!E;G9I861O<R!A;R!S97)V
M:61O<BX`06QF86)E=&\@;&%T:6YO(&5M(&UA:?IS8W5L;P!.^FUE<F]S(')O
M;6%N;W,@96T@;6%I^G-C=6QO`%5R=6=U86D`571I;&EZ87(@071U86PZ("5S
M`%5T:6QI>F%R(%-33`!5=&EL:7IA<B!S92!O(&YO;64O<V5N:&$@Z2!D:69E
M<F5N=&4@;F\@<V5R=FED;W(@24U34"X`57-UX7)I;W,`57-UX7)I;R`E<R!N
MXV\@97-TX2!A=71O<FEZ861O('!A<F$@)7,N`$%D;6EN:7-T<F'GXV\@9&4@
M57-UX7)I;W,`3W#G]65S(&1E(%5S=>%R:6]S`%)E9VES=')O(&1E(%5S=>%R
M:6]S`%)E9VES=')O(&1E(%5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861O(&YE
M<W1E('-I=&4N`$-O;G1A(&1E('5S=>%R:6\@;N-O(&5N8V]N=')A9&$`57-U
MX7)I;P!5<W7A<FEO("<E<R<@:N$@97AI<W1E+@!5<W7A<FEO.@!5<W7A<FEO
M.B``57-UX7)I;W,@;F\@<VES=&5M83H`57IB97%U:7-TXV\`3R!D:7)E=/-R
M:6\@5D93(&[C;R!E>&ES=&4N`$;I<FEA<P!,;V-A;&EZ8>?U97,@=N%L:61A
M<R!E;F-O;G1R861A<R!I;F-L=65M.B``5F%L:61A9&4`5F%L;W(@96T@;6EN
M=71O<R!A('!A<G1I<B!D92!A9V]R82X`3R!V86QO<B!E<W3A(&%C:6UA(&1O
M('1A;6%N:&\@;>%X:6UO(&1E("5S+@!686QO<F5S`%9A;&]R97,@<&%R82!S
M96QE8VEO;F%R`%9A;G5A='4`5F%R:>%V96P`5F5N97IU96QA`$9A;&AA(&YA
M('9E<FEF:6-AY^-O("T@97-T82!M96YS86=E;2!P;V1E('1E<B!S:61O(&%D
M=6QT97)A9&$N`%9E<G/C;P!#;VYT<F]L92!D92!697)SXV\`06QI;FAA;65N
M=&\@=F5R=&EC86P`36%R9V5M('9E<G1I8V%L`%9E<G1I8V%L.@!-=6ET;R!!
M;'1A`%9I971NXP!6:65T;F%M:71A("A625-#24DI`%9E<B`E<P!6:7-U86QI
M>F%R('5M82!PX6=I;F$@=V5B(&5X=&5R;F$`5FES=6%L:7IA<B!C;VUO("5S
M`$EL:&%S(%9I<F=E;G,L($)R:73B;FEC87,`26QH87,@5FER9V5N<RP@12Y5
M+D$N`%9I<VEB:6QI9&%D90!6:7-I8FEL:61A9&4Z(`!6;V1A9F]N92!)=&%L
M:6%N;R!V:6$@4TU44`!!5$5.Q\-/`$%414['PT\A(2$@4D5-3U9!($\@4T-2
M25!4($U!3E5!3$U%3E1%($1%("5S+@!724X@=FEA($A45%``5V%L;&ES(&4@
M1G5T=6YA`$%T96[GXV\`475A`%!R979I<^-O(&1O(%1E;7!O`$1A9&]S(&1O
M($-L:6UA(&9O<FYE8VED;R!P;W(`5V5A=&AE<BYC;VT`5V5B`%-I=&4@5V5B
M`%-E;6%N86QM96YT90!"96TM=FEN9&\`0F5M+79I;F1O(&%O("5S`$)E;2UV
M:6YD;RP@)7,`3V-I9&5N=&%L("A)4T\M.#@U.2TQ*0!/8VED96YT86P@*$E3
M3RTX.#4Y+3$U*0!386AA<F$@3V-I9&5N=&%L`%%U92!A<&QI8V'GXV\@)7,@
M9&5V97)I82!E>&EB:7(@87#S<R!A(&-O;F5XXV\_`%%U86P@;R!C87)A8W1E
M<F4@9&5L:6UI=&%D;W(_`%%U86P@;R!C87)A8W1E<F4@9&4@8VET8>?C;S\`
M36%P87,@075S=')A;&EA;F]S(%=H97)E:7,`16T@<75A;"!";&]C;R!D92!.
M;W1A<R!A<R!A;F]T8>?U97,@9&5V97+C;R!S97(@861I8VEO;F%D87,_`%%U
M86ES(&9A<V5S`%%U86ES('!L=6=I;G,@:&%B:6QI=&%R('!A<F$@;R!E9&ET
M;W(@4FEC:"!497AT+@!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D97,@0U-3
M`$QA<F=U<F$@9&\@;65N=2`E<R!D;R!L861O(&5S<75E<F1O("AT97+A(&5F
M96ET;R!N82!P<O-X:6UA(&-O;F5XXV\I.@!,87)G=7)A(&1A('1A8F5L80!5
M;FED861E(&1E($QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT;P!696YT;W,@
M<&5L82!M86YHXP!696QO8VED861E(&1O('9E;G1O(&5M(&[S<P!696YT;SH`
M5F5N=&\Z(`!386)E9&]R:6$`3&ES=&$@9&4@<&5D:61O<P!4<F%B86QH;P!%
M;F1E<F7G;R!#;VUE<F-I86P`1F]N92!#;VUE<F-I86P`3OIM97)O(&EN8V]R
M<F5T;R!D92!C86UP;W,@;F$@;&EN:&$@)60N($5S<&5R861O<R`E9"P@96YC
M;VYT<F%D;W,@)60N`$[Z;65R;R!E<G)A9&\@9&4@8V%M<&]S+B!%<W!E<F%D
M;W,@)60L(&5N8V]N=')A9&]S("5D+@!/9F9S970@)60@:6YC;W)R971O(&%O
M(&QE<B!O(&%R<75I=F\@5D93+@!8+5)E9@!297-T<FGG]65S($+A<VEC87,@
M6#4P.78S`%5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U,#EV,P!.
M;VUE($%L=&5R;F%T:79O(&1E($%S<W5N=&\@6#4P.78S`$ED96YT:69I8V%D
M;W(@9&$@0VAA=F4@9&4@07-S=6YT;R!8-3`Y=C,`17AT96YS]65S(%@U,#EV
M,P!!00!!04%!`$UA<&$@66%H;V\A`$%N=6%L;65N=&4`3.IM96X`4VEM`%-I
M;2P@174@0V]N8V]R9&\`5F]CZB!E<W3A(&5M($U/1$\@5$585$\N("!5=&EL
M:7IA(&\@8F]TXV\@6SP^72!P87)A('9O;'1A<B!P87)A(&\@;6]D;R!765-)
M5UE'+@!6;V/J(&[C;R!E<W3A(&%U=&]R:7IA9&\@82!C<FEA<B!M86ES(&1E
M("5D(&)L;V-O<RX`5F]CZB!NXV\@97-TX2!A=71O<FEZ861O(&$@8W)I87(@
M;6%I<R!D92`E9"!N;W1A<RX`5F]CZB!NXV\@97-TX2!A=71E;G1I8V%D;RX`
M5F]CZB!NXV\@<&]D92!T97(@;R!C87)A8W1E<B!<(&YO('-E=2!N;VUE+@!6
M;V/J(&[C;R!F;W)N96-E=2!U;2!E;F1E<F7G;R!D92!E+6UA:6P@=N%L:61O
M+@!6;V/J(&[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R<75I=F\@:6UP
M;W)T861O(&%O<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S(&5M("5S+@!6;V/J
M(&[C;R!T96T@<&5R;6ES<^-O('!A<F$@=FES=6%L:7IA<B!E<W1E(&)L;V-O
M(&1E(&YO=&%S("5S+@!6;V/J(&9O:2!D97-C;VYE8W1A9&\N`%9O8^H@9&5V
M92!P<F5E;F-H97(@=6T@;OIM97)O(&1E('1E;&5F;VYE(&-E;'5L87(@=N%L
M:61O+"!S;VUE;G1E(&3M9VET;W,@8V]M('5M(&]P8VEO;F%L("<K)R!P87)A
M(&1I<V-A9V5M(&1E('!R969I>&\@:6YT97)N86-I;VYA;"X`5F]CZB!D979E
M('!R965N8VAE<B!U;2!V86QO<B!VX6QI9&\N`%9O8^H@9&5V92!C;VYF:6=U
M<F%R('5M(&-O;F5C=&]R($1A=&%4<F5E('!A<F$@=71I;&EZ87(@0V%D87-T
M<F]S+@!6;V/J(&1E=F4@8V]N9FEG=7)A<B!U;2!C;VYE8W1O<B!61E,N`%9O
M8^H@9&5V92!D97-C<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@
M;R!R96QA=/-R:6\@9&4@<')O8FQE;6$N`%9O8^H@9&5V92!F;W)N96-E<B!A
M(%523"!O;F1E(&\@;&EN:R!A<&]N=&$`5F]CZB!D979E('-E;&5C:6]N87(@
M=6T@8FQO8V\@9&4@;F]T87,@<&%R82!S97(@97AC;'7M9&\N`%9O8^H@9&5V
M92!S96QE8VEO;F%R('5M('-E<G9I9&]R('!A<F$@<V5R(&5X8VQU[61O+@!6
M;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(&5X8VQU:7(N
M`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@<F5M;W9E
M<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R82!A9&EC
M:6]N87(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@
M871U86QI>F%R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6UA(&'GXV\@<&%R
M82!E>&5C=71A<BX`5F]CZB!D979E('!R965N8VAE<B!U;2!N;VUE('!A<F$@
M82!N;W9A(&-A=&5G;W)I82X`5F]CZB!P<F5C:7-A(&9O<FYE8V5R('5M(&[Z
M;65R;R!D92!T96QE9F]N92!I=&%L:6%N;P!3=6$@<V5S<^-O("5S(&5X<&ER
M;W4N(%!O<B!F879O<BP@8V]N96-T92US92!N;W9A;65N=&4N`%-E=2!%;F1E
M<F7G;R!D92!%+6UA:6P`4V5U($5N9&5R9>=O(&1E(%)E;65T96YT92`H1&4Z
M*3H`4W5A<R!);F9O<FUAY_5E<P!3974@16YD97)EYV\@9&4@26YT97)N970@
M;75D;W4@9&5S9&4@;R!I;NUC:6\@9&4@<W5A('-E<W/C;R`E<RX@4&%R82!P
M<F]T96=E<B!S=6$@<V5G=7)A;N=A('9O8^H@9&5V92!C;VYE8W1A<BUS92!N
M;W9A;65N=&4N`%-E=2!.;VUE`%-E=2!B86-K96YD(&1E(&%U=&5N=&EC8>?C
M;R!NXV\@<W5P;W)T82!A9&GGXV\@9&4@=7-UX7)I;W,L(&]U(&$@9G5NY^-O
M(&9O:2!D97-A8FEL:71A9&$@<&]R(&%L9W5M82!O=71R82!R87KC;RX`4V5U
M(&)A8VME;F0@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&QI<W1A9V5M
M(&1E('5S=>%R:6]S+"!O=2!A(&9U;N?C;R!F;VD@9&5S86)I;&ET861A('!O
M<B!A;&=U;6$@;W5T<F$@<F%ZXV\N`%-E=2!N879E9V%D;W(@<&%R96-E('1E
M<B!A;'1E<F%D;R!D97-D92!O(&EN[6-I;R!D92!S=6$@<V5S<^-O("5S+B!0
M87)A('!R;W1E9V5R('-U82!S96=U<F%NYV$L('9O8^H@9&5V92!C;VYE8W1A
M<BUS92!N;W9A;65N=&4N`%-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@97-T
M82!F=6[GXV\N`%-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@97-T82!O<.?C
M;R!D92!I;7!R97-SXV\N(%!R97-S:6]N92!#;VYT<F]L+T]P=&EO;B`K(%`@
M<&%R82!I;7!R:6UI<BX`4V5U(&9U<V\@:&]RX7)I;R!A='5A;#H`4W5A(&ED
M96YT:61A9&4@<&%D<N-O(&9O:2!A;'1E<F%D82X`4W5A(&ED96YT:61A9&4@
M<&%D<N-O.@!3974@8FQO8V\@9&4@;F]T87,@<&%D<N-O.@!3974@;F]M92!C
M;VUP;&5T;SH`4W5A(&-O;F5XXV\@97AP:7)O=2X`4W5A(&YO=F$@<V5N:&$@
M<&%R82`E<R#I.B`E<P!3975S(&)L;V-O<R!D92!N;W1A<SH`4W5A<R!O<.?U
M97,@9F]R86T@871U86QI>F%D87,@<&]R(&-A=7-A(&1A(&1U<F'GXV\@9&5S
M=&$@<V5S<^-O+@!3=6%S(&]PY_5E<R!F;W)A;2!A='5A;&EZ861A<RX`4W5A
M(&YO=F$@<V5N:&$@9F]I(&=E<F%D80!3=6$@;F]V82!S96YH82!F;VD@9V5R
M861A+"!V97)I9FEQ=64@<V5U(&4M;6%I;"!E(&-O;F5C=&4M<V4@8V]M('-U
M82!N;W9A('-E;FAA+@!3=6$@<V5N:&$@97AP:7)O=2X`4V5U<R!S97)V:61O
M<F5S(')E;6]T;W,Z`$EU9V]S;.%V:6$`6F%I<F4`6N)M8FEA`%II;6)A8G=E
M`%II<'!Y`%M/8W5L=&%R(%1E>'1O($-I=&%D;UT`6U)E;&%T\W)I;R!D92!0
M<F]B;&5M85T`6T5X:6)I<B!497AT;R!#:71A9&\@+0!;17AI8FER(%1E>'1O
M($-I=&%D;R`M("5S(&QI;FAA<UT`6VQI;FAA("5S(&1E("5S70!?061M:6YI
M<W1R8>?C;P!?5F]L=&%R(&%O($)L;V-O(&1E($YO=&%S`%]#3$D`7T-A=&5G
M;W)I80!$871A7U1R964`15]X8VQU:7(`15]X8VQU:7(@0V]L=6YA`%]%9&ET
M87(`7U!R:6UE:7)A($QI;FAA`%]'<G5P;W,`05]J=61A`%!R;W!R:65D861E
M<R!D82!?26UA9V5M+BXN`%]);7!O<G1A<B]%>'!O<G1A<@!?3&ES=&%R($%N
M;W1AY_5E<P!?0V]N96-T87(`7T1E<V-O;F5C=&%R`$%?;'1E<F%R($QI;FLN
M+BX`36EN:&%S(%]!;F]T8>?U97,`7TYO=F$@06YO=&'GXV\`7T]PY_5E<P!?
M4&5R;6ES<_5E<P!?26UP<FEM:7(`7U)E;6]V97(@3&EN:RXN+@!097-?<75I
M<V%R`$-O;F9I9W5R85]R`%!R;W!R:65D861E<R!D82!?5&%B96QA+BXN`%]5
M<W7A<FEO<P!C873A;&]G;R!D92!E;F1E<F7G;W,`8V%TX6QO9V\@9&4@96YD
M97)EYV]S`&%G96YD80!C86QM;P!I;7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@
M9&4@9&5S=&EN;P!I;7!O<W/M=F5L(&%B<FER(&$@;W)I9V5M`&-L:7%U92!A
M<75I`&5R<F\@9&4@<VEN=&%X92!D82!L:6YH82!D92!C;VUA;F1O`&5R<F\@
M9&4@8V]N9FEG=7)AY^-O`'5M(&%R<75I=F\@8W+M=&EC;R!D;R!S:7-T96UA
M(&5S=.$@9F%L=&%N9&\`97)R;R!N;R!F;W)M871O(&1O<R!D861O<P!E9&ET
M87(`<F5G:7-T<F\@;N-O(&5N8V]N=')A9&\`<75E9&$`87)Q=6EV;P!A('!A
M<G1I<B!D92`E<R`H)7,I(.`@)7,@)7,`8G)I<V$`:#H`:&@`;F]M92!D;R!H
M;W-T(.D@9&5S8V]N:&5C:61O`&EM961I871O`&EN8V]R<&]R861O`&5R<F\@
M9&4@96YT<F%D82]S8>UD80!E<G)O(&EN=&5R;F\@9&\@<')O9W)A;6$`;&EN
M:&%S70!C\V1I9V\@9&4@97)R;R`E9"!D;R!M:VES;V9S(&5N<75A;G1O(&=E
M<F%V82!A($E33RX`;6T`;F]M90!NXV\@:6UP;&5M96YT861O`&[C;R!I;7!L
M96UE;G1A9&\@86EN9&$`8FQO8V\@9&4@;F]T87,`86YO=&%C;V5S+F-S=@!P
M;W)C96YT86=E;0!097)M:7-SXV\`<&EX96QS`&5R<F\@<F5M;W1O(&YO('!R
M;W1O8V]L;P!N87-C96YT90!S97)V:>=O(&EN9&ES<&]N[79E;`!E>&EB:7(@
M9&EF97)E;N=A<P!S;7,R96UA:6P@=FEA($A45%``<W,`97-TX79E;`!E<G)O
M(&1E('-I<W1E;6$`;&ES=&$@9&4@=&%R969A<P!F86QH82!T96UP;W+A<FEA
M`'!R965N8VAA('-U82!S96YH82!D=6%S('9E>F5S('!A<F$@8V]N9FER;6%R
M`'5N:69I8V%D;P!S96T@;F]M90!S96QEY^-O(&1E('5S=>%R:6\`=D-A<F0`
M=DYO=&4`=SH`=V5A=&AE<BYC;VT`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O<'1?4%0O````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S0U`#`R,#`R-0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L
M92]P=%]05"],0U]-15-304=%4R\`````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-#4`,#(Q-C$R`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;6YE;6\O;&]C86QE+W!T7U!4+TQ#7TU%4U-!1T53+VUN96UO+FUO
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#0T-38T,0`Q,#0Q-S,V,C<T-0`P,C,R-S4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````#B!P``'````"P_``"%"@``/'X```````!0J```30```%&H``"_````
MGZ@``&0```!?J0``O@```,2I``"0````@ZH``$,````4JP``/````%BK```K
M````E:L``"X```#!JP``*0```/"K```H````&JP``$4```!#K```1P```(FL
M``!*````T:P``$<````<K0``10```&2M``!(````JJT``#D```#SK0``1@``
M`"VN``!(````=*X``#````"]K@``10```.ZN``!&````-*\``$P```![KP``
M-````,BO```R````_:\``&D````PL```,````)JP```E````R[```(@```#Q
ML```0````'JQ``#V````N[$``$H```"RL@``+````/VR``"%````*K,``$@`
M``"PLP``#@```/FS```/````"+0```T````8M```"````":T```+````+[0`
M``P````[M```!````$BT```;````3;0``"T```!IM```'0```)>T```D````
MM;0``"D```#:M```&0````2U```,````'K4``!$````KM0``"````#VU```E
M````1K4```\```!LM0``"P```'RU```1````B+4```X```":M0``!0```*FU
M```H````K[4```@```#8M0``"@```.&U```5````[+4``!(````"M@``"P``
M`!6V```=````(;8``!,````_M@``#@```%.V```*````8K8```T```!MM@``
M+@```'NV```.````JK8``!$```"YM@``#0```,NV```,````V;8```T```#F
MM@``!@```/2V```*````^[8```\````&MP``&````!:W```,````+[<``!L`
M```\MP``!@```%BW```.````7[<```X```!NMP``"````'VW```)````AK<`
M`$(```"0MP``+@```-.W```:`````K@``#(````=N```.````%"X``!4````
MB;@``%$```#>N```6@```#"Y``!7````B[D``#0```#CN0``"0```!BZ```-
M````(KH```<````PN@``"@```#BZ```/````0[H```4```!3N@``!@```%FZ
M```1````8+H```@```!RN@``"0```'NZ```)````A;H``"4```"/N@``(```
M`+6Z```<````UKH``!X```#SN@``(````!*[```=````,[L``!````!1NP``
M#P```&*[```*````<KL```,```!]NP``#P```(&[```4````D;L```D```"F
MNP``#0```+"[```2````OKL``!D```#1NP``'@```.N[```/````"KP```P`
M```:O```"@```">\```/````,KP```@```!"O```)````$N\```4````<+P`
M`!8```"%O```"````)R\``!.````I;P``"T```#TO```$0```"*]```?````
M-+T``!D```!4O0``!P```&Z]```,````=KT``"P```"#O0``#@```+"]```#
M````O[T```L```##O0``!P```,^]```'````U[T```4```#?O0``!0```.6]
M```*````Z[T```,```#VO0``%P```/J]```*````$KX```\````=O@``#@``
M`"V^```8````/+X``",```!5O@``#@```'F^```4````B+X``!<```"=O@``
M%P```+6^```7````S;X``!,```#EO@``#P```/F^```.````";\``!\````8
MOP``'0```#B_```'````5K\```8```!>OP``"````&6_```/````;K\```8`
M``!^OP``"@```(6_```3````D+\```L```"DOP``%0```+"_```5````QK\`
M``<```#<OP``$````.2_```%````];\``!4```#[OP``$0```!'````,````
M(\```#L````PP```.````&S````)````I<````<```"OP```%````+?````#
M````S,````4```#0P```"0```-;````0````X,````D```#QP```$P```/O`
M```Y````#\$``!(```!)P0``)P```%S!```L````A,$``"H```"QP0``)0``
M`-S!```*`````L(```8````-P@``"0```!3"```'````'L(``"\````FP@``
M-P```%;"```N````CL(``%4```"]P@``+0```!/#```M````0<,``"T```!O
MPP``0````)W#```C````WL,``",````"Q```+0```";$```S````5,0``!4`
M``"(Q```&0```)[$```I````N,0``"0```#BQ```%0````?%```1````'<4`
M``H````OQ0``#````#K%```/````1\4``!<```!7Q0``"@```&_%```0````
M>L4``!8```"+Q0``%@```*+%```'````N<4```<```#!Q0``%````,G%```*
M````WL4```@```#IQ0``"````/+%```'````^\4```<````#Q@``!@````O&
M```%````$L8```<````8Q@``!@```"#&```(````)\8``"D````PQ@``#@``
M`%K&```*````:<8```0```!TQ@``!P```'G&```)````@<8```8```"+Q@``
M$0```)+&```'````I,8``!8```"LQ@``!````,/&```(````R,8```8```#1
MQ@``#0```-C&```&````YL8``!X```#MQ@``$0````S'```B````'L<``!8`
M``!!QP``"````%C'```-````8<<```P```!OQP``!P```'S'```#````A,<`
M``,```"(QP``%P```(S'```#````I,<``!,```"HQP``'0```+S'```(````
MVL<```0```#CQP``"````.C'```(````\<<``$$```#ZQP``(````#S(```&
M````7<@```8```!DR```%0```&O(```8````@<@``"(```":R```+@```+W(
M```=````[,@``"$````*R0``5````"S)```I````@<D```H```"KR0``!P``
M`+;)```5````OLD```@```#4R0``#@```-W)```*````[,D```\```#WR0``
M#0````?*```/````%<H```T````ER@``"0```#/*```4````/<H```8```!2
MR@``&````%G*```=````<LH``!,```"0R@``$0```*3*```4````MLH```0`
M``#+R@``!@```-#*```5````U\H``%0```#MR@``+0```$++```$````<,L`
M``X```!URP``1````(3+```%````R<L```4```#/RP``&P```-7+```:````
M\<L``!$````,S```$0```![,```<````,,P``"H```!-S```-P```'C,```<
M````L,P``!````#-S```(0```-[,```E`````,T``!D````FS0``!0```$#-
M```*````1LT``!,```!1S0``$@```&7-```*````>,T```\```"#S0``#0``
M`)/-```1````H<T``!,```"SS0``#````,?-```&````U,T```P```#;S0``
M!@```.C-```7````[\T``!`````'S@``$0```!C.```(````*LX```4````S
MS@``#````#G.```0````1LX```4```!7S@``#0```%W.```&````:\X```<`
M``!RS@``#0```'K.```0````B,X```D```"9S@``!P```*/.```+````J\X`
M``L```"WS@``!P```,/.```'````R\X``!0```#3S@``"0```.C.```)````
M\LX```H```#\S@``&0````?/```=````(<\```P````_SP``$````$S/```%
M````7<\``"4```!CSP``$@```(G/```3````G,\``"L```"PSP``.P```-S/
M```@````&-```#8````YT```(0```'#0```0````DM````@```"CT```#```
M`*S0```&````N=````0```#`T```#@```,70```0````U-````H```#ET```
M#0```/#0```>````_M```!L````=T0``(0```#G1```>````6]$``!D```!Z
MT0``'@```)31```;````L]$``"X```#/T0``%P```/[1```F````%M(``#``
M```]T@``&P```&[2```>````BM(``!P```"IT@``)@```,;2```K````[=(`
M`#,````9TP``)@```$W3```K````=-,``#@```"@TP``'0```-G3```5````
M]],``"\````-U```(````#W4```2````7M0``"D```!QU```'@```)O4```2
M````NM0``*(```#-U```%@```'#5```C````A]4``"@```"KU0``*0```-35
M```H````_M4``!\````GU@``%0```$?6```@````7=8``"4```!^U@``*```
M`*36```M````S=8``#````#[U@``D@```"S7```A````O]<``!8```#AUP``
M'````/C7```F````%=@``"H````\V```00```&?8``!$````J=@```P```#N
MV```!P```/O8```'`````]D```8````+V0``#0```!+9```0````(-D``!(`
M```QV0``!P```$39```3````3-D``!(```!@V0``!P```'/9```$````>]D`
M`!````"`V0``#````)'9```.````GMD```\```"MV0``$P```+W9```-````
MT=D``"@```#?V0```P````C:```-````#-H```8````:V@``$0```"':```7
M````,]H``!L```!+V@``#@```&?:```"````=MH```4```!YV@``$````'_:
M```$````D-H```T```"5V@``#@```*/:```#````LMH```X```"VV@``"```
M`,7:```/````SMH```\```#>V@``!P```.[:```-````]MH``!`````$VP``
M#P```!7;```3````)=L``!,````YVP``&0```$W;```:````9]L```L```""
MVP``!@```([;```,````E=L``!$```"BVP``&0```+3;```+````SML```T`
M``#:VP``(@```.C;```;````"]P``#0````GW```"@```%S<```8````9]P`
M`!D```"`W```%@```)K<```0````L=P``"\```#"W```(@```/+<```-````
M%=T```<````CW0``"@```"O=```4````-MT```L```!+W0``#````%?=```B
M````9-T``"\```"'W0``"P```+?=```)````P]T``!D```#-W0``"P```.?=
M```7````\]T``!<````+W@``"0```"/>```6````+=X```\```!$W@``&0``
M`%3>```6````;MX```X```"%W@``&````)3>```(````K=X```T```"VW@``
M)@```,3>``!#````Z]X```@````OWP``$@```#C?```(````2]\```L```!4
MWP``+P```&#?```.````D-\```4```"?WP``!@```*7?```#````K-\```<`
M``"PWP``!````+C?```*````O=\```H```#(WP``"0```-/?```/````W=\`
M`!````#MWP``%P```/[?```:````%N```!$````QX```&0```$/@```7````
M7>````D```!UX```!0```'_@```+````A>````H```"1X````@```)S@```%
M````G^````T```"EX```&P```+/@```7````S^````D```#GX```"@```/'@
M```.````_.````T````+X0``$@```!GA```X````+.$``"````!EX0``"```
M`(;A```.````C^$``'L```">X0``&````!KB``!`````,^(``!$```!TX@``
M!P```(;B```%````CN(``!D```"4X@``$P```*[B```'````PN(```<```#*
MX@``"````-+B```&````V^(```8```#BX@``$````.GB```/````^N(``!``
M```*XP``#P```!OC```+````*^,```\````WXP``#````$?C```/````5.,`
M``<```!DXP``"@```&SC```&````=^,```X```!^XP``#````(WC```H````
MFN,```\```##XP``"````-/C```&````W.,```P```#CXP``%@```/#C```(
M````!^0``!,````0Y```"@```"3D```>````+^0``"$```!.Y```(````'#D
M```9````D>0``!<```"KY```)0```,/D```7````Z>0```0````!Y0``&P``
M``;E```-````(N4```P````PY0```P```#WE```(````0>4```H```!*Y0``
M#````%7E```+````8N4``!````!NY0``#````'_E```$````C.4``!,```"1
MY0``%````*7E```,````NN4```D```#'Y0``#@```-'E```+````X.4``!L`
M``#LY0``!P````CF```'````$.8```H````8Y@``#0```"/F```)````,>8`
M``0````[Y@``!0```$#F```#````1N8``!@```!*Y@``"@```&/F```$````
M;N8``"8```!SY@``#@```)KF``!\````J>8``!4````FYP``!0```#SG```'
M````0N<```P```!*YP``"````%?G```*````8.<```8```!KYP``"````'+G
M```6````>^<``!(```"2YP```@```*7G```&````J.<```8```"OYP``%```
M`+;G```-````R^<``!````#9YP``&P```.KG```$````!N@```D````+Z```
M$````!7H```)````)N@```D````PZ```!0```#KH```%````0.@``!H```!&
MZ```"````&'H```&````:N@``!D```!QZ```#@```(OH```B````FN@```<`
M``"]Z```!P```,7H```.````S>@```4```#<Z```"0```.+H```*````[.@`
M``(```#WZ```!@```/KH```-`````>D```D````/Z0``!@```!GI```2````
M(.D```D````SZ0``!P```#WI```4````1>D``!T```!:Z0``$0```'CI```&
M````BND```H```"1Z0``!````)SI```)````H>D```@```"KZ0``$0```+3I
M```1````QND```D```#8Z0``!@```.+I```-````Z>D```8```#WZ0``!```
M`/[I```Y`````^H``#T````]Z@``.@```'OJ```>````MNH```4```#5Z@``
M#@```-OJ```$````ZNH```8```#OZ@``(0```/;J```-````&.L``!4````F
MZP``!@```#SK```$````0^L``!$```!(ZP``!@```%KK``"@````8>L```H`
M```"[```(@````WL```$````,.P``"4````U[```!0```%OL```=````8>P`
M``0```!_[```#````(3L```*````D>P```@```"<[```"0```*7L```%````
MK^P``!L```"U[```.@```-'L```P````#.T``#4````][0``*0```'/M```N
M````G>T``$<```#,[0``.````!3N```I````3>X``#\```!W[@``+@```+?N
M```M````YNX``!\````4[P``#P```#3O```2````1.\```L```!7[P``)@``
M`&/O```I````BN\``"0```"T[P``)@```-GO```(`````/````H````)\```
M"0```!3P```'````'O```"`````F\```(````$?P```F````:/````H```"/
M\```&0```)KP```I````M/```!8```#>\```$@```/7P```'````"/$```H`
M```0\0``#P```!OQ```0````*_$``$`````\\0``<````'WQ``!F````[O$`
M``X```!5\@``"0```&3R```*````;O(``!(```!Y\@``$P```(SR```,````
MH/(```8```"M\@``%0```+3R```/````RO(``!,```#:\@``$@```.[R```0
M`````?,``!$````2\P``'````"3S```C````0?,``&H```!E\P``#P```-#S
M```%````X/,``!````#F\P``"0```/?S```$`````?0```L````&]```(```
M`!+T```:````,_0``!0```!.]```#````&/T```,````</0```\```!]]```
M%0```(WT```I````H_0``"H```#-]```)@```/CT```G````'_4``"D```!'
M]0``*@```''U```9````G/4``$(```"V]0``$0```/GU```2````"_8``!,`
M```>]@``%````#+V```/````1_8``!8```!7]@``%P```&[V```0````AO8`
M`!$```"7]@``-````*GV```3````WO8``!(```#R]@``-0````7W```4````
M._<```<```!0]P``#````%CW```@````9?<``!````"&]P``%````)?W```1
M````K/<``!<```"^]P``'````-;W```3````\_<``!0````'^```&@```!SX
M```1````-_@``!H```!)^```'@```&3X```:````@_@``!,```">^```%0``
M`++X```1````R/@``!<```#:^```%````/+X```7````!_D``!4````?^0``
M"0```#7Y```9````/_D```0```!9^0``!P```%[Y```+````9OD``!$```!R
M^0``!@```(3Y```&````B_D```8```"2^0``!0```)GY```'````G_D```<`
M``"G^0``!0```*_Y```6````M?D```8```#,^0``!@```-/Y```$````VOD`
M``0```#?^0``!P```.3Y```.````[/D```P```#[^0``#`````CZ```-````
M%?H```H````C^@``#@```"[Z```%````/?H``"@```!#^@``#@```&SZ```,
M````>_H```\```"(^@``"@```)CZ```(````H_H```D```"L^@``*P```+;Z
M```$````XOH```@```#G^@``)@```/#Z```2````%_L```\````J^P``!@``
M`#K[```*````0?L```<```!,^P``"````%3[```@````7?L```D```!^^P``
M#0```(C[```,````EOL```T```"C^P``#@```+'[```6````P/L``!$```#7
M^P``!@```.G[```#````\/L```8```#T^P``&0```/O[```'````%?P```0`
M```=_```"P```"+\```+````+OP```<````Z_```!P```$+\```6````2OP`
M``T```!A_```#0```&_\```*````??P``!````"(_```#P```)G\```1````
MJ?P``!<```"[_```"@```-/\```1````WOP```@```#P_```!````/G\```/
M````_OP``#H````._0``!0```$G]```,````3_T``!X```!<_0``#@```'O]
M```0````BOT```L```";_0``#````*?]```)````M/T```<```"^_0``"@``
M`,;]```)````T?T```X```#;_0``$````.K]```:````^_T```H````6_@``
M"0```"'^```4````*_X```H```!`_@``#````$O^```/````6/X```@```!H
M_@``!@```''^```'````>/X```L```"`_@``1P```(S^```-````U/X```D`
M``#B_@``!````.S^```#````\?X``!,```#U_@``$P````G_```3````'?\`
M``H````Q_P```@```#S_```$````/_\``"4```!$_P```P```&K_```%````
M;O\``"H```!T_P``"@```)__```%````JO\```0```"P_P``"@```+7_```-
M````P/\``$````#._P``$P````\``0`&````(P`!``@````J``$`"````#,`
M`0`$````/``!``4```!!``$`:````$<``0`)````L``!``P```"Z``$`!0``
M`,<``0`&````S0`!`!L```#4``$`+P```/```0`0````(`$!``H````Q`0$`
M#P```#P!`0`*````3`$!``D```!7`0$`$P```&$!`0`;````=0$!`!@```"1
M`0$`%P```*H!`0`.````P@$!``,```#1`0$`!P```-4!`0`(````W0$!``<`
M``#F`0$`"0```.X!`0`*````^`$!``L````#`@$`+0````\"`0`5````/0(!
M`#````!3`@$`)````(0"`0`'````J0(!`%$```"Q`@$`$`````,#`0`,````
M%`,!``T````A`P$`&@```"\#`0!*````2@,!`!D```"5`P$`!@```*\#`0`:
M````M@,!``8```#1`P$`!@```-@#`0`?````WP,!``8```#_`P$`"0````8$
M`0`8````$`0!`!<````I!`$`!@```$$$`0`-````2`0!`"(```!6!`$`5P``
M`'D$`0`3````T00!`",```#E!`$`$P````D%`0`"````'04!``L````@!0$`
M"````"P%`0`-````-04!``H```!#!0$`#````$X%`0`&````6P4!``<```!B
M!0$`%````&H%`0`&````?P4!``@```"&!0$`#@```(\%`0`'````G@4!``H`
M``"F!0$`"P```+$%`0`'````O04!``P```#%!0$`#0```-(%`0`,````X`4!
M``D```#M!0$`"0```/<%`0`*`````08!``<````,!@$`"0```!0&`0`'````
M'@8!``H````F!@$`&P```#$&`0`2````308!``H```!@!@$`"````&L&`0`)
M````=`8!`!````!^!@$`!P```(\&`0`2````EP8!``0```"J!@$`!P```*\&
M`0`%````MP8!``4```"]!@$`"P```,,&`0`4````SP8!`!$```#D!@$`&@``
M`/8&`0`6````$0<!`!0````H!P$`%P```#T'`0`8````50<!`!P```!N!P$`
M&0```(L'`0`'````I0<!``4```"M!P$`#0```+,'`0`,````P0<!``@```#.
M!P$`"````-<'`0`7````X`<!``L```#X!P$`$P````0(`0`$````&`@!``H`
M```="`$`!````"@(`0`-````+0@!``P````["`$`!0```$@(`0`)````3@@!
M``4```!8"`$`!P```%X(`0`%````9@@!``0```!L"`$``@```'$(`0`X````
M=`@!`"P```"M"`$`$@```-H(`0`I````[0@!`#(````7"0$`"@```$H)`0`V
M````50D!`"P```","0$`%0```+D)`0`N````SPD!`#,```#^"0$`,P```#(*
M`0`X````9@H!``\```"?"@$`&````*\*`0`[````R`H!`!`````$"P$`'```
M`!4+`0`4````,@L!`!,```!'"P$`%0```%L+`0`4````<0L!`!(```"&"P$`
M)````)D+`0`(````O@L!`"0```#'"P$`$P```.P+`0`4``````P!`!4````5
M#`$`+0```"L,`0`M````60P!`#$```"'#`$`+0```+D,`0`N````YPP!`"\`
M```6#0$`+````$8-`0!B````<PT!`!,```#6#0$`"````.H-`0`(````\PT!
M`"L```#\#0$`(0```"@.`0`:````2@X!``D```!E#@$`10```&\.`0!!````
MM0X!``4```#W#@$`!````/T.`0`3`````@\!`!0````6#P$`#@```"L/`0`3
M````.@\!`!@```!.#P$`!@```&</`0`)````;@\!``H```!X#P$`#P```(,/
M`0`0````DP\!``<```"D#P$`#@```*P/`0`-````NP\!``P```#)#P$`"@``
M`-8/`0`)````X0\!``H```#K#P$`#P```/8/`0`(````!A`!``\````/$`$`
M"````!\0`0`:````*!`!``4```!#$`$`#0```$D0`0`;````5Q`!``8```!S
M$`$`"````'H0`0`&````@Q`!`!0```"*$`$`$0```)\0`0`.````L1`!`#@`
M``#`$`$``@```/D0`0`&````_!`!``X````#$0$`&@```!(1`0`%````+1$!
M``<````S$0$`#@```#L1`0`&````2A$!``0```!1$0$`*0```%81`0`7````
M@!$!`!\```"8$0$`7````+@1`0`4````%1(!`#X````J$@$`'P```&D2`0`0
M````B1(!``<```":$@$`#@```*(2`0`(````L1(!``P```"Z$@$`#````,<2
M`0`3````U!(!``H```#H$@$`'0```/,2`0`9````$1,!``4````K$P$`$0``
M`#$3`0`-````0Q,!`!$```!1$P$`)````&,3`0`5````B!,!`!(```">$P$`
M#@```+$3`0`9````P!,!``@```#:$P$`"0```.,3`0`-````[1,!``H```#[
M$P$`!P````84`0`/````#A0!``8````>%`$`"P```"44`0`*````,10!``<`
M```\%`$`"````$04`0`%````310!`!\```!3%`$`!@```',4`0`0````>A0!
M``@```"+%`$`#0```)04`0`(````HA0!`!(```"K%`$`+````+X4`0`:````
MZQ0!``D````&%0$`"@```!`5`0`5````&Q4!``4````Q%0$`%````#<5`0`$
M````3!4!`!````!1%0$`!@```&(5`0`'````:14!`!X```!Q%0$`*````)`5
M`0`*````N14!`!P```#$%0$`$0```.$5`0`+````\Q4!`!H```#_%0$`#P``
M`!H6`0`4````*A8!``0````_%@$`!````$06`0`+````218!``4```!5%@$`
M!@```%L6`0`(````8A8!``8```!K%@$`"@```'(6`0`;````?18!`#0```"9
M%@$`-````,X6`0`@`````Q<!`"D````D%P$`(````$X7`0!!````;Q<!`!H`
M``"Q%P$`*````,P7`0`I````]1<!`%$````?&`$`+P```'$8`0`B````H1@!
M``8```#$&`$`"````,L8`0`%````U!@!``@```#:&`$`&0```.,8`0`9````
M_1@!`"H````7&0$`(P```$(9`0`9````9AD!`"X```"`&0$`-````*\9`0`(
M````Y!D!`!<```#M&0$`"@````4:`0`'````$!H!`"$````8&@$`$````#H:
M`0`.````2QH!``L```!:&@$`!P```&8:`0`3````;AH!``@```""&@$`"P``
M`(L:`0`*````EQH!`!0```"B&@$`#P```+<:`0`R````QQH!``L```#Z&@$`
M!0````8;`0`%````#!L!`!<````2&P$`#P```"H;`0`$````.AL!``H````_
M&P$`"0```$H;`0`+````5!L!``T```!@&P$`#````&X;`0`.````>QL!``4`
M``"*&P$`!````)`;`0`-````E1L!`#(```"C&P$`10```-8;`0`7````'!P!
M`!X````T'`$`#````%,<`0`4````8!P!``4```!U'`$`%````'L<`0`'````
MD!P!``X```"8'`$`*@```*<<`0`&````TAP!``P```#9'`$`#P```.8<`0`-
M````]AP!`!$````$'0$`"P```!8=`0`V````(AT!``H```!9'0$`(@```&0=
M`0`+````AQT!``\```"3'0$`,@```*,=`0`E````UAT!`#````#\'0$`,0``
M`"T>`0`M````7QX!``X```"-'@$`!0```)P>`0`.````HAX!`!,```"Q'@$`
M!P```,4>`0`:````S1X!``@```#H'@$`$0```/$>`0`'`````Q\!`!0````+
M'P$`&````"`?`0`'````.1\!``4```!!'P$`#````$<?`0`,````5!\!`!(`
M``!A'P$`!````'0?`0`'````>1\!``H```"!'P$`"P```(P?`0`,````F!\!
M``X```"E'P$`#@```+0?`0`%````PQ\!``4```#)'P$`+@```,\?`0`F````
M_A\!`",````E(`$``P```$D@`0`2````32`!``8```!@(`$`'@```&<@`0`8
M````AB`!`"4```"?(`$`#0```,4@`0`)````TR`!``,```#=(`$`!P```.$@
M`0`*````Z2`!``(```#T(`$`#````/<@`0`5````!"$!``L````:(0$`&0``
M`"8A`0`@````0"$!`!(```!A(0$`!0```'0A`0`*````>B$!`!4```"%(0$`
M$@```)LA`0`,````KB$!``0```"[(0$`!P```,`A`0`)````R"$!``P```#2
M(0$`4@```-\A`0`7````,B(!`"0```!*(@$`$@```&\B`0`'````@B(!``8`
M``"*(@$`#@```)$B`0`.````H"(!``P```"O(@$`#````+PB`0`B````R2(!
M`!T```#L(@$`#`````HC`0`-````%R,!`!4````E(P$`$@```#LC`0`0````
M3B,!``\```!?(P$`%````&\C`0`;````A",!`!````"@(P$`:0```+$C`0`:
M````&R0!`!<````V)`$`&0```$XD`0`:````:"0!`"4```"#)`$`)P```*DD
M`0`:````T20!`!<```#L)`$`&P````0E`0`9````("4!`!\````Z)0$`%```
M`%HE`0`3````;R4!``@```"#)0$`!P```(PE`0`(````E"4!``D```"=)0$`
M%0```*<E`0`-````O24!`",```#+)0$`$P```.\E`0`#`````R8!`$8````'
M)@$`/P```$XF`0`W````CB8!`%<```#&)@$`!0```!XG`0`?````)"<!`"\`
M``!$)P$`"@```'0G`0`(````?R<!``T```"()P$`+0```)8G`0`$````Q"<!
M``X```#))P$`%````-@G`0!/````[2<!`"4````]*`$`$@```&,H`0`@````
M=B@!`!P```"7*`$`"P```+0H`0`?````P"@!`!T```#@*`$`)0```/XH`0`@
M````)"D!`"0```!%*0$`(````&HI`0`+````BRD!``<```"7*0$`#0```)\I
M`0`,````K2D!`!<```"Z*0$`!@```-(I`0`Y````V2D!``P````3*@$`!P``
M`"`J`0`9````*"H!``D```!"*@$`$P```$PJ`0`)````8"H!``0```!J*@$`
M$````&\J`0`*````@"H!``@```"+*@$`"````)0J`0`$````G2H!``L```"B
M*@$`#````*XJ`0`2````NRH!`!$```#.*@$`#````.`J`0`:````[2H!``\`
M```(*P$`!P```!@K`0`-````("L!`!`````N*P$`$0```#\K`0`4````42L!
M``X```!F*P$`#````'4K`0`;````@BL!`"P```">*P$`$P```,LK`0`<````
MWRL!`"@```#\*P$`!@```"4L`0`'````+"P!`!,````T+`$`!0```$@L`0`$
M````3BP!`!<```!3+`$`"@```&LL`0`,````=BP!``D```"#+`$`!@```(TL
M`0`)````E"P!``@```">+`$`"0```*<L`0`*````L2P!`!$```"\+`$`!@``
M`,XL`0`8````U2P!``X```#N+`$`#@```/TL`0`-````#"T!``L````:+0$`
M'0```"8M`0`+````1"T!``(```!0+0$`!P```%,M`0`&````6RT!`&4```!B
M+0$`"0```,@M`0`'````TBT!`"8```#:+0$`.`````$N`0`:````.BX!`"H`
M``!5+@$`.P```(`N`0`8````O"X!`"@```#5+@$`-````/XN`0`9````,R\!
M`!4```!-+P$`!0```&,O`0`'````:2\!``@```!Q+P$`!P```'HO`0`%````
M@B\!``<```"(+P$`#@```)`O`0`)````GR\!``8```"I+P$`"````+`O`0`+
M````N2\!``<```#%+P$`"````,TO`0`'````UB\!`!8```#>+P$`"0```/4O
M`0`&````_R\!``L````&,`$`'````!(P`0`4````+S`!``<```!$,`$`$0``
M`$PP`0`(````7C`!``X```!G,`$`"````'8P`0`%````?S`!`!````"%,`$`
M$````)8P`0`&````IS`!`!D```"N,`$`"@```,@P`0`<````TS`!``<```#P
M,`$`!0```/@P`0`0````_C`!`!0````/,0$`"P```"0Q`0`-````,#$!`"@`
M```^,0$`&````&<Q`0`7````@#$!``0```"8,0$`"0```)TQ`0`*````IS$!
M``<```"R,0$``@```+HQ`0`.````O3$!``@```#,,0$`'P```-4Q`0`^````
M]3$!`",````T,@$`.````%@R`0`F````D3(!`#$```"X,@$`)P```.HR`0!D
M````$C,!`!0```!W,P$`50```(PS`0`X````XC,!`$H````;-`$`6P```&8T
M`0`H````PC0!`#@```#K-`$`*````"0U`0`L````334!`"<```!Z-0$`&P``
M`*(U`0`^````OC4!`*D!``#]-0$`*````*<W`0`C````T#<!`!<```#T-P$`
M2`````PX`0"%````53@!`#````#;.`$`%0````PY`0`H````(CD!`"(```!+
M.0$`(@```&XY`0`@````D3D!`$$```"R.0$`6P```/0Y`0!)````4#H!`!T`
M``":.@$`&````+@Z`0`A````T3H!`!\```#S.@$`*P```!,[`0`A````/SL!
M`"<```!A.P$`'0```(D[`0`1````ISL!`#,```"Y.P$`)0```.T[`0`G````
M$SP!`!\````[/`$`,````%L\`0!I````C#P!`"L```#V/`$`,0```"(]`0!!
M````5#T!`#,```"6/0$`)0```,H]`0`]````\#T!`&4````N/@$`30```)0^
M`0`O````XCX!`"X````2/P$`*0```$$_`0`P````:S\!`"P```"</P$`5```
M`,D_`0"#````'D`!`%H```"B0`$`*````/U``0`F````)D$!`$@```!-00$`
M2@```)9!`0`K````X4$!`!X````-0@$`,@```"Q"`0`O````7T(!`"P```"/
M0@$`+0```+Q"`0!Q````ZD(!`&\```!<0P$`LP```,Q#`0`7````@$0!`"4`
M``"81`$`,@```+Y$`0`I````\40!`#X````;10$`(@```%I%`0!2````?44!
M`"(```#010$`)0```/-%`0`+````&48!`+$````E1@$`10```-=&`0`A````
M'4<!`"X````_1P$`,````&Y'`0`E````GT<!`!P```#%1P$`,0```.)'`0`'
M````%$@!``<````<2`$`!````"1(`0`-````*4@!``L````W2`$`#@```$-(
M`0`+````4D@!``4```!>2`$`$````&1(`0`"````=4@!`%D```!X2`$`!0``
M`-)(`0`2````V$@!``0```#K2`$`!P```/!(`0`(````^$@!``4````!20$`
M`P````=)`0`0````"TD!``H````<20$`#````"=)`0`3````-$D!``T```!(
M20$``@```%9)`0`'````64D!``8```!A20$`%````&A)`0`,````?4D!`!@`
M``"*20$`!@```*-)`0`2````JDD!``P```"]20$``P```,I)`0`J````SDD!
M``0```#Y20$`!@```/Y)`0`'````!4H!`!\````-2@$`-0```"U*`0`N````
M8TH!`"\```"22@$`%P```,)*`0`@````VDH!`!L```#[2@$`&````!=+`0`D
M````,$L!`!\```!52P$`&@```'5+`0`@````D$L!`!H```"Q2P$`,@```,Q+
M`0`9````_TL!`!H````93`$`+P```#1,`0`K````9$P!`!\```"03`$`(P``
M`+!,`0`?````U$P!`!H```#T3`$`)0````]-`0`F````-4T!`"4```!<30$`
M)````()-`0`8````ITT!`!T```#`30$`)````-Y-`0`8`````TX!`"(````<
M3@$`%0```#].`0`E````54X!`#P```![3@$`'P```+A.`0`C````V$X!`!\`
M``#\3@$`(````!Q/`0`:````/4\!`!@```!83P$`)@```'%/`0`>````F$\!
M`"D```"W3P$`'@```.%/`0`)`````%`!``P````*4`$`#````!=0`0`7````
M)%`!`"\````\4`$`)````&Q0`0`'````D5`!``\```"94`$`%````*E0`0`.
M````OE`!``T```#-4`$`)````-M0`0`%`````%$!``<````&40$`(@````Y1
M`0`E````,5$!`!,```!740$`&@```&M1`0`=````AE$!`!H```"D40$`!P``
M`+]1`0#'````QU$!``L```"/4@$`&0```)M2`0`5````M5(!``P```#+4@$`
M!@```-A2`0`)````WU(!``L```#I4@$`#0```/52`0`=`````U,!`!<````A
M4P$`!@```#E3`0`S````0%,!`!,```!T4P$`$P```(A3`0`'````G%,!``8`
M``"D4P$`#P```*M3`0`'````NU,!`#(```##4P$`(0```/93`0`3````&%0!
M``P````L5`$`$0```#E4`0`R````2U0!`!````!^5`$`"````(]4`0`=````
MF%0!``D```"V5`$`"@```,!4`0`%````RU0!`!0```#15`$`"@```.94`0`=
M````\50!``@````/50$`'P```!A5`0`(````.%4!`!H```!!50$`)P```%Q5
M`0`&````A%4!`!4```"+50$`!P```*%5`0`(````J54!``D```"R50$`/P``
M`+Q5`0`'````_%4!``\````$5@$`#@```!16`0`0````(U8!``D````T5@$`
M"0```#Y6`0`(````2%8!`!,```!15@$`!P```&56`0`1````;58!`!D```!_
M5@$`"@```)E6`0`7````I%8!`!0```"\5@$`"@```-%6`0`,````W%8!`!<`
M``#I5@$`!`````%7`0`J````!E<!`!$````Q5P$`!P```$-7`0`)````2U<!
M``(```!55P$`$````%A7`0`8````:5<!``L```""5P$``P```(Y7`0`(````
MDE<!``8```";5P$`!P```*)7`0`-````JE<!``L```"X5P$`%````,17`0`5
M````V5<!``X```#O5P$`+P```/Y7`0`@````+E@!`!P```!/6`$`*P```&Q8
M`0`,````F%@!`#$```"E6`$`!0```-=8`0`2````W5@!`#\```#P6`$`$@``
M`#!9`0`*````0UD!``8```!.60$`!````%59`0`$````6ED!``H```!?60$`
M$P```&I9`0`%````?ED!``8```"$60$`!@```(M9`0`)````DED!``0```"<
M60$`#````*%9`0`*````KED!`"````"Y60$`!0```-I9`0`8````X%D!`!D`
M``#Y60$`'P```!-:`0`=````,UH!`!$```!16@$``@```&-:`0`$````9EH!
M``H```!K6@$`!@```'9:`0`%````?5H!``,```"#6@$`#````(=:`0!%````
ME%H!`!H```#:6@$`-0```/5:`0`H````*UL!`%,```!46P$`,@```*A;`0`9
M````VUL!`'(```#U6P$`(````&A<`0`U````B5P!`"$```"_7`$`10```.%<
M`0`P````)UT!`"@```!870$`*````(%=`0`I````JET!`"8```#470$`)0``
M`/M=`0`H````(5X!`"@```!*7@$`(@```'->`0`K````EEX!`#````#"7@$`
M$@```/->`0`3````!E\!`!`````:7P$`>0```"M?`0`)````I5\!`'(```"O
M7P$`<P```")@`0!\````EF`!`"L````380$`5````#]A`0`7````E&$!`!8`
M``"L80$`%0```,-A`0`/````V6$!`&4```#I80$`'P```$]B`0`.````;V(!
M`$````!^8@$`'P```+]B`0`<````WV(!`%$```#\8@$`%````$YC`0`*````
M8V,!``4```!N8P$`!@```'1C`0`(````>V,!``4```"$8P$`$@```(IC`0`0
M````G6,!`!,```"N8P$`'0```,)C`0`/````X&,!``\```#P8P$`$`````!D
M`0`$````$60!``D````69`$`"0```"!D`0`'````*F0!``L````R9`$`!0``
M`#YD`0`+````1&0!``<```!09`$`!0```%AD`0`4````7F0!``X```!S9`$`
M"P```()D`0`'````CF0!``@```"69`$`#P```)]D`0`,````KV0!``D```"\
M9`$`"````,9D`0`,````SV0!``8```#<9`$`#P```.-D`0`'````\V0!``8`
M``#[9`$`%`````)E`0`&````%V4!``P````>90$`%0```"ME`0`(````064!
M``0```!*90$`"@```$]E`0`$````6F4!``8```!?90$`!P```&9E`0`$````
M;F4!``<```!S90$`&0```'ME`0`'````E64!``(```"=90$``@```*!E`0`)
M````HV4!``8```"M90$`!@```+1E`0`G````NV4!``(```#C90$`!````.9E
M`0`+````ZV4!``D```#W90$`#P````%F`0`3````$68!``<````E9@$`"0``
M`"UF`0`'````-V8!``8````_9@$`!@```$9F`0`0````368!`!(```!>9@$`
M`@```'%F`0`&````=&8!``D```![9@$`,P```(5F`0`B````N68!``<```#<
M9@$`!P```.1F`0`'````[&8!``L```#T9@$`!0````!G`0`%````!F<!``(`
M```,9P$`"P````]G`0!9`0``&V<!`',```!U:`$`N````.EH`0!"````HFD!
M`,````#E:0$`D````*9J`0!&````-VL!`#<```!^:P$`,P```+9K`0`V````
MZFL!`"\````A;`$`+@```%%L`0!H````@&P!`&4```#I;`$`9P```$]M`0!E
M````MVT!`&<````=;@$`;P```(5N`0`_````]6X!`&0````U;P$`0P```)IO
M`0`O````WF\!`$T````.<`$`1````%QP`0!*````H7`!`#,```#L<`$`.```
M`"!Q`0!N````67$!`"X```#(<0$`+0```/=Q`0"(````)7(!`&(```"N<@$`
M#P$``!%S`0!.````(70!`#0```!P=`$`BP```*5T`0!0````,74!`!````""
M=0$`%0```)-U`0`4````J74!``<```"^=0$`"0```,9U`0`(````T'4!``4`
M``#9=0$`'@```-]U`0`N````_G4!`"P````M=@$`*0```%IV`0`N````A'8!
M`!@```"S=@$`"@```,QV`0`1````UW8!``@```#I=@$`*P```/)V`0`3````
M'G<!`!`````R=P$`$````$-W`0`4````5'<!``4```!I=P$`*````&]W`0`-
M````F'<!``T```"F=P$`$P```+1W`0`-````R'<!``L```#6=P$`(0```.)W
M`0`;````!'@!`!`````@>`$`"@```#%X`0`6````/'@!`#\```!3>`$`#0``
M`)-X`0`/````H7@!`!````"Q>`$`%0```,)X`0`-````V'@!``8```#F>`$`
M#0```.UX`0`3````^W@!`!4````/>0$`#0```"5Y`0`;````,WD!``8```!/
M>0$`&P```%9Y`0`3````<GD!``@```"&>0$`"0```(]Y`0!8````F7D!`#0`
M``#R>0$`%0```"=Z`0`]````/7H!`$X```![>@$`:@```,IZ`0!I````-7L!
M`'````"?>P$`;P```!!\`0!"````@'P!``\```##?`$`$@```--\`0`.````
MYGP!`!,```#U?`$`#P````E]`0`%````&7T!``8````??0$`$P```"9]`0`)
M````.GT!``\```!$?0$`$0```%1]`0`A````9GT!`",```"(?0$`(````*Q]
M`0`>````S7T!`"8```#L?0$`(P```!-^`0`6````-WX!`!````!.?@$`#0``
M`%]^`0`)````;7X!`!4```!W?@$`&0```(U^`0`1````IWX!`!4```"Y?@$`
M&````,]^`0`?````Z'X!`"0````(?P$`&@```"U_`0`3````2'\!`!````!<
M?P$`%P```&U_`0`2````A7\!`"X```"8?P$`&````,=_`0`<````X'\!`!0`
M``#]?P$`60```!*``0`J````;(`!`!D```"7@`$`*@```+&``0`J````W(`!
M``@````'@0$`"0```!"!`0`W````&H$!``T```!2@0$`"````&"!`0`+````
M:8$!``<```!U@0$`!P```'V!`0`'````A8$!``<```"-@0$`#````)6!`0`$
M````HH$!`"(```"G@0$`#P```,J!`0`3````VH$!`!<```#N@0$`'`````:"
M`0`P````(X(!``D```!4@@$`&````%Z"`0`>````=X(!`",```"6@@$`$0``
M`+J"`0`4````S((!`!(```#A@@$`#P```/2"`0`C````!(,!`!T````H@P$`
M!P```$:#`0`&````3H,!``<```!5@P$`&@```%V#`0`(````>(,!``H```"!
M@P$`$0```(R#`0`)````GH,!`!$```"H@P$`&@```+J#`0`'````U8,!`!(`
M``#=@P$`!0```/"#`0`6````]H,!`!X````-A`$`#P```"R$`0`_````/(0!
M`#L```!\A`$`"0```+B$`0`'````PH0!`!,```#*A`$`!````-Z$`0`%````
MXX0!``D```#IA`$`$````/.$`0`*````!(4!`!0````/A0$`/````"2%`0`5
M````884!`"T```!WA0$`,@```*6%`0`Q````V(4!`#`````*A@$`"0```#N&
M`0`&````188!``D```!,A@$`!P```%:&`0`[````7H8!`#L```":A@$`.@``
M`-:&`0!?````$8<!`#D```!QAP$`.0```*N'`0`Y````Y8<!`$L````?B`$`
M+0```&N(`0`P````F8@!`#D```#*B`$`/P````2)`0`5````1(D!`!D```!:
MB0$`,@```'2)`0`F````IXD!`!<```#.B0$`$P```.:)`0`*````^HD!`!``
M```%B@$`&````!:*`0`C````+XH!``4```!3B@$`#````%F*`0`>````9HH!
M`",```"%B@$`!@```*F*`0`%````L(H!`!4```"VB@$`"P```,R*`0`(````
MV(H!``H```#AB@$`#````.R*`0`'````^8H!``8````!BP$`!0````B+`0`'
M````#HL!``4````6BP$`"P```!R+`0`R````*(L!`!<```!;BP$`#0```'.+
M`0`'````@8L!``<```")BP$`"@```)&+`0`%````G(L!`!,```"BBP$`!@``
M`+:+`0`2````O8L!``4```#0BP$`"````-:+`0`$````WXL!``L```#DBP$`
M!@```/"+`0`E````]XL!`!$````=C`$`*P```"^,`0`>````6XP!``@```!Z
MC`$`#@```(.,`0`-````DHP!``<```"@C`$``P```*B,`0`#````K(P!`!H`
M``"PC`$``P```,N,`0`@````SXP!`"L```#PC`$`"@```!R-`0`%````)XT!
M``@````MC0$`"````#:-`0!>````/XT!`"@```">C0$`!@```,>-`0`(````
MSHT!`!\```#7C0$`)````/>-`0`O````'(X!`#(```!,C@$`)@```'^.`0`F
M````IHX!`%T```#-C@$`/@```"N/`0`7````:H\!``<```""CP$`$@```(J/
M`0`)````G8\!``P```"GCP$`$````+2/`0`8````Q8\!`!<```#>CP$`&```
M`/:/`0`8````#Y`!``D````HD`$`%0```#*0`0`'````2)`!`!D```!0D`$`
M&P```&J0`0`9````AI`!`!,```"@D`$`&````+20`0`2````S9`!``<```#@
MD`$`&P```.B0`0!;````!)$!`#@```!@D0$`"0```)F1`0`5````HY$!`#8`
M``"YD0$`$@```/"1`0`:`````Y(!`!T````>D@$`&0```#R2`0`7````5I(!
M`!T```!ND@$`'@```(R2`0`R````JY(!`$,```#>D@$`*0```"*3`0`-````
M3),!`"P```!:DP$`)P```(>3`0`=````KY,!``8```#-DP$`$0```-23`0`<
M````YI,!`!X````#E`$`&@```"*4`0`:````/90!``L```!8E`$`%0```&24
M`0`3````>I0!``T```".E`$`!@```)R4`0`/````HY0!``@```"SE`$`%0``
M`+R4`0`6````TI0!`!$```#IE`$`%0```/N4`0`%````$94!``8````7E0$`
M$0```!Z5`0`(````,)4!`!,````YE0$``@```$V5`0`'````4)4!`!,```!8
ME0$`$@```&R5`0`)````?Y4!``H```")E0$`"0```)25`0`*````GI4!``<`
M``"IE0$`!P```+&5`0`-````N94!``P```#'E0$`"````-25`0`)````W94!
M`!H```#GE0$`(@````*6`0`-````)98!`!@````SE@$`'@```$R6`0`>````
M:Y8!``\```"*E@$`$````)J6`0`P````JY8!`#\```#<E@$`(0```!R7`0`\
M````/I<!`"@```![EP$`#@```*27`0`)````LY<!``H```"]EP$`#@```,B7
M`0`&````UY<!``\```#>EP$`%@```.Z7`0`7````!9@!`!P````=F`$`+@``
M`#J8`0`L````:9@!`#````"6F`$`+P```,>8`0`I````]Y@!`"D````AF0$`
M)@```$N9`0`Y````<ID!`"(```"LF0$`,````,^9`0!"`````)H!`#$```!#
MF@$`,@```'6:`0`E````J)H!`#(```#.F@$`.0````&;`0!.````.YL!`#4`
M``"*FP$`.````,";`0!#````^9L!`"0````]G`$`%@```&*<`0!/````>9P!
M`"D```#)G`$`&@```/.<`0`[````#IT!`"(```!*G0$`&````&V=`0#5````
MAIT!`!H```!<G@$`+0```'>>`0`P````I9X!`#$```#6G@$`,@````B?`0`I
M````.Y\!`!8```!EGP$`+@```'R?`0`W````JY\!`#H```#CGP$`/0```!Z@
M`0`Z````7*`!`)H```"7H`$`*P```#*A`0`?````7J$!`"@```!^H0$`-P``
M`*>A`0`V````WZ$!`%8````6H@$`60```&VB`0`-````QZ(!``0```#5H@$`
M!@```-JB`0`%````X:(!`!$```#GH@$`#@```/FB`0`0````"*,!``8````9
MHP$`%0```""C`0`;````-J,!`!0```!2HP$`$0```&>C`0`6````>:,!``D`
M``"0HP$`#@```)JC`0`/````J:,!`!$```"YHP$`#0```,NC`0!#````V:,!
M``8````=I`$`$0```"2D`0`3````-J0!`!$```!*I`$`%P```%RD`0`;````
M=*0!``\```"0I`$``@```*"D`0`+````HZ0!`!P```"OI`$`!````,RD`0`0
M````T:0!`!````#BI`$``P```/.D`0`/````]Z0!``@````'I0$`$````!"E
M`0`2````(:4!``L````TI0$`#P```$"E`0`1````4*4!`!H```!BI0$`%@``
M`'VE`0`6````E*4!`!T```"KI0$`'````,FE`0`*````YJ4!``<```#QI0$`
M#0```/FE`0`1````!Z8!`!H````9I@$`#@```#2F`0`.````0Z8!`"0```!2
MI@$`&@```'>F`0`X````DJ8!``T```#+I@$`'P```-FF`0`9````^:8!`!@`
M```3IP$`$0```"RG`0`V````/J<!`"<```!UIP$`$@```)VG`0`)````L*<!
M``L```"ZIP$`$P```,:G`0`)````VJ<!``H```#DIP$`,````.^G`0`[````
M(*@!``\```!<J`$`$````&RH`0`A````?:@!`!(```"?J`$`(P```+*H`0`C
M````UJ@!``H```#ZJ`$`'`````6I`0`6````(JD!`!X````YJ0$`%@```%BI
M`0`7````;ZD!`!D```"'J0$`!P```*&I`0`+````J:D!`"H```"UJ0$`2@``
M`."I`0`(````*ZH!`!0````TJ@$`!P```$FJ`0`*````4:H!`#<```!<J@$`
M$P```)2J`0`&````J*H!`!,```"OJ@$``P```,.J`0`4````QZH!``8```#<
MJ@$`#````..J`0`,````\*H!``L```#]J@$`$0````FK`0`1````&ZL!`!<`
M```MJP$`&0```$6K`0`1````7ZL!`!D```!QJP$`%P```(NK`0`(````HZL!
M``8```"LJP$`&````+.K`0`+````S*L!``(```#8JP$`$P```-NK`0`?````
M[ZL!`!\````/K`$`&````"^L`0`2````2*P!``H```!;K`$`#P```&:L`0`/
M````=JP!`!4```"&K`$`/@```)RL`0`R````VZP!``H````.K0$`#P```!FM
M`0"B````*:T!`!X```#,K0$`30```.NM`0`0````.:X!`!(```!*K@$`!```
M`%VN`0`H````8JX!`!8```"+K@$`!@```**N`0`4````J:X!`"@```"^K@$`
M!0```.>N`0`&````[:X!``\```#TK@$`#@````2O`0`0````$Z\!``X````D
MKP$`#````#.O`0`.````0*\!``L```!/KP$`$````%NO`0`(````;*\!``L`
M``!UKP$`"````(&O`0`5````BJ\!``P```"@KP$`/P```*VO`0`1````[:\!
M``@```#_KP$`"`````BP`0`.````$;`!`!,````@L`$`%0```#2P`0`K````
M2K`!``\```!VL`$`)P```(:P`0`B````KK`!`"$```#1L`$`&````/.P`0`:
M````#+$!`"4````GL0$`&0```$VQ`0`#````9[$!`!D```!KL0$`"P```(6Q
M`0`+````D;$!``,```"=L0$`"0```*&Q`0`(````J[$!``H```"TL0$`$0``
M`+^Q`0`-````T;$!`!````#?L0$`!````/"Q`0`@````];$!`"$````6L@$`
M$P```#BR`0`/````3+(!`!,```!<L@$`%P```'"R`0`N````B+(!``<```"W
ML@$`"0```+^R`0`0````R;(!`!````#:L@$`"P```.NR`0`(````][(!``D`
M````LP$`"`````JS`0`6````$[,!``P````JLP$`!@```#>S`0`I````/K,!
M``X```!HLP$`B0```'>S`0`=`````;0!``<````?M`$`!0```">T`0`-````
M+;0!``4````[M`$`!P```$&T`0`&````2;0!``@```!0M`$`)````%FT`0`3
M````?K0!``(```"2M`$`"````)6T`0`2````GK0!`!4```"QM`$`#P```,>T
M`0`2````U[0!`"<```#JM`$``@```!*U`0`#````%;4!`!(````9M0$`"0``
M`"RU`0`-````-K4!``<```!$M0$`$@```$RU`0`@````7[4!``@```"`M0$`
M$P```(FU`0`5````G;4!``T```"SM0$`(````,&U`0`'````XK4!`!T```#J
MM0$`#P````BV`0`1````&+8!``D````JM@$`#````#2V`0`"````0;8!``4`
M``!$M@$`#P```$JV`0`2````6K8!``8```!MM@$`$@```'2V`0`+````A[8!
M``<```"3M@$`%P```)NV`0`F````L[8!`!,```#:M@$`!@```.ZV`0`)````
M];8!``0```#_M@$`%@````2W`0`(````&[<!`!8````DMP$`%@```#NW`0`0
M````4K<!``4```!CMP$`#````&FW`0`@````=K<!``0```"7MP$`10```)RW
M`0!&````XK<!`$4````IN`$`)0```&^X`0`2````E;@!`!,```"HN`$`!P``
M`+RX`0`)````Q+@!`!8```#.N`$`$````.6X`0`5````]K@!``8````,N0$`
M!0```!.Y`0`4````&;D!``4````NN0$`G````#2Y`0`*````T;D!`!X```#<
MN0$`!````/NY`0`S`````+H!``4````TN@$`'````#JZ`0`$````5[H!`!``
M``!<N@$`$````&VZ`0`6````?KH!``P```"5N@$`!0```**Z`0`:````J+H!
M`#(```##N@$`-P```/:Z`0!`````+KL!`"P```!ONP$`,@```)R[`0!!````
MS[L!`$H````1O`$`,0```%R\`0!%````CKP!`#4```#4O`$`-P````J]`0`G
M````0KT!`!````!JO0$`%0```'N]`0`+````D;T!`"@```"=O0$`(````,:]
M`0`A````Y[T!`!\````)O@$`"````"F^`0`*````,KX!``H````]O@$`%```
M`$B^`0`I````7;X!`"<```"'O@$`,````*^^`0`+````X+X!`!D```#LO@$`
M*0````:_`0`:````,+\!`!0```!+OP$`%````&"_`0`-````=;\!`!````"#
MOP$`$P```)2_`0!$````J+\!`'T```#MOP$`@@```&O``0`3````[L`!``T`
M```"P0$`#@```!#!`0`1````'\$!`!(````QP0$`%@```$3!`0`'````6\$!
M`!@```!CP0$`$@```'S!`0`7````C\$!`!,```"GP0$`$@```+O!`0`5````
MSL$!`"P```#DP0$`+````!'"`0!M````/L(!`!4```"LP@$`$@```,+"`0`8
M````U<(!`!8```#NP@$`"@````7#`0`*````$,,!`"$````;PP$`'0```#W#
M`0`6````6\,!``X```!RPP$`#@```('#`0`5````D,,!`!4```"FPP$`*@``
M`+S#`0`I````Y\,!`"D````1Q`$`*````#O$`0`G````9,0!`"D```",Q`$`
M&@```+;$`0!5````T<0!`!,````GQ0$`%0```#O%`0`5````4<4!`!0```!G
MQ0$`$0```'S%`0`7````CL4!`!<```"FQ0$`%````+[%`0`3````T\4!`#H`
M``#GQ0$`&````"+&`0`9````.\8!`#X```!5Q@$`%0```)3&`0`'````JL8!
M`!$```"RQ@$`(````,3&`0`3````Y<8!`!,```#YQ@$`'@````W'`0`B````
M+,<!`!T```!/QP$`&P```&W'`0`:````B<<!`"(```"DQP$`$@```,?'`0`<
M````VL<!`"$```#WQP$`'````!G(`0`8````-L@!`!L```!/R`$`$P```&O(
M`0`;````?\@!`!P```";R`$`'````+C(`0`8````U<@!``H```#NR`$`&@``
M`/G(`0`3````%,D!`!0````HR0$`"P```#W)`0`4````2<D!`!````!>R0$`
M!P```&_)`0`'````=\D!`!(```!_R0$`!P```)+)`0`'````FLD!``4```"B
MR0$`%0```*C)`0`&````OLD!`!L```#%R0$`!0```.')`0`%````Y\D!``H`
M``#MR0$`!P```/C)`0`*`````,H!`!4````+R@$`%````"'*`0`8````-LH!
M`!4```!/R@$`$P```&7*`0`L````><H!`!,```"FR@$`$````+K*`0`:````
MR\H!`!0```#FR@$`#0```/O*`0`3````"<L!`#$````=RP$`!@```$_+`0`)
M````5LL!`"<```!@RP$`$P```(C+`0`0````G,L!``8```"MRP$`$P```+3+
M`0`+````R,L!``8```#4RP$`(0```-O+`0`2````_<L!`!(````0S`$`$@``
M`"/,`0`4````-LP!`!(```!+S`$`&````%[,`0`5````=\P!`!0```"-S`$`
M`P```*+,`0`*````ILP!`"$```"QS`$`!@```-/,`0`(````VLP!`!4```#C
MS`$`$@```/G,`0`&````#,T!``<````3S0$`,P```!O-`0`,````3\T!`!,`
M``!<S0$`"0```'#-`0`2````>LT!`!4```"-S0$`$0```*/-`0`5````M<T!
M``T```#+S0$`!````-G-`0`*````WLT!``<```#IS0$`%````/'-`0!)````
M!LX!``@```!0S@$`#P```%G.`0`E````:<X!`!4```"/S@$`&````*7.`0`.
M````OLX!`!````#-S@$`#@```-[.`0`+````[<X!``T```#YS@$`$P````?/
M`0`3````&\\!`!<````OSP$`+````$?/`0`+````=,\!`!4```"`SP$`&0``
M`);/`0`-````L,\!``P```"^SP$`&@```,O/`0`+````YL\!``8```#RSP$`
M!````/G/`0`2````_L\!`%8````1T`$`%@```&C0`0`+````?]`!``0```"+
MT`$`!0```)#0`0`8````EM`!`!D```"OT`$`&@```,G0`0`*````Y-`!``(`
M``#OT`$`!````/+0`0`C````]]`!``,````;T0$`!0```!_1`0`H````)=$!
M``H```!.T0$`!0```%G1`0`'````7]$!`!@```!GT0$`$0```(#1`0!1````
MDM$!`!(```#DT0$`!@```/?1`0`'````_M$!``@````&T@$`!`````_2`0`%
M````%-(!`&0````:T@$`"@```'_2`0`-````BM(!``4```"8T@$`!@```)[2
M`0`9````I=(!`#@```"_T@$`#@```/C2`0`)````!],!`!<````1TP$`"@``
M`"G3`0`(````--,!`!D````]TP$`+P```%?3`0`I````A],!`"@```"QTP$`
M$@```-K3`0`$````[=,!``<```#RTP$`"````/K3`0`'`````]0!``T````+
MU`$`#0```!G4`0`,````)]0!`#8````TU`$`'P```&O4`0`Q````B]0!`"4`
M``"]U`$`"````./4`0!9````[-0!`!$```!&U0$`$````%C5`0`2````:=4!
M`!D```!\U0$`3@```);5`0`=````Y=4!``8````#U@$`'P````K6`0`'````
M*M8!``8````RU@$`(````#G6`0`&````6M8!``D```!AU@$`)P```&O6`0`F
M````D]8!``<```"ZU@$`"@```,+6`0`E````S=8!`$L```#SU@$`&````#_7
M`0`=````6-<!`!8```!VUP$``@```(W7`0`-````D-<!``@```">UP$`$P``
M`*?7`0`-````N]<!``X```#)UP$`!@```-C7`0`&````W]<!`!0```#FUP$`
M%````/O7`0`(````$-@!``D````9V`$`"P```"/8`0`*````+]@!``L````Z
MV`$`$0```$;8`0`/````6-@!`!(```!HV`$`$P```'O8`0`&````C]@!`!4`
M``"6V`$`%````*S8`0`%````P=@!``8```#'V`$`!0```,[8`0`7````U-@!
M`"````#LV`$`$0````W9`0`-````']D!``\````MV0$`#````#W9`0`4````
M2MD!`!````!?V0$`$0```'#9`0`$````@MD!`!0```"'V0$`!0```)S9`0`%
M````HMD!`!<```"HV0$`$P```,#9`0`4````U-D!`!P```#IV0$`(0````;:
M`0`9````*-H!`!D```!"V@$`'0```%S:`0`B````>MH!`!P```"=V@$`!```
M`+K:`0`%````O]H!``X```#%V@$`#@```-3:`0`(````X]H!``D```#LV@$`
M(@```/;:`0`-````&=L!`!0````GVP$`"````#S;`0`2````1=L!``<```!8
MVP$`$````&#;`0`/````<=L!``@```"!VP$`%@```(K;`0`2````H=L!`!P`
M``"TVP$`!0```-';`0`$````U]L!``,```#<VP$`40```.#;`0`_````,MP!
M`!X```!RW`$`)````)'<`0!!````MMP!`!$```#XW`$`/@````K=`0`N````
M2=T!`!P```!XW0$`.@```)7=`0!*````T-T!`%<````;W@$`7````'/>`0`0
M````T-X!`"(```#AW@$`1P````3?`0`5````3-\!`"8```!BWP$`(0```(G?
M`0`>````J]\!`",```#*WP$`'P```.[?`0`9````#N`!`#`````HX`$`"0``
M`%G@`0`O````8^`!`!8```"3X`$`&P```*K@`0`3````QN`!`#D```#:X`$`
M.0```!3A`0`]````3N$!`#D```",X0$`.@```,;A`0`[`````>(!`#@````]
MX@$`<0```';B`0`=````Z.(!``H````&XP$`"0```!'C`0`P````&^,!`#L`
M``!,XP$`*0```(CC`0`+````LN,!`$L```"^XP$`1@````KD`0`%````4>0!
M``<```!7Y`$`%P```%_D`0`5````=^0!``\```"-Y`$`$````)WD`0`7````
MKN0!`!````#&Y`$`#P```-?D`0`.````Y^0!`!,```#VY`$`$0````KE`0`,
M````'.4!``X````IY0$`$0```#CE`0`0````2N4!``\```!;Y0$`#0```&OE
M`0`.````>>4!`!0```"(Y0$`#P```)WE`0`7````K>4!``\```#%Y0$`(P``
M`-7E`0`%````^>4!`!$```#_Y0$`(P```!'F`0`$````->8!``@````ZY@$`
M!@```$/F`0`4````2N8!`!$```!?Y@$`$````''F`0!2````@N8!``(```#5
MY@$`!P```-CF`0`2````X.8!`"````#SY@$`!0```!3G`0`'````&N<!`!L`
M```BYP$`"````#[G`0`0````1^<!`#(```!8YP$`%@```(OG`0`R````HN<!
M`'8```#5YP$`%0```$SH`0!.````8N@!`"(```"QZ`$`$0```-3H`0`&````
MYN@!``P```#MZ`$`!P```/KH`0`.`````ND!``L````1Z0$`%@```!WI`0`+
M````-.D!`!P```!`Z0$`&````%WI`0`%````=ND!`!(```!\Z0$`#0```(_I
M`0`2````G>D!`"4```"PZ0$`%@```-;I`0`5````[>D!`!$````#Z@$`(P``
M`!7J`0`*````.>H!``P```!$Z@$`%````%'J`0`3````9NH!``P```!ZZ@$`
M#@```(?J`0`+````ENH!`!,```"BZ@$`#0```+;J`0`*````Q.H!`!\```#/
MZ@$`$@```._J`0`7`````NL!``8````:ZP$`$````"'K`0`5````,NL!`!8`
M``!(ZP$`#0```%_K`0`8````;>L!`#$```"&ZP$`'0```+CK`0`.````UNL!
M``\```#EZP$`)````/7K`0`%````&NP!`!$````@[`$`!P```#+L`0`6````
M.NP!``<```!1[`$`"P```%GL`0`@````9>P!`#0```"&[`$`"0```+OL`0`B
M````Q>P!`!````#H[`$`"@```/GL`0`;````!.T!``T````@[0$`%````"[M
M`0`$````0^T!`!0```!([0$`"0```%WM`0`(````9^T!``L```!P[0$`#@``
M`'SM`0`&````B^T!``H```"2[0$`(0```)WM`0`_````O^T!`$````#_[0$`
M)````$#N`0`M````9>X!`"H```"3[@$`1P```+[N`0`D````!N\!`#,````K
M[P$`0P```%_O`0!A````H^\!`#0````%\`$`+0```#KP`0`'````:/`!``@`
M``!P\`$`"0```'GP`0`4````@_`!`!L```"8\`$`&P```+3P`0`P````T/`!
M`"4````!\0$`(@```"?Q`0`Z````2O$!`$(```"%\0$`!P```,CQ`0`9````
MT/$!``D```#J\0$`"````/3Q`0`@````_?$!`!$````>\@$`%````##R`0`-
M````1?(!``@```!3\@$`%0```%SR`0`)````<O(!``\```!\\@$`#0```(SR
M`0`:````FO(!`!@```"U\@$`.P```,[R`0`*````"O,!``\````5\P$`!@``
M`"7S`0`:````+/,!`!````!'\P$`!0```%CS`0`-````7O,!`!````!L\P$`
M"0```'WS`0`,````A_,!``P```"4\P$`#@```*'S`0`'````L/,!``,```"X
M\P$`#0```+SS`0`V````RO,!`$@````!]`$`&````$KT`0`E````8_0!`!``
M``")]`$`(0```)KT`0`1````O/0!`!4```#.]`$`"P```.3T`0`2````\/0!
M`"D````#]0$`!P```"WU`0`-````-?4!`!$```!#]0$`#@```%7U`0`2````
M9/4!``L```!W]0$`/````(/U`0`)````P/4!`!P```#*]0$`$@```.?U`0`6
M````^O4!`$`````1]@$`)````%+V`0`\````=_8!`#H```"T]@$`-@```._V
M`0`1````)O<!``8````X]P$`%P```#_W`0`<````5_<!``H```!T]P$`'0``
M`'_W`0`+````G?<!`!````"I]P$`!P```+KW`0`5````PO<!`!4```#8]P$`
M"0```.[W`0`'````^/<!`!0`````^`$`$0```!7X`0`9````)_@!``4```!!
M^`$`!P```$?X`0`)````3_@!`!````!9^`$`#P```&KX`0`5````>O@!`!4`
M``"0^`$`!P```*;X`0`&````KO@!`#$```"U^`$`*0```.?X`0`E````$?D!
M``@````W^0$`#P```$#Y`0`3````4/D!`!\```!D^0$`'@```(3Y`0`?````
MH_D!``T```##^0$`#````-'Y`0`#````WOD!``<```#B^0$`#0```.KY`0`"
M````^/D!``P```#[^0$`$0````CZ`0`+````&OH!`!0````F^@$`&````#OZ
M`0`5````5/H!`!P```!J^@$`(P```(?Z`0`3````J_H!`!8```"_^@$`#@``
M`-;Z`0`&````Y?H!``H```#L^@$`#````/?Z`0`.````!/L!`%H````3^P$`
M&````&[[`0`L````A_L!`!4```"T^P$`!P```,K[`0`(````TOL!`!(```#;
M^P$`%@```.[[`0`1````!?P!``\````7_`$`*P```"?\`0`D````4_P!`!0`
M``!X_`$`$P```(W\`0`A````H?P!`!@```##_`$`'````-S\`0`6````^?P!
M`"0````0_0$`*````#7]`0`5````7OT!`%\```!T_0$`(0```-3]`0`=````
M]OT!`",````4_@$`(0```#C^`0`G````6OX!`"T```""_@$`(P```+#^`0`=
M````U/X!`"0```#R_@$`(````!?_`0`B````./\!`!D```!;_P$`'0```'7_
M`0`*````D_\!`!0```">_P$`"0```+/_`0`(````O?\!`!,```#&_P$`#P``
M`-K_`0`K````ZO\!`!4````6``(`"````"P``@!@````-0`"`#\```"6``(`
M4````-8``@!P````)P$"``H```"8`0(`)0```*,!`@`O````R0$"``D```#Y
M`0(`!P````,"`@`-````"P("`#X````9`@(`!P```%@"`@`8````8`("`!@`
M``!Y`@(`20```)("`@`M````W`("`!\````*`P(`'P```"H#`@`G````2@,"
M``X```!R`P(`-P```($#`@`=````N0,"`$$```#7`P(`-@```!D$`@`_````
M4`0"`#4```"0!`(`%````,8$`@`*````VP0"`!,```#F!`(`%@```/H$`@`8
M````$04"``@````J!0(`,0```#,%`@`*````904"``H```!P!0(`)@```'L%
M`@`*````H@4"`!<```"M!0(`%@```,4%`@`'````W`4"`!$```#D!0(`$0``
M`/8%`@`*````"`8"`!8````3!@(`!````"H&`@`%````+P8"``8````U!@(`
M#P```#P&`@`2````3`8"`!````!?!@(`'0```'`&`@`-````C@8"``<```"<
M!@(`$````*0&`@`5````M08"`!D```#+!@(`(````.4&`@`2````!@<"``T`
M```9!P(`&@```"<'`@`F````0@<"``X```!I!P(`'P```'@'`@`O````F`<"
M``D```#(!P(`"P```-('`@`8````W@<"`!````#W!P(`%@````@(`@`9````
M'P@"``X````Y"`(`$````$@(`@`-````60@"``D```!G"`(`+0```'$(`@`&
M````GP@"``D```"F"`(`#0```+`(`@`3````O@@"``8```#2"`(`'````-D(
M`@`8````]@@"``\````/"0(`"````!\)`@`>````*`D"`!L```!'"0(`#```
M`&,)`@`"````<`D"``<```!S"0(`"````'L)`@!N````A`D"`!````#S"0(`
M!P````0*`@`G````#`H"`$8````T"@(`'````'L*`@`G````F`H"`$0```#`
M"@(`&@````4+`@`Q````(`L"`$````!2"P(`'````),+`@`6````L`L"`!(`
M``#'"P(`!@```-H+`@`-````X0L"``H```#O"P(`"0```/H+`@`-````!`P"
M`!$````2#`(`#P```"0,`@`*````-`P"``P````_#`(`$````$P,`@`'````
M70P"``@```!E#`(`!P```&X,`@`4````=@P"`!0```"+#`(`#P```*`,`@`%
M````L`P"`"4```"V#`(`%0```-P,`@`*````\@P"`!0```#]#`(`"P```!(-
M`@`4````'@T"``L````S#0(`!@```#\-`@`6````1@T"`!8```!=#0(`!P``
M`'0-`@`'````?`T"`!D```"$#0(`"````)X-`@`%````IPT"``<```"M#0(`
M$@```+4-`@`;````R`T"``L```#D#0(`#0```/`-`@`M````_@T"`"$````L
M#@(`&````$X.`@`%````9PX"``P```!M#@(`%````'H.`@`-````CPX"``(`
M``"=#@(`$P```*`.`@`2````M`X"`!\```#'#@(`0````.<.`@`C````*`\"
M`#0```!,#P(`,0```($/`@`T````LP\"`"(```#H#P(`8@````L0`@`6````
M;A`"`&X```"%$`(`.P```/00`@!6````,!$"`'$```"'$0(`+0```/D1`@`\
M````)Q("`"L```!D$@(`,````)`2`@`P````P1("`!P```#R$@(`.@````\3
M`@"_`0``2A,"`"L````*%0(`'P```#85`@`6````5A4"`%8```!M%0(`C```
M`,05`@`S````418"`!0```"%%@(`+0```)H6`@`A````R!8"`",```#J%@(`
M(P````X7`@!`````,A<"`%H```!S%P(`4````,X7`@`B````'Q@"`!4```!"
M&`(`'0```%@8`@`=````=A@"`"H```"4&`(`'````+\8`@`E````W!@"`",`
M```"&0(`%@```"89`@`W````/1D"`"H```!U&0(`*````*`9`@`:````R1D"
M`#````#D&0(`8@```!4:`@`M````>!H"`#0```"F&@(`10```-L:`@`R````
M(1L"`"L```!4&P(`1P```(`;`@!E````R!L"`%H````N'`(`,0```(D<`@`N
M````NQP"`"L```#J'`(`,@```!8=`@`N````21T"`%D```!X'0(`E0```-(=
M`@!L````:!X"`"4```#5'@(`)````/L>`@!<````(!\"`%H```!]'P(`,@``
M`-@?`@`;````"R`"`#(````G(`(`)0```%H@`@`E````@"`"`"L```"F(`(`
M;@```-(@`@!K````02$"`,````"M(0(`&0```&XB`@`G````B"("`#X```"P
M(@(`+0```.\B`@!1````'2,"`"<```!O(P(`7````)<C`@`I````]","`!X`
M```>)`(`"@```#TD`@#>````2"0"`#L````G)0(`*0```&,E`@!"````C24"
M`#T```#0)0(`)0````XF`@`@````-"8"`#\```!5)@(`"````)4F`@`(````
MGB8"``D```"G)@(`$P```+$F`@`0````Q28"`!(```#6)@(`"P```.DF`@`&
M````]28"``X```#\)@(`!`````LG`@!<````$"<"``0```!M)P(`$0```'(G
M`@`2````A"<"``@```"7)P(`!@```*`G`@`.````IR<"``0```"V)P(`%@``
M`+LG`@`*````TB<"``D```#=)P(`$0```.<G`@`3````^2<"``(````-*`(`
M%````!`H`@`4````)2@"`!(````Z*`(`#@```$TH`@`5````7"@"``8```!R
M*`(`%@```'DH`@`-````D"@"``,```">*`(`-````*(H`@`$````UR@"`!,`
M``#<*`(`!P```/`H`@`D````^"@"`%`````=*0(`.0```&XI`@`Z````J"D"
M`!\```#C*0(`)P````,J`@`B````*RH"`"8```!.*@(`*````'4J`@`C````
MGBH"`"4```#"*@(`+````.@J`@`G````%2L"`#L````]*P(`'````'DK`@`B
M````EBL"`#@```"Y*P(`-````/(K`@`E````)RP"`"D```!-+`(`+````'<L
M`@`G````I"P"`"P```#,+`(`+0```/DL`@`U````)RT"`"$```!=+0(`)0``
M`'\M`@`J````I2T"`#(```#0+0(`)0````,N`@`L````*2X"`!L```!6+@(`
M)0```'(N`@!"````F"X"`"8```#;+@(`*@````(O`@`M````+2\"`"X```!;
M+P(`)@```(HO`@`D````L2\"`"X```#6+P(`*P````4P`@`X````,3`"`!T`
M``!J,`(`"@```(@P`@`3````DS`"`!,```"G,`(`&0```+LP`@`L````U3`"
M`",````",0(`#0```"8Q`@`/````-#$"`!8```!$,0(`"P```%LQ`@`9````
M9S$"`"H```"!,0(`"````*PQ`@`,````M3$"`"$```#",0(`,@```.0Q`@`8
M````%S("`"L````P,@(`*P```%PR`@`D````B#("``@```"M,@(`Y@```+8R
M`@`1````G3,"`"\```"O,P(`%@```-\S`@`,````]C,"``D````#-`(`#0``
M``TT`@`5````&S0"`!$````Q-`(`*0```$,T`@`B````;30"``8```"0-`(`
M10```)<T`@`<````W30"`!T```#Z-`(`'0```!@U`@`+````-C4"`!,```!"
M-0(`"0```%8U`@!2````8#4"`"H```"S-0(`'0```-XU`@`4````_#4"`!<`
M```1-@(`*````"DV`@`8````4C8"`!(```!K-@(`)````'XV`@`3````HS8"
M`!0```"W-@(`#````,PV`@`8````V38"`!@```#R-@(`%P````LW`@`(````
M(S<"`"P````L-P(`"0```%DW`@`I````8S<"`"@```"--P(`!P```+8W`@`;
M````OC<"``<```#:-P(`"````.(W`@`)````ZS<"`#P```#U-P(`!@```#(X
M`@`3````.3@"`!0```!-.`(`#@```&(X`@`)````<3@"``H```![.`(`(```
M`(8X`@`3````IS@"``T```"[.`(`%````,DX`@`6````WC@"`!(```#U.`(`
M&`````@Y`@`8````(3D"``P````Z.0(`#@```$<Y`@`8````5CD"``0```!O
M.0(`+P```'0Y`@`/````I#D"``4```"T.0(`!P```+HY`@`"````PCD"`!$`
M``#%.0(`(P```-<Y`@`+````^SD"``,````'.@(`!@````LZ`@`,````$CH"
M``P````?.@(`$0```"PZ`@`0````/CH"`!8```!/.@(`%P```&8Z`@`%````
M?CH"`"\```"$.@(`'P```+0Z`@`>````U#H"`#````#S.@(`"0```"0[`@`I
M````+CL"``<```!8.P(`%P```&`[`@`^````>#L"`!$```"W.P(`$@```,D[
M`@`(````W#L"``0```#E.P(`!0```.H[`@`-````\#L"`!H```#^.P(`!@``
M`!D\`@`'````(#P"``D````H/`(`$0```#(\`@`(````1#P"`!(```!-/`(`
M$@```&`\`@`P````<SP"`!0```"D/`(`&0```+D\`@`D````TSP"`"(```#X
M/`(`)0```!L]`@`0````03T"``(```!2/0(`!````%4]`@`+````6CT"``H`
M``!F/0(`!0```'$]`@`#````=ST"``T```![/0(`1P```(D]`@`5````T3T"
M`#(```#G/0(`.0```!H^`@!2````5#X"`"\```"G/@(`#P```-<^`@!V````
MYSX"`"(```!>/P(`3@```($_`@`O````T#\"`#8`````0`(`/0```#=``@`N
M````=4`"`"D```"D0`(`)P```,Y``@`P````]D`"`#0````G00(`+0```%Q!
M`@`I````BD$"`"P```"T00(`+@```.%!`@`Q````$$("`"8```!"0@(`%```
M`&E"`@`0````?D("`'L```"/0@(`"@````M#`@!X````%D,"`'H```"/0P(`
M>0````I$`@`P````A$0"`&$```"U1`(`%````!=%`@`2````+$4"`"$````_
M10(`#0```&%%`@"#````;T4"`"8```#S10(`&````!I&`@`Y````,T8"`"(`
M``!M1@(`(````)!&`@!K````L48"`!L````=1P(`"@```#E'`@`%````1$<"
M``8```!*1P(`"````%%'`@`%````6D<"`!<```!@1P(`&0```'A'`@`7````
MDD<"`"(```"J1P(`$````,U'`@`.````WD<"`!D```#M1P(`"`````=(`@`*
M````$$@"``<````;2`(`"````"-(`@`.````+$@"``<````[2`(`#P```$-(
M`@`'````4T@"``8```!;2`(`%P```&)(`@`2````>D@"``T```"-2`(`!P``
M`)M(`@`%````HT@"`!(```"I2`(`&````+Q(`@`*````U4@"``<```#@2`(`
M"P```.A(`@`)````]$@"`!,```#^2`(`"0```!))`@`-````'$D"`!<````J
M20(`#0```$))`@`)````4$D"`!````!:20(`"@```&M)`@`%````=DD"``L`
M``!\20(`!0```(A)`@`&````CDD"``H```"520(`"````*!)`@`,````J4D"
M`!,```"V20(`!P```,I)`@`"````TDD"``(```#520(`"````-A)`@`(````
MX4D"``<```#J20(`+````/))`@`"````'TH"``0````B2@(`#@```"=*`@`.
M````-DH"`!````!%2@(`%0```%9*`@`0````;$H"``D```!]2@(`"P```(=*
M`@`&````DTH"``<```":2@(`$@```*)*`@`2````M4H"``(```#(2@(`!P``
M`,M*`@`0````TTH"`"H```#D2@(`-@````]+`@`)````1DL"``@```!02P(`
M"P```%E+`@`<````94L"``4```""2P(`!0```(A+`@`&````CDL"``L```"5
M2P(``0```'0#````````/@8```````!B!@``9`,``+`"``#]`P``FP4``&H#
M```_!0``Q@4``!(#````````C@(```@'```2!0```````"D```#"`0``'`4`
M`,<#``#A`@``*`4``(T````)`0``*04```````!$!@``T0,``-8$```H`@``
MI`````,#``"G`P````````````"Z!```5P$``#$&``#4!0``6`<``#T$``#7
M`0``2@$``,`#``!!````_0$``%@"````````Z````%8"````````UP,``#P#
M```K````0P```+@'``#$`P```````"\#````````C@$``$,#````````````
M`*D%``"S`0``(P$``-P$````````W`<```````````````(``-<"````````
MCP0``.$%``#/`0``L08``(L!````````:P8``/@"``"]!P``%0<````````N
M!@``<P<``$D'```A`@``8P0```````"*!@````````````".`````P<``.,$
M``"M!@```````)<&``"P`0``L@<``)H%````````SP,``'@`````````904`
M`(\!``!0`````````!($```<`@``_@0``(8&````````-0(``$\%````````
M'`0`````````````:P<``#`#``"*!0``LP<``$4!``#&!````````%4$``!6
M!@```````'L#``"Q`0``"0(``$P$````````=P<``*0!``"_!@```````)$`
M``")!@``'`,``!8'``#S`@``SP8``%0$``#O`0``<04``/4"````````-@``
M`!8"``"6`0```````+<```!Y!0``KP<`````````````9P8```````#>`@``
M@@8``%\"```2!P``6`$```````"!``````````````!W`P``&P0`````````
M````-@4````````+`P``UP8```````!X!```A@4``"L'``#Z!@``````````
M``!\`0``Z`8```````">!0``O`8``#L#``"L`0``Z04````````/````90$`
M````````````````````````````$P(``+8%````````>P8```````!;!P``
M*P(``*`%```-!0``@@0```````#D`@``/@<``"(!``"/!P``\@(```````!Y
M`P``,00``.,&``"2!0``?0$```,%``#4`0````````````!?!0``,@,``,(#
M````````!@(``#4$```A!@``H@``````````````S@```!$```!%`P``````
M``````"O!````````#<"`````````````)0#``!^````AP<``)L"``!I`0``
M`````(`&```(!````````-4%``"``P``H`$``/8$````````A0```.0$``!Q
M!````````)8```"Z!@``3P0``#\"``!^!0``?@<``%L"```R````,@8`````
M``!<!@``5`4`````````````[````%$%``#(!0``XP```,<!``!B!0``````
M`!$%````````\@```$<!````````/04```````"*`@``P@```/8&``"/!0``
M`````!X&``"U!@``/@4``)$&``"O!@``:`4``/P$``#J!```NP<````````U
M`0```````)X$``!(!P```````*X$``!G`@``3@,``"(&```\!0``Z08``-8`
M``#@`P`````````````(`@``B0```-`%``!!`P```````%X'``!\!0``````
M`&4$```J!```H`<``%D'``!N`@```````"`#``!,`P```````+L"``"D!P``
M'P8```````#)!```D0$``#L$``!W!0``,@(``*,```!=!````````*$```!#
M!0``IP<``*L%``"$`P``V`$````````/`P```````),$``#_`@``P@0``,\%
M``#?!```HP$``$`!````````[00``,P!``!)`@````````````#"!0``#```
M``0#````````R@(``````````````````#8"```I`0``V@8``(\`````````
MYP$``-D$``!I`````````!<$```T`P``2`,``,,!`````````````+$#``!"
M!0``$`$```T#``"'!@``30,``.H```!7!@```````-4!````````H00`````
M``"^!@``S0<`````````````,P4``$0$``";!````````$P'````````DP$`
M`"H!```=!```3`$``!0````!!0``QP<``+("``"M````'04``/8%```A`P``
M^08``.4```"L!0``+`,``)\````!!@``TP0``-H'````````L0<``,<%``""
M!0```````#,#``!^`0```````,8"``#Q````T`0``#P'````````K@<``"`"
M```Y`0``````````````````RP```)\&``"G!0``4@8``'4#``#W!```````
M`-\`````````V@```'(````!!P``*P0``&`%```T````D0,``-8'````````
M`````&4````6`P``L04```````!.!@``)@4``#`$````````:`,```````!A
M!0```````+8'````````-04```````",`@``X@0``&$&```C!P``<`8``+@"
M``!-`0`````````````*````"@(``)@'``"\!P``N`,``"@```#.!P``6@``
M`&\!``!5!0``C`$``*($``#3`0``;`````````!C!@``RP<``$H&``!"`@``
MIP```*X&```A!0````````````#5!```D`$``#L"``"(`@``\P8```````#<
M`````````+8!``!Q`P``]`(``%H#```````````````````[!P``E@8``/$$
M``#'!```#@0``$T'`````````````/0&````````VP````````#2!```````
M`)`&``#-`P``ZP8``)D&``#N`0````$``%@%``!8`````````"H#````````
M`````+\$```J!P``#`4``*H'``#K!```G0$```````#K`0``J0(```````#I
M````>@4``,P#````````1`4``#,'```=`@``[0$``&8$`````````````(`'
M``"9`@``60(``"H&````````P`<``+L!``"!!P``T0(``*0"````````7P0`
M`&`&``"7!```_@$````````X!@``4P,``%`$``#S!````````%\&```@!P``
M`````%L&``````````````L$````````_@8````````N`P```````#H"```?
M!P``#P<``*X```!M`0``0@8``,`$``````````````````"$!```9`4``+``
M```+`@``\@4`````````````F`(`````````````Q0(``%4````Y!@``````
M`)D#````````V0`````````-!@``I0$``$D&``"6!0``E`4````````6`0``
M`````'T"````````8`$``+P"``!#`0``(@```)D%``!9!```U`<``%X$``#1
M!0```00```<'``"G`0`````````````\`@``40,``(\"``#%!```````````
M``#X`P```````%X!``#,!@``Y0,``(,!``"A!@``B0<```````!B`P``Y04`
M``````!`!0```````$@!``"H`0``S04``#T'``#X!@````````````![`0``
M4@(``!D%```4`P```````+$$`````````````*P"``#M!@```````#\&```&
M`0```````*0$``#-`0``'P,```````#0`0``Q08``$$%``!E!@``!@```$<'
M``#8`P``"P<``,,&``#2`P``20,```````!;`P``+`0``)D$````````Q0$`
M`,P%````````N00```````"#!```^`0``!T'``"K!```-0<``&D%``##!P``
MV`0```````#_````````````````````*P4``.`'``!/!P```````+H%``#A
M!```=`<``)4$``#Z````&`,```````#`````LP8``"@'````````M@,```4#
M``!:`0``^P```%H'``!T!@```````+T&````!0``0`(``%T!``#D!@``LP(`
M```````I`P``D@0``.L``````````````"X$```"!P```````%P'``"$!0``
M`````#D%``"_`@```````%T"```%!0```````)8'````````"P4`````````
M`````````*\%``!.`@``B`0``(`````M````9P4``(,```!3!P``````````
M``#G````_0````````!C!0`````````````%!@``J0<``/<&``!T!```````
M`*D!````````Q`0`````````````=@<```````"X!@``\0$`````````````
MS`0``(,&``#L`P```````$H%``!R`P``QP`````````>!P``W@8``#T#``#4
M`P``+P8``&\#````````R`````````!H`@```````#8$```"!```:@$``(X$
M`````````````!X%``!!`@``BP,```````!C!P``4@,```````!F!@``W08`
M``8%``#=`````````%(!```5`@``+08``/`"`````````````'8$``#S````
MX`(``/0!````````````````````````````````````````YP0``#L!``#[
M`@``70```"($```=````1`,``)P%``!A!P``GP,``+(#```L!0``.`4`````
M``"M!P``.`0``+4!````````1@4`````````````G@<```````!4!@```@8`
M``````",````&@8````````\`0``]@```%('```-`0```````)X```"4`0``
MZ00``+\```#A!@``@@,``&\%````````````````````````:P4``(\#```Y
M!```QP8``!D$````````=@(``(D!``#C!0``>P0```````#U````>@0``!4&
M``!7!0``C0$``%P"``"K`@``608```T"`````````````!$"``!-`@``=`4`
M`/,%```&!@``@08``.T"``#4!```NP,``$L#`````````````'<```!?`P``
M=P(``.D!````````5````*("``#`!0``%0$``%4#````````?`<```````#$
M`0```````/$#`````````````"(%```W!@````````````#J!@```````+4"
M``"8!@``WP,``"0!```>`0``X0<`````````````T0$``,$#```#!@``[@4`
M`/8!```"`0``=`(``*$%```Q````F@0``*L'```O!0``BP```%8'```I!```
M.@4`````````````F@```%`&``````````````````!I`@``I@8``(H$````
M````CP8``"X'```H`0```````%$'``"*````:`8```````!>!@``E@,``.,!
M``"H!P```````+0&```L`@``>P(``$<%``"&`@``9`8``,D&``"(````?P8`
M`!L'``!(`````````#$'````````2@(``,L"``"7!0```````"T#``#6`0``
M%`(``,D!``#O````+`8``'$'```0!```<`4```(```#H`P``?P0``!\%```.
M`@``/@$``+0%``"^!0``'0,``+L$```O````N0```(0'``#T!```-P$``#8'
M``!Y````,P$``$````#G`P```````#0!``!?````"`4``'8#``"A!P``````
M`+0"``"%!@``#`,``"H%```X`0```````+0#``"J!0```````+P#````````
M`````'`'```J````9@<`````````````Q@,``+H````/`@``<P0```````!"
M!P```````.@%``!8!@``,`8``$H'``!N!`````````````"#!P``1@```.``
M``!F!0``@`0``)@%```3!```;08`````````````;`0````````Z`P``3`8`
M``````"?`@``&0```````````````````.(#``!R!P``C`8``,X!``!Q`0``
M5@$``%8#``#*!```[04``'4$```-!```F@<``(,"``````````````````#X
M`0``^P,```````"&`0``1P```````````````````*P$````````````````
M```$!0``ZP(```````#1`````@4``&D'````````Z@,``#H!```6!@``````
M`&T#``"3!P``YP4``,8&``!Y!P``'P`````#```$!@``W`$``+\%````````
M`````#<$````````]00``'$```!@!P``GP$``"$$``!"````HP0``"0"``"$
M`0```````&8"``#Z!```I0(``&4#```I!@``C@,``!$$``!<````UP```,8'
M```\!```00$``-D&``!9````Y@8````````N`````````(<"``"^`P``L`,`
M`-,&``"*`0```````$8!``##````P04``)$'`````````````&P'``"A`@``
M`````/\$``#^`@``7@4```````!=`P``=````"D'``"'`P``TP(``"4%````
M````#@,``-H$```'!0````````````#B!0``FP,````````8!0```````-H%
M``!B`0```````-D%```G`0``#P4``,L#```9`P```````*P#````````E`0`
M`&8#````````D00`````````````@@```&P#````````/`````````!U`0``
MN@<``+4%````````!P(``*4$``!Z````\`,``-\%``"&````,@<``"$'```3
M!P``/P<``.8#`````````````,@!``!X`0``1@,``"P!```C!@``YP(``&`$
M``#^!0````````````#R!@``60,```````#B`````P$``$L!``#-!@``N@,`
M`+@```#]`@``S@8``+X"``"S!```/P0``!L```#<`P``5`(``+8`````````
M^P0``(L$``!6`````````'<$``#V`P```````.X"``!H````%0```$\"``#[
M!@``Y`4``%`!``!L`0``"08``!L#``!"`0``>P````@#``"2!P``.@0``-8%
M``!3`````````-\!```.````0`0``(P%``!R!````````(X%``!H!```V```
M`,D%````````WP(```````#H`@``%`<``&<#``"L!@`````````````E!P``
M7`$```0'````````-@$```````#U!0````````````":`@``````````````
M````/@(``*D&```1`P```````+P!````````0P(``/D%````````<`0`````
M``!6!```Y00```<$``#2`0``N`4``+T$``"2````MP,``&$$```8````!00`
M``````"[`````````'T&``!=!0``F`,``*\````N`0``5@4``-H!````````
MI0```/<"``!+!0```````#D"``"%!P``%0,```````"1!0``8@0```````!(
M!````````-D'``"=!````````+L%``"J`0``,`<``,H#```F!@``'`8`````
M```#````U0```-`"``#*!@``DP8``'P&``!S`0``.@<``#$!``#Z`0``&`0`
M``````#``@``N0$``/(#``#^`P``K@$````````>````&P$``$<"```B`P``
M8``````````G`@``X0```",%```:!P``2`(``*$#``!C`@``>0$```````!_
M!0``*`8``-@%```X!P``4@0````````U!@``)@(``)0'``#G!@``0@,``+X!
M``!``P``8`(`````````````G`,``%\!````````B0,```````!1`0``>@$`
M`)T&``````````````````"'!0``&@0``%(```"Y`@``M@(``.@$````````
M:08``!<```!>````X0,````````"`@``%P<```(#``"H`P``Y08``*8#``!>
M`@```````*<"``````````````````#S`P````````````"(`0```````!0%
M````````TP<``",#``"Z`0``%@```*D$````````%P$``#@#``#Z`P``````
M````````````MP8``*8%```O!P``P`$``+`%``!-!@``+0(``!0!``#B!@``
MRP0``&H"```:!0``100``-P&```P`@```````+T!``#E`0``10```-X%```N
M`@``2P8``.P%``"#`P``*P,```````!5!@``:`<````````9!P``````````
M```3`0``JP```,D#``";`0``Z@(```````#>`P``3````(L%```Z!@``B`8`
M`)X!```L`````````%0'``#/``````````````"J!@``;P(``,$&``#I`P``
M9@$``$4%``#$!P``;P8```````#1!P``SP0``)P'```9`@``U@(`````````
M````D`4```````"&!P```````+(!``#P!@``P@(``!,``````````````.H!
M``"%`P``"@4``/8"```5!0``@@(``)<'````````3P8``"D"````````````
M``H!``".!P``Q````+<$``"5`P``>P<``)(!```(````X`0``%,&````````
M/08```@&````````W0,``/<```"?!P``JP8``&H%```3!@``&0$``&X%``!M
M````/0$`````````````1P0``(,%````````K00``'T'````````H`(`````
M``#'`@```````"4#``"&`P``#@4``%H%``"<!@``F`````````!P`0``-@8`
M``````!U!0``@`$``#0%````````)`4```````!T`0``V`8`````````````
M`````#,"````````X@<``*0&``",`P``)`0``$L```!D`0``7`4```````"N
M`P``)08``"L&``!P````Y`,``.P"````````*`,``#D#``!_````O`4``&,!
M```!`P``"@0``%`#````````/`8``((!``"Z`@``H0$``.8"``!P`@``P`8`
M`````````````````*,&````````L`0```````#6`P``OP$``+,%````````
MK`<```H&``!S`@``;`(``(`%``#"!P``&08``&H&````````NP8````````7
M!@``^0,``.$!``````````0``%4'````````'@(```````"F!P``$`(``-P"
M``"B!@```````,0&```^!```XP,``%D%``"J!```A04````````^````C`0`
M`%P#```]```````````````8!@```````"<$``"7`@``P@8````````J`@``
MU0(``/X```!&!P```````'H#``!_`@``B`<```````"3````````````````
M`````````!@"`````````````.8!``"T`````````,H'````````N`$``.X&
M``#\!@``T`8```````"?!```&@`````````1`0``!P$``+8$``#_!@``````
M`'$&``#!``````````H'``#M````;@,``,0"```M!```C0(``$X$``"O`P``
MV`<````````[!0``]08``($$``#Q!@``X`4``.8%````````400``)P`````
M````HP4``!<#``"4````FP8``%<#`````````````,H!``#)!P``J@```%<'
M``"W`0``9P<``+($````````!````*T#``!]`P``U`(``(0````D!P``9`0`
M````````````<`,``&4'````````FP<``)X&``!X`P``4P$``$X!``#_`0``
M````````````````50$```````!^`P``P0<``.8$```&!```,0,``/`%``!`
M!P``G0<``%(%```2`@``DP,```````!C````;00``',%```S`````````'8!
M``!*````B04```````!5`@```````&T%````````TP```#\!``!K`0``````
M`&D#````````_`(``'@'``"U!P``G0```'<&``"H````D@8``.X$``!>`P``
MS`(``(L&````````@`(``*('``!]!0``\04```````!Y`@````````````"!
M`0``.````#(%``!]!```E0```-T$```P!0```````-H"``#U`0``]0,`````
M``"P!P```````.(!```%````OP<``/P#`````````````*D#```'`P``````
M``````#;!```8@<``)@$```Y````K@(``),%```B`@```````/0#````````
MGP4```````!L!0``O04``-4#``!R!@``-P<``-<$```C`````````/`$```C
M!```)````-D"```M`0```````,X%``#F``````````````"R````?`(``/\%
M``!D!P``S0````D%``!'!@``D@,``$D$```Z````C0,``.X#``!!!```408`
M`)H!```0````C0<``)`$``!&!@``T````,\'````````S`<``,L&````````
MS@(`````````````[P0``(L'```+!@``PP0``-4&```%`@``VP(``&X&``!1
M````JP$``"`!``"Y!@``J`8``#`!```3!0``8P,``!,#``#5!P``&@(``',&
M``#?!@``80```.0``````````````,@#```T`@``_````,,#``!&!```#0``
M`.\%```)!```!P````H#``#L`0``2P0``',```"$!@``S@0``#<#```!`@``
MG04``)8"``"^!```\@0``-T!```A`0``/@,``"<'```.!P``T`,``$L'````
M````PP(```````#[`0``:00``#@"``#Z`@``^`4``,,%``#B`@``D`<``!H!
M``"4!@```````&T"``"V!@``?``````````8`0``)P8``-H#``"P!@``H@$`
M`+X'```<`0``)@$```````#%!P``'`<``(@#```M!P``0P8```````!!!P``
MC08``&H$````````Q04``)8$``!\`P``C04`````````````VP4````````#
M`@``#`0``(4$`````````````#8#``!-!```I@0``$,$`````````````-8&
M``!1`@```````+P$```@````'08``)<!```G``````````````#(!P``MP4`
M`!\"````````3P$``+D'``"U````)`8``-0```#3!0``/P,``%@#``#W`0``
MWP<```````````````````````!O````:P(``"\"``#L!@````````````#(
M!```-0,``($#``#O`P``IP0`````````````T@8``"4$````````W@$``$<#
M``#R`0``T`<```$!``!Z`@``Q@```)D'``"@!```$@$`````````````````
M`'8`````````3P```($%``!3`@``XP(``-T"``!R`0```````!T!``"@````
MV0$``'(%``!4`P```````)`````@!```-0```%,$````````IP8``&@!``"0
M`P````````T'``!=!@``DP(``&$"``"S````=08```````"D`P``M`0``,$!
M```?!```"0<``&0````[!@``<P,``)$"``"C!P``-`8``"8'``!3!0``?P,`
M````````````2`4``/D```#]!``````````````1!@``W@0``"4!``"T`0``
M)@0```,$``"5!0``+@4```````#J!0```````.\"```E`@```````/`!```]
M`@``&P8`````````````+P$``/L%``";````>@8``-@"``#(`@```````+,#
M````````$`4``/$"``!Y!```>P4``&H```"N!0``[0,``$\#````````T08`
M`&$#```7`@``R0(``&("```[````I04``+D#```C`@``Q0,````````S!```
M!@,```````#,````R@4````````P````[`0``!0&``!-````C@8```````!Y
M!@```````%L!``")`@``!`(``"8```!^`@```````!X#````````VP8``&(`
M`````````````"P'```+`0``^````-P%```/!@````````````!$`0``````
M`(<$``"7````(0```,$$````````JP,``/<#````````OP,```````!U!P``
M``````L```")!```AP$``/D!````````(@<````````M!0``3@4`````````
M````I`4``$D`````````Q0```%L%``!A`0``I@(``%L$``"X!```KP(``*8`
M```R`0``/P```+(%`````````````'("``#>````#@8``,X#````````````
M``````!Z!P``-`<``,T"``"=`P```````)("````````C00``*H"```,`@``
M#`$``+4#``!8!````````/,!```W!0``O0,``````````````````*H#``!%
M`@``SP(``-D#``!?!P``$`8`````````````VP$``.L#``#)`````````+(&
M``!!!@``VP,``,$"``!"!```9P0``````````````````&\'``":`P``3@``
M`+0'```.`0``6P```'@&````````\````$4'````````,P8``,H`````````
MX`8``$@&``!V!0```````+T`````````````````````````*`0```````"U
M!```@0(``+$"``!W`0``Y`$`````````````#`<```````"L````!0$``$,'
M````````9P```#$"``"@!@````````<&````````204```````!.!P``E0<`
M``````!L!@````8``)`"``!*!```?@0``!X$``!N`0``$@8``!`'```/!```
MKP$``)H&``#$!0````````````#T!0``9P$``-0&````````]````*,"``"B
M`P``?@8```````",!P``9@```.@!``!4`0``'````&H'```T!```I0<``!L"
M````````=0```(('``"H`@``9`(```````!M!P``E0$``)X"``#1!```T@``
M`&L$````````?`0``*D```">`P``B`4``/T&````````4`(``%`%````````
ME0(``!`#````````70<`````````````_`4``'8&```/`0```````'4"````
M`````````,T$```R!```2@,```````"H!````````#<````$!```J`4`````
M```;!0``X`$```````#3`P```````%<"```:`P``1`````````#\`0``^@4`
M`%D!``!_!P``T@(``&X```#+`0```````!0$``!7````6@(``&\$```)`P``
MW04````````%!P``*P$```````#Y!```6@8``+$```"'````A`(``+X`````
M````G`0```@!``!_`0``)P4```````"E`P``?0```%<$``"&!```6@0`````
M`````````````)0"``#K!0```````!(`````````MP<``!8$``#O!@``&`<`
M```````G`P``%00``-('````!P``90(``*8!````````W@<``$8"````````
M``````````"<`@``EP,``(H'```@!0```````#$%``#I`@``0`8``&`#````
M````BP(```D```#7!P``I08``'$"```1!P``F`$``/T%````````O0(``*`#
M``#Y`@````````````!-!0```````-(%``#(!@``RP4```````!)`0``3`(`
M```````7!0``F0```'@"``#&`0``K0$``$4&``!0!P``!@<````````F`P``
MMP(``&L#```6!0``1`<``*T%``#_`P``A0$``$0"```,!@``!`$``+D%````
M````]P4`````````````'P$``"\$```E````A0(``)4&``!<!```>`4``$P%
M``!N!P``````````````````O````"`&``"*`P``Y0(``&L```"=`@``[@``
M``````#;!P```````)P!````````2P(``*T"```Y!P```````*,#```D`P``
MH@4``-T'``"9`0``UP4`````````("`M32P@+2UM97-S86=E/4U%4U-!1T4@
M(%5S92!T:&ES(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0@;VYE<RX`("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@
M9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F
M97)E;G0@8G)A;F-H('1O"B`@("`@("`@("`@("`@("`@("`@("`@('1H92!G
M96YE<F%T960@8V]M<&5N9&EU;2X`("`M8BP@+2UB87-E/2]0051(("!&=6QL
M('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U
M;&0@8F4*("`@("`@("`@("`@("`@("`@("!U<V5D+@`@("UC+"`M+6-O;7!E
M;F1I=6T]1DE,12`@365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O
M;7!E;F1I=6T@9FEL90H@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A
M9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE"B`@
M("`@("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E8W1O<GDN`"`@
M+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I
M;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L=`H@("`@("`@("`@("`@("`@("`@
M("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E
M8W1O<GDI+@`@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G
M97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I97,N`"`@+60L("TM9&ER96-T
M;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y
M+@`@("UH+"`M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N
M`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L
M92X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92X`
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+@`@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO
M;G,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U
M;&4]34]$54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E
M(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM
M;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N
M)W0@;65R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2X`
M("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I
M=6TN`"`@+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N
M('-T871I<W1I8W,@:6X@82!L;V-A;"!F:6QE+@`@("UT+"`M+71E<W0@("`@
M("`@(%-H;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@
M86YY=&AI;F<N`"`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U
M<"!F<F]M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RX`("!C
M;VUM:70@("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R
M=F5R+@`@(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#
M5E,@<V5R=F5R+@`@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I
M=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H90H@("`@("`@
M("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2X`("!E>'1R86-T("`@("!'96YE
M<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N`"`@:&5L<"`@("`@("`@
M4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`("!I;FET("`@("`@("!#<F5A=&4@
M;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN
M9SH@5&AI<PH@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG
M(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+@`@(&UA:V4@("`@("`@($)U:6QD
M(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N
M`"`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE
M;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9`H@("`@("`@("`@("`@('!R
M97!A<F4@=&AE(&9I;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A
M=&4M:&5L<"X@66]U"B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA
M:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE"B`@
M("`@("`@("`@("`@:&5L<"!F:6QE+@`@(&UE<F=E("`@("`@($UE<F=E('1H
M92!C=7)R96YT(%!/(&9I;&4@=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T
M92!F:6QE+@`@('5P9&%T92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S
M97%U96YT+@`@('5P9&%T92UH96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA
M;F=E9"!E;G1R:65S(&9R;VT@=&AE($5N9VQI<V@@6$U,(&AE;'`*("`@("`@
M("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG
M(&]N97,N`"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@
M*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A('9A
M;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@
M8W)E871E9#H@)7,N`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E
M9"!N;W1E<P`E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E
M`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO
M;@`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R
M;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E
M<P`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I<R!N;W0@=W)I
M=&%B;&4N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD
M+@`E<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT<F%C="<@9FER
M<W0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L
M96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@9W5S
M=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`M+2!S96QE8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`#$@
M;F]T90`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\
M4')E=FEO=7,`/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N
M"D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N`$$@9&%T86)A<V4@8F%C
M:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT
M(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]0
M30!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M
M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O
M<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D
M96YI960@9&5L971I;F<@;F]T92X`06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE
M(&YO=&4N`$%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N`$%C8V5S
M<R!D96YI960@<V%V:6YG(&YO=&4Z("5S`$%C8V]U;G0@4&%S<W=O<F0`06-C
M;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!
M9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!
M9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!
M9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z
M`$%D9"!C871E9V]R>0!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@
M<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D
M('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@
M=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN
M9R!!($YE=R!.;W1E`$%D9&EN9R!N97<@9FEL97,@=&\@<F5P;W-I=&]R>3H`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E
M<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A
M=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R
M('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA
M=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA
M=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E
M<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO
M80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@
M97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N
M;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"
M87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L
M>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P
M<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!
M<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT
M:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S
M8V5N9&EN9P!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF
M:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M
M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T
M`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E
M<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q
M=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E
M<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`
M075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB
M875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE
M($-A=&5G;W)I97,Z`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&
M2"!%>&-U<V5S`$)A8VL@=&\@3F]T97!A9`!"86-K('1O($YO=&5P860@3W!T
M:6]N<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H
M<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S
M`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D
M80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B
M)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD
M`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!"
M;W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!"
M;W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U:6QD:6YG($U/(&9I
M;&5S(&9O<B!M;V1U;&4@)7,N+BX`0G5I;&1I;F<@;&]C86QE("5S+BXN(`!"
M=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--
M4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL(%!R;W!E
M<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD
M87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N
M8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@
M(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA
M8F5L<P!#871E9V]R>0!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@
M4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL
M('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT
M97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@
M*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@
M3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E
M('-O<G0@9&ER96-T:6]N`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@96UA:6QS+@!#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@86YD(&1I<W!L
M87D@;W!T:6]N<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L
M:7-T<RD`0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T
M:&4@<W5M;6%R>2!V:65W+@!#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N
M`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N`$-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`
M0VQE86YI;F<@=7`@;&]C86QE("5S+BXN(`!#;&5A<@!#;&5A<B!&;W)M`$-L
M96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S
M97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N
M=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S
M`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`
M0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#
M;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU
M;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;6%N
M9"!O<'1I;VYS.@!#;VUM86YD<SH`0V]M;65N=`!#;VUM:71T:6YG.@!#;VUM
M;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&]S92!-97-S86=E("@E<RD`
M0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N
M9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`
M0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@
M;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU
M90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]P
M>6EN9R`E<R!T;R`E<P!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M
M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!S
M97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C;W!Y("5S('1O
M("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!C<F5A=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S
M.@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@
M;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN
M9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B
M)7,B+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P
M87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O
M9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U
M;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S
M`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B
M('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S
M`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A
M(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E
M871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#
M<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%1I;64`0W5R
M<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N
M.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI
M8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T
M851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I
M;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R
M<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U
M;'0@261E;G1I='D`1&5F875L="!.;W1E<&%D`$1E9F%U;'0@4&5R;6ES<VEO
M;G,`1&5F875L="!P97)M:7-S:6]N<P!$969A=6QT('-O<G1I;F<@8W)I=&5R
M:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E
M;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N
M9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E
M;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI
M<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L
M96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES(&YO=&4`1&5L971E('1H
M:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E
M9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E
M;FUA<FL`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP
M=&EO;@!$97-C<FEP=&EO;CH`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO
M9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA
M>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@
M9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N
M;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N
M(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L
M:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`
M161I="!'<F]U<`!%9&ET($YO=&4`161I="!097)M:7-S:6]N`$5D:70@4&5R
M;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!C871E9V]R
M:65S(&%N9"!C;VQO<G,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S
M:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I
M;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I
M;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@3F]T90!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@
M>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N
M('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=')I97,Z("5D
M('1O=&%L+"`E9"!U<"UT;RUD871E+"`E9"!N97<L("5D(&-H86YG960L("5D
M('5N:VYO=VX`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17)R
M;W(Z(`!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>&5C=71I;F<Z`$5X
M<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R
M92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`
M17AP;VYE;G0`17AP;W)T`$5X<&]R="!.;W1E<P!%>'1R86-T:6YG(&9R;VT@
M)7,N+BX@`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1E]U;&P@5&5X
M=`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--
M0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O
M(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86ER`$9A;&ML86YD
M($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R
M.@!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H
M;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE
M($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N
M86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S
M="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G
M`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@
M*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F
M;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G
M;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`
M1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1F]U;F0@87!P
M;&EC871I;VYS.B`E<P!&;W5N9"!D:7)E8W1O<FEE<SH`1G(`1G)A;65S`$9R
M86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC
M:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`
M1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M
M90!&=7IZ>0!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL
M97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T
M960@0V]D90!'96YE<F%T:6YG('-T871U<R!F;W(@;6]D=6QE("5S+BXN`$=E
M;W)G:6$`1V5R;6%N>0!'971O<'0@17)R;W(Z(`!':&%N80!':6)R86QT87(`
M1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`
M1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'
M<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>0!'<F]U<"!P97)M:7-S:6]N<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M
M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S="!P
M97)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y
M86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`
M2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U
M.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(
M96QP97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N
M<VQA=&EO;G,@9F]R('1H92!(;W)D90IF<F%M97=O<FL@86YD(&ET<R!A<'!L
M:6-A=&EO;G,N"D9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!2
M14%$344@:6X@=&AI<R!D:7)E8W1O<GDN`$AE;6ES<&AE<F4`2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AI<W1O<GD@96YT<GD@
M;F%M97,@;75S="!B92!N;VXM96UP='D`2&]?;64`2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(
M;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4@=')A;G-L871I;VX@9V5N
M97)A=&]R`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U
M;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@
M8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE
M8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S("(E<R(`2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@
M;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S
M`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2
M=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N
M9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T
M(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"
M969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N
M=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@
M55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@
M9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@3F]T97,L(%-T
M97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T97,`26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@
M069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN
M8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I
M80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I
M;&%B;&4N`$EN:71I86QI>FEN9R!M;V1U;&4@)7,N+BX@`$EN<V5R="!#7V]L
M=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E
M8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E
M;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W
M('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O
M<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!)
M;G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@
M<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@
M8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D
M:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D
M:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E
M<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A
M;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV
M86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`
M26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`
M26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D
M=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT
M.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D
M9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`
M27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`
M2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E
M<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z
M86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#
M<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+
M97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$55
M0RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!-
M;V1I9FEE9`!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`
M3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`
M3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`
M3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG
M:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET
M:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I
M8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S
M<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,
M:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI
M<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES
M="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0
M;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN
M9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE
M(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS
M`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N
M9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T
M:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`
M34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U3
M1P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L
M:6Y?:RXN+@!-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A;&QE
M9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA:VEN9R!D:7)E8W1O<GD@
M)7,`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E
M('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E
M;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N
M9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R
M:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA
M<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC
M:6YE`$UE;6)E<G,`365M;R!497AT`$UE;G4@;6]D93H`365R9V4@8V5L;',`
M365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@
M`$UE<F=I;F<@;&]C86QE("5S+BXN(`!-97)G:6YG('1H92!03R!F:6QE(&9O
M<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!T<F%N<VQA=&EO
M;B!F;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T
M>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`
M365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F
M`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G
M92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES
M<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I
M9FEE9"!$871E`$UO9&EF>2!54DP`36]D:69Y:6YG("5S`$UO9'5L90!-;V1U
M;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT
M:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R
M;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`
M36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D
M;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@3F]T97,`
M37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.
M3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S
M`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C
M87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`
M3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE
M=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!.
M;W1E`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W
M:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H
M87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R
M:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T
M92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@
M8F4@861D960@8F5L;W<@=&AI<R!L979E;"X`3F\@8VAI;&1R96X@8V%N(&)E
M(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]M;6%N9"!S<&5C:69I
M960N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F
M="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&5N=')Y('=I=&@@=&AE
M(&ED("(E<R(@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N`$YO
M(&9I;&4@=7!L;V%D960`3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+@!.
M;R!L;V-A;&4@<W!E8VEF:65D+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO
M8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE
M('-P96-I9FEE9"X`3F\@;F]T97!A9',@87)E(&%V86EL86)L92!T;R!G=65S
M=',N`$YO(&YO=&5S`$YO(&YO=&5S(&UA=&-H('1H92!C=7)R96YT(&-R:71E
M<FEA+@!.;R!N;W1E<R!T;R!D:7-P;&%Y`$YO(&YU;6)E<B!S<&5C:69I960N
M`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($Q$05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T
M;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I
M;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`
M3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP
M;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R
M971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO7W1E`$YO;F4`3F]N92`H=7-E(&EM<&QI
M8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T
M:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W
M87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I
M;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E($-A=&5G
M;W)Y`$YO=&4@1&5T86EL<P!.;W1E($QI<W1S`$YO=&4@5&5X=`!.;W1E(%]4
M97AT`$YO=&4@;F]T(&9O=6YD+@!.;W1E7W!A9`!.;W1E<&%D)W,@;F%M93H`
M3F]T97!A9',`3F]T97!A9',@;75S="!H879E(&$@;F%M92X`3F]T97,`3F]T
M97,@4W5M;6%R>0!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E
M`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@
M;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE
M8W0`3V)J96-T($-R96%T;W(`3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,`
M3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY
M($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F
M9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A
M('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y
M<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]P=&EO;G,Z`$]R9&5R960@
M3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ
M:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@
M3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%
M;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-
M(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M
M4W1O<FUS`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE
M<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@
M1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O
M<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W
M;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!0
M87-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O
M<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@
M1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E
M=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0
M;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U
M<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN
M0&QI<W1S+FAO<F1E+F]R9RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@
M9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E
M;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R
M`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A
M=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@3&ES=`!2969R97-H(%!O<G1A
M;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E
M;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C871E9V]R
M>0!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER
M`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T
M(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!297-U;'1S("AI;F-L=61I;F<@2&]R
M9&4I.@!297-U;'1S.@!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R
M="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D
M;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P
M97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T
M`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2
M;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U
M;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG
M`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE
M;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I
M($%R86)I80!3879E`%-A=F4@)7,`4V%V92`G)7,G`%-A=F4@3W!T:6]N<P!3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S
M(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A
M<F-H($5N9VEN97,`4V5A<F-H(%)E<W5L=',`4V5A<F-H(%-C;W!E`%-E87)C
M:"!?5&5X=`!396%R8VAI;F<@2&]R9&4@87!P;&EC871I;VYS(&EN("5S`%-E
M87)C:&EN9R!G971T97AT(&)I;F%R:65S+BXN`%-E;&5C="!&:6QE<P!396QE
M8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@
M;W=N97(`4V5L96-T(&$@;F]T97!A9`!396QE8W0@82!S97)V97(`4V5L96-T
M(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E
M;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D
M(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`
M4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M
M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396QE8W1E9"!#
M871E9V]R:65S.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G
M86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!3
M97)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B
M;&4N`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO
M;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3
M:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@3F]T97!A9',Z`%-H
M;W<@86-T:6]N(&)U='1O;G,_`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C
M=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/P!3:&]W(&YO=&5P860@;F%M93\`4VAO=R!N;W1E<R!F<F]M('1H97-E(&-A
M=&5G;W)I97,`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I
M8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE
M("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E
M<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@
M5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG
M;B!U<`!3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N
M871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N
M8V4`4VMI<'!E9"XN+@!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO
M=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W
M97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R
M="!B>2!#871E9V]R>0!3;W)T(&)Y($YO=&4@5&5X=`!3;W)T(&]R9&5R('-E
M;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R
M;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T
M:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@
M86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD
M('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,
M86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0
M<F]V:6YC90!3=&%T=7,`4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@`%-T;W)A
M9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG
M(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-3
M4UT`4W4`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D
M("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL
M('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U
M8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S
M<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"`B)7,B+@!3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U
M;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`
M4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES
M92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP
M=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-
M87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R
M;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!4
M4U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I
M97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A
M;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`
M5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A
M='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L
M871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`
M5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@
M9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H96QP(&9I;&4@9F]R("5S
M(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N`%1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N
M<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES
M<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@
M8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T
M:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!H
M96QP(&9I;&4@)7,@9&ED;B=T('-T87)T('=I=&@@/#]X;6P`5&AE(&ED96YT
M:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E
M(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@
M9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S
M86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@
M=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N;W1E
M('=A<R!D96QE=&5D+@!4:&4@;F]T97!A9"`B)7,B(&-O=6QD;B=T(&)E(&-R
M96%T960Z("5S`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@8W)E871E9"X`
M5&AE(&YO=&5P860@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;F]T97!A
M9"`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@
M<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4
M:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE
M`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI
M<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL
M>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO
M=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D
M+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE
M<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R
M=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@
M)7,N`%1H97)E(&1O97-N)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E
M<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES
M=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B
M;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE
M("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P
M87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@
M9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@
M)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.;W1E
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD
M+@!4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y
M(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@
M<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+@!4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<P!4:&5R
M92!W87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E
M<P!4:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="X`5&AI<R!)34%0('-E
M<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI
M<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO
M+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU4
M4"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O
M(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U
M;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4
M:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N
M=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA
M(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O
M;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R
M(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S
M=7!P;W)T960N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I
M;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E
M(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE
M87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S8W)I<'0@;75S="!B
M92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE+@!4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@
M3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C
M:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4
M:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O
M=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M
M92`H7W1O<"D`5')A;G-L871E9`!4<F%N<VQA=&EO;G,`5')I;FED860@86YD
M(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI
M<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X
M.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T
M:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O
M("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@
M(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O
M(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S
M+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G
M;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M
M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O
M(&-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H
M551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N
M:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M`%5N:VYO=VX@8V]M;6%N9#H@)7,`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N
M<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E;G0M5'EP92X`56YS=7!P;W)T
M960@17AT96YS:6]N`%5N=')A;G-L871E9`!5<&1A=&4`57!D871E("5S`%5P
M9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!D871I;F<@)7,@:&5L<"!F:6QE
M(&9O<B`E<RX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U
M9W5A>0!5<V%G93H`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R
M871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S
M97(@<&5R;6ES<VEO;G,`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y
M(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,`57-E<G,@:6X@
M=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L
M=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA
M`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6
M97)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y
M($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I
M97<@3F]T92!$971A:6QS`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE
M=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD
M<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=A<FYI
M;F<Z(`!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E
M9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ
M*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/P!7:&EC:"!.;W1E<&%D('-H;W5L9"!T:&4@;F]T97,@
M8F4@861D960@=&\_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I
M;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES
M=',`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<FET:6YG('5P9&%T
M960@:&5L<"!F:6QE('1O("5S+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R
M86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C
M="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R
M;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$
M12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE3
M25=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@
M:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED
M;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@
M=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S+@!9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@82!N;W1E<&%D('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I
M9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI
M86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&
M<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@
M061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E
M<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&1E9F%U;'0@;F]T97!A9#H`66]U
M<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@
M86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+@I.;W0@86QL('-T
M<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,`66]U<B!N;W1E<&%D<SH`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I
M<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;
M4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES
M=')A=&EO;@!?0F%C:R!T;R!.;W1E<&%D`%]#3$D`7T-A=&5G;W)Y`%]$871A
M5')E90!?1&5L971E`%]$96QE=&4@4F]W`%]%9&ET`%]&:7)S="!,:6YE`%]'
M<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%>'!O
M<G0`7TQI<W0@3F]T97,`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN
M+BX`7TUY($YO=&5P861S`%].97<@3F]T90!?3W!T:6]N<P!?4&5R;6ES<VEO
M;G,`7U!R:6YT`%]296UO=F4@3&EN:RXN+@!?4V5A<F-H`%]3971U<`!?5&%B
M;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%N(&5R<F]R
M(&AA<R!O8V-U<F5D.@!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`9&]N90!F
M86EL960`9F%L;&EN9P!F:6QE`&9O=6YD.B``9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&EM;65D:6%T90!I;FQI;F4`;&EN97-=
M`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N
M86UE`&YO="!C:&%N9V5D`&YO="!F;W5N9`!N;W0@:6UP;&5M96YT960`;F]T
M('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`&YO=&5S+F-S=@!P97)C96YT`'!I
M>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A4
M5%``<W,`<W1E861Y`'1A<VL@;&ES=`!T:&4@2&]R9&4@4$\@9FEL92!F;W(@
M=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7!D871E9`!U
M<V5R('-E;&5C=`!V0V%R9`!V3F]T90!W.@!W96%T:&5R+F-O;0!0<F]J96-T
M+4ED+59E<G-I;VXZ($UN96UO(#$N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3,@,3<Z,3,K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`T
M+3(R(#(S.C0P*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!.=6YO($QO=7)E:7)O
M(#QN=6YO0&5T:"YP=#X*3&%N9W5A9V4M5&5A;3H@4&]R='5G=65S92`\9&5V
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("`M32P@+2UM97-S86=E/4U%3E-!
M1T5-(%5S87(@97-T82!M96YS86=E;2!D92!C;VUE=&EM96YT;R!E;2!V97H@
M9&$*("`@("`@("`@("`@("`@("`@("`@("`@(&UE;G-A9V5M('!O<B!O;6ES
M<^-O+@`@("UA+"`M+6%D9#U!4E%5259/("`@("!!9&EC:6]N87(@97-T92!A
M<G%U:79O(%!/(&%O(&-O;7#J;F1I;RX@571I;"!P87)A"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU:7(@=6T@8V]M<.IN9&EO(&1E('5M(')A;6\@
M9&EF97)E;G1E(&YO"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;7#J;F1I
M;R!G97)A9&\N`"`@+6(L("TM8F%S93TO0T%-22`@0V%M:6YH;R!P87)A(&\@
M9&ER96-T\W)I;R!B87-E("A(;W)D92D@82!U<V%R+@`@("UC+"`M+6-O;7!E
M;F1I=6T]05)152`@26YT96=R87(@;F]V87,@=')A9'7G]65S(&$@97-T92!A
M<G%U:79O(&1E(&-O;7#J;F1I;PH@("`@("`@("`@("`@("`@("`@("`@("`@
M92!NXV\@86\@8V]M<.IN9&EO('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O
M(&YA"B`@("`@("`@("`@("`@("`@("`@("`@("!P87-T82!H;W)D92]P;RX`
M("`M8RP@+2UC;VUP96YD:75M/4%2454@(%5S87(@97-T92!A<G%U:79O(&1E
M(&-O;7#J;F1I;R!E;2!V97H@9&\@87)Q=6EV;PH@("`@("`@("`@("`@("`@
M("`@("`@("`@<&]R(&]M:7-SXV\@*&-O;7!E;F1I=6TN<&\@;F$@<&%S=&$@
M:&]R9&4O<&\N`"`@+60L("TM9&5B=6<@("`@("`@36]S=')A<B!M96YS86=E
M;G,@9&4@97)R;R!D;W,@8FENX7)I;W,@97AE8W5T861O<RX`("`M9"P@+2UD
M:7)E8W1O<GD]4$%35$$@0W)I87(@=6T@8V]M<.IN9&EO(&YE<W1A('!A<W1A
M+@`@("UH+"`M+6AE;'`@("`@("`@($UO<W1R87(@97-T82!M96YS86=E;2!D
M92!A:G5D82X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S87(@87!E;F%S
M(&5S=&$@;&]C86QI>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5
M<V%R(&5S=&$@;&]C86QI>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@
M(%5S87(@97-T82!L;V-A;&EZ8>?C;RX`("`M;2P@+2UM;V1U;&4]3=-$54Q/
M("`@($-O;G-T<G5I<B!A<G%U:79O<R!-3R!A<&5N87,@<&%R82!E<W1E(&WS
M9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@
M+2UM;V1U;&4]3=-$54Q/("`@($QI;7!A<B!A<G%U:79O<R!03R!A<&5N87,@
M<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO
M<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-O;65T97(@87,@=')A
M9'7G]65S(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@
M("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@
M0W)I87(@;R!A<G%U:79O(%!/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO"B`@
M("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO9'5L
M93U-TT153$\@("`@26YT96=R87(@87)Q=6EV;W,@4$\@87!E;F%S('!A<F$@
M97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN
M`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!!8W1U86QI>F%R(&%R<75I=F]S
M(&1E(&%J=61A(&%P96YA<R!P87)A(&5S=&4*("`@("`@("`@("`@("`@("`@
M("`@("`@(&WS9'5L;R`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@06-T=6%L:7IA<B!A<&5N87,@97-T92!M\V1U;&\@*$AO<F1E*2X`("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($=E<F%R(&%R8VAI=F\@4$]4(&%P96YA
M<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H
M2&]R9&4I+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@3N-O(&EN=&5G<F%R
M(&YO=F%S('1R861UY_5E<R!N;R!C;VUPZFYD:6\N`"`@+6XL("TM;F\M8V]M
M<&5N9&EU;2`@("!.XV\@=7-A<B!U;2!C;VUPZFYD:6\N`"`@+7,L("TM<W1A
M=&ES=&EC<R`@("`@("!'=6%R9&%R(&5S=&%T[7-T:6-A<R!D92!T<F%D=>?C
M;R!N=6T@9FEC:&5I<F\@;&]C86PN`"`@+70L("TM=&5S="`@("`@("`@36]S
M=')A<B!O<R!P<F]G<F%M87,@82!E>&5C=71A<B!M87,@;N-O(&\@9F%Z97(N
M`"`@8VQE86YU<"`@("`@3&EM<&%R(&]F(&%R<75I=F]S(%!/(&1E(&5N=')A
M9&%S('!O<B!T<F%D=7II<B!O=2!O8G-O;&5T87,N`"`@8V]M;6ET("`@("`@
M0V]M971E<B!A<R!T<F%D=>?U97,@;F\@<V5R=FED;W(@0U93+@`@(&-O;6UI
M="UH96QP($-O;65T97(@87)Q=6EV;W,@9&4@86IU9&$@;F\@<V5R=FED;W(@
M0U93+@`@(&-O;7!E;F1I=6T@(%)E8V]N<W1R=6ER(&\@87)Q=6EV;R!D92!C
M;VUPZFYD:6\N($%T96[GXV\Z($\@;F]V;R!A<G%U:79O"B`@("`@("`@("`@
M("`@<V]B<F5P]64M<V4@86\@86YT:6=O+@`@(&5X=')A8W0@("`@($=E<F%R
M(&%R<75I=F]S(&UO9&5L;R!03R`H+G!O="DN`"`@:&5L<"`@("`@("`@36]S
M=')A<B!E<W1A(&UE;G-A9V5M(&1E(&%J=61A+@`@(&EN:70@("`@("`@($-R
M:6%R('5M(&]U(&UA:7,@87)Q=6EV;W,@4$\@<&%R82!U;6$@;F]V82!L;V-A
M;&EZ8>?C;RX*("`@("`@("`@("`@("!!=&5NY^-O.B!/<R!N;W9O<R!A<G%U
M:79O<R!S;W!R97#U96TM<V4@86]S(&%N=&EG;W,N`"`@;6%K92`@("`@("`@
M0V]N<W1R=6ER(&%R<75I=F]S(&)I;N%R:6]S($U/(&$@<&%R=&ER(&1O<R!A
M<G%U:79O<PH@("`@("`@("`@("`@(%!/(&5S<&5C:69I8V%D;W,N`"`@;6%K
M92UH96QP("`@36%R8V%R('1O9&%S(&%S(&5N=')A9&%S(&YO(&%R<75I=F\@
M6$U,(&1E(&%J=61A(&-O;6\@97-T86YD;PH@("`@("`@("`@("`@(&%C='5A
M;&EZ861A<R!E('!R97!A<F%R(&\@87)Q=6EV;R!P87)A(&$@<'+S>&EM82!E
M>&5C=>?C;PH@("`@("`@("`@("`@(&1E('5P9&%T92UH96QP+B!$979E+7-E
M(&5X96-U=&%R(&UA:V4M:&5L<"!$15!/25,@9&4*("`@("`@("`@("`@("!U
M<&1A=&4M:&5L<"!E(&1E(')E=F5R(&\@87)Q=6EV;R!D92!A:G5D82X`("!M
M97)G92`@("`@("!);G1E9W)A<B!O(&%R<75I=F\@4$\@8V]R<F5N=&4@8V]M
M(&\@87)Q=6EV;R!M;V1E;&\@4$\@8V]R<F5N=&4N`"`@=7!D871E("`@("`@
M17AE8W5T87(@97AT<F%C="!E(&UE<F=E(&5M('-E<77J;F-I82X`("!U<&1A
M=&4M:&5L<"!%>'1R86ER('1O9&%S(&%S(&5N=')A9&%S(&YO=F%S(&4@;6]D
M:69I8V%D87,@9&\@87)Q=6EV;R!D90H@("`@("`@("`@("`@(&%J=61A(%A-
M3"!E;2!I;F=LZG,@92!I;G1E9W+A+6QA<R!C;VT@87,@97AI<W1E;G1E+@`@
M)B,Q-3$[("5S(&5S=.$@<')O;G1O('!A<F$@969E8W1U87(@87,@;W!E<F'G
M]65S(&1E(&UA;G5T96[GXV\@;6%R8V%D87,@86)A:7AO+@`@*"5S(&1I87,@
M871RX7,I`"`H0VAA=F4@9&4@86-E<W-O("5S*0`@*&1E;G1R;R!D92`E<R!D
M:6%S*0`@*&AO:F4I`"`H86UA;FCC*0`@*&]N=&5M*0`@8V]M(``B)7,B(&[C
M;R#I('5M82!E<V-O;&AA(';A;&ED82X`(B5S(B!NXV\@97-TX2!C;VYF:6=U
M<F%D;R!N;R!296=I<W1O(&1O($AO<F1E+@`B)7,B(')E<')E<V5N=&%D;W(@
M9&4@X7)V;W)E(&[C;R!E;F-O;G1R861O+@`B)7,B(&9O:2!A9&EC:6]N861O
M(&%O('-I<W1E;6$@9&4@9W)U<&]S+@`B)7,B)R!F;VD@861I8VEO;F%D;R!A
M;R!S:7-T96UA(&1E('!E<FUI<W/U97,N`"(E<R(@;N-O(&9O:2!C<FEA9&\Z
M("5S+@`E9"`E<R!E("5S`"5D(&)Y=&5S(&5S8W)I=&]S`"5D(&YO=&%S`"5D
M(&1E("5D(&5N=')A9&$@;6%R8V%D87,@8V]M;R!A8W1U86QI>F%D87,`<')E
M=FESXV\@9&4@)60@9&EA<P`E<R`M($YO=&EF:6-AY^-O`"5S($%D;6EN:7-T
M<F'GXV\`)7,@26UP<F5S<^-O($1I9VET86P`)7,@2T(`)7,@3W!E<F'G]65S
M(&1E($UA;G5T96[GXV\@+2!#;VYF:7)M8>?C;P!#;VYF:6=U<F%R("5S`"5S
M(%-U8G-C<F5V97(`)7,@5&5R;6]S(&1O($%C;W)D;P`E<R!JX2!E>&ES=&4N
M`"5S(&5M("5S("5S`$9I8VAE:7)O("5S(&EM<&]R=&%D;R!C;VT@<W5C97-S
M;P!NXV\@<V4@<&]D92!E<V-R979E<B!E;2`E<RX`)7,@Z2!O8G)I9V%T\W)I
M;P`E<R!M:6YU=&]S`"5S(&[C;R!F;VD@96YC;VYT<F%D;RX`)7,@;N-O(&9O
M:2!E;F-O;G1R861O+B!%>&5C=71A<B`G=')A;G-L871I;VX@97AT<F%C="<@
M<')I;65I<F\N`"5S(&$@)7,@9&4@)7,`0V]N=&%C=&]S(&1E("5S`$-A;&5N
M9.%R:6\@9&4@)7,`3&EV<F]S(&1E($YO=&%S(&1E("5S`%1A<F5F87,@9&4@
M)7,`)7,Z("5S`"P@8V]M(')A:F%D87,`+"!C;VT@<F%J861A<R`E<R`E<P`L
M('9A<FGA=F5L(&1E("5S(&$@)7,`+2T@97-C;VQH82`M+0`M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T`,2!N;W1A`$9O<FUA=&\@9&4@,3(@:&]R87,@
M*$%-+U!-*0!&;W)M871O(&1E(#(T(&AO<F%S`#(T(&AO<F%S`#Q!;G1E<FEO
M<@!E=&EQ=65T82`\9V5T=&5X=#X@<&]R(&9E8VAA<B!N;R!F:6-H96ER;R`E
M<RX*06)R:6YD;R!A(&5T:7%U971A(&5N8V]N=')A9&$@;F$@;&EN:&$@)60N
M`$5S=&4@8FQO8V\@97AI9V4@=6T@;65C86YI<VUO('5S86YD;R!B87-E<R!D
M92!D861O<RX`3V-O<G)E=2!U;2!E<G)O(&9A=&%L`,D@;F5C97-SX7)I82!U
M;6$@8VAA=F4@</IB;&EC82!01U`@<&%R82!E;F-R:7!T87(@82!M96YS86=E
M;2X`R2!N96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%!'4"!P87)A('9E
M<FEF:6-A<B!A(&%S<VEN871U<F$@9&4@=6UA(&UE;G-A9V5M`%!A<F$@9&5C
M:69R87(@=6UA(&UE;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@
M</IB;&EC82!01U`L('5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!F<F%S
M92UP87-S92X`4&%R82!A<W-I;F%R('5M82!M96YS86=E;2!SXV\@;F5C97-S
MX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4$=0+"!U;6$@8VAA=F4@<')I=F%D
M82!01U`@92!U;6$@9G)A<V4M<&%S<V4N`%!A<F$@9&5C:69R87(@=6UA(&UE
M;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!3+TU)
M344L('5M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M82!F<F%S92UP87-S
M92X`4&%R82!A<W-I;F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@
M=6UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D82!3
M+TU)344@92!U;6$@9G)A<V4M<&%S<V4N`,D@;F5C97-SX7)I82!U;6$@8VAA
M=F4@</IB;&EC82!3+TU)344@<&%R82!E;F-R:7!T87(@=6UA(&UE;G-A9V5M
M+@!.^G9E;G,@9&4@;6%N:.,`0VAU=FES8V]S(&1E($UA;FCC`$-H=79A(&1E
M(&UA;FCC`$%G=6%C96ER;W,@9&4@;6%N:.,`3F5V]65S(&1E(&UA;FCC`$%-
M+U!-`$%022!)1`!!8V5R8V$@9&5S=&4@961I=&]R`$%C97)C82XN+@!"87-E
M<R!A;&EN:&%D87,`0V5N=')O<R!A;&EN:&%D;W,`06-E<W-O(&YE9V%D;R!A
M;R!C<FEA<B!P87-T82!61E,N`$%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q
M=6EV;R!61E,N`$%C97-S;R!N96=A9&\@86\@<F5M;W9E<B!A(&YO=&$N`$%C
M97-S;R!N96=A9&\@86\@;6]V97(@82!N;W1A+@!!8V5S<V\@;F5G861O(&%O
M(&=U87)D87(@82!N;W1A(&5M("5S+@!!8V5S<V\@;F5G861O(&%O(&=U87)D
M87(@82!N;W1A.B`E<P!086QA=G)A+5!A<W-E(&1A($-O;G1A`$-O;G1A(&-O
M;F=E;&%D82X`0V]N=&%B:6QI9&%D90!!9&EC:6]N87(`061I8VEO;F%R($=R
M=7!O($9I;&AO`$%D:6-I;VYA<B!097)M:7-SXV\@1FEL:&$`06-R97-C96YT
M87(@07%U:3H`061D:6-I;VYA<B!.;W9O($=R=7!O`$%D:6-I;VYA<B!.;W9A
M(%!E<FUI<W/C;P!!9&EC:6]N87(@=6T@9W)U<&\@9FEL:&\@82`B)7,B`$%D
M:6-I;VYA<B!U;6$@<&5R;6ES<^-O(&9I;&AA(&$@(B5S(@!!9&EC:6]N87(@
M;F]V;R!U=&EL:7IA9&]R.@!!9&EC:6]N87(@8V%T96=O<FEA`$%D:6-I;VYA
M<B!C;VQU;F$`061I8VEO;F%R(&YO=F]S(&UE;6)R;W,`061I8VEO;F%R('!A
M<F-E:7)O`$%D:6-I;VYA<B!O($UE;G4@)7,@8V]M;R!"87)R82!,871E<F%L
M($UO>FEL;&$`061I8VEO;F%R(&%O<R!#;VYT86-T;W,Z`$%D:6-I;VYA<B!A
M;W,@;65U<R!C;VYT86-T;W,`061I8VEO;F%R('5T:6QI>F%D;W(`061I8VEO
M;F5I("(E<R(@86\@<VES=&5M82P@;6%S(&[C;R!P=61E(&%D:6-I;VYA<B!I
M;F9O<FUAY^-O(&1E('-U8G-C<FGGXV\@861I8VEO;F%L.B`E<RX`061I8VEO
M;F5I("(E<R(@86\@<VES=&5M82X@2N$@<&]D92!E;G1R87(N`$%D:6-I;VYA
M;F1O(%5M82!.;W9A($YO=&$`061I8VEO;F%N9&\@;F]V;W,@87)Q=6EV;W,@
M86\@<F5P;W-I=/-R:6\Z`$$@861IY^-O(&1E('5T:6QI>F%D;W)E<R!E<W3A
M(&1E<V%C=&EV861A+@!%;F1E<F7G;P!#;VYT86-T;W,`061M:6YI<W1R87(@
M+2!A=')I8G5I<B!P97)M:7-S]65S(&$@;W5T<F]S('5T:6QI>F%D;W)E<P!!
M9&UI;FES=')AY^-O`$%N^FYC:6]S`$%F96=A;FES=.-O`$%L8N)N:6$`07)G
MZ6QI80!!;&-U;FAA`$%L:6YH87(`06QI;FAA;65N=&\Z`%1U9&\`5&]D;W,@
M;W,@571I;&EZ861O<F5S($%U=&5N=&EC861O<P!4;V1O<R!O<R!'<G5P;W,`
M5&]D87,@87,@4&5R;6ES<_5E<P!4;V1O<R!O<R`H<75A=')O*2!L861O<P!0
M97)M:71I<B!M^FQT:7!L;W,@96YD97)EYV]S`%!E<FUI=&ER(&%T<FEB=6GG
MXV\@9&\@=&EP;R!D92!L:7-T87,@;W)D96YA9&%S/P!*X2!E>&ES=&4`16YT
M<F%D82!)35-0($%L=&5R;F%T:79A`%!A;&%V<F$M4&%S<V4@24U34"!!;'1E
M<FYA=&EV80!.;VUE(&1E(%5T:6QI>F%D;W(@24U34"!!;'1E<FYA=&EV;P!%
M;F1E<F7G;R!I;G;A;&ED;P!-;V1E;&]S(&%L=&5R;F%T:79O<P!497AT;R!A
M;'1E<FYA=&EV;SH`4V%M;V$@06UE<FEC86YA`$9O:2!E<W!E8VEF:6-A9&\@
M=6T@=F%L;W(@:6YVX6QI9&\N`$]C;W)R974@=6T@97)R;R!D97-C;VYH96-I
M9&\N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&$`16YT<F5P;W-T;R`H<')O>'DI
M($%N\VYI;6\`4F5S<&]S=&$`06YTX7)C=&EC;P!!;G3M9W5A(&4@0F%R8G5D
M80!!<&QI8V'GXV\`07!L:6-AY^-O('!R;VYT82X`07!L:6-A<B!A(%!A<G1I
M;&AA<R!&:6QH87,`07!R;W9A<@!486UA;FAO($%P<F]X:6UA9&\`06)R:6P`
M07+A8FEC;R`H5VEN9&]W<RTQ,C4V*0!486UA;FAO(&1O($9I8VAE:7)O(&1E
M($%R<75I=F\`3F]M92!D;R!!<G%U:79O`%1E;2!A(&-E<G1E>F$@<75E('%U
M97(@<F5M;W9E<B!O('!E9&ED;R!D92!S=6)S8W)IY^-O('!A<F$@)7,@/P!4
M96T@82!C97)T97IA('%U92!Q=65R(')E;6]V97(@(B5S(B!E('%U86ES<75E
M<B!S=6(M9W)U<&]S/P!!<F=E;G1I;F$`07)MZ6YI80!!<FWI;FEO("A!4DU3
M0TE)+3@I`$%R=&4`07)U8F$`0W)E<V-E;G1E`$EL:&$@9&4@07-C96YSXV\`
M07)T92!!4T-)20!296=IXV\@P7-I82]086/M9FEC;P!0961I<B!C;VYF:7)M
M8>?C;R!A;G1E<R!D92!R96%L:7IA<B!O<&5R8>?U97,@9&4@;6%N=71E;N?C
M;S\`0V]L=6YA<R!D92!A=')I8G5IY^-O`%1E;G1A=&EV82!D92!R96UOY^-O
M(&1E('5M(&=R=7!O(&EN97AI<W1E;G1E+@!496YT871I=F$@9&4@<F5M;^?C
M;R!D92!U;6$@<&5R;6ES<^-O(&EN97AI<W1E;G1E+@!496YT871I=F$@9&4@
M961IY^-O(&1E('5M82!P97)M:7-SXV\@:6YE>&ES=&5N=&4N`%1E;G1A=&EV
M82!D92!E9&GGXV\@9&4@=6UA('!A<G1I;&AA(&EN97AI<W1E;G1E+@!!=')I
M8G5T;W,`06=O<W1O`$%U<W1RX6QI80#!=7-T<FEA`$%U=&A?8WER<W%L.B!!
M(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N
M`$%U=&A?8WER=7,Z($\@;65C86YI<VUO(&[C;R!T96T@87,@8V%P86-I9&%D
M97,@;F5C97-SX7)I87,N`$%U=&A?8WER=7,Z($$@97AT96YSXV\@:6UA<"!N
M96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]F='`Z($$@97AT
M96YSXV\@1E10(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B!#;VUP
M:6QE(&\@4$A0(&-O;2!A(&]PY^-O("TM96YA8FQE+69T<"X`075T:%]I;6%P
M.B!!(&5X=&5N<^-O($E-05`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A
M9&$N`$%U=&A?:W)B-3H@02!E>'1E;G/C;R!K<F(U(&YE8V5S<^%R:6$@;N-O
M(&9O:2!E;F-O;G1R861A+@!!=71H7VQD87`Z($$@97AT96YSXV\@3$1!4"!N
M96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]L9&%P.B!);7!O
M<W/M=F5L(&%D:6-I;VYA<B!U=&EL:7IA9&]R("5S+B!%:7,@;R!Q=64@;R!S
M97)V:61O<B!D:7-S93H@`$%U=&A?;&1A<#H@26UP;W-S[79E;"!R96UO=F5R
M(&\@=71I;&EZ861O<B`E<P!!=71H7VQD87`Z($EM<&]S<^UV96P@86-T=6%L
M:7IA<B!O('5T:6QI>F%D;W(@)7,`075T:%]M8V%L.B!!(&5X=&5N<^-O($U#
M04P@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`$%U=&A?<VUB875T
M:#H@02!E>'1E;G/C;R!S;6)A=71H(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O
M;G1R861A+@!!(&%U=&5N=&EC8>?C;R!F86QH;W4`02!A=71E;G1I8V'GXV\@
M9F%L:&]U+B`E<P!!(&%U=&5N=&EC8>?C;R!F;VD@<F5J96ET861A('!E;&\@
M<V5R=FED;W(@4D%$2553+@!!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!&
M5%`@9F%L:&]U+@!#871E9V]R:6%S($1I<W!O;NUV96ES.@!#86UP;W,@9&ES
M<&]N[79E:7,Z`$%Z97)B86EJXV\`1&5S8W5L<&%S(")"3T9((@!6;VQT87(@
M86\@3&EV<F\@9&4@3F]T87,`5F]L=&%R(.!S($]PY_5E<R!D92!,:79R;W,@
M9&4@3F]T87,`1G5N9&\`0V]R(&1O($9U;F1O`%!A;&%V<F$M4&%S<V4@:V5R
M8F5R;W,@97)R861A+@!.;VUE(&1E(%5T:6QI>F%D;W(@:V5R8F5R;W,@97)R
M861O+@!"86%M87,`0F%RZ6T`0N%L=&EC;R`H25-/+3@X-3DM,3,I`$)A;F=L
M861E8VAE`$)A<F)A9&]S`$QI;FAA(&)A<V4`0FEE;&]R<OIS<VEA`$+I;&=I
M8V$`0F5L:7IE`$)E;FEM`$)E<FUU9&$`0G5TXV\`06YI=F5R<^%R:6\`3R!B
M;&]C;R`B)7,B(&1A(&%P;&EC8>?C;R`B)7,B(&[C;R!F;VD@96YC;VYT<F%D
M;RX`0V]N9FEG=7)AY_5E<R!D92!";&]C;W,`5&EP;R!D92!";&]C;P!.96=R
M:71O`$)O;.UV:6$`36%R8V%D;W)E<P!";W)D80!%<W!E<W-U<F$@9&$@8F]R
M9&$Z`$)O<F1A<P!"\W-N:6$M2&5R>F5G;W9I;F$`06UB87,`0F]T<W5A;F$`
M0F%S90!);&AA($)O=79E=`!"<F%S:6P`5&5R<FET\W)I;R!"<FETXFYI8V\@
M9&\@3V-E86YO(,UN9&EC;P!"<G5N96D@1&%R=7-S86QA;0!#;VYS=')U:6YD
M;R!A<G%U:79O<R!-3R!P87)A(&\@;?-D=6QO("5S+BXN`$-O;G-T<G5I;F1O
M(&QO8V%L:7IAY^-O("5S+BXN(`!"=6QGX7)I80!,:7-T($ET96UI>F%D80!"
M=7)Q=6EN82!&87-O`$)U<OIN9&D`0TU3`$-20P!0;VYT;W,@9&4@1&ES=')I
M8G5IY^-O($-23`!#4U8`4')O<')I961A9&5S(&1A*',I($/I7VQU;&$H<RDN
M+BX`26YI8VEA;&EZ8>?C;R!D82`B8V%C:&4B(&[C;R!F;VD@8V]N8VQU[61A
M+@!#86QE;F3A<FEO`$-A;&UO`$-A;6)O9&IA`$-A;6%R]65S`$[C;R!P;W-S
M;R!R96EN:6-I87(@82!P86QA=G)A+7!A<W-E(&%U=&]M871I8V%M96YT92P@
M8V]N=&%C=&4@;R!S974@861M:6YI<W1R861O<B!D92!S:7-T96UA<RX`26UP
M;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!)34%0.B`E<P!#86YA9.$`
M0V%N8V5L87(`0V%N8V5L87(@4F5L873S<FEO(&1E(%!R;V)L96UA<P!.XV\@
M8V]N<VEG;R!R96UO=F5R(&\@9FEC:&5I<F\@(B5S(BX`3N-O(&-O;G-I9V\@
M96YC;VYT<F%R('5M(&1I<F5C=/-R:6\@=&5M<&]RX7)I;RX`26UP;W-S[79E
M;"!C;VYT:6YU87(@<V5M(&\@<&%RXFUE=')O("=T87)G971&:6QE)RX`3N-O
M(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@(B5S(BX`26UP;W-S[79E
M;"!R96UO=F5R+"!E>&ES=&5M("5D(&9I;&AO<RX`3N-O(.D@<&]S<^UV96P@
M<F5O<F1E;F%R.B!O(&[Z;65R;R!D92!E;G1R861A<R!F;W)N96-I9&%S(&[C
M;R!C;W)R97-P;VYD92!A;R!N^FUE<F\@9W5A<F1A9&\N`$[C;R!F;VD@<&]S
M<^UV96P@96YC86UI;FAA<B!A(&UE;G-A9V5M('!A<F$@;R!N^FUE<F\@:6YD
M:6-A9&\N`%)E</IB;&EC82!D92!#86)O(%9E<F1E`$QE9V5N9&$`0V%T96=O
M<FEA<R!E($-O<F5S`$-A=&5G;W)I80!);&AA<R!#86EMXV\`5&5L969O;F4@
M0V5L=6QA<@!0<F]P<FEE9&%D97,@9&%S($/I;'5L87,`16YC:&EM96YT;R!D
M87,@0^EL=6QA<SH`4')O<')I961A9&5S(&1A<R!CZ6QU;&%S`$5S<&'G86UE
M;G1O(&1A<R!CZ6QU;&%S.@!496QE;?-V96P`0^EL=&EC;R`H25-/+3@X-3DM
M,30I`$-E;G1R87(`4F5P^F)L:6-A($-E;G1R;R!!9G)I8V%N80!%=7)O<&$@
M0V5N=')A;"`H25-/+3@X-3DM,BD`4&]R;65N;W)E<R!D;R!#97)T:69I8V%D
M;P!$;VYO(&1O($-E<G1I9FEC861O`%!O;.UT:6-A<R!D92!#97)T:69I8V%D
M;P!297#Z8FQI8V$@9&\@0VAA9&4`06QT97)A<@!-=61A<B!D:7)E8^?C;R!D
M92!O<F1E;F'GXV\`06QT97)E(&\@;F]M92!E(&5N9&5R9>=O('%U92!A<R!P
M97-S;V%S('9E<N-O('%U86YD;R!L97)E;2!E(')E<W!O;F1E<F5M(.!S('-U
M87,@;65N<V%G96YS+@!!;'1E<F%R(&%S(&]PY_5E<R!D92!O<F1E;F'GXV\@
M92!V:7-U86QI>F'GXV\@9&%S(&YO=&%S+@!#87)A8W1E<F4`5F5R:5]F:6-A
M<B!,:6=AY^-O+BXN`$UA<G%U92!A<R!O<&5R8>?U97,@<75E(&1E<V5J82!E
M>&5C=71A<B!N97-T92!M;VUE;G1O+@!297#Z8FQI8V$@9&\@0VAI;&4`4F5P
M^F)L:6-A(%!O<'5L87(@9&$@0VAI;F$`0VAI;NIS(%-I;7!L:69I8V%D;W,@
M*$=",C,Q,BD`0VAI;NIS(%1R861I8VEO;F%L("A":6<U*0!%<V-O;&AA(&$@
M<&%L879R82UP87-S90!%<V-O;&AA('5M($YO;64@9&4@571I;&EZ861O<@!%
M<V-O;&AA(&-O;6\@;6]S=')A<B!A<R!D871A<SH`17-C;VQH82!O(&5S=&EL
M;R!D87,@;&ES=&$@*'!A<F$@;&ES=&%S(&]R9&5N861A<RD`17-C;VQH82!A
M<R!C871E9V]R:6%S(&1E(&YO=&%S(&$@;&ES=&%R(&YA('9I<W5A;&EZ8>?C
M;R!S=6UA<FEZ861A+@!%<V-O;&AA(&\@<V5U($QI=G)O(&1E($YO=&%S('!O
M<B!O;6ES<^-O+@!);&AA(&1O($YA=&%L`$[C;R!F;VD@96YC;VYT<F%D82!A
M(&1E9FEN:>?C;R!D82!C;&%S<V4@)7,N`$QI;7!A;F1O(&]S(&%R<75I=F]S
M(%!/(&1O(&WS9'5L;R`E<RXN+@!,:6UP86YD;R!A(&QO8V%L:7IAY^-O("5S
M+BXN(`!,:6UP87(`3&EM<&%R($9O<FUU;.%R:6\`3&EM<&%R(&5T:7%U971A
M<R!D;R!-4T]F9FEC90!,:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<CH@)7,`
M3&EM<&%R(&1A9&]S(&1O('5T:6QI>F%D;W(`3&EM<&%R(&1A9&]S(&1O('5T
M:6QI>F%D;W(`3&EM<&$@5&%R9&4`0VQI<75E('!A<F$@0V]N=&EN=6%R`$-L
M:6-K871E;&P@=FEA($A45%``1F5C:&%R(&IA;F5L80!.^G9E;G,`3OIV96YS
M($UA=&EN86ES`$5N979O861O`$EL:&%S($-O8V]S("A+965L:6YG*0!#;VQA
M<'-A<B!"87)R82!,871E<F%L`$)O<F1A<R!#;VQA<'-A9&%S`%)E</IB;&EC
M82!D82!#;VST;6)I80!#;W)E<P!086QE=&4`4V5L96/GXV\@9&4@8V]R97(`
M0V]L=6YA<SH`5.UT=6QO<R!D87,@8V]L=6YA<P!"1`!#;VUA;F1O`$-O;G-O
M;&$@9&4@0V]M86YD;W,`3W#G]65S(&1O(&-O;6%N9&\Z`$-O;6%N9&]S.@!#
M;VUE;G3A<FEO`$-O;65T96YD;P!.;VUE($-O;75M`$-O;6]R;W,`16UP<F5S
M80!%<V-R979E<B`H)7,I`$-O;7!U=&%D;W)E<P!#;VYD:>?C;P!#;VYD:>?U
M97,`1&EF97)E;N=A<R!D92!#;VYF:6=U<F'GXV\`02!C;VYF:6=U<F'GXV\@
M97-TX2!D97-A8W1U86QI>F%D80!#;VYF:6=U<F%R("5S`$-O;F9I<FUE(&$@
M4&%L879R82U087-S90!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\@0V]N9V\`
M4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1O($-O;F=O`$-O;F5XXV\@9F%L:&]U
M+@!#;VYE>.-O(&9A;&AO=3H@`$-O;F5XXV\@86\@<V5R=FED;W(@9&4@8VAA
M=F5S('#Z8FQI8V%S(')E8W5S861A+@!#;VYE>.-O(&%O('-E<G9I9&]R(&1E
M(&-H879E<R!P^F)L:6-A<R!R96-U<V%D82X@4F%ZXV\Z("5S("@E<RD`0V]N
M97CC;R!A;R!S97)V:61O<B!&5%`@<F5C=7-A9&$N`$-O;G1A8W1O<R!A9&EC
M:6]N861O<R!C;VT@<W5C97-S;R!A;R!S974@;&EV<F\@9&4@96YD97)EYV]S
M+@!4:7!O(&1E(&-O;G1E^F1O(&1O(&%R<75I=F\@8V]M<')I;6ED;SH@`$-O
M;G1E^F1O(&1E("5S`$-O;G1I;G5A<@!);&AA<R!#;V]K`$)O;&EN:&\@8VAI
M;NIS`$-O<&EA<@!#;W!I87(@<V5L96/GXV\`0V]P:6%N9&\@9&4@)7,@<&%R
M82`E<P!297#Z8FQI8V$@9&$@0V]S=&$@4FEC80!297#Z8FQI8V$@9&$@0V]S
M=&$@9&\@36%R9FEM`$[C;R!F;VD@<&]S<^UV96P@96YC<FEP=&%R(&$@;65N
M<V%G96T@8V]M(%!'4"X`3N-O(&9O:2!P;W-S[79E;"!A<W-I;F%R(&$@;65N
M<V%G96T@8V]M(%!'4"X`3N-O(&9O:2!P;W-S[79E;"!E;F-R:7!A<B!A(&UE
M;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A
M(&UE;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@861I8VEO
M;F%R(&\@8V]N=&%C=&\N("5S`$9A;&AA(&YA(&QI9V'GXV\@*&)I;F0I(&%O
M('-E<G9I9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@=F5R:69I8V%R(&\@
M<V%L9&\N("5S`$[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED
M;W(@(B5S(B!U<V%N9&\@1E10.B`E<P!.XV\@9F]I('!O<W/M=F5L(&-O<&EA
M<B`E<R!P87)A("5S`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&-R:6%R('!A<W1A
M(&1E(&QO8V%L:7IAY^-O('!A<F$@82!L;V-A;&EZ8>?C;R`E<SH`3N-O(&9O
M:2!P;W-S[79E;"!D97-E;F-R:7!T87(@;W,@9&%D;W,@8V]M(&\@4$=0+@!.
MXV\@9F]I('!O<W/M=F5L(&1E<V5N8W)I<'1A<B!O<R!D861O<R!C;VT@4R]-
M24U%+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@8V]N=&%C=&\N("5S`$[C
M;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!L:7-T82!D92!D:7-T<FEB=6GGXV\N
M("5S`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(")S8W)I<'0B(&1E(&%C
M='5A;&EZ8>?C;R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@
M;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(&1O(&1E<W1I;F%T
MX7)I;RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!O(&QI=G)O(&1E(&5N9&5R
M9>=O<R!C;VUP;&5T;RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;R!C;VUP;&5T82X`3N-O(&9O:2!P;W-S[79E;"!O
M8G1E<B!A(&QI<W1A(&-O;7!L971A(&1A<R!L:7-T87,@9&4@9&ES=')I8G5I
MY^-O+@!);7!O<W/M=F5L(&-A<G)E9V%R(&5S=')A=.EG:6$@(B5S(BX`26UP
M;W-S[79E;"!M:V1I<B`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@
M8VAA=F4@</IB;&EC82!A('!A<G1I<B!D;R!S97)V:61O<B!D92!C:&%V97,@
M</IB;&EC87,N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@(B5S(B!P87)A(&5S
M8W)I=&$N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@)7,N`$[C;R!F;VD@<&]S
M<^UV96P@86)R:7(@;R!M\V1U;&\@9&4@36%N=71E;N?C;R!D92!487)E9F%S
M("5S`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@<&%S=&$@(B5S(BX`3N-O(&9O
M:2!P;W-S[79E;"!L97(@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5I;FEC:6%R
M(&$@<&%L879R82UP87-S92!D;R!U=&EL:7IA9&]R(&EN9&EC861O+B!!;&=U
M;2!O=2!T;V1O<R!O<R!P;W)M96YO<F5S(&[C;R!E<W1A=F%M(&-O<G)E8W1O
M<RX@4&]R(&9A=F]R('1E;G1E(&1E(&YO=F\@;W4@8V]N=&%C=&4@;R!S974@
M861M:6YI<W1R861O<B!D92!S:7-T96UA<R!S92!P<F5C:7-A<B!D92!M86ES
M(&%J=61A+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R($%#3`!.XV\@9F]I('!O
M<W/M=F5L(&]B=&5R(&QI=G)O(&1E(&5N9&5R9>=O<RX@)7,`3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX@)7,`
M3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A<R!C;VUP973J;F-I87,@9&\@<V5R
M=FED;W(`3N-O(&9O:2!P;W-S[79E;"!R979E<G1E<B!A(&-O;F9I9W5R8>?C
M;RX`26UP;W-S[79E;"!R;61I<B`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&=U
M87)D87(@82!C;VYF:6=U<F'GXV\@9&4@)7,N`$[C;R!F;VD@<&]S<^UV96P@
M9W5A<F1A<B!A(&-O;F9I9W5R8>?C;R!D92!S86QV86=U87)D82X`3N-O(&9O
M:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A
M<F1A.B`E<P!.XV\@9F]I('!O<W/M=F5L(&=U87)D87(@;R`B<V-R:7!T(B!D
M92!A8W1U86QI>F'GXV\@96TZ("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@9W5A
M<F1A<B!A(&-O;F9I9W5R8>?C;R!D92!S86QV86=U87)D82`E<RX`3N-O(&9O
M:2!P;W-S[79E;"!G=6%R9&%R(&\@87)Q=6EV;R!D92!C;VYF:6=U<F'GXV\@
M)7,N(%!O9&4@=7-A<B!U;6$@9&%S(&]PY_5E<R!P87)A(&=U87)D87(@;R!C
M\V1I9V\@96T@)7,@;W4@8V]P:6%R(&UA;G5A;&UE;G1E(&\@8_-D:6=O(&%B
M86EX;R!P87)A("5S+@!.XV\@9F]I('!O<W/M=F5L('!R;V-U<F%R(&YO('-E
M<G9I9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@9&5S;&EG87(@(B5S(BX`
M3N-O(&9O:2!P;W-S[79E;"!A8W1U86QI>F%R(&-O;G1A8W1O+B`E<P!.XV\@
M9F]I('!O<W/M=F5L(&%C='5A;&EZ87(@82!L:7-T82!D92!D:7-T<FEB=6GG
MXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@82!C;VYF:6=U<F'G
MXV\@<&%R82`B)7,B.B`E<P!.XV\@96YC;VYT<F5I(&$@0F%R<F$@3&%T97)A
M;"!D;R!-;WII;&QA+B!!<W-E9W5R92US92!Q=64@82!B87)R82!L871E<F%L
M(&5S=.$@86)E<G1A+@!.XV\@9F]I('!O<W/M=F5L(&%T<FEB=6ER(&%O('5T
M:6QI>F%D;W(@(B5S(B!O<R!S96=U:6YT97,@9&ER96ET;W,@<V]B<F4@82!P
M87-T82`B)7,B.B`E<P!497AT;R!#;VYT861O`%!A[7,`0W5R<V]S`$-R:6%R
M`$-R:6%R('5M82!L:6=AY^-O`$-R:6%R('5M82!N;W9A`$-R:6%R('-U8BUP
M87-T87,`0W)I861A`%!E<FUI<W/U97,@9&\@0W)I861O<@!.^FUE<F\@9&\@
M8V%R=.-O(&1E(&-RZ61I=&\`4F5P^F)L:6-A(&1A($-R;^%C:6$`4F5P^F)L
M:6-A(&1E($-U8F$`475A=')O(&9A<V5S(&-O<G)E;G1E<P!$871A+TAO<F$`
M55),(&-O<G)E;G1E(.D`17-T861O(&1O(%1E;7!O`%-I='5AY^-O(&%C='5A
M;#H@`$5S=&EL;R!A8W1U86P`4&5R<V]N86QI>F%R(&%S('1A<F5F87,@<75E
M('-E<N-O(&5X96-U=&%D87,@87%U86YD;R!O(&QO9VEN(&YO("5S+@!#;W)T
M87(`0V]R=&%R(&$@<V5L96/GXV\`4F5P^F)L:6-A(&1E($-H:7!R90!#:7+M
M;&EC;R`H2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W<RTQ,C4V*0!#:7+M;&EC
M;R]58W)A;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A($-H96-A`$1$`$1I87)I
M86UE;G1E`$YA=F5G861O<B!D92#!<G9O<F4@9&4@1&%D;W,`1&%T80!$871A
M(&1E(%)E8V5PY^-O`%-E;&5CY^-O(&1E(&1A=&$`1&EA`%)E;6]V97(@0V]?
M;'5N80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E9'5Z:7(@:6YD96YT
M8>?C;P!0;W(@3VUI<W/C;P!#;W(@4&]R($]M:7-SXV\`261E;G1I9&%D92!0
M861RXV\`3&EV<F\@9&4@3F]T87,@<&]R($]M:7-SXV\`4&5R;6ES<_5E<R!0
M;W(@3VUI<W/C;P!097)M:7-S]65S('!O<B!O;6ES<^-O`$-R:73I<FEO(&1E
M(&]R9&5N8>?C;R!P861RXV\Z`%-E;G1I9&\@9&$@;W)D96YAY^-O('!A9'+C
M;SH`1&5F:6YIY_5E<P!296UO=F5R`%)E;6]V97(@1W)U<&\`4F5M;W9E<B!0
M97)M:7-SXV\`4F5M;W9E<B!E('!U<F=A<B!M96YS86=E;G,`4F5M;W9E<B!C
MZ6QU;&$`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!M;V1E;&\@86QT97)N871I
M=F\@97AI<W1E;G1E`%)E;6]V97(@<&5R;6ES<_5E<R!D92`B)7,B`%)E;6]V
M97(@<&5R;6ES<_5E<R!P87)A("<E<R<@92!Q=6%I<W%U97(@<W5B+7!E<FUI
M<W/U97,_`%)E;6]V97(@;&EN:&$`4F5M;W9E<B!I9&5N=&ED861E('-E;&5C
M8VEO;F%D80!296UO=F5R(&$@8V]L=6YA(&-O<G)E;G1E`%)E;6]V97(@82!L
M:6YH82!C;W)R96YT90!296UO=F5R(&5S=&$@;F]T80!296UO=F5R(&5S=&$@
M<&5R;6ES<^-O(&4@=&]D87,@87,@<W5A<R!S=6(M<&5R;6ES<_5E<S\`(E-C
M<FEP="(@9&4@86-T=6%L:7IAY^-O("(E<R(@<F5M;W9I9&\N`$UO;65N=&\@
M9&4@96YT<F5G80!$:6YA;6%R8V$`1&5C<F5S8V5N=&4`1&5S8W)E=F$@;R!0
M<F]B;&5M80!$97-C<FGGXV\`1&5S8W)IY^-O.@!0;W)M96YO<F5S("AT86UB
MZ6T@;F\@<F5G:7-T;RP@(FQO9R(L(&1O($AO<F1E*3H`3W,@9&5T86QH97,@
M9F]R86T@96YV:6%D;W,@<&%R82!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M
M82X`1&5S96YV;VQV:6UE;G1O`%!O;G1O(&1E($]R=F%L:&\`4&]N=&\@9&4@
M3W)V86QH;R!N82#Z;'1I;6$@:&]R83H@`%!O;G1O(&1E(&]R=F%L:&\Z(`!$
M:7)E8^?C;R!D82!E<W%U97)D82!P87)A(&$@9&ER96ET80!$:7)E8^?C;R!D
M82!D:7)E:71A('!A<F$@82!E<W%U97)D80!$:7)E8W3S<FEO`$UO<W1R87(@
M=&5M<&]S(&-O;2`R-"!H;W)A<S\`3W#G]65S(&1E(%9I<W5A;&EZ8>?C;P!-
M;W-T<F%R('!R979I<^-O('!O<FUE;F]R:7IA9&$`36]S=')A<B!P<F5V:7/C
M;R`H5$%&*0!&;W)M871O(&1E('9I<W5A;&EZ8>?C;P!.;W1I9FEC8>?C;R!D
M92!$:7-P;W-IY^-O`$1J:6)U=&D`3N-O(')E;6]V97(`3N-O('5T:6QI>F4@
M;R!M86EN=&5N86YC92YP:'`@9&ER96-T86UE;G1E`$$@<')I;65I<F$@;&EN
M:&$@8V]N=.EM(&]S(&YO;65S(&1O<R!C86UP;W,_(%-E('-I;2P@87-S:6YA
M;&%R(&5S=&$@8V%I>&$Z`$1O;6EN:6-A`%)E</IB;&EC82!$;VUI;FEC86YA
M`%)E8V5B97(`4F5C96)E<B`E<P!$97-C87)R96=A<B!A(&-O;F9I9W5R8>?C
M;R!G97)A9&$@8V]M;R!U;2`B<V-R:7!T(B!02%`N`$QI<W1A(&1E(&1E<V5N
M<F]L87(`1')O9V%S`$-O<G)E:6\@96QE8W1R\VYI8V\`15)2`%)E</IB;&EC
M82!D;R!%<75A9&]R`$5D:71A<@!%9&ET87(@0FQO8V\`161I=&%R($=R=7!O
M`$5D:71A<B!.;W1A`$5D:71A<B!097)M:7-S]65S`$5D:71A<B!097)M:7-S
M]65S`$5D:71A<B!P97)M:7-S]65S(&1E("5S`$5D:71A<B!C871E9V]R:6%S
M(&4@8V]R97,`161I=&%R(&]PY_5E<R!D93H`161I=&%R('!E<FUI<W/U97,@
M9&4@(B5S(@!%9&ET87(@<&5R;6ES<_5E<R!D92`E<P!%9'5C8>?C;P!%9VEP
M=&\`4F5P^F)L:6-A(&1E($5L(%-A;'9A9&]R`$5L96UE;G1O+BXN`$5M`$-O
M<G)E:6\@16QE8W1R\VYI8V\`16YD97)EYV\@9&4@0V]R<F5I;R!%;&5C='+S
M;FEC;P!/<R!E;F1E<F7G;W,@=.IM('%U92!C;VEN8VED:7(N`$UE;G-A9V5M
M(&-O;2!C;VYF:7)M8>?C;P!3[6UB;VQO<R!D92!%;6_GXV\`3F]T82!687II
M80!-96YS86=E;2!V87II82X`4V5M(')E<W5L=&%D;W,N`%-E;2!T97)M;W,@
M9&4@<')O8W5R80!!8W1I=F%R(&EN<V5RY^-O(&1E(&EM86=E;G,@9&4@1V%L
M97)I87,@1F]T;V=RX69I8V%S(&YO('1E>'1O/P!!8W1I=F%R(&UE;G4@9&4@
M8V]N=&5X=&\@;F\@8F]TXV\@9&ER96ET;R!D;R!R871O/P!!;F\@9&4@9FEM
M`$%U;65N=&%R($5D:71O<@!);G1R;V1U>F$@=6UA('!E<F=U;G1A(&1E('-E
M9W5R86[G82!Q=64@<V5RX2!C;VYV:61A9&\@82!R97-P;VYD97(@<V4@<')E
M8VES87(@9&4@<F5I;FEC:6%R(&$@<W5A('!A;&%V<F$M<&%S<V4L(&4N9RXL
M("=C;VUO('-E(&-H86UA(&\@<V5U(&%N:6UA;"!D92!E<W1I;6'GXV\_)SH`
M26YT<F]D=7IA(&\@55),(&1A(&EM86=E;2!A<75I`$5N=')A9&%S.B`E9"!T
M;W1A;"P@)60@86-T=6%L:7IA9&%S+"`E9"!N;W9A<RP@)60@86QT97)A9&%S
M+"`E9"!D97-C;VYH96-I9&%S`$=U:6[I($5Q=6%T;W)I86P`17-T861O(&1A
M($5R:71R96EA`$5R<F\`17)R;R!N82!M96YS86=E;2!D92!C;W)R96EO(&5L
M96-T<O-N:6-O+@!%<G)O(&%O(&5S8W)E=F5R("(E<R(N`$5R<F\Z(`!297#Z
M8FQI8V$@9&$@17-T\VYI80!297#Z8FQI8V$@1&5M;V-RX71I8V$@1F5D97)A
M;"!D82!%=&GS<&EA`,ET:6-O`$5U<F]P80!#861A(#$U(&UI;G5T;W,`0V%D
M82`R(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@;6EN=71O<P!#
M861A($5N=')A9&$`0V%D82!M96EA(&AO<F$`0V%D82!M:6YU=&\`5F%L;W)E
M<R!E>&5M<&QO.@!%>&5C=71A<@!%>&5C=71A;F1O.@!%>'!A;F1I<@!-;W-T
M<F%R($)A<G)A($QA=&5R86P`)RDG(&5S<&5R861O`$5S<&5R879A('5M82!S
M:6UP;&5S('!A;&%V<F$@;W4@=6T@=&5R;6\@9&4@<')O8W5R82!E;G1R92!A
M<W!A<P!$871A(&1E($5X<&ER8>?C;P!%>'!O96YT90!%>'!O<G1A<@!%>'!O
M<G1A<B!.;W1A<P!%>'1R86EN9&\@9&4@)7,N+BX@`$-O<B!D;R!0<FEM96ER
M;R!0;&%N;P!#87)R96=A<B!C;VYF:6=U<F'GXV\@9&4@:6YS=&%L8>?C;R!P
M;W(@1E10`%1E7WAT;R!#;VUP;&5T;P!.XV\@9F]I('!O<W/M=F5L('!U>&%R
M(&%S('!R969E<NIN8VEA<RX`1F%L:&$@;F$@;&EG8>?C;R!A;R!S97)V:61O
M<B!,1$%0+@!&86QH82!N82!L:6=AY^-O(&%O('-E<G9I9&]R(%--0BX`1F%L
M:&$@86\@8V]P:6%R(&1E("(E<R(N`$9A;&AA(&%O(&-O<&EA<B!P87)A("(E
M<R(N`$9A;&AA(&%O(&-R:6%R('5M82!N;W9A(&-O;F5XXV\@4T%33"X`1F%L
M:&$@86\@;6]V97(@<&%R82`B)7,B+@!";VT`26QH87,@1F%L:VQA;F0@*$UA
M;'9I;F%S*0!);&AA<R!&87)O90!%<G)O($9A=&%L.@!&87@`1F5V97)E:7)O
M`$%P87)E;G1A`$%P87)E;G1A.B``06QG=6YS($%G=6%C96ER;W,`06QG=6YS
M($YE=O5E<P!-871R:7H@9&4@8V%M<&]S`$9I:FD`0V]N=&%G96T@9&4@07)Q
M=6EV;W,Z("5S(&%R<75I=F\`0V]N=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R
M<75I=F]S`$=E<W3C;R!D92!&:6-H96ER;W,`3F]M92!D;R!!<G%U:79O`%-E
M;&5CY^-O(&1O(&%R<75I=F\`0V%R<F5G86UE;G1O(&1E(&%R<75I=F\`0V%R
M<F5G86UE;G1O<R!D92!F:6-H96ER;W,@;N-O('/C;R!S=7!O<G1A9&]S+@!&
M:6QT<F]S`$9I;FSB;F1I80!1=6%R=&\@0W)E<V-E;G1E`%%U87)T;R!#<F5S
M8V5N=&4`1FEX87(@<N%C:6\`26YV97)T97(`1FQU='5A;G1E`$YE=F]E:7)O
M`$$@<&%S=&$@)7,@;N-O(&5X:7-T92X`0V]R(&1O(%1E>'1O`$-O;6ED80!0
M87)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P;W)T86T@:6UA9V5N<P!0<F5V
M:7/C;R`H5$%&*0!$:6%S(&1E(%!R979I<^-O("AN;W1E+7-E('%U92!A<R!P
M<F5V:7/U97,@:6YC;'5E;2!T86YT;R!D:6%S(&-O;6\@;F]I=&5S.R!U;2!V
M86QO<B!D96UA<VEA9&\@9W)A;F1E('!O9&4@<F5S=6QT87(@;G5M(&)L;V-O
M(&UU:71O(&QA<F=O*0!%<W%U96-E=2US92!D82!P86QA=G)A+7!A<W-E/P!-
M;V1E;&]S`$1I=&]S`%1I<&\@9&4@9&ET;W,`1&ET;W,`1&ET;W,@,@!&\W)U
M;G,`4F5E;G9I;W,`07!L:6-AY_5E<R`H;?-D=6QO<RD@96YC;VYT<F%D87,Z
M("5S`%!A<W1A<R!E;F-O;G1R861A<SH`-JH`36]L9'5R87,`4F5P^F)L:6-A
M($9R86YC97-A`$9R86[G82P@365T<F]P;VQI=&%N80!'=6EA;F$@1G)A;F-E
M<V$`4&]L:6[I<VEA($9R86YC97-A`%1E<G)A<R!!=7-T<F%I<R!E($%N=.%R
M8W1I8V%S($9R86YC97-A<P!$90!$92``1&5S8W)IY^-O($-O;7!L971A`$QU
M82!#:&5I80!.;VUE($-O;7!L971O`$1I9G5S87,`4F5P^F)L:6-A($=A8F]N
M97-A`$=A;&5R:6$@9&4@;VYD92!R971I<F%R(&$@:6UA9V5M`$=A;&5R:6$Z
M`%)E</IB;&EC82!D82!'XFUB:6$`1V5R87(@0V]N9FEG=7)AY^-O("5S`$/S
M9&EG;R!'97)A9&\`1V5R86YD;R!O(&5S=&%D;R!D;R!M\V1U;&\@)7,N+BX`
M1V7S<F=I80!297#Z8FQI8V$@1F5D97)A;"!D82!!;&5M86YH80!%<G)O(&5M
M(&=E=&]P=#H`4F5P^F)L:6-A(&1O($=A;F$`1VEB<F%L=&%R`$YO;64@4'+S
M<')I;P!)<@!']F1E;`!097-Q=6ES82!';V]G;&4`3NUV96ES(&1E(&-I;GIE
M;G1O`$=RZ6-I80!'<F5G;R`H25-/+3@X-3DM-RD`1W)O;F5LXFYD:6$`1W)A
M;F%D80!!9&UI;FES=')AY^-O(&1E($=R=7!O<P!.;VUE<R!D92!G<G5P;W,@
M;N-O('!O9&5M(&5S=&%R('9A>FEO<P!097)M:7-S]65S(&1E(&=R=7!O`$=R
M=7!O<P!'=6%D86QU<&4`1W5A;0!297#Z8FQI8V$@9&$@1W5A=&5M86QA`$=U
M97)N<V5Y`%!E<FUI<W/U97,@9&%S(%9I<VET87,`4&5R;6ES<_5E<R!D87,@
M5FES:71A<P!,:79R;R!D92!6:7-I=&%S`$=U:6[I`$=U:6[I+4)I<W-A=0!2
M97#Z8FQI8V$@0V\M;W!E<F%T:79A(&1A($=U:6%N80!(5$U,`$\@2%1-3$%R
M96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@82#Z;'1I;6$@
M8^EL=6QA(&1A(&QI;FAA+@!/($A434Q!<F5A(')E8W5S82US92!C;V)A<F1E
M;65N=&4@82!R96UO=F5R(&$@^FQT:6UA(&-O;'5N82!D82!T86)E;&$N`$\@
M2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@82#Z
M;'1I;6$@;&EN:&$@9&$@=&%B96QA+@!!=71E;G1I8V'GXV\@2%104"!NXV\@
M9F]I(&5N8V]N=')A9&$N`%)E</IB;&EC82!D;R!(86ET:0!!;&=O<FET;6\@
M9&4@(DAA<V@B`$YE8FQI;F$`0V%B9>=A;&AO`$EL:&%S($AE87)D(&4@36-$
M;VYA;&0`5&5M<&]R86PM5"!&;W)T90!(96)R974@*$E33RTX.#4Y+3@M22D`
M06QT=7)A`$%J=61A`$%J=61A('-O8G)E(&\@961I=&]R`$%J=61A`$%P;&EC
M8>?C;R!A=7AI;&EA<B!P87)A(&-R:6%R(&4@;6%N=&5R('1R861UY_5E<R!D
M82!P;&%T869O<FUA"DAO<F1E(&4@9&%S('-U87,@87!L:6-AY_5E<R`H;?-D
M=6QO<RDN"E!A<F$@=6UA(&EN=')O9'7GXV\@;&5R(&\@9FEC:&5I<F\@4D5!
M1$U%(&YE<W1A('!A<W1A+@!(96UI<V;I<FEO`$%Q=6D@97-TX2!O(&EN[6-I
M;R!D;R!A<G%U:79O.@!!;'1A`$YO;65S(&1A<R!E;G1R861A<R!H:7-T\W)I
M87,@;N-O('!O9&5M(&5S=&%R('9A>FEO<P!#85]S80!%<W1A9&\@9&$@0VED
M861E(&1O(%9A=&EC86YO`$-A<V$`16YD97)EYV\@9&4@0V%S80!496QE9F]N
M92!D92!#87-A`%)E</IB;&EC82!D87,@2&]N9'5R87,`2&]N9W5E8V]N9W5E
M`$AO<F1E`$=E<F%D;W(@9&4@=')A9'7G]65S($AO<F1E`$AO<F1E+TMO;&%B
M.B!$861O<R!834P@)7,@:6YVX6QI9&]S(&YA(&UE;G-A9V5M("5S`$AO<F1E
M+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E<W!O;F1E(&%O(&]B:F5C
M=&\@)7,`2&]R9&4O2V]L86(Z($YE;FAU;2!O8FIE8W1O(&1O('1I<&\@)7,@
M96YC;VYT<F%D;R!N82!M96YS86=E;2`E<P!(;W)D92]+;VQA8CH@4F5M;^?C
M;R!D92`E<R`B)7,B('1E=F4@<W5C97-S;P!(;W)D92]+;VQA8CH@4VEN8W)O
M;FEZ8>?C;R!D92`E<R`B)7,B('1E=F4@<W5C97-S;P!(;W)D92]+;VQA8CH@
M3R!M;W1O<B!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N<^-O(%!(4"`G
M9&]M>&UL)P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!U
M;6$@;F]V82#A<G9O<F5S(%A-3"!P87)A(&\@;V)J96-T;R`E<P!(;W)D92]+
M;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@240@34E-12!P
M87)A(&$@<&%R=&4@9&4@=&EP;R`E<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P
M;W-S[79E;"!S:6YC<F]N:7IA<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B!P87)T:6QH87,Z("5S`$AO
M<F1E+TMO;&%B.B!087)T:6QH82`B)7,B(&1E<V-O;FAE8VED80!4<F'G;R!(
M;W)I>F]N=&%L`$5N8VAI;65N=&\@:&]R:7IO;G1A;`!(;W)I>F]N=&%L.@!#
M;VUO(&-H96=O=2!A<75I/R`H4&]R(&9A=F]R(')E<&]R=&4M;R$I`%%U86YT
M87,@8V]L=6YA<R!P<F5T96YD92!J=6YT87(_`%%U86YT;W,@8V%M<&]S("AC
M;VQU;F%S*2!E>&ES=&5M/P!1=6%N=&%S(&QI;FAA<R!P<F5T96YD92!J=6YT
M87(_`$AU;6ED861E`$AU;6ED861E.B``2'5M;W)I<W1A<P!297#Z8FQI8V$@
M9&$@2'5N9W)I80!!(&-R:6'GXV\@9&$@8V%I>&$@<&]S=&%L($E-05`@9F%L
M:&]U.B`E<P!296UOY^-O(&1A(&-A:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@
M)7,`0W)I8>?C;R!D92!Q=6]T82!D92!C86EX82!P;W-T86P@24U!4"!F86QH
M;W4Z("5S`$5N9&5R9>=O($E0`$5N9&5R9>=O($E0(&EN9&ES<&]N[79E;"X`
M16YD97)EYV\@25`@9F]R82!D;R!B;&]C;R!#2412('!E<FUI=&ED;RX`5FEO
M;&'GXV\@9&4@8FQO<75E:6\@9&4@25``25]N<V5R:7(@3&EN:&$@06YT97,`
M4F5P^F)L:6-A(&1A($ES;.)N9&D`07!E;F%S(,UC;VYE<P#-8V]N97,@8V]M
M(%1E>'1O`$YO;64@9&$@:61E;G1I9&%D93H`4V4@;N-O(&9O<B!M;W-T<F%D
M;R!C;W)R96-T86UE;G1E+"`E<R!P87)A(&\@86)R:7(@;G5M82!N;W9A(&IA
M;F5L82X`4V4@;N-O('9I<B!Q=6%L<75E<B#M8V]N92!A;R!U<V%R(&\@26YT
M97)N970@17AP;&]R97(L('!O9&4@<')E8VES87(@9&4@<V5L96-C:6]N87(@
M97-T82!C86EX82!P87)A(&1E<VQI9V%R(&$@=')A;G-P87+J;F-I82X`4V4@
M=FER(&5S=&$@;65N<V%G96T@;FUA<R!NXV\@82!I;6%G96T@<')O<')I86UE
M;G1E(&1I=&$L(&$@:6UA9V5M('%U92!P<F5T96YD92!C87)R96=A<B!NXV\@
M<&]D92!S97(@;6]S=')A9&$@<&5L;R!S974@;F%V96=A9&]R+@!0<F5V:7/C
M;R!D82!);6%G96TZ`%523"!D82!I;6%G96T`55),(&1A(&EM86=E;3H`26UA
M9V5M(&1E(&=A;&5R:6$`26UA9V5M(&1E(&=A;&5R:6$Z`$-A<G)E9V%M96YT
M;R!D82!I;6%G96T`26UA9V5N<P!);7!O<G1A<B!.;W1A<RP@4&%S<V\@)60`
M26UP;W)T87(L(%!A<W-O("5D`$EM<&]R=&%R+T5X<&]R=&%R($YO=&%S`$-A
M;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R=&%D;W,Z`$EN7W-E<FER
M($QI;FAA($1E<&]I<P!#\V1I9V\@9&4@86/GXV\@:6YT<F]D=7II9&\@97-T
MX2!I;F-O<G)E8W1O+@!.;VUE(&1E('5T:6QI>F%D;W(@;W4@<&%L879R82UP
M87-S92!E<G)A9&]S+@!.;VUE(&1E('5T:6QI>F%D;W(@;W4@96YD97)EYV\@
M86QT97)N871I=F\@97)R861O<RX@0V]N=&%C=&4@;R!S974@861M:6YI<W1R
M861O<B!D92!S:7-T96UA('!A<F$@;V)T97(@86IU9&$N`$%U;65N=&%R(&$@
M26YD96YT8>?C;P!297#Z8FQI8V$@9&$@S6YD:6$`571I;&EZ861O<F5S($EN
M9&EV:61U86ES`%)E</IB;&EC82!D82!);F1O;NES:6$`26YF;W)M8>?C;P!)
M;F9O<FUAY^-O`$EN9F]R;6'GXV\@:N$@;N-O(&5S=.$@9&ES<&]N[79E;`!)
M;FEC:6%L:7IA;F1O(&\@;?-D=6QO("5S+BXN(`!);G-E<FER($-?;VQU;F$@
M1&5P;VES`$EN<V5R:7(@26UA9V5M`$EN<V5R:7(@5&%B96QA`$EN<V5R:7(@
M3&EG8>?C;R#@(%=E8@!);G-E<FER(%]#;VQU;F$@06YT97,`26YS:7)I<B!U
M;6$@;F]V82!C;VQU;F$@9&5P;VES(&1A(&-O<G)E;G1E`$EN<VER:7(@=6UA
M(&YO=F$@8V]L=6YA(&%N=&5S(&1A(&-O<G)E;G1E`$EN<VER:7(@=6UA(&YO
M=F$@;&EN:&$@9&5P;VES(&1A(&-O<G)E;G1E`$EN<VER:7(@=6UA(&YO=F$@
M;&EN:&$@86YT97,@9&$@8V]R<F5N=&4`26YS97)I<B!U;2!P87+A9W)A9F\@
M87#S<R!O(&[S(&-O<G)E;G1E`$EN<V5R:7(@=6T@<&%RX6=R869O(&%N=&5S
M(&1O(&[S(&-O<G)E;G1E`$EN<VER:7(@;6]D96QO(&%L=&5R;F%T:79O`$EN
M=')O9'5Z82!U;2!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(&]N
M9&4@<&]S<V$@<F5C96)E<B!A(&YO=F$@<&%L879R82UP87-S93H`26YS:7)I
M<B!CZ6QU;&$@87#S<P!);G-E<FER(&/I;'5L87,@86YT97,`26YS97)I<B!C
MZ6QU;&$@9&5P;VES`$EN<V5R:7(@8V]L=6YA(&%N=&5S`$EN<V5R:7(@;65N
M<V%G96YS`$EN<V5R:7(@<&%RX6=R869O(&%N=&5S`$EN<V5R:7(@<&%RX6=R
M869O(&%N=&5S`$EN<V5R:7(@;&EN:&$@9&5P;VES`$EN<V5R:7(@;&EN:&$@
M86YT97,`26YT<F]D=7IA(&$@<F5S<&]S=&$@97AI9VED82!P87)A(&$@<&5R
M9W5N=&$@9&4@<V5G=7)A;N=A.@!);G-E<FER+TUO9&EF:6-A<B!);6%G96T`
M26YS97)I<B]-;V1I9FEC87(@3&EG8>?C;P!#<NED:71O(&EN<W5F:6-I96YT
M92!P87)A(&5N=FEA<B!P87)A(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+@!#
M<NED:71O(&EN<W5F:6-I96YT92X`26YT96ER;P!,:7-T82!D92!I;G1E:7)O
M<P!51$@@*%5S97(@1&%T82!(96%D97(I(&EN=N%L:61O+@!$861O<R!:25`@
M:6YVX6QI9&]S`$%P;&EC8>?C;R!I;G;A;&ED82X`240@9&4@;&]T92`H(F)A
M=&-H(BD@:6YVX6QI9&\N`$]S(&1A9&]S('-U8FUE=&ED;W,@<^-O(&EN=N%L
M:61O<RX`16YD97)EYV\@9&4@9&5S=&EN;R!I;G;A;&ED;RX`1F]R;6%T;R!D
M;R!A<G%U:79O(&EN=N%L:61O`$-H879E(&1A(&QI8V5NYV$@:6YVX6QI9&$N
M`$QO8V%L:7IAY^-O(&EN=N%L:61A(&5S<&5C:69I8V%D82X`;7-G7W1Y<&4@
M:6YVX6QI9&\N`&%P:5]I9"!I;G;A;&ED;R!O=2!E;2!F86QT82X`4&%RXFUE
M=')O<R!I;G;A;&ED;W,@;W4@96T@9F%L=&$N`%!E<FUI<W/C;R!P87)E;G1A
M;"!I;G;A;&ED82X`240@9&4@<&%R8V5I<F\@:6YVX6QI9&\N`$/S9&EG;R!D
M92!P<F]D=71O(&EN=N%L:61O+@!0<F]T;V-O;&\@:6YVX6QI9&\N`$1E<W1I
M;F%TX7)I;R!I;G;A;&ED;SH@(B5S(@!/8FIE8W1O(&1E('!A<G1I;&AA(&EN
M=N%L:61O`$5N9&5R9>=O(&1A(&]R:6=E;2!I;G;A;&ED;RX`1&%D;W,@=6YI
M8V]D92!I;G;A;&ED;W,N`$EN=F5N=.%R:6\`4F5P^F)L:6-A($ES;.)M:6-A
M(&1O($ERXV\`4F5P^F)L:6-A(&1O($ER87%U90!297#Z8FQI8V$@9&$@27)L
M86YD80!);&AA(&1E($UA;@!496UP;W)A:7,M5"!)<V]L861O<P!%<W1A9&\@
M9&4@27-R865L`$5M:7-S;W(`273A;&EC;P!297#Z8FQI8V$@271A;&EA;F$`
M2F%M86EC80!*86YE:7)O`$IA<.-O`$IA<&]NZG,@*$E33RTR,#(R+4I0*0!*
M97)S97D`4F5I;F\@2&%S:&5M:71A(&1A($IO<F3B;FEA`$IU;&AO`$IU;FAO
M`$IU<W1I9FEC87(`0V5N=')A<@!*=7-T:69I8V%R`$IU<W1I9FEC87(@X"!%
M<W%U97)D80!*=7-T:69I8V%R(.`@1&ER96ET80!297#Z8FQI8V$@9&\@0V%Z
M87%U:7-TXV\`4')E<V5R=F%R(&\@;W)I9VEN86P_`%)E</IB;&EC82!D;R!1
M=>EN:6$`3R!S97)V:61O<B!+97)B97)O<R!R96IE:71O=2!A(&%U=&5N=&EC
M8>?C;RX`3F]V871O<R!N;R`B2V5R;F5L(@!#<FEAY^-O(&1A($-H879E`$EM
M<')E<W/C;R!D:6=I=&%L(&1A(&-H879E`$-O;7!R:6UE;G1O(&1A(&-H879E
M`%1I<&\@9&$@0VAA=F4`571I;&EZ8>?C;R!D82!#:&%V90!!(&-H879E(&KA
M(&5X:7-T92!N;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N`$UI^F1O
M<P!1=6ER:6)A=&D`4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@9&$@
M0V]R96EA`%)E</IB;&EC82!D82!#;W)E:6$`0V]R96%N;R`H155#+4M2*0!+
M=7=A:70`4F5P^F)L:6-A(%%U:7)G=6EZ90!?1&ES<&]S:>?C;P!)9&EO;6$`
M4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@3&%O`%%U87)T;R!$96-R
M97-C96YT90#:;'1I;6$@36]D:69I8V'GXV\`475A<G1O($1E8W)E<V-E;G1E
M`-IL=&EM82!!8W1U86QI>F'GXV\Z`-IL=&EM82!E;G1R861A.B`E<P#:;'1I
M;6$@96YT<F%D83H@)7,@9&4@)7,`VFQT:6UA(&5N=')A9&$Z($YU;F-A`%)E
M</IB;&EC82!D82!,973S;FEA`$QE:0!$:7-P;W-IY^-O`$1E:7AA<B!V87II
M;R!P87)A(&9I8V%R('-E;2!B;W)D80!,[6)A;F\`17-Q=65R9&$`0V%B9>=A
M;&AO(&1A(&5S<75E<F1A`%9A;&]R97,@X"!E<W%U97)D80!,97-O=&\`3&EB
MZ7)I80!'<F%N9&4@2F%M86AI<FEY82!3;V-I86QI<W1A(%!O<'5L87(@P7)A
M8F4@9&$@3.UB:6$`3&ES=&5N<W1A:6YE`$-H=79A(")-;VQH82U4;VQO<R(`
M0VAU=FES8V]S`$-H=79I<V-O<R!-871I;F%I<P!#:'5V:7-C;W,@5F5S<&5R
M=&EN;W,`4&5Q=65N;R!!9W5A8V5I<F\`0VAU=FES8V\@8V]M(%1R;W9O861A
M`%%U961A(&1E($YE=F4`3F5V90`B3&EM97)I8VLB`$QI9V'GXV\`3&EG8>?C
M;R!A<&]N=&$@<&%R83H`3&EG87(@;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L
M96-T<O-N:6-O(.`@<.%G:6YA(&1E(&-O;7!O<VGGXV\@86\@;6]S=')A<@!,
M:6=AY_5E<P!";VQI;FAO(&QI;G5XZG,`3&ES=&$@+2!O('5T:6QI>F%D;W(@
M<&]D92!V97(@82!P87-T80!,:7-T87(@0F%S97,@9&4@1&%D;W,`36]S=')A
M<B!4\W!I8V]S(&1E($%J=61A`$QI<W1A<B!486)E;&%S`$QI<W1A9V5M+4%R
M<75I=F\`3&ES=&%G96TM06IU9&$`240@9&$@3&ES=&$`3&ES=&%G96TM1&]N
M;P!,:7-T86=E;2U3=6)M:7-S]65S`$QI<W1A9V5M+5-U8G-C<FET87,`3&ES
M=&%G96TM3N-O('-U8G-C<FET87,`02!L:7-T86=E;2!D92!U=&EL:7IA9&]R
M97,@97-TX2!D97-A8W1I=F%D82X`3&ET97)A='5R83H`4F5P^F)L:6-A(&1A
M($QI='7B;FEA`$-A<G)E9V%N9&\@8FEB;&EO=&5C87,N+BX`0V%R<F5G86YD
M;RXN+@!496UP;R!L;V-A;#H`3&]C86QI>F'GXV\@92!&=7-O($AO<N%R:6\`
M3&]C86QI>F'GXV\`16YT<F%R`%-A:7(`5&%R969A<R!D92!%;G1R861A`$$@
M875T96YT:6-AY^-O(&9A;&AO=2!P;W(@;R!.;VUE(&1E(%5T:6QI>F%D;W(@
M;W4@82!086QA=G)A+5!A<W-E(&5S=&%R96T@:6YC;W)R96-T;W,N`$$@875T
M96YT:6-AY^-O(&9A;&AO=2X`5&5X=&\@;&]N9V\`06UO<@!"86EX;P!,971R
M87,@9W)E9V%S(&UI;OIS8W5L87,`3&5T<F%S(&QA=&EN87,@;6EN^G-C=6QA
M<P!.^FUE<F]S(')O;6%N;W,@;6EN^G-C=6QO<P!,=7AE;6)U<F=O`$U-`$U/
M5$0`3R!A;F5X;R!-4RU43D5&(&[C;R!C;VYT:6YH82!D861O<RX`35-'`$UA
M8V%U`$UA8V5D\VYI82P@06YT:6=A(%)E</IB;&EC82!*=6=O<VQA=F$@9&$`
M36%D86?A<V-A<@!-86=I80!#;W)R96EO`$%D;6EN:7-T<F'GXV\@9&4@0V]R
M<F5I;P!&87IE<B!L:5]G8>?C;RXN+@!!<W-E9W5R92US92!D92!Q=64@=&5M
M(&\@4$5!4B!I;G-T86QA9&\@92!N;R!C86UI;FAO(&1E(&EN8VQU<_5E<R`H
M:6YC;'5D92!P871H*2X`0W)I86YD;R!A('!A<W1A("5S`$UA;&%U:0!-86SA
M<VEA`$UA;&1I=F%S`$UA;&D`36%L=&$`1VER82!A(&QI<W1A(&1E(&-A=&5G
M;W)I87,@<75E('!O9&4@871R:6)U:7(@86]S(&ET96YS+"!B96T@8V]M;R!A
M<R!C;W)E<R!Q=64@;&AE<R!E<W3C;R!A<W-O8VEA9&%S+@!-87!A($UA<#(T
M`$UA<&$@36%P475E<W0`36%RYV\`36%R9V5M`$UA<F-A<B!C;VUO($QI9&$O
M3N-O(&QI9&$`36%R8V%R(&1E(&]U=')A<R!F;W)M87,@*&4N9RXL($EM<&]R
M=&%N=&4O4&]R(')E<W!O;F1E<BD`26QH87,@36%R<VAA;&P`36%R=&EN:6-A
M`$-A;7!O<R!Q=64@8V]R<F5S<&]N9&5M`$UA=7)I=.)N:6$`36%U<NUC:6\`
M3>%X:6UO(&-RZ61I=&\@<&5R;6ET:61O+@!-X7AI;6\@;OIM97)O(&1E('!A
M<G1E<R!N=6UA(&UE;G-A9V5M(&5X8V5D:61O+@!496UP97)A='5R82!MX7AI
M;6$@;F%S(/IL=&EM87,@,C0@:&]R87,Z(`!496UP97)A='5R82!MX7AI;6$@
M;F%S(/IL=&EM87,@-B!H;W)A<SH@`$-O;7!R:6UE;G1O(&WA>&EM;P!-86EO
M`$UA>6]T=&4`365D:6-I;F$`365M8G)O<P!497AT;R!D;R!-96UO`$UO9&\@
M9&\@;65N=3H`56YI<B!CZ6QU;&%S`$EN=&5G<F%N9&\@=&]D;W,@;W,@9FEC
M:&5I<F]S("5S+G!O(&-O;2!O(&-O;7#J;F1I;RXN+@!);G1E9W)A;F1O(&$@
M;&]C86QI>F'GXV\@)7,N+BX@`$EN=&5G<F%N9&\@;R!A<G%U:79O(%!/(&1E
M("5S(&-O;2!O(&-O;7#J;F1I;RXN+B``26YT96=R86YD;R!A('1R861UY^-O
M(&1O(&WS9'5L;R`E<RXN+@!-96YS86=E;0!-96YS86=E;B!697)I9FEC861A
M(&-O;2!3=6-E<W-O+"!M87,@;R!C97)T:69I8V%D;R!D;R!S=6)S8W)I=&]R
M(&[C;R!P]&1E('-E<B!V97)I9FEC861O+@!-96YS86=E;2!E>'!I<F]U+@!4
M:7!O(&1E(&UE;G-A9V5M`$UE=&5O<F]L;V=I82!-151!4@!";&]C;R!-151!
M4B!I;F1I<W!O;NUV96PN`$)L;V-O($U%5$%2(&EN9&ES<&]N[79E;"X@3W,@
M<&]R;65N;W)E<R!F;W)A;2!R96=I<W1A9&]S('!A<F$@;R!A9&UI;FES=')A
M9&]R+@!!($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861A+@!-Z71O9&\`3R!M
MZ71O9&\@(B5S(B!NXV\@97-TX2!D969I;FED;P!-Z71R:6-O`$WI>&EC;P!-
M:6-R;V[I<VEA+"!%<W1A9&]S($9E9&5R861O<R!D80!#96YT<F\`5&EP;R!-
M24U%`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A<P!4
M96UP97)A='5R82!M[6YI;6$@;F%S(/IL=&EM87,@-B!H;W)A<P!%<W!E;&AO
M`$UI<V-E;.)N96$`4&%C;W1E($A45%!?4F5Q=65S="!D;R!014%2(&5M(&9A
M;'1A+@!#;VYF:6=U<F'GXV\@96T@9F%L=&$N(%1E<N$@9&4@82!G97)A<B!A
M9V]R82!S92!Q=6ES97(@=7-A<B!E<W1A(&%P;&EC8>?C;RX`240@9&$@;65N
M<V%G96T@96T@9F%L=&$N`%!A8V]T92!-86EL(&1O(%!%05(@96T@9F%L=&$N
M`$E$(&1A('-E<W/C;R!E;2!F86QT82X`,JH`0V]R<F5I;R!-\W9E;`!-;V1E
M<F%D;P!$871A(&1E($UO9&EF:6-AY^-O`$UO9&EF:6-A<B!54DP`02!M;V1I
M9FEC87(@)7,`3?-D=6QO`$WS9'5L;P!297#Z8FQI8V$@9&$@36]L9&]V80!0
M<FEN8VEP861O(&1O($WS;F%C;P!-;VYG\VQI80!-ZG,@92!A;F\`365N<V%L
M;65N=&4`36]N='-E<G)A=`!&87-E(&1A($QU80!296EN;R!D92!-87)R;V-O
M<P!3;V)R971U9&\@3&EM<&\`4V]B<F5T=61O($5N979O861O`%-O8G)E='5D
M;R!3;VQA<F5N9V\`1&5S8V5R`$UO=F5R('!A<F$@82!%<W%U97)D80!-;W9E
M<B!P87)A(&$@1&ER96ET80!3=6)I<@!$97-C97(`4W5B:7(`4F5P^F)L:6-A
M(&1E($UOYV%M8FEQ=64`3&ES=&%S(&1E(&1E<V5N<F]L87(@;75L=&DM;NUV
M96P`4V5L96/GXV\@;?IL=&EP;&$`02!-:6YH82!#;VYT80!!<R!-:6YH87,@
M3F]T87,`3R!-974@4&]R=&%L`$1I<W!O<VGGXV\@9&\@4&]R=&%L`%5N:>-O
M(&1E($UY86YM87(`3N-O+"!NXV\@8V]N8V]R9&\`3F]M90!297#Z8FQI8V$@
M9&$@3F%M[6)I80!.875R=0!.97!A;`!296EN;R!D;W,@4&'M<V5S($)A:7AO
M<P!!;G1I;&AA<R!(;VQA;F1E<V%S`%523"!D92!"87-E($YE='-C87!E`%52
M3"!D92!2979O9V'GXV\@0T$@3F5T<V-A<&4`55),(&-O;2!A('!O;.UT:6-A
M(&1E($-!($YE='-C87!E`%523"!D92!296YO=F'GXV\@3F5T<V-A<&4`55),
M(&1E(%)E=F]G8>?C;R!.971S8V%P90!.;VUE(&1O('-E<G9I9&]R(%-33"!.
M971S8V%P90!#;VUE;G3A<FEO(&1E(&-E<G1I9FEC861O($YE='-C87!E`%1I
M<&\@9&4@8V5R=&EF:6-A9&\@3F5T<V-A<&4`4F5D90!.=6YC80!.;W9A($-A
M;&5D\VYI80!.;W9A($-A=&5G;W)I80!,=6$@3F]V80!.;W9A($YO=&$`3F]V
M;R!.;VUE(&1E(%5T:6QI>F%D;W(@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA
M`$YO=F$@:F%N96QA("A?8FQA;FLI`$YO=.UC:6%S`$=R=7!O<R!D92!.;W3M
M8VEA<P!0<O-X:6UA`%!R\WAI;6%S(#0@1F%S97,`4'+S>&EM87,@;W#G]65S
M`%!R\WAI;6$^`%)E</IB;&EC82!D82!.:6-A<N%G=6$`4F5P^F)L:6-A(&1O
M($[M9V5R`%)E</IB;&EC82!&961E<F%L(&1A($YI9V5R:6$`3F]I=&4`3FEU
M90!.XV\`3N-O(&CA(&1A9&]S(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I
M<R!E;2!R96QAY^-O(&%O<R!Q=6%I<R!M;W-T<F%R(&1I9F5R96[G87,N`$[C
M;R!HX2!N96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(')E86QI
M>F%R(&EM86=E;G,@25-/+@!.XV\@:.$@;6]D96QO(&1E(&QO=&4@(F)A=&-H
M(BX`3N-O(&5X:7-T92!B;&]C;R!N82!P;W-IY^-O(&EN9&EC861A`$[C;R!F
M;VD@9F]R;F5C:61O('5M(&YO;64@9&4@8V%L96YDX7)I;R!P87)A(&$@875T
M96YT:6-AY^-O($U#04PN`%-E;2!M;V1I9FEC8>?U97,N`$[C;R!S92!P;V1E
M(&%D:6-I;VYA<B!P97)M:7-S]65S(&1E(&9I;&AO<R!A8F%I>&\@9&5S=&4@
M;NUV96PN`$[C;R!S92!P;V1E(&%D:6-I;VYA<B!F:6QH;W,@82!E<W1A('!E
M<FUI<W/C;RX`3F5N:'5M(&-O;6%N9&\@97-P96-I9FEC861O+@!.XV\@9F]I
M(&5S<&5C:69I8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O('!A
M<F$@)7,N`$[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C
M;VYF:6=U<F'GXV\@<&%R82!61E,@8F%S96%D;R!E;2!&5%`N`$[C;R!F;VD@
M97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@;F5C
M97-SX7)I82!P87)A(&\@5D93(&)A<V5A9&\@96T@4U%,+@!.XV\@9F]I(&5S
M<&5C:69I8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&YE8V5S
M<^%R:6$@<&%R82!O(%9&4R!B87-E861O(&5M(%-13"U&:6QE+@!#<NED:71O
M(&5S9V]T;W4N`$YE;FAU;2!D97-T:6YA=.%R:6\@9F]I(&9O<FYE8VED;RX`
M3N-O(&5X:7-T92!Q=6%L<75E<B!E;G1R861A(&-O;2!O(&ED("(E<R(@;F\@
M87)Q=6EV;R!D92!A:G5D82!O<FEG:6YA;"X`3N-O('-E(&-A<G)E9V]U(&YA
M9&$N`$1A9&]S(&E#86QE;F1A<B!NXV\@9F]R86T@96YC;VYT<F%D;W,N`$YE
M;FAU;6$@;&]C86QI>F'GXV\@97-P96-I9FEC861A+@!&86QT82!I;F1I8V%R
M('5M82!L;V-A;&EZ8>?C;RX`02!L;V-A;&EZ8>?C;R!NXV\@9F]I(&5S<&5C
M:69I8V%D82X`3F5N:'5M82!M96YS86=E;2!F;VD@9F]R;F5C:61A+@!.96YH
M=6T@;F]M92!E<W!E8VEF:6-A9&\N`$[C;R!HX2!L:79R;W,@9&4@;F]T87,@
M9&ES<&]N[79E:7,@<&%R82!V:7-I=&%S+@!396T@;F]T87,`3F5N:'5M82!N
M;W1A(&1E(&%C;W)D;R!C;VT@;R!C<FETZ7)I;R!C;W)R96YT92X`4V5M(&YO
M=&%S('!A<F$@;6]S=')A<@!.96YH=6T@;OIM97)O(&5S<&5C:69I8V%D;RX`
M4V5M(&1I=&]S(&]F96YS:79O<P!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A
M+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@2%144"X`3N-O(&9O:2!F;W)N
M96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($E-05`N
M`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N
M=&EC8>?C;R!+97)B97)O<RX`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP
M87-S92!P87)A(&$@875T96YT:6-AY^-O($Q$05`N`$[C;R!F;VD@9F]R;F5C
M:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!,;V=I;BX`
M3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT
M:6-AY^-O(%!!4U-71"X`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S
M92!P87)A(&$@875T96YT:6-AY^-O(%--0BX`3N-O(&9O:2!I;F1I8V%D;R!C
M86UI;FAO('!A<F$@;R!B:6[A<FEO($]P96Y34TPN($\@8FENX7)I;R!/<&5N
M4U-,(.D@;F5C97-SX7)I;R!P87)A('1R86)A;&AA<B!C;VT@9&%D;W,@4$M#
M4R`Q,BX`3N-O(&CA('-U8G-C<FGG]65S('!E;F1E;G1E<RX`4V5M('1R8>=O
M<P!396T@;&%D;W,`3N-O(&CA('!A<W1A('1E;7!O<N%R:6$@9&ES<&]N[79E
M;"!P87)A(")C86-H92(N`$[C;R!F;W)A;2!E;G9I861O<R!O(&YO;64@9&\@
M=71I;&EZ861O<B!O=2!A('!A;&%V<F$M<&%S<V4N`$[C;R!F;W)A;2!R971O
M<FYA9&]S(&1A9&]S(&5M(%A-3"!VX6QI9&]S`%-E;2!V86QO<F5S`$[C;R!F
M;VD@96YC;VYT<F%D82!V97)SXV\@;F$@8V]N9FEG=7)AY^-O(&]R:6=I;F%L
M+B!296=E;F5R87(@8V]N9FEG=7)AY^-O+@!.XV\@9F]I(&5N8V]N=')A9&$@
M=F5R<^-O(&YA('-U82!C;VYF:6=U<F'GXV\N(%)E9V5N97)A<B!C;VYF:6=U
M<F'GXV\N`$YO7W1A`$YE;FAU;6$`3F5N:'5M("AU<V%R(&EM<&SM8VET;RD`
M3O-R9&EC;R`H25-/+3@X-3DM,3`I`$EL:&$@9&4@3F]R9F]L:P!(96UI<V;I
M<FEO($YO<G1E`$EL:&%S($UA<FEA;F%S(&1O($YO<G1E`%)E:6YO(&1A($YO
M<G5E9V$`3G5N8V$@1&5P;VES(&1E`$YU;F-A($%N=&5S(&1E`$[C;R#I('5M
M(&1I<F5C=/-R:6\`3N-O(&EM<&QE;65N=&%D82X`4&]R(&%T<FEB=6ER`$[C
M;R!S=7!O<G1A9&\N`$-A=&5G;W)I82!D82!.;W1A`$1E=&%L:&5S(&1A($YO
M=&$`3&ES=&%S(&1E($YO=&%S`%1E>'1O(&1A($YO=&$`7U1E>'1O(&1A($YO
M=&$`3F]T82!NXV\@96YC;VYT<F%D82X`3&E?=G)O(&1E($YO=&%S`$YO;64@
M9&\@3&EV<F\@9&4@3F]T87,Z`$QI=G)O<R!D92!.;W1A<P!,:79R;W,@9&4@
M;F]T87,@=.IM(&1E('1E<B!U;2!N;VUE+@!.;W1A<P!3=6WA<FEO(&1A<R!.
M;W1A<P!.861A('!A<F$@;F%V96=A<BP@=F]L=&4@<&%R82!T<N%S+@!.;W1A
M`$YO=F5M8G)O`$[Z;65R;P!.^FUE<F\@9&4@8V%R86-T97)E<P!.^FUE<F\@
M9&4@8V]L=6YA<P!.^FUE<F\@9&4@;&EN:&%S`$YA(&QI<W1A(&1E(&1I<W1R
M:6)U:>?C;R!HX2!N^FUE<F]S('%U92!NXV\@9F]R86T@97-P96-I9FEC861O
M<R!P87)A(&%C='5A;&EZ8>?C;RX`3TL`3V)J96-T;P!#<FEA9&]R(&1O($]B
M:F5C=&\`4&5R;6ES<_5E<R!D;R!C<FEA9&]R(&1O(&]B:F5C=&\`3V-T86P`
M3W5T=6)R;P!&:6QT<F\@9&4@;6%T97)I86P@;V9E;G-I=F\`1V%B:6YE=&4`
M4W5L=&%N871O(&1O($]MXP!3\R!O<R!S97)V:61O<F5S($E-05`@<W5P;W)T
M86T@<&%S=&%S('!A<G1I;&AA9&%S+@!!<&5N87,@9&ET;W,@;V9E;G-I=F]S
M`%/S(.D@<&5R;6ET:61O('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R
M\VYI8V\N`$%P96YA<R!O(&1O;F\@;W4@=6T@861M:6YI<W1R861O<B!D92!S
M:7-T96UA<R!P;V1E(&%L=&5R87(@82!T:71U;&%R:61A9&4@9&4@=6UA('!A
M<G1I;&AA(&]U(&%S('!E<FUI<W/U97,@9&\@<V5U(&1O;F\`06)R92!N=6UA
M(&YO=F$@:F%N96QA`$5R<F\@3W!E;E-33#H@3N-O(&9O:2!P;W-S[79E;"!E
M>'1R86ER(&1A9&]S(&1E('5M82!P87)T92!A<W-I;F%D82!C;VT@4R]-24U%
M+@!!8G)E(&5S=&$@;&EG8>?C;R!N=6UA(&YO=F$@:F%N96QA`%-I<W1E;6$@
M3W!E<F%T:79O`$]PY_5E<P!/<.?U97,@9&\@)7,`3W#G]65S.@!,:7-T82!/
M<F1E;F%D80!/<F=A;FEZ8>?C;P!5;FED861E($]R9V%N:7IA8VEO;F%L`$]R
M9V%N:7IAY^-O`$UO9&5L;R!O<FEG:6YA;"!D82!A<&QI8V'GXV\`36]D96QO
M<R!O<FEG:6YA:7,@96T@)7,Z`$]U=')O`$]U=')A<R!);F9O<FUAY_5E<P!/
M=71R87,@3W#G]65S`%!E<FUI<W/U97,@9&\@1&]N;P!!=71E;G1I8V'GXV\@
M4$%-(&[C;R!E<W3A(&1I<W!O;NUV96PN`$%S<VEN871U<F$@1&EG:71A;"!0
M1U``1&%D;W,@96YC<FEP=&%D;W,@4$=0`$-H879E(%#Z8FQI8V$@4$=0`$1A
M9&]S($%S<VEN861O<R]%;F-R:7!T861O<R!C;VT@4$=0`$/S9&EG;R!02%``
M0V]M86YD;W,@4$A0`$-H=79I<V-O<R!P96QA(%1A<F1E`$%G=6%C96ER;W,@
M9&4@5&%R9&4`3F5V92#@(%1A<F1E`$YE=O5E<R#@(%1A<F1E`%-O;"#@(%1A
M<F1E`%1E;7!O<F%I<RU4(.`@5&%R9&4`0V]M86YD;W,@4%](4`!%;F-H:6UE
M;G1O`%)E</IB;&EC82!)<VSB;6EC82!D;R!087%U:7-TXV\`4F5P^F)L:6-A
M(&1E(%!A;&%U`%1E<G)I=/-R:6\@4&%L97-T:6YI86YO`%!A;F%MX0!087!U
M82!.;W9A($=U:6[I`%)E</IB;&EC82!D;R!087)A9W5A:0!087)C:6%L;65N
M=&4@16YC;V)E<G1O`%!A;&%V<F$M4&%S<V4`4&%L879R82U087-S92!I;F-O
M<G)E8W1A`%!A;&%V<F$M4&%S<V4@;F5C97-SX7)I82!P87)A(&%U=&5N=&EC
M8>?C;R!2041)55,`4&%L879R82U087-S92!C;VT@8V]N9FER;6'GXV\`4&%L
M879R82U087-S93H`4&%L879R82U087-S93H@`$%S('!A;&%V<F%S+7!A<W-E
M('3J;2!D92!S97(@:6=U86ES+@!#;VQA<@!#;VQA<B!D92!R96-O<G1E<P!#
M86UI;FAO`%-U8G-C<FGG]65S(%!E;F1E;G1E<SH`4&5S<V]A<P!097)C96YT
M86=E;0!%>&5C=71A<B!/<&5R8>?U97,@9&4@36%N=71E;N?C;P!%>&5C=71A
M<B!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!A<75A;F1O(&1A(&5N=')A9&$_
M`%!E<FUI<W/C;P!!('!E<FUI<W/C;R`B)7,B(&[C;R!F;VD@<F5M;W9I9&$N
M`%!E<FUI<W/C;R!.96=A9&$`4&5R;6ES<_5E<P!!9&UI;FES=')AY^-O(&1E
M(%!E<FUI<W/U97,`4&5R;6ES<_5E<R!D90!);F9O<FUAY_5E<R!097-S;V%I
M<P!097+Z`$%N:6UA:7,@9&4@17-T:6UAY^-O`$9I;&EP:6YA<P!496QE9F]N
M90!&;W1O9W)A9FEA<P!);&AA<R!0:71C86ER;@!0[7AE:7,`4&QA=&ET=61E
M<P!0;W(@9F%V;W(@8VQI<75E('-O8G)E('5M82!CZ6QU;&$`4&]R(&9A=F]R
M(&-O;F9I<FUE('-E(')E86QM96YT92!P<F5T96YD92!R96UO=F5R(&5S=&4@
M96QE;65N=&\Z`%!O<B!F879O<B!C;VYF:7)M92!S92!R96%L;65N=&4@<')E
M=&5N9&4@9&5S;&EG87(@97-T92!E;&5M96YT;RX`4&]R(&9A=F]R(&EN=')O
M9'5Z82!U;2!MZG,@92!U;2!A;F\N`%!O<B!F879O<B!I;G1R;V1U>F$@;R!N
M;VUE(&1A(&YO=F$@8V%T96=O<FEA.@!0;W(@9F%V;W(@:6YT<F]D=7IA('5M
M(&5N9&5R9>=O($E0(';A;&ED;RX`4&]R(&9A=F]R(&EN=')O9'5Z82!U;6$@
M9&%T82!VX6QI9&$[('9E<FEF:7%U92!O(&[Z;65R;R!D92!D:6%S(&1O(&WJ
M<RX`4&]R(&9A=F]R(&EN=')O9'5Z82!U;6$@:&]R82!VX6QI9&$N`%!O<B!F
M879O<BP@9F]R;F7G82!U;6$@8G)E=F4@9&5S8W)IY^-O(&1O('!R;V)L96UA
M+@!0;W(@9F%V;W(L(&EN=')O9'5Z82!O('-E=2!.;VUE(&1E(%5T:6QI>F%D
M;W(@92!A('-U82!086QA=G)A+5!A<W-E`%!O<B!F879O<B!L96EA(&\@=&5X
M=&\@<V5G=6EN=&4N(%1E;2!D92!#3TY#3U)$05(@8V]M(&]S('1E<FUO<R!D
M97-T92!A8V]R9&\@<&%R82!U<V%R(&\@<VES=&5M82X`4&]R(&9A=F]R(')E
M<&]R=&4@;W,@97)R;W,@<&%R82!I,3AN0&QI<W1S+FAO<F1E+F]R9P!0;W(@
M9F%V;W(@:6YT<F]D=7IA(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83H`4&]L
M\VYI80!0;VSM=&EC80!3;VYD86=E;G,`4F5P^F)L:6-A(%!O<G1U9W5E<V$`
M4&]S:6-I;VYA;65N=&\@9&5S=&$@:6UA9V5M`%!O<VEC:6]N86UE;G1O(&1E
M<W1A('1A8F5L80`B4&]S="(@<&%R82!E<W1A('!A<W1A("ANXV\@Z2!R97%U
M:7-I=&\@9&\@24U!4"D`4')E8VEP:71AY^-O(&YA<R#Z;'1I;6%S("5S(&AO
M<F$H<RDZ(`!0<F]B86)I;&ED861E(&1E/&)R("\^4')E8VEP:71AY^-O`%!R
M969S7VQD87`Z($$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA(&[C;R!F;VD@
M96YC;VYT<F%D82X`4')E9G-?<V5S<VEO;CH@02!E>'1E;G/C;R!D92!S97-S
MXV\@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`%!R97-SXV\`4')E
M<W/C;R!A;R!N[79E;"!D;R!M87(Z(`!0<F5S<^-O.B``4')E=FESXV\`4')E
M=F5R(&$@:6UA9V5M(&YU;6$@;F]V82!J86YE;&$`3W#G]65S(&%N=&5R:6]R
M97,`26UP<FEM:7(@;R!D;V-U;65N=&\`0VAA=F4@4')I=F%D80!0<F]B;&5M
M80!$97-C<FGGXV\@9&\@4')O8FQE;6$`4')O:F5C=&]S`$UE;G-A9V5M+7!R
M;VYT;P!#:&%V92!0^F)L:6-A`$%L9V]R:71M;R!D92!#:&%V92!0^F)L:6-A
M`$EN9F]R;6'GXV\@4V]B<F4@82!#:&%V90!/('!A<B!D92!C:&%V97,@4'5B
M;&EC82]0<FEV861A(&[C;R!F;VD@9V5R861A(&-O;2!S=6-E<W-O+@!0;W)T
M;R!2:6-O`$5S=&%D;R!D;R!1871A<@!0961I9&\`0VAA=F4@4/IB;&EC82!2
M4T$@*"5D(&)I="D`4V5L96/GXV\@(G+A9&EO(@!#:'5V80!#:'5V82!-871I
M;F%L`$-H=79A(%9E<W!E<G1I;F$`06=U86-E:7)O`$-H=79A(&4@3F5V90!#
M:'5V82!A($YE=F4`1&ET;R!!;&5A=/-R:6\`4F5L8>?C;P!,97(`3&5R(&UE
M;G-A9V5N<P!1=65R(&UE<VUO(')E;6]V97(@)7,_($5S=&$@;W!E<F'GXV\@
M;N-O('1E;2!R96=R97-S;RX`4F5M;W9E<B!M97-M;R!O<R!D861O<R!D;R!U
M=&EL:7IA9&]R("5S/R!%<W1A(&]P97)AY^-O(&[C;R!T96T@<F5G<F5S<V\N
M`%)E9F%Z(&$@<W5A(/IL=&EM82!A8^?C;P!2969R97-C87(@16QE;65N=&]S
M(&1E($UE;G4@1&ENXFUI8V\Z`$%C='5A;&EZ87(@3&ES=&$`4F5F<F5S8V%R
M(%9I<W5A;&EZ8>?C;R!D;R!0;W)T86PZ`$5X<')E<W/C;R!296=U;&%R`$YA
M=F5G861O<B!D92!296QAY_5E<P!/8G-E<G9AY_5E<P!397)V:61O<F5S(%)E
M;6]T;W,`55),(%)E;6]T;R`H:'1T<#HO+W=W=RYE>&5M<&QO+G!T+VAO<F1E
M*3H`4F5M;W9E<@!296UO=F5R($)L;V-O`%)E;6]V97(@8V%T96=O<FEA`%)E
M;6]V97(@8V]L=6YA`%)E;6]V97(@9F]R;6%T8>?C;P!296UO=F5R('!A<@!2
M96UO=F5R(&\@(G-C<FEP="(@9W5A<F1A9&\@9&$@<&%S=&$@=&5M<&]RX7)I
M82!D;R!S97)V:61O<BX`4F5M;W9E<B!O`%)E;6]V97(@97-T92!N\R!D;R!D
M;V-U;65N=&\`4F5M;W9E<B!5=&EL:7IA9&]R`%)E;6]V97(@=71I;&EZ861O
M<CH@)7,`3N-O(&9O:2!P;W-S[79E;"!R97-P;VYD97(@86\@<&5D:61O+B!#
M\V1I9V\@9&4@97)R;R!D979O;'9I9&\Z(`!/('-E<G9IYV\@<&5D:61O(&[C
M;R!F;VD@96YC;VYT<F%D82X`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S
M<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@9&4@)7,N`"(E<R(@;V)R:6=A
M=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O(%9&
M4RX`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C
M;VYF:6=U<F'GXV\N`$-A;7!O($]B<FEG873S<FEO`$QI;7!A<@!296EN:6-I
M87(@4&%L879R82U087-S90!296EN:6-I92!A(%-U82!086QA=G)A+5!A<W-E
M`%)E<W5L=&%D;W,`4F5S=6QT861O<R`H:6YC;'5I;F1O($AO<F1E*3H`4F5S
M=6QT861O<SH`5F]L=&%R(.!S($]PY_5E<P!2975N:>-O`%)%=F5R=&5R($-O
M;F9I9W5R8>?C;P!/<.?U97,@9&4@161IY^-O(%)I8V$`061I=FEN:&%S`$1I
M<F5I=&$`0V%B9>=A;&AO(&1A(&1I<F5I=&$`5F%L;W)E<R#@(&1I<F5I=&$`
M4')O<')I961A9&5S(&1A($QI;E]H82XN+@!296=R80!2;VWI;FEA`%)O9&%R
M(#$X,`!2;V1A<B#@($5S<75E<F1A`%)O9&%R(.`@9&ER96ET80!0<F]P<FEE
M9&%D97,@9&$@3&EN:&$`4')O<')I961A9&5S(&1A(&QI;FAA`$QI;FAA<SH`
M5')AYV]S`%1R8>=O<R!A<&%R96-E<N-O(&5N=')E('1O9&%S(&%S(&QI;FAA
M<R!E(&-O;'5N87,`5')AYV]S(&%P87)E8V5RXV\@87!E;F%S(&5N=')E(&%S
M(&-O;'5N87,`5')AYV]S(&%P87)E8V5RXV\@87!E;F%S(&5N=')E(&QI;FAA
M<P!%>&5C=71A<@!&961E<F'GXV\@4G5S<V$`4F5P^F)L:6-A(&1O(%)U86YD
M80!!<W-I;F%T=7)A($-R:7!T;V=RX69I8V$@4R]-24U%`$UE;G-A9V5M($5N
M8W)I<'1A9&$@8V]M(%,O34E-10!!=71E;G1I8V'GXV\@4T%33"!I;F1I<W!O
M;NUV96PN`$UE;G-A9V5N<R!335,`0V]M86YD;W,@4U%,`%-32`!354-%4U-/
M`$-O;6%N9&]S(%-?44P`<^$`4V%N=&$@2&5L96YA`%/C;R!+:71T<R!E($YE
M=FES`%-A;G1A($SZ8VEA`%/C;R!0961R;R!E($UI<75E;&]N`%/C;R!6:6-E
M;G1E(&4@1W)E;F%D:6YE<P!-97-M82!M;VQD=7)A("A?<V5L9BD`17-T861O
M($EN9&5P96YD96YT92!D82!386UO80!297#Z8FQI8V$@4V5R96[M<W-I;6$@
M9&4@4^-O($UA<FEN;P!3XV\@5&]MZ2!E(%!R[6YC:7!E`$9O<FYE8V5D;W(@
M9&\@4V%TZ6QI=&4`07+A8FEA(%-A=61I=&$`1W)A=F%R`$=U87)D87(@)7,`
M1W5A<F1A<B`G)7,G`$=U87)D87(@3W#G]65S`$=U87)D87(@8V]N9FEG=7)A
MY^-O(&=E<F%D82!C;VUO('5M(")S8W)I<'0B(%!(4"!N;R!D:7)E8W3S<FEO
M('1E;7!O<N%R:6\@9&\@<V5U('-E<G9I9&]R+@!'=6%R9&5I(&-O;F9I9W5R
M8>?C;R`E<RX`1W5A<F1E:2!O(")S8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R!E
M;3H@(B5S(BX`5&5M<&]R86ES+50@1&ES<&5R<V]S`$-IZFYC:6$`4')O8W5R
M87(`36]T;W)E<R!D92!0<F]C=7)A`%)E<W5L=&%D;W,@9&$@4')O8W5R87(`
M17-C;W!O(&1E(%!R;V-U<F$`4')O8W5R87(@7U1E>'1O`%!R;V-U<F%N9&\@
M87!L:6-AY_5E<R`H;?-D=6QO<RD@2&]R9&4@96T@)7,`4')O8W5R86YD;R!O
M<R!B:6[A<FEO<R!D92!G971T97AT+BXN`%-E;&5C8VEO;F%R($%R<75I=F]S
M`%-E;&5C8VEO;F4@=6UA(&1A=&$`4V5L96-C:6]N92!U;2!G<G5P;R!A(&%C
M<F5S8V5N=&%R`%-E;&5C8VEO;F%R('5M(&YO=F\@9&]N;P!396QE8V-I;VYE
M('5M(&QI=G)O(&1E(&YO=&%S`%-E;&5C8VEO;F4@=6T@<V5R=FED;W(`4V5L
M96-C:6]N92!U;2!U=&EL:7IA9&]R(&$@861I8VEO;F%R`%-E;&5C8VEO;F4@
M=&]D;W,@;W,@8V]M<&]N96YT97,@9&$@9&%T82X`4V5L96-C:6]N92!U;2!O
M8FIE8W1O`%-E;&5C8VEO;F4@;W,@8V%R86-T97)E<R!N87,@8V%I>&%S(&%B
M86EX;RX@4&]D97+A(&5N=.-O(&-O<&GA+6QO<R!E(&-O;.$M;&]S(&YA(.%R
M96$@9&4@=&5X=&\N`%-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D82!D871A
M.@!396QE8V-I;VYE(&\@9F]R;6%T;R!D82!D871A.@!396QE8V-I;VYE(&\@
M9F]R;6%T;R!D92!E>'!O<G1AY^-O.@!396QE8V-I;VYE(&\@9FEC:&5I<F\@
M82!I;7!O<G1A<CH`4V5L96-C:6]N92!O(&9O<FUA=&\@9&\@9FEC:&5I<F\@
M9F]N=&4Z`%-E;&5C8VEO;F4@82!I9&5N=&ED861E('%U92!P<F5T96YD92!A
M;'1E<F%R.@!396QE8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&%S(&AO<F%S.@!3
M96QE8V-I;VYE(&\@9F]R;6%T;R!D82!H;W)A.@!396QE8V-I;VYE(&1O:7,@
M8V%M<&]S(')E;&%C:6]N861O<RX`17-C;VQH82!O('-E=2!C;VYJ=6YT;R!D
M92!C;W)E<RX`4V5L96-C:6]N92!O('-E=2!I9&EO;6$@<')E9F5R:61O.@!#
M871E9V]R:6%S(%-E;&5C8VEO;F%D87,Z`$5N=FEA<B!296QA=/-R:6\@9&4@
M4')O8FQE;6%S`$5N=FEA<B!335,`4F5P^F)L:6-A(&1O(%-E;F5G86P`(%-E
M;G-O<CH@`%-E=&5M8G)O`%/I<G9I82!E($UO;G1E;F5G<F\`3OIM97)O(&1E
M(%/I<FEE`$1A9&]S(&1O('-E<G9I9&]R(&5R<F%D;W,@;W4@:6YD:7-P;V[M
M=F5I<RX`240@9&4@<V5S<^-O(&5X<&ER;W4N`$%T<FEB=6ER`$5S=&%B96QE
MYV$@;W#G]65S('%U92!L:&4@<&5R;6ET86T@<F5I;FEC:6%R(&$@<W5A('!A
M;&%V<F$M<&%S<V4@<V4@86QG=6UA('9E>B!D96QA('-E(&5S<75E8V5R+@!%
M<W!E8VEF:6-A<B!S97)V:61O<F5S(')E;6]T;W,@<75E(&1E<V5J82!A8V5D
M97(@;F\@<V5U('!O<G1A;"X`4V5L96-C:6]N92!O('-E=2!I9&EO;6$@<')E
M9F5R:61O+"!O('-E=2!F=7-O(&AO<N%R:6\@92!A<R!S=6%S(&]PY_5E<R!D
M92!D871A<RX`17-C;VQH82!A('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@;R!E
M<W%U96UA(&1E(&-O<F5S+"!O(')E9G)E<V-A;65N=&\@9&4@<.%G:6YA<R!E
M(&]U=')A<R!O<.?U97,@9&4@=FES=6%L:7IAY^-O+@!#;VYF:6=U<F%R`")3
M8W)I<'1S(B!D92!A8W1U86QI>F'GXV\@9&ES<&]N[79E:7,`5N%R:6%S(&QO
M8V%L:7IAY_5E<R!P;W-S[79E:7,@8V]M(&\@<&%RXFUE=')O.B``4V5I8VAE
M;&5S`$-O;7!R87,`0G)E=F4@4W5MX7)I;P!$979E;2US92!D969I;FER('1E
M8VQA<R!D92!A8V5S<V\@<&%R82!A(&UA:6]R:6$@9&%S(&QI9V'G]65S/P!-
M;W-T<F%R`$UO<W1R87(@3&EV<F]S(&1E($YO=&%S.@!-;W-T<F%R(&)O=/5E
M<R!D92!A8^?C;S\`36]S=')A<B!D:69E<F5NYV%S(&5N=')E(&$@8V]N9FEG
M=7)AY^-O(&=U87)D861A(&4@87%U92!F;VD@86=O<F$@9V5R861A+@!-;W-T
M<F%R(&UO;65N=&\@9&$@^FQT:6UA(&5N=')A9&$@;F\@<VES=&5M83\`36]S
M=')A<B!N;VUE(&1O(&QI=G)O(&1E(&YO=&%S/P!-;W-T<F%R(&YO=&%S(&1E
M<W1A<R!C871E9V]R:6%S`$UO<W1R87(@;W#GXV\@<&%R82!P<F5S97)V87(@
M;R!O<FEG:6YA;`!-;W-T<F%R('!A;&5T90!-;W-T<F%R(&$@8F%R<F$@9&4@
M;65N=2!C;VT@87,@;W!E<F'G]65S('-O8G)E('1A8F5L87,_`$UO<W1R87(@
M;R!-96YU("5S(.`@97-Q=65R9&$_`$UO<W1R87(@82!C86EX82!D92!D:>%L
M;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D92!486)E;&$_`$UO
M<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@
M5&%B96QA<P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I
M961A9&5S(&1E($QI;FAA<R!D92!486)E;&$`36]S=')A<B!A(&-A:7AA(&1E
M(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!);6%G96T`36]S=')A<B!C
M87)R96=A;65N=&\`06=U86-E:7)O<P!!9W5A8V5I<F]S($UA=&EN86ES`$%G
M=6%C96ER;W,@5F5S<&5R=&EN;W,`06=U86-E:7)O<R!N82!6:7II;FAA;N=A
M`$5N8V]L:&5R`$5N8V]L:&$@;W4@;6]V82!O*',I(&)L;V-O*',I('9I>FEN
M:&\H<RD@<')I;65I<F\`4V5R<F$@3&7C;P!3=6)S8W)E=F5R`%-U8G-C<F5V
M82P@<V4@86EN9&$@;N-O(&5S=.$@<F5G:7-T861O`$%S<VEN871U<F$`06QG
M;W)I=&UO(&1E($%S<VEN871U<F$`4F5P^F)L:6-A(&1E(%-I;F=A<'5R80!4
M86UA;FAO`%-A;'1A<B!-86YU=&5NY^-O`$[C;R!P<F]C97-S861O+BXN`$5S
M;&]VX7%U:6$`4F5P^F)L:6-A(&1A($5S;&]VZ6YI80!.979E`$YE=N-O`$YE
M=O5E<P!.97;U97,@36%T:6YA:7,`3F5V]65S(%9E<W!E<G1I;F]S`$%L='5R
M82!D92!N979E.B``36]S=')A<B!E<75I=F%L96YT92!N82#A9W5A.B``26QH
M87,@4V%L;VWC;P!3;VWA;&EA`$-A;N?U97,@92!0;V5M87,`3W)D96YA<B!P
M;W(@0V%T96=O<FEA`$]R9&5N87(@<&]R(%1E>'1O(&1A($YO=&$`4V5L96/G
MXV\@9&\@<V5N=&ED;R!D82!O<F1E;F'GXV\`16YD97)EYV\@9&4@;W)I9V5M
M`,%F<FEC82!D;R!3=6P`175R;W!A(&1O(%-U;"`H25-/+3@X-3DM,RD`1V7S
M<F=I82!D;R!3=6P@92!);&AA<R!386YD=VEC:"!D;R!3=6P`2&5M:7-FZ7)I
M;R!3=6P`17-P8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E<P!%<W!AYV\@
M96YT<F4@;R!C;VYT9?ID;R!E(&$@8F]R9&$@9&4@=6UA(&/I;'5L80!%<W!A
MYV%D;W(`17-P8>=A;65N=&\`17-P8>=A;65N=&\@92!E;F-H:6UE;G1O`%)E
M:6YO(&1E($5S<&%N:&$`0V]R<F5I;R!NXV\@<V]L:6-I=&%D;P!);G-E<FER
M($-A<F%C=&5R($5S<&5C:6%L`$1I=FED:7(@8^EL=6QA`$%D:6-I;VYA<B!C
M;VQU;F$`1&EV:61I<B!L:6YH80!$97-P;W)T;W,`4F5P^F)L:6-A($1E;6]C
M<N%T:6-A(%-O8VEA;&ES=&$@9&\@4W)I($QA;FMA`%!A9'+C;P!3=&%R(%1R
M96L`06YO(&1E(&EN[6-I;P!%<W1A9&\@;W4@4')O=NUN8VEA`%-T871U<P!%
M<W1A9&\@9&$@;&]C86QI>F'GXV\@)7,N+BX@`$9O<FUA=&\@9&4@87)M87IE
M;F%M96YT;P!%;F1E<F7G;R!D92!2=6$`4F%S=7)A9&\`3&ES=&$@9&4@8V%D
M96EA<R!D92!C87)A8W1E<F5S`%)E=&ER87(@9&]M[6YI;R!D;R!E;F1E<F7G
M;P!%<W1I;&\@6T-34UT`9&\`07-S=6YT;P!3=6)M971E<@!&;VD@<W5B;65T
M:61O('!E9&ED;R!P87)A(&%D:6-I;VYA<B`B)7,B(&%O('-I<W1E;6$N($[C
M;R!P;V1E<N$@96YT<F%R(&5N<75A;G1O(&\@<V5U('!E9&ED;R!NXV\@9F]R
M(&%P<F]V861O+@!);F9E<FEO<B#@(&QI;FAA`%-U8V5S<V\`(B5S(B!A9&EC
M:6]N861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N`$QI;7!E>F$@9&\@<VES
M=&5M82!D;W,@9&%D;W,@9&\@=71I;&EZ861O<B`B)7,B(')E86QI>F%D82!C
M;VT@<W5C97-S;RX`4F5M;^?C;R!D92`B)7,B(&-O;2!S=6-E<W-O+@!296UO
MY^-O(&1E("(E<R(@9&\@<VES=&5M82!C;VT@<W5C97-S;RX`0V]N9FEG=7)A
MY^-O(')E=F5R=&ED82!C;VT@<W5C97-S;RX@4F5C87)R96=U92!P87)A('9E
M<B!A<R!M=61A;N=A<RX`(B5S(B!G=6%R9&%D82!C;VT@<W5C97-S;RX`0V]N
M9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A(&=U87)D861A(&-O;2!S=6-E<W-O
M+@!&:6-H96ER;R!D92!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R9&$@)7,@
M9W5A<F1A9&\@8V]M('-U8V5S<V\N`"(E<R(@86-T=6%L:7IA9&\@8V]M('-U
M8V5S<V\`)7,@97-C<FET;R!C;VT@<W5C97-S;P!297#Z8FQI8V$@9&\@4W5D
MXV\`4F5S=6UO`$YA<V-E<B!D;R!3;VP`4/1R(&1O(%-O;`!3;VQA<F5N9V\`
M3F%S8V5R(&1O(%-O;`!.87-C97(O4/1R(&1O(%-O;`!.87-C97(@9&\@4V]L
M.B``4/1R(&1O(%-O;`!0]'(@9&\@4V]L.B``4W5P97)I;W(@X"!L:6YH80!3
M=7!O<G1E`%-U<FEN86UE`$%P96QI9&\`4W9A;&)A<F0@92!*86X@36%Y96X`
M4F5I;F\@9&$@4W5A>FELXFYD:6$`4F5I;F\@9&$@4W7I8VEA`%-U[>=A`$5R
M<F\@9&4@<VEN=&%X92!N;W,@=&5R;6]S(&1E('!R;V-U<F$`4F5P^F)L:6-A
M(,%R86)E(%/M<FEA`%1E;7!O<F%L+50`5&5M<&]R86PM5"!E(%9E;G1O<V\`
M5&5M<&]R86ES+50`5&5M<&]R86ES+50@36%T:6YA:7,`07)Q=6EV;R!44U8`
M5&%B96QA`%!R;W!R:65D861E<R!D82!486)E;&$`4')O<')I961A9&5S(&1A
M('1A8F5L80!&;W)M;W-A`$9O<FUO<V$`4F5P^F)L:6-A(&1O(%1A9&II<75I
M<W3C;P!486YZXFYI80!!;'9O.@!487)E9F%S`$[Z;65R;R!D92!496QE9F]N
M90!496UP97)A='5R82!D82#Z;'1I;6$@:&]R83H`5&5M<&5R871U<F$`5&5M
M<&5R871U<F$Z(`!496UP97)A='5R83QB<B`O/B@E<T%L=&$E<R\E<T)A:7AA
M)7,I("9D96<[)7,`3R!M;V1E;&\@(B5S(B!NXV\@9F]I(&5N8V]N=')A9&\N
M`$%D;6EN:7-T<F'GXV\@9&4@36]D96QO<P!497AT;P!!<&5N87,@5&5X=&\`
M06QI;FAA;65N=&\@9&\@=&5X=&\`5&]P;R!D;R!T97AT;P`UJ@!486EL86YD
MZG,@*%1)4RTV,C`I`%)E:6YO(&1A(%1A:6SB;F1I80!/8G)I9V%D;R!P;W(@
M=7-A<B!E<W1E('-I<W1E;6$N`$\@87)Q=6EV;R!D92!A:G5D82`E<R!P87)A
M("5S(&[C;R!E>&ES=&4@86EN9&$N($-R:6%N9&\@=6T@;F]V;RX`02!E>'1E
M;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N[79E;"X`3R!E;F=E;FAO(&1E(&EN
M=&5G<F'GXV\@2&]R9&4O2V]L86(@;N-O('-U<&]R=&$@(B5S(@!/(')E9VES
M=&\@*")L;V<B*2!)35-0(&[C;R!P]&1E('-E<B!I;FEC:6%L:7IA9&\N`$$@
M8VQA<W-E($UA:6YT96YA;F-E.CH@;N-O(&9O:2!C87)R96=A9&$@8V]M('-U
M8V5S<V\`02!J86YE;&$@9&4@3W#G]65S(&9E8VAO=2X@4V'M;F1O+@!/(&%D
M;6EN:7-T<F%D;W(@=&5M(&1E(&-O;F9I9W5R87(@=6T@;65C86YI<VUO(&1E
M('!E<FUI<W/U97,@<&5R;6%N96YT92!S92!Q=6ES97(@=7-A<B!097)M:7-S
M]65S+@!!<&5N87,@;R!L861O(&EN9F5R:6]R`$\@;OIM97)O(&1E($E$(&1O
M(&-O;G1A8W1O(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E
M;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@9&%D
M;W,N`$\@8V]N=&%C=&\@9F]I(&%D:6-I;VYA9&\@X"!L:7-T82!D92!C;VYT
M86-T;W,@8V]M('-U8V5S<V\N`$\@8FQO8V\@9&4@87-S:6YA='5R82!01U`@
M9&5S=&%C861O(.D@;F5C97-SX7)I;R!P87)A('9E<FEF:6-A<B!U;6$@;65N
M<V%G96T@87-S:6YA9&$N`$\@240@9&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O
M(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E;2!B<F%N8V\@
M;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@9&%D;W,N`$$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861A+@!!<R!F
M=6YC:6]N86QI9&%D97,@9&4@96YC<FEP=&'GXV\@97AI9V5M('5M82!L:6=A
MY^-O('-E9W5R82X`3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N=&5R('5M(&%T
M<FEB=71O("5S+@!/(&%R<75I=F\@)7,@9&5V97)I82!C;VYT97(@86QG=6YS
M(&%T<FEB=71O<R`E<RX`3R!F:6-H96ER;R!NXV\@<&]D92!S97(@8V]P:6%D
M;R!P87)A('-I('!R\W!R:6\N`$\@9FEC:&5I<F\@;N-O(&-O;G3I;2!D861O
M<RX`06)A:7AO(&5S=.-O(&]S(&-A8F7G86QH;W,@9&5S=&$@;65N<V%G96TO
M;65N<V%G96T@<F9C.#(R+@!/(&UO9&\@9&4@96-RXR!I;G1E:7)O(&-A=7-A
M('!R;V)L96UA<R!N;R!);G1E<FYE="!%>'!L;W)E<BP@9&5V:61O(&$@97)R
M;W,@;F\@;F%V96=A9&]R('%U92!NXV\@8V]N<V5G=6EM;W,@=6QT<F%P87-S
M87(N("!0;V1E('-U<F=I<B!L:7AO+"!P;V1E;2!D97-A<&%R96-E<B!F=6YC
M:6]N86QI9&%D97,@9&\@961I=&]R(&4O;W4@;R!S974@;F%V96=A9&]R('!O
M9&4@86)O<G1A<BX@4V4@;R!S974@<VES=&5M82#I('5M(%=I;F1O=W,@.7@L
M(.D@;75I=&\@<')O=N%V96P@<75E(&]B=&5N:&$@=6T@)T=E;F5R86P@4')O
M=&5C=&EO;B!&875L="<@92!P<F5C:7-E(&1E(')E:6YI8VEA<B!O('-I<W1E
M;6$N7&Y<;D9O:2!A=FES861O+B`@4&]R(&9A=F]R('!R97-S:6]N92!/2R!S
M92!A:6YD82!A<W-I;2!Q=6ES97(@97AP97)I;65N=&%R(&\@961I=&]R(&1E
M(&5C<N,@:6YT96ER;RX`3R!F:6-H96ER;R!D92!A:G5D82`E<R!NXV\@8V]M
M9>=A(&-O;2`\/WAM;`!!(&ED96YT:61A9&4@(B5S(B!F;VD@<F5M;W9I9&$N
M`$%P96YA<R!O(&QA9&\@97-Q=65R9&\`02!L;V-A;&EZ8>?C;R!D;R!A<G%U
M:79O(&5X96-U=.%V96P@9&4@1VYU4$<@=&5M(&1E('-E<B!I;F1I8V%D82#@
M(&-L87-S92!#<GEP=%]P9W`Z.BX`02!M96YS86=E;2!E;G9I861A(&5M("5S
M('!A<F$@)7,@8V]M(&%S<W5N=&\@(B5S(B!F;VD@;6]S=')A9&$N"D[C;R!H
MX2!G87)A;G1I82!D92!Q=64@82!M96YS86=E;2!T96YH82!S:61O(')E86QM
M96YT92!L:61A(&]U(&-O;7!R965N9&ED82X`3R!N;VUE(&$@=7-A<B!Q=6%N
M9&\@;&EG86YD;R#@('#A9VEN82!D92!C;VUP;W-IY^-O`$$@;F]T82!F;VD@
M<F5M;W9I9&$N`$\@;&EV<F\@9&4@;F]T87,@(B5S(B!NXV\@<&]D92!S97(@
M8W)I861O.B`E<P!/(&QI=G)O(&1E(&YO=&%S("(E<R(@9F]I(&-R:6%D;RX`
M3R!L:79R;R!D92!N;W1A<R`B)7,B(&9O:2!R96UO=FED;RX`3R!L:79R;R!D
M92!N;W1A<R`B)7,B(&9O:2!G=6%R9&%D;RX`3R!M\V1U;&\@;W!E;G-S;"#I
M(&YE8V5S<^%R:6\@<&%R82!A(&-L87-S92!(;W)D95]#<GEP=%]S;6EM93HZ
M+@!!(&]PY^-O("(E<R(@;N-O('#T9&4@<V5R(&=U87)D861A+"!P;VES(&]S
M('-E=7,@9&%D;W,@97AC961E;2!A(&1I;65N<^-O(&WA>&EM82!P97)M:71I
M9&$`3R!P<F]G<F%M82!U<V%D;R!P87)A('9E<B!E<W1E('1I<&\@9&4@9&%D
M;W,@*"5S*2!NXV\@9F]I(&5N8V]N=')A9&\@;F\@<VES=&5M82X`07!E;F%S
M(&]S(&QA9&]S(&5S<75E<F1O(&4@9&ER96ET;P!!<&5N87,@;R!L861O(&1I
M<F5I=&\`3R!S97)V:61O<B`B)7,B(&9O:2!R96UO=FED;RX`3R!S97)V:61O
M<B`B)7,B(&9O:2!G=6%R9&%D;RX`3R!P961I9&\@9&4@<W5B<V-R:>?C;R!D
M92`E<R!F;VD@<F5M;W9I9&\N`$$@;&EN:&$@:6YD:6-A9&$@;N-O(&5X:7-T
M92X`3R!A<G%U:79O('1E;7!O<N%R:6\@(B5S(B!NXV\@97AI<W1E+@!!<&5N
M87,@;W,@;&%D;W,@<W5P97)I;W(@92!I;F9E<FEO<@!!<&5N87,@;R!L861O
M('-U<&5R:6]R`$]S(&1A9&]S(&-A<G)E9V%D;W,@<&5R9&5R86TM<V4@9&5S
M9&4@;R!P87-S;R!A;G1E<FEO<BX`3R!A<G%U:79O(&-A<G)E9V%D;R!NXV\@
M</1D92!S97(@9W5A<F1A9&\N`$\@8FQO8V\@=V5A=&AE<BYC;VT@;N-O(&5S
M=.$@9&ES<&]N[79E;"X`3N-O(&CA(&]PY_5E<R!D:7-P;V[M=F5I<RX`3N-O
M(&CA('!A<G1E<R!Q=64@<&]S<V%M('-E<B!M;W-T<F%D87,@96T@;&EN:&$N
M`$CA(&1E;6%S:6%D;W,@8V%R86-T97)E<R!N97-T92!C86UP;RX@26YT<F]D
M=7II=2`E<R!C87)A8W1E<F5S.R!T96T@9&4@:6YT<F]D=7II<B!M96YO<R!D
M;R!Q=64@)7,N`$[C;R!E>&ES=&4@86EN9&$@=6T@87)Q=6EV;R!D92!A:G5D
M82!P87)A("5S+@!/8V]R<F5U('5M('!R;V)L96UA(&YA(&%D:>?C;R!D92`B
M)7,B(&%O('-I<W1E;6$Z("5S`$]C;W)R974@=6T@<')O8FQE;6$@86\@;&EM
M<&%R(&]S(&1A9&]S(&1O('5T:6QI>F%D;W(@(B5S(B!D;R!S:7-T96UA+@!/
M8V]R<F5U('5M('!R;V)L96UA(&YA(')E;6_GXV\@9&4@(B5S(B!D;R!S:7-T
M96UA+@!/8V]R<F5U('5M('!R;V)L96UA(&%O(&%C='5A;&EZ87(@(B5S(CH@
M)7,N`$AO=79E('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M96YT;R!D;R!F
M:6-H96ER;SH@)7,@;N-O(&9O:2!C87)R96=A9&\N`$]C;W)R974@=6T@<')O
M8FQE;6$@8V]M(&\@8V%R<F5G86UE;G1O(&1O(&%R<75I=F\Z($\@)7,@97AC
M961E(&\@=&%M86YH;R!MX7AI;6\@<&5R;6ET:61O("@E9"!B>71E<RDN`$]C
M;W)R974@=6T@<')O8FQE;6$@8V]M(&\@8V%R<F5G86UE;G1O(&1O(&%R<75I
M=F\Z($\@)7,@9F]I(&%P96YA<R!P87)C:6%L;65N=&4@8V%R<F5G861O+@!/
M8V]R<F5U('5M(&5R<F\@86\@;6]S=')A<B!E<W1A('!A<G1E(&1A(&UE;G-A
M9V5M`$]C;W)R974@=6T@97)R;R!A;R!I;7!O<G1A<B!D861O<R!D92!C;VYT
M86-T;RX`3V-O<G)E=2!U;2!E<G)O(&YA(&EM<&]R=&'GXV\@9&]S(&1A9&]S
M.B`E<P!/8V]R<F5U('5M(&5R<F\@;F$@:6UP;W)T8>?C;R!D;W,@9&%D;W,@
M:4-A;&5N9&%R+@!/8V]R<F5U('5M(&5R<F\@;F$@:6UP;W)T8>?C;R!D;W,@
M9&%D;W,@=DYO=&4N`$]C;W)R974@=6T@97)R;R!N;R!F;W)M=6SA<FEO(&1E
M(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('1E;FAA(&]M:71I9&\@=6T@8V%M<&\@
M;V)R:6=A=/-R:6\N`$]C;W)R974@=6T@97)R;R!A;R!A8G)I<B!O(&%R<75I
M=F\@)7,N($5X<&5R:6UE;G1E(&5X96-U=&%R('1R86YS;&%T:6]N+G!H<"!C
M;VT@82!O<.?C;R`M9"!P87)A(&-O;G-E9W5I<B!V97(@87,@;65N<V%G96YS
M(&1E(&5R<F\@9&\@86YA;&ES861O<B!834PN`$]C;W)R974@=6T@97)R;R!A
M;R!R96%L:7IA<B!A(&9U;N?C;R!D92!L:79R;R!D92!E;F1E<F7G;W,@97-P
M96-I9FEC861A+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!M86ES('1A<F1E
M+@!/8V]R<F5U('5M(&5R<F\@86\@<F5M;W9E<B!A(&YO=&$Z("5S`$]C;W)R
M974@=6T@97)R;R!A;R!G<F%V87(@82!N;W1A.B`E<P!/8V]R<F5U('5M(&5R
M<F\@86\@86-T=6%L:7IA<B!O<R!P;W)M96YO<F5S(&1O(&-O;G1A8W1O+B!0
M;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!M86ES('1A<F1E+@!/8V]R<F5U('5M
M(&5R<F\@86\@86-T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@
M4&]R(&9A=F]R('1E;G1E(&1E(&YO=F\@;6%I<R!T87)D92X`3V-O<G)E=2!U
M;2!E<G)O(&%O(&UO<W1R87(@97-T92!L:79R;R!D92!N;W1A<SH@)7,`3N-O
M(&AO=79E(&YO=&%S(&$@97AP;W)T87(N`$5S=&4@<V5R=FED;W(@24U!4"!N
MXV\@<W5P;W)T82!P87)T:6QH82!D92!P87-T87,N`$[C;R!P87)E8V4@<V5R
M('5M(&%R<75I=F\@<F%R(';A;&ED;RX`3N-O('!A<F5C92!S97(@=6T@87)Q
M=6EV;R!Z:7`@=N%L:61O+@!.XV\@<&%R96-E('-E<B!U;6$@;OIM97)O(&1E
M(&-A<G3C;R!VX6QI9&\N`$5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!O(&5N
M=FEO(&1E(&UE;G-A9V5N<R!A=')A=NES(&1O($-L:6-K871E;&P@*&AT='`Z
M+R]C;&EC:V%T96QL+F-O;2DL('5S86YD;R!A($%022!(5%10`$5S=&4@8V]N
M=')O;&%D;W(@<&5R;6ET92!O(&5N=FEO(&1E(&UE;G-A9V5N<R!A=')A=NES
M(&1O('-M<S)M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2DL('5S86YD;R!A
M($%022!(5%10`$5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!O(&5N=FEO(&1E
M(&UE;G-A9V5N<R!V:6$@4TU44"!A=')A=NES(&1A(%9O9&%F;VYE($ETX6QI
M82!E(&%P96YA<R!P87)A(&[Z;65R;W,@5F]D869O;F4N($5X:6=E('5M82!C
M;VYT82!D92!C;W)R96EO(&5L96-T<O-N:6-O(&YA(%9O9&%F;VYE($ETX6QI
M82`H:'1T<#HO+W=W=RXQ.3`N:70I+@!%<W1E(&-A;7!O(.D@;V)R:6=A=/-R
M:6\N`$5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S(&EN=&5I<F]S+@!%
M<W1E(&-A;7!O('!O9&4@87!E;F%S(&-O;G1E<B!N^FUE<F]S(&4@;R!S[6UB
M;VQO(&1O:7,M<&]N=&]S+@!%<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA
M<R!V86QO<F5S(&]C=&%I<RX`17-T92!C86UP;R!T96T@9&4@8V]N=&5R('5M
M82!L:7-T82!D92!I;G1E:7)O<R!S97!A<F%D;W,@<&]R(&5S<&'G;W,@;W4@
M=NUR9W5L87,N`$5S=&4@8V%M<&\@=&5M(&1E('-E<B!U;2!N^FUE<F\@=N%L
M:61O+@!%<W1E(&-A;7!O('1E;2!D92!C;VYT97(@=6T@8_-D:6=O(&1E(&-O
M<B!N;R!F;W)M871O(%)'0B!H97AA9&5C:6UA;"P@<&]R(&5X96UP;&\@)R,Q
M,C,T868G+@!%<W1E(&9O<FUA=&\@9&4@9FEC:&5I<F\@;N-O(.D@<W5P;W)T
M861O+@!%<W1E(&UO9&5L;R!JX2!F;VD@<')O8V5S<V%D;RX`27-T;R#I("5S
M+@!%<W1E(.D@=6T@;V)J96-T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=F5R
M(&5S=&4@;V)J96-T;R!P<F5C:7-A(&1E('5M(&-L:65N=&4@9&4@8V]R<F5I
M;R!E;&5C='+S;FEC;R!Q=64@8V]N:&7G82!O(&9O<FUA=&\@2V]L86(@1W)O
M=7!W87)E+B!087)A('5M82!L:7-T82!D92!C;&EE;G1E<R!D92!C;W)R96EO
M(&5L96-T<O-N:6-O(&YE<W-A<R!C:7)C=6YS=.)N8VEA<R!V:7-I=&4@)7,`
M17-T82!M96YS86=E;2!F;VD@97-C<FET82!N=6T@8_-D:6=O("@E<RD@9&EF
M97)E;G1E(&1O('-E=2X`17-T92!N^FUE<F\@<')E8VES82!D92!S97(@<&5L
M;R!M96YO<R!U;2X`17-T92`B<V-R:7!T(B!T96T@<V5R(&5X96-U=&%D;R!A
M('!A<G1I<B!D92!U;6$@;&EN:&$@9&4@8V]M86YD;W,N`$5S=&4@<V5R=FED
M;W(@;N-O(&-O;G-E9W5E(&1E<V-O;7!R:6UI<B!A<G%U:79O<R!Z:7`@;W4@
M9WII<"X`17-T92!S:7-T96UA(&5N8V]N=')A+7-E(&1E<V%C=&EV861O+@!%
M<W1A('9A;&]R('1E;2!D92!S97(@=6T@;OIM97)O+@!%<W1A(&IA;F5L82!T
M96T@9&4@<V5R(&-H86UA9&$@82!P87)T:7(@9&4@=6UA(&IA;F5L82!D92!/
M<.?U97,`5')O=F]A9&$`0FEL:&5T97,`1&%T82](;W)A`%-E9W5I;65N=&\@
M5&5M<&]R86P`1F]R;6%T;R!D;R!T96UP;P!396QE8^?C;R!D871A+VAO<F$`
M5&EM;W(M3&5S=&4`5.UT=6QO`%3M='5L;R`H9&EC82DZ`%!A<F$`4&%R82!S
M96QE8V-I;VYA<B!M^FQT:7!L;W,@:71E;G,L(&-A<G)E9W5E(&5M($-O;G1R
M;VP@*%!#*2!O=2!#;VUM86YD("A-86,I(&5N<75A;G1O(&-L:6-A<BX`2&]J
M90!4<F]C87(@1F]N=&4@2%1-3`!297#Z8FQI8V$@5&]G;VQE<V$`5&]Q=65L
M874`06UA;FCC`%)E:6YO(&1O(%1O;F=A`%1O<&\`36]L9'5R82!D92!T;W!O
M("A?=&]P*0!4<F%D=7II9&%S`%1R861UY_5E<P!4<FEN9&%D92!E(%1O8F%G
M;P!697)D861E:7)O(&]U(&9A;'-O`#.J`%)E</IB;&EC82!D82!4=6[M<VEA
M`%)E</IB;&EC82!D82!4=7)Q=6EA`%1U<F-O("A)4T\M.#@U.2TY*0!4=7)Q
M=65M96YI<W3C;P!);&AA<R!4=7)C87,@92!#86EC;W,`5'5V86QU`$5S8W)E
M=F$@82!S=6$@97-C;VQH83H`S6YD:6-E(%4N5BXZ(`!54DP`55),(&1O('-E
M=2!R96QA=/-R:6\@9&4@97-T861O(&1O(&5N=FEO(&1E(")S8W)I<'1S(@!5
M4DPZ`%)E</IB;&EC82!D;R!59V%N9&$`56-RXFYI80!.XV\@9F]I('!O<W/M
M=F5L(&%C961E<B#@('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!A9&EC
M:6]N87(@:6YF;W)M8>?C;R!D92!U=&EL:7IA9&]R(&5X=')A(&%Q=6%N9&\@
M9&$@<W5B<V-R:>?C;RX`3N-O(&9O:2!P;W-S[79E;"!M=61A<B!A<R!P97)M
M:7-S]65S(&1O(&%R<75I=F\@5D93("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@
M;75D87(@87,@<&5R;6ES<_5E<R!D;R!A<G%U:79O(%9&4R`E<R\E<RX`3N-O
M(&9O:2!P;W-S[79E;"!M=61A<B!P87)A("5S+@!.XV\@9F]I('!O<W/M=F5L
M(&QI9V%R(&%O('-E<G9I9&]R(%-13"X`3N-O(&9O:2!P;W-S[79E;"!L:6=A
M<B!U<V%N9&\@4U-,+@!.XV\@9F]I('!O<W/M=F5L(&-O<&EA<B!O(&%R<75I
M=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@<&%S=&$@5D93("(E
M<R(N`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!P87-T82!61E,N`$[C;R!F
M;VD@<&]S<^UV96P@8W)I87(@;R!A<G%U:79O(%9&4RX`3N-O(&9O:2!P;W-S
M[79E;"!C<FEA<B!U;2!A<G%U:79O(%9&4R!V87II;RX`3N-O(&9O:2!P;W-S
M[79E;"!D97-C;VUP<FEM:7(@;W,@9&%D;W,N`$[C;R!F;VD@<&]S<^UV96P@
M<F5M;W9E<B`B)7,B+"!P;VES(&$@<&%S=&$@;N-O(&5S=.$@=F%Z:6$N`$[C
M;R!C;VYS:6=O(')E;6]V97(@(B5S(CH@)7,`3N-O(&9O:2!P;W-S[79E;"!R
M96UO=F5R("(E<R(Z("5S+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@)7,L
M('!O:7,@82!P87-T82!NXV\@97-TX2!V87II80!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@82!P87-T82!61E,@<F5C=7)S:79A;65N=&4N`$[C;R!F;VD@
M<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S[79E
M;"!R96UO=F5R(&$@<&%S=&$@5D93.B`E<RX`3N-O(&9O:2!P;W-S[79E;"!R
M96UO=F5R(&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!R
M96UO=F5R(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E
M<B!R96-U<G-I=F%M96YT93H@)7,N`$[C;R!F;VD@<&]S<^UV96P@9&5T97)M
M:6YA<B!A('!A<W1A(&-O<G)E;G1E+@!.XV\@9F]I('!O<W/M=F5L(&5X=')A
M:7(@;W,@<&]R;65N;W)E<R!D;R!C97)T:69I8V%D;P!);7!O<W/M=F5L(&QE
M<B!A(&1E9FEN:>?C;R!D92`E<RX`3N-O(&9O:2!P;W-S[79E;"!M;W9E<B!O
M(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@87)Q=6EV
M;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@
M5D93('!A<F$@97-C<FET82X`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&%R
M<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@87)Q=6EV;R!C
M;VUP<FEM:61O+@!.XV\@8V]N<VEG;R!L97(@;R!A<G%U:79O.B``3N-O(&9O
M:2!P;W-S[79E;"!L97(@82!P87-T82!V9G-R;V]T+@!.XV\@9F]I('!O<W/M
M=F5L(')E;F]M96%R("5S(&-O;6\@)7,Z(&$@<&%S=&$@9&4@9&5S=&EN;R!J
MX2!E>&ES=&4`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A('!A<W1A(%9&
M4RX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A('!A<W1A(%9&4SH@)7,N
M`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@;R!A<G%U:79O(%9&4R`B)7,B
M+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&\@87)Q=6EV;R!61E,@)7,O
M)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,N`$[C
M;R!F;VD@<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G+@!.XV\@9F]I('!O
M<W/M=F5L(&-O;G9E<G1E<B!E<W1E(&1O8W5M96YT;R!7;W)D`$[C;R!F;VD@
M<&]S<^UV96P@97-C<F5V97(@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P
M;W-S[79E;"!E<V-R979E<B!O(&%R<75I=F\@5D93("AC;W!Y*"D@9F%L:&]U
M*2X`3N-O(&-O;G-I9V\@<F5M;W9E<B`G)7,G.B`E<RX`4W5B;&EN:&%D;P!$
M97-F87IE<B!!;'1E<F'G]65S`$1E<V9A>F5R(&%L=&5R8>?U97,`1&5S9F%Z
M(&$@<W5A(/IL=&EM82!A8^?C;P!297-P;W-T82!I;F5S<&5R861A(&1O('-E
M<G9I9&]R(&YA(&-O;F5XXV\Z(`!297-P;W-T82!I;F5S<&5R861A(&1O('-E
M<G9I9&]R(&$Z(`!396T@8V%T96=O<FEA`%5N:6-O9&4@*%541BTX*0!%;6ER
M861O<R#!<F%B97,@56YI9&]S`%)E:6YO(%5N:61O`$5S=&%D;W,@56YI9&]S
M(&1A($%MZ7)I8V$`26QH87,@365N;W)E<R!$:7-T86YT97,@9&]S($5S=&%D
M;W,@56YI9&]S`%5N:61A9&5S`$1E<V-O;FAE8VED;P!A<&EM<V=I9"`H240@
M9&4@365N<V%G96T@9&4@05!)*2X`8VQI;7-G:60@9&5S8V]N:&5C:61O("A)
M1"!D92!-96YS86=E;2!D92!#;&EE;G1E*2X`0V]M86YD;R!D97-C;VYH96-I
M9&\Z("5S`$9O:2!F;W)N96-I9&$@=6UA(&QO8V%L:7IAY^-O(&1E<V-O;FAE
M8VED82X`3F]M92!D92!U=&EL:7IA9&]R(&]U('!A;&%V<F$M<&%S<V4@97)R
M861O<P!296UO=F5R(&QI9V'GXV\@9&\@96QE;65N=&\@8V]R<F5N=&4`4V5M
M(&YO;64`4&]R(')A>O5E<R!D92!S96=U<F%NYV$L(")S8W)I<'1S(B!S96T@
M<')I=FELZ6=I;R!NXV\@<&]D96T@86-E9&5R(&$@0V]R=&%R+T-O<&EA<B]#
M;VQA<B!P<F]G<F%M871I8V%M96YT92X@0V%R<F5G=64@96T@3TL@<&%R82!V
M97(@=6UA(&YO=&$@=.EC;FEC82!E;2!M;WII;&QA+F]R9R!Q=64@;&AE(&UO
M<W1R87+A(&-O;6\@875T;W)I>F%R('5M(")S8W)I<'0B(&$@86-E9&5R(&%O
M<R!R96-O<G1E<RX`4F5M;W9E<B!C;VQO<F'GXV\`5&EP;R!D92!C;VYT9?ID
M;R`H0V]N=&5N=&4M5'EP92D@;N-O('-U<&]R=&%D;RX`17AT96YSXV\@;N-O
M(%-U<&]R=&%D80!0;W(@=')A9'5Z:7(`36]D:69I8V%R`$%C='5A;&EZ87(@
M)7,`06-T=6%L:7IA<B!U=&EL:7IA9&]R`"(E<R(@86-T=6%L:7IA9&\N`$%C
M='5A;&EZ86YD;R!A<G%U:79O(&1E(&%J=61A("5S('!A<F$@)7,N`")38W)I
M<'0B(&1E(&%C='5A;&EZ8>?C;R!R96UO=FED;RX`57!L;V%D`$-A<G)E9V%D
M;W,@;F\@<V5R=FED;W(@=&]D;W,@;W,@87)Q=6EV;W,@9&4@:6YS=&%L8>?C
M;R!D92!A<&QI8V'G]65S+@!,971R87,@;&%T:6YA<R!E;2!M86GZ<V-U;&%S
M`$[Z;65R;W,@<F]M86YO<R!E;2!M86GZ<V-U;&%S`%)E</IB;&EC82!/<FEE
M;G1A;"!D;R!5<G5G=6%I`%5T:6QI>F'GXV\Z`%5S87(@;R!#;W)R96YT93H@
M)7,`57-A<B!34TPN`%5S87(@<V4@;R!N;VUE(&1E('5T:6QI>F%D;W(@;W4@
M82!P86QA=G)A+7!A<W-E(&9O<F5M(&1I9F5R96YT97,@;F\@<V5R=FED;W(@
M24U34"X`571I;&EZ861O<B`E<R!NXV\@97-TX2!A=71O<FES861O('!A<F$@
M)7,N`$%D;6EN:7-T<F'GXV\@9&4@571I;&EZ861O<F5S`$]PY_5E<R!D;R!5
M=&EL:7IA9&]R`%)E9VES=&\@9&4@571I;&EZ861O<F5S`$\@4F5G:7-T;R!D
M92!5=&EL:7IA9&]R97,@97-TX2!I;F%C=&EV;RX`4&5R;6ES<_5E<R!D;R!U
M=&EL:7IA9&]R`$YO;64@9&4@571I;&EZ861O<@!/($YO;64@9&4@571I;&EZ
M861O<B`B)7,B(&KA(&5X:7-T92X`3F]M92!D92!5=&EL:7IA9&]R.@!.;VUE
M(&1E(%5T:6QI>F%D;W(Z(`!5=&EL:7IA9&]R97,`571I;&EZ861O<F5S(&1O
M('-I<W1E;6$Z`%)E</IB;&EC82!D;R!5>F)E<75I<W3C;P!!('!A<W1A(%9&
M4R!NXV\@97AI<W1E+@!!=7/J;F-I80!!<R!L;V-A;&EZ8>?U97,@=N%L:61A
M<R!E;F-O;G1R861A<R!I;F-L=65M.@!686QI9&%D92X`5F%L;W(@96T@;6EN
M=71O<R!A('!A<G1I<B!D97-T92!I;G-T86YT92X`5F%L;W(@97AC961E(&\@
M8V]M<')I;65N=&\@;>%X:6UO(&1E("5S+@!686QO<F5S`%!O<W/M=F5L('9A
M;&]R97,@82!E<V-O;&AE<@!686YU871U`%9A<FGA=F5L`%9E;F5Z=65L80!6
M97)I9FEC8>?C;R!F86QH;W4@+2!E<W1A(&UE;G-A9V5M('!O9&4@=&5R('-I
M9&\@861U;'1E<F%D82X`5F5R<^-O`$-O;G1R;VQO(&1E(%9E<G/U97,`06QI
M;FAA;65N=&\@5F5R=&EC86P`0V%LYV\@5F5R=&EC86P`5F5R=&EC86PZ`$UU
M:71O($%L=&\`4F5P^F)L:6-A(%-O8VEA;&ES=&$@9&\@5FEE=&YA;64`5FEE
M=&YA;6ET82`H5DE30TE)*0!6:7-U86QI>F%R("5S`%9E<B!$971A;&AE<R!D
M82!.;W1A`%9E<B!U;6$@<.%G:6YA(&5X=&5R;F$`5FES=6%L:7IA<B!C;VUO
M("5S`$EL:&%S(%9I<F=E;G,@0G)I=.)N:6-A<P!);&AA<R!6:7)G96YS($%M
M97)I8V%N87,`5FES:6)I;&ED861E`%9I<VEB:6QI9&%D93H@`%9O9&%F;VYE
M($ETX6QI82!V:6$@4TU44`!!5DE3`$%414['PT\A(2$@4D5-3U9!($\@(E-#
M4DE05"(@34%.54%,345.5$4@1$4@)7,N`%=A;&QI<R!E($9U='5N80!!=FES
M;P!!=FES;SH@`#2J`%!R979I<^-O(&1O(%1E;7!O`$1A9&]S(&UE=&5O<F]L
M\V=I8V]S(&9O<FYE8VED;W,@<&]R`%=E871H97(N8V]M`%=E8@!0X6=I;F$`
M4V5M86YA;&UE;G1E`$)E;2UV:6YD82AO*0!"96TM=FEN9&$H;RD@82`E<P!"
M96TM=FEN9&$H;RDL("5S`$]C:61E;G1A;"`H25-/+3@X-3DM,2D`3V-I9&5N
M=&%L("A)4T\M.#@U.2TQ-2D`4V%A<F$`475E(&%P;&EC8>?C;R!D979E(&\@
M)7,@;6]S=')A<B!A</-S(&$@96YT<F%D83\`475A;"#I(&\@8V%R86-T97)E
M(&1E;&EM:71A9&]R/P!1=6%L(.D@;R!C87)A8W1E<F4@9&4@8VET8>?C;S\`
M02!Q=64@3&EV<F\@9&4@3F]T87,@<V4@9&5V92!A9&EC:6]N87(@87,@;F]T
M87,_`%%U92!F87-E<P!1=64@(G!L=6=I;G,B(&%C=&EV87(@<&%R82!A($5D
M:>?C;R!2:6-A+@!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D97,@0U-3`$QA
M<F=U<F$@9&\@365N=2`E<R#@(&5S<75E<F1A("AT96T@969E:71O(&YA('!R
M\WAI;6$@96YT<F%D82DZ`$QA<F=U<F$@9&$@=&%B96QA`%5N:61A9&4@9&4@
M;&%R9W5R80!,87)G=7)A.@!7:6MI`%9E;G1O`%9E;G1O($UA=&EN86P`5F5L
M;V-I9&%D92!D;R!V96YT;R!E;2!N\W,`5F5N=&\Z`%9E;G1O.B``4V%B961O
M<FEA`$QI<W1A<R!D92!$97-E:F]S`%1R86)A;&AO`$5N9&5R9>=O("A%;7!R
M96=O*0!496QE9F]N92`H16UP<F5G;RD`17-C<F5V96YD;R!A<G%U:79O(&1E
M(&%J=61A(&%C='5A;&EZ861O('!A<F$@)7,N`%)E9F5RZFYC:6%S(&-R=7IA
M9&%S`%)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y=C,`571I;&EZ8>?C;R!D92!#
M:&%V92!%>'1E;F1I9&$@6#4P.78S`$YO;64@06QT97)N871I=F\@9&4@4W5J
M96ET;R!8-3`Y=C,`261E;G1I9FEC861O<B!#:&%V92!D92!3=6IE:71O(%@U
M,#EV,P!%>'1E;G/U97,@6#4P.78S`$%!`$%!04$`36%P82!986AO;R$`06YU
M86QM96YT90!)Z6UE;@!3:6T`4VEM+"!#;VYC;W)D;P!%<W3A(&5M($U/1$\@
M9&4@5$585"X@(%5S92!O(&)O=.-O(%L\/ET@<&%R82!T<F]C87(@<&%R82!O
M(&UO9&\@5DE354%,+@!.XV\@97-TX2!A=71E;G1I8V%D;RX`3N-O('!O9&4@
M=&5R(&\@8V%R86-T97)E("=<)R!N;R!S974@;F]M92!C;VUP;&5T;RX`3N-O
M(&EN=')O9'5Z:74@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC
M;R!VX6QI9&\N`$[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R<75I=F\@
M:6UP;W)T861O('!A<F$@;W,@8V%M<&]S(&-O<G)E<W!O;F1E;G1E<R!E;2`E
M<RX`3N-O('1E;2!P97)M:7-SXV\@<&%R82!V97(@;R!L:79R;R!D92!N;W1A
M<R`E<RX`06-A8F]U(&1E('-A:7(N`%1E;2!D92!I;G1R;V1U>FER('5M(&[Z
M;65R;R!D92!T96QE;?-V96P@=N%L:61O+"!S\R!C;VT@9.UG:71O<RP@;6%S
M(&-O;2!U;2`G*R<@;W!C:6]N86P@<&%R82!O('!R969I>&\@:6YT97)N86-I
M;VYA;"X`5&5M(&1E(&EN=')O9'5Z:7(@=6T@=F%L;W(@=N%L:61O+@!496T@
M9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@8N%S:6-O('!A<F$@1&%T851R
M964@<V4@<75I<V5R('5S87(@4W5B<V-R:>?U97,`5&5M(&1E(&-O;F9I9W5R
M87(@=6T@;65C86YI<VUO(&)A<V4@<&%R82!O(%9&4RX`1&5V92!D97-C<F5V
M97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R:6\N`%1E
M;2!D92!I;G1R;V1U>FER(&\@55),(&1O(')E8W5R<V\@<75E(&5S=&$@;&EG
M8>?C;R!S92!R969E<F4`5&5M(&1E('-E;&5C8VEO;F%R(&\@;&EV<F\@9&4@
M;F]T87,@82!R96UO=F5R+@!496T@9&4@<V5L96-C:6]N87(@=6T@<V5R=FED
M;W(@82!R96UO=F5R+@!$979E(&5S<&5C:69I8V%R(&\@=71I;&EZ861O<B!A
M(&QI;7!A<BX`1&5V92!E<W!E8VEF:6-A<B!O(&YO;64@9&\@=71I;&EZ861O
M<B!A(')E;6]V97(N`%1E;2!D92!E<W!E8VEF:6-A<B!O(&YO;64@9&\@=71I
M;&EZ861O<B!A(&%D:6-I;VYA<BX`5&5M(&1E(&5S<&5C:69I8V%R(&\@=71I
M;&EZ861O<B!A(&%C='5A;&EZ87(N`%1E;2!D92!E<W!E8VEF:6-A<B!A(&%C
MY^-O(&$@9&5S96UP96YH87(N`%1E;2!D92!I;G1R;V1U>FER('5M(&YO=F\@
M;F]M92!D92!C871E9V]R:6$N`%1E;2!D92!F;W)N96-E<B!U;2!N^FUE<F\@
M9&4@=&5L969O;F4@:71A;&EA;F\`02!S=6$@<V5S<^-O("5S(&5X<&ER;W4N
M(%!O<B!F879O<B!E;G1R92!D92!N;W9O+@!/('-E=2!%;F1E<F7G;R!D92!#
M;W)R96EO($5L96-T<O-N:6-O.@!/('-E=2!E;F1E<F7G;R`B1&4Z(@!!('-U
M82!);F9O<FUAY^-O`$\@<V5U(&5N9&5R9>=O($E0('!A<F5C92!T97(@;75D
M861O(&1E<V1E(&\@:6[M8VEO(&1A('-E<W/C;R`E<RX@4&%R82!G87)A;G1I
M<B!A('-U82!S96=U<F%NYV$L(&1E=F4@875T96YT:6-A<BUS92!D92!N;W9O
M+@!/(%-E=2!.;VUE`$\@<V5U(&UE8V%N:7-M;R!D92!A=71E;G1I8V'GXV\@
M;N-O('-U<&]R=&$@861IY^-O(&1E('5T:6QI>F%D;W)E<R!O=2!E<W1A(&]P
MY^-O(&9O:2!D97-A8W1I=F%D82!P;W(@86QG=6T@;W5T<F\@;6]T:79O+@!/
M('-E=2!M96-A;FES;6\@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&QI
M<W1A9V5M(&1E('5T:6QI>F%D;W)E<R!O=2!E<W1A(&]PY^-O(&9O:2!D97-A
M8W1I=F%D82!P;W(@86QG=6T@;W5T<F\@;6]T:79O+@!/('-E=2!N879E9V%D
M;W(@<&%R96-E('1E<B!M=61A9&\@9&5S9&4@;R!I;NUC:6\@9&$@<V5S<^-O
M("5S+B!087)A(&=A<F%N=&ER(&$@<W5A('-E9W5R86[G82P@9&5V92!A=71E
M;G1I8V%R+7-E(&1E(&YO=F\N`$\@<V5U(&YA=F5G861O<B!NXV\@<W5P;W)T
M82!E<W1A(&9U;F-I;VYA;&ED861E+@!/('-E=2!N879E9V%D;W(@;N-O('-U
M<&]R=&$@97-T82!O<.?C;R!D92!I;7!R97-SXV\N(%!R97-S:6]N92!#;VYT
M<F]L+T-O;6UA;F0@*R!0('!A<F$@:6UP<FEM:7(N`$9U<V\@:&]RX7)I;R!A
M8W1U86PZ`$ED96YT:61A9&4@<&%D<N-O.@!/('-E=2!L:79R;R!D92!N;W1A
M<R!P;W(@;VUI<W/C;SH`3F]M92!C;VUP;&5T;P!!('-U82!V97)SXV\@9&\@
M9V5T=&5X="#I(&1E;6%S:6%D;R!A;G1I9V$L(&[C;R!S=7!O<G1A;F1O(%!(
M4"!D92!F;W)M82!N871I=F$N($YE;2!T;V1A<R!A<R!C861E:6%S(&1E(&-A
M<F%C=&5R97,@<V5RXV\@97AT<F'M9&%S+@!!('-U82!N;W9A('!A;&%V<F$M
M<&%S<V4@<&%R82`E<R#I.B`E<P!/<R!S975S($QI=G)O<R!D92!.;W1A<SH`
M07,@<W5A<R!O<.?U97,@9F]R86T@86QT97)A9&%S(&%TZ2!A;R!F:6YA;"!D
M97-T82!S97-SXV\N`$%S('-U87,@;W#G]65S(&9O<F%M(&%C='5A;&EZ861A
M<RX`02!S=6$@<&%L879R82UP87-S92!F;VD@<F5C<FEA9&$`02!S=6$@<&%L
M879R82UP87-S92!F;VD@<F5C<FEA9&$L('9E<FEF:7%U92!O('-E=2!C;W)R
M96EO(&5L96-T<O-N:6-O(&4@96YT<F4@8V]M(&$@<W5A(&YO=F$@<&%L879R
M82UP87-S92X`3W,@<V5U<R!S97)V:61O<F5S(')E;6]T;W,Z`$IU9V]S;.%V
M:6$`6F%I<F4`6N)M8FEA`%II;6)A8G7I`%II<'!Y`%M%<V-O;F1E<B!497AT
M;R!#:71A9&]=`%M296QA=/-R:6\@9&4@4')O8FQE;6%S72``6TUO<W1R87(@
M5&5X=&\@0VET861O("T`6TUO<W1R87(@5&5X=&\@0VET861O("T@)7,@;&EN
M:&%S70!;;&EN:&$@)7,@9&4@)7-=`%]!9&UI;FES=')AY^-O`%]6;VQT87(@
M86\@3&EV<F\@9&4@3F]T87,`7T-O;G-O;&$`7T-A=&5G;W)I80#!<E]V;W)E
M`%]296UO=F5R`%]296UO=F5R($QI;FAA`%]%9&ET87(`4')I7VUE:7)A($QI
M;FAA`%]'<G5P;W,`05]J=61A`%!R;W!R:65D861E<R!D82!?26UA9V5M`%])
M;7!O<G1A<B]%>'!O<G1A<@!?3&ES=&%R($YO=&%S`%]%;G1R87(`7U-A:7(`
M7TUO9&EF:6-A<B!,:6=AY^-O`$]S(%]-975S($QI=G)O<R!D92!.;W1A<P!?
M3F]V82!.;W1A`%]/<.?U97,`7U!E<FUI<W/U97,`26U?<')I;6ER`%]296UO
M=F5R($QI9V'GXV\N+BX`7U!R;V-U<F%R`%]#;VYF:6=U<F'GXV\`4')O<')I
M961A9&5S(&1A(%]486)E;&$`7U5T:6QI>F%D;W)E<P!C;VYT86-T;W,`;V-O
M<G)E=2!U;2!E<G)O.@!C86QE;F3A<FEO`&-A;&UO`&-L:7%U92!A<75I`&9E
M:71O`&9A;&AO=0!D:6UI;G5I;F1O`&9I8VAE:7)O`&5N8V]N=')A9&\Z(`!D
M;R`E<R`H)7,I(.!S("5S("5S`')A:F%D87,`:#H`:&@`:6UE9&EA=&\`96T@
M;&EN:&$`;&EN:&%S70!%<G)O(&UK:7-O9G,@8V]M(&/S9&EG;R`E9"!A;R!C
M;VYS=')U:7(@25-/+@!M;0!N;VUE`'-E;2!A;'1E<F'G]65S`&[C;R!E;F-O
M;G1R861O`&[C;R!I;7!L96UE;G1A9&$`86EN9&$@<&]R(&EM<&QE;65N=&%R
M`&-A9&5R;F\@9&4@;F]T87,`;F]T87,N8W-V`'!E<F-E;G1A9V5M`'#M>&5I
M<P!S=6)I;F1O`&UO<W1R87(@9&EF97)E;N=A<P!S;7,R96UA:6P@=FEA($A4
M5%``<W,`97-TX79E;`!L:7-T82!D92!T87)E9F%S`$\@9FEC:&5I<F\@4$\@
M<&%R82!O(&QO8V%L92`E<R!NXV\@97AI<W1E+@!I;G1R;V1U>F$@82!P86QA
M=G)A+7!A<W-E(&1U87,@=F5Z97,L('!A<F$@8V]N9FER;6'GXV\`=6YI9FEC
M861O`'-E;2!N;VUE`&%C='5A;&EZ861O`'-E;&5C8VEO;F%D82!P96QO('5T
M:6QI>F%D;W(`=D-A<F0`=DYO=&4`4F5E;F,Z`'=E871H97(N8V]M````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O<F]?4D\O
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S0U`#`R,#`Q-P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN
M96UO+VQO8V%L92]R;U]23R],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#4`,#(Q-C`T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+W)O7U)/+TQ#7TU%4U-!1T53
M+VUN96UO+FUO```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C,P-0`Q,#0Q-S,V,C<T
M-0`P,C,R-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````!]````'`````0$``"G````[`<```````"("@``"```
M`(D*```H````D@H```8```"["@``"````,(*```%````RPH```@```#1"@``
M$0```-H*```'````[`H```4```#T"@``'P```/H*```)````&@L``!$````D
M"P``#P```#8+```(````1@L```@```!/"P``%0```%@+```(````;@L```H`
M``!W"P``+0```((+```*````L`L```P```"["P``!P```,@+```I````T`L`
M``(```#Z"P``!0```/T+```0`````PP``!D````4#```&@```"X,```&````
M20P```H```!0#```%````%L,```O````<`P```\```"@#```)@```+`,```%
M````UPP```T```#=#```!0```.L,```0````\0P``!`````"#0``#P```!,-
M```+````(PT```\````O#0``#````#\-```/````3`T``!X```!<#0``(0``
M`'L-```#````G0T```0```"A#0``#````*8-```*````LPT```4```"^#0``
M$@```,0-```0````UPT```@```#H#0``$````/$-```&`````@X```<````)
M#@```@```!$.```$````%`X```\````9#@``!P```"D.```,````,0X```<`
M```^#@``!````$8.```%````2PX```@```!1#@``"````%H.```-````8PX`
M``P```!Q#@``"0```'X.```%````B`X```<```".#@``$0```)8.```-````
MJ`X```@```"V#@``'@```+\.```%````W@X``"@```#D#@``*0````T/```3
M````-P\```P```!+#P``"P```%@/```1````9`\```0```!V#P``#````'L/
M```&````B`\```X```"/#P``#````)X/```:````JP\``!<```#&#P``%P``
M`-X/```;````]@\``!\````2$```$P```#(0```0````1A```!````!7$```
M%P```&@0```'````@!````4```"($```(0```(X0```<````L!````4```#-
M$````P```-,0```@````UQ```"8```#X$```#````!\1```'````+!$```P`
M```T$0``"````$$1```'````2A$```8```!2$0``#0```%D1```+````9Q$`
M``P```!S$0``"@```(`1```"````BQ$```8```".$0``10```)41```P````
MVQ$``!`````,$@``'P```!T2```0````/1(```\```!.$@``!0```%X2``!=
M`0``9!(```<```#"$P``*````,H3```&````\Q,```D```#Z$P``!0````04
M```/````"A0``!4````:%```!@```#`4```%````-Q0``",````]%```"0``
M`&$4```4````:Q0``!$```"`%```#P```)(4```(````HA0``!$```"K%```
M"0```+T4```-````QQ0``"P```#5%```#P````(5```1````$A4```@````D
M%0``*````"T5```"````5A4```8```!9%0``%````&`5```=````=14``!X`
M``"3%0``!@```+(5```,````N14``!````#&%0``,0```-<5```/````"18`
M`"<````9%@``!0```$$6```9````1Q8```8```!A%@``$P```&@6```4````
M?!8``!,```"1%@``%````*46```3````NA8``!````#.%@``$@```-\6```9
M````\A8``"8````,%P```P```#,7```$````-Q<```\````\%P``$@```$P7
M```%````7Q<``!$```!E%P``$@```'<7```%````BA<``!H```"0%P``"0``
M`*L7```+````M1<```(```#!%P``#0```,07```=````TA<```4```#P%P``
M#0```/87```%````!!@```0````*&```"0````\8```)````&1@```L````C
M&```$0```"\8```,````01@```D```!.&```!````%@8```'````71@```\`
M``!E&```#````'48```&````@A@``"(```")&```!P```*P8```G````M!@`
M`#````#<&```%`````T9```3````(AD```\````V&0``$0```$89```0````
M6!D```\```!I&0``!P```'D9```1````@1D```P```"3&0``%````*`9```<
M````M1D``!L```#2&0``(@```.X9```;````$1H``!@````M&@``%0```$8:
M```6````7!H``!8```!S&@``!@```(H:```'````D1H``!8```"9&@``*```
M`+`:```%````V1H```,```#?&@``(@```.,:```N````!AL``!0````U&P``
M"P```$H;```2````5AL```H```!I&P``!P```'0;```*````?!L``!P```"'
M&P``$0```*0;```2````MAL``!,```#)&P```@```-T;```%````X!L``#H`
M``#F&P``.P```"$<```6````71P``!H```!T'```$0```(\<```1````H1P`
M`!$```"S'````0```'``````````9@```%P`````````;P```$0```!]````
M,````&L```!C````5P```!X````O````70````<```!X`````````'H```!;
M````````````````````````````````````1@```#D```!N````7P```#4`
M```2````:````%4```!G`````````%$````B````#0`````````H````````
M`#H```!+`````````!L```!I````<@````D```!#````2``````````A````
M;``````````1`````````",```!:````````````````````<0````\`````
M````)P```!<````%`````````',```!V````'0```"H```!2````=````!@`
M```:`````````#0```!M`````P```"````!)````,@```#\`````````?```
M`#8```!W````'P```#T```![````9````$(````.````4````'4````6````
M3@```'D```!,````8````!``````````)0```&H`````````!````$H`````
M````10```%X````````````````````K````$P```%,```!8````#````#@`
M```D`````````$<````5```````````````[````!@`````````"````````
M```````^````00````````!-````'````&(````S````+`````@```!A````
M%````$\````*````+0`````````F``````````L````I````90```!D````W
M``````````````!9````0````%0``````````````#P````N````,0```%8`
M````)60@;F]T97,`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;@`Q(&YO=&4`,C0@:&]U<G,`04TO4$T`061D('!A:7(`061D:6YG
M($$@3F5W($YO=&4`061D<F5S<P!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%S8V5N9&EN9P!!=F%I;&%B;&4@9FEE;&1S.@!"86-K
M('1O($YO=&5P860`0FER=&AD87D`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A=&5G;W)Y`$-E;&P@4&AO;F4`0VAA;F=E('EO=7(@;F]T92!S
M;W)T:6YG(&%N9"!D:7-P;&%Y(&]P=&EO;G,N`$-L96%R($9O<FT`0VQO<V4@
M5VEN9&]W`$-O;7!A;GD`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&5F875L="!)9&5N=&ET>0!$969A=6QT
M('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ
M`$1E;&5T90!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I
M<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`2&5L<`!(;VUE($%D9')E
M<W,`2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T
M960@9FEE;&1S.@!,86YG=6%G90!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,
M;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`36]D:69Y
M:6YG("5S`$UO;G1H;'D`3F%M90!.979E<@!.97<@3F]T90!.;R!N;W1E<P!.
M;W1E($-A=&5G;W)Y`$YO=&4@1&5T86EL<P!.;W1E(%1E>'0`3F]T97,`3W!T
M:6]N<P!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`%!A<W-W;W)D
M`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4F5F<F5S:"!,:7-T`%)E;6]V92!P86ER`%)E='5R;B!T;R!/<'1I
M;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E87)C:`!396%R8V@@4F5S=6QT<P!3
M96%R8V@@4V-O<&4`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3:VEP($UA:6YT96YA
M;F-E`%-O<G0@8GD@0V%T96=O<GD`4W!E8VEA;"!#:&%R86-T97(@26YP=70`
M4W5C8V5S<P!487-K<P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:71L90!54DP`56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5N9FEL960`
M57-E<B!/<'1I;VYS`%5S97)N86UE`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`
M665A<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O
M<FUA=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B
M;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M260M
M5F5R<VEO;CH@36YE;6\@,2XQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP,BTR."`P,CHR
M.2LP,C`P"DQA<W0M5')A;G-L871O<CH@175G96X@2&]A;F-A(#QE=6=E;FA`
M=7)B86XM9W)A9G@N<F\^"DQA;F=U86=E+51E86TZ(%)O;6%N:6%N(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`)60@;F]T90`E<R!/<&5R871I=6YI
M(&1E(&UE;G1E;F%N=&$@+2!#;VYF:7)M87)E`#$@;F]T80`R-"!D92!O<F4`
M04TO4$T`061A=6=A('!E<F5C:&5A`$%D875G87)E(&1E(&YO=&$@;F]U80!!
M9')E<V$`06QI87,`4RUA('-P96-I9FEC870@;R!V86QO87)E(&EN8V]R96-T
M82X`0W)E<V-A=&]R`$-I;7!U<FD@9&ES<&]N:6)I;&4Z`$EN87!O:2!I;B!.
M;W1E<&%D`%II=6$@9&4@;F%S=&5R90!#86QE;F1A<@!296YU;G1A(&QA(%)A
M<&]R=`!#871E9V]R:64`5&5L969O;B!-;V)I;`!38VAI;6)A<F4@<V]R=&%T
M92!D92!N;W1E('-H:2!O<'1I=6YI(&%F:7-A:@!3=&5R9V4@1F]R;75L87(`
M26YC:&ED92!F97)E87-T<F$`0V]M<&%N:6$`3G4@<&]T(&1E<V-H:61E(&UO
M9'5L=6P@9&4@365N=&5N86YT82`E<P!:6@!::6QN:6,`261E;G1I=&%T92!)
M;7!L:6-I=&$`0W)I=&5R:74@9&4@<V]R=&%R92!I;7!L:6-I=#H`1&ER96-T
M:64@9&4@<V]R=&%R92!I;7!L:6-I=&$Z`%-T97)G90!$97-C<F5S8V%T;W(`
M1&5S8W)I92!P<F]B;&5M80!$971A;&EI(&EN<F5G:7-T<F%T92!I;B!,3T<@
M<&5N=')U(&%D;6EN:7-T<F%T;W(N`$]P=&EU;FD@869I<V%R90!492!R;V<@
M;G4@86-C97-A(&1I<F5C="!M86EN=&5N86YC92YP:'``16UA:6P`16UP='D@
M<F5S=6QT+B`M(&1E('1R861U<P!%<F]A<F4`3R!D871A(&QA(#$U(&UI;G5T
M90!/(&1A=&$@;&$@,S`@<V5C=6YD90!,82!F:65C87)E(#4@;6EN=71E`$QA
M(&9I96-A<F4@0V]N96-T87)E`$\@9&%T82!L82`S,"!M:6YU=&4`26X@9FEE
M8V%R92!M:6YU=`!%>&5M<&QE(&1E('9A;&]R:3H`3G4@<&]T(&-I=&D@<')E
M9F5R:6YT96QE+@!.=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,
M1$%0+@!&87@`2&5L<`!!9')E<V$@9&4@86-A<V$`5&5L969O;G5L(&1E(&%C
M87-A`$AO<F1E`$-I;7`@:6UP;W)T870Z("5S`$-I;7!U<FD@:6UP;W)T871E
M.@!,:6UB80!,:7-T82!S=6)I96-T96QO<B!D:6X@2&5L<`!#;VYE8W1A<F4`
M1&5C;VYE8W1A<F4`3$P`0V]R97-P;VYD96YT80!#:6UP=7)I('!O=')I=FET
M92`M(&1E('1R861U<P!-97-A:@!-;V1I9FEC87)E("5S`$QU;F%R`$YU;64`
M3FEC:6]D871A`$YO=&$@;F]U80!.:6-I(&\@;F]T80!#871E9V]R:64@9&4@
M;F]T90!$971A;&EI(&YO=&$`5&5X="!N;W1A`$YO=&4`3W!T:75N:0!!;'1E
M(&EN9F]R;6%T:6D`06QT92!O<'1I=6YI`%!A<F]L80!%>&5C=71A($]P97)A
M=&EU;FEL92!D92!-96YT96YA;G1A`%1E;&5F;VX`5&4@<F]G('-P96-I9FEC
M82!U;B!S=6UA<B!A;"!P<F]B;&5M96DN`%1E(')O9R!I;G1R;V1U('5N(&YU
M;64@9&4@=71I;&EZ871O<B!S:2!O('!A<F]L80!$97-C<FEE<F5A('!R;V)L
M96UE:0!);7!R;W-P871E87IA(&QI<W1A`%-T97)G92!P97)E8VAE80!);F%P
M;VD@;&$@;W!T:75N:0!2;VQE("T@9&4@=')A9'5S`%-A;'9A>F$@3W!T:75N
M:0!#875T87)E`%)E>G5L=&%T92!C875T87)E`%-C;W`@8V%U=&%R90!$96QI
M;6ET871O<B!D92!D871A.@!&;W)M871U;"!D92!A9FES87)E(&$@9&%T96DZ
M`$9O<FUA='5L(&1E(&%F:7-A<F4@82!O<F5I.@!396QE8W1E87IA(&1O=6$@
M8VEM<'5R:2!P;W1R:79I=&4N`%-E;&5C=&5A>F$@;&EM8F$@<')E9F5R871A
M.@!4<FEM:71E(%)A<&]R="!D92!%<F]A<F4`4V%R:2!P97-T92!-96YT96YA
M;G1A`%-O<G1A<F4@9'5P82!C871E9V]R:64`0V%R86-T97)E(%-P96-I86QE
M("XN+@!3=6-C97,`4V%R8VEN:0!686QO87)E82!M:6YI;6$@97-T92`Q`$%C
M96%S=&$@=F%L;V%R92!T<F5B=6EE('-A(&9I92!N=6UE<FEC82X`5&ET;'4`
M55),`$YU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"X`3G4@<&]T
M('1R861U8V4@86-E<W0@9&]C=6UE;G0@5V]R9"`M(&1E('1R861U<P!!;G5L
M96%Z82!38VAI;6)A<FEL90!.96-O;7!L971A=`!/<'1I=6YI(%5T:6QI>F%T
M;W(`571I;&EZ871O<@!!=&5N=&EE`%-A<'1A;6EN86P`0FEN92!A:2!V96YI
M="!I;B!S:7-T96UU;"`E<P!":6YE(&%I('9E;FET+"`E<P!!9')E<V$@;&$@
M4V5R=FEC:74`5&5L969O;B!L82!397)V:6-I=0!!00!!;G5A;`!4<F5B=6EE
M('-A(&1E<V-R:6D@<')O8FQE;6$@:6YA:6YT92!D92!A('1R:6UI=&4@<F%P
M;W)T=6PN`%-E<VEU;F5A('1A(&1E("5S(&$@97AP:7)A="X@5&4@<F]G('-A
M(&9A8VD@3&]G($EN(&1I;B!N;W4N`$EN9F]R;6%T:6D@9&5S<')E('1I;F4`
M3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T92X`6U)A<&]R="!0<F]B;&5M85T`
M6VQI;FEA("5S(&1I;B`E<UT`=D-A<F0@+2!D92!T<F%D=7,`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O<G5?4E4O````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S0U`#`R,#`S,P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L
M92]R=5]252],0U]-15-304=%4R\`````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-#4`,#(Q-C(P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;6YE;6\O;&]C86QE+W)U7U)5+TQ#7TU%4U-!1T53+VUN96UO+FUO
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`U-#0Q-P`Q,#0Q-S,V,C<T-0`P,C,S,#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````!Z`0``'````.P+``#]`0``O!<```````"P'P``"````+$?```H````
MNA\```T```#C'P``'0```/$?```,````#R````8````<(```#@```",@```.
M````,B````@```!!(```!0```$H@```<````4"```!X```!M(```(````(P@
M```=````K2```!,```#+(````P```-\@```)````XR````P```#M(```"```
M`/H@```D`````R$``!$````H(0``!P```#HA```,````0B$``"P```!/(0``
M#@```'PA```%````BR$``!<```"1(0``"@```*DA```/````M"$``",```#$
M(0``%````.@A```7````_2$``!<````5(@``'P```"TB```+````32(``!4`
M``!9(@``"0```&\B```Y````>2(``"P```"S(@``*@```.`B```1````"R,`
M``\````=(P``%P```"TC```(````12,```X```!.(P``"@```%TC```#````
M:",```@```!L(P``!@```'4C```5````?",``!4```"2(P``"````*@C```*
M````L2,```8```"\(P``5````,,C```M````&"0``$0```!&)```$P```(LD
M```<````GR0``!P```"\)```"@```-DD```,````Y"0``!````#Q)```!P``
M``(E```=````"B4``"D````H)0``!@```%(E```0````624```<```!J)0``
M$P```'(E```,````AB4``"@```"3)0```@```+PE```%````OR4```0```#%
M)0``#0```,HE```0````V"4```\```#I)0``&0```/DE```:````$R8```8`
M```N)@``$P```#4F```7````228``!@```!A)@``$````'HF```*````BR8`
M`!0```"6)@``#````*LF```O````N"8```D```#H)@``%@```/(F```/````
M"2<``"8````9)P``*````$`G``!#````:2<```@```"M)P``"P```+8G```$
M````PB<```H```#')P``"0```-(G```7````W"<``!$```#T)P``!0````8H
M```*````#"@```T````7*```(````"4H```%````1B@``!````!,*```#P``
M`%TH```0````;2@```\```!^*```"P```(XH```/````FB@```P```"J*```
M#P```+<H```&````QR@```8```#.*```#````-4H```*````XB@``!X```#M
M*```(0````PI```#````+BD```0````R*0``#````#<I```'````1"D``!``
M``!,*0``#P```%TI```.````;2D```(```!\*0``#0```'\I```&````C2D`
M`!$```"4*0``!P```*8I```$````KBD```H```"S*0``(@```+XI```%````
MX2D```0```#G*0``#````.PI```*````^2D```4````$*@``"@````HJ```/
M````%2H``!`````E*@``!@```#8J```5````/2H```\```!3*@``$P```&,J
M```2````=RH``!````"**@``$````)LJ```'````K"H```@```"T*@``#0``
M`+TJ```.````RRH``!8```#:*@``$0```/$J```&`````RL``!`````**P``
M#P```!LK```(````*RL```8````T*P``!P```#LK```%````0RL```L```!)
M*P```@```%4K```$````6"L``&@```!=*P``#P```,8K```*````UBL```<`
M``#A*P``#````.DK```'````]BL```L```#^*P``"0````HL```)````%"P`
M``H````>+```!P```"DL```)````,2P```<````[+```"@```$,L```6````
M3BP```@```!E+```!````&XL```%````<RP```P```!Y+```"````(8L```$
M````CRP```0```"4+```#````)DL```"````IBP```@```"I+```)````+(L
M```)````URP```4```#A+```!````.<L```3````["P```T`````+0``#```
M``XM```)````&RT```H````E+0``"````#`M```/````.2T```@```!)+0``
M&@```%(M```%````;2T```T```!S+0```@```($M```'````A"T```X```",
M+0``"@```)LM```1````IBT```T```"X+0``"````,8M```)````SRT```H`
M``#9+0``'@```.0M```H`````RX```H````L+@``"P```#<N```4````0RX`
M``4```!8+@``*0```%XN```H````B"X``"D```"Q+@``$````-LN```'````
M["X``!,```#T+@``!`````@O```'````#2\``!X````5+P``#````#0O```4
M````02\```X```!6+P``*@```&4O```&````D"\```P```"7+P``"P```*0O
M```%````L"\``!$```"V+P``&````,@O```$````X2\```0```#F+P``#```
M`.LO```&````^"\```X```#_+P``#`````XP```,````&S```!`````H,```
M#P```#DP```*````23````L```!4,```&@```&`P```7````>S```!D```"3
M,```&@```*TP```E````R#```"<```#N,```%P```!8Q```;````+C$``!D`
M``!*,0``'P```&0Q```3````A#$``#\```"8,0``-P```-@Q``!7````$#(`
M``4```!H,@``#0```&XR```M````?#(```0```"J,@``#@```*\R```4````
MOC(``"4```#3,@``$@```/DR```@````##,``!\````M,P``'0```$TS```&
M````:S,```0```!R,P``$````'<S```3````B#,``!<```"<,P``!@```+0S
M```'````NS,```8```##,P``!P```,HS```8````TC,``#0```#K,P``%0``
M`"`T```.````-C0```4```!%-```"0```$LT```5````530``"@```!K-```
M(@```)0T```B````MS0``"````#:-```(0```/LT```?````'34``!\````]
M-0``,````%TU```O````CC4``"$```"^-0``'````.`U```'````_34```L`
M```%-@``!0```!$V```"````%S8``%D````:-@```P```'0V```@````>#8`
M`"0```"9-@``)@```+XV```,````Y38```P```#R-@``!P```/\V```&````
M!S<``#(````.-P``!````$$W```,````1C<```@```!3-P``"0```%PW```*
M````9C<```<```!Q-P``&0```'DW```'````DS<```,```";-P``!@```)\W
M```-````IC<```L```"T-P``+P```,`W```,````\#<``#$```#]-P``/P``
M`"\X```,````;S@```H```!\.````@```(<X```&````BC@```,```"1.```
M&0```)4X``!%````KS@``#````#U.```$@```"8Y```3````.3D``!````!-
M.0``"0```%XY```7````:#D``!8```"`.0``%0```)<Y```/````K3D```X`
M``"].0``'P```,PY```4````[#D``!`````!.@``#P```!(Z```/````(CH`
M`!`````R.@``"0```$,Z```'````33H```4```!5.@``"P```%LZ```'````
M9SH```4```!O.@``#@```'4Z```+````A#H```@```"0.@``#````)DZ```)
M````ICH```@```"P.@``#````+DZ```&````QCH```<```#-.@``!@```-4Z
M```&````W#H```0```#C.@``!P```.@Z```%````\#H``%P!``#V.@``"@``
M`%,\```E````7CP```<```"$/```'````(P\```/````J3P```D```"Y/```
M"@```,,\```*````SCP```<```#9/```!0```.$\```Q````YSP``#4````9
M/0``(@```$\]```L````<CT```X```"?/0``"````*X]```)````MST```\`
M``#!/0``#0```-$]```8````WST``!@```#X/0``!0```!$^```.````%SX`
M`#,````F/@``"@```%H^```)````93X```P```!O/@``"@```'P^```)````
MASX``!X```"1/@``$P```+`^```'````Q#X``!8```#,/@``(P```.,^```*
M````!S\```D````2/P``#@```!P_``!"````*S\``"0```!N/P``*@```),_
M```/````OC\``!L```#./P``$0```.H_```-````_#\```H````*0```"@``
M`!5````(````($````D````I0```!@```#-````8````.D```!$```!30```
M"0```&5````4````;T````@```"$0```(0```(U````U````KT```#X```#E
M0```%````"1!```8````.4$``"D```!200``#@```'Q!```,````BT$```L`
M``"800``"````*1!```5````K4$``"H```##00``!P```.Y!```5````]D$`
M``<````,0@``"0```!1"```-````'D(``"(````L0@```@```$]"```)````
M4D(```0```!<0@``$0```&%"```4````<T(``!,```"(0@``&````)Q"```2
M````M4(```<```#(0@``"````-!"```?````V4(``!D```#Y0@``#P```!-#
M```+````(T,``!`````O0P``"````$!#```V````24,```<```"`0P``)@``
M`(A#```+````KT,``"P```"[0P``+P```.A#``!!````&$0```D```!:1```
M#````&1$```.````<40```T```"`1```#0```(Y$```5````G$0```D```"R
M1```!0```+Q$```.````PD0``!(```#11```+@```.1$```&````$T4```\`
M```:10``#P```"I%```0````.D4```X```!+10``%````%I%```.````;T4`
M``T```!^10``$````(Q%```)````G44```<```"G10``#P```*]%```*````
MOT4``",```#*10``)0```.Y%```$````%$8```0````91@``"0```!Y&```'
M````*$8``!D````P1@``#P```$I&```&````6D8```<```!A1@``#@```&E&
M```&````>$8```4```!_1@``"0```(5&```)````CT8```D```"91@``-```
M`*-&```&````V$8```8```#?1@``#@```.9&```0````]48```8````&1P``
M#0````U'```0````&T<```P````L1P``"````#E'```6````0D<```X```!9
M1P``#@```&A'```6````=T<``!,```".1P``#````*)'```)````KT<```0`
M``"Y1P``"@```+Y'```7````R4<``"<```#A1P``'P````E(```%````*4@`
M`!D````O2```"P```$E(```,````54@```0```!B2```!0```&=(```.````
M;4@```0```!\2````@```(%(```%````A$@``#(```"*2```$````+U(```+
M````SD@```D```#:2```$0```.1(```*````]D@```D````!20``$`````M)
M```1````'$D``!(````N20``$0```$%)```0````4TD``!$```!D20``#@``
M`'9)```/````A4D```L```"520```P```*%)```'````I4D```\```"M20``
M#0```+U)```'````RTD```4```#320``$@```-E)```#````[$D```L```#P
M20``'0```/Q)```-````&DH```<````H2@``"P```#!*```2````/$H```D`
M``!/2@``!P```%E*```%````84H```4```!G2@``!@```&U*```9````=$H`
M``\```".2@``)0```)Y*```'````Q$H```D```#,2@```@```-9*```)````
MV4H``!$```#C2@``"@```/5*```1`````$L``!`````22P``!@```"-+```&
M````*DL```8````Q2P``(````#A+```T````64L```4```".2P``%@```)1+
M```&````JTL```<```"R2P``(0```+I+```C````W$L``#(`````3```$P``
M`#-,```)````1TP``!$```!13```!@```&-,```(````:DP``",```!S3```
M"````)=,```5````H$P``!````"V3```)P```,=,```'````[TP```P```#W
M3```#`````1-```(````$4T``!8````:30``'P```#%-```(````44T```@`
M``!:30``$P```&--```%````=TT``!$```!]30``#@```(]-```(````GDT`
M`!@```"G30``#P```,!-```+````T$T```X```#<30``(````.M-```5````
M#$X``!T````B3@``$P```$!.```E````5$X``!\```!Z3@``)````)I.```>
M````OTX``!,```#>3@``$````/).```<`````T\``$T````@3P``10```&Y/
M``!,````M$\```H````!4```$@````Q0```F````'U````D```!&4```$```
M`%!0```&````85```"D```!H4```&````))0```6````JU```"(```#"4```
M&0```.50```&````_U````8````&40``%`````U1```/````(E$``!,````R
M40``!@```$91```$````35$```8```!240``!P```%E1```>````85$``"@`
M``"`40``(@```*E1```4````S%$```8```#A40``#````.A1```5````]5$`
M`"X````+4@``*0```#I2```B````9%(``"0```"'4@``%````*Q2```4````
MP5(``!<```#64@``-P```.Y2```K````)E,``"<```!24P``(````'I3```'
M````FU,``!(```"C4P``"0```+93```$````P%,``$,```#%4P```P````E4
M```F````#50``"0````T5```*P```%E4```2````A50``!(```"85```"P``
M`*M4```)````MU0``$@```#!5```#`````I5```6````%U4``!`````N50``
M$````#]5```0````4%4```L```!A50``%0```&U5```(````@U4```,```",
M50``"P```)!5```5````G%4``!0```"R50``)0```,=5```$````[54``#$`
M``#R50``.@```"16```-````7U8```\```!M5@```@```'U6```(````@%8`
M``(```")5@``%````(Q6``!(````H58``$$```#J5@``"@```"Q7```6````
M-U<```\```!.5P``"0```%Y7```,````:%<``!D```!U5P``(@```(]7```)
M````LE<``!4```"\5P``'@```-)7```1````\5<``!8````#6```$0```!I8
M```*````+%@``!L````W6```"0```%-8```'````75@```T```!E6```#0``
M`'-8```&````@5@```8```"(6```#@```(]8```'````GE@```4```"F6```
M!@```*Q8```(````LU@```D```"\6```!0```,98```&````S%@```4```#3
M6```"@```-E8```,````Y%@```<```#Q6```#P```/E8```%````"5D```$`
M```/````CP```"(!``````````````````!0````@`````````!9`0``'0$`
M`)8`````````0P```,`````1````)0``````````````5P$``#H`````````
M"`$``$L!`````````````(P```!Y````]`````````"O````S@````````!&
M``````````````!N`0``H````&,```!G````&`````````"0````;`$``+D`
M``!G`0````````````!M`````````"$!``!=`0```````&\```#)````````
M`%,```!!````AP````````"-````<`$``#T!``!E`0``=@````````!U````
M`````$0```"U````F````%4```#:`````````,@`````````.`$``$<```!J
M````)@```$````#%````5`$``+$````K`0```@$``+````"2````,@$``*0`
M``#Q`````````+P```#\`````````"8!````````````````````````=P``
M`"4!```<`0``:@$``+0````S`0```````$\!```;````*P`````````G`0``
M6`$```````"!````2@$``(X```#"``````$``+(```!D`0``U0```'H```!?
M`0``(```````````````EP`````````T`0``QP```-@```"_````G```````
M``"5````?0```$H```!$`0``A@````T!``!P````)````#(```#-````\P``
M`+L`````````]@```````````````````'8!```,`0`````````````B````
M-@`````````=````2P```````````````````````````````````"X```#_
M`````````&8````>``````````L!```@`0``^@```)D```!R````%@$``"$`
M````````U@```,L``````````````#8!```]`````````"T!```D`0``````
M`.X```!T`0``;P$```````!K`````````!$!``!!`0````````````!%`0``
M```````````5`0``^P```$T````_`0``&@$``%X`````````2```````````
M````>`````````!<````"`````````!``0``G@`````````\`````````+T`
M``#G````0@$``+,```!,````=````',````H`0```P```"D!``#^````-0$`
M``<```!7````/@$```````#>````,````#<!```,````3@```)T````G````
MB`````````![````:````*8````?`0``!@$`````````````HP````````"H
M````#@$``#$```#!````$@$``)$```"W`````````#$!``!#`0``_0```!<!
M```W`````````-0````N`0``%````.````##````%@```'$!``"B````````
M`#P!````````&0$``$D!``!'`0``S````#L`````````J@````X`````````
MZ````!L!```%`0``80```'\````_````*@````(```#D`````````,8```#U
M`````````%(```!"````$`$``-(```!.`0```````"\```!X`0``:`$```8`
M``!9````9@$``.$```!C`0```````-$```!R`0``Y@```*T````2````6@$`
M`&$!``"^`````````-\`````````5`````4```!&`0``N````'D!```<````
M``````````"K````*````*D`````````2`$```T````L`0`````````````O
M`0````````````!K`0``4`$```````!D`````````!4```!\`````````%H`
M`````````````(,`````````8@$```````!1````"0```/D```"%````````
M`#D`````````IP```)0````[`0``"@```#4```";````:0$```````!,`0``
MQ````-,````8`0``(P````````!3`0```````.D```#J````,`$``!D```!1
M`0```````+H`````````;@`````````7`````````/(`````````=0$``$T!
M```^`````````,H`````````X@```&````!Z`0`````````````'`0``+```
M`%X!``#/````90```-````!=````:0```-<````T`````````!,```!<`0``
M"@$``&(````C`0``BP```#D!``"$````*@$``%4!``"3````'@$``',!````
M````;````/````!6````[0```#,```!W`0`````````````0``````````$!
M``!)`````````*4```!M`0``]P```'X``````````````*$```":````&@``
M`-D```""`````````!\```#O````.@$``%(!``!;````VP````````!;`0``
M*0```"T`````````10````,!```X````XP````\!``"N````8`$``/@```#=
M````Y0```+8```"*`````````.P```!?````$P$``-P````$````B0````L`
M````````%`$``'$```!/````"0$```````!6`0````````0!``"?````K```
M`.L```!8`````"5D(&YO=&5S`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VX`)7,@8VAA<F%C=&5R<P`E<R!F:6QE('-U8V-E<W-F
M=6QL>2!I;7!O<G1E9``E<R=S($YO=&5P860`,2!N;W1E`#$R($AO=7(@1F]R
M;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$%-+U!-`$%C8V5S<R!D96YI
M960@9&5L971I;F<@;F]T92X`06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO
M=&4N`$%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N`$%C8V5S<R!D
M96YI960@<V%V:6YG(&YO=&4Z("5S`$%C8V]U;G0@26YF;W)M871I;VX`061D
M`$%D9"!(97)E.@!!9&0@8V%T96=O<GD`061D('!A:7(`061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9&EN9R!!($YE=R!.;W1E`$%D
M9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO
M;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`07!P;&EC871I;VX`07!P;&EC871I;VX@:7,@<F5A9'DN`$%S8V5N9&EN
M9P!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%V86EL86)L92!F:65L9',Z`$)A8VL@=&\@3F]T97!A
M9`!"86-K('1O($YO=&5P860@3W!T:6]N<P!":7)T:&1A>0!";&]C:R!3971T
M:6YG<P!";&]C:R!4>7!E`$-35@!#86QE;F1A<@!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A=&5G;W)I97,@86YD($QA8F5L<P!#871E9V]R>0!#
M96QL(%!H;VYE`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P
M;&%Y(&]P=&EO;G,N`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH
M<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H;V]S92!!
M<'!L:6-A=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O
M<V4@>6]U<B!D969A=6QT($YO=&5P860N`$-L96%R($9O<FT`0VQO<V4@5VEN
M9&]W`$-O;&QA<'-E(%-I9&5B87(`0V]M<&%N>0!#;VYF:6=U<F%T:6]N(&ES
M(&]U="!O9B!D871E+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<P!#<F5A=&4`0W)E871E(&$@;F5W(&]N90!#<F5A=&5D`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W5R<F5N="!4:6UE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`1$0`1&%I;'D`1&%T90!$969A
M=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!.;W1E<&%D`$1E
M9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C
M=&EO;CH`1&5L971E`$1E;&5T92!#;VYF:7)M871I;VX`1&5L971E(&)U='1O
M;B!B96AA=FEO=7(`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T
M:&ES(&YO=&4`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;CH`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`
M1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT
M<FEE<S\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;W=N;&]A9`!$;W=N;&]A
M9"`E<P!%9&ET`$5D:70@0FQO8VL`161I="!.;W1E`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5M86EL`$5M<'1Y($YO=&4`
M16UP='D@<F5S=6QT+@!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/P!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>'!A
M;F0`17AP;W)T`$5X<&]R="!.;W1E<P!&7W5L;"!497AT`$9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`1F%X`$9I;&4`1FEL92!-86YA9V5R`$9I;'1E<G,`1G5L;"!$
M97-C<FEP=&EO;@!'96YE<F%L($]P=&EO;G,`1VQO8F%L($]P=&EO;G,`1V\`
M1V]O9VQE(%-E87)C:`!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`2&5A9&5R
M<P!(96QP`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.@!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO
M<F1E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M
M93H`26UA9V5S`$EM<&]R="!.;W1E<RP@4W1E<"`E9`!);7!O<G0L(%-T97`@
M)60`26UP;W)T+T5X<&]R="!.;W1E<P!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);F1I=FED=6%L(%5S97)S`$QA7WEO=70`3&%N9W5A
M9V4`3&%S="!-;V1I9FEE9`!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E
M<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA>6]U=`!,:7-T($AE;'`@
M5&]P:6-S`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U
M=`!,;V=I;@!,;V=I;B!487-K<P!-30!-86EL`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M=&-H:6YG(&9I96QD<P!-96YU(&UO9&4Z`$UE<W-A9V4`36]D:69Y:6YG("5S
M`$UO;G1H;'D`36]O;B!0:&%S97,`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E
M(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY($YO=&5S`$YA;64`3F5V97(`3F5W
M($-A=&5G;W)Y`$YE=R!.;W1E`$YE=W,`3F5X=`!.97AT(&]P=&EO;G,`3F\`
M3F\@;F]T97,`3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N
M`$YO('9A;'5E<P!.;U]T90!.;VYE`$YO<G1H97)N($AE;6ES<&AE<F4`3F]T
M92!#871E9V]R>0!.;W1E($1E=&%I;',`3F]T92!497AT`$YO=&4@7U1E>'0`
M3F]T95]P860`3F]T97!A9"=S(&YA;64Z`$YO=&5P861S`$YO=&5P861S(&UU
M<W0@:&%V92!A(&YA;64N`$YO=&5S`$YO=&5S(%-U;6UA<GD`3TL`3W!T:6]N
M<P!/<'1I;VYS(&9O<B`E<P!/<F=A;FEZ:6YG`$]T:&5R($EN9F]R;6%T:6]N
M`$]T:&5R($]P=&EO;G,`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N<P!097)S;VYA;"!);F9O<FUA=&EO;@!0:&]N90!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!R979I;W5S(&]P=&EO;G,`4')O8FQE
M;0!0<F]B;&5M($1E<V-R:7!T:6]N`%)E860`4F5F<F5S:`!2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!,:7-T`%)E9G)E<V@@4&]R
M=&%L(%9I97<Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E
M;6]V92!P86ER`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<P!2;VQE`%-A=F4`4V%V92!/<'1I;VYS`%-E87)C:`!3
M96%R8V@@4F5S=6QT<P!396%R8V@@4V-O<&4`4V5A<F-H(%]497AT`%-E;&5C
M="!A(&YO=&5P860`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A;&P`4V5L96-T
M(&YO;F4`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D
M871E(&9O<FUA=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@
M=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@
M<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-H;W)T(%-U
M;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@
M;&EN:W,_`%-H;W<`4VAO=R!.;W1E<&%D<SH`4VAO=R!A8W1I;VX@8G5T=&]N
M<S\`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M(&YO=&5P860@;F%M93\`4VAO=R!N;W1E<R!F<F]M('1H97-E(&-A=&5G;W)I
M97,`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/P!3:')I;FL`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-O=71H97)N($AE;6ES<&AE<F4`4W!E8VEA;"!#:&%R86-T97(@26YP
M=70`4W1A='5S`%-U8FIE8W0`4W5B;6ET`%-U8V-E<W,`4W5C8V5S<V9U;&QY
M('-A=F5D("(E<R(N`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M;G)I<V4O4W5N<V5T`%1A<VMS`%1E>'0@3VYL>0!4:&4@;F]T92!W87,@9&5L
M971E9"X`5&AE(&YO=&5P860@(B5S(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E
M<P!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&-R96%T960N`%1H92!N;W1E
M<&%D("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!H
M87,@8F5E;B!S879E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E
M<BX`5&EC:V5T<P!4:6UE(&9O<FUA=`!4:71L90!4;P!4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!54DP`56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&QO860@=&AE(&1E
M9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F1O(&-H86YG97,`56YF:6QE9`!5
M<&1A=&4`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BX`57-E<@!5<V5R($]P=&EO;G,`57-E<FYA;64`57-E<FYA
M;64Z`%5S97)N86UE.B``5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P
M86=E`%=A<FYI;F<`5V5B`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L
M("5S`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@
M;&]G:6X_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F('1H92`E<R!M96YU
M(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7
M;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!H879E
M(&)E96X@;&]G9V5D(&]U="X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L
M96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@3F%M90!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE
M.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9&5F875L="!N;W1E<&%D
M.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N;W1E<&%D<SH`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!;4')O
M8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`
M7T)A8VL@=&\@3F]T97!A9`!?0V%T96=O<GD`7T1E;&5T90!?161I=`!?1FER
M<W0@3&EN90!?1W)O=7!S`%](96QP`%]);7!O<G0O17AP;W)T`%],:7-T($YO
M=&5S`%],;V<@;W5T`%]->2!.;W1E<&%D<P!?3F5W($YO=&4`7T]P=&EO;G,`
M7U!E<FUI<W-I;VYS`%]0<FEN=`!?4V5A<F-H`%]3971U<`!?57-E<G,`961I
M=`!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@36YE;6\@2#,@
M*#(N,"XR*0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,2TQ-2`Q.#HQ-2LP,C`P
M"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#$M,34@,3@Z-#8K,#$P,`I,87-T
M+51R86YS;&%T;W(Z($%L97AE>2!:86MH87)O=B`\8F%B97)`;6]S9V$N;F5T
M/@I,86YG=6%G92U496%M.B!2=7-S:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4-0,3(U,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET"@`E9"#GX.SE\N[J`,[OY?#@]NC_(._NY.3E\.;JZ"`E<R`M(,_NY/+B
MY?#FY.7MZ.4`)7,@X?/JX@#4X.GK("5S(//Q[^7X[>X@Z.SO[O#RZ/#NXN#M
M`,SN_R#J[>CFZN`@*"5S*0`Q(.?@[.7RZN``,3(M]^#Q[N+NZ0`R-"WWX/'N
MXN[I`#(T(/?@\>``04TO4$T`TR#BX/$@[>7D[O'RX/+N]^WN(._PX.(@]_+N
MX?L@\^3@Z^CR_"#]\O,@Y^#LY?+J\P#3(.+@\2#MY>3N\?+@\N[W[>X@[_#@
MXB#W\N[A^R#OY?#E[.7Q\NCR_"#]\O,@Y^#LY?+J\P#3(.+@\2#MY?(@[_#@
MXB#OZ/'@\OP@Y^#LY?+JZ"#B("5S`,WEY.[Q\N#R[O?M[B#O\.#B(.3K_R#Q
M[O7PX.WE[>C_(.?@[.7RZN@Z("5S`-/WY?+MX/\@Y^#OZ/'\`,3NX>#BZ/+\
M`,3NX>#BZ/+\.@#-[N+@_R#JX/+EX^[PZ/\`Q.[AX.+H\OP@[^#P\P#$[N'@
MXNCR_"!-;WII;&QA(%-I9&5B87(`Q.[AX.+KY>WHY2#M[N+NZ2#GX.SE\NKH
M`,#D\.7Q`,#D\.7Q[>#_(.KMZ./@`,W@\?+P[NGJZ"`M(//Q\N#M[N+JX"#O
M\.#B(.3K_R#D\//CZ/4@[^[K_.?NXN#RY>OEZ0#3[_#@XNOE[>CE`,_QY>+D
M[NWH[`#"\>4@XN[XY>3XZ.4`PO'E(./P\^_O^P#"\>4@[_#@XN``T.#G\.7X
MZ/+\(.[OY?#@]NCH(/'N(/'OZ/'JX.SH`,#K_/+E\.W@\NCB[?OI($E335``
MS^#P[NO\.@#([/\@[^[K_.?NXN#RY>O_($E335`Z`,'[Z^X@\^K@Y^#M[B#M
MY>KN\/#EZO+M[N4@Y^W@]^7MZ.4N`,_PZ.ONYN7MZ.4`S>#Q\O#NY>WN`,_N
M(.+NY_#@\?+@[>C^`,?@[_#@^.CBX/+\(._NY/+BY?#FY.7MZ.4@[^7PY>0@
MXOOO[NOMY>WHY>P@[N_E\.#VZ.D@[N'QZ_/FZ.+@[>C_/P#/[N_[\NK@(//D
MX.OH\OP@[>7Q\_GE\?+B\_[YZ.4@[_#@XN``S^[O^_+JX"#PY>3@ZO+H\.[B
MX/+\(.WE\?/YY?'RXO/^^>CE(._PX.+@`,3N\?+S[^W[Y2#O[NO_.@#"Y?#M
M\_+\\?\@XB#'X._H\>WS_B#J[>CFZO,`PN7P[?/R\?\@ZB#N[_;H_^P`Q.7M
M_"#P[N;DY>WH_P#-X/'R\.[IZN`Z`-#@\?CH\.7MZ.4`0U-6+?3@Z>L`RN#K
MY>WDX/#\`,[R[.7MX`#.\NSE[>`@[O+WY?+@(.X@[_#NX>OE[.4`RN#RY>/N
M\.CH(.@@[.7RZN@`RN#RY>/N\.C_`,KKY?+N]^W@_R#PX.3H[O'B_^?\`,CG
M[.7MZ/+\`,W@\?+P[NGJZ"#H[.7MZ"P@X.3PY?'@+"#O[N3OZ/'H+@#(Y^SE
M[>CR_"#N[_;HZ"#N\N[A\.#FY>WH_R#H(._NZ/'JX"#B(.?@[^CQ[>[I(.KM
MZ.;JY0#.\NSE\OSRY2#TZ^#FZN#LZ"#N[^7PX/;H_BCHZ"DL(.KN\N[P^^4@
MPOL@]>[RZ/+E(.[Q\_GE\?+BZ/+\+@#"^^'E\.CRY2#O\.CK[N;E[>CE.@#4
M[O#LX/(@[O+NX?#@YN7MZ/\@Y.#R^SH`POOA\.#R_"#BX/CS(.?@[^CQ[?/^
M(.KMZ.;J\R#O[B#S[.[K]^#MZ/X`SO?H\?+H\OP@].[P[/,`Q^#J\/OR_"#N
MZNWN`-/A\.#R_"#LY>W^`,KN[._@[>C_`,KN[?3HX_/PX/;H_R#S\?+@\.7K
MX`#-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,`
MT>[GY.#R_`#1[N?DX/+\(.WNXOOI(._P[O3HZ_P`T>[GY.#MX`#1[N?DX/+E
MZ_P`TN7J\_GEY2#B\.7L_P#'X.3@]^@L(.?@[_/QZN#E[/OE(._PZ"#B]>[D
MY2#B("5S`,3$`,7FY>3MY>+M[@#$X/+@`-;BY?(@[^X@\^SNZ_?@[>C^`,_P
M[O3HZ_P@[^X@\^SNZ_?@[>C^`,KMZ.;JX"#O[B#S[.[K]^#MZ/X`T>[P\NCP
M[N+JX"#O[B#S[.[K]^#MZ/XZ`,_N\/_D[NH@\>[P\NCP[N+JZ`#3Y.#KZ/+\
M`-/DX.OE[>CE`,_NY/+BY?#FY.7MZ.4@[N_E\.#VZ.@@\^3@Z^7MZ/\`T^3@
MZ^CR_"#B^^'PX.WM^^D@[_#N].CK_`#3Y.#KZ/+\(.?@[.7RZO,`S^X@\^'[
MXN#MZ/X`SN_H^.CRY2#O\.[AZ^7L\P#.[^CQX.WHY0#/[N3P[N'M[O'RZ"#A
M^^OH(.?@[^CQX.W[(.(@YO/P[>#K(.3K_R#@Y.SH[>CQ\O#@\N[PX"X`RN#R
MX.ONXP#.\N[A\.#FX/+\(.+PY>S_(.(@,C0M]^#Q[N+N["#T[O#LX/+E/P#.
M\N[A\.#FY>WHY0#-Y2#B^^?[XN#I\N4@;6%I;G1E;F%N8V4N<&AP(.WE[^[Q
M\.7D\?+BY>WM[@#'X._PX/CHXN#R_"#O[N3RXN7PYN3E[>CE(._PZ"#SY.#K
MY>WHZ"#GX._H\>7I/P#"(._E\.+NZ2#Q\O#NZN4@\^K@Y^#M^R#H[.7MX"#O
M[NOEZ3\@Q?'KZ"#DX"P@[^[Q\N#B_/+E(./@Z^[WZO,Z(`#'X./P\^?H\OP`
MQ^#C\//GZ/+\("5S`-#EY.#J\NCP[N+@[>CE`-#EY.#J\NCP[N+@\OP`T.7D
MX.KRZ/#NXN#R_`#3\?+@[>[BZN`@[_#@XB#DZ_\@)7,`S>#Q\O#NZ>KH`$5M
M86EL`,_S\?+@_R#GX.SE\NK@`,WSZ^7B[ND@\.7G\^O\\N#R+@#*[NWRY>KQ
M\NWNY2#LY>W^(._N(.W@YN#RZ.@@[_#@XN[I(.KM[N_JZ"#L^_CH`,[XZ.'J
MX`#*X.;D^^4@,34@[.CM\_(`RN#FY/OE(#(@[.CM\_+[`,K@YN3[Y2`S,"#Q
MY>KS[>0`RN#FY/OE(#4@[.CM\_(`RN#FY/OI(/#@YR#O\.@@XO7NY.4`RN#F
MY/OE(._NZ_?@\>``RN#FY//^(.SH[?/R\P#/\.CLY?`@Y^W@]^7MZ.DZ`-#@
M\?CH\.CR_`#=ZO'O[O#R`-WJ\>_N\/(@Y^#LY?+NZ@#"Y?'\(/+EZO'R`,+N
M\?'RX.WNXNOE[>CE(.W@\?+P[N7J(.WE(//DX.ON\?PN`,WE\^3@]^WNY2#Q
M[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"X`U.#J\0#4X.GK`-7PX.WHZ^CY
MX`#4Z.O\\O#[`,_NZ^WNY2#N[^CQX.WHY2#O\.[AZ^7L^SH`SN'YZ.4@[>#Q
M\O#NZ>KH`,_N\/+@ZP#/Y?#EZ?+H`,_NZ/'J(.(@1V]O9VQE`,/P\^_O^P##
M[O'R_`#'X./NZ^[BZN@`S^[D\>K@Y^K@`,_NZ_/XX/#HY0#-Z.;E(._PY>3Q
M\N#BZ^7MX"#H[?3N\.S@]NC_(.CG(/'@[.[C[B#MX/?@Z^`@].#IZ^`Z`,_N
M\/+@ZP#/[O#RX.L`Q.[LX/CMZ.D@X.3PY?$`Q.[LX/CMZ.D@\N7KY?3N[0#/
M[O#RX.L`TN[K_.KN(.CJ[NWJZ`#(ZN[MZN@@\2#RY>KQ\N[L`,CL_R#O\.[T
MZ.O_.@#*X/#RZ.WJZ`#([._N\/(@Y^#LY?+NZBP@V.#C("5D`,CL[^[P\BP@
M^.#C("5D`,CL[^[P\B_=ZO'O[O#R`,CL[^[P\NCP[N+@[>X@[^[KY3H@)7,`
MR.SO[O#RZ/#NXN#M^R#O[NO_.@#/[NO\Y^[BX/+EZ^@`T.#QZNO@Y.K@`-_G
M^^H`R/'O\.#BZ^7MX`#/\.7D^^3S^>CI(.+U[N0@X?OK.B`E<P#/\.7D^^3S
M^>CI(.+U[N0@X?OK.B`E<R#Q(.KN[._\_O+E\.`@)7,`S_#EY/OD\_GHZ2#B
M]>[D(.WE(.?@].CJ\>CP[N+@[0#"^_7NY`#1[^CQ[NH@\.#GY.7K[N(@[^[D
M\>K@Y^KH`,ONZN#KZ.?@]NC_`-#@\>_NZ^[FY>WHY0#"]>[D`,+[]>[D`-/W
MY?+MX/\@Y^#OZ/'\`,+U[N0`S,P`S^[W\N``S>#Q\O#NZ>K@(/'OZ/'JX"#J
MX/+EX^[PZ.D@Z"#VXN7R[N(@Z/4@[O+NX?#@YN7MZ/\`T>[B[^#DX/[YZ.4@
M[^[K_P#0Y>;H["#LY>W^.@#1[N[A^>7MZ.4`T.7DX.KRZ/#NXN#MZ.4@)7,`
MQ>;E[.7Q__?M[@#4X.?[(,OS[?L`[^7PY>SE\?+H\OP@XNWHYP#OY?#E[.7Q
M\NCR_"#BZ^7B[@#OY?#E[.7Q\NCR_"#B[_#@XNX`[^7PY>SE\?+H\OP@XN+E
M\/4`[^7PY>SE\?+H\OP@XNWHYP#OY?#E[.7Q\NCR_"#BXN7P]0#3]^7R[>#_
M(.?@[^CQ_`#"X/C@(.CM].[P[.#VZ/\`S.[H(.?@[.7RZN@`R.S_`,WHZN[C
MY.``S>[BX/\@ZN#RY>/N\.C_`,WNXN#_(.?@[.7RZN``S>[B[O'RZ`#$X.OE
MY0#1Z^7D\_[YX/\@\?+PX.WH]N``S>7R`,WE\B#'X.SE\N[J`,_NY/7NY/_Y
MZ/4@Y^#LY?+NZB#MY2#MX.GDY>WN`,WE(.[O\.7DY>OE[>X`Q^#LY?+JZ``M
M[>4@XOOA\.#M+0#1Y>+E\.WNY2#O[NOS^.#PZ.4`RN#RY>/N\.C_`,?@[.7R
MZN``TN7J\?(`TN7J\?(`RNWHYNK@`,W@Y^+@[>CE(.?@[^CQ[>[I(.KMZ.;J
MZ#H`Q^#OZ/'M^^4@ZNWHYNKH`,+[(.WE(.?@Y.#KZ"#MX.?BX.WHY2#GX._H
M\>WNZ2#J[>CFZN@`Q^#LY?+JZ`#1[O'R[O_MZ.4`3TL`S>#Q\O#NZ>KH`,W@
M\?+P[NGJZ"#DZ_\Z("5S`,[PX^#MX.GGY?``S_#N]^#_(.CM].[P[.#VZ/\`
MQ/#SX^CE(.W@\?+P[NGJZ`#/X/#NZ_P`S^#P[NO\`,_@\.[K_`#.\?/YY?'R
MXNOE[>CE(.[OY?#@]NCI(._NY.3E\.;JZ`#"^^_NZ^WH\OP@[N_E\.#VZ.@@
M[N'QZ_/FZ.+@[>C_(._PZ"#B]>[DY2#B(/'H\?+E[/,_`,_PX.+@`,CG[.7M
MZ/+\(._PX.+@(.3N\?+S[^``R^CW[?OE`-+EZ^7T[NT`PN+EY.CRY2#MX.?B
MX.WHY2#M[N+NZ2#JX/+EX^[PZ.@Z`,_NYN#K\^GQ\N`L(/'N[N'YZ/+E(/'S
M\OP@[_#NX>OE[/LN`,_NYN#K\^GQ\N`L(.+BY>3H\N4@PN#XZ"#H[/\@[^[K
M_.?NXN#RY>O_(.@@[^#P[NO\`,_PY>3[Y//YX/\@\?+PX.WH]N``S_#NX>OE
M[.`_`,[OZ/'@[>CE(._P[N'KY>S[`-?H\N#R_`#.X>WNXNCR_`#.X>WNXNO_
M\OP@Y.CMX.SH]^7QZNCE(._S[>KR^R#LY>W^.@#.X>WNXNCR_`#.X>WNXNO_
M\OP@Z.WT[O#LX/;H_CH`S^[W\N[B^^4@\>7PXN7PX`#`Y/#E\2#QY?#BY?#@
M("CMX._PZ.SE\"!H='1P.B\O;6%I;"YR=2D`T^3@Z^CR_`#3Y.#KZ/+\(.'K
M[NH`T^3@Z^CR_"#OX/#S`-'A\.[QZ/+\`,+E\.WS\OSQ_R#J(.W@\?+P[NGJ
MX.P`S>#Q\O#NZ>KH(.+HY_/@Z_SM[N/N(/#EY.#J\N[PX`#1]N7MX/#HZ0#'
MX._H\>#R_`#1[O7PX.WH\OP@[>#Q\O#NZ>KH`,_NZ/'J`-#EY_/K_/+@\OL@
M[^[H\>K@`,[AZ^#Q\OP@[^[H\>K@`-?R[B#H^>7L`,+[X>7PZ/+E(.?@[^CQ
M[?/^(.KMZ.;J\P#"^^'E\.CRY2#QY?#BY?``POOA\.#R_"#B\>4`SO+LY>WH
M\OP@XOOA[O``POOAY?#H\N4@\.#GY.7KZ/+EZ_P@[^[KY>D@Y.#R^SH`POOA
MY?#H\N4@].[P[.#R(.3@\OLZ`,+[X>7PZ/+E(/3N\.S@\B#DZ_\@_>KQ[^[P
M\N`Z`,CL[^[P\NCP\^7L^^D@].#IZSH`POOAY?#H\N4@].[P[.#R(.CL[^[P
M\NCP\^7L[N/N(/3@Z>O@.@#"^^'E\.CRY2#O\.[TZ.O\(.3K_R#MX/'R\.[I
MZN@Z`,+[X>7PZ/+E(.[R[N'PX.;E[>C_(/3N\.S@\B#B\.7LY>WH.@#"^^'E
M\.CRY2#DXN`@\>[B[^#DX/[YZ/4@[^[K_RX`PN#XX"#VXN7R[N+@_R#Q]>7L
MX`#?Y_OJ(.[R[N'PX.;E[>C_`,_N\>O@\OP@\>[NX?GE[>CE(.X@[_#NX>OE
M[.4`Q.[O[NOMZ/+EZ_SM^^4@[^[W\N[B^^4@\>7PXN7PX"P@ZB#J[O+N\/OL
M(.+[(/7N\NCRY2#H[.7R_"#D[O'R\^\@Z.<@S^[P\N#KX"X`T_'RX.WNXNK@
M(/_G^^K@(.+[XN[DX"P@XO#E[.7M[>[I(.?N[?L@Z"#T[O#LX/+@(.[R[N'P
MX.;E[>C_(.+PY>SE[>@N`-/Q\N#M[N+JX"#O\.CK[N;E[>C_(._N(//L[NOW
MX.WH_BP@]N+E\N[B[ND@\?7E[/L@Z"#O\.[WZ/4@[N_VZ.D@[O+NX?#@YN7M
MZ/\`S_#HZ^[FY>WH_P#*\.#RZN[E(.[A[N'YY>WHY3H`SN_PY>3EZ^CR_"#A
M^_'R\/OE(.KKX.+H^.@@Y.O_(/'Q^^ONZC\`S^[JX.?@\OPZ`,?@[^CQ[?OE
M(.KMZ.;JZ#H`RNWN[^KH`,_NZN#G^^+@\OP@Z.WT[O#LX/;H_B#N(._PY>3[
MY//YY>P@XO7NY.4_`,W@Y^+@[>CE(.?@[^CQ[>[I(.KMZ.;JZ`#/[NK@Y^#R
M_"#O[B#JX/+EX^[PZ.@Z`,_NZN#GX/+\(.SE[?X@[N_E\.#VZ.D@\2#RX.'K
MZ/;@[.@`SO+NX?#@YN#R_"#LY>W^("5S(/'KY>+@/P#1\^?H\OP`T.#G[.7P
M`,_P[N_S\?+H\OP@[^[DY.7PYNKS`-[F[>[E(._NZ_/XX/#HY0#1[^7VZ.#K
M_.W[Y2#QZ.SB[NO[`-'RX/+S\0#2Y>S@`,CQZN#R_`#3\>_E^.WN`,?@[.7R
MZN`@)R5S)R#S\>_E^.WN(/'N]?#@[>7MX`#1\N#PX/\@ZN[M].CC\_#@]NC_
M(/'N]?#@[>7MX"#B(/3@Z>LZ("5S`,WNXN#_(.KN[?3HX_/PX/;H_R#Q[O7P
MX.WE[>`@XCH@)7,`PO#E[/\@XN[Q]>[DX"_GX.K@\N``Q^#DX/?H`-+NZ_SJ
M[B#RY>KQ\@#'X.SE\NK@(.'[Z^`@\^3@Z^7MX"X`Q^#OZ/'MX/\@ZNWHYNK@
M("<E<R<@[>4@[.[FY?(@X?OR_"#Q[N?DX.W@.B`E<P#'X._H\>W@_R#J[>CF
MZN`@)R5S)R#A^^O@(//Q[^7X[>X@\>[GY.#MX`#'X._H\>W@_R#J[>CFZN`@
M)R5S)R#A^^O@(//DX.OE[>`N`,?@[^CQ[>#_(.KMZ.;JX"`G)7,G(.'[Z^`@
M\>[U\.#MY>W@+@#1Y?#BY?`@)7,@X?OK(//DX.OE[0#1Y?#BY?`@)7,@X?OK
M(/'NY^3@[0#-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+@#1[N[A^>7MZ.4@XB#M
MY>+E\.WN["#T[O#LX/+E(.@@[>4@[.[FY?(@X?OR_"#N\N[A\.#FY>WN`,[X
MZ.'JX"#O\.@@[O+NX?#@YN7MZ.@@_?+NZ2#WX/'RZ"#Q[N[A^>7MZ/\`W?+N
M(/?H\>ON(.WE(.SNYN7R(.'[\OP@[.7M_/CE(.7DZ.WH]OLN`-WR[B#G[>#W
MY>WHY2#D[NOF[>X@X?OR_"#WZ/'K[NPN`,?@[_#N\?L`U.[P[.#R(.[R[N'P
MX.;E[>C_`,?@X^[K[N+NZ@#*[NSS`-?R[N'[(.+[X?#@\OP@[>7QZN[K_.KN
M(/WKY>SE[?+NXBP@\^3E\.;HXN#I\N4@[>#FX/+NZ2#JZ^#BZ.;S($-T<FP`
M55),`,WEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN`,WE
MXN[G[.[F[>X@Y^#C\//GZ/+\(.[O\.7DY>OE[>CE("5S+@#=\N[R(.3NZO/L
MY>WR(%=O<F0@[>4@[.[FY?(@X?OR_"#OY?#EXN7DY>TN`,[R[.7MZ/+\(.CG
M[.7MY>WH_P#.\NSE[>CR_"#HY^SE[>7MZ/\`SO+Q\_+Q\N+SY?(`S_#H[.7M
MZ/+\`,CQ[^[K_.?SY?+Q_R#E\>OH(.+@^.@@Z.S_+^_@\.[K_"#DZ_\@24U3
M4"#QY?#BY?#@(.[RZ^CWX/[R\?\@[O(@\N7J\_GH]0#/[NO\Y^[BX/+EZ_P`
MS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_P#([/\@[^[K_.?NXN#RY>O_`,CL_R#O
M[NO\Y^[BX/+EZ_\`R.S_(._NZ_SG[N+@\N7K_P#/\.[Q[.[R\"`E<P#/[NK@
MY^#R_"#BY>$M\?+PX.WH]O,`PNWH[.#MZ.4`PN7A`,7FY>WEY.7K_.WN`,3N
MX?#N(._NYN#K[N+@\OP@XB`E<P#$[N'P[B#O[N;@Z^[BX/+\+"`E<P#7\NX@
M[O+NX?#@YN#R_"#O[O'KY2#B]>[DX"#B(/'H\?+E[/,Z`-3@Y^``RN#JZ.4@
M[N_VZ.@@X?/D\_(@Y.[Q\O/O[?L@XB#BZ.?SX.O\[>[L(/#EY.#J\N[PY0#8
MZ/#H[>`@[.7M_B`E<R#QZ^7BX"`HX?/DY?(@[_#H[.7MY>W@(._PZ"#QZ^7D
M\_[YY>P@XO7NY.4I`-#@X>[WZ.D@X.3PY?$`T.#A[O?HZ2#RY>OE].[M`,/#
M`,7FY>/NY.WN`,3@`,+[(.+[^.OH(.CG(/'H\?+E[/LN`,+[(.3NZ^;M^R#N
M[^CQX/+\(._P[N'KY>S[+"#O\.7FY.4@]^7L(/'L[N;E\N4@[O+N\>O@\OP@
M\>[NX?GE[>CE(.X@[>7I+@#"X/C@("5S(/'E\?'H_R#GX.KN[??HZ^#Q_"X@
MS^[FX.OSZ?'RX"P@XN[IY.CRY2#B(/'H\?+E[/,@Y^#M[N+N+@#"X/@@16UA
M:6PZ`,+@^"#@Y/#E\2#N\N_PX.+H\N7K_SH`PN#XX"#H[?3N\.S@]NC_`,+@
M^.4@Z.S_.@#7X/'NXN[I(._N__$`PN#X(._P[O3HZ_P@[^X@\^SNZ_?@[>C^
M.@#"X/C@(.?@[^CQ[>#_(.KMZ.;JX"#O[B#S[.[K]^#MZ/XZ`,+@^.4@Z.S_
M.@#"X/C@(.?@[^CQ[>#_(.KMZ.;JX#H`PN#XZ"#MX/'R\.[IZN@@X?OKZ"#N
MX>WNXNOE[?LN`-'R[O#N[>WHZ2#QY?#BY?`Z`%O1[N[A^>7MZ.4@[B#O\.[A
MZ^7LY5T`6_'R\.[JX"`E<R#HYR`E<UT`T^_PX.+KY>WHY0#"Y?#M\_+\\?\@
MXB#GX._H\>WS_B#J[>CFZO,`RN#RY>/N\.C_`-/DX.OH\OP`T.7DX.KRZ/#N
MXN#R_`#/Y?#BX/\@\?+P[NK@`,/P\^_O^P#/[NSN^?P`R.SO[O#R+]WJ\>_N
M\/(`POOA\.#R_`#"^_7NY`#*[>CFZN@`Q.[AX.+H\OP`S>#Q\O#NZ>KH`,_P
MX.+@`,_E]^#R_`#/[NCQZ@#/\.CK[N;E[>C_`,_NZ_SG[N+@\N7KZ`#/\.#B
MZ/+\`/+EZO'R(/'N[N'YY>WH_P!V0V%R9```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O<VM?4TLO````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S0U`#`R,#`Q,0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO
M+VQO8V%L92]S:U]32R],0U]-15-304=%4R\`````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#4`,#(Q-3<V`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;6YE;6\O;&]C86QE+W-K7U-++TQ#7TU%4U-!1T53+VUN
M96UO+FUO```````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0R,S4T-P`Q,#0Q-S,V,C<T-0`P
M,C,R-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````#6!P``'````,P^``!U"@``?'T```````!0IP``#@```%&G
M```/````8*<```T```!PIP``"````'ZG```+````AZ<```P```"3IP``!```
M`*"G```8````I:<``!L```"^IP``+0```-JG```=````"*@``"0````FJ```
M*0```$NH```9````=:@``"8```"/J```#````+:H```D````PZ@```@```#H
MJ```#P```/&H```+`````:D```X````-J0``!0```!RI```H````(JD```@`
M``!+J0``"@```%2I```5````7ZD``!(```!UJ0``"P```(BI```-````E*D`
M`!T```"BJ0``A0```,"I```.````1JH```H```!5J@``#0```&"J```.````
M;JH``!$```!]J@``#0```(^J```,````G:H```T```"JJ@``!@```+BJ``"4
M````OZH```H```!4JP``#P```%^K```8````;ZL```P```"(JP``!@```)6K
M```.````G*L```X```"KJP``"````+JK```)````PZL``"X```#-JP``&@``
M`/RK```R````%ZP``#@```!*K```5````(.L``!1````V*P``%H````JK0``
M5P```(6M```T````W:T```D````2K@``#0```!RN```'````*JX```H````R
MK@``#P```#VN```%````3:X```8```!3K@``$0```%JN```(````;*X```D`
M``!UK@``"0```'^N```E````B:X``"````"OK@``'````-"N```>````[:X`
M`"`````,KP``'0```"VO```3````2Z\``!````!?KP``#P```'"O```*````
M@*\```,```"+KP``#P```(^O```4````GZ\```D```"TKP``#0```+ZO```2
M````S*\``!D```#?KP``'@```/FO```/````&+````P````HL```"@```#6P
M```/````0+````@```!0L```)````%FP```4````?K```!8```"3L```"```
M`*JP``!.````L[```"T````"L0``$0```#"Q```9````0K$```<```!<L0``
M#````&2Q```L````<;$```X```">L0```P```*VQ```+````L;$```<```"]
ML0``!P```,6Q```%````S;$```4```#3L0``"@```-FQ```#````Y+$``!<`
M``#HL0``"@````"R```/````"[(```X````;L@``&````"JR```C````0[(`
M``X```!GL@``%````':R```7````B[(``!<```"CL@``%P```+NR```3````
MT[(```\```#GL@``#@```/>R```?````!K,``!T````FLP``!P```$2S```&
M````3+,```@```!3LP``#P```%RS```&````;+,```H```!SLP``$P```'ZS
M```+````DK,``!````">LP``%0```*^S```5````Q;,```<```#;LP``$```
M`..S```%````]+,``!$```#ZLP``#`````RT```[````&;0``#@```!5M```
M"0```(ZT```'````F+0```,```"@M```!0```*2T```)````JK0``!````"T
MM```"0```,6T```3````S[0``#D```#CM```)P```!VU```L````1;4``"H`
M``!RM0``)0```)VU```*````P[4```8```#.M0``"0```-6U```'````W[4`
M`"\```#GM0``-P```!>V```N````3[8``%4```!^M@``+0```-2V```M````
M`K<``#T````PMP``/P```&ZW```M````KK<``$````#<MP``(P```!VX```C
M````0;@``$````!EN```+0```*:X```S````U+@``"4````(N0``%0```"ZY
M```9````1+D``"D```!>N0``)````(BY```H````K;D``!4```#6N0``$0``
M`.RY```*````_KD```P````)N@``#P```!:Z```7````)KH```H````^N@``
M$````$FZ```6````6KH``!8```!QN@``!P```(BZ```'````D+H```H```"8
MN@``"````*.Z```G````K+H```@```#4N@``!P```-VZ```'````Y;H```8`
M``#MN@``!0```/2Z```'````^KH```8````"NP``"`````F[```I````$KL`
M``X````\NP``"@```$N[```$````5KL```<```!;NP``"0```&.[```&````
M;;L``!$```!TNP``!P```(:[```6````CKL```0```"ENP``"````*J[```&
M````L[L```T```"ZNP``!@```,B[```>````S[L``!$```#NNP``"`````"\
M```-````";P```P````7O```!P```"2\```#````++P```,````PO```%P``
M`#2\```#````3+P``!,```!0O```'0```&2\```(````@KP```0```"+O```
M"````)"\```(````F;P``$$```"BO```&@```.2\```K````_[P``"`````K
MO0``%0```$R]```&````8KT```8```!IO0``%0```'"]```8````AKT``"(`
M``"?O0``+@```,*]```=````\;T``"$````/O@``5````#&^```I````AKX`
M``H```"PO@``!P```+N^```5````P[X```@```#9O@``#@```.*^```*````
M\;X```\```#\O@``#0````R_```/````&K\```T````JOP``"0```#B_```&
M````0K\``!@```!)OP``$P```&*_```1````=K\``!0```"(OP``!````)V_
M```&````HK\``!0```"IOP``5````+Z_```M````$\```&0```!!P```!```
M`*;````.````J\````4```"ZP```!0```,#````3````QL```!$```#:P```
M$0```.S````<````_L```"H````;P0``-P```$;!```<````?L$``!````";
MP0``(0```*S!```%````SL$```H```#4P0``$P```-_!```+````\\$``!(`
M``#_P0``"@```!+"```/````'<(```T````MP@``$0```#O"```3````3<(`
M``P```!AP@``!@```&["```,````=<(```8```""P@``%P```(G"```0````
MH<(``!$```"RP@``"````,3"```%````S<(```P```#3P@``$````.#"```%
M````\<(```T```#WP@``!@````7#```'````#,,```T````4PP``!P```"+#
M```+````*L,```<````VPP``!P```#[#```)````1L,```D```!0PP``"@``
M`%K#```9````9<,``#T```!_PP``'0```+W#```,````V\,``!````#HPP``
M!0```/G#```E````_\,``!(````EQ```$P```#C$```K````3,0``#L```!X
MQ```(````+3$```(````U<0``#8```#>Q```(0```!7%```0````-\4```@`
M``!(Q0``#````%'%```&````7L4```0```!EQ0``#P```&K%```.````>L4`
M``H```")Q0``#0```)3%```?````HL4``!P```#"Q0``(0```-_%```>````
M`<8``!D````@Q@``'@```#K&```=````6<8``!L```!WQ@``(````)/&```N
M````M,8``"8```#CQ@``'`````K'```>````)\<``!P```!&QP``)@```&/'
M```K````BL<``#,```"VQP``)@```.K'```K````$<@``#@````]R```'0``
M`';(```5````E,@``"\```"JR```(````-K(```2````^\@``"D````.R0``
M'@```#C)```@````5\D``!(```!XR0``H@```(O)```6````+LH``",```!%
MR@``*````&G*```I````DLH``"@```"\R@``'P```.7*```5````!<L``"``
M```;RP``)0```#S+```H````8LL``"T```"+RP``,````+G+``"2````ZLL`
M`"$```!]S```%@```)_,```<````MLP``"8```#3S```*@```/K,``!!````
M)<T``$0```!GS0``#````*S-```'````N<T```<```#!S0``!@```,G-```-
M````T,T``!````#>S0``$@```._-```'`````LX``!,````*S@``$@```![.
M```'````,<X```0````YS@``$````#[.```0````3\X```P```!@S@``#@``
M`&W.```-````?,X```\```"*S@``$P```)K.```-````KLX``"@```"\S@``
M`P```.7.```-````Z<X```8```#WS@``#@```/[.```"````#<\``$D````0
MSP``!0```%K/```0````8,\```\```!QSP``!````('/```-````AL\```X`
M``"4SP```P```*//```.````I\\```@```"VSP``#P```+_/```/````S\\`
M``<```#?SP``#0```.?/```0````]<\```\````&T```#0```!;0```9````
M)-```!H````^T```"P```%G0```&````9=````L```!LT```$P```'C0```,
M````C-````H```"9T```$0```*30```9````MM```!<```#0T```"P```.C0
M```-````]-```"(````"T0``&P```"71```T````0=$```H```!VT0``&```
M`('1```9````FM$``!8```"TT0``$````,O1```B````W-$```T```#_T0``
M!P````W2```*````%=(``!0````@T@``"P```#72```,````0=(``"(```!.
MT@``+P```''2```+````H=(```D```"MT@``&0```+?2```+````T=(``!<`
M``#=T@``%P```/72```)````#=,``!8````7TP``#P```"[3```9````/M,`
M`!8```!8TP``#@```&_3```8````?M,```@```"7TP``#0```*#3```F````
MKM,``"@```#5TP``0P```/[3```(````0M0``!(```!+U```'P```%[4```(
M````?M0```L```"'U```+P```)/4```.````P]0```4```#2U```!@```-C4
M```#````W]0```<```#CU```!````.O4```)````\-0```H```#ZU```"@``
M``75```)````$-4```\````:U0``$````"K5```7````.]4``!H```!3U0``
M$0```&[5```9````@-4``!<```":U0``"0```++5```%````O-4```L```#"
MU0``"@```,[5```"````V=4```4```#<U0``#0```.+5```;````\-4``!<`
M```,U@``%````"36```)````.=8```H```!#U@``#@```$[6```-````7=8`
M`!(```!KU@``.````'[6```@````M]8```@```#8U@``#@```.'6``![````
M\-8``!@```!LUP``&````(77```1````GM<```<```"PUP``!0```+C7```8
M````OM<``!X```#7UP``&P```/;7```9````$M@``!L````LV```&0```$C8
M```3````8M@```<```!VV```"````'[8```&````A]@```8```".V```$```
M`)78```/````IM@``!````"VV```#P```,?8```+````U]@```\```#CV```
M#````//8```/`````-D```<````0V0``!@```!C9```.````']D```P````N
MV0``*````#O9```/````9-D```@```!TV0``!@```'W9```,````A-D```@`
M``"1V0``$P```)K9```*````KMD``!X```"YV0``(0```-C9```@````^MD`
M`!D````;V@``%P```#7:```E````3=H``!<```!SV@``%@```(O:```$````
MHMH``!L```"GV@``#0```,/:```,````T=H```,```#>V@``!0```.+:```(
M````Z-H```H```#QV@``#````/S:```+````"=L``!`````5VP``#````";;
M```$````,]L```0````XVP``$P```#W;```4````4=L```P```!FVP``"0``
M`'/;```.````?=L```L```",VP``&P```)C;```'````M-L```<```"\VP``
M"@```,3;```-````S]L```D```#=VP``!````.?;```%````[-L```,```#R
MVP``&````/;;```*````#]P```0````:W```)@```!_<```.````1MP``'P`
M``!5W```%0```-+<```%````Z-P```<```#NW```#````/;<```(`````]T`
M``H````,W0``!@```!?=```(````'MT```(````GW0``!@```"K=```&````
M,=T``!0````XW0``#0```$W=```0````6]T``!L```!LW0``!````(C=```)
M````C=T``!````"7W0``"0```*C=```)````LMT```4```"\W0``&@```,+=
M```(````W=T```8```#FW0``#P```.W=```9````_=T```X````7W@``!P``
M`";>```'````+MX```4````VW@``"0```#S>```*````1MX```(```!1W@``
M!@```%3>```+````6]X```T```!GW@``"0```'7>```&````?]X```D```"&
MW@``!P```)#>```4````F-X``!T```"MW@``0@```,O>```E````#M\``"4`
M```TWP``!@```%K?```*````8=\```0```!LWP``"0```''?```(````>]\`
M`!$```"$WP``"0```);?```&````H-\```T```"GWP``!@```+7?```$````
MO-\``#D```#!WP``/0```/O?```Z````.>```!X```!TX```!0```)/@```.
M````F>````0```"HX```!@```*W@```'````M.```"$```"\X```#0```-[@
M```&````[.````0```#SX```$0```/C@```&````"N$```H````1X0``(@``
M`!SA```$````/^$```4```!$X0``'0```$KA```$````:.$```P```!MX0``
M#@```'KA```*````B>$```@```"4X0``"0```)WA```%````I^$``#H```"M
MX0``,````.CA```U````&>(``"D```!/X@``1P```'GB```X````P>(``"D`
M``#ZX@``/P```"3C```N````9.,``"T```"3XP``'P```,'C```/````X>,`
M`!(```#QXP``"P````3D```F````$.0``"D````WY```)````&'D```F````
MAN0```@```"MY```"@```+;D```)````P>0```<```#+Y```(````-/D```@
M````].0``"8````5Y0``"@```#SE```9````1^4``"D```!AY0``%@```(OE
M```2````HN4```<```"UY0``"@```+WE```,````R.4```\```#5Y0``$```
M`.7E``!`````]N4``'`````WY@``9@```*CF```.````#^<```D````>YP``
M"@```"CG```2````,^<``!,```!&YP``#````%KG```&````9^<``!4```!N
MYP``#P```(3G```3````E.<``!(```"HYP``$````+OG```1````S.<``!P`
M``#>YP``(P```/OG``!J````'^@```\```"*Z```!0```)KH```0````H.@`
M``D```"QZ```!````+OH```+````P.@``"````#,Z```%````.WH```,````
M`ND```P````/Z0``#P```!SI```5````+.D``"D```!"Z0``*@```&SI```F
M````E^D``"<```"^Z0``*0```.;I```J````$.H``!D````[Z@``0@```%7J
M```1````F.H``!(```"JZ@``$P```+WJ```4````T>H```\```#FZ@``%@``
M`/;J```7````#>L``!`````EZP``$0```#;K```T````2.L``!,```!]ZP``
M$@```)'K```U````I.L``!0```#:ZP``!P```._K```,````]^L``"`````$
M[```$````"7L```4````-NP``!$```!+[```%P```%WL```<````=>P``!,`
M``"2[```%````*;L```:````N^P``!$```#6[```&@```.CL```>`````^T`
M`!H````B[0``$P```#WM```5````4>T``!$```!G[0``%P```'GM```4````
MD>T``!<```"F[0``%0```+[M```)````U.T``!````#>[0``&0```._M```$
M````">X```<````.[@``"P```!;N```1````(NX```8````T[@``!@```#ON
M```&````0NX```4```!)[@``!P```$_N```'````5^X```4```!?[@``!@``
M`&7N```&````;.X```0```!S[@``!````'CN```'````?>X```X```"%[@``
M#````)3N```,````H>X```T```"N[@``"@```+SN```.````Q^X```4```#6
M[@``*````-SN```.````!>\```P````4[P``#P```"'O```*````,>\```@`
M```\[P``"0```$7O```K````3^\```0```![[P``"````(#O```F````B>\`
M`!(```"P[P``!@```,/O```*````RN\```<```#5[P``"````-WO```@````
MYN\```D````'\```#0```!'P```4````'_````P````T\```#0```$'P```.
M````3_```!8```!>\```$0```'7P```&````A_````,```".\```!@```)+P
M```9````F?````<```"S\```!````+OP```+````P/````L```#,\```!P``
M`-CP```%````X/````<```#F\```%@```.[P```-````!?$```T````3\0``
M"@```"'Q```0````+/$```\````]\0``$0```$WQ```7````7_$```H```!W
M\0``$0```(+Q```(````E/$```0```"=\0``#P```*+Q```Z````LO$```4`
M``#M\0``#````//Q```>`````/(```X````?\@``$````"[R```+````/_(`
M``P```!+\@``"0```%CR```'````8O(```H```!J\@``"0```'7R```.````
M?_(``!````".\@``&P```)_R```8````N_(``!H```#4\@``"@```._R```)
M````^O(```H````$\P``#`````_S```/````'/,```@````L\P``!@```#7S
M```<````//,```<```!9\P``!0```&'S```+````9_,``$<```!S\P``#0``
M`+OS```)````R?,```0```#3\P```P```-CS```3````W/,``!,```#P\P``
M$P````3T```*````&/0```(````C]```!````";T```E````*_0```,```!1
M]```!0```%7T```J````6_0```H```"&]```!0```)'T```$````E_0```H`
M``"<]```#0```*?T```&````M?0```@```"\]```"````,7T```$````SO0`
M``4```#3]```:````-GT```)````0O4```P```!,]0``$````%GU```%````
M:O4```8```!P]0``&P```'?U```O````D_4``!````##]0``"@```-3U```/
M````W_4```H```#O]0``"0```/KU```3````!/8``!L````8]@``&````#3V
M```7````3?8``!<```!E]@``'P```'WV```.````G?8```,```"L]@``!P``
M`+#V```(````N/8```<```#!]@``"0```,GV```*````T_8```L```#>]@``
M!P```.KV``!1````\O8``!````!$]P``#````%7W```-````8O<``!H```!P
M]P``2@```(OW```9````UO<```8```#P]P``&@```/?W```E````$O@```8`
M```X^```!@```#_X```?````1O@```8```!F^```"0```&WX```8````=_@`
M`!<```"0^```*````*CX```&````T?@```T```#8^```(@```.;X``!7````
M"?D``!,```!A^0``(P```'7Y```3````F?D```(```"M^0``"P```+#Y```(
M````O/D```T```#%^0``"@```-/Y```,````WOD```<```#K^0``%````//Y
M```&````"/H```@````/^@``#@```!CZ```'````)_H```H````O^@``"P``
M`#KZ```R````1OH```<```!Y^@``#````('Z```-````COH```P```"<^@``
M"0```*GZ```)````L_H```H```"]^@``!P```,CZ```)````T/H```<```#:
M^@``"@```.+Z```;````[?H``!(````)^P``"@```!S[```6````)_L```@`
M```^^P``"0```$?[```0````4?L```<```!B^P``$@```&K[```$````??L`
M``<```""^P``!0```(K[```%````D/L```L```"6^P``%````*+[```1````
MM_L``!H```#)^P``%@```.3[```4````^_L``!<````0_```&````"C\```<
M````0?P``!D```!>_```!P```'C\```%````@/P```T```"&_```#````)3\
M```1````H?P```@```"S_```"````+S\```7````Q?P```L```#=_```#```
M`.G\```?````]OP``!H````6_0``$P```#']```$````1?T```H```!*_0``
M!````%7]```-````6OT```P```!H_0``!0```'7]```)````>_T```4```"%
M_0``!P```(O]```%````D_T```0```"9_0```@```)[]```X````H?T``"P`
M``#:_0``$@````?^```I````&OX``#(```!$_@``"@```'?^```L````@OX`
M`"X```"O_@``,P```-[^```S````$O\``#@```!&_P``#P```'__```8````
MC_\``!````"H_P``'````+G_```/````UO\``!,```#F_P``%0```/K_```4
M````$``!`!(````E``$`)````#@``0`(````70`!`"0```!F``$`$P```(L`
M`0`4````GP`!`!4```"T``$`+0```,H``0`M````^``!`#$````F`0$`+@``
M`%@!`0`O````AP$!`"P```"W`0$`8@```.0!`0`3````1P(!``T```!;`@$`
M"````&D"`0`7````<@(!``@```"*`@$`#````),"`0`K````H`(!`"$```#,
M`@$`&@```.X"`0`)````"0,!`$4````3`P$`00```%D#`0`%````FP,!``0`
M``"A`P$`$P```*8#`0`.````N@,!`!,```#)`P$`&````-T#`0`&````]@,!
M``D```#]`P$`"@````<$`0`/````$@0!`!`````B!`$`!P```#,$`0`.````
M.P0!``T```!*!`$`#````%@$`0`*````900!``D```!P!`$`"@```'H$`0`/
M````A00!``@```"5!`$`#P```)X$`0`(````K@0!`!H```"W!`$`!0```-($
M`0`-````V`0!`!L```#F!`$`"`````(%`0`&````"P4!`!0````2!0$`$0``
M`"<%`0`.````.04!`#@```!(!0$``@```($%`0`&````A`4!``X```"+!0$`
M!0```)H%`0`'````H`4!``X```"H!0$`!@```+<%`0`H````O@4!``P```#G
M!0$`'````/0%`0`$````$08!`"D````6!@$`%P```$`&`0`?````6`8!`%P`
M``!X!@$`%````-4&`0`^````Z@8!`!\````I!P$`$````$D'`0`'````6@<!
M``X```!B!P$`#````'$'`0`,````?@<!`!,```"+!P$`"@```)\'`0`=````
MJ@<!`!D```#(!P$`!0```.('`0`1````Z`<!`!$```#Z!P$`)`````P(`0`2
M````,0@!`!4```!$"`$`$@```%H(`0`.````;0@!`!D```!\"`$`"````)8(
M`0`)````GP@!``T```"I"`$`"@```+<(`0`'````P@@!``\```#*"`$`!@``
M`-H(`0`+````X0@!`!H```#M"`$`"@````@)`0`'````$PD!``@````;"0$`
M!0```"0)`0`?````*@D!``8```!*"0$`$````%$)`0`(````8@D!``T```!K
M"0$`"````'D)`0`>````@@D!`!(```"A"0$`+````+0)`0`:````X0D!``D`
M``#\"0$`"@````8*`0`5````$0H!``4````G"@$`%````"T*`0`$````0@H!
M`!````!'"@$`!@```%@*`0`'````7PH!`!X```!G"@$`*````(8*`0`*````
MKPH!`!P```"Z"@$`$0```-<*`0`+````Z0H!`!H```#U"@$`%````!`+`0`$
M````)0L!``0````J"P$`"P```"\+`0`%````.PL!``8```!!"P$`"````$@+
M`0`&````40L!`!L```!8"P$`-````'0+`0`T````J0L!`"````#>"P$`*0``
M`/\+`0`@````*0P!`$$```!*#`$`&@```(P,`0`H````IPP!`"D```#0#`$`
M4````/H,`0`B````2PT!``8```!N#0$`"````'4-`0`%````?@T!``@```"$
M#0$`&0```(T-`0`9````IPT!`"H```#!#0$`(P```.P-`0`9````$`X!`"X`
M```J#@$`-````%D.`0`(````C@X!`!<```"7#@$`"@```*\.`0`'````N@X!
M`"$```#"#@$`$````.0.`0`.````]0X!``L````$#P$`!P```!`/`0`3````
M&`\!``@````L#P$`"P```#4/`0`*````00\!`!0```!,#P$`#P```&$/`0`R
M````<0\!``L```"D#P$`!0```+`/`0`%````M@\!``4```"\#P$`%P```,(/
M`0`/````V@\!``0```#J#P$`"@```.\/`0`)````^@\!``L````$$`$`#0``
M`!`0`0`,````'A`!``X````K$`$`!0```#H0`0`$````0!`!``T```!%$`$`
M,@```%,0`0`8````AA`!`$4```"?$`$`%P```.40`0`'````_1`!`!X````%
M$0$`#````"01`0`4````,1$!``4```!&$0$`%````$P1`0`&````81$!``<`
M``!H$0$`#@```'`1`0`J````?Q$!``8```"J$0$`#````+$1`0`/````OA$!
M``T```#.$0$`$0```-P1`0`+````[A$!`#8```#Z$0$`"@```#$2`0`B````
M/!(!``L```!?$@$`#P```&L2`0`R````>Q(!`"4```"N$@$`,````-02`0`Q
M````!1,!`"T````W$P$`#@```&43`0`%````=!,!``X```!Z$P$`$P```(D3
M`0`2````G1,!``<```"P$P$`$0```+@3`0`3````RA,!``<```#>$P$`%```
M`.83`0`8````^Q,!``<````4%`$`!0```!P4`0`,````(A0!``P````O%`$`
M$@```#P4`0`$````3Q0!``<```!4%`$`"@```%P4`0`+````9Q0!``P```!S
M%`$`#@```(`4`0`.````CQ0!``4```">%`$`!0```*04`0`N````JA0!`"8`
M``#9%`$`(P`````5`0`#````)!4!`!(````H%0$`!@```#L5`0`>````0A4!
M`!@```!A%0$`)0```'H5`0`-````H!4!``D```"N%0$`'P```+@5`0`#````
MV!4!``<```#<%0$`"@```.05`0`"````[Q4!``P```#R%0$`%0```/\5`0`+
M````%18!`!D````A%@$`(````#L6`0`2````7!8!``4```!O%@$`"@```'46
M`0`5````@!8!`!(```"6%@$`#````*D6`0`$````MA8!``D```"[%@$`!P``
M`,46`0`,````S18!`%(```#:%@$`%P```"T7`0`D````11<!`!(```!J%P$`
M!P```'T7`0`&````A1<!``X```",%P$`#@```)L7`0`,````JA<!``P```"W
M%P$`#````,07`0`-````T1<!`!4```#?%P$`$@```/47`0`0````"!@!``\`
M```9&`$`%````"D8`0`*````/A@!`!L```!)&`$`$````&48`0`+````=A@!
M`!L```""&`$`:0```)X8`0`:````"!D!`!<````C&0$`&0```#L9`0`:````
M51D!`"4```!P&0$`)P```)89`0`:````OAD!`!<```#9&0$`&P```/$9`0`9
M````#1H!`!\````G&@$`%````$<:`0`3````7!H!``@```!P&@$`!P```'D:
M`0`(````@1H!``D```"*&@$`%0```)0:`0`-````JAH!`",```"X&@$`#0``
M`-P:`0`3````ZAH!``@```#^&@$``P````<;`0!&````"QL!`#\```!2&P$`
M-P```)(;`0!7````RAL!``4````B'`$`'P```"@<`0`O````2!P!``H```!X
M'`$`"````(,<`0`-````C!P!`"T```":'`$`!````,@<`0`4````S1P!`$\`
M``#B'`$`)0```#(=`0`2````6!T!`"````!K'0$`'````(P=`0`+````J1T!
M`!\```"U'0$`'0```-4=`0`E````\QT!`"`````9'@$`)````#H>`0`@````
M7QX!``L```"`'@$`!P```(P>`0`-````E!X!``P```"B'@$`%P```*\>`0`&
M````QQX!`#D```#.'@$`#`````@?`0`'````%1\!``D````='P$`$P```"<?
M`0`)````.Q\!``0```!%'P$`$````$H?`0`(````6Q\!``@```!D'P$`!```
M`&T?`0`+````<A\!``P```!^'P$`$@```(L?`0`1````GA\!``P```"P'P$`
M&@```+T?`0`/````V!\!``<```#H'P$`#0```/`?`0`0````_A\!`!$````/
M(`$`%````"$@`0`.````-B`!``P```!%(`$`+````%(@`0`3````?R`!`!P`
M``"3(`$`*````+`@`0`&````V2`!``<```#@(`$`$P```.@@`0`%````_"`!
M``0````"(0$`%P````<A`0`*````'R$!``P````J(0$`"0```#<A`0`&````
M02$!``D```!((0$`"````%(A`0`)````6R$!``H```!E(0$`$0```'`A`0`&
M````@B$!``X```")(0$`#@```)@A`0`-````IR$!``L```"U(0$`'0```,$A
M`0`+````WR$!``(```#K(0$`'````.XA`0`'````"R(!``8````3(@$`9```
M`!HB`0`)````?R(!``<```")(@$`)@```)$B`0`X````N"(!`!H```#Q(@$`
M*@````PC`0`[````-R,!`!@```!S(P$`*````(PC`0`T````M2,!`!D```#J
M(P$`%0````0D`0`%````&B0!``<````@)`$`"````"@D`0`'````,20!``4`
M```Y)`$`!P```#\D`0`.````1R0!``D```!6)`$`!@```&`D`0`(````9R0!
M``L```!P)`$`!P```'PD`0`(````A"0!``<```"-)`$`%@```)4D`0`)````
MK"0!``8```"V)`$`"P```+TD`0`0````R20!``8```#:)`$`'````.$D`0`4
M````_B0!``<````3)0$`$0```!LE`0`(````+24!``X````V)0$`"````$4E
M`0`%````3B4!`!````!4)0$`$````&4E`0`&````=B4!`!D```!])0$`"@``
M`)<E`0`<````HB4!``<```"_)0$`!0```,<E`0`0````S24!`!0```#>)0$`
M"P```/,E`0`-````_R4!`"@````-)@$`&````#8F`0`7````3R8!``0```!G
M)@$`"0```&PF`0`*````=B8!``<```"!)@$``@```(DF`0`(````C"8!`",`
M``"5)@$`.````+DF`0`F````\B8!`#$````9)P$`)P```$LG`0!D````<R<!
M`!0```#8)P$`50```.TG`0`X````0R@!`$H```!\*`$`6P```,<H`0`H````
M(RD!`#@```!,*0$`*````(4I`0`L````KBD!`"8```#;*0$`&P````(J`0`^
M````'BH!`*D!``!=*@$`(P````<L`0`7````*RP!`$@```!#+`$`A0```(PL
M`0`P````$BT!`!4```!#+0$`*````%DM`0`B````@BT!`"(```"E+0$`(```
M`,@M`0`E````Z2T!`$$````/+@$`6P```%$N`0!)````K2X!`#$```#W+@$`
M'0```"DO`0`8````1R\!`"L```!@+P$`(0```(PO`0`?````KB\!`"L```#.
M+P$`(0```/HO`0`G````'#`!`#H```!$,`$`'0```'\P`0`1````G3`!`#,`
M``"O,`$`)0```.,P`0`G````"3$!`"`````Q,0$`'P```%(Q`0`P````<C$!
M`&D```"C,0$`,0````TR`0!!````/S(!`#,```"!,@$`)0```+4R`0`]````
MVS(!`&4````9,P$`30```'\S`0`O````S3,!`"X```#],P$`*0```"PT`0`P
M````5C0!`"P```"'-`$`5````+0T`0!:````"34!`"@```!D-0$`)@```(TU
M`0!(````M#4!`$H```#]-0$`*P```$@V`0`>````=#8!`#(```"3-@$`+P``
M`,8V`0`L````]C8!`"T````C-P$`<0```%$W`0!F````PS<!`&\````J.`$`
MLP```)HX`0`7````3CD!`"4```!F.0$`,@```(PY`0`I````OSD!`#X```#I
M.0$`(@```"@Z`0!2````2SH!`"(```">.@$`)0```,$Z`0`+````YSH!`+$`
M``#S.@$`10```*4[`0`A````ZSL!`#`````-/`$`)0```#X\`0`<````9#P!
M`#$```"!/`$`!P```+,\`0`'````NSP!``0```##/`$`#0```,@\`0`+````
MUCP!``X```#B/`$`"P```/$\`0`%````_3P!`!`````#/0$``@```!0]`0!9
M````%ST!``4```!Q/0$`$@```'<]`0`$````BCT!``<```"//0$`"````)<]
M`0`%````H#T!``,```"F/0$`$````*H]`0`,````NST!`!,```#(/0$`#0``
M`-P]`0`"````ZCT!``<```#M/0$`!@```/4]`0`,````_#T!`!@````)/@$`
M!@```"(^`0`2````*3X!``P````\/@$``P```$D^`0`J````33X!``0```!X
M/@$`!@```'T^`0`'````A#X!`!\```",/@$`-0```*P^`0`N````XCX!`"\`
M```1/P$`%P```$$_`0`B````63\!`"4```!\/P$`(````*(_`0`;````PS\!
M`!@```#?/P$`)````/@_`0`?````'4`!`!H````]0`$`(0```%A``0`@````
M>D`!`!H```";0`$`,@```+9``0`9````Z4`!`!H````#00$`+P```!Y!`0`K
M````3D$!`!\```!Z00$`(P```)I!`0`?````OD$!`!H```#>00$`(0```/E!
M`0`E````&T(!`"8```!!0@$`)0```&A"`0`D````CD(!`!@```"S0@$`'0``
M`,Q"`0`D````ZD(!`!@````/0P$`(@```"A#`0`L````2T,!`"\```!X0P$`
M%0```*A#`0`E````OD,!`#P```#D0P$`'P```"%$`0`C````040!`!\```!E
M1`$`(````(5$`0`:````ID0!`!@```#!1`$`)@```-I$`0`>`````44!`"D`
M```@10$`'@```$I%`0`Q````:44!``D```";10$`#````*5%`0`,````LD4!
M`!<```"_10$`+P```-=%`0`D````!T8!``<````L1@$`%````#1&`0`.````
M248!``T```!81@$`!0```&9&`0`'````;$8!`"(```!T1@$`)0```)=&`0`:
M````O48!`!T```#81@$`&@```/9&`0`'````$4<!`,<````91P$`"P```.%'
M`0`<````[4<!`!4````*2`$`!@```"!(`0`)````)T@!``L````Q2`$`#0``
M`#U(`0`7````2T@!``8```!C2`$`,P```&I(`0`3````GD@!`!,```"R2`$`
M!P```,9(`0`/````SD@!``<```#>2`$`,@```.9(`0`$````&4D!`"$````>
M20$`$P```$!)`0`,````5$D!`!$```!A20$`,@```'-)`0`6````IDD!``@`
M``"]20$`'0```,9)`0`)````Y$D!``H```#N20$`%````/E)`0`*````#DH!
M`!T````92@$`"````#=*`0`?````0$H!``@```!@2@$`&@```&E*`0`G````
MA$H!``8```"L2@$`%0```+-*`0`'````R4H!``@```#12@$`"0```-I*`0`_
M````Y$H!``<````D2P$`#P```"Q+`0`.````/$L!`!````!+2P$`"0```%Q+
M`0`)````9DL!``@```!P2P$`!P```'E+`0`9````@4L!``H```";2P$`%P``
M`*9+`0`4````ODL!``H```#32P$`#````-Y+`0`7````ZTL!``0````#3`$`
M*@````A,`0`,````,TP!`!$```!`3`$`!P```%),`0`"````6DP!`!````!=
M3`$`&````&Y,`0`+````ATP!``,```"33`$`"````)=,`0`&````H$P!``<`
M``"G3`$`#0```*],`0`+````O4P!``X```#)3`$`+P```-A,`0`@````"$T!
M`!P````I30$`%0```$9-`0`K````7$T!``P```"(30$`,0```)5-`0`%````
MQTT!`!(```#-30$`/P```.!-`0`2````($X!``H````S3@$`!@```#Y.`0`$
M````14X!``0```!*3@$`"@```$].`0`3````6DX!``4```!N3@$`!@```'1.
M`0`&````>TX!``@```""3@$`!````(M.`0`,````D$X!``H```"=3@$`.0``
M`*A.`0`N````XDX!`"D````13P$`!0```#M/`0`8````04\!`!D```!:3P$`
M'P```'1/`0`=````E$\!`!$```"R3P$``@```,1/`0`$````QT\!``H```#,
M3P$`!@```-=/`0`%````WD\!``,```#D3P$`#````.A/`0!%````]4\!`#(`
M```[4`$`,0```&Y0`0`:````H%`!`#0```"[4`$`*````/!0`0!3````&5$!
M`#(```!M40$`&0```*!1`0!R````NE$!`"`````M4@$`-0```$Y2`0`A````
MA%(!`$4```"F4@$`,````.Q2`0`H````'5,!`"@```!&4P$`*0```&]3`0`F
M````F5,!`"4```#`4P$`*````.93`0`H````#U0!`"(````X5`$`*P```%M4
M`0`P````AU0!`!(```"X5`$`$P```,M4`0`0````WU0!`'D```#P5`$`"0``
M`&I5`0"A````=%4!`',````65@$`?````(I6`0`K````!U<!`%0````S5P$`
M%P```(A7`0`G````H%<!`!8```#(5P$`%0```-]7`0`/````]5<!`!<````%
M6`$`'P```!U8`0`.````/5@!`$````!,6`$`'P```(U8`0`<````K5@!`%$`
M``#*6`$`&@```!Q9`0`4````-UD!``H```!,60$`!0```%=9`0`&````75D!
M``@```!D60$`!0```&U9`0`2````<UD!`!````"&60$`$P```)=9`0`=````
MJUD!``\```#)60$`#P```-E9`0`0````Z5D!``0```#Z60$`"0```/]9`0`)
M````"5H!``<````36@$`"P```!M:`0`%````)UH!``L````M6@$`!P```#E:
M`0`%````05H!`!0```!'6@$`#@```%Q:`0`+````:UH!``<```!W6@$`"```
M`']:`0`/````B%H!``P```"86@$`"0```*5:`0`(````KUH!``P```"X6@$`
M!@```,5:`0`/````S%H!``<```#<6@$`!@```.1:`0`4````ZUH!``8`````
M6P$`#`````=;`0`1````%%L!``@````F6P$`!````"];`0`9````-%L!`!$`
M``!.6P$`"@```&!;`0`8````:UL!`!,```"$6P$`'````)A;`0`1````M5L!
M``\```#'6P$`!P```-=;`0`$````WUL!`!D```#D6P$`!P```/Y;`0`"````
M!EP!``(````)7`$`$0````Q<`0`)````'EP!``8````H7`$`$@```"]<`0`7
M````0EP!``8```!:7`$`)P```&%<`0`"````B5P!``0```",7`$`#P```)%<
M`0`3````H5P!``<```"U7`$`"0```+U<`0`'````QUP!`!$```#/7`$`!@``
M`.%<`0`8````Z%P!``8````!70$`$P````A=`0`0````'%T!`!(````M70$`
M`@```$!=`0`&````0UT!``P```!*70$`"0```%==`0`1````85T!`"(```!S
M70$`!P```)9=`0`'````GET!``L```"F70$`!0```+)=`0`%````N%T!``(`
M``"^70$`"P```,%=`0!(`0``S5T!`!`````67P$`%P```"=?`0`+````/U\!
M``8```!+7P$`"0```%)?`0`(````7%\!``H```!E7P$`%````'!?`0`9````
MA5\!`"T```"?7P$`)0```,U?`0`E````\U\!`",````98`$`'P```#U@`0`M
M````76`!``H```"+8`$`*@```)9@`0`+````P6`!`!,```#-8`$`#0```.%@
M`0`+````[V`!``4```#[8`$`+0````%A`0`-````+V$!`!T````]80$`%0``
M`%MA`0`/````<6$!`!$```"!80$`"0```)-A`0`<````G6$!`'0```"Z80$`
M#@```"]B`0`(````/F(!`!$```!'8@$`#0```%EB`0`6````9V(!`!<```!^
M8@$`%P```)9B`0`:````KF(!``8```#)8@$`OP```-!B`0`+````D&,!`!(`
M``"<8P$`'0```*]C`0`0````S6,!``H```#>8P$`$@```.EC`0`2````_&,!
M``@````/9`$`#P```!AD`0`P````*&0!`!D```!99`$`-@```'-D`0`]````
MJF0!`%````#H9`$`3P```#EE`0!8````B64!`%8```#B90$`.````#EF`0`4
M````<F8!`!<```"'9@$`$0```)]F`0`5````L68!`!T```#'9@$`"````.5F
M`0`&````[F8!``\```#U9@$`!`````5G`0`0````"F<!``\````;9P$`,@``
M`"MG`0`P````7F<!`"\```"/9P$`+@```+]G`0`S````[F<!`#`````B:`$`
M$0```%-H`0`.````96@!`!$```!T:`$`"0```(9H`0`&````D&@!`!D```"7
M:`$`%P```+%H`0`'````R6@!``X```#1:`$`$0```.!H`0`>````\F@!`!P`
M```1:0$`$P```"YI`0`0````0FD!``T```!3:0$`#0```&%I`0`*````;VD!
M`"8```!Z:0$`$P```*%I`0`8````M6D!`!(```#.:0$`5````.%I`0`W````
M-FH!`!@```!N:@$`)````(=J`0`&````K&H!``<```"S:@$`-@```+MJ`0`-
M````\FH!``<`````:P$`"@````AK`0`(````$VL!``@````<:P$`!0```"5K
M`0`(````*VL!``L````T:P$`!@```$!K`0`C````1VL!``X```!K:P$`#```
M`'IK`0`3````AVL!`!8```";:P$`*P```+)K`0`+````WFL!`"0```#J:P$`
M%P````]L`0`D````)VP!`!T```!,;`$`%````&IL`0`2````?VP!``X```"2
M;`$`'````*%L`0`6````OFP!``<```#5;`$`!@```-UL`0`(````Y&P!``X`
M``#M;`$`!P```/QL`0`*````!&T!`!$````/;0$`"0```"%M`0`0````*VT!
M`!@````\;0$`*@```%5M`0`(````@&T!`!$```");0$`!0```)MM`0`/````
MH6T!``P```"Q;0$`,0```+YM`0`O````\&T!``D````@;@$`"````"IN`0`&
M````,VX!``4````Z;@$`"0```$!N`0`0````2FX!``P```!;;@$`%0```&AN
M`0`T````?FX!`"@```"S;@$`)P```-QN`0`D````!&\!`#$````I;P$`"```
M`%MO`0`&````9&\!``D```!K;P$`!P```'5O`0`W````?6\!`"\```"U;P$`
M-@```.5O`0!>````''`!`#4```![<`$`-0```+%P`0!*````YW`!`$L````R
M<0$`-0```'YQ`0!"````M'$!`#$```#W<0$`-````"ER`0!,````7G(!`#4`
M``"K<@$`.P```.%R`0`L````'7,!`!8```!*<P$`&@```&%S`0`F````?',!
M`"L```"C<P$`*P```,]S`0`3````^W,!`!$````/=`$`"P```"%T`0`,````
M+70!`!D````Z=`$`)P```%1T`0`'````?'0!``T```"$=`$`%P```))T`0`D
M````JG0!``8```#/=`$`!P```-9T`0`)````WG0!``@```#H=`$`*````/%T
M`0`/````&G4!``H````J=0$`"````#5U`0`&````/G4!``4```!%=0$`!P``
M`$MU`0`%````4W4!``H```!9=0$`)P```&1U`0`0````C'4!``D```"==0$`
M!0```*=U`0`'````K74!``<```"U=0$`!0```+UU`0`-````PW4!``8```#1
M=0$`$P```-AU`0`#````['4!``@```#P=0$`!@```/EU`0`-`````'8!``@`
M```.=@$`(````!=V`0`1````.'8!``D```!*=@$`$@```%1V`0`,````9W8!
M``<```!T=@$``P```'QV`0`#````@'8!`!0```"$=@$`'@```)EV`0`4````
MN'8!`#(```#-=@$`"`````!W`0`)````"7<!``@````3=P$`!P```!QW`0!+
M````)'<!`"0```!P=P$`+0```)5W`0`H````PW<!`"$```#L=P$`!@````YX
M`0`&````%7@!`!@````<>`$`(0```#5X`0`D````5W@!`"X```!\>`$`)0``
M`*MX`0`M````T7@!`&````#_>`$`+@```&!Y`0`2````CWD!``<```"B>0$`
M$P```*IY`0`)````OGD!`!$```#(>0$`#P```-IY`0`0````ZGD!`!````#[
M>0$`$`````QZ`0`0````'7H!``\````N>@$`"0```#YZ`0`7````2'H!`"$`
M``!@>@$`%````()Z`0`8````EWH!``,```"P>@$`!@```+1Z`0`1````NWH!
M`%4```#->@$`+0```"-[`0!<````47L!``0```"N>P$`%@```+-[`0`%````
MRGL!``0```#0>P$`$@```-5[`0`/````Z'L!`!P```#X>P$`)````!5\`0`P
M````.GP!`#P```!K?`$`+@```*A\`0`/````UWP!`",```#G?`$`!0````M]
M`0`0````$7T!`!H````B?0$`#0```#U]`0`9````2WT!`!4```!E?0$`&P``
M`'M]`0`1````EWT!`!D```"I?0$`$P```,-]`0`-````UWT!``8```#E?0$`
M#````.Q]`0`'````^7T!`!<````!?@$`$@```!E^`0`.````+'X!``@````[
M?@$`!0```$1^`0`+````2GX!``L```!6?@$`!P```&)^`0`/````:GX!``8`
M``!Z?@$`!@```(%^`0`5````B'X!``@```">?@$`"@```*=^`0`&````LGX!
M``H```"Y?@$`"````,1^`0`$````S7X!``0```#2?@$`%P```-=^`0!,````
M[WX!`"0````\?P$`#P```&%_`0`.````<7\!``4```"`?P$`'````(9_`0`1
M````HW\!`!(```"U?P$`+@```,A_`0`]````]W\!`"`````U@`$`"````%:`
M`0`P````7X`!`!H```"0@`$`"@```*N``0`*````MH`!``\```#!@`$`!@``
M`-&``0`)````V(`!`!<```#B@`$`#P```/J``0`)````"H$!`!(````4@0$`
M+0```">!`0`K````58$!`"\```"!@0$`+0```+&!`0`A````WX$!`"8````!
M@@$`)0```"B"`0`I````3H(!`"D```!X@@$`-0```**"`0`K````V((!`"0`
M```$@P$`)@```"F#`0`A````4(,!`"H```!R@P$`.@```)V#`0`N````V(,!
M`"0````'A`$`,````"R$`0`Y````780!`"4```"7A`$`(0```+V$`0`T````
MWX0!`"4````4A0$`&0```#J%`0`O````5(4!`",```"$A0$`)@```*B%`0`:
M````SX4!`+$```#JA0$`$@```)R&`0`@````KX8!`"D```#0A@$`*0```/J&
M`0`Q````)(<!`"(```!6AP$`(0```'F'`0`E````FX<!`"D```#!AP$`+```
M`.N'`0`Z````&(@!`"P```!3B`$`DP```("(`0`E````%(D!`!L````ZB0$`
M)@```%:)`0`O````?8D!`"\```"MB0$`1@```-V)`0!$````)(H!``T```!I
MB@$`!P```'>*`0`%````?XH!``@```"%B@$`#@```(Z*`0`-````G8H!`!4`
M``"KB@$`"0```,&*`0`,````RXH!`!4```#8B@$`"@```.Z*`0`$````^8H!
M``\```#^B@$`$`````Z+`0`,````'XL!``\````LBP$`%0```#R+`0`0````
M4HL!`!0```!CBP$`#0```'B+`0!"````AHL!``H```#)BP$`$````-2+`0`&
M````Y8L!``\```#LBP$``@```/R+`0!+````_XL!``4```!+C`$`(P```%&,
M`0`7````=8P!``4```"-C`$`#@```).,`0`,````HHP!``,```"OC`$`$0``
M`+.,`0`(````Q8P!`!````#.C`$`$0```-^,`0`-````\8P!`!,```#_C`$`
M&P```!.-`0`=````+XT!`",```!-C0$`'P```'&-`0`=````D8T!``D```"O
MC0$`!P```+F-`0`-````P8T!`!<```#/C0$`#P```.>-`0`.````]XT!``T`
M```&C@$`&@```!2.`0`B````+XX!``T```!2C@$`#@```&".`0`G````;XX!
M`!8```"7C@$`*P```*Z.`0`.````VHX!`!@```#IC@$`%P````*/`0`7````
M&H\!`!4````RCP$`,0```$B/`0`-````>H\!``8```"(CP$`"````(^/`0`/
M````F(\!``4```"HCP$`!@```*Z/`0`K````M8\!`"P```#ACP$`!0````Z0
M`0`)````%)`!`!X````>D`$`"P```#V0`0`2````29`!`!(```!<D`$`!P``
M`&^0`0`F````=Y`!`!4```">D`$`&P```+20`0`8````T)`!`!$```#ID`$`
M%0```/N0`0`)````$9$!``D````;D0$`(P```"61`0`H````29$!`#T```!R
MD0$`"````+"1`0`6````N9$!`!X```#0D0$`"````.^1`0`+````^)$!`#(`
M```$D@$`$````#>2`0`%````2)(!``8```!.D@$``P```%62`0`'````69(!
M``<```!AD@$`#````&F2`0`,````=I(!``\```"#D@$`$````).2`0`-````
MI)(!``T```"RD@$`%````,"2`0`9````U9(!`!<```#OD@$`%@````>3`0`4
M````'I,!``L````SDP$`!0```#^3`0`(````19,!``H```!.DP$``@```%F3
M`0`%````7),!`!````!BDP$`(P```'.3`0`3````EY,!`!(```"KDP$`"0``
M`+Z3`0`0````R),!``\```#9DP$`$0```.F3`0`:````^Y,!`"T````6E`$`
M*P```$24`0`+````<)0!``X```!\E`$`=@```(N4`0`3`````I4!`!\````6
ME0$`$````#:5`0`'````1Y4!``4```!/E0$`'0```%65`0`Q````<Y4!`"\`
M``"EE0$`'@```-65`0`@````])4!`!H````5E@$`&@```#"6`0`(````2Y8!
M``<```!4E@$`!P```%R6`0`&````9)8!`!````!KE@$`#@```'R6`0`1````
MBY8!``\```"=E@$`%0```*V6`0`/````PY8!``P```#3E@$`"@```."6`0`'
M````ZY8!``@```#SE@$`%````/R6`0`.````$9<!`#<````@EP$`#P```%B7
M`0`(````:)<!``8```!QEP$`$P```'B7`0`+````C)<!`!H```"8EP$`"@``
M`+.7`0`@````OI<!`"H```#?EP$`*0````J8`0`?````-)@!`"````!4F`$`
M*@```'68`0`?````H)@!`!@```#`F`$`!0```-F8`0`=````WY@!``\```#]
MF`$`#@````V9`0`#````')D!``0````@F0$`!P```"69`0`-````+9D!``\`
M```[F0$`"P```$N9`0`5````5YD!``L```!MF0$`!0```'F9`0`%````?YD!
M`!<```"%F0$`&0```)V9`0`/````MYD!``L```#'F0$`#````-.9`0`/````
MX)D!`"8```#PF0$`!@```!>:`0`&````'IH!``T````EF@$`"@```#.:`0`+
M````/IH!``8```!*F@$`#@```%&:`0`$````8)H!`!<```!EF@$`"P```'V:
M`0`'````B9H!`"H```"1F@$`#P```+R:`0"#````S)H!`!(```!0FP$`"0``
M`&.;`0`'````;9L!``L```!UFP$`!P```(&;`0`)````B9L!``0```"3FP$`
M#0```)B;`0`#````IIL!``4```"JFP$`"@```+";`0`3````NYL!`!(```#/
MFP$`%````.*;`0`:````]YL!``(````2G`$`"0```!6<`0`+````'YP!``0`
M```KG`$`"@```#"<`0`%````.YP!`"8```!!G`$`"````&B<`0`&````<9P!
M`!0```!XG`$`)P```(V<`0`.````M9P!``<```#$G`$`!P```,R<`0`%````
MU)P!``D```#:G`$`"P```.2<`0`'````\)P!``8```#XG`$`"P```/^<`0`0
M````"YT!``T````<G0$`!@```"J=`0`'````,9T!``<````YG0$`%````$&=
M`0`=````5IT!`#\```!TG0$`+````+2=`0`Q````X9T!``<````3G@$`"@``
M`!N>`0`$````)IX!``D````KG@$`"````#6>`0`=````/IX!``D```!<G@$`
M!@```&:>`0`-````;9X!``8```![G@$`!````(*>`0`R````AYX!`#0```"Z
MG@$`-````.^>`0`C````))\!``4```!(GP$`'0```$Z?`0`$````;)\!``@`
M``!QGP$`"````'J?`0`D````@Y\!``L```"HGP$`!0```+2?`0`(````NI\!
M`!\```##GP$`"````..?`0`(````[)\!`!8```#UGP$`!@````R@`0`&````
M$Z`!``<````:H`$`!0```"*@`0`-````**`!`!`````VH`$`#0```$>@`0`(
M````5:`!``D```!>H`$`!0```&B@`0`[````;J`!`#@```"JH`$`/````..@
M`0`G````(*$!`#@```!(H0$`0````(&A`0`P````PJ$!`#H```#SH0$`-0``
M`"ZB`0`^````9*(!`"D```"CH@$`$@```,VB`0`6````X*(!``T```#WH@$`
M*@````6C`0`<````,*,!`!T```!-HP$`'````&NC`0`'````B*,!``D```"0
MHP$`"0```)JC`0`(````I*,!`"@```"MHP$`)P```-:C`0`E````_J,!``D`
M```DI`$`&@```"ZD`0`O````2:0!`"8```!YI`$`$0```*"D`0`&````LJ0!
M``D```"YI`$`#````,.D`0`,````T*0!``\```#=I`$`-@```.VD`0""````
M)*4!`'8```"GI0$`#P```!ZF`0`+````+J8!``P````ZI@$`$0```$>F`0`2
M````6:8!`!````!LI@$`!P```'VF`0`8````A:8!``\```">I@$`%@```*ZF
M`0`4````Q:8!`!(```#:I@$`#P```.VF`0`?````_:8!`"H````=IP$`A@``
M`$BG`0`1````SZ<!``4```#AIP$`%P```.>G`0`)````_Z<!``0````)J`$`
M"@````ZH`0`>````&:@!`!$````XJ`$`#@```$JH`0`.````6:@!``P```!H
MJ`$`$P```'6H`0`>````B:@!`"````"HJ`$`'@```,FH`0`@````Z*@!`!\`
M```)J0$`(0```"FI`0`;````2ZD!`#@```!GJ0$`#P```*"I`0`1````L*D!
M`!````#"J0$`$@```-.I`0`-````YJD!`!(```#TJ0$`%`````>J`0`0````
M'*H!`!(````MJ@$`,@```$"J`0`6````<ZH!`!0```"*J@$`/0```)^J`0`4
M````W:H!``H```#RJ@$`$P```/VJ`0!!````$:L!`!L```!3JP$`$P```&^K
M`0`2````@ZL!`!T```"6JP$`&````+2K`0`6````S:L!`!<```#DJP$`'@``
M`/RK`0`:````&ZP!`"@````VK`$`(P```%^L`0`:````@ZP!`!4```">K`$`
M%@```+2L`0`1````RZP!`!<```#=K`$`&0```/6L`0`9````#ZT!`!<````I
MK0$`"````$&M`0`0````2JT!``0```!;K0$`!````&"M`0`%````9:T!``L`
M``!KK0$`#P```'>M`0`&````AZT!``D```".K0$`!P```)BM`0`)````H*T!
M``<```"JK0$`!@```+*M`0`(````N:T!``8```#"K0$`!@```,FM`0`#````
MT*T!``,```#4K0$`"````-BM`0`2````X:T!`!$```#TK0$`#@````:N`0`/
M````%:X!``H````EK@$`$@```#"N`0`$````0ZX!`"@```!(K@$`$@```'&N
M`0`0````A*X!`!@```"5K@$`"P```*ZN`0`)````NJX!``X```#$K@$`+0``
M`-.N`0`$`````:\!``@````&KP$`(@````^O`0`2````,J\!``8```!%KP$`
M"0```$RO`0`'````5J\!``4```!>KP$`!````&2O`0`1````::\!`!4```![
MKP$`%````)&O`0`.````IJ\!`!8```"UKP$`&````,RO`0`=````Y:\!`!L`
M```#L`$`"````!^P`0`%````*+`!``8````NL`$`(0```#6P`0`'````5[`!
M``4```!?L`$`#@```&6P`0`-````=+`!``<```""L`$`!@```(JP`0`'````
MD;`!``4```"9L`$`#P```)^P`0`/````K[`!``H```"_L`$`#P```,JP`0`1
M````VK`!`!8```#LL`$`%`````.Q`0`.````&+$!`!8````GL0$`"````#ZQ
M`0`%````1[$!`!$```!-L0$`-@```%^Q`0`%````EK$!``P```"<L0$`(P``
M`*FQ`0`6````S;$!`!0```#DL0$`%P```/FQ`0`,````$;(!``D````>L@$`
M!P```"BR`0`*````,+(!``D````[L@$`#@```$6R`0`0````5+(!`!T```!E
ML@$`(P```(.R`0`N````I[(!``H```#6L@$`!0```.&R`0`.````Y[(!``T`
M``#VL@$`$0````2S`0`(````%K,!``L````?LP$`)@```"NS`0`(````4K,!
M``L```!;LP$`%````&>S`0!1````?+,!`!0```#.LP$`"0```..S`0`%````
M[;,!``4```#SLP$`$P```/FS`0`5````#;0!`!,````CM`$`"P```#>T`0`"
M````0[0!``H```!&M`$`*@```%&T`0`#````?+0!``4```"`M`$`"@```(:T
M`0`*````D;0!``4```"<M`$`!0```**T`0`>````J+0!`!(```#'M`$`!@``
M`-JT`0`(````X;0!``@```#JM`$`!````/.T`0`%````^+0!`&$```#^M`$`
M"@```&"U`0`-````:[4!`!(```!YM0$`!0```(RU`0`%````DK4!`"<```"8
MM0$`-````,"U`0`3````];4!``@````)M@$`#````!*V`0`*````'[8!``D`
M```JM@$`&@```#2V`0`L````3[8!`"H```!\M@$`*0```*>V`0`8````T;8!
M`!X```#JM@$`#P````FW`0`#````&;<!``<````=MP$`"````"6W`0`(````
M+K<!``T````WMP$`$````$6W`0`,````5K<!``8```!CMP$`20```&JW`0`9
M````M+<!``H```#.MP$`#0```-FW`0`<````Y[<!`$T````$N`$`(````%*X
M`0`&````<[@!`!T```!ZN`$`*````)BX`0`(````P;@!``8```#*N`$`'0``
M`-&X`0`%````[[@!``@```#UN`$`*@```/ZX`0`I````*;D!`"X```!3N0$`
M$0```(*Y`0`%````E+D!`!X```":N0$`70```+FY`0`0````%[H!`"$````H
MN@$`$0```$JZ`0`#````7+H!``P```!@N@$`!@```&VZ`0`5````=+H!``L`
M``"*N@$`%````):Z`0`'````J[H!``D```"SN@$`!@```+VZ`0`)````Q+H!
M``P```#.N@$`!P```-NZ`0`*````X[H!``P```#NN@$`.0```/NZ`0`&````
M-;L!``X````\NP$`$````$N[`0`0````7+L!``T```!MNP$`#@```'N[`0`/
M````BKL!``T```":NP$`#0```*B[`0`-````MKL!``@```#$NP$`'@```,V[
M`0`1````[+L!``H```#^NP$`%P````F\`0`-````(;P!``H````OO`$`%```
M`#J\`0`'````3[P!`!````!7O`$`!````&B\`0`'````;;P!``4```!UO`$`
M!0```'N\`0`)````@;P!`!````"+O`$`%0```)R\`0`M````LKP!`!P```#@
MO`$`,0```/V\`0`J````+[T!`!D```!:O0$`'0```'2]`0`8````DKT!``0`
M``"KO0$`!0```+"]`0`.````MKT!``X```#%O0$`$@```-2]`0`#````Y[T!
M``T```#KO0$`(P```/F]`0`+````';X!``H````IO@$`(````#2^`0`:````
M5;X!`!(```!PO@$`!````(.^`0`0````B+X!``4```"9O@$`$@```)^^`0`1
M````LKX!``P```#$O@$`"0```-&^`0`%````V[X!``<```#AO@$``P```.F^
M`0`$````[;X!``,```#RO@$`4@```/:^`0!`````2;\!`!T```"*OP$`+@``
M`*B_`0`U````U[\!``T````-P`$`-@```!O``0`B````4L`!`"<```!UP`$`
M)P```)W``0`L````Q<`!``X```#RP`$`)`````'!`0`4````)L$!`"8````[
MP0$`'````&+!`0`:````?\$!`!<```":P0$`'````++!`0`A````S\$!`$P`
M``#QP0$`#P```#["`0`O````3L(!`!T```!^P@$`&P```)S"`0`7````N,(!
M`"P```#0P@$`+````/W"`0`P````*L,!`"T```!;PP$`+@```(G#`0`K````
MN,,!`%X```#DPP$`(````$/$`0`7````9,0!``@```!\Q`$`'@```(7$`0`)
M````I,0!``\```"NQ`$`0````+[$`0`Q````_\0!`!\````QQ0$`#@```%'%
M`0!5````8,4!`$P```"VQ0$`"0````/&`0`&````#<8!`"(````4Q@$`#@``
M`#?&`0`0````1L8!`!D```!7Q@$`!@```''&`0`*````>,8!``P```"#Q@$`
M#@```)#&`0`6````G\8!``L```"VQ@$`$P```,+&`0`2````UL8!`!````#I
MQ@$`$````/K&`0`-````"\<!``X````9QP$`&````"C'`0`0````0<<!`!D`
M``!2QP$`$````&S'`0`A````?<<!``@```"?QP$`#@```*C'`0`B````M\<!
M``@```#:QP$`!0```./'`0`,````Z<<!``T```#VQP$`#0````3(`0`^````
M$L@!``(```!1R`$`!@```%3(`0`-````6\@!``D```!IR`$`!P```'/(`0`1
M````>\@!``H```"-R`$`)0```)C(`0`+````OL@!`"(```#*R`$`!````.W(
M`0`N````\L@!`!0````AR0$`*````#;)`0!J````7\D!`!0```#*R0$`1```
M`-_)`0`?````),H!``\```!$R@$`"@```%3*`0`-````7\H!``\```!MR@$`
M"P```'W*`0`4````B<H!``T```">R@$`&0```*S*`0`5````QLH!``,```#<
MR@$`$0```.#*`0`/````\LH!`",````"RP$`$0```";+`0`4````.,L!`!T`
M``!-RP$`$````&O+`0`G````?,L!``<```"DRP$`"0```*S+`0`4````MLL!
M`!(```#+RP$`$@```-[+`0`:````\<L!`!(````,S`$`#P```!_,`0`6````
M+\P!``H```!&S`$`"0```%',`0`(````6\P!`!````!DS`$`$@```'7,`0`&
M````B,P!`!$```"/S`$`"````*',`0`1````JLP!``4```"\S`$`&P```,+,
M`0`/````WLP!`"X```#NS`$`$@```!W-`0`&````,,T!``<````WS0$`&```
M`#_-`0`&````6,T!`!(```!?S0$`!0```'+-`0`9````>,T!``4```"2S0$`
M!P```)C-`0`7````H,T!`"<```"XS0$`!0```.#-`0`;````YLT!`!(````"
MS@$`!0```!7.`0`2````&\X!`!$````NS@$`!````$#.`0`/````1<X!``@`
M``!5S@$`!P```%[.`0`*````9LX!``@```!QS@$`!0```'K.`0`@````@,X!
M`#,```"AS@$`/````-7.`0`<````$L\!`"<````OSP$`(````%?/`0`^````
M>,\!`!H```"WSP$`(````-+/`0`O````\\\!`%@````CT`$`)P```'S0`0`&
M````I-`!``@```"KT`$`!@```+30`0`+````N]`!`!D```#'T`$`&0```.'0
M`0`L````^]`!`!\````HT0$`&P```$C1`0`V````9-$!`#P```";T0$`!```
M`-C1`0`5````W=$!``8```#ST0$`!@```/K1`0`D`````=(!`!D````FT@$`
M$0```$#2`0`-````4M(!``<```!@T@$`#@```&C2`0`(````=](!`!8```"`
MT@$`#````)?2`0`:````I-(!`!L```"_T@$`.````-O2`0`)````%-,!``4`
M```>TP$`!0```"33`0`%````*M,!`!L````PTP$`$@```$S3`0`$````7],!
M``D```!DTP$`"P```&[3`0`0````>M,!``X```"+TP$`'0```)K3`0`/````
MN-,!``4```#(TP$`!0```,[3`0`,````U-,!`#4```#ATP$`)P```!?4`0!9
M````/]0!`!X```"9U`$`!P```+C4`0`B````P-0!`!(```#CU`$`&P```/;4
M`0`/````$M4!`!(````BU0$`#0```#75`0`(````0]4!`!$```!,U0$`+0``
M`%[5`0`)````C-4!``X```"6U0$`$P```*75`0`0````N=4!`!8```#*U0$`
M#0```.'5`0`Z````[]4!``D````JU@$`'P```#36`0`5````5-8!`!D```!J
MU@$`.P```(36`0`F````P-8!`#X```#GU@$`/P```";7`0`[````9M<!``P`
M``"BUP$`$````*_7`0`-````P-<!`!(```#.UP$`%@```.'7`0`(````^-<!
M`!0````!V`$`$@```!;8`0`'````*=@!`!,````QV`$`*````$78`0`'````
M;M@!``8```!VV`$`#P```'W8`0`.````C=@!`!4```"<V`$`!````++8`0`(
M````M]@!``P```#`V`$`#````,W8`0`-````VM@!`!$```#HV`$`$0```/K8
M`0`'````#-D!``4````4V0$`-````!K9`0`D````3]D!`"0```!TV0$`!P``
M`)G9`0`/````H=D!``8```"QV0$`'````+C9`0`A````U=D!`"0```#WV0$`
M#@```!S:`0`)````*]H!`!X````UV@$``P```%3:`0`&````6-H!``H```!?
MV@$``@```&K:`0`,````;=H!`!,```!ZV@$`"P```([:`0`5````FMH!`!D`
M``"PV@$`%@```,K:`0`%````X=H!``H```#GV@$`$P```/+:`0`6````!ML!
M``X````=VP$`!@```"S;`0`+````,]L!``D````_VP$`$0```$G;`0!5````
M6]L!`!T```"QVP$`,0```,_;`0`/`````=P!``0````1W`$`!@```!;<`0`+
M````'=P!`!$````IW`$`#0```#O<`0`+````2=P!``X```!5W`$`#0```&3<
M`0`;````<MP!`!@```".W`$`%P```*?<`0`.````O]P!`!\```#.W`$`#@``
M`.[<`0`@````_=P!``X````>W0$`#````"W=`0`Q````.MT!`&H```!LW0$`
M)````-?=`0`6````_-T!`!<````3W@$`&````"O>`0`A````1-X!`"8```!F
MW@$`(@```(W>`0`4````L-X!`!D```#%W@$`&0```-_>`0`.````^=X!`!(`
M```(WP$`&````!O?`0`*````--\!``<````_WP$`"````$??`0`)````4-\!
M`!0```!:WP$`#0```&_?`0`T````?=\!`!0```"RWP$`'0```,??`0`'````
MY=\!``X```#MWP$`.P```/S?`0!.````..`!`"\```"'X`$`>````+?@`0`*
M````,.$!`"@````[X0$`-P```&3A`0`(````G.$!``@```"EX0$`#````*[A
M`0`V````N^$!``@```#RX0$`&````/OA`0!)````%.(!`#D```!>X@$`(0``
M`)CB`0`D````NN(!`"@```#?X@$`(`````CC`0`G````*>,!`"$```!1XP$`
M+````'/C`0`F````H.,!`"T```#'XP$`)@```/7C`0`0````'.0!``@````M
MY`$`#0```#;D`0`/````1.0!``X```!4Y`$`!P```&/D`0`T````:^0!``P`
M``"@Y`$`$````*WD`0`&````ON0!`!(```#%Y`$`"````-CD`0`'````X>0!
M`!````#IY`$`"0```/KD`0`)````!.4!``@````.Y0$`$````!?E`0`0````
M*.4!`!4````YY0$`%P```$_E`0`-````9^4!`"(```!UY0$`$@```)CE`0`(
M````J^4!``X```"TY0$`%P```,/E`0`<````V^4!`!4```#XY0$`#P````[F
M`0`,````'N8!`"8````KY@$`#@```%+F`0`?````8>8!`"4```"!Y@$`"0``
M`*?F`0`&````L>8!`!(```"XY@$`"@```,OF`0`$````UN8!`!L```#;Y@$`
M#@```/?F`0`/````!N<!``\````6YP$`!@```";G`0`)````+><!``H````W
MYP$`"0```$+G`0`.````3.<!`!0```!;YP$`!````'#G`0`/````=><!``@`
M``"%YP$`"P```([G`0`/````FN<!`!D```"JYP$`"@```,3G`0`"````S^<!
M`"````#2YP$`!P```//G`0`'````^^<!`'(````#Z`$`"P```';H`0`&````
M@N@!`"8```")Z`$`/@```+#H`0`<````[^@!`"<````,Z0$`40```#3I`0`:
M````AND!`"$```"AZ0$`,@```,/I`0`?````]ND!`!0````6Z@$`!0```"OJ
M`0`%````,>H!``P````WZ@$`"P```$3J`0`'````4.H!``P```!8Z@$`$@``
M`&7J`0`.````>.H!``L```"'Z@$`#0```)/J`0`+````H>H!``<```"MZ@$`
M!P```+7J`0`*````O>H!`!0```#(Z@$`"0```-WJ`0`'````Y^H!``L```#O
MZ@$`(0```/OJ`0`&````'>L!`"@````DZP$`!0```$WK`0`%````4^L!``\`
M``!9ZP$`!0```&GK`0`*````;^L!``D```!ZZP$`!P```(3K`0`2````C.L!
M`!(```"?ZP$`!@```++K`0`6````N>L!``L```#0ZP$`"````-SK`0`%````
MY>L!``4```#KZP$`#P```/'K`0`<`````>P!``<````>[`$`"0```";L`0`F
M````,.P!`!P```!7[`$`#0```'3L`0`$````@NP!``@```"'[`$`$````)#L
M`0`)````H>P!``(```"K[`$`!P```*[L`0`?````MNP!`"<```#6[`$`(0``
M`/[L`0`J````(.T!`"D```!+[0$`6@```'7M`0`1````T.T!`%\```#B[0$`
M+@```$+N`0!)````<>X!`&P```"[[@$`'@```"CO`0`P````1^\!`"@```!X
M[P$`,0```*'O`0`K````T^\!`!\```#_[P$`.@```!_P`0#+`0``6O`!`!P`
M```F\@$`#P```$/R`0`_````4_(!`'P```"3\@$`0P```!#S`0`7````5/,!
M`"\```!L\P$`(P```)SS`0`B````P/,!`"$```#C\P$`&@````7T`0`R````
M(/0!`%X```!3]`$`2````++T`0`A````^_0!`!<````=]0$`$````#7U`0`>
M````1O4!`!D```!E]0$`&````'_U`0`G````F/4!`"````#`]0$`'@```.'U
M`0`Q`````/8!`!D````R]@$`$````$SV`0`T````7?8!`",```"2]@$`(0``
M`+;V`0`A````V/8!`"(```#Z]@$`.0```!WW`0!4````5_<!`"\```"L]P$`
M1P```-SW`0`P````)/@!`"<```!5^`$`00```'WX`0!>````O_@!`$4````>
M^0$`,````&3Y`0`L````E?D!`"0```#"^0$`*P```.?Y`0`G````$_H!`%8`
M```[^@$`3P```)+Z`0`K````XOH!`"<````.^P$`2@```#;[`0!)````@?L!
M`#D```#+^P$`(@````7\`0`S````*/P!`"P```!<_`$`+````(G\`0`M````
MMOP!`&4```#D_`$`6@```$K]`0!C````I?T!`)T````)_@$`%0```*?^`0`C
M````O?X!`"\```#A_@$`+P```!'_`0!!````0?\!`"````"#_P$`5````*3_
M`0`G````^?\!`"$````A``(`"P```$,``@"U````3P`"`$@````%`0(`'P``
M`$X!`@`V````;@$"`"(```"E`0(`'@```,@!`@`L````YP$"``<````4`@(`
M!P```!P"`@`#````)`("``T````H`@(`"P```#8"`@`*````0@("``L```!-
M`@(`!P```%D"`@`9````80("``,```![`@(`6P```'\"`@`$````VP("`"<`
M``#@`@(`!`````@#`@`'````#0,"``8````5`P(`!0```!P#`@`$````(@,"
M`!,````G`P(`"````#L#`@`1````1`,"`!4```!6`P(``@```&P#`@`'````
M;P,"``<```!W`P(`#````'\#`@`.````C`,"``8```";`P(`%````*(#`@`,
M````MP,"``,```#$`P(`)P```,@#`@`$````\`,"``8```#U`P(`"````/P#
M`@`P````!00"`$<````V!`(`+@```'X$`@`O````K00"`!L```#=!`(`+P``
M`/D$`@`R````*04"`"0```!<!0(`(0```($%`@`C````HP4"`"@```#'!0(`
M(P```/`%`@`A````%`8"`"H````V!@(`*0```&$&`@`B````BP8"`#,```"N
M!@(`'@```.(&`@`?`````0<"`#`````A!P(`+0```%('`@`B````@`<"`"8`
M``"C!P(`)0```,H'`@`@````\`<"`"D````1"`(`*0```#L(`@`E````90@"
M`"\```"+"`(`'````+L(`@`A````V`@"`"4```#Z"`(`*0```"`)`@`@````
M2@D"`"H```!K"0(`/@```)8)`@!!````U0D"`!T````7"@(`)````#4*`@!`
M````6@H"`"4```";"@(`*0```,$*`@`H````ZPH"`"D````4"P(`(P```#X+
M`@`@````8@L"`"H```"#"P(`)0```*X+`@`Y````U`L"`"<````.#`(`-0``
M`#8,`@`,````;`P"``P```!Y#`(`#````(8,`@`4````DPP"`"\```"H#`(`
M(P```-@,`@`+````_`P"`!<````(#0(`#@```"`-`@`6````+PT"``@```!&
M#0(`!P```$\-`@`B````5PT"`"4```!Z#0(`'@```*`-`@`G````OPT"`"4`
M``#G#0(`#`````T.`@#K````&@X"``\````&#P(`*P```!8/`@`8````0@\"
M``P```!;#P(`#P```&@/`@`8````>`\"`!\```"1#P(`'P```+$/`@`&````
MT0\"`#4```#8#P(`%@````X0`@`4````)1`"``<````Z$`(`$P```$(0`@`*
M````5A`"`#P```!A$`(`"@```)X0`@`H````J1`"`!,```#2$`(`&````.80
M`@`7````_Q`"`#@````7$0(`(````%`1`@`2````<1$"`"0```"$$0(`$P``
M`*D1`@`4````O1$"`!4```#2$0(`"@```.@1`@`7````\Q$"``D````+$@(`
M'0```!42`@`(````,Q("`!P````\$@(`)@```%D2`@`'````@!("`",```"(
M$@(`!P```*P2`@`(````M!("``D```"]$@(`-````,<2`@`&````_!("`!``
M```#$P(`%0```!03`@`4````*A,"``L````_$P(`#````$L3`@`'````6!,"
M``L```!@$P(`'````&P3`@`/````B1,"`!@```"9$P(`&0```+(3`@`+````
MS!,"``T```#8$P(`%P```.83`@`)````_A,"`"L````(%`(`#````#04`@`/
M````010"``D```!1%`(``@```%L4`@`1````7A0"`!@```!P%`(`"P```(D4
M`@`#````E10"``L```"9%`(`"````*44`@`'````KA0"``L```"V%`(`"P``
M`,(4`@`.````SA0"`"T```#=%`(`&@````L5`@`:````)A4"`"$```!!%0(`
M-@```&,5`@`*````FA4"`#H```"E%0(`!0```.`5`@`6````YA4"`#<```#]
M%0(`#0```#46`@`.````0Q8"``8```!2%@(`!````%D6`@`&````7A8"``L`
M``!E%@(`%P```'$6`@`'````B18"``@```"1%@(`!P```)H6`@`(````HA8"
M``4```"K%@(`#P```+$6`@`0````P18"`#X```#2%@(`,0```!$7`@`D````
M0Q<"``4```!H%P(`&@```&X7`@`A````B1<"`"$```"K%P(`(P```,T7`@`1
M````\1<"``(````#&`(`!`````88`@`*````"Q@"``4````6&`(`!0```!P8
M`@`#````(A@"``D````F&`(`3````#`8`@`E````?1@"`#````"C&`(`&```
M`-08`@`M````[1@"`"4````;&0(`7P```$$9`@`Q````H1D"`!,```#3&0(`
M>0```.<9`@`<````81H"`%,```!^&@(`(@```-(:`@`_````]1H"`#0````U
M&P(`-@```&H;`@`L````H1L"`#8```#.&P(`-@````4<`@`U````/!P"`#,`
M``!R'`(`*````*8<`@`B````SQP"`"8```#R'`(`3````!D=`@`4````9AT"
M`#0```!['0(`#P```+`=`@!O````P!T"``D````P'@(`H@```#H>`@![````
MW1X"`'````!9'P(`*````,H?`@!4````\Q\"`!H```!((`(`*0```&,@`@`7
M````C2`"`!X```"E(`(`"@```,0@`@`=````SR`"`!T```#M(`(`%@````LA
M`@`T````(B$"`",```!7(0(`&````'LA`@!4````E"$"`!X```#I(0(`%P``
M``@B`@`*````("("``0````K(@(`!@```#`B`@`(````-R("``4```!`(@(`
M%0```$8B`@`3````7"("`!D```!P(@(`)0```(HB`@`0````L"("``X```#!
M(@(`&@```-`B`@`$````ZR("``H```#P(@(`"0```/LB`@`(````!2,"``\`
M```.(P(`"````!XC`@`,````)R,"``@````T(P(`"0```#TC`@`6````1R,"
M``X```!>(P(`$````&TC`@`-````?B,"``P```",(P(`$0```)DC`@`6````
MJR,"``X```#"(P(`"P```-$C`@`&````W2,"``<```#D(P(`$P```.PC`@`'
M`````"0"``L````()`(`%@```!0D`@`-````*R0"``<````Y)`(`#P```$$D
M`@`(````420"``D```!:)`(`)0```&0D`@`;````BB0"``P```"F)`(`)```
M`+,D`@`2````V"0"`!X```#K)`(`%`````HE`@`1````'R4"``4````Q)0(`
M!0```#<E`@`A````/24"``@```!?)0(``@```&@E`@`"````:R4"`!8```!N
M)0(`"````(4E`@`(````CB4"`!0```"7)0(`%@```*PE`@`(````PR4"`"T`
M``#,)0(``@```/HE`@`$````_24"`!`````")@(`%P```!,F`@`/````*R8"
M``D````[)@(`!P```$4F`@`2````328"``4```!@)@(`&P```&8F`@`%````
M@B8"`!8```"()@(`$0```)\F`@`2````L28"``(```#$)@(`"````,<F`@`/
M````T"8"``L```#@)@(`#0```.PF`@`D````^B8"``L````?)P(`#````"LG
M`@`3````."<"``4```!,)P(`!0```%(G`@`"````6"<"``L```!;)P(``0``
M`%$!`````````````.T```"5!0``A00``#L````W!0``60```#<"``#\!```
MD`0```````!+`P``N@0``'(#``";`P``I0$``)D%````````30,``.(&``!$
M````!0,````````3!0``>`$``&0'``!2!@```````!T$```"`@```````/\&
M````````1@4``$$'`````````````(X````)`````````%X%```?`@``M0(`
M``````"J`@``%P(``!H#``!W!```\@```"`&````````^@,`````````````
MJ@<```````!R!0``%P4``````````````````&T#``!<!P``S`4```````#]
M!@``G0(``,L$`````````````#D#`````````````-4#````````4@$``-<$
M``#(````M````*0#``"-!@```````&`#``!(`0``3`8``$0'``">!0``````
M`'X"``#;````6@<``*8"`````````````'D"``!&`0``````````````````
MP`$``!T'``"$!0``:`````<"```[`P``,@(``$X%``!M!0``>@$``(T$``".
M`@``M00``),&``#>`````````(P#```%!```````````````````BP8`````
M````````H`4``!8'``!7!0``OP4``!@'````````R`<``'H&````````2@``
M`(4!``!``@```````*P!````````B0<```````!Z`@``*P(``-L"``!2!P``
MK0`````````E`0``/P0``'4!```Y````CP```,T$````````````````````
M`````````#H!``"Y!`````````````!G!0````````````!*`0``-0(``/L%
M``#W`0``:@0```````!M!P``U@(`````````````C`(```T```#3!@``G`8`
M`!\#````````M08``-$"``"`!P``IP<``#@$````````P0<``!P'``!2!```
MWP```#D!```#`@``AP<``$8`````````NP0``(L"``#/`0``Y@```.4$````
M````Y`0``-L&``#[!@``$`$```4!``#O!```-04``'T'``#Q`P``Z`$``.H"
M```+`@``H00``+$"```T!```[@0``#T$```6`0```````$4'```?````````
M`&\&``!$`P``M@$`````````````8P8``"L%`````````````!@!``"R!0``
MQP4``$,`````````K@,``'$````\!@``0@```#T'````````B@8``)`'``!%
M!0``/`4``$D`````````,P0``+8'`````````````*D!```I`P```````&8'
M``#7`P``/@`````````9`0``ZP,``!@#````````W`$`````````````GP0`
M`%4#``#:`````````%H"```Y!P```````.P%``!J!P``ZP0``#0#``"6!@``
MF0```+$```!G!```*@$``,D%```T`@```````#4!``#=`0``20(``#$```#X
M````:0(`````````````.`$````````Q!P``IP(``,T'````````#@(``&0"
M``"]!@``8`4``,0`````````FP$```H%``#S!0``"0,``"\&````````````
M`#(```#7!@``-00``$P````/`P````````````"(`0`````````````:````
MB`<``-@``````````````+<!``#C````S@$``"<$``!=`P``P00``!(!``!-
M!P``L````%P$``"U!0``KP$``+,$``#H!@``;`,```````#T!```\@0``#\"
M```5`0``F@$``/`%``"$`0``K@(``$P%````````:`(``+`#````````L@(`
M`"X%````````6@0``'$'``#;`0```````(D$``!*!````````"(#``#T!@``
M`````+H"``!L`0```````,D`````````M`8`````````````E0(`````````
M````:`<`````````````````````````````FP<````````3`@``T`(``)P'
M````````8P,``-T%``!D!@```````-@"``"C`0```````-\&````````V00`
M``````#"!```)P,``/L"```G`@```````$L"``!&!@``&04```8#````````
M#@0``+8%``!R!```#`(````````7`P```````)`"`````````````)L$````
M``````````,&`````````````!@$``!K`0``IP````````"[````X`$`````
M``!X````R`$``%L"``##`@``*@(``#@"``!F`@``)````/X!``#^`@``````
M``\'``#?`P``;@$```H'``!B!0``&0(```````"1`0``J08``'(&````````
M*P```"`%``#5`@```````&L#``#F!0``&0,`````````````O0```,X#``"7
M!P``>0$``#L!``"!!0``,0,``.,#`````````````&@%```$`P``.`,``(4%
M```````````````````)!````````,('```@````0P$``"X"``!K!@``C`<`
M`&\```#D!@``#`4``.T!``#U`@```````"T#``"J!@``NP$`````````````
M*````%4"``#J`P``HP````T!``"_`P``*`,```````#8!```YP,``.H%``"8
M!@``$`<``(,&````````!P4``$<&``""`P``J`0``````````````````*\%
M`````````````#($````````$@```(0````$!```I00``"0"``!A!```$@<`
M``````!D````(P,``"@'```?`0``7@<``'`#``":!0```````$,&``!9`@``
M]0````T$``#A`0``+04```````"A`@``N`$``!0````%!P``\@(```````"\
M`@```````$L!``"0````L08`````````````#@8`````````````J@0``)H#
M``!\!P``J0,``*D'````````>@,``","``"E`````````+,'``"_!@``10(`
M`'X!``!P````G`4```````",`````````((%``#,````6@$`````````````
ML`(```$$``````````````````#?`@``?P```$P#``!6`P``E````-P&``#L
M`@```````````````````````/\%``"9!@```````````````````````"D`
M````````G0```+T!``!:````#0,``"H$``!P!@``Q0$``&P%````````$0``
M``````!E!```0P(``-X$```Z!```$`````````#_`0``,`(``'P%```B!P``
M`````($```!>`P```````,```````````P```.4"````````U@,``%4```#R
M`0``&P,``(@"````````B@<``"\#``"&!@``@`$``+X%```1!@``,P4``!@`
M``#"`0``)0(``)4$``#T````3@,``$D!``!-````I04``!T&``#%!```````
M`$<'``"G!````````*T"``"L````@P4```````">`@```P$```````!V!@``
M(@$```````#A!0``@`(``(<%``#6!P````$``%4%``#F`@```````"\`````
M````E0```&<&``#>!0```````%$&``!5!```\@,```````!K!0``-P$``)T!
M``!=`@```````/X#``#:!0``;@,``"$'```+!P``>0,``!(%``"K!0``````
M````````````M0$```$&````````J`8``"T&```M!P```````/````"]!P``
M``````D"```D`0``_@4``$\#````````00(`````````````````````````
M`````````!,!``#:`P``"`0``'<!``!%!@`````````````R`0```````%T&
M````````U0````````#E!@``=`(``````````````````!,#``!^`P``A@(`
M`/\$````````;0(``!P!```=!0```````$D'``"S`0```````"`'``#)!P``
MAP```(`#``#V!@``0P0``)0'``!_`@`````````````7````U08``.T$``#I
M`0``H0```%(#````````H0<``*<!``!(````````````````````+@0`````
M```]`P``(0,``'P$``"F!0``;0```",'`````````````*4#``#;!```6`8`
M`)L`````````GP<```````#*!````````&<!```3````DP0```````"O!P``
MH`(``(X$````````.````*P%``"&````*P$``*(%``"I!0``M@0``/P#``#$
M!0``^@8``#4#````````JP,`````````````@P<``-(#```"!```7````)('
M``#&!@``T`,```P'``">`0```````$(#``!2!0```0$``$0"``!R`0``5P(`
M``````!!`P``]@(```0```"T!P``(@4```````"+`0``_@````````#B`@``
MK04```0%``#_`````````)D!``"<`0``,@,``&H#```+`P``4`,``)0&``!`
M!@``PP,``!4%``#;!0``(P````````#/````N````*0````%!0``W```````
M````````2`,``%0$```!`P``604``$@'``"Z`0``YP4``/D%````````\P0`
M`*L"```_!P``1P,`````````````[P4``*8!``#Q!0```````%\$``!=`0``
M;````"`#``"N!@``K@4``'$&``"\!````````#<`````````.@8````````&
M````T00`````````````V04``)X&````````(P0``-8$``"1!@``*@4``,`&
M``!)!```U@4``)`!``!-!@``OP$``'0#```*`P``H@```&$"````````````
M`#X$`````````````````````````````'L%````````R@,``-0'``!S````
M`````)L"``#A!```"08``",&``!S!P``L@$``)$'``"8!```?04``/$&```H
M!0``P@4``%\&``!1`P```````!<'``#D`P``>`8``*H%``"L!P```````+L%
M``#2!```)P8```````!H!````````*D```!?!P``OP```(L%``#N`0``508`
M`*````!J`0``D0(``'$%````````%`$``%<&```A!0``*08``,0$````````
M``````````#)`@``[`0``),!```H!@```````.4!``#1`0```````.,!``!!
M!@``:@````````#"`P``A0,``"D"``!"`0`````````````-!0``X0,``-8`
M``!0`0``7`$``+X&````````-````)(!``"C!@````````````"^!```````
M`&0$```\````N`(``+P'``````````````````#*`0``#0(``%@$``!C````
M`````&D!````````S`,``*T'``#S!@``@0(``/0"``#]!```U`0``)(%``#I
M`P``>P8``%P"``#_`P``GP8``"\%``"S`P``'`(``/@&```<!0``=@``````
M```/`@``908``/0#``!$`0``V0``````````````%`,``&8`````````^`,`
M`-('```V!```F0,``!$!```/`0``W00``&$%```V!P``W@,``"X!```2!@``
MYP0``.,"``!F`P``B@4``#`!``!2`@``H`,``&("`````````````(D%````
M````7@0`````````````W0,``+`$``!9!```4`0```````"?````6P0``&D&
M``!3`````````-`&``#Z!````````*,$``!O`@``"P$``!,'``!%`0``?`$`
M`%\"``!1!````````(0'````````V`4`````````````Z`4````````T!@``
M]08``&D'``!4`@``>`(``-H&````!0``^`0````````V`0``AP,``.D"````
M````00$````````*!```?`,```X#`````````````!T```")````````````
M```L`0```````/`$``#(!0``@0$```````"*````TP,``)X'````````1@,`
M``````"4!```]P,``,T&```K!```/@8```````#C!0````0``'T"``!8````
M`````-H"````````\@8``"@$`````````````)("``#4`@```````$L%```;
M````I`0``!L%```E!```JP0``(X'``!4`P```````.T%```<````I@```(T'
M````````;`8``,8````Q!```5@(```D'```Z!P``CP8``(\!``"[!P``3@0`
M`#D$``#0!````````+`'``!+!@``3@$```````"P`0```````.L%``!:`P``
M```````````^`@```````+D!```]!0``4`(``&L"````````'0,``#8%``#&
M`P``1P(``+<"``````````````````!N`@``)04``%4'``"#`@``O`8``,4"
M````````J0(``%<'``!]!```RP$``.(#``"O`@````````````!U!```.P4`
M`$4#``#\`@``K0,``"L&``!?````)0,``&T!``"2!```T`<``$<%````````
M#0<``+`&``!(!@``P04``-X&``#N````2P````L&``!P`0``=0<``'@'``!_
M!P```````,X```"O!@``=`$``'L$``#^!````````(L'`````````````#L"
M````````\`,```P&````````X`4``',"````````RP<``,\'``"@`0``.08`
M`/T#``#X`@```@4``*("``"N`````````"<%``!F`0```````.L!````````
MJ@```(X!````````BP,````````1!```LP````````"4`@``F@8``+X```#6
M`0```````.4```!_!```"P```&0#````````&@(````````V`````````'`$
M````````I`<``,,$``#9`P```````(L`````````1@(``*4"``!:!@``@08`
M`/(%```E!@``I`(``%`%```'!```&`(``*P$````````(@0``!`%``#<`@``
M6P$``%<#``!*`@```````,H&``!!!```@@$```0!````````!08``)@```!M
M!````````!`&``!=``````````(#``"%!P``Z@0```````#'`P``_04``,L&
M``"F!```+`,``+H%``"9!```Q`8``!8&`````````````#X!````````)0``
M``````#"````100``'X`````````/@<`````````````8P4``%0```"K````
MP`0```````"D`0``=````,4'``!(!0``?`8```````#3`0``O`,```,#````
M````40```+X"````````B````,T#```]````IP,``,@$````````'`,`````
M`````````````'\%```P!0``K`,``#@'```&!```808`````````````````
M``X```"H`@``U`4``!0'``!)!0``?P$```````":!`````````````"7`0``
M<0,``)@%``!"!P``?08``,4&````````"`,`````````````:P0`````````
M````N04``%L'```Z!0``SP0```````"H`````0(``#$%```D!P``!P```"`!
M````````S@<````````B````P`4``)@#``#A`@``[0,``"0$``#8`0``?P8`
M`&(&````````@`````````#@!@```````+T#``#A````/`,`````````````
M^P0``#\#```,`P``U04``,\&``!F!0``X`(``,D#``">!```NP(`````````
M````X08``(,```!G!P```````$8'``"A`P``/0$``!L"``!0!@``H`8``"8&
M``"3`P``,@4``"X'``#G`0``QP(``"$"``#8!@````,``,X&````````0```
M````````````HP,``+D```"\!0```````,H%``#]`0``,`8```````!(!```
M`````.\!```F!````````*\````N`P``H08``)4&``"/!0```````!X!``!'
M`0``Y@$``!\&``"`!0``K@<``#0%``"'`0``EP0````````)!0```````/$!
M``"&`0``#P4`````````````-P0``(@%``"1!0```````.,&````````I@8`
M`"$!``#%````0P,``/P%``#O!@``````````````````OP<``+0!``"O`P``
MWP$``"0#``#J!@``)@4``%L#```!!P``N@8``.H!````````'P0``$0$``!<
M`P``/@,``'0$``!I````[`8``/4%```2`@``PP<``'4#``#+`@``R`(```(`
M``".!@``WP0``,,%``#X`0````````````#L`P``,P$``,D&``"7!0``?@8`
M```````$!P``L@```%8$```W!P``"@(``,P'``!D`0````````X%``"4`0``
M`````!<!``"G!@``KP0``&($````````#@<``*(&``",`0```````!<$```/
M!@``TP(``#,```",!```+`4``"H#`````````````'L"```*`0``,P(``&4`
M``!3!@```````+0"``"1!````````-$%`````````````+8"``!?!0``7@$`
M`+L&``"*`@```````((`````````F`<``#L$``#/!0``)`4``+4'```9!```
M`````````````````````&0%``!V`0``=@,``+('``!=!0``W0(``'@#````
M`````````,P!``"@!P``]P0``'T```#2`````````'H```!9`P```````/,#
M``",!@````````````"N!```RP,``%``````````1@0````````O!P``&P$`
M`#0'```Q`0```````/D"``!0!P``(@8`````````````MP0`````````````
MC@,```8&``!T!@``H@<``&`````K`P``\00``+$%```6````QP<``)(&````
M````O@$``!`#```S!P``+P$``"P"``!6````$0(``&$!```6!0``*0$``-<`
M``!+!P````````````#4!@``'@```'<"``#F!@``3P(``)T%``!N!0``)@(`
M`(0#``!$!@```````$\%``#M`@````````````!F!@```````)@!```L!@``
MSP,``!X#``"S`@``7`4``#P$```P`P```````(T%``!`!0``:`8```P$``#Y
M!```@P,``'8"``#V````F`(```H&``#Y!@``AP0``/`&``"=!```ZP```(8%
M`````````````+0$``#$!P```````$T!``"=!@```````)`#````````&`8`
M`(@#``!N!P``$P8``!H'``#G`@``Q@0``(8'``!"`@``,P8``'L#``!`!P``
MA0(``(P%``!+!```&08``),%``"'!@``I@<``)<"``"R!```X````/P!``!*
M`P``L00``'4"```>!```,P,``````````````````/P&```0`@````<``%0&
M`````````````$\&``":`@``@@(````````\`0```````#8#``!(`@``Z04`
M````````````3P0``)8'```L!```!P<``((&``#Z````]00```````!G`P``
MV0$``.D$``#S````%@0``-("``![!P``3P$`````````````*04``*T&``!O
M!0```````"H&``!9!P``D`4``.T&``"]!```*`(``"`$``"A!0``Z08``&('
M``"J`0``\0(``,P&``"?`P``]`$``,H````+!0``@00```````"D!@``40(`
M``````#7!0``X@$``+P!``#2`0```````'X'```&!0``L0$````````F````
MI`4``'("``!;!0``$P0```````"U`P``/P```!@%```````````````````\
M!P``1P0```````!H`0``)P<``(X%``"$!@````````````#Y`````P<``&4"
M````````$@,``-<"``"$`@``4P<```('````````5P```,X%```R!P``Y`4`
M``\```#"!@``5@4```````!A!P````````````"U````C0$``",%````````
M700`````````````````````````````D0```.,$``!@!@``G`````````#!
M`P``_@8``'0%````````%`0```````":!P````````````!%````<P0``*,'
M``!Z!0``'@4``$0%``"1`P```````#4'``"%!@```````%\#``"6!```````
M`)8#``"X!@```````.4%``!N````Y`(``&(#````````0P4``$`$``")!@``
M3P```*`$``#4`P``B`0``#8"``"F`P``J00``&4%``!S`0`````````````]
M`@```````,`"````````N`<```````!@!`````````````"!!P``3P<``,T!
M````````QP```'4&```$!@``)P```)\!``!S!0``T@4``!H&``!4!P``````
M``````!F!```Y`$``)\%``#Z`0``JP8```````"<`P``&P8````````0!```
M`````(H$```P````-08``.\"```^!0``#@$````````M`0```````",!````
M````?@4``(L$````````E0<``%D!```A````UP$```````#-````"`<``/8!
M```6`@``$0<```````!Y`````P0``(\"``#,!````````%T'````````E`4`
M`#0!````````C0(``.P```"-`P``0`$``*P&``"B`P``;P<``+<'````````
MZ`(`````````````@P0``&,$``!W!P``8@$``*@'````````<@<``!H%``#%
M`P``8P<````````````````````````5`````````'<#``"3````T0<``$H'
M````````PP8``"$$``#K!@``<00```````!M!@``EP8``/T`````````P`<`
M`.@#````````004``/D!````````4P0``"8!``"&`P``?0,``!D'````````
MNP,``.X%``"B!```'P4`````````````E@$``!X&````````)P$``,<&```A
M!@``=`<``,@&``#G!@``,`<``.4#``!.!@``T0,``+D'```=`@``H@$``-(&
M```N````5`4``&`"````````?`(``"("````````Q@<```````#-`@``A@0`
M``````"\````P`,```````#>`0``U00``)T'````````RP4``$X"``#3!P``
M+`<```H```"K!P````````````#N!@``*00``&X$```K!P```````%,"``#:
M!```[P```'\#``!O`P``^@4```````")`0``,@8``$P!``!,`@``]P8`````
M``"`!@``7@(`````````````B`8``($#``"Q!P``%0,````````7!@``````
M```````M`@```````/T"``#@!``````````````'`0``````````````````
MO@,``%,#``!\````30(``,0"````````O@<``%@"``!O!```L`4``"P```"?
M`@``90,```````"=`P``````````````````Q@4````````(!@``:@4``)L%
M````````@@0``*$!```Z`P``T08```````!Y!@``G@````````!9!@``#```
M``````!U````$@0``),"```M!```[@,```8'``#*`@```````%<!``">`P``
MR@<``-P$````````1P```,@#``"W!0``#`$``%@'`````````````+(#``!A
M`P``T```````````!@``]`4``%(````5!P``L@8``+8````:!```4P4``-4!
M``![````@P$```````!I!0``=@<``%@%````````RP```&L````D!@``````
M`#P"``#'`0``3`<``(\'``#V`P``I08```````#3!0``K`(``$D#``#,`@``
MN`0`````````````D`8````````M````T0```)(```":````K00``/`"```(
M`0``>@<``/<```#=`````````(('``#%!0``V`,``#$&``#)`0``7@```'$"
M```Z`````````"8'``")`@``/08``#\&```Q`@``E0$``%8'````````]@0`
M`$P$```_`0``Y`````````"H!0``P@(``"@!```!!0``'`0``"D'```J!P``
MTP0``%$%````````X@0``!4"``#.`@```@8``!P&``#K`@``````````````
M````Y@,``+<```!Y!P```````-8&``"N`0``&P0``'X$``"7`P``?0$``/L`
M``!*!0```````.\#``!3`0```````)4#``#_`@``^`4```\$````````G`(`
M``````#'!```6`,```````#?!0``T`4``'8%``#&`@``B@$``,$"``"9!P``
M2@8````````9````]0,``/L!```5!@``!@(``$`#``#G````%`4``.(```"`
M!```JP$``"\$``#)!```-0````````!R````E@```)P$``"X!0``AP(```8!
M``#W!0``N@<``%X&``#U`0``8P$``!8#``"]`@``!`(``%H%``!P!0``"0$`
M`',&``!L!````````+D&``!.````Z0```/D#```P!```5`$``),'```J````
M5@8``&4'```````````````````?!P``N@```!H!``"M`0```````!X"``"W
M!@```````"X&``"E!P```````/P```#-!0``5@$``'@%```[!P``!0(``%<$
M``````````````````#0`0``Z````(D#`````````````.8$````````<`<`
M`,,!``##````HP4```````!8`0``&P<``/,!```O`@``M@,``+\$``!S`P``
M)@,``'4%``!P`@``;P$```,%``#[`P``;`<``-,``````````````-4'``#B
M!0```````+T%````````8@```#D%``#J````50$``&`!```=`0``W@(`````
M````````U`$``.X"``![`0``>@0``+D#```'!@``=P```)<```"2`P``/P4`
M`!0&``!G`````````+H#``#;`P``"`````````!.!P```````+0#```W!@``
M:00``+,%``!"!````````%L&````````V0(``)8%``#.!```P0```/$`````
M````\P(``&P"```W`P```````"`"``#H!```!P,``$$```#V!0``````````
M`````````````-H!``!Y!0````````@%``#&`0``CP,```````!W!0``0P<`
M````````````CP0``&L'```>!P``!0```+$#````````IP4```````!A````
M)0<``$(%``#L`0``:0,``-D&```X!0``HP(````````1!0``.@(`````````
M````Q`$``*@!``"6`@``9P(``&4!``!V!```.P8``+\"``!;````````````
M``"9`@``0@8``!$#``!<!@````````````"W`P``FP8```````!C`@``````
M```````"`0``>00``'$!```````````````````5!```E`,``#D"````````
MN0(``&@#``"J`P``8`<`````````````7P$``&X&````````M`4``-P#``"V
M!@``40<``(4```!-!0``A`0``-T&`````````````'<&``#Z`@``-@8``&H"
M``!X!```N`,`````````````%`(``#@&``"S!@``U`````@"``#<!0``````
M``````#P`0``:@8``.`#``#!!@``P0$```T&````````C0``````````````
M"P0``*@#``#W`@``208``,\"``!-!`````(```````"*`P``Q`,````@*"5S
M(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O
M9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO
M="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E
M<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B
M)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E
M+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A
M;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D
M(&YO=&5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P
M<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!C:&%R86-T
M97)S`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E861Y
M('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME
M9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y
M;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER
M960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S
M)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S
M)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B
M92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W
M:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E
M<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L
M(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E
M;&5C="`M+0`Q(&YO=&4`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`
M,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U
M:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R
M960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I
M;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O
M=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D96YI960@9&5L971I
M;F<@;F]T92X`06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N`$%C8V5S
M<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N`$%C8V5S<R!D96YI960@<V%V
M:6YG(&YO=&4Z("5S`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S
M=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD
M($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W
M($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T
M;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N
M97<@=7-E<CH`061D(&-A=&5G;W)Y`$%D9"!C;VQU;6X`061D(&YE=R!M96UB
M97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B
M;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O
M=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S
M+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RX`061D:6YG($$@3F5W($YO=&4`061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G
M:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N
M=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL
M(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!
M;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@
M24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA
M=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T
M92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R
M<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT
M87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI
M8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H
M:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U
M8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R=`!!<G5B80!!<V-E;F1I
M;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E
M9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S
M=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N
M(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D
M`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R
M=F5R(&9A:6QE9"X`079A:6QA8FQE($-A=&5G;W)I97,Z`$%V86EL86)L92!F
M:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VL@=&\@3F]T97!A
M9`!"86-K('1O($YO=&5P860@3W!T:6]N<P!"86-K9W)O=6YD`$)A8VMG<F]U
M;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@
M=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86YG;&%D97-H`$)A<F)A9&]S
M`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E
M;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU
M=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N
M;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI
M=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M
M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,
M:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',`0U-6`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#
M86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O
M(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@
M:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A
M;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T
M+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N
M;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!6
M97)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#871E9V]R>0!#
M87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL
M('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP
M:&]N90!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E<G1I9FEC
M871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L
M:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG92!Y;W5R
M(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS+@!#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAO;W-E($%P<&QI
M8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#
M:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=&AE(&UE;6\@8V%T
M96=O<FEE<R!T;R!L:7-T(&EN('1H92!S=6UM87)Y('9I97<N`$-H;V]S92!Y
M;W5R(&1E9F%U;'0@3F]T97!A9"X`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@1F]R;0!#
M;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R
M.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E
M`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@
M5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L
M:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E
M<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I
M;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD
M(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O
M;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I
M9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S
M+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O
M=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N
M9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN
M96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S
M`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``
M0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE
M`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I
M8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O
M34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B
M:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E
M<G9E<@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R
M=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@
M`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L
M971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R
M97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N
M("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N
M`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B
M.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@
M(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B
M.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A
M=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S
M`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S
M:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R
M<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT
M('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Z96-H(%)E<'5B;&EC`$1$
M`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA
M9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@
M0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A
M=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I
M;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#
M;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@3F]T97!A9`!$969A=6QT
M(%-H96QL`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T
M:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL
M`$1E;&5T92!#;VYF:7)M871I;VX`1&5L971E($=R;W5P`$1E;&5T92!,;V<`
M1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$
M96QE=&4@8G5T=&]N(&)E:&%V:6]U<@!$96QE=&4@8V5L;`!$96QE=&4@8V]L
M=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES(&YO=&4`1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE
M`$1E;FUA<FL`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$97-C<FEP=&EO;CH`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT
M(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES
M<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D
M971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L
M87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE
M<S\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S
M/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@
M4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N
M;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA
M:6P`15)2`$5C=6%D;W(`161I=`!%9&ET("(E<R(`161I="!";&]C:P!%9&ET
M($=R;W5P`$5D:70@3F]T90!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S
M:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&-A=&5G;W)I97,@
M86YD(&-O;&]R<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS
M(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%
M9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D
M9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@
M8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%
M;7!T>2!.;W1E`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@
M<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@
M4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C
M;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I
M<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I
M;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R
M<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U
M<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC
M`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C
M=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N
M($1A=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R="!.;W1E<P!&1R!#;VQO<@!&
M5%`@=7!L;V%D(&]F('-E='5P`$9?=6QL(%1E>'0`1F%I;&5D(')E=')I979I
M;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@
M=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A
M:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O
M(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A
M;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L
M($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L
M:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R
M:7@`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@
M)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO
M;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL
M=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T
M:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O
M;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T
M(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H
M870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD
M(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A
M('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T
M=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&
M;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N
M`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE
M<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO
M;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I
M;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%L($]P=&EO;G,`1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA
M`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L
M`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'
M<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R
M:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE:6=H=`!(96QP`$AE;'`@
M=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C
M=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T
M:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO
M;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A
M;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(
M=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL
M960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L
M;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD
M`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N
M=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@
M55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@
M9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@3F]T97,L(%-T
M97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T97,`26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@
M069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN
M8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I
M80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I
M;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E
M<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R
M90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E
M;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E
M<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E
M<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G
M<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W
M(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF
M>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I
M="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I
M96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED
M(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@
M<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L
M:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L
M;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O
M<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE
M<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN
M`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T
M`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A
M+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4
M+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA
M;G5A<GD`2F%P86X`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*
M=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I
M9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.
M97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T
M:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O
M9@!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P
M;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T($UO9&EF
M:65D`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P
M9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`
M3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP
M='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F
M="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA
M;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A
M:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I
M;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,
M:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O
M.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@
M=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP
M(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI
M<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES
M="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES
M=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM
M93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS
M`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N
M9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T
M:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`
M34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U3
M1P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L
M:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-
M86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E
M;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S
M('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N
M<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@
M9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I
M="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU
M;6)E<B!O9B!.;W1E<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS
M`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`
M365M;R!497AT`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I
M<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-
M971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I
M<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H
M;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D
M(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S
M`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S
M<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`
M36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-
M;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D:69Y:6YG("5S`$UO9'5L=7,`
M36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N
M9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I
M96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-
M;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN
M>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E
M(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O
M=6YT($EN9F]R;6%T:6]N`$UY($YO=&5S`$UY(%!O<G1A;`!->2!0;W)T86P@
M3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I
M80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE
M<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%52
M3`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),
M`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@
M;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE
M=R!#871E9V]R>0!.97<@365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@3F]T
M90!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S
M<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S
M<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`
M3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE
M>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/
M(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I0V%L
M96YD87(@9&%T82!W87,@9F]U;F0N`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A
M=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E
M('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;F]T97!A9',@87)E
M(&%V86EL86)L92!T;R!G=65S=',N`$YO(&YO=&5S`$YO(&YO=&5S(&UA=&-H
M('1H92!C=7)R96YT(&-R:71E<FEA+@!.;R!N;W1E<R!T;R!D:7-P;&%Y`$YO
M(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E
M9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A
M('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED
M97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]?
M=&4`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F9O;&L@27-L86YD`$YO
M<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO
M<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T
M(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&4@0V%T
M96=O<GD`3F]T92!$971A:6QS`$YO=&4@3&ES=',`3F]T92!497AT`$YO=&4@
M7U1E>'0`3F]T92!N;W0@9F]U;F0N`$YO=&5?<&%D`$YO=&5P860G<R!N86UE
M.@!.;W1E<&%D<P!.;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE+@!.;W1E<P!.
M;W1E<R!3=6UM87)Y`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E
M;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O
M;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B
M:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F
M:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`
M3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA
M;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S
M(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS
M(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T
M:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES
M=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG
M`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R
M;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0
M($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`
M4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@
M5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L
M;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`
M4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E
M<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N
M9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T
M(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I
M;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T
M960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS
M($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T
M<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO
M=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M
M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0
M;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R
M97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E
M($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O
M;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L
M:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`475O
M=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A
M:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@
M4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!2
M96%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!D96QE=&4@=&AI<R!N;W1E/P!2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I
M;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F
M<F5S:"!,:7-T`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C871E9V]R>0!296UO=F4@8V]L=6UN
M`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO
M=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M
M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I
M96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`
M4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`
M4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T
M:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I
M9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O
M;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H
M=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E
M9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R
M90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!3
M44P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?
M44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I
M<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF
M*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E
M;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A
M=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M
M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396%R8V@@4F5S=6QT
M<P!396%R8V@@4V-O<&4`4V5A<F-H(%]497AT`%-E;&5C="!&:6QE<P!396QE
M8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@
M;W=N97(`4V5L96-T(&$@;F]T97!A9`!396QE8W0@82!S97)V97(`4V5L96-T
M(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M
M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@
M;F]T97!A9',@=&\@9&ES<&QA>3H`4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM
M<&]R=#H`4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.@!3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T
M('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396QE
M8W1E9"!#871E9V]R:65S.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3
M`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N
M96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!3
M97-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE
M>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I
M<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U
M;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@
M;&EN:W,_`%-H;W<`4VAO=R!A8W1I;VX@8G5T=&]N<S\`4VAO=R!D:69F97)E
M;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W
M:&5N(&QO9V=I;F<@:6X_`%-H;W<@;F]T97!A9"!N86UE/P!3:&]W(&YO=&5S
M(&9R;VT@=&AE<V4@8V%T96=O<FEE<P!3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU
M(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@
M5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3
M:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I
M97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I
M=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`
M4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3
M:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M
M86QI80!3;VYG<R`F(%!O96US`%-O<G0@8GD@0V%T96=O<GD`4V]R="!B>2!.
M;W1E(%1E>'0`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`
M4V]U=&@@069R:6-A`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I
M;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C
M96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3
M=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC
M90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME
M=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D
M<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U
M;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B
M)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO
M=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E
M<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE
M('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U
M;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL
M>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG
M97,N`%-U8V-E<W-F=6QL>2!S879E9"`B)7,B+@!3=6-C97-S9G5L;'D@<V%V
M960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY
M('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M
M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3
M=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3
M=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE
M;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T
M960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N
M($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T
M;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P
M97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN
M8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O
M<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E
M<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@
M(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`
M5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I;&%N9`!4:&4@
M1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4
M:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES
M<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@
M8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T
M:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I
M9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@
M<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B
M965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@
M;F]T92!W87,@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!C;W5L9&XG="!B
M92!C<F5A=&5D.B`E<P!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&-R96%T
M960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO
M=&5P860@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&YU;6)E<B!O9B!F:65L
M9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@
M<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`
M5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O
M;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4
M:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S
M:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@
M<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE
M('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A
M(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@
M<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A
M9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@
M<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A
M9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A
M=&$Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!V
M3F]T92!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R
M871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F
M:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&4@;F]T93H@
M)7,`5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&4@;F]T93H@)7,`5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!V:65W:6YG('1H:7,@;F]T
M97!A9#H@)7,`5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E>'!O<G0N`%1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I
M;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET
M86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH
M='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F
M:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@
M;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE
M(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@
M9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A
M;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S
M('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U
M8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K
M971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C
M=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O
M9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`
M5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI
M9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME
M>0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L
M=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N
M9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L
M9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O
M(&-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI=&5D($%R
M86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET
M<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`
M56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N
M(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W
M;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@
M3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI
M8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@
M=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@0V]N=&5N
M="U4>7!E.B`E<P!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T
M92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5
M<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S
M92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O
M<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!2
M96=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L
M960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R
M;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`
M57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T
M=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I
M;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A
M9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65W("5S`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y
M`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@
M=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R
M($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O
M;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!7
M96QC;VUE+"`E<P!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!.;W1E<&%D('-H;W5L9"!T
M:&4@;F]T97,@8F4@861D960@=&\_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H
M`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@
M;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD
M($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O
M;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O
M=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X
M=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`
M665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@;F]T
M97,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V
M92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S+@!9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L
M;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G
M*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@82!N;W1E<&%D('1O(&)E(&1E
M;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@
M<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT
M<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&1E9F%U;'0@;F]T97!A9#H`66]U<B!F=6QL
M(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!N;W1E<&%D<SH`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0F%C
M:R!T;R!.;W1E<&%D`%]#3$D`7T-A=&5G;W)Y`%]$871A5')E90!?1&5L971E
M`%]$96QE=&4@4F]W`%]%9&ET`%]&:7)S="!,:6YE`%]'<F]U<',`7TAE;'``
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQI<W0@3F]T
M97,`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7TUY($YO=&5P
M861S`%].97<@3F]T90!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U!R:6YT`%]2
M96UO=F4@3&EN:RXN+@!?4V5A<F-H`%]3971U<`!?5&%B;&4@4')O<&5R=&EE
M<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A
M;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@
M;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O
M<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI
M<W-I;F<`9&%T82!F;W)M870@97)R;W(`96YT<GD@;F]T(&9O=6YD`&9A;&QI
M;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`
M:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O
M=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK
M:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE
M`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`
M;F]T97,N8W-V`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E
M;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL
M86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S
M=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R
M90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`
M=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!V3F]T90!W.@!W96%T:&5R+F-O
M;0!0<F]J96-T+4ED+59E<G-I;VXZ($UN96UO(#(N,0I297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T
M93H@,C`P-BTP,BTP,B`R,SHU.2LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#8M,#(M,#,@,#`Z,3`K,#(P,`I,87-T+51R86YS;&%T;W(Z($EV86X@3F]R
M:7,@/'9I>$!V87IK82YS:SX*3&%N9W5A9V4M5&5A;3H@4VQO=F%K(#QV:7A`
M=F%Z:V$N<VL^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:70*`"`H<')E9"`E<R!D\F%M:2D`("A+;.%V97-O=N$@
M<VMR871K82`E<RD`("AO("5S(&1N[2D`*&1N97,I`"`H>F%J=')A*0`@*';H
M97)A*0`@<OUC:&QO<[L@`"(E<R(@;FEE(&IE(&%D<F5SX7(N`"(E<R(@;FEE
M(&IE('!L871NX2!V;[5B82X`(B5S(B!N:64@:F4@;F%K;VYF:6=U<F]V86[I
M('8@<F5G:7-T<FD@2&]R9&4N`'IO8G)A>F]V8>@@<W1R;VUU("(E<R(@;F5B
M;VP@;N%J9&5N_2X`4VMU<&EN82`B)7,B(&)O;&$@<')I9&%NX2!D;R!S>7-T
MZ6UU+@!0<N%V;R`B)7,B(&)O;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+@`B)7,B
M(&YE8F]L;R!M;[YNZ2!V>71V;W)INSH@)7,N`%!O=;YI=/UC:"`E+C)F34(@
M>B!D;W9O;&5N_6-H("4N,F9-0B`H)2XR9B4E*0`E9"`E<R!A("5S`"5D(&1N
M[2!D;R!V>7!RN6%N:6$@<&QA=&YO<W1I(%;AN6AO(&AE<VQA+@`E9"!P;WIN
MX6UO:P!P<F5D<&]V9>\@;F$@)60@9&[M`"5S("T@4&]Z;N%M:V$`3V1T;&'H
M;VL@)7,`)7,@2T(`3W!E<N%C:64@^F1ROF)Y('!R92!A<&QI:^%C:74@)7,@
M+2!0;W1V<F1E;FEE`$YA<W1A=F5N:64@)7,`4F5G:7-T<F]V86YI92!D;R!A
M<&QI:^%C:64@)7,`4&]D;6EE;FMY('!O=;YI=&EA("5S`"5S('6^(&5X:7-T
M=6IE+@`E<R!V;R!V_;EK92`E<R`E<P`E<R!Z;F%K;W8`<_IB;W(@)7,@^G-P
M9;EN92!I;7!O<G1O=F%N_0!!<&QI:^%C:6$@)7,@:F4@<')I<')A=F5NX2!N
M82!V>6MO;F%N:64@;W!E<N%C:>T@^F1ROF)Y+D]Z;F'H=&4@N71V;W+H96L@
M<')I(&]P97+A8VGA8V@L(&MT;W+I(&-H8V5T92!V>6MO;F&[('1E<F%Z+@!0
M;[YA9'5J92!S82`E<P`E<R!M:6[Z=``E<R!N96)O;"!NX6ID96[]+@`E<R!A
MOB`E<R!Z("5S`$%D<F5SX7(@<&]UONUV871EM6$@)7,`2V%L96YDX7(@<&]U
MONUV871EM6$@)7,`4&]Z;N%M:WD@<&]UONUV871EM6$@)7,`6F]Z;F%M(/IL
M;V@@<&]UONUV871EM6$@)7,`)7,Z("5S`"5S.B!4X71O('-P<N%V82!N96UU
M<^T@8GF[(&]D(&]D;W-I96QA=&6U82P@:W1O<OT@<V$@>F]B<F%Z=6IE(&%K
M;R!O9&]S:65L871EM2!S<'+A=GDN(%IA8VAO=F%J=&4@;W!A=')N;W.[('!R
M:2!K;&EK86[M(&YA(&QI;FMY('8@<W!RX79E(&%L96)O('!O<VMY=&]V86[M
M(&]S;V)N_6-H(&EN9F]R;>%C:>T@;V1O<VEE;&%T9;5O=FDN`"P@;N%R87IO
M=OT@`"P@=B!NX7)A>F]C:"`E<R`E<P`L('!R96UE;F[A('8@<F]Z<V%H=2`E
M<R!AOB`E<P`M+2!V>6)E<G1E('-I("TM`#$@<&]Z;N%M:V$`,3(M:&]D:6YO
M=OT@9F]R;>%T`#(T+6AO9&EN;W;](&9O<FWA=``R-"!H;V3M;@`\4')E9&-H
MX61Z86KZ8V$`4')E('1E;G1O(&)L;VL@:F4@<&^^861O=F%N_2!D871A8N%Z
M;W;](&)A8VME;F0N`%9Y<VMY=&QA('-A('KA=F&^;N$@8VAY8F$`3F$@>F&Y
M:69R;W9A;FEE('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J;OT@4$A0(&NU
M^N@N`$YA(&]V97)E;FEE('!O9'#M<V%N96H@<W!RX79Y(&IE('!OOF%D;W9A
M;OT@=F5R96IN_2!01U`@:[7ZZ"X`3F$@9&6Y:69R;W9A;FEE('-P<N%V>2!S
M^B!P;W1R96)NZ3H@=F5R96IN_2!01U`@:[7ZZ"P@<')I=N%T;GD@4$=0(&NU
M^N@@82!H97-L;RX`3F$@<&]D<.US86YI92!S<'+A=GD@<_H@<&^^861O=F%N
MZ3H@=G)E:F[](%!'4"!KM?KH+"!P<FEVX71N>2!01U`@:[7ZZ"!A(&AE<VQO
M+@!.82!D9;EI9G)O=F%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J
M;OT@4R]-24U%(&NU^N@L('!R:7;A=&YY(%,O34E-12!KM?KH(&$@:&5S;&\N
M`$YA('!O9'#M<V%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@
M4R]-24U%(&NU^N@L('!R:7;A=&YY(%,O34E-12!KM?KH(&$@:&5S;&\N`$YA
M('IAN6EF<F]V86YI92!S<'+A=GD@:F4@<&^^861O=F%N_2!V97)E:F[](%--
M24U%(&NU^N@N`%!R961P;VQU9&[M;2!O8FQAZ&YO`%!R961P;VQU9&[M;2"U
M86AK_2!DX;[O`%!R961P;VQU9&[M;2!DX;[O`%!R961P;VQU9&[M;2!P<F5H
MX6YK>0!0<F5D<&]L=61N[6T@<VYE:&]VZ2!P<F5HX6YK>0`Q,B!H;V3M;@!!
M4$D@240`3R!T;VUT;R!E9&ET;W)E`$\N+BX`06)S;VSZ=&YY('-P;V1O:P!!
M8G-O;/IT;GD@<W1R960`4')I('9Y=';A<F%N[2!61E,@861R97/A<F$@8F]L
M('IA;6EE=&YU=/T@<'+M<W1U<"X`4')I('9Y=';A<F%N[2!61E,@<_IB;W)U
M(&)O;"!Z86UI971N=73]('!R[7-T=7`N`%!R:2!V>6UA>N%V86[M('!O>F[A
M;6MY(&)O;"!Z86UI971N=73]('!R[7-T=7`N`%!R:2!P<F5S^G9A;NT@<&]Z
M;N%M:WD@8F]L('IA;6EE=&YU=/T@<'+M<W1U<"X`4')I('5K;&%D86[M('!O
M>F[A;6MY(&1O("5S(&)O;"!Z86UI971N=73]('!R[7-T=7`N`%!R:2!U:VQA
M9&%N[2!P;WINX6UK>2!B;VP@>F%M:65T;G5T_2!P<NUS='5P.B`E<P!);F9O
M<FWA8VEE(&\@^NAT90!(97-L;R!P<F4@^NAE=`#:Z&5T('IA8FQO:V]V86[]
M+@#:Z'1O=F%N:64`4')I9&&[`%!R:61ANR!P;V1R:6%D96[Z('-K=7!I;G4`
M4')I9&&[('!O9')I861E;ND@<'+A=F\`4')I9&&[.@!0<FED8;L@<VMU<&EN
M=0!0<FED8;L@;F]VZ2!P<N%V;P!0<FED8;L@9&/I<G-K=2!S:W5P:6YU(&1O
M("(E<R(`4')I9&&[(&1CZ7)S:V4@<'+A=F\@9&\@(B5S(@!0<FED8;L@<&]U
MONUV871EM6$Z`%!R:61ANR!K871E9_-R:74`4')I9&&[('-TY7!E8P!0<FED
M8;L@Z&QE;F]V`%!R:61ANR!PX7(`4')I9&&[(&UE;G4@)7,@86MO($)OZ&[]
M('!A;F5L($UO>FEL;'D`4')I9&&[(&1O(&%D<F5SX7)A.@!0<FED8;L@9&\@
M;?1J:&\@861R97/A<F$`4')I9&&[('!O=;[M=F%T9;5A`"(E<R(@8F]L('!R
M:61A;OT@9&\@<WES=.EM=2P@86QE(&YE;6^^;F\@<')I9&&[(.]A;+EI92!P
M<FEH;&%S;W9A8VEE(&EN9F]R;>%C:64Z("5S+@`B)7,B(&)O;"!P<FED86[]
M(&1O('-Y<W3I;74N(%1E<F%Z('-A(&WTOF5T92!P<FEH;.%S:;LN`%!R:63A
M=F$@<V$@;F]VX2!P;WINX6UK80!0<FEDX79A;FEE('!O=;[M=F%T9;5O=B!J
M92!Z86OA>F%NZ2X`061R97-A`$%D<F5SX7(`061M:6YI<W1RX6-I82`M(&YA
M<W1A=F5N:64@<'+A=B!P<F4@:6[]8V@@<&]UONUV871EM6]V`$%D;6EN:7-T
M<N%C:6$`4F5K;&%M>0!!9F=A;FES=&%N`$%L8N%N<VMO`$%LONUR<VMO`$%L
M:6%S`%IA<F]V;F&[`%IA<F]V;F%N:64Z`%:Y971K>0!6N65T8VD@875T96YT
M:69I:V]V86[M('!O=;[M=F%T96QI80!6N65T:WD@<VMU<&EN>0!6N65T:WD@
M<'+A=F$`5KEE=&MY(+ET>7)I('-T<F%N>0!0;W9O;&F[('9I86-E<ND@861R
M97-Y`%!O=F]L:;L@;F%S=&%V96YI92!T>7!U('IO<F%D96[I:&\@>F]Z;F%M
M=3\`5;X@97AI<W1U:F4`06QT97)N873M=FYE('!R:6AL87-O=F%C:64@;65N
M;R!)35-0`$%L=&5R;F%T[79N92!H97-L;R!)35-0`$%L=&5R;F%T[79N92!P
M;W6^[79A=&6U<VOI(&UE;F\@24U34`!!;'1E<FYA=.UV;F$@92UM86EL;W;A
M(&%D<F5S80!!;'1E<FYA=.UV;F4@N6%B;/-N>0!!;'1E<FYA=.UV;GD@=&5X
M=#H`06UE<FEC:^$@4V%M;V$`0F]L82!Z861A;N$@;F5P;&%T;N$@:&]D;F]T
M80!.87-T86QA(&YE>F[A;6$@8VAY8F$N`$%N9&]R<F$`06YG;VQA`$%N9W5I
M;&QA`$%N;VYY;6[I('!R;WAY`$]D<&]V9>\`06YT87)K=&EK80!!;G1I9W5A
M(&$@0F%R8G5D80!!<&QI:^%C:6$`6F]Z;F%M(&%P;&EKX6-I[0!!<&QI:^%C
M:6$@:F4@<')I<')A=F5NX2X`07!L:6MO=F&[(&YA('!O9')I861E;ND@>F1I
M9;5A;ND@<')I9>AI;FMY`%-C:';A;&F[`%!R:6)L:;YNX2!V9;5K;W.[`$%P
M<NUL`%9EM6MO<[L@87)C:.UV=0!-96YO(&%R8VCM=G4`3F%O>F%J(&-H8V5T
M92!V>6UA>F&[(+YI861O<[L@;R!P<FEH;.%S96YI92`G)7,G/P!.86]Z86H@
M8VAC971E('9Y;6%Z8;L@(B5S(B!A(':Y971K>2!P;V1S:W5P:6YY/P!!<F=E
M;G3M;F$`07)MZ6YS:V\`56UE;FEE`$%R=6)A`%9Z;W-T=7!N90!/<W1R;W8@
M07-C96YS:6]N`$%S8VEI('5M96YI90#!>FEA+U!A8VEF:6-K_2!R96=I\VX`
M5GF^861O=F&[('!O='9R9&5N:64@<')E9"!V>6MO;F%N[6T@;W!E<N%C:>T@
M^F1ROF)Y/P!0;VMU<R!O('9Y;6%Z86YI92!N965X:7-T=6KZ8V5J('-K=7!I
M;GDN`%!O:W5S(&\@=GEM87IA;FEE(&YE97AI<W1U:OIC96AO('!RX79A+@!0
M;VMU<R!O(/IP<F%V=2!N965X:7-T=6KZ8V5H;R!P<N%V82X`4&]K=7,@;R#Z
M<')A=G4@;F5E>&ES='5J^F-E:&\@>F1I9;5A;NEH;R!O8FIE:W1U+@!!=')I
M8OIT>0!!=6=U<W0`075S='+A;&EA`%)A:_IS:V\`075T:%]C>7)S<6PZ(%!O
MOF%D;W9A;ND@<F]ZN>UR96YI92!I;6%P(&YE8F]L;R!NX6ID96[I+@!!=71H
M7V-Y<G5S.B!B86-K96YD(&YE;>$@<&^^861O=F%NZ2!S8VAO<&YO<W1I+@!!
M=71H7V-Y<G5S.B!P;[YA9&]V86[I(')O>KGM<F5N:64@:6UA<"!N96)O;&\@
M;N%J9&5NZ2X`075T:%]F='`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!&5%`@
M;F5B;VQO(&[A:F1E;NDN(%-K;VUP:6QU:G1E(%!(4"!S('!R97#M;F'H;VT@
M+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI
M92!)34%0(&YE8F]L;R!NX6ID96[I+@!!=71H7VMR8C4Z('!OOF%D;W9A;ND@
M<F]ZN>UR96YI92!K<F(U(&YE8F]L;R!NX6ID96[I+@!!=71H7VQD87`Z('!R
M:63A=F%N:64@<&]UONUV871EM6]V(&YI92!J92!P;V1P;W)O=F%NZ2!P<F4@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z('9Y;6%ZX79A;FEE('!O=;[M
M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;ND@<')E($%C=&EV92!$:7)E8W1O
M<GD`075T:%]L9&%P.B!P;[YA9&]V86[I(')O>KGM<F5N:64@3$1!4"!N96)O
M;&\@;N%J9&5NZ2X`075T:%]L9&%P.B!.97!O9&%R:6QO('-A('!R:61ANR!P
M;W6^[79A=&6U82`E<RX@4V5R=F5R(&]D<&]V961A;#H@`$%U=&A?;&1A<#H@
M;F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@<&]UONUV871EM6$@)7,`075T:%]L
M9&%P.B!N97!O9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!P;W6^[79A=&6U82`E
M<P!!=71H7VQD87`Z(&%K='5A;&EZX6-I82!P;W6^[79A=&6U;W8@;FEE(&IE
M('!O9'!O<F]V86[A('!R92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;6-A;#H@
M<&^^861O=F%NZ2!R;WJY[7)E;FEE($U#04P@;F5B;VQO(&[A:F1E;NDN`$%U
M=&A?<VUB875T:#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE('-M8F%U=&@@;F5B
M;VQO(&[A:F1E;NDN`$%U=&5N=&EF:6OA8VEA('!O;6]C;W4@24U!4"!S97)V
M97)A('IL>6AA;&$N`$%U=&5N=&EF:6OA8VEA('IL>6AA;&$`075T96YT:69I
M:^%C:6$@>FQY:&%L82X@)7,`4V5R=F5R(%)!1$E54R!Z86UI971O;"!A=71E
M;G1I9FEKX6-I=2X`075T96YT:69I:^%C:6$@<&]M;V-O=2!&5%`@<V5R=F5R
M82!Z;'EH86QA+@!!=71E;G1I9FEKX6-I82!P;VUO8V]U(%--0B!S97)V97)A
M('IL>6AA;&$N`$1O<W1U<&[I(&MA=&5G\W)I93H`1&]S='5P;ND@<&]L;[YK
M>3H`07IE<F)A:F2^86X`0D]&2"!%>&-U<V5S`$YA<W#DNR!N82!P;WINX6UK
M;W;](&)L;VL`3F%S<.2[(&YA(&YA<W1A=F5N:6$@<&]Z;N%M:V]VZ6AO(&)L
M;VMU`%!O>F%D:64`1F%R8F$@<&]Z861I80!:;.D@:&5S;&\@<')E(&ME<F)E
M<F]S+@!:;.D@<&]UONUV871EM7-KZ2!M96YO('!R92!K97)B97)O<RX`0F%H
M86UY`$)A:')A:FX`0F%N9VQA9.FY`$)A<F)A9&]S`%!R:67H:6YO:R!S(&=R
M869I:V]U("(E<R(@;F5B;VP@;N%J9&5N_2X`6N%K;&%D;OT@<FEA9&]K`$)I
M96QO<G5S:V\`0F5L9VEC:V\`0F5L:7IE`$)E;FEN`$)E<FUU9'D`0G5TX6X`
M3F%R;V1E;FEN>0!";&]K("(E<R(@87!L:6OA8VEE("(E<R(@;F5B;VP@;N%J
M9&5N_2X`3F%S=&%V96YI82!B;&]K=0!4>7`@8FQO:W4`5'7H;ND`0F]L[79I
M80!:X6QOOFMY`$]K<F%J`*GM<FMA(&]K<F%J83H`3VMR86IE`$)O<VYA(&$@
M2&5R8V5G;W9I;F$`3V)E`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD
M`$)R87KM;&EA`$)R:71S:^D@^GIE;6EE('8@26YD:6-K;VT@;V-EX6YE`$)R
M=6YE:2!$87)U<W-A;&%M`$)U;&AA<G-K;P!:;WIN86T@<R!O9'+AOFMA;6D`
M0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!$:7-T<FEB=>ANZ2!B;V1Y
M($-23`!#4U8@*&AO9&YO='D@;V1D96QE;ND@Z&EA<FMO=2D`5FQA<W1N;W-T
M:2!?8G5N:WDN+BX`26YC:6%L:7KA8VEA('9Y<F]V;N%V86-E:B!P86WD=&D@
M;F5B;VQA(&1O:V]NZ&5NX2X`2V%L96YDX7(`0F5Z=F5T<FEE`$MA;6)O9+YA
M`$MA;65R=6X`3F5P;V1A<FEL;R!S82!A=71O;6%T:6-K>2!O8FYO=FF[(&AE
M<VQO+"!K;VYT86MT=6IT92!S=F]J:&\@861M:6YI<W1RX71O<F$N`$YE<&]D
M87)I;&\@<V$@>F%P[7-ANR!D;R!S^F)O<G4@(B5S(@!.96UOOFYO(&%D;6EI
M<W1R;W9ANR!E>'1E<F[I(&]V;.%D8>AE('-E9&5N[2X`3F5P;V1A<FEL;R!S
M82!S<&]J:;L@<R!)34%0('-E<G9E<F]M.B`E<P!.97!O9&%R:6QO('-A(&]T
M=F]R:;L@<_IB;W(@(B5S(BX`2V%N861A`%IR=;EINP!:<G6Y:;L@<W!RX79U
M(&\@<')O8FSI;64`3F5P;V1A<FEL;R!S82!V>6UA>F&[('/Z8F]R("(E<R(N
M`$YE<&]D87)I;&\@<V$@;N%J<[L@9&_H87-N_2!A9')E<^%R+@!.96UOOFYO
M('!O:W)AZ&]V8;L@8F5Z('!A<F%M971R82`G=&%R9V5T1FEL92<N`$YE<&]D
M87)I;&\@<V$@;V1S='+A;FF[(&%D<F5SX7(@(B5S(BX`3F5M;[YN;R!O9'-T
M<N%N:;LL(&5X:7-T=6IE("5D(&YA<VQE9&]V;NUK;W8N`$YE;6^^;F\@<')E
M=7-P;W)I861ANRP@<&_H970@<&]L;[YI96L@<')E('!R975S<&]R:6%D86YI
M92!N97/Z:&QA<^T@<R!P;^AT;VT@=6QOOF5N_6-H('!O;&^^:65K+@!.97!O
M9&%R:6QO('-A('-M97)O=F&[('-P<N%V=2!N82!U<NAE;ND@Z.US;&\N`$MA
M<'9E<F1S:^D@;W-T<F]V>0!4:71U;&]K`$MA=&5G\W)I92!A('!O<&ES:WD`
M2V%T96?S<FEA`$MA:FUA;G-KZ2!O<W1R;W9Y`$UO8FEL;OT@=&5L96;S;@!6
M;&%S=&YO<W1I(&)U;FMY`%9Y<&QN96YI92!B=6YK>3H`5FQA<W1N;W-T:2!B
M=6YK>0!2;WIO<W1U<"!B=6YI96LZ`$UO8FEL;OT@=&5L96;S;@!$;R!S=')E
M9'4`4W1R961O869R:6-KX2!R97!U8FQI:V$`4&]D<F]B;ND@:6YF;W)MX6-I
M92!O(&-E<G1I9FEKX71E`%9L87-T;NUK(&-E<G1I9FEKX71U`%!O;&ET:6MY
M('!R92!C97)T:69I:^%T>0#(860`6FUE;FF[`%IM96YINR!68;EE(&AE<VQO
M`$YA<W1A=F5N:64@;65N82!A(&%D<FEE<RP@:W1O<ND@=FED:6$@M75D:6$L
M(&ME[R#H[71A:OH@82!O9'!O=F5D86KZ(&YA(%9AN64@92UM86EL>2X`3F%S
M=&%V96YI92!T<FEE9&5N:6$@82!Z;V)R87IO=F%N:6$@<&]Z;N%M;VLN`%IM
M96YA(&AE<VQA(&YI92!J92!V(&%K='7A;&YE:B!K;VYF:6=U<N%C:6D@<&]D
M<&]R;W9A;N$N("!+;VYT86MT=6IT92!S=F]J:&\@861M:6YI<W1RX71O<F$N
M`%IN86L`4U]K;VYT<F]L;W9ANR!L:6YK=2XN+@!#:&EL90#([6YA`%9Y8F5R
M=&4@87!L:6OA8VEU.@!:=F^U=&4@<VD@:&5S;&\`6G9OM71E('-I('!O=;[M
M=F%T9;5S:^D@;65N;P!6>6)E<G1E('-P]'-O8B!Z;V)R87IO=F%N:6$@9.%T
M=6UO=CH`5GEB97)T92!T>7`@N73];'4@>F]Z;F%M=2`H<')E('IO<F%D96[I
M('IO>FYA;7DI`%9Y8F5R=&4@:V%T96?S<FEE('!O>F[A;6]K(&YA('IO8G)A
M>F5N:64@=B!S^FAR;FYO;2!P;VBU861E+@!6>6)E<G1E('-I('-V;VH@<')E
M9&YA<W1A=F5N_2!P;WINX6UK;W;](&)L;VLN`%9I86YOZ&[](&]S=')O=@!$
M969I;NUC:6$@=')I961Y("5S(&YE8F]L82!NX6ID96[A+@!*87-N;P!6>6UA
M>F&[(&9O<FUU;.%R`$]D<W1RX6YINR!P<NUK87IY($U33V9F:6-E`%9Y;6%Z
M8;L@9&]T87H`3V1S='+A;FF[('!O=;[M=F%T9;5A.B`E<P!/9'-T<N%N:;L@
M<&]UONUV871EM6$`5GEM87IANR!P;W6^[79A=&6U<VOI(/ID86IE`$YE<VOT
M<B!V>6IA<VYE;FEE`$ML:6MN:71E('!R92!P;VMR8>AO=F%N:64`0VQI8VMA
M=&5L;"!C97H@2%144`!:871V;W)INR!O:VYO`$]B;&%K>0!2X6YO(&]B;&'H
M;F\`3V)L8>AN;P!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!:8F%L:;L@0F_H
M;OT@<&%N96P`6F)A;&5NZ2!O:W)A:F4`2V]L=6UB:6$`1F%R8F$`5OUB97(@
M9F%R8GD`5OUB97(@9F%R8GD`4W3E<&-E.@!.861P:7-Y('-TY7!C;W8`2V]M
M:6MS`%!R[6MA>@!0<NUK87IO=OT@:6YT97)P<F5T97(`2V]M96YTX7(`0F6^
M;ND@;65N;P!+;VUO<GD`4W!O;&_H;F]SNP!0;^CM=&'H90!3=&%V`%-T878`
M4F]Z9&EE;'D@=B!K;VYF:6=U<N%C:6D`2V]N9FEG=7+A8VEA('!R92!S>6YC
M:')O;FEZX6-I=2!S(%!$02P@:6YT96QI9V5N=&[];6D@=&5L96;S;FUI(&$@
M3W5T;&]O:V]M+@!+;VYF:6=U<N%C:6$@<&]T<F5B=6IE(&%K='5A;&EZX6-I
M=2X`2V]N9FEG=7)O=F&[("5S`%!O='9R[W1E(&AE<VQO`$MO;F=O`$1E;6]K
M<F%T:6-KX2!R97!U8FQI:V$@2V]N9V\`4W!O:F5N:64@>FQY:&%L;RX`4W!O
M:F5N:64@>FQY:&%L;SH@`$NU^N@@8F]L('IA;6EE=&YU=/T@<V5R=F5R;VT@
M=F5R96IN_6-H(&NU^NAO=BX`2[7ZZ"!B;VP@>F%M:65T;G5T_2!S97)V97)O
M;2!V97)E:F[]8V@@:[7ZZ&]V+B!$]'9O9#H@)7,@*"5S*0!3<&]J96YI92!S
M($944"!S97)V97)O;2!Z;'EH86QO+@!+;VYT86MT>0!+;VYT86MT>2!B;VQI
M(/IS<&6Y;F4@=FQOOF5NX2!D;R!6X;EH;R!A9')E<^%R82X`5'EP(&MO;7!R
M:6UO=F%NZ6AO('/Z8F]R=3H`3V)S86@@(B5S(@!0;VMR8>AO=F&[`$-O;VMO
M=F4@;W-T<F]V>0!#;V]K:64`2V]P[7)O=F&[`$MO<.UR;W9A;FEE('IL>6AA
M;&\Z("5S`$MO<.UR;W9ANR!V_6)E<@!+;W-T87)I:V$`4&]B<F6^:64@<VQO
M;F]V:6YY`$YE<&]D87)I;&\@<V$@>F&Y:69R;W9ANR!S<'+A=G4@<&]M;V-O
M=2!01U`Z(`!.97!O9&%R:6QO('-A('!O9'#M<V&[('-P<N%V=2!P;VUO8V]U
M(%!'4#H@`$YE<&]D87)I;&\@<V$@>F&Y:69R;W9ANR!S<'+A=G4@<&]M;V-O
M=2!3+TU)344N`$YE<&]D87)I;&\@<V$@<&]D<.US8;L@<W!RX79U('!O;6]C
M;W4@4R]-24U%+@!.97!O9&%R:6QO('-A('!R:61ANR!K;VYT86MT+B`E<RX`
M3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K($Q$05`@<V5R=F5R=2X`3F5P;V1A
M<FEL;R!S82!P<FEP;VIINR!K($Q$05`@<V5R=F5R=0!.97!O9&%R:6QO('-A
M(&]V97)INR!Z;W-T871O:R!N82#ZZ'1E+B`E<P!.87-T86QA(&-H>6)A('!R
M:2!P<NUS='5P92!K($Q$05`@<V5R=F5R=0!.97!O9&%R:6QO('-A('!R:7!O
M:FF[(&L@<V5R=F5R=2`B)7,B('!O;6]C;W4@1E10.B`E<P!.97!O9&%R:6QO
M('-A('9Y='9O<FF[('IO>FYA;2!P<NUJ96UC;W8N("5S`$YE<&]D87)I;&\@
M<V$@9&6Y:69R;W9ANR!01U`@^F1A:F4Z(`!.97!O9&%R:6QO('-A(&1EN6EF
M<F]V8;L@4R]-24U%(/ID86IE+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@:V]N
M=&%K="X@)7,`3F5P;V1A<FEL;R!S82!V>6UA>F&[('IO>FYA;2!P<NUJ96UC
M;W8N("5S`$YE<&]D87)I;&\@<V$@=GEM87IANR!S:W)I<'0@;F$@=7!G<F%D
M92!K;VYF:6=U<N%C:64@(B5S(BX`3F5P;V1A<FEL;R!S82!U<NAINR!E+6UA
M:6QO=OH@861R97-U('!R[6IE;6-U+@!.97!O9&%R:6QO('-A('-T:6%H;G6[
M(&-E;/T@861R97/A<BX`3F5P;V1A<FEL;R!S82!Z[7-K8;L@:V]M<&QE=&[]
M('IO>FYA;2!P<NUJ96UC;W8N`$YE<&]D87)I;&\@<V$@>NUS:V&[(&MO;7!L
M971N_2!Z;WIN86T@>F]Z;F%M;W8@<'+M:F5M8V]V+@!.97!O9&%R:6QO('-A
M(&YAZ.UT8;L@<W1R873I9VEU("(E<R(N`$YE<&]D87)I;&\@<V$@<W!U<W1I
MNR!M:V1I<B`B)7,B+@!.97!O9&%R:6QO('-A('KM<VMANR!V97)E:F[](&NU
M^N@@>F\@<V5R=F5R82!KM?KH;W8N`$YE<&]D87)I;&\@<V$@;W1V;W)INR`B
M)7,B('!R92!ZX7!I<RX`3F5P;V1A<FEL;R!S82!O='9O<FF[("5S+@!.97!O
M9&%R:6QO('-A(&]T=F]R:;L@;6]D=6P@36%I;G1E;F%N8V5?5&%S:R`E<P!.
M97!O9&%R:6QO('-A(&]T=F]R:;L@861R97/A<B`B)7,B+@!.97!O9&%R:6QO
M('-A('!R:7!O:FF[(&YA($Q$05`@<V5R=F5R+@!.97!O9&%R:6QO('-A('!R
M9>CM=&&[("5S+@!.97!O9&%R:6QO('-A(&]B;F]V:;L@:&5S;&\@>F%D86[I
M:&\@<&]UONUV871EM6$N($YI96MT;W+I(&%L96)O(':Y971K>2!P;V1R;V)N
M;W-T:2!N:64@<_H@<W!RX79N92X@4VOZ<W1E('1O('IN;W9U(&%L96)O(&MO
M;G1A:W1U:G1E(%;AN6AO(&%D;6EN:7-T<N%T;W)A+"!A:R!P;W1R96)U:F5T
M92!P;VUO8RX`3F5M;[YN;R!Z[7-K8;L@04-,`$YE<&]D87)I;&\@<V$@>NUS
M:V&[(&%D<F5SX7(N("5S`$YE<&]D87)I;&\@<V$@>NUS:V&[('IO>FYA;2!P
M<NUJ96UC;W8N("5S`$YE<&]D87)I;&\@<V$@>NUS:V&[('IO>FYA;7D@<'+M
M:F5M8V]V("5S`$YE;6^^;F\@>NUS:V&[(&EN9F]R;>%C:64@;R!V;&%S=&YO
M<W1I86-H('-E<G9E<F$`3F5P;V1A<FEL;R!S82!V<N%T:;L@:V]N9FEG=7+A
M8VEU+@!.97!O9&%R:6QO('-A('-P=7-T:;L@<FUD:7(@(B5S(BX`3F5P;V1A
M<FEL;R!S82!U;&^^:;L@:V]N9FEG=7+A8VEU("5S+@!.97!O9&%R:6QO('-A
M('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A8VEE+@!.97!O9&%R:6QO('-A('5L
M;[YINR!ZX6QO:'4@:V]N9FEG=7+A8VEE.B`E<P!.97!O9&%R:6QO('-A('5L
M;[YINR!S:W)I<'0@;F$@=7!G<F%D92!N87-T879E;NT@9&\Z("(E<R(N`$YE
M<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K;VYF:6=U<N%C:64@)7,N`$YE
M<&]D87)I;&\@<V$@>F%P[7-ANR!K;VYF:6=U<F'H;OT@<_IB;W(@)7,N($WT
MOF5T92!P;W6^:;L@;FEE:W1O<OH@>B!M;[YN;W-T[2!N82!ZX7!I<R!K\V1U
M(&YA("5S(&%L96)O('-K;W#M<F]V8;L@<G7H;F4@:_-D('5V961E;OT@;FF^
MN6EE(&1O("5S+@!.97!O9&%R:6QO('-A(&BU861ANR!N82!,1$%0('-E<G9E
M<FDN`$YE<&]D87)I;&\@<V$@=GEM87IANR`B)7,B+@!.97!O9&%R:6QO('-A
M(&%K='5A;&EZ;W9ANR!K;VYT86MT+B`E<P!.97!O9&%R:6QO('-A(&%K='5A
M;&EZ;W9ANR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO('-A('IA
M<.US8;L@:V]N9FEG=7+A8VEU('!R92`B)7,B.B`E<P!.96UOOFYO(&[A:G.[
M($)OZ&[]('!A;F5L($UO>FEL;'DN(%-K;VYT<F]L=6IT92P@OF4@:F4@<&%N
M96P@;W1V;W)E;OTN`%!O=;[M=F%T9;5O=FD@(B5S(B!S82!N97!O9&%R:6QO
M('!R:61ANR!P<N%V82!P<F4@<')I9>AI;F]K("(E<R(Z("5S`%!OZ.UT86[]
M('1E>'0`2W)A:FEN80!+=7)Z>0!6>71V;W)INP!6>71V;W)INR!L:6YK=0!6
M>71V;W)INR!N;W;]`%9Y='9O<FF[('!O9'!R:67H:6YO:P!6>71V;W)E;ND`
M4'+A=F$@='9O<F-U`,CM<VQO(&MR961I=&YE:B!K87)T>0!#:&]R=N%T<VMO
M`$MU8F$`06MT=>%L;F4@-"!FX7IY`$%K='7A;&YE('-E9&5N:6$`06MT=>%L
M;GD@Z&%S`$%K='7A;&YA(%523"!J90!!:W1UX6QN:2!P;W6^[79A=&5L:6$`
M06MT=>%L;F4@<&_H87-I90!!:W1UX6QN92!P;V1M:65N:WDZ(`!!:W1UX6QN
M>2"Y=/UL`$YA<W1A=F5N:64@^FQO:"P@:W1O<ND@<V$@<W#ZN;MA:OH@<')I
M('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S+@!6>7-T<FEH;OJ[`%9Y<W1R
M:6AN^KL@=OUB97(`0WEP<G5S`,AE<VOA(')E<'5B;&EK80!$1`!$4TX@*'!O
M>G)I(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&5N;F4`4')E>F5R8>@@9.%T;W;I
M:&\@<W1R;VUU("A$871A5')E92D`5GEHM6%DX79A;FEE('8@9&%T86+A>F4`
M1.%T=6T`1.%T=6T@<')I:F%T:6$`5OUB97(@9.%T=6UU`$1E\@!/7V1S='+A
M;FF[('-TY7!E8P!$96-E;6)E<@!$97-I871K;W;I(.CM<VQA`%IM96ZY:;L@
M;V1S861E;FEE`%!R961N87-T879E;ND`4')E9&YA<W1A=F5NX2!F87)B80!6
M8;EA('!R961N87-T879E;N$@:61E;G1I=&$`4')E9&YA<W1A=F5N_2!P;WIN
MX6UK;W;](&)L;VL`4')E9&YA<W1A=F5N_2!P<NUK87IO=OT@:6YT97)P<F5T
M97(`4')E9&YA<W1A=F5N_2!S</1S;V(@=')I961E;FEA.@!0<F5D;F%S=&%V
M96[]('-M97(@=')I961E;FEA.@!$969I;NUC:64`5GEM87IANP!6>6UA>F&[
M(&)U;FMU`%!O='9R9&5N:64@<')I('9Y;6%Z86[M`%9Y;6%Z8;L@<VMU<&EN
M=0!6>6UA>F&[('KA>FYA;0!6>6UA>F&[('!RX79O`%9Y;6%Z8;L@82!O9'-T
M<N%N:;L@<W!RX79Y`%-P<N%V86YI92!S82!T;&'H:61L82!N82!V>6UA>F%N
M:64`5GEM87IANR!B=6YK=0!6>6UA>F&[('-TY7!E8P!6>6UA>F&[(&5X:7-T
M=6KZ8W4@86QT97)N873M=FYU(+EA8FSS;G4`5GEM87IANR!P<N%V82!P<F4@
M(B5S(@!#:&-E=&4@=GEM87IANR`B)7,B(&$@=KEE=&MY(&IE:&\@<&]D<'+A
M=F$_`%9Y;6%Z8;L@<FEA9&]K`%9Y;6%Z8;L@=GEB<F%N^B!I9&5N=&ET=0!6
M>6UA>F&[(&%K='7A;&YY('-TY7!E8P!6>6UA>F&[(&%K='7A;&YY(')I861O
M:P!6>6UA>F&[('3Z=&\@<&]Z;N%M:W4`4VMR:7!T(&YA('5P9W)A9&4@:V]N
M9FEG=7+A8VEE("(E<R(@8F]L('9Y;6%Z86[]+@#(87,@9&]R=>AE;FEA`$3A
M;G-K;P!:;W-T=7!N90!0;W#MN71E('!R;V)LZ6T`4&]P:7,`4&]P:7,Z`%!O
M9')O8FYO<W1I("AT:66^('8@;&]G;W9A8V]M('/Z8F]R92!(;W)D92D`1&5T
M86EL>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82X`5OUV
M;VH`4F]S;OT@8F]D`%)O<V[](&)O9"!Z82!P;W-L961N^B!H;V1I;G4Z(`!2
M;W-N_2!B;V0Z(`!3;65R('JU879A(&1O<')A=F$`4VUE<B!S<')A=F$@9&^U
M879A`$%D<F5SX7(`6F]B<F%Z;W9ANR#H87,@=B`R-"UH;V1I;F]V;VT@9F]R
M;>%T93\`3F%S=&%V96YI92!Z;V)R87IE;FEA`%IO8G)A>FF[('!O9')O8F[Z
M('!R961P;W9E[P!:;V)R87IINR!P<F5D<&]V9>\@*%1!1BD`1F]R;>%T('IO
M8G)A>F5N:6$`4&]T=G)D96YI92!O(&1O<G7H96[M`$2^:6)U='-K;P!.979Y
M;6%Z8;L`3F5P;W6^[79A:G1E('!R:6%M;R!M86EN=&5N86YC92YP:'``0VAC
M971E('!O='9R9'IO=F&[('9Y;6%ZX79A;FEE('!O;&^^:65K/P!/8G-A:'5J
M92!P<G;](')I861O:R!NX7IV>2!P;VSM/R!!:R#A;F\L('IAN6MR=&YI=&4@
M<&]L[>AK;SH@`$1O;6EN:6-A`$1O;6EN:6OA;G-K82!R97!U8FQI:V$`3F5M
MX71E(/KH970_(%IA<F5G:7-T<G5J=&4@<V$N`%-T:6%H;G6[`%-T:6%H;G6[
M("5S`%-T:6%H;G6[('9Y9V5N97)O=F%N^B!K;VYF:6=U<N%C:74@86MO(%!(
M4"!S:W)I<'0N`%IO>FYA;2!S(';]8F5R;VT`1')O9WD`12UM86EL`$524@!%
M:W;A9&]R`%5P<F%V:;L`57!R879INR`B)7,B`%5P<F%V:;L@8FQO:P!5<')A
M=FF[('-K=7!I;G4`57!R879INR!P;WINX6UK=0!5<')A=FF[('!RX79O`%5P
M<F%V:;L@<'+A=F$`57!R879INR!P<N%V82!P<F4@)7,`57!R879INR!K871E
M9_-R:64@82!F87)B>0!5<')A=FF[(&YA<W1A=F5N:6$@<')E.@!5<')A=FF[
M('!RX79A('!R92`B)7,B`%5P<F%V:;L@<'+A=F$@<')E("5S`%9Z9&5LX79A
M;FEE`$5G>7!T`%-A;';A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6QO
M=N$@861R97-A.@!%+6UA:6QO=ND@861R97-Y(&UU<VEA(&)YNR!R;W9N86OI
M+@!%+6UA:6P@<R!P;W1V<F1E;NUM`$)RX6YA($5M86EL+6YA+5--4P!%;6]T
M:6MO;GD`4'+A>F1N82!P;WINX6UK80!0<N%Z9&YA('-P<N%V82X`4'+A>F1N
M>2!V_7-L961O:RX`4'+A>F1N92!P;V1M:65N:WD@:+5A9&%N:6$`4&]V;VQI
MNR!V;&^^96YI92!O8G+A>FMO=B!Z($=A;.ER:>T@9&\@=&5X='4_`%!O=F]L
M:;L@:V]N=&5X=&]VZ2!M96YU('!R92!P<F%VZ2!T;&'H:61L;S\`2V]N:65C
M(')O:V$`6G;DZ+EINR!E9&ET;W(`6F%D86IT92!B97IP9>AN;W-T;OH@;W3A
M>FMU+"!N82!K=&]R^B!B=61E=&4@;75S:66[(&]D<&]V961ANR!A:R!Z86)U
M9&YE=&4@:&5S;&\L(&YA<'(N("=A:V\@<V$@=F]LX2!M;VIE('IV:65R871K
M;S\G.@!:861A:G1E(%523"!O8G+A>FMA`%IA9&%J=&4@<.US;65NX2!U=F5D
M96[I(&YIOKEI93H`4F]V;NUK;W;A($=U:6YE80!%<FET<F5A`$-H>6)A`$-H
M>6)A('!R:2!V>71VX7)A;NT@8FQO:W4Z("5S`$-H>6)A('!R:2!V>6UA>N%V
M86[M('5K;W1V96YI82!S>6YC:')O;FEZX6-I93H@)7,`0VAY8F$@<')I('9Y
M;6%ZX79A;NT@>N%Z;F%M=2!S>6YC:')O;FEZX6-I93H@)7,`0VAY8F$@<')I
M('KM<VMA=F%N[2!O8G-A:'4Z("5S`$-H>6)A('!R:2!A:W1U86QI>N%C:6D@
M:&5S;&$Z("5S`$-H>6)A('8@92UM86EL;W9E:B!S<'+A=F4N`$-H>6)A('!R
M:2!Z87!I<V]V86[M("(E<R(N`$5S=/-N<VMO`$5T:?-P:6$`171N:6-KZ0!%
M=7+S<&$`2V&^9/UC:"`Q-2!M:6[Z=`!+8;YDZ2`R(&UI;OIT>0!+8;YD_6-H
M(#,P('-E:_IN9`!+8;YD_6-H(#4@;6EN^G0`4')I(&MAOF1O;2!P<FEH;.%S
M96[M`$MAOF3Z('!O;&AO9&EN=0!+8;YD^B!M:6[Z='4`3F%P<NUK;&%D.@!3
M<'5S=&F[`%)O>F)A;&F[`%)O>F)A;&F[($)OZ&[]('!A;F5L`$_H86OA=F$@
M<V$@)RDG`$_H86OA=F$@<V$@<VQO=F\@86QE8F\@<&]D;6EE;FMA(&BU861A
M;FEA('8@^G9O9'IO=FOA8V@`1.%T=6T@97AP:7+A8VEE`$5X<&]N96YT`$5X
M<&]R=`!%>'!O<G1O=F&[('!O>F[A;6MY`$9A<F)A('1E>'1U`$YA:')ANR!K
M;VYF:6=U<N%C:74@;F$@1E10`%]#96S]('1E>'0`3F5P;V1A<FEL;R!S82!Z
M[7-K8;L@;F%S=&%V96YI82X`3F%S=&%L82!C:'EB82!P<FD@<W!O:F5N[2!S
M($Q$05`@<V5R=F5R;VTN`$YA<W1A;&$@8VAY8F$@<')I('!R[7-T=7!E(&L@
M4TU"('-E<G9E<G4N`$YE<&]D87)I;&\@<V$@:V]P[7)O=F&[('H@(B5S(BX`
M3F5P;V1A<FEL;R!S82!K;W#M<F]V8;L@9&\@(B5S(BX`3F5P;V1A<FEL;R!S
M82!V>71V;W)INR!N;W;I(%-!4TP@<W!O:F5N:64N`$YE<&]D87)I;&\@<V$@
M<')E<W5N^KL@9&\@(B5S(BX`3F5P;V1A<FEL;R!S82!Z[7-K8;LZ("5S`$1O
M8G+I`$9A;&ML86YD<VOI(&]S=')O=GD@*$UA;';M;GDI`$9A97)S:^D@;W-T
M<F]V>0!:X79AOF[A(&-H>6)A.@!&87@`1F%X>0!&96)R=>%R`%!O8VET('1E
M<&QO='D`4&]C:70@=&5P;&]T>3H@`$UA;.D@>G+AOFMY`$UA;.D@<VYE:&]V
MZ2!P<F5HX6YK>0!-871I8V$@<&]L[0!&:62^:0!3^F)O<@!0;^AE="!S^F)O
M<F]V.B`E<R!S^F)O<@!0;^AE="!S^F)O<F]V.B`E<R!S^F)O<F]V`%-P<N%V
M8V$@<_IB;W)O=@!-96YO('/Z8F]R=0!6_6)E<B!S^F)O<G4`3F%H<F%T:64@
M<_IB;W)U`$YA:'+A=F%N:64@<_IB;W)O=B!N:64@:F4@<&]D<&]R;W9A;NDN
M`$9I;'1R90!&[6YS:V\`4')VX2!P;VQO=FEC80!0<G;A(+ET=G*[`%!E=F[]
M('!O;65R`$]T;^AINP!0;.%V86KZ8VD@=&5X=`!(;6QA`%!R:67H:6YO:R`E
M<R!N965X:7-T=6IE`$9A<F)A('#M<VUA`%!O=')A=F$`4')E('!R96AL:6%D
M8>AE+"!K=&]RZ2!N97!O9'!O<G5J^B!O8G+A>FMY`%!R961P;W9E[R`H5$%&
M*0!0<F5D<&]V9>\@;F$@=79E9&5N_2!P;^AE="!D;NT@*'!A;>1T86IT92!N
M82!T;RP@OF4@<')E9'!O=F7O(&IE('!R92!D;FD@86H@;F]C:2!A('1A:R!M
M]+YE('9EM6OI(.CM<VQO('9Y='9O<FF[('9EM6UI(+EI<F]K_2!B;&]K*0!:
M86)U9&QI('-T92!H97-L;S\`1F]R;75LX7)E`$9O<G1U;F$`5'EP(&9O<G1U
M;GD`1F]R='5N>0!&;W)T=6YY(#(`1O-R80!0<F5S;65R;W9A;FEA`%!I80!2
MX6UC90!&<F%N8_IZ<VMO`$9R86YC^GIS:V\@*$5U<O-P82D`1G)A;F/Z>G-K
M82!'=6%Y86YA`$9R86YC^GIS:V$@4&]L>6[I>FEA`$9R86YC^GIS:V4@:G6^
M;ND@=&5R:73S<FGA`$]D`%IO('-M97)U(`#:<&QN_2!P;W!I<P!3<&QN`$-E
M;.D@;65N;SH`1V%B=6X`1V%LZ7)I82P@>B!K=&]R96H@8VAC971E('9Z:6&[
M(&]B<N%Z;VL`1V%LZ7)I83H`1V%M8FEA`%:Y96]B96-NZ2!N87-T879E;FEA
M`$=E;F5R;W9ANR!K;VYF:6=U<N%C:74@<')E(&%P;&EKX6-I=2`E<P!'96YE
M<F]V86[](&OS9`!'96]R9VEA`$YE;65C:V\`1VAA;F$`1VEB<F%L=.%R`$MR
M<W1NZ2!M96YO`$]D;W-L8;L`1V]E9&5L`$=O;V=L92!-87!S`$BU861ANR!N
M82!';V]G;&4`3V1T:65N92"Y961E:@!'<NEC:V\`1W+S;G-K;P!'<F5N861A
M`$%D;6EN:7-T<N%C:6$@<VMU<.UN`$UE;N$@<VMU<.UN(&YE<VWZ(&)YNR!P
M<N%Z9&YE`$=R;W5P7VQD87`Z($YE<&]D87)I;&\@<V$@<')I9&&[('-K=7!I
M;G4@)7,N(%-E<G9E<B!O9'!O=F5D86PZ(`!'<F]U<%]L9&%P.B!N97!O9&%R
M:6QO('-A('9Y;6%Z8;L@<VMU<&EN=2`E<P!'<F]U<%]L9&%P.B!N97!O9&%R
M:6QO('-A(&%K='5A;&EZ;W9ANR!S:W5P:6YU("5S`%-K=7!I;GD`1W5A9&5L
M;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!0<N%V82!A;F]N>6UN_6-H
M('!O=;[M=F%T9;5O=@!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`
M1W5Y86YA`$A434P`2%1-3$%R96$@;F5D;W9O;.T@=GEM87IANR!P;W-L961N
M^B!B=6YK=2!V(')I861K=2X`2%1-3$%R96$@;F5D;W9O;.T@=GEM87IANR!P
M;W-L961N_2!S=.5P96,@=B!T86)UM6ME+@!(5$U,07)E82!N961O=F]L[2!V
M>6UA>F&[('!O<VQE9&[](')I861O:R!V('1A8G6U:V4N`$A45%`@875T96YT
M:69I:^%C:6$@;F5B;VQA(&[A:F1E;N$N`$AA:71I`$%L9V]R:71M=7,@:&%S
M:&]V86-E:B!F=6YK8VEE`$]P87(`2&QA=FGH:V$`2&QA=FGH:WD`2&5A<F1O
M=B!O<W1R;W8@82!-8T1O;F%L9&]V92!O<W1R;W9Y`%-I;&[A(&+Z<FMA`%;]
MN6MA`%!O;6]C;NUK`%!O;6]C;NUK('!R92!P;W6^[79A;FEE(&5D:71O<F$`
M4&]M;V-N[6L`4&]L;V=UM6$`5'4@:F4@>F'H:6%T;VL@<_IB;W)U.@!6>7-O
M:^$`1&]?;6]V`%9A=&EKX6X`1&]M;W8`1&]MX6-A(&%D<F5S80!$;VWA8VD@
M<')I9>AI;F]K`%1E;&5F\VX@9&]M;W8`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!V('-P<N%V92`E<R!B;VQI(&[A:F1E;ND@;F5P
M;&%T;ND@)7,@6$U,(/ID86IE`$AO<F1E+TMO;&%B.B!S(&]B:F5K=&]M("5S
M(&YE:V]R9;EP;VYD=6IE(+YI861N82!S<'+A=F$N`$AO<F1E+TMO;&%B.B!V
M('-P<N%V92`E<R!N96)O;"!NX6ID96[](+YI861E;B!O8FIE:W0@='EP=2`E
M<P!(;W)D92]+;VQA8CH@^G-P9;EN92!O9'-T<N%N96[I("5S("(E<R(`2&]R
M9&4O2V]L86(Z(&EN=&5G<N%C:6$@=GF^861U:F4@4$A0(')O>KGM<F5N:64@
M)V1O;7AM;"<`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@=GET=F]R:;L@
M;F]V_2!834P@<W1R;VT@<')E(&]B:F5K="`E<P!(;W)D92]+;VQA8CH@;F5P
M;V1A<FEL;R!S82!O9'-T<N%N:;L@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(&YE<&]D87)I;&\@<V$@>NUS:V&[($U)344@240@<')E(.AA<[L@='EP=2`E
M<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O;FEZ;W9ANR`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O
M;FEZ;W9ANR!Z9&EEM6%NZ2!O8FIE:W1Y.B`E<P!(;W)D92]+;VQA8CH@;F5Z
M;N%M>2!Z9&EEM6%N_2!O8FIE:W0@(B5S(@!(;W)I>F]N=.%L;F$@Z&EA<F$`
M2&]R:7IO;G3A;&YE('9Y<&QN96YI90!(;W)I>F]N=.%L;F4Z`$%K;R!S=&4@
M<V$@<V5M(&1O<W1A;&D_("A0<F]S[6T@;F%H;.%S=&4A*0!+;[5K;R!S=.5P
M8V]V(&-H8V5T92!Z;/KH:;L_`%IA9&%J=&4@<&_H970@<&]L[2`H<W3E<&-O
M=BD_`$MOM6MO(')I861K;W8@8VAC971E('IL^NAINS\`5FQH:V]SNP!6;&AK
M;W.[.B``2'5M;W)I<W1I`$UA[V%R<VMO`$YE<&]D87)I;&\@<V$@=GET=F]R
M:;L@24U!4"!S8VARX6YK=3H@)7,`3F5P;V1A<FEL;R!S82!V>6UA>F&[($E-
M05`@<V-H<N%N:W4Z("5S`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@24U!4"!K
M=O-T=3H@)7,`25`@861R97-A`$E0(&%D<F5S82!N:64@:F4@9&]S='5P;N$N
M`$E0(&%D<F5S82!N:64@:F4@=B!RX6UC:2!D;W9O;&5NZ6AO($-)1%(@8FQO
M:W4N`%!O<G6Y96YI92!P<F%V:61L82!O('!E=FYE:B!)4"!A9')E<V4N`%9L
M;[YINR!KM?KH(%]P<F5D`$ES;&%N9`!)8F$@:6MO;GD`26MO;GD@<')E("5S
M`$EK;VYY(&$@=&5X=`!.X7IO=B!I9&5N=&ET>3H`06L@<V$@;F5Z;V)R87KM
M(&MO<F5K=&YE+"`E<R!A(&]T=F]R[2!S82!V(&YO=F]M(&]K;F4N`$%K(&YE
M=FED[71E('!R:2!P;W6^:73M($EN=&5R;F5T($5X<&QO<F5R82"^:6%D;F4@
M:6MO;GDL('!O=')E8G5J971E('IAN6MR=&[ZNR!T^G1O('9OM6)U('!R92!V
M>7!N=71I92!P<FEE<W9I=&YO<W1I(%!.1R!O8G+A>FMO=BX`06L@=FED[71E
M('3Z=&\@<W!RX79U(&$@;F5V:63M=&4@;V)RX7IO:RP@;V)RX7IO:RP@:W1O
M<OT@<W1E(&-H8V5L:2!N86AR8;LL(&YE;?2^92!B>;L@>F]B<F%Z96[]('9O
M(%9AN6]M('!R96AL:6%D8>AI+@!5:^&^:V$@;V)RX7IK83H`55),(&]B<N%Z
M:V$`55),(&]B<N%Z:V$Z`$]B<N%Z;VL@>B!G86SI<FEE`$]B<N%Z;VL@>B!G
M86SI<FEE.@!.86AR871I92!O8G+A>FMU`$]B<N%Z:WD`26UP;W)T('!O>F[A
M;6]K+"!K<F]K("5D`$EM<&]R="P@:W)O:R`E9`!);7!O<G0O17AP;W)T('!O
M>F[A;6]K`$EM<&]R=&]V86[I('!O;&4Z("5S`$EM<&]R=&]V86[I('!O;&EA
M.@!6;&^^:;L@:[7ZZ"!?>F$`0F]L('IA9&%N_2!N97-P<N%V;GD@:_-D(&%K
M8VEE+@!.97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&$O86QE8F\@:&5S
M;&\`3F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!A;'1E<FYA
M=.UV;F$@861R97-A+B!3:_IS=&4@=&\@>FYO=G4@86QE8F\@:V]N=&%K='5J
M=&4@<W!RX79C=2!6X;EH;R!S>7-TZ6UU+"!A:R!P;W1R96)U:F5T92!P;VUO
M8RX`6G;DZ+EINR!O9'-A9&5N:64`26YD:6$`2F5D;F]T;&EV[2!P;W6^[79A
M=&5L:6$`26YD;V[I>FEA`$EN9F\`26YF;W)MX6-I90!);F9O<FWA8VEE('6^
M(&YI92!S^B!D;W-T=7!NZ2X`5FQOOFF[(%]S=.5P96,@>F$`5FQOOFF[(&]B
M<N%Z;VL`5FQOOFF[('1A8G6U:W4`5FQOOFF[(&QI;FMU`%9L;[YINR!?<W3E
M<&5C('!R960`5FQOOFF[(&YO=OT@<W3E<&5C('IA(&%K='7A;&YY`%9L;[YI
MNR!N;W;]('-TY7!E8R!P<F5D(&%K='7A;&YY`%9L;[YINR!N;W;](')I861O
M:R!Z82!A:W1UX6QN>0!6;&^^:;L@;F]V_2!R:6%D;VL@<')E9"!A:W1UX6QN
M>0!6;&^^:;L@;V1S=&%V96,@>F$@86MT=>%L;GD@8F]D`%9L;[YINR!O9'-T
M879E8R!P<F5D(&%K='7A;&YY(&)O9`!6;&^^:;L@86QT97)N873M=FYU(+EA
M8FSS;G4`6F%D86IT92!E+6UA:6QO=OH@861R97-U+"!N82!K=&]R^B!D;W-T
M86YE=&4@;F]VZ2!H97-L;SH`5FQOOFF[(&)U;FMU('IA`%9L;[YINR!B=6YK
M=2!P<F5D`%9L;[YINR!S=.5P96,@>F$`5FQOOFF[('-TY7!E8R!P<F5D`%9L
M;[YT92!S<'+A=GD`5FQOOFF[(&]D<W1A=F5C('IA`%9L;[YINR!O9'-T879E
M8R!P<F5D`%9L;[YINR!R:6%D;VL@>F$`5FQOOFF[(')I861O:R!P<F5D`%IA
M9&%J=&4@<&^^861O=F%N^B!O9'!O=F7O(&YA(&)E>G!EZ&YO<W1N^B!O=.%Z
M:W4Z`%9L;[YINR]U<')A=FF[(&]B<N%Z;VL`5FQOOFF[+W5P<F%V:;L@;&EN
M:W4`3F$@;V1O<VEE;&%N:64@<')E('IO>FYA;2!P<NUJ96UC;W8@;F5MX71E
M(&1O<W1A=&_H;OT@:W)E9&ET+@!.961O<W1A=&_H;OT@:W)E9&ET+@!#96SI
M(.CM<VQO`%IO>FYA;2!C96S]8V@@Z&ES96P`3F5P;&%D;ND@541(("A5<V5R
M($1A=&$@2&5A9&5R+"!(;&%V:>AK82!P;W6^[79A=&6U<VO]8V@@^F1A:F]V
M*2X`3F5P;&%T;ND@^F1A:F4@9F]R;>%T=2!:25`N`$YE<&QA=&[A(&%P;&EK
MX6-I82X`3F5P;&%T;ND@240@9.%V:WDN`$)O;&D@;V1O<VQA;ND@;F5P;&%T
M;ND@^F1A:F4N`$YE<&QA=&[A(&-I9;5O=N$@861R97-A+@!.97!L871N_2!F
M;W)MX70@<_IB;W)U`$YE<&QA=&[](&QI8V5NZ&[](&NU^N@N`$)O;&$@>F%D
M86[A(&YE<&QA=&[A(&QO:V%L:71A+@!.97!L871NX2!H;V1N;W1A(&US9U]T
M>7!E+@!.97!L871NX2!A;&5B;R!C:/UB86KZ8V$@:&]D;F]T82!A<&E?:60N
M`$YE<&QA=&[I(&%L96)O(&-H_6)A:OIC92!P87)A;65T<F4N`$YE<&QA=&[I
M(')O9&GH;W9S:^D@<'+A=F\N`$YE<&QA=&[I(&ED('!A<G1N97)A+@!.97!L
M871N_2!K\V0@<')O9'5K='4N`$YE<&QA=&[]('!R;W1O:V]L`$YE<&QA=&[]
M('!R[6IE;6-A.B`B)7,B`$YE<&QA=&[](&]B:F5K="!Z9&EEM6%N:6$`3F5P
M;&%T;N$@>F1R;VIO=N$@861R97-A+@!.97!L871NZ2#Z9&%J92!U;FEC;V1E
M+@!);G9E;G3A<@!);G9E<G1O=F&[(';]8F5R`$ERX6X`27)A:P#-<G-K;P!)
M<VQE(&]F($UA;@!/:F5D:6YE;.D@8OIR:WD`27IR865L`%9Y9&%V871EM0!+
M=7)Z[79A`%1A;&EA;G-K;P!*86UA:FMA`$IA;G7A<@!*87!O;G-K;P!*97)S
M97D`2F]R9.%N`$KZ;`!*^FX`6F%R;W9N8;L`6F%R;W9N8;L@9&\@<W1R961U
M`%IA<F]V;F&[(&1O(&)L;VMU`%IA<F]V;F&[(':U879O`%IA<F]V;F&[('9P
M<F%V;P!+87IA8VAS=&%N`%!O;F5C:&&[(&]R:6=I;N%L/P!+9?)A`$ME<F)E
M<F]S('-E<G9E<B!Z86UI971O;"!A=71E;G1I9FEKX6-I=2X`2V5R;F5L+6YO
M=N'H:6MO=FEA`%9Y='9O<F5N:64@:[7ZZ&$`1&EG:73A;&YY(&]D=&QAZ&]K
M(&NU^NAA`$3EOFMA(&NU^NAA`%1Y<"!KM?KH80!0;W6^:71I92!KM?KH80!+
MM?KH('6^(&5X:7-T=6IE(&YA('-E<G9E<FD@=F5R96IN_6-H(&NU^NAO=BX`
M1&5T:0!+:7)I8F%T:0"E=61O=F]D96UO:W)A=&EC:^$@<F5P=6)L:6MA($OS
M<F5A`$OS<F5J<VOA(')E<'5B;&EK80!+=79A:G0`2VER9VFY<VMO`%9Z7VBU
M860`2F%Z>6L`3&%O<P!0;W-L961NX2!P;VQO=FEC80!0;W-L961NX2!A:W1U
M86QI>N%C:6$`4&]S;&5D;N$@>FUE;F$@:&5S;&$`4&]S;&5D;N$@N71V<KL`
M4&]S;&5D;N$@86MT=6%L:7KA8VEA.@!0;W-L961NZ2!P<FEH;.%S96YI93H@
M)7,`4&]S;&5D;ND@<')I:&SA<V5N:64Z("5S('H@)7,`4&]S;&5D;ND@<')I
M:&SA<V5N:64Z(&YI:V1Y`$QO='FY<VMO`%!RX79O`%9Z:+5A9`!.96-H86IT
M92!P<N%Z9&YE('!R92"^:6%D96X@;VMR86H`3&EB86YO;@!6M6%V;P!(;&%V
M:>AK82!VM6%V;P!(;V1N;W1Y(':U879O`$QE<V]T:&\`VG)O=F7R`$QI8NER
M:6$`3.UB>6$`3&EC:'1E;KET86IN<VMO`*5A:&OI(&UR:&]L96YI90"E86AK
M_2!DX;[O`%+A;F\@M6%H:_T@9.&^[P!.97-K]'(@M6%H:_T@9.&^[P"E86AK
MZ2!D8;[O;W;I('!R96CA;FMY`*5A:&O](&3AON\@<R!H<FUE;NUM`*5A:&OI
M('-N9;YE;FEE`*5A:&OI('-N96AO=ND@<')E:.%N:WD`3&EM97)I8VL`3&EN
M:V$`3&EN:V$@=6MA>G5J92!N83H`4')E<&]J:;L@92UM86EL;W;Z(&%D<F5S
M=2!S;R!S='+A;FMO=2!N82!P[7-A;FEE('!ON71Y`$QI;FMY`$QI;G5X($-O
M;VMI90!:;WIN86T@+2!P;W6^[79A=&6U('5V:63M('!R:67H:6YO:P!6>7#M
M<V&[('IO>FYA;2!D871A8N%Z`%IO>FYA;2!TZ6T@4&]M;V-N[6MA`%9Y<.US
M8;L@>F]Z;F%M('1A8G5L:65K`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES
M="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T
M+55N<W5B<V-R:6)E`%IO8G)A>F5N:64@<V5D96[M('IL>6AA;&\Z("5S`%IO
M8G)A>F5N:64@<&]UONUV871EM6]V('IL>6AA;&\Z("5S`%IO8G)A>F]V86YI
M92!Z;WIN86UU('!O=;[M=F%T9;5O=B!J92!Z86OA>F%NZ2X`3&ET97)A=/IR
M80!,:71V80!.8>CM=&%V82!S82XN+@!-:65S=&YY(.AA<SH@`$QO:V%L:7KA
M8VEA(&$@Z&%S`$QO:V%L:71A`%!R:6ALX7-E;FEE`%KA>FYA;7D@<')E9&-H
MX61Z86KZ8V5J('-Y;F-H<F]N:7KA8VEE`$]D:&SA<VF[`%!R:6ALX7-E;FEE
M`-IL;VAY('!R:2!P<FEH;.%S96[M`%!R:6ALX7-E;FEE('IL>6AA;&\L('!R
M971OOF4@<W1E('IA9&%L:2!N97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO
M(&%L96)O(&AE<VQO+@!0<FEH;.%S96YI92!Z;'EH86QO+@!$;&C]('1E>'0`
M3.%S:V$`3NUZ:V$`36%LZ2!G<NEC:V4@<.US;65NX0!-86SI(&QA=&EN<VOI
M('#M<VUE;N$`36%LZ2!R[6US:V4@Z.US;&EC90!,=7AE;6)U<G-K;P!-30!3
M<'+A=F$@9/)A`%!R[6QO:&$@35,M5$Y%1B!N96]B<V%H;W9A;&$@OFEA9&YE
M(/ID86IE+@!-4T<`36%C86\`36%C963S;G-K;P!-861A9V%S:V%R`$WA9VEA
M`%!ON71A`%!O<VQANR!E+6UA:6P@861M:6YI<W1RX71O<F]V:0!6>71V;W)I
MNR!L:6Y?:W4N+BX`36%L87=I`$UA;&%J>FEA`$UA;&5D:79Y`$UA;&D`36%L
M=&$`4W!R879O=F&[('IO>FYA;2!K871E9_-R:>TL(',@:W1O<OUM:2!O>FYA
MZ'5J971E('!O;&^^:WD@82!F87)B>2!A<V]C:6]V86[I(',@=/UM:71O(&MA
M=&5G\W)I86UI+@!-87!A($UA<#(T`$UA<&$@36%P475E<W0`36%P;W9A;FEA
M('5L;[YE;NDN`$UA<F5C`$]K<F%J`$]Z;F'H:;L@<'+M>FYA:VUI(%!R9>CM
M=&%NZ2].97!R9>CM=&%NZ0!/>FYAZ&F[(&EN_6UI('!R[7IN86MM:2`H;F%P
M<BX@1/1L9;YI=.DO6F]D<&]V961A;NDI`$UA<G-H86QL;W9E(&]S=')O=GD`
M36%R=&EN:6L`6FAO9&[I('!O;&EA`$UA=7)E=.%N:6$`36%U<NUT:75S`$UA
M>&EMX6QN>2!P;W9O;&5N_2!K<F5D:70N`$)O;"!P<F5K<F_H96[](&UA>&EM
MX6QN>2!P;^AE="#H87-T[2!S<'+A=GDN`$YA:G9YN;EI82!T97!L;W1A('IA
M('!O<VQE9&[]8V@@,C0@:&]D[6XZ(`!.86IV>;FY:6$@=&5P;&]T82!Z82!P
M;W-L961N_6-H(#8@:&]D[6XZ(`!-87AI;>%L;GD@<&_H970@<&]Z;N%M;VL`
M36%X:6WA;&YY('!OZ&5T(&)L;VMO=B!P;W)TX6QU`$UA>&EMX6QN82!DY;YK
M80!-X6H`36%Y;W1T90!-961I8^UN80#(;&5N;W9I80!497AT('!O>F[A;6MY
M`%IO8G)A>F5N:64@;65N=3H`6FSZZ&F[(&)U;FMY`%-P<N%V80!3<'+A=F$@
M8F]L82#Z<W!EN6YE(&]V97)E;N$L(&%L92!C97)T:69I:^%T('!O9'!I<W4@
M<V$@;F5P;V1A<FEL;R!O=F5R:;LN`%!L871N;W.[('-P<N%V>2!V>7!RN6%L
M82X`5'EP('-P<N%V>0!0;^AA<VEE($UE=&%R`-ID86IE($UE=&%R(&YI92!S
M^B!D;W-T=7!NZ2X`VF1A:F4@365T87(@;FEE('/Z(&L@9&ES<&]Z[6-I:2X@
M1&5T86EL>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82X`
M4WES=.EM($UE=&%R1$(@;FEE(&IE('!R:7!O:F5N_2X`365T\V1A`$UE=/-D
M82`B)7,B(&YI92!J92!D969I;F]V86[A`$YE9&5F:6YO=F%NX2!M973S9&$N
M(%9O;&%NZ2!Z(&UE=/-D>3H@)7,`365T<FEC:^D`365X:6-O`$UI:W)O;NEZ
M<VME(&9E9&5R873M=FYE(+ETX71Y`%-T<F5D`%1Y<"!-:6UE`$YA:FYIOKEI
M82!T97!L;W1A('IA('!O<VQE9&[]8V@@,C0@:&]D[6XZ(`!.86IN:;ZY:6$@
M=&5P;&]T82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ(`!-:6YI;>%L;F$@9&]B
M82!P;&%T;F]S=&D@:&5S;&$@9;ET92!N979Y<'*Y86QA`%IR:V%D;&]V;R!O
M8G+A=&F[`%+T>FYE`$-H_6)A(&)A;.UK(%!%05(@2%144%]297%U97-T+@!#
M:/UB82!K;VYF:6=U<N%C:6$N($%K(&-H8V5T92!P;W6^[79ANR!T^G1O(&%P
M;&EKX6-I=2P@;75S[71E('1E<F%Z('9Y9V5N97)O=F&[(&MO;F9I9W5RX6-I
M=2X`0VC]8F$@240@<W!RX79Y+@!#:/UB82!P;[YA9&]V86[](%!%05(@8F%L
M[6L@36%I;"X`0VC]8F$@240@<F5LX6-I92X`4&]N`$UO8FEL;OT@;6%I;`!-
M:65R;GD`1.%T=6T@<&]S;&5D;F5J('IM96YY`%5P<F%V:;L@55),`-IP<F%V
M82!P;WINX6UK>2`G)7,G`$UO9'5L=7,`36]L9&%V<VMO`$UO;F%K;P!-;VYG
M;VQS:V\`365S:6%C(&$@<F]K`$UE<V'H;F4`36]N='-E<G)A=`!-97-AZ&[I
M(&;A>GD`3F$@<FEA9&MU("5D(&)O;&\@;N%J9&5N_6-H('9I86,@<&]L[2!A
M:V\@;^AA:^%V86[]8V@@)60N`$UA<F]K;P!0<F5V8;YN92!J87-N;P!0<F5V
M8;YN92!O8FQAZ&YO`%!R979AOFYE('-L;F7H;F\`4')E<W5N^KL@9&]L=0!0
M<F5S=6[ZNR!VM6%V;P!0<F5S=6[ZNR!V<')A=F\`4')E<W5N^KL@:&]R90!0
M<F5S=6[ZNR!D;VQU`%!R97-U;OJ[(&AO<F4`36]Z86)M:6L`5FEA8_IR;W;R
M;W;I('9Y8F5R86-I92!Z;WIN86UY`%9I86-NX7-O8F[](';]8F5R`$UO:F4@
M:V]N=&\`26YF;W)MX6-I92!O(&UO:F]M(/KH=&4`36]J92!P;WINX6UK>0!-
M]&H@<&]R=.%L`%9Z:+5A9"!M]&IH;R!P;W)TX6QU`$UY86YM87(`3FEE+"!.
M15/:2$Q!4\U-+@!-96YO`$YA;>UB:6$`3F%U<G4`3F5PX6P`2&]L86YD<VMO
M`$AO;&%N9'-KZ2!!;G1I;'D`6N%K;&%D;N$@55),($YE='-C87!E`%523"!P
M<F4@>FYE<&QA=&YE;FEE(&-E<G1I9FEKX71O=B!#02!.971S8V%P90!54DP@
M<')E('!O;&ET:6MU($-!($YE='-C87!E`%523"!P<F4@;V)N;W9E;FEE('!L
M871N;W-T:2!C97)T:69I:^%T;W8@3F5T<V-A<&4`55),('!R92!Z;F5P;&%T
M;F5N:64@8V5R=&EF:6OA=&]V($YE='-C87!E`$UE;F\@4U-,('-E<G9E<F$@
M3F5T<V-A<&4`2V]M96YTX7(@8V5R=&EF:6OA='4@3F5T<V-A<&4`5'EP(&-E
M<G1I9FEKX71U($YE='-C87!E`%-I9;L`3FEK9'D`3F]VX2!+86QE9/-N:6$`
M3F]VX2!K871E9_-R:6$`3F]VX2!S<'+A=F$@<')E("5S`$YO=@!.;W;A('!O
M>F[A;6MA`$YO=ND@<&]UONUV871EM7-KZ2!M96YO("AN97!O=FEN;NDI`$YO
M=OT@6NEL86YD`$YO=ND@:&5S;&\`4&QA=&YO<[L@;F]VZ6AO(&AE<VQA('9Y
M<'*Y[2`E>"X`3F]VZ2!H97-LX2!N:64@<_H@<F]V;F%KZ2X`3F]VZ2!O:VYO
M("A?8FQA;FLI`$YE=W,`1&ES:W5S;ND@<VMU<&EN>0#/86QE:@!.87-L961U
M:OIC92`T(&;A>GD`SV%LN6EE(&YA<W1A=F5N:6$`3F%S;&5D=6KZ8V$^`$YI
M:V%R86=U80!.:6=E<@!.:6?I<FEA`$YO8P!.:75E`$YI90!.:64@<_H@9&]S
M='5P;ND@OFEA9&YE(&MO;F9I9W5R8>ANZ2#Z9&%J92P@<')E(&MT;W+I(&)Y
M('-A(&1A;&D@>F]B<F%Z:;L@<F]Z9&EE;'DN`%!R92!V>71VX7)A;FEE($E3
M3R!O8G)A>F]V(&YI92!J92!K(&1I<W!O>NUC:6D@OFEA9&YA('-T<F%TZ6=I
M82X`3F5E>&ES='5J92"Y86)L\VYA('!R92!DX79K=2X`3F$@<&^^861O=F%N
M96H@<&]Z[6-I:2!N965X:7-T=6IE(+YI861E;B!B;&]K+@!0<F4@34-!3"!A
M=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&UE;F\@:V%L96YDX7)A+@"N
M:6%D;F$@>FUE;F$N`$L@=&]M=71O('!RX79U(&YE;6^^;F\@<')I9&&[(+YI
M861N92!P;V1R:6%D96[I('!RX79A+@!0<F4@)7,@;F5B;VQA('5RZ&5NX2!K
M;VYF:6=U<N%C:6$N`%!R92!&5%`@5D93(&YE8F]L82!U<NAE;N$@:V]N9FEG
M=7+A8VEA+@!0<F4@4U%,(%9&4R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I
M82X`4')E(%-13"U&:6QE(%9&4R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I
M82X`KFEA9&5N(&MR961I="X`3F5B;VQO(+EP96-I9FEK;W9A;ND@;6EE<W1O
M('5RZ&5N:6$N`%/Z8F]R(&YE8F]L(&YA:')A;OTN`$YE8F]L:2!NX6ID96[I
M(+YI861N92#Z9&%J92!I0V%L96YD87(N`$YE8F]L:2!NX6ID96[I(+YI861N
M92!I:V]N>2X`3FEE(&IE(&YA<W1A=F5NX2!L;VMA;&ET82X`3F5B;VQA('IA
M9&%NX2!L;VMA;&ET82X`3F5B;VQA('IA9&%NX2"^:6%D;F$@<W!RX79A+@!.
M96)O;&\@N7!E8VEF:6MO=F%NZ2"^:6%D;F4@;65N;RX`4')E(&YE<')I:&SA
M<V5N_6-H('!O=;[M=F%T9;5O=B!N:64@<_H@:R!D:7-P;WKM8VEI(+YI861N
M92!P;WINX6UK;W;I(&)L;VMY+@"N:6%D;F4@<&]Z;N%M:WD`KFEA9&YE('!O
M>F[A;6MY(&YE=GEH;W9U:OH@86MT=>%L;GEM(&MR:73I<FGA;2X`KFEA9&YE
M('!O>F[A;6MY(&YA('IO8G)A>F5N:64`3F5B;VQO(+EP96-I9FEK;W9A;ND@
MZ.US;&\N`*YI861N92!U<N&^;&EVZ2!F;W)T=6YY`%!R92!(5%10(&%U=&5N
M=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!)34%0(&%U=&5N
M=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!+97)B97)O<R!A
M=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@3&]G:6X@
M875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E(%!!4U-7
M1"!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@4TU"
M(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`$YE8F]L82!Z
M861A;N$@8V5S=&$@:R!P<F]G<F%M=2!/<&5N4U-,+B!0<F]G<F%M($]P96Y3
M4TP@:F4@<&]T<F5B;OT@;F$@<'+A8W4@<R#Z9&%J;6D@4$M#4R`Q,BX`KFEA
M9&YE('!R96)I96AA:OIC92!P<FEH;.%S96YI82X`2W;S=&$@;FEE(&IE(&YA
M<W1A=F5NX2X`0F5Z(.AI87(`3F5B;VP@N7!E8VEF:6MO=F%N_2!O9&1EM6]V
M8>@N`$)E>B!S='+A;@!3^F)O<B!N96[A:F1E;OT`4')E('9Y<F]V;N%V86-I
M=2!P86WDNR!N:64@:F4@9&]S='5P;OT@OFEA9&5N(&1OZ&%S;OT@<')I9>AI
M;F]K+@!.96)O;&\@;V1O<VQA;ND@<&]UONUV871EM7-KZ2!M96YO(&$O86QE
M8F\@:&5S;&\N`$YE8F]L:2!V<N%T96[I('!L871NZ2!834P@^F1A:F4`KFEA
M9&YE(&AO9&YO='D`5B!P]'9O9&YE:B!K;VYF:6=U<N%C:6D@;F5B;VQA(&[A
M:F1E;N$@OFEA9&YA('9E<GII82X@5GEG96YE<G5J=&4@>FYO=G4@:V]N9FEG
M=7+A8VEU+@!6(&MO;F9I9W5RX6-I:2!N96)O;&$@;N%J9&5NX2"^:6%D;F$@
M=F5R>FEA+B!6>6=E;F5R=6IT92!Z;F]V=2!K;VYF:6=U<N%C:74N`%!O7WIN
MX6UK80"N:6%D96X`KFEA9&YE("AP;W6^:;L@:6UP;&EC:71N^B!H;V1N;W1U
M*0!/<W1R;W8@3F]R9F]L:P!3979E<F[A('!O;&]G=;5A`%-E=F5R;ND@36%R
M:>%N<VME(&]S=')O=GD`3O-R<VMO`$YE<&QA=.T@<&\`3F5P;&%T[2!P<F5D
M`$YI92!J92!A9')E<^%R`$YI92!J92!I;7!L96UE;G1O=F%NZ2X`3F5N87-T
M879E;ND`3FEE(&IE('!O9'!O<F]V86[I+@!+871E9_-R:6$@<&]Z;N%M:WD`
M1&5T86EL>2!P;WINX6UK>0!:;WIN86UY('!O>F[A;6]K`%1E>'0@<&]Z;N%M
M:WD`7U1E>'0@<&]Z;N%M:WD`4&]Z;N%M:V$@;F5B;VQA(&[A:F1E;N$N`%]0
M;WINX6UK;W;](&)L;VL`3N%Z;W8@<&]Z;N%M:V]VZ6AO(&)L;VMU.@!0;WIN
MX6UK;W;I(&)L;VMY`%!O>F[A;6MO=ND@8FQO:WD@;75S:6$@;6&[(&[A>F]V
M+@!0;WINX6UK>0!3^FAR;B!P;WINX6UO:P!.:>@@;F$@<')E>F5R86YI92P@
M=G+ANW1E('-A('-PY+LN`$YO=F5M8F5R`,CM<VQO`%!OZ&5T('IN86MO=@!0
M;^AE="!S=.5P8V]V`%!OZ&5T(')I861K;W8`4')E(&%K='5A;&EZX6-I=2!Z
M;WIN86UU('!R[6IE;6-O=B!N96)O;&D@N7!E8VEF:6MO=F%NZ2#H[7-L82X`
M3TL`3V)J96MT`$%U=&]R(&]B:F5K='4`3W-M:>AK;W;]`$]K=/-B97(`1FEL
M=&5R(&YA(&YA9.%V:WD`4')A8V]V:7-K;P!3=&%RZ2!A(&YO=ND@:&5S;&\@
M;75S:6$@8GF[(&]D;&FY;NDN`%-T87+I(&AE<VQO`%-T87+I(&AE<VQO(&YE
M8F]L;R!Z861A;ND@<W!RX79N92X`3VWA;@!)8F$@24U!4"!S97)V97)Y('!O
M9'!O<G5J^B!Z9&EEM6%NZ2!P<FEEZ&EN:WDN`$EB82!U<N&^;&EVZ2!F;W)T
M=6YY`$IE('!R[7!U<W1NX2!I8F$@:F5D;F$@92UM86EL;W;A(&%D<F5S82X`
M5FQA<W1N[6MA(&%L96)O('!RX79A('9L87-T;NUK82!P<F4@>F1I9;5A;OT@
M;V)J96MT(&WTOF4@>FUE;FF[(&EB82!V;&%S=&[M:R!A;&5B;R!S>7-TZ6UO
M=OT@861M:6YI<W1RX71O<@!/='9O<FF[('8@;F]V;VT@;VMN90!#:'EB82!/
M<&5N4U-,.B!N97!O9&%R:6QO('-A('KM<VMANR#Z9&%J92!Z('!O9'#M<V%N
M96H@Z&%S=&D@4R]-24U%+@!/='9O<FF[('3Z=&\@;&EN:W4@=B!N;W9O;2!O
M:VYE`$]P97)AZ&[]('-Y<W3I;0!.87-T879E;FEA`$YA<W1A=F5N:6$@)7,`
M6F]R861E;OT@>F]Z;F%M`$]R9V%N:7KA8VEA`$]R9V%N:7IAZ&[A(&IE9&YO
M=&MA`$]R9V%N:7IO=F%N:64`4/1V;V1NX2"Y86)L\VYA(&%P;&EKX6-I90!0
M]'9O9&[I(+EA8FSS;GD@=B`E<SH`26[I`,]A;+EI92!I;F9O<FWA8VEE`%!R
MX79A('9L87-T;NUK80!004T@875T96YT:69I:^%C:6$@;FEE(&IE(&1O<W1U
M<&[A+@!014%2.DUA:6P@8F%C:V5N9`!$:6=I=.%L;GD@<&]D<&ES(%!'4`#:
M9&%J92!Z8;EI9G)O=F%NZ2!P;VUO8V]U(%!'4`!01U`@=F5R96IN_2!KM?KH
M`-ID86IE('!O9'#M<V%NZ2]Z8;EI9G)O=F%NZ2!P;VUO8V]U(%!'4`!02%`@
M:_-D`%!(4"!3:&5L;`!0;W!O;'5D;NT@M6%H:_T@9.&^[P!0;W!O;'5D;NT@
M<')E:.%N:WD`4&]P;VQU9&[M('-N9;YE;FEE`%!O<&]L=61N[2!S;F5H;W;I
M('!R96CA;FMY`%!O<&]L=61N[2!S;F6^96YI90!0;W!O;'5D;NT@8OIR:WD`
M0VC]8F$@<F]ZN>UR96YI92!03U-)6`!07TA0(%-H96QL`%9Y<&QN96YI90!0
M86MI<W1A;@!086QA=7-KZ2!O<W1R;W9Y`%!A;&5S=.UN<VME(/IZ96UI90!0
M86YA;6$`4&%P=6$@3F]VX2!'=6EN96$`4&%R86=U87D`R&EA<W1OZ&YE(&]B
M;&'H;F\`2&5S;&\`2&5S;&\@8F]L;R#Z<W!EN6YE('IM96YE;NDN`$YE<W!R
MX79N92!H97-L;P!0<F4@875T96YT:69I:^%C:74@4D%$2553(&IE('9YOF%D
M;W9A;ND@:&5S;&\N`$AE<VQO(',@<&]T=G)D96[M;0!(97-L;SH`2&5S;&\Z
M(`!(97-LX2!M=7-I82!B>;L@<F]V;F%KZ2X`5FQOOFF[`%9L;[YINR!Z;R!S
M8VARX6YK>0!#97-T80!0<F5B:65H86KZ8V4@<F5G:7-T<N%C:64Z`*5U9&EA
M`%!E<F-E;G0`5GEK;VYANR!O<&5RX6-I92#Z9'*^8GD`5GEK;VYANR!O<&5R
MX6-I92#Z9'*^8GD@<')I('!R:6ALX7-E;NT_`%!RX79O`%!RX79O("(E<R(@
M;F5B;VQO('9Y;6%Z86[I+@!0<NUS='5P('IA;6EE=&YU=/T`4'+A=F$`061M
M:6YI<W1RX6-I82!P<N%V`$]S;V)NZ2!I;F9O<FWA8VEE`%!E<G4`1&]MX6-E
M('IV:65R873A`$9I;&EP[6YY`%1E;&5F\VX`1F]T;V=R869I90!0:71C86ER
M;@!";V1O=@!+;&EK;FET92!P<F]S[6T@9&\@;F5J86ME:B!B=6YK>0!0;W1V
M<N]T92!P<F]S[6TL(+YE(&-H8V5T92!O9'-T<N%N:;L@=&5N=&\@96QE;65N
M=#H`4&]T=G+O=&4@<')O<^UM+""^92!C:&-E=&4@;V1S='+A;FF[(&QI;FMU
M('H@=&]H=&\@96QE;65N='4N`%IA9&%J=&4@<')O<^UM(&UE<VEA8R!A(')O
M:RX`6F%D86IT92!P<F]S[6T@;65N;R!P<F4@;F]V^B!K871E9_-R:74Z`%IA
M9&%J=&4@<')O<^UM('!L871N^B!)4"!A9')E<W4N`%IA9&%J=&4@<')O<^UM
M('!L871N_2!DX71U;2P@<VMO;G1R;VQU:G1E('!OZ&5T(&1N[2!V(&UE<VEA
M8VDN`%IA9&%J=&4@<')O<^UM('!L871N_2#H87,N`%!R;W/M;2!U=F7O=&4@
M>FAR;G5T:64@<')O8FSI;74N`%!R;W/M;2!Z861A:G1E('-V;VIE('!O=;[M
M=F%T9;5S:^D@;65N;R!A(&AE<VQO`%!R9>CM=&%J=&4@<VD@<')O<^UM(&YA
M<VQE9'5J^F-I('1E>'0N($U54\U412!S^FAL87-INR!S('!O9&UI96YK86UI
M('!O=;[M=F%N:6$@<WES=.EM=2X`6F%D86IT92!P<F]S[6T@;65N;R!P<F4@
M;F]V^B!K871E9_-R:74Z`%!OM7-K;P!0;VQI=&EK80!!;FME='D`4&]R='5G
M86QS:V\`56UI97-T;F5N:64@=&]H=&\@;V)RX7IK=0!5;6EE<W1N96YI92!T
M96IT;R!T86)UM6MY`$]D;W-L8;L@9&\@=&]H=&\@<')I9>AI;FMA("AN979Y
M;G5C=6IE($E-05`I`%IRX;YK>2!Z82!P;W-L961N_6-H("5S(&AO9.UN.B``
M4')A=F1E<&]D;V)N;W.[/&)R("\^>G+AOF]K`%!R969S7VQD87`Z('!OOF%D
M;W9A;ND@<F]ZN>UR96YI92!,1$%0(&YE8F]L;R!NX6ID96[I+@!0<F5F<U]S
M97-S:6]N.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<V5S<VEO;B!N96)O;&\@
M;N%J9&5NZ2X`5&QA:P!4;&%K(&YA(/IR;W9N:2!M;W)A.B``5&QA:SH@`%5K
MX;YK80!:;V)R87IINR!U:^&^:W4@;V)RX7IK=2!V(&YO=F]M(&]K;F4`4')E
M9&-HX61Z86KZ8V4@;F%S=&%V96YI80!6>71L8>AINR!D;VMU;65N=`!0<FEV
MX71N>2!KM?KH`%!R;V)LZ6T`4&]P:7,@<')O8FSI;74`4')O:F5K='D`5OUZ
M=F$@;F$@>F%D86YI92!T97AT=0!697)E:F[](&NU^N@`06QG;W)I=&UU<R!V
M97)E:F[I:&\@:[7ZZ&$`26YF;W)MX6-I92!O('9E<F5J;F]M(&NU^NAI`%9E
M<F5J;OTO<')I=N%T;GD@:[7ZZ&]V_2!PX7(@;F5B;VP@^G-P9;EN92!V>6=E
M;F5R;W9A;OTN`%!O<G1O<FEK;P!+871A<@!$;W1A>@!+=O-T80!24T$@=F5R
M96IN_2!KM?KH("@E9"!B:71O=BD`4')E<.UN8>@@<R!V_6)E<F]M`$3AON\`
M4N%N;R!DX;[O`$YE<VOT<B!DX;[O`$1AON]O=ND@<')E:.%N:WD`1.&^[R!S
M;R!S;F5H;VT`1.&^[R!P<F5C:.%D>F%J^F-I('8@<VYEOF5N:64`3N%H;V1N
MX2!F;W)T=6YA`%!O;65R`,CM=&&[`,CM=&&[('-P<N%V>0!.86]Z86H@=GEM
M87IANR`E<S\@5/IT;R!O<&5RX6-I=2!N96UOOFYO('9RX71INR!S<.2[+@!.
M86]Z86H@<VD@OF5LX71E('9Y;6%Z8;L@=/IT;R!P;WINX6UK=3\`3F%O>F%J
M('9Y;6%Z8;L@<&]UONUV871EM7-KZ2#Z9&%J92!P<F4@<&]UONUV871EM6$@
M)7,_(%3Z=&\@;W!E<N%C:74@;F5M;[YN;R!V<N%T:;L@<W#DNRX`5G+A=&D@
M<W#DNR!68;EU('!O<VQE9&[Z(&%K8VEU`$]B;F]V:;L`3V)N;W9INR!E;&5M
M96YT>2!D>6YA;6EC:^EH;R!M96YU.@!/8FYO=FF[('IO8G)A>F5N:64`3V)N
M;W9INR!Z;V)R87IE;FEE('!O<G3A;'4Z`%)E9W5LX7)N>2!V_7)A>@!0<F5H
M;&EA9&'H('9ZNV%H;W8`6FYO=G4@;F'H[71ANP!0;W-T<F5H>0!6>F1I86QE
M;ND@<V5R=F5R>0!6>F1I86QE;N$@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`3V1S='+A;FF[`$]D<W1RX6YINR!B;&]K`$]D<W1RX6YI
MNR!K871E9_-R:74`3V1S='+A;FF[('-TY7!E8P!/9'-T<N%N:;L@9F]R;>%T
M;W9A;FEE`$]D<W1RX6YINR!PX7(`3V1S='+A;FF[('5L;[YE;OT@<VMR:7!T
M('H@9&_H87-NZ6AO('!R:67H:6YK82!N82!S97)V97)I+@!/9'-T<N%N:;L`
M3V1S='+A;FF[('1E;G1O(&)O9"!Z(&1O:W5M96YT=0!/9'-T<N%N:;L@<&]U
MONUV871EM6$`3V1S='+A;FF[('!O=;[M=F%T9;5A.B`E<P!.82!P;[YI861A
M=FMU(&YE8F]L;R!M;[YNZ2!O9'!O=F5D8;LN($[A=G)A=&]V_2!K\V0@8VAY
M8GDZ(`!0;[YA9&]V86[Z('-L=;YB=2!S82!N97!O9&%R:6QO(&[A:G.[+@!6
M(&MO;F9I9W5RX6-I:2`E<R!N:64@:F4@N7!E8VEF:6MO=F%NX2!P;[YA9&]V
M86[A('!O;&^^:V$@(B5S(@!6(&MO;F9I9W5RX6-I:2!61E,@;FEE(&IE(+EP
M96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA("(E<R(`5B!K;VYF:6=U
M<N%C:6D@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA
M("(E<R(`4&]V:6YNZ2!P;VQE`%9Y;6%Z8;L@9F]R;75LX7(`3V)N;W9INR!H
M97-L;P!/8FYO=FF[(%9AN64@:&5S;&\`3V)N;W9INR!P;W-L961N_2!D;W1A
M>@!6_7-L961K>0!.X79R870@;F$@;F%S=&%V96YI80!:861A:G1E(&YO=ND@
M:&5S;&\`4F5U;FEO;@!6<N%T:;L@:V]N9FEG=7+A8VEU`$YA<W1A=F5N:6$@
M<F]ZN>UR96[I:&\@=&5X=&]VZ6AO(&5D:71O<G4`2.%D86YK>0!6<')A=F\`
M2&QA=FGH:V$@=G!R879O`$AO9&YO='D@=G!R879O`%9L87-T;F]S=&D@7W)I
M861K82XN+@!2;VQA`%)U;75N<VMO`$]T;^AINR!O(#$X,`!/=&_H:;L@=K5A
M=F\`3W1OZ&F[('9P<F%V;P!6;&%S=&YO<W1I(')I861K80!6;&%S=&YO<W1I
M(')I861K80!2:6%D:WDZ`,AI87)Y`,AI87)Y('-A('IO8G)A>FEA(&UE9'II
M(':Y971K_6UI(')I861K86UI(&$@<W3E<&-A;6D`R&EA<GD@<V$@>F]B<F%Z
M:6$@:6)A(&UE9'II('-TY7!C86UI`,AI87)Y('-A('IO8G)A>FEA(&EB82!M
M961Z:2!R:6%D:V%M:0!3<'5S=&F[`%)U<VOA(&9E9&5RX6-I80!2=V%N9&$`
M4R]-24U%(&MR>7!T;V=R869I8VO]('!O9'!I<P!3<'+A=F$@>F&Y:69R;W9A
M;N$@<&]M;V-O=2!3+TU)344`4T%33"!A=71E;G1I9FEKX6-I82!N:64@:F4@
M9&]S='5P;N$N`%!O<VEE;&%N:64@4TU3`%-13"!3:&5L;`!344P@<'+M:V%Z
M('!R92!HM6%D86YI92!H;V1N]'0`4U-(`-I34$5#2`!37U%,(%-H96QL`%-O
M`%-VY'3A($AE;&5N80!3=N1T_2!+:71T<R!A($YE=FES`%-VY'3A($QU8VEA
M`%-V+B!0:65R<F4@82!-:7%U96QO;@!3=N1T_2!6:6YC96YT(&$@1W)E;F%D
M:6YY`%1E;B!I<W3]('+A;65C("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!A(%!R:6YC:7!E`%-A=&5L:71N_2!P;W-K>71O=F%T9;4`4V%U
M9'-KX2!!<N%B:6$`56QOOFF[`%5L;[YINR`B)7,B`%5L;[YINR`E<P!5;&^^
M:;L@;F%S=&%V96YI80!5;&^^:;L@=GEG96YE<F]V86[Z(&MO;F9I9W5RX6-I
M=2!A:V\@4$A0('-K<FEP="!D;R!D;^AA<V[I:&\@<')I9>AI;FMA(%;AN6AO
M('-E<G9E<F$N`$MO;F9I9W5RX6-I82`E<R!B;VQA('5L;[YE;N$N`%-K<FEP
M="!N82!U<&=R861E(&YA<W1A=F5N[2!B;VP@=6QOOF5N_2!D;SH@(B5S(BX`
M3VIE9&EN96SI(&+Z<FMY`%9E9&$`2+5A9&&[`%9Y:+5A9.%V8>AE`%;]<VQE
M9&MY(&BU861A;FEA`$BU861ANR!V('!O;&D`2&%D8;L@7W1E>'0`5GEB97)T
M92!S^F)O<GD`5GEB97)T92!DX71U;0!6>6)E<G1E('-K=7!I;G4@;F$@<')I
M9&%N:64`5GEB97)T92!N;W;I:&\@=FQA<W1N[6MA`%9Y8F5R=&4@<&]Z;N%M
M:V]V_2!B;&]K`%9Y8F5R=&4@<V5R=F5R`%9Y8F5R=&4@<&]UONUV871EM6$@
M;F$@<')I9&%N:64`5GEB97)T92!VN65T:WD`5GEB97)T92!VN65T:WD@:V]M
M<&]N96YT>2!DX71U;74`5GEB97)T92!O8FIE:W0`6G)UN6F[(';]8F5R`%9Y
M8F5R=&4@<&]Z;N%M:V]VZ2!B;&]K>2P@:W1O<ND@<V$@;6%J^B!Z;V)R87II
MNSH`5GEB97)T92!Z;F%K>2P@:W1O<ND@<&]T<F5B=6IE=&4L('H@;VMI96YO
M:R!N:;ZY:64N(%!O=&]M(&EC:"!M]+YE=&4@<VMO<.UR;W9ANR!A('9L;[YI
MNR!Z('1E>'1O=NEH;R!P;[5A+@!6>6)E<G1E(&]D9&6U;W9AZ"!V;R!F;W)M
MX71E(&3A='5M=3H`5GEB97)T92!F;W)MX70@9.%T=6UU.@!6>6)E<G1E(&9O
M<FWA="!E>'!O<G1U.@!6>6)E<G1E('/Z8F]R(&YA(&EM<&]R=#H`5GEB97)T
M92!F;W)MX70@>F1R;VIO=NEH;R!S^F)O<G4Z`%9Y8F5R=&4@:61E;G1I='4L
M(&MT;W+Z(&-H8V5T92!Z;65N:;LZ`%9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O
M<FWA=&4@Z&%S=3H`5GEB97)T92!F;W)MX70@Z&%S=3H`5GEB97)T92!D=F4@
M>FAO9&[I('!O;&EA+@!6>6)E<G1E('-I(&9A<F5B;OH@<V-HZ6UU`%9Y8F5R
M=&4@:F%Z>6LZ`%9Y8G)A;ND@:V%T96?S<FEE.@!0;W-L8;L@<W!RX79U(&\@
M<')O8FSI;64`4&]S;&&[(%--4P!396YE9V%L`%-E;GIO<CH@`%-E<'1E;6)E
M<@!3<F)S:V\@82#(:65R;F$@:&]R80!3Z7)I;W;I(.CM<VQO`-ID86IE('IO
M('-E<G9E<F$@<_H@;F5S<'+A=FYE(&%L96)O(&YI92!S^B!D;W-T=7!NZ2X`
M061M:6YI<W1RX6-I82!S961E;NT`4&QA=&YO<[L@240@<V5D96YI82!V>7!R
MN6%L82X`4V5D96YI80!-;F^^:6YA(&AO9&[T=`!.87-T879T92!M;[YN;W-T
M:2!N82!O8FYO=F5N:64@5N&Y:&\@:&5S;&$@86L@:&\@>F%B=61N971E+@!.
M87-T879E;FEE('9Z9&EA;&5N_6-H('-E<G9E<F]V+"!K=2!K=&]R_6T@8VAC
M971E('!R:7-T=7!O=F&[('H@5N&Y:&\@<&]R=.%L=2X`5GEB97)T92!J87IY
M:RP@Z&%S;W;Z('KS;G4@82!N87-T879E;FEA(&3A='5M=2X`3F%S=&%V96YI
M92!A<&QI:^%C:64@<W#ZN;MA;F5J('!R:2"Y=&%R=&4L(&9A<F5B;F5J('-C
M:.EM>2P@:6YT97)V86QU(&]B;F]V;W9A;FEA('-T<N%N:WD@82!I;OUC:"!V
M;&%S=&YO<W3M('IO8G)A>F5N:6$N`$YA<W1A=F5N:64`4_H@9&]S='5P;ND@
M<VMR:7!T>2!N82!U<&=R861E(&YA<W1A=F5N[0!$;R#Z=F%H>2!P<FEC:.%D
M>F$@;FEE:V^U:V\@;&]K86SM="!P;VUO8V]U('!A<F%M971R83H@`%-E>6-H
M96QY`%-H;W!P:6YG`$MRX71K>2!S^FAR;@!-86KZ('-A('!R92!VY.BY:6YU
M(&QI;FEE:R!V>71V;W)INR!S:W)A=&MO=ND@:VSA=F5S>3\`6F]B<F%Z:;L`
M6F]B<F%Z:;L@=&QAZ&ED;.$@86MC:>T_`%IO8G)A>FF[(')O>F1I96QY(&UE
M9'II('!RX79E('5L;[YE;F]U(&$@;F]V;W9Y9V5N97)O=F%N;W4@:V]N9FEG
M=7+A8VEO=2X`3>$@<V$@<')I('!R:6ALX7-E;NT@>F]B<F%Z:;L@Z&%S('!O
M<VQE9&[I:&\@<')I:&SA<V5N:6$_`%IO8G)A>FF[(&UE;F\@<&]Z;N%M:V]V
MZ6AO(&)L;VMU/P!:;V)R87IINR!P;WINX6UK>2!Z('3]8VAT;R!K871E9_-R
M:>T`6F]B<F%Z:;L@;6^^;F]SNR!N82!P;VYE8VAA;FEE(&]R:6=I;N%L=0!:
M;V)R87IINR!NX7-T<F]J(&YA(';]8F5R(&9A<FEE8@!:;V)R87IINR!M96YU
M('!R92!O<&5RX6-I92!S('1A8G6U:V%M:3\`6F]B<F%Z:;L@;65N=2`E<R!N
M82"U879E:B!S=')A;F4_`%IO8G)A>FF[(&1I86SS9R!S('9L87-T;F]SNV%M
M:2!B=6YK>2!T86)UM6MY`%IO8G)A>FF[(&1I86SS9R!S('9L87-T;F]SNV%M
M:2!T86)UM6MY`%IO8G)A>FF[(&1I86SS9R!S('9L87-T;F]SNV%M:2!R:6%D
M:W4@=&%B=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@;V)R
MX7IK=0!:;V)R87IINR!N86AR86[I`%!R96CA;FMY`%+A;F\@<')E:.%N:WD`
M3F5S:_1R('!R96CA;FMY`%IRX;YK>2!V(&]K;VSM`%IM96ZY:;L`3F%J<')V
M(&UU<^UT92!Z;65NN6F[(&%L96)O('!R97-U;OJ[('-U<V5D;OT@8FQO:RAY
M*0!3:65R<F$@3&5O;F4`6F%R96=I<W1R;W9ANR!S80!0;V1P:7,`06QG;W)I
M=&UU<R!P;V1P:7-U`%-I;F=A<'5R`%9EM6MO<[L`4')E<VMOZ&F[(/ID<KYB
M=0!3;&]V96YS:V\`4VQO=FEN<VMO`%-N9;YE;FEE`%-N96AO=N$@<')E:.%N
M:V$`4VYE:&]VZ2!P<F5HX6YK>0!2X6YO('-N96AO=ND@<')E:.%N:WD`3F5S
M:_1R('-N96AO=ND@<')E:.%N:WD`2.5B:V$@<VYE:'4Z(`!-;F^^<W1V;R!V
M;V1Y(&5K=FEV86QE;G1NZ2!S;F5H=3H@`*EA;&%M^FYO=F4@;W-T<F]V>0!3
M;VWA;'-K;P!0:65S;F4@82!BX7-N90!4<FEE9&F[('!O9+5A(&MA=&5G\W)I
M90!4<FEE9&F[('!O9+5A('1E>'1U('!O>F[A;6MY`%;]8F5R('-M97)U('1R
M:65D96YI80!:9')O:F]VX2!A9')E<V$`2G6^;N$@069R:6MA`$IUOF[A($=E
M;W)G:6$@82!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$IUOF[A('!O;&]G=;5A
M`$UE9'IE<F$@;65D>FD@<W5S961N_6UI(&)U;FMA;6D`365D>F5R82!M961Z
M:2!O8G-A:&]M(&$@;VMR86IO;2!B=6YK>0!/9&1EM6]V8>@`3V1S='5P`$]D
M<W1U<"!A('9Y<&QN96YI90"I<&%N:65L<VMO`%-P86T`5FQOOF5N:64@N7!E
M8VGA;&YY8V@@>FYA:V]V`%)O>F1E;&F[(&)U;FMU`%)O>F1E;&F[('-TY7!E
M8P!2;WID96QINR!R:6%D;VL`J7!O<G1Y`%-R[2!,86YK80"I=&%N9&%R9&[I
M`%-T87(@5')E:P!0;^AI871OZ&[](')O:P"I=.%T(&%L96)O('!R;W9I;F-I
M80!3=&%V`$9O<FWA="!U;&^^96YI80!">61L:7-K;P!0<F6Y:W)T;G5TZ0!:
M;WIN86T@<F6[87IC;W8`3V1S='+A;FF[(&1O;>EN=2!Z(&%D<F5S>0"I=/UL
M(%M#4U-=`$YE`%!O9'!R:67H:6YO:R`B)7,B(&YE8F]L(&[A:F1E;OTN`%!R
M961M970`3V1O<VQANP!0;[YI861A=FMA(&YA('!R:61A;FEE("(E<R(@9&\@
M<WES=.EM=2!B;VQA(&]D;W-L86[A+B!.96WTOF5T92!S82!P<FEH;.%S:;LL
M(&O];2!N96)U9&4@5F&Y82!P;[YI861A=FMA('-C:';A;&5NX2X`1&]L;OT@
M:6YD97@`VG-P96-H`%!R:61A;FEE("(E<R(@9&\@<WES=.EM=2!B;VQO(/IS
M<&6Y;NDN`%9Y;6%Z86YI92#Z9&%J;W8@>F\@<WES=.EM=2!P<F4@<&]UONUV
M871EM6$@(B5S(B!B;VQO(/IS<&6Y;NDN`%9Y;6%Z86YI92`B)7,B(&)O;&\@
M^G-P9;ENZ2X`5GEM87IA;FEE("(E<R(@>F\@<WES=.EM=2!B;VQO(/IS<&6Y
M;NDN`$[A=G)A="!K=2!K;VYF:6=U<N%C:6D@8F]L(/IS<&6Y;OTN(%!R92!Z
M;V)R87IE;FEE('IM:65N('IN;W9U(&YAZ.UT86IT92!S='+A;FMU+@`B)7,B
M(&)O;&$@^G-P9;EN92!U;&^^96[A+@!:X6QO:&$@:V]N9FEG=7+A8VEE(&)O
M;&$@=6QOOF5NX2X`6N%L;[YN_2!K;VYF:6=U<F'H;OT@<_IB;W(@)7,@8F]L
M(/IS<&6Y;F4@=6QOOF5N_2X`06MT=6%L:7KA8VEA("(E<R(@8F]L82#Z<W!E
MN6[A+@!:X7!I<R`E<R!B;VP@^G-P9;EN_0!3=63A;@!3^FAR;@!6_6-H;V0@
M<VQN:V$`6N%P860@<VQN:V$`4VQN9>AN;P!6_6-H;V0@<VQN:V$`5OUC:&]D
M+WKA<&%D('-L;FMA`%;]8VAO9"!S;&YK83H@`%KA<&%D('-L;FMA`%KA<&%D
M('-L;FMA.B``2&]R;OT@:6YD97@`4&]D<&]R80!3=7)I;F%M`%!R:65Z=FES
M:V\`4W9A;&)A<F0@82!*86X@36%Y96X`4W9A>FEJ<VMO`*EVZ61S:V\`J79A
M:NAI87)S:V\`6N%Z;F%M>2!O('-Y;F-H<F]N:7KA8VEI('9Y;6%Z86[I`%-Y
M;F--3`!3>6YT86MT:6-KX2!C:'EB82!V('!O9&UI96YK86-H(&BU861A;FEA
M`%/]<FEA`$+Z<FMA`$+Z<FMA(&$@=F5T97)N;P!"^G)K>0!2X6YO(&+Z<FMY
M`%135B!S^F)O<@!486)UM6MA`%9L87-T;F]S=&D@=&%B=;5K>0!6;&%S=&YO
M<W1I('1A8G6U:WD`5&%I=V%N`%1A:7=A;BP@<')O=FEN8VEA(,CM;GD`5&%D
MOFEK:7-T86X`5&%N>N%N:6$`0VEEM3H`VFQO:'D`5&5L96;S;FYE(.CM<VQO
M`%1E<&QO=&$@>F$@<&]S;&5D;OH@:&]D:6YU.B``5&5P;&]T80!497!L;W1A
M.B``5&5P;&]T83QB<B`O/B@E<TUA>"5S+R5S36EN)7,I("9D96<[)7,`J6%B
M;/-N82`B)7,B(&YE8F]L82!NX6ID96[A+@!3<'+A=F$@N6%B;/-N`%1E>'0`
M26)A('1E>'0`6F%R;W9N86YI92!T97AT=0!497AT(&AO<F4`J70`5&AA:G-K
M;P!2;WJY[7)E;FEE($944"!N:64@:F4@9&]S='5P;NDN`$EN=&5G<N%C:6$@
M2&]R9&4O2V]L86(@;F5P;V1P;W)U:F4@(B5S(@!)35-0('KA>FYA;2!S82!N
M97!O9&%R:6QO('5L;[YINRX`5')I961A($UA:6YT96YA;F-E.CH@<V$@;F5N
M8>CM=&%L82#Z<W!EN6YE`$]K;F\@<R!N87-T879E;FEA;6D@<V$@>F%T=F]R
M:6QO+B!+;VYI96,N`$%D;6EN:7-T<N%T;W(@;75S[2!N86MO;F9I9W5R;W9A
MNR!P97)M86YE;G1N_2!B86-K96YD('!R92!0<N%V82P@86L@8VAC971E('!O
M=;[M=F&[(%!RX79A+@!)8F$@<W!O9&[A('-T<F%N80!)1"#H[7-L;R!K;VYT
M86MT=2!N96)O;&\@N7!E8VEF:6MO=F%NZ2P@8F]L;R!P;VYE8VAA;ND@<'+A
M>F1N92!A;&5B;R!N96)O;&\@;N%J9&5NZ2!V(&1A=&%BX7IE+@!+;VYT86MT
M(&)O;"#Z<W!EN6YE('9L;[YE;OT@9&\@5N&Y:&\@861R97/A<F$N`$YA(&]V
M97)E;FEE('!O9'#M<V%N96H@<W!RX79Y(&IE('!OOF%D;W9A;OT@;V1D96QE
M;OT@8FQO:R!S(%!'4"!P;V1P:7-O;2X`240@>F]Z;F%M=2!P<NUJ96UC;W8@
M8G7O(&YE8F]L;R"Y<&5C:69I:V]V86[I+"!A;&5B;R!B;VQO('!O;F5C:&%N
MZ2!P<N%Z9&YE(&%L96)O(&YE8F]L;R!NX6ID96[I('8@9&%T86+A>F4N`$YE
M8F]L('5RZ&5N_2!Z;WIN86T@<'+M:F5M8V]V+@"I:69R;W9A;FEE('9YOF%D
M=6IE(&)E>G!EZ&[I('!R:7!O:F5N:64@*&AT='!S*2X`4_IB;W(@)7,@8GD@
M;6%L(&]B<V%H;W9ANR!N87-T879E;FEE("5S+@!3^F)O<B`E<R!B>2!M86P@
M;V)S86AO=F&[(&YI96MT;W+I(&YA<W1A=F5N:6$@)7,N`%ID<F]J;W;](&$@
M8VEEM6]V_2!S^F)O<B!M=7-I82!B>;L@;V1L:;ENZ2X`4_IB;W(@;F5O8G-A
M:&]V86P@OFEA9&YE(/ID86IE+@!.87-L961U:OH@:&QA=FGH:WD@=&5J=&\@
M<W!RX79Y('9O(&9O<FWA=&4@;65S<V%G92]R9F,X,C(N`$-E;&]O8G)A>F]V
M:V]V_2!R9;YI;2!S</1S;V)U:F4@<')O8FSI;7D@=B!);G1E<FYE="!%>'!L
M;W)E<FD@:W;T;&D@8VAY8N%M('!R96AL:6%D8>AA+"!K=&]RZ2!S82!NX6T@
M;F5P;V1A<FEL;R!O8NUSNRX@3?2^=2!S82!P<F5J879INR!N97-P<N%V;GEM
M('IO8G)A>F5N[6TL(&-H_6)A:OIC:6UI(&9U;FMC:6%M:2!E9&ET;W)A(&$O
M86QE8F\@;N%H;V1N_6UI('#A9&UI('!R96AL:6%D8>AA+B!!:R!J92!6X;D@
M<WES=.EM(%=I;F1O=W,@.7@L(&IE('9EM6UI('!R879D97!O9&]B;NDL(+YE
M('-A('IO8G)A>NT@8VAY8F$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@
M82!B=61E=&4@;75S:66[(')EN71A<G1O=F&[('!OZ.UT8>@N7&Y<;E9A<F]V
M86QI('-M92!6X7,N(%-T;&'H=&4@<')O<^UM($]+(&%K(&YA;WIA:B!C:&-E
M=&4@<&]UOFF[(&5D:71O<B!V(&-E;&]O8G)A>F]V:V]V;VT@<F6^:6UE+@!)
M9&5N=&ET82`B)7,B(&)O;&$@=GEM87IA;N$N`$EB82"U87;A('-T<F%N80!4
M<FEE9&$@0W)Y<'1?<&=P.CH@<&]T<F5B=6IE('!O>FYANR!U;6EE<W1N96YI
M92!P<F]G<F%M=2!';G501RX`4W!RX79A(&]D;W-L86[A("5S('!R92`E<R!S
M('!R961M971O;2`B)7,B(&)O;&$@>F]B<F%Z96[A+@I.965X:7-T=6IE(':Y
M86L@>N%R=6MA+""^92!S<'+A=F$@8F]L82!P<F7H[71A;N$@86QE8F\@<&]C
M:&]P96[A+@!-96YO+"!K=&]RZ2!S82!MX2!P;W6^:;L@<')I(&QI;FMO=F%N
M[2!N82!S='+A;FMU(&YA('#M<V%N:64@<W!RX78@`%!O>F[A;6MA(&)O;&$@
M=GEM87IA;N$N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@<&]Z;N%M:V]V_2!B
M;&]K("(E<R(Z("5S`%!O>F[A;6MO=OT@8FQO:R`B)7,B(&)O;"!V>71V;W)E
M;OTN`%!O>F[A;6MO=OT@8FQO:R`B)7,B(&)O;"!V>6UA>F%N_2X`4&]Z;N%M
M:V]V_2!B;&]K("(E<R(@8F]L('5L;[YE;OTN`%!OZ&5T('!O;.T@;75S[2!B
M>;L@Z.US;&\N`%1R:65D82!(;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE
M(&UO9'5L(&]P96YS<VPN`$YA<W1A=F5N:64@(B5S(B!S82!N97!O9&%R:6QO
M('5L;[YINRP@<')E=&^^92!J96AO(/ID86IE('!R96MR8>AU:OH@;6%X:6WA
M;&YU('!O=F]L96[Z('9EM6MO<[L`4')O9W)A;2!P;W6^[79A;OT@;F$@>F]B
M<F%Z96YI92!T;VAT;R#Z9&%J;W;I:&\@='EP=2`H)7,I(&YE8F]L(&[A:F1E
M;OTN`%IN86L@8VETX6-I92!M=7/M(&)YNR!J961E;B!Z;F%K+@!)8F$@<')A
M=N$@82"U87;A('-T<F%N80!)8F$@<')A=N$@<W1R86YA`$]D9&6U;W9AZ"!M
M=7/M(&)YNR!J961E;B!Z;F%K+@!397)V97(@(B5S(B!B;VP@=GEM87IA;OTN
M`%-E<G9E<B`B)7,B(&)O;"!U;&^^96[]+@"N:6%D;W.[(&\@<')I:&SA<V5N
M:64@)7,@8F]L82!V>6UA>F%NX2X`J7!E8VEF:6MO=F%N_2!R:6%D;VL@;F5E
M>&ES='5J92X`1&_H87-N_2!S^F)O<B`B)7,B(&YE97AI<W1U:F4N`%IA9&%N
M_2!T97AT(&YI92!J92!R;W9N86O](&%K;R!T97AT(&YA(&]B<F%Z;W9K92X`
M26)A(&AO<F[A(&$@<W!O9&[A('-T<F%N80!)8F$@:&]R;N$@<W1R86YA`$YA
M:')A;ND@^F1A:F4@<V$@;V0@<')E9&-HX61Z86KZ8V5H;R!K<F]K=2!S=')A
M=&EL:2X`3F%H<F%N_2!S^F)O<B!S82!N97!O9&%R:6QO('5L;[YINRX`0FQO
M:R!W96%T:&5R+F-O;2!N:64@:F4@9&]S='5P;OTN`%!R:67H:6YO:R!TZ6T@
M(B5S(B!N96)O;"!NX6ID96[]+@"N:6%D;F4@;F%S=&%V96YI82!N:64@<_H@
M9&]S='5P;NDN`*YI861N92!A;'1E<FYA=.UV;F4@Z&%S=&D@;F5M;[YN;R!Z
M;V)R87IINR!V('1E;&4@<W!RX79Y+@!6('1O;71O('!O;&D@:F4@<'+M;&FY
M('9EM6$@>FYA:V]V+B!:861A;&D@<W1E("5S('IN86MO=CL@;75S[71E('IA
M9&&[(&UE;F5J(&%K;R`E<RX`3F%S=&%L82!C:'EB82!P<FD@<')I9.%V86[M
M("(E<R(@9&\@<WES=.EM=3H@)7,`3F%S=&%L82!C:'EB82!P<FD@;V1S=')A
M\F]V86[M('!O=;[M=F%T9;5S:_UC:"#Z9&%J;W8@(B5S(B!Z;R!S>7-TZ6UU
M.B``3F%S=&%L82!C:'EB82!P<FD@;V1S=')A\F]V86[M("(E<R(@>F\@<WES
M=.EM=3H@`$YA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2`B)7,B.B`E
M<P!6>7-K>71O;"!S82!P<F]B;.EM(',@;F%H<N%V86[M;2!S^F)O<G4Z(*YI
M861E;B`E<R!N96)O;"!N86AR86[]+@!6>7-K>71O;"!S82!P<F]B;.EM(',@
M;F%H<N%V86[M;2!S^F)O<G4Z("5S(&)O;"!VY.BY[2!A:V\@;F%J=N3HN>T@
M<&]V;VQE;OT@;&EM:70@*"5D(&)A:G1O=BDN`%9Y<VMY=&]L('-A('!R;V)L
MZ6T@<R!U:VQA9&%N[6T@<_IB;W)U.B`E<R!B;VP@;F%H<F%N_2!L96X@Z&EA
M<W1OZ&YE+@!.87-T86QA(&-H>6)A('!R:2!Z;V)R87IO=F%N[2!T96IT;R#H
M87-T:2!S<'+A=GD`3F%S=&%L82!C:'EB82!P<FD@:6UP;W)T92#Z9&%J;W8@
M;R!K;VYT86MT92X`3F%S=&%L82!C:'EB82!P<FD@:6UP;W)T92#Z9&%J;W8Z
M("5S`$YA<W1A;&$@8VAY8F$@<')I(&EM<&]R=&4@^F1A:F]V(&E#86QE;F1A
M<BX`3F%S=&%L82!C:'EB82!P<FD@:6UP;W)T92#Z9&%J;W8@=DYO=&4N`$YA
M<W1A;&$@8VAY8F$@=B!K;VYF:6=U<F'H;F]M(&9O<FUU;.%R:2X@4')A=F1E
M<&]D;V)N92!S=&4@;F5V>7!L;FEL:2!P;[YA9&]V86[I('!O;&4N`$YA<W1A
M;&$@8VAY8F$@<')I('9Y:V]NX79A;NT@=7+H96YE:B!F=6YK8VEE(&%D<F5S
MX7)A+B!0<F]S[6T@<VOZ<W1E('1O(&YE<VOT<BX`3F%S=&%L82!C:'EB82!P
M<FD@;V1S=')A\F]V86[M('!O>F[A;6MY.B`E<P!.87-T86QA(&-H>6)A('!R
M:2!U:VQA9&%N[2!P;WINX6UK>3H@)7,`3F%S=&%L82!C:'EB82!P<FD@86MT
M=6%L:7KA8VEI(&1E=&%I;&]V(&MO;G1A:W1U+B!0<F]S[6T@<VOZ<W1E('1O
M(&YE<VOT<BX`3F%S=&%L82!C:'EB82!P<FD@86MT=6%L:7KA8VEI('IO>FYA
M;74@<'+M:F5M8V]V+B!0<F]S[6T@<VOZ<W1E('1O('IN;W9U+@!.87-T86QA
M(&-H>6)A('!R:2!P<F5Z97)A;NT@=&]H=&\@<&]Z;N%M:V]VZ6AO(&)L;VMU
M.B`E<RX`3FEE('/Z(+YI861N92!P;WINX6UK>2!P<F4@97AP;W)T+@!496YT
M;R!)34%0('-E<G9E<B!N97!O9'!O<G5J92!Z9&EEM6%N:64@<')I9>AI;FMO
M=BX`5&]T;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@87)C:.UV(')A
M<BX`5&]T;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@87)C:.UV('II
M<"X`5&]T;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;ND@Z.US;&\@:V%R
M='DN`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L86YI92!S<'+A=B!C
M97H@8G+A;G4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!P
M;VUO8V]U($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L
M86YI92!S<'+A=B!C97H@8G+A;G4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@
M<&]M;V-O=2!(5%10($%020!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE
M;&%N:64@<W!RX78@8V5Z(&)RX6YU('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E
M;6%I;"YC;VTI('!O;6]C;W4@2%144"!!4$D`5&5N=&\@;W9LX61AZ"!U;6^^
M\G5J92!P;W-I96QANR!S<'+A=GD@8V5Z(%--5%`@8V5Z(&)RX6YU(%9O9&%F
M;VYE($ET86QY("AI8F$@;F$@Z.US;&$@5F]D869O;F4I+B!6>;YA9'5J92!E
M+6UA:6QO=OT@^NAE="!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4;W1O('!O;&4@:F4@<&]V:6YNZ2X`5&]T;R!P;VQE(&WTOF4@;V)S
M86AO=F&[(&EB82#H[7-L82X`5&]T;R!P;VQE(&WTOF4@;V)S86AO=F&[(&EB
M82#H[7-L82!A(&1V;VIB;V1K=2X`5&]T;R!P;VQE(&WTOF4@;V)S86AO=F&[
M(&EB82!O<VUIZ&MO=ND@:&]D;F]T>2X`5&]T;R!P;VQE(&UU<^T@8GF[('IO
M>FYA;2#H[7-E;"!O9&1E;&5N_6-H(.AI87)K;W4@86QE8F\@;65D>F5R;W4`
M5&]T;R!P;VQE(&UU<^T@8GF[('!L871NZ2#H[7-L;RX`5&]T;R!P;VQE(&UU
M<^T@;V)S86AO=F&[(&OS9"!F87)B>2!V(+EE<W1NX7-T:V]V;VT@9F]R;>%T
M92!21T(L(&YA<'+M:VQA9"`G(S$R,S1A9B<N`%1E;G1O(&9O<FWA="!S^F)O
M<G4@;FEE(&IE('!O9'!O<F]V86[]+@!496YT;R!F;W)M=6SA<B!UOB!B;VP@
M<W!R86-O=F%N_2X`5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE:W0@2V]L86(@
M1W)O=7!W87)E+B!0<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE:W1U('!O=')E
M8G5J971E(&4M;6%I;&]VZ6AO(&ML:65N=&$L(&MT;W+](')O>G5M:64@9F]R
M;>%T=2!+;VQA8B!'<F]U<'=A<F4N(%!R92!Z;WIN86T@=&%K_6-H=&\@:VQI
M96YT;W8@;F%VN73M=G1E('!R;W/M;2`E<P!4X71O('-P<N%V82!B;VQA(&YA
M<.US86[A('8@:6YE:B!A:V\@5F%M:2!P;W6^[79A;F5J('IN86MO=F5J('-A
M9&4@*"5S*2X`5&]T;R#H[7-L;R!M=7/M(&)YNR!N86IM96YE:B`Q+@!496YT
M;R!S97)V97(@;F5D;VOAOF4@9&5K;VUP<FEM;W9ANR!S^F)O<GD@>FEP(&$@
M9WII<"X`4WES=.EM(&IE(&UO;65N=.%L;F4@9&5A:W1I=F]V86[]+@!4X71O
M(&AO9&YO=&$@;75S[2!B>;L@Z.US96QNX2X`5&]T;R!O:VYO(&UU<^T@8GF[
M('IA=F]L86[I('H@;VMN82!.87-T879E;NT`2')M96YI90!4:6-K971S`,AA
M<P!4:6UE(%1R86-K:6YG`$9O<FWA="#H87-U`%;]8F5R(.AA<W4`5&EM;W(M
M3&5S=&4`5&ET=6QO:P!.861P:7,@*&)U8FQI;F]V_2!V_7!I<RDZ`%!R90!0
M<F4@=OUB97(@=FEA8V5R_6-H('!O;&^^:65K(&1ROG1E('!OZ&%S(&ML:6MA
M;FEA(&MLX79E<W4@0V]N=')O;"`H4$,I(&%L96)O($-O;6UA;F0@*$UA8RDN
M`$1N97,`4')E<&[ZNR!Z;V)R87IE;FEE('ID<F]J;W;I:&\@:_-D=2!(5$U,
M`%1O9V\`5&]K96QA=0!:86IT<F$`5&]N9V$`5G)C:`!6<F-H;OT@<N%M96,@
M*%]T;W`I`%!R96ML861Y`%1R:6YI9&%D(&$@5&]B86=O`%!R879D82!A;&5B
M;R!N97!R879D80!5=`!4=6YI<VMO`%1U<F5C:V\`5'5R:VUE;FES=&%N`%1U
M<FMS(&$@0V%I8V]S`%1U=F%L=0!:861A:G1E(%9AN74@=F^U8G4Z(`!5+E8N
M(&EN9&5X.B``55),`%523"!6X;EH;R!S:W)I<'1U('!R92!S<'+A=G4@;R!D
M;W)UZ&5N[0!54DPZ`%5G86YD80!5:W)A:FEN80!.97!O9&%R:6QO('-A('5S
M:W5T;^AN:;L@<'+M<W1U<"!K(%9&4R!A9')E<^%R=2X`3F5P;V1A<FEL;R!S
M82!P<FED8;L@[V%LN6EE(&EN9F]R;>%C:64@;R!P;W6^[79A=&6U;W9I('!R
M:2!R96=I<W1RX6-I:2X`3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@<')E
M(%9&4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IM96YINR!P<N%V;R!P
M<F4@5D93('/Z8F]R("5S+R5S+@!.97!O9&%R:6QO('-A('IM96YINR!N82`E
M<RX`3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S^F)O<G4@
M(B5S(BX`3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S^F)O
M<G4@(B5S+R5S(BX`3F5P;V1A<FEL;R!S82!S<&]J:;L@<R!344P@<V5R=F5R
M;VTN`$YE<&]D87)I;&\@<V$@<W!O:FF[('!O;6]C;W4@4U-,+@!.97!O9&%R
M:6QO('-A('-K;W#M<F]V8;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A('9Y
M='9O<FF[(%9&4R!A9')E<^%R("(E<R(N`$YE<&]D87)I;&\@<V$@=GET=F]R
M:;L@5D93(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93('/Z
M8F]R+@!.97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!P<FEEZ&EN;VL@(B5S
M(BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!P<N%Z9&YY(%9&4R!S^F)O<BX`
M3F5P;V1A<FEL;R!S82!D96MO;7!R:6UO=F&[(/ID86IE+@!.97!O9&%R:6QO
M('-A('9Y;6%Z8;L@(B5S(BP@861R97/A<B!N:64@:F4@<'+A>F1N>2X`3F5P
M;V1A<FEL;R!S82!V>6UA>F&[("(E<R(Z("5S`$YE<&]D87)I;&\@<V$@=GEM
M87IANR`B)7,B.B`E<RX`3F5P;V1A<FEL;R!S82!V>6UA>F&[("5S+"!A9')E
M<^%R(&YI92!J92!P<N%Z9&YY`$YE<&]D87)I;&\@<V$@<F5K=7)Z[79N92!V
M>6UA>F&[(%9&4R!A9')E<^%R+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93
M(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@=GEM87IANR!61E,@861R97/A<CH@
M)7,N`$YE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<_IB;W(@(B5S(BX`3F5P
M;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S82!V
M>6UA>F&[(%9&4R!P<FEEZ&EN;VL@(B5S(BX`3F5P;V1A<FEL;R!S82!R96MU
M<GKM=FYE('9Y;6%Z8;L@5D93.B`E<RX`3F5P;V1A<FEL;R!S82!U<NAINR!A
M:W1UX6QN>2!A9')E<^%R+@!.97!O9&%R:6QO('-A('II<W1INR!P;V1R;V)N
M;W-T:2!O(&-E<G1I9FEKX71E+@!.96UOOF[I(&YA:')ANR!D969I;NUC:74@
M)7,N`$YE<&]D87)I;&\@<V$@<')E<W5N^KL@5D93('/Z8F]R+@!.97!O9&%R
M:6QO('-A(&]T=F]R:;L@5D93('/Z8F]R("(E<R(N`$YE<&]D87)I;&\@<V$@
M;W1V;W)INR!61E,@<_IB;W(@;F$@>N%P:7,N`$YE<&]D87)I;&\@<V$@;W1V
M;W)INR!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@;W1V;W)INR!K;VUP<FEM
M;W9A;OT@87)C:.UV+@!.97!O9&%R:6QO('-A('!R9>CM=&&[(%9&4R!S^F)O
M<B`H9G5N:V-I82!F:6QE<VEZ92@I('IL>6AA;&$I+@!.97!O9&%R:6QO('-A
M('!R9>CM=&&[(%9&4R!S^F)O<B`H9G5N:V-I82!G971&:6QE4VEZ92@I('IL
M>6AA;&$I+@!.97!O9&%R:6QO('-A('!R9>CM=&&[('/Z8F]R.@!.97!O9&%R
M:6QO('-A(.CM=&&[(&%D<F5SX7(@=F9S<F]O="X`3F5P;V1A<FEL;R!S82!P
M<F5M96YO=F&[("5S(&YA("5S.B!C:66U;W;]('!R:67H:6YO:R!UOB!E>&ES
M='5J90!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93(&%D<F5SX7(N`$YE
M<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@861R97/A<CH@)7,N`$YE<&]D
M87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(@(B5S(BX`3F5P;V1A<FEL
M;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<B`E<R\E<RX`3F5P;V1A<FEL;R!S
M82!P<F5M96YO=F&[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S82!S<'5S=&F[
M("=M:VES;V9S)RX`3F5P;V1A<FEL;R!S82!P<F5L;[YINR!T96YT;R!D;VMU
M;65N="!7;W)D`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!61E,@<_IB;W(@(B5S
M(BX`3F5P;V1A<FEL;R!S82!Z87#M<V&[(%9&4R!S^F)O<B`H9G5N:V-I82!C
M;W!Y*"D@>FQY:&%L82DN`$YE<&]D87)I;&\@<V$@>F%P[7-ANR#Z9&%J92!6
M1E,@<_IB;W)U+@!.97!O9&%R:6QO('-A('IA<.US8;L@5D93('/Z8F]R+"!K
M=O-T82!J92!P<F5K<F_H96[A+@!0;V3H:6%R:VYU=.D`6G)UN6F[('IM96YY
M`%IR=;EINR!Z;65N>0!:<G6Y[2!P;W-L961N^B!A:V-I=0!.96_H86OA=F%N
MX2!O9'!O=F7O(&]D('-E<G9E<F$@<&_H87,@<W!O:F5N:6$Z(`!.96_H86OA
M=F%NX2!O9'!O=F7O(&]D('-E<G9E<F$@;F$Z(`!.96YA<W1A=F5NX0!3<&]J
M96[I(&%R86)S:^D@96UI<N%T>0!69;5KX2!"<FETX6YI80!3<&]J96[I(+ET
MX71Y($%M97)I8VOI`$IE9&YO=&MY`$YE>F[A;64`3F5Z;N%M92!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+@!.97INX6UE(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN`$)O;&$@>F%D86[A(&YE<&QA=&[A(&QO:V%L:71A+@!.
M97INX6UE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!H97-L;RX`3V1S='+A
M;FF[(&QI;FMU('H@86MT=>%L;F5H;R!E;&5M96YT=0!.97!O;65N;W9A;N$`
M3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M86KZ('H@8F5Z<&7H;F]S=&[]
M8V@@9/1V;V1O=B!P<NUS='5P(&L@=F^U8N%M(%9Y<W1R:6AN^KLO2V]P[7)O
M=F&[+U9L;[YINRX@2VQI:VYI=&4@;F$@3TL@82!Z;V)R87KM('-A('1E8VAN
M:6-KX2!I;F9O<FWA8VEA(&YA('-T<N%N:V4@;6]Z:6QL82YO<F<L(&MT;W+A
M(%;A<R!I;F9O<FUU:F4L(&%K;R!U;6^^;FF[('-K<FEP='4@<'+M<W1U<"!K
M('-C:'+A;FME+@!/9'-T<N%N:;L@9F%R8G4`3F5P;V1P;W)O=F%N_2!T>7`@
M;V)S86AU("A#;VYT96YT+51Y<&4I.B`E<P!.97!O9'!O<F]V86[I(')O>KGM
M<F5N:64`06MT=6%L:7KA8VEA`$%K='5A;&EZ;W9ANR`E<P!!:W1U86QI>F]V
M8;L@<&]UONUV871EM6$`06MT=6%L:7KA8VEA("(E<R(@8F]L82#Z<W!EN6[A
M+@!3:W)I<'0@;F$@=7!G<F%D92!B;VP@=GEM87IA;OTN`$YA:')ANP!6N65T
M:WD@<_IB;W)Y(',@:V]N9FEG=7+A8VEO=2!B;VQI(&YA:')A;ND@;F$@<V5R
M=F5R+@!69;5KZ2!L871I;G-KZ2!P[7-M96[A`%9EM6OI('+M;7-K92#H[7-L
M:6-E`%5R=6=U87D`4&]UOFF[(&%K='7A;&YE.B`E<P!0;W6^:;L@4U-,`%!O
M=;YI=&4@=B!P<NUP861E+""^92!J92!M96YO+VAE<VQO(&]D;&FY;ND@<')E
M($E-4U`@<V5R=F5R+@!0;W6^[79A=&6U`%!O=;[M=F%T9;4@)7,@;FEE(&IE
M(&%U=&]R:7IO=F%N_2!N82`E<RX`4W!RX79A('!O=;[M=F%T9;5O=@!0;W6^
M[79A=&6U<VOI(&YA<W1A=F5N:6$`4F5G:7-T<N%C:6$@<&]UONUV871EM6$`
M4F5G:7-T<N%C:6$@<&]UONUV871EM6]V(&)O;&$@<')E('1E;G1O('-Y<W3I
M;2!Z86OA>F%NX2X`4&]UONUV871EM7-K_2#ZZ&5T(&YE8F]L(&[A:F1E;OT`
M4&]UONUV871EM7-KZ2!M96YO`%!O=;[M=F%T9;5S:^D@;65N;R`B)7,B('6^
M(&5X:7-T=6IE+@!0;W6^[79A=&6U<VOI(&UE;F\Z`%!O=;[M=F%T9;5S:^D@
M;65N;SH@`%!O=;[M=F%T96QI82!S>7-TZ6UU.@!5>F)E:VES=&%N`%9&4R!A
M9')E<^%R(&YE97AI<W1U:F4N`$1O=F]L96YK80!0;&%T;ND@=6UI97-T;F5N
M:6$@>F%HX/)A:OHZ(`!0;&%T;F]SNP!0;&%T;F]SNR!V(&UI;OIT86-H(&]D
M=&5R87HN`$AO9&YO=&$@<')E:W)OZ&EL82!M87AI;>%L;G4@9.6^:W4@)7,N
M`$AO9&YO='D`2&]D;F]T>2P@>B!K=&]R_6-H('-I(&WTOF5T92!V>6)R8;L`
M5F%N=6%T=0!0<F5M96YNX0!696YE>G5E;&$`3W9E<F5N:64@>FQY:&%L;R`M
M('3A=&\@<W!RX79A(&UO:&QA(&)YNR!S9F%LN6]V86[A+@!697)Z:6$`36%N
M8;YM96YT('9E<GII[0!697)T:6OA;&YE('IA<F]V;F%N:64`5F5R=&EKX6QN
M92!V>7!L;F5N:64`5F5R=&EKX6QN93H`5F6U;6D@=GES;VOA`%9I971N86T`
M6F]B<F%Z:;L@)7,`6F]B<F%Z:;L@97AT97)N^B!W=W<@<W1RX6YK=0!:;V)R
M87IINR!A:V\@)7,`0G)I='-KZ2!086YE;G-KZ2!O<W1R;W9Y`$%M97)I8VOI
M(%!A;F5N<VOI(&]S=')O=GD`5FED:71EM6YO<[L`5FED:71EM6YO<[LZ(`!6
M;V1A9F]N92!)=&%L>2!C97H@4TU44`!605)/5D%.244`55!/6D]23D5.244A
M(2$@3T135%+!TE1%(%-+4DE05"!:("5S(%)5R$Y%+@!724X@8V5Z($A45%``
M5V%L;&ES(&$@1G5T=6YA`%9A<F]V86YI90!3=`!0<F5D<&]V9>\@<&_H87-I
M80#:9&%J92!O('!OZ&%S[2!P;W-K>71U:F4`5V5A=&AE<BYC;VT`5V5B`%=7
M5R!S='+A;FMA`%3]OF1E;FYE`%9I=&%J=&4`5NUT82!6X7,@)7,`5FET86IT
M92P@)7,`6N%P861NX2!386AA<F$`2W1O<OH@87!L:6OA8VEU(&WA("5S('IO
M8G)A>FF[('!O('!R:6ALX7-E;NT_`$%K_2!J92!Z;F%K('!R92!O9&1EM6]V
M8>@_`$%K_2!J92!Z;F%K('!R92#Z=F]D>F]V:W4_`$UA<&$@075S='+A;&EE
M('!R92!S;'6^8G4@5VAE<F5I<P!$;R!K=&]RZ6AO('!O>F[A;6MO=NEH;R!B
M;&]K=2!S82!M86KZ('!R:61ANR!P;WINX6UK>3\`2W1O<ND@9N%Z>0!+=&]R
MZ2!ZX7-U=F[I(&UO9'5L>2!P;W9O;&F[('!R92!R;WJY[7)E;OT@=&5X=&]V
M_2!E9&ET;W(N`*GM<FMA`*GM<FMA('8@:F5D;F]T:^%C:"!#4U,`J>UR:V$@
M;65N=2`E<R!VM6%V;R`H<')E:F%V[2!S82!P<FD@[V%LN6]M('!R:6ALX7-E
M;NTI.@"I[7)K82!T86)UM6MY`$IE9&YO=&MA(+GM<FMY`*GM<FMA.@!7:6MI
M`%9I971O<@!2X6YO('9I971O<@!2_6-H;&]SNR!V971R82!V('5Z;&]C:`!6
M:65T;W(Z`%9I971O<CH@`$WZ9')O<[L`5VES:&QI<W0`4'+A8V$`061R97-A
M(&1O('!RX6-E`%1E;&5F\VX@9&\@<'+A8V4`3F5S<'+A=FYY('!OZ&5T('!O
M;.T@;F$@<FEA9&MU("5D+B!/Z&%KX79A('-A("5D+"!N8;EL;R!S82`E9"X`
M3F5S<'+A=FYY('!OZ&5T('!O;.TN($_H86OA=F$@<V$@)60L(&YAN6QO('-A
M("5D+@!:;/T@;V9F<V5T("5D('!R:2#H[71A;NT@5D93('/Z8F]R=2X`6"U2
M968`6N%K;&%D;ND@;V)M961Z96YI82!8-3`Y=C,`4&]UOFET:64@<F]ZN>UR
M96[I:&\@:[7ZZ&$@6#4P.78S`$%L=&5R;F%T[79N92!M96YO('-U8FIE:W1U
M(%@U,#EV,P!)9&5N=&EF:6OA=&]R(&NU^NAA('-U8FIE:W1U(%@U,#EV,P!8
M-3`Y=C,@<F]ZN>UR96YI80!960!965E9`%EA:&]O(2!M87``4F_H;F4`2F5M
M96X`06YO`%/Z:&QA<^UM+@!3=&4@=B!415A43U9/32!21:Y)344N(%!O=;YI
M=&4@=&QAZ&ED;&\@6SP^72!N82!P<F5P;G5T:64@;F%S<.2[(&1O(%=94TE7
M64<N`$YE;?2^971E('9Y='9O<FF[('9I86,@86MO("5D(&)L;VMO=BX`3F5M
MX71E(&]P<N%V;F5N:64@=GET=F]R:;L@=FEA8R!A:V\@)60@<&]Z;N%M;VLN
M`$YI92!S=&4@875T96YT:69I:V]V86[]+@!6;R!68;EO;2!P;&YO;2!M96YE
M(&YE;?2^971E('!O=;YINR!Z;F%K("=<)RX`3F5Z861A;&D@<W1E('!L871N
M^B!E+6UA:6QO=OH@861R97-U+@!.975RZ&EL:2!S=&4@=GJ[86@@;65D>FD@
MOFEA9&YY;6D@<&]L:6%M:2!Z(&EM<&]R=&]V86[I:&\@<_IB;W)U(&$@>F]D
M<&]V961A:OIC:6UI('!OM6%M:2!V("5S+@!.96WA=&4@<'+A=F\@;F$@>F]B
M<F%Z96YI92!P;WINX6UK;W;I:&\@8FQO:W4@)7,N`$)O;&D@<W1E(&]D:&SA
M<V5N_2X`375S[71E('IA9&&[('!L871NZ2#H[7-L;R!M;V)I;&[I:&\@=&5L
M96;S;G4L(&MT;W+I(&]B<V%H=6IE(&EB82#H[7-L82!S('9O;&ET9;5N_6T@
M<')E9FEX;VT@)RLG('!R92!M961Z:6[A<F]D;OT@9F]R;>%T+@!-=7/M=&4@
M>F%D8;L@<&QA=&[Z(&AO9&YO='4N`$%B>2!S=&4@;6]H;&D@<&]UONUV8;L@
M4F5G:7-T<N%C:64L(&UU<^UT92!N86IS:_1R(&YA:V]N9FEG=7)O=F&[($1A
M=&%4<F5E(&)A8VME;F0N`$UU<^UT92!N86MO;F9I9W5R;W9ANR!61E,@8F%C
M:V5N9"X`375S[71E('!O<.US8;L@<')O8FSI;2!P<F5D=/UM+"!A:V\@;V1O
MN6QE=&4@<W!RX79U(&\@<')O8FSI;64N`$UU<^UT92!Z861ANR!54DP@861R
M97-U+"!N82!K=&]R^B!TX71O(&QI;FMA('5K87IU:F4`375S[71E(&]Z;F'H
M:;L@<&]Z;N%M:V]V_2!B;&]K+"!K=&]R_2!MX2!B>;L@=GEM87IA;OTN`$UU
M<^UT92!V>6)R8;L@<V5R=F5R+"!K=&]R_2!MX2!B>;L@=GEM87IA;OTN`$UU
M<^UT92!U<NAINR!M96YO('!O=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!V
M>6UA>F&[+@!-=7/M=&4@=7+H:;L@;65N;R!P;W6^[79A=&6U82P@:W1O<NEH
M;R!C:&-E=&4@=GEM87IANRX`375S[71E('5RZ&F[(&UE;F\@<&]UONUV871E
MM6$L(&MT;W+I:&\@8VAC971E('!R:61ANRX`375S[71E('5RZ&F[('!O=;[M
M=F%T9;5A+"!K=&]R_2!S82!MX2!A:W1U86QI>F]V8;LN`$UU<^UT92!U<NAI
MNR!A:V-I=2P@:W1O<N$@<V$@;>$@=GEK;VYANRX`375S[71E('IA9&&[(&UE
M;F\@;F]V96H@:V%T96?S<FEE+@!-=7/M=&4@>F%D8;L@=&%L:6%N<VME('1E
M;&5F\VYN92#H[7-L;P!0;&%T;F]SNR!68;EE:B!R96SA8VEE('!R92!A<&QI
M:^%C:74@)7,@=GEP<KEA;&$N(%!R;W/M;2!P<FEH;.%S=&4@<V$@>FYO=G4N
M`%9AN6$@16UA:6QO=N$@861R97-A`%9AN6$@16UA:6QO=N$@861R97-A('!O
M=;YI=.$@<')E(&]D8VCA9'IA:OIC=2!P;[ET=3H`5F&Y92!I;F9O<FWA8VEE
M`%9AN6$@:6YT97)N971O=N$@861R97-A('-A('IM96YI;&$@;V0@>F'H:6%T
M:W4@5F&Y96H@<F5LX6-I92`E<RX@4')E(%9AN74@8F5Z<&7H;F]SNR!S82!M
M=7/M=&4@>FYO=G4@<')I:&SA<VF[+@!68;EE(&UE;F\`5N&Y(&%U=&5N=&EF
M:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('!R:63A=F%N:64@<&]UONUV871E
MM6]V+B!!:R!S:2"^96SA=&4@<&]UOFF[($AO<F1E(&YA('-P<N%V=2!P;W6^
M[79A=&6U<VO]8V@@^NAT;W8L(&UU<^UT92!P;W6^:;L@:6[](&%U=&5N=&EF
M:6MAZ&[](&)A8VME;F0N`%;AN2!A=71E;G1I9FEK8>AN_2!M;V1U;"!N97!O
M9'!O<G5J92!Z;V)R87IO=F%N:64@>F]Z;F%M=2!P;W6^[79A=&6U;W8L(&%L
M96)O(&)O;&$@=.%T;R!M;[YN;W.[('H@;F5J86OI:&\@9/1V;V1U('IA:^%Z
M86[A+@!:9.$@<V$L(+YE(%;AN2!P<F5H;&EA9&'H('-A('IM96YI;"!O9"!Z
M8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0<F4@5F&Y=2!B97IP9>AN;W.[
M('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN`%;AN2!P<F5H;&EA9&'H(&YE
M<&]D<&]R=6IE('3Z=&\@9G5N:V-I=2X`5N&Y('!R96AL:6%D8>@@;F5P;V1P
M;W)U:F4@=/IT;R!F=6YK8VEU('1L8>AE+B!3=&QAZ'1E($-O;G1R;VPO0V]M
M;6%N9"`K(%`@<')E('1L8>@N`%9AN6$@86MT=>%L;F$@Z&%S;W;A('KS;F$Z
M`%9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET82!B;VQA('IM96YE;N$N`%!R
M961N87-T879E;N$@:61E;G1I=&$Z`%!R961N87-T879E;OT@<&]Z;N%M:V]V
M_2!B;&]K.@!68;EE(&UE;F\Z`%!L871N;W.[(%;AN6AO(/KH='4@=GEP<KEA
M;&$N`%9AN64@;F]VZ2!H97-L;R!P<F4@)7,@:F4Z("5S`%9AN64@<&]Z;N%M
M:V]VZ2!B;&]K>3H`5F&Y92!N87-T879E;FEA(&)O;&D@86MT=6%L:7IO=F%N
MZ2!P<F4@=&]T;R!S961E;FEE+@!68;EE(&YA<W1A=F5N:6$@8F]L:2!A:W1U
M86QI>F]V86[I+@!68;EE(&AE<VQO(&)O;&\@;V)N;W9E;ND`5F&Y92!H97-L
M;R!B;VQO(&]B;F]V96[I+"!S:V]N=')O;'5J=&4@<VD@<&^Y='4@82!P<FEH
M;.%S=&4@<V$@<R!68;GM;2!N;W;];2!H97-L;VTN`%!L871N;W.[(%;AN6AO
M(&AE<VQA('9Y<'*Y86QA+@!68;EE('9Z9&EA;&5NZ2!S97)V97)Y.@!*=6AO
M<VSA=FEA`%IA:7(`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M3:W)YNR!C:71O
M=F%N_2!T97AT70!;4W!RX79A(&\@<')O8FSI;65=`%M:;V)R87IINR!C:71O
M=F%N_2!T97AT("T`6UIO8G)A>FF[(&-I=&]V86[]('1E>'0@+2`E<R!R:6%D
M:V]V70!;<FEA9&]K("5S('H@)7-=`%]!9&UI;FES='+A8VEA`%].87-PY+L@
M;F$@<&]Z;N%M:V]V_2!B;&]K`%]#3$D`7TMA=&5G\W)I80!?1&%T851R964`
M7U9Y;6%Z8;L`7U9Y;6%Z8;L@<FEA9&]K`%]5<')A=FF[`%]0<G;](')I861O
M:P!?4VMU<&EN>0!?4&]M;V-N[6L`5FQA<W1N;W-T:2!?;V)RX7IK=2XN+@!?
M26UP;W)T+T5X<&]R=`!?6F]Z;F%M('!O>F[A;6]K`%]0<FEH;.%S:;L@<V$`
M7T]D:&SA<VF[('-A`%]5<')A=FF[(&QI;FMU+BXN`%]-;VIE('!O>F[A;6MO
M=ND@8FQO:WD`7TYO=N$@<&]Z;N%M:V$`7TYA<W1A=F5N:6$`7U!RX79A`%]4
M;&'H:;L`3V1S=%]RX6YINR!L:6YK=2XN+@!?2+5A9&&[`$YA7W-T879E;FEE
M`%9L87-T;F]S=&D@7W1A8G6U:WDN+BX`4&]?=;[M=F%T96QI80!A9')E<^%R
M`&%D<F5SX70@;F5Z;N%M>0!K86QE;F3A<@!B97IV971R:64`;F5P;V1A<FEL
M;R!S82!V>71V;W)INR!V_7-T=7!N_2!S^F)O<@!N97!O9&%R:6QO('-A(&]T
M=F]R:;L@=G-T=7``:VQI:VYI=&4@<V5M`&-H>6)A('!R:2!P;W6^:73M('!R
M[6MA>F]VZ6AO(')I861K=0!C:'EB82!K;VYF:6=U<N%C:64`8VC]8F$@9/1L
M9;YI=/T@<WES=.EM;W;]('/Z8F]R`&-H>6)A(&9O<FWA='4@^F1A:F]V`'!O
M;&^^:V$@;F5NX6ID96[A`&ML97/A`'/Z8F]R`'IO('-M97)U("5S("@E<RD@
M<OUC:&QO<[MO=2`E<R`E<P!NX7)A>F]V_0!V.@!H:`!N97INX6UE(&UE;F\@
M:&]S=&ET9;5A`&]K86V^:71E`'8@<W!RX79E`&-H>6)A('9S='5P=2]V_7-T
M=7!U`&EN=&5R;N$@8VAY8F$@<V]F=';I<G4`<FEA9&MO=ET`<&_H87,@=GET
M=N%R86YI82!)4T\@;F%S=&%L82!C:'EB82!M:VES;V9S("5D`&UM`&UE;F\`
M;F5I;7!L96UE;G1O=F%NZ0!Z871I8;4@;F5I;7!L96UE;G1O=F%NZ0!P;WIN
MX6UK;W;](&)L;VL`;F]T97,N8W-V`'!E<F-E;G0`<'+M<W1U<"!Z86UI971N
M=73]`&)O9&]V`'9Z9&EA;&5NX2!C:'EB82!V('!R;W1O:V]L90!S=/IP80!S
M;'6^8F$@;FEE(&IE(&1O<W1U<&[A`'IO8G)A>FF[(')O>F1I96QY`'-M<S)E
M;6%I;"!C97H@2%144`!S<P!U<W3A;&5N_0!S>7-TZ6UO=N$@8VAY8F$`>F]Z
M;F%M(/IL;V@`9&_H87-NX2!C:'EB80!P<F4@<&]T=G)D96YI92!Z861A:G1E
M(&AE<VQO(&1V86MRX70`=6YI9FEK;W9A;ND`;F5P;VUE;F]V86[A`&1E9FEN
M=6IE('!O=;[M=F%T9;4`=D-A<F0`=DYO=&4`N3H`=V5A=&AE<BYC;VT`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M
M;R]L;V-A;&4O<VM?4TLO:&5L<"YX;6P`````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S-3<S`#$P-#$W,S8R-S0U`#`R,30W,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TR(C\^"CPA+2T@)$AO<F1E.B!M
M;F5M;R]L;V-A;&4O<VM?4TLO:&5L<"YX;6PL=B`Q+C(N,3(N,2`R,#`V+S`Q
M+S,P(#$V.C`P.C,Y(&IA;B!%>'`@)"`M+3X*/"$M+2`H0RD@,C`P,BP@279A
M;B!.;W)I<RP@/'9I>$!V87IK82YS:SX@+2T^"CQH96QP/@H*/&5N=')Y(&ED
M/2)/=F5R=FEE=R(^"B`@("`\=&ET;&4^4')E:+5A9#PO=&ET;&4^"B`@("`\
M:&5A9&EN9S[:=F]D/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!<&QI:^%C
M:6$@/&D^4&]Z;N%M:WD\+VD^(';A;2!U;6^^;NT@=GET=N%R8;L@<&_H[71A
MZ&]VZ2!E:W9I=F%L96YT>2!P87!I97)O=OUC:"!P;WINX6UO:RX@4&]Z;N%M
M:WD@;?2^971E('9Y=';A<F&[+"!U<')A=F]V8;LL('9Y;6%ZX79ANR!A('1L
M8>AINRX@3VMR96T@=&]H;R!M]+YE=&4@=B!P;WINX6UK86-H('9Y:+5A9.%V
M8;L@=&5X="!A('!R:7)A[V]V8;L@<&]Z;N%M:WD@9&\@:V%T96?S<FGM('!R
M92!L97"Y:74@;W)G86YI>N%C:74@82!P<F5HM6%D+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H*/&5N=')Y(&ED/2)L:7-T+6%C=&EO;G,B/@H@("`@/'1I=&QE
M/EIO>FYA;2!P;WINX6UO:SH@06MC:64\+W1I=&QE/@H@("`@/&AE861I;F<^
M06MC:64\+VAE861I;F<^"B`@("`\<&%R83X*("`@($ML:6MN=73M;2!N82`\
M:3Y6>6UA>F&[('!O>F[A;6MU/"]I/B!V>6UAOF5T92!V>6)R86[Z('!O>F[A
M;6MU+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!+;&EK;G5T:64@;F$@
M/&D^57!R879INR!P;WINX6UK=3PO:3X@=N%M('5M;[YN[2!U<')A=FF[(&5X
M:7-T=6KZ8W4@<&]Z;N%M:W4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M(%1L8>AI9&QO;2`\:3Y.87-PY+L@9&\@>F]Z;F%M=2!P;WINX6UO:SPO:3X@
M<V$@9&]S=&%N971E(&YA<W#DNR!D;R!Z;WIN86UU('!O>F[A;6]K+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)M96YU+6%C=&EO;G,B/@H@
M("`@/'1I=&QE/E!O;&^^:WD@;65N=3PO=&ET;&4^"B`@("`\:&5A9&EN9SY0
M;VQOOFMY(&UE;G4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(#QI/EIO>FYA
M;2!P;WINX6UO:SPO:3X@>F]B<F%Z[2!VN65T:WD@<&]Z;N%M:WDN"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@(#QI/E!R:61ANR!P;WINX6UK=3PO:3X@
M=N%M('5M;[YN[2!V>71V;W)INR!N;W;Z('!O>F[A;6MU+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("`\:3Y(M6%D8;L\+VD^(';A;2!U;6^^;NT@:+5A
M9&&[('!O>F[A;6MU(&]B<V%H=6KZ8W4@>F%D86[]('1E>'0N(%1E>'0@;?2^
M971E(&BU861ANR!B=>\@:6)A('8@<&]P:7-E('!O>F[A;6MY(&%L96)O('8@
M8V5L;VT@=&5X=&4@<&]Z;N%M:WDN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@(#QI/E1L8>AINSPO:3X@=N%M('5M;[YN[2!V>71L8>AINR!P;WINX6UK
M=2X@26MO;F$@/&D^5&QAZ&F[/"]I/B!S82!Z;V)R87IU:F4@=B!M96YU(&EB
M82!P<FD@>F]B<F%Z;W9A;NT@<&]Z;N%M:WDN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"@H*/&5N=')Y(&ED/2)S;W)T:6YG(CX*("`@(#QT:71L93Y4<FEE9&5N
M:64@<&]L;[YI96L\+W1I=&QE/@H@("`@/&AE861I;F<^5')I961E;FEE('!O
M;&^^:65K/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!0;^AA<R!Z;V)R87IO
M=F%N:6$@>F]Z;F%M=2!S:2!M]+YE=&4@;F5C:&&[('!O;&^^:WD@>F]R861I
MNR!P;V2U82"U=6)O=F^U;NEH;R!S=.5P8V$@:F5D;F]D=6-H_6T@:VQI:VYU
M=.UM(&YA(&IE:&\@;N%Z;W8N($%K(&-H8V5T92!Z;65N:;L@<VUE<B!T<FEE
M9&5N:6$@*'9Z;W-T=7!N92!R97-P+B!Z;W-T=7!N92DL(&ML:6MN:71E(&YA
M(&EK;VYU(+GM<&MY('8@;65N92!S=.5P8V$N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"CPO:&5L<#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&]C
M86QE+W-V7U-%+P``````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-0`P,C`P,38`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]M;F5M;R]L;V-A;&4O<W9?4T4O3$-?34534T%'15,O````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0U`#`R,38P
M,P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]S=E]312],
M0U]-15-304=%4R]M;F5M;RYM;P``````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,S(W,S4`
M,3`T,3<S-C(W-#4`,#(S,C8V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````6`@``!P```#<0@``(PL``)R%````
M````*+(``$@````IL@``#@```'*R```/````@;(```P```"1L@``#0```)ZR
M```(````K+(```L```"UL@``#````,&R```$````SK(``!@```#3L@``&P``
M`.RR```M````"+,``!T````VLP``)````%2S```I````>;,``!D```"CLP``
M)@```+VS```,````Y+,``"0```#QLP``"````!:T```/````'[0```L````O
MM```#@```#NT```%````2K0``"@```!0M```"````'FT```*````@K0``!4`
M``"-M```$@```*.T```+````MK0```T```#"M```'0```-"T```4````[K0`
M`"8````#M0``)P```"JU```F````4K4``(4```!YM0``#@```/^U```*````
M#K8```T````9M@``)P```">V```@````3[8```X```!PM@``%P```'^V```B
M````E[8``#4```"ZM@``$0```/"V```-`````K<```P````0MP``#0```!VW
M```&````*[<``)0````RMP``"@```,>W```/````TK<``!@```#BMP``#```
M`/NW```&````"+@```X````/N```#@```!ZX```(````+;@```D````VN```
M+@```$"X```:````;[@``#(```"*N```.````+VX``!4````]K@``%$```!+
MN0``6@```)VY``!7````^+D``#0```!0N@``"0```(6Z```-````C[H```<`
M``"=N@``"@```*6Z```/````L+H```4```#`N@``!@```,:Z```1````S;H`
M``@```#?N@``"0```.BZ```)````\KH```X```#\N@``"`````N[```E````
M%+L``"`````ZNP``'````%N[```>````>+L``"````"7NP``'0```+B[```3
M````UKL``!````#JNP``#P```/N[```*````"[P```<````6O````P```!Z\
M```&````(KP```\````IO```%````#F\```)````3KP```T```!8O```$@``
M`&:\```9````>;P``!X```"3O```#P```+*\```,````PKP```H```#/O```
M#P```-J\```(````ZKP``"0```#SO```%P```!B]```4````,+T``!8```!%
MO0``"````%R]``!.````9;T``"T```"TO0``$0```.*]```9````]+T```<`
M```.O@``#````!:^```L````([X```X```!0O@```P```%^^```+````8[X`
M``<```!OO@``!P```'>^```%````?[X```4```"%O@``"@```(N^```#````
MEKX``!<```":O@``"@```+*^```/````O;X```X```#-O@``&````-R^```C
M````];X```X````9OP``%````"B_```7````/;\``!<```!5OP``%P```&V_
M```3````A;\```\```"9OP``#@```*F_```I````N+\``!\```#BOP``'0``
M``+````'````(,````8````HP```"````"_````/````.,````8```!(P```
M"@```$_````3````6L````L```!NP```$````'K````5````B\```!4```"A
MP```!P```+?````0````O\````4```#0P```%0```-;````1````[,````P`
M``#^P```.P````O!```X````1\$```D```"`P0``!P```(K!```4````DL$`
M``,```"GP0``!0```*O!```)````L<$``!````"[P0``"0```,S!```3````
MUL$``#D```#JP0``$@```"3"```Y````-\(``"<```!QP@``+````)G"```J
M````QL(``"4```#QP@``"0```!?#```*````(<,```8````LPP``"0```#/#
M```'````/<,``"\```!%PP``-P```'7#```N````K<,``%4```#<PP``+0``
M`#+$```M````8,0``#T```".Q```/P```,S$```M````#,4``$`````ZQ0``
M(P```'O%```C````G\4``$````##Q0``+0````3&```S````,L8``"4```!F
MQ@``%0```(S&```9````HL8``"D```"\Q@``)````.;&```H````"\<``!4`
M```TQP``$0```$K'```1````7,<```H```!NQP``!````'G'```,````?L<`
M``\```"+QP``%P```)O'```*````L\<``!````"^QP``%@```,_'```6````
MYL<```<```#]QP``!P````7(```4````#<@```H````BR```"````"W(```(
M````-L@```@````_R```!@```$C(```G````3\@```@```!WR```!P```(#(
M```'````B,@```8```"0R```!0```)?(```'````G<@```8```"ER```"```
M`*S(```I````M<@```X```#?R```"@```.[(```)````^<@```X````#R0``
M!````!+)```'````%\D```D````?R0``!@```"G)```1````,,D```<```!"
MR0``%@```$K)```$````8<D```@```!FR0``!@```&_)```-````=LD```8`
M``"$R0``'@```(O)```%````JLD``!$```"PR0``"````,+)```-````R\D`
M``P```#9R0``#````.;)```'````\\D```,```#[R0```P```/_)```7````
M`\H```,````;R@``$P```!_*```=````,\H```@```!1R@``!````%K*```(
M````7\H```@```!HR@``"@```''*``!!````?,H``!H```"^R@``*P```-G*
M```@````!<L``!4````FRP``!@```#S+```&````0\L``!4```!*RP``&```
M`&#+```B````><L``"X```"<RP``'0```,O+```A````Z<L``"D````+S```
M"@```#7,```'````0,P```<```!(S```%0```%#,```(````9LP```X```!O
MS```"@```'[,```/````B<P```T```"9S```#P```*?,```-````M\P```D`
M``#%S```%````,_,```&````Y,P``!@```#KS```'0````3-```3````(LT`
M`!$````VS0``%````$C-```$````7<T```P```!BS0``!@```&_-```4````
M=LT``!<```"+S0``5````*/-```M````^,T``&0````FS@``!````(O.```.
M````D,X``$0```"?S@``!0```.3.```%````ZLX``!L```#PS@``&@````S/
M```3````)\\``!$````[SP``$0```$W/```1````7\\``!P```!QSP``*@``
M`([/```W````N<\``!P```#QSP``$`````[0```A````']````4```!!T```
M"@```$?0```3````4M````L```!FT```$@```'+0```*````A=````\```"0
MT```#0```*#0```1````KM```!,```#`T```#````-30```&````X=````P`
M``#HT```!@```/70```7````_-```!`````4T0``$0```"71```(````-]$`
M``4```!`T0``#````$;1```0````4]$```4```!DT0``#0```&K1```&````
M>-$```<```!_T0``#0```(?1```'````E=$```L```"=T0``!P```*G1```'
M````L=$```D```"YT0``%````,/1```)````V-$```D```#BT0``"@```.S1
M```9````]]$``#T````1T@``'0```$_2```,````;=(``!````!ZT@``!0``
M`(O2```E````D=(``!(```"WT@``$P```,K2```K````WM(``#L````*TP``
M(````$;3```(````9],``#8```!PTP``(0```*?3```0````R=,```@```#:
MTP``#````./3```&````\-,```0```#WTP``#P```/S3```.````#-0```H`
M```;U```!P```";4```*````+M0```T````YU```'@```$?4```?````9M0`
M`!L```"&U```'````*+4```A````O]0``!X```#AU```&0````#5```>````
M&M4``!L````YU0``(0```%75```N````=]4``"8```"FU0``&P```,W5```<
M````Z=4``!X````&U@``'````"76```F````0M8``"L```!IU@``,P```)76
M```F````R=8``"L```#PU@``.````!S7```=````5=<``!T```!SUP``%0``
M`)'7```5````I]<``"\```"]UP``(````.W7```2````#M@``"`````AV```
M*0```$+8```>````;-@``!X```"+V```(````*K8```2````R]@``*(```#>
MV```%@```('9```C````F-D``"@```"\V0``*0```.79```H````#]H``!\`
M```XV@``%0```%C:```5````;MH``"````"$V@``)0```*7:```H````R]H`
M`"T```#TV@``,````"+;``"2````4]L``"$```#FVP``%@````C<```6````
M']P``!P````VW```)@```%/<```J````>MP``$$```"EW```1````.?<```,
M````+-T```<````YW0``!P```$'=```&````2=T```T```!0W0``$````%[=
M```2````;]T```<```""W0``$P```(K=```2````GMT```<```"QW0``!```
M`+G=```0````OMT``!````#/W0``#````.#=```.````[=T```T```#\W0``
M#P````K>```3````&MX```T````NW@``*````#S>```#````9=X```T```!I
MW@``!@```'?>```1````?MX``!<```"0W@``&P```*C>```.````Q-X```(`
M``#3W@``!0```-;>```0````W-X```\```#MW@``!````/W>```-`````M\`
M``X````0WP```P```!_?```.````(]\```@````RWP``#P```#O?```(````
M2]\```\```!4WP``!P```&3?```-````;-\``!````!ZWP``#P```(O?```-
M````F]\``!D```"IWP``&@```,/?```+````WM\``!$```#JWP``"0```/S?
M```&````!N````L````-X```$P```!G@```,````+>````H````ZX```$0``
M`$7@```9````5^```!<```!QX```"P```(G@```-````E>```"(```"CX```
M#P```,;@```;````UN```#0```#RX```"@```"?A```8````,N$``!(```!+
MX0``&0```%[A```6````>.$``!````"/X0``$````*#A```B````L>$```T`
M``#4X0``!P```.+A```,````ZN$``"8```#WX0``"@```![B```4````*>(`
M``L````^X@``#````$KB```B````5^(``"\```!ZX@``"P```*KB```)````
MMN(``!D```#`X@``"P```-KB```7````YN(``!<```#^X@``"0```!;C```6
M````(.,```\````WXP``&0```$?C```6````8>,```X```!XXP``!P```(?C
M```(````C^,```T```"8XP``)@```*;C```H````S>,``$,```#VXP``$@``
M`#KD```?````3>0```@```!MY```"P```';D```O````@N0```X```"RY```
M!0```,'D```&````Q^0``$4```#.Y````P```!3E```'````&.4```0````@
MY0``"0```"7E```*````+^4```H````ZY0``"0```$7E```/````3^4``!``
M``!?Y0``%P```'#E```:````B.4``!$```"CY0``&0```+7E```7````S^4`
M``D```#GY0``!0```/'E```+````]^4```H````#Y@```@````[F```%````
M$>8```T````7Y@``&P```"7F```7````0>8``!0```!9Y@``"0```&[F```*
M````>.8```X```"#Y@``#0```)+F```2````H.8```,```"SY@``"````+?F
M```.````P.8``!@```#/Y@``&````.CF```%`````><``!@````'YP``'@``
M`"#G```;````/^<``!D```!;YP``&````'7G```;````CN<``!,```"JYP``
M$P```+[G```'````TN<```@```#:YP``!@```./G```&````ZN<``!````#Q
MYP``#P````+H```0````$N@```\````CZ```"P```#/H```/````/^@```P`
M``!/Z```#P```%SH```'````;.@```8```!TZ```#@```'OH```,````BN@`
M`"@```"7Z```#P```,#H```(````T.@```8```#9Z```#````.#H```(````
M[>@``!,```#VZ```"@````KI```>````%>D``"$````TZ0``(````%;I```9
M````=^D``!<```"1Z0``)0```*GI```7````S^D``!8```#GZ0``!````/[I
M```;`````^H```T````?Z@``#````"WJ```#````.NH```4````^Z@``"```
M`$3J```*````3>H```P```!8Z@``"P```&7J```0````<>H```P```""Z@``
M#@```(_J```+````GNH```0```"JZ@``!````*_J```3````M.H``!0```#(
MZ@``#````-WJ```)````ZNH```X```#TZ@``"P````/K```;````#^L```<`
M```KZP``!P```#/K```*````.^L```T```!&ZP``&````%3K```*````;>L`
M``0```!XZP``)@```'WK```.````I.L``'P```"SZP``%0```##L```%````
M1NP```<```!,[```#````%3L```(````8>P```H```!J[```!@```'7L```(
M````?.P```(```"%[```!@```(CL```&````C^P``!0```"6[```%0```*OL
M```/````P>P``!$```#1[```&@```./L```-````_NP``!`````,[0``&P``
M`!WM```$````.>T```D````^[0``$````$CM```)````6>T```D```!C[0``
M!0```&WM```:````<^T```@```".[0``!@```)?M```/````GNT``!D```"N
M[0``#@```,CM```'````U^T```<```#?[0``!0```.?M```)````[>T```H`
M``#W[0``#@````+N```"````$>X```8````4[@``"P```!ON```-````)^X`
M``D````U[@``!@```#_N```%````1NX```D```!,[@``!P```%;N```$````
M7NX``!0```!C[@``0@```'CN```E````N^X``"4```#A[@``!@````?O```$
M````#N\```D````3[P``"````!WO```1````)N\```X````X[P``"0```$?O
M```&````4>\```T```!8[P``!@```&;O```$````;>\``#D```!R[P``/0``
M`*SO```Z````ZN\``!X````E\```!0```$3P```.````2O````0```!9\```
M!@```%[P```'````9?```"$```!M\```#0```(_P```5````G?````8```"S
M\```$@```+KP```$````S?```!$```#2\```!@```.3P```*````Z_```"(`
M``#V\```!````!GQ```%````'O$```0````D\0``#````"GQ```.````-O$`
M``H```!%\0``"````%#Q```)````6?$```4```!C\0``.@```&GQ```P````
MI/$``#4```#5\0``*0````OR``!'````-?(``#@```!]\@``*0```+;R```_
M````X/(``"X````@\P``+0```$_S```?````??,```\```"=\P``$@```*WS
M```+````P/,``"8```#,\P``*0```//S```D````'?0``"8```!"]```"```
M`&GT```*````<O0```D```!]]```!P```(?T```@````C_0``"````"P]```
M)@```-'T```*````^/0``!D````#]0``*0```!WU```6````1_4``!(```!>
M]0``!P```''U```*````>?4```P```"$]0``#P```)'U```0````H?4``$``
M``"R]0``<````//U``!F````9/8```X```#+]@``"0```-KV```*````Y/8`
M`!(```#O]@``$P````+W```,````%O<```8````C]P``%0```"KW```/````
M0/<``!,```!0]P``$@```&3W```0````=_<```H```"(]P``$0```)/W```<
M````I?<``",```#"]P``:@```.;W```/````4?@```4```!A^```$````&?X
M```)````>/@```0```""^```"P```(?X```@````D_@``!0```"T^```#```
M`,GX```,````UO@```\```#C^```%0```//X```I````"?D``"H````S^0``
M)@```%[Y```G````A?D``"D```"M^0``*@```-?Y```9`````OH``!$````<
M^@``$@```"[Z```3````0?H``!0```!5^@``#P```&KZ```6````>OH``!<`
M``"1^@``$````*GZ```1````NOH``#0```#,^@``$P````'[```2````%?L`
M`#4````H^P``%````%[[```'````<_L```P```![^P``*P```(C[```@````
MM/L``!````#5^P``%````.;[```1````^_L``!<````-_```'````"7\```3
M````0OP``!0```!6_```&@```&O\```1````AOP``!H```"8_```'@```+/\
M```:````TOP``!,```#M_```%0````']```1````%_T``!<````I_0``%```
M`$']```7````5OT``!4```!N_0``"0```(3]```0````COT``!D```"?_0``
M!````+G]```'````OOT```L```#&_0``$0```-+]```&````Y/T```8```#K
M_0``!@```/+]```%````^?T```<```#__0``!P````?^```%````#_X``!8`
M```5_@``!@```"S^```&````,_X```0````Z_@``!````#_^```'````1/X`
M``X```!,_@``#````%O^```,````:/X```T```!U_@``!0```(/^```H````
MB?X```P```"R_@``#P```+_^```*````S_X```@```#:_@``"0```./^```K
M````[?X```0````9_P``"````![_```%````)_\``"8````M_P``$@```%3_
M```/````9_\```8```!W_P``"@```'[_```'````B?\```@```"1_P``(```
M`)K_```)````N_\```T```#%_P``%````-/_```,````Z/\```T```#U_P``
M#@````,``0`6````$@`!`!$````I``$`!@```#L``0`(````0@`!``,```!+
M``$`!@```$\``0`9````5@`!``<```!P``$`!````'@``0`+````?0`!``L`
M``")``$`!P```)4``0`%````G0`!``<```"C``$`%@```*L``0`-````P@`!
M``H```#0``$`#0```-L``0`*````Z0`!`!````#T``$`#P````4!`0`1````
M%0$!`!<````G`0$`"@```#\!`0`1````2@$!``@```!<`0$`!````&4!`0`/
M````:@$!`#H```!Z`0$`!0```+4!`0`,````NP$!`!X```#(`0$`#@```.<!
M`0`0````]@$!``L````'`@$`#````!,"`0`)````(`(!``<````J`@$`"@``
M`#("`0`)````/0(!``X```!'`@$`$````%8"`0`;````9P(!`!@```"#`@$`
M&@```)P"`0`*````MP(!``D```#"`@$`"@```,P"`0`,````UP(!``\```#D
M`@$`"````/0"`0`&````_0(!``<````$`P$`!0````P#`0`+````$@,!`$<`
M```>`P$`#0```&8#`0`)````=`,!``0```!^`P$``P```(,#`0`3````AP,!
M`!,```";`P$`$P```*\#`0`&````PP,!``L```#*`P$`"@```-8#`0`"````
MX0,!``0```#D`P$`)0```.D#`0`#````#P0!``4````3!`$`*@```!D$`0`*
M````1`0!``4```!/!`$`!````%4$`0`*````6@0!``T```!E!`$`!@```',$
M`0`(````>@0!``@```"#!`$`!````(P$`0`%````D00!`&@```"7!`$`"0``
M```%`0`,````"@4!`!`````7!0$`!0```"@%`0`&````+@4!`!L````U!0$`
M+P```%$%`0`0````@04!``H```"2!0$`#P```)T%`0`*````K04!``D```"X
M!0$`$P```,(%`0`;````U@4!`!@```#R!0$`%P````L&`0`7````(P8!`!\`
M```[!@$`#@```%L&`0`#````:@8!``<```!N!@$`"````'8&`0`4````?P8!
M`!,```"4!@$`$````*@&`0`-````N08!``X```#'!@$`%@```-8&`0`'````
M[08!``D```#U!@$`"@```/\&`0`+````"@<!``<````6!P$`40```!X'`0`0
M````<`<!``P```"!!P$`#0```(X'`0`:````G`<!`$H```"W!P$`&0````((
M`0`&````'`@!`!H````C"`$`)0```#X(`0`&````9`@!``8```!K"`$`'P``
M`'((`0`&````D@@!``D```"9"`$`&````*,(`0`7````O`@!`"@```#4"`$`
M!@```/T(`0`-````!`D!`"(````2"0$`5P```#4)`0`3````C0D!`",```"A
M"0$`$P```,4)`0`"````V0D!``L```#<"0$`"````.@)`0`-````\0D!``H`
M``#_"0$`#`````H*`0`'````%PH!`!0````?"@$`!@```#0*`0`(````.PH!
M``X```!$"@$`!P```%,*`0`*````6PH!``L```!F"@$`,@```'(*`0`'````
MI0H!``P```"M"@$`#0```+H*`0`,````R`H!``D```#5"@$`"0```-\*`0`*
M````Z0H!``<```#T"@$`"0```/P*`0`'````!@L!``H````."P$`!P```!D+
M`0`;````(0L!``\````]"P$`$@```$T+`0`*````8`L!`!8```!K"P$`"```
M`((+`0`)````BPL!`!````"5"P$`!P```*8+`0`2````K@L!``0```#!"P$`
M!P```,8+`0`%````S@L!``0```#4"P$`#````-D+`0`%````Y@L!``L```#L
M"P$`%````/@+`0`1````#0P!`!0````?#`$`%P```#0,`0`8````3`P!`!P`
M``!E#`$`&0```((,`0`'````G`P!``4```"D#`$`#0```*H,`0`,````N`P!
M`!$```#%#`$`"````-<,`0`(````X`P!`!<```#I#`$`"P````$-`0`,````
M#0T!`!\````:#0$`&@```#H-`0`3````50T!``0```!I#0$`"@```&X-`0`$
M````>0T!``T```!^#0$`#````(P-`0`%````F0T!``D```"?#0$`!0```*D-
M`0`'````KPT!``4```"W#0$`!````+T-`0`"````P@T!`#@```#%#0$`+```
M`/X-`0`2````*PX!`"D````^#@$`,@```&@.`0`*````FPX!`"P```"F#@$`
M+@```-,.`0`S`````@\!`#,````V#P$`.````&H/`0`/````HP\!`!0```"S
M#P$`&````,@/`0`0````X0\!`!P```#R#P$`#P````\0`0`3````'Q`!`!4`
M```S$`$`%````$D0`0`2````7A`!`"0```!Q$`$`"````)80`0`D````GQ`!
M`!,```#$$`$`%````-@0`0`5````[1`!`"T````#$0$`+0```#$1`0`Q````
M7Q$!`"X```"1$0$`+P```,`1`0`L````\!$!`!,````=$@$`#````#$2`0`-
M````/A(!``@```!,$@$`%P```%42`0`(````;1(!``P```!V$@$`*P```(,2
M`0`A````KQ(!`!H```#1$@$`"0```.P2`0!%````]A(!`$$````\$P$`!0``
M`'X3`0`/````A!,!``0```"4$P$`$P```)D3`0`.````K1,!`!,```"\$P$`
M&````-`3`0`&````Z1,!``D```#P$P$`"@```/H3`0`/````!10!`!`````5
M%`$`!P```"84`0`.````+A0!``T````]%`$`#````$L4`0`*````6!0!``D`
M``!C%`$`"@```&T4`0`/````>!0!``@```"(%`$`#P```)$4`0`(````H10!
M`!H```"J%`$`!0```,44`0`-````RQ0!`!L```#9%`$`!@```/44`0`(````
M_!0!``8````%%0$`%`````P5`0`1````(14!``X````S%0$`.````$(5`0`"
M````>Q4!``8```!^%0$`#@```(45`0`%````E!4!``<```":%0$`#@```*(5
M`0`&````L14!`"@```"X%0$`#````.$5`0`<````[A4!``0````+%@$`*0``
M`!`6`0`7````.A8!`!\```!2%@$`7````'(6`0`4````SQ8!`#X```#D%@$`
M'P```",7`0`0````0Q<!`!0```!4%P$`!P```&D7`0`.````<1<!``P```"`
M%P$`#````(T7`0`3````FA<!``H```"N%P$`'0```+D7`0`9````UQ<!``4`
M``#Q%P$`$0```/<7`0`1````"1@!`"0````;&`$`$@```$`8`0`5````4Q@!
M`!(```!I&`$`#@```'P8`0`9````BQ@!``@```"E&`$`"0```*X8`0`-````
MN!@!``<```#&&`$`"@```,X8`0`'````V1@!``\```#A&`$`!@```/$8`0`+
M````^!@!`!H````$&0$`"@```!\9`0`'````*AD!``@````R&0$`!0```#L9
M`0`?````01D!``8```!A&0$`$````&@9`0`(````>1D!``T```""&0$`"```
M`)`9`0`>````F1D!`!(```"X&0$`+````,L9`0`:````^!D!``D````3&@$`
M"@```!T:`0`5````*!H!``4````^&@$`%````$0:`0`$````61H!`!````!>
M&@$`!@```&\:`0`'````=AH!`!X```!^&@$`*````)T:`0`*````QAH!`!P`
M``#1&@$`$0```.X:`0`+`````!L!`!H````,&P$`%````"<;`0`$````/!L!
M``0```!!&P$`"P```$8;`0`%````4AL!``8```!8&P$`"````%\;`0`&````
M:!L!``H```!O&P$`&P```'H;`0`T````EAL!`#0```#+&P$`(``````<`0`I
M````(1P!`"````!+'`$`00```&P<`0`:````KAP!`"@```#)'`$`*0```/(<
M`0!1````'!T!`%````!N'0$`5P```+\=`0`L````%QX!`"(```!$'@$`!@``
M`&<>`0`(````;AX!``4```!W'@$`"````'T>`0`9````AAX!`!D```"@'@$`
M*@```+H>`0`(````Y1X!`",```#N'@$`&0```!(?`0`N````+!\!`#0```!;
M'P$`"````)`?`0`7````F1\!``H```"Q'P$`!P```+P?`0`A````Q!\!`!``
M``#F'P$`#@```/<?`0`+````!B`!``<````2(`$`$P```!H@`0`(````+B`!
M``L````W(`$`"@```$,@`0`4````3B`!``\```!C(`$`,@```',@`0`+````
MIB`!``X```"R(`$`!0```,$@`0`%````QR`!``4```#-(`$`%P```-,@`0`/
M````ZR`!``0```#[(`$`"@`````A`0`)````"R$!``L````5(0$`#0```"$A
M`0`,````+R$!``X````\(0$`!0```$LA`0`$````42$!``T```!6(0$`,@``
M`&0A`0`8````ER$!`$4```"P(0$`%P```/8A`0`'````#B(!`!X````6(@$`
M#````#4B`0`4````0B(!``4```!7(@$`%````%TB`0`&````<B(!``<```!Y
M(@$`(P```($B`0`.````I2(!`"H```"T(@$`!@```-\B`0`,````YB(!``\`
M``#S(@$`#0````,C`0`1````$2,!`!<````C(P$`"P```#LC`0`V````1R,!
M``H```!^(P$`(@```(DC`0`+````K",!``\```"X(P$`"P```,@C`0`@````
MU",!`"<```#U(P$`*P```!TD`0`)````220!`#(```!3)`$`)0```(8D`0`P
M````K"0!`#$```#=)`$`+0````\E`0`.````/24!`!0```!,)0$`!0```&$E
M`0`.````9R4!`!,```!V)0$`$@```(HE`0`'````G24!`!$```"E)0$`$P``
M`+<E`0`'````RR4!`!0```#3)0$`&````.@E`0`'`````28!``4````))@$`
M#`````\F`0`,````'"8!`!(````I)@$`!````#PF`0`'````028!``H```!)
M)@$`"P```%0F`0`,````8"8!``X```!M)@$`#@```'PF`0`%````BR8!``4`
M``"1)@$`+@```)<F`0`F````QB8!`",```#M)@$``P```!$G`0`2````%2<!
M``8````H)P$`'@```"\G`0`8````3B<!`"4```!G)P$`#0```(TG`0`)````
MFR<!`!\```"E)P$``P```,4G`0`'````R2<!``H```#1)P$``@```-PG`0`,
M````WR<!`!4```#L)P$`"P````(H`0`9````#B@!`"`````H*`$`$@```$DH
M`0`%````7"@!``H```!B*`$`%0```&TH`0`2````@R@!``P```"6*`$`!```
M`*,H`0`)````J"@!``<```"R*`$`#````+HH`0!2````QR@!`!<````:*0$`
M)````#(I`0`2````5RD!``<```!J*0$`!@```'(I`0`.````>2D!``X```"(
M*0$`#````)<I`0`,````I"D!``P```"Q*0$`#0```+XI`0`5````S"D!`!(`
M``#B*0$`$````/4I`0`/````!BH!`!0````6*@$`"@```"LJ`0`;````-BH!
M`!````!2*@$`"P```&,J`0`;````;RH!`&D```"+*@$`&@```/4J`0`7````
M$"L!`!D````H*P$`&@```$(K`0`E````72L!`"<```"#*P$`&@```*LK`0`7
M````QBL!`!L```#>*P$`&0```/HK`0`?````%"P!`!0````T+`$`%P```$DL
M`0`3````82P!``@```!U+`$`!P```'XL`0`(````ABP!``D```"/+`$`%0``
M`)DL`0`-````KRP!`",```"]+`$`#0```.$L`0`3````[RP!``@````#+0$`
M`P````PM`0!&````$"T!`#\```!7+0$`-P```)<M`0!7````SRT!``4````G
M+@$`'P```"TN`0`O````32X!``H```!]+@$`"````(@N`0`-````D2X!`"T`
M``"?+@$`!````,TN`0`.````TBX!`!0```#A+@$`3P```/8N`0`E````1B\!
M`!(```!L+P$`(````'\O`0`<````H"\!``L```"]+P$`'P```,DO`0`=````
MZ2\!`"4````',`$`(````"TP`0`D````3C`!`"````!S,`$`"P```)0P`0`'
M````H#`!``T```"H,`$`#````+8P`0`7````PS`!``8```#;,`$`.0```.(P
M`0`,````'#$!``<````I,0$`"0```#$Q`0`3````.S$!``<```!/,0$`"0``
M`%<Q`0`$````83$!`!````!F,0$`"````'<Q`0`(````@#$!``0```"),0$`
M"P```(XQ`0`,````FC$!`!(```"G,0$`$0```+HQ`0`,````S#$!`!H```#9
M,0$`#P```/0Q`0`'````!#(!``T````,,@$`$````!HR`0`1````*S(!`!0`
M```],@$`#@```%(R`0`,````83(!`"P```!N,@$`$P```)LR`0`<````KS(!
M`"@```#,,@$`!@```/4R`0`'````_#(!`!,````$,P$`!0```!@S`0`$````
M'C,!`!<````C,P$`"@```#LS`0`,````1C,!``D```!3,P$`!@```%TS`0`)
M````9#,!``@```!N,P$`"0```'<S`0`%````@3,!``H```"',P$`$0```)(S
M`0`&````I#,!``X```"K,P$`#@```+HS`0`-````R3,!``L```#7,P$`'0``
M`.,S`0`+`````30!``(````--`$`'````!`T`0`'````+30!``8````U-`$`
M9````#PT`0`)````H30!``<```"K-`$`)@```+,T`0`X````VC0!`!H````3
M-0$`*@```"XU`0`[````634!`!@```"5-0$`*````*XU`0`T````US4!`!D`
M```,-@$`%0```"8V`0`%````/#8!``<```!"-@$`"````$HV`0`'````4S8!
M``4```!;-@$`!P```&$V`0`.````:38!``D```!X-@$`!@```((V`0`(````
MB38!``L```"2-@$`!P```)XV`0`(````IC8!``<```"O-@$`%@```+<V`0`)
M````SC8!``8```#8-@$`"P```-\V`0`0````ZS8!``8```#\-@$`'`````,W
M`0`4````(#<!``<````U-P$`$0```#TW`0`(````3S<!``X```!8-P$`"```
M`&<W`0`%````<#<!`!````!V-P$`"0```(<W`0`0````D3<!``8```"B-P$`
M&0```*DW`0`*````PS<!`!P```#.-P$`!P```.LW`0`%````\S<!``0```#Y
M-P$`$````/XW`0`4````#S@!``L````D.`$`#0```#`X`0`H````/C@!`!@`
M``!G.`$`%P```(`X`0`:````F#@!`!0```"S.`$`!````,@X`0`)````S3@!
M``H```#7.`$`!P```.(X`0`"````ZC@!``X```#M.`$`"````/PX`0`?````
M!3D!`",````E.0$`(P```$DY`0`?````;3D!`#@```"-.0$`)@```,8Y`0`Q
M````[3D!`"<````?.@$`9````$<Z`0`4````K#H!`!P```#!.@$`50```-XZ
M`0`X````-#L!`$H```!M.P$`6P```+@[`0`H````%#P!`#@````]/`$`*@``
M`'8\`0`H````H3P!`"P```#*/`$`)P```/<\`0`F````'ST!`!L```!&/0$`
M/@```&(]`0`C````H3T!`!<```#%/0$`&0```-T]`0!(````]ST!`(4```!`
M/@$`,````,8^`0`5````]SX!`"@````-/P$`(@```#8_`0`B````63\!`"``
M``!\/P$`)0```)T_`0!!````PS\!`%L````%0`$`20```&%``0`Q````JT`!
M`!T```#=0`$`&````/M``0`K````%$$!`"$```!`00$`'P```&)!`0`K````
M@D$!`"8```"N00$`(0```-5!`0`I````]T$!`"<````A0@$`.@```$E"`0`=
M````A$(!`!$```"B0@$`,P```+1"`0`E````Z$(!`#@````.0P$`)P```$=#
M`0`@````;T,!`!\```"00P$`,````+!#`0!I````X4,!`#$```!+1`$`00``
M`'U$`0`S````OT0!`"4```#S1`$`/0```!E%`0!E````5T4!`$T```"]10$`
M+P````M&`0`N````.T8!`"D```!J1@$`*P```)1&`0`P````P$8!`"H```#Q
M1@$`+````!Q'`0`^````24<!`%0```"(1P$`6@```-U'`0`H````.$@!`"8`
M``!A2`$`2````(A(`0!*````T4@!`"L````<20$`'@```$A)`0`R````9TD!
M`!T```":20$`(P```+A)`0`O````W$D!`"P````,2@$`+0```#E*`0!Q````
M9TH!`&8```#92@$`;P```$!+`0"S````L$L!`!<```!D3`$`)0```'Q,`0`R
M````HDP!`"D```#53`$`/@```/],`0`B````/DT!`%(```!A30$`(@```+1-
M`0`E````UTT!``L```#]30$`10````E.`0`A````3TX!`#````!Q3@$`)0``
M`*).`0`<````R$X!`#$```#E3@$`!P```!=/`0`'````'T\!``0````G3P$`
M#0```"Q/`0`+````.D\!``X```!&3P$`"P```%5/`0`%````84\!`!````!G
M3P$``@```'A/`0!9````>T\!``4```#53P$`$@```-M/`0`$````[D\!``<`
M``#S3P$`"````/M/`0`%````!%`!``,````*4`$`$`````Y0`0`,````'U`!
M`!,````L4`$`#0```$!0`0`"````3E`!``<```!14`$`!@```%E0`0`4````
M8%`!``P```!U4`$`&````()0`0`&````FU`!`!(```"B4`$`#````+50`0`#
M````PE`!`"H```#&4`$`!````/%0`0`&````]E`!``<```#]4`$`'P````51
M`0`U````)5$!`"X```!;40$`+P```(I1`0`7````NE$!`!\```#240$`(@``
M`/)1`0`E````%5(!`"`````[4@$`&P```%Q2`0`8````>%(!`"0```"14@$`
M'P```+92`0`:````UE(!`"$```#Q4@$`(````!-3`0`:````-%,!`#(```!/
M4P$`&0```()3`0`:````G%,!`"\```"W4P$`*P```.=3`0`?````$U0!`",`
M```S5`$`'P```%=4`0`:````=U0!`"$```"25`$`)0```+14`0`F````VE0!
M`"4````!50$`)````"=5`0`8````3%4!`!T```!E50$`)````(-5`0`8````
MJ%4!`"(```#!50$`+````.15`0`O````$58!`!4```!!5@$`)0```%=6`0`\
M````?58!`!\```"Z5@$`(P```-I6`0`?````_E8!`"`````>5P$`&@```#]7
M`0`8````6E<!`"8```!S5P$`'@```)I7`0`I````N5<!`!X```#C5P$`,0``
M``)8`0`)````-%@!``P````^6`$`#````$M8`0`7````6%@!`"\```!P6`$`
M)````*!8`0`'````Q5@!`!\```#-6`$`#P```.U8`0`4````_5@!``X````2
M60$`#0```"%9`0`D````+UD!``4```!460$`!P```%I9`0`B````8ED!`"4`
M``"%60$`&@```*M9`0`=````QED!`!H```#D60$`!P```/]9`0#'````!UH!
M``L```#/6@$`'````-M:`0`5````^%H!``8````.6P$`"0```!5;`0`8````
M'UL!``L````X6P$`#0```$1;`0`7````4EL!``8```!J6P$`,P```'%;`0`3
M````I5L!`!,```"Y6P$`!P```,U;`0`/````U5L!``<```#E6P$`,@```.U;
M`0`$````(%P!`"$````E7`$`$P```$=<`0`,````6UP!`!$```!H7`$`,@``
M`'I<`0`6````K5P!``@```#$7`$`'0```,U<`0`)````ZUP!``H```#U7`$`
M%`````!=`0`*````%5T!`!T````@70$`"````#Y=`0`?````1UT!``@```!G
M70$`&@```'!=`0`G````BUT!``8```"S70$`%0```+I=`0`'````T%T!``@`
M``#870$`"0```.%=`0`_````ZUT!``<````K7@$`#P```#->`0`.````0UX!
M`!````!27@$`"0```&->`0`)````;5X!``@```!W7@$`$P```(!>`0`'````
ME%X!`!D```"<7@$`"@```+9>`0`*````P5X!``D```#,7@$`%P```-9>`0`4
M````[EX!``H````#7P$`#`````Y?`0`7````&U\!``0````S7P$`*@```#A?
M`0`,````8U\!`!$```!P7P$`!P```()?`0`"````BE\!`!````"-7P$`&```
M`)Y?`0`+````MU\!``,```##7P$`"````,=?`0`3````T%\!`!<```#D7P$`
M!@```/Q?`0`'`````V`!``T````+8`$`"P```!E@`0`4````)6`!`!4````Z
M8`$`#@```%!@`0`O````7V`!`"````"/8`$`'````+!@`0`5````S6`!`"L`
M``#C8`$`#`````]A`0`Q````'&$!``4```!.80$`$@```%1A`0`_````9V$!
M`!(```"G80$`"@```+IA`0`&````Q6$!``0```#,80$`!````-%A`0`*````
MUF$!`!,```#A80$`!0```/5A`0`&````^V$!``8````"8@$`"`````EB`0`$
M````$F(!``P````78@$`"@```"1B`0`Y````+V(!`"X```!I8@$`*0```)AB
M`0`%````PF(!`!D```#(8@$`$0```.)B`0`"````]&(!``0```#W8@$`"@``
M`/QB`0`&````!V,!``4````.8P$``P```!1C`0`,````&&,!`$4````E8P$`
M,@```&MC`0`Q````GF,!`!H```#08P$`-0```.MC`0`T````(60!`"@```!6
M9`$`,@```']D`0`9````LF0!`'(```#,9`$`(````#]E`0`U````8&4!`"$`
M``"690$`10```+AE`0`P````_F4!`"@````O9@$`*````%AF`0`I````@68!
M`"8```"K9@$`)0```-)F`0`H````^&8!`"@````A9P$`(@```$IG`0`K````
M;6<!`#````"99P$`$@```,IG`0`3````W6<!`!````#Q9P$`>0````)H`0`)
M````?&@!`*$```"&:`$`<P```"AI`0!\````G&D!`"L````9:@$`5````$5J
M`0`7````FFH!`"<```"R:@$`%@```-IJ`0`5````\6H!``\````':P$`%P``
M`!=K`0`?````+VL!``X```!/:P$`0````%YK`0`?````GVL!`!P```"_:P$`
M40```-QK`0`:````+FP!`!0```!);`$`"@```%YL`0`%````:6P!``8```!O
M;`$`"````'9L`0`%````?VP!`!(```"%;`$`$````)AL`0`3````J6P!`!T`
M``"];`$`#P```-ML`0`/````ZVP!`!````#[;`$`!`````QM`0`)````$6T!
M``D````;;0$`!P```"5M`0`+````+6T!``4````Y;0$`"P```#]M`0`'````
M2VT!``4```!3;0$`%````%EM`0`.````;FT!``L```!];0$`!P```(EM`0`(
M````D6T!``\```":;0$`#````*IM`0`)````MVT!``@```#!;0$`#````,IM
M`0`&````UVT!``\```#>;0$`!P```.YM`0`&````]FT!`!0```#];0$`!@``
M`!)N`0`,````&6X!`!$````F;@$`"````#AN`0`$````06X!`!D```!&;@$`
M$0```&!N`0`*````<FX!``4```!];@$`&````(-N`0`3````G&X!`!P```"P
M;@$`$0```,UN`0`$````WVX!``\```#D;@$`!P```/1N`0`$````_&X!`!D`
M```!;P$`!P```!MO`0`"````(V\!``(````F;P$`$0```"EO`0`)````.V\!
M``8```!%;P$`$@```$QO`0`7````7V\!``8```!W;P$`)P```'YO`0`"````
MIF\!``0```"I;P$`#P```*YO`0`3````OF\!``<```#2;P$`"0```-IO`0`'
M````Y&\!`!$```#L;P$`!@```/YO`0`8````!7`!``8````><`$`$P```"5P
M`0`0````.7`!`!(```!*<`$``@```%UP`0`&````8'`!``P```!G<`$`"0``
M`'1P`0`1````?G`!`"(```"0<`$`!P```+-P`0`'````NW`!``L```##<`$`
M!0```,]P`0`%````U7`!``(```#;<`$`"P```-YP`0!B`0``ZG`!`$P```!-
M<@$`$0```)IR`0`2````K'(!``\```"_<@$`#@```,]R`0`'````WG(!``H`
M``#F<@$`!P```/%R`0`$````^7(!`!@```#^<@$`'0```!=S`0`L````-7,!
M`!T```!B<P$`(````(!S`0`F````H7,!`!<```#(<P$`*````.!S`0`,````
M"70!`"L````6=`$`#P```$)T`0`.````4G0!`!$```!A=`$`$@```'-T`0`%
M````AG0!`",```",=`$`"````+!T`0`*````N70!`!,```#$=`$`#P```-AT
M`0`+````Z'0!``D```#T=`$`%0```/YT`0`5````%'4!`$,````J=0$`(@``
M`&YU`0`Q````D74!`&\```##=0$`"````#-V`0`*````/'8!``H```!'=@$`
M-P```%)V`0`B````BG8!`!````"M=@$`&P```+YV`0`@````VG8!`#````#[
M=@$`$````"QW`0`/````/7<!`!,```!-=P$`$````&%W`0`&````<G<!`(D`
M``!Y=P$`"P````-X`0`1````#W@!`!T````A>`$`"@```#]X`0`,````2G@!
M`!````!7>`$`$````&AX`0`)````>7@!``L```"#>`$`+````(]X`0`<````
MO'@!`#L```#9>`$`10```!5Y`0!6````6WD!`%,```"R>0$`60````9Z`0!6
M````8'H!`#X```"W>@$`#@```/9Z`0`3````!7L!``X````9>P$`$````"A[
M`0`8````.7L!``4```!2>P$`!@```%A[`0`*````7WL!``4```!J>P$`!@``
M`'![`0`&````=WL!`!$```!^>P$`"@```)![`0`E````FWL!`"0```#!>P$`
M#@```.9[`0`H````]7L!`"\````>?`$`*@```$Y\`0`0````>7P!`!(```"*
M?`$`#````)U\`0`&````JGP!``@```"Q?`$`"0```+I\`0`,````Q'P!`!0`
M``#1?`$`&0```.9\`0`.`````'T!`!(````/?0$`%P```")]`0`>````.GT!
M`",```!9?0$`&@```'U]`0`2````F'T!`!````"K?0$`%P```+Q]`0`-````
MU'T!`"H```#B?0$`&`````U^`0`6````)GX!`!D````]?@$`$P```%=^`0!/
M````:WX!`#$```"[?@$`&0```.U^`0`D````!W\!``8````L?P$`"0```#-_
M`0`T````/7\!``X```!R?P$`!@```(%_`0`*````B'\!``@```"3?P$`"```
M`)Q_`0`%````I7\!``<```"K?P$`"@```+-_`0`$````OG\!`!P```##?P$`
M#````.!_`0`1````[7\!``\```#_?P$`%0````^``0`F````)8`!``L```!,
M@`$`&@```%B``0`=````<X`!`"$```"1@`$`&````+.``0`/````S(`!`!``
M``#<@`$`$0```.V``0`O````_X`!`!L````O@0$`&P```$N!`0`'````9X$!
M``8```!O@0$`"````':!`0`,````?X$!``0```",@0$`"0```)&!`0`3````
MFX$!``L```"O@0$`$0```+N!`0`6````S8$!`!\```#D@0$`!P````2"`0`2
M````#((!``4````?@@$`%@```"6"`0`/````/((!``P```!,@@$`,0```%F"
M`0!"````BX(!``D```#.@@$`"````-B"`0`4````X8(!``4```#V@@$`!0``
M`/R"`0`(`````H,!`!`````+@P$`"P```!R#`0`9````*(,!`#L```!"@P$`
M$@```'Z#`0!&````D8,!`"\```#8@P$`-`````B$`0`N````/80!`"T```!L
MA`$`"0```)J$`0`(````I(0!``<```"MA`$`"@```+6$`0`)````P(0!`",`
M``#*A`$`-````.Z$`0`B````(X4!`$8```!&A0$`(0```(V%`0`A````KX4!
M`$,```#1A0$`0@```!6&`0`?````6(8!`$````!XA@$`)P```+F&`0`J````
MX88!`$,````,AP$`(0```%"'`0`G````<H<!`"P```":AP$`&@```,>'`0`>
M````XH<!`"H````!B`$`*P```"R(`0`K````6(@!`!@```"$B`$`$@```)V(
M`0`.````L(@!``H```"_B`$`!P```,J(`0`-````TH@!`!X```#@B`$`,```
M`/^(`0`(````,(D!``T````YB0$`'P```$>)`0`C````9XD!``<```"+B0$`
M!P```).)`0`5````FXD!``H```"QB0$`!@```+R)`0`&````PXD!``@```#*
MB0$`!@```-.)`0`I````VHD!``@````$B@$`"P````V*`0`'````&8H!``8`
M```AB@$`!0```"B*`0`'````+HH!``8````VB@$`"@```#V*`0`G````2(H!
M`!(```!PB@$`"````(.*`0`(````C(H!``X```"5B@$``P```*2*`0`'````
MJ(H!``D```"PB@$``P```+J*`0`)````OHH!``4```#(B@$`%P```,Z*`0`$
M````YHH!``@```#KB@$`!@```/2*`0`-````^XH!``D````)BP$`)P```!.+
M`0`$````.XL!``8```!`BP$`"0```$>+`0`*````48L!``P```!<BP$`#```
M`&F+`0`'````=HL!``,```!^BP$``P```(*+`0`7````AHL!``,```">BP$`
M%@```**+`0`D````N8L!``@```#>BP$`!0```.>+`0`(````[8L!``<```#V
MBP$`"@```/Z+`0!%````"8P!`!T```!/C`$`.````&V,`0`B````IHP!`!<`
M``#)C`$`!@```.&,`0`&````Z(P!`!4```#OC`$`%0````6-`0`?````&XT!
M`"L````[C0$`&@```&>-`0`C````@HT!`#$```"FC0$`"0```-B-`0`&````
MXHT!``@```#IC0$`%P```/*-`0`(````"HX!``X````3C@$`#````"*.`0`1
M````+XX!``X```!!C@$`$0```%".`0`.````8HX!``P```!QC@$`%0```'Z.
M`0`)````E(X!`!P```">C@$`'0```+N.`0`2````V8X!``\```#LC@$`$@``
M`/R.`0`%````#X\!``H````5CP$`!0```""/`0`3````)H\!`!<````ZCP$`
M50```%*/`0`]````J(\!`&(```#FCP$``P```$F0`0`3````39`!`"D```!A
MD`$`!0```(N0`0`$````D9`!`!P```"6D`$`'@```+.0`0`1````TI`!``T`
M``#DD`$`$0```/*0`0`,````!)$!`!L````1D0$`)````"V1`0!!````4I$!
M`"4```"4D0$`!0```+J1`0`>````P)$!``4```#?D0$`#@```.61`0`5````
M])$!``L````*D@$`$P```!:2`0`/````*I(!`!(````ZD@$`$P```$V2`0`8
M````89(!`!,```!ZD@$`#0```(Z2`0`$````G)(!``L```"AD@$`"````*V2
M`0`7````MI(!`!4```#.D@$`$@```.22`0`(````]Y(!``0`````DP$`#0``
M``63`0`'````$Y,!``D````;DP$`#P```"63`0`+````-9,!``@```!!DP$`
M#P```$J3`0`)````6I,!``0```!DDP$`!P```&F3`0`'````<9,!``@```!Y
MDP$`%0```(*3`0`'````F),!``4```"@DP$`!0```*:3`0`8````K),!`%``
M``#%DP$`(0```!:4`0`.````.)0!`!$```!'E`$`!0```%F4`0`%````7Y0!
M`!D```!EE`$`&@```'^4`0`L````FI0!`#0```#'E`$`*````/R4`0`)````
M)94!`"4````OE0$`(@```%65`0`/````>)4!``@```"(E0$`#````)&5`0`&
M````GI4!``<```"EE0$`&@```*V5`0`1````R)4!``H```#:E0$`"P```.65
M`0`*````\94!``\```#\E0$`(0````R6`0`B````+I8!`"````!1E@$`(0``
M`'*6`0`D````E)8!`",```"YE@$`'P```-V6`0`F````_98!`"$````DEP$`
M)````$:7`0`I````:Y<!`"4```"5EP$`'0```+N7`0`>````V9<!`"````#X
MEP$`&P```!F8`0`F````-9@!`"T```!<F`$`*P```(J8`0`B````MI@!`"L`
M``#9F`$`-P````69`0`=````/9D!`!T```!;F0$`&0```'F9`0`9````DYD!
M`#````"MF0$`(0```-Z9`0`2`````)H!`"$````3F@$`*````#6:`0`:````
M7IH!`!@```!YF@$`'@```)*:`0`1````L9H!`+8```##F@$`$@```'J;`0`<
M````C9L!`"4```"JFP$`)@```-";`0`@````]YL!`"0````8G`$`&@```#V<
M`0`:````6)P!`"0```!SG`$`)````)B<`0`K````O9P!`"P```#IG`$`)P``
M`!:=`0",````/IT!`!\```#+G0$`%0```.N=`0`5`````9X!`!X````7G@$`
M*0```#:>`0`I````8)X!`$0```"*G@$`1````,^>`0`+````%)\!``0````@
MGP$`!@```"6?`0`%````+)\!``H````RGP$`"````#V?`0`/````1I\!``8`
M``!6GP$`%@```%V?`0`1````=)\!``@```"&GP$`!````(^?`0`0````E)\!
M``\```"EGP$`"P```+6?`0`.````P9\!`!````#0GP$`#@```.&?`0`2````
M\)\!``P````#H`$`-@```!"@`0`(````1Z`!``L```!0H`$`!@```%R@`0`2
M````8Z`!`!@```!VH`$`&P```(^@`0`(````JZ`!``(```"TH`$`!@```+>@
M`0`2````OJ`!``X```#1H`$`!0```."@`0`.````YJ`!``@```#UH`$``P``
M`/Z@`0`.`````J$!``@````1H0$`"0```!JA`0`&````)*$!``T````KH0$`
M!P```#FA`0`,````0:$!`!$```!.H0$`&````&"A`0`,````>:$!`!L```"&
MH0$`&0```**A`0`,````O*$!`!$```#)H0$`"0```-NA`0`&````Y:$!``L`
M``#LH0$`$@```/BA`0`,````"Z(!``L````8H@$`$0```"2B`0`<````-J(!
M`!L```!3H@$`"P```&^B`0`-````>Z(!`!\```")H@$`%````*FB`0`:````
MOJ(!`#$```#9H@$`"@````NC`0`5````%J,!`!(````LHP$`%0```#^C`0`2
M````5:,!`!4```!HHP$`$0```'ZC`0`D````D*,!``L```"UHP$`!P```,&C
M`0`-````R:,!`"L```#7HP$`"`````.D`0`1````#*0!``L````>I`$`#```
M`"JD`0`B````-Z0!`"\```!:I`$`"@```(JD`0`)````E:0!`!X```"?I`$`
M"P```+ZD`0`;````RJ0!`!L```#FI`$`!P````*E`0`7````"J4!`!4````B
MI0$`'````#BE`0`7````5:4!``X```!MI0$`"@```'RE`0`(````AZ4!``L`
M``"0I0$`(@```)RE`0`D````OZ4!`#D```#DI0$`%P```!ZF`0`C````-J8!
M``4```!:I@$`"````&"F`0`M````::8!``H```"7I@$`!@```**F`0`&````
MJ:8!`%8```"PI@$``P````>G`0`'````"Z<!``4````3IP$`"@```!FG`0`+
M````)*<!``L````PIP$`$````#RG`0`0````3:<!`!(```!>IP$`&0```'&G
M`0`;````BZ<!`!@```"GIP$`&P```,"G`0`;````W*<!``H```#XIP$`!P``
M``.H`0`+````"Z@!``H````7J`$``@```"*H`0`&````):@!``P````LJ`$`
M)0```#FH`0`@````7Z@!`!8```"`J`$`#````)>H`0`.````I*@!`!````"S
MJ`$`#@```,2H`0`0````TZ@!``0```#DJ`$`!P```.FH`0`/````\:@!`"$`
M```!J0$`&````".I`0`#````/*D!`!T```!`J0$`+````%ZI`0`K````BZD!
M`!P```"WJ0$`*0```-2I`0`C````_JD!`!<````BJ@$`&@```#JJ`0`'````
M5:H!``@```!=J@$`!@```&:J`0`&````;:H!``X```!TJ@$`#@```(.J`0`/
M````DJH!``T```"BJ@$`$````+"J`0`/````P:H!``L```#1J@$`$@```-VJ
M`0`#````\*H!``D```#TJ@$`$@```/ZJ`0`.````$:L!`"\````@JP$`#0``
M`%"K`0`(````7JL!``D```!GJP$`%@```'&K`0`-````B*L!`"````"6JP$`
M"P```+>K`0`E````PZL!`"8```#IJP$`)0```!"L`0`C````-JP!`",```!:
MK`$`*P```'ZL`0`B````JJP!`!H```#-K`$``P```.BL`0`.````[*P!``@`
M``#[K`$`"P````2M`0`#````$*T!``4````4K0$`"````!JM`0`)````(ZT!
M``L````MK0$`#P```#FM`0`2````2:T!``H```!<K0$`#@```&>M`0`.````
M=JT!``0```"%K0$``P```(JM`0`3````CJT!`!4```"BK0$`#````+BM`0`'
M````Q:T!``8```#-K0$`#@```-2M`0`:````XZT!``8```#^K0$`!P````6N
M`0`-````#:X!``X````;K@$`%P```"JN`0`(````0JX!``,```!+K@$`)0``
M`$^N`0`-````=:X!`$X```"#K@$`%````-*N`0`(````YZX!``H```#PK@$`
M$0```/NN`0`*````#:\!``P````8KP$`!0```"6O`0`.````*Z\!``(````Z
MKP$`!0```#VO`0`)````0Z\!`!,```!-KP$`&@```&&O`0`3````?*\!`!@`
M``"0KP$`(````*FO`0`.````RJ\!`!(```#9KP$`&0```.RO`0`$````!K`!
M``D````+L`$`%P```!6P`0`(````+;`!`!$````VL`$`!0```$BP`0`8````
M3K`!``@```!GL`$`!@```'"P`0`6````=[`!`!T```".L`$`#0```*RP`0`(
M````NK`!``@```##L`$`!0```,RP`0`)````TK`!``<```#<L`$`%0```.2P
M`0`"````^K`!``8```#]L`$`#`````2Q`0`-````$;$!``@````?L0$`%```
M`"BQ`0`$````/;$!``@```!"L0$`!P```$NQ`0`#````4[$!`!,```!7L0$`
M/0```&NQ`0`F````J;$!`"D```#0L0$`!P```/JQ`0`$`````K(!``D````'
ML@$`"````!&R`0`0````&K(!`!,````KL@$`!P```#^R`0`&````1[(!``T`
M``!.L@$`!@```%RR`0`$````8[(!`#$```!HL@$`-@```)JR`0`S````T;(!
M`!H````%LP$`!0```""S`0`,````)K,!``4````SLP$`!@```#FS`0`(````
M0+,!`!@```!)LP$`$@```&*S`0`7````=;,!``0```"-LP$`#0```)*S`0`%
M````H+,!`!$```"FLP$`#0```+BS`0`(````QK,!`!<```#/LP$``P```.>S
M`0`$````Z[,!``,```#PLP$`"P```/2S`0`*`````+0!``P````+M`$`"```
M`!BT`0`)````(;0!``4````KM`$`/0```#&T`0`Q````;[0!`#\```"AM`$`
M'0```.&T`0!!````_[0!`#<```!!M0$`*````'FU`0`Y````HK4!`"X```#<
MM0$`,@````NV`0`A````/K8!`!$```!@M@$`%0```'*V`0`,````B+8!`"\`
M``"5M@$`)````,6V`0`D````ZK8!`",````/MP$`"0```#.W`0`*````/;<!
M``H```!(MP$`!@```%.W`0`E````6K<!`"8```"`MP$`,````*>W`0`)````
MV+<!`!X```#BMP$`*@````&X`0`:````++@!`!````!'N`$`!@```%BX`0`-
M````7[@!``T```!MN`$`#P```'NX`0`2````B[@!`#L```">N`$`D0```-JX
M`0!D````;+D!`!4```#1N0$`"@```.>Y`0`+````\KD!`!$```#^N0$`$@``
M`!"Z`0`.````([H!``8````RN@$`'P```#FZ`0`2````6;H!`"````!LN@$`
M%````(VZ`0`1````HKH!``@```"TN@$`$0```+VZ`0`D````S[H!`"H```#T
MN@$`;@```!^[`0`*````CKL!``8```"9NP$`%@```*"[`0`*````M[L!``0`
M``#"NP$`"P```,>[`0`G````T[L!`!0```#[NP$`"P```!"\`0`-````'+P!
M``\````JO`$`$P```#J\`0`E````3KP!`"0```!TO`$`'````)F\`0`>````
MMKP!`"$```#5O`$`(````/>\`0`6````&+T!`!$````OO0$`$````$&]`0`3
M````4KT!`!(```!FO0$`$@```'F]`0`5````C+T!`!0```"BO0$`$````+>]
M`0`/````R+T!`"D```#8O0$`$0````*^`0`1````%+X!`#L````FO@$`%```
M`&*^`0`&````=[X!``P```!^O@$`)P```(N^`0`A````L[X!`!8```#5O@$`
M%0```.R^`0`2`````K\!`!8````5OP$`'````"R_`0`3````2;\!`!4```!=
MOP$`&@```'._`0`8````CK\!`!T```"GOP$`(0```,6_`0`A````Y[\!`!4`
M```)P`$`%````!_``0`4````-,`!`!@```!)P`$`&@```&+``0`8````?<`!
M`!8```"6P`$`"P```*W``0`/````N<`!``0```#)P`$`!````,[``0`&````
MT\`!``L```#:P`$`$0```.;``0`&````^,`!``L```#_P`$`!@````O!`0`'
M````$L$!``<````:P0$`!P```"+!`0`%````*L$!`!4````PP0$`!@```$;!
M`0`)````3<$!``0```!7P0$`!````%S!`0`'````8<$!``T```!IP0$`#```
M`'?!`0`.````A,$!``P```"3P0$`!0```*#!`0`I````IL$!``T```#0P0$`
M"P```-[!`0`+````ZL$!``D```#VP0$`$`````#"`0`P````$<(!``0```!"
MP@$`"````$?"`0`%````4,(!``D```!6P@$`"````&#"`0`1````:<(!``8`
M``![P@$`"0```(+"`0`'````C,(!``4```"4P@$`!````)K"`0`,````G\(!
M``T```"LP@$`$0```+K"`0`/````S,(!`!(```#<P@$`%@```._"`0`>````
M!L,!`!H````EPP$`"````$##`0`(````2<,!``,```!2PP$`!@```%;#`0`E
M````7<,!``<```"#PP$`!P```(O#`0`-````D\,!``T```"APP$`!P```*_#
M`0`$````M\,!``<```"\PP$`!@```,3#`0`-````R\,!``<```#9PP$`"```
M`.'#`0`)````ZL,!`!,```#TPP$`%0````C$`0`-````'L0!`!(````LQ`$`
M"````#_$`0`,````2,0!``@```!5Q`$`!````%[$`0`0````8\0!`$(```!T
MQ`$`!@```+?$`0`$````OL0!`!\```##Q`$`#@```./$`0`/````\L0!``X`
M```"Q0$`#````!'%`0`)````'L4!``<````HQ0$`"@```##%`0`)````.\4!
M``X```!%Q0$`$````%3%`0`E````9<4!`"4```"+Q0$`(@```+'%`0`*````
MU,4!``<```#?Q0$`"0```.?%`0`+````\<4!``D```#]Q0$`!0````?&`0`(
M````#<8!``@````6Q@$`!0```!_&`0`0````)<8!`$X````VQ@$`&````(7&
M`0`)````GL8!``8```"HQ@$``P```*_&`0`0````L\8!`!````#$Q@$`%```
M`-7&`0`&````ZL8!``H```#QQ@$`"0```/S&`0`"````!L<!``0````)QP$`
M(P````['`0`#````,L<!``4````VQP$`"@```#S'`0`*````1\<!``8```!2
MQP$`!@```%G'`0`+````8,<!``T```!LQP$`!@```'K'`0`(````@<<!``H`
M``"*QP$`!````)7'`0`%````FL<!`'8```"@QP$`"P```!?(`0`.````(\@!
M`!<````RR`$`!````$K(`0`(````3\@!`!4```!8R`$`+P```&[(`0`-````
MGL@!``H```"LR`$`#@```+?(`0`+````QL@!``D```#2R`$`%````-S(`0`S
M````\<@!`"@````ER0$`)P```$[)`0`;````=LD!`!H```"2R0$`#0```*W)
M`0`#````N\D!``<```"_R0$`!P```,?)`0`+````S\D!`!````#;R0$`#@``
M`.S)`0`)````^\D!`!`````%R@$`&P```!;*`0`)````,LH!``\````\R@$`
M"0```$S*`0`/````5LH!``H```!FR@$`30```''*`0`>````O\H!``T```#>
MR@$`"@```.S*`0`A````]\H!`$P````9RP$`&0```&;+`0`%````@,L!`!\`
M``"&RP$`+@```*;+`0`'````U<L!``8```#=RP$`"P```.3+`0`&````\,L!
M``<```#WRP$`)P```/_+`0`F````)\P!`"H```!.S`$`!@```'G,`0`'````
M@,P!`"\```"(S`$`50```+C,`0`5````#LT!`"<````DS0$`$P```$S-`0`"
M````8,T!``P```!CS0$`"````'#-`0`,````><T!``H```"&S0$`"0```)'-
M`0`'````F\T!``D```"CS0$`!@```*W-`0`)````M,T!``P```"^S0$`"```
M`,O-`0`)````U,T!``@```#>S0$`,@```.?-`0`'````&LX!``\````BS@$`
M$0```#+.`0`0````1,X!``H```!5S@$`#@```&#.`0`,````;\X!``H```!\
MS@$`"@```(?.`0`*````DLX!``H```"=S@$`!P```*C.`0`.````L,X!`!P`
M``"_S@$`!P```-S.`0`*````Y,X!`!0```#OS@$`$0````3/`0`*````%L\!
M`!`````ASP$`!P```#+/`0`8````.L\!``0```!3SP$`!P```%C/`0`%````
M8,\!``0```!FSP$`#@```&O/`0`%````>L\!``T```"`SP$`%P```([/`0`/
M````IL\!`!8```"VSP$`&0```,W/`0`7````Y\\!`!P```#_SP$`%@```!S0
M`0`'````,]`!``8````[T`$`#@```$+0`0`+````4=`!`!<```!=T`$`!@``
M`'70`0`-````?-`!`!P```"*T`$`"P```*?0`0`-````L]`!`"(```#!T`$`
M&@```.30`0`5````_]`!``<````5T0$`#0```!W1`0`%````*]$!`!`````Q
MT0$`$P```$+1`0`&````5M$!``D```!=T0$`!0```&?1`0`'````;=$!``0`
M``!UT0$`!````'K1`0`#````?]$!`#L```"#T0$`,P```+_1`0`2````\]$!
M`"\````&T@$`,@```#;2`0`.````:=(!`#P```!XT@$`+P```+72`0`T````
MY=(!`#0````:TP$`.````$_3`0`2````B-,!`!,```";TP$`&````*_3`0`3
M````R-,!`!T```#<TP$`%0```/K3`0`2````$-0!`!(````CU`$`&P```#;4
M`0`3````4M0!`"X```!FU`$`$0```)74`0`I````I]0!`!H```#1U`$`%0``
M`.S4`0`:`````M4!`"X````=U0$`+@```$S5`0`R````>]4!`"\```"NU0$`
M,````-[5`0`M````#]8!`!T````]U@$`$P```%O6`0`4````;]8!``L```"$
MU@$`&0```)#6`0`*````JM8!``\```"UU@$`+````,76`0`N````\M8!`"(`
M```AUP$`"P```$37`0!5````4-<!`$8```"FUP$`"P```.W7`0`.````^=<!
M``4````(V`$`'`````[8`0`,````*]@!`!`````XV`$`$@```$G8`0`%````
M7-@!``H```!BV`$`"0```&W8`0`/````=]@!`!$```"'V`$`"@```)G8`0`+
M````I-@!`!,```"PV`$`$P```,38`0`1````V-@!``\```#JV`$`$````/K8
M`0`2````"]D!`!$````>V0$`%@```##9`0`0````1]D!`",```!8V0$`#```
M`'S9`0`5````B=D!`"````"?V0$``P```,#9`0`(````Q-D!``8```#-V0$`
M#````-39`0`.````X=D!``L```#PV0$`0@```/S9`0`"````/]H!``8```!"
MV@$`#0```$G:`0`%````5]H!``<```!=V@$`&0```&7:`0`&````?]H!`"X`
M``"&V@$`$````+7:`0`=````QMH!``0```#DV@$`*@```.G:`0`<````%-L!
M`"`````QVP$`60```%+;`0`4````K-L!`$<```#!VP$`&0````G<`0`.````
M(]P!`!P````RW`$`#0```$_<`0`4````7=P!``X```!RW`$`#````('<`0`2
M````CMP!``H```"AW`$`'````*S<`0`9````R=P!``4```#CW`$`$P```.G<
M`0`0````_=P!`"8````.W0$`$P```#7=`0`5````2=T!`!(```!?W0$`$0``
M`'+=`0`9````A-T!``<```">W0$`"````*;=`0`3````K]T!``X```##W0$`
M$@```-+=`0`/````Y=T!`!H```#UW0$`#P```!#>`0`:````(-X!`!0````[
MW@$`"0```%#>`0`*````6MX!``@```!EW@$`!0```&[>`0`)````=-X!``8`
M``!^W@$`$````(7>`0`(````EMX!``X```"?W@$`"````*[>`0`2````M]X!
M`!(```#*W@$`*````-W>`0`8````!M\!``D````?WP$`"@```"G?`0`9````
M--\!``H```!.WP$`(@```%G?`0`&````?-\!`!@```"#WP$`"0```)S?`0`'
M````IM\!`!H```"NWP$`*P```,G?`0`*````]=\!`!\`````X`$`#0```"#@
M`0`,````+N`!`!D````[X`$`%0```%7@`0`$````:^`!``<```!PX`$`#```
M`'C@`0`'````A>`!``4```"-X`$`"````)/@`0`&````G.`!``@```"CX`$`
M&````*S@`0`F````Q>`!`"T```#LX`$`&@```!KA`0`@````->$!`!\```!6
MX0$`1````';A`0`<````N^$!`!T```#8X0$`)````/;A`0!;````&^(!`%L`
M``!WX@$`2@```-/B`0`B````'N,!`!<```!!XP$`!0```%GC`0`'````7^,!
M``X```!GXP$`"````';C`0`7````?^,!`!D```"7XP$`+@```+'C`0`(````
MX.,!`"(```#IXP$`&`````SD`0`?````)>0!`#L```!%Y`$`!0```('D`0`5
M````A^0!``L```"=Y`$`#P```*GD`0`C````N>0!`!@```#=Y`$`$0```/;D
M`0`.````".4!``<````7Y0$`$@```!_E`0`'````,N4!``0````ZY0$`#0``
M`#_E`0`5````3>4!`!@```!CY0$`+P```'SE`0`+````K.4!`!$```"XY0$`
M!0```,KE`0`%````T.4!``4```#6Y0$`'````-SE`0`+````^>4!``0````%
MY@$`"P````KF`0`)````%N8!``H````@Y@$`#````"OF`0`-````..8!`!<`
M``!&Y@$`"P```%[F`0`#````:N8!``\```!NY@$`.0```'[F`0`8````N.8!
M`$H```#1Y@$`'````!SG`0`)````.><!`"````!#YP$`#P```&3G`0`3````
M=.<!``4```"(YP$`$0```([G`0`(````H.<!``L```"IYP$`)P```+7G`0`,
M````W><!`",```#JYP$`!P````[H`0`-````%N@!``\````DZ`$`#@```#3H
M`0`3````0^@!`!D```!7Z`$`"P```''H`0`S````?>@!``<```"QZ`$`(```
M`+GH`0`1````VN@!`!4```#LZ`$`#0````+I`0`<````$.D!`$$````MZ0$`
M,P```&_I`0`(````H^D!`#````"LZ0$`+````-WI`0`V````"NH!`#<```!!
MZ@$`,````'GJ`0`3````JNH!`!8```"^Z@$`"0```-7J`0`2````W^H!`!(`
M``#RZ@$`&`````7K`0`(````'NL!`!L````GZP$`$@```$/K`0`'````5NL!
M`!<```!>ZP$`(@```';K`0`%````F>L!``4```"?ZP$`"P```*7K`0`+````
ML>L!`!0```"]ZP$`!````-+K`0`(````U^L!``H```#@ZP$`#@```.OK`0`,
M````^NL!`!`````'[`$`$````!CL`0`&````*>P!``8````P[`$`*P```#?L
M`0`C````8^P!`"````"'[`$``P```*CL`0`(````K.P!``8```"U[`$`#P``
M`+SL`0`;````S.P!`"<```#H[`$`#P```!#M`0`(````(.T!`"$````I[0$`
M`P```$OM`0`&````3^T!``D```!6[0$``@```&#M`0`,````8^T!`!4```!P
M[0$`"P```(;M`0`9````DNT!`!X```"L[0$`$0```,OM`0`%````W>T!``H`
M``#C[0$`%0```.[M`0`2````!.X!``P````7[@$`!0```"3N`0`*````*NX!
M``@````U[@$`$P```#[N`0!,````4NX!`!T```"?[@$`)0```+WN`0`1````
MX^X!``D```#U[@$``P```/_N`0`*`````^\!``L````.[P$`$0```!KO`0`)
M````+.\!``H````V[P$`#@```$'O`0`9````4.\!``T```!J[P$`&0```'CO
M`0`+````DN\!`!T```">[P$`"0```+SO`0`6````QN\!``\```#=[P$`"@``
M`.WO`0`?````^.\!`&`````8\`$`&@```'GP`0`1````E/`!`!(```"F\`$`
M'@```+GP`0`;````V/`!`!T```#T\`$`&````!+Q`0`0````*_$!`!@````\
M\0$`%0```%7Q`0`9````:_$!`!$```"%\0$`'````)?Q`0`5````M/$!``H`
M``#*\0$`!P```-7Q`0`(````W?$!``D```#F\0$`%@```/#Q`0`+````!_(!
M`#,````3\@$`%@```$?R`0`8````7O(!``D```!W\@$`!````('R`0!)````
MAO(!`#X```#0\@$`.0````_S`0!;````2?,!``4```"E\P$`-````*OS`0`E
M````X/,!``P````&]`$`!@```!/T`0`.````&O0!`#8````I]`$`!````&#T
M`0`6````9?0!`!<```!\]`$`3````)3T`0`K````X?0!`!X````-]0$`)@``
M`"SU`0`I````4_4!``L```!]]0$`(0```(GU`0`>````J_4!`!<```#*]0$`
M$P```.+U`0`3````]O4!`"(````*]@$`$````"WV`0`&````/O8!``T```!%
M]@$`"P```%/V`0`1````7_8!``D```!Q]@$`+P```'OV`0`,````J_8!``H`
M``"X]@$`"````,/V`0`0````S/8!``<```#=]@$`"0```.7V`0`'````[_8!
M`!````#W]@$`"0````CW`0`)````$O<!``,````<]P$`!P```"#W`0`)````
M*/<!`!`````R]P$`#@```$/W`0`)````4O<!`!H```!<]P$`#````'?W`0`'
M````A/<!`!$```",]P$`$P```)[W`0`:````LO<!`!8```#-]P$`"@```.3W
M`0`)````[_<!`"(```#Y]P$`$````!SX`0`C````+?@!`"L```!1^`$`"0``
M`'WX`0`)````A_@!`!<```"1^`$`!P```*GX`0`$````L?@!`!T```"V^`$`
M"0```-3X`0`+````WO@!``@```#J^`$`!P```//X`0`)````^_@!``@````%
M^0$`"0````[Y`0`%````&/D!``<````>^0$`$0```";Y`0`&````./D!``X`
M```_^0$`"@```$[Y`0`,````6?D!``L```!F^0$`&P```'+Y`0`*````COD!
M``(```"9^0$`(0```)SY`0`&````OOD!``8```#%^0$`<P```,SY`0`(````
M0/H!``8```!)^@$`&P```%#Z`0`G````;/H!``\```"4^@$`'0```*3Z`0!(
M````POH!``X````+^P$`'````!K[`0`?````-_L!`!(```!7^P$`"````&K[
M`0`%````<_L!``\```!Y^P$`"@```(G[`0`*````E/L!``8```"?^P$`"@``
M`*;[`0`2````L?L!``P```#$^P$`"@```-'[`0`,````W/L!``<```#I^P$`
M!P```/'[`0`(````^?L!``D````"_`$`%@````S\`0`)````(_P!``<````M
M_`$`!P```#7\`0`:````/?P!``8```!8_`$`%P```%_\`0`&````=_P!``<`
M``!^_`$`%0```(;\`0`)````G/P!`!````"F_`$`!P```+?\`0`&````O_P!
M`!,```#&_`$`$0```-K\`0`3````[/P!``8`````_0$`!@````?]`0`*````
M#OT!``@````9_0$`!````"+]`0`)````)_T!``0````Q_0$`#0```#;]`0`B
M````1/T!``H```!G_0$`#````'+]`0`I````?_T!`!<```"I_0$`%@```,']
M`0`;````V/T!`!8```#T_0$`!`````O^`0`+````$/X!``T````<_@$`!P``
M`"K^`0`"````,OX!``X````U_@$`"````$3^`0`B````3?X!`!\```!P_@$`
M(P```)#^`0`@````M/X!`#4```#5_@$`(0````O_`0`G````+?\!`"L```!5
M_P$`9````('_`0`2````YO\!`"$```#Y_P$`/@```!L``@`C````6@`"`$\`
M``!^``(`2````,X``@`F````%P$"`#\````^`0(`(0```'X!`@`O````H`$"
M`"X```#0`0(`)P```/\!`@`G````)P("`"$```!/`@(`-@```'$"`@`;````
MJ`("`!$```#$`@(`%@```-8"`@!+````[0("`'`````Y`P(`.````*H#`@`7
M````XP,"`"L```#[`P(`(0```"<$`@`B````200"`"````!L!`(`*@```(T$
M`@`U````N`0"`&(```#N!`(`5````%$%`@`K````I@4"`!P```#2!0(`#P``
M`.\%`@`A````_P4"`!8````A!@(`%0```#@&`@`M````3@8"`!P```!\!@(`
M&P```)D&`@`M````M08"`!T```#C!@(`/0````$'`@`9````/P<"``T```!9
M!P(`+@```&<'`@`G````E@<"`#8```"^!P(`*0```/4'`@`<````'P@"`"``
M```\"`(`-@```%T(`@!0````E`@"`#$```#E"`(`0P```!<)`@`L````6PD"
M`",```"("0(`-P```*P)`@!C````Y`D"`$P```!("@(`,P```)4*`@`>````
MR0H"`"<```#H"@(`(````!`+`@`A````,0L"`"````!3"P(`'0```'0+`@`T
M````D@L"`%\```#'"P(`40```"<,`@`S````>0P"`#(```"M#`(`/````.`,
M`@`_````'0T"`"\```!=#0(`'@```(T-`@`J````K`T"`!H```#7#0(`*```
M`/(-`@`M````&PX"`"T```!)#@(`%0```'<.`@"#````C0X"`'<````1#P(`
M@````(D/`@#(````"A`"`!D```#3$`(`(P```.T0`@`N````$1$"`"<```!`
M$0(`1P```&@1`@`B````L!$"`%````#3$0(`%P```"02`@`D````/!("``X`
M``!A$@(`00```'`2`@`D````LA("`"X```#7$@(`)P````83`@`D````+A,"
M`#H```!3$P(`!````(X3`@`'````DQ,"``,```";$P(`#P```)\3`@`*````
MKQ,"``<```"Z$P(`"````,(3`@`&````RQ,"`!$```#2$P(`!````.03`@!;
M````Z1,"``0```!%%`(`#P```$H4`@`$````6A0"``<```!?%`(`!P```&<4
M`@`%````;Q0"``,```!U%`(`$````'D4`@`.````BA0"`!,```"9%`(`$0``
M`*T4`@`"````OQ0"``@```#"%`(`!P```,L4`@`4````TQ0"``P```#H%`(`
M%@```/44`@`&````#!4"``\````3%0(`"@```",5`@`#````+A4"`"@````R
M%0(`!````%L5`@`&````8!4"``<```!G%0(`%P```&\5`@!(````AQ4"`"D`
M``#0%0(`+````/H5`@`7````)Q8"`"4````_%@(`)@```&46`@`I````C!8"
M`!T```"V%@(`&@```-06`@`9````[Q8"`!L````)%P(`&````"47`@`7````
M/A<"`!T```!6%P(`&P```'07`@`8````D!<"`"<```"I%P(`&@```-$7`@`8
M````[!<"`"<````%&`(`(P```"T8`@`9````41@"`!T```!K&`(`&P```(D8
M`@`8````I1@"`!X```"^&`(`(@```-T8`@`=`````!D"`"8````>&0(`(@``
M`$49`@`8````:!D"`!H```"!&0(`)0```)P9`@`7````PAD"`"$```#:&0(`
M,````/P9`@`S````+1H"`!,```!A&@(`)@```'4:`@`^````G!H"`!\```#;
M&@(`(P```/L:`@`A````'QL"`"0```!!&P(`'@```&8;`@`8````A1L"`"$`
M``">&P(`(````,`;`@`S````X1L"`"(````5'`(`-P```#@<`@`,````<!P"
M``\```!]'`(`#P```(T<`@`9````G1P"`"D```"W'`(`'P```.$<`@`0````
M`1T"`"(````2'0(`#P```#4=`@`5````11T"``X```!;'0(`$````&H=`@`;
M````>QT"``<```"7'0(`!0```)\=`@`I````I1T"`"0```#/'0(`%P```/0=
M`@`B````#!X"`"0````O'@(`!P```%0>`@#4````7!X"``P````Q'P(`&P``
M`#X?`@`4````6A\"``D```!O'P(`#````'D?`@`<````AA\"`!,```"C'P(`
M$0```+<?`@`;````R1\"``D```#E'P(`,@```.\?`@`(````(B`"`!`````K
M(`(`!P```#P@`@`2````1"`"``H```!7(`(`-@```&(@`@`)````F2`"`"0`
M``"C(`(`%@```,@@`@`5````WR`"`!0```#U(`(`)@````HA`@`<````,2$"
M``P```!.(0(`'````%LA`@`-````>"$"``X```"&(0(`%0```)4A`@`*````
MJR$"`!@```"V(0(`"````,\A`@`I````V"$"``D````"(@(`#P````PB`@`J
M````'"("``8```!'(@(`%0```$XB`@`'````9"("``@```!L(@(`"0```'4B
M`@`[````?R("``<```"[(@(`$````,,B`@`2````U"("`!(```#G(@(`"0``
M`/HB`@`+````!","``<````0(P(`%0```!@C`@`'````+B,"`!<````V(P(`
M"P```$XC`@`-````6B,"``P```!H(P(`%P```'4C`@`9````C2,"``0```"G
M(P(`!0```*PC`@`9````LB,"``0```#,(P(`+````-$C`@`,````_B,"`!$`
M```+)`(`!P```!TD`@`"````)20"``P````H)`(`#@```#4D`@`+````1"0"
M``0```!0)`(`"0```%4D`@`3````7R0"`!8```!S)`(`"````(HD`@`)````
MDR0"`!$```"=)`(`#0```*\D`@`9````O20"`!H```#7)`(`#0```/(D`@`R
M`````"4"`!X````S)0(`(P```%(E`@`7````=B4"`#P```".)0(`"P```,LE
M`@`S````UR4"``4````+)@(`$0```!$F`@!"````(R8"``L```!F)@(`"@``
M`'(F`@`&````?28"``0```"$)@(`!````(DF`@`*````CB8"`!0```"9)@(`
M!0```*XF`@`&````M"8"``8```"[)@(`"@```,(F`@`&````S28"``X```#4
M)@(`#P```.,F`@`T````\R8"`"H````H)P(`)P```%,G`@`%````>R<"`!X`
M``"!)P(`#@```*`G`@`"````KR<"``0```"R)P(`"@```+<G`@`%````PB<"
M``4```#()P(``@```,XG`@`1````T2<"`$,```#C)P(`+@```"<H`@`Y````
M5B@"`!@```"0*`(`(P```*DH`@`C````S2@"`"8```#Q*`(`,P```!@I`@`/
M````3"D"`%X```!<*0(`(````+LI`@!'````W"D"`"0````D*@(`00```$DJ
M`@`H````BRH"`#4```"T*@(`*@```.HJ`@`P````%2L"`#$```!&*P(`-0``
M`'@K`@`T````KBL"`"H```#C*P(`)`````XL`@`J````,RP"`#(```!>+`(`
M$````)$L`@`1````HBP"``\```"T+`(`;````,0L`@`)````,2T"`*D````[
M+0(`7P```.4M`@!W````12X"`"X```"]+@(`6````.PN`@`5````12\"`",`
M``!;+P(`%P```'\O`@`?````ER\"`!<```"W+P(`&P```,\O`@`?````ZR\"
M`!8````+,`(`.0```"(P`@`C````7#`"`",```"`,`(`6````*0P`@`:````
M_3`"`!(````8,0(`"P```"LQ`@`%````-S$"``8````],0(`"````$0Q`@`%
M````33$"`!(```!3,0(`#````&8Q`@`4````<S$"`!X```"(,0(`#@```*<Q
M`@`/````MC$"`!\```#&,0(`!````.8Q`@`)````ZS$"``D```#U,0(`!P``
M`/\Q`@`+````!S("``4````3,@(`#0```!DR`@`(````)S("``8````P,@(`
M%0```#<R`@`.````33("`!,```!<,@(`"0```'`R`@`)````>C("``X```"$
M,@(`%@```),R`@`.````JC("``X```"Y,@(`#0```,@R`@`)````UC("`!``
M``#@,@(`!````/$R`@`&````]C("`!<```#],@(`"@```!4S`@`)````(#,"
M``\````J,P(`"````#HS`@`%````0S,"`!0```!),P(`%0```%XS`@`*````
M=#,"``8```!_,P(`#P```(8S`@`1````EC,"`!@```"H,P(`#0```,$S`@`%
M````SS,"`!@```#5,P(`"````.XS`@`#````]S,"`!D```#[,P(`"0```!4T
M`@`"````'S0"``(````B-`(`#P```"4T`@`&````-30"``8````\-`(`#P``
M`$,T`@`7````4S0"``8```!K-`(`%@```'(T`@`"````B30"``0```",-`(`
M$@```)$T`@`2````I#0"`!````"W-`(`$````,@T`@`'````V30"``T```#A
M-`(`!@```.\T`@`,````]C0"``@````#-0(`&@````PU`@`/````)S4"`!(`
M```W-0(``@```$HU`@`'````334"``D```!5-0(`#0```%\U`@`/````;34"
M`"L```!]-0(`!````*DU`@`'````KC4"``L```"V-0(`!0```,(U`@`%````
MR#4"``(```#.-0(`"P```-$U`@`!````'@0``!\$````````[@<``#\&``#0
M!@```````#D%````````4`4``!\&``#C!@```````,8`````````````````
M``#S!P``I@0``'H'``",!```X@```#@#```_`P``R@<``&`#``#4!```````
M``````!4`P``,P8``+L&````````W0,``%0%````````.0@``)('````````
M&P8```4&``"X````<P<`````````````4@4```````#%`@``IP$``$0%````
M`````````(@```#0!````````#('``!X!@``N`(```````#S!@``!0```",&
M````````HP4``(<#``"[`P``]@(````````N`@``.@@```````#3!@``)0$`
M`(`!````````=0(```````#7!P``E`0``$T!``#+!@``JP```)P"```H````
M`````(L!``":!`````@``%X&``!)```````````````F`P```````!$&``#A
M````[P<``.4#```H"```B08``#L"``"(!P``U0```$D(``#*`P``[```````
M``!Y`P``<P,````````"``````````````!."```U@(``!,```!-`@``5`(`
M`!`"``#7!@````````````!G````L`4``#8````/!0``3P$``#P$``!<!```
MBP4`````````````A`,````````N"```U`$```````#N`@``>P8``!\%```\
M````?`$``(0$``"Z``````<```@&``!I!P```````$\'``#R`@``?`4`````
M``#7!```"@0``,0&```&`P``]0```"$&``#P`@``E@0``!D```"+`P``A```
M`.\````]!P``E`4``"$%``!`"```OP(```````!$`P``WP4``-D!``!7!@``
ML@```,8'````````W0$```````#G`0``I0```,X%````````S00`````````
M````TP<``````````````````'`#```<````*P@``%`&``"/!P``3`(``-<"
M``#-`@``7P```*X!````````90<``%8#````````GP0```````!5````"`<`
M`/('``#?````EP4``.H$````````,P<`````````````F0````````#5!```
MW04``/D```!2`@``C`8``/4%```9`P``?P4`````````````.`0``&D&````
M`````````#(%``!Z`````````$$(```;"```F04``%X"`````````````'8$
M`````````````*0'``!6!```=04``#8"``"S!P``KP,```````!X`@``````
M`.4&``!G!P````````T%````````*@0``.,!````````S@,````````O````
M;@```-$"``!2!P``````````````````%@4`````````````>P(``&`'``#T
M!```=`$``"X%``!*!0```````%8"``"@`0``.@````````";`0``MP<``#H!
M```L!@```````)`#```V"```%08``(L'``#Z!````````"$$```N!```(`0`
M``````#:`P``,`$``.@```!/!0````````````"\`P``*P```$,&```M"```
M\08``)4"`````````````,8!``!D`@``9@,```````#K`0```````-,"``!E
M`P```````)@&```'!0``9P0``.8&``"0!0```````%H"```C`@``-@$``&$"
M``#<!0``J@$```````##`0```````*X&````````"0<```0(``#N`0``QP0`
M````````````&`8``$<"```Y!````````````````````````+,$``!F!0``
MR@(``"4(``#6!```(@,``!8$``#B!@```````%<%``!8!P``/P(``&H$``#D
M`0```````'L$``!H!0``00```%(#``!R!0``N00``$D'````````EP$``+L!
M``"'````R@8``"T&``!;`@``608```<```"=!```=08``"8%```P!P``]P$`
M`#T(```-!````````+P&``#&!@``H08````````]`P``T08``.,````B!0``
MT`(`````````````U0,```8$``#_`P``4P`````````\!@``N0$``!0%```^
M`P``K0,```````"%!P```0<```````!(!0```````)\!``!(`0``90(``$X#
M``!E!0```````/,"````````@@,``)H!```;`0````````````#"!@``I`,`
M`/D'``"G`````@$`````````````,P,``#L(``!+!0``M0```+D```"/````
M#P$```,&``!B!0``(P```'L%``"1!0``#`8``"0'``"*`P``Q0$``/X&``#?
M!```D08``(4````_`````````/D$``#^`0``W````,(#```P!0``;`,``%`$
M``"Y!@``,00``(\%``#O!```_`8``/L#`````````````!X&``#0````!P@`
M````````````A@<``,L`````````%P$``!4"`````````````&`&```&`0``
M/P0``!$$``!/`P``Z08```\#````````E@4`````````````=P```.4%````
M````,P$```````#4!@``A0$```````";`@``JP(``#,(```9`0``FP4`````
M````````O08``#H&```[`0``C0```$(#``!N!```]`,```````"L`@``T0$`
M`.\%``#9!0``+P@``````````````````.`%```A`P``FP8``.<$``!$````
M6`$``*<#```J!P``N`<``+<"````````&P<``(<&`````````````,4```#>
M`P``&P(``&`!``"`!```:@(``)D"``#:!0``K08``*8%``#2`@```````.P#
M``"C!```6@,``(0!`````````````/$%```4!P```````/4!```1!0``,04`
M`%$!````````5P<```````"_!@```````%4(``"X`0``)`8``*\'```R!```
M$`<```````#F!P``-`8``((&```,`0``]P,``&4&``#^!```^@,``"(!``"I
M!@``O0```/P#``!Z!@```````````````````````+4'``!^`@``X@$`````
M``"#!0```````*($`````````````+<$``"S!0``C`,``"$"```%`0``(`<`
M```````$!@``R0```$X&```5!``````````````Z`@``^@8``'L!````````
MDP0``)8&``#D`P``'P,`````````````9P(``/T%``#8!0`````````````3
M`P``]@````````".!@``60(``-8#``!"!@``I`0``#@(``!D!0```````*L%
M````````8@8```D!````````]@8```````"E`P``#@4``%8```"H`@``````
M`-`'```U!P``B04``.`#``!=!0``A04``+T#`````````````(8&````````
MH@```.D!``!J!@``?0(`````````````C0<```````"[!0``O0(``-T'````
M``````````````",````M@<``%($```="```308````````1!P```````#L&
M``!+`@``Y````-$%````````(P@``(P'`````````````"D!``!'````7`(`
M`"@#``!0````60,``*4&``"=````J0<````````R`0```````.P!````````
M;P4``.<````^!@``B`0``&H%````````"P(``````````````````/<"```5
M!0``DP$``+4%````````Y@,```````"\!0``508``````````````````&X!
M``#]!@``P@$``'T!``#M`P``=P4``!H$``#(````4`$``!(!``#>`0``_`0`
M`#(#``!P`0``_P(``+H#````````R`4``"<```!M!@``\P0``%<!``"@`@``
M2`@``(D!````````^````%D!`````````````+H&````````@`4``+$&``!C
M`0``N`,``/$!``"Q`P``)P$```````"R`0``?`0``&0#````````-````(\#
M``"S!@````````````#@!```ZP0``-,`````````HP```*(!```4`0``````
M`,$$``!V!0``)@@``($$```*"```D`(```````"*!```A0(``!L`````````
M9P4``'<$``"]`0``_P0`````````````@`,``&L#``#T!0``?0,``,$`````
M`````````$X%`````````````,X'``!Z!0``X04``),"``#3`P``&0@``,`"
M```B!```S0,``,0$```R`@``L@4``$,!`````````````'0%``""!```````
M`$\"``#(`P``S`8``.D```!8!```5@$``,T!``"\!P``9@<``#@!```8`P``
M`````&8&````````0`0```````#_`0``2`0``#<"``"N`P``H0(````````F
M!@```````+P```#$!P``L`<``$\(``#N````C0$``'<'````````X0$``!`(
M``##`P``Q04````````C!```)P(``$,%``#'!0``S`<`````````````5P``
M```#``!8`@``H@<``&,$``!$`@``,0``````````````C@`````````@`P``
M2@0``&<!```>`@``IP0``"8"````````E`<``/@"````````#`(`````````
M``````````````"B`P``K`0```T"``"W`0``,P4``*L!``"7!```L@8``*H"
M````````8@,````````\`P``$@<```````#/!```(`4``-H```!C!0``````
M`"@'````````.0$``!H`````````#`,```````!)!@``*`$``)8!``"_`0``
MGP(``(,'```=!`````````````!2!@``?P````````#Z`@``E@`````%```M
M!P```@0``/@'```/`````````%@#```Q`0``)0``````````````TP0`````
M``!&````K@<``)$```#5`@```````$(`````````]P8```@(```0!```X```
M`$H"````````H`8``.@&``!T!@``3@<``(P%```]`0``)P4``+H%``!&!P``
M`````.H!```*`````````%8'```*`@```````,X!````````N@(``",#``!B
M!P``*P$```````";!````````-0#````````W@(``($!````````$@0``'H#
M```"`@``\`,``(H!```^!```\`0```````"B!0``T00```````!-`P``+P<`
M````````````)`(``'T'```8`0``$P8```````#:`0``G@````P%````````
MI@,``.(#````````6P,``,P#```Y!P``6@8``(````!$!```+00`````````
M````6@```)@'``"+!````````)`````""```U@8``/D%````````;P<``!`&
M``#%!P``+@<``!0(``!V!@```````-8```#Y`P``````````````````````
M````````````F0$``"P!````````$0,````````-!@``?P0``+\%````````
M`````,`!``!``0``B@8``+8!```3`0```````)0#``````````````````#M
M`````````*H&``"&!`````````````!Y!0```````+L````"`P``RP4```$#
M````````+`<``*$$``!1`P``:0(``$(%``!R!@``QP<``$0'``"P````````
M`'T%````````_0```)X&``#N`P``Y0$``'@'``!_`P``90$``$@'``"?````
M/P@``%(```#!`@```````*,!``#;`P``)`@``&0&```=!P```````)X'``"R
M!P``6P0``$H```!3`0```````/4"``#\!0``*0@```````#4`@``````````
M````````Y@(``(X#`````````````#\%`````````````.H%``":`@``:P<`
M`-P#````````WP$```````#M`0``]00```````!#`P``]P0````````@`@``
M,@8````````<`0``&04```4'``";`P````````````"O`0``-`@``#,$```L
M!0``&@4``)T'````````*@```!@(``#-!0``(P4```````!P!0``F08`````
M``#F````B`4``/H%``"E!```%@```)T#``!)!```4@$``*D"````````W@8`
M```````J`P``S`$``-@"`````````````),%````````1P$``"\%````````
M`````*T`````````^`$``$4$```W`P``Y0<``'P``````````````+,!````
M```````````````0`P``\P```!P&```W!@``+`@``$4'````````8P,``-@`
M``!\!P``8````"D```!&!````````+\$```(!```?`8``!T!``!)`0``-`(`
M``$!`````````````!("``!=!@``>P```)(```#5!P```````/X#````````
MC@$``$,$``!U!P```````#$"``#+`0``"0(``!L$``#:`@``````````````
M````/P$``$(!``"6!P``-@8``'``````````;0,``"8'``!-"```````````
M```I!P``'P```!`%``".!```R@$```````"8`@``]`(`````````````B0(`
M`'\"``">`@``)````&\```"H`P``CP$``!,(``!H!@``#@8``'$"``#2````
M]P4```````#:!```5````-8!``!9!0`````````````2"```;0```!D$```X
M!@``Y0```$`"``!4!@````````````#,`@``(@@``*P`````````8P(``)P#
M``#G`@``%P4``$@&``"'!````````+`"```O!```'0(```L(````````!00`
M``````!Z`0``P0,``/T$``!W`P``40(```````!H!P``-@0``!H"``"+````
MP@0``#4%```E!0``Q@4```T'``!X`P```````*X"``##!P```````*D```#.
M`@``^@```#X%``!O!```,`0```<!``!-````E`$``'D$``!X````!P(```4%
M````````AP<``((```!,!P````````(&````````"08``"\&``!L!P``M@0`
M`-X%``"<`0``R0(``'X'````````"`````````!O`0``J`$``%D'``#V`0``
MK`,```````#-!P``<`0``-(#``"^!```_0(```````">!0``%`0``#0#```V
M`P````````````#<`0``$0(``%0$````````:P(`````````````&P4```0$
M``````````````````!I`````````.H'```(!0``E08``!X!````````R00`
M`.T%```(`0``H`4```````#]`P``O@```/D"````````H@8```D#``#V!0``
M`````(,!``"7`@``;`0```````"2`@```````$0&``##`@```````%4!``#@
M!P``+`,``(8%````````9`$``#L%``````````````````!B!```VP$``)<`
M``#?`P````````H!``#G!0```@<``(,#````````+@$``%\$``"<!0``````
M`#<``````````````!H(```H!```J@````,$`````````````)`$```6`P``
MW0(``$<(```M````C08``"4&``"T`0``-08``,D!``!<`0``````````````
M````>0$``)D'``!*"```>08``&T'``!Y````RP,````````X!P``L0```+L"
M``#I`P``>P<``````````````````.8$````````$P0``!@"``!8!@``\`$`
M```````7!@````8``!X'``!6"```=0$``$L$```E`P``G@$``-(&````````
M``````<'``#(`@``N`0```````#I!```$@,``$L'``";!P``6````'8#````
M`````P@``.<&````````C@(``-\"``"8!0``:00``-8%``#C`P``Q0,``.T&
M``#U`P``QP(``*<&``#X`P``6P```````````````````"`&``!5`P``:`0`
M`%\!```6"```=@$```````!>!0``ZP```(T"````````V@<````````Y````
M_P<```0"``!C````"00```````"6`@```````.`!``#!`0``!`4``+$'``![
M`P```````)H%``"E!P``*P,``*D!````````2P@`````````````%P``````
M`````````````)@!``#Q!P``=P8``#H#``!V!P```````+T'```8!0``1P4`
M`"H"``````````````````#[!````````.L"`````````````"8```"I`P``
M`````#0%```\!0``7P(``,8"```K!P``1P0``/0'``#G!P``D@4``*X%``"3
M!@````````8&`````````````,\&``#^!P```````,0``````````````)H'
M``#'````J00``-0%````````W`0```````````````````````!&!@``````
M`/,!``#_!@``%P(````````I`@``;0$``"@%``#7`0``+`````````"'!0``
MA08```\"``"V`@``^P$````````+`P```````+@&``!V`@``<00``,,```!7
M`P``!P0``)@```"5`0``-0$``/P```!N!P``8@```.\&``!@`@``*@@`````
M```2!0``H`,``+4&``",`0``G`<```(%``!P!P```````!H#````````````
M``````#I!0``"P0```````"C!P````````````#O`P``D@,``+\'```_!P``
M`````.L&``#+!P``9`<````!````````#P0``!T%```^"```/00``!P#````
M````KP4``#X'``"/!@```````/($```U"```MP4``%$%``!*!@``80<``'("
M````````F`,``&@"``!_!P``^`4``'0$````````/`<``.`"````````5@4`
M`*P&```I!@```````"P$```+!0``K04``-<%```.`0```````$<'````````
MX00``!(&````````QP$``#L'````````/@$```````"K!P``O@<``-T````+
M`0``<08``%P&``#W````R@```.0"```L`@``X0<``&H'```P`P``!```````
M````````Q`$```````!,`````````-L```!S!````````,4&````````#P@`
M`+8```"*````^P8```````!;!@``Z0(``#(```"*`@``W00`````````````
M%@$``($%````````XP(```````!2"```<0<``*$!``"<!@``+0,``'0'``!1
M!@```````*0"``!:!````````/$`````````"`(``$$"``!0`P``P@4``'@!
M``#(!P``BP(``.($```4````/0(```````"?!P``A@````,'````````````
M`*0```#.`````````$T$``!5`@```````$\$````````L0(``"L%````````
M:````!4'``"C!@``M@8``-L$```@`````````&<#````````+0(```````#\
M!P```````$X```")!P``#@(``,\``````@``Q00``%0'```P"```K`4``/(%
M`````````````$P$``"L`0```````*\&```M!0```04``'4`````````O`$`
M``````#H!0```````'T$````````10@``&,&```*`P``7`4``#D#```]````
ML00``)4`````````M@4``!\!``!J`````````.H#```<!P``M@,``)(!```V
M!0``L@(``*T$``"T````-P@``)D$````````D@8`````````````KP0``%D$
M`````````````/8'``#N!```<P$``/L'``#+!```;P(``-@#``"<````=`(`
M``````!"`@````````````"7!@```````-T&``!&!0``OP,``!``````````
MG@0``"\#``!U!```^`0`````````````40````<#``#,````U@<``,0%``#3
M`0``;@,``*`$``#R`````````%$$``!=!P``F@8``.("``#N!@``@@(``*4!
M```8````/`@``$P(`````````````#$&`````````````*4%``!7"```(0``
M`,P%``!?`P``1`@``/@&``#Q`P```````"$!``!B`@````````````!#"```
MY@$```,"``!%!0``B@<```T#```C!P```````&D%``!K!```SP(``%`"``#9
M!```\0(``%P````T!P```````%,%``!I`P``R08``/0!``"[!P``T`,`````
M````````!0,`````````````5`$```````"K!````````/`&``"T!0``>0(`
M``````".!P``/@```/\````4`@``JP8``#T&```9`@``D`$`````````````
M"04``),#``#L`@``UP```&$&``"^!@``7P8``)$'````````P@<```0#``"4
M`@``8@$```,!``#8`0```````.@$````````MP,``!(```#O`@``(`@```8(
M````````500``,`'````````WP<``/P!`````````0@``%L'`````````08`
M`/X"``!%````;@4```````!&`P```````'X#``!`!0``10(``'($```U````
M;@8``-X'``"[!```H@(```````"G!0``+P(`````````````<0```/T!````
M``````````````#[!0``>`0``!P$``#Q!```4P@``"<'``!=!```+@8``"0#
M``!.!````````$('```5`P`````````````?`@``2P$``*`'````````)P@`
M`-@&`````````````"$(``#>!```9P8``$H'``"F`@``U04```````"%!```
M`````+,"```S`@``ZP<``+T$````````Z`,````````>!0```````!X`````
M````-@<````````U`@```````,T&``"7`P``;`8``````````````````%P#
M``!4"````````+($``!(````40<`````````````D`<``%D```#R`P``````
M``````!T````SP,``,`#`````````````.H```#,!```C@4````````Q"```
M*00```````#^````\P4``.P&```*!P``:P8``,@$```S`````````*0!````
M`````````&T%````````,`8``/L```!X!0``G08``*T!````````9`0`````
M`````````````)$$`````````````&\&```9!@``^08``.0$```?!P``````
M`-('``"-!0``9@```+T%``"5!```%@(``(4#``!>!P```````-4&``!Q`P``
M-`0```8"````````7@0```````!S!@``S0```'T&``"U!```P08``&8$``"(
M`P``8`0``(0"```X```````````````R"```?P8``#L#```<`@``X@4``*@%
M``!!!```RP(```T(``#8!```70$``(8#``"!````K`<```````"H````````
M``,#````````1@$``$\&````````Z0<``.H&``#Z!P``4P(``%X#```+!@``
M2P,`````````````&@$```P`````````2P```-$#```Y!@``[`<```````!:
M!P```````&4````B`@``PP0``$((``"3````]08``'$%``"T!@``.@<``+H!
M`````````````&L!``!=`P````````X`````````;00``-4!```K`@``:@$`
M`+,```#K`P``3`8``+<```##!0``;````*\`````````DP<````````3!P``
M````````````````%0@``!T#``"^`0``5P0``$($````````Q@0``.,%````
M````O@4``!@'``"J`P```````,D#``!3!P````````````!)!0``````````
M``````````````````"G`@``?@4``$D"````````V0<``*$%````````3@$`
M`%T"``#0`0``E@,`````````````?0```(\$``#M`@``;0(````````J!0``
M)`$``",!``":````]@,``!0&``#!!P``PP8```````#2!````````(T#````
M````G`0``$`&``!\`P``R@0``!`!``#[`@``MP8``+\```!I`0``D`8``$P%
M``#F!0``\@$``,8#```1````*@8``#<'``"?!@``(0<``"0%``"?!0``*`8`
M`($&``"T`P```````'X!```O`0``@0(``+P"```K!@``.P0```````#"````
MF0,``/D!```M`0```````%\%```\`0``>@(``*0&````````,`(``!,%``!A
M`P``;`$``(<!``!0!P``8`4``+0'``"$!@``S@0```````#/`0``G04`````
M``"N````CP(``-0'```:!P``10,``-0`````!````````&8"```=````0P<`
M``<&```.!```J`0``.$&``!.`@```````)4#``#V!````````"8!```I!0``
M2@$```````!#`@``Z`$``)4%``#D!P``[`4``+$!````````QP8``"`!```!
M!```"0@``(D```"^`@```````(0%````````V08```````"Q!0``?@```&\#
M``"`!@``.`4``$T%```W!`````````T!``#C!P``_P4```````#P!0``.P``
M`%@%``!%!@```````+@%````````T@4``$$'``!8"```.@0```````"E`@``
M<@,``)$"``!P!@``&@8``!$!```E!P``EP<``&X"``"N!```"`,``,`````\
M`@``GP,``(H%``!L`@``X0(``(`"``"T`@``"@4``*@&``!F`0``#@,``'`"
M``!!!0``-P$``,("``!0"`````````````#)!0```````'('````````504`
M`-L&````````R`8``)$#````````A`<`````````````N0<``,\'```,!```
M-`$``-L"````````_@4``!X#``#M!P``.@4``"(&```<"```,0<``$H#``#$
M`P``H0,``%P'````````?@0``(@"````````0`<```````#M!```````````
M``#C!```Z`(``-P&````````A@$``-H&```X`@``)00``*\"``!S!0``````
M```````$!P``*P0``(('```7!P``4P8``((!````````A@(``"8$``!&`@``
M`````(T$``"U`@``6@4``(,`````````'@@```````",`@``@0,``%H!```^
M`@``W`<``&L%``!-!P``:`,```,``````````````"<$```/!@``M0$`````
M``#@!@```````"H!```G`P``?`(```````#D!0``AP(``&0```"`!P``````
M`'(````;`P```````-$```!6!@``QP,``"@"``"+!@``G0$```````!J`P``
M4P0``%,#``!A!```G@,``)@$```W!0``@0<``*,"``"1`0``)0(``-,%```6
M!P``20,``'8```#9`P``7P<``&@!```&````Y0(``.0&``!S````R@4``-`%
M```7!````````!<#``!K````]0<``(,&``"Z!P```````!D'```Y`@``B`$`
M``8'``!A!0``%0```.L%``"4!@``N0,``/,#``#1!P``"P<```````"A````
M`````,`%````````UP,``%<"````````E0<``*D%``!;`0````````````"S
M`P``J`<``'(!````````(@```&4$```&!0```````!,"``#;!P``2P8``((%
M``!;!0``0````!@$``#<`@``#`@``-D"``#`!```G0(``'X&````````=0,`
M`/T'````````=P(``"0$``"#!```I@<```````"4`````````/P"````````
MJP,```````#O`0``3`$``)H#``"Z!````````%X`````````,````$<&``!!
M`P``M0,``$<#``"J!P``Z@(``$$&``#.!@``$0@``$$!````````%0$``(,"
M``#)!P``]`````L```#2`0``>0<``(D#``#Z`0``1`$``*8!``"P`0``!`$`
M````````````[`0```````#E!```3`,``+D%``"^`P``B00````````,!P``
M``````T```#>````X0,``+`$``#9`````````%X!```.!P``+@```,@!````
M````2`,``&P%````````80$``'$!```!`@``I`4``"D#``"(!@```````$@"
M``"M`@``40@``%4'`````````````,$%``"G!P``<P(``+`#```B!P``````
M`#T%``"@````-0,``*H%``"F````"0```*,#```#!0``#@@`````````````
M1@@``,\%````````YP,``!P%``!%`0``,0,``*T'`````````````!0#``!/
M````%P@``*H$``#H!P``?P$```\'``"\!```VP4``)($``#B!P``\@8``/``
M``"P!@```````'<!``"A!P``N0(``'0#``#N!0``-00``+(#```=!@``)P8`
M`-@'```%"```\`<```H&```````````````````6!@```````,0"``!#````
M+@,```````"F!@``]P<```````"T!```FP````````!A``````````````!`
M`P``P`8```4"``#T!@``'P@``&,'``!Z!````````-\&``!=`````"`F(S$U
M,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("A296%D(&]N;'DI`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`
M("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D
M:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE
M(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S
M:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"
M('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S
M`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"!N;W1E
M<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`
M)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E
M<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@8VAA<F%C=&5R<P`E
M<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!H87,@8V%N8V5L;&5D
M("5S+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E
M<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S
M('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E
M9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@<F5Q=65S=',@>6]U<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N
M8V4@870@)7,N`"5S('1O("5S(&]F("5S`"5S('=I<VAE<R!T;R!A9&0@=&\@
M)7,N`"5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RX`)7,@=VES
M:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E
M<RX`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P
M860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@
M;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F
M;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I
M;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`
M+2T@<V5L96-T("TM`#$@;F]T90`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O
M<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!
M32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)
M1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED
M9&QE`$%C8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92X`06-C97-S(&1E;FEE9"!D96QE=&EN9R!N;W1E+@!!8V-E<W,@
M9&5N:65D(&UO=FEN9R!T:&4@;F]T92X`06-C97-S(&1E;FEE9"!S879I;F<@
M;F]T92!T;R`E<RX`06-C97-S(&1E;FEE9"!S879I;F<@;F]T93H@)7,`06-C
M;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O
M>F5N+@!!8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"`E<P!!9&0@0VAI;&0@
M1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@
M1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O
M("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V%T96=O<GD`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E
M<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;R!A9&1R97-S(&)O
M;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S
M(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L
M('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@02!.97<@3F]T90!!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K
M`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R
M:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T
M960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@
M<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A
M`$%N(&5R<F]R(&]C8W5R<F5D(&9O;&QO=VEN9R!T:&ES(&QI;FLZ("5S`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM
M;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U
M9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I
M<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X
M:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG
M<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I
M`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!
M<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N
M="!C;VQU;6YS`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY
M('1O(&$@<F5Q=65S="!Y;W4@<V5N=`!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T96YD965S`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI
M80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V
M92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@
M1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE
M("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P
M.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S
M;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T
M:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N
M=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N
M('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE($-A=&5G;W)I
M97,Z`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B
M86EJ86X`07IU<@!"3T9(($5X8W5S97,`0F%C:R!T;R!.;W1E<&%D`$)A8VL@
M=&\@3F]T97!A9"!/<'1I;VYS`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO
M<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M
M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<V@`0F%R(%1I;64`0F%R('1I;64`0F%R8F%D;W,`0F%R8FEE`$)A<V4@
M9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"
M96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I
M<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U
M;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQU92!-;V]N`$)L=64@
M86YD(%=H:71E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E
M<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!"
M;W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)O=VX`0G)U;F5I($1A<G5S
M<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R
M;G0@3W)A;F=E`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<P!#4U8`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N
M;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N
M`$-A;6]U9FQA9V4`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A
M;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET
M92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S
M:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@
M3&%B96QS`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L
M;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E
M;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E
M;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A
M;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T
M92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86ER(%!E<G-O
M;@!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E(&1E9F%U;'0@
M:61E;G1I='D`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I
M;VYS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D
M("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!
M<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA
M;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T:&4@
M<W5M;6%R>2!V:65W+@!#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N`$-H
M<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N`$-L96%R`$-L96%R($9O<FT`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A
M<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U
M<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC
M:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A
M<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3
M:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R
M(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`
M0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!-97-S86=E
M("@E<RD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W
M:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S
M=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S
M;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D
M(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD
M<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`
M0V]R;F9L;W=E<@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@
M8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E
M<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B
M;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T
M<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N
M`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N`$-O=6QD(&YO="!M:V1I
M<B`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P
M96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD
M(&YO="!O<&5N("<E<R<@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2`B)7,B+@!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RX`0V]U
M;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@
M)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#
M;W5L9"!N;W0@<FUD:7(@)R5S)RX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG
M=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O
M=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@
M66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5N;&EN:R`G
M)7,G+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U
M<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-
M;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N
M+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT
M<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R
M>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O
M;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S
M:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@
M-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N
M="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N
M="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP
M<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$
M1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E
M`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L
M=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L:6YE9`!$96-R96%S
M92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I
M='D`1&5F875L="!.;W1E<&%D`$1E9F%U;'0@4VAE;&P`1&5F875L="!S;W)T
M:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$969I
M;FET:6]N<P!$96QE9V%T92!P;W-I=&EO;@!$96QE9V%T960`1&5L971E`$1E
M;&5T92!#96QL`$1E;&5T92!#;VYF:7)M871I;VX`1&5L971E($=R;W5P`$1E
M;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M
M97-S86=E<P!$96QE=&4@8G5T=&]N(&)E:&%V:6]U<@!$96QE=&4@8V5L;`!$
M96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S
M(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y
M`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@;&EN:P!$96QE
M=&4@=&AI<R!N;W1E`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S
M(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E;GD@<F5Q=65S=`!$96YY(')E
M<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;@!$97-C96YD:6YG`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E<V-R:7!T:6]N.@!$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M
M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P
M;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H
M="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I
M<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L
M87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&EV:61E<@!$:FEB
M;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@
M96YT<FEE<S\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC86X@4F5P
M=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A
M9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I
M="`B)7,B`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET($YO=&4`161I="!0
M97)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F
M;W(@)7,`161I="!C871E9V]R:65S(&%N9"!C;VQO<G,`161I="!O<'1I;VYS
M(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N
M="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU3
M35,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@3F]T90!%;7!T>2!M97-S86=E
M+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F0`16YD('EE
M87(`16YL87)G92!%9&ET;W(`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N
M=&5R('1H92!L971T97)S(&)E;&]W.@!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S`$5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+@!%<G)O<B!U<&1A=&EN9R!P
M87-S=V]R9#H@)7,`17)R;W(@=W)I=&EN9R`B)7,B+@!%<G)O<B!W<FET:6YG
M("<E<R<N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A
M;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`
M17AP;W)T`$5X<&]R="!.;W1E<P!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E
M='5P`$9?=6QL(%1E>'0`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E
M<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`
M1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X
M97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E
M<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#
M2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`
M1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&
M:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A
M<G1E<@!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E92]"=7-Y($EN
M9F]R;6%T:6]N`$9R964O0G5S>2!297!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&
M<F5E+T)U<WD@4F5Q=65S="!297-P;VYS90!&<F5N8V@@1W5I86YA`$9R96YC
M:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`
M1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M
M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'
M86UB:6$`1V5N97)A;"!/<'1I;VYS`$=E;F5R871E("5S($-O;F9I9W5R871I
M;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A
M;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G
M;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96X`
M1W)E96YL86YD`$=R96YA9&$`1W)E>0!'<F]U<"!!9&UI;FES=')A=&EO;@!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E
M;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S`$=R;W5P<P!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!0
M97)M:7-S:6]N<P!'=65S="!397)V:6-E<P!'=65S=&)O;VL`1W5I;F5A`$=U
M:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A
M9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@
M5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE:6=H="`H
M:6X@<&EX96QS*0!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI
M<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG
M:`!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE
M(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@
M:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V
M960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG
M`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E
M<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(
M=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0
M($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V
M:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N
M;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA
M;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O
M<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@
M:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T
M;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y
M('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E
M(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`
M26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@3F]T97,L(%-T97`@)60`26UP
M;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@3F]T97,`26UP;W)T960@9FEE
M;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26X@4')O8V5S<P!);E]S97)T(%)O
M=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C
M="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`
M26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE
M<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V
M86EL86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN
M<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F
M;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E
M`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS
M97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A
M<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E
M9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF
M>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`
M26YT96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES
M(&-O;7!O;F5N="X`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`
M26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED
M(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI
M9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV
M86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV
M86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T
M(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B
M)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E
M<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E
M;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N
M9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R
M`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@
M*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y
M`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S
M=&EF>2!2:6=H=`!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y
M($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO;&%B
M`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A
M+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T
M86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8P!,87-T($AA;&8`3&%S="!-;V1I9FEE9`!,87-T(%!A<W-W;W)D
M($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA='9I80!,879E;F1E<@!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S
M`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA
M`$QI96-H=&5N<W1E:6X`3&EG:'0@0FQU90!,:6=H="!$<FEZ>FQE`$QI9VAT
M(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@
M4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO
M=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S
M('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(
M96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP
M`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`
M3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`
M3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@
M=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U
M=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,;WEO;&$`3&]Y;VQA($)L=64`3'5X96UB;W5R9P!-30!-3U1$`$U3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O
M`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-
M861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN
M`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G
M;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D
M+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`
M36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@
M;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F
M($YO=&5S`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU
M;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365E=&EN9R!#86YC96QL
M871I;VX`365E=&EN9R!);F9O<FUA=&EO;@!-965T:6YG(%!R;W!O<V%L`$UE
M971I;F<@4F5P;'D`365E=&EN9R!5<&1A=&4`365E=&EN9R!5<&1A=&4@4F5Q
M=65S=`!-96UB97)S`$UE;6\@5&5X=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS
M`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N
M`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`
M365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN
M:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`
M36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N
M+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA
M:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9&EF>6EN
M9R`E<P!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG
M;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0
M:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E
M>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D
M>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-;WII;&QA
M`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``
M375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O
M<FUA=&EO;@!->2!.;W1E<P!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!-
M>6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`
M3F585`!.965D<R!!8W1I;VX`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N
M9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@4F5N97=A
M;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N
M:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE
M=R!.;W1E`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE
M=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`
M3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO
M;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.
M;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E
M+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N
M`$YO(&1E<V-R:7!T:6]N(&9O=6YD`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+@!.;R!F:6QE('5P;&]A9&5D`$YO(&E#86QE;F1A<B!D871A('=A<R!F;W5N
M9"X`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C
M871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@
M<W!E8VEF:65D+@!.;R!N;W1E<&%D<R!A<F4@879A:6QA8FQE('1O(&=U97-T
M<RX`3F\@;F]T97,`3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R
M:6$N`$YO(&YO=&5S('1O(&1I<W!L87D`3F\@;G5M8F5R('-P96-I9FEE9"X`
M3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!E;F1I;F<@
M<VEG;G5P<RX`3F\@<75O=&$@<V5T`$YO('%U;W1A('-E="X`3F\@<G5L97,`
M3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE
M`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]?=&4`3F]N(%!A<G1I8VEP
M86YT`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)F;VQK($ES;&%N9`!.
M;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.
M;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO
M="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E($-A
M=&5G;W)Y`$YO=&4@1&5T86EL<P!.;W1E($QI<W1S`$YO=&4@5&5X=`!.;W1E
M(%]497AT`$YO=&4@;F]T(&9O=6YD+@!.;W1E7W!A9`!.;W1E<&%D)W,@;F%M
M93H`3F]T97!A9',`3F]T97!A9',@;75S="!H879E(&$@;F%M92X`3F]T97,`
M3F]T97,@4W5M;6%R>0!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T
M:6-E`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB
M97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C
M:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/
M8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I
M;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF
M9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R
M96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL
M(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R
M;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E
M;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE
M9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;F%L(%!A<G1I8VEP86YT`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K
M96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`
M4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@
M0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E
M<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS
M`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN
M9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P
M:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#
M;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN
M`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`
M4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU
M<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M
M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP
M<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S
M`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@
M8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E
M(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y
M<W1E;2X`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE
M87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE
M;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S
M92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S
M`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S
M:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN
M;W0@96YF;W)C960@8GD@24U!4"D`4&]S=&YU:V4`4')E8VEP:71A=&EO;B!F
M;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC
M90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``
M4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A
M=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0
M<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U
M8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E
M<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2
M861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN
M(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R
M='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(&1E
M;&5T92!T:&ES(&YO=&4_`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U
M<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O
M97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-
M96YU($5L96UE;G1S.@!2969R97-H($QI<W0`4F5F<F5S:"!0;W)T86P@5FEE
M=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`
M4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M;W1E(%-E
M<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-A=&5G;W)Y`%)E;6]V
M92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E(&9R;VT@;7D@8V%L
M96YD87(`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO
M=F4@=7-E<CH@)7,`4F5P;'D@4V5N="X`4F5P;'D@=VET:"!.;W0@4W5P<&]R
M=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M
M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BX`4F5P;'DZ("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N
M(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN
M("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<75I
M<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO
M=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N
M('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R
M="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D
M;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P
M97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T
M`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2
M;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U
M;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG
M`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-3
M2`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI
M='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI
M<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@
M9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0
M<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`
M4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO
M;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T
M97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!3
M96%R8V@@4F5S=6QT<P!396%R8V@@4V-O<&4`4V5A<F-H(%]497AT`%-E;&5C
M="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!3
M96QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@;F]T97!A9`!396QE8W0@82!S
M97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@
M;F]N90!396QE8W0@;F]T97!A9',@=&\@9&ES<&QA>3H`4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R
M96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T
M92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H
M92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O
M=7)C92!F:6QE.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.@!396QE8W1E9"!#871E9V]R:65S.@!396YD($QA=&5S="!);F9O
M<FUA=&EO;@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I
M86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3
M970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H
M;W<`4VAO=R!.;W1E<&%D<SH`4VAO=R!A8W1I;VX@8G5T=&]N<S\`4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;F]T97!A9"!N86UE/P!3:&]W
M(&YO=&5S(&9R;VT@=&AE<V4@8V%T96=O<FEE<P!3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO
M=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@
M3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@
M06QG;W)I=&AM`%-I;7!L97@`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N
M86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@
M4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`
M4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M
M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!B>2!#871E
M9V]R>0!3;W)T(&)Y($YO=&4@5&5X=`!3;W)T(&]R9&5R('-E;&5C=&EO;@!3
M;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R
M90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A
M8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R
M($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R
M=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!Y
M96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3
M=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I
M<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O
M=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S
M(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O
M<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L
M971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE
M('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN
M(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D("(E
M<R(N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`
M4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL
M>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N
M;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U
M;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3
M=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE
M<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M
M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F
M:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R
M;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J
M:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`
M5&%S:W,`5&5A;`!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U
M<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@
M+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F
M;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5N=&%T:79E;'D@06-C
M97!T(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5X=`!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL
M86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE("5S(&QI
M;FL@=&\@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B
M;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN
M:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D
M+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H
M92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;G1A8W0@240@;G5M
M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@
M9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&5V96YT(&AA<R!B
M965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C
M;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I960@
M;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&EN:R!H87,@8F5E
M;B!R96UO=F5D`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B
M965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@
M;F]T92!W87,@9&5L971E9"X`5&AE(&YO=&5P860@(B5S(B!C;W5L9&XG="!B
M92!C<F5A=&5D.B`E<P!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N(&-R96%T
M960N`%1H92!N;W1E<&%D("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YO
M=&5P860@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&YU;6)E<B!O9B!F:65L
M9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@
M<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N
M;W0@97AI<W0N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@
M=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@
M>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R
M965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I
M9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@
M<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@
M;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@
M=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W
M960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&1A=&$Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V
M96YT.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M('1A<VLZ("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!V
M3F]T92!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G
M<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+@!4:&5R92!W87,@86X@97)R
M;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F
M="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E
M<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!R
M96UO=FEN9R!T:&4@;F]T93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN
M9R!T:&4@;F]T93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!V:65W:6YG('1H:7,@;F]T97!A9#H@)7,`5&AE<F4@=V5R92!N;R!M96UO
M<R!T;R!E>'!O<G0N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T
M960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H
M:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS
M,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F
M;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`
M5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N
M`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`
M5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG
M80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@
M86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U
M<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I
M8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN
M9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R
M;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE("5S+R5S`%5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E
M("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@
M9&5L971E("(E<R(Z("5S`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E
M=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N
M86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S
M:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I
M;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M
M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`
M56YD;R!C:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@
M;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O
M<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!#;VYT96YT
M+51Y<&4Z("5S`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E
M("5S`%5P9&%T92!R97-P;VYD96YT('-T871U<P!5<&1A=&4@=7-E<@!5<&1A
M=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R
M=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S
M<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R
M("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A
M=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E
M<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L
M<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T
M:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU
M97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E
M<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@
M2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I97<@979E;G0`
M5FEE=R!T87-K`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N
M80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!796)B<&QA='-E
M;B`M(%-O8F5R`%=E8F)P;&%T<V5N("T@4V]B97(@3D57`%=E96ML>0!796QC
M;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X
M-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H
M($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\`5VAI8V@@
M<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T
M:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7
M:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L
M9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G90!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M
M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!N;W1E<RX`66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N
M('1O('9I97<@=&AE(&YO=&5P860@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D
M(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M`%EO=2!M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E9"X`66]U
M(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB
M97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@
M86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z
M`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@
M<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I
M9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ`%EO=7(@9&5F875L="!N;W1E<&%D.@!9;W5R(&9U;&P@;F%M93H`66]U
M<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<P!9;W5R(&YO=&5P861S.@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C
M:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S
M=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@
M<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;
M;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"86-K('1O($YO=&5P
M860`7T-,20!?0V%T96=O<GD`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2
M;W<`7T5D:70`7T9I<G-T($QI;F4`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O
M<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&ES="!.;W1E<P!?3&]G(&EN
M`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?37D@3F]T97!A9',`7TYE=R!.
M;W1E`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK
M+BXN`%]396%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R
M<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L
M;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T
M`&-L:6-K(&AE<F4`8VQO8VL`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O
M;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL
M:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z
M`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O
M;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M
M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`&YO=&5S+F-S=@!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I
M;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`
M<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU
M<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=DYO=&4`=SH`=V5A=&AE<BYC
M;VT`4')O:F5C="U)9"U697)S:6]N.B!-;F5M;R`R+C$*4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#8M,#$M,S$@,C$Z-3(K,#$P,`I03RU2979I<VEO;BU$871E.B`R
M,#`V+3`Q+3,Q(#(R.C`P*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!*;V%Q=6EM
M($AO;7)I9VAA=7-E;B`\:F]H;T!W96)B<&QA='-E;BYS93X*3&%N9W5A9V4M
M5&5A;3H@4W=E9&ES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R
M<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI
M<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`F
M(S$U,3L@)7,@:V]M;65R(&%T="!U=&;V<F$@9&4@=6YD97)HY6QL<V%K=&EV
M:71E=&5R;F$@<V]M(&UA<FME<F%T<R!N961A;BX`("@E<R!D86=A<B!S961A
M;BD`("AS;F%B8G1A;F=E;G0@)7,I`"`H4VMR:79S:WED9&%D*0`@*&]M("5S
M(&1A9V%R*0`@*&ED86<I`"`H:6UO<F=O;BD`("AI9^5R*0`@:VP@`"<E<R<@
MY'(@:6YT92!E;B!K871A;&]G+@`G)7,G(.1R(&EN=&4@971T(&=O9&OD;G0@
M=F%L+@`G)7,G(.1R(&EN=&4@:V]N9FEG=7)E<F%T(&D@2&]R9&5R96=I<W1R
M97)T+@!4<N1D:&%N=&5R87)E;B!F]G(@)7,@<V%K;F%S+@`G)7,G(&QA9&5S
M('1I;&P@:2!G<G5P<'-Y<W1E;65T+@`G)7,G(&QA9&5S('1I;&P@:2!B96CV
M<FEG:&5T<W-Y<W1E;65T+@`G)7,G('-K87!A9&5S(&EN=&4Z("5S+@`E+C)F
M34(@86YVY&YT(&%V("4N,F9-0B!T:6QLY71E="`H)3)F)24I`"5D("5S(&]C
M:"`E<P!$:71T(&SV<V5N;W)D('5P<&CV<B!A='0@9^1L;&$@;VT@)60@9&%G
M87(N`"5D(&%N=&5C:VYI;F=A<@`E9"UD86=S<')O9VYO<P`E<R`M($;V<B!K
MY&YN961O;0!&:6YG97)P<FEN="!F]G(@)7,`)7,@2T(`)7,@56YD97)HY6QL
M<V9U;FMT:6]N("T@0F5K<N1F=&5L<V4`)7,@4V5T=7``)7,@86YMY&QA;@!4
M:N1N<W1E879T86P@9O9R("5S`"5S(&9I;FYS(')E9&%N+@`E<R!K;"`E<R`E
M<P`E<R!T96-K96X`1FEL96X@)7,@:6UP;W)T97)A9&5S`"5S(&AA<B!A;FYU
M;&QE<F%T("5S+@`E<R!H87(@<W9A<F%T('#E(&5N(&)E9^1R86X@;VT@:6YF
M;W)M871I;VX@86YGY65N9&4@;&5D:6<O=7!P=&%G96XN`"5S(&AA<B!S=F%R
M870@<.4@:6YB:G5D86X@=&EL;"`E<RX`)7,@:&%R('-K:6-K870@9&EG(&EN
M9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N+@`E<R!K;VUM97(@871T('5T
M9O9R82!D92!U;F1E<FCE;&QS86MT:79I=&5T97)N82!S;VT@;6%R:V5R871S
M(&YE9&%N+B!-87)K97)A(&1E(&%K=&EV:71E=&5R('-O;2!D=2!V:6QL('5T
M9O9R82X`)7,@:W+D=G,`)7,@;6EN=71E<@`E<R!S86MN87,N`"5S(&5F=&5R
M9G+E9V%R(&EN9F]R;6%T:6]N(&]M(&[D<B!D=2#D<B!L961I9R]U<'!T86=E
M;BX`)7,@969T97)F<N5G87(@9&EN(&[D<G9A<F\@=FED("5S+@`E<R!T:6QL
M("5S(&%V("5S`"5S('9I;&P@;.1G9V$@=&EL;"!T:6QL("5S+@`E<R!V:6QL
M(&?V<F$@9&EG(&UE9'9E=&5N(&]M("5S+@`E<R!V:6QL(&5R:.5L;&$@9&5N
M('-E;F%S=&4@:6YF;W)M871I;VYE;B!O;2`E<RX`061R97-S8F]K(&;V<B`E
M<P!+86QE;F1E<B!F]G(@)7,`06YT96-K;FEN9V%R(&;V<B`E<P!5<'!G:69T
M97(@9O9R("5S`"5S.B`E<P`E<SH@365D9&5L86YD970@:V%N<VME(&EN=&4@
MY'(@9G+E;B!D96X@<V]M(&1E="!V97)K87(N(%9A<B!F]G)S:6MT:6<@;65D
M(&%T="!F]FQJ82!LY&YK87(@96QL97(@<VMI8VMA(&%V<^1N9&%R96X@<&5R
M<V]N;&EG(&EN9F]R;6%T:6]N+@`L('-T;W)M8GEA<@`L('-T;W)M8GEA<B`E
M<R`E<P`L('9A<FEE<F%N9&4@;65L;&%N("5S(&]C:"`E<P`M+2!VY&QJ("TM
M`#$@86YT96-K;FEN9P`Q,BUT:6UM87)S9F]R;6%T`#(T+71I;6UA<G-F;W)M
M870`,C0@=&EM;6%R`#Q&]G)E9^5E;F1E`$5N(&1A=&%B87-K;W!P;&EN9R!K
M<N1V<R!F]G(@86MT=65L;'0@8FQO8VLN`$5T="!F871A;'0@9F5L(&AA<B!I
M;G1RY&9F870`16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D=G,@9O9R(&%T="!K
M<GEP=&5R82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK(%!'4"UN>6-K96P@
M:W+D=G,@9O9R(&%T="!V97)I9FEE<F$@971T('-I9VYE<F%T(&UE9&1E;&%N
M9&4N`$5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E
M;F]R9"!K<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N
M`$5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E;F]R
M9"!K<N1V<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N9&4N`$5N('!U
M8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M="!L]G-E;F]R9"!K
M<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N`$5N('!U
M8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M="!L]G-E;F]R9"!K
M<N1V<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N9&4N`$5N('!U8FQI
M:R!3+TU)344M;GEC:V5L(&MRY'9S(&;V<B!A='0@:W)Y<'1E<F$@971T(&UE
M9&1E;&%N9&4N`$;V<FUI9&1A9W-M;VQN`$SD='0@9O9R;6ED9&%G<W)E9VX`
M1O9R;6ED9&%G<W)E9VX`1O9R;6ED9&%G<W-K=7)A<@!&]G)M:61D86=S<VMU
M<F%R(&UE9"!S;O8`04TO4$T`05!)($E$`$]M(&5D:71O<FX`3VTN+BX`0F]T
M=&5N`$UI='1E;@!!8V-E<'1E<F$@8F5GY')A;@!!8V-E<'1E<F%D`$)E:/9R
M:6=H970@<V%K;F%S(&%T="!S:V%P82!61E,M;6%P<"X`0F5H]G)I9VAE="!S
M86MN87,@871T('-K87!A(%9&4RUF:6PN`,5T:V]M<W0@;F5K860N`$)E:/9R
M:6=H970@<V%K;F%S(&%T="!F;'ET=&$@86YT96-K;FEN9RX`0F5H]G)I9VAE
M="!S86MN87,@871T('-P87)A(&%N=&5C:VYI;F<@=&EL;"`E<RX`0F5H]G)I
M9VAE="!S86MN87,@871T('-P87)A(&%N=&5C:VYI;F<Z("5S`$MO;G1O:6YF
M;W)M871I;VX`3/9S96YO<F0@9O9R(&MO;G1O`$MO;G1O="!F<GES=`!"=61G
M970`Q71GY')D97(`3.1G9R!T:6QL`$SD9V<@=&EL;"`E<P!,Y&=G('1I;&P@
M=6YD97)G<G5P<`!LY&=G('1I;&P@=6YD97)B96CV<FEG:&5T`$SD9V<@=&EL
M;"!HY'(Z`$SD9V<@=&EL;"!N>2!G<G5P<`!,Y&=G('1I;&P@;GD@8F5H]G)I
M9VAE=`!,Y&=G('1I;&P@=6YD97)G<G5P<"!T:6QL("<E<R<`3.1G9R!T:6QL
M('5N9&5R8F5H]G)I9VAE="!T:6QL("<E<R<`3.1G9R!T:6QL(&5N(&YY(&%N
M=N1N9&%R93H`3.1G9R!T:6QL(&MA=&5G;W)I`$SD9V<@=&EL;"!K;VQU;6X`
M3.1G9R!T:6QL(&YY82!M961L96UM87(`3.1G9R!T:6QL('!A<@!,Y&=G('1I
M;&P@;65N>6X@9O9R("5S('-O;2!-;WII;&QA(%-I9&5B87(`3.1G9R!T:6QL
M(&D@;6EN(&MA;&5N9&5R`$SD9V<@=&EL;"!I(&%D<F5S<V)O:SH`3.1G9R!T
M:6QL(&D@;6EN(&%D<F5S<V)O:P!,Y&=G('1I;&P@86YVY&YD87)E`$QA9&4@
M=&EL;"`G)7,G('1I;&P@<WES=&5M970L(&UE;B!K=6YD92!I;G1E(&SD9V=A
M('1I;&P@97AT<F$@(&EN9F]R;6%T:6]N.B`E<RX`3&%D92!T:6QL("<E<R<@
M=&EL;"!S>7-T96UE="X@1'4@:V%N(&QO9V=A(&EN(&YU+@!,Y&=G97(@=&EL
M;"!E;B!A;G1E8VMN:6YG`%5P<&SD9V<@878@86YVY&YD87)E(.1R(&EN86MT
M:79E<F%T+@!!9')E<W,`061R97-S8F]K`$%D;6EN:7-T<F%T:6]N("T@86YG
M92!B96CV<FEG:&5T(&;V<B!A;F1R82!A;G;D;F1A<F4`061M:6YI<W1R871I
M;VX`4F5K;&%M`$%F9V%N:7-T86X`06QB86YI96X`06QG97)I970`06QI87,`
M2G5S=&5R80!*=7-T97)I;F<Z`$%L;&$`06QL82!A=71E;G1I<V5R861E(&%N
M=N1N9&%R90!!;&QA(&=R=7!P97(`06QL82!B96CV<FEG:&5T97(`06QL82!F
M>7)A('-I9&]R`%1I;&SE="!F;&5R82!A9')E<W-E<@!4:6QLY70@:6YS=.1L
M;&YI;F<@9O9R('-O<G1E<F%D(&QI<W1A/P!&:6YN<R!R961A;@!!;'1E<FYA
M=&EV($E-4U`M:6YL;V=G;FEN9P!!;'1E<FYA=&EV="!L]G-E;F]R9"!F]G(@
M24U34`!!;'1E<FYA=&EV="!A;G;D;F1A<FYA;6X@9O9R($E-4U``06QT97)N
M871I=B!E+7!O<W0@861R97-S`$%L=&5R;F%T:78@;6%L;`!!;'1E<FYA=&EV
M('1E>'0Z`$%M97)I:V%N<VMA(%-A;6]A`$5T="!F96P@=7!P<W1O9"!NY'(@
M;.1N:V5N("@E<RD@<VMU;&QE(&%N=N1N9&%S`$5T="!F96QA:W1I9W0@=N1R
M9&4@86YG879S+@!%='0@;VOD;G0@9F5L(&AA<B!I;G1RY&9F870`06YD;W)R
M80!!;F=O;&$`06YG=6EL;&$`06YO;GEM('!R;WAY`%-V87(`06YT87)K=&ES
M`$%N=&EG=6$@;V-H($)A<F)U9&$`07!P;&EK871I;VX`07!P;&EK871I;VYS
M;&ES=&$`07!P;&EK871I;VYE;B#D<B!K;&%R+@!697)K<W3D;&P@=&EL;"!U
M;F1E<G5T9&5L;FEN9V%R`$=O9&OD;FX`56YG96;D<FQI9R!S=&]R;&5K`&%P
M<FEL`$%R86)I<VL@*%=I;F1O=W,M,3(U-BD`07)K:79F:6QS=&]R;&5K`$%R
M:VEV9FEL;F%M;@#$<B!D970@<^1K97)T(&%T="!D=2!V:6QL('1A(&)O<G0@
M8F5GY')A;B!F]G(@)7,_`,1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@<F%D
M97)A("<E<R<@;V-H(&5V96YT=65L;&$@=6YD97)G<G5P<&5R/P!!<F=E;G1I
M;F$`07)M86YI96X`07)M96YI<VL@*$%235-#24DM."D`2V]N<W0`07)U8F$`
M4W1I9V%N9&4`07-C96YS:6]N($ES;&%N9`!!<V-I:2!K;VYS=`!!<VEE;B]3
M=&EL;&$@:&%V<W)E9VEO;F5N`$9RY6=A(&5F=&5R(&)E:W+D9G1E;'-E(&EN
M;F%N('5N9&5R:.5L;'-A:W1I=FET971E<B!U=&;V<G,_`%1I;&QD96QN:6YG
M<VMO;'5M;@!":69O9V%D(.1R(&5N(&E#86QE;F1E<B!F:6P@;65D(&5T="!S
M=F%R('#E(&5N(&)E9^1R86X@<V]M(&1U('-K:6-K870L`$;V<G/V:R!T:6QL
M(&%T="!R861E<F$@96X@9W)U<'`@<V]M(&EN=&4@9FEN;G,N`$;V<G/V:R!T
M:6QL(&%T="!R861E<F$@96X@8F5H]G)I9VAE="!S;VT@:6YT92!F:6YN<RX`
M1O9R<_9K(&%T="#D;F1R82!E;B!B96CV<FEG:&5T('-O;2!I;G1E(&9I;FYS
M+@!&]G)S]FL@871T(.1N9')A(&5N('5T9&5L;FEN9R!S;VT@:6YT92!F:6YN
M<RX`1&5L=&%G87)E`$%T=')I8G5T`&%U9W5S=&D`075S=')A;&EE;@#6<W1E
M<G)I:V4`075T:%]C>7)S<6PZ($E-05`M97AT96YS:6]N('-A:VYA<RX`075T
M:%]C>7)S<6PZ($MO<'!L:6YG96X@<V%K;F%R(&9U;FMT:6]N97(@<V]M(&MR
MY'9S+@!!=71H7V-Y<G5S.B!)34%0+65X=&5N<VEO;B!S86MN87,N`$%U=&A?
M9G1P.B!&5%`M=&EL;.1G9R!S86MN87,N($MO;7!I;&5R82!02%`@;65D('-W
M:71C:&5N("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!)34%0+65X=&5N<VEO
M;B!S86MN87,N`$%U=&A?:W)B-3H@:W)B-2UE>'1E;G-I;VX@<V%K;F%S+@!!
M=71H7VQD87`Z($1E="!GY7(@:6YT92!A='0@;.1G9V$@=&EL;"!A;G;D;F1A
M<F4@:2!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E
M(&%T="!R861E<F$@86YVY&YD87)E(&9RY6X@06-T:79E($1I<F5C=&]R>0!!
M=71H7VQD87`Z($Q$05`M=&EL;.1G9R!S86MN87,N`$%U=&A?;&1A<#H@2V%N
M(&EN=&4@;.1G9V$@=&EL;"!A;G;D;F1A<F4@)R5S)RX@4V5R=F5R;B!S=F%R
M861E.B``075T:%]L9&%P.B!+86X@:6YT92!R861E<F$@86YVY&YD87)E("5S
M`$%U=&A?;&1A<#H@2V%N(&EN=&4@=7!P9&%T97)A(&%N=N1N9&%R92`E<P!!
M=71H7VQD87`Z($1E="!GY7(@:6YT92!A='0@=7!P9&%T97)A(&%N=N1N9&%R
M92!I($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@34-!3"UE>'1E;G-I
M;VX@<V%K;F%S+@!!=71H7W-M8F%U=&@Z('-M8F%U=&@M97AT96YS:6]N('-A
M:VYA<RX`075T96YT:7-E<FEN9R!T:6QL($E-05`M<V5R=F5R(&UI<W-L>6-K
M861E<RX`075T96YT:7-E<FEN9R!M:7-S;'EC:V%D97,`075T96YT:7-E<FEN
M9R!M:7-S;'EC:V%D97,N("5S`$%U=&5N=&ES97)I;F<@879V:7-A9&5S(&%V
M(%)!1$E54RUS97)V97)N+@!!=71E;G1I<V5R:6YG('1I;&P@1E10+7-E<G9E
M<B!M:7-S;'EC:V%D97,N`$%U=&5N=&ES97)I;F<@=&EL;"!334(M<V5R=F5R
M(&UI<W-L>6-K861E<RX`5&EL;&?D;F=L:6=A(&MA=&5G;W)I97(Z`%1I;&QG
MY&YG;&EG82!FY&QT.@!6Y&YT87(@<.4@<W9A<@!!>F5R8F%I:F%N`$%Z=7)B
M;.4`0D]&2"UU<G/D:W1E<@!4:6QL8F%K82!T:6QL(&%N=&5C:VYI;F=S8FQO
M8VL`5&EL;&)A:V$@=&EL;"!I;G-TY&QL;FEN9V%R(&;V<B!A;G1E8VMN:6YG
M<V)L;V-K`$)A:V=R=6YD`$)A:V=R=6YD<V;D<F<`1F5L86MT:6=T(&SV<V5N
M;W)D(&;V<B!+97)B97)O<P!&96QA:W1I9W0@86YVY&YD87)N86UN(&;V<B!+
M97)B97)O<P!"86AA;6%S`$)A:')A:6X`0F%L=&ES:R`H25-/+3@X-3DM,3,I
M`$)A;F=L861E<V@`0F%R=&ED`%)A9'1I9`!"87)B861O<P!"87)B:64`0F%S
M:V%T86QO9R`G)7,G(&;V<B!B:6QD97(@:&ET=&%D97,@:6YT92X`0F%S;&EN
M:F4`5FET<GES<VQA;F0`0F5L9VEE;@!"96QI>F4`0F5N:6X`0F5R;75D80!"
M:'5T86X`1O9D96QS961A9P!";&]C:R`G)7,G(&;V<B!A<'!L:6MA=&EO;B`G
M)7,G('-A:VYA<RX`0FQO8VMI;G-TY&QL;FEN9V%R`$)L;V-K='EP`$)LY2!M
MY6YE`$)LY71T(&]C:"!V:71T`$9E=`!";VQI=FEA`$)O:VWD<FME;@!286T`
M4F%M8G)E9&0Z`%)A;6%R`$)O<VYI96X@;V-H($AE<GIE9V]V:6YA`$+E9&$`
M0F]T<W=A;F$`0F]T=&5N`$)O=79E="!)<VQA;F0`0G)A<VEL:65N`$)R:71T
M:7-K82!T97)R:71O<FEE="!I($EN9&ES:V$@;V-E86YE;@!"<G5N`$)R=6YE
M:0!"=6QG87)I96X`4'5N:W1L:7-T80!"=7)K:6YA($9A<V\`0G+D;F0@3W)A
M;F=E`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#
M4U8`0U]E;&P@:6YS=.1L;&YI;F=A<BXN+@!#86-H96EN:71I97)I;F<@Y'(@
M:6YT92!F=6QL<W3D;F1I9RX`2V%L96YD97(`3'5G;G0`2V%M8F]D:F$`2V%M
M97)U;@!+86UO=69L86=E`$MA;B!I;G1E(&YO;&QS=.1L;&$@;/9S96YO<F0@
M875T;VUA=&ES:W0L(&MO;G1A:W1A(&1I;B!A9&UI;FES=')A=/9R+@!+86X@
M:6YT92!S:W)I=F$@=&EL;"!F:6P@)R5S)P!$970@9^5R(&EN=&4@871T(&%D
M;6EN:7-T<F5R82!E>'1E<FYA('-E<W-I;VYS:&%N=&5R87)E+@!+86X@:6YT
M92!K;VYT86MT82!)34%0+7-E<G9E<FXZ("5S`$MA;B!I;G1E(/9P<&YA(&9I
M;"`G)7,G`$MA;F%D80!!=F)R>70`079B<GET('!R;V)L96UR87!P;W)T`$MA
M;B!I;G1E(')A9&5R82`G)7,G+@!+86X@:6YT92!H:71T82!E;B!T96UP<N1R
M(&UA<'`N`$MA;B!I;G1E(&9O<G1SY'1T82!U=&%N("=MY6QF:6PG+7!A<F%M
M971E<BX`2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RX`2V%N(&EN=&4@<F%D
M97)A.R`E9"!B87)N(&5X:7-T97)A<BX`2V%N(&EN=&4@9&ER:6=E<F$@;65D
M9&5L86YD92!T:6QL(&%N9VEV970@;G5M;65R+@!+87`@5F5R9&4`4G5B<FEK
M`$]P97)A=/9R`$MA=&5G;W)I97(@;V-H(')U8G)I:V5R`$MA=&5G;W)I`$-A
M>6UA;B!)<VQA;F1S`$UO8FEL=&5L969O;@!#96QL:6YS=.1L;&YI;F=A<@!#
M96QL=71F>6QL;F%D.@!#96QL:6YS=.1L;&YI;F=A<@!#96QL;65L;&%N<G5M
M.@!-;V)I;'1E;&5F;VX`0V5L=&ES:R`H25-/+3@X-3DM,30I`$-E;G1R97)A
M9`!#96YT<F%L869R:6MA;G-K82!R97!U8FQI:V5N`$-E;G1R86QE=7)O<&5I
M<VL@*$E33RTX.#4Y+3(I`$-E<G1I9FEK871D971A;&IE<@!#97)T:69I:V%T
MY&=A<F4`0V5R=&EF:6MA='!O;&EC:65S`%1C:&%D`$]R9&;V<F%N9&4`Q&YD
M<F$`Q&YD<F$@9&ET="!L]G-E;F]R9`#$;F1R82!F]G)V86QD(&ED96YT:71E
M=`#$;F1R82!N86UN(&]C:"!A9')E<W,@<V]M(&UO='1A9V%R;F$@<V5R(&[D
M<B!D92!LY'-E<B!O8V@@<W9A<F%R('#E(&1I;F$@;65D9&5L86YD96XN`,1N
M9')A('-O<G1E<FEN9W,M(&]C:"!V:7-N:6YG<VEN<W3D;&QN:6YG87(@9O9R
M(&%N=&5C:VYI;F=A<BX`071T(&)Y=&$@;/9S96YO<F0@<W3V9',@:6YT92!M
M960@9&5N(&YU=F%R86YD92!K;VYF:6=U<F%T:6]N96XN("!687(@9V]D(&MO
M;G1A:W1A(&%D;6EN:7-T<F%T]G)E;BX`5&MN`$MO;G1R;VQL97)A(&SD;FLN
M+BX`36%R:V5R82!D92!A:W1I=FET971E<B!D=2!V:6QL('5T9O9R82!N=2X`
M0VAI;&4`2VEN80!+:6YE<VES:W0@9O9R96YK;&%T("A'0C(S,3(I`$MI;F5S
M:7-K="!T<F%D:71I;VYE;&QT("A":6<U*0!6Y&QJ(&%P<&QI:V%T:6]N.@!6
MY&QJ(&SV<V5N;W)D`%;D;&H@86YVY&YD87)N86UN`%;D;&H@Y71GY')D.@!6
MY&QJ(&AU<B!D871U;2!S:V%L;"!V:7-A<SH`5N1L:B!L:7-T<W1I;"`H9O9R
M('-O<G1E<F%D92!L:7-T;W(I`%;D;&H@86YT96-K;FEN9W-K871E9V]R:65R
M('-O;2!S:V%L;"!V:7-A<R!I('-A;6UA;G-TY&QL;FEN9W-V>6XN`%;D;&H@
M9&ET="!F]G)V86QD82!A;G1E8VMN:6YG<V)L;V-K:RX`2G5L]FX`2VQA<W-D
M969I;FET:6]N(&;V<B`E<R!S86MN87,N`%)E;G-A`%)E;G-A(&9O<FUU;.1R
M`%)E;G-A($U33V9F:6-E+71A9V=A<@!296YS82!F<N5G80!296YS82!A;G;D
M;F1A<F4Z("5S`%)E;G-A(&%N=N1D;F%R90!296YS82!A;G;D;F1A<F1A=&$`
M4V5N87)E('5P<&ML87)N86YD90!+;&EC:V$@9O9R(&%T="!F;W)T<^1T=&$`
M0VQI8VMA=&5L;"!V:6$@2%144`!3=.1N9R!F]FYS=&5R`$UO;&X`5&ED:6=A
M(&UO;&X`36]L;FEN9W0`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`2V]M<')I
M;65R82!S:61O9N1L=&5T`$MO;7!R:6UE<F%D92!R86UA<@!+;VQO;6)I80!&
MY')G`$;D<F=H86YT97)A<F4`1N1R9W9A;`!+;VQU;6YE<CH`2V]L=6UN(')U
M8G)I:V5R`$QU<W1I9VAE=&5R`$MO;6UA;F1O`$MO;6UA;F1O9O9N<W1E<@!+
M;VUM96YT87(`3F%M;@!#;VUO<F]S`$;V<F5T86<`4VQU=&;V<F0`4VMR:78@
M;65D9&5L86YD92`H)7,I`$1A=&]R97(`5N1D97(`5N1D97(`2V]N9FEG=7)A
M=&EO;G-S:VEL;&YA9&5R`$EN<W3D;&QN:6YG87(@9O9R(&%T="!S>6YK<F]N
M:7-E<F$@;65D(&AA;F1D871O<F5R+"!S;6%R=&$@=&5L969O;F5R(&]C:"!/
M=71L;V]K`$MO;F9I9W5R871I;VX@8F5H]G9E<B!U<'!D871E<F%S+@!+;VYF
M:6=U<F5R82`E<P!"96MRY&9T82!L]G-E;F]R9`!+;VYG;P!+;VYG;P!&]G)B
M:6YD96QS92!M:7-S;'EC:V%D97,N`$;V<F)I;F1E;'-E(&UI<W-L>6-K861E
M<SH@`$;V<F)I;F1E;'-E(&UE9"!P=6)L:6L@;GEC:V5L<V5R=F5R(&YE:V%D
M97,N`$;V<F)I;F1E;'-E(&UE9"!P=6)L:6L@;GEC:V5L<V5R=F5R(&YE:V%D
M97,Z("5S("@E<RD`1O9R8FEN9&5L<V4@;65D($944"US97)V97(@;6ES<VQY
M8VMA9&5S+@!+;VYT86MT97(`2V]N=&%K=&5R(&QA9&5S('1I;&P@:2!D:6X@
M861R97-S8F]K+@!);FYE:.5L;'-T>7`@9O9R(&MO;7!R:6UE<F%D(&9I;#H@
M`$EN;F5HY6QL(&D@)R5S)P!&;W)T<^1T=`!#;V]K($ES;&%N9',`0V]O:VEE
M`$MO<&EE<F$`2V]P:65R:6YG(&UI<W-L>6-K861E<SH@)7,`2V]P:65R82!M
M87)K97)I;F<`36%J<V)L;VUM80!+;W-T;F%D<RU)1`!#;W-T82!2:6-A`$5L
M9F5N8F5N<VMU<W1E;@!+86X@:6YT92!01U`M:W)Y<'1E<F$@;65D9&5L86YD
M92X`2V%N(&EN=&4@4$=0+6MR>7!T97)A(&UE9&1E;&%N9&4Z(`!+86X@:6YT
M92!01U`M<VEG;F5R82!M961D96QA;F1E+@!+86X@:6YT92!01U`M<VEG;F5R
M82!M961D96QA;F1E.B``2V%N(&EN=&4@4R]-24U%+6MR>7!T97)A(&UE9&1E
M;&%N9&4N`$MA;B!I;G1E(%,O34E-12US:6=N97)A(&UE9&1E;&%N9&4N`$MA
M;B!I;G1E(&SD9V=A('1I;&P@:V]N=&%K="X@)7,`36ES<VQY8VMA9&5S(&%T
M="!K;VYT86MT82!,1$%0('-E<G9E<BX`2V%N(&EN=&4@=F5R:69I97)A(&MO
M;G1O<V%L9&\N("5S`$MU;F1E(&EN=&4@86YS;'5T82!T:6QL($Q$05`M<V5R
M=F5R+@!+86X@:6YT92!K;VYT86MT82!S97)V97(@)R5S)R!V:6$@1E10.B`E
M<P!+86X@:6YT92!S:V%P82!D:7-T<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I
M;G1E(&1E:W)Y<'1E<F$@4$=0+61A=&$N`$MA;B!I;G1E(&1E:W)Y<'1E<F$@
M4$=0+61A=&$Z(`!+86X@:6YT92!D96MR>7!T97)A(%,O34E-12UD871A+@!+
M86X@:6YT92!R861E<F$@:V]N=&%K="X@)7,`2V%N(&EN=&4@<F%D97)A(&1I
M<W1R:6)U=&EO;G-L:7-T82X@)7,`2V%N(&EN=&4@<F%D97)A('5P<&=R861E
M<FEN9W-S8W)I<'0@=&EL;#H@)7,N`$MA;B!I;G1E(&)E<W3D;6UA(&UO='1A
M9V%R96YS(&50;W-T+6%D<F5S<RX`2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@
M861R97-S8F]K+@!+86X@:6YT92!HY&UT82!K;VUP;&5T="!D:7-T<FEB=71I
M;VYS;&ES=&$N`$MA;B!I;G1E(&CD;71A(&MO;7!L971T(&QI<W1A(/9V97(@
M9&ES=')I8G5T:6]N<VQI<W1O<BX`2V%N(&EN=&4@;&%D9&$@<W1R871E9VD@
M)R5S)RX`2V%N(&EN=&4@;&%D9&$@<W1R871E9VD@)R5S)RX`2V%N(&EN=&4@
M<VMA<&$@;6%P<"`G)7,G+@!+86X@:6YT92!S:V%P82!M87!P("<E<R<N`$MA
M;B!I;G1E(&CD;71A('!U8FQI:R!N>6-K96P@9G+E;B!N>6-K96QS97)V97)N
M+@!+86X@:6YT92#V<'!N82`G)7,G(&;V<B!S:W)I=FEN9RX`2V%N(&EN=&4@
M]G!P;F$@)7,N`$MA;B!I;G1E(/9P<&YA("<E<R<@9O9R('-K<FEV:6YG+@!+
M86X@:6YT92#V<'!N82!-86EN=&5N86YC95]487-K(&UO9'5L("5S`$MA;B!I
M;G1E(/9P<&YA(&UA<'!E;B`G)7,G`$MA;B!I;G1E(/9P<&YA(&UA<'`@)R5S
M)P!+86X@:6YT92!K;VYT86MT82!,1$%0('-E<G9E<BX`2V%N(&EN=&4@;.1S
M82`E<RX`1&5T(&=I8VL@:6YT92!A='0@Y71E<G-TY&QL82!L]G-E;F]R9&5T
M(&;V<B!D96X@86YG:79N82!A;G;D;F1A<F5N+B!.Y6=O;B!E;&QE<B!NY6=R
M82!A=B!U<'!G:69T97)N82#D<B!I;G1E(&MO<G)E:W1A+B!&]G)S]FL@:6=E
M;B!E;&QE<B!K;VYT86MT82!A9&UI;FES=')A=/9R96X@;VT@9'4@8F5H]G9E
M<B!H:N1L<"X`2V%N(&EN=&4@:.1M=&$@04-,`$MA;B!I;G1E(&CD;71A(&%D
M<F5S<V)O:RX@)7,`2V%N(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI<W1A
M+B`E<P!+86X@:6YT92!HY&UT82!D:7-T<FEB=71I;VYS;&ES=&]R+B`E<P!+
M86X@:6YT92!HY&UT82!D<V5R=F5R9G5N:W1I;VYE<@!+86X@:6YT92#E=&5R
M<W3D;&QA(&MO;F9I9W5R871I;VYE;BX`2V%N(&EN=&4@<F%D97)A(&UA<'`@
M)R5S)RX`2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RX`2V%N(&EN=&4@<W!A
M<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,N`$MA;B!I;G1E('-P87)A(&)A8VMU
M<"UK;VYF:6=U<F%T:6]N+@!+86X@:6YT92!S<&%R82!E;B!B86-K=7`M:V]N
M9FEG=7)A=&EO;CH@)7,N`$MA;B!I;G1E('-P87)A('5P<&=R861E<FEN9W-S
M8W)I<'0@=&EL;#H@)7,N`$MA;B!I;G1E('-P87)A(&)A8VMU<"UK;VYF:6=U
M<F%T:6]N("5S+@!+86X@:6YT92!S<&%R82!K;VYF:6=U<F%T:6]N<V9I;&5N
M("5S+B!$=2!K86X@86YT:6YG96X@86YVY&YD82!E;B!A=B!A;'1E<FYA=&EV
M96X@871T('-P87)A(&MO9&5N('1I;&P@)7,@96QL97(@:V]P:65R82!K;V1E
M;B!N961A;B!T:6QL("5S+@!+86X@:6YT92!S]FMA(&D@3$1!4"UK871A;&]G
M96XN`$MA;B!I;G1E(')A9&5R82`G)7,G+@!+86X@:6YT92!R861E<F$@)R5S
M)RX`2V%N(&EN=&4@=7!P9&%T97)A(&MO;G1A:W0N("5S`$MA;B!I;G1E('5P
M<&1A=&5R82!D:7-T<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I;G1A('-P87)A
M(&MO;F9I9W5R871I;VX@9O9R("<E<R<Z("5S`$MA;B!I;G1E(&AI='1A($UO
M>FEL;&%S('-I9&]FY&QT+B!697)I9FEE<F$@871T('-I9&]FY&QT970@Y'(@
M]G!P970N`$MA;B!I;G1E(&=E(&%N=N1N9&%R96X@)R5S)R!A;F=I=FYA('+D
M='1I9VAE=&5R('1I;&P@;6%P<&5N("<E<R<Z("5S`%+D:VYA9"!T97AT`$QA
M;F0`2W5R<V5R`%-K87!A`%-K87!A(&SD;FL`4VMA<&$@;GD`4VMA<&$@=6YD
M97)M87!P`%-K87!A9`!"96CV<FEG:&5T97(@9O9R(.1G87)A`$MR961I=&MO
M<G1S;G5M;65R`$MR;V%T:65N`$MU8F$`06MT=65L;&$@-"!F87-E<@!!:W1U
M96QL('-E<W-I;VX`06MT=65L;"!T:60`06MT=65L;"!54DP@Y'(`06MT:79A
M(&%N=N1N9&%R90!!:W1U96QL="!VY&1E<@!!:W1U96QL82!V:6QL:V]R.B``
M06MT=65L;"!S=&EL`%-K<N1D9&%R<WD@86MT:79I=&5T97(@<V]M(&OV<G,@
M=FED(&EN;&]G;FEN9R!T:6QL("5S+@!+;&EP<"!U=`!+;&EP<"!U<G9A;`!#
M>7!E<FX`2WER:6QL:7-K("A+3TDX+5(I`$MY<FEL;&ES:R`H5VEN9&]W<RTQ
M,C4Q*0!+>7)I;&QI<VLO56MR86EN<VL@*$M/23@M52D`5&IE8VMI96X`1$0`
M1&%G;&EG`$1A=&%4<F5E(&)LY&1D<F%R90!$871A8F%S=7!P<VQA9P!$871U
M;0!$871U;2!M;W1T86=E=`!$871U;79A;`!$86<`7U)A9&5R82!K;VQU;6X`
M9&5C96UB97(`1&5C:6UA;&5R`$%V8O9J=`!-:6YS:V$@:6YD<F%G`$;V<G9A
M;'0`1O9R=F%L9"!FY')G`$;V<G9A;&0@:61E;G1I=&5T`$;V<G9A;'0@86YT
M96-K;FEN9W-B;&]C:P!&]G)V86QT('-K86P`1O9R=F%L9"!S;W)T97)I;F=S
M:W)I=&5R:6$Z`$;V<G9A;&0@<V]R=&5R:6YG<V]R9&YI;F<`1&5F:6YI=&EO
M;F5R`$1E;&5G97)A('!O<VET:6]N`$1E;&5G97)A9`!2861E<F$`4F%D97)A
M(&-E;&P`4F%D97)A(&)E:W+D9G1E;'-E`%)A9&5R82!G<G5P<`!2861E<F$@
M;&]G9P!2861E<F$@8F5H]G)I9VAE=`!2861E<F$@;V-H(')E;G-A(&UE9&1E
M;&%N9&5N`$9U;FMT:6]N(&;V<B!K;F%P<&5N(%)A9&5R80!2861E<F$@8V5L
M;`!2861E<F$@:V]L=6UN`%)A9&5R82!B969I;G1L:6<@86QT97)N871I=FUA
M;&P`4F%D97)A9&4@;65D9&5L86YD96X`4F%D97)A(&)E:/9R:6=H970@9O9R
M("<E<R<`4F%D97)A(&)E:/9R:6=H970@9O9R("<E<R<@;V-H('5N9&5R8F5H
M]G)I9VAE=&5R/P!2861E<F$@<F%D`%)A9&5R82!V86QD(&ED96YT:71E=`!2
M861E<F$@=6YD97)M87!P87(`4F%D97)A(&%K='5E;&P@:V]L=6UN`%)A9&5R
M82!A:W1U96QL(')A9`!2861E<F$@9&5N(&CD<B!LY&YK96X`4F%D97)A(&%N
M=&5C:VYI;F<`4F%D97)A9&4@=7!P9W)A9&5R:6YG<W-C<FEP=&5T("<E<R<N
M`$QE=F5R86YS=&ED`$1A;FUA<FL`079S;.4@8F5GY')A;@!!=G-LY2!B96?D
M<F%N(&]M(&QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N`$9A;&QA;F1E`$)E
M<VMR:78@<')O8FQE;65T`$)E<VMR:79N:6YG`$)E<VMR:79N:6YG.@!$971A
M;&IE<B`H;V-K<^4@:2!(;W)D97,@;&]G9V9I;"DZ`$1E=&%L:F5R(&AA<B!L
M;V=G871S(&;V<B!S>7-T96UA9&UI;FES=')A=/9R96XN`%5T=F5C:VQI;F<`
M1&%G9W!U;FMT`$1A9V=P=6YK="!F]G(@<V5N87-T92!T:6UM96XZ(`!$86=G
M<'5N:W0Z(`!2:6MT;FEN9R!VY&YS=&5R('1I;&P@:/9G97(`4FEK=&YI;F<@
M:/9G97(@=&EL;"!VY&YS=&5R`$MA=&%L;V<`5FES82`R-"UT:6UM87)S(&ML
M;V-K83\`5FES;FEN9W-I;G-TY&QL;FEN9V%R`%9I<V$@9&5T86QJ97)A9"!F
M]G)U='/D9V5L<V4`5FES82!F]G)U='/D9V5L<V4@*%1!1BD`5FES;FEN9W-F
M;W)M870`079S:VEL:F%R90!$:FEB;W5T:0!2861E<F$@:6YT90!!;G;D;F0@
M:6YT92!M86EN=&5N86YC92YP:'`@9&ER96MT`%9I;&P@9'4@8F5K<N1F=&$@
M<F%D97)I;F<@878@<&]S=&5R/P!);FYE:.5L;&5R(&;V<G-T82!R861E;B!F
MY&QT;F%M;F5N/R!/;2`G:F$G+"!M87)K97)A(&CD<CH`1&]M:6YI:V%N<VMA
M(')E<'5B;&EK96X`2&%R(&1U(&EN9V5T(&MO;G1O/R!296=I<W1R97)A(&1I
M9RX`2.1M=&$`2.1M=&$@)7,`2.1M=&$@9V5N97)E<F%D(&MO;F9I9W5R871I
M;VX@<V]M(%!(4"US:W)I<'0N`$1R;W!P;&ES=&$`1')O9V5R`$4M<&]S=`!$
M<FEV<G5T:6X@9O9R($4M<&]S="!T:6QL(%--4RUB<GEG9V$[(&;V<B!O<&5R
M873V<F5R('-O;2!T:6QL:&%N9&%HY6QL97(@9&5N;F$@=&KD;G-T+@!&14P`
M16MU861O<@#$;F1R80#$;F1R82`G)7,G`,1N9')A(&)L;V-K`,1N9')A(&=R
M=7!P`,1N9')A(&%N=&5C:VYI;F<`Q&YD<F$@8F5H]G)I9VAE=`#$;F1R82!B
M96CV<FEG:&5T97(`Q&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`E<P#$;F1R82!K
M871E9V]R:65R(&]C:"!FY')G97(`Q&YD<F$@:6YS=.1L;&YI;F=A<B!F]G(Z
M`,1N9')A(&)E:/9R:6=H971E<B!F]G(@)R5S)P#$;F1R82!B96CV<FEG:&5T
M97(@9O9R("<E<R<`571B:6QD;FEN9P!%9WEP=&5N`$5L(%-A;'9A9&]R`$5L
M96UE;G0N+BX`16T`12UP;W-T`$4M<&]S=&%D<F5S<P!%+7!O<W1A9')E<W-E
M<B!MY7-T92!S=.1M;6$@]G9E<G)E;G,N`$4M<&]S=&UE9&1E;&%N9&4@;65D
M(&)E:W+D9G1E;'-E`$4M<&]S="!T:6QL(%--4RUB<GEG9V$`2^1N<VQO:6MO
M;F5R`%1O;2!A;G1E8VMN:6YG`%1O;70@;65D9&5L86YD92X`5&]M="!R97-U
M;'1A="X`5&]M="!S]FMK<FET97)I80!3;'5T`%-L=70@Y7(`1O9R<W1O<F$@
M961I=&]R`$%N9V4@<_9K=N1G("A54DPI('1I;&P@8FEL9&5N(&CD<@!32W)I
M=B!B;VMS=.1V97)N82!N961A;CH`1F5L`$9E;"!V:60@<VMA<&%N9&4@878@
M8FQO8VLZ("5S`$9E;"!V:60@<F%D97)I;F<@878@<WEN:W)O;FES97)I;F=S
M;>1R:V4Z("5S`$9E;"!V:60@<F%D97)I;F<@878@<WEN:W)O;FES97)I;F=S
M;&]G9SH@)7,`1F5L(&[D<B!I;FYE:.5L(&CD;71A9&5S.B`E<P!&96P@=6YD
M97(@<^1N9&YI;F<@878@<W9A<G-M961D96QA;F1E.B`E<P!&96P@=FED('5P
M<&1A=&5R:6YG(&%V(&SV<V5N;W)D.B`E<P!&96P@=FED('-K<FEV;FEN9R`G
M)7,G+@!&96P@=FED('-K<FEV;FEN9R!A=B`G)7,G+@!%<W1L86YD`$5T:6]P
M:65N`$5T;FES:P!%=7)O<&$`5F%R(#$U.F4@;6EN=70`5F%R86YN86X@;6EN
M=70`5F%R(#,P.F4@<V5K=6YD`%9A<B`U.F4@;6EN=70`5F%R:F4@:6YL;V=G
M;FEN9P!687)J92!H86QV=&EM;64`5F%R:F4@;6EN=70`17AE;7!E;"!PY2!V
MY')D96XZ`$OV<@!%>'!A;F1E<F$`17AP86YD97)A('-I9&]FY&QT`$;V<G;D
M;G1A9&4@)RDG`$;V<G;D;G1A9&4@96YS:VEL="!O<F0@96QL97(@8VET97)A
M="!S]FMB96=R97!P`$;V<F9A;&QO9&%T=6T`17AP;VYE;G0`17AP;W)T97)A
M`$5X<&]R=&5R82!A;G1E8VMN:6YG87(`1O9R9W)U;F1S9N1R9P!,861D82!U
M<'`@:V]N9FEG=7)A=&EO;B!V:6$@1E10+@!(96QA('1E>'1E;@!-:7-S;'EC
M:V%D97,@871T(&CD;71A(&EN<W3D;&QN:6YG87(N`$UI<W-L>6-K861E<R!A
M='0@:V]N=&%K=&$@3$1!4"!S97)V97(N`$UI<W-L>6-K861E<R!A='0@:V]N
M=&%K=&$@4TU"('-E<G9E<BX`36ES<VQY8VMA9&5S(&%T="!K;W!I97)A(&9R
MY6X@)R5S)RX`36ES<VQY8VMA9&5S(&%T="!K;W!I97)A('1I;&P@)R5S)RX`
M36ES<VQY8VMA9&5S(&%T="!S:V%P82!N>2!305-,+6;V<F)I;F1E;'-E+@!-
M:7-S;'EC:V%D97,@871T(&9L>71T82!T:6QL("<E<R<N`$UI<W-L>6-K861E
M<R!A='0@:.1M=&$Z("5S`$)R80!&86QK;&%N9'/V87)N80!&Y'+V87)N80!&
M871A;'0@9F5L.@!&87@`1F%X87(`9F5B<G5A<FD`2^1N;G,@<V]M`$OD;FYS
M('-O;3H@`$;E=&%L:6=A('-K=7)A<@!&Y71A;&EG82!S;O9S:W5R87(`1N1L
M=&UA=')I<P!&:6=L970@0T%05$-(00!&:6=L971T>7!S;FET=`!&:6II`$9I
M;`!!;G1A;"!F:6QE<CH@)7,@9FEL`$%N=&%L(&9I;&5R.B`E<R!F:6QE<@!&
M:6QH86YT97)A<F4`1FEL;F%M;@!&:6QV86P`1FEL=7!P;&%D9&YI;F<`1FEL
M=7!P;&%D9&YI;F<@<W3V9',@:6YT92X`1FEL=&5R`$9I;FQA;F0`1O9R<W1A
M(&AA;'9A;@!&]G)S=&$@:W9A<G1E;@!-87!P("5S(&5X:7-T97)A<B!I;G1E
M+@!&;VYT9N1R9P!-870`1O9R('=E8F)LY'-A<F4@<V]M(&EN=&4@<W3V9&5R
M(&)I;&1E<@!0<F]G;F]S("A4048I`$%N=&%L(&1A9V%R(&;V<B!P<F]G;F]S
M("AV87)J92!D86<@8F5T>61E<B!E;B!P<F]G;F]S(&;V<B!D86<@;V-H(&5N
M(&;V<B!N871T*0!';/9M="!D:71T(&SV<V5N;W)D/P!&;W)M=6SD<@!6:7-H
M971S;W)D`%1Y<"!A=B!V:7-H971S;W)D`%9I<VAE='-O<F0`5FES:&5T<V]R
M9"`R`$9O<G5M`%9I9&%R8F5F;W)D<F%R`$9R`%)A;6%R`$9R86YK<FEK90!&
M<F%N:W)I:V4L($UE=')O<&]L`$QE9&EG+U5P<'1A9V5N(&EN9F]R;6%T:6]N
M`$QE9&EG+U5P<'1A9V5N('-V87(`3&5D:6<O=7!P=&%G96XM9O9R9G+E9V%N
M`%-V87(@<.4@;&5D:6<O=7!P=&%G96XM9O9R9G+E9V%N`$9R86YS:V$@1W5I
M86YA`$9R86YS:V$@4&]L>6YE<VEE;@!&<F%N<VMA('/V9')A('1E<G)I=&]R
M:65R`$9RY6X`1G+E;B!D96X@`$9U;&QS=.1N9&EG(&)E<VMR:79N:6YG`$9U
M;&QMY6YE`$9U;&QS=.1N9&EG="!N86UN`$=A8F]N`$=A;&QE<FD@871T('1A
M(&)I;&0@9G+E;@!'86QL97)I.@!'86UB:6$`06QL;>1N;F$@:6YS=.1L;&YI
M;F=A<@!'96YE<F5R82!K;VYF:6=U<F%T:6]N(&;V<B`E<P!'96YE<F5R860@
M:V]D`$=E;W)G:65N`%1Y<VML86YD`$=H86YA`$=I8G)A;'1A<@!&]G)N86UN
M`$=L;V)A;&$@:6YS=.1L;&YI;F=A<@!/2P!';V5D96P`1V]O9VQE:V%R=&]R
M`$=O;V=L97/V:VYI;F<`1W+E<VMA;&$`1W)E:VES:R`H25-/+3@X-3DM-RD`
M1W+V;@!'<O9N;&%N9`!'<F%N861A`$=RY0!'<G5P<&%D;6EN:7-T<F%T:6]N
M`$=R;W5P7VQD87`Z($MA;B!I;G1E(&SD9V=A('1I;&P@9W)U<'`@)R5S)RX@
M4V5R=F5R;B!S=F%R861E.B``1W)O=7!?;&1A<#H@2V%N(&EN=&4@<F%D97)A
M(&=R=7!P("<E<R<`1W)O=7!?;&1A<#H@2V%N(&EN=&4@=7!P9&%T97)A(&=R
M=7!P("<E<R<`1W)U<'!E<@!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'Y'-T
M8F5H]G)I9VAE=&5R`%1JY&YS=&5R(&;V<B!GY'-T97(`1^1S=&)O:P!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=6EN96$`2%1-3`!(5$U,07)E82!VY&=R87(@
M871T(')A9&5R82!S:7-T82!C96QL96X@:2!E;B!R860N`$A434Q!<F5A(';D
M9W)A<B!A='0@<F%D97)A('-I<W1A(&MO;'5M;F5N(&D@96X@=&%B96QL+@!(
M5$U,07)E82!VY&=R87(@871T(')A9&5R82!S:7-T82!R861E;B!I(&5N('1A
M8F5L;"X`2%144"!!=71E;G1I<V5R:6YG('-A:VYA<RX`2&%I=&D`2&%S:&%L
M9V]R:71M`$1I;6UA`%)U8G)I:P!2=6)R:6ME<@!(96%R9"T@;V-H($UC1&]N
M86QD]F%R;F$`2W)A9G1I9V$@Y7-K<VMU<F%R`$AE8G)E:7-K("A)4T\M.#@U
M.2TX+4DI`$CV:F0`2/9J9"`H<&EX;&%R*0!(:N1L<`!(:N1L<"!M960@961I
M=&]R;@!(:N1L<&9U;FMT:6]N`$AE;6ES9N1R`$CD<B#D<B!B]G)J86X@878@
M9FEL96XZ`$CV9P!(95]M`$AE;0!!9')E<W,L(&AE;0!(96UK871A;&]G`%1E
M;&5F;VXL(&AE;0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z($]G:6QT:6=T("5S(%A-3"UD871A('#E='+D9F9A9&5S(&D@;65D9&5L
M86YD92`E<P!(;W)D92]+;VQA8CH@26YG970@;65D9&5L86YD92!M871C:&%R
M(&]B:F5K=&5T("5S`$AO<F1E+TMO;&%N.B!);F=E="!O8FIE:W0@878@='EP
M96X@)7,@:&ET=&%D97,@:2!M961D96QA;F1E="`E<P!(;W)D92]+;VQA8CH@
M4F%D97)A9&4@)7,@)R5S)P!(;W)D92]+;VQA8CH@26YT96=R871I;VYS;6]T
M;W)N(&MRY'9E<B`G9&]M>&UL)RUT:6QLY&=G970@9O9R(%!(4`!(;W)D92]+
M;VQA8CH@2V%N(&EN=&4@<VMA<&$@;GET="!834PM='+D9"!F]G(@;V)J96MT
M("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!R861E<F$@)7,@)R5S)SH@)7,`
M2&]R9&4O2V]L86(Z($MA;B!I;G1E(&CD;71A($U)341%+4E$(&;V<B!D96QE
M;B!M960@='EP("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!S>6YK<F]N:7-E
M<F$@)7,@)R5S)SH@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E('-Y;FMR;VYI
M<V5R82!U=&1E;&YI;F=A<CH@)7,`2&]R9&4O2V]L86(Z($]KY&YD('5T9&5L
M;FEN9R`G)7,G`$AO<FES;VYT96QL(&QI;FIE`$AO<FES;VYT96QL('5T9GEL
M;&YA9`!(;W)I<V]N=&5L;#H`2'5R(&AA;6YA9&4@9'4@:.1R/R`H5F%R(&=O
M9"!R87!P;W)T97)A(&1E='1A(2D`2'5R(&WE;F=A(&MO;'5M;F5R('9I;&P@
M9'4@<VSE(&EH;W`_`$AU<B!MY6YG82!FY&QT("AK;VQU;6YE<BD@9FEN;G,@
M9&5T/P!(=7(@;>5N9V$@<F%D97(@=FEL;"!D=2!S;.4@<V%M;6%N/P!&=6MT
M:6=H970`1G5K=&EG:&5T.@!(=6UO<FES=&5R`%5N9V5R;@!3:V%P86YD92!A
M=B!)34%0+6UA<'`@;6ES<VQY8VMA9&4Z("5S`%)A9&5R:6YG(&%V($E-05`M
M;6%P<"!M:7-S;'EC:V%D97,Z("5S`%-K87!A;F1E(&%V('%U;W1A(&;V<B!)
M34%0+6UA<'`@;6ES<VQY8VMA9&5S.B`E<P!)4"UA9')E<W,`25`M861R97-S
M(.1R(&EN=&4@=&EL;&?D;F=L:6<N`$E0+6%D<F5S<R#D<B!I;G1E(&EN;VT@
M9V]D:^1N="!#2412+6)L;V-K+@!&]G)S]FL@871T(&MR:6YG9^4@25`M;.5S
M+@!)7VYF;V=A(')A9"!F]G)E`$ES;&%N9`!%;F)A<G0@:6MO;F5R`$EK;VYE
M<B!F]G(@)7,`26MO;F5R(&UE9"!T97AT`$ED96YT:71E=&5N<R!N86UN.@!/
M;2!D970@:6YT92!V:7-A<R!K;W)R96MT+"`E<R!F]G(@871T(/9P<&YA(&D@
M;GET="!F]FYS=&5R+@!/;2!D=2!I;G1E('-E<B!NY6=R82!I:V]N97(@;N1R
M(&1U(&%N=N1N9&5R($EN=&5R;F5T($5X<&QO<F5R+"!SY2!K86X@9'4@8F5H
M]G9A(&UA<FME<F$@9&5N;F$@<G5T82!F]G(@871T('-TY&YG82!A=B!G96YO
M;7-K:6YL:6=A(%!.1RUB:6QD9FEL97(N`$]M(&1U('-E<B!D96YN82!T97AT
M(&UE;B!I;F=E;B!B:6QD+"!SY2!K86X@:6YT92!D:6X@=V5B8FSD<V%R92!V
M:7-A(&1E;B!B:6QD(&1U(&;V<G/V:V5R(&QA9&1A('5P<"X`1O9R:&%N9'-G
M<F%N<VMA(&)I;&0Z`$)I;&1A9')E<W,`0FEL9&%D<F5S<SH`0FEL9"!F<N5N
M(&=A;&QE<FD`0FEL9"!F<N5N(&=A;&QE<FDZ`$QA9&1A('5P<"!B:6QD`$)I
M;&1E<@!);7!O<G1E<F$@86YT96-K;FEN9V%R+"!S=&5G("5D`$EM<&]R=&5R
M82P@<W1E9R`E9`!);7!O<G1E<F$O97AP;W)T97)A(&%N=&5C:VYI;F=A<@!)
M;7!O<G1E<F%D92!FY&QT.B`E<P!);7!O<G1E<F%D92!FY&QT.@!0Y6?E96YD
M90!);E]F;V=A(')A9"!E9G1E<@!&96QA:W1I=B!A:W1I=FET971S:V]D('-P
M96-I9FEC97)A9"X`1F5L86MT:6=T(&%N=N1N9&%R;F%M;B!O8V@O96QL97(@
M;/9S96YO<F0N`$]G:6QT:6=T(&%N=N1N9&%R;F%M;B!E;&QE<B!A;'1E<FYA
M=&EV(&%D<F5S<RX@1O9R<_9K(&EG96X@96QL97(@:V]N=&%K=&$@861M:6YI
M<W1R873V<F5N(&]M(&1U(&)E:/9V97(@:&KD;'`N`-9K82!I;F1R86<`26YD
M:65N`$EN9&EV:61U96QL82!A;G;D;F1A<F4`26YD;VYE<VEE;@!);F9O`$EN
M9F]R;6%T:6]N`$EN9F]R;6%T:6]N(.1R(&EN=&4@=&EL;&?D;F=L:6<@;.1N
M9W)E+@!);F9O9V$@:U]O;'5M;B!E9G1E<@!);F9O9V$@8FEL9`!);F9O9V$@
M=&%B96QL`$EN9F]G82!W96)B;.1N:P!);F9O9V$@7VMO;'5M;B!F]G)E`$EN
M9F]G82!N>2!K;VQU;6X@969T97(@86MT=65L;"!K;VQU;6X`26YF;V=A(&YY
M(&MO;'5M;B!F]G)E(&%K='5E;&P@:V]L=6UN`$EN9F]G82!R860@969T97(@
M86MT=65L;"!R860`26YF;V=A(&YY(')A9"!F]G)E(&5K='5E;&P@<F%D`$EN
M9F]G82!P87)A9W)A9B!E9G1E<B!A:W1U96QL(&YO9`!);F9O9V$@<&%R86=R
M868@9O9R92!A:W1U96QL(&YO9`!);F9O9V$@86QT97)N871I=B!M86QL`$EN
M9F]G82!C96QL(&5F=&5R`$EN9F]G82!C96QL(&;V<F4`26YF;V=A(&MO;'5M
M;B!E9G1E<@!);F9O9V$@:V]L=6UN(&;V<F4`26YF;V=A(&UE9&1E;&%N9&5N
M`$EN9F]G82!P87)A9W)A9B!E9G1E<@!);F9O9V$@<&%R86=R868@9O9R90!)
M;F9O9V$@<F%D(&5F=&5R`$EN9F]G82!R860@9O9R90!!;F=E(&5R9F]R9')A
M="!S=F%R('1I;&P@<^1K97)H971S9G+E9V%N.@!);F9O9V$OQ&YD<F$@8FEL
M9`!);F9O9V$OQ&YD<F$@;.1N:P!/=&EL;'+D8VML:6<@:W)E9&ET(&;V<B!A
M='0@<VMI8VMA('1I;&P@9&ES=')I8G5T:6]N<VQI<W1A+@!/=&EL;'+D8VML
M:6<@:W)E9&ET+@!(96QT86P`2&5L=&%L<VQI<W1A`$]G:6QT:6<@Y71GY')D
M(&;V<B!D96X@:.1R(&MO;7!O;F5N=&5N+@!/9VEL=&EG(%5$2"`H)W5S97(@
M9&%T82!H96%D97(G*2X`3V=I;'1I9W0@6DE0+6%R:VEV9&%T80!&96QA:W1I
M9R!A<'!L:6MA=&EO;BX`1F5L86MT:6=T(&)A=&-H+4E$`$9E;&%K=&EG(&1A
M=&$@<VMI8VMA9"X`1F5L86MT:6<@9&5S=&EN871I;VYS861R97-S+@!&96QA
M:W1I9W0@9FEL9F]R;6%T`$]G:6QT:6<@;&EC96YS;GEC:V5L+@!&96QA:W1I
M9R!O<G0@<W!E8VEF:6-E<F%D+@!&96QA:W1I9R!M961D96QA;F1E7W1Y<"X`
M1F5L86MT:6<@96QL97(@<V%K;F%D(&%P:5]I9"X`1F5L86MT:6=T(&5L;&5R
M('-A:VYA9"!P87)A;65T97(N`$9E;&%K=&EG(/9V97)L:6=G86YD92!B96CV
M<FEG:&5T+@!&96QA:W1I9W0@<&%R=&YE<BUI9"X`1F5L86MT:6<@<')O9'5K
M=&MO9"X`1F5L86MT:6=T('!R;W1O:V]L;"X`1F5L86MT:6<@;6]T=&%G87)E
M.B`G)7,G`$9E;&%K=&EG="!U=&1E;&YI;F=S;V)J96MT`$9E;&%K=&EG(&%V
M<^1N9&%R861R97-S+@!&96QA:W1I9W0@=6YI8V]D92UD871A`$EN=F5N=&%R
M:65R`$EN=F5R=&5R82!U<G9A;`!)<F%N`$ER86L`27)L86YD`$ES;&4@;V8@
M36%N`$5N<W1A:V$@Y7-K<VMU<F%R`$ES<F%E;`!5=&;D<F1A="!A=@!+=7)S
M:78`271A;&EE;@!*86UA:6-A`&IA;G5A<FD`2F%P86X`2F%P86YS:R`H25-/
M+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YI96X`:G5L:0!J=6YI`$IU<W1E<F$`
M0V5N=&5R:G5S=&5R80!*=7-T97)A(&KD;70`5N1N<W1E<FIU<W1E<F$`2/9G
M97)J=7-T97)A`$ME;GEA`$ME<F)E<F]S<V5R=F5R;B!A=G9I<V%D92!A=71E
M;G1I<V5R:6YG96XN`$YY8VME;"!S:V%P860`1FEN9V5R<')I;G0`3GEC:V5L
M;.1N9V0`3GEC:V5L='EP`$YY8VME;&%N=N1N9&%N9&4`3GEC:V5L(&9I;FYS
M(')E9&%N('#E(&1E;B!P=6)L:6MA(&YY8VME;'-E<G9E<FXN`$)A<FX`2VER
M:6)A=&D`2V]L86(`3F]R9&MO<F5A`%-Y9&MO<F5A`$MO<F5A;G-K("A%54,M
M2U(I`$MU=V%I=`!+:7)G:7-T86X`3&%?>6]U=`!3<'+E:P!,86]S`%-I<W1A
M(&AA;'9A;@!396YA<W0@Y&YD<F%D`$SV<V5N;W)D(.1N9')A9&5S`%-I<W1A
M(&MV87)T86QE=`!396YA<W0@=7!P9&%T97)A9#H`4V5N87-T92!I;FQO9V=N
M:6YG.B`E<P!396YA<W1E(&EN;&]G9VYI;F<Z("5S(&9RY6X@)7,`4V5N87-T
M92!I;FQO9V=N:6YG.B!!;&1R:6<`3&5T=&QA;F0`3&%V96YD97(`3&%G`$QA
M>6]U=`!,Y&UN82!T;VT@9O9R(&%T="!S=.1N9V$@878@:V%N=&QI;FIE`$QI
M8F%N;VX`5N1N<W1E<@!6Y&YS=&5R<G5B<FEK`%;D;G-T97)VY')D96X`3&5S
M;W1H;P!.:7;E`$QI8F5R:6$`3&EB>65N`$QI96-H=&5N<W1E:6X`3&IU<V)L
MY0!$=6=G<F5G;@!,Y'1T(')E9VX`3.1T="!F]G)M:61D86=S<F5G;@!,Y'1T
M(&5F=&5R;6ED9&%G<W)E9VX`3.1T="!R96=N<VMU<@!,Y'1T(')E9VX@;65D
M(.5S:V$`3.1T="!S;O8`3.1T="!S;O9S:W5R`$QI;65R:6-K`$SD;FL`3.1N
M:V5N('!E:V%R('#E.@!,Y&YK82!E+7!O<W1A9')E<W-E;B!T:6QL(&9U;FMT
M:6]N96X@9O9R(&%T="!S:V%P82!N>71T(&UE9&1E;&%N9&4`3.1N:V%R`$MA
M:V$`3&ES=&$@+2!A;G;D;F1A<F4@:V%N('-E(&UA<'!E;@!6:7-A(&1A=&%B
M87-E<@!6:7-A(&AJY&QPY&UN96X`3&ES=&$@=&%B96QL97(`3&ES="U!<F-H
M:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI
M<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`1&5T(&=I8VL@:6YT92!A
M='0@;&ES=&$@<V5S<VEO;F5R.B`E<P!$970@9VEC:R!I;G1E(&%T="!L:7-T
M82!A;G;D;F1A<F4Z("5S`$QI<W1N:6YG(&%V(&%N=N1N9&%R92!A=F%K=&EV
M97)A9"X`3&ET=&5R871U<@!,:71A=65N`$QA9&1A<BXN+@!,;VMA;"!T:60Z
M(`!296=I;VYA;'0`4&QA=',`3&]G9V$@:6X`3&]G9V$@=70`3&]G:6X`3&]G
M:6YA:W1I=FET971E<@!);FQO9V=N:6YG(&UI<W-L>6-K861E<RX@5')O;&EG
M='9I<R!V87(@86YVY&YD87)N86UN(&5L;&5R(&SV<V5N;W)D(&9E;&%K=&EG
M="X`26YL;V=G;FEN9R!M:7-S;'EC:V%D97,N`$SE;F<@=&5X=`!+Y')L96L`
M3.5G`$=R96MI<VMA(&=E;65N97(`3&%T:6YS:V$@9V5M96YE<@!3;>4@<F]M
M97)S:V$@<VEF9G)O<@!,;WEO;&$`3&]Y;VQA($)LY0!,=7AE;6)U<F<`34T`
M34]41`!-4RU43D5&(&)I;&%G82!I;FYE:/9L;"!I;F=E;B!D871A+@!-4T<`
M36%C86\`36%C961O;FEE;@!-86=A9V%S:V%R`$UA9VES:P!%+7!O<W0`12UP
M;W-T861M:6X`4VMA<&$@;.1N:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV
M97)N80!-86QI`$UA;'1A`%5N9&5R:.5L;"!L:7-T86X@;65D(&MA=&5G;W)I
M97(@9'4@86YVY&YD97(@9O9R(&%T="!K871E9V]R:7-E<F$@<&]S=&5R(&UE
M9"!O8V@@9N1R9V5R;F$@<V]M('1I;&QH]G(@9&5S<V$@:V%T96=O<FEE<BX`
M36%P,C0M:V%R=&$`36%P475E<W0M:V%R=&$`UG9E<G/D='1N:6YG87(@<W!A
M<F%D92X`;6%R<P!-87)G:6YA;`!&;&%G9V$@<V]M(&SD<W0O;VSD<W0`1FQA
M9V=A(&UE9"!A;FYA;B!S=&%T=7,@*'0@97@@=FEK=&EG="]B97-V87)A="D`
M36%R<VAA;&SV87)N80!-87)T:6YI<75E`$UA=&-H86YD92!FY&QT`$UA=7)I
M=&%N:65N`$UA=7)I=&EU<P!-87@@=&EL;.5T96X@:W)E9&ET+@!'<N1N<R!F
M]G(@;6%X(&%N=&%L(&1E;&%R(&D@;65D9&5L86YD92#V=F5R<VMR:61E;BX`
M2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S=&4@,C0@=&EM;6%R;F$Z(`!(]F=S
M=&$@=&5M<&5R871U<F4@<V5N87-T92`V('1I;6UA<FYA.B``36%X:6UA;'0@
M86YT86P@86YT96-K;FEN9V%R`$UA>&EM86QT(&%N=&%L('!O<G1A;&)L;V-K
M`$UA>&EM86P@;.1N9V0`;6%J`$UA>6]T=&4`365D:6-I;@!!=F)O:V$@;?9T
M90!-]G1E<VEN9F]R;6%T:6]N`$WV=&5S9O9R9G+E9V%N`$WV=&5S<W9A<@!-
M]G1E<W5P<&1A=&5R:6YG`%5P<&1A=&5R:6YG<V)E9^1R86X@;VT@;?9T90!-
M961L96UM87(`06YT96-K;FEN9W-T97AT`$UE;GELY&=E.@!3;.4@:6AO<"!C
M96QL97(`365D9&5L86YD90!-961D96QA;F1E="!V97)I9FEE<F%D97,@;65N
M(&1E;B!S:6=N97)A9&5S(&-E<G1I9FEK870@:W5N9&4@:6YT92!V97)I9FEE
M<F%S+@!-961D96QA;F1E(&?D;&QE<B!I;G1E(&SD;F=R92X`365D9&5L86YD
M971Y<`!-971A<G;D9&5R`$UE=&%R8FQO8VME="#D<B!I;G1E('1I;&QGY&YG
M;&ET+@!-971A<BUB;&]C:R!E:B!T:6QL9^1N9VQI9W0N($1E=&%L:F5R(&AA
M<B!L;V=G871S(&;V<B!S>7-T96UA9&UI;FES=')A=/9R96XN`$UE=&%R1$(@
MY'(@:6YT92!A;G-L=71E;BX`365T;V0`365T;V1E;B`G)7,G(.1R(&EN=&4@
M9&5F:6YI97)A9`!-971O9&5N(&AA<B!I;G1E(&1E9FEN97)A=',N($%N<F]P
M860@;65T;V0Z("5S`$UE=')I<VL`365X:6MO`$UI:W)O;F5S:65N`$UI='1E
M;@!-:6UE='EP`$SD9W-T82!T96UP97)A='5R('-E;F%S=&4@,C0@=&EM;6%R
M;F$Z(`!,Y&=S=&$@=&5M<&5R871U<B!S96YA<W1E(#8@=&EM;6%R;F$Z(`!-
M:6YS=&$@;/9S96YO<F1SY6QD97(@:&%R(&EN=&4@=7!P;N5T=',@Y&X`4W!E
M9VQA`$1I=F5R<V4`3V)L:6=A=&]R:7-K="!P86ME="!S86MN87,@*%!%05(@
M2%144%]297%U97-T*2X`2V]N9FEG=7)A=&EO;B!S86MN87,N($1U(&WE<W1E
M('-K87!A(&1E;B!N=2!O;2!D=2!V:6QL(&%N=N1N9&$@9&5N(&CD<B!A<'!L
M:6MA=&EO;F5N+@!386MN87(@;65D9&5L86YD92U)1"X`3V)L:6=A=&]R:7-K
M="!P86ME="!S86MN87,@*%!%05(@36%I;"DN`%-A:VYA<B!S97-S:6]N<RU)
M1"X`3>4`36]B:6P@92UP;W-T`$UO9&5R97)A`,1N9')A9"!D871U;0#$;F1R
M82!LY&YK`,1N9')A<B`E<P!-;V1U;'5S`$UO;&1A=FEE;@!-;VYA8V\`36]N
M9V]L:65T`$WE;F%D(&]C:"#E<@!-Y6YA=&QI9P!-;W1S97)R870`3>5N9F%S
M97(`1FQE<B!FY&QT(&AI='1A9&5S('#E(')A9"`E9"#D;B!D970@9O9R=N1N
M=&%D92`E9"X`36%R;V-K;P!-97-T861E;',@:VQA<G0`365S=&%D96QS(&UO
M;&YI9W0`365S=&%D96QS('-O;&EG=`!&;'ET=&$@;F5D`$9L>71T82!VY&YS
M=&5R`$9L>71T82!H]F=E<@!&;'ET=&$@=7!P`$9L>71T82!N960`1FQY='1A
M('5P<`!-;^=A;6)I<75E`$UO>FEL;&$`1FQE<FYI=N5S;&ES=&$`375L=&EM
M87`@4W1O<F)R:71A;FYI96YK87)T80!&;&5R=F%L`$UI='0@:V]N=&\`36EN
M(&MO;G1O:6YF;W)M871I;VX`36EN82!A;G1E8VMN:6YG87(`36EN('!O<G1A
M;`!-:6X@<&]R=&%L;&%Y;W5T`$UY86YM87(`3D5*+"!*86<@86-C97!T97)A
M<B!I;G1E`$YA;6X`3F%M:6)I80!.875R=0!.95A4`$)E:/9V97(@Y71GY')D
M`$YE<&%L`$YE9&5R;.1N9&5R;F$`3F5D97)LY&YD<VMA($%N=&EL;&5R;F$`
M3F5S8V%P92!B87,M55),`$YE='-C87!E(&;V<FYY96QS92U54DP`3F5T<V-A
M<&4@Y71E<FMA;&QE;'-E+5523`!.971S8V%P92!34TPM<V5R=F5R;F%M;@!.
M971S87!E(&-E<G1I9FEK871S:V]M;65N=&%R`$YE='-A<&4@8V5R=&EF:6MA
M='-T>7``3N1T=F5R:P!!;&1R:6<`3GEA($MA;&5D;VYI96X`3GD@:V%T96=O
M<FD`3GET="!M961D96QA;F1E('1I;&P@)7,`3GEMY6YE`$YY(&%N=&5C:VYI
M;F<`3GET="!A;G;D;F1A<FYA;6X@*'9A;&9R:71T*0!.>6$@6F5E;&%N9`!.
M>71T(&SV<V5N;W)D`$YY='0@;/9S96YO<F0@:V]M;65R(&%T="!GY2!U="`E
M>"X`3/9S96YO<F0@;>5S=&4@=F%R82!S86UM82X`3GET="!F]FYS=&5R("A?
M8FQA;FLI`$YY:&5T97(`3GEH971S9W)U<'!E<@!.Y'-T80!+;VUM86YD92`T
M(&9A<V5R`$[D<W1A(&EN<W3D;&QN:6YG87(`3N1S=&$^`$YI8V%R86=U80!.
M:6=E<@!.:6=E<FEA`$YA='0`3FEU90!.96H`1&5T(&9I;FYS(&EN9V5T(&MO
M;F9I9W5R871I;VYS9&%T82!A='0@=FES82!S:VEL;&YA9&5R(&;V<BX`26YG
M96X@=&EL;&?D;F=L:6<@<W1R871E9VD@9O9R(&%T="!S:V%P82!)4T\M:6UA
M9V4N`$EN=&4@96X@8F%T8VAM86QL+@!$970@9FEN;G,@:6YG970@8FQO8VL@
M<.4@9&5N(&)E9^1R9&$@<&]S:71I;VYE;@!);F=E="!K86QE;F1E<FYA;6X@
M9O9R($U#04P@875T96YT:7-E<FEN9R!A;F=I=F5T+@!);F=E;B#D;F1R:6YG
M+@!);F=A('5N9&5R8F5H]G)I9VAE=&5R(&MA;B!LY&=G87,@=&EL;"!D96X@
M:.1R(&)E:/9R:6=H971E;BX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA
M=&EO;B!A;F=I=F5N(&;V<B`E<RX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O
M<FUA=&EO;B!A;F=I=F5N(&;V<B!&5%`@5D93+@!);F=E;B!K;VYF:6=U<F5R
M:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R(%-13"!61E,N`$EN9V5N(&MO
M;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@4U%,+69I;"!6
M1E,N`$EN9V5N(&MR961I="!K=F%R+@!"97-K<FEV;FEN9R!S86MN87,N`$EN
M9V5N(&UO='1A9V%R92!A;F=I=F5N+@!);F=E;B!F:6P@=7!P;&%D9&%D`&E#
M86QE;F1A<BUI;F9O<FUA=&EO;B!S86MN87,N`$EN9V$@:6MO;F5R(&AI='1A
M9&5S+@!);F=E;B!O<G0@86YG:79E;BX`26YG96X@;W)T(&%N9VEV96XN`$EN
M9V5T(&UE9&1E;&%N9&4@8FEF;V=A9&5S+@!);F=E="!N86UN(&%N9VEV970N
M`$EN9V$@86YT96-K;FEN9W-B;&]C:R!T:6QL9^1N9VQI9V$@9O9R(&?D<W1E
M<BX`26YG82!A;G1E8VMN:6YG87(`26YG82!A;G1E8VMN:6YG87(@;6%T8VAA
M<B!A:W1U96QL="!U<G9A;"X`26YG82!A;G1E8VMN:6YG87(@871T('9I<V$`
M26YG96X@;G5M;65R(&%N9VEV970N`$EN9V$@;V;V<G-KY&UD82!V:7-H971S
M;W)D`$EN9V5T(&SV<V5N;W)D(&;V<B!(5%10+6%U=&5N=&ES97)I;F<@86YG
M:79E="X`26YG970@;/9S96YO<F0@9O9R($E-05`M875T96YT:7-E<FEN9R!A
M;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@2V5R8F5R;W,M875T96YT:7-E
M<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@3&]G:6XM875T96YT
M:7-E<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@4$%34U=$+6%U
M=&5N=&ES97)I;F<@86YG:79E="X`26YG970@;/9S96YO<F0@9O9R(%--0BUA
M=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V$@=N1N=&%N9&4@<F5G:7-T<F5R
M:6YG87(N`$EN9V5N(&MV;W1A(&%N9VEV96X`26YG96X@:W9O=&$@86YG:79E
M;BX`26YG82!R96=L97(`26YG96X@879G<N1N<V%R92!A;F=I=F5N+@!);F=A
M('-I9&]R`$EN9V5N('/E9&%N(&9I;`!);F=E;B!T96UP;W+D<FMA=&%L;V<@
M=&EL;&?D;F=L:6<@9O9R(&-A8VAE+@!);F=E="!A;G;D;F1A<FYA;6X@;V-H
M+V5L;&5R(&SV<V5N;W)D('-K:6-K870N`$EN9V5T(&=I;'1I9R!834PM9&%T
M82!R971U<FYE<F%D97,`26YG82!VY')D96X`26YG96X@=F5R<VEO;B!H:71T
M861E<R!I(&1E;B!U<G-P<G5N9VQI9V$@:V]N9FEG=7)A=&EO;F5N+B#%=&5R
M<VMA<&$@:V]N9FEG=7)A=&EO;F5N+@!);F=E;B!V97)S:6]N(&AI='1A9&5S
M(&D@9&EN(&MO;F9I9W5R871I;VXN(,5T97)S:V%P82!K;VYF:6=U<F%T:6]N
M96XN`$%N7W1E8VMN:6YG`$EC:V4M9&5L=&%G87)E`$EN9V5N`$EN9V5N("AA
M;G;D;F0@=6YD97)F]G)S=.5D9"D`3F]R9F]L:_9A<FYA`$YO<G)A(&AE;6ES
M9N1R96X`3F]R<F$@36%R:6%N8?9A<FYA`$YO<F=E`$EN=&4@969T97(`26YT
M92!F]G)E`$EN=&4@96X@:V%T86QO9P!%:B!I;7!L96UE;G1E<F%D+@!%:B!A
M;F=I=F5N`%-T]F1S(&EN=&4N`$%N=&5C:VYI;F=S:V%T96=O<FD`06YT96-K
M;FEN9W-D971A;&IE<@!!;G1E8VMN:6YG<VQI<W1O<@!!;G1E8VMN:6YG<W1E
M>'0`06YT96-K;FEN9W-?=&5X=`!!;G1E8VMN:6YG('-A:VYA<RX`06YT96-K
M;FEN9W-?8FQO8VL`06YT96-K;FEN9W-B;&]C:W-N86UN.@!!;G1E8VMN:6YG
M<V)L;V-K`$%N=&5C:VYI;F=S8FQO8VL@;>5S=&4@:&$@971T(&YA;6XN`$%N
M=&5C:VYI;F=A<@!!;G1E8VMN:6YG<R!S=6UM97)I;F<`26YG96YT:6YG(&%T
M="!V:7-A+"!GY2!T:6QL8F%K82X`3T)3`&YO=F5M8F5R`$YU;6UE<@!!;G1A
M;"!T96-K96X`06YT86P@:V]L=6UN97(`06YT86P@<F%D97(`3G5M;65R(&EN
M=&4@<W!E8VEF:6-E<F%D92!F]G(@871T('5P<&1A=&5R82!I(&1I<W1R:6)U
M=&EO;G-L:7-T86XN`$]+`$]B:F5K=`!/8FIE:W1S:V%P87)E`$]K=&%L`&]K
M=&]B97(`1FEL=&5R(&;V<B!O9O9R<VOD;61H971E<@!+;VYT;W(`1V%M;6%L
M="!O8V@@;GET="!L]G-E;F]R9"!FY7(@:6YT92!V87)A('-A;6UA+@!'86UM
M86QT(&SV<V5N;W)D`$=A;6UA;'0@;/9S96YO<F0@Y'(@9F5L86MT:6=T`$]M
M86X`1&5L861E(&UA<'!A<B!S=/9D<R!E;F)A<G0@878@24U!4"US97)V<F%R
M`$5N8F%R="!O9O9R<VOD;61A('9I<VAE='-O<F0`16YD87-T(&5N(&4M<&]S
M=&%D<F5S<R!T:6QLY71E;BX`16YD87-T(.1G87)E(&5L;&5R('-Y<W1E;6%D
M;6EN:7-T<F%T]G(@:V%N(.1N9')A(.1G87)E(&5L;&5R(&)E:/9R:6=H971E
M<B!PY2!E;B!U=&1E;&YI;F<`UG!P;F$@:2!N>71T(&;V;G-T97(`3W!E;E-3
M3"UF96PZ($1E="!G:6-K(&EN=&4@871T(&5X=')A:&5R82!D871A(&9RY6X@
M<VEG;F5R860@4R]-24U%+61E;"X`UG!P;F$@;.1N:R!I(&YY='0@9O9N<W1E
M<@!/<&5R871I=G-Y<W1E;0!)8VME(&]B;&EG871O<FES:V$@9&5L=&%G87)E
M`$EN<W3D;&QN:6YG87(`26YS=.1L;&YI;F=A<B!F]G(@)7,`4V]R=&5R860@
M;&ES=&$`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;G-E;FAE=`!/<F=A;FES
M97)A`%5R<W!R=6YG;&EG(&%P<&QI:V%T:6]N<VUA;&P`57)S<')U;F=L:6=A
M(&UA;&QA<B!I("5S.@!!;FYA;@!!;F1R82!I;G-TY&QL;FEN9V%R`,1G87)B
M96CV<FEG:&5T97(`4$%-+4%U=&5N=&ES97)I;F<@Y'(@:6YT92!T:6QL9^1N
M9VQI9RX`4$5!4CHZ36%I;"UK;W!P;&EN9P!01U`@1&EG:71A;"!3:6=N871U
M<F4`4$=0($5N8W)Y<'1E9"!$871A`%!U8FQI:R!01U`M;GEC:V5L`%!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$`4$A0+6MO9`!02%`M<VMA;`!,Y'1T(&;V
M<FUI9&1A9W-R96=N`$;V<FUI9&1A9W-R96=N`$5F=&5R;6ED9&%G<W-K=7)A
M<@!%9G1E<FUI9&1A9W-S;O8`169T97)M:61D86=S<VMU<F%R(&UE9"!S;O8`
M169T97)M:61D86=S<V]L`,5S:W-K=7)A<B!PY2!E9G1E<FUI9&1A9V5N`%!/
M4TE8+71I;&SD9V<@<V%K;F%S`%!?2%`M<VMA;`!5=&9Y;&QN860Z`%!A:VES
M=&%N`%!A;&%U`%!A;&5S=&EN80!086YA;6$`4&%P=6$M3GEA($=U:6YE80!0
M87)A9W5A>0!$96QV:7,@;6]L;FEG=`!,]G-E;F]R9`!,]G-E;F]R9"#D;F1R
M861E<RX`3/9S96YO<F0@9F5L86MT:6=T`$SV<V5N;W)D(&MRY'9S(&;V<B!2
M041)55,@875T96YT:7-E<FEN9RX`3/9S96YO<F0@;65D(&)E:W+D9G1E;'-E
M`$SV<V5N;W)D.@!,]G-E;F]R9#H@`$SV<V5N;W)D(&WE<W1E('9A<F$@;&EK
M82X`2VQI<W1R82!I;@!+;&ES=')A(&EN(&9RY6X@=7)K;&EP<'-H86YT97)A
M<F5N`%/V:W;D9P!6Y&YT86YD92!R96=I<W1R97)I;F=A<CH`3>1N;FES:V]R
M`%!R;V-E;G0`571F]G(@=6YD97)HY6QL<V9U;FMT:6]N97(`571F]G(@=6YD
M97)HY6QL<V%K=&EV:71E=&5R('9I9"!I;FQO9V=N:6YG/P!"96CV<FEG:&5T
M`$)E:/9R:6=H970@)R5S)R!R861E<F%D97,@:6YT92X`Q71K;VUS="!N96MA
M9`!"96CV<FEG:&5T97(`0F5H]G)I9VAE='-A9&UI;FES=')A=&EO;@!097)S
M;VYL:6<@:6YF;W)M871I;VX`4&5R=0!(=7-D:G5R`$9I;&EP<&EN97)N80!4
M96QE9F]N`$9O=&]N`%!I=&-A:7)N`%!I>&QA<@!+;&EC:.EE<@!687(@9V]D
M(&ML:6-K82!I(&5N(&-E;&P`0F5K<N1F=&$@871T(&1U('9I;&P@<F%D97)A
M('9A;&0@<&]S=#\`0F5K<N1F=&$@871T(&1U('9I;&P@<F%D97)A(&%K='5E
M;&QT(&5L96UE;G0N`%9A<B!G;V0@86YG92!MY6YA9"!O8V@@Y7(N`%9A<B!G
M;V0@86YG92!N86UN(&;V<B!K871E9V]R:6XZ`%9A<B!G;V0@86YG92!G;V1K
MY&YD($E0+6%D<F5S<RX`5F%R(&=O9"!A;F=E(&5T="!G:6QT:6=T(&1A='5M
M.R!K;VYT<F]L;&5R82!A;G1A;&5T(&1A9V%R(&D@;>5N861E;BX`5F%R(&=O
M9"!A;F=E(&5N(&=O9&OD;F0@=&ED+@!687(@9V]D('-U;6UE<F$@9&ET="!P
M<F]B;&5M+@!!;F=E(&1I='0@86YVY&YD87)N86UN(&]C:"!L]G-E;F]R9"X`
M5F%R(&=O9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E>'0N($1U($W%4U1%('-A
M;71Y8VMA(&UE9"!V:6QL:V]R96X@9O9R(&%T="!A;G;D;F1A('-Y<W1E;65T
M+@!687(@9V]D(&SD<R!I9V5N;VT@9O9L:F%N9&4@=&5X="X@1'4@3<535$4@
M<V%M='EC:V$@;65D('9I;&QK;W)E;B!F]G(@871T(&%N=N1N9&$@<WES=&5M
M970N`$MO;G1R;VQL97)A(&;V;&IA;F1E(&EN9F]R;6%T:6]N(&]C:"!VY&QJ
M('-E9&%N(&5N(&AA;F1L:6YG(&D@;65N>6X*;F5D86XN`%;D;&H@96X@:&%N
M9&QI;F<@9G+E;B!M96YY;B!N961A;BX`06YG92!N>71T(&MA=&5G;W)I;F%M
M;CH`4&]L96X`4&]L:71I:P!5;F1E<G/V:VYI;F=A<@!0;W)T=6=A;`!0;W-I
M=&EO;F5R:6YG(&%V(&)I;&1E;@!0;W-I=&EO;F5R:6YG(&%V('1A8F5L;&5N
M`%-K<FEV('1I;&P@9&5N(&CD<B!M87!P96X@*&5J('1V:6YG870@878@24U!
M4"D`4&]S=&YU:V4`3F5D97)B]G)D(&1E('-E;F%S=&4@)7,@=&EM;6%R;F$Z
M(`!#:&%N<R!T:6QL/&)R+SYN961E<F+V<F0`075T:%]L9&%P.B!,1$%0+71I
M;&SD9V<@<V%K;F%S+@!0<F5F<U]S97-S:6]N.B!/8FQI9V%T;W)I<VMT('-E
M<W-I;VYS=&EL;.1G9R!H:71T861E<R!I;G1E+@!4<GEC:P!,=69T=')Y8VL@
M=FED(&AA=F5T.B``3'5F='1R>6-K.B``1O9R:&%N9'-V:7-N:6YG`$;V<FAA
M;F1S9W)A;G-K82!B:6QD(&D@;GET="!F]FYS=&5R`$;V<F5GY65N9&4@:6YS
M=.1L;&YI;F=A<@!3:W)I=B!U="!D;VMU;65N=`!0<FEV871A(&YY8VME;`!0
M<F]B;&5M`%!R;V)L96UB97-K<FEV;FEN9P!0<F]J96MT`%1E>'0`4'5B;&EK
M(&YY8VME;`!0=6)L:6L@;GEC:V5L86QG;W)I=&T`4'5B;&EK(&YY8VME;&EN
M9F]R;6%T:6]N`$9E;"!V:60@9V5N97)E<FEN9R!A=B!P=6)L:6MT+W!R:79A
M="!N>6-K96QP87(N`%!U97)T;R!2:6-O`%)E;G-A(&UE9&1E;&%N9&5N`%%A
M=&%R`$9RY6=A`$MV;W1A`%!U8FQI:R!24T$M;GEC:V5L("@E9"!B:71A<BD`
M16YS:VEL="!V86P`4F5G;@!4:61I9W0@<F5G;@!396YT(')E9VX`4F5G;G-K
M=7)A<@!296=N(&]C:"!S;O8`4F5G;B!T:6QL('-N]@!3;'5M<&WD<W-I9W0@
M=FES:&5T<V]R9`!&]G)HY6QL86YD90!,Y',`3.1S(&UE9&1E;&%N9&5N`%/D
M:V5R="!A='0@9'4@=FEL;"!R861E<F$@)7,_(%)A9&5R:6YG96X@:V%N(&EN
M=&4@Y6YG<F%S+@!2861E<F$@9&5N;F$@86YT96-K;FEN9S\`4^1K97)T(&%T
M="!D=2!V:6QL(')A9&5R82!A;G;D;F1A<F1A=&$@9O9R("5S/R!2861E<FEN
M9V5N(&MA;B!I;G1E(.5N9W)A<RX`1_9R(&]M(&1I;B!S96YA<W1E(&EN;6%T
M;FEN9P!5<'!D871E<F$`57!P9&%T97)A(&1Y;F%M:7-K82!M96YY96QE;65N
M=#H`57!P9&%T97)A(&QI<W1A`%5P<&1A=&5R82!P;W)T86QV>3H`4F5G97@`
M5FES82!F]G)HY6QL86YD96X`3&%D9&$@;VT`2V]M;65N=&%R97(`2V]M(&EH
MY6<@:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96XN`$9JY')R<V5R=G)A
M<@!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!482!B;W)T
M`%1A(&)O<G0@8FQO8VL`4F%D97)A(&MA=&5G;W)I`%1A(&)O<G0@:V]L=6UN
M`%1A(&)O<G0@9F]R;6%T97)I;F<`5&$@8F]R="!F<N5N(&UI;B!K86QE;F1E
M<@!482!B;W)T('!A<@!2861E<F$@<W!A<F%T('-K<FEP="!F<N5N('-E<G9E
M<FYS('1E;7!O<N1R:V%T86QO9RX`5&$@8F]R=`!2861E<F$@9&5N;F$@;F]D
M(&9RY6X@9&]K=6UE;G1E=`!482!B;W)T(&%N=N1N9&%R90!482!B;W)T(&%N
M=N1N9&%R93H@)7,`4W9A<B!S:VEC:V%T+@!3=F%R82!A='0@8F5GY')A;B!I
M;G1E('-T]F1S`%-V87)A(&UE9"!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T
M86=E;B!F]G(@:V]M;6%N9&4@=';E(&WE;F%D97(N`%-V87)A(&UE9"!D96X@
M8F5GY')D82!L961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;F5N+@!3=F%R.B`E
M<P!"96?D<F%N(&MU;F1E(&EN=&4@8F5S=F%R87,N(%)E='5R;F5R860@9F5L
M:V]D.B``1&5N(&5F=&5R9G+E9V%D92!T:N1N<W1E;B!K=6YD92!I;G1E(&AI
M='1A<RX`17)F;V1R860@)R5S)R#D<B!I;G1E(&%N9VEV96X@:2!K;VYF:6=U
M<F%T:6]N96X@878@)7,N`$5R9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N
M(&D@:V]N9FEG=7)E<FEN9V5N(&%V(%9&4RX`17)F;V1R860@)R5S)R#D<B!I
M;G1E(&%N9VEV96X@:2!K;VYF:6=U<F5R:6YG96XN`$]B;&EG871O<FES:W1T
M(&;D;'0`3V)L:6=A=&]R:7-K(&1E;'1A9V%R90#%=&5R<W3D;&P`Q71E<G-T
MY&QL(&SV<V5N;W)D`,5T97)S=.1L;"!L]G-E;F]R9`#%<W1E<G3D;&P@<V5N
M87-T92!F<N5G86X`4F5S=6QT870`Q71E<G;D;F0@=&EL;"!I;G-TY&QL;FEN
M9V%R`$%N9V4@;GET="!L]G-E;F]R9`!2Z75N:6]N`,5T97)S=.1L;"!K;VYF
M:6=U<F%T:6]N`$EN<W3D;&QN:6YG87(@9O9R(%)I8V@@5&5X="!%9&ET;W(`
M1^5T;W(`2/9G97(`2/9G97)R=6)R:6L`2/9G97)VY')D96X`4F%?9&EN<W3D
M;&QN:6YG87(N+BX`4F]L;`!2=6WD;FEE;@!2;W1E<F$@,3@P`%)O=&5R82!V
MY&YS=&5R`%)O=&5R82!H]F=E<@!2861I;G-TY&QL;FEN9V%R`%)A9&EN<W3D
M;&QN:6YG87(`4F%D97(Z`$QI;FIE<@!,:6YJ97(@=FES87,@;65L;&%N(&%L
M;&$@<F%D97(@;V-H(&MO;'5M;F5R`$QI;FIE<B!V:7-A<R!E;F)A<G0@;65L
M;&%N(&MO;'5M;F5R`$QI;FIE<B!V:7-A<R!E;F)A<G0@;65L;&%N(')A9&5R
M`$OV<@!2>7-S;&%N9`!2=V%N9&$`4R]-24U%('-I9VYA='5R`%,O34E-12UK
M<GEP=&5R870@;65D9&5L86YD90!305-,+6%U=&5N=&ES97)I;F<@Y'(@:6YT
M92!T:6QL9^1N9VQI9RX`4TU3(&UE9&1E;&%N9&5N`%-13"US:V%L`%-13"US
M96MV96YS(&;V<B!U<'!S;&%G(&%V(';D<F1E;@!34T@`3%E#2T%4`%-?44PM
M<VMA;`!,]@!386EN="!(96QE;F$`4V%I;G0@2VET=',@;V-H($YE=FES`%-A
M:6YT($QU8VEA`%-A:6YT+5!I97)R92!O8V@@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="!O8V@@1W)E;F%D:6YE<FYA`%-A;6UA(')A;2`H7W-E;&8I`%-A;6]A
M`%-A;B!-87)I;F\`4V%O(%1O;64@;V-H(%!R:6YC:7!E`%-A='1E;&ET;&5V
M97)A;G3V<@!3875D:6%R86)I96X`4W!A<F$`4W!A<F$@)R5S)P!3<&%R82`E
M<P!3<&%R82!I;G-TY&QL;FEN9V%R`%-P87)A(&=E;F5R97)A9"!K;VYF:6=U
M<F%T:6]N('-O;2!02%`M<VMR:7!T('1I;&P@9&EN('-E<G9E<G,@('1E;7`M
M:V%T86QO9RX`4W!A<F%D92!K;VYF:6=U<F%T:6]N(&;V<B`E<RX`4W!A<F%D
M92!U<'!G<F%D97)I;F=S<V-R:7!T('1I;&PZ("5S+@!3<')I9&1A(.5S:W-K
M=7)A<@!6971E;G-K87``4_9K`%/V:VUO=&]R97(`4_9K<F5S=6QT870`57)V
M86P@9O9R('/V:VYI;F<`4_9K(%]T97AT`%;D;&H@9FEL97(`5N1L:B!E='0@
M9&%T=6T`5N1L:B!G<G5P<"!A='0@;.1G9V$@=&EL;`!6Y&QJ(&YY(.1G87)E
M`%;D;&H@971T(&%N=&5C:VYI;F=S8FQO8VL`5N1L:B!S97)V97(`5N1L:B!A
M;G;D;F1A<F4@871T(&SD9V=A('1I;&P`5N1L:B!A;&QA`%;D;&H@9&%T=6UK
M;VUP;VYE;G1E<BX`5N1L:B!E='0@;V)J96MT`%;D;&H@:6YG96X`06YG92!A
M;G1E8VMN:6YG<V)L;V-K(&%T="!V:7-A.@!!;F=E(&1E('1E8VME;B!D=2!B
M96CV=F5R(&D@<G5T;W)N82!N961A;BX@1'4@:V%N('-E9&%N(&MO<&EE<F$@
M;V-H(&ML:7-T<F$@:6X@9&5M(&D@=&5X=&%R=71A;BX`5N1L:B!A=F=RY&YS
M87)E(&;V<B!D871U;3H`5N1L:B!D871U;69O<FUA=#H`5N1L:B!E>'!O<G1F
M;W)M870Z`%;D;&H@9FEL('-O;2!S:V%L;"!I;7!O<G1E<F%S.@!6Y&QJ(&9O
M<FUA="!PY2!I;7!O<G1F:6QE;CH`5N1L:B!I9&5N=&ET970@9'4@=FEL;"#D
M;F1R83H`5N1L:B!A=F=RY&YS87)E(&;V<B!T:60Z`%;D;&H@=&ED<V9O<FUA
M=#H`5N1L:B!T=N4@;6%T8VAA;F1E(&;D;'0Z`%;D;&H@9&ET="!FY')G<V-H
M96UA+@!!;F=E(&1I='0@9O9R=F%L9&$@<W!RY6LZ`%9A;&1A(&MA=&5G;W)I
M97(Z`%-K:6-K82!S96YA<W1E(&EN9F]R;6%T:6]N96X`4VMI8VMA('!R;V)L
M96UR87!P;W)T`%-K:6-K82!335,`4V5N96=A;`!396YS;W(Z(`!S97!T96UB
M97(`4V5R8FEE;B!O8V@@36]N=&5N96=R;P!397)I96YU;6UE<@!397)V97)I
M;G-TY&QL;FEN9V%R(&9E;&%K=&EG82!E;&QE<B!I;F%K=&EV('-E<G9E<BX`
M4V5S<VEO;G-A9&UI;FES=')A=&EO;@!397-S:6]N<RU)1"!H87(@9^5T="!U
M="X`4V5S<VEO;F5R`%/D='0`2V]N9FEG=7)E<F$@86QT97)N871I=B!S;VT@
M;?9J;&EG9_9R(.5T97)S=.1L;&YI;F<@878@8F]R=&=L]FUT(&SV<V5N;W)D
M+@!+;VYF:6=U<F5R82!F:N1R<G-E<G9R87(@<V]M(&1U('9I;&P@:V]M;6$@
MY70@9G+E;B!D:6X@<&]R=&%L+@!!;F=E(&1I='0@9O9R=F%L9&$@<W!RY6LL
M('1I9'-Z;VX@8V]H(&1A='5M:6YS=.1L;&YI;F=A<BX`4^1T="!D:71T(&EN
M:71I86QA(&%P<&QI:V%T:6]N+"!FY')G<V-H96UA+"!S:61U<'!D871E<FEN
M9R!O8V@@86YD<F$@=FES;FEN9W-I;G-TY&QL;FEN9V%R+@!3971U<`!+;VYF
M:6=U<F%T:6]N<W5P<&=R861E<FEN9W-S:W)I<'0@9FEN;G,@=&EL;&?D;F=L
M:6=A`$1E="!F:6YN<R!F;&5R82!O<G1E<B!M960@<&%R86UE=&5R;CH`4V5Y
M8VAE;&QE<FYA`$AA;F1E;`!+;W)T('-U;6UE<FEN9P!3:V%L;"!G96YVY&=S
M=&%N9V5N=&5R(&1E9FEN97)A<R!F]G(@9&4@9FQE<W1A(&SD;FMA<C\`5FES
M80!6:7-A(&%N=&5C:VYI;F=S8FQO8VLZ`%9I<V$@86MT:79I=&5T<VMN87!P
M87(_`%9I<V$@<VMI;&QN861E<B!M96QL86X@9&5N(&%K='5E;&QA(&]C:"!D
M96X@;GEL:6=E;B!S:V%P861E(&MO;F9I9W5R871I;VYE;BX`5FES82!S96YA
M<W1E(&EN;&]G9VYI;F=S=&ED('9I9"!I;FQO9V=N:6YG/P!6:7-A(&%N=&5C
M:VYI;F=S8FQO8VME=',@;F%M;C\`5FES82!A;G1E8VMN:6YG87(@;65D(&1E
M<W-A(&MA=&5G;W)I97(`5FES82!I;G-TY&QL;FEN9R!F]G(@871T(&)E:.5L
M;&$@;W)I9VEN86P`5FES82!P86QE='0`5FES82`G=&%B96QL86MT:79I=&5T
M97(G(&D@;65N>6X_`%9I<V$@;65N>2!F]G(@)7,@=&EL;"!VY&YS=&5R/P!4
M86)E;&QC96QL:6YS=.1L;&YI;F=A<@!486)E;&QI;G-TY&QL;FEN9V%R`%1A
M8F5L;&EN<W3D;&QN:6YG87(`5FES82!D:6%L;V=R=71A(&;V<B!B:6QD96=E
M;G-K87!E<@!6:7-A('5P<&QA9&1N:6YG`%-K=7)A<@!4:61I9V$@<VMU<F%R
M`%-E;F$@<VMU<F%R`%-K=7)A<B!I(&[D<FAE=&5N`$;V<FUI;G-K80!+<GEM
M<"!E;&QE<B!F;'ET=&$@8F]R="!NY')L:6=G86YD92!B;&]C:R!F]G)S=`!3
M:65R<F$@3&5O;F4`4F5G:7-T<F5R80!3:6=N871U<@!3:6=N871U<F%L9V]R
M:71M`%-I;7!L97@`4VEN9V%P;W)E`%-T;W)L96L`079B<GET('5N9&5R:.5L
M;`!3;&]V86MI96X`4VQO=F5N:65N`%-N]@!3;O9S:W5R`%-N]G-K=7)A<@!4
M:61I9V$@<V[V<VMU<F%R`%-E;F$@<V[V<VMU<F%R`%-N]F1J=7`Z(`!-;W1S
M=F%R86YD92!S;O8@:2!V871T96XZ(`!386QO;6]N]F%R;F$`4V]M86QI80!3
MY6YG97(@;V-H(&1I:W1E<@!3;W)T97)A('#E(&MA=&5G;W)I`%-O<G1E<F$@
M<.4@86YT96-K;FEN9W-T97AT`%-O<G1E<FEN9W-I;W)D;FEN9W-V86P`:^1L
M;&%D<F5S<P!3>61A9G)I:V$`4_9D<F$@1V5O<F=I82!O8V@@4WES<V%N9'=I
M8VCV87)N80!3Y&1R82!H96UI<V;D<F5N`%5T<GEM;64@;65L;&%N(&EN=&EL
M;&EG9V%N9&4@8V5L;&5R`%5T<GEM;64@;65L;&%N(&EN;F5HY6QL(&]C:"!K
M86YT96X@:2!C96QL96X`365L;&%N<G5M`$UE;&QA;G)U;0!-96QL86YR=6T@
M;V-H('5T:N1M;FEN9P!3<&%N:65N`%-P86T`26YM871N:6YG(&%V('-P96-I
M96QL82!T96-K96X`1&5L82!C96QL`$1E;&$@:V]L=6UN`$1E;&$@<F%D`%-P
M;W)T97(`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R
M=.5R`%-T870@96QL97(@<F5G:6]N`%-T871U<P!,86=R:6YG<V9O<FUA=`!'
M871U861R97-S`$=E;F]M<W1R=6ME;@!3='+D;F=L:7-T80!482!B;W)T(&1O
M;>1N(&9RY6X@861R97-S96X`4W1I;"!;0U-370!3]@!+86X@:6YT92!H:71T
M82!U;F1E<FMA=&%L;V<@)R5S)RX`Q')E;F1E`%-K:6-K80!$:6X@8F5GY')A
M;B!A='0@;.1G9V$@=&EL;"`B)7,B('1I;&P@<WES=&5M970@:&%R('-K:6-K
M871S+B!$=2!K86X@:6YT92!L;V=G82!I;B!I;FYA;B!D:6X@8F5GY')A;B!H
M87(@86-C97!T97)A=',N`$YE9'/D;FMT`$QY8VMA=``G)7,G(&QA9&5S('1I
M;&P@:2!S>7-T96UE="X`4F%D97)A9&4@:6YF;W)M871I;VX@;VT@86YVY&YD
M87)E("<E<R<N`"<E<R<@<F%D97)A9&5S+@`G)7,G('1O9W,@8F]R="!F<N5N
M('-Y<W1E;65T+@!+;VYF:6=U<F%T:6]N96X@:&%R(.5T97)S=.1L;'1S+B!,
M861D82!O;2!S:61A;B!F]G(@871T('-E(&;V<N1N9')I;F=A<BX`)R5S)R!S
M<&%R861E<RX`4W!A<F%D92!B86-K=7!K;VYF:6=U<F%T:6]N+@!3<&%R861E
M(&)A8VMU<&MO;F9I9W5R871I;VX@)7,N`"<E<R<@=7!P9&%T97)A9&5S+@!3
M:W)E=B`E<P!3=61A;@!386UM86YS=.1L;&YI;F<`4V]L=7!P9^5N9P!3;VQN
M961GY6YG`%-O;&EG=`!3;VQU<'!GY6YG`%-O;'5P<&?E;F<O;F5D9^5N9P!3
M;VQU<'!GY6YG.B``4V]L;F5D9^5N9P!3;VQN961GY6YG.B``57!P:/9J9`!3
M=7!P;W)T`%-U<FEN86UE`$5F=&5R;F%M;@!3=F%L8F%R9"!O8V@@2F%N($UA
M>65N`%-W87II;&%N9`!3=F5R:6=E`%-C:'=E:7H`4WEK<F]N:7-E<FEN9W-L
M;V=G(')A9&5R860`4WEN8TU,`%-Y;G1A>&9E;"!I('/V:VMR:71E<FEA`%-Y
M<FEE;@#%<VMS:W5R`,5S:W-K=7)A<B!O8V@@8FSE<VEG=`#%<VMS:W5R87(`
M5&ED:6=A(.5S:W-K=7)A<@!44U8M9FEL`%1A8F5L;`!486)E;&QI;G-TY&QL
M;FEN9V%R`%1A8F5L;'5P<'/D='1N:6YG`%1A8F5L;&EN<W3D;&QN:6YG87(`
M5&%I=V%N`%1A:7=A;@!486II:VES=&%N`%1A;GIA;FEA`$WE;#H`57!P9VEF
M=&5R`%1E86P`5&5L969O;FYU;6UE<@!(]F=S=&$@=&5M<&5R871U<B!S96YA
M<W1E('1I;6UE;CH@`%1E;7!E<F%T=7(`5&5M<&5R871U<CH@`%1E;7!E<F%T
M=7(\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S`$MA;B!I;G1E(&AI
M='1A(&UA;&P@)7,N`$%N=N1N9&%R861M:6YI<W1R871I;VX`1V]D:^1N;B!B
M96?D<F%N('!R96QI;6ENY')T`%!R96QI;6ENY')T(&%C8V5P=&5R870`5&5X
M=`!%;F)A<G0@=&5X=`!497AT:G5S=&5R:6YG`%1E>'1T;W``5&\`5&AA:2`H
M5$E3+38R,"D`5&AA:6QA;F0`5&%C:R!F]G(@871T(&1U(&%N=N1N9&5R('-Y
M<W1E;65T+@!,Y&YK96X@)7,@=&EL;"`E<R!H87(@<F%D97)A=',N`$944"UT
M:6QLY&=G970@Y'(@:6YT92!T:6QL9^1N9VQI9W0N`$AI<W1O<FEK<WES=&5M
M970@Y'(@879A:W1I=F5R870N`$AO<F1E+TMO;&%B+6EN=&5G<F%T:6]N<V=R
MY&YS<VYI='1E="!S=/9D97(@:6YT92`B)7,B`$E-4U`M;&]G9V5N(&MU;F1E
M(&EN=&4@:6YI=&EE<F%S+@!+;&%S<V5N($UA:6YT96YA;F-E.CH@:W5N9&4@
M:6YT92!L861D87,`26YS=.1L;&YI;F=S9O9N<W1R970@:&%R('-TY&YG=',N
M($%V<VQU=&%R+@!!9&UI;FES=')A=/9R96X@;>5S=&4@:V]N9FEG=7)E<F$@
M96X@<&5R;6%N96YT($)E:/9R:6=H971S+6MO<'!L:6YG(&]M(&1U('9I;&P@
M86YVY&YD82!"96CV<FEG:&5T97(N`$5N8F%R="!N961R92!S:61A;@!+86QE
M;F1E<FEN9F]R;6%T:6]N96X@Y'(@9F5L86MT:6<`2V]N=&%K=&5N<R!)1"!A
M;F=A=G,@:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I(&1A=&%B87-E
M;BX`2V]N=&%K=&5N(&QA9&5S('1I;&P@:2!A9')E<W-B;VME;BX`1&5N(&SV
M<V=J;W)D82!01U`M<VEG;F%T=7)E;B!K<N1V<R!F]G(@871T('9E<FEF:65R
M82!D970@<VEG;F5R861E(&UE9&1E;&%N9&5T+@!$:7-T<FEB=71I;VYS;&ES
M=&%N<R!)1"!A;F=A=G,@:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I
M(&1A=&%B87-E;BX`1&ES=')I8G5T:6]N<VQI<W1A;B!H87(@:6YT92!A;F=I
M=FET<RX`2W)Y<'1E<FEN9W-F=6YK=&EO;F5R;F$@:W+D=F5R(&5N('/D:V5R
M('=E8F;V<F)I;F1E;'-E("A(5%104RDN`$CD;F1E;'-E;B!L861E<R!T:6QL
M(&D@:V%L96YD97)N+@!&:6QE;B`E<R!S:V%L;"!I;FYE:.5L;&$@96X@:6YS
M=.1L;&YI;F<@9O9R("5S+@!&:6QE;B`E<R!S:V%L;"!I;FYE:.5L;&$@:6YS
M=.1L;&YI;F=A<B!F]G(@)7,N`$9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I
M;&P@<VEG('-JY&QV+@!&:6QE;B!K86X@:6YT92!K;W!I97)A<R!T:6QL('-I
M9R!S:N1L=BX`1FEL96X@:6YN96CV;&P@:6YG96X@:6YF;W)M871I;VXN`$AU
M=G5D9N1L="!F]G(@9&5T=&$@;65D9&5L86YD92]R9F,X,C)M961D96QA;F1E
M(&;V;&IE<@!)9&5N=&ET971E;B`G)7,G(')A9&5R861E<RX`0F%R82!VY&YS
M=&5R('-I9&$`3.1N:V5N(&AA<B!T86=I=',@8F]R=`!3]FMVY&=E;B!T:6QL
M($=N=5!'+7!R;V=R86UM970@;>5S=&4@=F%R82!A;F=I=F5N('1I;&P@:VQA
M<W-E;B!#<GEP=%]P9W`Z.BX`365D9&5L86YD970@<VMI8VMA="`E<R!T:6QL
M("5S(&UE9"#D<F5N9&4@(B5S(B!H87(@=FES871S+@I$971T82#D<B!I;F=E
M;B!G87)A;G1I(&;V<B!A='0@;65D9&5L86YD970@:&%R(&SD<W1S+@!.86UN
M970@<V]M('-K86QL(&%N=N1N9&%S(&;V<B!A='0@;.1N:V$@=&EL;"!S:V%P
M82US:61A;@!!;G1E8VMN:6YG96X@<F%D97)A9&5S+@!!;G1E8VMN:6YG<V)L
M;V-K("<E<R<@:W5N9&4@:6YT92!S:V%P87,Z("5S`$%N=&5C:VYI;F=S8FQO
M8VME="`G)7,G('-K87!A9&5S+@!!;G1E8VMN:6YG<V)L;V-K970@)R5S)R!R
M861E<F%D97,N`$%N=&5C:VYI;F=S=FQO8VME="`G)7,G('-P87)A=',N`$%N
M=&%L(&;D;'0@;>5S=&4@=F%R82!E='0@;G5M97)I<VMT(';D<F1E+@!-;V1U
M;&5N(&]P96YS<VP@:W+D=G,@878@:VQA<W-E;B!(;W)D95]#<GEP=%]S;6EM
M93HZ+@!);G-TY&QL;FEN9V5N("(E<R(@:W5N9&4@:6YT92!S<&%R87,@<.4@
M9W)U;F0@878@871T(&1A=&%MY&YG9&5N(/9V97)S:W)I=F5R(&1E;B!M87AI
M;6%L="!T:6QLY71N80!0<F]G<F%M;65T('-O;2!A;G;D;F1S(&;V<B!A='0@
M=FES82!D96X@:.1R(&UE9&1E;&%N9&5T>7!E;B`H)7,I('-A:VYA<R!PY2!S
M>7-T96UE="X`5&5C:VYE="!F]G(@8VET97)I;F<@;>5S=&4@=F%R82!E='0@
M=&5C:V5N+@!"87)A(&CV9V5R(&]C:"!VY&YS=&5R('-I9&]R`$)A<F$@:/9G
M97(@<VED80!397!A<F%T;W)N(&WE<W1E('9A<F$@971T('1E8VME;BX`4V5R
M=F5R("<E<R<@<F%D97)A9&5S+@!397)V97(@)R5S)R!S<&%R861E<RX`4')E
M;G5M97)A=&EO;G-B96?D<F%N(&;V<B`E<R!H87(@=&%G:71S(&)O<G0N`$%N
M9VEV96X@<F%D("@E9"D@9FEN;G,@:6YT92X`06YG:79E;B!R860@97AI<W1E
M<F%R(&EN=&4N`%5P<&=I9G1E;B!H87(@;&%G=',@=&EL;"!I(&1I;B!U<'!G
M:69T<VQI<W1A+@!496UP;W+D<B!F:6P@)R5S)R!F:6YN<R!I;G1E+@!497AT
M96X@9'4@;6%T870@:6X@<W3D;6UE<B!I;G1E(/9V97)E;G,@;65D('1E>'1E
M;B!PY2!S:^1R;65N`$)A<F$@=&]P<"!O8V@@8F]T=&5N('-I9&$`0F%R82!T
M;W!P<VED80!5<'!L861D870@9&%T82!F]G)S=F%N;B!S961A;B!F]G)E9^5E
M;F1E('-T96<N`$1E;B!U<'!L861D861E(&9I;&5N(&MU;F1E(&EN=&4@<W!A
M<F%S+@!,961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;B!F]G(@86YVY&YD87)E
M;B!H87(@<W!A<F%T<RX`5V5A=&AE<BYC;VTM8FQO8VME="#D<B!I;G1E('1I
M;&QGY&YG;&EG="X`5&5M86MA=&%L;V<@)R5S)R!F:6YN<R!I;G1E+@!);F=A
M(&EN<W3D;&QN:6YG87(@=&EL;&?D;F=L:6=A+@!$970@9FEN;G,@:6YG82!A
M;'1E<FYA=&EV82!D96QA<B!S;VT@:V%N('9I<V%S(&EN;&EN92X`1O9R(&WE
M;F=A('1E8VME;B!I(&;D;'1E="X@1'4@:&%R(&%N9V5T="`E<R!T96-K96X[
M(&UA>&EM86QT(&%N=&%L('1E8VME;B#D<B`E<RX`4')O8FQE;2!M960@871T
M(&SD9V=A('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T.B`E<P!0<F]B;&5M(&UE
M9"!A='0@<F5N<V$@:6YF;W)M871I;VX@;VT@86YVY&YD87)E("<E<R<@9G+E
M;B!S>7-T96UE=#H@`%!R;V)L96T@;65D(&%T="!T82!B;W)T("<E<R<@9G+E
M;B!S>7-T96UE=#H@`%!R;V)L96T@=FED('5P<&1A=&5R:6YG(&%V("<E<R<Z
M("5S`%!R;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N+B!);F=A("5S
M(&QA9&1A9&5S('5P<"X`1&5T('5P<'-T;V0@<')O8FQE;2!V:60@=7!P;&%D
M9&YI;F<@878@9FEL96XZ("5S(.1R('-T]G)R92#D;B!M87AI;6%L="!T:6QL
MY71E;B!S=&]R;&5K("@E9"!B>71E<RDN`$1E="!U<'!S=&]D('!R;V)L96T@
M=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N.B`E<R!L861D861E<R!E;F)A<G0@
M=7!P(&1E;'9I<RX`1&5T('5P<'-T;V0@971T(&9E;"!V:60@=FES;FEN9R!A
M=B!M961D96QA;F1E9&5L96XN`$9E;"!V:60@:6UP;W)T(&%V(&MO;G1A:W1D
M871A+@!$970@=7!P<W1O9"!F96P@=FED(&EM<&]R="!A=B!D871A.B`E<RX`
M1F5L('9I9"!I;7!O<G0@878@:.1N9&5L<V5N.B`E<RX`1F5L('9I9"!I;7!O
M<G0@878@:4-A;&5N9&%R+61A=&$N`$9E;"!V:60@:6UP;W)T(&%V('5P<&=I
M9G1E;CH@)7,N`$9E;"!V:60@:6UP;W)T(&%V('9.;W1E+61A=&$N`$9E;"!V
M:60@:6UP;W)T(&%V(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N.B`E
M<RX`171T(&9E;"!PY71RY&9F861E<R!I(&9O<FUU;.1R970N($MO;G1R;VQL
M97)A(&%T="!D=2!I;G1E(&=L]FUT(&9Y;&QA(&D@971T(&]B;&EG871O<FES
M:W0@9N1L="X`1&5T(&=I8VL@:6YT92!A='0@=71F]G)A(&1E;B!B96?D<F1A
M(&%D<F5S<V)O:W-F=6YK=&EO;F5N+B!687(@9V]D(&;V<G/V:R!S96YA<F4N
M`$1E="!U<'!S=&]D(&9E;"!NY'(@86YT96-K;FEN9V5N('-K=6QL92!R861E
M<F%S.B`E<P!$970@=7!P<W1O9"!F96P@;N1R(&%N=&5C:VYI;F=E;B!S:W5L
M;&4@<W!A<F%S.B`E<P!&96P@=FED('5P<&1A=&5R:6YG(&%V(&MO;G1A:W1U
M<'!G:69T97(N($;V<G/V:R!I9V5N('-E;F%R92X`1F5L('9I9"!U<'!D871E
M<FEN9R!A=B!D:7-T<FEB=71I;VYS;&ES=&%N+B!&]G)S]FL@:6=E;B!S96YA
M<F4N`$1E="!U<'!S=&]D(&9E;"!V:60@=FES;FEN9R!A=B!A;G1E8VMN:6YG
M96XZ("5S`$EN9V$@86YT96-K;FEN9R!A='0@97AP;W)T97)A+@!$:6X@24U!
M4"US97)V97(@<W3V9&5R(&EN=&4@9&5L861E(&UA<'!A<BX`1&5N;F$@:&%N
M9&QI;F<@<W3V9',@:6YT92X`1&5N;F$@9G5N:W1I;VX@Y'(@:6YT92!I;7!L
M96UE;G1E<F%D(.1N+@!&:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT
M:6=T(%)!4BUA<FMI=BX`1FEL96X@=F5R:V%R(&EN=&4@=F%R82!E='0@9VEL
M=&EG="!:25`M87)K:78N`$9E;&%K=&EG="!K;W)T;G5M;65R+@!$96YN82!D
M<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD
M96X@=FEA($-L:6-K871E;&PM8G)Y9V=A;B`H:'1T<#HO+V-L:6-K871E;&PN
M8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT+@!$96YN82!D<FEV
M<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@
M=FEA(%=)3BUB<GEG9V%N("AH='1P.B\O=VEN<&QC+F-O;2D@9V5N;VT@871T
M(&%N=N1N9&$@2%144"!!4$DZ=`!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M
M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA('-M<S)E;6%I;"UB
M<GEG9V%N("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V5N;VT@871T(&%N=N1N
M9&$@2%144"!!4$DZ=`!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T
M(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA(%--5%`@9V5N;VT@5F]D869O
M;F4@271A;&EE;BUB<GEG9V%N("AE;F)A<G0@=&EL;"!6;V1A9F]N;G5M;65R
M*2X@1')I=G)U=&EN96X@:W+D=F5R(&5T="!E+7!O<W1K;VYT;R!H;W,@5F]D
M869O;F4@271A;&EE;B`H:'1T<#HO+W=W=RXQ.3`N:70I+@!&Y&QT970@;>5S
M=&4@=F%R82!I9GEL;'0N`$;D;'1E="!FY7(@96YB87)T(&EN;F5HY6QL82!H
M96QT86PN`$;D;'1E="!FY7(@96YB87)T(&EN;F5HY6QL82!S:69F<F]R(&]C
M:"!K;VQO;BX`1N1L=&5T(&;E<B!E;F)A<G0@:6YN96CE;&QA(&]K=&%L82!T
M86PN`$;D;'1E="!S:V%L;"!V87)A(&5N(&MO;6UA+2!E;&QE<B!M96QL86YS
M;&%G<W-E<&%R87)A9"!L:7-T82!M960@:&5L=&%L`$;D;'1E="!MY7-T92!V
M87)A(&5T="!G;V1KY&YT('1A;"X`1&5T=&$@9N1L="!MY7-T92!I;FYE:.5L
M;&$@96X@4D="+6;D<F=K;V0@:2!H97AA9&5C:6UA;'0@9F]R;6%T+"!T(&5X
M("<C,3(S-&%F)RX`1FEL9F]R;6%T970@<W3V9',@:6YT92X`1&5T=&$@9F]R
M;75LY'(@:&%R(')E9&%N(&)E87)B971A=',N`$1E="!HY'(@Y'(@)7,N`$UE
M9&1E;&%N9&5T('-K<F5V<R!I(&5N(&%N;F%N('1E8VME;G5P<'/D='1N:6YG
M("@E<RD@Y&X@9&EN(&5G96XN`$1E="!HY'(@;G5M<F5T(&WE<W1E('9A<F$@
M;6EN<W0@971T+@!397)V97)N(&MA;B!I;G1E('!A8VMA('5P<"!Z:7`@;V-H
M(&=Z:7`@9FEL97(N`%-Y<W1E;65T(.1R(&;V<B!T:6QL9N1L;&5T(&%V86MT
M:79E<F%T+@!$970@:.1R(';D<F1E="!MY7-T92!V87)A(&YU;65R:7-K="X`
M1&5T=&$@9O9N<W1E<B!MY7-T92!A;G)O<&%S(&9RY6X@971T(&MO;F9I9W5R
M871I;VYS9O9N<W1E<@#%<VMA`,1R96YD96X`5&ED`%1I9'-R961O=FES;FEN
M9P!4:61S9F]R;6%T`%1I9'-V86P`UG-T=&EM;W(`4G5B<FEK`%)U8G)I:R`H
M=&]O;'1I<"DZ`%1I;&P`1O9R(&%T="!M87)K97)A(&9L97)A('9A;"P@:.5L
M;"!N960@0W1R;"`H4$,I(&5L;&5R($-O;6UA;F0@*$UA8RD@=&%N9V5N=&5N
M(&[D<B!D=2!K;&EC:V%R+@!)9&%G`%9I<V$@2%1-3"UKY&QL80!4;V=O`%1O
M:V5L874`26UO<F=O;@!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0#6=F5R
M<^1T=&YI;F=A<@!4<FEN:61A9"!O8V@@5&]B86=O`%-A;G0@96QL97(@9F%L
M<VMT`%1I`%1U;FES:65N`%1U<FMI970`5'5R:VES:R`H25-/+3@X-3DM.2D`
M5'5R:VUE;FES=&%N`%1U<FMS+2!O8V@@0V%I8V]S]F%R;F$`5'5V86QU`$%N
M9V4@9&ET="!V86PZ(`!55BUI;F1E>#H@`%523`!54DP@9O9R(&1I='0@;&5V
M97)A;G-R87!P;W)T97)I;F=S<VMR:7!T`%523#H`56=A;F1A`%5K<F%I;F$`
M2V%N(&EN=&4@;.1S82!61E,M;6%P<"X`1&5T(&=I8VL@:6YT92!A='0@;.1G
M9V$@=&EL;"!U=/9K860@86YVY&YD87)I;F9O<FUA=&EO;B!V:60@<F5G:7-T
M97)I;F<N`$MA;B!I;G1E(.1N9')A(&)E:/9R:6=H970@9O9R(%9&4RUF:6P@
M)7,N`$MA;B!I;G1E(.1N9')A(&)E:/9R:6=H970@9O9R(%9&4RUF:6P@)7,O
M)7,N`$MA;B!I;G1E(.1N9')A('1I;&P@)7,N`$MA;B!I;G1E(&MO;G1R;VQL
M97)A(&9I;'-T;W)L96L@)7,O)7,`2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL
M<W1O<FQE:R!PY2`E<RX`2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL<W1O<FQE
M:R!PY2`E<R\E<RX`2V%N(&EN=&4@:V]N=&%K=&$@4U%,+7-E<G9E<BX`2V%N
M(&EN=&4@:V]N=&%K=&$@=FEA(%-33"X`2V%N(&EN=&4@:V]P:65R82!61E,M
M9FEL+@!+86X@:6YT92!S:V%P82!61E,M;6%P<"`E<RX`2V%N(&EN=&4@<VMA
M<&$@5D93+6UA<'`N`$MA;B!I;G1E('-K87!A(%9&4RUF:6PN`$MA;B!I;G1E
M('-K87!A(%9&4RUM87!P("<E<R<N`$MA;B!I;G1E('-K87!A('1O;2!61E,M
M9FEL+@!+86X@:6YT92!P86-K82!U<'`@9&%T82X`2V%N(&EN=&4@<F%D97)A
M("5S+"!M87!P96X@Y'(@:6YT92!T;VTN`$MU;F1E(&EN=&4@<F%D97)A("<E
M<R<Z("5S`$MA;B!I;G1E(')A9&5R82`G)7,G.B`E<P!+86X@:6YT92!R861E
M<F$@)7,L(&UA<'!E;B#D<B!I;G1E('1O;2X`2V%N(&EN=&4@<F%D97)A(%9&
M4RUM87!P(')E:W5R<VEV="X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P+@!+
M86X@:6YT92!R861E<F$@5D93+6UA<'`Z("5S+@!+86X@:6YT92!R861E<F$@
M5D93+69I;"`E<RX`2V%N(&EN=&4@<F%D97)A(%9&4RUF:6PN`$MA;B!I;G1E
M(')A9&5R82!61E,M;6%P<"`G)7,G+@!+86X@:6YT92!R861E<F$@5D93(')E
M:W5R<VEV=#H@)7,N`$MA;B!I;G1E(&%V9_9R82!A:W1U96QL(&UA<'`N`$MA
M;B!I;G1E(&5X=')A:&5R82!#97)T:69I:V%T<V1E=&%L:F5R`$MA;B!I;G1E
M(&QA9&1A(&1E9FEN:71I;VYE;B!A=B`E<RX`2V%N(&EN=&4@9FQY='1A(%9&
M4RUF:6PN`$MA;B!I;G1E(/9P<&YA(%9&4RUF:6P@)7,N`$MA;B!I;G1E(/9P
M<&YA(%9&4RUF:6P@9O9R('-K<FEV;FEN9RX`2V%N(&EN=&4@]G!P;F$@5D93
M+69I;"X`2V%N(&EN=&4@]G!P;F$@:V]M<')I;65R870@87)K:78N`$MA;B!I
M;G1E(&SD<V$@5D93+69I;"`H9FEL97-I>F4H*2!M:7-S;'EC:V%D97,I+@!+
M86X@:6YT92!LY'-A(%9&4RUF:6P@*&=E=$9I;&53:7IE*"D@;6ES<VQY8VMA
M9&5S*2X`2V%N(&EN=&4@;.1S82!F:6PZ(`!+86X@:6YT92!LY'-A(&MA=&%L
M;V=E;B!F]G(@)W9F<W)O;W0G+@!+86X@:6YT92!B>71A(&YA;6X@<.4@)7,@
M=&EL;"`E<SH@9&5S=&EN871I;VYS;6%P<"!F:6YN<R!R961A;@!+86X@:6YT
M92!B>71A(&YA;6X@<.4@5D93+6UA<'`N`$MA;B!I;G1E(&)Y=&$@;F%M;B!P
MY2!61E,M;6%P<#H@)7,N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL
M("5S+@!+86X@:6YT92!B>71A(&YA;6X@<.4@5D93+69I;"`E<R\E<RX`2V%N
M(&EN=&4@8GET82!N86UN('#E(%9&4RUF:6PN`$MA;B!I;G1E(&OV<F$@)VUK
M:7-O9G,G+@!+86X@:6YT92#V=F5R<^1T=&$@5V]R9&1O:W5M96YT970`2V%N
M(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`E<RX`2V%N(&EN=&4@<VMR:79A
M('1I;&P@5D93+69I;"`H8V]P>2@I(&UI<W-L>6-K861E<RDN`$MA;B!I;G1E
M('-K<FEV82!D871A('1I;&P@5D93+69I;"X`2V%N(&EN=&4@<VMR:79A('1I
M;&P@5D93+69I;"P@:W9O=&$@<VMU;&QE(/9V97)S:W)I9&%S+@!5;F1E<G-T
M<G5K96X`Q6YG<F$@Y&YD<FEN9V%R`,5N9W)A(.1N9')I;F=A<@#%;F=R87(@
M9&EN('-E;F%S=&4@Y71GY')D`$]VY&YT870@<W9A<B!F<N5N('-E<G9E<B!P
MY2!F]G)B:6YD96QS93H@`$]VY&YT870@<W9A<B!F<N5N('-E<G9E<B!T:6QL
M.B``16H@:V%T96=O<FES97)A9`!)8VME(&AA;G1E<F%D(&MO;7!O;F5N="!A
M=B!T>7`Z("5S`%5N:6-O9&4@*%541BTX*0!&]G)E;F%D92!!<F%B96UI<F%T
M96X`4W1O<F)R:71A;FYI96X`1O9R96YT82!3=&%T97)N80!!;65R:6MA;G-K
M82!3=&EL;&%H879S]F%R;F$`16YH971E<@!/:^1N9`!/:^1N="!G<N1N<W-N
M:71T<VUE9&1E;&%N9&5I9"`H87!I;7-G:60I+@!/:^1N="!K;&EE;G1M961D
M96QA;F1E:60@*&-L:6US9VED*2X`3VOD;F0@;W)T('-P96-I9FEC97)A9"X`
M3VOD;G0@86YVY&YD87)N86UN(&5L;&5R(&SV<V5N;W)D+@!482!B;W)T(&SD
M;FME;B!F<N5N(&YU=G)A;F1E(&5L96UE;G0`3F%M;FSV<P!)8VME+7!R:79I
M;&EG97)A9&4@<VMR:7!T(&MA;B!I;G1E(&MO;6UA(.5T($ML:7!P('5T+TMO
M<&EE<F$O2VQI<W1R82UF=6YK=&EO;F5R;F$@878@<^1K97)H971S<VOD;"X@
M2VQI8VMA($]+(&;V<B!A='0@<V4@96X@=&5K;FES:R!B97-K<FEV;FEN9R!F
M<N5N(&UO>FEL;&$N;W)G(&]M(&AU<B!D=2!K86X@=&EL;.5T82!A='0@<VMR
M:7!T(&MO;6UE<B#E="!U<FML:7!P+@!482!B;W)T(&;D<F<`0V]N=&5N="U4
M>7!E('-T]F1S(&EN=&4Z("5S`%1I;&SD9V=E="!S=/9D<R!I;G1E`%5P<&1A
M=&5R80!5<'!D871E<F$@)7,`57!P9&%T97)A('-T871U<R!PY2!S=F%R86YD
M90!5<'!D871E<F$@86YVY&YD87)E`%5P<&1A=&5R861E("<E<R<N`%5P<&1A
M=&5R:6YG<W-C<FEP="!R861E<F%T+@!,861D82!U<'``3&%D9&%D92!U<'`@
M86QL82!K;VYF:6=U<F%T:6]N<V9I;&5R('1I;&P@<V5R=F5R;BX`5F5R<V%L
M97(`4F]M97)S:V$@<VEF9G)O<@!5<G5G=6%Y`$%N=N1N9"!A:W1U96QL.B`E
M<P!!;G;D;F0@4U-,`$%N=N1N9"!O;2!N86UN+VSV<V5N;W)D(.1R(&%N;F]R
M;'5N9&$@9O9R($E-4U`M<V5R=F5R+@!!;G;D;F1A<F4`06YVY&YD87)E("5S
M(.1R(&EN=&4@8F5H]G)I9R!F]G(@)7,N`$%N=N1N9&%R861M:6YI<W1R871I
M;VX`06YVY&YD87)I;G-TY&QL;FEN9V%R`$%N=N1N9&%R<F5G:7-T<F5R:6YG
M`$%N=N1N9&%R<F5G:7-T<F5R:6YG(&AA<B!A=F%K=&EV97)A=',N`$%N=N1N
M9&%R:V]N=&]T(&AI='1A9&5S(&EN=&4`06YVY&YD87)N86UN`$%N=N1N9&%R
M;F%M;B`E<R!F:6YN<R!R961A;BX`06YVY&YD87)N86UN.@!!;G;D;F1A<FYA
M;6XZ(`!!;G;D;F1A<F4@:2!S>7-T96UE=#H`57IB96MI<W1A;@!61E,M;6%P
M<"!E>&ES=&5R87(@:6YT92X`4V5M97-T97(`1VEL=&EG82!P;&%T<V5R('-O
M;2!H:71T861E<R!I;FML=61E<F%R.B``1VEL=&EG:&5T`$UI;G5T97(@9G+E
M;B!N=0!6Y')D970@]G9E<G-T:6=E<B!D970@:/9G<W1A('1I;&SE=&YA("@E
M<RD`5N1R9&5N`%;D<F1E;B!A='0@=N1L:F$@9G+E;@!686YU=&%U`%9A<FEA
M8F5L`%9E;F5Z=65L80!697)I9FEE<FEN9R!M:7-S;'EC:V%D97,@+2!M961D
M96QA;F1E="!K86X@:&$@;6%N:7!U;&5R871S+@!697)S:6]N`%9E<G-I;VYH
M86YT97)I;F<`5F5R=&EK86P@:G5S=&5R:6YG`%9E<G1I:V%L('5T9GEL;&YA
M9`!697)T:6MA;#H`5N1L9&EG="!H]F<`5FEE=&YA;0!6:65T;F%M97-I<VL@
M*%9)4T-)22D`5FES82`E<P!6:7-A(&5N(&5X=&5R;B!W96)B<VED80!6:7-A
M('-O;2`E<P!6:7-A(&CD;F1E;'-E`%9I<V$@=7!P9VEF=`!*=6YG9G)U]F%R
M;F$L($)R:71T:7-K80!*=6YG9G)U]F%R;F$L($%M97)I:V%N<VMA`%-I:W0`
M4VEK=#H`5F]D869O;F4@271A;&EE;B!V:6$@4TU44`!605).`%9!4DY)3D<A
M(2$@4D%$15)!(%-+4DE05$54($U!3E5%3$Q4($92Q4X@)7,N`%=)3B!V:6$@
M2%144`!786QL:7,@;V-H($9U='5N80!687)N:6YG`$]N`%;D9&5R<')O9VYO
M<P!6Y&1E<F1A=&$@9G+E;@!W96%T:&5R+F-O;0!796)B`%=E8F)P;&%T<P!7
M96)B<&QA='-E;B`M(%-O8F5R`%=E8F)P;&%T<V5N("T@4V]B97(@3ED`5F5C
M:V]V:7,`5N1L:V]M;65N`%;D;&MO;6UE;B!T:6QL("5S`%;D;&MO;6UE;BP@
M)7,`5N1S=&5R;.1N9'-K("A)4T\M.#@U.2TQ*0!6Y'-T97)LY&YD<VL@*$E3
M3RTX.#4Y+3$U*0!6Y'-T<F$@4V%H87)A`%9I;&ME;B!A<'!L:6MA=&EO;B!S
M:V%L;"`E<R!V:7-A(&5F=&5R(&EN;&]G9VYI;F<_`%9I;&ME;B#D<B!A=F=R
MY&YS;FEN9W-T96-K;F5T/P!6:6QK970@Y'(@=&5C:VYE="!F]G(@8VET97)A
M9"!T97AT/P!7:&5R96ES($%U<W1R86QI96YK87)T80!4:6QL('9I;&ME="!A
M;G1E8VMN:6YG<V)L;V-K('-K86QL(&%N=&5C:VYI;F=A<B!LY&=G87,@=&EL
M;#\`5FEL:V$@9F%S97(`5FEL:V$@<&QU9VEN('-K86QL(&%K=&EV97)A<R!F
M]G(@4FEC:"!497AT(&5D:71O<FXN`$)R961D`$)R961D(&D@0U-3+75N:71S
M`$)R961D('#E(&UE;GEN(&;V<B`G)7,G('1I;&P@=N1N<W1E<B`H9^1L;&5R
M(&9RY6X@;N1S=&$@:6YL;V=G;FEN9P!486)E;&QB<F5D9`!"<F5D9&5N:&5T
M`$)R961D.@!7:6MI`%9I;F0`5&ED:6<@=FEN9`!6:6YD:&%S=&EG:&5T(&D@
M:VYO<`!6:6YD.@!6:6YD.B``5FES9&]M`-9N<VME;&ES=&$`07)B971E`$%D
M<F5S<RP@87)B971E`%1E;&5F;VXL(&%R8F5T90!&96P@86YT86P@9N1L="!P
MY2!R860@)60N($;V<G;D;G1A9&4@)60L(&AI='1A9&4@)60N`$9E;"!A;G1A
M;"!FY&QT+B!&]G)VY&YT861E("5D+"!H:71T861E("5D+@!&96P@<&]S:71I
M;VX@)60@=FED(&SD<VYI;F<@878@5D93+69I;"X`6"U2968`6#4P.58S(%5T
M]FMA9"!N>6-K96QA;G;D;F1N:6YG`%@U,#E6,RUT:6QLY&=G`%E9`%E965D`
M66%H;V\A(&UA<`#%<FQI9P!996UE;@!*80!*82P@:F%G('-A;71Y8VME<@!$
M=2!H87(@86MT:79E<F%T('1E>'1LY&=E+B!!;G;D;F0@6SP^72!F]G(@871T
M(.5T97)GY2!T:6QL(%=94TE764<N`$1U(&AA<B!I;G1E(&)E:/9R:6=H970@
M<VMA<&$@9FQE<B#D;B`E9"!B;&]C:RX`1'4@:&%R(&EN=&4@8F5H]G)I9VAE
M="!A='0@<VMA<&$@9FQE<B#D;B`E9"!A;G1E8VMN:6YG87(N`$1U(.1R(&EN
M=&4@875T96YT:7-E<F%D+@!$=2!K86X@:6YT92!A;G;D;F1A("=<)R!I(&1I
M='0@;F%M;@!$=2!K86X@:6YT92!A;G;D;F1A("=<)R!I(&1I='0@;F%M;@!$
M=2!A;F=A=B!I;G1E(&5N(&=O9&OD;F0@92UP;W-T861R97-S+@!$=2!H87(@
M:6YT92!B96CV<FEG(&%T="!V:7-A(&%N=&5C:VYI;F=S8FQO8VL@)R5S)RX`
M1'4@Y'(@=71L;V=G860N`$1U(&WE<W1E(&%N9V4@971T(&=I;'1I9W0@;6]B
M:6QN=6UM97([(&5N8F%R="!S:69F<F]R(&]C:"!E='0@)RLG(&;V<F4@:6YT
M97)N871I;VYE;&QT('!R969I>"X`1'4@86YG878@:6YT92!E='0@9V]D:^1N
M="!VY')D92X`1'4@;>5S=&4@:V]N9FEG=7)E<F$@96X@1&%T851RY&1S+6MO
M<'!L:6YG(&;V<B!A='0@86YVY&YD82!R96=I<W1R97)I;F<`1'4@;>5S=&4@
M:V]N9FEG=7)E<F$@96X@5D93+6MO<'!L:6YG`$1U(&WE<W1E(&)E<VMR:79A
M('!R;V)L96UE;BP@:6YN86X@9'4@:V%N(')A<'!O<G1E<F$@971T('!R;V)L
M96TN`$1U(&WE<W1E(&%N9V4@96X@55),('-O;2!LY&YK96X@<&5K87(@<.4`
M1'4@;>5S=&4@86YG92!E='0@86YT96-K;FEN9W-B;&]C:R!S;VT@<VMA;&P@
M<F%D97)A<RX`1'4@;>5S=&4@86YG92!E;B!S97)V97(@<V]M('-K86QL(')A
M9&5R87,N`$1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA
M;&P@<F5N<V%S+@!$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M
M('-K86QL(')A9&5R87,N`$1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M
M;B!S;VT@<VMA;&P@;.1G9V%S('1I;&PN`$1U(&WE<W1E(&%N9V4@971T(&%N
M=N1N9&%R;F%M;B!S;VT@<VMA;&P@=7!P9&%T97)A<RX`1'4@;>5S=&4@86YG
M92!E;B#E=&?D<F0@<V]M('-K86QL('5T9O9R87,N`$1U(&WE<W1E(&%N9V4@
M971T(&YY='0@:V%T96=O<FEN86UN+@!$=2!MY7-T92!A;F=E(&5T="!I=&%L
M:65N<VMT('1E;&5F;VYN=6UM97(`1&EN("5S('-E<W-I;VX@:&%R('5P<&CV
M<G0N(%9A<B!G;V0@;&]G9V$@:6X@:6=E;BX`1&EN(&4M<&]S=&%D<F5S<P!$
M:6X@1G+E;CH@861R97-S.@!$:6X@:6YF;W)M871I;VX`1&EN(&EN=&5R;F5T
M861R97-S(&AA<B#D;F1R871S(&5F=&5R(&%T="!D=2!L;V=G870@:6X@=&EL
M;"`G)7,G+B!&]G(@871T('-K>61D82!D:6<L(&WE<W1E(&1U(&QO9V=A(&EN
M(&EG96XN`$1I='0@;F%M;@!$:6X@875T96YT:7-E<FEN9W-K;W!P;&EN9R!S
M=/9D97(@:6YT92!U<'!LY&=G(&%V(&%N=N1N9&%R92X@3VT@9'4@=FEL;"!A
M;G;D;F1A($AO<F1E(&;V<B!A='0@861M:6YI<W1R97)A(&%N=N1N9&%R92!S
MY2!MY7-T92!D=2!A;G;D;F1A(&5N(&%N;F%N(&%U=&5N=&ES97)I;F=S:V]P
M<&QI;F<N`$1I='0@875T96YT:7-E<FEN9W-K;W!P;&EN9R!S=/9D97(@:6YT
M92!L:7-T;FEN9R!A=B!A;G;D;F1A<F4L(&5L;&5R('/E(.1R(&9U;FMT:6]N
M96X@879S=.1N9V0N`$1I;B!W96)B;.1S87)E+VEN=&5R;F5T861R97-S(&AA
M<B#D;F1R871S(&5F=&5R(&%T="!D=2!L;V=G870@:6X@=&EL;"`G)7,G+B!&
M]G(@871T('-K>61D82!D:6<L(&WE<W1E(&1U(&QO9V=A(&EN(&EG96XN`$1I
M;B!W96)B;.1S87)E('-T]F1E<B!I;G1E(&1E;B!HY'(@9G5N:W1I;VYE;BX`
M1&EN('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@=71S:W)I9G1S9G5N:W1I;VYE
M;BX@5')Y8VL@0W1R;"]/<'1I;VX@*R!0(&;V<B!A='0@<VMR:79A('5T+@!$
M:6X@86MT=65L;&$@=&ED<WIO;CH`1&EN(&;V<G9A;&1A(&ED96YT:71E="!H
M87(@Y&YD<F%T<RX`1&EN(&;V<G9A;&1A(&ED96YT:71E=#H`1&ET="!F]G)V
M86QD82!A;G1E8VMN:6YG<V)L;V-K.@!$:71T(&9U;&QS=.1N9&EG82!N86UN
M.@!$:6X@:6YL;V=G;FEN9R!H87(@9^5T="!U="X`1&ET="!N>6$@;/9S96YO
M<F0@9O9R("5S(.1R.B`E<P!$:6YA(&%N=&5C:VYI;F=S8FQO8VLZ`$1I;F$@
M:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T97)A=',@9O9R(&1E;B!HY'(@<V5S
M<VEO;F5N+@!$:6YA(&EN<W3D;&QN:6YG87(@:&%R('5P<&1A=&5R871S+@!$
M:71T(&SV<V5N;W)D(&AA<B!B;&EV:70@Y71E<G-TY&QL=`!$:71T(&SV<VYO
M<F0@:&%R(.5T97)S=.1L;'1S+"!K;VYT<F]L;&5R82!D:6X@92UP;W-T(&]C
M:"!L;V=G82!I;B!M960@9&ET="!N>6$@;/9S96YO<F0N`$1I='0@;/9S96YO
M<F0@:&%R(&?E='0@=70N`$1I;F$@9FKD<G)S97)V<F%R.@!*=6=O<VQA=FEE
M;@!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6T?V;2!C:71E<F%D('1E
M>'1=`%M&96QR87!P;W)T70!;5FES82!C:71E<F%D('1E>'0@+0!;5FES82!C
M:71E<F%D('1E>'0@+2`E<R!R861E<ET`6W)A9"`E<R!A=B`E<UT`7T%D;6EN
M:7-T<F%T:6]N`%]4:6QL8F%K82!T:6QL(&%N=&5C:VYI;F=S8FQO8VL`7T-,
M20!?2V%T96=O<FD`7T1A=&%4<N1D`%]2861E<F$`7U)A9&5R82!R860`Q&YD
M<F$`7T;V<G-T82!R861E;@!?1W)U<'!E<@!?2&KD;'``7T)I;&1I;G-TY&QL
M;FEN9V%R+BXN`%]);7!O<G0O17AP;W)T`%],:7-T82!A;G1E8VMN:6YG87(`
M7TQO9V=A(&EN`%],;V=G82!U=`#$7VYD<F$@;.1N:RXN+@!?36EN82!A;G1E
M8VMN:6YG<V)L;V-K`%].>2!A;G1E8VMN:6YG`%]);G-TY&QL;FEN9V%R`%]"
M96CV<FEG:&5T97(`7U5T<VMR:69T`%]482!B;W)T(&SD;FLN+BX`7U/V:P!?
M4V5T=7``7U1A8F5L;&EN<W3D;&QN:6YG87(N+BX`7T%N=N1N9&%R90!A9')E
M<W-B;VL`;VOD;F0@;6]T=&%G87)E`&MA;&5N9&5R`&QU9VYT`&MA;B!I;G1E
M('-K87!A('5T9FEL`&MA;B!I;G1E(/9P<&YA(&EN9&%T80!K;&EC:V$@:.1R
M`&ML;V-K80!K;VUM86YD;W)A9'-F96P`:V]N9FEG=7)A=&EO;G-F96P`:W)I
M=&ES:R!S>7-T96UF:6P@<V%K;F%S`&1A=&%F;W)M871F96P`Y&YD<F$`<&]S
M=&5N(&MU;F1E(&EN=&4@:&ET=&%S`&9A;&QA;F1E`&9I;`!F<N5N(&1E;B`E
M<R`H)7,I(&ML("5S("5S`'-T;W)M8GEA<@!H.@!H:`!O:^1N9"!VY')D9&%T
M;W(`9V5N87-T`&EN;&EN90!B96%R8F5T;FEN9W-F96P`26YT97)N="!A<'!L
M:6MA=&EO;G-F96P`<F%D97)=`&9E;&MO9"`E9"!F<N5N(&UK:7-O9G,`;6T`
M;F%M;@!I;G1E(&EM<&QE;65N=&5R860`:6YT92!I;7!L96UE;G1E<F%D`&%N
M=&5C:VYI;F=S8FQO8VL`86YT96-K;FEN9V%R+F-S=@!P<F]C96YT`.5T:V]M
M<W0@;F5K860`<&EX;&%R`'!R;W1O:V]L;&9E;`!S=&EG86YD90!4:N1N<W1E
M;B#D<B!E:B!T:6QL9^1N9VQI9P!V:7-A('-K:6QL;F%D97(`<VUS,F5M86EL
M('9I82!(5%10`'-S`'-T861I9W0`<WES=&5M9F5L`'5P<&=I9G1S;&ES=&$`
M=&EL;&;D;&QI9W0@9F5L`&%N9V4@;/9S96YO<F1E="!T=N4@9^5N9V5R(&;V
M<B!A='0@8F5K<N1F=&$`96YA9`!N86UN;/9S`&%N=N1N9&%R=F%L`'9#87)D
M`'9.;W1E`'<Z`'=E871H97(N8V]M````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]L
M;V-A;&4O=')?5%(O````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0V`#`R,#`S,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VUN96UO+VQO8V%L92]T<E]44B]H96QP+GAM;```````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`S-#4`,3`T,3<S-C(W-#8`,#(Q
M-3`T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3DB/SX*
M/"$M+2`D2&]R9&4Z(&UN96UO+VQO8V%L92]T<E]44B]H96QP+GAM;"QV(#$N
M,2XR+C$@,C`P-2\Q,"\Q."`Q,SHP,3HQ-"!J86X@17AP("0@+2T^"CQH96QP
M/@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](D]V97)V:65W(CX*
M("`@(#QT:71L93Y/=F5R=FEE=SPO=&ET;&4^"B`@("`\:&5A9&EN9SY);G1R
M;V1U8W1I;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(#QI/DYO=&5S/"]I
M/B!I<R!A;B!A<'!L:6-A=&EO;B!W:&EC:"!A;&QO=W,@>6]U('1O(&-R96%T
M92!T:&4@8V]M<'5T97(@97%U:79A;&5N="!O9B!S=&EC:WD@;F]T97,N("!.
M;W1E<R!C86X@8F4@8W)E871E9"P@;6]D:69I960L(&1E;&5T960L(&%N9"!P
M<FEN=&5D+B`@66]U(&-A;B!A;'-O('-E87)C:"!O;B!Y;W5R(&YO=&5S('1O
M(&QO8V%T92!I;F9O<FUA=&EO;BX@("!3=7!P;W)T(&9O<B!I;7!O<G1I;F<@
M86YD(&5X<&]R=&EN9R!N;W1E<R!I<R!A;'-O(&%V86EL86)L92X*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@56YL:6ME(')E86P@<W1I8VMY(&YO=&5S
M+"!Y;W5R(&-O;7!U=&5R(&YO=&5S(&-A;B!B92!S:&%R960@=VET:"!O=&AE
M<G,@:6X@9&EF9F5R96YT('!H>7-I8V%L(&QO8V%T:6]N<RX@($YO=&5S(&-A
M;B!B92!O<F=A;FEZ960@:6YT;R!D:69F97)E;G0@;F]T97!A9',L(&%N9"!A
M<W-I9VYE9"!C871E9V]R:65S+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*
M"CQE;G1R>2!I9#TB3W9E<G9I97<B(&UD-3TB-3!E93<V,3,X9F(P.&(P-&(P
M,CDP,#8P-3-B8F%D8F,B('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y'96YE
M;"!"86O]_CPO=&ET;&4^"CQH96%D:6YG/E1A;OUT_6T\+VAE861I;F<^"CQP
M87)A/@I.;W1L87(@>?9N971I;6D@>F]R(&]L86X@;F]T;&%R_6[]>OT@8FEL
M9VES87EA<OUN_7ID82!O;'7^='5R;6%N_7K]('-A\&QA>6%N(&)I<B!U>6=U
M;&%M863]<BX@3F]T;&%R(&]L=?YT=7)U;&%B:6QI<BP@9&7P:?YT:7)I;&5B
M:6QI<BP@<VEL:6YE8FEL:7(L('9E('EA>F3]<OUL86)I;&ER+B!!>7+]8V$@
M8FEL9VD@>65R;&7^=&ER;65K(&GG:6X@;F]T;&%R_6[]>F1A(&%R86UA(&1A
M('EA<&%B:6QI<G-I;FEZ+B!$_?YA<F1A;B!N;W0@86QM86L@=F4@9/W^87+]
M>6$@;F]T('9E<FUE:R!D92!D97-T96ML96YM96MT961I<BX*/"]P87)A/@H\
M+V5N=')Y/@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](FQI<W0M
M86-T:6]N<R(^"B`@("`\=&ET;&4^3F]T97,@3&ES=#H@06-T:6]N<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY!8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("`\:3Y$96QE=&4@3F]T93PO:3X@<&5R;6%N96YT;'D@9&5L971E<R!T
M:&4@<V5L96-T960@;F]T92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M/&D^36]D:69Y($YO=&4\+VD^(&%L;&]W<R!Y;W4@=&\@;6]D:69Y(&%N(&5X
M:7-T:6YG(&YO=&4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#QI/D)A
M8VL@=&\@3F]T97!A9#PO:3X@=&%K97,@>6]U(&)A8VL@9G)O;2!N;W1E('9I
M97<@=&\@=&AE(&YO=&5P860@=&AA="!C;VYT86EN<R!T:&4@8W5R<F5N="!N
M;W1E+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB;&ES
M="UA8W1I;VYS(B!M9#4](C9D-3DR9C$U,V)F8C5C,CDV9&4U9&9E8F(T,CAE
M,6)A(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^3F]T;&%R($QI<W1E<VDZ
M(-W^;&5M;&5R/"]T:71L93X*/&AE861I;F<^W?YL96UL97(\+VAE861I;F<^
M"CQP87)A/@I.;W1U(%-I;"!S9>=I;&D@;F]T=2!S_')E:VQI('-I;&5R+@H\
M+W!A<F$^"CQP87)A/@I.;W1U($1E\&G^=&ER('9A<F]L86X@8FER(&YO='1A
M(&1E\&G^:6ML:6L@>6%P;6%N_7K]('-A\&QA<BX*/"]P87)A/@H\<&%R83X*
M3F]T9&5F=&5R:6YE($3V;OS^('-I>FD@;F]T(&?V<W1E<FEM:6YD96X@86S]
M<"!O(&YO='5N(&]L9'7P=2!N;W1D969T97)I;F4@9_9T_'+\<BX*/"]P87)A
M/@H\+V5N=')Y/@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](FUE
M;G4M86-T:6]N<R(^"B`@("`\=&ET;&4^365N=2!)=&5M<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY-96YU($ET96US/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("`\:3Y,:7-T($YO=&5S/"]I/B!L:7-T<R!A;&P@=&AE(&YO=&5S(&EN('1H
M92!C=7)R96YT(&YO=&5P860N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M(#QI/DYE=R!.;W1E/"]I/B!A;&QO=W,@>6]U('1O(&-R96%T92!A(&YE=R!N
M;W1E(&EN('1H92!C=7)R96YT(&YO=&5P860N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@(#QI/E-E87)C:#PO:3X@86QL;W=S('EO=2!T;R!S96%R8V@@
M9F]R('1E>'0@:6X@>6]U<B!N;W1E<RX@(%EO=2!C86X@<V5A<F-H('1H92!D
M97-C<FEP=&EO;B!F:65L9"!O;FQY+"!O<B!T:&4@9G5L;"!T97AT(&]F('1H
M92!N;W1E<RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@/&D^26UP;W)T
M+T5X<&]R=#PO:3X@86QL;W=S('EO=2!T;R!I;7!O<G0@;W(@97AP;W)T(&YO
M=&5S+B`@0W5R<F5N=&QY($-35@H@("`@9F]R;6%T=&5D(&%N9"!V3F]T92!F
M:6QE<R!A<F4@<W5P<&]R=&5D+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("`\:3Y0<FEN=#PO:3X@86QL;W=S('EO=2!T;R!P<FEN="!A(&YO=&4N("!4
M:&4@/&D^4')I;G0\+VD^(&EC;VYS(&ES(&]N;'D@:6X@=&AE(&UE;G4@8F%R
M('=H96X@82!N;W1E(&ES(&)E:6YG('9I97=E9"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*+2T^"@H\96YT<GD@:60](FUE;G4M86-T:6]N<R(@;60U/2(W,35A
M.#4S9#DS8V0S,S,P931D-S,P8CDQ,3)C.&$X,B(@<W1A=&4](G5P=&]D871E
M(CX*/'1I=&QE/DUE;OP@UO!E;&5R:3PO=&ET;&4^"CQH96%D:6YG/DUE;OP@
MUO!E;&5R:3PO:&5A9&EN9SX*/'!A<F$^"DYO=&QA<OT@3&ES=&5L92!K=6QL
M86[];&%N(&YO="!D969T97)I;F1E:VD@8OQT_&X@;F]T;&%R_2!G]G-T97)I
M<@H\+W!A<F$^"CQP87)A/@I996YI($YO="!N;W0@9&5F=&5R:6YD92!Y96YI
M(&YO="!O;'7^='5R;6%N_7K]('-A\&QA<@H\+W!A<F$^"CQP87)A/@I!<F%M
M82#V>F5L;&GP:2`L;F]T;&%R_6[]>F1A(&UE=&EN(&%R86UA<_T@>6%P;6%N
M_7K]('-A\&QA<BX@4V%D96-E(&'G_6ML86UA(&%L86[];OTL('EA(&1A('3\
M;2!M971N:2!N;W1L87)D82!A<F%Y86)I;&ER<VEN:7HN"CPO<&%R83X*/'!A
M<F$^"D%L+U9E<B!N;W1L87+];OUZ_2!D_?YA<F1A;B!A;/UP(&3]_F%R_7EA
M('9E<FUE>6D@<V'P;&%R+B!+=6QL86[];&%N($-35B!B:>=I;6EN9&5K:2!V
M92!V3F]T92!D;W-Y86QA<OT@9&5S=&5K;&5N:7(N"CPO<&%R83X*/'!A<F$^
M"EEA>F3]<B!N;W1L87+]('EA>F3]<OUR+B!987ID_7(@<VEM9V5S:2!S861E
M8V4@8FER(&YO="!G]G+\;G3\;&5N9&GP:6YD92!M96[\(.=U8G7P=6YD82!B
M96QI<FER+@H\+W!A<F$^"CPO96YT<GD^"@H*"CPA+2T@16YG;&ES:"!E;G1R
M>3H*/&5N=')Y(&ED/2)S;W)T:6YG(CX*("`@(#QT:71L93Y3;W)T:6YG($5N
M=')I97,\+W1I=&QE/@H@("`@/&AE861I;F<^4V]R=&EN9R!%;G1R:65S/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!7:&5N('9I97=I;F<@82!L:7-T(&]F
M(&5N=')I97,L('EO=2!C86X@<V]R="!T:&4@96YT<FEE<R!B>2!A;GD@8V]L
M=6UN(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T92!C;VQU;6X@:&5A
M9&EN9R!T:71L92X@(%1O('-W:71C:"!A(&-O;'5M;B!B971W965N(&%S8V5N
M9&EN9R!A;F0@9&5S8V5N9&EN9R!S;W)T:6YG(&]R9&5R+"!C;&EC:R!O;B!T
M:&4@87)R;W<@:6-O;B!I;B!T:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"BTM/@H*/&5N=')Y(&ED/2)S;W)T:6YG(B!M9#4](F-C
M83-B,60Q8SEE9#!E8S5A8C,X-68X,C0V.61D8SAF(B!S=&%T93TB=7!T;V1A
M=&4B/@H\=&ET;&4^1VER:?YL97)I;B!3_6[]9FQA;F3]<OUL;6%S_3PO=&ET
M;&4^"CQH96%D:6YG/D=I<FG^;&5R:6X@4_UN_69L86YD_7+];&UA<_T\+VAE
M861I;F<^"CQP87)A/@I':7)I_FQE<FEN(&QI<W1E<VEN:2!G]G+\;G3\;&5R
M:V5N+"!G:7)I_FQE<FD@:&5R:&%N9VD@8FER('/\='5N82!G]G)E(&\@<_QT
M=6YU;B!B8?YL_?#];F$@=/UK;&%Y87)A:R!S_6[]9FQA;F3]<F%B:6QI<G-I
M;FEZ+B!3_'1U;G4@>?QK<V5L96X@=F4@86SG86QA;B!S_6[]9FQA;F3]<FUA
M(&%R87/];F1A(&1E\&G^=&ER;65K(&GG:6XL('/\='5N(&)A_FS]\/UN9&%K
M:2!O:R!S:6UG97-I;FD@=/UK;&%Y_6XN"CPO<&%R83X*/"]E;G1R>3X*"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;6YE;6\O;&]C86QE+WIH7T-.+P``````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-@`P,C`P,#$`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O>FA?0TXO3$-?34534T%'
M15,O````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S0V`#`R,34V-@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L
M92]Z:%]#3B],0U]-15-304=%4R]M;F5M;RYM;P``````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`R,#`R-3<`,3`T,3<S-C(W-#8`,#(S,C0Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````@`0``!P````<)```
M!P8``!Q(````````.&````X````Y8```#P```$A@```(````6&````P```!A
M8```!````&Y@```/````<V````L```"#8```#@```(]@```%````GF```"@`
M``"D8```"@```,U@```5````V&```!(```#N8```"P````%A```.````#6$`
M``H````<80``#0```"=A```.````-6$```8```!$80``#P```$MA```8````
M6V$```P```!T80``"````(%A```N````BF$``!H```"Y80``,@```-1A```X
M````!V(``%0```!`8@``40```)5B``!:````YV(``%<```!"8P``-````)IC
M```%````SV,```8```#58P``$0```-QC```(````[F,``"4```#W8P``(```
M`!UD```/````/F0```H```!.9````P```%ED```/````760``!0```!M9```
M"0```()D```-````C&0``!(```":9```#P```*UD```/````O60```@```#-
M9```)````-9D```(````^V0``!D````$90``!P```!YE```,````)F4``"P`
M```S90``#@```&!E```#````;V4```L```!S90``!P```']E```'````AV4`
M``4```"/90``%P```)5E```*````K64```\```"X90``&````,AE```.````
MX64``!0```#P90``%P````5F```7````'68``!,````U9@``#@```$EF```?
M````6&8```<```!X9@``!@```(!F```(````AV8```\```"09@``"@```*!F
M```3````JV8```L```"_9@``%0```,MF```5````X68```<```#W9@``!0``
M`/]F```5````!6<``!$````;9P``#````"UG```[````.F<```D```!V9P``
M!P```(!G```4````B&<```4```"=9P``"0```*-G```0````K6<``!,```"^
M9P``.0```-)G```G````#&@``"P````T:```*@```&%H```E````C&@```H`
M``"R:```!@```+UH```)````Q&@```<```#.:```+P```-9H```W````!FD`
M`"X````^:0``50```&UI```M````PVD``"T```#Q:0``+0```!]J``!`````
M36H``",```".:@``(P```+)J```M````UFH``#,````$:P``%0```#AK```9
M````3FL``"D```!H:P``)````))K```1````MVL```H```#):P``$````-1K
M```6````Y6L``!8```#\:P``!P```!-L```'````&VP``!0````C;```"@``
M`#AL```(````0VP```<```!,;```!P```%1L```&````7&P```4```!C;```
M!P```&EL```&````<6P```@```!X;```#@```(%L```*````D&P```0```";
M;```!P```*!L```)````J&P``!8```"R;```"````,EL```-````TFP```8`
M``#@;```'@```.=L```1````!FT```@````8;0``#0```"%M```,````+VT`
M``<````\;0```P```$1M```#````2&T``!<```!,;0``"````&1M```$````
M;6T```@```!R;0``"````'MM```@````A&T```8```"E;0``!@```*QM```5
M````LVT``!@```#);0``'0```.)M``!4`````&X``"D```!5;@``"@```']N
M```(````BFX```X```"3;@``"@```*)N```4````K6X``!@```#";@``'0``
M`-MN```3````^6X``!0````-;P``!````")O```%````)V\```4````M;P``
M&P```#-O```:````3V\``!$```!J;P``$0```'QO```<````CF\``!````"K
M;P``(0```+QO```*````WF\``!$```#I;P``#````/MO```&````"'```!<`
M```/<```"````"=P```%````,'````P````V<```!@```$-P```'````2G``
M``T```!2<```!P```&!P```+````:'````<```!T<```!P```'QP```*````
MA'````P```"/<```$````)QP```%````K7```"4```"S<```$P```-EP```[
M````[7```"`````I<0``#````$IQ```.````5W$```H```!F<0``#0```'%Q
M```>````?W$``!L```"><0``(0```+IQ```>````W'$``!X```#[<0``&P``
M`!IR```>````-G(``#,```!5<@``+P```(ER```2````N7(``"D```#,<@``
M$@```/9R```6````"7,``"@````@<P``(````$ES```A````:G,``$$```",
M<P``!P```,YS```2````UG,``!,```#I<P``$@```/US```'````$'0```0`
M```8=```#````!UT```/````*G0``!,````Z=```#0```$YT```-````7'0`
M``8```!J=```$0```'%T```7````@W0``!L```";=```#@```+=T```"````
MQG0```4```#)=```!````,]T```-````U'0```X```#B=````P```/%T```(
M````]70```\```#^=```$`````YU```9````'W4``!H````Y=0``#````%1U
M```1````874``!D```!S=0``#0```(UU```'````FW4```H```"C=0``%```
M`*YU```+````PW4``"(```#/=0``+P```/)U```+````(G8```D````N=@``
M&0```#AV```+````4G8``!<```!>=@``%P```'9V```)````CG8``!8```"8
M=@``#P```*]V```.````OW8```@```#.=@``#0```-=V```F````Y78``$,`
M```,=P``"````%!W```2````67<```@```!L=P``"P```'5W```O````@7<`
M``X```"Q=P``!@```,!W```#````QW<```<```#+=P``"@```--W```*````
MWG<```\```#I=P``$````/EW```7````"G@``!$````B>```%P```#1X```%
M````3'@```L```!2>```!0```%YX```-````9'@``!L```!R>```%P```(YX
M```)````IG@```X```"P>```#0```+]X```(````S7@```X```#6>```$0``
M`.5X```'````]W@```4```#_>```!P````5Y```(````#7D```8````6>0``
M$````!UY```0````+GD```\````_>0``"P```$]Y```/````6WD```P```!K
M>0``#P```'AY```'````B'D```8```"0>0``#P```)=Y```(````IWD``!,`
M``"P>0``'@```,1Y```A````XWD``"`````%>@``&0```"9Z```7````0'H`
M`"4```!8>@``%P```'YZ```;````EGH```T```"R>@```P```,!Z```(````
MQ'H```H```#->@``#````-AZ```$````Y7H``!,```#J>@``%````/YZ```,
M````$WL```D````@>P``"P```"I[```;````-GL```<```!2>P``!P```%I[
M```*````8GL```T```!M>P``"0```'M[```$````A7L``!@```"*>P``"@``
M`*-[``!\````KGL```4````K?```!P```#%\```,````.7P```@```!&?```
M!@```$]\```(````5GP```(```!??```!@```&)\```-````:7P``!````!W
M?```!````(A\```)````C7P``!````"7?```"0```*A\```)````LGP```4`
M``"\?```!@```,)\```9````R7P```<```#C?```!P```.M\```%````\WP`
M``D```#Y?```"@````-]```"````#GT```T````1?0``"0```!]]```&````
M*7T``!(````P?0``"0```$-]```'````37T``!0```!5?0``'0```&I]```&
M````B'T```H```"/?0``!````)I]```)````GWT```@```"I?0``$0```+)]
M```)````Q'T```8```#.?0``#0```-5]```&````XWT```0```#J?0``'@``
M`.]]```%````#GX```X````4?@``!@```"-^```A````*GX``!4```!,?@``
M!````&)^```1````9WX```8```!Y?@``(@```(!^```=````HWX```0```#!
M?@``#````,9^```*````TWX```@```#>?@``"0```.=^```%````\7X```\`
M``#W?@``)`````=_```(````+'\```H````U?P``!P```$!_```@````2'\`
M`"````!I?P``)@```(I_```9````L7\``"D```#+?P``!P```/5_```*````
M_7\```\````(@```#````!B````&````)8````\````L@```$@```#R````0
M````3X```!P```!@@```#P```'V````%````C8```!````"3@```"0```*2`
M```$````KH````L```"S@```#````+^````/````S(```!D```#<@```#P``
M`/:````3````!H$``!(````:@0``!P```"V!```,````-8$``"````!"@0``
M%````&.!```1````>($``!<```"*@0``'````**!```3````OX$``!$```#3
M@0``&@```.6!```>`````((``!H````?@@``$0```#J"```7````3((``!4`
M``!D@@``&0```'J"```$````E((```<```"9@@``"P```*&"```&````K8(`
M``8```"T@@``!@```+N"```%````PH(```<```#(@@``!P```-""```%````
MV((``!8```#>@@``!@```/6"```&````_((```0````#@P``!`````B#```.
M````#8,```P````<@P``#````"F#```-````-H,```H```!$@P``#@```$^#
M```%````7H,``"@```!D@P``#````(V#```/````FH,```H```"J@P``"```
M`+6#```)````OH,``"L```#(@P``"````/2#```F````_8,``!(````DA```
M#P```#>$```&````1X0```H```!.A```"````%F$```@````8H0```D```"#
MA```#````(V$```-````FH0```X```"HA```%@```+>$```1````SH0```8`
M``#@A```!@```.>$```'````[H0```<```#VA```!P```/Z$```6````!H4`
M``T````=A0``!````"N%```%````,(4``!X````VA0``$````%6%```,````
M9H4```D```!SA0``!P```'V%```*````A84```D```"0A0``#@```)J%```0
M````J84``!H```"ZA0``"@```-6%```)````X(4```P```#JA0``#P```/>%
M```(````!X8```8````0A@``!P```!>&```%````'X8``$<````EA@``#0``
M`&V&```*````>X8```(```"&A@``!````(F&```E````CH8```,```"TA@``
M!0```+B&```J````OH8```H```#IA@``!````/2&```*````^88```8````$
MAP``"`````N'```(````%(<```0````=AP``!0```"*'```%````*(<``!L`
M```NAP``+P```$J'```0````>H<```H```"+AP``#P```):'```*````IH<`
M``D```"QAP``&P```+N'```8````UX<``!<```#PAP``#@````B(```#````
M%X@```<````;B```!P```".(```)````*X@```H````UB```!P```$"(``!1
M````2(@``!````":B```#````*N(```:````N(@``$H```#3B```!@```!Z)
M```&````)8D```8````LB0``'P```#.)```)````4XD``!@```!=B0``%P``
M`':)```&````CHD``%<```"5B0``$P```.V)```3`````8H```(````5B@``
M"P```!B*```-````)(H```P````RB@``!P```#^*```4````1XH```8```!<
MB@``"````&.*```.````;(H```<```![B@``"@```(.*```+````CHH```<`
M``":B@``"0```***```)````K(H```H```"VB@``!P```,&*```)````R8H`
M``<```#3B@``"@```-N*```2````YHH```H```#YB@``"0````2+```0````
M#HL```<````?BP``$@```">+```$````.HL```<````_BP``!0```$>+```%
M````38L```L```!3BP``%````%^+```1````=(L``!@```"&BP``'````)^+
M```9````O(L```<```#6BP``!0```-Z+```-````Y(L```@```#RBP``%P``
M`/N+```+````$XP``!,````?C```!````#.,```,````.(P```D```!%C```
M!0```$^,```'````58P```4```!=C```!````&.,```I````:(P``#(```"2
MC```+@```,6,```S````](P``#,````HC0``.````%R-```0````E8T``!,`
M``"FC0``+0```+J-```M````Z(T``#$````6C@``+@```$B.```O````=XX`
M`"P```"GC@``$P```-2.```K````Z(X``!H````4CP``"0```"^/``!%````
M.8\``$$```!_CP``!````,&/```4````QH\```X```#;CP``$P```.J/```8
M````_H\```8````7D```"0```!Z0```*````*)````\````SD```#@```$.0
M```%````4I````@```!8D```!@```&&0```4````:)```!$```!]D```#@``
M`(^0```"````GI````X```"AD```!0```+"0```'````MI````8```"^D```
M!````,60```I````RI```!\```#TD```7````!21```4````<9$```<```"&
MD0``#@```(Z1```,````G9$```P```"JD0``$P```+>1```=````RY$``!D`
M``#ID0``!0````.2```1````"9(```T````;D@``$0```"F2```D````.Y(`
M`!4```!@D@``$@```':2```.````B9(``!D```"8D@``"````+*2```)````
MNY(```@```#%D@``!0```,Z2```?````U)(```8```#TD@``$````/N2```(
M````#),```@````5DP``+````!Z3```:````2Y,```D```!FDP``"@```'"3
M```5````>Y,```4```"1DP``%````)>3```$````K),``!````"QDP``'@``
M`,*3```H````X9,```H````*E```&@```!64```4````,)0```0```!%E```
M"P```$J4```%````5I0```8```!<E```"````&.4```@````;)0``$$```"-
ME```&@```,^4```H````ZI0``"D````3E0``!@```#V5```%````1)4```@`
M``!*E0``*@```%.5```C````?I4``"X```"BE0``-````-&5```(````!I8`
M`!<````/E@``"@```">6```'````,I8``!`````ZE@``"P```$N6```3````
M5Y8```@```!KE@``"P```'26```*````@)8``!0```"+E@``,@```*"6```+
M````TY8```4```#?E@``%P```.66```/````_98```4````-EP``!````!.7
M```-````&)<``#(````FEP``%P```%F7```,````<9<``!0```!^EP``!0``
M`).7```'````F9<```X```"AEP``*@```+"7```&````VY<```P```#BEP``
M"P```.^7```V````^Y<```L````RF```#P```#Z8```R````3I@```<```"!
MF```$0```(F8```'````FY@```0```"CF```!P```*B8```*````L)@```L`
M``"[F```#````,>8```#````U)@``!(```#8F```!@```.N8```>````\I@`
M`!@````1F0``)0```"J9```-````4)D```D```!>F0```P```&B9```'````
M;)D```(```!TF0``#````'>9```5````A)D```L```":F0``&0```*:9```@
M````P)D``!(```#AF0``!0```/29```*````^ID``!4````%F@``$@```!N:
M```,````+IH```<````[F@``#````$.:``!2````4)H``!<```"CF@``!@``
M`+N:```.````PIH```P```#1F@``#0```-Z:```5````[)H``!(````"FP``
M#P```!6;```4````)9L``!L````ZFP``:0```%:;```:````P)L``!<```#;
MFP``&@```/.;```7````#IP``!L````FG```&0```$*<```?````7)P``!,`
M``!\G```!P```)"<```(````F)P```D```"AG```%0```*N<```-````P9P`
M`!,```#/G````P```..<```_````YYP``#<````GG0``5P```%^=```O````
MMYT```H```#GG0``"````/*=```-````^YT``"T````)G@``!````#>>```E
M````/)X```L```!BG@``'0```&Z>```&````C)X```P```"3G@``!P```*">
M```)````J)X``!,```"RG@``"0```,:>```$````T)X``!````#5G@``"```
M`.:>```(````[YX```P```#XG@``#P````6?```'````%9\``!`````=GP``
M%````"Z?```.````0Y\```P```!2GP``&P```%^?```L````>Y\``!,```"H
MGP``!0```+R?```$````PI\``!<```#'GP``"0```-^?```(````Z9\```H`
M``#RGP``$0```/V?```&````#Z````X````6H```#@```"6@```-````-*``
M``L```!"H````@```$Z@```'````4:````8```!9H```"0```&"@```'````
M:J```!4```!RH```!0```(B@```'````CJ````@```"6H```!P```)^@```'
M````IZ````X```"OH```"0```+Z@```&````R*````@```#/H```"P```-B@
M```'````Y*````@```#LH```!P```/6@```6````_:````D````4H0``!@``
M`!ZA```+````):$``!0````QH0``"````$:A```&````3Z$``!D```!6H0``
M"@```'"A```<````>Z$```<```"8H0``!0```*"A```0````IJ$``!0```"W
MH0``"P```,RA```-````V*$``!<```#FH0``!````/ZA```)`````Z(```(`
M```-H@``#@```!"B```(````'Z(``!\````HH@``(P```$BB```Q````;*(`
M`"<```">H@``2@```,:B```X````$:,``"@```!*HP``+````'.C```;````
MH*,``#X```"\HP``2````/NC``!!````1*0``%L```"&I```20```.*D```A
M````+*4``!\```!.I0``*P```&ZE```A````FJ4``#,```"\I0``)0```/"E
M```G````%J8``#`````^I@``:0```&^F```]````V:8``&4````7IP``30``
M`'VG```O````RZ<``"X```#[IP``5````"JH```R````?Z@``"\```"RJ```
M+````.*H```M````#ZD``!<````]J0``)0```%6I```R````>ZD``"D```"N
MJ0``/@```-BI```B````%ZH``%(````ZJ@``)0```(VJ```+````LZH``"$`
M``"_J@``,````.&J```E````$JL``!P````XJP``,0```%6K```$````AZL`
M``T```",JP``"P```)JK```.````IJL```L```"UJP``!0```,&K```"````
MQZL``%D```#*JP``!0```"2L```2````*JP```0````]K```!P```$*L```(
M````2JP```4```!3K```$P```%FL```-````;:P```(```![K```!P```'ZL
M```&````AJP``!0```"-K```#````**L```8````KZP```8```#(K```$@``
M`,^L```,````XJP```,```#OK```!````/.L```&````^*P```<```#_K```
M'P````>M```U````)ZT``"X```!=K0``+P```(RM```7````O*T``"````#4
MK0``&P```/6M```8````$:X``"0````JK@``'P```$^N```:````;ZX``!H`
M``"*K@``+P```*6N```K````U:X``!\````!KP``(P```"&O```?````1:\`
M`!H```!EKP``)0```("O```F````IJ\``"4```#-KP``)````/.O```8````
M&+```!T````QL```)````$^P```8````=+```"(```"-L```)0```+"P```?
M````UK```",```#VL```'P```!JQ```@````.K$``!H```!;L0``)@```':Q
M```>````G;$``!X```"\L0``"0```-NQ```,````Y;$``!<```#RL0``+P``
M``JR```D````.K(```<```!?L@``#P```&>R```4````=[(```X```",L@``
M#0```)NR```D````J;(```4```#.L@``!P```-2R```=````W+(``!4```#Z
ML@``!@```!"S```)````%[,```L````ALP``%P```"VS```&````1;,``#,`
M``!,LP``!P```("S```A````B+,``!,```"JLP``#````+ZS```1````R[,`
M`#(```#=LP``"````!"T```)````&;0```H````CM```%````"ZT```*````
M0[0``!T```!.M```"````&RT```?````=;0```@```"5M```&@```)ZT```&
M````N;0```<```#`M```"````,BT```)````T;0``#\```#;M```!P```!NU
M```/````([4```@````SM0``$P```#RU```'````4+4``!D```!8M0``"@``
M`'*U```7````?;4``!0```"5M0``"@```*JU```,````M;4``!<```#"M0``
M!````-JU```J````W[4``!$````*M@``!P```!RV```"````)+8``!`````G
MM@```P```#BV```(````/+8```8```!%M@``!P```$RV```-````5+8```L`
M``!BM@``%````&ZV```5````@[8```X```"9M@``+P```*BV```@````V+8`
M`!P```#YM@``$P```!:W```%````*K<```8````PMP``#````#>W```*````
M1+<``!$```!/MP```@```&&W```$````9+<```H```!IMP``!@```'2W```%
M````>[<```P```"!MP``10```(ZW```H````U+<``%,```#]MP``&0```%&X
M```@````:[@``#4```",N```10```,*X```P````"+D``"@````YN0``)@``
M`&*Y```E````B;D``"@```"ON0``*````-BY```P`````;H``!(````RN@``
M$````$6Z``!Y````5KH```D```#0N@``<P```-JZ``!\````3KL``"L```#+
MNP``%P```/>[```?````#[P``!0````OO```"@```$2\```%````3[P```8`
M``!5O```"````%R\```0````9;P```\```!VO```!````(:\```9````B[P`
M``(```"EO```"0```*B\```$````LKP```\```"WO```$P```,>\```B````
MV[P```<```#^O```"P````:]```%````$KT```(````8O0``"P```!N]``!9
M`0``)[T```H```"!O@``#````(R^```'````F;X```<```"AO@```@```*F^
M```2````K+X```L```"_O@``!P```,N^```%````T[X``!(```#9O@``!P``
M`.R^```+````]+X```D`````OP``"P````J_```)````%K\```4````@OP``
M"@```":_```/````,;\```8```!!OP``#````$B_```2````5;\```H```!H
MOP``"0```'._```=````?;\``!0```";OP``)0```+"_```M````UK\``#P`
M```$P```0````$'```!`````@L```$8```##P```)P````K!```%````,L$`
M``@````XP0``#@```$'!```'````4,$``!L```!8P0``&P```'3!```+````
MD,$```0```"<P0``!````*'!```*````IL$```P```"QP0``"@```+[!```*
M````R<$```@```#4P0``#0```-W!```-````Z\$```8```#YP0``'P````#"
M```(````(,(``!D````IP@``!````$/"```&````2,(``!\```!/P@``!```
M`&_"```(````=,(```8```!]P@``"@```(3"```*````C\(```0```":P@``
M$````)_"```*````L,(```@```"[P@``%````,3"```&````V<(```X```#@
MP@``#@```._"```.````_L(```@````-PP``"@```!;#```5````(<,```8`
M```WPP``!@```#[#```&````1<,```@```!,PP``!@```%7#```0````7,,`
M``@```!MPP``#@```';#```2````A<,```0```"8PP``!````)W#```7````
MHL,```P```"ZPP``#````,?#```:````U,,```8```#OPP``"````/;#```6
M````_\,```8````6Q```!````!W$```*````(L0```\````MQ```'0```#W$
M```;````6\0``!D```!WQ```&P```)'$```9````K<0```0```#'Q```!```
M`,S$```(````T<0```8```#:Q```*@```.'$```C````#,4``"D````PQ0``
M:P```%K%```H````QL4``"@```#OQ0``*````!C&```G````0<8``!H```!I
MQ@``&@```(3&```H````G\8``"X```#(Q@``"0```/?&```,`````<<``!``
M```.QP``#0```!_'```+````+<<```@````YQP``"````$+'```2````2\<`
M`!0```!>QP``"@```'/'```$````?L<``!@```"#QP``"````)S'```(````
MI<<```@```"NQP``!@```+?'```&````OL<```0```#%QP``"@```,K'```$
M````U<<```0```#:QP``"````-_'```(````Z,<```0```#QQP``"````/;'
M```$````_\<``!0````$R```"````!G(```(````(L@```0````KR```#@``
M`##(```$````/\@```@```!$R```"````$W(```*````5L@```8```!AR```
M#````&C(```#````=<@```H```!YR```!````(3(```&````B<@```8```"0
MR```!@```)?(```:````GL@```8```"YR```!````,#(```,````Q<@``!(`
M``#2R```$@```.7(```Q````^,@``!D````JR0``!@```$3)```$````2\D`
M``@```!0R0``"````%G)```6````8LD```H```!YR0``$0```(3)```(````
MELD```@```"?R0``!````*C)```$````K<D```0```"RR0``$0```+?)```/
M````R<D```@```#9R0``#@```.+)```-````\<D```8```#_R0``%0````;*
M```(````',H```P````ER@``"````#+*```$````.\H```H```!`R@``"```
M`$O*```$````5,H```8```!9R@``!````&#*```$````9<H```@```!JR@``
M!````'/*```&````>,H```8```!_R@``!````(;*```$````B\H```<```"0
MR@``"````)C*```$````H<H```H```"FR@``"@```+'*```K````O,H``!H`
M``#HR@``"`````/+```(````#,L```H````5RP``"````"#+```4````*<L`
M`!@````^RP``%P```%?+```7````;\L``!0```"'RP``$@```)S+```5````
MK\L``!T```#%RP``'0```./+```,`````<P``!<````.S```#````";,```7
M````,\P``!@```!+S```$P```&3,```6````>,P``#````"/S```!````,#,
M```,````Q<P```P```#2S```"@```-_,```(````ZLP```0```#SS```"```
M`/C,```(`````<T```H````*S0``"````!7-```(````'LT```@````GS0``
M$0```##-```7````0LT``!H```!:S0``"@```'7-```"````@,T```0```"#
MS0``!````(C-```(````C<T```@```"6S0``!````)_-```&````I,T```@`
M``"KS0``#````+3-```-````P<T```T```#/S0``"@```-W-```(````Z,T`
M``X```#QS0``"`````#.```$````"<X```0````.S@``"````!/.```$````
M',X``!T````AS@``%P```#_.```$````5\X```@```!<S@``%@```&7.```*
M````?,X```@```"'S@``"````)#.```$````F<X``!$```">S@``"````+#.
M```(````N<X```8```#"S@``!@```,G.```<````T,X``"D```#MS@``"```
M`!?/```.````(,\```0````OSP``!P```#3/```>````/,\```@```!;SP``
M"````&3/```$````;<\```@```!RSP``"````'O/```*````A,\```@```"/
MSP``"````)C/```.````H<\```@```"PSP``#@```+G/```$````R,\```@`
M``#-SP``"````-;/```,````W\\``!4```#LSP``#`````+0```(````#]``
M``D````8T```"0```"+0```$````+-````H````QT```"@```#S0```*````
M1]````0```!2T```"````%?0```*````8-````0```!KT```"@```'#0```*
M````>]````D```"&T```"````)#0```*````F=````D```"DT```!P```*[0
M```$````MM````0```"[T```!@```,#0```&````Q]````T```#.T```$```
M`-S0```5````[=```!0````#T0``$````!C1```0````*=$``!L````ZT0``
M$````%;1```=````9]$```@```"%T0``!````([1```$````D]$```@```"8
MT0``"@```*'1```$````K-$``!,```"QT0``$0```,71```*````U]$```@`
M``#BT0``"````.O1```5````]-$```8````*T@``!````!'2```&````%M(`
M``8````=T@``"````"32```$````+=(```X````RT@``"````$'2``!.````
M2M(```0```"9T@``!````)[2```(````H](```0```"LT@``!````+'2```(
M````MM(```8```"_T@``!````,;2```*````R](```X```#6T@``!@```.72
M```"````[-(```@```#OT@``!````/C2```$````_=(```0````"TP``!@``
M``?3```2````#M,```@````ATP``!````"K3```$````+],```@````TTP``
M`@```#W3```$````0-,```L```!%TP``!````%'3```$````5M,``!,```!;
MTP``!@```&_3```(````=M,```H```!_TP``$@```(K3```&````G=,```H`
M``"DTP``!````*_3```(````M-,```@```"]TP``"````,;3```(````S],`
M``8```#8TP``$````-_3```&````\-,```0```#WTP``$0```/S3```$````
M#M0```D````3U```!````!W4```0````(M0``!<````SU```!````$O4```.
M````4-0```0```!?U```$0```&34```&````=M0```0```!]U```"````(+4
M```(````B]0```@```"4U```"````)W4```%````IM0```8```"LU```#0``
M`+/4```$````P=0```8```#&U```!@```,W4```5````U-0``!4```#JU```
M'0````#5```0````'M4``"`````OU0``!````%#5```(````5=4```H```!>
MU0``"````&G5```$````<M4```T```!WU0``#````(75```)````DM4``!,`
M``"<U0``"````+#5```$````N=4```@```"^U0``"@```,?5```$````TM4`
M``0```#7U0``"````-S5```,````Y=4```X```#RU0``"`````'6```-````
M"M8``!$````8U@``!````"K6```&````+]8``!D````VU@``#P```%#6```/
M````8-8```\```!PU@``#@```(#6```0````C]8``!````"@U@``%@```+'6
M```3````R-8```\```#<U@``#P```.S6```/````_-8``!$````,UP``$```
M`![7```&````+]<```8````VUP``!````#W7```&````0M<```8```!)UP``
M!````%#7```&````5=<```8```!<UP``!````&/7```,````:-<``!(```!U
MUP``!@```(C7```$````C]<```0```"4UP``!````)G7```$````GM<```@`
M``"CUP``"````*S7```(````M=<```H```"^UP``"@```,G7```&````U-<`
M`!(```#;UP``"````.[7```(````]]<```@`````V```"`````G8```(````
M$M@``"@````;V```#@```$38```$````4]@```0```!8V```#0```%W8```&
M````:]@```H```!RV```!````'W8```$````@M@```8```"'V```!@```([8
M```)````E=@```X```"?V```%````*[8```6````P]@```@```#:V```"```
M`./8```&````[-@```8```#SV```"````/K8```&`````]D```H````*V0``
M!````!79```$````&MD``!T````?V0``#````#W9```1````2MD```\```!<
MV0``$P```&S9```1````@-D``!$```"2V0``#P```*39```3````M-D``!0`
M``#(V0``!````-W9```&````XMD```H```#IV0``"@```/39```$````_]D`
M``0````$V@``!`````G:```$````#MH``"L````3V@``"0```#_:```&````
M2=H```(```!0V@``"````%/:```;````7-H```,```!XV@``"````'S:```,
M````A=H```P```"2V@``!````)_:```(````I-H```8```"MV@``"````+3:
M```(````O=H```0```#&V@``!@```,O:```$````TMH``!(```#7V@``)```
M`.K:```*````#]L```H````:VP``#````"7;```*````,ML```@````]VP``
M%P```$;;```8````7ML``!<```!WVP``#````(_;```$````G-L```H```"A
MVP``!````*S;```(````L=L```D```"ZVP``!````,3;```L````R=L```L`
M``#VVP``"`````+<```3````"]P``"L````?W```!````$O<```$````4-P`
M``8```!5W```$@```%S<```)````;]P``!@```!YW```%P```)+<```$````
MJMP``#<```"OW```$````.?<```0````^-P```8````)W0``"````!#=```(
M````&=T```H````BW0``!````"W=```(````,MT```8````[W0``!````$+=
M```&````1]T```0```!.W0``"@```%/=```(````7MT```8```!GW0``!```
M`&[=```$````<]T```0```!XW0``!````'W=```$````@MT```0```"'W0``
M"````(S=```$````E=T```@```":W0``"````*/=```0````K-T```0```"]
MW0``"P```,+=```$````SMT```@```#3W0``!````-S=```&````X=T```0`
M``#HW0``#````.W=```3````^MT``!<````.W@``$P```";>```1````.MX`
M``0```!,W@``!````%'>```,````5MX```0```!CW@``$0```&C>```&````
M>MX```\```"!W@``!````)'>```*````EMX```@```"AW@``!@```*K>```(
M````L=X```0```"ZW@``!@```+_>```:````QMX``!\```#AW@``%P````'?
M```<````&=\``!L````VWP``(````%+?```*````<]\``!````!^WP``&P``
M`(_?```;````J]\``!\```#'WP``'````.??```=````!.```!H````BX```
M$P```#W@```3````4>```!D```!EX```!@```'_@```O````AN```#$```"V
MX````@```.C@```6````Z^````@````"X0``!@````OA```.````$N$```0`
M```AX0``!@```";A```&````+>$```P````TX0``"````$'A```&````2N$`
M``8```!1X0``!````%CA```&````7>$```@```!DX0``!````&WA```"````
M<N$```H```!UX0``!@```(#A```$````A^$```8```",X0``!````)/A```C
M````F.$``!,```"\X0``)@```-#A```.````]^$```0````&X@``"0````OB
M```(````%>(```0````>X@``"````"/B```0````+.(``!0````]X@``!```
M`%+B```(````5^(```@```!@X@``"@```&GB```-````=.(```P```""X@``
M#````(_B```,````G.(``!8```"IX@``#````,#B```(````S>(```@```#6
MX@``!````-_B```0````Y.(```8```#UX@``#@```/SB```&````"^,```0`
M```2XP``'0```!?C```(````->,```4````^XP``!@```$3C```-````2^,`
M``0```!9XP``!````%[C```$````8^,```H```!HXP``#````'/C```3````
M@.,```0```"4XP``"````)GC```$````HN,```0```"GXP``!@```*SC```$
M````L^,```0```"XXP``"````+WC```5````QN,``"8```#<XP``$0````/D
M```1````%>0``!8````GY```!````#[D```$````0^0```8```!(Y```*P``
M`$_D```6````>^0``"D```"2Y```+P```+SD```$````[.0```P```#QY```
M!@```/[D```$````!>4```H````*Y0``"````!7E```(````'N4```0````G
MY0``"````"SE```(````->4```P````^Y0``&@```$OE```(````9N4```8`
M``!OY0``%````';E```$````B^4```0```"0Y0``!````)7E```(````FN4`
M`"4```"CY0``"````,GE```,````TN4```T```#?Y0``"@```.WE```$````
M^.4```H```#]Y0``*`````CF```$````,>8```@````VY@``!@```#_F```G
M````1N8```@```!NY@``#````'?F```7````A.8```0```"<Y@``"````*'F
M```2````JN8```0```"]Y@``$@```,+F```+````U>8```@```#AY@``"```
M`.KF```$````\^8``!L```#XY@``#P```!3G```/````).<``!8````TYP``
M#@```$OG```$````6N<```H```!?YP``"@```&KG```$````=><```8```!Z
MYP``"@```('G```.````C.<```H```";YP``%````*;G```2````N^<``!(`
M``#.YP``!@```.'G```(````Z.<``!````#QYP``"@````+H```*````#>@`
M``<````8Z```"````"#H```Z````*>@```\```!DZ```!````'3H```(````
M>>@```@```""Z```#````(OH```6````F.@``!(```"OZ```#@```,+H```4
M````T>@``!$```#FZ```0P```/CH```-````/.D``!$```!*Z0``#0```%SI
M```1````:ND``!<```!\Z0``$````)3I```-````I>D```P```"SZ0``$@``
M`,#I```(````T^D```0```#<Z0``+````.'I```$````#NH```\````3Z@``
M!````"/J```A````*.H``",```!*Z@``.@```&[J```<````J>H``!,```#&
MZ@``!````-KJ```(````W^H``"$```#HZ@``!`````KK```@````#^L```H`
M```PZP``$P```#OK```$````3^L``!<```!4ZP``!````&SK```$````<>L`
M``@```!VZP``$@```'_K```$````DNL```@```"7ZP``$P```*#K```5````
MM.L```H```#*ZP``'````-7K```2````\NL```H````%[```#````!#L```(
M````'>P``!,````F[```$0```#KL```L````3.P```8```!Y[```#@```(#L
M```(````C^P```P```"8[```%````*7L```$````NNP```@```"_[````@``
M`,CL```$````R^P```@```#0[```!````-GL```&````WNP```@```#E[```
M!@```.[L```$````]>P```0```#Z[```!````/_L```$````!.T```T````)
M[0``#````!?M```$````).T```0````I[0``!````"[M```$````,^T```D`
M```X[0``!@```$+M```$````2>T```8```!.[0``!````%7M```$````6NT`
M`!$```!?[0``!````''M```6````=NT``!0```"-[0``#0```*+M```2````
ML.T``!T```##[0``$````.'M```$````\NT```0```#W[0``%0```/SM```G
M````$NX```4````Z[@``"````$#N```(````2>X``!(```!2[@``!````&7N
M```&````:NX```@```!Q[@``!````'KN```&````?^X```8```"&[@``#@``
M`(WN```/````G.X``!$```"L[@``&````+[N```<````U^X``!8```#T[@``
M*`````OO```;````-.\``!T```!0[P``'0```&[O```1````C.\``!D```">
M[P``,@```+CO```O````Z^\``#$````;\```+P```$WP```7````??```!<`
M``"5\```%@```*WP```3````Q/```!\```#8\```$P```/CP```9````#/$`
M`!$````F\0``0@```#CQ```D````>_$``#D```"@\0``+P```-KQ```7````
M"O(``!L````B\@``.````#[R```E````=_(``!X```"=\@``'@```+SR```;
M````V_(``!$```#W\@``&0````GS```;````(_,``!L````_\P``)````%OS
M```/````@/,``#T```"0\P``$P```,[S```(````XO,``!,```#K\P``+0``
M`/_S```7````+?0```\```!%]```)````%7T```$````>O0```@```!_]```
M"````(CT```(````D?0```L```":]```!````*;T```&````J_0``$\```"R
M]```!`````+U```-````!_4```0````5]0``"@```!KU```$````)?4```0`
M```J]0``$````"_U```&````0/4```8```!']0``!@```$[U```&````5?4`
M`!4```!<]0``"@```'+U```2````??4```8```"0]0``#@```)?U```,````
MIO4```0```"S]0``!0```+CU```&````OO4```8```#%]0``$@```,SU```=
M````W_4``!X```#]]0``'P```!SV```.````//8``!8```!+]@``$@```&+V
M```2````=?8``!<```"(]@``$@```*#V```2````L_8``!$```#&]@``&@``
M`-CV```1````\_8``!(````%]P``%@```!CW```7````+_<``!(```!']P``
M%0```%KW```3````</<``!````"$]P``%P```)7W```2````K?<``!<```#`
M]P``$@```-CW```2````Z_<``!$```#^]P``%@```!#X```8````)_@``!8`
M``!`^```'@```%?X```?````=O@``!@```"6^```$@```*_X```7````PO@`
M`!8```#:^```!@```/'X```(````^/@```0````!^0``'@````;Y```;````
M)?D```8```!!^0``#@```$CY```0````5_D```0```!H^0``!````&WY```D
M````<OD```0```"7^0``!@```)SY```3````H_D```X```"W^0``!````,;Y
M```'````R_D```@```#3^0``#P```-SY```$````[/D``"4```#Q^0``!@``
M`!?Z```=````'OH```@````\^@``"````$7Z```(````3OH``!L```!7^@``
M!@```'/Z```'````>OH```8```""^@``#0```(GZ```,````E_H``!$```"D
M^@``!````+;Z```2````N_H```8```#.^@``&````-7Z```"````[OH```@`
M``#Q^@``!````/KZ```(````__H``"0````(^P``!````"W[```(````,OL`
M``0````[^P``#P```$#[```'````4/L```P```!8^P``"@```&7[```.````
M</L```P```!_^P``!@```(S[```(````D_L``!T```"<^P``!````+K[```;
M````O_L``!````#;^P``!````.S[```&````\?L```@```#X^P``!`````'\
M```$````!OP```0````+_```!````!#\```)````%?P```@````?_```$0``
M`"C\```2````.OP```@```!-_```(P```%;\```/````>OP```T```"*_```
M"````)C\```%````H?P```8```"G_```"@```*[\```*````N?P```T```#$
M_````@```-+\```"````U?P```P```#8_```!````.7\```$````ZOP```L`
M``#O_```/0```/O\```A````.?T``"4```!;_0``"P```(']```7````C?T`
M`#\```"E_0``(0```.7]```<````!_X``!4````D_@``$P```#K^```3````
M3OX``!,```!B_@``$P```';^```>````BOX``!````"I_@``"````+K^``!1
M````P_X```@````5_P``*P```![_``!1````2O\``!L```"<_P``$P```+C_
M```/````S/\```\```#<_P``"````.S_```&````]?\```8```#\_P``"```
M``,``0`*````#``!`!0````7``$`!````"P``0`3````,0`!``,```!%``$`
M!````$D``0`$````3@`!``D```!3``$`"0```%T``0`:````9P`!``8```""
M``$`"````(D``0`%````D@`!``4```"8``$`$````)X``0`!````:0```!8"
M``#:`P``O0,``$D$```T````90$``)(!````````^P$``#4!``!T`P``L`$`
M``````":`````````````````````````&`$`````````````,$"``"^`P``
M90(``(8#``!C`P``6````'T"````````W````)D#``"Z`0``-`(``'X$````
M``````````````#5````#0````<```!A````20``````````````LP(``-0!
M``"=`0``:P,``"($```:``````````````!4`@```````&,```"K`@``````
M``,```""`0```````.````!?`````0(``*,"```Z`P``L````.X"`````0``
MP`,````````Q!```OP(``-P!```7`@``(`(``#<"````````:@```!L#````
M`````````'0`````````+00``(H````^`0``+@$``!8```"R`@``;@```$X#
M``"-`P``I0$``*,````H`@``D@,``"$$````````OP$``!@!``!0`P``$`0`
M``P"``",`0``VP,``)8"``"Y````000``+8!``!7`P``?00``,D#```6`0``
M4`(``$4$````````80,``/H"````````-@````````"_````Y````.H"``#I
M`P``D0```'$#````````_0```&$$```M`0``(P$``/X"````````````````
M``!+``````````````#F````1@(```````"B`0`````````````,````%@,`
M`'0!``!:````;@0``$X```!B`P```````/D#``!?`0``M0,``,L#``"`````
M``````````#M`@``]`(``/P!````````#P$````````)````Z0(``#X$``"Z
M`@``B`,``!,```!3`0``1P0`````````````%`0``,H#````````4P0```X#
M```P`P``=`0```("``"7`@```````',"````````H`,``!,"``#O`P``1@0`
M``0!``!:`P``:````),"```1!```1P```)\#``#7````60(``(<"``"1`0``
M1@,``.8#````````M@(```````!4````;P`````````#`P``U@(```````"=
M``````````````#B````=0````````#G`P``]P(``!T#```+!```-@,``&P`
M``!K`@``\0``````````````N@,`````````````ZP,```````#4````@`0`
M`,`"````````7`(``/@#```%````H0,``,T#``!N`@``Q@$``)D!``"M`0``
MV`$``&H$```7````J@$```````!9`0```````$````#?`@```````&4#``"A
M`@``'0```%8$``!Y````O0$``-8!``!)`0``R`,``!X#````````FP```+X"
M``"``0``#@(``)`"``!5!```\P`````````U`P``L0```)L#````````````
M``````!5`@``TP(``.P!````````0P```&T!``!$`P``)P```%,`````````
M`````'D!``#'`0```````!\!````````,@,``"H"```H````F`(`````````
M`````````!D$``#-`0```````#D"``"M````*0(``$P$``!9`P``3@0``/,!
M````````9@0``*@"`````````@$``#(!````````2````$<!````````WP``
M`)L"```O`P``^@,``"``````````.@(``!0`````````````````````````
MG`(```````"L`P``]`,````````1`0```````'D#``!9!````````&P#``!]
M`P``-@(``$@!``#P`0``T0```#P!`````````````'0"``#9`@``T@```)0!
M```7`0``W@```+`"``!O`0``X@,``)$"````````@P,``*4```!"`0``8@``
M`,4!``#`````'@0``"P!``!!`@``YP$```````"R`0``Z`,``)`!```L````
M#@```#D#```@`0``:0(``'L#``!/`P``>`,```````"A````CP$``%4```#$
M`@``:0$``,<`````````````````````````E@,``"4$````````!@```*8"
M````````0`(``.<"```;!```3P```'P#````````)P$`````````````4@0`
M`-<"````````9````!4```!;!``````````````%`P```````($`````````
M]P$````````P!```O`,```````"T`0``LP,``/@`````````#`0```<$```<
M`0```````$H!```K`@````````D#``````````````````!X!```(`0`````
M``#1`0``S@(``%P$`````````````"\"``!/`0``X`$``-D!``"-`0``<P``
M`-0"``"E`P``K`$```,$```%!```W@,``&T$`````````````$@$````````
M`````'P"```>````\0(``/(#``"4`P`````````````;````2P$``$L#``#*
M`@`````````````P`0``=P(``.P#``!R`@``%`(``*D```"^`0``````````
M``"Q`@``>@0```````!I!```(`,``'L$``"I`P````````L"``!P`@``&0``
M`'<!```````````````````&`@``"````)4"````````.0$```T"``#-`@``
M``````````#S`@``9`,``)H#``"F````?@$``"$"``!"`P``+0```&(!````
M````40(``&("````````[````````````````````#($``"#`0``*`0``!0!
M``!V!```7`,``'4!``"Y`@``)P(``%(#``"I`0``K@(``-@"```U!```Q`$`
M`-P"````````I````(D```"K````K0(```L!``#;`@````````````!"````
M_````%,#``!S`P```````&L```"X````70$``*0#````````U0,``#\#````
M````1@```+P!```1````"P```"H!``!,````J`$``*\#``"R````5`,``,\"
M`````````````#,"````````X0(```````!U`@``'@$``/8#````````````
M`$$```!$`0``?@````````!:`@``70```%$#````````W0$``*H```#]`0``
M#P```'$```#"`P``LP````````#N`0```````+D!``"6````'00```````!Q
M`0``?@,``#<!``"S`0```````/4#````````BP```%0!`````````````+L`
M```W````4`$`````````````L0,```````"0`P``30```&<#``#O`0``F0(`
M`````````````````#H$```<!```W0(``,@!``!F`@``=@(````````9`@``
M+`(``)(`````````I`$``#L#``#R`@``$`$```````#H`0``A@$``"("```:
M`0``M0$``.T#`````````````+(#````````;0```!D#``#%`````````,L"
M````````]@(```H"``!N`P``5@```&<$``"^`````````*\!``#N`P``=00`
M`````````````````*`````L`P```````,,!``#.`0```````#\````"````
M_@,``&8#````````WP$```````"*`0``>00``+0#```P````A`(`````````
M`````00```````!!`0````````````!]`````````*P"``!:`0``"00`````
M``"A`0``PP(``!@$````````V0```&4```!:!```?P(```````!;`@``/00`
M`/\!```7!```C@```((```"F`P``XP(``!P"```F````YP```&8```#5`@``
MF`,````````K`P```````-````#=`````````$`$``#C`P``R@````````!R
M`````````+T```#_`@``B0,``&,$``!2````<@0``%$!``!<`0```````!(`
M``")`@``P0```*`"``#]`P``/P$``*`!```>`@``S@````````!B!```/0``
M``````!\`0``+`0``+$!``!G````RP```'`!`````````````/(!````````
M_P```+H````O`0``W@$``(,```";`0``"@$``)<```"T````+0(``%0$````
M`````````&\#``#Y`@``!`0``#D```!_`````````)8!``#:``````````,!
M``""`P```````'`#``"E`@``2@0`````````````#@0``#@"````````7P,`
M`/`#````````````````````````#@$````````S`0``]@```,(`````````
M`````#(```#[`P``G@```%@"````````,0,``-$"``"!`P``]````'X"``"G
M`@```````/L"````````!0$```````##`````````+L#``!R`0``G@$``&P!
M```8`P``E`(```L#````````]P,```````!8`0``+P0```````"/`@``Q@``
M`+L"``!1`````````',!``!]`0``O`(``"0#````````70(```````#\`@``
M`````&H#```(!````````#H!``!.`@``S`,``"X"```/`P```````!,$``!)
M`@``+0,```@"```X!```3P(``-<!``#,`0``!`,``(8"``!E!```6P$``,,#
M``"W`P``%0(```````!L!```!0(``%T$``!+`@``_0(``&@#``#-````(@$`
M`)<#````````O````!<#````````S@,``&````#*`0``)`$``"4#``#X`0``
M>@```,$#``"'````T`,``)P!``!'`@``MP$``*(````````````````#```&
M`P```````````````````````#L"``!0````C`,``$L$```"!```Y0```*8!
M````!```T`(```\"``!2`@````````````#:`@``>```````````````)0``
M``````!-`@``````````````````*00`````````````AP$``"H#````````
M:`$``%L#``!?!```,P````````!6`P``I`(````````U````M@,```D"``#H
M`@````````````"J`@``2@,``'\$``!"`@``#0,``$($``"K`0``B0$``#D$
M``#A`````````#X"``#N````:P$``!\$````````,0$``%T#``#8````5P``
M`),!``#J`0``+@0```````"C`0``'P(``+8```````````````0```!5`P``
M`````.T```"<`P```````)\`````````ZP```!P```#%`@```````%$$``"L
M````Y0,``#$`````````]0$``!,#``#,`@``10,``%<"````````!P$``*L#
M```F`0``7P(``'8!``":`@``&0$``-T#````````'0$``!(#``".`@``U@,`
M````````````KP(``!L"``#@`@``)`(``+D#``#'`@``A`$``&,"```E`0``
MG``````````D!```XP```,8"``!#`0``9`(```````"$`````````#8!``"U
M````CP,``&`"``!_`0```````#0!````````Y0$``!("``!7!````````'H"
M`````````````(\`````````TP,``"<#````````A0$```````!Q`@``B```
M``````!>`@```````#<#````````;0(``*X```````````````D!```_`@``
MZ`````````!>!```A0,``"$!```!`0``1`(``"(#`````````````",#``"3
M````\````&0$``!H!````````'H#``!K!````````,D````X````````````
M``!A`0``=P,``#0#``!$````50$``(`"```U`@```````(4"``"?`0``ZP(`
M``````!,`P``=P0``'8#``":`0````````8$````````````````````````
M&`````````"&````Z0`````````(`P``]P````````!,`0``Q`````````#Y
M`0``J0(``*("``!>````NP$``'D"```'`P``R`(```````#5`0``0`,``$\$
M``#D`@``]`$````````I`0``)@0``-0#```S!```@P(``-H!``"!`0``SP,`
M`"$#````````Z0$``,0#``#6````(P````8!``!M`P``/0$```````!_`P``
MKP```&P"``!8!```_@```'8````:!```E0$``"@!``"T`@```````/H`````
M````R0(``#\$```H`P``IP````````!-`P``1@$``#P"``#2`0```````"L$
M````````RP$````````W!````0,``%,"``#)`0``]0```*(#``#M`0``F```
M``````!2`0``'0(``.4"````````:@$``#L!``#3`0``;P0``(P```"5`P``
M```````````\`P``*P````````#_`P```````'L!``".`P````````````"+
M`@```````(@!```:`@``D@(``!4#``#C`0``O0(``"4"``!#`@```````"D`
M``#>`@``K@,``,\````:`P``[P````````#2`P``$0,``#`"``"W````````
M``````"%````\P,``#@#``"M`P``20,``$@#``#'`P``(@```.0!````````
M:`(`````````````Z@```+`#``#"`@``J````+4"``"-`@``@@(``-@#``"+
M`P``>P```/P#``"G`0``$````!`"``#P`@``TP```/H!``#^`0``N`,``.L!
M```4`P``&`(```````!``0``%00```````````````````@!````````<```
M`#X#```,`P```````#P`````````K@$``!P#```R`@```````)<!```?`P``
M+P```)@!``!<````D0,````````/!```0P0```````!.`0``G@(``%X!````
M`````````$@"```Q`@``!`(``/D```!G`@``]@$``'@"````````#`$`````
M``"W`@``10(``%L````S`P```````$T!``#?`P``>@$``',$````````````
M`-`!````````SP$``"H```!G`0``=0,```````!,`@``"@,``(L!``#F`0``
M@0(``$0$```D````9`$``'L"``#1`P``$@0``#H```!A`@```````/$!```A
M`````````&`!``#A`0``R````,8#``"3`P```````"X````\!```T@(``!,!
M``"X`@```````'P```"$`P``.P0````````*```````````````C`@``G0(`
M`(X!````````;P(``(`#``!%`0``"@0``%8"``"(`@``#00````````K`0``
MX@(````````]`P```````"D#```5`0``E````-L```#7`P``Y`,``/(````1
M`@```````*@#```'`@``)@(``````````````````"<$``",`@```````$$#
M```#`@``S````&D#``"X`0````````T!``````````````````!'`P``G0,`
M`.`#``!*````GP(`````````````-@0``#X```"*`@```````'$$``"G`P``
M`````!8$``#U`@```````+\#```]`@````(```````!6`0``;@$``/L```"5
M`````````.P"```T!```VP$````````C!```&P$``%`$``!X`0``Q0,`````
M``!%````<`0``,(!```N`P``*@0``"8#``"9````8`,```````!J`@``9@$`
M`$T$``"C`P``Y@(``(H#``!W````$`,``(T```#Q`P``<@,``/@"````````
M?`0``*H#````````60```.$#``#!`0```````#@!`````````@,``.\"````
M````AP,``-D#``!>`P``5P$``)X#```2`0``.P````````#J`P```````$H"
M``!8`P``D````,`!````````W`,``!\`````````X@$``$,#``!C`0```"`H
M)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@*'EE<W1E
M<F1A>2D`(&%T(``E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN
M9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E
M<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5Q=6ER960`
M)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S.B`E
M<P`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM
M('-E;&5C="`M+0`R-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q
M=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O
M<@!!8F]U="XN+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O
M<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@
M9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H
M:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE
M=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@;F5W(&UE;6)E<G,`
M061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!
M9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@
M;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L
M8F%N:6$`06QG97)I80!!;&EA<P!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!
M;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT
M97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`
M06QT97)N871E('1E;7!L871E<P!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA
M`$%N;VYY;6]U<R!0<F]X>0!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U
M9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ
M,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(#\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`
M07)U8F$`07-C96YD:6YG`$%S8V5N<VEO;B!)<VQA;F0`07-I82]086-I9FEC
M(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T
M<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5
M;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE
M8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"
M86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME
M<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M
M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"96QA<G5S`$)E;&=I=6T`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K(%-E
M='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W-N
M:6$@86YD($AE<GIE9V]V:6YA`$)O='-W86YA`$)O=79E="!)<VQA;F0`0G)A
M>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R
M=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0V%L96YD
M87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E
M<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N`$-A<&4@5F5R9&4`0V%T96=O<GD`0V%Y;6%N($ES;&%N9',`0V5L
M;"!0:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF
M:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H:6QE
M`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U
M<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H<FES=&UA
M<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L
M96%R($9O<FT`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-L;W5D
M<P!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQO;6)I80!#;VQO<@!#;VQO
M<B!0:6-K97(`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT
M`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VYD:71I;VYS`$-O;F9I
M9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M
M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960Z(`!#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!#;V]K($ES;&%N9',`0V]P>2!S96QE8W1I;VX`0V]S=&$@4FEC80!#;W1E
M(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R
M>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D("5S+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!S97)V
M97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD
M;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S
M:61E8F%R(&ES(&]P96XN`$-O=6YT<GD`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(%1I;64`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N
M9&ET:6]N.B``0W5R<F5N="!S='EL90!#=70@<V5L96-T:6]N`$-Y<')U<P!#
M>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I
M;'D`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$96-E
M;6)E<@!$96-R96%S92!);F1E;G0`1&5F875L="!)9&5N=&ET>0!$969A=6QT
M('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ
M`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C96YD:6YG
M`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L
M<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O
M:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`
M1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I
M;VYS`$1I<W!L87D@9F]R;6%T`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W
M;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`12U-86EL`$52
M4@!%8W5A9&]R`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I
M;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%
M9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9WEP
M=`!%;"!386QV861O<@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E
M<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T
M:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;F0@>65A<@!%
M;FQA<F=E($5D:71O<@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R
M`$5S=&]N:6$`171H:6]P:6$`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E
M<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E
M<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE
M8W5T90!%>'!A;F0`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$944"!U<&QO
M860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N
M;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N
M`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%L
M:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9I:FD`1FEL92!#;W5N
M=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`
M1FEL92!.86UE`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R
M`$9I>"!R871I;P!&;&EP`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT
M($-O;&]R`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R=6US`$9O<G=A
M<F1S`$9R`$9R86YC90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`
M1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L
M;"!.86UE`$=A8F]N`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!'
M;P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX
M.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N
M`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(
M5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O
M<FET:&T`2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<P!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5L<`!(96QP('5S:6YG(&5D:71O
M<@!(96QP97(`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S
M<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)I>F]N
M=&%L(%)U;&4`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_
M`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N
M<R!W:71H('1E>'0`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@
M)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-R96%S92!);F1E;G0`26YD:6$`
M26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!)
M;G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4`26YS97)T(&UE<W-A9V5S`$EN<V5R="]-;V1I9GD@26UA9V4`
M26YS97)T+TUO9&EF>2!,:6YK`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I
M;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!S
M;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$ER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES
M<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A
M;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*
M=6YE`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`
M2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA
M`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y
M($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E
M`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+
M4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T
M(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA>6]U=`!,96)A;F]N`$QE
M<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N
M<W1E:6X`3&EN:P!,:6YK<P!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD
M97(`3&ES="!(96QP(%1O<&EC<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI
M<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES
M="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE
M`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN(&9A:6QE9"!B
M96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@
M:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3'5X96UB;W5R9P!-30!-3U1$
M`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA
M8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O
M9@!-861A9V%S8V%R`$UA:6P`36%I;"!!9&UI;@!-86QA=VD`36%L87ES:6$`
M36%L9&EV97,`36%L:0!-86QT80!-87)C:`!-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H
M:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E
M`$UE;6)E<G,`365M;R!497AT`$UE;G4@;6]D93H`365S<V%G90!-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D
M+@!-97-S86=E('1Y<&4`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=')I8P!-97AI
M8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:6UE(%1Y<&4`
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@`$UI<G)O<@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG('-E<W-I;VX@
M240N`$UO`$UO8FEL92!-86EL`$UO9&EF:65D($1A=&4`36]D:69Y:6YG("5S
M`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA
M`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E
M<P!-;W)O8V-O`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E
M(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&EP;&4@<V5L
M96-T:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`
M37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U
M`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C
M87!E($)A<V4@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!-;V]N`$YE=R!5
M<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B
M;&%N:RD`3F5W<P!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI9V5R
M:6$`3FEG:'0`3FEU90!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`
M3F\@9FEL92!U<&QO861E9`!.;R!L;V-A=&EO;B!I<R!S970N`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I
M;VXN`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;F4`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R
M9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I
M86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A
M(&1I<F5C=&]R>0!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W9E;6)E<@!.=6UB
M97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M
M8F5R(&]F(')O=W,`3TL`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/
M9F9I8V4`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+@!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@
M=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@
M;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P
M96X@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D
M97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@3W!T:6]N
M<P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T
M960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$
M871A`%!(4"!#;V1E`%!(4"!3:&5L;`!086MI<W1A;@!086QA=0!086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I
M;F5A`%!A<F%G=6%Y`%!A<W-W;W)D`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H
M+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG
M;G5P<SH`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!0
M97)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO
M;@!097)U`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!V
M86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO
M;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!O;&%N9`!0;VQL<P!0;W)T=6=A
M;`!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``
M4')E=FEE=P!0<F5V:6]U<R!O<'1I;VYS`%!R:79A=&4@2V5Y`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0
M=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!2
M4T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%T:6\`
M4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N`%)E9G)E<V@@3&ES=`!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!2
M96UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B``4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)O;&4`
M4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2
M=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A
M<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN
M9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4V$`4V%I;G0@2&5L96YA`%-A:6YT
M($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD
M($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A
M;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N
M9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A
M=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V5A<F-H`%-E
M87)C:"!297-U;'1S`%-E87)C:"!38V]P90!396QE8W0@82!D871E`%-E;&5C
M="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@
M<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M
M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L
M96T@4F5P;W)T`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A
M;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E
M9"X`4V5T`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L
M;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!L87-T(&QO
M9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('!I8VME<@!3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/P!3:')I;FL`4VEE<G)A($QE;VYE`%-I
M9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E
M`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W
M(&1E<'1H.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]R="!B>2!#871E
M9V]R>0!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T
M:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N
M($AE;6ES<&AE<F4`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V
M:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R
M:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=0!3=6)J96-T`%-U8FUI=`!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M
M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;G)I<V4`4W5N<FES92]3=6YS970`
M4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T
M`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z
M:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y<FEA;B!!<F%B(%)E<'5B;&EC
M`%135B!F:6QE`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A
M:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z
M`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``
M5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A
M=&EO;@!497AT`%1E>'0@3VYL>0!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N
M9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!-86EN=&5N86YC93HZ(&-L
M87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@
M8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S
M+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O
M=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H
M92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@
M=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O
M=R!D;V5S(&YO="!E>&ES="X`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A
M9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@
M<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A
M9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I
M96QD+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI
M9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N
M)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M
M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N
M($]P=&EO;G,@=VEN9&]W`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4;P!4;R!S96QE
M8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I
M(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4
M;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A
M`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA
M`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R
M:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E
M.B``52Y6+B!I;F1E>#H@`%523`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L
M92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R
M82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O
M(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S
M('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YS=7!P;W)T960@
M17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!G<F%D
M92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A
M=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<G5G=6%Y`%5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T
M:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R
M;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M
M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A
M8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I
M='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A;G5A='4`
M5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N
M`%9E<G-I;VX@0V]N=')O;`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI
M`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S
M`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N
M`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!3
M3510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&
M;W)E8V%S=`!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T
M;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N
M("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@
M9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C
M=&5R/P!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA
M:&]O(2!M87``665A<FQY`%EE;65N`%EE<RP@22!!9W)E90!9;W4@87)E(&EN
M(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A
M8VL@=&\@5UE325=91RX`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN
M("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&1E<V-R:6)E
M('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@
M<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C
M=7)R96YT('1I;64@>F]N93H`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S
M70!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`:6UM961I871E
M`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FYA;65D`'5S97(@
M<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO
M;CH@36YE;6\@,BXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q
M-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#4M,S`@,38Z,S0K
M,#@P,`I,87-T+51R86YS;&%T;W(Z(%!E=&5R(%=A;F<@/'=H=T!O=6QI;FLN
M;F5T/@I,86YG=6%G92U496%M.B!3:6UP;&EF:65D($-H:6YE<V4@/'=H=T!O
M=6QI;FLN;F5T/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]1T(R,S$R"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#@M8FET"@`@*"5S(,SLQ[`I`"`HO^R]W;S\("5S*0`@*+WQS.PI
M`"`HU_+,["D`T]H`U^Z]_"`E9"#,[,;XS_/4I+&H`"5S("T@L;C-_,*\`"5S
M(-:XSL8`)7,@2T(`)7,@SJR[I++9U_<@+2#(M\C/`"5S(->BLN$`)7,@S:S2
MXL_NQ+\`)7,@TM&TYM3:`"5S(-3:("5S("5S`+'8T.C2JB`E<P`E<R"WU@#5
MTK*[M;T@)7,N`"`E<R"UO2`E<R"YLB`E<P`E<SH@)7,`+"#5\[?G("5S("5S
M`"RQY+NOP;^TTR`E<R"UO2`E<P`M+2#1H=3Q("TM`#(T(-"ARK'6Q@"TR\?X
MO^FQV-#KTJK6N+:HROV^W;_BM_[.\;;++@"WHLGZP<O2N[CVT<_6V+7$M.W.
M\P#3^[S3P]S3RKS^++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<U+\N`-/[T>G6
MI-+1QZG#^[7$T\J\_BR[N=#HTJK3T-*[N/8@4$=0(+FKOZK#W-2_+@#3^[WB
MP]S3RKS^++NYT.C2JM/0TKNX]KFKOZH@4$=0(,/<U+\LR[W#W"!01U`@P]S4
MORS2U+RPO]K![BX`T_O6M-#0T\J\_L>IP_LLN[G0Z-*JT]#2N[CVN:N_JB!0
M1U`@P]S4ORS+O</<(%!'4"##W-2_+-+4O+"_VL'N+@#3^[WBP]S3RKS^++NY
MT.C2JM/0TKNX]KFKOZH@4TU)344@P]S4ORS+O</<(%--24U%(,/<U+\LTM2\
ML+_:P>XN`-/[UK30T-/*O/['J</[++NYT.C2JM/0TKNX]KFKOZH@4R]-24U%
M(,/<U+\LR[W#W"!3+TU)344@P]S4ORS2U+RPO]K![BX`T_N\T\/<T\J\_BR[
MN=#HTJK3T-*[N/8@4TU)344@N:N_JL/<U+\N`$%-+U!-`$%022"QX+K%`+G8
MT]K5XKCVL>"\K<;W`+G8T]HN+BX`R*C/WK*[U^,LSMZWJ+VHP:(@5D93(,2_
MPKPN`,BHS]ZRN]?C+,[>MZB]J,&B(%9&4R#.Q+S^+@#5R[K%TM&VL[WA+@"]
MX=7*`-#"U/8`T,+4]L_"O+;7Z0#0PM3VS\*\MLBHS]X`U-JTR]#"U/:CN@#0
MPM3VT\.[I]?I`-#"U/;(J,_>`-#"U/;2N[CVT\.[ISH`T,+4]M*[N/:SR=2Q
M.@#0PM3VMM0`T,+4]B`E<R#.JB!-;WII;&QA(%-I9&5B87(@LLNUI0#0PM3V
MT\.[IP#0PM3VT\.[I[7$N:;$W+6QQ["QN[G8L=4N`+78UK<`S:C1MK*^`+/)
MSJJYW,#MU+$@+2#.JL;DR_S3P[NGQ>36P\BHS]X`N=S`[0"YX[CFN=S`[0"P
MHKB[NKD`L**V^[#-Q.'1QP"PHK;[O+#`^]''`+'PP_L`R_G3T-+1T>G6I+7$
MT\.[IP#+^=/0T\.[I]?I`,OYT]#(J,_>`-3*T.VVX+CVM>?7T]/*O/ZUV-:W
M`-+1M.;4V@"QY+C\($E-4U`@M<?"O`"QY+C\($E-4U`@P]S"ZP"QY+C\($E-
M4U`@T\.[IP"QY+C\Q*.PY@##P,KTR/C$IM''`-*[N/:RN[K/MZBUQ-:UL;O*
MN=/#+@"PLK7`MOL`L+*XY\"M`+"RN>?`K0#$Y,/[M/K`[0#$S[RKUMX`L++,
MX;G/O+"PS;;[LKRT[P#3IM/#L\S0\@#3IM/#L\S0\M+1OLW0]P#3IM/#M;W+
M^=/0S\*\MKFRS^T`Q?K7O`#+Q-3"`+"BP*VRKL[$("A7:6YD;W=S+3$R-38I
M`-&YR_7.Q+S^M//0H0#1N<OUSL2\_L/[L\8`Q/K(M[:HTJK)OK/]("5S(+7$
MUZ*RX<+P(#\`L**X^<VB`-''P\#$X=''`-''P\#$X=''SL0@*$%235-#24DM
M."D`L*+"L[#-`,G]T/(`L*+)K<O)R+JUN@#1Q];>+\RKQKW1\[78Q_@`UK30
MT,ZLNZ2RV=?WQ[#/U,J^R+?(S[;4N["_\C\`RM3-O,F^L_W2N[CVLKNTYM3:
MM<33P[NGU^DN`,K4S;S)OK/]TKNX]K*[M.;4VK7$R*C/WBX`RM3-O+'@O*W2
MN[CVLKNTYM3:M<33P[NGU^DN`,K4S;RQX+RMTKNX]K*[M.;4VK7$N;+/[2X`
MRO30U`"PR]3"`+#$M//`^]''`+#"M=C`^P!!=71H7V-R>7-Q;#H@U=*RN[6]
MR_G0Z-*JM<0@:6UA<"#`J=6YU^F\_BX`075T:%]C>7)U<SH@M_[.\;;+LJ+.
MM,SAN:FXP\_NUJ>SUBX`075T:%]C<GEU<SH@U=*RN[6]R_G0Z-*JM<0@:6UA
M<"#`J=6YU^F\_BX`075T:%]F='`Z(-72LKNUO<OYT.C2JK7$($944"#`J=6Y
MU^F\_B['Z];8T,*QX-+K(%!(4""RHL?2O-/(ZR`M+65N86)L92UF='`@T:'/
M[BS`_<CG(&-O;F9I9W5R92`M+65N86)L92UF='``075T:%]I;6%P.B#5TK*[
MM;W+^=#HTJJUQ"!)34%0(,"IU;G7Z;S^+@!!=71H7VMR8C4Z(-72LKNUO<OY
MT.C2JK7$(&MR8C4@P*G5N=?IO/XN`$%U=&A?;&1A<#H@U=*RN[6]R_G0Z-*J
MM<0@3$1!4"#`J=6YU^F\_BX`075T:%]L9&%P.B#.WK>HT,+4]M/#NZ<@)7,N
M(+?^SO'&][O8TZ8Z`$%U=&A?;&1A<#H@SMZWJ,F^L_W3P[NG("5S`$%U=&A?
M;&1A<#H@SMZWJ+C\T,+3P[NG("5S`$%U=&A?;6-A;#H@U=*RN[6]R_G0Z-*J
MM<0@34-!3"#`J=6YU^F\_BX`075T:%]S;6)A=71H.B#5TK*[M;W+^=#HTJJU
MQ"!S;6)A=71H(,"IU;G7Z;S^+@#1Z=:DRJ>PW"X`T>G6I,JGL-PN("5S`%)!
M1$E54R#1Z=:DM.W.\RX`1E10(-'IUJ2T[<[S+@"_R=/#M<37UK;..@"PHLC[
ML-V]K@"QL[ZPT=7)JP!K97)B97)O<R##W,+KM.W.\RX`:V5R8F5R;W,@T\.[
MI\/[M.W.\RX`L,VY_L+MR+JUN@"PS<'6`+*HPMZUQ+JCSL0@*$E33RTX.#4Y
M+3$S*0##S[S3P*VY^@"PS;#-MN#+N0"PU[;MPM[+N0"QR,#[RK$`LJ[`^]?(
M`+&TQ/X`L-G$O;3SR+JUN@"RN[6D`,GZR-4`Q_B_Z<7DUL,`Q_B_Z<#@T,T`
MM-;,Y0"RH\#[SJS1QP#*Z<>I`+*HR[G$X=''NLVZVLC[N.?.K,3'`+*IM,3-
MW\3)`+*HSJS,V+6Z`+#-SO<`TZ+*]-.AMLC1\\'LM=@`SL3`LP"QH[S3P/O1
MQP#/[L2_M_NZQ0"RO+RJQ,FWJ,OW`+*\PJ&USP#$VLC=N=S`[<^US;,`0U)#
M`$-23""WUK*\M>,`R-7`^@#!X[RVM^<`O.W&TM6O`+^FPO/"H0#.WK>HP:J[
M^M;!($E-05`@M_[.\<;W.B`E<P"\T\3#M/,`R*'/^P#(H<_[SLK,XK&HN.8`
MSMZWJ,F^L_W.Q+S^("(E<R(N`,[>MZC)OK/]Q+_"O"`B)7,B+@#.WK>HUMC7
MZ:&CR_G,X;FIM<2\Q\*\ROW$O]/KS\C'L,OYL:.TYK7$ROV^W;*[M_LN`,[>
MMZBTJ\O-T,7/HK6]UKBVJ+7$NL7"ZRX`M_"UP[W'`,#@L?``OZK"_,BZM;H`
MTL:VK[7GN[``R/NV^\S8SL0@*$E33RTX.#4Y+3$T*0#6T+?'N;*ZS;GZ`-;0
MQ;<@*$E33RTX.#4Y+3(I`,:^UJ3/N+W:`,:^UJ2RW\+4`-6GM<,`UL?`^P#6
MT+GZ`+SRS.76T,[$("A'0C(S,3(I`+>QS.76T,[$("A":6<U*0#1H=3QP]S"
MZP#1H=3QTKNX]M/#NZ?#^P#(U<;:S]3*OK>]RKTZ`,JEM:ZUN@#5TK*[M;T@
M)7,@M<3`X+'PMJC2Y2X`Q^6S_;'MM:4`L+3*\['JO/R\S-#X`+G8L=6TL+_:
M`-3&P;\`O\:_QLNYR+JUN@"XY\+7L<C1QP#1U<FK`+7WR:O%S`"_J,VH`,/\
MP>X`P_S![KW%L;X`QL#"VP#-J-/#P_L`O\;$IL+>`+FKR[X`S/6\_@#%Y-;#
M("5S`,BWR,_#W,+K`+C5N?L`N-6Y^[FRNLVY^@#!K+W3RJ>PW#H@`,&LO=/6
MP;FKOZK#W-2_M_[.\<;WRK'4XK[<OO@N(-2MTO(Z("5S("@E<RD`P:R]T];!
M($944"#.Q+S^M_[.\<;WRJ>PW"X`O^*_R\BZM;H`N+36QM&AU/$`N.?+N;3O
MP.B\TP"_QLS8M<_-WP#.WK>HTM0@4$=0(+S3P]S3RKS^+@#.WK>HSJH@4$=0
M(-:TT-#3RKS^QZG#^RX`SMZWJ-+4(%,O34E-12"\T\/<T\J\_BX`SMZWJ,ZJ
M(%,O34E-12#3RKS^QZG#^RX`SMZWJ+#SMJ@@3$1!4""W_L[QQO<`SMZWJ+WB
MP]P@4$=0(,K]OMTN`,[>MZB]XL/<(%,O34E-12#*_;[=+@#.WK>HOO:VJ,K5
MO/[(R[7$M>?7T]/*O/ZUV-:W+@#.WK>HU]3#W-2_M_[.\<;WR*&UP[FKOZK#
MW-2_+@#.WK>HM/*_JB`E<RX`SMZWJ+3ROZK.K+NDN:37]\2CO^D@)7,`SMZW
MJ+;!R*$@)7,N`,[>MZBVP<BAM.;(H;_8UL:Q[2A!0TPI`,[>MZBVP<BAM_[.
M\<;WM<3/X+G8S-C0U`#.WK>HL:.TYB`E<R"UQ,7DUL,N`,[>MZBRZ=72($Q$
M05`@(+?^SO'&]RX`U=*RN[6]($UO>FEL;&$@4VED96)A<BX@Q^O(M\C/('-I
M9&5B87(@RL>W\;3ROZHN`+GZO-(`O:C!HM?3SL2\_KS0`+VHP:+5W[7$R*C/
MW@#0Q=/#OZBZQ<+K`+_+PMZUV-''`+G%L,T`M;''L,JQO.0`M;''L,SLQO@`
MM;''L->TO_8Z(`"UL<>PM^>X\0"\],?0T:'4\0#(^\;6PK?+N0#.]\#OMOO.
MQ"`H2T])."U2*0#.]\#OMOO.Q"`H5VEN9&]W<RTQ,C4Q*0#.]\#OMOO.Q"_.
MVK_+P+S.Q"`H2T])."U5*0"]W;_+N;*ZS;GZ`,C5`,._R-4`R-7&V@#*U;6]
MR-7&V@#1H=3QR-7&V@"PU\SL`,JNMO[4P@"\]<G9R_7%Q0#$K,C/R>VWW<JV
ML?``R+'*H<7%T/*QZM>\.@#(L<JAQ<70\K>]S_(Z`,F^L_W3P[NGU^D`R;ZS
M_<BHS]X`R;ZS_:&BQ^6_U=/*O/X`M=W+S<JQO.0`M:3"\P"]M=#R`,[*S.+#
MZ,KV`,/HRO8`S[B]VB`HQ^NRSK^\($AO<F1E(+S'PKS.Q+S^*3H`S[B]VL?K
MLLZ_O,^US;.YW,#MM<?"O"X`T="WH@#"MK7CSL*VR`#7[KKSTKO0H<JQM<3"
MMK7CSL*VR#H@`,*VM>/.PK;(.B``M-/7\];!T](`M-/3TM;!U_,`Q+_"O`#2
MU"`R-"#0H<JQUL;/U,J^/P#/U,J^T:'/[@#/U,J^N/'*O0"\JK*\S.$`LKO)
MOK/]`+*[TJK6L;W3M.;(H2!M86EN=&5N86YC92YP:'``M=K2N['*O,?"O,K'
MM_&P_+JLU]:VSL/[L\8_(,CGN?O*Q\?KT:'4\2X`MN##U\3AO-,`MN##U\3A
MO-.YLKK-N?H`S\+4V`#/PM38("5S`,_"U-C)^K/)M<3%Y-;#SL2\_LZJ(%!(
M4""SS-#R+@#/PL"MLLNUI0"UY]?3T\J\_@"T[<[S`+;RN<^VX+;[`+'@O*W'
M^+_I`+'@O*W3P[NGU^D`L>"\K<BHS]X`L>"\K<BHS]X`L>"\K2`E<R"UQ,BH
MS]X`L>"\K=&AS^X`L>"\K2`E<R"UQ,BHS]X`L*.\L`#(^+;[S=^VX`"UY]?3
MT\J\_@"UY]?3T\J\_K78UK<`M>?7T]/*O/ZUV-:WL=C0Z\['NL\N`+7GU]/3
MRKS^R+?(SP"Q[<?IM_NZQ0"_U;#7T,6\_BX`O]6PU[WAN?LN`,3JM=<`M\6T
M\['@O*W&]P"SX+7`O+C$VM''`+;RP:+,V,#OT<<`M.W.\P"PKLFSQ.'1QP"P
MH\C[MNVQR-''`,6WUMX`P[\@,34@M];6TP##OR`S,"##Z];3`,._(#4@M];6
MTP##O[3.M<?"O`##OR`S,""WUM;3`,._(#$@M];6TP"WML#]UK4Z`-:TT-``
MU;F_J@"UO<;:R-4`O>++M=2Q`$944"#)S[2KQ>36PRX`ML'(H<:KNL/%Y-;#
MRJ>PW`#.WK>HP:R]TR!,1$%0(+?^SO'&]RX`SMZWJ,&LO=,@4TU"(+?^SO'&
M]RX`N+36QLJGL-S7U"`B)7,B+@"XM-;&RJ>PW+6]("(E<R(N`,[>MZB]J,&B
MTKNX]M#"M<0@4T%33"#!K+W3+@#2QK:OM;T@(B5S(LJGL-PN`+>HP+R_R[BC
MR+JUNB`HPNVV^\ZLQ,G+N<BZM;HI`+>HPM[(NK6Z`+2KU>8`MO[4P@"XT+[U
MS_'*QP"XT+[US_'*QSH@`.RSO,,`SL2\_LK]Q+\Z("5S(+CVSL2\_@#.Q+S^
MROW$OSH@)7,@SL2\_@#.Q+S^N=S`[<;W`,[$O/[#^[/&`,[$O/[)S[2K`,[$
MO/[)S[2KN:;$W,ZTL;O6I[/6+@"Y_<++QO<`M]+`O`#)S[#KU,(`R<_/TM3"
M`+G,MJBQR,#]`+>MUZH`Q+_"O"`E<R"RN[3FU-H`U];0S='5R:L`U*2QJ,SL
MROT@*-2DL:C,[,K]L/S`J+#7S.S2U+RPTKF\Y+7$ROV^W3O(Y[G[U*2QJ,SL
MROV]S[.DO:O5O-/#L<B]S[_MM_FUQ+#FP^8I`+2PS.4`R^/#_`#+X\/\P.#0
MS0#+X\/\`,+;S+,`U]2VK]>JT,4`T,?&VL[E`+>HN?H`MZC*]+GGT<?$QP"W
MJ,KTLJ/`^\3ASO?1QP"\Q+S^R,L`M-,`S>K5^\/HRO8`POK4P@#(J\/[`+S3
MQ>X`N-2QR-''`++ZR?H@)7,@M<3/M<VSQ>36PP"X\<*SO*K1QP"UPKGZ`.7(
MQ,D`UK&RO,+>S=,`P_L`UZJUO0!';V]G;&4@R]'+]P"[TK;(`,^CP+``SZ/`
ML,[$("A)4T\M.#@U.2TW*0"X\<'JP+P`N/'!UL3)M.\`T\.[I]?IN=S`[0#3
MP[NGU^G#^[/&LKNUP[_5L-<`T\.[I]?I`+G/M<+"WL;5M;H`N=BUN@#.H[78
MPNW`K0"X\;;WSO>UN@"WP[_-R*C/W@"WP[_-P?31U`"\N,3:T<<`O+C$VM''
ML<C)W+FRNLVY^@"YY]''Q,<`2%1-3`#5TK*[M;T@2%144"#1Z=:D+@"ZH[78
M`-33M-4MR^.WJ`"Q[<VW`+K5M<*ZS<+TM;'`S<BZM;H`SZ.RKL"TSL0@*$E3
M3RTX.#4Y+3@M22D`L._6^@"QX+RMQO?*N=/#L._6^@"P[];Z`-7BP._*Q\[$
MO/ZUQ+^JRKPZ`.CSM=FXU`#*U]*S`,K7TK.UV-:W`,K7TK.UY[NP`+KIMKS`
MK<NY`-;0N?K/X[C;`$AO<F1E`,NNQKW/WP#7UK;.ROW$O[FRO,8_`,JJML@`
MRJJVR#H@`-#9T<#`^P!)34%0(-/*S^2]J,&BRJ>PW#H@)7,`24U!4"#3RL_D
MR;ZS_<JGL-PZ("5S`$E-05`@T\K/Y+3%Q<S%Y-;#O:C!HLJGL-PZ("5S`$E0
M(+78UK?.WK>HRKG3PRX`25`@M=C6M[*BLKO4VB!#2412(+7$O=/*W,?XO^G6
MT"X`L?FUN@#6N]/0S;RQZ@#-O+'JO+#.Q-?6`,G/M*O-O,:L`,V\QJP`N^/(
MZRP@LKW6Z"`E9`"[X\CKU]:VSCH@)7,`N^/(Z]?6MLXZ`,KDR.NRN]7]R+>U
MQ-?WT\/"ZRX`U/:\T\OUQ<4`TZ&VR`"X]K'PT\.[IP#3H;;(Q.'.]]''`-#%
MSZ(`T,7/H@"RY<CKL>VX\0"RY<CKS?C"Y\&LO=,`LN7(Z[_)S.:T^L2CL.8`
MLN7(Z]/*O/X`LN7(ZR^QY+C\S;S&K`"RY<CK+['DN/S-^,+GP:R]TP#5^\K]
M`-7[ROW!T`#.WM"GM<0@541(*-/#NZ?*_;[=L>W-MRDN`,[>T*>UQ-.FT\.S
MS-#R+@#.WM"GM<3%^K3.NL7"ZRX`S.&]N[7$ROV^W<[>T*<N`,[>T*>UQ,2_
ML>K7H=:W`+*[NL^WJ+7$SL2\_KCQRKT`SM[0I[7$(&US9U]T>7!E+@#.WM"G
MM<2[\M72LKNUO2!A<&E?:60N`,[>T*>UQ+ORU=*RN[6]LL[*_2X`LKNZS[>H
MM<2XN,BHS]XN`,[>T*>UQ,VHT;;0K=+I+@#.WM"GM<3`M-2TUZ'6MRX`SM[0
MI[7$S?+3P\+KROV^W2X`TL'`RM+!R[G`O+FRNLVY^@#2P<"MO\L`L*ZV^\"\
M`,+\M;H`TM3)J\'0`,>IMZ+5WP#0L<SE`-+BM//`^P#1P,+RO-,`TKO4P@!*
M87!A;B`HR-6QOBD`R-7.Q"`H25-/+3(P,C(M2E`I`-3SSO>UN@#4O+6I`,;?
MU,(`P?G4P@#6P];0`-?ST]*VU,;K`+^_U_.VU,;K`+^_T]*VU,;K`+G^R/B_
MR\NYS+D`L:/!]-2MT?D@/P"_S\3AT<<`2V5R8F5R;W,@R,_6I+3MSO,N`,/<
MU+^]J,&B`,/<U+_,V-7W`,/<U+^SI+;(`,/<U+_`X-#-`,/<U+_3[[>H`+6Q
MQ["UQ+FKOZK#W-2_M_[.\<;WUM`LTM&^K;3FU-K$^K7$P]S4ORX`N_G`[[#-
MR[FYLKK-N?H`LZ_/R@"ZJ[GZ`+JKSL0@*$550RU+4BD`O\;-_LS8`+RJMON\
MJLNYS+D`T^_1U`#`S\[.`,_"L.O4P@#/PL_2U,(`R<^TSKC\T,(Z`,G/TKNT
MSK7'PKPZ("5S`,G/TKNTSK7'PKPZ("5S(-?4("5S`,G/TKNTSK7'PKPZ(+7:
MTKNTSK7'PKP`P*W-T<ZLT<<`L.;#YL7DUL,`P.BPS<3;`,"SR_?-T`#`^['(
MP._1QP#`^['(T<<`P=#6I[;8RK^UQP#!K+W3`,&LO=,`P="S]B`M(-/#NZ>_
MR=+4O[2UO=7BN/;.Q+S^O-``P="S]LNUP_>QZLSB`,S6PMO3P[NGU^DMSL2\
M_KGQ`,S6PMO3P[NGU^DMQ_/6^@#,UL+;T\.[I]?I+<JVL?"ZQ<+K`,S6PMO3
MP[NGU^DMT[73T-7?`,S6PMO3P[NGU^DMO,2\_LC+`,S6PMO3P[NGU^DMMJG4
MQ`#,UL+;T\.[I]?I+<BAS_NVJ=3$`,'0L_;3P[NGM<2YIL3<L;NYV+'5`,[$
MT:<`P:+,U<WP`+6QM=C*L;SD.B``M=C'^-/KRK&\Y`"UV,?X`+7'PKP`UZ+/
M^@"UQ\*\`+7'PKS*I[#<+"#'Z[SLLNG$^K7$T\.[I\/[NLW#W,+K+"#(N[KS
MUMC*U"X`M<?"O,JGL-PN`,*LR:VQI`#4P@##O\C5T,7/H@!-4RU43D5&(+B]
MO-/.Q+S^UM##N]/0ROV^W2X`35-'`-;0N?JPQ,/%`,+MQN2VV;FRNLVY^@#"
M[;3OO-/+N;S3M;H`T\J\_@#3RKS^N=S`[0#"[<"MS?X`PNW`M,[WT<<`PNVV
M^[3ZM_(`PNW`^P#"[;;ZR_L`R/W4P@"QZKS'L\D@O[2Y_2_.M+^TN?T`L>J\
MQ[/)QN3+_+7$RK:Q\"`HP/W(YRX@UMC2JB_2T;O8N+0I`,+MR=RV^\BZM;H`
MPNW,X<3AO\NUN@#5_=3:QJ7%Y-?6MLX`PZO`[\O^Q.'1QP##J\#OQ_/+N0"X
MO;S^ROW$O]+1LZRS]KW3RMS)S\_>+@#7[KW\(#(T(-"ARK&UQ-?NN-_.PK;(
M.B``U^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B``O=/*W-?NM/.SI+;(`,[EU,(`
MPNW4O,S8R+JUN@"SR=2Q`+&XS?S$VLC=`-&AM:7$H\J].@#3RKS^`-/*O/[1
MZ=:DTM'-ZK/)++6KRL?3P[NGM<3'J</[R+3.WK>HS:BY_='IUJ0N`-#%SZ+2
MT;G]QMHN`-#%SZ+`X-#-`$UE=&%R(,?XO^G.WK>HRKG3PRX`365T87(@Q_B_
MZ<[>MZC*N=/#+B#/N+W:Q^NRSK^\S[7-L[G<P.VUQ\*\+@"WO;>H`+FKUL8`
MQ*O.][CG`,/<O\O"WL3ASO?1Q\&JL.ZY^@!-:6UE(,#@T,T`U^Z]_"`R-"#0
MH<JQM<37[K7-SL*VR#H@`-?NO?P@-B#0H<JQM<37[KC?SL*VR#H@`-.SR>0`
MQ>36P\[$O/[2Q<JG+B#(Y[G[TJK*N=/#U>*X]M.FT\.SS-#RQ/JQV-#KS];4
MVK[-LOK)^LO[+@#5TK*[M;W0Q<^BM<0@240N`-72LKNUO;OAQMJUQ"!)1"X`
MT,?&VM*[`-#0MJ_3RKS^`+C\T,+(U<;:`-#>N,0@)7,@UM``Q*._Z0#$IK;[
MMN#-WP#$IL3)N.<`P\FYQ0#4PKK-Q.H`P[_4P@##R<S8R/O`K<S8`-3"P<'3
MK[_W`,2FPN6XYP#/PM+&`-?STL8`T]+2Q@#)S]+&`,_"TL8`R<_2Q@#$JLFC
ML<B_RP"XM-&A`,[2M<35R[K%`,[2M<3#Q;NG`,[2M<3#Q;NGTK/#YL7DUL,`
MP^6UZ0"RNRS.TK*[S:S2X@##^[/&`,3)P]>QR-''`.BGPK,`Q.&RM+;[`+K)
MP+P`NLG*]+"RM=C!T,NY`+OYT]I.971S8V%P92"UQ,WXUK<`3F5T<V-A<&4@
M4U-,(+?^SO'&]\/[L\8`3F5T<V-A<&4@R,_6I+7$Q?K7H@!.971S8V%P92#(
MS]:DP.#0S0#-^,+G`+33SK0`T,*_IL#OMN#$X=''`-#"U,(`T,+3P[NGP_L@
M*+?'L=C2JBD`T,+.]\"\`-#"M+"_VB`H7V)L86YK*0#0PL[%`,_"TKNX]M&A
MS^X`Q.&\T\"MN<\`Q.'(U;;[`,3AR-7`^]''`,WMR<\`Q::PH[6Z`,OYUKBV
MJ+7$SKO6P\G/P[O3T,?XO^FTYM3:`,.[T]#,X;FIR-7`^L/[L\;2U+FI($U#
M04P@T>G6I"X`P[O3T-:XMJBUQ"`E<R#%Y-;#T,7/HBX`P[O3T-:XMJBUQ"!&
M5%`@5D93(,7DUL/0Q<^B+@##N]/0UKBVJ+7$(%-13"!61E/%Y-;#T,7/HBX`
MP[O3T-:XMJBUQ"!344PM1FEL92!61E/%Y-;#T,7/HBX`SL2\_LZTR<^TJP#.
MN];#T,7/HLG0SK3%Y-;#`,.[T]#6N+:HP]S"Z]+4N:D@2%144"#1Z=:D+@##
MN]/0UKBVJ,/<PNO2U+FI($E-05`@T>G6I"X`P[O3T-:XMJC#W,+KTM2YJ2!+
M97)B97)O<R#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI($QO9VEN(-'IUJ0N`,.[
MT]#6N+:HP]S"Z]+4N:D@4$%34U=$(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4N:D@
M4TU"(-'IUJ0N`,.[T]"T_<GSM<37HK+AR>K'ZRX`SM[4W;3FQ+_"O+_)N:F_
M[,BA+@##N]/0NL^WJ+7$(%A-3"#*_;[=L;NTJ[O8`+_5L-?6M0#4K<J\Q>36
MP\[$O/[6T-72LKNUO;#FL;[0Q<^B+B#6V-#"LOK)^L7DUL/.Q+S^+@#4VL3Z
MM<3%Y-;#SL2\_M;0U=*RN[6]L.:QOM#%SZ(N(-;8T,*R^LGZQ>36P\[$O/XN
M`,[>`,C5MOK"_,[$("A)4T\M.#@U.2TQ,"D`Q;6XH[_+M;H`L;&PZ\?R`+&Q
MPNW`[]''Q,G(NK6Z`,6RS?X`M\?6KKKS`+?'UJ['L`"RN\K'TKNX]L2_PKP`
MSK2QN]:GL]8`L;C-_,*\`,JNTKO4P@#*_=?6`-?6M_O*_0#7UK;.ROW$OP"Q
MRLK]`$]+`+;4S_.]J,&BU=\`L,N]^,Z[`,JNU,(`L.RYJ\K2`+"BPOP`UKO3
MT"!)34%0(+?^SO'&]]:GL];.Q+S^O-"YLL_MN:;$W"X`UKN]T\K<TKNX]M/*
MO/ZUV-:W+@#6N]/0T[73T-7?T^O/M<VSN=S`[=2QO\G2U+'DN/RYLL_MR*C/
MW@#4VM#"M+"_VM;0M/*_J@#1H<_N`"5S(+7$T:'/[@#/[L2_L>"ZQ0#7Z=:O
M`-?IUJ^UI<Z[`-2MRKS3IM/#L\S0\L2CL.8`U-H@)7,Z(-;0M<34K<J\Q*.P
MYBX`QN3+_`#&Y,O\T,7/H@#&Y,O[T:'/[@#3M=/0U=_(J,_>`%!!32#1Z=:D
MSM[0IRX`4$=0(,K]U];'J</[`%!'4""\T\/<U\K!SP!01U`@N:N_JL/<U+\`
M4$=0(-+1QZG#^R_2T;S3P]P@U\K!SP!02%`@L\S0\K3ZPNL`4$A0(+W%L;X`
ML,V[^<NYS+D`Q<'`S0"PS<#5R[G,N;&[U;S![,?X`+#-Q,/"[0"PS;*\T<?0
MPKRXQ-K1QP"PS<"MN><`P]S"ZP##N]/0UKBVJ,/<PNO2U+FI(%)!1$E54R#1
MZ=:D+@##W,+KR+?(SP##W,+K.@##W,+K.B``P]S"Z['8T.O.Q[K/+@#,^<G/
M`,SYR<\`PK>^M@"T_<GSM<?"O*.Z`-:TT-#.K+NDLMG7]P"UQ\*\NO/6M-#0
MSJR[I++9U_<_`,BHS]X`R*C/WKG<P.T`SM*UQ`##V,*S`+?&PLFQ]@"UY[NP
M`-75QJP`QJ3,V+^UM;H`Q^O*Y,CKTKNX]M3"M]V\L,3JM]TN`,?KRN3(Z]*[
MN/:ZS[>HM<3(U<;:.]&AU/&TR]3"M]VUQ,C5QMHN`,?KRN3(Z[K/MZBUQ,JQ
MO.0N`,?KS.&YJ<[*S.*UQ-6JTJHN`,?KRN3(Z\3ZM<33P[NGP_N\L,/<PNL`
MLJC`O`#-ML:Q`,;/S-'1P`"UW<O-T\J\_K6]U>*X]L[$O/Z\T"`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I`-?NO?P@)7,@T*'*L;7$O;73ZL&_.B``4')E9G-?
M;&1A<#H@U=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\_BX`4')E9G-?<V5S
M<VEO;CH@U=*RN[6]R_G0Z-*JM<0@<V5S<VEO;B#`J=6YU^F\_BX`QOC1N0"Z
MH\:]P^;&^-&Y.B``QOC1N3H@`-2DP,``R<_2N[CVT:'/[@#+O</<P]S4OP#.
MRLSBP^C*]@#7J+"X`,SARK[$VLC=`+FKOZK#W-2_`+FKOZK#W-2_T=W+XP"Y
MJ[^J+\N]P]S#W-2_MM2RHLZTL;NR^LGZ+@"RJ+;@P.BX]P"_J,O^MOL`4E-!
M(+FKOZK#W-2_("@E9"#.NRD`M:71H0"QR,+*`+;!R*$`ML'(H=/*O/X`U>:U
MQ-*JR;ZS_2`E<R#"\#\@U>+/[K+9U_>]J\[>MZB[UKBT+@#(H<_[N+34K0#6
MV-#"U?O`[<?EM:4`RZ+0PL/%NZ?*T\V\.@"YYM3RL>VT[\J]`,;`PML`U+:S
MS+?^SO'&]P#4MK/,S?C6MR`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ`,F^L_T`R;ZS_<?XO^D`R;ZS_;;4`-?4M_[.\<;WU-VTYL2_PKS6T,F^
ML_W2T;&CM.:UQ,7DUL.SS-#R+@#)OK/]T\.[IP#)OK/]T\.[ISH@)7,`T.C'
M\\ZTL;O/[-.F.B"T[<[SNL7"ZSH`O>&Y^P"WM;O8T:'/[@!2975N:6]N("C!
M],3AS?JUNBD`O<?)JP!2;VUA;FEA("C"WL+MQ.'1QRD`T/W7JB`Q.#`@ML@`
MS_+7\]#]UZH`S_+3TM#]UZH`UK30T`!2=7-S:6%N($9E9&5R871I;VX@*+;M
MPM[+N2D`4G=A;F1A("C"K+"RM.\I`%,O34E-12"\T\/<QZG#^P#3RKS^TM'*
MN=/#(%,O34E-12"\T\/<`%-!4TP@T>G6I,[>T*<N`-#%SZ(`ROV^W;_BO<6Q
MO@"\T\/<UM6VR[OZ`+/)N:8`T,?&VL'Y`,JENM7`U<3#M;H`RJ6[^;7"NLW!
MT,ZLR[D`RJ7"K,[WT<>UN@#*I<:DL*.V^[K-PO._R\+7R+JUN@#*I<[$R:W,
MV+K-N/'!UL3)M.\`S:S2N[CVM+"_VB`H7W-E;&8I`,CXQ*;1QP#*I<+MP:;%
MM0#*I;;@P\"ZS<;5P=;.]['(`,[`T,?,X;FIU=\`R;/,V+"BP*VRK@"QH[3F
M("5S`+&CM.;1H<_N`+VKLOK)^K7$Q>36P\[$O/[2U"!02%`@T^_1U+CQRKVQ
MH[3FM;W$^K7$M_[.\<;WU-VTYL2_PKS6T"X`Q>36PR`E<R#2T;&CM.8N`++I
MU=(`LNG5TKWAN?L`LNG5TK>VSJ<`T:'4\=*[N/;(U<;:`-&AU/'2N[CVT\.[
MI]?IT\/2U-#"U/8`T:'4\=*[SKO0PK7$T[73T-7?`-&AU/'2N[*_M_[.\<;W
M`-&AU/'2N\Z[T\.[I]/#TM30PM3V`-&AU/'+^=/0R-7&VM?IO/XN`-/:TM3/
MPK7$M+"_VM;0T:'(H<3ZTJJUQ-?6M_LNTM3*\['JN+36QLOYT:'.Q-?6+,B[
MNO/,^<G/SL2\_K'@O*W'^"X`T:'4\<C5QMJWUKCT.@#1H=3QR-7&VLC5QMJX
M\<J].@#1H=3QRK&\Y+?6N/0Z`-&AU/'(U<;:RK&\Y+CQRKTZ`-&AU/'/X+NE
MQJ7%Y+7$MOZX]M?6MLXN`-&AU/'$^K7$T=7)J\7DUL,`T:'4\<:KNL/3[]'4
M.@"TJ\O-SLK,XK>TTZ8`4V5N96=A;"`HR/O$VKS3MOLI`+2KN-#&]SH@`+[%
MU,(`4V5R8FEA(&%N9"!-;VYT96YE9W)O("C(^[;[SJS1Q]/KP\G,V,3AN.?"
MWBD`T/*ZQ0"[X<;:($E$(-+1N?W&VBX`Q>36PP#%Y-;#U+:SS+?^SO'&]\G/
MRO33VL3ZM<2X]LC+U;[,J"X`Q>36P\3ZM<3&J[K#T^_1U"P@RK''^-+4O+#(
MU<;:N/'*O2X`Q>36P\3ZM<3&],J\TZ;3P[/,T/(LT=7)J\7DUL,LTK/#YKC\
MT,+&M<+*++RPQN3+_,_4RK[1H<_N+@#3T+K#O+BX]K78M>.ZS=7BN/:RSLK]
MT]"YV#H@`%-E>6-H96QL97,@*,C[SO2V^RD`N;K.[P"\\K;,U:K2J@#*Q[?Q
MSJJT\[*_M]VUQ,&LO=.VJ-+EO^R]W;FFQ-R\_#\`S]3*O@##O[3.M<?"O+KS
MS]3*OLG/TKNTSK7$M<?"O,JQO.0@/P#/U,J^M>/1H<;W`-/:U_.QW\_4RKX@
M)7,@LLNUI3\`RM7+]0!3:65R<F$@3&5O;F4@*,JHU]/)O;GZ*0#7HK+A`,>I
MP_L`QZG#^]'=R^,`4VEN9V%P;W)E("C0PKS3QL(I`+3ST*$`PM2Y_<ZLNZ0`
M4VQO=F%K:6$@*,NYPN6WI;_+*0!3;&]V96YI82`HR[G"Y;>EQ.'1QRD`N_W1
MJ<GNML@Z(`!3;VQO;6]N($ES;&%N9',@*,OWPM[#Q<BZM;HI`%-O;6%L:6$@
M*,OWPNW`^]''*0#2U,#@L?#%Q=#R`,7%P="WO<_RT:'4\0#`M-2TM=C6MP!3
M;W5T:"!!9G)I8V$@*,3/M\<I`,3/Q;<@*$E33RTX.#4Y+3,I`%-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`,3/L.O'\@!3
M<&%I;B`HSO>PX-'`*0#`K+OXT\J\_@#,V,KBU]:W^\KDR.L`4W)I($QA;FMA
M("C+N<#OP+R_J"D`L>K7O`#&],J\Q.JWW0#*H0#7M,RL`+&CM.:X\<J]`+W6
MM<``R;ZS_<_?`-?6M_NTKL'0`-#'QMK,[`#6]]:\`,SAO;L`S\*QZ@"SR;FF
M`-+1L\FYIKBRN,<@)7,`4W5D86X@*,O5M:0I`-6JTJH`R-6S]@#(U<+D`,C5
ML_8`R-6S]B_(U<+D`,C5L_8Z(`#(U<+D`,C5PN0Z(`#)S['J`-:GL]8`4W5R
M:6YA;64@*,O5P/O$SRD`M,*ZQ0!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W
M87II;&%N9"`HRK?-W[S#P+PI`%-W961E;B`HR/"UY"D`4W=I='IE<FQA;F0@
M*,CPRK\I`%-Y<FEA;B!!<F%B(%)E<'5B;&EC("C0\,#[T<<I`%1!0B"WUKCT
MN/'*O<[$O/X`S*C-Y0#,J,WE`%1A:FEK:7-T86X@*,O^O*K+N<RY*0!486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F("C,N<G0Q.'1QRD`Q+^QZCH`M/VP
M[,K"S^X`M>>[L+K%PNL`U^Z]_-*[T*'*L;7$SL*VR#H@`,["ML@`SL*VR#H@
M`,2CL.:YW,#M`,3:R-T`M+_.Q-?6`-#'QMK+Q`#,J<[$("A425,M-C(P*0!4
M:&%I;&%N9"`HS*FY^BD`T+O0N\3ZRKG3P[&^S[7-LRX`1E10(-'3R>PH97AT
M96YS:6]N*<[>T*<N`$UA:6YT96YA;F-E(,#@L?"RHLZTL\FYIM38R.L`T:'/
M[K2PO]K2U+G8L=4NP.N_JM;0+@#1Z=:DT\J\_L>IP_O0Z-*JT]#2N[CVTM&]
MXK^JM<0@4$=0(,?XO^DN`-#HTJK2N[CVOJVY_;S3P]RUQ,WXPN?!K+W3+@#.
MQ+S^("5S(-.FN,.P_+JLTKNX]B`E<R#%Y-;#+@#.Q+S^("5S(-.FN,.P_+JL
MTKO0J2`E<R#%Y-;#+@"TR\[$O/[6T,.[T]#*_;[=+@#2U,_"RL<@<F9C.#(R
M(-/*O/ZUQ+'MS;<N`$=N=5!'(+;^U*K.Q+S^M<3"M[ZVL=C0Z[:HTN74VB!#
M<GEP=%]P9W`Z.B#`X+'PUM`N`$AO<F1E7T-R>7!T7W-M:6UE.CH@P."Q\"RQ
MV-#HTJK3T"!O<&5N<W-L(,2CO^DN`+3+QJNZPR`B)7,B(,K]OMW2\LZJLZRY
M_=?NM/.]T\K<UK4LR_G2U,[>MZBQN[&CM.8`T\/2U+SLRM.TR\K]OMW`X-#-
M("@E<RD@M<2SS-#RLJ*RN[3FU-K3VL^US;/)SRX`M,NW_L[QQO<@(B5S(B#2
MT;&[R;ZS_2X`M,NW_L[QQO<@(B5S(B#2T;&[L:.TYBX`)7,@M<37HK+AT.C'
M\]+1L;O)OK/]+@#6N+:HM<2\Q\*\LJ*RN[3FU-HN`+33R<_2N[CVLKW6Z-:N
MNO/)S[2KM<3*_;[=TL7*IRX`R<^TJ\[$O/ZRHLZTL;NQH[3F+@!W96%T:&5R
M+F-O;2#'^+_ISMZWJ,JYT\,N`,[>N+V\_K_)UK&]T[3ROZHN`+3+U]:VSM;0
ML/RZK,RKMN"UQ-?6ROTNQ/K2T<KDR.L@)7,@N/;7ULK].\3ZRN3(Z[7$U];*
M_;'8T.O0H=/:("5S+@#)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB.B`E<R#.M+&[
MR<^TJRX`R<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@)7,@M//0H;.LN?V]T\K<
MU^ZT\]:U("@E9"!B>71E<RDN`,G/M*O.Q+S^RK&WHLGZTKNX]L[*S.(Z(+WV
MLK^WUK7$("5S(,[$O/ZQN\G/M*LN`+SLRM/3RKS^RK&WHLGZTKNX]K3MSO,N
M`+OCR.NTR\VHT;:ROLK]OMW*L;>BR?JT[<[S+@#4VL7DUL.TL,SEUM"WHLGZ
MP<O2N[CVM.W.\R[3T+_)Q-S$^M+%PJG!R['8T.O,[M"TM<37UK;.+@"TRR!)
M34%0(+?^SO'&][*BSK36I[/6SL2\_KS0M];/[;FFQ-PN`-7BR\:Z];*[RL?5
M_<BWM<0@<F%R(-&YR_7.Q+S^+@#5XLO&NO6RN\K'U?W(M[7$('II<"#1N<OU
MSL2\_BX`U>++QKKULKO*Q]7]R+>UQ-#%T\._J+K%PNLN`+3+U]:VSLK'L=C0
MZ-*JM<0N`+3+U]:VSL3:R-W6N[W3RMS5^\K]ROW7UBX`M,O7UK;.Q-K(W=:[
MO=/*W,K]U]:\L,.PNL4N`+3+U]:VSL3:R-W6N[W3RMRPR[WXUL;*_=:U+@"T
MR]?6ML[$VLC=L=C0Z\ZJMKJZQ;ORO]6PU[?6N/2UQ,K]U]8`L=C0Z\K'TKNX
M]LK]U]8N`+3+U]:VSL3:R-VQV-#KL/RZK-*[U^G*KL'YO?C6QK7$(%)'0B#1
MU<FKM/K"ZRS`_<CG("<C,3(S-&%F)RX`U>*X]K2PS.72T;&[M*;`[;G]+@#5
MXLK'("5S+@"TR\K]UK77[LG9L=C0Z\K'(#$N`+3+M_[.\<;WSMZWJ+;4('II
M<""\L"!G>FEP(+CQRKW.Q+S^O?C0T+WBT;G+]0"TR\^US;.UL<>PRL?-H]/#
MM<37M,RL+@"QV-#KRL?2N[CVROW7UBX`M,NTL+_:L=C0Z]*JT\G1H<_NM+"_
MVBA/<'1I;VXIR_FZ]+W0`,JQO.0`RK&\Y->WU]D`RK&\Y+CQRKT`RK''^-&A
MU/$`5&EM;W(M3&5S=&4`L>K,X@#*U;S^R,L`R.>Y^]*JN+31H2S'Z]3:M>/1
MH<KSL>JUQ,VLRK&PM"!#;VYT<F]LO/PHN/;(R[S&R^.[^BD@N_(@0V]M;6%N
M9+S\*,:[N?N\QLOCN_HI+@"]\<SL`$A434P@U*W*O,[$O/X`MN"XYP#-T+_+
MP,W(NK6Z`,/WS.P`S,"\TP#,V,&BQ.&T[[K-MN"PS;CG`-7FN_*\V0#0Q\;:
MMOX`S;O$X<NY`,W!MOK&Y`#-P;;ZQN3.Q"`H25-/+3@X-3DM.2D`S<&_XL+\
MR[G,N0#,V+_+R[FZS;^MO\;+N<BZM;H`S;S-W\*L`,KDR.O$^K7$T:'4\3H@
M`-?/S>+/W]:XROTZ(`#-^-:W`,WXUK<Z`,[:N,FT[P#.VK_+P+P`SMZWJ+3F
MR*$@5D93(,2_PKPN`->BLN'*L<[>MZC4]KS3MN[-XK7$T\.[I]#%SZ(N`,[>
MMZBXQ+'D(%9&4R#.Q+S^("(E<R(@M<3(J,_>+@#.WK>HL>2X_"!61E,@SL2\
M_B`E<R\E<R"UQ,BHS]XN`,[>MZBQY+C\SJH@)7,N`,[>MZC!K+W3UL$@4U%,
M(+?^SO'&]RX`SMZWJ,JYT\,@4U-,(,&LO=,N`,[>MZBXM-;&(%9&4R#.Q+S^
M+@#.WK>HO:C!HB!61E,@Q+_"O"`B)7,B+@#.WK>HO:C!HB!61E,@Q+_"O"X`
MSMZWJ+VHP:(@5D93(,[$O/XN`,[>MZB]J\K]OMV]XM&YR_4N`,[>MZC)OK/]
M("5S++3+Q+_"O+*BM\>_U;#7`,[>MZBUW;GIR;ZS_<2_PKPN`,[>MZC)OK/]
M(%9&4R#$O\*\+@#.WK>HR;ZS_2!61E,@Q+_"O#H@)7,N`,[>MZC)OK/](%9&
M4R#.Q+S^("(E<R(N`,[>MZC)OK/](%9&4R#.Q+S^+@#.WK>HM=VYZ<F^L_T@
M5D93.B`E<RX`SMZWJ,70ML^UL<>PM<3$O\*\+@#.WK>HO>*_JL:^UJ3/N+W:
M`,[>MZB\T]38("5S(+7$MJC2Y<K]OMTN`,[>MZC2QK:O(%9&4R#.Q+S^+@#.
MWK>HM/*_JB!61E,@SL2\_B`B)7,B+@#.WK>HT+3(ZR!61E,@SL2\_BX`SMZW
MJ+3ROZH@5D93(,[$O/XN`,[>MZBT\K^JT;G+]<[$O/XN`,[>MZBVP<BA('9F
M<W)O;W0@Q+_"O"X`SMZWJ+'DN/P@5D93(,2_PKRUQ,/[L\8N`,[>MZC)OK/]
M(%9&4R#$O\*\.B`E<RX`SMZWJ+'DN/P@5D93(,[$O/X@(B5S(B"UQ,/[L\8N
M`,[>MZBQY+C\(%9&4R#.Q+S^("5S+R5S(+7$P_NSQBX`SMZWJ+'DN/P@5D93
M(,[$O/ZUQ,/[L\8N`,[>MZC7JKN[(%=O<F0@SL2\_@#.WK>HT+3(ZR!61E,@
M(B5S(B#.Q+S^+@#.WK>HT+3(ZR!61E,@SL2\_LK]OMTN`,_"NZ[/WP#(H<_[
MN/RXQ`"XM-2M`+?^SO'&]\&LO=/*L;>BR?K.M-2DQMJUQ+O8TZ8Z(`"WHLGZ
MSK34I,;:M<2[V-.F+-/)M_[.\<;W.B``SK2YZ;6U`,WRT\/"ZR`H551&+3@I
M`+"BP*VRKL&JNL_'];.DN?H`TZ*Y^@##P+GZ`%5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<P"UI=2J`,ZTUJJUQ`#.M-:JM<33P[NGP_N[
M\L/<PNLN`,ZTUJ>SUK7$P*G5N</[`+'DN/P`N/S0PB`E<P"X_-#"T\.[IP"X
M_-#"L\S0\M+1R;ZS_2X`R<^TJP#2T<G/M*O+^=/0TZ;3P[/,T/*UQ,7DUL/.
MQ+S^M;VW_L[QQO<N`,[:P*VYYP#3P[NG("5S(,ZTS:BY_2`E<R"UQ,K:R*C1
MZ=:D+@#3P[NGN=S`[0#3P[NGT:'/[@#3P[NGUZ*RX0"TR]6^S*BUQ-/#NZ?7
MHK+AS[7-L]+1S:/3PRX`T\.[I\/[`-/#NZ?#^SH`T\.[ISH@`,^US;/6T+7$
MT\.[ISH`SMK7R+'PO\O+N<RY`%9&4R#$O\*\LJ*RN[3FU-HN`+S9QMH`TM'5
MTK6]T]#0I[7$M=BUXSH@`-/0T*?0U`#2U+?6UM/.JK6ESKLHM-//UM3:QO#+
MXRD`UK4`S=_"L["BS;P`L>2[KP#.K\3:R/#`K0#1Z=:DRJ>PW"`M(+3+T\J\
M_K_)Q-S2T=3BR,O)P]?4M-NXQ"X`L.:QO@"PYK&^O]C6Q@#4O<3/`-2]Q,_.
MQ"`H5DE30TE)*0"\[,K3("5S`-3:T,*TL+_:M/*_J@#2U"`E<R"RZ;^T`-.B
MRO3.K+;[OJG(NK6Z`,/`RO3.K+ZIR+JUN@#$W+S[ML@`Q-R\^[;(.B``TN*T
M\\#[M_RUPK?GM>?0Q;FKR[[-N+G](%--5%``OJ^XY@"^K[CF(2$A(+33("5S
M(,K6MJ_)OK/]L\S0\BX`S=_`^\NYNLVXN\V\R+JUN@"^K[CF`-#'QMK(_0#,
M[,;XU*2RX@#-^-6^`,WXU;X`P[_6W`"[MM.M`+NVTZVUO2`E<P"[MM.M+"`E
M<P#.]\6W("A)4T\M.#@U.2TQ*0#.]\6W("A)4T\M.#@U.2TQ-2D`SO?(]KG^
MP*T`M<?"O+KSTZ:XP\_(S]3*OB`E<R#$Q-*[N/;3IM/#L\S0\C\`U]:VSK7$
MM]:X]-?6M_L_`-+]RO:UQ,>PM;RW^S\`M^?+V2B]VBD`M^?+V3H`M^?+V3H@
M`+#LN:O*TK78UK<`L.RYJ\K2M>>[L`!8-3`Y=C,@P*G5N</[`,3J`,3J`%EA
M:&]O("$@M=C-O`##O\3J`-*RP\4`RL>UQ"S.TLVLTN(`Q/JUL<>PRKG3P[2_
MSL37UK'@T+3$H\J]+B#*N=/#(%L\/ET@L+3%I;_)Q]"[N\ZJS?C2L['@T+3$
MH\J]+@#$^K*BSK3*Y,CKTKNX]KK/MZBUQ+7GU]/3RKS^M=C6MRX`Q/JRHLZT
MT\FUO,CKM<3.Q+S^UM"VU-.SR,ZZSM?6MLZUO2`E<P#$^M+1OJW7HL_Z+@#$
M^K'8T.O*Y,CKTKNX]KK/MZBUQ-:U+@#$^K'8T.O/R+GFNZZZP\K]OMW*]RA$
M871A5')E92FW_L[QMLNRQ<3<O,S0^,JYT\/0PM/#NZ?7HK+AM_[.\2X`Q^O#
MZ,KVSLK,XJ.LU-K$^K2KR\W.RLSBL:BXYM:NQ[`N`,3ZL=C0Z\KDR.NTR\&L
MO=/+^=:XS_*UQ,WXUK<`Q^O6N+:HTJK)OK/]M<2W_L[QQO<N`,?KUKBVJ-*J
MR;ZS_;7$T\.[IRX`Q^O6N+:HTJK0PM3VM<33P[NG+@#'Z]:XMJC2JKC\T,*U
MQ-/#NZ<N`,?KUKBVJ-*JUK30T+7$U_?3PRX`Q/JUQ"`E<R"[X<;:TM&Y_<JQ
M+L?KUMC0PK7'PKPN`,3ZM<2UY]?3T\J\_K78UK<`Q/JUQ-#%SZ(`U]2TT\3Z
MM<0@)7,@N^'&VK^JRKS2U,"TQ/JUQ-+RS-C-^+78UK?2T;'DN/PN(,ZJL:.[
MI,3ZM<2PLLBKQO"\^Z.LQ/JQV-#KUMC0PK7'PKPN`,3ZM<30U</[`,3ZM<31
MZ=:DMLNRHLZTUJ>SUL'0L_;3P[NGN_*XP[FFQ-S2T;&[N=BQU2X`U]2TT\3Z
MM<0@)7,@N^'&VK^JRKS2U,"TQ/JUQ.2OP,#&]\O&NO72T;'DN/PN(,ZJL:.[
MI,3ZM<2PLLBKQO"\^Z.LQ/JQV-#KUMC0PK7'PKPN`,3ZM<3DK\#`QO>RHLZT
MUJ>SUM7BN/:YIL3<+@#$^K6QQ[#+^<7DUL.UQ,JQQ_@Z`,3ZM<31H<_NTM&X
M_-#"+@#$^K7$U+:SS+?^SO'&]SH`Q,_+N<"MM_(`U/K2P;;[`-3>L<C1QP"]
M\K#-LKS.I`!;SLK,XK&HN.9=`%O.N]/:T-`@)7,@N;(@)7,@T-!=`,[$O/X`
MM-,@)7,@*"5S*2#3VB`E<R`E<P#*L3H`P:*\M`##^[/&`,G0SK3*M<_6+@#)
MT,ZTRK7/UBX`U-FTSLKDR.O$^K7$P]S"Z]+4R+?(S\[>SO,`SK3#_,/[`-/#
MNZ?1H=3Q`'9#87)D`-#'QMHZ`'=E871H97(N8V]M(,WXU;X`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O
M;&]C86QE+WIH7U17+P``````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-@`P,C`P,S,`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]M;F5M;R]L;V-A;&4O>FA?5%<O3$-?34534T%'15,O````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0V`#`R
M,38R,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQO8V%L92]Z:%]4
M5R],0U]-15-304=%4R]M;F5M;RYM;P``````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S-34W
M-#(`,3`T,3<S-C(W-#8`,#(S,S`U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-X2!)4`````P`<``!P````</@``5PH``!Q\
M````````>*4```X```!YI0``#P```(BE```-````F*4```@```"FI0``"P``
M`*^E```,````NZ4```0```#(I0``&````,VE```;````YJ4``"T````"I@``
M'0```#"F```D````3J8``"D```!SI@``&0```)VF```F````MZ8```P```#>
MI@``)````.NF```(````$*<```\````9IP``"P```"FG```.````-:<```4`
M``!$IP``*````$JG```(````<Z<```H```!\IP``%0```(>G```2````G:<`
M``L```"PIP``#0```+RG```=````RJ<``(4```#HIP``#@```&ZH```*````
M?:@```T```"(J```#@```):H```1````I:@```T```"WJ```#````,6H```-
M````TJ@```8```#@J```E````.>H```*````?*D```\```"'J0``&````)>I
M```,````L*D```8```"]J0``#@```,2I```.````TZD```@```#BJ0``"0``
M`.NI```N````]:D``!H````DJ@``,@```#^J```X````<JH``%0```"KJ@``
M40````"K``!:````4JL``%<```"MJP``-`````6L```)````.JP```T```!$
MK```!P```%*L```*````6JP```\```!EK```!0```'6L```&````>ZP``!$`
M``""K```"````)2L```)````G:P```D```"GK```)0```+&L```@````UZP`
M`!P```#XK```'@```!6M```@````-*T``!T```!5K0``$P```'.M```0````
MAZT```\```"8K0``"@```*BM```#````LZT```\```"WK0``%````,>M```)
M````W*T```T```#FK0``$@```/2M```9````!ZX``!X````AK@``#P```$"N
M```,````4*X```H```!=K@``#P```&BN```(````>*X``"0```"!K@``%```
M`*:N```6````NZX```@```#2K@``3@```-NN```M````*J\``!$```!8KP``
M&0```&JO```'````A*\```P```",KP``+````)FO```.````QJ\```,```#5
MKP``"P```-FO```'````Y:\```<```#MKP``!0```/6O```%````^Z\```H`
M```!L````P````RP```7````$+````H````HL```#P```#.P```.````0[``
M`!@```!2L```(P```&NP```.````C[```!0```">L```%P```+.P```7````
MR[```!<```#CL```$P```/NP```/````#[$```X````?L0``'P```"ZQ```=
M````3K$```<```!LL0``!@```'2Q```(````>[$```\```"$L0``!@```)2Q
M```*````F[$``!,```"FL0``"P```+JQ```0````QK$``!4```#7L0``%0``
M`.VQ```'`````[(``!`````+L@``!0```!RR```5````(K(``!$````XL@``
M#````$JR```[````5[(``#@```"3L@``"0```,RR```'````UK(``!0```#>
ML@```P```/.R```%````][(```D```#]L@``$`````>S```)````&+,``!,`
M```BLP``.0```#:S```2````<+,``"<```"#LP``+````*NS```J````V+,`
M`"4````#M```"@```"FT```&````-+0```D````[M```!P```$6T```O````
M3;0``#<```!]M```+@```+6T``!5````Y+0``"T````ZM0``+0```&BU```]
M````EK4``#\```#4M0``+0```!2V``!`````0K8``",```"#M@``(P```*>V
M``!`````R[8``"T````,MP``,P```#JW```E````;K<``!4```"4MP``&0``
M`*JW```I````Q+<``"0```#NMP``*````!.X```5````/+@``!$```!2N```
M"@```&2X```/````;[@``!<```!_N```"@```)>X```0````HK@``!8```"S
MN```%@```,JX```'````X;@```<```#IN```%````/&X```*````!KD```@`
M```1N0``)P```!JY```(````0KD```<```!+N0``!P```%.Y```&````6[D`
M``4```!BN0``!P```&BY```&````<+D```@```!WN0``*0```("Y```.````
MJKD```H```"YN0``!````,2Y```'````R;D```D```#1N0``!@```-NY```1
M````XKD```<```#TN0``%@```/RY```$````$[H```@````8N@``!@```"&Z
M```-````*+H```8````VN@``'@```#VZ```1````7+H```@```!NN@``#0``
M`'>Z```,````A;H```<```"2N@```P```)JZ```#````GKH``!<```"BN@``
M`P```+JZ```3````OKH``!T```#2N@``"````/"Z```$````^;H```@```#^
MN@``"`````>[``!!````$+L``!H```!2NP``(````&V[```5````CKL```8`
M``"DNP``!@```*N[```5````LKL``!@```#(NP``(@```.&[```N````!+P`
M`!T````SO```(0```%&\``!4````<[P``"D```#(O```"@```/*\```'````
M_;P``!4````%O0``"````!N]```.````)+T```H````SO0``#P```#Z]```-
M````3KT```\```!<O0``#0```&R]```)````>KT``!0```"$O0``!@```)F]
M```8````H+T``!T```"YO0``$P```->]```1````Z[T``!0```#]O0``!```
M`!*^```&````%[X``!0````>O@``5````#.^```M````B+X``&0```"VO@``
M!````!N_```.````(+\```4````OOP``!0```#6_```;````.[\``!H```!7
MOP``$P```'*_```1````AK\``!$```"8OP``'````*J_```J````Q[\``#<`
M``#ROP``'````"K````0````1\```"$```!8P```!0```'K````*````@,``
M`!,```"+P```"P```)_````2````J\````H```"^P```#P```,G````-````
MV<```!$```#GP```$P```/G````,````#<$```8````:P0``#````"'!```&
M````+L$``!<````UP0``$````$W!```1````7L$```@```!PP0``!0```'G!
M```,````?\$``!````",P0``!0```)W!```-````H\$```8```"QP0``!P``
M`+C!```-````P,$```<```#.P0``"P```-;!```'````XL$```<```#JP0``
M"0```/+!```)````_,$```H````&P@``&0```!'"```]````*\(``!T```!I
MP@``#````(?"```0````E,(```4```"EP@``)0```*O"```2````T<(``!,`
M``#DP@``*P```/C"```[````),,``"````!@PP``"````('#```V````BL,`
M`"$```#!PP``$````./#```(````],,```P```#]PP``!`````K$```/````
M#\0```X````?Q```"@```"[$```-````.<0``!\```!'Q```'````&?$```A
M````A,0``!X```"FQ```&0```,7$```>````W\0``!T```#^Q```&P```!S%
M```@````.,4``"X```!9Q0``)@```(C%```<````K\4``!X```#,Q0``'```
M`.O%```F````",8``"L````OQ@``,P```%O&```F````C\8``"L```"VQ@``
M.````.+&```=````&\<``!4````YQP``+P```$_'```@````?\<``!(```"@
MQP``*0```+/'```>````W<<``"````#\QP``$@```!W(``"B````,,@``!8`
M``#3R```(P```.K(```H````#LD``"D````WR0``*````&')```?````BLD`
M`!4```"JR0``(````,#)```E````X<D``"@````'R@``+0```##*```P````
M7LH``)(```"/R@``(0```"++```6````1,L``!P```!;RP``)@```'C+```J
M````G\L``$$```#*RP``1`````S,```,````4<P```<```!>S```!P```&;,
M```&````;LP```T```!US```$````(/,```2````E,P```<```"GS```$P``
M`*_,```2````P\P```<```#6S```!````-[,```0````X\P```P```#TS```
M#@````'-```-````$,T```\````>S0``$P```"[-```-````0LT``"@```!0
MS0```P```'G-```-````?<T```8```"+S0``$0```)+-```7````I,T``!L`
M``"\S0``#@```-C-```"````Y\T``$D```#JS0``!0```#3.```0````.LX`
M``\```!+S@``!````%O.```-````8,X```X```!NS@```P```'W.```.````
M@<X```@```"0S@``#P```)G.```/````J<X```<```"YS@``#0```,'.```0
M````S\X```\```#@S@``#0```/#.```9````_LX``!H````8SP``"P```#//
M```&````/\\```L```!&SP``$P```%+/```,````9L\```H```!SSP``$0``
M`'[/```9````D,\``!<```"JSP``"P```,+/```-````SL\``"(```#<SP``
M&P```/_/```T````&]````H```!0T```&````%O0```9````=-```!8```".
MT```$````*70```B````MM````T```#9T```!P```.?0```*````[]```!0`
M``#ZT```"P````_1```,````&]$``"(````HT0``+P```$O1```+````>]$`
M``D```"'T0``&0```)'1```+````J]$``!<```"WT0``%P```,_1```)````
MY]$``!8```#QT0``#P````C2```9````&-(``!8````RT@``#@```$G2```8
M````6-(```@```!QT@``#0```'K2```F````B-(``"@```"OT@``0P```-C2
M```(````'-,``!(````ETP``'P```#C3```(````6-,```L```!ATP``+P``
M`&W3```.````G=,```4```"LTP``!@```++3```#````N=,```<```"]TP``
M!````,73```)````RM,```H```#4TP``"@```-_3```)````ZM,```\```#T
MTP``$`````34```7````%=0``!H````MU```$0```$C4```9````6M0``!<`
M``!TU```"0```(S4```%````EM0```L```"<U```"@```*C4```%````L]0`
M``T```"YU```&P```,?4```7````X]0``!0```#[U```"0```!#5```*````
M&M4```X````EU0``#0```#35```2````0M4``#@```!5U0``(````([5```(
M````K]4```X```"XU0``>P```,?5```8````0]8``!$```!<U@``!P```&[6
M```%````=M8``!@```!\U@``'@```)76```;````M-8``!D```#0U@``&P``
M`.K6```3````!M<```<````:UP``"````"+7```&````*]<```8````RUP``
M$````#G7```/````2M<``!````!:UP``#P```&O7```+````>]<```\```"'
MUP``#````)?7```/````I-<```<```"TUP``!@```+S7```.````P]<```P`
M``#2UP``#P```-_7```(````[]<```8```#XUP``#````/_7```(````#-@`
M`!,````5V```"@```"G8```>````--@``"$```!3V```(````'78```9````
MEM@``!<```"PV```)0```,C8```7````[M@``!8````&V0``!````!W9```;
M````(MD```T````^V0``#````$S9```#````6=D```4```!=V0``"````&/9
M```*````;-D```P```!WV0``"P```(39```0````D-D```P```"AV0``!```
M`*[9```3````L]D``!0```#'V0``#````-S9```)````Z=D```X```#SV0``
M"P````+:```;````#MH```<````JV@``!P```#+:```*````.MH```T```!%
MV@``"0```%/:```$````7=H```4```!BV@```P```&C:```8````;-H```H`
M``"%V@``!````)#:```F````E=H```X```"\V@``?````,O:```5````2-L`
M``4```!>VP``!P```&3;```,````;-L```@```!YVP``"@```(+;```&````
MC=L```@```"4VP```@```)W;```&````H-L```8```"GVP``%````*[;```-
M````P]L``!````#1VP``&P```.+;```$````_ML```D````#W```$`````W<
M```)````'MP```D````HW```!0```#+<```(````.-P```8```!!W```#P``
M`$C<```9````6-P```X```!RW```!P```('<```'````B=P```4```"1W```
M"0```)?<```*````H=P```(```"LW```!@```*_<```+````MMP```T```#"
MW```"0```-#<```&````VMP``!(```#AW```"0```/3<```'````_MP``!0`
M```&W0``'0```!O=``!"````.=T``"4```!\W0``)0```*+=```&````R-T`
M``H```#/W0``!````-K=```)````W]T```@```#IW0``$0```/+=```)````
M!-X```8````.W@``#0```!7>```&````(]X```0````JW@``'@```"_>```%
M````3MX```X```!4W@``!````&/>```&````:-X```<```!OW@``(0```'?>
M```-````F=X``!4```"GW@``!@```+W>```$````Q-X``!$```#)W@``!@``
M`-O>```*````XMX``"(```#MW@``!````!#?```%````%=\``!T````;WP``
M!````#G?```,````/M\```X```!+WP``"@```%K?```(````9=\```D```!N
MWP``!0```'C?```Z````?M\``#````"YWP``-0```.K?```I````(.```$<`
M``!*X```.````)+@```I````R^```#\```#UX```+@```#7A```M````9.$`
M`!\```"2X0``#P```++A```2````PN$```L```#5X0``)@```.'A```I````
M".(``"0````RX@``)@```%?B```(````?N(```H```"'X@``"0```)+B```'
M````G.(``"````"DX@``(````,7B```F````YN(```H````-XP``&0```!CC
M```I````,N,``!(```!<XP``!P```&_C```*````=^,```P```""XP``#P``
M`(_C```0````G^,``$````"PXP``<````/'C``!F````8N0```X```#)Y```
M"0```-CD```*````XN0``!(```#MY```$P````#E```,````%.4```8````A
MY0``%0```"CE```/````/N4``!,```!.Y0``$@```&+E```0````=>4``!$`
M``"&Y0``'````)CE```C````M>4``&H```#9Y0``#P```$3F```%````5.8`
M`!````!:Y@``"0```&OF```$````=>8```L```!ZY@``(````(;F```4````
MI^8```P```"\Y@``#````,GF```/````UN8``!4```#FY@``*0```/SF```J
M````)N<``"8```!1YP``)P```'CG```I````H.<``"H```#*YP``&0```/7G
M``!"````#^@``!$```!2Z```$@```&3H```3````=^@``!0```"+Z```#P``
M`*#H```6````L.@``!<```#'Z```$````-_H```1````\.@``#0````"Z0``
M$P```#?I```2````2^D``#4```!>Z0``%````)3I```'````J>D```P```"Q
MZ0``(````+[I```0````W^D``!0```#PZ0``$0````7J```7````%^H``!P`
M```OZ@``$P```$SJ```4````8.H``!H```!UZ@``$0```)#J```:````HNH`
M`!X```"]Z@``&@```-SJ```3````]^H``!4````+ZP``$0```"'K```7````
M,^L``!0```!+ZP``%P```&#K```5````>.L```D```".ZP``$````)CK```9
M````J>L```0```##ZP``!P```,CK```+````T.L``!$```#<ZP``!@```.[K
M```&````]>L```8```#\ZP``!0````/L```'````">P```<````1[```!0``
M`!GL```6````'^P```8````V[```!@```#WL```$````1.P```0```!)[```
M!P```$[L```.````5NP```P```!E[```#````'+L```-````?^P```H```"-
M[```#@```)CL```%````I^P``"@```"M[```#@```-;L```,````Y>P```\`
M``#R[```"@````+M```(````#>T```D````6[0``*P```"#M```$````3.T`
M``@```!1[0``)@```%KM```2````@>T```\```"4[0``!@```*3M```*````
MJ^T```<```"V[0``"````+[M```@````Q^T```D```#H[0``#0```/+M```4
M`````.X```P````5[@``#0```"+N```.````,.X``!8````_[@``$0```%;N
M```&````:.X```,```!O[@``!@```'/N```'````>NX```0```""[@``"P``
M`(?N```+````D^X```<```"?[@``!P```*?N```6````K^X```T```#&[@``
M#0```-3N```*````XNX``!````#M[@``#P```/[N```1````#N\``!<````@
M[P``"@```#CO```1````0^\```@```!5[P``!````%[O```/````8^\``#H`
M``!S[P``!0```*[O```>````M.\```X```#3[P``$````.+O```+````\^\`
M``P```#_[P``"0````SP```'````%O````H````>\```"0```"GP```.````
M,_```!````!"\```&P```%/P```8````;_```!H```"(\```"@```*/P```)
M````KO````H```"X\```#````,/P```/````T/````@```#@\```!@```.GP
M```'````\/````4```#X\```"P```/[P``!'````"O$```T```!2\0``"0``
M`&#Q```$````:O$```,```!O\0``$P```'/Q```3````A_$``!,```";\0``
M"@```*_Q```"````NO$```0```"]\0``)0```,+Q```#````Z/$```4```#L
M\0``*@```/+Q```*````'?(```4````H\@``!````"[R```*````,_(```T`
M```^\@``!@```$SR```(````4_(```@```!<\@``!````&7R```%````:O(`
M`&@```!P\@``"0```-GR```,````X_(```4```#P\@``!@```/;R```;````
M_?(``"\````9\P``$````$GS```*````6O,```\```!E\P``"@```'7S```)
M````@/,``!,```"*\P``&P```)[S```8````NO,``!<```#3\P``%P```.OS
M```?`````_0```X````C]````P```#+T```'````-O0```@````^]```!P``
M`$?T```)````3_0```H```!9]```"P```&3T```'````</0``%$```!X]```
M$````,KT```,````V_0``!H```#H]```2@````/U```9````3O4```8```!H
M]0``&@```&_U```E````BO4```8```"P]0``!@```+?U```?````OO4```8`
M``#>]0``"0```.7U```8````[_4``!<````(]@``*````"#V```&````2?8`
M``T```!0]@``(@```%[V``!7````@?8``!,```#9]@``(P```.WV```3````
M$?<```(````E]P``"P```"CW```(````-/<```T````]]P``"@```$OW```,
M````5O<```<```!C]P``%````&OW```&````@/<```@```"']P``#@```)#W
M```'````G_<```H```"G]P``"P```++W```R````OO<```<```#Q]P``#```
M`/GW```-````!O@```P````4^```"0```"'X```)````*_@```H````U^```
M!P```$#X```)````2/@```<```!2^```"@```%KX```;````9?@``!(```"!
M^```"@```)3X```6````G_@```@```"V^```"0```+_X```0````R?@```<`
M``#:^```$@```.+X```$````]?@```<```#Z^```!0````+Y```%````"/D`
M``L````.^0``%````!KY```1````+_D``!H```!!^0``%@```%SY```4````
M<_D``!<```"(^0``&````*#Y```<````N?D``!D```#6^0``!P```/#Y```%
M````^/D```T```#^^0``#`````SZ```1````&?H```@````K^@``"````#3Z
M```7````/?H```L```!5^@``#````&'Z```?````;OH``!H```".^@``$P``
M`*GZ```$````O?H```H```#"^@``!````,WZ```,````TOH```4```#?^@``
M"0```.7Z```%````[_H```<```#U^@``!0```/WZ```$`````_L```(````(
M^P``.`````O[```L````1/L``!(```!Q^P``*0```(3[```R````KOL```H`
M``#A^P``+````.S[```N````&?P``#,```!(_```,P```'S\```X````L/P`
M``\```#I_```&````/G\```0````$OT``!P````C_0``#P```$#]```3````
M4/T``!4```!D_0``%````'K]```2````C_T``"0```"B_0``"````,?]```D
M````T/T``!,```#U_0``%`````G^```M````'OX``"T```!,_@``,0```'K^
M```N````K/X``"\```#;_@``+`````O_``!B````./\``!,```";_P``#0``
M`*__```(````O?\``!<```#&_P``"````-[_```,````Y_\``"L```#T_P``
M(0```"```0`:````0@`!``D```!=``$`10```&<``0!!````K0`!``4```#O
M``$`!````/4``0`3````^@`!`!0````.`0$`#@```",!`0`3````,@$!`!@`
M``!&`0$`!@```%\!`0`)````9@$!``H```!P`0$`#P```'L!`0`0````BP$!
M``<```"<`0$`#@```*0!`0`-````LP$!``P```#!`0$`"@```,X!`0`)````
MV0$!``H```#C`0$`#P```.X!`0`(````_@$!``\````'`@$`"````!<"`0`:
M````(`(!``4````[`@$`#0```$$"`0`;````3P(!``@```!K`@$`!@```'0"
M`0`4````>P(!`!$```"0`@$`#@```*("`0`X````L0(!``(```#J`@$`!@``
M`.T"`0`.````]`(!``4````#`P$`!P````D#`0`&````$0,!`"@````8`P$`
M#````$$#`0`<````3@,!``0```!K`P$`*0```'`#`0`?````F@,!`%P```"Z
M`P$`%````!<$`0`^````+`0!`!\```!K!`$`$````(L$`0`'````G`0!``X`
M``"D!`$`#````+,$`0`,````P`0!`!,```#-!`$`"@```.$$`0`=````[`0!
M`!D````*!0$`!0```"0%`0`1````*@4!`!$````\!0$`)````$X%`0`2````
M<P4!`!4```"&!0$`$@```)P%`0`.````KP4!`!D```"^!0$`"````-@%`0`)
M````X04!``T```#K!0$`"@```/D%`0`'````!`8!``\````,!@$`!@```!P&
M`0`+````(P8!`!H````O!@$`"@```$H&`0`'````508!``@```!=!@$`!0``
M`&8&`0`?````;`8!``8```",!@$`$````),&`0`(````I`8!``T```"M!@$`
M"````+L&`0`>````Q`8!`!(```#C!@$`+````/8&`0`:````(P<!``D````^
M!P$`"@```$@'`0`5````4P<!``4```!I!P$`%````&\'`0`$````A`<!`!``
M``")!P$`!@```)H'`0`'````H0<!`!X```"I!P$`*````,@'`0`*````\0<!
M`!P```#\!P$`$0```!D(`0`+````*P@!`!H````W"`$`%````%((`0`$````
M9P@!``0```!L"`$`"P```'$(`0`%````?0@!``8```"#"`$`"````(H(`0`&
M````DP@!`!L```":"`$`-````+8(`0`T````ZP@!`"`````@"0$`*0```$$)
M`0`@````:PD!`$$```","0$`&@```,X)`0`H````Z0D!`"D````2"@$`4```
M`#P*`0`B````C0H!``8```"P"@$`"````+<*`0`%````P`H!``@```#&"@$`
M&0```,\*`0`9````Z0H!`"H````#"P$`(P```"X+`0`9````4@L!`"X```!L
M"P$`-````)L+`0`(````T`L!`!<```#9"P$`"@```/$+`0`'````_`L!`"$`
M```$#`$`$````"8,`0`.````-PP!``L```!&#`$`!P```%(,`0`3````6@P!
M``@```!N#`$`"P```'<,`0`*````@PP!`!0```".#`$`#P```*,,`0`R````
MLPP!``L```#F#`$`!0```/(,`0`%````^`P!``4```#^#`$`%P````0-`0`/
M````'`T!``0````L#0$`"@```#$-`0`)````/`T!``L```!&#0$`#0```%(-
M`0`,````8`T!``X```!M#0$`!0```'P-`0`$````@@T!``T```"'#0$`,@``
M`)4-`0`8````R`T!`$4```#A#0$`%P```"<.`0`'````/PX!`!X```!'#@$`
M#````&8.`0`4````<PX!``4```"(#@$`%````(X.`0`&````HPX!``<```"J
M#@$`#@```+(.`0`J````P0X!``8```#L#@$`#````/,.`0`/``````\!``T`
M```0#P$`$0```!X/`0`+````,`\!`#8````\#P$`"@```',/`0`B````?@\!
M``L```"A#P$`#P```*T/`0`R````O0\!`"4```#P#P$`,````!80`0`Q````
M1Q`!`"T```!Y$`$`#@```*<0`0`%````MA`!``X```"\$`$`$P```,L0`0`2
M````WQ`!``<```#R$`$`$0```/H0`0`3````#!$!``<````@$0$`%````"@1
M`0`8````/1$!``<```!6$0$`!0```%X1`0`,````9!$!``P```!Q$0$`$@``
M`'X1`0`$````D1$!``<```"6$0$`"@```)X1`0`+````J1$!``P```"U$0$`
M#@```,(1`0`.````T1$!``4```#@$0$`!0```.81`0`N````[!$!`"8````;
M$@$`(P```$(2`0`#````9A(!`!(```!J$@$`!@```'T2`0`>````A!(!`!@`
M``"C$@$`)0```+P2`0`-````XA(!``D```#P$@$``P```/H2`0`'````_A(!
M``H````&$P$``@```!$3`0`,````%!,!`!4````A$P$`"P```#<3`0`9````
M0Q,!`"````!=$P$`$@```'X3`0`%````D1,!``H```"7$P$`%0```*(3`0`2
M````N!,!``P```#+$P$`!````-@3`0`)````W1,!``<```#G$P$`#````.\3
M`0!2````_!,!`!<```!/%`$`)````&<4`0`2````C!0!``<```"?%`$`!@``
M`*<4`0`.````KA0!``X```"]%`$`#````,P4`0`,````V10!``P```#F%`$`
M#0```/,4`0`5`````14!`!(````7%0$`$````"H5`0`/````.Q4!`!0```!+
M%0$`"@```&`5`0`;````:Q4!`!````"'%0$`"P```)@5`0`;````I!4!`&D`
M``#`%0$`&@```"H6`0`7````118!`!D```!=%@$`&@```'<6`0`E````DA8!
M`"<```"X%@$`&@```.`6`0`7````^Q8!`!L````3%P$`&0```"\7`0`?````
M21<!`!0```!I%P$`$P```'X7`0`(````DA<!``<```";%P$`"````*,7`0`)
M````K!<!`!4```"V%P$`#0```,P7`0`C````VA<!``T```#^%P$`$P````P8
M`0`(````(!@!``,````I&`$`1@```"T8`0`_````=!@!`#<```"T&`$`5P``
M`.P8`0`%````1!D!`!\```!*&0$`+P```&H9`0`*````FAD!``@```"E&0$`
M#0```*X9`0`M````O!D!``0```#J&0$`%````.\9`0!/````!!H!`"4```!4
M&@$`$@```'H:`0`@````C1H!``L```"N&@$`'P```+H:`0`=````VAH!`"4`
M``#X&@$`(````!X;`0`D````/QL!`"````!D&P$`"P```(4;`0`'````D1L!
M``T```"9&P$`#````*<;`0`7````M!L!``8```#,&P$`#````-,;`0`'````
MX!L!``D```#H&P$`$P```/(;`0`)````!AP!``0````0'`$`$````!4<`0`(
M````)AP!``@````O'`$`!````#@<`0`+````/1P!``P```!)'`$`$@```%8<
M`0`1````:1P!``P```!['`$`#P```(@<`0`'````F!P!``T```"@'`$`$```
M`*X<`0`1````OQP!`!0```#1'`$`#@```.8<`0`,````]1P!`!L````"'0$`
M+````!X=`0`3````2QT!``8```!?'0$`!P```&8=`0`3````;AT!``4```""
M'0$`!````(@=`0`7````C1T!``H```"E'0$`#````+`=`0`)````O1T!``8`
M``#''0$`"0```,X=`0`(````V!T!``D```#A'0$`"@```.L=`0`1````]AT!
M``8````('@$`#@````\>`0`.````'AX!``T````M'@$`"P```#L>`0`=````
M1QX!``L```!E'@$``@```'$>`0`<````=!X!``<```"1'@$`!@```)D>`0!D
M````H!X!``D````%'P$`!P````\?`0`F````%Q\!`#@````^'P$`&@```'<?
M`0`J````DA\!`#L```"]'P$`&````/D?`0`H````$B`!`#0````[(`$`&0``
M`'`@`0`5````BB`!``4```"@(`$`!P```*8@`0`(````KB`!``<```"W(`$`
M!0```+\@`0`'````Q2`!``X```#-(`$`"0```-P@`0`&````YB`!``@```#M
M(`$`"P```/8@`0`'`````B$!``@````*(0$`!P```!,A`0`6````&R$!``D`
M```R(0$`!@```#PA`0`+````0R$!`!````!/(0$`!@```&`A`0`<````9R$!
M`!0```"$(0$`!P```)DA`0`1````H2$!``@```"S(0$`#@```+PA`0`(````
MRR$!``4```#4(0$`$````-HA`0`0````ZR$!``8```#\(0$`&0````,B`0`*
M````'2(!`!P````H(@$`!P```$4B`0`%````32(!`!````!3(@$`%````&0B
M`0`+````>2(!``T```"%(@$`*````),B`0`8````O"(!`!<```#5(@$`!```
M`.TB`0`)````\B(!``H```#\(@$`!P````<C`0`"````#R,!``X````2(P$`
M"````"$C`0`C````*B,!`#@```!.(P$`)@```(<C`0`Q````KB,!`"<```#@
M(P$`9`````@D`0`4````;20!`%4```"")`$`.````-@D`0!*````$24!`%L`
M``!<)0$`*````+@E`0`X````X24!`"@````:)@$`+````$,F`0`F````<"8!
M`!L```"7)@$`/@```+,F`0`C````\B8!`!<````6)P$`2````"XG`0"%````
M=R<!`#````#])P$`%0```"XH`0`H````1"@!`"(```!M*`$`(@```)`H`0`@
M````LR@!`"4```#4*`$`00```/HH`0!;````/"D!`$D```"8*0$`,0```.(I
M`0`=````%"H!`!@````R*@$`*P```$LJ`0`A````=RH!`!\```"9*@$`*P``
M`+DJ`0`A````Y2H!`"<````'*P$`.@```"\K`0`=````:BL!`!$```"(*P$`
M,P```)HK`0`E````SBL!`"<```#T*P$`(````!PL`0`?````/2P!`#````!=
M+`$`:0```(XL`0`Q````^"P!`$$````J+0$`,P```&PM`0`E````H"T!`#T`
M``#&+0$`90````0N`0!-````:BX!`"\```"X+@$`+@```.@N`0`I````%R\!
M`#````!!+P$`+````'(O`0!4````GR\!`%H```#T+P$`*````$\P`0`F````
M>#`!`$@```"?,`$`2@```.@P`0`K````,S$!`!X```!?,0$`,@```'XQ`0`O
M````L3$!`"P```#A,0$`+0````XR`0`7````/#(!`"4```!4,@$`,@```'HR
M`0`I````K3(!`#X```#7,@$`(@```!8S`0!2````.3,!`"(```",,P$`)0``
M`*\S`0`+````U3,!`+$```#A,P$`10```),T`0`A````V30!`#````#[-`$`
M)0```"PU`0`<````4C4!`#$```!O-0$`!P```*$U`0`'````J34!``0```"Q
M-0$`#0```+8U`0`+````Q#4!``X```#0-0$`"P```-\U`0`%````ZS4!`!``
M``#Q-0$``@````(V`0!9````!38!``4```!?-@$`$@```&4V`0`$````>#8!
M``<```!]-@$`"````(4V`0`%````CC8!``,```"4-@$`$````)@V`0`3````
MJ38!``T```"]-@$``@```,LV`0`'````SC8!``8```#6-@$`%````-TV`0`,
M````\C8!`!@```#_-@$`!@```!@W`0`2````'S<!``P````R-P$``P```#\W
M`0`$````0S<!``8```!(-P$`!P```$\W`0`?````5S<!`#4```!W-P$`+@``
M`*TW`0`O````W#<!`!<````,.`$`(@```"0X`0`E````1S@!`"````!M.`$`
M&P```(XX`0`8````JC@!`"0```##.`$`'P```.@X`0`:````"#D!`"$````C
M.0$`(````$4Y`0`:````9CD!`#(```"!.0$`&0```+0Y`0`:````SCD!`"\`
M``#I.0$`*P```!DZ`0`?````13H!`",```!E.@$`'P```(DZ`0`:````J3H!
M`"$```#$.@$`)0```.8Z`0`F````##L!`"4````S.P$`)````%D[`0`8````
M?CL!`!T```"7.P$`)````+4[`0`8````VCL!`"(```#S.P$`+````!8\`0`O
M````0SP!`!4```!S/`$`)0```(D\`0`\````KSP!`!\```#L/`$`(P````P]
M`0`?````,#T!`"````!0/0$`&@```'$]`0`8````C#T!`"8```"E/0$`'@``
M`,P]`0`I````ZST!`!X````5/@$`,0```#0^`0`)````9CX!``P```!P/@$`
M#````'T^`0`7````BCX!`"\```"B/@$`)````-(^`0`'````]SX!``\```#_
M/@$`%`````\_`0`.````)#\!``T````S/P$`)````$$_`0`%````9C\!``<`
M``!L/P$`(@```'0_`0`E````ES\!`!H```"]/P$`'0```-@_`0`:````]C\!
M``<````10`$`QP```!E``0`+````X4`!`!P```#M0`$`%0````I!`0`&````
M($$!``D````G00$`"P```#%!`0`-````/4$!`!<```!+00$`!@```&-!`0`S
M````:D$!`!,```">00$`$P```+)!`0`'````QD$!``\```#.00$`!P```-Y!
M`0`R````YD$!``0````90@$`(0```!Y"`0`3````0$(!``P```!40@$`$0``
M`&%"`0`R````<T(!`!8```"F0@$`"````+U"`0`=````QD(!``D```#D0@$`
M"@```.Y"`0`4````^4(!``H````.0P$`'0```!E#`0`(````-T,!`!\```!`
M0P$`"````&!#`0`:````:4,!``8```"$0P$`%0```(M#`0`'````H4,!``@`
M``"I0P$`"0```+)#`0`_````O$,!``<```#\0P$`#P````1$`0`.````%$0!
M`!`````C1`$`"0```#1$`0`)````/D0!``@```!(1`$`$P```%%$`0`'````
M940!`!D```!M1`$`"@```(=$`0`7````DD0!`!0```"J1`$`"@```+]$`0`,
M````RD0!`!<```#71`$`!````.]$`0`J````]$0!``P````?10$`$0```"Q%
M`0`'````/D4!``(```!&10$`$````$E%`0`8````6D4!``L```!S10$``P``
M`']%`0`(````@T4!``8```",10$`!P```)-%`0`-````FT4!``L```"I10$`
M%````+5%`0`5````RD4!``X```#@10$`+P```.]%`0`@````'T8!`!P```!`
M1@$`%0```%U&`0`K````<T8!``P```"?1@$`,0```*Q&`0`%````WD8!`!(`
M``#D1@$`/P```/=&`0`2````-T<!``H```!*1P$`!@```%5'`0`$````7$<!
M``0```!A1P$`"@```&9'`0`3````<4<!``4```"%1P$`!@```(M'`0`&````
MDD<!``@```"91P$`!````*)'`0`,````IT<!``H```"T1P$`.0```+]'`0`N
M````^4<!`!D````H2`$`'P```$)(`0`=````8D@!`!$```"`2`$``@```))(
M`0`$````E4@!``H```":2`$`!@```*5(`0`%````K$@!``,```"R2`$`#```
M`+9(`0!%````PT@!`#(````)20$`,0```#Q)`0`:````;DD!`#0```")20$`
M*````+Y)`0!3````YTD!`#(````[2@$`&0```&Y*`0!R````B$H!`"````#[
M2@$`-0```!Q+`0`A````4DL!`$4```!T2P$`,````+I+`0`H````ZTL!`"@`
M```43`$`*0```#U,`0`F````9TP!`"4```".3`$`*````+1,`0`H````W4P!
M`"(````&30$`*P```"E-`0`P````54T!`!(```"&30$`$P```)E-`0`0````
MK4T!`'D```"^30$`"0```#A.`0"A````0DX!`',```#D3@$`?````%A/`0`K
M````U4\!`%0````!4`$`%P```%90`0`G````;E`!`!8```"64`$`%0```*U0
M`0`/````PU`!`!<```#34`$`'P```.M0`0`.````"U$!`$`````:40$`'P``
M`%M1`0`<````>U$!`%$```"840$`&@```.I1`0`4````!5(!``H````:4@$`
M!0```"52`0`&````*U(!``@````R4@$`$@```#M2`0`0````3E(!`!,```!?
M4@$`'0```'-2`0`/````D5(!``\```"A4@$`$````+%2`0`$````PE(!``D`
M``#'4@$`"0```-%2`0`'````VU(!``L```#C4@$`!0```.]2`0`+````]5(!
M``<````!4P$`!0````E3`0`4````#U,!``X````D4P$`"P```#-3`0`'````
M/U,!``@```!'4P$`#P```%!3`0`,````8%,!``D```!M4P$`"````'=3`0`,
M````@%,!``8```"-4P$`#P```)13`0`'````I%,!``8```"L4P$`%````+-3
M`0`&````R%,!``P```#/4P$`"````-Q3`0`9````Y5,!`!$```#_4P$`"@``
M`!%4`0`8````'%0!`!,````U5`$`'````$E4`0`1````9E0!``\```!X5`$`
M!````(A4`0`9````C50!``<```"G5`$``@```*]4`0`"````LE0!`!$```"U
M5`$`"0```,=4`0`&````T50!`!(```#85`$`%P```.M4`0`&`````U4!``(`
M```*50$`!`````U5`0`/````$E4!`!,````B50$`!P```#95`0`)````/E4!
M``<```!(50$`$0```%!5`0`&````8E4!`!@```!I50$`!@```()5`0`3````
MB54!`!````"=50$`$@```*Y5`0`"````P54!``8```#$50$`#````,M5`0`)
M````V%4!`!$```#B50$`(@```/15`0`'````%U8!``<````?5@$`"P```"=6
M`0`%````,U8!``4````Y5@$``@```#]6`0`+````0E8!`&`!``!.5@$`"@``
M`*]7`0`,````NE<!``H```#'5P$`!P```-)7`0`'````VE<!``<```#B5P$`
M`@```.I7`0`1````[5<!`!@```#_5P$`*P```!A8`0`:````1%@!`!T```!?
M6`$`$P```'U8`0`1````D5@!`"D```"C6`$`#0```,U8`0`;````VU@!``D`
M``#W6`$`$@````%9`0`+````%%D!``<````@60$`!0```"A9`0`2````+ED!
M``<```!!60$`!P```$E9`0`+````45D!``D```!=60$`"P```&=9`0`'````
M<UD!`!(```![60$`/````(Y9`0`)````RUD!``4```#560$`"@```-M9`0`/
M````YED!``H```#V60$`"@````%:`0`*````#%H!``H````76@$`!@```"):
M`0!9````*5H!``<```"#6@$`#````(M:`0`2````F%H!``H```"K6@$`"```
M`+9:`0`)````OUH!``D```#)6@$`"0```--:`0`&````W5H!`!T```#D6@$`
M%`````);`0`E````%UL!`"T````]6P$`0````&M;`0!$````K%L!`$0```#Q
M6P$`2@```#9<`0`G````@5P!``@```"I7`$`"````+)<`0`(````NUP!``@`
M``#$7`$`"````,U<`0`)````UEP!``@```#@7`$`#@```.E<`0`'````^%P!
M``8`````70$`!@````==`0`;````#ET!`!L````J70$`%````$9=`0`6````
M6UT!`!H```!R70$`&0```(U=`0`(````IUT!``H```"P70$`"P```+M=`0`$
M````QUT!``0```#,70$`"@```-%=`0`*````W%T!``D```#G70$`"````/%=
M`0`(````^ET!`!$````#7@$`$````!5>`0`/````)EX!``@````V7@$`"```
M`#]>`0`-````2%X!``8```!67@$`&0```%U>`0`/````=UX!`!````"'7@$`
M"@```)A>`0`S````HUX!`"L```#77@$`#0````-?`0`;````$5\!``0````M
M7P$`!@```#)?`0`A````.5\!``0```!;7P$`!````&!?`0`4````95\!`!0`
M``!Z7P$`%````(]?`0`(````I%\!``0```"M7P$`"0```+)?`0`$````O%\!
M`!(```#!7P$`"````-1?`0`(````W5\!``8```#F7P$`%@```.U?`0`7````
M!&`!``8````<8`$`#@```"-@`0`.````,F`!`!````!!8`$`$````%)@`0`(
M````8V`!``@```!L8`$`'0```'5@`0`3````DV`!`!4```"G8`$`$````+U@
M`0`/````SF`!`!,```#>8`$`#````/)@`0`$````_V`!`!4````$80$`*@``
M`!IA`0`(````16$!``P```!.80$`#@```%MA`0`2````:F$!``0```!]80$`
M"````()A`0`$````BV$!`!<```"080$`"@```*AA`0`*````LV$!`!H```"^
M80$`)````-EA`0`2````_F$!`!(````18@$`%@```"1B`0`$````.V(!`!``
M``!`8@$`!````%%B`0`0````5F(!``@```!G8@$`#P```'!B`0`;````@&(!
M``@```"<8@$`&0```*5B`0`9````OV(!`!D```#98@$`&0```/-B`0`$````
M#6,!``0````28P$`%````!=C`0`0````+&,!`"H````]8P$`(P```&AC`0`I
M````C&,!`&L```"V8P$`*````")D`0`H````2V0!`#$```!T9`$`,0```*9D
M`0`H````V&0!`"D````!90$`'````"ME`0`<````2&4!`#$```!E90$`*```
M`)=E`0`N````P&4!`!0```#O90$`"0````1F`0`,````#F8!`!`````;9@$`
M#0```"QF`0`-````.F8!``L```!(9@$`"P```%1F`0`5````8&8!``H```!V
M9@$`#@```(%F`0`$````D&8!``@```"59@$`$@```)YF`0`8````L68!`!``
M``#*9@$`#@```-MF`0`8````ZF8!`!,````#9P$`$0```!=G`0`4````*6<!
M``0````^9P$`!P```$-G`0`0````2V<!``\```!<9P$`#````&QG`0`0````
M>6<!``T```"*9P$`!````)AG`0`A````G6<!``@```"_9P$`"````,AG`0`$
M````T6<!`!(```#69P$`!````.EG`0`$````[F<!``@```#S9P$`!````/QG
M`0`M`````6@!``0````O:`$`$0```#1H`0`$````1F@!``T```!+:`$`#0``
M`%EH`0`>````9V@!`!@```"&:`$`$P```)]H`0`(````LV@!`!D```"\:`$`
M$````-9H`0`(````YV@!``,```#P:`$`"@```/1H`0`1````_V@!``\````1
M:0$`$P```"%I`0`&````-6D!``8````\:0$`$0```$-I`0`1````56D!`"8`
M``!G:0$`$0```(YI`0`:````H&D!`!(```"[:0$`#P```,YI`0`$````WFD!
M``P```#C:0$`$@```/!I`0`/`````VH!`",````3:@$`$@```#=J`0`:````
M2FH!`#$```!E:@$`&0```)=J`0`3````L6H!``@```#%:@$`"@```,YJ`0`$
M````V6H!`!D```#>:@$`"````/AJ`0`*`````6L!``L````,:P$`"@```!AK
M`0`+````(VL!``@````O:P$`%@```#AK`0`$````3VL!`"4```!4:P$`$0``
M`'IK`0`(````C&L!``H```"5:P$`"````*!K`0`+````J6L!``0```"U:P$`
M#````+IK`0`;````QVL!`!T```#C:P$`+0````%L`0`$````+VP!``T````T
M;`$`#````$)L`0`,````3VP!`!$```!<;`$`#P```&YL`0`-````?FP!``@`
M``",;`$`$@```)5L`0`-````J&P!`!(```"V;`$`&P```,EL`0`3````Y6P!
M`!D```#Y;`$`%0```!-M`0`"````*6T!``@````L;0$`%````#5M`0`(````
M2FT!``X```!3;0$`"@```&)M`0`0````;6T!``8```!^;0$`#@```(5M`0`4
M````E&T!``@```"I;0$`!````+)M`0`&````MVT!``(```"^;0$`%P```,%M
M`0`*````V6T!``@```#D;0$`$P```.UM`0`$`````6X!``8````&;@$`#@``
M``UN`0`#````'&X!``@````@;@$`!````"EN`0`$````+FX!``@````S;@$`
M!````#QN`0`$````06X!`!````!&;@$`!````%=N`0`$````7&X!``0```!A
M;@$`!````&9N`0`$````:VX!`#0```!P;@$`#0```*5N`0`'````LVX!``@`
M``"[;@$`#````,1N`0`R````T6X!``D````$;P$`"@````YO`0`;````&6\!
M`"D````U;P$`&@```%]O`0`&````>F\!`!\```"!;P$`%````*%O`0`-````
MMF\!``0```#$;P$`%P```,EO`0`$````X6\!``P```#F;P$`!````/-O`0`7
M````^&\!`!@````0<`$`%0```"EP`0`9````/W`!`!<```!9<`$`%P```'%P
M`0`2````B7`!`!0```"<<`$`%````+%P`0`0````QG`!`!8```#7<`$`(@``
M`.YP`0`4````$7$!`!,````F<0$`%0```#IQ`0`2````4'$!`!0```!C<0$`
M%@```'AQ`0`=````CW$!`!4```"M<0$`%P```,-Q`0`9````VW$!`!(```#U
M<0$`$@````AR`0`=````&W(!`!4````Y<@$`#````$]R`0`7````7'(!`!(`
M``!T<@$`%@```(=R`0`,````GG(!`$L```"K<@$`)P```/=R`0`2````'W,!
M`!0````R<P$`%````$=S`0`8````7',!``T```!U<P$`$@```(-S`0`3````
MEG,!`!$```"J<P$`%0```+QS`0`9````TG,!`!0```#L<P$`3`````%T`0`6
M````3G0!``X```!E=`$`$@```'1T`0`4````AW0!`!D```"<=`$`*@```+9T
M`0`M````X70!``8````/=0$`!````!9U`0`$````&W4!``0````@=0$`#```
M`"5U`0`,````,G4!``P````_=0$`!````$QU`0`,````474!``H```!>=0$`
M$@```&EU`0`+````?'4!``@```"(=0$`"````)%U`0`(````FG4!``P```"C
M=0$`"````+!U`0`,````N74!``H```#&=0$`'P```-%U`0`$````\74!``0`
M``#V=0$`$0```/MU`0`1````#78!`!<````?=@$`&@```#=V`0`;````4G8!
M``(```!N=@$`50```'%V`0`$````QW8!``P```#,=@$`"@```-EV`0`$````
MY'8!``@```#I=@$`"````/)V`0`$````^W8!``H`````=P$`!@````MW`0`*
M````$G<!``@````==P$`!````"9W`0`(````*W<!``X````T=P$`"@```$-W
M`0`5````3G<!``\```!D=P$`#P```'1W`0`$````A'<!``0```")=P$`"@``
M`(YW`0`(````F7<!``@```"B=P$`"````*MW`0`(````M'<!``X```"]=P$`
M#@```,QW`0`*````VW<!``@```#F=P$`$@```.]W`0`.`````G@!`"`````1
M>`$`!@```#)X`0`8````.7@!``X```!2>`$`#````&%X`0`,````;G@!`!4`
M``![>`$`"````)%X`0`.````FG@!``0```"I>`$`"````*YX`0`$````MW@!
M``0```"\>`$`'0```,%X`0`7````WW@!``0```#W>`$`"````/QX`0`6````
M!7D!``H````<>0$`"````"=Y`0`(````,'D!``0````Y>0$`$0```#YY`0`(
M````4'D!``X```!9>0$`#@```&AY`0`(````=WD!``@```"`>0$`$0```(EY
M`0`&````FWD!`!P```"B>0$`%````+]Y`0`I````U'D!`!,```#^>0$`(P``
M`!)Z`0`3````-GH!``0```!*>@$`!P```$]Z`0`<````5WH!``H```!T>@$`
M!````']Z`0`(````A'H!``0```"->@$`$@```))Z`0`$````I7H!``D```"J
M>@$`"````+1Z`0`(````O7H!``@```#&>@$`"````,]Z`0`(````V'H!``P`
M``#A>@$`#@```.YZ`0`(````_7H!``X````&>P$`#````!5[`0`$````(GL!
M``P````G>P$`%@```#1[`0`'````2WL!``@```!3>P$`#````%Q[`0`5````
M:7L!``P```!_>P$`$P```(Q[`0`(````H'L!``@```"I>P$`"0```+)[`0`)
M````O'L!``P```#&>P$`*@```--[`0`3````_GL!``@````2?`$`"@```!M\
M`0`\````)GP!`!(```!C?`$`'@```'9\`0`4````E7P!``0```"J?`$`%```
M`*]\`0`;````Q'P!`!L```#@?`$`%@```/Q\`0`7````$WT!`!4````K?0$`
M$@```$%]`0`3````5'T!``0```!H?0$`#0```&U]`0`*````>WT!``D```"&
M?0$`"@```)!]`0`)````FWT!``@```"E?0$`"@```*Y]`0`)````N7T!``<`
M``##?0$`!````,M]`0`$````T'T!``H```#5?0$`"````.!]`0`&````Z7T!
M``8```#P?0$`!````/=]`0`(````_'T!``@````%?@$`#0````Y^`0`*````
M''X!`!`````G?@$`%P```#A^`0`6````4'X!`!````!G?@$`$````'A^`0`;
M````B7X!`!````"E?@$`#````+9^`0`$````PWX!`"X```#(?@$`#0```/=^
M`0`)````!7\!``0````/?P$`!````!1_`0`$````&7\!``0````>?P$`!@``
M`"-_`0`&````*G\!``@````Q?P$`"````#I_`0`+````0W\!`!,```!/?P$`
M$0```&-_`0`(````=7\!``@```!^?P$`"````(=_`0`(````D'\!`!4```"9
M?P$`!@```*]_`0`.````MG\!``8```#%?P$`!````,Q_`0`(````T7\!``@`
M``#:?P$`!````.-_`0`"````Z'\!``X```#K?P$`"````/I_`0`$`````X`!
M`!L````(@`$`#@```"2``0!.````,X`!``H```""@`$`!````(V``0`$````
MDH`!``@```"7@`$`!````*"``0`&````I8`!``0```"L@`$`"````+&``0`&
M````NH`!``0```#!@`$`#0```,:``0`4````U(`!`!H```#I@`$`(0````2!
M`0`;````)H$!``8```!"@0$``@```$F!`0`(````3($!``0```!5@0$`!```
M`%J!`0`,````7X$!``4```!L@0$`#P```'*!`0`(````@H$!`!(```"+@0$`
M$````)Z!`0`6````KX$!``X```#&@0$`#````-6!`0`4````XH$!``0```#W
M@0$`!````/R!`0`&`````8(!``L````(@@$`"P```!2"`0`$````(((!``T`
M```E@@$`$P```#."`0`4````1X(!`!(```!<@@$`"````&^"`0`0````>((!
M`"D```")@@$`&P```+."`0`;````SX(!``0```#K@@$`%0```/""`0`+````
M!H,!`!0````2@P$`"````">#`0`(````,(,!``@````Y@P$`#P```$*#`0`@
M````4H,!``\```!S@P$`#````(.#`0`1````D(,!``P```"B@P$`"0```*^#
M`0`"````N8,!``0```"\@P$`!````,&#`0`A````QH,!``8```#H@P$`%P``
M`.^#`0`$````!X0!``0````,A`$`#@```!&$`0`$````((0!``0````EA`$`
M$0```"J$`0`"````/(0!``0````_A`$`$0```$2$`0`"````5H0!``@```!9
MA`$`!@```&*$`0`(````:80!`!,```!RA`$`$````(:$`0`%````EX0!`#``
M``"=A`$`'@```,Z$`0`L````[80!`"$````:A0$`+@```#R%`0`F````:X4!
M`"$```"2A0$`,0```+2%`0`A````YH4!`!T````(A@$`'````":&`0`&````
M0X8!``@```!*A@$`!0```%.&`0`6````688!`!4```!PA@$`#0```(:&`0`1
M````E(8!``0```"FA@$`!@```*N&`0`(````LH8!`!````"[A@$`%0```,R&
M`0`5````XH8!`!T```#XA@$`!P```!:'`0`0````'H<!`"`````OAP$`#@``
M`%"'`0`.````7X<!``8```!NAP$`"````'6'`0`*````?H<!``\```")AP$`
M,````)F'`0!I````RH<!`#X````TB`$`"0```'.(`0`(````?8@!``D```"&
MB`$`#````)"(`0`-````G8@!``@```"KB`$`!````+2(`0`1````N8@!``T`
M``#+B`$`#0```-F(`0`,````YX@!``D```#TB`$`#@```/Z(`0`3````#8D!
M`!H````AB0$`1@```#R)`0`(````@XD!``P```",B0$`"@```)F)`0`0````
MI(D!``0```"UB0$`!````+J)`0`-````OXD!`!````#-B0$`"````-Z)`0`(
M````YXD!``P```#PB0$`$````/V)`0`<````#HH!`!P````KB@$`&````$B*
M`0`8````88H!`!H```!ZB@$`&@```)6*`0`.````L(H!`!L```"_B@$`$```
M`-N*`0`0````[(H!``X```#]B@$`#@````R+`0`(````&XL!``X````DBP$`
M#@```#.+`0`,````0HL!``P```!/BP$`#P```%R+`0`-````;(L!`!$```!Z
MBP$`(0```(R+`0`)````KHL!``0```"XBP$`!@```+V+`0`;````Q(L!`!``
M``#@BP$`#P```/&+`0`/`````8P!``\````1C`$`#@```"&,`0`.````,(P!
M``T````_C`$`"P```$V,`0`0````68P!`!8```!JC`$`$P```(&,`0`-````
ME8P!`!$```"CC`$`#0```+6,`0`/````PXP!`!$```#3C`$`#P```.6,`0`/
M````]8P!`!$````%C0$`!````!>-`0`(````'(T!`"`````EC0$`#0```$:-
M`0`0````5(T!`!(```!EC0$`"````'B-`0`/````@8T!``8```"1C0$`!```
M`)B-`0`.````G8T!`!````"LC0$`!````+V-`0`,````PHT!`!(```#/C0$`
M!@```.*-`0`-````Z8T!``0```#WC0$`!````/R-`0`$`````8X!``0````&
MC@$`"`````N.`0`(````%(X!``@````=C@$`"@```":.`0`*````,8X!``P`
M```\C@$`$@```$F.`0`(````7(X!``@```!EC@$`"````&Z.`0`(````=XX!
M``@```"`C@$`"````(F.`0`H````DHX!``0```"[C@$`$P```,".`0`M````
MU(X!`!D````"CP$`#0```!R/`0`/````*H\!``H````ZCP$`"@```$6/`0`$
M````4(\!`"<```!5CP$`!@```'V/`0`,````A(\!`!(```"1CP$`!@```*2/
M`0`)````JX\!``X```"UCP$`%````,2/`0`6````V8\!`!$```#PCP$`!```
M``*0`0`(````!Y`!`!`````0D`$`!````"&0`0`(````)I`!``8````OD`$`
M$````#:0`0`2````1Y`!`!\```!:D`$`&@```'J0`0`$````E9`!``0```":
MD`$`"````)^0`0`(````J)`!``8```"QD`$`"````+B0`0`$````P9`!``8`
M``#&D`$`!@```,V0`0`$````U)`!``D```#9D`$`(````..0`0`$````!)$!
M`!\````)D0$`"@```"F1`0`,````-)$!``@```!!D0$`#P```$J1`0`-````
M6I$!`!$```!HD0$`#P```'J1`0`/````BI$!``T```":D0$`$0```*B1`0`0
M````NI$!`!(```#+D0$`%@```-Z1`0`$````]9$!`!(```#ZD0$`"0````V2
M`0`*````%Y(!``H````BD@$`!````"V2`0`$````,I(!``0````WD@$`!```
M`#R2`0`(````09(!`"T```!*D@$`"0```'B2`0`$````@I(!``0```"'D@$`
M`@```(R2`0`,````CY(!``P```"<D@$`#````*F2`0`3````MI(!``(```#*
MD@$`"````,V2`0`;````UI(!``,```#RD@$`#````/:2`0`Y`````Y,!`!<`
M```]DP$`!````%63`0`$````6I,!``@```!?DP$`#0```&B3`0`/````=I,!
M`!,```"&DP$`$P```)J3`0`+````KI,!``X```"ZDP$`(````,F3`0`*````
MZI,!``T```#UDP$`!`````.4`0`$````")0!`!(````-E`$`)````""4`0`=
M````190!`!<```!CE`$`"@```'N4`0`7````AI0!`!0```">E`$`#P```+.4
M`0`7````PY0!`!@```#;E`$`%P```/24`0`,````#)4!``P````9E0$`#```
M`":5`0`$````,Y4!`!(````XE0$`!````$N5`0`$````4)4!``@```!5E0$`
M"0```%Z5`0`*````:)4!``0```!SE0$`+@```'B5`0`+````IY4!``@```"S
ME0$`$P```+R5`0`K````T)4!`!$```#\E0$`!`````Z6`0`2````$Y8!`!H`
M```FE@$`!````$&6`0`/````1I8!`"X```!6E@$`!````(66`0`)````BI8!
M`!@```"4E@$`%P```*V6`0`4````Q98!``0```#:E@$`!````-^6`0`>````
MY)8!`#4````#EP$`$````#F7`0`<````2I<!`!````!GEP$`!@```'B7`0`(
M````?Y<!``0```"(EP$`"````(V7`0`(````EI<!``X```"?EP$`!````*Z7
M`0`?````LY<!``\```#3EP$`#P```..7`0`&````\Y<!``0```#ZEP$`"```
M`/^7`0`$````")@!`",````-F`$`!@```#&8`0`(````.)@!``@```!!F`$`
M"````$J8`0`$````4Y@!``0```!8F`$`!````%V8`0`$````8I@!``0```!G
MF`$`!````&R8`0`5````<9@!`!````"'F`$`!````)B8`0`(````G9@!``P`
M``"FF`$`"@```+.8`0`(````OI@!`!````#'F`$`#@```-B8`0`+````YY@!
M``0```#SF`$`$@```/B8`0`,````"YD!``X````8F0$`$@```">9`0`C````
M.ID!`!4```!>F0$`%0```'29`0`5````BID!`!$```"@F0$`$0```+*9`0`7
M````Q)D!`!,```#<F0$`$0```/"9`0`(`````IH!``0````+F@$`'````!":
M`0`(````+9H!``D````VF@$`!````$":`0`(````19H!`!4```!.F@$`%```
M`&2:`0`&````>9H!`!$```"`F@$`#0```)*:`0`/````H)H!``0```"PF@$`
M"````+6:`0`&````OIH!``H```#%F@$`!@```-":`0`4````UYH!``P```#L
MF@$`$@```/F:`0`$````#)L!``T````1FP$``@```!^;`0`9````(IL!`!H`
M```\FP$`#0```%>;`0`:````99L!`"$```"`FP$`"0```**;`0`;````K)L!
M`!<```#(FP$`'````.";`0`;````_9L!`"`````9G`$`"P```#J<`0`+````
M1IP!``H```!2G`$`%@```%V<`0`+````=)P!`!````"`G`$`$0```)&<`0`+
M````HYP!``L```"OG`$`%P```+N<`0`(````TYP!`!4```#<G`$`#@```/*<
M`0`+`````9T!`!L````-G0$`&P```"F=`0`?````19T!`!P```!EG0$`'0``
M`(*=`0`:````H)T!`$@```"[G0$`$P````2>`0`.````&)X!``8````GG@$`
M%0```"Z>`0`&````1)X!``@```!+G@$`$P```%2>`0`7````:)X!`!<```"`
MG@$`!@```)B>`0`K````GYX!`"T```#+G@$`!@```/F>`0`"`````)\!`!$`
M```#GP$`%@```!6?`0`9````+)\!``8```!&GP$`&````$V?`0`-````9I\!
M``8```!TGP$`!@```'N?`0`,````@I\!``T```"/GP$`!@```)V?`0`(````
MI)\!``@```"MGP$`"````+:?`0`(````OY\!``@```#(GP$`"@```-&?`0`+
M````W)\!``@```#HGP$`#0```/&?`0`&````_Y\!`!<````&H`$`!@```!Z@
M`0`(````):`!`!(````NH`$`!@```$&@`0`$````2*`!``8```!-H`$`"```
M`%2@`0`$````7:`!`!D```!BH`$``@```'R@`0`$````?Z`!``H```"$H`$`
M!@```(^@`0`$````EJ`!``8```";H`$`%P```**@`0`&````NJ`!``P```#!
MH`$`"P```,Z@`0`C````VJ`!`!,```#^H`$`)@```!*A`0`.````.:$!`"T`
M``!(H0$`$@```':A`0`(````B:$!``0```"2H0$`!@```)>A`0`(````GJ$!
M``0```"GH0$`"````*RA`0`$````M:$!`!````"ZH0$`%````,NA`0`$````
MX*$!``@```#EH0$`"@```.ZA`0`-````^:$!`!`````'H@$`#````!BB`0`,
M````):(!``P````RH@$`%@```#^B`0`*````5J(!``@```!AH@$`"````&JB
M`0`(````<Z(!``@```!\H@$`"````(6B`0`&````CJ(!``@```"5H@$`%```
M`)ZB`0`*````LZ(!``0```"^H@$`$P```,.B`0`,````UZ(!`#````#DH@$`
M#P```!6C`0`A````):,!`!$```!'HP$`!````%FC`0`$````7J,!``T```!C
MHP$`"@```'&C`0`=````?*,!``@```":HP$`!0```*.C`0`&````J:,!``T`
M``"PHP$`!````+ZC`0`$````PZ,!``0```#(HP$`"@```,VC`0`$````V*,!
M``8```#=HP$`#````.2C`0`3````\:,!``0````%I`$`$P````JD`0`(````
M'J0!``0````GI`$`"````"RD`0`$````-:0!``L````ZI`$`!````$:D`0`4
M````2Z0!``0```!@I`$`!````&6D`0`(````:J0!``0```!SI`$`$````'BD
M`0`3````B:0!`!L```"=I`$`%0```+FD`0`5````SZ0!`!@```#EI`$`)@``
M`/ZD`0`5````):4!`!$````[I0$`&@```$VE`0`N````:*4!`!,```"7I0$`
M#0```*NE`0`$````N:4!``0```"^I0$`$0```,.E`0`(````U:4!``@```#>
MI0$`*P```.>E`0`6````$Z8!``X````JI@$`*0```#FF`0`O````8Z8!``0`
M``"3I@$`#````)BF`0`&````I:8!``0```"LI@$`$@```+&F`0`*````Q*8!
M``@```#/I@$`"````-BF`0`$````X:8!``@```#FI@$`!````.^F`0`(````
M]*8!``@```#]I@$`#`````:G`0`,````$Z<!`!H````@IP$`%@```#NG`0`,
M````4J<!``0```!?IP$`"````&2G`0`6````;:<!``8```"$IP$``@```(NG
M`0`&````CJ<!``8```"5IP$`!````)RG`0`&````H:<!``8```"HIP$`"```
M`*^G`0`$````N*<!``0```"]IP$`"````,*G`0`E````RZ<!`!````#QIP$`
M,@````*H`0`(````-:@!``@````^J`$`%0```$>H`0`(````7:@!`!4```!F
MJ`$`"@```'RH`0`*````AZ@!``0```"2J`$`!````)>H`0`*````G*@!`"@`
M``"GJ`$`!````-"H`0`(````U:@!``@```#>J`$`"````.>H`0`(````\*@!
M``8```#YJ`$`)P````"I`0`$````**D!`!0````MJ0$`"@```$*I`0`.````
M3:D!`!<```!<J0$`$0```'2I`0`:````AJD!`!<```"AJ0$`%0```+FI`0`(
M````SZD!``0```#8J0$`"````-VI`0`-````YJD!`!````#TJ0$`!`````6J
M`0`(````"JH!``X````3J@$`$@```"*J`0`(````-:H!``X````^J@$`!```
M`$VJ`0`$````4JH!``@```!7J@$`!@```&"J`0`+````9ZH!``0```!SJ@$`
M$@```'BJ`0`+````BZH!`!````"7J@$`$````*BJ`0`&````N:H!``8```#`
MJ@$``@```,>J`0`$````RJH!``P```#/J@$`"````-RJ`0`&````Y:H!``0`
M``#LJ@$`&P```/&J`0`/````#:L!``\````=JP$`%@```"VK`0`.````1*L!
M``0```!3JP$`"@```%BK`0`*````8ZL!``0```!NJP$`#````'.K`0`&````
M@*L!`!<```"'JP$`+````)^K`0`6````S*L!`!D```#CJP$`,P```/VK`0`2
M````,:P!`!(```!$K`$`%0```%>L`0`H````;:P!``H```"6K`$`&P```*&L
M`0`$````O:P!``D```#"K`$`!P```,RL`0`(````U*P!`#@```#=K`$`#P``
M`!:M`0`7````)JT!``@````^K0$`!````$>M`0`$````3*T!``@```!1K0$`
M"````%JM`0`(````8ZT!``H```!LK0$`"````'>M`0`,````@*T!`!0```"-
MK0$`$@```**M`0`4````M:T!``X```#*K0$`%@```-FM`0`(````\*T!`!$`
M``#YK0$`#`````NN`0`&````&*X!`!,````?K@$`0P```#.N`0`-````=ZX!
M`!$```"%K@$`#0```)>N`0`-````I:X!`!$```"SK@$`%0```,6N`0`-````
MVZX!`!$```#IK@$`%P```/NN`0`0````$Z\!``T````DKP$`#````#*O`0`,
M````/Z\!``@```!,KP$`$@```%6O`0`(````:*\!``0```!QKP$`+````':O
M`0`$````HZ\!`!L```"HKP$`"````,2O`0`/````S:\!``0```#=KP$`"```
M`.*O`0`H````ZZ\!`"$````4L`$`(P```#:P`0`Z````6K`!``0```"5L`$`
M#````)JP`0`<````I[`!`!,```#$L`$`!````-BP`0`(````W;`!`"$```#F
ML`$`!`````BQ`0`-````#;$!`!\````;L0$`(````#NQ`0`0````7+$!`!(`
M``!ML0$`"@```("Q`0`4````B[$!`!4```"@L0$`%@```+:Q`0`4````S;$!
M`!(```#BL0$`%````/6Q`0`(````"K(!``@````3L@$`"````!RR`0`(````
M);(!``H````NL@$`!````#FR`0`7````/K(!``0```!6L@$`!````%NR`0`(
M````8+(!`!(```!IL@$`!````'RR`0`(````@;(!`!,```"*L@$`%0```)ZR
M`0`"````M+(!``0```"WL@$`!````+RR`0`(````P;(!``@```#*L@$`"@``
M`-.R`0`<````WK(!`!(```#[L@$`!@````ZS`0`*````%;,!``X````@LP$`
M#````"^S`0`(````/+,!`!,```!%LP$`$0```%FS`0`L````:[,!``8```"8
MLP$`!@```)^S`0`$````IK,!``H```"KLP$`#@```+:S`0`(````Q;,!``P`
M``#.LP$`"````-NS`0`(````Y+,!``8```#MLP$`!````/2S`0`4````^;,!
M``0````.M`$`"@```!.T`0`(````'K0!``(````GM`$`!````"JT`0`(````
M+[0!``0````XM`$`!@```#VT`0`&````1+0!`!@```!+M`$`"@```&2T`0`&
M````;[0!`!$```!VM`$`!````(BT`0`$````C;0!`#\```"2M`$`!````-*T
M`0`$````U[0!`!D```#<M`$`)0```/:T`0`/````'+4!`!@````LM0$`)0``
M`$6U`0`/````:[4!`!4```![M0$`&````)&U`0`/````JK4!``\```"ZM0$`
M#````,JU`0`$````U[4!``0```#<M0$`!````.&U`0`"````YK4!``0```#I
MM0$`"0```.ZU`0`&````^+4!``0```#_M0$`!@````2V`0`$````"[8!``0`
M```0M@$`$0```!6V`0`$````)[8!`!8````LM@$`%````$.V`0`-````6+8!
M`!(```!FM@$`#@```'FV`0`,````B+8!`!0```"5M@$`'0```*JV`0`$````
MR+8!``@```#-M@$`!````-:V`0`,````V[8!`!````#HM@$`!````/FV`0`(
M````_K8!``@````'MP$`!````!"W`0`$````%;<!`!4````:MP$`)P```#"W
M`0`%````6+<!``@```!>MP$`"````&>W`0`2````<+<!``0```"#MP$`!@``
M`(BW`0`A````C[<!`!````"QMP$`"````,*W`0`$````R[<!``8```#0MP$`
M"````->W`0`,````X+<!``8```#MMP$`#@```/2W`0`/`````[@!`!@````3
MN`$`(0```"RX`0`4````3K@!`!P```!CN`$`%@```("X`0`[````E[@!``8`
M``#3N`$`)@```-JX`0`?`````;D!`"@````AN0$`.@```$JY`0`/````A;D!
M`!L```"5N0$`'0```+&Y`0`=````S[D!`!,```#MN0$`$0````&Z`0`9````
M$[H!`!4````MN@$`!@```$.Z`0`P````2KH!`&4```![N@$`'@```.&Z`0`+
M`````+L!`!X````,NP$`%P```"N[`0`7````0[L!`!<```!;NP$`#P```'.[
M`0`O````@[L!`#$```"SNP$`+P```.6[`0`5````%;P!``@````KO`$`!@``
M`#2\`0`9````.[P!`!<```!5O`$`%P```&V\`0`6````A;P!`!,```"<O`$`
M$P```+"\`0`=````Q+P!``@```#BO`$`!@```.N\`0`?````\KP!`!,````2
MO0$`&0```":]`0`8````0+T!``T```!9O0$`$0```&>]`0!"````>;T!`"0`
M``"\O0$`)0```.&]`0`?````![X!`!P````GO@$`)````$2^`0`Y````:;X!
M`"\```"CO@$`%P```-.^`0`;````Z[X!`!\````'OP$`(@```">_`0`>````
M2K\!`#@```!IOP$`,0```**_`0`<````U+\!`!P```#QOP$`*P````[``0`I
M````.L`!`"````!DP`$`#P```(7``0`E````E<`!`!X```"[P`$`'@```-K`
M`0`;````^<`!`!$````5P0$`&0```"?!`0`;````0<$!`!L```!=P0$`)```
M`'G!`0`/````GL$!`#T```"NP0$`%0```.S!`0`3`````L(!``@````6P@$`
M:@```!_"`0`S````BL(!`!,```"^P@$`+0```-+"`0`7`````,,!``\````8
MPP$`)````"C#`0`"````3<,!``@```!0PP$`!````%G#`0`(````7L,!``@`
M``!GPP$`"````'##`0`+````><,!``0```"%PP$`#P```(K#`0`&````FL,!
M`$L```"APP$`!````.W#`0`+````\L,!``L```#^PP$`!P````K$`0`$````
M$L0!``P````7Q`$`!````"3$`0`1````*<0!``X````[Q`$`!@```$K$`0`&
M````4<0!`!(```!8Q`$`#P```&O$`0`5````>\0!``P```"1Q`$`&````)[$
M`0`/````M\0!``X```#'Q`$`#````-;$`0`$````X\0!``4```#HQ`$`#P``
M`.[$`0`0````_L0!`!(````/Q0$`'P```"+%`0`>````0L4!`!\```!AQ0$`
M#@```('%`0`6````D,4!`!D```"GQ0$`%````,'%`0`2````UL4!`!(```#I
MQ0$`%P```/S%`0`2````%,8!`!(````GQ@$`%P```#K&`0`8````4L8!`!$`
M``!KQ@$`'0```'W&`0`1````F\8!`!$```"MQ@$`&@```+_&`0`1````VL8!
M`!(```#LQ@$`%@```/_&`0`7````%L<!`!(````NQP$`%P```$''`0`5````
M6<<!`!,```!OQP$`$````(/'`0`1````E,<!`!(```"FQP$`%P```+G'`0`2
M````T<<!`!(```#DQP$`#P```/?'`0`F````!\@!`"D````NR`$`#@```%C(
M`0`6````9\@!`"<```!^R`$`&````*;(`0`6````O\@!`!X```#6R`$`'P``
M`/7(`0`8````%<D!`!,````NR0$`$@```$+)`0`7````5<D!`"(```!MR0$`
M%@```)#)`0`@````I\D!``0```#(R0$`"````,W)`0`(````ULD!``0```#?
MR0$`'@```.3)`0`;`````\H!``8````?R@$`#@```";*`0`G````-<H!`!4`
M``!=R@$`%````'/*`0`D````B,H!``0```"MR@$`!@```++*`0`E````N<H!
M`"0```#?R@$`#P````3+`0`7````%,L!`!(````LRP$`!@```#_+`0"-````
M1LL!``@```#4RP$`,````-W+`0`.````#LP!``0````=S`$`!P```"+,`0`*
M````*LP!``L````US`$`#P```$',`0`$````4<P!`",```!6S`$`#````'K,
M`0`,````A\P!`!````"4S`$`#@```*7,`0`(````M,P!`#4```"]S`$`!@``
M`//,`0`?````^LP!``H````:S0$`"@```"7-`0`*````,,T!`!T````[S0$`
M$````%G-`0`*````:LT!`!<```!US0$`"P```(W-`0`(````F<T!``\```"B
MS0$`%0```++-`0`1````R,T!``0```#:S0$`$@```-_-`0`&````\LT!`!@`
M``#YS0$``@```!+.`0`(````%<X!`!(````>S@$`!````#'.`0`4````-LX!
M`"0```!+S@$`!````'#.`0`(````=<X!``@```!^S@$`"````(?.`0`%````
MD,X!``8```"6S@$`#P```)W.`0`/````K<X!``<```"]S@$`#````,7.`0`*
M````TLX!`"8```#=S@$`(P````3/`0`&````*,\!``@````OSP$`'0```#C/
M`0`$````5L\!`!L```!;SP$`#0```'?/`0`1````A<\!``0```"7SP$`!@``
M`)S/`0`(````H\\!``P```"LSP$`$````+G/`0`$````RL\!``0```#/SP$`
M!````-3/`0`$````V<\!``D```#>SP$`"````.C/`0`1````\<\!`!(````#
MT`$`&0```!;0`0`C````,-`!``\```!4T`$`#P```&30`0`6````=-`!`!T`
M``"+T`$`"````*G0`0`B````LM`!``0```#5T`$`$P```-K0`0`C````[M`!
M``@````2T0$`"````!O1`0`%````)-$!``@````JT0$``@```#/1`0`&````
M-M$!``@````]T0$`!0```$;1`0`&````3-$!``0```!3T0$`"````%C1`0`$
M````8=$!``H```!FT0$`"@```''1`0`X````?-$!`#````"UT0$`$P```.;1
M`0`3````^M$!`!4````.T@$`#0```"32`0`"````,M(!``(````UT@$`#```
M`#C2`0`$````1=(!``P```!*T@$``@```%?2`0`+````6M(!`#T```!FT@$`
M&0```*32`0`?````OM(!``L```#>T@$`(0```.K2`0`A````#-,!`"4````N
MTP$`'P```%33`0`+````=-,!`%,```"`TP$`%P```-33`0!!````[-,!`"@`
M```NU`$`(0```%?4`0`<````>=0!`!\```"6U`$`%0```+;4`0`5````S-0!
M`!4```#BU`$`%0```/C4`0`5````#M4!`!,````DU0$`%P```#C5`0`B````
M4-4!`!X```!SU0$`$````)+5`0`7````H]4!``@```"[U0$`4P```,35`0`(
M````&-8!`%8````AU@$`+0```'C6`0!1````IM8!`!L```#XU@$`-@```!37
M`0`3````2]<!`!D```!?UP$`$P```'G7`0`.````C=<!``D```"<UP$`#P``
M`*;7`0`8````MM<!``L```#/UP$`&P```-O7`0`/````]]<!`!(````'V`$`
M.@```!K8`0`/````5=@!``\```!EV`$`%0```'78`0`,````B]@!``\```"8
MV`$`$0```*C8`0`*````NM@!``H```#%V`$`"P```-#8`0`2````W-@!`!0`
M``#OV`$`!@````39`0`,````"]D!``@````8V0$`!@```"'9`0`*````*-D!
M``8````SV0$`"````#K9`0`&````0]D!``@```!*V0$`!@```%/9`0`&````
M6MD!``T```!AV0$`"P```&_9`0`*````>]D!``8```"&V0$`!@```(W9`0`-
M````E-D!``P```"BV0$`"@```*_9`0`&````NMD!``8```#!V0$`!@```,C9
M`0`/````S]D!``8```#?V0$`!@```.;9`0`-````[=D!``@```#[V0$`!@``
M``3:`0`&````"]H!`!`````2V@$`#````"/:`0`$````,-H!``X````UV@$`
M"````$3:`0`2````3=H!``P```!@V@$`"@```&W:`0`$````>-H!`!,```!]
MV@$`!````)':`0`#````EMH!``(```":V@$`$@```)W:`0`$````L-H!`!``
M``"UV@$`#0```,;:`0`,````U-H!``,```#AV@$``@```.7:`0`$````Z-H!
M``D```#MV@$`"0```/?:`0`&`````=L!``H````(VP$`!@```!/;`0`(````
M&ML!``0````CVP$`$````"C;`0`$````.=L!``P````^VP$`"````$O;`0`3
M````5-L!``(```!HVP$`!````&O;`0`(````<-L!``8```!YVP$`#````(#;
M`0`:````C=L!``0```"HVP$`!@```*W;`0`*````M-L!``4```"_VP$`!0``
M`,7;`0`%````R]L!`!````#1VP$``0```)$'``#K````W`4``,D&````````
M`````,$#````````\00```````!2!```CP8``/4&``";`````````)`&````
M````BP8``/0```#``@````````````#M`@``JP0``+H'``#;````````````
M``"T!0``=0$```````!J!````````(8%``#&````^`0``.T````Y`0``M08`
M`-0#``"I!0```````$4"```M!P```````/`!``"M`@```````!\&``#X!@``
MF0````````!0`0``V`,``&$$``"L!P```````````````````````"4%``#=
M`P``60$``(H!``!N`@````````````!4`0``%P4```````!Z`@``'`0``#`"
M````````-04```````#/`P``H@,``$4!``!(````R`8``&(`````````G`(`
M`)T#``">!```!`0``&P!```5`@``'@```/8$``#X````P`8``'L!``#'!0``
M``````````"9!@```````+(!````````\@,``/4#``"0!```L0<``+X`````
M````8@0``,4&``#V`P``X@```"H%```9!@``50$``%8$``#-!@``)@0```,#
M````````````````````````5````-\&``!``0```````.\%``!P`0``R`$`
M``````"U`@```````$4'``"5````J@$``)<&``!-````R@4``"$!````````
M80<``(8#``"I`P``(0````````!T!@```````.D#```5````MP0```````#T
M`0``F`4````````3````_0(``)`"``![`P``"P,``+X%``"0`0``H`0```X'
M`````````````%D$````````````````````````W`8``+,&``#J!0``````
M`(P#```9`@``RP4``#4$```+`@``Q@$``,X````L`0``+04```````"%!```
MFP8``&P`````````R`````````"&!@``W`$``!`````4````<00```````!`
M!`````````````#F`P``````````````````\`8``*X'```````````````"
M``"T`P``40$``)@```!&!P``+```````````````30<``$\```#,`P``````
M`/8%```O!@```````#,#``````````````H%``""!@``S00````````W`0``
M/P<```T$````````HP0``'(%```D````J0$``(L#`````````````.D%``#\
M!@``D`4``,0%````````<P4``$4```!D`P``SP$```0&``#2!```KP8``),%
M``#%`0```````!@```"K`P``J00``+4```"X!@``90```.H#```G`@``````
M`$@$``"K````H@8``/X%``!#!@``$@<``)8!````````%@8``&4"````````
M>`8``/P!````````G08``"H"``#G!```KP4````````+!````````'$"```"
M!0````````````#,!```:@8``/L&``#Z!````````*`&``#-`@``L@8`````
M``"M!@``*`$``&`#``#`!0``]@```'P#`````````````.8`````````````
M``@#``!&!```G`0``!@$``"Z!0``JP8``!,"```>!```EP<``),'``!*`P``
M^P$``(<'````````!00````````>!@``'`<``%H%````````+P0``$``````
M``````````````#N`0``/`0``!<&``"!!```/P$``+$#```9!```XP```','
M````````V0````````#5!@``80$``*8```"R`@````````````"Y!@``[P$`
M``D!``!<`0``^`(``*$```")!```500``$H$```>`@``J@<```,'``"7````
MO`$``#P%``#+``````````````"W`P```@$````````R`@``#P4``),$````
M````6````/("``#O````%P,``&H```#=!```7`0``+H&``"1!```#0```$X'
M``!W!@``5`8```````!N````%0,``$,```"*`P``"`(``&\'``!$`P``TP,`
M`'4`````````4@,```````#K!@``AP$``*<'```R`P``3P(``%H"``"\!```
ME`0```````")!@``E08``)D'``!?`0``+`8```,"``!P!0``/````/8&``!(
M!P``\P0``+L&``!<`P``W04``(T!````````*0(``-$%````````````````
M```M!@``>P(```````!,`P````````````!%!@````````````!'`P``U0,`
M``````"B!0``.@8``+H"``"+````R@(``&(#``",!P``)@4``((`````````
MPP0``"0$``"?`0```````*0#````````VP4```````````````````T!``#A
M!0``+0$``"L````E`P````````0#``#9`P```````(,%``#`!```O`<`````
M``"_!0``G@4````````%`0````````````#*`0``G@,`````````````D`<`
M`!\$`````````````*`!````````J`<```````#A`P```````+X&```N`@``
M`````-,%``#"`0``#`$```````!(!0``:P$``(0```!Z`0``50,``#D"```G
M!0``C@4``/H%``"T`@```````%L$```2`P``I@$``$0'``!"`0``!08``&T&
M````````'P,``*P$``#O!```QP,``/D!````````AP(````````1!0``NP$`
M`)@&``!'`0````````````!T`@```@8``'<#``!G!0``AP0``*T```!_!@``
M8`<`````````````A@(``.($``#H````M@$```````"!!0``.P,``!`$````
M````&P```.L!``"0`P``7@,``"<!``!3`0```````$8%``!O````,@``````
M``"E`P```````*T$``"]`P``E04``)\"``!X`P``50``````````````^0,`
M```````\`@``A0,``'H%``!E!0``I`$```````"G`P``^04``/@#``""!```
M40,``",%````````GP,````````M````7P4`````````````Y`$``%<#```:
M!@``?`4``,4`````````$@0``$L$``!J`P``M@(``*P"``"G`0``$08`````
M``!\!```#`0``#8$```>`P``I00``$8```!]!```VP(``.`#```4!```$`(`
M`#<#``#,!@````````````"O`P```````/D```![!```HP<``!8#``!3`@``
MI0$``,0#``#3`@``9`$```````#/!```Y@$``'T'``!?!```!@8``"(!````
M````W`````,!``#5````=P0```````!G!P```````)L#``"!!@``<````+8&
M```[!@``L08``%T'````````^P4````````-!P``+`,````````)!```:P(`
M`)(!``!2!0``OP$``)T```!3!P``;P8``)<"`````````````%0%````````
M.08```\"``#O`@``_@8``-X#``!.!```8@8``#<````Y````(P,````````Z
M!P``;@4``*0%`````````````#T"``!X`0```````$P```"%!@``J@8``$$#
M``!8`@``=@$``%@%````````````````````````?P,``&D%````````L```
M`*<%````````2P,``-H!`````````````,T`````````+P(```L!```Q!```
M`````'@```!X`@``P0$``*4"```Y!0```````.<&``````````````````#_
M`@```````$$!````````\`0``$0$```K`0``900````````!!0``'`4``!H$
M``"9`@``@@,```````";`@``O`4`````````````HP```(<&``!(!@``;@0`
M`+T%```U!P````````````#I!```50<````````L!P``P0```/D$``#<!```
MJ@```#\$``#[!```[`,`````````````?0```#D#``"T!```2P8``/(%``#W
M`@``,P<``!L$```U`0```````'P"````````-@(``.4%``"]!P``OP,``&@!
M``#;!@```````&@```"V!````````"("``"W!@``7P8``/4%````````4P0`
M`,\"```/!```00(``%8"``"U!````````"T"````````F`0```````#_!0``
M```````````2````F@$``-4%```)`P``-0(``#,$``#+`0``/@4``%D"``!Z
M`P``FP0``$P'``!)!@``(`4``````````````````/,```#8!0``;@<``.$$
M``"M`P``004``%T````7`0```````*,&``!F!@``D````"$"```A`P``;`<`
M`+`"``!>!````````)8&```3!@``GP8``.D`````````8P0``)(#```A!@``
M`````)L%``!7!P``O`8``"D%```/`P``.`$``+`'``````````````````!^
M`0````````````#)!0``L04`````````````90,``*T%``""!0```````'@%
M````````B`<`````````````_`0``+('```S`@```````#T'``#U`0``2@``
M`%H!``!R`@``]`8``$$'``"!`````````*("``!/`P``$00``(T'``!T`0``
MBP$`````````````[0,``"D!``#2`0``LP$```````!;!0```P0``$H%```K
M!0``J`4`````````````!@(``)@!````````S````$4$````````````````
M```H!0````````````"]`0``?08``/4$```^!@``N`<``*0$``#H`@``.P<`
M```````Z`@``/0$``*\'``#P!0```````"@&``#D!@``F@8``(H%```4`0``
M`````&D"```K!```A`4``!@%```C!P``M0,``,\%``"B`0``&0$``$P$````
M`````````!H!````````+`4``!4'``"9!0``604``$<&``"+!P```````,`!
M``"X!0``````````````````=04``#H```#'!@```````(H&````````@`4`
M`-$!``#7`@``=@0``'L&``!F`0``[`0``%@$``":!0``"04```````!;`@``
M7@4``*X#```R!0``>0<``$,"`````````````(<%```R!@``0P0``-<#````
M````=@<``*L'```G!P``G`<``'`&``"D`@``N`$```,```#@!```B@(`````
M``#M`0``S0,```````!?!P``Q@4```````#D`P```````%8#``"5!P``;`0`
M`!$#``"F!@``O08``&`$``"?!```4P4```````#6`@````````<!``##!@``
MXP0``"H!`````````````$`&``!.````6`$``-$"```@!P```````&X#``#`
M!P``)@8````````C!```CP$``#X#``"H`0``3@$```@!``"3!@``]P,``$<"
M``!-!@```````(@`````````R@,``,4#``````````````````!<!0``]@(`
M``````!'!```O00``'(&``"X`P``O@$``&0```![!P``WP4``,<$````````
MW0```#0"``"%`0```````%<&``"4!P``=0(``#8#```T```````````````5
M!`````````0`````````U@``````````````30(``&8$``#2````40<``'D!
M```[`@```````#L`````````>@````X#``"A!0``&0<`````````````````
M``````#G`P```````+D"``""!P``T00``#P!```_`P``!@```,@%```)!P``
M4P````````!$`@``]`,````````=!P``)08``"(#````````_P$``'4$``"[
M`@``C@```.T$``!-`P``G`,``+0'``!"!```-`<````````7!P``XP(``',"
M``!O!```!0<``*X!``!=!@``70$``.$!```I````8P(``&,&``!G`@``X0(`
M``D"``#;`P``7`(``,("``#-!0``[@```,8$``!``@``\0,```````![````
M`````(0!``!0!0``^@(```````"=`0```@,``,L$``!S!```````````````
M````2P4``"<$````````S@8````````X`P``6@<```````!_!0``6`8`````
M```,!P```````.X"```````````````````A!P``M0$``($'````````[`4`
M`&<&``````````````````!P`P``P04``+H$````````2`(``'$!````````
MS`(````````'`P``U`0``!0%``!-`0``Y@(``/<%```B!@``"0`````````,
M`P``V`8``&T"``!:````DP,``*,%``!Y`````````#4&``!H`P```````+X#
M``"@!0``(`````````"$`@``M@<``,$$``#^`@```````(P$``#"`P``````
M`+L#````````;P,``+,```!I`0``4`0``````````````````(H$``".`P``
MV04```````#\`P``,08``%X"``!1!@``-P(``/P"``!F!0```````&(%```E
M!P``80,``$D"``#)`0``Q@8``(8'`````````````'4'``!V!0``U`8``#``
M``#E`0``'0(``$L````X!@``_`4```````#.`@``T`8```````"W!P``40``
M`,,#``#U`````````+D!```D`P``N@$``*P&``"C`0```````)$#````````
M!P8``!L&``"X````N00``&`!````````E@,``!,$``"V````AP```#P&``!_
M````_0$``#(!``!W!0``*P8``$D!``"#`@```````'`"``"4!0```````/0$
M``"+!```,0$````````=!```%0$``(`"``#E`````````-8$``#'`@``````
M`'\"````````Z`,``%T$````````TP0````````;!P``\P$``,0"``!/!P``
M7````)D#``"F`P``_P,```````!.!0``:P8``#,!``#S`P``=08``%````!/
M!`````````````!"````V@4`````````````I08````````Z!```9P,```\&
M```;!0``6P```',```"_`@``-`,``(("`````````````#T%```Q!0``.@,`
M````````````W@8``%`#```<`@``U@$````````+!0``\@0``,\```"\````
M/@````````#N!0``\```````````````3@8``%,&````````D@8``),`````
M````Q04``'0%``"_!```(`(``-0!``!H!P``E00```````"P`0``+@8`````
M````````-P4``+<```!J`0``X08``-H```#L````-@8```````"P!```<P$`
M`+D'``!\!@``3`$``#P'``#B`0``1P4````````3`P`````````````H`@``
M"@,```````!+`0``#P<``!8````0!0```````%L'````````;`8``)H"````
M````60<``&0&``"G!```#@4``'D#```J!P``O`,``$L"````````)P```&T#
M``#8````H@0``(\$```T!0``E@````````"E!P```````",`````````F`,`
M`!@"```K`P``YP4```````!Y!@```````"4"````````]@$``#X$```0!@``
M```````````*!P``H0,``*T'``!:!@``.00``$D'`````````````(4`````
M````1@(``'X%``#2!0```````*$&`````````````*`"``"H!@``@`8``-L!
M````````)@<``%\```"$!P````````````",`0``608``'T!``#=`@``"@8`
M`*T!````````MP(```````"-!@``YP```)<$``"%`@``CP(``(T$``!Q!P``
MI04``+(#``!(`0``:@<```````!O`0``/00```P&``#*!```9@,``#\&``#Z
M````;`,```@$``#_!````````$<'``"[!```0@4``%T"``")`0``-`8``,`#
M```<`0```````!\"``!R!````````+@$````````R00``&8"````````````
M`%<"```7````+`0``%P&``!"`P``G`8``,0&```D`0```````$$```##`0``
M```````````E!```U@,``),!``!K!0``C0(``````````````````+0!``#2
M`@``5`<``'<'```H````<0,``#<'`````````````%0#``#?`````````"X%
M``";`0``#P$````````P!@``#0,``&`%```-`@``\P4``.`!````````````
M`)H'``"``P``5@4````````(`````````*X```!#!P``'0$``!T`````````
M````````````````)@,``"4````$!0``````````````!P```````+0````D
M!P``7P(``!8%```R!P``0P4``"H$```!`0``G@$``+D#`````````````+4%
M```7`@``!P0``#0$``"2`@``UP8````````9`P``&@```-<%```_!0``````
M`&D#``!,`@````````````!2!P``<08``"(````\`P``#`(``%\#````````
MI@(``-H$```(!P````````````!B`0``=0,``!\'``"6!P```````(8$````
M````"P```!H%``"7`0````````8$```:`P``H`<``(P"``#J!````````(T`
M``#J`0````````````!7!````````&L$````````<@$``*0&````````KP$`
M````````````2P<``"('``#R`0``W`,``$H"````````W@(```````"F!```
M`````'0#``"P!@``````````````````G@<```````#7``````````````#<
M`@``&`8```````!4!```.P4``*P#```/````V@,``*\$``!P!```1`$`````
M``#B!0``.`0``&T!``":````-P0````````,!0``BP4``,L"```J!@``````
M`'0```!C````X`(``'8&``"V!0``:P<``!@!``!>`0```````)$!```<`P``
MW0$``+`#``#K`@```````(D'``#@!0```P4``%8!``!!!@``,P```*D'``!C
M!0``^@8```````#1````J`(``&,#``"8!P``0P$```````"?!P``\`(``&T'
M``#_!@``$0(``'X$````````K@(````````)!@``U@8```````"(!0``=@,`
M``````!6````7@8``!8"```X!P```````-`!``#Q!0```````-4$``";!P``
M$0$```````#*!@````````````"&````'P$``)X`````````UP0`````````
M!0``O@<``%T%````````K`4```$$``#N`P```````.<!``"6`@``?0,`````
M```!!P``Q@,``$D$``!*`0``!0(``'0'````````Y````-D"```<!@``,`,`
M```````.!@``$`,```$&``!G`0``G@(``&8'``![!0```````%,#``!<!P``
MN0````````"H````T`,``.X$``"4`````````!4%``"=!```XP,``"\```"N
M!0``X@(``*X&```<````$0```(0$````````:0```,P!``!O!0```@```$$$
M``!2`@``G`$`````````````X@,``&D$```4`@``X0```!\%``#O!@``````
M`$\%```"`@```````!0'``"5`P``_@,``"H#``"3`@``!@<``#8%````````
MW@4``(X"````````J`,``!L#``#\````WP(```````!]!0``<0```)\`````
M````(@4```0'```*````U0$``"($``!_`0```````)$&``#C`0``@P```"8!
M``#H!@``5@<```8!`````````````"8"``#"!0``_@0``.D&```Z!0``,`0`
M`/$!``"8`@``(04```````"'`P``"@0``"X#``"P!0```````.@!````````
M`````/(&``#"!@```````.4"``#$````C@0``'8`````````F@,``)D!``#]
M`P```````(P&``!W`@``PP(``&H%````````>@0````````H!P``OP<`````
M``!E`0``````````````````'08``$H&``#]!@``$P<``-````"%!P``````
M``<"```R!```9P`````````[`0``*P(``!X%`````````````'D"``#J`@``
M!`(``#X!``#Y!@``:@(``/$``````````````"`&```````````````````3
M!0``J08``#@%``#1!@``M0<`````````````8`8``+\```!:`P``T`(``&4'
M``"G`````````,\&```:!P``QP$````````O!0``N`(``#4```#J!@``80(`
M`)8%```N!```304``"\#``!6!@```````%(!``"D````\P(``"T$``"/!0``
M`````(P%```K!P````````````!S!@``S@0```````#.!0````````````")
M!0````8``#4#`````````````#,%```"!```0`<``.D!````````B`(`````
M```.`@``T@,``!$'``"5`0``80```.T%``!7````;0````````!G!```V`(`
M`)8$``````````$``+\&```5!@``;`4``"<#``"L`0``104``"@#```L`@``
MKP(``&X&``````````````0!``!"!@````````````#@!@``[@8``(\`````
M`````````!8$``"=!0``W08``+L'````````?@(``$4#``#B!@``JP(``"`#
M`````````````$P%````````V08``*L!``#>`0``808``$('``!@````````
M`!<$````````'@$```````!*!P```````-H"``#?!```B`,``(T%``#9`0``
MI@<``*L%```*`@``W@```-`$````````508```````"A!```Y`4``$,#``!_
M!P``#`````````#M!@```````!8!``!0!P``!0````````#U`@``E`(``(0#
M````````O0(``*8%``!]`@```````!L"```3`0```````$8#``"4`0``````
M`&0"``!R!P````````L'````!```O@(``$`#``!Q!0``Y@0``%@'```E`0``
M`````-0%```N`0````````X```"1````.````/T$````````?P0``((!``!H
M!```*`0```````">!@``#08``$D`````````[P,``(H`````````G0(``.P!
M``!0`@```````#<&``#[````Q`$``&`"```2!@```````,X!```:`@``^@$`
M`#8````]`P``C0,``-@$``#X`0```````%`&``#[`P``_04``&4&``!D!P``
M`````/0%``":!```)`8````````F````9@````4#``!P!P``NP```(X&````
M``````````````#-`0``WP,```````#F!@``(P8``*D"``!\`0``A04``%$"
M``#(`P```````",!``!2!@```````#\"``!Y!0``L@0``&('``!X!P``````
M``````!=`P``*0,````````^!P``6P,```<%``#4`````````*$!``!>````
MP@0`````````````=`0``/<&``!-!```&04``*(`````````K@0``*4`````
M````_@$```````!)!0``D@<````````4`P``&`,``%D```"S!```<P,``"0"
M``"2!`````,``'P'```?`````````+0&```I!@``TP```)P%```Q!P``W@0`
M```````I!`````````````!.`P``XP8``)$%```T`0``C@$``,$&``!"`@``
M`````/,&```V`0``$`$````````8!P```````%<%``!D!0```````!(!``#2
M!@``@0(`````````````E`8``$\&``````````````````"G`@``+@<``(8!
M``!L`@``LP<``-,&``#C!0```````$<```#+!@``@`$``-4"``#`````N04`
M`.`````(!@``]`(``!("````````0`4``````````````````%<!````````
ML0(``&\"``"#`P``\0(``!X'`````````````+(```!\````TP$``/`#``#:
M!@``T`4```````!/`0``EP,``'@$````````,0````````!^`````````#X"
M``!H!@``6@0``+$$``!W````L0```$0`````````;@$``'H'``"R!0``-@<`
M``````#]````B0```)D$``"<````CP,`````````````:`(``$8&```6!P``
M!P<``(,$```O`0```````*H$```0!P``T0,``.8%`````````````!T#``"#
M!P``(00``(````!.`@``MP4``&0$````````<@,`````````````S`4``*('
M``"O`````````+,"````````7@<``#$"``!,!@``J`0``"\'````````@P8`
M``````"!`0``I`<``,H````*`0``^@,``'X#``#Y`@``#@$``($#``!^!P``
MV`$``"D'````````B`8``)(``````````````)$"```D!0``5`(``'D$````
M`````````,D"``!5`@``/0```(\'``!K`P```````,4"``#'````%`8``%(`
M``"Z`P``1@$```$#```J``````````````#G`@``HP,``&$%``#_````````
M`&D'``"S`P``E0(``&L```#&`@```````.P"```;`0``R`0``(D"``!;!@``
M`0(``+T```#7`0```````*$'``!)`P``G0<``(0&````````ZP,``$0&``"J
M`P``RP,````````@!```H0(``(`'``"Q`0``MP$``+X$``"?!0``Z`0``*H%
M``#L!@``C````/$&````````H````.L%``!V`@````````````"\`@``````
M``````#"````H`,``.4#````````$@4``"`!``!1!```U`(````````"!P``
M``````4%``"C`@``&0```.L$``"`!```U@4``"T#````````@P$``","```S
M!@```````,$"``"*!P``404``(@!```=!0``8P$``/@%``!8`P```````#T&
M````````PP4```````#(`@``Z0(``,D`````````,`$``#`'``#E!```J@(`
M``````!B`@``,`4``#$#``!M!```C@<``/(```#W````_@````<```#W`0``
MBP(````````-!0```````#@"``#D`@``8P<``*D```!Z!@``!@4``/<$``"4
M`P``B`0```````#J````^P(``"X````G!@``!@,``&@%``"[!0``D@4``'X&
M``!R`````````+H````[!```60,```````#$!```"P8```,&``#?`0``6P$`
M````````````/P``````````````V00`````````````:08``,4$````````
MEP4```````#H!0``=P$``(D#````````Y08``&T%``"V`P````````````#)
M`P``1`4```@%`````````````,,```"G!@```````,X#````````Y`0``-L$
M````````.0<``%4%``!(`P``LP4``#H!``"L````#@0````@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@
M*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I
M<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@
M;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I
M;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@
M=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`
M)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D(&YO=&5S
M`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E
M<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S
M(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!C:&%R86-T97)S`"5S
M(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N
M="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@
M;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D
M<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S
M:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M
M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N
M>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H
M(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I
M;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M
M+0`Q(&YO=&4`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U
M<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S
M:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E
M+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3
M:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI
M<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D96YI960@9&5L971I;F<@;F]T
M92X`06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N`$%C8V5S<R!D96YI
M960@<V%V:6YG(&YO=&4@=&\@)7,N`$%C8V5S<R!D96YI960@<V%V:6YG(&YO
M=&4Z("5S`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!
M8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P
M`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B
M`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E
M<CH`061D(&-A=&5G;W)Y`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D
M9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!
M9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D
M9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E
M9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D
M:6YG($$@3F5W($YO=&4`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R
M97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS
M(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T
M86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL
M`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI
M<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E
M<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y
M(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!0
M87-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA
M:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT
M.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC
M80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N
M($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H
M87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7
M:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!
M<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YD:6YG`$%S8V5N
M<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U
M<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E
M<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N
M86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@
M4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A
M=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@
M=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@0V%T96=O<FEE<SH`
M079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"86-K('1O($YO=&5P860`
M0F%C:R!T;R!.;W1E<&%D($]P=&EO;G,`0F%C:V=R;W5N9`!"86-K9W)O=6YD
M($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S
M97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`
M0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B
M)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ
M90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F
M(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!"
M;&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E
M<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!"
M;W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`
M0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#
M35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-35@!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N
M9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@8V]N;F5C="!T
M;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D
M80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#
M:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D
M:7-P;&%Y(&]P=&EO;G,N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN
M+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#
M:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T
M;R!L:7-T(&EN('1H92!S=6UM87)Y('9I97<N`$-H;V]S92!Y;W5R(&1E9F%U
M;'0@3F]T97!A9"X`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@1F]R;0!#;&5A<B!-4T]F
M9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A
M<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O
M($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L
M;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA
M;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB
M:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`
M0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O
M;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#
M;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@
M;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]P>0!#;W!Y(&9A:6QE
M9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E
M`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'
M4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO
M="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C
M:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E
M<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&
M5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@
M;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN
M9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B
M)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@
M=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD
M(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O
M=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER
M("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K
M(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N
M`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I
M;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X
M=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E
M(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871E9`!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`
M0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`
M0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I
M;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O
M;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL
M;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC
M+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E
M92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`
M1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C
M=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB
M97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F
M875L="!)9&5N=&ET>0!$969A=6QT($YO=&5P860`1&5F875L="!3:&5L;`!$
M969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E
M8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@
M0V]N9FER;6%T:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!0
M97)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&)U
M='1O;B!B96AA=FEO=7(`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE
M=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E
M('1H92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!N;W1E`$1E;&5T960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K
M`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`
M1&5S8W)I<'1I;VXZ`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S
M="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`
M1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M
M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA
M=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E
M;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$
M;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC
M`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W
M;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$524@!%
M8W5A9&]R`$5D:70`161I="`B)7,B`$5D:70@0FQO8VL`161I="!'<F]U<`!%
M9&ET($YO=&4`161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!C871E9V]R:65S(&%N9"!C;VQO
M<G,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S
M(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@
M4V%L=F%D;W(`16QE;65N="XN+@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@3F]T90!%
M;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M
M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T
M;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO
M8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D
M96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E
M<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=W)I=&EN9R`B
M)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD
M(%-I9&5B87(`17AP96-T960@)RDG`$5X<&ER871I;VX@1&%T90!%>'!O;F5N
M=`!%>'!O<G0`17AP;W)T($YO=&5S`$9'($-O;&]R`$944"!U<&QO860@;V8@
M<V5T=7``1E]U;&P@5&5X=`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@
M(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B
M+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&
M87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO
M=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@
M0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA
M9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T
M($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H
M5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O
M<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O
M="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&
M;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`
M1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E
M;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O
M;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.
M86UE`$=A8F]N`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%L($]P=&EO;G,`1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA
M`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L
M`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'
M<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M
M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U
M<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U"
M:7-S874`1W5Y86YA`$A434P`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O
M<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I
M;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A
M;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R
M>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N
M(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@
M240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P
M861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E
M/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI
M9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!
M9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)7VYS97)T
M(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)
M8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T($YO=&5S+"!3=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O
M<G0O17AP;W)T($YO=&5S`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I
M9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA
M=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E
M<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!)
M;G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R
M="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE
M<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P
M:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!)
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK
M`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E
M<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L
M:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C
M:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC
M96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@
M;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E
M+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!)
M;G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!)
M;G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I
M;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L
M92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L
M:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M
M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T
M:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@
M4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B
M:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+
M97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A
M=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+
M;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG
M=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA
M;&8`3&%S="!-;V1I9FEE9`!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U
M87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN
M.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y
M;W5T`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O
M=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T
M96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY
M`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN
M('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI
M;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN
M:W,`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A
M<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E
M`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M
M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F
M86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG
M+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G
M(&EN`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`
M3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R
M(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI
M82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R
M`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3
M965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@
M26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ
M=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A
M;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-87AI;75M($YU;6)E<B!O9B!.;W1E<P!-87AI;75M($YU;6)E<B!O9B!0
M;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC
M:6YE`$UE;6)E<G,`365M;R!497AT`$UE;G4@;6]D93H`365R9V4@8V5L;',`
M365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`
M365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@
M;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A
M9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A
M9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI
M<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D
M:69I960@1&%T90!-;V1I9GD@55),`$UO9&EF>6EN9R`E<P!-;V1U;'5S`$UO
M;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@
M>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L
M9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R
M;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`
M36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D
M;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N
M="!);F9O<FUA=&EO;@!->2!.;W1E<P!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`
M3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`
M3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.
M971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA
M;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T
M:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@
M0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`3F5W($YO=&4`
M3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W
M;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W
M;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE
M=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI
M9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG
M=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C
M:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A
M=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@
M861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&E#86QE;F1A<B!D871A('=A<R!F
M;W5N9"X`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA
M;64@<W!E8VEF:65D+@!.;R!N;W1E<&%D<R!A<F4@879A:6QA8FQE('1O(&=U
M97-T<RX`3F\@;F]T97,`3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I
M=&5R:6$N`$YO(&YO=&5S('1O(&1I<W!L87D`3F\@;G5M8F5R('-P96-I9FEE
M9"X`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.
M;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N
M`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU
M97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO7W1E`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO
M="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T
M('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E($-A=&5G;W)Y`$YO=&4@1&5T86EL
M<P!.;W1E($QI<W1S`$YO=&4@5&5X=`!.;W1E(%]497AT`$YO=&4@;F]T(&9O
M=6YD+@!.;W1E7W!A9`!.;W1E<&%D)W,@;F%M93H`3F]T97!A9',`3F]T97!A
M9',@;75S="!H879E(&$@;F%M92X`3F]T97,`3F]T97,@4W5M;6%R>0!.;W1H
M:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E
M<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R
M;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES
M=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A
M;`!/8W1O8F5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B
M92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T
M(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RX`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R
M90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N
M<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T
M:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL
M(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@
M1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`
M4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!0
M86MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U
M9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A
M<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!0
M87-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S
M:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN
M97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R
M979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I
M;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE
M;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U
M8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O
M`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L
M:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R
M;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T
M;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@9&5L971E('1H:7,@;F]T93\`4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@3&ES=`!2
M969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E
M<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!"
M;&]C:P!296UO=F4@8V%T96=O<GD`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R
M;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E
M;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2
M971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N
M;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I
M9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!2
M97-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S
M="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@
M<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E
M>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`
M4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`
M4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E
M<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W
M86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N
M8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`
M4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE
M=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E
M;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A
M=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`
M4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O
M<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!297-U
M;'1S`%-E87)C:"!38V]P90!396%R8V@@7U1E>'0`4V5L96-T($9I;&5S`%-E
M;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE
M=R!O=VYE<@!396QE8W0@82!N;W1E<&%D`%-E;&5C="!A('-E<G9E<@!396QE
M8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C
M="!N;W1E<&%D<R!T;R!D:7-P;&%Y.@!396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`
M4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@
M:6UP;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z
M`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;&5C=&5D($-A=&5G;W)I97,Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!3
M35,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT
M96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N
M`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W(&%C=&EO;B!B=71T;VYS/P!3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!N;W1E<&%D(&YA;64_`%-H;W<@;F]T
M97,@9G)O;2!T:&5S92!C871E9V]R:65S`%-H;W<@<&EC:V5R`%-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A
M<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I
M;FL`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!
M;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V
M86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3
M;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T
M:#H@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R
M="!B>2!#871E9V]R>0!3;W)T(&)Y($YO=&4@5&5X=`!3;W)T(&]R9&5R('-E
M;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R
M;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T
M:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V5R
M`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P
M;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3
M=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O
M<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T
M`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U
M`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`
M4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D
M960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D
M871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L
M;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A
M=F5D("(E<R(N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E
M<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N
M<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R
M;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`
M4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T
M;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY
M`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R
M=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES
M=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K
M<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E
M<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S
M+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M
M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG
M;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@
M97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)
M35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`
M5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0
M('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I
M9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I
M=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I
M;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T
M('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D
M(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE
M(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R
M9F,X,C(@;65S<V%G92X`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F
M('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET
M:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO
M(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@
M=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T
M:&4@8V]M<&]S92!P86=E`%1H92!N;W1E('=A<R!D96QE=&5D+@!4:&4@;F]T
M97!A9"`B)7,B(&-O=6QD;B=T(&)E(&-R96%T960Z("5S`%1H92!N;W1E<&%D
M("(E<R(@:&%S(&)E96X@8W)E871E9"X`5&AE(&YO=&5P860@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!4:&4@;F]T97!A9"`B)7,B(&AA<R!B965N('-A=F5D
M+@!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM
M=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H
M="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I
M9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B
M)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T
M:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O
M;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B
M)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE('9.;W1E(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L
M969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@
M<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO
M;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R
M(')E;6]V:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@<V%V
M:6YG('1H92!N;W1E.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@
M;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<P!4:&5R92!W97)E(&YO(&UE
M;6]S('1O(&5X<&]R="X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@
M;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N
M`%1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E
M<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE
M('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ
M`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#
M;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI
M;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M
M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')I;FED860@86YD
M(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI
M<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X
M.B``55),`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S`%5N86)L92!T;R!D96QE=&4@
M(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F
M;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@
M9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5
M;F1O($-H86YG97,`56YD;R!C:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5
M;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5
M;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@
M8V]L;W(`56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<P!5;G-U<'!O<G1E
M9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A
M=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R
M=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S
M<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R
M("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A
M=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E
M<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L
M<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T
M:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S
M`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z
M=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H
M879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R
M;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`
M5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E
M<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN
M($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I
M;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%2
M3@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`
M5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A
M=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE
M<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H
M25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E
M;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H($YO=&5P860@<VAO=6QD
M('1H92!N;W1E<R!B92!A9&1E9"!T;S\`5VAI8V@@<&AA<V5S`%=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED
M=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T
M:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I
M;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES
M9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"X`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)
M9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA
M<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&YO=&5S+@!9;W4@87)E(&YO="!A=71H96YT:6-A
M=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U
M<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@
M861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I
M;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E
M<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T
M97!A9"`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY
M('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D
M:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU
M92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U
M<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T
M(&$@;F]T97!A9"!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@
M<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@
M4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R
M96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!D969A=6QT
M(&YO=&5P860Z`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I
M<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;F]T
M97!A9',Z`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE
M(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W
M;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA
M=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;2&ED92!1=6]T960@5&5X=%T`
M6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U
M;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI
M<W1R871I;VX`7T)A8VL@=&\@3F]T97!A9`!?0TQ)`%]#871E9V]R>0!?1&%T
M851R964`7T1E;&5T90!?1&5L971E(%)O=P!?161I=`!?1FER<W0@3&EN90!?
M1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%]);7!O<G0O17AP
M;W)T`%],:7-T($YO=&5S`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK
M+BXN`%]->2!.;W1E<&%D<P!?3F5W($YO=&4`7T]P=&EO;G,`7U!E<FUI<W-I
M;VYS`%]0<FEN=`!?4F5M;W9E($QI;FLN+BX`7U-E87)C:`!?4V5T=7``7U1A
M8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A
M<@!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T
M`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R
M871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A
M(&9O<FUA="!E<G)O<@!E;G1R>2!N;W0@9F]U;F0`9FEL90!F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO
M=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N
M86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UM`&YA;64`;F]T(&EM<&QE;65N
M=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!N;W1E<RYC<W8`<&5R
M8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN
M('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF
M9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@
M97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@
M<V5L96-T`'9#87)D`'9.;W1E`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M
M5F5R<VEO;CH@34Y%34\@,BXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP
M,2TP-2`Q-3HP-"LP.#`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#$M,#@@
M,3`Z-3,K,#$P,`I,87-T+51R86YS;&%T;W(Z($1A=FED($-H86YG(#QD879I
M9$!T;78N9V]V+G1W/@I,86YG=6%G92U496%M.B!4<F%D:71I;VYA;"!#:&EN
M97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4))1S4*0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R"DT:ME*0`@**?6L;;!
MY"`E<RD`("@E<R"DT:2Z*0`@**2UI-$I`"`HJ?JDT2D`("BL4:31*0"I\P`B
M)7,B(*2CK$^D0*W3I=B__0`B)7,B(*2CK$^D0*W3IK.NQ*JZO^^^W"X`(B5S
M(B"I?*6\IF(@2$]21$4@JKJU^:55P,DH4F5G:7-T<GDII*2S7:EW+@"GY*2C
MJ.P@(B5S(B!T<F5E(')E;F1E<F5R+@`B)7,BI'>FJ*5<JKJE6Z1*J.RX<[+5
MJ'2RSJ2D+@`B)7,BI'>E6Z1*Q7:MK:ATLLXN`"(E<R*HPZ6\J]BEWSH@)7,N
M`*1WJ,^ESB`E+C)F34(@+*YEMG$@)2XR9DU"("RST;YL("@E+C)F)24I`"5D
M("5S(*5(I,X@)7,`L\RJ\:1`IKBQ2[U8Q=RG\ZGS("5D(*31JV4N`"5D(*W3
MNDNM;@"SS*KQ("5D(*31KO"V2+EWL_@`)7,@+2"SQJ?1O_T`)7,@J_ROO@`E
M<R!+0@`E<R"Z^\5`OMZG0"`M(+U4NWL`)7,@LUVI=P`E<R"U^:55`"5S(*90
MMTZVM:78`"5S(*1WIG.F8@`E<R"F8B`E<R`E<P`E<R"F<J2X`,#)KM<@)7,@
MI'>VUZ1*I[FFJ``E<R"D=[1.I%6F0ZC&MK6JNKK[Q4"^WJ=`M$ZZ_"X@O="I
M\Z:YKLFDQ+_OIT&W4:UNOMZG0*JZMK6EV"X`I;*[W:UN("5S`"5S(*3``*?D
MI*.H["`E<RX`("5S(*CL("5S(*9`("5S`"5SJKJS<;!4O_T`)7.JNJ;FJ,:^
MY``E<ZJZL\:GT;_]`"5SJKJKW;_LPZ\`)7,Z("5S`"5S.B"S;ZO*JTBE\Z2C
MI$"I=Z]UI=&K2*2DJKJQ2*7SI$BITK%(M6\N(+W0JF"W3J15ID.ITJ:SJKJZ
M]+CTLW.ULJ:SI6FOX*RJNGRG0:JZK=.D2+CJKL8N`"P@L'VMMR``+""P?:VW
M("5S("5S`"S%W*3&MG&Q<2`E<R"H["`E<P`M+2"_[[[<("TM`*1`K=.Z2ZUN
M`#$R(*1PKLFH[@`R-""D<*[)J.X`,C0@I'"NR:CN`*17I$"MM@"FN;#/MO2E
MLK:WK6ZK_*EWN.JNQJYWIOBJ0;K=+@"U;Z7-I$:D0*W3Q%FMJZJZO_F[?@"Q
M_:5;L4NV;*7S+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N`+']Q>?#TJ1W
MP[&SN:JZMFRE\RS!V;O=K6ZFLZ1`K=,@4$=0(*2]MGVJ]\9?+@"Q_;C1L4NV
M;*7S+,'9N]VM;J:SI$"MTZ2]MGT@4$=0(*KWQE\LJ'"Q2R!01U`@JO?&7RRE
M2*3.LW'#]J1FI4\N`+']L/6FYK9LI?/#L;.Y+,'9N]VM;J:SI$"MTZ2]MGT@
M4$=0(*KWQE\LJ'"Q2R!01U`@JO?&7RRE2*3.LW'#]J1FI4\N`+']N-&Q2[9L
MI?,LP=F[W:UNIK.D0*W3I+VV?2!334E-12"J]\9?+*APL4L@4TU)344@JO?&
M7RRE2*3.LW'#]J1FI4\N`+']L/6FYK9LI?/#L;.Y+,'9N]VM;J:SI$"MTZ2]
MMGT@4R]-24U%(*KWQE\LJ'"Q2R!3+TU)344@JO?&7RRE2*3.LW'#]J1FI4\N
M`+']I5NQ2[9LI?,LP=F[W:UNIK.D0*W3(%--24U%(*2]MGVJ]\9?+@"DR*ME
MIK.VLP"DR*MEI'"K0@"DR*MEIK.K0@"DR*MEL'VK0@"DR*MEL'VSMP"DR*ME
M+Z3(J^$`05!)(+USN+D`P_:I\[-OK=.]<[_HOKD`P_:I\RXN+@"EOZ15I.@`
MI;^DI*6A`,5VK:VDHZBL++5,JFNKV*7?(%9&4R"EV+_]+@#%=JVMI*.HK"RU
M3*IKJ]BEWR!61E,@P,FNURX`IU*PH[I+K6ZNR2RF<ZCZOD2IVBX`MVBROJ:Y
MNDNM;J[)+*9SJ/J^1*G:+@#`>*9SNDNM;JCL("5S(*[)+*9SJ/J^1*G:+@#`
M>*9SNDNM;CH@)7,@KLDLIG.H^KY$J=HN`+%BN+FXZK!4`+%BN+F[4+%+O5@`
ML6*XN:1WK>&ULBX`M;*Q8@"W<[Q7`+=SO%>FN+ASLM4`MW.\5Z1LQ7:MK0"F
M8J:YMW.\5SH`MW.\5[ASLM4`MW.\5\5VK:T`MW.\5Z:XN'.RU:CL("(E<R(`
MMW.\5Z:XQ7:MK:;<(B5S(@"W<[Q7I$"MTZC/I<ZJS#H`MW.\5Z3`P_X`MW.\
M5\3FINP`MW.\5Z1`K=.FJ*W[.@"W<[Q7N>\`MW.\5R`E<R"LL"!-;WII;&QA
M(*JZI,"MM@"W<[Q7J.RJNK-QL%2__3H`MW.\5ZCLI]JJNK-QL%2__0"W<[Q7
MJ,^ESJK,`*1WMW.\5R`B)7,B(*CLJ'2RSJ2D+B"F_;5,JFNW<[Q7PT*E?JJZ
MM?FE5;CJL%0Z("5S+@"D=[=SO%<@(B5S(B"H[*ATLLZDI"X@IT&R>Z9BI6FE
M2+9IIN:U;J1*I$8N`+=SO%<@,2"MT[I+K6X`MW.\5ZC/I<ZJS*JZI5ROX*78
MJV6S4</VLZPN`*9AIWT`LW&P5+_]`*:HK+"ZWK)ZK?L@+2"LL*CDI4RHSZ7.
MJLRS7:EWQ7:MK0"ZWK)Z`+QSIVD`069G:&%N:7-T86X@**K\M$FFO2D`06QB
M86YI82`HJORZN*3:I:>HR"D`06QG97)I82`HJORZN*3.IU&HR"D`MFRE\Z=/
MIE<`N>^[]`"Y[[OTI.BFH3H`J=*FLP"ITJ:SI'?%Y\/2JKJHSZ7.JLP`J=*F
ML[ASLM4`J=*FL\5VK:T`I7ZNV+UU`*2YLURF;K18K=.Y<:1LMFRE\Z9AIWT`
MI+FS7,7<I_.VM:78O7.XN:JZJZRZ03\`I'>F<Z9B`,7<I_,@24U34""U;J1*
M`,7<I_,@24U34""Q2[U8`,7<I_,@24U34""HSZ7.JLP`Q=RG\[EQI&RV;*7S
MINVG?0#%W*?SO,NJ3P"TP*5.I.6F<@!!;65R:6-A;B!386UO82`HK/S$4K#M
MPL2\KZC(*0"D0*W3M4RNQ*JZK<BS4:C/I<XN`+5OI<VD1J1`K=.EO*J^JKJ_
M^;M^+@!!;F1O<G)A("BF=[E$IM4I`$%N9V]L82`HIG>M]*G4*0!!;F=U:6QL
M82`HIG>F8ZG4KG$I`+#.IE>E3K)ZIG.H^@"UJJ[7`$%N=&%R8W1I8V$@**MN
MMZ6D:K.P*0!!;G1I9W5A(&%N9"!"87)B=61A("BF=[2CI<JN<:3.I-JZN*6L
MN4:N<2D`P+.ESK5[IJ$`P+.ESK5[IJ&R3;/F`,"SI<ZU>Z:AI'>T3KK\`*Y-
MI<ZH[*G2IK.JNJ:XID"HR0"GY:WC`+EWIO2D:J1P`*5\I.L`JORIU*="I.4@
M*%=I;F1O=W,M,3(U-BD`P*/!6<#)I&JD<`#`H\%9P,FF5[K9`*=!O52I=ZUN
MIU*PHR`E<R"JNK7YI56VW"`_`*=!O52I=ZUNIU*PHR`B)7,B(*5(I,ZE]*;S
MJKJFN+ASLM4@/P!!<F=E;G1I;F$@**K\KMJGRBD`07)M96YI82`HJ,BL_*6G
MJ,@I`*C(K/REIZC(I.4@*$%235-#24DM."D`P\"S3@!!<G5B82`HJOR^?*3:
MKG$I`*3)OJT`07-C96YS:6]N($ES;&%N9`"DY:9RP\"S3@"HR*QW+Z33I:VL
M=J9AL,\`L/6FYK[>IT"Z^\5`JV7%XZ7<O52[>[GON-P_`*3`L'3$YJ;L`,!\
MN-6G4K"CI$"MTZ2CIG.F8JJZN'.RU2X`P'RXU:=2L*.D0*W3I*.F<Z9BJKK%
M=JVM+@#`?+C5O7._Z*1`K=.DHZ9SIF*JNKASLM4N`,!\N-6]<[_HI$"MTZ2C
MIG.F8JJZID"HR2X`Q-VIR@"D2Z3K`$%U<W1R86QI82`HOT2D:J=1J,@I`$%U
M<W1R:6$@*+;XIF&G42D`075T:%]C<GES<6PZ(*?DI*.H[*G2N]VM;JJZ(&EM
M87`@J;6F^:Y-I?,N`$%U=&A?8WER=7,Z(*;XJD&ZW:C#I;RTHZC1N-.VM:3D
MM*DN`$%U=&A?8W)Y=7,Z(*?DI*.H[*G2N]VM;JJZ(&EM87`@J;6F^:Y-I?,N
M`$%U=&A?9G1P.B"GY*2CJ.RITKO=K6ZJNB!&5%`@J;6F^:Y-I?,NO="MJ[=S
MO7/$MB!02%`@J,.E0J5;I$H@+2UE;F%B;&4M9G1P(+_OMK4LJ-*F<"!C;VYF
M:6=U<F4@+2UE;F%B;&4M9G1P`$%U=&A?:6UA<#H@I^2DHZCLJ=*[W:UNJKH@
M24U!4""IM:;YKDVE\RX`075T:%]K<F(U.B"GY*2CJ.RITKO=K6ZJNB!K<F(U
M(*FUIOFN3:7S+@!!=71H7VQD87`Z(+=SO%>HSZ7.JLRS;[:UI5ROX*78JV6H
MPZ2CI.2TJ:78O_VJ0;#(`$%U=&A?;&1A<#H@IU*PHZC/I<ZJS+-OMK6E7*_@
MI=BK9:C#I*.DY+2II=B__:I!L,@`075T:%]L9&%P.B"GY*2CJ.RITKO=K6ZJ
MNB!,1$%0(*FUIOFN3:7S+@!!=71H7VQD87`Z(+5,JFNW<[Q7J,^ESJK,("5S
M+B"F^*I!OKFF7L"S.@!!=71H7VQD87`Z(+5,JFNROK"CJ,^ESJK,("5S`$%U
M=&A?;&1A<#H@M4RJ:Z?SMW.HSZ7.JLP@)7,`075T:%]L9&%P.B"G\[=SJ,^E
MSJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]JD&PR`!!=71H7VUC86PZ(*?D
MI*.H[*G2N]VM;JJZ($U#04P@J;6F^:Y-I?,N`$%U=&A?<VUB875T:#H@I^2D
MHZCLJ=*[W:UNJKH@<VUB875T:""IM:;YKDVE\RX`24U!4""F^*I!OKG%Y\/2
MO_F[?BX`Q>?#TJ6BL=$N`,7GP]*EHK'1+B`E<P!2041)55,@Q>?#TK_YNWXN
M`$944"#%Y\/2O_F[?BX`4TU"(,7GP]*_^;M^+@"E::7.JKJDP,/^.@"E::7.
MJKK$YJ;L.@!!>F5R8F%I:F%N("BHR+;KJ_2U32D`JO"F7K/&I]&__0"J\*9>
ML\:GT;_]O^^VM0"M2;2Z`*U)M+K#0Z;B`&ME<F)E<F]S(+%+O5B_^;M^+@!K
M97)B97)O<R"HSZ7.JLRF5[K9O_F[?BX`0F%H86UA<R`HI-JKHK"H*0!"86AR
M86EN("BDVJI,*0"J:<.YJKJN_*3E("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:"`HJ7.E6ZG4*0!"87)B861O<R`HI-JHJ:9H*0"GY*2CJ.RYSZ7<I=B__2`B
M)7,B+@"P\KUU`$)E;&%R=7,`0F5L9VEU;2`HI/&G4:[)*0!"96QI>F4@**BI
MJ+VTM2D`0F5N:6X@**BIN><I`$)E<FUU9&$@**;*O'VY1BD`0FAU=&%N("BD
MHZ2F*0"ES:3I`*?DI*.H[,"SI<ZU>Z:A(B4R)',BJKJPS[;T(B4Q)',B+@"P
MS[;TLUVI=P"PS[;TJZRZ00"RRL7I`$)O;&EV:6$@**S!IU&Z^ZC(*0"NT<72
M`*[8O74`KMB]=:1JI'``KMB]=0!";W-N:6$@86YD($AE<GIE9V]V:6YA("BJ
M::1HI:>HR*3.ML+!R:WTNONHNBD`I?ZSH0!";W1S=V%N82`HJFFEOJBZ*0"I
ML[.A`$)O=79E="!)<VQA;F0`0G)A>FEL("BDVJ;H*0!"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T@**A:M=PI`$)U
M;&=A<FEA("BK3Z5;IU&HR"D`MK6EV++%N+D`0G5R:VEN82!&87-O("BEK+18
MK\>J:Z_!*0!"=7)U;F1I("B[6K:IIF$I`*JIK;&ZWK)Z`$-20P!#4DP@I,"S
MH<))`+-RPDFDP+EJKN:FH2`N8W-V`,!XIG.NYJ2ZKF4N+BY?90"GUJCZJNRI
M;*3&J7REO*>YIJ@N`*;FJ,:^Y`"Y<Z_%K;<`0V%M8F]D:6$@**Q:KDBYZRD`
M0V%M97)O;VX@*+/8L\&VJ2D`M4RJ:Z;;L,JMJ[AML4N]6"R]T,%PM;BG0:JZ
MJ'2RSKK>LGJM^RX`M4RJ:[QGI$K`R:[7("(E<R(`M4RJ:[-SO76FW"!)34%0
M(*;XJD&^N3H@)7,`M4RJ:[9]L=+`R:[7("(E<R(N`$-A;F%D82`HI5NNLZ1J
M*0"H^J[X`*CZKOBPW<-$IEZS^`"U3*IKIU*PH\#)KM<@(B5S(BX`I^2DHZCL
MO,BF<Z78O_TN`*_*I-8@)W1A<F=E=$9I;&4G(+#1O,:U3*IKQ'[$\K-"LGHN
M`+5,JFNROK"CI=B__2`B)7,B+@"U3*IKLKZPHSL@)60@K=.D;+:PI'>F<Z9B
M+@"U3*IKK:NRU:%#J=*THZC1JKJP3[_]O,:EV+M0I?VK9:G2P'BF<ZJZN.JN
MQJ2CLL4N`+5,JFNVQ[!EPK*P5*CLJ_RI=ZJZN+F]6"X`0V%P92!697)D92`H
MNON\=ZBD*0"[H:GZI.6F<@"DP,/^NU"\T,72`*3`P_X`0V%Y;6%N($ES;&%N
M9',@*+9]L-*X<ZYQ*0"FYK#*N7&XW`#`>*9SKN:DNJYE`,!XIG.NYKG4I5(Z
M`,!XIG.NYJ2ZKF4`P'BF<Z[FMJ&V6CH`IN:PRKEQN-P`MNNZN*]3I.4@*$E3
M3RTX.#4Y+3$T*0"X;:2D`$-E;G1R86P@069R:6-A;B!297!U8FQI8R`HI*2K
M1*9`J4VPZBD`I*2\VB`H25-/+3@X-3DM,C``OLS#TK+3N&``OLS#TK[6IK.J
MS`"^S,/2K$:UI@!#:&%D("BL9+QW*0#%W*?S`*?SI^^G0:JZL4N]6`"G\Z?O
MIT&JNJJZI?ZF5Z5(I,ZF7K9LIF&G?2X`Q=RG\Z=!JKJZ2ZUNL<:GQZ5(I,[%
MXZ7<O^^VM2X`I=BK9:JZLUVI=ZC#I;RDY+2IL4N]6,7<I_,N(+W0P7"UN*=!
MJKJZWK)ZK?LN`*9RI+@`P,NL9+-SM;(N+BY?:P!#:&EL92`HM+RG42D`0VAI
M;F$@**2DL.HI`,*RQ>FDI*3E("A'0C(S,3(I`*6_Q>FDI*3E("A":6<U*0"_
M[[[<P+.ESK5[IJ$Z`+_OOMRQ2[U8`+_OOMRD0*W3J,^ESJK,IE>ZV0"DZ;3!
MQ>.EW*3HIJ$Z`+_OOMRVM:78JZRZ0:JZK;>NY@"_[[[<I,##_J5(Q>.EW*GS
MNDNM;L#+M?BDI"X`O^^^W*=!JKJY=[-=L\:GT;_]+@!#:')I<W1M87,@27-L
M86YD("BX=+W/KG$I`*?DI*.H["`E<R"JNL/^IT^I=[AQ+@"TN`"R3;"CJNVS
MY@"R3;"CMTRS;B!/9F9I8V4@O-#%T@"R3;"CK&2XWP"R3;"CJ,^ESJK,.B`E
M<P"R3;"CJ,^ESJK,`+)-L*.HSZ7.JLRJNKCJKL8`L=_"X+2X`*OVM\:YJ\'D
MI4C$?L3R`$-L:6-K871E;&P@LWJY3"!(5%10`,/VLZRU^+6A`+:SMG$`IJVF
M:+:S`+.Q`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`*?IQ7RXZJ[&IZ@`I^G%
M?,/DK,D`0V]L;VUB:6$@**WTK=ND\:C(*0##0Z;B`+W5IN*]3``Q-K9IINS#
M0Z;BI4Z]6`#$YCH`Q.:F[+S0PT0`I62S<0"I4J5/`*?EIKBI4J5/`+7[O=<`
MNMFI20!#;VUO<F]S("BL[+ROP[DI`*2]I7$`N7&XHP#`]+G2`+'XI?,`KG2R
MIP"[4"!01$$@M'BD5ZNLN7&XHRRTO+QZJZRDXK[WI4BDSB!/=71L;V]K(*JZ
MIE"H0K-=J7<N`+-=J7>XZJ[&N4RTP2X`LUVI=R`E<P"]5+M[L4N]6`!#;VYG
M;R`HK>BJ1RD`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92`HK>BJ1Z9`J4VPZBD`LW.ULJ6BL=$N`+-SM;*EHK'1.B``LW.ULJ;<I+VV
M?:KWQE^F^*I!OKFNR;Y$J=HN`+-SM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^1*G:
M+B"M[*9=.B`E<R`H)7,I`+-SM;*FW"!&5%`@P,FNUZ;XJD&^N:6BL=$N`+-S
MM;BD2`"P3[_]I'>FJ*5<IF&W<[Q7IMRG0:JZLW&P5+_]I*0N`,"CP5G`R:[7
MJKJDNJYEJZRZ03H@`"(E<R(@P,FNUZ2ZKF4`Q'[$\@!#;V]K($ES;&%N9',@
M**SLITJX<ZYQ*0"]QKMS`+W&NW.EHK'1.B`E<P"]QKMS`$-O<W1A(%)I8V$@
M**WTM+6D:KZDI5LI`$-O=&4@9"=)=F]I<F4@*+9(I/JN_*FD*0"U3*IKI4@@
M4$=0(*5;L4NV;*7S.B``M4RJ:Z5((%!'4""P]:;FMFRE\\.QL[DZ(`"U3*IK
MI4@@4R]-24U%(*5;L4NV;*7S+@"U3*IKK+`@4R]-24U%(+9LI?/#L;.Y+@"U
M3*IKMW.\5[-SM;BD2"X@)7,`M4RJ:\.TM;(@3$1!4""F^*I!OKD`M4RJ:\.T
MM;(@;&1A<""F^*I!OKD`M4RJ:\#+K&2W;*]Q+B`E<P"U3*IKLW.ULJ;<(&QD
M87`@IOBJ0;ZY`+5,JFNS<[6RIMRF^*I!OKD@(B5S(B"HSZ7.($944#H@)7,`
MM4RJ:ZO8I=^P=+AMN'.RU2X@)7,`M4RJ:[C1L4L@4$=0(+CJKL8Z(`"U3*IK
MN-&Q2R!3+TU)344@N.JNQBX`M4RJ:Z=2L*.S<[6XI$@N("5S`+5,JFNG4K"C
ML'2X;;)-L^8N("5S`+5,JFNG4K"CI_.W<[5[IJ$@(B5S(BX`M4RJ:ZA-J7>F
MK*7SI$BJNKEQI&RV;*7SINRG?2X`M4RJ:\#RJ/JGN;[CJKJS<;!4O_TN`+5,
MJFO`\JCZI[F^XZJZL'2X;;)-L^8N`+5,JFO`\JCZL'2X;;)-L^:DI*JZN'.R
MU2X`M4RJ:[C\I$JUIK*D("(E<R(N`+5,JFNKV*7?I=B__2`B)7,B+@"U3*IK
MIMNJ]\9?IOBJ0;ZYJ/JQ;Z2]MGVJ]\9?+@"U3*IKMGVQTB`B)7,B(*5(O&>D
M2BX`M4RJ:[9]L=(@)7,N`+5,JFNV?;'2NOO%0*1UIT"\TK+5("5S`+5,JFNV
M?;'2I=B__2`B)7,B+@"U3*IKLW.QM2!,1$%0(""F^*I!OKDN`+5,JFO%JJCZ
M("5S+@"U3*IKK:NW<[-=J7>HSZ7.JLRJNK%+O5@N(+.AI,"JNK+3N&"DHZ6_
MO50N(+W0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BX`M4RJ:\6JJ/JF
M<ZCZL;&H[JKM*$%C8V5S<R!#;VYT<F]L($QI<W0I`+5,JFO%JJCZLW&P5+_]
M+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E
M<P"U3*IKQ:JH^J;XJD&^N:JZK-O#]J]3J<H`M4RJ:Z9>M%^S7:EW+@"U3*IK
MIU*PHZ78O_T@(B5S(BX`M4RJ:\!XIG,@)7,@JKJS7:EW+@"U3*IKP'BF<[/&
MI?>S7:EW+@"U3*IKP'BF<[/&I?>S7:EW.B`E<RX`M4RJ:\!XIG.G\[=SM7NF
MH:CL.B`B)7,B+@"U3*IKP'BF<[/&I?>S7:EW("5S+@"U3*IKP'BF<[-=J7?`
MR25S+B"G0:5II4BHSZ7.)7.DI*JZJ.2E3*5<K^#`>*9SLUVI=ZG.I.*PRKW&
MNW.D5:VQM7NFH;U8J.P@)7,N`+5,JFNW:K1-($Q$05`@(*;XJD&^N2X`M4RJ
M:Z=2L*,@(B5S(BX`M4RJ:Z?SMW.S<[6XI$@N("5S`+5,JFNG\[=SL'2X;;)-
MI54N("5S`+5,JFO"T+QG("(E<R(Z("5S(*JZLUVI=RX`I^2DHZCL($UO>FEL
M;&$@JKJDP*VV+B"]T+U4NWNDP*VVK$^G7[9]L=(N`+5,JFN]X:2IJ,^ESJK,
M("(E<R(@I%6F0\5VK:VH[*M(I?.G6"`B)7,B.B`E<P"GWK-.I7D`L.JN80"]
MTJKM`*O8I=\`J]BEWZ1`K=.S<[6R`*O8I=^D0*W3MW.JN@"KV*7?IKBK2*7S
MIU@`J]BEWP"KV*7?JLRJNL5VK:T`JTBESJ5DN+F]6`!#<F]A=&EA("BG2L.Y
MINBHR"D`0W5B82`HI6JDVBD`I=BK9;=\M,$`I=BK9:[)MJ$`I=BK9;KTIWT`
MI=BK9:JZJ,^ESJK,`*78JV6DT:[P`*78JV6JNJJLJG`Z(`"EV*MEJKJMMZ[F
M`*;;K7&D0*C'M6ZD2B5SJ^&ITJUNL/6FYJJZI'6G0"X`L,6D50"PQ:15`$-Y
M<')U<R`HP<FTMK#'M+4I`*;HJ+VZN*3E("A+3TDX+5(I`*;HJ+VZN*3E("A7
M:6YD;W=S+3$R-3$I`*;HJ+VZN*3E+Z]1ITK$]:3E("A+3TDX+54I`$-Z96-H
M(%)E<'5B;&EC("BQMJ=*ID"I3;#J*0"DZ0"XZJ[&J-.WO:97NMD@*+W0L-&F
MTB!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I`*A#I.D`OO"JK+CJKL;"<\3]`+CJKL:N
M=[=JM$T`I.FTP0"FK*CLI.FTP0"_[[[<I.FTP0"EU:31`*=2L*/$YJ;L7VP`
MI%&D1Z3K`*11MFFF[+S&IG(`M.ZDUL%9L<8`N7>S70"Y=[-=PT.FX@"Y=[-=
MJKJHK:7WP]&G3P"Y=[-=L\:GT;_]`+EWLUVI4J5/N-&J4KZY*%-H96QL*0"Y
M=[-=JKJQQJ?'JFNK:#H`N7>S7:JZL<:GQZ3HIE8Z`*EWN'$`IU*PHP"G4K"C
MP'BF<Z[F`*=2L*.]5+M[`*=2L*.X<[+5`*=2L*.L]K_]`*=2L*/%=JVM`*=2
ML*.A0K)-JL6V;*7S`*=2L*.K]K9SJKJFYJRP`*=2L*/`>*9SKN8`IU*PH\3F
MINP`IU*PH[)[IG.JNK3`I4Z\RZI/`*=2L*,B)7,BJKK%=JVM`+U4J7>M;J=2
ML*,B)7,BJKK%=JVMI4BDSJ:XQ7:MK2`_`*=2L*.F0P"G4K"CJ=*_[[[<JKJH
MK:7WP]&G3[CJKL8`IU*PHZ78JV6JNL3FINP`IU*PHZ78JV6JNJ9#`*=2L*.S
M;ZW3NDNM;@"G\[=SM7NFH2`B)7,B(*1WIU*PHRX`N[RP9:[)MJ$`1&5N;6%R
M:R`HI*:SP2D`K;"^K0"PW<-$M'FM>@"T>:UZ`+1YK7H`LM.X8"`HO="PT:;2
M($AO<F1E(+!/O_W`R:[7*3H`LM.X8+W0L-&FTJATLLZZWK)ZM6Z__2X`K..U
M;P#%4\))M\6KUP"SS*OAI$"D<*[)JKK%4\))M\6KUSH@`,53PDFWQ:O7.B``
ML7&EJJ;<I6L`L7&E:Z;<I:H`I=B__0"E2"`R-""D<*[)J.[%XZ7</P#%XZ7<
MO^^VM0#%XZ7<N-2RTZJZN7>S^`#%XZ7<N7>S^"`H5$%&*0#%XZ7<KN:FH0"V
MQ[!EIEZQ^`!$:FEB;W5T:2`HIDZEK*9A*0"DHZ=2L*,`I*.M;JJ]L;6F<ZCZ
M(&UA:6YT96YA;F-E+G!H<`"G0;U4J7>M;J=2L*.P3[_]MMP@/P"RQ*1`M:>P
M3[_]K$^G7Z5=IW3$YJ;LIE>ZV3\@IG"J1ZQ/O="DQ+_O+@!$;VUI;FEC82`H
MIFBI^J6GI5LI`$1O;6EN:6-A;B!297!U8FQI8R`HIFBI^J6GI5NF0*E-L.HI
M`,'9J%.FL[%BN+FVW#\@M?FE52X`I%6X_`"D5;C\("5S`*15N/RS7:EWP,FN
MUZ5TIG.LL"!02%`@M7NFH2X`I%6IU*5<K^"J[0##Q*M^`+EQI&RV;*7S`+_Y
MNWX`16-U861O<B`HI,RERJ9HNK@I`+USO^@`O7._Z"`B)7,B`+USO^BPS[;T
M`+USO^BX<[+5`+USO^BZ2ZUN`+USO^C%=JVM`+USO^C%=JVM`+USO^@E<ZJZ
MQ7:MK0"]<[_HI,##_KM0PT.FX@"]<[_HO^^VM0"]<[_H(B5S(JJZQ7:MK0"]
M<[_H)7.JNL5VK:T`L="H?`!%9WEP="`HKDJDSBD`16P@4V%L=F%D;W(@*,+$
MNKBERZ9H*0"DN*7S+BXN`+EQI&RV;*7S`+EQI&RV;*7SINVG?0"Y<:1LMFRE
M\Z;MIWVELK:WIVNF6"X`N7&D;+9LI?.]5+M[`$5M86EL+71O+5--4R"Y:+E$
MOKD`JNVQH;+%N+D`LDVJQ;I+K6X`JL6EU:M(I?,N`*K%I=6ULJI'+@"JQ:75
MMVJT3;:UI=@`I+FS7*;;P\"T6;2AI$JWTZ3YJ.RK2*7SI*0HNO2MMKUSO&>\
MTJ:A*2`_`+'2L,JWQKFKI6O!Y*5<K^"J[3\`M;*G]*9^I?<`J?&D:KUSO^B^
MN0"F<*I'IT&[W:UNK:NS7;%+O5@LO="_Z:1*I$"MTZ9WI?ZPW:5Y+*C2IG`@
M)Z=!PV2JJZJZIE>ZV2`_)SH`IF*FN;_II$J\=KFSJKJZ]*=]`$5Q=6%T;W)I
M86P@1W5I;F5A("BHJKE$M%BDNJC(*0!%<FET<F5A("BDS*7?KU.HO:9W*0"_
M^;M^`*O8I=^PS[;T)7.NR;5OI<V_^;M^`*=2L*.F4*A"P>/"23H@)7,@KLFU
M;Z7-O_F[?@"G4K"CIE"H0K!/O_TZ("5S(*[)M6^ES;_YNWX`Q:JH^J2ZKF4Z
M)7,@KLFU;Z7-O_F[?@"G\[=SL4N]6#H@)7,@KLFU;Z7-O_F[?@"\9Z1*("(E
M<R(@KLFU;Z7-O_F[?BX`17-T;VYI82`HMU*H1J6GJ,@I`$5T:&EO<&EA("BF
MYZ_!I/&HR"D`NMBQV@!%=7)O<&4@*+S:K'<I`*A#(#$U(*3`Q,$`J$,@,B"D
MP,3!`*A#(#,P(*SMQ,$`J$,@-2"DP,3!`*A#IKBU;J1*`*A#(#,P(*3`Q,$`
MJ$,@,2"DP,3!`+UDJ-*MR#H`L/6FY@"N:;9]`*YIMGVXZJ[&IZ@`K6ZH1"`G
M*2<`J.RTP:3I`+C1NZ&M^P"VUZ58`+;7I5BZ2ZUN`*MEM+K#0Z;B`$944""D
M5[;'LUVI=RX`I[F^XZ2ZKF5?=0#%JJCZL+ZF;K-=J7>EHK'1`+5,JFNS<[UU
MIMP@3$1!4""F^*I!OKDN`+5,JFNS<[UUIMP@4TU"(*;XJD&^N2X`O<:[<Z6B
ML=&FVR`B)7,B+@"]QKMSI:*QT:CL("(E<R(N`+5,JFNKV*7?I$"MT[=SJKH@
M4T%33""S<[&U+@"W:+*^I:*QT:CL("(E<R(N`,)>J/JEHK'1.B`E<P"TMK-Q
M`$9A;&ML86YD($ES;&%N9',@JFO$]:=*NM:X<ZYQ("BPJ+JXNONOQ[2UN'.N
M<2D`1F%R;V4@27-L86YD<P#$6:VKO_F[?CH`ML>O=0"VQZ]U`*1'I.L`MU#$
ML0"W4,2Q.B``I/*D\JM"`+5UO,BP?;.W`,3FINRP?:9#`$9I:FD@*+2TP-DI
M`,#)KM>\QJ78.B`E<R"MT\#)KM<`P,FNU[S&I=@Z("5S(,#)KM<`P,FNU\%@
MNMX`P,FNUZ97NMD`P,FNU[_OOMP`P,FNUZ17ML<`P,FNUZ17ML>E7*_@I;RS
M4:3DM*DN`+E,PF^^N0!&:6YL86YD("BJXL3U*0"D5Z5BI.L`I%>IM@"I5*EW
MI/&HT@"D5Z15Q$&MRP"O0K#*`,/Z`*78O_T@)7,@I*.F<Z9B`*9RJZS#0Z;B
M`*VYJJL`IEVLL,)SQ/V^N:C#I;RDY+2IO':YLZ5<K^`N`*[PMDBY=[/X("A4
M048I`+EWL_BDT;S&("BY=[/XI-&\QJ5=K$&EU:31I4BDSJE=MJ&JNKCJKL8[
MIG"J1[EWL_BDT;S&N/NJ^+%.IONESJ3QN/N\9;14JKJJJ:VQ*0"GT;!/L4N]
M6"`_`*KML^8`I'"[>0"D<+MYP_ZKK`"D<+MY`*1PNWD@,@"]U[["`*;;L,K"
MX*M(`*Q0M,&DK0"NV*Q;`$9R86YC92`HJFNPZBD`1G)A;F-E+"!-971R;W!O
M;&ET86X`1G)E;F-H($=U:6%N82`HJFO$W;M<J,BHNBD`1G)E;F-H(%!O;'EN
M97-I82`HJFO$W:S!IU&EIZ;HJ,@I`$9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<P"Q2*7SI$@`L7$`I[F^X[1YK7H`NJ&DZP"E_J97`$=A8F]N("BE6[1>
M*0##P+19.@!'86UB:6$@**7,I/&HR"D`I$"OZ[_OMK4`LJ.ES2`E<R"MTZAT
MLLZS7:EW`*1WLJ.ES:JZLUVI=[CJKL8`1V5O<F=I82`HL^RJ=JC(ID"I3;#J
M*0!'97)M86YY("B\=[#J*0!':&%N82`HK7NOQRD`1VEB<F%L=&%R("BJO:6L
MP[FJ^RD`IE>ZV0"K9:FY`*WTO'>ZN`!';V]G;&4@IF&YSP!';V]G;&4@MVJT
M30"FQ[:E`$=R965C92`HI\;#OBD`I\;#OJ3E("A)4T\M.#@U.2TW*0!'<F5E
M;FQA;F0@**[FLZ[$]:YQ*0!G<F5N861A("BNYK?GK\>Y1BD`N'.RU;K>LGH`
MN'.RU:97NMFDH[%OJL6EU0!'<F]U<%]L9&%P.B"U3*IKMW.\5[ASLM4@)7,N
M(*;XJD&^N:9>P+,Z(`!'<F]U<%]L9&%P.B"U3*IKIU*PH[ASLM4@)7,`1W)O
M=7!?;&1A<#H@M4RJ:Z?SMW.X<[+5("5S`+ASLM4`1W5A9&5L;W5P92`HK?2\
M=ZREM+8I`$=U86T@*,/VKG$I`$=U871E;6%L82`HI<JF8;"HJ=0I`*[FKJ:F
MZ*YQ`*C3NZO%=JVM`+-8J\BO9*BE`$=U:6YE82`HM%BDNJC(*0!'=6EN96$M
M0FES<V%U("BT6*2ZJ,BD\:_!ID"I3;#J*0!'=7EA;F$@*+M<J,BHNBD`ME>D
MY;-SM;*[>:BE`*?DI*.H["!(5%10(,7GP](N`$AA:71I("BN_*9A*0#"^+3J
M+;ITNN(`QD<`JNW`60"J[<!9`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<P"D:KEPJT(`I\:G0JC3I.4@*$E33RTX.#4Y+3@M22D`L*JKUP"[
MH:GZ`+USO^B^N:C/I<Z[H:GZ`+NAJ?H`I6*R>0"S;[C,K$_`R:[7JKJV?:EL
M.@"PJ@"N85]M`$AO;'D@4V5E("BQZ[_-J:,I`*YA`*;MKF&F8:=]`*YAI=B_
M_0"F[:YAN7&XW`!(;VYD=7)A<R`HI[NSHZG4M+4I`$AO;F<@2V]N9R`HK;NT
MY"D`2&]R9&4`2&]R9&4O2V]L86(Z(+9LI?,@)3(D<R"DI+E*J.RU3*[$JKH@
M)3$D<R!834RXZJ[&`$AO<F1E+TMO;&%B.B"U3+9LI?.^0:98JJNE\R`E<P!(
M;W)D92]+;VQA8CH@MFRE\R`E,B1S(*2DI^2DHZCLJJNE\ZNLND$@)3$D<P!(
M;W)D92]+;VQA8CH@I'>FJ*5<JKJROK"C("5S("(E<R(`2&]R9&4O2V]L86(Z
M(+[CIEBD=;5[N]VM;B`G9&]M>&UL)R"JNB!02%`@J;6F^0!(;W)D92]+;VQA
M8CH@M4RJ:ZO8I=\@)7,@JJNE\ZJZ(%A-3""^\`!(;W)D92]+;VQA8CH@M4RJ
M:[*^L*,@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(+5,JFO`\JCZLZ&E]R`E
M<R"KK+I!JKH@34E-12##T:=/N+F]6`!(;W)D92]+;VQA8CH@M4RJ:Z90J$(@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(+5,JFNF4*A"I,"HR3H@)7,`2&]R
M9&4O2V]L86(Z(*6\JKZJNJ3`J,D@(B5S(@"D]*6MO74`I/2EK;G4I5(`I/2E
MK3H`IT&F<*;SJ.RFN2`_("B]T+'4K7HA*0"G0:UNIEBHUJ9HI-:MT\3FINRI
M3S\`Q.:F[+S&I=BF0*UP/P"G0:UNIEBHUJ9HI-:F0ZE//P"WPZO7`+?#J]<Z
M(`"WQKU=I&JN=@!(=6YG87)Y("BF2:3ZIU$I`$E-05`@MFR]8ZO8I=^EHK'1
M.B`E<P!)34%0(+9LO6.G4K"CI:*QT3H@)7,`24U!4""V;+UCNL^ZT+!TN&VK
MV*7?I:*QT3H@)7,`25`@INRG?0!)4""F[*=]M4RJ:ZC/I<XN`$E0(*;LIWVH
MPZ2CIF(@0TE$4B"JNJ2YLURPS[;TI*0N`*9BJ^&ML;2AI$JF0U]N`$EC96QA
M;F0@**9"KG$I`*_"N<^EW``E<ZJZN<^EW`"YSZ7<I,ZDY:9R`*BMI??#T:=/
MJKJF5[K9.@"F<*I'M4RJ:Z6_O52F8<7CI=PL("5S(*5(I72V?;'2MFRE\ZGS
MMW.U^+6AM^VDI"X`J,^ESB!);G1E<FYE="!%>'!L;W)E<B#"<\3]OKFNR:9P
MJD>H4Z:SK-VH[*7TIO.JNJ1PN<^EW"P@IT&E::_@N]VM;J3$O^^S;ZW3MK6E
MV*5(P_:SK"!03D<@O':YLZJZP?3"PZ[$JD<N`*9PJD>LW:CLLV^K:*A3IK.\
M=KFSJKJP5*ZG++-OJNVEW*=!JKK"<\3]OKFU3*IKQ>.EW*17ML>JNKQVN;,N
M`+QVN;.Y=\3].@"\=KFSNO2G?0"\=KFSNO2G?3H`O':YLZC3IMO#P+19`+QV
MN;.HTZ;;P\"T63H`I%>VQ[QVN;,`O':YLP"VUZ1*NDNM;BP@J$+&2B`E9`"V
MUZ1*+""H0L9*("5D`+;7I$HOMM>E6+I+K6X`MM>D2L3FINPZ("5S`+;7I$K$
MYJ;L.@"F8JOAK;&TH:1*ID-?<P"_Z:1*I*.EO[U4JKJG0*7.O5@N`+W0P,NL
M9*=!JKJHSZ7.JLRF5[K9I,ZQ2[U8`*C/I<ZJS*97NMFDHZ6_O52ISJK,N7&D
M;+9LI?.F[:=]I'?%W*?S+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R
M>BX`O%>E6\%9L<8`26YD:6$@**9,J]<I`*W3IT^HSZ7.JLP`26YD;VYE<VEA
M("BF3*6G*0"XZK!4`+CJL%0`M4RE::7.JKJXZK!4+@"F8JOAK;&TH:1*Q.:F
M[%]O`+2AI$JYSZ3Y`+2AI$JJ[:[F`+2AI$JZ]+CTLW.UL@"F8JMEK;&TH:1*
MQ.:F[%]#`*9BI=BK9<3FINRKX:VQM*&D2J1`K=.W<\3FINP`IF*EV*MEQ.:F
M[*MEK;&TH:1*I$"MT[=SQ.:F[`"F8J78JV6F0ZOAK;&TH:1*I$"MT[=SID,`
MIF*EV*MEID.K9:VQM*&D2J1`K=.W<Z9#`*9BI=BK9;A@PDFKX:VQM*&D2J1`
MK=.L<;BH`*9BI=BK9;A@PDFK9:VQM*&D2J1`K=.L<;BH`+2AI$JE:;3`I4Z\
MRZI/`+=SL4N]6+%.L4BU;ZCLLV^MT[9LI?.F8:=].@"F8JOAK;&TH:1*P'BF
M<Z[F`*9BJV6ML;2AI$K`>*9SKN8`IF*KX:VQM*&D2L3FINP`IF*K9:VQM*&D
M2L3FINP`M*&D2K9LI?,`IF*KX:VQM*&D2JQQN*@`IF*K9:VQM*&D2JQQN*@`
MIF*KX:VQM*&D2J9#`*9BJV6ML;2AI$JF0P"F=Z7^L-VE>:JZM:JNUSH`M*&D
M2B_%W*?SO':YLP"TH:1*+\7<I_.Z]+CTLW.UL@#"2;S&I*.HK*5(IMRI\[5,
MJFNVQ[!EM;FP=+AMN'.RU2X`PDF\QJ2CJ*PN`+[CO,8`ON.\QJ9#`+5,KL2J
MNB!51$@HJ,^ESJK,N.JNQJKMP%DI+@"U3*[$JKH@6DE0(+CJKL8N`+5,KL2J
MNL"SI<ZU>Z:A+@"U3*[$JKJGY::XN+F]6"X`L&6E6*JZN.JNQK5,KL0N`+5,
MKL2JNJ78O-"F[:=]`+5,KL2JNL#)KM>NYJ:A`+5,KL2JNK'"Q7:]6"X`M4RN
MQ*JZIF&PSRX`M4RNQ*JZ(&US9U]T>7!E+@"U3*[$JKJISJ?DI*.H["!A<&E?
M:60N`+5,KL2JNJG.I^2DHZCLL-&\QBX`M4RNQ*JZI/?%=JVM+@"U3*[$JKJY
MV:;QP]&G3[U8+@"U3*[$JKJRHZM^O5@N`+5,KL2JNK-QL%2H\ZEW+@"U3*[$
MJKJFK*7SI$@Z(B5S(@"U3*[$JKJDP*C)JJNE\RX`M4RNQ*JZJ-.WO:;MIWTN
M`+5,KL2JNKA5L.J]6+CJKL8N`+CJLJ,`IEZT7[_OOMP`27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B`HI>RNU"D`27)A<2`HI>RIU*=**0!)<F5L86YD("BW
M4KJXQ/4I`$ES;&4@;V8@36%N("BPTJYQ*0"GO;.AN7"K0@!)<W)A96P@**5(
MIN*F0RD`P[&U;ZK,`+'7Q>D`271A;'D@*+AQI&JG42D`2F%M86EC82`HI/JV
M4J5;*0"D0*3K`$IA<&%N("BDZ:6[*0"DZ:3E("A)4T\M,C`R,BU*4"D`OT&F
MZ*YQ`$IO<F1A;B`HK/FEN2D`I$.DZP"DNZ3K`+GON_0`N&VDI`"EJJ5KN>^[
M]`"^8:6JN>^[]`"^8:5KN>^[]`!+87IA:VAS=&%N`*M/KV2M[+S+(#\`2V5N
M>6$@**K6J,@I`$ME<F)E<F]S(+M[P]*_^;M^+@"NUJ3?MW.DX@"J]\9?J]BE
MWP"J]\9?KU.\>`"J]\9?JOBKUP"J]\9?JZRZ00"J]\9?NWFJ:P"EV*MEJKJD
MO;9]JO?&7Z;XJD&^N:2D+*1WN&>F<Z9BIT&JNJKWQE\N`*C@M:,`2VER:6)A
M=&D@*+#RJ+VDVK2U*0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U
M8FQI8R!O9B`HI5_!^BD`2V]R96$L(%)E<'5B;&EC(&]F("BK;L'Z*0#!^J3E
M("A%54,M2U(I`$MU=V%I="`HK.RKPJ]3*0!+>7)G>7IS=&%N`*JIK;&P=+AM
M7WD`NWFHI0!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R`HO&2P
MZBD`I%6E8J3K`+/,JO&D0*:XI_.W<P"SS*KQI$"FN+%+O5C%W*?SJ?,`I%6I
MMJ3K`*17IKBG\[=S.@"D5Z1`IKBU;J1*.B`E<P"D5Z1`IKBU;J1*.B`E<R"F
MVR`E<P"D5Z1`IKBU;J1*.B"RQ*1`IKBU;J1*`$QA='9I82`HJ=2RYKK[J,@I
M`*IKJ]\`JJFML;!TN&T`3&5B86YO;B`HOJ2DVKG@*0"EJL/D`*6JP^2J[<!9
M`*6JP^2MR`!,97-O=&AO("B_X*_!IJLI`$QI8F5R:6$@*+_@I/&WYZC(*0!,
M:6)Y86X@07)A8B!*86UA:&ER:7EA("BG4:3QJ,@I`$QI96-H=&5N<W1E:6X@
M**9#I.2TL+2UM6XI`+=,JT(`I'"K0@"FK::SI'"K0@"QWZ:SI'"K0@"D<+!]
MJT(`I'"K0J:SN7``I'"SMP"D<+!]L[<`I;2J;[C6`+-SM;(`LW.ULL))J.PZ
M`,7CI=RNR;-SM;*V;*7SINVG?:CLO7.\9[9LI?.MMJVQ`+-SM;(`ID.E6"`M
M(*C/I<ZJS*5II4BLW:CLLV^MTZM(I?.G6`"F0Z58N.JNQJYW`*9#I5B[H:GZ
MO-##1`"F0Z58JNVNY@"P4;W7N'.RU2W`R:[7PF0`L%&]U[ASLM4MJ$2G50"P
M4;W7N'.RU2W#T:=/N+F]6`"P4;W7N'.RU2V^UJ:SJLP`L%&]U[ASLM4ML4BE
M\Z1(`+!1O=>X<[+5+:UQOEP`L%&]U[ASLM4MJ/JN^*UQOEP`ID.E6+=\M,&E
MHK'1.B`E<P"F0Z58J,^ESJK,I:*QT3H@)7,`ID.E6*C/I<ZJS*JZI5ROX+-1
MP_:SK`"DY;['`$QI=&AU86YI82`HI=^SLZE[*0"X_*1*I*0N+BX`M^VF8:[)
MMJ$Z(`"F8;#/NU"NR;:A`*9AL,\`M6ZD2@"U;J58`+5NI$H`M6ZD2J1UIT``
MM6ZD2J6BL=$L(+W0P,NL9+O5I%6JNJ7.I.&F5ZE-L4N]6"P@M4VKX:VKN-4N
M`+5NI$JEHK'1+@"J^*5Y`+=2L:$`IT,`I'"\9Z?&P[Z\QJ9R`*1PO&>IU*1"
MO,:F<@"D<+QGP[FPJ+S&IG(`3'5X96UB;W5R9R`HOV.TR[/Y*0"DZP"H0Z3I
ML%2NIP!-4RU43D5&(*K^I5O`R:[7I*2H4Z:SN.JNQBX`35-'`$UA8V%O("B_
M1*KY*0!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8@*+"HJ.2Y>:9`J4VPZBD`36%D86=A<V-A<B`HL*BY1J5;M+6E6RD`Q5VS
M3@"V;*7S`+9LI?.ZWK)Z`*O8I=^S<[6R7VLN+BX`36%L87=I("BPJ*G4J\(I
M`$UA;&%Y<VEA("BPJ*C3INBHR"D`36%L9&EV97,@*+"HNKBF8:32*0!-86QI
M("BPJ*=1*0!-86QT82`HL*BZN*5,*0"ZWK)ZIT&JNJ3`P_XLJ,.E0JRPI,##
M_K-=J7?#0Z;B+@!-87`R-""F8;G/`$UA<%%U97-T(*9AN<\`I%2DZP##Y*S)
M`+S0L$^FJ""LW;E,+Z6\K-VY3`"\T+!/IJBHY*5,JKK#T:=/("BHTJ9P+B"M
MJZUN+Z1WIE["T"D`36%R<VAA;&P@27-L86YD<R`HL*BN3+JXN'.N<2D`36%R
M=&EN:7%U92`HL*BTHZ6GITJN<2D`I,>P=,3FINRDI`!-875R:71A;FEA("BM
M5*=1MO"EIZC(*0!-875R:71I=7,@*+ROJ+VFZ+2U*0"DN;-<JKJSS*1JPDF\
MQBX`JOZE\[S&I=BD=[97I5BDN;-<I%>MK2X`L\RJ\2`R-""D<*[)JKJSS+"J
MM\6KUSH@`+/,JO$@-B"D<*[)JKJSS+"JM\6KUSH@`+I+K6ZD5ZVMO,:EV`"P
MS[;TI%>MK;S&I=@`I+FS7+/,I&JJ^*O7`*2MI.L`36%Y;W1T92`HL*BL^:]3
MKG$I`,+EOL<`IJBM^P"Z2ZUNI+JN90"_[[/FO-*FH3H`IEBHUL!XIG.NY@"V
M;*7S`+9LI?/%Y\/2I'>GN::H+*;]K$^HSZ7.JLRJNL.QL[FK;[5,JFNS<;E,
MQ>?#TBX`PK*P5*1WN4RTP2X`PK*P5*NLND$`365T87(@L,^V]+5,JFNHSZ7.
M+@!-971A<B"PS[;TM4RJ:ZC/I<XN(++3N&"]T+#1IM*H=++.NMZR>K5NO_TN
M`$UE=&%R1$(@J7REO+-SL;4N`*3HJFL`I.BJ:R`B)7,B(*6\LU&I=[AQ`*3H
MJFNEO*EWN'$N(*5(J4FE<Z3HJFLZ("5S`*2]J.X`365X:6-O("B^I:;HK?0I
M`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8@*+%+ITK#N:6GINBH
MR"D`I*2VH0!-:6UE(*NLND$`L\RJ\2`R-""D<*[)JKJSS*=#M\6KUSH@`+/,
MJO$@-B"D<*[)JKJSS+"JM\6KUSH@`+/,M76Q2[U8KL2TP:E\I;RH[+3!`*Q-
MKF<`POBVM0"GY*2CJ.P@4$5!4B"E7;C+($A45%!?4F5Q=65S="X`LUVI=\#)
MO_*EHBX@IG"J1ZUNJ,^ESK-OK=/`LZ7.M7NFH:=!I;*VM[)[IF*T3K*CI<VE
M3"X`I^2DHZCLPK*P5*JZ($E$+@"GY*2CJ.RELK:WJKH@4$5!4B"E7;C+($UA
M:6PN`*?DI*.H[+=\M,&JNB!)1"X`K%"TP:1``*;FL,JV;*7S`+?%J4T`I_.W
M<Z3IM,$`K=>G[[KTIWT`I;^F8KUSO^@@)7,@I*0`O-*RU0!-;VQD;W9A+"!2
M97!U8FQI8R!O9B`HO*^ZN*9HI<LI`$UO;F%C;R`HO*^OQZWT*0!-;VYG;VQI
M82`HNUBE:BD`I.NDSJ9^`*A#I.L`NUBVZZG4KU,`I.NLVP"F8K+$)62FYJ?D
MJ.RJNL3FINR\QJ78I'>V5Z58N7>TP25D+@"\KZREK?0`IFBVLZ[)M+@`IFBV
MLZ[)L[$`M+BNR:9HMK,`I%6RO@"EJK*^`*5KLKX`I%>RO@"D5;*^`*17LKX`
M36]Z86UB:7%U92`HLO:D5*3QITHI`+W&O^^FH:15J=2E7*_@JNT`O<:_[P"G
MVJJZL6*XN0"GVJJZL6*XN;CJL%0`I]JJNK/&I]&__0"MTZ1(K[BE>`"MTZ1(
MK[BE>*VVK;&P=+AM`$UY86YM87(@*+UQJ&PI`*2C+*?:I*.F4+=.`*97NMD`
M3F%M:6)I82`HJ+JFS*3QJ,@I`$YA=7)U("B_U;Y\*0!.97!A;"`HI:>J>;JX
M*0!.971H97)L86YD<R`HLOS$]2D`3F5T:&5R;&%N9',@06YT:6QL97,@*++\
MQ-VF=Z9AID.TM2D`3F5T<V-A<&4@K+"P\L*FJKJZ]*=]`$YE='-C87!E(+[,
MP]*G0+QONO2G?0!.971S8V%P92"^S,/2K$:UIKKTIWT`3F5T<V-A<&4@I_.W
M<[KTIWT`3F5T<V-A<&4@IT"\;[KTIWT`3F5T<V-A<&4@4U-,(*;XJD&^N:97
MNMD`3F5T<V-A<&4@OLS#TJJZM?FXT0!.971S8V%P92"^S,/2JZRZ00"Z]+CT
MI'6HXP"Q<:6\`$YE=R!#86QE9&]N:6$@*+=SL]BHO:9HI:>HR"D`MW.\5Z3`
MP_X`O&>K2+6Y("5S`+=SI.L`MW.\5[I+K6X`MW.HSZ7.JLRF5[K9("BK1*6R
MK6XI`$YE=R!:96%L86YD("BOPZ;HQ/4I`+=SL4N]6`"W<[%+O5BQ3JGS)7BH
M[+3!+@"W<[%+O5BDH[+%IE@N`+=SM?BUH2`H7V)L86YK*0"W<[M$`+=SNT2X
M<[+5`*15I$"H0@"D5:1`K=._[[:U`*15I$"MM@!.:6-A<F%G=6$@**6GI5NI
MU*7**0!.:6=E<B`HI:>DZ2D`3FEG97)I82`HJ6"DSJ=1J,@I`+'?I%<`3FEU
M92`HK\.N2JYQ*0"G7P"U3*5IJ-'%XZ7<KG2RIZJZLUVI=[CJKL8N`+5,I6FE
MSJJZM::RI*O8LWD@25-/(+QVN;,N`*A3IK.GY::XO,NFH2X`J=*K_*EWJKJF
M[+AMI%>H4Z:SL,^V]*9SIF(`J%.FL[2CJ-&FYJC&ON2F5[K9I4BHT2!-0T%,
M(,7GP](N`*A3IK/%W*?S+@"U3*IKIF*EV*MEQ7:MK:2DO%>E6Z:XQ7:MK2X`
MJ%.FLZO\J7>JNB`E<R"S7:EWN.JP5"X`J%.FLZO\J7>JNB!&5%`@5D93(+-=
MJ7>XZK!4+@"H4Z:SJ_RI=ZJZ(%-13"!61E.S7:EWN.JP5"X`J%.FLZO\J7>J
MNB!344PM1FEL92!61E.S7:EWN.JP5"X`M4RST;YLPDF\QBX`I;RTHZC1I=BJ
MNBX`P,FNUZ6\I%>VQP"GY*2CJ.P@:4-A;&5N9&%R(+CJKL8N`*?DI*.H[+G/
MI=PN`*;LN&VXZK!4J7REO+-=J7<`J7REO+2CJ-&F[+AMN.JP5"X`I;RTHZC1
MPK*P5"X`I;RK_*EWIE>ZV2X`M4RE::C1J-.[JZC/I<ZJNK/&I]&__2X`J%.F
ML[I+K6X`J%.FL[I+K6ZRQ:98MVJT3;'XI?,N`+5,NDNM;J5IJ-'%XZ7<`*6\
MJ_RI=[BYO5@N`*A3IK.K_*EWL4N]6*5(J-$@2%144"#%Y\/2+@"H4Z:SJ_RI
M=[%+O5BE2*C1($E-05`@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!+97)B97)O
M<R#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1($QO9VEN(,7GP](N`*A3IK.K_*EW
ML4N]6*5(J-$@4$%34U=$(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@4TU"(,7G
MP](N`*6\O^FD2B!/<&5N4U-,(*1'I+BP]:;FP,FJNJ7^N/2N?"X@4$M#4R`Q
M,B"S5Z[FJKJE6[%+N.JNQKO=K6ZESJCLN-.U>Z:A+@"H4Z:SJ]V\9JJZM?FE
M5:73O=`N`+K/NM"P=,-"I;RS7:EW`+5,KN:]=0"I?*6\J_RI=\3FINRDP+EJ
MIG*DN"X`M4RNV+UU`+5,IKG`R:[7`+5,O,BF<Z78O_VE::C1I]:H^BX`I;RV
MQ[!EJ,^ESJK,IE>ZV:G.L4N]6"X`M4RE::7.JKH@6$U,(+CJKL:S4;;'IEX`
MJL6EU:W(`*WLJ6RS7:EWP,FDI*?DI*.H[*JII;NXZK!4+B"MJ[=SLJ.ES;-=
MJ7?`R2X`IF*G0:JZLUVI=\#)I*2GY*2CJ.RJJ:6[N.JP5"X@K:NW<[*CI<VS
M7:EWP,DN`+I+K6Y?=`"U3`"U3"`H=7-E(&EM<&QI8VET*0"DZ:;5L-*DY2`H
M25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD("B_U;K6ITJN<2D`I5^E8K)Y
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D@**Z_J\(I`*M$I*>K
MX0"K1*2GJV4`I*.L3Z1`K=.EV+_]`+5[IJ&I?*6\I[FFJ"X`I*.S7:EW`*6\
MLU&DY+2I`+I+K6ZDP,/^`+I+K6ZRT[A@`*9#I5BZ2ZUN`+I+K6ZDNJYE`+I+
MK6ZDNJYE7U0`I^2DHZCLNDNM;BX`L\:GT;_]7W``L\:GT;_]JKJF5[K9.@"S
MQJ?1O_T`L\:GT;_]I;*VMZUNIK.D0*W3IE>ZV2X`L\:GT;_]`+I+K6ZDP,/^
M`*A3IK.E:<)SQ/VJNBRF7J5H+@"D4:1`I.L`O,:F<@"F<J2XO,8`IG*DN+QE
MJ]<`IN:\Q@"G\[=SL'2X;;ASLM6NR:6\J_RI=[S&I=@N`$]+`*JKI?,`JJNE
M\ZO8I=^JS`"D2[9IINP`I%&DZP"_[*2]J\<`MW.Q2[U8I;*VM[M0PL*Q2[U8
MI*.F4"X`PL*Q2[U8`,+"L4N]6*2CI;^]5`!/;6%N("BJ_+#2*0"E=::S($E-
M05`@IOBJ0;ZYI.2TJ:M(I?.G6*3`J,FE7*_@+@"E=:2YLURD0*W3MFRE\Z;M
MIWTN`*5UIK.^UJ:SJLR[4*ATLLZZWK)ZK?NE::5(Q=RG\Z9`J,G%=JVM`*9B
MMW.JNK7XM:&V?;'2`$]P96Y34TP@O_F[?CH@M4RJ:[%Q(%,O34E-12##L;.Y
MJOZE\[C1MGVXZJ[&+@"F8K=SJKJU^+6AMGVQTK-SM;(`IT"W?JATLLX`O^^V
MM0`E<[_OMK4`MK6EV+USN+D`LM7"M`"RU<*TL^:F[`"RU<*T`*WLJ6S`LZ7.
MM7NFH;S+JD\`IF(@)7,Z(*2DJKJM[*ELO,NJ3RX`J.2E3`"HY*5,N.JP5`"^
MUJ:SJLS%=JVM`%!!32#%Y\/2M4RNQ"X`4$5!4CHZMFRE\Z;XJD&ZW0!01U`@
MO,:F[,.QL[D`4$=0(*5;L4NXZJ[&`%!'4""DO;9]JO?&7P!01U`@I'?#L;.Y
M+Z1WI5NQ2R"XZJ[&`%!(4""U>Z:AO5@`4$A0(*_SO5H`I,BKX:1PJT(`I,BK
MX;!]JT(`I,BKX::SL[<`I,BKX;!]L[<`I,BKX;2X`*3(J^&Y<*M"`%!/4TE8
M(&5X=&5N<VEO;B"_\J6B`%!(4""O\[U:7T@`N=2E4@!086MI<W1A;B`HI-JP
M\K2UJ5HI`%!A;&%U("BIK:];*0!086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D("BDVK#'M+6I6J;[N^*PSRD`4&%N86UA("BDVJZSL*@I`%!A<'5A
M($YE=R!'=6EN96$@**3:I:RHR+=SM%BDNJC(*0!087)A9W5A>2`HI-JIU*9C
M*0"F:+:S`+%+O5@`L4N]6,7<I_.GN::H+@"Q2[U8I*.EO[U4`*A3IK.K_*EW
ML4N]6*5(J-$@4D%$2553(,7GP](N`+%+O5B]5+M[`+%+O5@Z`+%+O5@Z(`"Q
M2[U8I;*VMZ=KIE@N`+9+I%<`MDND5P"X]*Y\`*O=O&:U;K_]H4<`IJBM^P"F
MRJ3`I/$`L/6FYKK[Q4"^WJ=``+5NI$JKX;#UIN:Z^\5`OMZG0#\`Q7:MK0`B
M)7,BJKK%=JVMI;RS4:=2L*,N`*9SJ/J^1*G:`,5VK:T`Q7:MK;K>LGH`I]JJ
MN@!097)U("BOM;Y\*0##9*JK`%!H:6QI<'!I;F5S("BUX:O?NZLI`+EQN-P`
MP\"T60!0:71C86ER;@"YLZ_``+W0MFFD2L!XIG.NYL))O^\`O="]5*EWK6ZR
MOK"CIKFDN*7S.@"]T+U4J7>G0:UNI*3"7Z:YI+BE\ZJZLW.ULBX`O="_Z:1*
MI$"MTZ3KI?>DSJ9^I?<N`+W0O^FD2K=SO%>DP,/^JKJF5[K9.@"]T+_II$JD
M0*W3IK.NQ*JZ($E0(*;LIWT`O="_Z:1*I$"MTZ:SKL2JNJ3IM,$[I,2_[Z:Y
MI.NE]ZJZI.FTP2X`O="_Z:1*I$"MTZ:SKL2JNJ[)MJ$N`+W0M*.HT;#=PT2J
MNKI+K6XN`+W0O^FD2J=!JKJHSZ7.JLRF5[K9I,ZQ2[U8`+W0OES%JJ15ID.D
MNJYE+J=!I;*VMZ90MTZS;ZC'J,:VM:1^K^"HSZ7.J'2RSBX`O="_Z:1*MW.J
MNJ3`P_ZF5[K9.@!0;VQA;F0@**IIQ/4I`*Q&JG8`I^NRO`!0;W)T=6=A;"`H
MN+*UY:3Z*0"\=KFSINRX;0"J[:[FINRX;0"[O+!EMFRE\ZCLLV^MTZM(I?.G
M6"`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`+/,JO$@)7,@I'"NR:JZK;"K0K9Q
M.B``K;"K0CQB<B`O/K[WLG8`4')E9G-?;&1A<#H@I^2DHZCLJ=*[W:UNJKH@
M3$1!4""IM:;YKDVE\RX`4')E9G-?<V5S<VEO;CH@I^2DHZCLJ=*[W:UNJKH@
M<V5S<VEO;B"IM:;YKDVE\RX`KO#`HP"N_*6MK;&N\,"C.B``KO#`HSH@`+EW
MQ/T`IF*W<ZJZM?BUH;EWQ/V\=KFS`*17I$"MT[_OMK4`ID.F3*3EI?,`J'"Q
M2ZKWQE\`L-W#1`"PW<-$M'FM>@"Q3:[7`+2CI=RDNJYE`*2]MGVJ]\9?`*2]
MMGVJ]\9?NG2ZX@"DO;9]JO?&7[CJL%0`I+VV?2^H<+%+JO?&7[GOJ,.EO+-1
MLJ.ES2X`4'5E<G1O(%)I8V\@**IIIFB^I*95*0!1871A<B`HI62Y1BD`K&2X
MWP"ZS[K0L'2X;0!24T$@I+VV?:KWQE\@*"5D(*;LI+@I`+_OOMRV<P"K0@"F
MK::SJT(`L=^FLZM"`+!]JT(`JT*FL[.W`*M"PN"SMP#`2+[WI'"[>0"D\;)V
M`,6JJ/H`Q:JH^K9LI?,`KW6JNJUNIU*PHR`E<R"VW#\@LV^VM;[>IT"Q3K5,
MJFNK[+1?+@"]5*EWIU*PHZ:YNDNM;B`_`*]UJKJM;K)-L*.HSZ7.JLP@)7,@
MJKJXZJ[&MMP@/R"S;[:UOMZG0+%.M4RJ:ZOLM%\N`*CZKOBT7ZWL`*VKMW.^
MX[)Z`*VKMW.^X[)ZL,JZ0:78O_VDN*7S.@"MJ[=SON.R>@"MJ[=SON.R>JW3
MI$BON*5XI+JN93H`L6"S5ZKMI=RFH0##]L%PPG/$_;ZY`*VKQ:H`M?N]UP"[
MM[K=IOBJ0;ZY`+NWNMVZ]*=]("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3H`LKZPHP"ROK"CL,^V]`"ROK"CI,##_@"ROK"CQ.:F[`"E:+"CKN:F
MH0"ROK"CN>\`IMNF^*I!OKF\R*9SI=B__:2DLKZPHZ1WP'BF<ZJZLUVI=[5[
MIJ$N`+*^L*,`IMNDY:7SI*2ROK"CIKFD0+A@PDD`LKZPHZC/I<ZJS`"ROK"C
MJ,^ESJK,.B`E<P"[W:A$I;RS4:9>P+,Z(+_YNWZXN;U8.@"GY*2CJ.RITKO=
MJKJJ0;#(+@`E,B1S(*JZLUVI=Z6RMK>K_*EW("(E,21S(@!61E,@JKJS7:EW
MI;*VMZO\J7<@(B5S(@"S7:EWN.JNQJ6RMK>K_*EW("(E<R(`I;*VM\3FINP`
MK:NS70"MJ[-=L4N]6`"MJ[-=IT&JNK%+O5@Z`*9>IG.SS*OAI$"MTZQDN-\`
MM;*J1P"J\*9>O^^VM0"F0::XO^FD2K=SL4N]6`!2975N:6]N("BO9*6GJ?2N
M<2D`IEZT7[-=J7<`NO2MMKUSO^B^N;_OMK4`P;R[>0"E:\/D`*5KP^2J[<!9
M`*5KP^2MR`"F0Z2ZKF5?=RXN+@"HI*;B`%)O;6%N:6$@*,.YL*BEIZC(*0"Q
MV\+@(#$X,""KUP"P9J[)L'<@.3`@J]>QV\+@`+:VKLFP=R`Y,""KU[';PN``
MID.DNJYE`*9#I+JN90"F0P"NYKUU`,3FINR[4*9#KN:]=0#$YJ;LKN:]=0"F
M0Z[FO74`L/6FY@!2=7-S:6%N($9E9&5R871I;VX@**M8P[FTM2D`4G=A;F1A
M("B_8Z9WN48I`%,O34E-12"E6[%+P[&SN0"V;*7SI'>HSZ7.(%,O34E-12"E
M6[%+`%-!4TP@Q>?#TK5,KL0N`,*RL%0`N.JNQJYWK_.]6@"E6[%+LM>ZW;[W
M`*:HI5P`N.JNQJYWK_.]6E]1`*Q0M,&DNP!386EN="!(96QE;F$@*+ATNZZP
MQZ_'*0!386EN="!+:71T<R!A;F0@3F5V:7,@*+ATITJHO;2UIFBZUJ3.I:>Z
M^[2U*0!386EN="!,=6-I82`HN'3%4Z;HJ,@I`%-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,@*+AT
MI.6TRZ3.KN:WYZBZI$(I`*90I$"MT[7XM:$@*%]S96QF*0!386UO82`HPL2\
MKZC(N'.N<2D`4V%N($UA<FEN;R`HN'2PJ*=1O]4I`%-A;R!4;VUE(&%N9"!0
M<FEN8VEP92`HN'2F:*S\I,ZTMJI,INBD\2D`O<.L4+2CJ-&JS`!3875D:2!!
M<F%B:6$@**A&KU&F8:K\J=2G0BD`P'BF<P#`>*9S("(E<R(`P'BF<R`E<P#`
M>*9SO^^VM0"Q3K*CI<VJNK-=J7?`R:5((%!(4""[>:BEKN:FH<!XIG.H[*=!
MJKJF^*I!OKF\R*9SI=B__:2D+@"S7:EW("5S(*1WP'BF<RX`I_.W<[5[IJ&D
M=\!XIG.H[#H@(B5S(BX`N7.L4+EPJT(`K.R^QP"W:K1-`+=JM$VDWL"Z`+=J
MM$VULJI'`+=JM$V]9+/R`+=JM$VDNJYE7U0`O^^^W,#)KM<`O^^^W*1`K=.D
MZ;3!`+_OOMRD0*W3N'.RU:7.I4BW<[Q7`+_OOMRD0*;LMW.JNK[6IK.JS`"A
ML+W0O^^^W*1`I;NSQJ?1O_VAL`"_[[[<I$"SH:;XJD&^N0"_[[[<I$"F[*C/
MI<ZJS*7.I4BW<[Q7`+_OOMRITJ:S`+_OOMRITJ:SI.FTP:2XI?,N`+_OOMRD
M0*W3JJNE\P"DH[_OOMP`O^^^W*UNQ>.EW*JZL\:GT;_].@"I\Z5(I%6JNK7X
MM:&DI+_OJ/JG0:UNJKJF<J2X+J5(M\:YJ[W&NW.ITK_OI.6F<BRU3:OAMDND
M5Z3EI?.]<[_HL,\N`+_OOMRDZ;3!I,"Y:CH`O^^^W*3IM,&DZ;3!KN:FH3H`
MO^^^W+;7I5BNYJ:A.@"_[[[<MM>D2L#)KM<Z`+_OOMRHT[>]P,FNUZ[FIJ$Z
M`+_OOMRQ_<7<I_.JNJBMI??#T:=/.@"_[[[<KLFVH:3`N6HZ`+_OOMRDZ;3!
MKLFVH:[FIJ$Z`+_OOMRLVZ2LI,>P=*JZI$>MT\3FINPN`+_OOMRG0:JZPT.F
MXK!TN&T`O^^^W+"^IFZ[>:BE.@"D=[_OOMRJNJ3`P_X`ML>P9;#=PT2DS\"S
M`+;'L&7"LK!4`%-E;F5G86P@*+;KI+JE6[JX*0"W4+3ZOKDZ(`"D1:3K`%-E
M<F)I82!A;F0@36]N=&5N96=R;R`HMNNZN+K[J,B[4+M8KU.EIZWTP[DI`*?'
MN+D`IOBJ0;ZYN.JNQK_YNWZISJK,M4RJ:ZC/I<XN`+=\M,&ZWK)Z`+=\M,$@
M240@I'>Y3+3!+@"W?+3!`*[6J/JDZ+;T`*2YLURG0:GSI]&P3[%+O5BJNJ[)
MK=0LI6FE2*;;IN:MJ[-=L4N]6"X`LUVI=[NWNMVF^*I!OKFD5\3=J?.G0:JZ
MK=.D2*^XI7@N`+-=J7>G0:JZL+ZF;KMYJ*4L(*[)L,^E2*3.I.FTP:[FIJ$N
M`+-=J7>G0:JZL=*I;,"SI<ZU>Z:A+,-#IN*P=+AM+*VVK;&G\[=SP%>R=BRD
MSJCDI4S%XZ7<O^^VM2X`LUVI=P"G\[=SM7NFH;1.NOP`IK.F;K18K=.F8<))
MJ4VS;ZW3L-&\QJ:SP_8Z(`!397EC:&5L;&5S("BVZZGUNK@I`,'*JJL`PK*U
M=;I+K6X`K$^G7ZRPI&JSH:7WJKJS<[6RJ7>X<:?6L;:E7*_@P>0_`,7CI=P`
MQ>.EW*=`I<ZK]K9S/P#%XZ7<MW.RHZ7-NU"M[,!XIG.S7:EWP,FJNJYTLJ<N
M`*A#IKBU;J1*J^'%XZ7<I%>D0*:XJKJU;J1*KLFVH2`_`,7CI=RSQJ?1O_VF
M5[K9(#\`L7&S;ZC'I,##_L7CI=RZ2ZUN`,7CI=S"2;_OOKD`Q>.EW*KMKN:^
MWJ=`I5ROX*KM(#\`J?.EJL/DQ>.EW"`E<R"E7*_@JNT_`,7CI=S`>*9SKN:D
MNJYEN>^XW*3HMO0`Q>.EW*KMKN:DNJYEN>^XW*3HMO0`Q>.EW*9#I+JN9;GO
MN-RDZ+;T`,7CI=R\=KFSI+JN9;GON-RDZ+;T`,7CI=RD5[;'`*OYQ/*P?:M"
M`*:MIK.P?:M"`+'?IK.P?:M"`+NWI.BFL[!]JT(`IJS!60!3:65R<F$@3&5O
M;F4@*+?@I&RD<[#J*0"U^:55`,.QL[D`P[&SN;ITNN(`4VEN9V%P;W)E("BW
M<Z5;J5DI`*1JI'``LJ2Y3+K[Q4``4VQO=F%K:6$@*+2UK*6E[Z=**0!3;&]V
M96YI82`HM+6LI:7OI:>HR"D`L[<`L'VSMP"P?;.W`*:MIK.P?;.W`+'?IK.P
M?;.W`+]NL[>R8*O7.B``4V]L;VUO;B!)<VQA;F1S("BOP<.YJOFX<ZYQ*0!3
M;VUA;&EA("BOP;"HIU&HR"D`NG&[4+C6`*C,I,##_K'&I\<`I4BZ2ZUNI+JN
M9;'&I\<`L<:F0Z3HIE:_[[[<`*C3M[VF8:=]`%-O=71H($%F<FEC82`HJVZK
M1"D`JVZ\VB`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',`JVZE8K)Y`*K%I=6FY@"VH;9:`+:AMEJ[
M4+G4I5(`4W!A:6X@**;HKUJD^BD`J56GH[9LI?,`KU.N[:9RI+B_Z:1*`*3`
ML\[`>*9S`*3`L\[$YJ;L`*3`L\ZF0P"Y0K#*`%-R:2!,86YK82`HM+6HO<3U
MI60I`+S0M\<`K%"[VJJGQ5&^U`"QTJELIGZE]P"LV0"JK+I!`,!XIG.NYJ:A
M`+7SN40`IU*PH[UU`*9RINJF0P"FV[9LI?.F8:=]I*2E:+"CNO2P[*97NMD`
MO,NFH2!;0U-370"L4+3!I-$`I^2DHZCLIKBEV+_]("(E<R(`I42FK@"P9:58
M`+Q7I5L@(B5S(B"H[*ATLLZJNJ73O="D=[!EI5@N(*=!I;*VM[6EJ.RXTZ73
MO="S4:[6K>.KX:1^K^"U;J1*+@"D5;S0`*:HI5P`IJBE7*JZI5ND2B`B)7,B
M(*CLJ'2RSJ2D+@"FJ*5<JKJFVZATLLZDI+)-L*.HSZ7.JLP@(B5S(B"JNKCJ
MKL8N`"(E<R*D=Z=2L*.GN::H+@"FJ*5<JKJFVZATLLZDI+*^L*,@(B5S(BX`
MI'>FJ*5<JKJF7K1?LUVI=RX@O="MJ[=SN/RD2L#+M?BN=+*G+@`B)7,BI'?`
M>*9SI[FFJ"X`I'>FJ*5<JKJSQJ7WLUVI=[CJKL8N`*1WIJBE7*JZL\:E][-=
MJ7>XZJ[&("5S+@"FJ*5<JKJG\[=S("(E<R(`I'>FJ*5<JKK"T+QG("5S`%-U
M9&%N("C$K*2F*0"Z2ZUN`*3II5@`I.FXJ`"TN`"DZ:58`*3II5@OI.FXJ`"D
MZ:58.B``I.FXJ`"DZ;BH.B``I%>\T`"DY+2I`%-U<FEN86UE("C$K*=1JVXI
M`+KON+D`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0@**5VI<O`
MV<3U*0!3=V5D96X@*+?GJ.4I`%-W:71Z97)L86YD("BWYZ1H*0"F4*A"L$^_
M_:1WIU*PHP"F4*A"IN:PRKC+N&T`MVJT3;:UI=BDI*JZNWFJ:[_YNWX`4WER
M:6%N($%R86(@4F5P=6)L:6,@*+'4IU&HR"D`N7"K0@"Y<*M"IK.MMP"Y<*M"
M`*:MIK.K^<3RN7"K0@!404(@I,"Y:J[FIJ'`R:[7`*KML^8`JNVNYJ2ZKF4`
MJNVNYJ2ZKF4`I7C&5P"E>,97`%1A:FEK:7-T86X@*+;PIDZTM:E:*0!486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F("BI6JE\I:>HR"D`I=B\T#H`J]V_
M[*C&MK4`N7&XW+BYO5@`L\RJ\:1`I'"NR:JZM\6KUSH@`+?%J]<`M\6KUSH@
M`+?%J]<\8G(@+SXH)7.PJB5S+R5SIT,E<RD@)F1E9SLE<P"GY*2CJ.R\RZI/
M("(E<R(N`+S+JD^ZWK)Z`*2ZKF4`K\*DY:9R`+GON_2DY:9R`+GON_2DY:9R
ML[NZW0"L4+3!I7P`KO6DY2`H5$E3+38R,"D`5&AA:6QA;F0@**[UL.HI`$94
M4""IM:;Y*&5X=&5N<VEO;BFU3*[$+@!(;W)D92]+;VQA8B"^XZ98I'6U>ZC#
MI;RDY+2I("(E<R(`24U34""L]K_]M4RJ:[-1JNRI;"X`36%I;G1E;F%N8V4@
MP_ZG3ZC#I;RFJ*5<N/RD2@"_[[:UM?BUH:5(P_:SK"["][9]I*0N`*=!JKJH
M=++.NMZR>JW[I;*VMZ7]LUVI=Z9NI$"MT\5VK:VKX;K=I'ZOX,7]IT&HSZ7.
MQ7:MK:ATLLXN`*FSKMB]=0#!<+6XN+F]6*6\J_RI=RRJQ:75J<ZF8KCJKL:N
M=Z2DI^2DHZCL+@"D=Z:HI5RJNK%.P7"UN*1(MW.\5Z;<LW&P5+_]I*0N`,7G
MP]*V;*7SP[&SN;O=K6ZFLZ1`K=.D=[C1MGVJNB!01U`@L,^V]"X`L'2X;;AS
MLM6JNL/1IT^XN;U8*$E$*:2CK$^EO*O\J7<LM$ZL3ZK%I=6ISJK,I*.F8KCJ
MKL:N=Z2D+@"P=+AMN'.RU:6\J_RI=RX`N]VM;J1`K=.X9[E,I5NQ2ZJZNO2X
M]+-SM;(N`,#)KM<@)7,@P+.XTZ5=IW2D0*W3("5S(+-=J7<N`,#)KM<@)7,@
MP+.XTZ5=IW2D0*C'("5S(+-=J7<N`+5,JFN]QKMSJ.RFVZBMP,FNURX`IKG`
MR:[7I*2H4Z:SN.JNQBX`I4BD5:Q/(')F8S@R,B"V;*7SJKJJ[<!9+@"HK:7W
MP]&G3R`E<R"D=[-1IU*PHRX`I:JNV+UU`$=N=5!'(*1'I+C`R:JZN/2N?*6R
MMK>I=[AQIF(@0W)Y<'1?<&=P.CH@P_ZG3Z2D+@"G0;2_J?,@)7,@L4BUN2`E
M<R"D0*O*I42FKJRP("(E<R(@JKJK2*7SI'>S4;9]L=(N"J;]LV^HPZ2CK^"K
M3\/2N-.K2*7SJKJDNJYEI'>GN:7^LU&FK*7SI$BLW:>YJ<ZD1KC1+@"S<[6R
MJ.R]<[QGMFRE\ZVVK;&ITJC/I<ZJNJ97NMD`NDNM;J1WIU*PHRX`IKFSQJ?1
MO_T@(B5S(B"U3*IKLU$Z("5S(*O8I=\N`*:YL\:GT;_]("(E<R(@I'>S4:O8
MI=\N`*:YL\:GT;_]("(E<R(@I'>S4:=2L*,N`*:YL\:GT;_]("(E<R(@I'>S
M4<!XIG,N`*6RMK>L3Z1`K=.\QJ9R+@!(;W)D95]#<GEP=%]S;6EM93HZ(,/^
MIT\LI;*[W:UNIK,@;W!E;G-S;""\TK+5+@"FN;"^IFX@(B5S(B"XZJ[&IEVL
ML+97N4RSS*1JI+FS7*W(+*G2I4BU3*IKLU'`>*9S`*7.I4C`R[7XIKFXZJ[&
MP_ZKK"`H)7,I(*JZM7NFH:C#I*.F<Z9BJ?.H=++.I%<N`*3>K7JF<J6RMK>L
ML+/FI$"F<J2X+@"EJJ5KKMB]=0"E:Z[8O74`Q.:F[*3`N6JF<J6RMK>LL+/F
MI$"F<J2X+@"FN:;XJD&^N2`B)7,B(*1WLU&G4K"C+@"FN:;XJD&^N2`B)7,B
M(*1WLU'`>*9S+@`E<R"JNK7YI56[W:A$I'>S4;*^L*,N`*O\J7>JNK!/O_VH
MPZ2CIG.F8BX`O,BF<\#)KM<B)7,BI*.F<Z9B+@"G0:G2O^FD2JJZN.JNQKM0
MM66ML;CJKL:DH[+%+@"D5Z15KMB]=0"D5Z[8O74`L7&D5Z1`K=.H0L9*I*>K
MX:17ML>JNKCJKL:_\J6B+@"D5[;'P,FNUZC#I;RS4<!XIG,N`'=E871H97(N
M8V]M(+#/MO2U3*IKJ,^ESBX`I^2DHZCLO,NFH;!TN&VEV+_]("(E<R(N`+5,
MI6FESJJZO^^VM2X`M4RJ_J7SI6FJO;&UMGVQTBX`IKG$YJ;LI*2E7:=TI-.F
M:*JZIG*\QBZG0:1WO^FD2B`E<R"MTZ9RO,8[IT&_Z:1*JKJF<KS&I;*VMZ1P
MJ?,@)7,N`+=SO%<@(B5S(B"H[*ATLLXZ("5S(*[)M6^ES:1`K=.PW<-$+@"F
MVZATLLZR3;"C("(E<R(@JKJXZJ[&KLFU;Z7-I$"MT[#=PT0Z`*;;J'2RSK*^
ML*,@(B5S(B"NR;5OI<VD0*W3L-W#1#H`I_.W<R`B)7,B.B`E<R"NR;5OI<VD
M0*W3L-W#1`"D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E<R"EO+-1I%>VQRX`
MI%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@)7,@I&JD<+97N4RDN;-<L\RD:JW(
M("@E9"!B>71E<RDN`*17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z(+;(LZ&DP*JZ
M("5S(,#)KM>S4:17ML<N`,#+M?BV;*7SKLFU;Z7-I$"MT[_YNWXN`+;7I$JF
MN;-QL%2__;CJKL:NR;5OI<V_^;M^+@"VUZ1*LV^MT[CJKL8Z("5S(*[)M6^E
MS:1`K=._^;M^`+;7I$H@:4-A;&5N9&%R(+CJKL:NR;5OI<VD0*W3O_F[?BX`
MMM>D2B!V3F]T92"XZJ[&KLFU;Z7-I$"MT[_YNWXN`*9BLUVI=ZKML^:DI+5O
MI<VD1J1`K=._^;M^+J:SI6FOX*=!O_*Z?*1&I;*VM[;QO&>JNL3FINPN`+#U
MIN:S<;!4O_VK_*EWI5ROX*[)M6^ES:1`K=._^;M^+B"]T+5YJ^&F0;C5I$"F
MN"X`LKZPH[I+K6XZ("5S(*[)M6^ES:1`K=._^;M^+@#`>*9SNDNM;CH@)7,@
MKLFU;Z7-I$"MT[_YNWXN`*?SMW/!<+6XI$BXZJ[&KLFU;Z7-I$:D0*W3O_F[
M?BX@O="U>:OAID&XU2X`I_.W<[!TN&VX<[+5KLFU;Z7-I$:D0*W3O_F[?BX@
MO="U>:OAID&XU2X`P,NU^*:YL\:GT;_].B`E<R"NR;5OI<VD0*W3O_F[?BX`
MJ%.FL[I+K6ZE:;;7I5@N`*:Y($E-05`@IOBJ0;ZYJ,.EO*3DM*FK2*7SIUBD
MP*C)I5ROX"X`LV^F_*5'I*.L3Z6_O52JNB!R87(@P*/!6<#)KM<N`+-OIORE
M1Z2CK$^EO[U4JKH@>FEP(,"CP5G`R:[7+@"S;Z;\I4>DHZQ/I;^]5*JZJTBE
MSJ5DN+F]6"X`IKG$YJ;LK$^ELKO=K6ZJNBX`IKG$YJ;LI+JN9:5UI+FS7+[C
MO,:\QJ9R+@"FN<3FINRDNJYEI76DN;-<O,:F<J3.JU^XN2X`IKG$YJ;LI+JN
M9:5UI+FS7*1+MFFF[+S&K<@N`*:YQ.:F[*2ZKF6ELK:WK+"S<KBYJ<ZJQ:75
MI,"Y:JJZO,:F<@"ELK:WK$^D0*W3O,:F<BX`IKG$YJ;LI+JN9:6RMK>E7:=T
MI$"RU:11I+NV::;LJKH@4D="(,-#IN*E3KU8+*C2IG`@)R,Q,C,T868G+@"F
MN<#)KM>NYJ:AJ,.EO+-1I.2TJ2X`LV^MTZKML^:D=[-1LT*R>KE,+@"S;ZQ/
M("5S+@"S;ZQ/($MO;&%B(+ASLM6JNJ1`K=.JJZ7S+B"Q_<#+M?BFN:JKI?.[
MW:UNK^"DY+2I2V]L86(@N'.RU:[FIJ&JNKEQI&RV;*7SLV[%Z2Z]T+#1IM(@
M)7,@I4BD1KC1LV^HQ[9LI?.S;L7I`+-OJ\JV;*7SJ,.K1*5(IT&Z1*7.JKJF
M<J2XMK"FTZQ/J,^ESB`H)7,I(*[1O&>FTZ:H+@"FN;S&K<BSS*36I;*VMZQ/
M(#$N`*:YIOBJ0;ZYM4RJ:[GO('II<""DSB!G>FEP(*[FIJ'`R:[7MFFFYKC1
MP*/!60"FN:ATLLZEV*MEK$^PL:7.JKJJK+I!+@"ELK:WK$^D0*W3O,:F<BX`
MIKFU^+6AI;*VMZUNI=&_[[:UM?BUH2A/<'1I;VXIJ=*I2:5S`+EP`+#=PT2P
M;,+<`*[)MJ$`KLFVH:O\JVX`KLFVH:[FIJ$`KLFPS[_OOMP`5&EM;W(M3&5S
M=&4`O-##1`"\T,-$("AT;V]L=&EP*3H`IJRE\Z1(`*9PJD>M;KW&O^\LO="F
M8L))O^^WQKFKJKJF4*[)J_8@0V]N=')O;,'D**W3I$BY<;BC*2"ISB!#;VUM
M86YDP>0HQ*NJ1[EQN*,I+@"DM:31`$A434P@K>RI;,#)`%1O9V\@**9HK?0I
M`%1O:V5L874`J?JDT0!4;VYG82`HJD:E6RD`L[NSH0"SS*17O&BNV*Q;("A?
M=&]P*0"D9*B]N4:DSJ:KJ*FM]`"O=:G.L+``K%"TP:1'`%1U;FES:6$@**SP
MI:>FZ*C(*0!4=7)K97D@**1GIM6HY"D`I&>FU:CDI.4@*$E33RTX.#4Y+3DI
M`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU
M("BD9Z7+OGPI`+_II$JG0:JZO^^^W#H@`+6UI7Z]=:O\O,8Z(`"Z]*=]`+KT
MIWTZ`%5G86YD82`HKU&D>KE&*0!5:W)A:6YE("BO4:=*Q/4I`+5,JFNF<ZCZ
M(%9&4R"EV+_]+@"U^:55KLFU3*IKO%>E6\-"I7ZJNJC/I<ZJS+CJL%0N`+5,
MJFNG[\7<(%9&4R#`R:[7("(E<R(@JKK%=JVM+@"U3*IKQ=RG\R!61E,@P,FN
MUR`E<R\E<R"JNL5VK:TN`+5,JFO%W*?SK+`@)7,N`+5,JFO`RZQDP,FNUZ1J
MI'`@(B5S(BX`M4RJ:\#+K&3`R:[7I&JD<"`B)7,O)7,B+@"U3*IKLW.ULB!3
M44P@IOBJ0;ZY+@"U3*IKJ,^ESB!34TP@LW.ULBX`M4RJ:[W&NW,@5D93(,#)
MKM<N`+5,JFNKV*7?(%9&4R"EV+_]("(E<R(N`+5,JFNKV*7?(%9&4R"EV+_]
M+@"U3*IKJ]BEWR!61E,@P,FNURX`M4RJ:ZO8I=\@5D93(*78O_T@(B5S(BX`
MM4RJ:ZO8I=^JQ:75JKH@5D93(,#)KM<N`+5,JFNQ3KCJKL:XT<"CP5DN`+5,
MJFNG4K"C("(E<R(LIKFEV+_]J,.K1*K%I=4N`+5,JFNG4K"C("(E<R(Z("5S
M`+5,JFNG4K"C("(E<R(Z("5S`+5,JFNG4K"C("5S+*:YI=B__:C#JT2JQ:75
M`+5,JFN[O+!JIU*PHZ78O_TN`+5,JFNG4K"C(%9&4R"EV+_]+@"U3*IKIU*P
MHR!61E,@I=B__3H@)7,N`+5,JFNG4K"C(%9&4R#`R:[7("(E<R(N`+5,JFNG
M4K"C(%9&4R#`R:[7+@"U3*IKIU*PHR!61E,@I=B__2`B)7,B+@"U3*IKN[RP
M:J=2L*,@5D93.B`E<RX`M4RJ:Z=0PE^EV*MEJKJEV+_]+@"U3*IKN-&V?;[,
MP]*RT[A@`+5,JFNX_*1*)7.JNJEWN'$N`+5,JFNW:+*^(%9&4R#`R:[7+@"U
M3*IKMGVQTB!61E,@P,FNUR`B)7,B+@"U3*IKO&>D2B!61E,@P,FNURX`M4RJ
M:[9]L=(@5D93(,#)KM<N`+5,JFNV?;'2P*/!6<#)+@"U3*IKQ:JH^B!61E,@
MP,FNUR`H9FEL97-I>F4H*2!F86EL960I+@"U3*IKQ:JH^B!61E,@P,FNUR`H
M9V5T1FEL95-I>F4H*2!F86EL960I+@"U3*IKQ:JH^L#)KM<Z(`"U3*IKQ:JH
M^B!V9G-R;V]T(*78O_TN`+5,JFNG\Z97("5S(*RP("5S.B"F7:RPI=B\T*M(
MI?.G6*1WIG.F8@"U3*IKQ=RG\R!61E,@I=B__:JZIE>ZV2X`M4RJ:[*^L*,@
M5D93(*78O_TZ("5S+@"U3*IKQ=RG\R!61E,@P,FNUR`B)7,B(*JZIE>ZV2X`
MM4RJ:\7<I_,@5D93(,#)KM<@)7,O)7,@JKJF5[K9+@"U3*IKQ=RG\R!61E,@
MP,FNUZJZIE>ZV2X`M4RJ:[#UIN8@)VUK:7-O9G,G+@"U3*IKPN"TJR!7;W)D
M(*3EI?,`M4RJ:[QGI$H@5D93("(E<R(@P,FNURX`M4RJ:[QGI$H@5D93(,#)
MKM<@*&-O<'DH*2!F86EL960I+@"U3*IKO&>D2B!61E,@P,FNU[CJKL8N`+5,
MJFN\9Z1*(%9&4R#`R:[7+""ZS[K0L'3#0J1WNJ$N`*FSO74`J/JN^*?SI^\`
MJ/JN^,7<I_,`M%^M[`"F^*I!OKFS<[6RKLFU;Z7-I;RY=[3!JKJF7L"S.B``
MM6^ES:6\N7>TP:JZIE[`LRRET:;XJD&^N3H@`*6\I,##_@"X5;#JO5@@*%54
M1BTX*0!5;FET960@07)A8B!%;6ER871E<R`HJORIU*="P7"F6*1JI+VPZBD`
M56YI=&5D($MI;F=D;VT@**U>L.HI`%5N:71E9"!3=&%T97,@**S\L.HI`%5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P"SYJ;L`*6\JKZJ
MN@"EO*J^JKH@05!)(+!4KJ>]<[BY("A!4$D@365S<V%G92!)1"DN`*6\JKZJ
MNJO(I.&P5*ZGO7.XN2`H05!)($UE<W-A9V4@240I+@"EO*J^JKJF[+AMN.JP
M5"X`I;RJOJJZJ,^ESJK,IE>ZV:G.L4N]6"X`I*3"7Z78JV6DN*7SJKJS<[6R
M`*6\J5*F5P"F7:9WI?[%5;Q[I*.DN;-<I;RQPL5VJKJU>Z:AL/6FYK#%I%4O
MO<:[<R^V2Z17+B#"2;_OO52I=Z5(P,NU^"!M;WII;&QA+F]R9R"ITK2CJ-&J
MNJS;P_:GWK-.I.6E\RS%_:=!I6FE2+C1L*.FN:1`K:VH[JC#IMNFYK9]J?&U
M>Z:AIG.H^K#%MDO#KRX`J/JN^,-#IN(`I;RDY+2IJKJDNJYEJZRZ03H@)7,N
M("A5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4I`*6\I.2TJ:JZL,;`R:97`,7<
MI_,`I_.W<R`E<P"G\[=SJ,^ESJK,`"(E<R*D=Z?SMW,N`*?SMW.U>Z:AI'>G
M4K"C+@"D5[;'`*1WI%>VQZG2IK/`LZ7.M7NFH:JZLUVI=\#)J.RF^*I!OKDN
M`*1JO&>IU*1"O,:F<@"D:KQGP[FPJ+S&IG(`57)U9W5A>2`HKU&IU*9C*0"H
MSZ7.I=BK9:JZ.B`E<P"HSZ7.(%-33`"F<*I'IT&JNJC/I<ZJS*97NMDOL4N]
M6+M0($E-4U`@IOBJ0;ZYI*.F4"RE::9BIKFS7:EW+@"HSZ7.JLP`J,^ESJK,
M("5S(*6\LW&Y3"`E<R"JNK'"Q7;%Y\/2+@"HSZ7.JLRZWK)Z`*C/I<ZJS+_O
MMK4`J,^ESJK,M?FE50"FN:^XI7BJNJC/I<ZJS+7YI56H=++.I'>PL:7.+@"G
MY*2CJ.RHSZ7.JLRQ8KBY`*C/I<ZJS*97NMD`J,^ESJK,IE>ZV2`B)7,B(*1W
MIG.F8BX`J,^ESJK,IE>ZV3H`J,^ESJK,.B``J'2RSJ2DJKJHSZ7.JLPZ`%5Z
M8F5K:7-T86X@**]1K_>G3Z=**0!61E,@I=B__:C#I*.F<Z9B+@"PLK3!`*1W
MI^2H[*:SKL2JNJ9APDDZ(`"FLZ[$J<H`I4BDP,3!K+"SYJ;L*+%QLGNF8K!?
MNN(I`*W(`+_OJ/JMR*;;`%9A;G5A='4@**7+I:.J_+G/*0#%W*3&`%9E;F5Z
M=65L82`HJ66DNK?GJ=0I`,7GP]*EHK'1("T@IKFV;*7SI6FOX*1WOD2D2+[5
MIMN_>:?O+@"JJ:6[`*JII;NQL:CN`*NKJKVY[[OT`*NKJKVYU*52`*NKJKTZ
M`*M$L6"PJ@!6:65T($YA;2`HME:K;BD`ME:K;J3E("A625-#24DI`,#+M?@@
M)7,`IF*W<[7XM:&V?;'2`*5(("5S(,#+M?@`5FER9VEN($ES;&%N9',L($)R
M:71I<V@@**U>Q-VZ^ZC*N'.N<2D`5FER9VEN($ES;&%N9',L(%4N4RX@**S\
MQ-VZ^ZC*N'.N<2D`K^"HHZO7`*_@J*.KUSH@`+AQI&JG4:7QO'>MM[EQJTBD
MO:5QLWJY3"!33510`,2UIVD`Q+6G:2$A(2"Q<2`E<R"DXK#*LKZPH[5[IJ$N
M`%=)3B"X9Z71($A45%``5V%L;&ES(&%N9"!&=71U;F$`Q+6G:0"L4+3!I%0`
MI-&N\+EWM/H`KO"V2+CJKL:THZC1`'=E871H97(N8V]M(+KTK[@`NO2ON`"Z
M]*^X`*A#MF<`Q7>J[P#%=ZKOJ.P@)7,`Q7>J[RP@)7,`INB\VB`H25-/+3@X
M-3DM,2D`INB\VB`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A("BFZ+R[
MJZ*IU"D`M6ZD2JOAP+.XTZ7]Q>.EW"`E<R"M_J1`K=/`LZ7.M7NFH3\`Q.:F
M[*JZI,"Y:J9RI+@_`*3>K7JJNJMEN&VF<J2X/P!7:&5R96ES($%U<W1R86QI
M82"F8;G/`*UNL4ZZ2ZUNO%>E6Z;<K?ZD0*6[L\:GT;_]J4\_`*W^K=.DZZS;
M`+KTK;:]<[_HOKFJNK2AI?,H<&QU9VEN<RFQTK#*L;&H[BX`O&6KUP"E2"!#
M4U,@K+"SYJ;LJKJ\9:O7`*6JP^0E<Z5<K^"J[:JZO&6KURBD5::XM6ZD2JEL
MI<VNQ"DZ`*KMKN:\9:O7`+QEJ]>SYJ;L`+QEJ]<Z`+:PQ>FST*=``*VW`*:M
MIK.MMP"MM[-T*+A@*0"MM[-T.@"MM[-T.B``M+R\>@"TP:O=PJ>JJP"D=:=`
M`+_LI+VKQZ9AIWT`O^RDO:O'N7&XW`"RQ"5DIN:JNL3FINR\QJ78I*.EO[U4
M+B#`L[C3K6ZFLR5DK=/$YJ;L+*5UI^2H["5DK=/$YJ;L+@#$YJ;LO,:EV*2C
MI;^]5"X@P+.XTZUNIK,E9*W3Q.:F["RE=:?DJ.PE9*W3Q.:F["X`6#4P.78S
M(*FUIOFJ]\9?NWFJ:P!8-3`Y=C,@I42FKK3`I4ZF5[K9`%@U,#EV,R"E1*:N
MJO?&7\/1IT^JS`!8-3`Y=C,@L,;`R:97`*9^`*9^`%EA:&]O("$@IF&YSP"H
M0Z9^`%EE;65N("BXK:KY*0"L3P"L3ZJZ+*?:IE"W3@"G0:78JV6HSZ7.K\*D
MY:9RO7.\9[S2IJ$N(*C/I<X@6SP^72"K]K9SI6FDP;2KK+"Z]*VVO7.\9[S2
MIJ$N`*2CI+FS7*=!J]BEWR5DI4BD5ZJZL,^V]"X`IT&H4Z:SJ]BEW[97N4P@
M)60@K=.Z2ZUNJKK%=JVM+@"G0:6\LU&QPL5V+@"G0:JZI?ZF5Z2DI*.E:::S
M("=<)R"S;[S+JKJF<J2X+B``IT&HPZ6\O^FD2J1`K=.FLZ[$JKJY<:1LMFRE
M\Z;LIWTN`*=!J,.EO*71MM>D2JJZP,FNUZ2DN>^L3:7TIO/$YJ;LJ.P@)7,`
MIT&HPZ6\OM:FL\#+M?BSQJ?1O_T@)7,@JKK%=JVM+@"G0:1WN&>U;J58+@"]
MT+_II$JD0*W3IK.NQ*JZN7&XW+BYO5@LL.J[VKEQN-RXN;U8MLBE=:2YLUR\
MQJ9RN+F]6"RHP[7XL:&J<*5IJ?.K9:VQID&E6Z1`K=,@)RLG+@"G0:6RMK>_
MZ:1*I$"MTZ:SKL2JNJW(+@"G0:6RMK>E_;-7N;JF;K[PJJRXZJ[&*$1A=&%4
M<F5E*:;XJD&ZW:1^K^#$?L3RJ,^ESK=SI<ZDX;7YI56J0;#(+@"G0:6RMK>E
M_;-7N;JD0*W3M>K`P,#)KM>H=++.*%9&4RFF^*I!NMTN`+W0M'FM>K#=PT2A
M0:9BIT&VQ[!EL-W#1+/XIVFDIZME+@"G0:6RMK>_Z:1*IKFS<[6RJ=*K_*96
MJKJZ]*=]`*=!I;*VMZ7]O^^^W*1`K=.M;J=2L*.JNK/&I]&__2X`O="K_*EW
MK6ZG4K"CJKJF^*I!OKDN`+W0J_RI=ZUNLDVPHZJZJ,^ESJK,+@"]T*O\J7>M
M;K*^L*.JNJC/I<ZJS"X`O="K_*EWK6ZW<[Q7JKJHSZ7.JLPN`+W0J_RI=ZUN
MI_.W<ZJZJ,^ESJK,+@"]T*O\J7>M;K#UIN:JNJ=`I<XN`*=!I;*VM[_II$JW
M<Z3`P_ZJNJ97NMDN`*=!I;*VM[2CJ-&D0*W3N'&D:J=1N=*DNJJZN7&XW+BY
MO5@`IT&JNB`E<R"W?+3!I'>Y3*[)+KW0K:NW<[5NI$HN`*=!JKJY<:1LMFRE
M\Z;MIWT`IT&JNK%(I?.D2+EQI&RV;*7SINVG?3H`IT&JNKCJL%0`IMNQ<:=!
MJKH@)7,@MWRTP;9]J6RE2*C3IT&JNKKTN]JZ]+CTINRG?:1WQ=RG\RX@K+"K
M3\5`IT&JNJ9WI?ZP7ZBCH4&G0:6RMK>MJ[=SM6ZD2BX`IT&JNJ97NMD`IT&J
MNL7GP]*F^*I!NMVHPZ2CI.2TJ;=SO%>HSZ7.JLPN(*9PJD>G0:?&L>:ZWK)Z
MJ,^ESJK,L6*XN2RG0:6RMK>E=+_OJ.2E3*JZQ>?#TJ;XJD&ZW2X`IT&JNL7G
MP]*ZW:C#I;RDY+2IID.E6*C/I<ZJS*G.N-.E7*_@I'>S4</VLZPN`*;;L7&G
M0:JZ("5S(+=\M,&V?:ELI4BHTZ=!JKK"<\3]OKFF_*5'I'?%W*?S+B"LL*M/
MQ4"G0:JZIG>E_K!?J*.A0:=!I;*VMZVKMW.U;J1*+@"G0:JZPG/$_;ZYJ,.E
MO*3DM*FS;ZW3I5ROX"X`IT&JNL)SQ/V^N:C#I;RDY+2IID.F3+_OMK4NO="K
M]B!#5%),+T-O;6UA;F0@*R!0(*9#IDPN`*=!I=BK9:G2LUVI=ZJZKLFPSSH`
MN]6D5;EWLUVJNJBMI??#T:=/I'?%W*?S+@"[U:15N7>S7:JZJ*VE]\/1IT\Z
M`*=!JKJY=[-=L\:GT;_]`*=!JKJE_J97.@"G0:JZM6ZD2J1WJ.RTP2X`IT&F
M8B`E<R"DI*JZMW.Q2[U8K$\Z("5S`*=!JKJSQJ?1O_TZ`*=!IF*U;J1*M,&V
MH:JZO^^VM:1WLU&G\[=S+@"G0:JZO^^VM:1WI_.W<RX`IT&JNK%+O5BD=ZVK
MMW.S7:EW`+%+O5BD=[-1K:NW<[-=J7<LMW.JNK%+O5BD=[-ZN4RY<:1LMFRE
M\[%(M6^]T*5(N-.Q2[U8M6ZD2BX`IT&JNK%+O5BD=ZCLM,$N`*=!JKJ[M[K=
MIOBJ0;ZY.@!9=6=O<VQA=FEA("BK;K2UJ=2DTBD`6F%I<F4@*,+$I>PI`%IA
M;6)I82`HJ7RD\:C(*0!::6UB86)W92`HJ*^DVJO"*0!;P?3"PZ3>K7I=`%NP
MW<-$I,^L35T`6\7CI=RDWJUZ("T`6\7CI=RDWJUZ("T@)7,@IN9=`%NF[*GS
MIN8@)7,@ID`@)7,@IN9=`+K>LGI?00"J\*9>L\:GT;_]7T(`J5*E3Z9#7T,`
MI,##_E]#`+[PJJRXZJ[&7T0`IU*PHU]$`*=2L*.F0U]$`+USO^A?10"RQ*1`
MIN9?1@"X<[+57T<`NZ&I^E](`+QVN;.DNJYE7TDN+BX`MM>D2B^VUZ587TD`
MID.E6+I+K6Y?3`"U;J1*7TP`M6ZE6%],`*W7I^^S<[6R7TTN+BX`I]JJNK/&
MI]&__5]-`+=SO%>Z2ZUN7TX`O^^VM5]/`,5VK:U?4`"F0Z9,7U``LKZPH[GO
MLW.ULE]2+BXN`+=JM$U?4P"S7:EW7U,`JNVNYJ2ZKF5?5"XN+@"HSZ7.JLQ?
M50"S<;!4O_T`IN:HQK[D`+5,JFNKV*7?O^FE6,#)KM<`M4RJ:[9]L=*_Z:1*
M`*OVIKD`L4NE3Z9#NWFJ:[_YNWX`LUVI=[_YNWX`O_*EHJVKK6ZJNJATLL[`
MR:[7`+CJKL:NYJ:AO_F[?@"GY*2CJ.RP3[_]`,#)KM<`L7$@)7,@*"5S*2"I
M\R`E<R`E<P"P?:VW`*[).@"NR0"EO*J^JKJV;*7SI42^]Z97NMD`I=^G60"J
MO;&UQ>.EW*GSI;NDY;#/`+_II$HOO^FE6+_YNWX`I+JSH;-NQ>F_^;M^`*;F
M70"DP`"F5[K9`*E\I;RYZJ=`+@"I?*6\N>JG0"X`L\:GT;_]`+/&I]&__2YC
M<W8`ILJDP*3Q`*9SJ/J^1*G:`+FSK\``LW&K2*CSJ7>[M[K=O_F[?@"D5Z3)
M`+5,I6FESJJZJD&PR`#%XZ7<KG2RIP!S;7,R96UA:6P@N&>ET2!(5%10`*SM
M`,.MJ7<`J'2RSK_YNWX`J]V_[,.O`+S(KLFIRJJZI:*QT0"F0::XO^FD2J=!
MJKJQ2[U8I4B]5+M[M4R[?@"^XZ98`*6\J5*F5P"HSZ7.JLR_[[[<`'9#87)D
M`'9.;W1E`*Q0M,$Z`'=E871H97(N8V]M(+KTK[@`````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M
M;R]P;R\`````````````````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0V`#`Q-C$U-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VUN96UO+W!O+V5S7T53+G!O````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S(P-3$`,3`T,3<S-C(W-#8`
M,#$W-3$S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",@4W!A;FES:"!T<F%N<VQA=&EO;G,@9F]R(&AO<F1E('!A8VMA9V4*
M(R!4<F%D=6-C:6]N97,@86P@97-P8?%O;"!P87)A(&5L('!A<75E=&4@:&]R
M9&4N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*(R!4:&ES
M(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A
M<R!T:&4@:&]R9&4@<&%C:V%G92X*(R!!=71O;6%T:6-A;&QY(&=E;F5R871E
M9"P@,C`P-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R
M<VEO;CH@36YE;6\@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`V+3`R+3`R(#$Q.C4Q*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#8M,#(M,#(@,3$Z-3$K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!-86YU
M96P@4"X@07EA;&$@/&UA>6%L84!U;F5X+F5S/EQN(@HB3&%N9W5A9V4M5&5A
M;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB
M4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@,2D[7&XB
M"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;F]T97,B"FUS9W-T<B`B)60@;F]T87,B"@HC.B!T96UP
M;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!C:&%R86-T97)S(@IM<V=S='(@(B5S(&-A<F%C=&5R97,B"@HC.B!D871A
M+G!H<#HQ.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S
M9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B16P@87)C:&EV;R`E<R!S92!H82!I
M;7!O<G1A9&\@<V%T:7-F86-T;W)I86UE;G1E(@H*(SH@;F]T97!A9',N<&AP
M.CDY(&QI8B]B87-E+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!.;W1E<&%D(@IM<V=S='(@(DQI8G)E=&$@9&4@)7,B"@HC.B!T96UP;&%T
M97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(C$@;F]T92(*;7-G<W1R("(Q
M(&YO=&$B"@HC.B!M96UO+G!H<#HQ-C(*;7-G:60@(D%C8V5S<R!D96YI960@
M9&5L971I;F<@;F]T92XB"FUS9W-T<B`B4V4@:&$@9&5N96=A9&\@96P@86-C
M97-O('!A<F$@96QI;6EN87(@;&$@;F]T82XB"@HC.B!M96UO+G!H<#HQ,3(@
M;65M;RYP:'`Z,3$U"FUS9VED(")!8V-E<W,@9&5N:65D(&UO=FEN9R!T:&4@
M;F]T92XB"FUS9W-T<B`B4V4@:&$@9&5N96=A9&\@96P@86-C97-O('!A<F$@
M=')A<VQA9&%R(&QA(&YO=&$N(@H*(SH@;65M;RYP:'`Z.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T92!T;R`E<RXB
M"FUS9W-T<B`B4V4@:&$@9&5N96=A9&\@96P@86-C97-O('!A<F$@9W5A<F1A
M<B!L82!N;W1A(&5N("5S+B(*"B,Z(&UE;6\N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(D%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4Z("5S(@IM<V=S
M='(@(E-E(&AA(&1E;F5G861O(&5L(&%C8V5S;R!P87)A(&=U87)D87(@;&$@
M;F]T83H@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE
M8W0N:6YC.C$P,PIM<V=I9"`B061D(&-A=&5G;W)Y(@IM<V=S='(@(D'Q861I
M<B!C871E9V]R[6$B"@HC.B!M96UO+G!H<#HU,@IM<V=I9"`B061D:6YG($$@
M3F5W($YO=&4B"FUS9W-T<B`B0?%A9&EE;F1O('5N82!N;W1A(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D%S8V5N9&EN9R(*
M;7-G<W1R(")!<V-E;F1E;G1E(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S
M=6UM87)Y<V5L96-T+FEN8SHY.0IM<V=I9"`B079A:6QA8FQE($-A=&5G;W)I
M97,Z(@IM<V=S='(@(D-A=&5G;W+M87,@9&ES<&]N:6)L97,Z(@H*(SH@=&5M
M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3@*;7-G:60@(D)A8VL@=&\@3F]T97!A
M9"(*;7-G<W1R(")296=R97-A<B!A(&QA(&QI8G)E=&$B"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDW"FUS9VED(")"86-K('1O($YO
M=&5P860@3W!T:6]N<R(*;7-G<W1R(")296=R97-A<B!A(&]P8VEO;F5S(&1E
M(&QA(&QI8G)E=&$B"@HC.B!D871A+G!H<#HS,B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS9W-T<B`B0U-6(@H*(SH@9&%T
M82YP:'`Z-30@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C8*;7-G:60@(D-A
M=&5G;W)Y(@IM<V=S='(@(D-A=&5G;W+M82(*"B,Z('1E;7!L871E<R]N;W1E
M<&%D<R]N;W1E<&%D<RYI;F,Z,C(*;7-G:60@(D-H86YG92(*;7-G<W1R(")#
M86UB:6%R(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,34*;7-G
M:60@(D-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R(")#86UB:6%R(&]P8VEO;F5S(&1E(&]R9&5N86-I\VX@
M>2!V:7-U86QI>F%C:?-N(&1E(&YO=&%S+B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3,*;7-G:60@(D-H;V]S92!T:&4@
M;65M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RXB
M"FUS9W-T<B`B16QI:F$@;&%S(&-A=&5G;W+M87,@9&4@;F]T87,@;&ES=&%D
M87,@96X@;&$@=FES=&$@<F5S=6UE;BXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HR,@IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!.;W1E
M<&%D+B(*;7-G<W1R(")%;&EJ82!S=2!L:6)R971A('!O<B!O;6ES:?-N+B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS,@IM<V=I9"`B0VQE
M87(@1F]R;2(*;7-G<W1R("),:6UP:6%R(&9O<FUU;&%R:6\B"@HC.B!T96UP
M;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C$W('1E;7!L871E<R]N;W1E
M<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E871E(@IM<V=S='(@(D-R96%R(@H*
M(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,S(*;7-G:60@(D-R96%T960B
M"FUS9W-T<B`B0W)E861O(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z,C$*;7-G:60@(D1E9F%U;'0@3F]T97!A9"(*;7-G<W1R("),:6)R971A
M('!O<B!O;6ES:?-N.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C0R"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@
M(D-R:71E<FEO(&1E(&-L87-I9FEC86-I\VX@<&]R(&]M:7-I\VXZ(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-3,*;7-G:60@(D1E9F%U;'0@
M<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(E-E;G1I9&\@9&4@8VQA<VEF
M:6-A8VGS;B!P;W(@;VUI<VGS;CHB"@HC.B!T96UP;&%T97,O;F]T97!A9',O
M;F]T97!A9',N:6YC.CDU('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B16QI;6EN87(B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")#;VYF:7)M86-I\VX@9&4@96QI;6EN86-I\VXB"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B1&5L971E(&)U
M='1O;B!B96AA=FEO=7(B"FUS9W-T<B`B0V]M<&]R=&%M:65N=&\@9&5L(&)O
M=/-N($5L:6UI;F%R(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-C<*
M;7-G:60@(D1E;&5T92!T:&ES(&YO=&4B"FUS9W-T<B`B16QI;6EN87(@;F]T
M82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C4R"FUS9VED(")$
M97-C96YD:6YG(@IM<V=S='(@(D1E<V-E;F1E;G1E(@H*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHX-0IM<V=I9"`B1&5S8W)I<'1I;VXZ
M(@IM<V=S='(@(D1E<V-R:7!C:?-N.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B
M3W!C:6]N97,@9&4@5FES=6%L:7IA8VGS;B(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.CDX"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF:7)M
M(&1E;&5T:6YG(&5N=')I97,_(@IM<V=S='(@(K]$97-E82!C;VYF:7)M87(@
M;&$@96QI;6EN86-I\VX@9&4@;&%S(&5N=')A9&%S/R(*"B,Z('1E;7!L871E
M<R]V:65W+VUE;6\N:6YC.C$Q"FUS9VED(")%9&ET(@IM<V=S='(@(DUO9&EF
M:6-A<B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(DUO
M9&EF:6-A<B!<(B5S7"(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E
M<G,N:6YC.C0R(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HX,@IM<V=I9"`B161I
M="!.;W1E(@IM<V=S='(@(DUO9&EF:6-A<B!N;W1A(@H*(SH@=&5M<&QA=&5S
M+VQI<W0O;65M;U]H96%D97)S+FEN8SHU,@IM<V=I9"`B161I="!C871E9V]R
M:65S(&%N9"!C;VQO<G,B"FUS9W-T<B`B36]D:69I8V%R(&QA<R!C871E9V]R
M[6%S('D@<W5S(&-O;&]R97,B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U
M;6UA<FEE<RYI;F,Z,3(*;7-G:60@(D5M<'1Y($YO=&4B"FUS9W-T<B`B5F%C
M:6%R(&YO=&$B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS
M9VED(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T87(B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R="!.;W1E<R(*;7-G<W1R
M(")%>'!O<G1A<B!N;W1A<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHR,0IM<V=I9"`B1E]U;&P@5&5X="(*;7-G<W1R(")495]X=&\@8V]M
M<&QE=&\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR,`HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HR-PIM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S='(@
M(D]P8VEO;F5S(&=E;F5R86QE<R(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@3F]T97,L(%-T
M97`@)60B"FUS9W-T<B`B26UP;W)T87(@;F]T87,N(%!A<V\@)60B"@HC.B!D
M871A+G!H<#HQ.3,*;7-G:60@(DEM<&]R="]%>'!O<G0@3F]T97,B"FUS9W-T
M<B`B26UP;W)T87(O17AP;W)T87(@;F]T87,B"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHS.0IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("+:
M;'1I;6$@;6]D:69I8V%C:?-N(@H*(SH@;&EB+V%P:2YP:'`Z-S(*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F($YO=&5S(@IM<V=S='(@(D[Z;65R;R!MX7AI
M;6\@9&4@;F]T87,B"@HC.B!D871A+G!H<#HU,PIM<V=I9"`B365M;R!497AT
M(@IM<V=S='(@(E1E>'1O(&1E(&QA(&YO=&$B"@HC.B!M96UO+G!H<#HV.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GEI;F<@)7,B"FUS9W-T<B`B36]D
M:69I8V%N9&\@)7,B"@HC.B!L:7-T+G!H<#HS-0IM<V=I9"`B37D@3F]T97,B
M"FUS9W-T<B`B36ES(&YO=&%S(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C(R"FUS9VED(").97<@3F]T92(*;7-G<W1R(").=65V82!N;W1A(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I9"`B3F5X="(*;7-G
M<W1R(")3:6=U:65N=&4B"@HC.B!L:6(O87!I+G!H<#HR,#8*;7-G:60@(DYO
M(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@:&%N
M(&5N8V]N=')A9&\@9&%T;W,@:4-A;&5N9&%R+B(*"B,Z('1E;7!L871E<R]M
M96YU+FEN8SHW"FUS9VED(").;R!N;W1E<&%D<R!A<F4@879A:6QA8FQE('1O
M(&=U97-T<RXB"FUS9W-T<B`B4VEN(&QI8G)E=&%S(&1I<W!O;FEB;&5S('!A
M<F$@;&]S(&EN=FET861O<RXB"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N
M:6YC.C,*;7-G:60@(DYO(&YO=&5S(@IM<V=S='(@(E-I;B!N;W1A<R(*"B,Z
M('1E;7!L871E<R]L:7-T+V5M<'1Y+FEN8SHS"FUS9VED(").;R!N;W1E<R!M
M871C:"!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B3F\@:&%Y(&YO
M=&%S('%U92!C;VEN8VED86X@8V]N(&QO<R!C<FET97)I;W,@86-T=6%L97,N
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P.`IM<V=I9"`B3F\@;F]T
M97,@=&\@9&ES<&QA>2(*;7-G<W1R(")3:6X@;F]T87,@=FES:6)L97,B"@HC
M.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0T"FUS9VED(").
M;U]T92(*;7-G<W1R(")?3F]T82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C0Q"FUS9VED(").;W1E($-A=&5G;W)Y(@IM<V=S='(@(D-A=&5G
M;W+M82!D92!L82!N;W1A(@H*(SH@=FEE=RYP:'`Z.#`@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z,C$*;7-G:60@(DYO=&4@1&5T86EL<R(*;7-G<W1R(")$
M971A;&QE<R!D92!L82!N;W1A(@H*(SH@;F]T97!A9',N<&AP.C$Q,`IM<V=I
M9"`B3F]T92!,:7-T<R(*;7-G<W1R("),:7-T861O(&1E(&YO=&%S(@H*(SH@
M=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-#4@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z-#`*;7-G:60@(DYO=&4@5&5X="(*;7-G<W1R(")497AT;R!D
M92!L82!N;W1A(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*;7-G
M:60@(DYO=&4@7U1E>'0B"FUS9W-T<B`B7U1E>'1O(&1E(&QA(&YO=&$B"@HC
M.B!V:65W+G!H<#HU-R!M96UO+G!H<#HV,`IM<V=I9"`B3F]T92!N;W0@9F]U
M;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N='+S(&QA(&YO=&$N(@H*(SH@=&5M
M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,S0*;7-G:60@(DYO=&5?<&%D(@IM<V=S
M='(@(E],:6)R971A(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHW.0IM<V=I9"`B3F]T97!A9"=S(&YA;64Z(@IM<V=S='(@(DYO;6)R
M92!D92!L82!L:6)R971A.B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E
M<&%D<RYI;F,Z-C$*;7-G:60@(DYO=&5P861S(@IM<V=S='(@(DQI8G)E=&%S
M(@H*(SH@;F]T97!A9',N<&AP.C,S"FUS9VED(").;W1E<&%D<R!M=7-T(&AA
M=F4@82!N86UE+B(*;7-G<W1R("),87,@;&EB<F5T87,@=&EE;F5N('%U92!T
M96YE<B!U;B!N;VUB<F4N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*
M;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`B4F5S=6UE;B!D92!N;W1A
M<R(*"B,Z(&QI8B]A<&DN<&AP.C$X,R!L:6(O87!I+G!H<#HR-SD@;&EB+V%P
M:2YP:'`Z,S4U(&QI8B]A<&DN<&AP.C,X-`IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`B4&5R;6ES;R!D96YE9V%D;R(*"B,Z('1E;7!L871E
M<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#(*;7-G:60@(E!E<FUI<W-I;VYS
M(@IM<V=S='(@(E!R:79I;&5G:6]S(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M
M;RYI;F,Z,34*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI<R!N;W1E/R(*;7-G
M<W1R("*_4V5G=7)O('%U92!Q=6EE<F4@8F]R<F%R(&5S=&$@;F]T83\B"@HC
M.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C4@=&5M<&QA=&5S+VQI<W0O
M:&5A9&5R+FEN8SHV"FUS9VED(")2969R97-H($QI<W0B"FUS9W-T<B`B06-T
M=6%L:7IA<B!L:7-T82(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R
M>7-E;&5C="YI;F,Z,3`U"FUS9VED(")296UO=F4@8V%T96=O<GDB"FUS9W-T
M<B`B475I=&%R(&-A=&5G;W+M82(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N
M;W1E<&%D<RYI;F,Z.38*;7-G:60@(E)E<V5T(@IM<V=S='(@(DQI;7!I87(B
M"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU-@IM<V=I9"`B4V%V92(*
M;7-G<W1R(")'=6%R9&%R(@H*(SH@<V5A<F-H+G!H<#HQ-R!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z,S$*;7-G:60@(E-E87)C:"(*;7-G<W1R(")"=7-C87(B"@HC.B!L:7-T
M+G!H<#HU-PIM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B4F5S=6QT
M861O<R!D92!L82!B^G-Q=65D82(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHQ-PIM<V=I9"`B4V5A<F-H(%-C;W!E(@IM<V=S='(@(L%M8FET
M;R!D92!L82!B^G-Q=65D82(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHY"FUS9VED(")396%R8V@@7U1E>'0B"FUS9W-T<B`B0G5S8V%R(%]T
M97AT;R(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C<*
M;7-G:60@(E-E;&5C="!A(&YO=&5P860B"FUS9W-T<B`B4V5L96-C:6]N92!U
M;F$@;&EB<F5T82(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ-@IM<V=I9"`B
M4V5L96-T(&YO=&5P861S('1O(&1I<W!L87DZ(@IM<V=S='(@(E-E;&5C8VEO
M;F4@;&%S(&QI8G)E=&%S('9I<VEB;&5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T
M.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&9O<FUA=&\@9&4@97AP;W)T86-I
M\VXZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-PIM<V=I9"`B
M4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B4V5L96-C:6]N
M92!E;"!A<F-H:79O(&$@:6UP;W)T87(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE
M('-O=7)C92!F:6QE.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&9O<FUA=&\@
M9&5L(&%R8VAI=F\@;W)I9V5N.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W
M<W5M;6%R>7-E;&5C="YI;F,Z,3`Y"FUS9VED(")396QE8W1E9"!#871E9V]R
M:65S.B(*;7-G<W1R(")#871E9V]R[6%S('-E;&5C8VEO;F%D87,Z(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,W"FUS9VED(")3:&]W(&%C=&EO;B!B
M=71T;VYS/R(*;7-G<W1R("*_36]S=')A<B!B;W1O;F5S(&1E(&%C8VGS;C\B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#`*;7-G:60@(E-H;W<@;F]T
M97!A9"!N86UE/R(*;7-G<W1R("*_36]S=')A<B!E;"!N;VUB<F4@9&4@;&$@
M;&EB<F5T83\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#,*;7-G:60@
M(E-H;W<@;F]T97,@9G)O;2!T:&5S92!C871E9V]R:65S(@IM<V=S='(@(K]-
M;W-T<F%R(&QA<R!N;W1A<R!D92!E<W1A<R!C871E9V]R[6%S/R(*"B,Z('1E
M;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#@*;7-G:60@(E-O<G0@
M8GD@0V%T96=O<GDB"FUS9W-T<B`B3W)D96YA<B!P;W(@8V%T96=O<NUA(@H*
M(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-`IM<V=I9"`B
M4V]R="!B>2!.;W1E(%1E>'0B"FUS9W-T<B`B3W)D96YA<B!P;W(@=&5X=&\@
M9&5L(&-O;65N=&%R:6\B"@HC.B!M96UO+G!H<#HQ,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(%PB)7-<(BXB"FUS9W-T<B`B
M4V4@:&$@9W5A<F1A9&\@8V]R<F5C=&%M96YT92!<(B5S7"(N(@H*(SH@;65M
M;RYP:'`Z,34Y"FUS9VED(")4:&4@;F]T92!W87,@9&5L971E9"XB"FUS9W-T
M<B`B4V4@96QI;6EN\R!L82!N;W1A+B(*"B,Z(&YO=&5P861S+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@8V]U;&1N
M)W0@8F4@8W)E871E9#H@)7,B"FUS9W-T<B`B3F\@<V4@<'5D;R!C<F5A<B!L
M82!L:6)R971A(%PB)7-<(CH@)7,B"@HC.B!N;W1E<&%D<RYP:'`Z-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N
M(&-R96%T960N(@IM<V=S='(@(E-E(&AA(&-R96%D;R!L82!L:6)R971A(%PB
M)7-<(BXB"@HC.B!N;W1E<&%D<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(E-E(&AA(&5L:6UI;F%D;R!L82!L:6)R971A(%PB)7-<(BXB"@HC.B!N
M;W1E<&%D<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P
M860@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")392!H82!G=6%R
M9&%D;R!L82!L:6)R971A(%PB)7-<(BXB"@HC.B!D871A+G!H<#HQ.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A
M;"!I;7!O<G1A<B!L;W,@9&%T;W,Z("5S(@H*(SH@;&EB+V%P:2YP:'`Z,C`P
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82XB"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I
M;7!O<G1A<B!L;W,@9&%T;W,@:4-A;&5N9&%R+B(*"B,Z(&QI8B]A<&DN<&AP
M.C0P,PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M=DYO=&4@9&%T82XB"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I
M;7!O<G1A<B!L;W,@9&%T;W,@=DYO=&4N(@H*(SH@;65M;RYP:'`Z,34W"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN
M9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A
M;"!E;&EM:6YA<B!L82!N;W1A.B`E<R(*"B,Z(&UE;6\N<&AP.C$S,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H
M92!N;W1E.B`E<R(*;7-G<W1R(")392!P<F]D=6IO('5N(&5R<F]R(&%L(&=U
M87)D87(@;&$@;F]T83H@)7,B"@HC.B!V:65W+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=FEE=VEN9R!T:&ES(&YO
M=&5P860Z("5S(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@=F5R
M(&5S=&$@;&EB<F5T83H@)7,B"@HC.B!D871A+G!H<#HW.0IM<V=I9"`B5&AE
M<F4@=V5R92!N;R!M96UO<R!T;R!E>'!O<G0N(@IM<V=S='(@(DYO(&AU8F\@
M;65M;W)A;F1O<R!A(&5X<&]R=&%R+B(*"B,Z(&1A=&$N<&AP.C$P-0IM<V=I
M9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M(")%<W1E(&9O<FUA=&\@9&4@87)C:&EV;R!N;R!E<W3A('-O<&]R=&%D;RXB
M"@HC.B!N;W1E<&%D<RYP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(DEN8V%P87H@9&4@
M96QI;6EN87(@7"(E<UPB.B`E<R(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N
M:6YC.C4X"FUS9VED(")5;F1O(&-H86YG97,B"FUS9W-T<B`B1&5S:&%C97(@
M8V%M8FEO<R(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(W('1E;7!L
M871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ-`HC.B!L:6(O36YE;6\N
M<&AP.C(P-B!L:6(O36YE;6\N<&AP.C(P-R!L:6(O36YE;6\N<&AP.C(R,2!L
M:6(O36YE;6\N<&AP.C(R,@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3`S
M"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(E-I;B!C871E9V]R[6$B"@HC.B!L
M:6(O87!I+G!H<#HR,S8@;&EB+V%P:2YP:'`Z,S$Y(&QI8B]A<&DN<&AP.C0Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y
M<&4Z("5S(@IM<V=S='(@(E1I<&\@9&4@8V]N=&5N:61O(&YO('-O<&]R=&%D
M;SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(R"FUS9VED
M(")7:&EC:"!.;W1E<&%D('-H;W5L9"!T:&4@;F]T97,@8F4@861D960@=&\_
M(@IM<V=S='(@(K]!('%UZ2!L:6)R971A(&AA>2!Q=64@8?%A9&ER(&QA<R!N
M;W1A<S\B"@HC.B!D871A+G!H<#HT,B!D871A+G!H<#HQ,C4@;65M;RYP:'`Z
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T
M;R!C<F5A=&4@;6]R92!T:&%N("5D(&YO=&5S+B(*;7-G<W1R(").;R!D:7-P
M;VYE(&1E('!R:79I;&5G;VES('!A<F$@8W)E87(@;>%S(&1E("5D(&YO=&%S
M+B(*"B,Z('9I97<N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@)7,N
M(@IM<V=S='(@(DYO(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!V97(@
M;&$@;&EB<F5T82`E<RXB"@HC.B!N;W1E<&%D<RYP:'`Z-C4*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E9"XB"FUS9W-T
M<B`B5&EE;F4@<75E('-E;&5C8VEO;F%R('5N82!L:6)R971A(&$@96QI;6EN
M87(N(@H*(SH@=&5M<&QA=&5S+W!R969S+VYO=&5P861S96QE8W0N:6YC.C$P
M"FUS9VED(")9;W5R(&1E9F%U;'0@;F]T97!A9#HB"FUS9W-T<B`B4W4@;&EB
M<F5T82!P;W(@;VUI<VGS;CHB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T
M97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*;7-G<W1R(")3
M=7,@;&EB<F5T87,Z(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3@*
M;7-G:60@(E]"86-K('1O($YO=&5P860B"FUS9W-T<B`B7U)E9W)E<V%R(&$@
M;&$@;&EB<F5T82(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4Q('1E
M;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#@*;7-G:60@(E]#871E
M9V]R>2(*;7-G<W1R(")?0V%T96=O<NUA(@H*(SH@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z,34*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B7T5L:6UI;F%R
M(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3$*;7-G:60@(E]%9&ET
M(@IM<V=S='(@(DUO7V1I9FEC87(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z,C`*;7-G:60@(E]&:7)S="!,:6YE(@IM<V=S='(@(E!?<FEM
M97)A(&SM;F5A(@H*(SH@;&EB+TUN96UO+G!H<#HR.#$*;7-G:60@(E]);7!O
M<G0O17AP;W)T(@IM<V=S='(@(E]);7!O<G1A<B]%>'!O<G1A<B(*"B,Z(&QI
M8B]-;F5M;RYP:'`Z,C8T"FUS9VED(")?3&ES="!.;W1E<R(*;7-G<W1R(")?
M3&ES=&%R(@H*(SH@;&EB+TUN96UO+G!H<#HR-S8*;7-G:60@(E]->2!.;W1E
M<&%D<R(*;7-G<W1R(")?36ES(&QI8G)E=&%S(@H*(SH@;&EB+TUN96UO+G!H
M<#HR-CD*;7-G:60@(E].97<@3F]T92(*;7-G<W1R(")?0?%A9&ER(@H*(SH@
M;&EB+TUN96UO+G!H<#HR.#8*;7-G:60@(E]0<FEN="(*;7-G<W1R("));5]P
M<FEM:7(B"@HC.B!L:6(O36YE;6\N<&AP.C(W,@IM<V=I9"`B7U-E87)C:"(*
M;7-G<W1R(")?0G5S8V%R(@H*(SH@9&%T82YP:'`Z.3$@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ"FUS9VED(")N;W1E<RYC<W8B"FUS9W-T<B`B;F]T
M87,N8W-V(@H*(SH@9&%T82YP:'`Z,S,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHQ.`IM<V=I9"`B=DYO=&4B"FUS9W-T<B`B=DYO=&4B"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O
M<&\O>FA?0TXN<&\`````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R-#8V-P`Q,#0Q-S,V,C<T-@`P,3<U,S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!-;F5M;R!3:6UP;&EF
M:65D($-H:6YE<V4@5')A;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@
M4&5T97(@5V%N9PHC(%!E=&5R(%=A;F<@/'=H=T!O=6QI;FLN;F5T/BP@,C`P
M,@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!-
M;F5M;R`R+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP-2TS
M,"`Q-CHS-"LP.#`P7&XB"B),87-T+51R86YS;&%T;W(Z(%!E=&5R(%=A;F<@
M/'=H=T!O=6QI;FLN;F5T/EQN(@HB3&%N9W5A9V4M5&5A;3H@4VEM<&QI9FEE
M9"!#:&EN97-E(#QW:'=`;W5L:6YK+FYE=#Y<;B(*(DU)344M5F5R<VEO;CH@
M,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]1T(R
M,S$R7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*
M(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!N;W1E<R(*;7-G<W1R("(E9""QN,W\PKPB"@HC
M.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I
M;7!O<G1E9"(*;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z.3D@;&EB+V)A
M<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS
M9VED("(Q(&YO=&4B"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z,38R"FUS9VED
M(")!8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N(@IM<V=S='(@(B(*"B,Z
M(&UE;6\N<&AP.C$Q,B!M96UO+G!H<#HQ,34*;7-G:60@(D%C8V5S<R!D96YI
M960@;6]V:6YG('1H92!N;W1E+B(*;7-G<W1R("(B"@HC.B!M96UO+G!H<#HX
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N
M;W1E('1O("5S+B(*;7-G<W1R("(B"@HC.B!M96UO+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE
M8W0N:6YC.C$P,PHC+"!F=7IZ>0IM<V=I9"`B061D(&-A=&5G;W)Y(@IM<V=S
M='(@(L#@L?`B"@HC.B!M96UO+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B061D
M:6YG($$@3F5W($YO=&4B"FUS9W-T<B`BT,+4]K&XS?PB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#0*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R("+)
M_=#R(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN
M8SHY.0IM<V=I9"`B079A:6QA8FQE($-A=&5G;W)I97,Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(X('1E;7!L871E<R]V:65W
M+VUE;6\N:6YC.C8W"B,L(&9U>GIY"FUS9VED(")"86-K('1O($YO=&5P860B
M"FUS9W-T<B`BN]BUO;&XS?S"O,'0L>TB"@HC.B!T96UP;&%T97,O;F]T97!A
M9',O;F]T97!A9',N:6YC.CDW"B,L(&9U>GIY"FUS9VED(")"86-K('1O($YO
M=&5P860@3W!T:6]N<R(*;7-G<W1R("*[V+6]L;C-_,*\P="Q[2(*"B,Z(&1A
M=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*;7-G:60@
M(D-35B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU-"!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHQ-0IM<V=I9"`B0V%T96=O<GDB"FUS9W-T<B`BP."Q\"(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,C(*(RP@9G5Z
M>GD*;7-G:60@(D-H86YG92(*;7-G<W1R("*[UKBTL>2X_"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E('EO
M=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@
M(KC\N,3$X[7$L;C-_,K"S^[%Q=#RM[W*O=+4O+#/U,J^T:'/[BXB"@HC.B!T
M96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.CDS"FUS9VED
M(")#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T;R!L:7-T(&EN('1H92!S
M=6UM87)Y('9I97<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,@IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!.;W1E<&%D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S(*
M;7-G:60@(D-L96%R($9O<FTB"FUS9W-T<B`BQ^6S_;'MM:4B"@HC.B!T96UP
M;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C$W('1E;7!L871E<R]N;W1E
M<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]V:65W+VUE;6\N:6YC.C,U"FUS9VED(")#<F5A=&5D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0HC+"!F=7IZ>0IM
M<V=I9"`B1&5F875L="!.;W1E<&%D(@IM<V=S='(@(LBQRJ'%Q=#RL>K7O#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4*;7-G:60@(D1E9F%U;'0@
M<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`BR+'*H<7%T/*QZM>\.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B1&5F875L="!S;W)T
M:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`BR+'*H<7%T/*WO<_R.B(*"B,Z('1E
M;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.34@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z,C4*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C0*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92(*;7-G<W1R("+)OK/]L;C-_,K"S^XB
M"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHV-PIM<V=I9"`B1&5L971E
M('1H:7,@;F]T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#4*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`BO;70\B(*"B,Z('1E
M;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*(RP@9G5Z>GD*;7-G
M:60@(D1E<V-R:7!T:6]N.B(*;7-G<W1R("+#Z,KV(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T
M<B`BS]3*OM&AS^XB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T
M96UP;&%T97,O=FEE=R]M96UO+FEN8SHV,`IM<V=I9"`B161I="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0T(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HX,PIM<V=I9"`B161I="!.;W1E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-30*;7-G:60@
M(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ,@IM<V=I9"`B16UP
M='D@3F]T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$Y"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@3F]T97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(Q"B,L(&9U
M>GIY"FUS9VED(")&7W5L;"!497AT(@IM<V=S='(@(LBKSL0B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T($YO=&5S+"!3=&5P("5D(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C$Y,PIM<V=I9"`B26UP;W)T+T5X<&]R="!.;W1E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHT,PIM<V=I9"`B3&%S="!-;V1I
M9FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW,@IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@3F]T97,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M-3,*;7-G:60@(DUE;6\@5&5X="(*;7-G<W1R("*QN,W\Q-K(W2(*"B,Z(&UE
M;6\N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(DUO9&EF>6EN9R`E<R(*
M;7-G<W1R("+0WKC$("5S(-;0(@H*(SH@;&ES="YP:'`Z,S4*;7-G:60@(DUY
M($YO=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR
M,@HC+"!F=7IZ>0IM<V=I9"`B3F5W($YO=&4B"FUS9W-T<B`BT,+4]K&XS?S*
MPL_N(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I9"`B
M3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR,#8*;7-G:60@(DYO
M(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE;G4N:6YC.C<*;7-G:60@(DYO(&YO=&5P861S(&%R92!A=F%I
M;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES
M="]H96%D97(N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(DYO(&YO=&5S(@IM<V=S
M='(@(L[>L;C-_,K"S^XB"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z
M,PIM<V=I9"`B3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#D*;7-G
M:60@(DYO(&YO=&5S('1O(&1I<W!L87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-@IM<V=I9"`B3F]?=&4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T"B,L(&9U>GIY
M"FUS9VED(").;W1E($-A=&5G;W)Y(@IM<V=S='(@(K&XS?S`X+'P(@H*(SH@
M=FEE=RYP:'`Z.#`@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z.0HC+"!F=7IZ
M>0IM<V=I9"`B3F]T92!$971A:6QS(@IM<V=S='(@(K&XS?S/N+W:(@H*(SH@
M;F]T97!A9',N<&AP.C$Q,`IM<V=I9"`B3F]T92!,:7-T<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,*(RP@9G5Z>GD*;7-G:60@
M(DYO=&4@5&5X="(*;7-G<W1R("*QN,W\Q-K(W2(*"B,Z('1E;7!L871E<R]M
M96UO+VUE;6\N:6YC.C(V"B,L(&9U>GIY"FUS9VED(").;W1E(%]497AT(@IM
M<V=S='(@(K&XS?S$VLC=(@H*(SH@=FEE=RYP:'`Z-3<@;65M;RYP:'`Z-C`*
M;7-G:60@(DYO=&4@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65M;R]M96UO+FEN8SHS-`IM<V=I9"`B3F]T95]P860B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHW.0IM<V=I
M9"`B3F]T97!A9"=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N
M;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C$*;7-G:60@(DYO=&5P861S(@IM<V=S
M='(@(B(*"B,Z(&YO=&5P861S+G!H<#HS,PIM<V=I9"`B3F]T97!A9',@;75S
M="!H879E(&$@;F%M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C,*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,`IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R("+&Y,O[T:'/[B(*
M"B,Z(&QI8B]A<&DN<&AP.C$X,R!L:6(O87!I+G!H<#HR-S0@;&EB+V%P:2YP
M:'`Z,S0U(&QI8B]A<&DN<&AP.C,W-`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI
M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHX,@IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHU('1E;7!L871E<R]L:7-T+VAE861E
M<BYI;F,Z-@IM<V=I9"`B4F5F<F5S:"!,:7-T(@IM<V=S='(@(M;8T,+5^\#M
MQ^6UI2(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI
M;F,Z,3`U"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V%T96=O<GDB"FUS9W-T
M<B`BL;C-_,#@L?`B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.CDV"FUS9VED(")297-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65M;R]M96UO+FEN8SHU-@HC+"!F=7IZ>0IM<V=I9"`B4V%V92(*;7-G<W1R
M("*THK3FL;C-_,K"S^XB"@HC.B!S96%R8V@N<&AP.C$W('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHT('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN
M8SHS,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(K+IU=(B"@HC.B!L:7-T+G!H
M<#HU-PIM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`BLNG5TKWAN?LB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3<*;7-G:60@(E-E
M87)C:"!38V]P92(*;7-G<W1R("*RZ=72M[;.IR(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHY"B,L(&9U>GIY"FUS9VED(")396%R8V@@7U1E
M>'0B"FUS9W-T<B`BLNG5TK&^SL0B"@HC.B!T96UP;&%T97,O;F]T97!A9',O
M;F]T97!A9',N:6YC.C8W"FUS9VED(")396QE8W0@82!N;W1E<&%D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ-@IM<V=I9"`B4V5L96-T
M(&YO=&5P861S('1O(&1I<W!L87DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T
M(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHS-PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0IM<V=I
M9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N
M:6YC.C$P.0IM<V=I9"`B4V5L96-T960@0V%T96=O<FEE<SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,X"FUS9VED(")3:&]W(&%C
M=&EO;B!B=71T;VYS/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z-#$*;7-G:60@(E-H;W<@;F]T97!A9"!N86UE/R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#0*;7-G:60@(E-H;W<@;F]T
M97,@9G)O;2!T:&5S92!C871E9V]R:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3`*;7-G:60@(E-O<G0@8GD@
M0V%T96=O<GDB"FUS9W-T<B`BTM3`X+'PQ<70\B(*"B,Z('1E;7!L871E<R]L
M:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@
M8GD@3F]T92!497AT(@IM<V=S='(@(M+4P."Q\,7%T/(B"@HC.B!M96UO+G!H
M<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z,34Y"B,L(&9U>GIY
M"FUS9VED(")4:&4@;F]T92!W87,@9&5L971E9"XB"FUS9W-T<B`BP[O3T+&X
MS?S*PL_NL;O0WKC$+B(*"B,Z(&YO=&5P861S+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@8V]U;&1N)W0@8F4@8W)E
M871E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!C
M<F5A=&5D+B(*;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H<#HU-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@<V%V
M960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A
M.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR,#`*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HS.3,*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.;W1E(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&UE;6\N<&AP.C$U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E
M<R(*;7-G<W1R("+)OK/]L;C-_,K"S^[*L;>BR?JT[<[S+B(*"B,Z(&UE;6\N
M<&AP.C$S,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('-A=FEN9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`BR;ZS_;&X
MS?S*PL_NRK&WHLGZM.W.\RXB"@HC.B!V:65W+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=FEE=VEN9R!T:&ES(&YO
M=&5P860Z("5S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C<Y"B,L(&9U>GIY
M"FUS9VED(")4:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="XB"FUS9W-T
M<B`BT.C2JK7$L;C-_,K"S^ZRHK*[M.;4VBXB"@HC.B!D871A+G!H<#HQ,#4*
M;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B
M56YD;R!C:&%N9V5S(@IM<V=S='(@(KO6N+2QY+C\(@H*(SH@=&5M<&QA=&5S
M+W9I97<O;65M;RYI;F,Z,38@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I
M97,N:6YC.C$T"B,Z(&QI8B]-;F5M;RYP:'`Z,C`V(&QI8B]-;F5M;RYP:'`Z
M,C`W(&QI8B]-;F5M;RYP:'`Z,C(Q(&QI8B]-;F5M;RYP:'`Z,C(R"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#4*;7-G:60@(E5N9FEL960B"FUS9W-T
M<B`BSK2YZ;6U(@H*(SH@;&EB+V%P:2YP:'`Z,C,V(&QI8B]A<&DN<&AP.C,P
M.2!L:6(O87!I+G!H<#HT,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P
M;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C(R"FUS9VED(")7:&EC:"!.;W1E<&%D('-H
M;W5L9"!T:&4@;F]T97,@8F4@861D960@=&\_(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C0R(&1A=&$N<&AP.C$R-2!M96UO+G!H<#HS-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@;F]T97,N(@IM<V=S='(@(B(*"B,Z('9I97<N<&AP.C4P"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N
M('1O('9I97<@=&AE(&YO=&5P860@)7,N(@IM<V=S='(@(B(*"B,Z(&YO=&5P
M861S+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@
M;F]T97!A9"!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+$X['8T.O1H=3QUL')
MV=*[N/:QN,W\RL+/[BXB"@HC.B!T96UP;&%T97,O<')E9G,O;F]T97!A9'-E
M;&5C="YI;F,Z,3`*;7-G:60@(EEO=7(@9&5F875L="!N;W1E<&%D.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8U
M"FUS9VED(")9;W5R(&YO=&5P861S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV
M-PHC+"!F=7IZ>0IM<V=I9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R("*[
MV+6]L;C-_,*\P="Q[2(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4Q
M('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3`*(RP@9G5Z>GD*
M;7-G:60@(E]#871E9V]R>2(*;7-G<W1R("+`X+'P(@H*(SH@=&5M<&QA=&5S
M+W9I97<O;65M;RYI;F,Z,C4@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C0*
M(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`BR;ZS_;&XS?S*PL_N
M(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C$@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z-C`*;7-G:60@(E]%9&ET(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,`IM<V=I9"`B7T9I<G-T($QI
M;F4B"FUS9W-T<B`B(@H*(SH@;&EB+TUN96UO+G!H<#HR.#$*;7-G:60@(E])
M;7!O<G0O17AP;W)T(@IM<V=S='(@(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8T
M"B,L(&9U>GIY"FUS9VED(")?3&ES="!.;W1E<R(*;7-G<W1R("+!T+/VL;C-
M_,K"S^XB"@HC.B!L:6(O36YE;6\N<&AP.C(W-@IM<V=I9"`B7TUY($YO=&5P
M861S(@IM<V=S='(@(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8Y"FUS9VED(")?
M3F5W($YO=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TUN96UO+G!H<#HR.#8*;7-G
M:60@(E]0<FEN="(*;7-G<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP.C(W,@HC
M+"!F=7IZ>0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R("*RZ=72(@H*(SH@9&%T
M82YP:'`Z.3$@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ"FUS9VED(")N
M;W1E<RYC<W8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S,@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHQ.`IM<V=I9"`B=DYO=&4B"FUS9W-T<B`B(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]M;F5M;R]P;R]Z:%]45RYP;P``````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(W,3$P`#$P-#$W,S8R-S0V`#`Q-S4U
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M($U.14U/(%1R861I=&EO;F%L($-H:6YE<V4@5')A;G-L871I;VX*(R!#;W!Y
M<FEG:'0@*$,I(#(P,#(@1&%V:60@0VAA;F<NL6FH?:3E+*5XQE<*(R!$879I
M9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SXL(#(P,#(N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($U.14U/(#(N,"UC=G-<
M;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,2TP-2`Q-3HP-"LP.#`P
M7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`S+3`Q+3`X(#$P.C4S*S`Q,#!<
M;B(*(DQA<W0M5')A;G-L871O<CH@1&%V:60@0VAA;F<@/&1A=FED0'1M=BYG
M;W8N='<^7&XB"B),86YG=6%G92U496%M.B!4<F%D:71I;VYA;"!#:&EN97-E
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0DE'-5QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@=&5M
M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&YO=&5S(@IM<V=S='(@(B5D(*W3NDNM;B(*"B,Z('1E;7!L871E<R]M
M96UO+VUE;6\N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&-H87)A
M8W1E<G,B"FUS9W-T<B`B)7,@IG*DN"(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E
M9"(*;7-G<W1R("+`R:[7("5S(*1WMM>D2J>YIJ@B"@HC.B!N;W1E<&%D<RYP
M:'`Z.3D@;&EB+V)A<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`B)7.JNK/&I]&__2(*"B,Z('1E;7!L871E
M<R]L:7-T+VAE861E<BYI;F,Z,PIM<V=I9"`B,2!N;W1E(@IM<V=S='(@(J1`
MK=.Z2ZUN(@H*(SH@;65M;RYP:'`Z,38R"FUS9VED(")!8V-E<W,@9&5N:65D
M(&1E;&5T:6YG(&YO=&4N(@IM<V=S='(@(J=2L*.Z2ZUNKLDLIG.H^KY$J=HN
M(@H*(SH@;65M;RYP:'`Z,3$R(&UE;6\N<&AP.C$Q-0IM<V=I9"`B06-C97-S
M(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N(@IM<V=S='(@(K=HLKZFN;I+K6ZN
MR2RF<ZCZOD2IVBXB"@HC.B!M96UO+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E('1O("5S+B(*;7-G<W1R
M("+`>*9SNDNM;JCL("5S(*[)+*9SJ/J^1*G:+B(*"B,Z(&UE;6\N<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@<V%V:6YG(&YO
M=&4Z("5S(@IM<V=S='(@(L!XIG.Z2ZUN.B`E<R"NR2RF<ZCZOD2IVBXB"@HC
M.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P,PIM
M<V=I9"`B061D(&-A=&5G;W)Y(@IM<V=S='(@(K=SO%>DP,/^(@H*(SH@;65M
M;RYP:'`Z-3(*;7-G:60@(D%D9&EN9R!!($YE=R!.;W1E(@IM<V=S='(@(K=S
MO%<@,2"MT[I+K6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G
M:60@(D%S8V5N9&EN9R(*;7-G<W1R("*DR;ZM(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY.0IM<V=I9"`B079A:6QA8FQE
M($-A=&5G;W)I97,Z(@IM<V=S='(@(J5II<ZJNJ3`P_XZ(@H*(SH@=&5M<&QA
M=&5S+W9I97<O;65M;RYI;F,Z,3@*;7-G:60@(D)A8VL@=&\@3F]T97!A9"(*
M;7-G<W1R("*J\*9>L\:GT;_](@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHY-PIM<V=I9"`B0F%C:R!T;R!.;W1E<&%D($]P=&EO;G,B
M"FUS9W-T<B`BJO"F7K/&I]&__;_OMK4B"@HC.B!D871A+G!H<#HS,B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS9W-T<B`B
MLW+"2:3`N6JNYJ:A("YC<W8B"@HC.B!D871A+G!H<#HU-"!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHR-@IM<V=I9"`B0V%T96=O<GDB"FUS9W-T<B`BI,##
M_B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,C(*;7-G
M:60@(D-H86YG92(*;7-G<W1R("+%W*?S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U"FUS9VED(")#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@86YD
M(&1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`BQ=RG\Z=!JKJZ2ZUNL<:GQZ5(
MI,[%XZ7<O^^VM2XB"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES
M96QE8W0N:6YC.CDS"FUS9VED(")#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE
M<R!T;R!L:7-T(&EN('1H92!S=6UM87)Y('9I97<N(@IM<V=S='(@(K_OOMRD
MP,/^I4C%XZ7<J?.Z2ZUNP,NU^*2D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,@IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!.;W1E<&%D+B(*
M;7-G<W1R("*_[[[<IT&JNKEWLUVSQJ?1O_TN(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C,R"FUS9VED(")#;&5A<B!&;W)M(@IM<V=S='(@
M(K)-L*.J[;/F(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN
M8SHQ-R!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDT"B,Z('1E
M;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.38*;7-G:60@(D-R96%T
M92(*;7-G<W1R("*KV*7?(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,S(*;7-G:60@(D-R96%T960B"FUS9W-T<B`BJ]BEWR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,0IM<V=I9"`B1&5F875L="!.;W1E<&%D(@IM<V=S
M='(@(KEWLUVSQJ?1O_TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(*
M;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`BN7>S
M7:JZL<:GQZIKJV@Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S"FUS
M9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R("*Y=[-=
MJKJQQJ?'I.BF5CHB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.CDU('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`BIU*PHR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R("*G4K"CO52[
M>R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B1&5L971E
M(&)U='1O;B!B96AA=FEO=7(B"FUS9W-T<B`BIU*PHZOVMG.JNJ;FK+`B"@HC
M.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHV-PIM<V=I9"`B1&5L971E('1H
M:7,@;F]T92(*;7-G<W1R("*G4K"CLV^MT[I+K6XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`BK;"^
MK2(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*;7-G
M:60@(D1E<V-R:7!T:6]N.B(*;7-G<W1R("*T>:UZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T
M<B`BQ>.EW+_OMK4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G
M:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B
M"FUS9W-T<B`BIT&]5*EWK6ZG4K"CL$^__;;<(#\B"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHQ,0IM<V=I9"`B161I="(*;7-G<W1R("*]<[_H(@H*
M(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`BO7._Z"!<(B5S
M7"(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0R(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HX,@IM<V=I9"`B161I="!.;W1E(@IM<V=S
M='(@(KUSO^BZ2ZUN(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S
M+FEN8SHU,@IM<V=I9"`B161I="!C871E9V]R:65S(&%N9"!C;VQO<G,B"FUS
M9W-T<B`BO7._Z*3`P_Z[4,-#IN(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO
M7W-U;6UA<FEE<RYI;F,Z,3(*;7-G:60@(D5M<'1Y($YO=&4B"FUS9W-T<B`B
MLDVJQ;I+K6XB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS
M9VED(")%>'!O<G0B"FUS9W-T<B`BMM>E6"(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z.`IM<V=I9"`B17AP;W)T($YO=&5S(@IM<V=S='(@(K;7
MI5BZ2ZUN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(Q"FUS
M9VED(")&7W5L;"!497AT(@IM<V=S='(@(J>YON.DNJYE7W4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-PIM<V=I9"`B1V5N97)A;"!/<'1I
M;VYS(@IM<V=S='(@(J1`K^N_[[:U(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!.;W1E<RP@
M4W1E<"`E9"(*;7-G<W1R("*VUZ1*NDNM;BP@J$+&2B`E9"(*"B,Z(&1A=&$N
M<&AP.C$Y,PIM<V=I9"`B26UP;W)T+T5X<&]R="!.;W1E<R(*;7-G<W1R("*V
MUZ1*+[;7I5BZ2ZUN(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,SD*
M;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`BL\RJ\:1`IKBG\[=S(@H*
M(SH@;&EB+V%P:2YP:'`Z-S(*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($YO
M=&5S(@IM<V=S='(@(KI+K6ZD5ZVMO,:EV"(*"B,Z(&1A=&$N<&AP.C4S"FUS
M9VED(")-96UO(%1E>'0B"FUS9W-T<B`BNDNM;J2ZKF4B"@HC.B!M96UO+G!H
M<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GEI;F<@)7,B"FUS9W-T
M<B`BI;^F8KUSO^@@)7,@I*0B"@HC.B!L:7-T+G!H<#HS-0IM<V=I9"`B37D@
M3F]T97,B"FUS9W-T<B`BI]JJNK/&I]&__2(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HR,@IM<V=I9"`B3F5W($YO=&4B"FUS9W-T<B`BMW.\5[I+K6XB
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0P"FUS9VED(").97AT
M(@IM<V=S='(@(J15I$"H0B(*"B,Z(&QI8B]A<&DN<&AP.C(P-@IM<V=I9"`B
M3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.P@
M:4-A;&5N9&%R(+CJKL8N(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*;7-G
M:60@(DYO(&YO=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G
M<W1R("*U3*5IJ-&HT[NKJ,^ESJJZL\:GT;_]+B(*"B,Z('1E;7!L871E<R]L
M:7-T+VAE861E<BYI;F,Z,PIM<V=I9"`B3F\@;F]T97,B"FUS9W-T<B`BJ%.F
ML[I+K6XB"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z,PIM<V=I9"`B
M3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@
M(JA3IK.Z2ZUNLL6F6+=JM$VQ^*7S+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ,#@*;7-G:60@(DYO(&YO=&5S('1O(&1I<W!L87DB"FUS9W-T<B`B
MM4RZ2ZUNI6FHT<7CI=PB"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E
M<G,N:6YC.C0T"FUS9VED(").;U]T92(*;7-G<W1R("*Z2ZUN7W0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$*;7-G:60@(DYO=&4@0V%T96=O<GDB
M"FUS9W-T<B`BNDNM;J3`P_XB"@HC.B!V:65W+G!H<#HX,"!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHR,0IM<V=I9"`B3F]T92!$971A:6QS(@IM<V=S='(@
M(KI+K6ZRT[A@(@H*(SH@;F]T97!A9',N<&AP.C$Q,`IM<V=I9"`B3F]T92!,
M:7-T<R(*;7-G<W1R("*F0Z58NDNM;B(*"B,Z('1E;7!L871E<R]V:65W+VUE
M;6\N:6YC.C0U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`IM<V=I9"`B3F]T
M92!497AT(@IM<V=S='(@(KI+K6ZDNJYE(@H*(SH@=&5M<&QA=&5S+VUE;6\O
M;65M;RYI;F,Z,C8*;7-G:60@(DYO=&4@7U1E>'0B"FUS9W-T<B`BNDNM;J2Z
MKF5?5"(*"B,Z('9I97<N<&AP.C4W(&UE;6\N<&AP.C8P"FUS9VED(").;W1E
M(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLNDNM;BXB"@HC.B!T96UP;&%T
M97,O;65M;R]M96UO+FEN8SHS-`IM<V=I9"`B3F]T95]P860B"FUS9W-T<B`B
ML\:GT;_]7W`B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC
M.C<Y"FUS9VED(").;W1E<&%D)W,@;F%M93HB"FUS9W-T<B`BL\:GT;_]JKJF
M5[K9.B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C$*
M;7-G:60@(DYO=&5P861S(@IM<V=S='(@(K/&I]&__2(*"B,Z(&YO=&5P861S
M+G!H<#HS,PIM<V=I9"`B3F]T97!A9',@;75S="!H879E(&$@;F%M92XB"FUS
M9W-T<B`BL\:GT;_]I;*VMZUNIK.D0*W3IE>ZV2XB"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,PIM<V=I9"`B3F]T97,@4W5M;6%R>2(*;7-G<W1R("*Z
M2ZUNI,##_B(*"B,Z(&QI8B]A<&DN<&AP.C$X,R!L:6(O87!I+G!H<#HR-SD@
M;&EB+V%P:2YP:'`Z,S4U(&QI8B]A<&DN<&AP.C,X-`IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`BIG.H^KY$J=HB"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C@R"FUS9VED(")097)M:7-S:6]N<R(*
M;7-G<W1R("+%=JVM(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*
M;7-G:60@(E)E86QL>2!D96QE=&4@=&AI<R!N;W1E/R(*;7-G<W1R("*]5*EW
MIU*PHZ:YNDNM;B`_(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHU
M('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z-@IM<V=I9"`B4F5F<F5S:"!,
M:7-T(@IM<V=S='(@(JVKMW.^X[)Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H
M;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*;7-G:60@(E)E;6]V92!C871E9V]R
M>2(*;7-G<W1R("*ROK"CI,##_B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N
M;W1E<&%D<RYI;F,Z.38*;7-G:60@(E)E<V5T(@IM<V=S='(@(JVKLUTB"@HC
M.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU-@IM<V=I9"`B4V%V92(*;7-G
M<W1R("+`>*9S(@H*(SH@<V5A<F-H+G!H<#HQ-R!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S$*
M;7-G:60@(E-E87)C:"(*;7-G<W1R("*W:K1-(@H*(SH@;&ES="YP:'`Z-3<*
M;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(K=JM$VULJI'(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$W"FUS9VED(")396%R8V@@
M4V-O<&4B"FUS9W-T<B`BMVJT3;UDL_(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z.0IM<V=I9"`B4V5A<F-H(%]497AT(@IM<V=S='(@(K=J
MM$VDNJYE7U0B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC
M.C8W"FUS9VED(")396QE8W0@82!N;W1E<&%D(@IM<V=S='(@(J&PO="_[[[<
MI$"EN[/&I]&__:&P(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$V"FUS9VED
M(")396QE8W0@;F]T97!A9',@=&\@9&ES<&QA>3HB"FUS9W-T<B`BO^^^W*UN
MQ>.EW*JZL\:GT;_].B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,34*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B
MO^^^W+;7I5BNYJ:A.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,S<*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@
M(K_OOMRVUZ1*P,FNUSHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$U"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z(@IM<V=S='(@(K_OOMRHT[>]P,FNUZ[FIJ$Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#D*;7-G:60@(E-E;&5C
M=&5D($-A=&5G;W)I97,Z(@IM<V=S='(@(J1WO^^^W*JZI,##_B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HS-PIM<V=I9"`B4VAO=R!A8W1I;VX@8G5T
M=&]N<S\B"FUS9W-T<B`BQ>.EW*=`I<ZK]K9S/R(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HT,`IM<V=I9"`B4VAO=R!N;W1E<&%D(&YA;64_(@IM<V=S
M='(@(L7CI=RSQJ?1O_VF5[K9(#\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z-#,*;7-G:60@(E-H;W<@;F]T97,@9G)O;2!T:&5S92!C871E9V]R:65S
M(@IM<V=S='(@(K%QLV^HQZ3`P_[%XZ7<NDNM;B(*"B,Z('1E;7!L871E<R]L
M:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#@*;7-G:60@(E-O<G0@8GD@0V%T96=O
M<GDB"FUS9W-T<B`BJ,RDP,/^L<:GQR(*"B,Z('1E;7!L871E<R]L:7-T+VUE
M;6]?:&5A9&5R<RYI;F,Z-#0*;7-G:60@(E-O<G0@8GD@3F]T92!497AT(@IM
M<V=S='(@(J5(NDNM;J2ZKF6QQJ?'(@H*(SH@;65M;RYP:'`Z,3,U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!<(B5S7"(N(@IM
M<V=S='(@(EPB)7-<(J1WP'BF<Z>YIJ@N(@H*(SH@;65M;RYP:'`Z,34Y"FUS
M9VED(")4:&4@;F]T92!W87,@9&5L971E9"XB"FUS9W-T<B`BNDNM;J1WIU*P
MHRXB"@HC.B!N;W1E<&%D<RYP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&YO=&5P860@7"(E<UPB(&-O=6QD;B=T(&)E(&-R96%T960Z("5S(@IM
M<V=S='(@(J:YL\:GT;_](%PB)7-<(B"U3*IKLU$Z("5S(*O8I=\N(@H*(SH@
M;F]T97!A9',N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E
M<&%D(%PB)7-<(B!H87,@8F5E;B!C<F5A=&5D+B(*;7-G<W1R("*FN;/&I]&_
M_2!<(B5S7"(@I'>S4:O8I=\N(@H*(SH@;F]T97!A9',N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R("*FN;/&I]&__2!<(B5S7"(@I'>S4:=2L*,N(@H*
M(SH@;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N
M;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`BIKFSQJ?1
MO_T@7"(E<UPB(*1WLU'`>*9S+B(*"B,Z(&1A=&$N<&AP.C$X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!D871A.B`E<R(*;7-G<W1R("*VUZ1*LV^MT[CJKL8Z("5S(*[)M6^ES:1`
MK=._^;M^(@H*(SH@;&EB+V%P:2YP:'`Z,C`P"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T
M<B`BMM>D2B!I0V%L96YD87(@N.JNQJ[)M6^ES:1`K=._^;M^+B(*"B,Z(&QI
M8B]A<&DN<&AP.C0P,PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@=DYO=&4@9&%T82XB"FUS9W-T<B`BMM>D2B!V3F]T92"XZJ[&
MKLFU;Z7-I$"MT[_YNWXN(@H*(SH@;65M;RYP:'`Z,34W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&4@;F]T
M93H@)7,B"FUS9W-T<B`BLKZPH[I+K6XZ("5S(*[)M6^ES:1`K=._^;M^+B(*
M"B,Z(&UE;6\N<&AP.C$S,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R("+`>*9S
MNDNM;CH@)7,@KLFU;Z7-I$"MT[_YNWXN(@H*(SH@=FEE=RYP:'`Z-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@
M=&AI<R!N;W1E<&%D.B`E<R(*;7-G<W1R("+`R[7XIKFSQJ?1O_TZ("5S(*[)
MM6^ES:1`K=._^;M^+B(*"B,Z(&1A=&$N<&AP.C<Y"FUS9VED(")4:&5R92!W
M97)E(&YO(&UE;6]S('1O(&5X<&]R="XB"FUS9W-T<B`BJ%.FL[I+K6ZE:;;7
MI5@N(@H*(SH@9&%T82YP:'`Z,3`U"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T
M(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(J:YP,FNUZ[FIJ&HPZ6\LU&D
MY+2I+B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`BM4RJ:Z=2
ML*,@7"(E<UPB.B`E<R(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4X
M"FUS9VED(")5;F1O(&-H86YG97,B"FUS9W-T<B`BJ/JN^,7<I_,B"@HC.B!T
M96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-R!T96UP;&%T97,O;&ES="]M96UO
M7W-U;6UA<FEE<RYI;F,Z,30*(SH@;&EB+TUN96UO+G!H<#HR,#8@;&EB+TUN
M96UO+G!H<#HR,#<@;&EB+TUN96UO+G!H<#HR,C$@;&EB+TUN96UO+G!H<#HR
M,C(*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P,PIM<V=I9"`B56YF:6QE
M9"(*;7-G<W1R("*EO*3`P_XB"@HC.B!L:6(O87!I+G!H<#HR,S8@;&EB+V%P
M:2YP:'`Z,S$Y(&QI8B]A<&DN<&AP.C0Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(J6\I.2T
MJ:JZI+JN9:NLND$Z("5S+B`H56YS=7!P;W)T960@0V]N=&5N="U4>7!E*2(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C(*;7-G:60@(E=H:6-H
M($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\B"FUS9W-T
M<B`BK6ZQ3KI+K6Z\5Z5;IMRM_J1`I;NSQJ?1O_VI3S\B"@HC.B!D871A+G!H
M<#HT,B!D871A+G!H<#HQ,C4@;65M;RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&YO=&5S+B(*;7-G<W1R("*G0:A3IK.KV*7?ME>Y3"`E9""MT[I+K6ZJ
MNL5VK:TN(@H*(SH@=FEE=RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A
M9"`E<RXB"FUS9W-T<B`BIT&HPZ6\OM:FL\#+M?BSQJ?1O_T@)7,@JKK%=JVM
M+B(*"B,Z(&YO=&5P861S+G!H<#HV-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T
M(&$@;F]T97!A9"!T;R!B92!D96QE=&5D+B(*;7-G<W1R("*G0:6RMK>E_;_O
MOMRD0*W3K6ZG4K"CJKJSQJ?1O_TN(@H*(SH@=&5M<&QA=&5S+W!R969S+VYO
M=&5P861S96QE8W0N:6YC.C$P"FUS9VED(")9;W5R(&1E9F%U;'0@;F]T97!A
M9#HB"FUS9W-T<B`BIT&JNKEWLUVSQJ?1O_TB"@HC.B!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*
M;7-G<W1R("*G0:JZL\:GT;_].B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N
M:6YC.C$X"FUS9VED(")?0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(JKPIEZS
MQJ?1O_U?0B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4Q('1E;7!L
M871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#@*;7-G:60@(E]#871E9V]R
M>2(*;7-G<W1R("*DP,/^7T,B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHQ-0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R("*G4K"C7T0B"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHQ,0IM<V=I9"`B7T5D:70B"FUS9W-T<B`B
MO7._Z%]%(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"FUS
M9VED(")?1FER<W0@3&EN92(*;7-G<W1R("*RQ*1`IN9?1B(*"B,Z(&QI8B]-
M;F5M;RYP:'`Z,C@Q"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R("*V
MUZ1*+[;7I5A?22(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8T"FUS9VED(")?3&ES
M="!.;W1E<R(*;7-G<W1R("*F0Z58NDNM;E],(@H*(SH@;&EB+TUN96UO+G!H
M<#HR-S8*;7-G:60@(E]->2!.;W1E<&%D<R(*;7-G<W1R("*GVJJZL\:GT;_]
M7TTB"@HC.B!L:6(O36YE;6\N<&AP.C(V.0IM<V=I9"`B7TYE=R!.;W1E(@IM
M<V=S='(@(K=SO%>Z2ZUN7TXB"@HC.B!L:6(O36YE;6\N<&AP.C(X-@IM<V=I
M9"`B7U!R:6YT(@IM<V=S='(@(J9#IDQ?4"(*"B,Z(&QI8B]-;F5M;RYP:'`Z
M,C<R"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(K=JM$U?4R(*"B,Z(&1A=&$N
M<&AP.CDQ('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B;F]T
M97,N8W-V(@IM<V=S='(@(K/&I]&__2YC<W8B"@HC.B!D871A+G!H<#HS,R!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$X"FUS9VED(")V3F]T92(*;7-G
M<W1R(")V3F]T92(*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W!O+VUN96UO+G!O
M=```````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C,V
M,C(`,3`T,3<S-C(W-#8`,#(P,#(P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@4T]-12!$15-#4DE05$E612!4251,12X*
M(R!#;W!Y<FEG:'0@*$,I(%E%05(@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL
M92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H
M92!004-+04=%('!A8VMA9V4N"B,@1DE24U0@05542$]2(#Q%34%)3$!!1$12
M15-3/BP@645!4BX*(PHC+"!F=7IZ>0IM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@4$%#2T%'12!615)324].7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z-#<K,#$P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@645!4BU-3RU$02!(3SI-22M:3TY%7&XB"B),87-T+51R
M86YS;&%T;W(Z($953$P@3D%-12`\14U!24Q`041$4D534SY<;B(*(DQA;F=U
M86=E+51E86TZ($Q!3D=504=%(#Q,3$!L:2YO<F<^7&XB"B)-24U%+59E<G-I
M;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/4-(05)3151<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<
M;B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!N;W1E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!C:&%R
M86-T97)S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G
M<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z.3D@;&EB+V)A<V4N<&AP.C$P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS9VED("(Q(&YO=&4B
M"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z,38R"FUS9VED(")!8V-E<W,@9&5N
M:65D(&1E;&5T:6YG(&YO=&4N(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP.C$Q
M,B!M96UO+G!H<#HQ,34*;7-G:60@(D%C8V5S<R!D96YI960@;6]V:6YG('1H
M92!N;W1E+B(*;7-G<W1R("(B"@HC.B!M96UO+G!H<#HX-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E('1O("5S+B(*
M;7-G<W1R("(B"@HC.B!M96UO+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P,PIM
M<V=I9"`B061D(&-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP.C4R
M"FUS9VED(")!9&1I;F<@02!.97<@3F]T92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC
M.CDY"FUS9VED(")!=F%I;&%B;&4@0V%T96=O<FEE<SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3@*;7-G:60@(D)A8VL@=&\@
M3F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T
M97!A9',N:6YC.CDW"FUS9VED(")"86-K('1O($YO=&5P860@3W!T:6]N<R(*
M;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M-30@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C8*;7-G:60@(D-A=&5G;W)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI
M;F,Z,C(*;7-G:60@(D-H86YG92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34*;7-G:60@(D-H86YG92!Y;W5R(&YO=&4@<V]R=&EN
M9R!A;F0@9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.CDS"FUS9VED(")#:&]O
M<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T;R!L:7-T(&EN('1H92!S=6UM87)Y
M('9I97<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,@IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!.;W1E<&%D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S(*;7-G:60@
M(D-L96%R($9O<FTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHQ-R!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.CDT"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.38*
M;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]M
M96UO+FEN8SHS,@IM<V=I9"`B0W)E871E9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C$*;7-G:60@(D1E9F%U;'0@3F]T97!A9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(*;7-G:60@
M(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S"FUS9VED(")$969A=6QT('-O<G1I;F<@
M9&ER96-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;F]T97!A9',O
M;F]T97!A9',N:6YC.CDU('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(X"FUS9VED(")$96QE=&4@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B1&5L971E(&)U
M='1O;B!B96AA=FEO=7(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;6\O
M;65M;RYI;F,Z-C<*;7-G:60@(D1E;&5T92!T:&ES(&YO=&4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R"FUS9VED(")$97-C96YD
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D
M<RYI;F,Z.#4*;7-G:60@(D1E<V-R:7!T:6]N.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(D1I<W!L87D@3W!T:6]N
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G
M:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3$*;7-G
M:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]S
M=6UM87)I97,N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S
M+FEN8SHT,B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-S<*;7-G:60@(D5D:70@
M3F]T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E
M<G,N:6YC.C4R"FUS9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI
M;F,Z,3(*;7-G:60@(D5M<'1Y($YO=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ.0IM<V=I9"`B17AP;W)T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z.`IM<V=I9"`B17AP
M;W)T($YO=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHR,0IM<V=I9"`B1E]U;&P@5&5X="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-PIM<V=I9"`B1V5N97)A;"!/
M<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@3F]T97,L(%-T97`@
M)60B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3DS"FUS9VED("));7!O<G0O
M17AP;W)T($YO=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+VUE
M;6\N:6YC.C,Y"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C<R"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!.;W1E
M<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,PIM<V=I9"`B365M;R!497AT
M(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO9&EF>6EN9R`E<R(*;7-G<W1R("(B"@HC.B!L:7-T+G!H<#HS-0IM
M<V=I9"`B37D@3F]T97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C0P"FUS9VED(").97AT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C(P-0IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A
M=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N=2YI
M;F,Z-PIM<V=I9"`B3F\@;F]T97!A9',@87)E(&%V86EL86)L92!T;R!G=65S
M=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z
M,PIM<V=I9"`B3F\@;F]T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI
M<W0O96UP='DN:6YC.C,*;7-G:60@(DYO(&YO=&5S(&UA=&-H('1H92!C=7)R
M96YT(&-R:71E<FEA+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,3`S"FUS9VED(").;R!N;W1E<R!T;R!D:7-P;&%Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#0*;7-G
M:60@(DYO7W1E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,0IM<V=I9"`B3F]T92!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!V:65W
M+G!H<#HX,B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,0IM<V=I9"`B3F]T
M92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H<#HQ,3`*;7-G
M:60@(DYO=&4@3&ES=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z-#4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P"FUS9VED(").
M;W1E(%1E>'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI
M;F,Z,C8*;7-G:60@(DYO=&4@7U1E>'0B"FUS9W-T<B`B(@H*(SH@=FEE=RYP
M:'`Z-3<@;65M;RYP:'`Z-C`*;7-G:60@(DYO=&4@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHS-`IM<V=I9"`B
M3F]T95]P860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHW.0IM<V=I9"`B3F]T97!A9"=S(&YA;64Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C$*;7-G
M:60@(DYO=&5P861S(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H<#HS,PIM
M<V=I9"`B3F]T97!A9',@;75S="!H879E(&$@;F%M92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(DYO=&5S(%-U;6UA
M<GDB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3@R(&QI8B]A<&DN<&AP
M.C(W."!L:6(O87!I+G!H<#HS-30@;&EB+V%P:2YP:'`Z,S@S"FUS9VED(")0
M97)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.C@R"FUS9VED(")097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B
M4F5A;&QY(&1E;&5T92!T:&ES(&YO=&4_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L:7-T+VAE861E<BYI;F,Z-2!T96UP;&%T97,O;&ES="]H96%D97(N
M:6YC.C8*;7-G:60@(E)E9G)E<V@@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P-0IM<V=I9"`B
M4F5M;W9E(&-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N;W1E
M<&%D<R]N;W1E<&%D<RYI;F,Z.38*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4V"FUS9VED(")3879E(@IM
M<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z,3<@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:6YC.C0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,Q"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@
M(E-E87)C:"!297-U;'1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B4V5A<F-H(%-C;W!E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHY"FUS9VED(")3
M96%R8V@@7U1E>'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHV-PIM<V=I9"`B4V5L96-T(&$@;F]T97!A9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,38*;7-G:60@(E-E;&5C
M="!N;W1E<&%D<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")396QE8W0@=&AE(&5X<&]R
M="!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,S<*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*;7-G
M:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T
M+FEN8SHQ,#D*;7-G:60@(E-E;&5C=&5D($-A=&5G;W)I97,Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS-PIM<V=I9"`B4VAO=R!A
M8W1I;VX@8G5T=&]N<S\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C0P"FUS9VED(")3:&]W(&YO=&5P860@;F%M93\B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0S"FUS9VED(")3:&]W(&YO
M=&5S(&9R;VT@=&AE<V4@8V%T96=O<FEE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0X"FUS9VED(")3;W)T(&)Y
M($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?
M:&5A9&5R<RYI;F,Z-#0*;7-G:60@(E-O<G0@8GD@3F]T92!497AT(@IM<V=S
M='(@(B(*"B,Z(&UE;6\N<&AP.C$S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!M96UO
M+G!H<#HQ-3D*;7-G:60@(E1H92!N;W1E('=A<R!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!N;W1E<&%D<RYP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&YO=&5P860@7"(E<UPB(&-O=6QD;B=T(&)E(&-R96%T960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS
M9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R
M("(B"@HC.B!D871A+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3DY"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z-#`R"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!V3F]T92!D871A+B(*;7-G<W1R("(B"@HC.B!M
M96UO+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R("(B"@HC.B!M
M96UO+G!H<#HQ,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R('-A=FEN9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B(@H*(SH@=FEE
M=RYP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<R(*;7-G<W1R("(B"@HC.B!D
M871A+G!H<#HW.0IM<V=I9"`B5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E>'!O
M<G0N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$P-0IM<V=I9"`B5&AI<R!F
M:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!N
M;W1E<&%D<RYP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M96UO+VUE;6\N:6YC.C4X"FUS9VED(")5;F1O(&-H86YG97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C<@=&5M<&QA=&5S+VQI
M<W0O;65M;U]S=6UM87)I97,N:6YC.C$T"B,Z(&QI8B]-;F5M;RYP:'`Z,C`V
M(&QI8B]-;F5M;RYP:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z,C(Q(&QI8B]-;F5M
M;RYP:'`Z,C(R"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HY.`IM<V=I9"`B
M56YF:6QE9"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR,S4@;&EB+V%P
M:2YP:'`Z,S$X(&QI8B]A<&DN<&AP.C0Q,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C(*;7-G:60@(E=H:6-H($YO
M=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\B"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z-#(@9&%T82YP:'`Z,3(U(&UE;6\N<&AP.C,U"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!N;W1E<RXB"FUS9W-T<B`B(@H*(SH@=FEE=RYP
M:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A9"`E<RXB"FUS9W-T<B`B(@H*
M(SH@;F]T97!A9',N<&AP.C8U"FUS9VED(")9;W4@;75S="!S96QE8W0@82!N
M;W1E<&%D('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]N;W1E<&%D<V5L96-T+FEN8SHQ,`IM<V=I9"`B66]U<B!D969A
M=6QT(&YO=&5P860Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N;W1E<&%D
M<R]N;W1E<&%D<RYI;F,Z-C4*;7-G:60@(EEO=7(@;F]T97!A9',Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$X"FUS9VED(")?
M0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M96UO
M+VUE;6\N:6YC.C4Q('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z
M-#@*;7-G:60@(E]#871E9V]R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ,0IM<V=I9"`B7T5D:70B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"FUS
M9VED(")?1FER<W0@3&EN92(*;7-G<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP
M.C(X,0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TUN96UO+G!H<#HR-C0*;7-G:60@(E],:7-T($YO=&5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-;F5M;RYP:'`Z,C<V"FUS9VED(")?37D@3F]T97!A9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+TUN96UO+G!H<#HR-CD*;7-G:60@(E].97<@3F]T
M92(*;7-G<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP.C(X-@IM<V=I9"`B7U!R
M:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<R"FUS9VED(")?
M4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.CDQ('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B;F]T97,N8W-V(@IM<V=S='(@(B(*
M"B,Z(&1A=&$N<&AP.C,S('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3@*
M;7-G:60@(G9.;W1E(@IM<V=S='(@(B(*````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W!O+VAU7TA5+G!O````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S(T-S4`
M,3`T,3<S-C(W-#8`,#$W-3,W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@36YE;6\@2'5N9V%R:6%N('1R86YS;&%T:6]N
M(&9I;&4N"B,@0V]P>7)I9VAT("A#*2`R,#`R+3(P,#8@3&%S>FQO($PN(%1O
M<FYO8VD*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A
M;64@;&EC96YS92!A<R!T:&4@36YE;6\@2&]R9&4@<&%C:V%G92X*(R!,871E
M<W0@=F5R<VEO;G,Z(&9T<#HO+WAE;FEA+G-O=&4N:'4O<'5B+VQI;G5X+VAO
M<F1E+PHC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!-;F5M;R`R+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ
M-R`Q,#HP,"LP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$W
M(#$R.C$U*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@3&%S>FQO($PN(%1O
M<FYO8VD@/'1O<FQA<WI`>&5N:6$N<V]T92YH=3Y<;B(*(DQA;F=U86=E+51E
M86TZ($AU;F=A<FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/6ES;RTX.#4Y+3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!N;W1E<R(*;7-G<W1R("(E9"!F96QJ
M96=Y>NES(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@8VAA<F%C=&5R<R(*;7-G<W1R("(E<R!K87)A
M:W1E<B(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R(")!("5S(&;A
M:FP@:6UP;W)TX6SA<V$@<VEK97)E<V5N(&UE9W3V<G3I;G0B"@HC.B!N;W1E
M<&%D<RYP:'`Z.3D@;&EB+V)A<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,@9F5L:F5G>7KI<V5I(@H*
M(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS9VED("(Q(&YO=&4B
M"FUS9W-T<B`B,2!F96QJ96=Y>NES(@H*(SH@;65M;RYP:'`Z,38R"FUS9VED
M(")!8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N(@IM<V=S='(@(DYI;F-S
M(&IO9V]S=6QT<^%G82!A(&9E;&IE9WEZZ7,@=/9R;.ESZ6AE>BXB"@HC.B!M
M96UO+G!H<#HQ,3(@;65M;RYP:'`Z,3$U"FUS9VED(")!8V-E<W,@9&5N:65D
M(&UO=FEN9R!T:&4@;F]T92XB"FUS9W-T<B`B3FEN8W,@:F]G;W-U;'1SX6=A
M(&$@9F5L:F5G>7KI<R#A=&AE;'EE>NESZ6AE>BXB"@HC.B!M96UO+G!H<#HX
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N
M;W1E('1O("5S+B(*;7-G<W1R(").:6YC<R!J;V=O<W5L='/A9V$@82!F96QJ
M96=Y>NES("5S+6)E('3V<G3I;O4@;65N=.ESZ6AE>BXB"@HC.B!M96UO+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN
M9R!N;W1E.B`E<R(*;7-G<W1R(").:6YC<R!J;V=O<W5L='/A9V$@82!F96QJ
M96=Y>NES(&5L;65N=.ESZ6AE>CH@)7,N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#,*;7-G:60@(D%D9"!C871E9V]R
M>2(*;7-G<W1R(")+871E9_-R:6$@:&]Z>N%A9.%S82(*"B,Z(&UE;6\N<&AP
M.C4R"FUS9VED(")!9&1I;F<@02!.97<@3F]T92(*;7-G<W1R("+::B!F96QJ
M96=Y>NES(&OI<WKM=.ES92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,0IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(F[V=F5K=O4B"@HC.B!T96UP
M;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.CDY"FUS9VED(")!
M=F%I;&%B;&4@0V%T96=O<FEE<SHB"FUS9W-T<B`B02!R96YD96QK97KI<W)E
M(.%L;/,@:V%T96?S<FGA:SHB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHQ.`IM<V=I9"`B0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(E9I<W-Z82!A
M(&9E;&IE9WEZZ7-E:VAE>B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E
M<&%D<RYI;F,Z.3<*;7-G:60@(D)A8VL@=&\@3F]T97!A9"!/<'1I;VYS(@IM
M<V=S='(@(E9I<W-Z82!A(&9E;&IE9WEZZ7-E:R!B9>%L;.UTX7-A:6AO>B(*
M"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*
M;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!D871A+G!H<#HU-"!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHR-@IM<V=I9"`B0V%T96=O<GDB"FUS9W-T
M<B`B2V%T96?S<FEA(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHR,@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(E;A;'1O>G1A=.%S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U"FUS9VED(")#:&%N9V4@>6]U
M<B!N;W1E('-O<G1I;F<@86YD(&1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B
M02!S;W)R96YD<F4@Z7,@;65G:F5L96[M=.ES<F4@=F]N871K;WKS(&)EX6QL
M[73A<V]K(&UE9W;A;'1O>G1A=.%S82XB"@HC.B!T96UP;&%T97,O<')E9G,O
M<VAO=W-U;6UA<GES96QE8W0N:6YC.CDS"FUS9VED(")#:&]O<V4@=&AE(&UE
M;6\@8V%T96=O<FEE<R!T;R!L:7-T(&EN('1H92!S=6UM87)Y('9I97<N(@IM
M<V=S='(@(B(*(E;A;&%S<WIA(&MI+"!M96QY(&MA=&5G\W)IX6KZ(&9E;&IE
M9WEZZ7-E:R!J96QE;FIE;F5K(&UE9R!A>B#V<W-Z969O9VQA;/-B86XN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R"FUS9VED(")#:&]O<V4@>6]U
M<B!D969A=6QT($YO=&5P860N(@IM<V=S='(@(E;A;&%S<WIA(&MI(&%Z(-9N
M(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&IE9WEZ971T]FUB:NET+B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS,@IM<V=I9"`B0VQE87(@
M1F]R;2(*;7-G<W1R(")!(&UE>O5K('3V<FSI<V4B"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C$W('1E;7!L871E<R]N;W1E<&%D<R]N
M;W1E<&%D<RYI;F,Z.30*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHY-@IM<V=I9"`B0W)E871E(@IM<V=S='(@(DSI=')E:&]ZX7,B"@HC
M.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHS,@IM<V=I9"`B0W)E871E9"(*
M;7-G<W1R("),Z71R96AO>G9A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q"FUS9VED(")$969A=6QT($YO=&5P860B"FUS9W-T<B`B07H@UFX@86QA
M<.ER=&5L;65ZZ7,@<WIE<FEN=&D@:F5G>7IE='3V;6)J92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,@IM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R
M:71E<FEA.B(*;7-G<W1R(")!('-O<F)A<F5N9&5ZZ7,@86QA<.ER=&5L;65Z
MZ7,@<WIE<FEN=&D@<WIE;7!O;G1J83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM
M<V=S='(@(D$@<V]R8F%R96YD97KI<R!A;&%PZ7)T96QM97KI<R!S>F5R:6YT
M:2!I<N%N>6$Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN
M8SHY-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B1&5L971E
M(@IM<V=S='(@(E3V<FSI<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R(")!('3V<FSI
M<R!M96=E<O5S[73I<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*
M;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(D$@=/9R
M;.ES(&=O;6(@=FES96QK963I<V4B"@HC.B!T96UP;&%T97,O;65M;R]M96UO
M+FEN8SHV-PIM<V=I9"`B1&5L971E('1H:7,@;F]T92(*;7-G<W1R(")4]G+V
M;&K\:R!E>G0@82!F96QJ96=Y>NES="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,@IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R(")C<_9K:V5N]2(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*;7-G:60@
M(D1E<V-R:7!T:6]N.B(*;7-G<W1R("),9>URX7,Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T
M<B`B365G:F5L96[M=.ES:2!B9>%L;.UTX7-O:R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D
M96QE=&EN9R!E;G1R:65S/R(*;7-G<W1R(")!>B!A9&%T;VL@=/9R;.ESZ70@
M;65G96SU>O5E;B#S:&%J="UE(&5G>2!M96=E<O5S[73U(&OI<F3I<W0_(@H*
M(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3$*;7-G:60@(D5D:70B"FUS
M9W-T<B`B3?-D;W/M=.%S(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM
M87)I97,N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B
M"FUS9W-T<B`B7"(E<UPB(&WS9&]S[73A<V$B"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C0R(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HW
M-PIM<V=I9"`B161I="!.;W1E(@IM<V=S='(@(D$@9F5L:F5G>7KI<R!M\V1O
M<^UTX7-A(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHU
M,@IM<V=I9"`B161I="!C871E9V]R:65S(&%N9"!C;VQO<G,B"FUS9W-T<B`B
M2V%T96?S<FGA:R#I<R!S>NUN96EK(';A;'1O>G1A=.%S82(*"B,Z('1E;7!L
M871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ,@IM<V=I9"`B16UP='D@
M3F]T92(*;7-G<W1R(")!(&9E;&IE9WEZZ7,@_')E<R(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3D*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%
M>'!O<G3A;.%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS
M9VED(")%>'!O<G0@3F]T97,B"FUS9W-T<B`B2F5G>7IE='3V;6+V:R!E>'!O
M<G3A;.%S82(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,0IM
M<V=I9"`B1E]U;&P@5&5X="(*;7-G<W1R(")496QJ97,@<WKV=F5G(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<*;7-G:60@(D=E;F5R86P@
M3W!T:6]N<R(*;7-G<W1R("+!;'1A;.%N;W,@8F7A;&SM=.%S;VLB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T($YO=&5S+"!3=&5P("5D(@IM<V=S='(@(D9E;&IE9WEZZ7-E
M:R!I;7!O<G3A;.%S82P@)60N(&SI<.ES(@H*(SH@9&%T82YP:'`Z,3DS"FUS
M9VED("));7!O<G0O17AP;W)T($YO=&5S(@IM<V=S='(@(D9E;&IE9WEZZ7-E
M:R!I;7!O<G3A;.%S82]E>'!O<G1J82(*"B,Z('1E;7!L871E<R]V:65W+VUE
M;6\N:6YC.C,Y"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(E5T;VQS
M\R!M\V1O<^UTX7,B"@HC.B!L:6(O87!I+G!H<#HW,@IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@3F]T97,B"FUS9W-T<B`B02!F96QJ96=Y>NES96L@;6%X
M:6WA;&ES('-ZX6UA(@H*(SH@9&%T82YP:'`Z-3,*;7-G:60@(DUE;6\@5&5X
M="(*;7-G<W1R(")!(&9E;&IE9WEZZ7,@<WKV=F5G92(*"B,Z(&UE;6\N<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(DUO9&EF>6EN9R`E<R(*;7-G<W1R
M("(E<R!VX6QT;WIT873A<V$B"@HC.B!L:7-T+G!H<#HS-0IM<V=I9"`B37D@
M3F]T97,B"FUS9W-T<B`B2F5G>7IE='3V;6)J96EM(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*;7-G<W1R("+::B!F
M96QJ96=Y>NES(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM
M<V=I9"`B3F5X="(*;7-G<W1R(")+]G9E=&ME>O4B"@HC.B!L:6(O87!I+G!H
M<#HR,#8*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS
M9W-T<B`B3F5M('1A;.%L:&%T\R!I0V%L96YD87(@861A="XB"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B3F\@;F]T97!A9',@87)E(&%V86EL
M86)L92!T;R!G=65S=',N(@IM<V=S='(@(D$@=F5N9.EG(&9E;&AA<WINX6SS
M:R!RZ7-ZZ7)E(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92!J96=Y>F5T=/9M8BXB
M"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(DYO(&YO
M=&5S(@IM<V=S='(@(DYI;F-S(&5G>2!F96QJ96=Y>NES('-E;2(*"B,Z('1E
M;7!L871E<R]L:7-T+V5M<'1Y+FEN8SHS"FUS9VED(").;R!N;W1E<R!M871C
M:"!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B3FEN8W,@82!F96QT
MZ71E;&5K;F5K(&UE9V9E;&5L]2!F96QJ96=Y>NES+B(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ,#,*;7-G:60@(DYO(&YO=&5S('1O(&1I<W!L87DB
M"FUS9W-T<B`B3FEN8W,@;65G:F5L96[M=&AE=/4@9F5L:F5G>7KI<R(*"B,Z
M('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#0*;7-G:60@(DYO
M7W1E(@IM<V=S='(@(D9E;&IE9WEZZ7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#$*;7-G:60@(DYO=&4@0V%T96=O<GDB"FUS9W-T<B`B02!F96QJ
M96=Y>NES(&MA=&5G\W)IX6IA(@H*(SH@=FEE=RYP:'`Z.#`@=&5M<&QA=&5S
M+W9I97<O;65M;RYI;F,Z,C$*;7-G:60@(DYO=&4@1&5T86EL<R(*;7-G<W1R
M(")!(&9E;&IE9WEZZ7,@<NES>FQE=&5S96XB"@HC.B!N;W1E<&%D<RYP:'`Z
M,3$P"FUS9VED(").;W1E($QI<W1S(@IM<V=S='(@(D9E;&IE9WEZZ7-E:R!L
M:7-TX6IA(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-#4@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0P"FUS9VED(").;W1E(%1E>'0B"FUS9W-T<B`B
M02!F96QJ96=Y>NES('-Z]G9E9V4B"@HC.B!T96UP;&%T97,O;65M;R]M96UO
M+FEN8SHR-@IM<V=I9"`B3F]T92!?5&5X="(*;7-G<W1R(")!(&9E;&IE9WEZ
MZ7,@<WKV=F5G92(*"B,Z('9I97<N<&AP.C4W(&UE;6\N<&AP.C8P"FUS9VED
M(").;W1E(&YO="!F;W5N9"XB"FUS9W-T<B`B02!F96QJ96=Y>NES(&YE;2!T
M86SA;&AA=/,N(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,S0*;7-G
M:60@(DYO=&5?<&%D(@IM<V=S='(@(DIE9WEZ971T]FUB(@H*(SH@=&5M<&QA
M=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHW.0IM<V=I9"`B3F]T97!A9"=S
M(&YA;64Z(@IM<V=S='(@(D$@:F5G>7IE='3V;6(@;F5V93HB"@HC.B!T96UP
M;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"FUS9VED(").;W1E<&%D
M<R(*;7-G<W1R(")*96=Y>F5T=/9M8O9K(@H*(SH@;F]T97!A9',N<&AP.C,S
M"FUS9VED(").;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R(")!
M(&IE9WEZ971T]FUB;F5K(&YE=F5T(&ME;&P@861N:2XB"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,PIM<V=I9"`B3F]T97,@4W5M;6%R>2(*;7-G<W1R
M("+6<W-Z969O9VQA;.%S(&$@:F5G>7IE=&5K<O5L(@H*(SH@;&EB+V%P:2YP
M:'`Z,3@S(&QI8B]A<&DN<&AP.C(W.2!L:6(O87!I+G!H<#HS-34@;&EB+V%P
M:2YP:'`Z,S@T"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("+6
M;FYE:R!N:6YC<R!E:&AE>B!E;&5G96YD]2!J;V=O<W5L='/A9V$B"@HC.B!T
M96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C@R"FUS9VED(")097)M
M:7-S:6]N<R(*;7-G<W1R(")*;V=O<W5L='/A9V]K(@H*(SH@=&5M<&QA=&5S
M+W9I97<O;65M;RYI;F,Z,34*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI<R!N
M;W1E/R(*;7-G<W1R(")686SS8F%N('3V<O9L;FD@:^UVX6YJ82!E>G0@82!F
M96QJ96=Y>NES=#\B"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C4@
M=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHV"FUS9VED(")2969R97-H($QI
M<W0B"FUS9W-T<B`B02!L:7-T82!F<FES<^UTZ7-E(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*;7-G:60@(E)E;6]V
M92!C871E9V]R>2(*;7-G<W1R(")!(&MA=&5G\W)I82!T]G)LZ7-E(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S
M970B"FUS9W-T<B`B4F5S970B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN
M8SHU-@IM<V=I9"`B4V%V92(*;7-G<W1R(")-96YTZ7,B"@HC.B!S96%R8V@N
M<&AP.C$W('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHT('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHS,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@
M(DME<F5SZ7,B"@HC.B!L:7-T+G!H<#HU-PIM<V=I9"`B4V5A<F-H(%)E<W5L
M=',B"FUS9W-T<B`B02!K97)E<^ES(&5R961MZ6YY92(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B4V5A<F-H(%-C;W!E(@IM
M<V=S='(@(D$@:V5R97/I<R!H873A<F%I(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.CD*;7-G:60@(E-E87)C:"!?5&5X="(*;7-G<W1R(")+
M97)E<^ES(&$@<WKV=F5G8F5N(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHV-PIM<V=I9"`B4V5L96-T(&$@;F]T97!A9"(*;7-G<W1R
M(")6X6QA<W-Z;VX@:VD@96=Y(&IE9WEZ971T]FUB]G0B"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,38*;7-G:60@(E-E;&5C="!N;W1E<&%D<R!T;R!D:7-P
M;&%Y.B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A(&UE9VIE;&5N[71E;F3U(&IE
M9WEZ971T]FUB]FME=#HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$U"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@
M(E;A;&%S<WIA(&MI(&%Z(&5X<&]R=.%LX7,@9F]R;>%T=6WA=#HB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,W"FUS9VED(")396QE8W0@=&AE
M(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A>B!I;7!O
M<G3A;&%N9/,@9N%J;'0Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F
M:6QE.B(*;7-G<W1R(")6X6QA<W-Z82!K:2P@:&]G>2!M:6QY96X@9F]R;>%T
M=6WZ(&;A:FQB\VP@:^UVX6X@:6UP;W)TX6QN:3HB"@HC.B!T96UP;&%T97,O
M<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P.0IM<V=I9"`B4V5L96-T
M960@0V%T96=O<FEE<SHB"FUS9W-T<B`B02!K:7;A;&%S>G1O='0@:V%T96?S
M<FGA:SHB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,S<*;7-G:60@(E-H
M;W<@86-T:6]N(&)U='1O;G,_(@IM<V=S='(@(DQE9WEE;F5K(&9U;FMC:?-V
M86P@96QLX71O='0@:6MO;F]K/R`B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z-#`*;7-G:60@(E-H;W<@;F]T97!A9"!N86UE/R(*;7-G<W1R(")-=71A
M<W-U:R!A(&IE9WEZ971T]FUB(&YE=NET/R(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HT,PIM<V=I9"`B4VAO=R!N;W1E<R!F<F]M('1H97-E(&-A=&5G
M;W)I97,B"FUS9W-T<B`B02!K]G9E=&ME>O4@:V%T96?S<FGA:OH@9F5L:F5G
M>7KI<V5K970@:F5L96[M='/\:R!M96<B"@HC.B!T96UP;&%T97,O;&ES="]M
M96UO7VAE861E<G,N:6YC.C0X"FUS9VED(")3;W)T(&)Y($-A=&5G;W)Y(@IM
M<V=S='(@(DMA=&5G\W)I82!S>F5R:6YT:2!S;W)R96YD(@H*(SH@=&5M<&QA
M=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-`IM<V=I9"`B4V]R="!B>2!.
M;W1E(%1E>'0B"FUS9W-T<B`B16QN979E>NES('-Z97)I;G1I('-O<G)E;F0B
M"@HC.B!M96UO+G!H<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D(%PB)7-<(BXB"FUS9W-T<B`B4VEK97)E<V5N(&5L;65N
M=&5T=/QK(%PB)7-<(BUT+B(*"B,Z(&UE;6\N<&AP.C$U.0IM<V=I9"`B5&AE
M(&YO=&4@=V%S(&1E;&5T960N(@IM<V=S='(@(D%Z(&9E;&IE9WEZZ7-T(&MI
M=/9R]FQT_&LN(@H*(SH@;F]T97!A9',N<&AP.C0V"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!C;W5L9&XG="!B92!C<F5A=&5D
M.B`E<R(*;7-G<W1R(")!*'HI(%PB)7-<(B!J96=Y>F5T=/9M8O9T(&YE;2!S
M:6ME<OQL="!LZ71R96AO>FYI.B`E<R(*"B,Z(&YO=&5P861S+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E
M96X@8W)E871E9"XB"FUS9W-T<B`B3.ET<F5H;WIT=6L@82AZ*2!<(B5S7"(@
M:F5G>7IE='3V;6+V="XB"@HC.B!N;W1E<&%D<RYP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&IE9WEZ971T]FUB]G0@:VET]G+V
M;'3\:RXB"@HC.B!N;W1E<&%D<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R
M(")!*'HI(%PB)7-<(B!J96=Y>F5T=/9M8O9T(&5L;65N=&5T=/QK+B(*"B,Z
M(&1A=&$N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R(")!>B!I
M;7!O<G3A;.%S('-O<N%N(&AI8F$@=/9R=.EN=#H@)7,B"@HC.B!L:6(O87!I
M+G!H<#HR,#`*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")!>B!I0V%L96YD87(@861A
M=&]K(&EM<&]R=.%LX7-A('-O<N%N(&AI8F$@=/9R=.EN="XB"@HC.B!L:6(O
M87!I+G!H<#HT,#,*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE('9.;W1E(&1A=&$N(@IM<V=S='(@(D$@=DYO=&4@861A=&]K(&EM
M<&]R=.%LX7-A('-O<N%N(&AI8F$@=/9R=.EN="XB"@HC.B!M96UO+G!H<#HQ
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E
M;6]V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R(")(:6)A('3V<G3I;G0@82!F
M96QJ96=Y>NES('3V<FSI<V4@<V]RX6XZ("5S(@H*(SH@;65M;RYP:'`Z,3,S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I
M;F<@=&AE(&YO=&4Z("5S(@IM<V=S='(@(DAI8F$@=/9R=.EN="!A(&9E;&IE
M9WEZZ7,@96QM96YTZ7-E('-O<N%N.B`E<R(*"B,Z('9I97<N<&AP.C0V"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!V:65W:6YG
M('1H:7,@;F]T97!A9#H@)7,B"FUS9W-T<B`B2&EB82!T]G)TZ6YT(&$@9F5L
M:F5G>7KI<R!M96=J96QE;NUTZ7-E:V]R.B`E<R(*"B,Z(&1A=&$N<&AP.C<Y
M"FUS9VED(")4:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="XB"FUS9W-T
M<B`B3F5M('9O;'0@97AP;W)TX6QH873S(&9E;&IE9WEZZ7,N(@H*(SH@9&%T
M82YP:'`Z,3`U"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(DES;65R971L96X@9N%J;&9O<FWA='5M+B(*"B,Z
M(&YO=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(%PB
M)7-<(BUT('3V<O9L;FDZ("5S(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI
M;F,Z-3@*;7-G:60@(E5N9&\@8VAA;F=E<R(*;7-G<W1R(")-Z6=S92!M96YT
M<_QK(&5L(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C<@=&5M<&QA
M=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C$T"B,Z(&QI8B]-;F5M;RYP
M:'`Z,C`V(&QI8B]-;F5M;RYP:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z,C(Q(&QI
M8B]-;F5M;RYP:'`Z,C(R"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HY.`IM
M<V=I9"`B56YF:6QE9"(*;7-G<W1R(")"97-O<F]L871L86XB"@HC.B!L:6(O
M87!I+G!H<#HR,S8@;&EB+V%P:2YP:'`Z,S$Y(&QI8B]A<&DN<&AP.C0Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z
M("5S(@IM<V=S='(@(DYE;2!TX6UO9V%T;W1T('1A<G1A;&]M=.UP=7,Z("5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,@IM<V=I9"`B5VAI
M8V@@3F]T97!A9"!S:&]U;&0@=&AE(&YO=&5S(&)E(&%D9&5D('1O/R(*;7-G
M<W1R(")-96QY:6L@:F5G>7IE='3V;6)B92!K[7;A;FIA(&$@9F5L:F5G>7KI
M<V5K970@=&5N;FD_(@H*(SH@9&%T82YP:'`Z-#(@9&%T82YP:'`Z,3(U(&UE
M;6\N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!N;W1E<RXB"FUS9W-T<B`B
M3F5M(&AO>FAA="!LZ71R92!T]F)B+"!M:6YT("5D(&9E;&IE9WEZZ7-T+B(*
M"B,Z('9I97<N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@)7,N(@IM
M<V=S='(@(M9N(&YE;2!J;V=O<W5L="!A*'HI("5S(&IE9WEZ971T]FUB(&AA
M<WINX6QA=.%R82XB"@HC.B!N;W1E<&%D<RYP:'`Z-C4*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B
M16SU<WKV<B!K:2!K96QL(';A;&%S>G1A;FEA(&$@=/9R;&5N9/4@:F5G>7IE
M='3V;6+V="XB"@HC.B!T96UP;&%T97,O<')E9G,O;F]T97!A9'-E;&5C="YI
M;F,Z,3`*;7-G:60@(EEO=7(@9&5F875L="!N;W1E<&%D.B(*;7-G<W1R(")!
M>B#6;B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!J96=Y>F5T=/9M8FIE.B(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C4*;7-G:60@
M(EEO=7(@;F]T97!A9',Z(@IM<V=S='(@(D%Z(-9N(&IE9WEZ971T]FUB:F5I
M.B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$X"FUS9VED(")?0F%C
M:R!T;R!.;W1E<&%D(@IM<V=S='(@(E9I<W-Z82!A($9E;&IE9WEZZ7-E:VAE
M>B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4Q('1E;7!L871E<R]L
M:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#@*;7-G:60@(E]#871E9V]R>2(*;7-G
M<W1R(")+871E9_-R:6$B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ
M-0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")4]G)LZ7,B"@HC.B!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHQ,0IM<V=I9"`B7T5D:70B"FUS9W-T<B`B3?-D
M;W/M=.%S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"FUS
M9VED(")?1FER<W0@3&EN92(*;7-G<W1R(")%;'/U('-O<B(*"B,Z(&QI8B]-
M;F5M;RYP:'`Z,C@Q"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R("))
M;7!O<G0O7T5X<&]R="(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8T"FUS9VED(")?
M3&ES="!.;W1E<R(*;7-G<W1R(")?3&ES=&$B"@HC.B!L:6(O36YE;6\N<&AP
M.C(W-@IM<V=I9"`B7TUY($YO=&5P861S(@IM<V=S='(@(DIE9WEZ971T]FUB
M:F5I7VTB"@HC.B!L:6(O36YE;6\N<&AP.C(V.0IM<V=I9"`B7TYE=R!.;W1E
M(@IM<V=S='(@(MI?:B!F96QJ96=Y>NES(@H*(SH@;&EB+TUN96UO+G!H<#HR
M.#8*;7-G:60@(E]0<FEN="(*;7-G<W1R(")?3GEO;71A=.%S(@H*(SH@;&EB
M+TUN96UO+G!H<#HR-S(*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B2V5R95]S
MZ7,B"@HC.B!D871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$*;7-G:60@(FYO=&5S+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS
M,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$X"FUS9VED(")V3F]T92(*
M;7-G<W1R("(B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;6YE;6\O<&\O9FE?1DDN<&\`````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`S,30P-0`Q,#0Q-S,V,C<T-@`P,3<T-S,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R!&
M:6YN:7-H('1R86YS;&%T:6]N(&9O<B!-;F5M;RX*(R!#;W!Y<FEG:'0@*$,I
M"B,@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3XL(#(P,#(M,C`P-BX*(PIM
M<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@36YE;6\@
M,BXQ+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$X(#$X
M.C4R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,3,@,3(Z
M-3DK,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!,965N82!(96EN;R`\;&EI
M;G5`=71A+F9I/EQN(@HB3&%N9W5A9V4M5&5A;3H@1FEN;FES:"`\:3$X;D!L
M:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*
M(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!T96UP
M;&%T97,O;&ES="]H96%D97(N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@;F]T97,B"FUS9W-T<B`B)60@;75I<W1I:6YP86YO82(*"B,Z('1E;7!L
M871E<R]M96UO+VUE;6\N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&-H87)A8W1E<G,B"FUS9W-T<B`B)7,@;65R:VMIY"(*"B,Z(&1A=&$N<&AP
M.C$X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL
M>2!I;7!O<G1E9"(*;7-G<W1R("(E<R!T:65D;W-T;VX@='5O;G1I(&]N;FES
M='5I(@H*(SH@;F]T97!A9',N<&AP.CDY(&QI8B]B87-E+G!H<#HQ,#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S.FX@
M;75I<W1I;&ES=&$B"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*
M;7-G:60@(C$@;F]T92(*;7-G<W1R("(Q(&UU:7-T:6EN<&%N;R(*"B,Z(&UE
M;6\N<&AP.C$V,@IM<V=I9"`B06-C97-S(&1E;FEE9"!D96QE=&EN9R!N;W1E
M+B(*;7-G<W1R(")3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@<&]I<W1A82!M
M=6ES=&EI;G!A;F]A+B(*"B,Z(&UE;6\N<&AP.C$Q,B!M96UO+G!H<#HQ,34*
M;7-G:60@(D%C8V5S<R!D96YI960@;6]V:6YG('1H92!N;W1E+B(*;7-G<W1R
M(")3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@<&]I<W1A82!M=6ES=&EI;G!A
M;F]A+B(*"B,Z(&UE;6\N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D%C
M8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N(@IM<V=S='(@(E-I;G5L
M;&$@96D@;VQE(&]I:V5U:W-I82!T86QL971T86$@;75I<W1I;&ES=&%A;B`E
M<RXB"@HC.B!M96UO+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E
M<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<R(*;7-G<W1R(")3:6YU;&QA(&5I
M(&]L92!O:6ME=6MS:6$@=&%L;&5T=&%A(&UU:7-T:6QI<W1A86X@)7,N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#,*
M;7-G:60@(D%D9"!C871E9V]R>2(*;7-G<W1R("),:7/DY"!L=6]K:71U<R(*
M"B,Z(&UE;6\N<&AP.C4R"FUS9VED(")!9&1I;F<@02!.97<@3F]T92(*;7-G
M<W1R("),:7/D=.3D;B!U=71T82!M=6ES=&EI;G!A;F]A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B
M3F]U<V5V82(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C
M="YI;F,Z.3D*;7-G:60@(D%V86EL86)L92!#871E9V]R:65S.B(*;7-G<W1R
M(")+Y'ET971TY'9I<W/D(&]L979A="!L=6]K:71U:W-E=#HB"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHQ.`IM<V=I9"`B0F%C:R!T;R!.;W1E<&%D
M(@IM<V=S='(@(E1A:V%I<VEN(&UU:7-T:6QI<W1A86XB"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDW"FUS9VED(")"86-K('1O($YO
M=&5P860@3W!T:6]N<R(*;7-G<W1R(")486MA:7-I;B!M=6ES=&EL:7-T86X@
M87-E='5K<VEI;B(*"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3<*;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!D871A
M+G!H<#HU-"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-@IM<V=I9"`B0V%T
M96=O<GDB"FUS9W-T<B`B2V%T96=O<FEA(@H*(SH@=&5M<&QA=&5S+VYO=&5P
M861S+VYO=&5P861S+FEN8SHR,@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(DUU
M=71A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U"FUS9VED(")#:&%N
M9V4@>6]U<B!N;W1E('-O<G1I;F<@86YD(&1I<W!L87D@;W!T:6]N<RXB"FUS
M9W-T<B`B5F]I="!M=75T=&%A(&UU:7-T:6EN<&%N;VIE;B!JY')J97-T96QY
M+2!J82!NY'ET=/9A<V5T=6MS:6$N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H
M;W=S=6UM87)Y<V5L96-T+FEN8SHY,PIM<V=I9"`B0VAO;W-E('1H92!M96UO
M(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T:&4@<W5M;6%R>2!V:65W+B(*;7-G
M<W1R(")686QI='-E('EH=&5E;G9E=&]NY&MY;>1S<^0@;N1Y=&5T=.1VY'0@
M;75I<W1I:6YP86YO;'5O:VET=6MS970N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R"FUS9VED(")#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N
M(@IM<V=S='(@(E9O:70@=F%L:71A(&]L971U<VUU:7-T:6QI<W1A<VDN(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,R"FUS9VED(")#;&5A
M<B!&;W)M(@IM<V=S='(@(E1Y:&IE;F[D(&QO;6%K92(*"B,Z('1E;7!L871E
M<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,3<@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHY-`HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A
M9',N:6YC.CDV"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3'5O(@H*(SH@=&5M
M<&QA=&5S+W9I97<O;65M;RYI;F,Z,S(*;7-G:60@(D-R96%T960B"FUS9W-T
M<B`B3'5O='4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*;7-G:60@
M(D1E9F%U;'0@3F]T97!A9"(*;7-G<W1R(")/;&5T=7-M=6ES=&EL:7-T82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,@IM<V=I9"`B1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")/;&5T=7-JY')J97-T>7,Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S"FUS9VED(")$969A=6QT('-O
M<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R(")/;&5T=7-JY')J97-T>6MS96X@
M<W5U;G1A.B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U('1E;7!L
M871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.34*;7-G:60@(D1E;&5T92(*
M;7-G<W1R(")0;VES=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@*
M;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T<B`B4&]I<W1O;B!V
M87)M:7-T=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*;7-G:60@
M(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(E9O:70@;75U='1A
M82!0;VES=&$@<&%I;FEK:V5E;B!T;VEM:6YT86$B"@HC.B!T96UP;&%T97,O
M;65M;R]M96UO+FEN8SHV-PIM<V=I9"`B1&5L971E('1H:7,@;F]T92(*;7-G
M<W1R(")0;VES=&$@=.1MY"!M=6ES=&EI;G!A;F\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B3&%S
M:V5V82(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*
M;7-G:60@(D1E<V-R:7!T:6]N.B(*;7-G<W1R(")+=79A=7,Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B
M"FUS9W-T<B`B3N1K>6WD;B!A<V5T=6MS970B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3@*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L
M971I;F<@96YT<FEE<S\B"FUS9W-T<B`B2&%L=6%T:V\@=F%R;6ES='5K<V5N
M('!O:7-T971T879I<W1A(&UE<FMI;F[V:7-TY#\B"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHQ,0IM<V=I9"`B161I="(*;7-G<W1R(")-=6]K:V%A
M(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B375O:VMA
M82!<(B5S7"(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC
M.C0R(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HW-PIM<V=I9"`B161I="!.;W1E
M(@IM<V=S='(@(DUU;VMK86$@;75I<W1I:6YP86YO82(*"B,Z('1E;7!L871E
M<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3(*;7-G:60@(D5D:70@8V%T96=O
M<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(DUU;VMK86$@:V%T96=O<FEO:71A
M(&IA(';D<F5JY"(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S
M+FEN8SHQ,@IM<V=I9"`B16UP='D@3F]T92(*;7-G<W1R(")4>6AJY"!M=6ES
M=&EI;G!A;F\B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS
M9VED(")%>'!O<G0B"FUS9W-T<B`B5FEE(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@3F]T97,B"FUS9W-T<B`B5FEE
M(&UU:7-T:6EN<&%N;W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z,C$*;7-G:60@(D9?=6QL(%1E>'0B"FUS9W-T<B`B5%]E:W-T:2!K;VMO
M;F%I<W5U9&5S<V%A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(W"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS9W-T<B`B66QE:7-E="!A
M<V5T=6MS970B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($YO=&5S+"!3=&5P("5D(@IM<V=S
M='(@(E9I97-T:65N('1U;VYT:2P@87-K96P@)60B"@HC.B!D871A+G!H<#HQ
M.3,*;7-G:60@(DEM<&]R="]%>'!O<G0@3F]T97,B"FUS9W-T<B`B5'5O+U9I
M92!M=6ES=&EI;G!A;F]T(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,SD*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B375O:V%T='4@=FEI
M;65K<VDB"@HC.B!L:6(O87!I+G!H<#HW,@IM<V=I9"`B36%X:6UU;2!.=6UB
M97(@;V8@3F]T97,B"FUS9W-T<B`B375I<W1I:6YP86YO:F5N(&5N:6UMY&ES
M;>3D<N0B"@HC.B!D871A+G!H<#HU,PIM<V=I9"`B365M;R!497AT(@IM<V=S
M='(@(DUU:7-T:6EN<&%N;VX@=&5K<W1I(@H*(SH@;65M;RYP:'`Z-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y:6YG("5S(@IM<V=S='(@(DUU;VMA
M=&%A;B`E<R(*"B,Z(&QI<W0N<&AP.C,U"FUS9VED(")->2!.;W1E<R(*;7-G
M<W1R(")/;6$@;75I<W1I:6YP86YO;FDB"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,C(*;7-G:60@(DYE=R!.;W1E(@IM<V=S='(@(E5U<VD@;75I<W1I
M:6YP86YO(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I
M9"`B3F5X="(*;7-G<W1R(")3975R86%V82(*"B,Z(&QI8B]A<&DN<&AP.C(P
M-@IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R
M(")I0V%L96YD87(@=&EE=&]J82!E:2!L]GET>6YY="XB"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z-PIM<V=I9"`B3F\@;F]T97!A9',@87)E(&%V86EL86)L
M92!T;R!G=65S=',N(@IM<V=S='(@(E9I97)A:6QI:F]I;&QE(&5I(&]L92!S
M86QL:71T=2!A:6YU='1A:V%A;B!M=6ES=&EL:7-T86$N(@H*(SH@=&5M<&QA
M=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS9VED(").;R!N;W1E<R(*;7-G<W1R
M(")%:2!M=6ES=&EI;G!A;F]J82(*"B,Z('1E;7!L871E<R]L:7-T+V5M<'1Y
M+FEN8SHS"FUS9VED(").;R!N;W1E<R!M871C:"!T:&4@8W5R<F5N="!C<FET
M97)I82XB"FUS9W-T<B`B66MS:6ODY&X@;75I<W1I:6YP86YO(&5I('9A<W1A
M;FYU="!K<FET965R96ETY"XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,3`S"FUS9VED(").;R!N;W1E<R!T;R!D:7-P;&%Y(@IM<V=S='(@(D5I(&UU
M:7-T:6EN<&%N;VIA(&[D>71E='3D=N1K<VDB"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C0T"FUS9VED(").;U]T92(*;7-G<W1R(")-
M=5]I<W1I:6YP86YO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q"FUS
M9VED(").;W1E($-A=&5G;W)Y(@IM<V=S='(@(DUU:7-T:6EN<&%N;VX@;'5O
M:VET=7,B"@HC.B!V:65W+G!H<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHR,0IM<V=I9"`B3F]T92!$971A:6QS(@IM<V=S='(@(DUU:7-T:6EN<&%N
M;VX@>6MS:71Y:7-K;VAD870B"@HC.B!N;W1E<&%D<RYP:'`Z,3$P"FUS9VED
M(").;W1E($QI<W1S(@IM<V=S='(@(DUU:7-T:6EN<&%N;VQI<W1A="(*"B,Z
M('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C0U(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,`IM<V=I9"`B3F]T92!497AT(@IM<V=S='(@(DUU:7-T:6EN<&%N
M;VX@=&5K<W1I(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*;7-G
M:60@(DYO=&4@7U1E>'0B"FUS9W-T<B`B375I<W1I:6YP86YO;B!?=&5K<W1I
M(@H*(SH@;65M;RYP:'`Z-C`@=FEE=RYP:'`Z-3<*;7-G:60@(DYO=&4@;F]T
M(&9O=6YD+B(*;7-G<W1R(")-=6ES=&EI;G!A;F]A(&5I(&SV>71Y;GET+B(*
M"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C,T"FUS9VED(").;W1E7W!A
M9"(*;7-G<W1R(")-=6ES=&E?;&ES=&$B"@HC.B!T96UP;&%T97,O;F]T97!A
M9',O;F]T97!A9',N:6YC.C<Y"FUS9VED(").;W1E<&%D)W,@;F%M93HB"FUS
M9W-T<B`B375I<W1I;&ES=&%N(&YI;6DZ(@H*(SH@=&5M<&QA=&5S+VYO=&5P
M861S+VYO=&5P861S+FEN8SHV,0IM<V=I9"`B3F]T97!A9',B"FUS9W-T<B`B
M375I<W1I;&ES=&%T(@H*(SH@;F]T97!A9',N<&AP.C,S"FUS9VED(").;W1E
M<&%D<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R(")-=6ES=&EL:7-T86QL
M82!P:73DY"!O;&QA(&YI;6DN(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C,*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`B375I<W1I:6YP86YO
M:F5N('EH=&5E;G9E=&\B"@HC.B!L:6(O87!I+G!H<#HQ.#,@;&EB+V%P:2YP
M:'`Z,C<Y(&QI8B]A<&DN<&AP.C,U-2!L:6(O87!I+G!H<#HS.#0*;7-G:60@
M(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(DOD>71T]B!K:65L;&5T='DB
M"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C@R"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R(")/:6ME=61E="(*"B,Z('1E;7!L871E
M<R]V:65W+VUE;6\N:6YC.C$U"FUS9VED(")296%L;'D@9&5L971E('1H:7,@
M;F]T93\B"FUS9W-T<B`B4&]I<W1E=&%A;FMO('3D;>0@;75I<W1I:6YP86YO
M/R(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z-2!T96UP;&%T97,O
M;&ES="]H96%D97(N:6YC.C8*;7-G:60@(E)E9G)E<V@@3&ES="(*;7-G<W1R
M(")0Y&EV:73D(&QI<W1A(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM
M87)Y<V5L96-T+FEN8SHQ,#4*;7-G:60@(E)E;6]V92!C871E9V]R>2(*;7-G
M<W1R(")0;VES=&$@;'5O:VET=7,B"@HC.B!T96UP;&%T97,O;F]T97!A9',O
M;F]T97!A9',N:6YC.CDV"FUS9VED(")297-E="(*;7-G<W1R(")4>6AJ96YN
MY"(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4V"FUS9VED(")3879E
M(@IM<V=S='(@(E1A;&QE=&$B"@HC.B!S96%R8V@N<&AP.C$W('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHT('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHS,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(DAA:W4B"@HC.B!L:7-T
M+G!H<#HU-PIM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B2&%U;B!T
M=6QO:W-E="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ-PIM
M<V=I9"`B4V5A<F-H(%-C;W!E(@IM<V=S='(@(DAA=6X@:V]H9&ES='5S(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.CD*;7-G:60@(E-E87)C
M:"!?5&5X="(*;7-G<W1R(")(864@7W1E:W-T:>0B"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C8W"FUS9VED(")396QE8W0@82!N;W1E
M<&%D(@IM<V=S='(@(E9A;&ET<V4@;75I<W1I;&ES=&$B"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,38*;7-G:60@(E-E;&5C="!N;W1E<&%D<R!T;R!D:7-P
M;&%Y.B(*;7-G<W1R(")686QI='-E(&[D>71E='3D=N1T(&UU:7-T:6QI<W1A
M=#HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")3
M96QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E9A;&ET<V4@=FEE
M;FYI<W/D(&OD>71E='3D=N0@;75O=&\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHS-PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R
M=#HB"FUS9W-T<B`B5F%L:71S92!T:65D;W-T;RP@:F]S=&$@='5O9&%A;B!T
M:65T;VIA.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*;7-G
M:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS
M9W-T<B`B5F%L:71S92!LY&AD971I961O<W1O;B!M=6]T;SHB"@HC.B!T96UP
M;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P.0IM<V=I9"`B
M4V5L96-T960@0V%T96=O<FEE<SHB"FUS9W-T<B`B5F%L:71U="!L=6]K:71U
M:W-E=#HB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,S<*;7-G:60@(E-H
M;W<@86-T:6]N(&)U='1O;G,_(@IM<V=S='(@(D[D>73D('1O:6UI;G1O<&%I
M;FEK:V5E="XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#`*;7-G:60@
M(E-H;W<@;F]T97!A9"!N86UE/R(*;7-G<W1R(").Y'ETY"!M=6ES=&EL:7-T
M86YN:6UI+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT,PIM<V=I9"`B
M4VAO=R!N;W1E<R!F<F]M('1H97-E(&-A=&5G;W)I97,B"FUS9W-T<B`B3N1Y
M=.0@;75I<W1I:6YP86YO="!NY&ES=.0@:V%T96=O<FEO:7-T82(*"B,Z('1E
M;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#@*;7-G:60@(E-O<G0@
M8GD@0V%T96=O<GDB"FUS9W-T<B`B2N1R:F5S=.0@;'5O:VET=6MS96X@;75K
M86%N(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-`IM
M<V=I9"`B4V]R="!B>2!.;W1E(%1E>'0B"FUS9W-T<B`B2N1R:F5S=.0@;75I
M<W1I:6YP86YO;B!T96MS=&D@;75K86%N(@H*(SH@;65M;RYP:'`Z,3,U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!<(B5S7"(N
M(@IM<V=S='(@(B<E<R<Z;B!T86QL971U<R!O;FYI<W1U:2XB"@HC.B!M96UO
M+G!H<#HQ-3D*;7-G:60@(E1H92!N;W1E('=A<R!D96QE=&5D+B(*;7-G<W1R
M(")-=6ES=&EI;G!A;F\@;VX@<&]I<W1E='1U+B(*"B,Z(&YO=&5P861S+G!H
M<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@
M8V]U;&1N)W0@8F4@8W)E871E9#H@)7,B"FUS9W-T<B`B375I<W1I;&ES=&%A
M(%PB)7-<(B!E:2!V;VET=2!L=6]D83H@)7,B"@HC.B!N;W1E<&%D<RYP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA
M<R!B965N(&-R96%T960N(@IM<V=S='(@(DUU:7-T:6QI<W1A(%PB)7-<(B!O
M;B!L=6]T=2XB"@HC.B!N;W1E<&%D<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(DUU:7-T:6QI<W1A(%PB)7-<(B!O;B!P;VES=&5T='4N(@H*(SH@
M;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E
M<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B375I<W1I;&ES
M=&$@7"(E<UPB(&]N('1A;&QE=&5T='4N(@H*(SH@9&%T82YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(E1A<&%H='5I('9I<FAE('1U;W1A
M97-S82!T:65T;V$Z("5S(@H*(SH@;&EB+V%P:2YP:'`Z,C`P"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`B5&%P86AT=6D@=FER:&4@='5O=&%E<W-A(&E#86QE;F1A
M<B!T:65T;VIA+B(*"B,Z(&QI8B]A<&DN<&AP.C0P,PIM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=DYO=&4@9&%T82XB"FUS9W-T
M<B`B5&%P86AT=6D@=FER:&4@='5O=&%E<W-A('9.;W1E('1I971O:F$N(@H*
M(SH@;65M;RYP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!R96UO=FEN9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B375I
M<W1I:6YP86YO;B!P;VES=&%M:7-E<W-A('1A<&%H='5I('9I<FAE.B`E<R(*
M"B,Z(&UE;6\N<&AP.C$S,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R(")-=6ES
M=&EI;G!A;F]N('1A;&QE='5K<V5S<V$@=&%P86AT=6D@=FER:&4Z("5S(@H*
M(SH@=FEE=RYP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<R(*;7-G<W1R(")-
M=6ES=&EL:7-T86X@:V%T<V5L=7-S82!T87!A:'1U:2!V:7)H93H@)7,B"@HC
M.B!D871A+G!H<#HW.0IM<V=I9"`B5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E
M>'!O<G0N(@IM<V=S='(@(D5I(&UU:7-T:6EN<&%N;VIA('9I973D=N1K<VDN
M(@H*(SH@9&%T82YP:'`Z,3`U"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES
M(&YO="!S=7!P;W)T960N(@IM<V=S='(@(E3D;>0@=&EE9&]S=&]M=6]T;R!E
M:2!O;&4@='5E='1U+B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B16D@=F]I9&$@<&]I<W1A82!<(B5S7"(Z("5S(@H*(SH@=&5M<&QA=&5S
M+VUE;6\O;65M;RYI;F,Z-3@*;7-G:60@(E5N9&\@8VAA;F=E<R(*;7-G<W1R
M(")097)U(&UU=71O:W-E="(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC
M.C(W('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ-`HC.B!L
M:6(O36YE;6\N<&AP.C(P-B!L:6(O36YE;6\N<&AP.C(P-R!L:6(O36YE;6\N
M<&AP.C(R,2!L:6(O36YE;6\N<&AP.C(R,@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z.3@*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3'5O:VET=&5L96UA
M=&]N(@H*(SH@;&EB+V%P:2YP:'`Z,C,V(&QI8B]A<&DN<&AP.C,Q.2!L:6(O
M87!I+G!H<#HT,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@
M0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R(")%:2!T=65T='4@0V]N=&5N="U4
M>7!E.B`E<R(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C(*;7-G
M:60@(E=H:6-H($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T
M;S\B"FUS9W-T<B`B36EH:6X@;75I<W1I;&ES=&%A;B!M=6ES=&EI;G!A;F]T
M(&QI<^1TY.1N/R(*"B,Z(&1A=&$N<&AP.C0R(&1A=&$N<&AP.C$R-2!M96UO
M+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@;F]T97,N(@IM<V=S='(@(E-I
M;G5L;&$@96D@<V%A(&]L;&$@:W5I;B!E;FEN=.3D;B`E9"!M=6ES=&EI;G!A
M;F]A+B(*"B,Z('9I97<N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@
M)7,N(@IM<V=S='(@(E-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!S96QA=&$@
M;75I<W1I;&ES=&%A("5S+B(*"B,Z(&YO=&5P861S+G!H<#HV-0IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&$@;F]T97!A9"!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R(")3:6YU;B!P:73DY"!V86QI=&$@<&]I<W1E='1A=F$@;75I<W1I;&ES
M=&$N(@H*(SH@=&5M<&QA=&5S+W!R969S+VYO=&5P861S96QE8W0N:6YC.C$P
M"FUS9VED(")9;W5R(&1E9F%U;'0@;F]T97!A9#HB"FUS9W-T<B`B3VQE='5S
M;75I<W1I;&ES=&%S:3HB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A
M9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*;7-G<W1R(")-=6ES
M=&EL:7-T87-I.B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$X"FUS
M9VED(")?0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(E]486MA:7-I;B!M=6ES
M=&EL:7-T86%N(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3$@=&5M
M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT.`IM<V=I9"`B7T-A=&5G
M;W)Y(@IM<V=S='(@(E]+871E9V]R:6$B"@HC.B!T96UP;&%T97,O=FEE=R]M
M96UO+FEN8SHQ-0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")?4&]I<W1A(@H*
M(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3$*;7-G:60@(E]%9&ET(@IM
M<V=S='(@(E]-=6]K:V%A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C(P"FUS9VED(")?1FER<W0@3&EN92(*;7-G<W1R(")?16YS:6UMY&EN
M96X@<FEV:2(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C@S"FUS9VED(")?26UP;W)T
M+T5X<&]R="(*;7-G<W1R(")?5'5O+U9I92(*"B,Z(&QI8B]-;F5M;RYP:'`Z
M,C8V"FUS9VED(")?3&ES="!.;W1E<R(*;7-G<W1R(")?3&ES=&%A(&UU:7-T
M:6EN<&%N;W0B"@HC.B!L:6(O36YE;6\N<&AP.C(W.`IM<V=I9"`B7TUY($YO
M=&5P861S(@IM<V=S='(@(E]/;6%T(&UU:7-T:6QI<W1A;FDB"@HC.B!L:6(O
M36YE;6\N<&AP.C(W,0IM<V=I9"`B7TYE=R!.;W1E(@IM<V=S='(@(E]5=7-I
M(&UU:7-T:6EN<&%N;R(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C@X"FUS9VED(")?
M4')I;G0B"FUS9W-T<B`B7U1U;&]S=&$B"@HC.B!L:6(O36YE;6\N<&AP.C(W
M-`IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?2&%K=2(*"B,Z(&1A=&$N<&AP
M.CDQ('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B;F]T97,N
M8W-V(@IM<V=S='(@(FYO=&5S+F-S=B(*"B,Z(&1A=&$N<&AP.C,S('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,3@*;7-G:60@(G9.;W1E(@IM<V=S='(@
M(G9.;W1E(@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;6YE;6\O<&\O4D5!1$U%````````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`R,P`Q,#0Q-S,V,C<T
M-@`P,3<P,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````<V5E(&AO<F1E+W!O+U)%041-10``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VUN96UO+W!O+W)U7U)5+G!O````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-#4T,C(`,3`T,3<S-C(W-#8`,#$W-34W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",@4G5S
M<VEA;B!T<F%N<VQA=&EO;G,@9F]R($UN96UO('!A8VMA9V4*(R!#;W!Y<FEG
M:'0@*$,I"B,@06QE>&5Y(%IA:VAA<F]V(#QB86)E<D!M;W-G82YN970^+"`R
M,#`V(`HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!-;F5M;R!(,R`H,BXP+C(I7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#8M,#$M,34@,3@Z,34K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-BTP,2TQ-2`Q.#HT-BLP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($%L97AE
M>2!:86MH87)O=B`\8F%B97)`;6]S9V$N;F5T/EQN(@HB3&%N9W5A9V4M5&5A
M;3H@4G5S<VEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E
M<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/4-0,3(U,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!T96UP;&%T97,O;&ES="]H
M96%D97(N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;F]T97,B"FUS
M9W-T<B`B)60@Y^#LY?+NZB(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@=&5M
M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*;7-G:60@(B5S(&-H87)A8W1E<G,B
M"FUS9W-T<B`B)7,@X?/JXB(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G
M<W1R("+4X.GK("5S(//Q[^7X[>X@Z.SO[O#RZ/#NXN#M(@H*(R!F=7IZ>2P@
M<&AP+69O<FUA=`HC.B!N;W1E<&%D<RYP:'`Z.3D@;&EB+V)A<V4N<&AP.C$P
M,PIM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(LSN_R#J[>CFZN`@*"5S
M*2(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS
M9VED("(Q(&YO=&4B"FUS9W-T<B`B,2#GX.SE\NK@(@H*(R!F=7IZ>0HC.B!M
M96UO+G!H<#HQ-C(*;7-G:60@(D%C8V5S<R!D96YI960@9&5L971I;F<@;F]T
M92XB"FUS9W-T<B`BTR#BX/$@[>7D[O'RX/+N]^WN(._PX.(@]_+NX?L@\^3@
MZ^CR_"#]\O,@Y^#LY?+J\R(*"B,@9G5Z>GD*(SH@;65M;RYP:'`Z,3$R(&UE
M;6\N<&AP.C$Q-0IM<V=I9"`B06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO
M=&4N(@IM<V=S='(@(M,@XN#Q(.WEY.[Q\N#R[O?M[B#O\.#B(/?R[N'[(._E
M\.7LY?'RZ/+\(/WR\R#GX.SE\NKS(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC
M.B!M96UO+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N
M:65D('-A=FEN9R!N;W1E('1O("5S+B(*;7-G<W1R("+3(.+@\2#MY?(@[_#@
MXB#OZ/'@\OP@Y^#LY?+JZ"#B("5S(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC
M.B!M96UO+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N
M:65D('-A=FEN9R!N;W1E.B`E<R(*;7-G<W1R("+-Y>3N\?+@\N[W[>X@[_#@
MXB#DZ_\@\>[U\.#MY>WH_R#GX.SE\NKH.B`E<R(*"B,@9G5Z>GD*(SH@=&5M
M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#,*;7-G:60@
M(D%D9"!C871E9V]R>2(*;7-G<W1R("+-[N+@_R#JX/+EX^[PZ/\B"@HC.B!M
M96UO+G!H<#HU,@IM<V=I9"`B061D:6YG($$@3F5W($YO=&4B"FUS9W-T<B`B
MQ.[AX.+KY>WHY2#M[N+NZ2#GX.SE\NKH(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4Q"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`BS^X@XN[G\.#Q
M\N#MZ/XB"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N
M:6YC.CDY"B,L(&9U>GIY"FUS9VED(")!=F%I;&%B;&4@0V%T96=O<FEE<SHB
M"FUS9W-T<B`BQ.[Q\O/O[?OE(._NZ_\Z(@H*(R!P:'`M9F]R;6%T"B,@9G5Z
M>GD*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3@*;7-G:60@(D)A8VL@
M=&\@3F]T97!A9"(*;7-G<W1R("+"Y?#M\_+\\?\@XB#'X._H\>WS_B#J[>CF
MZO,B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDW"FUS
M9VED(")"86-K('1O($YO=&5P860@3W!T:6]N<R(*;7-G<W1R("+"Y?#M\_+Q
M_R#J(.[O]NC_["(*"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3<*;7-G:60@(D-35B(*;7-G<W1R(")#4U8M].#IZR(*"B,@
M9G5Z>GD*(SH@9&%T82YP:'`Z-30@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,C8*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(LK@\N7C[O#H_R(*"B,Z('1E
M;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,C(*;7-G:60@(D-H86YG
M92(*;7-G<W1R("+(Y^SE[>CR_"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-0IM<V=I9"`B0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P
M;&%Y(&]P=&EO;G,N(@IM<V=S='(@(LCG[.7MZ/+\(.[O]NCH(.[R[N'PX.;E
M[>C_(.@@[^[H\>K@(.(@Y^#OZ/'M[ND@ZNWHYNKE(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I
M9"`B0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T:&4@
M<W5M;6%R>2!V:65W+B(*;7-G<W1R("+"^^'E\.CRY2#O[O#_Y.[J(.[R[N'P
MX.;E[>C_(/'R[NOA]N[B(.(@\>_H\>KE(.#D\.7Q[N(N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(R"FUS9VED(")#:&]O<V4@>6]U<B!D969A=6QT
M($YO=&5P860N(@IM<V=S='(@(L+[X?#@\OP@XN#X\R#GX._H\>WS_B#J[>CF
MZO,@[^X@\^SNZ_?@[>C^(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z,S(*;7-G:60@(D-L96%R($9O<FTB"FUS9W-T<B`BSO?H
M\?+H\OP@].[P[/,B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.C$W('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(M'NY^3@\OPB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO
M+FEN8SHS,@IM<V=I9"`B0W)E871E9"(*;7-G<W1R("+1[N?DX.W@(@H*(R!F
M=7IZ>0HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0IM<V=I
M9"`B1&5F875L="!.;W1E<&%D(@IM<V=S='(@(LKMZ.;JX"#O[B#S[.[K]^#M
MZ/XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(*;7-G:60@(D1E9F%U
M;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`BT>[P\NCP[N+JX"#O[B#S
M[.[K]^#MZ/XZ(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@
M(L_N\/_D[NH@\>[P\NCP[N+JZ"(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N
M;W1E<&%D<RYI;F,Z.34@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*;7-G
M:60@(D1E;&5T92(*;7-G<W1R("+3Y.#KZ/+\(@H*(R!F=7IZ>0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C@*;7-G:60@(D1E;&5T92!#;VYF:7)M871I
M;VXB"FUS9W-T<B`BT^3@Z^7MZ.4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,CD*;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@
M(L_NY/+BY?#FY.7MZ.4@[N_E\.#VZ.@@\^3@Z^7MZ/\B"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C8W"FUS9VED(")$96QE=&4@=&AI
M<R!N;W1E(@IM<V=S='(@(M/DX.OH\OP@Y^#LY?+J\R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,@IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("+/
M[B#SX?OBX.WH_B(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.C@U"FUS9VED(")$97-C<FEP=&EO;CHB"FUS
M9W-T<B`BSN_H\>#MZ.4B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(L[R[N'P
MX.;E[>CE(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*
M;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE
M<S\B"FUS9W-T<B`BQ^#O\.#XZ.+@\OP@[^[D\N+E\.;DY>WHY2#O\.@@\^3@
MZ^7MZ.@@Y^#OZ/'EZ3\B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ
M,0IM<V=I9"`B161I="(*;7-G<W1R("+0Y>3@ZO+H\.[BX.WHY2(*"B,Z('1E
M;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHU"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R("+0Y>3@ZO+H
M\.[BX.WHY2`G)7,G(@H*(R!F=7IZ>0HC(&9U>GIY"B,Z('1E;7!L871E<R]L
M:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#(@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C@R"FUS9VED(")%9&ET($YO=&4B"FUS9W-T<B`BT.7DX.KRZ/#NXN#R_"(*
M"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3(*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@
M(LK@\N7C[O#HZ"#H(.SE\NKH(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;&ES
M="]M96UO7W-U;6UA<FEE<RYI;F,Z,3(*;7-G:60@(D5M<'1Y($YO=&4B"FUS
M9W-T<B`BS_/Q\N#_(.?@[.7RZN`B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$Y"FUS9VED(")%>'!O<G0B"FUS9W-T<B`BW>KQ[^[P\B(*"B,@
M9G5Z>GD*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%
M>'!O<G0@3F]T97,B"FUS9W-T<B`BW>KQ[^[P\B#GX.SE\N[J(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C$*;7-G:60@(D9?
M=6QL(%1E>'0B"FUS9W-T<B`BPN7Q_"#RY>KQ\B(*"B,@9G5Z>GD*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<*;7-G:60@(D=E;F5R86P@3W!T
M:6]N<R(*;7-G<W1R("+.X?GHY2#MX/'R\.[IZN@B"@HC(&9U>GIY+"!P:'`M
M9F]R;6%T"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0@3F]T97,L(%-T97`@)60B"FUS9W-T<B`B
MR.SO[O#R(.?@[.7R[NHL(-C@XR`E9"(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!D
M871A+G!H<#HQ.3,*;7-G:60@(DEM<&]R="]%>'!O<G0@3F]T97,B"FUS9W-T
M<B`BR.SO[O#R+]WJ\>_N\/(B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHS.0IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("+(\>_PX.+KY>W@
M(@H*(SH@;&EB+V%P:2YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@
M3G5M8F5R(&]F($YO=&5S(@IM<V=S='(@(LS@ZO'H[.#K_.WNY2#J[NOH]^7Q
M\N+N(/'R\.#MZ/8B"@HC.B!D871A+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B
M365M;R!497AT(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@
M(RTC+2,M(RTC7&XB"B+$X.OEY5QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+$X.OEY5QN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+$
MX.OEY5QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@
M(RTC+2,M(RTC7&XB"B+$X.OEY2(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F
M=7IZ>2P@<&AP+69O<FUA=`HC.B!M96UO+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-;V1I9GEI;F<@)7,B"FUS9W-T<B`BT.7DX.KRZ/#NXN#MZ.4@
M)7,B"@HC(&9U>GIY"B,Z(&QI<W0N<&AP.C,U"FUS9VED(")->2!.;W1E<R(*
M;7-G<W1R("+,[N@@Y^#LY?+JZ"(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*;7-G<W1R("+-[N+@_R#G
MX.SE\NK@(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I
M9"`B3F5X="(*;7-G<W1R("+$X.OEY2(*"B,Z(&QI8B]A<&DN<&AP.C(P-@HC
M+"!F=7IZ>0IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*
M;7-G<W1R("+/\.CJ\.7OZ^7M[?OE(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC
M.C<*;7-G:60@(DYO(&YO=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S
M+B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]L:7-T+VAE861E
M<BYI;F,Z,PIM<V=I9"`B3F\@;F]T97,B"FUS9W-T<B`BS>7R(,?@[.7R[NHB
M"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z,PIM<V=I9"`B3F\@;F]T
M97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(L_NY/7N
MY/_YZ/4@Y^#LY?+NZB#MY2#MX.GDY>WN(@H*(R!F=7IZ>0HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(").;R!N;W1E<R!T
M;R!D:7-P;&%Y(@IM<V=S='(@(L[R[N'PX.?H\OP@ZNWHYNKH.B(*"B,@9G5Z
M>GD*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-`IM<V=I
M9"`B3F]?=&4B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,@9G5Z>GD*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Q"FUS9VED(").;W1E($-A=&5G;W)Y(@IM<V=S
M='(@(LK@\N7C[O#H_R(*"B,@9G5Z>GD*(SH@=FEE=RYP:'`Z.#`@=&5M<&QA
M=&5S+W9I97<O;65M;RYI;F,Z,C$*;7-G:60@(DYO=&4@1&5T86EL<R(*;7-G
M<W1R("+'X.SE\NK@(@H*(R!F=7IZ>0HC.B!N;W1E<&%D<RYP:'`Z,3$P"B,L
M(&9U>GIY"FUS9VED(").;W1E($QI<W1S(@IM<V=S='(@(LWNXN#_(./P\^_O
MX"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-#4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0P"FUS9VED(").;W1E(%1E>'0B"FUS9W-T
M<B`BTN7J\?(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC
M.C(V"FUS9VED(").;W1E(%]497AT(@IM<V=S='(@(M+EZO'R(@H*(SH@=FEE
M=RYP:'`Z-3<@;65M;RYP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(DYO=&4@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M
M(RTC+2,M(UQN(@HBP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M
M(RTC+2-<;B(*(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+EQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M
M(RTC7&XB"B+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2Y<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M
M(UQN(@HBP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(R!F
M=7IZ>0HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHS-`IM<V=I9"`B3F]T
M95]P860B"FUS9W-T<B`BRNWHYNK@(@H*(R!F=7IZ>0HC(&9U>GIY"B,Z('1E
M;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-SD*;7-G:60@(DYO=&5P
M860G<R!N86UE.B(*;7-G<W1R("+-X.?BX.WHY2#GX._H\>WNZ2#J[>CFZN@Z
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC
M.C8Q"FUS9VED(").;W1E<&%D<R(*;7-G<W1R("+'X._H\>W[Y2#J[>CFZN@B
M"@HC.B!N;W1E<&%D<RYP:'`Z,S,*;7-G:60@(DYO=&5P861S(&UU<W0@:&%V
M92!A(&YA;64N(@IM<V=S='(@(L+[(.WE(.?@Y.#KZ"#MX.?BX.WHY2#GX._H
M\>WNZ2#J[>CFZN@B"@HC(&9U>GIY"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C,*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`BT>[Q
M\N[_[>CE(@H*(R!F=7IZ>0HC.B!L:6(O87!I+G!H<#HQ.#,@;&EB+V%P:2YP
M:'`Z,C<Y(&QI8B]A<&DN<&AP.C,U-2!L:6(O87!I+G!H<#HS.#0*(RP@9G5Z
M>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(LCG[.7MZ/+\
M(._PX.+@(.3N\?+S[^`B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]N;W1E<&%D
M<R]N;W1E<&%D<RYI;F,Z.#(*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@
M(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^`B"@HC(&9U>GIY"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(E)E
M86QL>2!D96QE=&4@=&AI<R!N;W1E/R(*;7-G<W1R("+3Y.#KZ/+\(.?R\R#G
MX.3@]_,B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z
M-2!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C8*;7-G:60@(E)E9G)E<V@@
M3&ES="(*;7-G<W1R("+.X>WNXNCR_"(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`U"B,L(&9U>GIY"FUS9VED(")296UO
M=F4@8V%T96=O<GDB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@=&5M<&QA
M=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS
M9W-T<B`BT>'P[O'H\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M96UO+VUE
M;6\N:6YC.C4V"FUS9VED(")3879E(@IM<V=S='(@(L?@[^CQX/+\(@H*(SH@
M<V5A<F-H+G!H<#HQ-R!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-"!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S$*;7-G:60@(E-E87)C:"(*
M;7-G<W1R("+/[NCQZB(*"B,Z(&QI<W0N<&AP.C4W"FUS9VED(")396%R8V@@
M4F5S=6QT<R(*;7-G<W1R("+0Y>?SZ_SRX/+[(._NZ/'JX"(*"B,@9G5Z>GDL
M('!H<"UF;W)M870*(R!F=7IZ>0HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z,3<*;7-G:60@(E-E87)C:"!38V]P92(*;7-G<W1R("+.X>O@\?+\
M(._NZ/'JX"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.CD*;7-G:60@(E-E87)C:"!?5&5X="(*;7-G<W1R("+7\NX@Z/GE["(*
M"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHV
M-PIM<V=I9"`B4V5L96-T(&$@;F]T97!A9"(*;7-G<W1R("+"^^'E\.CRY2#G
MX._H\>WS_B#J[>CFZO,B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M96YU+FEN
M8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&YO=&5P861S('1O(&1I<W!L
M87DZ(@IM<V=S='(@(L[R[N'PX.?H\OP@ZNWHYNKH.B(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H
M92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@Y.O_
M(/WJ\>_N\/+@.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S<*
M;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(LCL
M[^[P\NCP\^7L^^D@].#IZSHB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,34*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H
M92!S;W5R8V4@9FEL93HB"FUS9W-T<B`BPOOAY?#H\N4@].[P[.#R(.CL[^[P
M\NCP\^7L[N/N(/3@Z>O@.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M
M;6%R>7-E;&5C="YI;F,Z,3`Y"B,L(&9U>GIY"FUS9VED(")396QE8W1E9"!#
M871E9V]R:65S.B(*;7-G<W1R("+"^^'PX.WM^^4@\?+NZ^'V^SHB"@HC(&9U
M>GIY"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS-PIM<V=I9"`B4VAO=R!A
M8W1I;VX@8G5T=&]N<S\B"FUS9W-T<B`BRNWN[^KH(@H*(R!F=7IZ>0HC(&9U
M>GIY"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT,`IM<V=I9"`B4VAO=R!N
M;W1E<&%D(&YA;64_(@IM<V=S='(@(LW@Y^+@[>CE(.?@[^CQ[>[I(.KMZ.;J
MZ"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT,PIM<V=I9"`B4VAO=R!N
M;W1E<R!F<F]M('1H97-E(&-A=&5G;W)I97,B"FUS9W-T<B`BS^[JX.?@\OP@
M[^X@ZN#RY>/N\.CH.B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R
M<RYI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@0V%T96=O<GDB"FUS
M9W-T<B`BT>[P\NCP[N+@\OP@[^X@\N7LY2(*"B,Z('1E;7!L871E<R]L:7-T
M+VUE;6]?:&5A9&5R<RYI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@
M3F]T92!497AT(@IM<V=S='(@(M'N\/+H\.[BX/+\(._N(/+E[.4B"@HC(&9U
M>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@;65M;RYP
M:'`Z,3,U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!<(B5S7"(N(@IM<V=S='(@(L?@[.7RZN`@)R5S)R#S\>_E^.WN(/'N]?#@
M[>7MX"(*"B,@9G5Z>GD*(SH@;65M;RYP:'`Z,34Y"FUS9VED(")4:&4@;F]T
M92!W87,@9&5L971E9"XB"FUS9W-T<B`BQ^#LY?+JX"#A^^O@(//DX.OE[>`N
M(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!N;W1E<&%D<RYP:'`Z-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&-O=6QD;B=T
M(&)E(&-R96%T960Z("5S(@IM<V=S='(@(L?@[^CQ[>#_(.KMZ.;JX"`G)7,G
M(.WE(.SNYN7R(.'[\OP@\>[GY.#MX#H@)7,B"@HC(&9U>GIY+"!P:'`M9F]R
M;6%T"B,Z(&YO=&5P861S+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B
MQ^#OZ/'MX/\@ZNWHYNK@("<E<R<@X?OKX"#S\>_E^.WN(/'NY^3@[>`B"@HC
M(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&YO=&5P861S+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`BQ^#OZ/'MX/\@ZNWHYNK@("<E<R<@X?OKX"#SY.#K
MY>W@+B(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@;F]T97!A9',N<&AP.C4V
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`BQ^#OZ/'MX/\@ZNWHYNK@("<E<R<@X?OK
MX"#Q[O7PX.WE[>`N(@H*(SH@9&%T82YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!D871A.B`E<R(*;7-G<W1R("+.^.CAZN`@[_#H(.CL[^[P\N4@Y.#M[?OU
M+B(*"B,Z(&QI8B]A<&DN<&AP.C(P,`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I
M("`C+2,M(RTC+2-<;B(*(L[XZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM^_4N(@H*
M(SH@;&EB+V%P:2YP:'`Z-#`S"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!V3F]T92!D871A+B(*;7-G<W1R("(B
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB
MSOCHX>K@(._PZ"#H[._N\/+E(.3@[>W[]2Y<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSOCH
MX>K@(._PZ"#H[._N\/+E(.3@[>W[]2Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSOCHX>K@
M(._PZ"#H[._N\/+E(.3@[>W[]2Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSOCHX>K@(._P
MZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!M96UO+G!H<#HQ-3<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN
M9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M
M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ
M_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M
M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WN
MX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N
M,BD@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P
M[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P
M[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@
M[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HBS_#N
MX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M(UQN
M(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@
M+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC
M+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@
M[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@
M(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE
M[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T
M+C`N,BD@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#G
MX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H
M(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M
M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ
M_.S@+B(*"B,Z(&UE;6\N<&AP.C$S,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&4@;F]T93H@)7,B
M"FUS9W-T<B`BSOCHX>K@(.[R[_#@XNKH(._H\?SLX#H@)7,B"@HC.B!V:65W
M+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<R(*;7-G<W1R("+.
M^.CAZN`@[_#H(.CL[^[P\N4@Y.#M[?OU+B(*"B,Z(&1A=&$N<&AP.C<Y"B,L
M(&9U>GIY"FUS9VED(")4:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="XB
M"FUS9W-T<B`BS>7R(.#D\.7Q[?OU(.KMZ.,L(.3N\?+S[^W[]2#DZ_\@Y^#O
MZ/'H+B(*"B,Z(&1A=&$N<&AP.C$P-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F
M:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N,BD@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N
M,"XR*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7MZ.5<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WHY5QN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B
M[N4@\>[NX?GE[>CE(@H*(SH@;F]T97!A9',N<&AP.C@P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC+2-<
M;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC
M+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M
M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P
M[NPN7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C
M+2,M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7P
MXN7P[NPN(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU
M.`IM<V=I9"`B56YD;R!C:&%N9V5S(@IM<V=S='(@(L[R[.7MZ/+\(.CG[.7M
MY>WH_R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C<@
M=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C$T"B,Z(&QI8B]-
M;F5M;RYP:'`Z,C`V(&QI8B]-;F5M;RYP:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z
M,C(Q(&QI8B]-;F5M;RYP:'`Z,C(R"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ,#,*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BSO+Q\_+Q\N+SY?(B"@HC
M.B!L:6(O87!I+G!H<#HR,S8@;&EB+V%P:2YP:'`Z,S$Y(&QI8B]A<&DN<&AP
M.C0Q,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@
M0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R("+-Y>KN\/#EZO+M[N4@Z.S_+B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C(*;7-G:60@(E=H:6-H
M($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\B"FUS9W-T
M<B`B(@H*(SH@9&%T82YP:'`Z-#(@9&%T82YP:'`Z,3(U(&UE;6\N<&AP.C,U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@;F]T97,N(@IM<V=S='(@(L+[
M(/'NY^3@Y?+E(._@[^KS(.+E\/7MY>/N(//P[N+M_RXB"@HC.B!V:65W+G!H
M<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R
M;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S+B(*;7-G<W1R("(B"@HC
M.B!N;W1E<&%D<RYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BPOL@Y.[K
MYNW[(.+[X?#@\OP@[_#N].CK_"#DZ_\@\^3@Z^7MZ/\N(@H*(R!F=7IZ>0HC
M.B!T96UP;&%T97,O<')E9G,O;F]T97!A9'-E;&5C="YI;F,Z,3`*;7-G:60@
M(EEO=7(@9&5F875L="!N;W1E<&%D.B(*;7-G<W1R("+"X/C@(.?@[^CQ[>#_
M(.KMZ.;JX"#O[B#S[.[K]^#MZ/XZ(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S
M.B(*;7-G<W1R("+"X/C@(.?@[^CQ[>#_(.KMZ.;JX#HB"@HC('!H<"UF;W)M
M870*(R!F=7IZ>0HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ.`IM<V=I
M9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R("+"Y?#M\_+\\?\@XB#GX._H
M\>WS_B#J[>CFZO,B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M96UO+VUE;6\N
M:6YC.C4Q('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#@*;7-G
M:60@(E]#871E9V]R>2(*;7-G<W1R("+*X/+EX^[PZ/\B"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS9VED(")?1&5L971E(@IM
M<V=S='(@(M/DX.OH\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]V:65W+VUE
M;6\N:6YC.C$Q"FUS9VED(")?161I="(*;7-G<W1R("+0Y>3@ZO+H\.[BX/+\
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C`*
M;7-G:60@(E]&:7)S="!,:6YE(@IM<V=S='(@(L_E\.+@_R#Q\O#NZN`B"@HC
M(&9U>GIY"B,Z(&QI8B]-;F5M;RYP:'`Z,C@Q"FUS9VED(")?26UP;W)T+T5X
M<&]R="(*;7-G<W1R("+([._N\/(OW>KQ[^[P\B(*"B,@9G5Z>GD*(SH@;&EB
M+TUN96UO+G!H<#HR-C0*;7-G:60@(E],:7-T($YO=&5S(@IM<V=S='(@(L+[
MX?#@\OPB"@HC(&9U>GIY"B,Z(&QI8B]-;F5M;RYP:'`Z,C<V"FUS9VED(")?
M37D@3F]T97!A9',B"FUS9W-T<B`BRNWHYNKH(@H*(R!F=7IZ>0HC.B!L:6(O
M36YE;6\N<&AP.C(V.0IM<V=I9"`B7TYE=R!.;W1E(@IM<V=S='(@(L3NX>#B
MZ/+\(@H*(R!F=7IZ>0HC.B!L:6(O36YE;6\N<&AP.C(X-@IM<V=I9"`B7U!R
M:6YT(@IM<V=S='(@(L_E]^#R_"(*"B,@9G5Z>GD*(SH@;&EB+TUN96UO+G!H
M<#HR-S(*;7-G:60@(E]396%R8V@B"FUS9W-T<B`BS^[H\>HB"@HC.B!D871A
M+G!H<#HY,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(FYO
M=&5S+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,R!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")V3F]T92(*;7-G
M<W1R("+'X.SE\NKH(@H*(R!F=7IZ>0IM<V=I9"`B3W1H97(@3W!T:6]N<R(*
M;7-G<W1R("+$\//CZ.4@[>#Q\O#NZ>KH(@H*(R!F=7IZ>0IM<V=I9"`B4VAO
M=R(*;7-G<W1R("+/[NK@Y^#R_#HB"@HC(&9U>GIY"B,@9G5Z>GD*;7-G:60@
M(E-H;W<@3F]T97!A9',Z(@IM<V=S='(@(L?@[^CQ[?OE(.KMZ.;JZ#HB"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W!O
M+W)O7U)/+G!O````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,C8U,C4`,3`T,3<S-C(W-#8`,#$W-30V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@36YE;6\@4F]M86YI86X@
M5')A;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#,@2&]R9&4@4')O:F5C
M=`HC($5U9V5N($AO86YC82`\975G96YH0'5R8F%N+6=R869X+G)O/BP@,C`P
M,RX*(R!-87)I=7,@1')A9W5L97-C=2`\;6%R:75S9$!U<F)A;BUG<F%F>"YR
M;SXL(#(P,#,N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($UN96UO(#$N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M
M,#(M,C@@,#(Z,CDK,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!%=6=E;B!(
M;V%N8V$@/&5U9V5N:$!U<F)A;BUG<F%F>"YR;SY<;B(*(DQA;F=U86=E+51E
M86TZ(%)O;6%N:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M
M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=%QN(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&YO=&5S(@IM<V=S='(@(B5D(&YO=&4B
M"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C$X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL
M>2!I;7!O<G1E9"(*;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z.3D@;&EB
M+V)A<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P
M860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS
M"FUS9VED("(Q(&YO=&4B"FUS9W-T<B`B,2!N;W1A(@H*(SH@;65M;RYP:'`Z
M,38R"B,L(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO
M=&4N(@IM<V=S='(@(D$@87!A<G5T(&\@<')O8FQE;6$@;&$@<W1E<F=E<F5A
M(&YO=&5L;W(N(@H*(SH@;65M;RYP:'`Z,3$R(&UE;6\N<&AP.C$Q-0IM<V=I
M9"`B06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N(@IM<V=S='(@(B(*
M"B,Z(&UE;6\N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D
M96YI960@<V%V:6YG(&YO=&4@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&UE;6\N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@<V%V
M:6YG(&YO=&4Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`S"B,L(&9U>GIY"FUS9VED(")!9&0@
M8V%T96=O<GDB"FUS9W-T<B`B0V%T96=O<FEE(@H*(SH@;65M;RYP:'`Z-3(*
M;7-G:60@(D%D9&EN9R!!($YE=R!.;W1E(@IM<V=S='(@(D%D875G87)E(&1E
M(&YO=&$@;F]U82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-`IM<V=I
M9"`B07-C96YD:6YG(@IM<V=S='(@(D-R97-C871O<B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3D*;7-G:60@(D%V86EL
M86)L92!#871E9V]R:65S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM<V=I
M9"`B0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(DEN87!O:2!I;B!.;W1E<&%D
M(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-PHC+"!F
M=7IZ>0IM<V=I9"`B0F%C:R!T;R!.;W1E<&%D($]P=&EO;G,B"FUS9W-T<B`B
M26YA<&]I(&EN($YO=&5P860B"@HC.B!D871A+G!H<#HS,B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z-30@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*;7-G:60@
M(D-A=&5G;W)Y(@IM<V=S='(@(D-A=&5G;W)I92(*"B,Z('1E;7!L871E<R]N
M;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D-H86YG
M92(*;7-G<W1R(")2969A('-C:&EM8F%R:6QE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U"FUS9VED(")#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@
M86YD(&1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B4V-H:6UB87)E('-O<G1A
M=&4@9&4@;F]T92!S:&D@;W!T:75N:2!A9FES86HB"@HC.B!T96UP;&%T97,O
M<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.CDS"B,L(&9U>GIY"FUS9VED
M(")#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T;R!L:7-T(&EN('1H92!S
M=6UM87)Y('9I97<N(@IM<V=S='(@(E!U;F5R92!I;B!V86QO87)E(&$@<W5M
M87)U;'5I/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@IM<V=I9"`B
M0VAO;W-E('EO=7(@9&5F875L="!.;W1E<&%D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S(*;7-G:60@(D-L96%R($9O
M<FTB"FUS9W-T<B`B4W1E<F=E($9O<FUU;&%R(@H*(SH@=&5M<&QA=&5S+VYO
M=&5P861S+VYO=&5P861S+FEN8SHQ-R!T96UP;&%T97,O;F]T97!A9',O;F]T
M97!A9',N:6YC.CDT"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI
M;F,Z.38*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHS-0IM<V=I9"`B0W)E871E9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*(RP@9G5Z>GD*;7-G:60@(D1E
M9F%U;'0@3F]T97!A9"(*;7-G<W1R(")3=&5R9V4@;F]T82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-0IM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R
M:71E<FEA.B(*;7-G<W1R(")#<FET97)I=2!D92!S;W)T87)E(&EM<&QI8VET
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B1&ER96-T:64@9&4@<V]R
M=&%R92!I;7!L:6-I=&$Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P
M861S+FEN8SHY-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-0HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHV-`IM<V=I9"`B1&5L971E(@IM<V=S='(@
M(E-T97)G92(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C8W"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@=&AI<R!N;W1E(@IM<V=S='(@(D\@;F]T82!S
M=&5A<G-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U"FUS9VED(")$
M97-C96YD:6YG(@IM<V=S='(@(D1E<V-R97-C871O<B(*"B,Z('1E;7!L871E
M<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*(RP@9G5Z>GD*;7-G:60@(D1E
M<V-R:7!T:6]N.B(*;7-G<W1R(")$97-C<FEE<F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M(")/<'1I=6YI(&%F:7-A<F4B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHR,2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV,`IM<V=I9"`B161I="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0T(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HX,PHC+"!F=7IZ>0IM<V=I9"`B161I="!.
M;W1E(@IM<V=S='(@(DQI<W1E87IA(&YO=&4B"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C4T"FUS9VED(")%9&ET(&-A=&5G;W)I97,@
M86YD(&-O;&]R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO
M7W-U;6UA<FEE<RYI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y($YO=&4B
M"FUS9W-T<B`B3&ES=&5A>F$@;F]T92(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,3D*;7-G:60@(D5X<&]R="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(D5X<&]R
M="!.;W1E<R(*;7-G<W1R(").;W1E(&-U<F5N=&4B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D9?=6QL(%1E
M>'0B"FUS9W-T<B`B3G5M86D@=&5X="(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@3F]T97,L
M(%-T97`@)60B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3DS"FUS9VED("))
M;7!O<G0O17AP;W)T($YO=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V
M:65W+VUE;6\N:6YC.C0S"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C<R"FUS9VED(")-87AI;75M($YU;6)E<B!O
M9B!.;W1E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,PHC+"!F=7IZ>0IM
M<V=I9"`B365M;R!497AT(@IM<V=S='(@(E1E>'0@;F]T82(*"B,Z(&UE;6\N
M<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(DUO9&EF>6EN9R`E<R(*;7-G
M<W1R(")-;V1I9FEC87)E("5S(@H*(SH@;&ES="YP:'`Z,S4*(RP@9G5Z>GD*
M;7-G:60@(DUY($YO=&5S(@IM<V=S='(@(DUO9&EF:6-A(&YO=&$B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*;7-G:60@(DYE=R!.;W1E(@IM<V=S
M='(@(DYO=&$@;F]U82(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M-#`*(RP@9G5Z>GD*;7-G:60@(DYE>'0B"FUS9W-T<B`B5&5X="!N;W1A(@H*
M(SH@;&EB+V%P:2YP:'`Z,C`V"FUS9VED(").;R!I0V%L96YD87(@9&%T82!W
M87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHW
M"FUS9VED(").;R!N;W1E<&%D<R!A<F4@879A:6QA8FQE('1O(&=U97-T<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS
M9VED(").;R!N;W1E<R(*;7-G<W1R(").:6-I(&\@;F]T82(*"B,Z('1E;7!L
M871E<R]L:7-T+V5M<'1Y+FEN8SHS"FUS9VED(").;R!N;W1E<R!M871C:"!T
M:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C$P.0IM<V=I9"`B3F\@;F]T97,@=&\@9&ES<&QA>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC
M.C0V"B,L(&9U>GIY"FUS9VED(").;U]T92(*;7-G<W1R(").;W1A(&YO=6$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0*;7-G:60@(DYO=&4@0V%T
M96=O<GDB"FUS9W-T<B`B0V%T96=O<FEE(&1E(&YO=&4B"@HC.B!V:65W+G!H
M<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHY"FUS9VED(").;W1E($1E
M=&%I;',B"FUS9W-T<B`B1&5T86QI:2!N;W1A(@H*(SH@;F]T97!A9',N<&AP
M.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B3F]T92!,:7-T<R(*;7-G<W1R(")$971A
M;&EI(&YO=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,*;7-G:60@
M(DYO=&4@5&5X="(*;7-G<W1R(")497AT(&YO=&$B"@HC.B!T96UP;&%T97,O
M;65M;R]M96UO+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B3F]T92!?5&5X="(*
M;7-G<W1R(")497AT(&YO=&$B"@HC.B!V:65W+G!H<#HU-R!M96UO+G!H<#HV
M,`IM<V=I9"`B3F]T92!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M96UO+VUE;6\N:6YC.C,T"B,L(&9U>GIY"FUS9VED(").;W1E7W!A
M9"(*;7-G<W1R("));F%P;VD@:6X@3F]T97!A9"(*"B,Z('1E;7!L871E<R]N
M;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-SD*;7-G:60@(DYO=&5P860G<R!N86UE
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.C8Q"B,L(&9U>GIY"FUS9VED(").;W1E<&%D<R(*;7-G<W1R(").:6-I
M(&\@;F]T82(*"B,Z(&YO=&5P861S+G!H<#HS,PIM<V=I9"`B3F]T97!A9',@
M;75S="!H879E(&$@;F%M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS
M9W-T<B`B0V%T96=O<FEE(&1E(&YO=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P"FUS9VED(")/=&AE
M<B!/<'1I;VYS(@IM<V=S='(@(D%L=&4@;W!T:75N:2(*"B,Z(&QI8B]A<&DN
M<&AP.C$X,R!L:6(O87!I+G!H<#HR-S0@;&EB+V%P:2YP:'`Z,S0U(&QI8B]A
M<&DN<&AP.C,W-`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHX,@IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M:&5A9&5R+FEN8SHU('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z-@IM<V=I
M9"`B4F5F<F5S:"!,:7-T(@IM<V=S='(@(DEM<')O<W!A=&5A>F$@;&ES=&$B
M"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P
M-0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-A=&5G;W)Y(@IM<V=S='(@(D-A
M=&5G;W)I92!D92!N;W1E(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P
M861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUE;6\O;65M;RYI;F,Z-38*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS
M9W-T<B`B4V%L=F5A>F$@;F]T82(*"B,Z('-E87)C:"YP:'`Z,3<@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C0@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC.C,Q"FUS9VED(")396%R8V@B"FUS9W-T<B`B0V%U=&%R92(*"B,Z
M(&QI<W0N<&AP.C4W"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R(")2
M97IU;'1A=&4@8V%U=&%R92(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHQ-PIM<V=I9"`B4V5A<F-H(%-C;W!E(@IM<V=S='(@(E-C;W`@8V%U
M=&%R92(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHY"B,L(&9U
M>GIY"FUS9VED(")396%R8V@@7U1E>'0B"FUS9W-T<B`B5&5X="!C875T87)E
M(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHV-PHC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&$@;F]T97!A9"(*;7-G<W1R(")396QE8W1E
M87IA(&-A=&5G;W)I92(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ-@IM<V=I
M9"`B4V5L96-T(&YO=&5P861S('1O(&1I<W!L87DZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(E-E;&5C="!T
M:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHS-PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM
M<&]R=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F
M:6QE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA
M<GES96QE8W0N:6YC.C$P.0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T960@0V%T
M96=O<FEE<SHB"FUS9W-T<B`B4V5L96-T96%Z82!C871E9V]R:64B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,S@*;7-G:60@(E-H;W<@86-T:6]N(&)U
M='1O;G,_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT
M,0IM<V=I9"`B4VAO=R!N;W1E<&%D(&YA;64_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HT-`IM<V=I9"`B4VAO=R!N;W1E<R!F<F]M
M('1H97-E(&-A=&5G;W)I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI
M<W0O;65M;U]H96%D97)S+FEN8SHU,`IM<V=I9"`B4V]R="!B>2!#871E9V]R
M>2(*;7-G<W1R(")3;W)T87)E(&1U<&$@8V%T96=O<FEE(@H*(SH@=&5M<&QA
M=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B
M4V]R="!B>2!.;W1E(%1E>'0B"FUS9W-T<B`B5&5X="!N;W1A(@H*(SH@;65M
M;RYP:'`Z,3,U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP.C$U.0HC+"!F
M=7IZ>0IM<V=I9"`B5&AE(&YO=&4@=V%S(&1E;&5T960N(@IM<V=S='(@(DYI
M8VD@;R!N;W1A(&XM82!F;W-T('-T96%R<V$B"@HC.B!N;W1E<&%D<RYP:'`Z
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&-O
M=6QD;B=T(&)E(&-R96%T960Z("5S(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S
M+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S
M7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B(@H*(SH@;F]T97!A9',N
M<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A
M9"!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B3FEC:2!O(&YO
M=&$@;BUA(&9O<W0@<W1E87)S82(*"B,Z(&YO=&5P861S+G!H<#HU-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`B02!A<&%R=70@;R!P<F]B;&5M82!L
M82!S=&5R9V5R96$@;F]T96QO<BXB"@HC.B!L:6(O87!I+G!H<#HR,#`*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HS.3,*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.
M;W1E(&1A=&$N(@IM<V=S='(@(D$@87!A<G5T(&\@<')O8FQE;6$@;&$@<W1E
M<F=E<F5A(&YO=&5L;W(N(@H*(SH@;65M;RYP:'`Z,34W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@
M=&AE(&YO=&4Z("5S(@IM<V=S='(@(D$@87!A<G5T(&\@<')O8FQE;6$@;&$@
M<W1E<F=E<F5A(&YO=&5L;W(N(@H*(SH@;65M;RYP:'`Z,3,S"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG
M('1H92!N;W1E.B`E<R(*;7-G<W1R(")!(&%P87)U="!O('!R;V)L96UA(&QA
M('-T97)G97)E82!N;W1E;&]R+B(*"B,Z('9I97<N<&AP.C0V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=FEE=VEN
M9R!T:&ES(&YO=&5P860Z("5S(@IM<V=S='(@(D$@87!A<G5T(&\@<')O8FQE
M;6$@;&$@<W1E<F=E<F5A(&YO=&5L;W(N(@H*(SH@9&%T82YP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E('=E<F4@;F\@;65M;W,@=&\@97AP;W)T+B(*
M;7-G<W1R(").;W1A(&-E<G5T82!N=2!E>&ES=&$N(@H*(SH@9&%T82YP:'`Z
M,3`U"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM
M<V=S='(@(D-R96%R92!A(&-A=&5G;W)I96D@)7,@97-U871A(@H*(SH@=&5M
M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(E5N9&\@
M8VAA;F=E<R(*;7-G<W1R(")2969A('-C:&EM8F%R:6QE(@H*(SH@=&5M<&QA
M=&5S+W9I97<O;65M;RYI;F,Z,38@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM
M87)I97,N:6YC.C$T"B,Z(&QI8B]-;F5M;RYP:'`Z,C`V(&QI8B]-;F5M;RYP
M:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z,C(Q(&QI8B]-;F5M;RYP:'`Z,C(R"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#4*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`B3F5C;VUP;&5T870B"@HC.B!L:6(O87!I+G!H<#HR,S8@;&EB+V%P
M:2YP:'`Z,S`Y(&QI8B]A<&DN<&AP.C0P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C(*;7-G:60@(E=H:6-H($YO
M=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\B"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z-#(@9&%T82YP:'`Z,3(U(&UE;6\N<&AP.C,U"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!N;W1E<RXB"FUS9W-T<B`B(@H*(SH@=FEE=RYP
M:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A9"`E<RXB"FUS9W-T<B`B(@H*
M(SH@;F]T97!A9',N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S
M96QE8W0@82!N;W1E<&%D('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E-E;&5C
M=&%T:2!C96P@<'5T:6X@;R!N;W1A+B(*"B,Z('1E;7!L871E<R]P<F5F<R]N
M;W1E<&%D<V5L96-T+FEN8SHQ,`IM<V=I9"`B66]U<B!D969A=6QT(&YO=&5P
M860Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D
M<RYI;F,Z-C4*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;F]T97!A9',Z(@IM<V=S
M='(@(DYI8VD@;R!N;W1A(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,C@@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@
M(E]"86-K('1O($YO=&5P860B"FUS9W-T<B`B26YA<&]I(&EN($YO=&5P860B
M"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU,2!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C4P"B,L(&9U>GIY"FUS9VED(")?0V%T96=O
M<GDB"FUS9W-T<B`B0V%T96=O<FEE(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M
M;RYI;F,Z,C4@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C0*(RP@9G5Z>GD*
M;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B4W1E<F=E(@H*(SH@=&5M<&QA=&5S
M+W9I97<O;65M;RYI;F,Z,C$@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*
M;7-G:60@(E]%9&ET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHR,`IM<V=I9"`B7T9I<G-T($QI;F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TUN96UO+G!H<#HR.#$*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8T"B,L(&9U>GIY"FUS9VED
M(")?3&ES="!.;W1E<R(*;7-G<W1R("),:7-T96%Z82!N;W1E(@H*(SH@;&EB
M+TUN96UO+G!H<#HR-S8*(RP@9G5Z>GD*;7-G:60@(E]->2!.;W1E<&%D<R(*
M;7-G<W1R(")-;V1I9FEC82!N;W1A(@H*(SH@;&EB+TUN96UO+G!H<#HR-CD*
M(RP@9G5Z>GD*;7-G:60@(E].97<@3F]T92(*;7-G<W1R(").;W1A(&YO=6$B
M"@HC.B!L:6(O36YE;6\N<&AP.C(X-@HC+"!F=7IZ>0IM<V=I9"`B7U!R:6YT
M(@IM<V=S='(@(E1I<&%R97-T92(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<R"B,L
M(&9U>GIY"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(D-A=71A<F4B"@HC.B!D
M871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@
M(FYO=&5S+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,R!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")V3F]T92(*
M;7-G<W1R(")386QV96%Z82!N;W1A(@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO
M+W!O+W-K7U-++G!O````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,S$U-S(`,3`T,3<S-C(W-#8`,#$W-3,V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````",@36YE;6\@4VQO=F%K
M('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R+"`R,#`T($EV86X@
M3F]R:7,*(R!)=F%N($YO<FES(#QV:7A`=F%Z:V$N<VL^+"`R,#`R+"`R,#`T
M"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($UN
M96UO(#(N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3`R(#(S
M.C4Y*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,#,@,#`Z
M,3`K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!)=F%N($YO<FES(#QV:7A`
M=F%Z:V$N<VL^7&XB"B),86YG=6%G92U496%M.B!3;&]V86L@/'9I>$!V87IK
M82YS:SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M:&5A9&5R+FEN8SHS"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&YO=&5S(@IM
M<V=S='(@(B5D('!O>F[A;6]K(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI
M;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@8VAA<F%C=&5R<R(*;7-G
M<W1R("(E<R!Z;F%K;W8B"@HC.B!D871A+G!H<#HQ.#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T
M<B`B<_IB;W(@)7,@^G-P9;EN92!I;7!O<G1O=F%N_2(*"B,Z(&YO=&5P861S
M+G!H<#HY.2!L:6(O8F%S92YP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@3F]T97!A9"(*;7-G<W1R(")0;WINX6UK>2!P;W6^[79A=&6U82`E
M<R(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z,PIM<V=I9"`B,2!N
M;W1E(@IM<V=S='(@(C$@<&]Z;N%M:V$B"@HC.B!M96UO+G!H<#HQ-C(*;7-G
M:60@(D%C8V5S<R!D96YI960@9&5L971I;F<@;F]T92XB"FUS9W-T<B`B4')I
M('9Y;6%ZX79A;NT@<&]Z;N%M:WD@8F]L('IA;6EE=&YU=/T@<'+M<W1U<"XB
M"@HC.B!M96UO+G!H<#HQ,3(@;65M;RYP:'`Z,3$U"FUS9VED(")!8V-E<W,@
M9&5N:65D(&UO=FEN9R!T:&4@;F]T92XB"FUS9W-T<B`B4')I('!R97/Z=F%N
M[2!P;WINX6UK>2!B;VP@>F%M:65T;G5T_2!P<NUS='5P+B(*"B,Z(&UE;6\N
M<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@<V%V
M:6YG(&YO=&4@=&\@)7,N(@IM<V=S='(@(E!R:2!U:VQA9&%N[2!P;WINX6UK
M>2!D;R`E<R!B;VP@>F%M:65T;G5T_2!P<NUS='5P+B(*"B,Z(&UE;6\N<&AP
M.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@<V%V:6YG
M(&YO=&4Z("5S(@IM<V=S='(@(E!R:2!U:VQA9&%N[2!P;WINX6UK>2!B;VP@
M>F%M:65T;G5T_2!P<NUS='5P.B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`S"FUS9VED(")!9&0@8V%T96=O<GDB
M"FUS9W-T<B`B4')I9&&[(&MA=&5G\W)I=2(*"B,Z(&UE;6\N<&AP.C4R"FUS
M9VED(")!9&1I;F<@02!.97<@3F]T92(*;7-G<W1R(")0<FEDX79A('-A(&YO
M=N$@<&]Z;N%M:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G
M:60@(D%S8V5N9&EN9R(*;7-G<W1R(")6>F]S='5P;F4B"@HC.B!T96UP;&%T
M97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.CDY"FUS9VED(")!=F%I
M;&%B;&4@0V%T96=O<FEE<SHB"FUS9W-T<B`B1&]S='5P;ND@:V%T96?S<FEE
M.B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$X"FUS9VED(")"86-K
M('1O($YO=&5P860B"FUS9W-T<B`B3F%S<.2[(&YA('!O>F[A;6MO=OT@8FQO
M:R(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.3<*;7-G
M:60@(D)A8VL@=&\@3F]T97!A9"!/<'1I;VYS(@IM<V=S='(@(DYA<W#DNR!N
M82!N87-T879E;FEA('!O>F[A;6MO=NEH;R!B;&]K=2(*"B,Z(&1A=&$N<&AP
M.C,R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*;7-G:60@(D-35B(*
M;7-G<W1R(")#4U8@*&AO9&YO='D@;V1D96QE;ND@Z&EA<FMO=2DB"@HC.B!D
M871A+G!H<#HU-"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-@IM<V=I9"`B
M0V%T96=O<GDB"FUS9W-T<B`B2V%T96?S<FEA(@H*(SH@=&5M<&QA=&5S+VYO
M=&5P861S+VYO=&5P861S+FEN8SHR,@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@
M(EIM96YINR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B
M0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P;&%Y(&]P=&EO;G,N
M(@IM<V=S='(@(DYA<W1A=F5N:64@=')I961E;FEA(&$@>F]B<F%Z;W9A;FEA
M('!O>F[A;6]K+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E
M;&5C="YI;F,Z.3,*;7-G:60@(D-H;V]S92!T:&4@;65M;R!C871E9V]R:65S
M('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RXB"FUS9W-T<B`B5GEB97)T
M92!K871E9_-R:64@<&]Z;N%M;VL@;F$@>F]B<F%Z96YI92!V('/Z:')N;F]M
M('!O:+5A9&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R"FUS9VED
M(")#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N(@IM<V=S='(@(E9Y8F5R
M=&4@<VD@<W9O:B!P<F5D;F%S=&%V96[]('!O>F[A;6MO=OT@8FQO:RXB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S(*;7-G:60@(D-L96%R
M($9O<FTB"FUS9W-T<B`B5GEM87IANR!F;W)M=6SA<B(*"B,Z('1E;7!L871E
M<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,3<@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHY-`HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A
M9',N:6YC.CDV"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B5GET=F]R:;LB"@HC
M.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHS,@IM<V=I9"`B0W)E871E9"(*
M;7-G<W1R(")6>71V;W)E;NDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C$*;7-G:60@(D1E9F%U;'0@3F]T97!A9"(*;7-G<W1R(")0<F5D;F%S=&%V
M96[]('!O>F[A;6MO=OT@8FQO:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,@IM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R
M(")0<F5D;F%S=&%V96[]('-P]'-O8B!T<FEE9&5N:6$Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER
M96-T:6]N.B(*;7-G<W1R(")0<F5D;F%S=&%V96[]('-M97(@=')I961E;FEA
M.B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.34@=&5M
M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*;7-G:60@(D1E;&5T92(*;7-G<W1R
M(")6>6UA>F&[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X"FUS9VED
M(")$96QE=&4@0V]N9FER;6%T:6]N(@IM<V=S='(@(E!O='9R9&5N:64@<')I
M('9Y;6%Z86[M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS9VED
M(")$96QE=&4@8G5T=&]N(&)E:&%V:6]U<B(*;7-G<W1R(")3<'+A=F%N:64@
M<V$@=&QAZ&ED;&$@;F$@=GEM87IA;FEE(@H*(SH@=&5M<&QA=&5S+VUE;6\O
M;65M;RYI;F,Z-C<*;7-G:60@(D1E;&5T92!T:&ES(&YO=&4B"FUS9W-T<B`B
M5GEM87IANR!T^G1O('!O>F[A;6MU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4R"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(EIO<W1U<&YE(@H*
M(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHX-0IM<V=I9"`B
M1&5S8W)I<'1I;VXZ(@IM<V=S='(@(E!O<&ES.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(DYA<W1A=F5N:64@>F]B<F%Z96YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN
M9R!E;G1R:65S/R(*;7-G<W1R(")#:&-E=&4@<&]T=G)D>F]V8;L@=GEM87KA
M=F%N:64@<&]L;[YI96L_(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,3$*;7-G:60@(D5D:70B"FUS9W-T<B`B57!R879INR(*"B,Z('1E;7!L871E
M<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(E5P<F%V:;L@7"(E<UPB(@H*(SH@
M=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT,B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z.#(*;7-G:60@(D5D:70@3F]T92(*;7-G<W1R(")5<')A
M=FF[('!O>F[A;6MU(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S
M+FEN8SHU,@IM<V=I9"`B161I="!C871E9V]R:65S(&%N9"!C;VQO<G,B"FUS
M9W-T<B`B57!R879INR!K871E9_-R:64@82!F87)B>2(*"B,Z('1E;7!L871E
M<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ,@IM<V=I9"`B16UP='D@3F]T
M92(*;7-G<W1R(")0<N%Z9&YA('!O>F[A;6MA(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ.0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(D5X<&]R
M="(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z.`IM<V=I9"`B17AP
M;W)T($YO=&5S(@IM<V=S='(@(D5X<&]R=&]V8;L@<&]Z;N%M:WDB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C$*;7-G:60@(D9?=6QL(%1E
M>'0B"FUS9W-T<B`B7T-E;/T@=&5X="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(W"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS9W-T<B`B
M5KEE;V)E8V[I(&YA<W1A=F5N:6$B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($YO=&5S+"!3
M=&5P("5D(@IM<V=S='(@(DEM<&]R="!P;WINX6UO:RP@:W)O:R`E9"(*"B,Z
M(&1A=&$N<&AP.C$Y,PIM<V=I9"`B26UP;W)T+T5X<&]R="!.;W1E<R(*;7-G
M<W1R("));7!O<G0O17AP;W)T('!O>F[A;6]K(@H*(SH@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z,SD*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B
M4&]S;&5D;N$@86MT=6%L:7KA8VEA(@H*(SH@;&EB+V%P:2YP:'`Z-S(*;7-G
M:60@(DUA>&EM=6T@3G5M8F5R(&]F($YO=&5S(@IM<V=S='(@(DUA>&EMX6QN
M>2!P;^AE="!P;WINX6UO:R(*"B,Z(&1A=&$N<&AP.C4S"FUS9VED(")-96UO
M(%1E>'0B"FUS9W-T<B`B5&5X="!P;WINX6UK>2(*"B,Z(&UE;6\N<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(DUO9&EF>6EN9R`E<R(*;7-G<W1R("+:
M<')A=F$@<&]Z;N%M:WD@)R5S)R(*"B,Z(&QI<W0N<&AP.C,U"FUS9VED(")-
M>2!.;W1E<R(*;7-G<W1R(")-;VIE('!O>F[A;6MY(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*;7-G<W1R(").;W;A
M('!O>F[A;6MA(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM
M<V=I9"`B3F5X="(*;7-G<W1R("+/86QE:B(*"B,Z(&QI8B]A<&DN<&AP.C(P
M-@IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R
M(").96)O;&D@;N%J9&5NZ2"^:6%D;F4@^F1A:F4@:4-A;&5N9&%R+B(*"B,Z
M('1E;7!L871E<R]M96YU+FEN8SHW"FUS9VED(").;R!N;W1E<&%D<R!A<F4@
M879A:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B(@HB4')E(&YE<')I:&SA
M<V5N_6-H('!O=;[M=F%T9;5O=B!N:64@<_H@:R!D:7-P;WKM8VEI(+YI861N
M92!P;WINX6UK;W;I(&)L;VMY+B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E
M<BYI;F,Z,PIM<V=I9"`B3F\@;F]T97,B"FUS9W-T<B`BKFEA9&YE('!O>F[A
M;6MY(@H*(SH@=&5M<&QA=&5S+VQI<W0O96UP='DN:6YC.C,*;7-G:60@(DYO
M(&YO=&5S(&UA=&-H('1H92!C=7)R96YT(&-R:71E<FEA+B(*;7-G<W1R("*N
M:6%D;F4@<&]Z;N%M:WD@;F5V>6AO=G5J^B!A:W1UX6QN>6T@:W)I=.ER:>%M
M+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#@*;7-G:60@(DYO(&YO
M=&5S('1O(&1I<W!L87DB"FUS9W-T<B`BKFEA9&YE('!O>F[A;6MY(&YA('IO
M8G)A>F5N:64B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC
M.C0T"FUS9VED(").;U]T92(*;7-G<W1R(")0;U]Z;N%M:V$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#$*;7-G:60@(DYO=&4@0V%T96=O<GDB"FUS
M9W-T<B`B2V%T96?S<FEA('!O>F[A;6MY(@H*(SH@=FEE=RYP:'`Z.#`@=&5M
M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C$*;7-G:60@(DYO=&4@1&5T86EL<R(*
M;7-G<W1R(")$971A:6QY('!O>F[A;6MY(@H*(SH@;F]T97!A9',N<&AP.C$Q
M,`IM<V=I9"`B3F]T92!,:7-T<R(*;7-G<W1R("):;WIN86UY('!O>F[A;6]K
M(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-#4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0P"FUS9VED(").;W1E(%1E>'0B"FUS9W-T<B`B5&5X="!P
M;WINX6UK>2(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C(V"FUS9VED
M(").;W1E(%]497AT(@IM<V=S='(@(E]497AT('!O>F[A;6MY(@H*(SH@=FEE
M=RYP:'`Z-3<@;65M;RYP:'`Z-C`*;7-G:60@(DYO=&4@;F]T(&9O=6YD+B(*
M;7-G<W1R(")0;WINX6UK82!N96)O;&$@;N%J9&5NX2XB"@HC.B!T96UP;&%T
M97,O;65M;R]M96UO+FEN8SHS-`IM<V=I9"`B3F]T95]P860B"FUS9W-T<B`B
M7U!O>F[A;6MO=OT@8FQO:R(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E
M<&%D<RYI;F,Z-SD*;7-G:60@(DYO=&5P860G<R!N86UE.B(*;7-G<W1R(").
MX7IO=B!P;WINX6UK;W;I:&\@8FQO:W4Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P
M861S+VYO=&5P861S+FEN8SHV,0IM<V=I9"`B3F]T97!A9',B"FUS9W-T<B`B
M4&]Z;N%M:V]VZ2!B;&]K>2(*"B,Z(&YO=&5P861S+G!H<#HS,PIM<V=I9"`B
M3F]T97!A9',@;75S="!H879E(&$@;F%M92XB"FUS9W-T<B`B4&]Z;N%M:V]V
MZ2!B;&]K>2!M=7-I82!M8;L@;N%Z;W8N(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C,*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`B4_IH<FX@
M<&]Z;N%M;VLB"@HC.B!L:6(O87!I+G!H<#HQ.#,@;&EB+V%P:2YP:'`Z,C<Y
M(&QI8B]A<&DN<&AP.C,U-2!L:6(O87!I+G!H<#HS.#0*;7-G:60@(E!E<FUI
M<W-I;VX@1&5N:65D(@IM<V=S='(@(E!R[7-T=7`@>F%M:65T;G5T_2(*"B,Z
M('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#(*;7-G:60@(E!E
M<FUI<W-I;VYS(@IM<V=S='(@(E!RX79A(@H*(SH@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z,34*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI<R!N;W1E/R(*
M;7-G<W1R(").86]Z86H@<VD@OF5LX71E('9Y;6%Z8;L@=/IT;R!P;WINX6UK
M=3\B"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C4@=&5M<&QA=&5S
M+VQI<W0O:&5A9&5R+FEN8SHV"FUS9VED(")2969R97-H($QI<W0B"FUS9W-T
M<B`B3V)N;W9INR!Z;V)R87IE;FEE(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H
M;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*;7-G:60@(E)E;6]V92!C871E9V]R
M>2(*;7-G<W1R(")/9'-T<N%N:;L@:V%T96?S<FEU(@H*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS9W-T
M<B`B5GEM87IANR!F;W)M=6SA<B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N
M:6YC.C4V"FUS9VED(")3879E(@IM<V=S='(@(E5L;[YINR(*"B,Z('-E87)C
M:"YP:'`Z,3<@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C0@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C,Q"FUS9VED(")396%R8V@B"FUS9W-T
M<B`B2+5A9&&[(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@(E-E87)C:"!297-U
M;'1S(@IM<V=S='(@(E;]<VQE9&MY(&BU861A;FEA(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C$W"FUS9VED(")396%R8V@@4V-O<&4B"FUS
M9W-T<B`B2+5A9&&[('8@<&]L:2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHY"FUS9VED(")396%R8V@@7U1E>'0B"FUS9W-T<B`B2&%D8;L@
M7W1E>'0B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8W
M"FUS9VED(")396QE8W0@82!N;W1E<&%D(@IM<V=S='(@(E9Y8F5R=&4@<&]Z
M;N%M:V]V_2!B;&]K(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$V"FUS9VED
M(")396QE8W0@;F]T97!A9',@=&\@9&ES<&QA>3HB"FUS9W-T<B`B5GEB97)T
M92!P;WINX6UK;W;I(&)L;VMY+"!K=&]RZ2!S82!M86KZ('IO8G)A>FF[.B(*
M"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(E-E;&5C
M="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B5GEB97)T92!F;W)MX70@
M97AP;W)T=3HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,W"FUS
M9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")6>6)E
M<G1E('/Z8F]R(&YA(&EM<&]R=#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$U"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U
M<F-E(&9I;&4Z(@IM<V=S='(@(E9Y8F5R=&4@9F]R;>%T('ID<F]J;W;I:&\@
M<_IB;W)U.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C
M="YI;F,Z,3`Y"FUS9VED(")396QE8W1E9"!#871E9V]R:65S.B(*;7-G<W1R
M(")6>6)R86[I(&MA=&5G\W)I93HB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,S<*;7-G:60@(E-H;W<@86-T:6]N(&)U='1O;G,_(@IM<V=S='(@(EIO
M8G)A>FF[('1L8>AI9&SA(&%K8VGM/R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HT,`IM<V=I9"`B4VAO=R!N;W1E<&%D(&YA;64_(@IM<V=S='(@(EIO
M8G)A>FF[(&UE;F\@<&]Z;N%M:V]VZ6AO(&)L;VMU/R(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HT,PIM<V=I9"`B4VAO=R!N;W1E<R!F<F]M('1H97-E
M(&-A=&5G;W)I97,B"FUS9W-T<B`B6F]B<F%Z:;L@<&]Z;N%M:WD@>B!T_6-H
M=&\@:V%T96?S<FGM(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S
M+FEN8SHT.`IM<V=I9"`B4V]R="!B>2!#871E9V]R>2(*;7-G<W1R(")4<FEE
M9&F[('!O9+5A(&MA=&5G\W)I92(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?
M:&5A9&5R<RYI;F,Z-#0*;7-G:60@(E-O<G0@8GD@3F]T92!497AT(@IM<V=S
M='(@(E1R:65D:;L@<&]DM6$@=&5X='4@<&]Z;N%M:WDB"@HC.B!M96UO+G!H
M<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&)O;&$@^G-P9;EN92!U;&^^96[A
M+B(*"B,Z(&UE;6\N<&AP.C$U.0IM<V=I9"`B5&AE(&YO=&4@=V%S(&1E;&5T
M960N(@IM<V=S='(@(E!O>F[A;6MA(&)O;&$@=GEM87IA;N$N(@H*(SH@;F]T
M97!A9',N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D
M(%PB)7-<(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E<R(*;7-G<W1R(").97!O
M9&%R:6QO('-A('9Y='9O<FF[('!O>F[A;6MO=OT@8FQO:R!<(B5S7"(Z("5S
M(@H*(SH@;F]T97!A9',N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!C<F5A=&5D+B(*;7-G<W1R(")0
M;WINX6UK;W;](&)L;VL@7"(E<UPB(&)O;"!V>71V;W)E;OTN(@H*(SH@;F]T
M97!A9',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")0;WINX6UK;W;]
M(&)L;VL@7"(E<UPB(&)O;"!V>6UA>F%N_2XB"@HC.B!N;W1E<&%D<RYP:'`Z
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R(")0;WINX6UK;W;](&)L;VL@7"(E<UPB
M(&)O;"!U;&^^96[]+B(*"B,Z(&1A=&$N<&AP.C$X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A
M.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!I;7!O<G1E(/ID86IO
M=CH@)7,B"@HC.B!L:6(O87!I+G!H<#HR,#`*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R
M(").87-T86QA(&-H>6)A('!R:2!I;7!O<G1E(/ID86IO=B!I0V%L96YD87(N
M(@H*(SH@;&EB+V%P:2YP:'`Z-#`S"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!V3F]T92!D871A+B(*;7-G<W1R(").87-T86QA
M(&-H>6)A('!R:2!I;7!O<G1E(/ID86IO=B!V3F]T92XB"@HC.B!M96UO+G!H
M<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(')E;6]V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A
M('!R:2!O9'-T<F'R;W9A;NT@<&]Z;N%M:WDZ("5S(@H*(SH@;65M;RYP:'`Z
M,3,S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S
M879I;F<@=&AE(&YO=&4Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I
M('5K;&%D86[M('!O>F[A;6MY.B`E<R(*"B,Z('9I97<N<&AP.C0V"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!V:65W:6YG('1H
M:7,@;F]T97!A9#H@)7,B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@<')E
M>F5R86[M('1O:'1O('!O>F[A;6MO=NEH;R!B;&]K=3H@)7,N(@H*(SH@9&%T
M82YP:'`Z-SD*;7-G:60@(E1H97)E('=E<F4@;F\@;65M;W,@=&\@97AP;W)T
M+B(*;7-G<W1R(").:64@<_H@OFEA9&YE('!O>F[A;6MY('!R92!E>'!O<G0N
M(@H*(SH@9&%T82YP:'`Z,3`U"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES
M(&YO="!S=7!P;W)T960N(@IM<V=S='(@(E1E;G1O(&9O<FWA="!S^F)O<G4@
M;FEE(&IE('!O9'!O<F]V86[]+B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%PB)7-<(CH@)7,B"@HC
M.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU.`IM<V=I9"`B56YD;R!C:&%N
M9V5S(@IM<V=S='(@(EIR=;EINR!Z;65N>2(*"B,Z('1E;7!L871E<R]V:65W
M+VUE;6\N:6YC.C(W('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN
M8SHQ-`HC.B!L:6(O36YE;6\N<&AP.C(P-B!L:6(O36YE;6\N<&AP.C(P-R!L
M:6(O36YE;6\N<&AP.C(R,2!L:6(O36YE;6\N<&AP.C(R,@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3`S"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DYE
M;F%S=&%V96[A(@H*(SH@;&EB+V%P:2YP:'`Z,C,V(&QI8B]A<&DN<&AP.C,Q
M.2!L:6(O87!I+G!H<#HT,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P
M;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R(").97!O9'!O<F]V86[]
M('1Y<"!O8G-A:'4@*$-O;G1E;G0M5'EP92DZ("5S(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHR,@IM<V=I9"`B5VAI8V@@3F]T97!A9"!S:&]U
M;&0@=&AE(&YO=&5S(&)E(&%D9&5D('1O/R(*;7-G<W1R(")$;R!K=&]RZ6AO
M('!O>F[A;6MO=NEH;R!B;&]K=2!S82!M86KZ('!R:61ANR!P;WINX6UK>3\B
M"@HC.B!D871A+G!H<#HT,B!D871A+G!H<#HQ,C4@;65M;RYP:'`Z,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&YO=&5S+B(*;7-G<W1R(").96WA=&4@;W!RX79N
M96YI92!V>71V;W)INR!V:6%C(&%K;R`E9"!P;WINX6UO:RXB"@HC.B!V:65W
M+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S+B(*;7-G<W1R(").
M96WA=&4@<'+A=F\@;F$@>F]B<F%Z96YI92!P;WINX6UK;W;I:&\@8FQO:W4@
M)7,N(@H*(SH@;F]T97!A9',N<&AP.C8U"FUS9VED(")9;W4@;75S="!S96QE
M8W0@82!N;W1E<&%D('1O(&)E(&1E;&5T960N(@IM<V=S='(@(DUU<^UT92!O
M>FYAZ&F[('!O>F[A;6MO=OT@8FQO:RP@:W1O<OT@;>$@8GF[('9Y;6%Z86[]
M+B(*"B,Z('1E;7!L871E<R]P<F5F<R]N;W1E<&%D<V5L96-T+FEN8SHQ,`IM
M<V=I9"`B66]U<B!D969A=6QT(&YO=&5P860Z(@IM<V=S='(@(E!R961N87-T
M879E;OT@<&]Z;N%M:V]V_2!B;&]K.B(*"B,Z('1E;7!L871E<R]N;W1E<&%D
M<R]N;W1E<&%D<RYI;F,Z-C4*;7-G:60@(EEO=7(@;F]T97!A9',Z(@IM<V=S
M='(@(E9AN64@<&]Z;N%M:V]VZ2!B;&]K>3HB"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHQ.`IM<V=I9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R
M(")?3F%S<.2[(&YA('!O>F[A;6MO=OT@8FQO:R(*"B,Z('1E;7!L871E<R]M
M96UO+VUE;6\N:6YC.C4Q('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI
M;F,Z-#@*;7-G:60@(E]#871E9V]R>2(*;7-G<W1R(")?2V%T96?S<FEA(@H*
M(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*;7-G:60@(E]$96QE=&4B
M"FUS9W-T<B`B7U9Y;6%Z8;LB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHQ,0IM<V=I9"`B7T5D:70B"FUS9W-T<B`B7U5P<F%V:;LB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C`*;7-G:60@(E]&:7)S="!,:6YE
M(@IM<V=S='(@(E]0<G;](')I861O:R(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C@Q
M"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R(")?26UP;W)T+T5X<&]R
M="(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8T"FUS9VED(")?3&ES="!.;W1E<R(*
M;7-G<W1R(")?6F]Z;F%M('!O>F[A;6]K(@H*(SH@;&EB+TUN96UO+G!H<#HR
M-S8*;7-G:60@(E]->2!.;W1E<&%D<R(*;7-G<W1R(")?36]J92!P;WINX6UK
M;W;I(&)L;VMY(@H*(SH@;&EB+TUN96UO+G!H<#HR-CD*;7-G:60@(E].97<@
M3F]T92(*;7-G<W1R(")?3F]VX2!P;WINX6UK82(*"B,Z(&QI8B]-;F5M;RYP
M:'`Z,C@V"FUS9VED(")?4')I;G0B"FUS9W-T<B`B7U1L8>AINR(*"B,Z(&QI
M8B]-;F5M;RYP:'`Z,C<R"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E](M6%D
M8;LB"@HC.B!D871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$*;7-G:60@(FYO=&5S+F-S=B(*;7-G<W1R(")N;W1E<RYC<W8B"@HC.B!D
M871A+G!H<#HS,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$X"FUS9VED
M(")V3F]T92(*;7-G<W1R(")V3F]T92(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VUN96UO+W!O+VQT7TQ4+G!O````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,S`T,#,`,3`T,3<S-C(W-#8`,#$W-3,R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",@3&ET
M:'5A;FEA;B!T<F%N<VQA=&EO;G,@9F]R($UN96UO('!A8VMA9V4N"B,@0V]P
M>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@
M9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@36YE
M;6\@<&%C:V%G92X*(R!$87)I=7,@36%T=6QI875S:V%S(#QD87)I=7-`;&YK
M+FQT/BP@,C`P,BX*(R!6:6QI=7,@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#XL
M(#(P,#,L(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED
M+59E<G-I;VXZ($UN96UO(#(N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`T+3$Q+3,P(#$X.C4P*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M5FEL:75S(%-U;7-K87,@/'9I;&EU<T!L;FLN;'0^7&XB"B),86YG=6%G92U4
M96%M.B!,:71H=6%N:6%N(#QV:6QI=7-`;&YK+FQT/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ,UQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=%QN(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&YO=&5S(@IM<V=S='(@(B5D('7^<F'P86DB
M"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C$X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL
M>2!I;7!O<G1E9"(*;7-G<W1R("(E<R!F86EL87,@<^MK;6EN9V%I(.%K96QT
M87,B"@HC.B!N;W1E<&%D<RYP:'`Z.3D@;&EB+V)A<V4N<&AP.C$P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,@=?YR
M8?#X(&MN>6=E;.LB"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*
M;7-G:60@(C$@;F]T92(*;7-G<W1R("(Q('7^<F'P87,B"@HC.B!M96UO+G!H
M<#HQ-C(*;7-G:60@(D%C8V5S<R!D96YI960@9&5L971I;F<@;F]T92XB"FUS
M9W-T<B`B3F5T=7)I=&4@=&5I<VGX(&GP=')I;G1I('7^<F'P;RXB"@HC.B!M
M96UO+G!H<#HQ,3(@;65M;RYP:'`Z,3$U"FUS9VED(")!8V-E<W,@9&5N:65D
M(&UO=FEN9R!T:&4@;F]T92XB"FUS9W-T<B`B3F5T=7)I=&4@=&5I<VGX('!E
M<FME;'1I('7^<F'P;RXB"@HC.B!M96UO+G!H<#HX-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E('1O("5S+B(*;7-G
M<W1R(").971U<FET92!T96ES:?@@:?!S875G;W1I('7^<F'PX"#A("5S+B(*
M"B,Z(&UE;6\N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D
M96YI960@<V%V:6YG(&YO=&4Z("5S(@IM<V=S='(@(DYE='5R:71E('1E:7-I
M^"!I\'-A=6=O=&D@=?YR8?#@.B`E<RXB"@HC.B!T96UP;&%T97,O<')E9G,O
M<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P,PIM<V=I9"`B061D(&-A=&5G;W)Y
M(@IM<V=S='(@(E-U:W5R=&D@:V%T96=O<FEJX"(*"B,Z(&UE;6\N<&AP.C4R
M"FUS9VED(")!9&1I;F<@02!.97<@3F]T92(*;7-G<W1R(").875J;R!U_G)A
M\&\@:_MR:6UA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-`IM<V=I
M9"`B07-C96YD:6YG(@IM<V=S='(@(D1I9.MJ:6UO('1V87)K82(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3D*;7-G:60@
M(D%V86EL86)L92!#871E9V]R:65S.B(*;7-G<W1R(")'86QI;6]S(&MA=&5G
M;W)I:F]S.B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(X('1E;7!L
M871E<R]V:65W+VUE;6\N:6YC.C8W"FUS9VED(")"86-K('1O($YO=&5P860B
M"FUS9W-T<B`B1W+A_G1I(.$@=?YR8?#X(&MN>6=E;.8B"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDW"FUS9VED(")"86-K('1O($YO
M=&5P860@3W!T:6]N<R(*;7-G<W1R(")'<N'^=&D@X2!U_G)A\/@@:VYY9V5L
MZW,@;G5S=&%T>6UU<R(*"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3<*;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!D
M871A+G!H<#HU-"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B
M0V%T96=O<GDB"FUS9W-T<B`B2V%T96=O<FEJ82(*"B,Z('1E;7!L871E<R]N
M;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,C(*;7-G:60@(D-H86YG92(*;7-G<W1R
M(")+96ES=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@
M(D-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS
M+B(*;7-G<W1R(")+96ES=&D@=?YR8?#X('+[\&EA=FEMX"!B96D@<F]D>6UO
M(&YU<W1A='EM=7,N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y
M<V5L96-T+FEN8SHY,PIM<V=I9"`B0VAO;W-E('1H92!M96UO(&-A=&5G;W)I
M97,@=&\@;&ES="!I;B!T:&4@<W5M;6%R>2!V:65W+B(*;7-G<W1R(")087-I
M<FEN:VET92!K=7)I87,@=?YR8?#X(&MA=&5G;W)I:F%S(')O9'ET:2!SX')A
M\&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R"B,L(&9U>GIY"FUS
M9VED(")#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N(@IM<V=S='(@(DK[
M<_@@<&%G<FEN9&ENZR!U_G)A\/@@:VYY9V5LZSHB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z,S(*;7-G:60@(D-L96%R($9O<FTB"FUS9W-T
M<B`B2?!V86QY=&DB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.C$W('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(E-U:W5R=&DB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO
M+FEN8SHS-0IM<V=I9"`B0W)E871E9"(*;7-G<W1R(")3=6MU<G1A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT($YO=&5P860B"FUS9W-T<B`B2OMS^"!P86=R:6YD:6[K('7^<F'P^"!K
M;GEG96SK.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-0IM<V=I9"`B
M1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")2^_!I=6]T:2!P
M86=A;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D1E
M9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(E+[\&EU;W1I.B(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.34@=&5M<&QA
M=&5S+W9I97<O;65M;RYI;F,Z,C4*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI
M;F,Z-C0*;7-G:60@(D1E;&5T92(*;7-G<W1R("))\'1R:6YT:2(*"B,Z('1E
M;7!L871E<R]M96UO+VUE;6\N:6YC.C8W"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@=&AI<R!N;W1E(@IM<V=S='(@(E!A<VER:6YK:71E('7^<F'P^"!K;GEG
M96SF(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U"FUS9VED(")$97-C
M96YD:6YG(@IM<V=S='(@(DUA_NMJ:6UO('1V87)K82(*"B,Z('1E;7!L871E
M<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*;7-G:60@(D1E<V-R:7!T:6]N
M.B(*;7-G<W1R(")!<')A\'EM87,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B5F%I>F1A
M=FEM;R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,C$@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*;7-G:60@(D5D:70B"FUS
M9W-T<B`B4F5D86=U;W1I(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM
M87)I97,N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@
M7"(E<UPB(@IM<V=S='(@(E)E9&%G=6]T:2(*"B,Z('1E;7!L871E<R]L:7-T
M+VUE;6]?:&5A9&5R<RYI;F,Z-#0@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C@S
M"FUS9VED(")%9&ET($YO=&4B"FUS9W-T<B`B4F5D86=U;W1I('7^<F'PX"(*
M"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-30*;7-G:60@
M(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ,@IM<V=I9"`B16UP
M='D@3F]T92(*;7-G<W1R(")4=?#H:6%S('7^<F'P87,B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B
M2?!K96QT:2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z.`IM<V=I
M9"`B17AP;W)T($YO=&5S(@IM<V=S='(@(DGP:V5L=&D@=?YR8?!U<R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,0IM<V=I9"`B1E]U;&P@
M5&5X="(*;7-G<W1R(")6:7-A;64@7W1E:W-T92(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@
M3F]T97,L(%-T97`@)60B"FUS9W-T<B`B5?YR8?#X(.%KZVQI;6%S+"`E9"UA
M<R#^:6YG<VYI<R(*"B,Z(&1A=&$N<&AP.C$Y,PIM<V=I9"`B26UP;W)T+T5X
M<&]R="!.;W1E<R(*;7-G<W1R("+!:V5L=&DO2?!K96QT:2!U_G)A\'5S(@H*
M(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-#,*;7-G:60@(DQA<W0@36]D
M:69I960B"FUS9W-T<B`B4&%S:W5T:6[A(&MA<G3@(')E9&%G=6]T82(*"B,Z
M(&QI8B]A<&DN<&AP.C<R"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!.;W1E
M<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,PIM<V=I9"`B365M;R!497AT
M(@IM<V=S='(@(E7^<F'P;R!T96MS=&%S(@H*(SH@;65M;RYP:'`Z-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y:6YG("5S(@IM<V=S='(@(E)E9&%G
M=6]J86UA<R`E<R(*"B,Z(&QI<W0N<&AP.C,U"FUS9VED(")->2!.;W1E<R(*
M;7-G<W1R(")-86YO('7^<F'P86DB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,C(*;7-G:60@(DYE=R!.;W1E(@IM<V=S='(@(DYA=6IA<R!U_G)A\&%S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I9"`B3F5X
M="(*;7-G<W1R(")396MA;G1I<R(*"B,Z(&QI8B]A<&DN<&AP.C(P-@IM<V=I
M9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B3F\@;F]T97!A9',@87)E
M(&%V86EL86)L92!T;R!G=65S=',N(@IM<V=S='(@(E7^<F'P^"!K;GEG96QI
M^"!S=F7H:6%M<R!NZW)A+B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI
M;F,Z,PIM<V=I9"`B3F\@;F]T97,B"FUS9W-T<B`B5?YR8?#X(&[K<F$B"@HC
M.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z,PIM<V=I9"`B3F\@;F]T97,@
M;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(DIO:VEE('7^
M<F'P86D@;F5A=&ET:6YK82!P86EE\&MO<R!K<FET97)I:F%U<RXB"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3`Y"FUS9VED(").;R!N;W1E<R!T;R!D
M:7-P;&%Y(@IM<V=S='(@(E7^<F'P^"!NZW)A(@H*(SH@=&5M<&QA=&5S+VQI
M<W0O;65M;U]H96%D97)S+FEN8SHT-@IM<V=I9"`B3F]?=&4B"FUS9W-T<B`B
M5?YR7V'P87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0*;7-G:60@
M(DYO=&4@0V%T96=O<GDB"FUS9W-T<B`B5?YR8?!O(&MA=&5G;W)I:F$B"@HC
M.B!V:65W+G!H<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHY"FUS9VED
M(").;W1E($1E=&%I;',B"FUS9W-T<B`B5?YR8?!O(&%P<F'P>6UA<R(*"B,Z
M(&YO=&5P861S+G!H<#HQ,3`*;7-G:60@(DYO=&4@3&ES=',B"FUS9W-T<B`B
M5?YR8?#X('/@<F'P86DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,*
M;7-G:60@(DYO=&4@5&5X="(*;7-G<W1R(")5_G)A\&\@=&5K<W1A<R(*"B,Z
M('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C(V"FUS9VED(").;W1E(%]497AT
M(@IM<V=S='(@(E7^<F'P;R!?=&5K<W1A<R(*"B,Z('9I97<N<&AP.C4W(&UE
M;6\N<&AP.C8P"FUS9VED(").;W1E(&YO="!F;W5N9"XB"FUS9W-T<B`B5&]K
M:6\@=?YR8?!O(&[K<F$N(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z
M,S0*;7-G:60@(DYO=&5?<&%D(@IM<V=S='(@(E7^<F'P^"!K;E]Y9V5LZR(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-SD*;7-G:60@
M(DYO=&5P860G<R!N86UE.B(*;7-G<W1R(")5_G)A\/@@:VYY9V5LZW,@<&%V
M861I;FEM87,Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN
M8SHV,0IM<V=I9"`B3F]T97!A9',B"FUS9W-T<B`B5?YR8?#X(&MN>6=E;.MS
M(@H*(SH@;F]T97!A9',N<&AP.C,S"B,L(&9U>GIY"FUS9VED(").;W1E<&%D
M<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R(")5_G)A\/@@:VYY9V5LZW,@
M<&%V861I;FEM87,Z(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G
M:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`B5?YR8?#X('-A;G1R=6UP82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B2VET:2!N
M=7-T871Y;6%I(@H*(SH@;&EB+V%P:2YP:'`Z,3@S(&QI8B]A<&DN<&AP.C(W
M-"!L:6(O87!I+G!H<#HS-#4@;&EB+V%P:2YP:'`Z,S<T"FUS9VED(")097)M
M:7-S:6]N($1E;FEE9"(*;7-G<W1R(").977^=&5N:V$@=&5I<VGX(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHX,@IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B5&5I<^MS(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M:&5A9&5R+FEN8SHU('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z-@IM<V=I
M9"`B4F5F<F5S:"!,:7-T(@IM<V=S='(@(D%T;F%U:FEN=&D@<^!R8?#@(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*
M;7-G:60@(E)E;6]V92!C871E9V]R>2(*;7-G<W1R("))\'1R:6YT:2!K871E
M9V]R:6K@(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY
M-@IM<V=I9"`B4F5S970B"FUS9W-T<B`B2?!V86QY=&DB"@HC.B!T96UP;&%T
M97,O;65M;R]M96UO+FEN8SHU-@IM<V=I9"`B4V%V92(*;7-G<W1R("))\'-A
M=6=O=&DB"@HC.B!S96%R8V@N<&AP.C$W('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHT('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS,0IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(DEE\&MO=&DB"@HC.B!L:7-T+G!H<#HU-PIM
M<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B4&%I9?!K;W,@<F5Z=6QT
M871A:2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ-PIM<V=I
M9"`B4V5A<F-H(%-C;W!E(@IM<V=S='(@(DEE\&MO=&DB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z.0IM<V=I9"`B4V5A<F-H(%]497AT(@IM
M<V=S='(@(E])9?!K;W1I('1E:W-T;R(*"B,Z('1E;7!L871E<R]N;W1E<&%D
M<R]N;W1E<&%D<RYI;F,Z-C<*;7-G:60@(E-E;&5C="!A(&YO=&5P860B"FUS
M9W-T<B`B4&%S:7)I;FMI=&4@=?YR8?#X(&MN>6=E;.8B"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;W1E<&%D
M<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")5_G)A\/@@;NMR82(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(E-E;&5C="!T:&4@97AP
M;W)T(&9O<FUA=#HB"FUS9W-T<B`B4&%S:7)I;FMI=&4@:?!KZVQI;6\@9F]R
M;6%TX#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,W"FUS9VED
M(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")087-I<FEN
M:VET92#A:V5L:6%MX"!F86ELX#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$U"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U
M<F-E(&9I;&4Z(@IM<V=S='(@(E!A<VER:6YK:71E(.%KZVQI86UO(&9A:6QO
M(&9O<FUA=.`Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L
M96-T+FEN8SHQ,#D*;7-G:60@(E-E;&5C=&5D($-A=&5G;W)I97,Z(@IM<V=S
M='(@(E!A<VER:6YK=&]S(&MA=&5G;W)I:F]S.B(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HS.`IM<V=I9"`B4VAO=R!A8W1I;VX@8G5T=&]N<S\B"FUS
M9W-T<B`B4F]D>71I(&UY9W1U:W5S/R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HT,0IM<V=I9"`B4VAO=R!N;W1E<&%D(&YA;64_(@IM<V=S='(@(E)O
M9'ET:2!U_G)A\/@@:VYY9V5LZW,@<&%V861I;FEMX#\B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z-#0*;7-G:60@(E-H;W<@;F]T97,@9G)O;2!T:&5S
M92!C871E9V]R:65S(@IM<V=S='(@(E)O9'ET:2!U_G)A\'5S(&GP(/!I^"!K
M871E9V]R:6KX(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN
M8SHU,`IM<V=I9"`B4V]R="!B>2!#871E9V]R>2(*;7-G<W1R(")2^_!I=6]T
M:2!P86=A;"!K871E9V]R:6K@(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H
M96%D97)S+FEN8SHT-@IM<V=I9"`B4V]R="!B>2!.;W1E(%1E>'0B"FUS9W-T
M<B`B4OOP:75O=&D@<&%G86P@=?YR8?!O('1E:W-TX"(*"B,Z(&UE;6\N<&AP
M.C$S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R!SZVMM:6YG86D@:?!S875G
M;W1A<RXB"@HC.B!M96UO+G!H<#HQ-3D*;7-G:60@(E1H92!N;W1E('=A<R!D
M96QE=&5D+B(*;7-G<W1R(")5_G)A\&%S(&GP=')I;G1A<RXB"@HC.B!N;W1E
M<&%D<RYP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@
M7"(E<UPB(&-O=6QD;B=T(&)E(&-R96%T960Z("5S(@IM<V=S='(@(DYE<&%V
M>6MO('-U:W5R=&D@=?YR8?#X(&MN>6=E;.MS(%PB)7-<(CH@)7,B"@HC.B!N
M;W1E<&%D<RYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P
M860@7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(E7^<F'P^"!K
M;GEG96SK(%PB)7-<(B!S=6MU<G1A+B(*"B,Z(&YO=&5P861S+G!H<#HX-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B5?YR8?#X(&MN>6=E;.L@7"(E<UPB(&GP
M=')I;G1A+B(*"B,Z(&YO=&5P861S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S
M='(@(E7^<F'P^"!K;GEG96SK(%PB)7-<(B!I\'-A=6=O=&$N(@H*(SH@9&%T
M82YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(DML86ED82#A
M:V5L:6%N="!D=6]M96YI<SH@)7,B"@HC.B!L:6(O87!I+G!H<#HR,#`*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")+;&%I9&$@X6ME;&EA;G0@=DYO
M=&4@9'5O;65N:7,N(@H*(SH@;&EB+V%P:2YP:'`Z,SDS"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!V3F]T92!D871A+B(*;7-G
M<W1R(")+;&%I9&$@X6ME;&EA;G0@=DYO=&4@9'5O;65N:7,N(@H*(SH@;65M
M;RYP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!R96UO=FEN9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B2VQA:61A(&GP
M=')I;F%N="!U_G)A\.`Z("5S(@H*(SH@;65M;RYP:'`Z,3,S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AE(&YO
M=&4Z("5S(@IM<V=S='(@(DML86ED82!I\'-A=6=A;G0@=?YR8?#@.B`E<RXB
M"@HC.B!V:65W+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@=FEE=VEN9R!T:&ES(&YO=&5P860Z("5S(@IM<V=S='(@
M(DML86ED82!P97+^:?MR:6YT(/!IX"!U_G)A\/@@:VYY9V5LYCH@)7,B"@HC
M.B!D871A+G!H<#HW.0IM<V=I9"`B5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E
M>'!O<G0N(@IM<V=S='(@(E7^<F'P^"!I\&OK;&EM=6D@;NMR82XB"@HC.B!D
M871A+G!H<#HQ,#4*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B1F%I;&\@9F]R;6%T87,@;F5P86QA:6MO;6%S
M+B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F5G86QI=2!I
M\'1R:6YT:2!<(B5S7"(Z("5S(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI
M;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(E5N9&\@8VAA;F=E<R(*;7-G<W1R(")!
M=/!A=6MT:2!P86ME:71I;75S(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI
M;F,Z,38@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C$T"B,Z
M(&QI8B]-;F5M;RYP:'`Z,C`V(&QI8B]-;F5M;RYP:'`Z,C`W(&QI8B]-;F5M
M;RYP:'`Z,C(Q(&QI8B]-;F5M;RYP:'`Z,C(R"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ,#4*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3F5N=7)O9'ET
M82(*"B,Z(&QI8B]A<&DN<&AP.C(S-B!L:6(O87!I+G!H<#HS,#D@;&EB+V%P
M:2YP:'`Z-#`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O
M<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(DYE_FEN;VUA<R!D=6]M
M96[X('1I<&%S+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C(*
M;7-G:60@(E=H:6-H($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E
M9"!T;S\B"FUS9W-T<B`B4')I92!K=7)I;W,@=?YR8?#X(&MN>6=E;.MS('!R
M:63K=&D@9&%R8G5S/R(*"B,Z(&1A=&$N<&AP.C0R(&1A=&$N<&AP.C$R-2!M
M96UO+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@;F]T97,N(@IM<V=S='(@
M(B(*"B,Z('9I97<N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@)7,N
M(@IM<V=S='(@(DYE='5R:71E('1E:7-I^"!P97+^:?MRZW1I('7^<F'P^"!K
M;GEG96SK<R`E<RXB"@HC.B!N;W1E<&%D<RYP:'`Z-C4*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B
M3G5R;V1Y:VET92!U_G)A\/@@:VYY9V5LYBP@:W5R:>`@;F]R:71E(&GP=')I
M;G1I+B(*"B,Z('1E;7!L871E<R]P<F5F<R]N;W1E<&%D<V5L96-T+FEN8SHQ
M,`IM<V=I9"`B66]U<B!D969A=6QT(&YO=&5P860Z(@IM<V=S='(@(DK[<_@@
M<&%G<FEN9&ENZR!U_G)A\/@@:VYY9V5LZSHB"@HC.B!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*
M;7-G<W1R(")*^W/X('7^<F'P^"!K;GEG96SK<SHB"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM
M<V=I9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")?1W+A_G1I(.$@=?YR
M8?#X(&MN>6=E;.8B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU,2!T
M96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C4P"FUS9VED(")?0V%T
M96=O<GDB"FUS9W-T<B`B7TMA=&5G;W)I:F$B"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHR-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-`IM<V=I
M9"`B7T1E;&5T92(*;7-G<W1R(")?2?!T<FEN=&DB"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV,`IM
M<V=I9"`B7T5D:70B"FUS9W-T<B`B7U)E9&%G=6]T:2(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHR,`IM<V=I9"`B7T9I<G-T($QI;F4B"FUS
M9W-T<B`B4&ER;6]J92!?96EL=73K:F4B"@HC.B!L:6(O36YE;6\N<&AP.C(X
M,0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7\%K96QT:2])\&ME
M;'1I(@H*(SH@;&EB+TUN96UO+G!H<#HR-C0*;7-G:60@(E],:7-T($YO=&5S
M(@IM<V=S='(@(E]5_G)A\/@@<^!R8?!A<R(*"B,Z(&QI8B]-;F5M;RYP:'`Z
M,C<V"B,L(&9U>GIY"FUS9VED(")?37D@3F]T97!A9',B"FUS9W-T<B`B36%N
M;R!U_G)A\&%I(@H*(SH@;&EB+TUN96UO+G!H<#HR-CD*;7-G:60@(E].97<@
M3F]T92(*;7-G<W1R(")?3F%U:F%S('7^<F'P87,B"@HC.B!L:6(O36YE;6\N
M<&AP.C(X-@IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(E]3<&%U<V1I;G1I(@H*
M(SH@;&EB+TUN96UO+G!H<#HR-S(*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B
M267P:U]O=&DB"@HC.B!D871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$*;7-G:60@(FYO=&5S+F-S=B(*;7-G<W1R(")U>G)A<V%I+F-S
M=B(*"B,Z(&1A=&$N<&AP.C,S('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,3@*;7-G:60@(G9.;W1E(@IM<V=S='(@(G9.;W1E(@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M
M;R]P;R]D95]$12YP;P``````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#,Q-S`R`#$P-#$W,S8R-S0V`#`Q-S0U-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````C($UN96UO($=E<FUA
M;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$M,C`P-"!*86X@
M4V-H;F5I9&5R+@HC($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^+"`R
M,#`Q+3(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($UN96UO(#(N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-BTP,RTP-B`Q,CHT-RLP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R
M,#`U+3$P+3$X(#$V.C0Y*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SY<;B(*(DQA;F=U86=E+51E86TZ
M($=E<FUA;B`\9&5V0&AO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X
M-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*
M(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D(&YO=&5S(@IM<V=S='(@(B5D($YO=&EZ96XB"@HC.B!T96UP
M;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!C:&%R86-T97)S(@IM<V=S='(@(B5S(%IE:6-H96XB"@HC.B!D871A+G!H
M<#HQ.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L
M;'D@:6UP;W)T960B"FUS9W-T<B`B1&EE("5S+41A=&5I('=U<F1E(&5R9F]L
M9W)E:6-H(&EM<&]R=&EE<G0B"@HC.B!N;W1E<&%D<RYP:'`Z.3D@;&EB+V)A
M<V4N<&AP.C$P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B
M"FUS9W-T<B`B)7-S($YO=&EZ8FQO8VLB"@HC.B!T96UP;&%T97,O;&ES="]H
M96%D97(N:6YC.C,*;7-G:60@(C$@;F]T92(*;7-G<W1R("(Q($YO=&EZ(@H*
M(SH@;65M;RYP:'`Z,38R"FUS9VED(")!8V-E<W,@9&5N:65D(&1E;&5T:6YG
M(&YO=&4N(@IM<V=S='(@(EIU9W)I9F8@=F5R=V5I9V5R="!B96EM($SV<V-H
M96X@9&5R($YO=&EZ+B(*"B,Z(&UE;6\N<&AP.C$Q,B!M96UO+G!H<#HQ,34*
M;7-G:60@(D%C8V5S<R!D96YI960@;6]V:6YG('1H92!N;W1E+B(*;7-G<W1R
M("):=6=R:69F('9E<G=E:6=E<G0@8F5I;2!697)S8VAI96)E;B!D97(@3F]T
M:7HN(@H*(SH@;65M;RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C
M97-S(&1E;FEE9"!S879I;F<@;F]T92!T;R`E<RXB"FUS9W-T<B`B3F]T:7H@
M:V]N;G1E(&YI8VAT(&YA8V@@)7,@9V5S<&5I8VAE<G0@=V5R9&5N+B!:=6=R
M:69F('9E<G=E:6=E<G0N(@H*(SH@;65M;RYP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T93H@)7,B"FUS9W-T
M<B`B6G5G<FEF9B!V97)W96EG97)T(&)E:6T@4W!E:6-H97)N(&1E<B!.;W1I
M>CH@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N
M:6YC.C$P,PIM<V=I9"`B061D(&-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G;W)I
M92!H:6YZ=6;\9V5N(@H*(SH@;65M;RYP:'`Z-3(*;7-G:60@(D%D9&EN9R!!
M($YE=R!.;W1E(@IM<V=S='(@(D5I;F4@;F5U92!.;W1I>B!H:6YZ=6;\9V5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED(")!<V-E;F1I
M;F<B"FUS9W-T<B`B075F<W1E:6=E;F0B"@HC.B!T96UP;&%T97,O<')E9G,O
M<VAO=W-U;6UA<GES96QE8W0N:6YC.CDY"FUS9VED(")!=F%I;&%B;&4@0V%T
M96=O<FEE<SHB"FUS9W-T<B`B5F5R9OQG8F%R92!+871E9V]R:65N.B(*"B,Z
M('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$X"FUS9VED(")"86-K('1O($YO
M=&5P860B"FUS9W-T<B`B6G5R_&-K('IU;2!.;W1I>F)L;V-K(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-PIM<V=I9"`B0F%C:R!T
M;R!.;W1E<&%D($]P=&EO;G,B"FUS9W-T<B`B6G5R_&-K('IU<B!.;W1I>F)L
M;V-K=F5R=V%L='5N9R(*"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3<*;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!D
M871A+G!H<#HU-"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-@IM<V=I9"`B
M0V%T96=O<GDB"FUS9W-T<B`B2V%T96=O<FEE(@H*(SH@=&5M<&QA=&5S+VYO
M=&5P861S+VYO=&5P861S+FEN8SHR,@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@
M(L1N9&5R;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B
M0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P;&%Y(&]P=&EO;G,N
M(@IM<V=S='(@(L1N9&5R;B!3:64@9&EE(%-O<G1I97)R96EH96YF;VQG92!U
M;F0@86YD97)E($%N>F5I9V5E:6YS=&5L;'5N9V5N+B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3,*;7-G:60@(D-H;V]S
M92!T:&4@;65M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@
M=FEE=RXB"FUS9W-T<B`B(@HB5^1H;&5N(%-I92!D:64@3F]T:7IE;FMA=&5G
M;W)I96X@875S+"!D:64@:6T@4&]R=&%L(&%N9V5Z96EG="!W97)D96X@<V]L
M;&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@IM<V=I9"`B0VAO
M;W-E('EO=7(@9&5F875L="!.;W1E<&%D+B(*;7-G<W1R(")7Y&AL96X@4VEE
M($EH<F5N(%-T86YD87)D+4YO=&EZ8FQO8VL@875S+B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHS,@IM<V=I9"`B0VQE87(@1F]R;2(*;7-G
M<W1R(")&;W)M=6QA<B!Z=7+\8VMS971Z96XB"@HC.B!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.C$W('1E;7!L871E<R]N;W1E<&%D<R]N;W1E
M<&%D<RYI;F,Z.30*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN
M8SHY-@IM<V=I9"`B0W)E871E(@IM<V=S='(@(D5R<W1E;&QE;B(*"B,Z('1E
M;7!L871E<R]V:65W+VUE;6\N:6YC.C,R"FUS9VED(")#<F5A=&5D(@IM<V=S
M='(@(D5R<W1E;&QT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q"FUS
M9VED(")$969A=6QT($YO=&5P860B"FUS9W-T<B`B4W1A;F1A<F0M3F]T:7IB
M;&]C:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,@IM<V=I9"`B1&5F
M875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")3;W)T:65R<F5I:&5N
M9F]L9V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S"FUS9VED(")$
M969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R(")3;W)T:65R<FEC
M:'1U;F<Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY
M-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B1&5L971E(@IM
M<V=S='(@(DSV<V-H96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@*
M;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T<B`B3/9S8VAB97-T
MY'1I9W5N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B
M1&5L971E(&)U='1O;B!B96AA=FEO=7(B"FUS9W-T<B`B5F5R:&%L=&5N(&)E
M:6T@3/9S8VAE;BXB"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHV-PIM
M<V=I9"`B1&5L971E('1H:7,@;F]T92(*;7-G<W1R(")$:65S92!.;W1I>B!L
M]G-C:&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R"FUS9VED(")$
M97-C96YD:6YG(@IM<V=S='(@(D%B<W1E:6=E;F0B"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C@U"FUS9VED(")$97-C<FEP=&EO;CHB
M"FUS9W-T<B`B0F5S8VAR96EB=6YG.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D%N>F5I
M9V4M16EN<W1E;&QU;F=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M.`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R
M:65S/R(*;7-G<W1R(")-]F-H=&5N(%-I92!D87,@3/9S8VAE;B!V;VX@16EN
M='+D9V5N(&)E<W3D=&EG96X_(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI
M;F,Z,3$*;7-G:60@(D5D:70B"FUS9W-T<B`B0F5A<F)E:71E;B(*"B,Z('1E
M;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHU"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!B96%R8F5I
M=&5N(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT,B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-S<*;7-G:60@(D5D:70@3F]T92(*;7-G
M<W1R(").;W1I>B!B96%R8F5I=&5N(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M
M;U]H96%D97)S+FEN8SHU,@IM<V=I9"`B161I="!C871E9V]R:65S(&%N9"!C
M;VQO<G,B"FUS9W-T<B`B2V%T96=O<FEE;B!U;F0@1F%R8F5N(&)E87)B96ET
M96XB"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z,3(*
M;7-G:60@(D5M<'1Y($YO=&4B"FUS9W-T<B`B3&5E<F4@3F]T:7HB"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS9VED(")%>'!O<G0B"FUS
M9W-T<B`B17AP;W)T:65R96XB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C@*;7-G:60@(D5X<&]R="!.;W1E<R(*;7-G<W1R(").;W1I>F5N(&5X
M<&]R=&EE<F5N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(Q
M"FUS9VED(")&7W5L;"!497AT(@IM<V=S='(@(E]6;VQL=&5X="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W"FUS9VED(")'96YE<F%L($]P
M=&EO;G,B"FUS9W-T<B`B06QL9V5M96EN92!%:6YS=&5L;'5N9V5N(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="!.;W1E<RP@4W1E<"`E9"(*;7-G<W1R(").;W1I>F5N(&EM
M<&]R=&EE<F5N+"!38VAR:71T("5D(@H*(SH@9&%T82YP:'`Z,3DS"FUS9VED
M("));7!O<G0O17AP;W)T($YO=&5S(@IM<V=S='(@(DYO=&EZ96X@26UP;W)T
M+T5X<&]R="(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C,Y"FUS9VED
M("),87-T($UO9&EF:65D(@IM<V=S='(@(DQE='IT92#$;F1E<G5N9R(*"B,Z
M(&QI8B]A<&DN<&AP.C<R"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!.;W1E
M<R(*;7-G<W1R(")-87AI;6%L92!!;GIA:&P@86X@3F]T:7IE;B(*"B,Z(&1A
M=&$N<&AP.C4S"FUS9VED(")-96UO(%1E>'0B"FUS9W-T<B`B3F]T:7IE;G1E
M>'0B"@HC.B!M96UO+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I
M9GEI;F<@)7,B"FUS9W-T<B`B)7,@8F5A<F)E:71E;B(*"B,Z(&QI<W0N<&AP
M.C,U"FUS9VED(")->2!.;W1E<R(*;7-G<W1R(")-96EN92!.;W1I>F5N(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*
M;7-G<W1R(").975E($YO=&EZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHT,`IM<V=I9"`B3F5X="(*;7-G<W1R(")796ET97(B"@HC.B!L:6(O
M87!I+G!H<#HR,#4*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N
M9"XB"FUS9W-T<B`B17,@=W5R9&5N(&ME:6YE(&E#86QE;F1A<BU$871E;B!G
M969U;F1E;BXB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B3F\@
M;F]T97!A9',@87)E(&%V86EL86)L92!T;R!G=65S=',N(@IM<V=S='(@(D5S
M('-I;F0@:V5I;F4@3F]T:7IB;/9C:V4@9OQR($?D<W1E('9E<F;\9V)A<BXB
M"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(DYO(&YO
M=&5S(@IM<V=S='(@(DME:6YE($YO=&EZ96XB"@HC.B!T96UP;&%T97,O;&ES
M="]E;7!T>2YI;F,Z,PIM<V=I9"`B3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E
M;G0@8W)I=&5R:6$N(@IM<V=S='(@(DME:6YE($YO=&EZ96X@96YT<W!R96-H
M96X@9&5N(%-U8VAK<FET97)I96XN(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$P,PIM<V=I9"`B3F\@;F]T97,@=&\@9&ES<&QA>2(*;7-G<W1R(")+
M96EN92!.;W1I>F5N(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S
M+FEN8SHT-`IM<V=I9"`B3F]?=&4B"FUS9W-T<B`B3F]?=&EZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0Q"FUS9VED(").;W1E($-A=&5G;W)Y(@IM
M<V=S='(@(DYO=&EZ:V%T96=O<FEE(@H*(SH@=FEE=RYP:'`Z.#(@=&5M<&QA
M=&5S+W9I97<O;65M;RYI;F,Z,C$*;7-G:60@(DYO=&4@1&5T86EL<R(*;7-G
M<W1R(").;W1I>F1E=&%I;',B"@HC.B!N;W1E<&%D<RYP:'`Z,3$P"FUS9VED
M(").;W1E($QI<W1S(@IM<V=S='(@(DYO=&EZ:7-T96XB"@HC.B!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHT-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`*
M;7-G:60@(DYO=&4@5&5X="(*;7-G<W1R(").;W1I>G1E>'0B"@HC.B!T96UP
M;&%T97,O;65M;R]M96UO+FEN8SHR-@IM<V=I9"`B3F]T92!?5&5X="(*;7-G
M<W1R(").;W1I>E]T97AT(@H*(SH@=FEE=RYP:'`Z-3<@;65M;RYP:'`Z-C`*
M;7-G:60@(DYO=&4@;F]T(&9O=6YD+B(*;7-G<W1R(").;W1I>B!N:6-H="!G
M969U;F1E;BXB"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHS-`IM<V=I
M9"`B3F]T95]P860B"FUS9W-T<B`B3F]T:7I?8FQO8VLB"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.C<Y"FUS9VED(").;W1E<&%D)W,@
M;F%M93HB"FUS9W-T<B`B3F]T:7IB;&]C:VYA;64Z(@H*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHV,0IM<V=I9"`B3F]T97!A9',B"FUS
M9W-T<B`B3F]T:7IB;/9C:V4B"@HC.B!N;W1E<&%D<RYP:'`Z,S,*;7-G:60@
M(DYO=&5P861S(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S='(@(DYO=&EZ8FSV
M8VME(&W\<W-E;B!E:6YE;B!.86UE;B!H86)E;BXB"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,PIM<V=I9"`B3F]T97,@4W5M;6%R>2(*;7-G<W1R(").
M;W1I>F5N+5IU<V%M;65N9F%S<W5N9R(*"B,Z(&QI8B]A<&DN<&AP.C$X,B!L
M:6(O87!I+G!H<#HR-S@@;&EB+V%P:2YP:'`Z,S4T(&QI8B]A<&DN<&AP.C,X
M,PIM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B6G5G<FEF9B!V
M97)W96EG97)T(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN
M8SHX,@IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5C:'1E(@H*(SH@
M=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*;7-G:60@(E)E86QL>2!D96QE
M=&4@=&AI<R!N;W1E/R(*;7-G<W1R(")$:65S92!.;W1I>B!W:7)K;&EC:"!L
M]G-C:&5N/R(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z-2!T96UP
M;&%T97,O;&ES="]H96%D97(N:6YC.C8*;7-G:60@(E)E9G)E<V@@3&ES="(*
M;7-G<W1R("),:7-T92!A:W1U86QI<VEE<F5N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*;7-G:60@(E)E;6]V92!C
M871E9V]R>2(*;7-G<W1R(")+871E9V]R:64@96YT9F5R;F5N(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B
M"FUS9W-T<B`B6G5R_&-K<V5T>F5N(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M
M;RYI;F,Z-38*;7-G:60@(E-A=F4B"FUS9W-T<B`B4W!E:6-H97)N(@H*(SH@
M<V5A<F-H+G!H<#HQ-R!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-"!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S$*;7-G:60@(E-E87)C:"(*
M;7-G<W1R(")3=6-H92(*"B,Z(&QI<W0N<&AP.C4W"FUS9VED(")396%R8V@@
M4F5S=6QT<R(*;7-G<W1R(")3=6-H97)G96)N:7-S92(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B4V5A<F-H(%-C;W!E(@IM
M<V=S='(@(E-U8VAF96QD97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z.0IM<V=I9"`B4V5A<F-H(%]497AT(@IM<V=S='(@(E-U8VA?=&5X
M="(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C<*;7-G
M:60@(E-E;&5C="!A(&YO=&5P860B"FUS9W-T<B`B3F]T:7IB;&]C:R!A=7-W
MY&AL96XB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,38*;7-G:60@(E-E;&5C
M="!N;W1E<&%D<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")7Y&AL96X@4VEE($YO
M=&EZ8FSV8VME(&%U<SHB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$U"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@
M(E?D:&QE;B!3:64@9&%S($5X<&]R=&9O<FUA=#HB"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C,W"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@
M:6UP;W)T.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1I92!$871E:2P@9&EE(&EM
M<&]R=&EE<G0@=V5R9&5N('-O;&PZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O
M=7)C92!F:6QE.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1A<R!&;W)M870@9&5R
M(&EM<&]R=&EE<G1E;B!$871E:3HB"@HC.B!T96UP;&%T97,O<')E9G,O<VAO
M=W-U;6UA<GES96QE8W0N:6YC.C$P.0IM<V=I9"`B4V5L96-T960@0V%T96=O
M<FEE<SHB"FUS9W-T<B`B075S9V5WY&AL=&4@2V%T96=O<FEE;CHB"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,S<*;7-G:60@(E-H;W<@86-T:6]N(&)U
M='1O;G,_(@IM<V=S='(@(D%K=&EO;G-K;O9P9F4@86YZ96EG96X_(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0P"FUS9VED(")3:&]W(&YO=&5P860@
M;F%M93\B"FUS9W-T<B`B3F]T:7IB;&]C:VYA;64@86YZ96EG96X_(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0S"FUS9VED(")3:&]W(&YO=&5S(&9R
M;VT@=&AE<V4@8V%T96=O<FEE<R(*;7-G<W1R(").;W1I>F5N(&1I97-E<B!+
M871E9V]R:65N(&%N>F5I9V5N(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H
M96%D97)S+FEN8SHT.`IM<V=I9"`B4V]R="!B>2!#871E9V]R>2(*;7-G<W1R
M(")3;W)T:65R96X@;F%C:"!+871E9V]R:64B"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C0T"FUS9VED(")3;W)T(&)Y($YO=&4@5&5X
M="(*;7-G<W1R(")3;W)T:65R96X@;F%C:"!.;W1I>G1E>'0B"@HC.B!M96UO
M+G!H<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A
M=F5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB('=U<F1E(&5R9F]L9W)E:6-H
M(&=E<W!E:6-H97)T+B(*"B,Z(&UE;6\N<&AP.C$U.0IM<V=I9"`B5&AE(&YO
M=&4@=V%S(&1E;&5T960N(@IM<V=S='(@(D1I92!.;W1I>B!W=7)D92!G96SV
M<V-H="XB"@HC.B!N;W1E<&%D<RYP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&YO=&5P860@7"(E<UPB(&-O=6QD;B=T(&)E(&-R96%T960Z("5S
M(@IM<V=S='(@(D1E<B!.;W1I>F)L;V-K(%PB)7-<(B!K;VYN=&4@;FEC:'0@
M97)S=&5L;'0@=V5R9&5N.B`E<R(*"B,Z(&YO=&5P861S+G!H<#HT.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@
M8W)E871E9"XB"FUS9W-T<B`B1&5R($YO=&EZ8FQO8VL@7"(E<UPB('=U<F1E
M(&5R<W1E;&QT+B(*"B,Z(&YO=&5P861S+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B1&5R($YO=&EZ8FQO8VL@7"(E<UPB('=U<F1E(&=E;/9S8VAT
M+B(*"B,Z(&YO=&5P861S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(D1E
M<B!.;W1I>F)L;V-K(%PB)7-<(B!W=7)D92!G97-P96EC:&5R="XB"@HC.B!D
M871A+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`B0F5I;2!)
M;7!O<G1I97)E;B!D97(@1&%T96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T
M96XZ("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3DY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T
M<B`B0F5I;2!);7!O<G1I97)E;B!D97(@:4-A;&5N9&%R+41A=&5N(&ES="!E
M:6X@1F5H;&5R(&%U9F=E=')E=&5N+B(*"B,Z(&QI8B]A<&DN<&AP.C0P,@IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=DYO=&4@
M9&%T82XB"FUS9W-T<B`B0F5I;2!);7!O<G1I97)E;B!D97(@=DYO=&4M1&%T
M96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN(@H*(SH@;65M;RYP:'`Z
M,34W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R
M96UO=FEN9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B0F5I;2!,]G-C:&5N(&1E
M<B!.;W1I>B!I<W0@96EN($9E:&QE<B!A=69G971R971E;CH@)7,B"@HC.B!M
M96UO+G!H<#HQ,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R('-A=FEN9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B0F5I;2!3<&5I
M8VAE<FX@9&5R($YO=&EZ(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N.B`E
M<R(*"B,Z('9I97<N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!V:65W:6YG('1H:7,@;F]T97!A9#H@)7,B"FUS9W-T
M<B`B0F5I;2!!;GIE:6=E;B!D:65S97,@3F]T:7IB;&]C:W,@:7-T(&5I;B!&
M96AL97(@875F9V5T<F5T96XZ("5S(@H*(SH@9&%T82YP:'`Z-SD*;7-G:60@
M(E1H97)E('=E<F4@;F\@;65M;W,@=&\@97AP;W)T+B(*;7-G<W1R(")%<R!K
M;VYN=&5N(&ME:6YE(%1E<FUI;F4@>G5M($5X<&]R=&EE<F5N(&=E9G5N9&5N
M('=E<F1E;BXB"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H:7,@9FEL92!F
M;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1&EE<V5S($1A=&5I
M9F]R;6%T('=I<F0@;FEC:'0@=6YT97)S=/QT>G0N(@H*(SH@;F]T97!A9',N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M7"(E<UPB.B`E<R(*;7-G<W1R(")<(B5S7"(@:V%N;B!N:6-H="!G96SV<V-H
M="!W97)D96XZ("5S(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3@*
M;7-G:60@(E5N9&\@8VAA;F=E<R(*;7-G<W1R("+$;F1E<G5N9V5N('+\8VMG
MY&YG:6<@;6%C:&5N(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C<@
M=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C$T"B,Z(&QI8B]-
M;F5M;RYP:'`Z,C`V(&QI8B]-;F5M;RYP:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z
M,C(Q(&QI8B]-;F5M;RYP:'`Z,C(R"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HY.`IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(").:6-H="!Z=6=E;W)D;F5T
M(@H*(SH@;&EB+V%P:2YP:'`Z,C,U(&QI8B]A<&DN<&AP.C,Q."!L:6(O87!I
M+G!H<#HT,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N
M=&5N="U4>7!E.B`E<R(*;7-G<W1R(").:6-H="!U;G1E<G-T_'1Z=&5R($EN
M:&%L='-T>7`Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR
M,@IM<V=I9"`B5VAI8V@@3F]T97!A9"!S:&]U;&0@=&AE(&YO=&5S(&)E(&%D
M9&5D('1O/R(*;7-G<W1R("):=2!W96QC:&5M($YO=&EZ8FQO8VL@<V]L;&5N
M(&1I92!.;W1I>F5N(&AI;GIU9V5F_&=T('=E<F1E;C\B"@HC.B!D871A+G!H
M<#HT,B!D871A+G!H<#HQ,C4@;65M;RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&YO=&5S+B(*;7-G<W1R(")3:64@9/QR9F5N(&YI8VAT(&UE:'(@86QS
M("5D($YO=&EZ96X@97)S=&5L;&5N+B(*"B,Z('9I97<N<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M('9I97<@=&AE(&YO=&5P860@)7,N(@IM<V=S='(@(E-I92!H86)E;B!N:6-H
M="!G96[\9V5N9"!296-H=&4L('5M(&1E;B!.;W1I>F)L;V-K("5S(&%N>G5Z
M96EG96XN(@H*(SH@;F]T97!A9',N<&AP.C8U"FUS9VED(")9;W4@;75S="!S
M96QE8W0@82!N;W1E<&%D('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E-I92!M
M_'-S96X@9&5N('IU(&SV<V-H96YD96X@3F]T:7IB;&]C:R!A=7-WY&AL96XN
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VYO=&5P861S96QE8W0N:6YC.C$P"FUS
M9VED(")9;W5R(&1E9F%U;'0@;F]T97!A9#HB"FUS9W-T<B`B26AR(%-T86YD
M87)D+4YO=&EZ8FQO8VLZ(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P
M861S+FEN8SHV-0IM<V=I9"`B66]U<B!N;W1E<&%D<SHB"FUS9W-T<B`B26AR
M92!.;W1I>F)L]F-K93HB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ
M.`IM<V=I9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")?6G5R_&-K('IU
M;2!.;W1I>F)L;V-K(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3$@
M=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT.`IM<V=I9"`B7T-A
M=&5G;W)Y(@IM<V=S='(@(E]+871E9V]R:64B"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHQ-0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")?3/9S8VAE
M;B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$Q"FUS9VED(")?161I
M="(*;7-G<W1R(")?0F5A<F)E:71E;B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHR,`IM<V=I9"`B7T9I<G-T($QI;F4B"FUS9W-T<B`B17)S
M=&4@7UIE:6QE(@H*(SH@;&EB+TUN96UO+G!H<#HR.#$*;7-G:60@(E]);7!O
M<G0O17AP;W)T(@IM<V=S='(@(E]);7!O<G0O17AP;W)T(@H*(SH@;&EB+TUN
M96UO+G!H<#HR-C0*;7-G:60@(E],:7-T($YO=&5S(@IM<V=S='(@(DYO=&EZ
M96X@7V%N>F5I9V5N(@H*(SH@;&EB+TUN96UO+G!H<#HR-S8*;7-G:60@(E]-
M>2!.;W1E<&%D<R(*;7-G<W1R(")?365I;F4@3F]T:7IB;/9C:V4B"@HC.B!L
M:6(O36YE;6\N<&AP.C(V.0IM<V=I9"`B7TYE=R!.;W1E(@IM<V=S='(@(E].
M975E($YO=&EZ(@H*(SH@;&EB+TUN96UO+G!H<#HR.#8*;7-G:60@(E]0<FEN
M="(*;7-G<W1R(")?1')U8VME;B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<R"FUS
M9VED(")?4V5A<F-H(@IM<V=S='(@(E]3=6-H92(*"B,Z(&1A=&$N<&AP.CDQ
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B;F]T97,N8W-V
M(@IM<V=S='(@(FYO=&EZ96XN8W-V(@H*(SH@9&%T82YP:'`Z,S,@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ.`IM<V=I9"`B=DYO=&4B"FUS9W-T<B`B
M=DYO=&4B"@``````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]M;F5M;R]P;R]N;%].3"YP;P``````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#,P-S$P`#$P-#$W,S8R-S0V`#`Q-S4Q-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C($UN
M96UO($1U=&-H('1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,B!*
M86X@2W5I<&5R<RX*(R!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C
M;VQL96=E+FYL/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE
M8W0M260M5F5R<VEO;CH@36YE;F\@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#0M,3(M,#D@,#@Z-3(K,#$P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@1'5T8V@@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O;&ES="]H
M96%D97(N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;F]T97,B"FUS
M9W-T<B`B)60@;F]T:71I97,B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN
M8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!C:&%R86-T97)S(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R("(E<R!B97-T
M86YD(&UE="!S=6-C97,@9V5I;7!O<G1E97)D(@H*(SH@;F]T97!A9',N<&AP
M.CDY(&QI8B]B87-E+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!.;W1E<&%D(@IM<V=S='(@(B5S)W,@;F]T:71I96)O96LB"@HC.B!T96UP
M;&%T97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(C$@;F]T92(*;7-G<W1R
M("(Q(&YO=&ET:64B"@HC.B!M96UO+G!H<#HQ-C(*;7-G:60@(D%C8V5S<R!D
M96YI960@9&5L971I;F<@;F]T92XB"FUS9W-T<B`B5&]E9V%N9R!G97=E:6=E
M<F0@8FEJ('9E<G=I:F1E<F5N('9A;B!N;W1I=&EE+B(*"B,Z(&UE;6\N<&AP
M.C$Q,B!M96UO+G!H<#HQ,34*;7-G:60@(D%C8V5S<R!D96YI960@;6]V:6YG
M('1H92!N;W1E+B(*;7-G<W1R(")4;V5G86YG(&=E=V5I9V5R9"!B:6H@=F5R
M<&QA871S96X@=F%N(&1E(&YO=&ET:64N(@H*(SH@;65M;RYP:'`Z.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T92!T
M;R`E<RXB"FUS9W-T<B`B5&]E9V%N9R!G97=E:6=E<F0@8FEJ(&]P<VQA86X@
M=F%N(&YO=&ET:64@:6X@)7,N(@H*(SH@;65M;RYP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T93H@)7,B"FUS
M9W-T<B`B5&]E9V%N9R!G97=E:6=E<F0@8FEJ(&]P<VQA86X@=F%N(&YO=&ET
M:64Z("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T
M+FEN8SHQ,#,*;7-G:60@(D%D9"!C871E9V]R>2(*;7-G<W1R(")#871E9V]R
M:64@=&]E=F]E9V5N(@H*(SH@;65M;RYP:'`Z-3(*;7-G:60@(D%D9&EN9R!!
M($YE=R!.;W1E(@IM<V=S='(@(D5E;B!N:65U=V4@;F]T:71I92!T;V5V;V5G
M96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0*;7-G:60@(D%S8V5N
M9&EN9R(*;7-G<W1R(")4;V5N96UE;F0B"@HC.B!T96UP;&%T97,O<')E9G,O
M<VAO=W-U;6UA<GES96QE8W0N:6YC.CDY"FUS9VED(")!=F%I;&%B;&4@0V%T
M96=O<FEE<SHB"FUS9W-T<B`B0F5S8VAI:V)A<F4@8V%T96=O<FEE96XZ(@H*
M(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C@@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z-C<*;7-G:60@(D)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")4
M97)U9R!N86%R(&YO=&ET:65B;V5K(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHY-PIM<V=I9"`B0F%C:R!T;R!.;W1E<&%D($]P=&EO
M;G,B"FUS9W-T<B`B5&5R=6<@;F%A<B!D92!N;W1I=&EE8F]E:V]P=&EE<R(*
M"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*
M;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!D871A+G!H<#HU-"!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B0V%T96=O<GDB"FUS9W-T
M<B`B0V%T96=O<FEE(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHR,@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(E=I:GII9V5N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U"FUS9VED(")#:&%N9V4@>6]U<B!N
M;W1E('-O<G1I;F<@86YD(&1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B5VEJ
M>FEG('5W(&YO=&ET:64@<V]R=&5E<BT@96X@=V5E<F=A=F5O<'1I97,N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY,PIM
M<V=I9"`B0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T
M:&4@<W5M;6%R>2!V:65W+B(*;7-G<W1R("(B"B)+:65S(&1E(&YO=&ET:65C
M871E9V]R:65E;B!D:64@:6X@9&4@<V%M96YV871T:6YG(&1I96YE;B!T92!W
M;W)D96X@(@HB=V5E<F=E9V5V96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R"FUS9VED(")#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N(@IM
M<V=S='(@(DMI97,@<W1A;F1A87)D(&YO=&ET:65B;V5K+B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHS,@IM<V=I9"`B0VQE87(@1F]R;2(*
M;7-G<W1R(")7:7,@9F]R;75L:65R(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHQ-R!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.CDT"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.38*
M;7-G:60@(D-R96%T92(*;7-G<W1R(")-86ME;B(*"B,Z('1E;7!L871E<R]V
M:65W+VUE;6\N:6YC.C,U"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(D=E;6%A
M:W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*;7-G:60@(D1E9F%U
M;'0@3F]T97!A9"(*;7-G<W1R(")3=&%N9&%A<F0@;F]T:71I96)O96LB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4*;7-G:60@(D1E9F%U;'0@<V]R
M=&EN9R!C<FET97)I83HB"FUS9W-T<B`B4W1A;F1A87)D('-O<G1E97)C<FET
M97)I83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D1E
M9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(E-T86YD86%R9"!S
M;W)T965R=F]L9V]R9&4Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P
M861S+FEN8SHY-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-0HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHV-`IM<V=I9"`B1&5L971E(@IM<V=S='(@
M(E9E<G=I:F1E<F5N(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-C<*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!T:&ES(&YO=&4B"FUS9W-T<B`B4V5L
M96-T965R(&5E;B!N;W1I=&EE8F]E:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-0IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R(")!9FYE;65N9"(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*;7-G:60@
M(D1E<V-R:7!T:6]N.B(*;7-G<W1R(")"97-C:')I:G9I;F<Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B
M"FUS9W-T<B`B5V5E<F=A=F5O<'1I97,B"@HC.B!T96UP;&%T97,O=FEE=R]M
M96UO+FEN8SHR,2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV,`IM<V=I9"`B
M161I="(*;7-G<W1R(")"97=E<FME;B(*"B,Z('1E;7!L871E<R]L:7-T+VUE
M;6]?<W5M;6%R:65S+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET(%PB)7-<(B(*;7-G<W1R(")"97=E<FME;B(*"B,Z('1E;7!L871E
M<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#0@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C@S"FUS9VED(")%9&ET($YO=&4B"FUS9W-T<B`B3F]T:71I92!B97=E
M<FME;B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-30*
M;7-G:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ,@IM<V=I
M9"`B16UP='D@3F]T92(*;7-G<W1R("),96=E(&YO=&ET:64B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS9VED(")%>'!O<G0B"FUS9W-T
M<B`B17AP;W)T97)E;B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M.`IM<V=I9"`B17AP;W)T($YO=&5S(@IM<V=S='(@(DYO=&ET:65S(&5X<&]R
M=&5R96XB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C$*;7-G
M:60@(D9?=6QL(%1E>'0B"FUS9W-T<B`B7U9O;&QE9&EG92!T96MS="(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G0@3F]T97,L(%-T97`@)60B"FUS9W-T<B`B3F]T:71I97,@
M:6UP;W)T97)E;BP@<W1A<"`E9"(*"B,Z(&1A=&$N<&AP.C$Y,PIM<V=I9"`B
M26UP;W)T+T5X<&]R="!.;W1E<R(*;7-G<W1R(").;W1I=&EE<R!I;7!O<G1E
M<F5N+V5X<&]R=&5R96XB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHT
M,PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("),86%T<W0@9V5W:6IZ
M:6=D(@H*(SH@;&EB+V%P:2YP:'`Z-S(*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F($YO=&5S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4S"FUS9VED(")-
M96UO(%1E>'0B"FUS9W-T<B`B3F]T:71I971E:W-T(@H*(SH@;65M;RYP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y:6YG("5S(@IM<V=S='(@
M(B5S(&)E=V5R:V5N(@H*(SH@;&ES="YP:'`Z,S4*;7-G:60@(DUY($YO=&5S
M(@IM<V=S='(@(DUI:FX@;F]T:71I97,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,C(*;7-G:60@(DYE=R!.;W1E(@IM<V=S='(@(DYI975W92!N;W1I
M=&EE(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I9"`B
M3F5X="(*;7-G<W1R(")6;VQG96YD92(*"B,Z(&QI8B]A<&DN<&AP.C(P-@IM
M<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B3F\@;F]T97!A9',@
M87)E(&%V86EL86)L92!T;R!G=65S=',N(@IM<V=S='(@(D=E96X@;F]T:71I
M96)O96ME;B!B97-C:&EK8F%A<B!V;V]R(&=A<W1E;BXB"@HC.B!T96UP;&%T
M97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(DYO(&YO=&5S(@IM<V=S='(@
M(D=E96X@;F]T:71I97,B"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z
M,PIM<V=I9"`B3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N
M(@IM<V=S='(@(D=E96X@;F]T:71I97,@9&EE(&]V97)E96X@:V]M96X@;65T
M(&1E(&AU:61I9V4@8W)I=&5R:6$N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$P.0IM<V=I9"`B3F\@;F]T97,@=&\@9&ES<&QA>2(*;7-G<W1R(")'
M965N(&YO=&ET:65S('=E97(@=&4@9V5V96XB"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C0V"FUS9VED(").;U]T92(*;7-G<W1R(").
M;U]T:71I92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-`IM<V=I9"`B
M3F]T92!#871E9V]R>2(*;7-G<W1R(").;W1I=&EE8V%T96=O<FEE(@H*(SH@
M=FEE=RYP:'`Z.#`@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z.0IM<V=I9"`B
M3F]T92!$971A:6QS(@IM<V=S='(@(DYO=&ET:65D971A:6QS(@H*(SH@;F]T
M97!A9',N<&AP.C$Q,`IM<V=I9"`B3F]T92!,:7-T<R(*;7-G<W1R(").;W1I
M=&EE;&EJ<W1E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM<V=I
M9"`B3F]T92!497AT(@IM<V=S='(@(DYO=&ET:65T96MS="(*"B,Z('1E;7!L
M871E<R]M96UO+VUE;6\N:6YC.C(V"FUS9VED(").;W1E(%]497AT(@IM<V=S
M='(@(DYO=&ET:65T7V5K<W0B"@HC.B!V:65W+G!H<#HU-R!M96UO+G!H<#HV
M,`IM<V=I9"`B3F]T92!N;W0@9F]U;F0N(@IM<V=S='(@(DYO=&ET:64@;FEE
M="!G979O;F1E;BXB"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHS-`IM
M<V=I9"`B3F]T95]P860B"FUS9W-T<B`B3F]T:71I95]B;V5K(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHW.0IM<V=I9"`B3F]T97!A
M9"=S(&YA;64Z(@IM<V=S='(@(DYO=&ET:65B;V5K;F%A;3HB"@HC.B!T96UP
M;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"FUS9VED(").;W1E<&%D
M<R(*;7-G<W1R(").;W1I=&EE8F]E:V5N(@H*(SH@;F]T97!A9',N<&AP.C,S
M"B,L(&9U>GIY"FUS9VED(").;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE+B(*
M;7-G<W1R(").;W1I=&EE8F]E:VYA86TZ(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C,*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`B3F]T:71I
M97-A;65N=F%T=&EN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`*;7-G:60@(D]T:&5R($]P=&EO;G,B
M"FUS9W-T<B`B06YD97)E(&]P=&EE<R(*"B,Z(&QI8B]A<&DN<&AP.C$X,R!L
M:6(O87!I+G!H<#HR-S0@;&EB+V%P:2YP:'`Z,S0U(&QI8B]A<&DN<&AP.C,W
M-`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B5&]E9V%N9R!G
M97=E:6=E<F0B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC
M.C@R"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")296-H=&5N(@H*(SH@
M=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHU('1E;7!L871E<R]L:7-T+VAE
M861E<BYI;F,Z-@IM<V=I9"`B4F5F<F5S:"!,:7-T(@IM<V=S='(@(DQI:G-T
M('9E<G9E<G-E;B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E
M;&5C="YI;F,Z,3`U"FUS9VED(")296UO=F4@8V%T96=O<GDB"FUS9W-T<B`B
M0V%T96=O<FEE('9E<G=I:F1E<F5N(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS9W-T<B`B2&5R<W1E
M;&QE;B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4V"FUS9VED(")3
M879E(@IM<V=S='(@(D]P<VQA86XB"@HC.B!S96%R8V@N<&AP.C$W('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHT('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHS,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(EIO96ME;B(*"B,Z
M(&QI<W0N<&AP.C4W"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R("):
M;V5K<F5S=6QT871E;B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN
M8SHQ-PIM<V=I9"`B4V5A<F-H(%-C;W!E(@IM<V=S='(@(EIO96MG96)I960B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z.0IM<V=I9"`B4V5A
M<F-H(%]497AT(@IM<V=S='(@(E1E:W-T(%]Z;V5K96XB"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8W"FUS9VED(")396QE8W0@82!N
M;W1E<&%D(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@;F]T:71I96)O96LB"@HC
M.B!T96UP;&%T97,O;65N=2YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!N;W1E<&%D<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")'965N(&YO=&ET:65S
M('=E97(@=&4@9V5V96XB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$U"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@
M(E-E;&5C=&5E<B!H970@97AP;W)T9F]R;6%A=#HB"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C,W"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@
M:6UP;W)T.B(*;7-G<W1R(")396QE8W1E97(@:&5T(&EM<&]R=&)E<W1A;F0Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L
M96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")3
M96QE8W1E97(@:&5T(&9O<FUA870@=F%N(&AE="!B<F]N8F5S=&%N9#HB"@HC
M.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P.0IM
M<V=I9"`B4V5L96-T960@0V%T96=O<FEE<SHB"FUS9W-T<B`B1V5S96QE8W1E
M97)D92!C871E9V]R:65E;CHB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,S@*;7-G:60@(E-H;W<@86-T:6]N(&)U='1O;G,_(@IM<V=S='(@(D)E=V5R
M:VEN9W-K;F]P<&5N('=E97)G979E;C\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z-#$*;7-G:60@(E-H;W<@;F]T97!A9"!N86UE/R(*;7-G<W1R(").
M;W1I=&EE8F]E:VYA;65N('=E97)G979E;C\B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z-#0*;7-G:60@(E-H;W<@;F]T97,@9G)O;2!T:&5S92!C871E
M9V]R:65S(@IM<V=S='(@(DYO=&ET:65S('9A;B!D97IE(&-A=&5G;W)I965N
M('=E97)G979E;B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI
M;F,Z-3`*;7-G:60@(E-O<G0@8GD@0V%T96=O<GDB"FUS9W-T<B`B4V]R=&5R
M96X@;W`@8V%T96=O<FEE(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D
M97)S+FEN8SHT-@IM<V=I9"`B4V]R="!B>2!.;W1E(%1E>'0B"FUS9W-T<B`B
M4V]R=&5R96X@;W`@;F]T:71I971E:W-T(@H*(SH@;65M;RYP:'`Z,3,U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M7"(E<UPB+B(*;7-G<W1R("(G)7,G(&UE="!S=6-C97,@;W!G97-L86=E;BXB
M"@HC.B!M96UO+G!H<#HQ-3D*;7-G:60@(E1H92!N;W1E('=A<R!D96QE=&5D
M+B(*;7-G<W1R(")$92!N;W1I=&EE(&ES('9E<G=I:F1E<F0N(@H*(SH@;F]T
M97!A9',N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D
M(%PB)7-<(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E<R(*;7-G<W1R(")(970@
M;F]T:71I96)O96L@7"(E<UPB(&MO;B!N:65T('=O<F1E;B!A86YG96UA86MT
M.B`E<R(*"B,Z(&YO=&5P861S+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T
M<B`B2&5T(&YO=&ET:65B;V5K(%PB)7-<(B!I<R!A86YG96UA86MT+B(*"B,Z
M(&YO=&5P861S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T
M97!A9"!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B2&5T(&YO
M=&ET:65B;V5K(%PB)7-<(B!I<R!V97)W:6ID97)D+B(*"B,Z(&YO=&5P861S
M+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S
M7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(DAE="!N;W1I=&EE8F]E:R!<
M(B5S7"(@:7,@;W!G97-L86=E;BXB"@HC.B!D871A+G!H<#HQ.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@9&%T83H@)7,B"FUS9W-T<B`B165N(&9O=70@8FEJ(&AE="!I;7!O<G1E
M<F5N('9A;B!D92!D871A.B`E<R(*"B,Z(&QI8B]A<&DN<&AP.C(P,`HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D5E;B!F;W5T(&)I:B!H970@:6UP
M;W)T97)E;B!V86X@9&4@=DYO=&4@9&%T82XB"@HC.B!L:6(O87!I+G!H<#HS
M.3,*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.
M;W1E(&1A=&$N(@IM<V=S='(@(D5E;B!F;W5T(&)I:B!H970@:6UP;W)T97)E
M;B!V86X@9&4@=DYO=&4@9&%T82XB"@HC.B!M96UO+G!H<#HQ-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H
M92!N;W1E.B`E<R(*;7-G<W1R(")%96X@<')O8FQE96T@8FEJ(&AE="!V97)W
M:6ID97)E;B!V86X@9&4@;F]T:71I93H@)7,B"@HC.B!M96UO+G!H<#HQ,S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN
M9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B165N('!R;V)L965M(&)I:B!H970@
M;W!S;&%A;B!V86X@9&4@;F]T:71I93H@)7,B"@HC.B!V:65W+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=FEE=VEN
M9R!T:&ES(&YO=&5P860Z("5S(@IM<V=S='(@(D5E;B!P<F]B;&5E;2!B:6H@
M:&5T(&)E:VEJ:V5N('9A;B!D:70@;F]T:71I96)O96LZ("5S(@H*(SH@9&%T
M82YP:'`Z-SD*;7-G:60@(E1H97)E('=E<F4@;F\@;65M;W,@=&\@97AP;W)T
M+B(*;7-G<W1R(")%<B!W87)E;B!G965N(&YO=&ET:65S(&]M('1E(&5X<&]R
M=&5R96XN(@H*(SH@9&%T82YP:'`Z,3`U"FUS9VED(")4:&ES(&9I;&4@9F]R
M;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D1I="!B97-T86YD<V9O
M<FUA870@=V]R9'0@;FEE="!O;F1E<G-T975N9"XB"@HC.B!N;W1E<&%D<RYP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<
M(B5S7"(Z("5S(@IM<V=S='(@(DYI970@:6X@<W1A870@;VT@7"(E<UPB.B`E
M<R!T92!V97)W:6ID97)E;B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC
M.C4X"B,L(&9U>GIY"FUS9VED(")5;F1O(&-H86YG97,B"FUS9W-T<B`B2&5R
M<W1E;"!W:6IZ:6=I;F=E;B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC
M.C$V('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ-`HC.B!L
M:6(O36YE;6\N<&AP.C(P-B!L:6(O36YE;6\N<&AP.C(P-R!L:6(O36YE;6\N
M<&AP.C(R,2!L:6(O36YE;6\N<&AP.C(R,@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,3`U"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(D]N8F5N;V5M9"(*
M"B,Z(&QI8B]A<&DN<&AP.C(S-B!L:6(O87!I+G!H<#HS,#D@;&EB+V%P:2YP
M:'`Z-#`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E
M9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(DYI970@;VYD97)S=&5U;F0@
M0V]N=&5N="U4>7!E+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,C(*;7-G:60@(E=H:6-H($YO=&5P860@<VAO=6QD('1H92!N;W1E<R!B92!A
M9&1E9"!T;S\B"FUS9W-T<B`B06%N('=E;&L@;F]T:71I96)O96L@9&EE;F5N
M(&1E(&YO=&ET:65S('1O96=E=F]E9V0@=&4@=V]R9&5N/R(*"B,Z(&1A=&$N
M<&AP.C0R(&1A=&$N<&AP.C$R-2!M96UO+G!H<#HS-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@;F]T97,N(@IM<V=S='(@(B(*"B,Z('9I97<N<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M('9I97<@=&AE(&YO=&5P860@)7,N(@IM<V=S='(@(E4@:&5E9G0@9V5E;B!R
M96-H="!O;2!H970@;F]T:71I96)O96L@)7,@=&4@8F5K:6IK96XN(@H*(SH@
M;F]T97!A9',N<&AP.C8U"FUS9VED(")9;W4@;75S="!S96QE8W0@82!N;W1E
M<&%D('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E4@9&EE;G0@965N(&YO=&ET
M:65B;V5K('1E('-E;&5C=&5R96X@;VT@=&4@=F5R=VEJ9&5R96XN(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VYO=&5P861S96QE8W0N:6YC.C$P"FUS9VED(")9
M;W5R(&1E9F%U;'0@;F]T97!A9#HB"FUS9W-T<B`B57<@<W1A;F1A87)D(&YO
M=&ET:65B;V5K.B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI
M;F,Z-C4*;7-G:60@(EEO=7(@;F]T97!A9',Z(@IM<V=S='(@(E5W(&YO=&ET
M:65B;V5K96XZ(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C@@=&5M
M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C<*;7-G:60@(E]"86-K('1O($YO=&5P
M860B"FUS9W-T<B`B5&5?<G5G(&YA87(@;F]T:71I96)O96LB"@HC.B!T96UP
M;&%T97,O;65M;R]M96UO+FEN8SHU,2!T96UP;&%T97,O;&ES="]M96UO7VAE
M861E<G,N:6YC.C4P"FUS9VED(")?0V%T96=O<GDB"FUS9W-T<B`B7T-A=&5G
M;W)I92(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(U('1E;7!L871E
M<R]V:65W+VUE;6\N:6YC.C8T"FUS9VED(")?1&5L971E(@IM<V=S='(@(E9E
M<E]W:6ID97)E;B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(Q('1E
M;7!L871E<R]V:65W+VUE;6\N:6YC.C8P"FUS9VED(")?161I="(*;7-G<W1R
M(")?0F5W97)K96XB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M,C`*;7-G:60@(E]&:7)S="!,:6YE(@IM<V=S='(@(D5E<E]S=&4@<F5G96PB
M"@HC.B!L:6(O36YE;6\N<&AP.C(X,0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B
M"FUS9W-T<B`B7TEM<&]R="]%>'!O<G0B"@HC.B!L:6(O36YE;6\N<&AP.C(V
M-`IM<V=I9"`B7TQI<W0@3F]T97,B"FUS9W-T<B`B3F]T:71I97,@=V5E<E]G
M979E;B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<V"FUS9VED(")?37D@3F]T97!A
M9',B"FUS9W-T<B`B7TUI:FX@;F]T:71I96)O96ME;B(*"B,Z(&QI8B]-;F5M
M;RYP:'`Z,C8Y"FUS9VED(")?3F5W($YO=&4B"FUS9W-T<B`B7TYI975W92!N
M;W1I=&EE(@H*(SH@;&EB+TUN96UO+G!H<#HR.#8*;7-G:60@(E]0<FEN="(*
M;7-G<W1R(")!7V9D<G5K:V5N(@H*(SH@;&EB+TUN96UO+G!H<#HR-S(*;7-G
M:60@(E]396%R8V@B"FUS9W-T<B`B7UIO96ME;B(*"B,Z(&1A=&$N<&AP.CDQ
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B;F]T97,N8W-V
M(@IM<V=S='(@(FYO=&5S+F-S=B(*"B,Z(&1A=&$N<&AP.C,S('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,3@*;7-G:60@(G9.;W1E(@IM<V=S='(@(G9.
M;W1E(@H`````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE
M;6\O<&\O:F%?2E`N<&\`````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`R-S4S-P`Q,#0Q-S,V,C<T-@`P,3<U,34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!*87!A;F5S92!T
M<F%N<VQA=&EO;B!F;W(@36YE;6\N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO
M<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@
M=&AE('-A;64@;&EC96YS92!A<R!T:&4@36YE;6\@<&%C:V%G92X*(R!(:7)O
M;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N:G`^"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($UN96UO(#(N,"XQ
M7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P
M,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP,BTR,2`Q,CHP,"LP.3`P
M7&XB"B),87-T+51R86YS;&%T;W(Z($AI<F]M:2!+:6UU<F$@/&AI<F]M:4!T
M86,N='-U:W5B82YA8RYJ<%QN(@HB3&%N9W5A9V4M5&5A;3H@2F%P86YE<V4@
M/$Q,0&QI+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]4TA)1E1?2DE37&XB"B)#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O
M;&ES="]H96%D97(N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;F]T
M97,B"FUS9W-T<B`B)60@@X&#@B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N
M:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&-H87)A8W1E<G,B"FUS
M9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3@W"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(H-T@T"#
M0X.+("5S((+-@T.#DX-\@5N#9X*S@NJ"W(*U@KTB"@HC.B!N;W1E<&%D<RYP
M:'`Z.3D@;&EB+V)A<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`B)7,@@LR#@8."DJ`B"@HC.B!T96UP;&%T
M97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(C$@;F]T92(*;7-G<W1R("(Q
M((.!@X(B"@HC.B!M96UO+G!H<#HQ-C(*;7-G:60@(D%C8V5S<R!D96YI960@
M9&5L971I;F<@;F]T92XB"FUS9W-T<B`B@X&#@H+,C>V/G(+-@T&#3H-:@UB+
MD93;@K."ZH+<@K6"O8%"(@H*(SH@;65M;RYP:'`Z,3$R(&UE;6\N<&AP.C$Q
M-0IM<V=I9"`B06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N(@IM<V=S
M='(@(H.!@X*"S(C:DZZ"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0B(*"B,Z
M(&UE;6\N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI
M960@<V%V:6YG(&YO=&4@=&\@)7,N(@IM<V=S='(@(H.!@X*"S"`E<R""UH+,
ME=N1MH+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"(@H*(SH@;65M;RYP:'`Z
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@
M;F]T93H@)7,B"FUS9W-T<B`B@X&#@H+,E=N1MH+-@T&#3H-:@UB+D93;@K."
MZH+<@K6"O8%&)7,B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES
M96QE8W0N:6YC.C$P,PIM<V=I9"`B061D(&-A=&5G;W)Y(@IM<V=S='(@(I6J
ME]Z"\)+'B<$B"@HC.B!M96UO+G!H<#HU,@IM<V=I9"`B061D:6YG($$@3F5W
M($YO=&4B"FUS9W-T<B`BD%:+2X.!@X*"\)+'B<$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#0*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R("*/N(^'
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY
M.0IM<V=I9"`B079A:6QA8FQE($-A=&5G;W)I97,Z(@IM<V=S='(@(HYGEW")
MPI1<@LB5JI?>@48B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR."!T
M96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM<V=I9"`B0F%C:R!T;R!.;W1E
M<&%D(@IM<V=S='(@(H.!@X*2H(+)EM^"Z2(*"B,Z('1E;7!L871E<R]N;W1E
M<&%D<R]N;W1E<&%D<RYI;F,Z.3<*;7-G:60@(D)A8VL@=&\@3F]T97!A9"!/
M<'1I;VYS(@IM<V=S='(@(H.!@X*2H(+,@TF#=H-6@X>#DX+)EM^"Z2(*"B,Z
M(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*;7-G
M:60@(D-35B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU-"!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B0V%T96=O<GDB"FUS9W-T<B`BE:J7
MWB(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,C(*;7-G
M:60@(D-H86YG92(*;7-G<W1R("*5SXU8(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U"FUS9VED(")#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@86YD
M(&1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B@X&#@H+,E<""T8^'@L:57(ZF
M@TF#=H-6@X>#DX+PE<^-6(*W@NF!0B(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3,*;7-G:60@(D-H;V]S92!T:&4@;65M
M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RXB"FUS
M9W-T<B`BBE27=I5<CJ:"Q8+,E:J7WH+PD4F1\(*U@L2)NH*S@J*!0B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@IM<V=I9"`B0VAO;W-E('EO=7(@
M9&5F875L="!.;W1E<&%D+B(*;7-G<W1R("*#9H-T@TB#BX-G@LR#@8."DJ""
M\)%)D?""M8+$B;J"LX*B@4(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z,S(*;7-G:60@(D-L96%R($9O<FTB"FUS9W-T<B`BD_R7S8[FC\&"
MM2(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,3<@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-`HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.CDV"FUS9VED(")#<F5A=&4B"FUS9W-T
M<B`BC>R0K"(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C,U"FUS9VED
M(")#<F5A=&5D(@IM<V=S='(@(HWLD*R"LX+J@MR"M8*](@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q"FUS9VED(")$969A=6QT($YO=&5P860B"FUS
M9W-T<B`B@V:#=(-(@XN#9X+,@X&#@I*@(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,U"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM
M<V=S='(@(H-F@W2#2(.+@V>"S)7`@M&*[H^`@48B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I
M;VXZ(@IM<V=S='(@(H-F@W2#2(.+@V>"S)7`@M&5^XS\@48B"@HC.B!T96UP
M;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDU('1E;7!L871E<R]V:65W
M+VUE;6\N:6YC.C(U"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C8T"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`BC>V/G"(*"B,Z('1E;7!L871E<R]M96UO
M+VUE;6\N:6YC.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AI<R!N;W1E
M(@IM<V=S='(@(H.!@X*2H(+,D4F1\"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-0IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("*-?H^'(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHX-0IM<V=I9"`B1&5S
M8W)I<'1I;VXZ(@IM<V=S='(@(I#@EKZ!1B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(I5<
MCJ:#28-V@U:#AX.3(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C$@
M=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*;7-G:60@(D5D:70B"FUS9W-T
M<B`BE=*/5R(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN
M8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*
M;7-G<W1R("*5TH]7(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S
M+FEN8SHT-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z.#,*;7-G:60@(D5D:70@
M3F]T92(*;7-G<W1R("*#@8."@LR5TH]7(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M;65M;U]H96%D97)S+FEN8SHU-`IM<V=I9"`B161I="!C871E9V]R:65S(&%N
M9"!C;VQO<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]S
M=6UM87)I97,N:6YC.C$R"FUS9VED(")%;7!T>2!.;W1E(@IM<V=S='(@(HOS
M@LR#@8."(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.0IM<V=I
M9"`B17AP;W)T(@IM<V=S='(@(H-'@TZ#6(-\@5N#9R(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z.`IM<V=I9"`B17AP;W)T($YO=&5S(@IM<V=S
M='(@(H.!@X*"S(-'@TZ#6(-\@5N#9R(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHR,0IM<V=I9"`B1E]U;&P@5&5X="(*;7-G<W1R(")?59%3
ME;8B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T($YO=&5S+"!3=&5P("5D(@IM<V=S='(@(H.!
M@X*"S(-#@Y.#?(%;@V>!08-8@V6#8H-V("5D(@H*(SH@9&%T82YP:'`Z,3DS
M"FUS9VED("));7!O<G0O17AP;W)T($YO=&5S(@IM<V=S='(@(H.!@X*"S(-#
M@Y.#?(%;@V>!7H-'@TZ#6(-\@5N#9R(*"B,Z('1E;7!L871E<R]V:65W+VUE
M;6\N:6YC.C0S"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(HW%CTF5
MSXU8D_HB"@HC.B!L:6(O87!I+G!H<#HW,@IM<V=I9"`B36%X:6UU;2!.=6UB
M97(@;V8@3F]T97,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-3,*;7-G:60@
M(DUE;6\@5&5X="(*;7-G<W1R("*#@8."@LR3X)=E(@H*(SH@;65M;RYP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y:6YG("5S(@IM<V=S='(@
M(B5S()7/C5B2AB(*"B,Z(&QI<W0N<&AP.C,U"FUS9VED(")->2!.;W1E<R(*
M;7-G<W1R("*.A(+,@X&#@B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR
M,@IM<V=I9"`B3F5W($YO=&4B"FUS9W-T<B`BD%:+2X.!@X(B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C0P"FUS9VED(").97AT(@IM<V=S='(@
M(HZ?(@H*(SH@;&EB+V%P:2YP:'`Z,C`V"FUS9VED(").;R!I0V%L96YD87(@
M9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M96YU
M+FEN8SHW"FUS9VED(").;R!N;W1E<&%D<R!A<F4@879A:6QA8FQE('1O(&=U
M97-T<RXB"FUS9W-T<B`B@U&#6(-GEW""S(.!@X*2H(+-@J""Z(+<@KF"\8%"
M(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS9VED(").;R!N
M;W1E<R(*;7-G<W1R("*#@8."@LB"M2(*"B,Z('1E;7!L871E<R]L:7-T+V5M
M<'1Y+FEN8SHS"FUS9VED(").;R!N;W1E<R!M871C:"!T:&4@8W5R<F5N="!C
M<FET97)I82XB"FUS9W-T<B`BC+N-W8+,BNZ/@(+)B.J2=H*W@NF#@8."@LV"
MH(+H@MR"N8+Q@4(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3`Y"FUS
M9VED(").;R!N;W1E<R!T;R!D:7-P;&%Y(@IM<V=S='(@(I5<CJ:"MX+I@X&#
M@H+-@J""Z(+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D
M97)S+FEN8SHT-@IM<V=I9"`B3F]?=&4B"FUS9W-T<B`B7U2#@8."(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T"FUS9VED(").;W1E($-A=&5G;W)Y
M(@IM<V=S='(@(H.!@X*"S)6JE]XB"@HC.B!V:65W+G!H<#HX,"!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHY"FUS9VED(").;W1E($1E=&%I;',B"FUS9W-T
M<B`B@X&#@H+,C]J-UR(*"B,Z(&YO=&5P861S+G!H<#HQ,3`*;7-G:60@(DYO
M=&4@3&ES=',B"FUS9W-T<B`B@X&#@HCJEY<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,*;7-G:60@(DYO=&4@5&5X="(*;7-G<W1R("*#@8."@LR3
MX)=E(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*;7-G:60@(DYO
M=&4@7U1E>'0B"FUS9W-T<B`B7U2#@8."@LR3X)=E(@H*(SH@=FEE=RYP:'`Z
M-3<@;65M;RYP:'`Z-C`*;7-G:60@(DYO=&4@;F]T(&9O=6YD+B(*;7-G<W1R
M("*#@8."@JJ,J95T@JF"Z(+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VUE;6\O
M;65M;RYI;F,Z,S0*;7-G:60@(DYO=&5?<&%D(@IM<V=S='(@(E]0@X&#@I*@
M(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHW.0IM<V=I
M9"`B3F]T97!A9"=S(&YA;64Z(@IM<V=S='(@(H.!@X*2H(+,EKR13X%&(@H*
M(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHV,0IM<V=I9"`B
M3F]T97!A9',B"FUS9W-T<B`B@X&#@I*@(@H*(SH@;F]T97!A9',N<&AP.C,S
M"FUS9VED(").;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R("*#
M@8."DJ""R8+-EKR13X*JE4N7=H+%@K>!0B(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HS"FUS9VED(").;W1E<R!3=6UM87)Y(@IM<V=S='(@(H.!@X**
M5)=V(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,`IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R("*"
MNX+,D;R"S(-)@W:#5H.'@Y,B"@HC.B!L:6(O87!I+G!H<#HQ.#,@;&EB+V%P
M:2YP:'`Z,C<T(&QI8B]A<&DN<&AP.C,T-2!L:6(O87!I+G!H<#HS-S0*;7-G
M:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(H-!@TZ#6H-8BY&4VR(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#(*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(H-!@TZ#6H-8C*`B"@HC.B!T96UP;&%T
M97,O;&ES="]H96%D97(N:6YC.C4@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN
M8SHV"FUS9VED(")2969R97-H($QI<W0B"FUS9W-T<B`BC<257(ZF(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*;7-G
M:60@(E)E;6]V92!C871E9V]R>2(*;7-G<W1R("*5JI?>@LR-[8^<(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S
M970B"FUS9W-T<B`B@XJ#6H-B@V<B"@HC.B!T96UP;&%T97,O;65M;R]M96UO
M+FEN8SHU-@IM<V=I9"`B4V%V92(*;7-G<W1R("*5VY&V(@H*(SH@<V5A<F-H
M+G!H<#HQ-R!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-"!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z,S$*;7-G:60@(E-E87)C:"(*;7-G<W1R
M("*,GXWU(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@(E-E87)C:"!297-U;'1S
M(@IM<V=S='(@(HR?C?6,BXG*(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC.C$W"FUS9VED(")396%R8V@@4V-O<&4B"FUS9W-T<B`BC)^-]93-
MB,TB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z.0IM<V=I9"`B
M4V5A<F-H(%]497AT(@IM<V=S='(@(E]4C)^-]96VCIJ7\2(*"B,Z('1E;7!L
M871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C<*;7-G:60@(E-E;&5C="!A
M(&YO=&5P860B"FUS9W-T<B`B@X&#@I*@@LR129'P(@H*(SH@=&5M<&QA=&5S
M+VUE;G4N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]T97!A9',@
M=&\@9&ES<&QA>3HB"FUS9W-T<B`BE5R.IH*W@NF#@8."@LV"H(+H@MR"N8+Q
M@4(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")3
M96QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(H-'@TZ#6(-\@5N#
M9X+,C&".KH+PD4F1\(%&(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHS-PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T
M<B`B@T.#DX-\@5N#9X*W@NF#=(-`@T.#BX+PD4F1\(%&(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H92!F;W)M
M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("*#7(%;@UB#=(-`@T.#
MBX+,C&".KH+PD4F1\(%&(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM
M87)Y<V5L96-T+FEN8SHQ,#D*;7-G:60@(E-E;&5C=&5D($-A=&5G;W)I97,Z
M(@IM<V=S='(@(I%)D?""LX+J@KV5JI?>@48B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,S@*;7-G:60@(E-H;W<@86-T:6]N(&)U='1O;G,_(@IM<V=S
M='(@(I.NC>R#>X->@Y."\)5<CJ:!2"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HT,0IM<V=I9"`B4VAO=R!N;W1E<&%D(&YA;64_(@IM<V=S='(@(H.!
M@X*2H(+,EKR13X+PE5R.IH%((@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C0T"FUS9VED(")3:&]W(&YO=&5S(&9R;VT@=&AE<V4@8V%T96=O<FEE<R(*
M;7-G<W1R("*"L8+,E:J7WH+,@X&#@H+PE5R.IB(*"B,Z('1E;7!L871E<R]L
M:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3`*;7-G:60@(E-O<G0@8GD@0V%T96=O
M<GDB"FUS9W-T<B`BE:J7WH+%E<""T9'6@J8B"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C0V"FUS9VED(")3;W)T(&)Y($YO=&4@5&5X
M="(*;7-G<W1R("*3X)=E@L65P(+1D=:"IB(*"B,Z(&UE;6\N<&AP.C$S-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R""R97;D;:"LX+J@MR"M8*]@4(B"@HC
M.B!M96UO+G!H<#HQ-3D*;7-G:60@(E1H92!N;W1E('=A<R!D96QE=&5D+B(*
M;7-G<W1R("*#@8."@LV-[8^<@K."ZH+<@K6"O8%"(@H*(SH@;F]T97!A9',N
M<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<
M(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E<R(*;7-G<W1R("*#@8."(%PB)7-<
M(B""S8WLD*R"Q8*K@MR"N8+Q@L6"M8*]@48@)7,B"@HC.B!N;W1E<&%D<RYP
M:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB
M(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(H.!@X(@7"(E<UPB((+-C>R0
MK(*S@NJ"W(*U@KV!0B(*"B,Z(&YO=&5P861S+G!H<#HX-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B@X&#@B!<(B5S7"(@@LV-[8^<@K."ZH+<@K6"O8%"(@H*
M(SH@;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N
M;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B@X&#@B!<
M(B5S7"(@@LV5VY&V@K."ZH+<@K6"O8%"(@H*(SH@9&%T82YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(H-F@5N#7H+,@T.#DX-\@5N#9Y*&
M@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%&)7,B"@HC.B!L:6(O87!I+G!H<#HR
M,#`*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")V3F]T92""S(-#@Y.#
M?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0B(*"B,Z(&QI8B]A<&DN
M<&AP.C,Y,PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@=DYO=&4@9&%T82XB"FUS9W-T<B`B=DYO=&4@@LR#0X.3@WR!6X-GDH:"
MR8-'@XF!6X*JE*V0MH*U@MR"M8*]@4(B"@HC.B!M96UO+G!H<#HQ-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG
M('1H92!N;W1E.B`E<R(*;7-G<W1R("*#@8."@LR-[8^<DH:"R8-'@XF!6X*J
ME*V0MH*U@MR"M8*]@48E<R(*"B,Z(&UE;6\N<&AP.C$S,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E
M.B`E<R(*;7-G<W1R("*#@8."@LR5VY&VDH:"R8-'@XF!6X*JE*V0MH*U@MR"
MM8*]@48E<R(*"B,Z('9I97<N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!V:65W:6YG('1H:7,@;F]T97!A9#H@)7,B
M"FUS9W-T<B`B@X&#@H+,E5R.II*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%&
M)7,B"@HC.B!D871A+G!H<#HW.0IM<V=I9"`B5&AE<F4@=V5R92!N;R!M96UO
M<R!T;R!E>'!O<G0N(@IM<V=S='(@(H-'@TZ#6(-\@5N#9X*W@NF#@8."@JJ"
MH(+H@MR"N8+Q@4(B"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H:7,@9FEL
M92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B@K&"S(Q@CJZ"
MS8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&YO=&5P861S+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(CH@)7,B"FUS9W-T<B`BC>V/G(+%@JN"W(*Y@O$@7"(E<UPB.B`E<R(*"B,Z
M('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4X"B,L(&9U>GIY"FUS9VED(")5
M;F1O(&-H86YG97,B"FUS9W-T<B`BE<^-6([FC\&"M2(*"B,Z('1E;7!L871E
M<R]V:65W+VUE;6\N:6YC.C$V('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R
M:65S+FEN8SHQ-`HC.B!L:6(O36YE;6\N<&AP.C(P-B!L:6(O36YE;6\N<&AP
M.C(P-R!L:6(O36YE;6\N<&AP.C(R,2!L:6(O36YE;6\N<&AP.C(R,@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3`U"FUS9VED(")5;F9I;&5D(@IM<V=S
M='(@(I:BD*Z7G2(*"B,Z(&QI8B]A<&DN<&AP.C(S-B!L:6(O87!I+G!H<#HS
M,#D@;&EB+V%P:2YP:'`Z-#`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(H-4@WR!
M6X-G@K."ZH+$@J*"R(*B($-O;G1E;G0M5'EP92""Q8*W@4(B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C(R"FUS9VED(")7:&EC:"!.;W1E<&%D
M('-H;W5L9"!T:&4@;F]T97,@8F4@861D960@=&\_(@IM<V=S='(@(H+'@LR#
M@8."DJ""R9+'B<&"M8+<@K>"J8%((@H*(SH@9&%T82YP:'`Z-#(@9&%T82YP
M:'`Z,3(U(&UE;6\N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!N;W1E<RXB
M"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T
M97!A9"`E<RXB"FUS9W-T<B`B@J""R(*]@LF"S8.!@X*2H"`E<R""\)5<CJ:"
MMX+I@T&#3H-:@UB,H(*J@J""Z(+<@KF"\8%"(@H*(SH@;F]T97!A9',N<&AP
M.C8U"FUS9VED(")9;W4@;75S="!S96QE8W0@82!N;W1E<&%D('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(HWMCYR"MX+I@X&#@I*@@O"129'P@K6"Q(FZ@K."
MHH%"(@H*(SH@=&5M<&QA=&5S+W!R969S+VYO=&5P861S96QE8W0N:6YC.C$P
M"FUS9VED(")9;W5R(&1E9F%U;'0@;F]T97!A9#HB"FUS9W-T<B`B@J""R(*]
M@LR#9H-T@TB#BX-G@LR#@8."DJ"!1B(*"B,Z('1E;7!L871E<R]N;W1E<&%D
M<R]N;W1E<&%D<RYI;F,Z-C4*;7-G:60@(EEO=7(@;F]T97!A9',Z(@IM<V=S
M='(@(H*@@LB"O8+,@X&#@I*@@48B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO
M+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM<V=I9"`B7T)A
M8VL@=&\@3F]T97!A9"(*;7-G<W1R(")?0H.!@X*2H(+)EM^"Z2(*"B,Z('1E
M;7!L871E<R]M96UO+VUE;6\N:6YC.C4Q('1E;7!L871E<R]L:7-T+VUE;6]?
M:&5A9&5R<RYI;F,Z-3`*;7-G:60@(E]#871E9V]R>2(*;7-G<W1R(")?0Y6J
ME]XB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-2!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHV-`IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")?1(WM
MCYPB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHV,`IM<V=I9"`B7T5D:70B"FUS9W-T<B`B7T65TH]7
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"FUS9VED(")?
M1FER<W0@3&EN92(*;7-G<W1R(")?1HW%CXF"S(US(@H*(SH@;&EB+TUN96UO
M+G!H<#HR.#$*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(E])@T.#
MDR^#08-%@V<B"@HC.B!L:6(O36YE;6\N<&AP.C(V-`IM<V=I9"`B7TQI<W0@
M3F]T97,B"FUS9W-T<B`B7TR#@8."B.J7ER(*"B,Z(&QI8B]-;F5M;RYP:'`Z
M,C<V"FUS9VED(")?37D@3F]T97!A9',B"FUS9W-T<B`B7TV.A(+,@X&#@I*@
M(@H*(SH@;&EB+TUN96UO+G!H<#HR-CD*;7-G:60@(E].97<@3F]T92(*;7-G
M<W1R(")?3I!6BTN#@8."(@H*(SH@;&EB+TUN96UO+G!H<#HR.#8*;7-G:60@
M(E]0<FEN="(*;7-G<W1R(")?4(CSC?PB"@HC.B!L:6(O36YE;6\N<&AP.C(W
M,@IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?4XR?C?4B"@HC.B!D871A+G!H
M<#HY,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(FYO=&5S
M+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,R!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")V3F]T92(*;7-G<W1R
M(")?5(.!@X(B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]M;F5M;R]P;R]B9U]"1RYP;P``````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(W-S<R`#$P-#$W,S8R
M-S0V`#`Q-S0W,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````C($)U;&=A<FEA;B!T<F%N<VQA=&EO;G,@9F]R($UN96UO('!A
M8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`R($AO<F1E(%!R;VIE8W0*(R!4
M:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS
M92!A<R!T:&4@5VAU<',@<&%C:V%G92X*(R!-:7)O<VQA=B!096YD978@/&UI
M<F]`8WEB97)S:&%D92YU<SXL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B
M"B)0<F]J96-T+4ED+59E<G-I;VXZ($UN96UO(#(N,"UC=G-<;B(*(E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`R+3$Q+3$Y(#(P.C0T+3`U,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N
M=7,^7&XB"B),86YG=6%G92U496%M.B!"1R!I,3AN0&QI<W1S+FAO<F1E+F]R
M9UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U#4#$R-3%<;B(*(D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI
M;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!N;W1E<R(*;7-G<W1R("(E
M9"#AY>OEYNKH(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC
M.B!D871A+G!H<#HQ.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S
M=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B)7,@].#IZR#AY?CE(.CL
M[^[P\NCPX.T@\_'OY?CM[B(*"B,Z(&YO=&5P861S+G!H<#HY.2!L:6(O8F%S
M92YP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO
M=&5P860B"FUS9W-T<B`BP>7KY>;MZ.HB"@HC.B!T96UP;&%T97,O;&ES="]H
M96%D97(N:6YC.C,*;7-G:60@(C$@;F]T92(*;7-G<W1R("(Q(.'EZ^7FZN`B
M"@HC.B!M96UO+G!H<#HQ-C(*;7-G:60@(D%C8V5S<R!D96YI960@9&5L971I
M;F<@;F]T92XB"FUS9W-T<B`BSO+JX.?@[2#D[O'R^N\@Y^`@Z.?R\.CBX.WE
M(.W@(.'EZ^7FZN`B"@HC.B!M96UO+G!H<#HQ,3(@;65M;RYP:'`Z,3$U"B,L
M(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&UO=FEN9R!T:&4@;F]T92XB
M"FUS9W-T<B`BSO+JX.?@[2#D[O'R^N\@Y^`@[_#E[.#UXN#MY2#MX"#AY>OE
MYNK@(@H*(SH@;65M;RYP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N(@IM<V=S='(@
M(L[RZN#GX.T@Y.[Q\OKO(.?@(.CG\O#HXN#MY2#MX"#AY>OEYNK@(@H*(SH@
M;65M;RYP:'`Z.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%C8V5S
M<R!D96YI960@<V%V:6YG(&YO=&4Z("5S(@IM<V=S='(@(L[RZN#GX.T@Y.[Q
M\OKO(.?@(.CG\O#HXN#MY2#MX"#AY>OEYNK@(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#,*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!C871E9V]R>2(*;7-G<W1R("+*X/+EX^[PZ/\B"@HC.B!M96UO+G!H
M<#HU,@IM<V=I9"`B061D:6YG($$@3F5W($YO=&4B"FUS9W-T<B`BQ.[AX.+_
M[>4@[>`@[>[BX"#AY>OEYNK@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`BS>#PX/'RXN#YZ"(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3D*;7-G
M:60@(D%V86EL86)L92!#871E9V]R:65S.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHV-PIM<V=I9"`B0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(L[A\.#R[>X@
MXB#AY>OEYNWHZN`B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.CDW"B,L(&9U>GIY"FUS9VED(")"86-K('1O($YO=&5P860@3W!T:6]N
M<R(*;7-G<W1R("+.X?#@\NWN(.(@X>7KY>;MZ.K@(@H*(SH@9&%T82YP:'`Z
M,S(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B0U-6(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4T('1E;7!L871E<R]V:65W+VUE;6\N
M:6YC.C$U"FUS9VED(")#871E9V]R>2(*;7-G<W1R("+*X/+EX^[PZ/\B"@HC
M.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C(R"FUS9VED(")#
M:&%N9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U
M"FUS9VED(")#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@86YD(&1I<W!L87D@
M;W!T:6]N<RXB"FUS9W-T<B`BT_'RX.WNXN7RY2#O\.7D[^[WZ/+@[>CRY2#Q
M[O#RZ/#@[>4@Z"#N[_;HZ"#MX"#DZ/'OZ^7_+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@
M(D-H;V]S92!T:&4@;65M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE('-U
M;6UA<GD@=FEE=RXB"FUS9W-T<B`BQ.`@\>4@[^[JX.?BX/(@Z^@@Y^#QXN7R
MY>WH(.KNZ^[MZ"#B(.[A[N'YY>WH__(@Z.?CZ^7D/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,@HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('EO=7(@
M9&5F875L="!.;W1E<&%D+B(*;7-G<W1R("+"X/CH__(@X>7KY>;MZ.H@[^X@
M[^[D\.#GX>CPX.WE.B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN
M8SHS,@IM<V=I9"`B0VQE87(@1F]R;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.C$W('1E;7!L871E<R]N;W1E<&%D
M<R]N;W1E<&%D<RYI;F,Z.30*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P
M861S+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(@IM<V=S='(@(M?@
M\?+E[2(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C,U"FUS9VED(")#
M<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,0HC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!.;W1E<&%D(@IM<V=S='(@(L+@
M^.C_\B#AY>OEYNWHZB#O[B#O[N3PX.?AZ/#@[>4Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,U"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R
M:6$Z(@IM<V=S='(@(LKPZ/+E\.CH(.?@(/'N\/+H\.#MY2#O[B#O[N3PX.?A
MZ/#@[>4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V"FUS9VED(")$
M969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R("+/[O'NZN`@[>`@
M\>[P\NCPX.WE(._N(._NY/#@Y^'H\.#MY3HB"@HC.B!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.CDU('1E;7!L871E<R]V:65W+VUE;6\N:6YC
M.C(U"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C8T"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`BR.?R\.CI(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI
M;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!T:&ES(&YO=&4B"FUS9W-T
M<B`BR.?R\.CI(.'EZ^7FZN`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#4*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`BS>#LX.O_XN#YZ"(*"B,Z
M('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*;7-G:60@(D1E
M<V-R:7!T:6]N.B(*;7-G<W1R("+.[^CQX.WHY3HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M("+$Z/'OZ^7I(,[O]NCH(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,C$@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*;7-G:60@(D5D:70B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-"!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(D5D:70@3F]T
M92(*;7-G<W1R("+1[^CQ^NH@\2#AY>OEYNKH(@H*(SH@=&5M<&QA=&5S+VQI
M<W0O;65M;U]H96%D97)S+FEN8SHU-`IM<V=I9"`B161I="!C871E9V]R:65S
M(&%N9"!C;VQO<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M
M;U]S=6UM87)I97,N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!.;W1E
M(@IM<V=S='(@(L7J\>_N\/(@X>7KY>;JZ"(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,3D*(RP@9G5Z>GD*;7-G:60@(D5X<&]R="(*;7-G<W1R
M("+%ZO'O[O#R(.'EZ^7FZN@B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C@*;7-G:60@(D5X<&]R="!.;W1E<R(*;7-G<W1R("+%ZO'O[O#R(.'E
MZ^7FZN@B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(D9?=6QL(%1E>'0B"FUS9W-T<B`BS_KKY>T@\N7J\?(B
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="!.;W1E<RP@4W1E<"`E9"(*;7-G<W1R
M("+([._N\/(@X>7KY>;JZ"(*"B,Z(&1A=&$N<&AP.C$Y,PIM<V=I9"`B26UP
M;W)T+T5X<&]R="!.;W1E<R(*;7-G<W1R("+([._N\/(OQ>KQ[^[P\B#MX"#A
MY>OEYNKH(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-#,*;7-G:60@
M(DQA<W0@36]D:69I960B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-S(*
M;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($YO=&5S(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C4S"FUS9VED(")-96UO(%1E>'0B"FUS9W-T<B`BTN7J\?(B
M"@HC.B!M96UO+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GEI
M;F<@)7,B"FUS9W-T<B`BS.[DZ/3H]NCPX.D@)7,B"@HC.B!L:7-T+G!H<#HS
M-0HC+"!F=7IZ>0IM<V=I9"`B37D@3F]T97,B"FUS9W-T<B`BS.[_\B#!Y>OE
MYNWHZB(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR,@IM<V=I9"`B3F5W
M($YO=&4B"FUS9W-T<B`BS>[BX"#AY>OEYNK@(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B3F5X="(*;7-G<W1R
M("+!Y>OEYNK@(/+EZO'R(@H*(SH@;&EB+V%P:2YP:'`Z,C`V"FUS9VED(").
M;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M96YU+FEN8SHW"FUS9VED(").;R!N;W1E<&%D<R!A<F4@879A
M:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI
M<W0O:&5A9&5R+FEN8SHS"FUS9VED(").;R!N;W1E<R(*;7-G<W1R("+-_^S@
M(.'EZ^7FZN@B"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z,PIM<V=I
M9"`B3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#D*;7-G:60@(DYO
M(&YO=&5S('1O(&1I<W!L87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI
M<W0O;65M;U]H96%D97)S+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B3F]?=&4B
M"FUS9W-T<B`BP>7KY>;MZ.HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0*;7-G:60@(DYO=&4@0V%T96=O<GDB"FUS9W-T<B`BP>7KY>;JX"#JX/+E
MX^[PZ/\B"@HC.B!V:65W+G!H<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHY"FUS9VED(").;W1E($1E=&%I;',B"FUS9W-T<B`BP>7KY>;JX"#DY?+@
MZ>OH(@H*(SH@;F]T97!A9',N<&AP.C$Q,`IM<V=I9"`B3F]T92!,:7-T<R(*
M;7-G<W1R("+1[^CQ^NH@X>7KY>;JZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,PIM<V=I9"`B3F]T92!497AT(@IM<V=S='(@(L'EZ^7FZN`@\N7J
M\?(B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!F=7IZ>0IM
M<V=I9"`B3F]T92!?5&5X="(*;7-G<W1R("+!Y>OEYNK@(/+EZO'R(@H*(SH@
M=FEE=RYP:'`Z-3<@;65M;RYP:'`Z-C`*;7-G:60@(DYO=&4@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHS-`HC
M+"!F=7IZ>0IM<V=I9"`B3F]T95]P860B"FUS9W-T<B`BP>7KY>;MZ.HB"@HC
M.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C<Y"FUS9VED(").
M;W1E<&%D)W,@;F%M93HB"FUS9W-T<B`BR.SE(.W@(.'EZ^7F[>CJX#HB"@HC
M.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"FUS9VED(").
M;W1E<&%D<R(*;7-G<W1R("+!Y>OEYNWH]N@B"@HC.B!N;W1E<&%D<RYP:'`Z
M,S,*(RP@9G5Z>GD*;7-G:60@(DYO=&5P861S(&UU<W0@:&%V92!A(&YA;64N
M(@IM<V=S='(@(LCLY2#MX"#AY>OEYNWHZN`Z(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS
M9W-T<B`BP>7KY>;JX"#JX/+EX^[PZ/\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P"FUS9VED(")/=&AE
M<B!/<'1I;VYS(@IM<V=S='(@(L3P\^/H(,[O]NCH(@H*(SH@;&EB+V%P:2YP
M:'`Z,3@S(&QI8B]A<&DN<&AP.C(W-"!L:6(O87!I+G!H<#HS-#4@;&EB+V%P
M:2YP:'`Z,S<T"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C@R"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]H
M96%D97(N:6YC.C4@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHV"FUS9VED
M(")2969R97-H($QI<W0B"FUS9W-T<B`BSN_PY?'MZ"#Q[^CQ^NK@(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!C871E9V]R>2(*;7-G<W1R("+!Y>OEYNK@
M(.K@\N7C[O#H_R(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI
M;F,Z.38*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M96UO+VUE;6\N:6YC.C4V"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S='(@
M(L_NY.7KY>TB"@HC.B!S96%R8V@N<&AP.C$W('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHT('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS,0IM
M<V=I9"`B4V5A<F-H(@IM<V=S='(@(M+Z\/'H(@H*(SH@;&ES="YP:'`Z-3<*
M;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(M#EY_/K\N#RZ"#N\B#R
M^O#QY>WE\NXB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3<*
M;7-G:60@(E-E87)C:"!38V]P92(*;7-G<W1R("+.X?7BX/(@[>`@\OKP\>7M
MY2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHY"B,L(&9U>GIY
M"FUS9VED(")396%R8V@@7U1E>'0B"FUS9W-T<B`BTN7J\?(@Y^`@\OKP\>7M
MY2(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C<*;7-G
M:60@(E-E;&5C="!A(&YO=&5P860B"FUS9W-T<B`BR.?AY?#H(.'EZ^7F[>CJ
M(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@;F]T97!A9',@=&\@9&ES<&QA>3HB"FUS9W-T<B`BR.?AY?#H(.'E
MZ^7F[>CJ(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R
M("+(Y^'E\.7RY2#HY_+N]^WHZN`@Y^`@Z.SO[O#R.B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,S<*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T
M;R!I;7!O<G0Z(@IM<V=S='(@(LCGX>7PY?+E(/3@Z>L@Y^`@Z.SO[O#R.B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS
M9W-T<B`BR.?AY?#E\N4@].[P[.#R+"#J^NP@ZN[I\NX@Y.`@\>4@Y>KQ[^[P
M\NCPX#HB"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N
M:6YC.C$P.0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T960@0V%T96=O<FEE<SHB
M"FUS9W-T<B`BR.?AY?#H(,K@\N7C[O#H_R(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HS.`IM<V=I9"`B4VAO=R!A8W1I;VX@8G5T=&]N<S\B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0Q"B,L(&9U>GIY"FUS
M9VED(")3:&]W(&YO=&5P860@;F%M93\B"FUS9W-T<B`BR.SE(.W@(.'EZ^7F
M[>CJX#HB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#0*;7-G:60@(E-H
M;W<@;F]T97,@9G)O;2!T:&5S92!C871E9V]R:65S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3`*;7-G:60@(E-O
M<G0@8GD@0V%T96=O<GDB"FUS9W-T<B`BT>[P\NCPX.D@[^X@ZN#RY>/N\.C_
M(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-@HC+"!F
M=7IZ>0IM<V=I9"`B4V]R="!B>2!.;W1E(%1E>'0B"FUS9W-T<B`BP>7KY>;J
MX"#RY>KQ\B(*"B,Z(&UE;6\N<&AP.C$S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!M
M96UO+G!H<#HQ-3D*;7-G:60@(E1H92!N;W1E('=A<R!D96QE=&5D+B(*;7-G
M<W1R("+!Y>OEYNK@\N`@X>7XY2#HY_+PZ/+@+B(*"B,Z(&YO=&5P861S+G!H
M<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@
M7"(E<UPB(&-O=6QD;B=T(&)E(&-R96%T960Z("5S(@IM<V=S='(@(L'EZ^7F
M[>CJX"!<(B5S7"(@X>7XY2#Q^N?DX.3E[2XB"@HC.B!N;W1E<&%D<RYP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA
M<R!B965N(&-R96%T960N(@IM<V=S='(@(L'EZ^7F[>CJX"!<(B5S7"(@X>7X
MY2#Q^N?DX.3E[2XB"@HC.B!N;W1E<&%D<RYP:'`Z.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(L'EZ^7F[>CJX"!<(B5S7"(@X>7XY2#O\.7LX/7MX/(N(@H*
M(SH@;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N
M;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`BP>7KY>;M
MZ.K@(%PB)7-<(B#AY?CE(.?@[^CQX.TN(@H*(SH@9&%T82YP:'`Z,3@T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(.CL
M[^[P\B#MX"#DX.WMZ/+E+B(*"B,Z(&QI8B]A<&DN<&AP.C(P,`HC+"!F=7IZ
M>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.SO[O#R(.W@(.3@
M[>WH\N4N(@H*(SH@;&EB+V%P:2YP:'`Z,SDS"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!V3F]T92!D871A+B(*
M;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ/+E+B(*"B,Z(&UE
M;6\N<&AP.C$U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R("+#
M\.7XZN`@[_#H(._PY>SE\?+BX.WE(.W@(.'EZ^7FZN#RX"XB"@HC.B!M96UO
M+G!H<#HQ,S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!S879I;F<@=&AE(&YO=&4Z("5S(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@Y^#OZ/'@(.W@(.'EZ^7FZN#RX"XB"@HC.B!V:65W+G!H<#HT-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H
M(.?@[^CQX"#MX"#AY>OEYNK@\N`N(@H*(SH@9&%T82YP:'`Z-SD*;7-G:60@
M(E1H97)E('=E<F4@;F\@;65M;W,@=&\@97AP;W)T+B(*;7-G<W1R("+-_^S@
M(.'EZ^7FZN@@Y^`@Y>KQ[^[P\BXB"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@
M(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
M(@H*(SH@;F]T97!A9',N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H
M(.CG\O#HXN#MY2!<(B5S7"(Z("5S+B(*"B,Z('1E;7!L871E<R]M96UO+VUE
M;6\N:6YC.C4X"FUS9VED(")5;F1O(&-H86YG97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,38@=&5M<&QA=&5S+VQI<W0O;65M
M;U]S=6UM87)I97,N:6YC.C$T"B,Z(&QI8B]-;F5M;RYP:'`Z,C`V(&QI8B]-
M;F5M;RYP:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z,C(Q(&QI8B]-;F5M;RYP:'`Z
M,C(R"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#4*;7-G:60@(E5N9FEL
M960B"FUS9W-T<B`BS>7O[N_ZZ^WE[2(*"B,Z(&QI8B]A<&DN<&AP.C(S-B!L
M:6(O87!I+G!H<#HS,#D@;&EB+V%P:2YP:'`Z-#`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,@IM<V=I9"`B5VAI
M8V@@3F]T97!A9"!S:&]U;&0@=&AE(&YO=&5S(&)E(&%D9&5D('1O/R(*;7-G
M<W1R("+*^NP@ZN[I(.'EZ^7F[>CJ(.3@(.'ZY.4@Y.[AX.+E[>`@X>7KY>;J
MX/+@/R(*"B,Z(&1A=&$N<&AP.C0R(&1A=&$N<&AP.C$R-2!M96UO+G!H<#HS
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O
M(&-R96%T92!M;W)E('1H86X@)60@;F]T97,N(@IM<V=S='(@(B(*"B,Z('9I
M97<N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@)7,N(@IM<V=S='(@
M(B(*"B,Z(&YO=&5P861S+G!H<#HV-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T
M(&$@;F]T97!A9"!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+2\/_AXN`@Y.`@
MZ.?AY?#E\N4@X>7KY>;MZ.HL(.KNZ?+N(.3@(.'ZY.4@Z.?R\.CR+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]N;W1E<&%D<V5L96-T+FEN8SHQ,`IM<V=I9"`B
M66]U<B!D969A=6QT(&YO=&5P860Z(@IM<V=S='(@(L+@^.C_\B#AY>OEYNWH
MZB#O[B#O[N3PX.?AZ/#@[>4Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHV-0IM<V=I9"`B66]U<B!N;W1E<&%D<SHB"FUS9W-T<B`B
MPN#XZ/+E(.'EZ^7F[>CVZ#HZ(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI
M;F,Z,C@@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C<*(RP@9G5Z>GD*;7-G
M:60@(E]"86-K('1O($YO=&5P860B"FUS9W-T<B`BSN'PX/+M[B#B(.'EZ^7F
M[>CJX"(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4Q('1E;7!L871E
M<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3`*(RP@9G5Z>GD*;7-G:60@(E]#
M871E9V]R>2(*;7-G<W1R("+*X/+EX^[PZ/\B"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHR-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-`HC+"!F
M=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHV,`IM<V=I9"`B7T5D:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C(P"FUS9VED(")?1FER<W0@3&EN92(*;7-G<W1R
M("(B"@HC.B!L:6(O36YE;6\N<&AP.C(X,0HC+"!F=7IZ>0IM<V=I9"`B7TEM
M<&]R="]%>'!O<G0B"FUS9W-T<B`BR.SO[O#R+\7J\>_N\/(B"@HC.B!L:6(O
M36YE;6\N<&AP.C(V-`HC+"!F=7IZ>0IM<V=I9"`B7TQI<W0@3F]T97,B"FUS
M9W-T<B`BT>_H\?KJ(/$@X>7KY>;JZ"(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<V
M"B,L(&9U>GIY"FUS9VED(")?37D@3F]T97!A9',B"FUS9W-T<B`BS.[_\B#!
MY>OEYNWHZB(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED
M(")?3F5W($YO=&4B"FUS9W-T<B`BS>[BX"#AY>OEYNK@(@H*(SH@;&EB+TUN
M96UO+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@(E]0<FEN="(*;7-G<W1R("+.
M\N_E]^#RX.DB"@HC.B!L:6(O36YE;6\N<&AP.C(W,@HC+"!F=7IZ>0IM<V=I
M9"`B7U-E87)C:"(*;7-G<W1R("+2^O#QZ"(*"B,Z(&1A=&$N<&AP.CDQ('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B;F]T97,N8W-V(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,S('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(G9.;W1E(@IM<V=S='(@(L'EZ^7F
M[>CJ(@H````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W!O
M+V9R7T92+G!O````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,S$T-C4`,3`T,3<S-C(W-#8`,#$W-3(S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@=')A;G-L871I;VX@;V8@
M9G)?1E(N<&\@=&\@1G)A;F-A:7,*(R!-;F5M;R!&<F5N8V@@=')A;G-L871I
M;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`R(%1H:65R<GD@5&AO;6%S(#QT:&EE
M<G)Y0'!O;7!O+FYE=#XN"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N
M9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($UN96UO('!A8VMA9V4N"B,@
M5&AI97)R>2!4:&]M87,@/'1H:65R<GE`<&]M<&\N;F5T/BP@,C`P,BX*(R!"
M96YO:70@4W0M06YD<ND@/&)E;D!B96YO:71S="UA;F1R92YN970^+"`R,#`T
M+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!F
M<E]&4EQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R
M*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,3(M,#<@,34Z,C`M
M,#4P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!"96YO:70@4W0M06YD<F4@/&)E
M;D!B96YO:71S="UA;F1R92YN970^7&XB"B),86YG=6%G92U496%M.B!&<F%N
M8V%I<R`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ
M(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E3
M3RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<
M;B(*(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN(#X@,2D[
M7&XB"B)8+4=E;F5R871O<CH@2T)A8F5L(#$N,RXQ7&XB"@HC.B!T96UP;&%T
M97,O;&ES="]H96%D97(N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M;F]T97,B"FUS9W-T<B`B)60@;F]T97,B"@HC.B!T96UP;&%T97,O;65M;R]M
M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!C:&%R86-T97)S
M(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R("(E
M<R!F:6-H:65R<R!I;7!O<G3I<R!A=F5C('-U8V/H<R(*"B,Z(&YO=&5P861S
M+G!H<#HY.2!L:6(O8F%S92YP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@3F]T97!A9"(*;7-G<W1R(")";&]C+6YO=&5S(&1E("5S(@H*(SH@
M=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS9VED("(Q(&YO=&4B"FUS
M9W-T<B`B,2!N;W1E(@H*(SH@;65M;RYP:'`Z,38R"FUS9VED(")!8V-E<W,@
M9&5N:65D(&1E;&5T:6YG(&YO=&4N(@IM<V=S='(@(E-U<'!R97-S:6]N(&1E
M(&QA(&YO=&4@:6YT97)D:71E+B(*"B,Z(&UE;6\N<&AP.C$Q,B!M96UO+G!H
M<#HQ,34*;7-G:60@(D%C8V5S<R!D96YI960@;6]V:6YG('1H92!N;W1E+B(*
M;7-G<W1R(")!8V/H<R!R969U<^D@96X@9.EP;&'G86YT(&QA(&YO=&4N(@H*
M(SH@;65M;RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E
M;FEE9"!S879I;F<@;F]T92!T;R`E<RXB"FUS9W-T<B`B26YT97)D:6-T:6]N
M(&0G96YR96=I<W1R97(@;&$@;F]T92!V97)S("5S+B(*"B,Z(&UE;6\N<&AP
M.C@R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D
M('-A=FEN9R!N;W1E.B`E<R(*;7-G<W1R("));G1E<F1I8W1I;VX@9"=E;G)E
M9VES=')E<B!L82!N;W1E('9E<G,@)7,N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#,*;7-G:60@(D%D9"!C871E9V]R
M>2(*;7-G<W1R(")!:F]U=&5R('5N92!C873I9V]R:64B"@HC.B!M96UO+G!H
M<#HU,@IM<V=I9"`B061D:6YG($$@3F5W($YO=&4B"FUS9W-T<B`B06IO=70@
M9"=U;F4@;F]U=F5L;&4@;F]T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-`IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(D-R;VES<V%N="(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3D*;7-G
M:60@(D%V86EL86)L92!#871E9V]R:65S.B(*;7-G<W1R(")#873I9V]R:65S
M(&1I<W!O;FEB;&5SH#HB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR
M."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM<V=I9"`B0F%C:R!T;R!.
M;W1E<&%D(@IM<V=S='(@(E)E=F5N:7(@874@8FQO8RUN;W1E<R(*"B,Z('1E
M;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.3<*;7-G:60@(D)A8VL@
M=&\@3F]T97!A9"!/<'1I;VYS(@IM<V=S='(@(E)E=&]U<B!A=7@@;W!T:6]N
M<R!D92!";&]C+6YO=&5S(@H*(SH@9&%T82YP:'`Z,S(@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B0U-6(@IM<V=S='(@(D-35B(*"B,Z
M(&1A=&$N<&AP.C4T('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS9VED
M(")#871E9V]R>2(*;7-G<W1R(")#873I9V]R:64B"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C(R"FUS9VED(")#:&%N9V4B"FUS9W-T
M<B`B36]D:69I97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G
M:60@(D-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R(")-;V1I9FEE<B!L92!T<FD@9&4@=F]S(&YO=&5S(&5T
M(&QE<R!O<'1I;VYS(&0G869F:6-H86=E+B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3,*;7-G:60@(D-H;V]S92!T:&4@
M;65M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RXB
M"FUS9W-T<B`B0VAO:7-I<W-E>B!L97,@8V%TZ6=O<FEE<R!D92!N;W1E<R#@
M('!RZ7-E;G1E<B!D86YS(&QE('-O;6UA:7)E+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,@HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('EO=7(@9&5F
M875L="!.;W1E<&%D+B(*;7-G<W1R(")6;W1R92!B;&]C+6YO=&5S('!A<B!D
MZ69A=72@.B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS,@IM
M<V=I9"`B0VQE87(@1F]R;2(*;7-G<W1R(")%9F9A8V5R(&QE(&9O<FUU;&%I
M<F4B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C$W('1E
M;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E871E(@IM<V=S
M='(@(D-RZ65R(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,S4*;7-G
M:60@(D-R96%T960B"FUS9W-T<B`B0W+IZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,0HC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!.;W1E<&%D(@IM
M<V=S='(@(E9O=')E(&)L;V,M;F]T97,@<&%R(&3I9F%U=*`Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,U"FUS9VED(")$969A=6QT('-O<G1I;F<@
M8W)I=&5R:6$Z(@IM<V=S='(@(D-R:73H<F4@9&4@=')I('!A<B!DZ69A=72@
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B4V5N<R!D=2!T<FD@<&%R
M(&3I9F%U=*`Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN
M8SHY-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-0HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHV-`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-U<'!R
M:6UE<B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C8W"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@=&AI<R!N;W1E(@IM<V=S='(@(E/I;&5C=&EO;FYE
M>B!U;B!B;&]C+6YO=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U
M"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(D3I8W)O:7-S86YT(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHX-0IM<V=I9"`B1&5S
M8W)I<'1I;VXZ(@IM<V=S='(@(D1E<V-R:7!T:6]NH#HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G
M<W1R(")/<'1I;VYS(&0G869F:6-H86=E(@H*(SH@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z,C$@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*;7-G:60@
M(D5D:70B"FUS9W-T<B`B36]D:69I97(B"@HC.B!T96UP;&%T97,O;&ES="]M
M96UO7W-U;6UA<FEE<RYI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!<(B5S7"(B"FUS9W-T<B`B36]D:69I97(B"@HC.B!T96UP;&%T
M97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0T(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HX,PIM<V=I9"`B161I="!.;W1E(@IM<V=S='(@(DUO9&EF:65R(&QA
M(&YO=&4B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C4T
M"FUS9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z,3(*;7-G
M:60@(D5M<'1Y($YO=&4B"FUS9W-T<B`B5FED97(@;&$@;F]T92(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3D*;7-G:60@(D5X<&]R="(*;7-G
M<W1R(")%>'!O<G1E<B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M.`IM<V=I9"`B17AP;W)T($YO=&5S(@IM<V=S='(@(D5X<&]R=&5R(&1E<R!N
M;W1E<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,0IM<V=I
M9"`B1E]U;&P@5&5X="(*;7-G<W1R(")497AT92!I;G3I7V=R86PB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T($YO=&5S+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&%T:6]N
M(&1E<R!N;W1E<RP@Z71A<&4@)60B"@HC.B!D871A+G!H<#HQ.3,*;7-G:60@
M(DEM<&]R="]%>'!O<G0@3F]T97,B"FUS9W-T<B`B26UP;W)T97(O17AP;W)T
M97(@9&5S(&YO=&5S(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-#,*
M;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B1&5R;FGH<F4@;6]D:69I
M8V%T:6]N(@H*(SH@;&EB+V%P:2YP:'`Z-S(*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F($YO=&5S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4S"FUS9VED
M(")-96UO(%1E>'0B"FUS9W-T<B`B5&5X=&4@9&4@;&$@;F]T92(*"B,Z(&UE
M;6\N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(DUO9&EF>6EN9R`E<R(*
M;7-G<W1R(")-;V1I9FEC871I;VX@9&4@)7,B"@HC.B!L:7-T+G!H<#HS-0IM
M<V=I9"`B37D@3F]T97,B"FUS9W-T<B`B365S(&YO=&5S(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*;7-G<W1R(").
M;W5V96QL92!N;W1E(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT
M,`IM<V=I9"`B3F5X="(*;7-G<W1R(")3=6EV86YT(@H*(SH@;&EB+V%P:2YP
M:'`Z,C`V"FUS9VED(").;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHW"FUS9VED(").;R!N
M;W1E<&%D<R!A<F4@879A:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B075C
M=6X@8FQO8RUN;W1E<R!N)V5S="!D:7-P;VYI8FQE('!O=7(@;&5S(&EN=FET
MZ7,N(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS9VED(").
M;R!N;W1E<R(*;7-G<W1R(")!=6-U;F4@;F]T92(*"B,Z('1E;7!L871E<R]L
M:7-T+V5M<'1Y+FEN8SHS"FUS9VED(").;R!N;W1E<R!M871C:"!T:&4@8W5R
M<F5N="!C<FET97)I82XB"FUS9W-T<B`B075C=6YE(&YO=&4@;F4@8V]R<F5S
M<&]N9"!A=2!P<NES96YT(&-R:73H<F4N(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$P.0IM<V=I9"`B3F\@;F]T97,@=&\@9&ES<&QA>2(*;7-G<W1R
M(")!=6-U;F4@;F]T92#@(&%F9FEC:&5R(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M;65M;U]H96%D97)S+FEN8SHT-@IM<V=I9"`B3F]?=&4B"FUS9W-T<B`B3F]?
M=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0*;7-G:60@(DYO=&4@
M0V%T96=O<GDB"FUS9W-T<B`B0V%TZ6=O<FEE(&1E(&YO=&4B"@HC.B!V:65W
M+G!H<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHY"FUS9VED(").;W1E
M($1E=&%I;',B"FUS9W-T<B`B1.ET86EL<R!D92!L82!N;W1E(@H*(SH@;F]T
M97!A9',N<&AP.C$Q,`IM<V=I9"`B3F]T92!,:7-T<R(*;7-G<W1R("),:7-T
M97,@9&4@;F]T97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,*;7-G
M:60@(DYO=&4@5&5X="(*;7-G<W1R(")497AT92!D92!L82!N;W1E(@H*(SH@
M=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*;7-G:60@(DYO=&4@7U1E>'0B
M"FUS9W-T<B`B7U1E>'1E(&1E(&QA(&YO=&4B"@HC.B!V:65W+G!H<#HU-R!M
M96UO+G!H<#HV,`IM<V=I9"`B3F]T92!N;W0@9F]U;F0N(@IM<V=S='(@(DYO
M=&4@;F]N('1R;W5VZ64B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHS
M-`IM<V=I9"`B3F]T95]P860B"FUS9W-T<B`B7T)L;V,M;F]T97,B"@HC.B!T
M96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C<Y"FUS9VED(").;W1E
M<&%D)W,@;F%M93HB"FUS9W-T<B`B3F]M(&1U(&)L;V,M;F]T97.@.B(*"B,Z
M('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C$*;7-G:60@(DYO
M=&5P861S(@IM<V=S='(@(D)L;V-S+6YO=&5S(@H*(SH@;F]T97!A9',N<&AP
M.C,S"B,L(&9U>GIY"FUS9VED(").;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE
M+B(*;7-G<W1R(").;VT@9'4@8FQO8RUN;W1E<Z`Z(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C,*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`B
M4V]M;6%I<F4@9&5S(&YO=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,`IM<V=I9"`B3W1H97(@3W!T
M:6]N<R(*;7-G<W1R(")!=71R97,@;W!T:6]N<R(*"B,Z(&QI8B]A<&DN<&AP
M.C$X,R!L:6(O87!I+G!H<#HR-S0@;&EB+V%P:2YP:'`Z,S0U(&QI8B]A<&DN
M<&AP.C,W-`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B06-C
MZ',@<F5F=7/I(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN
M8SHX,@IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B1')O:71S(&0G86-C
MZ',B"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C4@=&5M<&QA=&5S
M+VQI<W0O:&5A9&5R+FEN8SHV"FUS9VED(")2969R97-H($QI<W0B"FUS9W-T
M<B`B4F%F<F'N8VAI<B!L82!L:7-T92(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`U"FUS9VED(")296UO=F4@8V%T96=O
M<GDB"FUS9W-T<B`B4F5T:7)E<B!L82!C873I9V]R:64B"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDV"FUS9VED(")297-E="(*;7-G
M<W1R(")2P%HB"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU-@IM<V=I
M9"`B4V%V92(*;7-G<W1R(")%;G)E9VES=')E<B(*"B,Z('-E87)C:"YP:'`Z
M,3<@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C0@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C,Q"FUS9VED(")396%R8V@B"FUS9W-T<B`B4F5C
M:&5R8VAE(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@(E-E87)C:"!297-U;'1S
M(@IM<V=S='(@(E+I<W5L=&%T<R!D92!L82!R96-H97)C:&4B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3<*;7-G:60@(E-E87)C:"!38V]P
M92(*;7-G<W1R("+)=&5N9'5E(&1E(&QA(')E8VAE<F-H92(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHY"FUS9VED(")396%R8V@@7U1E>'0B
M"FUS9W-T<B`B7U1E>'1E(')E8VAE<F-HZ2(*"B,Z('1E;7!L871E<R]N;W1E
M<&%D<R]N;W1E<&%D<RYI;F,Z-C<*;7-G:60@(E-E;&5C="!A(&YO=&5P860B
M"FUS9W-T<B`B4^EL96-T:6]N;F5Z('5N(&)L;V,M;F]T97,B"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;W1E
M<&%D<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")!=6-U;F4@;F]T92#@(&%F9FEC
M:&5R(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B
M4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R(")3Z6QE8W1I;VYN
M97H@;&4@9F]R;6%T(&1E(&PG97AP;W)T871I;VXZ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHS-PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O
M(&EM<&]R=#HB"FUS9W-T<B`B0VAO:7-I<W-E>B!L92!F:6-H:65R(.`@:6UP
M;W)T97*@.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*;7-G
M:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS
M9W-T<B`B4^EL96-T:6]N;F5Z(&QE(&9O<FUA="!D=2!F:6-H:65R('-O=7)C
M93HB"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC
M.C$P.0IM<V=I9"`B4V5L96-T960@0V%T96=O<FEE<SHB"FUS9W-T<B`B0V%T
MZ6=O<FEE<R!SZ6QE8W1I;VYNZ65SH#HB"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,S@*;7-G:60@(E-H;W<@86-T:6]N(&)U='1O;G,_(@IM<V=S='(@
M(D%F9FEC:&5R(&)O=71O;G,@9"=A8W1I;VX@/R(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HT,0IM<V=I9"`B4VAO=R!N;W1E<&%D(&YA;64_(@IM<V=S
M='(@(D%F9FEC:&5R(&QE(&YO;2!D=2!B;&]C+6YO=&5S(#^@.B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HT-`IM<V=I9"`B4VAO=R!N;W1E<R!F<F]M
M('1H97-E(&-A=&5G;W)I97,B"FUS9W-T<B`B069F:6-H97(@;&5S(&YO=&5S
M(&1E(&-E<R!C873I9V]R:65S(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H
M96%D97)S+FEN8SHU,`IM<V=I9"`B4V]R="!B>2!#871E9V]R>2(*;7-G<W1R
M(")4<FD@<V5L;VX@;&$@8V%TZ6=O<FEE(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M;65M;U]H96%D97)S+FEN8SHT-@IM<V=I9"`B4V]R="!B>2!.;W1E(%1E>'0B
M"FUS9W-T<B`B5')I('-E;&]N(&QE('1E>'1E(&1E(&QA(&YO=&4B"@HC.B!M
M96UO+G!H<#HQ,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!<(B5S7"(N(@IM<V=S='(@(JN@)7.@NR!A(.ETZ2!E
M;G)E9VES='+I(&%V96,@<W5C8^AS+B(*"B,Z(&UE;6\N<&AP.C$U.0IM<V=I
M9"`B5&AE(&YO=&4@=V%S(&1E;&5T960N(@IM<V=S='(@(DQA(&YO=&4@82#I
M=.D@<W5P<')I;>EE+B(*"B,Z(&YO=&5P861S+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@8V]U;&1N)W0@8F4@8W)E
M871E9#H@)7,B"FUS9W-T<B`B0W+I871I;VX@:6UP;W-S:6)L92!D=2!B;&]C
M+6YO=&5S(*N@)7.@NZ`Z("5S(@H*(SH@;F]T97!A9',N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!C
M<F5A=&5D+B(*;7-G<W1R("),92!B;&]C+6YO=&5S(*N@)7.@NR!A(.ETZ2!C
M<NGI+B(*"B,Z(&YO=&5P861S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B3&4@8FQO8RUN;W1E<R"KH"5SH+L@82#I=.D@<W5P<')I;>DN(@H*(SH@
M;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E
M<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B3&4@8FQO8RUN
M;W1E<R"KH"5SH+L@82#I=.D@96YR96=I<W1RZ2XB"@HC.B!D871A+G!H<#HQ
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`B56YE(&5R<F5U<B!E<W0@
M87!P87)U92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I97.@.B`E
M<R(*"B,Z(&QI8B]A<&DN<&AP.C(P,`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM
M<V=S='(@(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L)VEM
M<&]R=&%T:6]N(&1E<R!D;VYNZ65S('9.;W1E+B(*"B,Z(&QI8B]A<&DN<&AP
M.C,Y,PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M=DYO=&4@9&%T82XB"FUS9W-T<B`B56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET
M92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I97,@=DYO=&4N(@H*
M(SH@;65M;RYP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!R96UO=FEN9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B56YE
M(&5R<F5U<B!E<W0@87!P87)U92!L;W)S(&1U(')E=')A:70@9&4@;&$@;F]T
M92`Z("5S(@H*(SH@;65M;RYP:'`Z,3,S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AE(&YO=&4Z("5S(@IM<V=S
M='(@(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L)V5N<F5G
M:7-T<F5M96YT(&1E(&QA(&YO=&4Z("5S(@H*(SH@=FEE=RYP:'`Z-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@
M=&AI<R!N;W1E<&%D.B`E<R(*;7-G<W1R("));"!Y(&$@974@=6YE(&5R<F5U
M<B!L;W)S(&1E(&PG;W5V97)T=7)E(&1E(&-E(&)L;V,M;F]T97,Z("5S(@H*
M(SH@9&%T82YP:'`Z-SD*;7-G:60@(E1H97)E('=E<F4@;F\@;65M;W,@=&\@
M97AP;W)T+B(*;7-G<W1R(")!=6-U;F4@;F]T92#@(&5X<&]R=&5R(&XG82#I
M=.D@=')O=7;I92XB"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H:7,@9FEL
M92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B0V4@9F]R;6%T
M(&1E(&9I8VAI97(@;B=E<W0@<&%S('!R:7,@96X@8V]M<'1E+B(*"B,Z(&YO
M=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B4W5P<')E<W-I;VX@:6UP;W-S
M:6)L92!D92"KH"5SH+N@.B`E<R(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N
M:6YC.C4X"B,L(&9U>GIY"FUS9VED(")5;F1O(&-H86YG97,B"FUS9W-T<B`B
M1.EF86ER92!L97,@;6]D:69I8V%T:6]N<R(*"B,Z('1E;7!L871E<R]V:65W
M+VUE;6\N:6YC.C$V('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN
M8SHQ-`HC.B!L:6(O36YE;6\N<&AP.C(P-B!L:6(O36YE;6\N<&AP.C(P-R!L
M:6(O36YE;6\N<&AP.C(R,2!L:6(O36YE;6\N<&AP.C(R,@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3`U"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DAO
M<G,@8V%TZ6=O<FEE(@H*(SH@;&EB+V%P:2YP:'`Z,C,V(&QI8B]A<&DN<&AP
M.C,P.2!L:6(O87!I+G!H<#HT,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B5'EP
M92!D92!C;VYT96YU(&YO;BUS=7!P;W)TZ2XB"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C(R"FUS9VED(")7:&EC:"!.;W1E<&%D('-H;W5L9"!T
M:&4@;F]T97,@8F4@861D960@=&\_(@IM<V=S='(@(L`@<75E;"!C86QE<&EN
M(&9A=70M:6P@86IO=71E<B!L97,@;F]T97.@/R(*"B,Z(&1A=&$N<&AP.C0R
M(&1A=&$N<&AP.C$R-2!M96UO+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M;F]T97,N(@IM<V=S='(@(B(*"B,Z('9I97<N<&AP.C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@
M=&AE(&YO=&5P860@)7,N(@IM<V=S='(@(E9O=7,@;B?J=&5S('!A<R!A=71O
M<FESZ2#@(&-O;G-U;'1E<B!L92!B;&]C+6YO=&5S("5S+B(*"B,Z(&YO=&5P
M861S+G!H<#HV-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@;F]T97!A9"!T
M;R!B92!D96QE=&5D+B(*;7-G<W1R("));"!F875T(&0G86)O<F0@<^EL96-T
M:6]N;F5R(&QE(&)L;V,M;F]T97,@X"!S=7!P<FEM97(N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VYO=&5P861S96QE8W0N:6YC.C$P"FUS9VED(")9;W5R(&1E
M9F%U;'0@;F]T97!A9#HB"FUS9W-T<B`B5F]T<F4@8FQO8RUN;W1E<R!P87(@
M9.EF875TH#HB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC
M.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*;7-G<W1R(")6;W,@8FQO8W,M
M;F]T97.@.B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(X('1E;7!L
M871E<R]V:65W+VUE;6\N:6YC.C8W"FUS9VED(")?0F%C:R!T;R!.;W1E<&%D
M(@IM<V=S='(@(E)E=F5N:7(@X"!?3F]T97,B"@HC.B!T96UP;&%T97,O;65M
M;R]M96UO+FEN8SHU,2!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC
M.C4P"FUS9VED(")?0V%T96=O<GDB"FUS9W-T<B`B7T-A=.EG;W)I92(*"B,Z
M('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(U('1E;7!L871E<R]V:65W+VUE
M;6\N:6YC.C8T"FUS9VED(")?1&5L971E(@IM<V=S='(@(E]3=7!P<FEM97(B
M"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHV,`IM<V=I9"`B7T5D:70B"FUS9W-T<B`B36]D:69I7V5R
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"FUS9VED(")?
M1FER<W0@3&EN92(*;7-G<W1R(")?4')E;6GH<F4@;&EG;F4B"@HC.B!L:6(O
M36YE;6\N<&AP.C(X,0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B
M7TEM<&]R=&5R+T5X<&]R=&5R(@H*(SH@;&EB+TUN96UO+G!H<#HR-C0*;7-G
M:60@(E],:7-T($YO=&5S(@IM<V=S='(@(D%F9FEC:&5R(%]L97,@;F]T97,B
M"@HC.B!L:6(O36YE;6\N<&AP.C(W-@IM<V=I9"`B7TUY($YO=&5P861S(@IM
M<V=S='(@(E]-97,@8FQO8RUN;W1E<R(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8Y
M"FUS9VED(")?3F5W($YO=&4B"FUS9W-T<B`B7TYO=79E;&QE(&YO=&4B"@HC
M.B!L:6(O36YE;6\N<&AP.C(X-@IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(DEM
M7W!R:6UE<B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<R"FUS9VED(")?4V5A<F-H
M(@IM<V=S='(@(E]296-H97)C:&4B"@HC.B!D871A+G!H<#HY,2!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(FYO=&5S+F-S=B(*;7-G<W1R
M(")N;W1E<RYC<W8B"@HC.B!D871A+G!H<#HS,R!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C$X"FUS9VED(")V3F]T92(*;7-G<W1R(")V3F]T92(*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VUN96UO+W!O+VET7TE4+G!O````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,S`U-S8`,3`T,3<S-C(W-#8`,#$W-3,W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@271A;&EA
M;B!T<F%N<VQA=&EO;G,@9F]R(&]P('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#
M*2`R,#`S($AO<F1E(%!R;VIE8W0*(R!#;W!Y<FEG:'0@*&,I(#(P,#,@4V5R
M9VEO($<N($-A<F5D9&$N"B,@4V5R9VEO($<N($-A<F5D9&$@/'-C87)E9&1A
M0'1I<V-A;&DN:70^+"`R,#`S+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!-;F5M;R`R+C`M8W9S7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-2TP,BTR,R`Q.#HQ-"LP,3`P7&XB"B),87-T+51R86YS
M;&%T;W(Z($UA<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O=F%N;T!U;FEB;V-C
M;VYI+FET/EQN(@HB3&%N9W5A9V4M5&5A;3H@271A;&EA;B`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E
M<R]L:7-T+VAE861E<BYI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!N
M;W1E<R(*;7-G<W1R("(E9"!A<'!U;G1I(@H*(SH@=&5M<&QA=&5S+VUE;6\O
M;65M;RYI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@8VAA<F%C=&5R
M<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B
M1FEL92`E<R!I;7!O<G1A=&\@8V]N('-U8V-E<W-O(@H*(SH@;F]T97!A9',N
M<&AP.CDY(&QI8B]B87-E+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S)W,@0FQO8V-O($%P<'5N=&DB"@HC
M.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(C$@;F]T92(*
M;7-G<W1R("(Q(&%P<'5N=&\B"@HC.B!M96UO+G!H<#HQ-C(*;7-G:60@(D%C
M8V5S<R!D96YI960@9&5L971I;F<@;F]T92XB"FUS9W-T<B`B06-C97-S;R!N
M96=A=&\@<&5R(&5L:6UI;F%Z:6]N92!A<'!U;G1O+B(*"B,Z(&UE;6\N<&AP
M.C$Q,B!M96UO+G!H<#HQ,34*;7-G:60@(D%C8V5S<R!D96YI960@;6]V:6YG
M('1H92!N;W1E+B(*;7-G<W1R(")!8V-E<W-O(&YE9V%T;R!R:6UO>FEO;F4@
M87!P=6YT;RXB"@HC.B!M96UO+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E('1O("5S+B(*;7-G<W1R(")!
M8V-E<W-O(&YE9V%T;R!A;"!S86QV871A9V=I;R!D:2!A<'!U;G1O(&EN("5S
M+B(*"B,Z(&UE;6\N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S
M<R!D96YI960@<V%V:6YG(&YO=&4Z("5S(@IM<V=S='(@(D%C8V5S<V\@;F5G
M871O(&%L('-A;'9A=&%G9VEO(&1I(&%P<'5N=&\@:6X@)7,N(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#,*;7-G:60@
M(D%D9"!C871E9V]R>2(*;7-G<W1R(")!9V=I=6YG:2!C871E9V]R:6$B"@HC
M.B!M96UO+G!H<#HU,@IM<V=I9"`B061D:6YG($$@3F5W($YO=&4B"FUS9W-T
M<B`B06=G:75N9VD@56X@3G5O=F\@07!P=6YT;R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-`IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(D-R97-C
M96YT92(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI
M;F,Z.3D*;7-G:60@(D%V86EL86)L92!#871E9V]R:65S.B(*;7-G<W1R(")#
M871E9V]R:64@1&ES<&]N:6)I;&DZ(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M
M;RYI;F,Z,C@@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C<*;7-G:60@(D)A
M8VL@=&\@3F]T97!A9"(*;7-G<W1R(")4;W)N82!A;"!";&]C8V\@07!P=6YT
M:2(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.3<*;7-G
M:60@(D)A8VL@=&\@3F]T97!A9"!/<'1I;VYS(@IM<V=S='(@(E1O<FYA(&%L
M($)L;V-C;R!!<'!U;G1I(@H*(SH@9&%T82YP:'`Z,S(@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B0U-6(@IM<V=S='(@(D-35B(*"B,Z
M(&1A=&$N<&AP.C4T('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS9VED
M(")#871E9V]R>2(*;7-G<W1R(")#871E9V]R:6$B"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C(R"FUS9VED(")#:&%N9V4B"FUS9W-T
M<B`B36]D:69I8V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G
M:60@(D-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R(")-;V1I9FEC82!I;7!O<W1A>FEO;FD@=FES=6%L:7IZ
M87II;VYE(&4@;W)D:6YA;65N=&\@07!P=6YT:2XB"@HC.B!T96UP;&%T97,O
M<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.CDS"FUS9VED(")#:&]O<V4@
M=&AE(&UE;6\@8V%T96=O<FEE<R!T;R!L:7-T(&EN('1H92!S=6UM87)Y('9I
M97<N(@IM<V=S='(@(E-C96=L:2!L92!C871E9V]R:64@9&D@07!P=6YT:2!D
M82!M;W-T<F%R92!N96P@<V]M;6%R:6\N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R"FUS9VED(")#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N
M(@IM<V=S='(@(D)L;V-C;R!A<'!U;G1I(&1I(&1E9F%U;'0Z(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,R"FUS9VED(")#;&5A<B!&;W)M
M(@IM<V=S='(@(D-R96$@36]D=6QO(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHQ-R!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.CDT"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.38*
M;7-G:60@(D-R96%T92(*;7-G<W1R(")#<F5A(@H*(SH@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z,S4*;7-G:60@(D-R96%T960B"FUS9W-T<B`B0W)E871O
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q"FUS9VED(")$969A=6QT
M($YO=&5P860B"FUS9W-T<B`B0FQO8V-O(&%P<'5N=&D@9&D@9&5F875L=#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4*;7-G:60@(D1E9F%U;'0@
M<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`B0W)I=&5R:6\@9&D@;W)D:6YA
M;65N=&\@9&D@9&5F875L=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#8*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@
M(D1I<F5Z:6]N92!D:2!O<F1I;F%M96YT;R!D:2!D969A=6QT.B(*"B,Z('1E
M;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.34@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z,C4*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C0*
M;7-G:60@(D1E;&5T92(*;7-G<W1R(")%;&EM:6YA(@H*(SH@=&5M<&QA=&5S
M+VUE;6\O;65M;RYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!T:&ES
M(&YO=&4B"FUS9W-T<B`B4V5L97II;VYA('5N(&)L;V-C;R!A<'!U;G1I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U"FUS9VED(")$97-C96YD:6YG
M(@IM<V=S='(@(D1I<V-E;F1E;G1E(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHX-0IM<V=I9"`B1&5S8W)I<'1I;VXZ(@IM<V=S='(@
M(D1E<V-R:7II;VYE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-`IM
M<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P>FEO;FD@9&D@5FES
M=6%L:7IZ87II;VYE(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C$@
M=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*;7-G:60@(D5D:70B"FUS9W-T
M<B`B36]D:69I8V$B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE
M<RYI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S
M7"(B"FUS9W-T<B`B36]D:69I8V$B"@HC.B!T96UP;&%T97,O;&ES="]M96UO
M7VAE861E<G,N:6YC.C0T(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HX,PIM<V=I
M9"`B161I="!.;W1E(@IM<V=S='(@(DUO9&EF:6-A($%R=&EC;VQO(@H*(SH@
M=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHU-`IM<V=I9"`B161I
M="!C871E9V]R:65S(&%N9"!C;VQO<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C$R"FUS9VED(")%;7!T>2!.
M;W1E(@IM<V=S='(@(D-H:6%V92!V=6]T;R(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,3D*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%<W!O<G1A
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O
M<G0@3F]T97,B"FUS9W-T<B`B17-P;W)T82!!<'!U;G1I(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C(Q"FUS9VED(")&7W5L;"!497AT(@IM
M<V=S='(@(E1E<W1O($-O;7!L971O(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!.;W1E<RP@
M4W1E<"`E9"(*;7-G<W1R("));7!O<G1A>FEO;F4@07!P=6YT:2P@4&%S<V\@
M)60B"@HC.B!D871A+G!H<#HQ.3,*;7-G:60@(DEM<&]R="]%>'!O<G0@3F]T
M97,B"FUS9W-T<B`B26UP;W)T82]%<W!O<G1A($%P<'5N=&DB"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHT,PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*
M;7-G<W1R(")5;'1I;6$@36]D:69I8V$B"@HC.B!L:6(O87!I+G!H<#HW,@IM
M<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@3F]T97,B"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z-3,*;7-G:60@(DUE;6\@5&5X="(*;7-G<W1R(")497-T;R!!
M<'!U;G1I(@H*(SH@;65M;RYP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M36]D:69Y:6YG("5S(@IM<V=S='(@(DUO9&EF:6-A(&EN(&-O<G-O("5S(@H*
M(SH@;&ES="YP:'`Z,S4*;7-G:60@(DUY($YO=&5S(@IM<V=S='(@(D)L;V-C
M;R!!<'!U;G1I(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS9VED
M(").97<@3F]T92(*;7-G<W1R(").=6]V;R!!<'!U;G1O(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I9"`B3F5X="(*;7-G<W1R(")3
M=6-C97-S:79O(@H*(SH@;&EB+V%P:2YP:'`Z,C`V"FUS9VED(").;R!I0V%L
M96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M96YU+FEN8SHW"FUS9VED(").;R!N;W1E<&%D<R!A<F4@879A:6QA8FQE
M('1O(&=U97-T<RXB"FUS9W-T<B`B3F5S<W5N(&)L;V-C;R!A<'!U;G1I(&1I
M<W!O;FEB:6QE('!E<B!G;&D@;W-P:71I+B(*"B,Z('1E;7!L871E<R]L:7-T
M+VAE861E<BYI;F,Z,PIM<V=I9"`B3F\@;F]T97,B"FUS9W-T<B`B3F5S<W5N
M(&%P<'5N=&\B"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z,PIM<V=I
M9"`B3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S
M='(@(DYE<W-U;B!A<'!U;G1O(&-O<G)I<W!O;F1E(&%L(&-R:71E<FEO(&-O
M<G)E;G1E+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#D*;7-G:60@
M(DYO(&YO=&5S('1O(&1I<W!L87DB"FUS9W-T<B`B3F5S<W5N(&%P<'5N=&\@
M9&$@=FES=6%L:7IZ87)E(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D
M97)S+FEN8SHT-@IM<V=I9"`B3F]?=&4B"FUS9W-T<B`B3F]?=&4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0*;7-G:60@(DYO=&4@0V%T96=O<GDB
M"FUS9W-T<B`B0V%T96=O<FEA($%P<'5N=&\B"@HC.B!V:65W+G!H<#HX,"!T
M96UP;&%T97,O=FEE=R]M96UO+FEN8SHY"FUS9VED(").;W1E($1E=&%I;',B
M"FUS9W-T<B`B1&5T=&%G;&D@07!P=6YT;R(*"B,Z(&YO=&5P861S+G!H<#HQ
M,3`*;7-G:60@(DYO=&4@3&ES=',B"FUS9W-T<B`B3&ES=&$@07!P=6YT:2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B3F]T92!497AT
M(@IM<V=S='(@(E1E<W1O($%P<'5N=&\B"@HC.B!T96UP;&%T97,O;65M;R]M
M96UO+FEN8SHR-@IM<V=I9"`B3F]T92!?5&5X="(*;7-G<W1R(")497-T;R!!
M<'!U;G1O(@H*(SH@=FEE=RYP:'`Z-3<@;65M;RYP:'`Z-C`*;7-G:60@(DYO
M=&4@;F]T(&9O=6YD+B(*;7-G<W1R(")&:6QE(&1I(&9O;G0@;F]N('1R;W9A
M=&\N(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,S0*;7-G:60@(DYO
M=&5?<&%D(@IM<V=S='(@(D)L;V-C;R!!<'!U;G1O(@H*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHW.0IM<V=I9"`B3F]T97!A9"=S(&YA
M;64Z(@IM<V=S='(@(DYO;64@0FQO8V-O($%P<'5N=&DZ(@H*(SH@=&5M<&QA
M=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHV,0IM<V=I9"`B3F]T97!A9',B
M"FUS9W-T<B`B0FQO8V-H:2!!<'!U;G1I(@H*(SH@;F]T97!A9',N<&AP.C,S
M"FUS9VED(").;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R(").
M;VUE($)L;V-C;R!!<'!U;G1I.B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HS"FUS9VED(").;W1E<R!3=6UM87)Y(@IM<V=S='(@(E-O;6UA<FEO($%P
M<'5N=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(P"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@
M(D%L=')E($]P>FEO;FDB"@HC.B!L:6(O87!I+G!H<#HQ.#,@;&EB+V%P:2YP
M:'`Z,C<T(&QI8B]A<&DN<&AP.C,T-2!L:6(O87!I+G!H<#HS-S0*;7-G:60@
M(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<FUE<W-O($YE9V%T;R(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#(*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUE<W-I(@H*(SH@=&5M<&QA=&5S
M+VQI<W0O:&5A9&5R+FEN8SHU('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z
M-@IM<V=I9"`B4F5F<F5S:"!,:7-T(@IM<V=S='(@(D%G9VEO<FYA($QI<W1A
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ
M,#4*;7-G:60@(E)E;6]V92!C871E9V]R>2(*;7-G<W1R(")2:6UU;W9I($-A
M=&5G;W)I82(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z
M.38*;7-G:60@(E)E<V5T(@IM<V=S='(@(D%N;G5L;&$B"@HC.B!T96UP;&%T
M97,O;65M;R]M96UO+FEN8SHU-@IM<V=I9"`B4V%V92(*;7-G<W1R(")386QV
M82(*"B,Z('-E87)C:"YP:'`Z,3<@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,Q"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`B0V5R8V$B"@HC.B!L:7-T+G!H<#HU-PIM<V=I9"`B
M4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B4FES=6QT871I(%)I8V5R8V$B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3<*;7-G:60@(E-E87)C
M:"!38V]P92(*;7-G<W1R(")!;7!I97IZ82!2:6-E<F-A(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.CD*;7-G:60@(E-E87)C:"!?5&5X="(*
M;7-G<W1R(")2:6-E<F-A(%1E<W1O(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHV-PIM<V=I9"`B4V5L96-T(&$@;F]T97!A9"(*;7-G
M<W1R(")396QE>FEO;F$@=6X@8FQO8V-O(&%P<'5N=&DB"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;W1E<&%D
M<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(").97-S=6X@87!P=6YT;R!D82!V:7-U
M86QI>GIA<F4B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS
M9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E-E;&5Z
M:6]N82!I;"!F;W)M871O('!E<B!E<W!O<G1A<F4B"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C,W"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@
M:6UP;W)T.B(*;7-G<W1R(")396QE>FEO;F$@:6P@9FEL92!D82!I;7!O<G1A
M<F4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0IM<V=I9"`B
M4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R
M(")396QE>FEO;F$@:6P@9F]R;6%T;R!V97)S;R!C=6D@97-P;W)T87)E.B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`Y
M"FUS9VED(")396QE8W1E9"!#871E9V]R:65S.B(*;7-G<W1R(")396QE>FEO
M;F$@0V%T96=O<FEE.B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS.`IM
M<V=I9"`B4VAO=R!A8W1I;VX@8G5T=&]N<S\B"FUS9W-T<B`B36]S=')A($-O
M;G1A='1I(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0Q"FUS9VED(")3
M:&]W(&YO=&5P860@;F%M93\B"FUS9W-T<B`B36]S=')A($)L;V-C:&D@07!P
M=6YT:3HB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#0*;7-G:60@(E-H
M;W<@;F]T97,@9G)O;2!T:&5S92!C871E9V]R:65S(@IM<V=S='(@(DUO<W1R
M82!N;W1E(&1A('%U97-T92!C871E9V]R:64B"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C4P"FUS9VED(")3;W)T(&)Y($-A=&5G;W)Y
M(@IM<V=S='(@(D]R9&EN82!P97(@0V%T96=O<FEA(@H*(SH@=&5M<&QA=&5S
M+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-@IM<V=I9"`B4V]R="!B>2!.;W1E
M(%1E>'0B"FUS9W-T<B`B3W)D:6YA('!E<B!497-T;R!D:2!!<'!U;G1O(@H*
M(SH@;65M;RYP:'`Z,3,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@7"(E<UPB+B(*;7-G<W1R("(G)7,G(&%G9VEO
M<FYA=&\@8V]N('-U8V-E<W-O(@H*(SH@;65M;RYP:'`Z,34Y"FUS9VED(")4
M:&4@;F]T92!W87,@9&5L971E9"XB"FUS9W-T<B`B3"=!<'!U;G1O(.@@<W1A
M=&\@96QI;6EN871O+B(*"B,Z(&YO=&5P861S+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@8V]U;&1N)W0@8F4@8W)E
M871E9#H@)7,B"FUS9W-T<B`B26P@0FQO8V-O($%P<'5N=&D@7"(E<UPB(&YO
M;B#H('-T871O(&-R96%T;SH@)7,@(@H*(SH@;F]T97!A9',N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E
M;B!C<F5A=&5D+B(*;7-G<W1R("));"!";&]C8V\@07!P=6YT:2!<(B5S7"(@
MZ"!S=&%T;R!C<F5A=&\N(@H*(SH@;F]T97!A9',N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("));"!B;&]C8V\@87!P=6YT:2!<(B5S7"(@Z"!S=&%T
M;R!E;&EM:6YA=&\N(@H*(SH@;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB
M"FUS9W-T<B`B26P@8FQO8V-O(&%P<'5N=&D@7"(E<UPB(.@@<W1A=&\@<V%L
M=F%T;RXB"@HC.B!D871A+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS
M9W-T<B`B17)R;W)E(&YE;&PG:6UP;W)T87II;VYE(&1E:2!D871I.B`E<R(*
M"B,Z(&QI8B]A<&DN<&AP.C(P,`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S
M='(@(D5R<F]R92!N96QL)VEM<&]R=&%Z:6]N92!D96D@9&%T:2XB"@HC.B!L
M:6(O87!I+G!H<#HS.3,*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE('9.;W1E(&1A=&$N(@IM<V=S='(@(D5R<F]R92!N96QL)VEM
M<&]R=&%Z:6]N92!D96D@9&%T:2XB"@HC.B!M96UO+G!H<#HQ-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H
M92!N;W1E.B`E<R(*;7-G<W1R(")%<G)O<F4@;F5L;&$@<FEM;WII;VYE(&1E
M;&PG87!P=6YT;SH@)7,B"@HC.B!M96UO+G!H<#HQ,S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&4@;F]T93H@
M)7,B"FUS9W-T<B`B17)R;W)E(&YE;"!S86QV871A9V=I;R!D96QL)V%P<'5N
M=&\Z("5S(@H*(SH@=FEE=RYP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E<R(*
M;7-G<W1R(")#)V5R82!U;B!E<G)O<F4@;F5L;"=A<&5R='5R82!D:2!Q=65S
M=&\@<75E<W1O(&)L;V-C;R!A<'!U;G1I.B`E<R(*"B,Z(&1A=&$N<&AP.C<Y
M"FUS9VED(")4:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="XB"FUS9W-T
M<B`B3F]N('9I(&5R86YO(&%P<'5N=&D@9&$@97-P;W)T87)E(@H*(SH@9&%T
M82YP:'`Z,3`U"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(E%U97-T;R!F;W)M871O(&YO;B#H('-U<'!O<G1A
M=&\B"@HC.B!N;W1E<&%D<RYP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(DEM<&]S<VEB
M:6QE(&5L:6UI;F%R92!<(B5S7"(Z("5S(@H*(SH@=&5M<&QA=&5S+VUE;6\O
M;65M;RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(E5N9&\@8VAA;F=E<R(*;7-G
M<W1R("));F1I971R;R(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$V
M('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ-`HC.B!L:6(O
M36YE;6\N<&AP.C(P-B!L:6(O36YE;6\N<&AP.C(P-R!L:6(O36YE;6\N<&AP
M.C(R,2!L:6(O36YE;6\N<&AP.C(R,@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,3`U"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DYO;B!C;&%S<VEF:6-A
M=&\B"@HC.B!L:6(O87!I+G!H<#HR,S8@;&EB+V%P:2YP:'`Z,S`Y(&QI8B]A
M<&DN<&AP.C0P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P
M;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R(")%<W1E;G-I;VYE($YO
M;B!3=7!P;W)T871A(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR
M,@IM<V=I9"`B5VAI8V@@3F]T97!A9"!S:&]U;&0@=&AE(&YO=&5S(&)E(&%D
M9&5D('1O/R(*;7-G<W1R(")!('%U86QE($)L;V-C;R!!<'!U;G1I(&%G9VEU
M;F=E<F4@9VQI(&%P<'5N=&D_(@H*(SH@9&%T82YP:'`Z-#(@9&%T82YP:'`Z
M,3(U(&UE;6\N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!N;W1E<RXB"FUS
M9W-T<B`B(@H*(SH@=FEE=RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A
M9"`E<RXB"FUS9W-T<B`B3F]N(&AA:2!I;"!P97)M97-S;R!D:2!V:7-U86QI
M>GIA<F4@:6P@8FQO8V-O(&%P<'5N=&D@)7,N(@H*(SH@;F]T97!A9',N<&AP
M.C8U"FUS9VED(")9;W4@;75S="!S96QE8W0@82!N;W1E<&%D('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(D1E=FD@<V5L97II;VYA<F4@=6X@8FQO8V-O(&%P
M<'5N=&D@9&$@96QI;6EN87)E+B(*"B,Z('1E;7!L871E<R]P<F5F<R]N;W1E
M<&%D<V5L96-T+FEN8SHQ,`IM<V=I9"`B66]U<B!D969A=6QT(&YO=&5P860Z
M(@IM<V=S='(@(D)L;V-C;R!A<'!U;G1I(&1I(&1E9F%U;'0Z(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHV-0IM<V=I9"`B66]U<B!N
M;W1E<&%D<SHB"FUS9W-T<B`B22!T=6]I(&)L;V-C:&D@87!P=6YT:3HB"@HC
M.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M
M96UO+FEN8SHV-PIM<V=I9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")4
M;W)N82!A;"!";&]C8V\@07!P=6YT:2(*"B,Z('1E;7!L871E<R]M96UO+VUE
M;6\N:6YC.C4Q('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3`*
M;7-G:60@(E]#871E9V]R>2(*;7-G<W1R(")#871E9V]R:6$B"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHR-2!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHV-`IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")?16QI;6EN82(*"B,Z('1E
M;7!L871E<R]V:65W+VUE;6\N:6YC.C(Q('1E;7!L871E<R]V:65W+VUE;6\N
M:6YC.C8P"FUS9VED(")?161I="(*;7-G<W1R(")?36]D:69I8V$B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C`*;7-G:60@(E]&:7)S="!,
M:6YE(@IM<V=S='(@(E!R:6UA(%)I9V$B"@HC.B!L:6(O36YE;6\N<&AP.C(X
M,0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R=&$O17-P
M;W)T82(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8T"FUS9VED(")?3&ES="!.;W1E
M<R(*;7-G<W1R("),:7-T82!!<'!U;G1I(@H*(SH@;&EB+TUN96UO+G!H<#HR
M-S8*;7-G:60@(E]->2!.;W1E<&%D<R(*;7-G<W1R(")?0FQO8V-O($%P<'5N
M=&DB"@HC.B!L:6(O36YE;6\N<&AP.C(V.0IM<V=I9"`B7TYE=R!.;W1E(@IM
M<V=S='(@(E].=6]V;R!!<'!U;G1O(@H*(SH@;&EB+TUN96UO+G!H<#HR.#8*
M;7-G:60@(E]0<FEN="(*;7-G<W1R(")3=&%M<&$B"@HC.B!L:6(O36YE;6\N
M<&AP.C(W,@IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?0V5R8V$B"@HC.B!D
M871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@
M(FYO=&5S+F-S=B(*;7-G<W1R(")A<'!U;G1I+F-S=B(*"B,Z(&1A=&$N<&AP
M.C,S('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3@*;7-G:60@(G9.;W1E
M(@IM<V=S='(@(G9.;W1E(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]P
M;R]L=E],5BYP;P``````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#,S,S8S`#$P-#$W,S8R-S0V`#`Q-S4T-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C($QA='9I86X@=')A;G-L
M871I;VYS(&9O<B!-;F5M;R!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@,C`P
M-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N
M9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($UN96UO('!A8VMA9V4N"B,@
M075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P,#0N"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($UN96UO(#$N,2XR7&XB"B)2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,2TQ.2`Q-3HU,"LP,C`P7&XB"B),
M87-T+51R86YS;&%T;W(Z($IA;FES($5I<V%K<R`\:F%N8W-`9'8N;'8^7&XB
M"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-
M12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U#4#$R-3=<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:71<;B(*(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU<F%L/2AN
M)3$P/3TQ("8F(&XE,3`P(3TQ,2`_(#`@.B!N("$](#`@/R`Q(#H@(@HB,BD[
M7&XB"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@;F]T97,B"FUS9W-T<B`B)60@<&EE>NYM97,B"@HC
M.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S
M9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!L=E],5BYP
M;R`H5'5R8F$@,2XQ*2`@(RTC+2,M(RTC7&XB"B)F86EL<R`E<R!V96EK<VWN
M9VD@:65LXF3G='-<;B(*(B,M(RTC+2,M(R`@;'9?3%8N<&\@*#$N,"D@(",M
M(RTC+2,M(UQN(@HB)7,@9&%T;F4@<V5K;>YG:2!I96SB9.=T82(*"B,Z(&YO
M=&5P861S+G!H<#HY.2!L:6(O8F%S92YP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B4&EE>NYM97,B
M"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(C$@;F]T
M92(*;7-G<W1R("(Q('!I97KN;64B"@HC.B!M96UO+G!H<#HQ-C(*(RP@9G5Z
M>GD*;7-G:60@(D%C8V5S<R!D96YI960@9&5L971I;F<@;F]T92XB"FUS9W-T
M<B`B2^_[;64@9'KG\&]T('!I97KN;65S+B(*"B,Z(&UE;6\N<&AP.C$Q,B!M
M96UO+G!H<#HQ,34*(RP@9G5Z>GD*;7-G:60@(D%C8V5S<R!D96YI960@;6]V
M:6YG('1H92!N;W1E+B(*;7-G<W1R(")+[_MM92!D>N?P;W0@<&EE>NYM97,N
M(@H*(SH@;65M;RYP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N(@IM<V=S='(@(DOO
M^VUE(&1ZY_!O="!P:65Z[FUE<RXB"@HC.B!M96UO+G!H<#HX,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T
M93H@)7,B"FUS9W-T<B`B2^_[;64@9'KG\&]T('!I97KN;65S+B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`S"B,L(&9U
M>GIY"FUS9VED(")!9&0@8V%T96=O<GDB"FUS9W-T<B`B2V%T96=O<FEJ82(*
M"B,Z(&UE;6\N<&AP.C4R"FUS9VED(")!9&1I;F<@02!.97<@3F]T92(*;7-G
M<W1R(")0:65V:65N;VIA;2!J875N=2!P:65Z[FUI(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0T"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B075G
M;_!I(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN
M8SHY.0HC+"!F=7IZ>0IM<V=I9"`B079A:6QA8FQE($-A=&5G;W)I97,Z(@IM
M<V=S='(@(E!I965J86UI92!L875K:3HB"@HC.B!T96UP;&%T97,O=FEE=R]M
M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM<V=I9"`B
M0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(D%T<&%K8>\@=7H@<V%R86MS='4B
M"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDW"B,L(&9U
M>GIY"FUS9VED(")"86-K('1O($YO=&5P860@3W!T:6]N<R(*;7-G<W1R(")!
M='!A:V'O('5Z('-A<F%K<W1U(@H*(SH@9&%T82YP:'`Z,S(@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B0U-6(@IM<V=S
M='(@(D-64R(*"B,Z(&1A=&$N<&AP.C4T('1E;7!L871E<R]V:65W+VUE;6\N
M:6YC.C$U"FUS9VED(")#871E9V]R>2(*;7-G<W1R(")+871E9V]R:6IA(@H*
M(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHR,@IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(DUA:6[N="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-0IM<V=I9"`B0VAA;F=E('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(DUA:6[N="!P:65Z[FUJ=2#P[6ER
M;_!A;F%S('5N(&5K<N)N82!I97-T873N:G5M=7,N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I
M9"`B0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T:&4@
M<W5M;6%R>2!V:65W+B(*;7-G<W1R(")2XF3N="!B96EG=2!D871U;75S(&MO
M<'-K873B/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@HC+"!F=7IZ
M>0IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!.;W1E<&%D+B(*;7-G<W1R
M(")*^W-U('!A<F%S=.(@:61E;G1I=.)T93HB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(D-L96%R($9O<FTB
M"FUS9W-T<B`B3F]T[G+N="(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E
M<&%D<RYI;F,Z,3<@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY
M-`HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDV"FUS9VED
M(")#<F5A=&4B"FUS9W-T<B`B27IV96ED;W0B"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B0W)E871E9"(*;7-G<W1R
M("))>G9E:61O="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0HC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="!.;W1E<&%D(@IM<V=S='(@(DK[<W4@<&%R
M87-TXB!I9&5N=&ETXG1E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-0IM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(").
M;VML=7/G=&%I<R#P[6ER;_!A;F%S(&MR:73G<FEJ<SHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E
M8W1I;VXZ(@IM<V=S='(@(DYO:VQU<^=TXB#P[6ER;_!A;F%S(&OB<G3N8F$Z
M(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-2!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHR-0HC.B!T96UP;&%T97,O=FEE=R]M96UO
M+FEN8SHV-`IM<V=I9"`B1&5L971E(@IM<V=S='(@(D1ZYW-T(@H*(SH@=&5M
M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!T:&ES(&YO=&4B"FUS9W-T<B`B3F5I>G;G;.=T:65S(&YE:V\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*;7-G:60@(D1E<V-E;F1I;F<B"FUS
M9W-T<B`B1&EL<W1O\&DB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A
M9',N:6YC.C@U"B,L(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;CHB"FUS9W-T
M<B`B07!R86MS=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")%:W+B;F$@:65S=&%T[FIU
M;6DB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B161I="(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(&QV7TQ6+G!O("A)35`@,RXQ*2`@(RTC+2,M(RTC
M7&XB"B)2961I[.=T7&XB"B(C+2,M(RTC+2,@(&QV7TQ6+G!O("A4=7)B82`Q
M+C$I("`C+2,M(RTC+2-<;B(*(E)E9&GLYW1<;B(*(B,M(RTC+2,M(R`@;'9?
M3%8N<&\@*#$N,"D@(",M(RTC+2,M(UQN(@HB3&%B;W0B"@HC.B!T96UP;&%T
M97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!L=E],5BYP;R`H24U0(#,N,2D@(",M(RTC+2,M(UQN(@HB4F5D:>SG=%QN
M(@HB(RTC+2,M(RTC("!L=E],5BYP;R`H5'5R8F$@,2XQ*2`@(RTC+2,M(RTC
M7&XB"B)2961I[.=T7&XB"B(C+2,M(RTC+2,@(&QV7TQ6+G!O("@Q+C`I("`C
M+2,M(RTC+2-<;B(*(DQA8F]T(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H
M96%D97)S+FEN8SHT-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z.#,*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@3F]T92(*;7-G<W1R(")0:65Z[FUJ=2!S87)A:W-T
M<R(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-30*;7-G
M:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ,@IM<V=I9"`B
M16UP='D@3F]T92(*;7-G<W1R(")4=6OP82!P:65Z[FUE(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ.0IM<V=I9"`B17AP;W)T(@IM<V=S='(@
M(D5K<W!O<G3G="(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z.`HC
M+"!F=7IZ>0IM<V=I9"`B17AP;W)T($YO=&5S(@IM<V=S='(@(E1U:_!A('!I
M97KN;64B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(D9?=6QL(%1E>'0B"FUS9W-T<B`B4&EL;G,@=&5K<W1S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHX"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G0@3F]T97,L(%-T97`@)60B"FUS9W-T
M<B`B5'5K\&$@<&EE>NYM92(*"B,Z(&1A=&$N<&AP.C$Y,PHC+"!F=7IZ>0IM
M<V=I9"`B26UP;W)T+T5X<&]R="!.;W1E<R(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(&QV7TQ6+G!O("A4=7)B82`Q+C$I("`C+2,M(RTC+2-<;B(*(DEM<&]R
M=.=T+T5K<W!O<G3G=%QN(@HB(RTC+2,M(RTC("!L=E],5BYP;R`H,2XP*2`@
M(RTC+2,M(RTC7&XB"B))979I;&MT+T5K<W!O<G3G="(*"B,Z('1E;7!L871E
M<R]V:65W+VUE;6\N:6YC.C0S"B,L(&9U>GIY"FUS9VED("),87-T($UO9&EF
M:65D(@IM<V=S='(@(E#G9.=J86ES(&WG;F5S:7,B"@HC.B!L:6(O87!I+G!H
M<#HW,@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@3F]T97,B"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(DUE;6\@5&5X="(*
M;7-G<W1R(")0:65Z[FUE<R!T96MS=',B"@HC.B!M96UO+G!H<#HV.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-;V1I9GEI;F<@)7,B"FUS9W-T<B`B3&%B;VIA
M;2`E<R(*"B,Z(&QI<W0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")->2!.;W1E
M<R(*;7-G<W1R(")0:65Z[FUE<R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HR,@IM<V=I9"`B3F5W($YO=&4B"FUS9W-T<B`B2F%U;F$@<&EE>NYM92(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#`*;7-G:60@(DYE>'0B
M"FUS9W-T<B`B3N)K86UA:7,B"@HC.B!L:6(O87!I+G!H<#HR,#8*;7-G:60@
M(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE;G4N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(DYO(&YO=&5P
M861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R("))97-T873N
M:G5M:2!N878@<&EE96IA;6DB"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N
M:6YC.C,*;7-G:60@(DYO(&YO=&5S(@IM<V=S='(@(E!I97KN;6IU(&YA=B(*
M"B,Z('1E;7!L871E<R]L:7-T+V5M<'1Y+FEN8SHS"FUS9VED(").;R!N;W1E
M<R!M871C:"!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P.0IM<V=I9"`B3F\@;F]T97,@=&\@
M9&ES<&QA>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE
M861E<G,N:6YC.C0V"B,L(&9U>GIY"FUS9VED(").;U]T92(*;7-G<W1R(")0
M:65Z[FUE<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-`IM<V=I9"`B
M3F]T92!#871E9V]R>2(*;7-G<W1R(")0:65Z[FUE<R!K871E9V]R:6IA(@H*
M(SH@=FEE=RYP:'`Z.#`@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z.0IM<V=I
M9"`B3F]T92!$971A:6QS(@IM<V=S='(@(E!I97KN;65S('-A='5R<R(*"B,Z
M(&YO=&5P861S+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(DYO=&4@3&ES=',B
M"FUS9W-T<B`B4&EE>NYM97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S,*;7-G:60@(DYO=&4@5&5X="(*;7-G<W1R(")0:65Z[FUE<R!T96MS=',B
M"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!F=7IZ>0IM<V=I
M9"`B3F]T92!?5&5X="(*;7-G<W1R(")0:65Z[FUE<R!T96MS=',B"@HC.B!V
M:65W+G!H<#HU-R!M96UO+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B3F]T92!N
M;W0@9F]U;F0N(@IM<V=S='(@(DYA=B!S=')O9&%M<R!P87II\F]J=6UU(&ML
M875S[G3B:G,@)7,B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHS-`HC
M+"!F=7IZ>0IM<V=I9"`B3F]T95]P860B"FUS9W-T<B`B4&EE>NYM97,B"@HC
M.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C<Y"B,L(&9U>GIY
M"FUS9VED(").;W1E<&%D)W,@;F%M93HB"FUS9W-T<B`B4&EE>NYM97,B"@HC
M.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"B,L(&9U>GIY
M"FUS9VED(").;W1E<&%D<R(*;7-G<W1R(")0:65Z[FUE<R(*"B,Z(&YO=&5P
M861S+G!H<#HS,PIM<V=I9"`B3F]T97!A9',@;75S="!H879E(&$@;F%M92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*(RP@9G5Z
M>GD*;7-G:60@(DYO=&5S(%-U;6UA<GDB"FUS9W-T<B`BSG-A(&%N;W3B8VEJ
M83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(P"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D-I
M=&%S(&]P8VEJ87,B"@HC.B!L:6(O87!I+G!H<#HQ.#,@;&EB+V%P:2YP:'`Z
M,C<T(&QI8B]A<&DN<&AP.C,T-2!L:6(O87!I+G!H<#HS-S0*(RP@9G5Z>GD*
M;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<G-O;NYG86ES
M(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHX,@HC+"!F
M=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R<V]N[F=A:7,B
M"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C4@=&5M<&QA=&5S+VQI
M<W0O:&5A9&5R+FEN8SHV"FUS9VED(")2969R97-H($QI<W0B"FUS9W-T<B`B
M071S=F%I9'II;N)T('-A<F%K<W1U(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H
M;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*(RP@9G5Z>GD*;7-G:60@(E)E;6]V
M92!C871E9V]R>2(*;7-G<W1R(")0:65Z[FUE<R!K871E9V]R:6IA(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S
M970B"FUS9W-T<B`B1'KG<W0@=FES=7,B"@HC.B!T96UP;&%T97,O;65M;R]M
M96UO+FEN8SHU-@IM<V=I9"`B4V%V92(*;7-G<W1R(")386=L86+B="(*"B,Z
M('-E87)C:"YP:'`Z,3<@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C0@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,Q"FUS9VED(")396%R8V@B
M"FUS9W-T<B`B365K;.=T(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@(E-E87)C
M:"!297-U;'1S(@IM<V=S='(@(DUE:VSG\&%N87,@<F5Z=6QTXG1I(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$W"FUS9VED(")396%R8V@@
M4V-O<&4B"FUS9W-T<B`B365K;.?P86YA<R!A<&IO;7,B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H
M(%]497AT(@IM<V=S='(@(DUE:VSG="!T96MS='4B"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C8W"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!N;W1E<&%D(@IM<V=S='(@(DYE:7IVYVSG=&EE<R!N96MO(@H*(SH@
M=&5M<&QA=&5S+VUE;G4N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M;F]T97!A9',@=&\@9&ES<&QA>3HB"FUS9W-T<B`B3F5I>G;G;.=T:65S(&YE
M:V\B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(DEZ
M=N=L:65T:65S(&1A='5M82!F;W)MXG1U.B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9FEL
M92!T;R!I;7!O<G0Z(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@;'9?3%8N<&\@
M*%1U<F)A(#$N,2D@(",M(RTC+2,M(UQN(@HB27IVYVQI971I97,@9F%I;'4L
M(&MO(&EM<&]R=.=T.EQN(@HB(RTC+2,M(RTC("!L=E],5BYP;R`H,2XP*2`@
M(RTC+2,M(RTC7&XB"B))>G;G;&EE=&EE<R!D871N:2!K;R!I96QA<^YT.B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!L=E],5BYP;R`H5'5R8F$@,2XQ*2`@(RTC
M+2,M(RTC7&XB"B))>G;G;&EE=&EE<R!KXF3B(&9O<FWB=.(@96MS<&]R=.=T
M.EQN(@HB(RTC+2,M(RTC("!L=E],5BYP;R`H,2XP*2`@(RTC+2,M(RTC7&XB
M"B))>G;G;&EE=&EE<R!F;W)MXG1U(&OB9.(@96MS<&]R=.=T.B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`Y"B,L(&9U
M>GIY"FUS9VED(")396QE8W1E9"!#871E9V]R:65S.B(*;7-G<W1R("))>G;G
M;&EE=&EE<R!K871E9V]R:6IU(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C,X"FUS9VED(")3:&]W(&%C=&EO;B!B=71T;VYS/R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@(E-H
M;W<@;F]T97!A9"!N86UE/R(*;7-G<W1R(")!='!A:V'O('5Z('-A<F%K<W1U
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0T"FUS9VED(")3:&]W(&YO
M=&5S(&9R;VT@=&AE<V4@8V%T96=O<FEE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C4P"FUS9VED(")3;W)T(&)Y
M($-A=&5G;W)Y(@IM<V=S='(@(M#M:7)O="!PYV,@:V%T96=O<FEJXFTB"@HC
M.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0V"B,L(&9U>GIY
M"FUS9VED(")3;W)T(&)Y($YO=&4@5&5X="(*;7-G<W1R(")0:65Z[FUE<R!T
M96MS=',B"@HC.B!M96UO+G!H<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('-A=F5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;65M
M;RYP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")4:&4@;F]T92!W87,@9&5L971E
M9"XB"FUS9W-T<B`B4&EE>NYM97,@;F5T:6MA(&EZ9'KG<W1A<RXB"@HC.B!N
M;W1E<&%D<RYP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!N;W1E<&%D(%PB)7-<(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E<R(*;7-G
M<W1R(")087)A:W-T=2!N96EZ9'IVXG,@86EZ=FEE=&]T+B(*"B,Z(&YO=&5P
M861S+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO
M=&5P860@7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(DED96YT
M:73B=&4@7"(E<UPB('9E:6MS;>YG:2!I>F1ZYW-T82XB"@HC.B!N;W1E<&%D
M<RYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E
M<&%D(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET
MXG1E(%PB)7-<(B!V96EK<VWN9VD@:7ID>N=S=&$N(@H*(SH@;F]T97!A9',N
M<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A
M9"!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(DED96YT:73B=&4@
M7"(E<UPB('-A9VQA8N)T82XB"@HC.B!D871A+G!H<#HQ.#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@;'9?3%8N
M<&\@*%1U<F)A(#$N,2D@(",M(RTC+2,M(UQN(@HB2^_[9&$@:6UP;W)TYVIO
M="!D871U<RY<;B(*(B,M(RTC+2,M(R`@;'9?3%8N<&\@*#$N,"D@(",M(RTC
M+2,M(UQN(@HB2^_[9&$@:65L87-O="!D871U<R(*"B,Z(&QI8B]A<&DN<&AP
M.C(P,`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*(B,M(RTC+2,M
M(R`@;'9?3%8N<&\@*%1U<F)A(#$N,2D@(",M(RTC+2,M(UQN(@HB2^_[9&$@
M:6UP;W)TYVIO="!D871U<RY<;B(*(B,M(RTC+2,M(R`@;'9?3%8N<&\@*#$N
M,"D@(",M(RTC+2,M(UQN(@HB2^_[9&$@:65L87-O="!D871U<R(*"B,Z(&QI
M8B]A<&DN<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@=DYO=&4@9&%T82XB"FUS9W-T<B`B(@HB(RTC
M+2,M(RTC("!L=E],5BYP;R`H5'5R8F$@,2XQ*2`@(RTC+2,M(RTC7&XB"B)+
M[_MD82!I;7!O<G3G:F]T(&1A='5S+EQN(@HB(RTC+2,M(RTC("!L=E],5BYP
M;R`H,2XP*2`@(RTC+2,M(RTC7&XB"B)+[_MD82!I96QA<V]T(&1A='5S(@H*
M(SH@;65M;RYP:'`Z,34W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@=&AE(&YO=&4Z("5S(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@;'9?3%8N<&\@*%1U<F)A(#$N,2D@(",M(RTC
M+2,M(UQN(@HB2^_[9&$@:6UP;W)TYVIO="!D871U<RY<;B(*(B,M(RTC+2,M
M(R`@;'9?3%8N<&\@*#$N,"D@(",M(RTC+2,M(UQN(@HB2^_[9&$@:65L87-O
M="!D871U<R(*"B,Z(&UE;6\N<&AP.C$S,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&4@;F]T93H@
M)7,B"FUS9W-T<B`B4F%DXG,@:^_[9&$@<V%G;&%BXFIO="!M96QN<F%K<W1U
M+B(*"B,Z('9I97<N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@=FEE=VEN9R!T:&ES(&YO=&5P860Z("5S
M(@IM<V=S='(@(E)A9.)S(&OO^V1A(&%P<VMA=&]T('!I97!R87/N=&\@=N=S
M='5L:2XB"@HC.B!D871A+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V5R92!N;R!M96UO<R!T;R!E>'!O<G0N(@IM<V=S='(@(DYA=B!N;W1I:W5M
M=2!K;R!E:W-P;W)TYW0B"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H:7,@
M9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@
M;F]T97!A9',N<&AP.C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F5V87(@;F5O
M9'KG<W0@)7,N(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3@*(RP@
M9G5Z>GD*;7-G:60@(E5N9&\@8VAA;F=E<R(*;7-G<W1R(")!=&-E;'0@:7IM
M86GR87,B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ-B!T96UP;&%T
M97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z,30*(SH@;&EB+TUN96UO+G!H
M<#HR,#8@;&EB+TUN96UO+G!H<#HR,#<@;&EB+TUN96UO+G!H<#HR,C$@;&EB
M+TUN96UO+G!H<#HR,C(*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P-0IM
M<V=I9"`B56YF:6QE9"(*;7-G<W1R(").96ML87-I9FECYW1S(@H*(SH@;&EB
M+V%P:2YP:'`Z,C,V(&QI8B]A<&DN<&AP.C,P.2!L:6(O87!I+G!H<#HT,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E
M.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C(R"FUS9VED(")7:&EC:"!.;W1E<&%D('-H;W5L9"!T:&4@;F]T97,@8F4@
M861D960@=&\_(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C0R(&1A=&$N<&AP
M.C$R-2!M96UO+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@;F]T97,N(@IM
M<V=S='(@(B(*"B,Z('9I97<N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P
M860@)7,N(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H<#HV-0HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@;F]T97!A9"!T;R!B92!D96QE
M=&5D+B(*;7-G<W1R(")*XFEZ=N=L87,@:61E;G1I=.)T92P@:V\@:7ID>N=S
M="XB"@HC.B!T96UP;&%T97,O<')E9G,O;F]T97!A9'-E;&5C="YI;F,Z,3`*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!N;W1E<&%D.B(*;7-G<W1R
M(")*^W-U('!A<F%S=.(@:61E;G1I=.)T93HB"@HC.B!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.C8U"B,L(&9U>GIY"FUS9VED(")9;W5R(&YO
M=&5P861S.B(*;7-G<W1R(")*^W-U(&ED96YT:73B=&5S.B(*"B,Z('1E;7!L
M871E<R]V:65W+VUE;6\N:6YC.C(X('1E;7!L871E<R]V:65W+VUE;6\N:6YC
M.C8W"B,L(&9U>GIY"FUS9VED(")?0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@
M(D%T<&%K8>\@=7H@<V%R86MS='4B"@HC.B!T96UP;&%T97,O;65M;R]M96UO
M+FEN8SHU,2!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C4P"B,L
M(&9U>GIY"FUS9VED(")?0V%T96=O<GDB"FUS9W-T<B`B2V%T96=O<FEJ82(*
M"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(U('1E;7!L871E<R]V:65W
M+VUE;6\N:6YC.C8T"B,L(&9U>GIY"FUS9VED(")?1&5L971E(@IM<V=S='(@
M(D1ZYW-T(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C$@=&5M<&QA
M=&5S+W9I97<O;65M;RYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(E]%9&ET(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@;'9?3%8N<&\@*$E-4"`S+C$I("`C+2,M
M(RTC+2-<;B(*(E)E9&GLYW1<;B(*(B,M(RTC+2,M(R`@;'9?3%8N<&\@*%1U
M<F)A(#$N,2D@(",M(RTC+2,M(UQN(@HB4F5D:>SG=%QN(@HB(RTC+2,M(RTC
M("!L=E],5BYP;R`H,2XP*2`@(RTC+2,M(RTC7&XB"B),86)O="(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,`HC+"!F=7IZ>0IM<V=I9"`B
M7T9I<G-T($QI;F4B"FUS9W-T<B`B4&ER;>(@;&%P82(*"B,Z(&QI8B]-;F5M
M;RYP:'`Z,C@Q"B,L(&9U>GIY"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G
M<W1R("(B"B(C+2,M(RTC+2,@(&QV7TQ6+G!O("A4=7)B82`Q+C$I("`C+2,M
M(RTC+2-<;B(*(DEM<&]R=.=T+T5K<W!O<G3G=%QN(@HB(RTC+2,M(RTC("!L
M=E],5BYP;R`H,2XP*2`@(RTC+2,M(RTC7&XB"B))979I;&MT+T5K<W!O<G3G
M="(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8T"B,L(&9U>GIY"FUS9VED(")?3&ES
M="!.;W1E<R(*;7-G<W1R(")0:65Z[FUJ=2!S87)A:W-T<R(*"B,Z(&QI8B]-
M;F5M;RYP:'`Z,C<V"B,L(&9U>GIY"FUS9VED(")?37D@3F]T97!A9',B"FUS
M9W-T<B`B4&EE>NYM97,B"@HC.B!L:6(O36YE;6\N<&AP.C(V.0HC+"!F=7IZ
M>0IM<V=I9"`B7TYE=R!.;W1E(@IM<V=S='(@(DIA=6YA('!I97KN;64B"@HC
M.B!L:6(O36YE;6\N<&AP.C(X-@HC+"!F=7IZ>0IM<V=I9"`B7U!R:6YT(@IM
M<V=S='(@(D1R=6OB="(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<R"B,L(&9U>GIY
M"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(DUE:VSG="(*"B,Z(&1A=&$N<&AP
M.CDQ('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B;F]T97,N
M8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,S('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(G9.;W1E(@IM<V=S='(@
M(E!I97KN;65S(@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O<&\O
M;FY?3D\N<&\`````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R-30R-P`Q,#0Q-S,V,C<T-@`P,3<U,S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!-;F5M;R!.;W)W96=I86X@
M3GEN;W)S:R!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@4&5R
M+5-T:6%N(%9A=&YE"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R
M('1H92!S86UE(&QI8V5N<V4@87,@=&AE($UN96UO('!A8VMA9V4N"B,@4&5R
M+5-T:6%N(%9A=&YE(#QP<W9`;W)S=&$N;W)G/BP@,C`P,BX*(R`*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($UN96UO(#(N,"UC
M=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R+3`V+3`X(#(R.C0R*S`Q
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@4&5R+5-T:6%N(%9A=&YE(#QP<W9`
M;W)S=&$N;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@3F]R=V5G:6%N($YY;F]R
M<VL@/&YY;F]R<VM`;W)S=&$N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U
M.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC
M.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B5D(&YO=&5S(@IM<V=S='(@(B5D(&UE;6]S(@H*(SH@
M=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP
M;W)T960B"FUS9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP.CDY(&QI8B]B87-E
M+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z,PIM<V=I
M9"`B,2!N;W1E(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP.C$V,@IM<V=I9"`B
M06-C97-S(&1E;FEE9"!D96QE=&EN9R!N;W1E+B(*;7-G<W1R("(B"@HC.B!M
M96UO+G!H<#HQ,3(@;65M;RYP:'`Z,3$U"FUS9VED(")!8V-E<W,@9&5N:65D
M(&UO=FEN9R!T:&4@;F]T92XB"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T
M92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T93H@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T
M+FEN8SHQ,#,*(RP@9G5Z>GD*;7-G:60@(D%D9"!C871E9V]R>2(*;7-G<W1R
M(")+871E9V]R:2(*"B,Z(&UE;6\N<&AP.C4R"B,L(&9U>GIY"FUS9VED(")!
M9&1I;F<@02!.97<@3F]T92(*;7-G<W1R("),96=G('1I;"!E:70@;GET="!N
M;W1A="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-`IM<V=I9"`B07-C
M96YD:6YG(@IM<V=S='(@(E-T:6=A;F1E(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY.0IM<V=I9"`B079A:6QA8FQE($-A
M=&5G;W)I97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N
M:6YC.C(X('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C8W"B,L(&9U>GIY"FUS
M9VED(")"86-K('1O($YO=&5P860B"FUS9W-T<B`B5&EL8F%K92!T:6P@;F]T
M871L:7-T92(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z
M.3<*(RP@9G5Z>GD*;7-G:60@(D)A8VL@=&\@3F]T97!A9"!/<'1I;VYS(@IM
M<V=S='(@(E1I;&)A:V4@=&EL(&YO=&%T;&ES=&4B"@HC.B!D871A+G!H<#HS
M,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS
M9W-T<B`B(@H*(SH@9&%T82YP:'`Z-30@=&5M<&QA=&5S+W9I97<O;65M;RYI
M;F,Z,34*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G;W)I(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHR,@HC+"!F=7IZ>0IM
M<V=I9"`B0VAA;F=E(@IM<V=S='(@(D%N9W)E(&5N9')I;F=A<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E
M('EO=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(D5N9')E(&%L=&5R;F%T:78@9F]R('-O<G1E<FEN9R!O9R!V:7-I;F<@
M878@;F]T870B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE
M8W0N:6YC.CDS"FUS9VED(")#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T
M;R!L:7-T(&EN('1H92!S=6UM87)Y('9I97<N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@IM<V=I9"`B0VAO;W-E('EO=7(@9&5F
M875L="!.;W1E<&%D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z,S(*;7-G:60@(D-L96%R($9O<FTB"FUS9W-T<B`B3G5L
M;'-T:6QL('-K:F5M82(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D
M<RYI;F,Z,3<@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-`HC
M.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDV"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,S4*;7-G:60@(D-R96%T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Q"B,L(&9U>GIY"FUS9VED(")$969A=6QT($YO=&5P860B
M"FUS9W-T<B`B4W1A;F1A<F0@<V]R=&5R:6YG<VMR:71E<FEU;3HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4*;7-G:60@(D1E9F%U;'0@<V]R=&EN
M9R!C<FET97)I83HB"FUS9W-T<B`B4W1A;F1A<F0@<V]R=&5R:6YG<VMR:71E
M<FEU;3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D1E
M9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(E-T86YD87)D('-O
M<G1E<FEN9W-R96MK96;X;&=J93HB"@HC.B!T96UP;&%T97,O;F]T97!A9',O
M;F]T97!A9',N:6YC.CDU('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(U"B,Z
M('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C8T"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4B"FUS9W-T<B`B4VQE='0@;F]T870B"@HC.B!T96UP;&%T97,O;65M
M;R]M96UO+FEN8SHV-PIM<V=I9"`B1&5L971E('1H:7,@;F]T92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*;7-G:60@(D1E<V-E
M;F1I;F<B"FUS9W-T<B`B4WEN:V%N9&4B"@HC.B!T96UP;&%T97,O;F]T97!A
M9',O;F]T97!A9',N:6YC.C@U"B,L(&9U>GIY"FUS9VED(")$97-C<FEP=&EO
M;CHB"FUS9W-T<B`B4VMI;&1R:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B5FES:6YG
M<V%L=&5R;F%T:78B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T
M96UP;&%T97,O=FEE=R]M96UO+FEN8SHV,`IM<V=I9"`B161I="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0T(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HX,PIM<V=I9"`B161I="!.;W1E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-30*;7-G:60@
M(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ,@IM<V=I9"`B16UP
M='D@3F]T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$Y"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@3F]T97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(Q"B,L(&9U
M>GIY"FUS9VED(")&7W5L;"!497AT(@IM<V=S='(@(D9U;&QT96MS="(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G0@3F]T97,L(%-T97`@)60B"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z,3DS"FUS9VED("));7!O<G0O17AP;W)T($YO=&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C0S"FUS9VED("),87-T
M($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C<R"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!.;W1E<R(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HU,PIM<V=I9"`B365M;R!497AT(@IM<V=S='(@(DYO=&%T=&5K<W0B
M"@HC.B!M96UO+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GEI
M;F<@)7,B"FUS9W-T<B`B16YD<F%R("5S(@H*(SH@;&ES="YP:'`Z,S4*;7-G
M:60@(DUY($YO=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HR,@HC+"!F=7IZ>0IM<V=I9"`B3F5W($YO=&4B"FUS9W-T<B`B3GET
M="!N;W1A="(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#`*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,C`V"FUS9VED
M(").;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M96YU+FEN8SHW"FUS9VED(").;R!N;W1E<&%D<R!A<F4@
M879A:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQI<W0O:&5A9&5R+FEN8SHS"B,L(&9U>GIY"FUS9VED(").;R!N;W1E<R(*
M;7-G<W1R("));F=E;B!N;W1A="(*"B,Z('1E;7!L871E<R]L:7-T+V5M<'1Y
M+FEN8SHS"FUS9VED(").;R!N;W1E<R!M871C:"!T:&4@8W5R<F5N="!C<FET
M97)I82XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P
M.0IM<V=I9"`B3F\@;F]T97,@=&\@9&ES<&QA>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0V"FUS9VED(").;U]T
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0*(RP@
M9G5Z>GD*;7-G:60@(DYO=&4@0V%T96=O<GDB"FUS9W-T<B`B3F]T871K871E
M9V]R:2(*"B,Z('9I97<N<&AP.C@P('1E;7!L871E<R]V:65W+VUE;6\N:6YC
M.CD*(RP@9G5Z>GD*;7-G:60@(DYO=&4@1&5T86EL<R(*;7-G<W1R(").;W1A
M=&1E=&%L:F%R(@H*(SH@;F]T97!A9',N<&AP.C$Q,`IM<V=I9"`B3F]T92!,
M:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,*
M(RP@9G5Z>GD*;7-G:60@(DYO=&4@5&5X="(*;7-G<W1R(").;W1A='1E:W-T
M(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,C8*(RP@9G5Z>GD*;7-G
M:60@(DYO=&4@7U1E>'0B"FUS9W-T<B`B3F]T871T96MS="(*"B,Z('9I97<N
M<&AP.C4W(&UE;6\N<&AP.C8P"FUS9VED(").;W1E(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,S0*;7-G:60@
M(DYO=&5?<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N
M;W1E<&%D<RYI;F,Z-SD*;7-G:60@(DYO=&5P860G<R!N86UE.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"FUS
M9VED(").;W1E<&%D<R(*;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z,S,*
M;7-G:60@(DYO=&5P861S(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(").;W1E<R!3=6UM
M87)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`*;7-G:60@(D]T:&5R($]P=&EO;G,B
M"FUS9W-T<B`B06YD<F4@86QT97)N871I=B(*"B,Z(&QI8B]A<&DN<&AP.C$X
M,R!L:6(O87!I+G!H<#HR-S0@;&EB+V%P:2YP:'`Z,S0U(&QI8B]A<&DN<&AP
M.C,W-`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHX,@IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R
M+FEN8SHU('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z-@IM<V=I9"`B4F5F
M<F5S:"!,:7-T(@IM<V=S='(@(D9R:7-K(&]P<"!L:7-T92(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`U"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@8V%T96=O<GDB"FUS9W-T<B`B3F]T871K871E9V]R
M:2(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.38*;7-G
M:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N
M:6YC.C4V"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S='(@(DQA9W)E(&YO
M=&%T(@H*(SH@<V5A<F-H+G!H<#HQ-R!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S$*;7-G:60@
M(E-E87)C:"(*;7-G<W1R(")3^&LB"@HC.B!L:7-T+G!H<#HU-PIM<V=I9"`B
M4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B4_AK97)E<W5L=&%T(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$W"FUS9VED(")396%R8V@@4V-O
M<&4B"FUS9W-T<B`B4_AK96]M<N5D92(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHY"B,L(&9U>GIY"FUS9VED(")396%R8V@@7U1E>'0B"FUS
M9W-T<B`B4_AK97-T<F5N9R(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E
M<&%D<RYI;F,Z-C<*;7-G:60@(E-E;&5C="!A(&YO=&5P860B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$V"FUS9VED(")396QE8W0@;F]T
M97!A9',@=&\@9&ES<&QA>3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R
M;6%T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C,W"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U"FUS9VED(")3
M96QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z
M,3`Y"FUS9VED(")396QE8W1E9"!#871E9V]R:65S.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,S@*;7-G:60@(E-H;W<@86-T:6]N
M(&)U='1O;G,_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HT,0IM<V=I9"`B4VAO=R!N;W1E<&%D(&YA;64_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT-`IM<V=I9"`B4VAO=R!N;W1E<R!F
M<F]M('1H97-E(&-A=&5G;W)I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQI<W0O;65M;U]H96%D97)S+FEN8SHU,`IM<V=I9"`B4V]R="!B>2!#871E
M9V]R>2(*;7-G<W1R(")3;W)T97(@971T97(@:V%T96=O<FDB"@HC.B!T96UP
M;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0V"B,L(&9U>GIY"FUS9VED
M(")3;W)T(&)Y($YO=&4@5&5X="(*;7-G<W1R(")3;W)T97(@971T97(@:V%T
M96=O<FDB"@HC.B!M96UO+G!H<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('-A=F5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;65M
M;RYP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")4:&4@;F]T92!W87,@9&5L971E
M9"XB"FUS9W-T<B`B26YG96X@;F]T870@=F%R="!S;&5T=&$N(@H*(SH@;F]T
M97!A9',N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D
M(%PB)7-<(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!N;W1E<&%D<RYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO
M=&5P860@7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(B(*"B,Z
M(&YO=&5P861S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T
M97!A9"!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@
M;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E
M<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C(P,`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C,Y,PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@=DYO=&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z,34W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@<F5M;W9I;F<@=&AE(&YO=&4Z("5S(@IM<V=S='(@(E!R;V)L96T@=F5D
M('-L971T:6YG(&%V(&YO=&%T+B(*"B,Z(&UE;6\N<&AP.C$S,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN
M9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B4')O8FQE;2!V960@<VQE='1I;F<@
M878@;F]T870N(@H*(SH@=FEE=RYP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@=&AI<R!N;W1E<&%D.B`E
M<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B
M5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E>'!O<G0N(@IM<V=S='(@(D1E="!F
M^')E<W!U<G1E(&YO=&%T970@96MS:7-T97)E<B!I:VMJ92XB"@HC.B!D871A
M+G!H<#HQ,#4*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O
M<G1E9"XB"FUS9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP.C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU.`HC+"!F=7IZ
M>0IM<V=I9"`B56YD;R!C:&%N9V5S(@IM<V=S='(@(D%N9W)E(&5N9')I;F=A
M<B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$V('1E;7!L871E<R]L
M:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ-`HC.B!L:6(O36YE;6\N<&AP.C(P
M-B!L:6(O36YE;6\N<&AP.C(P-R!L:6(O36YE;6\N<&AP.C(R,2!L:6(O36YE
M;6\N<&AP.C(R,@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3`U"FUS9VED
M(")5;F9I;&5D(@IM<V=S='(@(E5A<FMI=F5R="(*"B,Z(&QI8B]A<&DN<&AP
M.C(S-B!L:6(O87!I+G!H<#HS,#D@;&EB+V%P:2YP:'`Z-#`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,@IM<V=I
M9"`B5VAI8V@@3F]T97!A9"!S:&]U;&0@=&AE(&YO=&5S(&)E(&%D9&5D('1O
M/R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HT,B!D871A+G!H<#HQ,C4@;65M
M;RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&YO=&5S+B(*;7-G<W1R("(B
M"@HC.B!V:65W+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S+B(*
M;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A(&YO=&5P860@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B1'4@;>4@9OAR<W0@=F5L:F4@;6EN<W0@96ET="!N;W1A="XB"@HC
M.B!T96UP;&%T97,O<')E9G,O;F]T97!A9'-E;&5C="YI;F,Z,3`*;7-G:60@
M(EEO=7(@9&5F875L="!N;W1E<&%D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P
M861S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR
M."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B
M7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")4:6QB86ME('1I;"!N;W1A=&QI
M<W1E(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3$@=&5M<&QA=&5S
M+VQI<W0O;65M;U]H96%D97)S+FEN8SHU,`HC+"!F=7IZ>0IM<V=I9"`B7T-A
M=&5G;W)Y(@IM<V=S='(@(DMA=&5G;W)I(@H*(SH@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z,C4@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C0*(RP@9G5Z
M>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B4VQE='0@;F]T870B"@HC.B!T
M96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O=FEE=R]M96UO
M+FEN8SHV,`IM<V=I9"`B7T5D:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C(P"FUS9VED(")?1FER<W0@3&EN92(*;7-G
M<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP.C(X,0IM<V=I9"`B7TEM<&]R="]%
M>'!O<G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUN96UO+G!H<#HR-C0*(RP@9G5Z
M>GD*;7-G:60@(E],:7-T($YO=&5S(@IM<V=S='(@(E9I<R!N;W1A="(*"B,Z
M(&QI8B]-;F5M;RYP:'`Z,C<V"FUS9VED(")?37D@3F]T97!A9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+TUN96UO+G!H<#HR-CD*;7-G:60@(E].97<@3F]T92(*
M;7-G<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP.C(X-@IM<V=I9"`B7U!R:6YT
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<R"B,L(&9U>GIY"FUS
M9VED(")?4V5A<F-H(@IM<V=S='(@(E/X:R(*"B,Z(&1A=&$N<&AP.CDQ('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B;F]T97,N8W-V(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,S('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,3@*;7-G:60@(G9.;W1E(@IM<V=S='(@(B(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W!O+W!L7U!,+G!O````````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`S-#0`,3`T
M,3<S-C(W-#8`,#$W-3(V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````",@4&]L:7-H('1R86YS;&%T:6]N<R!F;W(@36YE;6\@
M<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!-3D5-3R!P86-K86=E+@HC($UA=&5U<WH@2V%M:6YS:VD@
M/&UA=&EP;$!P;&0M;&EN=7@N;W)G/BP@,C`P-2X*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@36YE;6\M:#,M,BXP7&XB"B)2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP,2TS,2`R,3HT,2LP,C`P7&XB"B),
M87-T+51R86YS;&%T;W(Z($UA=&5U<WH@2V%M:6YS:VD@/&UA=&EP;$!P;&0M
M;&EN=7@N;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@4&]L:7-H(#QI,3AN0&QI
M<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,EQN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@=&5M<&QA
M=&5S+VQI<W0O:&5A9&5R+FEN8SHS"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&YO=&5S(@IM<V=S='(@(B5D(&YO=&%T96LB"@HC.B!T96UP;&%T97,O;65M
M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!C:&%R86-T
M97)S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R
M("(E<R!P;&EK\W<@>F%I;7!O<G1O=V%N>2!P;VUYMFQN:64B"@HC.B!N;W1E
M<&%D<RYP:'`Z.3D@;&EB+V)A<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B3F]T871N:6L@)7,B"@HC.B!T
M96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(C$@;F]T92(*;7-G
M<W1R("(Q(&YO=&%T:V$B"@HC.B!M96UO+G!H<#HQ-C(*;7-G:60@(D%C8V5S
M<R!D96YI960@9&5L971I;F<@;F]T92XB"FUS9W-T<B`B3FEE(&UA<WH@9&]S
M=.IP=2P@86)Y('5S=6ZQYB!N;W1A=&OJ(@H*(SH@;65M;RYP:'`Z,3$R(&UE
M;6\N<&AP.C$Q-0IM<V=I9"`B06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO
M=&4N(@IM<V=S='(@(DYI92!M87-Z(&1O<W3J<'4L(&%B>2!P<GIE;FEEMN8@
M;F]T871KZB(*"B,Z(&UE;6\N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N(@IM<V=S='(@(DYI
M92!M87-Z(&1O<W3J<'4L(&%B>2!Z87!I<V'F(&YO=&%T:^H@9&\@)7,N(@H*
M(SH@;65M;RYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E
M;FEE9"!S879I;F<@;F]T93H@)7,B"FUS9W-T<B`B3FEE(&UA<WH@9&]S=.IP
M=2P@86)Y('IA<&ES8>8@;F]T871KZCH@)7,B"@HC.B!T96UP;&%T97,O<')E
M9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P,PIM<V=I9"`B061D(&-A=&5G
M;W)Y(@IM<V=S='(@(D1O9&%J(&MA=&5G;W)IZB(*"B,Z(&UE;6\N<&AP.C4R
M"FUS9VED(")!9&1I;F<@02!.97<@3F]T92(*;7-G<W1R(")$;V1A:B!N;W>Q
M(&YO=&%T:^HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0*;7-G:60@
M(D%S8V5N9&EN9R(*;7-G<W1R(")2;W-NL6-O(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY.0IM<V=I9"`B079A:6QA8FQE
M($-A=&5G;W)I97,Z(@IM<V=S='(@(D1O<W3J<&YE(&MA=&5G;W)I93HB"@HC
M.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M
M96UO+FEN8SHV-PIM<V=I9"`B0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(E=R
M\^8@9&\@3F]T871N:6MA(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P
M861S+FEN8SHY-PIM<V=I9"`B0F%C:R!T;R!.;W1E<&%D($]P=&EO;G,B"FUS
M9W-T<B`B5W+SYB!D;R!O<&-J:2!.;W1A=&YI:V$B"@HC.B!D871A+G!H<#HS
M,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS
M9W-T<B`B0U-6(@H*(SH@9&%T82YP:'`Z-30@=&5M<&QA=&5S+W9I97<O;65M
M;RYI;F,Z,34*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G;W)I82(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,C(*;7-G:60@
M(D-H86YG92(*;7-G<W1R("):;6EA;F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,34*;7-G:60@(D-H86YG92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@
M9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("):;6EE\2!S;W)T;W=A;FEE('1W
M;VEC:"!N;W1A=&5K(&]R87H@<&%R86UE=')Y('=YMG=I971L86YI82(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3,*;7-G
M:60@(D-H;V]S92!T:&4@;65M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE
M('-U;6UA<GD@=FEE=RXB"FUS9W-T<B`B5WEB:65R>B!Z(&QI<W1Y(&MA=&5G
M;W)IZB!N;W1A=&MI('<@<VMR\V-O;GEM('!O9&=LL61Z:64N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R"FUS9VED(")#:&]O<V4@>6]U<B!D969A
M=6QT($YO=&5P860N(@IM<V=S='(@(E=Y8FEE<GH@9&]M>;9L;GD@;F]T871N
M:6LB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S(*;7-G:60@
M(D-L96%R($9O<FTB"FUS9W-T<B`B5WEC>GFVYB!F;W)M=6QA<GHB"@HC.B!T
M96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C$W('1E;7!L871E<R]N
M;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E871E(@IM<V=S='(@(E1W\W)Z
M(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,S4*;7-G:60@(D-R96%T
M960B"FUS9W-T<B`B571W;W)Z;VYO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Q"FUS9VED(")$969A=6QT($YO=&5P860B"FUS9W-T<B`B1&]M>;9L
M;GD@;F]T871N:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4*;7-G
M:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`B1&]M>;9L
M;F4@:W)Y=&5R:75M('-O<G1O=V%N:6$Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0V"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*
M;7-G<W1R(")$;VUYMFQN>2!S<&]S\V(@<V]R=&]W86YI83HB"@HC.B!T96UP
M;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDU('1E;7!L871E<R]V:65W
M+VUE;6\N:6YC.C(U"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C8T"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L871E<R]M96UO
M+VUE;6\N:6YC.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AI<R!N;W1E
M(@IM<V=S='(@(E=Y8FEE<GH@;F]T871N:6LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#4*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B36%L96JQ
M8V\B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C@U"FUS
M9VED(")$97-C<FEP=&EO;CHB"FUS9W-T<B`B3W!I<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S
M='(@(D]P8VIE('=YMG=I971L86YI82(*"B,Z('1E;7!L871E<R]V:65W+VUE
M;6\N:6YC.C(Q('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C8P"FUS9VED(")%
M9&ET(@IM<V=S='(@(D5D>71U:B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?
M<W5M;6%R:65S+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET(%PB)7-<(B(*;7-G<W1R(")%9'ET=6HB"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7VAE861E<G,N:6YC.C0T(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HX
M,PIM<V=I9"`B161I="!.;W1E(@IM<V=S='(@(D5D>71U:B!N;W1KZB(*"B,Z
M('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-30*;7-G:60@(D5D
M:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ,@IM<V=I9"`B16UP='D@
M3F]T92(*;7-G<W1R(")0=7-T82!N;W1K82(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,3D*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%:W-P;W)T
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O
M<G0@3F]T97,B"FUS9W-T<B`B16MS<&]R="!N;W1A=&5K(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C(Q"FUS9VED(")&7W5L;"!497AT(@IM
M<V=S='(@(D-ALWD@=&5K<W0@*%]U*2(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@3F]T97,L
M(%-T97`@)60B"FUS9W-T<B`B26UP;W)T;W=A;FEE(&YO=&%T96LL(&MR;VL@
M)60B"@HC.B!D871A+G!H<#HQ.3,*;7-G:60@(DEM<&]R="]%>'!O<G0@3F]T
M97,B"FUS9W-T<B`B26UO<G0O16MS<&]R="!N;W1A=&5K(@H*(SH@=&5M<&QA
M=&5S+W9I97<O;65M;RYI;F,Z-#,*;7-G:60@(DQA<W0@36]D:69I960B"FUS
M9W-T<B`B3W-T871N:6$@;6]D>69I:V%C:F$B"@HC.B!L:6(O87!I+G!H<#HW
M,@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@3F]T97,B"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-3,*;7-G:60@(DUE;6\@5&5X="(*;7-G<W1R(")496MS
M="!N;W1A=&MI(@H*(SH@;65M;RYP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B36]D:69Y:6YG("5S(@IM<V=S='(@(D5D>6-J82`E<R(*"B,Z(&QI<W0N
M<&AP.C,U"FUS9VED(")->2!.;W1E<R(*;7-G<W1R(")-;VIE(&YO=&%T:VDB
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*;7-G:60@(DYE=R!.;W1E
M(@IM<V=S='(@(DYO=V$@;F]T871K82(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z-#`*;7-G:60@(DYE>'0B"FUS9W-T<B`B3F%S=.IP;F4B"@HC
M.B!L:6(O87!I+G!H<#HR,#8*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A
M<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*
M;7-G:60@(DYO(&YO=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*
M;7-G<W1R(").:65D;W-TZG!N92!N;W1A=&YI:VD@9&QA(&=OMF-I+B(*"B,Z
M('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z,PIM<V=I9"`B3F\@;F]T97,B
M"FUS9W-T<B`B0G)A:R!N;W1A=&5K(@H*(SH@=&5M<&QA=&5S+VQI<W0O96UP
M='DN:6YC.C,*;7-G:60@(DYO(&YO=&5S(&UA=&-H('1H92!C=7)R96YT(&-R
M:71E<FEA+B(*;7-G<W1R("*O861N92!N;W1A=&MI(&YI92!S<&6S;FEA:K$@
M;V)E8VYE9V\@:W)Y=&5R:75M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$P.0IM<V=I9"`B3F\@;F]T97,@=&\@9&ES<&QA>2(*;7-G<W1R(")"<F%K
M(&YO=&%T96L@9&\@=WFV=VEE=&QE;FEA(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M;65M;U]H96%D97)S+FEN8SHT-@IM<V=I9"`B3F]?=&4B"FUS9W-T<B`B3F]?
M=&%T:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0*;7-G:60@(DYO
M=&4@0V%T96=O<GDB"FUS9W-T<B`B2V%T96=O<FEA(&YO=&%T:VDB"@HC.B!V
M:65W+G!H<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHY"FUS9VED(").
M;W1E($1E=&%I;',B"FUS9W-T<B`B4WIC>F5G\[-Y(&YO=&%T:VDB"@HC.B!N
M;W1E<&%D<RYP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(").;W1E($QI<W1S(@IM
M<V=S='(@(E-Z8WIE9_.S>2!N;W1A=&MI(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S"FUS9VED(").;W1E(%1E>'0B"FUS9W-T<B`B5&5K<W0@;F]T
M871K:2(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C(V"FUS9VED(").
M;W1E(%]497AT(@IM<V=S='(@(E]496MS="!N;W1A=&MI(@H*(SH@=FEE=RYP
M:'`Z-3<@;65M;RYP:'`Z-C`*;7-G:60@(DYO=&4@;F]T(&9O=6YD+B(*;7-G
M<W1R(").;W1A=&MA(&YI97IN86QE>FEO;F$N(@H*(SH@=&5M<&QA=&5S+VUE
M;6\O;65M;RYI;F,Z,S0*;7-G:60@(DYO=&5?<&%D(@IM<V=S='(@(DYO=&%T
M;FEK("A?<"DB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC
M.C<Y"FUS9VED(").;W1E<&%D)W,@;F%M93HB"FUS9W-T<B`B3F%Z=V$@;F]T
M871N:6MA.B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z
M-C$*;7-G:60@(DYO=&5P861S(@IM<V=S='(@(DYO=&%T;FEK:2(*"B,Z(&YO
M=&5P861S+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B3F]T97!A9',@;75S="!H
M879E(&$@;F%M92XB"FUS9W-T<B`B3F%Z=V$@;F]T871N:6MA.B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(").;W1E<R!3=6UM87)Y(@IM
M<V=S='(@(E-K<O-C;VYE(&YO=&%T:VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P"FUS9VED(")/=&AE
M<B!/<'1I;VYS(@IM<V=S='(@(DEN;F4@;W!C:F4B"@HC.B!L:6(O87!I+G!H
M<#HQ.#,@;&EB+V%P:2YP:'`Z,C<T(&QI8B]A<&DN<&AP.C,T-2!L:6(O87!I
M+G!H<#HS-S0*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(D)R
M86L@9&]S=.IP=2(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI
M;F,Z.#(*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E5P<F%W;FEE;FEA
M(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHU('1E;7!L871E<R]L
M:7-T+VAE861E<BYI;F,Z-@IM<V=I9"`B4F5F<F5S:"!,:7-T(@IM<V=S='(@
M(D]DMG=I9;\@;&ES=.HB"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA
M<GES96QE8W0N:6YC.C$P-0IM<V=I9"`B4F5M;W9E(&-A=&5G;W)Y(@IM<V=S
M='(@(E5S=?$@:V%T96=O<FGJ(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS9W-T<B`B4F5S970B"@HC
M.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU-@IM<V=I9"`B4V%V92(*;7-G
M<W1R("):87!I<WHB"@HC.B!S96%R8V@N<&AP.C$W('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHT('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS
M,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E-Z=6MA:B(*"B,Z(&QI<W0N<&AP
M.C4W"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R(")7>6YI:VD@=WES
M>G5K:7=A;FEA(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$W
M"FUS9VED(")396%R8V@@4V-O<&4B"FUS9W-T<B`B6F%K<F5S('-Z=6MA;FEA
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.CD*;7-G:60@(E-E
M87)C:"!?5&5X="(*;7-G<W1R(")3>G5K86YY(%]T96MS="(*"B,Z('1E;7!L
M871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C<*;7-G:60@(E-E;&5C="!A
M(&YO=&5P860B"FUS9W-T<B`B5WEB:65R>B!N;W1A=&YI:R(*"B,Z('1E;7!L
M871E<R]M96YU+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&YO=&5P
M861S('1O(&1I<W!L87DZ(@IM<V=S='(@(D)R86L@;F]T871E:R!D;R!W>;9W
M:65T;&5N:6$B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS
M9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E=Y8FEE
M<GH@9F]R;6%T('!L:6MU(&5K<W!O<G1O=V%N96=O.B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,S<*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T
M;R!I;7!O<G0Z(@IM<V=S='(@(E=Y8FEE<GH@<&QI:R!D;R!Z86EM<&]R=&]W
M86YI83HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U"FUS9VED
M(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S
M='(@(E=Y8FEE<GH@9F]R;6%T('!L:6MU(+QR\V2S;W=E9V\Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#D*;7-G:60@
M(E-E;&5C=&5D($-A=&5G;W)I97,Z(@IM<V=S='(@(E=Y8G)A;F$@:V%T96=O
M<FEA.B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS.`IM<V=I9"`B4VAO
M=R!A8W1I;VX@8G5T=&]N<S\B"FUS9W-T<B`B5WFV=VEE=&QAYB!P<GIY8VES
M:R!A:V-J:3\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*;7-G:60@
M(E-H;W<@;F]T97!A9"!N86UE/R(*;7-G<W1R(")7>;9W:65T;&'F(&YA>G?J
M(&YO=&%T;FEK83\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#0*;7-G
M:60@(E-H;W<@;F]T97,@9G)O;2!T:&5S92!C871E9V]R:65S(@IM<V=S='(@
M(E!O:V%Z>7=AYB!N;W1A=&MI('H@=&5J(&MA=&5G;W)I:2(*"B,Z('1E;7!L
M871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3`*;7-G:60@(E-O<G0@8GD@
M0V%T96=O<GDB"FUS9W-T<B`B4V]R='5J('!O(&MA=&5G;W)I:2(*"B,Z('1E
M;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#8*;7-G:60@(E-O<G0@
M8GD@3F]T92!497AT(@IM<V=S='(@(E-O<G1U:B!P;R!T96NV8VEE(&YO=&%T
M:VDB"@HC.B!M96UO+G!H<#HQ,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!<(B5S7"(N(@IM<V=S='(@(E!O;7FV
M;&YI92!Z87!I<V%N;R`G)7,G+B(*"B,Z(&UE;6\N<&AP.C$U.0IM<V=I9"`B
M5&AE(&YO=&4@=V%S(&1E;&5T960N(@IM<V=S='(@(DYO=&%T:V$@>F]S=&&S
M82!U<W5N:>IT82XB"@HC.B!N;W1E<&%D<RYP:'`Z-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&-O=6QD;B=T(&)E(&-R96%T
M960Z("5S(@IM<V=S='(@(DYO=&%T;FEK(%PB)7-<(B!N:64@;6^_92!Z;W-T
M8>8@=71W;W)Z;VYY.B`E<R(*"B,Z(&YO=&5P861S+G!H<#HT.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@8W)E
M871E9"XB"FUS9W-T<B`B3F]T871N:6L@7"(E<UPB('IO<W1ALR!U='=O<GIO
M;GDN(@H*(SH@;F]T97!A9',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(").;W1A=&YI:R!<(B5S7"(@>F]S=&&S('5S=6YIZG1Y+B(*"B,Z(&YO=&5P
M861S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<
M(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(DYO=&%T;FEK(%PB)7-<
M(B!Z;W-T8;,@>F%P:7-A;GDN(@H*(SH@9&%T82YP:'`Z,3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&1A=&$Z("5S(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!I;7!O
M<G1O=V%N:6$@9&%N>6-H.B`E<R(*"B,Z(&QI8B]A<&DN<&AP.C(P,`HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@<&]D8WIA
M<R!I;7!O<G1O=V%N:6$@9&%N>6-H('9.;W1E+B(*"B,Z(&QI8B]A<&DN<&AP
M.C,Y,PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M=DYO=&4@9&%T82XB"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S(&EM
M<&]R=&]W86YI82!D86YY8V@@=DYO=&4N(@H*(SH@;65M;RYP:'`Z,34W"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN
M9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S
M('5S=7=A;FEA(&YO=&%T:VDZ("5S(@H*(SH@;65M;RYP:'`Z,3,S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AE
M(&YO=&4Z("5S(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!Z87!I
M<WEW86YI82!N;W1A=&MI.B`E<R(*"B,Z('9I97<N<&AP.C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!V:65W:6YG('1H:7,@
M;F]T97!A9#H@)7,B"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S('!O
M9&=LL61A;FEA('1E9V\@;F]T871N:6MA.B`E<R(*"B,Z(&1A=&$N<&AP.C<Y
M"FUS9VED(")4:&5R92!W97)E(&YO(&UE;6]S('1O(&5X<&]R="XB"FUS9W-T
M<B`B0G)A:R!N;W1E:R!D;R!E:W-P;W)T;W=A;FEA+B(*"B,Z(&1A=&$N<&AP
M.C$P-0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D
M+B(*;7-G<W1R(")&;W)M870@<&QI:W4@:F5S="!N:65O8G.S=6=I=V%N>2XB
M"@HC.B!N;W1E<&%D<RYP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(DYI92!M;V?J('5S
M=6ZQYB!<(B5S7"(Z("5S(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z
M-3@*(RP@9G5Z>GD*;7-G:60@(E5N9&\@8VAA;F=E<R(*;7-G<W1R(")#;V9N
M:6H@>FUI86YY(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,38@=&5M
M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C$T"B,Z(&QI8B]-;F5M
M;RYP:'`Z,C`V(&QI8B]-;F5M;RYP:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z,C(Q
M(&QI8B]-;F5M;RYP:'`Z,C(R"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M,#4*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3FEE>FYA;F$B"@HC.B!L:6(O
M87!I+G!H<#HR,S8@;&EB+V%P:2YP:'`Z,S`Y(&QI8B]A<&DN<&AP.C0P,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N
M="U4>7!E.B`E<R(*;7-G<W1R(").:65O8G.S=6=I=V%N>2!#;VYT96YT+51Y
M<&4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,@IM<V=I9"`B
M5VAI8V@@3F]T97!A9"!S:&]U;&0@=&AE(&YO=&5S(&)E(&%D9&5D('1O/R(*
M;7-G<W1R(")$;R!K=/-R96=O(&YO=&%T;FEK82!D;V1AYB!N;W1A=&MI/R(*
M"B,Z(&1A=&$N<&AP.C0R(&1A=&$N<&AP.C$R-2!M96UO+G!H<#HS-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T
M92!M;W)E('1H86X@)60@;F]T97,N(@IM<V=S='(@(B(*"B,Z('9I97<N<&AP
M.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M
M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@)7,N(@IM<V=S='(@(DYI92!M
M87-Z('!R87<L(&%B>2!Z;V)A8WIYYB!N;W1A=&YI:R`E<RXB"@HC.B!N;W1E
M<&%D<RYP:'`Z-C4*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A(&YO=&5P860@
M=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B375S:7-Z('=Y8G)AYB!N;W1A=&YI
M:R!D;R!U<W5N:>IC:6$N(@H*(SH@=&5M<&QA=&5S+W!R969S+VYO=&5P861S
M96QE8W0N:6YC.C$P"FUS9VED(")9;W5R(&1E9F%U;'0@;F]T97!A9#HB"FUS
M9W-T<B`B5'?S:B!D;VUYMFQN>2!N;W1A=&YI:R(*"B,Z('1E;7!L871E<R]N
M;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C4*;7-G:60@(EEO=7(@;F]T97!A9',Z
M(@IM<V=S='(@(E1W;VIE(&YO=&%T;FEK:3HB"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM<V=I
M9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")7<O/F(&1O(&YO=&%T;FEK
M82`H7V(I(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3$@=&5M<&QA
M=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHU,`IM<V=I9"`B7T-A=&5G;W)Y
M(@IM<V=S='(@(DMA=&5G;W)I82`H7V,I(@H*(SH@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z,C4@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C0*;7-G:60@
M(E]$96QE=&4B"FUS9W-T<B`B57-U\2`H7V0I(@H*(SH@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z,C$@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*;7-G
M:60@(E]%9&ET(@IM<V=S='(@(E]%9'ET=6HB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z,C`*;7-G:60@(E]&:7)S="!,:6YE(@IM<V=S='(@
M(E!I97)W<WIA(&QI;FEA("A?9BDB"@HC.B!L:6(O36YE;6\N<&AP.C(X,0IM
M<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R="]%:W-P;W)T
M(@H*(SH@;&EB+TUN96UO+G!H<#HR-C0*;7-G:60@(E],:7-T($YO=&5S(@IM
M<V=S='(@(E],:7-T82!N;W1A=&5K(@H*(SH@;&EB+TUN96UO+G!H<#HR-S8*
M;7-G:60@(E]->2!.;W1E<&%D<R(*;7-G<W1R(")?36]J92!N;W1A=&YI:VDB
M"@HC.B!L:6(O36YE;6\N<&AP.C(V.0IM<V=I9"`B7TYE=R!.;W1E(@IM<V=S
M='(@(E].;W=A(&YO=&%T:V$B"@HC.B!L:6(O36YE;6\N<&AP.C(X-@IM<V=I
M9"`B7U!R:6YT(@IM<V=S='(@(D1R=6MU:B`H7W`I(@H*(SH@;&EB+TUN96UO
M+G!H<#HR-S(*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B7U-Z=6MA:B(*"B,Z
M(&1A=&$N<&AP.CDQ('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I
M9"`B;F]T97,N8W-V(@IM<V=S='(@(FYO=&%T:VDN8W-V(@H*(SH@9&%T82YP
M:'`Z,S,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ.`IM<V=I9"`B=DYO
M=&4B"FUS9W-T<B`B=DYO=&4B"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]M;F5M;R]P;R]D85]$2RYP;P``````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U-C,P`#$P-#$W,S8R-S0V
M`#`Q-S0V-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C($U.96UO($1A;FES:"!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@
M*$,I($UA<G1I;B!,:7-T+5!E=&5R<V5N(#QM87)T:6Y`;&ES="UP971E<G-E
M;BYD:SXL(#(P,#$N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED
M+59E<G-I;VXZ($UN96UO(#(N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`R+38Q+3(Q(#$R.C$Q*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M36%R=&EN($QI<W0M4&5T97)S96X@/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@1&%N:7-H(#QD:RUH;W)D94!H=6QP<WES
M=&5M<RYN970^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]L
M:7-T+VAE861E<BYI;F,Z,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M)60@;F]T97,B"FUS9W-T<B`B)60@:'5S:V5S961L97(B"@HC.B!T96UP;&%T
M97,O;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!C
M:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*
M;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z.3D@;&EB+V)A<V4N<&AP.C$P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHS"FUS9VED("(Q(&YO
M=&4B"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z,38R"FUS9VED(")!8V-E<W,@
M9&5N:65D(&1E;&5T:6YG(&YO=&4N(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP
M.C$Q,B!M96UO+G!H<#HQ,34*;7-G:60@(D%C8V5S<R!D96YI960@;6]V:6YG
M('1H92!N;W1E+B(*;7-G<W1R("(B"@HC.B!M96UO+G!H<#HX-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E('1O("5S
M+B(*;7-G<W1R("(B"@HC.B!M96UO+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P
M,PHC+"!F=7IZ>0IM<V=I9"`B061D(&-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G
M;W)I(@H*(SH@;65M;RYP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(D%D9&EN9R!!
M($YE=R!.;W1E(@IM<V=S='(@(E1I;&;X:B!N>2!H=7-K97-E9&1E;"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-`IM<V=I9"`B07-C96YD:6YG(@IM
M<V=S='(@(E-T:6=E;F1E(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM
M87)Y<V5L96-T+FEN8SHY.0IM<V=I9"`B079A:6QA8FQE($-A=&5G;W)I97,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(X('1E
M;7!L871E<R]V:65W+VUE;6\N:6YC.C8W"B,L(&9U>GIY"FUS9VED(")"86-K
M('1O($YO=&5P860B"FUS9W-T<B`B5&EL8F%G92!T:6P@:'5S:V5S961L97)N
M92(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.3<*(RP@
M9G5Z>GD*;7-G:60@(D)A8VL@=&\@3F]T97!A9"!/<'1I;VYS(@IM<V=S='(@
M(E1I;&)A9V4@=&EL(&AU<VME<V5D;&5R;F4B"@HC.B!D871A+G!H<#HS,B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS9W-T
M<B`B(@H*(SH@9&%T82YP:'`Z-30@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z
M,34*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G;W)I(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHR,@HC+"!F=7IZ>0IM<V=I
M9"`B0VAA;F=E(@IM<V=S='(@(D9O<G1R>60@YFYD<FEN9V5R;F4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*(RP@9G5Z>GD*;7-G:60@(D-H86YG
M92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS+B(*;7-G
M<W1R(")6YFQG(&WE9&5N+"!D:6YE(&AU<VME<V5D;&5R('9I<V5S(&]G('-O
M<G1E<F5S('#E+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E
M;&5C="YI;F,Z.3,*;7-G:60@(D-H;V]S92!T:&4@;65M;R!C871E9V]R:65S
M('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R"FUS9VED(")#:&]O<V4@>6]U<B!D
M969A=6QT($YO=&5P860N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHS,@IM<V=I9"`B0VQE87(@1F]R;2(*;7-G<W1R(")4
M^&T@9F5L=&5R;F4B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.C$W('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C,U
M"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,0HC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!.;W1E<&%D(@IM
M<V=S='(@(E-T86YD87)D('-O<G1E<FEN9W-K<FET97)I93HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S4*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C
M<FET97)I83HB"FUS9W-T<B`B4W1A;F1A<F0@<V]R=&5R:6YG<VMR:71E<FEE
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B4W1A;F1A<F0@<V]R=&5R
M:6YG<W)E=&YI;F<Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHY-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-0HC.B!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHV-`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(@IM
M<V=S='(@(E-L970@:'5S:V5S961D96PB"@HC.B!T96UP;&%T97,O;65M;R]M
M96UO+FEN8SHV-PIM<V=I9"`B1&5L971E('1H:7,@;F]T92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*;7-G:60@(D1E<V-E;F1I
M;F<B"FUS9W-T<B`B1F%L9&5N9&4B"@HC.B!T96UP;&%T97,O;F]T97!A9',O
M;F]T97!A9',N:6YC.C@U"B,L(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;CHB
M"FUS9W-T<B`B0F5S:W)I=F5L<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("));F1S=&EL
M;&EN9V5R(&9O<B!V:7-N:6YG(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI
M;F,Z,C$@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*;7-G:60@(D5D:70B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N
M:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-"!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z.#,*;7-G:60@(D5D:70@3F]T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C4T
M"FUS9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z,3(*;7-G
M:60@(D5M<'1Y($YO=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ.0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z.`IM<V=I9"`B17AP;W)T($YO=&5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR
M,0HC+"!F=7IZ>0IM<V=I9"`B1E]U;&P@5&5X="(*;7-G<W1R(")&=6QD('1E
M>'0B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T($YO=&5S+"!3=&5P("5D(@IM<V=S='(@(B(*
M"B,Z(&1A=&$N<&AP.C$Y,PIM<V=I9"`B26UP;W)T+T5X<&]R="!.;W1E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHT,PIM<V=I
M9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW
M,@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@3F]T97,B"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-3,*;7-G:60@(DUE;6\@5&5X="(*;7-G<W1R(")496MS
M=&5N(&%F(&AU<VME<V5D9&5L(@H*(SH@;65M;RYP:'`Z-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B36]D:69Y:6YG("5S(@IM<V=S='(@(L9N9')E<B`E<R(*
M"B,Z(&QI<W0N<&AP.C,U"FUS9VED(")->2!.;W1E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(RP@9G5Z>GD*;7-G:60@(DYE
M=R!.;W1E(@IM<V=S='(@(DYY(&AU<VME<V5D9&5L(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HR,#8*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A
M<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*
M;7-G:60@(DYO(&YO=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*(RP@
M9G5Z>GD*;7-G:60@(DYO(&YO=&5S(@IM<V=S='(@(DEN9V5N(&AU<VME<V5D
M;&5R(@H*(SH@=&5M<&QA=&5S+VQI<W0O96UP='DN:6YC.C,*;7-G:60@(DYO
M(&YO=&5S(&UA=&-H('1H92!C=7)R96YT(&-R:71E<FEA+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3`Y"FUS9VED(").;R!N;W1E
M<R!T;R!D:7-P;&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VUE
M;6]?:&5A9&5R<RYI;F,Z-#8*;7-G:60@(DYO7W1E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-`HC+"!F=7IZ>0IM<V=I9"`B3F]T
M92!#871E9V]R>2(*;7-G<W1R(")+871E9V]R:2!F;W(@:'5S:V5S961D96PB
M"@HC.B!V:65W+G!H<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHY"B,L
M(&9U>GIY"FUS9VED(").;W1E($1E=&%I;',B"FUS9W-T<B`B26YD:&]L9&5T
M(&%F(&AU<VME<V5D9&5L(@H*(SH@;F]T97!A9',N<&AP.C$Q,`IM<V=I9"`B
M3F]T92!,:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,*(RP@9G5Z>GD*;7-G:60@(DYO=&4@5&5X="(*;7-G<W1R(")496MS
M=&5N(&%F(&AU<VME<V5D9&5L(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI
M;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(DYO=&4@7U1E>'0B"FUS9W-T<B`B5&5K
M<W1E;B!A9B!H=7-K97-E9&1E;"(*"B,Z('9I97<N<&AP.C4W(&UE;6\N<&AP
M.C8P"FUS9VED(").;W1E(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,S0*;7-G:60@(DYO=&5?<&%D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-SD*
M;7-G:60@(DYO=&5P860G<R!N86UE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"FUS9VED(").;W1E<&%D<R(*
M;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z,S,*;7-G:60@(DYO=&5P861S
M(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HS"FUS9VED(").;W1E<R!3=6UM87)Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B06YD<F4@
M:6YD<W1I;&QI;F=E<B(*"B,Z(&QI8B]A<&DN<&AP.C$X,R!L:6(O87!I+G!H
M<#HR-S0@;&EB+V%P:2YP:'`Z,S0U(&QI8B]A<&DN<&AP.C,W-`IM<V=I9"`B
M4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VYO
M=&5P861S+VYO=&5P861S+FEN8SHX,@IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHU('1E;7!L
M871E<R]L:7-T+VAE861E<BYI;F,Z-@IM<V=I9"`B4F5F<F5S:"!,:7-T(@IM
M<V=S='(@(D]P9&%T97(@;&ES=&4B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO
M=W-U;6UA<GES96QE8W0N:6YC.C$P-0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G;W)I(&9O<B!H=7-K97-E9&1E;"(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.38*;7-G:60@
M(E)E<V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC
M.C4V"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S='(@(D=E;2!H=7-K97-E
M9&1E;"(*"B,Z('-E87)C:"YP:'`Z,3<@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC.C0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,Q"FUS9VED
M(")396%R8V@B"FUS9W-T<B`B4_AG(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@
M(E-E87)C:"!297-U;'1S(@IM<V=S='(@(E)E<W5L=&%T(&9O<B!S^&=N:6YG
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$W"FUS9VED(")3
M96%R8V@@4V-O<&4B"FUS9W-T<B`B365D=&%G(&D@<_AG;FEN9R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHY"B,L(&9U>GIY"FUS9VED(")3
M96%R8V@@7U1E>'0B"FUS9W-T<B`B4_AG971E:W-T(@H*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHV-PIM<V=I9"`B4V5L96-T(&$@;F]T
M97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,38*;7-G
M:60@(E-E;&5C="!N;W1E<&%D<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")396QE8W0@
M=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,S<*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I
M;7!O<G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,34*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@
M9FEL93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM
M87)Y<V5L96-T+FEN8SHQ,#D*;7-G:60@(E-E;&5C=&5D($-A=&5G;W)I97,Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS.`IM<V=I
M9"`B4VAO=R!A8W1I;VX@8G5T=&]N<S\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C0Q"FUS9VED(")3:&]W(&YO=&5P860@;F%M93\B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0T"FUS9VED
M(")3:&]W(&YO=&5S(&9R;VT@=&AE<V4@8V%T96=O<FEE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C4P"FUS9VED
M(")3;W)T(&)Y($-A=&5G;W)Y(@IM<V=S='(@(E-O<G1E<B!E9G1E<B!K871E
M9V]R:2(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#8*
M(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@3F]T92!497AT(@IM<V=S='(@(E-O
M<G1E<B!E9G1E<B!K871E9V]R:2(*"B,Z(&UE;6\N<&AP.C$S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!M96UO+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E1H92!N
M;W1E('=A<R!D96QE=&5D+B(*;7-G<W1R(")$97(@8FQE=B!I:VME('-L971T
M970@:'5S:V5S961L97(N(@H*(SH@;F]T97!A9',N<&AP.C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!C;W5L9&XG="!B92!C
M<F5A=&5D.B`E<R(*;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N
M(&-R96%T960N(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H<#HX-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP.C4V"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S
M879E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3@T"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A
M=&$Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C(P,`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,Y,PIM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=DYO=&4@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@;65M;RYP:'`Z,34W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@=&AE(&YO=&4Z
M("5S(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!S;&5T;FEN
M9R!A9B!H=7-K97-E9&QE<FYE+B(*"B,Z(&UE;6\N<&AP.C$S,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN
M9R!T:&4@;F]T93H@)7,B"FUS9W-T<B`B1&5R(&]P<W1O9"!E;B!F96IL('5N
M9&5R('-L971N:6YG(&%F(&AU<VME<V5D;&5R;F4N(@H*(SH@=FEE=RYP:'`Z
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('9I
M97=I;F<@=&AI<R!N;W1E<&%D.B`E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HW.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E
M>'!O<G0N(@IM<V=S='(@(D1E;B!H=7-K97-E9&1E;"P@<V]M(&1U(&AA<B!B
M961T(&]M+"!E:W-I<W1E<F5R(&EK:V4N(@H*(SH@9&%T82YP:'`Z,3`U"FUS
M9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S
M='(@(B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(E5N
M9&\@8VAA;F=E<R(*;7-G<W1R(")&;W)T<GED(.9N9')I;F=E<FYE(@H*(SH@
M=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,38@=&5M<&QA=&5S+VQI<W0O;65M
M;U]S=6UM87)I97,N:6YC.C$T"B,Z(&QI8B]-;F5M;RYP:'`Z,C`V(&QI8B]-
M;F5M;RYP:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z,C(Q(&QI8B]-;F5M;RYP:'`Z
M,C(R"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#4*;7-G:60@(E5N9FEL
M960B"FUS9W-T<B`B26MK92!T:6QD96QT(@H*(SH@;&EB+V%P:2YP:'`Z,C,V
M(&QI8B]A<&DN<&AP.C,P.2!L:6(O87!I+G!H<#HT,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(R"FUS9VED(")7
M:&EC:"!.;W1E<&%D('-H;W5L9"!T:&4@;F]T97,@8F4@861D960@=&\_(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C0R(&1A=&$N<&AP.C$R-2!M96UO+G!H
M<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@;F]T97,N(@IM<V=S='(@(B(*"B,Z
M('9I97<N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@)7,N(@IM<V=S
M='(@(B(*"B,Z(&YO=&5P861S+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&$@;F]T97!A9"!T;R!B92!D96QE=&5D+B(*;7-G<W1R
M(")$=2!S:V%L(';F;&=E(&UI;F1S="!E;B!H=7-K97-E9&1E;"!F^')S="XB
M"@HC.B!T96UP;&%T97,O<')E9G,O;F]T97!A9'-E;&5C="YI;F,Z,3`*;7-G
M:60@(EEO=7(@9&5F875L="!N;W1E<&%D.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO
M=&5P861S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PHC+"!F=7IZ>0IM<V=I
M9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")4:6QB86=E('1I;"!H=7-K
M97-E9&QE<FYE(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3$@=&5M
M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHU,`HC+"!F=7IZ>0IM<V=I
M9"`B7T-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G;W)I(@H*(SH@=&5M<&QA=&5S
M+W9I97<O;65M;RYI;F,Z,C4@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C0*
M(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B4VQE="!H=7-K97-E
M9&1E;"(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(Q('1E;7!L871E
M<R]V:65W+VUE;6\N:6YC.C8P"FUS9VED(")?161I="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C`*;7-G:60@(E]&:7)S
M="!,:6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C@Q"FUS9VED
M(")?26UP;W)T+T5X<&]R="(*;7-G<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP
M.C(V-`HC+"!F=7IZ>0IM<V=I9"`B7TQI<W0@3F]T97,B"FUS9W-T<B`B5FES
M(&AU<VME<V5D;&5R(@H*(SH@;&EB+TUN96UO+G!H<#HR-S8*;7-G:60@(E]-
M>2!.;W1E<&%D<R(*;7-G<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP.C(V.0IM
M<V=I9"`B7TYE=R!.;W1E(@IM<V=S='(@(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z
M,C@V"FUS9VED(")?4')I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUN96UO+G!H
M<#HR-S(*(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B4_AG(@H*
M(SH@9&%T82YP:'`Z.3$@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ"FUS
M9VED(")N;W1E<RYC<W8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S,@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ.`IM<V=I9"`B=DYO=&4B"FUS9W-T
M<B`B(@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;6YE;6\O<&\O8W-?0UHN<&\`````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`S,#0W,``Q,#0Q-S,V,C<T-@`P,3<U,C$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R!-;F5M;R!#
M>F5C:"!T<F%N<VQA=&EO;G,N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E
M(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!0879E;"!#
M:'ET:6P@/'!A=F5L0&-H>71I;"YT:SXL(#(P,#0N"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($UN96UO(#(N,"UC=G-<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`T+3$Q+3(Q(#`Y.C`R+3`X,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@4&%V96P@0VAY=&EL(#QP879E;$!C:'ET:6PN
M=&L^7&XB"B),86YG=6%G92U496%M.B!#>F5C:"`\:3$X;D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3)<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A;"U&;W)M<SH@;G!L
M=7)A;',],SL@<&QU<F%L/2AN)3$P/3TQ("8F(&XE,3`P(3TQ,2`_(#`@.B!N
M)3$P/CTR("8F(&XE(@HB,3`\/30@)B8@*&XE,3`P/#$P('Q\(&XE,3`P/CTR
M,"D@/R`Q(#H@,BD[7&XB"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC
M.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;F]T97,B"FUS9W-T<B`B)60@
M<&]Z;N%M96LB"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C$X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U
M8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R(")S;W5B;W(@)7,@8GEL(/IS
M<.RY;NP@:6UP;W)T;W;A;B(*"B,Z(&YO=&5P861S+G!H<#HY.2!L:6(O8F%S
M92YP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*
M;7-G<W1R("(E<R=S(%KA<&ES;NUK(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A
M9&5R+FEN8SHS"FUS9VED("(Q(&YO=&4B"FUS9W-T<B`B,2!P;WINX6UK82(*
M"B,Z(&UE;6\N<&AP.C$V,@IM<V=I9"`B06-C97-S(&1E;FEE9"!D96QE=&EN
M9R!N;W1E+B(*;7-G<W1R(")3;6%ZX6[M('!O>F[A;6MY(&YE8GEL;R!P;W9O
M;&5N;RXB"@HC.B!M96UO+G!H<#HQ,3(@;65M;RYP:'`Z,3$U"FUS9VED(")!
M8V-E<W,@9&5N:65D(&UO=FEN9R!T:&4@;F]T92XB"FUS9W-T<B`B4/AE<W5N
M=73M('!O>F[A;6MY(&YE8GEL;R!P;W9O;&5N;RXB"@HC.B!M96UO+G!H<#HX
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N
M;W1E('1O("5S+B(*;7-G<W1R(").96)Y;&\@<&]V;VQE;F\@=6QOOF5N[2!P
M;WINX6UK>2!D;R`E<RXB"@HC.B!M96UO+G!H<#HX,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<R(*;7-G<W1R
M(").96)Y;&\@<&]V;VQE;F\@=6QOOF5N[2!P;WINX6UK>3H@)7,B"@HC.B!T
M96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P,PIM<V=I
M9"`B061D(&-A=&5G;W)Y(@IM<V=S='(@(E#X:61A="!K871E9V]R:6DB"@HC
M.B!M96UO+G!H<#HU,@IM<V=I9"`B061D:6YG($$@3F5W($YO=&4B"FUS9W-T
M<B`B4/AI9.%T($YO=F]U(%!O>F[A;6MU(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B5GIE<W1U<&[L
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY
M.0IM<V=I9"`B079A:6QA8FQE($-A=&5G;W)I97,Z(@IM<V=S='(@(D1O<W1U
M<&[I($MA=&5G;W)I93HB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR
M."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM<V=I9"`B0F%C:R!T;R!.
M;W1E<&%D(@IM<V=S='(@(EIP['0@9&\@6N%P:7-N[6MU(@H*(SH@=&5M<&QA
M=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-PIM<V=I9"`B0F%C:R!T;R!.
M;W1E<&%D($]P=&EO;G,B"FUS9W-T<B`B6G#L="!D;R!-;[YN;W-T[2!P<F\@
M6N%P:7-N[6LB"@HC.B!D871A+G!H<#HS,B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS9W-T<B`B0U-6(@H*(SH@9&%T82YP
M:'`Z-30@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*;7-G:60@(D-A=&5G
M;W)Y(@IM<V=S='(@(DMA=&5G;W)I92(*"B,Z('1E;7!L871E<R]N;W1E<&%D
M<R]N;W1E<&%D<RYI;F,Z,C(*;7-G:60@(D-H86YG92(*;7-G<W1R("):;>QN
M:70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@(D-H86YG
M92!Y;W5R(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS+B(*;7-G
M<W1R("):;>SR(&UOOFYO<W1I('3X[61E;NT@82!Z;V)R87IE;NT@<&]Z;N%M
M96LN(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN
M8SHY,PIM<V=I9"`B0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES
M="!I;B!T:&4@<W5M;6%R>2!V:65W+B(*;7-G<W1R(")6>6)E<G1E(&MA=&5G
M;W)I92!P;WINX6UE:R!P<F\@<V5Z;F%M('8@</AE:&QE9&]VZ6T@>F]B<F%Z
M96[M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@IM<V=I9"`B0VAO
M;W-E('EO=7(@9&5F875L="!.;W1E<&%D+B(*;7-G<W1R("):=F]L:70@:6UP
M;&EC:71N[2!ZX7!I<V[M:SHB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z,S(*;7-G:60@(D-L96%R($9O<FTB"FUS9W-T<B`B5GGH:7-T:70@
M1F]R;75LX?@B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC
M.C$W('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E871E
M(@IM<V=S='(@(E9Y='9O^&ET(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI
M;F,Z,S4*;7-G:60@(D-R96%T960B"FUS9W-T<B`B5GET=F_X96YO(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q"FUS9VED(")$969A=6QT($YO=&5P
M860B"FUS9W-T<B`B26UP;&EC:71N[2!:X7!I<V[M:SHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S4*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET
M97)I83HB"FUS9W-T<B`B26UP;&EC:71N[2!T^.UD[6/M(&MR:73I<FEA.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B1&5F875L="!S
M;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B26UP;&EC:71N[2!S;>QR('3X
M[63L;NTZ(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY
M-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-0HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHV-`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-M87IA="(*
M"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C8W"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@=&AI<R!N;W1E(@IM<V=S='(@(E9Y8G)A="!ZX7!I<V[M:R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-0IM<V=I9"`B1&5S8V5N9&EN
M9R(*;7-G<W1R(")397-T=7!N["(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N
M;W1E<&%D<RYI;F,Z.#4*;7-G:60@(D1E<V-R:7!T:6]N.B(*;7-G<W1R(")0
M;W!I<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R(")-;[YN;W-T:2!:;V)R87IE;NTB"@HC
M.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O=FEE=R]M
M96UO+FEN8SHV,`IM<V=I9"`B161I="(*;7-G<W1R(")5<')A=FET(@H*(SH@
M=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(E5P<F%V
M:70B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0T(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HX,PIM<V=I9"`B161I="!.;W1E(@IM<V=S
M='(@(E5P<F%V:70@4&]Z;N%M:W4B"@HC.B!T96UP;&%T97,O;&ES="]M96UO
M7VAE861E<G,N:6YC.C4T"FUS9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O
M;&]R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA
M<FEE<RYI;F,Z,3(*;7-G:60@(D5M<'1Y($YO=&4B"FUS9W-T<B`B4'+A>F1N
MX2!0;WINX6UK82(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3D*
M;7-G:60@(D5X<&]R="(*;7-G<W1R(")%>'!O<G1O=F%T(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@3F]T97,B"FUS
M9W-T<B`B17AP;W)T;W9A="!0;WINX6UK>2(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHR,0IM<V=I9"`B1E]U;&P@5&5X="(*;7-G<W1R("+:
M7W!L;OT@5&5X="(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@3F]T97,L(%-T97`@)60B"FUS
M9W-T<B`B26UP;W)T;W9A="!0;WINX6UK=2P@2W)O:R`E9"(*"B,Z(&1A=&$N
M<&AP.C$Y,PIM<V=I9"`B26UP;W)T+T5X<&]R="!.;W1E<R(*;7-G<W1R("))
M;7!O<G1O=F%T+T5X<&]R=&]V870@4&]Z;N%M:WDB"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHT,PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R
M(").87!O<VQE9'D@6FWL;NQN;R(*"B,Z(&QI8B]A<&DN<&AP.C<R"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!.;W1E<R(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HU,PIM<V=I9"`B365M;R!497AT(@IM<V=S='(@(E1E>'0@4&]Z;N%M
M:WDB"@HC.B!M96UO+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I
M9GEI;F<@)7,B"FUS9W-T<B`B57!R879O=N%N[2`E<R(*"B,Z(&QI<W0N<&AP
M.C,U"FUS9VED(")->2!.;W1E<R(*;7-G<W1R(")-;VIE(%!O>F[A;6MY(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*
M;7-G<W1R(").;W;A(%!O>F[A;6MA(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHT,`IM<V=I9"`B3F5X="(*;7-G<W1R(")$86RY[2(*"B,Z(&QI
M8B]A<&DN<&AP.C(P-@IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I
M9"`B3F\@;F]T97!A9',@87)E(&%V86EL86)L92!T;R!G=65S=',N(@IM<V=S
M='(@(J[A9&[]('IE('KA<&ES;NUK^2!N96[M(&1O<W1U<&[]('!R;R!H;W-T
M>2XB"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(DYO
M(&YO=&5S(@IM<V=S='(@(J[A9&[I(%!O>F[A;6MY(@H*(SH@=&5M<&QA=&5S
M+VQI<W0O96UP='DN:6YC.C,*;7-G:60@(DYO(&YO=&5S(&UA=&-H('1H92!C
M=7)R96YT(&-R:71E<FEA+B(*;7-G<W1R("*NX61NZ2!P;WINX6UK>2!S92!N
M97-H;V1U:NT@<V4@<V]UZ&%S;OUM(&MR:73I<FEE;2XB"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3`Y"FUS9VED(").;R!N;W1E<R!T;R!D:7-P;&%Y
M(@IM<V=S='(@(J[A9&[I('!O>F[A;6MY('!R;R!Z;V)R87IE;NTB"@HC.B!T
M96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0V"FUS9VED(").;U]T
M92(*;7-G<W1R(")0;U]Z;N%M:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0*;7-G:60@(DYO=&4@0V%T96=O<GDB"FUS9W-T<B`B3F]VX2!+871E
M9V]R:64B"@HC.B!V:65W+G!H<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHY"FUS9VED(").;W1E($1E=&%I;',B"FUS9W-T<B`B1&5T86EL>2!P<F\@
M4&]Z;N%M:W4B"@HC.B!N;W1E<&%D<RYP:'`Z,3$P"FUS9VED(").;W1E($QI
M<W1S(@IM<V=S='(@(E-E>FYA;2!0;WINX6UE:R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,PIM<V=I9"`B3F]T92!497AT(@IM<V=S='(@(E1E>'0@
M4&]Z;N%M:WDB"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@IM<V=I
M9"`B3F]T92!?5&5X="(*;7-G<W1R(")?5&5X="!0;WINX6UK>2(*"B,Z('9I
M97<N<&AP.C4W(&UE;6\N<&AP.C8P"FUS9VED(").;W1E(&YO="!F;W5N9"XB
M"FUS9W-T<B`B4&]Z;N%M:V$@;F5B>6QA(&YA;&5Z96YA+B(*"B,Z('1E;7!L
M871E<R]M96UO+VUE;6\N:6YC.C,T"FUS9VED(").;W1E7W!A9"(*;7-G<W1R
M("):X7!I<U]N[6LB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.C<Y"FUS9VED(").;W1E<&%D)W,@;F%M93HB"FUS9W-T<B`B3N%Z978@
M6N%P:7-N[6MU.B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI
M;F,Z-C$*;7-G:60@(DYO=&5P861S(@IM<V=S='(@(EKA<&ES;NUK>2(*"B,Z
M(&YO=&5P861S+G!H<#HS,PIM<V=I9"`B3F]T97!A9',@;75S="!H879E(&$@
M;F%M92XB"FUS9W-T<B`B6N%P:7-N[6L@;75S[2!M[70@;N%Z978N(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(DYO=&5S(%-U;6UA<GDB
M"FUS9W-T<B`B4VAR;G5T[2!0;WINX6UE:R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`*;7-G:60@(D]T
M:&5R($]P=&EO;G,B"FUS9W-T<B`B1&%LN>T@36^^;F]S=&DB"@HC.B!L:6(O
M87!I+G!H<#HQ.#,@;&EB+V%P:2YP:'`Z,C<T(&QI8B]A<&DN<&AP.C,T-2!L
M:6(O87!I+G!H<#HS-S0*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S
M='(@(DYE<&]V;VQE;OT@</CM<W1U<"(*"B,Z('1E;7!L871E<R]N;W1E<&%D
M<R]N;W1E<&%D<RYI;F,Z.#(*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@
M(E!RX79A(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHU('1E;7!L
M871E<R]L:7-T+VAE861E<BYI;F,Z-@IM<V=I9"`B4F5F<F5S:"!,:7-T(@IM
M<V=S='(@(D]B;F]V:70@4V5Z;F%M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H
M;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*;7-G:60@(E)E;6]V92!C871E9V]R
M>2(*;7-G<W1R(")/9'-T<F%N:70@:V%T96=O<FEI(@H*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS9W-T
M<B`B5GGH:7-T:70B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU-@IM
M<V=I9"`B4V%V92(*;7-G<W1R(")5;&^^:70B"@HC.B!S96%R8V@N<&AP.C$W
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHT('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHS,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E9Y:&QE
M9&%T(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@(E-E87)C:"!297-U;'1S(@IM
M<V=S='(@(E;]<VQE9&MY(%9Y:&QE9.%VX6[M(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C$W"FUS9VED(")396%R8V@@4V-O<&4B"FUS9W-T
M<B`B5GEH;&5DX7;A;NT@=B!/8FQA<W1I(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.CD*;7-G:60@(E-E87)C:"!?5&5X="(*;7-G<W1R(")(
M;&5D86[](%]497AT(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHV-PIM<V=I9"`B4V5L96-T(&$@;F]T97!A9"(*;7-G<W1R(")6>6)R
M870@>N%P:7-N[6LB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,38*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!N;W1E<&%D<R!T;R!D:7-P;&%Y.B(*;7-G<W1R
M("*NX61NZ2!P;WINX6UK>2!P<F\@>F]B<F%Z96[M(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@
M9F]R;6%T.B(*;7-G<W1R(")6>6)R870@9F]R;>%T(&5X<&]R='4Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-PIM<V=I9"`B4V5L96-T('1H
M92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B5GEB<F%T('-O=6)O<B!K(&EM
M<&]R=&]VX6[M.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*
M;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB
M"FUS9W-T<B`B5GEB<F%T(&9O<FWA="!Z9')O:F]VZ6AO('-O=6)O<G4Z(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#D*
M;7-G:60@(E-E;&5C=&5D($-A=&5G;W)I97,Z(@IM<V=S='(@(E9Y8G)A;ND@
M2V%T96=O<FEE.B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS.`IM<V=I
M9"`B4VAO=R!A8W1I;VX@8G5T=&]N<S\B"FUS9W-T<B`B6F]B<F%Z:70@86OH
M;NT@=&QAZ.UT:V$_(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0Q"FUS
M9VED(")3:&]W(&YO=&5P860@;F%M93\B"FUS9W-T<B`B6F]B<F%Z:70@;N%Z
M978@>N%P:7-N[6MU/R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT-`IM
M<V=I9"`B4VAO=R!N;W1E<R!F<F]M('1H97-E(&-A=&5G;W)I97,B"FUS9W-T
M<B`B6F]B<F%Z:70@<&]Z;N%M:WD@=B!T[&-H=&\@:V%T96=O<FGM8V@B"@HC
M.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C4P"FUS9VED(")3
M;W)T(&)Y($-A=&5G;W)Y(@IM<V=S='(@(E-E=/CM9&ET('!O9&QE($MA=&5G
M;W)I[2(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#8*
M;7-G:60@(E-O<G0@8GD@3F]T92!497AT(@IM<V=S='(@(E-E=/CM9&ET('!O
M9&QE(%1E>'1U(%!O>F[A;65K(@H*(SH@;65M;RYP:'`Z,3,U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@7"(E<UPB
M+B(*;7-G<W1R("(G)7,G(/IS<.RY;NP@=6QOOF5N;RXB"@HC.B!M96UO+G!H
M<#HQ-3D*;7-G:60@(E1H92!N;W1E('=A<R!D96QE=&5D+B(*;7-G<W1R(")0
M;WINX6UK82!B>6QA('9Y;6%ZX6YA+B(*"B,Z(&YO=&5P861S+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@8V]U;&1N
M)W0@8F4@8W)E871E9#H@)7,B"FUS9W-T<B`B3F5L>F4@=GET=F_X:70@>N%P
M:7-N[6L@7"(E<UPB.B`E<R(*"B,Z(&YO=&5P861S+G!H<#HT.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@8W)E
M871E9"XB"FUS9W-T<B`B6N%P:7-N[6L@7"(E<UPB(&)Y;"!V>71V;_AE;BXB
M"@HC.B!N;W1E<&%D<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&YO=&5P860@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(EKA
M<&ES;NUK(%PB)7-<(B!B>6P@<VUA>N%N+B(*"B,Z(&YO=&5P861S+G!H<#HU
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(EKA<&ES;NUK(%PB)7-<(B!B>6P@=6QO
MOF5N+B(*"B,Z(&1A=&$N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G
M<W1R(").87-T86QA(&-H>6)A('#X:2!I;7!O<G1O=N%N[2!D870Z("5S+B(*
M"B,Z(&QI8B]A<&DN<&AP.C(P,`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S
M='(@(DYA<W1A;&$@8VAY8F$@</AI(&EM<&]R=&]VX6[M('9.;W1E(&1A="XB
M"@HC.B!L:6(O87!I+G!H<#HS.3,*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE('9.;W1E(&1A=&$N(@IM<V=S='(@(DYA<W1A;&$@
M8VAY8F$@</AI(&EM<&]R=&]VX6[M('9.;W1E(&1A="XB"@HC.B!M96UO+G!H
M<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(')E;6]V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A
M('#X:2!O9'-T<F'R;W;A;NT@<&]Z;N%M:WDZ("5S(@H*(SH@;65M;RYP:'`Z
M,3,S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S
M879I;F<@=&AE(&YO=&4Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI
M('5K;.%D;NT@<&]Z;N%M:WDZ("5S(@H*(SH@=FEE=RYP:'`Z-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('9I97=I;F<@=&AI
M<R!N;W1E<&%D.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!P<F]H
M;.V^96[M('KA<&ES;NUK=3H@)7,B"@HC.B!D871A+G!H<#HW.0IM<V=I9"`B
M5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E>'!O<G0N(@IM<V=S='(@(DYE;&IO
M=7,@>F1E(+[A9&[I('!O>F[A;6MY(&L@97AP;W)T;W;A;NTN(@H*(SH@9&%T
M82YP:'`Z,3`U"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(E1E;G1O(&9O<FWA="!S;W5B;W)U(&YE;'IE('!O
M=;[M="XB"@HC.B!N;W1E<&%D<RYP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(DYE;'IE
M('-M87IA="!<(B5S7"(Z("5S+B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N
M:6YC.C4X"B,L(&9U>GIY"FUS9VED(")5;F1O(&-H86YG97,B"FUS9W-T<B`B
M4W1O<FYO(%IM[&YY(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,38@
M=&5M<&QA=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C$T"B,Z(&QI8B]-
M;F5M;RYP:'`Z,C`V(&QI8B]-;F5M;RYP:'`Z,C`W(&QI8B]-;F5M;RYP:'`Z
M,C(Q(&QI8B]-;F5M;RYP:'`Z,C(R"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ,#4*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3F5V>7!L;NQN;R(*"B,Z
M(&QI8B]A<&DN<&AP.C(S-B!L:6(O87!I+G!H<#HS,#D@;&EB+V%P:2YP:'`Z
M-#`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#
M;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(DYE<&]D<&]R;W9A;OT@5'EP($]B
M<V%H=2XB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(R"FUS9VED
M(")7:&EC:"!.;W1E<&%D('-H;W5L9"!T:&4@;F]T97,@8F4@861D960@=&\_
M(@IM<V=S='(@(D1O(&MT97+I:&\@6N%P:7-N[6MU('-E(&UA:NT@<&]Z;N%M
M:WD@=6MLX61A=#\B"@HC.B!D871A+G!H<#HT,B!D871A+G!H<#HQ,C4@;65M
M;RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&YO=&5S+B(*;7-G<W1R("(B
M"@HC.B!V:65W+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S+B(*
M;7-G<W1R(").961O<W1A=&7H;N$@<'+A=F$@<')O('!R;VAL[;YE;NT@>N%P
M:7-N[6MU("5S+B(*"B,Z(&YO=&5P861S+G!H<#HV-0IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&$@;F]T97!A9"!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")-
M=7/M=&4@=GEB<F%T('KA<&ES;NUK+"!K=&5R_2!S:2!P^&5J971E('-M87IA
M="XB"@HC.B!T96UP;&%T97,O<')E9G,O;F]T97!A9'-E;&5C="YI;F,Z,3`*
M;7-G:60@(EEO=7(@9&5F875L="!N;W1E<&%D.B(*;7-G<W1R(")6X;D@:6UP
M;&EC:71N[2!ZX7!I<V[M:SHB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T
M97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*;7-G<W1R(")6
M8;EE('KA<&ES;NUK>3HB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR
M."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM<V=I9"`B7T)A8VL@=&\@
M3F]T97!A9"(*;7-G<W1R(")?6G#L="!K(%KA<&ES;NUK=2(*"B,Z('1E;7!L
M871E<R]M96UO+VUE;6\N:6YC.C4Q('1E;7!L871E<R]L:7-T+VUE;6]?:&5A
M9&5R<RYI;F,Z-3`*;7-G:60@(E]#871E9V]R>2(*;7-G<W1R(")?2V%T96=O
M<FEE(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C4@=&5M<&QA=&5S
M+W9I97<O;65M;RYI;F,Z-C0*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B7U-M
M87IA="(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(Q('1E;7!L871E
M<R]V:65W+VUE;6\N:6YC.C8P"FUS9VED(")?161I="(*;7-G<W1R(")?57!R
M879I="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,`IM<V=I
M9"`B7T9I<G-T($QI;F4B"FUS9W-T<B`B7U!R=F[M(-CA9&5K(@H*(SH@;&EB
M+TUN96UO+G!H<#HR.#$*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@
M(E]);7!O<G1O=F%T+T5X<&]R=&]V870B"@HC.B!L:6(O36YE;6\N<&AP.C(V
M-`IM<V=I9"`B7TQI<W0@3F]T97,B"FUS9W-T<B`B7U-E>FYA;2!0;WINX6UE
M:R(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C<V"FUS9VED(")?37D@3F]T97!A9',B
M"FUS9W-T<B`B7U!O>F[A;6MY(@H*(SH@;&EB+TUN96UO+G!H<#HR-CD*;7-G
M:60@(E].97<@3F]T92(*;7-G<W1R(")?3F]VX2!0;WINX6UK82(*"B,Z(&QI
M8B]-;F5M;RYP:'`Z,C@V"FUS9VED(")?4')I;G0B"FUS9W-T<B`B7U1I<VLB
M"@HC.B!L:6(O36YE;6\N<&AP.C(W,@IM<V=I9"`B7U-E87)C:"(*;7-G<W1R
M(")?5GEH;&5D870B"@HC.B!D871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$*;7-G:60@(FYO=&5S+F-S=B(*;7-G<W1R(")P;WIN86UK
M>2YC=G,B"@HC.B!D871A+G!H<#HS,R!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$X"FUS9VED(")V3F]T92(*;7-G<W1R(")V3F]T92(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W!O
M+W!T7T)2+G!O````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,S(P-C4`,3`T,3<S-C(W-#8`,#$W-3,P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@=')A;G-L871I;VX@;V8@
M;6YE;6\N<&\@=&\@0G)A>FEL:6%N(%!O<G1U9W5E<V4*(R!#;W!Y<FEG:'0@
M*$,I(%E%05(@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB
M=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!-;F5M;R!P86-K
M86=E+@HC"B,@1F%B:6\@1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R/BP@,C`P
M-BX*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($UN
M96UO7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-2`Q.#HS-"TP
M,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($9A8FEO($=O;65S(#QF;&=O;7-`
M=6]L+F-O;2YB<CY<;B(*(DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T
M=6=U97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@HB6"U'96YE<F%T;W(Z($M"86)E;"`Q+C,N,5QN(@HB4&QU<F%L+49O
M<FUS.B`@;G!L=7)A;',],CL@<&QU<F%L/2AN(#X@,2D[7&XB"@HC.B!T96UP
M;&%T97,O;&ES="]H96%D97(N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@;F]T97,B"FUS9W-T<B`B)60@86YO=&'G]65S(@H*(SH@=&5M<&QA=&5S
M+VUE;6\O;65M;RYI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@8VAA
M<F%C=&5R<R(*;7-G<W1R("(E<R!C87)A8W1E<F5S(@H*(SH@9&%T82YP:'`Z
M,3@W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY
M(&EM<&]R=&5D(@IM<V=S='(@(D%R<75I=F\@)7,@:6UP;W)T861O(&-O;2!S
M=6-E<W-O(@H*(SH@;F]T97!A9',N<&AP.CDY(&QI8B]B87-E+G!H<#HQ,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(D%N
M;W1AY_5E<R!D92`E<R(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z
M,PIM<V=I9"`B,2!N;W1E(@IM<V=S='(@(C$@86YO=&'GXV\B"@HC.B!M96UO
M+G!H<#HQ-C(*;7-G:60@(D%C8V5S<R!D96YI960@9&5L971I;F<@;F]T92XB
M"FUS9W-T<B`B06-E<W-O(&YE9V%D;R!A;R!E>&-L=6ER(&%N;W1AY^-O+B(*
M"B,Z(&UE;6\N<&AP.C$Q,B!M96UO+G!H<#HQ,34*;7-G:60@(D%C8V5S<R!D
M96YI960@;6]V:6YG('1H92!N;W1E+B(*;7-G<W1R(")!8V5S<V\@;F5G861O
M(&%O(&UO=F5R(&$@86YO=&'GXV\N(@H*(SH@;65M;RYP:'`Z.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T92!T;R`E
M<RXB"FUS9W-T<B`B06-E<W-O(&YE9V%D;R!S86QV86YD;R!A(&%N;W1AY^-O
M(&5M("5S+B(*"B,Z(&UE;6\N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(D%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4Z("5S(@IM<V=S='(@(D%C97-S
M;R!N96=A9&\@<V%L=F%N9&\@86YO=&'GXV\Z("5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#,*;7-G:60@(D%D9"!C
M871E9V]R>2(*;7-G<W1R(")!9&EC:6]N87(@8V%T96=O<FEA(@H*(SH@;65M
M;RYP:'`Z-3(*;7-G:60@(D%D9&EN9R!!($YE=R!.;W1E(@IM<V=S='(@(D%D
M:6-I;VYA;F1O(%5M82!.;W9A($%N;W1AY^-O(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4Q"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B07-C96YD
M96YT92(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI
M;F,Z.3D*;7-G:60@(D%V86EL86)L92!#871E9V]R:65S.B(*;7-G<W1R(")#
M871E9V]R:6%S($1I<W!O;NUV96ES.B(*"B,Z('1E;7!L871E<R]V:65W+VUE
M;6\N:6YC.C$X"FUS9VED(")"86-K('1O($YO=&5P860B"FUS9W-T<B`B5F]L
M=&%R(&%O($)L;V-O(&1E($YO=&%S(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S
M+VYO=&5P861S+FEN8SHY-PIM<V=I9"`B0F%C:R!T;R!.;W1E<&%D($]P=&EO
M;G,B"FUS9W-T<B`B5F]L=&%R(.!S($]PY_5E<R!D;R!";&]C;R!D92!.;W1A
M<R(*"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,3<*;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!D871A+G!H<#HU-"!T
M96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-@IM<V=I9"`B0V%T96=O<GDB"FUS
M9W-T<B`B0V%T96=O<FEA(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P
M861S+FEN8SHR,@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D%L=&5R87(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@(D-H86YG92!Y;W5R
M(&YO=&4@<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R(")!
M;'1E<F$@82!O<F1E;F'GXV\@9&4@<W5A<R!A;F]T8>?U97,@92!O<.?U97,@
M9&4@=FES=6%L:7IAY^-O+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M
M;6%R>7-E;&5C="YI;F,Z.3,*;7-G:60@(D-H;V]S92!T:&4@;65M;R!C871E
M9V]R:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE=RXB"FUS9W-T<B`B
M(@HB17-C;VQH82!A<R!C871E9V]R:6%S(&1E(&UE;6]R86YD;W,@82!S97)E
M;2!L:7-T861A<R!N82!V:7-U86QI>F'GXV\@(@HB<F5S=6UI9&$N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R"FUS9VED(")#:&]O<V4@>6]U<B!D
M969A=6QT($YO=&5P860N(@IM<V=S='(@(D5S8V]L:&$@<V5U($)L;V-O(&1E
M($YO=&%S('!A9'+C;RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z,S(*;7-G:60@(D-L96%R($9O<FTB"FUS9W-T<B`B3&EM<&%R($9O<FUU
M;.%R:6\B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C$W
M('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@=&5M<&QA
M=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E871E(@IM
M<V=S='(@(D-R:6%R(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,S(*
M;7-G:60@(D-R96%T960B"FUS9W-T<B`B0W)I861O(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Q"FUS9VED(")$969A=6QT($YO=&5P860B"FUS9W-T
M<B`B0FQO8V\@9&4@3F]T87,@4&%D<N-O(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0R"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM
M<V=S='(@(D-R:73I<FEO('!A9'+C;R!D92!O<F1E;F'GXV\Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S"FUS9VED(")$969A=6QT('-O<G1I;F<@
M9&ER96-T:6]N.B(*;7-G<W1R(")$:7)EY^-O(&1E(&]R9&5N8>?C;R!P861R
MXV\Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-2!T
M96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(D5X8VQU:7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@*;7-G
M:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T<B`B0V]N9FER;6'GXV\@
M17AC;'7M9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*;7-G:60@
M(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(D-O;7!O<G1A;65N
M=&\@9&\@8F]TXV\@9&4@97AC;'5SXV\B"@HC.B!T96UP;&%T97,O;65M;R]M
M96UO+FEN8SHV-PIM<V=I9"`B1&5L971E('1H:7,@;F]T92(*;7-G<W1R(")%
M>&-L=6ER(&5S=&$@86YO=&'GXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3(*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B1&5S8V5N9&5N=&4B
M"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C@U"FUS9VED
M(")$97-C<FEP=&EO;CHB"FUS9W-T<B`B1&5S8W)IY^-O.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM
M<V=S='(@(D]PY_5E<R!D92!%>&EB:>?C;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY.`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE
M=&EN9R!E;G1R:65S/R(*;7-G<W1R(")6;V/J(&=O<W1A<FEA(&1E(&-O;F9I
M<FUA<B!A(&5X8VQU<^-O(&1E(')E9VES=')O/R(*"B,Z('1E;7!L871E<R]V
M:65W+VUE;6\N:6YC.C$Q"FUS9VED(")%9&ET(@IM<V=S='(@(D5D:71A<B(*
M"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHU"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(D5D:71A<B!<
M(B5S7"(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0R
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HX,@IM<V=I9"`B161I="!.;W1E(@IM
M<V=S='(@(D5D:71A<B!!;F]T8>?C;R(*"B,Z('1E;7!L871E<R]L:7-T+VUE
M;6]?:&5A9&5R<RYI;F,Z-3(*;7-G:60@(D5D:70@8V%T96=O<FEE<R!A;F0@
M8V]L;W)S(@IM<V=S='(@(D5D:71A<B!C871E9V]R:6%S(&4@8V]R97,B"@HC
M.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z,3(*;7-G:60@
M(D5M<'1Y($YO=&4B"FUS9W-T<B`B06YO=&'GXV\@96T@0G)A;F-O(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.0IM<V=I9"`B17AP;W)T(@IM
M<V=S='(@(D5X<&]R=&%R(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHX"FUS9VED(")%>'!O<G0@3F]T97,B"FUS9W-T<B`B17AP;W)T87(@06YO
M=&'G]65S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(Q"FUS
M9VED(")&7W5L;"!497AT(@IM<V=S='(@(E1E>'1O(%]#;VUP;&5T;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W"FUS9VED(")'96YE<F%L
M($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S($=E<F%I<R(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G0@3F]T97,L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T87(@06YO=&'G]65S
M+"!087-S;R`E9"(*"B,Z(&1A=&$N<&AP.C$Y,PIM<V=I9"`B26UP;W)T+T5X
M<&]R="!.;W1E<R(*;7-G<W1R("));7!O<G1A<B]%>'!O<G1A<B!!;F]T8>?U
M97,B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHS.0IM<V=I9"`B3&%S
M="!-;V1I9FEE9"(*;7-G<W1R("+:;'1I;6$@36]D:69I8V'GXV\B"@HC.B!L
M:6(O87!I+G!H<#HW,@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@3F]T97,B
M"FUS9W-T<B`B3OIM97)O($WA>&EM;R!D92!!;F]T8>?U97,B"@HC.B!D871A
M+G!H<#HU,PIM<V=I9"`B365M;R!497AT(@IM<V=S='(@(E1E>'1O(&1O($UE
M;6]R86YD;R(*"B,Z(&UE;6\N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@
M(DUO9&EF>6EN9R`E<R(*;7-G<W1R(")!;'1E<F%N9&\@)7,B"@HC.B!L:7-T
M+G!H<#HS-0IM<V=I9"`B37D@3F]T97,B"FUS9W-T<B`B36EN:&%S($%N;W1A
MY_5E<R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR,@IM<V=I9"`B3F5W
M($YO=&4B"FUS9W-T<B`B3F]V82!!;F]T8>?C;R(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z-#`*;7-G:60@(DYE>'0B"FUS9W-T<B`B4'+S>&EM
M82(*"B,Z(&QI8B]A<&DN<&AP.C(P-@IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A
M=&$@=V%S(&9O=6YD+B(*;7-G<W1R(").96YH=6T@9&%D;R!I0V%L96YD87(@
M9F]I(&5N8V]N=')A9&\N(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*;7-G
M:60@(DYO(&YO=&5P861S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G
M<W1R(").96YH=6T@8FQO8V\@9&4@;F]T87,@97-TX2!D:7-P;V[M=F5L('!A
M<F$@8V]N=FED861O<RXB"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC
M.C,*;7-G:60@(DYO(&YO=&5S(@IM<V=S='(@(DYE;FAU;6$@86YO=&'GXV\B
M"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z,PIM<V=I9"`B3F\@;F]T
M97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(DYE;FAU
M;6$@86YO=&'GXV\@8V]R<F5S<&]N9&4@86\@8W)I=.ER:6\@871U86PN(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P.`IM<V=I9"`B3F\@;F]T97,@
M=&\@9&ES<&QA>2(*;7-G<W1R(").96YH=6UA(&%N;W1AY^-O('!A<F$@97AI
M8FER(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT-`IM
M<V=I9"`B3F]?=&4B"FUS9W-T<B`B06YO7W1AY^-O(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Q"FUS9VED(").;W1E($-A=&5G;W)Y(@IM<V=S='(@
M(D-A=&5G;W)I82!D82!!;F]T8>?C;R(*"B,Z('9I97<N<&AP.C@P('1E;7!L
M871E<R]V:65W+VUE;6\N:6YC.C(Q"FUS9VED(").;W1E($1E=&%I;',B"FUS
M9W-T<B`B1&5T86QH97,@9&$@06YO=&'GXV\B"@HC.B!N;W1E<&%D<RYP:'`Z
M,3$P"FUS9VED(").;W1E($QI<W1S(@IM<V=S='(@(DQI<W1A9V5M(&1E($%N
M;W1AY_5E<R(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C0U(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,`IM<V=I9"`B3F]T92!497AT(@IM<V=S='(@
M(E1E>'1O(&1A($%N;W1AY^-O(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI
M;F,Z,C8*;7-G:60@(DYO=&4@7U1E>'0B"FUS9W-T<B`B7U1E>'1O(&1A($%N
M;W1AY^-O(@H*(SH@=FEE=RYP:'`Z-3<@;65M;RYP:'`Z-C`*;7-G:60@(DYO
M=&4@;F]T(&9O=6YD+B(*;7-G<W1R(")!;F]T8>?C;R!NXV\@96YC;VYT<F%D
M82XB"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHS-`IM<V=I9"`B3F]T
M95]P860B"FUS9W-T<B`B0FQO8V\@9&4@7TYO=&%S(@H*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHW.0IM<V=I9"`B3F]T97!A9"=S(&YA
M;64Z(@IM<V=S='(@(DYO;64@9&\@8FQO8V\@9&4@;F]T87,Z(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHV,0IM<V=I9"`B3F]T97!A
M9',B"FUS9W-T<B`B0FQO8V]S(&1E(&YO=&%S(@H*(SH@;F]T97!A9',N<&AP
M.C,S"FUS9VED(").;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R
M(")";&]C;W,@9&4@;F]T87,@9&5V96T@<&]S<W5I<B!U;2!N;VUE+B(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(").;W1E<R!3=6UM87)Y
M(@IM<V=S='(@(E)E<W5M;R!D87,@06YO=&'G]65S(@H*(SH@;&EB+V%P:2YP
M:'`Z,3@S(&QI8B]A<&DN<&AP.C(W.2!L:6(O87!I+G!H<#HS-34@;&EB+V%P
M:2YP:'`Z,S@T"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")0
M97)M:7-SXV\@3F5G861A(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P
M861S+FEN8SHX,@IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES
M<_5E<R(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS9VED(")2
M96%L;'D@9&5L971E('1H:7,@;F]T93\B"FUS9W-T<B`B17AC;'5I<B!R96%L
M;65N=&4@97-T82!A;F]T8>?C;S\B"@HC.B!T96UP;&%T97,O;&ES="]H96%D
M97(N:6YC.C4@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHV"FUS9VED(")2
M969R97-H($QI<W0B"FUS9W-T<B`B071U86QI>F%R($QI<W1A(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHQ,#4*;7-G:60@
M(E)E;6]V92!C871E9V]R>2(*;7-G<W1R(")296UO=F5R(&-A=&5G;W)I82(*
M"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.38*;7-G:60@
M(E)E<V5T(@IM<V=S='(@(DQI;7!A<B(*"B,Z('1E;7!L871E<R]M96UO+VUE
M;6\N:6YC.C4V"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9A<B(*"B,Z('-E
M87)C:"YP:'`Z,3<@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C0@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,Q"FUS9VED(")396%R8V@B"FUS
M9W-T<B`B4&5S<75I<V%R(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@(E-E87)C
M:"!297-U;'1S(@IM<V=S='(@(E)E<W5L=&%D;W,@9&$@4&5S<75I<V$B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3<*;7-G:60@(E-E87)C
M:"!38V]P92(*;7-G<W1R(")%<V-O<&\@9&$@4&5S<75I<V$B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z.0IM<V=I9"`B4V5A<F-H(%]497AT
M(@IM<V=S='(@(E!E<W%U:7-A<B!?5&5X=&\B"@HC.B!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.C8W"FUS9VED(")396QE8W0@82!N;W1E<&%D
M(@IM<V=S='(@(E-E;&5C:6]N92!U;2!B;&]C;R!D92!N;W1A<R(*"B,Z('1E
M;7!L871E<R]M96YU+FEN8SHQ-@IM<V=I9"`B4V5L96-T(&YO=&5P861S('1O
M(&1I<W!L87DZ(@IM<V=S='(@(DYE;FAU;6$@86YO=&'GXV\@<&%R82!E>&EB
M:7(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B
M4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R(")396QE8VEO;F4@
M;R!F;W)M871O('!A<F$@97AP;W)T87(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHS-PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R
M=#HB"FUS9W-T<B`B4V5L96-I;VYE(&\@87)Q=6EV;R!P87)A(&EM<&]R=&%R
M.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*;7-G:60@(E-E
M;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B
M4V5L96-I;VYE(&\@9F]R;6%T;R!D;R!A<G%U:79O(&1E(&]R:6=E;3HB"@HC
M.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P.0IM
M<V=I9"`B4V5L96-T960@0V%T96=O<FEE<SHB"FUS9W-T<B`B0V%T96=O<FEA
M<R!396QE8VEO;F%D87,Z(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,W
M"FUS9VED(")3:&]W(&%C=&EO;B!B=71T;VYS/R(*;7-G<W1R(")%>&EB:7(@
M8F]T]65S(&1E(&'GXV\_(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0P
M"FUS9VED(")3:&]W(&YO=&5P860@;F%M93\B"FUS9W-T<B`B17AI8FER(&\@
M;F]M92!D;R!B;&]C;R!D92!N;W1A<S\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z-#,*;7-G:60@(E-H;W<@;F]T97,@9G)O;2!T:&5S92!C871E9V]R
M:65S(@IM<V=S='(@(D5X:6)I<B!A;F]T8>?U97,@9&5S=&%S(&-A=&5G;W)I
M87,B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0X"FUS
M9VED(")3;W)T(&)Y($-A=&5G;W)Y(@IM<V=S='(@(D]R9&5N87(@<&]R($-A
M=&5G;W)I82(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z
M-#0*;7-G:60@(E-O<G0@8GD@3F]T92!497AT(@IM<V=S='(@(D]R9&5N87(@
M<&5L;R!T97AT;R!D82!A;F]T8>?C;R(*"B,Z(&UE;6\N<&AP.C$S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@7"(E<UPB+B(*
M;7-G<W1R(")<(B5S7"(@9F]I('-A;'9O(&-O;2!S=6-E<W-O+B(*"B,Z(&UE
M;6\N<&AP.C$U.0IM<V=I9"`B5&AE(&YO=&4@=V%S(&1E;&5T960N(@IM<V=S
M='(@(D$@86YO=&'GXV\@9F]I(&5X8VQU[61A+B(*"B,Z(&YO=&5P861S+G!H
M<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@
M8V]U;&1N)W0@8F4@8W)E871E9#H@)7,B"FUS9W-T<B`B3R!B;&]C;R!D92!N
M;W1A<R!<(B5S7"(@;N-O('#T9&4@<V5R(&-R:6%D;SH@)7,B"@HC.B!N;W1E
M<&%D<RYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@
M7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(D\@8FQO8V\@9&4@
M;F]T87,@7"(E<UPB(&9O:2!C<FEA9&\N(@H*(SH@;F]T97!A9',N<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")/(&)L;V-O(&1E(&YO=&%S(%PB)7-<
M(B!F;VD@97AC;'7M9&\N(@H*(SH@;F]T97!A9',N<&AP.C4V"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`B3R!B;&]C;R!D92!N;W1A<R!<(B5S7"(@9F]I('-A;'9O
M+B(*"B,Z(&1A=&$N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R
M(")(;W5V92!U;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S.B`E<R(*"B,Z
M(&QI8B]A<&DN<&AP.C(P,`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(DAO=79E('5M
M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@=DYO=&4N(@H*(SH@;&EB+V%P
M:2YP:'`Z-#`S"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!V3F]T92!D871A+B(*;7-G<W1R(")(;W5V92!U;2!E<G)O(&%O(&EM
M<&]R=&%R(&]S(&1A9&]S('9.;W1E+B(*"B,Z(&UE;6\N<&AP.C$U-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@
M=&AE(&YO=&4Z("5S(@IM<V=S='(@(DAO=79E('5M(&5R<F\@86\@<F5M;W9E
M<B!A(&%N;W1AY^-O.B`E<R(*"B,Z(&UE;6\N<&AP.C$S,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E
M.B`E<R(*;7-G<W1R(")(;W5V92!U;2!E<G)O(&%O('-A;'9A<B!A(&%N;W1A
MY^-O.B`E<R(*"B,Z('9I97<N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!V:65W:6YG('1H:7,@;F]T97!A9#H@)7,B
M"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!V:7-U86QI>F%R(&5S=&4@8FQO
M8V\@9&4@;F]T87,Z("5S(@H*(SH@9&%T82YP:'`Z-SD*;7-G:60@(E1H97)E
M('=E<F4@;F\@;65M;W,@=&\@97AP;W)T+B(*;7-G<W1R(").XV\@:&%V:6%M
M(&UE;6]R86YD;W,@<&%R82!E>'!O<G1A<BXB"@HC.B!D871A+G!H<#HQ,#4*
M;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B17-T92!F;W)M871O(&1E(&%R<75I=F\@;N-O(.D@<W5P;W)T861O
M+B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B26UP;W-S[79E
M;"!E>&-L=6ER(%PB)7-<(CH@)7,B"@HC.B!T96UP;&%T97,O;65M;R]M96UO
M+FEN8SHU.`IM<V=I9"`B56YD;R!C:&%N9V5S(@IM<V=S='(@(D1E<V9A>F5R
M(&%L=&5R8>?U97,B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-R!T
M96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z,30*(SH@;&EB+TUN
M96UO+G!H<#HR,#8@;&EB+TUN96UO+G!H<#HR,#<@;&EB+TUN96UO+G!H<#HR
M,C$@;&EB+TUN96UO+G!H<#HR,C(*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$P,PIM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")396T@8V%T96=O<FEA(@H*
M(SH@;&EB+V%P:2YP:'`Z,C,V(&QI8B]A<&DN<&AP.C,Q.2!L:6(O87!I+G!H
M<#HT,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N
M="U4>7!E.B`E<R(*;7-G<W1R(")#;VYT96YT+51Y<&4@;N-O('-U<&]R=&%D
M;SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(R"FUS9VED
M(")7:&EC:"!.;W1E<&%D('-H;W5L9"!T:&4@;F]T97,@8F4@861D960@=&\_
M(@IM<V=S='(@(D5M('%U86P@0FQO8V\@9&4@3F]T87,@87,@86YO=&'G]65S
M(&1E=F5RXV\@<V5R(&%D:6-I;VYA9&%S/R(*"B,Z(&1A=&$N<&AP.C0R(&1A
M=&$N<&AP.C$R-2!M96UO+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@;F]T
M97,N(@IM<V=S='(@(E9O8^H@;N-O(&5S=.$@875T;W)I>F%D;R!A(&-R:6%R
M(&UA:7,@9&4@)60@;F]T87,N(@H*(SH@=FEE=RYP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE
M=R!T:&4@;F]T97!A9"`E<RXB"FUS9W-T<B`B5F]CZB!NXV\@=&5M('!E<FUI
M<W/C;R!P87)A('9I<W5A;&EZ87(@97-T92!B;&]C;R!D92!N;W1A<R`E<RXB
M"@HC.B!N;W1E<&%D<RYP:'`Z-C4*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M(&YO=&5P860@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B5F]CZB!D979E('-E
M;&5C:6]N87(@=6T@8FQO8V\@9&4@;F]T87,@<&%R82!S97(@97AC;'7M9&\N
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VYO=&5P861S96QE8W0N:6YC.C$P"FUS
M9VED(")9;W5R(&1E9F%U;'0@;F]T97!A9#HB"FUS9W-T<B`B4V5U(&)L;V-O
M(&1E(&YO=&%S('!A9'+C;SHB"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T
M97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*;7-G<W1R(")3
M975S(&)L;V-O<R!D92!N;W1A<SHB"@HC.B!T96UP;&%T97,O=FEE=R]M96UO
M+FEN8SHQ.`IM<V=I9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")?5F]L
M=&%R(&%O($)L;V-O(&1E($YO=&%S(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M
M;RYI;F,Z-3$@=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHT.`IM
M<V=I9"`B7T-A=&5G;W)Y(@IM<V=S='(@(E]#871E9V]R:6$B"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R
M(")%7WAC;'5I<B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$Q"FUS
M9VED(")?161I="(*;7-G<W1R(")?161I=&%R(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C(P"FUS9VED(")?1FER<W0@3&EN92(*;7-G<W1R
M(")?4')I;65I<F$@3&EN:&$B"@HC.B!L:6(O36YE;6\N<&AP.C(X,0IM<V=I
M9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R=&%R+T5X<&]R=&%R
M(@H*(SH@;&EB+TUN96UO+G!H<#HR-C0*;7-G:60@(E],:7-T($YO=&5S(@IM
M<V=S='(@(E],:7-T87(@06YO=&'G]65S(@H*(SH@;&EB+TUN96UO+G!H<#HR
M-S8*;7-G:60@(E]->2!.;W1E<&%D<R(*;7-G<W1R(")-:6YH87,@7T%N;W1A
MY_5E<R(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8Y"FUS9VED(")?3F5W($YO=&4B
M"FUS9W-T<B`B7TYO=F$@06YO=&'GXV\B"@HC.B!L:6(O36YE;6\N<&AP.C(X
M-@IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(E]);7!R:6UI<B(*"B,Z(&QI8B]-
M;F5M;RYP:'`Z,C<R"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E!E<U]Q=6ES
M87(B"@HC.B!D871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$*;7-G:60@(FYO=&5S+F-S=B(*;7-G<W1R(")A;F]T86-O97,N8W-V(@H*
M(SH@9&%T82YP:'`Z,S,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ.`IM
M<V=I9"`B=DYO=&4B"FUS9W-T<B`B=DYO=&4B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O<&\O<'1?4%0N<&\`````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,#4V,@`Q,#0Q-S,V
M,C<T-@`P,3<U-3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!-3D5-3R!0;W)T=6=A;"!0;W)T=6=U97-E('1R86YS;&%T
M:6]N+@HC($UA;G5E;"!-96YE>F5S(&1E(%-E<75E:7)A(#Q-86YU96PN4V5Q
M=65I<F$^+"`R,#`U+@HC($)A<V5D(&]N(&$@<')E=FEO=7,*(R!-3D5-3R!0
M;W)T=6=A;"!0;W)T=6=U97-E('1R86YS;&%T:6]N+@HC($YU;F\@3&]U<F5I
M<F\@/&YU;F]`971H+G!T/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*
M(E!R;VIE8W0M260M5F5R<VEO;CH@36YE;6\@,2XP+6-V<UQN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$S(#$W.C$S*S`R,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#(M,#0M,C(@,C,Z-#`K,#$P,%QN(@HB3&%S="U4
M<F%N<VQA=&]R.B!.=6YO($QO=7)E:7)O(#QN=6YO0&5T:"YP=#Y<;B(*(DQA
M;F=U86=E+51E86TZ(%!O<G1U9W5E<V4@/&1E=D!L:7-T<RYH;W)D92YO<F<^
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E
M<BYI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!N;W1E<R(*;7-G<W1R
M("(E9"!N;W1A<R(*"B,Z(&1A=&$N<&AP.C$V-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R(")&
M:6-H96ER;R`E<R!I;7!O<G1A9&\@8V]M('-U8V5S<V\B"@HC.B!N;W1E<&%D
M<RYP:'`Z.3D@;&EB+V)A<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($YO=&5P860B"FUS9W-T<B`B3&EV<F]S(&1E($YO=&%S(&1E("5S
M(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHY"FUS9VED("(Q(&YO
M=&4B"FUS9W-T<B`B,2!N;W1A(@H*(SH@;65M;RYP:'`Z,30Q"FUS9VED(")!
M8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N(@IM<V=S='(@(D%C97-S;R!N
M96=A9&\@86\@<F5M;W9E<B!A(&YO=&$N(@H*(SH@;65M;RYP:'`Z.3@@;65M
M;RYP:'`Z,3`Q"FUS9VED(")!8V-E<W,@9&5N:65D(&UO=FEN9R!T:&4@;F]T
M92XB"FUS9W-T<B`B06-E<W-O(&YE9V%D;R!A;R!M;W9E<B!A(&YO=&$N(@H*
M(SH@;65M;RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E
M;FEE9"!S879I;F<@;F]T92!T;R`E<RXB"FUS9W-T<B`B06-E<W-O(&YE9V%D
M;R!A;R!G=6%R9&%R(&$@;F]T82!E;2`E<RXB"@HC.B!M96UO+G!H<#HW,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E
M.B`E<R(*;7-G<W1R(")!8V5S<V\@;F5G861O(&%O(&=U87)D87(@82!N;W1A
M.B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI
M;F,Z,3`S"FUS9VED(")!9&0@8V%T96=O<GDB"FUS9W-T<B`B061I8VEO;F%R
M(&-A=&5G;W)I82(*"B,Z(&UE;6\N<&AP.C0Q"FUS9VED(")!9&1I;F<@02!.
M97<@3F]T92(*;7-G<W1R(")!9&EC:6]N86YD;R!5;6$@3F]V82!.;W1A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T"FUS9VED(")!<V-E;F1I;F<B
M"FUS9W-T<B`B0W)E<V-E;G1E(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S
M=6UM87)Y<V5L96-T+FEN8SHY.0IM<V=I9"`B079A:6QA8FQE($-A=&5G;W)I
M97,Z(@IM<V=S='(@(D-A=&5G;W)I87,@1&ES<&]N[79E:7,Z(@H*(SH@=&5M
M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C@@=&5M<&QA=&5S+W9I97<O;65M;RYI
M;F,Z-C<*;7-G:60@(D)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")6;VQT87(@
M86\@3&EV<F\@9&4@3F]T87,B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T
M97!A9',N:6YC.CDW"FUS9VED(")"86-K('1O($YO=&5P860@3W!T:6]N<R(*
M;7-G<W1R(")6;VQT87(@X',@3W#G]65S(&1E($QI=G)O<R!D92!.;W1A<R(*
M"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*
M;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!D871A+G!H<#HT-"!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B0V%T96=O<GDB"FUS9W-T
M<B`B0V%T96=O<FEA(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHR,@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D%L=&5R87(B"@HC.B!T
M96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C8@=&5M<&QA=&5S+VQI
M<W0O;65M;U]H96%D97)S+FEN8SHQ,`IM<V=I9"`B0VAA;F=E('-O<G0@9&ER
M96-T:6]N(@IM<V=S='(@(DUU9&%R(&1I<F5CY^-O(&1E(&]R9&5N8>?C;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B0VAA;F=E('EO
M=7(@;F]T92!S;W)T:6YG(&%N9"!D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@
M(D%L=&5R87(@87,@;W#G]65S(&1E(&]R9&5N8>?C;R!E('9I<W5A;&EZ8>?C
M;R!D87,@;F]T87,N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y
M<V5L96-T+FEN8SHY,PIM<V=I9"`B0VAO;W-E('1H92!M96UO(&-A=&5G;W)I
M97,@=&\@;&ES="!I;B!T:&4@<W5M;6%R>2!V:65W+B(*;7-G<W1R(")%<V-O
M;&AA(&%S(&-A=&5G;W)I87,@9&4@;F]T87,@82!L:7-T87(@;F$@=FES=6%L
M:7IAY^-O('-U;6%R:7IA9&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(R"FUS9VED(")#:&]O<V4@>6]U<B!D969A=6QT($YO=&5P860N(@IM<V=S
M='(@(D5S8V]L:&$@;R!S974@3&EV<F\@9&4@3F]T87,@<&]R(&]M:7-SXV\N
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,R"FUS9VED(")#
M;&5A<B!&;W)M(@IM<V=S='(@(DQI;7!A<B!&;W)M=6SA<FEO(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHQ-R!T96UP;&%T97,O;F]T
M97!A9',O;F]T97!A9',N:6YC.CDT"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N
M;W1E<&%D<RYI;F,Z.38*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<FEA<B(*
M"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C,U"FUS9VED(")#<F5A=&5D
M(@IM<V=S='(@(D-R:6%D82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,0IM<V=I9"`B1&5F875L="!.;W1E<&%D(@IM<V=S='(@(DQI=G)O(&1E($YO
M=&%S('!O<B!/;6ES<^-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(D-R
M:73I<FEO(&1E(&]R9&5N8>?C;R!P861RXV\Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0V"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N
M.B(*;7-G<W1R(")396YT:61O(&1A(&]R9&5N8>?C;R!P861RXV\Z(@H*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-2!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHR-0HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV
M-`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E)E;6]V97(B"@HC.B!T96UP;&%T
M97,O;65M;R]M96UO+FEN8SHU-@IM<V=I9"`B1&5L971E('1H:7,@;F]T92(*
M;7-G<W1R(")296UO=F5R(&5S=&$@;F]T82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-0IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R(")$96-R97-C
M96YT92(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*
M;7-G:60@(D1E<V-R:7!T:6]N.B(*;7-G<W1R(")$97-C<FGGXV\Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`B3W#G]65S(&1E(%9I<W5A;&EZ8>?C;R(*"B,Z('1E;7!L
M871E<R]V:65W+VUE;6\N:6YC.C(Q('1E;7!L871E<R]V:65W+VUE;6\N:6YC
M.C8P"FUS9VED(")%9&ET(@IM<V=S='(@(D5D:71A<B(*"B,Z('1E;7!L871E
M<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHT('1E;7!L871E<R]L:7-T+VUE
M;6]?<W5M;6%R:65S+FEN8SHU"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A
M9&5R<RYI;F,Z-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z.#,*;7-G:60@(D5D
M:70@3F]T92(*;7-G<W1R(")%9&ET87(@3F]T82(*"B,Z('1E;7!L871E<R]L
M:7-T+VUE;6]?:&5A9&5R<RYI;F,Z,38*;7-G:60@(D5D:70@8V%T96=O<FEE
M<R!A;F0@8V]L;W)S(@IM<V=S='(@(D5D:71A<B!C871E9V]R:6%S(&4@8V]R
M97,B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z.0IM
M<V=I9"`B16UP='D@3F]T92(*;7-G<W1R(").;W1A(%9A>FEA(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.0IM<V=I9"`B17AP;W)T(@IM<V=S
M='(@(D5X<&]R=&%R(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX
M"FUS9VED(")%>'!O<G0@3F]T97,B"FUS9W-T<B`B17AP;W)T87(@3F]T87,B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C$*;7-G:60@(D9?
M=6QL(%1E>'0B"FUS9W-T<B`B5&5?>'1O($-O;7!L971O(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R="!.;W1E<RP@4W1E<"`E9"(*;7-G<W1R("));7!O<G1A<B!.;W1A<RP@
M4&%S<V\@)60B"@HC.B!D871A+G!H<#HQ-S(*;7-G:60@(DEM<&]R="]%>'!O
M<G0@3F]T97,B"FUS9W-T<B`B26UP;W)T87(O17AP;W)T87(@3F]T87,B"@HC
M.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHT,PIM<V=I9"`B3&%S="!-;V1I
M9FEE9"(*;7-G<W1R("+:;'1I;6$@36]D:69I8V'GXV\B"@HC.B!D871A+G!H
M<#HT,PIM<V=I9"`B365M;R!497AT(@IM<V=S='(@(E1E>'1O(&1O($UE;6\B
M"@HC.B!M96UO+G!H<#HU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GEI
M;F<@)7,B"FUS9W-T<B`B02!M;V1I9FEC87(@)7,B"@HC.B!L:7-T+G!H<#HS
M-0IM<V=I9"`B37D@3F]T97,B"FUS9W-T<B`B07,@36EN:&%S($YO=&%S(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*
M;7-G<W1R(").;W9A($YO=&$B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C0P"FUS9VED(").97AT(@IM<V=S='(@(E!R\WAI;6$B"@HC.B!L:6(O
M87!I+G!H<#HQ-#@*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N
M9"XB"FUS9W-T<B`B1&%D;W,@:4-A;&5N9&%R(&[C;R!F;W)A;2!E;F-O;G1R
M861O<RXB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B3F\@;F]T
M97!A9',@87)E(&%V86EL86)L92!T;R!G=65S=',N(@IM<V=S='(@(D[C;R!H
MX2!L:79R;W,@9&4@;F]T87,@9&ES<&]N[79E:7,@<&%R82!V:7-I=&%S+B(*
M"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z.0IM<V=I9"`B3F\@;F]T
M97,B"FUS9W-T<B`B4V5M(&YO=&%S(@H*(SH@=&5M<&QA=&5S+VQI<W0O96UP
M='DN:6YC.C,*;7-G:60@(DYO(&YO=&5S(&UA=&-H('1H92!C=7)R96YT(&-R
M:71E<FEA+B(*;7-G<W1R(").96YH=6UA(&YO=&$@9&4@86-O<F1O(&-O;2!O
M(&-R:73I<FEO(&-O<G)E;G1E+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ,#D*;7-G:60@(DYO(&YO=&5S('1O(&1I<W!L87DB"FUS9W-T<B`B4V5M
M(&YO=&%S('!A<F$@;6]S=')A<B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?
M:&5A9&5R<RYI;F,Z-PIM<V=I9"`B3F]?=&4B"FUS9W-T<B`B3F]?=&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0*;7-G:60@(DYO=&4@0V%T96=O
M<GDB"FUS9W-T<B`B0V%T96=O<FEA(&1A($YO=&$B"@HC.B!V:65W+G!H<#HV
M-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHY"FUS9VED(").;W1E($1E=&%I
M;',B"FUS9W-T<B`B1&5T86QH97,@9&$@3F]T82(*"B,Z(&YO=&5P861S+G!H
M<#HQ,3`*;7-G:60@(DYO=&4@3&ES=',B"FUS9W-T<B`B3&ES=&%S(&1E($YO
M=&%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S"FUS9VED(").;W1E
M(%1E>'0B"FUS9W-T<B`B5&5X=&\@9&$@3F]T82(*"B,Z('1E;7!L871E<R]M
M96UO+VUE;6\N:6YC.C$U"FUS9VED(").;W1E(%]497AT(@IM<V=S='(@(E]4
M97AT;R!D82!.;W1A(@H*(SH@=FEE=RYP:'`Z-#(@;65M;RYP:'`Z-#D*;7-G
M:60@(DYO=&4@;F]T(&9O=6YD+B(*;7-G<W1R(").;W1A(&[C;R!E;F-O;G1R
M861A+B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C(S"FUS9VED(").
M;W1E7W!A9"(*;7-G<W1R("),:5]V<F\@9&4@3F]T87,B"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.C<Y"FUS9VED(").;W1E<&%D)W,@
M;F%M93HB"FUS9W-T<B`B3F]M92!D;R!,:79R;R!D92!.;W1A<SHB"@HC.B!T
M96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"FUS9VED(").;W1E
M<&%D<R(*;7-G<W1R("),:79R;W,@9&4@3F]T87,B"@HC.B!N;W1E<&%D<RYP
M:'`Z,S,*;7-G:60@(DYO=&5P861S(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S
M='(@(DQI=G)O<R!D92!N;W1A<R!TZFT@9&4@=&5R('5M(&YO;64N(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(DYO=&5S(%-U;6UA<GDB
M"FUS9W-T<B`B4W5MX7)I;R!D87,@3F]T87,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P"FUS9VED(")/
M=&AE<B!/<'1I;VYS(@IM<V=S='(@(D]U=')A<R!/<.?U97,B"@HC.B!L:6(O
M87!I+G!H<#HQ,C4@;&EB+V%P:2YP:'`Z,C$V(&QI8B]A<&DN<&AP.C(X-R!L
M:6(O87!I+G!H<#HS,38*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S
M='(@(E!E<FUI<W/C;R!.96=A9&$B"@HC.B!T96UP;&%T97,O;F]T97!A9',O
M;F]T97!A9',N:6YC.C@R"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")0
M97)M:7-S]65S(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHT('1E
M;7!L871E<R]L:7-T+VAE861E<BYI;F,Z-0IM<V=I9"`B4F5F<F5S:"!,:7-T
M(@IM<V=S='(@(D%C='5A;&EZ87(@3&ES=&$B"@HC.B!T96UP;&%T97,O<')E
M9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P-0IM<V=I9"`B4F5M;W9E(&-A
M=&5G;W)Y(@IM<V=S='(@(E)E;6]V97(@8V%T96=O<FEA(@H*(SH@=&5M<&QA
M=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS
M9W-T<B`B3&EM<&%R(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-#4*
M;7-G:60@(E-A=F4B"FUS9W-T<B`B1W)A=F%R(@H*(SH@<V5A<F-H+G!H<#HQ
M-R!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-"!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z,S$*;7-G:60@(E-E87)C:"(*;7-G<W1R(")0<F]C
M=7)A<B(*"B,Z(&QI<W0N<&AP.C4W"FUS9VED(")396%R8V@@4F5S=6QT<R(*
M;7-G<W1R(")297-U;'1A9&]S(&1A(%!R;V-U<F%R(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C$W"FUS9VED(")396%R8V@@4V-O<&4B"FUS
M9W-T<B`B17-C;W!O(&1E(%!R;V-U<F$B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z.0IM<V=I9"`B4V5A<F-H(%]497AT(@IM<V=S='(@(E!R
M;V-U<F%R(%]497AT;R(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D
M<RYI;F,Z-C<*;7-G:60@(E-E;&5C="!A(&YO=&5P860B"FUS9W-T<B`B4V5L
M96-C:6]N92!U;2!L:79R;R!D92!N;W1A<R(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,34*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA
M=#HB"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O<FUA=&\@9&4@97AP;W)T8>?C
M;SHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,W"FUS9VED(")3
M96QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")396QE8V-I;VYE
M(&\@9FEC:&5I<F\@82!I;7!O<G1A<CHB"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C$U"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@
M<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!F;W)M871O(&1O
M(&9I8VAE:7)O(&9O;G1E.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M
M;6%R>7-E;&5C="YI;F,Z,3`Y"FUS9VED(")396QE8W1E9"!#871E9V]R:65S
M.B(*;7-G<W1R(")#871E9V]R:6%S(%-E;&5C8VEO;F%D87,Z(@H*(SH@=&5M
M<&QA=&5S+VUE;G4N:6YC.C(V"FUS9VED(")3:&]W(@IM<V=S='(@(DUO<W1R
M87(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,38*;7-G:60@(E-H;W<@3F]T
M97!A9',Z(@IM<V=S='(@(DUO<W1R87(@3&EV<F]S(&1E($YO=&%S.B(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS.`IM<V=I9"`B4VAO=R!A8W1I;VX@
M8G5T=&]N<S\B"FUS9W-T<B`B36]S=')A<B!B;W3U97,@9&4@86/GXV\_(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0Q"FUS9VED(")3:&]W(&YO=&5P
M860@;F%M93\B"FUS9W-T<B`B36]S=')A<B!N;VUE(&1O(&QI=G)O(&1E(&YO
M=&%S/R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT-`IM<V=I9"`B4VAO
M=R!N;W1E<R!F<F]M('1H97-E(&-A=&5G;W)I97,B"FUS9W-T<B`B36]S=')A
M<B!N;W1A<R!D97-T87,@8V%T96=O<FEA<R(*"B,Z('1E;7!L871E<R]L:7-T
M+VUE;6]?:&5A9&5R<RYI;F,Z,3$*;7-G:60@(E-O<G0@8GD@0V%T96=O<GDB
M"FUS9W-T<B`B3W)D96YA<B!P;W(@0V%T96=O<FEA(@H*(SH@=&5M<&QA=&5S
M+VQI<W0O;65M;U]H96%D97)S+FEN8SHW"FUS9VED(")3;W)T(&)Y($YO=&4@
M5&5X="(*;7-G<W1R(")/<F1E;F%R('!O<B!497AT;R!D82!.;W1A(@H*(SH@
M;65M;RYP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!G=6%R9&%D82!C;VT@
M<W5C97-S;RXB"@HC(&,M9F]R;6%T"B,Z(&UE;6\N<&AP.C$S.`IM<V=I9"`B
M5&AE(&YO=&4@=V%S(&1E;&5T960N(@IM<V=S='(@(D$@;F]T82!F;VD@<F5M
M;W9I9&$N(@H*(SH@;F]T97!A9',N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!N;W1E<&%D(%PB)7-<(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E
M<R(*;7-G<W1R(")/(&QI=G)O(&1E(&YO=&%S(%PB)7-<(B!NXV\@<&]D92!S
M97(@8W)I861O.B`E<R(*"B,@8RUF;W)M870*(SH@;F]T97!A9',N<&AP.C0X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@
M8F5E;B!C<F5A=&5D+B(*;7-G<W1R(")/(&QI=G)O(&1E(&YO=&%S(%PB)7-<
M(B!F;VD@8W)I861O+B(*"B,@8RUF;W)M870*(SH@;F]T97!A9',N<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")/(&QI=G)O(&1E(&YO=&%S(%PB)7-<
M(B!F;VD@<F5M;W9I9&\N(@H*(SH@;F]T97!A9',N<&AP.C4V"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`B3R!L:79R;R!D92!N;W1A<R!<(B5S7"(@9F]I(&=U87)D
M861O+B(*"B,Z(&1A=&$N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G
M<W1R(")/8V]R<F5U('5M(&5R<F\@;F$@:6UP;W)T8>?C;R!D;W,@9&%D;W,Z
M("5S(@H*(SH@;&EB+V%P:2YP:'`Z,30R"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B
M3V-O<G)E=2!U;2!E<G)O(&YA(&EM<&]R=&'GXV\@9&]S(&1A9&]S(&E#86QE
M;F1A<BXB"@HC.B!L:6(O87!I+G!H<#HS,S4*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.;W1E(&1A=&$N(@IM<V=S='(@(D]C
M;W)R974@=6T@97)R;R!N82!I;7!O<G1AY^-O(&1O<R!D861O<R!V3F]T92XB
M"@HC.B!M96UO+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R(")/
M8V]R<F5U('5M(&5R<F\@86\@<F5M;W9E<B!A(&YO=&$Z("5S(@H*(SH@;65M
M;RYP:'`Z,3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!S879I;F<@=&AE(&YO=&4Z("5S(@IM<V=S='(@(D]C;W)R974@=6T@
M97)R;R!A;R!G<F%V87(@82!N;W1A.B`E<R(*"B,Z('9I97<N<&AP.C(X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!V:65W:6YG
M('1H:7,@;F]T97!A9#H@)7,B"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O
M(&UO<W1R87(@97-T92!L:79R;R!D92!N;W1A<SH@)7,B"@HC.B!D871A+G!H
M<#HV.0IM<V=I9"`B5&AE<F4@=V5R92!N;R!M96UO<R!T;R!E>'!O<G0N(@IM
M<V=S='(@(D[C;R!H;W5V92!N;W1A<R!A(&5X<&]R=&%R+B(*"B,Z(&1A=&$N
M<&AP.CDU"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T
M960N(@IM<V=S='(@(D5S=&4@9F]R;6%T;R!D92!F:6-H96ER;R!NXV\@Z2!S
M=7!O<G1A9&\N(@H*(SH@;F]T97!A9',N<&AP.C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<R(*;7-G<W1R(").
MXV\@8V]N<VEG;R!R96UO=F5R(%PB)7-<(CH@)7,B"@HC.B!T96UP;&%T97,O
M;65M;R]M96UO+FEN8SHT-PIM<V=I9"`B56YD;R!C:&%N9V5S(@IM<V=S='(@
M(D1E<V9A>F5R(&%L=&5R8>?U97,B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO
M+FEN8SHQ-B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z,3$*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P-0IM<V=I9"`B56YF:6QE9"(*
M;7-G<W1R(")396T@8V%T96=O<FEA(@H*(SH@;&EB+V%P:2YP:'`Z,3<X(&QI
M8B]A<&DN<&AP.C(U,2!L:6(O87!I+G!H<#HS-#,*;7-G:60@(E5N<W5P<&]R
M=&5D($-O;G1E;G0M5'EP92XB"FUS9W-T<B`B5&EP;R!D92!C;VYT9?ID;R`H
M0V]N=&5N=&4M5'EP92D@;N-O('-U<&]R=&%D;RXB"@HC.B!T96UP;&%T97,O
M;&ES="]M96UO7W-U;6UA<FEE<RYI;F,Z.0IM<V=I9"`B5FEE=R!.;W1E($1E
M=&%I;',B"FUS9W-T<B`B5F5R($1E=&%L:&5S(&1A($YO=&$B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C(R"FUS9VED(")7:&EC:"!.;W1E<&%D
M('-H;W5L9"!T:&4@;F]T97,@8F4@861D960@=&\_(@IM<V=S='(@(D$@<75E
M($QI=G)O(&1E($YO=&%S('-E(&1E=F4@861I8VEO;F%R(&%S(&YO=&%S/R(*
M"B,Z('9I97<N<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AE(&YO=&5P860@)7,N(@IM
M<V=S='(@(D[C;R!T96T@<&5R;6ES<^-O('!A<F$@=F5R(&\@;&EV<F\@9&4@
M;F]T87,@)7,N(@H*(SH@;F]T97!A9',N<&AP.C8U"FUS9VED(")9;W4@;75S
M="!S96QE8W0@82!N;W1E<&%D('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E1E
M;2!D92!S96QE8V-I;VYA<B!O(&QI=G)O(&1E(&YO=&%S(&$@<F5M;W9E<BXB
M"@HC.B!T96UP;&%T97,O<')E9G,O;F]T97!A9'-E;&5C="YI;F,Z,3`*;7-G
M:60@(EEO=7(@9&5F875L="!N;W1E<&%D.B(*;7-G<W1R(")/('-E=2!L:79R
M;R!D92!N;W1A<R!P;W(@;VUI<W/C;SHB"@HC.B!T96UP;&%T97,O;F]T97!A
M9',O;F]T97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*;7-G
M<W1R(")/<R!S975S($QI=G)O<R!D92!.;W1A<SHB"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-PIM
M<V=I9"`B7T)A8VL@=&\@3F]T97!A9"(*;7-G<W1R(")?5F]L=&%R(&%O($QI
M=G)O(&1E($YO=&%S(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-#`@
M=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8SHQ,0IM<V=I9"`B7T-A
M=&5G;W)Y(@IM<V=S='(@(E]#871E9V]R:6$B"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHR-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-`IM<V=I
M9"`B7T1E;&5T92(*;7-G<W1R(")?4F5M;W9E<B(*"B,Z('1E;7!L871E<R]V
M:65W+VUE;6\N:6YC.C(Q('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C8P"FUS
M9VED(")?161I="(*;7-G<W1R(")?161I=&%R(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C(P"FUS9VED(")?1FER<W0@3&EN92(*;7-G<W1R
M(")0<FE?;65I<F$@3&EN:&$B"@HC.B!L:6(O36YE;6\N<&AP.C(Q,`IM<V=I
M9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R=&%R+T5X<&]R=&%R
M(@H*(SH@;&EB+TUN96UO+G!H<#HQ.38*;7-G:60@(E],:7-T($YO=&5S(@IM
M<V=S='(@(E],:7-T87(@3F]T87,B"@HC.B!L:6(O36YE;6\N<&AP.C(P-0IM
M<V=I9"`B7TUY($YO=&5P861S(@IM<V=S='(@(D]S(%]-975S($QI=G)O<R!D
M92!.;W1A<R(*"B,Z(&QI8B]-;F5M;RYP:'`Z,3DX"FUS9VED(")?3F5W($YO
M=&4B"FUS9W-T<B`B7TYO=F$@3F]T82(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C$U
M"FUS9VED(")?4')I;G0B"FUS9W-T<B`B26U?<')I;6ER(@H*(SH@;&EB+TUN
M96UO+G!H<#HR,#$*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B7U!R;V-U<F%R
M(@H*(SH@9&%T82YP:'`Z.#$@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M"FUS9VED(")N;W1E<RYC<W8B"FUS9W-T<B`B;F]T87,N8W-V(@H*(SH@9&%T
M82YP:'`Z,S,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ.`IM<V=I9"`B
M=DYO=&4B"FUS9W-T<B`B=DYO=&4B"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VUN96UO+W!O+VYB7TY/+G!O````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C4T-#,`,3`T,3<S-C(W-#8`,#$W
M-3$W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",@3F]R=V5G:6%N($UN96UO(%1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H
M0RD@,C`P,B!(;W)D92!0<F]J96-T+@HC(%1H:7,@9FEL92!I<R!D:7-T<FEB
M=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!-;F5M;R!P86-K
M86=E+@HC(%1O<G-T96EN(%,N($AA;G-E;B`\:'5L96)O97)`=&5C:&)E92YN
M;SXL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($UN96UO(#(N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R
M,#`R+3`V+3`U(#$Q.C0U*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@5&]R
M<W1E:6X@4RX@2&%N<V5N(#QH=6QE8F]E<D!T96-H8F5E+FYO/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@3F]R=V5G:6%N("A";VMM86PI(#QI,3AN0&QI<W1S+FAO
M<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@=&5M<&QA=&5S+VQI
M<W0O:&5A9&5R+FEN8SHS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!N;W1E<R(*;7-G<W1R("(E9"!M96UO<R(*"B,Z('1E;7!L871E<R]M96UO
M+VUE;6\N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&-H87)A8W1E
M<G,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3@W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@
M(B(*"B,Z(&YO=&5P861S+G!H<#HY.2!L:6(O8F%S92YP:'`Z,3`S"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*;7-G:60@(C$@;F]T92(*;7-G
M<W1R("(B"@HC.B!M96UO+G!H<#HQ-C(*;7-G:60@(D%C8V5S<R!D96YI960@
M9&5L971I;F<@;F]T92XB"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z,3$R(&UE
M;6\N<&AP.C$Q-0IM<V=I9"`B06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO
M=&4N(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP.C@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N(@IM<V=S
M='(@(B(*"B,Z(&UE;6\N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D%C
M8V5S<R!D96YI960@<V%V:6YG(&YO=&4Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z,3`S"B,L(&9U
M>GIY"FUS9VED(")!9&0@8V%T96=O<GDB"FUS9W-T<B`B2V%T96=O<FDB"@HC
M.B!M96UO+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B061D:6YG($$@3F5W($YO
M=&4B"FUS9W-T<B`B3&5G9R!T:6P@96ET(&YY='0@;F]T870B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#0*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R
M(")3=&EG86YD92(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E
M;&5C="YI;F,Z.3D*;7-G:60@(D%V86EL86)L92!#871E9V]R:65S.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR."!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B0F%C:R!T;R!.
M;W1E<&%D(@IM<V=S='(@(E1I;&)A:V4@=&EL(&YO=&%T;&ES=&4B"@HC.B!T
M96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDW"B,L(&9U>GIY"FUS
M9VED(")"86-K('1O($YO=&5P860@3W!T:6]N<R(*;7-G<W1R(")4:6QB86ME
M('1I;"!N;W1A=&QI<W1E(@H*(SH@9&%T82YP:'`Z,S(@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B0U-6(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C4T('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS9VED(")#
M871E9V]R>2(*;7-G<W1R(")+871E9V]R:2(*"B,Z('1E;7!L871E<R]N;W1E
M<&%D<R]N;W1E<&%D<RYI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*
M;7-G<W1R(")!;F=R92!E;F1R:6YG87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,34*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!Y;W5R(&YO=&4@<V]R
M=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R(")%;F1R92!A;'1E
M<FYA=&EV(&9O<B!S;W)T97)I;F<@;V<@=FES:6YG(&%V(&YO=&%T(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-H;W=S=6UM87)Y<V5L96-T+FEN8SHY,PIM<V=I
M9"`B0VAO;W-E('1H92!M96UO(&-A=&5G;W)I97,@=&\@;&ES="!I;B!T:&4@
M<W5M;6%R>2!V:65W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C(*;7-G:60@(D-H;V]S92!Y;W5R(&1E9F%U;'0@3F]T97!A9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,R
M"FUS9VED(")#;&5A<B!&;W)M(@IM<V=S='(@(DYU;&QS=&EL;"!S:VIE;6$B
M"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C$W('1E;7!L
M871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@=&5M<&QA=&5S+VYO
M=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C,U"FUS9VED(")#<F5A
M=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0HC
M+"!F=7IZ>0IM<V=I9"`B1&5F875L="!.;W1E<&%D(@IM<V=S='(@(E-T86YD
M87)D('-O<G1E<FEN9W-K<FET97)I=6TZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,U"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM
M<V=S='(@(E-T86YD87)D('-O<G1E<FEN9W-K<FET97)I=6TZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0V"FUS9VED(")$969A=6QT('-O<G1I;F<@
M9&ER96-T:6]N.B(*;7-G<W1R(")3=&%N9&%R9"!S;W)T97)I;F=S<F5K:V5F
M^&QG:F4Z(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY
M-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR-0HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHV-`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(@IM<V=S='(@
M(E-L971T(&YO=&%T(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-C<*
M;7-G:60@(D1E;&5T92!T:&ES(&YO=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0U"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@
M(E-Y;FMA;F1E(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN
M8SHX-0HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXZ(@IM<V=S='(@(E-K
M:6QD<FEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-`IM<V=I9"`B
M1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E9I<VEN9W-A;'1E<FYA=&EV(@H*
M(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C$@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z-C`*;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQI<W0O;65M;U]S=6UM87)I97,N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI
M<W0O;65M;U]H96%D97)S+FEN8SHT-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M.#,*;7-G:60@(D5D:70@3F]T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&ES="]M96UO7VAE861E<G,N:6YC.C4T"FUS9VED(")%9&ET(&-A=&5G;W)I
M97,@86YD(&-O;&]R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M
M96UO7W-U;6UA<FEE<RYI;F,Z,3(*;7-G:60@(D5M<'1Y($YO=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.0IM<V=I9"`B
M17AP;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z.`IM<V=I9"`B17AP;W)T($YO=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B1E]U
M;&P@5&5X="(*;7-G<W1R(")&=6QL=&5K<W0B"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($YO
M=&5S+"!3=&5P("5D(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$Y,PIM<V=I
M9"`B26UP;W)T+T5X<&]R="!.;W1E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHT,PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW,@IM<V=I9"`B36%X:6UU;2!.=6UB
M97(@;V8@3F]T97,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-3,*;7-G:60@
M(DUE;6\@5&5X="(*;7-G<W1R(").;W1A='1E:W-T(@H*(SH@;65M;RYP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y:6YG("5S(@IM<V=S='(@
M(D5N9')A<B`E<R(*"B,Z(&QI<W0N<&AP.C,U"FUS9VED(")->2!.;W1E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(RP@9G5Z
M>GD*;7-G:60@(DYE=R!.;W1E(@IM<V=S='(@(DYY='0@;F]T870B"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0P"FUS9VED(").97AT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C(P-@IM<V=I9"`B3F\@:4-A;&5N9&%R
M(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N
M=2YI;F,Z-PIM<V=I9"`B3F\@;F]T97!A9',@87)E(&%V86EL86)L92!T;R!G
M=65S=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI
M;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;F]T97,B"FUS9W-T<B`B26YG96X@
M;F]T870B"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z,PIM<V=I9"`B
M3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,#D*;7-G:60@(DYO(&YO
M=&5S('1O(&1I<W!L87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M;65M;U]H96%D97)S+FEN8SHT-@IM<V=I9"`B3F]?=&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T"B,L(&9U>GIY"FUS9VED(").
M;W1E($-A=&5G;W)Y(@IM<V=S='(@(DYO=&%T:V%T96=O<FDB"@HC.B!V:65W
M+G!H<#HX,"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHY"B,L(&9U>GIY"FUS
M9VED(").;W1E($1E=&%I;',B"FUS9W-T<B`B3F]T871D971A;&IA<B(*"B,Z
M(&YO=&5P861S+G!H<#HQ,3`*;7-G:60@(DYO=&4@3&ES=',B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S"B,L(&9U>GIY"FUS9VED
M(").;W1E(%1E>'0B"FUS9W-T<B`B3F]T871T96MS="(*"B,Z('1E;7!L871E
M<R]M96UO+VUE;6\N:6YC.C(V"B,L(&9U>GIY"FUS9VED(").;W1E(%]497AT
M(@IM<V=S='(@(DYO=&%T=&5K<W0B"@HC.B!V:65W+G!H<#HU-R!M96UO+G!H
M<#HV,`IM<V=I9"`B3F]T92!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M96UO+VUE;6\N:6YC.C,T"FUS9VED(").;W1E7W!A9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C<Y
M"FUS9VED(").;W1E<&%D)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHV,0IM<V=I9"`B3F]T97!A9',B
M"FUS9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP.C,S"FUS9VED(").;W1E<&%D
M<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,PIM<V=I9"`B3F]T97,@4W5M;6%R>2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(P"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D%N9')E
M(&%L=&5R;F%T:78B"@HC.B!L:6(O87!I+G!H<#HQ.#,@;&EB+V%P:2YP:'`Z
M,C<T(&QI8B]A<&DN<&AP.C,T-2!L:6(O87!I+G!H<#HS-S0*;7-G:60@(E!E
M<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N;W1E
M<&%D<R]N;W1E<&%D<RYI;F,Z.#(*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI;F,Z-2!T96UP;&%T
M97,O;&ES="]H96%D97(N:6YC.C8*;7-G:60@(E)E9G)E<V@@3&ES="(*;7-G
M<W1R(")&<FES:R!O<'`@;&ES=&4B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO
M=W-U;6UA<GES96QE8W0N:6YC.C$P-0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&-A=&5G;W)Y(@IM<V=S='(@(DYO=&%T:V%T96=O<FDB"@HC.B!T96UP;&%T
M97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDV"FUS9VED(")297-E="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU-@HC+"!F=7IZ
M>0IM<V=I9"`B4V%V92(*;7-G<W1R("),86=R92!N;W1A="(*"B,Z('-E87)C
M:"YP:'`Z,3<@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C0@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C,Q"FUS9VED(")396%R8V@B"FUS9W-T
M<B`B4_AK(@H*(SH@;&ES="YP:'`Z-3<*;7-G:60@(E-E87)C:"!297-U;'1S
M(@IM<V=S='(@(E/X:V5R97-U;'1A="(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHQ-PIM<V=I9"`B4V5A<F-H(%-C;W!E(@IM<V=S='(@(E/X
M:V5O;7+E9&4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z.0HC
M+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(%]497AT(@IM<V=S='(@(E/X:V5S=')E
M;F<B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8W"FUS
M9VED(")396QE8W0@82!N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M96YU+FEN8SHQ-@IM<V=I9"`B4V5L96-T(&YO=&5P861S('1O(&1I<W!L
M87DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,34*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-PIM<V=I9"`B4V5L
M96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H92!F;W)M
M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P.0IM<V=I9"`B4V5L
M96-T960@0V%T96=O<FEE<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C,X"FUS9VED(")3:&]W(&%C=&EO;B!B=71T;VYS/R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*;7-G:60@(E-H
M;W<@;F]T97!A9"!N86UE/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z-#0*;7-G:60@(E-H;W<@;F]T97,@9G)O;2!T:&5S92!C871E
M9V]R:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A
M9&5R<RYI;F,Z-3`*;7-G:60@(E-O<G0@8GD@0V%T96=O<GDB"FUS9W-T<B`B
M4V]R=&5R(&5T=&5R(&MA=&5G;W)I(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M
M;U]H96%D97)S+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!.;W1E
M(%1E>'0B"FUS9W-T<B`B4V]R=&5R(&5T=&5R(&MA=&5G;W)I(@H*(SH@;65M
M;RYP:'`Z,3,U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP.C$U.0HC+"!F
M=7IZ>0IM<V=I9"`B5&AE(&YO=&4@=V%S(&1E;&5T960N(@IM<V=S='(@(DEN
M9V5N(&YO=&%T('9A<G0@<VQE='1A+B(*"B,Z(&YO=&5P861S+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@8V]U;&1N
M)W0@8F4@8W)E871E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP
M.C0X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H
M87,@8F5E;B!C<F5A=&5D+B(*;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&YO=&5P860@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H<#HU
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!D871A.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR,#`*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HS.3,*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('9.;W1E(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&UE;6\N<&AP.C$U-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H
M92!N;W1E.B`E<R(*;7-G<W1R(")0<F]B;&5M('9E9"!S;&5T=&EN9R!A=B!N
M;W1A="XB"@HC.B!M96UO+G!H<#HQ,S,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AE(&YO=&4Z("5S
M(@IM<V=S='(@(E!R;V)L96T@=F5D('-L971T:6YG(&%V(&YO=&%T+B(*"B,Z
M('9I97<N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!V:65W:6YG('1H:7,@;F]T97!A9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=E<F4@;F\@
M;65M;W,@=&\@97AP;W)T+B(*;7-G<W1R(")$970@9OAR97-P=7)T92!N;W1A
M=&5T(&5K<VES=&5R97(@:6MK:F4N(@H*(SH@9&%T82YP:'`Z,3`U"FUS9VED
M(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(E5N9&\@
M8VAA;F=E<R(*;7-G<W1R(")!;F=R92!E;F1R:6YG87(B"@HC.B!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHQ-B!T96UP;&%T97,O;&ES="]M96UO7W-U;6UA
M<FEE<RYI;F,Z,30*(SH@;&EB+TUN96UO+G!H<#HR,#8@;&EB+TUN96UO+G!H
M<#HR,#<@;&EB+TUN96UO+G!H<#HR,C$@;&EB+TUN96UO+G!H<#HR,C(*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P-0IM<V=I9"`B56YF:6QE9"(*;7-G
M<W1R(")587)K:79E<G0B"@HC.B!L:6(O87!I+G!H<#HR,S8@;&EB+V%P:2YP
M:'`Z,S`Y(&QI8B]A<&DN<&AP.C0P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C(*;7-G:60@(E=H:6-H($YO=&5P
M860@<VAO=6QD('1H92!N;W1E<R!B92!A9&1E9"!T;S\B"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-#(@9&%T82YP:'`Z,3(U(&UE;6\N<&AP.C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!N;W1E<RXB"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI
M<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M;F]T97!A9',N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE
M8W0@82!N;W1E<&%D('1O(&)E(&1E;&5T960N(@IM<V=S='(@(D1U(&WE(&;X
M<G-T('9E;&IE(&UI;G-T(&5I='0@;F]T870N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VYO=&5P861S96QE8W0N:6YC.C$P"FUS9VED(")9;W5R(&1E9F%U;'0@
M;F]T97!A9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHV-0IM<V=I9"`B66]U<B!N;W1E<&%D<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,C@@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E]"86-K('1O($YO=&5P
M860B"FUS9W-T<B`B5&EL8F%K92!T:6P@;F]T871L:7-T92(*"B,Z('1E;7!L
M871E<R]M96UO+VUE;6\N:6YC.C4Q('1E;7!L871E<R]L:7-T+VUE;6]?:&5A
M9&5R<RYI;F,Z-3`*(RP@9G5Z>GD*;7-G:60@(E]#871E9V]R>2(*;7-G<W1R
M(")+871E9V]R:2(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(U('1E
M;7!L871E<R]V:65W+VUE;6\N:6YC.C8T"B,L(&9U>GIY"FUS9VED(")?1&5L
M971E(@IM<V=S='(@(E-L971T(&YO=&%T(@H*(SH@=&5M<&QA=&5S+W9I97<O
M;65M;RYI;F,Z,C$@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-C`*;7-G:60@
M(E]%9&ET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHR,`IM<V=I9"`B7T9I<G-T($QI;F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TUN96UO+G!H<#HR.#$*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8T"B,L(&9U>GIY"FUS9VED(")?3&ES
M="!.;W1E<R(*;7-G<W1R(")6:7,@;F]T870B"@HC.B!L:6(O36YE;6\N<&AP
M.C(W-@IM<V=I9"`B7TUY($YO=&5P861S(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M;F5M;RYP:'`Z,C8Y"FUS9VED(")?3F5W($YO=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TUN96UO+G!H<#HR.#8*;7-G:60@(E]0<FEN="(*;7-G<W1R("(B"@HC
M.B!L:6(O36YE;6\N<&AP.C(W,@HC+"!F=7IZ>0IM<V=I9"`B7U-E87)C:"(*
M;7-G<W1R(")3^&LB"@HC.B!D871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$*;7-G:60@(FYO=&5S+F-S=B(*;7-G<W1R("(B"@HC.B!D
M871A+G!H<#HS,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$X"FUS9VED
M(")V3F]T92(*;7-G<W1R("(B"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M
M;R]P;R]S=E]312YP;P``````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#,R,S`U`#$P-#$W,S8R-S0V`#`Q-S4S-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````C(%-W961I<V@@=')A
M;G-L871I;VYS(&9O<B!-;F5M;R!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@
M,C`P-2!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D
M('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($UN96UO('!A8VMA9V4N
M"B,@2F]A<75I;2!(;VUR:6=H875S96X@/&IO:&]`=V5B8G!L871S96XN<V4^
M+"`R,#`V+@HC($%N9')E87,@1&%H;&5N(#QA;F1R96%S0&1A:&QE;BYW<SXL
M(#(P,#(M,C`P-2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M
M5F5R<VEO;CH@36YE;6\@,BXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#8M,#$M,S$@,C$Z-3(K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-BTP,2TS,2`R,CHP,"LP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($IO87%U
M:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@4W=E9&ES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB
M"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]L:7-T+VAE861E<BYI
M;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!N;W1E<R(*;7-G<W1R("(E
M9"!A;G1E8VMN:6YG87(B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!C:&%R86-T97)S(@IM<V=S='(@
M(B5S('1E8VME;B(*"B,Z(&1A=&$N<&AP.C$X-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R(")&
M:6QE;B`E<R!I;7!O<G1E<F%D97,B"@HC.B!N;W1E<&%D<RYP:'`Z.3D@;&EB
M+V)A<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P
M860B"FUS9W-T<B`B06YT96-K;FEN9V%R(&;V<B`E<R(*"B,Z('1E;7!L871E
M<R]L:7-T+VAE861E<BYI;F,Z,PIM<V=I9"`B,2!N;W1E(@IM<V=S='(@(C$@
M86YT96-K;FEN9R(*"B,Z(&UE;6\N<&AP.C$V,@IM<V=I9"`B06-C97-S(&1E
M;FEE9"!D96QE=&EN9R!N;W1E+B(*;7-G<W1R("+%=&MO;7-T(&YE:V%D+B(*
M"B,Z(&UE;6\N<&AP.C$Q,B!M96UO+G!H<#HQ,34*;7-G:60@(D%C8V5S<R!D
M96YI960@;6]V:6YG('1H92!N;W1E+B(*;7-G<W1R(")"96CV<FEG:&5T('-A
M:VYA<R!A='0@9FQY='1A(&%N=&5C:VYI;F<N(@H*(SH@;65M;RYP:'`Z.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!S879I;F<@;F]T
M92!T;R`E<RXB"FUS9W-T<B`B0F5H]G)I9VAE="!S86MN87,@871T('-P87)A
M(&%N=&5C:VYI;F<@=&EL;"`E<RXB"@HC.B!M96UO+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E.B`E<R(*
M;7-G<W1R(")"96CV<FEG:&5T('-A:VYA<R!A='0@<W!A<F$@86YT96-K;FEN
M9SH@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N
M:6YC.C$P,PIM<V=I9"`B061D(&-A=&5G;W)Y(@IM<V=S='(@(DSD9V<@=&EL
M;"!K871E9V]R:2(*"B,Z(&UE;6\N<&AP.C4R"FUS9VED(")!9&1I;F<@02!.
M97<@3F]T92(*;7-G<W1R("),Y&=G97(@=&EL;"!E;B!A;G1E8VMN:6YG(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED(")!<V-E;F1I;F<B
M"FUS9W-T<B`B4W1I9V%N9&4B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U
M;6UA<GES96QE8W0N:6YC.CDY"FUS9VED(")!=F%I;&%B;&4@0V%T96=O<FEE
M<SHB"FUS9W-T<B`B5&EL;&?D;F=L:6=A(&MA=&5G;W)I97(Z(@H*(SH@=&5M
M<&QA=&5S+W9I97<O;65M;RYI;F,Z,3@*;7-G:60@(D)A8VL@=&\@3F]T97!A
M9"(*;7-G<W1R(")4:6QL8F%K82!T:6QL(&%N=&5C:VYI;F=S8FQO8VLB"@HC
M.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDW"FUS9VED(")"
M86-K('1O($YO=&5P860@3W!T:6]N<R(*;7-G<W1R(")4:6QL8F%K82!T:6QL
M(&EN<W3D;&QN:6YG87(@9O9R(&%N=&5C:VYI;F=S8FQO8VLB"@HC.B!D871A
M+G!H<#HS,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")#
M4U8B"FUS9W-T<B`B0U-6(@H*(SH@9&%T82YP:'`Z-30@=&5M<&QA=&5S+W9I
M97<O;65M;RYI;F,Z,C8*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G
M;W)I(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHR,@IM
M<V=I9"`B0VAA;F=E(@IM<V=S='(@(L1N9')A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U"FUS9VED(")#:&%N9V4@>6]U<B!N;W1E('-O<G1I;F<@
M86YD(&1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`BQ&YD<F$@<V]R=&5R:6YG
M<RT@;V-H('9I<VYI;F=S:6YS=.1L;&YI;F=A<B!F]G(@86YT96-K;FEN9V%R
M+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z
M.3,*;7-G:60@(D-H;V]S92!T:&4@;65M;R!C871E9V]R:65S('1O(&QI<W0@
M:6X@=&AE('-U;6UA<GD@=FEE=RXB"FUS9W-T<B`B5N1L:B!A;G1E8VMN:6YG
M<VMA=&5G;W)I97(@<V]M('-K86QL('9I<V%S(&D@<V%M;6%N<W3D;&QN:6YG
M<W9Y;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(*;7-G:60@(D-H
M;V]S92!Y;W5R(&1E9F%U;'0@3F]T97!A9"XB"FUS9W-T<B`B5N1L:B!D:71T
M(&;V<G9A;&1A(&%N=&5C:VYI;F=S8FQO8VMK+B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHS,@IM<V=I9"`B0VQE87(@1F]R;2(*;7-G<W1R
M(")296YS82!F;W)M=6SD<B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E
M<&%D<RYI;F,Z,3<@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY
M-`HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.CDV"FUS9VED
M(")#<F5A=&4B"FUS9W-T<B`B4VMA<&$B"@HC.B!T96UP;&%T97,O=FEE=R]M
M96UO+FEN8SHS,@IM<V=I9"`B0W)E871E9"(*;7-G<W1R(")3:V%P860B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*;7-G:60@(D1E9F%U;'0@3F]T
M97!A9"(*;7-G<W1R(")&]G)V86QT(&%N=&5C:VYI;F=S8FQO8VLB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(*;7-G:60@(D1E9F%U;'0@<V]R=&EN
M9R!C<FET97)I83HB"FUS9W-T<B`B1O9R=F%L9"!S;W)T97)I;F=S:W)I=&5R
M:6$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S"FUS9VED(")$969A
M=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R(")&]G)V86QD('-O<G1E
M<FEN9W-O<F1N:6YG(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S
M+FEN8SHY-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ-0IM<V=I9"`B1&5L
M971E(@IM<V=S='(@(E)A9&5R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R(")2861E
M<F$@8F5K<N1F=&5L<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*
M;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(D9U;FMT
M:6]N(&;V<B!K;F%P<&5N(%)A9&5R82(*"B,Z('1E;7!L871E<R]M96UO+VUE
M;6\N:6YC.C8W"FUS9VED(")$96QE=&4@=&AI<R!N;W1E(@IM<V=S='(@(E)A
M9&5R82!A;G1E8VMN:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R
M"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(D9A;&QA;F1E(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHX-0IM<V=I9"`B1&5S8W)I
M<'1I;VXZ(@IM<V=S='(@(D)E<VMR:79N:6YG.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(E9I<VYI;F=S:6YS=.1L;&YI;F=A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN
M9R!E;G1R:65S/R(*;7-G<W1R(")6:6QL(&1U(&)E:W+D9G1A(')A9&5R:6YG
M(&%V('!O<W1E<C\B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHQ,0IM
M<V=I9"`B161I="(*;7-G<W1R("+$;F1R82(*"B,Z('1E;7!L871E<R]L:7-T
M+VUE;6]?<W5M;6%R:65S+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@7"(E<UPB(@IM<V=S='(@(L1N9')A("<E<R<B"@HC.B!T96UP;&%T97,O
M;&ES="]M96UO7VAE861E<G,N:6YC.C0R(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HX,@IM<V=I9"`B161I="!.;W1E(@IM<V=S='(@(L1N9')A(&%N=&5C:VYI
M;F<B"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C4R"FUS
M9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<R(*;7-G<W1R("+$;F1R
M82!K871E9V]R:65R(&]C:"!FY')G97(B"@HC.B!T96UP;&%T97,O;&ES="]M
M96UO7W-U;6UA<FEE<RYI;F,Z,3(*;7-G:60@(D5M<'1Y($YO=&4B"FUS9W-T
M<B`B5&]M(&%N=&5C:VYI;F<B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$Y"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T97)A(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@3F]T
M97,B"FUS9W-T<B`B17AP;W)T97)A(&%N=&5C:VYI;F=A<B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,0IM<V=I9"`B1E]U;&P@5&5X="(*
M;7-G<W1R(")(96QA('1E>'1E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(W"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS9W-T<B`B06QL
M;>1N;F$@:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@3F]T97,L(%-T
M97`@)60B"FUS9W-T<B`B26UP;W)T97)A(&%N=&5C:VYI;F=A<BP@<W1E9R`E
M9"(*"B,Z(&1A=&$N<&AP.C$Y,PIM<V=I9"`B26UP;W)T+T5X<&]R="!.;W1E
M<R(*;7-G<W1R("));7!O<G1E<F$O97AP;W)T97)A(&%N=&5C:VYI;F=A<B(*
M"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C,Y"FUS9VED("),87-T($UO
M9&EF:65D(@IM<V=S='(@(E-E;F%S="#D;F1R860B"@HC.B!L:6(O87!I+G!H
M<#HW,@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@3F]T97,B"FUS9W-T<B`B
M36%X:6UA;'0@86YT86P@86YT96-K;FEN9V%R(@H*(SH@9&%T82YP:'`Z-3,*
M;7-G:60@(DUE;6\@5&5X="(*;7-G<W1R(")!;G1E8VMN:6YG<W1E>'0B"@HC
M.B!M96UO+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GEI;F<@
M)7,B"FUS9W-T<B`BQ&YD<F%R("5S(@H*(SH@;&ES="YP:'`Z,S4*;7-G:60@
M(DUY($YO=&5S(@IM<V=S='(@(DUI;F$@86YT96-K;FEN9V%R(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS9VED(").97<@3F]T92(*;7-G<W1R
M(").>2!A;G1E8VMN:6YG(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHT,`IM<V=I9"`B3F5X="(*;7-G<W1R(").Y'-T82(*"B,Z(&QI8B]A<&DN
M<&AP.C(P-@IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*
M;7-G<W1R(")I0V%L96YD87(M:6YF;W)M871I;VX@<V%K;F%S+B(*"B,Z('1E
M;7!L871E<R]M96YU+FEN8SHW"FUS9VED(").;R!N;W1E<&%D<R!A<F4@879A
M:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B26YG82!A;G1E8VMN:6YG<V)L
M;V-K('1I;&QGY&YG;&EG82!F]G(@9^1S=&5R+B(*"B,Z('1E;7!L871E<R]L
M:7-T+VAE861E<BYI;F,Z,PIM<V=I9"`B3F\@;F]T97,B"FUS9W-T<B`B26YG
M82!A;G1E8VMN:6YG87(B"@HC.B!T96UP;&%T97,O;&ES="]E;7!T>2YI;F,Z
M,PIM<V=I9"`B3F\@;F]T97,@;6%T8V@@=&AE(&-U<G)E;G0@8W)I=&5R:6$N
M(@IM<V=S='(@(DEN9V$@86YT96-K;FEN9V%R(&UA=&-H87(@86MT=65L;'0@
M=7)V86PN(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P.`IM<V=I9"`B
M3F\@;F]T97,@=&\@9&ES<&QA>2(*;7-G<W1R("));F=A(&%N=&5C:VYI;F=A
M<B!A='0@=FES82(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?:&5A9&5R<RYI
M;F,Z-#0*;7-G:60@(DYO7W1E(@IM<V=S='(@(D%N7W1E8VMN:6YG(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q"FUS9VED(").;W1E($-A=&5G;W)Y
M(@IM<V=S='(@(D%N=&5C:VYI;F=S:V%T96=O<FDB"@HC.B!V:65W+G!H<#HX
M,"!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,0IM<V=I9"`B3F]T92!$971A
M:6QS(@IM<V=S='(@(D%N=&5C:VYI;F=S9&5T86QJ97(B"@HC.B!N;W1E<&%D
M<RYP:'`Z,3$P"FUS9VED(").;W1E($QI<W1S(@IM<V=S='(@(D%N=&5C:VYI
M;F=S;&ES=&]R(@H*(SH@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z-#4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0P"FUS9VED(").;W1E(%1E>'0B"FUS9W-T
M<B`B06YT96-K;FEN9W-T97AT(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI
M;F,Z,C8*;7-G:60@(DYO=&4@7U1E>'0B"FUS9W-T<B`B06YT96-K;FEN9W-?
M=&5X="(*"B,Z('9I97<N<&AP.C4W(&UE;6\N<&AP.C8P"FUS9VED(").;W1E
M(&YO="!F;W5N9"XB"FUS9W-T<B`B06YT96-K;FEN9R!S86MN87,N(@H*(SH@
M=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,S0*;7-G:60@(DYO=&5?<&%D(@IM
M<V=S='(@(D%N=&5C:VYI;F=S7V)L;V-K(@H*(SH@=&5M<&QA=&5S+VYO=&5P
M861S+VYO=&5P861S+FEN8SHW.0IM<V=I9"`B3F]T97!A9"=S(&YA;64Z(@IM
M<V=S='(@(D%N=&5C:VYI;F=S8FQO8VMS;F%M;CHB"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"FUS9VED(").;W1E<&%D<R(*;7-G
M<W1R(")!;G1E8VMN:6YG<V)L;V-K(@H*(SH@;F]T97!A9',N<&AP.C,S"FUS
M9VED(").;W1E<&%D<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R(")!;G1E
M8VMN:6YG<V)L;V-K(&WE<W1E(&AA(&5T="!N86UN+B(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HS"FUS9VED(").;W1E<R!3=6UM87)Y(@IM<V=S='(@
M(D%N=&5C:VYI;F=S('-U;6UE<FEN9R(*"B,Z(&QI8B]A<&DN<&AP.C$X,R!L
M:6(O87!I+G!H<#HR-SD@;&EB+V%P:2YP:'`Z,S4U(&QI8B]A<&DN<&AP.C,X
M-`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`BQ71K;VUS="!N
M96MA9"(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#(*
M;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(D)E:/9R:6=H971E<B(*"B,Z
M('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS9VED(")296%L;'D@9&5L
M971E('1H:7,@;F]T93\B"FUS9W-T<B`B4F%D97)A(&1E;FYA(&%N=&5C:VYI
M;F<_(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8SHU('1E;7!L871E
M<R]L:7-T+VAE861E<BYI;F,Z-@IM<V=I9"`B4F5F<F5S:"!,:7-T(@IM<V=S
M='(@(E5P<&1A=&5R82!L:7-T82(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W
M<W5M;6%R>7-E;&5C="YI;F,Z,3`U"FUS9VED(")296UO=F4@8V%T96=O<GDB
M"FUS9W-T<B`B4F%D97)A(&MA=&5G;W)I(@H*(SH@=&5M<&QA=&5S+VYO=&5P
M861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS9W-T<B`BQ71E
M<G-TY&QL(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-38*;7-G:60@
M(E-A=F4B"FUS9W-T<B`B4W!A<F$B"@HC.B!S96%R8V@N<&AP.C$W('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHT('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHS,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E/V:R(*"B,Z(&QI
M<W0N<&AP.C4W"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R(")3]FMR
M97-U;'1A="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ-PIM
M<V=I9"`B4V5A<F-H(%-C;W!E(@IM<V=S='(@(E5R=F%L(&;V<B!S]FMN:6YG
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.CD*;7-G:60@(E-E
M87)C:"!?5&5X="(*;7-G<W1R(")3]FL@7W1E>'0B"@HC.B!T96UP;&%T97,O
M;F]T97!A9',O;F]T97!A9',N:6YC.C8W"FUS9VED(")396QE8W0@82!N;W1E
M<&%D(@IM<V=S='(@(E;D;&H@971T(&%N=&5C:VYI;F=S8FQO8VLB"@HC.B!T
M96UP;&%T97,O;65N=2YI;F,Z,38*;7-G:60@(E-E;&5C="!N;W1E<&%D<R!T
M;R!D:7-P;&%Y.B(*;7-G<W1R(")!;F=E(&%N=&5C:VYI;F=S8FQO8VL@871T
M('9I<V$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I
M9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R(")6Y&QJ(&5X
M<&]R=&9O<FUA=#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,W
M"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")6
MY&QJ(&9I;"!S;VT@<VMA;&P@:6UP;W)T97)A<SHB"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$U"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O
M9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E;D;&H@9F]R;6%T('#E(&EM
M<&]R=&9I;&5N.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E
M;&5C="YI;F,Z,3`Y"FUS9VED(")396QE8W1E9"!#871E9V]R:65S.B(*;7-G
M<W1R(")686QD82!K871E9V]R:65R.B(*"B,Z('1E;7!L871E<R]M96YU+VUE
M;G4N:6YC.C,X"FUS9VED(")3:&]W(@IM<V=S='(@(E9I<V$B"@HC.B!T96UP
M;&%T97,O;65N=2]M96YU+FEN8SHT,PIM<V=I9"`B4VAO=R!.;W1E<&%D<SHB
M"FUS9W-T<B`B5FES82!A;G1E8VMN:6YG<V)L;V-K.B(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HS-PIM<V=I9"`B4VAO=R!A8W1I;VX@8G5T=&]N<S\B
M"FUS9W-T<B`B5FES82!A:W1I=FET971S:VYA<'!A<C\B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z-#`*;7-G:60@(E-H;W<@;F]T97!A9"!N86UE/R(*
M;7-G<W1R(")6:7-A(&%N=&5C:VYI;F=S8FQO8VME=',@;F%M;C\B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#,*;7-G:60@(E-H;W<@;F]T97,@9G)O
M;2!T:&5S92!C871E9V]R:65S(@IM<V=S='(@(E9I<V$@86YT96-K;FEN9V%R
M(&UE9"!D97-S82!K871E9V]R:65R(@H*(SH@=&5M<&QA=&5S+VQI<W0O;65M
M;U]H96%D97)S+FEN8SHT.`IM<V=I9"`B4V]R="!B>2!#871E9V]R>2(*;7-G
M<W1R(")3;W)T97)A('#E(&MA=&5G;W)I(@H*(SH@=&5M<&QA=&5S+VQI<W0O
M;65M;U]H96%D97)S+FEN8SHT-`IM<V=I9"`B4V]R="!B>2!.;W1E(%1E>'0B
M"FUS9W-T<B`B4V]R=&5R82!PY2!A;G1E8VMN:6YG<W1E>'0B"@HC.B!M96UO
M+G!H<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A
M=F5D(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R!S<&%R861E<RXB"@HC.B!M96UO
M+G!H<#HQ-3D*;7-G:60@(E1H92!N;W1E('=A<R!D96QE=&5D+B(*;7-G<W1R
M(")!;G1E8VMN:6YG96X@<F%D97)A9&5S+B(*"B,Z(&YO=&5P861S+G!H<#HT
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@8V]U
M;&1N)W0@8F4@8W)E871E9#H@)7,B"FUS9W-T<B`B06YT96-K;FEN9W-B;&]C
M:R`G)7,G(&MU;F1E(&EN=&4@<VMA<&%S.B`E<R(*"B,Z(&YO=&5P861S+G!H
M<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;F]T97!A9"!<(B5S7"(@
M:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B06YT96-K;FEN9W-B;&]C:V5T
M("<E<R<@<VMA<&%D97,N(@H*(SH@;F]T97!A9',N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R(")!;G1E8VMN:6YG<V)L;V-K970@)R5S)R!R861E<F%D
M97,N(@H*(SH@;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B
M06YT96-K;FEN9W-V;&]C:V5T("<E<R<@<W!A<F%T<RXB"@HC.B!D871A+G!H
M<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`B1&5T('5P<'-T;V0@
M9F5L('9I9"!I;7!O<G0@878@9&%T83H@)7,N(@H*(SH@;&EB+V%P:2YP:'`Z
M,C`P"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`B1F5L('9I9"!I;7!O<G0@878@:4-A
M;&5N9&%R+61A=&$N(@H*(SH@;&EB+V%P:2YP:'`Z-#`S"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!V3F]T92!D871A+B(*;7-G
M<W1R(")&96P@=FED(&EM<&]R="!A=B!V3F]T92UD871A+B(*"B,Z(&UE;6\N
M<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@<F5M;W9I;F<@=&AE(&YO=&4Z("5S(@IM<V=S='(@(D1E="!U<'!S=&]D
M(&9E;"!NY'(@86YT96-K;FEN9V5N('-K=6QL92!R861E<F%S.B`E<R(*"B,Z
M(&UE;6\N<&AP.C$S,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<R(*;7-G<W1R(")$970@=7!P
M<W1O9"!F96P@;N1R(&%N=&5C:VYI;F=E;B!S:W5L;&4@<W!A<F%S.B`E<R(*
M"B,Z('9I97<N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!V:65W:6YG('1H:7,@;F]T97!A9#H@)7,B"FUS9W-T<B`B
M1&5T('5P<'-T;V0@9F5L('9I9"!V:7-N:6YG(&%V(&%N=&5C:VYI;F=E;CH@
M)7,B"@HC.B!D871A+G!H<#HW.0IM<V=I9"`B5&AE<F4@=V5R92!N;R!M96UO
M<R!T;R!E>'!O<G0N(@IM<V=S='(@(DEN9V$@86YT96-K;FEN9R!A='0@97AP
M;W)T97)A+B(*"B,Z(&1A=&$N<&AP.C$P-0IM<V=I9"`B5&AI<R!F:6QE(&9O
M<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")&:6QF;W)M871E="!S
M=/9D<R!I;G1E+B(*"B,Z(&YO=&5P861S+G!H<#HX,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2W5N9&4@:6YT92!R861E<F$@)R5S)SH@)7,B"@HC.B!T96UP;&%T97,O;65M
M;R]M96UO+FEN8SHU.`IM<V=I9"`B56YD;R!C:&%N9V5S(@IM<V=S='(@(L5N
M9W)A(.1N9')I;F=A<B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C(W
M('1E;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ-`HC.B!S8W)I
M<'1S+V-O;G9E<G1?8V%T96=O<FEE<RYP:'`Z-#D*(SH@<V-R:7!T<R]U<&=R
M861E<R\R,#`T+3`U+3$Y7V-O;G9E<G1?8V%T96=O<FEE<U]T;U]S=')I;F=S
M+G!H<#HT.0HC.B!L:6(O36YE;6\N<&AP.C(P-B!L:6(O36YE;6\N<&AP.C(P
M-R!L:6(O36YE;6\N<&AP.C(R,2!L:6(O36YE;6\N<&AP.C(R,@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,3`S"FUS9VED(")5;F9I;&5D(@IM<V=S='(@
M(D5J(&MA=&5G;W)I<V5R860B"@HC.B!L:6(O87!I+G!H<#HR,S8@;&EB+V%P
M:2YP:'`Z,S$Y(&QI8B]A<&DN<&AP.C0Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(D-O;G1E
M;G0M5'EP92!S=/9D<R!I;G1E.B`E<R(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,C(*;7-G:60@(E=H:6-H($YO=&5P860@<VAO=6QD('1H92!N
M;W1E<R!B92!A9&1E9"!T;S\B"FUS9W-T<B`B5&EL;"!V:6QK970@86YT96-K
M;FEN9W-B;&]C:R!S:V%L;"!A;G1E8VMN:6YG87(@;.1G9V%S('1I;&P_(@H*
M(SH@9&%T82YP:'`Z-#(@9&%T82YP:'`Z,3(U(&UE;6\N<&AP.C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!N;W1E<RXB"FUS9W-T<B`B1'4@:&%R(&EN=&4@8F5H
M]G)I9VAE="!A='0@<VMA<&$@9FQE<B#D;B`E9"!A;G1E8VMN:6YG87(N(@H*
M(SH@=FEE=RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&4@;F]T97!A9"`E<RXB"FUS
M9W-T<B`B1'4@:&%R(&EN=&4@8F5H]G)I9R!A='0@=FES82!A;G1E8VMN:6YG
M<V)L;V-K("<E<R<N(@H*(SH@;F]T97!A9',N<&AP.C8U"FUS9VED(")9;W4@
M;75S="!S96QE8W0@82!N;W1E<&%D('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(D1U(&WE<W1E(&%N9V4@971T(&%N=&5C:VYI;F=S8FQO8VL@<V]M('-K86QL
M(')A9&5R87,N(@H*(SH@=&5M<&QA=&5S+W!R969S+VYO=&5P861S96QE8W0N
M:6YC.C$P"FUS9VED(")9;W5R(&1E9F%U;'0@;F]T97!A9#HB"FUS9W-T<B`B
M1&ET="!F]G)V86QD82!A;G1E8VMN:6YG<V)L;V-K.B(*"B,Z('1E;7!L871E
M<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z-C4*;7-G:60@(EEO=7(@;F]T97!A
M9',Z(@IM<V=S='(@(D1I;F$@86YT96-K;FEN9W-B;&]C:SHB"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHQ.`IM<V=I9"`B7T)A8VL@=&\@3F]T97!A
M9"(*;7-G<W1R(")?5&EL;&)A:V$@=&EL;"!A;G1E8VMN:6YG<V)L;V-K(@H*
M(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-3$@=&5M<&QA=&5S+VQI<W0O
M;65M;U]H96%D97)S+FEN8SHT.`IM<V=I9"`B7T-A=&5G;W)Y(@IM<V=S='(@
M(E]+871E9V]R:2(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$U"FUS
M9VED(")?1&5L971E(@IM<V=S='(@(E]2861E<F$B"@HC.B!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHQ,0IM<V=I9"`B7T5D:70B"FUS9W-T<B`BQ&YD<F$B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C`*;7-G:60@(E]&
M:7)S="!,:6YE(@IM<V=S='(@(E]&]G)S=&$@<F%D96XB"@HC.B!T96UP;&%T
M97,O;65N=2]M96YU+FEN8SHQ-B!L:6(O36YE;6\N<&AP.C(X,0IM<V=I9"`B
M7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R="]%>'!O<G0B"@HC.B!T
M96UP;&%T97,O;65N=2]M96YU+FEN8SHV(&QI8B]-;F5M;RYP:'`Z,C8T"FUS
M9VED(")?3&ES="!.;W1E<R(*;7-G<W1R(")?3&ES=&$@86YT96-K;FEN9V%R
M(@H*(SH@;&EB+TUN96UO+G!H<#HR-S8*;7-G:60@(E]->2!.;W1E<&%D<R(*
M;7-G<W1R(")?36EN82!A;G1E8VMN:6YG<V)L;V-K(@H*(SH@=&5M<&QA=&5S
M+VUE;G4O;65N=2YI;F,Z."!L:6(O36YE;6\N<&AP.C(V.0IM<V=I9"`B7TYE
M=R!.;W1E(@IM<V=S='(@(E].>2!A;G1E8VMN:6YG(@H*(SH@=&5M<&QA=&5S
M+VUE;G4O;65N=2YI;F,Z,C$@;&EB+TUN96UO+G!H<#HR.#8*;7-G:60@(E]0
M<FEN="(*;7-G<W1R(")?571S:W)I9G0B"@HC.B!T96UP;&%T97,O;65N=2]M
M96YU+FEN8SHQ,2!L:6(O36YE;6\N<&AP.C(W,@IM<V=I9"`B7U-E87)C:"(*
M;7-G<W1R(")?4_9K(@H*(SH@9&%T82YP:'`Z.3$@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ"FUS9VED(")N;W1E<RYC<W8B"FUS9W-T<B`B86YT96-K
M;FEN9V%R+F-S=B(*"B,Z(&1A=&$N<&AP.C,S('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3@*;7-G:60@(G9.;W1E(@IM<V=S='(@(G9.;W1E(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W!O+V5L7T=2+G!O````````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8Q-C8`,3`T
M,3<S-C(W-#8`,#$W-3$W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````",@36YE;6\@1W)E96L@=')A;G-L871I;VX*(R!#;W!Y
M<FEG:'0@*$,I(#(P,#(@4W1E9F%N;W,@22X@1&EM:71R:6]U+@HC(%-T969A
M;F]S($DN($1I;6ET<FEO=2`\<W5P<&]R=%]W96)M86EL0'1E:6%T:"YG<CXL
M(#(P,#(N"B,@4VEL;&EG87)D;W,@6')I<W1O9F]R;W,L(#(P,#(N"B,@06YA
M9VYO<W1O<&]U;&]S($%P;W-T;VQI<RP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@36YE;6\Z(#$N,2UC=G-<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`R+3$Q+3$R(#$R.C$R*S`R,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@4W1E9F%N;W,@22X@1&EM:71R:6]U(#QS=7!P
M;W)T7W=E8FUA:6Q`=&5I871H+F=R/EQN(@HB3&%N9W5A9V4M5&5A;3H@1W)E
M96L@/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N
M,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX
M.#4Y+3=<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB
M"@HC.B!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5D(&YO=&5S(@IM<V=S='(@(B5D(//G[.7I_O/E
MZ?(B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHR-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&1A=&$N
M<&AP.C$X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F
M=6QL>2!I;7!O<G1E9"(*;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z.3D@
M;&EB+V)A<V4N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO
M=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN
M8SHS"FUS9VED("(Q(&YO=&4B"FUS9W-T<B`B(@H*(SH@;65M;RYP:'`Z,38R
M"FUS9VED(")!8V-E<W,@9&5N:65D(&1E;&5T:6YG(&YO=&4N(@IM<V=S='(@
M(B(*"B,Z(&UE;6\N<&AP.C$Q,B!M96UO+G!H<#HQ,34*;7-G:60@(D%C8V5S
M<R!D96YI960@;6]V:6YG('1H92!N;W1E+B(*;7-G<W1R("(B"@HC.B!M96UO
M+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A
M=FEN9R!N;W1E('1O("5S+B(*;7-G<W1R("(B"@HC.B!M96UO+G!H<#HX,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('-A=FEN9R!N;W1E
M.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA
M<GES96QE8W0N:6YC.C$P,PHC+"!F=7IZ>0IM<V=I9"`B061D(&-A=&5G;W)Y
M(@IM<V=S='(@(LKA].?C[_'?X2(*"B,Z(&UE;6\N<&AP.C4R"B,L(&9U>GIY
M"FUS9VED(")!9&1I;F<@02!.97<@3F]T92(*;7-G<W1R("+0\>_SZ-[JYR#L
MW^'R(.W=X?(@\^?LY=_Y\^?R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`BP?WN[_7SX2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S:&]W<W5M;6%R>7-E;&5C="YI;F,Z.3D*;7-G:60@
M(D%V86EL86)L92!#871E9V]R:65S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHR."!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV
M-PHC+"!F=7IZ>0IM<V=I9"`B0F%C:R!T;R!.;W1E<&%D(@IM<V=S='(@(M#?
M\_D@\_3G(.O?\_3A(.SE(/3I\B#SY^SEZ?[SY>GR(@H*(SH@=&5M<&QA=&5S
M+VYO=&5P861S+VYO=&5P861S+FEN8SHY-PHC+"!F=7IZ>0IM<V=I9"`B0F%C
M:R!T;R!.;W1E<&%D($]P=&EO;G,B"FUS9W-T<B`BT-_S^2#S].<@Z]_S].$@
M[.4@].GR(//G[.7I_O/EZ?(B"@HC.B!D871A+G!H<#HS,B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")#4U8B"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z-30@=&5M<&QA=&5S+W9I97<O;65M;RYI;F,Z,34*;7-G:60@
M(D-A=&5G;W)Y(@IM<V=S='(@(LKA].?C[_'?X2(*"B,Z('1E;7!L871E<R]N
M;W1E<&%D<R]N;W1E<&%D<RYI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D-H86YG
M92(*;7-G<W1R("+!ZOWQ^?/G(,'KZ^'C_NTB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!Y;W5R(&YO=&4@
M<V]R=&EN9R!A;F0@9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("+!Z^OAX]X@
M]._U(/3Q_/#O]2#TX>[I[?SLY_/G\B#JX>D@]/GM(.7PZ>OOX_[M(.7L]MSM
MZ?/G\BXB"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N
M:6YC.CDS"FUS9VED(")#:&]O<V4@=&AE(&UE;6\@8V%T96=O<FEE<R!T;R!L
M:7-T(&EN('1H92!S=6UM87)Y('9I97<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,@IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L
M="!.;W1E<&%D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z,S(*;7-G:60@(D-L96%R($9O<FTB"FUS9W-T<B`BRN'HX?'I
M\^S\\B#V_/'LX?(B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N
M:6YC.C$W('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.30*(SH@
M=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-@IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C,U
M"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,0HC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!.;W1E<&%D(@IM
M<V=S='(@(M#Q[^7PZ>OEX^S=[>\@ZO'I]-[QZ>\@].'NZ>W\[.?SY_(Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U"FUS9VED(")$969A=6QT('-O
M<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(M#Q[^7PZ>OEX^S=[>\@ZO'I]-[Q
MZ>\@].'NZ>W\[.?SY_(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V
M"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R("+0
M\>_E\.GKY>/LW>WG(.KA].7]Z/7M\^<@].'NZ>W\[.?SY_(Z(@H*(SH@=&5M
M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8SHY-2!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHR-0HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-`HC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(@IM<V=S='(@(L3IX>/QX?;>(-/G[.7?
M^?/G\B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C8W"FUS9VED(")$
M96QE=&4@=&AI<R!N;W1E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-0IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("+6Z-_M[_7S
MX2(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#4*(RP@
M9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N.B(*;7-G<W1R("+0Y?'IX_'A]MXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(D1I<W!L87D@
M3W!T:6]N<R(*;7-G<W1R("+%\.GK[^/=\B#%[/;<[>GSY_(B"@HC.B!T96UP
M;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O=FEE=R]M96UO+FEN
M8SHV,`IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES
M="]M96UO7W-U;6UA<FEE<RYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&ES="]M96UO
M7VAE861E<G,N:6YC.C0T(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HX,PIM<V=I
M9"`B161I="!.;W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VUE
M;6]?:&5A9&5R<RYI;F,Z-30*;7-G:60@(D5D:70@8V%T96=O<FEE<R!A;F0@
M8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VUE;6]?<W5M
M;6%R:65S+FEN8SHQ,@IM<V=I9"`B16UP='D@3F]T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS9VED(")%>'!O<G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS
M9VED(")%>'!O<G0@3F]T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")&7W5L;"!497AT
M(@IM<V=S='(@(M#KWO'G\B#*Y=_LY>WO(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!.;W1E
M<RP@4W1E<"`E9"(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.3,*;7-G:60@
M(DEM<&]R="]%>'!O<G0@3F]T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W9I97<O;65M;RYI;F,Z-#,*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-S(*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F($YO=&5S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4S"FUS9VED(")-
M96UO(%1E>'0B"FUS9W-T<B`BRN7?[.7M[R#3Y^SEZ?[SY?GM(@H*(SH@;65M
M;RYP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y:6YG("5S(@IM
M<V=S='(@(L7PY>[E\>/A\]_A(/3O]2`E<R(*"B,Z(&QI<W0N<&AP.C,U"FUS
M9VED(")->2!.;W1E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,C(*(RP@9G5Z>GD*;7-G:60@(DYE=R!.;W1E(@IM<V=S='(@(LW=
MX2#3Y^SEW_GSYR(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#`*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,C`V"FUS
M9VED(").;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M96YU+FEN8SHW"FUS9VED(").;R!N;W1E<&%D<R!A
M<F4@879A:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQI<W0O:&5A9&5R+FEN8SHS"B,L(&9U>GIY"FUS9VED(").;R!N;W1E
M<R(*;7-G<W1R("+*X>S?X2#SY^SEW_GSYR(*"B,Z('1E;7!L871E<R]L:7-T
M+V5M<'1Y+FEN8SHS"FUS9VED(").;R!N;W1E<R!M871C:"!T:&4@8W5R<F5N
M="!C<FET97)I82XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$P.0IM<V=I9"`B3F\@;F]T97,@=&\@9&ES<&QA>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&ES="]M96UO7VAE861E<G,N:6YC.C0V"FUS9VED
M(").;U]T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0*(RP@9G5Z>GD*;7-G:60@(DYO=&4@0V%T96=O<GDB"FUS9W-T<B`BRN'T
MY^/O\=_A(-/G[.7I_O/E^>TB"@HC.B!V:65W+G!H<#HX,"!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHY"B,L(&9U>GIY"FUS9VED(").;W1E($1E=&%I;',B
M"FUS9W-T<B`BR^7P]._LW?'EZ>7R(-/G[.7I_O/E^>TB"@HC.B!N;W1E<&%D
M<RYP:'`Z,3$P"FUS9VED(").;W1E($QI<W1S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PHC+"!F=7IZ>0IM<V=I9"`B3F]T92!4
M97AT(@IM<V=S='(@(LKEW^SE[>\@T^?LY>G^\^7Y[2(*"B,Z('1E;7!L871E
M<R]M96UO+VUE;6\N:6YC.C(V"B,L(&9U>GIY"FUS9VED(").;W1E(%]497AT
M(@IM<V=S='(@(LKEW^SE[>\@T^?LY>G^\^7Y[2(*"B,Z('9I97<N<&AP.C4W
M(&UE;6\N<&AP.C8P"FUS9VED(").;W1E(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE;6\O;65M;RYI;F,Z,S0*;7-G:60@(DYO=&5?
M<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]N;W1E<&%D<R]N;W1E<&%D
M<RYI;F,Z-SD*;7-G:60@(DYO=&5P860G<R!N86UE.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC.C8Q"FUS9VED(").
M;W1E<&%D<R(*;7-G<W1R("(B"@HC.B!N;W1E<&%D<RYP:'`Z,S,*;7-G:60@
M(DYO=&5P861S(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(").;W1E<R!3=6UM87)Y(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T
M<B`BP>OKY?(@Q?#IZ^_CW?(B"@HC.B!L:6(O87!I+G!H<#HQ.#,@;&EB+V%P
M:2YP:'`Z,C<T(&QI8B]A<&DN<&AP.C,T-2!L:6(O87!I+G!H<#HS-S0*;7-G
M:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]N;W1E<&%D<R]N;W1E<&%D<RYI;F,Z.#(*(RP@9G5Z>GD*;7-G:60@(E!E
M<FUI<W-I;VYS(@IM<V=S='(@(M#Q[_/Y\.GJ_"(*"B,Z('1E;7!L871E<R]L
M:7-T+VAE861E<BYI;F,Z-2!T96UP;&%T97,O;&ES="]H96%D97(N:6YC.C8*
M;7-G:60@(E)E9G)E<V@@3&ES="(*;7-G<W1R("+![>'MW?GSYR#+W_/TX?(B
M"@HC.B!T96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P
M-0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-A=&5G;W)Y(@IM<V=S='(@(LKA
M].?C[_'?X2#3Y^SEZ?[SY?GM(@H*(SH@=&5M<&QA=&5S+VYO=&5P861S+VYO
M=&5P861S+FEN8SHY-@IM<V=I9"`B4F5S970B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE;6\O;65M;RYI;F,Z-38*(RP@9G5Z>GD*;7-G:60@(E-A=F4B
M"FUS9W-T<B`BP?#OZ-[JY?7SYR#3Y^SEW_GSY_(B"@HC.B!S96%R8V@N<&AP
M.C$W('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHT('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHS,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(L'M
MX>;>].?SYR(*"B,Z(&QI<W0N<&AP.C4W"FUS9VED(")396%R8V@@4F5S=6QT
M<R(*;7-G<W1R("+!\._TY>O=\^SA].$@P>WAYM[TY_/G\B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B4V5A<F-H(%-C;W!E
M(@IM<V=S='(@(M#EY-_A(//TX2#O\._?X2#HX2#CW^WEZ2#A[>'FWO3G\^<B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z.0HC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H(%]497AT(@IM<V=S='(@(LKEW^SE[>\@\._U(.CA(.'M
MX>;G].?HY=\B"@HC.B!T96UP;&%T97,O;F]T97!A9',O;F]T97!A9',N:6YC
M.C8W"FUS9VED(")396QE8W0@82!N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M96YU+FEN8SHQ-@IM<V=I9"`B4V5L96-T(&YO=&5P861S('1O
M(&1I<W!L87DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,34*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-PIM<V=I
M9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0IM<V=I9"`B4V5L96-T('1H
M92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC.C$P.0IM<V=I
M9"`B4V5L96-T960@0V%T96=O<FEE<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C,X"FUS9VED(")3:&]W(&%C=&EO;B!B=71T;VYS
M/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*;7-G
M:60@(E-H;W<@;F]T97!A9"!N86UE/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z-#0*;7-G:60@(E-H;W<@;F]T97,@9G)O;2!T:&5S
M92!C871E9V]R:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L:7-T+VUE
M;6]?:&5A9&5R<RYI;F,Z-3`*;7-G:60@(E-O<G0@8GD@0V%T96=O<GDB"FUS
M9W-T<B`BU.'NZ>W\[.?SYR#JX?3<(,KA].?C[_'?X2(*"B,Z('1E;7!L871E
M<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-#8*(RP@9G5Z>GD*;7-G:60@(E-O
M<G0@8GD@3F]T92!497AT(@IM<V=S='(@(M3A[NGM_.SG\^<@ZN'TW"#*X?3G
MX^_QW^$B"@HC.B!M96UO+G!H<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('-A=F5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;65M
M;RYP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")4:&4@;F]T92!W87,@9&5L971E
M9"XB"FUS9W-T<B`BRN'LW^$@\^?LY=_Y\^<@Y.7M(.3IX>/QW/;GZN4N(@H*
M(SH@;F]T97!A9',N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!N
M;W1E<&%D(%PB)7-<(B!C;W5L9&XG="!B92!C<F5A=&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!N;W1E<&%D<RYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@
M(B(*"B,Z(&YO=&5P861S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@;F]T97!A9"!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@;F]T97!A9',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C(P,`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C,Y,PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@=DYO=&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@;65M;RYP
M:'`Z,34W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@<F5M;W9I;F<@=&AE(&YO=&4Z("5S(@IM<V=S='(@(M#A\>_U
M\^G<\_3GZN4@\/'\XNOG[.$@ZN'TW"#TY^T@Y.GAX_'A]MX@]/GM(//G[.7I
M_O/E^>TN(@H*(SH@;65M;RYP:'`Z,3,S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E
M<R(*;7-G<W1R("+0X?'O]?/IW//TY^KE(/#Q_.+KY^SA(.KA]-P@].?M(.3I
MX>/QX?;>(/3Y[2#SY^SEZ?[SY?GM+B(*"B,Z('9I97<N<&AP.C0V"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!V:65W:6YG('1H
M:7,@;F]T97!A9#H@)7,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E('=E<F4@;F\@;65M;W,@=&\@97AP;W)T+B(*
M;7-G<W1R("+'(//G[.7?^?/G(/#O]2#FY_3>Z.?JY2#DY>T@]?#<\??EZ2XB
M"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;F]T97!A9',N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65M;R]M96UO+FEN8SHU
M.`HC+"!F=7IZ>0IM<V=I9"`B56YD;R!C:&%N9V5S(@IM<V=S='(@(L'J_?'Y
M\^<@P>OKX>/^[2(*"B,Z('1E;7!L871E<R]V:65W+VUE;6\N:6YC.C$V('1E
M;7!L871E<R]L:7-T+VUE;6]?<W5M;6%R:65S+FEN8SHQ-`HC.B!L:6(O36YE
M;6\N<&AP.C(P-B!L:6(O36YE;6\N<&AP.C(P-R!L:6(O36YE;6\N<&AP.C(R
M,2!L:6(O36YE;6\N<&AP.C(R,@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,3`U"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(LSG(,KA].?C[_'I[_#OZ>?L
MW>WO(@H*(SH@;&EB+V%P:2YP:'`Z,C,V(&QI8B]A<&DN<&AP.C,P.2!L:6(O
M87!I+G!H<#HT,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@
M0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C(R"FUS9VED(")7:&EC:"!.;W1E<&%D('-H;W5L9"!T
M:&4@;F]T97,@8F4@861D960@=&\_(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C0R(&1A=&$N<&AP.C$R-2!M96UO+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@;F]T97,N(@IM<V=S='(@(B(*"B,Z('9I97<N<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AE(&YO=&5P860@)7,N(@IM<V=S='(@(B(*"B,Z(&YO=&5P861S+G!H
M<#HV-0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@;F]T97!A
M9"!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+0\=WPY>D@\/'^].$@[>$@Y?#I
MZ]WNY?3E(/3O]>O<]^GS]._M(.S?X2#SY^SEW_GSYRXB"@HC.B!T96UP;&%T
M97,O<')E9G,O;F]T97!A9'-E;&5C="YI;F,Z,3`*;7-G:60@(EEO=7(@9&5F
M875L="!N;W1E<&%D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;F]T97!A
M9',O;F]T97!A9',N:6YC.C8U"FUS9VED(")9;W5R(&YO=&5P861S.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR."!T96UP;&%T
M97,O=FEE=R]M96UO+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B7T)A8VL@=&\@
M3F]T97!A9"(*;7-G<W1R("+0W_/Y(//TYR#KW_/TX2#LY2#TZ?(@\^?LY>G^
M\^7I\B(*"B,Z('1E;7!L871E<R]M96UO+VUE;6\N:6YC.C4Q('1E;7!L871E
M<R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,Z-3`*(RP@9G5Z>GD*;7-G:60@(E]#
M871E9V]R>2(*;7-G<W1R("+*X?3GX^_QW^$B"@HC.B!T96UP;&%T97,O=FEE
M=R]M96UO+FEN8SHR-2!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHV-`HC+"!F
M=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R("+$Z>'C\>'VWB#3Y^SEW_GS
MY_(B"@HC.B!T96UP;&%T97,O=FEE=R]M96UO+FEN8SHR,2!T96UP;&%T97,O
M=FEE=R]M96UO+FEN8SHV,`IM<V=I9"`B7T5D:70B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"FUS9VED(")?1FER<W0@
M3&EN92(*;7-G<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP.C(X,0IM<V=I9"`B
M7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUN96UO+G!H<#HR
M-C0*(RP@9G5Z>GD*;7-G:60@(E],:7-T($YO=&5S(@IM<V=S='(@(LO?\_3A
M(-/G[.7I_O/E^>TB"@HC.B!L:6(O36YE;6\N<&AP.C(W-@IM<V=I9"`B7TUY
M($YO=&5P861S(@IM<V=S='(@(B(*"B,Z(&QI8B]-;F5M;RYP:'`Z,C8Y"FUS
M9VED(")?3F5W($YO=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TUN96UO+G!H<#HR
M.#8*;7-G:60@(E]0<FEN="(*;7-G<W1R("(B"@HC.B!L:6(O36YE;6\N<&AP
M.C(W,@HC+"!F=7IZ>0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R("+![>'FWO3G
M\^<B"@HC.B!D871A+G!H<#HY,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$*;7-G:60@(FYO=&5S+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS
M,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$X"FUS9VED(")V3F]T92(*
M;7-G<W1R("(B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQI8B\`````````````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-#8`,#$V,S`W`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE
M;6\O;&EB+T1R:79E<B\`````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-@`P,3<U-#(`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]M;F5M;R]L:6(O1')I=F5R+VMO;&%B+G!H<```````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,S$W`#$P-#$W,S8R-S0V
M`#`R,3,T-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]+;VQA8BYP:'`G.PH*
M+RHJ"B`J($AO<F1E($UN96UO(&1R:79E<B!F;W(@=&AE($MO;&%B($E-05`@
M<V5R=F5R+@H@*@H@*B`D2&]R9&4Z(&UN96UO+VQI8B]$<FEV97(O:V]L86(N
M<&AP+'8@,2XW+C(N-R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`V(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($AO<F1E(%!R;VIE8W0@*&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*("H*("H@0&%U=&AO<B`@
M4W1U87)T($)I;F=E(#QO;6EC<F]N0&UI9VAT>2YC;RYZ83X*("H@0'-I;F-E
M("`@36YE;6\@,BXP"B`J($!P86-K86=E($UN96UO"B`J+PIC;&%S<R!-;F5M
M;U]$<FEV97)?:V]L86(@97AT96YD<R!-;F5M;U]$<FEV97(@>PH*("`@("\J
M*@H@("`@("H@2&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<R`H;F]T('5S960I+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($]U<B!+;VQA8B!S97)V97(@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`
M=F%R($MO;&%B"B`@("`@*B\*("`@('9A<B`D7VMO;&%B(#T@;G5L;#L*"B`@
M("!F=6YC=&EO;B!-;F5M;U]$<FEV97)?:V]L86(H)&YO=&5P860L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F]T97!A9"`]
M("1N;W1E<&%D.PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*
M("`@('T*"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?:V]L86(I*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]K;VQA8B`](&YE
M=R!+;VQA8B@I.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]K;VQA8BT^;W!E
M;B@D=&AI<RT^7VYO=&5P860I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]D:7-C
M;VYN96-T*"D*("`@('L*("`@("`@("`D=&AI<RT^7VMO;&%B+3YC;&]S92@I
M.PH@("`@("`@("1T:&ES+3Y?:V]L86(@/2!N=6QL.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]B=6EL9$YO=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A
M>2@*("`@("`@("`@("`@)VUE;6]L:7-T7VED)R`]/B`D=&AI<RT^7VYO=&5P
M860L"B`@("`@("`@("`@("=M96UO7VED)R`]/B`D=&AI<RT^7VMO;&%B+3YG
M9715240H*2P*("`@("`@("`@("`@)W5I9"<@/3X@)'1H:7,M/E]K;VQA8BT^
M9V5T54E$*"DL"B`@("`@("`@("`@("=D97-C)R`]/B`D=&AI<RT^7VMO;&%B
M+3YG9713='(H)W-U;6UA<GDG*2P*("`@("`@("`@("`@)V)O9'DG(#T^("1T
M:&ES+3Y?:V]L86(M/F=E=%-T<B@G8F]D>2<I+`H@("`@("`@("`@("`G8V%T
M96=O<GDG(#T^("1T:&ES+3Y?:V]L86(M/F=E=%-T<B@G8V%T96=O<FEE<R<I
M+`H@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!O
M;F4@;F]T92!F<F]M('1H92!S=&]R92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N;W1E260@(%1H92!)1"!O9B!T:&4@;F]T92!T;R!R971R:65V
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@87)R87D@;V8@
M;F]T92!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)&YO
M=&5)9"D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T
M*"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7VMO;&%B+3YL;V%D3V)J96-T*"1N;W1E
M260I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]B=6EL9$YO=&4H*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E=')I979E(&]N92!N;W1E(&)Y(%5)1"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U:60@(%1H92!5240@;V8@=&AE(&YO=&4@
M=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&%R<F%Y(&]F(&YO=&4@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T0GE5240H)'5I9"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G3F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]S971/8FIE8W0H)&1E<V,L("1B;V1Y+"`D8V%T96=O<GD@/2`G)RP@
M)'5I9"`](&YU;&PI"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)'5I9"DI('L*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?:V]L86(M/FQO861/8FIE8W0H)'5I9"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'5I9"`](&UD-2AU;FEQ:60H;71?
M<F%N9"@I+"!T<G5E*2D["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7VMO;&%B+3YN97=/8FIE8W0H)'5I9"D["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VMO
M;&%B+3YS9713='(H)W-U;6UA<GDG+"`D9&5S8RD["B`@("`@("`@)'1H:7,M
M/E]K;VQA8BT^<V5T4W1R*"=B;V1Y)RP@)&)O9'DI.PH@("`@("`@("1T:&ES
M+3Y?:V]L86(M/G-E=%-T<B@G8V%T96=O<FEE<R<L("1C871E9V]R>2D["@H@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VMO;&%B+3YS879E3V)J96-T*"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=6ED.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@;F]T
M92!T;R!T:&4@8F%C:V5N9"!S=&]R86=E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&1E<V,@("`@("!4:&4@9&5S8W)I<'1I;VX@*&QO;F<I(&]F
M('1H92!N;W1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]D>2`@("`@(%1H
M92!D97-C<FEP=&EO;B`H;&]N9RD@;V8@=&AE(&YO=&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C871E9V]R>2`@5&AE(&-A=&5G;W)Y(&]F('1H92!N;W1E
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;65R:6,@
M240@;V8@=&AE(&YE=R!N;W1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H
M)&1E<V,L("1B;V1Y+"`D8V%T96=O<GD@/2`G)RD*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]S971/8FIE8W0H)&1E<V,L("1B;V1Y+"`D8V%T96=O
M<GDI.PH@("`@?0H*("`@("\J*@H@("`@("H@36]D:69Y(&%N(&5X:7-T:6YG
M(&YO=&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&YO=&5)9"`@
M(%1H92!N;W1E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!S=')I;F<@)&1E
M<V,@("`@("!4:&4@9&5S8W)I<'1I;VX@*&QO;F<I(&]F('1H92!N;W1E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8F]D>2`@("`@(%1H92!D97-C<FEP=&EO
M;B`H;&]N9RD@;V8@=&AE(&YO=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M871E9V]R>2`@5&AE(&-A=&5G;W)Y(&]F('1H92!N;W1E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!M;V1I9GDH)&YO=&5)9"P@)&1E<V,L("1B;V1Y+"`D8V%T
M96=O<GD@/2`G)RD*("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]S
M971/8FIE8W0H)&1E<V,L("1B;V1Y+"`D8V%T96=O<GDL("1N;W1E260I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E<W5L="`]/2`D;F]T94ED.PH@("`@?0H*("`@("\J*@H@("`@
M("H@36]V92!A(&YO=&4@=&\@82!N97<@;F]T97!A9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N;W1E260@("`@("!4:&4@;F]T92!T;R!M;W9E
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W3F]T97!A9"`@5&AE(&YE=R!N
M;W1E<&%D+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E*"1N;W1E260L("1N
M97=.;W1E<&%D*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-O
M;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:V]L86(M/FUO=F5/8FIE8W0H)&YO
M=&5)9"P@)&YE=TYO=&5P860I.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E;&5T
M92@D;F]T94ED*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-O
M;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:V]L86(M/G)E;6]V94]B:F5C=',H
M)&YO=&5)9"D["B`@("!]"@H@("`@9G5N8W1I;VX@9&5L971E06QL*"D*("`@
M('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7VMO;&%B+3YR96UO=F5!;&Q/8FIE8W1S*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971R:65V97,@86QL(&]F('1H92!N;W1E<R!F<F]M
M("1T:&ES+3Y?;F]T97!A9"!F<F]M('1H92!D871A8F%S92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5T<FEE=F4H
M*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-O;FYE8W0H*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]M96UO<R`](&%R<F%Y*"D["@H@("`@("`@("1M<V=?;&ES="`]
M("1T:&ES+3Y?:V]L86(M/FQI<W1/8FIE8W1S*"D["B`@("`@("`@:68@*&ES
M7V$H)&US9U]L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D;7-G7VQI<W0["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH
M)&US9U]L:7-T*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1M<V=?;&ES="!A<R`D;7-G*2!["B`@
M("`@("`@("`@("1X;6P@/2`F)'1H:7,M/E]K;VQA8BT^;&]A9$]B:F5C="@D
M;7-G+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)'AM;"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1X;6P["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?;65M;W-;)'1H:7,M/E]K
M;VQA8BT^9V5T54E$*"E=(#T@)'1H:7,M/E]B=6EL9$YO=&4H)'AM;"D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VUN96UO+VQI8B]$<FEV97(O<W%L+G!H<```````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S8P-S0`,3`T,3<S-C(W-#8`,#(Q
M,#8Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!-;F5M;R!S=&]R86=E(&EM<&QE;65N=&%T:6]N(&9O
M<B!02%`G<R!014%2(&1A=&%B87-E(&%B<W1R86-T:6]N"B`J(&QA>65R+@H@
M*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@("`@)W!H<'1Y
M<&4G("`@("`@(%1H92!D871A8F%S92!T>7!E("AE+F<N("=P9W-Q;"<L("=M
M>7-Q;"<L(&5T8RXI+@H@*B`@("`@("=C:&%R<V5T)R`@("`@("!4:&4@9&%T
M86)A<V4G<R!I;G1E<FYA;"!C:&%R<V5T+CPO<')E/@H@*@H@*B!/<'1I;VYA
M;"!V86QU97,Z/'!R93X*("H@("`@("`G=&%B;&4G("`@("`@("`@5&AE(&YA
M;64@;V8@=&AE(&UE;6]S('1A8FQE(&EN("=D871A8F%S92<N($1E9F%U;'1S
M"B`J("`@("`@("`@("`@("`@("`@("`@('1O("=M;F5M;U]M96UO<R<\+W!R
M93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A
M=&EO;G,Z/'!R93X*("H@("`@("`G:&]S='-P96,G("`@("`@5&AE(&AO<W1N
M86UE(&]F('1H92!D871A8F%S92!S97)V97(N"B`J("`@("`@)W!R;W1O8V]L
M)R`@("`@(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N
M:7@G+"!E=&,N*2X*("H@("`@("`G9&%T86)A<V4G("`@("`@5&AE(&YA;64@
M;V8@=&AE(&1A=&%B87-E+@H@*B`@("`@("=U<V5R;F%M92<@("`@("!4:&4@
M=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S
M92X*("H@("`@("`G<&%S<W=O<F0G("`@("`@5&AE('!A<W-W;W)D(&%S<V]C
M:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("`@("=O<'1I;VYS)R`@("`@
M("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T86)A<V4N
M"B`J("`@("`@)W1T>2<@("`@("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W!O<G0G("`@("`@
M("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B
M87-E+CPO<')E/@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&ES(&1E9FEN
M960@:6X@<V-R:7!T<R]D<FEV97)S+VUN96UO7VUE;6]S+G-Q;"X*("H*("H@
M)$AO<F1E.B!M;F5M;R]L:6(O1')I=F5R+W-Q;"YP:'`L=B`Q+C(X+C(N,3(@
M,C`P-B\P,2\Q."`Q.3HT-SHR-R!B96X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#$M,C`P-B!(;W)D92!0<F]J96-T("AH='1P.B\O=W=W+FAO<F1E+F]R
M9R\I"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI
M8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!-;F5M;R`Q+C`*("H@
M0'!A8VMA9V4@36YE;6\*("HO"F-L87-S($UN96UO7T1R:79E<E]S<6P@97AT
M96YD<R!-;F5M;U]$<FEV97(@>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B
M87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO
M"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J($%R92!W92!C;VYN96-T
M960@=&\@=&AE(%-13"!S97)V97(_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L
M96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T(&$@;F5W(%-13"!S=&]R86=E(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N;W1E<&%D("`@5&AE
M(&YA;64@;V8@=&AE(&YO=&5P860@=&\@;&]A9"]S879E(&YO=&5S(&9R;VTN
M"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@("`@02!H87-H(&-O;G1A
M:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!-;F5M;U]$<FEV97)?<W%L*"1N;W1E<&%D+"`D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7VYO=&5P860@/2`D;F]T97!A
M9#L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971R:65V92!O;F4@;F]T92!F<F]M('1H92!D871A
M8F%S92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N;W1E260@(%1H
M92!)1"!O9B!T:&4@;F]T92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@87)R87D@;V8@;F]T92!A='1R:6)U=&5S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G970H)&YO=&5)9"D*("`@('L*("`@("`@
M("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE
M8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@
M("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@
M)U-%3$5#5"`J($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*
M("`@("`@("`@("`@("`@("`G(%=(15)%(&UE;6]?;W=N97(@/2`_($%.1"!M
M96UO7VED(#T@/R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?
M;F]T97!A9"P@)&YO=&5)9"D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@
M870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H<W!R:6YT9B@G36YE;6]?1')I=F5R7W-Q;#HZ9V5T*"DZ("5S)RP@
M)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T
M92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M
M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<F]W(#T@)')E<W5L="T^9F5T
M8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("!I9B`H:7-?82@D
M<F]W+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F]W
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8G5I;&1.;W1E
M*"1R;W<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@;VYE(&YO
M=&4@9G)O;2!T:&4@9&%T86)A<V4@8GD@54E$+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5I9"`@5&AE(%5)1"!O9B!T:&4@;F]T92!T;R!R971R
M:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@87)R87D@
M;V8@;F]T92!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971"
M>55)1"@D=6ED*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E
M(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI
M<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R
M>2X@*B\*("`@("`@("`D<75E<GD@/2`G4T5,14-4("H@1E)/32`G("X@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%
M4D4@;65M;U]U:60@/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH)'5I
M9"D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@
M;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G
M36YE;6]?1')I=F5R7W-Q;#HZ9V5T0GE5240H*3H@)7,G+"`D<75E<GDI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R
M>2X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U
M97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%
M5$-(34]$15]!4U-/0RD["B`@("`@("`@:68@*&ES7V$H)')O=RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')O=SL*("`@("`@("!]
M"@H@("`@("`@("\J($1E8V]D92!A;F0@<F5T=7)N('1H92!T87-K+B`J+PH@
M("`@("`@("1T:&ES+3Y?;F]T97!A9"`]("1R;W=;)VUE;6]?;W=N97(G73L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]B=6EL9$YO=&4H)')O=RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&0@82!N;W1E('1O('1H92!B86-K96YD('-T
M;W)A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S8R`@("`@
M(%1H92!F:7)S="!L:6YE(&]F('1H92!N;W1E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8F]D>2`@("`@(%1H92!W:&]L92!N;W1E(&)O9'DN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C871E9V]R>2`@5&AE(&-A=&5G;W)Y(&]F('1H92!N
M;W1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=6ED("`@("`@($$@56YI<75E
M($ED96YT:69I97(@9F]R('1H92!N;W1E+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@=6YI<75E($E$(&]F('1H92!N97<@;F]T92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D*"1D97-C+"`D8F]D>2P@)&-A=&5G;W)Y
M(#T@)R<L("1U:60@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R
M92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@
M("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@)&YO=&5)9"`](&UD
M-2AU;FEQ:60H;71?<F%N9"@I+"!T<G5E*2D["B`@("`@("`@:68@*&ES7VYU
M;&PH)'5I9"DI('L*("`@("`@("`@("`@)'5I9"`]("1T:&ES+3YG96YE<F%T
M955)1"@I.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@)TE.4T525"!)
M3E1/("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@
M("`@("`@)R`H;65M;U]O=VYE<BP@;65M;U]I9"P@;65M;U]D97-C+"!M96UO
M7V)O9'DL(&UE;6]?8V%T96=O<GDL(&UE;6]?=6ED*2<@+@H@("`@("`@("`@
M("`@("`@("<@5D%,5453("@_+"`_+"`_+"`_+"`_+"`_*2<["B`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?;F]T97!A9"P*("`@("`@("`@("`@
M("`@("`@("`@("`@)&YO=&5)9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&5S8RP@3DQ3.CIG971#:&%R<V5T
M*"DL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1B;V1Y+"!.3%,Z
M.F=E=$-H87)S970H*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72DL"B`@
M("`@("`@("`@("`@("`@("`@("`@(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M)&-A=&5G;W)Y+"!.3%,Z.F=E=$-H87)S970H*2P@)'1H:7,M/E]P87)A;7-;
M)V-H87)S970G72DL"B`@("`@("`@("`@("`@("`@("`@("`@(%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)'5I9"P@3DQ3.CIG971#:&%R<V5T*"DL("1T:&ES
M+3Y?<&%R86US6R=C:&%R<V5T)UTI*3L*"B`@("`@("`@+RH@3&]G('1H92!Q
M=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92AS<')I;G1F*"=-;F5M;U]$<FEV97)?<W%L.CIA9&0H*3H@
M)7,G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!!
M='1E;7!T('1H92!I;G-E<G1I;VX@<75E<GDN("HO"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@
M("`@("\J(%)E='5R;B!A;B!E<G)O<B!I;6UE9&EA=&5L>2!I9B!T:&4@<75E
M<GD@9F%I;&5D+B`J+PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E
M<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J
M($QO9R!T:&4@8W)E871I;VX@;V8@=&AI<R!I=&5M(&EN('1H92!H:7-T;W)Y
M(&QO9RX@*B\*("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS
M:6YG;&5T;VXH*3L*("`@("`@("`D:&ES=&]R>2T^;&]G*"=M;F5M;SHG("X@
M)'1H:7,M/E]N;W1E<&%D("X@)SHG("X@)'5I9"P@87)R87DH)V%C=&EO;B<@
M/3X@)V%D9"<I+"!T<G5E*3L*"B`@("`@("`@<F5T=7)N("1N;W1E260["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-;V1I9GD@86X@97AI<W1I;F<@;F]T92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N;W1E260@("`@5&AE(&YO
M=&4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S8R`@("`@
M(%1H92!D97-C<FEP=&EO;B`H;&]N9RD@;V8@=&AE(&YO=&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1B;V1Y("`@("`@5&AE(&1E<V-R:7!T:6]N("AL;VYG
M*2!O9B!T:&4@;F]T92X*("`@("`J($!P87)A;2!S=')I;F<@)&-A=&5G;W)Y
M("!4:&4@8V%T96=O<GD@;V8@=&AE(&YO=&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UO9&EF>2@D;F]T94ED+"`D9&5S8RP@)&)O9'DL("1C871E9V]R>2`]
M(&YU;&PI"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V
M86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?
M8V]N;F5C="@I.PH*("`@("`@("`D<75E<GD@(#T@)U501$%412`G("X@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`G(%-%
M5"!M96UO7V1E<V,@/2`_+"!M96UO7V)O9'D@/2`_)SL*("`@("`@("`D=F%L
M=65S(#T@87)R87DH4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&5S8RP@3DQ3
M.CIG971#:&%R<V5T*"DL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI+`H@
M("`@("`@("`@("`@("`@("`@("`@("!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T
M*"1B;V1Y+"!.3%,Z.F=E=$-H87)S970H*2P@)'1H:7,M/E]P87)A;7-;)V-H
M87)S970G72DI.PH*("`@("`@("`O+R!$;VXG="!C:&%N9V4@=&AE(&-A=&5G
M;W)Y(&EF(&ET(&ES;B=T('!R;W9I9&5D+@H@("`@("`@(&EF("@A:7-?;G5L
M;"@D8V%T96=O<GDI*2!["B`@("`@("`@("`@("1Q=65R>2`N/2`G+"!M96UO
M7V-A=&5G;W)Y(#T@/R<["B`@("`@("`@("`@("1V86QU97-;72`](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)&-A=&5G;W)Y+"!.3%,Z.F=E=$-H87)S970H
M*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("`@("`@?0H@("`@
M("`@("1Q=65R>2`N/2`G(%=(15)%(&UE;6]?;W=N97(@/2`_($%.1"!M96UO
M7VED(#T@/R<["B`@("`@("`@87)R87E?<'5S:"@D=F%L=65S+"`D=&AI<RT^
M7VYO=&5P860L("1N;W1E260I.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y
M(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*'-P<FEN=&8H)TUN96UO7T1R:79E<E]S<6PZ.FUO9&EF>2@I.B`E
M<R<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($%T
M=&5M<'0@=&AE('5P9&%T92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*"B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]G('1H92!M;V1I9FEC871I;VX@
M;V8@=&AI<R!I=&5M(&EN('1H92!H:7-T;W)Y(&QO9RX@*B\*("`@("`@("`D
M;F]T92`]("1T:&ES+3YG970H)&YO=&5)9"D["B`@("`@("`@:68@*"%E;7!T
M>2@D;F]T95LG=6ED)UTI*2!["B`@("`@("`@("`@("1H:7-T;W)Y(#T@)DAO
M<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@("`@("`@("`D:&ES=&]R
M>2T^;&]G*"=M;F5M;SHG("X@)'1H:7,M/E]N;W1E<&%D("X@)SHG("X@)&YO
M=&5;)W5I9"==+"!A<G)A>2@G86-T:6]N)R`]/B`G;6]D:69Y)RDL('1R=64I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!-;W9E(&$@;F]T92!T;R!A(&YE=R!N;W1E<&%D+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YO=&5)9"`@("`@(%1H92!N;W1E
M('1O(&UO=F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=.;W1E<&%D("!4
M:&4@;F5W(&YO=&5P860N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F4H)&YO
M=&5)9"P@)&YE=TYO=&5P860I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E
M('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@
M("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D<75E<GD@/2`G55!$
M051%("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@
M("`@("`@)R!3150@;65M;U]O=VYE<B`](#\G("X*("`@("`@("`@("`@("`@
M("`G(%=(15)%(&UE;6]?;W=N97(@/2`_($%.1"!M96UO7VED(#T@/R<["B`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"1N97=.;W1E<&%D+"`D=&AI<RT^7VYO
M=&5P860L("1N;W1E260I.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T
M(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*'-P<FEN=&8H)TUN96UO7T1R:79E<E]S<6PZ.FUO=F4H*3H@)7,G+"`D
M<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!!='1E;7!T
M('1H92!M;W9E('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&1E;&5T92@D;F]T94ED*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`O*B!'970@=&AE(&YO=&4G<R!D971A:6QS(&9O<B!U
M<V4@;&%T97(N("HO"B`@("`@("`@)&YO=&4@/2`D=&AI<RT^9V5T*"1N;W1E
M260I.PH*("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%=(15)%
M(&UE;6]?;W=N97(@/2`_($%.1"!M96UO7VED(#T@/R<["B`@("`@("`@)'9A
M;'5E<R`](&%R<F%Y*"1T:&ES+3Y?;F]T97!A9"P@)&YO=&5)9"D["@H@("`@
M("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO
M"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G36YE;6]?1')I
M=F5R7W-Q;#HZ9&5L971E*"DZ("5S)RP@)'%U97)Y*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*"B`@("`@("`@+RH@071T96UP="!T:&4@9&5L971E('%U97)Y+B`J
M+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL
M("1V86QU97,I.PH*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U
M;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,
M;V<@=&AE(&1E;&5T:6]N(&]F('1H:7,@:71E;2!I;B!T:&4@:&ES=&]R>2!L
M;V<N("HO"B`@("`@("`@:68@*"%E;7!T>2@D;F]T95LG=6ED)UTI*2!["B`@
M("`@("`@("`@("1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O
M;B@I.PH@("`@("`@("`@("`D:&ES=&]R>2T^;&]G*"=M;F5M;SHG("X@)'1H
M:7,M/E]N;W1E<&%D("X@)SHG("X@)&YO=&5;)W5I9"==+"!A<G)A>2@G86-T
M:6]N)R`]/B`G9&5L971E)RDL('1R=64I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@9&5L971E06QL*"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@)'%U
M97)Y(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!M96UO7V]W;F5R(#T@/R<[
M"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?;F]T97!A9"D["@H@
M("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN
M("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G36YE;6]?
M1')I=F5R7W-Q;#HZ9&5L971E06QL*"DZ("5S)RP@)'%U97)Y*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@071T96UP="!T:&4@9&5L971E('%U
M97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D
M<75E<GDL("1V86QU97,I.PH*("`@("`@("!R971U<FX@:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I(#\@)')E<W5L="`Z('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971R:65V97,@86QL(&]F('1H92!N;W1E<R!F<F]M("1T
M:&ES+3Y?;F]T97!A9"!F<F]M('1H90H@("`@("H@9&%T86)A<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!014%2
M7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I
M979E*"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A
M;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C
M;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO
M"B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"`J($923TT@)R`N("1T:&ES+3Y?
M<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%=(15)%(&UE
M;6]?;W=N97(@/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M
M/E]N;W1E<&%D*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%
M0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS
M<')I;G1F*"=-;F5M;U]$<FEV97)?<W%L.CIR971R:65V92@I.B`E<R<L("1Q
M=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@
M=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("!I9B`H(6ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D<F]W(#T@)')E
M<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')O=RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R;W<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J(%-T;W)E('1H92!R971R:65V960@=F%L=65S(&EN(&$@9G)E<V@@)&UE
M;6]S(&QI<W0N("HO"B`@("`@("`@("`@("1T:&ES+3Y?;65M;W,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!W:&EL92`H)')O=R`F)B`A:7-?82@D<F]W+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`O*B!!9&0@=&AI<R!N
M97<@;65M;R!T;R!T:&4@)&UE;6]S(&QI<W0N("HO"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VUE;6]S6R1R;W=;)VUE;6]?:60G75T@/2`D=&AI<RT^7V)U
M:6QD3F]T92@D<F]W*3L*"B`@("`@("`@("`@("`@("`O*B!!9'9A;F-E('1O
M('1H92!N97<@<F]W(&EN('1H92!R97-U;'0@<V5T+B`J+PH@("`@("`@("`@
M("`@("`@)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!
M4U-/0RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L="T^9G)E
M92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@<&5R<VES=&5N="!C
M;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S.R!E>&ET<R`H2&]R9&4Z
M.F9A=&%L*"DI(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N
M;F5C="@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V-O;FYE8W1E9"D@
M>PH@("`@("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1T:&ES
M+3Y?<&%R86US+"`G<W1O<F%G92<L"B`@("`@("`@("`@("`@("!A<G)A>2@G
M<&AP='EP92<L("=C:&%R<V5T)RDI.PH*("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;64G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@)R<[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72`]("=M;F5M;U]M96UO<R<["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V97(@
M=7-I;F<@=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]D
M8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES=&5N="<@
M/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@($AO<F1E.CIF871A;"@D=&AI<RT^7V1B+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!3970@1$(@<&]R=&%B:6QI='D@;W!T:6]N<RX*("`@("`@("`@("`@
M<W=I=&-H("@D=&AI<RT^7V1B+3YP:'!T>7!E*2!["B`@("`@("`@("`@(&-A
M<V4@)VUS<W%L)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P
M=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@
M?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))
M32D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R
M=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)4
M04))3$E465]%4E)/4E,I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!?8G5I;&1.;W1E*"1R
M;W<I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E(&YO=&5S(&%L=V%Y<R!H
M879E(&$@54E$+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<F]W6R=M96UO7W5I
M9"==*2D@>PH@("`@("`@("`@("`D<F]W6R=M96UO7W5I9"==(#T@)'1H:7,M
M/F=E;F5R871E54E$*"D["@H@("`@("`@("`@("`D<75E<GD@/2`G55!$051%
M("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@
M("`G(%-%5"!M96UO7W5I9"`](#\G("X*("`@("`@("`@("`@("`@("<@5TA%
M4D4@;65M;U]O=VYE<B`](#\@04Y$(&UE;6]?:60@/2`_)SL*("`@("`@("`@
M("`@)'9A;'5E<R`](&%R<F%Y*"1R;W=;)VUE;6]?=6ED)UTL("1R;W=;)VUE
M;6]?;W=N97(G72P@)')O=ULG;65M;U]I9"==*3L*"B`@("`@("`@("`@("\J
M($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)TUN96UO7T1R:79E
M<E]S<6P@861D:6YG(&UI<W-I;F<@54E$.B`E<R<L("1Q=65R>2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=65R
M>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E
M871E(&$@;F5W('1A<VL@8F%S960@;VX@)')O=R=S('9A;'5E<RX@*B\*("`@
M("`@("!R971U<FX@87)R87DH)VUE;6]L:7-T7VED)R`]/B`D<F]W6R=M96UO
M7V]W;F5R)UTL"B`@("`@("`@("`@("`@("`@("`@("=M96UO7VED)R`]/B`D
M<F]W6R=M96UO7VED)UTL"B`@("`@("`@("`@("`@("`@("`@("=U:60G(#T^
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)')O=ULG;65M;U]U:60G72P@)'1H
M:7,M/E]P87)A;7-;)V-H87)S970G72DL"B`@("`@("`@("`@("`@("`@("`@
M("=D97-C)R`]/B!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1R;W=;)VUE;6]?
M9&5S8R==+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*2P*("`@("`@("`@
M("`@("`@("`@("`@)V)O9'DG(#T^(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M)')O=ULG;65M;U]B;V1Y)UTL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`G8V%T96=O<GDG(#T^(%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)')O=ULG;65M;U]C871E9V]R>2==+"`D=&AI<RT^
M7W!A<F%M<ULG8VAA<G-E="==*2D["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]M;F5M;R]L:6(O0FQO8VLO````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0V
M`#`Q-S,T,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VQI8B]";&]C
M:R]S=6UM87)Y+G!H<```````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3`V-30`,3`T,3<S-C(W-#8`,#(Q-34R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HD8FQO8VM?;F%M92`](%\H
M(DYO=&5S(%-U;6UA<GDB*3L*"B\J*@H@*B!);7!L96UE;G1A=&EO;B!O9B!(
M;W)D95]";&]C:R!A<&D@=&\@<VAO=R!N;W1E<R!S=6UM87)Y+@H@*@H@*B`D
M2&]R9&4Z(&UN96UO+VQI8B]";&]C:R]S=6UM87)Y+G!H<"QV(#$N,C(N."XV
M(#(P,#8O,#(O,#@@,30Z-#,Z-#<@:F%N($5X<"`D"B`J"B`J($!P86-K86=E
M($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U]-;F5M;U]S=6UM
M87)Y(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=M
M;F5M;R<["@H@("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH@("`@("`@(')E='5R;B!(;W)D93HZ;&EN:RA(
M;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T26YI=&EA;%!A9V4H*2P@=')U92DI
M("X*("`@("`@("`@("`@)')E9VES=')Y+3YG970H)VYA;64G*2`N("<\+V$^
M(#QS;6%L;#XG("X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=M96UO+G!H<#]A8W1I;VY)1#UA9&1?;65M;R<L('1R
M=64I*2`N"B`@("`@("`@("`@($AO<F1E.CII;6<H)VUN96UO+G!N9R<L(%\H
M(DYE=R!.;W1E(BDI("X@)R`G("X@7R@B3F5W($YO=&4B*2`N"B`@("`@("`@
M("`@("<\+V$^/"]S;6%L;#XG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P87)A
M;7,H*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXO8F%S92YP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<"<["B`@("`@("`@)&--
M86YA9V5R(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G97(H*3L*("`@("`@
M("`D8V%T96=O<FEE<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&--
M86YA9V5R+3YG970H*2!A<R`D8RD@>PH@("`@("`@("`@("`D8V%T96=O<FEE
M<ULD8UT@/2`D8SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@G
M<VAO=U]A8W1I;VYS)R`]/B!A<G)A>2@G='EP92<@/3X@)V-H96-K8F]X)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VYA;64G(#T^(%\H(E-H;W<@86-T:6]N(&)U='1O;G,_(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT
M)R`]/B`Q*2P*("`@("`@("`@("`@("`@("`@("`@)W-H;W=?;F]T97!A9"<@
M/3X@87)R87DH)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")3
M:&]W(&YO=&5P860@;F%M93\B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^(#$I+`H@("`@("`@
M("`@("`@("`@("`@("`G<VAO=U]C871E9V]R:65S)R`]/B!A<G)A>2@G='EP
M92<@/3X@)VUU;'1I96YU;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")3:&]W(&YO=&5S
M(&9R;VT@=&AE<V4@8V%T96=O<FEE<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@87)R
M87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W9A;'5E<R<@/3X@)&-A=&5G;W)I97,I"B`@("`@("`@("`@
M("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@
M("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO
M8F%S92YP:'`G.PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<"<[
M"B`@("`@("`@)&--86YA9V5R(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G
M97(H*3L*("`@("`@("`D8V]L;W)S(#T@)&--86YA9V5R+3YC;VQO<G,H*3L*
M("`@("`@("`D9F=C;VQO<G,@/2`D8TUA;F%G97(M/F9G0V]L;W)S*"D["@H@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W-H;W=?;F]T97!A
M9"==*2D@>PH@("`@("`@("`@("`D<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS
M:6YG;&5T;VXH)VUN96UO)RD["B`@("`@("`@?0H*("`@("`@("`D:'1M;"`]
M("<G.PH@("`@("`@("1M96UO<R`]($UN96UO.CIL:7-T365M;W,H)'!R969S
M+3YG971686QU92@G<V]R=&)Y)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<')E9G,M/F=E=%9A;'5E*"=S;W)T9&ER)RDI.PH@("`@
M("`@(&9O<F5A8V@@*"1M96UO<R!A<R`D:60@/3X@)&UE;6\I('L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<VAO=U]C871E9V]R
M:65S)UTI("8F"B`@("`@("`@("`@("`@("`A:6Y?87)R87DH)&UE;6];)V-A
M=&5G;W)Y)UTL("1T:&ES+3Y?<&%R86US6R=S:&]W7V-A=&5G;W)I97,G72DI
M('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D:'1M;"`N/2`G/'1R/B<["@H@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=S:&]W7V%C=&EO;G,G72DI('L*("`@
M("`@("`@("`@("`@("1E9&ET=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=M
M96UO+G!H<"<L(&%R<F%Y*"=M96UO)R`]/B`D;65M;ULG;65M;U]I9"==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VUE;6]L:7-T)R`]/B`D;65M;ULG;65M;VQI
M<W1?:60G72DI.PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!W:61T
M:#TB,24B/B<@+B!(;W)D93HZ;&EN:RAH=&UL<W!E8VEA;&-H87)S*$AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"A5=&EL.CIA9&1087)A;65T97(H)&5D:71U<FPL
M("=A8W1I;VY)1"<L("=M;V1I9GE?;65M;R<I+"!T<G5E*2DL(%\H(D5D:70@
M3F]T92(I*2`N($AO<F1E.CII;6<H)V5D:70N<&YG)RP@7R@B161I="!.;W1E
M(BDL("<G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO
M<F1E)RDI("X@)SPO83X\+W1D/B<["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W-H;W=?;F]T97!A9"==
M*2D@>PH@("`@("`@("`@("`@("`@)&]W;F5R(#T@)&UE;6];)VUE;6]L:7-T
M7VED)UT["B`@("`@("`@("`@("`@("`D<VAA<F4@/2`D<VAA<F5S+3YG9713
M:&%R92@D;W=N97(I.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A*"1S:&%R
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("1O=VYE
M<B`]("1S:&%R92T^9V5T*"=N86UE)RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D/B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1O=VYE<BD@+B`G/"]T9#XG.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D:'1M;"`N/2`G/'1D/B<["B`@("`@("`@("`@("1V:65W=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"=V:65W+G!H<"<L(&%R<F%Y*"=M96UO)R`]
M/B`D;65M;ULG;65M;U]I9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;65M;VQI<W0G
M(#T^("1M96UO6R=M96UO;&ES=%]I9"==*2D["B`@("`@("`@("`@("1H=&UL
M("X]($AO<F1E.CIL:6YK*&AT;6QS<&5C:6%L8VAA<G,H2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"1V:65W=7)L+"!T<G5E*2DI("X@:'1M;'-P96-I86QC:&%R
M<R@D;65M;ULG9&5S8R==*2`N("<\+V$^/"]T9#XG.PH*("`@("`@("`@("`@
M)&-O;&]R(#T@:7-S970H)&-O;&]R<ULD;65M;ULG8V%T96=O<GDG75TI(#\@
M)&-O;&]R<ULD;65M;ULG8V%T96=O<GDG75T@.B`D8V]L;W)S6R=?9&5F875L
M=%\G73L*("`@("`@("`@("`@)&9G8V]L;W(@/2!I<W-E="@D9F=C;VQO<G-;
M)&UE;6];)V-A=&5G;W)Y)UU=*2`_("1F9V-O;&]R<ULD;65M;ULG8V%T96=O
M<GDG75T@.B`D9F=C;VQO<G-;)U]D969A=6QT7R==.PH@("`@("`@("`@("`D
M:'1M;"`N/2`G/'1D('=I9'1H/2(Q)2(@<W1Y;&4](F)A8VMG<F]U;F0Z)R`N
M"B`@("`@("`@("`@("`@("`D8V]L;W(@+B`G.V-O;&]R.B<@+B`D9F=C;VQO
M<B`N("<B/B9N8G-P.R<@+@H@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC
M:&%R<R@D;65M;ULG8V%T96=O<GDG72`_("1M96UO6R=C871E9V]R>2==(#H@
M7R@B56YF:6QE9"(I*2`N"B`@("`@("`@("`@("`@("`B)FYB<W`[/"]T9#X\
M+W1R/EQN(CL*("`@("`@("!]"@H@("`@("`@(&EF("@A)&UE;6]S*2!["B`@
M("`@("`@("`@(')E='5R;B`G/'`^/&5M/B<@+B!?*").;R!N;W1E<R!T;R!D
M:7-P;&%Y(BD@+B`G/"]E;3X\+W`^)SL*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("<\=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(B!C;&%S
M<STB;&EN9612;W<B/B<@+B`D:'1M;"`N("<\+W1A8FQE/B<["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&EB+T1R:79E<BYP:'``````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S(Q-P`Q,#0Q
M-S,V,C<T-@`P,C`R-C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($UN96UO7T1R:79E<CHZ(&1E9FEN
M97,@86X@05!)(&9O<B!I;7!L96UE;G1I;F<@<W1O<F%G92!B86-K96YD<R!F
M;W(@36YE;6\N"B`J"B`J("1(;W)D93H@;6YE;6\O;&EB+T1R:79E<BYP:'`L
M=B`Q+C(U+C(N.2`R,#`V+S`S+S`S(#(S.C`P.C(Y(&-H=6-K($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2&]R9&4@4')O:F5C="`H:'1T<#HO
M+W=W=RYH;W)D92YO<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!*
M;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!-;F5M;R`Q
M+C`*("H@0'!A8VMA9V4@36YE;6\*("HO"F-L87-S($UN96UO7T1R:79E<B![
M"@H@("`@+RHJ"B`@("`@*B!!<G)A>2!H;VQD:6YG('1H92!C=7)R96YT(&UE
M;6\@;&ES="X@($5A8V@@87)R87D@96YT<GD@:7,@82!H87-H"B`@("`@*B!D
M97-C<FEB:6YG(&$@;65M;RX@(%1H92!A<G)A>2!I<R!I;F1E>&5D(&YU;65R
M:6-A;&QY(&)Y(&UE;6\@240N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]M96UO<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@8W5R<F5N="!N;W1E<&%D(&YA
M;64N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?;F]T97!A9"`]("<G.PH*("`@("\J*@H@("`@("H@3&ES=',@;65M;W,@
M8F%S960@;VX@=&AE(&=I=F5N(&-R:71E<FEA+B!!;&P@;65M;W,@=VEL;"!B
M90H@("`@("H@<F5T=7)N960@8GD@9&5F875L="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("`@(%)E='5R;G,@82!L:7-T(&]F('1H92!R97%U97-T
M960@;65M;W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1-96UO<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;65M;W,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T92!A('5N:79E<G-A;"`O('5N:7%U92!I9&5N
M=&EF:65R(&9O<B!A('1A<VLN(%1H:7,@:7,*("`@("`J($Y/5"!S;VUE=&AI
M;F<@=&AA="!W92!E>'!E8W0@=&\@8F4@86)L92!T;R!P87)S92!I;G1O(&$*
M("`@("`J('1A<VML:7-T(&%N9"!A('1A<VM)9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@02!N:6-E('5N:7%U92!S=')I;F<@*'-H;W5L9"!B
M92`R-34@8VAA<G,@;W(@;&5S<RDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M;F5R871E54E$*"D*("`@('L*("`@("`@("!R971U<FX@9&%T92@G66UD2&ES
M)RD@+B`G+B<@+@H@("`@("`@("`@("!S=6)S='(H8F%S95]C;VYV97)T*&UI
M8W)O=&EM92@I+"`Q,"P@,S8I+"`M,38I("X*("`@("`@("`@("`@)T`G("X@
M)$=,3T)!3%-;)V-O;F8G75LG<V5R=F5R)UU;)VYA;64G73L*("`@('T*"B`@
M("`O*BH*("`@("`J(%5P9&%T92!T:&4@9&5S8W)I<'1I;VX@*'-H;W)T('-U
M;6UA<GDI(&]F(&$@;65M;RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;65M;U]I9"`@5&AE(&UE;6\@=&\@=7!D871E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971-96UO1&5S8W)I<'1I;VXH)&)O9'DI"B`@("!["B`@("`@
M("`@:68@*"%S=')S='(H)&)O9'DL(")<;B(I("8F(%-T<FEN9SHZ;&5N9W1H
M*"1B;V1Y*2`\/2`V-"D@>PH@("`@("`@("`@("!R971U<FX@=')I;2@D8F]D
M>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&QI;F5S(#T@97AP
M;&]D92@B7&XB+"`D8F]D>2D["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)&QI;F5S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R:6TH4W1R:6YG
M.CIS=6)S='(H)&)O9'DL(#`L(#8T*2D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`O+R!-;W9E('1O(&$@;&EN92!W:71H(&UO<F4@
M=&AA;B!S<&%C97,N"B`@("`@("`@("`@("`@("`D:2`](#`["B`@("`@("`@
M("`@("`@("!W:&EL92`H:7-S970H)&QI;F5S6R1I72D@)B8@(7!R96=?;6%T
M8V@H)WQ;7EQS77PG+"`D;&EN97-;)&E=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1I*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H4W1R:6YG.CIL96YG=&@H)&QI;F5S6R1I72D@/#T@-C0I('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')I;2@D;&EN97-;)&E=*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R:6TH4W1R:6YG.CIS=6)S='(H)&QI;F5S6R1I72P@,"P@-C0I*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E
M($UN96UO7T1R:79E<B!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)&YO=&5P860@("`@5&AE(&YA
M;64@;V8@=&AE(&-U<G)E;G0@;F]T97!A9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`@("1D<FEV97(@("`@(%1H92!T>7!E(&]F(&-O;F-R971E
M($UN96UO7T1R:79E<B!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T;R!R971U<FXN("!4:&4@:7,@8F%S960@;VX@=&AE
M('-T;W)A9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9')I=F5R("@D9')I=F5R*2X@(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&5D+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("`@)'!A<F%M<R`@("`@*&]P
M=&EO;F%L*2!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYF:6=U<F%T:6]N
M(&]R(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@("!4:&4@;F5W;'D@8W)E871E9"!C
M;VYC<F5T92!-;F5M;U]$<FEV97(@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@D;F]T97!A9"`]("<G+"`D9')I=F5R(#T@;G5L
M;"P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH
M)&1R:79E<BDI('L*("`@("`@("`@("`@)&1R:79E<B`]("1'3$]"04Q36R=C
M;VYF)UU;)W-T;W)A9V4G75LG9')I=F5R)UT["B`@("`@("`@?0H*("`@("`@
M("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("AI
M<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@/2!(;W)D
M93HZ9V5T1')I=F5R0V]N9FEG*"=S=&]R86=E)RP@)&1R:79E<BD["B`@("`@
M("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+T1R:79E<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D8VQA
M<W,@/2`G36YE;6]?1')I=F5R7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D;6YE;6\@/2`F
M;F5W("1C;&%S<R@D;F]T97!A9"P@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&UN96UO(#T@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&UN96UO.PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@36YE
M;6]?1')I=F5R(&EN<W1A;F-E(&)A<V5D"B`@("`@*B!O;B`D9')I=F5R+@H@
M("`@("H*("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N
M8V4@:68@;F\@36YE;6]?1')I=F5R(&EN<W1A;F-E('=I=&@@=&AE"B`@("`@
M*B!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@
M("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE('-T;W)A9V4@
M<V]U<F-E<R!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)DUN96UO7T1R:79E<CHZ
M<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N
M;W1E<&%D("`@(%1H92!N86UE(&]F('1H92!C=7)R96YT(&YO=&5P860N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@("`D9')I=F5R("`@("!4:&4@
M='EP92!O9B!C;VYC<F5T92!-;F5M;U]$<FEV97(@<W5B8VQA<W,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@<F5T=7)N+B`@5&AE
M(&ES(&)A<V5D(&]N('1H92!S=&]R86=E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&1R:79E<B`H)&1R:79E<BDN("!4:&4@8V]D92!I
M<R!D>6YA;6EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;F-L=61E9"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`@
M("1P87)A;7,@("`@("AO<'1I;VYA;"D@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N9FEG=7)A=&EO;B!O<B!C;VYN96-T:6]N('!A<F%M971E<G,@80H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<R!M
M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@5&AE
M(&-R96%T960@8V]N8W)E=&4@36YE;6]?1')I=F5R(&EN<W1A;F-E+"!O<B!F
M86QS90H@("`@("H@("`@("`@("`@("`@("`@("!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D;F]T97!A9"`]("<G+"`D9')I
M=F5R(#T@;G5L;"P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<W1A
M=&EC("1I;G-T86YC97,["@H@("`@("`@(&EF("AI<U]N=6QL*"1D<FEV97(I
M*2!["B`@("`@("`@("`@("1D<FEV97(@/2`D1TQ/0D%,4ULG8V]N9B==6R=S
M=&]R86=E)UU;)V1R:79E<B==.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'!A<F%M<R`]($AO<F1E
M.CIG971$<FEV97)#;VYF:6<H)W-T;W)A9V4G+"`D9')I=F5R*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@
M("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1N;W1E<&%D+"`D9')I
M=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S
M6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N
M871U<F5=(#T@)DUN96UO7T1R:79E<CHZ9F%C=&]R>2@D;F]T97!A9"P@)&1R
M:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN
M<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"B`@("`O*BH*("`@("`J($5X
M<&]R="!T:&ES(&UE;6\@:6X@:4-A;&5N9&%R(&9O<FUA="X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@(&UE;6\@("`@("!T:&4@;65M;R`H:&%S:"!A
M<G)A>2D@=&\@97AP;W)T"B`@("`@*B!`<&%R86T@;V)J96-T('9C86P@("`@
M("!A($AO<F1E7VE#86QE;F1A<B!O8FIE8W0@=&AA="!A8W1S(&%S(&-O;G1A
M:6YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@2&]R9&5?:4-A
M;&5N9&%R7W9N;W1E(&]B:F5C="!F;W(@=&AI<R!E=F5N="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=&]I0V%L96YD87(H)&UE;6\L("8D8V%L96YD87(I"B`@
M("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)'9N;W1E(#T@
M)DAO<F1E7VE#86QE;F1A<CHZ;F5W0V]M<&]N96YT*"=V;F]T92<L("1C86QE
M;F1A<BD["@H@("`@("`@("1V;F]T92T^<V5T071T<FEB=71E*"=5240G+"`D
M;65M;ULG=6ED)UTI.PH@("`@("`@("1V;F]T92T^<V5T071T<FEB=71E*"="
M3T19)RP@)&UE;6];)V)O9'DG72D["B`@("`@("`@:68@*"%E;7!T>2@D;65M
M;ULG8V%T96=O<GDG72DI('L*("`@("`@("`@("`@)'9N;W1E+3YS971!='1R
M:6)U=&4H)T-!5$5'3U))15,G+"`D;65M;ULG8V%T96=O<GDG72D["B`@("`@
M("`@?0H*("`@("`@("`O*B!'970@=&AE(&YO=&4G<R!H:7-T;W)Y+B`J+PH@
M("`@("`@("1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I
M.PH@("`@("`@("1L;V<@/2`D:&ES=&]R>2T^9V5T2&ES=&]R>2@G;6YE;6\Z
M)R`N("1M96UO6R=M96UO;&ES=%]I9"==("X@)SHG("X@)&UE;6];)W5I9"==
M*3L*("`@("`@("!I9B`H)&QO9R`F)B`A:7-?82@D;&]G+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1L;V<M/F=E=$1A=&$H*2!A
M<R`D96YT<GDI('L*("`@("`@("`@("`@("`@('-W:71C:"`H)&5N=')Y6R=A
M8W1I;VXG72D@>PH@("`@("`@("`@("`@("`@8V%S92`G861D)SH*("`@("`@
M("`@("`@("`@("`@("`D8W)E871E9"`]("1E;G1R>5LG=',G73L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=M
M;V1I9GDG.@H@("`@("`@("`@("`@("`@("`@("1M;V1I9FEE9"`]("1E;G1R
M>5LG=',G73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*"%E;7!T>2@D8W)E871E9"DI('L*("`@("`@("`@("`@)'9N;W1E+3YS971!
M='1R:6)U=&4H)T1#4D5!5$5$)RP@)&-R96%T960I.PH@("`@("`@('T*("`@
M("`@("!I9B`H(65M<'1Y*"1M;V1I9FEE9"DI('L*("`@("`@("`@("`@)'9N
M;W1E+3YS971!='1R:6)U=&4H)TQ!4U0M34]$249)140G+"`D;6]D:69I960I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V;F]T93L*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T92!A(&UE;6\@*&AA<V@@87)R87DI(&9R;VT@
M82!(;W)D95]I0V%L96YD87)?=FYO=&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!(;W)D95]I0V%L96YD87)?=FYO=&4@)'9N;W1E("!4:&4@:4-A
M;&5N9&%R(&1A=&$@=&\@=7!D871E(&9R;VTN"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@365M;R`H:&%S:"!A<G)A>2D@8W)E871E9"!F<F]M('1H
M92!V3F]T92X*("`@("`J+PH@("`@9G5N8W1I;VX@9G)O;6E#86QE;F1A<B@D
M=DYO=&4I"B`@("!["B`@("`@("`@)&UE;6\@/2!A<G)A>2@I.PH*("`@("`@
M("`D8F]D>2`]("1V3F]T92T^9V5T071T<FEB=71E*"="3T19)RD["B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D8F]D>2D@)B8@(6ES7V$H)&)O9'DL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@)&UE;6];)V)O9'DG72`]("1B;V1Y
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M96UO6R=B;V1Y)UT@
M/2`G)SL*("`@("`@("!]"@H@("`@("`@("1M96UO6R=D97-C)UT@/2`D=&AI
M<RT^9V5T365M;T1E<V-R:7!T:6]N*"1M96UO6R=B;V1Y)UTI.PH*("`@("`@
M("`D8V%T(#T@)'9.;W1E+3YG971!='1R:6)U=&4H)T-!5$5'3U))15,G*3L*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C870I("8F("%I<U]A*"1C870L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&UE;6];)V-A=&5G;W)Y)UT@
M/2`D8V%T.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M96UO.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO
M+VQI8B]-;F5M;RYP:'``````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,C$S,3``,3`T,3<S-C(W-#8`,#(P,#8U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@HO*BH*("H@
M4V]R="!B>2!M96UO(&1E<V-R:7!T:6]N+@H@*B\*9&5F:6YE*"=-3D5-3U]3
M3U)47T1%4T,G+"`P*3L*"B\J*@H@*B!3;W)T(&)Y(&UE;6\@8V%T96=O<GDN
M"B`J+PID969I;F4H)TU.14U/7U-/4E1?0T%414=/4EDG+"`Q*3L*"B\J*@H@
M*B!3;W)T(&EN(&%S8V5N9&EN9R!O<F1E<BX*("HO"F1E9FEN92@G34Y%34]?
M4T]25%]!4T-%3D0G+"`P*3L*"B\J*@H@*B!3;W)T(&EN(&1E<V-E;F1I;F<@
M;W)D97(N"B`J+PID969I;F4H)TU.14U/7U-/4E1?1$530T5.1"<L(#$I.PH*
M+RHJ"B`J($UN96UO($)A<V4@0VQA<W,N"B`J"B`J("1(;W)D93H@;6YE;6\O
M;&EB+TUN96UO+G!H<"QV(#$N-3(N,BXX(#(P,#8O,#$O,#$@,C$Z,CDZ,#8@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2&]R9&4@4')O
M:F5C="`H:'1T<#HO+W=W=RYH;W)D92YO<F<O*0H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M05-,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@
M*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!-;F5M;R`Q+C`*("H@0'!A8VMA9V4@36YE;6\*("HO"F-L87-S($UN
M96UO('L*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@8W5R<F5N="!U
M<V5R)W,@;F]T92!L:7-T(&9R;VT@<W1O<F%G92X@5&AI<R!F=6YC=&EO;B!W
M:6QL"B`@("`@*B!A;'-O('-O<G0@=&AE(')E<W5L=&EN9R!L:7-T+"!I9B!R
M97%U97-T960N"B`@("`@*@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1S;W)T
M8GD@("!4:&4@9FEE;&0@8GD@=VAI8V@@=&\@<V]R="X@*$U.14U/7U-/4E1?
M1$530RP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@34Y%34]?
M4T]25%]#051%1T]262D*("`@("`J($!P87)A;2!C;VYS=&%N="`D<V]R=&1I
M<B`@5&AE(&1I<F5C=&EO;B!B>2!W:&EC:"!T;R!S;W)T+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`H34Y%34]?4T]25%]!4T,L($U.14U/
M7U-/4E1?1$530RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI
M<W0@;V8@=&AE(')E<75E<W1E9"!N;W1E<RX*("`@("`J"B`@("`@*B!`<V5E
M($UN96UO7T1R:79E<CHZ;&ES=$UE;6]S*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&ES=$UE;6]S*"1S;W)T8GD@/2!-3D5-3U]33U)47T1%4T,L"B`@("`@
M("`@("`@("`@("`@("`@("`@)'-O<G1D:7(@/2!-3D5-3U]33U)47T%30T5.
M1"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8L("1D:7-P;&%Y7VYO=&5P
M861S.PH@("`@("`@("1M96UO<R`](&%R<F%Y*"D["@H@("`@("`@("\J(%-O
M<G0@=&AE(&UE;6\@;&ES="X@*B\*("`@("`@("`D<V]R=%]F=6YC=&EO;G,@
M/2!A<G)A>2@*("`@("`@("`@("`@34Y%34]?4T]25%]$15-#(#T^("=">41E
M<V,G+`H@("`@("`@("`@("!-3D5-3U]33U)47T-!5$5'3U)9(#T^("=">4-A
M=&5G;W)Y)PH@("`@("`@("D["@H@("`@("`@(&9O<F5A8V@@*"1D:7-P;&%Y
M7VYO=&5P861S(&%S("1N;W1E<&%D*2!["B`@("`@("`@("`@("\J($-R96%T
M92!A($UN96UO('-T;W)A9V4@:6YS=&%N8V4N("HO"B`@("`@("`@("`@("1S
M=&]R86=E(#T@)DUN96UO7T1R:79E<CHZ<VEN9VQE=&]N*"1N;W1E<&%D*3L*
M("`@("`@("`@("`@)'-T;W)A9V4M/G)E=')I979E*"D["@H@("`@("`@("`@
M("`O*B!2971R:65V92!T:&4@;65M;R!L:7-T(&9R;VT@<W1O<F%G92X@*B\*
M("`@("`@("`@("`@)&YE=VUE;6]S(#T@)'-T;W)A9V4M/FQI<W1-96UO<R@I
M.PH@("`@("`@("`@("`D;65M;W,@/2!A<G)A>5]M97)G92@D;65M;W,L("1N
M97=M96UO<RD["B`@("`@("`@?0H*("`@("`@("`O*B!3;W)T('1H92!A<G)A
M>2!I9B!W92!H879E(&$@<V]R="!F=6YC=&EO;B!D969I;F5D(&9O<B!T:&ES
M"B`@("`@("`@("H@9FEE;&0N("HO"B`@("`@("`@:68@*&ES<V5T*"1S;W)T
M7V9U;F-T:6]N<ULD<V]R=&)Y72DI('L*("`@("`@("`@("`@)'!R969I>"`]
M("@D<V]R=&1I<B`]/2!-3D5-3U]33U)47T1%4T-%3D0I(#\@)U]R<V]R="<@
M.B`G7W-O<G0G.PH@("`@("`@("`@("!U87-O<G0H)&UE;6]S+"!A<G)A>2@G
M36YE;6\G+"`D<')E9FEX("X@)'-O<G1?9G5N8W1I;VYS6R1S;W)T8GE=*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&UE;6]S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(&YO=&5S(&EN(&YO
M=&5P861S('1H870@=&AE(&-U<G)E;G0@=7-E<B!O=VYS+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!N;W1E<R!T:&%T
M('1H92!U<V5R(&]W;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT365M
M;W,H*0H@("`@>PH@("`@("`@('-T871I8R`D8V]U;G0["B`@("`@("`@:68@
M*&ES<V5T*"1C;W5N="DI('L*("`@("`@("`@("`@<F5T=7)N("1C;W5N=#L*
M("`@("`@("!]"@H@("`@("`@("1N;W1E<&%D<R`]($UN96UO.CIL:7-T3F]T
M97!A9',H=')U92P@4$5235-?04Q,*3L*"B`@("`@("`@)&-O=6YT(#T@,#L*
M("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1N;W1E<&%D<RD@87,@)&YO
M=&5P860I('L*("`@("`@("`@("`@+RH@0W)E871E(&$@36YE;6\@<W1O<F%G
M92!I;G-T86YC92X@*B\*("`@("`@("`@("`@)'-T;W)A9V4@/2`F36YE;6]?
M1')I=F5R.CIS:6YG;&5T;VXH)&YO=&5P860I.PH@("`@("`@("`@("`D<W1O
M<F%G92T^<F5T<FEE=F4H*3L*"B`@("`@("`@("`@("\J(%)E=')I979E('1H
M92!M96UO(&QI<W0@9G)O;2!S=&]R86=E+B`J+PH@("`@("`@("`@("`D8V]U
M;G0@*ST@8V]U;G0H)'-T;W)A9V4M/FQI<W1-96UO<R@I*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8V]U;G0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971R:65V97,@82!S<&5C:69I8R!N;W1E(&9R;VT@<W1O<F%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M96UO;&ES="`@5&AE(&YO=&5P
M860@=&\@<F5T<FEE=F4@=&AE(&YO=&4@9G)O;2X*("`@("`J($!P87)A;2!S
M=')I;F<@)&UE;6\@("`@("!4:&4@260@;V8@=&AE(&YO=&4@=&\@<F5T<FEE
M=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&YO=&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE;6\H)&YO=&5P860L("1M96UO*0H@
M("`@>PH@("`@("`@("1S=&]R86=E(#T@)DUN96UO7T1R:79E<CHZ<VEN9VQE
M=&]N*"1N;W1E<&%D*3L*("`@("`@("!R971U<FX@)'-T;W)A9V4M/F=E="@D
M;65M;RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T<R!A;&P@;F]T97!A
M9',@82!U<V5R(&AA<R!A8V-E<W,@=&\N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&]W;F5R;VYL>2`@($]N;'D@<F5T=7)N(&UE;6\@;&ES=',@
M=&AA="!T:&ES('5S97(@;W=N<S\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!$969A=6QT<R!T;R!F86QS92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!T;R!F:6QT97(@
M;F]T97!A9',@8GDN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&UE;6\@;&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1.;W1E<&%D
M<R@D;W=N97)O;FQY(#T@9F%L<V4L("1P97)M:7-S:6]N(#T@4$5235-?4TA/
M5RD*("`@('L*("`@("`@("`D;F]T97!A9',@/2`D1TQ/0D%,4ULG;6YE;6]?
M<VAA<F5S)UTM/FQI<W13:&%R97,H075T:#HZ9V5T075T:"@I+"`D<&5R;6ES
M<VEO;BP@)&]W;F5R;VYL>2`_($%U=&@Z.F=E=$%U=&@H*2`Z(&YU;&PI.PH@
M("`@("`@(&EF("AI<U]A*"1N;W1E<&%D<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D;F]T97!A9',L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&YO=&5P
M861S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9&5F875L
M="!N;W1E<&%D(&9O<B!T:&4@8W5R<F5N="!U<V5R(&%T('1H92!S<&5C:69I
M960*("`@("`J('!E<FUI<W-I;VYS(&QE=F5L+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971$969A=6QT3F]T97!A9"@D<&5R;6ES<VEO;B`](%!%4DU37U-(
M3U<I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)&1E
M9F%U;'1?;F]T97!A9"`]("1P<F5F<RT^9V5T5F%L=64H)V1E9F%U;'1?;F]T
M97!A9"<I.PH@("`@("`@("1N;W1E<&%D<R`]($UN96UO.CIL:7-T3F]T97!A
M9',H9F%L<V4L("1P97)M:7-S:6]N*3L*"B`@("`@("`@:68@*&ES<V5T*"1N
M;W1E<&%D<ULD9&5F875L=%]N;W1E<&%D72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1D969A=6QT7VYO=&5P860["B`@("`@("`@?2!E;'-E:68@*"1P<F5F
M<RT^:7-,;V-K960H)V1E9F%U;'1?;F]T97!A9"<I*2!["B`@("`@("`@("`@
M(')E='5R;B`G)SL*("`@("`@("!](&5L<V5I9B`H8V]U;G0H)&YO=&5P861S
M*2D@>PH@("`@("`@("`@("!R971U<FX@:V5Y*"1N;W1E<&%D<RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VUP87)I<V]N(&9U;F-T:6]N(&9O<B!S;W)T:6YG(&YO=&5S(&)Y
M(&1E<V-R:7!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D82`@
M3F]T92!O;F4N"B`@("`@*B!`<&%R86T@87)R87D@)&(@($YO=&4@='=O+@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@,2!I9B!M96UO(&]N92!I
M<R!G<F5A=&5R+"`M,2!I9B!M96UO('1W;R!I<R!G<F5A=&5R.R`P"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&EF('1H97D@87)E(&5Q=6%L+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<V]R=$)Y1&5S8R@D82P@)&(I"B`@("!["B`@("`@
M("`@<F5T=7)N('-T<F-A<V5C;7`H)&%;)V1E<V,G72P@)&);)V1E<V,G72D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP87)I<V]N(&9U;F-T:6]N(&9O
M<B!R979E<G-E('-O<G1I;F<@;F]T97,@8GD@9&5S8W)I<'1I;VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A("!.;W1E(&]N92X*("`@("`J($!P
M87)A;2!A<G)A>2`D8B`@3F]T92!T=V\N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("`M,2!I9B!N;W1E(&]N92!I<R!G<F5A=&5R+"`Q(&EF(&YO
M=&4@='=O(&ES(&=R96%T97([(#`*("`@("`J("`@("`@("`@("`@("`@("`@
M:68@=&AE>2!A<F4@97%U86PN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R<V]R
M=$)Y1&5S8R@D82P@)&(I"B`@("!["B`@("`@("`@<F5T=7)N('-T<F-A<V5C
M;7`H)&);)V1E<V,G72P@)&%;)V1E<V,G72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VUP87)I<V]N(&9U;F-T:6]N(&9O<B!S;W)T:6YG(&YO=&5S(&)Y
M(&-A=&5G;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D82`@3F]T
M92!O;F4N"B`@("`@*B!`<&%R86T@87)R87D@)&(@($YO=&4@='=O+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@,2!I9B!N;W1E(&]N92!I<R!G
M<F5A=&5R+"`M,2!I9B!N;W1E('1W;R!I<R!G<F5A=&5R.R`P"B`@("`@*B`@
M("`@("`@("`@("`@("`@(&EF('1H97D@87)E(&5Q=6%L+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V]R=$)Y0V%T96=O<GDH)&$L("1B*0H@("`@>PH@("`@
M("`@(')E='5R;B!S=')C87-E8VUP*"1A6R=C871E9V]R>2==(#\@)&%;)V-A
M=&5G;W)Y)UT@.B!?*")5;F9I;&5D(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&);)V-A=&5G;W)Y)UT@/R`D8ELG8V%T96=O<GDG72`Z(%\H(E5N
M9FEL960B*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP87)I<V]N(&9U
M;F-T:6]N(&9O<B!R979E<G-E('-O<G1I;F<@;F]T97,@8GD@8V%T96=O<GDN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A("!.;W1E(&]N92X*("`@
M("`J($!P87)A;2!A<G)A>2`D8B`@3F]T92!T=V\N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("`M,2!I9B!N;W1E(&]N92!I<R!G<F5A=&5R+"`Q
M(&EF(&YO=&4@='=O(&ES(&=R96%T97([(#`*("`@("`J("`@("`@("`@("`@
M("`@("`@:68@=&AE>2!A<F4@97%U86PN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]R<V]R=$)Y0V%T96=O<GDH)&$L("1B*0H@("`@>PH@("`@("`@(')E='5R
M;B!S=')C87-E8VUP*"1B6R=C871E9V]R>2==(#\@)&);)V-A=&5G;W)Y)UT@
M.B!?*")5;F9I;&5D(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@)&%;
M)V-A=&5G;W)Y)UT@/R`D85LG8V%T96=O<GDG72`Z(%\H(E5N9FEL960B*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S<&5C:69I960@
M<&5R;6ES<VEO;B!F;W(@=&AE(&-U<G)E;G0@=7-E<BX*("`@("`J"B`@("`@
M*B!`<VEN8V4@36YE;6\@,BXQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&5R;6ES<VEO;B`@02!P97)M:7-S:6]N+"!C=7)R96YT;'D@;VYL>2`G
M;6%X7VYO=&5S)RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M=F%L=64@;V8@=&AE('-P96-I9FEE9"!P97)M:7-S:6]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1P97)M:7-S:6]N*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D<&5R;7,["@H@("`@("`@(&EF("@A)'!E<FUS+3YE
M>&ES=',H)VUN96UO.B<@+B`D<&5R;6ES<VEO;BDI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D86QL;W=E9"`]("1P
M97)M<RT^9V5T4&5R;6ES<VEO;G,H)VUN96UO.B<@+B`D<&5R;6ES<VEO;BD[
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1A;&QO=V5D*2D@>PH@("`@("`@("`@
M("!S=VET8V@@*"1P97)M:7-S:6]N*2!["B`@("`@("`@("`@(&-A<V4@)VUA
M>%]N;W1E<R<Z"B`@("`@("`@("`@("`@("`D86QL;W=E9"`](&%R<F%Y7W)E
M9'5C92@D86QL;W=E9"P@8W)E871E7V9U;F-T:6]N*"<D82P@)&(G+"`G<F5T
M=7)N(&UA>"@D82P@)&(I.R<I+"`P*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%L
M;&]W960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@36YE;6\G<R!L
M:7-T(&]F(&UE;G4@:71E;7,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE
M;G4H)')E='5R;E1Y<&4@/2`G;V)J96-T)RD*("`@('L*("`@("`@("!G;&]B
M86P@)&-O;F8L("1R96=I<W1R>2P@)'!R:6YT7VQI;FL["@H@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PH*("`@("`@("`D;65N=2`]
M("9N97<@365N=2@I.PH@("`@("`@("1M96YU+3YA9&0H2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=L:7-T+G!H<"<I+"!?*")?3&ES="!.;W1E<R(I+"`G;6YE
M;6\N<&YG)RP@;G5L;"P@;G5L;"P@;G5L;"P@8F%S96YA;64H)%]315)615);
M)U!(4%]314Q&)UTI(#T]("=I;F1E>"YP:'`G(#\@)V-U<G)E;G0G(#H@;G5L
M;"D["B`@("`@("`@:68@*$UN96UO.CIG971$969A=6QT3F]T97!A9"A015)-
M4U]%1$E4*2`F)@H@("`@("`@("`@("`H(65M<'1Y*"1C;VYF6R=H;V]K<R==
M6R=P97)M<V1E;FEE9"==*2!\?`H@("`@("`@("`@("`@36YE;6\Z.FAA<U!E
M<FUI<W-I;VXH)VUA>%]N;W1E<R<I(#T]/2!T<G5E('Q\"B`@("`@("`@("`@
M("!-;F5M;SHZ:&%S4&5R;6ES<VEO;B@G;6%X7VYO=&5S)RD@/B!-;F5M;SHZ
M8V]U;G1-96UO<R@I*2D@>PH@("`@("`@("`@("`D;65N=2T^861D*$AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G;65M;RYP:'`_86-T:6]N240]861D7VUE;6\G
M*2P@7R@B7TYE=R!.;W1E(BDL("=A9&0N<&YG)RP@;G5L;"P@;G5L;"P@;G5L
M;"P@571I;#HZ9V5T1F]R;41A=&$H)VUE;6\G*2`_("=?7VYO<V5L96-T:6]N
M)R`Z(&YU;&PI.PH@("`@("`@('T*("`@("`@("!I9B`H36YE;6\Z.F=E=$1E
M9F%U;'1.;W1E<&%D*%!%4DU37U)%040I*2!["B`@("`@("`@("`@("1M96YU
M+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S96%R8V@N<&AP)RDL(%\H
M(E]396%R8V@B*2P@)W-E87)C:"YP;F<G+"`D<F5G:7-T<GDM/F=E=$EM86=E
M1&ER*"=H;W)D92<I*3L*("`@("`@("!]"@H@("`@("`@(&EF("A!=71H.CIG
M971!=71H*"DI('L*("`@("`@("`@("`@)&UE;G4M/F%D9"A(;W)D93HZ87!P
M;&EC871I;VY5<FPH)VYO=&5P861S+G!H<"<I+"!?*")?37D@3F]T97!A9',B
M*2P@)VYO=&5P861S+G!N9R<I.PH@("`@("`@('T*"B`@("`@("`@+RH@26UP
M;W)T+T5X<&]R="`J+PH@("`@("`@(&EF("@D8V]N9ELG;65N=2==6R=I;7!O
M<G1?97AP;W)T)UTI('L*("`@("`@("`@("`@)&UE;G4M/F%D9"A(;W)D93HZ
M87!P;&EC871I;VY5<FPH)V1A=&$N<&AP)RDL(%\H(E]);7!O<G0O17AP;W)T
M(BDL("=D871A+G!N9R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI.PH@("`@("`@('T*"B`@("`@("`@+RH@4')I;G0@*B\*("`@("`@("!I
M9B`H)&-O;F9;)VUE;G4G75LG<')I;G0G72`F)B!I<W-E="@D<')I;G1?;&EN
M:RDI('L*("`@("`@("`@("`@)&UE;G4M/F%D9"@D<')I;G1?;&EN:RP@7R@B
M7U!R:6YT(BDL("=P<FEN="YP;F<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I+"`G7V)L86YK)RP@)W!O<'5P*'1H:7,N:')E9BD[(')E='5R
M;B!F86QS93LG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5T=7)N5'EP
M92`]/2`G;V)J96-T)RD@>PH@("`@("`@("`@("!R971U<FX@)&UE;G4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1M96YU+3YR96YD
M97(H*3L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;6YE;6\O;&EB+V%P:2YP:'``````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`S,3,W,@`Q,#0Q-S,V,C<T-@`P,3<U-S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($UN96UO(&5X=&5R;F%L($%022!I;G1E<F9A8V4N"B`J"B`J(%1H
M:7,@9FEL92!D969I;F5S($UN96UO)W,@97AT97)N86P@05!)(&EN=&5R9F%C
M92X@($]T:&5R(&%P<&QI8V%T:6]N<R!C86X*("H@:6YT97)A8W0@=VET:"!-
M;F5M;R!T:')O=6=H('1H:7,@05!)+@H@*@H@*B`D2&]R9&4Z(&UN96UO+VQI
M8B]A<&DN<&AP+'8@,2XU,RXR+C$R(#(P,#8O,#,O,#8@,3,Z-30Z,#0@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2&]R9&4@4')O:F5C
M="`H:'1T<#HO+W=W=RYH;W)D92YO<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`
M<VEN8V4@("!-;F5M;R`Q+C`*("H@0'!A8VMA9V4@36YE;6\*("HO"@HD7W-E
M<G9I8V5S6R=P97)M<R==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH
M*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I.PH*
M)%]S97)V:6-E<ULG<VAO=R==(#T@87)R87DH"B`@("`G;&EN:R<@/3X@)R5A
M<'!L:6-A=&EO;B4O=FEE=RYP:'`_;65M;VQI<W0]?&YO=&5P861\)FUE;6\]
M?&YO=&5\)G5I9#U\=6ED?"<L"BD["@HD7W-E<G9I8V5S6R=L:7-T3F]T97!A
M9',G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=O=VYE<F]N;'DG
M(#T^("=B;V]L96%N)RP@)W!E<FUI<W-I;VXG(#T^("=I;G0G*2P*("`@("=T
M>7!E)R`]/B`G>W5R;CIH87-H?7-T<FEN9T%R<F%Y)RP**3L*"B1?<V5R=FEC
M97-;)VQI<W0G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@
M("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG"BD["@HD7W-E
M<G9I8V5S6R=L:7-T0GDG72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y
M*"=A8W1I;VXG(#T^("=S=')I;F<G+"`G=&EM97-T86UP)R`]/B`G:6YT)RDL
M"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG"BD["@HD
M7W-E<G9I8V5S6R=G971!8W1I;VY4:6UE<W1A;7`G72`](&%R<F%Y*`H@("`@
M)V%R9W,G(#T^(&%R<F%Y*"=U:60G(#T^("=S=')I;F<G+"`G=&EM97-T86UP
M)R`]/B`G:6YT)RDL"B`@("`G='EP92<@/3X@)VEN="<L"BD["@HD7W-E<G9I
M8V5S6R=I;7!O<G0G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=C
M;VYT96YT)R`]/B`G<W1R:6YG)RP@)V-O;G1E;G14>7!E)R`]/B`G<W1R:6YG
M)RDL"B`@("`G='EP92<@/3X@)VEN="<**3L*"B1?<V5R=FEC97-;)V5X<&]R
M="==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W5I9"<@/3X@)W-T
M<FEN9R<L("=C;VYT96YT5'EP92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G
M(#T^("=S=')I;F<G"BD["@HD7W-E<G9I8V5S6R=D96QE=&4G72`](&%R<F%Y
M*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=U:60G(#T^("=S=')I;F<G*2P*("`@
M("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)W)E<&QA8V4G
M72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=U:60G(#T^("=S=')I
M;F<G+"`G8V]N=&5N="<@/3X@)W-T<FEN9R<L("=C;VYT96YT5'EP92<@/3X@
M)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*"F9U;F-T
M:6]N(%]M;F5M;U]P97)M<R@I"GL*("`@("1P97)M<R`](&%R<F%Y*"D["B`@
M("`D<&5R;7-;)W1R964G75LG;6YE;6\G75LG;6%X7VYO=&5S)UT@/2!F86QS
M93L*("`@("1P97)M<ULG=&ET;&4G75LG;6YE;6\Z;6%X7VYO=&5S)UT@/2!?
M*")-87AI;75M($YU;6)E<B!O9B!.;W1E<R(I.PH@("`@)'!E<FUS6R=T>7!E
M)UU;)VUN96UO.FUA>%]N;W1E<R==(#T@)VEN="<["@H@("`@<F5T=7)N("1P
M97)M<SL*?0H*+RHJ"B`J($!P87)A;2!B;V]L96%N("1O=VYE<F]N;'D@("!/
M;FQY(')E='5R;B!N;W1E<&%D<R!T:&%T('1H:7,@=7-E<B!O=VYS/PH@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@9F%L<V4N
M"B`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO
M;B!T;R!F:6QT97(@;F]T97!A9',@8GDN"B`J"B`J($!R971U<FX@87)R87D@
M(%1H92!N;W1E<&%D<RX*("HO"F9U;F-T:6]N(%]M;F5M;U]L:7-T3F]T97!A
M9',H)&]W;F5R;VYL>2P@)'!E<FUI<W-I;VXI"GL*("`@(')E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH*("`@(')E='5R
M;B!-;F5M;SHZ;&ES=$YO=&5P861S*"1O=VYE<F]N;'DL("1P97)M:7-S:6]N
M*3L*?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R87D@;V8@54E$<R!F;W(@86QL
M(&YO=&5S('1H870@=&AE(&-U<G)E;G0@=7-E<B!I<PH@*B!A=71H;W)I>F5D
M('1O('-E92X*("H*("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@54E$
M<R!F;W(@86QL(&YO=&5S('1H92!U<V5R(&-A;B!A8V-E<W,N"B`J+PIF=6YC
M=&EO;B!?;6YE;6]?;&ES="@I"GL*("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH@("`@9VQO8F%L("1C;VYF.PH*
M("`@(&EF("@A:7-S970H)&-O;F9;)W-T;W)A9V4G75LG9')I=F5R)UTI('Q\
M"B`@("`@("`@(6ES<V5T*"1C;VYF6R=S=&]R86=E)UU;)W!A<F%M<R==*2D@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;W0@8V]N9FEG
M=7)E9"<I.PH@("`@?0H*("`@("1M96UO<R`]($UN96UO.CIL:7-T365M;W,H
M*3L*("`@(&EF("AI<U]A*"1M96UO<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@(')E='5R;B`D;65M;W,["B`@("!]"@H@("`@)'5I9',@/2!A<G)A>2@I
M.PH@("`@9F]R96%C:"`H)&UE;6]S(&%S("1M96UO*2!["B`@("`@("`@)'5I
M9'-;72`]("1M96UO6R=U:60G73L*("`@('T*"B`@("!R971U<FX@)'5I9',[
M"GT*"B\J*@H@*B!2971U<FYS(&%N(&%R<F%Y(&]F(%5)1',@9F]R(&YO=&5S
M('1H870@:&%V92!H860@)&%C=&EO;B!H87!P96X*("H@<VEN8V4@)'1I;65S
M=&%M<"X*("H*("H@0'!A<F%M('-T<FEN9R`@)&%C=&EO;B`@("`@5&AE(&%C
M=&EO;B!T;R!C:&5C:R!F;W(@+2!A9&0L(&UO9&EF>2P@;W(@9&5L971E+@H@
M*B!`<&%R86T@:6YT96=E<B`D=&EM97-T86UP("!4:&4@=&EM92!T;R!S=&%R
M="!T:&4@<V5A<F-H+@H@*B!`<&%R86T@<W1R:6YG("`D;F]T97!A9"`@("!4
M:&4@;F]T97!A9"!T;R!S96%R8V@@:6XN"B`J"B`J($!R971U<FX@87)R87D@
M($%N(&%R<F%Y(&]F(%5)1',@;6%T8VAI;F<@=&AE(&%C=&EO;B!A;F0@=&EM
M92!C<FET97)I82X*("HO"F9U;F-T:6]N(%]M;F5M;U]L:7-T0GDH)&%C=&EO
M;BP@)'1I;65S=&%M<"P@)&YO=&5P860@/2`G)RD*>PH@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<["@H@("`@+RH@
M36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!N;W1E<&%D+B`J+PH@("`@:68@
M*&5M<'1Y*"1N;W1E<&%D*2D@>PH@("`@("`@("1N;W1E<&%D(#T@36YE;6\Z
M.F=E=$1E9F%U;'1.;W1E<&%D*"D["B`@("!]"@H@("`@)&AI<W1O<GD@/2`F
M2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@("`D:&ES=&]R:65S(#T@
M)&AI<W1O<GDM/F=E=$)Y5&EM97-T86UP*"<^)RP@)'1I;65S=&%M<"P@87)R
M87DH87)R87DH)V]P)R`]/B`G/2<L("=F:65L9"<@/3X@)V%C=&EO;B<L("=V
M86QU92<@/3X@)&%C=&EO;BDI+"`G;6YE;6\Z)R`N("1N;W1E<&%D("D["B`@
M("!I9B`H:7-?82@D:&ES=&]R:65S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@<F5T=7)N("1H:7-T;W)I97,["B`@("!]"@H@("`@+R\@4W1R:7`@;&5A
M9&EN9R!M;F5M;SIU<V5R;F%M93HN"B`@("!R971U<FX@<')E9U]R97!L86-E
M*"<O7BA;7CI=*CHI>S)]+R<L("<G+"!A<G)A>5]K97ES*"1H:7-T;W)I97,I
M*3L*?0H*+RHJ"B`J(%)E='5R;G,@=&AE('1I;65S=&%M<"!O9B!A;B!O<&5R
M871I;VX@9F]R(&$@9VEV96X@=6ED(&%N(&%C=&EO;BX*("H*("H@0'!A<F%M
M('-T<FEN9R`D=6ED("`@("!4:&4@=6ED('1O(&QO;VL@9F]R+@H@*B!`<&%R
M86T@<W1R:6YG("1A8W1I;VX@(%1H92!A8W1I;VX@=&\@8VAE8VL@9F]R("T@
M861D+"!M;V1I9GDL(&]R(&1E;&5T92X*("H@0'!A<F%M('-T<FEN9R`D;F]T
M97!A9"!4:&4@;F]T97!A9"!T;R!S96%R8V@@:6XN"B`J"B`J($!R971U<FX@
M:6YT96=E<B`@5&AE('1I;65S=&%M<"!F;W(@=&AI<R!A8W1I;VXN"B`J+PIF
M=6YC=&EO;B!?;6YE;6]?9V5T06-T:6]N5&EM97-T86UP*"1U:60L("1A8W1I
M;VXL("1N;W1E<&%D(#T@)R<I"GL*("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH*("`@("\J($UA:V4@<W5R92!W
M92!H879E(&$@=F%L:60@;F]T97!A9"X@*B\*("`@(&EF("AE;7!T>2@D;F]T
M97!A9"DI('L*("`@("`@("`D;F]T97!A9"`]($UN96UO.CIG971$969A=6QT
M3F]T97!A9"@I.PH@("`@?0H*("`@("1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O
M<GDZ.G-I;F=L971O;B@I.PH@("`@<F5T=7)N("1H:7-T;W)Y+3YG971!8W1I
M;VY4:6UE<W1A;7`H)VUN96UO.B<@+B`D;F]T97!A9"`N("<Z)R`N("1U:60L
M("1A8W1I;VXI.PI]"@HO*BH*("H@26UP;W)T(&$@;65M;R!R97!R97-E;G1E
M9"!I;B!T:&4@<W!E8VEF:65D(&-O;G1E;G14>7!E+@H@*@H@*B!`<&%R86T@
M<W1R:6YG("1C;VYT96YT("`@("`@5&AE(&-O;G1E;G0@;V8@=&AE(&UE;6\N
M"B`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("!7:&%T(&9O<FUA="!I
M<R!T:&4@9&%T82!I;C\@0W5R<F5N=&QY('-U<'!O<G1S.@H@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&5X="]P;&%I;@H@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&5X="]X+79N;W1E"B`J($!P87)A;2!S=')I
M;F<@)&YO=&5P860@("`@("`H;W!T:6]N86PI(%1H92!N;W1E<&%D('1O('-A
M=F4@=&AE(&UE;6\@;VXN"B`J"B`J($!R971U<FX@<W1R:6YG("!4:&4@;F5W
M(%5)1"P@;W(@9F%L<V4@;VX@9F%I;'5R92X*("HO"F9U;F-T:6]N(%]M;F5M
M;U]I;7!O<G0H)&-O;G1E;G0L("1C;VYT96YT5'EP92P@)&YO=&5P860@/2!N
M=6QL*0I["B`@("!G;&]B86P@)'!R969S.PH@("`@<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<["@H@("`@+RH@36%K92!S
M=7)E('=E(&AA=F4@82!V86QI9"!N;W1E<&%D(&%N9"!P97)M:7-S:6]N<R!T
M;R!E9&ET"B`@("`@*B!I="X@*B\*("`@(&EF("AE;7!T>2@D;F]T97!A9"DI
M('L*("`@("`@("`D;F]T97!A9"`]($UN96UO.CIG971$969A=6QT3F]T97!A
M9"A015)-4U]%1$E4*3L*("`@('T*"B`@("!I9B`H(6%R<F%Y7VME>5]E>&ES
M=',H)&YO=&5P860L($UN96UO.CIL:7-T3F]T97!A9',H9F%L<V4L(%!%4DU3
M7T5$250I*2D@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E!E<FUI<W-I;VX@1&5N:65D(BDI.PH@("`@?0H*("`@("\J($-R96%T92!A
M($UN96UO7T1R:79E<B!I;G-T86YC92X@*B\*("`@(')E<75I<F5?;VYC92!-
M3D5-3U]"05-%("X@)R]L:6(O1')I=F5R+G!H<"<["B`@("`D<W1O<F%G92`]
M("9-;F5M;U]$<FEV97(Z.G-I;F=L971O;B@D;F]T97!A9"D["@H@("`@<W=I
M=&-H("@D8V]N=&5N=%1Y<&4I('L*("`@(&-A<V4@)W1E>'0O<&QA:6XG.@H@
M("`@("`@("1N;W1E260@/2`D<W1O<F%G92T^861D*"1S=&]R86=E+3YG971-
M96UO1&5S8W)I<'1I;VXH)&-O;G1E;G0I+"`D8V]N=&5N="D["B`@("`@("`@
M8G)E86L["@H@("`@8V%S92`G=&5X="]X+79N;W1E)SH*("`@("`@("!I9B`H
M(6ES7V$H)&-O;G1E;G0L("=(;W)D95]I0V%L96YD87)?=FYO=&4G*2D@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G
M.PH@("`@("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D[
M"B`@("`@("`@("`@(&EF("@A)&E#86PM/G!A<G-E=D-A;&5N9&%R*"1C;VYT
M96YT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8V]M
M<&]N96YT<R`]("1I0V%L+3YG971#;VUP;VYE;G1S*"D["B`@("`@("`@("`@
M('-W:71C:"`H8V]U;G0H)&-O;7!O;F5N=',I*2!["B`@("`@("`@("`@(&-A
M<V4@,#H*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB*2D["@H@("`@("`@
M("`@("!C87-E(#$Z"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1C;VUP
M;VYE;G1S6S!=.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@)&ED<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D8V]M<&]N96YT<R!A<R`D8V]N=&5N
M="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1C;VYT96YT+"`G
M2&]R9&5?:4-A;&5N9&%R7W9N;W1E)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&YO=&4@/2`D<W1O<F%G92T^9G)O;6E#86QE;F1A<B@D8V]N=&5N
M="D["B`@("`@("`@("`@("`@("`@("`@("`@("1N;W1E260@/2`D<W1O<F%G
M92T^861D*"1N;W1E6R=D97-C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N;W1E6R=B;V1Y)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%E
M;7!T>2@D;F]T95LG8V%T96=O<GDG72D@/R`D;F]T95LG8V%T96=O<GDG72`Z
M("<G*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&YO=&5)
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1N;W1E260["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@)&ED<UM=(#T@)&YO=&5)9#L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!R971U<FX@)&ED<SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&YO=&4@/2`D<W1O<F%G92T^9G)O;6E#86QE;F1A<B@D8V]N
M=&5N="D["B`@("`@("`@)&YO=&5)9"`]("1S=&]R86=E+3YA9&0H)&YO=&5;
M)V1E<V,G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]T
M95LG8F]D>2==+"`A96UP='DH)&YO=&5;)V-A=&5G;W)Y)UTI(#\@)&YO=&5;
M)V-A=&5G;W)Y)UT@.B`G)RD["B`@("`@("`@8G)E86L["@H@("`@9&5F875L
M=#H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B*2PD8V]N=&5N=%1Y<&4I
M*3L*("`@('T*"B`@("!I9B`H:7-?82@D;F]T94ED+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@<F5T=7)N("1N;W1E260["B`@("!]"@H@("`@)&YO=&4@
M/2`D<W1O<F%G92T^9V5T*"1N;W1E260I.PH@("`@<F5T=7)N("1N;W1E6R=U
M:60G73L*?0H*+RHJ"B`J($5X<&]R="!A(&UE;6\L(&ED96YT:69I960@8GD@
M54E$+"!I;B!T:&4@<F5Q=65S=&5D(&-O;G1E;G14>7!E+@H@*@H@*B!`<&%R
M86T@<W1R:6YG("1U:60@("`@("`@("!)9&5N=&EF>2!T:&4@;65M;R!T;R!E
M>'!O<G0N"B`J($!P87)A;2!M:7AE9"`D8V]N=&5N=%1Y<&4@(%=H870@9F]R
M;6%T('-H;W5L9"!T:&4@9&%T82!B92!I;C\*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@16ET:&5R(&$@<W1R:6YG('=I=&@@;VYE(&]F.@H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\<')E/@H@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T97AT+W!L86EN)PH@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T97AT+W@M=FYO=&4G"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO<')E/@H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!O<B!A;B!A<G)A>2!W:71H(&]P=&EO;G,Z"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QP<F4^"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G0V]N=&5N=%1Y<&4G.B`@87,@86)O=F4*("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=%3D-/1$E.1R<Z("AO<'1I;VYA
M;"D@8VAA<F%C=&5R(&5N8V]D:6YG"B`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@<W1R:6YG<R!F:65L9',*("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=#2$%24T54)SH@("AO<'1I;VYA
M;"D@8VAA<G-E="X@3&EK92!55$8M.`H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)U9%4E-)3TXG.B`@*&]P=&EO;F%L*2!&;W)M870@=F5R<VEO
M;B`H97@N(&E#86QE;F1A<B`R+C`L('9#86QE;F1A<B`Q+C`I+@H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+W!R93X*("H*("H@0')E='5R;B!S
M=')I;F<@(%1H92!R97%U97-T960@9&%T82X*("HO"F9U;F-T:6]N(%]M;F5M
M;U]E>'!O<G0H)'5I9"P@)&-O;G1E;G14>7!E*0I["B`@("!R97%U:7)E7V]N
M8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A<V4N<&AP)SL*"B`@("`D<W1O
M<F%G92`]("9-;F5M;U]$<FEV97(Z.G-I;F=L971O;B@I.PH@("`@)&UE;6\@
M/2`D<W1O<F%G92T^9V5T0GE5240H)'5I9"D["B`@("!I9B`H:7-?82@D;65M
M;RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D;65M;SL*("`@
M('T*"B`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&UE;6];)VUE;6]L:7-T
M7VED)UTL($UN96UO.CIL:7-T3F]T97!A9',H9F%L<V4L(%!%4DU37T5$250I
M*2D@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E!E<FUI
M<W-I;VX@1&5N:65D(BDI.PH@("`@?0H*("`@("1V97)S:6]N(#T@)S$N,2<[
M"B`@("!I9B`H:7-?87)R87DH)&-O;G1E;G14>7!E*2D@>PH@("`@("`@("1O
M<'1I;VYS(#T@)&-O;G1E;G14>7!E.PH@("`@("`@("1C;VYT96YT5'EP92`]
M("1O<'1I;VYS6R=#;VYT96YT5'EP92==.PH@("`@("`@('5N<V5T*"1O<'1I
M;VYS6R=#;VYT96YT5'EP92==*3L*("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;G-;)U9%4E-)3TXG72DI('L*("`@("`@("`@("`@)'9E<G-I;VX@/2`D;W!T
M:6]N<ULG5D524TE/3B==.PH@("`@("`@("`@("!U;G-E="@D;W!T:6]N<ULG
M5D524TE/3B==*3L*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("1O
M<'1I;VYS(#T@87)R87DH*3L*("`@('T*"B`@("!S=VET8V@@*"1C;VYT96YT
M5'EP92D@>PH@("`@8V%S92`G=&5X="]P;&%I;B<Z"B`@("`@("`@<F5T=7)N
M("1M96UO6R=B;V1Y)UT["@H@("`@8V%S92`G=&5X="]X+79N;W1E)SH*("`@
M("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W9E<G-I
M;VXN<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+VE#86QE;F1A
M<BYP:'`G.PH*("`@("`@("`O+R!#<F5A=&4@=&AE(&YE=R!I0V%L96YD87(@
M8V]N=&%I;F5R+@H@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD
M87(H)'9E<G-I;VXI.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)U9%
M4E-)3TXG+"`G,2XQ)RD["B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G
M4%)/1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J96-T+R]-;F5M;R`G("X@34Y%
M34]?5D524TE/3B`N("<O+T5.)RD["B`@("`@("`@)&E#86PM/G-E=$%T=')I
M8G5T92@G34542$]$)RP@)U!50DQ)4T@G*3L*"B`@("`@("`@+R\@0W)E871E
M(&$@;F5W('9.;W1E+@H@("`@("`@("1V3F]T92`]("1S=&]R86=E+3YT;VE#
M86QE;F1A<B@D;65M;RP@)&E#86PI.PH*("`@("`@("`O+R!3970@96YC;V1I
M;F<@;W!T:6]N<R!F;W(@86QL('-T<FEN9R!V86QU97,N($9O<B!V3F]T97,L
M"B`@("`@("`@+R\@:G5S="!"3T19+@H@("`@("`@("1V3F]T92T^<V5T4&%R
M86UE=&5R*"="3T19)RP@)&]P=&EO;G,I.PH*("`@("`@("!R971U<FX@)'9.
M;W1E+3YE>'!O<G1V0V%L96YD87(H*3L*"B`@("!D969A=6QT.@H@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YS=7!P;W)T
M960@0V]N=&5N="U4>7!E.B`E<R(I+"1C;VYT96YT5'EP92DI.PH@("`@?0I]
M"@HO*BH*("H@1&5L971E(&$@;65M;R!I9&5N=&EF:65D(&)Y(%5)1"X*("H*
M("H@0'!A<F%M('-T<FEN9R!\(&%R<F%Y("1U:60@($ED96YT:69Y('1H92!N
M;W1E('1O(&1E;&5T92P@96ET:&5R(&$*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-I;F=L92!5240@;W(@86X@87)R87DN"B`J"B`J($!R971U
M<FX@8F]O;&5A;B`@4W5C8V5S<R!O<B!F86EL=7)E+@H@*B\*9G5N8W1I;VX@
M7VUN96UO7V1E;&5T92@D=6ED*0I["B`@("`O+R!(86YD;&4@86X@87)R<F%Y
M(&]F(%5)1',@9F]R(&-O;G9E;FEE;F-E(&]F(&1E;&5T:6YG(&UU;'1I<&QE
M"B`@("`O+R!N;W1E<R!A="!O;F-E+@H@("`@:68@*&ES7V%R<F%Y*"1U:60I
M*2!["B`@("`@("`@9F]R96%C:"`H)'5I9"!A<R`D=2D@>PH@("`@("`@("`@
M("`D<F5S=6QT(#T@7VUN96UO7V1E;&5T92@D=2D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!R97%U:7)E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A<V4N<&AP)SL*"B`@("`D<W1O<F%G
M92`]("9-;F5M;U]$<FEV97(Z.G-I;F=L971O;B@I.PH@("`@)&UE;6\@/2`D
M<W1O<F%G92T^9V5T0GE5240H)'5I9"D["B`@("!I9B`H:7-?82@D;65M;RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D;65M;SL*("`@('T*
M"B`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&UE;6];)VUE;6]L:7-T7VED
M)UTL($UN96UO.CIL:7-T3F]T97!A9',H9F%L<V4L(%!%4DU37T1%3$5412DI
M*2!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&5R;6ES
M<VEO;B!$96YI960B*2D["B`@("!]"@H@("`@<F5T=7)N("1S=&]R86=E+3YD
M96QE=&4H)&UE;6];)VUE;6]?:60G72D["GT*"B\J*@H@*B!297!L86-E('1H
M92!M96UO(&ED96YT:69I960@8GD@54E$('=I=&@@=&AE(&-O;G1E;G0@<F5P
M<F5S96YT960@:6X*("H@=&AE('-P96-I9FEE9"!C;VYT96YT5'EP92X*("H*
M("H@0'!A<F%M('-T<FEN9R`D=6ED("`@("`@("`@261E;F9I='D@=&AE(&UE
M;6\@=&\@<F5P;&%C92X*("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@
M(%1H92!C;VYT96YT(&]F('1H92!M96UO+@H@*B!`<&%R86T@<W1R:6YG("1C
M;VYT96YT5'EP92`@5VAA="!F;W)M870@:7,@=&AE(&1A=&$@:6X_($-U<G)E
M;G1L>2!S=7!P;W)T<SH*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1E>'0O<&QA:6X*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1E
M>'0O>"UV;F]T90H@*@H@*B!`<F5T=7)N(&)O;VQE86X@(%-U8V-E<W,@;W(@
M9F%I;'5R92X*("HO"F9U;F-T:6]N(%]M;F5M;U]R97!L86-E*"1U:60L("1C
M;VYT96YT+"`D8V]N=&5N=%1Y<&4I"GL*("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH*("`@("1S=&]R86=E(#T@
M)DUN96UO7T1R:79E<CHZ<VEN9VQE=&]N*"D["B`@("`D;65M;R`]("1S=&]R
M86=E+3YG971">55)1"@D=6ED*3L*("`@(&EF("AI<U]A*"1M96UO+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1M96UO.PH@("`@?0H*("`@
M(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D;65M;ULG;65M;VQI<W1?:60G72P@
M36YE;6\Z.FQI<W1.;W1E<&%D<RAF86QS92P@4$5235-?141)5"DI*2!["B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&5R;6ES<VEO;B!$
M96YI960B*2D["B`@("!]"@H@("`@<W=I=&-H("@D8V]N=&5N=%1Y<&4I('L*
M("`@(&-A<V4@)W1E>'0O<&QA:6XG.@H@("`@("`@(')E='5R;B`D<W1O<F%G
M92T^;6]D:69Y*"1M96UO6R=M96UO7VED)UTL("1S=&]R86=E+3YG971-96UO
M1&5S8W)I<'1I;VXH)&-O;G1E;G0I+"`D8V]N=&5N="P@;G5L;"D["@H@("`@
M8V%S92`G=&5X="]X+79N;W1E)SH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+VE#86QE;F1A<BYP:'`G.PH*("`@("`@("`O+R!#<F5A=&4@=&AE(&YE
M=R!I0V%L96YD87(@8V]N=&%I;F5R+@H@("`@("`@("1I0V%L(#T@)FYE=R!(
M;W)D95]I0V%L96YD87(H*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E
M*"=04D]$240G+"`G+2\O5&AE($AO<F1E(%!R;VIE8W0O+TUN96UO("\O14XG
M*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=-151(3T0G+"`G4%5"
M3$E32"<I.PH*("`@("`@("`O+R!#<F5A=&4@82!N97<@=DYO=&4N"B`@("`@
M("`@)'9.;W1E(#T@)DAO<F1E7VE#86QE;F1A<CHZ;F5W0V]M<&]N96YT*"=V
M;F]T92<L("1I0V%L*3L*"B`@("`@("`@:68@*"$D=DYO=&4M/G!A<G-E=D-A
M;&5N9&%R*"1C;VYT96YT*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!V3F]T92!D871A+B(I*3L*("`@("`@("!]"B`@("`@("`@)&YO=&4@/2`D
M<W1O<F%G92T^9G)O;6E#86QE;F1A<B@D=DYO=&4I.PH*("`@("`@("!R971U
M<FX@)'-T;W)A9V4M/FUO9&EF>2@D;65M;ULG;65M;U]I9"==+"`D;F]T95LG
M9&5S8R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;W1E
M6R=B;V1Y)UTL(65M<'1Y*"1N;W1E6R=C871E9V]R>2==*2`_("1N;W1E6R=C
M871E9V]R>2==(#H@)R<I.PH*("`@(&1E9F%U;'0Z"B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;G-U<'!O<G1E9"!#;VYT
M96YT+51Y<&4Z("5S(BDL)&-O;G1E;G14>7!E*2D["B`@("!]"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;6YE;6\O;&EB+V)A<V4N<&AP````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S,T,@`Q,#0Q-S,V,C<T-@`P
M,3<W,S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($UN96UO(&)A<V4@:6YC;'5S:6]N(&9I;&4N"B`J
M"B`J(%1H:7,@9FEL92!B<FEN9W,@:6X@86QL(&]F('1H92!D97!E;F1E;F-I
M97,@=&AA="!E=F5R>2!-;F5M;PH@*B!S8W)I<'0@=VEL;"!N965D(&%N9"!S
M971S('5P(&]B:F5C=',@=&AA="!A;&P@<V-R:7!T<R!U<V4N"B`J"B`J("1(
M;W)D93H@;6YE;6\O;&EB+V)A<V4N<&AP+'8@,2XT-BXQ,"XT(#(P,#8O,#,O
M,#$@,3DZ,S$Z-#,@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M
M,C`P-B!(;W)D92!0<F]J96-T("AH='1P.B\O=W=W+FAO<F1E+F]R9R\I"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A!4TPI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S
M+V%S;"YP:'`N"B`J"B`J($!S:6YC92`@($UN96UO(#$N,`H@*B!`<&%C:V%G
M92!-;F5M;PH@*B\*"B\O($-H96-K(&9O<B!A('!R:6]R(&1E9FEN:71I;VX@
M;V8@2$]21$5?0D%312`H<&5R:&%P<R!B>2!A;@HO+R!A=71O7W!R97!E;F1?
M9FEL92!D969I;FET:6]N(&9O<B!S:71E(&-U<W1O;6EZ871I;VXI+@II9B`H
M(61E9FEN960H)TA/4D1%7T)!4T4G*2D@>PH@("`@0&1E9FEN92@G2$]21$5?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PI]"@HO+R!,
M;V%D('1H92!(;W)D92!&<F%M97=O<FL@8V]R92P@86YD('-E="!U<"!I;F-L
M=7-I;VX@<&%T:',N"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O
M8V]R92YP:'`G.PH*+R\@4F5G:7-T<GDN"B1R96=I<W1R>2`]("9296=I<W1R
M>3HZ<VEN9VQE=&]N*"D["FEF("AI<U]A*"@D<'5S:&5D(#T@)')E9VES=')Y
M+3YP=7-H07!P*"=M;F5M;R<L("%D969I;F5D*"=!551(7TA!3D1,15(G*2DI
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("!I9B`H)'!U<VAE9"T^9V5T0V]D92@I
M(#T]("=P97)M:7-S:6]N7V1E;FEE9"<I('L*("`@("`@("!(;W)D93HZ875T
M:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*("`@('T*("`@($AO<F1E
M.CIF871A;"@D<'5S:&5D+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*
M?0HD8V]N9B`]("8D1TQ/0D%,4ULG8V]N9B==.PI`9&5F:6YE*"=-3D5-3U]4
M14U03$%415,G+"`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RDI.PH*+R\@
M3F]T:69I8V%T:6]N('-Y<W1E;2X*)&YO=&EF:6-A=&EO;B`]("9.;W1I9FEC
M871I;VXZ.G-I;F=L971O;B@I.PHD;F]T:69I8V%T:6]N+3YA='1A8V@H)W-T
M871U<R<I.PH*+R\@1FEN9"!T:&4@8F%S92!F:6QE('!A=&@@;V8@36YE;6\N
M"D!D969I;F4H)TU.14U/7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXG*3L*"B\O($UN96UO(&QI8G)A<FEE<RX*<F5Q=6ER95]O;F-E($U.14U/
M7T)!4T4@+B`G+VQI8B]-;F5M;RYP:'`G.PIR97%U:7)E7V]N8V4@34Y%34]?
M0D%312`N("<O;&EB+T1R:79E<BYP:'`G.PH*+R\@2&]R9&4@;&EB<F%R:65S
M+@IR97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O2&5L<"YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+TAI<W1O<GDN<&AP)SL*"B\O(%-T87)T(&-O;7!R97-S:6]N+"!I9B!R97%U
M97-T960N"DAO<F1E.CIC;VUP<F5S<T]U='!U="@I.PH*+R\@0W)E871E(&$@
M<VAA<F4@:6YS=&%N8V4N"G)E<75I<F5?;VYC92`G2&]R9&4O4VAA<F4N<&AP
M)SL*)$=,3T)!3%-;)VUN96UO7W-H87)E<R==(#T@)DAO<F1E7U-H87)E.CIS
M:6YG;&5T;VXH)')E9VES=')Y+3YG971!<'`H*2D["@HO+R!5<&1A=&4@=&AE
M('!R969E<F5N8V4@9F]R('=H:6-H(&YO=&5P861S('1O(&1I<W!L87DN($EF
M('1H92!U<V5R"B\O(&1O97-N)W0@:&%V92!A;GD@<V5L96-T960@;F]T97!A
M9',@9F]R('9I97<@=&AE;B!F86QL(&)A8VL@=&\@<V]M90HO+R!A=F%I;&%B
M;&4@;F]T97!A9"X*)$=,3T)!3%-;)V1I<W!L87E?;F]T97!A9',G72`]('5N
M<V5R:6%L:7IE*"1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G9&ES<&QA
M>5]N;W1E<&%D<R<I*3L*:68@*"@D9%]N;W1E(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V1I<W!L87E?;F]T97!A9"<I*2`A/3T@;G5L;"D@>PH@("`@:68@*&EN
M7V%R<F%Y*"1D7VYO=&4L("1'3$]"04Q36R=D:7-P;&%Y7VYO=&5P861S)UTI
M*2!["B`@("`@("`@)&ME>2`](&%R<F%Y7W-E87)C:"@D9%]N;W1E+"`D1TQ/
M0D%,4ULG9&ES<&QA>5]N;W1E<&%D<R==*3L*("`@("`@("!U;G-E="@D1TQ/
M0D%,4ULG9&ES<&QA>5]N;W1E<&%D<R==6R1K97E=*3L*("`@('T@96QS92![
M"B`@("`@("`@)$=,3T)!3%-;)V1I<W!L87E?;F]T97!A9',G75M=(#T@)&1?
M;F]T93L*("`@('T*("`@("1'3$]"04Q36R=P<F5F<R==+3YS971686QU92@G
M9&ES<&QA>5]N;W1E<&%D<R<L('-E<FEA;&EZ92@D1TQ/0D%,4ULG9&ES<&QA
M>5]N;W1E<&%D<R==*2D["GT*"B\O($UA:V4@<W5R92!A;&P@=&%S:R!L:7-T
M<R!E>&ES="!N;W<L('1O('-A=F4@;VX@8VAE8VMI;F<@;&%T97(N"B1?=&5M
M<"`]("1'3$]"04Q36R=D:7-P;&%Y7VYO=&5P861S)UT["B1?86QL(#T@36YE
M;6\Z.FQI<W1.;W1E<&%D<R@I.PHD1TQ/0D%,4ULG9&ES<&QA>5]N;W1E<&%D
M<R==(#T@87)R87DH*3L*9F]R96%C:"`H)%]T96UP(&%S("1I9"D@>PH@("`@
M:68@*&ES<V5T*"1?86QL6R1I9%TI*2!["B`@("`@("`@)$=,3T)!3%-;)V1I
M<W!L87E?;F]T97!A9',G75M=(#T@)&ED.PH@("`@?0I]"@II9B`H8V]U;G0H
M)$=,3T)!3%-;)V1I<W!L87E?;F]T97!A9',G72D@/3T@,"D@>PH@("`@)&QI
M<W1S(#T@36YE;6\Z.FQI<W1.;W1E<&%D<RAT<G5E*3L*("`@(&EF("@A075T
M:#HZ9V5T075T:"@I*2!["B`@("`@("`@+R\@06QL(&YO=&5P861S(&9O<B!G
M=65S=',N"B`@("`@("`@)$=,3T)!3%-;)V1I<W!L87E?;F]T97!A9',G72`]
M(&%R<F%Y7VME>7,H)&QI<W1S*3L*("`@('T@96QS96EF("@A8V]U;G0H)&QI
M<W1S*2D@>PH@("`@("`@("\O($-R96%T92!A('!E<G-O;F%L(&UE;6\@;&ES
M=`H@("`@("`@("1'3$]"04Q36R=D:7-P;&%Y7VYO=&5P861S)UT@/2!A<G)A
M>2A!=71H.CIG971!=71H*"DI.PH*("`@("`@("`O+R!)9B!T:&ES('-H87)E
M(&1O97-N)W0@97AI<W0@=&AE;B!C<F5A=&4@:70N"B`@("`@("`@:68@*"$D
M1TQ/0D%,4ULG;6YE;6]?<VAA<F5S)UTM/F5X:7-T<RA!=71H.CIG971!=71H
M*"DI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I
M='DN<&AP)SL*("`@("`@("`@("`@)&ED96YT:71Y(#T@)DED96YT:71Y.CIS
M:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&YA;64@/2`D:61E;G1I='DM/F=E
M=%9A;'5E*"=F=6QL;F%M92<I.PH@("`@("`@("`@("!I9B`H=')I;2@D;F%M
M92D@/3T@)R<I('L*("`@("`@("`@("`@("`@("1N86UE(#T@075T:#HZ<F5M
M;W9E2&]O:RA!=71H.CIG971!=71H*"DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1S:&%R92`]("8D1TQ/0D%,4ULG;6YE;6]?<VAA<F5S)UTM/FYE
M=U-H87)E*$%U=&@Z.F=E=$%U=&@H*2D["B`@("`@("`@("`@("1S:&%R92T^
M<V5T*"=N86UE)RP@<W!R:6YT9BA?*"(E<R=S($YO=&5P860B*2P@)&YA;64I
M*3L*("`@("`@("`@("`@)$=,3T)!3%-;)VUN96UO7W-H87)E<R==+3YA9&13
M:&%R92@D<VAA<F4I.PH@("`@("`@('T*("`@('T*?0H*)$=,3T)!3%-;)W!R
M969S)UTM/G-E=%9A;'5E*"=D:7-P;&%Y7VYO=&5P861S)RP@<V5R:6%L:7IE
M*"1'3$]"04Q36R=D:7-P;&%Y7VYO=&5P861S)UTI*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&EB+W!R969S
M+G!H<```````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C`P,``Q,#0Q-S,V,C<T-@`P,C`Q,C0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@;6YE
M;6\O;&EB+W!R969S+G!H<"QV(#$N,BXQ,"XT(#(P,#8O,#$O,#$@,C$Z,CDZ
M,#8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!
M4TPI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!-;F5M;R`R+C`*("H@0'!A8VMA9V4@36YE;6\*("HO"@IF
M=6YC=&EO;B!H86YD;&5?;F]T97!A9'-E;&5C="@D=7!D871E9"D*>PH@("`@
M9VQO8F%L("1P<F5F<SL*"B`@("`D9&5F875L=%]N;W1E<&%D(#T@571I;#HZ
M9V5T1F]R;41A=&$H)V1E9F%U;'1?;F]T97!A9"<I.PH@("`@:68@*"%I<U]N
M=6QL*"1D969A=6QT7VYO=&5P860I*2!["B`@("`@("`@)&YO=&5P861S(#T@
M36YE;6\Z.FQI<W1.;W1E<&%D<R@I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M;F]T97!A9',I("8F(&%R<F%Y7VME>5]E>&ES=',H)&1E9F%U;'1?;F]T97!A
M9"P@)&YO=&5P861S*2D@>PH@("`@("`@("`@("`D<')E9G,M/G-E=%9A;'5E
M*"=D969A=6QT7VYO=&5P860G+"`D9&5F875L=%]N;W1E<&%D*3L*("`@("`@
M("`@("`@)'5P9&%T960@/2!T<G5E.PH@("`@("`@('T*("`@('T*("`@(')E
M='5R;B`D=7!D871E9#L*?0H*9G5N8W1I;VX@:&%N9&QE7W-H;W=S=6UM87)Y
M<V5L96-T*"1U<&1A=&5D*0I["B`@("!G;&]B86P@)'!R969S.PH*("`@("1S
M=6UM87)Y7V-A=&5G;W)I97,@/2!5=&EL.CIG971&;W)M1&%T82@G<W5M;6%R
M>5]C871E9V]R:65S)RD["B`@("`D<')E9G,M/G-E=%9A;'5E*"=S=6UM87)Y
M7V-A=&5G;W)I97,G+"`D<W5M;6%R>5]C871E9V]R:65S*3L*("`@(')E='5R
M;B!T<G5E.PI]"BXO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;&EB
M+W9E<G-I;VXN<&AP````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`U-0`Q,#0Q-S,V,C<T-@`P,C`U,#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`@9&5F:6YE*"=-3D5-
M3U]615)324].)RP@)T@S("@R+C$I)RD@/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W1E;7!L871E<R\`````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-#8`,#$W-3,W`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE
M;6\O=&5M<&QA=&5S+W9I97<O````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-@`P,C`U,3$`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]M;F5M;R]T96UP;&%T97,O=FEE=R]M96UO+FEN8P``
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,C4T`#$P-#$W,S8R-S0V
M`#`R,C$T,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HD;65M;W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@G;65M
M;RYP:'`G+"!A<G)A>2@G;65M;R<@/3X@)&UE;6]?:60L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M96UO;&ES
M="<@/3X@)&UE;6]L:7-T7VED*2D["@HD<VAA<F4@/2`D1TQ/0D%,4ULG;6YE
M;6]?<VAA<F5S)UTM/F=E=%-H87)E*"1M96UO;&ES=%]I9"D["C\^"CQD:78@
M8VQA<W,](FAE861E<B(^"B`\<W!A;B!C;&%S<STB<VUA;&QH96%D97(B('-T
M>6QE/2)F;&]A=#IR:6=H="(^"B`\/W!H<"!I9B`H(21P<FEN=%]V:65W*2`Z
M(#\^"B`\/W!H<"!I9B`H)'-H87)E+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E
M=$%U=&@H*2P@4$5235-?141)5"DI.B`_/@H@("`\/W!H<"!E8VAO($AO<F1E
M.CIW:61G970H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*%5T:6PZ.F%D9%!A<F%M
M971E<B@D;65M;W5R;"P@)V%C=&EO;DE$)RP@)VUO9&EF>5]M96UO)RDI+"!?
M*")%9&ET(BDL("=S;6%L;&AE861E<B<L("<G+"`G)RP@7R@B7T5D:70B*2D@
M/SX*("`@?`H@/#]P:'`@96YD:68[(#\^"B`\/W!H<"!I9B`H)'-H87)E+3YH
M87-097)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H*2P@4$5235-?1$5,151%*2DZ
M(#\^"B`@(#P_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="A(;W)D93HZ87!P;&EC
M871I;VY5<FPH571I;#HZ861D4&%R86UE=&5R*"1M96UO=7)L+"`G86-T:6]N
M240G+"`G9&5L971E7VUE;6]S)RDI+"!?*")$96QE=&4B*2P@)W-M86QL:&5A
M9&5R)RP@)R<L("1P<F5F<RT^9V5T5F%L=64H)V1E;&5T95]O<'0G*2`_("=R
M971U<FX@=VEN9&]W+F-O;F9I<FTH7"<G("X@861D<VQA<VAE<RA?*")296%L
M;'D@9&5L971E('1H:7,@;F]T93\B*2D@+B`G7"<I.R<@.B`G)RP@7R@B7T1E
M;&5T92(I*2`_/@H@("!\"B`\/W!H<"!E;F1I9CL@/SX*(#P_<&AP(&5C:&\@
M2&]R9&4Z.G=I9&=E="A(;W)D93HZ87!P;&EC871I;VY5<FPH)VQI<W0N<&AP
M)RDL(%\H(D)A8VL@=&\@3F]T97!A9"(I+"`G<VUA;&QH96%D97(G+"`G)RP@
M)R<L(%\H(E]"86-K('1O($YO=&5P860B*2D@/SXF;F)S<#LF;F)S<#L*(#P_
M<&AP(&5N9&EF.R`_/@H@/"]S<&%N/@H@/#]P:'`@96-H;R!?*").;W1E($1E
M=&%I;',B*2`_/@H\+V1I=CX*"CQT86)L92!C96QL<W!A8VEN9STB,"(@=VED
M=&@](C$P,"4B(&-L87-S/2)H96%D97)B;W@@<W1R:7!E9"!N;W=R87`B/@H\
M='(^"B`@/'1D(&%L:6=N/2)R:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H
M(D-A=&5G;W)Y(BD@/SX\+W-T<F]N9SXF;F)S<#L\+W1D/@H@(#QT9"!W:61T
M:#TB,3`P)2(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1M96UO6R=C
M871E9V]R>2==(#\@)&UE;6];)V-A=&5G;W)Y)UT@.B!?*")5;F9I;&5D(BDI
M(#\^/"]T9#X*/"]T<CX*"CP_<&AP(&EF("AI<W-E="@D8W)E871E9"DI.B`_
M/@H\='(^"B`@/'1D(&%L:6=N/2)R:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO
M(%\H(D-R96%T960B*2`_/CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@/'1D/CP_
M<&AP(&5C:&\@<W1R9G1I;64H)'!R969S+3YG971686QU92@G9&%T95]F;W)M
M870G*2P@)&-R96%T960I("X@)R`G("X@9&%T92@D<')E9G,M/F=E=%9A;'5E
M*"=T=V5N='E&;W5R)RD@/R`G1SII)R`Z("=G.FD@82<L("1C<F5A=&5D*2`_
M/CPO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H*/#]P:'`@:68@*&ES<V5T
M*"1M;V1I9FEE9"DI.B`_/@H\='(^"B`@/'1D(&%L:6=N/2)R:6=H="(^/'-T
M<F]N9SX\/W!H<"!E8VAO(%\H(DQA<W0@36]D:69I960B*2`_/CPO<W1R;VYG
M/B9N8G-P.SPO=&0^"B`@/'1D/CP_<&AP(&5C:&\@<W1R9G1I;64H)'!R969S
M+3YG971686QU92@G9&%T95]F;W)M870G*2P@)&UO9&EF:65D*2`N("<@)R`N
M(&1A=&4H)'!R969S+3YG971686QU92@G='=E;G1Y1F]U<B<I(#\@)T<Z:2<@
M.B`G9SII(&$G+"`D;6]D:69I960I(#\^/"]T9#X*/"]T<CX*/#]P:'`@96YD
M:68[(#\^"@H\='(^"B`@/'1D('9A;&EG;CTB=&]P(B!A;&EG;CTB<FEG:'0B
M/CQS=')O;F<^/#]P:'`@96-H;R!?*").;W1E(%1E>'0B*2`_/CPO<W1R;VYG
M/B9N8G-P.SPO=&0^"B`@/'1D(&-L87-S/2)F:7AE9"(^/#]P:'`@96-H;R!4
M97AT7T9I;'1E<CHZ9FEL=&5R*"1M96UO6R=B;V1Y)UTL("=T97AT,FAT;6PG
M+"!A<G)A>2@G<&%R<V5L979E;"<@/3X@5$585%](5$U,7TU)0U)/*2D@/SX\
M+W1D/@H\+W1R/@H\+W1A8FQE/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]T96UP;&%T97,O9&%T
M82\`````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S0V`#`R,#0U,``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN
M96UO+W1E;7!L871E<R]D871A+VEM<&]R="YI;F,`````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,W-38`,3`T,3<S-C(W-#8`,#(R-#8U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#QF;W)M(&UE=&AO
M9#TB<&]S="(@;F%M93TB:6UP;W)T7V9O<FTB(&5N8W1Y<&4](FUU;'1I<&%R
M="]F;W)M+61A=&$B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)V1A=&$N<&AP)RD@/SXB/@H\:6YP=70@='EP93TB:&ED9&5N
M(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D;F5X=%]S=&5P*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB:6UP;W)T7W-T97`B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I
M)&EM<&]R=%]S=&5P(#\^(B`O/@H\=&%B;&4@8V5L;'-P86-I;F<](C`B(&-E
M;&QP861D:6YG/2(P(B!B;W)D97(](C`B('=I9'1H/2(Q,#`E(CX*/'1R/@H@
M("`@/'1D/@H@("`@("`@(#QT86)L92!C96QL<&%D9&EN9STB,R(@8V5L;'-P
M86-I;F<](C`B(&)O<F1E<CTB,"(@=VED=&@](C$P,"4B/@H@("`@("`@(#QT
M<CX\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@<')I
M;G1F*%\H(DEM<&]R="!.;W1E<RP@4W1E<"`E9"(I+"`H:6YT*21I;7!O<G1?
M<W1E<"D@/SX\+W1D/@H@("`@("`@(#PO='(^/"]T86)L93X*("`@(#PO=&0^
M"CPO='(^"CQT<CX*("`@(#QT9"!C;&%S<STB:71E;2(^"B`@("`\=&%B;&4@
M8F]R9&5R/2(P(CX\='(^/'1D/@H@("`@("`@(#P_<&AP(&5C:&\@7R@B4V5L
M96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(I(#\^/&)R("\^
M"B`@("`@("`@/'-E;&5C="!N86UE/2)I;7!O<G1?9F]R;6%T(CX*("`@("`@
M("`@("`@/&]P=&EO;B!V86QU93TB8W-V(CX\/W!H<"!E8VAO(%\H(D-35B(I
M(#\^/"]O<'1I;VX^"B`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](G9N;W1E
M(CX\/W!H<"!E8VAO(%\H(G9.;W1E(BD@/SX\+V]P=&EO;CX*("`@("`@("`\
M+W-E;&5C=#X\8G(@+SX*"CP_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G
M9&5F875L=%]N;W1E<&%D)RD@)B8@8V]U;G0H)&YO=&5P861S(#T@36YE;6\Z
M.FQI<W1.;W1E<&%D<RAF86QS92P@4$5235-?141)5"DI(#X@,2DZ(#\^"B`@
M("`@("`@/&)R("\^/#]P:'`@96-H;R!?*")7:&EC:"!.;W1E<&%D('-H;W5L
M9"!T:&4@;F]T97,@8F4@861D960@=&\_(BD@/SX\8G(@+SX*("`@("`@("`\
M<V5L96-T(&ED/2)N;W1E<&%D7W1A<F=E="(@;F%M93TB;F]T97!A9%]T87)G
M970B/@H@("`@("`@(#P_<&AP"B`@("`@("`@)&1E9F%U;'0@/2!-;F5M;SHZ
M9V5T1&5F875L=$YO=&5P860H4$5235-?141)5"D["B`@("`@("`@9F]R96%C
M:"`H)&YO=&5P861S(&%S("1I9"`]/B`D;F]T97!A9"D@>PH@("`@("`@("`@
M("`D<V5L(#T@*"1I9"`]/2`D9&5F875L="D@/R`G('-E;&5C=&5D/2)S96QE
M8W1E9"(G(#H@)R<["B`@("`@("`@("`@('!R:6YT9B@G/&]P=&EO;B!V86QU
M93TB)7,B)7,^)7,\+V]P=&EO;CXG+`H@("`@("`@("`@("`@("`@("`@:'1M
M;'-P96-I86QC:&%R<R@D:60I+"`D<V5L+"!H=&UL<W!E8VEA;&-H87)S*"1N
M;W1E<&%D+3YG970H)VYA;64G*2DI("X@(EQN(CL*("`@("`@("!](#\^"B`@
M("`@("`@/"]S96QE8W0^/&)R("\^"CP_<&AP(&5L<V4Z(#\^"B`@("`@("`@
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB;F]T97!A9%]T87)G970B('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H36YE;6\Z.F=E=$1E
M9F%U;'1.;W1E<&%D*%!%4DU37T5$250I*2`_/B(@+SX*/#]P:'`@96YD:68[
M(#\^"B`@("`@("`@/&)R("\^"@H@("`@("`@(#P_<&AP(&5C:&\@7R@B4V5L
M96-T('1H92!F:6QE('1O(&EM<&]R=#HB*2`_/CQB<B`O/@H@("`@("`@(#QI
M;G!U="!T>7!E/2)F:6QE(B!N86UE/2)I;7!O<G1?9FEL92(@8VQA<W,](F9I
M>&5D(B!S:7IE/2(T,"(@+SX*("`@("`@("`\8G(@+SX\8G(@+SX*("`@("`@
M("`\:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*").
M97AT(BD@/SXB(&-L87-S/2)B=71T;VXB("\^"B`@("`\+W1D/CPO='(^/"]T
M86)L93X*("`@(#PO=&0^"CPO='(^"CPO=&%B;&4^"CPO9F]R;3X*````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q-3(R`#$P-#$W,S8R-S0V`#`R,C0V,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\9F]R;2!M971H;V0](G!O
M<W0B(&YA;64](F5X<&]R="(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CID
M;W=N;&]A9%5R;"A?*")N;W1E<RYC<W8B*2P@;G5L;"P@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=D871A+G!H<"<I*2`_/B(^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB97AP;W)T(B`O/@H\8G(@+SX*
M/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!C96QL<&%D9&EN9STB,"(@8F]R9&5R
M/2(P(B!W:61T:#TB,3`P)2(^"CQT<CX*("`@(#QT9#X*("`@("`@("`\=&%B
M;&4@8V5L;'!A9&1I;F<](C,B(&-E;&QS<&%C:6YG/2(P(B!B;W)D97(](C`B
M('=I9'1H/2(Q,#`E(CX*("`@("`@("`\='(^/'1D(&-L87-S/2)H96%D97(B
M(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B17AP;W)T($YO=&5S(BD@
M/SX\+W1D/@H@("`@("`@(#PO='(^/"]T86)L93X*("`@(#PO=&0^"CPO='(^
M"CQT<CX*("`@(#QT9"!C;&%S<STB:71E;2(^"B`@("`\=&%B;&4@8F]R9&5R
M/2(P(CX\='(^/'1D/@H@("`@("`@(#P_<&AP(&5C:&\@7R@B4V5L96-T('1H
M92!E>'!O<G0@9F]R;6%T.B(I(#\^/&)R("\^"B`@("`@("`@/'-E;&5C="!N
M86UE/2)E>'!O<G1)1"(^"B`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](CP_
M<&AP(&5C:&\@15A03U)47T-35B`_/B(^0U-6/"]O<'1I;VX^"B`@("`@("`@
M/"]S96QE8W0^/&)R("\^/&)R("\^"B`@("`@("`@/&EN<'5T('1Y<&4](G-U
M8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B17AP;W)T(BD@/SXB(&-L87-S
M/2)B=71T;VXB("\^"B`@("`\+W1D/CPO='(^/"]T86)L93X*("`@(#PO=&0^
M"CPO='(^"CPO=&%B;&4^"CPO9F]R;3X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M
M;F5M;R]T96UP;&%T97,O;&ES="\`````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0V`#`R,#4Q,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VUN96UO+W1E;7!L871E<R]L:7-T+VUE;6]?9F]O
M=&5R<RYI;F,`````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,C(`,3`T,3<S-C(W
M-#8`,#(S-C<R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#PO=&)O9'D^"CPO=&%B;&4^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]M;F5M;R]T96UP;&%T97,O;&ES="]M96UO7W-U;6UA<FEE<RYI;F,`
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3`V`#$P-#$W,S8R-S0V`#`R-#(R-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````@/'1R
M/@H@(#QT9#X*/#]P:'`*:68@*"%I<U]A*"1S:&%R92P@)U!%05)?17)R;W(G
M*2`F)B`D<VAA<F4M/FAA<U!E<FUI<W-I;VXH075T:#HZ9V5T075T:"@I+"!0
M15)-4U]%1$E4*2D@>PH@("`@)&QA8F5L(#T@<W!R:6YT9BA?*")%9&ET(%PB
M)7-<(B(I+"`D;65M;ULG9&5S8R==*3L*("`@(&5C:&\@2&]R9&4Z.FQI;FLH
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*%5T:6PZ.F%D9%!A<F%M971E<B@D;65M
M;W5R;"P@)V%C=&EO;DE$)RP@)VUO9&EF>5]M96UO)RDI+"`D;&%B96PI("X*
M("`@("`@("!(;W)D93HZ:6UG*"=E9&ET+G!N9R<L("1L86)E;"P@)R<L("1R
M96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PI]"C\^
M"B`@/"]T9#X*("`\=&0^"B`@(#P_<&AP(&5C:&\@2&]R9&4Z.FQI;FM4;V]L
M=&EP*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D=FEE=W5R;"DL("<G+"`G)RP@
M)R<L("<G+"`H)&UE;6];)V)O9'DG72`A/2`D;65M;ULG9&5S8R==*2`_('=O
M<F1W<F%P*"1M96UO6R=B;V1Y)UTI(#H@)R<I("X@*"@A96UP='DH)&UE;6];
M)V1E<V,G72D@?'P@)&UE;6];)V1E<V,G72`]/2`G,"<I(#\@:'1M;'-P96-I
M86QC:&%R<R@D;65M;ULG9&5S8R==*2`Z("<\96T^)R`N(%\H(D5M<'1Y($YO
M=&4B*2`N("<\+V5M/B<I(#\^/"]A/@H@(#PO=&0^"B`@/'1D('-T>6QE/2)B
M86-K9W)O=6YD.CP_<&AP(&5C:&\@)&-O;&]R(#\^.R!C;VQO<CH\/W!H<"!E
M8VAO("1F9V-O;&]R(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&UE;6];)V-A=&5G;W)Y)UT@/R`D;65M;ULG8V%T96=O<GDG72`Z(%\H(E5N
M9FEL960B*2D@/SX\+W1D/@H@/"]T<CX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]M;F5M;R]T96UP;&%T97,O;&ES="]E;7!T>2YI;F,`````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S$R`#$P-#$W,S8R-S0V`#`R
M,C,S-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\=&%B;&4@=VED=&@](C$P,"4B(&)O<F1E<CTB,"(@8V5L;'!A9&1I;F<]
M(C`B(&-E;&QS<&%C:6YG/2(P(B!S='EL93TB<&%D9&EN9RUR:6=H=#HU<'@[
M(CX*(#QT<CX*("`\=&0@8VQA<W,](G1E>'0B/CQE;3X\/W!H<"!E8VAO(%\H
M(DYO(&YO=&5S(&UA=&-H('1H92!C=7)R96YT(&-R:71E<FEA+B(I(#\^/"]E
M;3X\+W1D/@H@/"]T<CX*/"]T86)L93X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;6YE;6\O=&5M<&QA=&5S+VQI<W0O;65M;U]H96%D97)S+FEN8P``````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#<V,P`Q,#0Q-S,V,C<T-@`P,C,V-#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`@)'-O
M<G1D:7)C;&%S<R`]("1S;W)T9&ER(#\@)W-O<G1U<"<@.B`G<V]R=&1O=VXG
M(#\^"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"G9A
M<B!04D5&4U]54$1!5$5?5$E-14]55#L*"F9U;F-T:6]N('1A8FQE7W-O<G1#
M86QL8F%C:RAT86)L94ED+"!C;VQU;6XL('-O<G1$;W=N*0I["B`@("!I9B`H
M='EP96]F(%!214937U501$%415]424U%3U54("$](")U;F1E9FEN960B*2![
M"B`@("`@("`@=VEN9&]W+F-L96%R5&EM96]U="A04D5&4U]54$1!5$5?5$E-
M14]55"D["B`@("!]"@H@("`@4%)%1E-?55!$051%7U1)345/550@/2!W:6YD
M;W<N<V5T5&EM96]U="@G9&]0<F5F<U5P9&%T92@B)R`K(&-O;'5M;B`K("<B
M+"`B)R`K('-O<G1$;W=N("L@)R(I)RP@,S`P*3L*?0H*9G5N8W1I;VX@9&]0
M<F5F<U5P9&%T92AC;VQU;6XL('-O<G1$;W=N*0I["B`@("`O+R!!8F]R="!I
M9B!T:&5R92!I<R!N;R!H='1P8VQI96YT('-U<'!O<G0N"B`@("!I9B`H='EP
M96]F*$A45%!#;&EE;G0I("$]("=F=6YC=&EO;B<I('L*("`@("`@("!R971U
M<FX["B`@("!]"@H@("`@8F%S975R;"`]("<\/W!H<"!E8VAO($AO<F1E.CIU
M<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<G!C
M+G!H<#]R97-T0V%L;#UH;W)D92]S9710<F5F97)E;F-E)RP@=')U92D@/SXG
M.PH@("`@=')Y('L*("`@("`@("!C;&EE;G0@/2!N97<@2%144$-L:65N="@I
M.PH@("`@("`@(&-L:65N="YI;FET*&)A<V5U<FP@*R`G)G!R968]<V]R=&)Y
M)F%P<#UM;F5M;R9V86QU93TG("L@96YC;V1E55))0V]M<&]N96YT*&-O;'5M
M;BYS=6)S=')I;F<H,2DI*3L*("`@("`@("!C;&EE;G0N87-Y;F-'150H*3L*
M"B`@("`@("`@8VQI96YT(#T@;F5W($A45%!#;&EE;G0H*3L*("`@("`@("!C
M;&EE;G0N:6YI="AB87-E=7)L("L@)R9P<F5F/7-O<G1D:7(F87!P/6UN96UO
M)G9A;'5E/2<@*R!E;F-O9&554DE#;VUP;VYE;G0H<V]R=$1O=VXI*3L*("`@
M("`@("!C;&EE;G0N87-Y;F-'150H*3L*("`@('T@8V%T8V@@*&4I('M]"GT*
M"B\O("TM/@H\+W-C<FEP=#X*"CQT86)L92!W:61T:#TB,3`P)2(@:60](FUE
M;6]S(B!C96QL<W!A8VEN9STB,"(@8VQA<W,](G-O<G1A8FQE(&QI;F5D4F]W
M(&YO=W)A<"(^"CQT:&5A9#X*(#QT<B!C;&%S<STB:71E;2(^"B`@/'1H(&-L
M87-S/2)L969T06QI9VX@;F]S;W)T(B!W:61T:#TB,R4B/CP_<&AP(&5C:&\@
M2&]R9&4Z.FEM9R@G961I="YP;F<G+"!?*")%9&ET($YO=&4B*2P@)R<L("1R
M96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]T:#X*("`\=&@@
M:60](G,\/W!H<"!E8VAO($U.14U/7U-/4E1?1$530R`_/B(@8VQA<W,](FQE
M9G1!;&EG;CP_<&AP(&5C:&\@*"1S;W)T8GD@/3T@34Y%34]?4T]25%]$15-#
M*2`_("<@)R`N("1S;W)T9&ER8VQA<W,@.B`G)R`_/B(@=VED=&@](C@R)2(^
M"B`@("`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*%5T:6PZ.F%D9%!A<F%M971E<B@G;&ES="YP:'`G+"`G<V]R=&)Y
M)RP@34Y%34]?4T]25%]$15-#*2DL(%\H(E-O<G0@8GD@3F]T92!497AT(BDL
M("=S;W)T;&EN:R<L("<G+"`G)RP@7R@B3F]?=&4B*2D@/SX*("`\+W1H/@H@
M(#QT:"!I9#TB<SP_<&AP(&5C:&\@34Y%34]?4T]25%]#051%1T]262`_/B(@
M8VQA<W,](FQE9G1!;&EG;CP_<&AP(&5C:&\@*"1S;W)T8GD@/3T@34Y%34]?
M4T]25%]#051%1T]262D@/R`G("<@+B`D<V]R=&1I<F-L87-S(#H@)R<@/SXB
M('=I9'1H/2(Q-24B/@H@("`@/#]P:'`*("`@(&5C:&\@2&]R9&4Z.G=I9&=E
M="A(;W)D93HZ87!P;&EC871I;VY5<FPH571I;#HZ861D4&%R86UE=&5R*"=L
M:7-T+G!H<"<L("=S;W)T8GDG+"!-3D5-3U]33U)47T-!5$5'3U)9*2DL(%\H
M(E-O<G0@8GD@0V%T96=O<GDB*2P@)W-O<G1L:6YK)RP@)R<L("<G+"!?*")?
M0V%T96=O<GDB*2D["B`@("!I9B`H075T:#HZ9V5T075T:"@I("8F("@A)$=,
M3T)!3%-;)W!R969S)UTM/FES3&]C:V5D*"=C871E9V]R:65S)RD@?'P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("$D1TQ/0D%,4ULG<')E9G,G72T^
M:7-,;V-K960H)V-A=&5G;W)Y7V-O;&]R<R<I*2D@>PH@("`@("`@("1C871E
M9V]R>55R;"`](%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ=7)L*"1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O
M<V5R=FEC97,O<')E9G,N<&AP)RDL(&%R<F%Y*"=A<'`G(#T^("=H;W)D92<L
M("=G<F]U<"<@/3X@)V-A=&5G;W)I97,G*2D["B`@("`@("`@96-H;R`G("<@
M+B!(;W)D93HZ;&EN:R@D8V%T96=O<GE5<FPL(%\H(D5D:70@8V%T96=O<FEE
M<R!A;F0@8V]L;W)S(BDL("<G+"`G7V)L86YK)RD@+B!(;W)D93HZ:6UG*"=C
M;VQO<G!I8VME<BYP;F<G+"!?*")%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R
M<R(I+"`G)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*2`N("<\+V$^)SL*("`@('T*("`@(#\^"B`@/"]T:#X*(#PO='(^
M"CPO=&AE860^"CQT8F]D>3X*`````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;6YE;6\O=&5M<&QA=&5S+VQI<W0O:&5A9&5R+FEN8P``
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<S,@`Q,#0Q-S,V,C<T-@`P
M,C(T,S0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/&1I=B!C;&%S<STB:&5A9&5R(CX*(#QS<&%N(&-L87-S/2)R:6=H=$9L
M;V%T(CX*("`\<W1R;VYG/CP_<&AP(&EF("AC;W5N="@D;65M;W,I(#T](#$I
M('L@96-H;R!?*"(Q(&YO=&4B*3L@?2!E;'-E:68@*&-O=6YT*"1M96UO<RD@
M/3T@,"D@>R!E8VAO(%\H(DYO(&YO=&5S(BD[('T@96QS92![('!R:6YT9BA?
M*"(E9"!N;W1E<R(I+"!C;W5N="@D;65M;W,I*3L@?2`_/CPO<W1R;VYG/@H@
M/"]S<&%N/@H@/#]P:'`@96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC
M871I;VY5<FPH)VQI<W0N<&AP)RDL(%\H(E)E9G)E<V@@3&ES="(I*2`N"B`@
M("`@("`@("`@($AO<F1E.CII;6<H)W)E;&]A9"YP;F<G+"!?*")2969R97-H
M($QI<W0B*2P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI
M(#\^/"]A/@H@/'-T<F]N9SX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'1I=&QE*2`_/CPO<W1R;VYG/@H\+V1I=CX*````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VUN96UO+W1E;7!L871E<R]S96%R8V@O````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#8`,#(Q,#`T`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4U-``Q,#0Q-S,V
M,C<T-@`P,C(W-#<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)M96UO(B!E;F-T
M>7!E/2)M=6QT:7!A<G0O9F]R;2UD871A(B!A8W1I;VX](CP_<&AP(&5C:&\@
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L:7-T+G!H<"<I(#\^(CX*/&EN<'5T
M('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)S96%R8VA?
M;65M;W,B("\^"CQT86)L92!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B
M/@H\='(^/'1D(&%L:6=N/2)L969T(B!C;&%S<STB:&5A9&5R(CX\<W1R;VYG
M/CP_<&AP(&5C:&\@7R@B4V5A<F-H(BD@/SX\+W-T<F]N9SX\+W1D/CPO='(^
M/"]T86)L93X*"CQT86)L92!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B
M/@H\='(^"B`@/'1D(&-L87-S/2)I=&5M(B!A;&EG;CTB<FEG:'0B('9A;&EG
M;CTB=&]P(B!N;W=R87`](FYO=W)A<"(^"B`@("`\<W1R;VYG/CP_<&AP(&5C
M:&\@2&]R9&4Z.FQA8F5L*"=S96%R8VA?<&%T=&5R;B<L(%\H(E-E87)C:"!?
M5&5X="(I*2`_/CH\+W-T<F]N9SXF;F)S<#L*("`\+W1D/@H@(#QT9"!C;&%S
M<STB:71E;2(@=VED=&@](C$P,"4B/@H@("`@/&EN<'5T(&YA;64](G-E87)C
M:%]P871T97)N(B!I9#TB<V5A<F-H7W!A='1E<FXB('1Y<&4](G1E>'0B('9A
M;'5E/2(B('-I>F4](C4P(B!M87AL96YG=&@](C$P,"(@+SX*("`\+W1D/@H\
M+W1R/@H\='(^"B`@/'1D(&-L87-S/2)I=&5M(B!A;&EG;CTB<FEG:'0B('9A
M;&EG;CTB=&]P(B!N;W=R87`](FYO=W)A<"(^"B`@("`\<W1R;VYG/CP_<&AP
M(&5C:&\@7R@B4V5A<F-H(%-C;W!E(BD@/SXZ/"]S=')O;F<^)FYB<W`["B`@
M/"]T9#X*("`\=&0@8VQA<W,](FET96TB('=I9'1H/2(Q,#`E(CX*("`@(#QI
M;G!U="!N86UE/2)S96%R8VA?9&5S8R(@:60](G-E87)C:%]D97-C(B!T>7!E
M/2)C:&5C:V)O>"(@8VAE8VME9#TB8VAE8VME9"(@+SX\/W!H<"!E8VAO($AO
M<F1E.CIL86)E;"@G<V5A<F-H7V1E<V,G+"!?*")?1FER<W0@3&EN92(I*2`_
M/B9N8G-P.PH@("`@/&EN<'5T(&YA;64](G-E87)C:%]B;V1Y(B!I9#TB<V5A
M<F-H7V)O9'DB('1Y<&4](F-H96-K8F]X(B`O/CP_<&AP(&5C:&\@2&]R9&4Z
M.FQA8F5L*"=S96%R8VA?8F]D>2<L(%\H(D9?=6QL(%1E>'0B*2D@/SX*("`\
M+W1D/@H\+W1R/@H\+W1A8FQE/@H*/&)R("\^"@H\=&%B;&4@=VED=&@](C$P
M,"4B(&-E;&QS<&%C:6YG/2(P(CX*/'1R/@H@(#QT9#X*("`@(#QI;G!U="!T
M>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(E-E87)C:"(I(#\^(B`O/B9N8G-P.PH@("`@/&EN<'5T('1Y<&4](G)E
M<V5T(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")#;&5A
M<B!&;W)M(BD@/SXB("\^"B`@/"]T9#X*/"]T<CX*/"]T86)L93X*/"]F;W)M
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M
M;R]T96UP;&%T97,O;65M;R\`````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0V`#`R,#0W-``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VUN96UO+W1E;7!L871E<R]M96UO+VUE;6\N:6YC````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<Q,3(`,3`T,3<S-C(W-#8`
M,#(R,3(R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*9G5N8W1I;VX@
M=7!D871E0VAA<D-O=6YT*"D*>PH\/W!H<"!I9B`H*"1'3$]"04Q36R=B<F]W
M<V5R)UTM/FES0G)O=W-E<B@G;7-I92<I("8F"B`@("`@("`@("`@)$=,3T)!
M3%-;)V)R;W=S97(G72T^9V5T36%J;W(H*2`^/2`T*2!\?`H@("`@("`@("`@
M*"1'3$]"04Q36R=B<F]W<V5R)UTM/FES0G)O=W-E<B@G;6]Z:6QL82<I("8F
M"B`@("`@("`@("`@)$=,3T)!3%-;)V)R;W=S97(G72T^9V5T36%J;W(H*2`^
M/2`U*2DZ(#\^"B`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@G8VAA<F-O
M=6YT)RDN:6YN97)(5$U,(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)VUE
M;6]?8F]D>2<I+G9A;'5E+G)E<&QA8V4H+UM<<EQN72]G+"`G)RDN;&5N9W1H
M.PH\/W!H<"!E;F1I9CL@/SX*?0H\+W-C<FEP=#X*/#]P:'`@96-H;R`D8TUA
M;F%G97(M/F=E=$IA=F%38W)I<'0H)VUE;6\G+"`G;65M;U]C871E9V]R>2<I
M(#\^"CQF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB;65M;R(@86-T:6]N/2)M
M96UO+G!H<"(^"CP_<&AP(%5T:6PZ.G!&;W)M26YP=70H*2`_/@H\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](G-A=F5?;65M
M;R(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB;65M;R(@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;65M;U]I9"D@/SXB("\^
M"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FYE=U]C871E9V]R>2(@=F%L
M=64](B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB;65M;VQI<W1?
M;W)I9VEN86PB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&UE;6]L:7-T7VED*2`_/B(@+SX*/#]P:'`@:68@*"1P<F5F<RT^:7-,;V-K
M960H)V1E9F%U;'1?;F]T97!A9"<I('Q\(&-O=6YT*"1N;W1E<&%D<RD@/#T@
M,2DZ(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FYO=&5P861?=&%R
M9V5T(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1M96UO
M;&ES=%]I9"D@/SXB("\^"CP_<&AP(&5N9&EF.R`_/@H\:#$@8VQA<W,](FAE
M861E<B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1T:71L92D@/SX\
M+V@Q/@H*/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^"CQT
M<CX*("`@(#QT9"!C;&%S<STB:71E;2(@;F]W<F%P/2)N;W=R87`B(&%L:6=N
M/2)R:6=H="(@=F%L:6=N/2)T;W`B/CQS=')O;F<^/#]P:'`@96-H;R!(;W)D
M93HZ;&%B96PH)VUE;6]?8F]D>2<L(%\H(DYO=&4@7U1E>'0B*2D@/SXF;F)S
M<#LH/#]P:'`@<')I;G1F*%\H(B5S(&-H87)A8W1E<G,B*2P@)SQS<&%N(&ED
M/2)C:&%R8V]U;G0B/B<@+B!3=')I;F<Z.FQE;F=T:"AS=')?<F5P;&%C92AA
M<G)A>2@B7'(B+"`B7&XB*2P@)R<L("1M96UO7V)O9'DI*2`N("<\+W-P86X^
M)RD@/SXI.CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@("`\=&0@8VQA<W,](FET
M96TB/@H@("`@("`@(#QT97AT87)E82!N86UE/2)M96UO7V)O9'DB(&ED/2)M
M96UO7V)O9'DB(&-L87-S/2)F:7AE9"(@8V]L<STB.#`B(')O=W,](C(P(B!O
M;F-H86YG93TB=7!D871E0VAA<D-O=6YT*"DB(&]N8VQI8VL](G5P9&%T94-H
M87)#;W5N="@I(B!O;FME>7!R97-S/2)S9714:6UE;W5T*"=U<&1A=&5#:&%R
M0V]U;G0H*2<L(#$I(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&UE
M;6]?8F]D>2D@/SX\+W1E>'1A<F5A/@H@("`@/"]T9#X*("`@(#QT9"!C;&%S
M<STB:71E;2(@=VED=&@](C$P,"4B/B9N8G-P.SPO=&0^"CPO='(^"CP_<&AP
M(&EF("@A)'!R969S+3YI<TQO8VME9"@G9&5F875L=%]N;W1E<&%D)RD@)B8@
M8V]U;G0H)&YO=&5P861S*2`^(#$I.B`_/@H\='(^"B`@("`\=&0@8VQA<W,]
M(FET96T@;F]W<F%P(B!A;&EG;CTB<FEG:'0B('9A;&EG;CTB=&]P(CX\<W1R
M;VYG/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=N;W1E<&%D7W1A<F=E="<L
M(%\H(DYO=&5?<&%D(BDI(#\^/"]S=')O;F<^)FYB<W`[/"]T9#X*("`@(#QT
M9"!C;&%S<STB:71E;2(^"@H@("`@/'-E;&5C="!I9#TB;F]T97!A9%]T87)G
M970B(&YA;64](FYO=&5P861?=&%R9V5T(CX*("`@(#P_<&AP"B`@("!F;W)E
M86-H("@D;F]T97!A9',@87,@)&ED(#T^("1N;W1E<&%D*2!["B`@("`@("`@
M)'-E;"`]("@D:60@/3T@)&UE;6]L:7-T7VED*2`_("<@<V5L96-T960](G-E
M;&5C=&5D(B<@.B`G)SL*("`@("`@("!P<FEN=&8H)SQO<'1I;VX@=F%L=64]
M(B5S(B5S/B5S/"]O<'1I;VX^)RP*("`@("`@("`@("`@("`@:'1M;'-P96-I
M86QC:&%R<R@D:60I+"`D<V5L+"!H=&UL<W!E8VEA;&-H87)S*"1N;W1E<&%D
M+3YG970H)VYA;64G*2DI("X@(EQN(CL*("`@('T@/SX*("`@(#PO<V5L96-T
M/@H*("`@(#PO=&0^"B`@("`\=&0@8VQA<W,](FET96TB/B9N8G-P.SPO=&0^
M"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H\='(^"B`@("`\=&0@8VQA<W,](FET
M96TB(&%L:6=N/2)R:6=H="(@=F%L:6=N/2)T;W`B/CQS=')O;F<^/#]P:'`@
M96-H;R!(;W)D93HZ;&%B96PH)VUE;6]?8V%T96=O<GDG+"!?*")?0V%T96=O
M<GDB*2D@/SX\+W-T<F]N9SXF;F)S<#L\+W1D/@H@("`@/'1D(&-L87-S/2)I
M=&5M(CX\/W!H<"!E8VAO("1C36%N86=E<BT^9V5T4V5L96-T*"=M96UO7V-A
M=&5G;W)Y)RP@)&UE;6]?8V%T96=O<GDI(#\^/"]T9#X*("`@(#QT9"!C;&%S
M<STB:71E;2(^)FYB<W`[/"]T9#X*/"]T<CX*/'1R/@H@("`@/'1D(&-L87-S
M/2)I=&5M(B!A;&EG;CTB<FEG:'0B/CQI;G!U="!T>7!E/2)S=6)M:70B(&-L
M87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-A=F4B*2`_/B(@
M;VYC;&EC:STB<F5T=7)N(&-H96-K0V%T96=O<GDH*3LB("\^/"]T9#X*("`@
M(#QT9"!C;&%S<STB:71E;2(@86QI9VX](G)I9VAT(CX*("`@("`@("`\:6YP
M=70@='EP93TB<F5S970B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E
M8VAO(%\H(E5N9&\@8VAA;F=E<R(I(#\^(B`O/B9N8G-P.PH\/W!H<`II9B`H
M)&UE;6]?:60I.@H@("`@)&UE;6]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M)VUE;6\N<&AP)RP@87)R87DH)VUE;6\G(#T^("1M96UO7VED+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VUE;6]L:7-T)R`]/B`D;65M;VQI<W1?:60I*3L*"B`@("`D<VAA<F4@/2`D
M1TQ/0D%,4ULG;6YE;6]?<VAA<F5S)UTM/F=E=%-H87)E*"1M96UO;&ES=%]I
M9"D["B`@("!I9B`H(6ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I("8F("1S
M:&%R92T^:&%S4&5R;6ES<VEO;BA!=71H.CIG971!=71H*"DL(%!%4DU37T1%
M3$5412DI.@H_/@H@("`@("`@(#QI;G!U="!T>7!E/2)B=71T;VXB(&-L87-S
M/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1E;&5T92!T:&ES(&YO
M=&4B*2`_/B(@;VYC;&EC:STB=VEN9&]W+FQO8V%T:6]N/2<\/W!H<"!E8VAO
M(&%D9'-L87-H97,H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*%5T:6PZ.F%D9%!A
M<F%M971E<B@D;65M;W5R;"P@)V%C=&EO;DE$)RP@)V1E;&5T95]M96UO<R<I
M*2D@/SXG.R(@+SXF;F)S<#L*/#]P:'`@96YD:68[(&5N9&EF.R`_/@H@("`@
M/"]T9#X*("`@(#QT9"!C;&%S<STB:71E;2(^)FYB<W`[/"]T9#X*/"]T<CX*
M/"]T86)L93X*/"]F;W)M/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W1E;7!L871E
M<R]N;W1E<&%D<R\`````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#8`,#(Q,S4T`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;6YE;6\O=&5M<&QA=&5S+VYO=&5P861S+VYO=&5P861S+FEN8P``````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-S<S,@`Q,#0Q-S,V,C<T-@`P,C,V-S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IV87(@961I=%523"`]
M(&1E8V]D955224-O;7!O;F5N="@G/#]P:'`@96-H;R!R87=U<FQE;F-O9&4H
M571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H
M)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP/V%P<#UM;F5M;R<L('1R=64I+"`G<VAA<F4G+"`G0$E$0"<L(&9A;'-E
M*2D@/SXG*3L*=F%R(&-A;F-E;%-U8FUI="`](&9A;'-E.PIV87(@9FEE;&1S
M(#T@;F5W($%R<F%Y*"D["CP_<&AP(&9O<F5A8V@@*"1P97)S;VYA;%]N;W1E
M<&%D<R!A<R`D:60@/3X@)&YO=&5P861S*3H@/SX*9FEE;&1S6R<\/W!H<"!E
M8VAO(')A=W5R;&5N8V]D92@D:60I(#\^)UT@/2!N97<@07)R87DH"B`@("`@
M("`@(CP_<&AP(&5C:&\@<F%W=7)L96YC;V1E*"1N;W1E<&%D<RT^9V5T*"=N
M86UE)RDI(#\^(BP*("`@("`@("`B/#]P:'`@96-H;R!R87=U<FQE;F-O9&4H
M)&YO=&5P861S+3YG970H)V1E<V,G*2D@/SXB*3L*/#]P:'`@96YD9F]R96%C
M:#L@/SX*"F9U;F-T:6]N(&YE=T-H;VEC92@I"GL*("`@('9A<B!A8W1I;VX@
M/2!D;V-U;65N="YS:&%R97,N<VAA<F4N;W!T:6]N<UMD;V-U;65N="YS:&%R
M97,N<VAA<F4N<V5L96-T961);F1E>%TN=F%L=64["B`@("!I9B`H86-T:6]N
M(#T]("TQ*2!["B`@("`@("`@9&]C=6UE;G0N<VAA<F5S+G-A=F4N=F%L=64@
M/2`G/#]P:'`@96-H;R!?*")#<F5A=&4B*2`_/B<["B`@("`@("`@9&]C=6UE
M;G0N<VAA<F5S+F%C8V5S<VQI<W0N<W1Y;&4N9&ES<&QA>2`]("=N;VYE)SL*
M("`@("`@("!D;V-U;65N="YS:&%R97,N<F5S970H*3L*("`@("`@("!C;&5A
M<D9O<FTH*3L*("`@('T@96QS92!["B`@("`@("`@9&]C=6UE;G0N<VAA<F5S
M+G-A=F4N=F%L=64@/2`G/#]P:'`@96-H;R!?*")#:&%N9V4B*2`_/B<["B`@
M("`@("`@9&]C=6UE;G0N<VAA<F5S+F%C8V5S<VQI<W0N<W1Y;&4N9&ES<&QA
M>2`]("=B;&]C:R<["B`@("`@("`@=7!D871E1F]R;2AA8W1I;VXI.PH@("`@
M?0I]"@IF=6YC=&EO;B!U<&1A=&5&;W)M*'-H87)E*0I["B`@("!D;V-U;65N
M="YS:&%R97,N961I=%]S:&%R92YV86QU92`]('-H87)E.PH@("`@9&]C=6UE
M;G0N<VAA<F5S+FED+G9A;'5E(#T@9&5C;V1E55))0V]M<&]N96YT*&9I96QD
M<UMS:&%R95U;,%TI.PH@("`@9&]C=6UE;G0N<VAA<F5S+F1E<V-R:7!T:6]N
M+G9A;'5E(#T@9&5C;V1E55))0V]M<&]N96YT*&9I96QD<UMS:&%R95U;,5TI
M.PI]"@IF=6YC=&EO;B!C;&5A<D9O<FTH*0I["B`@("!D;V-U;65N="YS:&%R
M97,N961I=%]S:&%R92YV86QU92`]("<G.PH@("`@9&]C=6UE;G0N<VAA<F5S
M+FED+G9A;'5E(#T@)R<["B`@("!D;V-U;65N="YS:&%R97,N9&5S8W)I<'1I
M;VXN=F%L=64@/2`G)SL*("`@(&1O8W5M96YT+G-H87)E<RYA8V-E<W-L:7-T
M+G-T>6QE+F1I<W!L87D@/2`G;F]N92<["B`@("!C86YC96Q3=6)M:70@/2!T
M<G5E.PI]"@IF=6YC=&EO;B!C:&5C:U-U8FUI="@I"GL*("`@(&-A;F-E;"`]
M(&-A;F-E;%-U8FUI=#L*("`@(&-A;F-E;%-U8FUI="`](&9A;'-E.PH\/W!H
M<"!I9B`H)&)R;W=S97(M/F=E=$)R;W=S97(H*2`]/2`G;7-I92<@)B8@)&)R
M;W=S97(M/F=E=$UA:F]R*"D@/CT@-"DZ(#\^"B`@("!W:6YD;W<N979E;G0N
M<F5T=7)N5F%L=64@/2`A8V%N8V5L.PH\/W!H<"!E;F1I9CL@/SX*("`@(')E
M='5R;B`A8V%N8V5L.PI]"@HO+RTM/@H\+W-C<FEP=#X*"CQF;W)M(&UE=&AO
M9#TB<&]S="(@;F%M93TB<VAA<F5S(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"=N;W1E<&%D<RYP:'`G*2`_/B(@;VYS=6)M
M:70](G)E='5R;B!C:&5C:U-U8FUI="@I(CX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)S879E(B`O/@H*/'1A8FQE('=I
M9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^"CQT<CX\=&0@8VQA<W,](FAE
M861E<B(@86QI9VX](FQE9G0B/CQS=')O;F<^/#]P:'`@96-H;R!?*").;W1E
M<&%D<R(I(#\^/"]S=')O;F<^/"]T9#X\+W1R/@H\='(^/'1D(&-L87-S/2)I
M=&5M(CX\=&%B;&4^"@H\='(@=F%L:6=N/2)T;W`B/CQT9"!C;&%S<STB:71E
M;2(^"CP_<&AP(&5C:&\@7R@B66]U<B!N;W1E<&%D<SHB*2`_/CQB<B`O/@H\
M<V5L96-T(&YA;64](G-H87)E(B!O;F-H86YG93TB:F%V87-C<FEP=#IN97=#
M:&]I8V4H*2(^"B`@/&]P=&EO;B!V86QU93TB+3$B/CP_<&AP(&5C:&\@7R@B
M4V5L96-T(&$@;F]T97!A9"(I(#\^/"]O<'1I;VX^"CP_<&AP(&9O<F5A8V@@
M*"1P97)S;VYA;%]N;W1E<&%D<R!A<R`D:60@/3X@)&YO=&5P860I.B`_/@H@
M(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M:60I(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&YO=&5P860M
M/F=E="@G;F%M92<I*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W)E86-H.R`_
M/@H\+W-E;&5C=#X*/"]T9#X\+W1R/@H*/'1R/CQT9"!C;&%S<STB:71E;2(^
M/'1A8FQE/@H*/'1R('9A;&EG;CTB=&]P(CX\=&0@8VQA<W,](FET96TB/@H*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB961I=%]S:&%R92(@=F%L=64]
M(CP_<&AP(&5C:&\@:7-S970H)'1O7V5D:70I(#\@:'1M;'-P96-I86QC:&%R
M<R@D=&]?961I="D@.B`G)R`_/B(@+SX*/#]P:'`@96-H;R!?*").;W1E<&%D
M)W,@;F%M93HB*2`_/CQB<B`O/@H\:6YP=70@;F%M93TB:60B('-I>F4](C,P
M(B!M87AL96YG=&@](C8P(B`O/CQB<B`O/@H*/&EN<'5T('1Y<&4](F)U='1O
M;B(@;F%M93TB86-C97-S;&ES="(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB
M<&]P=7`H961I=%523"YR97!L86-E*"\E-#!)1"4T,"\L(&1O8W5M96YT+G-H
M87)E<RYE9&ET7W-H87)E+G9A;'5E*2D[(B!V86QU93TB/#]P:'`@96-H;R!?
M*")097)M:7-S:6]N<R(I(#\^(B!S='EL93TB9&ES<&QA>3IN;VYE(B`O/@H\
M8G(@+SX*"CP_<&AP(&5C:&\@7R@B1&5S8W)I<'1I;VXZ(BD@/SX\8G(@+SX*
M/'1E>'1A<F5A(&YA;64](F1E<V-R:7!T:6]N(B!R;W=S/2(V(B!C;VQS/2(X
M,"(^/"]T97AT87)E83X\8G(@+SX*"CPO=&0^/"]T<CX\+W1A8FQE/CPO=&0^
M/"]T<CX*/'1R/@H@(#QT9#X*("`@(#QT86)L92!W:61T:#TB,3`P)2(^"B`@
M("`\='(^"B`@("`@(#QT9#X*("`@("`@("`\:6YP=70@='EP93TB<W5B;6ET
M(B!N86UE/2)S879E(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N
M="YS:&%R97,N86-T:6]N240N=F%L=64@/2`G<V%V92<[(')E='5R;B!T<G5E
M(B!V86QU93TB/#]P:'`@96-H;R!?*")#<F5A=&4B*2`_/B(@+SX*("`@("`@
M("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)D96QE=&4B(&-L87-S/2)B
M=71T;VXB(&]N8VQI8VL](F1O8W5M96YT+G-H87)E<RYA8W1I;VY)1"YV86QU
M92`]("=D96QE=&4G(B!V86QU93TB/#]P:'`@96-H;R!?*")$96QE=&4B*2`_
M/B(@+SX*("`@("`@("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)N97<B
M(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F-L96%R1F]R;2@I.R!D;V-U;65N
M="YS:&%R97,N<V%V92YV86QU92`]("<\/W!H<"!E8VAO(%\H(D-R96%T92(I
M(#\^)SLB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E<V5T(BD@/SXB("\^"B`@
M("`@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB8F%C:R(@8VQA<W,]
M(F)U='1O;B(@;VYC;&EC:STB8V%N8V5L4W5B;6ET(#T@=')U93L@9&]C=6UE
M;G0N;&]C871I;VXN:')E9B`]("<\/W!H<"!E8VAO($AO<F1E.CIU<FPH571I
M;#HZ861D4&%R86UE=&5R*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W-E<G9I8V5S+W!R969S+G!H<"<L(&%R<F%Y*"=A<'`G(#T^
M("=M;F5M;R<L("=G<F]U<"<@/3X@)W-H87)E)RDI+"!T<G5E*2`_/B<B('9A
M;'5E/2(\/W!H<"!E8VAO(%\H(D)A8VL@=&\@3F]T97!A9"!/<'1I;VYS(BD@
M/SXB("\^"B`@("`@(#PO=&0^"B`@("`\+W1R/@H@("`@/"]T86)L93X*("`\
M+W1D/@H\+W1R/@H\+W1A8FQE/@H\+W1D/CPO='(^/"]T86)L93X*/"]F;W)M
M/@H``````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O=&5M<&QA=&5S+W!R969S+P``
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<T-@`P,C`V-38`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]T
M96UP;&%T97,O<')E9G,O<VAO=W-U;6UA<GES96QE8W0N:6YC````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$Q,30W`#$P-#$W,S8R-S0V`#`R-3$U,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HD8VAO<V5N0V%T
M96=O<FEE<R`](&5X<&QO9&4H)SLG+"`D<')E9G,M/F=E=%9A;'5E*"=S=6UM
M87)Y7V-A=&5G;W)I97,G*2D["FEF("@D8VAO<V5N0V%T96=O<FEE<R`A/2!A
M<G)A>2@G)RDI('L*("`@(&9O<F5A8V@@*"1C:&]S96Y#871E9V]R:65S(&%S
M("1C:&]S96Y#;VQU;6XI('L*("`@("`@("!L:7-T*"1C871E9V]R:65S6UTL
M*2`](&5X<&QO9&4H)RPG+"`D8VAO<V5N0V]L=6UN*3L*("`@('T*?2!E;'-E
M('L*("`@("1C871E9V]R:65S(#T@87)R87DH*3L*?0H*)&IS(#T@(G9A<B!C
M871E9V]R:65S(#T@;F5W($%R<F%Y*"D[7&XB.PH*<F5Q=6ER95]O;F-E("=(
M;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP)SL*)&--86YA9V5R(#T@
M)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G97(H*3L*)&-O;'5M;E]C;W5N="`]
M(#`["F9O<F5A8V@@*"1C36%N86=E<BT^9V5T*"D@87,@)&ED(#T^("1N86UE
M*2!["B`@("!I9B`H:6Y?87)R87DH)&ED+"`D8V%T96=O<FEE<RDI('L*("`@
M("`@("`D:G,@+CT@(F-A=&5G;W)I97-;)&-O;'5M;E]C;W5N=%T@/2!N97<@
M07)R87DH9&5C;V1E55))0V]M<&]N96YT*"<B("X@<F%W=7)L96YC;V1E*"1I
M9"D@+B`B)RDL(&1E8V]D955224-O;7!O;F5N="@G(B`N(')A=W5R;&5N8V]D
M92@D;F%M92D@+B`B)RDL('1R=64I.UQN(CL*"7T@96QS92!["B`@("`@("`@
M)&IS("X](")C871E9V]R:65S6R1C;VQU;6Y?8V]U;G1=(#T@;F5W($%R<F%Y
M*&1E8V]D955224-O;7!O;F5N="@G(B`N(')A=W5R;&5N8V]D92@D:60I("X@
M(B<I+"!D96-O9&554DE#;VUP;VYE;G0H)R(@+B!R87=U<FQE;F-O9&4H)&YA
M;64I("X@(B<I+"!F86QS92D[7&XB.PH@("`@?0H@("`@)&-O;'5M;E]C;W5N
M="LK.PI]"@H_/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA
M+2T*/#]P:'`@96-H;R`D:G,@/SX*"F9U;F-T:6]N(&1E<V5L96-T2&5A9&5R
M<R@I"GL*("`@(&1O8W5M96YT+G!R969S+G5N<V5L96-T961?8V%T96=O<FEE
M<ULP72YS96QE8W1E9"`](&9A;'-E.PH@("`@9&]C=6UE;G0N<')E9G,N<V5L
M96-T961?8V%T96=O<FEE<ULP72YS96QE8W1E9"`](&9A;'-E.PI]"@IF=6YC
M=&EO;B!R97-E=$AI9&1E;B@I"GL*("`@('9A<B!T;7`@/2`G)SL*("`@('9A
M<B!F:7)S="`]("<G.PH@("`@=F%R(&8@/2!D;V-U;65N="YP<F5F<SL*("`@
M('9A<B!I(#T@,#L*("`@(&9O<B`H=F%R(&H@/2`Q.R!J(#P@9BYS96QE8W1E
M9%]C871E9V]R:65S+FQE;F=T:#L@:BLK*2!["B`@("`@("`@:68@*&8N<V5L
M96-T961?8V%T96=O<FEE<UMJ72YV86QU92D@>PH@("`@("`@("`@("!T;7`@
M*ST@9FER<W0@*R!F+G-E;&5C=&5D7V-A=&5G;W)I97-;:ETN=F%L=64@*R`G
M+"<@*R!I.PH@("`@("`@("`@("!F:7)S="`]("<[)SL*("`@("`@("`@("`@
M:2LK.PH@("`@("`@('T*("`@('T*("`@(&1O8W5M96YT+G!R969S+G-U;6UA
M<GE?8V%T96=O<FEE<RYV86QU92`]('1M<#L*?0H*9G5N8W1I;VX@861D0V]L
M=6UN*"D*>PH@("`@=F%R(&8@/2!D;V-U;65N="YP<F5F<SL*"B`@("!F;W(@
M*&D@/2`Q.R!I(#P@9BYU;G-E;&5C=&5D7V-A=&5G;W)I97,N;&5N9W1H.R!I
M*RLI('L*("`@("`@("!I9B`H9BYU;G-E;&5C=&5D7V-A=&5G;W)I97-;:5TN
M<V5L96-T960I('L*("`@("`@("`@("`@9F]R("AV87(@:B`](#$[(&H@/"!C
M871E9V]R:65S+FQE;F=T:#L@:BLK*2!["B`@("`@("`@("`@("`@("!I9B`H
M8V%T96=O<FEE<UMJ75LP72`]/2!F+G5N<V5L96-T961?8V%T96=O<FEE<UMI
M72YV86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&-A=&5G;W)I97-;:EU;
M,ET@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&8N<V5L96-T961?8V%T96=O<FEE<UMF+G-E;&5C=&5D7V-A
M=&5G;W)I97,N;&5N9W1H72`](&YE=R!/<'1I;VXH9BYU;G-E;&5C=&5D7V-A
M=&5G;W)I97-;:5TN=&5X="P@9BYU;G-E;&5C=&5D7V-A=&5G;W)I97-;:5TN
M=F%L=64I.PH@("`@("`@("`@("!F+G5N<V5L96-T961?8V%T96=O<FEE<UMI
M72`](&YU;&P["B`@("`@("`@("`@(&DM+3L*("`@("`@("!]"B`@("!]"@H@
M("`@<F5S971(:61D96XH*3L*?0H*9G5N8W1I;VX@<F5M;W9E0V]L=6UN*"D*
M>PH@("`@=F%R(&8@/2!D;V-U;65N="YP<F5F<SL*"B`@("!F;W(@*&D@/2`Q
M.R!I(#P@9BYS96QE8W1E9%]C871E9V]R:65S+FQE;F=T:#L@:2LK*2!["B`@
M("`@("`@:68@*&8N<V5L96-T961?8V%T96=O<FEE<UMI72YS96QE8W1E9"D@
M>PH@("`@("`@("`@("!F;W(@*'9A<B!J(#T@,3L@:B`\(&-A=&5G;W)I97,N
M;&5N9W1H.R!J*RLI('L*("`@("`@("`@("`@("`@(&EF("AC871E9V]R:65S
M6VI=6S!=(#T](&8N<V5L96-T961?8V%T96=O<FEE<UMI72YV86QU92D@>PH@
M("`@("`@("`@("`@("`@("`@(&-A=&5G;W)I97-;:EU;,ET@/2!F86QS93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!F
M+G5N<V5L96-T961?8V%T96=O<FEE<UMF+G5N<V5L96-T961?8V%T96=O<FEE
M<RYL96YG=&A=(#T@;F5W($]P=&EO;BAF+G-E;&5C=&5D7V-A=&5G;W)I97-;
M:5TN=&5X="P@9BYS96QE8W1E9%]C871E9V]R:65S6VE=+G9A;'5E*0H@("`@
M("`@("`@("!F+G-E;&5C=&5D7V-A=&5G;W)I97-;:5T@/2!N=6QL.PH@("`@
M("`@("`@("!I+2T["B`@("`@("`@?0H@("`@?0H*("`@(')E<V5T2&ED9&5N
M*"D["GT*+R\@+2T^"CPO<V-R:7!T/@H\/W!H<"!E8VAO(%\H(D-H;V]S92!T
M:&4@;65M;R!C871E9V]R:65S('1O(&QI<W0@:6X@=&AE('-U;6UA<GD@=FEE
M=RXB*2`_/CQB<B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)S=6UM
M87)Y7V-A=&5G;W)I97,B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'!R969S+3YG971686QU92@G<W5M;6%R>5]C871E9V]R:65S)RDI
M(#\^(B`O/@H\=&%B;&4^"B`@/'1R/@H@("`@/'1D/@H@("`@("`\<V5L96-T
M(&YA;64](G5N<V5L96-T961?8V%T96=O<FEE<R(@;75L=&EP;&4](FUU;'1I
M<&QE(B!S:7IE/2(Q,"(@=VED=&@](C,P(B!O;F-H86YG93TB9&5S96QE8W1(
M96%D97)S*"D[(CX*("`@("`@("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C
M:&\@7R@B079A:6QA8FQE($-A=&5G;W)I97,Z(BD@/SX\+V]P=&EO;CX*("`@
M("`@/"]S96QE8W0^"B`@("`\+W1D/@H@("`@/'1D/@H@("`@("`\82!H<F5F
M/2(C(B!O;F-L:6-K/2)A9&1#;VQU;6XH*3L@<F5T=7)N(&9A;'-E.R(^/#]P
M:'`@96-H;R!(;W)D93HZ:6UG*"=R:&%N9"YP;F<G+"!?*")!9&0@8V%T96=O
M<GDB*2P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^
M/"]A/@H@("`@("`\8G(@+SX*("`@("`@/&$@:')E9CTB(R(@;VYC;&EC:STB
M<F5M;W9E0V]L=6UN*"D[(')E='5R;B!F86QS93LB/CP_<&AP(&5C:&\@2&]R
M9&4Z.FEM9R@G;&AA;F0N<&YG)RP@7R@B4F5M;W9E(&-A=&5G;W)Y(BDL("<G
M+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*("`@
M(#PO=&0^"B`@("`\=&0^"B`@("`@(#QS96QE8W0@;F%M93TB<V5L96-T961?
M8V%T96=O<FEE<R(@;75L=&EP;&4](FUU;'1I<&QE(B!S:7IE/2(Q,"(@=VED
M=&@](C,P(B!O;F-H86YG93TB9&5S96QE8W1(96%D97)S*"D[(CX*("`@("`@
M("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B4V5L96-T960@0V%T
M96=O<FEE<SHB*2`_/CPO;W!T:6]N/@H@("`@("`\+W-E;&5C=#X*("`@(#PO
M=&0^"B`@/"]T<CX*/"]T86)L93X*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@H\(2TM"G9A<B!F(#T@9&]C=6UE;G0N<')E9G,["G9A<B!F:65L
M9%-T<FEN9R`]("<G.PH*=VAI;&4@*&8N=6YS96QE8W1E9%]C871E9V]R:65S
M+FQE;F=T:"`^(#$I('L*("`@(&8N=6YS96QE8W1E9%]C871E9V]R:65S+F]P
M=&EO;G-;9BYU;G-E;&5C=&5D7V-A=&5G;W)I97,N;&5N9W1H("T@,5T@/2!N
M=6QL.PI]"G=H:6QE("AF+G-E;&5C=&5D7V-A=&5G;W)I97,N;&5N9W1H(#X@
M,2D@>PH@("`@9BYS96QE8W1E9%]C871E9V]R:65S+F]P=&EO;G-;9BYS96QE
M8W1E9%]C871E9V]R:65S+FQE;F=T:"`M(#%=(#T@;G5L;#L*?0H*=F%R('-E
M;&5C=&5D(#T@;F5W($%R<F%Y*"D["G9A<B!U;G-E;&5C=&5D(#T@;F5W($%R
M<F%Y*"D["F9O<B`H=F%R(&D@/2`P.R!I(#P@8V%T96=O<FEE<RYL96YG=&@[
M(&DK*RD@>PH@("`@:68@*&-A=&5G;W)I97-;:5U;,ETI('L*("`@("`@("!S
M96QE8W1E9%MS96QE8W1E9"YL96YG=&A=(#T@;F5W($%R<F%Y*&-A=&5G;W)I
M97-;:5U;,5TL(&-A=&5G;W)I97-;:5U;,%TI.PH@("`@?2!E;'-E('L*("`@
M("`@("!U;G-E;&5C=&5D6W5N<V5L96-T960N;&5N9W1H72`](&YE=R!!<G)A
M>2AC871E9V]R:65S6VE=6S%=+"!C871E9V]R:65S6VE=6S!=*3L*("`@('T*
M?0IF;W(@*&D@/2`P.R!I(#P@<V5L96-T960N;&5N9W1H.R!I*RLI('L*("`@
M(&8N<V5L96-T961?8V%T96=O<FEE<RYO<'1I;VYS6VD@*R`Q72`](&YE=R!/
M<'1I;VXH<V5L96-T961;:5U;,%TL('-E;&5C=&5D6VE=6S%=*3L*?0IF;W(@
M*&D@/2`P.R!I(#P@=6YS96QE8W1E9"YL96YG=&@[(&DK*RD@>PH@("`@9BYU
M;G-E;&5C=&5D7V-A=&5G;W)I97,N;W!T:6]N<UMI("L@,5T@/2!N97<@3W!T
M:6]N*'5N<V5L96-T961;:5U;,%TL('5N<V5L96-T961;:5U;,5TI.PI]"@HO
M+RTM/@H\+W-C<FEP=#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;6YE;6\O=&5M<&QA=&5S+W!R969S+VYO=&5P861S96QE8W0N:6YC````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,3$W-``Q,#0Q-S,V,C<T-@`P,C0R,#,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*:68@
M*"$D<')E9G,M/FES3&]C:V5D*"=D969A=6QT7VYO=&5P860G*2DZ"B`@("`D
M;F]T97!A9',@/2!-;F5M;SHZ;&ES=$YO=&5P861S*"D["B`@("!I9B`H*"1D
M969A=6QT7VYO=&5P860@/2`D<')E9G,M/F=E=%9A;'5E*"=D969A=6QT7VYO
M=&5P860G*2D@/3T@;G5L;"!\?`H@("`@("`@("%I<W-E="@D;F]T97!A9'-;
M)&1E9F%U;'1?;F]T97!A9%TI*2!["B`@("`@("`@)&1E9F%U;'1?;F]T97!A
M9"`]($%U=&@Z.F=E=$%U=&@H*3L*("`@('T*/SX*"CP_<&AP(&5C:&\@7R@B
M66]U<B!D969A=6QT(&YO=&5P860Z(BD@/SX\8G(@+SX*/'-E;&5C="!N86UE
M/2)D969A=6QT7VYO=&5P860B/@H\/W!H<"!F;W)E86-H("@D;F]T97!A9',@
M87,@)&ED(#T^("1N;W1E<&%D*3H@/SX*("`@(#QO<'1I;VX@=F%L=64](CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:60I(#\^(CP_<&AP(&EF("@D
M:60@/3T@)&1E9F%U;'1?;F]T97!A9"D@96-H;R`G('-E;&5C=&5D/2)S96QE
M8W1E9"(G(#\^/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;F]T97!A
M9"T^9V5T*"=N86UE)RDI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[
M(#\^"CPO<V5L96-T/CQB<B`O/CQB<B`O/@H\/W!H<"!E;F1I9CL@/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;6YE;6\O=&5M<&QA=&5S+V-O;6UO;BUH96%D97(N:6YC````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0T,P`Q,#0Q-S,V,C<T-@`P,C(W-3``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*:68@*&ES<V5T*"1L86YG=6%G92DI('L*("`@(&AE861E<B@G0V]N=&5N
M="UT>7!E.B!T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E
M="@I*3L*("`@(&AE861E<B@G5F%R>3H@06-C97!T+4QA;F=U86=E)RD["GT*
M/SX*/"%$3T-465!%(&AT;6P@4%5"3$E#("(M+R]7,T,O+T141"!82%1-3"`Q
M+C`@5')A;G-I=&EO;F%L+R]%3B(@(D141"]X:'1M;#$M=')A;G-I=&EO;F%L
M+F1T9"(^"CPA+2T@("`@("`@("`@("!-;F5M;SH@0V]P>7)I9VAT(#(P,#(M
M,C`P-BP@5&AE($AO<F1E(%!R;VIE8W0N("`@("`@("`@("`M+3X*/"$M+2!(
M;W)D92!0<F]J96-T.B!H='1P.B\O:&]R9&4N;W)G+R!\($UN96UO.B!H='1P
M.B\O:&]R9&4N;W)G+VUN96UO+R`@("TM/@H\(2TM("`@("`@("`@($AO<F1E
M($QI8V5N<V5S.B!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R\@("`@
M("`@("`@("`@+2T^"CP_<&AP(&5C:&\@(65M<'1Y*"1L86YG=6%G92D@/R`G
M/&AT;6P@;&%N9STB)R`N('-T<G1R*"1L86YG=6%G92P@)U\G+"`G+2<I("X@
M)R(^)R`Z("<\:'1M;#XG(#\^"CQH96%D/@H\/W!H<`H*)'!A9V5?=&ET;&4@
M/2`D<F5G:7-T<GDM/F=E="@G;F%M92<I.PII9B`H(65M<'1Y*"1T:71L92DI
M("1P86=E7W1I=&QE("X]("<@.CH@)R`N("1T:71L93L*:68@*"%E;7!T>2@D
M<F5F<F5S:%]T:6UE*2`F)B`H)')E9G)E<VA?=&EM92`^(#`I("8F("%E;7!T
M>2@D<F5F<F5S:%]U<FPI*2!["B`@("!E8VAO("(\;65T82!H='1P+65Q=6EV
M/5PB<F5F<F5S:%PB(&-O;G1E;G0]7"(D<F5F<F5S:%]T:6UE.W5R;#TD<F5F
M<F5S:%]U<FQ<(CY<;B(["GT*"FEF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YI
M<T)R;W=S97(H)VMO;G%U97)O<B<I*2!["B`@("!(;W)D93HZ861D4V-R:7!T
M1FEL92@G9FEX56YS='EL961/<'1I;VYS+FIS)RP@)VUN96UO)RP@=')U92D[
M"GT*2&]R9&4Z.FEN8VQU9&538W)I<'1&:6QE<R@I.PH*/SX*/'1I=&QE/CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<&%G95]T:71L92D@/SX\+W1I
M=&QE/@H\;&EN:R!H<F5F/2(\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG971);6%G941I<B@I/SXO9F%V:6-O;BYI8V\B(')E;#TB4TA/4E1#
M550@24-/3B(@+SX*/#]P:'`@96-H;R!(;W)D93HZ<W1Y;&5S:&5E=$QI;FLH
M)VUN96UO)RP@96UP='DH)'!R:6YT7W9I97<I(#\@)R<@.B`G<')I;G0G*2`_
M/@H\+VAE860^"@H\8F]D>3P_<&AP(&EF("A5=&EL.CIN;VY);G!U=%9A<B@G
M8F]D>4-L87-S)RDI(&5C:&\@)R!C;&%S<STB)R`N("1B;V1Y0VQA<W,@+B`G
M(B<@/SX^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]T96UP;&%T97,O
M;65N=2YI;F,`````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,S0P`#$P-#$W,S8R-S0V`#`R,3$W,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HD;F]T97!A9',@/2!-;F5M;SHZ
M;&ES=$YO=&5P861S*"D["@HO+R!#:&5C:R!H97)E(&9O<B!G=65S="!N;W1E
M<&%D<R!S;R!T:&%T('=E(&1O;B=T(&=E="!M=6QT:7!L90HO+R!M97-S86=E
M<R!A9G1E<B!R961I<F5C=',L(&5T8RX*:68@*"%!=71H.CIG971!=71H*"D@
M)B8@(6-O=6YT*$UN96UO.CIL:7-T3F]T97!A9',H*2DI('L*("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B3F\@;F]T97!A9',@87)E(&%V86EL86)L92!T
M;R!G=65S=',N(BDI.PI]"C\^"CQF;W)M(&%C=&EO;CTB;&ES="YP:'`B(&UE
M=&AO9#TB<&]S="(@;F%M93TB;F]T97!A9'-M96YU(CX*/#]P:'`@96-H;R!5
M=&EL.CIF;W)M26YP=70H*2`_/@H\9&EV(&ED/2)M96YU(CX*/#]P:'`@:68@
M*"$D<')E9G,M/FES3&]C:V5D*"=D969A=6QT7VYO=&5P860G*2`F)B`H8V]U
M;G0H)&YO=&5P861S*2`^(#$@?'P@(6-O=6YT*"1'3$]"04Q36R=D:7-P;&%Y
M7VYO=&5P861S)UTI*2DZ(#\^"B`\9&EV('-T>6QE/2)F;&]A=#IR:6=H="(^
M"CQS96QE8W0@;F%M93TB9&ES<&QA>5]N;W1E<&%D(B!O;F-H86YG93TB;F]T
M97!A9%-U8FUI="@I.R(^"B`@/&]P=&EO;B!V86QU93TB(CX\/W!H<"!E8VAO
M(%\H(E-E;&5C="!N;W1E<&%D<R!T;R!D:7-P;&%Y.B(I(#\^/"]O<'1I;VX^
M"CP_<&AP(&9O<F5A8V@@*"1N;W1E<&%D<R!A<R`D:60@/3X@)&YO=&5P860I
M.B`_/@H@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D:60I(#\^(CP_<&AP(&5C:&\@*&EN7V%R<F%Y*"1I9"P@)$=,3T)!
M3%-;)V1I<W!L87E?;F]T97!A9',G72D@/R`G(&-L87-S/2)S96QE8W1E9"(G
M(#H@)R<I("X@)SXG("X@:'1M;'-P96-I86QC:&%R<R@D;F]T97!A9"T^9V5T
M*"=N86UE)RDI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"CPO
M<V5L96-T/@H@/"]D:78^"CP_<&AP(&5N9&EF.R`_/@H*(#P_<&AP(&5C:&\@
M36YE;6\Z.F=E=$UE;G4H)W-T<FEN9R<I(#\^"B`\8G(@8VQA<W,](F-L96%R
M(B`O/@H\+V1I=CX*/"]F;W)M/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@H\(2TM"F9U;F-T:6]N(&YO=&5P8613=6)M:70H*0I["B`@("!D
M;V-U;65N="YN;W1E<&%D<VUE;G4N<W5B;6ET*"D["B`@("!R971U<FX@9F%L
M<V4["GT*+R\@+2T^"CPO<V-R:7!T/@H*/#]P:'`@)$=,3T)!3%-;)VYO=&EF
M:6-A=&EO;B==+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U
M<R<I*2`_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VUN96UO+W1H96UE<R\`````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#8`,#$W,#(V
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O=&AE;65S+V=R87!H:6-S
M+P``````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<T-@`P,C`V,C8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M
M;R]T:&5M97,O9W)A<&AI8W,O9F%V:6-O;BYI8V\`````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R-3<V`#$P-#$W,S8R-S0V`#`R,C<U-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````$``0`0$````0`(
M`&@%```6````*````!`````@`````0`(````````````$0L``!$+`````0``
M`````#OI_``[Y_L`/>O\`%ZDK`!KNL,`;+O$`&^_R`!NO,4`<+['`)[AZ0"@
MXNH`H-[E`*OF[0"RYNP`R^SP`'+.W`!TT-X`=M+@`'3/W`!SSML`>-3B`'?3
MX0!YU>,`=]+?`';1W@!GML$`9K2_`%J@J0!YU.$`9[7``&:SO@!;H*D`6I^H
M`%J>IP!9G:8`?-CF`'O6XP!ZU>(`:;C"`%VBK`!<H:H`?=CE`'S7Y`!WSML`
M=\W:`&JXPP!EK[H`?]KG`'[9Y@!YT-P`7Z.M`('<Z0"`V^@`>M'<`'G0VP!A
MIK``8*6N`&ZZQ0!HL;L`J./K`+'E[`#!ZO``P.GO`,WM\0`YW_D`;<?7`&S&
MU@!KP],`:L+2`&_)V0!NR-@`;,34`'#*V@!NQM8`<<O;`'#(V`!OQ]<`=,[>
M`'/-W0!QR=D`=<_?`'/+VP!US=T`?]GG`&&EL`"JY.T`J>/L`#;2]@`P664`
M-E]J`!5!3P`Q668`-%]L`"M/7`!-MO(`3;3O`$2U]P!%M?<`1++T`'2NUP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!D9&1D9&1D
M9&1D9&1D9&1D9!X:'1DF+2T$!3D'!@@Z9&0B(2`;'R@G)P,R.#A4-V1D#C\^
M/3P-"0H[.U95#`MD9`X8%Q$<)20J(S!3-#,U9&0.$A`7$14E%BHI,"\T,61D
M#E$235`1%10D*BDP4S9D9`Y1$DU0$61D)"HI,%,V9&0.3TH/4E!D6F1D*BDP
M*V1D#DM/2@]24&1C6&0J*BMD9`Y!1D]*#U)D5U]=9"0L9&0.0D%&14H33F1`
M8EED+F1D#D-'24M%2%%.9`!A7&1D9`Y$0T=)3$](44YD`F!;9&0.#@X.#@X.
M#@X.#F0!7F1D9&1D9&1D9&1D9&1D9&1D````"@``;&D``%1Y````````26T`
M``````!B;P``9',``&IC`````0```````%)C`````````````%1O``!L;P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W1H96UE<R]G<F%P:&EC<R]M;F5M
M;RYP;F<`````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,3``,3`T,3<S
M-C(W-#8`,#(R-#0P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M``1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J
M8```.I@``!=ODE_%1@```P!03%1%_.D[^^<[_.L]K*1>P[IKQ+MLR+]OQ;QN
MQ[YPZ>&>ZN*@Y=Z@[>:K[.:R\.S+W,YRWM!TX-)VW,]TV\YSXM1XX=-WX]5Y
MW])WWM%VP;9GO[1FJ:!:X=1YP+5GOK-FJ:!;J)]:IYY:IIU9YMA\X]9[XM5Z
MPKAIK*)=JJ%<Y=A]Y-=\V\YWVLUWP[AJNJ]EY]I_YME^W-!YK:-?Z=R!Z-N`
MW-%ZV]!YL*9AKJ5@Q;INN[%HZ^.H[.6Q\.K![^G`\>W-^=\YU\=MUL9LT\-K
MTL)JV<EOV,ANU,1LVLIPUL9NV\MQV,APU\=OWLYTW<USV<EQW\]UV\MSW<UU
MY]E_L*5A[>2J[..I]M(V95DP:E\V3T$59EDQ;%\T7$\K\K9-[[1-][5$][5%
M]+)$UZYT````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/]I4!@```&9T4DY3____________
M____________________________________________________________
M____________________________________________________________
M__\`-8ZHMP````EP2%ES```+$@``"Q(!TMU^_````,!)1$%4*,]C2$$##"E\
M")#"&`<2<'%V]_3Q]PCT2V%*B`8)`/G>KB`^0V(,6(N3HYNKE[!?BD-29(H>
M2,#1S=^+/R@E/#XV144').`-X@>D)$>D:&EI@P0@_*B4%"U-`[!`H)!O@&!*
MB@J0'VP&%Q`500@("8@+BJJ*`?GZ)H8@`0EQ01E5%2UE@V`38U.0@+V=K0TO
M)Y>U=5@H#S=00$E105I>0UV=V<C"(L0<*"`G)2NIIJO+PFK)SL9A!11``P#Y
ML3ZA=#K([0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE
M;6\O=&AE;65S+V=R87!H:6-S+V%Z+G!N9P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#(V-P`Q,#0Q-S,V,C<T-@`P,C$W-3``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@````D````)`@,```"=_^Z#````"5!,5$6Z`!9F9F8```",M<Q"````
M`7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@`
M```'=$E-10?4#!01-AFO8RFB````)TE$051XVF-@`($&!@;&"0P,3`L8&-B6
M,#!PK6!@D%K)P*"U"BP+`$YG!*?ZOMDG`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+W1H96UE<R]G
M<F%P:&EC<R]A9&0N<&YG````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(R-3<`,3`T,3<S-C(W-#8`,#(R,#8W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y
M_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%U]:6HYY<_.D[^^<[
M_.L]U\UVGI=7F)%4VM!YV])[[.:R\.S+W,YRWM!TX-)VW,]TV\YSXM1XX=-W
MW])WWM%VP;9GO[1FJ:!:X=1YP+5GOK-FJ:!;J)]:IYY:IIU9X]9[XM5ZPKAI
MJJ%<Y=A]Y-=\V\YWVLUWP[AJNJ]EYME^V]!YS<)QN[%H[.6Q\.K![^G`\>W-
M^=\YU\=MUL9LT\-KTL)JV<EOV,ANU,1LVLIPUL9NV\MQV,APU\=OWLYTW<US
MV<EQW\]UV\MSW<UU]M(V95DP:E\V3T$59EDQ;%\T7$\K_]1R\J@5\K9-[[1-
M__#6][5$][5%]+)$UZYT$!`0#0T-````____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````UG'S9@```%AT
M4DY3________________________________________________________
M____________________________________________________________
M`'B;P@@````)<$A9<P``"Q(```L2`=+=?OP```"U241!5"C/7<[5#L)`$`70
MXMY"B[L4=W<J.%LH.O__*>R4!!+NVSV[DQD&_L*`YQ>PG!&&@\EL*4]5":S7
M`P+MBQ%V\^UHC/1[X]'<+T'WOH,*0F\LS[UKV%Q.D"DA++`K\-B"*!81/GT/
M(!:J!JC<2F$!;'A%[0M\P`4Z^0#G$UC>29\I&&N#`AO-UE^ZKA-"$#KM5M/-
M/&G3-(U".I6,)/(F^IMHQD@\'`OERF6[XTFA0>$O;\W?.K,1GJ!8`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;6YE;6\O=&AE;65S+V=R87!H:6-S+WIA+G!N9P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(W,``Q,#0Q-S,V,C<T-@`P,C$W
M-#(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@````D````)`@,```"=_^Z#````"5!,5$6Z`!9F
M9F8```",M<Q"`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q,```L3`0":G!@````'=$E-10?4#!01-@M<VECJ````*$E$051XVF-@``*M
M50P,4BL9&+A6,#"P+6%@8%K`P,`X`2C1`))E``!9YP2G>URP]`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN
M96UO+W1H96UE<R]G<F%P:&EC<R]N;W1E<&%D<RYP;F<`````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(S,3``,3`T,3<S-C(W-#8`,#(S,30R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA2
M30``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%
M_.D[^^<[_.L]K*1>P[IKQ+MLR+]OQ;QNQ[YPZ>&>ZN*@Y=Z@[>:K[.:R\.S+
MW,YRWM!TX-)VW,]TV\YSXM1XX=-WX]5YW])WWM%VP;9GO[1FJ:!:X=1YP+5G
MOK-FJ:!;J)]:IYY:IIU9YMA\X]9[XM5ZPKAIK*)=JJ%<Y=A]Y-=\V\YWVLUW
MP[AJNJ]EY]I_YME^W-!YK:-?Z=R!Z-N`W-%ZV]!YL*9AKJ5@Q;INN[%HZ^.H
M[.6Q\.K![^G`\>W-^=\YU\=MUL9LT\-KTL)JV<EOV,ANU,1LVLIPUL9NV\MQ
MV,APU\=OWLYTW<USV<EQW\]UV\MSW<UUY]E_L*5A[>2J[..I]M(V95DP:E\V
M3T$59EDQ;%\T7$\K\K9-[[1-][5$][5%]+)$UZYT````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/]I4!@```&9T4DY3________________________________________
M____________________________________________________________
M__________________________________\`-8ZHMP````EP2%ES```+$@``
M"Q(!TMU^_````,!)1$%4*,]C2$$##"E\")#"&`<2<'%V]_3Q]PCT2V%*B`8)
M`/G>KB`^0V(,6(N3HYNKE[!?BD-29(H>2,#1S=^+/R@E/#XV144').`-X@>D
M)$>D:&EI@P0@_*B4%"U-`[!`H)!O@&!*B@J0'VP&%Q`500@("8@+BJJ*`?GZ
M)H8@`0EQ01E5%2UE@V`38U.0@+V=K0TO)Y>U=5@H#S=00$E105I>0UV=V<C"
M(L0<*"`G)2NIIJO+PFK)SL9A!11``P#YL3ZA=#K([0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O=&AE;65S+W-C<F5E;BYC<W,`
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,30V-``Q,#0Q
M-S,V,C<T-@`P,C$P,C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+RHJ"B`J("1(;W)D93H@;6YE;6\O=&AE;65S+W-C<F5E
M;BYC<W,L=B`Q+C0N,BXQ(#(P,#4O,3`O,3@@,3,Z,#$Z,3D@:F%N($5X<"`D
M"B`J+PH*+RH@365N=2!B;W1T;VT@;6%R9VEN+"!A9&1E9"!F;W(@0D,N("HO
M"B-M96YU('L*("`@(&UA<F=I;BUB;W1T;VTZ(#AP>#L*?0H*+RH@26UA9V4@
M86QI9VYM96YT+"!A9&1E9"!F;W(@0D,N("HO"FEM9R!["B`@("!V97)T:6-A
M;"UA;&EG;CH@;6ED9&QE.PI]"@HO*B!3;W)T(&%R<F]W('-T>6QE<RP@861D
M960@9F]R($)#+B`J+PHN<V]R='5P('L*("`@(&)A8VMG<F]U;F0Z("-B8F-B
M9F8@=7)L*")G<F%P:&EC<R]Z82YP;F<B*2!C96YT97(@;&5F="!N;RUR97!E
M870["B`@("!P861D:6YG+6QE9G0Z(#$P<'@["GT*+G-O<G1D;W=N('L*("`@
M(&)A8VMG<F]U;F0Z("-B8F-B9F8@=7)L*")G<F%P:&EC<R]A>BYP;F<B*2!C
M96YT97(@;&5F="!N;RUR97!E870["B`@("!P861D:6YG+6QE9G0Z(#$P<'@[
M"GT*"B\J(%1A8FQE($-34RP@861D960@9F]R($)#+B`J+PIT:"!["B`@("!C
M;VQO<CH@(S,S,SL*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED(",Y.3D["GT*"B\J(%)43"!S='EL97,L(&%D
M9&5D(&9O<B!"0RX@*B\*+FQE9G1!;&EG;B!["B`@("!T97AT+6%L:6=N.B!L
M969T.PI]"BYR:6=H=$%L:6=N('L*("`@('1E>'0M86QI9VXZ(')I9VAT.PI]
M"BYL969T1FQO870@>PH@("`@9FQO870Z(&QE9G0["GT*+G)I9VAT1FQO870@
M>PH@("`@9FQO870Z(')I9VAT.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O9&]C<R\`````````
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<T-@`P,38T-S$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]M
M;F5M;R]D;V-S+U501U)!1$E.1P``````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q-34U`#$P-#$W,S8R-S0V`#`Q-S<S-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*(%5P9W)A9&EN9R!T;R!-;F5M;R`R+C`*/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P
M,#0O,3$O,38@,C(Z-#8Z-#D@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N
M.B`Q+C$@)`HZ0V]N=&%C=#H@("`@("`@;6YE;6]`;&ES=',N:&]R9&4N;W)G
M"@H*5&AE<V4@87)E(&EN<W1R=6-T:6]N<R!T;R!U<&=R861E(&9R;VT@36YE
M;6\@,2XQ+G@@=&\@36YE;6\@,BXP+B`@4&QE87-E"F)A8VMU<"!Y;W5R(&5X
M:7-T:6YG(&1A=&$@8F5F;W)E(')U;FYI;F<@86YY(&]F('1H92!S=&5P<R!D
M97-C<FEB960@8F5L;W<N"EEO=2!C86XG="!U<V4@=&AE('5P9&%T960@9&%T
M82!W:71H('EO=7(@;VQD($UN96UO('9E<G-I;VX@86YY;6]R92X*"@I344P@
M0F%C:V5N9',*/3T]/3T]/3T]/3T]"@I%>&5C=71E('1H92!P<F]V:61E9"!3
M44P@<V-R:7!T('1O('5P9&%T92!Y;W5R(&1A=&$@=&\@=&AE(&YE=R!.86<@
M=F5R<VEO;CHZ"@H@("!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W;W)D/3Q-
M>5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"!S8W)I<'1S+W5P9W)A
M9&5S+S$N,5]T;U\R+C`N;7ES<6PN<W%L"@H*0V%T96=O<FEE<PH]/3T]/3T]
M/3T]"@I#871E9V]R:65S(&%R92!N;W<@8F5I;F<@;6%I;G1A:6YE9"!C96YT
M<F%L;'D@9F]R(&%L;"!(;W)D92!A<'!L:6-A=&EO;G,@=&AA=`IS=7!P;W)T
M('1H96TN("!4;R!C;VYV97)T('1H92!O;&0@;65M;R!C871E9V]R:65S(&5X
M96-U=&4@=&AE('!R;W9I9&5D(%!(4`IS8W)I<'0Z.@H*("`@<&AP('-C<FEP
M=',O=7!G<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T7V-A=&5G;W)I97-?=&]?
M<W1R:6YG<RYP:'`*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]M;F5M;R]D;V-S+U)%041-10``````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-#,S`#$P-#$W,S8R-S0V`#`Q-S,U,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!7:&%T
M(&ES($UN96UO/PH]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$
M871E.B`R,#`U+S$P+S$X(#$S.C`Q.C`V("0*.E)E=FES:6]N.B`@("`@("12
M979I<VEO;CH@,2XW+C$P+C$@)`HZ0V]N=&%C=#H@("`@("`@;6YE;6]`;&ES
M=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"BXN('-E8W1I
M;VXM;G5M8F5R:6YG.CH*"DUN96UO(&ES('1H92!(;W)D92!N;W1E<R!A;F0@
M;65M;W,@87!P;&EC871I;VXN("!)="!L971S('5S97)S(&ME97`@9G)E92UT
M97AT"FYO=&5S(&%N9"!O=&AE<B!B:71S(&]F(&EN9F]R;6%T:6]N('=H:6-H
M(&1O97-N)W0@9FET(&%S(&$@8V]N=&%C="P@82!T;V1O"FET96TL(&%N(&5V
M96YT+"!E=&,N("!)="!I<R!V97)Y('-I;6EL87(@:6X@9G5N8W1I;VYA;&ET
M>2!T;R!T:&4@4&%L;2!-96UO"F%P<&QI8V%T:6]N+@H*5&AI<R!S;V9T=V%R
M92!I<R!/4TD@0V5R=&EF:65D($]P96X@4V]U<F-E(%-O9G1W87)E+B`@3U-)
M($-E<G1I9FEE9"!I<R!A"F-E<G1I9FEC871I;VX@;6%R:R!O9B!T:&4@8$]P
M96X@4V]U<F-E($EN:71I871I=F5@7RX*"BXN(%]@3W!E;B!3;W5R8V4@26YI
M=&EA=&EV96`Z(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O"@H*3V)T86EN
M:6YG($UN96UO"BTM+2TM+2TM+2TM+2TM+0H*1G5R=&AE<B!I;F9O<FUA=&EO
M;B!O;B!-;F5M;R!A;F0@=&AE(&QA=&5S="!V97)S:6]N(&-A;B!B92!O8G1A
M:6YE9"!A=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]M;F5M;R\*"@I$;V-U
M;65N=&%T:6]N"BTM+2TM+2TM+2TM+2T*"E1H92!F;VQL;W=I;F<@9&]C=6UE
M;G1A=&EO;B!I<R!A=F%I;&%B;&4@:6X@=&AE($UN96UO(&1I<W1R:6)U=&EO
M;CH*"CI214%$345?.B`@("`@("`@("`@(%1H:7,@9FEL90HZ3$E#14Y315\Z
M("`@("`@("`@("!#;W!Y<FEG:'0@86YD(&QI8V5N<V4@:6YF;W)M871I;VX*
M.F!D;V-S+T-(04Y'15-@7SH@("`@0VAA;F=E<R!B>2!R96QE87-E"CI@9&]C
M<R]#4D5$25138%\Z("`@(%!R;VIE8W0@9&5V96QO<&5R<PHZ8&1O8W,O24Y3
M5$%,3&!?.B`@("!);G-T86QL871I;VX@:6YS=')U8W1I;VYS(&%N9"!N;W1E
M<PHZ8&1O8W,O5$]$3V!?.B`@("`@("!$979E;&]P;65N="!43T1/(&QI<W0*
M.F!D;V-S+U501U)!1$E.1V!?.B`@4&]I;G1E<G,@;VX@=7!G<F%D:6YG(&9R
M;VT@<')E=FEO=7,@36YE;6\@=F5R<VEO;G,*"@I);G-T86QL871I;VX*+2TM
M+2TM+2TM+2TM"@I);G-T<G5C=&EO;G,@9F]R(&EN<W1A;&QI;F<@36YE;6\@
M8V%N(&)E(&9O=6YD(&EN('1H92!F:6QE($E.4U1!3$Q?(&EN('1H90I@8&1O
M8W,O8&`@9&ER96-T;W)Y(&]F('1H92!-;F5M;R!D:7-T<FEB=71I;VXN"@H*
M07-S:7-T86YC90HM+2TM+2TM+2TM"@I)9B!Y;W4@96YC;W5N=&5R('!R;V)L
M96US('=I=&@@36YE;6\L(&AE;'`@:7,@879A:6QA8FQE(2`*"E1H92!(;W)D
M92!&<F5Q=65N=&QY($%S:V5D(%%U97-T:6]N<R!,:7-T("A&05$I+"!A=F%I
M;&%B;&4@;VX@=&AE(%=E8B!A=`H@"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M9F%Q+PH*5&AE($AO<F1E(%!R;VIE8W0@<G5N<R!A(&YU;6)E<B!O9B!M86EL
M:6YG(&QI<W1S+"!F;W(@:6YD:79I9'5A;"!A<'!L:6-A=&EO;G,*86YD(&9O
M<B!I<W-U97,@<F5L871I;F<@=&\@=&AE('!R;VIE8W0@87,@82!W:&]L92X@
M($EN9F]R;6%T:6]N+"!A<F-H:79E<RP@86YD"G-U8G-C<FEP=&EO;B!I;F9O
M<FUA=&EO;B!C86X@8F4@9F]U;F0@870*"B`@:'1T<#HO+W=W=RYH;W)D92YO
M<F<O;6%I;"\*"DQA<W1L>2P@2&]R9&4@9&5V96QO<&5R<RP@8V]N=')I8G5T
M;W)S(&%N9"!U<V5R<R!A;'-O(&UA:V4@;V-C87-I;VYA;`IA<'!E87)A;F-E
M<R!O;B!)4D,L(&]N('1H92!C:&%N;F5L("-H;W)D92!O;B!T:&4@1G)E96YO
M9&4@3F5T=V]R:PHH:7)C+F9R965N;V1E+FYE="DN"@H*3&EC96YS:6YG"BTM
M+2TM+2TM+0H*1F]R(&QI8V5N<VEN9R!A;F0@8V]P>7)I9VAT(&EN9F]R;6%T
M:6]N+"!P;&5A<V4@<V5E('1H92!F:6QE($Q)0T5.4T5?(&EN('1H90I-;F5M
M;R!D:7-T<FEB=71I;VXN"@I4:&%N:W,L"@I4:&4@36YE;6\@=&5A;0H*"BXN
M(%]214%$344Z(#]F/5)%041-12YH=&UL"BXN(%],24-%3E-%.B!H='1P.B\O
M=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP"BXN(%]D;V-S+T-(04Y'
M15,Z(#]F/4-(04Y'15,N:'1M;`HN+B!?9&]C<R]#4D5$2513.B`_9CU#4D5$
M2513+FAT;6P*+BX@7TE.4U1!3$PZ"BXN(%]D;V-S+TE.4U1!3$PZ(#]F/4E.
M4U1!3$PN:'1M;`HN+B!?9&]C<R]43T1/.B`_9CU43T1/+FAT;6P*+BX@7V1O
M8W,O55!'4D%$24Y'.B`_9CU54$=2041)3D<N:'1M;`H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]M;F5M;R]D;V-S+T-(04Y'15,`````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S-S(Q`#$P-#$W,S8R
M-S0V`#`Q-S0V-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````M+2TM"G8R+C$*+2TM+0H*6VIA;ET@1FEX('!O<G1A;"!B;&]C
M:R!I9B!U<V5D('=I=&@@2V]L86(@9')I=F5R("AT;VMO94!K9&4N;W)G+"!"
M=6<@(S(W,S4I+@I;:F%N72!!9&0@4G5S<VEA;B!T<F%N<VQA=&EO;B`H06QE
M>&5Y(%IA:VAA<F]V(#QB86)E<D!M;W-G82YN970^*2X*6V)E;ET@0F5T=&5R
M('-U<'!O<G0@9F]R($U3+5-13"X*"@HM+2TM+2TM+0IV,BXQ+5)#,0HM+2TM
M+2TM+0H*6VIA;ET@0V]N9FER;2!N;W1E(&1E;&5T:6]N<R`H4F5Q=65S="`C
M,3$U-BDN"EMJ86Y=($%D9"!#3$D@<V-R:7!T('1O(&EM<&]R="!V3F]T92!D
M871A+@I;8VIH72!!9&0@<W5P<&]R="!F;W(@9'EN86UI8R!R92US;W)T:6YG
M(&]F('1H92!N;W1E(&QI<W0L(&EN8VQU9&EN9R!S879I;F<*("`@("`@=&AE
M('-O<G0@<')E9F5R96YC97,@;VX@86YY(&-H86YG97,N"EMJ86Y=(%-H;W<@
M8VAA<F%C=&5R(&-O=6YT(&YE>'0@=&\@;F]T97,N"EMM87-=($-H86YG92!A
M;GD@;W5T<'5T(&]F(#QB/B!A;F0@/&D^('1A9W,@=&\@/'-T<F]N9SX@86YD
M(#QE;3X@9F]R(&)E='1E<@H@("`@("!A8V-E<W-I8FEL:71Y('-U<'!O<G0N
M"EMJ86Y=($%D9"!P97)M:7-S:6]N<R!T;R!R97-T<FEC="!N=6UB97(@;V8@
M;F]T97,N"@H*+2TM+2TM"G8R+C`N,PHM+2TM+2T*"EMC:FA=($-L;W-E('-E
M=F5R86P@6%-3('9U;&YE<F%B:6QI=&EE<R!W:71H(&YO=&4@86YD(&YO=&5P
M860@9&%T82X*"@HM+2TM+2T*=C(N,"XR"BTM+2TM+0H*6VIA;ET@06QL;W<@
M=&\@:6UP;W)T(&UO<F4@=&AA;B!O;F4@;F]T92!F<F]M('9.;W1E(&1A=&$@
M870@;VYC92X*"@HM+2TM+2TM+2TM"G8R+C`N,BU20S$*+2TM+2TM+2TM+0H*
M6V-J:%T@1FEX(')E<V5T=&EN9R!C871E9V]R:65S('1O(%5N9FEL960@*$)U
M9R`C,C`Q."DN"EMC:FA=(%5S92!B:6YD('9A<FEA8FQE<R!I;B!344P@9')I
M=F5R+"!C;&5A;B!U<"!R97%U:7)E9"!P87)A;65T97)S"B`@("`@("AS96QS
M:WE`8V]L=6UB:6$N961U+"!"=6<@(S$W.3$I+@I;8VIH72!!9&0@82!0;W-T
M9W)E4U%,('5P9W)A9&4@<V-R:7!T("A"=6<@(S$W-SDI+@I;8VIH72!"971T
M97(@97)R;W(@:&%N9&QI;F<@=VAE;B!D96QE=&EN9R!S:&%R97,@=&AA="!D
M;VXG="!E>&ES="`H0G5G(",Q-S4T*2X*6VIA;ET@061D($IA<&%N97-E('1R
M86YS;&%T:6]N("A(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N
M86,N:G`^*2X*6VIA;ET@061D('-H;W)T8W5T(&EC;VX@*&9A=FEC;VXN:6-O
M*2X*"@HM+2TM+2T*=C(N,"XQ"BTM+2TM+0H*6VIA;ET@1FEX('!R:6YT('9I
M97<N"EMJ86Y=($9I>"!P<FEN="!B=71T;VXN"@H*+2TM+0IV,BXP"BTM+2T*
M"EMC:FA=(%5)1',@;F5E9"!T;R!B92!S=&]R960@:6X@=&AE($AI<W1O<GD@
M<WES=&5M('=I=&@@82!M;F5M;SH@<')E9FEX(&%N9`H@("`@("!W:71H('1H
M92!N;W1E<&%D('-O(&%S(&YO="!T;R!C;VYF=7-E(&1I9F9E<F5N="!I;G-T
M86YC97,@;V8@=&AE"B`@("`@('-A;64@;F]T92`H:68@='=O('5S97)S(&)O
M=&@@:&%V92!A(&YO=&4@;VX@=&AE:7(@<V5P97)A=&4@;F]T97!A9',L"B`@
M("`@('1H97D@<VAO=6QD(&AA=F4@=6YI<75E(&AI<W1O<FEE<R!F;W(@=&AA
M="!N;W1E*2X*6V-J:%T@1&]N)W0@=&AR;W<@82!F871A;"!E<G)O<B!I9B!A
M;B!E;7!T>2!S:&%R92!N86UE(&ES('-U8FUI='1E9`H@("`@("`H0G5G(",Q
M,#`P*2X*"@HM+2TM+2TM+0IV,BXP+5)#,PHM+2TM+2TM+0H*6V-J:%T@061D
M($UY($YO=&5P861S(&UE;G4@96YT<GDN"@H*+2TM+2TM+2T*=C(N,"U20S(*
M+2TM+2TM+2T*"EMJ86Y=($%D9"!#>F5C:"!T<F%N<VQA=&EO;B`H4&%V96P@
M0VAY=&EL(#QP879E;$!C:'ET:6PN=&L^*2X*6VIA;ET@061D($QA='9I86X@
M=')A;G-L871I;VX@*$IA;FES($5I<V%K<R`\:F%N8W-`9'8N;'8^*2X*"@HM
M+2TM+2TM+0IV,BXP+5)#,0HM+2TM+2TM+0H*6VIA;ET@5'=E86L@;&%Y;W5T
M(&]F('1H92!S=6UM87)Y(&)L;V-K+@H*"BTM+2TM+2TM+0IV,BXP+4)%5$$*
M+2TM+2TM+2TM"@I;:F%N72!!9&0@4&]L:7-H('1R86YS;&%T:6]N("A-871E
M=7-Z($MA;6EN<VMI(#QM871I<&Q`9',N<&<N9V1A+G!L/BDN"EMJ86Y=($%D
M9"!S<&5C:6%L(&)L86-K+6]N+7=H:71E('-T>6QE<R!F;W(@;65S<V%G92!P
M<FEN=&EN9RX*6VIA;ET@061D(&%C8V5S<R!K97ES+@I;8VIH72!!9&0@2V]L
M86(@9')I=F5R<R`H4W1U87)T($)I;F?K(#QS+F)I;F=E0&-O9&5F=7-I;VXN
M8V\N>F$^*2X*"@HM+2TM+2TM+2TM"G8R+C`M04Q02$$*+2TM+2TM+2TM+0H*
M6V-J:%T@1U5)1',@;F]W(&]N;'D@8V]N=&%I;B!M;F5M;SH@86YD('1H92!N
M;W1E($E$("T@<VAA<F5N86UE(&ES(&YO="!N965D960N"EMC:FA=($YO=&4@
M241S(&%R92!N;W<@,S(M8VAA<F%C=&5R('5N:7%U92!S=')I;F=S+"!T;R!B
M92!U<V5A8FQE(&%S($=5241S+@H@("`@("!4:&4@4U%,('1A8FQE(&1E9FEN
M:71I;VX@:&%S(&-H86YG960[(&-O;G9E<G-I;VX@<V-R:7!T<R!A<F4@:6X@
M<V-R:7!T<R\N"EMC:FA=(%1H92!N;W1E<R\@05!)(&YO=R!I;7!L96UE;G1S
M('1H92!M;V1E<FX@;65T:&]D<R!R97%U:7)E9"!F;W(@4WEN8TU,(&%N9`H@
M("`@("!O=&AE<B!S>6YC:6YG(&5F9F]R=',N"EMC:FA=($UA:V4@<W5R92!T
M:&5R92!I<R!A('9I97<@;&EN:R!F;W(@96UP='D@;F]T97,N"EMC:FA=($%D
M9"!A($1E;&5T92!L:6YK(&9R;VT@=&AE(&YO=&4@961I="!S8W)E96XN"EMC
M:FA=($UA:V4@<W5R92!T:&%T('1H92!C;W)R96-T(&-A=&5G;W)I97,@9F]R
M(&$@;F]T92=S(&-U<G)E;G0@;F]T97!A9`H@("`@("!A<F4@86QW87ES('5S
M960N"EMC:FA=($-H86YG92!H;W<@;65M;W,@87)E('-T;W)E9"!I;B!T:&4@
M4U%,(&1R:79E<BX*("`@("`@<V-R:7!T<R]C<F5A=&5?<V5Q=65N8V4N<&AP
M('=I;&P@=7!D871E(&%N(&5X:7-T:6YG(&1A=&%B87-E('=I=&@@;F\*("`@
M("`@;&]S<R!O9B!D871A+@I;8VIH72!$:7-P;&%Y('1H92!#<F5A=&EO;B!A
M;F0@3&%S="U-;V1I9FEE9"!D871E<R!I;B!T:&4@;F]T92!V:65W+@I;8VIH
M72!4<F%C:R!A9&1I=&EO;BP@;6]D:69I8V%T:6]N+"!A;F0@9&5L971I;VX@
M;V8@;F]T97,*("`@("`@=VET:"!T:&4@2&]R9&4@2&ES=&]R>3HZ($%022X*
M6V-J:%T@061D(&EM<&]R="!O9B!V3F]T97,N"EMC:FA=(%-H;W<@=&AE(&9U
M;&P@;65M;R!B;V1Y(&EN(&$@=&]O;'1I<"X*6V-J:%T@061D(&$@<')E9F5R
M96YC92!F;W(@=&AE(&1E9F%U;'0@8V%T96=O<GD@9F]R(&YO=&5S"B`@("`@
M("A"<FEA;B!+96EF97(@/&)R:6%N0'9A;&EN;W(N;F5T/BDN"EMJ86Y=($%D
M9"!55$8M."!S=7!P;W)T(&%N9"!C:&%R<V5T('!A<F%M971E<B!F;W(@8F%C
M:V5N9"!D<FEV97)S+@I;:F%N72!/;FQY('-H;W<@<V5L96-T960@;F]T92!C
M871E9V]R:65S(&]N('1H92!S=6UM87)Y('-C<F5E;@H@("`@("`H0G)I86X@
M2V5I9F5R(#QB<FEA;D!V86QI;F]R+FYE=#XI+@I;8VIH72!-=6-H(&UO<F4@
M8V]M<')E:&5N<VEV92!P97)M:7-S:6]N<R!C:&5C:VEN9RP@86YD('-U<'!O
M<G0@9F]R"B`@("`@(&=U97-T(&%C8V5S<RX*6V-J:%T@57-E('1H92!G;&]B
M86P@<VAA<F5S(&5D:71I;F<@<&%G92!F;W(@8VAA;F=I;F<O87-S:6=N:6YG
M('-H87)E"B`@("`@('!E<FUI<W-I;VYS+@I;;6%C72!!;&QO=R!I;7!O<G1I
M;F<@;VYT;R!A;GD@879A:6QA8FQE($YO=&5P860N"EMM86-=($%D9"!S:&%R
M960@;F]T97!A9',N"@H*+2TM+2TM"G8Q+C$N-`HM+2TM+2T*"EMJ86Y=($-L
M;W-E(%A34R!W:&5N('-E='1I;F<@=&AE('!A<F5N="!F<F%M92=S('!A9V4@
M=&ET;&4@8GD@:F%V87-C<FEP="`H8VIH*2X*"@HM+2TM+2T*=C$N,2XS"BTM
M+2TM+0H*6VIA;ET@061D(%!O;&ES:"!T<F%N<VQA=&EO;B`H36%T975S>B!+
M86UI;G-K:2`\;6%T:7!L0&1S+G!G+F=D82YP;#XI+@H*"BTM+2TM+0IV,2XQ
M+C(*+2TM+2TM"@I;:F%N72!-86ME(&UE;6]S('=I=&AO=70@9&5S8W)I<'1I
M;VX@86-C97-S:6)L92!F<F]M('1H92!M96UO(&QI<W0N"@H*+2TM+2TM"G8Q
M+C$N,0HM+2TM+2T*"EMJ86Y=($%D9"!)=&%L:6%N('1R86YS;&%T:6]N("A3
M97)G:6\@1RX@0V%R961D82`\<V-A<F5D9&%`=&ES8V%L:2YI=#XI+@I;:F%N
M72!!9&0@4F]M86YI86X@=')A;G-L871I;VX@*$5U9V5N($AO86YC82`\975G
M96YH0'5R8F%N+6=R869X+G)O/BP*("`@("`@36%R:75S($1R86=U;&5S8W4@
M/&UA<FEU<V1`=7)B86XM9W)A9G@N<F\^*2X*"@HM+2TM"G8Q+C$*+2TM+0H*
M6VIA;ET@4F5N86UE($UE;6]S('1O($YO=&5S("AM86,I+@I;:F%N72!!9&0@
M<')I;G0@;65M;R!B=71T;VX@*&UA8RDN"EMJ86Y=(%-H;W<@8W5R<F5N="!C
M871E9V]R>2!C;VQO<B!I;B!C871E9V]R>2!C;VQO<B!O<'1I;VYS('-C<F5E
M;@H@("`@("`H2F%N($MU:7!E<G,@/&IR:W5I<&5R<T!L875W97)S8V]L;&5G
M92YN;#XI+@I;:F%N72!!9&0@86)I;&ET>2!T;R!C<F5A=&4O<F5M;W9E(&-A
M=&5G;W)I97,@*&UA8RDN"EMJ86Y=($%D9"!U<V5R('!R969E<F5N8V5S(&9O
M<B!T:&4@8V]L;W(@;V8@9&EF9F5R96YT(&-A=&5G;W)I97,@*&UA8RDN"EMJ
M86Y=($%D9"!-;F5M;SHZ861D4&%R86UE=&5R*"DN"EMJ86Y=($%D9"!'<F5E
M:R!T<F%N<VQA=&EO;B`H4W1E9F%N;W,@22X@1&EM:71R:6]U(#QS9&EM:71R
M:4!T96EA=&@N9W(^*2X*6VIA;ET@061D(%-L;W9A:R!T<F%N<VQA=&EO;B`H
M279A;B!.;W)I<R`\=FEX0'9A>FMA+G-K/BDN"EMJ86Y=($%D9"!.;W)W96=I
M86X@0F]K;6%A;"!T<F%N<VQA=&EO;B`H5&]R<W1E:6X@4RX@2&%N<V5N(#QH
M=6QE8F]E<D!T96-H8F5E+FYO/BDN"EMJ86Y=($%D9"!"=6QG87)I86X@=')A
M;G-L871I;VX@*$UI<F]S;&%V(%!E;F1E=B`\;6ER;T!C>6)E<G-H861E+G5S
M/BDN"EMJ86Y=($%D9"!,:71H=6%N:6%N('1R86YS;&%T:6]N("A$87)I=7,@
M36%T=6QI875S:V%S(#QD87)I=7-`;&YK+FQT/BDN"EMJ86Y=(%)E<&QA8V4@
M/#\]('=I=&@@/#]P:'`@96-H;R!T;R!R96UO=F4@=&AE('-H;W)T7V]P96Y?
M=&%G<R!R97%U:7)E;65N="`H8VIH*2X*6VIA;ET@061D($1A;FES:"!T<F%N
M<VQA=&EO;B`H36%R=&EN($QI<W0M4&5T97)S96X@/&UA<G1I;D!L:7-T+7!E
M=&5R<V5N+F1K/BDN"@H*+2TM+0IV,2XP"BTM+2T*"EMJ86Y=($%D9"!(=6YG
M87)I86X@=')A;G-L871I;VX@*$QA<WIL;R!,+B!4;W)N;V-I(#QT;W)L87-Z
M0'AE;FEA+G-O=&4N:'4^*2X*6VIA;ET@061D(%-I;7!L:69I960@0VAI;F5S
M92!T<F%N<VQA=&EO;B`H4&5T97(@5V%N9R`\=VAW0&]U;&EN:RYN970^*2X*
M6VIA;ET@061D($-Z96-H('1R86YS;&%T:6]N("A0879E;"!#:'ET:6P@/'!A
M=F5L0&-H>71I;"YT:SXI+@I;:F%N72!!9&0@0G)A>FEL:6%N(%!O<G1U9W5E
M<V4@=')A;G-L871I;VX@*$%N=&]N:6\@1&EA<R`\86-C9&EA<RUH;W)D92UI
M,3AN0'-S="YC;VTN8G(^*2X*6VIA;ET@061D($1U=&-H('1R86YS;&%T:6]N
M("A*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL/BDN
M"EMJ86Y=($%D9"!&<F5N8V@@=')A;G-L871I;VX@*%1H:65R<GD@5&AO;6%S
M(#QT:&EE<G)Y0'!O;7!O+FYE=#XI+@I;:F%N72!!9&0@1FEN;FES:"!T<F%N
M<VQA=&EO;B`H3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3XI+@I;:F%N72!!
M9&0@3F]R=V5G:6%N($YY;F]R<VL@=')A;G-L871I;VX@*%!E<BU3=&EA;B!6
M871N92`\<'-V0&]R<W1A+F]R9SXI+@I;:F%N72!!9&0@5')A9&ET:6]N86P@
M0VAI;F5S92!T<F%N<VQA=&EO;B`H0VAI:"U796D@665H(#QC=WEE:$!C8V-A
M+FYC='4N961U+G1W/BDN"EMJ86Y=($%D9"!3=V5D:7-H('1R86YS;&%T:6]N
M("A!;F1R96%S($1A:&SI;B`\86YD<F5A<T!D86AL96XN=W,^*2X*6VIA;ET@
M061D(%-P86YI<V@@=')A;G-L871I;VX@*%)A=6P@06QV87)E>B!696YE9V%S
M(#QR879`=&5C;VUA;BYU8V]L+FUX/BDN"EMJ86Y=($%D9"!'97)M86X@=')A
M;G-L871I;VXN"EMJ86Y=($%D9"!0;W)T=6=U97-E('1R86YS;&%T:6]N("A.
M=6YO($QO=7)E:7)O(#QN=6YO0&-O+F5T:"YP=#XI+@I;8VIH72!);FET:6%L
M($UN96UO('9E<G-I;VXL(&)A<V5D(&]N($YA9RX*````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VUN96UO+V1O8W,O0U)%1$E44P``````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4S-30`,3`T,3<S-C(W-#8`
M,#$W-3$U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@36YE;6\@1&5V96QO<&UE
M;G0@5&5A;0H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T
M93H@("`D1&%T93H@,C`P-B\P,2\S,2`R,3HQ,SHR,2`D"CI2979I<VEO;CH@
M("`@("`D4F5V:7-I;VXZ(#$N,S(N-BXX("0*.D-O;G1A8W0Z("`@("`@(&UN
M96UO0&QI<W1S+FAO<F1E+F]R9PH*"D-O<F4@1&5V96QO<&5R<PH]/3T]/3T]
M/3T]/3T]/3T*"BT@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"BT@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*"@I,;V-A;&EZ871I
M;VX*/3T]/3T]/3T]/3T]"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T@("`]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*0G)A>FEL:6%N(%!O<G1U9W5E<V4@("`@06YT;VYI;R!$:6%S(#QA
M8V-D:6%S+6AO<F1E+6DQ.&Y`<W-T+F-O;2YB<CX*("`@("`@("`@("`@("`@
M("`@("`@("`@1F%B:6\@1V]M97,@/&9L9V]M97-`9F%Z96YD82YS<"YG;W8N
M8G(^"D)U;&=A<FEA;B`@("`@("`@("`@("`@($UI<F]S;&%V(%!E;F1E=B`\
M;6ER;T!C>6)E<G-H861E+G5S/@I#:&EN97-E("A3:6UP;&EF:65D*2`@("!0
M971E<B!786YG(#QW:'=`;W5L:6YK+FYE=#X*0VAI;F5S92`H5')A9&ET:6]N
M86PI("`@0VAI:"U796D@665H(#QC=WEE:$!C8V-A+FYC='4N961U+G1W/@I#
M>F5C:"`@("`@("`@("`@("`@("`@("!0879E;"!#:'ET:6P@/'!A=F5L0&-H
M>71I;"YT:SX*1&%N:7-H("`@("`@("`@("`@("`@("`@36%R=&EN($QI<W0M
M4&5T97)S96X@/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K/@I$=71C:"`@("`@
M("`@("`@("`@("`@("!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C
M;VQL96=E+FYL/@I&:6YN:7-H("`@("`@("`@("`@("`@("!,965N82!(96EN
M;R`\;&EI;G5`=71A+F9I/@I&<F5N8V@@("`@("`@("`@("`@("`@("!4:&EE
M<G)Y(%1H;VUA<R`\=&AI97)R>4!P;VUP;RYN970^"D=E<FUA;B`@("`@("`@
M("`@("`@("`@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"D=R965K
M("`@("`@("`@("`@("`@("`@(%-T969A;F]S($DN($1I;6ET<FEO=2`\<W5P
M<&]R=%]W96)M86EL0'1E:6%T:"YG<CX*("`@("`@("`@("`@("`@("`@("`@
M("`@4VEL;&EG87)D;W,@6')I<W1O9F]R;W,*("`@("`@("`@("`@("`@("`@
M("`@("`@06YA9VYO<W1O<&]U;&]S($%P;W-T;VQI<PI(=6YG87)I86X@("`@
M("`@("`@("`@("!,87-Z;&\@3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS
M;W1E+FAU/@I)=&%L:6%N("`@("`@("`@("`@("`@("!397)G:6\@1RX@0V%R
M961D82`\<V-A<F5D9&%`=&ES8V%L:2YI=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@36%R:V\@1&IU:VEC(#QT96-H0&]B;&\N8V]M/@H@("`@("`@("`@
M("`@("`@("`@("`@("!-87)C;R!0:7)O=F%N;R`\;6%R8V\N<&ER;W9A;F]`
M=6YI+6)O8V-O;FDN:70^"B`@("`@("`@("`@("`@("`@("`@("`@($-R:7-T
M:6%N($UA;F]N:2`\8W)I<W1I86XN;6%N;VYI0&YE=&AE<VES+FET/@I*87!A
M;F5S92`@("`@("`@("`@("`@("!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C
M+G1S=6MU8F$N86,N:G`^"DQA='9I86X@("`@("`@("`@("`@("`@($IA;FES
M($5I<V%K<R`\:F%N8W-`9'8N;'8^"DQI=&AU86YI86X@("`@("`@("`@("`@
M($1A<FEU<R!-871U;&EA=7-K87,@/&1A<FEU<T!L;FLN;'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@(%9I;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT
M/@I.;W)W96=I86X@0F]K;6%A;"`@("`@("!4;W)S=&5I;B!3+B!(86YS96X@
M/&AU;&5B;V5R0'1E8VAB964N;F\^"DYO<G=E9VEA;B!.>6YO<G-K("`@("`@
M(%!E<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R9SX*4&]L:7-H("`@("`@
M("`@("`@("`@("`@36%T975S>B!+86UI;G-K:2`\;6%T:7!L0&1S+G!G+F=D
M82YP;#X*4&]R='5G=65S92`@("`@("`@("`@("`@3G5N;R!,;W5R96ER;R`\
M;G5N;T!C;RYE=&@N<'0^"B`@("`@("`@("`@("`@("`@("`@("`@($UA;G5E
M;"!-96YE>F5S(&1E(%-E<75E:7)A(#Q-86YU96PN4V5Q=65I<F$^"E)O;6%N
M:6%N("`@("`@("`@("`@("`@($5U9V5N($AO86YC82`\975G96YH0'5R8F%N
M+6=R869X+G)O/@H@("`@("`@("`@("`@("`@("`@("`@("!-87)I=7,@1')A
M9W5L97-C=2`\;6%R:75S9$!U<F)A;BUG<F%F>"YR;SX*4G5S<VEA;B`@("`@
M("`@("`@("`@("`@06QE>&5Y(%IA:VAA<F]V(#QB86)E<D!M;W-G82YN970^
M"E-L;W9A:R`@("`@("`@("`@("`@("`@($EV86X@3F]R:7,@/'9I>$!V87IK
M82YS:SX*4W!A;FES:"`@("`@("`@("`@("`@("`@4F%U;"!!;'9A<F5Z(%9E
M;F5G87,@/')A=D!T96-O;6%N+G5C;VPN;7@^"B`@("`@("`@("`@("`@("`@
M("`@("`@($UA;G5E;"!097)E>B!!>6%L82`\;7!E<F%Y84!A;&-A>F%B82YU
M;F5X+F5S/@I3=V5D:7-H("`@("`@("`@("`@("`@("!!;F1R96%S($1A:&SI
M;B`\86YD<F5A<T!D86AL96XN=W,^"B`@("`@("`@("`@("`@("`@("`@("`@
M($IO87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/@I4
M=7)K:7-H("`@("`@("`@("`@("`@("!)<W1A;F)U;"!496-H;FEC86P@56YI
M=F5R<VET>2!)5"!$97!A<G1M96YT"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QI='5B:6U`:71U+F5D=2YT<CX*/3T]/3T]/3T]/3T]/3T]/3T]/3T]("`@
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE
M;6\O9&]C<R])3E-404Q,````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q-3<U-P`Q,#0Q-S,V,C<T-@`P,3<U,S8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H@26YS=&%L;&EN9R!-;F5M;R`R+C$*/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H*5&AI<R!D;V-U;65N="!C;VYT86EN<R!I;G-T<G5C=&EO
M;G,@9F]R(&EN<W1A;&QI;F<@=&AE($UN96UO('=E8BUB87-E9"!N;W1E<PIA
M<'!L:6-A=&EO;B!O;B!Y;W5R('-Y<W1E;2X*"D9O<B!I;F9O<FUA=&EO;B!O
M;B!T:&4@8V%P86)I;&ET:65S(&%N9"!F96%T=7)E<R!O9B!-;F5M;RP@<V5E
M('1H92!F:6QE"E)%041-15\@:6X@=&AE('1O<"UL979E;"!D:7)E8W1O<GD@
M;V8@=&AE($UN96UO(&1I<W1R:6)U=&EO;BX*"@I/8G1A:6YI;F<@36YE;6\*
M/3T]/3T]/3T]/3T]/3T]"@I-;F5M;R!C86X@8F4@;V)T86EN960@9G)O;2!T
M:&4@2&]R9&4@=V5B<VET92!A;F0@1E10('-E<G9E<BP@870*"B`@(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VUN96UO+PH*("`@9G1P.B\O9G1P+FAO<F1E+F]R
M9R]P=6(O;6YE;6\O"@I";&5E9&EN9RUE9&=E(&1E=F5L;W!M96YT('9E<G-I
M;VYS(&]F($UN96UO(&%R92!A=F%I;&%B;&4@=FEA($-64SL@<V5E('1H90IF
M:6QE(&!D;V-S+TA!0TM)3D=@7R!I;B!T:&4@2&]R9&4@9&ES=')I8G5T:6]N
M(&9O<B!I;F9O<FUA=&EO;B!O;B!A8V-E<W-I;F<*=&AE($AO<F1E($-64R!R
M97!O<VET;W)Y+@H*"E!R97)E<75I<VET97,*/3T]/3T]/3T]/3T]/0H*5&\@
M9G5N8W1I;VX@<')O<&5R;'DL($UN96UO(')E<75I<F5S('1H92!F;VQL;W=I
M;F<Z"@HQ+B!!('=O<FMI;F<@2&]R9&4@:6YS=&%L;&%T:6]N+@H*("`@36YE
M;6\@<G5N<R!W:71H:6X@=&AE(&!(;W)D92!!<'!L:6-A=&EO;B!&<F%M97=O
M<FM@7RP@82!S970@;V8@8V]M;6]N('1O;VQS"B`@(&9O<B!796(@87!P;&EC
M871I;VYS('=R:71T96X@:6X@4$A0+B`@66]U(&UU<W0@:6YS=&%L;"!(;W)D
M92!B969O<F4*("`@:6YS=&%L;&EN9R!-;F5M;RX*"B`@("XN(%]@2&]R9&4@
M07!P;&EC871I;VX@1G)A;65W;W)K8#H@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M:&]R9&4O"@H@("!4:&4@2&]R9&4@1G)A;65W;W)K(&-A;B!B92!O8G1A:6YE
M9"!F<F]M('1H92!(;W)D92!W96)S:71E(&%N9"!&5%`@<V5R=F5R+`H@("!A
M=`H*("`@("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O:&]R9&4O"@H@("`@("!F
M='`Z+R]F='`N:&]R9&4N;W)G+W!U8B]H;W)D92\*"B`@($UA;GD@;V8@36YE
M;6\G<R!P<F5R97%U:7-I=&5S(&%R92!A;'-O($AO<F1E('!R97)E<75I<VET
M97,N("!"92!S=7)E('1O"B`@(&AA=F4@8V]M<&QE=&5D(&%L;"!O9B!T:&4@
M<W1E<',@:6X@=&AE($E.4U1!3$Q?(&9I;&4@9F]R('1H92!(;W)D90H@("!&
M<F%M97=O<FL@8F5F;W)E(&EN<W1A;&QI;F<@36YE;6\N"@HR+B!344P@<W5P
M<&]R="!I;B!02%`N"@H@("!-;F5M;R!S=&]R97,@:71S(&1A=&$@:6X@86X@
M4U%,(&1A=&%B87-E+B`@0G5I;&0@4$A0('=I=&@@=VAI8VAE=F5R(%-13`H@
M("!D<FEV97(@>6]U(')E<75I<F4[('-E92!T:&4@2&]R9&4@24Y35$%,3%\@
M9FEL92!F;W(@9&5T86EL<RX*"@I);G-T86QL:6YG($UN96UO"CT]/3T]/3T]
M/3T]/3T]/3T*"DUN96UO(&ES('=R:71T96X@:6X@4$A0+"!A;F0@;75S="!B
M92!I;G-T86QL960@:6X@82!W96(M86-C97-S:6)L92!D:7)E8W1O<GDN"E1H
M92!P<F5C:7-E(&QO8V%T:6]N(&]F('1H:7,@9&ER96-T;W)Y('=I;&P@9&EF
M9F5R(&9R;VT@<WES=&5M('1O('-Y<W1E;2X*0V]N=F5N=&EO;F%L;'DL($UN
M96UO(&ES(&EN<W1A;&QE9"!D:7)E8W1L>2!U;F1E<FYE871H($AO<F1E(&EN
M('1H90IW96)S97)V97(G<R!D;V-U;65N="!T<F5E+@H*4VEN8V4@36YE;6\@
M:7,@=W)I='1E;B!I;B!02%`L('1H97)E(&ES(&YO(&-O;7!I;&%T:6]N(&YE
M8V5S<V%R>3L@<VEM<&QY"F5X<&%N9"!T:&4@9&ES=')I8G5T:6]N('=H97)E
M('EO=2!W86YT(&ET('1O(')E<VED92!A;F0@<F5N86UE('1H92!R;V]T"F1I
M<F5C=&]R>2!O9B!T:&4@9&ES=')I8G5T:6]N('1O('=H871E=F5R('EO=2!W
M:7-H('1O(&%P<&5A<B!I;B!T:&4@55),+B`@1F]R"F5X86UP;&4L('=I=&@@
M=&AE($%P86-H92!W96)S97)V97(G<R!D969A=6QT(&1O8W5M96YT(')O;W0@
M;V8*8&`O=7-R+VQO8V%L+V%P86-H92]H=&1O8W-@8"P@>6]U('=O=6QD('1Y
M<&4Z.@H*("`@8V0@+W5S<B]L;V-A;"]A<&%C:&4O:'1D;V-S+VAO<F1E"B`@
M('1A<B!Z>'9F("]P871H+W1O+VUN96UO+7@N>2YZ+G1A<BYG>@H@("!M=B!M
M;F5M;RUX+GDN>B!M;F5M;PH*86YD('=O=6QD('1H96X@9FEN9"!-;F5M;R!A
M="!T:&4@55),.CH*"B`@(&AT='`Z+R]Y;W5R+7-E<G9E<B]H;W)D92]M;F5M
M;R\*"@I#;VYF:6=U<FEN9R!-;F5M;PH]/3T]/3T]/3T]/3T]/3T]/0H*,2X@
M0V]N9FEG=7)I;F<@2&]R9&4@9F]R($UN96UO"@H@("!A+B!296=I<W1E<B!T
M:&4@87!P;&EC871I;VX*"B`@("`@($EN(&!@:&]R9&4O8V]N9FEG+W)E9VES
M=')Y+G!H<&!@+"!F:6YD('1H92!@8&%P<&QI8V%T:6]N<ULG;6YE;6\G76!@
M"B`@("`@('-T86YZ82X@(%1H92!D969A=6QT('-E='1I;F=S(&AE<F4@<VAO
M=6QD(&)E(&]K87D@9F]R(&UO<W0*("`@("`@:6YS=&%L;&%T:6]N<RP@8G5T
M('EO=2!C86X@8VAA;F=E('1H96T@:68@9&5S:7)E9"P@;W(@:68@>6]U(&AA
M=F4@80H@("`@("!N;VXM<W1A;F1A<F0@:6YS=&%L;"X@($EF('EO=2!H879E
M(&-H86YG960@=&AE(&QO8V%T:6]N(&]F($UN96UO"B`@("`@(')E;&%T:79E
M('1O($AO<F1E+"!E:71H97(@:6X@=&AE(%523"!O<B!I;B!T:&4@9FEL97-Y
M<W1E;2!O<B!B;W1H+"!T:&5N"B`@("`@('EO=2!M=7-T('5P9&%T92!T:&4@
M8&!F:6QE<F]O=&!@(&%N9"!@8'=E8G)O;W1@8"!S971T:6YG<R!T;R!T:&5I
M<@H@("`@("!C;W)R96-T('9A;'5E<RX*"B`@(&(N($-O;F9I9W5R:6YG(&$@
M1&%T851R964@8F%C:V5N9`H*("`@("`@36YE;6\@<F5Q=6ER97,@82!P97)M
M86YE;G0@8&!$871A5')E96!@(&)A8VME;F0@:6X@2&]R9&4@=&\@;6%N86=E
M"B`@("`@(&YO=&5P861S(&%N9"!T;R!A9&0@;F]T97,@=&\@;F]T97!A9',N
M("!)9B!Y;W4@9&ED;B=T('-E='5P(&$@1&%T851R964*("`@("`@8F%C:V5N
M9"!Y970L(&=O('1O('1H92!C;VYF:6=U<F%T:6]N(&EN=&5R9F%C92P@<V5L
M96-T($AO<F1E(&9R;VT@=&AE"B`@("`@(&QI<W0@;V8@87!P;&EC871I;VYS
M(&%N9"!S96QE8W0@82!D<FEV97(@9&EF9F5R96YT('1H86X@8&!.;VYE8&`@
M;VX@=&AE"B`@("`@(&!@1&%T851R964@4WES=&5M8&`@=&%B+B`@36%K92!S
M=7)E('1H870@>6]U(')A;B!T:&4@;F5C97-S87)Y('-C<FEP=',*("`@("`@
M=&\@8W)E871E(&$@<W1O<F%G92!B86-K96YD(&9O<B!T:&4@1&%T851R964@
M<WES=&5M+"!E+F<N(&]N92!O9B!T:&4*("`@("`@8&!C<F5A=&4N*BYS<6Q@
M8"!O<B!@8&AO<F1E7V1A=&%T<F5E+BHN<W%L8&`@4U%,('-C<FEP=',@:6X*
M("`@("`@8&!H;W)D92]S8W)I<'1S+W-Q;"]@8"X@(%EO=2!S:&]U;&0@:&%V
M92!D;VYE('1H:7,@86QR96%D>2!D=7)I;F<@=&AE"B`@("`@(&EN<W1A;&QA
M=&EO;B!O9B!(;W)D92X*"C(N($-R96%T:6YG('1H92!D871A8F%S92!T86)L
M90H*("`@5&AE('-P96-I9FEC('-T97!S('1O(&-R96%T92!T:&4@36YE;6\@
M9&%T86)A<V4@=&%B;&4@9&5P96YD(&]N('=H:6-H"B`@(&1A=&%B87-E('EO
M=2=V92!C:&]S96X@=&\@=7-E+@H*("`@1FER<W0L(&QO;VL@:6X@8&!S8W)I
M<'1S+V1R:79E<G,O<W%L+V!@('1O('-E92!I9B!A('-C<FEP="!A;')E861Y
M(&5X:7-T<PH@("!F;W(@>6]U<B!D871A8F%S92!T>7!E+B`@268@<V\L('EO
M=2!S:&]U;&0@8F4@86)L92!T;R!S:6UP;'D@97AE8W5T92!T:&%T"B`@('-C
M<FEP="!A<R!S=7!E<G5S97(@:6X@>6]U<B!D871A8F%S92X@("A.;W1E('1H
M870@97AE8W5T:6YG('1H92!S8W)I<'0@87,*("`@=&AE(")H;W)D92(@=7-E
M<B!W:6QL('!R;V)A8FQY(&9A:6P@=VAE;B!G<F%N=&EN9R!P<FEV:6QE9V5S
M+BD*"B`@($EF('-U8V@@82!S8W)I<'0@9&]E<R!N;W0@97AI<W0L('EO=2=L
M;"!N965D('1O(&)U:6QD('EO=7(@;W=N+"!U<VEN9R!T:&4*("`@9FEL92!M
M;F5M;RYS<6P@87,@82!S=&%R=&EN9R!P;VEN="X@($EF('EO=2!N965D(&%S
M<VES=&%N8V4@:6X@8W)E871I;F<*("`@9&%T86)A<V5S+"!Y;W4@;6%Y('=I
M<V@@=&\@;&5T('5S(&MN;W<@;VX@=&AE($UN96UO(&UA:6QI;F<@;&ES="X*
M"C,N($-O;F9I9W5R:6YG($UN96UO"@H@("!4;R!C;VYF:6=U<F4@36YE;6\L
M(&-H86YG92!T;R!T:&4@8&!C;VYF:6<O8&`@9&ER96-T;W)Y(&]F('1H92!I
M;G-T86QL960*("`@9&ES=')I8G5T:6]N+"!A;F0@;6%K92!C;W!I97,@;V8@
M86QL(&]F('1H92!C;VYF:6=U<F%T:6]N(&!@9&ES=&!@(&9I;&5S"B`@('=I
M=&AO=70@=&AE(&!@9&ES=&!@('-U9F9I>#HZ"@H@("`@("!C9"!C;VYF:6<O
M"B`@("`@(&9O<B!F;V\@:6X@*BYD:7-T.R!D;R!C<"`D9F]O(&!B87-E;F%M
M92`D9F]O("YD:7-T8#L@9&]N90H*("`@1&]C=6UE;G1A=&EO;B!O;B!T:&4@
M9F]R;6%T(&]F('1H;W-E(&9I;&5S(&-A;B!B92!F;W5N9"!I;B!E86-H(&9I
M;&4N("!7:71H"B`@('1H92!E>&-E<'1I;VX@;V8@=&AE(&!@8V]N9BXJ8&`@
M9FEL97,@*'-E92!B96QO=RDL('1H92!O=&AE<B!F:6QE<R!I;@H@("!@8&-O
M;F9I9R]@8"!N965D(&]N;'D@8F4@;6]D:69I960@:68@>6]U('=I<V@@=&\@
M8W5S=&]M:7IE($UN96UO)W,*("`@87!P96%R86YC92!O<B!B96AA=FEO<BP@
M87,@=&AE(&1E9F%U;'1S('=I;&P@8F4@8V]R<F5C="!F;W(@;6]S="!S:71E
M<RX*"B`@(%EO=2!M=7-T(&QO9VEN('1O($AO<F1E(&%S(&$@2&]R9&4@061M
M:6YI<W1R871O<B!T;R!F:6YI<V@@=&AE"B`@(&-O;F9I9W5R871I;VX@;V8@
M36YE;6\N("!5<V4@=&AE($AO<F1E(&!@061M:6YI<W1R871I;VY@8"!M96YU
M(&ET96T@=&\@9V5T"B`@('1O('1H92!A9&UI;FES=')A=&EO;B!P86=E+"!A
M;F0@=&AE;B!C;&EC:R!O;B!T:&4@8&!#;VYF:6=U<F%T:6]N8&`@:6-O;B!T
M;PH@("!G970@=&AE(&-O;F9I9W5R871I;VX@<&%G92X@(%-E;&5C="!@8$YO
M=&5S8&`@9G)O;2!T:&4@<V5L96-T:6]N(&QI<W0@;V8*("`@87!P;&EC871I
M;VYS+B`@1FEL;"!I;B!O<B!C:&%N9V4@86YY(&-O;F9I9W5R871I;VX@=F%L
M=65S(&%S(&YE961E9"X@(%=H96X*("`@9&]N92!C;&EC:R!O;B!@8$=E;F5R
M871E($YO=&5S($-O;F9I9W5R871I;VY@8"!T;R!G96YE<F%T92!T:&4@8&!C
M;VYF+G!H<&!@"B`@(&9I;&4N("!)9B!Y;W5R('=E8B!S97)V97(@9&]E<VXG
M="!H879E('=R:71E('!E<FUI<W-I;VYS('1O('1H92!-;F5M;PH@("!C;VYF
M:6=U<F%T:6]N(&1I<F5C=&]R>2!O<B!F:6QE+"!I="!W:6QL(&YO="!B92!A
M8FQE('1O('=R:71E('1H92!F:6QE+B`@26X*("`@=&AI<R!C87-E+"!G;R!B
M86-K('1O(&!@0V]N9FEG=7)A=&EO;F!@(&%N9"!C:&]O<V4@;VYE(&]F('1H
M92!O=&AE<B!M971H;V1S"B`@('1O(&-R96%T92!T:&4@8V]N9FEG=7)A=&EO
M;B!F:6QE(&!@;6YE;6\O8V]N9FEG+V-O;F8N<&AP8&`N"@H@("!.;W1E(&9O
M<B!I;G1E<FYA=&EO;F%L('5S97)S.B!.86<@=7-E<R!'3E4@9V5T=&5X="!T
M;R!P<F]V:61E(&QO8V%L"B`@('1R86YS;&%T:6]N<R!O9B!T97AT(&1I<W!L
M87EE9"!B>2!A<'!L:6-A=&EO;G,[('1H92!T<F%N<VQA=&EO;G,@87)E(&9O
M=6YD"B`@(&EN('1H92!P;R\@9&ER96-T;W)Y+B`@268@82!T<F%N<VQA=&EO
M;B!I<R!N;W0@>65T(&%V86EL86)L92!F;W(@>6]U<@H@("!L;V-A;&4@*&%N
M9"!Y;W4@=VES:"!T;R!C<F5A=&4@;VYE*2P@<V5E('1H92!@8&AO<F1E+W!O
M+U)%041-16!@(&9I;&4L(&]R"B`@(&EF('EO=2=R92!H879I;F<@=')O=6)L
M92!U<VEN9R!A('!R;W9I9&5D('1R86YS;&%T:6]N+"!P;&5A<V4@<V5E('1H
M90H@("!@:&]R9&4O9&]C<R]44D%.4TQ!5$E/3E-@7R!F:6QE(&9O<B!I;G-T
M<G5C=&EO;G,N"@HT+B!497-T:6YG($UN96UO"@H@("!5<V4@36YE;6\@=&\@
M8W)E871E+"!M;V1I9GDL(&%N9"!D96QE=&4@;F]T97,N(%1E<W0@870@;&5A
M<W0@=&AE(&9O;&QO=VEN9SH*"B`@("T@0W)E871I;F<@82!N97<@;65M;PH@
M("`M($UO9&EF>6EN9R!A(&UE;6\*("`@+2!$96QE=&EN9R!A(&UE;6\*"@I/
M8G1A:6YI;F<@4W5P<&]R=`H]/3T]/3T]/3T]/3T]/3T]/0H*268@>6]U(&5N
M8V]U;G1E<B!P<F]B;&5M<R!W:71H($UN96UO+"!H96QP(&ES(&%V86EL86)L
M92$*"E1H92!(;W)D92!&<F5Q=65N=&QY($%S:V5D(%%U97-T:6]N<R!,:7-T
M("A&05$I+"!A=F%I;&%B;&4@;VX@=&AE(%=E8B!A=`H*("!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]F87$O"@I4:&4@2&]R9&4@4')O:F5C="!R=6YS(&$@;G5M
M8F5R(&]F(&UA:6QI;F<@;&ES=',L(&9O<B!I;F1I=FED=6%L(&%P<&QI8V%T
M:6]N<PIA;F0@9F]R(&ES<W5E<R!R96QA=&EN9R!T;R!T:&4@<')O:F5C="!A
M<R!A('=H;VQE+B`@26YF;W)M871I;VXL(&%R8VAI=F5S+"!A;F0*<W5B<V-R
M:7!T:6]N(&EN9F]R;6%T:6]N(&-A;B!B92!F;W5N9"!A=`H*("!H='1P.B\O
M=W=W+FAO<F1E+F]R9R]M86EL+PH*3&%S=&QY+"!(;W)D92!D979E;&]P97)S
M+"!C;VYT<FEB=71O<G,@86YD('5S97)S(&%L<V\@;6%K92!O8V-A<VEO;F%L
M"F%P<&5A<F%N8V5S(&]N($E20RP@;VX@=&AE(&-H86YN96P@(VAO<F1E(&]N
M('1H92!&<F5E;F]D92!.971W;W)K"BAI<F,N9G)E96YO9&4N;F5T*2X*"E!L
M96%S92!K965P(&EN(&UI;F0@=&AA="!-;F5M;R!I<R!F<F5E('-O9G1W87)E
M('=R:71T96X@8GD@=F]L=6YT965R<RX@($9O<@II;F9O<FUA=&EO;B!O;B!R
M96%S;VYA8FQE('-U<'!O<G0@97AP96-T871I;VYS+"!P;&5A<V4@<F5A9`H*
M("!H='1P.B\O=W=W+FAO<F1E+F]R9R]S=7!P;W)T+G!H<`H*5&AA;FMS(&9O
M<B!U<VEN9R!-;F5M;R$*"E1H92!(;W)D92!T96%M"@H*+BX@7U)%041-13H@
M/V8]4D5!1$U%+FAT;6P*+BX@7V!D;V-S+TA!0TM)3D=@.B`N+B\N+B]H;W)D
M92]D;V-S+S]F/4A!0TM)3D<N:'1M;`HN+B!?24Y35$%,3#H*+BX@7V!H;W)D
M92]D;V-S+TE.4U1!3$Q@.B`N+B\N+B]H;W)D92]D;V-S+S]F/4E.4U1!3$PN
M:'1M;`HN+B!?8&AO<F1E+V1O8W,O5%)!3E-,051)3TY38#H@+BXO+BXO:&]R
M9&4O9&]C<R\_9CU44D%.4TQ!5$E/3E,N:'1M;`H`````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O9&]C<R]214Q%05-%
M7TY/5$53````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$U
M-@`Q,#0Q-S,V,C<T-@`P,C`T-#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%)E;&5A<V4@9F]C=7,N
M(%!O<W-I8FQE('9A;'5E<SH*("H@,"`M($XO00H@*B`Q("T@26YI=&EA;"!F
M<F5S:&UE870@86YN;W5N8V5M96YT"B`J(#(@+2!$;V-U;65N=&%T:6]N"B`J
M(#,@+2!#;V1E(&-L96%N=7`*("H@-"`M($UI;F]R(&9E871U<F4@96YH86YC
M96UE;G1S"B`J(#4@+2!-86IO<B!F96%T=7)E(&5N:&%N8V5M96YT<PH@*B`V
M("T@36EN;W(@8G5G9FEX97,*("H@-R`M($UA:F]R(&)U9V9I>&5S"B`J(#@@
M+2!-:6YO<B!S96-U<FET>2!F:7AE<PH@*B`Y("T@36%J;W(@<V5C=7)I='D@
M9FEX97,*("HO"B1T:&ES+3YN;W1E<ULG9FTG75LG9F]C=7,G72`](#4["@HO
M*B!-86EL:6YG(&QI<W0@<F5L96%S92!N;W1E<RX@*B\*)'1H:7,M/FYO=&5S
M6R=M;"==6R=C:&%N9V5S)UT@/2`\/#Q-3`I4:&4@2&]R9&4@5&5A;2!I<R!P
M;&5A<V5D('1O(&%N;F]U;F-E('1H92!F:6YA;"!R96QE87-E(&]F('1H92!-
M;F5M;R!.;W1E"DUA;F%G97(@=F5R<VEO;B!(,R`H,BXQ*2X*"E1H92!-;F5M
M;R!.;W1E($UA;F%G97(@:7,@=&AE($AO<F1E(&YO=&5S+VUE;6]S(&%P<&QI
M8V%T:6]N+B`@270@<')O=FED97,*=V5B+6)A<V5D(&YO=&5S(&%N9"!F<F5E
M9F]R;2!T97AT+"!S:6UI;&%R('1O('1H92!086QM3U,@3F]T92!A<'!L:6-A
M=&EO;B!A;F0*<VAA<F5D(&YO=&5P861S+B`@270@<F5Q=6ER97,@=&AE($AO
M<F1E($%P<&QI8V%T:6]N($9R86UE=V]R:R!A;F0@86X@4U%,"F1A=&%B87-E
M(&9O<B!B86-K96YD('-T;W)A9V4N"@I4:&4@;6%J;W(@8VAA;F=E<R!C;VUP
M87)E9"!T;R!T:&4@36YE;6\@2#,@*#(N,"D@=F5R<VEO;G,@87)E.@H@("`@
M*B!$>6YA;6EC('1A8FQE(')E<V]R=&EN9RX*("`@("H@26UP<F]V960@86-C
M97-S:6)I;&ET>2X*("`@("H@0V]M<&%T:6)L92!W:71H(%!(4"`U+C$N"B`@
M("`J(%!E<FUI<W-I;VYS('1O(')E<W1R:6-T(&YU;6)E<B!O9B!N;W1E<RX*
M("`@("H@0V]M;6%N9"!L:6YE('-C<FEP="!T;R!B871C:"!I;7!O<G0@=DYO
M=&5S+@H@("`@*B!3;VUE($MO;&%B(')E;&%T960@9FEX97,N"B`@("`J($EM
M<')O=F5D($U3+5-13"!S=7!P;W)T+@H@("`@*B!!9&1E9"!2=7-S:6%N('1R
M86YS;&%T:6]N+@I-3#L*"B\J($9R97-H;65A="!R96QE87-E(&YO=&5S+"!N
M;W0@;6]R92!T:&%N(#8P,"!C:&%R86-T97)S+B`J+PHD=&AI<RT^;F]T97-;
M)V9M)UU;)V-H86YG97,G72`](#P\/$9-"D1Y;F%M:6,@=&%B;&4@<F5S;W)T
M:6YG(&AA<R!B965N(&%D9&5D+@I!8V-E<W-I8FEL:71Y(&AA<R!B965N(&EM
M<')O=F5D+@I097)M:7-S:6]N<R!T;R!R97-T<FEC="!N=6UB97(@;V8@;F]T
M97,@:&%V92!B965N(&%D9&5D+@I!(&-O;6UA;F0@;&EN92!S8W)I<'0@=&\@
M8F%T8V@@:6UP;W)T('9.;W1E<R!H87,@8F5E;B!A9&1E9"X*4V]M92!+;VQA
M8B!R96QA=&5D(&)U9W,@:&%V92!B965N(&9I>&5D+@I-4RU344P@<W5P<&]R
M="!H87,@8F5E;B!I;7!R;W9E9"X*02!2=7-S:6%N('1R86YS;&%T:6]N(&AA
M<R!B965N(&%D9&5D+@I&33L*"B1T:&ES+3YN;W1E<ULG;F%M92==(#T@)TUN
M96UO)SL*)'1H:7,M/FYO=&5S6R=F;2==6R=P<F]J96-T)UT@/2`G;6YE;6\G
M.PHD=&AI<RT^;F]T97-;)V9M)UU;)V)R86YC:"==(#T@)TAO<F1E(#,G.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+V1O8W,O5$]$3P``````````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T,S0`,3`T
M,3<S-C(W-#8`,#$W,34W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!-
M;F5M;R!$979E;&]P;65N="!43T1/($QI<W0*/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-"\P.2\R
M."`R,3HR-3HU-2`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N,B`D
M"CI#;VYT86-T.B`@("`@("!M;F5M;T!L:7-T<RYH;W)D92YO<F<*"BT@06QL
M;W<@<F5S;W)T:6YG('-E87)C:"!R97-U;'1S+@H*+2!.97AT+U!R979I;W5S
M(&)U='1O;G,@:6X@=&AE(&YO=&4@=FEE=RX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]M;F5M;R]D;V-S+TQ)0T5.4T4`````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,C0T`#$P-#$W,S8R-S0V`#`Q
M-S0W-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!697)S:6]N(#$N,`H*0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4@5&AE($AO
M<F1E(%!R;VIE8W0N($%L;"!R:6=H=',@<F5S97)V960N"@I2961I<W1R:6)U
M=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H
M(&]R('=I=&AO=70*;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I
M9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS(&%R90IM970Z"@HQ
M+B!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@
M=&AE(&%B;W9E(&-O<'ER:6=H=`IN;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD
M:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"@HR+B!2961I
M<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE
M(&%B;W9E(&-O<'ER:6=H=`IN;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I
M;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE"F1O8W5M
M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H
M('1H92!D:7-T<FEB=71I;VXN"@HS+B!4:&4@96YD+75S97(@9&]C=6UE;G1A
M=&EO;B!I;F-L=61E9"!W:71H('1H92!R961I<W1R:6)U=&EO;BP@:68*86YY
M+"!M=7-T(&EN8VQU9&4@=&AE(&9O;&QO=VEN9R!A8VMN;W=L961G;65N=#H*
M"B`@(")4:&ES('!R;V1U8W0@:6YC;'5D97,@<V]F='=A<F4@9&5V96QO<&5D
M(&)Y('1H92!(;W)D92!0<F]J96-T"B`@("`H:'1T<#HO+W=W=RYH;W)D92YO
M<F<O*2XB"@I!;'1E<FYA=&5L>2P@=&AI<R!A8VMN;W=L961G;65N="!M87D@
M87!P96%R(&EN('1H92!S;V9T=V%R92!I='-E;&8L(&EF"F%N9"!W:&5R979E
M<B!S=6-H('1H:7)D+7!A<G1Y(&%C:VYO=VQE9&=M96YT<R!N;W)M86QL>2!A
M<'!E87(N"@HT+B!4:&4@;F%M97,@(DAO<F1E(BP@(E1H92!(;W)D92!0<F]J
M96-T(BP@86YD(")-;F5M;R(@;75S="!N;W0@8F4*=7-E9"!T;R!E;F1O<G-E
M(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A
M<F4@=VET:&]U=`IP<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN($9O<B!W<FET
M=&5N('!E<FUI<W-I;VXL('!L96%S92!C;VYT86-T"F-O<F5`:&]R9&4N;W)G
M+@H*-2X@4')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@;6%Y
M(&YO="!B92!C86QL960@(DAO<F1E(B!O<@HB36YE;6\B+"!N;W(@;6%Y(")(
M;W)D92(@;W(@(DUN96UO(B!A<'!E87(@:6X@=&AE:7(@;F%M92P@=VET:&]U
M=`IP<FEO<B!W<FET=&5N('!E<FUI<W-I;VX@;V8@=&AE($AO<F1E(%!R;VIE
M8W0N"@I42$E3(%-/1E1705)%($E3(%!23U9)1$5$(")!4R!)4R(@04Y$($%.
M62!%6%!215-3140@3U(@24U03$E%1`I705)204Y42453+"!)3D-,541)3D<L
M($)55"!.3U0@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/
M1@I-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!
M4B!055)03U-%($%212!$25-#3$%)345$+@I)3B!.3R!%5D5.5"!32$%,3"!4
M2$4@2$]21$4@4%)/2D5#5"!/4B!)5%,@0T].5%))0E543U)3($)%($Q)04),
M12!&3U(*04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)
M04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3`I$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"
M4U1)5%5412!'3T]$4PI/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L
M($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD*2$]7159%
M4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$54
M2$52($E.($-/3E1204-4+`I35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)
M3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<*24X@
M04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.
M($E&($%$5DE3140@3T8@5$A%"E!/4U-)0DE,2519($]&(%-50T@@1$%-04=%
M+@H*5&AI<R!S;V9T=V%R92!C;VYS:7-T<R!O9B!V;VQU;G1A<GD@8V]N=')I
M8G5T:6]N<R!M861E(&)Y(&UA;GD*:6YD:79I9'5A;',@;VX@8F5H86QF(&]F
M('1H92!(;W)D92!0<F]J96-T+B!&;W(@;6]R92!I;F9O<FUA=&EO;B!O;@IT
M:&4@2&]R9&4@4')O:F5C="P@<&QE87-E('-E92`\:'1T<#HO+W=W=RYH;W)D
M92YO<F<O/BX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]M;F5M;R]D871A+G!H<```````````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U-S(W`#$P
M-#$W,S8R-S0V`#`Q-S$W-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!M;F5M;R]D871A
M+G!H<"QV(#$N,S8N,BXU(#(P,#8O,#$O,#$@,C$Z,CDZ,#4@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.
M4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D
M92YO<F<O;&EC96YS97,O87-L+G!H<"X*("H*("H@0&%U=&AO<B`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@36YE;6\@,2XP
M"B`J($!P86-K86=E($UN96UO"B`J+PH*9G5N8W1I;VX@7V-L96%N=7`H*0I[
M"B`@("!G;&]B86P@)&EM<&]R=%]S=&5P.PH@("`@)&EM<&]R=%]S=&5P(#T@
M,3L*("`@(')E='5R;B!)35!/4E1?1DE,13L*?0H*0&1E9FEN92@G34Y%34]?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E($U.14U/
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M1&%T82YP:'`G.PH*:68@*"$D8V]N9ELG;65N=2==6R=I;7!O<G1?97AP;W)T
M)UTI('L*("`@(')E<75I<F4@34Y%34]?0D%312`N("<O:6YD97@N<&AP)SL*
M("`@(&5X:70["GT*"B\J($EM<&]R=&%B;&4@9FEL92!T>7!E<RX@*B\*)&9I
M;&5?='EP97,@/2!A<G)A>2@G8W-V)R`]/B!?*")#4U8B*2P*("`@("`@("`@
M("`@("`@("`@("`G=FYO=&4G(#T^(%\H(G9.;W1E(BDI.PH*+RH@5&5M<&QA
M=&5S(&9O<B!T:&4@9&EF9F5R96YT(&EM<&]R="!S=&5P<RX@*B\*)'1E;7!L
M871E<R`](&%R<F%Y*`H@("`@24U03U)47T-35B`]/B!A<G)A>2@D<F5G:7-T
M<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V1A=&$O8W-V:6YF
M;RYI;F,G*2P*("`@($E-4$]25%]-05!0140@/3X@87)R87DH)')E9VES=')Y
M+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]D871A+V-S=FUA<"YI
M;F,G*2P**3L*:68@*$UN96UO.CIH87-097)M:7-S:6]N*"=M87A?;F]T97,G
M*2`A/3T@=')U92`F)@H@("`@36YE;6\Z.FAA<U!E<FUI<W-I;VXH)VUA>%]N
M;W1E<R<I(#P]($UN96UO.CIC;W5N=$UE;6]S*"DI('L*("`@("1M97-S86=E
M(#T@0&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@;F]T97,N(BDL($UN96UO
M.CIH87-097)M:7-S:6]N*"=M87A?;F]T97,G*2DL($5.5%]#3TU0050L($Y,
M4SHZ9V5T0VAA<G-E="@I*3L*("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS
M)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@("`@)&UE<W-A9V4@/2!(;W)D
M93HZ8V%L;$AO;VLH)U]P97)M<U]H;V]K7V1E;FEE9"<L(&%R<F%Y*"=M;F5M
M;SIM87A?;F]T97,G*2P@)VAO<F1E)RP@)&UE<W-A9V4I.PH@("`@?0H@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"@D;65S<V%G92P@)VAO<F1E+G=A<FYI;F<G
M+"!A<G)A>2@G8V]N=&5N="YR87<G*2D["B`@("`D=&5M<&QA=&5S6TE-4$]2
M5%]&24Q%72`](&%R<F%Y*$U.14U/7U1%35!,051%4R`N("<O9&%T82]E>'!O
M<G0N:6YC)RD["GT@96QS92!["B`@("`D=&5M<&QA=&5S6TE-4$]25%]&24Q%
M72`](&%R<F%Y*$U.14U/7U1%35!,051%4R`N("<O9&%T82]I;7!O<G0N:6YC
M)RP@34Y%34]?5$5-4$Q!5$53("X@)R]D871A+V5X<&]R="YI;F,G*3L*?0H*
M+RH@1FEE;&0O8VQE87(@;F%M92!M87!P:6YG+B`J+PHD87!P7V9I96QD<R`]
M(&%R<F%Y*"=B;V1Y)R`]/B!?*")-96UO(%1E>'0B*2P*("`@("`@("`@("`@
M("`@("`@("`G8V%T96=O<GDG(#T^(%\H(D-A=&5G;W)Y(BDI.PH*+RH@26YI
M=&EA;"!V86QU97,N("HO"B1P87)A;2`](&%R<F%Y*"=F:6QE7W1Y<&5S)R`@
M/3X@)&9I;&5?='EP97,I.PHD:6UP;W)T7V9O<FUA="`](%5T:6PZ.F=E=$9O
M<FU$871A*"=I;7!O<G1?9F]R;6%T)RP@)R<I.PHD:6UP;W)T7W-T97`@/2!5
M=&EL.CIG971&;W)M1&%T82@G:6UP;W)T7W-T97`G+"`P*2`K(#$["B1A8W1I
M;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PHD97)R;W(@
M/2!F86QS93L*"B\J($QO;W`@=&AR;W5G:"!T:&4@86-T:6]N(&AA;F1L97)S
M+B`J+PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=E>'!O<G0G.@H@("`@
M)&5X<&]R=$E$(#T@571I;#HZ9V5T1F]R;41A=&$H)V5X<&]R=$E$)RD["@H@
M("`@+RH@0W)E871E(&$@36YE;6\@<W1O<F%G92!I;G-T86YC92X@*B\*("`@
M(')E<75I<F5?;VYC92!-3D5-3U]"05-%("X@)R]L:6(O1')I=F5R+G!H<"<[
M"B`@("`D<W1O<F%G92`]("9-;F5M;U]$<FEV97(Z.G-I;F=L971O;BA!=71H
M.CIG971!=71H*"DI.PH@("`@)'-T;W)A9V4M/G)E=')I979E*"D["@H@("`@
M+RH@1V5T('1H92!F=6QL+"!S;W)T960@;65M;R!L:7-T+B`J+PH@("`@)&YO
M=&5S(#T@36YE;6\Z.FQI<W1-96UO<R@I.PH*("`@('-W:71C:"`H)&5X<&]R
M=$E$*2!["B`@("!C87-E($584$]25%]#4U8Z"B`@("`@("`@:68@*&-O=6YT
M*"1N;W1E<RD@/3T@,"D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(E1H97)E('=E<F4@;F\@;65M;W,@=&\@97AP;W)T+B(I+"`G:&]R
M9&4N;65S<V%G92<I.PH@("`@("`@("`@("`D97)R;W(@/2!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)&YO=&5S(&%S("1N;W1E*2!["B`@("`@("`@
M("`@("`@("!U;G-E="@D;F]T95LG;65M;U]I9"==*3L*("`@("`@("`@("`@
M("`@('5N<V5T*"1N;W1E6R=M96UO;&ES=%]I9"==*3L*("`@("`@("`@("`@
M("`@('5N<V5T*"1N;W1E6R=D97-C)UTI.PH@("`@("`@("`@("`@("`@=6YS
M970H)&YO=&5;)W5I9"==*3L*("`@("`@("`@("`@("`@("1D871A6UT@/2`D
M;F]T93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8W-V(#T@)DAO<F1E
M7T1A=&$Z.G-I;F=L971O;B@G8W-V)RD["B`@("`@("`@("`@("1C<W8M/F5X
M<&]R=$9I;&4H7R@B;F]T97,N8W-V(BDL("1D871A+"!T<G5E*3L*("`@("`@
M("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@
M24U03U)47T9)3$4Z"B`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)W1A
M<F=E="==(#T@571I;#HZ9V5T1F]R;41A=&$H)VYO=&5P861?=&%R9V5T)RD[
M"B`@("!B<F5A:SL*?0H*:68@*"$D97)R;W(I('L*("`@("1D871A(#T@)DAO
M<F1E7T1A=&$Z.G-I;F=L971O;B@D:6UP;W)T7V9O<FUA="D["B`@("!I9B`H
M:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H7R@B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R
M=&5D+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`D;F5X=%]S=&5P(#T@
M24U03U)47T9)3$4["B`@("!](&5L<V4@>PH@("`@("`@("1N97AT7W-T97`@
M/2`D9&%T82T^;F5X=%-T97`H)&%C=&EO;DE$+"`D<&%R86TI.PH@("`@("`@
M(&EF("AI<U]A*"1N97AT7W-T97`L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D;F5X=%]S=&5P+3YG971-97-S
M86=E*"DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`D;F5X=%]S=&5P
M(#T@)&1A=&$M/F-L96%N=7`H*3L*("`@("`@("!]"B`@("!]"GT*"B\J(%=E
M(&AA=F4@82!F:6YA;"!R97-U;'0@<V5T+B`J+PII9B`H:7-?87)R87DH)&YE
M>'1?<W1E<"DI('L*("`@("\J($-R96%T92!A($UN96UO('-T;W)A9V4@:6YS
M=&%N8V4N("HO"B`@("!R97%U:7)E7V]N8V4@34Y%34]?0D%312`N("<O;&EB
M+T1R:79E<BYP:'`G.PH@("`@)'-T;W)A9V4@/2`F36YE;6]?1')I=F5R.CIS
M:6YG;&5T;VXH)%]315-324].6R=I;7!O<G1?9&%T82==6R=T87)G970G72D[
M"B`@("`D;6%X7VUE;6]S(#T@36YE;6\Z.FAA<U!E<FUI<W-I;VXH)VUA>%]N
M;W1E<R<I.PH@("`@)&YU;5]M96UO<R`]($UN96UO.CIC;W5N=$UE;6]S*"D[
M"B`@("!F;W)E86-H("@D;F5X=%]S=&5P(&%S("1R;W<I('L*("`@("`@("!I
M9B`H)&UA>%]M96UO<R`A/3T@=')U92`F)B`D;G5M7VUE;6]S(#X]("1M87A?
M;65M;W,I('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!`:'1M;'-P96-I86QC
M:&%R<RAS<')I;G1F*%\H(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!N;W1E<RXB*2P@36YE;6\Z.FAA<U!E<FUI<W-I;VXH
M)VUA>%]N;W1E<R<I*2P@14Y47T-/35!!5"P@3DQ3.CIG971#:&%R<V5T*"DI
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P97)M
M<V1E;FEE9"==*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!(;W)D
M93HZ8V%L;$AO;VLH)U]P97)M<U]H;V]K7V1E;FEE9"<L(&%R<F%Y*"=M;F5M
M;SIM87A?;F]T97,G*2P@)VAO<F1E)RP@)&UE<W-A9V4I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&UE<W-A9V4L
M("=H;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!W
M92!N965D('1O(&-O;G9E<G0@9G)O;2!I0V%L96YD87(@9&%T82!I;G1O(&%N
M(&%R<F%Y+B`J+PH@("`@("`@(&EF("AI<U]A*"1R;W<L("=(;W)D95]I0V%L
M96YD87)?=FYO=&4G*2D@>PH@("`@("`@("`@("`D<F]W(#T@)'-T;W)A9V4M
M/F9R;VUI0V%L96YD87(H)')O=RD["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D87!P7V9I96QD<R!A<R`D9FEE;&0@/3X@)&YU;&PI('L*("`@("`@
M("`@("`@:68@*"%I<W-E="@D<F]W6R1F:65L9%TI*2!["B`@("`@("`@("`@
M("`@("`D<F]W6R1F:65L9%T@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@1&5F875L="!T:&4@8V%T96=O<GD@:68@=&AE<F4@
M:7-N)W0@;VYE+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<F]W6R=C871E9V]R
M>2==*2D@>PH@("`@("`@("`@("`D<F]W6R=C871E9V]R>2==(#T@,#L*("`@
M("`@("!]"@H@("`@("`@("\J(%!A<G-E(&]U="!T:&4@9FER<W0@;&EN92!A
M<R!T:&4@9&5S8W)I<'1I;VX@:68@;F5C97-S87)Y+B`J+PH@("`@("`@(&EF
M("AE;7!T>2@D<F]W6R=D97-C)UTI*2!["B`@("`@("`@("`@("1T;7`@/2!E
M>'!L;V1E*")<;B(L("1R;W=;)V)O9'DG72P@,BD["B`@("`@("`@("`@("1R
M;W=;)V1E<V,G72`](&%R<F%Y7W-H:69T*"1T;7`I.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]("1S=&]R86=E+3YA9&0H)')O=ULG9&5S8R==+"`D
M<F]W6R=B;V1Y)UTL("1R;W=;)V-A=&5G;W)Y)UTI.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H@("`@("`@("1N;W1E(#T@)'-T;W)A9V4M/F=E="@D
M<F5S=6QT*3L*"B`@("`@("`@+RH@268@=V4@:&%V92!C<F5A=&5D(&]R(&UO
M9&EF:65D(&1A=&5S(&9O<B!T:&4@;F]T92P@<V5T('1H96T*("`@("`@("`@
M*B!C;W)R96-T;'D@:6X@=&AE(&AI<W1O<GD@;&]G+B`J+PH@("`@("`@(&EF
M("@A96UP='DH)')O=ULG8W)E871E9"==*2D@>PH@("`@("`@("`@("`D:&ES
M=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1R;W=;)V-R96%T960G72DI('L*("`@("`@("`@
M("`@("`@("1R;W=;)V-R96%T960G72`]("1R;W=;)V-R96%T960G75LG=',G
M73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:&ES=&]R>2T^;&]G*"=M
M;F5M;SHG("X@)%]315-324].6R=I;7!O<G1?9&%T82==6R=T87)G970G72`N
M("<Z)R`N("1N;W1E6R=U:60G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G86-T:6]N)R`]/B`G861D)RP@)W1S)R`]/B`D<F]W6R=C<F5A
M=&5D)UTI+"!T<G5E*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D
M<F]W6R=M;V1I9FEE9"==*2D@>PH@("`@("`@("`@("`D:&ES=&]R>2`]("9(
M;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1R;W=;)VUO9&EF:65D)UTI*2!["B`@("`@("`@("`@("`@("`D
M<F]W6R=M;V1I9FEE9"==(#T@)')O=ULG;6]D:69I960G75LG=',G73L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:&ES=&]R>2T^;&]G*"=M;F5M;SHG
M("X@)%]315-324].6R=I;7!O<G1?9&%T82==6R=T87)G970G72`N("<Z)R`N
M("1N;W1E6R=U:60G72P*("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G86-T:6]N)R`]/B`G;6]D:69Y)RP@)W1S)R`]/B`D<F]W6R=M;V1I9FEE
M9"==*2P@=')U92D["B`@("`@("`@?0H*("`@("`@("`D;G5M7VUE;6]S*RL[
M"B`@("!]"@H@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT+3YG971-
M97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92!["B`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(B5S(&9I;&4@<W5C
M8V5S<V9U;&QY(&EM<&]R=&5D(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F:6QE7W1Y<&5S6R1?4T534TE/3ELG:6UP;W)T7V1A
M=&$G75LG9F]R;6%T)UU=*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T*("`@
M("1N97AT7W-T97`@/2`D9&%T82T^8VQE86YU<"@I.PI]"@HD=&ET;&4@/2!?
M*"));7!O<G0O17AP;W)T($YO=&5S(BD["G)E<75I<F4@34Y%34]?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@34Y%34]?5$5-
M4$Q!5$53("X@)R]M96YU+FEN8R<["@IF;W)E86-H("@D=&5M<&QA=&5S6R1N
M97AT7W-T97!=(&%S("1T96UP;&%T92D@>PH@("`@<F5Q=6ER92`D=&5M<&QA
M=&4["GT*"G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]M;F5M;R]C;VYF:6<`````````````````````````````````
M`````````````````````````````````````````````````#`Q,C`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0V`#`R-3$V
M,0`@,B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O;6YE;6\`````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VUN96UO+VUE;6\N<&AP````````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38U,#$`
M,3`T,3<S-C(W-#8`,#$W,C`W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&UN96UO+VUE
M;6\N<&AP+'8@,2XT,BXR+C4@,C`P-B\P,2\P,2`R,3HR.3HP-2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($UN96UO(#$N,`H@*B!`<&%C:V%G92!-;F5M;PH@*B\*"D!D969I;F4H)TU.
M14U/7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!-
M3D5-3U]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`G.PHD8TUA;F%G97(@/2`F
M;F5W(%!R969S7T-A=&5G;W)Y36%N86=E<B@I.PH*+RH@4F5D:7)E8W0@=&\@
M=&AE(&YO=&5P860@=FEE=R!I9B!N;R!A8W1I;VX@:&%S(&)E96X@<F5Q=65S
M=&5D+B`J+PHD;65M;U]I9"`](%5T:6PZ.F=E=$9O<FU$871A*"=M96UO)RD[
M"B1M96UO;&ES=%]I9"`](%5T:6PZ.F=E=$9O<FU$871A*"=M96UO;&ES="<I
M.PHD86-T:6]N240@/2!5=&EL.CIG971&;W)M1&%T82@G86-T:6]N240G*3L*
M:68@*&ES7VYU;&PH)&%C=&EO;DE$*2D@>PH@("`@:&5A9&5R*"=,;V-A=&EO
M;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G;&ES="YP:'`G+"!T<G5E
M*2D["B`@("!E>&ET.PI]"@HO*B!2=6X@=&AR;W5G:"!T:&4@86-T:6]N(&AA
M;F1L97)S+B`J+PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=A9&1?;65M
M;R<Z"B`@("`O*B!#:&5C:R!P97)M:7-S:6]N<RX@*B\*("`@(&EF("A-;F5M
M;SHZ:&%S4&5R;6ES<VEO;B@G;6%X7VYO=&5S)RD@(3T]('1R=64@)B8*("`@
M("`@("!-;F5M;SHZ:&%S4&5R;6ES<VEO;B@G;6%X7VYO=&5S)RD@/#T@36YE
M;6\Z.F-O=6YT365M;W,H*2D@>PH@("`@("`@("1M97-S86=E(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")9;W4@87)E(&YO="!A;&QO=V5D('1O
M(&-R96%T92!M;W)E('1H86X@)60@;F]T97,N(BDL($UN96UO.CIH87-097)M
M:7-S:6]N*"=M87A?;F]T97,G*2DL($5.5%]#3TU0050L($Y,4SHZ9V5T0VAA
M<G-E="@I*3L*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P
M97)M<V1E;FEE9"==*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]($AO<F1E
M.CIC86QL2&]O:R@G7W!E<FUS7VAO;VM?9&5N:65D)RP@87)R87DH)VUN96UO
M.FUA>%]N;W1E<R<I+"`G:&]R9&4G+"`D;65S<V%G92D["B`@("`@("`@?0H@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&UE<W-A9V4L("=H;W)D92YE
M<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@("`@("!H96%D97(H
M)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L:7-T+G!H
M<"<L('1R=64I*3L*("`@("`@("!E>&ET.PH@("`@?0H@("`@+RH@4V5T('5P
M('1H92!N;W1E(&%T=')I8G5T97,N("HO"B`@("`D;65M;VQI<W1?:60@/2!-
M;F5M;SHZ9V5T1&5F875L=$YO=&5P860H*3L*("`@(&EF("AI<U]A*"1M96UO
M;&ES=%]I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H)&UE;6]L:7-T7VED+"`G:&]R9&4N97)R;W(G*3L*("`@('T*
M("`@("1M96UO7VED(#T@;G5L;#L*("`@("1M96UO7V)O9'D@/2`G)SL*("`@
M("1M96UO7V-A=&5G;W)Y(#T@)R<["@H@("`@)'1I=&QE(#T@7R@B061D:6YG
M($$@3F5W($YO=&4B*3L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H)V1O8W5M
M96YT+FUE;6\N;65M;U]B;V1Y+F9O8W5S*"D[)RP@)VIA=F%S8W)I<'0G*3L*
M("`@(&)R96%K.PH*8V%S92`G;6]D:69Y7VUE;6\G.@H@("`@+RH@1V5T('1H
M92!C=7)R96YT(&YO=&4N("HO"B`@("`D;65M;R`]($UN96UO.CIG971-96UO
M*"1M96UO;&ES=%]I9"P@)&UE;6]?:60I.PH@("`@:68@*"$D;65M;R!\?"`A
M:7-S970H)&UE;6];)VUE;6]?:60G72DI('L*("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*%\H(DYO=&4@;F]T(&9O=6YD+B(I+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=L:7-T+G!H<"<L('1R=64I*3L*("`@("`@("!E>&ET.PH@
M("`@?0H*("`@("\J(%-E="!U<"!T:&4@;F]T92!A='1R:6)U=&5S+B`J+PH@
M("`@)&UE;6]?8F]D>2`]("1M96UO6R=B;V1Y)UT["B`@("`D;65M;U]C871E
M9V]R>2`]("1M96UO6R=C871E9V]R>2==.PH@("`@)'1I=&QE(#T@<W!R:6YT
M9BA?*")-;V1I9GEI;F<@)7,B*2P@)&UE;6];)V1E<V,G72D["B`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*"=D;V-U;65N="YM96UO+FUE;6]?8F]D>2YF;V-U
M<R@I.R<L("=J879A<V-R:7!T)RD["B`@("!B<F5A:SL*"F-A<V4@)W-A=F5?
M;65M;R<Z"B`@("`O*B!'970@=&AE(&9O<FT@=F%L=65S+B`J+PH@("`@)&UE
M;6]?:60@/2!5=&EL.CIG971&;W)M1&%T82@G;65M;R<I.PH@("`@)&UE;6]?
M8F]D>2`](%5T:6PZ.F=E=$9O<FU$871A*"=M96UO7V)O9'DG*3L*("`@("1M
M96UO7V-A=&5G;W)Y(#T@571I;#HZ9V5T1F]R;41A=&$H)VUE;6]?8V%T96=O
M<GDG*3L*("`@("1M96UO;&ES=%]O<FEG:6YA;"`](%5T:6PZ.F=E=$9O<FU$
M871A*"=M96UO;&ES=%]O<FEG:6YA;"<I.PH@("`@)&YO=&5P861?=&%R9V5T
M(#T@571I;#HZ9V5T1F]R;41A=&$H)VYO=&5P861?=&%R9V5T)RD["@H@("`@
M)'-H87)E(#T@)$=,3T)!3%-;)VUN96UO7W-H87)E<R==+3YG9713:&%R92@D
M;F]T97!A9%]T87)G970I.PH@("`@:68@*&ES7V$H)'-H87)E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F
M*%\H(D%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4Z("5S(BDL("1S:&%R92T^
M9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V5I9B`H
M(21S:&%R92T^:&%S4&5R;6ES<VEO;BA!=71H.CIG971!=71H*"DL(%!%4DU3
M7T5$250I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F
M*%\H(D%C8V5S<R!D96YI960@<V%V:6YG(&YO=&4@=&\@)7,N(BDL("1S:&%R
M92T^9V5T*"=N86UE)RDI+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92![
M"B`@("`@("`@:68@*"1N97=?8V%T96=O<GD@/2!5=&EL.CIG971&;W)M1&%T
M82@G;F5W7V-A=&5G;W)Y)RDI('L*("`@("`@("`@("`@)&YE=U]C871E9V]R
M>2`]("1C36%N86=E<BT^861D*"1N97=?8V%T96=O<GDI.PH@("`@("`@("`@
M("!I9B`H)&YE=U]C871E9V]R>2D@>PH@("`@("`@("`@("`@("`@)&UE;6]?
M8V%T96=O<GD@/2`D;F5W7V-A=&5G;W)Y.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B`D;65M;U]I9"!I<R!S970L('=E)W)E(&UO
M9&EF>6EN9R!A;B!E>&ES=&EN9R!N;W1E+B`@3W1H97)W:7-E+`H@("`@("`@
M("`J('=E)W)E(&%D9&EN9R!A(&YE=R!N;W1E('=I=&@@=&AE('!R;W9I9&5D
M(&%T=')I8G5T97,N("HO"B`@("`@("`@:68@*"%E;7!T>2@D;65M;U]I9"D@
M)B8*("`@("`@("`@("`@(6ES7V$H36YE;6\Z.F=E=$UE;6\H)&UE;6]L:7-T
M7V]R:6=I;F%L+"`D;65M;U]I9"DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)'-T;W)A9V4@/2`F36YE;6]?1')I=F5R.CIS:6YG;&5T;VXH)&UE
M;6]L:7-T7V]R:6=I;F%L*3L*("`@("`@("`@("`@)&UE;6]?9&5S8R`]("1S
M=&]R86=E+3YG971-96UO1&5S8W)I<'1I;VXH)&UE;6]?8F]D>2D["B`@("`@
M("`@("`@("1R97-U;'0@/2`D<W1O<F%G92T^;6]D:69Y*"1M96UO7VED+"`D
M;65M;U]D97-C+"`D;65M;U]B;V1Y+"`D;65M;U]C871E9V]R>2D["@H@("`@
M("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2`F)@H@
M("`@("`@("`@("`@("`@)&UE;6]L:7-T7V]R:6=I;F%L("$]("1N;W1E<&%D
M7W1A<F=E="D@>PH@("`@("`@("`@("`@("`@+RH@36]V:6YG('1H92!N;W1E
M('1O(&%N;W1H97(@;F]T97!A9"X@*B\*("`@("`@("`@("`@("`@("1S:&%R
M92`]("1'3$]"04Q36R=M;F5M;U]S:&%R97,G72T^9V5T4VAA<F4H)&UE;6]L
M:7-T7V]R:6=I;F%L*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?82@D<VAA
M<F4L("=014%27T5R<F]R)RD@)B8*("`@("`@("`@("`@("`@("`@("`D<VAA
M<F4M/FAA<U!E<FUI<W-I;VXH075T:#HZ9V5T075T:"@I+"!015)-4U]$14Q%
M5$4I*2!["B`@("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)$=,3T)!3%-;
M)VUN96UO7W-H87)E<R==+3YG9713:&%R92@D;F]T97!A9%]T87)G970I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-?82@D<VAA<F4L("=014%27T5R
M<F]R)RD@)B8*("`@("`@("`@("`@("`@("`@("`@("`@)'-H87)E+3YH87-0
M97)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H*2P@4$5235-?141)5"DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1S=&]R86=E+3YM;W9E
M*"1M96UO7VED+"`D;F]T97!A9%]T87)G970I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H7R@B06-C97-S(&1E;FEE9"!M;W9I;F<@=&AE(&YO=&4N
M(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"A?*")!8V-E<W,@9&5N:65D(&UO=FEN9R!T:&4@
M;F]T92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!#
M:&5C:R!P97)M:7-S:6]N<RX@*B\*("`@("`@("`@("`@:68@*$UN96UO.CIH
M87-097)M:7-S:6]N*"=M87A?;F]T97,G*2`A/3T@=')U92`F)@H@("`@("`@
M("`@("`@("`@36YE;6\Z.FAA<U!E<FUI<W-I;VXH)VUA>%]N;W1E<R<I(#P]
M($UN96UO.CIC;W5N=$UE;6]S*"DI('L*("`@("`@("`@("`@("`@(&AE861E
M<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)VQI<W0N
M<&AP)RP@=')U92DI.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`O*B!#<F5A=&EN9R!A(&YE=R!N;W1E+B`J+PH@
M("`@("`@("`@("`D<W1O<F%G92`]("9-;F5M;U]$<FEV97(Z.G-I;F=L971O
M;B@D;F]T97!A9%]T87)G970I.PH@("`@("`@("`@("`D;65M;U]D97-C(#T@
M)'-T;W)A9V4M/F=E=$UE;6]$97-C<FEP=&EO;B@D;65M;U]B;V1Y*3L*("`@
M("`@("`@("`@)')E<W5L="`]("1M96UO7VED(#T@)'-T;W)A9V4M/F%D9"@D
M;65M;U]D97-C+"`D;65M;U]B;V1Y+"`D;65M;U]C871E9V]R>2D["B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!O=7(@<F5S=6QT<RX@*B\*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R92!W87,@
M86X@97)R;W(@<V%V:6YG('1H92!N;W1E.B`E<R(I+"`D<F5S=6QT+3YG971-
M97-S86=E*"DI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3
M=6-C97-S9G5L;'D@<V%V960@7"(E<UPB+B(I+"`D;65M;U]D97-C*2P@)VAO
M<F1E+G-U8V-E<W,G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RH@4F5T=7)N
M('1O('1H92!N;W1E<&%D('9I97<N("HO"B`@("!H96%D97(H)TQO8V%T:6]N
M.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L:7-T+G!H<"<L('1R=64I
M*3L*("`@(&5X:70["B`@("!B<F5A:SL*"F-A<V4@)V1E;&5T95]M96UO<R<Z
M"B`@("`O*B!$96QE=&4@=&AE(&YO=&4@:68@=V4G<F4@<')O=FED960@=VET
M:"!A('9A;&ED(&YO=&4@240N("HO"B`@("`D;65M;U]I9"`](%5T:6PZ.F=E
M=$9O<FU$871A*"=M96UO)RD["B`@("`D;65M;VQI<W1?:60@/2!5=&EL.CIG
M971&;W)M1&%T82@G;65M;VQI<W0G*3L*"B`@("!I9B`H(6ES7VYU;&PH)&UE
M;6]?:60I("8F($UN96UO.CIG971-96UO*"1M96UO;&ES=%]I9"P@)&UE;6]?
M:60I*2!["B`@("`@("`@)'-H87)E(#T@)$=,3T)!3%-;)VUN96UO7W-H87)E
M<R==+3YG9713:&%R92@D;65M;VQI<W1?:60I.PH@("`@("`@(&EF("@A:7-?
M82@D<VAA<F4L("=014%27T5R<F]R)RD@)B8*("`@("`@("`@("`@)'-H87)E
M+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H*2P@4$5235-?1$5,151%
M*2D@>PH@("`@("`@("`@("`D<W1O<F%G92`]("9-;F5M;U]$<FEV97(Z.G-I
M;F=L971O;B@D;65M;VQI<W1?:60I.PH@("`@("`@("`@("`D<F5S=6QT(#T@
M)'-T;W)A9V4M/F1E;&5T92@D;65M;U]I9"D["@H@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&%N
M(&5R<F]R(')E;6]V:6YG('1H92!N;W1E.B`E<R(I+"`D<F5S=6QT+3YG971-
M97-S86=E*"DI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")4
M:&4@;F]T92!W87,@9&5L971E9"XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B06-C97-S(&1E;FEE9"!D96QE=&EN9R!N;W1E
M+B(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*B!2971U<FX@=&\@=&AE(&YO=&5P860N("HO"B`@("!H96%D97(H)TQO8V%T
M:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L:7-T+G!H<"<L('1R
M=64I*3L*("`@(&5X:70["B`@("!B<F5A:SL*"F1E9F%U;'0Z"B`@("!H96%D
M97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L:7-T
M+G!H<"<L('1R=64I*3L*("`@(&5X:70["GT*"B1N;W1I9FEC871I;VXM/G!U
M<V@H)V1O8W5M96YT+FUE;6\N;65M;U]B;V1Y+F9O8W5S*"DG+"`G:F%V87-C
M<FEP="<I.PHD;F]T97!A9',@/2!-;F5M;SHZ;&ES=$YO=&5P861S*&9A;'-E
M+"!015)-4U]%1$E4*3L*<F5Q=6ER92!-3D5-3U]414U03$%415,@+B`G+V-O
M;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!-3D5-3U]414U03$%415,@+B`G
M+VUE;G4N:6YC)SL*<F5Q=6ER92!-3D5-3U]414U03$%415,@+B`G+VUE;6\O
M;65M;RYI;F,G.PIR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G
M+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O<V5A<F-H+G!H<```
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(T
M-``Q,#0Q-S,V,C<T-@`P,3<U,34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@;6YE;6\O
M<V5A<F-H+G!H<"QV(#$N.2XX+C0@,C`P-B\P,2\P,2`R,3HR.3HP-2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!*;VX@4&%R:7-E(#QJ
M;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#
M14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!*;VX@
M4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!-;F5M;R`Q+C`*
M("H@0'!A8VMA9V4@36YE;6\*("HO"@I`9&5F:6YE*"=-3D5-3U]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@34Y%34]?0D%312`N
M("<O;&EB+V)A<V4N<&AP)SL*)'1I=&QE(#T@7R@B4V5A<F-H(BD["G)E<75I
M<F4@34Y%34]?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E
M<75I<F4@34Y%34]?5$5-4$Q!5$53("X@)R]M96YU+FEN8R<["G)E<75I<F4@
M34Y%34]?5$5-4$Q!5$53("X@)R]S96%R8V@O<V5A<F-H+FEN8R<["G)E<75I
M<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C
M;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;6YE;6\O;F]T97!A
M9',N<&AP````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-S<S-P`Q,#0Q-S,V,C<T-@`P,C`Q,#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@
M;6YE;6\O;F]T97!A9',N<&AP+'8@,2XS,2XR+C4@,C`P-B\P,2\P,2`R,3HR
M.3HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!*;V5L
M(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C:RYQ8RYC83X*("H@0V]P>7)I9VAT
M(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O
M+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L
M:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!*;V5L(%9A;F1A;"`\
M:G9A;F1A;$!I;F9O=&5C:RYQ8RYC83X*("H@0&%U=&AO<B`@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@36YE
M;6\@,BXP"B`J($!P86-K86=E($UN96UO"B`J+PH*0&1E9FEN92@G34Y%34]?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E($U.14U/
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HO*B!%>&ET(&EF('1H:7,@:7-N
M)W0@86X@875T:&5N=&EC871E9"!U<V5R+B`J+PII9B`H(4%U=&@Z.F=E=$%U
M=&@H*2D@>PH@("`@<F5Q=6ER92!-3D5-3U]"05-%("X@)R]L:7-T+G!H<"<[
M"B`@("!E>&ET.PI]"@HO*B!2=6X@=&AR;W5G:"!T:&4@86-T:6]N(&AA;F1L
M97)S+B`J+PHD86-T:6]N240@/2!5=&EL.CIG971&;W)M1&%T82@G86-T:6]N
M240G*3L*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G<V%V92<Z"B`@("`D
M=&]?961I="`](%5T:6PZ.F=E=$9O<FU$871A*"=E9&ET7W-H87)E)RD["B`@
M("`D:60@/2!5=&EL.CIG971&;W)M1&%T82@G:60G*3L*("`@(&EF("AE;7!T
M>2@D:60I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*").;W1E
M<&%D<R!M=7-T(&AA=F4@82!N86UE+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!B<F5A:SL*("`@('T*"B`@("`D;F]T97!A9"`]("<G.PH@("`@:68@
M*"%S=')L96XH)'1O7V5D:70I*2!["B`@("`@("`@+RH@0W)E871E($YE=R!3
M:&%R92X@*B\*("`@("`@("`D;F]T97!A9"`]("1'3$]"04Q36R=M;F5M;U]S
M:&%R97,G72T^;F5W4VAA<F4H;60U*&UI8W)O=&EM92@I*2D["B`@("`@("`@
M)&YO=&5P860M/G-E="@G;F%M92<L("1I9"D["B`@("`@("`@)&YO=&5P860M
M/G-E="@G9&5S8R<L(%5T:6PZ.F=E=$9O<FU$871A*"=D97-C<FEP=&EO;B<L
M("<G*2D["B`@("`@("`@)')E<W5L="`]("1'3$]"04Q36R=M;F5M;U]S:&%R
M97,G72T^861D4VAA<F4H)&YO=&5P860I.PH*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@;F]T97!A9"!<(B5S7"(@8V]U
M;&1N)W0@8F4@8W)E871E9#H@)7,B*2P@)&ED+"`D<F5S=6QT+3YG971-97-S
M86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&YO
M=&5P860@7"(E<UPB(&AA<R!B965N(&-R96%T960N(BDL("1I9"DL("=H;W)D
M92YS=6-C97-S)RD["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`D
M;F]T97!A9"`]("8D1TQ/0D%,4ULG;6YE;6]?<VAA<F5S)UTM/F=E=%-H87)E
M*"1T;U]E9&ET*3L*("`@("`@("`D;F]T97!A9"T^<V5T*"=N86UE)RP@)&ED
M*3L*("`@("`@("`D;F]T97!A9"T^<V5T*"=D97-C)RP@571I;#HZ9V5T1F]R
M;41A=&$H)V1E<V-R:7!T:6]N)RP@)R<I*3L*("`@("`@("`D;F]T97!A9"T^
M<V%V92@I.PH*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B5&AE(&YO=&5P860@7"(E<UPB(&AA<R!B965N('-A=F5D+B(I+"`D:60I
M+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@?0H*("`@('5N<V5T*"1T;U]E9&ET
M*3L*("`@(&)R96%K.PH*8V%S92`G9&5L971E)SH*("`@("1T;U]D96QE=&4@
M/2!5=&EL.CIG971&;W)M1&%T82@G961I=%]S:&%R92<I.PH@("`@:68@*"$D
M=&]?9&5L971E*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9
M;W4@;75S="!S96QE8W0@82!N;W1E<&%D('1O(&)E(&1E;&5T960N(BDL("=H
M;W)D92YW87)N:6YG)RD["B`@("`@("`@8G)E86L["B`@("!]"@H@("`@)'-H
M87)E(#T@)$=,3T)!3%-;)VUN96UO7W-H87)E<R==+3YG9713:&%R92@D=&]?
M9&5L971E*3L*("`@(&EF("AI<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'-H87)E+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("!B<F5A:SL*("`@('T*"B`@("`O*B!$96QE=&4@
M=&AE(&YO=&5P860N("HO"B`@("!R97%U:7)E7V]N8V4@34Y%34]?0D%312`N
M("<O;&EB+T1R:79E<BYP:'`G.PH@("`@)'-T;W)A9V4@/2`F36YE;6]?1')I
M=F5R.CIS:6YG;&5T;VXH)'1O7V1E;&5T92D["B`@("`D<F5S=6QT(#T@)'-T
M;W)A9V4M/F1E;&5T94%L;"@I.PH@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B*2P@)'-H87)E
M+3YG970H)VYA;64G*2P@)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@8G)E86L["B`@("!](&5L<V4@>PH@("`@("`@
M("\J(%)E;6]V92!S:&%R92!A;F0@86QL(&=R;W5P<R]P97)M:7-S:6]N<RX@
M*B\*("`@("`@("`D1TQ/0D%,4ULG;6YE;6]?<VAA<F5S)UTM/G)E;6]V95-H
M87)E*"1S:&%R92D["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(E1H92!N;W1E<&%D(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(I
M+"`D<VAA<F4M/F=E="@G;F%M92<I*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@
M('T*"B`@("`O*B!-86ME('-U<F4@=V4@<W1I;&P@;W=N(&%T(&QE87-T(&]N
M92!N;W1E<&%D+B`J+PH@("`@:68@*"%C;W5N="A-;F5M;SHZ;&ES=$YO=&5P
M861S*'1R=64I*2D@>PH@("`@("`@("\J($EF('1H:7,@<VAA<F4@9&]E<VXG
M="!E>&ES="!T:&5N(&-R96%T92!I="X@*B\*("`@("`@("!I9B`H(21'3$]"
M04Q36R=M;F5M;U]S:&%R97,G72T^97AI<W1S*$%U=&@Z.F=E=$%U=&@H*2DI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP
M:'`G.PH@("`@("`@("`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L
M971O;B@I.PH@("`@("`@("`@("`D;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L
M=64H)V9U;&QN86UE)RD["B`@("`@("`@("`@(&EF("AT<FEM*"1N86UE*2`]
M/2`G)RD@>PH@("`@("`@("`@("`@("`@)&YA;64@/2!!=71H.CIR96UO=F5(
M;V]K*$%U=&@Z.F=E=$%U=&@H*2D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'-H87)E(#T@)$=,3T)!3%-;)VUN96UO7W-H87)E<R==+3YN97=3:&%R
M92A!=71H.CIG971!=71H*"DI.PH@("`@("`@("`@("`D<VAA<F4M/G-E="@G
M;F%M92<L('-P<FEN=&8H7R@B)7,G<R!.;W1E<&%D(BDL("1N86UE*2D["B`@
M("`@("`@("`@("1'3$]"04Q36R=M;F5M;U]S:&%R97,G72T^861D4VAA<F4H
M)'-H87)E*3L*("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*?0H*+RH@4&5R
M<V]N86P@3F]T92!,:7-T<R`J+PHD<&5R<V]N86Q?;F]T97!A9',@/2!-;F5M
M;SHZ;&ES=$YO=&5P861S*'1R=64I.PH*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U92D["B1T:71L92`](%\H(DYO=&4@
M3&ES=',B*3L*<F5Q=6ER92!-3D5-3U]414U03$%415,@+B`G+V-O;6UO;BUH
M96%D97(N:6YC)SL*<F5Q=6ER92!-3D5-3U]414U03$%415,@+B`G+VUE;G4N
M:6YC)SL*<F5Q=6ER92!-3D5-3U]414U03$%415,@+B`G+VYO=&5P861S+VYO
M=&5P861S+FEN8R<["G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E
M<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;6YE;6\O=FEE=RYP:'``````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C8V-@`Q,#0Q-S,V,C<T-@`P,3<R,S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@;6YE;6\O=FEE=RYP:'`L=B`Q+C(W+C(N-R`R
M,#`V+S`S+S`S(#(S.C`P.C(Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`Q+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$%33"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O87-L
M+G!H<"X*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@36YE;6\@,2XP"B`J($!P86-K86=E($UN96UO"B`J
M+PH*0&1E9FEN92@G34Y%34]?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*
M<F5Q=6ER95]O;F-E($U.14U/7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HO
M*B!792!C86X@96ET:&5R(&AA=F4@82!5240@;W(@82!M96UO(&ED(&%N9"!A
M(&YO=&5P860N($-H96-K(&9O<B!5240*("H@9FER<W0N("HO"FEF("@D=6ED
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W5I9"<I*2!["B`@("`D<W1O<F%G92`]
M("9-;F5M;U]$<FEV97(Z.G-I;F=L971O;B@I.PH@("`@)&UE;6\@/2`D<W1O
M<F%G92T^9V5T0GE5240H)'5I9"D["B`@("!I9B`H:7-?82@D;65M;RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)VQI<W0N<&AP)RP@=')U92DI.PH@("`@
M("`@(&5X:70["B`@("!]"@H@("`@)&UE;6]?:60@/2`D;65M;ULG;65M;U]I
M9"==.PH@("`@)&UE;6]L:7-T7VED(#T@)&UE;6];)VUE;6]L:7-T7VED)UT[
M"GT@96QS92!["B`@("`O*B!)9B!W92!A<F5N)W0@<')O=FED960@=VET:"!A
M(&UE;6\@86YD(&UE;6]L:7-T+"!R961I<F5C="!T;PH@("`@("H@;&ES="YP
M:'`N("HO"B`@("`D;65M;U]I9"`](%5T:6PZ.F=E=$9O<FU$871A*"=M96UO
M)RD["B`@("`D;65M;VQI<W1?:60@/2!5=&EL.CIG971&;W)M1&%T82@G;65M
M;VQI<W0G*3L*("`@(&EF("@A:7-S970H)&UE;6]?:60I('Q\("$D;65M;VQI
M<W1?:60I('L*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=L:7-T+G!H<"<L('1R=64I*3L*("`@("`@("!E
M>&ET.PH@("`@?0H*("`@("\J($=E="!T:&4@8W5R<F5N="!M96UO+B`J+PH@
M("`@)&UE;6\@/2!-;F5M;SHZ9V5T365M;R@D;65M;VQI<W1?:60L("1M96UO
M7VED*3L*?0H*)'-H87)E(#T@)$=,3T)!3%-;)VUN96UO7W-H87)E<R==+3YG
M9713:&%R92@D;65M;VQI<W1?:60I.PII9B`H:7-?82@D<VAA<F4L("=014%2
M7T5R<F]R)RDI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")4:&5R92!W87,@86X@97)R;W(@=FEE=VEN9R!T:&ES(&YO=&5P860Z("5S
M(BDL("1S:&%R92T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"=L:7-T+G!H<"<L('1R=64I*3L*("`@(&5X:70["GT@96QS96EF("@A)'-H
M87)E+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H*2P@4$5235-?4D5!
M1"DI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H92!N;W1E<&%D("5S
M+B(I+"`D<VAA<F4M/F=E="@G;F%M92<I*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"=L:7-T+G!H<"<L('1R=64I*3L*("`@(&5X:70["GT*"B\J($EF('1H92!R
M97%U97-T960@;F]T92!D;V5S;B=T(&5X:7-T+"!D:7-P;&%Y(&%N(&5R<F]R
M(&UE<W-A9V4N("HO"FEF("@A)&UE;6\@?'P@(6ES<V5T*"1M96UO6R=M96UO
M7VED)UTI*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(DYO=&4@;F]T
M(&9O=6YD+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C871I
M;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)VQI<W0N<&AP)RP@=')U
M92DI.PH@("`@97AI=#L*?0H*+RH@1V5T('1H92!N;W1E)W,@:&ES=&]R>2X@
M*B\*:68@*"%E;7!T>2@D;65M;ULG=6ED)UTI*2!["B`@("`D:&ES=&]R>2`]
M("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("1L;V<@/2`D:&ES
M=&]R>2T^9V5T2&ES=&]R>2@G;6YE;6\Z)R`N("1M96UO;&ES=%]I9"`N("<Z
M)R`N("1M96UO6R=U:60G72D["B`@("!I9B`H)&QO9R`F)B`A:7-?82@D;&]G
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@9F]R96%C:"`H)&QO9RT^9V5T
M1&%T82@I(&%S("1E;G1R>2D@>PH@("`@("`@("`@("!S=VET8V@@*"1E;G1R
M>5LG86-T:6]N)UTI('L*("`@("`@("`@("`@8V%S92`G861D)SH*("`@("`@
M("`@("`@("`@("1C<F5A=&5D(#T@)&5N=')Y6R=T<R==.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=M;V1I9GDG.@H@("`@
M("`@("`@("`@("`@)&UO9&EF:65D(#T@)&5N=')Y6R=T<R==.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"GT*"B\J(%-E="!T:&4@<&%G92!T:71L92!T;R!T:&4@8W5R<F5N="!N;W1E
M)W,@;F%M92P@:68@:70@97AI<W1S+B`J+PHD=&ET;&4@/2`H(21M96UO*2`_
M("1M96UO6R=D97-C)UT@.B!?*").;W1E($1E=&%I;',B*3L*)'!R:6YT7W9I
M97<@/2`H571I;#HZ9V5T1F]R;41A=&$H)W!R:6YT)RD@/3T@)W1R=64G*3L*
M:68@*"$D<')I;G1?=FEE=RD@>PH@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U92D["GT*<F5Q=6ER92!-3D5-3U]4
M14U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*"FEF("@D<')I;G1?
M=FEE=RD@>PH@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S
M)RP@)VAO<F1E)RD@+B`G+VIA=F%S8W)I<'0O<')I;G0N:G,G.PI](&5L<V4@
M>PH@("`@)'!R:6YT7VQI;FL@/2!5=&EL.CIA9&1087)A;65T97(H)W9I97<N
M<&AP)RP@87)R87DH)VUE;6\G(#T^("1M96UO7VED+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUE
M;6]L:7-T)R`]/B`D;65M;VQI<W1?:60L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<')I;G0G(#T^
M("=T<G5E)RDI.PH@("`@)'!R:6YT7VQI;FL@/2!(;W)D93HZ=7)L*"1P<FEN
M=%]L:6YK*3L*("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=S=')I<&4N:G,G
M+"`G:&]R9&4G+"!T<G5E*3L*("`@(')E<75I<F4@34Y%34]?5$5-4$Q!5$53
M("X@)R]M96YU+FEN8R<["GT*"G)E<75I<F4@34Y%34]?5$5-4$Q!5$53("X@
M)R]V:65W+VUE;6\N:6YC)SL*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M
M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VUN96UO+VQI<W0N<&AP````````````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8U,S0`,3`T,3<S-C(W-#8`,#$W,C,R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&UN96UO+VQI<W0N<&AP+'8@,2XS-2XX+C0@
M,C`P-B\P,2\P,2`R,3HR.3HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#$M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H05-,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN
M<&AP+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!-;F5M;R`Q+C`*("H@0'!A8VMA9V4@36YE;6\*("HO
M"@I`9&5F:6YE*"=-3D5-3U]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR
M97%U:7)E7V]N8V4@34Y%34]?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP)SL*
M"B\J($=E="!T:&4@8W5R<F5N="!A8W1I;VX@240N("HO"B1A8W1I;VY)1"`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PH*+RH@4V]R="!O=70@
M=&AE('-O<G1I;F<@=F%L=65S+B`J+PII9B`H571I;#HZ9V5T1F]R;41A=&$H
M)W-O<G1B>2<I("$]/2!N=6QL*2!["B`@("`D<')E9G,M/G-E=%9A;'5E*"=S
M;W)T8GDG+"!5=&EL.CIG971&;W)M1&%T82@G<V]R=&)Y)RDI.PI]"FEF("A5
M=&EL.CIG971&;W)M1&%T82@G<V]R=&1I<B<I("$]/2!N=6QL*2!["B`@("1P
M<F5F<RT^<V5T5F%L=64H)W-O<G1D:7(G+"!5=&EL.CIG971&;W)M1&%T82@G
M<V]R=&1I<B<I*3L*?0H*+RH@1V5T('1H92!F=6QL+"!S;W)T960@;F]T97!A
M9"X@*B\*)&UE;6]S(#T@36YE;6\Z.FQI<W1-96UO<R@D<')E9G,M/F=E=%9A
M;'5E*"=S;W)T8GDG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E
M9G,M/F=E=%9A;'5E*"=S;W)T9&ER)RDI.PH*+RH@4&%G92!V87)I86)L97,N
M("HO"B1T:71L92`](%\H(DUY($YO=&5S(BD["@IS=VET8V@@*"1A8W1I;VY)
M1"D@>PIC87-E("=S96%R8VA?;65M;W,G.@H@("`@+RH@268@=V4G<F4@<V5A
M<F-H:6YG+"!O;FQY(&QI<W0@=&AO<V4@;F]T97,@=&AA="!M871C:"!T:&4@
M<V5A<F-H"B`@("`@*B!R97-U;'0N("HO"B`@("`D<&%T=&5R;B`](%5T:6PZ
M.F=E=$9O<FU$871A*"=S96%R8VA?<&%T=&5R;B<I.PH@("`@)'-E87)C:%]D
M97-C(#T@*%5T:6PZ.F=E=$9O<FU$871A*"=S96%R8VA?9&5S8R<I(#T]("=O
M;B<I.PH@("`@)'-E87)C:%]B;V1Y(#T@*%5T:6PZ.F=E=$9O<FU$871A*"=S
M96%R8VA?8F]D>2<I(#T]("=O;B<I.PH*("`@(&EF("@A96UP='DH)'!A='1E
M<FXI("8F("@D<V5A<F-H7V)O9'D@?'P@)'-E87)C:%]D97-C*2D@>PH@("`@
M("`@("1P871T97)N(#T@)R\G("X@<')E9U]Q=6]T92@D<&%T=&5R;BP@)R\G
M*2`N("<O:2<["B`@("`@("`@)'-E87)C:%]R97-U;'0@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<F5A8V@@*"1M96UO<R!A<R`D;65M;U]I9"`]/B`D;65M;RD@
M>PH@("`@("`@("`@("!I9B`H*"1S96%R8VA?9&5S8R`F)B!P<F5G7VUA=&-H
M*"1P871T97)N+"`D;65M;ULG9&5S8R==*2D@?'P*("`@("`@("`@("`@("`@
M("@D<V5A<F-H7V)O9'D@)B8@<')E9U]M871C:"@D<&%T=&5R;BP@)&UE;6];
M)V)O9'DG72DI*2!["B`@("`@("`@("`@("`@("`D<V5A<F-H7W)E<W5L=%LD
M;65M;U]I9%T@/2`D;65M;SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@4F5A<W-I9VX@)&UE;6]S('1O('1H92!S96%R8V@@<F5S=6QT
M+B`J+PH@("`@("`@("1M96UO<R`]("1S96%R8VA?<F5S=6QT.PH@("`@("`@
M("1T:71L92`](%\H(E-E87)C:"!297-U;'1S(BD["B`@("!]"B`@("!B<F5A
M:SL*?0H*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAT='!C;&EE;G0N:G,G+"`G
M:&]R9&4G+"!T<G5E*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W1O;VQT:7`N
M:G,G+"`G:&]R9&4G+"!T<G5E*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W1A
M8FQE<RYJ<R<L("=M;F5M;R<L('1R=64I.PIR97%U:7)E($U.14U/7U1%35!,
M051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($U.14U/7U1%
M35!,051%4R`N("<O;65N=2YI;F,G.PIR97%U:7)E($U.14U/7U1%35!,051%
M4R`N("<O;&ES="]H96%D97(N:6YC)SL*"FEF("AC;W5N="@D;65M;W,I*2![
M"B`@("`D8TUA;F%G97(@/2`F;F5W(%!R969S7T-A=&5G;W)Y36%N86=E<B@I
M.PH@("`@)&-O;&]R<R`]("1C36%N86=E<BT^8V]L;W)S*"D["B`@("`D9F=C
M;VQO<G,@/2`D8TUA;F%G97(M/F9G0V]L;W)S*"D["B`@("`D<V]R=&)Y(#T@
M)'!R969S+3YG971686QU92@G<V]R=&)Y)RD["B`@("`D<V]R=&1I<B`]("1P
M<F5F<RT^9V5T5F%L=64H)W-O<G1D:7(G*3L*("`@(')E<75I<F4@34Y%34]?
M5$5-4$Q!5$53("X@)R]L:7-T+VUE;6]?:&5A9&5R<RYI;F,G.PH*("`@(&9O
M<F5A8V@@*"1M96UO<R!A<R`D;65M;U]I9"`]/B`D;65M;RD@>PH@("`@("`@
M("1C;VQO<B`](&ES<V5T*"1C;VQO<G-;)&UE;6];)V-A=&5G;W)Y)UU=*2`_
M("1C;VQO<G-;)&UE;6];)V-A=&5G;W)Y)UU=(#H@)&-O;&]R<ULG7V1E9F%U
M;'1?)UT["B`@("`@("`@)&9G8V]L;W(@/2!I<W-E="@D9F=C;VQO<G-;)&UE
M;6];)V-A=&5G;W)Y)UU=*2`_("1F9V-O;&]R<ULD;65M;ULG8V%T96=O<GDG
M75T@.B`D9F=C;VQO<G-;)U]D969A=6QT7R==.PH*("`@("`@("`D=FEE=W5R
M;"`](%5T:6PZ.F%D9%!A<F%M971E<B@G=FEE=RYP:'`G+"!A<G)A>2@G;65M
M;R<@/3X@)&UE;6];)VUE;6]?:60G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;65M;VQI<W0G
M(#T^("1M96UO6R=M96UO;&ES=%]I9"==*2D["@H@("`@("`@("1M96UO=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"=M96UO+G!H<"<L(&%R<F%Y*"=M96UO
M)R`]/B`D;65M;ULG;65M;U]I9"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M96UO;&ES="<@
M/3X@)&UE;6];)VUE;6]L:7-T7VED)UTI*3L*("`@("`@("`D<VAA<F4@/2`D
M1TQ/0D%,4ULG;6YE;6]?<VAA<F5S)UTM/F=E=%-H87)E*"1M96UO6R=M96UO
M;&ES=%]I9"==*3L*"B`@("`@("`@<F5Q=6ER92!-3D5-3U]414U03$%415,@
M+B`G+VQI<W0O;65M;U]S=6UM87)I97,N:6YC)SL*("`@('T*"B`@("!R97%U
M:7)E($U.14U/7U1%35!,051%4R`N("<O;&ES="]M96UO7V9O;W1E<G,N:6YC
M)SL*?2!E;'-E('L*("`@(')E<75I<F4@34Y%34]?5$5-4$Q!5$53("X@)R]L
M:7-T+V5M<'1Y+FEN8R<["GT*"G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E
M;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]M;F5M;R]I;F1E>"YP:'``````````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S4R`#$P-#$W,S8R-S0V`#`Q-S,U
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AO<F1E.B!M;F5M;R]I;F1E>"YP:'`L=B`Q+C$P+C$P
M+C0@,C`P-B\P,2\P,2`R,3HR.3HP-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#$M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H05-,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A
M<VPN<&AP+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!-;F5M;R`Q+C`*("H@0'!A8VMA9V4@36YE;6\*
M("HO"@I`9&5F:6YE*"=-3D5-3U]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI
M.PHD;6YE;6]?8V]N9FEG=7)E9"`]("A`:7-?<F5A9&%B;&4H34Y%34]?0D%3
M12`N("<O8V]N9FEG+V-O;F8N<&AP)RD@)B8*("`@("`@("`@("`@("`@("`@
M("`@0&ES7W)E861A8FQE*$U.14U/7T)!4T4@+B`G+V-O;F9I9R]P<F5F<RYP
M:'`G*2D["@II9B`H(21M;F5M;U]C;VYF:6=U<F5D*2!["B`@("!R97%U:7)E
M($U.14U/7T)!4T4@+B`G+RXN+VQI8B]497-T+G!H<"<["B`@("!(;W)D95]4
M97-T.CIC;VYF:6=&:6QE<TUI<W-I;F<H)TUN96UO)RP@34Y%34]?0D%312P@
M87)R87DH)V-O;F8N<&AP)RP@)W!R969S+G!H<"<I*3L*?0H*<F5Q=6ER92!-
M3D5-3U]"05-%("X@)R]L:7-T+G!H<"<["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;F=O+P``````````````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4P
M`#`Q-3,U-0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O<V-R:7!T<R\`
M````````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#8`,#$W,#4Q`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6YG;R]S8W)I<'1S+RYH=&%C8V5S<P``````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`Q-@`Q,#0Q-S,V,C<T-@`P,C`V-#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1&5N>2!F
M<F]M(&%L;`H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O<V-R
M:7!T<R]C;VYV97)T7VEM<%]F:6QT97)S+G!H<```````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,C$R-C$`,3`T,3<S-C(W-#8`,#(S-C,V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!#;VYV
M97)T<R!A('5S97(G<R!P<F5F97)E;F-E<R!F<F]M('1H92`B;VQD(B!)35`@
M,RYX(&]R($E-4"!(14%$"B`J("AP<F4@-"YX*2!F:6QT97(@9&%T82!S=')U
M8W1U<F4@=&\@=&AE(")N97<B($EN9V\@,BYX('-T<G5C='5R92X*("H*("H@
M5&AI<R!S8W)I<'0@:7,@=6YT97-T960@<V\@=7-E(&%T('EO=7(@;W=N(')I
M<VLN"B`J"B`J(%5S86=E.B!P:'`@8V]N=F5R=%]F:6QT97)S+G!H<"`\(&9I
M;&5N86UE"B`J($9I;&5N86UE(&ES(&$@9FEL92!T:&%T(&-O;G1A:6YS(&$@
M;&ES="!O9B!U<V5R<RP@;VYE('5S97)N86UE('!E<B!L:6YE+@H@*B!4:&4@
M=7-E<FYA;64@<VAO=6QD(&)E('1H92!S86UE(&%S(&AO=R!T:&4@<')E9F5R
M96YC97,@87)E('-T;W)E9"!I;@H@*B!T:&4@<')E9F5R96YC97,@8F%C:V5N
M9"`H92YG+B!U<V5R;F%M97,@;6%Y(&AA=F4@=&\@8F4@:6X@=&AE(&9O<FT*
M("H@=7-E<D!E>&%M<&QE+F-O;2DN"B`J"B`J(%1H:7,@<V-R:7!T(&ES('=R
M:71T96X@=&\@8V]N=F5R="!344P@9&%T86)A<V5S($].3%DN"B`J(%1H97)E
M(&ES(&YO(&=U87)A;G1E92!I="!W:6QL('=O<FL@;VX@;W1H97(@<')E9F5R
M96YC92!B86-K96YD<R`H92YG+B!,1$%0*2X*("H*("H@)$AO<F1E.B!I;F=O
M+W-C<FEP=',O8V]N=F5R=%]I;7!?9FEL=&5R<RYP:'`L=B`Q+C$X+C$P+C<@
M,C`P-B\P,2\S,2`R,#HP,#HS-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC
M;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%
M3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*B\*"D!D969I;F4H)T%55$A?
M2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["D!D969I;F4H)TE.1T]?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PH*+R\@1&\@0TQ)(&-H96-K
M<R!A;F0@96YV:7)O;FUE;G0@<V5T=7`@9FER<W0N"G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+T-,22YP:'`G.PH*+R\@36%K92!S=7)E(&YO(&]N92!R=6YS('1H:7,@
M9G)O;2!T:&4@=V5B+@II9B`H(4AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH
M*2D@>PH@("`@97AI="@B375S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L
M:6YE7&XB*3L*?0H*+R\@3&]A9"!T:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K
M92!S=7)E('1H97)E)W,@;F\@=&EM92!L:6UI="P@:6YI=`HO+R!S;VUE('9A
M<FEA8FQE<RP@971C+@I(;W)D95]#3$DZ.FEN:70H*3L*"B\J($EN:71I86QI
M>F4@=&AE(&YE961E9"!L:6)R87)I97,N("HO"G)E<75I<F5?;VYC92!)3D=/
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HO*B!5<&1A=&4@96%C:"!U<V5R
M+B`J+PIW:&EL92`H(69E;V8H4U1$24XI*2!["B`@("`D=7-E<B`](&9G971S
M*%-41$E.*3L*("`@("1C;W5N="`](#`["B`@("`D=7-E<B`]('1R:6TH)'5S
M97(I.PH*("`@(&5C:&\@(D-O;G9E<G1I;F<@9FEL=&5R<R!F;W(@=7-E<CH@
M)'5S97)<;B(["@H@("`@)'5S97)P<F5F<R`]("90<F5F<SHZ<VEN9VQE=&]N
M*"1C;VYF6R=P<F5F<R==6R=D<FEV97(G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:6UP)RP@)'5S97(L("<G+"!N=6QL+"!F86QS
M92D["B`@("`D=7-E<G!R969S+3YR971R:65V92@I.PH@("`@)&]L9&9I;'1E
M<G,@/2!`=6YS97)I86QI>F4H)'5S97)P<F5F<RT^9V5T5F%L=64H)V9I;'1E
M<G,G*2D["@H@("`@:68@*"%I<U]A<G)A>2@D;VQD9FEL=&5R<RDI('L*("`@
M("`@("!E8VAO("(@("`@3F]T:&EN9R!T;R!C;VYV97)T7&XB.PH@("`@("`@
M(&-O;G1I;G5E.PH@("`@?0H*("`@("\J($QO860@=&AE('5S97(G<R!P<F5F
M97)E;F-E<RX@*B\*("`@("1P<F5F<R`]("90<F5F<SHZ9F%C=&]R>2@D8V]N
M9ELG<')E9G,G75LG9')I=F5R)UTL("=I;F=O)RP@)'5S97(L(&YU;&PL(&YU
M;&PL(&9A;'-E*3L*("`@("1P<F5F<RT^<F5T<FEE=F4H*3L*"B`@("`O*B!-
M97)G92!W:71H(&5X:7-T:6YG(&EN9V\@9FEL=&5R<RX@*B\*("`@("1F:6QT
M97)S(#T@)B1I;F=O7W-T;W)A9V4M/G)E=')I979E*$E.1T]?4U1/4D%'15]!
M0U1)3TY?1DE,5$524RP@9F%L<V4I.PH*("`@("\J($UA:V4@<W5R92!S<&5C
M:6%L(')U;&5S(&5X:7-T("HO"B`@("`D<G5L95]C;W5N="`](#`["B`@("`D
M;&]C871E9"`](&%R<F%Y*"D["B`@("`D9FEL=&5R;&ES="`]("1F:6QT97)S
M+3YG971&:6QT97),:7-T*"D["B`@("!I9B`H(65M<'1Y*"1F:6QT97)L:7-T
M*2D@>PH@("`@("`@(&9O<F5A8V@@*"1F:6QT97)S+3YG971&:6QT97),:7-T
M*"D@87,@)')U;&4I('L*("`@("`@("`@("`@)&QO8V%T961;)')U;&5;)V%C
M=&EO;B==72`]('1R=64["B`@("`@("`@?0H@("`@?0H*("`@(&EF("@A:7-S
M970H)&QO8V%T961;24Y'3U]35$]204=%7T%#5$E/3E]"3$%#2TQ)4U1=*2D@
M>PH@("`@("`@("1F:6QT97)S+3YA9&12=6QE*&%R<F%Y*"=N86UE)R`]/B`B
M0FQA8VML:7-T(BP@)V%C=&EO;B<@/3X@24Y'3U]35$]204=%7T%#5$E/3E]"
M3$%#2TQ)4U0I+"!F86QS92D["B`@("`@("`@96-H;R`B("`@($%D9&5D($)L
M86-K;&ES="!2=6QE7&XB.PH@("`@("`@("1R=6QE7V-O=6YT*RL["B`@("!]
M"@H@("`@:68@*"%I<W-E="@D;&]C871E9%M)3D=/7U-43U)!1T5?04-424].
M7U=(251%3$E35%TI*2!["B`@("`@("`@)&9I;'1E<G,M/F%D9%)U;&4H87)R
M87DH)VYA;64G(#T^(")7:&ET96QI<W0B+"`G86-T:6]N)R`]/B!)3D=/7U-4
M3U)!1T5?04-424].7U=(251%3$E35"DL(&9A;'-E*3L*("`@("`@("!E8VAO
M("(@("`@061D960@5VAI=&5L:7-T(%)U;&5<;B(["B`@("`@("`@)')U;&5?
M8V]U;G0K*SL*("`@('T*"B`@("!I9B`H(6ES<V5T*"1L;V-A=&5D6TE.1T]?
M4U1/4D%'15]!0U1)3TY?5D%#051)3TY=*2D@>PH@("`@("`@("1F:6QT97)S
M+3YA9&12=6QE*&%R<F%Y*"=N86UE)R`]/B`B5F%C871I;VXB+"`G86-T:6]N
M)R`]/B!)3D=/7U-43U)!1T5?04-424].7U9!0T%424].*2P@9F%L<V4I.PH@
M("`@("`@(&5C:&\@(B`@("!!9&1E9"!686-A=&EO;B!2=6QE7&XB.PH@("`@
M("`@("1R=6QE7V-O=6YT*RL["B`@("!]"@H@("`@:68@*"%I<W-E="@D;&]C
M871E9%M)3D=/7U-43U)!1T5?04-424].7T9/4E=!4D1=*2D@>PH@("`@("`@
M("1F:6QT97)S+3YA9&12=6QE*&%R<F%Y*"=N86UE)R`]/B`B1F]R=V%R9"(L
M("=A8W1I;VXG(#T^($E.1T]?4U1/4D%'15]!0U1)3TY?1D]25T%21"DL(&9A
M;'-E*3L*("`@("`@("!E8VAO("(@("`@061D960@1F]R=V%R9"!2=6QE7&XB
M.PH@("`@("`@("1R=6QE7V-O=6YT*RL["B`@("!]"@H@("`@:68@*"1R=6QE
M7V-O=6YT*2!["B`@("`@("`@96-H;R`B("`@($EM<&]R=&EN9R`B("X@)')U
M;&5?8V]U;G0@+B`B(&5X:7-T:6YG(&EN9V\@9FEL=&5R<UQN(CL*("`@('T*
M"B`@("`O*B!)35`@2$5!1"!F:6QT97(@<W1Y;&4*("`@("`J($%R<F%Y"B`@
M("`@*B`H"B`@("`@*B`@(%MB;%T@/3X@07)R87D*("`@("`J("`@*`H@("`@
M("H@("`@(%M"3$%#2TQ)4U1%1"!!1$1215-315-="B`@("`@*B`@("DL"B`@
M("`@*@H@("`@("H@("!;<G5L95T@/3X@07)R87D*("`@("`J("`@*`H@("`@
M("H@("`@(%LJ1FEL=&5R(&YU;6)E<BI=(#T^($%R<F%Y"B`@("`@*B`@("`@
M*`H@("`@("H@("`@("`@6V9L=%T@/3X@07)R87D*("`@("`J("`@("`@("@*
M("`@("`J("`@("`@("`@6UT@/3X@07)R87D*("`@("`J("`@("`@("`@("`H
M"B`@("`@*B`@("`@("`@("`@("!;9FQD72`]/B!!<G)A>2@J1FEE;&0@;F%M
M92AS*2HI"B`@("`@*B`@("`@("`@("`@("!;='AT72`]/B!!<G)A>2@J5&5X
M="!T;R!M871C:"HI"B`@("`@*B`@("`@("`@("`@*0H@("`@("H@("`@("`@
M*0H@("`@("H@("`@("`@6V%C=%T@/3X@*D%C=&EO;B!C;V1E*@H@("`@("H@
M("`@("`@6V9O;%T@/3X@*D9O;&1E<B!N86UE('1O(&UO=F4@=&\J"B`@("`@
M*B`@("`@*0H@("`@("H@("`I"B`@("`@*B`I"B`@("`@*B\*("`@(&EF("AI
M<W-E="@D;VQD9FEL=&5R<ULG8FPG72DI('L*("`@("`@("!I9B`H(65M<'1Y
M*"1O;&1F:6QT97)S6R=B;"==*2D@>PH@("`@("`@("`@("`D;V(@/2`F;F5W
M($EN9V]?4W1O<F%G95]B;&%C:VQI<W0H*3L*("`@("`@("`@("`@)&]B+3YS
M971";&%C:VQI<W0H)&]L9&9I;'1E<G-;)V)L)UTI.PH@("`@("`@("`@("`D
M:6YG;U]S=&]R86=E+3YS=&]R92@D;V(I.PH@("`@("`@("`@("!E8VAO("(@
M("`@0V]N=F5R=&5D($)L86-K;&ES=%QN(CL*("`@("`@("!]"@H@("`@("`@
M(&EF("@A96UP='DH)&]L9&9I;'1E<G-;)W)U;&4G72DI('L*("`@("`@("`@
M("`@9F]R96%C:"`H)&]L9&9I;'1E<G-;)W)U;&4G72!A<R`D=F%L*2!["B`@
M("`@("`@("`@("`@("`D8W5R<B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=A8W1I;VXG(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^("=#;VYV97)T960@24U0($9I;'1E<B<L"B`@("`@("`@("`@("`@("`@
M("`@)V-O;6)I;F4G(#T^($E.1T]?4U1/4D%'15]#3TU"24Y%7T%,3"P*("`@
M("`@("`@("`@("`@("`@("`G<W1O<"<@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@)V9L86=S)R`]/B`P+`H@("`@("`@("`@("`@("`@("`@("=C
M;VYD:71I;VYS)R`]/B!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("=A
M8W1I;VXM=F%L=64G(#T^(&YU;&P*("`@("`@("`@("`@("`@("D["@H@("`@
M("`@("`@("`@("`@+RH@24U07T9)3%1%4E]$14Q%5$4@/2`Q+"!)35!?1DE,
M5$527TU/5D4@/2`R+`H@("`@("`@("`@("`@("`@("`@24U07T9)3%1%4E].
M54M%(#T@,R`J+PH@("`@("`@("`@("`@("`@:68@*"1V86Q;)V%C="==(#T]
M(#$I('L*("`@("`@("`@("`@("`@("`@("`D8W5R<ELG86-T:6]N)UT@/2!)
M3D=/7U-43U)!1T5?04-424].7TU/5D4["B`@("`@("`@("`@("`@("`@("`@
M)&-U<G);)V-O;6)I;F4G72`N/2`G("T@1$5,151%)SL*("`@("`@("`@("`@
M("`@('T@96QS96EF("@D=F%L6R=A8W0G72`]/2`R*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-U<G);)V%C=&EO;B==(#T@24Y'3U]35$]204=%7T%#5$E/
M3E]-3U9%.PH@("`@("`@("`@("`@("`@("`@("1C=7)R6R=C;VUB:6YE)UT@
M+CT@)R`M($U/5D4G.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1V86Q;
M)V%C="==(#T](#,I('L*("`@("`@("`@("`@("`@("`@("`D8W5R<ELG86-T
M:6]N)UT@/2!)3D=/7U-43U)!1T5?04-424].7T1)4T-!4D0["B`@("`@("`@
M("`@("`@("`@("`@)&-U<G);)V-O;6)I;F4G72`N/2`G("T@3E5+12<["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A
M;%LG9FQT)UT@87,@)'9A;#(I('L*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=F%L,ELG9FQD)UT@87,@)&ME>2`]/B`D9FEE;&0I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-U<G);)V-O;F1I=&EO;G,G75M=(#T@07)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9FEE;&0G(#T^('5C
M9FER<W0H)&9I96QD*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M871C:"<@/3X@)V-O;G1A:6YS)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=V86QU92<@/3X@)'9A;#);)W1X="==6R1K97E=+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V-A<V4G(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^($E.1T]?4U1/4D%'15]465!%
M7TA%041%4@H@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'9A;%LG9F]L)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&-U<G);)V%C=&EO;BUV86QU92==(#T@)'9A;%LG9F]L)UT["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&-O=6YT*RL["B`@("`@
M("`@("`@("`@("`D9FEL=&5R<RT^861D4G5L92@D8W5R<BD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&5C:&\@(B`@("!#;VYV97)T960@
M)&-O=6YT($9I;'1E<G-<;B(["B`@("`@("`@)&EN9V]?<W1O<F%G92T^<W1O
M<F4H)&9I;'1E<G,I.PH@("`@?0H*("`@("\J($E-4"`S+G@@9FEL=&5R('-T
M>6QE"B`@("`@*B!!<G)A>0H@("`@("H@*`H@("`@("H@("!;(UT@/3X@07)R
M87D*("`@("`J("`@*`H@("`@("H@("`@(%MA8W1I;VY=(#T^("=M;W9E)R`M
M;W(M("=D96QE=&4G"B`@("`@*B`@("`@6V9O;&1E<ET@/3X@9F]L9&5R(&YA
M;64@*&UA>2!N;W0@97AI<W0I"B`@("`@*B`@("`@6V9I96QD<UT@/3X@07)R
M87D*("`@("`J("`@("`H"B`@("`@*B`@("`@*0H@("`@("H@("`@(%MT97AT
M72`]/B!!<G)A>0H@("`@("H@("`@("@*("`@("`J("`@("`I"B`@("`@*B`@
M("D*("`@("`J("D*("`@("`J+PH@("`@96QS92!["B`@("`@("`@)&)L7V%R
M<F%Y(#T@87)R87DH*3L*"B`@("`@("`@:68@*"%E;7!T>2@D;VQD9FEL=&5R
M<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&]L9&9I;'1E<G,@87,@)')U
M;&4I('L*("`@("`@("`@("`@("`@(&EF("@H)')U;&5;)V%C=&EO;B==(#T]
M("=D96QE=&4G*2`F)@H@("`@("`@("`@("`@("`@("`@("AC;W5N="@D<G5L
M95LG9FEE;&1S)UTI(#T](#$I("8F"B`@("`@("`@("`@("`@("`@("`@*"1R
M=6QE6R=F:65L9',G75LP72`]/2`G9G)O;2<I*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I;E]A<G)A>2@D<G5L95LG=&5X="==+"`D8FQ?87)R87DI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1B;%]A<G)A>5M=(#T@)')U
M;&5;)W1E>'0G73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1C=7)R(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=A8W1I;VXG(#T^(#`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`G0V]N=F5R=&5D($E-
M4"!&:6QT97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`G8V]M8FEN92<@
M/3X@24Y'3U]35$]204=%7T-/34))3D5?04Y9+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G<W1O<"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=F;&%G<R<@/3X@,"P*("`@("`@("`@("`@("`@("`@("`@("`@)V-O
M;F1I=&EO;G,G(#T^(&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("=A8W1I;VXM=F%L=64G(#T^(&YU;&P*("`@("`@("`@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@("`@("`@("!I9B`H)')U;&5;)V%C=&EO;B==(#T]
M("=M;W9E)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<ELG86-T
M:6]N)UT@/2!)3D=/7U-43U)!1T5?04-424].7TU/5D4["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C=7)R6R=N86UE)UT@+CT@)R`M($U/5D4G.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D<G5L95LG86-T:6]N)UT@/3T@
M)V1E;&5T92<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G);)V%C
M=&EO;B==(#T@24Y'3U]35$]204=%7T%#5$E/3E]$25-#05)$.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8W5R<ELG;F%M92==("X]("<@+2!$25-#05)$
M)SL*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<G5L95LG9F]L9&5R)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C=7)R6R=A8W1I;VXM=F%L=64G72`]("1R=6QE6R=F;VQD
M97(G73L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1R=6QE6R=F:65L9',G72!A<R`D:V5Y(#T^("1V86PI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G);)V-O;F1I=&EO;G,G
M75M=(#T@07)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9FEE
M;&0G(#T^('5C9FER<W0H)'9A;"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;6%T8V@G(#T^("=C;VYT86EN<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=F%L=64G(#T^("1R=6QE6R=T97AT)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8V%S92<@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@24Y'3U]35$]204=%7U19
M4$5?2$5!1$52"B`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`D8V]U;G0K*SL*
M("`@("`@("`@("`@("`@("`@("`D9FEL=&5R<RT^861D4G5L92@D8W5R<BD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1O8B`]("9N97<@26YG;U]3=&]R86=E7V)L86-K;&ES="@I.PH@
M("`@("`@("1O8BT^<V5T0FQA8VML:7-T*"1B;%]A<G)A>2D["B`@("`@("`@
M)&EN9V]?<W1O<F%G92T^<W1O<F4H)&]B*3L*("`@("`@("!E8VAO("(@("`@
M0V]N=F5R=&5D("(@+B!C;W5N="@D8FQ?87)R87DI("X@(B!";&%C:VQI<W0@
M16YT<FEE<UQN(CL*"B`@("`@("`@)&EN9V]?<W1O<F%G92T^<W1O<F4H)&9I
M;'1E<G,I.PH@("`@("`@(&5C:&\@(B`@("!#;VYV97)T960@)&-O=6YT($9I
M;'1E<G-<;B(["@H@("`@("`@("1P<F5F<RT^<W1O<F4H*3L*("`@('T*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6YG;R]L;V-A;&4O````````````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,38V,C(`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]D85]$2R\`````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S0W`#`Q-S4V-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE
M+V1A7T1++TQ#7TU%4U-!1T53+P``````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-#<`,#(Q,S4Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6YG;R]L;V-A;&4O9&%?1$LO3$-?34534T%'15,O:6YG;RYM;P``
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`T,S<T-0`Q,#0Q-S,V,C<T-P`P,C(V-30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0`````4`0``'````+P(``!U`0``7!$````````P%P``!````#$7```#````
M-A<``"@````Z%P``"````&,7```%````;!<``"$```!R%P``#P```)07```/
M````I!<```@```"T%P``"````+T7```9````QA<``!,```#@%P``!P```/07
M```.````_!<```4````+&```%````!$8```(````)A@``!0````O&```#0``
M`$08```J````4A@``#(```!]&```$0```+`8```#````PA@```L```#&&```
M"````-(8```)````VQ@```X```#E&```.P```/08```3````,!D``!4```!$
M&0``!````%H9```(````7QD``!4```!H&0``#@```'X9```"````C1D```H`
M``"0&0``#@```)L9```,````JAD```<```"W&0``$````+\9```(````T!D`
M``<```#9&0``"@```.$9```I````[!D``!$````6&@```@```"@:```*````
M*QH```4````V&@``$0```#P:```0````3AH```8```!?&@``"0```&8:```0
M````<!H``!D```"!&@``!P```)L:```5````HQH``"$```"Y&@``)0```-L:
M```1`````1L``!0````3&P``"@```"@;```(````,QL``#H````\&P``+P``
M`'<;```F````IQL```@```#.&P``$@```-<;```/````ZAL``!````#Z&P``
M#0````L<```A````&1P```0````['```!P```$`<```%````2!P```T```!.
M'```"0```%P<```'````9AP```D```!N'```"````'@<```%````@1P``!4`
M``"''```"P```)T<```/````J1P```X```"Y'```!@```,@<```A````SQP`
M``,```#Q'```#````/4<```3`````AT``!D````6'0``&P```#`=```.````
M3!T```L```!;'0``#````&<=```5````=!T```T```"*'0``0P```)@=```Q
M````W!T``$(````.'@``1P```%$>``!/````F1X``#T```#I'@``3@```"<?
M```1````=A\``"4```"('P``!P```*X?```Y````MA\```@```#P'P``#0``
M`/D?```$````!R````P````,(```&````!D@```$````,B````P````W(```
M"@```$0@```%````3R````D```!5(```$@```%\@```0````<B```$,```"#
M(```,@```,<@```"````^B````4```#](```"0````,A```5````#2$``!``
M```C(0``!P```#0A```:````/"$```8```!7(0``!P```%XA```"````9B$`
M``0```!I(0``&````&XA```0````AR$``!L```"8(0``#P```+0A``")````
MQ"$``(D```!.(@``!P```-@B```F````X"(``!D````'(P``&P```"$C```'
M````/2,```0```!%(P``#@```$HC```,````62,``"D```!F(P``!````)`C
M```'````E2,```@```"=(P``!````*8C```O````JR,``",```#;(P``)@``
M`/\C```N````)B0``!0```!5)```%````&HD```4````?R0```P```"4)```
M!0```*$D```>````IR0```T```#&)```"````-0D```5````W20``!X```#S
M)```!0```!(E```H````&"4``"@```!!)0``*0```&HE```3````E"4```<`
M``"H)0``"````+`E```+````N24``!(```#%)0``$@```-@E```+````ZR4`
M``D```#W)0``"P````$F```%````#28``!8````3)@``$0```"HF```4````
M/"8```0```!1)@``!````%8F```+````6R8```P```!G)@``#0```'0F```,
M````@B8```D```"/)@``!````)DF```,````GB8```T```"K)@``!@```+DF
M```/````P"8``!,```#0)@``'@```.0F```@`````R<```0````D)P``#@``
M`"DG```4````."<``!H```!-)P``%P```&@G```7````@"<``!L```"8)P``
M$P```+0G```3````R"<```8```#<)P``'@```.,G```2`````B@``!,````5
M*```!````"DH```0````+B@``!<````_*```(P```%<H```=````>R@```<`
M``"9*```!P```*$H```%````J2@``!$```"O*```*0```,$H```K````ZR@`
M``4````7*0```@```!TI```#````("D``"`````D*0``)````$4I```F````
M:BD```P```"1*0``"````)XI```4````IRD```@```"\*0``#0```,4I```0
M````TRD``#H```#D*0``!P```!\J```&````)RH```L````N*@``%0```#HJ
M```)````4"H```X```!:*@``.P```&DJ```5````I2H```P```"[*@``"@``
M`,@J```*````TRH```P```#>*@``#````.LJ```-````^"H```(````&*P``
M!@````DK``!%````$"L``"8```!6*P``8````'TK```E````WBL``',````$
M+```#````'@L```0````A2P``!L```"6+```)````+(L```*````URP``!H`
M``#B+```(@```/TL```(````("T``"D````I+0``&````%,M```4````;"T`
M``<```"!+0``"0```(DM```*````DRT```,```">+0``!0```*(M```%````
MJ"T```(```"N+0``(0```+$M```>````TRT``(\!``#R+0```P```((O```&
M````AB\``"````"-+P``"````*XO```%````MR\``!\```"]+P``#@```-TO
M```5````["\```D````",```#`````PP```B````&3```!@````\,```!P``
M`%4P```.````73````D```!L,```$0```'8P```(````B#```!H```"1,```
M#````*PP```N````N3```"\```#H,```%````!@Q```#````+3$```L````Q
M,0``"@```#TQ```,````2#$``!(```!5,0``10```&@Q```2````KC$``!0`
M``#!,0``!@```-8Q```(````W3$``!T```#F,0``(0````0R```"````)C(`
M``4````I,@``#P```"\R```*````/S(```4```!*,@``#P```%`R```*````
M8#(```D```!K,@``"@```'4R```L````@#(```X```"M,@```@```+PR```+
M````OS(```8```#+,@``$````-(R```2````XS(```0```#V,@``!P```/LR
M```/`````S,``!0````3,P``!P```"@S```6````,#,``"0```!',P``*```
M`&PS```/````E3,``!$```"E,P``"@```+<S```)````PC,``#@```#,,P``
M-0````4T```H````.S0```H```!D-```$````&\T```/````@#0``!````"0
M-```"P```*$T```=````K30```<```#+-```!@```-,T```%````VC0```\`
M``#@-```"@```/`T```)````^S0```D````%-0``!P````\U```$````%S4`
M`"`````<-0``#P```#TU```0````334``!,```!>-0``!@```'(U```L````
M>34```,```"F-0``#0```*HU```5````N#4``!H```#.-0``&P```.DU```4
M````!38```L````:-@``#````"8V```8````,S8```P```!,-@``0@```%DV
M```Q````G#8``#H```#.-@``/P````DW``!$````23<``#,```".-P``0P``
M`,(W```2````!C@``"H````9.```"@```$0X``!%````3S@```X```"5.```
M%P```*0X```#````O#@```H```#`.```&````,LX```%````Y#@```X```#J
M.```#@```/DX```%````"#D```<````..0``%@```!8Y```3````+3D``$H`
M``!!.0``/0```(PY```"````RCD```<```#-.0``"@```-4Y```8````X#D`
M`!D```#Y.0``!P```!,Z```@````&SH```<````\.@``!@```$0Z```"````
M2SH```0```!..@``%P```%,Z```0````:SH``!T```!\.@``%@```)HZ``"-
M````L3H``(T````_.P``"@```,T[```C````V#L``!L```#\.P``%@```!@\
M```(````+SP```0````X/```#@```#T\```-````3#P``!T```!:/```!```
M`'@\```'````?3P```@```"%/```!P```(X\```Z````ECP``#0```#1/```
M0`````8]```W````1ST``!D```!_/0``%@```)D]```;````L#T```P```#,
M/0``!0```-D]```K````WST``!,````+/@``!P```!\^```9````)SX``!4`
M``!!/@``!P```%<^```J````7SX``#H```"*/@``)@```,4^```2````[#X`
M``4```#_/@``"`````4_```.````#C\```\````=/P``#P```"T_```(````
M/3\```P```!&/P``#````%,_```'````8#\``",```!H/P``&P```(P_```B
M````J#\```4```#+/P``!0```-$_```.````US\```T```#F/P``#P```/0_
M```/````!$````D````40````P```!Y````3````(D```!$````V0```!@``
M`$A````0````3T```!8```!@0```$0```'=````1````B4````,```";0```
M#````)]````2````K$```!8```"_0```$````-9````0````YT```"@```#X
M0```%@```"%!```7````.$$```@```!000``&````%E!```1````<D$``!0`
M``"$00``"0```)E!```;````HT$``!\```"_00``,P```-]!```6````$T(`
M``0````J0@``"````"]"```'````.$(``!(```!`0@``,````%-"```R````
MA$(```4```"W0@```P```+U"```#````P4(``"L```#%0@``)````/%"```H
M````%D,``!$````_0P``"@```%%#```3````7$,```4```!P0P``"P```'9#
M```,````@D,``#L```"/0P``"````,M#```(````U$,```T```#=0P``%0``
M`.M#```,`````40```\````.1```0@```!Y$```4````840``!$```!V1```
M$0```(A$```*````FD0```P```"E1```#````+)$```-````OT0```(```#-
M1```!0```-!$``!*````UD0``"\````A10``4P```%%%```P````I44``(,`
M``#610``#````%I&```4````9T8``!P```!\1@``+P```)E&```.````R48`
M`!(```#81@``&0```.M&```*````!4<``"D````01P``&````#I'```5````
M4T<```8```!I1P``!0```'!'```.````=D<```(```"%1P``"@```(A'```*
M````DT<```4```">1P``(0```*1'```>````QD<```$`````````>0``````
M``#4````E@`````````T````R0`````````(`0```P```%D```!P````````
M`.@````[``````$``',````U````@P```&$```"3````L@```+X````(````
MD0```.,``````````````",````\`````````&<```"]````YP`````````O
M````#`$``(D`````````C0```!$````4````E0```!,!``#0````"@$`````
M``!``````````/H````-`````````!X``````````````$D```"V````E```
M``,!```%`````````,$````:````\P```````````````````.L```#N````
M`````%\```!0````!P```"4```!Z````A@```$H```!'````U@``````````
M````8P`````````N`````````"(``````````0$``($```"H`````````#X`
M```P`````````$8```"W````-P```%T````.````J0`````````9````#P$`
M``\```"Q````!@$`````````````"0$``!,```"`````R````+,```"O````
MB@`````````0`0``=````#T````*``````````````!J````:P```%0`````
M``````````````"_````\````#@```#O````2````.T`````````)P```*P`
M``""````````````````````N````)````#'````'P````4!``!]````VP``
M`'P```!Q``````````T!``!U```````````````A````R@```,P`````````
M%P```"8```#T````9@```!0!````````^0```%$```#A````)````$(````$
M`0``S@````````#F````L````'\```"@`````````(\```#X`````````*0`
M``"U``````````````!B````9`````<!``"$````M````"D`````````*@``
M``(!``!8`````````/8```#$````X@```%X```#D````W0```$,````2`0``
M`````&\````@````"P```*H```"+````V@```)L```":``````````````#7
M`````````%<```#R````H@```-$```"?````=P```$L```#2````````````
M````````50```#\```"2`````````'@``````````````-P````5````K@``
M``````"\````$0$``(@```!V````+0````````"=````N0```+L`````````
M`````!L`````````Y0```````````````````,8```!^`````````$$````L
M````PP````````#/````5@```*8``````````````$X```!I````-@```"@`
M``">````_P```.````!2`````````&````"A````RP```&P````S````````
M`*<`````````!````&4```#W````#````(P````Q````P````%L`````````
M``````````"'````"P$``/T```#3````&`````X!`````````````,T```#J
M````N@````````#Q````10```/P``````````````/L```"8````U0```)D`
M``#L`````````!(```#%````'0```````````````````(X````<````WP``
M`)<````6````P@```.D```#>````>P```'(````K````.0```#H```!,````
MV````#(```"M````A0````D`````````G`````8```#^`````````*,```!N
M````]0```%,```!$````:``````````"````I0````````#9````````````
M````````JP```%P```!-````6@```!````!/`````````&T`````(&%N9``@
M;W(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`R
M-"!H;W5R<P!!32]030!!8W1I;VX@9F]R(&)L86-K;&ES=&5D(&%D9')E<W-E
M<SH`06-T:79A=&4@4V-R:7!T`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!
M9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@
M4V5T=&EN9W,`061D<F5S<P!!9&UI;FES=')A=&EO;@!!;&EA<P!!;&P@;V8@
M=&AE(&9O;&QO=VEN9P!!;G-W97)E9`!!;GD@;V8@=&AE(&9O;&QO=VEN9P!!
M<'!L>2!&:6QT97)S`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@
M=&AI<R!R=6QE/P!!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F
M=&5R(&5A8V@@8VAA;F=E/P!!=F%I;&%B;&4@9FEE;&1S.@!"8V,`0F5G:6YS
M('=I=&@`0FER=&AD87D`0FQA8VML:7-T`$)L86-K;&ES="!%9&ET`$)L86-K
M;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN
M9R!D<FEV97(N`$)L86-K;&ES=&5D($%D9')E<W,`0FQA8VML:7-T960@061D
M<F5S<V5S`$)O9'D`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A
M<V4@4V5N<VET:79E`$-C`$-E;&P@4&AO;F4`0VAA;F=E<R!S879E9"X`0VQO
M<V4@5VEN9&]W`$-O;7!A;GD`0V]N9FER;2!087-S=V]R9`!#;VYT86EN<P!#
M;W!Y("5S`$-O<'D@;V8@)7,`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?
M5&%S:R!M;V1U;&4@)7,`0W)E871E(&YE=R!F;VQD97(`1$0`1$E304),140Z
M(`!$86EL>0!$96%C=&EV871E(%-C<FEP=`!$969A=6QT($ED96YT:71Y`$1E
M;&5T90!$96QE=&4@)7,`1&5L971E($-O;F1I=&EO;@!$96QE=&4@;65S<V%G
M92!C;VUP;&5T96QY`$1E;&5T960`1&5L:79E<B!I;G1O(&UY($E.0D]8`$1E
M;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@8V]P>2!T;P!$96QI=F5R(&EN=&\@
M;7D@24Y"3U@@86YD(')E9&ER96-T('1O`$1E;&EV97(@=&\@9F]L9&5R`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1I<V%B;&4@)7,`1&ES86)L960`1&ES<&QA
M>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A
M<'!L:65D/P!$;R!?;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES
M="!M97-S86=E<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!$;R!T:&ES.@!$;V5S;B=T(&)E9VEN('=I=&@`1&]E<VXG="!C;VYT
M86EN`$1O97-N)W0@96YD('=I=&@`1&]E<VXG="!E>&ES=`!$;V5S;B=T(&UA
M=&-H("AW:71H('!L86-E:&]L9&5R<RD`161I=`!%9&ET("5S`$5M86EL`$5M
M<'1Y(')E<W5L="X`16YA8FQE("5S`$5N86)L960`16YD<R!W:71H`$5Q=6%L
M('1O`$5R<F]R`$5R<F]R('-A=FEN9R!C:&%N9V5S+@!%=F5R>2!,;V=I;@!%
M>&%M<&QE('9A;'5E<SH`17AI<W1I;F<@4G5L97,`17AI<W1S`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`1FEL92!-86YA9V5R`$9I
M;'1E<B!!;&P@365S<V%G97,`1FEL=&5R($]N;'D@4V5E;B!-97-S86=E<P!&
M:6QT97(@3VYL>2!5;G-E96X@365S<V%G97,`1FEL=&5R($]P=&EO;G,`1FEL
M=&5R(%)U;&4`1FEL=&5R(%)U;&5S`$9I;'1E<B!38W)I<'0@1&ES<&QA>0!&
M:6QT97(@7U)U;&5S`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H
M879E(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@(B5S(BX`1FEL=&5R(&%C
M=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+@!&:6QT
M97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O
M('1H92!F;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E
M*',I('1H870@;6%T8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@9&5L971E9"X`
M1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H
M87,@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T
M:79I='DZ(%1H92!M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&1E
M;&5T960N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M
M("(E<R(@:&%S(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT
M97(@;F]T(&9O=6YD+@!&;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA
M=&-H97,Z`$9O<G=A<F0`1F]R=V%R9"!I<R!N;W0@<W5P<&]R=&5D(&EN('1H
M92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$9O<G=A<F1S`$9O<G=A<F1S
M($5D:70`1G)O;0!'<F5A=&5R('1H86X`1W)E871E<B!T:&%N(&]R(&5Q=6%L
M('1O`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`26UP;W)T
M86YT`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN9&EV
M:61U86P@<G5L97,@87)E(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@
M9FEL=&5R:6YG(&1R:79E<BX`26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE
M9"!F;W(@;65S<V%G92!D96QI=F5R>2X`27,`27-N)W0`3&5S<R!T:&%N`$QE
M<W,@=&AA;B!O<B!E<75A;"!T;P!,:7-T($AE;'`@5&]P:6-S`$QI<W0M240`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]G(&EN`$QO9R!O=70`34T`
M36%I;`!-87)?:R!M97-S86=E(&%S(&1E;&5T960`36%R:R!M97-S86=E(&%S
M.@!-871C:&5S("AW:71H('!L86-E:&]L9&5R<RD`36%T8VAI;F<@9FEE;&1S
M`$UA>&EM=6T@;G5M8F5R(&]F(&)L86-K;&ES=&5D(&%D9')E<W-E<R!E>&-E
M961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@36%X:6UU;2!A9&1R97-S97,Z
M("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!B;&%C:VQI
M<W0N`$UA>&EM=6T@;G5M8F5R(&]F('=H:71E;&ES=&5D(&%D9')E<W-E<R!E
M>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@36%X:6UU;2!A9&1R97-S
M97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!W:&ET
M96QI<W0N`$UE<W-A9V4`36ES<VEN9R!A9&1R97-S('1O(')E9&ER96-T(&UE
M<W-A9V4@=&\`36ES<VEN9R!R96%S;VX@9F]R(')E:F5C=`!-:7-S:6YG(')E
M87-O;B!I;B!V86-A=&EO;BX`36]N=&AL>0!-;W9E`$UO=F4@4G5L92!$;W=N
M`$UO=F4@4G5L92!5<`!.7W5M8F5R(&]F(&1A>7,@8F5T=V5E;B!V86-A=&EO
M;B!R97!L:65S.@!.86UE`$YE='=O<FL`3F5W(%)U;&4`3F5W<P!.;R`B)7,B
M(&5L96UE;G0@9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N+@!.;R!B
M86-K96YD(&-O;F9I9W5R960@9F]R('1H:7,@:&]S=`!.;R!B86-K96YD<R!C
M;VYF:6=U<F5D(&EN(&)A8VME;F1S+G!H<`!.;R!F:6QT97)S+B!#;&EC:R`B
M)7,B('1O(&-R96%T92!A(&YE=R!F:6QT97(N`$YO(&AE861E<G,@<W!E8VEF
M:65D`$YO('-C<FEP="!G96YE<F%T960N`$YO('-T<FEN9W,@<W!E8VEF:65D
M`$YO="!E<75A;"!T;P!.;W1E<P!/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A
M=&EN9RX`3W1H97(@3W!T:6]N<P!087-S=V]R9`!087-S=V]R9',@;75S="!M
M871C:"X`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!H;VYE`%!L
M96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R
M:7!T:6]N`%)?96%S;VX`4F5C96EV960`4F5D:7)E8W0@=&\`4F5G=6QA<B!E
M>'!R97-S:6]N`%)E:F5C="!W:71H(')E87-O;@!296UO=F4@<&%I<@!297-E
M;G0@5&\`4F5S96YT+69R;VT`4F5S970`4F5T=7)N('1O($9I;'1E<G,@3&ES
M=`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@4G5L97,@3&ES=`!2;VQE
M`%)U;&4`4G5L92!#;W!I960`4G5L92!$96QE=&5D`%)U;&4@1&ES86)L960`
M4G5L92!%;F%B;&5D`%)U;&4@3F%M90!3879E`%-A=F4@3W!T:6]N<P!3879E
M(%-E='1I;F=S`%-C<FEP=`!38W)I<'0@57!D871I;F<`4V-R:7!T(&YO="!U
M<&1A=&5D+@!38W)I<'0@<W5C8V5S<V9U;&QY(&%C=&EV871E9"X`4V-R:7!T
M('-U8V-E<W-F=6QL>2!D96%C=&EV871E9"X`4V5E;@!396QE8W0@82!F:65L
M9`!396QE8W0@=&%R9V5T(&9O;&1E<@!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L9BU$969I
M;F5D($AE861E<@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F1E<@!3971T:6YG
M<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4VAO=R!!8W1I=F4@4V-R:7!T`%-H
M;W<@0W5R<F5N="!38W)I<'0`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-T;W`@8VAE8VMI;F<@:68@=&AI<R!R=6QE
M(&UA=&-H97,_`%-U8FIE7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z`%-U8FIE
M8W0`4W5C8V5S<P!487-K<P!4:&4@9')I=F5R('-A:60Z(`!4:&5R92!W87,@
M86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4:&5R92!W87,@86X@
M97)R;W(@9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N`%1I=&QE`%1O`%523`!5
M;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S97)N86UE`%5S97)S
M(&EN('1H92!S>7-T96TZ`%9A8V%T:6]N`%9A8V%T:6]N($5D:70`5F%C871I
M;VX@365S<V%G90!686-A=&EO;B!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C
M=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`%=A<FYI;F<`5V5E:VQY`%=E;&-O
M;64L("5S`%=H7VET96QI<W0@861D<F5S<V5S.@!7:&ET96QI<W0`5VAI=&5L
M:7-T($5D:70`5VAI=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U
M<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`5VAI=&5L:7-T960@061D<F5S<V5S
M`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%@M4')I;W)I='D`6"U3<&%M+4QE
M=F5L`%@M4W!A;2U38V]R90!8+5-P86TM4W1A='5S`%E9`%EE87)L>0!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@
M96UA:6P@861D<F5S<R!F;W(@=VAI8V@@=&AE('9A8V%T:6]N(&UE<W-A9V5S
M('-H;W5L9"!B92!A8W1I=F%T960N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!;3F\@
M4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!?061D<F5S<RAE<RD@=&\@9F]R
M=V%R9"!T;SH`7T%D9')E<W-E<R!T;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z
M`%]";&%C:VQI<W0`7T1E;&5T92!M97-S86=E(&-O;7!L971E;'D`7T5N=&5R
M(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE.@!?1F]R=V%R9`!?2V5E<"!A
M(&-O<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT/P!?36]V92!M97-S
M86=E('1O(&9O;&1E<CH`7TUY(&5M86EL(&%D9')E<W-E<SH`7U-C<FEP=`!?
M5F%C871I;VX`7U=H:71E;&ES=`!A;F0`9FEE;&0`;6%T8V@`;W(`<')O8VUA
M:6P@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O`'-I979E(&9I;'1E<B!G96YE
M<F%T960@8GD@26YG;P!0<F]J96-T+4ED+59E<G-I;VXZ($EN9V\@2#,@*#$N
M,"XR+6-V<RD*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P
M,`I03RU2979I<VEO;BU$871E.B`R,#`U+3$P+3`Y(#$U.C$W*S`R,#`*3&%S
M="U4<F%N<VQA=&]R.B!"<FEA;B!4<G5E;'-E;B`\:&]R9&4K:3$X;D!B<FEA
M;G1R=65L<V5N+F1K/@I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E
M+F]R9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN
M("$](#$I.PH`(&]G`"!E;&QE<@`E<R!6961L:6=E:&]L9&5L<V4@+2!"96MR
MYF9T96QS90`R-"!T:6UE<@!!32]030!(86YD;&EN9R!F;W(@=?AN<VME9&4@
M861R97-S97(Z`$%K=&EVZ7(@<V-R:7!T`$]P<F5T=&4@96X@;GD@8G)U9V5R
M.@!/<')E="!P87(`3W!R970@8G)U9V5R`$]P<F5T=&5L<V4@868@8G)U9V5R
M92!E<B!S;.5E="!F<F$`661E<FQI9V5R92!I;F1S=&EL;&EN9V5R`$%D<F5S
M<V4`061M:6YI<W1R871I;VX`2V%L9&5N879N`$%L;&4@;F5D96YS=.5E;F1E
M`$)E<W9A<F5T`%9I;&OE<FQI9V4@868@;F5D96YS=.5E;F1E`%#E9OAR(&9I
M;'1R90!%<B!D=2!S:6MK97(@<.4L(&%T(&1U('9I;"!S;&5T=&4@9&5N;F4@
M<F5G96P_`$]P9&%TZ7(@875T;VUA=&ES:R!S8W)I<'1E="!E9G1E<B!H=F5R
M(.9N9')I;F<_`$9E;'1E<B!T:6P@<N5D:6=H960Z`$)C8P!3=&%R=&5R(&UE
M9`!&^&1S96QS9&%G`%-O<G1L:7-T;FEN9P#&;F1R92!S;W)T;&ES=&YI;F<`
M4V]R=&QI<W1N:6YG('5N9&5R<W3X='1E<R!I:VME(&%F(&1E;B!N=7;F<F5N
M9&4@9FEL=')E<FEN9W-M96MA;FES;64N`%-O<G1L:7-T970@861R97-S90!3
M;W)T;&ES=&5D92!A9')E<W-E<@!"97-K960`2V%L96YD97(`069B<GED(')E
M<&]R=&5R:6YG(&%F('!R;V)L96T`1F]R<VME;"!PY2!S=&]R92!O9R!S;>4@
M8F]G<W1A=F5R`$-C`$UO8FEL`,9N9')I;F=E<B!G96UT+@!,=6L@=FEN9'5E
M`$9I<FUA`$)E:W+F9G0@:V]D96]R9`!);F1E:&]L9&5R`$MO<&GI<B`E<P!+
M;W!I(&%F("5S`$MU;FYE(&EK:V4@Y6)N92!M;V1U;"!T:6P@=F5D;&EG96AO
M;&1E;'-E("5S`$]P<F5T(&YY(&UA<'!E`$1$`%-LY65T($9203H@`$1A9VQI
M9P!);F%K=&EVZ7(@<V-R:7!T`%-T86YD87)D+6ED96YT:71E=`!3;&5T`%-L
M970@)7,`4VQE="!B971I;F=E;'-E`%-L970@8F5S:V5D97(@=&]T86QT`%-L
M971T970`069L97;I<B!I(&UI;B!);F1B86MK90!!9FQE=NER(&D@;6EN($EN
M9&)A:VME(&]G(&MO<&GI<B!T:6P`069L97;I<B!I(&UI;B!);F1B86MK92!O
M9R!O;6%D<F5S<^ER('1I;`!!9FQE=NER(&D@;6%P<&4`0F5S:W)I=B!P<F]B
M;&5M970`4VSE("5S(&9R80!3;.5E="!F<F$`5FES(&1E=&%L:F5R961E(&YO
M=&EF:6MA=&EO;F5R(&[E<B!H=F5R="!F:6QT97(@=61F^')E<S\`4V5N9"!I
M:VME(&UE9&1E;&5L<V5R('1I;"!M87-S92T@96QL97(@;&ES=&4M8F5S:V5D
M97(`1'4@;>4@:6MK92!K86QD92!M86EN=&5N86YC92YP:'`@9&ER96MT90!'
M^'(@9&5T=&4Z`%-T87)T97(@:6MK92!M960`26YD96AO;&1E<B!I:VME`%-L
M=71T97(@:6MK92!M960`1FEN9&5S(&EK:V4`4&%S<V5R(&EK:V4@*&UE9"!P
M;&%D<VAO;&1E<BD`4F5D:6=E<@!2970@)7,`94UA:6P`26YT970@<F5S=6QT
M870N`%-LY2`E<R!T:6P`4VSE970@=&EL`$5N9&5R(&UE9`!,:6<@;65D`$9E
M:FP`1F5J;"!U;F1E<B!L86=R:6YG(&%F(.9N9')I;F=E<BX`06QT:60@=F5D
M(&QO9VEN`$5K<V5M<&5L=N9R9&EE<CH`16MS:7-T97)E;F1E(')E9VQE<@!&
M:6YD97,`2W5N;F4@:6MK92!FY2!F;W)B:6YD96QS92!T:6P@3$1!4"!S97)V
M97)E;BX`1F%X`$9I;&CE;F1T97)I;F<`1FEL='+I<B!A;&QE(&)E<VME9&5R
M`$9I;'1RZ7(@:W5N(&SF<W1E(&)E<VME9&5R`$9I;'1RZ7(@:W5N('5LYG-T
M92!B97-K961E<@!&:6QT97(M:6YD<W1I;&QI;F=E<@!&:6QT97)R96=E;`!&
M:6QT97)R96=L97(`5FES;FEN9R!A9B!F:6QT97(M<V-R:7!T`$9I;'1E<G)E
M9VQE<@!&:6QT97)A:W1I=FET970Z("5S(&)E<VME9"AE<BD@97(@8FQE=F5T
M(&MO<&EE<F5T('1I;"!M87!P96X@(B5S(BX`1FEL=&5R86MT:79I=&5T.B`E
M<R!B97-K960H97(I(&5R(&)L979E="!S;&5T=&5T+@!&:6QT97)A:W1I=FET
M970Z("5S(&)E<VME9"AE<BD@97(@9FQY='1E="!T:6P@;6%P<&5N("(E<R(N
M`$9I;'1E<F%K=&EV:71E=#H@)7,@8F5S:V5D*&5R*2P@9&5R('9A<B!S;W)T
M;&ES=&5T+"!E<B!S;&5T=&5T+@!&:6QT97)A:W1I=FET970Z($)E<VME9&5N
M("(E<R(@9G)A("(E<R(@97(@:V]P:65R970@=&EL(&UA<'!E;B`B)7,B+@!&
M:6QT97)A:W1I=FET970Z($)E<VME9&5N("(E<R(@9G)A("(E<R(@97(@<VQE
M='1E="X`1FEL=&5R86MT:79I=&5T.B!"97-K961E;B`B)7,B(&9R82`B)7,B
M(&5R(&9L>71T970@=&EL(&UA<'!E;B`B)7,B+@!&:6QT97(@:6MK92!F=6YD
M970`1F]R(&5N(&EN9&MO;6UE;F1E(&)E<VME9"P@<V]M('!A<W-E<B!T:6PZ
M`%9I9&5R97-E;F0`5FED97)E<V5N9&5L<V4@97(@:6MK92!U;F1E<G-T^'1T
M970@868@9&5N(&YU=N9R96YD92!F:6QT97)M96MA;FES;64N`%9I9&5R97-E
M;F1E;'-E`%)E9&EGZ7(@=FED97)E<V5N9&5L<V5R`$9R80!3=/AR<F4@96YD
M`%-T^')R92!E;F0@96QL97(@;&EG(&UE9`!(:N9L<`!!9')E<W-E("AH:F5M
M*0!496QE9F]N("AH:F5M*0!(;W)D90!6:6=T:6=T`$EM<&]R=&5R961E(&9E
M;'1E<CH@)7,`26UP;W)T97)E9&4@9F5L=&5R.@!);F1I=FED=65L;&4@<F5G
M;&5R(&5R(&EK:V4@=6YD97)S=/AT=&5T(&%F(&1E;B!N=7;F<F5N9&4@9FEL
M=&5R;65K86YI<VUE+@!):VME+65K<VES=&5R96YD92!B<F5V8F%K:V4@86YG
M:79E="!T:6P@869L979E<FEN9R!A9B!B97-K960N`$5R`$5R(&EK:V4`36EN
M9')E(&5N9`!-:6YD<F4@96YD(&5L;&5R(&QI9R!M960`3W!L:7-T;FEN9R!A
M9B!H:N9L<&5E;6YE<@!,:7-T+4E$`%9I<VYI;F<@868@8G)U9V5R92!E<B!S
M;.5E="!F<F$N`$QO9R!I;F0`3&]G('5D`$U-`$UA:6P`36%R:^ER(&)E<VME
M9&5N('-L971T970`36%R:^ER(&)E<VME9&5N.@!087-S97(@=&EL("AM960@
M<&QA9'-H;VQD97)E*0!/=F5R96YS<&%S<V5N9&4@9F5L=&5R`$UA:W-I;6%L
M="!A;G1A;"!S;W)T;&ES=&5D92!A9')E<W-E<B!O=F5R<W1E9V5T("A!;G1A
M;"!A9')E<W-E<CH@)7,L(&UA:W-I;6%L="!A;G1A;#H@)7,I+B`@2W5N;F4@
M:6MK92!T:6QF^&IE(&YY92!A9')E<W-E<B!T:6P@<V]R=&QI<W1N:6YG+@!-
M86MS:6UA;'0@86YT86P@:'9I9&QI<W1E9&4@861R97-S97(@;W9E<G-T96=E
M="`H06YT86P@861R97-S97(Z("5S+"!M86MS:6UA;'0@86YT86PZ("5S*2X@
M($MU;FYE(&EK:V4@=&EL9OAJ92!N>64@861R97-S97(@=&EL(&AV:61L:7-T
M;FEN9RX`365D9&5L96QS90!-86YG;&5R(&%D<F5S<V5R(&%T(&]M861R97-S
M97)E('1I;`!-86YG;&5R(.5R<V%G(&9O<B!A9G9I<VYI;F<`36%N9VQE<B#E
M<G-A9R!I(&9E<FEE+@!-Y6YE9&QI9P!&;'ET`$9L>70@<F5G96P@;F5D`$9L
M>70@<F5G96P@;W``06YT86P@9&%G92!M96QL96T@9F5R:64M<W9A<CH`3F%V
M;@!.971VYG)K`$YY(')E9V5L`$YY:&5D97(`(B5S(B!E;&5M96YT(&EK:V4@
M9G5N9&5T(&D@/&5M/F)A8VME;F0\+V5M/BUK;VYF:6=U<F%T:6]N+@!);F=E
M;B`\96T^8F%C:V5N9#PO96T^(&MO;F9I9W5R97)E="!F;W(@9&5N;F4@<V5R
M=F5R`$EN9V5N(#QE;3YB86-K96YD<SPO96T^(&MO;F9I9W5R97)E="!I(#QC
M;V1E/F)A8VME;F1S+G!H<#PO8V]D93X`26YG96X@9FEL=')E+B!#;&EC:R`B
M)7,B(&9O<B!A="!O<')E='1E="!E="!N>70@9FEL=&5R+@!);F=E;B!B<F5V
M:&]V961E<B!A;F=I=F5T`%-C<FEP="!I:VME(&=E;F5R97)E="X`26YG96X@
M=&5K<W0M<W1R96YG92!A;F=I=F5T`$EK:V4@;&EG(&UE9`!.;W1E<@!);F1S
M=&EL;&EN9V5R('9E9'+X<F5N9&4@<V-R:7!T+6]P9&%T97)I;F<N`$%N9')E
M(&EN9'-T:6QL:6YG97(`2V]D96]R9`!+;V1E;W)D96YE('-K86P@=N9R92!E
M;G,N`%5D9OAR('9E9&QI9V5H;VQD96QS90!496QE9F]N`$EN9'1A<W0@=F5N
M;&EG<W0@;F%V;F5T('1I;"!D96X@;GEE(&UA<'!E.@!3:W)I=B!V96YL:6=S
M="P@:'9A9"!P<F]B;&5M970@9^5R('5D('#E(&]G(&AV860@9&5R('-K97(N
M`$EN9'1A<W0@=F5N;&EG<W0@8G)U9V5R;F%V;B!O9R!K;V1E;W)D`%!R;V)L
M96UB97-K<FEV96QS90#%<G-A9P!-;V1T86=E=`!/;6%D<F5S<V5R('1I;`!2
M96=U;.9R92!U9'1R>6L`069V:7,@;65D(.5R<V%G`%-L970@<&%R`$=E;G-E
M;F1T('1I;`!'96YS96YD="!F<F$`3G5L<W1I;`!696YD('1I;&)A9V4@=&EL
M(&9I;'1E<F9O<G1E9VYE;'-E;@!4:6QB86=E('1I;"!I;F1S=&EL;&EN9V5R
M;F4`5F5N9"!T:6QB86=E('1I;"!R96=E;&9O<G1E9VYE;'-E;@!296=E;`!2
M96=E;`!296=E;"!K;W!I97)E=`!296=E;"!S;&5T=&5T`%)E9V5L('-LY65T
M(&9R80!296=E;"!S;.5E="!T:6P`4F5G96QN879N`$=E;0!'96UM92!);F1S
M=&EL;&EN9V5R`$=E;2!I;F1S=&EL;&EN9V5R`%-C<FEP=`!/<&1A=&5R97(@
M<V-R:7!T`%-C<FEP="!I:VME(&]P9&%T97)E="X`4V-R:7!T('-LY65T('1I
M;"X`4V-R:7!T('-LY65T(&9R82X`4V5T`%;F;&<@970@9F5L=`!6YFQG(&5N
M9&5L:6<@;6%P<&4`5N9L9R!D871O+6%D<VMI;&QE<F5N.@!6YFQG(&1A=&]F
M;W)M870Z`%;F;&<@=&ED<V9O<FUA=#H`5N9L9R!T;R!F96QT97(L(&1E<B!S
M=F%R97(@=&EL(&AI;F%N9&5N+@!%9V5N+61E9FEN960@8G)E=FAO=F5D`%-E
M;F0@<')O8FQE;6)E<VMR:79E;'-E`$%F<V5N9&5R`%!RYF9E<F5N8V5R;F4@
M;W!D871E<F5T+@!6:7,@86MT:79T('-C<FEP=`!6:7,@;G5VYG)E;F1E('-C
M<FEP=`!3=/AR<F5L<V4`4W!R:6YG('9E9&QI9V5H;VQD96QS92!O=F5R`$EN
M9'1A<W1N:6YG(&9O<B!S<&5C:6%L:V%R86MT97(`4W1O<"!V:61E<F4@=6YD
M97)S^&=E;'-E<BP@:'9I<R!D96YN92!R96=E;"!P87-S97(_`$5M;F4@=&EL
M(&9E<FEE+6)E<VME9#H`16UN90!,>6MK961E<P!/<&=A=F5R`$UE:V%N:7-M
M96X@<V%G9&4Z(`!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@86MT:79E<FEN
M9R!A9B!S8W)I<'1E="X`1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&1E86MT
M:79E<FEN9R!A9B!S8W)I<'1E="X`5&ET96P`5&EL`%523`!+=6YN92!I:VME
M(&;E(&9O<F)I;F1E;'-E('1I;"!344P@<V5R=F5R96XN`$MA;B!I:VME(&EN
M9&SF<V4@9&5F:6YI=&EO;F5N(&%F("5S+@!+=6YN92!I:VME(&]V97)SYG1T
M92!D971T92!7;W)D(&1O:W5M96YT`$9O<G1R>60@YFYD<FEN9V5R`$)R=6=E
M<FYA=FX`0G)U9V5R92!I('-Y<W1E;65T.@!&97)I90#&;F1R92!F97)I90!&
M97)I92UB97-K960`1F5R:64@97(@:6MK92!U;F1E<G-T^'1T970@:2!D96X@
M;G5VYG)E;F1E(&9I;'1E<FUE:V%N:7-M92X`061V87)S96P`56=E;G1L:6<`
M5F5L:V]M;65N+"`E<P!(=FED;&ES=&5D92!A9')E<W-E<CH`2'9I9&QI<W1N
M:6YG`,9N9')E(&AV:61L:7-T90!(=FED;&ES=&YI;F<@97(@:6MK92!U;F1E
M<G-T^'1T970@:2!D96X@;G5VYG)E;F1E(&9I;'1E<FUE:V%N:7-M92X`2'9I
M9&QI<W1E9&4@861R97-S97(`061R97-S92`H87)B96ID92D`5&5L969O;B`H
M87)B96ID92D`6"U0<FEO<FET>0!8+5-P86TM3&5V96P`6"U3<&%M+5-C;W)E
M`%@M4W!A;2U3=&%T=7,`Q<4`Q7)L:6<`1'4@8FQI=F5R(&[X9"!T:6P@870@
M;&%V92!E;B!P<F]B;&5M8F5S:W)I=F5L<V4L(&;X<B!D=2!K86X@<V5N9&4@
M9&5N(&EN9"X`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@9'4@
M=FEL(&9J97)N92X`1'4@<VMA;"!A;F=I=F4@;6EN9'-T(.EN(&4M;6%I;"UA
M9')E<W-E(&AV;W)T:6P@9F5R:64M8F5S:V5D97(@<VMA;"!VYG)E(&%K=&EV
M97)E="X`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@9'4@=FEL
M('1I;&;X:F4N`$1I;B!A=71O<FES871I;VYS+6)A8VME;F0@=6YD97)S=/AT
M=&5R(&EK:V4@;W!L:7-T;FEN9V5N(&%F(&)R=6=E<F4@96QL97(@97(@9&5N
M(&9U;FMT:6]N(&%F(&5N(&5L;&5R(&%N9&5N(&=R=6YD(&)L979E="!S;.5E
M="!F<F$N`%M);G1E="!E;6YE70!;4')O8FQE;6)E<VMR:79E;'-E70!!9')E
M<W-E<B!A="!V:61E<F5S96YD92!T:6PZ`$%D<F5S<V5R+"!S;VT@9&5R(&EK
M:V4@<VMA;"!S96YD97,@<F5S<&]N<R!T:6PZ`%-O<G1L:7-T;FEN9V5R`%-L
M970@8F5S:V5D('1O=&%L=`!+=6X@Z6X@861R97-S92!P<BX@;&EN:64Z`%9I
M9&5R97-E;F0`0F5H;VQD(&5N(&MO<&D@868@8F5S:V5D97(@:2!D96YN92!K
M;VYT;S\`1FQY="!B97-K961E<B!T:6P@;6%P<&4Z`$UI;F4@92UM86EL+6%D
M<F5S<V5R.@!38W)I<'0`1F5R:64`2'9I9&QI<W1N:6YG97(`;V<`8G)E=FAO
M=F5D90!P87-S97(@=&EL`&5L;&5R`'!R;V-M86EL('-C<FEP="!G96YE<F5R
M970@868@26YG;P!S:65V92!F:6QT97(@9V5N97)E<F5T(&%F($EN9V\`````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;F=O+VQO8V%L92]D95]$12\`````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0W`#`Q-S4V,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE+V1E7T1%+TQ#7TU%
M4U-!1T53+P``````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-#<`,#(Q,S0W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L
M;V-A;&4O9&5?1$4O3$-?34534T%'15,O:6YG;RYM;P``````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#0V,S,R-``Q,#0Q-S,V,C<T-P`P,C(V-3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````!1"```'```
M`*1"```;"P``+(4```````"8L0``#@```)FQ```/````J+$```T```"XL0``
M"````,:Q```+````S[$```P```#;L0``!````.BQ```$````[;$```,```#R
ML0``&````/:Q```;````#[(``"T````KL@``'0```%FR```D````=[(``"D`
M``"<L@``&0```,:R```F````X+(```P````'LP``)````!2S```/````.;,`
M``L```!)LP``#@```%6S```%````9+,``"@```!JLP``"````).S```*````
MG+,``!4```"GLP``$@```+VS```+````T+,``(4```#<LP``#@```&*T```*
M````<;0```T```!\M```#@```(JT```1````F;0```T```"KM```#````+FT
M```-````QK0```8```#4M```E````-NT```*````<+4```\```![M0``&```
M`(NU```,````I+4```X```"QM0``#@```,"U```(````S[4```D```#8M0``
M+@```.*U```:````$;8``#(````LM@``.````%^V``!4````F+8``%$```#M
MM@``6@```#^W``!7````FK<``#0```#RMP``"0```">X```-````,;@```<`
M```_N```"@```$>X```/````4K@```4```!BN```!@```&BX```1````;[@`
M``@```"!N```"0```(JX```)````E+@``"4```">N```(````,2X```3````
MY;@``!````#YN```#P````JY```*````&KD``"$````EN0``#P```$>Y```N
M````5[D```,```"&N0``#P```(JY```4````FKD```D```"ON0``#0```+FY
M```2````Q[D``!D```#:N0``'@```/2Y```/````$[H```H````CN@``#P``
M`"ZZ```(````/KH``"0```!'N@``%````&RZ```6````@;H```@```"8N@``
M3@```*&Z```M````\+H``!D````>NP``$P```#B[```'````3+L```P```!4
MNP``+````&&[```.````CKL```,```"=NP``"P```*&[```'````K;L```<`
M``"UNP``!0```+V[```%````P[L```H```#)NP```P```-2[```7````V+L`
M``H```#PNP``#P```/N[```.````"[P``!0````:O```"P```"^\```8````
M.[P``",```!4O```#@```'B\```4````A[P``!<```"<O```%P```+2\```7
M````S+P``!,```#DO```#P```/B\```.````"+T``!\````7O0``'0```#>]
M```'````5;T```8```!=O0``"````&2]```/````;;T```8```!]O0``"```
M`(2]```*````C;T``!,```"8O0``%````*R]```+````P;T``!````#-O0``
M%0```-Z]```-````]+T``!4````"O@``!P```!B^```0````(+X```4````Q
MO@``%0```#>^```1````3;X```P```!?O@``*@```&R^```[````E[X``#@`
M``#3O@``"0````R_```'````%K\``!0````>OP```P```#._```%````-[\`
M`!`````]OP``"0```$Z_```3````6+\``#D```!LOP``$@```*:_```G````
MN;\``"P```#AOP``*@````[````E````.<````H```!?P```!@```&K````)
M````<<````<```![P```+P```(/````W````L\```"X```#KP```50```!K!
M```M````<,$``"T```">P0``/0```,S!```_````"L(``"T```!*P@``0```
M`'C"```C````N<(``",```#=P@``0`````'#```M````0L,``#,```!PPP``
M)0```*3#```5````RL,``!D```#@PP``*0```/K#```D````),0``"@```!)
MQ```,@```'+$```1````I<0```H```"WQ```#````,+$```*````S\0``!``
M``#:Q```%@```.O$```6`````L4```<````9Q0``!P```"'%```4````*<4`
M``H````^Q0``"````$G%```G````4L4```@```!ZQ0```P```(/%```+````
MA\4```<```"3Q0``!P```)O%```&````H\4```4```"JQ0``!P```+#%```&
M````N,4``!0```"_Q0``"````-3%```)````W<4```X```#GQ0``.P```/;%
M```5````,L8``"D```!(Q@``#@```'+&```*````@<8```0```",Q@``!```
M`)'&```'````EL8```D```">Q@``!@```*C&```1````K\8```<```#!Q@``
M%@```,G&```$````X,8```@```#EQ@``!@```.[&```-````]<8```8````#
MQP``'@````K'```1````*<<```@````[QP``#0```$3'```,````4L<```<`
M``!?QP```P```&?'```#````:\<``!<```!OQP``$P```(?'```=````F\<`
M``@```"YQP``!````,+'```(````Q\<```@```#0QP``00```-G'```:````
M&\@``"L````VR```(````&+(```5````@\@```8```"9R```!@```*#(```5
M````I\@``!@```"]R```(@```-;(```N````^<@``!T````HR0``(0```$;)
M``!4````:,D``"D```"]R0``"@```.?)```'````\LD```<```#ZR0``#@``
M``+*```5````$<H```X````GR@```@```#;*```*````.<H```\```!$R@``
M#0```%3*```/````8LH```T```!RR@``"0```(#*```4````BLH```8```"?
MR@``&````*;*```=````O\H``!,```#=R@``$0```/'*```4`````\L```0`
M```8RP``!@```!W+```4````),L``%0````YRP``#@```([+``!D````G<L`
M``0````"S```#@````?,```%````%LP```4````<S```&P```"+,```:````
M/LP``!,```!9S```$0```&W,```1````?\P``!P```"1S```*@```*[,```0
M````V<P``"$```#JS```!0````S-```3````$LT```L````FS0``$@```#+-
M```*````1<T```\```!0S0``#0```&#-```1````;LT``!,```"`S0``#```
M`)3-```&````H<T```P```"HS0``!@```+7-```7````O,T``!````#4S0``
M$0```.7-```(````]\T```4`````S@``#`````;.```0````$\X```4````D
MS@``#0```"K.```&````.,X```<````_S@``#0```$?.```'````5<X```L`
M``!=S@``!P```&G.```'````<<X```D```!YS@``"0```(/.```*````C<X`
M`!D```"8S@``/0```++.```=````\,X```P````.SP``$````!O/```%````
M+,\``"4````RSP``$@```%C/```3````:\\``!(```!_SP``*P```)+/```[
M````OL\``"````#ZSP``"````!O0```V````)-````@```!;T```(0```&30
M```0````AM````@```"7T```#````*#0```&````K=````0```"TT```!P``
M`+G0```/````P=````H```#1T```#@```-S0```'````Z]````H```#ST```
M#0```/[0```?````#-$``!P````LT0``(0```$G1```>````:]$``!D```"*
MT0``'@```*31```;````P]$``"$```#?T0``+@````'2```F````,-(``!P`
M``!7T@``'@```'32```<````D](``"8```"PT@``*P```-?2```S`````],`
M`"8````WTP``*P```%[3```X````BM,``!T```##TP``%0```.'3```O````
M]],``"`````GU```$@```$C4```I````6]0``!X```"%U```(````*34```2
M````Q=0``*(```#8U```%@```'O5```C````DM4``"@```"VU0``*0```-_5
M```H````"=8``!\````RU@``%0```%+6```@````:-8``"4```")U@``*```
M`*_6```M````V-8``#`````&UP``D@```#?7```A````RM<``!8```#LUP``
M'`````/8```F````(-@``"H```!'V```00```'+8``!$````M-@```P```#Y
MV```!P````;9```'````#MD```8````6V0``#0```!W9```0````*]D``!$`
M```\V0``$@```$[9```3````8=D``!(```!UV0``!P```(C9```$````D-D`
M`!````"5V0``$````*;9```,````M]D```X```#$V0``#0```-/9```/````
MX=D``!,```#QV0``#0````7:```H````$]H```,````\V@``#0```$#:```&
M````3MH``!$```!5V@``%P```&?:```;````?]H```X```";V@```@```*K:
M```*````K=H``$D```"XV@``!0````+;```0````"-L```\````9VP``!```
M`"G;```-````+ML```X````\VP```P```$O;```.````3]L``!$```!>VP``
M"````'#;```/````>=L```\```")VP``!P```)G;```-````H=L``!````"O
MVP``#0```,#;```+````SML```8```#:VP``"0```.';```+````Z]L``!``
M``#WVP``#`````C<```*````%=P``!$````@W```&0```#+<```+````3-P`
M``T```!8W```(@```&;<```9````B=P```\```"CW```&P```+/<```T````
MS]P```H````$W0``&`````_=```2````*-T``!D````[W0``%@```%7=```'
M````;-T``"(```!TW0``%0```)?=```A````K=T``"4```#/W0``$0```/7=
M```-````!]X```<````5W@``%````!W>```+````,MX``"(````^W@``+P``
M`&'>```+````D=X```D```"=W@``&0```*?>```+````P=X``!<```#-W@``
M%P```.7>```)````_=X```H````'WP``"````!+?```6````&]\```\````R
MWP``&0```$+?```Z````7-\``!8```"7WP``#@```*[?```8````O=\```@`
M``#6WP``+P```-_?```-````#^```"8````=X```"````$3@``!#````3>``
M`!(```"1X```#P```*3@```0````M.````T```#%X```(0```-/@```(````
M]>```!(```#^X```'P```!'A```(````,>$```L````ZX0``+P```$;A```.
M````=N$```4```"%X0``!@```(OA``!%````DN$```,```#8X0``!P```-SA
M```$````Y.$```<```#IX0``"@```/'A```*````_.$```\````'X@``$```
M`!?B```7````*.(``!$```!`X@``&0```%+B```7````;.(```D```"$X@``
M!0```([B```+````E.(```H```"@X@```@```*OB```%````KN(```T```"T
MX@``&P```,+B```7````WN(``!0```#VX@``"0````OC```.````%>,```T`
M```DXP``$@```#+C```)````1>,``#@```!/XP``(````(CC```'````J>,`
M``@```"QXP``"0```+KC```.````Q.,``'L```#3XP``&````$_D```8````
M:.0```@```"!Y```$0```(KD```'````G.0```4```"DY```&````*KD```>
M````P^0``!L```#BY```&0```/[D```H````&.4``!4```!!Y0``&P```%?E
M```9````<^4``!,```"-Y0``!P```*'E```(````J>4```8```"RY0``!@``
M`+GE```0````P.4```\```#1Y0``$````.'E```/````\N4```L````"Y@``
M#P````[F```,````'N8```\````KY@``!P```#OF```.````0^8```8```!2
MY@``!@```%GF```.````8.8```P```!OY@``&@```'SF```H````E^8```\`
M``#`Y@``"````-#F```(````V>8``!,```#BY@``'@```/;F```A````%><`
M`"`````WYP``&0```%CG```7````<N<``"4```"*YP``%P```+#G```6````
MR.<```0```#?YP``&P```.3G```-`````.@```P````.Z````P```!OH```%
M````'^@```@````EZ```"@```"[H```,````.>@```L```!&Z```$````%+H
M```,````8^@```X```!PZ```"P```'_H```$````B^@```0```"0Z```$P``
M`)7H```4````J>@```P```"^Z```"0```,OH```.````U>@```L```#DZ```
M&P```/#H```3````#.D``!D````@Z0``&P```#KI```.````5ND```L```!E
MZ0``#````''I```5````?ND```T```"4Z0``0P```*+I```Q````YND``$(`
M```8Z@``1P```%OJ``!/````H^H``#T```#SZ@``3@```#'K```1````@.L`
M``<```"2ZP``!P```)KK```*````HNL```T```"MZP``"0```+OK```$````
MQ>L```4```#*ZP```P```-#K```8````U.L```H```#MZP``!````/CK```E
M````_>L``"8````C[```#@```$KL``!\````6>P``!4```#6[```!0```.SL
M```'````\NP```P```#Z[```"`````?M```*````$.T```8````;[0``!P``
M`"+M```Y````*NT```@```!D[0``#0```&WM```"````>^T```8```!^[0``
M!@```(7M```4````C.T```T```"A[0``$````*_M```;````P.T```0```#<
M[0``"0```.'M```%````Z^T``!````#Q[0``"0````+N```)````#.X```4`
M```6[@``&@```!SN```(````-^X```8```!`[@``&0```$?N```.````8>X`
M`"X```!P[@``!P```)_N```'````I^X```4```"O[@``"0```+7N```*````
MO^X```X```#*[@```@```-GN```&````W.X```L```#C[@``#0```._N```)
M````_>X```P````'[P``&````!3O```&````+>\``!(````T[P``"0```$?O
M```'````4>\``!0```!9[P``'0```&[O``!"````C.\``"4```#/[P``)0``
M`/7O```&````&_````H````B\```!````"WP```)````,O````@````\\```
M$0```$7P```)````5_````8```!A\```#0```&CP```&````=O````0```!]
M\```.0```(+P```]````O/```#H```#Z\```'@```#7Q```%````5/$```X`
M``!:\0``!````&GQ```&````;O$```<```!U\0``(0```'WQ```-````G_$`
M`!4```"M\0``!@```,/Q```$````RO$``!$```#/\0``!@```.'Q```*````
MZ/$``"(```#S\0``!````!;R```%````&_(``!T````A\@``!````#_R```,
M````1/(```X```!1\@``"@```&#R```(````:_(```D```!T\@``!0```'[R
M```Z````A/(``#````"_\@``-0```/#R```I````)O,``$<```!0\P``.```
M`)CS```I````T?,``#\```#[\P``+@```#OT```M````:O0``!\```"8]```
M#P```+CT```2````R/0```L```#;]```)@```.?T```I````#O4``"0````X
M]0``)@```%WU```(````A/4```H```"-]0``"0```)CU```'````HO4``"``
M``"J]0``(````,OU```F````[/4```H````3]@``&0```![V```I````./8`
M`!8```!B]@``$@```'GV```'````C/8```H```"4]@``#````)_V```/````
MK/8``!````"\]@``0````,WV``!P````#O<``&8```!_]P``#@```.;W```)
M````]?<```H```#_]P``$@````KX```3````'?@```P````Q^```!@```#[X
M```/````1?@```D```!5^```$@```%_X```0````<O@``!$```"#^```'```
M`)7X```C````LO@``&H```#6^```#P```$'Y```%````4?D``!````!7^0``
M0P```&CY```)````K/D``#(```"V^0``!````.GY```+````[OD``"````#Z
M^0``%````!OZ```,````,/H```P````]^@``#P```$KZ```5````6OH``"D`
M``!P^@``*@```)KZ```F````Q?H``"<```#L^@``*0```!3[```J````/OL`
M`!D```!I^P``0@```(/[```1````QOL``!(```#8^P``$P```.O[```4````
M__L```\````4_```%@```"3\```7````._P``!````!3_```$0```&3\```T
M````=OP``!,```"K_```$@```+_\```U````TOP``!0````(_0``!P```!W]
M```,````)?T``"`````R_0``$````%/]```4````9/T``!$```!Y_0``%P``
M`(O]```<````H_T``!,```#`_0``%````-3]```:````Z?T``!$````$_@``
M&@```!;^```>````,?X``!H```!0_@``$P```&O^```5````?_X``!$```"5
M_@``%P```*?^```4````O_X``!<```#4_@``%0```.S^```)`````O\``!``
M```,_P``&0```!W_```$````-_\```<````\_P```@```$3_```+````1_\`
M``4```!3_P``$0```%G_```&````:_\```8```!R_P``!@```'G_```%````
M@/\```<```"&_P``!P```([_```%````EO\``!8```"<_P``!@```+/_```&
M````NO\```0```#!_P``!````,;_```'````R_\```X```#3_P``#````.+_
M```,````[_\```T```#\_P``"@````H``0`.````%0`!``4````D``$`*```
M`"H``0`.````4P`!``P```!B``$`#P```&\``0`*````?P`!``@```"*``$`
M"0```),``0`K````G0`!``0```#)``$`"````,X``0`F````UP`!`!(```#^
M``$`#P```!$!`0`&````(0$!``H````H`0$`3````#,!`0`'````@`$!``@`
M``"(`0$`(````)$!`0`)````L@$!`!0```"\`0$`#````-$!`0`-````W@$!
M``X```#L`0$`%@```/L!`0`1````$@(!``8````D`@$``P```"L"`0`&````
M+P(!`!D````V`@$`!P```%`"`0`$````6`(!``L```!=`@$`"P```&D"`0`'
M````=0(!``D```!]`@$`%0```(<"`0`%````G0(!``<```"C`@$`%@```*L"
M`0`-````P@(!``T```#0`@$`"@```-X"`0`0````Z0(!``\```#Z`@$`$0``
M``H#`0`7````'`,!``H````T`P$`$0```#\#`0`(````40,!``0```!:`P$`
M#P```%\#`0`Z````;P,!``4```"J`P$`#````+`#`0`>````O0,!``X```#<
M`P$`$````.L#`0`+````_`,!``P````(!`$`"0```!4$`0`'````'P0!``<`
M```G!`$`"@```"\$`0`)````.@0!``X```!$!`$`$````%,$`0`;````9`0!
M`!@```"`!`$`&@```)D$`0`*````M`0!``D```"_!`$`"@```,D$`0`,````
MU`0!``\```#A!`$`"````/$$`0`&````^@0!`!P````!!0$`!P```!X%`0`%
M````)@4!``L````L!0$`1P```#@%`0`-````@`4!``D```".!0$`!````)@%
M`0`#````G04!`!,```"A!0$`$P```+4%`0`3````R04!``H```#=!0$``@``
M`.@%`0`$````ZP4!`"4```#P!0$``P```!8&`0`%````&@8!`"H````@!@$`
M"@```$L&`0`%````5@8!``0```!<!@$`"@```&$&`0`-````;`8!``8```!Z
M!@$`"````($&`0`(````B@8!``0```"3!@$`!0```)@&`0!H````G@8!``D`
M```'!P$`#````!$'`0`0````'@<!`!@````O!P$`!0```$@'`0`&````3@<!
M`!````!5!P$`&P```&8'`0`O````@@<!`!````"R!P$`"@```,,'`0`;````
MS@<!``\```#J!P$`"@```/H'`0`)````!0@!`!,````/"`$`&P```",(`0`8
M````/P@!`!<```!8"`$`'P```'`(`0`7````D`@!``X```"H"`$`B0```+<(
M`0")````00D!``,```#+"0$`!P```,\)`0`(````UPD!``<```#@"0$`"@``
M`.@)`0`+````\PD!``<```#_"0$`40````<*`0`0````60H!``P```!J"@$`
M#0```'<*`0`:````A0H!`$H```"@"@$`&0```.L*`0`&````!0L!`!H````,
M"P$`)0```"<+`0`&````30L!``8```!4"P$`'P```%L+`0`&````>PL!``D`
M``"""P$`&````(P+`0`7````I0L!`"@```"]"P$`!@```.8+`0`-````[0L!
M`"(```#["P$`&0```!X,`0`F````.`P!`%<```!?#`$`$P```+<,`0`9````
MRPP!`!L```#E#`$`(P````$-`0`3````)0T!``(````Y#0$`"P```#P-`0`(
M````2`T!``T```!1#0$`"@```%\-`0`'````:@T!`!0```!R#0$`!@```(<-
M`0`(````C@T!``X```"7#0$`!P```*8-`0`*````K@T!``L```"Y#0$`,@``
M`,4-`0`'````^`T!``P`````#@$`#0````T.`0`7````&PX!``P````S#@$`
M!````$`.`0`)````10X!``D```!/#@$`"@```%D.`0`.````9`X!``P```!S
M#@$`!P```(`.`0`)````B`X!``<```"2#@$`"@```)H.`0`;````I0X!``\`
M``#!#@$`$@```-$.`0`*````Y`X!`!8```#O#@$`"0````8/`0`0````$`\!
M``<````A#P$`$@```"D/`0`I````/`\!``0```!F#P$`!P```&L/`0`%````
M<P\!``4```!Y#P$`"P```'\/`0`4````BP\!`!$```"@#P$`&@```+(/`0`6
M````S0\!`!0```#D#P$`%P```/D/`0`8````$1`!`!P````J$`$`&0```$<0
M`0`'````81`!``4```!I$`$`#0```&\0`0`,````?1`!``@```"*$`$`"```
M`),0`0`7````G!`!``L```"T$`$`#````,`0`0`?````S1`!`!H```#M$`$`
M$P````@1`0`$````'!$!``H````A$0$`!````"P1`0`-````,1$!``P````_
M$0$`!0```$P1`0`)````4A$!``4```!<$0$`!P```&(1`0`%````:A$!``0`
M``!P$0$``@```'41`0`O````>!$!`#@```"H$0$`+````.$1`0`C````#A(!
M`"8````R$@$`$@```%D2`0`I````;!(!`#(```"6$@$`"@```,D2`0`L````
MU!(!`"X````!$P$`,P```#`3`0`S````9!,!`#@```"8$P$`#P```-$3`0`8
M````X1,!`!````#Z$P$`+@````L4`0`4````.A0!``\```!/%`$`$P```%\4
M`0`5````<Q0!`!0```")%`$`$@```)X4`0`4````L10!`!4```#&%`$`+0``
M`-P4`0`M````"A4!`#$````X%0$`+@```&H5`0`O````F14!`"P```#)%0$`
M8@```/85`0`3````618!``T```!M%@$`"````'L6`0`4````A!8!`!<```"9
M%@$`"````+$6`0`4````NA8!``P```#/%@$`*P```-P6`0`A````"!<!`!H`
M```J%P$`"0```$47`0!%````3Q<!`$$```"5%P$`!````-<7`0`3````W!<!
M`!0```#P%P$`#@````48`0`3````%!@!`!@````H&`$`!@```$$8`0`)````
M2!@!``H```!2&`$`#P```%T8`0`,````;1@!`!````!Z&`$`!P```(L8`0`.
M````DQ@!``4```"B&`$`&P```*@8`0`4````Q!@!``@```#9&`$`!@```.(8
M`0`4````Z1@!`!$```#^&`$`#@```!`9`0`X````'QD!``(```!8&0$`!@``
M`%L9`0`.````8AD!``4```!Q&0$`!P```'<9`0`.````?QD!``8```".&0$`
M*````)49`0`,````OAD!`!P```#+&0$`!````.@9`0`I````[1D!`!4````7
M&@$`%P```"T:`0`?````11H!`%P```!E&@$`%````,(:`0`^````UQH!`!\`
M```6&P$`$````#8;`0`'````1QL!`!X```!/&P$`#@```&X;`0`,````?1L!
M``P```"*&P$`$P```)<;`0`*````JQL!`!T```"V&P$`&0```-0;`0`%````
M[AL!`!$```#T&P$`#0````8<`0`(````%!P!`!$````='`$`)````"\<`0`2
M````5!P!`!4```!G'`$`$@```'T<`0`.````D!P!`!D```"?'`$`"````+D<
M`0`)````PAP!``T```#,'`$`!P```-H<`0`*````XAP!``<```#M'`$`#P``
M`/4<`0`&````!1T!``L````,'0$`&@```!@=`0`*````,QT!``<````^'0$`
M"````$8=`0`%````3QT!`!\```!5'0$`!@```'4=`0`0````?!T!``@```"-
M'0$`#0```)8=`0`(````I!T!`!X```"M'0$`$@```,P=`0`L````WQT!`!H`
M```,'@$`"0```"<>`0`*````,1X!`!4````\'@$`!0```%(>`0`4````6!X!
M``0```!M'@$`$````'(>`0`&````@QX!``<```"*'@$`'@```)(>`0`H````
ML1X!``H```#:'@$`'````.4>`0`1`````A\!``L````4'P$`&@```"`?`0`4
M````.Q\!``0```!0'P$`!````%4?`0`+````6A\!``4```!F'P$`!@```&P?
M`0`(````<Q\!``8```!\'P$`"@```(,?`0`;````CA\!`#0```"J'P$`-```
M`-\?`0`@````%"`!`"D````U(`$`(````%\@`0!!````@"`!`!H```#"(`$`
M*````-T@`0`H````!B$!`"D````O(0$`4````%DA`0`B````JB$!``8```#-
M(0$`"````-0A`0`%````W2$!``@```#C(0$`&0```.PA`0`9````!B(!`"H`
M```@(@$`(P```$LB`0`9````;R(!`"X```")(@$`-````+@B`0`(````[2(!
M`!<```#V(@$`"@````XC`0`'````&2,!`"$````A(P$`$````$,C`0`.````
M5",!``L```!C(P$`!P```&\C`0`3````=R,!``@```"+(P$`"P```)0C`0`*
M````H",!`!0```"K(P$`#P```,`C`0`R````T",!``L````#)`$`#@````\D
M`0`%````'B0!``4````D)`$`!0```"HD`0`7````,"0!``<```!()`$`#P``
M`%`D`0`$````8"0!``H```!E)`$`"0```'`D`0`+````>B0!``T```"&)`$`
M#````)0D`0`.````H20!``4```"P)`$`!````+8D`0`-````NR0!`#(```#)
M)`$`10```/PD`0`(````0B4!``L```!+)0$`%P```%<E`0`'````;R4!`!X`
M``!W)0$`%````)8E`0`%````JR4!`!(```"Q)0$`$@```,0E`0`4````UR4!
M``8```#L)0$`!P```/,E`0`.````^R4!`"H````*)@$`!@```#4F`0`,````
M/"8!``T```!))@$`$0```%<F`0`+````:28!`#8```!U)@$`"@```*PF`0`B
M````MR8!``L```#:)@$`#P```.8F`0`R````]B8!`"4````I)P$`,````$\G
M`0`Q````@"<!`"T```"R)P$`#@```.`G`0`)````[R<!``L```#Y)P$`!0``
M``4H`0`.````"R@!`!,````:*`$`$@```"XH`0`'````02@!`!8```!)*`$`
M$0```&`H`0`4````<B@!`!,```"'*`$`!P```)LH`0`4````HR@!`!@```"X
M*`$`!P```-$H`0`%````V2@!``P```#?*`$`#````.PH`0`2````^2@!``0`
M```,*0$`!P```!$I`0`*````&2D!``L````D*0$`#````#`I`0`.````/2D!
M``X```!,*0$`!0```%LI`0`$````82D!``L```!F*0$`#````'(I`0`-````
M?RD!``P```"-*0$`"0```)HI`0`%````I"D!``4```"J*0$`+@```+`I`0`F
M````WRD!`",````&*@$``P```"HJ`0`2````+BH!``8```!!*@$`'@```$@J
M`0`8````9RH!`"4```"`*@$`#0```*8J`0`)````M"H!`!\```"^*@$``P``
M`-XJ`0`8````XBH!``<```#[*@$`"@````,K`0`"````#BL!``P````1*P$`
M%0```!XK`0`+````-"L!`!D```!`*P$`(````%HK`0`2````>RL!``4```".
M*P$`"@```)0K`0`5````GRL!`!(```"U*P$`#````,@K`0`$````U2L!``D`
M``#:*P$`!P```.0K`0`,````["L!``T```#Y*P$`4@````<L`0`7````6BP!
M`"0```!R+`$`$@```)<L`0`'````JBP!``8```"R+`$`#P```+DL`0`3````
MR2P!`!X```#=+`$`(````/PL`0`&````'2T!``X````D+0$`!````#,M`0`,
M````."T!``T```!%+0$`#@```%,M`0`5````8BT!`!(```!X+0$`#P```(LM
M`0`4````FRT!``H```"P+0$`&P```+LM`0`0````URT!``L```#H+0$`%```
M`/0M`0!I````"2X!`!H```!S+@$`%P```(XN`0`G````IBX!`!H```#.+@$`
M%P```.DN`0`;`````2\!`!D````=+P$`'P```#<O`0`3````5R\!`!,```!K
M+P$`"````'\O`0`&````B"\!``<```"/+P$`"````)<O`0`)````H"\!`!4`
M``"J+P$`#0```,`O`0`C````SB\!``T```#R+P$`$P`````P`0`(````%#`!
M``,````=,`$`1@```"$P`0`_````:#`!`#<```"H,`$`5P```.`P`0`>````
M.#$!``4```!7,0$`'P```%TQ`0`O````?3$!``H```"M,0$`"````+@Q`0`-
M````P3$!`"T```#/,0$`!````/TQ`0`2`````C(!`!,````5,@$`3P```"DR
M`0`E````>3(!`!P```"?,@$`"P```+PR`0`?````R#(!`!T```#H,@$`)0``
M``8S`0`@````+#,!`"0```!-,P$`(````'(S`0`+````DS,!``<```"?,P$`
M#0```*<S`0`,````M3,!`!<```#",P$`!@```-HS`0`Y````X3,!``P````;
M-`$`!P```"@T`0`)````,#0!`!,````Z-`$`1P```$XT`0`)````EC0!``0`
M``"@-`$`$````*4T`0`(````MC0!``@```"_-`$`!````,@T`0`+````S30!
M``P```#9-`$`$@```.8T`0`1````^30!``P````+-0$`&@```!@U`0`/````
M,S4!``<```!#-0$`#0```$LU`0`4````634!``X```!N-0$`#````'TU`0`;
M````BC4!`"P```"F-0$`$P```-,U`0`<````YS4!`"@````$-@$`!@```"TV
M`0`'````-#8!`!,````\-@$`!0```%`V`0`$````5C8!``X```!;-@$`%P``
M`&HV`0`*````@C8!``P```"--@$`"0```)HV`0`&````I#8!``D```"K-@$`
M"````+4V`0`)````OC8!``H```#(-@$`$0```-,V`0`&````Y38!`",```#L
M-@$`#@```!`W`0`.````'S<!``T````N-P$`"P```#PW`0`=````2#<!``L`
M``!F-P$``@```'(W`0`<````=3<!`!T```"2-P$`!P```+`W`0`(````N#<!
M``8```#!-P$`9````,@W`0`)````+3@!``<````W.`$`)@```#\X`0`X````
M9C@!`!H```"?.`$`*@```+HX`0`[````Y3@!`"@````A.0$`-````$HY`0`9
M````?SD!`!4```"9.0$`!0```*\Y`0`'````M3D!``@```"].0$`!P```,8Y
M`0`%````SCD!``<```#4.0$`#@```-PY`0`)````ZSD!``8```#U.0$`"```
M`/PY`0`+````!3H!``<````1.@$`"````!DZ`0`'````(CH!`!8````J.@$`
M"0```$$Z`0`&````2SH!``L```!2.@$`$````%XZ`0`&````;SH!`!P```!V
M.@$`%````),Z`0`'````J#H!`!$```"P.@$`"````,(Z`0`.````RSH!``@`
M``#:.@$`$````.,Z`0`)````]#H!`!````#^.@$`!@````\[`0`9````%CL!
M``H````P.P$`'````#L[`0`'````6#L!``4```!@.P$`$````&8[`0`4````
M=SL!``L```",.P$`#0```)@[`0`H````ICL!`!@```#/.P$`%P```.@[`0`$
M`````#P!``D````%/`$`"@````\\`0`'````&CP!``(````B/`$`#@```"4\
M`0`(````-#P!`",````]/`$`'P```&$\`0`X````@3P!`"8```"Z/`$`,0``
M`.$\`0`G````$ST!`#(````[/0$`,@```&X]`0!D````H3T!`!0````&/@$`
M50```!L^`0`X````<3X!`$H```"J/@$`6P```/4^`0`H````43\!`!$```!Z
M/P$`.````(P_`0`H````Q3\!`"P```#N/P$`)@```!M``0`;````0D`!`#X`
M``!>0`$`J0$``)U``0`C````1T(!`!<```!K0@$`2````(-"`0"%````S$(!
M`#````!20P$`)0```(-#`0!!````J4,!`%L```#K0P$`20```$=$`0`Q````
MD40!`!T```##1`$`&````.%$`0`K````^D0!`"$````F10$`'P```$A%`0`K
M````:$4!`"8```"410$`)P```+M%`0`Z````XT4!`!T````>1@$`$0```#Q&
M`0`S````3D8!`"4```""1@$`)P```*A&`0`@````T$8!`!\```#Q1@$`,```
M`!%'`0!I````0D<!`#$```"L1P$`00```-Y'`0`S````($@!`"4```!42`$`
M/0```'I(`0!E````N$@!`$T````>20$`*0```&Q)`0`K````EDD!`"\```#"
M20$`+@```/))`0`P````(4H!`%0```!22@$`6@```*=*`0!(`````DL!`$H`
M``!+2P$`,@```)9+`0`O````R4L!`"P```#Y2P$`+0```"9,`0!Q````5$P!
M`&8```#&3`$`;P```"U-`0"S````G4T!`!<```!13@$`)0```&E.`0`R````
MCTX!`"D```#"3@$`/@```.Q.`0`B````*T\!`%(```!.3P$`)0```*%/`0`+
M````QT\!`+$```#33P$`10```(50`0`A````RU`!`#````#M4`$`)0```!Y1
M`0`<````1%$!`#$```!A40$`!P```)-1`0`'````FU$!``0```"C40$`#0``
M`*A1`0`+````ME$!``X```#"40$`"P```-%1`0`%````W5$!`!````#C40$`
M`@```/11`0!9````]U$!``,```!14@$`!0```%52`0`2````6U(!``0```!N
M4@$`!P```'-2`0`(````>U(!``4```"$4@$`,````(I2`0`#````NU(!`!``
M``"_4@$`#````-!2`0`3````W5(!``T```#Q4@$``@```/]2`0`'`````E,!
M``8````*4P$`%````!%3`0`,````)E,!`!@````S4P$`!@```$Q3`0`2````
M4U,!``P```!F4P$``P```'-3`0`J````=U,!``0```"B4P$`!@```*=3`0`'
M````KE,!`!\```"V4P$`-0```-93`0`N````#%0!`"\````[5`$`%P```&M4
M`0`B````@U0!`"4```"F5`$`(````,Q4`0`;````[50!`!@````)50$`)```
M`")5`0`?````1U4!`!H```!G50$`(0```()5`0`@````I%4!`!H```#%50$`
M,@```.!5`0`:````$U8!`"\````N5@$`*P```%Y6`0`?````BE8!`",```"J
M5@$`'P```,Y6`0`:````[E8!`"$````)5P$`)0```"M7`0`F````45<!`"4`
M``!X5P$`)````)Y7`0`8````PU<!`!T```#<5P$`)````/I7`0`8````'U@!
M`"(````X6`$`+````%M8`0`O````B%@!`!4```"X6`$`)0```,Y8`0`\````
M]%@!`!\````Q60$`(P```%%9`0`?````=5D!`"````"560$`&@```+99`0`8
M````T5D!`"8```#J60$`'@```!%:`0`I````,%H!`!X```!:6@$`,0```'E:
M`0`)````JUH!``P```"U6@$`%P```,):`0`O````VEH!`"0````*6P$`!P``
M`"];`0`/````-UL!`!0```!'6P$`#@```%Q;`0`-````:UL!`"0```!Y6P$`
M!0```)Y;`0`'````I%L!`"(```"L6P$`)0```,];`0`:````]5L!`!T````0
M7`$`&@```"Y<`0`'````25P!`,<```!17`$`"P```!E=`0`5````)5T!``8`
M```[70$`"0```$)=`0`+````3%T!``T```!870$`%P```&9=`0`&````?ET!
M`#,```"%70$`$P```+E=`0`3````S5T!``<```#A70$`#P```.E=`0`'````
M^5T!`#(````!7@$`!````#1>`0`A````.5X!`!,```!;7@$`#````&]>`0`1
M````?%X!`#(```".7@$`%@```,%>`0`(````V%X!`!T```#A7@$`"0```/]>
M`0`*````"5\!`!0````47P$`"@```"E?`0`=````-%\!``@```!27P$`#0``
M`%M?`0`Z````:5\!`!\```"D7P$`"````,1?`0`:````S5\!`"<```#H7P$`
M!@```!!@`0`5````%V`!``<````M8`$`"````#5@`0`)````/F`!`#\```!(
M8`$`!P```(A@`0`/````D&`!``X```"@8`$`$````*]@`0`)````P&`!``D`
M``#*8`$`"````-1@`0`3````W6`!``<```#Q8`$`&0```/E@`0`*````$V$!
M`!<````>80$`%````#9A`0`*````2V$!``P```!680$`%P```&-A`0`$````
M>V$!`"H```"`80$`#````*MA`0`1````N&$!``<```#*80$``@```-)A`0`0
M````U6$!`!@```#F80$`"P```/]A`0`#````"V(!``@````/8@$`!@```!AB
M`0`'````'V(!``T````G8@$`"P```#5B`0`4````06(!`!4```!68@$`#@``
M`&QB`0`5````>V(!`"\```"18@$`(````,%B`0`<````XF(!`!4```#_8@$`
M#````!5C`0`Q````(F,!``D```!48P$`#@```%YC`0`[````;6,!`!4```"I
M8P$`!0```+]C`0`2````Q6,!`#\```#88P$`$@```!AD`0`*````*V0!``8`
M```V9`$`!````#UD`0`$````0F0!``H```!'9`$`$P```%)D`0`%````9F0!
M``8```!L9`$`!@```'-D`0`(````>F0!``0```"#9`$`#````(AD`0`*````
ME60!`#D```"@9`$`+@```-ID`0`I````"64!``H````S90$`!0```#YE`0`,
M````1&4!``P```!190$`#0```%YE`0`8````;&4!`!D```"%90$`'P```)]E
M`0`=````OV4!`!$```#=90$``@```.]E`0`$````\F4!``H```#W90$`!@``
M``)F`0`%````"68!``,````/9@$`#````!-F`0!%````(&8!`#(```!F9@$`
M,0```)EF`0`S````RV8!`!H```#_9@$`-````!IG`0`H````3V<!`%,```!X
M9P$`&0```,QG`0`?````YF<!`'(````&:`$`(````'EH`0`U````FF@!`"$`
M``#0:`$`10```/)H`0`P````.&D!`"@```!I:0$`*0```))I`0`F````O&D!
M`&````#C:0$`)0```$1J`0`H````:FH!`"@```"3:@$`(@```+QJ`0`K````
MWVH!`#`````+:P$`$@```#QK`0`3````3VL!`!````!C:P$`>0```'1K`0`)
M````[FL!`*$```#X:P$`<P```)IL`0!\````#FT!`"L```"+;0$`5````+=M
M`0`7````#&X!`"<````D;@$`%@```$QN`0`/````8VX!`!<```!S;@$`'P``
M`(MN`0!`````JVX!`!\```#L;@$`'`````QO`0!1````*6\!`!H```![;P$`
M%````)9O`0`*````JV\!``4```"V;P$`!@```+QO`0`(````PV\!``4```#,
M;P$`$@```-)O`0`,````Y6\!`!````#R;P$`$P````-P`0`=````%W`!``\`
M```U<`$`&P```$5P`0`D````87`!``\```"&<`$`"@```)9P`0`$````H7`!
M``D```"F<`$`"P```+!P`0`:````O'`!`"(```#7<`$`"````/IP`0`'````
M`W$!``4````+<0$`%````!%Q`0`I````)G$!``<```!0<0$`"````%AQ`0`/
M````87$!`!@```!Q<0$`%````(IQ`0`(````GW$!``P```"H<0$`#P```+5Q
M`0`'````Q7$!``8```#-<0$`%````-1Q`0`&````Z7$!``D```#P<0$`"@``
M`/IQ`0`&````!7(!``P````,<@$`$0```!ER`0`#````*W(!``@````O<@$`
M!````#AR`0`9````/7(!`!$```!7<@$`"@```&ER`0`8````='(!`!,```"-
M<@$`'````*%R`0`1````OG(!`!H```#0<@$`!````.MR`0`/````\'(!``<`
M````<P$`!0````AS`0`$````#G,!`!D````3<P$`!P```"US`0`"````-7,!
M``(````X<P$`$0```#MS`0`)````37,!``@```!7<P$`!@```&!S`0`2````
M9W,!`!<```!Z<P$`!@```))S`0`A````F7,!``4```"[<P$`)P```,%S`0`"
M````Z7,!``0```#L<P$`#P```/%S`0`3`````70!``<````5=`$``@```!UT
M`0`'````('0!`!$````H=`$`!@```#IT`0`A````070!`!@```!C=`$`!@``
M`'QT`0`3````@W0!`!````"7=`$`$@```*AT`0`"````NW0!``8```"^=`$`
M#````,5T`0`)````TG0!`!$```#<=`$`(@```.YT`0`'````$74!``<````9
M=0$`"P```"%U`0`%````+74!``(````S=0$`"P```#9U`0!I`0``0G4!``\`
M``"L=@$`$P```+QV`0`.````T'8!``@```#?=@$`"0```.AV`0`*````\G8!
M``0```#]=@$`!0````)W`0`%````"'<!`!H````.=P$`'P```"EW`0`R````
M27<!`#````!\=P$`*0```*UW`0`H````UW<!`!X`````>`$`,P```!]X`0`,
M````4W@!`"<```!@>`$`$@```(AX`0`,````FW@!`!````"H>`$`!0```+EX
M`0`A````OW@!`!````#A>`$`$````/)X`0`6`````WD!`!4````:>0$`#```
M`#!Y`0"%````/7D!`!````##>0$`"@```-1Y`0`2````WWD!`!````#R>0$`
M#@````-Z`0`,````$GH!``X````?>@$`$0```"YZ`0`&````0'H!`,$```!'
M>@$`!P````E[`0`+````$7L!`!H````=>P$`#P```#A[`0`1````2'L!`!$`
M``!:>P$`"@```&Q[`0`'````=WL!`"P```!_>P$`)````*Q[`0!5````T7L!
M`&$````G?`$`>0```(E\`0!X`````WT!`'P```!\?0$`>P```/E]`0!8````
M=7X!`!$```#.?@$`&0```.!^`0`0````^GX!`!(````+?P$`&````!Y_`0`%
M````-W\!``8````]?P$`$@```$1_`0`'````5W\!``T```!??P$`#0```&U_
M`0`W````>W\!`"X```"S?P$`$@```.)_`0`-````]7\!`!(````#@`$`"P``
M`!:``0`D````(H`!`!$```!'@`$`-P```%F``0`*````D8`!`!L```"<@`$`
M&P```+B``0`0````U(`!`!8```#E@`$`%@```/R``0`>````$X$!`!X````R
M@0$`)0```%&!`0`1````=X$!`!H```")@0$`#P```*2!`0`J````M($!`!H`
M``#?@0$`'P```/J!`0`3````&H(!`'H````N@@$`0@```*F"`0`O````[((!
M`!D````<@P$`!P```#:#`0`*````/H,!`#````!)@P$`#@```'J#`0`'````
MB8,!``L```"1@P$`"````)V#`0`(````IH,!``D```"O@P$`"P```+F#`0`,
M````Q8,!``0```#2@P$`%````->#`0`,````[(,!``L```#Y@P$`$`````6$
M`0`2````%H0!``\````IA`$`&0```#F$`0`F````4X0!`!$```!ZA`$`&@``
M`(R$`0`:````IX0!`!X```#"A`$`&````.&$`0`4````^H0!`!(````/A0$`
M$@```"*%`0`G````-84!`"<```!=A0$`!P```(6%`0`&````C84!``@```"4
MA0$`#@```)V%`0`'````K(4!``L```"TA0$`"0```,"%`0`3````RH4!`!,`
M``#>A0$`"0```/*%`0`/````_(4!`!4````,A@$`%0```"*&`0`8````.(8!
M``H```!1A@$`#P```%R&`0`%````;(8!`!<```!RA@$`"P```(J&`0`*````
MEH8!`#8```"AA@$`2P```-B&`0!%````)(<!``L```!JAP$`"````':'`0`5
M````?X<!``4```"5AP$`!0```)N'`0`0````H8<!``L```"RAP$`%P```+Z'
M`0`N````UH<!`!`````%B`$`/0```!:(`0`\````5(@!`#\```"1B`$`/P``
M`-&(`0`)````$8D!``8````;B0$`"@```"*)`0`*````+8D!`$$````XB0$`
M/0```'J)`0!`````N(D!`'$```#YB0$`/P```&N*`0!#````JXH!`%,```#O
MB@$`4````$.+`0`_````E(L!`%$```#4BP$`,P```":,`0`W````6HP!`%<`
M``"2C`$`/P```.J,`0!#````*HT!`"H```!NC0$`(````)F-`0`<````NHT!
M`#T```#7C0$`*0```!6.`0`I````/XX!`#D```!IC@$`$@```*..`0`-````
MMHX!``T```#$C@$`"P```-*.`0`0````WHX!`!L```#OC@$`'P````N/`0`'
M````*X\!``<````SCP$`%@```#N/`0`+````4H\!``@```!>CP$`+0```&>/
M`0`*````E8\!``,```"@CP$`"P```*2/`0`*````L(\!``<```"[CP$`!@``
M`,./`0`%````RH\!``@```#0CP$`!@```-F/`0`B````X(\!``H````#D`$`
M#P````Z0`0`:````'I`!`$8````YD`$`&````("0`0`M````F9`!`!(```#'
MD`$`"````-J0`0`$````XY`!``0```#HD`$`"````.V0`0`+````]I`!``0`
M```"D0$`#`````>1`0`&````%)$!`!,````;D0$`!@```"^1`0`(````-I$!
M``4````_D0$`"P```$61`0`)````49$!`"D```!;D0$`$0```(61`0`)````
MEY$!`!,```"AD0$`#````+61`0`'````PI$!``,```#*D0$``P```,Z1`0`7
M````TI$!`!<```#JD0$`-P````*2`0`(````.I(!``D```!#D@$`"@```$V2
M`0`'````6)(!`&,```!@D@$`+````,22`0`Z````\9(!`#P````LDP$`*@``
M`&F3`0`&````E),!``D```";DP$`&````*63`0`L````OI,!`"4```#KDP$`
M-@```!&4`0`R````2)0!`#,```![E`$`D0```*^4`0!(````094!``D```"*
ME0$`"P```)25`0`(````H)4!`!X```"IE0$`'0```,B5`0`-````YI4!``(`
M``#TE0$`#````/>5`0`3````!)8!``T````8E@$`$P```":6`0`.````.I8!
M``P```!)E@$`%@```%:6`0`)````;98!`!P```!WE@$`'0```)26`0`1````
MLI8!`!(```#$E@$`%0```->6`0`&````[98!``8```#TE@$`%P```/N6`0"$
M````$Y<!`!<```"8EP$`>P```+"7`0`'````+)@!`!,````TF`$`!0```$B8
M`0`%````3I@!`!\```!4F`$`'@```'28`0`4````DY@!`!<```"HF`$`'@``
M`,"8`0`T````WY@!`"\````4F0$`#P```$29`0`H````5)D!``8```!]F0$`
M&````(29`0`4````G9D!`!D```"RF0$`%0```,R9`0`5````XID!`!$```#X
MF0$`"@````J:`0`3````%9H!`!$````IF@$`!@```#N:`0`+````0IH!``<`
M``!.F@$`"P```%::`0`.````8IH!`!<```!QF@$`"0```(F:`0`%````DYH!
M``L```"9F@$`"````*6:`0`(````KIH!`!0```"WF@$`!@```,R:`0`&````
MTYH!``P```#:F@$`"0```.>:`0`0````\9H!``<````"FP$`!0````J;`0`(
M````$)L!``L````9FP$`"P```"6;`0`:````,9L!`$0```!,FP$`*P```)&;
M`0`0````O9L!`!,```#.FP$`!0```.*;`0`<````Z)L!`!H````%G`$`&P``
M`""<`0`9````/)P!`#T```!6G`$`3````)2<`0`H````X9P!``@````*G0$`
M/0```!.=`0`'````49T!`"0```!9G0$`#P```'Z=`0`&````CIT!``L```"5
MG0$`!@```*&=`0`(````J)T!``L```"QG0$`&P```+V=`0`,````V9T!`!``
M``#FG0$`"0```/>=`0`*`````9X!``X````,G@$`.0```!N>`0`Y````59X!
M`#L```"/G@$`.P```,N>`0`K````!Y\!`"H````SGP$`+````%Z?`0`J````
MBY\!`$(```"VGP$`+P```/F?`0`N````*:`!`#````!8H`$`*````(F@`0`O
M````LJ`!`#P```#BH`$`/@```!^A`0`T````7J$!`#$```"3H0$`.0```,6A
M`0`O````_Z$!`#(````OH@$`1@```&*B`0`P````J:(!`!\```#:H@$`.@``
M`/JB`0`N````-:,!`#L```!DHP$`'P```*"C`0#<````P*,!`!\```"=I`$`
M+@```+VD`0`Q````[*0!`#(````>I0$`-0```%&E`0`P````AZ4!`"X```"X
MI0$`,0```.>E`0`Y````&:8!`#P```!3I@$`1````)"F`0`\````U:8!`,4`
M```2IP$`+P```-BG`0`B````"*@!`"\````KJ`$`,P```%NH`0`^````CZ@!
M`&0```#.J`$`70```#.I`0`.````D:D!``0```"@J0$`!0```*6I`0`)````
MJZD!``X```"UJ0$`%@```,2I`0`6````VZD!`!4```#RJ0$`#P````BJ`0`2
M````&*H!``@````KJ@$`!````#2J`0`1````.:H!`!$```!+J@$`#0```%VJ
M`0`0````:ZH!`!$```!\J@$`$````(ZJ`0`8````GZH!``X```"XJ@$`40``
M`,>J`0`,````&:L!`!0````FJP$`!@```#NK`0`3````0JL!`!D```!6JP$`
M'@```'"K`0`5````CZL!``(```"EJP$`#0```*BK`0!+````MJL!``<````"
MK`$`$`````JL`0`0````&ZP!``4````LK`$`#0```#*L`0`-````0*P!``,`
M``!.K`$`#P```%*L`0`3````8JP!``@```!VK`$`!@```'^L`0`1````AJP!
M``@```"8K`$`#0```*&L`0`1````KZP!``T```#!K`$`#````,^L`0`'````
MW*P!``H```#DK`$`#0```.^L`0`1````_:P!``X````/K0$`"P```!ZM`0`.
M````*JT!`"$````YK0$`#0```%NM`0`.````::T!`"8```!XK0$`&@```)^M
M`0`3````NJT!`!<```#.K0$`+0```.:M`0`-````%*X!`!T````BK@$`$P``
M`$"N`0`;````5*X!`!H```!PK@$`"````(NN`0`N````E*X!`"````##K@$`
M,@```.2N`0`V````%Z\!`!P```!.KP$`$0```&NO`0`(````?:\!`!L```"&
MKP$`#````**O`0`B````KZ\!`#````#2KP$`"P````.P`0`(````#[`!`!T`
M```8L`$`"@```#:P`0`5````0;`!`!4```!7L`$`"P```&VP`0`/````>;`!
M``L```")L`$`(P```)6P`0`5````N;`!`!\```#/L`$`30```.^P`0`9````
M/;$!``T```!7L0$`$P```&6Q`0`)````>;$!`%````"#L0$`#0```-2Q`0`O
M````XK$!``L````2L@$`40```!ZR`0`1````<+(!``T```""L@$`#P```)"R
M`0`/````H+(!`",```"PL@$`"````-2R`0`7````W;(!`"(```#UL@$`#0``
M`!BS`0`0````)K,!`#0````WLP$`#````&RS`0`&````>;,!``4```"`LP$`
M2P```(:S`0`&````TK,!``<```#9LP$`"@```.&S`0`-````[+,!`!````#Z
MLP$`$0````NT`0`1````';0!`!$````OM`$`&@```$&T`0`=````7+0!`!H`
M``!ZM`$`&````)6T`0`'````KK0!``<```"VM`$`"P```+ZT`0`*````RK0!
M``(```#5M`$`!0```-BT`0`,````WK0!`"4```#KM`$`%0```!&U`0`6````
M)[4!``<````^M0$`$````$:U`0`0````5[4!`!0```!HM0$`#0```'VU`0`[
M````B[4!`"<```#'M0$`"0```.^U`0`'````^;4!``D````!M@$`$0````NV
M`0"7````';8!`!D```"UM@$`(P```,^V`0`&````\[8!`!$```#ZM@$`!P``
M``RW`0`&````%+<!`"8````;MP$`,@```$*W`0`P````=;<!`"0```"FMP$`
M,````,NW`0`E````_+<!`"0````BN`$`'0```$>X`0`?````9;@!``<```"%
MN`$`"0```(VX`0`)````E[@!``8```"AN`$`#P```*BX`0`.````N+@!`!``
M``#'N`$`#@```-BX`0`3````Y[@!`!$```#[N`$`$`````VY`0`.````'KD!
M``D````MN0$`$0```#>Y`0`)````2;D!``H```!3N0$`#@```%ZY`0`,````
M;;D!`!\```!ZN0$`/0```)JY`0`-````V+D!``@```#FN0$`$````.^Y`0`C
M`````+H!`#,````DN@$`)P```%BZ`0`F````@+H!`"\```"GN@$`*0```->Z
M`0`V`````;L!`"P````XNP$`%0```&6[`0`&````>[L!``X```""NP$`!@``
M`)&[`0`0````F+L!``,```"INP$`!````*V[`0`'````LKL!`!,```"ZNP$`
M%0```,Z[`0`3````Y+L!`!D```#XNP$`"@```!*\`0`.````';P!``L````L
MO`$`!P```#B\`0`%````0+P!`!````!&O`$`$@```%>\`0`,````:KP!``D`
M``!WO`$`#````(&\`0`/````CKP!`#$```">O`$`&````-"\`0`@````Z;P!
M`"(````*O0$`$P```"V]`0`+````0;T!``P```!-O0$`%````%J]`0`-````
M;[T!`$$```!]O0$`,@```+^]`0!$````\KT!`%@````WO@$`2P```)"^`0`\
M````W+X!`$X````9OP$`&P```&B_`0`&````A+\!``@```"+OP$`#````)2_
M`0`.````H;\!`!<```"POP$`"````,B_`0`(````T;\!``4```#:OP$`(@``
M`."_`0`,`````\`!``4````0P`$`/@```!;``0`J````5<`!`!````"`P`$`
M<0```)'``0`3`````\$!``D````7P0$`"@```"'!`0`-````+,$!``L````Z
MP0$`#0```$;!`0`%````5,$!``T```!:P0$`10```&C!`0`-````KL$!`!@`
M``"\P0$``@```-7!`0`&````V,$!``H```#?P0$`%P```.K!`0`3`````L(!
M`!8````6P@$`,0```"W"`0`#````7\(!``0```!CP@$`!````&C"`0`9````
M;<(!``@```"'P@$`$@```)#"`0`%````H\(!`!D```"IP@$`"````,/"`0`&
M````S,(!`!D```#3P@$`#@```.W"`0`M````_,(!``@````JPP$`"P```#/#
M`0`%````/\,!``D```!%PP$`!P```$_#`0`8````5\,!``,```!PPP$`!@``
M`'3#`0`+````>\,!``P```"'PP$`"@```)3#`0`*````G\,!`!8```"JPP$`
M#````,'#`0`7````SL,!``@```#FPP$`!P```._#`0`1````]\,!`",````)
MQ`$`4````"W$`0`V````?L0!`#H```"UQ`$`!P```/#$`0`*````^,0!``0`
M```#Q0$`"0````C%`0`(````$L4!``H````;Q0$`"0```";%`0`&````,,4!
M``T````WQ0$`!@```$7%`0`$````3,4!`#L```!1Q0$`/@```(W%`0`]````
MS,4!`"8````*Q@$`!0```#'&`0`0````-\8!``8```!(Q@$`"P```$_&`0`,
M````6\8!`!D```!HQ@$`$````(+&`0`8````D\8!``0```"LQ@$`!0```+'&
M`0`+````M\8!``4```##Q@$`"@```,G&`0`>````U,8!``0```#SQ@$`"P``
M`/C&`0`,````!,<!``H````1QP$`#@```!S'`0`/````*\<!``X````[QP$`
M"````$K'`0`)````4\<!``4```!=QP$`,P```&/'`0`S````E\<!`#P```#+
MQP$`+P````C(`0!.````.,@!`$@```"'R`$`-0```-#(`0!6````!LD!`#L`
M``!=R0$`3````)G)`0`P````YLD!`!$````7R@$`&0```"G*`0`+````0\H!
M`$,```!/R@$`+P```)/*`0`B````P\H!`"X```#FR@$`$````!7+`0`2````
M)LL!``<````YRP$`!@```$'+`0`Q````2,L!`#$```!ZRP$`.````*S+`0`*
M````Y<L!`!L```#PRP$`*0````S,`0`?````-LP!`!,```!6S`$`!@```&K,
M`0`*````<<P!``P```!\S`$`#P```(G,`0`9````F<P!`%\```"SS`$`?0``
M`!/-`0!Z````D<T!``T````,S@$`"````!K.`0`)````(\X!`!`````MS@$`
M$0```#[.`0`.````4,X!``8```!?S@$`%P```&;.`0`'````?LX!`!4```"&
MS@$`$P```)S.`0`4````L,X!`!L```#%S@$`*@```.'.`0"5````#,\!`!$`
M``"BSP$`!@```+3/`0`1````N\\!`$D```#-SP$`"@```!?0`0!#````(M`!
M``L```!FT`$`#0```'+0`0`C````@-`!`!8```"DT`$`#P```+O0`0`0````
MR]`!``T```#<T`$`%P```.K0`0`L`````M$!`"L````OT0$`*P```%O1`0`J
M````A]$!`#8```"RT0$`-0```.G1`0`<````'](!`$\````\T@$`%0```(S2
M`0`4````HM(!`!8```"WT@$`%0```,[2`0`6````Y-(!`!8```#[T@$`%0``
M`!+3`0`5````*-,!`!0````^TP$`,P```%/3`0`8````A],!`!@```"@TP$`
M.P```+G3`0`2````]=,!``@````(U`$`%````!'4`0`C````)M0!`!0```!*
MU`$`%````%_4`0`3````=-0!`!D```"(U`$`%@```*+4`0`6````N=0!`!L`
M``#0U`$`&0```.S4`0`4````!M4!`!\````;U0$`(@```#O5`0`5````7M4!
M`!4```!TU0$`%P```(K5`0`5````HM4!`!H```"XU0$`'0```-/5`0`;````
M\=4!`!@````-U@$`"````";6`0`0````+]8!`!@```!`U@$`!````%G6`0`&
M````7M8!``,```!EU@$`"P```&G6`0`)````==8!`!0```!_U@$`!@```)36
M`0`*````F]8!``8```"FU@$`!P```*W6`0`'````M=8!``8```"]U@$`!0``
M`,36`0`7````RM8!``8```#BU@$`"0```.G6`0`$````\]8!``0```#XU@$`
M"0```/W6`0`*````!]<!``D````2UP$`$````!S7`0`1````+=<!``H````_
MUP$`%0```$K7`0`%````8-<!`#4```!FUP$`#P```)S7`0`2````K-<!`!P`
M``"_UP$`#@```-S7`0`,````Z]<!``X```#XUP$`20````?8`0`&````4=@!
M``@```!8V`$`(0```&'8`0`.````@]@!`!,```"2V`$`!@```*;8`0`+````
MK=@!`&,```"YV`$`"0```!W9`0`'````)]D!``0````OV0$`#0```#39`0`7
M````0MD!``\```!:V0$`%@```&K9`0`4````@=D!`!L```"6V0$`&@```++9
M`0`(````S=D!``8```#6V0$`!@```-W9`0`=````Y-D!``<````"V@$`!0``
M``K:`0`1````$-H!``L````BV@$`!P```"[:`0`+````-MH!`!<```!"V@$`
M!0```%K:`0`'````8-H!``8```!HV@$`#0```&_:`0`*````?=H!``X```"(
MV@$`$P```)?:`0`5````J]H!`!0```#!V@$`&P```-;:`0`3````\MH!`!4`
M```&VP$`"````!S;`0`$````)=L!`!(````JVP$`%P```#W;`0`%````5=L!
M`!$```!;VP$`)0```&W;`0`4````D]L!`!8```"HVP$`$0```+_;`0`-````
MT=L!``P```#?VP$`!P```.S;`0`)````]-L!``\```#^VP$`#@````[<`0`0
M````'=P!`!`````NW`$`,````#_<`0`P````<-P!`"P```"AW`$`"0```,[<
M`0`'````V-P!``<```#@W`$`$````.C<`0`0````^=P!``,````*W0$`"```
M``[=`0`@````%]T!``@````XW0$`"````$'=`0`/````2MT!`&D```!:W0$`
M&0```,3=`0`+````WMT!``4```#JW0$`!P```/#=`0`:````^-T!`!H````3
MW@$`$P```"[>`0`)````0MX!``(```!,W@$`!````$_>`0`D````5-X!``<`
M``!YW@$`!0```('>`0`O````A]X!``H```"WW@$`!0```,+>`0`'````R-X!
M`!0```#0W@$`$````.7>`0`&````]MX!``@```#]W@$`"0````;?`0`$````
M$-\!``4````5WP$`=````!O?`0`+````D-\!``X```"<WP$`&````*O?`0`A
M````Q-\!``0```#FWP$`#````.O?`0`8````^-\!`"8````1X`$`-0```#C@
M`0`.````;N`!``H```!]X`$`'0```(C@`0`2````IN`!``L```"YX`$`"0``
M`,7@`0`9````S^`!`"@```#IX`$`*0```!+A`0`H````/.$!`"````!EX0$`
M&0```(;A`0`.````H.$!`*X```"OX0$`K````%[B`0`#````"^,!``X````/
MXP$`!P```![C`0`*````)N,!``H````QXP$`%````#SC`0`)````4>,!`%H`
M``!;XP$`'````+;C`0`.````T^,!``P```#BXP$`&P```._C`0!,````"^0!
M`!T```!8Y`$`!P```';D`0`D````?N0!`#````"CY`$`"````-3D`0`&````
MW>0!`"(```#DY`$`!0````?E`0`'````#>4!`"D````5Y0$`*````#_E`0`T
M````:.4!``@```"=Y0$`#0```*;E`0`>````M.4!`!X```#3Y0$`10```/+E
M`0!B````..8!`!@```";Y@$`+0```+3F`0`]````XN8!`!8````@YP$`%0``
M`#?G`0`"````3><!``L```!0YP$`!0```%SG`0`.````8N<!``X```!QYP$`
M!P```(#G`0`/````B.<!``8```"8YP$`"````)_G`0`.````J.<!``D```"W
MYP$`"@```,'G`0`*````S.<!`#<```#7YP$`!P````_H`0`2````%^@!`!,`
M```JZ`$`'@```#[H`0`2````7>@!``L```!PZ`$`"@```'SH`0`*````A^@!
M``L```"2Z`$`'````)[H`0`;````N^@!``D```#7Z`$`"@```.'H`0`)````
M[.@!``@```#VZ`$`'P```/_H`0`1````'^D!``\````QZ0$`"@```$'I`0`*
M````3.D!``L```!7Z0$`$0```&/I`0`%````=>D!`!D```![Z0$`-@```)7I
M`0`$````S.D!``<```#1Z0$`!0```-GI`0`%````W^D!``L```#EZ0$`&```
M`/'I`0`2````"NH!`!D````=Z@$`&P```#?J`0`B````4^H!`!8```!VZ@$`
M%P```(WJ`0`2````I>H!`!8```"XZ@$`"````,_J`0`#````V.H!``T```#<
MZ@$`#@```.KJ`0`'````^>H!``H````!ZP$`'0````SK`0`*````*NL!``X`
M```UZP$`)@```$3K`0`K````:^L!`!8```"7ZP$`"P```*[K`0`+````NNL!
M``8```#&ZP$`$````,WK`0`5````WNL!``<```#TZP$`"0```/SK`0`%````
M!NP!``<````,[`$`!@```!3L`0`$````&^P!``0````@[`$`,0```"7L`0!`
M````5^P!`#H```"8[`$`-````-/L`0`K````".T!`!0````T[0$`,P```$GM
M`0`[````?>T!`!$```"Y[0$`3````,OM`0`Z````&.X!`$L```!3[@$`2P``
M`)_N`0!1````Z^X!`!<````][P$`&0```%7O`0`7````;^\!`#T```"'[P$`
M&@```,7O`0`5````X.\!`!T```#V[P$`$P```!3P`0`:````*/`!`!0```!#
M\`$`%P```%CP`0`<````</`!`#<```"-\`$`-P```,7P`0`[````_?`!`#@`
M```Y\0$`.0```'+Q`0`V````K/$!`'4```#C\0$`(P```%GR`0`I````??(!
M``P```"G\@$`%````+3R`0`<````R?(!``P```#F\@$`%0```//R`0`4````
M"?,!`#0````>\P$`+````%/S`0`P````@/,!``L```"Q\P$`7````+WS`0!6
M````&O0!``4```!Q]`$`&0```'?T`0`6````D?0!``P```"H]`$`%````+7T
M`0`2````RO0!``@```#=]`$`"@```.;T`0`)````\?0!`!````#[]`$`"```
M``SU`0`4````%?4!`!`````J]0$`$@```#OU`0`'````3O4!`"4```!6]0$`
M(P```'SU`0`(````H/4!``0```"I]0$`$@```*[U`0`2````P?4!`!$```#4
M]0$`+P```.;U`0`"````%O8!``8````9]@$`#P```"#V`0`)````,/8!``<`
M```Z]@$`'````$+V`0`$````7_8!`#L```!D]@$`#@```*#V`0`8````K_8!
M``0```#(]@$`+P```,WV`0`7````_?8!`!D````5]P$`'P```"_W`0!>````
M3_<!`!<```"N]P$`1P```,;W`0`I````#O@!``T````X^`$`#0```$;X`0`G
M````5/@!`!0```!\^`$`$0```)'X`0`,````H_@!`!8```"P^`$`#````,?X
M`0`=````U/@!`!8```#R^`$`"`````GY`0`4````$OD!`!0````G^0$`"0``
M`#SY`0`.````1OD!`"H```!5^0$`$@```(#Y`0`9````D_D!`!@```"M^0$`
M&@```,;Y`0`K````X?D!``@````-^@$`"0```!;Z`0`9````(/H!`!$````Z
M^@$`$P```$SZ`0`2````8/H!`!D```!S^@$`$0```(WZ`0`4````G_H!`!L`
M``"T^@$`"@```-#Z`0`,````V_H!``@```#H^@$`!0```/'Z`0`A````]_H!
M``8````9^P$`#P```"#[`0`(````,/L!`!$````Y^P$`"````$O[`0`>````
M5/L!`!$```!S^P$`.0```(7[`0`8````O_L!``D```#8^P$`"@```.+[`0`B
M````[?L!``@````0_`$`'P```!G\`0`$````.?P!`!P````^_`$`"````%O\
M`0`'````9/P!`!P```!L_`$`,````(G\`0`&````NOP!`"````#!_`$`$@``
M`.+\`0`&````]?P!`!````#\_`$`$P````W]`0`$````(?T!``D````F_0$`
M"P```##]`0`'````//T!``4```!$_0$`"````$K]`0`%````4_T!``L```!9
M_0$`'P```&7]`0`^````A?T!`$P```#$_0$`)P```!'^`0`V````.?X!`"<`
M``!P_@$`50```)C^`0`G````[OX!`#(````6_P$`-P```$G_`0`W````@?\!
M`(L```"Y_P$`*````$4``@`%````;@`"``<```!T``(`"````'P``@`(````
MA0`"`!L```".``(`'0```*H``@`J````R``"`"H```#S``(`)@```!X!`@!`
M````10$"`$8```"&`0(`"0```,T!`@`7````UP$"``L```#O`0(`"````/L!
M`@`X````!`("`!8````]`@(`$````%0"`@`2````90("``@```!X`@(`$P``
M`($"`@`(````E0("``T```">`@(`%@```*P"`@`G````PP("`"@```#K`@(`
M0P```!0#`@`+````6`,"`!T```!D`P(`!0```((#`@`'````B`,"`!@```"0
M`P(`(P```*D#`@`&````S0,"``P```#4`P(`!0```.$#`@`*````YP,"``P`
M``#R`P(`#````/\#`@`+````#`0"`!H````8!`(`"@```#,$`@`*````/@0"
M``4```!)!`(`$0```$\$`@!)````800"`%T```"K!`(`%`````D%`@`/````
M'@4"`!X````N!0(`#````$T%`@`F````6@4"`!P```"!!0(`$@```)X%`@`2
M````L04"`!P```#$!0(`$P```.$%`@`-````]04"``L````#!@(`$`````\&
M`@`M````(`8"``D```!.!@(`#0```%@&`@`.````9@8"`!8```!U!@(`#```
M`(P&`@`^````F08"``@```#8!@(`*0```.$&`@`0````"P<"`!0````<!P(`
M10```#$'`@`S````=P<"`#<```"K!P(`-````.,'`@`P````&`@"`!````!)
M"`(`'````%H(`@`?````=P@"``P```"7"`(`%0```*0(`@`>````N@@"`!<`
M``#9"`(`"@```/$(`@`6````_`@"`!<````3"0(`%0```"L)`@`>````00D"
M``<```!@"0(`&@```&@)`@`<````@PD"``8```"@"0(`!@```*<)`@`2````
MK@D"``P```#!"0(`%P```,X)`@`%````Y@D"``@```#L"0(`#@```/4)`@`1
M````!`H"`!(````6"@(`$P```"D*`@`3````/0H"``<```!1"@(`!0```%D*
M`@`-````7PH"``X```!M"@(`$0```'P*`@`/````C@H"``D```">"@(`!@``
M`*@*`@`&````KPH"`"@```"V"@(`&P```-\*`@`:````^PH"``<````6"P(`
M%0```!X+`@`&````-`L"`",````["P(`(P```%\+`@`K````@PL"``L```"O
M"P(`"0```+L+`@`C````Q0L"``,```#I"P(`(````.T+`@`&````#@P"``H`
M```5#`(``@```"`,`@`,````(PP"`!4````P#`(`"P```$8,`@`9````4@P"
M`"````!L#`(`%P```(T,`@`%````I0P"``H```"K#`(`%0```+8,`@`2````
MS`P"``T```#?#`(`"0```.T,`@`.````]PP"``P````&#0(`%P```!,-`@`7
M````*PT"`%@```!##0(`'0```)P-`@`T````N@T"`!0```#O#0(`#`````0.
M`@`&````$0X"`!4````8#@(`&@```"X.`@`=````20X"`!T```!G#@(`!0``
M`(4.`@`-````BPX"``<```"9#@(`$0```*$.`@`/````LPX"`!<```###@(`
M(````-L.`@`8````_`X"`!`````5#P(`(@```"8/`@`.````20\"`"8```!8
M#P(`$````'\/`@`0````D`\"`!0```"A#P(`D0```+8/`@`B````2!`"`!P`
M``!K$`(`,0```(@0`@`@````NA`"`!H```#;$`(`+````/80`@`:````(Q$"
M`",````^$0(`'P```&(1`@`9````@A$"``\```"<$0(`$0```*P1`@`'````
MOA$"``@```#&$0(`"0```,\1`@`6````V1$"``P```#P$0(`*@```/T1`@`2
M````*!("`!8````[$@(`"0```%(2`@`,````7!("`'L```!I$@(`5````.42
M`@!%````.A,"`'````"`$P(`,0```/$3`@`-````(Q0"`"4````Q%`(`+```
M`%<4`@`*````A!0"``<```"/%`(`%0```)<4`@!"````K10"``8```#P%`(`
M%P```/<4`@`9````#Q4"`%0````I%0(`,````'X5`@`B````KQ4"`!(```#2
M%0(`)0```.45`@`J````"Q8"`"\````V%@(`*0```&86`@`O````D!8"`"4`
M``#`%@(`%0```.86`@`'````_!8"``P````$%P(`#@```!$7`@`7````(!<"
M``L````X%P(`/0```$07`@`,````@A<"``P```"/%P(`"````)P7`@`3````
MI1<"`$T```"Y%P(`"`````<8`@`%````$!@"`!T````6&`(`"````#08`@`)
M````/1@"``8```!'&`(`#0```$X8`@`-````7!@"`!(```!J&`(`%````'T8
M`@`,````DA@"`!@```"?&`(`#0```+@8`@`(````QA@"`!$```#/&`(`'@``
M`.$8`@`0`````!D"``D````1&0(`&@```!L9`@`L````-AD"`!,```!C&0(`
M+0```'<9`@`M````I1D"``T```#3&0(`!P```.$9`@`(````Z1D"``<```#R
M&0(`!````/H9`@`*````_QD"`!4````*&@(`#````"`:`@`-````+1H"``P`
M```[&@(`!0```$@:`@`)````3AH"``@```!8&@(`"0```&$:`@`)````:QH"
M`!@```!U&@(`!@```(X:`@`X````E1H"``X```#.&@(`!@```-T:`@`/````
MY!H"``P```#T&@(`(`````$;`@`*````(AL"``(````M&P(`)0```#`;`@`C
M````5AL"``<```!Z&P(`"````((;`@`*````BQL"`(H```"6&P(`#````"$<
M`@`&````+AP"`",````U'`(`-````%D<`@`@````CAP"`"````"O'`(`5P``
M`-`<`@`Q````*!T"`#0```!:'0(`(P```(\=`@`@````LQT"``4```#4'0(`
M#P```-H=`@`-````ZAT"``\```#X'0(`!@````@>`@`-````#QX"`!,````=
M'@(`#P```#$>`@`/````01X"`!$```!1'@(`#````&,>`@`'````<!X"``<`
M``!X'@(`"````(`>`@`6````B1X"``D```"@'@(`"````*H>`@`'````LQX"
M`!P```"['@(`!@```-@>`@`=````WQX"`!D```#]'@(`"````!<?`@`3````
M(!\"``@````T'P(`#0```#T?`@`)````2Q\"`!4```!5'P(`!P```&L?`@`5
M````<Q\"``8```")'P(`&P```)`?`@`-````K!\"`!P```"Z'P(`!0```-<?
M`@`(````W1\"``T```#F'P(`'P```/0?`@`*````%"`"``P````?(`(`*0``
M`"P@`@`<````5B`"`!(```!S(`(`!````(8@`@`(````BR`"``L```"4(`(`
M"0```*`@`@`"````JB`"`!8```"M(`(`"````,0@`@`F````S2`"`"8```#T
M(`(`/@```!LA`@`O````6B$"`#0```"*(0(`.@```+\A`@`\````^B$"`#D`
M```W(@(`;P```'$B`@`)````X2("`&P```#K(@(`.P```%@C`@!3````E","
M`'(```#H(P(`*0```%LD`@`6````A20"`$<```"<)`(`+P```.0D`@`Q````
M%"4"`#0```!&)0(`'P```'LE`@`^````FR4"`.@!``#:)0(`(@```,,G`@`)
M````YB<"`$D```#P)P(`J````#HH`@`K````XR@"`#4````/*0(`0P```$4I
M`@!V````B2D"`$@`````*@(`0@```$DJ`@`4````C"H"``H```"A*@(`/0``
M`*PJ`@`?````ZBH"`"(````**P(`,````"TK`@`J````7BL"`"D```")*P(`
M4````+,K`@`2````!"P"``@````7+`(`2````"`L`@`W````:2P"`"H```"A
M+`(`)P```,PL`@`F````]"P"`"L````;+0(`:````$<M`@!#````L"T"`$8`
M``#T+0(`0@```#LN`@`[````?BX"`%````"Z+@(`;0````LO`@!8````>2\"
M`#<```#2+P(`.0````HP`@!!````1#`"`#T```"&,`(`0````,0P`@!F````
M!3$"`'@```!L,0(`<````.4Q`@!P````5C("`#@```#',@(`+@`````S`@`N
M````+S,"`#````!>,P(`@P```(\S`@!X````$S0"`'\```",-`(`TP````PU
M`@`:````X#4"`"P```#[-0(`-@```"@V`@`K````7S8"`%@```"+-@(`+0``
M`.0V`@!7````$C<"`"H```!J-P(`#````)4W`@"^````HC<"`%T```!A.`(`
M(P```+\X`@`X````XS@"`"<````<.0(`(````$0Y`@!#````93D"``8```"I
M.0(`!P```+`Y`@`$````N#D"``T```"].0(`"@```,LY`@`+````UCD"``L`
M``#B.0(`!0```.XY`@`0````]#D"``(````%.@(`7P````@Z`@`#````:#H"
M``4```!L.@(`'````'(Z`@`$````CSH"``<```"4.@(`!@```)PZ`@`%````
MHSH"`#H```"I.@(`!````.0Z`@`7````Z3H"``T````!.P(`$P````\[`@`0
M````(SL"``(````T.P(`"````#<[`@`&````0#L"`!4```!'.P(`#````%T[
M`@`7````:CL"``8```"".P(`#@```(D[`@`*````F#L"``@```"C.P(`+@``
M`*P[`@`(````VSL"``8```#D.P(`!P```.L[`@`X````\SL"`%P````L/`(`
M2````(D\`@!)````TCP"`#(````</0(`,````$\]`@`S````@#T"`#@```"T
M/0(`+P```.T]`@`J````'3X"`#8```!(/@(`,0```'\^`@`K````L3X"`#8`
M``#=/@(`+0```!0_`@`M````0C\"`$(```!P/P(`)````+,_`@`_````V#\"
M`#H````80`(`,0```%-``@`U````A4`"`#````"[0`(`*P```.Q``@`V````
M&$$"`#(```!/00(`-@```()!`@`U````N4$"`"L```#O00(`+0```!M"`@`P
M````24("`#L```!Z0@(`*P```+9"`@`H````XD("`$8````+0P(`20```%)#
M`@`G````G$,"`#0```#$0P(`3P```/E#`@`R````240"`#8```!\1`(`,0``
M`+-$`@`R````Y40"`"P````810(`*0```$5%`@`N````;T4"`#,```">10(`
M1@```-)%`@`O````&48"`&````!)1@(`#0```*I&`@`<````N$8"`"(```#5
M1@(`00```/A&`@`E````.D<"`!````!@1P(`#P```'%'`@`<````@4<"`!8`
M``">1P(`$@```+5'`@`D````R$<"``D```#M1P(`"0```/='`@`E`````4@"
M`"@````G2`(`)P```%!(`@`G````>$@"`"0```"@2`(`"0```,5(`@`#`0``
MST@"`!(```#320(`'0```.9)`@`.````!$H"`!`````32@(`%@```"1*`@`8
M````.TH"`!\```!42@(`"0```'1*`@!.````?DH"`!H```#-2@(`$P```.A*
M`@`'````_$H"`!4````$2P(`#````!I+`@!9````)TL"``@```"!2P(`*0``
M`(I+`@`2````M$L"`!4```#'2P(`%0```-U+`@`^````\TL"`!P````R3`(`
M#````$],`@`H````7$P"``T```"%3`(`#@```)-,`@`5````HDP"``H```"X
M3`(`)````,-,`@`+````Z$P"`"````#T3`(`30```!5-`@`9````8TT"``H`
M``!]30(`'0```(A-`@`M````IDT"``4```#430(`)P```-I-`@`'`````DX"
M``<````*3@(`"0```!).`@!,````'$X"``<```!I3@(`$0```'%.`@`+````
M@TX"`!<```"/3@(`"0```*=.`@`)````L4X"``<```"[3@(`%@```,-.`@`+
M````VDX"`!X```#F3@(`#P````5/`@`8````%4\"`!P````N3P(`!0```$M/
M`@`'````44\"`!D```!93P(`!P```'-/`@`Q````>T\"``T```"M3P(`$0``
M`+M/`@`'````S4\"``(```#53P(`$````-A/`@`/````Z4\"``L```#Y3P(`
M`P````50`@`'````"5`"``L````14`(`"@```!U0`@`1````*%`"``X````Z
M4`(`&P```$E0`@`<````95`"``H```""4`(`&P```(U0`@`V````J5`"`"0`
M``#@4`(`*@````51`@`7````,%$"``T```!(40(`/@```%91`@`,````E5$"
M`!<```"B40(`0P```+I1`@`9````_E$"``8````84@(`%P```!]2`@!`````
M-U("``X```!X4@(`!P```(=2`@`'````CU("``0```"74@(`!````)Q2`@`)
M````H5("`!X```"K4@(`!0```,I2`@`&````T%("``@```#74@(`#````.!2
M`@`&````[5("`!0```#T4@(`%`````E3`@!`````'E,"`#0```!?4P(`+@``
M`)13`@`*````PU,"``P```#.4P(`#````-M3`@`,````Z%,"``T```#U4P(`
M'@````-4`@`A````(E0"`"\```!$5`(`*0```'14`@`4````GE0"``(```"S
M5`(`!````+94`@`,````NU0"``@```#(5`(`!0```-%4`@`"````UU0"`!$`
M``#:5`(`80```.Q4`@`N````3E4"`"X```!]50(`.@```*Q5`@`:````YU4"
M`#H````"5@(`+P```#U6`@!>````;58"`!8```#,5@(`)@```.-6`@!]````
M"E<"`"D```"(5P(`5@```+)7`@`I````"5@"`$`````S6`(`/@```'18`@`U
M````LU@"`$P```#I6`(`-0```#99`@!E````;%D"`#<```#260(`.0````I:
M`@`?````1%H"`"X```!D6@(`,@```)-:`@!`````QEH"`!(````'6P(`$@``
M`!I;`@`,````+5L"`(D````Z6P(`"````,1;`@#&````S5L"`'$```"47`(`
MBP````9=`@`M````DET"`&4```#`70(`%P```"9>`@`F````/EX"`!<```!E
M7@(`%P```'U>`@`:````E5X"`"0```"P7@(`0P```-5>`@`F````&5\"`"``
M``!`7P(`:P```&%?`@`<````S5\"``P```#J7P(`"P```/=?`@`%`````V`"
M``8````)8`(`"````!!@`@`%````&6`"`!8````?8`(`#@```#9@`@`0````
M16`"`!4```!68`(`(````&Q@`@`1````C6`"`"\```"?8`(`.````,]@`@`/
M````"&$"`!`````880(`#0```"EA`@`)````-V$"``X```!!80(`&P```%!A
M`@`O````;&$"``X```"<80(`"````*MA`@`&````M&$"`!4```"[80(`,0``
M`-%A`@`)`````V("``D````-8@(`$P```!=B`@`H````*V("`!4```!48@(`
M#@```&IB`@`'````>6("`!(```"!8@(`!P```)1B`@`.````G&("`!D```"K
M8@(`"0```,5B`@`,````SV("``T```#<8@(`!0```.IB`@`*````\&("`!(`
M``#[8@(``P````YC`@`(````$F,"``D````;8P(`*0```"5C`@`B````3V,"
M`!````!R8P(`)0```(-C`@`4````J6,"`!L```"^8P(`$0```-IC`@`F````
M[&,"``H````39`(`%@```!YD`@`'````-60"``0````]9`(`!0```$)D`@`5
M````2&0"``0```!>9`(``@```&-D`@`"````9F0"`!(```!I9`(`!@```'QD
M`@`'````@V0"``8```"+9`(`$@```))D`@`7````I60"``<```"]9`(`(@``
M`,5D`@`*````Z&0"`#H```#S9`(``@```"YE`@`$````,64"`!,````V90(`
M&````$IE`@`*````8V4"``0```!N90(`!P```'-E`@`2````>V4"``4```".
M90(`(@```)1E`@`9````MV4"``@```#190(`%P```-IE`@`5````\F4"`!,`
M```(9@(``@```!QF`@`.````'V8"``P````N9@(`#0```#MF`@`6````268"
M`#H```!@9@(`!P```)MF`@`)````HV8"`!$```"M9@(`!0```+]F`@`"````
MQ68"``L```#(9@(``0```.D$``#!!```:P```(``````````4P0`````````
M````2P0```````!S`````````/0&``!,`0``=P0```D&``"'`P``XP<``$``
M````````)@4``%P#``#6`````@````````!.`P```````.\%```V`P``D`4`
M``````"V`0``"P8``((#``!X`@``E0,``#<"````````W@8``-@!``!^`0``
MKP4``-,#````````$0$``*H#``#&````.`8``/X"``"Y````/0<``(T!```:
M"`````````````!\`@``$P,``"T````?`@``700``````````````````/0%
M`````````````,0$``"U!P``:0,```````"M!```H@(``$$#``!6`0``)08`
M`*8$``!P!````````.T#``#O!@```````,P$``"X`0````````````!$!0``
M``````````"*`@``+`$``#,(````````E0$``&P```#$!@``E`(``.L$````
M````_00``(<```!9!0``#@4``)X%`````````````$@"````````````````
M``!4`@```@,``-@"````````!`,``+4&``"Q!0``E`,```T$```1!@``TP<`
M`/@#``!C!@``9P,``#0&````````3`(``+,%```4````000```````#4!```
M4@,``!8"``"!````@`$``),&```Y"````````+(```````````8```````!W
M!P``"`4``-H````R`0```````'T"``#B!P``GP0```````#"!P``J`(`````
M``!]````KP`````````$!0`````````````%`P``/0(``%``````````Y@8`
M```````0!```````````````````,08``)T&``````````@``/0$````````
MX`0``!8&``#R`@``B`(``,L'`````````````+@'````````0`8```````!-
M!0```````!,(````````80<``-`&````````/`8``$`'````````G@0``.4`
M``#O`P`````````````*!````````!L%```M`P``.P$``+L$``"&`0``N@(`
M`)L%```]````/0$``#8````I"`````````````#L`````````!\!````````
M@`(``,T!````````Q0(````````Q"```Z@(```````"6!0``!0$``'T%``#]
M!P``-`<``&8```#C!0```````/(!``!Y`@``R0```-D&``!H!@``)@8``"<&
M````````U@$```````#(`0``RP$```````!T`0``Z08``'4'````````````
M``<%````````8P0``*<"```B!0``&08``&T&```Y!@``?````#,#````````
M`````',$``"5!@``]P,``%,#``#\!P```````'L'``!V!P``2`8``%8$``!&
M!0``408``"P#````````<00```````!)`0``H@<```````!\`P```````&X#
M`````````````$,%````````^P```,(!``"\!`````````````#%!@``````
M`&P'``"^`@``40$``.<'``#'`0``;P$``+L"``!$`@```````*<%``"D!@``
M`````)X`````````<P$```````!>!0``UP8``%P!````````BP,```````!.
M!@``.`<``+H$``!Z!@``TP8``#\"`````````````'X$````````0P0`````
M``"^`P``?P(``%<!````````10```'<"``#Y!````````+L'```\!```````
M`/X&``"X!0``/@,``/(%``!_!@``=````"D#```8`@```````%`&```+!0``
M;04``)D%```[!P``8`,``%`%```8!P``/@$``"\````E!0``W0<``+``````
M`````````````````````````&@$```<!@``:@8`````````````H@```-0&
M```<`0```````$H"```C!```RP(``'<&````````%08```P!``"J!```/@0`
M`(\#``!-"```D`,``(P#``#T!P``>P0``%\!````````W0```%@"````````
MDP0``'`&``!K`@```````-D#``!'!0``#@<```````#L`P```````'<!``"@
M!@``B0<````'````````6@<``*D&````````>0<```````"6````%P$`````
M````````M04``"0(``"_!```=`4``-\#``#B`@``^P(```X&````````?`4`
M``````!#`0``B@0``$X!````````>````*,"``!*`````````,8!``#`!```
M``````````#F`0``S@0```````!*!P``JP0```````!2!@``*`<``"H&````
M````/`,``,4$``#I`P``\P0``.0%``"<!`````````````![!@``Z`$``,H'
M``!Z!```&0$``&$%``!D!0``<`,````````@`@``A0,``+,$``"<!P``````
M`*P'````````4`<``!H%````````[@$```````#Q````S@(``%,'````````
M/`<``"L$``"F!0```````)L"``"0!@``6P<``-@$````````S0<``&(#``#]
M!@````````````#3`0```````"D$```#!P``I`(``/,"``!Y````````````
M```/!0``ZP8``&L$``"A````U08``(<!```Z!```Y0<``-$```#R!@``````
M`&,````8`0````````````!=!@``$@8``+T!``!4`P``;00``,$&``!:`P``
M`````!T!``"C!P``S````-<#``!@!P```````,\```"-!P``A`4``*,````=
M!@``<@0``/8%```3`@``A`$```````!/!```>@<````````T!```R`0`````
M``!F`0``XP```!<'``!/"```B@<``/<```!3!@``\@0``"T%```"!```"P``
M`.@````A!P```````"T&```^`@``CP8``$8&``#"!@``2P@```````#X!```
M&P<``*(#``"S!P``F0````````!:`0``$0@``"\'``#[`P``J@<``(8'```0
M!@``#`8``!P'``!%!P``Y@<``)X&```:`P```````)(!````````)@0``!,$
M``````````````````#;`0``<08``/,'``!>````^@```.`%``#M`0``Q@(`
M`&4"``!N!```QP0``````````````````),#``"F`P``@0,``*<'```5`P``
M(@8````````8!0``YP0``)@```"-!0``@@4``&,!```P````9P4``&P&``"?
M````F`8``&D%``")`0```````/D'``"E!P``'`@``(8#``!6!P``Z@8`````
M````````_`````````#W!```^P0``(4&``!?!`````````````#A`P``)0<`
M`#4(``!V`P``?08``$$(``")!```?`$``$0'````````A`,``%P%````````
MU0(```````#$!P```````%T"``!B!@``20,````````-````]`$```````!C
M`P``1`0``!D'``!5`0``?0<`````````````M@(````````4!0``9@<``'4"
M```L!0```````!H'``"H`0``(04```````";!```=0,``/<&```9`@``C0``
M`/\!```H`````````/\$``"%!```)`8````````N`P``&00```````"]!P``
MA0(``#@$````````N@4``!8%````````;0```*T&``#\`0``%04```@'````
M`0````````D"``"C`0``,@(```````!)!@``(`,```````!/`P``=@```*(!
M``!'`0``?@,`````````````]@8``#`(``#%`P``+P0``%,!``"D!P``;P(`
M`.T$``!;`P```````)T#``"A`@``'@@``#,'``!?````J`0```````#Z`P``
M+00```````````````````````"V````LP````````".!0``!0`````````O
M"```U`$```````"8!```QP```(<%``#_!@``R`(`````````````````````
M```_`0```````+0```!S`P``>P$``-4'``"(````G@<``!0&````````J@(`
M`$X(``"+!@````````````"Y!```NP4``%X#``#`!0``3P8``)8&````````
MQ`(``'(#```D!0````````````!-!```]0```-P#``"@`P``K`$``%@#````
M````*`8``+D#```\!0```````'(`````````#@(`````````````1P<``(H!
M``!J```````````````,!0``:00``(<&```:!@``$````&`&``"8!P``_`8`
M`%P'````````)0@``*L"``!%!```U0,``)8'``"U`P```````-H%``!9`@``
M6P(``$L&`````````````)<'``"8`P```````$T"`````````````+X&``#=
M!@``7P(``!\$`````````````-X$`````@``J04``#<#``#0!```T````,<#
M``!-!P`````````````6````#P@``",%````````904``,,%````````^08`
M`%4$``#>!0``TP0``(\'`````````````',&````````6`$``$\!````````
MLP,``/<!``!K!@```````(X!``!D`@``3@0````````X`P``,`$```````#>
M`@``DP$``#$#```6!```F@,```````!M`@``O````/`#``!`!```7P8``)H"
M``#A!0``````````````````8`$``'0'```````````````````3!@``%P8`
M`.P"````````5````````````````P`````````%!P``B`<```````#_`@``
MBP`````````)`P``RP````````#B`P```````*<&```6"```KP$``-P$``"5
M!`````````````#\`@``F0,``#<&``#N!```X0<```````#[`0``3`4``%`!
M``#Y````$@0``&0&````````?P,``,,"``!C`@`````````````]`P``S`(`
M``````!G!```00<``%D#``!2````0@@``.L'```2````R`,``/4!```8!@``
M#P```/$&``!N!@``L`(`````````````KP,``,P#````````(@$``&4!``!5
M!@``*P(``&4#````````>@$```````!=!0``/08```````#?!P``_P4``.($
M```:`@``4`0``/4%```H!```2`4``$H%````````J0<```````#@`0``*P``
M`(($````````J`<```````!2`0``<0,``$@#```X!0``*P4``*D#``#Z!0``
M0@0`````````````C00``#D$``"Z!P```````!D(``#%!0``60$``&D'``".
M`P``=04```````!7!@``!`0````````_!@``]`,```(!`````````````"((
M``"X!````````,<%``"^`0``W`8``-0#``#4!P``#`,```$(``"B!@``````
M`.X%```?````6P4``(0"````````\`(``(X&``"W!0```````-@'``#W!P``
M+P(``*L#``#/!0``Q@<``+`#````````608``(P```"U``````````````#*
M`P``E@$``!\#``!H`0```P4``'<```"+`0```````-0"```-!P````````4(
M``#V!```Y`(``"\&`````````````&(%````````/P0`````````````#`@`
M`+("`````````````.P%``#A````P0$```````#G`0``Z`<``!(!``"2!```
M#P8``#4!``!8!P```````)H```#Z!P``<@8````````5`0``CP4````````F
M`0```````(`$```B`@```````$$```"``P``!08``(L"`````````````-<`
M``"(!```M`0``-4$``#)`@``J`4``,\&````````L@0`````````````O`4`
M`+L!`````````````,4'``#&!```)P$```````":!0``)P,``%T#````````
M!P````````#%````T@(``!`!````````F`$``*T%``!H````H`(``.(!``!=
M!P``3`@``&("``"]!@``-````.<&````````,00```````!_!0``*@0```<&
M````````$`(`````````````*P<``.\!```$`0``-@@```````#\!```K`8`
M`````````````````'@$```Q``````````P````Y!0```````.`#``!2!P``
M7@$``"0"`````````````'8"`````````08``+\"````````B`8``+(%````
M````0`,``+`$``#E`@``+`(```````!%"`````````````":!P``*04``*8"
M``#(!@`````````````<!0``0@4```````!F!```G0(``/$"``".`@``@@8`
M``P"``#``@``'0,``.P$```P!P````````0&````````GP8``,H````A!@``
MBP0``*<```#2!0``L0,``)P#````````9@,`````````````+@8```$!````
M````2@8```````"K`0```````#D```!'`@```````,`#``"<!0``RP4`````
M```I`@``_04``$\```!K`P``I04```$%``!/!P``3@(`````````````J@4`
M``````#E!```0@(``````````````````&<```#^`0```````(`'``"^!P``
MGP<``.$"``!$!@``'@(``!X$``"<`@``P0,``-T#```<`P``TP`````````[
M!```W@<``,,#``#`````?@```)L#``":!```0P@``!8'``!Q!0``````````
M````````F`(`````````````L0<```D$````````5P0``,\"``!,!P``'P<`
M`(4`````````_P````\$`````````````,$'``#"`P``M`8``%4'``#>`0``
MEP```*X"``#H`@``'@$``"0'````````CP$`````````````-P4``)T!``"V
M!```=@0``*0%```5````2@,``,X#```D`0``"@$``,$%```O`0``+0(``-T$
M`````````````)\!```?!0``,P$``$<#``!`"```\@,``&`"``"Z`P``?@<`
M`*$%```8!`````````````!5`@``>P,``,H"```4!P``+`@````````$"```
M`````+$&````````"`,``$T&``"1`@``KP(```@`````````>`$``)<%``#`
M!@``U`4``((```"\`0``.P@```T(``#R````````````````````10,``!0!
M``"^!0``N`8``&@%``!N````(@```",!``#V`````````$D```!"!@``HP4`
M`%8&```)````(P8``$0!````````H`<``-D"``!9`````````$$%``"_!0``
MW`(``#@```"6`@``G00``+`%````````]@(``#X```#X`0``H````/T"``!Y
M!@```````-@#``#?`@```````#$'```(!@``X`8```````"W!````````"X!
M````````&04``,D%``";!@```````"D!``!Q````=`,``(8````G!P``T`<`
M`+,&```G````\P```'0&``#N!P``K0```-($``"W````SP,``.L"```K`P``
M`````%8"```&!````````*X'``!4!P``G@$`````````````'`(``"@(``"Z
M!@```````'4$````````7P4````````]!0``S`<``%X"``"&`@```````,H%
M``!H`@``(0(``*4#```)!P``D@8``)<#`````````````)P!``"Z`0``R0<`
M`!4"````````E````(H%``!,!@``S@```)L```!X!0``#P$``(P!````````
MY04``*X%``"W`0``800``.8%``#9!P``Z0$``,T#``#I`@``OP$``#L````0
M!0``D0,``*H`````````PP0``#D#``!O!0``,P0``#0(``"]`P``0`(``(,!
M```Z!P`````````````*````W@,```````!4!0``C@0``-X`````````^0(`
M`-<$``#)`P``:@0``(8%````````T`4``)0$````````&P(``)T'``!3!0``
MR08``#0#``".`````````)$'`````````````#H```!0`@``;0,````````[
M!0``]0<``$P#``"E`@``S@4``/D!``"4!P``]`````````"I`0``I0```!$`
M``#+!@``L@<``*@```#'!P````````````"C!@```````*X```!R!P``.P8`
M``("``"N!@``T00``$@`````````-04```````!Z````%@$``&$#````````
M>P```%4````,!P``T0<``'D$````````-`$`````````````UP(``$@$``!:
M!0``R`<``"L!```V!P``Z0```-4````7`@``#0$```````!B`0``O`,`````
M``#R!P``8@0``(0$``"`!0``I`$``-L&```4`P```````#4$``"@!0``Z0<`
M`)`"``#O`@```````$@!``````````````````````````````````"$!@``
M\`0``/<"```````````````$``#X!@``V04``.T%``#J!````P$``&X!```Q
M!0``M`,``+L#`````````````/$!````````^`<``-L#```F`P``DP``````
M```#`@```````,P&```C````F@$``(@%`````````````/@%```@"```I`,`
M`,P%``!1!0``[`$``(,%``")`P```````)0%```P!```LP$``-(````E`0``
MCP``````````````<`4``!8#``#!`@``UP4``&@#``!S!0``N08``"('```+
M!P``8````$T````.````*P@````````=!0```````!T```"5!P``7@0``+4!
M```D!```!@```&4`````````;`$``"@#``"#!@``````````````````\`4`
M`*L'``#<!0``0@,``%,"```P`P``/@4``!L(``#5`0``\P4``&P$``#=`@``
M``````````"1`````````-(!``"#!```1@````('``!:!@``70$``.<`````
M````(````"$(``"!`0``^`(``*\'```1!0``7````-L%````````Q@8```<!
M````````U@8``$('``#]`P``M@8``*D"````````^@(``(('``!O!```W`<`
M`"H`````````IP,```<'```+`P``O`<``/<%```T!0``/00``+<'``#\`P``
M#04``)<"``#D`P```````&L%``#S`0``````````````````Y08``/$%````
M``````````L"````````K0(``&`%````````E@0``.(&``!8!0``````````
M````````H@4```8%````````]0(``)L'```N!0``'@8``,4!```@!P``00$`
M`&4&```2`P``V0$``&\'``#_!P``;0<``/$$``#M!@``#P,``$,"``#C`P``
MT@8``-D$```%!```+@```"4#``!^!@``J@$```H#```(!```=0$``$@(``!W
M`P``L00````````M`0``!@<```````"H!@```@@``,D$``#-!@``[P0``%0!
M````````IP0``-<!``#P!@``@08`````````````K0,``$8!``#^!```````
M`%8`````````9@4``"4`````````Z@<``/`!``#-!````````",#``"9!@``
M`````)0!```!`P``9`<```````"E!@````````<#````````<`(``.H!```A
M`0``D@,```````!;````,P8``&X%``#+!```+`<``.4!``#F!```C`8``$L%
M```S`@````````````#D!```XP$``*$$``"!!```>`<``-\%```'`@``9`$`
M````````````@@$``-\&`````````````+\```!)!0``T04``/D#``#,`0``
M&`,``/H&`````````````-,"``!&`@``VP<``(\$```"!0``4P```"(#``#(
M````<````.4#```W`0``\P8```````#Q`P````````\"``";`0``Y`$``-$&
M```O!0``-P0``-<'``#?````$P<``(4!``"1`0``4`@``!`#``!Z`P``L0``
M`#(#`````````````+`!``#D`````````,0#``!D`P```````*@#``"1!0``
MG@(``)<!```^!P```````!4$``#6!0``$@<``(D%```#"```@P,```````#U
M!@```````"@%``!_`0``````````````````#08``$8'````````B`$``#\'
M```4`@``````````````````-P<``.\`````````L0(``-\$```;````108`
M`&X"```1`P``]`(``+D!``"7!````````%($```2`@``[@8```````!O````
M.`$``,0!`````````````#D"``"5````200``&<"``!J!P``^@$```````",
M!```L0$``.L#````````N`(``#\(``"'!```#0,``#\%``!R!0``MP8`````
M```Z!0``;0$```````#O!P```````$X%``"L````,@@````````A````````
M`&L'``!0`P``:`<``-D```#J!0``Y@```)P```!Y!0``"0$``.````")!@``
M'@4``"H#``#(!0```````&H%``!+`@``7`0``!<%``!Q`@``GP(``"`&``"0
M````!P@``'H%````````M`$``*P#`````````````,,'````````H@0``*$&
M``#*`0```````#X(````````^P4```````!*"```6@```$,`````````````
M````````````U````*L&````````H0<``#L"``"*!@``+`8```T"```F!P``
M"P@```````#.!P``,0$``#$"``!B!P```````-L"``"@`0``&P$``)(`````
M````)P@``&<&````````@`8``%T```"N`P``10(```````#Y!0``K`(``"P`
M````````:0$``$8(``"$````,`4``,`!``!^`@``2@0``.`"``"X`P``(P@`
M`"<$``!6`P``I@<``+D%``!U!@``V@(```````#H`P``"@8``#H&``"M`0``
M`````,`'```=!P``T`(``-$!``!1!```B`,``#\```#6!P``*@@`````````
M`````````+0'``#:!@``Q@,```@"```R!P```````,(```"$!P``I00``!L$
M``"9!```9P$````````K!@``U@,```````````````````````#A!```````
M`&0`````````N0<``($"```V!```V@0``%@```"O!```Q`4``)D"``!\!P``
MH0$``,T"``!"`0``X0$``&,%````````;`,``*X$```Y!P``I@8``$4!``"I
M!``````````````<````D`<``%D$```M"```8`0``&P%```?!@``%P@`````
M``"\!@``3@```.@&```&!@``F@8``.`'``!J`@``9@(`````````````````
M`-H!````````5@4``$<```!+`0``K0<``/T!``!U````X@4``#8%````````
M,@0``%<"````````40,``'@#`````````````'\'`````````````)`$````
M````C`(``'T!``"T`@``````````````````40(``+(!```T`@``L@8`````
M```,!```+@@```````!&!```>0,``)("``!T!```SP0``(P'```)"```;@<`
M``````"!!P``OP8``$0#``#M`@``'@`````````$`@``[0`````````)!0``
M`````````````````````%0$``#N````K`0```````#V!P``&0,```8(```%
M!0``-0,``*\&```\`0``)@@``.T'``"/`@``$`<``/X'``!E!```0@```'T#
M``!$"````````.P'```&`0``K@$``)@%``"K!0````````H%``"+!P``"P0`
M`.,"`````````````,$````U`@```````-$"````````O04``*<!````````
M-08```````!I!@``B0(````#``"Y`@``YP4``.<#``#K!0``'0@``!D`````
M````_P,````````5!P``6P0```H(``!7!P``7P,``%X'``"[!@``E`8``#D!
M``!$````40@``','```;!@``!`````````#H!```30,``&<'````````QP(`
M`.L!``!9!P``F0$``"X"```X`@``@04```````"#`````````$X'````````
M`````,($``#.!@``A@0``$P```#H!0``'@<``,(%``!+`````````+\'``!:
M!```$@@``"0#```W`````````,8%````````;P8``/`'``!1!P``L`<`````
M`````````````/``````````[@(``&H#````````80``````````````````
M`'H"```H`@``B0```#,```![!0```````!H$````````%P```/X%``#3!0``
M*`$``"P$`````````````````````````````!P$``!P`0```````!T$``#C
M!@``PP8``-L$````````&`@``.$&````````5P,``,\!`````````00``.L`
M```.`P```````/T```![`@``A04``-(#```X"```(00```````#S`P``5`8`
M`#H#````````AP<``'\```",!0```````)X#``!&`P``=@8``*8````[`P``
MV@<``"8```!8!@``WP$``$D'`````````````.8"```.!```N````$D(```J
M`@``?P0``.H````I!P```````#T(````````-@8```````"F`0``!P0`````
M``!2`@```````'P$```#`P``+@<``$D"```R````(P(``!,```#*!```808`
M`````````````0(``(T#````````"`$``,<&```."```D00``!H```!%!0``
MOP,```````"W`P``7P<``````````````````)4"``#.`0``!@(``-@&````
M````U@0``(H```#5!0``8P<```````!I`@``$P$``!H!``"2!P``+@0`````
M``"3!P````````````"K````O`(``"<"````````N@```*0```!R`@``````
M`(8&``!D!````````$,&``#[!@``7@8``$\%````````?@4`````````````
M`````+8#``#+`P``1P0``"`%``#2!P``%`0``&$!``!R`0```````&L!``#0
M`P````````````!,!````````$$"````````7`8``%H"``"'`@``````````
M``"^````^````+,"``!I````PP$``/8!``!-`0``0`$``,,````W"```GP,`
M`!,%``#<``````````````!W!0``$0(```(&``"7!@``_`4```````"L!0``
M`````!$'``#)`0``O0(````````A`P```````'$'``#N`P``SP<```````!]
M!```-@$```4"```P`@```````"D&``!O`P``90<``.,$```8````````````
M``"9!P```````'@&````````W`$``)(%```!!P``@P(``/8#```$!P``M@4`
M`+`&``````````````````!5`P``2P,````%``#D!P``^@0``%<```!B````
M`````-H#``!/`@``,@4``"0`````````O@0``"T'``"]````2P<````````&
M`P``*0```),%````````$@4`````````````C0(``#H"```7!```*@4``!$$
M``"J!@``%`@```H'```=`@``O00``/X`````````-@(``.P&``"[````C08`
M`%<%``"W`@```````/4#```/!P``#@$``-T!``#*!@``2@$```````"R`P``
MZ04```````!;`0``.@$``,("```O`P``80(``#`&``#B````G04``#H(````
M````<0$``````````````````#,%``"U`@````````````!2!0``*@<``-L`
M``"5!0``(`0``*4!``"+!0````````H"``#J`P```````"4$``"#!P``````
M``,&``"T!0``@@(``-`!``"C`P````````,$````````*@$``,0```"3`@``
M2`<``'8!``#G`@``$`@``!4(``"?!0``%P,``,T%``!8!```C@<```````"A
M`P``U@(``*D````+`0``]00``&H!``!`!0``)0(``)P&```_`P``)P4`````
M``!!!@``I`0``#(&``"*`P``H`0``$<&``!\!@``_@,``-@`````````````
M`#X&````````=`(``*,$```C!P``````````````````/````&P"``!<`@``
M0P<``'D!````````Y@,``'8%````````\0<``#4```!F!@``'@,`````````
M````E@,`````````````6P8``$,#```("```M00`````````````````````
M``#=!0``A0<```````#1`P``M@<``.0&``!'"````````,T`````````````
M`'`'```F`@``^P<``',"````````-0<``!L#```B!```/`@```````"1!@``
M(`$``%4%``#8!0``/`(```````"=````'P@``%$`````````D`$`````````
M("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`
M("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A;F0`(&%T(``@
M;W(`(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L
M:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D
M92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D
M9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C
M<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N
M,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R
M9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN
M9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G
M<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@
M<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C
M:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N
M*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R
M97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@
M)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P
M860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@
M;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F
M;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I
M;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`
M+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T
M(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER
M960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S
M<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S
M86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`
M04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T
M('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C
M8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`06-T
M:6]N(&9O<B!B;&%C:VQI<W1E9"!A9&1R97-S97,Z`$%C=&EV871E(%-C<FEP
M=`!!8W1I=F%T:6YG('1H92!S8W)I<'0@9F]R("(E<R(@9F%I;&5D.B`H)60I
M("5S`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`
M061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D
M9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@
M;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E
M<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U
M="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N
M.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D:71I;VYA;"!3
M971T:6YG<P!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!
M9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L
M:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U
M<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;"!O9B!T:&4@
M9F]L;&]W:6YG`$%L;&]W(%)U;&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E
M<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y
M(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!0
M87-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA
M:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT
M.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`
M06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%N>2!O9B!T:&4@9F]L
M;&]W:6YG`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I
M;VX@:7,@<F5A9'DN`$%P<&QY($9I;'1E<G,`07!P;'D@=&\@0VAI;&0@4VAA
M<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I
M;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/P!!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E
M<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE
M;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!
M<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S
M:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I
M=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U
M=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V
M92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A
M="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!
M=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C
M=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E
M<B!F86EL960N`$%U=&]M871I8V%L;'D@=7!D871E('1H92!S8W)I<'0@869T
M97(@96%C:"!C:&%N9V4_`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`
M0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@
M:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H
M86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`
M0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U
M;F0N`$)A<V5L:6YE`$)C8P!"96=I;G,@=VET:`!"96QA<G5S`$)E;&=I=6T`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I;F0@9F%I;&5D.B`H)7,I
M("5S`$)I<G1H9&%Y`$)L86-K;&ES=`!";&%C:VQI<W0@161I=`!";&%C:VQI
M<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@
M9')I=F5R+@!";&%C:VQI<W1E9"!!9&1R97-S97,`0FQO8VL@(B5S(B!O9B!A
M<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO
M8VL@5'EP90!";V1Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O
M<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN
M80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"
M<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L
M86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD
M:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E
M<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD
M87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R
M(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@
M24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`
M0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I
M;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#
M86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N
M`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L
M("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F
M(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@
M;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%S92!3
M96YS:71I=F4`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S
M`$-C`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`
M0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I
M8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@
M1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE
M<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E<R!S879E9"X`
M0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E
M<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I
M`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`
M0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A
M`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V
M:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U
M9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#
M;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`
M0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#
M;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO
M<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN
M8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER
M;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE
M9#H@`$-O;FYE8W1I;VX@9F%I;'5R90!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E
M<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#
M;VYT86EN<P!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N
M=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O
M<'D`0V]P>2`E<P!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!O9B`E<P!#;W!Y('-E
M;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG
M;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B
M)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E
M<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B
M;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T
M<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N
M`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B
M(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@
M9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L
M9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L
M9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@
M=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`
M0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@
M;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!N97<@9F]L9&5R`$-R96%T
M92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D
M(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT
M(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT
M(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U
M<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/
M23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN
M:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1)4T%"3$5$.B``1%-.
M("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W
M<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S
M96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E86-T:79A=&4@4V-R:7!T
M`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F
M875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3
M:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E("5S`$1E;&5T92!#96QL
M`$1E;&5T92!#;VYD:71I;VX`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L
M971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L>0!$96QE=&4@
M;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`
M1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U
M8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H
M92!C=7)R96YT(')O=P!$96QE=&5D`$1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`1&5L:79E<B!I;G1O(&UY($EN8F]X`$1E;&EV97(@:6YT
M;R!M>2!);F)O>"!A;F0@8V]P>2!T;P!$96QI=F5R(&EN=&\@;7D@26YB;W@@
M86YD(')E9&ER96-T('1O`$1E;&EV97(@=&\@9F]L9&5R`$1E;&EV97)Y('1I
M;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M
M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P
M;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H
M="!T;R!L969T`$1I<F5C=&]R>0!$:7-A8FQE("5S`$1I<V%B;&5D`$1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0`1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@
M=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/P!$:7-P;&%Y(&9O<F5C87-T
M("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;@!$:FEB;W5T:0!$;R!?;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@
M;&ES="!M97-S86=E<P!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('1H:7,Z`$1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#H`1&]E<VXG="!B96=I;B!W:71H`$1O97-N)W0@8V]N=&%I;@!$
M;V5S;B=T(&5N9"!W:71H`$1O97-N)W0@97AI<W0`1&]E<VXG="!M871C:"`H
M=VET:"!P;&%C96AO;&1E<G,I`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI
M8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O
M=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I
M;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P
M<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET("5S
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO
M;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O
M+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R
M97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@)7,`16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YA8FQE9`!%
M;F0@>65A<@!%;F1S('=I=&@`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H
M92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R
M90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U86P@=&\`17%U871O<FEA
M;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T
M:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R
M<F]R(')E=')I979I;F<@8W5R<F5N="!S8W)I<'0Z("@E9"D@)7,`17)R;W(@
M<V%V:6YG(&-H86YG97,N`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%
M<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`
M17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M
M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU
M=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AI<W1I;F<@4G5L97,`17AI
M<W1S`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T
M960@,2!O8FIE8W0L(&=O="`E9"X`17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@
M0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C
M;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V
M92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R
M;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z
M(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&
M:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`
M1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97(@06QL($UE<W-A9V5S`$9I;'1E
M<B!/;FQY(%-E96X@365S<V%G97,`1FEL=&5R($]N;'D@56YS965N($UE<W-A
M9V5S`$9I;'1E<B!/<'1I;VYS`$9I;'1E<B!2=6QE`$9I;'1E<B!2=6QE<P!&
M:6QT97(@4V-R:7!T($1I<W!L87D`1FEL=&5R(%]2=6QE<P!&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@
M9F]L9&5R("(E<R(N`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H
M879E(&)E96X@9&5L971E9"X`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E
M*',I(&AA=F4@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E
M<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!T:&%T(&UA=&-H960@=&AE(&)L
M86-K;&ES="!W97)E(&1E;&5T960N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE
M<W-A9V4@(B5S(B!F<F]M("(E<R(@:&%S(&)E96X@8V]P:65D('1O('1H92!F
M;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B
M(&9R;VT@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ
M(%1H92!M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&UO=F5D('1O
M('1H92!F;VQD97(@(B5S(BX`1FEL=&5R(&YO="!F;W5N9"X`1FEL=&5R<P!&
M:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI
M<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L
M;W(`1F]O9`!&;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R
M9"!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D
M<FEV97(N`$9O<G=A<F1S`$9O<G=A<F1S($5D:70`1G(`1G)A;65S`$9R86YC
M90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0
M;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O
M;2!T:&4@`$9R;VTZ`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@
M3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y
M.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@
M0V]D90!'96YE<F%T960@8GD@26YG;R`H:'1T<#HO+W=W=RYH;W)D92YO<F<O
M:6YG;R\I`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@
M3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O
M9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E871E<B!T:&%N`$=R96%T97(@=&AA
M;B!O<B!E<75A;"!T;P!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N
M;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`
M1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM
M`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI
M`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H
M97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(
M;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@
M061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO
M;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M
M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@
M3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R
M96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E
M<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N
M=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T
M<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E
M9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@
M4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC
M;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D
M:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I
M;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N
M970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T
M;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA
M9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G
M86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E
M<P!);7!O<G0L(%-T97`@)60`26UP;W)T86YT`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`
M26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1I=FED=6%L(')U;&5S(&%R92!N
M;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N
M`$EN9&]N97-I80!);F5X:7-T86YT(&UA:6QB;W@@<W!E8VEF:65D(&9O<B!M
M97-S86=E(&1E;&EV97)Y+@!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN
M<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R
M="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!)
M;G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O
M;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G
M97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E
M9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI
M<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:
M25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$
M+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E
M(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?
M='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M
M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN
M=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L
M:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L
M:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<P!)<VQE
M(&]F($UA;@!)<VXG=`!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R
M`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@
M*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y
M`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S
M=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L
M($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N
M9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@
M=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E
M;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC
M(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,1$%0('-U
M<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@
M879A:6QA8FQE(&]R(&YO="!L;V%D960N`$QA7WEO=70`3&%N9W5A9V4`3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@
M4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA
M<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I
M;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`
M3&5S;W1H;P!,97-S('1H86X`3&5S<R!T:&%N(&]R(&5Q=6%L('1O`$QE=F5L
M`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN
M`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI
M9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I
M=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R
M:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`
M3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,
M:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)1`!,:7-T+4ED`$QI<W0M3W=N
M97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I
M;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E
M`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD
M(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E
M<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO
M=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W
M97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!
M='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O
M;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C
M87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I
M`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T
M(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@
M86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`
M36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<E]K
M(&UE<W-A9V4@87,@9&5L971E9`!-87)C:`!-87)G:6X`36%R:R!M97-S86=E
M(&%S.@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T
M:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@
M27-L86YD<P!-87)T:6YI<75E`$UA=&-H97,@*'=I=&@@<&QA8V5H;VQD97)S
M*0!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L
M;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!.=6UB
M97(@;V8@4G5L97,`36%X:6UU;2!L96YG=&@`36%X:6UU;2!N=6UB97(@;V8@
M8FQA8VML:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S
M97,Z("5S+"!-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T(&%D
M9"!N97<@861D<F5S<V5S('1O(&)L86-K;&ES="X`36%X:6UU;2!N=6UB97(@
M;V8@=VAI=&5L:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R
M97-S97,Z("5S+"!-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T
M(&%D9"!N97<@861D<F5S<V5S('1O('=H:71E;&ES="X`36%Y`$UA>6]T=&4`
M365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A
M9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N
M97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A
M9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D
M("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L
M;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI
M<W-I;F<@861D<F5S<R!T;R!N;W1I9GD`36ES<VEN9R!A9&1R97-S('1O(')E
M9&ER96-T(&UE<W-A9V4@=&\`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@
M:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H
M:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R
M96%S;VX@9F]R(')E:F5C=`!-:7-S:6YG(')E87-O;B!I;B!V86-A=&EO;BX`
M36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S
M97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$
M871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-
M;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R
M<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@
M=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO
M<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN9'D`36]S=&QY(%-U
M;FYY`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@
M4G5L92!$;W=N`$UO=F4@4G5L92!5<`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E
M('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU
M;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y
M;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$Y?=6UB97(@;V8@9&%Y
M<R!B971W965N('9A8V%T:6]N(')E<&QI97,Z`$YA;64`3F%M:6)I80!.875R
M=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S
M8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S
M8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C
M87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.
M971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E
M9V]R>0!.97<@36]O;@!.97<@4G5L90!.97<@57-E<FYA;64@*&]P=&EO;F%L
M*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@
M97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@
M=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0
M:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`$YI9VAT`$YI=64`3F\`3F\@(B5S(B!E;&5M96YT(&9O=6YD(&EN(&)A
M8VME;F0@8V]N9FEG=7)A=&EO;BX`3F\@879A:6QA8FQE(&-O;F9I9W5R871I
M;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE
M('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%C:V5N9"!C
M;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0`3F\@8F%C:V5N9',@8V]N9FEG=7)E
M9"!I;B!B86-K96YD<RYP:'``3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H
M86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L
M969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E
M9`!.;R!F:6QT97)S+B!#;&EC:R`B)7,B('1O(&-R96%T92!A(&YE=R!F:6QT
M97(N`$YO(&AE861E<G,@<W!E8VEF:65D`$YO(&EC;VYS(&9O=6YD+@!.;R!L
M;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S
M86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P
M96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO
M('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E
M;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R
M(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R
M=6QE<P!.;R!S8W)I<'0@9V5N97)A=&5D+@!.;R!S97!A<F%T;W(@<W!E8VEF
M:65D+@!.;R!S:61E<P!.;R!S=')I;F=S('-P96-I9FEE9`!.;R!S=6-H(&9I
M;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE
M+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@
M6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@
M:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I
M;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`
M3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`
M3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.
M;W0@97%U86P@=&\`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P
M;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I
M9GD@96UA:6P@861D<F5S<P!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H
M87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B
M97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D
M<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P
M;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&9L86<@=&AE(&UE<W-A9V4`3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F
M;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN
M9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A=&EN
M9RX`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]V97)V:65W`$]W
M;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T
M=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG
M;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H
M="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO
M=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI
M<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S
M=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'
M=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@
M`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B
M;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N
M("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I
M;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R
M;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET
M8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A
M<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A
M>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0
M;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z`%!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C
M:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S
M<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`
M4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E
M<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B
M;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T
M;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0
M=6)L:6,@2V5Y("@E9"!B:70I`%)?96%S;VX`4F%D:6\@<V5L96-T:6]N`%)A
M:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@
M4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!2
M96%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O
M<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2
M96-E:79E9`!2961I<F5C="!T;P!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2
M969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H
M(%!O<G1A;"!6:65W.@!296=E>`!296=U;&%R(&5X<')E<W-I;VX`4F5J96-T
M('=I=&@@<F5A<V]N`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA
M<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C
M;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D
M('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@1FEE;&0`4F5S96YT(%1O`%)E<V5N="UF<F]M`%)E<V5T`%)E<V5T(%!A
M<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y
M`%)E<W5L=',`4F5T=7)N('1O($9I;'1E<G,@3&ES=`!2971U<FX@=&\@3W!T
M:6]N<P!2971U<FX@=&\@4G5L97,@3&ES=`!2971Y<&4@;F5W('!A<W-W;W)D
M`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A
M;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q
M.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O
M=R!P<F]P97)T:65S`%)O=W,Z`%)U;&4`4G5L92!#;W!I960`4G5L92!$96QE
M=&5D`%)U;&4@1&ES86)L960`4G5L92!%;F%B;&5D`%)U;&4@3F%M90!2=6QE
M.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O
M;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2
M=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-1
M3"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!3
M5$%25%1,4R!F86EL960Z("@E<RD@)7,`4U5#0T534P!37U%,(%-H96QL`%-A
M`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N
M9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I
M9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@
M3W!T:6]N<P!3879E(%-E='1I;F=S`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T
M;W)M<P!38VEE;F-E`%-C<FEP=`!38W)I<'0@57!D871I;F<`4V-R:7!T(&YO
M="!U<&1A=&5D+@!38W)I<'0@<W5C8V5S<V9U;&QY(&%C=&EV871E9"X`4V-R
M:7!T('-U8V-E<W-F=6QL>2!D96%C=&EV871E9"X`4V5A<F-H`%-E87)C:"!%
M;F=I;F5S`%-E96X`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T
M(&$@9FEE;&0`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O
M=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L
M96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N
M(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&%R9V5T(&9O;&1E<@!396QE
M8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L
M;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5L9BU$969I;F5D($AE861E<@!396YD(%!R;V)L
M96T@4F5P;W)T`%-E;F0@4TU3`%-E;F1E<@!396YE9V%L`%-E;G-O<CH@`%-E
M<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D
M;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M`%-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!3971U<`!3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I
M;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W($%C=&EV92!38W)I<'0`4VAO
M=R!#=7)R96YT(%-C<FEP=`!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E
M('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R
M<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`
M4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N
M871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6UP;&4@<W!A;2!F:6QT97)I
M;F<@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@
M9')I=F5R+@!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A
M:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N
M;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H
M.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S
M`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3
M;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E
M<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`
M4W!A:6X`4W!A;0!3<&%M($9I;'1E<FEN9P!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S
M`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T
M92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<"!C:&5C:VEN9R!I9B!T:&ES(')U
M;&4@;6%T8VAE<S\`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R
M:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@
M861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@
M9F]U;F0N`%-U8FIE7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z`%-U8FIE8W0`
M4W5B:F5C=#H`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`
M4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O
M<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE
M`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`
M5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!4
M86YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L
M97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R
M90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO
M)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E
M($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X
M='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@
M9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@
M9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!A9&1R97-S("(E<R(@:&%S(&)E96X@861D
M960@=&\@>6]U<B!B;&%C:VQI<W0N`%1H92!A9&1R97-S("(E<R(@:&%S(&)E
M96X@861D960@=&\@>6]U<B!W:&ET96QI<W0N`%1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O
M='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"X`5&AE(&1R:79E<B!S86ED.B``5&AE(&5N8W)Y<'1I;VX@9F5A='5R
M97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@
M86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R
M8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R
M(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7
M:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@
M)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E
M<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N
M;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X
M:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@
M<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E
M8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y
M(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R
M960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S
M(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO
M;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@
M9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A
M('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@
M=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O
M;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B
M)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D
M871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E
M<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@
M97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4:&5R92!W87,@86X@97)R
M;W(@9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N`%1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@
M*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@
M;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N
M`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I
M<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET
M("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S
M970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F
M;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@
M*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H
M:6QE(&-L:6-K:6YG+@!4;SH`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O
M9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@;6%N>2!I;G9A;&ED(&QO
M9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P`%1O<"!F<F%M92`H
M7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O
M<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY
M*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L
M=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N
M9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L
M9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E
M860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L
M9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN
M90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI
M8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG
M9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E
M<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U
M<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E
M<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A
M9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB
M97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E
M<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI
M;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B
M)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R
M<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A8V%T:6]N($5D:70`5F%C871I;VX@
M:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I
M=F5R+@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y
M`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE
M(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C
M="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO
M;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E
M9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG
M;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.
M86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N
M86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ
M(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L
M;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E
M871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I
M=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7
M97-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S
M=&5R;B!386AA<F$`5VA?:71E;&ES="!A9&1R97-S97,Z`%=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H
M87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7
M:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET
M;W(N`%=H:71E;&ES=`!7:&ET96QI<W0@161I=`!7:&ET96QI<W0@:7,@;F]T
M('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!7
M:&ET96QI<W1E9"!!9&1R97-S97,`5VED=&@`5VED=&@@:6X@0U-3('5N:71S
M`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@
M=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I
M;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R
M:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U0<FEO<FET>0!8
M+5)E9@!8+5-P86TM3&5V96P`6"U3<&%M+5-C;W)E`%@M4W!A;2U3=&%T=7,`
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!9
M65E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!R=6QE<RX`66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@;W(@961I="!C=7-T;VT@<G5L97,N`%EO
M=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T:&4@
M)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@
M96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N`%EO=2!H879E(')E8V5I=F5D(&$@;F5W(&UE<W-A9V4`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O
M;F4@96UA:6P@861D<F5S<R!F;W(@=VAI8V@@=&AE('9A8V%T:6]N(&UE<W-A
M9V5S('-H;W5L9"!B92!A8W1I=F%T960N`%EO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O
M('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(
M;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S
M92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN
M="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`
M66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M
M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E
M`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L
M96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061D<F5S<RAE<RD@
M=&\@9F]R=V%R9"!T;SH`7T%D9')E<W-E<R!T;R!N;W0@<V5N9"!R97-P;VYS
M97,@=&\Z`%]!9&UI;FES=')A=&EO;@!?0FQA8VML:7-T`%]#3$D`7T1A=&%4
M<F5E`%]$96QE=&4@4F]W`%]$96QE=&4@;65S<V%G92!C;VUP;&5T96QY`%]%
M;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN93H`7T9O<G=A<F0`7T=R
M;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?2V5E<"!A(&-O<'D@
M;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT/P!?3&]G(&EN`%],;V<@;W5T
M`%]-;V1I9GD@3&EN:RXN+@!?36]V92!M97-S86=E('1O(&9O;&1E<CH`7TUY
M(&5M86EL(&%D9')E<W-E<SH`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO
M=F4@3&EN:RXN+@!?4V-R:7!T`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN
M+@!?57-E<G,`7U9A8V%T:6]N`%]7:&ET96QI<W0`86-T:79E`&%D9')E<W,@
M8F]O:P!A9&1R97-S964@=6YK;F]W;@!A;F0`8V%L96YD87(`8V%L;0!C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K
M(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!D:7-A8FQE9"`M(&-L:6-K('1O(&5N86)L90!E9&ET`&5N=')Y
M(&YO="!F;W5N9`!F86QL:6YG`&9I96QD`&9I;&4`9G)O;2!T:&4@)7,@*"5S
M*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM
M;65D:6%T90!I;F%C=&EV90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN
M=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M86EL9')O<"!S8W)I<'0@
M9V5N97)A=&5D(&)Y($EN9V\`;6%T8V@`;6MI<V]F<R!E<G)O<B!C;V1E("5D
M('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO
M="!Y970@:6UP;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT`'!E<FUI<W-I
M;VX@9&5N:65D`'!I>&5L<P!P<F]C;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y
M($EN9V\`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E
M('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(
M5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R
M>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N
M8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@26YG;R`Q+C$M8W9S"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`S+3`V(#$R.C0W*S`Q,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-BTP,RTP-B`Q,CHU,RLP,3`P"DQA<W0M5')A;G-L871O<CH@2F%N
M(%-C:&YE:61E<@I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R
M9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN("$]
M(#$I.PH`("AV;W(@)7,@5&%G96XI`"`H6G5G<FEF9G-T87-T92`E<RD`("AI
M;B`E<R!486=E;BD`("AH975T92D`("AM;W)G96XI`"`H9V5S=&5R;BD`('5N
M9``@;6ET(``@;V1E<@`B)7,B(&ES="!K96EN(%9E<GIE:6-H;FES+@`B)7,B
M(&ES="!K96EN92!G_&QT:6=E($%U<W=A:&PN`"(E<R(@:7-T(&EN(&1E<B!(
M;W)D92!296=I<W1R>2!N:6-H="!K;VYF:6=U<FEE<G0N`$1E<B!"875M+5)E
M;F1E<F5R(&;\<B`B)7,B('=U<F1E(&YI8VAT(&=E9G5N9&5N+@`B)7,B('=U
M<F1E('IU;2!'<G5P<&5N<WES=&5M(&AI;GIU9V5F_&=T+@`B)7,B('=U<F1E
M('IU;2!296-H=&5S>7-T96T@:&EN>G5G96;\9W0N`"(E<R(@=W5R9&4@;FEC
M:'0@97)S=&5L;'0Z("5S+@`E+C)F34(@*"4S)"XR9B4E*2!V;VX@)3(D+C)F
M34(@97)L875B=&5N('9E<F)R875C:'0`)60@)7,@=6YD("5S`$EN("5D(%1A
M9V5N('=I<F0@26AR(%!A<W-W;W)T('5N9_QL=&EG+@`E9"U486=E+59O<FAE
M<G-A9V4`)7,@+2!(:6YW96ES`"5S($9I;F=E<F%B9')U8VL`)7,@2T(`)7,@
M5V%R='5N9W-A<F)E:71E;B`M($)E<W3D=&EG=6YG`"5S+4MO;F9I9W5R871I
M;VX`)7,@4F5G:7-T<FEE<G5N9P`E<R!.=71Z=6YG<V)E9&EN9W5N9V5N`"5S
M(&5X:7-T:65R="!B97)E:71S+@`E<R!M:70@)7,@)7,`)7,@=VER9"!D:64@
M5V%R='5N9W-A<F)E:71E;B!D=7)C:&;\:')E;BP@9&EE('5N=&5N(&UA<FMI
M97)T('-I;F0N($UA<FMI97)E;B!3:64@86QL92!!=69G86)E;BP@9&EE(&IE
M='IT(&1U<F-H9V5F_&AR="!W97)D96X@<V]L;&5N+@`E<R!I<W0@;F]T=V5N
M9&EG`"5S($UI;G5T96X`)7,@;FEC:'0@9V5F=6YD96XN`"5S(&)I<R`E<R!V
M;VX@)7,`)7-S($%D<F5S<V)U8V@`)7-S($MA;&5N9&5R`"5S<R!.;W1I>F)L
M;V-K`"5S<R!!=69G86)E;FQI<W1E`"5S.B`E<P`E<SH@1&EE<V4@3F%C:')I
M8VAT('-T86UM="!U;G1E<B!5;7-TY&YD96X@;FEC:'0@=F]N(&1E;2!A;F=E
M9V5B96YE;B!!8G-E;F1E<BX@1F]L9V5N(%-I92!K96EN96X@3&EN:W,@:6X@
M9&EE<V5R($YA8VAR:6-H="!U;F0@:/QT96X@4VEE('-I8V@@9&%V;W(L(&1E
M;2!!8G-E;F1E<B!P97)S]FYL:6-H92!$871E;B!P<F5I<WIU9V5B96XN`"P@
M8O9I9R``+"!B:6<@)7,@)7,`+"!S8VAW86YK96YD('9O;B`E<R!B:7,@)7,`
M+2T@075S=^1H;&5N("TM`#$R+5-T=6YD96XM1F]R;6%T`#(T+5-T=6YD96XM
M1F]R;6%T`#(T(%-T=6YD96X`/%IU<OQC:P!&<B!D:65S96X@0FQO8VL@=VER
M9"!E:6YE($1A=&5N8F%N:R!B96YT:6=T+@!%:6X@<V-H=V5R97(@1F5H;&5R
M(&ES="!A=69G971R971E;CH`16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS
M<V5L('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU;F<@96EN97(@3F%C:')I
M8VAT(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P@
M=VER9"!F_'(@9&EE(-QB97)P<OQF=6YG(&5I;F5R('5N=&5R>F5I8VAN971E
M;B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I
M;B!P<FEV871E<B!01U`M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R="!W
M:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B
M96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%!'
M4"U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5
M;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V
M9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L
M('-O=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L
M=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE
M<B!U;F0@96EN('!R:79A=&5R(%,O34E-12U38VAL_'-S96P@<V]W:64@96EN
M(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.
M86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@4R]-24U%+5-C
M:&S\<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R($YA
M8VAR:6-H="!B96[V=&EG="X`5F]R;6ET=&%G<R!7;VQK96X`5F]R;6ET=&%G
M<R!L96EC:'1E<B!296=E;@!6;W)M:71T86=S(%)E9V5N`%9O<FUI='1A9W,@
M4V-H875E<@!6;W)M:71T86=S(%-C:&YE97-C:&%U97(`04TO4$T`05!)($E$
M`-QB97(@9&EE<V5N($5D:71O<@!);F9O+BXN`$%B<V]L=70@56YT96X`06)S
M;VQU="!-:71T90!:=6=R:69F('9E<G=E:6=E<G0@8F5I;2!!;FQE9V5N(&1E
M<R!61E,M5F5R>F5I8VAN:7-S97,N`%IU9W)I9F8@=F5R=V5I9V5R="!B96EM
M($%N;&5G96X@9&5R(%9&4RU$871E:2X`2V]N=&]I;F9O<FUA=&EO;F5N`$MO
M;G1O<&%S<W=O<G0`2V]N=&\@96EN9V5F<F]R96XN`$)U8VAH86QT=6YG`$%K
M=&EO;B!F_'(@875S9V5S8VAL;W-S96YE($%D<F5S<V5N.@!3:W)I<'0@86MT
M:79I97)E;@!!:W1I=FEE<F5N(&1E<R!3:W)I<'1S(&;\<B`B)7,B(&9E:&QG
M97-C:&QA9V5N.B`H)60I("5S`$AI;GIU9OQG96X`3F5U92!5;G1E<F=R=7!P
M92!H:6YZ=6;\9V5N`$YE=64@56YT97)R96-H=&4@:&EN>G5F_&=E;@!(:65R
M(&AI;GIU9OQG96XZ`$YE=64@1W)U<'!E(&AI;GIU9OQG96X`3F5U92!296-H
M=&4@:&EN>G5F_&=E;@!5;G1E<F=R=7!P92!Z=2`B)7,B(&AI;GIU9OQG96X`
M56YT97)R96-H=&4@>G4@(B5S(B!H:6YZ=6;\9V5N`$;\9V5N(%-I92!E:6YE
M;B!N975E;B!"96YU='IE<B!H:6YZ=3H`4W!A;'1E(&AI;GIU9OQG96X`3F5U
M92!-:71G;&EE9&5R(&AI;GIU9OQG96X`4&%A<B!H:6YZ=6;\9V5N`$1A<R`E
M<RU-96[\('IU<B!-;WII;&QA(%-I9&5B87(@:&EN>G5F_&=E;@!:=6T@061R
M97-S8G5C:"!H:6YZ=6;\9V5N.@!:=2!M96EN96T@061R97-S8G5C:"!H:6YZ
M=6;\9V5N`$)E;G5T>F5R(&AI;GIU9OQG96X`(B5S(B!W=7)D92!Z=6T@4WES
M=&5M(&AI;GIU9V5F_&=T+"!A8F5R(&1I92!Z=7/D='IL:6-H96X@4F5G:7-T
M<FEE<G5N9W-I;F9O<FUA=&EO;F5N(&MO;FYT96X@;FEC:'0@9V5S<&5I8VAE
M<G0@=V5R9&5N.B`E<RX`(B5S(B!W=7)D92!Z=6T@4WES=&5M(&AI;GIU9V5F
M_&=T+B!3:64@:_9N;F5N('-I8V@@:F5T>G0@86YM96QD96XN`$1A<R!(:6YZ
M=6;\9V5N('9O;B!"96YU='IE<FX@:7-T(&YI8VAT(&WV9VQI8V@N`%IU<^1T
M>FQI8VAE($5I;G-T96QL=6YG96X`061R97-S90!!9')E<W-B=6-H`%9E<G=A
M;'1E;B`M(%)E8VAT92!F_'(@86YD97)E($)E;G5T>F5R(&9E<W1L96=E;@!!
M9&UI;FES=')A=&EO;@!797)B=6YG`$%F9VAA;FES=&%N`$%L8F%N:65N`$%L
M9V5R:65N`%-P:71Z;F%M90!!=7-R:6-H='5N9P!!=7-R:6-H='5N9SH`06QL
M90!!;F=E;65L9&5T92!"96YU='IE<@!!;&QE($=R=7!P96X`06QL92!296-H
M=&4`06QL92!V:65R(%-E:71E;@!!;&QE(&1E<B!F;VQG96YD96X`4F5G96QN
M(&5R;&%U8F5N`$UE:')E<F4@061R97-S96X@97)L875B96X`1F]R;6%T('9O
M;B!N=6UM97)I97)T96X@3&ES=&5N(.1N9&5R;C\`17AI<W1I97)T(&)E<F5I
M=',`06QT97)N871I=F4@24U34"U!;FUE;&1U;F<`06QT97)N871I=F5S($E-
M4U`M4&%S<W=O<G0`06QT97)N871I=F5R($E-4U`M0F5N=71Z97)N86UE`$%L
M=&5R;F%T:79E($5M86EL861R97-S90!!;'1E<FYA=&EV92!6;W)L86=E;@!!
M;'1E<FYA=&EV97(@5&5X=#H`06UE<FEK86YI<V-H+5-A;6]A`$5S('=U<F1E
M(&5I;B!U;F?\;'1I9V5R(%=E<G0@86YG96=E8F5N+@!%:6X@=6YB96MA;FYT
M97(@1F5H;&5R(&ES="!A=69G971R971E;BX`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM97(@4')O>'D`06YT=V]R=`!"96%N='=O<G1E=`!!;G1A
M<FMT:7,`06YT:6=U82!U;F0@0F%R8G5D80!%:6YE<B!D97(@9F]L9V5N9&5N
M`$%N=V5N9'5N9P!!;G=E;F1U;F=S;&ES=&4`06YW96YD=6YG(&ES="!B97)E
M:70N`$9I;'1E<G)E9V5L;B!A;G=E;F1E;@!!=68@56YT97)R96-H=&4@86YW
M96YD96X`0F5S=.1T:6=E;@!5;F=E9N1H<F4@1W+VWV4`07!R:6P`07)A8FES
M8V@@*%=I;F1O=W,M,3(U-BD`07)C:&EV9W+VWV4`07)C:&EV;F%M90!3:6YD
M(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I97-E(%)E9V5L(&SV<V-H96X@;?9C
M:'1E;C\`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D:64@4F5G:7-T<FEE
M<G5N9W-A;F9R86=E('9O;B`E<R!L]G-C:&5N(&WV8VAT96X_`%-I;F0@4VEE
M('-I8VAE<BP@9&%S<R!3:64@(B5S(B!U;F0@86QL92!5;G1E<F=R=7!P96X@
M;/9S8VAE;B!M]F-H=&5N/P!!<F=E;G1I;FEE;@!!<FUE;FEE;@!!<FUE;FES
M8V@@*$%235-#24DM."D`2W5N<W0`07)U8F$`07-C96YS:6]N+4EN<V5L;@!!
M4T-)22U+=6YS=`!!<VEE;B]087II9FES8VAE(%)E9VEO;@!!;G-T96AE;F1E
M(%=A<G1U;F=S87)B96ET96X@8F5S=.1T:6=E;B!L87-S96X_`%IU;W)D;G5N
M9W-F96QD97(`17,@=W5R9&4@=F5R<W5C:'0L(&5I;F4@;FEC:'0@97AI<W1I
M97)E;F1E($=R=7!P92!Z=2!L]G-C:&5N+@!%<R!W=7)D92!V97)S=6-H="P@
M96EN(&YI8VAT(&5X:7-T:65R96YD97,@4F5C:'0@>G4@;/9S8VAE;BX`17,@
M=W5R9&4@=F5R<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT
M('IU(&)E87)B96ET96XN`$5S('=U<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@
M97AI<W1I97)E;F1E<R!296-H="!Z=2!B96%R8F5I=&5N+@!!='1R:6)U=&4`
M075G=7-T`$%U<W1R86QI96X`UG-T97)R96EC:`!!=71H7V-Y<G-Q;#H@1&EE
M(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N
M9&5N+@!!=71H7V-Y<G5S.B!$87,@0F%C:V5N9"!H870@;FEC:'0@9&EE(&)E
M;O9T:6=T96X@1N1H:6=K96ET96XN`$%U=&A?8WER=7,Z($1I92!B96[V=&EG
M=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T
M:%]F='`Z($1I92!B96[V=&EG=&4@1E10+45R=V5I=&5R=6YG('=U<F1E(&YI
M8VAT(&=E9G5N9&5N+B!+;VUP:6QI97)E;B!3:64@4$A0(&UI="!D96T@+2UE
M;F%B;&4M9G1P(%!A<F%M971E<BX`075T:%]I;6%P.B!$:64@8F5N]G1I9W1E
M($E-05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?
M:W)B-3H@1&EE(&)E;O9T:6=T92!+97)B97)O<RU%<G=E:71E<G5N9R!W=7)D
M92!N:6-H="!G969U;F1E;BX`075T:%]L9&%P.B!$87,@2&EN>G5F_&=E;B!V
M;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV92!$:7)E8W1O<GD@;FEC:'0@
M=6YT97)S=/QT>G0`075T:%]L9&%P.B!$87,@3/9S8VAE;B!V;VX@0F5N=71Z
M97)N('=I<F0@9OQR($%C=&EV92!$:7)E8W1O<GD@;FEC:'0@=6YT97)S=/QT
M>G0`075T:%]L9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M17)W96ET97)U;F<@
M=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?;&1A<#H@1&5R($)E;G5T>F5R
M("5S(&MO;FYT92!N:6-H="!H:6YZ=6=E9OQG="!W97)D96XN($UE;&1U;F<@
M9&5S(%-E<G9E<G,Z(`!!=71H7VQD87`Z($)E;G5T>F5R("5S(&MO;FYT92!N
M:6-H="!G96SV<V-H="!W97)D96X`075T:%]L9&%P.B!"96YU='IE<B`E<R!K
M;VYN=&4@;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;@!!=71H7VQD87`Z($1A
M<R!!:W1U86QI<VEE<F5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@06-T:79E
M($1I<F5C=&]R>2!N:6-H="!U;G1E<G-T_'1Z="X`075T:%]M8V%L.B!$:64@
M8F5N]G1I9W1E($U#04PM17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD
M96XN`$%U=&A?<VUB875T:#H@1&EE(&)E;O9T:6=T92!386UB82U%<G=E:71E
M<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`06YM96QD=6YG(&)E:6T@24U!
M4"U397)V97(@9F5H;&=E<V-H;&%G96XN`$%U=&AE;G1I9FEZ:65R=6YG(&9E
M:&QG97-C:&QA9V5N`$%N;65L9'5N9R!F96AL9V5S8VAL86=E;BX@)7,`1&EE
M($%U=&AE;G1I9FEZ:65R=6YG('=U<F1E('9O;2!2041)55,M4V5R=F5R('IU
M<OQC:V=E=VEE<V5N+@!!;FUE;&1U;F<@8F5I;2!&5%`M4V5R=F5R(&9E:&QG
M97-C:&QA9V5N+@!!;FUE;&1U;F<@8F5I;2!334(M4V5R=F5R(&9E:&QG97-C
M:&QA9V5N+@!$87,@4VMR:7!T(&YA8V@@:F5D97(@Q&YD97)U;F<@875T;VUA
M=&ES8V@@86MT=6%L:7-I97)E;C\`5F5R9OQG8F%R92!&96QD97(Z`$%S97)B
M86ED<V-H86X`0D]&2"U!=7-R961E;@!(:6YT97)G<G5N9`!(:6YT97)G<G5N
M9&9A<F)E`$9A;'-C:&5S($ME<F)E<F]S+5!A<W-W;W)T+@!&86QS8VAE<B!+
M97)B97)O<RU"96YU='IE<FYA;64N`$)A:&%M87,`0F%H<F5I;@!"86QT:7-C
M:"`H25-/+3@X-3DM,3,I`$)A;F=L861E<V-H`$)A<F)A9&]S`$)A<VES+4)I
M;&1E<BU697)Z96EC:&YI<R`B)7,B(&YI8VAT(&=E9G5N9&5N+@!'<G5N9&QI
M;FEE`$)C8P!"96=I;FYT(&UI=`!796G?<G5L86YD`$)E;&=I96X`0F5L:7IE
M`$)E;FEN`$)E<FUU9&%S`$)H=71A;@!697)B:6YD=6YG(&9E:&QG97-C:&QA
M9V5N.B`H)7,I("5S`$=E8G5R='-T86<`075S<V-H;'5S<VQI<W1E`$%U<W-C
M:&QU<W-L:7-T92!"96%R8F5I=&5N`$%U<W-C:&QU<W-L:7-T96X@=V5R9&5N
M('9O;2!A:W1U96QL96X@1FEL=&5R=')E:6)E<B!N:6-H="!U;G1E<G-T_'1Z
M="X`075S9V5S8VAL;W-S96YE($%D<F5S<V5N`$)L;V-K("(E<R(@9&5R($%N
M=V5N9'5N9R`B)7,B(&YI8VAT(&=E9G5N9&5N+@!";&]C:V5I;G-T96QL=6YG
M96X`0FQO8VMT>7``5&5X=`!&971T`$)O;&EV:65N`$QE<V5Z96EC:&5N`%)A
M;F0`4F%H;65N9&EC:V4Z`%+D;F1E<@!";W-N:65N+4AE<GIE9V]W:6YA`$)E
M:61E<P!";W1S=V%N80!5;G1E;@!";W5V971I;G-E;`!"<F%S:6QI96X`0G)I
M=&ES8VAE<R!497)R:71O<FEU;2!I;2!);F1I<V-H96X@3WIE86X`0G)U;F5I
M($1A<G5S<V%L86T`0G5L9V%R:65N`%5N;G5M;65R:65R=&4@3&ES=&4`0G5R
M:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N<W-T
M96QL90!?6F5L;&5N96EG96YS8VAA9G1E;BXN+@!$97(@6G=I<V-H96YS<&5I
M8VAE<B!K;VYN=&4@;FEC:'0@:6YI=&EA;&ES:65R="!W97)D96XN`$MA;&5N
M9&5R`%=I;F1S=&EL;`!+86UB;V1S8VAA`$MA;65R=6X`4&%S<W=O<G0@:V%N
M;B!N:6-H="!A=71O;6%T:7-C:"!Z=7+\8VMG97-E='IT('=E<F1E;BP@8FET
M=&4@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T<F%T;W(N`$1I
M92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N`$5X
M=&5R;F4@4V5S<VEO;BU(86YD;&5R(&OV;FYE;B!N:6-H="!A9&UI;FES=')I
M97)T('=E<F1E;BX`5F5R8FEN9'5N9R!Z=6T@24U!4"U397)V97(@:V%N;B!N
M:6-H="!H97)G97-T96QL="!W97)D96XZ("5S`$1I92!$871E:2`B)7,B(&MA
M;FX@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!+86YA9&$`06)B<F5C:&5N`%!R
M;V)L96UB97)I8VAT(&%B8G)E8VAE;@!$:64@1&%T96D@(B5S(B!K;VYN=&4@
M;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!+96EN('1E;7!O<N1R97,@5F5R>F5I
M8VAN:7,@9V5F=6YD96XN`$9O<G1S971Z=6YG(&]H;F4@(G1A<F=E=$9I;&4B
M+5!A<F%M971E<B!N:6-H="!M]F=L:6-H+@!$87,@5F5R>F5I8VAN:7,@(B5S
M(B!K;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N+@!+;VYN=&4@;FEC:'0@
M96YT9F5R;G0@=V5R9&5N+"`E9"!+:6YD97(@97AI<W1I97)E;BX`56US;W)T
M:65R96X@;FEC:'0@;?9G;&EC:"X@1&EE($%N>F%H;"!D97(@16EN='+D9V4L
M(&1I92!U;7-O<G1I97)T('=E<F1E;B!S;VQL96XL('-T:6UM="!N:6-H="!M
M:70@9&5R($%N>F%H;"!D97(@9V5S<&5I8VAE<G1E;B!%:6YT<N1G92#\8F5R
M96EN+@!$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!A;B!D:64@86YG96=E
M8F4@3G5M;65R('=E:71E<F=E;&5I=&5T('=E<F1E;BX`2V%P(%9E<F1E`-QB
M97)S8VAR:69T`%!R;W9I9&5R`$=R;]\M+TML96EN<V-H<F5I8G5N9R!B96%C
M:'1E;@!+871E9V]R:65N('5N9"!"97-C:')I9G1U;F=E;@!#87EM86XM26YS
M96QN`$-C`$UO8FEL=&5L969O;@!:96QL96YE:6=E;G-C:&%F=&5N`$EN;F5N
M86)S=&%N9#H`6F5L;&5N96EG96YS8VAA9G1E;@!:96QL96YA8G-T86YD.@!-
M;V)I;'1E;&5F;VX`2V5L=&ES8V@@*$E33RTX.#4Y+3$T*0!:96YT<FEE<G0`
M6F5N=')A;&%F<FEK86YI<V-H92!297!U8FQI:P!-:71T96QE=7)O<.1I<V-H
M("A)4T\M.#@U.2TR*0!:97)T:69I:V%T9&5T86EL<P!:97)T:69I:V%T8F5S
M:71Z97(`6F5R=&EF:6MA=')I8VAT;&EN:65N`%1S8VAA9`#$;F1E<FX`Q&YD
M97)N(%-I92!):'(@4&%S<W=O<G0`Q&YD97)N(%-I92!D96X@3F%M96X@;V1E
M<B!D:64@16UA:6QA9')E<W-E+"!D:64@9&EE($5M<&;D;F=E<B!):')E<B!%
M;6%I;',@<V5H96XL('=E;FX@9&EE<V4@26AR92!%;6%I;',@;&5S96X@;V1E
M<B!D87)A=68@86YW;W)T96XN`,1N9&5R=6YG96X@9V5S<&5I8VAE<G0N`$1A
M<R#$;F1E<FX@26AR97,@4&%S<W=O<G1S('=I<F0@=F]N(&1I97-E;2!3>7-T
M96T@>G5R(%IE:70@;FEC:'0@=6YT97)S=/QT>G0N($)I='1E('=E;F1E;B!3
M:64@<VEC:"!A;B!):')E;B!!9&UI;FES=')A=&]R+@!:96EC:&5N`$QI;FL@
M_&)E<E]P<OQF96XN+BX`0VAI;&4`0VAI;F$`0VAI;F5S:7-C:"!V97)E:6YF
M86-H="`H1T(R,S$R*0!#:&EN97-I<V-H('1R861I=&EO;F5L;"`H0FEG-2D`
M06YW96YD=6YG(&%U<W?D:&QE;CH`5^1H;&5N(%-I92!E:6X@4&%S<W=O<G0`
M5^1H;&5N(%-I92!E:6YE;B!"96YU='IE<FYA;65N`$QE9V5N(%-I92!F97-T
M+"!W:64@9&%S($1A='5M(&%N9V5Z96EG="!W97)D96X@<V]L;#H`3&ES=&5N
M9F]R;6%T(&%U<W?D:&QE;B`H9OQR(&YU;6UE<FEE<G1E($QI<W1E;BD`5V5I
M:&YA8VAT<VEN<V5L`$ML87-S96YD969I;FET:6]N(&;\<B`E<R!N:6-H="!G
M969U;F1E;BX`2&5I=&5R`$U3+4]F9FEC92U486=S(&5N=&9E<FYE;@!!8F9R
M86=E('IU<OQC:W-E='IE;@!"96YU='IE<F1A=&5N(&SV<V-H96XZ("5S`$)E
M;G5T>F5R9&%T96X@;/9S8VAE;@!"96YU='IE<F1A=&5N(&SV<V-H96X`4W#D
M=&5R($%U9FML87)E;F0`1F]R=&9A:')E;@!#;&EC:V%T96QL('!E<B!(5%10
M`$9E;G-T97(@<V-H;&EEWV5N`%=O;&ME;@!&<OQH(%=O;&ME;@!"97?V;&MT
M`$MO:V]S:6YS96QN`$UE;OP@96EN9F%H<F5N`%IU<V%M;65N:.1N9V5N9&4@
M4F%H;65N`$MO;'5M8FEE;@!&87)B90!&87)B875S=V%H;`!&87)B=V%H;`!3
M<&%L=&5N.@!3<&%L=&5N_&)E<G-C:')I9G1E;@!#;VUI8W,`0F5F96AL`$)E
M9F5H;'-Z96EL90!+;VUM96YT87(`16EN9&5U=&EG97(@3F%M90!+;VUO<F5N
M`$9I<FUA`$-O;7!U=&5R`$)E9&EN9W5N9V5N`$)E9&EN9W5N9V5N`$MO;F9I
M9W5R871I;VYS=6YT97)S8VAI961E`$MO;F9I9W5R871I;VX@9&5R(%-Y;F-H
M<F]N:7IA=&EO;B!M:70@4$1!<RP@4VUA<G1P:&]N97,@=6YD($]U=&QO;VLN
M`$1I92!+;VYF:6=U<F%T:6]N(&UU<W,@86MT=6%L:7-I97)T('=E<F1E;BX`
M)7,@:V]N9FEG=7)I97)E;@!087-S=V]R="!B97-TY'1I9V5N`$MO;F=O`$1E
M;6]K<F%T:7-C:&4@4F5P=6)L:6,@2V]N9V\`5F5R8FEN9'5N9R!F96AL9V5S
M8VAL86=E;BX`5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E;CH@`%9E<F)I;F1U
M;F<@9F5H;&=E<V-H;&%G96X`5F5R8FEN9'5N9R!Z=6T@]F9F96YT;&EC:&5N
M(%-C:&S\<W-E;'-E<G9E<B!W=7)D92!A8F=E=VEE<V5N+@!697)B:6YD=6YG
M('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E(&%B9V5W
M:65S96XN($=R=6YD.B`E<R`H)7,I`%9E<F)I;F1U;F<@>G5M($944"U397)V
M97(@9F5H;&=E<V-H;&%G96X`2V]N=&%K=&4`1&EE($MO;G1A:W1E('=U<F1E
M;B!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T+@!%
M;G1HY&QT`$EN:&%L='-T>7`@9&5R(&MO;7!R:6UI97)T96X@1&%T96DZ(`!)
M;FAA;'0@=F]N("(E<R(`5V5I=&5R`$-O;VLM26YS96QN`$-O;VMI90!+;W!I
M97)E;@`E<R!K;W!I97)E;@!+;W!I97)E;B!F96AL9V5S8VAL86=E;CH@)7,`
M2V]P:64@=F]N("5S`$%U<W=A:&P@:V]P:65R96X`2V]S=&5N+4E$`$-O<W1A
M(%)I8V$`16QF96YB96EN:_QS=&4`1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC
M:'0@;6ET(%!'4"!V97)S8VAL_'-S96QT('=E<F1E;CH@`$1I92!.86-H<FEC
M:'0@:V]N;G1E(&YI8VAT(&UI="!01U`@=6YT97)Z96EC:&YE="!W97)D96XZ
M(`!$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@4R]-24U%('9E<G-C
M:&S\<W-E;'0@=V5R9&5N+@!$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M
M:70@4R]-24U%('5N=&5R>F5I8VAN970@=V5R9&5N+@!+;VYT86MT(&MO;FYT
M92!N:6-H="!G97-P96EC:&5R="!W97)D96XN("5S`%9E<F)I;F1U;F<@>G5M
M($Q$05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+@!+;VYT;W-T86YD(&MO;FYT
M92!N:6-H="#\8F5R<'+\9G0@=V5R9&5N+B`E<P!697)B:6YD=6YG('IU;2!,
M1$%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`1E10+59E<F)I;F1U;F<@>G5M
M(%-E<G9E<B`B)7,B(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W97)D96XZ
M("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D
M96XN("5S`%!'4"U$871E;B!K;VYN=&5N(&YI8VAT(&5N='-C:&S\<W-E;'0@
M=V5R9&5N.B``4R]-24U%+41A=&5N(&MO;FYT96X@;FEC:'0@96YT<V-H;/QS
M<V5L="!W97)D96XN`$MO;G1A:W0@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E
M<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&=E;/9S8VAT
M('=E<F1E;BX@)7,`1&%S($%K='5A;&ES:65R=6YG<W-K<FEP="`B)7,B(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1I92!%;6%I;&%D<F5S<V4@
M9&5S($5M<&;D;F=E<G,@:V]N;G1E(&YI8VAT(&5R;6ET=&5L="!W97)D96XN
M`$1A<R!!9')E<W-B=6-H(&MO;FYT92!N:6-H="!K;VUP;&5T="!G96QE<V5N
M('=E<F1E;BX`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&%U<V=E;&5S
M96X@=V5R9&5N+B`E<P!,:7-T92!D97(@5F5R=&5I;&5R;&ES=&5N(&MO;FYT
M92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX`1&EE(%-T<F%T96=I92`B)7,B
M(&MO;FYT92!N:6-H="!G96QA9&5N('=E<F1E;BX`1&%S(%9E<GIE:6-H;FES
M("(E<R(@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`UF9F96YT;&EC
M:&5R(%-C:&S\<W-E;"!K;VYN=&4@;FEC:'0@=F]M(%-C:&S\<W-E;'-E<G9E
M<B!G96AO;'0@=V5R9&5N+@`B)7,B(&MO;FYT92!N:6-H="!Z=6T@4V-H<F5I
M8F5N(&=E]F9F;F5T('=E<F1E;BX`)7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@
M=V5R9&5N+@!$87,@36%I;G1E;F%N8V5?5&%S:R!-;V1U;"`E<R!K;VYN=&4@
M;FEC:'0@9V7V9F9N970@=V5R9&5N`%9E<GIE:6-H;FES("(E<R(@:V]N;G1E
M(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX`5F5R8FEN9'5N9R!Z=6T@3$1!4"U3
M97)V97(@:V]N;G1E(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;BX`)7,@:V]N
M;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N+@!$87,@4&%S<W=O<G0@9OQR(&1E
M;B!A;F=E9V5B96YE;B!"96YU='IE<B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S
M971Z="!W97)D96XL('=E:6P@96EN:6=E($%N9V%B96X@;FEC:'0@<FEC:'1I
M9R!W87)E;BX@5F5R<W5C:&5N(%-I92!E<R!E<FYE=70@;V1E<B!W96YD96X@
M4VEE('-I8V@@86X@26AR96X@061M:6YI<W1R871O<BP@=V5N;B!3:64@=V5I
M=&5R92!(:6QF92!B96[V=&EG96XN`$%#3"!K;VYN=&4@;FEC:'0@9V5L97-E
M;B!W97)D96X`1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI8VAT(&=E;&5S96X@
M=V5R9&5N+B`E<P!697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@875S9V5L
M97-E;B!W97)D96XN("5S`%9E<G1E:6QE<FQI<W1E;B!K;VYN=&4@;FEC:'0@
M875S9V5L97-E;B!W97)D96XN("5S`$1I92!397)V97)FY&AI9VME:71E;B!K
M;VYN=&5N(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N`$MO;F9I9W5R871I;VX@
M:V]N;G1E(&YI8VAT('IU<OQC:V=E<V5T>G0@=V5R9&5N+@!697)Z96EC:&YI
M<R`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`"5S+4MO;F9I
M9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`0F%C
M:W5P(&1E<B!+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P96EC:&5R
M="!W97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC
M:'0@9V5S<&5I8VAE<G0@=V5R9&5N.B`E<P!$87,@06MT=6%L:7-I97)U;F=S
M<VMR:7!T(&MO;FYT92!N:6-H="!N86-H("(E<R(@9V5S<&5I8VAE<G0@=V5R
M9&5N+@!"86-K=7`@9&5R($MO;F9I9W5R871I;VX@)7,@:V]N;G1E(&YI8VAT
M(&=E<W!E:6-H97)T('=E<F1E;BX`1&EE($MO;F9I9W5R871I;VX@)7,@:V]N
M;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX@4VEE(&OV;FYE;B!E;G1W
M961E<B!E:6YE(&1E<B!-]F=L:6-H:V5I=&5N('5N=&5R("5S('9E<G=E;F1E
M;BP@=6T@9&5N($-O9&4@>G4@<W!E:6-H97)N+"!O9&5R(&1E;B!U;G1E;G-T
M96AE;F1E;B!#;V1E(&UA;G5E;&P@;F%C:"`E<R!K;W!I97)E;BX`1&5R($Q$
M05`M4V5R=F5R(&MO;FYT92!N:6-H="!D=7)C:'-U8VAT('=E<F1E;BX`(B5S
M(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!$97(@2V]N=&%K="!K
M;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B`E<P!697)T96EL97)L
M:7-T92!K;VYN=&4@;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;BX@)7,`1&EE
M($MO;F9I9W5R871I;VX@9OQR("(E<R(@:V]N;G1E(&YI8VAT(&=E<W!E:6-H
M97)T('=E<F1E;CH@)7,`1&EE($UO>FEL;&$@4VED96)A<B!K;VYN=&4@;FEC
M:'0@9V5F=6YD96X@=V5R9&5N+B!3=&5L;&5N(%-I92!S:6-H97(L(&1A<W,@
M9&EE(%-I9&5B87(@9V7V9F9N970@:7-T+@!$96T@0F5N=71Z97(@(B5S(B!K
M;VYN=&5N(&1I92!F;VQG96YD92!296-H=&4@9OQR(&1E;B!/<F1N97(@(B5S
M(B!N:6-H="!Z=6=E=VEE<V5N('=E<F1E;CH@)7,`1V5ZY&AL=&5R(%1E>'0`
M3&%N9`!+=7)S90!%<G-T96QL96X`3&EN:R!E<G-T96QL96X`3F5U92!)9&5N
M=&ETY'0@86YL96=E;@!.975E;B!/<F1N97(@97)S=&5L;&5N`%5N=&5R;W)D
M;F5R(&5R<W1E;&QE;@!%<G-T96QL97)R96-H=&4`2W)E9&ET:V%R=&5N;G5M
M;65R`$MR;V%T:65N`$MU8F$`06MT=65L;&4@-"!0:&%S96X`06MT=65L;&4@
M4V5S<VEO;G,`06MT=65L;&4@6F5I=`!!:W1U96QL92!54DP@:7-T`$%K='5E
M;&QE($)E;G5T>F5R`$%K='5E;&QE<R!7971T97(`1&5R>F5I=&EG92!"961I
M;F=U;F=E;CH@`$%K='5E;&QE<B!3=&EL`$QE9V5N(%-I92!F97-T+"!W96QC
M:&4@075F9V%B96X@;F%C:"!D97(@06YM96QD=6YG(&)E:2`E<R!E<FQE9&EG
M="!W97)D96X@<V]L;&5N+@!!=7-S8VAN96ED96X`075S=V%H;"!A=7-S8VAN
M96ED96X`6GEP97)N`$MY<FEL;&ES8V@@*$M/23@M4BD`2WER:6QL:7-C:"`H
M5VEN9&]W<RTQ,C4Q*0!+>7)I;&QI<V-H+U5K<F%I;FES8V@@*$M/23@M52D`
M5'-C:&5C:&ES8VAE(%)E<'5B;&EK`%14`$1%04M4259)15)4.B``1%-.("AS
M:65H92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`%3D9VQI8V@`1&%T851R964@0G)O
M=W-E<@!$871E;F)A;FMA8F9R86=E`$1A='5M`$5M<&9A;F=S9&%T=6T`1&%T
M=6US875S=V%H;`!486<`4W!A;'1E(%]L]G-C:&5N`%-K<FEP="!D96%K=&EV
M:65R96X`1&5Z96UB97(`6F%H;&5N`$5I;GIU9R!V97)R:6YG97)N`%-T86YD
M87)D`%-T86YD87)D9F%R8F4`4W1A;F1A<F1I9&5N=&ETY'0`4W1A;F1A<F1S
M:&5L;`!$969I;FET:6]N96X`3/9S8VAE;@`E<R!L]G-C:&5N`%IE;&QE(&SV
M<V-H96X`0F5D:6YG=6YG(&SV<V-H96X`1W)U<'!E(&SV<V-H96X`3&]G(&SV
M<V-H96X`4F5C:'1E(&SV<V-H96X`3F%C:')I8VAT96X@;/9S8VAE;B!U;F0@
M96YT9F5R;F5N`%IE;&QE(&SV<V-H96X`4W!A;'1E(&SV<V-H96X`0F5S=&5H
M96YD92!A;'1E<FYA=&EV92!6;W)L86=E(&SV<V-H96X`3F%C:')I8VAT(&MO
M;7!L971T(&SV<V-H96X`3F%C:')I8VAT96X@;/9S8VAE;@!296-H=&4@9OQR
M("(E<R(@;/9S8VAE;@!296-H=&4@9OQR("(E<R(@=6YD(&%L;&4@56YT97)R
M96-H=&4@;/9S8VAE;C\`6F5I;&4@;/9S8VAE;@!!=7-G97?D:&QT92!)9&5N
M=&ETY'0@;/9S8VAE;@!5;G1E<F]R9&YE<B!L]G-C:&5N`$1I92!A:W1U96QL
M92!3<&%L=&4@;/9S8VAE;@!$:64@86MT=65L;&4@6F5I;&4@;/9S8VAE;@!'
M96SV<V-H=`!$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T("(E<R(@=W5R9&4@
M9V5L]G-C:'0N`$EN(&UE:6YE;B!0;W-T96EN9V%N9R!A=7-L:65F97)N`$EN
M(&UE:6YE;B!0;W-T96EN9V%N9R!A=7-L:65F97)N('5N9"!K;W!I97)E;B!N
M86-H`$EN(&UE:6YE;B!0;W-T96EN9V%N9R!A=7-L:65F97)N('5N9"!W96ET
M97)L96ET96X@;F%C:`!);B!D:65S96X@3W)D;F5R(&%U<VQI969E<FXZ`$%U
M<VQI969E<G5N9W-Z96ET`$3D;F5M87)K`$)E<V-H<F5I8F5N(%-I92!D87,@
M4')O8FQE;0!"97-C:')E:6)U;F<`1&5T86EL<R`H875C:"!I;B!(;W)D97,@
M3&]G9&%T96DI.@!$971A:6QS('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T
M;W(@;6ET9V5L;V=G="X`16YT=VEC:VQU;F<`5&%U<'5N:W0`5&%U<'5N:W0@
M9&5R(&QE='IT96X@4W1U;F1E.B``5&%U<'5N:W0Z(`!6;VX@;&EN:W,@;F%C
M:"!R96-H=',`5F]N(')E8VAT<R!N86-H(&QI;FMS`%9E<GIE:6-H;FES`"5S
M(&1E86MT:79I97)E;@!$96%K=&EV:65R=`!:96ET(&EM(#(T+5-T=6YD96XM
M1F]R;6%T(&%N>F5I9V5N/P!!;GIE:6=E+45I;G-T96QL=6YG96X`1&5T86EL
M:65R=&4@5F]R:&5R<V%G92!A;GIE:6=E;@!$971A:6QI97)T92!"96YA8VAR
M:6-H=&EG=6YG(&%N>F5I9V5N(&)E:2!J961E;2!&:6QT97(L(&1E<B!A;F=E
M=V5N9&5T('=U<F1E/P!6;W)H97)S86=E("A4048I(&%N>F5I9V5N`$%N>F5I
M9V5F;W)M870`16UP9F%N9W-B97-TY'1I9W5N9P!$<V-H:6)U=&D`7TME:6YE
M($%N='=O<G1E;B!A=68@3F%C:')I8VAT96X@=F]N($UA:6QI;F=L:7-T96X@
M;V1E<B!-87-S96YE;6%I;',@=F5R<V-H:6-K96X`3FEC:'0@;/9S8VAE;@!'
M<F5I9F5N(%-I92!N:6-H="!D:7)E:W0@875F(&UA:6YT96YA;F-E+G!H<"!Z
M=0!$:65S97,@='5N.@!%;G1HY&QT(&1I92!E<G-T92!:96EL92!D:64@1F5L
M9&YA;65N/R!796YN(&IA+"!D:65S97,@075S=V%H;&OD<W1C:&5N(&UA<FMI
M97)E;CH`0F5G:6YN="!N:6-H="!M:70`16YT:.1L="!N:6-H=`!%;F1E="!N
M:6-H="!M:70`17AI<W1I97)T(&YI8VAT`$5N='-P<FEC:'0@;FEC:'0@*&UI
M="!0;&%T>FAA;'1E<FXI`$1O;6EN:6-A`$1O;6EN:6MA;FES8VAE(%)E<'5B
M;&EK`$YO8V@@:V5I;F5N(%IU9V%N9S\@2&EE<B!A;FUE;&1E;BX`2&5R=6YT
M97)L861E;@`E<R!(97)U;G1E<FQA9&5N`$5R>F5U9W1E($MO;F9I9W5R871I
M;VX@86QS(%!(4"U3:W)I<'0@:&5R=6YT97)L861E;BX`075S=V%H;&QI<W1E
M`$1R;V=E;@!%;6%I;`!%;6%I;"UN86-H+5--4RUG871E=V%Y(&;\<B!0<F]V
M:61E<BP@9&EE(&5I;F5N('-O;&-H96X@1&EE;G-T('5N=&5R<W3\='IE;BX`
M1D5(3$52`$5C=6%D;W(`0F5A<F)E:71E;@`E<R!"96%R8F5I=&5N`$)L;V-K
M(&)E87)B96ET96X`1W)U<'!E(&)E87)B96ET96X`4F5C:'1E(&)E87)B96ET
M96X`4F5C:'1E(&)E87)B96ET96X`4F5C:'1E(&;\<B`G)7,G(&)E87)B96ET
M96X`16EN<W1E;&QU;F=E;B!B96%R8F5I=&5N(&;\<CH`4F5C:'1E(&;\<B`B
M)7,B(&)E87)B96ET96X`4F5C:'1E(&;\<B`E<R!B96%R8F5I=&5N`$)I;&1U
M;F<`Q&=Y<'1E;@!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL861R97-S90!$:64@16UA:6QA9')E<W-E;B!M_'-S96X@9VQE:6-H('-E
M:6XN`$5M86EL(&UI="!"97-TY'1I9W5N9P!%;6%I;"UN86-H+5--4RU'871E
M=V%Y`%-M:6QE>7,`3&5E<F4@3F%C:')I8VAT+@!,965R97,@17)G96)N:7,N
M`%-U8VAB96=R:69F92!L]G-C:&5N`"5S(&%K=&EV:65R96X`16EN9OQG96X@
M=F]N($)I;&1E<FX@875S($9O=&]G86QE<FEE;B!I;B!D96X@5&5X="!E<FQA
M=6)E;C\`2V]N=&5X=&UE;OP@8F5I(%)E8VAT<VML:6-K(&%K=&EV:65R96X_
M`$%K=&EV:65R=`!%;F1J86AR`$5N9&5T(&UI=`!%9&ET;W(@=F5R9W+VWV5R
M;@!'96)E;B!3:64@96EN92!3:6-H97)H96ET<V9R86=E(&5I;BP@9&EE($EH
M;F5N(&=E<W1E;&QT('=I<F0L('=E;FX@4VEE($EH<B!087-S=V]R="!Z=7+\
M8VMS971Z96X@;?9C:'1E;BP@>BX@0BX@(E=I92!L875T970@9&5R($YA;64@
M26AR97,@2&%U<W1I97)S/R(Z`$AI97(@9&EE($)I;&0M55),(&%N9V5B96X`
M1V5B96X@<VEE(&1I92!"=6-H<W1A8F5N('5N=&5N(&5I;CH`1VQE:6-H`,1Q
M=6%T;W)I86PM1W5I;F5A`$5R:71R96$`1F5H;&5R`$9E:&QE<B!B96EM($5R
M<W1E;&QE;B!E:6YE<R!";&]C:W,Z("5S`$9E:&QE<B!B96EM($SV<V-H96X@
M9&5S(%-Y;F-H<F]N:7-A=&EO;G-A;FME<G,Z("5S`$9E:&QE<B!B96EM($SV
M<V-H96X@9&5S(%-Y;F-H<F]N:7-A=&EO;G-L;V=S.B`E<P!&96AL97(@8F5I
M;2!%<GIE=6=E;B!D97,@26YH86QT<SH@)7,`1F5H;&5R(&)E:6T@3&5S96X@
M9&5S(&%K='5E;&QE;B!3:W)I<'1S.B`H)60I("5S`$9E:&QE<B!B96EM(%-P
M96EC:&5R;B!D97(@Q&YD97)U;F=E;BX`1F5H;&5R(&)E:6T@Q&YD97)N(&1E
M<R!087-S=V]R=',Z("5S`$9E:&QE<B!I;B!D97(@16UA:6QN86-H<FEC:'0N
M`$9E:&QE<B!B96EM(%-C:')E:6)E;B!V;VX@(B5S(BX`17-T;&%N9`#$=&AI
M;W!I96X`171N:7-C:&5S`$5U<F]P80!!;&QE(#$U($UI;G5T96X`06QL92`R
M($UI;G5T96X`06QL92`S,"!396MU;F1E;@!!;&QE(#4@36EN=71E;@!"96D@
M:F5D97(@06YM96QD=6YG`$%L;&4@:&%L8F4@4W1U;F1E`$%L;&4@-C`@4V5K
M=6YD96X`0F5I<W!I96QW97)T93H`075S9OQH<F5N`$)E<W1E:&5N9&4@4F5G
M96QN`$5X:7-T:65R=`!697)G<O;?97)N`$UE;OP@875S9F%H<F5N`"<I)R!E
M<G=A<G1E=``Q($]B:F5K="!E<G=A<G1E="P@)60@97)H86QT96XN`$5I;GIE
M;&YE<R!7;W)T(&]D97(@4W5C:&)E9W)I9F8@:6X@06YF_&AR=6YG<WIE:6-H
M96X@97)W87)T970`5F5R9F%L;'-D871U;0!%>'!O;F5N=`!6;W)D97)G<G5N
M9&9A<F)E`$AO8VAL861E;B!D97(@2V]N9FEG=7)A=&EO;B!P97(@1E10`$)E
M;G5T>F5R96EN<W1E;&QU;F=E;B!K;VYN=&5N(&YI8VAT(&=E;&%D96X@=V5R
M9&5N+@!697)B:6YD=6YG('IU;2!,1$%0(%-E<G9E<B!G97-C:&5I=&5R="X`
M5F5R8FEN9'5N9R!Z=6T@4TU"+5-E<G9E<B!G97-C:&5I=&5R="X`17,@:V]N
M;G1E(&ME:6YE($MO<&EE('9O;B`B)7,B(&5R<W1E;&QT('=E<F1E;BX`17,@
M:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!K;W!I97)T('=E<F1E;BX`075F8F%U
M(&5I;F5N(&YE=65N(%-!4TPM5F5R8FEN9'5N9R!I<W0@9F5H;&=E<V-H;&%G
M96XN`$5S(&MO;FYT92!N:6-H="!N86-H("(E<R(@=F5R<V-H;V)E;B!W97)D
M96XN`$9E:&QE<B!B96EM($QE<V5N.B`E<P!(96ET97(`1F%L:VQA;F1I;G-E
M;&X`1F%R]F5R`%-C:'=E<F5R($9E:&QE<CH`1F%X`$9A>&4`1F5B<G5A<@!'
M96;\:&QT92!496UP97)A='5R`$=E9OQH;'1E(%1E;7!E<F%T=7(Z(`!697)E
M:6YZ96QT92!38VAA=65R`%9E<F5I;GIE;'1E(%-C:&YE97-C:&%U97(`1F5L
M9&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970M1F]N=`!&:61S8VAI`$1A
M=&5I`$%N>F%H;#H@)7,@1&%T96D`06YZ86AL.B`E<R!$871E:65N`$1A=&5I
M;6%N86=E<@!$871E:6YA;64`1&%T96EA=7-W86AL`$1A=&5I+4AO8VAL861E
M;@!$87,@2&]C:&QA9&5N('9O;B!$871E:65N('=I<F0@;FEC:'0@=6YT97)S
M=/QT>G0N`$%L;&4@3F%C:')I8VAT96X@9FEL=&5R;@!.=7(@9V5L97-E;F4@
M3F%C:')I8VAT96X@9FEL=&5R;@!.=7(@=6YG96QE<V5N92!.86-H<FEC:'1E
M;B!F:6QT97)N`$9I;'1E<F5I;G-T96QL=6YG96X`1FEL=&5R<F5G96P`1FEL
M=&5R<F5G96QN`$9I;'1E<G-K<FEP="U!;GIE:6=E`%]&:6QT97)R96=E;&X`
M1FEL=&5R86MT:79I=.1T.B`E<R!.86-H<FEC:'0H96XI('=U<F1E;B!Z=6T@
M3W)D;F5R("(E<R(@:V]P:65R="X`1FEL=&5R86MT:79I=.1T.B`E<R!.86-H
M<FEC:'0H96XI('=U<F1E;B!G96SV<V-H="X`1FEL=&5R86MT:79I=.1T.B`E
M<R!.86-H<FEC:'0H96XI('=U<F1E;B!Z=6T@3W)D;F5R("(E<R(@=F5R<V-H
M;V)E;BX`1FEL=&5R86MT:79I=.1T.B`E<R!.86-H<FEC:'0H96XI+"!D:64@
M9&5R($%U<W-C:&QU<W-L:7-T92!E;G1S<')A8VAE;BP@=W5R9&5N(&=E;/9S
M8VAT+@!&:6QT97)A:W1I=FETY'0Z($1I92!.86-H<FEC:'0@(B5S(B!V;VX@
M(B5S(B!W=7)D92!Z=6T@3W)D;F5R("(E<R(@:V]P:65R="X`1FEL=&5R86MT
M:79I=.1T.B!$:64@3F%C:')I8VAT("(E<R(@=F]N("(E<R(@=W5R9&4@9V5L
M]G-C:'0N`$9I;'1E<F%K=&EV:73D=#H@1&EE($YA8VAR:6-H="`B)7,B('9O
M;B`B)7,B('=U<F1E('IU;2!/<F1N97(@(B5S(B!V97)S8VAO8F5N+@!&:6QT
M97)R96=E;"!N:6-H="!G969U;F1E;BX`1FEL=&5R`$9I;FYL86YD`$5R<W1E
M($CD;&9T90!%<G-T97,@5FEE<G1E;`!697)HY&QT;FES('IU<OQC:W-E='IE
M;@!5;61R96AE;@!497AT9FQUWP!.96)E;`!$87,@5F5R>F5I8VAN:7,@)7,@
M97AI<W1I97)T(&YI8VAT`%-C:')I9G1F87)B90!%<W-E;@!&_'(@96EN9V5H
M96YD92!.86-H<FEC:'1E;BP@875F(&1I92!F;VQG96YD92!296=E;&X@>G5T
M<F5F9F5N.@!&_'(@0G)O=W-E<BP@9&EE(&ME:6YE($)I;&1E<B!U;G1E<G-T
M_'1Z96X`5F]R:&5R<V%G92`H5$%&*0!6;W)H97)G97-A9W1E(%1A9V4@*%9O
M<FAE<G-A9V5N(&5N=&AA;'1E;B!486=E('5N9"!.Y&-H=&4L(&5I;B!H;VAE
M<B!797)T(&MA;FX@>G4@96EN96T@<V5H<B!G<F_?96X@0FQO8VL@9OQH<F5N
M*0!087-S=V]R="!V97)G97-S96X_`$9O<FUU;&%R90!';/QC:W-K96MS`$=L
M_&-K<VME:W-T>7``1VS\8VMS:V5K<V4`1VS\8VMS:V5K<V4@,@!&;W)E;@!7
M96ET97)L96ET=6YG`%=E:71E<FQE:71U;F=E;B!W97)D96X@=F]M(&%K='5E
M;&QE;B!&:6QT97)T<F5I8F5R(&YI8VAT('5N=&5R<W3\='IT+@!796ET97)L
M96ET=6YG`%=E:71E<FQE:71U;F<@0F5A<F)E:71E;@!&<@!286AM96X`1G)A
M;FMR96EC:`!%=7)O<.1I<V-H97,@1G)A;FMR96EC:`!&<F%N>O9S:7-C:"U'
M=6%Y86YA`$9R86YZ]G-I<V-H+5!O;'EN97-I96X`1G)A;GKV<VES8VAE($=E
M8FEE=&4@:6T@<_QD;&EC:&5N($EN9&ES8VAE;B!/>F5A;@!6;VX`075S(`!6
M;VXZ`%9O;&QS=.1N9&EG92!"97-C:')E:6)U;F<`5F]L;&UO;F0`5F]L;'-T
MY&YD:6=E<B!.86UE`$=A8G5N`$)I;&1E<B!A=7,@9&EE<V5R($=A;&5R:64`
M1V%L97)I93H`1V%M8FEA`"5S+4MO;F9I9W5R871I;VX@97)Z975G96X`17)Z
M975G=&5R($-O9&4`17)Z975G="!V;VX@26YG;R`H:'1T<#HO+W=W=RYH;W)D
M92YO<F<O:6YG;R\I`$=E;W)G:65N`$1E=71S8VAL86YD`$=H86YA`$=I8G)A
M;'1A<@!6;W)N86UE`$%L;&=E;65I;F4@16EN<W1E;&QU;F=E;@!,;W,`1V]E
M9&5L`$=O;V=L92!-87!S`$=O;V=L92!3=6-H90!'<F%U<W1U9F5N`$=R]M]E
M<B!A;',`1W+VWV5R(&%L<R!O9&5R(&=L96EC:`!'<FEE8VAE;FQA;F0`1W)I
M96-H:7-C:"`H25-/+3@X-3DM-RD`1W+V;FQA;F0`1W)E;F%D80!'<G5P<&5N
M=F5R=V%L='5N9P!'<G5P<&5N;F%M96X@9/QR9F5N(&YI8VAT(&QE97(@<V5I
M;@!'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S(&MO;FYT92!N:6-H="!H:6YZ
M=6=E9OQG="!W97)D96XN($UE;&1U;F<@9&5S(%-E<G9E<G,Z(`!'<F]U<%]L
M9&%P.B!$:64@1W)U<'!E("5S(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D
M96X`1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC:'0@86MT
M=6%L:7-I97)T('=E<F1E;@!'<G5P<&5N`$=U861E;&]U<&4`1W5A;0!'=6%T
M96UA;&$`1W5E<FYS97D`1V%S=')E8VAT90!'Y'-T96)U8V@`1W5I;F5A`$=U
M:6YE82U":7-S874`1W5Y86YA`$A434P`1&5R($5D:71O<B!K86YN(&1I92!L
M971Z=&4@6F5L;&4@96EN97(@6F5I;&4@;FEC:'0@;/9S8VAE;BX`1&5R($5D
M:71O<B!K86YN(&1I92!L971Z=&4@4W!A;'1E(&5I;F5R(%1A8F5L;&4@;FEC
M:'0@;/9S8VAE;BX`1&5R($5D:71O<B!K86YN(&1I92!L971Z=&4@6F5I;&4@
M96EN97(@5&%B96QL92!N:6-H="!L]G-C:&5N+@!(5%10+4%U=&AE;G1I9FEZ
M:65R=6YG(&YI8VAT(&=E9G5N9&5N+@!(86ET:0!(87-H+4%L9V]R:71H;75S
M`$1I97-I9P#<8F5R<V-H<FEF=`!+;W!F96EN='+D9V4`2&5A<F0M('5N9"!-
M8T1O;F%L9&EN<V5L;@!38VAW97)E($=E=VET=&5R`$AE8G+D:7-C:"`H25-/
M+3@X-3DM."U)*0!(]FAE`$AI;&9E`$5D:71O<FAI;&9E`$AI;&9E`$AE;6ES
M<&AE<F4`1&EE<R!I<W0@9&5R($)E9VEN;B!D97(@1&%T96DZ`$AO8V@`7U-T
M87)T<V5I=&4`5F%T:6MA;G-T861T`%-T87)T<V5I=&4`061R97-S92!P<FEV
M870`2&5I;79E<GIE:6-H;FES`%1E;&5F;VX@<')I=F%T`$AO;F1U<F%S`$AO
M;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@56YG_&QT:6=E("5S+5A-3"U$
M871E;B!I;B!.86-H<FEC:'0@)7,`2&]R9&4O2V]L86(Z($5S('!A<W-T(&ME
M:6YE($YA8VAR:6-H="!Z=6T@3V)J96MT("5S`$AO<F1E+TMO;&%B.B!+96EN
M($]B:F5K="!V;VT@5'EP("5S(&EN($YA8VAR:6-H="`E<R!G969U;F1E;@!(
M;W)D92]+;VQA8CH@)7,@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!E;G1F97)N
M=`!(;W)D92]+;VQA8CH@1&EE($EN=&5G<F%T:6]N<V9U;FMT:6]N96X@8F5N
M]G1I9V5N(&1I92`B9&]M>&UL(B!02%`M17)W96ET97)U;F<`2&]R9&4O2V]L
M86(Z($;\<B!D87,@3V)J96MT("5S(&MO;FYT92!K96EN(&YE=65R(%A-3"U"
M875M(&5R>F5U9W0@=V5R9&5N`$AO<F1E+TMO;&%B.B`E<R`B)7,B(&MO;FYT
M92!N:6-H="!E;G1F97)N="!W97)D96XZ("5S`$AO<F1E+TMO;&%B.B!$:64@
M34E-12U)1"!D97,@06)S8VAN:71T<R!V;VT@5'EP("5S(&MO;FYT92!N:6-H
M="!H97)A=7-G969U;F1E;B!W97)D96XN`$AO<F1E+TMO;&%B.B`E<R`B)7,B
M(&MO;FYT92!N:6-H="!S>6YC:')O;FES:65R="!W97)D96XZ("5S`$AO<F1E
M+TMO;&%B.B!$:64@9V5M96EN<V%M96X@3V)J96MT92!K;VYN=&5N(&YI8VAT
M('-Y;F-H<F]N:7-I97)T('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z(%5N8F5K
M86YN=&5S(&=E;65I;G-A;65S($]B:F5K="`B)7,B`$AO<FEZ;VYT86QE($QI
M;FEE`$AO<FEZ;VYT86QE<B!);FYE;F%B<W1A;F0`2&]R:7IO;G1A;#H`5VEE
M('-I;F0@4VEE(&AI97)H97)G96QA;F=T/R!":71T92!A;B!D:64@16YT=VEC
M:VQE<B!Z=7+\8VMM96QD96XA*0!7:64@=FEE;&4@4W!A;'1E;B!S;VQL96X@
M>G5S86UM96YG96;\9W0@=V5R9&5N/P!7:65V:65L92!&96QD97(@*%-P86QT
M96XI(&=I8G0@97,_`%=I92!V:65L92!:96EL96X@<V]L;&5N('IU<V%M;65N
M9V5F_&=T('=E<F1E;C\`3'5F=&9E=6-H=&EG:V5I=`!,=69T9F5U8VAT:6=K
M96ET.B``2V]M:6ME<@!5;F=A<FX`06YL96=E;B!D97,@24U!4"U0;W-T9F%C
M:',@:7-T(&9E:&QG97-C:&QA9V5N.B`E<P!,]G-C:&5N(&1E<R!)34%0+5!O
M<W1F86-H<R!I<W0@9F5H;&=E<V-H;&%G96XZ("5S`$9E<W1L96=E;B!D97(@
M24U!4"U0;W-T9F%C:"U1=6]T82!I<W0@9F5H;&=E<V-H;&%G96XZ("5S`$E0
M+4%D<F5S<V4`25`M061R97-S92!N:6-H="!V97)F_&=B87(N`$E0+4%D<F5S
M<V4@;FEC:'0@:6T@97)L875B=&5N($-)1%(M0FQO8VLN`%9E<FQE='IU;F<@
M9&5R(&9E<W1G96QE9W1E;B!)4"X`6F5I;&4@96EN9OQG96X@7W9O<@!)<VQA
M;F0`3G5R($)I;&1E<@!)8V]N<R!F_'(@)7,`0FEL9&5R('5N9"!497AT`$)E
M>F5I8VAN=6YG(&1E<B!)9&5N=&ETY'0`5V5N;B!S:64@;FEC:'0@:V]R<F5K
M="!A;F=E>F5I9W0@=VER9"P@)7,L('5M('-I92!I;B!E:6YE;2!N975E;B!&
M96YS=&5R(&%N9V5Z96EG="!Z=2!B96MO;6UE;BX`5V5N;B!3:64@;6ET(&1E
M;2!);G1E<FYE="!%>'!L;W)E<B!K96EN92!3>6UB;VQE('-E:&5N+"!M_'-S
M96X@4VEE(&1I97-E<R!+Y'-T8VAE;B!M87)K:65R96XL('5M(%!.1RU4<F%N
M<&%R96YZ(&%U<WIU<W1E;&QE;BX`5V5N;B!3:64@9&EE<V4@3F%C:')I8VAT
M(&%N(%-T96QL92!E:6YE($)I;&1E<R!S96AE;BP@:V%N;B!):'(@0G)O=W-E
M<B!D87,@0FEL9"P@9&%S(%-I92!H;V-H;&%D96X@;?9C:'1E;B!N:6-H="!A
M;GIE:6=E;BX`0FEL9'9O<G-C:&%U.@!":6QD+5523`!":6QD+5523#H`0FEL
M9"!V;VX@1V%L97)I90!":6QD('9O;B!'86QE<FEE.@!":6QD+4AO8VAL861E
M;@!":6QD97(`26UP;W)T:65R96XL(%-C:')I='0@)60`5VEC:'1I9P!);7!O
M<G1I97)T97,@1F5L9#H@)7,`26UP;W)T:65R=&4@1F5L9&5R.@!:96EL92!E
M:6YF_&=E;B!?;F%C:`!5;F?\;'1I9V4@06MT:6]N(&%N9V5G96)E;BX`56YG
M_&QT:6=E<B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O<G0N`$9A;'-C
M:&5R($)E;G5T>F5R;F%M92!O9&5R($5M86EL861R97-S92X@5F5R<W5C:&5N
M(%-I92!E<R!E<FYE=70@;V1E<B!W96YD96X@4VEE('-I8V@@86X@26AR96X@
M4WES=&5M861M:6YI<W1R871O<BP@=V5N;B!3:64@=V5I=&5R92!(:6QF92!B
M96[V=&EG96XN`$5I;GIU9R!V97)G<O;?97)N`$EN9&EE;@!%:6YZ96QN92!"
M96YU='IE<@!);F1I=FED=65L;&4@4F5G96QN('=E<F1E;B!V;VT@86MT=65L
M;&5N($9I;'1E<G1R96EB97(@;FEC:'0@=6YT97)S=/QT>G0N`$EN9&]N97-I
M96X`3FEC:'0@=F]R:&%N9&5N97(@3W)D;F5R(&;\<B!D:64@3F%C:')I8VAT
M96YA=7-L:65F97)U;F<@86YG96=E8F5N+@!);F9O<FUA=&EO;@!);F9O<FUA
M=&EO;F5N`$EN9F]R;6%T:6]N96X@;FEC:'0@;65H<B!V97)F_&=B87(N`%]3
M<&%L=&4@9&%V;W(@96EN9OQG96X`0FEL9"!H:6YZ=6;\9V5N`%1A8F5L;&4@
M96EN9OQG96X`3&EN:R!E:6YF_&=E;@!37W!A;'1E(&1A;F%C:"!E:6YF_&=E
M;@!%:6YE(&YE=64@4W!A;'1E(&YA8V@@9&5R(&%K='5E;&QE;B!E:6YF_&=E
M;@!%:6YE(&YE=64@4W!A;'1E('9O<B!D97(@86MT=65L;&5N(&5I;F;\9V5N
M`$5I;F4@;F5U92!:96EL92!N86-H(&1E<B!A:W1U96QL96X@96EN9OQG96X`
M16EN92!N975E(%IE:6QE('9O<B!D97(@86MT=65L;&5N(&5I;F;\9V5N`$5I
M;F5N(&YE=65N($%B<V%T>B!N86-H(&1E;2!A:W1U96QL96X@16QE;65N="!E
M:6YF_&=E;@!%:6YE;B!N975E;B!!8G-A='H@=F]R(&1E;2!A:W1U96QL96X@
M16QE;65N="!E:6YF_&=E;@!!;'1E<FYA=&EV92!6;W)L86=E(&5I;F;\9V5N
M`$=E8F5N(%-I92!E:6YE($5M86EL861R97-S92!A;BP@86X@9&EE(&1A<R!N
M975E(%!A<W-W;W)T(&=E<V-H:6-K="!W97)D96X@<V]L;#H`6F5L;&4@9&%N
M86-H(&5I;F;\9V5N`%IE;&QE(&1A=F]R(&5I;F;\9V5N`%-P86QT92!D86YA
M8V@@96EN9OQG96X`4W!A;'1E(&1A=F]R(&5I;F;\9V5N`$YA8VAR:6-H=&5N
M(&AI;GIU9OQG96X`06)S871Z(&1A;F%C:"!E:6YF_&=E;@!!8G-A='H@9&%V
M;W(@96EN9OQG96X`6F5I;&4@9&%N86-H(&5I;F;\9V5N`%IE:6QE(&1A=F]R
M(&5I;F;\9V5N`$=E8F5N(%-I92!D:64@06YT=V]R="!A=68@9&EE(%-I8VAE
M<FAE:71S9G)A9V4@96EN.@!":6QD(&5I;F;\9V5N+V)E87)B96ET96X`3&EN
M:R!E:6YF_&=E;B]B96%R8F5I=&5N`%IU('=E;FEG($=U=&AA8F5N+"!U;2!A
M;B!D:64@5F5R=&5I;&5R;&ES=&4@>G4@=F5R<V-H:6-K96XN`%IU('=E;FEG
M($=U=&AA8F5N+@!'86YZ>F%H;`!,:7-T92!V;VX@1V%N>GIA:&QE;@!5;F?\
M;'1I9V5R(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!5;F?\;'1I9V4@6DE0
M+41A=&5N+@!5;F?\;'1I9V4@06YW96YD=6YG+@!5;F?\;'1I9V4@0F%T8V@M
M240N`%5N9_QL=&EG92!$871E;B!E:6YG96)E;BX`56YG_&QT:6=E(%II96QA
M9')E<W-E+@!5;F?\;'1I9V5S($1A=&5I9F]R;6%T`%5N9_QL=&EG97(@3&EZ
M96YZ<V-H;/QS<V5L+@!5;F?\;'1I9V5R($]R="!A;F=E9V5B96XN`%5N9_QL
M=&EG97(@;7-G7W1Y<&4N`%5N9_QL=&EG92!O9&5R(&9E:&QE;F1E(&%P:5]I
M9"X`56YG_&QT:6=E(&]D97(@9F5H;&5N9&4@4&%R86UE=&5R+@!5;F?\;'1I
M9V5S(-QB97)R96-H="X`56YG_&QT:6=E(%!A<G1N97(M240N`%5N9_QL=&EG
M97(@4')O9'5K=&-O9&4N`%5N9_QL=&EG97,@4')O=&]K;VQL+@!5;F?\;'1I
M9V5R($5M<&;D;F=E<CH@(B5S(@!5;F?\;'1I9V5S(&=E;65I;G-A;65S($]B
M:F5K=`!5;F?\;'1I9V4@57)S<')U;F=S861R97-S92X`56YG_&QT:6=E(%5N
M:6-O9&4M1&%T96XN`$EN=F5N=&%R`$%U<W=A:&P@=6UK96AR96X`27-L86UI
M<V-H92!297!U8FQI:R!)<F%N`$ER86L`27)L86YD`$ES=`!)<VQE(&]F($UA
M;@!)<W0@;FEC:'0`5F5R96EN>F5L=&4@1V5W:71T97(`27-R865L`$%U<W-T
M96QL97(`2W5R<VEV`$ET86QI96X`2F%M86EK80!*86YU87(`2F%P86X`2F%P
M86YI<V-H("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE;@!*=6QI`$IU
M;FD`0FQO8VMS871Z`%IE;G1R:65R96X`0FQO8VMS871Z`$QI;FMS(&%U<W)I
M8VAT96X`4F5C:'1S(&%U<W)I8VAT96X`2V%S86-H<W1A;@!/<FEG:6YA;"!B
M96EB96AA;'1E;C\`2V5N:6$`2V5R8F5R;W,M4V5R=F5R(&AA="!!=71H96YT
M:69I>FEE<G5N9R!Z=7+\8VMG97=I97-E;BX`2V5R;F5L+4YE=6QI;F=E`%-C
M:&S\<W-E;&5R>F5U9W5N9P!&:6YG97)A8F1R=6-K(&1E<R!38VAL_'-S96QS
M`%-C:&S\<W-E;&SD;F=E`%-C:&S\<W-E;'1Y<`!38VAL_'-S96QZ=V5C:P!$
M97(@4V-H;/QS<V5L(&)E9FEN9&5T('-I8V@@8F5R96ET<R!A=68@9&5M(/9F
M9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(N`$MI;F1E<@!+:7)I8F%T:0!$
M96UO:W)A=&ES8VAE(%9O;&MS<F5P=6)L:6,@2V]R96$`4F5P=6)L:6L@2V]R
M96$`2V]R96%N:7-C:"`H155#+4M2*0!+=7=A:70`2VER9VES:7-T86X`3$1!
M4"U5;G1E<G-T_'1Z=6YG('=I<F0@8F5N]G1I9W0L(&%B97(@9&%S($Q$05`M
M36]D=6P@:7-T(&YI8VAT('9E<F;\9V)A<B!O9&5R('=U<F1E(&YI8VAT(&=E
M;&%D96XN`$%N7W!A<W-E;@!3<')A8VAE`$QA;W,`3&5T>G1E($CD;&9T90!,
M971Z=&4@4&%S<W=O<G3D;F1E<G5N9P!,971Z=&5S(%9I97)T96P`3&5T>G1E
M($%K='5A;&ES:65R=6YG.@!,971Z=&4@06YM96QD=6YG.B`E<P!,971Z=&4@
M06YM96QD=6YG.B`E<R!V;VX@)7,`3&5T>G1E($%N;65L9'5N9SH@3F]C:"!N
M:64`3&5T=&QA;F0`1V5S971Z`$9O<FUA=`!,965R(&QA<W-E;B!F_'(@:V5I
M;F5N(%)A:&UE;@!,:6)A;F]N`$QI;FMS`$QI;FME(-QB97)S8VAR:69T`$QI
M;FME(%=E<G1E`$QE<V]T:&\`2VQE:6YE<B!A;',`2VQE:6YE<B!A;',@;V1E
M<B!G;&5I8V@`16)E;F4`3&EB97)I80!,:6)Y96X`3&EE8VAT96YS=&5I;@!3
M<'+\:')E9V5N`$QE:6-H=&5R(%)E9V5N`$9R_&@@;&5I8VAT97(@4F5G96X`
M4W#D=&5R($QE:6-H=&5R(%)E9V5N`$QE:6-H=&4@4F5G96YS8VAA=65R`$QE
M:6-H=&5R(%)E9V5N(&UI="!'97=I='1E<@!,96EC:'1E<B!38VAN965F86QL
M`$QE:6-H=&4@4V-H;F5E<V-H875E<@!,:6UE<FEC:P!,:6YK`$QI;FL@=F5R
M=V5I<W0@875F.@!%;6%I;&%D<F5S<V4@=F5R;&EN:V5N/P!,:6YK<P!,:6YU
M>"U';/QC:W-K96MS90!,:7-T("T@0F5N=71Z97(@:V%N;B!D96X@3W)D;F5R
M('-E:&5N`$1A=&5N8F%N:V5N(&%N>F5I9V5N`$AI;&9E96EN='+D9V4@86YZ
M96EG96X`5&%B96QL96X@86YZ96EG96X`3&ES=&5N+4%R8VAI=@!,:7-T96XM
M2&EL9F4`3&ES="U)1`!,:7-T96XM260`3&ES=&5N+4)E<VET>F5R`$QI<W1E
M;BU!9')E<W-E`$QI<W1E;BU!;FUE;&1U;F<`3&ES=&5N+4%B;65L9'5N9P!$
M87,@06YZ96EG96X@9&5R(%-E<W-I;VYS(&ES="!F96AL9V5S8VAL86=E;CH@
M)7,`1&%S($%N>F5I9V5N(&1E<B!"96YU='IE<B!I<W0@9F5H;&=E<V-H;&%G
M96XZ("5S`$1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@:7-T(&YI8VAT(&WV
M9VQI8V@N`$QI=&5R871U<@!,:71A=65N`$QA9&4N+BX`3&]K86QE(%5H<GIE
M:70Z(`!3<')A8VAE('5N9"!:96ET`$]R=`!!;FUE;&1E;@!,;V<@9&5R(&QE
M='IT96X@4WEN8VAR;VYI<V%T:6]N+@!!8FUE;&1E;@!!;FUE;&1E;@!!;FUE
M;&1E875F9V%B96X`1&EE($%N;65L9'5N9R!I<W0@9F5H;&=E<V-H;&%G96XL
M('=E:6P@4VEE($EH<F5N($)E;G5T>F5R;F%M96X@;V1E<B!):'(@4&%S<W=O
M<G0@9F%L<V-H(&5I;F=E9V5B96X@:&%B96XN`$%N;65L9'5N9R!F96AL9V5S
M8VAL86=E;BX`3&%N9V5R(%1E>'0`3&EE8F4`3FEE9')I9P!+;"X@9W)I96-H
M:7-C:&4@0G5C:'-T86)E;@!+;"X@;&%T96EN:7-C:&4@0G5C:'-T86)E;@!+
M;"X@<O9M:7-C:&4@6F%H;&5N`$QU>&5M8G5R9P!-30!-3U1$`$U3+51.148M
M06YH86YG(&5N=&AI96QT(&ME:6YE($1A=&5N+@!(24Y714E3`$UA8V%O`$1I
M92!E:&5M86QI9V4@2G5G;W-L87=I<V-H92!297!U8FQI:R!-87IE9&]N:65N
M`$UA9&%G87-K87(`36%G:64`5V5B;6%I;`!%;6%I;"!!9&UI;FES=')A=&EO
M;@!,:6YK(%]A;FQE9V5N+BXN`$UA;&%W:0!-86QA>7-I80!-86QI9&EV96X`
M36%L:0!-86QT80!697)W86QT96X@4VEE(&1I92!+871E9V]R:65N+"!M:70@
M9&5N96X@4VEE($5L96UE;G1E('5N9"!%:6YT<N1G92!K96YN>F5I8VAN96X@
M:_9N;F5N+"!S;W=I92!D:64@>G5G96CV<FEG96X@1F%R8F5N+@!-87`R-"U+
M87)T90!-87!1=65S="U+87)T90!:=6]R9&YU;F=E;B!G97-P96EC:&5R="X`
M3F%C:')I8VAT(&%L<R!?9V5L]G-C:'0@;6%R:VEE<F5N`$WD<GH`077?96YA
M8G-T86YD`$YA8VAR:6-H="!M87)K:65R96X@86QS.@!-:70@1V5L97-E;BTO
M56YG96QE<V5N+5-T871U<R!V97)S96AE;@!-:70@86YD97)E;2!3=&%T=7,@
M=F5R<V5H96X@*'HN0BX@5VEC:'1I9R]"96%N=V]R=&5T*0!-87)S:&%L;&EN
M<V5L;@!-87)T:6YI<75E`$5N='-P<FEC:'0@*&UI="!0;&%T>FAA;'1E<FXI
M`%IU9V5O<F1N971E($9E;&1E<@!-875R971A;FEE;@!-875R:71I=7,`36%X
M:6UA;"!E<FQA=6)T97(@2W)E9&ET+@!-87AI;6%L92!.86-H=&EC:'1E;G1E
M:6QE(/QB97)S8VAR:71T96XN`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT
M96X@,C0@4W1U;F1E;CH@`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT96X@
M-B!3='5N9&5N.B``36%X:6UA;&4@06YZ86AL(&%N(%!O<G1A;&)L]F-K96X`
M36%X:6UA;&4@06YZ86AL(&%N(%)E9V5L;@!-87AI;6%L92!,Y&YG90!-87AI
M;6%L92!!;GIA:&P@9&5R(&%U<V=E<V-H;&]S<V5N96X@061R97-S96X@_&)E
M<G-C:')I='1E;B`H061R97-S96X@:6YS9V5S86UT.B`E<RP@36%X:6UA;&4@
M06YZ86AL.B`E<RDN($YE=64@061R97-S96X@:V]N;G1E;B!N:6-H="!Z=7(@
M075S<V-H;'5S<VQI<W1E(&AI;GIU9V5F_&=T('=E<F1E;BX`36%X:6UA;&4@
M06YZ86AL(&1E<B!P;W-I=&EV9V5L:7-T971E;B!!9')E<W-E;B#\8F5R<V-H
M<FET=&5N("A!9')E<W-E;B!I;G-G97-A;70Z("5S+"!-87AI;6%L92!!;GIA
M:&PZ("5S*2X@3F5U92!!9')E<W-E;B!K;VYN=&5N(&YI8VAT('IU<B!0;W-I
M=&EV;&ES=&4@:&EN>G5G96;\9W0@=V5R9&5N+@!-86D`36%Y;W1T92!)<VQA
M;F0`365D:7II;@!-:71G;&EE9&5R`$UE;OQM;V1U<SH`6F5L;&5N('IU<V%M
M;65N9OQG96X`3F%C:')I8VAT`$1I92!.86-H<FEC:'0@:V]N;G1E(&5R9F]L
M9W)E:6-H(/QB97)P<OQF="!W97)D96X@86)E<B!N:6-H="!D87,@6F5R=&EF
M:6MA="!D97,@06)S96YD97)S+@!.86-H<FEC:'0@;FEC:'0@;65H<B!G_&QT
M:6<N`$YA8VAR:6-H=&5N='EP`$UE=&%R(%=E='1E<@!-971A<F)L;V-K(&YI
M8VAT('9E<F;\9V)A<BX`365T87)B;&]C:R!N:6-H="!V97)F_&=B87(N($1E
M=&%I;',@=W5R9&5N(&;\<B!D96X@061M:6YI<W1R871O<B!M:71G96QO9V=T
M+@!+96EN92!697)B:6YD=6YG('IU<B!-971A<D1"+@!-971H;V1E`$1I92!-
M971H;V1E("(E<R(@:7-T(&YI8VAT(&1E9FEN:65R=`!-971H;V1E(&YI8VAT
M(&1E9FEN:65R="X@075F9V5R=69E;F4@365T:&]D93H@)7,`365T<FES8V@`
M365X:6MO`$;V9&5R:65R=&4@4W1A871E;B!V;VX@36EK<F]N97-I96X`36ET
M=&4`36EM971Y<`!4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T
M=6YD96XZ(`!4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#8@4W1U;F1E
M;CH@`$1A<R!M:6YI;6%L92!087-S=V]R=&%L=&5R(&ES="!N;V-H(&YI8VAT
M(&%B9V5L875F96X`4W!I96=E;&X`5F5R<V-H:65D96YE<P!014%2+5!A:V5T
M($A45%!?4F5Q=65S="!F96AL="X`0F5N86-H<FEC:'1I9W5N9W-A9')E<W-E
M(&9E:&QT`$1I92!!9')E<W-E+"!Z=2!D97(@=V5I=&5R9V5L96ET970@=V5R
M9&5N('-O;&PL('=U<F1E(&YI8VAT(&%N9V5G96)E;@!&96AL96YD92!+;VYF
M:6=U<F%T:6]N+B!3:64@;?QS<V5N(&1I97-E(&IE='IT(&5R>F5U9V5N+"!W
M96YN(%-I92!D:64@06YW96YD=6YG('9E<G=E;F1E;B!M]F-H=&5N+@!&96AL
M96YD92!.86-H<FEC:'1E;BU)1"X`1&5R($=R=6YD(&;\<B!!8FQE:&YU;F<@
M=W5R9&4@;FEC:'0@86YG96=E8F5N`$1E<B!'<G5N9"!F_'(@9&EE($%B=V5S
M96YH96ET<VYA8VAR:6-H="!W=7)D92!N:6-H="!A;F=E9V5B96X`4$5!4BU0
M86ME="!-86EL(&9E:&QT+@!&96AL96YD92!3:71Z=6YG<RU)1"X`36\`16UA
M:6P@36]B:6P`3>3?:6<`Q&YD97)U;F=S9&%T=6T`55),(&)E87)B96ET96X`
M36]D=6QU<P!297!U8FQI:R!-;VQD874`36]N86-O`$UO;F=O;&5I`$UO;F%T
M('5N9"!*86AR`$UO;F%T;&EC:`!-;VYT<V5R<F%T`$UO;F1P:&%S96X`365H
M<B!&96QD97(@:6X@6F5I;&4@)60@86QS(&1I92!E<G=A<G1E=&5N("5D(&=E
M9G5N9&5N+@!-87)O:VMO`-QB97)W:65G96YD(&AE:71E<@#<8F5R=VEE9V5N
M9"!"97?V;&MT`-QB97)W:65G96YD($)E=_9L:W0@=6YD(%=I;F1I9P#<8F5R
M=VEE9V5N9"!3;VYN:6<`5F5R<V-H:65B96X`3F%C:"!U;G1E;@!.86-H(&QI
M;FMS`$YA8V@@<F5C:'1S`%)E9V5L(&YA8V@@=6YT96X@=F5R<V-H:65B96X`
M4F5G96P@;F%C:"!O8F5N('9E<G-C:&EE8F5N`$YA8V@@;V)E;@!.86-H('5N
M=&5N`$YA8V@@;V)E;@!-;W-A;6)I:P!!=7-W86AL;&ES=&4@:6X@;65H<F5R
M96X@16)E;F5N`$UU;'1I;6%P+55++4MA<G1E`$UE:')F86-H875S=V%H;`!-
M96EN($MO;G1O`$UE:6X@2V]N=&\`365I;B!0;W)T86P`365I;B!0;W)T86QL
M87EO=70`0G5R;6$`3D5)3BP@:6-H('-T:6UM92!.24-(5"!Z=0!!;GIA:&P@
M9&5R(%]486=E('IW:7-C:&5N(&1E;B!!8G=E<V5N:&5I='-N86-H<FEC:'1E
M;CH`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YI961E<FQA;F1E`$YI961E
M<FSD;F1I<V-H92!!;G1I;&QE;@!.971S8V%P92U"87-I<RU54DP`3F5T<V-A
M<&4M0T$M4W!E<G)U;F=S+5523`!.971S8V%P92U#02U2:6-H=&QI;FEE;BU5
M4DP`3F5T<V-A<&4M6F5T:69I:V%T<V5R;F5U97)U;F=S+5523`!.971S8V%P
M92U3<&5R<G5N9W,M55),`$YE='-C87!E+5-33"U397)V97)N86UE`$YE='-C
M87!E+4MO;6UE;G1A<@!.971S8V%P92U:97)T:69I:V%T='EP`$YE='IW97)K
M`$YI90!.975K86QE9&]N:65N`$YE=64@2V%T96=O<FEE`$YE=6UO;F0`3F5U
M92!296=E;`!.975E<B!"96YU='IE<FYA;64@*&]P=&EO;F%L*0!.975S965L
M86YD`$YE=65S(%!A<W-W;W)T`$1A<R!N975E(%!A<W-W;W)D('=I<F0@86T@
M)7@@86)L875F96XN`$1I92!N975E;B!087-S=_9R=&5R('-T:6UM96X@;FEC
M:'0@_&)E<F5I;BX`3F5U97,@1F5N<W1E<B`H7V)L86YK*0!.86-H<FEC:'1E
M;@!.97=S9W)U<'!E;@!796ET97(`3N1C:'-T92`T(%!H87-E;@!.Y&-H<W1E
M($5I;G-T96QL=6YG96X`5V5I=&5R/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I
M80!.86-H=',`3FEU90!.96EN`"(E<R(@:6X@9&5R($)A8VME;F1K;VYF:6=U
M<F%T:6]N(&YI8VAT(&%N9V5G96)E;BX`2V5I;F4@2V]N9FEG=7)A=&EO;G-D
M871E;B!V97)F_&=B87(L('5M(%5N=&5R<V-H:65D92!A;GIU>F5I9V5N+@!+
M96EN92!3=')A=&5G:64@>G5M($5R<W1E;&QE;B!V;VX@25-/+4%B8FEL9&5R
M;B!V97)F_&=B87(N`$ME:6YE($)A8VME;F1K;VYF:6=U<F%T:6]N(&;\<B!D
M:65S96X@2&]S="!A;F=E9V5B96X`2V5I;F4@0F%C:V5N9',@:6X@8F%C:V5N
M9',N<&AP(&MO;F9I9W5R:65R=`!+96EN92!"871C:"U6;W)L86=E+@!%<R!E
M>&ES=&EE<G0@:V5I;B!";&]C:R!A;B!D97(@86YG96=E8F5N96X@4&]S:71I
M;VX`2V5I;B!+86QE;F1E<FYA;64@9OQR(&1I92!-0T%,+4%U=&AE;G1I9FEZ
M:65R=6YG(&%N9V5G96)E;BX`2V5I;F4@Q&YD97)U;F=E;BX`56YT97)H86QB
M(&1I97-E<B!%8F5N92!K]FYN96X@:V5I;F4@=V5I=&5R96X@56YT97)R96-H
M=&4@:&EN>G5G96;\9W0@=V5R9&5N+@!&_'(@)7,@=W5R9&5N(&ME:6YE($MO
M;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN`$;\<B!D96X@
M1E10+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN
M9F]R;6%T:6]N96X@86YG96=E8F5N+@!&_'(@9&5N(%-13"U61E,M5')E:6)E
M<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N(&%N
M9V5G96)E;BX`1OQR(&1E;B!344PM1&%T96DM5D93+51R96EB97(@=W5R9&5N
M(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN
M`$ME:6X@2W)E9&ET(&UE:'(@_&)R:6<N`$ME:6X@16UP9N1N9V5R(&%N9V5G
M96)E;BX`2V5I;F4@1&%T96D@:&]C:&=E;&%D96X`2V5I;F4@1FEL=&5R+B!+
M;&EC:V5N(%-I92!A=68@(B5S(BP@=6T@;F5U92!&:6QT97(@86YZ=6QE9V5N
M+@!+96EN92!%;6%I;&OV<&9E(&%N9V5G96)E;@!+96EN92!)8V]N<R!G969U
M;F1E;BX`17,@=W5R9&4@:V5I;B!/<G0@9F5S=&=E;&5G="X`2V5I;B!/<G0@
M86YG96=E8F5N+@!+96EN92!.86-H<FEC:'0@86YG96=E8F5N+@!+96EN($YA
M;64@86YG96=E8F5N+@!+96EN92!.=6UM97(@86YG96=E8F5N+@!+96EN92!A
M;G-T]M]I9V5N($=L_&-K<VME:W-E`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!(
M5%10+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R
M="!F_'(@9&EE($E-05`M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+
M96EN(%!A<W-W;W)T(&;\<B!D:64@2V5R8F5R;W,M075T:&5N=&EF:7II97)U
M;F<@86YG96=E8F5N+@!+96EN(%!A<W-W;W)T(&;\<B!D:64@3&]G:6XM075T
M:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+96EN(%!A<W-W;W)T(&;\<B!D
M:64@4$%34U=$+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!0
M87-S=V]R="!F_'(@9&EE(%--0BU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B
M96XN`$ME:6X@4&9A9"!Z=6T@3W!E;E-33"U0<F]G<F%M;2!A;F=E9V5B96XN
M($1A<R!/<&5N4U-,+5!R;V=R86UM('=I<F0@8F5N]G1I9W0L('5M(%!+0U,M
M,3(M1&%T96X@=F5R87)B96ET96X@>G4@:_9N;F5N+@!+96EN92!A=7-S=&5H
M96YD96X@4F5G:7-T<FEE<G5N9V5N+@!+96EN(%-P96EC:&5R<&QA='HM2V]N
M=&EN9V5N="!F97-T9V5L96=T+@!+96EN92!286AM96X`2V5I;B!3:W)I<'0@
M97)Z975G="X`2V5I;B!4<F5N;GIE:6-H96X@86YG96=E8F5N+@!+96EN92!3
M96ET96X`2V5I;F4@5&5X=&4@86YG96=E8F5N`$1A=&5I(&YI8VAT(&=E9G5N
M9&5N`$ME:6YE('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9OQR(&1E;B!#86-H
M92!G969U;F1E;BX`2V5I;B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O
M<G0@86YG96)E;BX`17,@=W5R9&5N(&ME:6YE(&?\;'1I9V5N(%A-3"U$871E
M;B!Z=7+\8VMG96=E8F5N`$ME:6YE(%=E<G1E`$ME:6YE(%9E<G-I;VYS;G5M
M;65R(&EN(&1E<B!/<FEG:6YA;&MO;F9I9W5R871I;VX@9V5F=6YD96XN($5R
M;F5U97)N(%-I92!):')E($MO;F9I9W5R871I;VXN`$ME:6YE(%9E<G-I;VYS
M;G5M;65R(&EN($EH<F5R($MO;F9I9W5R871I;VX@9V5F=6YD96XN($5R;F5U
M97)N(%-I92!):')E($MO;F9I9W5R871I;VXN`$ME:6YE`$ME:6YS("A3=&%N
M9&%R9"!B96YU='IE;BD`3F]R9&ES8V@@*$E33RTX.#4Y+3$P*0!.;W)F;VQK
M:6YS96P`3O9R9&QI8VAE($AE;6ES<&AE<F4`3O9R9&QI8VAE($UA<FEA;F5N
M`$YO<G=E9V5N`$?\;'1I9R!B:7,`1_QL=&EG(&%B`$ME:6X@5F5R>F5I8VAN
M:7,`56YG;&5I8V@`3FEC:'0@:6UP;&5M96YT:65R="X`3FEC:'0@9F5S=&=E
M;&5G=`!.:6-H="!U;G1E<G-T_'1Z="X`3F]T:7IE;@!.:6-H=',@86YZ=7IE
M:6=E;BP@8FET=&4@>G5R_&-K9V5H96XN`$1I97-E($5M86EL861D<F5S<V4@
M8F5N86-H<FEC:'1I9V5N`$YO=F5M8F5R`%IA:&P`06YZ86AL(&1E<B!:96EC
M:&5N`$%N>F%H;"!D97(@4W!A;'1E;@!!;GIA:&P@9&5R(%IE:6QE;@!+96EN
M92!.=6UM97)N(&;\<B!D:64@5F5R=&5I;&5R;&ES=&4@86YG96=E8F5N+@!/
M2P!/8FIE:W0`3V)J96MT97)S=&5L;&5R`$]K=&%L>F%H;`!/:W1O8F5R`$9I
M;'1E<B!F_'(@86YS=/;?:6=E($EN:&%L=&4`0OQR;P!):'(@;F5U97,@4&%S
M<W=O<G0@;75S<R!S:6-H('9O;B!):')E;2!A;'1E;B!U;G1E<G-C:&5I9&5N
M+@!!;'1E<R!087-S=V]R=`!&86QS8VAE<R!A;'1E<R!087-S=V]R="X`3VUA
M;@!.=7(@24U!4"U397)V97(@=6YT97)S=/QT>F5N(&=E;65I;G-A;64@3W)D
M;F5R+@!.86-H<FEC:'0@;G5R(&UA<FMI97)E;@!.=7(@86YS=/;?:6=E($=L
M_&-K<VME:W-E`$YU<B!E:6YE($5M86EL+4%D<F5S<V4@97)L875B="X`3G5R
M(&1E<B!"97-I='IE<B!O9&5R(&1E<B!3>7-T96UA9&UI;FES=')A=&]R(&MA
M;FX@9&5N($)E<VET>F5R(&]D97(@9&EE($)E<VET>F5R<F5C:'1E(.1N9&5R
M;@!);B!N975E;2!&96YS=&5R(/9F9FYE;@!/<&5N4U-,+49E:&QE<CH@4VEG
M;FEE<G1E(%,O34E-12U$871E;B!K;VYN=&5N(&YI8VAT(&5X=')A:&EE<G0@
M=V5R9&5N+@!$:65S96X@3&EN:R!I;B!E:6YE;2!N975E;2!&96YS=&5R(/9F
M9FYE;@!"971R:65B<WES=&5M`$5I;G-T96QL=6YG96X`16EN<W1E;&QU;F=E
M;B!Z=7(@4VMR:7!T+4%K='5A;&ES:65R=6YG`$5I;G-T96QL=6YG96X@9OQR
M("5S`$YU;6UE<FEE<G1E($QI<W1E`$]R9V%N:7-A=&EO;@!/<F=A;FES871I
M;VYS86)T96EL=6YG`$]R9V%N:7-I97)E;@!/<FEG:6YA;'9O<FQA9V4@9&5R
M($%N=V5N9'5N9P!/<FEG:6YA;'9O<FQA9V4@:6X@)7,Z`%-O;G-T:6=E`$%N
M9&5R92!);F9O<FUA=&EO;F5N`$%N9&5R92!%:6YS=&5L;'5N9V5N`-QB97)S
M:6-H=`!"97-I='IE<G)E8VAT90!004TM075T:&5N=&EF:7II97)U;F<@:7-T
M(&YI8VAT('9E<F;\9V)A<BX`4$5!4CHZ36%I;"U"86-K96YD`$1I9VET86QE
M(%!'4"U5;G1E<G-C:')I9G0`4$=0+79E<G-C:&S\<W-E;'1E($1A=&5N`-9F
M9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L`$UI="!01U`@=6YT97)Z96EC:&YE
M=&4O=F5R<V-H;/QS<V5L=&4@1&%T96X`4$A0($-O9&4`4$A0(%-H96QL`%9O
M<FUI='1A9W,@;&5I8VAT97(@4F5G96X`3F%C:&UI='1A9W,@4F5G96X`3F%C
M:&UI='1A9W,@4V-H875E<@!.86-H;6ET=&%G<R!38VAN964`3F%C:&UI='1A
M9W,@4V-H;F5E<V-H875E<@!.86-H;6ET=&%G<R!3;VYN90!.86-H;6ET=&%G
M<R!'97=I='1E<@!$:64@4$]325@M17)W96ET97)U;F<@9F5H;'0`7U!(4"!3
M:&5L;`!);FYE;F%B<W1A;F0`4&%K:7-T86X`4&%L874`0F5S971Z=&4@4&%L
MY'-T:6YE;G-I<V-H92!'96)I971E`%!A;F%M80!087!U82U.975G=6EN96$`
M4&%R86=U87D`5&5I;'=E:7-E($)E=_9L:W0`4&%S<W=O<G0`4&%S<W=O<G0@
M97)F;VQG<F5I8V@@9V7D;F1E<G0N`$9A;'-C:&5S(%!A<W-W;W)T`$ME:6X@
M4&%S<W=O<G0@9OQR(&1I92!2041)55,M075T:&5N=&EF:7II97)U;F<@86YG
M96=E8F5N+@!087-S=V]R="!M:70@0F5S=.1T:6=U;F<`4&%S<W=O<G0Z`%!A
M<W-W;W)T.B``1&EE(%!A<W-W]G)T97(@;?QS<V5N(&=L96EC:"!S96EN+@!%
M:6YF_&=E;@!6;VX@9&5R(%IW:7-C:&5N86)L86=E(&5I;F;\9V5N`%!F860`
M075S<W1E:&5N9&4@4F5G:7-T<FEE<G5N9V5N.@!097)S;VYE;@!0<F]Z96YT
M`%=A<G1U;F=S87)B96ET96X@9'5R8VAF_&AR96X`5V%R='5N9W-A<F)E:71E
M;B!N86-H(&1E<B!!;FUE;&1U;F<@9'5R8VAF_&AR96X_`%)E8VAT90!296-H
M="`B)7,B('=U<F1E(&YI8VAT(&=E;/9S8VAT+@!:=6=R:69F('9E<G=E:6=E
M<G0`4F5C:'1E`%)E8VAT979E<G=A;'1U;F<`4&5R<_9N;&EC:&4@06YG86)E
M;@!097)U`$AA=7-T:65R90!0:&EL:7!P:6YE;@!496QE9F]N`$9O=&]S`%!I
M=&-A:7)N`%!I>&5L`%!L871T:&5I=&5N`$)I='1E(&ML:6-K96X@4VEE(&EN
M(&5I;F4@6F5L;&4`0FET=&4@8F5S=.1T:6=E;B!3:64L(&1A<W,@4VEE(&1I
M97-E<R!%;&5M96YT(&SV<V-H96X@;?9C:'1E;CH`0FET=&4@8F5TY'1I9V5N
M(%-I92P@9&%S<R!3:64@9&5N($QI;FL@=F]N(&1I97-E;2!%;&5M96YT(&5N
M=&9E<FYE;B!M]F-H=&5N+@!":71T92!E:6YE;B!-;VYA="!U;F0@96EN($IA
M:'(@86YG96)E;BX`0FET=&4@9V5B96X@4VEE(&5I;F5N($YA;65N(&;\<B!D
M:64@;F5U92!+871E9V]R:64@86XZ`$)I='1E(&5I;F4@9_QL=&EG92!)4"U!
M9')E<W-E(&5I;F=E8F5N+@!":71T92!G96)E;B!3:64@96EN(&?\;'1I9V5S
M($1A='5M(&%N.R#\8F5R<'+\9F5N(%-I92!D:64@6F%H;"!D97(@5&%G92!I
M;B!D96T@36]N870N`$)I='1E(&5I;F5N(&?\;'1I9V5N(%IE:71W97)T(&5I
M;F=E8F5N+@!":71T92!G96)E;B!3:64@9&5N($YA;65N(&;\<B!D96X@;F5U
M96X@3W)D;F5R(&%N.@!":71T92!G96)E;B!3:64@96EN92!:=7-A;6UE;F9A
M<W-U;F<@26AR97,@4')O8FQE;7,@86XN`$)I='1E(&=E8F5N(%-I92!):')E
M;B!"96YU='IE<FYA;65N('5N9"!):'(@4&%S<W=O<G0@86X`0FET=&4@;&5S
M96X@4VEE('-I8V@@9&5N(&9O;&=E;F1E;B!497AT('-O<F=FY&QT:6<@9'5R
M8V@N(%-I92!-W%-314X@9&EE<V5N($)E9&EN9W5N9V5N('IU<W1I;6UE;BP@
M=V5N;B!3:64@9&EE<V5S(%-Y<W1E;2!B96YU='IE;B!M]F-H=&5N+@!":71T
M92!D96X@;F5U96X@2V%T96=O<FEE;F%M96X@96EN9V5B96XZ`%!O;&5N`%!O
M;&ET:6L`56UF<F%G96X`4&]R='5G86P`4&]S:71I;VYI97)U;F<@9&EE<V4@
M0FEL9&5S`%!O<VET:6]N:65R=6YG(&1I97-E<B!486)E;&QE`%-E;F1E;B!A
M;B!D:65S96X@3W)D;F5R("AN:6-H="!D=7)C:"!)34%0*0!.:65D97)S8VAL
M86<@:6X@9&5N(&QE='IT96X@)7,@4W1U;F1E*&XI.B``3FEE9&5R<V-H;&%G
M<RT\8G(@+SYW86AR<V-H96EN;&EC:&ME:70`4')E9G-?;&1A<#H@1&EE(&)E
M;O9T:6=T92!,1$%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N
M+@!0<F5F<U]S97-S:6]N.B!$:64@8F5N]G1I9W1E(%-E<W-I;VXM17)W96ET
M97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$QU9G1D<G5C:P!,=69T9')U
M8VL@875F(%-E96CV:&4Z(`!,=69T9')U8VLZ(`!6;W)S8VAA=0!%:6YE(%9O
M<G-C:&%U(&1E<R!":6QD97,@:6X@96EN96T@;F5U96T@1F5N<W1E<B!A;GIE
M:6=E;@!6;VAE<FEG92!%:6YS=&5L;'5N9V5N`$1O:W5M96YT(&1R=6-K96X`
M4')I=F%T97(@4V-H;/QS<V5L`%!R;V)L96UE`%!R;V)L96UB97-C:')E:6)U
M;F<`4')O:F5K=&4`3F%C:&9R86=E=&5X=`#69F9E;G1L:6-H97(@4V-H;/QS
M<V5L`$%L9V]R:71H;75S(&1E<R#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<P!)
M;F9O<FUA=&EO;F5N('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L`$1A<R#V
M9F9E;G1L:6-H92]P<FEV871E(%-C:&S\<W-E;'!A87(@:V]N;G1E(&YI8VAT
M(&5R<W1E;&QT('=E<F1E;BX`4'5E<G1O(%)I8V\`3F%C:')I8VAT96X@96YD
M9_QL=&EG(&SV<V-H96X`2V%T87(`06)F<F%G90!3<&5I8VAE<G!L871Z+4MO
M;G1I;F=E;G0`UF9F96YT;&EC:&5R(%)302!38VAL_'-S96P@*"5D($)I="D`
M7T=R=6YD`$%U<W=A:&QK;F]P9@!296=E;@!&<OQH(%)E9V5N`%-PY'1E<B!2
M96=E;@!296=E;G-C:&%U97(`4V-H;F5E<F5G96X`4F5G96X@:6X@4V-H;F5E
M(/QB97)G96AE;F0`1VS\8VMS:V5K<P!697)HY&QT;FES`$QE<V5N`$YA8VAR
M:6-H=&5N(&QE<V5N`"5S('=I<FML:6-H(&SV<V-H96X_($1I97-E<B!6;W)G
M86YG(&MA;FX@;FEC:'0@<OQC:V?D;F=I9R!G96UA8VAT('=E<F1E;BX`1&%T
M96X@9&5S($)E;G5T>F5R<R`E<R!W:7)K;&EC:"!L]G-C:&5N/R!$:65S97(@
M5F]R9V%N9R!K86YN(&YI8VAT('+\8VMGY&YG:6<@9V5M86-H="!W97)D96XN
M`$5M<&9A;F=E;B`H4F5C96EV960I`%=E:71E<FQE:71E;B!A;@!&_&AR="!L
M971Z=&4@06MT:6]N(&5R;F5U="!A=7,`06MT=6%L:7-I97)E`$1Y;F%M:7-C
M:&4@365N_&5L96UE;G1E(&%K='5A;&ES:65R96XZ`%!O<G1A;&%N<VEC:'0@
M86MT=6%L:7-I97)E;CH`4F5G=6SD<F5R($%U<V1R=6-K`%)E9W5LY')E<B!!
M=7-D<G5C:P!-:70@9F]L9V5N9&5M($=R=6YD(&%B;&5H;F5N`%9E<F)I;F1U
M;F=S+4)R;W=S97(`06MT=6%L:7-I97)E;@!"96UE<FMU;F=E;@!%;G1F97)N
M=&4@4V5R=F5R`%-E<G9E<F%D<F5S<V4@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.@!%;G1F97)N96X`0FQO8VL@;/9S8VAE;@!3<&%L=&4@;/9S
M8VAE;@!&;W)M871I97)U;F<@96YT9F5R;F5N`%!A87(@;/9S8VAE;@!'97-P
M96EC:&5R=&5S(%-K<FEP="!A=7,@9&5M('1E;7!O<N1R96X@5F5R>F5I8VAN
M:7,@96YT9F5R;F5N+@!%;G1F97)N90!$:65S97,@16QE;65N="!A=7,@9&5M
M($1O:W5M96YT(&5N=&9E<FYE;@!"96YU='IE<B!L]G-C:&5N`$)E;G5T>F5R
M(&SV<V-H96XZ("5S`$%N9G)A9V4@:V]N;G1E(&YI8VAT(&)E86YT=V]R=&5T
M('=E<F1E;BX@6G5R_&-K9V5G96)E;F5R($9E:&QE<F-O9&4Z(`!$97(@9V5W
M_&YS8VAT92!$:65N<W0@:V]N;G1E(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`
M(B5S(B!W=7)D92!I;B!D97(@2V]N9FEG=7)A=&EO;B!F_'(@)7,@;FEC:'0@
M86YG96=E8F5N+@`B)7,B('=U<F1E(&EN(&1E<B!61E,M2V]N9FEG=7)A=&EO
M;B!N:6-H="!A;F=E9V5B96XN`"(E<R(@=W5R9&4@:6X@9&5R($MO;F9I9W5R
M871I;VX@;FEC:'0@86YG96=E8F5N+@!.;W1W96YD:6=E<R!&96QD`$YE=2!V
M97)S96YD970@86X@*%)E<V5N="!T;RD`3F5U('9E<G-E;F1E="!V;VX@*%)E
M<V5N="UF<F]M*0!:=7+\8VMS971Z96X`4&%S<W=O<G0@>G5R_&-K<V5T>F5N
M`%-E='IE;B!3:64@26AR(%!A<W-W;W)T('IU<OQC:P!,971Z=&4@06)F<F%G
M92!E:6YF_&=E;@!%<F=E8FYI<W-E`%IU<OQC:R!Z=7(@1FEL=&5R;&ES=&4`
M6G5R_&-K('IU($5I;G-T96QL=6YG96X`6G5R_&-K('IU<B!296=E;&QI<W1E
M`$YE=65S(%!A<W-W;W)T(&5R;F5U="!E:6YG96)E;@!2Z75N:6]N`$MO;F9I
M9W5R871I;VX@>G5R_&-K<V5T>F5N`%=94TE764<M161I=&]R($5I;G-T96QL
M=6YG96X`4N1T<V5L`%)E8VAT<P!296-H=&4@W&)E<G-C:')I9G0`4F5C:'1E
M(%=E<G1E`%]:96EL96YE:6=E;G-C:&%F=&5N+BXN`%)O;&QE`%)U;>1N:65N
M`%5M(#$X,+`@9')E:&5N`$YA8V@@;&EN:W,@9')E:&5N`$YA8V@@<F5C:'1S
M(&1R96AE;@!:96EL96YE:6=E;G-C:&%F=&5N`%IE:6QE;F5I9V5N<V-H869T
M96X`6F5I;&5N.@!296=E;`!296=E;"!K;W!I97)T`%)E9V5L(&=E;/9S8VAT
M`%)E9V5L(&1E86MT:79I97)T`%)E9V5L(&%K=&EV:65R=`!296=E;&YA;64`
M4F5G96PZ`%)E9V5L;@!286AM96X@>G=I<V-H96X@86QL96X@6F5I;&5N('5N
M9"!3<&%L=&5N`%)A:&UE;B!N=7(@>G=I<V-H96X@4W!A;'1E;@!286AM96X@
M;G5R('IW:7-C:&5N(%IE:6QE;@!3=&%R=&5N`%)U<W-I<V-H92!&]G)D97)A
M=&EO;@!2=6%N9&$`4R]-24U%(&MR>71O9W)A<&AI<V-H92!5;G1E<G-C:')I
M9G0`36ET(%,O34E-12!V97)S8VAL_'-S96QT92!.86-H<FEC:'0`4T%33"U!
M=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!335,M5F5R
M<V%N9`!344P@4VAE;&P`4U%,+4%N=V5I<W5N9R!Z=7(@06)F<F%G92!D97(@
M5V5R=&4`4U-(`%-405)45$Q3(&9E:&QG97-C:&QA9V5N.B`H)7,I("5S`$52
M1D],1P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!U
M;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E('5N9"!-:7%U96QO
M;@!386EN="!6:6YC96YT('5N9"!D:64@1W)E;F%D:6YE;@!';&5I8VAE<B!2
M86AM96X@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE('5N9"!0
M<FEN8VEP90!3871E;&QI=&5N<')O=FED97(`4V%U9&DM07)A8FEE;@!3<&5I
M8VAE<FX`(B5S(B!S<&5I8VAE<FX`)7,@<W!E:6-H97)N`$5I;G-T96QL=6YG
M96X@<W!E:6-H97)N`$5I;G-T96QL=6YG96X@<W!E:6-H97)N`$5R>F5U9W1E
M($MO;F9I9W5R871I;VX@86QS(%!(4"U3:W)I<'0@:6T@=&5M<&]RY')E;B!6
M97)Z96EC:&YI<R!):')E<R!397)V97)S('-P96EC:&5R;BX`)7,M2V]N9FEG
M=7)A=&EO;B!G97-P96EC:&5R="X`1&%S($%K='5A;&ES:65R=6YG<W-K<FEP
M="!W=7)D92!I;B`B)7,B(&=E<W!E:6-H97)T+@!697)E:6YZ96QT92!'97=I
M='1E<@!7:7-S96YS8VAA9G0`4VMR:7!T`%-K<FEP="U!:W1U86QI<VEE<G5N
M9P!3:W)I<'0@;FEC:'0@86MT=6%L:7-I97)T+@!3:W)I<'0@97)F;VQG<F5I
M8V@@86MT:79I97)T+@!3:W)I<'0@97)F;VQG<F5I8V@@86MT:79I97)T+@!3
M=6-H90!3=6-H;6%S8VAI;F5N`$=E;&5S96X`1&%T96EE;B!A=7-WY&AL96X`
M1&%T=6T@875S=^1H;&5N`%?D:&QE;B!3:64@96EN($9E;&0@875S`$AI;GIU
M>G5F_&=E;F1E($=R=7!P96X@875S=^1H;&5N`$YE=65N($)E<VET>F5R(&%U
M<W?D:&QE;@!397)V97(@875S=^1H;&5N`$AI;GIU>G5F_&=E;F1E;B!"96YU
M='IE<B!A=7-WY&AL96X`06QL92!A=7-WY&AL96X`3&5G96X@4VEE(&%L;&4@
M1&%T=6US:V]M<&]N96YT96X@9F5S="X`3V)J96MT(&%U<W?D:&QE;@!+96EN
M96X@875S=^1H;&5N`%II96QO<F1N97(@875S=^1H;&5N`%?D:&QE;B!3:64@
M9&EE(&)E;O9T:6=T96X@6F5I8VAE;B!A=7,@9&5N(&IE=V5I;&EG96X@1F5L
M9&5R;B!A=7,N($1A;FX@:_9N;F5N(%-I92!D:65S92!A=7,@9&5M(%1E>'1F
M96QD(&MO<&EE<F5N('5N9"!I;B!):')E($YA8VAR:6-H="!E:6YF_&=E;BX`
M5^1H;&5N(%-I92!D87,@1&%T=6US=')E;FYZ96EC:&5N.@!7Y&AL96X@4VEE
M(&1A<R!$871U;7-F;W)M870Z`%?D:&QE;B!3:64@9&EE($ED96YT:73D="P@
M9&EE(%-I92#D;F1E<FX@;?9C:'1E;CH`5^1H;&5N(%-I92!D87,@6F5I='1R
M96YN>F5I8VAE;CH`5^1H;&5N(%-I92!D87,@6F5I=&9O<FUA=#H`5^1H;&5N
M(%-I92!Z=V5I('IU<V%M;65N9V5H]G)I9V4@1F5L9&5R(&%U<RX`5^1H;&5N
M(%-I92!E:6X@1F%R8G-C:&5M82X`5^1H;&5N(%-I92!):')E(&)E=F]R>G5G
M=&4@4W!R86-H93H`0F5N=71Z97)D969I;FEE<G1E($MO<&9E:6YT<N1G90!0
M<F]B;&5M8F5R:6-H="!A8G-C:&EC:V5N`%--4R!V97)S8VAI8VME;@!!8G-E
M;F1E<B`H4V5N9&5R*0!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B
M:65N('5N9"!-;VYT96YE9W)O`%-E<FEE;FYU;6UE<@!397)V97)D871E;B!U
M;F?\;'1I9R!O9&5R(&YI8VAT('9E<F;\9V)A<BX`4V5S<W-I;VYV97)W86QT
M=6YG`%-E<W-I;VXM240@86)G96QA=69E;BX`4VET>G5N9V5N`$%U<W=A:&PM
M4V%T>@!,96=E;B!3:64@9&EE($5I;G-T96QL=6YG96X@9F5S="P@9&EE(&5S
M($EH;F5N(&5R;&%U8F5N($EH<B!087-S=V]R="!Z=7+\8VMZ=7-E='IE;BP@
M9F%L;',@<VEE(&5S(&5I;FUA;"!V97)G97-S96X@<V]L;'1E;BX`3&5G96X@
M4VEE(&5N=&9E<FYT92!397)V97(@9F5S="P@875F(&1I92!3:64@=F]N($EH
M<F5M(%!O<G1A;"!A=7,@>G5G<F5I9F5N(&WV8VAT96XN`%?D:&QE;B!3:64@
M26AR92!B979O<GIU9W1E(%-P<F%C:&4L(%IE:71Z;VYE('5N9"!$871U;7-E
M:6YS=&5L;'5N9V5N+@!,96=E;B!3:64@9&%S(&1I92!3=&%R=&%N=V5N9'5N
M9RP@9&%S($9A<F)S8VAE;6$L(&1I92!396ET96YA:W1U86QI<VEE<G5N9R!U
M;F0@86YD97)E($%N>F5I9V5E:6YS=&5L;'5N9V5N(&9E<W0N`$1I92!%:6YS
M=&5L;'5N9V5N('=U<F1E;B!E<F9O;&=R96EC:"!G97-P96EC:&5R="X`2V]N
M9FEG=7)A=&EO;@!!:W1U86QI<VEE<G5N9W-S:W)I<'1E('-I;F0@=F5R9OQG
M8F%R`$UE:')E<F4@<&%S<V5N9&4@3W)T92!M:70@9&EE<V5M(%!A<F%M971E
M<CH@`%-E>6-H96QL96X`16EN:V%U9@!+=7)Z92!:=7-A;6UE;F9A<W-U;F<`
M4V]L;&5N(%1A<W1E;FMO;6)I;F%T:6]N96X@9OQR(&1I92!M96ES=&5N($QI
M;FMS(&%K=&EV:65R="!W97)D96X_`%IE:6=E;@!!:W1I=F5S(%-K<FEP="!A
M;GIE:6=E;@!!:W1U96QL97,@4VMR:7!T(&%N>F5I9V5N`%5N=&5R<V-H:65D
M92!Z=VES8VAE;B!D97(@86MT=65L;&5N('5N9"!D97(@9V5R861E(&5R>F5U
M9W1E;B!+;VYF:6=U<F%T:6]N(&%N>F5I9V5N+@!!;GIE:6=E;BP@=V%N;B!D
M:64@;&5T>G1E($%N;65L9'5N9R!E<F9O;&=T(&ES=#\`17)H86QT96X@9&5S
M($]R:6=I;F%L<R!E<FWV9VQI8VAE;@!!=7-WY&AL97(@86YZ96EG96X`5V5R
M:WIE=6=L96ES=&4@9OQR(%1A8F5L;&5N(&%N>F5I9V5N/P!$87,@)7,M365N
M_"!A=68@9&5R(&QI;FME;B!396ET92!A;GIE:6=E;C\`1&EA;&]G(&;\<B!4
M86)E;&QE;GIE;&QE;F5I9V5N<V-H869T96X@86YZ96EG96X`1&EA;&]G(&;\
M<B!486)E;&QE;F5I9V5N<V-H869T96X@86YZ96EG96X`1&EA;&]G(&;\<B!4
M86)E;&QE;GIE:6QE;F5I9V5N<V-H869T96X@86YZ96EG96X`1&EA;&]G(&;\
M<B!":6QD96EG96YS8VAA9G1E;B!A;GIE:6=E;@!(;V-H;&%D96X@97)M]F=L
M:6-H96X`4V-H875E<@!&<OQH(%-C:&%U97(`4W#D=&5R(%-C:&%U97(`4V-H
M875E<B!I;B!D97(@56UG96)U;F<`5F5R:VQE:6YE<FX`5F5R:VQE:6YE<FX@
M;V1E<B!V97)S8VAI96)E;B!3:64@97)S="!D:64@8F5N86-H8F%R=&5N($)L
M]F-K90!3:65R<F$@3&5O;F4`4F5G:7-T<FEE<F5N`%-I9VYA='5R`%-I9VYA
M='5R86QG;W)I=&AM=7,`5F5R96EN9F%C:'1E(%-P86UF:6QT97(@=V5R9&5N
M('9O;2!A:W1U96QL96X@1FEL=&5R=')E:6)E<B!N:6-H="!U;G1E<G-T_'1Z
M="X`4VEN9V%P=7(`1W+VWV4`5V%R='5N9W-A<F)E:71E;B#\8F5R<W!R:6YG
M96X`4VQO=V%K96D`4VQO=V5N:65N`%-C:&YE90!38VAN965S8VAA=65R`%-C
M:&YE97-C:&%U97(`1G+\:"!38VAN965S8VAA=65R`%-PY'1E<B!38VAN965S
M8VAA=65R`%-C:&YE96CV:&4Z(`!38VAN965M96YG92!A;',@5V%S<V5R.B``
M4V]L;VUO;FEN<V5L;@!3;VUA;&EE;@!,:65D97(@)B!'961I8VAT90!!=7-W
M86AL(&1E<B!3;W)T:65R<F5I:&5N9F]L9V4`57)S<')U;F=S861R97-S90!3
M_&1A9G)I:V$`4_QD975R;W#D:7-C:"`H25-/+3@X-3DM,RD`4_QD9V5O<F=I
M96X@=6YD(&1I92!3_&1L:6-H96X@4V%N9'=I8VAI;G-E;&X`4_QD;&EC:&4@
M2&5M:7-P:&5R90!!8G-T86YD('IW:7-C:&5N(&%U9F5I;F%N9&5R(&9O;&=E
M;F1E;B!:96QL96X`06)S=&%N9"!Z=VES8VAE;B!);FAA;'0@=6YD(%)A:&UE
M;B!V;VX@6F5L;&5N`$%B<W1A;F1H86QT97(`06)S=&%N9`!!8G-TY&YD90!3
M<&%N:65N`%-P86T`4W!A;69I;'1E<@!3;VYD97)Z96EC:&5N+45I;F=A8F4`
M6F5L;&4@=&5I;&5N`%-P86QT92!T96EL96X`6F5I;&4@=&5I;&5N`%-P;W)T
M`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G1J86AR`$)U;F1E
M<W-T86%T(&]D97(@4')O=FEN>@!3=&%T=7,`5V5I=&5R92#<8F5R<'+\9G5N
M9R!A;FAA;'1E;BP@=V5N;B!D:65S92!296=E;"!Z=71R:69F=#\`4W!E:6-H
M97)F;W)M870`4W1R8=]E`$1U<F-H9V5S=')I8VAE;@!:96EC:&5N;&ES=&4`
M1&]M86EN(&%U<R!D97(@061R97-S92!E;G1F97)N96X`4W1I;"!;0U-370!3
M;P!5;G1E<G9E<GIE:6-H;FES("(E<R(@;FEC:'0@9V5F=6YD96XN`$)E=')E
M7V9F(&1E<B!!8G=E<V5N:&5I='-N86-H<FEC:'0Z`$)E=')E9F8`0F5T<F5F
M9CH`06)S8VAI8VME;@!$:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E(&;\<B`B
M)7,B('=U<F1E(&%B9V5S8VAI8VMT+B!3:64@:_9N;F5N('-I8V@@;F]C:"!N
M:6-H="!A;FUE;&1E;BP@<V]L86YG92!D:64@06YF<F%G92!N;V-H(&YI8VAT
M(&)E<W3D=&EG="!W=7)D92X`5&EE9F=E<W1E;&QT`$5R9F]L9P`B)7,B('=U
M<F1E(&5R9F]L9W)E:6-H(&AI;GIU9V5F_&=T+@!$871E;B!D97,@0F5N=71Z
M97)S("(E<R(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N`"(E<R(@=W5R
M9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N`"(E<R(@=W5R9&4@97)F;VQG<F5I
M8V@@9V5L]G-C:'0N`$MO;F9I9W5R871I;VX@97)F;VQG<F5I8V@@>G5R_&-K
M9V5S971Z="X@4V5I=&4@;F5U(&QA9&5N+"!U;2!D:64@Q&YD97)U;F=E;B!A
M;GIU>F5I9V5N+@!"86-K=7`@9&5R($MO;F9I9W5R871I;VX@97)F;VQG<F5I
M8V@@9V5S<&5I8VAE<G0N`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E<R!E
M<F9O;&=R96EC:"!G97-P96EC:&5R="X`(B5S(B!W=7)D92!E<F9O;&=R96EC
M:"!A:W1U86QI<VEE<G0`)7,@=W5R9&4@97)F;VQG<F5I8V@@9V5S<&5I8VAE
M<G0`4W5D86X`6G5S86UM96YF87-S=6YG`%-O;FYE;F%U9F=A;F<`4V]N;F5N
M=6YT97)G86YG`%-O;FYI9P!3;VYN96YA=69G86YG`%-O;FYE;F%U9B]U;G1E
M<F=A;F<`4V]N;F5N875F9V%N9SH@`%-O;FYE;G5N=&5R9V%N9P!3;VYN96YU
M;G1E<F=A;F<Z(`!(;V-H9V5S=&5L;'0`4W5P<&]R=`!3=7)I;F%M`$YA8VAN
M86UE`%-V86QB87)D('5N9"!*86X@36%Y96X`4W=A<VEL86YD`%-C:'=E9&5N
M`%-C:'=E:7H`4WEN8VAR;VYI>F%T:6]N<VQO9R!G96SV<V-H=`!3>6YC34P`
M1F]R;6%T9F5H;&5R(&EN(%-U8VAB96=R:69F96X`07)A8FES8VAE(%)E<'5B
M;&EK(%-Y<FEE;@!'97=I='1E<@!'97=I='1E<B!U;F0@5VEN9&EG`$=E=VET
M=&5R`$9R_&@@1V5W:71T97(`5%-6+41A=&5I`%1A8F5L;&5N96EG96YS8VAA
M9G1E;@!486)E;&QE`%1A8F5L;&5N96EG96YS8VAA9G1E;@!486EW86X`5&%I
M=V%N+"!C:&EN97-I<V-H92!0<F]V:6YZ`%1A9'-C:&EK:7-T86X`5F5R96EN
M:6=T92!297!U8FQI:R!486YS86YI80!::65L.@!!=69G86)E;@!496QE9F]N
M;G5M;65R`%1E;7!E<F%T=7(@9&5R(&QE='IT96X@4W1U;F1E.B``5&5M<&5R
M871U<@!496UP97)A='5R.B``5&5M<&5R871U<CQB<B`O/B@E<TUA>"5S+R5S
M36EN)7,I("9D96<[)7,`5F]R;&%G92`B)7,B(&YI8VAT(&=E9G5N9&5N+@!6
M;W)L86=E;G9E<G=A;'1U;F<`5&5X=`!.=7(@5&5X=`!!=7-R:6-H='5N9P!4
M97AT($]B96X`1&\`5&AA:6SD;F1I<V-H("A425,M-C(P*0!4:&%I;&%N9`!$
M:64@1E10+45X=&5N<VEO;B!I<W0@;FEC:'0@=F5R9OQG8F%R+@!$:64@0VAR
M;VYI:R!S=&5H="!N:6-H="!Z=7(@5F5R9OQG=6YG+@!$:64@2&]R9&4O2V]L
M86(@26YT96=R871I;VYS9G5N:W1I;VYE;B!U;G1E<G-T_'1Z96X@(B5S(B!N
M:6-H=`!$:64@24U34"U,;V=D871E:2!K;VYN=&4@;FEC:'0@97)S=&5L;'0@
M=V5R9&5N+@!$:64@36%I;G1E;F%N8V4Z.B!+;&%S<V4@:V]N;G1E(&YI8VAT
M(&=E;&%D96X@=V5R9&5N`$1A<R!%:6YS=&5L;'5N9V5N+49E;G-T97(@:7-T
M(&=E<V-H;&]S<V5N('=O<F1E;BX@06)B<G5C:"X`1&EE($%D<F5S<V4@(B5S
M(B!W=7)D92!Z=2!):')E<B!!=7-S8VAL=7-S;&ES=&4@:&EN>G5G96;\9W0N
M`$1I92!!9')E<W-E("(E<R(@=W5R9&4@>G4@26AR97(@4&]S:71I=FQI<W1E
M(&AI;GIU9V5F_&=T+@!$97(@061M:6YI<W1R871O<B!M=7-S(&5I;B!P97)M
M86YE;G1E<R!296-H=&4M0F%C:V5N9"!E:6YR:6-H=&5N+"!W96YN(%-I92!D
M:64@4F5C:'1E=F5R=V%L='5N9R!N=71Z96X@;?9C:'1E;BX`3G5R('5N=&5N
M`$1I92!)1"U.=6UM97(@9&5S($MO;G1A:W1S('=U<F1E(&YI8VAT(&%N9V5B
M96XL('=A<B!L965R(&]D97(@:V]N;G1E(&EN(&1E<B!$871E;F)A;FL@;FEC
M:'0@9V5F=6YD96X@=V5R9&5N+@!$97(@2V]N=&%K="!W=7)D92!E<F9O;&=R
M96EC:"!):')E;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T+@!$97(@4$=0+5-I
M9VYA='5R8FQO8VL@=VER9"!B96[V=&EG="P@=6T@9&EE('5N=&5R>F5I8VAN
M971E($YA8VAR:6-H="!Z=2#\8F5R<'+\9F5N+@!$:64@240M3G5M;65R(&1E
M<B!697)T96EL97)L:7-T92!W=7)D92!N:6-H="!A;F=E8F5N+"!W87(@;&5E
M<B!O9&5R(&MO;FYT92!I;B!D97(@1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N
M('=E<F1E;BX`1&EE(%9E<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5G
M96)E;BX`06YT=V]R="!D97,@5')E:6)E<G,Z(`!$:64@5F5R<V-H;/QS<V5L
M=6YG<V9U;FMT:6]N96X@8F5N]G1I9V5N(&5I;F4@<VEC:&5R92!397)V97)V
M97)B:6YD=6YG+@!$:64@1&%T96D@)7,@<V]L;'1E(&5I;F5N("5S($5I;G1R
M86<@96YT:&%L=&5N+@!$:64@1&%T96D@)7,@<V]L;'1E(&5I;FEG92`E<R!%
M:6YT<N1G92!E;G1H86QT96XN`$1I92!$871E:2!K86YN(&YI8VAT(&%U9B!S
M:6-H('-E;&)S="!K;W!I97)T('=E<F1E;BX`1&EE($1A=&5I(&5N=&AI96QT
M(&ME:6YE($1A=&5N+@!(:65R('-I;F0@9&EE($MO<&9E:6YT<N1G92!F_'(@
M9&EE<V4@;65S<V%G92]R9F,X,C(@3F%C:')I8VAT+@!$97(@5F]L;&)I;&1M
M;V1U<R!V97)U<G-A8VAT(&%U9B!'<G5N9"!V;VX@1F5H;&5R;B!I;2!);G1E
M<FYE="!%>'!L;W)E<B!B96MA;FYT97)M8=]E;B!0<F]B;&5M92!M:70@9&EE
M<V5M($)R;W=S97(L(&1I92!W:7(@;FEC:'0@=6UG96AE;B!K]FYN96XN(%5N
M=&5R(%5M<W3D;F1E;B!E<FAA;'1E;B!3:64@96EN92!F96AL97)H869T92!!
M;GIE:6=E+"!F96AL96X@161I=&]R9G5N:W1I;VYE;BP@;V1E<B!D97(@0G)O
M=W-E<B!S=/QR>G0@86(N($%U9B!E:6YE;2!7:6YD;W<@.7@@4WES=&5M('=E
M<F1E;B!3:64@=F5R;75T;&EC:"!E:6YE("=!;&QG96UE:6YE(%-C:'5T>G9E
M<FQE='IU;F<G(&5R:&%L=&5N('5N9"!M_'-S96X@9&5N(%)E8VAN97(@;F5U
M('-T87)T96XN7&Y<;E-I92!W=7)D96X@9V5W87)N="X@0FET=&4@9'+\8VME
M;B!3:64@875F($]++"!W96YN(%-I92!N;V-H(&EM;65R(&1E;B!6;VQL8FEL
M9&UO9'5S('9E<G=E;F1E;B!M]F-H=&5N+@!$:64@261E;G1I=.1T("(E<R(@
M=W5R9&4@9V5L]G-C:'0N`$YU<B!L:6YK<P!$97(@3W)T(&1E<R!';G501RU0
M<F]G<F%M;7,@;75S<R!D97(@0W)Y<'1?<&=P.CH@2VQA<W-E(/QB97)G96)E
M;B!W97)D96XN`$1I92!.86-H<FEC:'0@;6ET(&1E;2!"971R969F("(E,R1S
M(BP@9&EE(&%M("4Q)',@86X@)3(D<R!G97-C:&EC:W0@=W5R9&4L(&ES="!A
M;F=E>F5I9W0@=V]R9&5N+@I$87,@:&5IWW0@;FEC:'0L(&1A<W,@9&EE($YA
M8VAR:6-H="!A=6-H(&=E;&5S96X@;V1E<B!V97)S=&%N9&5N('=U<F1E+@!.
M86UE(&;\<B!D96X@3&EN:R!Z=7(@3F%C:')I8VAT96YE<G-T96QL=6YG`$1I
M92!!;GIA:&P@9&5R($9E;&1E<B!M=7-S(&%L<R!:86AL(&%N9V5G96)E;B!W
M97)D96XN`$1A<R!/<&5N4U-,+4UO9'5L('=I<F0@9OQR(&1I92!(;W)D95]#
M<GEP=%]S;6EM93HZ($ML87-S92!B96[V=&EG="X`1&EE($)E;G5T>F5R96EN
M<W1E;&QU;F<@(B5S(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N
M+"!W96EL(&EH<F4@1&%T96X@9&EE(&UA>&EM86P@97)L875B=&4@1W+VWV4@
M_&)E<G-C:')E:71E;@!$87,@4')O9W)A;6T@9OQR(&1I92!!;GIE:6=E(&1I
M97-E<R!$871E:71Y<',@*"5S*2!W=7)D92!N:6-H="!G969U;F1E;BX`1&%S
M($%N9OQH<G5N9W-Z96EC:&5N(&UU<W,@86QS(&5I;GIE;&YE<R!:96EC:&5N
M(&%N9V5G96)E;B!W97)D96XN`$YU<B!L:6YK<R!U;F0@<F5C:'1S`$YU<B!R
M96-H=',`1&%S(%1R96YN>F5I8VAE;B!M=7-S(&%L<R!E:6YZ96QN97,@6F5I
M8VAE;B!A;F=E9V5B96X@=V5R9&5N+@!$97(@4V5R=F5R("(E<R(@=W5R9&4@
M96YT9F5R;G0N`$1E<B!397)V97(@(B5S(B!W=7)D92!G97-P96EC:&5R="X`
M1&EE(%)E9VES=')I97)U;F=S86YF<F%G92!V;VX@)7,@=W5R9&4@96YT9F5R
M;G0N`$1I92!A;F=E9V5B96YE(%IE:6QE("@E9"D@97AI<W1I97)T(&YI8VAT
M+@!$:64@=&5M<&]RY')E($1A=&5I("(E<R(@97AI<W1I97)T(&YI8VAT+@!$
M97(@5&5X="P@9&5N(%-I92!A;F=E9V5B96X@:&%B96XL(&5N='-P<FEC:'0@
M;FEC:'0@9&5M(%1E>'0@875F(&1E;2!":6QD<V-H:7)M+@!.=7(@;V)E;B!U
M;F0@=6YT96X`3G5R(&]B96X`1&EE(&AO8VAG96QA9&5N96X@1&%T96X@<VEN
M9"!N86-H(&1E;2!L971Z=&5N(%-C:')I='0@=F5R;&]R96X@9V5G86YG96XN
M`$1I92!H;V-H9V5L861E;F4@1&%T96D@:V]N;G1E(&YI8VAT(&=E<W!E:6-H
M97)T('=E<F1E;BX`1&5R('=E871H97(N8V]M($)L;V-K(&ES="!N:6-H="!V
M97)F_&=B87(N`%1H96UE;BU697)Z96EC:&YI<R`B)7,B(&YI8VAT(&=E9G5N
M9&5N+@!%<R!S:6YD(&ME:6YE($5I;G-T96QL=6YG96X@=F5R9OQG8F%R+@!%
M<R!G:6)T(&ME:6YE(&%N>F5I9V)A<F5N($YA8VAR:6-H=&5N=&5I;&4N`$1I
M97-E<R!&96QD(&5N=&CD;'0@>G4@=FEE;&4@6F5I8VAE;BX@4VEE(&AA8F5N
M("5S(%IE:6-H96X@86YG96=E8F5N.R!3:64@;?QS<V5N('=E;FEG97(@86QS
M("5S(&%N9V5B96XN`$)E:6T@2&EN>G5F_&=E;B!V;VX@(B5S(B!Z=6T@4WES
M=&5M(&ES="!E:6X@4')O8FQE;2!A=69G971R971E;CH@)7,`0F5I;2!,]G-C
M:&5N(&1E<B!$871E;B!V;VX@0F5N=71Z97(@(B5S(B!I<W0@96EN(%!R;V)L
M96T@875F9V5T<F5T96XZ(`!"96EM($SV<V-H96X@=F]N("(E<R(@875S(&1E
M;2!3>7-T96T@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B``0F5I;2!!
M:W1U86QI<VEE<F5N('9O;B`B)7,B(&ES="!E:6X@4')O8FQE;2!A=69G971R
M971E;CH@)7,`0F5I;2!(;V-H;&%D96X@9&5R($1A=&5I(&ES="!E:6X@1F5H
M;&5R(&%U9F=E=')E=&5N+B`E<R!W=7)D92!N:6-H="!H;V-H9V5L861E;BX`
M0F5I;2!(;V-H;&%D96X@9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E
M=')E=&5N+B`E<R!W87(@9W+VWV5R(&%L<R!D:64@;6%X:6UA;"!E<FQA=6)T
M92!'<O;?92`H)60@0GET97,I+@!"96EM($AO8VAL861E;B!D97(@1&%T96D@
M:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN("5S('=U<F1E(&YU<B!T96EL
M=V5I<V4@:&]C:&=E;&%D96XN`$)E:6T@06MT:79I97)E;B!D97,@4VMR:7!T
M<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`0F5I;2!$96%K=&EV:65R
M96X@9&5S(%-K<FEP=',@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN`$)E
M:6T@06YZ96EG96X@9&EE<V5S($YA8VAR:6-H=&5N=&5I;',@:7-T(&5I;B!&
M96AL97(@875F9V5T<F5T96XN`$)E:6T@26UP;W)T:65R96X@9&5R($MO;G1A
M:W1D871E;B!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`0F5I;2!);7!O
M<G1I97)E;B!D97(@:4-A;&5N9&%R($1A=&5N(&ES="!E:6X@1F5H;&5R(&%U
M9F=E=')E=&5N+@!$87,@2V]N9FEG=7)A=&EO;G,M1F]R;75L87(@96YT:&EE
M;'0@96EN96X@1F5H;&5R+B!6:65L;&5I8VAT(&AA8F5N(%-I92!E:6X@4&9L
M:6-H=&9E;&0@;&5E<B!G96QA<W-E;BX`0F5I;2!!=7-F_&AR96X@9&5R(&%N
M9V5G96)E;F5N($%D<F5S<V)U8VAF=6YK=&EO;B!I<W0@96EN($9E:&QE<B!A
M=69G971R971E;BX@0FET=&4@=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C
M:"!E:6YM86PN`$)E:2!D97(@06MT=6%L:7-I97)U;F<@9&5R($MO;G1A:W1D
M971A:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92!V97)S
M=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`0F5I(&1E<B!!:W1U
M86QI<VEE<G5N9R!D97(@5F5R=&5I;&5R;&ES=&4@:7-T(&5I;B!&96AL97(@
M875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO
M8V@@96EN;6%L+@!$:65S97(@24U!4"U397)V97(@=6YT97)S=/QT>G0@:V5I
M;F4@9V5M96EN<V%M96X@3W)D;F5R+@!$:65S('-C:&5I;G0@:V5I;B!G_&QT
M:6=E<R!205(M07)C:&EV('IU('-E:6XN`$1I97,@<V-H96EN="!K96EN(&?\
M;'1I9V5S(%I)4"U!<F-H:78@>G4@<V5I;BX`1&EE<R!S8VAE:6YT(&ME:6YE
M(&?\;'1I9V4@2V%R=&5N;G5M;65R('IU('-E:6XN`$1I97-E<B!4<F5I8F5R
M(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C
M:"!D96X@0VQI8VMA=&5L;"U'871E=V%Y("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&UI="!(:6QF92!D97(@2%144"U!4$DN`$1I97-E<B!4<F5I8F5R(&5R
M;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D
M96X@5TE.+4=A=&5W87D@*&AT='`Z+R]W:6YP;&,N8V]M*2!M:70@2&EL9F4@
M9&5R($A45%`M05!)+@!$:65S97(@5')E:6)E<B!E<FQA=6)T(&1A<R!697)S
M8VAI8VME;B!V;VX@3F%C:')I8VAT96X@9'5R8V@@9&5N('-M<S)M86EL+4=A
M=&5W87D@*&AT='`Z+R]S;7,R;6%I;"YC;VTI(&UI="!(:6QF92!D97(@2%14
M4"U!4$DN`$1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N
M('9O;B!.86-H<FEC:'1E;B!P97(@4TU44"!D=7)C:"!D96X@5F]D869O;F4M
M271A;&EE;BU'871E=V%Y(&%U<W-C:&QI9=]L:6-H(&%N(%9O9&%F;VYE+4YU
M;6UE<FXN($1A9OQR('=I<F0@96EN($5M86EL:V]N=&\@8F5I(%9O9&%F;VYE
M($ET86QI96X@*&AT='`Z+R]W=W<N,3DP+FET*2!B96[V=&EG="X`1&EE<V5S
M($9E;&0@:7-T(&YO='=E;F1I9RX`1&EE<V5S($9E;&0@9&%R9B!N=7(@9V%N
M>F4@6F%H;&5N(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@9&%R9B!N=7(@6F%H
M;&5N('5N9"!E:6YE;B!0=6YK="!E;G1H86QT96XN`$1I97-E<R!&96QD(&1A
M<F8@;G5R($]K=&%L>F%H;&5N(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@;75S
M<R!E:6YE(&MO;6UA+2!O9&5R(&QE97)Z96EC:&5N9V5T<F5N;G1E($QI<W1E
M('9O;B!G86YZ96X@6F%H;&5N(&5N=&AA;'1E;@!$:65S97,@1F5L9"!M=7-S
M(&5I;F4@9_QL=&EG92!:86AL(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@;75S
M<R!E:6YE;B!&87)B=V5R="!I;2!H97AA9&5Z:6UA;&5N(%)'0BU&;W)M870@
M96YT:&%L=&5N+"!Z+B!"+B`G(S$R,S1A9B<N`$1I97-E<R!&;W)M=6QA<B!W
M=7)D92!B97)E:71S('9E<F%R8F5I=&5T+@!$:65S(&ES="`E<RX`1&EE(&ES
M="!E:6X@2V]L86(M1W)O=7!W87)E+4]B:F5K="X@56T@9&EE<V5S($]B:F5K
M="!A;GIU>F5I9V5N+"!B96[V=&EG96X@4VEE(&5I;B!%;6%I;'!R;V=R86UM
M+"!D87,@9&%S($MO;&%B+4=R;W5P=V%R92U&;W)M870@=6YT97)S=/QT>G0N
M($5I;F4@3&ES=&4@<V]L8VAE<B!0<F]G<F%M;64@9FEN9&5N(%-I92!U;G1E
M<B`E<P!$:65S92!.86-H<FEC:'0@=W5R9&4@:6X@96EN96T@6F5I8VAE;G-A
M='H@*"5S*2!E<G-T96QL="P@9&5R(&YI8VAT($EH<F5M(&5I9V5N96X@96YT
M<W!R:6-H="X`1&EE<V4@6F%H;"!M=7-S(#$@;V1E<B!G<O;?97(@<V5I;BX`
M1&EE<V5R(%-E<G9E<B!K86YN(%I)4"T@=6YD($=:25`M1&%T96EN(&YI8VAT
M(&5N='!A8VME;BX`1&EE<V5S(%-Y<W1E;2!I<W0@>G5R(%IE:70@9&5A:W1I
M=FEE<G0N`$1I97-E<B!797)T(&UU<W,@96EN92!:86AL('-E:6XN`$1I97-E
M<R!&96YS=&5R(&UU<W,@=F]N(&5I;F5M($5I;G-T96QL=6YG96XM1F5N<W1E
M<B!G9?9F9FYE="!W97)D96X`1&]N;F5R`%1I8VME=',`6F5I=`!:96ET97)F
M87-S=6YG`%IE:71F;W)M870`6F5I=&%U<W=A:&P`5&EM;W(M3&5S=&4`5&ET
M96P`5&ET96P@*%1O;VQT:7`I.@!!;@!(86QT96X@4VEE(&)E:6T@2VQI8VME
M;B!3=')G(&)Z=RX@*%!#*2!#;VUM86YD("A-86,I(&=E9'+\8VMT+"!U;2!M
M96AR97)E($5I;G1RY&=E(&%U<WIU=^1H;&5N+@!!;CH`2&5U=&4`6G4@2%1-
M3"U1=65L;&-O9&4@=6US8VAA;'1E;@!4;V=O`%1O:V5L874`36]R9V5N`%1O
M;F=A`%IU('9I96QE('5N9_QL=&EG92!!;FUE;&1E=F5R<W5C:&4@:6X@9&5N
M(&QE='IT96X@36EN=71E;BX`3V)E;@#$==]E<G-T97(@4F%H;65N("A?=&]P
M*0#<8F5R<V5T>G5N9V5N`%1R:6YI9&%D('5N9"!4;V)A9V\`5V%H<B!O9&5R
M(&9A;'-C:`!$:0!4=6YE<VEE;@!4_')K96D`5/QR:VES8V@@*$E33RTX.#4Y
M+3DI`%1U<FMM96YI<W1A;@!4=7)K<RT@=6YD($-A:6-O<VEN<V5L;@!4=79A
M;'4`26AR92!!=7-W86AL.B``558M26YD97@Z(`!(;VUE<&%G90!54DP@26AR
M97,@4VMR:7!T<R!F_'(@9&5N(%9E<G-A;F1S=&%T=7-B97)I8VAT`$%D<F5S
M<V4Z`%5G86YD80!5:W)A:6YE`$%U9B!D87,@5D93+59E<GIE:6-H;FES(&MO
M;FYT92!N:6-H="!Z=6=E9W)I9F9E;B!W97)D96XN`$1I92!Z=7/D='IL:6-H
M96X@0F5N=71Z97)I;F9O<FUA=&EO;F5N(&MO;FYT96X@8F5I(&1E<B!296=I
M<W1R:65R=6YG(&YI8VAT(&AI;GIU9OQG="!W97)D96XN`$1I92!:=6=R:69F
M<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`B)7,B(&MO;FYT96X@;FEC:'0@
M9V7D;F1E<G0@=V5R9&5N+@!$:64@6G5G<FEF9G-R96-H=&4@9OQR(&1I92!6
M1E,M1&%T96D@)7,O)7,@:V]N;G1E;B!N:6-H="!G9>1N9&5R="!W97)D96XN
M`$5S(&MA;FX@;FEC:'0@:6X@5F5R>F5I8VAN:7,@)7,@9V5W96-H<V5L="!W
M97)D96XN`$1I92!'<O;?92!V;VX@(B5S(B!K;VYN=&4@;FEC:'0@8F5S=&EM
M;70@=V5R9&5N+@!$:64@1W+VWV4@=F]N("(E<R\E<R(@:V]N;G1E(&YI8VAT
M(&)E<W1I;6UT('=E<F1E;BX`5F5R8FEN9'5N9R!Z=6T@4U%,(%-E<G9E<B!K
M86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;BX`4U-,+59E<F)I;F1U;F<@
M:V]N;G1E(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;BX`1&EE(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@:V]P:65R="!W97)D96XN`$1A<R!61E,M5F5R>F5I
M8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@!$87,@
M5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN
M`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`
M1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!A;F=E;&5G
M="!W97)D96XN`$QE97)E(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@86YG96QE
M9W0@=V5R9&5N+@!$:64@1&%T96X@:V]N;G1E;B!N:6-H="!D96MO;7!R:6UI
M97)T('=E<F1E;BX`(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M+"!D87,@5F5R>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(N`"(E<R(@:V%N;B!N
M:6-H="!G96SV<V-H="!W97)D96XZ("5S+@`E<R!K;VYN=&4@;FEC:'0@9V5L
M]G-C:'0@=V5R9&5N+"!D87,@5F5R>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(`
M1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@<F5K=7)S:78@9V5L
M]G-C:'0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H
M="!G96SV<V-H="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E
M(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N`$1I92!61E,M1&%T96D@(B5S
M(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!$:64@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1A<R!61E,M5F5R>F5I
M8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!$87,@
M5D93(&MO;FYT92!N:6-H="!R96MU<G-I=B!G96SV<V-H="!W97)D96XZ("5S
M+@!$87,@86MT=65L;&4@5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&)E<W1I
M;6UT('=E<F1E;BX`1&EE(%IE<G1I9FEK871D971A:6QS(&MO;FYT96X@;FEC
M:'0@875S9V5L97-E;B!W97)D96X`1&5R("5S+51R96EB97(@:V]N;G1E(&YI
M8VAT(&=E;&%D96X@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H
M="!V97)S8VAO8F5N('=E<F1E;BX`1&EE(%9&4RU$871E:2`B)7,B(&MO;FYT
M92!N:6-H="!G9?9F9FYE="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E
M(&YI8VAT('IU;2!"97-C:')E:6)E;B!G9?9F9FYE="!W97)D96XN`$1I92!6
M1E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX`1&%S($%R
M8VAI=B!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!$:64@5D93+41A
M=&5I(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;B`H9FEL97-I>F4H*2!F
M96AL9V5S8VAL86=E;BDN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E
M;&5S96X@=V5R9&5N("AG971&:6QE4VEZ92@I(&9E:&QG97-C:&QA9V5N*2X`
M1&EE($1A=&5I(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;CH@`$1A<R!V
M9G-R;V]T+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E
M;BX`)7,@:V]N;G1E(&YI8VAT(&YA8V@@)7,@=6UB96YA;FYT('=E<F1E;CH@
M1&%S(%II96QV97)Z96EC:&YI<R!E>&ES=&EE<G0@8F5R96ET<P!$87,@5D93
M+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N+@!$
M87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R
M9&5N.B`E<RX`1&EE(%9&4RU$871E:2`B)7,B(&MO;FYT92!N:6-H="!U;6)E
M;F%N;G0@=V5R9&5N+@!$:64@5D93+41A=&5I("5S+R5S(&MO;FYT92!N:6-H
M="!U;6)E;F%N;G0@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H
M="!U;6)E;F%N;G0@=V5R9&5N+@`B;6MI<V]F<R(@:V]N;G1E(&YI8VAT(&%U
M<V=E9OQH<G0@=V5R9&5N+@!$:65S97,@5V]R9"U$;VMU;65N="!LY'-S="!S
M:6-H(&YI8VAT(&%N>F5I9V5N`$1I92!61E,M1&%T96D@(B5S(B!K;VYN=&4@
M;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT
M92!N:6-H="!G97-C:')I96)E;B!W97)D96X@*&-O<'DH*2!F96AL9V5S8VAL
M86=E;BDN`$1I92!61E,M1&%T96X@:V]N;G1E;B!N:6-H="!G97-C:')I96)E
M;B!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E<V-H<FEE
M8F5N('=E<F1E;BP@9&%S(%-P96EC:&5R<&QA='HM2V]N=&EN9V5N="!W_')D
M92#\8F5R<V-H<FET=&5N+@!5;G1E<G-T<FEC:&5N`,1N9&5R=6YG96X@<OQC
M:V?D;F=I9R!M86-H96X`36%C:'0@9&EE(&QE='IT92!!:W1I;VX@<OQC:V?D
M;F=I9P!5;F?\;'1I9V4@4OQC:VUE;&1U;F<@=F]M(%-E<G9E<B!B96EM($AE
M<G-T96QL96X@9&5R(%9E<F)I;F1U;F<Z(`!5;F5R=V%R=&5T92!!;G1W;W)T
M(&1E<R!397)V97)S(&%U9CH@`$YI8VAT('IU9V5O<F1N970`56YI8V]D92`H
M551&+3@I`%9E<F5I;FEG=&4@07)A8FES8VAE($5M:7)A=&4`5F5R96EN:6=T
M97,@2_9N:6=R96EC:`!697)E:6YI9W1E(%-T86%T96X`2VQE:6YE<F4@06UE
M<FEK86YI<V-H92#<8F5R<V5E:6YS96QN`$5I;FAE:71E;@!5;F)E:V%N;G0`
M56YB96MA;FYT92!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;F)E:V%N
M;G1E(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$5S('=U<F1E(&5I
M;B!U;F)E:V%N;G1E<B!/<G0@86YG96=E8F5N+@!5;F)E:V%N;G1E<B!"96YU
M='IE<FYA;64@;V1E<B!087-S=V]R="X`3&EN:R!V;VT@86MT=65L;&5N($5L
M96UE;G0@96YT9F5R;F5N`%5N8F5N86YN=`!!=7,@4VEC:&5R:&5I='-G<OQN
M9&5N(&3\<F9E;B!U;F%U=&]R:7-I97)T92!3:W)I<'1E(&YI8VAT(&%U<V-H
M;F5I9&5N+"!K;W!I97)E;B!U;F0@96EN9OQG96XN($ML:6-K96X@4VEE(&%U
M9B!/2RP@=6T@96EN96X@2&EN=V5I<R!A=68@;6]Z:6QL82YO<F<@86YG97IE
M:6=T('IU(&)E:V]M;65N+"!D97(@8F5S8VAR96EB="P@=VEE(%-I92!E:6YE
M;2!3:W)I<'0@9&5N(%IU9W)I9F8@875F(&1I92!:=VES8VAE;F%B;&%G92!E
M<FQA=6)E;B!K]FYN96XN`$9A<F)E('IU<OQC:W-E='IE;@!%<G=E:71E<G5N
M9R!N:6-H="!U;G1E<G-T_'1Z=`!!:W1U86QI<VEE<G5N9P`E<R!A:W1U86QI
M<VEE<F5N`$)E;G5T>F5R(&%K='5A;&ES:65R96X`(B5S(B!W=7)D92!A:W1U
M86QI<VEE<G0N`$%K='5A;&ES:65R=6YG<W-K<FEP="!G96SV<V-H="X`2&]C
M:&QA9&5N`$1I92!+;VYF:6=U<F%T:6]N<V1A=&5I96X@86QL97(@06YW96YD
M=6YG96X@=W5R9&5N(&%U9B!D96X@4V5R=F5R(&AO8VAG96QA9&5N+@!'<BX@
M;&%T96EN:7-C:&4@0G5C:'-T86)E;@!'<BX@<O9M:7-C:&4@6F%H;&5N`%5R
M=6=U87D`06MT=65L;&4@8F5N=71Z96XZ("5S`%-33"!B96YU='IE;@!":71T
M92!A=7-F_&QL96XL('=E;FX@4VEE(&5I;F5N(&%N9&5R96X@0F5N=71Z97)N
M86UE;B]087-S=V]R="!F_'(@9&5N($E-4U`M4V5R=F5R(&AA8F5N+@!"96YU
M='IE<@!"96YU='IE<B`E<R!I<W0@9OQR("5S(&YI8VAT(&%U=&]R:7-I97)T
M+@!"96YU='IE<G9E<G=A;'1U;F<`0F5N=71Z97)E:6YS=&5L;'5N9V5N`$)E
M;G5T>F5R<F5G:7-T<FEE<G5N9P!$:64@0F5N=71Z97)R96=I<W1R:65R=6YG
M('=U<F1E(&%U9B!D:65S96T@4WES=&5M(&1E86MT:79I97)T+@!"96YU='IE
M<FMO;G1O(&YI8VAT(&=E9G5N9&5N`$)E;G5T>F5R;F%M90!$97(@0F5N=71Z
M97)N86UE("(E<R(@97AI<W1I97)T(&)E<F5I=',N`$)E;G5T>F5R;F%M93H`
M0F5N=71Z97)N86UE.B``0F5N=71Z97(@9&5S(%-Y<W1E;7,Z`%5S8F5K:7-T
M86X`1&%S(%9&4RU697)Z96EC:&YI<R!E>&ES=&EE<G0@;FEC:'0N`$%B=V5S
M96YH96ET`$%B=V5S96YH96ET<VYA8VAR:6-H="!"96%R8F5I=&5N`$%B=V5S
M96YH96ET<VYA8VAR:6-H=&5N('=E<F1E;B!V;VT@86MT=65L;&5N($9I;'1E
M<G1R96EB97(@;FEC:'0@=6YT97)S=/QT>G0N`%!A<W-E;F1E(&=E9G5N9&5N
M92!/<G1E.B``1_QL=&EG:V5I=`!797)T(&EN($UI;G5T96X@=F]N(&IE='IT
M(&%N+@!$97(@5V5R="!I<W0@_&)E<B!D97(@;6%X:6UA;&5N($SD;F=E('9O
M;B`E<RX`5V5R=&4`5V5R=&4L(&%U<R!D96YE;B!A=7-G97?D:&QT('=E<F1E
M;B!K86YN`%9A;G5A='4`1')E:&5N9`!696YE>G5E;&$`W&)E<G!R_&9U;F<@
M9F5H;&=E<V-H;&%G96X@+2!D:65S92!.86-H<FEC:'0@:_9N;G1E(&UA;FEP
M=6QI97)T('=O<F1E;B!S96EN+@!697)S:6]N`%9E<G-I;VYS:V]N=')O;&QE
M`$%U<W)I8VAT=6YG`%9E<G1I:V%L97(@26YN96YA8G-T86YD`%9E<G1I:V%L
M.@!396AR($AO8V@`5FEE=&YA;0!6:65T;F%M97-I<V-H("A625-#24DI`"5S
M(&%N>F5I9V5N`$5I;F4@97AT97)N92!796)S96ET92!A;GIE:6=E;@!!;GIE
M:6=E;B!A;',@)7,`0G)I=&ES8VAE($IU;F=F97)N:6YS96QN`$%M97)I:V%N
M:7-C:&4@2G5N9V9E<FYI;G-E;&X`4VEC:'0`4VEC:'0Z(`!6;V1A9F]N92!)
M=&%L:65N('!E<B!33510`%=!4DY53D<`5T%23E5.1R$A(2!,UE-#2$5.(%-)
M12!$05,@4TM225!4($U!3E5%3$P@0553("5S+@!724X@_&)E<B!(5%10`%=A
M;&QI<R!U;F0@1G5T=6YA`%=A<FYU;F<`36D`5V5T=&5R=F]R:&5R<V%G90!7
M971T97)D871E;B!V;VX`5V5A=&AE<BYC;VT`5V5B`%=E8G-I=&4`5_9C:&5N
M=&QI8V@`5VEL;&MO;6UE;@!7:6QL:V]M;65N(&)E:2`E<P!7:6QL:V]M;65N
M+"`E<P!797-T975R;W#D:7-C:"`H25-/+3@X-3DM,2D`5V5S=&5U<F]PY&ES
M8V@@*$E33RTX.#4Y+3$U*0!797-T<V%H87)A`%!?;W-I=&EV9V5L:7-T971E
M($%D<F5S<V5N.@!796QC:&4@06YW96YD=6YG('-O;&P@)7,@;F%C:"!D96T@
M06YM96QD96X@86YG97IE:6=E;C\`5V5L8VAE<R!4<F5N;GIE:6-H96X@=VER
M9"!V97)W96YD970_`%=E;&-H92!!;F;\:')U;F=S>F5I8VAE;B!W97)D96X@
M=F5R=V5N9&5T/P!7:&5R96ES+4%U<W1R86QI82U+87)T90!796QC:&4@4&AA
M<V5N`%=E;&-H92!0;'5G:6YS(&;\<B!D96X@5UE325=91RU%9&ET;W(@<V]L
M;&5N(&%K=&EV:65R="!W97)D96X_`%!O<VET:79L:7-T90!0;W-I=&EV;&ES
M=&4@0F5A<F)E:71E;@!0;W-I=&EV;&ES=&5N('=E<F1E;B!V;VT@86MT=65L
M;&5N($9I;'1E<G1R96EB97(@;FEC:'0@=6YT97)S=/QT>G0N`%!O<VET:79G
M96QI<W1E=&4@061R97-S96X`0G)E:71E`$)R96ET92!I;B!#4U,M16EN:&5I
M=&5N`$)R96ET92!D97,@)7,M365N_',@;&EN:W,@*'=I<FMS86T@;F%C:"!D
M97(@;N1C:'-T96X@06YM96QD=6YG*3H`5&%B96QL96YB<F5I=&4`16EN:&5I
M=`!"<F5I=&4Z`%=I:VD`5VEN9`!&<OQH(%=I;F0`5VEN9&=E<V-H=VEN9&EG
M=&ME:70@:6X@2VYO=&5N`%=I;F0Z`%=I;F0Z(`!796ES:&5I=`!7=6YS8VAZ
M971T96P`07)B96ET`$%D<F5S<V4@9V5S8VCD9G1L:6-H`%1E;&5F;VX@9V5S
M8VCD9G1L:6-H`$9A;'-C:&4@06YZ86AL(&%N($9E;&1E<FX@:6X@6F5I;&4@
M)60N("5D(&5R=V%R=&5T+"`E9"!G969U;F1E;BX`1F%L<V-H92!!;GIA:&P@
M86X@1F5L9&5R;BX@)60@97)W87)T970L("5D(&=E9G5N9&5N+@!5;F?\;'1I
M9V5R($]F9G-E="`E9"!B96EM($QE<V5N(&1E<B!61E,M1&%T96DN`%@M4')I
M;W)I='D`475E<G9E<G=E:7-E`%@M4W!A;2U,979E;`!8+5-P86TM4V-O<F4`
M6"U3<&%M+5-T871U<P!8-3`Y=C,@1V5N97)E;&QE($5I;G-C:'+D;FMU;F<`
M6#4P.78S($5R=V5I=&5R=&5R(%-C:&S\<W-E;'IW96-K`%@U,#EV,R!!;'1E
M<FYA=&EV97(@3F%M92!D97,@6F5R=&EF:6MA=&EN:&%B97)S`%@U,#EV,R!)
M9&5N=&ETY'0@9&5S(%IE<G1I9FEK871S8VAL_'-S96QS`%@U,#EV,R!%<G=E
M:71E<G5N9V5N`$I*`$I*2DH`66%H;V\A($MA<G1E`$KD:')L:6-H`$IE;65N
M`$IA`$IA+"!I8V@@<W1I;6UE('IU`%-I92!B969I;F1E;B!S:6-H(&EM(%1E
M>'1M;V1U<RX@0F5N=71Z96X@4VEE(&1E;B!;/#Y=($MN;W!F+"!U;2!I;B!D
M96X@5UE325=)1RU-;V1U<R!Z=2!W96-H<V5L;BX`4VEE(&3\<F9E;B!N:6-H
M="!M96AR(&%L<R`E9"!";/9C:V4@97)S=&5L;&5N+@!3:64@9/QR9F5N(&YI
M8VAT(&UE:'(@86QS("5D(%)E9V5L;B!E<G-T96QL96XN`%-I92!D_')F96X@
M:V5I;F4@96EG96YE;B!296=E;&X@97)S=&5L;&5N(&]D97(@8F5A<F)E:71E
M;BX`4VEE('-I;F0@;FEC:'0@86YG96UE;&1E="X`4VEE(&3\<F9E;B!D87,@
M6F5I8VAE;B`G7"<@;FEC:'0@:6X@26AR96T@3F%M96X@=F5R=V5N9&5N+@!3
M:64@:&%B96X@:V5I;F4@9_QL=&EG92!%;6%I;&%D<F5S<V4@86YG96=E8F5N
M+@!3:64@:&%B96X@:V5I;F4@1F5L9&5R(&%U<R!D96X@:6UP;W)T:65R=&5N
M($1A=&5N(&1E;B!E;G1S<')E8VAE;F1E;B!&96QD97)N(&EN("5S('IU9V5O
M<F1N970N`%-I92!W=7)D96X@86)G96UE;&1E="X`4VEE(&AA8F5N(&5I;F4@
M;F5U92!.86-H<FEC:'0@97)H86QT96X`4VEE(&W\<W-E;B!E:6YE(&?\;'1I
M9V4@36]B:6QT96QE9F]N;G5M;65R(&%N9V5B96XL(&YU<B!A=7,@6F%H;&5N
M('5N9"!G9V8N(&5I;F5M("(K(B!F_'(@:6YT97)N871I;VYA;&4@5F]R=V%H
M;&5N(&)E<W1E:&5N9"X`4VEE(&W\<W-E;B!E:6YE;B!G_&QT:6=E;B!797)T
M(&%N9V5G96)E;BX`4VEE(&W\<W-E;B!E:6X@1&%T851R964M0F%C:V5N9"!K
M;VYF:6=U<FEE<F5N+"!U;2!296=I<W1R:65R=6YG96X@=F5R=V5N9&5N('IU
M(&OV;FYE;BX`4VEE(&W\<W-E;B!E:6X@5D93+4)A8VME;F0@:V]N9FEG=7)I
M97)E;BX`4VEE(&W\<W-E;B!D87,@4')O8FQE;2!B97-C:')E:6)E;BP@=6T@
M9&5N($)E<FEC:'0@86)Z=7-C:&EC:V5N+@!3:64@;?QS<V5N(&1I92!54DP@
M86YG96)E;BP@875F(&1I92!D:65S97(@3&EN:R!V97)W96ES96X@<V]L;`!3
M:64@;?QS<V5N(&5R<W0@9&5N('IU(&5N=&9E<FYE;F1E;B!397)V97(@875S
M=^1H;&5N+@!3:64@;?QS<V5N(&5I;F5N($)E;G5T>F5R;F%M96X@86YG96)E
M;BP@9&5S<V5N($1A=&5N(&=E;/9S8VAT('=E<F1E;B!S;VQL96XN`%-I92!M
M_'-S96X@96EN96X@>G4@;/9S8VAE;F1E;B!"96YU='IE<FYA;65N(&%N9V5B
M96XN`%-I92!M_'-S96X@;6EN9&5S=&5N<R!E:6YE($5M86EL861R97-S92!A
M;F=E8F5N+"!F_'(@9&EE($%B=V5S96YH96ET<VYO=&EZ96X@86MT:79I97)T
M('=E<F1E;B!S;VQL96XN`%-I92!M_'-S96X@96EN96X@:&EN>G5Z=6;\9V5N
M9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BX`4VEE(&W\<W-E;B!D96X@>G4@
M86MT=6%L:7-I97)E;F1E;B!"96YU='IE<FYA;65N(&%N9V5B96XN`%-I92!M
M_'-S96X@96EN92!!:W1I;VX@86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE;B!N
M975E;B!+871E9V]R:65N86UE;B!A;F=E8F5N+@!3:64@;?QS<V5N(&5I;F4@
M271A;&EE;FES8VAE(%1E;&5F;VYN=6UM97(@86YG96)E;@!):')E("5S+5-E
M<W-I;VX@:7-T(&%B9V5L875F96XN($)I='1E(&UE;&1E;B!3:64@<VEC:"!E
M<FYE=70@86XN`$EH<F4@16UA:6PM061R97-S90!):')E(%9O;CH@061R97-S
M93H`26AR92!!;F=A8F5N`$EH<F4@26YT97)N971A9')E<W-E(&AA="!S:6-H
M(&=EY&YD97)T+"!S96ET(%-I92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B!H
M86)E;BX@6G5M(%-C:'5T>B!):')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@
M<VEC:"!N974@86YM96QD96XN`$EH<B!.86UE`$EH<B!!=71H96YT:69I>FEE
M<G5N9W-S>7-T96T@97)L875B="!K96EN($AI;GIU9OQG96X@=F]N(&YE=65N
M($)E;G5T>F5R;BX@5V5N;B!3:64@2&]R9&4@8F5N=71Z96X@;?9C:'1E;BP@
M=6T@26AR92!"96YU='IE<B!Z=2!V97)W86QT96XL(&W\<W-E;B!3:64@96EN
M96X@86YD97)E;B!!=71H96YT:69I>FEE<G5N9W-T<F5I8F5R(&)E;G5T>F5N
M+@!):'(@075T:&5N=&EF:7II97)U;F=S<WES=&5M(&5R;&%U8G0@9&%S($%N
M>F5I9V5N(&1E<B!"96YU='IE<B!N:6-H="P@;V1E<B!D:65S92!-]F=L:6-H
M:V5I="!W=7)D92!A=7-G97-C:&%L=&5T+@!):'(@0G)O=W-E<B!H870@<VEC
M:"!A;G-C:&5I;F5N9"!G9>1N9&5R="!S96ET(%-I92!D:64@)7,M4VET>G5N
M9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C:'5T>B!):')E<B!3:6-H97)H96ET
M(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN`$EH<B!"<F]W<V5R('5N
M=&5R<W3\='IT(&1I97-E($9U;FMT:6]N(&YI8VAT+@!):'(@0G)O=W-E<B!U
M;G1E<G-T_'1Z="!D:65S92!$<G5C:V9U;FMT:6]N(&YI8VAT+B!":71T92!D
M<OQC:V5N(%-I92!3=')G+TMO;6UA;F1O("L@4"!U;2!Z=2!D<G5C:V5N+@!)
M:')E(&%K='5E;&QE(%IE:71Z;VYE.@!):')E(%-T86YD87)D:61E;G1I=.1T
M('=U<F1E(&=EY&YD97)T+@!):')E(%-T86YD87)D:61E;G1I=.1T.@!):'(@
M=F]L;'-TY&YD:6=E<B!.86UE.@!):'(@6G5G86YG(&ES="!A8F=E;&%U9F5N
M+@!):'(@;F5U97,@4&%S<W=O<G0@9OQR("5S(&QA=71E=#H@)7,`26AR92!%
M:6YS=&5L;'5N9V5N('=U<F1E;B!F_'(@9&EE($1A=65R(&1I97-E<B!3:71Z
M=6YG(&=E<W!E:6-H97)T+@!):')E($5I;G-T96QL=6YG96X@=W5R9&5N(&=E
M<W!E:6-H97)T+@!):'(@4&%S<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z=`!)
M:'(@4&%S<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z="X@4G5F96X@4VEE($EH
M<F4@16UA:6QS(&%B('5N9"!M96QD96X@4VEE('-I8V@@;6ET($EH<F5M(&YE
M=65N(%!A<W-W;W)T(&%N+@!):'(@4&%S<W=O<G0@:7-T(&%B9V5L875F96XN
M`$EH<F4@4V5R=F5R.@!*=6=O<VQA=VEE;@!:86ER90!386UB:6$`4VEM8F%B
M=V4`6FEP<'D`6UII=&%T=&5X="!V97)S=&5C:V5N70!;2V5I;B!"971R969F
M70!;4')O8FQE;6)E<FEC:'1=`%M::71A='1E>'0@86YZ96EG96X@+0!;6FET
M871T97AT(&%N>F5I9V5N("T@)7,@6F5I;&5N70!;6F5I;&4@)7,@=F]N("5S
M70!!7V1R97-S92AN*2P@86X@9&EE('=E:71E<F=E;&5I=&5T('=E<F1E;B!S
M;VQL.@!!7V1R97-S92AN*2P@86X@9&EE(&ME:6YE($%N='=O<G0@9V5S8VAI
M8VMT('=E<F1E;B!S;VQL.@!?061M:6YI<W1R871I;VX`7T%U<W-C:&QU<W-L
M:7-T90!"95]F96AL<WIE:6QE`%]$871A5')E90!:96EL92!?;/9S8VAE;@!.
M86-H<FEC:'0@:V]M<&QE='0@7VSV<V-H96X`7TIE9&4@061R97-S92!I;B!E
M:6YE<B!E:6=E;F5N(%IE:6QE(&5I;G1R86=E;CH`7U=E:71E<FQE:71U;F<`
M7T=R=7!P96X`7TAI;&9E`%]":6QD96EG96YS8VAA9G1E;BXN+@!?2V]P:65N
M(&1E<B!.86-H<FEC:'1E;B!I;B!D:65S96T@2V]N=&\@8F5L87-S96X_`$%N
M7VUE;&1E;@!!8E]M96QD96X`3&EN:R!?8F5A<F)E:71E;BXN+@!.86-H<FEC
M:'0@:6X@9&EE<V5N($]R9&YE<B!?=F5R<V-H:65B96XZ`%]-96EN92!%;6%I
M;&%D<F5S<V5N.@!?16EN<W1E;&QU;F=E;@!?4F5C:'1E`$QI;FL@7V5N=&9E
M<FYE;BXN+@!?4VMR:7!T`%]+;VYF:6=U<F%T:6]N`%]486)E;&QE;F5I9V5N
M<V-H869T96XN+BX`7T)E;G5T>F5R`$%?8G=E<V5N:&5I=`!?4&]S:71I=FQI
M<W1E`&%K=&EV`$%D<F5S<V)U8V@`061R97-S870@=6YB96MA;FYT`'5N9`!+
M86QE;F1E<@!W:6YD<W1I;&P`075S9V%B961A=&5I(&MO;FYT92!N:6-H="!E
M<G-T96QL="!W97)D96X`16EN9V%B92!K86YN(&YI8VAT(&=E]F9F;F5T('=E
M<F1E;@!K;&EC:V5N(%-I92!H:65R`%5N9_QL=&EG92!"96YU='IU;F<@9&5R
M($MO;6UA;F1O>F5I;&4`2V]N9FEG=7)A=&EO;G-F96AL97(`2W)I=&ES8VAE
M(%-Y<W1E;61A=&5I(&9E:&QT`$1A=&5N9F]R;6%T9F5H;&5R`&1E86MT:79I
M97)T("T@>G5M($%K=&EV:65R96X@86YK;&EC:V5N`&)E87)B96ET96X`16EN
M=')A9R!N:6-H="!G969U;F1E;@!F86QL96YD`$9E;&0`1&%T96D`875S("5S
M("@E<RD@;6ET("5S("5S`&+V:6<`:#H`:&@`2&]S=&YA;64@=6YB96MA;FYT
M`'-O9F]R=`!I;F%K=&EV`$EN;&EN90!%:6XM+T%U<V=A8F5F96AL97(`26YT
M97)N97(@4V]F='=A<F5F96AL97(`6F5I;&5N70!6;VX@26YG;R!E<GIE=6=T
M97,@;6%I;&1R;W`@4V-R:7!T`&5N='-P<FEC:'0`;6MI<V]F<RU&96AL97)C
M;V1E("5D(&)E:2!D97(@17)S=&5L;'5N9R!D97,@25-/+4%B8FEL9&5S+@!M
M;0!.86UE`&YI8VAT(&EM<&QE;65N=&EE<G0`3F]C:"!N:6-H="!I;7!L96UE
M;G1I97)T`$YO=&EZ8FQO8VL`;V1E<@!0<F]Z96YT`%IU9W)I9F8@=F5R=V5I
M9V5R=`!0:7AE;`!6;VX@26YG;R!E<GIE=6=T97,@<')O8VUA:6P@4V-R:7!T
M`%)E;6]T969E:&QE<B!I;2!0<F]T;VMO;&P`<W1E:6=E;F0`4V5R=FEC92!N
M:6-H="!V97)F_&=B87(`56YT97)S8VAI961E(&%N>F5I9V5N`'-M<S)E;6%I
M;"#\8F5R($A45%``<W,`9VQE:6-H8FQE:6)E;F0`4WES=&5M9F5H;&5R`$%U
M9F=A8F5N;&ES=&4`5F]R_&)E<F=E:&5N9&5R($9E:&QE<@!G96)E;B!3:64@
M9&%S(%!A<W-W;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@0F5S=.1T:6=U;F<@
M96EN`'5N:69I960`=6YB96YA;FYT`&)E;G5T>F5R9&5F:6YI97)T`'9#87)D
M`&(Z`'=E871H97(N8V]M````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O9&5?1$4O
M:&5L<"YX;6P`````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-C`Q
M,@`Q,#0Q-S,V,C<T-P`P,C$R,S,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN
M9STB:7-O+3@X-3DM,2(_/@H\(2TM("1(;W)D93H@:6YG;R]L;V-A;&4O9&5?
M1$4O:&5L<"YX;6PL=B`Q+C$N-"XR(#(P,#4O,3`O,3<@,C,Z,SDZ,#0@:F%N
M($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](F)L86-K;&ES="(@;60U
M/2(U8S$R93$V,F8V-F8V.&,V8S)D.#1C8S=C,C@P9#<Q,"(@<W1A=&4](G5P
M=&]D871E(CX*("`@(#QT:71L93Y!=7-S8VAL=7-S;&ES=&4\+W1I=&QE/@H@
M("`@/'!A<F$^26X@9&5R($%U<W-C:&QU<W-L:7-T92!B969I;F1E;B!S:6-H
M(&%L;&4@16UA:6QA9')E<W-E;BP@=F]N(&1E;F5N"B`@("!3:64@=VES<V5N
M+"!D87-S(&1I97-E($EH;F5N($YA8VAR:6-H=&5N('-C:&EC:V5N+"!D:64@
M4VEE(&YI8VAT(&EN($EH<F5M"B`@("!0;W-T9F%C:"!H86)E;B!M]F-H=&5N
M+CPO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8FQA8VML:7-T+6%C
M=&EO;B(@;60U/2(Q-S`Q9C0Q-3)C,#DP,#`T93-B-#`R,#4T,SEF.3$P."(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y!=7-S8VAL=7-S;&ES=&4Z
M($%K=&EO;CPO=&ET;&4^"B`@("`\<&%R83Y$:65S92!!:W1I;VX@;&5G="!F
M97-T+"!W87,@;6ET($YA8VAR:6-H=&5N(&=E<V-H:65H="P@9&EE(%-I92!V
M;VX*("`@(&5I;F5M(&)L;V-K:65R=&5N($%B<V5N9&5R(&5R:&%L=&5N+B!-
M]F=L:6-H92!!:W1I;VYE;B!S:6YD"B`@("`B3/9S8VAE;B(@=6YD(")697)S
M8VAI96)E;B(N(%=E;FX@4VEE("),]G-C:&5N(B!A=7-WY&AL96XL"B`@("!W
M:7)D(&1I92!.86-H<FEC:'0@9V5L]G-C:'0L(&)E=F]R('-I92#\8F5R:&%U
M<'0@875S9V5L:65F97)T"B`@("!W=7)D92X@36ET(")697)S8VAI96)E;B(@
M=VER9"!D:64@3F%C:')I8VAT(&EN(&1E;B!A;F=E9V5B96YE;B!/<F1N97(*
M("`@(&%U<V=E;&EE9F5R="X\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](F)L86-K;&ES="UA9&1R97-S97,B(&UD-3TB,S0S,64Y.&$X9#$U8F9A
M-C0U868S.31C969D.#,T-F0B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET
M;&4^075S<V-H;'5S<VQI<W1E.B!!9')E<W-E;CPO=&ET;&4^"B`@("`\<&%R
M83Y$:64@3&ES=&4@9&5R($%D<F5S<V5N+"!D:64@8FQO8VMI97)T('=E<F1E
M;B!S;VQL96XN($IE9&4@061R97-S90H@("`@;75S<R!I;B!E:6YE<B!E:6=E
M;F5N(%IE:6QE(&5I;F=E=')A9V5N('=E<F1E;BX\+W!A<F$^"B`@/"]E;G1R
M>3X*("`\96YT<GD@:60](F9I;'1E<G-?<G5L97,B(&UD-3TB9#@T-C$W83)F
M-3`P,F0R-&5F,3$U,#EE-68T96(V8S`B('-T871E/2)U<'1O9&%T92(^"B`@
M("`\=&ET;&4^4F5G96QN.B!&:6QT97)R96=E;&X\+W1I=&QE/@H@("`@/'!A
M<F$^1&EE<R!I<W0@9&EE($AA=7!T<V5I=&4@;6ET(&1E;B!V97)S8VAI961E
M;F5N(%)E9V5L;BX@2&EE<@H@("`@:_9N;F5N(%-I92!296=E;&X@:&EN>G5F
M_&=E;BP@:6YD96T@4VEE(&%U9B`B3F5U92!296=E;"(@:VQI8VME;BX*("`@
M(%-I92!K]FYN96X@4F5G96QN(&%R<F%N9VEE<F5N+"!I;F1E;2!3:64@875F
M(&1I92!(;V-H+2!U;F0*("`@(%)U;G1E<G!F96EL92!I;B!D97(@(E9E<G-C
M:&EE8F5N(BU3<&%L=&4@:VQI8VME;B!O9&5R(&YE=64@4F5G96QP;W-I=&EO
M;F5N"B`@("!I;B!D:64@16EN9V%B969E;&1E<B!E:6YT<F%G96XL(%)E9V5L
M;B!A:W1I=FEE<F5N('5N9"!D96%K=&EV:65R96XL(&EN9&5M"B`@("!3:64@
M875F(&1A<R!E;G1S<')E8VAE;F1E($EC;VX@:6X@9&5R(")!:W1I=FEE<G0B
M+5-P86QT92!K;&EC:V5N+"!U;F0*("`@(&5I;GIE;&YE(%)E9V5L;B!B96%R
M8F5I=&5N+"!I;F1E;2!3:64@875F(&1A<R!E;G1S<')E8VAE;F1E($EC;VX@
M:6X@9&5R"B`@("`B0F5A<F)E:71E;B(M4W!A;'1E(&]D97(@875F(&1E;B!D
M96X@4F5G96QN86UE;B!K;&EC:V5N+CPO<&%R83X*("`@(#QP87)A/@H@("`@
M("`\=&EP/D)E86-H=&5N(%-I92P@9&%S<R!D:64@4F5G96QN(&EN(&1E<B!H
M:65R(&%U9F=E;&ES=&5T96X@4F5I:&5N9F]L9V4*("`@("`@875S9V5F_&AR
M="!W97)D96XN(%=I<F0@>G5M($)E:7-P:65L(&5I;F4@16UA:6P@9'5R8V@@
M96EN96X@16EN=')A9PH@("`@("!I;B!D97(@075S<V-H;'5S<VQI<W1E(&=E
M;/9S8VAT+"!H86)E;B!D:64@;F%C:&9O;&=E;F1E;B!296=E;&X*("`@("`@
M:V5I;F5N($5I;F9L=7-S(&%U9B!D:65S92!%;6%I;"!M96AR+CPO=&EP/@H@
M("`@/"]P87)A/@H@("`@"B`@/"]E;G1R>3X*("`\96YT<GD@:60](F9O<G=A
M<F0B(&UD-3TB8SDV-C1B.38P8V5E9C@W8V%B-&%F.#-E.&8S,S0Q,F,B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^5V5I=&5R;&5I='5N9SPO=&ET
M;&4^"B`@("`\<&%R83Y$86UI="!K]FYN96X@4VEE($EH<F4@96EN9V5H96YD
M96X@16UA:6QS(&%U=&]M871I<V-H(&%N(&5I;F4*("`@(&]D97(@;65H<F5R
M92!A;F1E<F4@16UA:6QA9')E<W-E;B!W96ET97)L96ET96XN/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F;W)W87)D+6%D9')E<W-E<R(@;60U
M/2(X,3=C-68P,#)F.3EC,&%F9#`P,3!A86)A9C`W8SDQ8R(@<W1A=&4](G5P
M=&]D871E(CX*("`@(#QT:71L93Y796ET97)L96ET=6YG.B!!9')E<W-E;CPO
M=&ET;&4^"B`@("`\<&%R83Y(:65R(&OV;FYE;B!3:64@9F5S=&QE9V5N+"!A
M;B!W96QC:&4@061R97-S96X@26AR92!%;6%I;',*("`@('=E:71E<F=E;&5I
M=&5T('=E<F1E;B!S;VQL96XN(%-I92!K]FYN96X@8F5L:65B:6<@=FEE;&4@
M16UA:6QA9')E<W-E;@H@("`@96EN=')A9V5N+"!J961E(&EN(&5I;F5R(&5I
M9V5N96X@6F5I;&4N/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F
M;W)W87)D+6ME97!C;W!Y(B!M9#4](F)E,68S-F,R9CEA.&1C8F$W-3$W8CAE
M9&8U,S$Y9#8T(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E=E:71E
M<FQE:71U;F<Z($MO<&EE(&)E:&%L=&5N/"]T:71L93X*("`@(#QP87)A/E=E
M;FX@4VEE(&1I97-E($5I;G-T96QL=6YG(&%K=&EV:65R96XL('=E<F1E;B!+
M;W!I96X@86QL97(*("`@(&5I;F=E:&5N9&5N($YA8VAR:6-H=&5N(&EN($EH
M<F5M($MO;G1O(&)E;&%S<V5N+B!5;F%B:.1N9VEG(&1A=F]N"B`@("!W97)D
M96X@86QL92!.86-H<FEC:'1E;B!A;B!D:64@061R97-S96XL(&1I92!3:64@
M86YG96=E8F5N(&AA8F5N+`H@("`@=V5I=&5R9V5L96ET970N/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F+7-H;W=?9FEL=&5R7VUS9R(@
M;60U/2)D.#<Y-64U8C<Q8S8R.#=E9#=B9F4S9CAD8S1F-#@V,2(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93Y%:6YS=&5L;'5N9V5N.B!$971A:6QI
M97)T92!"96YA8VAR:6-H=&EG=6YG(&%N>F5I9V5N/SPO=&ET;&4^"B`@("`\
M<&%R83Y796YN(&1E<B!)34%0+49I;'1E<G1R96EB97(@=F5R=V5N9&5T('=I
M<F0L(&MA;FX@_&)E<B!D:65S90H@("`@16EN<W1E;&QU;F<@9F5S=&=E;&5G
M="!W97)D96XL('=I92!A=7-F_&AR;&EC:"!D:64@0F5N86-H<FEC:'1I9W5N
M9PH@("`@_&)E<B!D:64@075F_&AR=6YG(&1E<B!&:6QT97(@875S9N1L;'0N
M(%=E;FX@9&EE<V4*("`@($5I;G-T96QL=6YG(&%K=&EV:65R="!W:7)D+"!W
M:7)D(&5I;F4@0F5N86-H<FEC:'1I9W5N9R#\8F5R(&IE9&4*("`@(&5I;GIE
M;&YE($YA8VAR:6-H="P@9&EE(&=E9FEL=&5R="!W=7)D92P@875F(&1E;2!"
M:6QD<V-H:7)M(&%N9V5Z96EG="X*("`@($%N9&5R96YF86QL<R!W:7)D(&YU
M<B!E:6YE(%IU<V%M;65N9F%S<W5N9R!A;&QE<B!&:6QT97)A:W1I;VYE;@H@
M("`@86YG97IE:6=T+CPO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9BUF:6QT97)?<V5E;B(@;60U/2(X-38X-V,V.61B-C$T-60W-S`U,V$X
M8C8S,#)E-6%D,B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y%:6YS
M=&5L;'5N9V5N.B!.=7(@*'5N*6=E;&5S96YE($YA8VAR:6-H=&5N(&9I;'1E
M<FX_/"]T:71L93X*("`@(#QP87)A/DUI="!D:65S97(@16EN<W1E;&QU;F<@
M:_9N;F5N(%-I92!F97-T;&5G96XL('=E;&-H92!.86-H<FEC:'1E;@H@("`@
M:6T@4&]S=&5I;F=A;F<@=F]N(&1E;B!&:6QT97)R96=E;&X@8F5T<F]F9F5N
M('-E:6X@<V]L;&5N+B!3:64@:_9N;F5N"B`@("!D:64@1FEL=&5R(&5N='=E
M9&5R(&%U9B!A;&QE+"!N=7(@875F(&=E;&5S96YE+"!O9&5R(&YU<B!A=68@
M=6YG96QE<V5N90H@("`@3F%C:')I8VAT96X@86YW96YD96X@;&%S<V5N+CPO
M<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<G5L92(@;60U/2)C9C(Q
M,65C.3<Y-39E.6%D8S-B.&8P,6(R830P.#@X9B(@<W1A=&4](G5P=&]D871E
M(CX*("`@(#QT:71L93Y&:6QT97)R96=E;#PO=&ET;&4^"B`@("`\<&%R83Y2
M96=E;&X@<VEN9"!D97(@1W)U;F1B875S=&5I;B!):')E<B!%;6%I;&9I;'1E
M<BX@4VEE(&)E<W1E:&5N(&%U<PH@("`@96EN97(@;V1E<B!M96AR97)E($)E
M9&EN9W5N9V5N('5N9"!E:6YE<B!O9&5R(&UE:')E<F4@06MT:6]N96XN(%=E
M;FX@4VEE"B`@("!E:6YE($YA8VAR:6-H="!E<FAA;'1E;BP@=VER9"!D:65S
M92!Z=6[D8VAS="!D=7)C:"!D:64@0F5D:6YG=6YG96X*("`@('9E<F%R8F5I
M=&5T.R!W96YN(&1I97-E('IU=')E9F9E;BP@=V5R9&5N(&1I92!!:W1I;VYE
M;BP@9&EE(%-I92!A;F=E9V5B96X*("`@(&AA8F5N+"!M:70@9&EE<V5R($YA
M8VAR:6-H="!A=7-G96;\:')T+B!&:6QT97(@:_9N;F5N('-E:'(*("`@(&[\
M='IL:6-H('IU<B!!=7-S;W)T:65R=6YG('5N97)W_&YS8VAT97(@16UA:6QS
M('-E:6XL(&]D97(@=6T@26AR"B`@("!%;6%I;&MO;G1O(/QB97)S:6-H=&QI
M8VAE<B!Z=2!G97-T86QT96XL(&EN9&5M(%-I90H@("`@>G5S86UM96YG96CV
M<FEG92!%;6%I;',@:F5W96EL<R!I;B!U;G1E<G-C:&EE9&QI8VAE($]R9&YE
M<@H@("`@96EN<V]R=&EE<F5N+CPO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<G5L92UA8W1I;VXB(&UD-3TB,&8V-C4W-&9E8S(Q-C0U,30W8C-C
M8F(Y-C=C8S(S8C$B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^1FEL
M=&5R<F5G96PZ($%K=&EO;CPO=&ET;&4^"B`@("`\<&%R83Y$:65S('-I;F0@
M86QL92!M]F=L:6-H96X@06MT:6]N96XL(&1I92!A=7-G96;\:')T('=E<F1E
M;@H@("`@:_9N;F5N+"!W96YN(&5I;F4@96EN9V5H96YD92!.86-H<FEC:'0@
M9&5N($)E9&EN9W5N9V5N(&5N='-P<FEC:'0L(&1I90H@("`@:6X@9&5R($9I
M;'1E<G)E9V5L(&%N9V5G96)E;B!W=7)D92X@0F5A8VAT96X@4VEE+"!D87-S
M(&5V96YT=65L;"!N:6-H="!A;&QE"B`@("!D:65S92!-]F=L:6-H:V5I=&5N
M('IU<B!697)F_&=U;F<@<W1E:&5N+"!N=7(@9&EE($%K=&EO;F5N('=E<F1E
M;@H@("`@86YG97IE:6=T+"!D:64@=F]N($EH<F5M(%-Y<W1E;2!U;G1E<G-T
M_'1Z="!W97)D96XN/"]P87)A/@H@("`@/&AE861I;F<^26X@;65I;F5N(%!O
M<W1E:6YG86YG(&%U<VQI969E<FX\+VAE861I;F<^"B`@("`\<&%R83Y$:64@
M3F%C:')I8VAT('=I<F0@:6X@26AR96T@4&]S=&5I;F=A;F<@9V5S<&5I8VAE
M<G0N($1I97,@:7-T(&1I90H@("`@4W1A;F1A<F1E:6YS=&5L;'5N9RX\+W!A
M<F$^"B`@("`\:&5A9&EN9SY);B!D:65S96X@3W)D;F5R(&%U<VQI969E<FX\
M+VAE861I;F<^"B`@("`\<&%R83Y$:64@3F%C:')I8VAT('=I<F0@:6X@9&5N
M(&%N9V5G96)E;F5N($]R9&YE<B!A=7-G96QI969E<G0N/"]P87)A/@H@("`@
M/&AE861I;F<^3F%C:')I8VAT(&MO;7!L971T(&SV<V-H96X\+VAE861I;F<^
M"B`@("`\<&%R83Y$:64@3F%C:')I8VAT('=I<F0@<W1I;&QS8VAW96EG96YD
M(&=E;/9S8VAT+B!7961E<B!3:64@;F]C:"!D97(*("`@($%B<V5N9&5R(&5R
M:&%L=&5N(&5I;F4@0F5N86-H<FEC:'1I9W5N9R#\8F5R(&1I97-E;B!6;W)G
M86YG+CPO<&%R83X*("`@(#QH96%D:6YG/E=E:71E<FQE:71E;B!A;CPO:&5A
M9&EN9SX*("`@(#QP87)A/D1I92!.86-H<FEC:'0@=VER9"!A;B!D:64@86YG
M96=E8F5N92!%;6%I;&%D<F5S<V4@=V5I=&5R9V5L96ET970N(%-I90H@("`@
M97)H86QT96X@:V5I;F4@2V]P:64@9&EE<V5R($YA8VAR:6-H="!I;B!):')E
M;B!0;W-T96EN9V%N9RX\+W!A<F$^"B`@("`\:&5A9&EN9SY);B!M96EN96X@
M4&]S=&5I;F=A;F<@875S;&EE9F5R;B!U;F0@=V5I=&5R;&5I=&5N(&%N/"]H
M96%D:6YG/@H@("`@/'!A<F$^1&EE($YA8VAR:6-H="!W:7)D(&%N(&1I92!A
M;F=E9V5B96YE($5M86EL861R97-S92!W96ET97)G96QE:71E="P@=6YD"B`@
M("!3:64@97)H86QT96X@96EN92!+;W!I92!D:65S97(@3F%C:')I8VAT(&EN
M($EH<F5N(%!O<W1E:6YG86YG+CPO<&%R83X*("`@(#QH96%D:6YG/DUI="!F
M;VQG96YD96T@1W)U;F0@86)L96AN96X\+VAE861I;F<^"B`@("`\<&%R83Y$
M:64@3F%C:')I8VAT('=I<F0@9V5L]G-C:'0L('5N9"!D97(@06)S96YD97(@
M9&EE<V5R($YA8VAR:6-H=`H@("`@97)HY&QT(&5I;F4@06YT=V]R="!M:70@
M9&5M(%1E>'0L(&1E;B!3:64@:&EE<B!A;F=E8F5N+CPO<&%R83X*("`\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<G5L92UC;VUB:6YE(B!M9#4](C(Y-#@T8S%E
M8F1D-V-E-S%E9&,S-&9C.#$P,&5F-CEC(B!S=&%T93TB=7!T;V1A=&4B/@H@
M("`@/'1I=&QE/D9I;'1E<G)E9V5L.B!"961I;F=U;F=E;B!K;VUB:6YI97)E
M;CPO=&ET;&4^"B`@("`\<&%R83Y3:64@:_9N;F5N(&UE:')E<F4@0F5D:6YG
M=6YG96X@:6X@96EN97(@4F5G96P@86YG96)E;B!U;F0@9&EE<V4*("`@(&QO
M9VES8V@@;6ET(")U;F0B('5N9"`B;V1E<B(@=F5R:V[\<&9E;BX@2V]M<&QE
M>&4@0F5D:6YG=6YG96X@;6ET"B`@("!E:6YE<B!+;VUB:6YA=&EO;B!B96ED
M97(@5F5R:V[\<&9U;F=S='EP96X@<VEN9"!N:6-H=`H@("`@;?9G;&EC:"X\
M+W!A<F$^"B`@("`\:&5A9&EN9SY5;F0\+VAE861I;F<^"B`@("`\<&%R83Y7
M96YN(%-I92`B06QL92!D97(@9F]L9V5N9&5N(B!A=7-WY&AL96XL(&W\<W-E
M;B!E:6YG96AE;F1E"B`@("!.86-H<FEC:'1E;B!A;&QE;B!A;F=E9V5B96YE
M;B!"961I;F=U;F=E;B!E;G1S<')E8VAE;BP@8F5V;W(@9&EE"B`@("!&:6QT
M97)A:W1I;VYE;B!A=7-G96;\:')T('=E<F1E;BX\+W!A<F$^"B`@("`\:&5A
M9&EN9SY/9&5R/"]H96%D:6YG/@H@("`@/'!A<F$^5V5N;B!3:64@(D5I;F4@
M9&5R(&9O;&=E;F1E;B(@875S=^1H;&5N+"!M_'-S96X@96EN9V5H96YD90H@
M("`@3F%C:')I8VAT96X@;6EN9&5S=&5N<R!E:6YE<B!D97(@86YG96=E8F5N
M96X@0F5D:6YG=6YG96X@96YT<W!R96-H96XL(&)E=F]R"B`@("!D:64@1FEL
M=&5R86MT:6]N96X@875S9V5F_&AR="!W97)D96XN/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)R=6QE+6UA<FLB(&UD-3TB,&-B8V,T860T.#4W
M8C@U,SAC9#1E,SDQ-69B93ED-S,B('-T871E/2)U<'1O9&%T92(^"B`@("`\
M=&ET;&4^1FEL=&5R<F5G96PZ($YA8VAR:6-H="!M87)K:65R96X\+W1I=&QE
M/@H@("`@/'!A<F$^4VEE(&OV;FYE;B!F97-T;&5G96XL(&1A<W,@96EN92!.
M86-H<FEC:'0@86QS($9I;'1E<F%K=&EO;B!M:70*("`@(&5I;F5R(&]D97(@
M;65H<F5R96X@24U!4"U-87)K:65R=6YG96X@=F5R<V5H96X@=VER9"X@1&EE
M(&WV9VQI8VAE;@H@("`@36%R:VEE<G5N9V5N('-I;F0@1V5L97-E;BP@5VEC
M:'1I9RP@0F5A;G1W;W)T970@=6YD($=E;/9S8VAT+CPO<&%R83X*("`\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<G5L92UM871C:&5S(B!M9#4](C4Q-V4R-#DW
M,68R8S4T-#-B,F5D,#1E.6,U,#1E-V5B(B!S=&%T93TB=7!T;V1A=&4B/@H@
M("`@/'1I=&QE/D9I;'1E<G)E9V5L.B!"961I;F=U;F=E;CPO=&ET;&4^"B`@
M("`\<&%R83Y*961E($)E9&EN9W5N9R!E:6YE<B!&:6QT97)R96=E;"!B97-T
M96AT(&%U<R!D<F5I($MO;7!O;F5N=&5N+B!$:64*("`@(&5R<W1E(&)E<W1I
M;6UT(&1A<R!&96QD(&1E<B!.86-H<FEC:'0L(&1A<R#\8F5R<'+\9G0@=V5R
M9&5N('-O;&PN"B`@("!$:64@>G=E:71E(&QE9W0@9&EE($%R="!D97(@W&)E
M<G!R_&9U;F<@9F5S="P@=6YD(&1I92!D<FET=&4@9VEB=`H@("`@9&5N(%=E
M<G0@86XL(&UI="!D96T@9&%S($9E;&0@=F5R9VQI8VAE;B!W97)D96X@<V]L
M;"X@17,@9VEB="!V:65L90H@("`@=F5R<V-H:65D96YE(%9E<F=L96EC:'-A
M<G1E;BP@9&EE(&IE(&YA8V@@9&5M('9E<G=E;F1E=&5N($9I;'1E<G-Y<W1E
M;2!U;F0*("`@(&1E;2!Z=2#\8F5R<'+\9F5N9&5N($YA8VAR:6-H=&5N9F5L
M9"!V87)I:65R96X@:_9N;F5N+B!$86AE<@H@("`@=V5R9&5N('9O;B!D96X@
M9F]L9V5N9&5N($WV9VQI8VAK96ET96X@;FEC:'0@=6YB961I;F=T(&%L;&4*
M("`@(&%N9V5Z96EG="X\+W!A<F$^"B`@("`\:&5A9&EN9SY%;FCD;'0\+VAE
M861I;F<^"B`@("`\<&%R83Y)<W0@=V%H<BP@=V5N;B!D:64@86YG96=E8F5N
M92!:96EC:&5N:V5T=&4@:7)G96YD=V\@:6T@1F5L9"!G969U;F1E;@H@("`@
M=VER9"X@0F5I<W!I96PZ(&UA>%]M=7-T97)M86YN0&)E:7-P:65L+F1E($5N
M=&CD;'0*("`@(&UU<W1E<FUA;FY`8F5I<W!I96PN/"]P87)A/@H@("`@/&AE
M861I;F<^16YHY&QT(&YI8VAT/"]H96%D:6YG/@H@("`@/'!A<F$^27-T('=A
M:'(L('=E;FX@9&EE(&%N9V5G96)E;F4@6F5I8VAE;FME='1E(&YI8VAT(&EM
M($9E;&0@9V5F=6YD96X*("`@('=I<F0N($)E:7-P:65L.B!M87A?;75S=&5R
M;6%N;D!B96ES<&EE;"YD92!%;G1HY&QT(&YI8VAT"B`@("!M=7-T97)M86YN
M0&)E:7-P:65L+CPO<&%R83X*("`@(#QH96%D:6YG/DES=#PO:&5A9&EN9SX*
M("`@(#QP87)A/DES="!W86AR+"!W96YN(&1I92!A;F=E9V5B96YE(%IE:6-H
M96YK971T92!D96T@1F5L9"!G96YA=2!E;G1S<')I8VAT+@H@("`@0F5I<W!I
M96PZ(&UA>%]M=7-T97)M86YN0&)E:7-P:65L+F1E($ES="!M87A?;75S=&5R
M;6%N;D!B96ES<&EE;"YD92X\+W!A<F$^"B`@("`\:&5A9&EN9SY)<W0@;FEC
M:'0\+VAE861I;F<^"B`@("`\<&%R83Y)<W0@=V%H<BP@=V5N;B!D:64@86YG
M96=E8F5N92!:96EC:&5N:V5T=&4@9&5M($9E;&0@;FEC:'0@9V5N874*("`@
M(&5N='-P<FEC:'0N($)E:7-P:65L.B!M87A?;75S=&5R;6%N;D!B96ES<&EE
M;"!)<W0@3FEC:'0*("`@(&UA>%]M=7-T97)M86YN0&)E:7-P:65L+F1E+CPO
M<&%R83X*("`@(#QH96%D:6YG/D)E9VEN;G0@;6ET/"]H96%D:6YG/@H@("`@
M/'!A<F$^27-T('=A:'(L('=E;FX@9&EE(&%N9V5G96)E;F4@6F5I8VAE;FME
M='1E(&1E;2!!;F9A;F<@9&5S($9E;&1E<PH@("`@96YT<W!R:6-H="X@0F5I
M<W!I96PZ(&UA>%]M=7-T97)M86YN0&)E:7-P:65L+F1E($)E9VEN;G0@;6ET
M"B`@("!M87A?;75S=&5R;6%N;D`N/"]P87)A/@H@("`@/&AE861I;F<^0F5G
M:6YN="!N:6-H="!M:70\+VAE861I;F<^"B`@("`\<&%R83Y)<W0@=V%H<BP@
M=V5N;B!D:64@86YG96=E8F5N92!:96EC:&5N:V5T=&4@;FEC:'0@9&5M($%N
M9F%N9R!D97,*("`@($9E;&1E<R!E;G1S<')I8VAT+B!"96ES<&EE;#H@;6%X
M7VUU<W1E<FUA;FY`8F5I<W!I96PN9&4@0F5G:6YN="!N:6-H="!M:70*("`@
M(&UU<W1E<FUA;FY`8F5I<W!I96PN9&4N/"]P87)A/@H@("`@/&AE861I;F<^
M16YD970@;6ET/"]H96%D:6YG/@H@("`@/'!A<F$^27-T('=A:'(L('=E;FX@
M9&EE(&%N9V5G96)E;F4@6F5I8VAE;FME='1E(&1E;2!%;F1E(&1E<R!&96QD
M97,*("`@(&5N='-P<FEC:'0N($)E:7-P:65L.B!M87A?;75S=&5R;6%N;D!B
M96ES<&EE;"YD92!%;F1E="!M:70*("`@($!B96ES<&EE;"YD92X\+W!A<F$^
M"B`@("`\:&5A9&EN9SY%;F1E="!N:6-H="!M:70\+VAE861I;F<^"B`@("`\
M<&%R83Y)<W0@=V%H<BP@=V5N;B!D:64@86YG96=E8F5N92!:96EC:&5N:V5T
M=&4@;FEC:'0@9&5M($5N9&4@9&5S($9E;&1E<PH@("`@96YT<W!R:6-H="X@
M0F5I<W!I96PZ(&UA>%]M=7-T97)M86YN0&)E:7-P:65L+F1E($5N9&5T(&YI
M8VAT(&UI=`H@("`@;6%X7VUU<W1E<FUA;FY`8F5I<W!I96PN/"]P87)A/@H@
M("`@/&AE861I;F<^17AI<W1I97)T/"]H96%D:6YG/@H@("`@/'!A<F$^27-T
M('=A:'(L('=E;FX@9&%S(&%N9V5G96)E;F4@1F5L9"!I;B!D97(@3F%C:')I
M8VAT(&5X:7-T:65R="P*("`@('5N86)HY&YG:6YG('9O;B!D97-S96X@26YH
M86QT+CPO<&%R83X*("`@(#QH96%D:6YG/D5X:7-T:65R="!N:6-H=#PO:&5A
M9&EN9SX*("`@(#QP87)A/DES="!W86AR+"!W96YN(&1A<R!A;F=E9V5B96YE
M($9E;&0@;FEC:'0@:6X@9&5R($YA8VAR:6-H=`H@("`@97AI<W1I97)T+CPO
M<&%R83X*("`@(#QH96%D:6YG/E)E9W5LY')E<B!!=7-D<G5C:SPO:&5A9&EN
M9SX*("`@(#QP87)A/D5R;&%U8G0@9&EE(%9E<G=E;F1U;F<@:V]M<&QE>&5R
M+"!03U-)6"!K;VUP871I8FQE<BP@<F5G=6SD<F5R"B`@("!!=7-D<OQC:V4L
M('5M(&1I92!.86-H<FEC:'1E;F9E;&1E<B!Z=2#\8F5R<'+\9F5N+B!"96ES
M<&EE;#H*("`@(")296-E:79E9"!F<F]M(%LJ7"XJ7"XJ7"XJ72!B>2`H:&]S
M=&%\:&]S=&(I+F)E:7-P:65L+F1E*B(@=_QR9&4@875F"B`@("`B4F5C96EV
M960@9G)O;2!;,3<R+C$V+C$P,"XQ72!B>2!H;W-T82YB96ES<&EE;"YD92!O
M;B!4=65S9&%Y(@H@("`@>G5T<F5F9F5N+CPO<&%R83X*("`@(#QH96%D:6YG
M/D5N='!R:6-H="`H;6ET(%!L871Z:&%L=&5R;BD\+VAE861I;F<^"B`@("`\
M<&%R83XB16YT<W!R:6-H="(@:7-T(.1H;FQI8V@@>G4@(D5N=&CD;'0B+"!E
M<FQA=6)T(&%B97(@9&EE"B`@("!697)W96YD=6YG('9O;B`J('5N9"`_(&%L
M<R!0;&%T>FAA;'1E<BX@16EN("H@96YT<W!R:6-H="!E:6YE<B!B96QI96)I
M9V5N"B`@("!!;GIA:&P@=F]N(%IE:6-H96XL(#\@96YT<W!R:6-H="!G96YA
M=2!E:6YE;2!:96EC:&5N+B!"96ES<&EE;#H*("`@("(J8F5N=71Z97(_0&)E
M:7-P:65L+F1E(B!W_')D92!S;W=O:&P@875F(")B96YU='IE<C%`8F5I<W!I
M96PN9&4B(&%L<PH@("`@875C:"!A=68@(F%N9&5R97)B96YU='IE<C)`8F5I
M<W!I96PN9&4B('IU=')E9F9E;BX\+W!A<F$^"B`@("`\:&5A9&EN9SY%;G1P
M<FEC:'0@;FEC:'0@*&UI="!0;&%T>FAA;'1E<FXI/"]H96%D:6YG/@H@("`@
M/'!A<F$^(D5N='-P<FEC:'0@;FEC:'0B(&9U;FMT:6]N:65R="!G96YA=2!W
M:64@(D5N='-P<FEC:'0B+"!A==]E<@H@("`@9&%S<R!D:64@0F5D:6YG=6YG
M(&9A;'-C:"!W:7)D+"!W96YN(&1E<B!A;F=E9V5B96YE($%U<V1R=6-K(&1E
M;2!797)T(&EM"B`@("!.86-H<FEC:'1E;F9E;&0@96YT<W!R:6-H="X\+W!A
M<F$^"B`@("`\:&5A9&EN9SY+;&5I;F5R(&%L<SPO:&5A9&EN9SX*("`@(#QP
M87)A/D1I97,@:7-T(&5I;B!697)G;&5I8VAS=&5S="P@9&5R(&1E;B!A;F=E
M9V5B96YE;B!797)T('5N9"!D96X@5V5R="!I;0H@("`@3F%C:')I8VAT96YF
M96QD(&YU;65R:7-C:"!V97)G;&5I8VAT+CPO<&%R83X*("`@(#QH96%D:6YG
M/DML96EN97(@86QS(&]D97(@9VQE:6-H/"]H96%D:6YG/@H@("`@/'!A<F$^
M1&EE<R!I<W0@96EN(%9E<F=L96EC:'-T97-T+"!D97(@9&5N(&%N9V5G96)E
M;F5N(%=E<G0@=6YD(&1E;B!797)T(&EM"B`@("!.86-H<FEC:'1E;F9E;&0@
M;G5M97)I<V-H('9E<F=L96EC:'0N/"]P87)A/@H@("`@/&AE861I;F<^1VQE
M:6-H/"]H96%D:6YG/@H@("`@/'!A<F$^1&EE<R!I<W0@96EN(%9E<F=L96EC
M:'-T97-T+"!D97(@9&5N(&%N9V5G96)E;F5N(%=E<G0@=6YD(&1E;B!797)T
M(&EM"B`@("!.86-H<FEC:'1E;F9E;&0@;G5M97)I<V-H('9E<F=L96EC:'0N
M/"]P87)A/@H@("`@/&AE861I;F<^1W+VWV5R(&%L<R!O9&5R(&=L96EC:#PO
M:&5A9&EN9SX*("`@(#QP87)A/D1I97,@:7-T(&5I;B!697)G;&5I8VAS=&5S
M="P@9&5R(&1E;B!A;F=E9V5B96YE;B!797)T('5N9"!D96X@5V5R="!I;0H@
M("`@3F%C:')I8VAT96YF96QD(&YU;65R:7-C:"!V97)G;&5I8VAT+CPO<&%R
M83X*("`@(#QH96%D:6YG/D=R]M]E<B!A;',\+VAE861I;F<^"B`@("`\<&%R
M83Y$:65S(&ES="!E:6X@5F5R9VQE:6-H<W1E<W0L(&1E<B!D96X@86YG96=E
M8F5N96X@5V5R="!U;F0@9&5N(%=E<G0@:6T*("`@($YA8VAR:6-H=&5N9F5L
M9"!N=6UE<FES8V@@=F5R9VQE:6-H="X\+W!A<F$^"B`@/"]E;G1R>3X*("`\
M96YT<GD@:60](G)U;&4M;F%M92(@;60U/2(X9F%A9C<Q931B9C)F.3%D.30S
M9#<W9C@P,V8Y83)D-2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y&
M:6QT97)R96=E;#H@4F5G96QN86UE/"]T:71L93X*("`@(#QP87)A/D1I97,@
M:7-T(&1E<B!.86UE(&1E<B!296=E;"P@9&5N(%-I92!F<F5I('9E<F=E8F5N
M(&OV;FYE;BX@17(*("`@('=I<F0@:6X@9&5R($QI<W1E(&1E<B!&:6QT97)R
M96=E;&X@8F5N=71Z="P@=6T@875F(&1I92!296=E;`H@("`@>G5Z=6=R96EF
M96XN/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)R=6QE+7-T;W`B
M(&UD-3TB-C<W8SDR,&5F9F-A.34Y,3(S8C=D-3,Y8C-B,&0X-C0B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^1FEL=&5R<F5G96PZ(%=E:71E<F4@
MW&)E<G!R_&9U;F<@86YH86QT96X\+W1I=&QE/@H@("`@/'!A<F$^5V5N;B!D
M:65S92!%:6YS=&5L;'5N9R!A=7-G97?D:&QT(&ES="!U;F0@9&EE(%)E9V5L
M(&%U9B!E:6YE"B`@("!.86-H<FEC:'0@>G5T<FEF9G0L('=E<F1E;B!A;&QE
M(&9O;&=E;F1E;B!296=E;&X@;FEC:'0@;65H<B!A=68@9&EE<V4*("`@($YA
M8VAR:6-H="!A;F=E=V5N9&5T+CPO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB=F%C871I;VXB(&UD-3TB,F,Y93$R.3<S9#,V9F4Y-&%E8C<S8C,R
M9&(Y838T938B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^06)W97-E
M;FAE:70\+W1I=&QE/@H@("`@/'!A<F$^06)W97-E;FAE:71S;F%C:')I8VAT
M96X@<VEN9"!A=71O;6%T:7-C:&4@06YT=V]R=&5N(&%N(%!E<G-O;F5N+"!D
M:64*("`@($EH;F5N(&5I;F4@16UA:6P@<V-H<F5I8F5N+"!WY&AR96YD('-I
M92!F_'(@96EN92!LY&YG97)E"B`@("!:96ET(&%B=V5S96YD('-I;F0N/"]P
M87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)V86-A=&EO;BUB=6QK(B!M
M9#4](C9F-F4T,3<X93@P9C0V93<X-S9C-V5E-60P86,U,V(W(B!S=&%T93TB
M=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%B=V5S96YH96ET.B!+96EN92!!;G1W
M;W)T96X@875F($YA8VAR:6-H=&5N('9O;B!-86EL:6YG;&ES=&5N(&]D97(*
M("`@($UA<W-E;F5M86EL<SPO=&ET;&4^"B`@("`\<&%R83Y796YN(%-I92!D
M:65S92!%:6YS=&5L;'5N9R!A:W1I=FEE<F5N+"!W97)D96X@:V5I;F4*("`@
M($%B=V5S96YH96ET<VYA8VAR:6-H=&5N(&%L<R!!;G=O<G0@875F($YA8VAR
M:6-H=&5N('9O;B!-86EL:6YG;&ES=&5N(&]D97(*("`@('-O;&-H96XL(&1I
M92!A;',@36%S<V5N;6%I;',@;6%R:VEE<G0@<VEN9"P@=F5R<V-H:6-K="X\
M+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G9A8V%T:6]N+61A>7,B
M(&UD-3TB,C5B83<T8S!E-SEC93<R,C,W-SDU96(X,#EE930U.#4B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^06)W97-E;FAE:70Z($%N='=O<G1I
M;G1E<G9A;&P\+W1I=&QE/@H@("`@/'!A<F$^2&EE<B!K]FYN96X@4VEE(&1I
M92!!;GIA:&P@9&5R(%1A9V4@86YG96)E;BP@9&EE(&=E=V%R=&5T('=E<F1E
M;@H@("`@<V]L;"P@8F5V;W(@96EN($%B<V5N9&5R+"!D97(@<V-H;VX@96EN
M92!!8G=E<V5N:&5I='-N86-H<FEC:'0@97)H86QT96X*("`@(&AA="P@96EN
M92!W96ET97)E('IU9V5S8VAI8VMT(&)E:V]M;70N/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)V86-A=&EO;BUM>65M86EL(B!M9#4](F5F,V9A
M-S!E.30P960Q-#<R,C<V8S!F9&4U864R865D(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/D%B=V5S96YH96ET.B!-96EN92!%;6%I;&%D<F5S<V5N
M/"]T:71L93X*("`@(#QP87)A/E=E;FX@4VEE(&UE:'(@86QS(&5I;F4@16UA
M:6QA9')E<W-E(&AA8F5N+"!F_'(@9&EE(%-I90H@("`@3F%C:')I8VAT96X@
M:6X@9&EE<V5M($MO;G1O(&5R:&%L=&5N+"!K]FYN96X@4VEE(&1I97-E(&AI
M97(*("`@(&%N9V5B96XN/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)V86-A=&EO;BUN;W)E<W!O;G-E(B!M9#4](C)B-S)E,3)B-CDX.6,Y968Q
M-C8W834Y,#0P8S<P,S$P(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/D%B=V5S96YH96ET.B!+96EN92!!;G1W;W)T96X\+W1I=&QE/@H@("`@/'!A
M<F$^06X@9&EE(&%N9V5B96YE;B!%;6%I;&%D<F5S<V5N('=E<F1E;B!K96EN
M92!!8G=E<V5N:&5I='-N86-H<FEC:'1E;@H@("`@=F5R<V-H:6-K="X@2F5D
M92!!9')E<W-E(&UU<W,@:6X@96EN97(@96EG96YE;B!:96EL92!S=&5H96XN
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)V86-A=&EO;BUR96%S
M;VXB(&UD-3TB9#1D83)F,V$P9#,U-V4P,#DU,&5C-3=D.3@T8V)C964B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^06)W97-E;FAE:70Z($=R=6YD
M/"]T:71L93X*("`@(#QP87)A/D1I97-E<B!497AT('=I<F0@:6X@26AR96X@
M06)W97-E;FAE:71S;F%C:')I8VAT96X@=F5R=V5N9&5T+CPO<&%R83X*("`\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB=F%C871I;VXM<W5B:F5C="(@;60U/2)C
M93$V8S=C-F$P.#DY,S@R,3(P.&-F8F5E,&(Q.#AA,"(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y!8G=E<V5N:&5I=#H@0F5T<F5F9CPO=&ET;&4^
M"B`@("`\<&%R83Y$:65S97(@0F5T<F5F9B!W:7)D(&EN($EH<F5N($%B=V5S
M96YH96ET<VYA8VAR:6-H=&5N"B`@("!V97)W96YD970N/"]P87)A/@H@(#PO
M96YT<GD^"B`@/&5N=')Y(&ED/2)W:&ET96QI<W0B(&UD-3TB96-B9C<P,#!F
M,3`W.#,R9#8X8F0W8F$X9C4Q,C$Y,#DB('-T871E/2)U<'1O9&%T92(^"B`@
M("`\=&ET;&4^4&]S:71I=FQI<W1E/"]T:71L93X*("`@(#QP87)A/DEN(&1E
M<B!0;W-I=&EV;&ES=&4@8F5F:6YD96X@<VEC:"!A;&QE($5M86EL861R97-S
M96XL(&1E<F5N"B`@("!.86-H<FEC:'1E;B!3:64@:6UM97(@:6X@26AR96T@
M4&]S=&9A8V@@:&%B96X@;?9C:'1E;BX@2F5D92!!9')E<W-E"B`@("!M=7-S
M(&EN(&5I;F5R(&5I9V5N96X@6F5I;&4@<W1E:&5N+CPO<&%R83X*("`\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB=VAI=&5L:7-T+6%D9')E<W-E<R(@;60U/2(X
M9F4P-31C,6(U-64V861C.#%D,60X-3(U8S$S,38S-R(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y0;W-I=&EV;&ES=&4Z($%D<F5S<V5N/"]T:71L
M93X*("`@(#QP87)A/DIE9&4@061R97-S92!M=7-S(&EN(&5I;F5R(&5I9V5N
M96X@6F5I;&4@<W1E:&5N+CPO<&%R83X*("`\+V5N=')Y/@H\+VAE;'`^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE+V-S
M7T-:+P``````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#<`,#$W-C(S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6YG;R]L;V-A;&4O8W-?0UHO3$-?34534T%'15,O````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,C$T,3``(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]C<U]#6B],0U]-15-3
M04=%4R]I;F=O+FUO````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S8U-C`U`#$P-#$W
M,S8R-S0W`#`R,C<Q-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#>$@25`````$,'```<````-#H``,<)``!,=````````&B;
M```.````:9L```\```!XFP``#0```(B;```(````EIL```L```"?FP``#```
M`*N;```$````N)L```0```"]FP```P```,*;```,````QIL```\```#3FP``
M"P```..;```.````[YL```4```#^FP``*`````2<```(````+9P```H````V
MG```%0```$&<```2````5YP```L```!JG```#@```':<```*````A9P```T`
M``"0G```#@```)Z<```1````K9P```T```"_G```#````,V<```-````VIP`
M``8```#HG```#P```.^<```8````_YP```P````8G0``#@```"6=```.````
M-)T```@```!#G0``+@```$R=```:````>YT``#(```"6G0``.````,F=``!4
M`````IX``%$```!7G@``6@```*F>``!7````!)\``#0```!<GP``!P```)&?
M```*````F9\```\```"DGP``!0```+2?```&````NI\``!$```#!GP``"```
M`-.?```)````W)\```D```#FGP``)0```/"?```@````%J```!`````WH```
M#P```$B@```*````6*```"$```!CH```#P```(6@```#````E:````\```"9
MH```%````*F@```)````OJ````T```#(H```$@```-:@```/````Z:````H`
M``#YH```#P````2A```(````%*$``"0````=H0``%````$*A```6````5Z$`
M``@```!NH0``&0```'>A```3````D:$```<```"EH0``#````*VA```L````
MNJ$```X```#GH0```P```/:A```+````^J$```<````&H@``!P````ZB```%
M````%J(```4````<H@``"@```"*B```#````+:(``!<````QH@``"@```$FB
M```/````5*(```X```!DH@``%````'.B```8````B*(``",```"AH@``#@``
M`,6B```4````U*(``!<```#IH@``%P````&C```7````&:,``!,````QHP``
M#P```$6C```.````5:,``!\```!DHP``!P```(2C```&````C*,```@```"3
MHP``#P```)RC```&````K*,```@```"SHP``"@```+RC```3````QZ,``!0`
M``#;HP``"P```/"C```0````_*,``!4````-I```#0```".D```5````,:0`
M``<```!'I```$````$^D```%````8*0``!4```!FI```$0```'RD```,````
MCJ0``"H```";I```.P```,:D```)`````J4```<````,I0``%````!2E```#
M````*:4```4````MI0``$````#.E```)````1*4``!,```!.I0``.0```&*E
M```2````G*4``"<```"OI0``+````->E```J````!*8``"4````OI@``"@``
M`%6F```&````8*8```D```!GI@``!P```'&F```O````>:8``#<```"II@``
M+@```.&F``!5````$*<``"T```!FIP``+0```)2G```M````PJ<``$````#P
MIP``(P```#&H```C````5:@``"T```!YJ```,P```*>H```5````VZ@``!D`
M``#QJ```*0````NI```D````-:D``#(```!:J0``$0```(VI```*````GZD`
M``P```"JJ0``"@```+>I```0````PJD``!8```#3J0``%@```.JI```'````
M`:H```<````)J@``%````!&J```*````)JH```@````QJ@``"````#JJ```#
M````0ZH```L```!'J@``!P```%.J```'````6ZH```8```!CJ@``!0```&JJ
M```'````<*H```8```!XJ@``"````'^J```)````B*H```X```"2J@``.P``
M`*&J```3````W:H``!4```#QJ@``*0````>K```.````,:L```H```!`JP``
M!````$NK```$````4*L```<```!5JP``"0```%VK```&````9ZL``!$```!N
MJP``!P```("K```6````B*L```0```"?JP``"````*2K```&````K:L```T`
M``"TJP``!@```,*K```>````R:L``!$```#HJP``"````/JK```-`````ZP`
M``P````1K```!P```!ZL```#````)JP```,````JK```%P```"ZL```3````
M1JP```@```!:K```!````&.L```(````:*P```@```!QK```00```'JL```@
M````O*P```8```#=K```!@```.2L```5````ZZP``!@````!K0``(@```!JM
M```N````/:T``!T```!LK0``(0```(JM``!4````K*T``"D````!K@``"@``
M`"NN```'````-JX```X````^K@``%0```$VN```.````8ZX```(```!RK@``
M"@```'6N```/````@*X```T```"0K@``#P```)ZN```-````KJX```D```"\
MK@``%````,:N```&````VZX``!@```#BK@``'0```/NN```3````&:\``!0`
M```MKP``!````$*O```&````1Z\``%0```!.KP``#@```*.O```$````LJ\`
M``X```"WKP``!0```,:O```%````S*\``!L```#2KP``&@```.ZO```1````
M";```!$````;L```'````"VP```J````2K```!````!UL```(0```(:P```%
M````J+```!,```"NL```$@```,*P```*````U;````\```#@L```$0```/"P
M```3`````K$```P````6L0``!@```".Q```&````*K$``!<````QL0``$```
M`$FQ```1````6K$```@```!LL0``!0```'6Q```,````>[$``!````"(L0``
M!0```)FQ```-````G[$```8```"ML0``!P```+2Q```-````O+$```<```#*
ML0``"P```-*Q```'````WK$```<```#FL0``"0```.ZQ```*````^+$``!D`
M```#L@``#````!VR```0````*K(```4````[L@``)0```$&R```2````9[(`
M`!,```!ZL@``*P```(ZR```[````NK(``"````#VL@``-@```!>S```(````
M3K,```@```!7LP``#````&"S```&````;;,```0```!TLP``!P```'FS```*
M````@;,```X```",LP``"@```)NS```-````IK,``!X```"TLP``&P```-.S
M```A````[[,``!X````1M```&0```#"T```>````2K0``!L```!IM```)@``
M`(6T```;````K+0``!X```#(M```'````.>T```F````!+4``#,````KM0``
M)@```%^U```K````AK4``#@```"RM0``+P```.NU```2````&[8``"D````N
MM@``$@```%BV``"B````:[8``!8````.MP``(P```"6W```H````2;<``"D`
M``!RMP``*````)RW```?````Q;<``"````#EMP``)0````:X```P````++@`
M`"$```!=N```'````'^X```F````G+@``$$```##N```#`````6Y```'````
M$KD```<````:N0``!@```"*Y```-````*;D``!`````WN0``$0```$BY```2
M````6KD``!,```!MN0``$@```(&Y```'````E+D```0```"<N0``#````*&Y
M```.````KKD```\```"]N0``$P```,VY```-````X;D``"@```#ON0```P``
M`!BZ```-````'+H```8````JN@``$0```#&Z```7````0[H``!L```!;N@``
M#@```'>Z```"````AKH```H```")N@``!0```)2Z```0````FKH```0```"K
MN@``#0```+"Z```.````OKH```,```#-N@``#@```-&Z```1````X+H```@`
M``#RN@``#P```/NZ```/````"[L```<````;NP``#0```".[```0````,;L`
M``L```!"NP``!@```$Z[```)````5;L``!````!?NP``#````'"[```1````
M?;L``!D```"/NP``"P```*F[```-````M;L``"(```##NP``&0```.:[```*
M`````+P``!@````+O```&0```"2\```6````/KP```<```!5O```%0```%V\
M```A````<[P``"4```"5O```$0```+N\```-````S;P```<```#;O```%```
M`..\```+````^+P``"(````$O0``+P```">]```+````5[T```D```!CO0``
M&0```&V]```+````A[T``!<```"3O0``%P```*N]```)````P[T```H```#-
MO0``"````-B]```6````X;T```\```#XO0``.@````B^```6````0[X```X`
M``!:O@``&````&F^```(````@KX``"\```"+O@``#0```+N^```F````R;X`
M``@```#PO@``0P```/F^```2````/;\```\```!0OP``$````&"_```-````
M<;\``"$```!_OP``"````*&_```2````JK\```@```"]OP``"P```,:_```O
M````TK\```X````"P```!0```!'````&````%\````,````>P```!P```"+`
M```$````*L````<````OP```"@```#?````*````0L````\```!-P```$```
M`%W````7````;L```!$```"&P```%P```)C````)````L,````4```"ZP```
M"P```,#````*````S,````(```#7P```!0```-K````-````X,```!L```#N
MP```%P````K!```)````(L$```X````LP0``#0```#O!```2````2<$```D`
M``!<P0``.````&;!```@````G\$```<```#`P0``"````,C!```)````T<$`
M``X```#;P0``>P```.K!```8````9L(```@```!_P@``$0```(C"```'````
MFL(```4```"BP@``&0```*C"```'````PL(```@```#*P@``!@```-/"```&
M````VL(``!````#AP@``#P```/+"```0`````L,```\````3PP``"P```"/#
M```/````+\,```P````_PP``#P```$S#```'````7,,```X```!DPP``!@``
M`'/#```&````>L,```X```"!PP``#````)##```H````G<,```\```#&PP``
M"````-;#```(````W\,``!,```#HPP``'@```/S#```A````&\0``"`````]
MQ```&0```%[$```7````>,0``"4```"0Q```%P```+;$```$````SL0``!L`
M``#3Q```#0```._$```,````_<0```,````*Q0``"`````[%```*````%\4`
M``P````BQ0``"P```"_%```0````.\4```P```!,Q0``!````%G%```3````
M7L4``!0```!RQ0``#````(?%```)````E,4```X```">Q0``"P```*W%```;
M````N<4``!,```#5Q0``&0```.G%```;`````\8```X````?Q@``"P```"[&
M```,````.L8``!4```!'Q@``#0```%W&``!#````:\8``#$```"OQ@``0@``
M`.'&``!'````),<``$\```!LQP``/0```+S'``!.````^L<``!$```!)R```
M!P```%O(```'````8\@```H```!KR```#0```';(```)````A,@```0```".
MR```!0```)/(```#````F<@``!@```"=R```"@```+;(```$````P<@``"4`
M``#&R```)@```.S(```.````$\D``'P````BR0``%0```)_)```%````M<D`
M``<```"[R0``#````,/)```(````T,D```H```#9R0``!@```.3)```'````
MZ\D``#D```#SR0``"````"W*```-````-LH```(```!$R@``!@```$?*```&
M````3LH``!0```!5R@``#0```&K*```0````>,H``!L```")R@``!````*7*
M```)````JLH``!````"TR@``"0```,7*```)````S\H```4```#9R@``&@``
M`-_*```(````^LH```8````#RP``&0````K+```.````),L```<````SRP``
M!P```#O+```%````0\L```D```!)RP``"@```%/+```"````7LL```8```!A
MRP``#0```&C+```)````=LL```P```"`RP``&````(W+```&````ILL``!(`
M``"MRP``"0```,#+```'````RLL``!0```#2RP``'0```.?+```&````!<P`
M``H````,S```!````!?,```)````',P```@````FS```$0```"_,```)````
M0<P```8```!+S```#0```%+,```&````8,P```0```!GS```.0```&S,```]
M````ILP``#H```#DS```'@```!_-```%````/LT```X```!$S0``!````%/-
M```&````6,T``"$```!?S0``%0```('-```&````E\T```0```">S0``$0``
M`*/-```&````M<T```H```"\S0``(@```,?-```$````ZLT```4```#OS0``
M'0```/7-```$````$\X```P````8S@``"@```"7.```(````,,X```D````Y
MS@``!0```$/.```Z````2<X``#````"$S@``-0```+7.```I````Z\X``$<`
M```5SP``.````%W/```I````EL\``#\```#`SP``+@````#0```M````+]``
M`!\```!=T```#P```'W0```2````C=````L```"@T```)@```*S0```I````
MT]```"0```#]T```)@```"+1```(````2=$```H```!2T0``"0```%W1```'
M````9]$``"````!OT0``(````)#1```F````L=$```H```#8T0``&0```./1
M```I````_=$``!8````GT@``$@```#[2```'````4=(```H```!9T@``#```
M`&32```/````<=(``!````"!T@``0````)+2``!P````T](``&8```!$TP``
M#@```*O3```)````NM,```H```#$TP``$@```,_3```3````XM,```P```#V
MTP``!@````/4```/````"M0```D````:U```$@```"34```0````-]0``!$`
M``!(U```'````%K4```C````=]0``&H```";U```#P````;5```%````%M4`
M`!`````<U0``0P```"W5```)````<=4``#(```![U0``!````*[5```+````
ML]4``!0```"_U0``#````-35```,````X=4```\```#NU0``%0```/[5```I
M````%-8``"H````^U@``)@```&G6```G````D-8``"D```"XU@``*@```.+6
M```9````#=<``$(````GUP``$0```&K7```2````?-<``!,```"/UP``%```
M`*/7```/````N-<``!8```#(UP``%P```-_7```0````]]<``!$````(V```
M-````!K8```3````3]@``!(```!CV```-0```';8```4````K-@```<```#!
MV```#````,G8```@````UM@``!0```#WV```$0````S9```7````'MD``!P`
M```VV0``$P```%/9```1````9]D``!H```!YV0``'@```)39```:````L]D`
M`!$```#.V0``%````.#9```7````]=D``!4````-V@``"0```"/:```9````
M+=H```0```!'V@``!P```$S:```"````5-H```L```!7V@``!0```&/:```1
M````:=H```8```![V@``!@```(+:```&````B=H```4```"0V@``!P```);:
M```'````GMH```4```"FV@``%@```*S:```&````P]H```8```#*V@``!```
M`-':```$````UMH```<```#;V@``#@```./:```,````\MH```P```#_V@``
M#0````S;```*````&ML```X````EVP``!0```#3;```H````.ML```X```!C
MVP``#````'+;```/````?]L```H```"/VP``"````)K;```)````H]L``"L`
M``"MVP``!````-G;```(````WML``"8```#GVP``$@````[<```/````(=P`
M``8````QW```"@```#C<```'````0]P```@```!+W```(````%3<```)````
M==P```P```!_W```#0```(S<```.````FMP``!8```"IW```$0```,#<```&
M````TMP```,```#9W```!@```-W<```9````Y-P```<```#^W```!`````;=
M```+````"]T```L````7W0``!P```"/=```)````*]T``!4````UW0``!P``
M`$O=```6````4]T```T```!JW0``#0```'C=```*````AMT``!````"1W0``
M#P```*+=```1````LMT``!<```#$W0``"@```-S=```1````Y]T```@```#Y
MW0``!`````+>```/````!]X``#H````7W@``!0```%+>```,````6-X``!X`
M``!EW@``#@```(3>```0````D]X```L```"DW@``#````+#>```)````O=X`
M``<```#'W@``!P```,_>```*````U]X```D```#BW@``#@```.S>```0````
M^]X``!H````,WP``"@```"??```)````,M\```H````\WP``#````$??```/
M````5-\```@```!DWP``!@```&W?```'````=-\```L```!\WP``1P```(C?
M```-````T-\```D```#>WP``!````.C?```#````[=\``!,```#QWP``$P``
M``7@```3````&>````H````MX````@```#C@```$````.^```"4```!`X```
M`P```&;@```%````:N```"H```!PX```"@```)O@```%````IN````0```"L
MX```"@```+'@```-````O.````8```#*X```"````-'@```(````VN````0`
M``#CX```!0```.C@``!H````[N````D```!7X0``#````&'A```8````;N$`
M``4```"'X0``!@```(WA```0````E.$``!L```"EX0``+P```,'A```0````
M\>$```H````"X@``&P````WB```/````*>(```H````YX@``"0```$3B```3
M````3N(``!L```!BX@``&````'[B```7````E^(```X```"OX@``B0```+[B
M``")````2.,```,```#2XP``!P```-;C```(````WN,```<```#GXP``"@``
M`._C```+````^N,```<````&Y```40````[D```0````8.0```P```!QY```
M#0```'[D```:````C.0``$H```"GY```!@```/+D```&````^>0```8`````
MY0``'P````?E```&````)^4```D````NY0``&````#CE```7````4>4```8`
M``!IY0``#0```'#E```B````?N4``"8```"AY0``5P```,CE```3````(.8`
M`!D````TY@``&P```$[F```C````:N8``!,```".Y@```@```*+F```+````
MI>8```@```"QY@``#0```+KF```*````R.8```<```#3Y@``%````-OF```&
M````\.8```@```#WY@``#@````#G```'````#^<```H````7YP``"P```"+G
M```'````+N<```P````VYP``#0```$/G```,````4><```0```!>YP``"0``
M`&/G```)````;><```H```!WYP``#@```(+G```,````D><```<```">YP``
M"0```*;G```'````L.<```H```"XYP``&P```,/G```2````W^<```H```#R
MYP``"0```/WG```0````!^@```<````8Z```$@```"#H```I````,^@```0`
M``!=Z```!P```&+H```%````:N@```4```!PZ```"P```';H```4````@N@`
M`!$```"7Z```&@```*GH```6````Q.@``!0```#;Z```%P```/#H```8````
M".D``!P````AZ0``&0```#[I```'````6.D```4```!@Z0``#0```&;I```,
M````=.D```@```"!Z0``"````(KI```7````D^D```L```"KZ0``$P```+?I
M```$````R^D```H```#0Z0``!````-OI```,````X.D```D```#MZ0``!0``
M`/?I```'````_>D```4````%Z@``!`````OJ```"````$.H``#@````3Z@``
M+````$SJ```C````>>H``"8```"=Z@``$@```,3J```I````U^H``#(````!
MZP``"@```#3K```L````/^L``"X```!LZP``,P```)OK```S````S^L``#@`
M```#[```#P```#SL```8````3.P``!````!E[```%````';L```/````B^P`
M`!,```";[```%````*_L```2````Q.P``!0```#7[```%0```.SL```M````
M`NT``"T````P[0``,0```%[M```N````D.T``"\```"_[0``+````._M``!B
M````'.X``!,```!_[@``"````)/N```4````G.X```@```"Q[@``%````+KN
M```K````S^X``"$```#[[@``&@```!WO```)````..\``$4```!"[P``00``
M`(CO```$````RN\``!,```#/[P``%````./O```.````^.\``!,````'\```
M&````!OP```&````-/````D````[\```"@```$7P```/````4/````P```!@
M\```$````&WP```'````?O````X```"&\```!0```)7P```;````F_````@`
M``"W\```!@```,#P```4````Q_```!$```#<\```#@```.[P```X````_?``
M``(````V\0``!@```#GQ```.````0/$```4```!/\0``!P```%7Q```.````
M7?$```8```!L\0``!````'/Q```I````>/$``!<```"B\0``'P```+KQ``!<
M````VO$``!0````W\@``/@```$SR```?````B_(``!````"K\@``!P```+SR
M```>````Q/(```X```#C\@``#````/+R```,````__(``!,````,\P``"@``
M`"#S```=````*_,``!D```!)\P``!0```&/S```1````:?,```T```![\P``
M$0```(GS```D````F_,``!4```#`\P``$@```-;S```.````Z?,``!D```#X
M\P``"````!+T```)````&_0```T````E]```"@```#/T```'````/O0```\`
M``!&]```"P```%;T```*````8O0```<```!M]```"````'7T```%````?O0`
M`!\```"$]```!@```*3T```0````J_0```@```"\]```#0```,7T```(````
MT_0``!(```#<]```+````._T```:````'/4```D````W]0``"@```$'U```5
M````3/4```4```!B]0``%````&CU```$````??4``!````""]0``!@```)/U
M```'````FO4``!X```"B]0``*````,'U```*````ZO4``!H```#U]0``%```
M`!#V```$````)?8```0````J]@``"P```"_V```%````._8```8```!!]@``
M"````$CV```&````4?8```H```!8]@``&P```&/V```T````?_8``#0```"T
M]@``(````.GV```I````"O<``"`````T]P``00```%7W```:````E_<``"@`
M``"R]P``*````-OW```I````!/@``"(````N^```!@```%'X```(````6/@`
M``4```!A^```"````&?X```9````</@``!D```"*^```*@```*3X```C````
MS_@``"X```#S^```-````"+Y```(````5_D``!<```!@^0``"@```'CY```'
M````@_D``"$```"+^0``$````*WY```.````OOD```L```#-^0``!P```-GY
M```3````X?D```@```#U^0``"P```/[Y```*````"OH``!0````5^@``,@``
M`"KZ```+````7?H```4```!I^@``!0```&_Z```7````=?H```<```"-^@``
M#P```)7Z```$````I?H```H```"J^@``"0```+7Z```+````O_H```T```#+
M^@``#````-GZ```.````YOH```4```#U^@``!````/OZ```-`````/L``#(`
M```.^P``10```$'[```(````A_L```L```"0^P``%P```)S[```>````M/L`
M`!0```#3^P``!0```.C[```2````[OL``!(````!_```%````!3\```'````
M*?P```X````Q_```*@```$#\```&````:_P```P```!R_```#0```'_\```1
M````C?P```L```"?_```-@```*O\```*````XOP``"(```#M_```"P```!#]
M```/````'/T``#(````L_0``#@```%_]```)````;OT```L```!X_0``!0``
M`(3]```.````BOT``!,```"9_0``!P```*W]```6````M?T``!$```#,_0``
M%````-[]```'````\_T``!0```#[_0``&````!#^```'````*?X```4````Q
M_@``#````#?^```,````1/X``!(```!1_@``!````&3^```'````:?X```H`
M``!Q_@``"P```'S^```,````B/X```X```"5_@``#@```*3^```%````L_X`
M``0```"Y_@``"P```+[^```,````ROX```T```#7_@``#````.7^```)````
M\OX```4```#\_@``+@````+_```F````,?\``",```!8_P```P```'S_```2
M````@/\```8```"3_P``'@```)K_```8````N?\``"4```#2_P``#0```/C_
M```)````!@`!``,````0``$`!P```!0``0`*````'``!``(````G``$`#```
M`"H``0`5````-P`!``L```!-``$`&0```%D``0`@````<P`!`!(```"4``$`
M!0```*<``0`*````K0`!`!4```"X``$`$@```,X``0`,````X0`!``0```#N
M``$`!P```/,``0`,````^P`!``T````(`0$`4@```!8!`0`7````:0$!``<`
M``"!`0$`!@```(D!`0`/````D`$!`!,```"@`0$`'@```+0!`0`@````TP$!
M``8```#T`0$`#@```/L!`0`$````"@(!``P````/`@$`#0```!P"`0`.````
M*@(!`!4````Y`@$`$@```$\"`0`/````8@(!`!0```!R`@$`&P```(<"`0`0
M````HP(!`!0```"T`@$`:0```,D"`0`:````,P,!`!<```!.`P$`)P```&8#
M`0`:````C@,!`!<```"I`P$`&P```,$#`0`9````W0,!`!\```#W`P$`$P``
M`!<$`0`3````*P0!``@````_!`$`!@```$@$`0`'````3P0!``@```!7!`$`
M"0```&`$`0`5````:@0!``T```"`!`$`$P```(X$`0`#````H@0!`$8```"F
M!`$`/P```.T$`0`W````+04!`%<```!E!0$`'@```+T%`0`%````W`4!`!\`
M``#B!0$`+P````(&`0`*````,@8!``@````]!@$`#0```$8&`0`M````5`8!
M``0```""!@$`$@```(<&`0`3````F@8!`$\```"N!@$`)0```/X&`0`<````
M)`<!``L```!!!P$`'P```$T'`0`=````;0<!`"4```"+!P$`(````+$'`0`D
M````T@<!`"````#W!P$`"P```!@(`0`'````)`@!``T````L"`$`#````#H(
M`0`7````1P@!``8```!?"`$`.0```&8(`0`,````H`@!``<```"M"`$`"0``
M`+4(`0`3````OP@!``D```#3"`$`!````-T(`0`0````X@@!``@```#S"`$`
M"````/P(`0`$````!0D!``L````*"0$`#````!8)`0`2````(PD!`!$````V
M"0$`#````$@)`0`:````50D!``\```!P"0$`!P```(`)`0`-````B`D!`!0`
M``"6"0$`#@```*L)`0`,````N@D!`!L```#'"0$`+````.,)`0`3````$`H!
M`!P````D"@$`*````$$*`0`&````:@H!``<```!Q"@$`$P```'D*`0`%````
MC0H!``0```"3"@$`%P```)@*`0`*````L`H!``P```"["@$`"0```,@*`0`&
M````T@H!``D```#9"@$`"````.,*`0`)````[`H!``H```#V"@$`$0````$+
M`0`&````$PL!`",````:"P$`#@```#X+`0`.````30L!``T```!<"P$`"P``
M`&H+`0`=````=@L!``L```"4"P$``@```*`+`0`=````HPL!``<```#!"P$`
M!@```,D+`0`)````T`L!``<```#:"P$`.P```.(+`0`H````'@P!`#0```!'
M#`$`%0```'P,`0`%````D@P!``<```"8#`$`"````*`,`0`'````J0P!``4`
M``"Q#`$`!P```+<,`0`.````OPP!``D```#.#`$`!@```-@,`0`(````WPP!
M``L```#H#`$`!P```/0,`0`(````_`P!``<````%#0$`%@````T-`0`)````
M)`T!``8````N#0$`"P```#4-`0`<````00T!`!0```!>#0$`!P```',-`0`(
M````>PT!``@```"$#0$`!0```(T-`0`0````DPT!`!````"D#0$`!@```+4-
M`0`9````O`T!``H```#6#0$`'````.$-`0`'````_@T!``4````&#@$`$```
M``P.`0`4````'0X!``L````R#@$`#0```#X.`0`7````3`X!``0```!D#@$`
M"0```&D.`0`*````<PX!``<```!^#@$``@```(8.`0`.````B0X!``@```"8
M#@$`'P```*$.`0`C````P0X!`#@```#E#@$`,0```!X/`0`G````4`\!`&0`
M``!X#P$`%````-T/`0!5````\@\!`#@```!($`$`2@```($0`0!;````S!`!
M`"@````H$0$`$0```%$1`0`X````8Q$!`"@```"<$0$`+````,41`0`G````
M\A$!`!L````:$@$`/@```#82`0"I`0``=1(!`",````?%`$`%P```$,4`0!(
M````6Q0!`(4```"D%`$`,````"H5`0!!````6Q4!`%L```"=%0$`20```/D5
M`0`=````0Q8!`!@```!A%@$`(0```'H6`0`?````G!8!`"L```"\%@$`(0``
M`.@6`0`G````"A<!`!T````R%P$`$0```%`7`0`S````8A<!`"4```"6%P$`
M)P```+P7`0`?````Y!<!`#`````$&`$`:0```#48`0`]````GQ@!`&4```#=
M&`$`30```$,9`0`I````D1D!`"L```"[&0$`+P```.<9`0`N````%QH!`#``
M``!&&@$`5````'<:`0!:````S!H!`$@````G&P$`2@```'`;`0`R````NQL!
M`"\```#N&P$`+````!X<`0`M````2QP!`'$```!Y'`$`;P```.L<`0"S````
M6QT!`!<````/'@$`)0```"<>`0`R````31X!`"D```"`'@$`/@```*H>`0`B
M````Z1X!`%(````,'P$`)0```%\?`0`+````A1\!`+$```"1'P$`10```$,@
M`0`A````B2`!`#````"K(`$`)0```-P@`0`<`````B$!`#$````?(0$`!P``
M`%$A`0`'````62$!``0```!A(0$`#0```&8A`0`+````="$!``X```"`(0$`
M"P```(\A`0`%````FR$!`!````"A(0$``@```+(A`0!9````M2$!``4````/
M(@$`$@```!4B`0`$````*"(!``<````M(@$`"````#4B`0`%````/B(!``,`
M``!$(@$`$````$@B`0`,````62(!`!,```!F(@$`#0```'HB`0`"````B"(!
M``<```"+(@$`!@```),B`0`4````FB(!``P```"O(@$`&````+PB`0`&````
MU2(!`!(```#<(@$`#````.\B`0`#````_"(!`"H`````(P$`!````"LC`0`&
M````,",!``<````W(P$`'P```#\C`0`U````7R,!`"X```"5(P$`+P```,0C
M`0`7````]",!`"`````,)`$`&P```"TD`0`8````220!`"0```!B)`$`'P``
M`(<D`0`:````IR0!`"````#")`$`&@```.,D`0`R````_B0!`"\````Q)0$`
M*P```&$E`0`?````C24!`",```"M)0$`'P```-$E`0`:````\24!`"4````,
M)@$`)@```#(F`0`E````628!`"0```!_)@$`&````*0F`0`=````O28!`"0`
M``#;)@$`&``````G`0`B````&2<!`"4````\)P$`/````&(G`0`?````GR<!
M`",```"_)P$`'P```.,G`0`@`````R@!`!H````D*`$`&````#\H`0`F````
M6"@!`!X```!_*`$`*0```)XH`0`>````R"@!``D```#G*`$`#````/$H`0`7
M````_B@!`"\````6*0$`)````$8I`0`'````:RD!``\```!S*0$`%````(,I
M`0`.````F"D!``T```"G*0$`)````+4I`0`%````VBD!``<```#@*0$`(@``
M`.@I`0`E````"RH!`!T````Q*@$`&@```$\J`0`'````:BH!`,<```!R*@$`
M"P```#HK`0`5````1BL!``8```!<*P$`"0```&,K`0`+````;2L!`!<```!Y
M*P$`!@```)$K`0`S````F"L!`!,```#,*P$`$P```.`K`0`'````]"L!``\`
M``#\*P$`!P````PL`0`R````%"P!`"$```!'+`$`$P```&DL`0`,````?2P!
M`!$```"*+`$`,@```)PL`0`(````SRP!``D```#8+`$`"@```.(L`0`4````
M[2P!``H````"+0$`'0````TM`0`(````*RT!``T````T+0$`$````$(M`0`Z
M````4RT!`!\```".+0$`"````*XM`0`:````MRT!``8```#2+0$`%0```-DM
M`0`'````[RT!``@```#W+0$`"0`````N`0`_````"BX!``<```!*+@$`#P``
M`%(N`0`.````8BX!`!````!Q+@$`"0```((N`0`)````C"X!``@```"6+@$`
M$P```)\N`0`'````LRX!`!D```"[+@$`"@```-4N`0`7````X"X!`!0```#X
M+@$`"@````TO`0`,````&"\!`!<````E+P$`!````#TO`0`J````0B\!`!$`
M``!M+P$`!P```'\O`0`"````AR\!`!````"*+P$`&````)LO`0`+````M"\!
M``,```#`+P$`"````,0O`0`&````S2\!``<```#4+P$`#0```-PO`0`+````
MZB\!`!0```#V+P$`%0````LP`0`.````(3`!`!4````P,`$`+P```$8P`0`@
M````=C`!`!P```"7,`$`#````+0P`0`Q````P3`!``D```#S,`$`#@```/TP
M`0`[````##$!`!4```!(,0$`!0```%XQ`0`2````9#$!`#\```!W,0$`$@``
M`+<Q`0`*````RC$!``8```#5,0$`!````-PQ`0`$````X3$!``H```#F,0$`
M$P```/$Q`0`%````!3(!``8````+,@$`!@```!(R`0`$````&3(!``P````>
M,@$`"@```"LR`0`*````-C(!``4```!!,@$`#````$<R`0`,````5#(!``T`
M``!A,@$`&````&\R`0`9````B#(!`!\```"B,@$`'0```,(R`0`1````X#(!
M``(```#R,@$`!````/4R`0`*````^C(!``8````%,P$`!0````PS`0`#````
M$C,!``P````6,P$`10```",S`0`:````:3,!`#4```"$,P$`*````+HS`0!3
M````XS,!`!D````W-`$`<@```%$T`0`@````Q#0!`#4```#E-`$`(0```!LU
M`0!%````/34!`#````"#-0$`*````+0U`0`I````W34!`"8````'-@$`8```
M`"XV`0`E````CS8!`"@```"U-@$`*````-XV`0`B````!S<!`#`````J-P$`
M$@```%LW`0`3````;C<!`!````""-P$`>0```),W`0`)````#3@!`',````7
M.`$`?````(LX`0`K````"#D!`!<````T.0$`%@```$PY`0`/````8SD!`!\`
M``!S.0$`0````),Y`0`?````U#D!`!P```#T.0$`40```!$Z`0`4````8SH!
M``H```!X.@$`!0```(,Z`0`&````B3H!``@```"0.@$`!0```)DZ`0`2````
MGSH!``P```"R.@$`$````+\Z`0`3````T#H!`!T```#D.@$`#P````([`0`;
M````$CL!`"0````N.P$`#P```%,[`0`*````8SL!``0```!N.P$`"0```',[
M`0`+````?3L!`!H```").P$`(@```*0[`0`(````QSL!``<```#0.P$`!0``
M`-@[`0`4````WCL!`"D```#S.P$`!P```!T\`0`(````)3P!``\````N/`$`
M&````#X\`0`4````5SP!``@```!L/`$`#````'4\`0`/````@CP!``<```"2
M/`$`!@```)H\`0`4````H3P!``8```"V/`$`"0```+T\`0`*````QSP!``P`
M``#2/`$``P```-\\`0`(````XSP!``0```#L/`$`"@```/$\`0`'````_#P!
M``4````$/0$`!`````H]`0`9````#ST!``(````I/0$`"0```"P]`0`&````
M-CT!``8````]/0$`!0```$0]`0`G````2CT!``0```!R/0$`#P```'<]`0`3
M````AST!``<```";/0$``@```*,]`0`'````ICT!``8```"N/0$`(0```+4]
M`0`&````UST!`!````#>/0$`'@```.\]`0`2````#CX!``8````A/@$`"0``
M`"@^`0`B````,CX!``<```!5/@$`!P```%T^`0`+````93X!``4```!Q/@$`
M`@```'<^`0`+````>CX!`,4!``"&/@$`#@```$Q``0`5````6T`!``T```!Q
M0`$`!P```']``0`(````AT`!``@```"00`$``@```)E``0`*````G$`!``4`
M``"G0`$`"@```*U``0`2````N$`!``T```#+0`$`"````-E``0`%````XD`!
M`!T```#H0`$`#`````9!`0`-````$T$!`!4````A00$`$````#=!`0`+````
M2$$!`!````!400$`"````&5!`0`3````;D$!``T```""00$`"@```)!!`0`+
M````FT$!``L```"G00$`#P```+-!`0`&````PT$!`!````#*00$`%@```-M!
M`0`+````\D$!`!(```#^00$`$@```!%"`0`(````)$(!`"T````M0@$`&0``
M`%M"`0`X````=4(!`$$```"N0@$`4P```/!"`0!1````1$,!`%D```"60P$`
M5P```/!#`0`[````2$0!``H```"$1`$`#@```(]$`0`6````GD0!``4```"U
M1`$`!@```+M$`0`9````PD0!``P```#<1`$`%````.E$`0`7````_D0!`"<`
M```610$`)@```#Y%`0`1````944!`!\```!W10$`#P```)=%`0`A````IT4!
M`!````#)10$`!````-I%`0`1````WT4!`!````#Q10$`!P````)&`0`4````
M"D8!`!$````?1@$`&````#%&`0`.````2D8!`!$```!91@$`"@```&M&`0`I
M````=D8!`!,```"@1@$`%P```+1&`0`0````S$8!`",```#=1@$`%`````%'
M`0`&````%D<!``<````=1P$`2@```"5'`0`,````<$<!``@```!]1P$`"P``
M`(9'`0`'````DD<!``@```":1P$`#P```*-'`0`(````LT<!``H```"\1P$`
M`P```,='`0`9````RT<!``\```#E1P$`&0```/5'`0`4````#T@!`!`````D
M2`$`$@```#5(`0`H````2$@!``P```!Q2`$`)P```'Y(`0`7````ID@!`",`
M``"^2`$`'0```.)(`0`2`````$D!`!(````320$`#@```"9)`0`?````-4D!
M``8```!520$`!@```%Q)`0`(````8TD!``X```!L20$`!P```'M)`0`+````
M@TD!``H```"/20$`$0```)I)`0`4````K$D!``@```#!20$`#P```,I)`0`6
M````VDD!`!````#Q20$`&@````)*`0`(````'4H!`!(````F2@$`!0```#E*
M`0`6````/TH!`!X```!62@$`#0```'5*`0`O````@TH!`#````"S2@$`"0``
M`.1*`0`'````[DH!`!0```#V2@$`!0````M+`0`%````$4L!`!`````72P$`
M"P```"A+`0`:````-$L!`#,```!/2P$`#P```(-+`0`F````DTL!`#,```"Z
M2P$`,0```.Y+`0`P````($P!``@```!13`$`!0```%I,`0`)````8$P!``@`
M``!J3`$`.0```'-,`0`M````K4P!`#@```#;3`$`4P```!1-`0`W````:$T!
M`#<```"@30$`-@```-A-`0`W````#TX!`"4```!'3@$`*@```&U.`0`W````
MF$X!`#T```#03@$`#P````Y/`0`3````'D\!`"<````R3P$`'````%I/`0`J
M````=T\!``X```"B3P$`"P```+%/`0`,````O4\!``8```#*3P$`#````-%/
M`0`:````WD\!`"8```#Y3P$`!@```"!0`0`'````)U`!`!8````O4`$`"0``
M`$90`0`(````4%`!``8```!94`$`#````&!0`0`(````;5`!``D```!V4`$`
M!@```(!0`0`%````AU`!``4```"-4`$`!P```)-0`0`&````FU`!``H```"B
M4`$`#0```*U0`0`4````NU`!`#\```#04`$`%P```!!1`0`7````*%$!`"4`
M``!`40$`#P```&91`0`)````=E$!``8```"`40$`!0```(=1`0`'````C5$!
M``<```"540$`!0```)U1`0`-````HU$!``8```"Q40$`$P```+A1`0`#````
MS%$!``@```#040$`"@```-E1`0`-````Y%$!``@```#R40$`(P```/M1`0`1
M````'U(!``D````Q4@$`$@```#M2`0`,````3E(!``<```!;4@$``P```&-2
M`0`#````9U(!`!0```!K4@$`%````(!2`0`(````E5(!``@```">4@$`"```
M`*=2`0`'````L%(!`%<```"X4@$`)````!!3`0`&````-5,!``8````\4P$`
M%P```$-3`0`:````6U,!`!P```!V4P$`+````)-3`0`;````P%,!`"X```#<
M4P$`<@````M4`0`E````?E0!``H```"D5`$`!P```*]4`0`>````MU0!`!(`
M``#65`$`$0```.E4`0`%````^U0!``\````!50$`#@```!%5`0`4````(%4!
M`!`````U50$`%````$95`0`/````6U4!`!4```!K50$`!0```(%5`0`7````
MAU4!`!L```"?50$`%P```+M5`0`4````TU4!``,```#H50$`!@```.Q5`0!H
M````\U4!``X```!<5@$`!````&M6`0`6````<%8!``4```"'5@$`!````(U6
M`0`>````DE8!`!@```"Q5@$`#````,I6`0`8````UU8!`!@```#P5@$`+0``
M``E7`0`.````-U<!`"(```!&5P$`"````&E7`0`:````<E<!`!@```"-5P$`
M$P```*97`0`<````NE<!`!@```#75P$`%````/!7`0`+````!5@!``@````1
M6`$`!P```!I8`0`0````(E@!`!4````S6`$`$````$E8`0`(````6E@!``4`
M``!C6`$`"P```&E8`0`,````=5@!``@```""6`$`#0```(M8`0`'````F5@!
M``8```"A6`$`$0```*A8`0`(````NE@!``P```##6`$`!P```-!8`0`%````
MV%@!``@```#>6`$`"````.=8`0`3````\%@!``L````$60$`#@```!!9`0`%
M````'UD!`!T````E60$`$````$-9`0`1````5%D!`#0```!F60$`1````)M9
M`0`?````X%D!`#$`````6@$`"````#):`0`*````.UH!``\```!&6@$`!P``
M`%9:`0`)````7EH!``P```!H6@$`"````'5:`0`/````?EH!``D```".6@$`
M$0```)A:`0`A````JEH!`"$```#,6@$`)````.Y:`0`D````$UL!`!@````X
M6P$`(0```%%;`0`;````<UL!`"4```"/6P$`&@```+5;`0`=````T%L!`!@`
M``#N6P$`(P````=<`0`I````*UP!`!L```!57`$`)@```'%<`0`P````F%P!
M`"X```#)7`$`$0```/A<`0`I````"ET!``X````T70$`L````$-=`0`0````
M]%T!`!@````%7@$`(P```!Y>`0`D````0EX!`!\```!G7@$`&P```(=>`0`@
M````HUX!`"$```#$7@$`+@```.9>`0`<````%5\!`!X````R7P$`*0```%%?
M`0!+````>U\!``\```#'7P$`!````-=?`0`2````W%\!``@```#O7P$`#@``
M`/A?`0`.````!V`!`!4````68`$`$@```"Q@`0`+````/V`!`!0```!+8`$`
M"@```&!@`0`$````:V`!``P```!P8`$`#P```'U@`0`/````C6`!`!,```"=
M8`$`#````+%@`0`Q````OF`!``L```#P8`$`$0```/Q@`0`$````#F$!``\`
M```380$`%0```"-A`0`8````.6$!``\```!280$``@```&)A`0`.````96$!
M``4```!T80$`$@```'IA`0`%````C6$!``L```"380$`#````)]A`0`#````
MK&$!``\```"P80$`$@```,!A`0`(````TV$!`!@```#<80$`$````/5A`0`*
M````!F(!`!`````18@$`$P```")B`0`(````-F(!``8````_8@$`"0```$9B
M`0`/````4&(!``X```!@8@$`#````&]B`0`8````?&(!``P```"58@$`#@``
M`*)B`0`C````L6(!`!,```#58@$`#````.EB`0`>````]F(!`!<````58P$`
M%0```"UC`0`'````0V,!`!D```!+8P$`)````&5C`0`J````BF,!`!$```"U
M8P$`#````,=C`0`&````U&,!``X```#;8P$`!0```.IC`0`G````\&,!`#\`
M```89`$`!0```%AD`0`)````7F0!`!X```!H9`$`"P```(=D`0`3````DV0!
M`!,```"G9`$`!P```+MD`0`.````PV0!``P```#29`$`&0```-]D`0`2````
M^60!`#@````,90$`&````$5E`0`0````7F4!`!4```!O90$`"````(5E`0!"
M````CF4!``@```#190$`)@```-IE`0`(`````68!`$@````*9@$`#````%-F
M`0`*````8&8!``L```!K9@$`"@```'=F`0`,````@F8!``@```"/9@$`%@``
M`)AF`0`'````KV8!``H```"W9@$`,0```,)F`0`/````]&8!``4````$9P$`
M!@````IG`0`#````$6<!``<````59P$`!P```!UG`0`*````)6<!``P````P
M9P$`#P```#UG`0`-````36<!``T```!;9P$`%````&EG`0`5````?F<!`!0`
M``"49P$`!0```*EG`0`%````KV<!``L```"U9P$`"````,%G`0`"````RF<!
M``4```#-9P$`#P```--G`0`A````XV<!`!(````%:`$`$````!AH`0`/````
M*6@!`!$````Y:`$`'@```$MH`0`,````:F@!`#$```!W:`$`+0```*EH`0`*
M````UV@!``H```#B:`$`"````.UH`0`.````]F@!`(L````%:0$`%@```)%I
M`0`(````J&D!`!````"Q:0$`!P```,)I`0`%````RFD!`"$```#0:0$`"```
M`/)I`0`'````^VD!``<````#:@$`!@````MJ`0`0````$FH!``X````C:@$`
M$0```#)J`0`/````1&H!`!L```!4:@$`$0```'!J`0`-````@FH!`!<```"0
M:@$`!P```*AJ`0`3````L&H!``@```#$:@$`"0```,UJ`0`4````UVH!``T`
M``#L:@$`.P```/IJ`0`9````-FL!``@```!0:P$`#0```%EK`0`=````9VL!
M`!D```"%:P$`(0```)]K`0`@````P6L!`!H```#B:P$`&P```/UK`0`E````
M&6P!`!H````_;`$`!0```%IL`0`=````8&P!`!````!^;`$`#@```(]L`0`#
M````GFP!``0```"B;`$`#0```*=L`0`.````M6P!``\```#$;`$`%P```-1L
M`0`+````[&P!``0```#X;`$`&````/UL`0`9````%FT!``\````P;0$`#0``
M`$!M`0`-````3FT!``X```!<;0$`'P```&MM`0`8````BVT!`"(```"D;0$`
M(P```,=M`0`/````ZVT!`!,```#[;0$`$P````]N`0`?````(VX!`!0```!#
M;@$`.P```%AN`0`I````E&X!`#H```"^;@$`10```/EN`0`]````/V\!`"P`
M``!];P$`/````*IO`0`D````YV\!``8````,<`$`!@```!-P`0`.````&G`!
M``X````I<`$`#0```#AP`0`(````1G`!``@```!/<`$`!````%AP`0`4````
M77`!``L```!R<`$`!0```'YP`0`C````A'`!`"0```"H<`$`#P```,UP`0!K
M````W7`!`!H```!)<0$`"0```&1Q`0`&````;G$!``H```!U<0$`!@```(!Q
M`0`(````AW$!``0```"0<0$`"0```)5Q`0`\````GW$!``H```#<<0$`$@``
M`.=Q`0`"````^G$!``0```#]<0$`!P````)R`0`5````"G(!`!(````@<@$`
M%````#-R`0`:````2'(!``(```!C<@$``@```&9R`0`.````:7(!``8```!X
M<@$`"@```']R`0`%````BG(!`!D```"0<@$`"````*IR`0`&````LW(!`!<`
M``"Z<@$`$````-)R`0`)````XW(!``<```#M<@$`!0```/5R`0`)````^W(!
M``T````%<P$`!@```!-S`0`&````&G,!`!D````A<P$`"P```#MS`0`)````
M1W,!`!````!1<P$`!0```&)S`0`2````:',!``<```![<P$`!P```(-S`0`8
M````BW,!`!T```"D<P$`!P```,)S`0`*````RG,!``0```#5<P$`"0```-IS
M`0`(````Y',!``L```#M<P$`"P```/ES`0`&````!70!``T````,=`$`!@``
M`!IT`0`$````(70!`#<````F=`$`00```%YT`0`X````H'0!`"8```#9=`$`
M!0````!U`0`/````!G4!``8````6=0$`"````!UU`0`?````)G4!`!H```!&
M=0$`!0```&%U`0`(````9W4!`!,```!P=0$`"````(1U`0`)````C74!`!<`
M``"7=0$`!@```*]U`0`&````MG4!`!4```"]=0$`!0```--U`0`+````V74!
M``P```#E=0$`"````/)U`0`)````^W4!``4````%=@$`+@````MV`0`T````
M.G8!`#P```!O=@$`)P```*QV`0`^````U'8!`#@````3=P$`*````$QW`0`R
M````=7<!`"T```"H=P$`-0```-9W`0`H````#'@!`!(````U>`$`$P```$AX
M`0`-````7'@!`#$```!J>`$`'````)QX`0`<````N7@!`!H```#6>`$`!P``
M`/%X`0`(````^7@!``<````">0$`"`````IY`0`F````$WD!`"0````Z>0$`
M,0```%]Y`0`)````D7D!`!@```";>0$`*````+1Y`0`6````W7D!`!(```#T
M>0$`!@````=Z`0`+````#GH!``P````:>@$`#@```"=Z`0`/````-GH!`#@`
M``!&>@$`@````']Z`0!F`````'L!``\```!G>P$`"P```'=[`0`,````@WL!
M`!$```"0>P$`$@```*)[`0`.````M7L!``<```#$>P$`#P```,Q[`0`(````
MW'L!`!0```#E>P$`$0```/I[`0`/````#'P!`!X````<?`$`,````#M\`0!]
M````;'P!`!````#J?`$`!0```/M\`0`4`````7T!`$D````6?0$`"0```&!]
M`0`U````:GT!``D```"@?0$`"0```*I]`0`2````M'T!``X```#'?0$`#@``
M`-9]`0`3````Y7T!`!4```#Y?0$`'P````]^`0`A````+WX!`!T```!1?@$`
M'P```&]^`0`@````CWX!`"(```"P?@$`&````--^`0`W````['X!``\````D
M?P$`$0```#1_`0`1````1G\!`!,```!8?P$`#0```&Q_`0`2````>G\!`!0`
M``"-?P$`#P```*)_`0`1````LG\!`#(```#$?P$`%@```/=_`0`4````#H`!
M`#P````C@`$`%````&"``0`*````=8`!`!,```"`@`$`(@```)2``0`2````
MMX`!`"@```#*@`$`&0```/.``0`9````#8$!`!<````G@0$`$@```#^!`0`?
M````4H$!`"(```!R@0$`&@```)6!`0`2````L($!`!<```##@0$`'````-N!
M`0`6````^($!``@````/@@$`&````!B"`0`$````,8(!``4````V@@$``@``
M`#R"`0`+````/X(!``0```!+@@$`$````%""`0`&````88(!``P```!H@@$`
M!P```'6"`0`&````?8(!``<```"$@@$`!0```(R"`0`(````DH(!`!@```";
M@@$`!@```+2"`0`)````NX(!``@```#%@@$`!@```,Z"`0`(````U8(!`!$`
M``#>@@$`$@```/""`0`/`````X,!`!`````3@P$`"@```"2#`0`1````+X,!
M``0```!!@P$`(0```$:#`0`/````:(,!``\```!X@P$`%@```(B#`0`+````
MGX,!``D```"K@P$`"P```+6#`0`O````P8,!``0```#Q@P$`"````/:#`0`$
M````_X,!``4````$A`$`$0````J$`0`&````'(0!``H````CA`$`"@```"Z$
M`0`%````.80!`",````_A`$`#@```&.$`0`1````<H0!`!4```"$A`$`%P``
M`)J$`0`<````LH0!`!H```#/A`$`!0```.J$`0`%````\(0!``D```#VA`$`
M&0````"%`0`'````&H4!``8````BA0$`#0```"F%`0`.````-X4!``<```!&
MA0$`"0```$Z%`0`0````6(4!``<```!IA0$`!0```'&%`0`/````=X4!``X`
M``"'A0$`"@```):%`0`0````H84!`!(```"RA0$`%````,6%`0`4````VH4!
M``T```#OA0$`%@```/V%`0`(````%(8!``4````=A@$`$@```".&`0!(````
M-H8!``8```!_A@$`#P```(:&`0`C````EH8!``\```"ZA@$`%0```,J&`0`.
M````X(8!``T```#OA@$`#P```/V&`0`)````#8<!``D````7AP$`#P```"&'
M`0`/````,8<!`!$```!!AP$`$````%.'`0`>````9(<!``H```"#AP$`"```
M`(Z'`0`,````EX<!``P```"DAP$`#````+&'`0`%````OH<!``P```#$AP$`
M"0```-&'`0`>````VX<!`&<```#ZAP$`$P```&*(`0`+````=H@!``4```""
MB`$`!0```(B(`0`2````CH@!`!0```"AB`$`$P```+:(`0`+````RH@!``(`
M``#6B`$`"@```-F(`0`O````Y(@!``,````4B0$`!0```!B)`0`F````'HD!
M``H```!%B0$`!0```%")`0`%````5HD!`!,```!<B0$`$@```'")`0`&````
M@XD!``@```"*B0$`!P```).)`0`$````FXD!``4```"@B0$`;@```*:)`0`*
M````%8H!``T````@B@$`'````"Z*`0`&````2XH!``4```!2B@$`%````%B*
M`0`I````;8H!`#(```"7B@$`$0```,J*`0`*````W(H!``H```#GB@$`$0``
M`/**`0`*````!(L!``D````/BP$`&0```!F+`0`G````,XL!`"D```!;BP$`
M*````(6+`0`/````KHL!`)$```"^BP$`CP```%",`0`&````X(P!``<```#G
MC`$`"````.^,`0`'````^(P!``X`````C0$`#`````^-`0`&````'(T!`$4`
M```CC0$`$````&F-`0`*````>HT!``8```"%C0$`'````(R-`0!A````J8T!
M``8````+C@$`"````!*.`0`&````&XX!`!0````BC@$`"0```#>.`0`(````
M08X!`"D```!*C@$`*````'2.`0`)````G8X!``4```"GC@$`*P```*V.`0`D
M````V8X!`&<```#^C@$`*0```&:/`0`@````D(\!`!<```"QCP$`+@```,F/
M`0`8````^(\!``(````1D`$`#0```!20`0`%````(I`!`!0````HD`$`"@``
M`#V0`0`%````2)`!``@```!.D`$`!@```%>0`0`)````7I`!``L```!HD`$`
M!P```'20`0`(````?)`!``L```"%D`$`!@```)&0`0`.````F)`!`!````"G
MD`$`$0```+B0`0`)````RI`!``T```#4D`$`#P```.*0`0`0````\I`!`!8`
M```#D0$`&````!J1`0`/````,Y$!``T```!#D0$`#P```%&1`0`(````89$!
M`!X```!JD0$`$P```(F1`0`(````G9$!``H```"FD0$`%@```+&1`0`'````
MR)$!``\```#0D0$`(@```."1`0`%`````Y(!``<````)D@$`!0```!&2`0`%
M````%Y(!``@````=D@$`$0```":2`0`1````.)(!`!H```!*D@$`%@```&62
M`0`4````?)(!`!<```"1D@$`&@```*F2`0`?````Q)(!`!@```#DD@$``P``
M`/V2`0`%`````9,!``X````'DP$`#@```!:3`0`6````)9,!``T````\DP$`
M(@```$J3`0`+````;9,!`!0```!YDP$`!P```(Z3`0`*````EI,!``4```"A
MDP$`#@```*>3`0`)````MI,!``4```#`DP$`!P```,:3`0`#````SI,!``0`
M``#2DP$``@```->3`0`^````VI,!`#0````9E`$`*@```$Z4`0`I````>90!
M`!0```"CE`$`*@```+B4`0!%````XY0!``H````IE0$`+````#25`0`S````
M894!`#@```"5E0$`.````,Z5`0`]````!Y8!`!0```!%E@$`&@```%J6`0`;
M````=98!`!X```"1E@$`'````+"6`0`;````S98!`!\```#IE@$`&P````F7
M`0`;````)9<!``X```!!EP$`,````%"7`0`P````@9<!`#0```"REP$`/0``
M`.>7`0`R````)9@!`"\```!8F`$`<@```(B8`0`F````^Y@!``P````BF0$`
M'0```"^9`0`*````39D!`!H```!8F0$`,P```'.9`0`U````IYD!`"<```#=
MF0$`#0````6:`0!$````$YH!`#\```!8F@$`!0```)B:`0`;````GIH!`!8`
M``"ZF@$`$@```-&:`0`1````Y)H!`!D```#VF@$`!@```!";`0`'````%YL!
M``D````?FP$`#@```"F;`0`*````.)L!`!0```!#FP$`#@```%B;`0`1````
M9YL!``@```!YFP$`'@```(*;`0`(````H9L!``4```"JFP$`"P```+";`0`-
M````O)L!``L```#*FP$`.@```-:;`0`"````$9P!``8````4G`$`#@```!N<
M`0`)````*IP!``4````TG`$`$@```#J<`0`(````39P!``0```!6G`$`,P``
M`%N<`0`.````CYP!`"D```">G`$`4````,B<`0`5````&9T!`#H````OG0$`
M(````&J=`0`/````BYT!``@```";G0$`(0```*2=`0`/````QIT!``\```#6
MG0$`"@```.:=`0`4````\9T!``P````&G@$`&@```!.>`0`5````+IX!``<`
M``!$G@$`$0```$R>`0`.````7IX!`!$```!MG@$`(0```'^>`0`4````H9X!
M`!(```"VG@$`$````,F>`0`C````VIX!``<```#^G@$`"P````:?`0`4````
M$I\!`!(````GGP$`$0```#J?`0`:````3)\!`!````!GGP$`#````'B?`0`'
M````A9\!``@```"-GP$`!0```):?`0`A````G)\!``8```"^GP$`$0```,6?
M`0`(````UY\!``X```#@GP$`!0```.^?`0`/````]9\!`"\````%H`$`$@``
M`#6@`0`&````2*`!``<```!/H`$`%P```%>@`0`&````;Z`!`!(```!VH`$`
M!0```(F@`0`5````CZ`!``0```"EH`$`!P```*J@`0`6````LJ`!`#$```#)
MH`$`!0```/N@`0`3`````:$!`!`````5H0$`!````":A`0`.````*Z$!``@`
M```ZH0$`!P```$.A`0`*````2Z$!``@```!6H0$`!@```%^A`0`%````9J$!
M`"````!LH0$`-0```(VA`0`U````PZ$!`!L```#YH0$`)````!6B`0`C````
M.J(!`#\```!>H@$`&P```)ZB`0`A````NJ(!`"8```#<H@$`+0````.C`0`D
M````,:,!``8```!6HP$`"````%VC`0`)````9J,!``L```!PHP$`%P```'RC
M`0`0````E*,!`"X```"EHP$`)````-2C`0`T````^:,!`#@````NI`$`$0``
M`&>D`0`B````>:0!`!(```"<I`$`!@```*^D`0`;````MJ0!`!(```#2I`$`
M$0```.6D`0`-````]Z0!``<````%I0$`#@````VE`0`(````'*4!``L````E
MI0$`#````#&E`0`;````/J4!`#0```!:I0$`"0```(^E`0`%````F:4!``D`
M``"?I0$`&@```*FE`0`&````Q*4!`!$```#+I0$`!````-VE`0`*````XJ4!
M``L```#MI0$`$````/FE`0`.````"J8!``P````9I@$`%@```":F`0`%````
M/:8!``4```!#I@$`#P```$FF`0`L````6:8!`$L```"&I@$`!P```-*F`0`.
M````VJ8!`!8```#II@$`'0````"G`0`:````'J<!``4````YIP$`$@```#^G
M`0`3````4J<!`!````!FIP$`!P```'>G`0`1````?Z<!`"P```"1IP$`"0``
M`+ZG`0`.````R*<!`!$```#7IP$`%0```.FG`0`-````_Z<!`#D````-J`$`
M"0```$>H`0`=````4:@!`!,```!OJ`$`%P```(.H`0`O````FZ@!``\```#+
MJ`$`#P```-NH`0`1````ZZ@!`!$```#]J`$`%P````^I`0`>````)ZD!``@`
M``!&J0$`%P```$^I`0`2````9ZD!`"8```!ZJ0$`!P```*&I`0`4````J:D!
M`!H```"^J0$`!P```-FI`0`'````X:D!`!````#IJ0$`#P```/JI`0`1````
M"JH!``4````<J@$`"````"*J`0`-````*ZH!``T````YJ@$`#@```$>J`0`0
M````5JH!`!````!GJ@$`!@```'BJ`0`(````?ZH!`!@```"(J@$`%0```*&J
M`0`:````MZH!`!@```#2J@$`#@```.NJ`0`(````^JH!`"X````#JP$`)@``
M`#*K`0`D````6:L!``<```!^JP$`#@```(:K`0`&````E:L!`!<```"<JP$`
M%P```+2K`0`B````S*L!``H```#OJP$`"P```/JK`0`#````!JP!``8````*
MK`$`#````!&L`0`"````'JP!``P````AK`$`$P```"ZL`0`+````0JP!`!D`
M``!.K`$`(````&BL`0`2````B:P!``4```"<K`$`"@```**L`0`5````K:P!
M`!$```##K`$`#@```-6L`0`&````Y*P!``D```#KK`$`$````/6L`0`0````
M!JT!`$H````7K0$`%P```&*M`0`$````>JT!``8```!_K0$`$P```(:M`0`:
M````FJT!`!T```"UK0$`'P```-.M`0`(````\ZT!`!0```#\K0$`"P```!&N
M`0`.````':X!``P````LK@$`"P```#FN`0`B````1:X!`!<```!HK@$`#0``
M`("N`0`C````CJX!`!P```"RK@$`#0```,^N`0`5````W:X!`&(```#SK@$`
M(@```%:O`0`6````>:\!`"L```"0KP$`(````+RO`0`4````W:\!`!X```#R
MKP$`%@```!&P`0`?````*+`!`!L```!(L`$`&````&2P`0`*````?;`!``H`
M``"(L`$`!P```).P`0`'````F[`!``0```"CL`$`$P```*BP`0`-````O+`!
M`!$```#*L`$`"````-RP`0!!````Y;`!`#P````GL0$`0@```&2Q`0!@````
MI[$!`"H````(L@$`"0```#.R`0`^````/;(!`"\```!\L@$`"@```*RR`0`*
M````M[(!``X```#"L@$`.P```-&R`0`(````#;,!`!<````6LP$`&````"ZS
M`0`X````1[,!`"X```"`LP$`(@```*^S`0`/````TK,!`"D```#BLP$`&```
M``RT`0`P````);0!`"(```!6M`$`*````'FT`0`B````HK0!``\```#%M`$`
M"````-6T`0`.````WK0!``\```#MM`$`$````/VT`0`'````#K4!`#T````6
MM0$`#````%2U`0`.````8;4!``8```!PM0$`%0```'>U`0`(````C;4!``@`
M``"6M0$`#P```)^U`0`)````K[4!``D```"YM0$`!P```,.U`0`0````R[4!
M`!````#<M0$`%@```.VU`0`7````!+8!`!$````<M@$`&P```"ZV`0`3````
M2K8!``@```!>M@$`#0```&>V`0`,````=;8!``\```""M@$`#````)*V`0`9
M````G[8!`"P```"YM@$`#P```.:V`0`?````]K8!`"@````6MP$`"````#^W
M`0`&````2+<!`!````!/MP$`"0```&"W`0`$````:K<!`!@```!OMP$`#@``
M`(BW`0`0````E[<!``X```"HMP$`!0```+>W`0`)````O;<!``@```#'MP$`
M"0```-"W`0`+````VK<!`!$```#FMP$`!````/BW`0`V````_;<!``X````T
MN`$`!0```$.X`0`+````2;@!``X```!5N`$`(0```&2X`0`*````AK@!``(`
M``"1N`$`'P```)2X`0`'````M+@!``4```"\N`$`"P```,*X`0`'````SK@!
M`#(```#6N`$`)`````FY`0`Q````+KD!`!<```!@N0$`!0```'BY`0`'````
M?KD!``<```"&N0$`#````(ZY`0`(````F[D!``T```"DN0$`$P```+*Y`0`/
M````QKD!``P```#6N0$`#@```..Y`0`+````\KD!``<```#^N0$`"`````:Z
M`0`(````#[H!`!8````8N@$`"0```"^Z`0`'````.;H!``D```!!N@$`(```
M`$NZ`0`%````;+H!``8```!RN@$`!@```'FZ`0`*````@+H!``<```"+N@$`
M$@```).Z`0`2````IKH!``8```"YN@$`%@```,"Z`0`+````U[H!`!L```#C
MN@$`!````/^Z`0`%````!+L!``\````*NP$`'````!J[`0`'````-[L!``D`
M```_NP$`%0```$F[`0`$````7[L!``H```!DNP$`#P```&^[`0`*````?[L!
M``(```"*NP$`$0```(V[`0`'````G[L!`!X```"GNP$`'@```,:[`0`S````
MY;L!`"4````9O`$`*0```#^\`0!=````:;P!`!,```#'O`$`5````-N\`0`N
M````,+T!`$$```!?O0$`7@```*&]`0`@`````+X!`!,````AO@$`2@```#6^
M`0`H````@+X!`#(```"IO@$`(P```-R^`0`=`````+\!`"P````>OP$`[@$`
M`$N_`0`;````.L$!`!0```!6P0$`1@```&O!`0"%````LL$!`#\````XP@$`
M,0```'C"`0!+````JL(!`#@```#VP@$`'````"_#`0`5````3,,!`!@```!B
MPP$`%P```'O#`0`K````D\,!`!P```"_PP$`'P```-S#`0`3````_,,!``P`
M```0Q`$`+P```!W$`0`>````3<0!`!\```!LQ`$`(0```(S$`0!"````KL0!
M`%````#QQ`$`-0```$+%`0!A````>,4!`$8```#:Q0$`(P```"'&`0`E````
M1<8!`"\```!KQ@$`)P```)O&`0`L````P\8!`$<```#PQ@$`4````#C'`0!!
M````B<<!`$X```#+QP$`+0```!K(`0`E````2,@!`"4```!NR`$`)@```)3(
M`0!J````N\@!`&@````FR0$`K@```(_)`0`;````/LH!`"H```!:R@$`-@``
M`(7*`0`O````O,H!`$4```#LR@$`(````#++`0!1````4\L!`"$```"ERP$`
M"P```,?+`0"U````T\L!`#P```")S`$`(@```,;,`0`J````Z<P!`"L````4
MS0$`'````$#-`0`O````7<T!``8```"-S0$`!@```)3-`0`#````F\T!``X`
M``"?S0$`"P```*[-`0`*````NLT!``L```#%S0$`!0```-'-`0`,````U\T!
M``0```#DS0$`;@```.G-`0`$````6,X!`!8```!=S@$`!````'3.`0`'````
M><X!``4```"!S@$`!0```(?.`0`$````C<X!`!````"2S@$`"````*/.`0`1
M````K,X!`!,```"^S@$``@```-+.`0`'````U<X!``<```#=S@$`%````.7.
M`0`,````^LX!`!8````'SP$`!@```![/`0`3````)<\!``P````YSP$``P``
M`$;/`0`H````2L\!``0```!SSP$`!@```'C/`0`(````?\\!`!L```"(SP$`
M-````*3/`0`G````V<\!`"@````!T`$`$P```"K0`0`@````/M`!`!T```!?
MT`$`&P```'W0`0`@````F=`!`!L```"ZT`$`&@```-;0`0`B````\=`!`!0`
M```4T0$`,0```"G1`0`O````6]$!`"8```"+T0$`&@```++1`0`>````S=$!
M`!X```#LT0$`&0````O2`0`C````)=(!`!T```!)T@$`*````&?2`0`@````
MD-(!`!L```"QT@$`(````,W2`0`C````[M(!`!D````2TP$`(0```"S3`0`>
M````3M,!`#8```!MTP$`'@```*33`0`B````P],!`"(```#FTP$`(P````G4
M`0`=````+=0!`!@```!+U`$`(@```&34`0`A````A]0!`#(```"IU`$`(```
M`-S4`0`*````_=0!``L````(U0$`%@```!35`0`H````*]4!`!T```!4U0$`
M"@```'+5`0`/````?=4!`!<```"-U0$`#@```*75`0`6````M-4!`"$```#+
MU0$`"````.W5`0`'````]M4!`"(```#^U0$`)0```"'6`0`E````1]8!`!8`
M``!MU@$`"@```(36`0#<````C]8!`!$```!LUP$`%0```'[7`0`,````E-<!
M``\```"AUP$`%@```+'7`0`C````R-<!``8```#LUP$`0````//7`0`5````
M--@!`!0```!*V`$`!P```%_8`0`3````9]@!``H```![V`$`-P```(;8`0`I
M````OM@!`!8```#HV`$`%````/_8`0`4````%-D!`#$````IV0$`$0```%O9
M`0`2````;=D!`!,```"`V0$`$0```)39`0`*````IMD!`!<```"QV0$`"```
M`,G9`0`1````TMD!`!$```#DV0$`.@```/;9`0`@````,=H!``@```!2V@$`
M$P```%O:`0`'````;]H!`!$```!WV@$`!P```(G:`0`(````D=H!``D```":
MV@$`-@```*3:`0`%````V]H!``\```#AV@$`%````/':`0`1````!ML!``L`
M```8VP$`#````"3;`0`'````,=L!`!,````YVP$`"P```$W;`0`;````6=L!
M`!````!UVP$`&@```(;;`0`7````H=L!``L```"YVP$`#````,7;`0`8````
MTML!``D```#KVP$`*@```/7;`0`1````(-P!``H````RW`$``@```#W<`0`0
M````0-P!`!<```!1W`$`"P```&G<`0`#````==P!``H```!YW`$`!0```(3<
M`0`'````BMP!``P```"2W`$`"P```)_<`0`4````J]P!`!4```#`W`$`#@``
M`-;<`0`-````Y=P!`#@```#SW`$`&````"S=`0`8````1=T!``H```!>W0$`
M)0```&G=`0`,````C]T!`!4```"<W0$`/@```++=`0`6````\=T!``4````(
MW@$`%@````[>`0`\````)=X!``T```!BW@$`#@```'#>`0`&````?]X!``0`
M``"&W@$`!````(O>`0`*````D-X!`!<```";W@$`!0```+/>`0`&````N=X!
M``@```#`W@$`!0```,G>`0`4````S]X!`!4```#DW@$`"@```/K>`0`%````
M!=\!``P````+WP$`#````!C?`0`-````)=\!`!<````SWP$`'@```$O?`0`?
M````:M\!`!H```"*WP$`$````*7?`0`"````MM\!``0```"YWP$`"P```+[?
M`0`%````RM\!``4```#0WP$``P```-;?`0`.````VM\!`$P```#IWP$`'```
M`#;@`0`J````4^`!`"8```!^X`$`3@```*7@`0`?````].`!`%T````4X0$`
M'0```'+A`0!'````D.$!`"````#8X0$`,0```/GA`0`S````*^(!`"@```!?
MX@$`-````(CB`0`V````O>(!`#H```#TX@$`-````"_C`0`P````9.,!`"@`
M``"5XP$`(@```+[C`0`X````X>,!`!0````:Y`$`%0```"_D`0`.````1>0!
M`&$```!4Y`$`"@```+;D`0!C````P>0!`&D````EY0$`)P```(_E`0`;````
MM^4!`!@```#3Y0$`$0```.SE`0`=````_N4!`#D````<Y@$`(@```%;F`0`;
M````>>8!`&H```"5Y@$`%@````#G`0`*````%^<!``0````BYP$`!@```"?G
M`0`(````+N<!``4````WYP$`%0```#WG`0`/````4^<!`!(```!CYP$`&0``
M`';G`0`C````D.<!``\```"TYP$`&@```,3G`0`F````W^<!``T````&Z`$`
M#@```!3H`0`$````(^@!``D````HZ`$`#0```#+H`0`5````0.@!`"0```!6
MZ`$`"@```'OH`0`(````AN@!``D```"/Z`$`%@```)GH`0`E````L.@!``L`
M``#6Z`$`"@```.+H`0`5````[>@!`!P````#Z0$`%@```"#I`0`)````-^D!
M``8```!!Z0$`$P```$CI`0`'````7.D!``H```!DZ0$`%@```&_I`0`*````
MAND!``D```"1Z0$`#0```)OI`0`'````J>D!``(```"QZ0$`"````+3I`0`(
M````O>D!``P```#&Z0$`!@```-/I`0`$````VND!``8```#?Z0$`&0```.;I
M`0`"`````.H!``@````#Z@$`!@````SJ`0`&````$^H!``4````:Z@$`*0``
M`"#J`0`%````2NH!`!,```!0Z@$`&0```&3J`0`(````?NH!``0```"'Z@$`
M!P```(SJ`0`&````E.H!`"````";Z@$`"@```+SJ`0`0````Q^H!`!T```#8
MZ@$`&0```/;J`0`(````$.L!``P````9ZP$`(P```";K`0`*````2NL!``D`
M``!5ZP$`$````%_K`0`%````<.L!``(```!VZP$`"P```'GK`0`!````4@4`
M`&,&``#5!@``A04``$L$```T!@``M````)`"``";!```QP4``#$$``!S`0``
M`````"L`````````````````````````C`$``'@#```2!```8`(``(\```#:
M`0``U0$``*8$``#%````J@8```````#(`0``:@0``.8`````````S0``````
M````````T00```````"B!0```````&(&````````/P<``$@&``#U`@``````
M`*,%```(`0```````-8!``!`````B04````````S!P``W@0``/T#``#T!```
MW0(``!\&``"-!@`````````````<`@``0`0``*L#```W`@``O0,``#$'``#Q
M!@``"@````````#<!```0@,``!\#```(````0P4``"('```V`@``JP8``',&
M``!N!```:@8``$<"``#Y`@``5@```'<```"1`P``;0(``.4&````````T`8`
M`/X"``!X!@```````%@```#;!@```````($%````````\@(``!D#``#>!@``
M"0``````````````80```&8%``````````````````!`!@```````,$`````
M````!`8``"$"```J!```1P,``/L!````````[P0````````;!```K`4``!@'
M``"\`0``%@(```````"M`0``````````````````+`8``)<#``!=!@``````
M```````"!0``QP8```````#>!0``)`8`````````````$0``````````````
ML0,``#@%``"+`@`````````````_`0``A@$``/<$``!K````#00``-0$```9
M!````@8``'4#```\`@``@P0``#0$``!^````L`(``$D%``#``````````'<!
M````````7P4``&@#``#'!```)0$``%<```"8`@``Q`0``+P%``">!@``@@(`
M`","``"Q`0``[P8``.0$``"`!````````(T"``"G`P``F0$``-D#```7!0``
M`````#@"``!X!0``.@4``%L&``"$````4`,``,$$```Y!0````````\$````
M````ZP$```````"<`@``+`,``%T`````````?@,`````````````500``(`#
M```$`````````%<&```G`@``P@````````"+!````````&T```!_`0``U`4`
M`"8````E!P``#P<``!T&```R!@``5`8````````Y!P``^`(``#4`````````
MU04``'0%````````DP4``#$%``"<!@```````&D%``!F`@``D08``#$#````
M````3P0``"T%``!J`0``)0````````"(!0``.P8``!`%``".`P``NP8``,0%
M``!>`@``FP4``````````````P8```@$```0!P``V00````````7`0``````
M``````#T````^04``)4#``#=````7````)4```#B!0``7@8``!`&``!B`0``
M&@````H'`````````````&8#``!,`P````````````"&!@````````````"W
M!@``.`8``"T#``"6!@``$04``!$"``````````````8#``#E!````````#H!
M``"/`P``9@0```L$`````````````(8$```2````:P$``.8#``"4`P```0,`
M`+8"````````!00``%,"``#L`0``)@8``.$"```[````L04``%D&````````
M``````,```"'`@`````````````^`P``'0,``'P#`````````````"L'``"(
M!```^@,``,\```!L!```2@8``-T!````````.````#`%``!;`````@,``!H%
M``"U!@``R0````\%``"?!```6@,``.8"``#C````4````$P&``"_!```00(`
M```````7`@``00,``/\&```<`P``CP4``&(```"6`0```````,\$```$`0``
M,`8``$8#````````?0,``$P`````````Y`$```X&```;!@```````+<#````
M`````````'D#``#&`@``O@````````!^`@``PP$``*,!```6`P``K@```$@`
M``")`@``H`(```L#```U!0```````$`'`````````````#P#````````M04`
M`.L`````````RP(``$`#``"(````,@```"H&``!P!0``R`0``$`%````````
M`````-T#```!!@``!04``($#```S!```Z`,`````````````#````+X#````
M````M`,```````````````````D!``!T!@```````#\&``!V!```T`4`````
M``#J!0``&@<``%\&```_!```^`,``-X#``#G!```104``#D$```!!P``RP$`
M```````J!0``Q0,``!$#``"Z!0``U@8``+8%````````*0(``-\"``"L!@``
M-@<```````"F`@``!0(``$`"``!:`0``N0$``',#```&`@```````&H%``"O
M!@```````*H%``````````````````#&!@``QP,```X%````````E@(`````
M``")`P``;P,``,H!``"#`0``<0$``+L!````````@`(`````````````!`4`
M`)(&```O`P``]0```#H&``"H`P``>08``-P&````````]P,``+`$````````
ML@8`````````````K`,``(`&``#C!```EP0``#T"````````YP8```````"H
M!@``>P0```H$````````;0$``+,!``#8!@``````````````````$@,`````
M```+!P``!0```!(!``!!!@``,P,``.D&``"D!@```````!,!``!N!0``*@<`
M`'(&```.!P``B08``/(%```W!0``404``'H"``!R`0``1@0``(`!```N!@``
M&`4``&D````:!@``Q08```````"G`0`````````````,`P```````*$"````
M```````````````8`P````````````#L`@``%04``!0!````````9P8`````
M```.!```V@0`````````````=P(```@#``":!0```````'H%````````T`$`
M``````!,!0```````/\"``!'!@``!P0`````````````LP(```````#-!0``
M1````.X!``!B`@```````!4&```5`@``4P8````````A`0``P@8``#(%````
M````.@0`````````````7`8``*0```"0!0``!0$``)P%``"8`P``BP$``&P&
M```@!@``,0```'P%``!]`@``3P,``'H&``!?`P``4`8`````````````F`0`
M`#('````````:````*X$``"Q!```&P<````````=`0```````*0#````````
MS@(``*X%```P`0```````!<```"D`0``$00``,T$```I!P``^08````````^
M!P``*`(``,,&``"!`@``[`````````"C`@``Z``````````^!```"`(`````
M``#`!0``$@4``-8$````````RP,``-T&````````"0(```````!C`@``````
M`,$&``!#!```U00``&`$``!;`0``^0```&@!``#;`0````````````"T!0``
M`````$H$``"J`````````%(&`````````````)H"````````.08``"P`````
M````J0```"\$``"O`@``,`,``!T"`````````````*@"````````[@4``&H`
M````````O`8``+X&````````FP$`````````````(P,``.`%``#&`P``````
M`+\&``!M!````````!<#``##`@````4``((```#.!```*P0`````````````
MQP```#P!```I!0``-0(``#`$````````*````-<!``#9`````````(($````
M````S@4``)D$``"-`P``DP8`````````````2@,``&D&````````L0(``%D#
M``#I`````````*`&``#``@``S0,```````")!```&`8``!,"```Q`0``'04`
M`+(```!)!```%@```(P```"<`````````*8&`````````````!,&``!]!0``
M`````*P!````````D00``)T!````````]@,``*0"``#+!@``#08``$L```##
M``````````````#.`0``=`0``$@!``#1````.`$``*<$``":!@``?08``!X#
M``````````````````!_`P``400``(0%``"U````Z0(``+0$``"&!0``6`,`
M`($$``"Q!@``GP,``.`!``#>`0```````$P$```^````C`4```````":!```
M``````D%````````]P4``$(%``#$`````````#D"````````>P```%X%``!2
M````20$``'(%````````^P,``!H!``!L````4`0````````@!0```````/@$
M``#O!0```````)\```!R!```T`,`````````````%`8``!$&``#J!@``/P(`
M`+L$``#A`0``]@$```````#G`P``+P````````#/`0``$@8``'L"````````
M00$``#L!````````5@0``-H"``"M`P``F08``/@!``"R`P``S@```!\```!.
M`0``?@4```````"A`P```````%`"````````J`0``)\&````````%P0``#($
M``!5`P``2`0``#L%``!1`P``?P0``/4%``!P`0``5`(``'D!```;`P``O```
M`.H"``#T!0```````,`$````````OP,``(,&``#B!```T@4``",%``"U`0``
M)P8``&P%```T````004``!0#````````?`$``!T$```G!0````````````"*
M!@``U@(``&L%``#B`@``)@,``/`#````````-@```)T&``!K`@``6P(``%X#
M``#A!0``M`$``",!`````````````+P$``"I`0``B`$``%@%````````U```
M`!H#``#B!@``9@8``-$"````````Y0$``/L&```0!```60```"8'````````
M``````````"R`@````````````"B!```M@,``,,%```!!```_00``)X`````
M`````````.D!``"*`P```````.<"``````````8``*(````9`0```````%,$
M``!0!0```````.P$````````0@`````#``!;!0```````"4&```)!```K04`
M`&0&``!A!````````"L#``#1!@```````$D"````````.`0``&X"``"+````
M90```$0!````````.@(``$T#```_`P``,P```-4`````````4P$````````#
M`P``O0```,D"``!Z!```$0$``)\!```F`@````````````";````*`,``'@$
M``!I!````````(<!``"+`P``(0```#4#``!+`P``=`$``!H"````````(04`
M``````#8`@``````````````````2`(```````"@`0``#`<``'$```"2````
MX`0``%<%````````=00``-\$````````,P4``#<$``"-`````````+````"#
M````0@(``/(!``"@`P``%`<``*<&``#M`@``"0<``-\%``!1````/````!D`
M``!-`0````````X#````````````````````````$P,``-T%``!U`@``I`0`
M``````!"!@```P4``.P#````````9`,``-P```#2!@``#`$``*X"``"$!@``
ME`0``-L%````````_`(``%T$```B!@```````%P!```D!```+@0``"<#````
M````O@4``/H&```````````````````9!0``#P(``"<'``!-!0```````.@&
M``!3`P`````````````<!0``:0$``*0%`````````````*@`````````````
M``L%```N!P``9`4``$@%``"O!0``N@```+H!``">`0```````'X&``#3!0``
M``````T```!\!```10(``!X&``!)!@``'@$``#,&````````?00``+\!```-
M!0```````.4`````````E@4```````!G`P``=@$``(H"``"'!```-`(`````
M``#J`0``LP4``!T'````````D0(``!4'``!%!```\`````````"N!@``[0``
M`*P```!/`0``N04``.,#```[`P``HP,```````!3````\@```-X"``!O!0``
M(00``$P"```$`@`````````````2!P``_`4``%8"``!8`@``[0,``(X"````
M````804``/P!```@````<0(``&$"```V!```;@````````#[!```(@$```<!
M`````````````%D%``"U!````````'`&````````T0$``"(%```W`P``&P(`
M`"<$``"X`@```````#T!`````````````$4```!L`0``````````````````
MXP$``*$$```M!P```````$8%``#\````0P(````````5````F0(``!8%```"
M`@``5@$```````"X!@`````````````5!````````%H"```4`@``@@8``-D"
M`````````````/X#```'`P````````````!6!@``3P(``"$#``!Q!@``?P4`
M`%4``````````````-,````)!@```````%$!``!E!```M@0``.D$````````
M`````'$$``!1!@``5`0```````#Y!```W@```,X&```^`@``Q`8``/8"````
M````_08``/0&```$!P```````",`````````%0$``&0````<````B@```(4!
M````````-08``(,"``!#````=P8``+`#``#O````,@,``.0````T!0``_@$`
M`+L#````````80,``(,#``#-`@``O04`````````````%`4``!D&``#K`@``
MVP,``-`"``!&`0``(`,```````!/`````````$\&```X`P``A@````````"X
M````N00``.4#``"B`@``"P(``.<%``#9`0``0P8````````V`0``*00`````
M`````````````*8#``"7````\04````````:!```-@8``,8%``#\`P``_@0`
M`*8`````````O08``$<%``!>!```AP4``-,!``#I`P``T@```(<#```K!@``
MR`,``*4&```]!P````````````#N!```M`8```H%````````,`<``'H`````
M````6`8```````!'````QP$```($``#S!@```````.$#```U!P``Q0$``-0&
M````````9P0``+4"``!#!P````````````#D`@``````````````````)0(`
M`,(%``![`0`````````'```K!0``.P(`````````````5`,```````"S!```
MZ@,``"\"```M!```B@0````````0`@`````````````.`0``O@(``*``````
M````&`0```````#D!@`````````$``#R!```#`4```````"3!```P`8``+`!
M``#,`@``U@```,H&```4!```704``!\$```@!P``#P,```````#Z!0``````
M`(<```",`@```````-@#``#,!0``"@,``+`%``"_!0``60(``.\#``!J`@``
MA`$``*8%```*!@````````````#5`@``J0,``/8````7!@``LP8``/P$``"<
M`0```````%X!````````4`$``)$%`````````````$X#``#T`P``-P```)0!
M```R`@``G@,``%4!````````;04``!8$`````````````#$&``"Z!```)00`
M`.8!``"J`@``ZP4``(@"``"1````70(``)L"``#4`0``$P<``!P'``!+`0``
MZ@0``#<&````````:P8``$X```":`0````````````"[!0```````,T!````
M````=04``#<'``!<`P``_04```<'```L!P``(@,````````I!@``J0(`````
M``#)!```N@(``,D&```Y`0```````,\%``!"!````````$0#``">!0``E@``
M`-D&``#1`P``N@,``)P#```'````P@$````````M!@``*`4``!X"```&````
M`````%D!``"U`P``V@,```X```"G!0``9`0```(!``````````````````!$
M!```A00``'D$``"=`@````````````!]`0``-`<```````!%!@```````#\%
M``#(!@``L@0``.``````````/`0``",&```&!```5P0``,P&``"&`P``;@,`
M``````":````QP(``&,%````````$````-(!``!2!```<04``-<"``"&`@``
M5```````````````!P8``+D"````````T@(``/4$````````Y`4``"H```!2
M`0```````&P#``"O`0``(`0``&D#``"<!```'@<``($!````````5P$``,P`
M```O`0``#0<```,"``!B!```H04```(```"B`P``[@8``&\!``#H!```````
M`)0`````````!@8````````M`0``<`,``&<%``"]`@```````$X&``#)!0``
MBP4``#,"```>!0```````$D`````````>`$``,($``#;`@```````&,#``#A
M!````````&H#``"+!@``7`(``&<"```8````Y@4```P$`````````````*H#
M``#,`0``(P<``"X#````````M@```$T"```A!P``V`$`````````````/@$`
M`"\'```(!0``(@0``,`!``#``P``!P4``*T$``!.!```D`,```````!-!@``
MX`8``,P#```D!P```````````````````````&,```#G`0``&`(``/0"```L
M`0``D@0``#X%`````````````-4#`````````````&(#``#+!0``````````
M``";`P``@`4``%H%``!5`@``:`0`````````````)`$``.P&``"S````[08`
M`&`#``!U````40(``*4$``"5`0```````)``````````Y0(``)\"``">`@``
MAP8``!P!``!W`P``H`4`````````````EP(```,'```[!P``.@```&L#``"_
M````$P4``/4#`````````````'P&``#N`P```````(\$````````7@```)D%
M````````]08````````]!@```P$```````"=!0``+@$`````````````E@,`
M`/D!```V!0``?0```#<!```E`P``Z`$``#D```",!```&`$```````"W`0``
MH08```````#A!@``T````(T!```;`0```````"<```!?!```J`4```8'``#)
M`P```````````````````````'X!````````)`,``#4$``"%````````````
M``"F`0``[`4``(H!``#E!0```````$L"``!$`@``JP4``-<&````````4@(`
M````````````)@4``)4&``!_`@``3P4``-($``!S`@``_0```((#``"*!0``
MF@,``,8$``#*!````````"X"``#?`````````$,!``#(!0```````$4!````
M`````````%8%``"7!@`````````````Y`P``)04``(X`````````70$`````
M``"L!`````````P&````````,P$```````!.!0``D@(````````>!```VP``
M```````3!````0(```\```#]`0````(``&0!``#J````^0,``"$&````````
M,`(``.@"``````````````````!@````!@$```````#3`P``E0(``/<"````
M````V@4``.@%`````````````'0````D`@``*@$``#\```"O!````````'("
M``"=`P``8@4``&D"``!7`P``T`0``#P%``#X!@``Z04``.`"``"1`0``````
M`&\```"3`0````````````"2!0```````#4!``"M`@``@0```/(&``#;!```
M`````'0#``!=`P``[P(```````"E`@``A0(```````#M!```;08``,P$````
M`````````#0!``"5!```@@$``&8!``#1!0``[@(``%L#```<!```F````/,#
M``#(`@``OP(``+,#``#<`0``UP4``,H#``!@!@```````!\%```H!P``+`0`
M`(@&````````/`8``````````````````%L$``"Y!@``\00```````#A````
M`````.`#`````````````-@`````````'`8``+L```!4!0```````+X$``"3
M`P```````#P'``!"!P```````,0"``#W!@``X@,``*\#``#V!```O@$``$8`
M``"K`@`````````````?`@````````````"M!@``FP8``&8````(!@``=@(`
M`/$!``!E`@``904``$8&``#S````Y`,``$X"````````&P4``),````;````
M*P(``((%```K`0``?@0``"T```#&`0```````%0!```D`````````"D#```O
M!0````````0#``"X!0``6@```$<!``#V!@```````",$``!S!0``U`(``+@#
M``#Z!```K`(```4#``#S`@``JP0``-D%``````````````````"3`@``D`$`
M``````!8!````````'(#``"```````````````#\!@``````````````````
M=@8``/X&``!W!0``H0$`````````````ZP,``&@"``!L`@``C@8``-,$```X
M!P``!@4``/`!```R`0````````````",`P``L`8`````````````(@```"P"
M``#C!@``H`0``,T&``#8!```%@<``&X&``"0!```/0```-H```"V!@``"@(`
M`)X$````````WP8```@'``"G````/@8````````Z!P``#@(```````!_````
MC@4``,,$``"E!0```````%4&```+````PP,``/`"``#3`@``'@```/$"````
M````\P4``%8#```F`0``P04```````#R`P``N@8```````"]!```C`8``$$$
M``"Q````;0,``,4$```M`@```````'L#``!7`@````````T#````````R```
M```````+!@``F0```)@!``#^!0``MP4``/@```!5!0``D`8``.\!``#3!@``
M`````$T```#[!0``CP$```````!<!````````"X%````````-`,``#T#``!D
M`@``300``/0!``#U`0``ZP0``,X#```,`@``*0$`````````````R@```$$'
M``#$`0``;P8```````"A````!P(``$0%``#!`@``Y@0``-P%```+`0``G00`
M``````!R````6@0```````#Z`0``JP````````!S!````````&$&``"O````
M[04``/L```!%`P``G0`````````P`````````,4%``"7`0``?````&L$```@
M`0``!08```````"/!@````````````#?`P``^@(```D#````````WP$`````
M````````B0$``+@$```F!```9P$``'0"````````F`8``#H#``!U!@``600`
M``('``#B````*0```/L"``"4`@``I0$``'H#````````W00``,$!``!Y`@``
M\0````````````````````T"````````?`(``/,$```9!P``YP```)0&``!Q
M`P``+P8````````V`P``A`,``%\!````````IP(``.8&``"R!0``*`$`````
M`````````````````````````````````````````````*D$```]!```>0``
M`$<$``"-!```E`4``/@%``!*!0``7P(``*D&``".`0``3`$``%,%````````
M\P$``'\&``#+!```7`4```\&````````J04``)8$`````````````'4!``"$
M!```_0(``&$!````````(`(``)(!```B`@``:`8``)@%`````````````/<!
M``!X````SP8``````````````````&4!``!C!```C04``,("````````X@$`
M`*4`````````Q0(````!```G`0``B`,``'L%````````M@$``&X!````````
MD@,``/\$````````@08``!$'``!P!```_P,``"@$``"K`0``N`$``,D!````
M````@P4``,H"``!X`@```````"X```#C`@``8P$````````!`0```````(0"
M`````````````%\`````````$`,``+0"``"9`P```````/\%````````MP(`
M`*X#``#P!```=@4``#L$```/`0```````/H```"]`0```````*X!``#/`P``
M`04``.L&``"5!0``H@8``,$#``!P`````````-8#``!``0``_@````0$``!"
M`0``I0,``*,$````````;P(``%@!``!Y!0``]@4``"P%``"W````\`4``$8"
M``!S````&0(`````````````U`,```````"R`0``1`8``!8&````````N0,`
M`+P#```6`0``````````````````=@```$L&``#<`P``%0,``,0#```#!```
MO`(``.T!```D!0``4@,``.,%``#<`@``$`$``.X`````````MP0``-<$``!#
M`P``*@,``$H"`````````````'<$``"%`P``2@$```````#7`P``*@(`````
M```?!P``GP4```````#"`P``2`,``(X$``#/`@``EP4```````"%!@``````
M`-<```"Y`````````$$```"H`0```````-H&``"M````$P```&4#``"J`0``
M`````'`"```=````9P`````````?`0``V`4``/\`````````%````!("``!Z
M`0``2@```!<'``!)`P``RP```#$"````````2P4``/<````%!P``=@,`````
M``#P!@``/04``(D`````````HP8`````````````H@$``,H%``"J!```````
M``````"/`@``"@$```````#_`0``6@8```````!@!0``#0$``&@%``#&````
M`````'L&````````T@,``&4&`````````````"@&``"C````8`$``&\$``#6
M!0```````/$#``"[`@```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S
M*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R
M9&%Y*0`@86YD`"!A="``(&]R`"5D("5S(&%N9"`E<P`E9"UD87D@9F]R96-A
M<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3
M:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T
M<RX`)7,@870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N
M;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S
M)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S
M`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@
M<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO
M=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@
M240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI
M9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O
M<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`06-T:6]N(&9O<B!B;&%C
M:VQI<W1E9"!A9&1R97-S97,Z`$%C=&EV871E(%-C<FEP=`!!9&0`061D($-H
M:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@
M3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`
M061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O
M;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(%-E='1I;F=S`$%D9')E<W,`
M061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!
M;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL
M($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO
M;G,`06QL(&9O=7(@<VED97,`06QL(&]F('1H92!F;VQL;W=I;F<`06QL;W<@
M;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN
M`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N
M86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T
M97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G-W97)E9`!!;G1A<F-T:6-A`$%N
M=&EG=6$@86YD($)A<F)U9&$`06YY(&]F('1H92!F;VQL;W=I;F<`07!P;&EC
M871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`
M07!P;'D@1FEL=&5R<P!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!
M<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!
M<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(&1E;&5T92!T:&ES(')U;&4_`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B
M80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G
M:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R
M86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U
M:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT
M:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T;VUA=&EC86QL>2!U
M<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\`079A:6QA8FQE
M(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"
M86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME
M<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M
M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN90!"8V,`0F5G
M:6YS('=I=&@`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A
M`$)H=71A;@!":7)T:&1A>0!";&%C:VQI<W0`0FQA8VML:7-T($5D:70`0FQA
M8VML:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R
M:6YG(&1R:79E<BX`0FQA8VML:7-T960@061D<F5S<P!";&%C:VQI<W1E9"!!
M9&1R97-S97,`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F
M;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";V1Y`$)O;&0`0F]L
M:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E
M<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O
M;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!4
M97)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@
M3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%L
M;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG
M="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A
M;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O
M8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD
M<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@
M<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T
M;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BX`0V%P92!697)D90!#87!T:6]N`$-A<V4@4V5N<VET:79E`$-A=&5G;W)I
M97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#8P!#96QL(%!H;VYE`$-E
M;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#
M96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#
M96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A
M=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG97,@<V%V960N`$-H87(`0VAE8U]K
M($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W
M;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T
M('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O
M($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L
M;W5D<P!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO
M<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S
M`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@
M3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!0
M87-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@
M`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!2
M96%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"X`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN`$-O;G1A:6YS`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#
M;V]K:64`0V]P>0!#;W!Y("5S`$-O<'D@;V8@)7,`0V]P>2!S96QE8W1I;VX`
M0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R
M>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD
M(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@
M;&ES=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-
M86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`
M0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E
M9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O
M<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V
M92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E
M<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T
M97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A
M=&4@82!N97<@;VYE`$-R96%T92!N97<@9F]L9&5R`$-R96%T92!S=6(@9F]L
M9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#
M<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E
M;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`
M0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M`$-Z96-H(%)E<'5B;&EC`$1$`$1)4T%"3$5$.B``1&%I;'D`1&%T851R964@
M0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y
M`$1E7VQE=&4@0V]L=6UN`$1E86-T:79A=&4@4V-R:7!T`$1E8V5M8F5R`$1E
M8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT
M($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L971E`$1E
M;&5T92`E<P!$96QE=&4@0V]N9&ET:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@
M4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C
M96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T90!$96QE=&4@;65S<V%G92!C;VUP;&5T96QY`$1E;&5T92!R;W<`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D`$1E;&EV97(@
M:6YT;R!M>2!)3D)/6`!$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(&-O<'D@
M=&\`1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R961I<F5C="!T;P!$96QI
M=F5R('1O(&9O;&1E<@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@
M=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O
M:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`
M1&ES86)L92`E<P!$:7-A8FQE9`!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I
M<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&YO=&EF:6-A=&EO;B!W
M:&5N(&5A8V@@9FEL=&5R(&ES(&%P<&QI960_`$1I<W!L87D@9F]R96-A<W0@
M*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M`$1J:6)O=71I`$1O(%]N;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L:R!O<B!L
M:7-T(&UE<W-A9V5S`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'``1&\@=&AI<SH`1&]E<R!T:&4@9FER<W0@
M<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H
M:7,@8F]X.@!$;V5S;B=T(&)E9VEN('=I=&@`1&]E<VXG="!C;VYT86EN`$1O
M97-N)W0@96YD('=I=&@`1&]E<VXG="!E>&ES=`!$;V5S;B=T(&UA=&-H("AW
M:71H('!L86-E:&]L9&5R<RD`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S
M`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@)7,`161I="!";&]C:P!%
M9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O
M<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M
M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E
M87)C:"!T97)M<P!%;F%B;&4@)7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G
M97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT
M(&-L:6-K(&-O;G1E>'0@;65N=3\`16YA8FQE9`!%;F0@>65A<@!%;F1S('=I
M=&@`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@
M<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<75A;"!T;P!%<75A
M=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92X`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y
M(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`
M179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AI<W1I;F<@
M4G5L97,`17AI<W1S`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G
M*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%
M>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O
M9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I
M;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%3
M3"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86ER`$9A
M;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L
M($5R<F]R.@!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``
M1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ
M:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I
M;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO
M860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<B!!;&P@365S
M<V%G97,`1FEL=&5R($]N;'D@4V5E;B!-97-S86=E<P!&:6QT97(@3VYL>2!5
M;G-E96X@365S<V%G97,`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%)U;&4`1FEL
M=&5R(%)U;&5S`$9I;'1E<B!38W)I<'0@1&ES<&QA>0!&:6QT97(@7U)U;&5S
M`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@8V]P
M:65D('1O('1H92!F;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M
M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ
M("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD97(@
M(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I('1H870@;6%T
M8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@9&5L971E9"X`1FEL=&5R(&%C=&EV
M:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@8F5E;B!C;W!I
M960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&1E;&5T960N`$9I;'1E
M<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@:&%S(&)E
M96X@;6]V960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@;F]T(&9O=6YD
M+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I
M>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!A;B!I;F-O;6EN9R!M97-S86=E('1H
M870@;6%T8VAE<SH`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9`!&;W)W87)D(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@
M9FEL=&5R:6YG(&1R:79E<BX`1F]R=V%R9',`1F]R=V%R9',@161I=`!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA
M;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`
M1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A
M;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R
M871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV
M96X@3F%M90!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E
M871E<B!T:&%N`$=R96%T97(@=&AA;B!O<B!E<75A;"!T;P!'<F5E8V4`1W)E
M96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P
M<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E
M<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA
M;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(
M87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(
M96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(
M;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA
M8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E
M("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D
M:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET
M>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL
M960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S
M`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W
M;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS
M($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S
M(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E
M;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM
M86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R
M>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T
M86YT`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E
M<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!)
M;F1I=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R
M96YT(&9I;'1E<FEN9R!D<FEV97(N`$EN9&]N97-I80!);F5X:7-T86YT(&UA
M:6QB;W@@<W!E8VEF:65D(&9O<B!M97-S86=E(&1E;&EV97)Y+@!);F9O`$EN
M9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!)
M;G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E
M9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E
M('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A
M9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!)
M;G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A
M<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@
M<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO
M9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F
M:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`
M26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV
M86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T
M`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED('-H87)E
M(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O
M9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`
M27)A<0!)<F5L86YD`$ES`$ES;&4@;V8@36%N`$ES;B=T`$ES;VQA=&5D(%0M
M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N
M=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D
M86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&
M=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E
M<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U
M=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y
M($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED
M<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I
M=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T
M(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@
M96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`
M3&5F="!V86QU97,`3&5S;W1H;P!,97-S('1H86X`3&5S<R!T:&%N(&]R(&5Q
M=6%L('1O`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E
M;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A
M<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!2
M86EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R
M`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`
M3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B
M;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)1`!,:7-T+4ED`$QI
M<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S
M8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,
M:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4
M:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT
M`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T
M=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A
M;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`
M36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN
M+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<E]K(&UE<W-A9V4@
M87,@9&5L971E9`!-87)C:`!-87)G:6X`36%R:R!M97-S86=E(&%S.@!-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-
M87)T:6YI<75E`$UA=&-H97,@*'=I=&@@<&QA8V5H;VQD97)S*0!-871C:&EN
M9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E
M9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@
M;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&)L86-K;&ES=&5D(&%D9')E<W-E
M<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@36%X:6UU;2!A9&1R
M97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!B
M;&%C:VQI<W0N`$UA>&EM=6T@;G5M8F5R(&]F('=H:71E;&ES=&5D(&%D9')E
M<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@36%X:6UU;2!A
M9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T
M;R!W:&ET96QI<W0N`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N
M=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@
M='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`
M365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE
M`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@
M;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&%D9')E<W,@=&\@
M<F5D:7)E8W0@;65S<V%G92!T;P!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG
M(')E87-O;B!F;W(@<F5J96-T`$UI<W-I;F<@<F5A<V]N(&EN('9A8V%T:6]N
M+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG
M('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D
M($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F
M`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S
M97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY
M($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V90!-;W9E($1O=VX`36]V92!,969T
M`$UO=F4@4FEG:'0`36]V92!2=6QE($1O=VX`36]V92!2=6QE(%5P`$UO=F4@
M57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D
M<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`
M37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.
M3U0@06=R964`3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C871I;VX@<F5P
M;&EE<SH`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE
M=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E
M($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T
M<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R
M`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!2=6QE
M`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD
M;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I;VYS
M`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM
M86=E<RX`3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0`3F\@
M8F%C:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K96YD<RYP:'``3F\@8F%T8V@@
M=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL
M92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE
M9"X`3F\@9FEL92!U<&QO861E9`!.;R!H96%D97)S('-P96-I9FEE9`!.;R!I
M8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E('-U
M<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE
M9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`3F\@<V-R:7!T(&=E;F5R
M871E9"X`3F\@<VED97,`3F\@<W1R:6YG<R!S<&5C:69I960`3F\@=&5M<&]R
M87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V
M97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R
M9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M
M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!
M9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@97%U86P@=&\`
M3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S
M`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`
M3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R
M(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R
M`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]M86X`3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M
M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@
M82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#
M;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T
M+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3
M>7-T96T`3W!T:6]N<P!/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A=&EN9RX`
M3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A
M;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I
M;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/
M=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I
M;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@
M1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L
M:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0
M(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N
M;W<@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`4&%K
M:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!0
M86YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y
M`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S
M="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD
M:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S
M`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K
M('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E
M<B!A('9A;&ED('1I;64N`%!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@
M;F5W(&9O;&1E<CH`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9`!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N
M9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@
M9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S
M<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`
M4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E
M<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B
M;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E
M<GD`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4E]E87-O;@!2861I;R!S96QE
M8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!2
M86EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I
M;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R
M(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N`%)E8V5I=F5D`%)E9&ER96-T('1O`%)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H
M(%!O<G1A;"!6:65W.@!296=E>`!296=U;&%R(&5X<')E<W-I;VX`4F5J96-T
M('=I=&@@<F5A<V]N`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M
M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!2
M96UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E
M('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V
M92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"!&:65L9`!2
M97-E;G0@5&\`4F5S96YT+69R;VT`4F5S970`4F5S970@4&%S<W=O<F0`4F5S
M970@66]U<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!&:6QT97)S($QI
M<W0`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O(%)U;&5S($QI<W0`4F5U
M;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S
M`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2
M;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R
M;W!E<G1I97,`4F]W<SH`4G5L90!2=6QE($-O<&EE9`!2=6QE($1E;&5T960`
M4G5L92!$:7-A8FQE9`!2=6QE($5N86)L960`4G5L92!.86UE`%)U;&5S`%)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D
M97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-3
M2`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI
M='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI
M<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@
M9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0
M<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`
M4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!3971T:6YG<P!3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R
M871I;VXN`%-C:65N8V4`4V-R:7!T`%-C<FEP="!5<&1A=&EN9P!38W)I<'0@
M;F]T('5P9&%T960N`%-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D+@!3
M8W)I<'0@<W5C8V5S<V9U;&QY(&1E86-T:79A=&5D+@!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5E;@!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE
M8W0@82!F:65L9`!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W
M(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!3
M96QE8W0@=&%R9V5T(&9O;&1E<@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L9BU$
M969I;F5D($AE861E<@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E
M;F1E<@!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E
M=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA
M>2!O<'1I;VYS+@!3971T:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4V5T
M=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L
M;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!!8W1I=F4@
M4V-R:7!T`%-H;W<@0W5R<F5N="!38W)I<'0`4VAO=R!D:69F97)E;F-E<R!B
M971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO
M9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P
M:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W
M97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@
M8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I
M9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E
M`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W
M`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`
M4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N
M="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@
M4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U
M=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R
M;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`
M4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA
M;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L
M:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T
M87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W`@8VAE8VMI
M;F<@:68@=&AI<R!R=6QE(&UA=&-H97,_`%-T;W)A9V4@9F]R;6%T`%-T<F5E
M="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5?8W0@
M;V8@=F%C871I;VX@;65S<V%G93H`4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN
M(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T
M92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N
M<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@
M`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R
M9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U
M8FQI8P!4+5-T;W)M`%0M4W1O<FUS`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R
M;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V
M:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@
M9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M
M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG
M;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H86YK('EO
M=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($944"!E>'1E;G-I;VX@:7,@
M;F]T(&%V86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N
M9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T
M=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D
M871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF
M:65D+@!4:&4@9')I=F5R('-A:60Z(`!4:&4@96YC<GEP=&EO;B!F96%T=7)E
M<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@
M86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R
M8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R
M(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7
M:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@
M)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E
M<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@
M8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@
M=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T
M;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@
M<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F
M:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B
M;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ
M92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D
M+@!4:&5R92!W87,@86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4
M:&5R92!W87,@86X@97)R;W(@9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N`%1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD
M+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F
M)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES
M(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE
M(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`
M5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS
M90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K
M;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E
M('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C
M=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L
M92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO
M=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B
M($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`
M56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M
M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E
M9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&=R
M861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN
M(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R
M96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E
M<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5
M<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R;F%M90!5<V5R;F%M93H`57-E
M<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D
M:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A8V%T:6]N($5D
M:70`5F%C871I;VX@365S<V%G90!686-A=&EO;B!I<R!N;W0@<W5P<&]R=&5D
M(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`%9A;&ED(&QO8V%T
M:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E
M<R!F<F]M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU
M871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@
M=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R
M<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@
M<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE
M<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES
M;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@
M271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@
M34%.54%,3%D@1E)/32`E<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!7
M90!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!7
M96%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M
M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T
M97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VA?:71E;&ES="!A
M9&1R97-S97,Z`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BX`5VAI=&5L:7-T`%=H:71E;&ES="!%9&ET`%=H:71E;&ES="!I<R!N;W0@
M<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`%=H
M:71E;&ES=&5D($%D9')E<W-E<P!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`
M5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C
M="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U
M;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN
M(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!8+5!R:6]R:71Y`%@M4F5F`%@M4W!A;2U,979E;`!8+5-P
M86TM4V-O<F4`6"U3<&%M+5-T871U<P!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`
M665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V
M92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE
M(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R
M;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N
M`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT
M<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T
M('-P96-I9GD@870@;&5A<W0@;VYE(&5M86EL(&%D9')E<W,@9F]R('=H:6-H
M('1H92!V86-A=&EO;B!M97-S86=E<R!S:&]U;&0@8F4@86-T:79A=&5D+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E
M9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U
M<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET
M>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E
M('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II
M<'!Y`%M(:61E(%%U;W1E9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061D<F5S<RAE<RD@=&\@
M9F]R=V%R9"!T;SH`7T%D9')E<W-E<R!T;R!N;W0@<V5N9"!R97-P;VYS97,@
M=&\Z`%]!9&UI;FES=')A=&EO;@!?0FQA8VML:7-T`%]#3$D`7T1A=&%4<F5E
M`%]$96QE=&4@4F]W`%]$96QE=&4@;65S<V%G92!C;VUP;&5T96QY`%]%;G1E
M<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN93H`7T9O<G=A<F0`7T=R;W5P
M<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?2V5E<"!A(&-O<'D@;V8@
M;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT/P!?3&]G(&EN`%],;V<@;W5T`%]-
M;V1I9GD@3&EN:RXN+@!?36]V92!M97-S86=E('1O(&9O;&1E<CH`7TUY(&5M
M86EL(&%D9')E<W-E<SH`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@
M3&EN:RXN+@!?4V-R:7!T`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?
M57-E<G,`7U9A8V%T:6]N`%]7:&ET96QI<W0`861D<F5S<R!B;V]K`&%N9`!C
M86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`9F%L;&EN9P!F:65L9`!F:6QE`&9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`:6UM961I871E`&EN;&EN90!L
M:6YE<UT`;6%T8V@`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT
M960`;F]T97!A9`!O<@!P97)C96YT`'!I>&5L<P!P<F]C;6%I;"!S8W)I<'0@
M9V5N97)A=&5D(&)Y($EN9V\`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VEE
M=F4@9FEL=&5R(&=E;F5R871E9"!B>2!);F=O`'-M<S)E;6%I;"!V:6$@2%14
M4`!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z
M`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@26YG;R`P+C$M8W9S
M"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-"TQ,2TR,2`P.3HP,2TP.#`P"DQA<W0M5')A;G-L
M871O<CH@4&%V96P@0VAY=&EL(#QP879E;$!C:'ET:6PN;W)G/@I,86YG=6%G
M92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M
M<SH@;G!L=7)A;',],SL@<&QU<F%L/2AN)3$P/3TQ("8F(&XE,3`P(3TQ,2`_
M(#`@.B!N)3$P/CTR("8F(&XE,3`\/30@)B8@*&XE,3`P/#$P('Q\(&XE,3`P
M/CTR,"D@/R`Q(#H@,BD["@`@*'#X960@)7,@9&YY*0`@*%#X[7-T=7!O=OT@
M:VSMZ"`E<RD`("AV("5S(&1N96-H*0`@*&1N97,I`"`H>NUT<F$I`"`H=NAE
M<F$I`"!A`"!R>6-H;&]S="``(&YE8F\`)60@)7,@82`E<P`E9"UD96YN[2!P
M^&5D<&]V[.\`)7,@+2!O>F[A;65N[0`E<R!O=&ES:P`E<R!+0@`E<R!O<&5R
M86-E(/ID<KYB>2`M('!O='9R>F5N[0`E<R!N87-T879E;NT`)7,@<F5G:7-T
M<F%C90`E<R!P;V1M[6YK>2!P;W6^[7;A;NT`)7,@:FF^(&5X:7-T=6IE+@`E
M<R!N82`E<R`E<P`E<R!J92!P;[YA9&]VX6YO`"5S(&UI;G5T`"5S(&YE8GEL
M;R!N86QE>F5N;RX`)7,@8;X@)7,@>B`E<P`E<R!A9')E<^'X`"5S(&MA;&5N
M9.'X`"5S('KA<&ES;NUK`"5S('-E>FYA;2#Z:V]L^0`E<SH@)7,`+"!NX7)A
M>F]V_2`E<R`E<P`L('!R;VWL;F[A(&]D("5S(&1O("5S`"TM(';]8NQR("TM
M`#$R(&AO9&EN;W;](&9O<FWA=``R-"!H;V1I;F]V_2!F;W)MX70`,C0@:&]D
M:6X`4')O('1E;G1O(&)L;VL@:F4@=GF^861O=N%N(&1A=&%BX7IO=OT@>F1R
M;VHN`%9Y<VMY=&QA('-E('KA=F&^;N$@8VAY8F$`4')O('IAN6EF<F]VX6[M
M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"X`4')O
M('9E<FEF:6MA8VD@<&]D97!S86[I('IP<N%V>2!J92!N=71N;R!P;W6^[70@
M=F7X96IN_2!01U`@:VSMZ"X`4')O(&1EN6EF<F]VX6[M('IP<N%V>2!J92!N
M=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"P@<')I=N%T;NT@4$=0(&ML
M[>@@82!H97-L;RX`4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]U
MONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'4"!K;.WH(&$@:&5S
M;&\N`%!R;R!D9;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E
M^&5J;OT@4R]-24U%(&ML[>@L('!R:7;A=&[M(%,O34E-12!K;.WH(&$@:&5S
M;&\N`%!R;R!P;V1E<'/A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE
M:F[](%,O34E-12!K;.WH+"!P<FEVX71N[2!3+TU)344@:VSMZ"!A(&AE<VQO
M+@!0<F\@>F&Y:69R;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE
M:F[](%,O34E-12!K;.WH+@!286YN[2!DZ;F[`%)A;F[M('#X96CA\FMY`%)A
M;F[M('-N[&AO=ND@</AE:.'R:WD`04TO4$T`05!)($E$`$EN9F]R;6%C92!O
M('1O;71O(&5D:71O<G4`26YF;W)M86-E+BXN`%1E>'0@9&]L^2!D;R!O8G+A
M>FMU`%1E>'0@9&]P<F]S=/AE9"!O8G+A>FMU`%9Y='9O^&5N[2!61E,@861R
M87/A^&4@;F5B>6QO('!O=F]L96YO+@!6>71V;_AE;NT@5D93('-O=6)O<G4@
M;F5B>6QO('!O=F]L96YO+@!5OFEV871E;'-KZ2!H97-L;P!5OFEV871E;&O]
M(/KH970@8GEL('IA8FQO:V]VX6XN`%6^:79A=&5L:^D@^NAT>0!!:V-E('!R
M;R!A9')E<WD@;F$@Z&5R;ND@;&ES=&EN[#H`06MT:79O=F%T(%-K<FEP=`!6
M;&^^`%#X:61A="!P;V1S:W5P:6YU`%#X:61A="!P;V0M<'+A=F$`4/AI9&%T
M.@!0^&ED870@;F]V;W4@<VMU<&EN=0!0^&ED870@;F]VX2!P<N%V80!0^&ED
M870@;F]VZ6AO('6^:79A=&5L93H`4/AI9&%T('-L;W5P96,`4/AI9&%T(&YO
M=ND@Z&QE;GD`4/AI9&%T('#A<@!0^&ED870@)7,@;65N=2!J86MO(&)OZ&[M
M('-L;W5P96,@36]Z:6QL>0!0^&ED870@9&\@861R97/A^&4Z`%#X:61A="!D
M;R!MZ6AO(&%D<F5SX?AE`%#X:61A="!UOFEV871E;&4`4/AI9.%VX6[M('6^
M:79A=&5L^2!J92!Z86)L;VMO=N%N;RX`1&]P;/)U:NUC[2!.87-T879E;NT`
M061R97-A`$%D<F5SX?@`5GEK;V[A=F%T(&%D;6EN:7-T<F%C:2`M(&YA<W1A
M=F5N[2!P^.US='5P;W;]8V@@<'+A=B!P<F\@;W-T871N[2!UOFEV871E;&4`
M061M:6YI<W1R86-E`$EN>F5RX71Y`$%F9VCA;FES=.%N`$%L8N%N:64`06R^
M[7)S:V\`4/AE>F3M=FMA+T%L:6%S`%IA<F]V;F%T`%IA<F]V;N%N[3H`5KEE
M`%:Y:6-H;FD@;W;L^&5N[2!UOFEV871E;.D`5KEE8VAN>2!S:W5P:6YY`%:Y
M96-H;F$@=;YI=F%T96QS:^$@<'+A=F$`5KEE8VAN>2#H='GX:2!S=')A;GD`
M5KEE(&-O(&[A<VQE9'5J90!0;W9O;&ET(';M8V4@861R97,`4&]V;VQI="!N
M87-T879E;NT@='EP=2!S973X[63L;OT@<V5Z;F%M/P!*:;X@97AI<W1U:F4`
M06QT97)N871I=F[M($E-4U`@</AI:&SAN65N[2!D;R!S>7-TZ6UU`$%L=&5R
M;F%T:79N[2!)35-0(&AE<VQO`$%L=&5R;F%T:79N[2!)35-0('6^:79A=&5L
M<VOI(&IMZ6YO`$%L=&5R;F%T:79N[2!E+6UA:6QO=N$@861R97-A`$%L=&5R
M;F%T:79N[2!V>F]R>0!!;'1E<FYA=&EV;NT@=&5X=#H`06UE<FEC:^$@4V%M
M;V$`0GEL82!Z863A;F$@;F5P;W9O;&5NX2!H;V1N;W1A+@!!;F1O<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6[M('!R;WAY`$]D<&]V[.\`6F]D<&]V['IE
M;ND`06YT87)K=&EK80!!;G1I9W5A(&$@0F%R8G5D80!#;VMO;&EV(&-O(&[A
M<VQE9'5J90!!<&QI:V%C90!397IN86T@87!L:6MA8^T`07!L:6MA8V4@:F4@
M</AI<')A=F5N80!!<&QI:V]V870@1FEL=')Y`%!O=;[M="!P<F\@9.QD:>AN
MZ2!S9.UL96[M`%-C:';A;&ET`%#X:6)L:;YNX2!V96QI:V]S=`!$=6)E;@!!
M<F%B<VMY("A7:6YD;W=S+3$R-38I`%9E;&EK;W-T(&%R8VAI=F]V86[I:&\@
M<V]U8F]R=0!*;>EN;R!A<F-H:79U`$IS=&4@<VD@:FES=.TL(+YE(&-H8V5T
M92!V>6UA>F%T('1O=&\@<')A=FED;&\_`%5RZ&ET["!C:&-E=&4@=GEM87IA
M=""^X61O<W0@;R!P^&EH;.&Y96[M(&1O("5S/P!!<F=E;G1I;F$`07)MZ6YI
M90!!<FWI;G-K_2`H05)-4T-)22TX*0!5;>QN[0!!<G5B80!!<V-E;G-I;VX@
M27-L86YD`$%S8VEI('5M[&[M`$%S:64O<F5G:6]N(%1I8VCI:&\@;V-EX6YU
M`%!OON%D870@;R!P;W1V<GIE;NT@</AE9"!P<F]V961E;NUM(&]P97)A8^T@
M^F1ROF)Y/P!3;&]U<&-E(',@^FMO;'D`4&]K=7,@;R!V>6UA>N%N[2!N965X
M:7-T=6KM8^T@<VMU<&EN>2X`4&]K=7,@;R!V>6UA>N%N[2!N965X:7-T=6KM
M8^UC:"!UOFEV871E;'-K_6-H('!RX78N`%!O:W5S(&\@^G!R879U(&YE97AI
M<W1U:NUC[6-H('6^:79A=&5L<VO]8V@@<'+A=BX`4&]K=7,@;R#Z<')A=G4@
M;F5E>&ES='5J[6/M:&\@<V3M;&5NZ6AO(&]B:F5K='4N`$%T<FEB=71Y`%-R
M<&5N`$%U<W1RX6QI90!286MO=7-K;P!!=71H7V-Y<G-Q;#H@3F5B>6QA(&YA
M;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:6UA<"X`075T:%]C>7)U
M<SH@6F1R;VH@;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN`$%U=&A?8WER
M=7,Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&EM
M87`N`$%U=&A?9G1P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP
M;VYA('!R;R!F='`N($MO;7!I;'5J=&4@4$A0(',@+2UE;F%B;&4M9G1P`$%U
M=&A?:6UA<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P
M<F\@24U!4"X`075T:%]K<F(U.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%N
MX2!P^.UP;VYA('!R;R!K<F(U+@!!=71H7VQD87`Z($YE8GEL82!N86QE>F5N
M82!P;[YA9&]V86[A('#X[7!O;F$@<')O($Q$05``075T:%]L9&%P.B!.96QZ
M92!P^&ED870@=;YI=F%T96QE("5S+B!(;.&Y96[M('-E<G9E<G4Z(`!!=71H
M7VQD87`Z($YE;'IE('9Y;6%Z870@=;YI=F%T96QE("5S`$%U=&A?;&1A<#H@
M3F5L>F4@86MT=6%L:7IO=F%T('6^:79A=&5L92`E<P!!=71H7VUC86PZ($YE
M8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O($U#04PN`$%U
M=&A?<VUB875T:#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N
M82!P<F\@<VUB875T:"X`3W;L^&5N[2!S96QH86QO`$]V[/AE;NT@<V5L:&%L
M;RX@)7,`3W;L^&5N[2!B>6QO('IA;>UT;G5T;R!2041)55,@<V5R=F5R96TN
M`%-E;&AA;&\@;W;L^&5N[2!&5%`@<V5V97)E;2X`3V)N;W9T92!S:W)I<'0@
M875T;VUA=&EC:WD@<&\@:V&^9.D@>FWL;NP_`$1O<W1U<&[A('!O;&4Z`$%Z
M97)B86IDON%N`$)/1D@@=OUM;'5V>0!0;WIA9.T`0F%R=F$@<&]Z863M`*EP
M871NZ2!H97-L;R!P<F\@:V5R8F5R;W,N`*EP871NZ2!UOFEV871E;'-KZ2!J
M;>EN;R!P<F\@:V5R8F5R;W,N`$)A:&%M>0!"86AR86EN`$)A;'1I8VOI("A)
M4T\M.#@U.2TQ,RD`0F%N9VQA9.FY`$)A<F)A9&]S`%KA:VQA9`!3:W)Y=.$@
M2V]P:64`6F'H[6[A(',`0NQL;W)U<VMO`$)E;&=I90!"96QI>@!"96YI;@!"
M97)M=61Y`$)H^G3A;@!.87)O>F5N:6YY`,AE<F[A($QI<W1I;F$`VG!R879A
M(,AE<F[I($QI<W1I;F$`R&5R;N$@3&ES=&EN82!N96[M('IA:')N=73A('8@
M<V]UZ&%S;NEM(&1R:79E<G4@<')O(&9I;'1R;W;A;NTN`$%D<F5S82!N82#(
M97)NX2!,:7-T:6[L`$%D<F5S>2!N82#(97)NX2!,:7-T:6[L`$YE;'IE(&YA
M;.EZ="#HX7-T("(E<R(@87!L:6MA8V4@(B5S(BX`3F%S=&%V96[M(&)L;VMU
M`%1Y<"!B;&]K=0!:<'+A=F$`5'7H;NP`0F]L[79I90!:X6QOOFMY`$]K<F%J
M`*GM^&MA(&]K<F%J93H`3VMR86IE`$)O<VYA(&$@2&5R8V5G;W9I;F$`3V)A
M`$)O='-W86YA`$1O;&[M(.CA<W0`0F]U=F5T($ES;&%N9`!"<F%Z[6QI90!"
M<FET<VOA('1E<FET;W)I82!V($EN9&EC:^EM(&]C9>%N[`!"<G5N96D@1&%R
M=7-S86QA;0!"=6QH87)S:V\`4V5Z;F%M(',@;V1RX;YK86UI`$)U<FMI;F$@
M1F%S;P!"=7)U;F1A`$--4P!#4D,`0U),(&1I<W1R:6)UZ&[M(&)O9'D`5FQA
M<W1N;W-T:2!B7W7R:WDN+BX`2V%L96YDX?@`0F5Z=NQT^.T`2V%M8F]DOF$`
M2V%M97)U;@!(97-L;R!N96QZ92!N87-T879I="!A=71O;6%T:6-K>2P@<')O
M<^UM(&MO;G1A:W1U:G1E(%9AN65H;R!S>7-TZ6UO=NEH;R!A9&UI;FES='+A
M=&]R82X`3F5L>F4@<V4@</AI<&]J:70@:R!)34%0('-E<G9E<G4Z("5S`$MA
M;F%D80!3=&]R;F\`4W1O<FYO(&ALX;EE;NT@<')O8FSI;74`3F5L>F4@=GEM
M87IA="!S;W5B;W(@(B5S(BX`3F5L>F4@;F%J[70@9&_H87-N_2!A9')E<^'X
M+@!.96QZ92!P;VMR8>AO=F%T(&)E>B!P87)A;65T<G4@)W1A<F=E=$9I;&4G
M+@!.96QZ92!V>6UA>F%T(&%D<F5SX?@@(B5S(BX`3F5L>F4@=GEM87IA="P@
M<')O=&^^92!E>&ES='5J[2!P;V1S:W5P:6YY("5D+@!.96QZ92!P<F]VZ7-T
M('IM[&YU('5S<&_XX63A;NTL('!OZ&5T('!O<VMY=&YU=/UC:"!P;VQOOF5K
M('!R;R!N;W;I('5S<&_XX63A;NT@;F5O9'!O=NUDX2!P;^AT=2!U;&^^96[]
M8V@@<&]L;[YE:RX`3F5L>F4@>F%S;&%T('IP<N%V=2!N82!Z861A;ND@Z.US
M;&\N(`!#87!E(%9E<F1E`%1I='5L:WD`4F]Z;&FY=6IE(%9E;&OA(&$@36%L
MX2!0[7-M96YA`$MA=&5G;W)I92!A('IN8>AK>0!+86IM86YS:^D@;W-T<F]V
M>0!+;W!I90!-;V)I;&[M('1E;&5F;VX`36^^;F]S=&D@8G7R:WD`3V1S='5P
M(&UE>FD@8G7R:V%M:3H`5FQA<W1N;W-T:2!B=?)K>0!-97IE<GD@;65Z:2!B
M=?)K86UI.@!-;V)I;&[M('1E;&5F;VX`2V5L='-K_2`H25-/+3@X-3DM,30I
M`%-T^&5D`%-T^&5D;V%F<FEC:^$@<F5P=6)L:6MA`%-T^&5D;V5V<F]P<VO]
M("A)4T\M.#@U.2TR*0!0;V1R;V)N;W-T:2!C97)T:69I:^%T=0!0;V1M[6YK
M>2!C97)T:69I:^%T=0#(860`6FWL;FET`$YA<W1A=F5N[2!J;>EN82!A(&5M
M86EL;W;I(&%D<F5S>2X@5'ET;R!P;VQOOFMY(&QI9.D@=79I9.TL(&MD>;X@
M<VD@Z'1O=2!N96)O(&]D<&]V[61A:NT@;F$@5F&Y92!Z<'+A=GDN`%IM[&YY
M(%5L;[YE;GDN`%IN86L`6FMO;G1?<F]L;W9A="!O9&MA>BXN+@!#:&EL90#(
M[6YA`,CM;KET:6YA('IJ961N;V1UN65NX2`H1T(R,S$R*0!4<F%D:>AN[2#H
M[6ZY=&EN82`H0FEG-2D`6G9O;'1E(&AE<VQO`%IV;VQT92!UOFEV871E;'-K
MZ2!J;>EN;P!6>6)R870@>F]B<F%Z96[M(&1A='5M=3H`5GEB<F%T('1Y<"!S
M='EL=2!S97IN86UU("AP<F\@^&%Z96[I('-E>FYA;7DI`%;A;F_H;NT@;W-T
M<F]V`$YE8GEL82!N86QE>F5N82!D969I;FEC92!T^.UD>2`E<RX`5GGH:7-T
M:70`5GGH:7-T:70@>FYAZ&MY('H@35-/9F9I8V4`3V1S=')A;NQN[2!UOFEV
M871E;&4Z("5S`$]D<W1R86YI="!UOFEV871E;&4`3V1S=')A;NQN[2#Z9&%J
M^2!O('6^:79A=&5L:0!+;&EK;NQT92!P<F\@<&]K<F'H;W;A;NT`0VQI8VMA
M=&5L;"!P^&5S($A45%``6F%V^.UT(&]K;F\`6F%T8;YE;F\`3V)L8>AN;P!+
M;VMO<V]VZ2!O<W1R;W9Y`%-K;&%P;F]U="!B;^AN[2!L:;ET=0!3:VQA<&YO
M=70@;VMR86IE`$MO;'5M8FEE`$)A<G9A`%;]8NQR(&)A<F5V`%!A;&5T82!B
M87)E=@!3;&]U<&-E.@!.X7IV>2!S;&]U<&-E`$MO;6EK<WD`4/CM:V%Z`%#X
M[6MA>F]VX2!K;VYZ;VQA`%!O>F[A;6MA`$]B96-NZ2!J;>EN;P!+;VUO<F]S
M`$9I<FUA`%!OZ.UT8>AE`%!O9&WM;FMY`%)O>F3M;'D@=B!N87-T879E;NT`
M3F%S=&%V:70@)7,`4&]T=G)D:70@:&5S;&\`2V]N9V\`2V]N9V\L($1E;6]K
M<F%T:6-KX2!R97!U8FQI:V$`4W!O:F5N[2!S96QH86QO+@!3<&]J96[M('-E
M;&AA;&\Z(`!">6QO('IA;>UT;G5T;R!S<&]J96[M(',@=F7X96IN_6T@:VSM
MZ&]V_6T@<V5R=F5R96TN`$)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE
M:F[];2!K;.WH;W;];2!S97)V97)E;2X@1/EV;V0@.B`E<R`H)7,I`%-E;&AA
M;&\@<W!O:F5N[2!S($944"!S97)V97)E;2X`2V]N=&%K='D@8GEL>2#Z<W#L
MN6[L('#X:63A;GD@9&\@5F&Y96AO(&%D<F5SX?AE+@!/8G-A:'5J90!0;VMR
M8>AO=F%T`$-O;VMO=GD@;W-T<F]V>0!+;VSAZ&5K`$MO<.UR;W9A=`!+;W#M
M<F]V870@)7,`2V]P:64@)7,`2V]P[7)O=F%T(';]8NQR`$MO<W1A<FEK80!0
M;V+X9;[M('-L;VYO=FEN>0!:<'+A=G4@;F5L>F4@N6EF<F]V870@<&]M;V/M
M(%!'4"X`6G!RX79U(&YE;'IE('!O9&5P<V%T('!O;6]C[2!01U`N`%IP<N%V
M=2!N96QZ92"Y:69R;W9A="!P;VUO8^T@4R]-24U%+@!:<'+A=G4@;F5L>F4@
M<&]D97!S870@<&]M;V/M(%,O34E-12X`3F5L>F4@</AI9&%T(&MO;G1A:W0N
M("5S`$YE;'IE('-E('#X:7!O:FET(&L@3$1!4"!S97)V97)U+@!.96QZ92!Z
M:V]N=')O;&]V870@^NAE="X@)7,`3F5L>F4@=GET=F_X:70@9&ES=')I8G7H
M;NT@<V5Z;F%M+B`E<P!.96QZ92!D9;EI9G)O=F%T(%!'4"!D871A+@!.96QZ
M92!D9;EI9G)O=F%T(%,O34E-12!D871A+@!.96QZ92!S;6%Z870@:V]N=&%K
M="X@)7,`3F5L>F4@<VUA>F%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,`3F5L
M>F4@>FII<W1I="!E+6UA:6QO=F]U(&%D<F5S=2!P^.UJ96UC92X`3F5L>F4@
M>NUS:V%T(/IP;&[](&%D<F5SX?@N`$YE;'IE('KM<VMA="#Z<&QN_2!D:7-T
M<FEB=>AN[2!S97IN86TN`$YE;'IE('KM<VMA="#Z<&QN_2!S97IN86T@9&ES
M=')I8G7H;NUC:"!S97IN86WY+@!.96QZ92!Z[7-K870@=F7X96IN_2!K;.WH
M('H@:VSMZ&]VZ6AO('-E<G9E<G4N`$YE;'IE(&]T97;X[70@)7,N`$YE;'IE
M('!R;W;I<W0@;W!E<F%C92#Z9'*^8GD@<')O(&UO9'5L("5S`$YE;'IE(.CM
M<W0@)7,N`$YE;'IE(')E<V5T;W9A="!H97-L;R!P<F\@9&%NZ6AO('6^:79A
M=&5L92X@5KEE8VAN>2!N96)O(&[L:W1E<ND@>B!P;V1R;V)N;W-T[2!N96)Y
M;'D@<W!RX79N["!Z863A;GDN(%IK=7-T92!T;R!Z;F]V=2!N96)O('!O:W5D
M('!O=/AE8G5J971E('!O;6]C+"!K;VYT86MT=6IT92!S<'+A=F-E('-Y<W3I
M;74N`$YE;'IE('KM<VMA="!!0TP`3F5L>F4@>NUS:V%T(&%D<F5SX?@N("5S
M`$YE;'IE('KM<VMA="!D:7-T<FEB=>AN[2!S97IN86TN("5S`$YE;'IE('KM
M<VMA="!D:7-T<FEB=>AN[2!S97IN86UY+B`E<P!.96QZ92!Z[7-K870@<V-H
M;W!N;W-T:2!S97)V97)U`$YE;'IE('#X97!N;W5T(&MO;F9I9W5R86-I+@!.
M96QZ92!U;&^^:70@:V]N9FEG=7)A8VD@<')O("5S+@!.96QZ92!U;&^^:70@
M>N%L;[YN[2!K;VYF:6=U<F%C:2X`3F5L>F4@=6QOOFET('KA;&]H=2!K;VYF
M:6=U<F'H;NUH;R!S;W5B;W)U("5S+@!.96QZ92!H;&5D870@=B!,1$%0('-E
M<G9E<G4N`$YE;'IE(&%K='5A;&EZ;W9A="!K;VYT86MT+B`E<P!.96QZ92!A
M:W1U86QI>F]V870@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!N86SI
M>G0@8F_H;NT@;&FY='4@<')O($UO>FEL;'4N(%!R;W/M;2!P^&5S=NQDZ'1E
M('-E+""^92!J92!O=&5V^&5NX2X`3V1P;^CM=&%N_2!T97AT`%IE;>P`5GEU
MZ&]V86/M('#X961M['1Y`%9Y='9O^&ET`%9Y='9O^&ET(&]D:V%Z`%9Y='9O
M^&ET(&YO=F]U`%9Y='9O^&ET(&YO=F]U('-L;[YK=0!6>71V;_AI="!P;V1S
M;&^^:WD`5';Y<F-E('!RX78`R.US;&\@:W)E9&ET;NT@:V%R='D`0VAO<G9A
M='-K;P!+=6)A`$%K='7A;&[M(.AA<P!!:W1UX6QN[2!54DP@:F4`06MT=>%L
M;NT@<&_H87/M`$%K='7A;&[M('!O9&WM;FMY.B``3GEN[&JY[2!S='EL`$YA
M<W1A=F5N[2#Z:V]L^2!P<F]VX63L;OUC:"!P^&D@</AI:&SAN65N[2!D;R`E
M<RX`5GES=/AI:&YO=70`5GES=/AI:&YO=70@=OUB['(`2WEP<@!!>F)U:V$@
M*$M/23@M4BD`07IB=6MA("A7:6YD;W=S+3$R-3$I`$%Z8G5K82]5:W)A:FEN
M82`H2T])."U5*0#(97-KX2!R97!U8FQI:V$`1$0`1$5!2U1)5D]6P4Y/.B``
M1&5N;NP`1&%T851R964@<')O:&SMOF7H`$1A='5M`%#X:6IA=&\@9&YE`%;]
M8NQR(&1A='5M=0!$96X`4VUA7WIA="!S;&]U<&5C`$1E86MT:79O=F%T(%-K
M<FEP=`!0<F]S:6YE8P#([7-L82!D97/M=&MO=ND@<V]U<W1A=GD`6FUE;KEI
M="!O9'-A>F5N[0!);7!L:6-I=&[M`$EM<&QI8VET;NT@8F%R=F$`26UP;&EC
M:71N[2!I9&5N=&ET80!$969I;FEC90!3;6%Z870`4VUA>F%T("5S`%-M87IA
M="!0;V1M[6YK=0!3;6%Z870@<VMU<&EN=0!3;6%Z870@<'+A=F$`4VUA>F%T
M(&$@=GGH:7-T:70@>G!RX79Y`%-M87IA="!B=?)K=0!3;6%Z870@<VQO=7!E
M8P!3;6%Z870@97AI<W1U:NUC[2!A;'1E<FYA=&EV;NT@=GIO<@#:<&QN["!S
M;6%Z870@>G!RX79U`%-M87IA="#XX61E:P!3;6%Z870@=GEB<F%N;W4HZ2D@
M:61E;G1I='4H>2D`4VUA>F%T('-O=>AA<V[]('-L;W5P96,`4VUA>F%T('-O
M=>AA<V[](/CA9&5K`%-M87KA;F\`1&]R=>AI="!D;R!0V,U#2$]:S2!03ZE4
M60!$;W)UZ&ET(&1O(%#8S4-(3UK-(%!/J519(&$@:V]P:6D@9&\`1&]R=>AI
M="!D;R!0V,U#2$]:S2!03ZE462!A('#X97-M[')O=F%T(&1O`$1O<G7H:70@
M9&\@<VQOOFMY`,AA<R!D;W)UZ&5N[0!$X6YS:V\`4&]P<V%T('!R;V)LZ6T`
M4&]P:7,`4&]D<F]B;F]S=&D@*'1A:^D@=B!L;V<@<V]U8F]R=2!(;W)D92DZ
M`%!O9')O8FYO<W1I(&)Y;'D@>F%Z;F%M96[A;GD@9&\@;&]G('-O=6)O<G4@
M<')O(&%D;6EN:7-T<N%T;W)A+@!6_79O:@!2;W-N_2!B;V0`4F]S;OT@8F]D
M('IA('!O<VQE9&[M(&AO9&EN=3H@`%)O<V[](&)O9#H@`%-M['(@>B!L979A
M(&1O<')A=F$`4VWL<B!Z('!R879A(&1O;&5V80!!9')E<^'X`$1E86MT:79O
M=F%T("5S`$1E86MT:79O=N%N;P!:;V)R87II="`R-"UH;V1I;F]V_2#H87,_
M`$UOOFYO<W1I('IO8G)A>F5N[0!:;V)R87II="!I9&5T86EL;NT@=7!O>F]R
M;NQN[2!P^&D@:V&^9.EM('!O=;YI=.T@9FEL='+Y/P!:;V)R87II="!P^&5D
M<&]V[.\@*%1!1BD`1F]R;>%T('IO8G)A>F5N[0!$:7-P;WIIZ&[M('5P;WIO
M<F[L;NT`1&II8F]U=&D`7TYE<&]S[6QA="!O9'!O=NQD:2!N82!Z<')A=GD@
M;WIN8>AE;ND@8G5L:R!N96)O(&YA('IP<N%V>2!Z(&QI<W3Y`$YE<VUA>F%T
M`$YE</AI<W1U<&]V870@</CM;6\@9&\@;6%I;G1E;F%N8V4N<&AP`%!R;W;I
M<W0Z`$]B<V%H=6IE('!R=F[M(/CA9&5K(&[A>F5V('-L;W5P8_D_(%!O:W5D
M(&%N;RP@>F&Y:W)T;NQT92!T96YT;R!RX6UEZ&5K.@!.97KAZ.UNX2!N83H`
M3F5O8G-A:'5J90!.96MO;NCM(&YA.@!.965X:7-T=6IE`$YE<VAO9'5J92!S
M90!$;VUI;FEK80!$;VUI;FEKX6YS:^$@<F5P=6)L:6MA`%-T8;YE;NT`4W1A
MOF5N[2`E<P!3=&%H;F]U="!G96YE<F]V86YO=2!K;VYF:6=U<F%C:2!J86MO
M(%!(4"!S:W)I<'0N`%)O;&5T;W;]('-E>FYA;0!$<F]G>0!%+6UA:6P`15)2
M`$5K=N%D;W(`57!R879I=`!5<')A=FET("5S`%5P<F%V:70@8FQO:P!5<')A
M=FET('-K=7!I;G4`57!R879I="!P<N%V80!5<')A=FET('!RX79A`%5P<F%V
M:70@<'+A=F$@<')O("5S`%5P<F%V:70@;6^^;F]S=&D@<')O.@!5<')A=FET
M('!RX79A('!R;R`E<P!6_75K80!%9WEP=`!%;"!386QV861O<@!0<G9E:RXN
M+@!%;0!%;6%I;`!%;6%I;&]VX2!A9')E<V$`16UA:6QO=ND@861R97-Y('-E
M(&UU<^T@<VAO9&]V870N`$5M86EL(',@<&]T=G)Z96[M;0!):V]N:WD@<R!E
M;6]C96UI`%!RX7ID;N$@>G!RX79A+@!0<N%Z9&[](';]<VQE9&5K+@!0<N%Z
M9&[]('1E<FWM;B!P<F\@=GEH;&5DX7;A;NT`06MT:79O=F%T("5S`%!O=F]L
M:70@=FMLX63A;NT@;V)R87IK^2!Z(&9O=&\@9V%L97)I[2!D;R!T97AT=3\`
M06MT:79O=F%T('!R87;I(&ML:6MN=73M('!R;R!K;VYT97AT;W;I(&UE;G4_
M`$%K=&EV;W;A;F\`2V]N96,@<F]K=0!+;V[H[2!N80!:=NQTN6ET(&5D:71O
M<@!:861E:G1E(&)E>G!EZ&YO<W1N[2!O=.%Z:W4L(&YA(&MT97)O=2!B=61E
M=&4@;75S970@;V1P;W;L9.QT('!O:W5D('-I(&)U9&5T92!C:'3M="!R97-E
M=&]V870@<W;I(&AE<VQO+"!N87#X+B`G2F%KZ2!J92!J;>EN;R!68;EE:&\@
M<'-A/R<Z`%ID92!V;&^^:70@55),(&]B<N%Z:W4`4F]N=N$@<V4`4F]V;NUK
M;W;A($=U:6YE80!%<FET<F5A`$-H>6)A`$YA<W1A;&$@8VAY8F$@<R!P;[ET
M;W9N[2!Z<'+A=F]U+@!%<W1O;G-K;P!%=&EO<&EE`$5T;FEC:^D`179R;W!A
M`$MAOF3]8V@@,34@;6EN=70`2V&^9.D@,B!M:6YU='D`2V&^9/UC:"`S,"!S
M96MU;F0`2V&^9/UC:"`U(&UI;G5T`$MAOF3I('#X:6ALX;EE;NT@9&\@<WES
M=.EM=0!+8;YD;W4@</EL(&AO9&EN=0!+8;YD;W4@;6EN=71U`%9Z;W)O=OT@
M</CM:VQA9"!H;V1N;W0Z`%!R;W;I<W0`17AI<W1U:NUC[2!0<F%V:61L80!%
M>&ES='5J90!2;WIV:6YO=70`4F]Z8F%L:70@8F_H;NT@;&FY='4`3^AE:^%V
MX6YA("<I)P!/Z&5KX7;A;F\@<V%M;W-T871NZ2!S;&]V;R!N96)O(&AL961A
M;OT@=&5R;>UN('8@=79O>F]V:^%C:`!$871U;2!P<F\@:V]N96,@<&QA=&YO
M<W1I`$5X<&]N96YT`$)A<G9A('!O</AE9.T`4/AE;F]S(&MO;F9I9W5R86-E
M('!O;6]C[2!&5%``4V5L:&%L;R!Z[7-KX6[M(&UOOFYO<W3M+@!.96QZ92!S
M92!P^&EP;VII="!K($Q$05`@<V5R=F5R=2X`3F5L>F4@<V4@</AI<&]J:70@
M:R!334(@<V5R=F5R=2X`4V5L:&%L;R!K;W#M<F]VX6[M('H@(B5S(BX`4V5L
M:&%L;R!K;W#M<F]VX6[M(&1O("(E<R(N`%-E;&AA;&\@>F%L;[YE;NT@;F]V
MZ6AO(%-!4TP@<W!O:F5N[2X`4V5L:&%L;R!P^&5S=6YU=.T@9&\@(B5S(BX`
M1&]B<ND`1F%L:VQA;F1S:^D@;W-T<F]V>2`H36%L=FEN>2D`1F%R:6IS:^D@
M;W-T<F]V>0!:X79AOF[A(&-H>6)A.@!&87@`VFYO<@!#[71I="!S92!J86MO
M`$/M=&ET('-E(&IA:V\Z`$1R;V)NZ2!P^&5HX?)K>0!$<F]B;ND@<V[L:&]V
MZ2!P^&5HX?)K>0!-871I8V4@<&]L90!&:6II`%!OZ&5T('-O=6)O<ODZ("5S
M('-O=6)O<@!0;^AE="!S;W5B;W+Y.B`E<R!S;W5B;W+Y`%-P<N%V8V4@<V]U
M8F]R^0!.X7IE=B!S;W5B;W)U`%;]8NQR('-O=6)O<G4`4/AE;NES="!S;W5B
M;W(`4/AE;F]S('-O=6)O<OD@;F5N[2!P;V1P;W)O=N%N+@!&:6QT<F]V870@
M5KEE8VAN>2!:<'+A=GD`1FEL=')O=F%T(%!O=7IE(%!R;VAL[61N=73I(%IP
M<N%V>0!I;'1R;W9A="!0;W5Z92!.97!R;VAL[61N=73I(%IP<N%V>0!-;[YN
M;W-T:2!&:6QT<OD`1FEL=')O=F%C[2!0<F%V:61L;P!&:6QT<F]V86/M(%!R
M879I9&QA`%IO;V)R87IE;NT@1FEL=')O=F%C[6AO(%-K<FEP='4`1FEL=')O
M=F%C[2!?4')A=FED;&$`1FEL=')A8V4Z("5S('IP<N%V*&$I(&)Y;&\H82D@
M:V]P[7)O=N%N;RAA*2!D;R!S;&^^:WD@(B5S(BX`1FEL=')A8V4Z("5S('!R
MX78H82D@8GEL;RAA*2!V>6UA>N%N;RAA*2X`1FEL=')A8V4Z("5S('IP<N%V
M*&$I(&)Y;&\H82D@</AE<W5N=71O*&$I(&1O('-L;[YK>2`B)7,B+@!&:6QT
M<F%C93H@)7,@>G!RX78H82D@:G-O=2]J92!N82#H97)NZ2!L:7-T:6[L(&$@
M8GEL;RAA*2!V>6UA>N%N>2AA*2X`1FEL=')A8V4Z(%IP<N%V82`B)7,B(&]D
M("(E<R(@8GEL82!K;W#M<F]VX6YA(&1O('-L;[YK>2`B)7,B+@!&:6QT<F%C
M93H@6G!RX79A("(E<R(@;V0@(B5S(B!B>6QA('9Y;6%ZX6YA+@!&:6QT<F%C
M93H@6G!RX79A("(E<R(@;V0@(B5S(B!B>6QA('#X97-U;G5T82!D;R!S;&^^
M:WD@(B5S(BX`1FEL=')O=F%C[2!P<F%V:61L82!N96)Y;&D@;F%L97IE;GDN
M`$9I;'1R>0!&:6YS:V\`4')V;NT@<&]L;W9I;F$`4')V;NT@Z'1V<G1I;F$`
M4&5V;ND@;>SX[71K;P!0^&5H;V1I=`!0;&]V;W5C[0!-;&AA`%-L;[YK82`E
M<R!N965X:7-T=6IE`$)A<G9A('#M<VUA`$KM9&QO`%!R;R!P^.UC:&]Z[2!Z
M<'+A=GD@:W1E<ND@;V)S86AU:NTZ`%!R;R!P<F]H;.V^9>AE(&YE<&]D<&]R
M=6KM8^T@;V)RX7IK>0!0^&5D<&]V[.\@*%1!1BD`4/AE9'!O=NSO('!OZ&%S
M[2!P<F\@9&YY("AP;WINX6UK83H@</AE9'!O=NSO(&IE('!R;R!D;GD@:2!N
M;V-I.R!T;W1O(&WYOF4@=GET=F_X:70@<&]M[')N["!O8G/A:&S]('-E>FYA
M;2X`6F%P;VUN[&QI(&IS=&4@5F&Y92!H97-L;S\`1F]R;75LX?AE`*ET['-T
M[0!4>7`@N73L<W3M`*ET['-T[0"I=.QS=.T@,@!&\W)A`%#X97!O<VQA=`!0
M^&5P;W-LX6[M(&YE;NT@>F%H<FYU=&\@=B!S;W7H87-NZ6T@9')I=F5R=2!P
M<F\@9FEL=')O=N%N[2X`4/AE<&]S;.%N[0!5<')A=FET(%#X97!O<VSA;NT`
M4.$`4N%M>0!&<F%N8VEE`$9R86YC:64L(&UE=')O<&]L:71N[0!&<F%N8V]U
M<VOA($=U86GA;F$`1G)A;F-O=7-KX2!0;VQY;NES:64`1G)A;F-O=7-KX2!J
M:;YN[2!T97)I=&]R:6$`3V0`3V0`4&]D<F]B;OT@<&]P:7,`VG!L;NQK`$-E
M;.D@:FWI;F\`1V%B;VX`1V%L97)I92!P<F\@=OUB['(@;V)RX7IK^0!'86QE
M<FEE.@!'86UB:64`5GET=F_X:70@)7,@:V]N9FEG=7)A8VD`5GEG96YE<F]V
M86[](&OS9`!'<G5Z[6YS:V\`3NQM96-K;P!':&%N80!':6)R86QT87(`2_AE
M<W1N[2!J;>EN;P!*9&D@;F$`1V]E9&5L`%9Y:&QE9.%VX6[M('!O;6]C[2!'
M;V]G;'4`4W1U<&[L(+EE9&D`5NQTN>T@;F6^`%;L=+GM(&YE8F\@<F]V;F\`
MV&5C:V\`V&5C:^D@*$E33RTX.#4Y+3<I`$=R\VYS:V\`1W)E;F%D80!!9&UI
M;FES=')A8V4@<')O('-K=7!I;GD`375S[2!B_70@>F%DX6YO(&IMZ6YO('-K
M=7!I;GD`4VMU<&EN>0!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`%!RX79A(&AO<W3Y`$MN:6AA(&AO<W3Y`$=U:6YE80!'=6EN96$M0FES
M<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA
M="!P;W-L961N[2!B=?)K=2!N82#XX61K=2X`2%1-3$%R96$@>F)A8NQL92!O
M9&WM=.$@<VUA>F%T('!O<VQE9&[M(&)U\FMU('9E('-L;W5P8VD@=&%B=6QK
M>2X`2%1-3$%R96$@>F)A8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M(/CA
M9&5K('8@=&%B=6QC92X`3W;L^&]VX6[M('!O;6]C[2!(5%10(&YE8GEL;R!N
M86QE>F5N;RX`2&%I=&D`2&%S:"UA;&=O<FET;75S`$UL:&%V;P!(;&%V:>AK
M80!(96%R9"!)<VQA;F0@82!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E:KET:6YA
M("A)4T\M.#@U.2TX+4DI`%;]N6MA`$[A<&]V[&1A`$[A<&]V[&1A('!R;R!E
M9&ET;W(`4&]M;V-N[6L`2&5M:7-FZ7)A`%ID92!J92!Z8>CA=&5K('-O=6)O
M<G4Z`%9Y<V]KX0!?2&]R9&4`4W9A=.D@3>QS=&\@*%9A=&EKX6XI`$AO<F1E
M`$%D<F5S82!D;VWY`%1E;&5F;VX@9&]M^0!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z($YE<&QA=&[I("5S(%A-3"!D871A('9E('IP
M<N%V["`E<P!(;W)D92]+;VQA8CH@KN%D;N$@>G!RX79A('-E(&YE<VAO9'5J
M92!S(&]B:F5K=&5M("5S`$AO<F1E+TMO;&%B.B!.96)Y;"!N86QE>F5N(+[A
M9&[](&]B:F5K="!T>7!U("5S('9E('IP<N%V["`E<P!(;W)D92]+;VQA8CH@
MVG-P[+ENZ2!O9'-T<F%N[&[M("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G
M<F'H;NT@;N%S=')O:B!P;W3X96)U:F4@4$A0('#X[7!O;G4@)V1O;7AM;"<`
M2&]R9&4O2V]L86(Z($YE;'IE('9Y='9O^&ET(&YO=OT@<W1R;VT@6$U,('!R
M;R!O8FIE:W0@)7,`2&]R9&4O2V]L86(Z($YE;'IE(&]D<W1R86YI="`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@3F5L>F4@>NUS:V%T($U)344@240@<')O
M(.CA<W0@='EP=2`E<P!(;W)D92]+;VQA8CH@3F5L>F4@<WEN8VAR;VYI>F]V
M870@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO
M=F%T('-D[6QE;ND@;V)J96MT>3H@)7,`2&]R9&4O2V]L86(Z($YE>F[A;?T@
M<V3M;&5N_2!O8FIE:W0@(B5S(@!6;V1O<F]V;ND@<')A=NUT:V\`2&]R:7IO
M;G3A;&[M(&]D<W1U<`!(;W)I>F]N=.%L;NTZ`$IA:R!J<W1E('-E('-E;2!D
M;W-T86QI/R`H6F&Y;&5T92!P<F]S[6T@>G!RX79U(2D`2V]L:6L@<VQO=7!C
M^2!C:&-E=&4@<W!O:FET/P!+;VQI:R!J92!T86T@<&]L[2`H<VQO=7!C^2D_
M`$MO;&EK(/CA9&OY(&-H8V5T92!S<&]J:70_`%9L:&MO<W0`5FQH:V]S=#H`
M2'5M;W)NZ0!-8>]A<G-K;P!396QH86QO('9Y='9O^&5N[2!)34%0;W;I('-C
M:'+A;FMY.B`E<P!396QH86QO('-M87KA;NT@24U!4&]VZ2!S8VARX6YK>3H@
M)7,`4V5L:&%L;R!N87-T879E;NT@:W;S='D@<')O($E-05!O=F]U('-C:'+A
M;FMU.B`E<P!)4"!A9')E<V$`25`@861R97-A(&YE;NT@9&]S='5P;N$N`$E0
M(&%D<F5S82!N96[M('8@<&]V;VQE;NEM($-)1%(@<F]Z<V%H=2X`4&]R=;EE
M;NT@:6YT96=R:71Y($E0+@!67VQOOG1E(/CA9&5K('#X960`27-L86YD`%!O
M=7IE(&EK;VYY`$EK;VYY('!R;R`E<P!):V]N>2!S('1E>'1E;0!.X7IE=B!I
M9&5N=&ET>3H`4&]K=60@>F]B<F%Z96[M(&YE;NT@=B!P;_CA9&MU+"`E<R!O
M=&5V^.UT('8@;F]VZ6T@;VMN["X`4&]K=60@<&]UONUVX71E($EN=&5R;F5T
M($5X<&QO<F5R(&$@;F5V:63M=&4@ON%D;ND@:6MO;GDL('KX96IM["!P;W3X
M96)U:F5T92!O>FYAZ&ET('1E;G1O('+A;67H96L@<')O('9Y<&YU=.T@4$Y'
M('1R86YS<&%R96YC92X`4&]K=60@=FED[71E('1U=&\@>G!RX79U(&WM<W1O
M(&]B<N%Z:W4L(&]B<N%Z96L@:W1E<OT@8VAC971E('#X96[I<W0@;F5L>F4@
M5F&Y[6T@<')O:&SMOF7H96T@>F]B<F%Z:70N`$[A:&QE9"!O8G+A>FMU.@!5
M4DP@;V)RX7IK=0!54DP@;V)RX7IK=3H`3V)RX7IE:R!Z(&=A;&5R:64`3V)R
MX7IE:R!Z(&=A;&5R:64Z`%#X96YO<R!O8G+A>FMU`$]B<N%Z:WD`26UP;W)T
M+"!K<F]K("5D`$3Y;&6^:73I`$EM<&]R=&]V86[I('!O;&4Z("5S`$EM<&]R
M=&]V86[A('!O;&4Z`%9L;[YI="#XX61K=2!Z80!">6P@>F%DX6X@;F5S<'+A
M=F[](&%KZ&[M(&OS9"X`3F5S<'+A=F[L('IA9&%NZ2!UOFEV871E;'-KZ2!J
M;>EN;R!A+VYE8F\@:&5S;&\N`$YE<W!RX79NZ2!UOFEV871E;'-KZ2!J;>EN
M;R!N96)O(&%L=&5R;F%T:79N[2!A9')E<V$N(%IK=7-T92!J9;ET["!J961N
M;W4@;F5B;R!K;VYT86MT=6IT92!68;EE:&\@<WES=.EM;W;I:&\@861M:6YI
M<W1RX71O<F$N`%IV['2Y:70@;V1S87IE;NT`26YD:64`2F5D;F]T;&EV[2!U
MOFEV871E;.D`26YD:79I9'7A;&[M('!R879I9&QA(&YE:G-O=2!Z86AR;G5T
M>2!V('-O=>AA<V[I;2!D<FEV97)U('!R;R!F:6QT<F]VX6[M+@!);F1O;NES
M:64`0GEL82!V>6)RX6YA(&YE97AI<W1U:NUC[2!S;&^^:V$@<')O(&1O<G7H
M96[M('IP<N%V>2X`26YF;W)M86-E`$EN9F]R;6%C90!6;&^^:70@<U]L;W5P
M96,@>F$`5FQOOFET(&]B<N%Z96L`5FQOOFET('1A8G5L:W4`5FQOOFET('=E
M8F]V_2!O9&MA>@!6;&^^:70@7W-L;W5P96,@</AE9"``5FQOOFET(&YO=OT@
M<VQO=7!E8R!Z82!S;W7H87-N_0!6;&^^:70@;F]V_2!S;&]U<&5C('#X960@
M<V]UZ&%S;OT`5FQOOFET(&YO=OT@^.%D96L@>F$@<V]UZ&%S;OT`5FQOOFET
M(&YO=OT@^.%D96L@</AE9"!S;W7H87-N_0!6;&^^:70@;V1S=&%V96,@>F$@
M<V]UZ&%S;OT@=7IE;`!6;&^^:70@;V1S=&%V96,@</AE9"!S;W7H87-N_2!U
M>F5L`%9L;[YI="!A;'1E<FYA=&EV;NT@=GIO<@!6;&^^=&4@96UA:6QO=F]U
M(&%D<F5S=2P@;F$@:W1E<F]U(&]B9'*^[71E(&YO=ND@:&5S;&\Z`%9L;[YI
M="!B=?)K=2!Z80!6;&^^:70@8G7R:W4@</AE9`!6;&^^:70@<VQO=7!E8R!Z
M80!6;&^^:70@<VQO=7!E8R!P^&5D`%9L;[YI="!Z<'+A=GD`5FQOOFET(&]D
M<W1A=F5C('IA`%9L;[YI="!O9'-T879E8R!P^&5D`%9L;[YI="#XX61E:R!Z
M80!6;&^^:70@^.%D96L@</AE9`!6;&^^=&4@<&^^861O=F%N;W4@;V1P;W;L
M[R!N82!B97IP9>AN;W-T;NT@;W3A>FMU.@!6;&^^:70O=7!R879I="!O8G+A
M>F5K`%9L;[YI="]U<')A=FET(&]D:V%Z`$YE9&]S=&%T9>AN_2!K<F5D:70@
M:R!O9&5S;.%N[2!Z<'+A=GD@;F$@9&ES=')I8G7H;NT@<V5Z;F%M+@!.961O
M<W1A=&7H;OT@:W)E9&ET+@!#96SI(.CM<VQO`%-E>FYA;2!C96S]8V@@Z.US
M96P`3F5S<'+A=F[I(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!.97!L871N
MX2!A<&QI:V%C92X`3F5P;&%T;ND@:61E;G1I9FEK8>AN[2#H[7-L;R`H240I
M(&3A=FMY+@!">6QA('IA9.%N82!N97!L871NX2!D871A`$YE<&QA=&[A(&%D
M<F5S82!P^.UJ96UC92X`3F5P;&%T;OT@9F]R;>%T('-O=6)O<G4`3F5P;&%T
M;OT@;7-G7W1Y<&4N`$YE<&QA=&[I(&YE8F\@8VAY8NQJ[6/M(&%P:5]I9"X`
M3F5P;&%T;ND@;F5B;R!C:'EB[&KM8^T@<&%R86UE=')Y+@!.97!L871NX2!V
M;&%S=&YI8VOA('!RX79A+@!.97!L871N_2!P<F]T;VMO;"X`3F5P;&%T;OT@
M<V3M;&5N_2!O8FIE:W0`3F5P;&%T;N$@861R97-A(&]D97/M;&%T96QE+@!.
M97!L871NX2!D871A('5N:6-O9&4N`$EN=F5N=.'X`,URX6XL($ES;.%M<VOA
M(')E<'5B;&EK80!)<N%K`$ER<VMO`$IE`$]S=')O=B!M=;YE`$YE;NT`3VIE
M9&EN[&SI(&)O=?AK>0!)<W)A96P`4&]S:WET;W9A=&5L`$MU<GKM=F$`273A
M;&EE`$IA;6%J:V$`3&5D96X`2F%P;VYS:V\`2F%P;VZY=&EN82`H25-/+3(P
M,C(M2E`I`%1R:6MO=`!*;W)DX6YS:V\`R&5R=F5N96,`R&5R=F5N`%IA<F]V
M;F%T`%IA<F]V;F%T(&YA('-T^&5D`%IA<F]V;F%T('9Y<&QN[&[M;0!:87)O
M=FYA="!D;VQE=F$`6F%R;W9N870@9&]P<F%V80!+87IA8VAS=.%N`%5C:&]V
M870@;W)I9VENX6P_`$ME\F$`2V5R8F5R;W,@<V5R=F5R('IA;>UT;G5L(&]V
M[/AE;NTN`$YO=N'H8VD@:V5R;F5L=0!6>71V;_AE;NT@:VSMZ&4`5GET=F_X
M96[M(&]T:7-K=2!K;.WH90!$Z6QK82!K;.WH90!4>7`@:VSMZ&4`5;YI=.T@
M:VSMZ&4`2VSMZ"!J:;X@97AI<W1U:F4@;F$@=F7X96INZ6T@:VSMZ&]VZ6T@
M<V5R=F5R=2X`1.QT:0!+:7)I8F%T:0!+3$12`$MO<F5A`$MO<F5J<VMY("A%
M54,M2U(I`$MU=F%J=`!+>7)G:7IS=.%N`%]2;WIL;[YE;NT`2F%Z>6L`3&%O
M<RP@3&ED;W;L($1E;6]K<F%T:6-K82!297!U8FQI:V$`1')U:.$@<&]L;W9I
M;F$`4&]S;&5D;NT@Z'1V<G1I;F$`4&]S;&5D;NT@86MT=6%L:7IA8V4Z`%!O
M<VQE9&[M('#X:6ALX;EE;NTZ("5S`%!O<VQE9&[M('#X:6ALX;EE;NTZ("5S
M('H@)7,`4&]S;&5D;NT@</AI:&SAN65N[3H@3FEK9'D`3&ET=F$`4'+A=F\`
M4F]Z;&^^96[M`$YE8VAA="!P<N%Z9&[I(&)E>B!O:W)A:F4`3&EB86YO;@!$
M;VQE=F$`3&5VX2!H;&%V:>AK80!(;V1N;W1Y(&YA;&5V;P!,97-O=&AO`$UE
M;KGM(&YEO@!-96ZY[2!N96)O(')O=FYO`$QI8NER:64`3&EB:64`3&EC:'1E
M;KET96IN<VMO`$QE:&OI(&UR:&]L96[M`$QE:&O](&3IN;L`0G)Z:_T@;&5H
M:_T@9.FYNP!0;WID[&II(&QE:&O](&3IN;L`3&5H:^D@9&6YNV]VZ2!S<N&^
M:WD`3&5H:_T@9.FYNR!S(&CX;>QN[6T`3&5H:^D@<V[LOF5N[0!,96AKZ2!S
M;NQH;W;I('#X96CA\FMY`$QI;65R:6-K`$]D:V%Z`$]D:V%Z>2!U:V%Z=6KM
M(&YA.@!0;W6^[70@;V1K87IY(&YA(&5M86EL;W;I(&%D<F5S>2!P^&D@>F]B
M<F%Z;W;A;NT@<W1RX6YK>2!P<F\@<'-A;NT@>G!RX78`3V1K87IY`$QI;G5X
M;W;I(&-O;VMI90!397IN86T@+2!UOFEV871E;"!M^;YE('9I9.QT('-L;[YK
M=0!397IN86T@9&%T86+A>NT`4V5Z;F%M('3I;6%T(&[A<&]V[&1Y`%-E>FYA
M;2!T86)U;&5K`%-E>FYA;2U!<F-H:78`4V5Z;F%M+4[A<&]V[&1A`%-E>FYA
M;2U)9`!397IN86TM260`4V5Z;F%M+59L87-T;NUK`%-E>FYA;2U/9&5S;.%N
M[0!397IN86TM4/AI:&SAN65N[0!397IN86TM3V1H;.&Y96[M`%;]<&ES('6^
M:79A=&5L^2!N96[M(&1O<W1U<&[]+@!,:71E<F%T=7)A`$QO='FY<VMO`$YA
M:'+A=N%N[2XN+@!-[7-T;NT@Z&%S.B``3&]C86QE(&$@Z&%S`$WM<W1O`%#X
M:6ALX7-I="!S90!/9&ALX;EE;NT`VFMO;'D@<')O=N%D[&[I('#X:2!P^&EH
M;.&Y96[M`%-E;&AA;&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU+B!0<F%V9.QP
M;V1O8F[L(%9AN64@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO(&YE
M8GEL;R!S<'+A=F[L('IA9.%N;RX`4/AI:&SAN65N[2!S96QH86QO+@!$;&]U
M:/T@=&5X=`!,X7-K80!.[7IKX0!-86SA(/AE8VOA('#M<VUE;F$`36%LX2!T
M:7-K86/M('#M<VUE;F$`36%LZ2#X[6US:^D@Z.US;&EC90!,=6-E;6)U<G-K
M;P!-30!:<'+A=F$@9&YE`%#X:7!O:F5N_2!S;W5B;W(@35,M3E1%1B!N96]B
M<V%H=6IE(+[A9&[A(&1A=&$N`$U31P!-86MA;P!-86ME9&]N:64L(&+]=F%L
MX2!297!U8FQI:V$@2G5G;W-LX79I90!-861A9V%S:V%R`$UA9VEE`%!ON71A
M`$%D;6EN:7-T<N%T;W(@<&^Y='D`5GET=F_X:70@;V1?:V%Z+BXN`$UA;&%W
M:0!-86QA:G-I90!-86QD:79Y`$UA;&D`36%L=&$`4')O('5M;[YN[&[M(&]V
M;.%DX6[M(&MA=&5G;W)I[2!J92!Z87!O=/AE8NT@;WIN8>AI="!P;VQOOFMY
M(&)A<G9A;6DL(&MT97+I(&IS;W4@</AI^&%Z96YY(&L@=.QM=&\@:V%T96=O
M<FGM;2X`36%P82!-87`R-`!-87!A($UA<%%U97-T`$]Z;F%?Z&ET('IP<N%V
M=2!Z82!V>6UA>F%N;W4`0OAE>F5N`$]K<F%J`$]Z;F'H:70@6G!RX79U(&IA
M:V\Z`$]Z;F'H:70@>FYAZ&MO=2!0<F]H;.ED;G5T;R].97!R;VALZ61N=71O
M`$]Z;F'H:70@:FEN_6UI('IN8>AK86UI("AJ86MO($3Y;&6^:73I+T]D<&]V
M['IE;NDI`$UA<KEA;'-KZ2!/<W1R;W9Y`$UA<G1I;FEQ=64`4VAO9'5J92!S
M90!3:&]D=6KM8^T@<V4@<&]L90!-875R973A;FEE`$UA=7)I8VEU<P!-87AI
M;6%L;NT@<&]V;VQE;OT@:W)E9&ET`$)Y;&$@</AE:W)OZ&5N82!M87AI;6%L
M;NT@9.EL:V$@>G!RX79Y+@!.96IV>;FY[2!T97!L;W1A('IA('!O<VQE9&[M
M8V@@,C0@:&]D:6XZ(`!.96IV>;FY[2!T97!L;W1A('IA('!O<VQE9&[M8V@@
M-B!H;V1I;CH@`$UA>&EMX6QN[2!DZ6QK80!">6P@</AE:W)OZ&5N(&UA>&EM
MX6QN[2!L:6UI="!A9')E<R!N82#H97)NZ2!L:7-T:6[L("A#96QK;W;]('!O
MZ&5T(&%D<F5S.B`E<RP@36%X:6WA;&[M('!OZ&5T(&%D<F5S.B`E<RDN($YE
M;'IE('#X:61A="!A9')E<W4@;F$@Z&5R;F]U(&QI<W1I;G4N`$)Y;"!P^&5K
M<F_H96X@;6%X:6WA;&[M(&QI;6ET(&%D<F5S(&YA(&+M;.D@;&ES=&EN["`H
M0V5L:V]V_2!P;^AE="!A9')E<SH@)7,L($UA>&EMX6QN[2!P;^AE="!A9')E
M<SH@)7,I+B!.96QZ92!P^&ED870@861R97-U(&YA(&+M;&]U(&QI<W1I;G4N
M`$MV['1E;@!-87EO='1E`$UE9&EC[6YA`,AL96YO=ND`3?-D>2!P<F\@;65N
M=3H`4W!O:FET(&)U\FMY`%IP<N%V80!:<'+A=F$@8GEL82!O=NSX96YA('8@
M<&_XX61K=2P@86QE(&YE;'IE(&]V[/AI="!P;V1P:7-O=OT@8V5R=&EF:6OA
M="X`6G!RX79A('!R;W!A9&QA+@!4>7`@>G!RX79Y`%!OZ&%S[0!";&]K(&\@
M<&_H87/M(&YE;NT@9&]S='5P;OTN`$)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T
M=7!N_2X@4&]D<F]B;F]S=&D@8GEL>2!Z87IN86UE;N%N>2!P<F\@<WES=.EM
M;W;I:&\@861M:6YI<W1RX71O<F$@9&\@;&]G=2X`365T;V1A`$UE=')I8VO]
M`$UE>&EK;P!-:6MR;V[I<VEE+"!&961E<F%C90!5<')O<W3X960`5'EP($UI
M;64`3F5J;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``
M3F5J;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!:<F-A
M9&QO=NP`4OEZ;ND`4')O9W)A;6]V_2!B86SM:R!(5%107U)E<75E<W0@8VAY
M8NT@=B!014%2+@!#:'EB[2!A9')E<V$@<')O('#X97-M[')O=N%N[2!Z<'+A
M=GD`0VAY8NQJ[6/M(&MO;F9I9W5R86-E+B!0;VMU9"!S:2!P^&5J971E('!O
M=;[M=F%T('1U=&\@87!L:6MA8VDL(&UU<^UT92!V>6=E;F5R;W9A="!K;VYF
M:6=U<F'H;NT@<V]U8F]R+@!#:'EB[&KM8^T@240@>G!RX79Y("AI9&5N=&EF
M:6MAZ&[M(.CM<VQO*0!#:'EB[2!D^79O9"!P<F\@>F%M[71N=73M('IP<N%V
M>0!#:'EB[2!D^79O9"!V(&1O=F]L96[I+@!0;[YA9&]V86[]('!R;V=R86UO
M=OT@8F%L[6L@36%I;"!C:'EB[2!V(%!%05(N`$-H>6+L:NUC[2!)1"!P<F\@
M<F5L86-I+@!0;P!-;V)I;&[M('!ON71A`$WM<F[]`$1A='5M('!O<VQE9&[M
M('IM[&YY`%IM[/)I="!54DP`36]D=6P`36]L9.%V:64`36]N86MO`$UO;F=O
M;'-K;P!-['/M8R!A(')O:P!-['/MZ&[L`$UO;G-E<F%T`$;A>F4@3>QS[6-E
M`$UA<F]K;P!0^&5VX;YN["!J87-N;P!0^&5VX;YN["!O8FQAZ&YO`%#X97;A
MOF[L('-L=6YEZ&YO`%#X97-U;F]U=`!0;W-U;F]U="!D;VSY`%!O<W5N;W5T
M(&1O;&5V80!0;W-U;F]U="!D;W!R879A`%!O<W5N;W5T(%!R879I9&QO($1O
M;/D`4&]S=6YO=70@4')A=FED;&\@3F%H;W)U`%!O<W5N;W5T(&YA:&]R=0!0
M;W-U;F]U="!D;VSY`%!O<W5N;W5T(&YA:&]R=0!-;W-A;6)I:P!6[6-E+?IR
M;W;R;W;I(')O;&5T;W;I('-E>FYA;7D`5NUC96[A<V]B;N$@<V5L96MC90!-
M^6H@^NAE=`!-^6H@<&]R=.%L`$UO:F4@<F]Z;&^^96[M('!O<G3A;'4`37EA
M;FUA<@!.12P@3D533U5(3$%3S4T`4%]OZ&5T(&1N^2!M97II(&]D<&]V[&1I
M(&1O=F]L96[I.@!*;>EN;P!.86UI8FEE`$YA=7)U`$YE<.%L`$YI>F]Z96WM
M`$YI>F]Z96US:^D@06YT:6QY`$YE='-C87!E($)A<V4@55),`$YE='-C87!E
M($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T
M<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`2FWI
M;F\@3F5T<V-A<&4@4U-,('-E<G9E<G4`4&]Z;N%M:V$@:R!C97)T:69I:^%T
M=2!.971S8V%P=0!4>7`@8V5R=&EF:6OA='4@3F5T<V-A<'4`4^V[`$YI:V1Y
M`$YO=N$@2V%L961O;FEE`$YO=N$@:V%T96=O<FEE`$WL<^UC('8@<')V;NT@
MZ'1V<G1I;NP`3F]VZ2!0<F%V:61L;P!.;W;I('6^:79A=&5L<VOI(&IMZ6YO
M("AN97!O=FEN;NDI`$YO=OT@6NEL86YD`$YO=ND@;VMN;R`H7W!RX7ID;NDI
M`$YO=FEN:WD`3F5W<V=R;W5P<P!$86RY[0!$86RY[2!M;[YN;W-T:0!.:6MA
M<F%G=6$`3FEG97(`3FEGZ7)I90!.;V,`3FEU90!.90"N861NX2!K;VYF:6=U
M<F'H;NT@9&%T82!N96IS;W4@9&]S='5P;N$@<')O('IO8G)A>F5N[2!R;WID
M[6SY+@!.96[M(&1O<W1U<&[A(+[A9&[A('-T<F%T96=I92!P<F\@='9O<F)U
M($E33R!O8G)A>ODN`$)A8VME;F0@;F5B>6P@:V]N9FEG=7)O=N%N('!R;R!T
M96YT;R!H;W-T+@!"86-K96YD(&YE8GEL(&MO;F9I9W5R;W;A;B!V(&)A8VME
M;F1S+G!H<`!"97H@9.%V:V]VZ6AO('9Z;W)U+@!.82!P;[YA9&]V86[I('!O
M>FEC:2!N965X:7-T=6IE(+[A9&[](&)L;VL`3F5B>6QO('!O<VMY=&YU=&\@
MON%D;ND@:FWI;F\@<')O(&MA;&5N9.'X('#X:2!O=NSX;W;A;NT@<&]M;V/M
M($U#04PN`$)E>B!Z;>QN>2X`3F5L>F4@</AI9&%T(+[A9&[A('!O9"UP<N%V
M82!K('3L;71O('!RX7;Y;2X`3F5B>6QY('5V961E;GD@ON%D;ND@:V]N9FEG
M=7)AZ&[M(&EN9F]R;6%C92!P<F\@)7,N`$YE8GEL>2!U=F5D96YY(+[A9&[I
M(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O($944"!61E,N`$YE8GEL>2!U
M=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O(%-13"!6
M1E,N`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA
M8V4@<')O(%-13"U&:6QE(%9&4RX`3F5MX71E(+[A9&[](&MR961I="X`3F5B
M>6P@<&]S:WET;G5T(+[A9&[](&/M;"X`KN%D;OT@<V]U8F]R(&YE8GEL('#X
M96YE<V5N`$YE8GEL82!U=F5D96YA(+[A9&[A(&AL879IZ&MA+@!.96)Y;'D@
M;F%L97IE;GD@ON%D;ND@:6MO;GDN`$YE8GEL;R!V>6)RX6YO(+[A9&[I(&WM
M<W1O+@!.96)Y;'D@<&]S:WET;G5T>2"^X61NZ2!Z<'+A=GDN`$YE8GEL;R!U
M=F5D96YO(+[A9&[I(&IMZ6YO+@!.96)Y;&\@=79E9&5N;R"^X61NZ2#H[7-L
M;RX`0F5Z(&YE<VQUN6[]8V@`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O
M(&]V[/AE;NT@<&]M;V/M($A45%`N`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO
M('!R;R!O=NSX96[M('!O;6]C[2!)34%0+@!.96)Y;&\@<&]S:WET;G5T;R!H
M97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@2V5R8F5R;W,N`$YE8GEL;R!P;W-K
M>71N=71O(&AE<VQO('!R;R!O=NSX96[M('#X:6ALX;EE;NT@<V4@9&\@<WES
M=.EM=2X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M
M;V/M(%!!4U-71"X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE
M;NT@<&]M;V/M(%--0BX`3F5B>6QA('!O<VMY=&YU=&$@8V5S=&$@:R!B:6[A
M<F[M;74@<V]U8F]R=2!/<&5N4U-,+B!":6[A<F[M('-O=6)O<B!/<&5N4U-,
M(&IE('IA<&]T^&5B[2!P<F\@<'+A8VD@<R!02T-3(#$R(&1A='DN`*[A9&[I
M(&YE=GGX[7IE;ND@ON%D;W-T:2!O('#X:6ALX;EE;NTN`$)E>B!P<F%V:61E
M;`!.96)Y;"!G96YE<F]VX6X@ON%D;OT@<VMR:7!T+@!"97H@;VMR86KY`$YE
M8GEL:2!U=F5D96YY(+[A9&[I('IN86MY`*[A9&[]('H@9&_H87-N_6-H(&%D
M<F5SX?CY(&YE;NT@9&]S='5P;OT@<')O(&-A8VAE+@!.96)Y;&\@;V1E<VSA
M;F\@ON%D;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+@!.96)Y
M;&$@;F%V<N%C96YA(+[A9&[A('!L871NX2!834P@9&%T82X`KN%D;ND@:&]D
M;F]T>0!6(&]R:6=I;N%L;NT@:V]N9FEG=7)A8VD@;F5B>6QA(&YA;&5Z96YA
M('9E<GIE+B!/8FYO=G1E(&MO;F9I9W5R86-I+@!692!68;GM(&MO;F9I9W5R
M86-I(&YE8GEL82!N86QE>F5N82!V97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C
M:2X`KN%D;OT`KN%D;OT@*'!O=;YI:G1E(&EM<&QI8VET;NTI`%-E=F5R<VO]
M("A)4T\M.#@U.2TQ,"D`3F]R9F]L:W-KZ2!O<W1R;W9Y`%-E=F5R;NT@<&]L
M;VMO=6QE`%-E=F5R;NT@36%R:>%N<VOI(&]S=')O=GD`3F]R<VMO`$YE;NT@
M<&\`3F5N[2!P^&5D`$YE;NT@861R97/A^&5M`$YE<F]V;N$@<V4`3F5N[2!I
M;7!L96UE;G1O=N%N;RX`3F5N[2!N87-T879E;F\`3F5N[2!P;V1P;W)O=N%N
M;RX`4&]Z;N%M:V$`3FEC(&L@<')O:&SI9&YU=.TL(&+LOG1E('IP['0N`$QI
M<W1O<&%D`,CM<VQO`%!OZ&5T('IN86OY`%!OZ&5T('-L;W5P8_D`4&_H970@
M^.%D:_D`3F5B>6QA('IA9.%N82#H[7-L82!P<F\@86MT=6%L:7IA8VD@9&ES
M=')I8G7H;NUH;R!S97IN86UU+@!/2P!/8FIE:W0`5';Y<F-E(&]B:F5K=/D`
M3W-M:>AK;W;]`-CM:F5N`$9I;'1R;W9A="!N97-L=;ENZ0!+86YC96SA^`!/
M;>%N`%-D[6QE;ND@<VQOOFMY(&IS;W4@<&]S:WET;W;A;GD@<&]U>F4@24U!
M4"!S97)V97)Y+@!0;W5Z92!N97-L=;ENZ0!*92!P;W9O;&5N82!P;W5Z92!J
M961N82!E+6UA:6QO=N$@861R97-A+@!0;W5Z92!V;&%S=&[M:R!N96)O('-Y
M<W3I;6]V_2!A9&UI;FES='+A=&]R(&WYOF4@;>QN:70@<'+A=F$@<')O('-D
M[6QE;OT@;V)J96MT+@!/=&5V^.UT('8@;F]VZ6T@;VMN["X`0VAY8F$@3W!E
M;E-33#H@3F5L>F4@>NUS:V%T(&1A=&$@>B!P;V1E<'-A;ND@Z.%S=&D@4R]-
M24U%+@!/=&5V^.UT('1E;G1O(&]D:V%Z('8@;F]VZ6T@;VMN[`!/<&5R8>AN
M[2!S>7-TZ6T`36^^;F]S=&D`36^^;F]S=&D@<')O(&%K='5A;&EZ86-I('-K
M<FEP='4N`$UOOFYO<W1I('!R;R`E<P!39?AA>F5N_2!S97IN86T`3W)G86YI
M>F%C90!/<F=A;FEZ8>AN[2!J961N;W1K80!/<F=A;FEZ;W;A;NT`3W)I9VEN
MX6QN[2!V>F]R('!R;R"^X61O<W0`3W)I9VENX6QN[2!V>F]R('8@)7,Z`$]S
M=&%T;NT`3W-T871N[2!I;F9O<FUA8V4`1&%LN>T@36^^;F]S=&D`5;YI=F%T
M96QS:^$@<'+A=F$`3W;L^&5N[2!P;VUO8^T@4$%-(&YE;NT@9&]S='5P;NDN
M`%!'4"!D:6=I=.%L;NT@<&]D<&ES`%!'4""Y:69R;W9A;N$@9&%T80!69?AE
M:F[](%!'4"!K;.WH`$1A=&$@<&]D97!S86[A+[EI9G)O=F%NX2!P;VUO8^T@
M4$=0`%!(4"!K\V0`4$A0(&MO;GIO;&$`3V1P;VQE9&[M(&QE:&O](&3IN;L`
M3V1P;VQE9&[M('#X96CA\FMY`$]D<&]L961N[2!S;NR^96[M`$]D<&]L961N
M[2!S;NQH;W;I('#X96CA\FMY`$]D<&]L961N[2!B;W7X:WD`4%](4"!K;VYZ
M;VQA`$]D<W1U<'D`4.%K:7-TX6X`4&%L874`4&%L97-T:6YS:^D@=&5R:71O
M<FEU;2P@;VMU<&]V86[I`%!A;F%M80!087!U82!.;W;A($=U:6YE80!087)A
M9W5A>0!-[7-T>2!Z871AOF5N;P!(97-L;P!.97-P<N%V;ND@:&5S;&\`4')O
M(&]V[/AE;NT@<&]M;V/M(%)!1%5)4R!J92!N=71N;R!Z861A="!H97-L;RX`
M2&5S;&\@<R!P;W1V<GIE;NUM`$AE<VQO.@!(97-L;SH@`$AE<VQA('-E(&UU
M<^T@<VAO9&]V870N`%9L;[YI=`!6;&^^:70@>F4@<V-H<N%N:WD`0V5S=&$`
MKN%D;W-T:2!O('#X:6ALX;EE;NTZ`$QI9.D`4')O8V5N=`!0<F]VZ7-T(&]P
M97)A8V4@^F1ROF)Y`%!R;W;I<W0@;W!E<F%C92#Z9'*^8GD@</AI('#X:6AL
MX;EE;NT@9&\@<WES=.EM=3\`4'+A=F$`061M:6YI<W1R8>AN[2!P<N%V80!/
M<V]B;NT@:6YF;W)M86-E`%!E<G4`1&]MX6/M('IV[?AA=&$`1FEL:7#M;GD`
M5&5L969O;@!&;W1O9W)A9FEE`%!I=&-A:7)N`%!I>&5L^0!&<N%Z90!0<F]S
M[6T@:VQI:V[L=&4@;F$@;NQJ86MO=2!B=?)K=0!0<F]S[6T@<&]T=G+O=&4L
M(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E;G1O('!R=F5K.@!0<F]S[6T@
M<&]T=G+O=&4L(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E;G1O('!R=F5K
M+@!0<F]S[6T@>F%D96IT92!M['/M8R!A(')O:RX`4')O<^UM('IA9&5J=&4@
M;N%Z978@;F]VZ2!K871E9V]R:64Z`%!R;W/M;2!Z861E:G1E('-P<N%V;F]U
M($E0(&%D<F5S=2XN`%!R;W/M;2!Z861E:G1E('-P<N%V;OT@9&%T=6T@82!Z
M:V]N=')O;'5J=&4@<&_H970@9&[M('8@;>QS[6-I+@!0<F]S[6T@>F%D96IT
M92!S<'+A=F[](.AA<RX`4')O<^UM('IA9&5J=&4@;N%Z978@;F]VZ2!S;&^^
M:WDZ`%!R;W/M;2!U=F7O=&4@<VAR;G5T[2!68;EE:&\@<')O8FSI;74N`%!R
M;W/M;2!Z861E:G1E(%9AN64@=;YI=F%T96QS:^D@:FWI;F\@82!H97-L;P!0
M<F]S[6T@>F%D96IT92!N;W;](&[A>F5V(&MA=&5G;W)I93H`4&]L<VMO`%!O
M;&ET:6MA`$AL87-O=N%N[0!0;W)T=6=A;'-K;P!5;>US=.QN[2!T;VAO=&\@
M;V)RX7IK=0!5;>US=.QN[2!T86)U;&MY`%IA<VQA="!D;R!TZ71O('-L;[YK
M>2`H;F5N[2!P;W-K>71N=71O($E-05!E;2D`4W+AOFMY('IA('!O<VQE9&[M
M*&-H*2`E<R!H;V1I;BAU*3H@`%!R969S7VQD87`Z($YE8GEL82!N86QE>F5N
M82!P;[YA9&]V86[A('#X[7!O;F$@3$1!4"X`4')E9G-?<V5S<VEO;CH@3F5B
M>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!S96MC92X`0F%R;VUE
M=')I8VO]('1L86L`0F%R;VUE=')I8VO]('1L86L@;F$@^G)O=FYI(&UO^&4Z
M(`!"87)O;65T<FEC:_T@=&QA:SH`3N%H;&5D`$[A:&QE9"!O8G+A>FMU('8@
M;F]VZ6T@;VMN[`!0^&5D8VAO>NT@;6^^;F]S=&D`5&ES:VYO=70@9&]K=6UE
M;G0`4')I=N%T;NT@:VSMZ`!0<F]B;.EM`%!O<&ES('!R;V)LZ6UU`%!R;VIE
M:W1Y`%!R;VUP="!T97AT`%9E^&5J;OT@:VSMZ`!!;&=O<FET;75S('!R;R!V
M9?AE:F[](&ML[>@`5F7X96IN_2]P<FEVX71N[2!K;.WH;W;]('#A<B!N96)Y
M;"#Z<W#LN6[L('9Y='9O^&5N+@!0;W)T;W)I:V\`2V%T87(`5GEH;&5DX6[M
M`%)302!V9?AE:F[](&ML[>@@*"5D(&)I=/DI`$1?^79O9`!3</AAOF5NZ2!T
M;&'H[71K;P!$Z;F[`$)R>FO](&3IN;L`4&]Z9&[M(&3IN;L`1&6YNV]VZ2!P
M^&5HX?)K>0!$Z;F[('-E('-N[&AE;0!$Z;F[(&&^('-N[6@`3N%H;V1N["!V
M>6)R86[I(+ET['-T[0!0;VWL<@#(=&5C[0!0^&7H=&5NZ2!Z<'+A=GD`3W!R
M879D=2!S;6%Z870@)7,_(%1A=&\@;W!E<F%C92!J92!N979R871NX2X`3W!R
M879D=2!S;6%Z870@=;YI=F%T96QS:^$@9&%T82!P<F\@=;YI=F%T96QE("5S
M/R!4871O(&]P97)A8V4@:F4@;F5V<F%T;N$N`%#X:6IA=&\`4/AE<VWL<F]V
M870@9&\`3W!A:V]V870@<&]S;&5D;NT@86MC:0!/8FYO=FET(&1Y;F%M:6-K
MZ2!P<G9K>2!M96YU.@!/8FYO=F$@>F]B<F%Z96[M('!O<G3A;'4Z(`!296=E
M>`!296=U;&%R(&5X<')E<W-I;VX`6F%M[71N=71O(',@9/EV;V1E;0!0<F]H
M;.V^9>@@=GIT86CY`$AO9&YO='D`5GIDX6QE;ND@<V5R=F5R>2X`5GIDX6QE
M;N$@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`3V1S=')A
M;FET`$]D<W1R86YI="!B;&]K`$]D<W1R86YI="!S;&]U<&5C`$]D<W1R86YI
M="!F;W)MX71O=N%N[0!/9'-T<F%N:70@<.%R`$]D<W1R871I="!U;&^^96[]
M('-K<FEP="!Z(&1OZ&%S;NEH;R!A9')E<^'X92!N82!S97)V97)U+@!/9'-T
M<F%N:70`3V1S=')A;FET('1U=&\@Z.%S="!D;VMU;65N='4`3V1S=')A;FET
M('6^:79A=&5L90!/9'-T<F%N:70@=;YI=F%T96QE.B`E<P!.96QZ92!O9'!O
M=NQD['0@;F$@<&^^861A=F5K+B!#:'EB;W;I(&ALX;EE;NTZ(`!0;[YA9&]V
M86[I('!O;&4`4/AE<&]S;.%N;R!+;VUU`%#X97!O<VSA;F\M3V1K;VAO`%;]
M8VAO>NT@;F%S=&%V96[M`%;]8VAO>NT@;F%S=&%V96[M(&AE<VQA`%;]8VAO
M>NT@;F%S=&%V96[M(%9AN65H;R!H97-L80!6_7-L961K>0!.X79R870@:R!3
M97IN86UU($9I;'1R^0!.X79R870@9&\@;6^^;F]S=.T`3N%V<F%T(&L@4V5Z
M;F%M=2!&:6QT<F]V86/M8V@@4')A=FED96P`4F5U;FEO;@!0^&5P;F]U="!K
M;VYF:6=U<F%C:0!-;[YN;W-T:2!2:6-H(%1E>'0@961I=&]R=0!(X61A;FMY
M`$1O<')A=F$`2&QA=FGH:V$@;F%P<F%V;P!(;V1N;W1Y(&YA<')A=F\`5FQA
M<W1N;W-T:2#XX5]D:W4`VFQO:&$`4G5M=6YS:V\`3W1OZ&ET(&\@,3@PL`!/
M=&_H:70@9&]L979A`$]T;^AI="!D;W!R879A`%9L87-T;F]S=&D@^.%D:W4`
M5FQA<W1N;W-T:2#XX61K=0#8X61K>3H`4')A=FED;&\`4')A=FES;&\@8GEL
M;R!K;W#M<F]VX6YO`%!R879I9&QO(&)Y;&\@4VUA>N%N;P!0<F%V:61L;R!B
M>6QO($1E86MT:79O=N%N;P!0<F%V:61L;R!B>6QO($%K=&EV;W;A;F\`3N%Z
M978@4')A=FED;&$`4')A=FED;&$`4')A=FED;&$@<V4@=7!L871N[2!M97II
M(':Y96UI(/CA9&MY(&$@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M('!O
M=7IE(&UE>FD@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M('!O=7IE(&UE
M>FD@^.%D:WD`4')O=NES=`!2=7-KX2!F961E<F%C90!2=V%N9&$`4R]-24U%
M(+EI9G)O=F%N_2!P;V1P:7,`4R]-24U%(+EI9G)O=F%NX2!Z<'+A=F$`3W;L
M^&5N[2!P;VUO8^T@4T%33"!N96[M(&1O<W1U<&[I+@!335,@>G!RX79Y`%-1
M3"!K;VYZ;VQA`%-32`#:4U#,0T@`4U]13"!K;VYZ;VQA`%-O`%-V873A($AE
M;&5N80!3=F%T_2!+:71T<R!A($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,`4W1E:F[]('+A;2`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@86YD(%!R:6YC:7!E`%9L87-T;NUK('-A=&5L:71U`%-A=61S:^$@
M07+A8FEE`%5L;[YI=`!5;&^^:70@)7,`56QOOF5N[2!M;[YN;W-T[0!-;[YN
M;W-T:2!5;&^^96[M`%5L;[YI="!V>71V;_AE;OT@:V]N9FEG=7)AZ&[M(%!(
M4"!S:W)I<'0@9&\@9&_H87-NZ6AO(&%D<F5SX?AE(&YA('-E<G9E<G4N`$MO
M;F9I9W5R86-E("5S('5L;[YE;F$N`%;L9&$`4VMR:7!T`$%K='5A;&EZ86-E
M(%-K<FEP='4`4VMR:7!T(&YE8GEL($%K='5A;&EZ;W;A;BX`4VMR:7!T(&)Y
M;"#Z<W#LN6[L(&%K=&EV;W;A;BX`4VMR:7!T(&)Y;"#Z<W#LN6[L(&1E86MT
M:79O=N%N+@!6>6AL961A=`!6>6AL963A=F%C[2!NX7-T<F]J90!0<F]H;.UD
M;G5TZ0!6>6)R870@<V]U8F]R>0!6>6)R870@9&%T=6T`5GEB<F%T('!O;&4`
M5GEB<F%T('-K=7!I;G4L(&MT97+A(&)U9&4@</AI9.%N80!6>6)R870@;F]V
MZ6AO('9L87-T;NUK80!6>6)R870@<V5R=F5R`%9Y8G)A="!UOFEV871E;&4L
M(&MT97+](&)U9&4@</AI9.%N`%9Y8G)A="!VN65C:&YY(.CA<W1I(&1A='5M
M=2X`5GEB<F%T(&]B:F5K=`!6>6)R870@8^UL;W9O=2!S;&^^:W4`5GEB97)T
M92!P;W3X96)NZ2!Z;F%K>2!Z(&[MOF4@=79E9&5N_6-H(&)O>/DN(%!O=.D@
M:F4@;?F^971E(&MO<.UR;W9A="!A('9L;[YI="!Z('1E>'1O=ND@;V)L87-T
M:2X`5GEB97)T92!O9&3L;&]V86/M('IN86L@<')O(&1A='5M.@!6>6)E<G1E
M(&9O<FWA="!D871U;74Z`%9Y8F5R=&4@:61E;G1I='4L(&MT97)O=2!S:2!P
M^&5J971E('IM[&YI=#H`5GEB97)T92!O9&3L;&]V86/M('IN86L@<')O(.AA
M<SH`5GEB97)T92!F;W)MX70@Z&%S=3H`5GEB97)T92!D=NP@;V1P;W;M9&%J
M[6/M('!O;&4N`%9Y8F5R=&4@8F%R979N_2!M;W1I=BX`5GEB97)T92!6X6UI
M('!R969E<F]V86[](&IA>GEK.@!386UA('-E($1E9FEN=6KM8^T@2&QA=FGH
M:V$`4&]S;&%T('IP<N%V=2!O('!R;V)LZ6UU`%!O<VQA="!335,`3V1E<^UL
M871E;`!396YE9V%L`%-E;G-O<CH`6N'X[0!3<F)S:V\@82#(97)NX2!(;W)A
M`%/I<FEO=ND@Z.US;&\`240@<V5K8V4@>F%N:6ML;RX`3F%S=&%V:70`3F%S
M=&%V:70@;6^^;F]S=&D@<')O('!O=F]L96[M(')E<V5T=2!H97-L82P@<&]K
M=60@:&\@>F%P;VUE;F5T92X`3F%S=&%V:70@=GIDX6QE;ND@<V5R=F5R>2!T
M86LL(+YE(&)U9&]U('#X[7-T=7!NZ2!Z('!O<G3A;'4N`$YA<W1A=F5N[2!6
MX6UI('!R969E<F]V86[I:&\@:F%Z>6MA+"#H87-O=NEH;R!PX7-M82!A('1Y
M<'4@9&%T=6UU+@!.87-T879E;NT@<&_HX71EZ&[M(&%P;&EK86-E+"!B87)E
M=F[I:&\@;6]T:79U+"!O8FYO=F]VX6[M('-T<N%N96L@82!D86RY[6-H(&UO
MOFYO<W3M('IO8G)A>F5N[2X`5F&Y92!N87-T879E;NT@8GEL;R#Z<W#LN6[L
M(&%K='5A;&EZ;W;A;F\N`$YA<W1A=F5N[0!.87-T879O=F%C[2!K;VYF:6=U
M<F'H;NT@<VMR:7!T>2!P<F\@86MT=6%L:7IA8VD@:G-O=2!D;W-T=7!NZ0!.
M[&MT97+A(&WM<W1A(&QZ92!N87-T879I="!S('3M;71O('!A<F%M971R96TZ
M(`!397EC:&5L;&5S`$YA:W5P;W;A;NT`2W+A=&OI('-H<FYU=.T`3>QL>2!B
M>2!B_70@</CM<W1U<&]VZ2!K;.WH92!D969I;F]VX6YY('!R;R!V['2Y:6YU
M(&]D:V%Z^3\`6F]B<F%Z:70`6F]B<F%Z:70@06MT:79N[2!3:W)I<'0`6F]B
M<F%Z:70@06MT=>%L;NT@4VMR:7!T`%IO8G)A>FET(')O>F3M;'D@;65Z:2!S
M;W7H87-N;W4@82!P^&5D8VAO>NT@:V]N9FEG=7)A8^TN`%IO8G)A>FET(.AA
M<R!P;W-L961N[6AO('#X:6ALX;EE;NT@9&\@<WES=.EM=3\`6F]B<F%Z:70@
M;6^^;F]S="!U9'*^96[M(&]R:6=I;N%L=0!:;V)R87II="!S8NQR8>@`6F]B
M<F%Z:70@;65N=2!O<&5R8>AN[2!L:;ET=2!P<F\@=&%B=6QK>3\`6F]B<F%Z
M:70@)7,@;65N=2!N86QE=F\_`%IO8G)A>FET(&1I86QO9R!P<F\@=FQA<W1N
M;W-T:2!B=6[L:R!V('1A8G5L:^%C:`!:;V)R87II="!D:6%L;V<@=FQA<W1N
M;W-T[2!T86)U;&5K`%IO8G)A>FET(&1I86QO9R!V;&%S=&YO<W3M(/CA9&5K
M('1A8G5L96L`6F]B<F%Z:70@9&EA;&]G('9L87-T;F]S=.T@;V)RX7IK^0!:
M;V)R87II="!P^&5N;W,`4/AE:.'R:WD`0G)Z:^D@</AE:.'R:WD`4&]Z9&[M
M('#X96CA\FMY`%#X96CA\FMY('8@;VMO;.T`6FUE;KEI=`!:;65NN6ET(&YE
M8F\@<&]S=6YO=70@9&\@<V]U<V5D;NUH;R!B;&]K=2CY*2P@>B!C97-T>2!P
M<G9N[6UU`%-I97)R82!,96]N90!296=I<W1R;W9A="!S90!0;V1P:7,`06QG
M;W)I=&UU<R!P<F\@<&]D<&ES`%-I;F=A<'5R`%9E;&EK;W-T`%9Y;F5C:&%T
M(/ID<KYB=0!3;&]V96YS:V\`4VQO=FEN<VMO`%-N[+YE;NT`4V[L:&]VX2!P
M^&5HX?)K80!3;NQH;W;I('#X96CA\FMY`%)A;F[M('-N[&AO=ND@</AE:.'R
M:WD`4&]Z9&[M('-N[&AO=ND@</AE:.'R:WD`4V[L:&]VX2!P;VMR_79K83H`
M5F]D;NT@96MV:79A;&5N="!P<F\@<V[M:#H@`*EA;&%M;W5N;W9Y(&]S=')O
M=GD`4V]MX6QS:V\`4.US;NP@82!BX7-N[`!3;>QR('3X[63L;NT`6F1R;VIO
M=N$@861R97-A`$IIOF[M($%F<FEK80!*:6AO979R;W!S:_T@*$E33RTX.#4Y
M+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S`$IIOF[M('!O;&]K;W5L90!0<F]S=&]R(&UE>FD@<V]U<V5D;NUM:2!B
M=?)K86UI`%!R;W-T;W(@;65Z:2!O8G-A:&5M(&$@:')A;FEC96UI('8@8G7R
M8V4`365Z97)N[6L`365Z97)Y`$]D<W1U<'D@82!M97IE<GD`J7!A;NQL<VMO
M`%-P86T`5G-T=7`@<')O('IV;.&Y=&[M('IN86MY`%)O>F3L;&ET(&)U\FMU
M`%)O>F3L;&ET('-L;W5P96,`4F]Z9.QL:70@^.%D96L`4W!O<G0`4W)I($QA
M;FMA`%-T86YD87)D`%-T87(@5')E:P!2;VL@>F'HX71K=0!3=.%T(.AI('!R
M;W9I;F-I90!3=&%V`%IA='-T879I="!K;VYT<F]L=2!P;VMU9"!S92!S:&]D
M=6IE(',@=.UM=&\@<')A=F]D;&5M/P!&;W)MX70@=6QOOF5N[0!5;&EC90!0
M^&6Y:W)T;G5T_0!397IN86T@^&5T['IC90!/9'-T<F%N:70@9&]MZ6YO=ND@
M:FWI;F\@>B!A9')E<WD`4W1Y;"!;0U-370!.90!0^&5D7VWL="!P<F\@>G!R
MX79U(&\@9&]V;VQE;NDZ`%#X961M['0`4&]D870`1&]L;NT@:6YD97@`VG-P
M[+EN[`!+;VYF:6=U<F%C92!B>6QA(/IS<.RY;NP@>FWL;NQN82X@3V)N;W9T
M92!S='+A;FMU+@#:<W#LN6[I('5L;[YE;NT@>N%L;[YN[2!K;VYF:6=U<F%C
M92X`VG-P[+ENZ2!U;&^^96[M('KA;&]H>2!K;VYF:6=U<F'H;NUH;R!S;W5B
M;W)U("5S+@`E<R!B>6QO(/IS<.RY;NP@>F%P<^%N;P!3=63A;@!3:')N=73M
M`%-V[73A;NT`6N%P860@4VQU;F-E`%-L=6YEZ&YO`%;]8VAO9"!3;'5N8V4`
M5OUC:&]D+WKA<&%D(%-L=6YC90!6_6-H;V0@4VQU;F-E.B``6N%P860@4VQU
M;F-E`%KA<&%D(%-L=6YC93H@`$AO<F[M(&EN9&5X`%!O9'!O<F$`4W5R:6YA
M;64`4/CM:FUE;NT`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QS:V\`
MJ7;I9'-K;P"I=OUC87)S:V\`4WEN=&%X;W;A(&-H>6)A('8@:&QE9&%NZ6T@
M=&5X='4`4_UR:64`0F]U^&MA`$)O=?AK>0!44U8@<V]U8F]R`%1A8G5L:V$`
M5FQA<W1N;W-T:2!T86)U;&MY`%9L87-T;F]S=&D@=&%B=6QK>0!486EW86X`
M5&%I=V%N+"!P<F]V:6YC:64@R.UN>0!4862^:6MI<W3A;@!486YZX6YI92P@
M4W!O:F5NX2!R97!U8FQI:V$`0^UL.@#::V]L>0!496QE9F]N;NT@Z.US;&\`
M5&5P;&]T82!Z82!P;W-L961N[2!H;V1I;G4Z(`!497!L;W1A`%1E<&QO=&$Z
M(`!6>F]R('!R;R!A9&UI;FES=')A8VD`5&5X=`!0;W5Z92!T97AT`%IA<F]V
M;N%N[2!T97AT=0!6<F-H('1E>'1U`,AT`%1H86IS:WD@*%1)4RTV,C`I`%1H
M86IS:V\`1.QK=6IE;64@>F$@<&]UONUVX6[M('-Y<W3I;74N`%#X[7!O;F$@
M<')O($944"!N96[M(&1O<W1U<&[A+@!);G1E9W)AZ&[M(&%L9V]R:71M>2!V
M($AO<F1E+TMO;&%B(&YE<&]D<&]R=6KM("(E<R(`3F7Z<W#LN6[I(&YAZ'1E
M;NT@=/CM9'D@36%I;G1E;F%N8V4Z.@!">6QO('5Z87;X96YO(&]K;F\@<R!M
M;[YN;W-T;6DN(%5K;V[H96YO+@!!9&UI;FES='+M=&]R('!O=/AE8G5J92!N
M86MO;F9I9W5R;W9A="!T<G9A;.$@<'+A=F$@=B!S>7-TZ6UU+"!P;VMU9"!S
M:2!P^&5J971E('!O=;[M="!P<N%V82X`4&]U>F4@<W!O9&[M('-T<F%N80!.
M96)Y;&\@=79E9&5N;R!)1"!P<F\@:V]N=&%K="P@;F5B>6QO(&YA;&5Z96YO
M('8@9&%T86+A>FD@;F5B;R!B>6QO(/IP;&[L('9Y;F5C:.%N;RX`2V]N=&%K
M="!B>6P@^G-P[+EN["!P^&EDX6X@9&\@5F&Y96AO(&%D<F5SX?AE+@!+(&]V
M[/AE;NT@<&]D97!S86[I('IP<N%V>2!J92!T^&5B82!O9&3L;&5N_2!B;&]K
M(',@4$=0('!O9'!I<V5M+@!.96)Y;&\@=79E9&5N;R!)1"!D:7-T<FEB=>AN
M[6AO('-E>FYA;74L(&YE8GEL;R!N86QE>F5N;R!V(&1A=&%BX7II(&YE8F\@
M8GEL;R#Z<&QN["!V>6YE8VCA;F\N`$YE8GEL('5V961E;B!D:7-T<FEB=>AN
M[2!S97IN86TN`%IP<N%V82!O9"!D<FEV97)U.B``J6EF<F]V86/M(&UOOFYO
M<W1I(&QZ92!V>76^[70@<&]U>F4@</AI(&)E>G!EZ&[I;2!S<&]J96[M(',@
M=V5B96T@*&AT='!S*2X`4V]U8F]R("5S(&)Y(&WL;"!O8G-A:&]V870@;F%S
M=&%V96[M("5S+@!3;W5B;W(@)7,@8GD@;>QL(&]B<V%H;W9A="!N[&MT97+A
M('H@;F%S=&%V96[M("5S+@!3;W5B;W(@;F5L>F4@:V]P[7)O=F%T('/A;2!D
M;R!S96)E+@!3;W5B;W(@;F5O8G-A:'5J92"^X61NX2!D871A+@!.X7-L961U
M:NT@:&QA=FGH:WD@<')O(&UE<W-A9V4O<F9C.#(R('IP<N%V=0!*92!Z;N%M
MZ2P@OF4@;?-D('#X97,@8V5L;W4@;V)R87IO=FMU('8@26YT97)N970@17AP
M;&]R97)U('#Y<V]B[2!P<F]B;.EM>2P@<')O=&^^92!S92!V(&[L;2!V>7-K
M>71U:F4@8VAY8F$L(&MT97+I('-E(&YE;'IE('9Y:&YO=70N($IA:V\@;N%S
M;&5D96L@;?F^92!B_70@;N%H;V1NZ2!Z:')O=6-E;NT@=&]H;W1O('!R;V=R
M86UU+"!C:'EB[&KM8^T@9G5N:V-E(&5D:71O<G4@;F5B;R!N97-P<N%V;ND@
M>F]B<F%Z;W;A;NTN(%!O:W5D(&IE(%;AN2!S>7-T96WI;2!7:6YO9'=S(#EX
M+"!J92!V96QM:2!P<F%V9.QP;V1O8F[I+""^92!S92!O8FIE=NT@8VAY8F]V
MZ2!H;.&Y96[M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&$@8G5D971E
M(&UU<V5T(')E<W1A<G1O=F%T('!OZ.UT8>@N7&Y<;D)Y;&D@:G-T92!V87)O
M=N%N:2X@4')O<^UM('-T:7-K;NQT92!/2R!P;VMU9"!S:2!P^&5J971E('!O
M:W)AZ&]V870@=B!M\V1U('#X97,@8V5L;W4@;V)R87IO=FMU+@!)9&5N=&ET
M82`B)7,B(&)Y;&$@<VUA>N%N82X`4&]U>F4@;F$@;&5VZ2!S=')A;NP`56WM
M<W3L;NT@8FENX7)N[6AO('-O=6)O<G4@1VYU4$<@;75S[2!B_70@>F%DX6YO
M(&1O('3X[61Y($-R>7!T7W!G<#HZ+@!:<'+A=F$@>F%S;&%NX2!V("5S(&L@
M)7,@<R!P^&5D;>QT96T@(B5S(B!B>6QA('IO8G)A>F5N82X*5&]T;R!N97IA
M<G7H=6IE+""^92!Z<'+A=F$@8GEL82!P^&7H=&5N82!N96)O(+YE(&KM(&%D
M<F5SX70H:V$I(')O>G5M[&PH82DN`$[A>F5V+"!K=&5R_2!B=61E('!O=;YI
M="!P^&D@;V1K87IO=N%N[2!N82!S='+A;F-E('1V;W)B>2!Z<'+A=@!4^.UD
M82!(;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN
M`$YE;'IE('5L;[YI="!N87-T879E;NT@(B5S(BP@<')O=&^^92!J96AO('9E
M;&EK;W-T('#X97/A:&QA('!O=F]L96[](&QI;6ET+@!.96)Y;&$@;F%L97IE
M;F$@87!L:6MA8V4@<')O(.AT96[M('1O:&]T;R!T>7!U(&1A="`H)7,I+@!0
M;W5Z92!N82!P<F%VZ2!A(&QE=ND@<W1R86[L`%!O=7IE(&YA('!R87;I('-T
M<F%N[`!397)V97(@(B5S(B!B>6P@=GEM87KA;BX`4V5R=F5R("(E<R(@8GEL
M('5L;[YE;BX`0GEL82!O9'-T<F%N[&YA(+[A9&]S="!O('#X:6ALX;EE;NT@
M<')O("5S+@!0;[YA9&]V86[](/CA9&5K(&YE97AI<W1U:F4N`$1OZ&%S;OT@
M<V]U8F]R("(E<R(@;F5E>&ES='5J92X`4&]U>F4@;F%H;_AE(&$@9&]L90!0
M;W5Z92!N86AO^&4`6G1R871I;&$@<V4@</AE;F5S96[A(&1A=&$@>B!P^&5D
M8VAO>NUH;R!K<F]K=2X`4/AE;F5S96[]('-O=6)O<B!N96QZ92!U;&^^:70N
M`$)L;VL@=V5A=&AE<BYC;VT@;F5N[2!D;W-T=7!N_2X`KN%D;ND@>B!M;[YN
M;W-T[2!N96IS;W4@9&]S='5P;NDN`$YE8GEL>2!N86QE>F5N>2"^X61NZ2#H
MX7-T:2P@:W1E<ND@8GD@8GEL;R!M;[YN;R!Z;V)R87II="!V(/CA9&MU+@!0
M^.UL:;D@;6YO:&\@>FYA:_D@=B!P;VQI+B!:861A;&D@:G-T92`E<R!Z;F%K
M^3L@;75S[71E('IA9&%T(&WI;NP@;F6^("5S('IN86OY+@!.87-T86QA(&-H
M>6)A('#X:2!P^&5N;W-U('-O=6)O<G4Z("5S(&YE8GEL('#X96YE<V5N+@!.
M87-T86QA(&-H>6)A('#X:2!P^&5N;W-U('-O=6)O<G4N("5S(&YE;?F^92!B
M_70@=NQTN>T@;F6^(&UA>&EMX6QN[2!P;W9O;&5NX2!V96QI:V]S="`H)60@
M8GET^2DN`$YA<W1A;&$@8VAY8F$@</AI('#X96YO<W4@<V]U8F]R=3H@8GEL
M82!P^&5N97-E;F$@:F5N(.CA<W0@<V]U8F]R=2`E<RX`3F%S=&%L82!C:'EB
M82!P^&D@86MT:79A8VD@<VMR:7!T=2X`3F%S=&%L82!C:'EB82!P^&D@9&5A
M:W1I=F%C:2!S:W)I<'1U+@!$;[EL;R!K(&-H>6+L('#X:2!Z;V)R87IO=N%N
M[2!TZ71O(.CA<W1I('IP<N%V>0!.87-T86QA(&-H>6)A('#X:2!I;7!O<G1O
M=N%N[2!K;VYT86MT=2X`4/AI(&EM<&]R=&]VX6[M(&E#86QE;F1A<B!D870@
M9&^Y;&\@:R!C:'EB["X`0VAY8F$@=B!K;VYF:6=U<F'H;NUM(&9O<FUU;.'X
M:2X@6OAE:FWL(&IS=&4@=GEN96-H86QI('!OOF%D;W9A;ND@<&]L92X`3F%S
M=&%L82!C:'EB82!P^&D@<')O=N%D[&[M('IA9&%NZ2!O<&5R86-E('8@861R
M97/A^&DN(%!R;W/M;2!Z:W5S=&4@=&\@<&]Z9.QJ:2X`3F%S=&%L82!C:'EB
M82!P^&D@86MT=6%L:7IA8VD@:V]N=&%K='4N(%!R;W/M;2!Z:W5S=&4@=&\@
M<&]Z9.QJ:2X`3F%S=&%L82!C:'EB82!P^&D@86MT=6%L:7IA8VD@9&ES=')I
M8G7H;NUH;R!S97IN86UU+B!0<F]S[6T@>FMU<W1E('1O('!O>F3L:FDN`%1E
M;G1O($E-05`@<V5R=F5R(&YE<&]D<&]R=6IE('-D[6QE;NT@<VQOOF5K+@!4
M;W1O(&YE=GEP863A(&IA:V\@<&QA=&[](')A<B!A<F-H:78N`%1O=&\@;F5V
M>7!A9.$@:F%K;R!P;&%T;OT@>FEP('-O=6)O<BX`5&]T;R!N979Y<&%DX2!J
M86MO('!L871NZ2#H[7-L;R!K87)T>2X`5&5N=&\@;W9L861AZ"!U;6^^\G5J
M92!P;W/M;.%N[2!Z<'+A=B!P;VUO8^T@0VQI8VMA=&5L;"`H:'1T<#HO+V-L
M:6-K871E;&PN8V]M*2!B<N%N>2!P^&D@<&]UOFET[2!(5%10($%020!496YT
M;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP<N%V('!O;6]C[2!S;7,R
M96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!B<N%N>2!P^&D@<&]UOFET
M[2!(5%10($%020!496YT;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP
M<N%V('!O;6]C[2!33510(&1O(%9O9&%F;VYE($ET86QY(&)RX6YY('!O=7IE
M('!R;R#H[7-L82!P;W-K>71N=73I(%9O9&%F;VYE;2X@375S[71E(&WM="!E
M;6%I;&]V_2#ZZ&5T('4@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP
M+FET*2X`5&]T;R!P;VQE(&IE(&YU=&[I('9Y<&QN:70N`%1O=&\@<&]L92!M
M^;YE(&]B<V%H;W9A="!P;W5Z92!C96SA(.CM<VQA+@!4;W1O('!O;&4@;?F^
M92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L82!A(&1V;VIT9>AK=2X`5&]T
M;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&]S;6GH:V]VZ2#H[7-L82X`
M5&]T;R!P;VQE(&UU<^T@8OUT('-E>FYA;2!C96S]8V@@Z.US96P@;V1D[&QE
M;OUC:"#HX7)K;W4@;F5B;R!M97IE<F]U`%1O=&\@<&]L92!M=7/M(&+]="!P
M;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M=7/M('!B<V%H;W9A="!B87)E=F[]
M(&OS9"!V(+EE<W1NX6-K;W;I;2!21T(@9F]R;>%T=2P@;F%P^"X@)R,Q,C,T
M868G+@!496YT;R!F;W)M=6SA^"!J:;X@8GEL('IP<F%C;W;A;BX`5&]T;R!J
M92`E<RX`5&]T;R!J92!O8FIE:W0@2V]L86(@1W)O=7!W87)U+B!+('IH;.ED
M;G5T[2!T;VAO=&\@;V)J96MT=2!J92!Z87!O=/AE8NT@;>UT('!ON71O=F[M
M:&\@:VQI96YT82P@:W1E<OT@<F]Z=6WM(&9O<FWA='4@2V]L86(@1W)O=7!W
M87)U+B!0<F\@<V5Z;F%M('1A:V]V_6-H(&ML:65N=/D@<')O<^UM(&YA=KET
M:79T92`E<P!4871O('IP<N%V82!B>6QA(&YA<'/A;F$@=B!J:6[I('IN86MO
M=ND@<V%D["`H)7,I(&YEOB!68;GM+B``5&]T;R#H[7-L;R!M=7/M(&+]="!N
M96IMZ6[L(&IE9&YA+@!397)V97(@;F5M^;YE(')O>F)A;&ET('II<"!A(&=Z
M:7`@<V]U8F]R>2X`5&5N=&\@<WES=.EM(&IE('8@<V]UZ&%S;F]S=&D@9&5A
M:W1I=F]V86[]+@!4871O(&AO9&YO=&$@;75S[2!B_70@Z.US;&\N`%1O=&\@
M;VMN;R!M=;YE(&+]="!V;VSA;F\@<&]U>F4@>B!O:VYA(&UOOFYO<W3M`$CX
M;>QN[0!,[7-T:WD`R&%S`%-L961O=N%N[2#H87-U`$9O<FWA="#H87-U`%;]
M8NQR(.AA<W4`5&EM;W(M3&5S=&4`5&ET=6P`5&ET=6P@*'1I<"DZ`$MO;74`
M4&]K=60@<VD@</AE:F5T92!V>6)R870@=NUC92!P;VQOOF5K+"!Z;>'H:V[L
M=&4@:VSA=F5S=2!#;VYT<F]L("A00RD@;F5B;R!#;VUM86YD("A-86,I(&$@
M:VQI:V[L=&4@;F$@<&]L;[YK=2X`1&YE<P!0^&5P;F]U="!N82!(5$U,('ID
M<F]J`%1O9V\`5&]K96QA=0!:[71R80!4;VYG80!6<F-H`$AO<F[M('+A;2`H
M7W1O<"D`4/AE:VQA9'D`5')I;FED860@82!4;V)A9V\`4W!RX79N["!N96)O
M(+EP871N[`#:=`!4=6YI<VMO`%1U<F5C:V\`5'5R96-K>2`H25-/+3@X-3DM
M.2D`5'5R:VUE;FES=.%N`%1U<FMS(&$@0V%I8V]S(&]S=')O=GD`5'5V86QU
M`$YA<&FY=&4@5F&Y:2!V;VQB=3H`52Y6+B!I;F1E>#H@`%523`!54DP@<')O
M('IP<N%V=2!O('-T879U('IA<VQA;NEH;R!S:W)I<'1U`%523#H`56=A;F1A
M`%5K<F%J:6YA`%9&4R!A9')E<^'X(&IE(&YE</CM<W1U<&[]+@!0^&D@<F5G
M:7-T<F%C:2!N96QZ92!P^&ED870@97AT<F$@=;YI=F%T96QS:^D@^F1A:F4N
M`$YE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O<B`B)7,B+@!.96QZ
M92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@)7,O)7,N`$YE;'IE('IM
M[&YI="!N82`E<RX`3F5L>F4@<V4@</AI<&]J:70@:R!344P@<V5R=F5R=2X`
M3F5L>F4@<V4@</AI<&]J:70@<&]M;V/M(%-33"X`3F5L>F4@:V]P[7)O=F%T
M(%9&4R!S;W5B;W(N`$YE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X("(E<R(N
M`$YE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X+@!.96QZ92!V>71V;_AI="!6
M1E,@<V]U8F]R+@!.96QZ92!V>71V;_AI="!P<N%Z9&[](%9&4R!S;W5B;W(N
M`$YE;'IE(')O>F)A;&ET(&1A=&$N`$YE;'IE('9Y;6%Z870@(B5S(BP@<')O
M=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2X`3F5L>F4@=GEM87IA="`E<RP@
M<')O=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2X`3F5L>F4@<F5K=7)Z:7;L
M(&]D<W1R86YI="!61E,@861R97/A^"X`3F5L>F4@=GEM87IA="!61E,@861R
M97/A^"X`3F5L>F4@=GEM87IA="!61E,@861R97/A^#H@)7,N`$YE;'IE('9Y
M;6%Z870@5D93('-O=6)O<B`B)7,B+@!.96QZ92!V>6UA>F%T(%9&4R!S;W5B
M;W(N`$YE;'IE(')E:W5R>FEV;NP@;V1S=')A;FET(%9&4SH@)7,N`$YE;'IE
M('5RZ&ET(&%K='7A;&[M(&%D<F5SX?@N`$YE;'IE('IJ:7-T:70@<&]D<F]B
M;F]S=&D@;R!C97)T:69I:^%T=2X`3F5L>F4@9&]SX6AN;W5T(&1E9FEN:6-I
M('!R;R`E<RX`3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(N`$YE;'IE('#X
M97-U;F]U="!61E,@<V]U8F]R("(E<R(N`%9&4R!S;W5B;W(@;F5L>F4@;W1E
M=OCM="!P<F\@>N%P:7,N`$YE;'IE(&]T97;X[70@5D93('-O=6)O<BX`3F5L
M>F4@;W1E=OCM="!A<F-H:79O=F%N_2!S;W5B;W(N`$YE;'IE(.CM<W0@>B!V
M9G-R;V]T(&%D<F5SX?AE+@!.96QZ92!P^&5J;65N;W9A="`E<R!N82`E<SH@
M8^UL;W;A('-L;[YK82!J:;X@97AI<W1U:F4`5D93(&%D<F5SX?@@;F5L>F4@
M</AE:FUE;F]V870N`%9&4R!A9')E<^'X(&YE;'IE('#X96IM96YO=F%T.B`E
M<RX`3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<B`B)7,B+@!.96QZ92!P
M^&5J;65N;W9A="!61E,@<V]U8F]R("5S+R5S+@!.96QZ92!P^&5J;65N;W9A
M="!61E,@<V]U8F]R+@!.96QZ92!P<F]VZ7-T("=M:VES;V9S)RX`5&5N=&\@
M9&]K=6UE;G0@5V]R9"!N96QZ92!P^&5L;[YI=`!.96QZ92!Z87!S870@9&\@
M5D93('-O=6)O<G4@(B5S(BX`3F5L>F4@>F%P<V%T(&1A=&$@9&\@5D93('-O
M=6)O<G4@*'-E;&AA;&\@8V]P>2@I*2X`3F5L>F4@>F%P<V%T(&1A=&$@9&\@
M5D93('-O=6)O<G4`4&]D=')H;G5TZ0!3=&]R;F\@>FWL;@!3=&]R;F]V870@
M<&]S;&5N[2!A:V-I`$YE;^AE:^%V86[A(&]D<&]V[.\@<V5R=F5R=2!N82!S
M<&]J96[M.B``3F5OZ&5KX79A;N$@;V1P;W;L[R!S97)V97)U.B``3F5V>7!L
M;NQN;P!5;FEC;V1E("A55$8M."D`4W!O:F5NZ2!!<F%B<VOI($5M:7+A='D`
M5F5L:^$@0G)I=.%N:64`4W!O:F5NZ2!3=.%T>2!!;65R:6-KZ0!3<&]J96[I
M(%-TX71Y($UE;KEI;F]V_6-H(&]S=')O=OD`2F5D;F]T:WD`3F5Z;N%MZ0!.
M97INX6WI(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`$YE>F[A;>D@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`3F5Z;N%MZ2!UOFEV871E;'-K
MZ2!J;>EN;R!N96)O(&AE<VQO+@!/9'!O:FET('-O=>AA<V[]('!R=F5K`$)E
M>F4@:FWI;F$`3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M;VAO=2!V>76^
M[79A="!F=6YK8V$@5GEJ;6]U="]+;W#M<F]V870O5FQOOB!Z(&)E>G!EZ&YO
M<W1N[6-H(&3Y=F]D^2X@2VQI:V[L=&4@;F$@3TL@86)Y<W1E('9I9.QL:2!T
M96-H;FEC:V]U('IP<N%V=2!Z(&UO>FEL;&$N;W)G+"!K=&5RX2!V>7-V['1L
M=6IE+"!J86L@;F%S=&%V:70@<VMR:7!T('!R;R!P^.US='5P(&ME('-C:'+A
M;F-E+@!.96YA<W1A=F5NX2!B87)V80!.97!O9'!O<F]V86[A('#X[7!O;F$`
M06MT=6%L:7IO=F%T`$%K='5A;&EZ;W9A="`E<P!!:W1U86QI>F]V870@=;YI
M=F%T96QE`%-K<FEP="!P<F\@86MT=6%L:7IA8VD@8GEL('9Y;6%ZX6XN`%#X
M96YO<P!6N65C:&YY('-O=6)O<GD@<')O(&YA<W1A=F5N[2!A<&QI:V%C[2!B
M>6QY('#X96YE<V5N>2!N82!S97)V97(N`%9E;&OA('1I<VMA8^T@<.US;65N
M80!696QKZ2#X[6US:^D@Z.US;&EC90!5<G5G=6%Y`%!O=;[M="!A:W1UX6QN
M[3H@)7,`4&]UONUT(%-33`!0;W6^[70@<&]K=60@:FWI;F\O:&5S;&\@:G-O
M=2!J:6[I(&YEOB!P<F\@24U34"!S97)V97(N`%6^:79A=&5L("5S(&YE;NT@
M;W!RX79N[&X@:R!P;W6^[7;A;NT@)7,N`$%D;6EN:7-T<F%C92!UOFEV871E
M;/D`5;YI=F%T96QS:^D@;6^^;F]S=&D`4F5G:7-T<F%C92!UOFEV871E;/D`
M3F$@=&]M=&\@<V5R=F5R=2!N96[M(&UOOF[A(')E9VES=')A8V4@=;YI=F%T
M96SY+@!5OFEV871E;'-KZ2!J;>EN;P!5OFEV871E;'-KZ2!J;>EN;SH`5;YI
M=F%T96QS:^D@:FWI;F\Z(`!397IN86T@=;YI=F%T96SY.@!5>F)E:VES=.%N
M`%9&4R!A9')E<^'X(&YE97AI<W1U:F4N`$1O=F]L96[A`%5P<F%V:70@1&]V
M;VQE;F]U`%IP<N%V82!O($1O=F]L96[I`$YE;'IE('!O=;[M="!$;W9O;&5N
M;W4@<V4@<V]UZ&%S;OUM(&1R:79E<F5M('!R;R!F:6QT<F%C:2X`3F%L97IE
M;N$@<&QA=&[A(&WM<W1A('IA:')N=6KM.B``4&QA=&YO<W0`2&]D;F]T82!V
M(&UI;G5TX6-H+@!(;V1N;W1Y`%9Y8G)A;ND@:&]D;F]T>2!Z`%9A;G5A='4`
M4')O;>QN;ND`5F5N97IU96QA`%-E;&AA;&$@=F5R:69I:V%C92`M('1A=&\@
M>G!RX79A(&UO:&QA(&+]="!Z9F%LN6]VX6YA+@!697)Z90!697)S:6]N($-O
M;G1R;VP`5F5R=&EKX6QN[2!Z87)O=F[A;NT`5F5R=&EKX6QN[2!O9'-T=7``
M5F5R=&EKX6QN[3H`5F5L;6D@=GES;VOA`%9I971N86T`5FEE=&YA;7-K>2`H
M5DE30TE)*0!:;V)R87II="`E<P!:;V)R87II="!E>'1E<F[M('=E8G-T<N%N
M:W4`6F]B<F%Z:70@:F%K;R`E<P!086YN96YS:^D@3W-T<F]V>2P@0G)I='-K
MZ0!086YN96YS:^D@3W-T<F]V>2P@52Y3+@!6:61I=&5L;F]S=`!6:61I=&5L
M;F]S=#H`5F]D869O;F4@271A;'D@</AE<R!33510`%503UI/4DY)5`!54$]:
M3U).S$[-(2$A($]$4U120=)412!32U))4%0@4E7(3LP@6B`E<RX`5V%L;&ES
M(&%N9"!&=71U;F$`57!O>F]R;NQN[0!3=`!0^&5D<&]V[.\@<&_H87/M`$1A
M=&$@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H97(N8V]M`%=E8@!796(@<V5R
M=F5R`%3]9&[L`%;M=&5J=&4`5NUT96IT92!V("5S`%;M=&5J=&4L("5S`%KA
M<&%D;NT@*$E33RTX.#4Y+3$I`%KA<&%D;NT@*$E33RTX.#4Y+3$U*0!:X7!A
M9&[M(%-A:&%R80!"[5]LZ2!A9')E<WDZ`$MT97)O=2!A<&QI:V%C:2!MX2`E
M<R!Z;V)R87II="!P;R!P^&EH;.&Y96[M(&1O('-Y<W3I;74_`$IA:_T@:F4@
M;V1D[&QO=F%C[2!Z;F%K/P!*86O](&IE('IN86L@<')O(&-I=&%C:3\`2W1E
M<ND@9N%Z90!6;VQB82!R;WJY[?AE;NT@<')O(%)I8V@@5&5X="!E9&ET;W(N
M`$+M;.$@;&ES=&EN80!5<')A=FET($+M;&]U(&QI<W1I;G4`3F5L>F4@<&]U
MONUT($+M;&]U(&QI<W1I;G4@<V4@<V]UZ&%S;OUM(&1R:79E<F5M('!R;R!F
M:6QT<F%C:2X`061R97-Y(&YA($)I;.D@;&ES=&EN[`"I[?AK80"I[?AK82!V
M($-34R!J961N;W1KX6-H`*GM^&MA("5S(&UE;G4@=FQE=F\@*'IM[&YA('-E
M(&]B:F5V[2!P^&D@9&%LN>UM('#X:6ALX;EE;NTI.@"I[?AK82!T86)U;&MY
M`$IE9&YO=&MA(+GM^&MY`*GM^&MA.@!7:6MI`%;M='(`4F%N;NT@=NUT<@!2
M>6-H;&]S="!V['1R=2!V('5Z;&5C:`!6[71R.@!6[71R.B``36]U9')O<W0`
M4'+A8V4`061R97-A(&1O('IA;>QS=&[A;NT`5&5L969O;B!D;R!Z86WL<W1N
MX6[M`%@M4')I;W)I='D`6"U2968`6"U3<&%M+4QE=F5L`%@M4W!A;2U38V]R
M90!8+5-P86TM4W1A='5S`%@U,#EV,R!ZX6ML861N[2!O;65Z96[M`%@U,#EV
M,R!R;WJY[?AE;ND@<&]UOFET[2!K;.WH90!8-3`Y=C,@86QT97)N871I=F[M
M(&IMZ6YO(&]S;V)Y`%@U,#EV,R!I9&5N=&EF:6OA=&]R(&ML[>AE`%@U,#EV
M,R!R;WJY[?AE;NT`4E(`4E)24@!-87!A(%EA:&]O(0!2;^AN[`!*96UE;@!!
M;F\`06YO+"!S;W5H;&%S[6T`2G-T92!V(%1%6%1/5LE-($W31%4N(%!O=;YI
M:G1E(%L\/ET@=&QAZ.UT:V$@:R!Z<.QT;NEM=2!P^&5P;G5T[2!D;R!765-)
M5UE'+@!.96)Y;&D@:G-T92!S<'+A=F[L(&]V[/AE;FDN`%IN86L@)UPG(&YE
M;?F^92!B_70@<V]UZ.%S=.T@5F&Y96AO(&IMZ6YA+@!">6QA('IA9.%N82!N
M97!L871NX2!E+6UA:6QO=N$@861R97-A+@!.96UA<&]V86QI(&IS=&4@ON%D
M;N$@<&]L92!Z(&EM<&]R=&]V86[I:&\@<V]U8F]R=2!K(&]D<&]V[61A:NUC
M[6T@<&]L[6T@=B`E<RX`0GEL:2!J<W1E(&]D:&SAN65N:2!Z92!S>7-TZ6UU
M+@!6;&^^=&4@Z.US;&\@;6]B:6QN[6AO('1E;&5F;VYU+"!P;W6^:6IT92!J
M96X@Z.US;&EC(&YE8F\@</CM<&%D;NP@)RLG('!R;R!M97II;N%R;V1N[2#H
M:7-L82X`375S[71E('IA9&%T('!L871N;W4@:&]D;F]T=2X`375S[71E(&MO
M;F9I9W5R;W9A="!D871A8N%Z:2!D870L('!O:W5D('-I('#X96IE=&4@<&]U
MONUV870@4F5G:7-T<F%C92X`375S[71E(&MO;F9I9W5R;W9A="!61E,@8F%C
M:V5N9"X`375S[71E(&YE:F3X[79E('!O<'-A="!P<F]B;.EM(&$@<&]TZ2!H
M;R!O9&5S;&%T+@!-=7/M=&4@>F%D870@55),(&YA(&MT97+I(&)U9&4@=&5N
M=&\@;V1K87H@=6MA>F]V870`375S[71E('9Y8G)A="!S97)V97(L(&MT97+]
M(&)U9&4@<VUA>N%N+@!-=7/M=&4@=GEB<F%T('6^:79A=&5L<VOI(&IMZ6YO
M+"!K=&5RZ2!B=61E('-M87KA;F\N`$UU<^UT92!Z861A="!UOFEV871E;'-K
MZ2!J;>EN;RP@:W1E<ND@8G5D92!O9'-T<F%N[&YO+@!-=7/M(&+]="!U=F5D
M96YA(&YE:FWI;NP@:F5D;F$@861R97-A('!R;R!P;W6^:73M($1O=F]L96[I
M`$YE=79E9&QI(&IS=&4@=;YI=F%T96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@
M</AI9.%N;RX`3F5U=F5D;&D@:G-T92!UOFEV871E;'-KZ2!J;>EN;R!P<F\@
M86MT=6%L:7IA8VDN`$UU<^UT92!Z861A="!A:V-I+"!K=&5RX2!B=61E('!R
M;W9E9&5N82X`375S[71E('IA9&%T(&IMZ6YO(&YO=ND@:V%T96=O<FEE+@!6
M8;EE("5S(')E;&%C92!B>6QA('5K;V[H96YA+B!/<.QT('-E('#X:6AL8;ET
M92P@<')O<^UM+@!68;EE(&5M86EL;W;A(&%D<F5S80!68;EE($]D+6MO:&\Z
M(&%D<F5S83H`5F&Y92!I;F9O<FUA8V4`5B!R96QA8VD@)7,@<V4@>FWL;FEL
M82!68;EE(&EN=&5R;F5T;W;A(&%D<F5S82X@6B!B97IP9>AN;W-T;NUC:"!D
M^79O9/D@<V4@;75S[71E(&]P['0@</AI:&SA<VET+@!68;EE(&IMZ6YO`%;A
MN2!O=NSX;W9A8^T@<WES=.EM(&YE<&]D<&]R=6IE(';]<&ES('6^:79A=&5L
M^2!A;F5B;R!T871O(&UOOFYO<W0@;F5N[2!P^.US='5P;N$@>B!J:6[]8V@@
M9/EV;V3Y+@!:9.$@<V4L(+YE('8@<'+Y8NQH=2!R96QA8V4@)7,@<V4@>FWL
M;FEL(%;AN2!P<F]H;.V^9>@N(%H@8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y('-E
M(&UU<^UT92!O<.QT('#X:6ALX7-I="X`5N&Y('!R;VAL[;YEZ"!N97!O9'!O
M<G5J92!T=71O(&UOOFYO<W0N`%9AN64@<V]UZ&%S;ND@Z&%S;W;I('#A<VUO
M.@!68;EE(&EM<&QI8VET;NT@:61E;G1I=&$`5F&Y92#Z<&QNZ2!J;>EN;SH`
M5F&Y92!N;W;I(&AE<VQO('!R;R`E<R!J93H@)7,`5F&Y92!N87-T879E;NT@
M8GEL;R!A:W1U86QI>F]VX6YO('!R;R!T<G;A;NT@=.ET;R!R96QA8V4N`%9A
MN64@;F%S=&%V96[M(&)Y;&\@86MT=6%L:7IO=N%N;RX`5F&Y92!H97-L;R!B
M>6QO(')E<V5T;W;A;F\N`%9AN64@:&5S;&\@8GEL;R!R97-E=&]VX6YO+"!Z
M:V]N=')O;'5J=&4@<VD@>G!RX79Y(&5L96MT<F]N:6-KZ2!P;[ET>2!A('#X
M:6AL8;ET92!S92!S(%9AN>UM(&YO=OUM(&AE<VQE;2X`5F&Y92!V>F3A;&5N
MZ2!S97)V97)Y.@!*=6=O<VSA=FEE`%IA:7(`6F%M8FEE`%II;6)A8G9E`%II
M<'!Y`%M5:W+]="!C:71O=F%N_2!T97AT70!;KN%D;OT@4/AE9&WL=%T`6TAL
MX;EE;NT@<')O8FSI;75=`%M:;V)R87II="!C:71O=F%N_2!T97AT("T`6UIO
M8G)A>FET(&-I=&]V86[]('1E>'0@+2`E<R#XX61K^5T`6_CA9&5K("5S('H@
M)7-=`%]!9')E<V$H>2D@<')O('#X97!O<VSA;NTZ`%]!9')E<WD@:W1E<N%M
M(&YE8G5D92!Z87-LX6YA(&]D<&]V[.\Z`%]!9&UI;FES=')A8V4`7\AE<F[A
M($QI<W1I;F$`7T-,20!?1&%T851R964`7U-M87IA="#XX61E:P!?VG!L;ND@
M4VUA>N%N[2!:<'+A=GD`7U9L;[YI="!K8;YD;W4@861R97-U(&YA(&YO=OT@
M^.%D96LZ`%]0^&5P;W-L870`7U-K=7!I;GD`7T[A<&]V[&1A`%]6;&%S=&YO
M<W1I(&]B<N%Z:W4N+BX`7U!O;F5C:&%T(&MO<&EI('IP<N%V>2!N82!T;VUT
M;R#ZZ'1U/P!?4/AI:&SAN65N[0!?3V1H;.&Y96[M`%]-;V1I9FEK;W9A="!O
M9&MA>BXN+@!?4/AE<W5N;W5T('IP<N%V=2!D;R!S;&^^:WDZ`%]-;VIE(&5M
M86EL;W;I(&%D<F5S>3H`7TUOOFYO<W1I`%]0<N%V80!?3V1S=')A;FET(&]D
M:V%Z+BXN`%]3:W)I<'0`7TYA<W1A=F5N[0!?5FQA<W1N;W-T:2!T86)U;&MY
M+BXN`%]5OFEV871E;.D`7T1O=F]L96[A`%]"[6SA(&QI<W1I;F$`861R97/A
M^`!A.@!K86QE;F3A^`!B97IV['3X[0!K;&EK;F]U="!Z9&4`<W+AOFMY`'!O
M;&4`<V]U8F]R`'H@)7,@*"5S*2!R>6-H;&]S=.T@)7,@)7,`:#H`;VMA;;YI
M=.P`=B#X863L`/CA9&OY70!S:&]D80!C:'EB;W;](&OS9"!M:VES;V9S("5D
M('#X:2!V>71VX?AE;NT@25-/+@!J;>EN;P!N96[M(&EM<&QE;65N=&]VX6YO
M`&YE;NT@9&]S=60@:6UP;&5M96YT;W;A;F\`>N%P:7-N[6L`;F5B;P!P<F]C
M96YT`'!I>&5L^0!P<F]C;6%I;"!S:W)I<'0@9V5N97)O=F%N_2!);F=E;0!S
M=&]U<&%J[6/M`'IO8G)A>FET(')O>F3M;'D`<VEE=F4@9FEL=&5R(&=E;F5R
M;W9A;OT@26YG96T`<VUS,F5M86EL('IA('!O=;YI=.T@2%144`!V>71R=F%L
MZ0!S97IN86T@^FMO;/D`<')O('!O='9R>F5N[2!N87!IN71E(&AE<VQO(&1V
M86MRX70`<VIE9&YO8V5N_0!B97H@;N%Z=G4`=GEB<F%T('6^:79A=&5L90!V
M0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE
M+V5N7U53+P``````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-#<`,#$W-C,S`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6YG;R]L;V-A;&4O96Y?55,O:&5L<"YX;6P`````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`S,#0Q,0`Q,#0Q-S,V,C<T-P`P,C$S,#$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!I;F=O+VQO8V%L92]E
M;E]54R]H96QP+GAM;"QV(#$N.2XT+C(@,C`P-2\Q,"\Q-R`R,SHS.3HP-2!J
M86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB8FQA8VML:7-T(CX*
M("`@(#QT:71L93Y";&%C:VQI<W0\+W1I=&QE/@H@("`@/'!A<F$^5&AE(&)L
M86-K;&ES="!I<R!A(&QI<W0@;V8@96UA:6P@861D<F5S<V5S(&MN;W=N('1O
M('-E;F0@96UA:6P@=&AA=`H@("`@>6]U(&1O(&YO="!W:7-H('1O('-E92!I
M;B!Y;W5R($E.0D]8+CPO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M8FQA8VML:7-T+6%C=&EO;B(^"B`@("`\=&ET;&4^0FQA8VML:7-T.B!!8W1I
M;VX\+W1I=&QE/@H@("`@/'!A<F$^5&AI<R!A8W1I;VX@9&5F:6YE<R!W:&%T
M('1O(&1O('=H96X@82!M97-S86=E(&9R;VT@82!B;&]C:V5D('-E;F1E<@H@
M("`@:7,@<V5N="!T;R!Y;W4N(%1H92!P;W-S:6)L92!V86QU97,@87)E(")D
M96QE=&4B(&]R(")M;W9E('1O(&9O;&1E<B(N($EF"B`@("`B9&5L971E(B!I
M<R!S96QE8W1E9"P@=&AE(&UE<W-A9V5S('=I;&P@8F4@9&ES8V%R9&5D(&)E
M9F]R92!E=F5R(&)E:6YG"B`@("!S=&]R960@:6X@>6]U<B!);F)O>"X@268@
M(FUO=F4@=&\@9F]L9&5R(B!I<R!S96QE8W1E9"P@=&AE>2!W:6QL(&)E"B`@
M("!D96QI=F5R960@=&\@=&AE('-E;&5C=&5D(&9O;&1E<BX\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](F)L86-K;&ES="UA9&1R97-S97,B/@H@
M("`@/'1I=&QE/D)L86-K;&ES=#H@061D<F5S<V5S/"]T:71L93X*("`@(#QP
M87)A/E1H92!L:7-T(&]F(&%D9')E<W-E<R!T;R!B;&]C:RX@16%C:"!A9&1R
M97-S('-H;W5L9"!B92!E;G1E<F5D(&]N(&$*("`@('-E<&%R871E(&QI;F4N
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97)S7W)U;&5S
M(CX*("`@(#QT:71L93Y2=6QE<SH@1FEL=&5R(%)U;&5S/"]T:71L93X*("`@
M(#QP87)A/E1H:7,@:7,@=&AE(&UA:6X@<G5L97,@<V-R965N+B!&<F]M(&AE
M<F4@>6]U(&-A;B!C<F5A=&4@;F5W(')U;&5S(&)Y"B`@("!C;&EC:VEN9R!O
M;B!T:&4@(DYE=R!2=6QE(B!B=71T;VX[(')E87)R86YG92!T:&4@<G5L92!O
M<F1E<B!B>2!C;&EC:VEN9R!O;@H@("`@=&AE('5P(&%N9"!D;W=N(&%R<F]W
M<R!O<B!E;G1E<FEN9R!N97<@<G5L92!P;W-I=&EO;G,@:6X@=&AE(")-;W9E
M(B!C;VQU;6X["B`@("!E;F%B;&4@86YD(&1I<V%B;&4@<W!E8VEF:6,@<G5L
M97,@8GD@8VQI8VMI;F<@;VX@=&AE(&EC;VX@:6X@=&AE(")%;F%B;&5D(@H@
M("`@8V]L=6UN.R!A;F0@961I="!I;F1I=FED=6%L(')U;&5S(&)Y(&-L:6-K
M:6YG(&]N('1H92!I8V]N(&EN('1H92`B161I="(*("`@(&-O;'5M;B!O<B!O
M;B!T:&4@<G5L92!N86UE+CPO<&%R83X*("`@(#QP87)A/@H@("`@("`\=&EP
M/E!L96%S92!N;W1E+"!T:&%T('1H92!R=6QE<R!A<F4@97AE8W5T960@:6X@
M=&AE(&]R9&5R(&1I<W!L87EE9`H@("`@("!H97)E+B!&;W(@97AA;7!L92P@
M:68@86X@96UA:6P@:7,@9&5L971E9"!B>2!T:&4@8FQA8VML:7-T+"!T:&4@
M9F]L;&]W:6YG"B`@("`@(')U;&5S('=I;&P@;F]T(&AA=F4@86YY(&EN9FQU
M96YC92!O;B!T:&ES(&5M86EL+CPO=&EP/@H@("`@/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F;W)W87)D(CX*("`@(#QT:71L93Y&;W)W87)D
M/"]T:71L93X*("`@(#QP87)A/EEO=2!M87D@8VAO;W-E('1O(&%U=&]M871I
M8V%L;'D@9F]R=V%R9"!Y;W5R(&EN8V]M:6YG(&UA:6P@=&\@80H@("`@;G5M
M8F5R(&]F(&]T:&5R(&UA:6P@861D<F5S<V5S+CPO<&%R83X*("`\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9F]R=V%R9"UA9&1R97-S97,B/@H@("`@/'1I=&QE
M/D9O<G=A<F0Z($%D9')E<W-E<SPO=&ET;&4^"B`@("`\<&%R83Y9;W4@;6%Y
M(&-H;V]S92!T;R!H879E('EO=7(@:6YC;VUI;F<@;6%I;"!R961I<F5C=&5D
M('1O(&%N;W1H97(*("`@(&%C8V]U;G0N(%EO=2!M87D@96YT97(@87,@;6%N
M>2!A9&1R97-S97,@87,@>6]U(&QI:V4N($5N=&5R(&5A8V@@861D<F5S<R!O
M;@H@("`@82!N97<@;&EN92X\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](F9O<G=A<F0M:V5E<&-O<'DB/@H@("`@/'1I=&QE/D9O<G=A<F0Z($ME
M97`@0V]P>3PO=&ET;&4^"B`@("`\<&%R83Y)9B!Y;W4@<V5L96-T('1H:7,@
M;W!T:6]N+"!A(&-O<'D@;V8@>6]U<B!I;F-O;6EN9R!M97-S86=E<R!W:6QL
M(&)E"B`@("!S879E9"!I;B!T:&ES(&%C8V]U;G0@87,@=V5L;"!A<R!B96EN
M9R!S96YT('1O('1H92!A9&1R97-S97,@=&\@=VAI8V@@>6]U"B`@("!H879E
M('EO=7(@;6%I;"!F;W)W87)D960N/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F+7-H;W=?9FEL=&5R7VUS9R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC93H@4VAO=R!D971A:6QE9"!F:6QT97(@<W1A='5S(&UE<W-A9V5S
M/SPO=&ET;&4^"B`@("`\<&%R83Y)9B!U<VEN9R!T:&4@24U!4"!F:6QT97)I
M;F<@9')I=F5R+"!T:&ES('!R969E<F5N8V4@8V]N=')O;',@:&]W"B`@("!V
M97)B;W-E('1H92!F:6QT97)I;F<@<')O8V5S<R!I<RX@268@<V5T('1O('EE
M<RP@979E<GD@;65S<V%G92!F:6QT97)E9`H@("`@=VEL;"!R97-U;'0@:6X@
M82!S97!A<F%T92!N;W1I9FEC871I;VX@;65S<V%G92!O=71P=70@=&\@=&AE
M('-C<F5E;@H@("`@:6UM961I871E;'D@869T97(@=&AE(&UE<W-A9V4@:7,@
M<')O8V5S<V5D+B!)9B!S970@=&\@;F\L(&]N;'D@82!S=6UM87)Y(&]F"B`@
M("!F:6QT97(@86-T:6]N<R!W:6QL(&)E(&]U='!U="!T;R!T:&4@<V-R965N
M+CPO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9BUF:6QT97)?
M<V5E;B(^"B`@("`\=&ET;&4^4')E9F5R96YC93H@1FEL=&5R(&]N;'D@6W5N
M77-E96X@;65S<V%G97,_/"]T:71L93X*("`@(#QP87)A/E1H:7,@<')E9F5R
M96YC92!I9&5N=&EF:65S('=H96X@=&AE($E-05`@9FEL=&5R:6YG(&1R:79E
M<B!W:6QL"B`@("!A='1E;7!T('1O(&%P<&QY(')U;&5S('1O('1H92!)3D)/
M6"X@66]U(&-A;B!E:71H97(@87!P;'D@9FEL=&5R<R!T;R!A;&P*("`@(&UE
M<W-A9V5S+"!A<'!L>2!F:6QT97)S($].3%D@=&\@;65S<V%G97,@=&AA="!A
M<F4@;6%R:V5D('5N<V5E;BP@;W(@87!P;'D*("`@(&9I;'1E<G,@3TY,62!T
M;R!M97-S86=E('1H870@:&%V92!B965N(&UA<FME9"!S965N+CPO<&%R83X*
M("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<G5L92(^"B`@("`\=&ET;&4^1FEL
M=&5R(%)U;&4\+W1I=&QE/@H@("`@/'!A<F$^02!R=6QE(&ES('1H92!B87-I
M8R!B=6EL9&EN9R!B;&]C:R!O9B!Y;W5R(&UA:6P@9FEL=&5R<RP@:70@8V]N
M<VES=',*("`@(&]F(&]N92!O<B!M;W)E(&-O;F1I=&EO;G,@86YD(&]N92!O
M<B!M;W)E(&%C=&EO;G,N(%=H96X@82!M97-S86=E(&ES('-E;G0*("`@('1O
M('EO=2P@:70@:7,@<')O8V5S<V5D('1H<F]U9V@@=&AE(&-O;F1I=&EO;G,@
M;V8@>6]U<B!F:6QT97(@<G5L97,L(&EF('1H90H@("`@8V]N9&ET:6]N<R!T
M:&%T('EO=2!S<&5C:69Y(&%R92!M970L('1H96X@=&AE(&%C=&EO;G,@=&AA
M="!Y;W4@<W!E8VEF>2!W:6QL"B`@("!B92!P97)F;W)M960@;VX@=&AA="!M
M97-S86=E+B!&:6QT97)S(&-A;B!B92!V97)Y('5S969U;"!F;W(@875T;VUA
M=&EC86QL>0H@("`@9&5L971I;F<@=6YW86YT960@;6%I;"P@;W(@;6%K:6YG
M('EO=7(@;6%I;"!A8V-O=6YT(&UO<F4@;6%N86=A8FQE(&)Y"B`@("!S=&]R
M:6YG(')E;&%T960@;65S<V%G97,@:6YT;R!D:69F97)E;G0@9F]L9&5R<RX\
M+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G)U;&4M86-T:6]N(CX*
M("`@(#QT:71L93Y&:6QT97(@4G5L93H@06-T:6]N/"]T:71L93X*("`@(#QP
M87)A/E1H97-E(&%R92!T:&4@<&]S<VEB;&4@86-T:6]N<R!T;R!T86ME(&EF
M(&%N(&EN8V]M:6YG(&UE<W-A9V4@;6%T8VAE<PH@("`@=&AE('-P96-I9FEE
M9"!C;VYD:71I;VYS+B!.;W1E('1H870@86QL(&]F('1H97-E(&]P=&EO;G,@
M;6%Y(&YO="!B90H@("`@879A:6QA8FQE('1O('EO=2`M(&]N;'D@=&AE(&]P
M=&EO;G,@=&AA="!W;W)K('=I=&@@=&AE('5N9&5R;'EI;F<@9FEL=&5R:6YG
M"B`@("!S;V9T=V%R92!W:6QL(&)E('-H;W=N+CPO<&%R83X*("`@(#QH96%D
M:6YG/D1E;&EV97(@=&AI<R!M97-S86=E(&EN=&\@;7D@24Y"3U@\+VAE861I
M;F<^"B`@("`\<&%R83Y4:&4@;65S<V%G92!W:6QL(&)E('-A=F5D(&EN('EO
M=7(@24Y"3U@N(%1H:7,@:7,@=&AE(&1E9F%U;'0*("`@(&]P=&EO;BX\+W!A
M<F$^"B`@("`\:&5A9&EN9SY$96QI=F5R('1O('1H:7,@;6%I;&)O>#PO:&5A
M9&EN9SX*("`@(#QP87)A/E1H92!M97-S86=E('=I;&P@8F4@9&5L:79E<F5D
M('1O('1H92!S<&5C:69I960@9F]L9&5R+CPO<&%R83X*("`@(#QH96%D:6YG
M/D1I<V-A<F0@=&AI<R!M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE
M(&UE<W-A9V4@=VEL;"!B92!S:6QE;G1L>2!D96QE=&5D+B!.96ET:&5R('EO
M=2!N;W(@=&AE('-E;F1E<B!W:6QL"B`@("!R96-E:79E(&YO=&EF:6-A=&EO
M;B!T:&%T('1H:7,@:&%S(&AA<'!E;F5D+CPO<&%R83X*("`@(#QH96%D:6YG
M/E)E9&ER96-T('1H:7,@;65S<V%G92!T;SPO:&5A9&EN9SX*("`@(#QP87)A
M/E1H92!M97-S86=E('=I;&P@8F4@<V5N="!T;R!T:&4@96UA:6P@861D<F5S
M<R!T:&%T('EO=2!S<&5C:69Y+B!.;PH@("`@8V]P>2!O9B!T:&4@;65S<V%G
M92!W:6QL(')E;6%I;B!I;B!T:&ES(&%C8V]U;G0N/"]P87)A/@H@("`@/&AE
M861I;F<^1&5L:79E<B!T;R!M>2!)3D)/6"!A;F0@<F5D:7)E8W0@=&\\+VAE
M861I;F<^"B`@("`\<&%R83Y4:&4@;65S<V%G92!W:6QL(&)E('-E;G0@=&\@
M=&AE(&5M86EL(&%D9')E<W,@=&AA="!Y;W4@<W!E8VEF>2P@86YD(&$*("`@
M(&-O<'D@;V8@=&AE(&UE<W-A9V4@=VEL;"!R96UA:6X@:6X@>6]U<B!)3D)/
M6"X\+W!A<F$^"B`@("`\:&5A9&EN9SY296IE8W0@=&AI<R!M97-S86=E('=I
M=&@@<F5A<V]N/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE(&]R:6=I;F%L(&UE
M<W-A9V4@=VEL;"!B92!D:7-C87)D960L(&%N9"!A(&YE=R!M97-S86=E('=I
M;&P@8F4*("`@('-E;G0@=&\@=&AE('-E;F1E<B!W:71H('1H92!T97AT('1H
M870@>6]U('-P96-I9GDN/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)R=6QE+6-O;6)I;F4B/@H@("`@/'1I=&QE/D9I;'1E<B!2=6QE.B!#;VUB
M:6YE($]P=&EO;G,\+W1I=&QE/@H@("`@/'!A<F$^66]U(&UA>2!D969I;F4@
M;75L=&EP;&4@8V]N9&ET:6]N<R!W:71H:6X@82!S:6YG;&4@<G5L92X@66]U
M(&UA>0H@("`@9W)O=7`@=&AE;2!T;V=E=&AE<B!L;V=I8V%L;'D@=7-I;F<@
M(F%N9"(O(F]R(BX@66]U(&UA>2!N;W0@8W)E871E(&-O;7!L97@*("`@(&9I
M;'1E<G,@8V]N=&%I;F<@8F]T:"!T>7!E<R!O9B!C;VYD:71I;VYS+CPO<&%R
M83X*("`@(#QH96%D:6YG/D%N9#PO:&5A9&EN9SX*("`@(#QP87)A/DEF('EO
M=2!S96QE8W0@04Y$+"!A;B!I;F-O;6EN9R!M97-S86=E(&UU<W0@;6%T8V@@
M979E<GD@8V]N9&ET:6]N"B`@("!T:&%T('EO=2!S<&5C:69Y(&EN(&]R9&5R
M(&9O<B!T:&4@86-T:6]N<R!T;R!B92!E>&5C=71E9"X\+W!A<F$^"B`@("`\
M:&5A9&EN9SY/<CPO:&5A9&EN9SX*("`@(#QP87)A/DEF('EO=2!S96QE8W0@
M3U(L('1H92!S<&5C:69I960@86-T:6]N<R!W:6QL(&)E(&5X96-U=&5D(&EF
M(&%T(&QE87-T"B`@("!O;F4@;V8@=&AE(&-O;F1I=&EO;G,@:7,@;65T+CPO
M<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<G5L92UM87)K(CX*("`@
M(#QT:71L93Y&:6QT97(@4G5L93H@36%R:R!-97-S86=E/"]T:71L93X*("`@
M(#QP87)A/EEO=2!M87D@<W!E8VEF>2!M87)K:6YG(&$@;65S<V%G92!W:71H
M(&]N92!O<B!M;W)E($E-05`@9FQA9W,@87,@;VYE"B`@("!O9B!T:&4@86-T
M:6]N<R!I;B!A(')U;&4N(%1H92!P;W-S:6)L92!V86QU97,@87)E(%-E96XL
M($EM<&]R=&%N="P*("`@($%N<W=E<F5D+"!A;F0@1&5L971E9"X\+W!A<F$^
M"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G)U;&4M;6%T8VAE<R(^"B`@("`\
M=&ET;&4^1FEL=&5R(%)U;&4Z($UA=&-H97,\+W1I=&QE/@H@("`@/'!A<F$^
M5&AE<F4@87)E(#,@8V]M<&]N96YT<R!T;R!E86-H(&-O;F1I=&EO;B!I;B!A
M(')U;&4N(%1H92!F:7)S="!I<R!T:&4*("`@(&9I96QD('1O(&5X86UI;F4N
M(%1H92!S96-O;F0@:7,@=&AE('1Y<&4@;V8@8V]M<&%R:7-O;B!T;R!P97)F
M;W)M+B!4:&4*("`@('1H:7)D(&ES('1H92!V86QU92!T;R!W:&EC:"!T:&4@
M9FEE;&0@<VAO=6QD(&)E(&-O;7!A<F5D+B!4:&5R92!A<F4@82!F97<*("`@
M(&1I9F9E<F5N="!T>7!E<R!O9B!C;VUP87)I<V]N<R!T:&%T(&-A;B!B92!P
M97)F;W)M960N(%1H92!C;VUP87)I<V]N<PH@("`@879A:6QA8FQE(&9O<B!A
M;GD@9VEV96X@9FEE;&0@=VEL;"!D97!E;F0@;VX@8F]T:"!T:&4@='EP92!O
M9B!T:&4@9FEE;&0@86YD"B`@("!W:&%T('1H92!U;F1E<FQY:6YG(&9I;'1E
M<FEN9R!S;V9T=V%R92!C86X@:&%N9&QE+B!4:'5S+"!A;&P@<&]T96YT:6%L
M"B`@("!M871C:&EN9R!O<'1I;VYS(&QI<W1E9"!B96QO=R!M87D@;F]T(&%P
M<&5A<B!F;W(@82!G:79E;B!F:65L9"X\+W!A<F$^"B`@("`\:&5A9&EN9SY#
M;VYT86EN<SPO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@8F4@8V]N<VED97)E
M9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R:6YG(&ES(&9O=6YD
M"B`@("!A;GEW:&5R92!O;B!T:&4@;&EN92X@17AA;7!L93H@=7-E<D!E>&%M
M<&QE('=O=6QD(&UA=&-H"B`@("!J;V5?=7-E<D!E>&%M<&QE+F-O;3PO<&%R
M83X*("`@(#QH96%D:6YG/D1O97-N)W0@0V]N=&%I;CPO:&5A9&EN9SX*("`@
M(#QP87)A/E=I;&P@8F4@8V]N<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S
M<&5C:69I960@<W1R:6YG(&ES(&YO="!F;W5N9`H@("`@86YY=VAE<F4@;VX@
M=&AE(&QI;F4N($5X86UP;&4Z('5S97)`97AA;7!L92!W;W5L9"!N;W0@;6%T
M8V@*("`@(&IO95]U<V5R0&5X86UP;&4N8V]M/"]P87)A/@H@("`@/&AE861I
M;F<^27,\+VAE861I;F<^"B`@("`\<&%R83Y7:6QL(&)E(&-O;G-I9&5R960@
M=&\@8F4@=')U92!I9B!T:&4@<W!E8VEF:65D('-T<FEN9R!M871C:&5S('1H
M90H@("`@;&EN92!E>&%C=&QY+B!%>&%M<&QE.B!U<V5R0&5X86UP;&4N8V]M
M(&ES('5S97)`97AA;7!L92YC;VT\+W!A<F$^"B`@("`\:&5A9&EN9SY)<VXG
M=#PO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@8F4@8V]N<VED97)E9"!T;R!B
M92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R:6YG(&1O97,@;F]T(&UA=&-H
M"B`@("!T:&4@;&EN92!E>&%C=&QY+B!%>&%M<&QE.B!U<V5R0&5X86UP;&4@
M:7,@;F]T('5S97)`97AA;7!L92YC;VT\+W!A<F$^"B`@("`\:&5A9&EN9SY"
M96=I;G,@=VET:#PO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@8F4@8V]N<VED
M97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R:6YG(&UA=&-H
M97,@=&AE"B`@("!B96=I;FYI;F<@;V8@=&AE(&QI;F4N($5X86UP;&4Z('5S
M97)`97AA;7!L92!W:6QL(&UA=&-H"B`@("!U<V5R0&5X86UP;&4N8V]M/"]P
M87)A/@H@("`@/&AE861I;F<^1&]E<VXG="!B96=I;B!W:71H/"]H96%D:6YG
M/@H@("`@/'!A<F$^5VEL;"!B92!C;VYS:61E<F5D('1O(&)E('1R=64@:68@
M=&AE('-P96-I9FEE9"!S=')I;F<@9&]E<R!N;W0@;6%T8V@*("`@('1H92!B
M96=I;FYI;F<@;V8@=&AE(&QI;F4N($5X86UP;&4Z('5S97)`97AA;7!L92YC
M;VT@=VEL;"!N;W0@;6%T8V@*("`@('5S97)`97AA;7!L93PO<&%R83X*("`@
M(#QH96%D:6YG/D5N9',@=VET:#PO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@
M8F4@8V]N<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R
M:6YG(&UA=&-H97,@=&AE(&5N9`H@("`@;V8@=&AE(&QI;F4N($5X86UP;&4Z
M(&5X86UP;&4N8V]M('=I;&P@;6%T8V@@=7-E<D!E>&%M<&QE+F-O;3PO<&%R
M83X*("`@(#QH96%D:6YG/D1O97-N)W0@96YD('=I=&@\+VAE861I;F<^"B`@
M("`\<&%R83Y7:6QL(&)E(&-O;G-I9&5R960@=&\@8F4@=')U92!I9B!T:&4@
M<W!E8VEF:65D('-T<FEN9R!D;V5S(&YO="!M871C:`H@("`@=&AE(&5N9"!O
M9B!T:&4@;&EN92X@17AA;7!L93H@:&]R9&4N;W)G('=I;&P@;F]T(&UA=&-H
M"B`@("!U<V5R0&5X86UP;&4N8V]M/"]P87)A/@H@("`@/&AE861I;F<^17AI
M<W1S/"]H96%D:6YG/@H@("`@/'!A<F$^5VEL;"!B92!C;VYS:61E<F5D('1O
M(&)E('1R=64@:68@=&AE('-P96-I9FEE9"!H96%D97(@97AI<W1S(&EN('1H
M90H@("`@;65S<V%G92P@<F5G87)D;&5S<R!O9B!W:&%T(&ET<R!V86QU92!I
M<RX\+W!A<F$^"B`@("`\:&5A9&EN9SY$;V5S;B=T($5X:7-T/"]H96%D:6YG
M/@H@("`@/'!A<F$^5VEL;"!B92!C;VYS:61E<F5D('1O(&)E('1R=64@:68@
M=&AE('-P96-I9FEE9"!H96%D97(@9&]E<R!N;W0@97AI<W0*("`@(&EN('1H
M92!M97-S86=E+CPO<&%R83X*("`@(#QH96%D:6YG/E)E9V5X/"]H96%D:6YG
M/@H@("`@/'!A<F$^4F5G97@@86QL;W=S('EO=2!T;R!U<V4@8V]M<&QE>"!0
M3U-)6"!C;VUP871I8FQE(')E9W5L87(@97AP<F5S<VEO;G,*("`@('1O(&-O
M;7!A<F4@86=A:6YS="!M97-S86=E(&AE861E<G,N($5X86UP;&4Z(")296-E
M:79E9"!F<F]M(%LJ7"XJ7"XJ7"XJ72!B>0H@("`@*&AO<W1A?&AO<W1B*2YE
M>&%M<&QE+F-O;2HB('=O=6QD(&UA=&-H(")296-E:79E9"!F<F]M(%LQ-S(N
M,38N,3`P+C%=(&)Y"B`@("!H;W-T82YE>&%M<&QE+F-O;2!O;B!4=65S9&%Y
M(CPO<&%R83X*("`@(#QH96%D:6YG/DUA=&-H97,\+VAE861I;F<^"B`@("`\
M<&%R83Y-871C:&5S(&ES('-I;6EL87(@=&\@8V]N=&%I;G,L('=I=&@@=&AE
M(&5X8V5P=&EO;B!T:&%T('EO=2!M87D@=7-E("H*("`@(&%N9"`_(&%S('=I
M;&1C87)D<RX@06X@*B!W:6QL(&UA=&-H(&%N>2!N=6UB97(@;V8@8VAA<F%C
M=&5R<RP@86YD(&$@/R!W:6QL"B`@("!M871C:"!E>&%C=&QY(&]N92!C:&%R
M871E<BX@17AA;7!L93H@(BIU<V5R/T!E>&%M<&QE+F-O;2(@=VEL;"!M871C
M:"!B;W1H"B`@("`B=7-E<C%`97AA;7!L92YC;VTB(&%N9"`B;W1H97)U<V5R
M,D!E>&%M<&QE+F-O;2(\+W!A<F$^"B`@("`\:&5A9&EN9SY$;V5S;B=T(&UA
M=&-H/"]H96%D:6YG/@H@("`@/'!A<F$^1&]E<VXG="!M871C:"!I<R!T:&4@
M<V%M92!A<R!M871C:&5S(&5X8V5P="!T:&%T(&ET('=I;&P@979A;'5A=&4@
M=&\*("`@(&9A;'-E(&EF('1H92!S<&5C:69I960@=F%L=64@;6%T8VAE<R!T
M:&4@<W1R:6YG(&EN('1H92!M97-S86=E"B`@("!H96%D97(N/"]P87)A/@H@
M("`@/&AE861I;F<^3&5S<R!T:&%N/"]H96%D:6YG/@H@("`@/'!A<F$^5&AI
M<R!I<R!A(')E;&%T:6]N86P@=&5S="!W:&EC:"!W:6QL(&-O;7!A<F4@=&AE
M('9A;'5E('EO=2!S<&5C:69Y"B`@("!A;F0@=&AE('9A;'5E(&EN('1H92!M
M97-S86=E(&AE861E<B!N=6UE<FEC86QL>2X\+W!A<F$^"B`@("`\:&5A9&EN
M9SY,97-S('1H86X@;W(@97%U86P@=&\\+VAE861I;F<^"B`@("`\<&%R83Y4
M:&ES(&ES(&$@<F5L871I;VYA;"!T97-T('=H:6-H('=I;&P@8V]M<&%R92!T
M:&4@=F%L=64@>6]U('-P96-I9GD*("`@(&%N9"!T:&4@=F%L=64@:6X@=&AE
M(&UE<W-A9V4@:&5A9&5R(&YU;65R:6-A;&QY+CPO<&%R83X*("`@(#QH96%D
M:6YG/D5Q=6%L('1O/"]H96%D:6YG/@H@("`@/'!A<F$^5&AI<R!I<R!A(')E
M;&%T:6]N86P@=&5S="!W:&EC:"!W:6QL(&-O;7!A<F4@=&AE('9A;'5E('EO
M=2!S<&5C:69Y"B`@("!A;F0@=&AE('9A;'5E(&EN('1H92!M97-S86=E(&AE
M861E<B!N=6UE<FEC86QL>2X\+W!A<F$^"B`@("`\:&5A9&EN9SY'<F5A=&5R
M('1H86X@;W(@97%U86P@=&\\+VAE861I;F<^"B`@("`\<&%R83Y4:&ES(&ES
M(&$@<F5L871I;VYA;"!T97-T('=H:6-H('=I;&P@8V]M<&%R92!T:&4@=F%L
M=64@>6]U('-P96-I9GD*("`@(&%N9"!T:&4@=F%L=64@:6X@=&AE(&UE<W-A
M9V4@:&5A9&5R(&YU;65R:6-A;&QY+CPO<&%R83X*("`@(#QH96%D:6YG/D=R
M96%T97(@=&AA;CPO:&5A9&EN9SX*("`@(#QP87)A/E1H:7,@:7,@82!R96QA
M=&EO;F%L('1E<W0@=VAI8V@@=VEL;"!C;VUP87)E('1H92!V86QU92!Y;W4@
M<W!E8VEF>0H@("`@86YD('1H92!V86QU92!I;B!T:&4@;65S<V%G92!H96%D
M97(@;G5M97)I8V%L;'DN/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)R=6QE+6YA;64B/@H@("`@/'1I=&QE/D9I;'1E<B!2=6QE.B!.86UE/"]T
M:71L93X*("`@(#QP87)A/E1H:7,@:7,@82!D97-C<FEP=&EV92!N86UE(&9O
M<B!A(')U;&4N(%EO=2!M87D@=7-E(&ET('1O(&ED96YT:69Y(&$*("`@(')U
M;&4@:6X@>6]U<B!F:6QT97(@;&ES=&EN9RX\+W!A<F$^"B`@/"]E;G1R>3X*
M("`\96YT<GD@:60](G)U;&4M<W1O<"(^"B`@("`\=&ET;&4^1FEL=&5R(%)U
M;&4Z(%-T;W`@0VAE8VMI;F<\+W1I=&QE/@H@("`@/'!A<F$^268@=&AI<R!O
M<'1I;VX@:7,@8VAE8VME9"P@86YD(&$@;65S<V%G92!M871C:&5S('1H:7,@
M<G5L92P@=&AE"B`@("!R96UA:6YI;F<@9FEL=&5R<R!W:6QL(&YO="!B92!P
M<F]C97-S960N/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)V86-A
M=&EO;B(^"B`@("`\=&ET;&4^5F%C871I;VX\+W1I=&QE/@H@("`@/'!A<F$^
M5F%C871I;VX@;65S<V%G97,@87)E(&%U=&]M871I8R!R97-P;VYS97,@<V5N
M="!T;R!P96]P;&4@=VAE;B!T:&5Y"B`@("!E;6%I;"!Y;W4N(%1H97D@87)E
M(&YO<FUA;&QY('5S960@=VAE;B!Y;W4@87)E(&%W87D@9F]R(&$@;&]N9R!P
M97)I;V0@;V8*("`@('1I;64N/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y
M(&ED/2)V86-A=&EO;BUB=6QK(CX*("`@(#QT:71L93Y686-A=&EO;CH@3F\@
M4F5S<&]N9"!T;R!"=6QK/"]T:71L93X*("`@(#QP87)A/D-H96-K:6YG('1H
M:7,@;W!T:6]N('=I;&P@8V%U<V4@=F%C871I;VX@<F5S<&]N<V5S('1O(&YO
M="!B92!S96YT('1O"B`@("!M97-S86=E<R!T:&%T(&%P<&5A<B!T;R!C;VUE
M(&9R;VT@;6%I;&EN9R!L:7-T<R!O<B!T:&%T(&%R92!M87)K960@87,@8G5L
M:PH@("`@;6%I;"X\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G9A
M8V%T:6]N+61A>7,B/@H@("`@/'1I=&QE/E9A8V%T:6]N.B!297!L>2!);G1E
M<G9A;#PO=&ET;&4^"B`@("`\<&%R83Y4:&ES(&ES('1H92!N=6UB97(@;V8@
M9&%Y<R!T;R!W86ET(&)E9F]R92!S96YD:6YG(&%N(&%U=&]R97-P;VYS92!T
M;PH@("`@86X@861D<F5S<R!T:&%T(&AA<R!A;')E861Y(')E8V5I=F5D(&]N
M92X\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G9A8V%T:6]N+6UY
M96UA:6PB/@H@("`@/'1I=&QE/E9A8V%T:6]N.B!->2!%;6%I;"!!9&1R97-S
M97,\+W1I=&QE/@H@("`@/'!A<F$^268@>6]U(&AA=F4@;6]R92!T:&%N(&]N
M92!E;6%I;"!A9&1R97-S(&-O;6EN9R!T;R!T:&ES(&UA:6QB;W@@=&AE;@H@
M("`@<W!E8VEF>2!T:&5M(&AE<F4N/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N
M=')Y(&ED/2)V86-A=&EO;BUN;W)E<W!O;G-E(CX*("`@(#QT:71L93Y686-A
M=&EO;CH@3F\@4F5S<&]N<V5S/"]T:71L93X*("`@(#QP87)A/D1O;B=T('-E
M;F0@=&AE('9A8V%T:6]N(&UE<W-A9V4@=&\@=&AE<V4@<F5C:7!I96YT<RX@
M16%C:"!A9&1R97-S"B`@("!S:&]U;&0@8F4@;VX@:71S(&]W;B!L:6YE+CPO
M<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=F%C871I;VXM<F5A<V]N
M(CX*("`@(#QT:71L93Y686-A=&EO;CH@5F%C871I;VX@4F5A<V]N/"]T:71L
M93X*("`@(#QP87)A/E1H:7,@:7,@=&AE('1E>'0@=&AA="!W:6QL(&)E('-E
M;G0@:6X@>6]U<B!V86-A=&EO;B!R97-P;VYS97,N/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)V86-A=&EO;BUS=6)J96-T(CX*("`@(#QT:71L
M93Y686-A=&EO;CH@5F%C871I;VX@4W5B:F5C=#PO=&ET;&4^"B`@("`\<&%R
M83Y4:&ES(&ES('1H92!S=6)J96-T('1H870@=VEL;"!B92!U<V5D(&9O<B!V
M86-A=&EO;B!R97-P;VYS97,N/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y
M(&ED/2)W:&ET96QI<W0B/@H@("`@/'1I=&QE/E=H:71E;&ES=#PO=&ET;&4^
M"B`@("`\<&%R83Y4:&4@=VAI=&5L:7-T(&ES(&$@;&ES="!O9B`H;&5G:71I
M;6%T92D@96UA:6P@861D<F5S<V5S('1H870@>6]U"B`@("!A;'=A>7,@=VES
M:"!T;R!S964@:6X@>6]U<B!)3D)/6"X@16%C:"!A9&1R97-S('-H;W5L9"!B
M92!E;G1E<F5D(&]N(&$*("`@('-E<&%R871E(&QI;F4N/"]P87)A/@H@(#PO
M96YT<GD^"B`@/&5N=')Y(&ED/2)W:&ET96QI<W0M861D<F5S<V5S(CX*("`@
M(#QT:71L93Y7:&ET96QI<W0Z($%D9')E<W-E<SPO=&ET;&4^"B`@("`\<&%R
M83Y43T1/+B!%86-H(&%D9')E<W,@<VAO=6QD(&)E(&5N=&5R960@;VX@82!S
M97!A<F%T92!L:6YE+CPO<&%R83X*("`\+V5N=')Y/@H\+VAE;'`^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN
M9V\O;&]C86QE+V5S7T53+P``````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#<`,#$W-C(P`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O97-?15,O3$-?34534T%'15,O
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T
M-P`P,C$T,#4`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]E
M<U]%4R],0U]-15-304=%4R]I;F=O+FUO````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M-#4U-S4W`#$P-#$W,S8R-S0W`#`R,C<R,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````$\(```<````E$(``!4+
M```,A0```````&"Q```.````8;$```\```!PL0``#0```("Q```(````CK$`
M``L```"7L0``#````*.Q```$````L+$```0```"UL0```P```+JQ```8````
MOK$``!L```#7L0``+0```/.Q```=````(;(``"0````_L@``*0```&2R```9
M````CK(``"8```"HL@``#````,^R```D````W+(```\````!LP``"P```!&S
M```.````';,```4````LLP``*````#*S```(````6[,```H```!DLP``%0``
M`&^S```2````A;,```L```"8LP``A0```*2S```.````*K0```H````YM```
M#0```$2T```.````4K0``!$```!AM```#0```'.T```,````@;0```T```".
MM```!@```)RT``"4````H[0```H````XM0``#P```$.U```8````4[4```P`
M``!LM0``#@```'FU```.````B+4```@```"7M0``"0```*"U```N````JK4`
M`!H```#9M0``,@```/2U```X````)[8``%0```!@M@``40```+6V``!:````
M![<``%<```!BMP``-````+JW```)````[[<```T```#YMP``!P````>X```*
M````#[@```\````:N```!0```"JX```&````,+@``!$````WN```"````$FX
M```)````4K@```D```!<N```)0```&:X```@````C+@``!,```"MN```$```
M`,&X```/````TK@```H```#BN```(0```.VX```/````#[D``"X````?N0``
M`P```$ZY```/````4KD``!0```!BN0``"0```'>Y```-````@;D``!(```"/
MN0``&0```**Y```>````O+D```\```#;N0``"@```.NY```/````]KD```@`
M```&N@``)`````^Z```4````-+H``!8```!)N@``"````&"Z``!.````:;H`
M`"T```"XN@``&0```.:Z```3`````+L```<````4NP``#````!R[```L````
M*;L```X```!6NP```P```&6[```+````:;L```<```!UNP``!P```'V[```%
M````A;L```4```"+NP``"@```)&[```#````G+L``!<```"@NP``"@```+B[
M```/````P[L```X```#3NP``%````.*[```+````][L``!@````#O```(P``
M`!R\```.````0+P``!0```!/O```%P```&2\```7````?+P``!<```"4O```
M$P```*R\```/````P+P```X```#0O```'P```-^\```=````_[P```<````=
MO0``!@```"6]```(````++T```\````UO0``!@```$6]```(````3+T```H`
M``!5O0``$P```&"]```4````=+T```L```")O0``$````)6]```5````IKT`
M``T```"\O0``%0```,J]```'````X+T``!````#HO0``!0```/F]```5````
M_[T``!$````5O@``#````">^```J````-+X``#L```!?O@``.````)N^```)
M````U+X```<```#>O@``%````.:^```#````^[X```4```#_O@``$`````6_
M```)````%K\``!,````@OP``.0```#2_```2````;K\``"<```"!OP``+```
M`*F_```J````UK\``"4````!P```"@```"?````&````,L````D````YP```
M!P```$/````O````2\```#<```![P```+@```+/```!5````XL```"T````X
MP0``+0```&;!```]````E,$``#\```#2P0``+0```!+"``!`````0,(``",`
M``"!P@``(P```*7"``!`````R<(``"T````*PP``,P```#C#```E````;,,`
M`!4```"2PP``&0```*C#```I````PL,``"0```#LPP``*````!'$```R````
M.L0``!$```!MQ```"@```'_$```,````BL0```H```"7Q```$````*+$```6
M````L\0``!8```#*Q```!P```.'$```'````Z<0``!0```#QQ```"@````;%
M```(````$<4``"<````:Q0``"````$+%```#````2\4```L```!/Q0``!P``
M`%O%```'````8\4```8```!KQ0``!0```'+%```'````>,4```8```"`Q0``
M%````(?%```(````G,4```D```"EQ0``#@```*_%```[````OL4``!4```#Z
MQ0``*0```!#&```.````.L8```H```!)Q@``!````%3&```$````6<8```<`
M``!>Q@``"0```&;&```&````<,8``!$```!WQ@``!P```(G&```6````D<8`
M``0```"HQ@``"````*W&```&````ML8```T```"]Q@``!@```,O&```>````
MTL8``!$```#QQ@``"`````/'```-````#,<```P````:QP``!P```"?'```#
M````+\<```,````SQP``%P```#?'```3````3\<``!T```!CQP``"````(''
M```$````BL<```@```"/QP``"````)C'``!!````H<<``!H```#CQP``*P``
M`/['```@````*L@``!4```!+R```!@```&'(```&````:,@``!4```!OR```
M&````(7(```B````GL@``"X```#!R```'0```/#(```A````#LD``%0````P
MR0``*0```(7)```*````K\D```<```"ZR0``!P```,+)```.````RLD``!4`
M``#9R0``#@```._)```"````_LD```H````!R@``#P````S*```-````',H`
M``\````JR@``#0```#K*```)````2,H``!0```!2R@``!@```&?*```8````
M;LH``!T```"'R@``$P```*7*```1````N<H``!0```#+R@``!````.#*```&
M````Y<H``!0```#LR@``5`````'+```.````5LL``&0```!ERP``!````,K+
M```.````S\L```4```#>RP``!0```.3+```;````ZLL``!H````&S```$P``
M`"',```1````-<P``!$```!'S```'````%G,```J````=LP``!````"AS```
M(0```++,```%````U,P``!,```#:S```"P```.[,```2````^LP```H````-
MS0``#P```!C-```-````*,T``!$````VS0``$P```$C-```,````7,T```8`
M``!IS0``#````'#-```&````?<T``!<```"$S0``$````)S-```1````K<T`
M``@```"_S0``!0```,C-```,````SLT``!````#;S0``!0```.S-```-````
M\LT```8`````S@``!P````?.```-````#\X```<````=S@``"P```"7.```'
M````,<X```<````YS@``"0```$'.```)````2\X```H```!5S@``&0```&#.
M```]````>LX``!T```"XS@``#````-;.```0````X\X```4```#TS@``)0``
M`/K.```2````(,\``!,````SSP``$@```$?/```K````6L\``#L```"&SP``
M(````,+/```(````X\\``#8```#LSP``"````"/0```A````+-```!````!.
MT```"````%_0```,````:-````8```!UT```!````'S0```'````@=````\`
M``")T```"@```)G0```.````I-````<```"ST```"@```+O0```-````QM``
M`!\```#4T```'````/30```A````$=$``!X````ST0``&0```%+1```>````
M;-$``!L```"+T0``(0```*?1```N````R=$``"8```#XT0``'````!_2```>
M````/-(``!P```!;T@``)@```'C2```K````G](``#,```#+T@``)@```/_2
M```K````)M,``#@```!2TP``'0```(O3```5````J=,``"\```"_TP``(```
M`._3```2````$-0``"D````CU```'@```$W4```@````;-0``!(```"-U```
MH@```*#4```6````0]4``",```!:U0``*````'[5```I````I]4``"@```#1
MU0``'P```/K5```5````&M8``"`````PU@``)0```%'6```H````=]8``"T`
M``"@U@``,````,[6``"2````_]8``"$```"2UP``%@```+37```<````R]<`
M`"8```#HUP``*@````_8``!!````.M@``$0```!\V```#````,'8```'````
MSM@```<```#6V```!@```-[8```-````Y=@``!````#SV```$0````39```2
M````%MD``!,````IV0``$@```#W9```'````4-D```0```!8V0``$````%W9
M```0````;MD```P```!_V0``#@```(S9```-````F]D```\```"IV0``$P``
M`+G9```-````S=D``"@```#;V0```P````3:```-````"-H```8````6V@``
M$0```!W:```7````+]H``!L```!'V@``#@```&/:```"````<MH```H```!U
MV@``20```(#:```%````RMH``!````#0V@``#P```.':```$````\=H```T`
M``#VV@``#@````3;```#````$]L```X````7VP``$0```";;```(````.-L`
M``\```!!VP``#P```%';```'````8=L```T```!IVP``$````'?;```-````
MB-L```L```"6VP``!@```*+;```)````J=L```L```"SVP``$````+_;```,
M````T-L```H```#=VP``$0```.C;```9````^ML```L````4W```#0```"#<
M```B````+MP``!D```!1W```#P```&O<```;````>]P``#0```"7W```"@``
M`,S<```8````U]P``!(```#PW```&0````/=```6````'=T```<````TW0``
M(@```#S=```5````7]T``"$```!UW0``)0```)?=```1````O=T```T```#/
MW0``!P```-W=```4````Y=T```L```#ZW0``(@````;>```O````*=X```L`
M``!9W@``"0```&7>```9````;]X```L```")W@``%P```)7>```7````K=X`
M``D```#%W@``"@```,_>```(````VMX``!8```#CW@``#P```/K>```9````
M"M\``#H````DWP``%@```%_?```.````=M\``!@```"%WP``"````)[?```O
M````I]\```T```#7WP``)@```.7?```(````#.```$,````5X```$@```%G@
M```/````;.```!````!\X```#0```(W@```A````F^````@```"]X```$@``
M`,;@```?````V>````@```#YX```"P````+A```O````#N$```X````^X0``
M!0```$WA```&````4^$``$4```!:X0```P```*#A```'````I.$```0```"L
MX0``!P```+'A```*````N>$```H```#$X0``#P```,_A```0````W^$``!<`
M``#PX0``$0````CB```9````&N(``!<````TX@``"0```$SB```%````5N(`
M``L```!<X@``"@```&CB```"````<^(```4```!VX@``#0```'SB```;````
MBN(``!<```"FX@``%````+[B```)````T^(```X```#=X@``#0```.SB```2
M````^N(```D````-XP``.````!?C```@````4.,```<```!QXP``"````'GC
M```)````@N,```X```",XP``>P```)OC```8````%^0``!@````PY```"```
M`$GD```1````4N0```<```!DY```!0```&SD```8````<N0``!X```"+Y```
M&P```*KD```9````QN0``"@```#@Y```%0````GE```;````'^4``!D````[
MY0``$P```%7E```'````:>4```@```!QY0``!@```'KE```&````@>4``!``
M``"(Y0``#P```)GE```0````J>4```\```"ZY0``"P```,KE```/````UN4`
M``P```#FY0``#P```//E```'`````^8```X````+Y@``!@```!KF```&````
M(>8```X````HY@``#````#?F```:````1.8``"@```!?Y@``#P```(CF```(
M````F.8```@```"AY@``$P```*KF```>````ON8``"$```#=Y@``(````/_F
M```9````(.<``!<````ZYP``)0```%+G```7````>.<``!8```"0YP``!```
M`*?G```;````K.<```T```#(YP``#````-;G```#````X^<```4```#GYP``
M"````.WG```*````]N<```P````!Z```"P````[H```0````&N@```P````K
MZ```#@```#CH```+````1^@```0```!3Z```!````%CH```3````7>@``!0`
M``!QZ```#````(;H```)````D^@```X```"=Z```"P```*SH```;````N.@`
M`!,```#4Z```&0```.CH```;`````ND```X````>Z0``"P```"WI```,````
M.>D``!4```!&Z0``#0```%SI``!#````:ND``#$```"NZ0``0@```.#I``!'
M````(^H``$\```!KZ@``/0```+OJ``!.````^>H``!$```!(ZP``!P```%KK
M```'````8NL```H```!JZP``#0```'7K```)````@^L```0```"-ZP``!0``
M`)+K```#````F.L``!@```"<ZP``"@```+7K```$````P.L``"4```#%ZP``
M)@```.OK```.````$NP``'P````A[```%0```)[L```%````M.P```<```"Z
M[```#````,+L```(````S^P```H```#8[```!@```./L```'````ZNP``#D`
M``#R[```"````"SM```-````->T```(```!#[0``!@```$;M```&````3>T`
M`!0```!4[0``#0```&GM```0````=^T``!L```"([0``!````*3M```)````
MJ>T```4```"S[0``$````+GM```)````RNT```D```#4[0``!0```-[M```:
M````Y.T```@```#_[0``!@````CN```9````#^X```X````I[@``!P```#CN
M```'````0.X```4```!([@``"0```$[N```*````6.X```X```!C[@```@``
M`'+N```&````=>X```L```!\[@``#0```(CN```)````ENX```P```"@[@``
M&````*WN```&````QNX``!(```#-[@``"0```.#N```'````ZNX``!0```#R
M[@``'0````?O``!"````)>\``"4```!H[P``)0```([O```&````M.\```H`
M``"[[P``!````,;O```)````R^\```@```#5[P``$0```-[O```)````\.\`
M``8```#Z[P``#0````'P```&````#_````0````6\```.0```!OP```]````
M5?```#H```"3\```'@```,[P```%````[?````X```#S\```!`````+Q```&
M````!_$```<````.\0``(0```!;Q```-````./$``!4```!&\0``!@```%SQ
M```$````8_$``!$```!H\0``!@```'KQ```*````@?$``"(```",\0``!```
M`*_Q```%````M/$``!T```"Z\0``!````-CQ```,````W?$```X```#J\0``
M"@```/GQ```(````!/(```D````-\@``!0```!?R```Z````'?(``#````!8
M\@``-0```(GR```I````O_(``$<```#I\@``.````#'S```I````:O,``#\`
M``"4\P``+@```-3S```M`````_0``!\````Q]```#P```%'T```2````8?0`
M``L```!T]```)@```(#T```I````I_0``"0```#1]```)@```/;T```(````
M'?4```H````F]0``"0```#'U```'````._4``"````!#]0``(````&3U```F
M````A?4```H```"L]0``&0```+?U```I````T?4``!8```#[]0``$@```!+V
M```'````)?8```H````M]@``#````#CV```/````1?8``!````!5]@``0```
M`&;V``!P````I_8``&8````8]P``#@```'_W```)````CO<```H```"8]P``
M$@```*/W```3````MO<```P```#*]P``!@```-?W```/````WO<```D```#N
M]P``$@```/CW```0````"_@``!$````<^```'````"[X```C````2_@``&H`
M``!O^```#P```-KX```%````ZO@``!````#P^```0P````'Y```)````1?D`
M`#(```!/^0``!````(+Y```+````A_D``"````"3^0``%````+3Y```,````
MR?D```P```#6^0``#P```./Y```5````\_D``"D````)^@``*@```#/Z```F
M````7OH``"<```"%^@``*0```*WZ```J````U_H``!D````"^P``0@```!S[
M```1````7_L``!(```!Q^P``$P```(3[```4````F/L```\```"M^P``%@``
M`+W[```7````U/L``!````#L^P``$0```/W[```T````#_P``!,```!$_```
M$@```%C\```U````:_P``!0```"A_```!P```+;\```,````OOP``"````#+
M_```$````.S\```4````_?P``!$````2_0``%P```"3]```<````//T``!,`
M``!9_0``%````&W]```:````@OT``!$```"=_0``&@```*_]```>````ROT`
M`!H```#I_0``$P````3^```5````&/X``!$````N_@``%P```$#^```4````
M6/X``!<```!M_@``%0```(7^```)````F_X``!````"E_@``&0```+;^```$
M````T/X```<```#5_@```@```-W^```+````X/X```4```#L_@``$0```/+^
M```&````!/\```8````+_P``!@```!+_```%````&?\```<````?_P``!P``
M`"?_```%````+_\``!8````U_P``!@```$S_```&````4_\```0```!:_P``
M!````%__```'````9/\```X```!L_P``#````'O_```,````B/\```T```"5
M_P``"@```*/_```.````KO\```4```"]_P``*````,/_```.````[/\```P`
M``#[_P``#P````@``0`*````&``!``@````C``$`"0```"P``0`K````-@`!
M``0```!B``$`"````&<``0`F````<``!`!(```"7``$`#P```*H``0`&````
MN@`!``H```#!``$`3````,P``0`'````&0$!``@````A`0$`(````"H!`0`)
M````2P$!`!0```!5`0$`#````&H!`0`-````=P$!``X```"%`0$`%@```)0!
M`0`1````JP$!``8```"]`0$``P```,0!`0`&````R`$!`!D```#/`0$`!P``
M`.D!`0`$````\0$!``L```#V`0$`"P````("`0`'````#@(!``D````6`@$`
M%0```"`"`0`%````-@(!``<````\`@$`%@```$0"`0`-````6P(!``T```!I
M`@$`"@```'<"`0`0````@@(!``\```"3`@$`$0```*,"`0`7````M0(!``H`
M``#-`@$`$0```-@"`0`(````Z@(!``0```#S`@$`#P```/@"`0`Z````"`,!
M``4```!#`P$`#````$D#`0`>````5@,!``X```!U`P$`$````(0#`0`+````
ME0,!``P```"A`P$`"0```*X#`0`'````N`,!``<```#``P$`"@```,@#`0`)
M````TP,!``X```#=`P$`$````.P#`0`;````_0,!`!@````9!`$`&@```#($
M`0`*````300!``D```!8!`$`"@```&($`0`,````;00!``\```!Z!`$`"```
M`(H$`0`&````DP0!`!P```":!`$`!P```+<$`0`%````OP0!``L```#%!`$`
M1P```-$$`0`-````&04!``D````G!0$`!````#$%`0`#````-@4!`!,````Z
M!0$`$P```$X%`0`3````8@4!``H```!V!0$``@```($%`0`$````A`4!`"4`
M``")!0$``P```*\%`0`%````LP4!`"H```"Y!0$`"@```.0%`0`%````[P4!
M``0```#U!0$`"@```/H%`0`-````!08!``8````3!@$`"````!H&`0`(````
M(P8!``0````L!@$`!0```#$&`0!H````-P8!``D```"@!@$`#````*H&`0`0
M````MP8!`!@```#(!@$`!0```.$&`0`&````YP8!`!````#N!@$`&P```/\&
M`0`O````&P<!`!````!+!P$`"@```%P'`0`;````9P<!``\```"#!P$`"@``
M`),'`0`)````G@<!`!,```"H!P$`&P```+P'`0`8````V`<!`!<```#Q!P$`
M'P````D(`0`7````*0@!``X```!!"`$`B0```%`(`0")````V@@!``,```!D
M"0$`!P```&@)`0`(````<`D!``<```!Y"0$`"@```($)`0`+````C`D!``<`
M``"8"0$`40```*`)`0`0````\@D!``P````#"@$`#0```!`*`0`:````'@H!
M`$H````Y"@$`&0```(0*`0`&````G@H!`!H```"E"@$`)0```,`*`0`&````
MY@H!``8```#M"@$`'P```/0*`0`&````%`L!``D````;"P$`&````"4+`0`7
M````/@L!`"@```!6"P$`!@```'\+`0`-````A@L!`"(```"4"P$`&0```+<+
M`0`F````T0L!`%<```#X"P$`$P```%`,`0`9````9`P!`!L```!^#`$`(P``
M`)H,`0`3````O@P!``(```#2#`$`"P```-4,`0`(````X0P!``T```#J#`$`
M"@```/@,`0`'`````PT!`!0````+#0$`!@```"`-`0`(````)PT!``X````P
M#0$`!P```#\-`0`*````1PT!``L```!2#0$`,@```%X-`0`'````D0T!``P`
M``"9#0$`#0```*8-`0`,````M`T!``0```#!#0$`"0```,8-`0`)````T`T!
M``H```#:#0$`#@```.4-`0`,````]`T!``<````!#@$`"0````D.`0`'````
M$PX!``H````;#@$`&P```"8.`0`/````0@X!`!(```!2#@$`"@```&4.`0`6
M````<`X!``D```"'#@$`$````)$.`0`'````H@X!`!(```"J#@$`*0```+T.
M`0`$````YPX!``<```#L#@$`!0```/0.`0`%````^@X!``L`````#P$`%```
M``P/`0`1````(0\!`!H````S#P$`%@```$X/`0`4````90\!`!<```!Z#P$`
M&````)(/`0`<````JP\!`!D```#(#P$`!P```.(/`0`%````Z@\!``T```#P
M#P$`#````/X/`0`1````"Q`!``@````=$`$`"````"80`0`7````+Q`!``L`
M``!'$`$`#````%,0`0`?````8!`!`!H```"`$`$`$P```)L0`0`$````KQ`!
M``H```"T$`$`!````+\0`0`-````Q!`!``P```#2$`$`!0```-\0`0`)````
MY1`!``4```#O$`$`!P```/40`0`%````_1`!``0````#$0$``@````@1`0`O
M````"Q$!`#@````[$0$`+````'01`0`C````H1$!`"8```#%$0$`$@```.P1
M`0`I````_Q$!`#(````I$@$`"@```%P2`0`L````9Q(!`"X```"4$@$`,P``
M`,,2`0`S````]Q(!`#@````K$P$`#P```&03`0`8````=!,!`!````"-$P$`
M+@```)X3`0`4````S1,!``\```#B$P$`$P```/(3`0`5````!A0!`!0````<
M%`$`$@```#$4`0`4````1!0!`!4```!9%`$`+0```&\4`0`M````G10!`#$`
M``#+%`$`+@```/T4`0`O````+!4!`"P```!<%0$`8@```(D5`0`3````[!4!
M``T`````%@$`"`````X6`0`4````%Q8!`!<````L%@$`"````$06`0`4````
M318!``P```!B%@$`*P```&\6`0`A````FQ8!`!H```"]%@$`"0```-@6`0!%
M````XA8!`$$````H%P$`!````&H7`0`3````;Q<!`!0```"#%P$`#@```)@7
M`0`3````IQ<!`!@```"[%P$`!@```-07`0`)````VQ<!``H```#E%P$`#P``
M`/`7`0`,`````!@!`!`````-&`$`!P```!X8`0`.````)A@!``4````U&`$`
M&P```#L8`0`4````5Q@!``@```!L&`$`!@```'48`0`4````?!@!`!$```"1
M&`$`#@```*,8`0`X````LA@!``(```#K&`$`!@```.X8`0`.````]1@!``4`
M```$&0$`!P````H9`0`.````$AD!``8````A&0$`*````"@9`0`,````41D!
M`!P```!>&0$`!````'L9`0`I````@!D!`!4```"J&0$`%P```,`9`0`?````
MV!D!`%P```#X&0$`%````%4:`0`^````:AH!`!\```"I&@$`$````,D:`0`'
M````VAH!`!X```#B&@$`#@````$;`0`,````$!L!``P````=&P$`$P```"H;
M`0`*````/AL!`!T```!)&P$`&0```&<;`0`%````@1L!`!$```"'&P$`#0``
M`)D;`0`(````IQL!`!$```"P&P$`)````,(;`0`2````YQL!`!4```#Z&P$`
M$@```!`<`0`.````(QP!`!D````R'`$`"````$P<`0`)````51P!``T```!?
M'`$`!P```&T<`0`*````=1P!``<```"`'`$`#P```(@<`0`&````F!P!``L`
M``"?'`$`&@```*L<`0`*````QAP!``<```#1'`$`"````-D<`0`%````XAP!
M`!\```#H'`$`!@````@=`0`0````#QT!``@````@'0$`#0```"D=`0`(````
M-QT!`!X```!`'0$`$@```%\=`0`L````<AT!`!H```"?'0$`"0```+H=`0`*
M````Q!T!`!4```#/'0$`!0```.4=`0`4````ZQT!``0`````'@$`$`````4>
M`0`&````%AX!``<````='@$`'@```"4>`0`H````1!X!``H```!M'@$`'```
M`'@>`0`1````E1X!``L```"G'@$`&@```+,>`0`4````SAX!``0```#C'@$`
M!````.@>`0`+````[1X!``4```#Y'@$`!@```/\>`0`(````!A\!``8````/
M'P$`"@```!8?`0`;````(1\!`#0````]'P$`-````'(?`0`@````IQ\!`"D`
M``#('P$`(````/(?`0!!````$R`!`!H```!5(`$`*````'`@`0`H````F2`!
M`"D```#"(`$`4````.P@`0`B````/2$!``8```!@(0$`"````&<A`0`%````
M<"$!``@```!V(0$`&0```'\A`0`9````F2$!`"H```"S(0$`(P```-XA`0`9
M`````B(!`"X````<(@$`-````$LB`0`(````@"(!`!<```")(@$`"@```*$B
M`0`'````K"(!`"$```"T(@$`$````-8B`0`.````YR(!``L```#V(@$`!P``
M``(C`0`3````"B,!``@````>(P$`"P```"<C`0`*````,R,!`!0````^(P$`
M#P```%,C`0`R````8R,!``L```"6(P$`#@```*(C`0`%````L2,!``4```"W
M(P$`!0```+TC`0`7````PR,!``<```#;(P$`#P```.,C`0`$````\R,!``H`
M``#X(P$`"0````,D`0`+````#20!``T````9)`$`#````"<D`0`.````-"0!
M``4```!#)`$`!````$DD`0`-````3B0!`#(```!<)`$`10```(\D`0`(````
MU20!``L```#>)`$`%P```.HD`0`'`````B4!`!X````*)0$`%````"DE`0`%
M````/B4!`!(```!$)0$`$@```%<E`0`4````:B4!``8```!_)0$`!P```(8E
M`0`.````CB4!`"H```"=)0$`!@```,@E`0`,````SR4!``T```#<)0$`$0``
M`.HE`0`+````_"4!`#8````()@$`"@```#\F`0`B````2B8!``L```!M)@$`
M#P```'DF`0`R````B28!`"4```"\)@$`,````.(F`0`Q````$R<!`"T```!%
M)P$`#@```',G`0`)````@B<!``L```",)P$`!0```)@G`0`.````GB<!`!,`
M``"M)P$`$@```,$G`0`'````U"<!`!8```#<)P$`$0```/,G`0`4````!2@!
M`!,````:*`$`!P```"XH`0`4````-B@!`!@```!+*`$`!P```&0H`0`%````
M;"@!``P```!R*`$`#````'\H`0`2````C"@!``0```"?*`$`!P```*0H`0`*
M````K"@!``L```"W*`$`#````,,H`0`.````T"@!``X```#?*`$`!0```.XH
M`0`$````]"@!``L```#Y*`$`#`````4I`0`-````$BD!``P````@*0$`"0``
M`"TI`0`%````-RD!``4````]*0$`+@```$,I`0`F````<BD!`",```"9*0$`
M`P```+TI`0`2````P2D!``8```#4*0$`'@```-LI`0`8````^BD!`"4````3
M*@$`#0```#DJ`0`)````1RH!`!\```!1*@$``P```'$J`0`8````=2H!``<`
M``".*@$`"@```)8J`0`"````H2H!``P```"D*@$`%0```+$J`0`+````QRH!
M`!D```#3*@$`(````.TJ`0`2````#BL!``4````A*P$`"@```"<K`0`5````
M,BL!`!(```!(*P$`#````%LK`0`$````:"L!``D```!M*P$`!P```'<K`0`,
M````?RL!``T```",*P$`4@```)HK`0`7````[2L!`"0````%+`$`$@```"HL
M`0`'````/2P!``8```!%+`$`#P```$PL`0`3````7"P!`!X```!P+`$`(```
M`(\L`0`&````L"P!``X```"W+`$`!````,8L`0`,````RRP!``T```#8+`$`
M#@```.8L`0`5````]2P!`!(````++0$`#P```!XM`0`4````+BT!``H```!#
M+0$`&P```$XM`0`0````:BT!``L```![+0$`%````(<M`0!I````G"T!`!H`
M```&+@$`%P```"$N`0`G````.2X!`!H```!A+@$`%P```'PN`0`;````E"X!
M`!D```"P+@$`'P```,HN`0`3````ZBX!`!,```#^+@$`"````!(O`0`&````
M&R\!``<````B+P$`"````"HO`0`)````,R\!`!4````]+P$`#0```%,O`0`C
M````82\!``T```"%+P$`$P```),O`0`(````IR\!``,```"P+P$`1@```+0O
M`0`_````^R\!`#<````[,`$`5P```',P`0`>````RS`!``4```#J,`$`'P``
M`/`P`0`O````$#$!``H```!`,0$`"````$LQ`0`-````5#$!`"T```!B,0$`
M!````)`Q`0`2````E3$!`!,```"H,0$`3P```+PQ`0`E````##(!`!P````R
M,@$`"P```$\R`0`?````6S(!`!T```![,@$`)0```)DR`0`@````OS(!`"0`
M``#@,@$`(`````4S`0`+````)C,!``<````R,P$`#0```#HS`0`,````2#,!
M`!<```!5,P$`!@```&TS`0`Y````=#,!``P```"N,P$`!P```+LS`0`)````
MPS,!`!,```#-,P$`"0```.$S`0`$````ZS,!`!````#P,P$`"`````$T`0`(
M````"C0!``0````3-`$`"P```!@T`0`,````)#0!`!(````Q-`$`$0```$0T
M`0`,````5C0!`!H```!C-`$`#P```'XT`0`'````CC0!``T```"6-`$`%```
M`*0T`0`.````N30!``P```#(-`$`&P```-4T`0`L````\30!`!,````>-0$`
M'````#(U`0`H````3S4!``8```!X-0$`!P```'\U`0`3````AS4!``4```";
M-0$`!````*$U`0`7````IC4!``H```"^-0$`#````,DU`0`)````UC4!``8`
M``#@-0$`"0```.<U`0`(````\34!``D```#Z-0$`"@````0V`0`1````#S8!
M``8````A-@$`(P```"@V`0`.````3#8!``X```!;-@$`#0```&HV`0`+````
M>#8!`!T```"$-@$`"P```*(V`0`"````KC8!`!P```"Q-@$`'0```,XV`0`'
M````[#8!``@```#T-@$`!@```/TV`0!D````!#<!``D```!I-P$`!P```',W
M`0`F````>S<!`#@```"B-P$`&@```-LW`0`J````]C<!`#L````A.`$`*```
M`%TX`0`T````AC@!`!D```"[.`$`%0```-4X`0`%````ZS@!``<```#Q.`$`
M"````/DX`0`'`````CD!``4````*.0$`!P```!`Y`0`.````&#D!``D````G
M.0$`!@```#$Y`0`(````.#D!``L```!!.0$`!P```$TY`0`(````53D!``<`
M``!>.0$`%@```&8Y`0`)````?3D!``8```"'.0$`"P```(XY`0`0````FCD!
M``8```"K.0$`'````+(Y`0`4````SSD!``<```#D.0$`$0```.PY`0`(````
M_CD!``X````'.@$`"````!8Z`0`%````'SH!`!`````E.@$`"0```#8Z`0`0
M````0#H!``8```!1.@$`&0```%@Z`0`*````<CH!`!P```!].@$`!P```)HZ
M`0`%````HCH!`!````"H.@$`%````+DZ`0`+````SCH!``T```#:.@$`*```
M`.@Z`0`8````$3L!`!<````J.P$`!````$([`0`)````1SL!``H```!1.P$`
M!P```%P[`0`"````9#L!``X```!G.P$`"````'8[`0`C````?SL!`!\```"C
M.P$`.````,,[`0`F````_#L!`#$````C/`$`)P```%4\`0`R````?3P!`#(`
M``"P/`$`9````.,\`0`4````2#T!`%4```!=/0$`.````+,]`0!*````[#T!
M`%L````W/@$`*````),^`0`1````O#X!`#@```#./@$`*`````<_`0`L````
M,#\!`"8```!=/P$`&P```(0_`0`^````H#\!`*D!``#?/P$`(P```(E!`0`7
M````K4$!`$@```#%00$`A0````Y"`0`P````E$(!`"4```#%0@$`00```.M"
M`0!;````+4,!`$D```")0P$`,0```--#`0`=````!40!`!@````C1`$`*P``
M`#Q$`0`A````:$0!`!\```"*1`$`*P```*I$`0`F````UD0!`"<```#]1`$`
M.@```"5%`0`=````8$4!`!$```!^10$`,P```)!%`0`E````Q$4!`"<```#J
M10$`(````!)&`0`?````,T8!`#````!31@$`:0```(1&`0`Q````[D8!`$$`
M```@1P$`,P```&)'`0`E````ED<!`#T```"\1P$`90```/I'`0!-````8$@!
M`"D```"N2`$`*P```-A(`0`O````!$D!`"X````T20$`,````&-)`0!4````
ME$D!`%H```#I20$`2````$1*`0!*````C4H!`#(```#82@$`+P````M+`0`L
M````.TL!`"T```!H2P$`<0```)9+`0!F````"$P!`&\```!O3`$`LP```-],
M`0`7````DTT!`"4```"K30$`,@```-%-`0`I````!$X!`#X````N3@$`(@``
M`&U.`0!2````D$X!`"4```#C3@$`"P````E/`0"Q````%4\!`$4```#'3P$`
M(0````U0`0`P````+U`!`"4```!@4`$`'````(90`0`Q````HU`!``<```#5
M4`$`!P```-U0`0`$````Y5`!``T```#J4`$`"P```/A0`0`.````!%$!``L`
M```340$`!0```!]1`0`0````)5$!``(````V40$`60```#E1`0`#````DU$!
M``4```"740$`$@```)U1`0`$````L%$!``<```"U40$`"````+U1`0`%````
MQE$!``,```#,40$`$````-!1`0`,````X5$!`!,```#N40$`#0````)2`0`"
M````$%(!``<````34@$`!@```!M2`0`4````(E(!``P````W4@$`&````$12
M`0`&````75(!`!(```!D4@$`#````'=2`0`#````A%(!`"H```"(4@$`!```
M`+-2`0`&````N%(!``<```"_4@$`'P```,=2`0`U````YU(!`"X````=4P$`
M+P```$Q3`0`7````?%,!`"(```"44P$`)0```+=3`0`@````W5,!`!L```#^
M4P$`&````!I4`0`D````,U0!`!\```!85`$`&@```'A4`0`A````DU0!`"``
M``"U5`$`&@```-94`0`R````\50!`!H````D50$`+P```#]5`0`K````;U4!
M`!\```";50$`(P```+M5`0`?````WU4!`!H```#_50$`(0```!I6`0`E````
M/%8!`"8```!B5@$`)0```(E6`0`D````KU8!`!@```#45@$`'0```.U6`0`D
M````"U<!`!@````P5P$`(@```$E7`0`L````;%<!`"\```"95P$`%0```,E7
M`0`E````WU<!`#P````%6`$`'P```$)8`0`C````8E@!`!\```"&6`$`(```
M`*98`0`:````QU@!`!@```#B6`$`)@```/M8`0`>````(ED!`"D```!!60$`
M'@```&M9`0`Q````BED!``D```"\60$`#````,99`0`7````TUD!`"\```#K
M60$`)````!M:`0`'````0%H!``\```!(6@$`%````%A:`0`.````;5H!``T`
M``!\6@$`)````(I:`0`%````KUH!``<```"U6@$`(@```+U:`0`E````X%H!
M`!H````&6P$`'0```"%;`0`:````/UL!``<```!:6P$`QP```&);`0`+````
M*EP!`!4````V7`$`!@```$Q<`0`)````4UP!``L```!=7`$`#0```&E<`0`7
M````=UP!``8```"/7`$`,P```)9<`0`3````REP!`!,```#>7`$`!P```/)<
M`0`/````^EP!``<````*70$`,@```!)=`0`$````15T!`"$```!*70$`$P``
M`&Q=`0`,````@%T!`!$```"-70$`,@```)]=`0`6````TET!``@```#I70$`
M'0```/)=`0`)````$%X!``H````:7@$`%````"5>`0`*````.EX!`!T```!%
M7@$`"````&->`0`-````;%X!`#H```!Z7@$`'P```+5>`0`(````U5X!`!H`
M``#>7@$`)P```/E>`0`&````(5\!`!4````H7P$`!P```#Y?`0`(````1E\!
M``D```!/7P$`/P```%E?`0`'````F5\!``\```"A7P$`#@```+%?`0`0````
MP%\!``D```#17P$`"0```-M?`0`(````Y5\!`!,```#N7P$`!P````)@`0`9
M````"F`!``H````D8`$`%P```"]@`0`4````1V`!``H```!<8`$`#````&=@
M`0`7````=&`!``0```",8`$`*@```)%@`0`,````O&`!`!$```#)8`$`!P``
M`-M@`0`"````XV`!`!````#F8`$`&````/=@`0`+````$&$!``,````<80$`
M"````"!A`0`&````*6$!``<````P80$`#0```#AA`0`+````1F$!`!0```!2
M80$`%0```&=A`0`.````?6$!`!4```",80$`+P```*)A`0`@````TF$!`!P`
M``#S80$`%0```!!B`0`,````)F(!`#$````S8@$`"0```&5B`0`.````;V(!
M`#L```!^8@$`%0```+IB`0`%````T&(!`!(```#68@$`/P```.EB`0`2````
M*6,!``H````\8P$`!@```$=C`0`$````3F,!``0```!38P$`"@```%AC`0`3
M````8V,!``4```!W8P$`!@```'UC`0`&````A&,!``@```"+8P$`!````)1C
M`0`,````F6,!``H```"F8P$`.0```+%C`0`N````ZV,!`"D````:9`$`"@``
M`$1D`0`%````3V0!``P```!59`$`#````&)D`0`-````;V0!`!@```!]9`$`
M&0```)9D`0`?````L&0!`!T```#09`$`$0```.YD`0`"`````&4!``0````#
M90$`"@````AE`0`&````$V4!``4````:90$``P```"!E`0`,````)&4!`$4`
M```Q90$`,@```'=E`0`Q````JF4!`#,```#<90$`&@```!!F`0`T````*V8!
M`"@```!@9@$`4P```(EF`0`9````W68!`!\```#W9@$`<@```!=G`0`@````
MBF<!`#4```"K9P$`(0```.%G`0!%`````V@!`#````!):`$`*````'IH`0`I
M````HV@!`"8```#-:`$`8````/1H`0`E````56D!`"@```![:0$`*````*1I
M`0`B````S6D!`"L```#P:0$`,````!QJ`0`2````36H!`!,```!@:@$`$```
M`'1J`0!Y````A6H!``D```#_:@$`H0````EK`0!S````JVL!`'P````?;`$`
M*P```)QL`0!4````R&P!`!<````=;0$`)P```#5M`0`6````76T!``\```!T
M;0$`%P```(1M`0`?````G&T!`$````"\;0$`'P```/UM`0`<````'6X!`%$`
M```Z;@$`&@```(QN`0`4````IVX!``H```"\;@$`!0```,=N`0`&````S6X!
M``@```#4;@$`!0```-UN`0`2````XVX!``P```#V;@$`$`````-O`0`3````
M%&\!`!T````H;P$`#P```$9O`0`;````5F\!`"0```!R;P$`#P```)=O`0`*
M````IV\!``0```"R;P$`"0```+=O`0`+````P6\!`!H```#-;P$`(@```.AO
M`0`(````"W`!``<````4<`$`!0```!QP`0`4````(G`!`"D````W<`$`!P``
M`&%P`0`(````:7`!``\```!R<`$`&````()P`0`4````FW`!``@```"P<`$`
M#````+EP`0`/````QG`!``<```#6<`$`!@```-YP`0`4````Y7`!``8```#Z
M<`$`"0````%Q`0`*````"W$!``8````6<0$`#````!UQ`0`1````*G$!``,`
M```\<0$`"````$!Q`0`$````27$!`!D```!.<0$`$0```&AQ`0`*````>G$!
M`!@```"%<0$`$P```)YQ`0`<````LG$!`!$```#/<0$`&@```.%Q`0`$````
M_'$!``\````!<@$`!P```!%R`0`%````&7(!``0````?<@$`&0```"1R`0`'
M````/G(!``(```!&<@$``@```$ER`0`1````3'(!``D```!><@$`"````&AR
M`0`&````<7(!`!(```!X<@$`%P```(MR`0`&````HW(!`"$```"J<@$`!0``
M`,QR`0`G````TG(!``(```#Z<@$`!````/UR`0`/`````G,!`!,````2<P$`
M!P```"9S`0`"````+G,!``<````Q<P$`$0```#ES`0`&````2W,!`"$```!2
M<P$`&````'1S`0`&````C7,!`!,```"4<P$`$````*AS`0`>````N7,!`!(`
M``#8<P$``@```.MS`0`&````[G,!``P```#U<P$`"0````)T`0`1````#'0!
M`"(````>=`$`!P```$%T`0`'````270!``L```!1=`$`!0```%UT`0`"````
M8W0!``L```!F=`$`?`$``')T`0`/````[W4!`!(```#_=0$`#0```!)V`0`&
M````('8!``D````G=@$`!P```#%V`0`"````.78!``,````\=@$``0```$!V
M`0`9````0G8!`!\```!<=@$`,@```'QV`0`O````KW8!`"@```#?=@$`+0``
M``AW`0`9````-G<!`"L```!0=P$`"@```'QW`0`N````AW<!`!8```"V=P$`
M"@```,UW`0`4````V'<!``4```#M=P$`+@```/-W`0`3````(G@!``L````V
M>`$`&@```$)X`0`-````77@!``X```!K>`$`F0```'IX`0`-````%'D!``H`
M```B>0$`%P```"UY`0`.````17D!`!$```!4>0$`#````&9Y`0`6````<WD!
M``P```"*>0$`!@```)=Y`0"=````GGD!``H````\>@$`#P```$=Z`0`5````
M5WH!`!$```!M>@$`$P```']Z`0`3````DWH!``@```"G>@$`"0```+!Z`0`V
M````NGH!`"0```#Q>@$`.````!9[`0!#````3WL!`&4```"3>P$`8@```/E[
M`0!K````7'P!`&@```#(?`$`.@```#%]`0`/````;'T!`!4```!\?0$`#@``
M`))]`0`3````H7T!`!D```"U?0$`!0```,]]`0`)````U7T!`!$```#??0$`
M#````/%]`0`-````_GT!``T````,?@$`-````!I^`0`Q````3WX!``D```"!
M?@$`%````(M^`0`4````H'X!``P```"U?@$`*@```,)^`0`-````[7X!`#4`
M``#[?@$`!@```#%_`0`9````.'\!`!X```!2?P$`#````'%_`0`,````?G\!
M`!$```"+?P$`(P```)U_`0`H````P7\!`!(```#J?P$`#@```/U_`0`/````
M#(`!``H````<@`$`+P```">``0`9````5X`!`!D```!Q@`$`#@```(N``0!<
M````FH`!`#H```#W@`$`*@```#*!`0`4````78$!``D```!R@0$`"P```'R!
M`0`T````B($!``X```"]@0$`"````,R!`0`*````U8$!``<```#@@0$`!P``
M`.B!`0`%````\($!``<```#V@0$`"P```/Z!`0`%````"H(!`"$````0@@$`
M$````#*"`0`5````0X(!``\```!9@@$`$0```&F"`0`/````>X(!`!L```"+
M@@$`-````*>"`0`)````W((!`!<```#F@@$`%@```/Z"`0`8````%8,!`"$`
M```N@P$`%P```%"#`0`1````:(,!``\```!Z@P$`'P```(J#`0`E````JH,!
M``<```#0@P$`!@```-B#`0`'````WX,!``T```#G@P$`"0```/6#`0`*````
M_X,!``D````*A`$`$@```!2$`0`:````)X0!``H```!"A`$`%0```$V$`0`9
M````8X0!``\```!]A`$`+````(V$`0`'````NH0!`!$```#"A`$`!0```-2$
M`0`6````VH0!`!(```#QA`$`$@````2%`0`N````%X4!`#X```!&A0$`/@``
M`(6%`0`)````Q(4!``<```#.A0$`$P```-:%`0`$````ZH4!``4```#OA0$`
M#@```/6%`0`.````!(8!`!<````3A@$`1P```"N&`0`6````<X8!`"8```"*
MA@$`*P```+&&`0`L````W88!`#0````*AP$`"0```#^'`0`&````28<!``D`
M``!0AP$`!P```%J'`0`X````8H<!`#H```";AP$`-P```-:'`0!<````#H@!
M`#8```!KB`$`-@```**(`0!'````V8@!`$L````AB0$`-@```&V)`0!.````
MI(D!`"P```#SB0$`+@```""*`0!-````3XH!`#8```"=B@$`/````-2*`0`N
M````$8L!`!@```!`BP$`'````%F+`0`S````=HL!`"T```"JBP$`+0```-B+
M`0`V````!HP!`!,````]C`$`"@```%&,`0`,````7(P!``4```!IC`$`#@``
M`&^,`0`?````?HP!`"8```">C`$`!P```,6,`0`'````S8P!`!4```#5C`$`
M"@```.N,`0`(````]HP!`#,```#_C`$`"@```#.-`0`#````/HT!``L```!"
MC0$`!P```$Z-`0`'````5HT!``8```!>C0$`!0```&6-`0`(````:XT!``8`
M``!TC0$`(@```'N-`0`*````GHT!``L```"IC0$`%0```+6-`0`[````RXT!
M`"<````'C@$`-````"^.`0`2````9(X!``X```!WC@$`!@```(:.`0`'````
MC8X!``<```"5C@$`"@```)V.`0`%````J(X!`!$```"NC@$`!@```,".`0`2
M````QXX!``4```#:C@$`"````.".`0`(````Z8X!``X```#RC@$`!@````&/
M`0`I````"(\!`!$````RCP$`"````$2/`0`1````38\!``P```!?CP$`!P``
M`&R/`0`#````=(\!``,```!XCP$`&@```'R/`0`8````EX\!`"H```"PCP$`
M!@```-N/`0`%````XH\!``<```#HCP$`!P```/"/`0!E````^(\!`"<```!>
MD`$`.````(:0`0`I````OY`!`"(```#ID`$`!@````R1`0`(````$Y$!`!T`
M```<D0$`)0```#J1`0`G````8)$!`#0```"(D0$`*````+V1`0`M````YI$!
M`&(````4D@$`-@```'>2`0`*````KI(!``D```"YD@$`"0```,.2`0`4````
MS9(!`!8```#BD@$`#````/F2`0`"````!I,!``X````)DP$`%````!B3`0`0
M````+9,!`!0````^DP$`$P```%.3`0`.````9Y,!`!4```!VDP$`!P```(R3
M`0`8````E),!`!L```"MDP$`&````,F3`0`;````XI,!`!D```#^DP$`!```
M`!B4`0`'````'90!`!0````EE`$`6````#J4`0`<````DY0!`'(```"PE`$`
M!P```".5`0`5````*Y4!``4```!!E0$`!0```$>5`0`;````394!`!@```!I
ME0$`"P```(*5`0`4````CI4!`!H```"CE0$`'@```+Z5`0`[````W94!``X`
M```9E@$`+````"B6`0`'````598!`!L```!=E@$`#P```'F6`0`2````B98!
M``X```"<E@$`&````*N6`0`0````Q)8!`!8```#5E@$`$P```.R6`0`.````
M`)<!``4````/EP$`#P```!67`0`&````)9<!`!@````LEP$`%0```$67`0`/
M````6Y<!``@```!KEP$`!0```'27`0`1````>I<!`!(```",EP$`"0```)^7
M`0`7````J9<!``8```#!EP$`!P```,B7`0`1````T)<!``H```#BEP$`#```
M`.V7`0`'````^I<!``@````"F`$`"P````N8`0`)````%Y@!``L````AF`$`
M'P```"V8`0!)````39@!`"4```"7F`$`#0```+V8`0`4````RY@!``4```#@
MF`$`(````.:8`0`2````!YD!`!,````:F0$`$0```"Z9`0`Z````0)D!`$H`
M``![F0$`)P```,:9`0`)````[ID!`#P```#XF0$`"````#6:`0`J````/IH!
M`!$```!IF@$`"0```'N:`0`*````A9H!``8```"0F@$`!@```)>:`0`)````
MGIH!`!(```"HF@$`"P```+N:`0`0````QYH!``L```#8F@$`"@```.2:`0`/
M````[YH!`"P```#_F@$`+````"R;`0`M````69L!`"X```"'FP$`(@```+:;
M`0`E````V9L!`"(```#_FP$`)@```"*<`0`V````29P!`"X```"`G`$`)@``
M`*^<`0`H````UIP!`"0```#_G`$`,0```"2=`0!%````5IT!`$````"<G0$`
M-0```-V=`0`T````$YX!`#X```!(G@$`)@```(>>`0`E````KIX!`#P```#4
MG@$`)0```!&?`0`5````-Y\!`#D```!-GP$`)0```(>?`0`G````K9\!`!0`
M``#5GP$`R@```.J?`0`;````M:`!`#$```#1H`$`,`````.A`0`S````-*$!
M`#$```!HH0$`)P```)JA`0`H````PJ$!`"L```#KH0$`,@```!>B`0`U````
M2J(!`$L```"`H@$`-````,RB`0"D`````:,!`"<```"FHP$`'0```,ZC`0`F
M````[*,!`#,````3I`$`,0```$>D`0!.````>:0!`%4```#(I`$`#0```!ZE
M`0`$````+*4!``8````QI0$`!0```#BE`0`/````/J4!``4```!.I0$`#0``
M`%2E`0`1````8J4!`!8```!TI0$`'````(NE`0`'````J*4!``0```"PI0$`
M$````+6E`0`1````QJ4!``L```#8I0$`"@```.2E`0`1````[Z4!``T````!
MI@$`$@````^F`0`-````(J8!`#H````PI@$`!@```&NF`0`0````<J8!``8`
M``"#I@$`$0```(JF`0`7````G*8!`!L```"TI@$`#P```-"F`0`"````X*8!
M``T```#CI@$`20```/&F`0`+````.Z<!``P```!'IP$`'````%2G`0`%````
M<:<!`!<```!WIP$`$@```(^G`0`#````HJ<!`!$```"FIP$`$````+BG`0`)
M````R:<!`!$```#3IP$`$````.6G`0`+````]J<!`!$````"J`$`%0```!2H
M`0`1````*J@!``P````\J`$`%````$FH`0`+````7J@!``X```!JJ`$`$@``
M`'FH`0`.````C*@!`!$```";J`$`$P```*VH`0`:````P:@!``X```#<J`$`
M$````.NH`0`K````_*@!`"$````HJ0$`$0```$JI`0`<````7*D!`$0```!Y
MJ0$`#0```+ZI`0`?````S*D!`!0```#LJ0$`&0````&J`0`6````&ZH!``D`
M```RJ@$`0P```#RJ`0`?````@*H!`"H```"@J@$`+0```,NJ`0`4````^:H!
M`!`````.JP$`"0```!^K`0`4````*:L!``L````^JP$`-@```$JK`0`U````
M@:L!``H```"WJP$`%0```,*K`0`I````V*L!`!<````"K`$`%@```!JL`0`6
M````,:P!``H```!(K`$`#0```%.L`0`+````8:P!`"````!MK`$`&0```(ZL
M`0`<````J*P!`#(```#%K`$`&````/BL`0`9````$:T!`!@````KK0$`"```
M`$2M`0`\````3:T!``L```"*K0$`*0```):M`0`*````P*T!`%@```#+K0$`
M#@```"2N`0`+````,ZX!``X````_K@$`"0```$ZN`0`;````6*X!``@```!T
MK@$`%````'VN`0`B````DJX!``D```"UK@$`#````+^N`0`V````S*X!`!$`
M```#KP$`!@```!6O`0`&````'*\!`%4````CKP$``P```'FO`0`'````?:\!
M``D```"%KP$`#````(^O`0`0````G*\!``\```"MKP$`%````+VO`0`5````
MTJ\!`!L```#HKP$`%@````2P`0`=````&[`!`!L````YL`$`"0```%6P`0`&
M````7[`!``L```!FL`$`"P```'*P`0`"````?K`!``8```"!L`$`$P```(BP
M`0`O````G+`!`!<```#,L`$`%0```.2P`0`*````^K`!`!$````%L0$`%```
M`!>Q`0`<````++$!``H```!)L0$`.0```%2Q`0`W````CK$!``@```#&L0$`
M$@```,^Q`0`+````XK$!``\```#NL0$`A@```/ZQ`0`C````A;(!`"````"I
ML@$`!P```,JR`0`1````TK(!``<```#DL@$`!0```.RR`0`<````\K(!`"T`
M```/LP$`,P```#VS`0`?````<;,!`"L```"1LP$`'0```+VS`0`E````V[,!
M`!\````!M`$`%P```"&T`0`'````.;0!``<```!!M`$`!@```$FT`0`&````
M4+0!``\```!7M`$`#@```&>T`0`0````=K0!``X```"'M`$`%0```):T`0`/
M````K+0!``L```"\M`$`$P```,BT`0`(````W+0!`!$```#EM`$`!@```/>T
M`0`(````_K0!`!4````'M0$`#P```!VU`0`C````+;4!`$4```!1M0$`%```
M`)>U`0`)````K+4!``X```"VM0$`'P```,6U`0`@````Y;4!`"<````&M@$`
M)@```"ZV`0`8````5;8!`!<```!NM@$`(````(:V`0`8````I[8!`!8```#`
MM@$`"0```->V`0`9````X;8!``L```#[M@$`%`````>W`0`#````'+<!``4`
M```@MP$`!P```":W`0`.````+K<!`!`````]MP$`#0```$ZW`0`8````7+<!
M`!````!UMP$`$0```(:W`0`/````F+<!``0```"HMP$`!P```*VW`0`:````
MM;<!`!L```#0MP$`"````.RW`0`1````];<!`!0````'N`$`#@```!RX`0`G
M````*[@!`!H```!3N`$`(````&ZX`0`C````C[@!`!0```"SN`$`$0```,BX
M`0`&````VK@!`!D```#AN`$`!P```/NX`0!'`````[D!`#<```!+N0$`2@``
M`(.Y`0!3````SKD!`$X````BN@$`/@```'&Z`0!1````L+H!`!D````"NP$`
M!P```!R[`0`)````)+L!`!`````NNP$`$````#^[`0`*````4+L!``<```!;
MNP$`"P```&.[`0`&````;[L!`!@```!VNP$`#@```(^[`0`&````GKL!`"H`
M``"ENP$`*````-"[`0`0````^;L!`)L````*O`$`&P```*:\`0`+````PKP!
M``<```#.O`$`#P```-:\`0`(````YKP!``H```#OO`$`!0```/J\`0`(````
M`+T!`#8````)O0$`"````$"]`0`2````2;T!``,```!<O0$`!@```&"]`0`'
M````9[T!`!8```!OO0$`$````(:]`0`2````E[T!`!T```"JO0$``@```,B]
M`0`$````R[T!``,```#0O0$`%````-2]`0`*````Z;T!``\```#TO0$`!0``
M``2^`0`C````"KX!``@````NO@$`!@```#>^`0`;````/KX!``\```!:O@$`
M!P```&J^`0`(````<KX!``4```![O@$`"0```(&^`0`/````B[X!`!$```";
MO@$``@```*V^`0`&````L+X!``\```"WO@$`$@```,>^`0`0````VKX!``D`
M``#KO@$`$0```/6^`0`&````![\!`!,````.OP$`"P```"*_`0`'````+K\!
M`!@````VOP$`,````$^_`0!-````@+\!`"L```#.OP$`+0```/J_`0`&````
M*,`!``D````OP`$`!````#G``0`)````/L`!``D```!(P`$`%P```%+``0`,
M````:L`!``8```!WP`$`#0```'[``0`'````C,`!``0```"4P`$`00```)G`
M`0!(````V\`!`$$````DP0$`)P```&;!`0`%````CL$!``T```"4P0$`!P``
M`*+!`0`(````JL$!``D```"SP0$`&P```+W!`0`9````V<$!`!4```#SP0$`
M!@````G"`0`%````$,(!`!`````6P@$`"````"?"`0`*````,,(!`",````[
MP@$`!````%_"`0`'````9,(!`"<```!LP@$`!@```)3"`0`)````F\(!`!,`
M``"EP@$`$P```+G"`0`(````S<(!``D```#6P@$`!0```.#"`0!'````YL(!
M`#0````NPP$`00```&/#`0`R````I<,!`$D```#8PP$`.P```"+$`0`L````
M7L0!`#X```"+Q`$`+P```,K$`0`]````^L0!`#$````XQ0$`$````&K%`0`1
M````>\4!``L```"-Q0$`,@```)G%`0`A````S,4!`!\```#NQ0$`'@````[&
M`0`'````+<8!``D````UQ@$`"@```#_&`0`'````2L8!`"D```!2Q@$`+```
M`'S&`0`]````J<8!``P```#GQ@$`(P```/3&`0`V````&,<!`!8```!/QP$`
M%0```&;'`0`(````?,<!``L```"%QP$`#````)''`0`0````GL<!`!<```"O
MQP$`10```,?'`0!\````#<@!`&<```"*R`$`#0```/+(`0`0`````,D!`!$`
M```1R0$`%````"/)`0`5````.,D!`!<```!.R0$`"````&;)`0`1````;\D!
M``H```"!R0$`$P```(S)`0`2````H,D!`!4```"SR0$`+@```,G)`0`M````
M^,D!`)<````FR@$`$0```+[*`0`%````T,H!`!4```#6R@$`00```.S*`0`)
M````+LL!`#D````XRP$`"P```'++`0`+````?LL!`"4```"*RP$`&````+#+
M`0`/````R<L!``X```#9RP$`%````.C+`0`9````_<L!`"T````7S`$`+@``
M`$7,`0`J````=,P!`"H```"?S`$`)@```,K,`0`H````\<P!`!X````:S0$`
M00```#G-`0`5````>\T!`!0```"1S0$`%P```*;-`0`6````OLT!`!$```#5
MS0$`%P```.?-`0`6````_\T!`!0````6S@$`%````"O.`0`[````0,X!`!D`
M``!\S@$`&@```);.`0`Z````L<X!`!,```#LS@$`!@````#/`0`0````!\\!
M`"T````8SP$`%````$;/`0`5````6\\!`!4```!QSP$`(````(?/`0`>````
MJ,\!`!P```#'SP$`'````.3/`0`G`````=`!`!,````IT`$`(````#W0`0`F
M````7M`!`"````"%T`$`&0```*;0`0`=````P-`!`!0```#>T`$`'````//0
M`0`<````$-$!`"$````MT0$`&0```$_1`0`*````:=$!`!(```!TT0$`&P``
M`(?1`0`$````H]$!``<```"HT0$``@```+#1`0`+````L]$!``4```"_T0$`
M$@```,71`0`&````V-$!``8```#?T0$`!P```.;1`0`&````[M$!``<```#U
MT0$`!0```/W1`0`%`````](!`!4````)T@$`!@```!_2`0`&````)M(!``4`
M```MT@$`!0```#/2`0`*````.=(!`!$```!$T@$`"@```%;2`0`6````8=(!
M`!0```!XT@$`"@```(W2`0`7````F-(!``4```"PT@$`-0```+;2`0`2````
M[-(!`!$```#_T@$`&@```!'3`0`/````+-,!``T````\TP$`$````$K3`0`T
M````6],!``4```"0TP$`"````);3`0`G````G],!`!,```#'TP$`$````-O3
M`0`&````[-,!``H```#STP$`4@```/[3`0`-````4=0!``8```!?U`$`(@``
M`&;4`0`0````B=0!`!L```":U`$`$````+;4`0`5````Q]0!`!$```#=U`$`
M&@```._4`0`4````"M4!``8````?U0$`!0```";5`0`,````+-4!`"8````Y
MU0$`!P```&#5`0`)````:-4!`!(```!RU0$`%P```(75`0`'````G=4!``D`
M``"EU0$`$0```*_5`0`%````P=4!``<```#'U0$`%@```,_5`0`-````YM4!
M``\```#TU0$`#0````36`0`6````$M8!`!@````IU@$`#P```$+6`0`1````
M4M8!``P```!DU@$`&````''6`0`,````BM8!``<```"7U@$`%````)_6`0!"
M````M-8!``@```#WU@$`#`````#7`0`M````#=<!`!4````[UP$`%0```%'7
M`0`-````9]<!``P```!UUP$`"0```(+7`0`'````C-<!``<```"4UP$`"@``
M`)S7`0`)````I]<!``X```"QUP$`$````,#7`0`I````T=<!`"4```#[UP$`
M*@```"'8`0`*````3-@!``@```!7V`$`"@```&#8`0`,````:]@!``T```!X
MV`$`"0```(;8`0`.````D-@!`#4```"?V`$`!0```-78`0`.````V]@!`!H`
M``#JV`$`70````79`0`:````8]D!``X```!^V0$`!````(W9`0`$````DMD!
M`!H```"7V0$`&@```++9`0`:````S=D!``H```#HV0$``@```//9`0`$````
M]MD!`"4```#[V0$``P```"':`0`%````)=H!`"D````KV@$`"@```%7:`0`%
M````8-H!``8```!FV@$`"P```&W:`0`1````>=H!``8```"+V@$`!P```)+:
M`0`(````FMH!``0```"CV@$`!0```*C:`0!K````KMH!``H````:VP$`#0``
M`"7;`0`=````,]L!`!\```!1VP$`!0```'';`0`&````=]L!`!4```!^VP$`
M*0```)3;`0`V````OML!``X```#UVP$`"0````3<`0`8````#MP!`!,````G
MW`$`"@```#O<`0`(````1MP!`!<```!/W`$`.````&?<`0`?````H-P!`!X`
M``#`W`$`(P```-_<`0`7`````]T!``\````;W0$`KP```"O=`0"Q````V]T!
M``0```"-W@$`!P```)+>`0`(````FMX!``@```"CW@$`$0```*S>`0`/````
MOMX!``<```#.W@$`80```-;>`0`1````.-\!``\```!*WP$`#P```%K?`0`;
M````:M\!`%$```"&WP$`'````-C?`0`&````]=\!`!\```#\WP$`)@```!S@
M`0`'````0^`!``8```!+X`$`(````%+@`0`(````<^`!``D```!\X`$`(0``
M`(;@`0`@````J.`!`#P```#)X`$`"`````;A`0`*````#^$!`"<````:X0$`
M,@```$+A`0`P````=>$!`%0```"FX0$`&P```/OA`0`;````%^(!`!\````S
MX@$`'P```%/B`0`:````<^(!``,```".X@$`#````)+B`0`(````G^(!`!D`
M``"HX@$`#0```,+B`0`&````T.(!`!8```#7X@$`!@```.[B`0`(````]>(!
M``D```#^X@$`#`````CC`0`*````%>,!`!`````@XP$`00```#'C`0`)````
M<^,!`!H```!]XP$`%P```)CC`0`8````L.,!``D```#)XP$`%0```-/C`0`8
M````Z>,!`!8````"Y`$`#@```!GD`0`.````*.0!`!8````WY`$`%0```$[D
M`0`6````9.0!``H```![Y`$`'P```(;D`0`0````IN0!`!(```"WY`$`"0``
M`,KD`0`,````U.0!``D```#AY`$`&0```.OD`0`'````!>4!`!<````-Y0$`
M+@```"7E`0`&````5.4!``<```!;Y0$`!0```&/E`0`%````:>4!``<```!O
MY0$`$P```'?E`0`4````B^4!`"(```"@Y0$`(@```,/E`0`=````YN4!`!P`
M```$Y@$`(@```"'F`0`F````1.8!`!\```!KY@$``P```(OF`0`%````C^8!
M``\```"5Y@$`#P```*7F`0`3````M>8!``H```#)Y@$`"P```-3F`0`B````
MX.8!``T````#YP$`$````!'G`0`C````(N<!`!T```!&YP$`%@```&3G`0`(
M````>^<!``X```"$YP$`"0```)/G`0`0````G><!`!,```"NYP$`"@```,+G
M`0`)````S><!``4```#7YP$`!P```-WG`0`%````Y><!``0```#KYP$``@``
M`/#G`0!#````\^<!`#<````WZ`$`.P```&_H`0`P````J^@!`"T```#<Z`$`
M&0````KI`0`F````).D!`$8```!+Z0$`#````)+I`0`T````G^D!`#L```#4
MZ0$`1````!#J`0!$````5>H!`$P```":Z@$`#P```.?J`0`@````]^H!`!\`
M```8ZP$`)P```#CK`0`@````8.L!`!P```"!ZP$`'P```)[K`0`?````ONL!
M`"````#>ZP$`(````/_K`0`@````(.P!``P```!![`$`00```$[L`0!!````
MD.P!`$4```#2[`$`1@```!CM`0!#````7^T!`$````"C[0$`>0```.3M`0`5
M````7NX!`!````!T[@$`"0```(7N`0`?````C^X!`",```"O[@$`!P```-/N
M`0`>````V^X!`!0```#Z[@$`.@````_O`0`X````2N\!`"0```"#[P$`"P``
M`*CO`0!3````M.\!`$H````(\`$`!P```%/P`0`7````6_`!`!4```!S\`$`
M#P```(GP`0`0````F?`!`!@```"J\`$`!P```,/P`0`*````R_`!``@```#6
M\`$`$P```-_P`0`+````\_`!`!````#_\`$`#@```!#Q`0`2````'_$!``4`
M```R\0$`)````#CQ`0`=````7?$!``D```![\0$`!@```(7Q`0`4````C/$!
M`!(```"A\0$`#P```+3Q`0!(````Q/$!``<````-\@$`!@```!7R`0`2````
M'/(!``4````O\@$`!P```#7R`0`/````/?(!``<```!-\@$`-0```%7R`0`2
M````B_(!`"4```">\@$`!````,3R`0`[````R?(!`!8````%\P$`#@```!SS
M`0`H````*_,!`(<```!4\P$`&@```-SS`0!%````]_,!`"<````]]`$`$0``
M`&7T`0`(````=_0!`"4```"`]`$`#@```*;T`0`.````M?0!``P```#$]`$`
M$P```-'T`0`,````Y?0!`"````#R]`$`'````!/U`0`$````,/4!`!`````U
M]0$`#@```$;U`0`,````5?4!`!L```!B]0$`*@```'[U`0`5````J?4!`!$`
M``"_]0$`%@```-'U`0`1````Z/4!`!\```#Z]0$`"@```!KV`0`,````)?8!
M`!,````R]@$`$0```$;V`0`7````6/8!`!````!P]@$`'````('V`0`.````
MGO8!`!4```"M]@$`(@```,/V`0`-````YO8!``8```#T]@$`"````/OV`0`%
M````!/<!`"`````*]P$`!@```"OW`0`2````,O<!``@```!%]P$`$P```$[W
M`0`*````8O<!`"@```!M]P$`%0```);W`0!!````K/<!`!L```#N]P$`"P``
M``KX`0`,````%O@!`"4````C^`$`!0```$GX`0`6````3_@!``,```!F^`$`
M$0```&KX`0`%````?/@!``H```""^`$`)0```(WX`0`Y````L_@!``H```#M
M^`$`)@```/CX`0`3````'_D!``L````S^0$`'0```#_Y`0`4````7?D!``0`
M``!R^0$`"````'?Y`0`)````@/D!``@```"*^0$`"P```)/Y`0`(````G_D!
M``<```"H^0$`!P```+#Y`0`2````N/D!`"H```#+^0$`-P```/;Y`0`;````
M+OH!`"L```!*^@$`(P```';Z`0!!````FOH!`!L```#<^@$`*0```/CZ`0`D
M````(OL!`"T```!'^P$`3````'7[`0`H````POL!``<```#K^P$`"````//[
M`0`)````_/L!``@````&_`$`%0````_\`0`4````)?P!`"P````Z_`$`+P``
M`&?\`0`B````E_P!`#<```"Z_`$`/P```/+\`0`'````,OT!`!H````Z_0$`
M"0```%7]`0`,````7_T!`"X```!L_0$`$P```)O]`0`2````K_T!``T```#"
M_0$`"P```-#]`0`8````W/T!``D```#U_0$`$@```/_]`0`1````$OX!`!H`
M```D_@$`'````#_^`0`Y````7/X!``L```"6_@$`$````*+^`0`%````L_X!
M``@```"Y_@$`!0```,+^`0`:````R/X!``<```#C_@$`#P```.O^`0`&````
M^_X!``\````"_P$`$0```!+_`0`(````)/\!``X````M_P$`#@```#S_`0`3
M````2_\!``4```!?_P$`$````&7_`0`-````=O\!`#P```"$_P$`4@```,'_
M`0`(````%``"``L````=``(`(@```"D``@`*````3``"`"<```!7``(`&P``
M`'\``@`%````FP`"`!$```"A``(`$P```+,``@`7````QP`"``D```#?``(`
M#0```.D``@`2````]P`"`"H````*`0(`!@```#4!`@`-````/`$"``X```!*
M`0(`$````%D!`@`*````:@$"`#T```!U`0(`"0```+,!`@`@````O0$"`!``
M``#>`0(`%````.\!`@!`````!`("`"8```!%`@(`0@```&P"`@!#````KP("
M`#P```#S`@(`#P```#`#`@`*````0`,"``T```!+`P(`!P```%D#`@`2````
M80,"`!(```!T`P(`&0```(<#`@`*````H0,"`!X```"L`P(`$P```,L#`@`=
M````WP,"`!L```#]`P(`!P```!D$`@`7````(00"`"@````Y!`(`!@```&($
M`@`'````:00"`!````!Q!`(`%0```(($`@`7````F`0"``<```"P!`(`!P``
M`+@$`@`)````P`0"`!0```#*!`(`$@```-\$`@`3````\@0"`!,````&!0(`
M!@```!H%`@`%````(04"`!8````G!0(`&````#X%`@`1````5P4"``X```!I
M!0(`$@```'@%`@`&````BP4"``4```"2!0(`,0```)@%`@`H````R@4"`"4`
M``#S!0(`"````!D&`@`/````(@8"``8````R!@(`&@```#D&`@`9````5`8"
M`"L```!N!@(`"0```)H&`@`,````I`8"`"<```"Q!@(``P```-D&`@`<````
MW08"``4```#Z!@(`#0`````'`@`#````#@<"``P````2!P(`$P```!\'`@`+
M````,P<"`!<````_!P(`&````%<'`@`3````<`<"``4```"$!P(`"@```(H'
M`@`6````E0<"`!4```"L!P(`#@```,('`@`'````T0<"``P```#9!P(`"@``
M`.8'`@`0````\0<"`!`````""`(`70```!,(`@`F````<0@"`#P```"8"`(`
M$@```-4(`@`'````Z`@"``4```#P"`(`%@```/8(`@`>````#0D"`"8````L
M"0(`*0```%,)`@`&````?0D"``L```"$"0(`!0```)`)`@`4````E@D"`!0`
M``"K"0(`$P```,`)`@`<````U`D"`!\```#Q"0(`%@```!$*`@`>````*`H"
M`!````!'"@(`+0```%@*`@`5````A@H"``T```"<"@(`&@```*H*`@!N````
MQ0H"`"0````T"P(`(````%D+`@`K````>@L"`",```"F"P(`'P```,H+`@`C
M````Z@L"`"4````.#`(`'P```#0,`@`6````5`P"`!L```!K#`(`"@```(<,
M`@`)````D@P"``<```"<#`(`"````*0,`@`*````K0P"`!,```"X#`(`#P``
M`,P,`@`M````W`P"`!@````*#0(`'````",-`@`(````0`T"``H```!)#0(`
M4@```%0-`@!%````IPT"`$````#M#0(`>````"X.`@`N````IPX"``T```#6
M#@(`,````.0.`@`Q````%0\"``H```!'#P(`!P```%(/`@`-````6@\"`#H`
M``!H#P(`$P```*,/`@`4````MP\"`!0```#,#P(`1````.$/`@`M````)A`"
M`"<```!4$`(`$````'P0`@`R````C1`"`",```#`$`(`,P```.00`@`J````
M&!$"`#(```!#$0(`*P```'81`@`-````HA$"``D```"P$0(`$0```+H1`@`3
M````S!$"`!@```#@$0(`!P```/D1`@`W`````1("``P````Y$@(`!````$82
M`@`%````2Q("`!(```!1$@(`"````&02`@`&````;1("`!0```!T$@(`"@``
M`(D2`@`)````E!("``4```">$@(`$0```*02`@`1````MA("`!H```#($@(`
M'````.,2`@`5`````!,"`"$````6$P(`#0```#@3`@`'````1A,"`!(```!.
M$P(`*0```&$3`@`)````BQ,"``D```"5$P(`&P```)\3`@`H````NQ,"``X`
M``#D$P(`(0```/,3`@`T````%10"``D```!*%`(`"0```%04`@`2````7A0"
M``8```!Q%`(`!````'@4`@`B````?10"``T```"@%`(`#P```*X4`@`,````
MOA0"``@```#+%`(`"0```-04`@`(````WA0"``D```#G%`(`#0```/$4`@`2
M````_Q0"``8````2%0(`+0```!D5`@`9````1Q4"`!4```!A%0(`!P```'<5
M`@`0````?Q4"`"````"0%0(`#````+$5`@`#````OA4"`"4```#"%0(`(```
M`.@5`@`&````"18"``<````0%@(`!@```!@6`@![````'Q8"``D```";%@(`
M!0```*46`@`L````JQ8"`$8```#8%@(`(P```!\7`@`O````0Q<"`%````!S
M%P(`.@```,07`@`]````_Q<"`"0````]&`(`(````&(8`@`%````@Q@"``<`
M``")&`(`"````)$8`@`)````FA@"``<```"D&`(`"````*P8`@`2````M1@"
M``H```#(&`(`"0```-,8`@`+````W1@"``L```#I&`(`!P```/48`@`'````
M_1@"``@````%&0(`%`````X9`@`+````(QD"``8````O&0(`!0```#89`@`D
M````/!D"``8```!A&0(`+0```&@9`@`8````EAD"``@```"O&0(`%````+@9
M`@`)````S1D"`!,```#7&0(`"P```.L9`@`%````]QD"`!0```#]&0(`!0``
M`!(:`@`4````&!H"``8````M&@(`&@```#0:`@`*````3QH"`!P```!:&@(`
M"````'<:`@`&````@!H"`!(```"'&@(`)````)H:`@`+````OQH"``T```#+
M&@(`*@```-D:`@`A````!!L"`!P````F&P(`!0```$,;`@`*````21L"`!,`
M``!4&P(`&````&@;`@`#````@1L"`!,```"%&P(`"0```)D;`@`D````HQL"
M`"@```#(&P(`,P```/$;`@`H````)1P"`#4```!.'`(`+P```(0<`@`Q````
MM!P"`#(```#F'`(`9````!D=`@`6````?AT"`%P```"5'0(`.@```/(=`@!)
M````+1X"`&L```!W'@(`*@```.,>`@`5````#A\"`$$````D'P(`,0```&8?
M`@`W````F!\"`"T```#0'P(`'0```/X?`@!"````'"`"`-,!``!?(`(`(@``
M`#,B`@`7````5B("`$P```!N(@(`@````+LB`@`W````/","`"P```!T(P(`
M/P```*$C`@!>````X2,"`$H```!`)`(`*@```(LD`@`B````MB0"`!0```#9
M)`(`'P```.XD`@`A````#B4"`"`````P)0(`*P```%$E`@`D````?24"`",`
M``"B)0(`/@```,8E`@`B````!28"`!4````H)@(`-P```#XF`@`F````=B8"
M`"P```"=)@(`*P```,HF`@`:````]B8"`"T````1)P(`:0```#\G`@`V````
MJ2<"`$D```#@)P(`-P```"HH`@`M````8B@"`$````"0*`(`<````-$H`@!2
M````0BD"`"@```"5*0(`*P```+XI`@`U````ZBD"`#<````@*@(`-````%@J
M`@!K````C2H"`',```#Y*@(`6@```&TK`@!9````R"L"`#<````B+`(`*0``
M`%HL`@`I````A"P"`"\```"N+`(`>0```-XL`@!N````6"T"`'<```#'+0(`
MQ````#\N`@`6````!"\"`"<````;+P(`.````$,O`@`O````?"\"`$T```"L
M+P(`*@```/HO`@!C````)3`"`",```"),`(`"P```*TP`@"H````N3`"`$H`
M``!B,0(`*0```*TQ`@`X````US$"`"H````0,@(`(P```#LR`@`]````7S("
M``8```"=,@(`"P```*0R`@`$````L#("``H```"U,@(`#P```,`R`@`1````
MT#("``L```#B,@(`!@```.XR`@`1````]3("``0````',P(`9@````PS`@`%
M````<S,"``,```!Y,P(`%````'TS`@`$````DC,"``<```"7,P(`!@```)\S
M`@`%````IC,"``@```"L,P(`%0```+4S`@`,````RS,"`!$```#8,P(`$0``
M`.HS`@`#````_#,"``4`````-`(`!P````8T`@`2````#C0"``P````A-`(`
M%````"XT`@`&````0S0"`!4```!*-`(`#0```&`T`@`#````;C0"`"X```!R
M-`(`!````*$T`@`&````IC0"``<```"M-`(`)0```+4T`@!'````VS0"`#@`
M```C-0(`.0```%PU`@`8````EC4"`"<```"O-0(`*@```-<U`@`F`````C8"
M`!P````I-@(`(0```$8V`@`H````:#8"`",```"1-@(`(````+4V`@`D````
MUC8"`"8```#[-@(`(@```"(W`@`V````13<"`!T```!\-P(`,P```)HW`@`Y
M````SC<"`"8````(.`(`*@```"\X`@`H````6C@"`",```"#.`(`*````*<X
M`@`R````T#@"`"L````#.0(`,````"\Y`@`F````8#D"`"0```"'.0(`)0``
M`*PY`@`N````TCD"`"`````!.@(`)P```"(Z`@`W````2CH"`#H```"".@(`
M'````+TZ`@`F````VCH"`#T````!.P(`)P```#\[`@`K````9SL"`"@```"3
M.P(`*@```+P[`@`D````YSL"`!X````,/`(`*P```"L\`@`H````5SP"`#<`
M``"`/`(`+@```+@\`@`Y````YSP"``D````A/0(`$````"L]`@`8````/#T"
M`#(```!5/0(`)0```(@]`@`-````KCT"``\```"\/0(`%@```,P]`@`*````
MXST"``X```#N/0(`*@```/T]`@`(````*#X"``L````Q/@(`+P```#T^`@`Q
M````;3X"`"D```"?/@(`(@```,D^`@`D````[#X"``H````1/P(`[````!P_
M`@`,````"4`"`!8````60`(`"@```"U``@`-````.$`"`!(```!&0`(`%P``
M`%E``@`J````<4`"``8```"<0`(`4@```*-``@`:````]D`"`!H````100(`
M!P```"Q!`@`/````-$$"``@```!$00(`0@```$U!`@`'````D$$"`"T```"8
M00(`&@```,9!`@`3````X4$"`!0```#U00(`-`````I"`@`@````/T("``<`
M``!@0@(`)````&A"`@`(````C4("``D```"60@(`%P```*!"`@`*````N$("
M`!P```##0@(`"````.!"`@`B````Z4("`$@````,0P(`+@```%5#`@`'````
MA$,"`",```",0P(`)P```+!#`@`'````V$,"`!4```#@0P(`!P```/9#`@`(
M````_D,"``D````'1`(`0````!%$`@`'````4D0"``P```!:1`(`$P```&=$
M`@`/````>T0"``D```"+1`(`"````)5$`@`'````GD0"`!,```"F1`(`!@``
M`+I$`@`:````P40"``L```#<1`(`&@```.A$`@`4`````T4"``L````810(`
M#0```"1%`@`@````,D4"``4```!310(`-0```%E%`@`,````CT4"``\```"<
M10(`"P```*Q%`@`#````N$4"`!0```"\10(`(@```-%%`@`+````]$4"``,`
M````1@(`"`````1&`@`,````#48"``H````:1@(`$````"5&`@`.````-D8"
M`!(```!%1@(`$P```%A&`@`1````;$8"`!T```!^1@(`.````)Q&`@`A````
MU48"`!\```#W1@(`(0```!='`@`)````.4<"`#0```!#1P(`#````'A'`@`6
M````A4<"`#L```"<1P(`*````-A'`@`'`````4@"`!<````)2`(`0````"%(
M`@`3````8D@"`!,```!V2`(`"````(I(`@`$````DT@"``8```"82`(`#P``
M`)](`@`=````KT@"``<```#-2`(`"````-5(`@`)````WD@"``8```#H2`(`
M!@```.](`@`5````]D@"`!0````,20(`0@```"%)`@`S````9$D"`"D```"8
M20(`"@```,))`@`%````S4D"``P```#320(`#````.!)`@`-````[4D"`!L`
M``#[20(`'0```!=*`@`C````-4H"`"<```!92@(`$@```(%*`@`"````E$H"
M``0```"72@(`#P```)Q*`@`*````K$H"``4```"W2@(``@```+U*`@`-````
MP$H"`$@```#.2@(`-P```!=+`@`V````3TL"`$<```"&2P(`%@```,Y+`@`W
M````Y4L"`"P````=3`(`6@```$I,`@`7````I4P"`!P```"]3`(`@P```-I,
M`@`E````7DT"`#H```"$30(`(@```+]-`@`V````XDT"`#@````93@(`+0``
M`%).`@`L````@$X"`"P```"M3@(`9````-I.`@`J````/T\"`"X```!J3P(`
M+@```)E/`@`R````R$\"`#,```#[3P(`,@```"]0`@`6````8E`"``T```!Y
M4`(`#@```(=0`@"&````EE`"``D````=40(`K0```"=1`@!Q````U5$"`(4`
M``!'4@(`*P```,U2`@!<````^5("`!0```!64P(`*````&M3`@`6````E%,"
M`!````"K4P(`)````+Q3`@`B````X5,"`$(````$5`(`(````$=4`@`>````
M:%0"`%P```"'5`(`&@```.14`@`3````_U0"``H````350(`!0```!Y5`@`&
M````)%4"``@````K50(`!0```#15`@`6````.E4"``P```!150(`%0```%Y5
M`@`7````=%4"`"(```",50(`$````*]5`@`@````P%4"`"\```#A50(`#P``
M`!%6`@`,````(58"``0````N5@(`#````#-6`@`.````0%8"`"(```!/5@(`
M,0```')6`@`)````I%8"``<```"N5@(`!@```+96`@`9````O58"`#@```#7
M5@(`#P```!!7`@`&````(%<"`!4````G5P(`(0```#U7`@`;````7U<"``D`
M``![5P(`#````(57`@`4````DE<"``8```"G5P(`#````*Y7`@`8````NU<"
M``D```#45P(`"0```-Y7`@`-````Z%<"``8```#V5P(`"P```/U7`@`8````
M"5@"``$````B6`(`!@```"18`@`%````*U@"`"<````Q6`(`&P```%E8`@`*
M````=5@"`!D```"`6`(`%@```)I8`@`D````L5@"`!D```#66`(`(@```/!8
M`@`)````$UD"`!4````=60(`"````#-9`@`%````/%D"``<```!"60(`%P``
M`$I9`@`'````8ED"``(```!J60(``@```&U9`@`?````<%D"``X```"060(`
M"````)]9`@`(````J%D"`!<```"Q60(`&0```,E9`@`'````XUD"`"````#K
M60(`"0````Q:`@`K````%EH"``(```!"6@(`!@```$5:`@`/````3%H"`!D`
M``!<6@(`!0```'9:`@`!````?%H"``H```!^6@(`$P```(E:`@`'````G5H"
M`"````"E6@(`&0```,9:`@`*````X%H"`!<```#K6@(`$P````-;`@`A````
M%UL"`!(````Y6P(``@```$Q;`@`'````3UL"`!$```!76P(`!@```&E;`@`.
M````<%L"`#````!_6P(`"0```+!;`@`*````NEL"`!0```#%6P(`!0```-I;
M`@`"````X%L"``L```#C6P(``0`````````Q`@``@`<``+D"````````2```
M`,P!``#0`@``)@$``%H#``#8!0``?@`````````J"```Q`8``((!```J`@``
MQ@4``(@#``"*!P``8P,``/$%``#H`P``C@<``-,`````````O0$``"T'````
M````QP$``)D'`````````````-\!```_"```+`4``/H```#R!@``008``-4!
M```\!0``:`8```$%``!<!```K0(``+X`````````"P,`````````````3P0`
M`$T(``"%`0``-08``*P'``"9`@````````````!G`P``X@(``/`#````````
MD0$``#\$``#]`P``PP,``-,&``!7!0``500``-D!``#R`P``3P,``.4'``!P
M!P``Z`8``$P&```A!P``^@(``*L#``!L`@```````*\%````````S0$``)P$
M``!$`@``0@@``+P`````````^P$``$@%```9`P```````!8&``!W!```3`4`
M``````#4`0``(`$``%L!```Q!0``U@````````!?!0```````(D$``"%`@``
M``````````#Q!@``````````````````W`8``%@!``!6````.@,``(<"``!%
M````1P4``'<&``!V!P``0@,```````"J`P``(@$``-H#````````VP0``(T#
M``#N`@``+0@``'$%````````/P<````````U!```?@,``*T!```$"```>@(`
M`"\!``#)!```@@4``)<'``!(!P```````%X#``"E!0``_@<``'D#``#;!0``
M2@4``/````"?!0```````.D#```3`````````#H(```L````*08```````"'
M!P``4@`````````R"`````````````!_!@``I@```+`'``";`@``7P<``-D`
M``#/`@````````8!``":!@``0@4```````!7`P```````"X&``#9`@``S`(`
M`*\!```A"```+P8``+4'``"S`P```P(``$0(``!]````"00``&(!```2!P``
M`````-8"``!1!P``9`<``*`$````````P0```-X```!4`@``*@8``(\'````
M````(@4```````"!!P``X@0``,P#````````S@$`````````````T@(`````
M````````1@0```````!Z!P``;P(``$8&``#%`0``&@@````````K!0``7@``
M``````!L!P``-@@``'4'``#R!0`````````````E!P``Z@4````````8````
M7P0``)0$``!.`@```````*T#```+````5@8``,(```#B`0``E`<``/T%``##
M`@``;P,``$8```#=!0```````-L#``#W!0``;00```H(```;`0```````&D%
M``"3`0````````8&``"J`@``5@4```````")!@``O`<``"L'``!\!P``````
M`.\&``!,`P````````````#"!P``#@(``,("``#B!0```````'`"``!*!```
M/P8```````#&`@``&`0``)L```#O`0``K0<``!D'```*`@``;@(```\%````
M````00@``/('`````````````,`%``#N!```L@4```````"C!P``<P8``(,"
M````````Z@$``/@"``!E`P```P@``/8"```]`P``R@(``!((``!V````$P,`
M`.8%``"Z`P``S`0``.T$```(!P``FP4```````!'!```#````&$$```+!```
M5`0```````"8`````````$,&``",!```AP4``/X#```&!0```````!0(```Z
M!@``#@8```````"'`0``H0<``#4``````````````%$$```[`P``D@<``,``
M``"O!```TP,``+<!``#K!0``S`<``!,'``!-`@``<0$```````"2!```````
M`,@$``#/````Q04``*8&``!8!@``+P@````````%!@``X`4``'@%``#^`0``
M,`4``/@``````````````)0"```\!P``?P(```````":````U`8```D&``"+
M`P``@P$``+$$```S`P````````````!>!P``[0```(`&```X!0``NP<``#4#
M``#X`0``1`,``'L`````````*`4``,,$``!&`@``.00``&D'````````````
M`'8"`````````@<``'(!``"(!P``^P```!P!``!Z!@``+`$``)$$````````
M`````'('```*`0``D0```!4'``!.`````````!,%``#F!@``F04```````"Z
M````F`4``*L$```W"```[````#0%``#O!P```````'L%```N`````````#(%
M``")````X0<```````#\`0``=P4``(,&``!$!````````'D%````````+0$`
M`"`%``!6`@``80````````#A`P``F`8``$P'``!`!0``4P,````````U`0``
M8P4````````@!P``3@$``,`$```1!@``````````````````#`$``"8#``#:
M!@``LP8``.P"``"G!P``R`4``,,!```4!P``*@$``+4#``!3!@``5P$``'0#
M````````>`$``.4$``!S`@``2P```)L$``!\`0``L`0``%X&````````SP$`
M`(D#``#`!P``2P8```T```"5!```C@4```L&````````%0(``$T&``#K`@``
M`````/,'``!X`P``/`(``(('``"=!P````````````"8`@``L`$``/T```#9
M!0```````+4$````````C@$``"4````1````KP,``%@"````````W@$``!L'
M```;!0``4`(``!$#```M!````````*D&``!+!```UP(```\'``"R````0`,`
M`.@```#D`P``=`$``.,$``#$!0```````&$!``!W`0```````%$!``!F!0``
M`````+@```"J!0```````&T&``!=!```10<```````!X`@```00``"(```#H
M!```.`0``.T&``!=`0``E04```````#0!```OP4``/<```!;`P``<@(``(`!
M```(`P``&P8``+,!``!P````QP8``,@#``"?`@``J`$``#<#```4`P``S```
M``````#F````L0````````````````````````#'!P``BP<``"$!``!2!0``
M`````'L$`````P``<P$``)T$``!4!0``!@```)8!``#:!0``1@$``"("``"[
M`````````%<'``![!@```````+8'``!1!0``BP(``$H#``"Q!0``J04``(4'
M```Q!@```````(P"``#K`````````'<```"^`0``D`8``#H$````````````
M`$0'``#.!@``````````````````/04`````````````C04``-H!````````
M```````````%!P```````&0%``#9!````````+X&```G`0``H@8``"$"``!!
M````+`(``/`!```P"```G`(`````````````!P<```````"^`P```````"(#
M```7!````````)`"``!M````?````!@%````````HP,``+X'``"K`0``````
M``````"`!0``[0<``)8&``"G`0```````)L!``!2`0``/@0``"H'```*!P``
M'04``!`'``!Y!P``0@(``.X'`````````@,``"D(````````-04```,`````
M````!0$``+0!```@````'@8``.4```"Y!```>P$````````K`0```````#$`
M``!;`@`````````````Y!0```````(8&``"9````U`(`````````````7`$`
M`&L"``"7`P``>0$``!\``````````@@``*0`````````E@<``%@$````````
MN@8``-@```"Z!0``R`8```````"$`@``"P4``'D"``````````````````!&
M!P``@`(``(P'``"<````JP```(,```#5!@``S04``.H$````````\P8``*D"
M``":`0```````+4"```/`@``:`,``,$&``!T!```(P4``*<%````````?`4`
M````````````,@<```\```!(`0``0`@``&4````_`@``'P(``(\```!#`@``
M+08``'<"`````````````!8"`````````````)H#``"F!P``VP```$@(``"H
M`@``?`(``(H```!L````M`8``&H"``"5!@``!@(`````````````H0``````
M``#2!P```````*X!``!9!P```````,<```#S`P``A00``/,"````````]0``
M``````!4````(0,``!D(```_`P``+`@```````"`!````````!T$```;!```
M2@@``-(%``#M`0```````#4"``"&`0```````*P!``#<````QP0``#@!``""
M`@``:@4``)$&``#U`P``.P4``/0```!\!````````"T#``"M````(@@``.,'
M``!G!```#04``+(!``"&!P``X`,``*X$``"S!```J`,``$D$```6!```````
M`.@"``!K!```)P(``'4&``!T````I0<``-`%``#*!P``C`8``+`"``#U`0``
M`````/4$````````4`<``&H&```I`P````````````"@`0``#@4``.$&``"O
M!@``,P$``$`'``!/!P``K`,``($&````````20@``%`#``#(`@``%@@``)0&
M``">`P```````$D"``!+`P```````)8$``"Y````9`(`````````````&@8`
M`+L#````````B`4`````````````>00``$<(``!1````_P```*X'``"L`@``
M`````(<$``!7!@``]08``)D&``#-`P```````$\!``"7!0``[`0``%`!````
M````````````````````+@(``/$'`````````````/D%``".````4P0``*@'
M``"R!```Q`0``-($```Y"```00(``````````````````!@(``!W`P``5P0`
M`/P$````````#08```4````O`@``B@0``$,%``#K!P``S@4``-P"``"%!0``
M6@4``"<#``",````10@``&\%``"G````,`0``&H!``!B`````````.`'``"T
M!0``Z@(``#D"``````````````````!!`0```````!`"``!,!````````%D"
M``"A!````````'$&````````4@0``.(`````````&@,``/0&````````````
M`*\"``!)!0``J````'H```#N`P``M@0``.L!```0`P``<P0```````#``0``
MOP<``+<"``!6`P``]@4``-(```!'````)`@``*D'``#^!````````-H"````
M````I`,``#$!``!G!P``O04``-0'``#Z`P`````````'```W````B@,``/L#
M````````N`0``(<&```````````````````)`@``E@````````#5`P``````
M``$"```T!```(P0``(\&``!J````?0,``&8#``##!@``@@,`````````````
M)P<``"($``"5!P````0``+<'``!N`0```````,P&```8!@``;@<```````!)
M`P```````(L```#9`P``B@4``&X%``!!`P`````````````B!@``5@0``/4"
M````````NP8``+(&``#W!```"P(``$8%```<`P```````!``````````(P$`
M`/\%``!."````````)(!``!E`0``)0@```````"U````)P``````````````
M`````!$'`````````````'0'````````60```"T```#I!```````````````
M`````````-P!````````A@```.8"``#7!@```````&X$````````1`$``/H$
M````````E0$``,$'````````CP4```````"L!````````"`$````````,`(`
M`&@```!]`@``OP,``!0&``#"`P``.@```$<'``#(!P``0@$````````T`P``
MT@$```````"_`0``'`@```@&``!%`0``UP$``$$'````````,P@``#H'``!B
M`P```````+L!``"B`0``K`8``#D'```R`P``FP8``.0'````````_P(``%``
M``#``P``'0```,0```"F!```6`<``!`!```M!0``.P<```````![`P``C0``
M`-8$````````;`8``(0&``#Q````O`0``/$$``"!!0``*@0``(T'```[````
MWP4``/`'`````````````$`````8!P``T0<``/P"``#-!@``3@,```D%````
M````P@8``#8#``!F`0``SP<``*X%````````(08```````#8!```W0```'X&
M```C"```!04``"0"```>!0```````.`"``"#`P``70,``$P"```N!P``_0<`
M`!L(``"5`@``J@<``/`%```R`````````/`"``"B`@````````(%``"E`@``
M^P8``*8"```L!@``]P,``,D#``````````````````#+!```TP0``(T"``#C
M`@```````$T%``"_`@```````&H$````````U`4``+\```"1`@``8P(``$L%
M``"9`P``6P````````!_!0``?@(``-8#```D!P``7P```-X"``#\!@``;`0`
M`'0"``"=`P``J`0``#T````$`0``D`0``+<```!R!@``[P0``,T`````````
M``````````"8!```_`,``&($``!J`P``-`8``)`%`````````````&D$````
M````@P<```X'````````>@4``&`#```V!@```````*$#````````IP(``.0!
M``#@!@``XP```,\$``"/`@``Y`0``!<"``!#!P``*`<``-P#``#Q`0``=@0`
M`,<"````````*0<``+X"````````Z04``$\```"0`0``````````````````
M!P4``'@`````````F@0``*$"``!]`0``0P$``*D!```="````````&<```!Q
M!P``"@0``$(`````````,P```/X```````````````<&```K`@``!`4``%L%
M````````/@4``%P&```[`@``/`@``.4#```\!@``'@@``.L&````````-@<`
M`%X%``!_!```=00```````"!`@``Q@0``*4&``#D!0``<`$```\(```2````
M`````"D```".!@``Z`$``&4$````````'````,8'``#"`0``]0<``#,%````
M`````````$D````"!@```````#\!`````````````-,"``!D!@``9@(`````
M`````````````,\%```2`0```````,($`````````````)$%``#W!P``%@<`
M``8'`````````````!0`````````[04``#$$``#G!@`````````````3`0``
M`````*P```!5`@``CP,```\&``"=````"@4````"````````C08``-`'``#0
M!@``H@4```````#X!```````````````````R08``#D&```7"```````````
M``!K!@``]`(``-4```#8`@``0P0``.\#```E`P``XP4``)P!``#R````````
M```````N!0``2P(```````````````````````!N````W@8``*$&````````
M'@,```````#I!P``[`8``(4#````````-`(```````!$````'@(```````"6
M`P``&`,``+("`````````````.X%``!*`@``:P````P(``"N!@``-P0`````
M``"#!0``'08``$0&```E!``````````````W!P``W`0``&T%````````#@$`
M`-<#``!_!P``H`````````#?!P``7P$``#D!``````````````````#1````
M2P$````````-"```$04``#H!``"[!0``\P```%,!``#)````!P```)T&````
M````IP8````````E!0``7````%T```#.`P``5@$````````D!@``M@$``-0#
M```%!```?00``-\"``"U`0```````#````"[!```-@(```````#X!@``'P,`
M`/H&``"4!0````````````!C`0``S`4```````!*!@``8@4```````"4`0``
MQ@,```````#A````)@4``'\#``#X!P``%P4``!$(``#R`@``S@```!L```"D
M`0```````$8#``#R`0```````-H```"Q!P```````#@````(`0``G0$``+`%
M```*````X0(``(8"``!L`P``C@0``,`&``">`@``<P4``-4"``!?!@``````
M`+P!````````3@8`````````````9P4````````.!```I@,``$T```#]`@``
M````````````````N`4``%H'````````?P$```````"2`@```````&4%``#S
M`0``D@8```````#M`P``6`````````!1!@``=@4``-@!``"]!@``0`8``!,&
M```L!```Z@,````````:!P`````````````R!````````,X'````````60,`
M`'4!``!)!@``;P```.D"``#L`0``C0$```````#\!P``.P8``&L#``!"!@``
M_00``+T$``!L!0```````/,%``"Z`@``7P,``/$"``"!`0```P0``+T'``#'
M!0``R@4``(\!````````-0@``%(&``#/!@``X`$``%H````A!````````+@&
M``"7`@``VP$``-@#```:!0``9P(```````!H`@```````,L&```&!```%0``
M`,$#``",!0``B`(``)P'``!@`@``2P<``/\&``!^`0``*@```,D"````````
M*`$``-\&``#5!```UP4``!(#````````*0$``,T$````````+P```!<&``"R
M!P```````%D%```!!P``'`0``/0'``#T`0``B````+,%````````8P8``!$"
M```P`P``;P8``%(#`````0```````*D#````````,0<```````!9`0``<`8`
M`*4````E!@``T0$``/X"````````@@0```\#```#`P``M`<``(<#```7`P``
MK@````@````]!````````"L&````````H@0``*0&``!@!@``30$```````!N
M!@``*`(```````#%`@``@`,```@%```E`@````````,'`````````````+8#
M```<!0``6P<``(@!``!2!P``[P(````````)````P0$``.H````_````````
M`+X%``!-!```+0(``*L"`````````````*,%```'"```20<```````"Y`0``
M]@$``!X$```+!P``T00``.0```"#!`````````P'``#N!@``9@0``&<!``",
M`P``B0$``%,"``!Z!```_@8`````````````M08```````"9`0``YP4`````
M```0!@```````#4'``!@!0``!P,``````````````````-``````````G0(`
M`#L(````````"0<```````"Y`P```````````````````````$H!``!=`@``
M`````+H'``",`0```````*('``#-`@```````*\'``#;`@```````*X#````
M`````P$``+4%```\`0``(`8``.P'``"B````#`0``+@#``#+!0````4`````
M`````````````"\$`````````````*T&````````T0(``-(&```?!P``GP$`
M`*T$```T"````````$\(``"<`P``!`8``-H'``!;!@``^0$``*`'```^````
MB0(``)\'``!5`P``'0<``%<"``#\!0``+@0``/L'````````T04``+0```"=
M!0``I00```````"H!0``HP8``"D%``"+`0``*P@```````#Q`P```````)<`
M```:````````````````````Z`<``+`#`````````````.D!```+"```/@$`
M``````!V`P``*P0``-L'``!<`P``4P<``"P'``"A!0``3`@``!8%``">````
M`````/L%``#3`0``?`8`````````````%P$``"8'``#*!````````-4'``#7
M!P``F`<``'X'``#=`@``$P@``!8!````````(04``'$"``!@!P``/0(``#@"
M``!I`P``9@8``-T'```>!P````````````"J``````````````!P!0``"@,`
M`%@%``"<!0```````%<```#=`0```````!H!``"S`@````````````!R`P``
M'@```*0%``"E`0``-P8``$L(``"T`@```````((&``"0````R`$``%0&```4
M`0``R04``+L"``!-`P``*@,``#@#``!Z`0```````.@%```D!````````!@!
M``"`````J0```/D#````````F`$`````````````;P<``,8!```C`P``'@$`
M`)4#````````<0```.H'```)`P``4`8`````````````QP,`````````````
MX0$````````D`0``W`4``&\$``#&````M@(```````!U!0``^`,``!8```"*
M!@``N04``+8%````````;@,```````"R`P``_P0``.L$``"C`@``'`<``*<#
M````````;0$```````!<`@``CP0``.,!``#G`@``I`0``#8```!U`@``A@,`
M`$,(```X!P``(`,``*,!```4`@``EP0``),%```3!```600``*4#````````
M`````#X"```'`@``V`8``%X!`````````````),#````````5`,``*,```"7
M!@``&@(``.<$````````4P4``,0!```X"```````````````````DP8``!\!
M```?!0``VP8``!D````^"```%0$``$\%``!I````7`4``/8#```$````````
M`.T"``"1!P```````,H!``#+!P``O`4``$\"````````-`````````!A!@``
MQ0````````!V`0``A08``"@#````````\@0````````C!@``G@<``,4'````
M`````````&0#````````708``%`%``"6`@``A`,```T$``!8`P```P4``*0"
M`````````````!T!```7!P``R`````````"2````8`$```````!Q`P``W@<`
M``````!R!0```````-,'``````````````<$````````)P@```````!.!0``
M3@0``(0'```````````````````9`@``"0@``)0```"0`P``\`0````````-
M`P``?@4``&0````S!@``"`(``+,'``#%`P`````````&````````#P$``/T!
M```F!```\`8``),```#B!P````````````!*````$`@``$,#``#9!@``````
M`$$%``#S!```4P```(@&```C`@``50$``*@&```\!```B@(```````"Z`0``
M4`0``!$!``"Z!````````%0'```5!````````.D&```"`0``,@8``!P&````
M`````````"8``````````````#8!``!%!0``6@8``'D&````````^P(``-4%
M```$`P``:`0``.4&``!=!P``-@4``-0```!(!```V@0`````````````I`<`
M`'$$``!6!P``=`4``)4```"P!@``T`$``-P'```D````!`(``#T(```'`0``
MJP<``.P#````````,`<``!\$```S`@```````$<"``"1`P``_08``"D"````
M````-P(```````!X!P```0,```````!Y`````````#`!````````=`8`````
M``````````````$!``#0`P``(P<````````1!```J00````````8`@``````
M`.X```!``@``,@$```````!^!```W0,`````````````7P(````````L`P``
M#0(```````#=!```]`0```````"+!@``MP,```````!*!P``:`4``+P&``##
M!0``-P$``&("```T!P``+P,```````#!`@```````-8%````````)`4``"\%
M``"?`P``]`,``,L#````````$@0```````!"!```+@@```````"'````%08`
M``````!B!P``C@,``&P!``#E`0````````````"+!```N`(```````!R!```
M90<``($````.````4@(``%$"```=`P``[@$```````";`P```````&$#````
M````T0,``!0$```K`P````````$&``#U!0``*`@```4(```,`P``.0```)\`
M``!A!P``K@(```X(``"Q`0```````'T'``#V````UP0```````!,````B@$`
M`,4$``#-!P``%04```````#E`@``]@0```````"2!0``3`$````````]!P``
M`````.,#````````%P```#P#``!)`0``U@<```````!J!P``M@8```````!M
M!P``O0,``,H#``!4`0``.`8```````#J!@``/````.P%``#4!```804``)H%
M```%`@``0`0````````<`@``O@0`````````````108`````````````:0$`
M`!L#``#A!```,P0```````#A!0``Z0``````````````<`,``/\#````````
M>P(``"<%``#=!@``,P<```````"J!@``L````'H#`````````````&@!``"K
M!0``WP0``'4```!``0````````````!'`P``K04``/H%````````&04``/X%
M````````MP4``!L"```^`P``N`$```````#*!@``L0(`````````````P00`
M`'8&````````_P<``+0#````````(`@``)X!``#%!@``$`4``.\````V!```
MR0<``$('````````*`8``",`````````:P4````````&`P``%@,```````!/
M!@``W@4``!0%``#W`@``W@,``````````````````$<&``!9!@``OP8``.8#
M```,!0``&00``+P#``!%`@`````````````Z!0``````````````````````
M`*$!``"3!P``O0```(D'``"Q`P```````/L$```%`P``J@$````````H!```
M)P8``&@'``#_`0``A`````````#``@``"`0``&8```"9!````````#("``#W
M`0``R@`````````("```9P8``'@$``!:`@``908`````````````[P4``&,'
M``#Y!P``L08``#$(``#?`P``.P0``)X$```F"```$P(``/D"``!1`P``<P<`
M``````#T!0``000```("````````A`0``/<&``#+`0``"0$``',#``#6!@``
M````````````````@@```/D$``"\`@``'P@```($``!K`0``'0(``.<#````
M````A@4``!(%``"X!P``*```````````````Y@$``.0"``!=!0```````-8!
M``"B`P``/P4``&L'````````B04``````````````P8```X#``!I`@``)@(`
M``````!U`P``0P`````````@`@``508```````!%!```A0````L!``#.`@``
ME`,``%4%````````EP$```````#?````8P```,,'````````#`(``'T&````
M````2`,``%X$``"<!@``Y`8``&D&````````X@8``!`$``!F!P``````````
M```T`0``C00``+D&```9!@```````#T&``#C!@``H`(``"X!````````````
M`*<$``"_!```9`0```````!D`0``%0@`````````````H`,```````#V!@``
M````````````````I@$``%P'``!:`0```````+,`````````F@<``($$````
M````)0$``'`$```W!0````````````!R````Q`<```````!@!```2`(``'<'
M``".`@``R0$```````#B`P```````#$#````````V0<``%4`````````;0,`
M``0'``"T!````````(8$``#3!0``K`4``!(&``#+````"@8```$(``#$`P``
M``````````#1!@```````),$````````)P0`````````````J@0``.L#```Z
M`@``]@<````````I!```/@<``$X'``#!!0``?P```,8&`````````````.``
M``"W!```*@4```````"+!0```````````````````````.`$``!&"```````
M`+T"``#.!```)`,```````#7````F`,````````````````````````^!@``
M```````````:!```8P0``.4%````````+P<``)8%``"?!@``A`4```````"$
M`0``.P$```````!@``````````````"K!@``/0$```````!O`0``10,``"('
M```?!@``>P<``'T%``"@!@```````/@%````````<P`````(``!M`@``!`0`
M``````!;!```FP<``)\$``">!0``^@$``$<!````````8@8```\$``"Y!P``
M50<````````P!@```````-(#```K````&0$````````N`P```````&4"````
M`````````#D#``"3`@```````-X$``!\`P```````!("``#Y````I@4``+8`
M``!>`@```````)(#``!:!````````,L"``#\````HP0``'@&```"````````
M`)H"```,!@```````$@&``#F!````````````````````````"$`````````
MKP```!4#``">!@``H`4``+<&``#F!P``D`<``,,````-!P``Q`(``,\#``#G
M`0``B`0``$0%```F!@``80(```T!``#G!P``30<``.<```#Y!@```````/H'
M``#"!0```````($#````````V`<```8(````("@E<R!D87ES(&%G;RD`("A!
M8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O
M=RD`("AY97-T97)D87DI`"!A;F0`(&%T(``@;W(`(B5S(B!I<R!N;W0@82!D
M:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE
M(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S
M:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"
M('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S
M`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@
M9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U
M<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y
M(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T
M:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C
M:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E
M<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S
M`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O
M;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E
M<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I
M="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS
M(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E
M<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E
M<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L
M;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W
M(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T
M+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C
M;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`06-T:6]N(&9O<B!B;&%C:VQI<W1E
M9"!A9&1R97-S97,Z`$%C=&EV871E(%-C<FEP=`!!8W1I=F%T:6YG('1H92!S
M8W)I<'0@9F]R("(E<R(@9F%I;&5D.B`H)60I("5S`$%D9`!!9&0@0VAI;&0@
M1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@
M1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O
M("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D
M9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!
M9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`061D:71I;VYA;"!3971T:6YG<P!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;"!F;W5R('-I9&5S`$%L;"!O9B!T:&4@9F]L;&]W:6YG`$%L;&]W(%)U
M;&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@
M24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@
M24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA
M=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R
M;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY
M;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`06YT87)C=&EC80!!;G1I9W5A
M(&%N9"!"87)B=61A`$%N>2!O9B!T:&4@9F]L;&]W:6YG`$%P<&QI8V%T:6]N
M`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY
M($9I;'1E<G,`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X
M:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AI<R!R=6QE/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O
M=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!
M<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I
M9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S
M=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T
M;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL
M960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL
M960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H
M96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%U=&]M871I
M8V%L;'D@=7!D871E('1H92!S8W)I<'0@869T97(@96%C:"!C:&%N9V4_`$%V
M86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG
M<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N
M`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I
M8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P
M:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)C8P!"
M96=I;G,@=VET:`!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU
M9&$`0FAU=&%N`$)I;F0@9F%I;&5D.B`H)7,I("5S`$)I<G1H9&%Y`$)L86-K
M;&ES=`!";&%C:VQI<W0@161I=`!";&%C:VQI<W0@:7,@;F]T('-U<'!O<G1E
M9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!";&%C:VQI<W1E
M9"!!9&1R97-S97,`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO
M="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";V1Y`$)O;&0`
M0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O
M<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O
M='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T
M960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#
M86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O
M(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@
M:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A
M;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T
M+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N
M;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!6
M97)D90!#87!T:6]N`$-A<G)I97(`0V%S92!396YS:71I=F4`0V%T96=O<FEE
M<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-C`$-E;&P@4&AO;F4`0V5L
M;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E
M;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E
M;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A
M;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T
M92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N
M9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAA;F=E<R!S879E9"X`0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P
M;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE
M`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`
M0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R
M($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S
M`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI
M8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD
M;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#
M;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE
M;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T
M97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M
M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I
M;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@9F%I
M;'5R90!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT86EN<P!#;VYT96YT('1Y
M<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT
M:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2`E<P!#;W!Y(&9A
M:6QE9#H@)7,`0V]P>2!O9B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O
M<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B
M)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L
M9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D
M("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@
M(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@
M8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!N97<@9F]L9&5R`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A
M=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U
M8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@
M5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A
M=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M
M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E
M;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H
M(%)E<'5B;&EC`$1$`$1)4T%"3$5$.B``1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU
M<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE
M=&4@0V]L=6UN`$1E86-T:79A=&4@4V-R:7!T`$1E8V5M8F5R`$1E8VEM86P@
M;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R
M`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$
M96QE=&4`1&5L971E("5S`$1E;&5T92!#96QL`$1E;&5T92!#;VYD:71I;VX`
M1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L
M=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E
M(&UE<W-A9V4@8V]M<&QE=&5L>0!$96QE=&4@;65S<V%G97,`1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@
M<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T
M:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE
M=&5D`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E
M<B!I;G1O(&UY($EN8F]X`$1E;&EV97(@:6YT;R!M>2!);F)O>"!A;F0@8V]P
M>2!T;P!$96QI=F5R(&EN=&\@;7D@26YB;W@@86YD(')E9&ER96-T('1O`$1E
M;&EV97(@=&\@9F]L9&5R`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB
M92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO
M<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@
M4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L
M969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R
M>0!$:7-A8FQE("5S`$1I<V%B;&5D`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`
M1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES
M<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I
M<R!A<'!L:65D/P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R
M;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!?;F]T
M('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES="!M97-S86=E<P!$;R!N
M;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O('1H:7,Z`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]E<VXG="!B
M96=I;B!W:71H`$1O97-N)W0@8V]N=&%I;@!$;V5S;B=T(&5N9"!W:71H`$1O
M97-N)W0@97AI<W0`1&]E<VXG="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I
M`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C
M8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@
M9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D
M<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC
M92X`15)2`$5C=6%D;W(`161I=`!%9&ET("5S`$5D:70@0FQO8VL`161I="!'
M<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI
M<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A
M=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I
M8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C
M:"!T97)M<P!%;F%B;&4@)7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L
M:6-K(&-O;G1E>'0@;65N=3\`16YA8FQE9`!%;F0@>65A<@!%;F1S('=I=&@`
M16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC
M:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R
M<R!B96QO=SH`17%U86P@=&\`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%
M<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R(')E=')I979I;F<@8W5R
M<F5N="!S8W)I<'0Z("@E9"D@)7,`17)R;W(@<V%V:6YG(&-H86YG97,N`$5R
M<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%
M=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S
M`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN
M`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z
M`$5X96-U=&4`17AI<W1I;F<@4G5L97,`17AI<W1S`$5X<&%N9`!%>'!A;F0@
M4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@,2!O8FIE8W0L(&=O="`E
M9"X`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%
M>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O
M9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I
M;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%3
M3"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@
M=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R
M=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@
M4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L
M970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O
M=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L
M96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D
M+@!&:6QT97(@06QL($UE<W-A9V5S`$9I;'1E<B!/;FQY(%-E96X@365S<V%G
M97,`1FEL=&5R($]N;'D@56YS965N($UE<W-A9V5S`$9I;'1E<B!/<'1I;VYS
M`$9I;'1E<B!2=6QE`$9I;'1E<B!2=6QE<P!&:6QT97(@4V-R:7!T($1I<W!L
M87D`1FEL=&5R(%]2=6QE<P!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H
M<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E
M<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@9&5L971E9"X`
M1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!M;W9E
M9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S
M<V%G92AS*2!T:&%T(&UA=&-H960@=&AE(&)L86-K;&ES="!W97)E(&1E;&5T
M960N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E
M<R(@:&%S(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@(B5S(BX`1FEL=&5R
M(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E("(E<R(@
M9G)O;2`B)7,B(&AA<R!B965N(&UO=F5D('1O('1H92!F;VQD97(@(B5S(BX`
M1FEL=&5R(&YO="!F;W5N9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`
M1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@86X@:6YC
M;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z`$9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O
M<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U
M;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9"!I<R!N;W0@<W5P<&]R=&5D
M(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$9O<G=A<F1S`$9O
M<G=A<F1S($5D:70`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L
M:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9R;VTZ`$9U;&P@
M1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA
M;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`
M1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE
M`$=R96%T97(@=&AA;@!'<F5A=&5R('1H86X@;W(@97%U86P@=&\`1W)E96-E
M`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!
M9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E
M;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S
M`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T
M;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S
M:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O
M<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O
M2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S
M<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S
M(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%
M($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5
M;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@
M<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M
M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)
M8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I
M='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S
M964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y
M(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS
M<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%52
M3`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A
M;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM
M<&]R=&%N=`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!)
M;E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN
M`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C
M="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E
M<G,`26YD:79I9'5A;"!R=6QE<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@
M8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!);F1O;F5S:6$`26YE>&ES=&%N
M="!M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G92!D96QI=F5R>2X`26YF
M;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A
M8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS
M97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O
M;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@
M869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E
M<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA
M9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@
M<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C
M<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E
M<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI
M='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I
M;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!)
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N
M`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A
M;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A
M;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV
M96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9@!)<F%Q`$ER96QA;F0`27,`27-L92!O9B!-86X`27-N)W0`27-O;&%T
M960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC
M80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y
M`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T
M:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A
M;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T
M960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO
M;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A
M9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`
M2W5W86ET`$MY<F=Y>G-T86X`3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U
M="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A
M9&5D+@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T
M(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO
M9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`
M3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T
M`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5S<R!T:&%N`$QE
M<W,@=&AA;B!O<B!E<75A;"!T;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B
M($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT
M(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@
M4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO
M=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S
M('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(
M96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP
M`$QI<W0M240`3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN
M+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I
M;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`
M3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@
M9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R
M<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X
M96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!
M9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M
M87``36%P<&EN9W,@<W1O<F5D+@!-87)?:R!M97-S86=E(&%S(&1E;&5T960`
M36%R8V@`36%R9VEN`$UA<FL@;65S<V%G92!A<SH`36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-
M871C:&5S("AW:71H('!L86-E:&]L9&5R<RD`36%T8VAI;F<@9FEE;&1S`$UA
M=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0
M;W)T86P@0FQO8VMS`$UA>&EM=6T@3G5M8F5R(&]F(%)U;&5S`$UA>&EM=6T@
M;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&)L86-K;&ES=&5D(&%D9')E<W-E
M<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@36%X:6UU;2!A9&1R
M97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!B
M;&%C:VQI<W0N`$UA>&EM=6T@;G5M8F5R(&]F('=H:71E;&ES=&5D(&%D9')E
M<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@36%X:6UU;2!A
M9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T
M;R!W:&ET96QI<W0N`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N
M=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@
M='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T
M(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D
M`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC
M`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L
M90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@
M>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&%D9')E<W,@=&\@;F]T
M:69Y`$UI<W-I;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O`$UI
M<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@
M;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S
M:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5A<V]N(&9O<B!R96IE8W0`36ES
M<VEN9R!R96%S;VX@:6X@=F%C871I;VXN`$UI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE
M($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L
M=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3
M=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E
M(%)U;&4@1&]W;@!-;W9E(%)U;&4@57``36]V92!5<`!-;W9E(&1O=VX`36]V
M92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-
M=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`
M37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.7W5M8F5R(&]F(&1A
M>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S.@!.86UE`$YA;6EB:6$`3F%U
M<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T
M<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S
M8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I
M8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T
M96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`3F5W(%)U;&4`3F5W
M(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D
M`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D
M<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G
M<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.
M:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO("(E<R(@
M96QE;65N="!F;W5N9"!I;B!B86-K96YD(&-O;F9I9W5R871I;VXN`$YO(&%V
M86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E
M<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I
M;6%G97,N`$YO(&)A8VME;F0@8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T`$YO
M(&)A8VME;F1S(&-O;F9I9W5R960@:6X@8F%C:V5N9',N<&AP`$YO(&)A=&-H
M('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P
M;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A
M9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N`$YO(&9I;&4@=7!L;V%D960`3F\@9FEL=&5R<RX@0VQI8VL@(B5S(B!T
M;R!C<F5A=&4@82!N97<@9FEL=&5R+@!.;R!H96%D97)S('-P96-I9FEE9`!.
M;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO
M;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C
M:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T
M=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R
M>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T
M;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N
M`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V-R:7!T(&=E;F5R871E9"X`
M3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W1R:6YG<R!S
M<&5C:69I960`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E
M<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I
M;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM
M,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE
M<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R
M90!.;W0@82!D:7)E8W1O<GD`3F]T(&5Q=6%L('1O`$YO="!I;7!L96UE;G1E
M9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R
M;W=S92P@9V\@8F%C:RX`3F]T:69Y(&5M86EL(&%D9')E<W,`3F]V96UB97(`
M3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@
M0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P
M87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!F
M;&%G('1H92!M97-S86=E`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@
M;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!A
M8F]U="!S8W)I<'0@=7!D871I;F<N`$]P=&EO;G,@9F]R("5S`$]R9&5R960@
M3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ
M:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@
M3W!T:6]N<P!/=F5R=FEE=P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD
M`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0
M(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D
M90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`
M4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!0
M86MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U
M9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A
M<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!0
M87-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S
M:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN
M97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H
M92!N97<@9F]L9&5R.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L
M96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET
M:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F
M<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U
M<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y
M`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@
M=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+
M97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@
M<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A
M<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!27V5A<V]N
M`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A
M:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&
M;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@
M<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5C96EV960`4F5D:7)E8W0@=&\`4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5G=6QA
M<B!E>'!R97-S:6]N`%)E:F5C="!W:71H(')E87-O;@!296QA=&EO;G-H:7`@
M0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E
M;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO
M9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z
M("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N
M9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5N="!4;P!297-E;G0M
M9G)O;0!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D
M`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!&:6QT97)S
M($QI<W0`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O(%)U;&5S($QI<W0`
M4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T
M:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I
M9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O
M;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H
M=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE`%)U
M;&4@0V]P:65D`%)U;&4@1&5L971E9`!2=6QE($1I<V%B;&5D`%)U;&4@16YA
M8FQE9`!2=6QE($YA;64`4G5L93H`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<P!34T@`4U1!4E143%,@9F%I;&5D.B`H)7,I("5S`%-5
M0T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@
M86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M
M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC
M:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E
M("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!3971T:6YG<P!3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O
M;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!38W)I<'0`4V-R:7!T
M(%5P9&%T:6YG`%-C<FEP="!N;W0@=7!D871E9"X`4V-R:7!T('-U8V-E<W-F
M=6QL>2!A8W1I=F%T960N`%-C<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T
M960N`%-E87)C:`!396%R8V@@16YG:6YE<P!3965N`%-E;&5C="!&:6QE<P!3
M96QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A(&=R;W5P('1O
M(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C
M="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T
M('1A<F=E="!F;VQD97(`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D
M(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I
M;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&8M1&5F:6YE
M9"!(96%D97(`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YD97(`
M4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE
M9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E
M<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@9&ES<&QA>2!O<'1I;VYS+@!3971T:6YG<R!S=6-C97-S9G5L;'D@=7!D
M871E9"X`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO
M=R!!8W1I=F4@4V-R:7!T`%-H;W<@0W5R<F5N="!38W)I<'0`4VAO=R!D:69F
M97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN
M86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R
M/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L
M92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P
M;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E
M<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A
M($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`
M4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V
M96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E
M<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@
M97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA
M`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D
M9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD
M<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P
M86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C
M;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A
M<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T
M;W`@8VAE8VMI;F<@:68@=&AI<R!R=6QE(&UA=&-H97,_`%-T;W)A9V4@9F]R
M;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`
M4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`
M4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J95]C="!O9B!V86-A
M=&EO;B!M97-S86=E.@!3=6)J96-T`%-U8FIE8W0Z`%-U8FUI=`!3=6)M:71T
M960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V
M960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B
M('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R
M('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE
M=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C
M:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T
M960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3
M=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`
M4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T
M`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z
M:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN
M8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@
M4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4
M+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S
M`%1A8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M
M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!4
M96UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L
M871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!4
M97AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3
M+38R,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL
M86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4
M:&4@861D<F5S<R`B)7,B(&AA<R!B965N(&%D9&5D('1O('EO=7(@8FQA8VML
M:7-T+@!4:&4@861D<F5S<R`B)7,B(&AA<R!B965N(&%D9&5D('1O('EO=7(@
M=VAI=&5L:7-T+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!D<FEV97(@
M<V%I9#H@`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O
M(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL
M;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R
M(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C
M:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C
M<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E
M<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I
M;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E
M;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@
M=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY
M`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV
M96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L
M87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H
M87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F
M(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I
M>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA
M<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL
M>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D
M;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N
M;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@
M=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L
M;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE
M<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N
M(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B
M)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE
M87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T
M96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@
M=&AE('-C<FEP="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T
M:&4@<V-R:7!T+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE
M(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R
M97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@
M=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L
M9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O
M<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME
M=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T
M:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&\Z
M`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R
M;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R
M:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U
M<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``
M52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y
M('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@
M86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B
M)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN
M96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`
M56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE
M*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S
M('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W
M<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI
M<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D
M871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A
M9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@
M;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E
M;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO
M;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F
M;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5
M<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E
M:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N
M`%9A8V%T:6]N($5D:70`5F%C871I;VX@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B
M;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I
M;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E
M<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)
M*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E
M<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3
M+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&
M4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN
M9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B
M>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!7
M97-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VA?:71E;&ES
M="!A9&1R97-S97,Z`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T
M<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:&ET96QI
M<W0@161I=`!7:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R
M<F5N="!F:6QT97)I;F<@9')I=F5R+@!7:&ET96QI<W1E9"!!9&1R97-S97,`
M5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU
M(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7
M:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD
M`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``
M5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D
M("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@
M82!61E,@9FEL92X`6"U0<FEO<FET>0!8+5)E9@!8+5-P86TM3&5V96P`6"U3
M<&%M+5-C;W)E`%@M4W!A;2U3=&%T=7,`6#4P.78S($)A<VEC($-O;G-T<F%I
M;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@
M06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE
M<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY
M`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!R=6QE<RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;W(@961I="!C=7-T;VT@<G5L97,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T
M960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R
M(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A
M9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM
M<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S
M+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E(')E8V5I=F5D
M(&$@;F5W(&UE<W-A9V4`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U
M(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@96UA:6P@861D<F5S<R!F;W(@
M=VAI8V@@=&AE('9A8V%T:6]N(&UE<W-A9V5S('-H;W5L9"!B92!A8W1I=F%T
M960N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A
M;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S
M`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT
M:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N
M=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@
M>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@
M;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V
M:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!4
M97AT70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T
M960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE
M("5S(&]F("5S70!?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SH`7T%D9')E
M<W-E<R!T;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z`%]!9&UI;FES=')A=&EO
M;@!?0FQA8VML:7-T`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]$96QE
M=&4@;65S<V%G92!C;VUP;&5T96QY`%]%;G1E<B!E86-H(&%D9')E<W,@;VX@
M82!N97<@;&EN93H`7T9O<G=A<F0`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O
M<&5R=&EE<RXN+@!?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A
M8V-O=6YT/P!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?36]V
M92!M97-S86=E('1O(&9O;&1E<CH`7TUY(&5M86EL(&%D9')E<W-E<SH`7T]P
M=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V-R:7!T`%]3
M971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`7U9A8V%T:6]N`%]7
M:&ET96QI<W0`86-T:79E`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W
M;@!A;F0`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE
M`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S
M86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M
M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!D:7-A8FQE9"`M(&-L
M:6-K('1O(&5N86)L90!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I
M96QD`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z
M`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;F%C=&EV90!I;FQI
M;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R
M`&QI;F5S70!M86EL9')O<"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\`;6%T
M8V@`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM
M`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T
M97!A9`!O<@!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!P<F]C
M;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\`<F5M;W1E(&5R<F]R(&EN
M('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF
M9F5R96YC97,`<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!);F=O`'-M<S)E
M;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES
M=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W
M.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($EN9V\@,2XP+6-V
M<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI0
M3U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ-2`Q-SHT-BLP,3`P"E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#8M,#(M,34@,3<Z-#8K,#$P,`I,87-T+51R86YS
M;&%T;W(Z($UA;G5E;"!0+B!!>6%L82`\;6%Y86QA0'5N97@N97,^"DQA;F=U
M86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@
M,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U
M.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU<F%L+49O
M<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@,2D["@`@*&AA8V4@)7,@
M9.UA<RD`("A!8V-E9&EE;F1O(&$@)7,I`"`H96X@)7,@9.UA<RD`("AH;WDI
M`"`H;6'Q86YA*0`@*&%Y97(I`"!Y`&5N(`!O`"(E<R(@;F\@97,@=6X@9&ER
M96-T;W)I;RX`(B5S(B!N;R!E<R!U;F$@96QE8V-I\VX@=N%L:61A+@!.;R!S
M92!H82!C;VYF:6=U<F%D;R`B)7,B(&5N(&5L(')E9VES=')O(&1E($AO<F1E
M+@!.;R!S92!E;F-O;G1R\R!E;"!G96YE<F%D;W(@9&4@X7)B;VQE<R!D92`B
M)7,B+@!392!H82!A\6%D:61O("(E<R(@86P@<VES=&5M82!D92!G<G5P;W,N
M`%-E(&AA(&'Q861I9&\@(B5S(B!A;"!S:7-T96UA(&1E('!R:79I;&5G:6]S
M+@!.;R!S92!H82!C<F5A9&\@(B5S(CH@)7,N`%5S861O<R`E+C)F34(@9&4@
M)2XR9DU"('!E<FUI=&ED;W,@*"4N,F8E)2D`)60@)7,@>2`E<P!1=65D86X@
M)60@9.UA<R!H87-T82!Q=64@97AP:7)E(&QA(&-O;G1R87-E\6$N`"5D('!R
M;V[S<W1I8V]S(&1I87)I;W,`)7,@+2!!=FES;P!(=65L;&$@9&EG:71A;"!D
M92`E<P`E<R!+0@`E<R!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O("T@
M0V]N9FER;6%C:?-N`$-O;F9I9W5R86-I\VX@9&4@)7,`1FER;6$@9&4@)7,`
M06-U97)D;W,@9&4@;&EC96YC:6$@9&4@)7,`66$@97AI<W1E("5S+@`E<R!A
M(&QA<R`E<R`E<P`E<R!E<W3A('!R97!A<F%D;R!P87)A(')E86QI>F%R(&QA
M<R!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O('-E;&5C8VEO;F%D87,N
M06-T:79E(&QA<R!C87-I;&QA<R!D92!L87,@;W!E<F%C:6]N97,@<75E(&1E
M<V5A(&5J96-U=&%R(&5N(&5S=&$@;V-A<VGS;BX`2&%C92!F86QT82`E<P`E
M<R!M:6YU=&]S`$YO('-E(&AA(&5N8V]N=')A9&\@)7,N`"5S(&%L("5S(&1E
M("5S`$1I<F5C8VEO;F5S(&1E("5S`$%G96YD82!D92`E<P!,:6)R971A(&1E
M(&YO=&%S(&1E("5S`%1A<F5A<R!D92`E<P`E<SH@)7,`)7,Z($5S=&4@;65N
M<V%J92!P=65D92!Q=64@;F\@<')O8V5D82!D92!Q=6EE;B!P87)E8V4@<V5R
M+B!%=FET92!S96=U:7(@8W5A;'%U:65R(';M;F-U;&\@:6YC;'7M9&\@;R!S
M=6UI;FES=')A<B!C=6%L<75I97(@:6YF;W)M86-I\VX@<&5R<V]N86P@86P@
M<F5M:71E;G1E+@`L('9E;G1O<V\@`"P@=F5N=&]S;R`E<R`E<P`L('9A<FEA
M8FQE(&1E("5S(&$@)7,`+2T@<V5L96-C:6]N87(@+2T`1F]R;6%T;R!D92`Q
M,B!H;W)A<P!&;W)M871O(&1E(#(T(&AO<F%S`#(T(&AO<F%S`#Q!;G1E<FEO
M<@!087)A(&5S=&4@8FQO<75E(&AA8V4@9F%L=&$@=6X@;6]T;W(@9&4@8F%S
M92!D92!D871O<RX`4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&ER<F5P87)A
M8FQE`$AA8V4@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A('!A<F$@8VEF
M<F%R('5N(&UE;G-A:F4N`$AA8V4@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L
M:6-A('!A<F$@8V]M<')O8F%R('5N(&UE;G-A:F4@9FER;6%D;RX`2&%C96X@
M9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A+"!U;F$@8VQA=F4@4$=0('!R
M:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@<&%R82!D97-C:69R87(@=6X@;65N
M<V%J92X`2&%C96X@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A+"!U;F$@
M8VQA=F4@4$=0('!R:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@<&%R82!F:7)M
M87(@=6X@;65N<V%J92X`2&%C96X@9F%L=&$@=6YA(&-L879E(%,O34E-12!P
M^F)L:6-A+"!U;F$@8VQA=F4@4R]-24U%('!R:79A9&$@>2!U;F$@9G)A<V4@
M8VQA=F4@<&%R82!D97-C:69R87(@=6X@;65N<V%J92X`2&%C96X@9F%L=&$@
M=6YA(&-L879E(%,O34E-12!P^F)L:6-A+"!U;F$@8VQA=F4@4R]-24U%('!R
M:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@<&%R82!F:7)M87(@=6X@;65N<V%J
M92X`2&%C92!F86QT82!U;F$@8VQA=F4@4TU)344@</IB;&EC82!P87)A(&-I
M9G)A<B!U;B!M96YS86IE+@!.=6)E<R!M871I;F%L97,`3&EG97)A(&QL=79I
M82!M871I;F%L`$QL=79I82!M871I;F%L`$%G=6%C97)O<R!M871I;F%L97,`
M06=U86-E<F\@;6%T:6YA;"!D92!N:65V90!!32]030!)1"!D92!!4$D`06-E
M<F-A(&1E;"!E9&ET;W(`06-E<F-A(&1E+BXN`$EN9F5R:6]R($%B<RX`16X@
M;65D:6\@06)S+@!392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@
M96P@9&ER96-T;W)I;R!61E,N`%-E(&AA(&1E;F5G861O(&5L(&%C8V5S;R!A
M;"!C<F5A<B!E;"!A<F-H:79O(%9&4RX`261E;G1I9&%D`$-O;G1R87-E\6$@
M9&4@86-C97-O`$ED96YT:61A9"!B;&]Q=65A9&$N`$-O;G1A8FEL:61A9`!!
M8V-I\VX@<&%R82!D:7)E8V-I;VYE<R!D92!L82!L:7-T82!N96=R83H`06-T
M:79A<B!G=6GS;@!(82!F86QL861O(&QA(&%C=&EV86-I\VX@9&5L(&=U:?-N
M('!A<F$@(B5S(CH@*"5D*2`E<P!!\6%D:7(`0?%A9&ER(&=R=7!O(&1E<V-E
M;F1I96YT90!!\6%D:7(@<')I=FEL96=I;R!D97-C96YD:65N=&4`0?%A9&ER
M(&%Q=>TZ`$'Q861I<B!G<G5P;P!!\6%D:7(@<')I=FEL96=I;P!!\6%D:7(@
M82`B)7,B('5N(&=R=7!O(&1E<V-E;F1I96YT90!!\6%D:7(@82`B)7,B('5N
M('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E`$'Q861I<B!U;B!U<W5A<FEO.@!!
M\6%D:7(@8V]L=6UN80!!\6%D:7(@;6EE;6)R;W,`0?%A9&ER('!A<@!!\6%D
M:7(@96P@;65N^B`E<R!C;VUO('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL80!!
M\6%D:7(@82!L87,@9&ER96-C:6]N97,Z`$'Q861I<B!A(&QA<R!D:7)E8V-I
M;VYE<SH`0?%A9&ER('5S=6%R:6\`4V4@:&$@8?%A9&ED;R`B)7,B(&%L('-I
M<W1E;6$L('!E<F\@;F\@<V4@<'5E9&4@8?%A9&ER(&QA(&EN9F]R;6%C:?-N
M(&%D:6-I;VYA;"!D92!A;'1A.B`E<RX`4V4@:&$@8?%A9&ED;R`B)7,B(&%L
M('-I<W1E;6$N(%EA('!U961E(&EN:6-I87(@;&$@<V5S:?-N+@!,82!A9&EC
M:?-N(&1E('5S=6%R:6]S(&5S=.$@9&5S:&%B:6QI=&%D82X`3W!C:6]N97,@
M861I8VEO;F%L97,`1&ER96-C:?-N`$1I<F5C8VEO;F5S`$%D;6EN:7-T<F%D
M;W(@+2!D969I;F4@<')I=FEL96=I;W,@9&4@;W1R;W,@=7-U87)I;W,`061M
M:6YI<W1R86-I\VX`06YU;F-I;W,`069G86YI<W3A;@!!;&)A;FEA`$%R9V5L
M:6$`06QI87,`06QI;F5A<@!!;&EN96%C:?-N.@!4;V1O<P!4;V1O<R!L;W,@
M=7-U87)I;W,@875T96YT:69I8V%D;W,`5&]D;W,@;&]S(&=R=7!O<P!4;V1O
M<R!L;W,@<')I=FEL96=I;W,`5&]D;W,@;&]S(&QA9&]S`%1O9&\@;&\@<75E
M('-I9W5E`%!E<FUI=&ER(')E9VQA<P!097)M:71I<B!V87)I87,@9&ER96-C
M:6]N97,`OU!E<FUI=&ER(&-O;F9I9W5R86-I\VX@9&4@=&EP;R!D92!L:7-T
M87,@;W)D96YA9&%S/P!982!E>&ES=&4`06-C97-O($E-4U`@86QT97)N871I
M=F\`0VQA=F4@24U34"!A;'1E<FYA=&EV80!5<W5A<FEO($E-4%,@86QT97)N
M871I=F\`1&ER96-C:?-N(&5L96-T<O-N:6-A(&%L=&5R;F%T:79A`%!L86YT
M:6QL87,@86QT97)N871I=F%S`%1E>'1O(&%L=&5R;F%T:79O`%-A;6]A($%M
M97)I8V%N80!392!H82!I;F1I8V%D;R!U;B!V86QO<B!I;&5G86PN`%-E(&AA
M('!R;V1U8VED;R!U;B!E<G)O<B!D97-C;VYO8VED;RX`06YD;W)R80!!;F=O
M;&$`06YG=6EL80!0<F]X>2!A;O-N:6UO`%)E<W!U97-T80!297-P;VYD:61O
M`$%N=.%R=&ED80!!;G1I9W5A('D@0F%R8F%D;W,`0W5A;'%U:65R82!D92!L
M;R!Q=64@<VEG=64`07!L:6-A8VGS;@!,:7-T82!D92!A<&QI8V%C:6]N97,`
M3&$@87!L:6-A8VGS;B!E<W3A(&QI<W1A+@!!<&QI8V%R(&9I;'1R;W,`07!L
M:6-A<B!A(')E8W5R<V]S(&-O;7!A<G1I9&]S(&1E<V-E;F1I96YT97,`07!R
M;V)A<@!486UA\6\@87!R;WAI;6%D;P!!8G)I;`!!<N%B:6=O("A7:6YD;W=S
M+3$R-38I`%1A;6'Q;R!D96P@87)C:&EV;P!.;VUB<F4@9&5L(&%R8VAI=F\`
MOT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!E<W1A(')E9VQA
M/P"_17-T82!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&QA('-O;&EC
M:71U9"!D92!A;'1A(&1E("5S/P"_17-TX2!S96=U<F\@9&4@<75E(&1E<V5A
M(&5L:6UI;F%R("(E<R(@>2!T;V1O<R!S=7,@<W5B9W)U<&]S/P!!<F=E;G1I
M;F$`07)M96YI80!!<FUE;FEO("A!4DU30TE)+3@I`$%R=&4`07)U8F$`27-L
M82!!<V-E;G-I\VX`1W+A9FEC;W,@07-C:6D`4F5G:?-N(&1E($%S:6$O4&%C
M[69I8V\`OU-O;&EC:71A<B!C;VYF:7)M86-I\VX@86YT97,@9&4@<F5A;&EZ
M87(@;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;S\`0V]L=6UN87,@9&4@
M87-I9VYA8VGS;@!);G1E;G1A(&5L:6UI;F%R('5N(&=R=7!O(&EN97AI<W1E
M;G1E+@!);G1E;G1A(&5L:6UI;F%R('5N('!R:79I;&5G:6\@:6YE>&ES=&5N
M=&4N`$EN=&5N=&$@;6]D:69I8V%R('5N('!R:79I;&5G:6\@:6YE>&ES=&5N
M=&4N`$EN=&5N=&$@;6]D:69I8V%R('5N(')E8W5R<V\@8V]M<&%R=&ED;R!I
M;F5X:7-T96YT92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<F%L:6$`075S=')I
M80!!=71H7V-Y<G-Q;#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&EM
M87`@;F5C97-A<FEA+@!!=71H7V-Y<G5S.B!%;"!M;W1O<B!C87)E8V4@9&4@
M;&%S(&-A<&%C:61A9&5S(&YE8V5S87)I87,N`$%U=&A?8WER=7,Z($YO('-E
M(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!I;6%P(&YE8V5S87)I82X`075T:%]F
M='`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!&5%`@;F5C97-A<FEA
M+B!#;VUP:6QE(%!(4"!C;VX@;&$@;W!C:?-N("TM96YA8FQE+69T<"X`075T
M:%]I;6%P.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@24U!4"!N96-E
M<V%R:6$N`$%U=&A?:W)B-3H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N
M(&MR8C4@;F5C97-A<FEA+@!!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A
M(&QA(&%D:6-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>0!!
M=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&5L:6UI;F%C:?-N(&1E
M('5S=6%R:6]S(&1E($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!.;R!S
M92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@3$1!4"!N96-E<V%R:6$N`$%U=&A?
M;&1A<#H@3F\@<V4@<'5E9&4@8?%A9&ER(&5L('5S=6%R:6\@)7,N(,ES=&\@
M97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(Z(`!!=71H7VQD87`Z($EN8V%P
M87H@9&4@96QI;6EN87(@96P@=7-U87)I;R`E<P!!=71H7VQD87`Z($EN8V%P
M87H@9&4@86-T=6%L:7IA<B!E;"!U<W5A<FEO("5S`$%U=&A?;&1A<#H@3F\@
M97-TX2!S;W!O<G1A9&$@;&$@86-T=6%L:7IA8VGS;B!D92!U<W5A<FEO<R!D
M92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;6-A;#H@3F\@<V4@96YC;VYT<O,@
M;&$@97AT96YS:?-N($U#04P@;F5C97-A<FEA+@!!=71H7W-M8F%U=&@Z($YO
M('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!S;6)A=71H(&YE8V5S87)I82X`
M1F%L;/,@;&$@875T96YT:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!)34%0
M+@!&86QL\R!L82!A=71E;G1I9FEC86-I\VX`1F%L;/,@;&$@875T96YT:69I
M8V%C:?-N+B`E<P!%;"!S97)V:61O<B!2041)55,@:&$@<F5C:&%Z861O(&QA
M(&%U=&5N=&EF:6-A8VGS;BX`1F%L;/,@;&$@875T96YT:69I8V%C:?-N(&-O
M;B!E;"!S97)V:61O<B!&5%`N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C
M;VX@96P@<V5R=FED;W(@4TU"+@"_06-T=6%L:7IA<B!A=71O;>%T:6-A;65N
M=&4@96P@9W5I\VX@=')A<R!C861A(&-A;6)I;S\`0V%M<&]S(&1I<W!O;FEB
M;&5S.@!!>F5R8F%I:F%N`$5X8W5S87,@0D]&2`!&;VYD;P!#;VQO<B!D92!F
M;VYD;P!#;VYT<F%S9?%A(&ME<F)E<F]S(&EN8V]R<F5C=&$N`$YO;6)R92!D
M92!U<W5A<FEO(&ME<F)E<F]S(&EN8V]R<F5C=&\N`$)A:&%M87,`0F%H<F%I
M;@!"X6QT:6-O("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!.
M;R!S92!E;F-O;G1R\R!E;"!D:7)E8W1O<FEO(&)A<V4@9&4@:6WA9V5N97,@
M(B5S(BX`3.UN96$@8F%S90!"8V,`16UP:65Z82!P;W(`0F5L87)U<P!"Z6QG
M:6-A`$)E;&EZ90!"96YI;@!"97)M=61A<P!":'5T86X`2&$@9F%L;&%D;R!L
M82!V:6YC=6QA8VGS;CH@*"5S*2`E<P!#=6UP;&5A\6]S`$QI<W1A(&YE9W)A
M`$UO9&EF:6-A<B!L:7-T82!N96=R80!%;"!C;VYT<F]L861O<B!D92!F:6QT
M<F%D;R!A8W1U86P@;F\@<V]P;W)T82!L:7-T87,@;F5G<F%S+@!$:7)E8V-I
M;VYE<R!I;F-L=6ED87,@96X@;&$@;&ES=&$@;F5G<F$`3F\@<V4@96YC;VYT
M<O,@96P@8FQO<75E("(E<R(@9&4@;&$@87!L:6-A8VGS;B`B)7,B+@!/<&-I
M;VYE<R!D92!B;&]Q=64`5&EP;R!D92!B;&]Q=64`0W5E<G!O`$YE9W)I=&$`
M0F]L:79I80!-87)C861O<F5S`$)O<F1E`$=R;W-O<B!D96P@8F]R9&4Z`$)O
M<F1E<P!";W-N:6$@2&5R>F5G;W9I;F$`06UB;W,`0F]T<W=A;F$`26YF97)I
M;W(`27-L82!D92!";W5V970`0G)A<VEL`%1E<G)I=&]R:6\@;V-EX6YI8V\@
M9&4@;&$@26YD:6$@8G)I=.%N:6-A`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A
M<FEA`$QI<W1A(&1E<V]R9&5N861A`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--
M4P!#4D,`4'5N=&]S(&1E(&1I<W1R:6)U8VGS;B!#4D,`4')O<&EE9&%D97,@
M9&4@7V-E;&1A+BXN`$YO('-E(&AA(&9I;F%L:7IA9&\@96P@:6YI8VEO(&1E
M(&QA(&-A8VCI+@!!9V5N9&$`0V%L;6$`0V%M8F]Y80!#86UE<OIN`$YO('-E
M('!U961E(')E86IU<W1A<B!L82!C;&%V92!A=71O;>%T:6-A;65N=&4L('#S
M;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@9&5L('-I
M<W1E;6$N`$YO('-E('!U961E(&5S8W)I8FER(&5N(&5L(&%R8VAI=F\@(B5S
M(@!.;R!S92!P=65D96X@861M:6YI<W1R87(@;6%N96IA9&]R97,@9&4@<V5S
M:?-N(&5X=&5R;F]S+@!.;R!S92!P=65D92!C;VYE8W1A<B!A;"!S97)V:61O
M<B!)34%0.B`E<P!.;R!S92!P=65D92!A8G)I<B!E;"!A<F-H:79O("(E<R(N
M`$-A;F%DX0!#86YC96QA<@!#86YC96QA<B!I;F9O<FUE(&1E('!R;V)L96UA
M<P!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!A<F-H:79O("(E<R(N`$YO('-E
M(&5N8W5E;G1R82!U;B!D:7)E8W1O<FEO('1E;7!O<F%L+@!.;R!S92!P=65D
M92!C;VYT:6YU87(@<VEN(&5L('!A<N%M971R;R`G=&%R9V5T1FEL92<N`$YO
M('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@(B5S(BX`3F\@<V4@
M<'5E9&4@96QI;6EN87(L('1I96YE("5D(&1E<V-E;F1I96YT97,N`$YO('-E
M('!U961E(')E;W)D96YA<BP@96P@;OIM97)O(&1E(&5N=')A9&%S('%U92!S
M92!D97-E82!O<F1E;F%R(&YO(&-O:6YC:61E(&-O;B!L87,@86QM86-E;F%D
M87,N`$YO('-E('!U961E(&1I<FEG:7(@96P@;65N<V%J92!A;"!N^FUE<F\@
M97-P96-I9FEC861O+@!#86)O(%9E<F1E`%-U8G3M='5L;P!0<F]V965D;W(`
M1&ES=&EN9W5I<B!M87DN+VUI;BX`0V%T96=O<NUA<R!Y(&5T:7%U971A<P!)
M<VQA<R!#86EMX6X`0V,`5&5LZ69O;F\@;?-V:6P`4')O<&EE9&%D97,@9&4@
M8V5L9&$`36%R9V5N(&1E(&-E;&1A.@!0<F]P:65D861E<R!D92!C96QD80!%
M<W!A8VEA9&\@9&4@8V5L9&$Z`%1E;.EF;VYO(&WS=FEL`$/I;'1I8V\@*$E3
M3RTX.#4Y+3$T*0!#96YT<F%R`%)E</IB;&EC82!#96YT<F]A9G)I8V%N80!%
M=7)O<&$@0V5N=')A;"`H25-/+3@X-3DM,BD`1&5T86QL97,@9&5L(&-E<G1I
M9FEC861O`%!R;W!I971A<FEO(&1E;"!C97)T:69I8V%D;P!0;VSM=&EC87,@
M9&5L(&-E<G1I9FEC861O`$-H860`0V%M8FEA<@!#86UB:64@;&$@8V]N=')A
M<V7Q80!#86UB:6$@96P@;F]M8G)E('D@;&$@9&ER96-C:?-N(&5L96-T<O-N
M:6-A('9I<VEB;&5S(&%L(&QE97(@;R!R97-P;VYD97(@82!S=7,@;65N<V%J
M97,N`%-E(&AA;B!G=6%R9&%D;R!L;W,@8V%M8FEO<RX`3&$@8V]N9FEG=7)A
M8VGS;B!A8W1U86P@;F\@<V]P;W)T82!E;"!C86UB:6\@9&4@8V]N=')A<V7Q
M87,N(%#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@
M9&5L('-I<W1E;6$N`$=RX69I8V\`5F5R:69I8V%R(%]V[6YC=6QO+BXN`$-H
M:6QE`$-H:6YA`$-H:6YO('-I;7!L:69I8V%D;R`H1T(R,S$R*0!#:&EN;R!T
M<F%D:6-I;VYA;"`H0FEG-2D`07!L:6-A8VGS;CH`16QI:F$@=6YA(&-O;G1R
M87-E\6$`16QI:F$@=6X@;F]M8G)E(&1E('5S=6%R:6\`16QI:F$@8_-M;R!M
M;W-T<F%R(&QA<R!F96-H87,Z`%-E;&5C8VEO;F%R('1I<&\@9&4@97-T:6QO
M(&1E(&QI<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D87,I`$ES;&$@9&4@4&%S
M8W5A`$YO('-E(&5N8V]N='+S(&QA(&1E9FEN:6-I\VX@9&4@8VQA<V4@9&4@
M)7,N`$QI;7!I87(`16QI;6EN87(@971I<75E=&%S($U33V9F:6-E`$)O<G)A
M<B!C;VYS=6QT80!";W)R87(@=7-U87)I;SH@)7,`0F]R<F%R('5S=6%R:6\`
M0F]R<F%R(&1A=&]S(&1E;"!U<W5A<FEO`$1E<W!E:F%D;R!T87)D[6\`2&%G
M82!C;&EC:R!P87)A('-E9W5I<@!#;&EC:V%T96QL('!O<B!(5%10`$-E<G)A
M<B!V96YT86YA`$YU8F5S`$YU8F5S('1E;7!R86YA<P!N=6)O<V\`27-L87,@
M9&4@8V]C;W,@*$ME96QI;F<I`$]C=6QT87(@8F%R<F$@;&%T97)A;`!#;VQA
M<'-A<B!B;W)D97,`0V]L;VUB:6$`0V]L;W(`4V5L96-T;W(@9&4@8V]L;W(`
M4V5L96-C:?-N(&1E(&-O;&]R`$-O;'5M;F%S.@!4[71U;&]S(&1E(&QA<R!C
M;VQU;6YA<P!#\VUI8W,`0V]M86YD;P!);G3I<G!R+B!C;VUA;F1O<P!#;VUE
M;G1A<FEO`$YO;6)R92!C;VWZ;@!#;VUO<F]S`$-O;7!A\>UA`$]R9&5N861O
M<F5S`$-O;F1I8VGS;@!#;VYD:6-I;VYE<P!$:69E<F5N8VEA<R!D92!L82!C
M;VYF:6=U<F%C:?-N`$-O;F9I9W5R86-I\VX@<&%R82!S:6YC<F]N:7IA8VGS
M;B!C;VX@4$1!<RP@3?-V:6QE<R!C;VX@86=E;F1A('D@3W5T;&]O:RX`3&$@
M8V]N9FEG=7)A8VGS;B!E<W3A(&1E<V%C='5A;&EZ861A+@!#;VYF:6=U<F%R
M("5S`$-O;F9I<FUA<B!C;VYT<F%S9?%A`$-O;F=O`$-O;F=O+"!297#Z8FQI
M8V$@1&5M;V-RX71I8V$@9&5L`$9A;&SS(&QA(&-O;F5X:?-N+@!&86QL\R!L
M82!C;VYE>&GS;CH@`$9A;&QO(&1E(&-O;F5X:?-N`%-E(&AA(')E8VAA>F%D
M;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RX`
M4V4@:&$@<F5C:&%Z861O(&QA(&-O;F5X:?-N(&%L('-E<G9I9&]R(&1E(&-L
M879E<R!P^F)L:6-O+B!-;W1I=F\Z("5S("@E<RD`2&$@9F%L;&%D;R!L82!C
M;VYE>&GS;B!A;"!S97)V:61O<B!&5%`N`$-O;G1A8W1O<P!392!H86X@8?%A
M9&ED;R!C;W)R96-T86UE;G1E(&QO<R!C;VYT86-T;W,@82!S=7,@9&ER96-C
M:6]N97,`0V]N=&EE;F4`5&EP;R!D92!C;VYT96YI9&\@9&5L(&%R8VAI=F\@
M8V]M<')I;6ED;SH@`$-O;G1E;FED;R!D92`B)7,B`$-O;G1I;G5A<@!)<VQA
M<R!#;V]K`$-O;VMI90!#;W!I87(`0V]P:6%R("5S`$9A;&SS(&QA(&-O<&EA
M.B`E<P!#;W!I82!D92`E<P!#;W!I87(@<V5L96-C:?-N`$E$(&1E(&-O<W1E
M`$-O<W1A(%)I8V$`0V]S=&$@9&4@36%R9FEL`$YO('-E('!U961E(&-I9G)A
M<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E('!U961E(&9I<FUA
M<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E('!U961E(&-I9G)A
M<B!E;"!M96YS86IE(&UE9&EA;G1E(%,O34E-10!.;R!S92!P=65D92!F:7)M
M87(@96P@;65N<V%J92!M961I86YT92`@4R]-24U%`$YO('-E('!U961E(&'Q
M861I<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@96YL87IA<B!A;"!S
M97)V:61O<B!,1$%0+@!.;R!S92!P=65D92!C;VUP<F]B87(@96P@<V%L9&\N
M("5S`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($Q$05`N`$YO
M('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R("(E<R(@;65D:6%N=&4@
M1E10.B`E<P!.;R!S92!P=65D92!C<F5A<B!L82!L:7-T82!D92!D:7-T<FEB
M=6-I\VXN("5S`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A=&]S(%!'
M4#H@`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A=&]S(%,O34E-12X`
M3F\@<V4@<'5E9&4@96QI;6EN87(@96P@8V]N=&%C=&\N("5S`$YO('-E('!U
M961E(&5L:6UI;F%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@
M<V4@<'5E9&4@96QI;6EN87(@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D
M92!C;VYF:6=U<F%C:?-N("(E<R(N`$YO('-E('!U961E(&1E=&5R;6EN87)A
M(&QA(&1I<F5C8VGS;B!D92!C;W)R96\@9&5L(&1E<W1I;F%T87)I;RX`3F\@
M<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!C;VUP
M;&5T82X`3F\@<V4@<'5E9&4@=')A97(@;&$@;&ES=&$@9&4@9&ES=')I8G5C
M:?-N(&-O;7!L971A+@!.;R!S92!P=65D92!T<F%E<B!L82!L:7-T82!C;VUP
M;&5T82!D92!L:7-T87,@9&4@9&ES=')I8G5C:?-N+@!.;R!S92!P=65D92!C
M87)G87(@;&$@97-T<F%T96=I82`B)7,B+@!.;R!S92!P=65D92!C<F5A<B!E
M;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&]B=&5N97(@;&$@8VQA
M=F4@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=F5S+@!.;R!S92!P=65D
M92!A8G)I<B`B)7,B('!A<F$@97-C<FEB:7(N`$YO('-E('!U961E(&%B<FER
M("5S+@!.;R!S92!P=65D92!A8G)I<B!E;"!M\V1U;&\@9&4@=&%R96%S(&1E
M(&UA;G1E;FEM:65N=&\@)7,`3F\@<V4@<'5E9&4@86)R:7(@96P@9&ER96-T
M;W)I;R`B)7,B+@!.;R!S92!P=65D92!L;V-A;&EZ87(@96P@<V5R=FED;W(@
M3$1!4"X`3F\@<V4@<'5E9&4@;&5E<B`E<RX`3F\@<V4@<'5E9&4@<F5S=&%B
M;&5C97(@;&$@8V]N=')A<V7Q82!D96P@=7-U87)I;R!S;VQI8VET861O+B!0
M87)T92!D92!L;W,@9&5T86QL97,@;R!T;V1O<RP@<V]N(&EN8V]R<F5C=&]S
M+B!0<G5E8F4@;W1R82!V97H@;R!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E
M;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA('!A<F$@;>%S(&EN9F]R;6%C
M:?-N+@!.;R!S92!P=65D92!O8G1E;F5R(&QA($%#3"X`3F\@<V4@<'5E9&4@
M;V)T96YE<B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B`E<P!.;R!S92!P
M=65D92!O8G1E;F5R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@
M<V4@<'5E9&5N(&]B=&5N97(@;&%S(&QI<W1A<R!D92!D:7-T<FEB=6-I\VXN
M("5S`$YO('-E('!U961E;B!O8G1E;F5R(&QA<R!C87!A8VED861E<R!D96P@
M<V5R=FED;W(`3F\@<V4@<'5E9&4@<F5S=&%U<F%R(&QA(&-O;F9I9W5R86-I
M\VXN`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@(B5S(BX`
M3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;VYF:6=U<F%C:?-N(&1E("5S+@!.
M;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C;VYF:6=U<F%C
M:?-N+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C;VYF
M:6=U<F%C:?-N.B`E<P!.;R!S92!P=65D92!G=6%R9&%R(&5L(&=U:?-N(&1E
M(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS;B!E;CH@(B5S(BX`
M3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;W!I82`E<R!D92!L82!C;VYF:6=U
M<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R(&5L(&%R8VAI=F\@)7,@9&4@
M8V]N9FEG=7)A8VGS;BX@4'5E9&4@=71I;&EZ87(@=6YA(&1E(&QA<R!O<&-I
M;VYE<R!P87)A(')E<W1A=7)A<B!E;"!C\V1I9V\@9&4@)7,@;R!C;W!I87(@
M;6%N=6%L;65N=&4@82`E<R!E;"!C\V1I9V\@<VEG=6EE;G1E+@!.;R!S92!P
M=65D92!B=7-C87(@96X@96P@<V5R=FED;W(@3$1!4"X`3F\@<V4@<'5E9&4@
M9&5S=FEN8W5L87(@(B5S(BX`3F\@<V4@<'5E9&4@86-T=6%L:7IA<B!E;"!C
M;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@86-T=6%L:7IA<B!L82!L:7-T82!D
M92!D:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E(&5S8W)I8FER(&QA(&-O
M;F9I9W5R86-I\VX@9&4@(B5S(CH@)7,`3F\@<V4@<'5E9&4@;&]C86QI>F%R
M(&5L('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL82X@0V]M<')U96)E('%U92!E
M<W3I(&%B:65R=&\N`$YO('-E('!U961E;B!O=&]R9V%R(&%L('5S=6%R:6\@
M(B5S(B!L;W,@<VEG=6EE;G1E<R!D97)E8VAO<R!P87)A(&QA(&-A<G!E=&$@
M(B5S(CH@)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O<P!#<F5A<@!#<F5A
M('5N(';M;F-U;&\`0W)E87(`0W)E87(@8V%R<&5T80!#<F5A<B!S=6)C87)P
M971A<P!0<FEV:6QE9VEO<R!D92!C<F5A9&]R`$[Z;65R;R!D92!T87)J971A
M(&1E(&-RZ61I=&\`0W)O86-I80!#=6)A`#0@1F%S97,@86-T=6%L97,`4V5S
M:6]N97,@86-T=6%L97,`2&]R82!A8W1U86P`55),(&%C='5A;`!5<W5A<FEO
M<R!A8W1U86QE<P!4:65M<&\@86-T=6%L`$-O;F1I8VGS;B!A8W1U86PZ(`!%
M<W1I;&\@86-T=6%L`%!E<G-O;F%L:7IA(&QA<R!T87)E87,@82!E:F5C=71A
M<B!A;"!I;FEC:6%R('-E<VGS;B!E;B`E<RX`0V]R=&%R`$-O<G1A<B!S96QE
M8V-I\VX`0VAI<')E`$-I<NUL:6-O("A+3TDX+5(I`$-I<NUL:6-O("A7:6YD
M;W=S+3$R-3$I`$-I<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5*0!297#Z8FQI
M8V$@0VAE8V$`1$0`1$5304-4259!1$\Z(`!$4TX@*'9E82!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E<R]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I`$1I87)I86UE;G1E`,%R7V)O;"!D871O<P!#;VYS=6QT82!D
M92!L82!B87-E(&1E(&1A=&]S`$9E8VAA`%-E(&AA(')E8VEB:61O(&QA(&9E
M8VAA`%-E;&5C8VGS;B!D92!F96-H80!$[6$`15]L:6UI;F%R(&-O;'5M;F$`
M1&5S86-T:79A<B!G=6GS;@!$:6-I96UB<F4`3OIM97)O<R!D96-I;6%L97,`
M4F5D=6-I<B!S86YG<F%D;P!0;W(@;VUI<VGS;@!#;VQO<B!P;W(@;VUI<VGS
M;@!)9&5N=&ED860@<&]R(&]M:7-I\VX`4VAE;&P@<&]R(&]M:7-I\VX`1&5F
M:6YI8VEO;F5S`"9N8G-P.T5L:6UI;F%R)FYB<W`[`$5L:6UI;F%R("5S`$5L
M:6UI;F%R(&-E;&1A`$5L:6UI;F%R(&-O;F1I8VGS;@!%;&EM:6YA<B!G<G5P
M;P!%;&EM:6YA<B!R96=I<W1R;P!%;&EM:6YA<B!P<FEV:6QE9VEO`$5L:6UI
M;F%R('D@=F%C:6%R(&UE;G-A:F5S`$5L:6UI;F%R(&-E;&1A`$5L:6UI;F%R
M(&-O;'5M;F$`16QI;6EN87(@<&QA;G1I;&QA<R!A;'1E<FYA=&EV87,@97AI
M<W1E;G1E<P!%;&EM:6YA<B!C;VUP;&5T86UE;G1E(&5L(&UE;G-A:F4`16QI
M;6EN87(@;65N<V%J97,`16QI;6EN87(@<')I=FEL96=I;W,@9&4@(B5S(@"_
M16QI;6EN87(@<')I=FEL96=I;W,@<&%R82`B)7,B('D@8W5A;'%U:65R('!R
M:79I;&5G:6\@9&5S8V5N9&EE;G1E/P!%;&EM:6YA<B!F:6QA`$5L:6UI;F%R
M(&ED96YT:61A9"!S96QE8V-I;VYA9&$`16QI;6EN87(@<W5B8V%R<&5T87,`
M16QI;6EN82!L82!C;VQU;6YA(&%C='5A;`!%;&EM:6YA(&QA(&9I;&$@86-T
M=6%L`$5L:6UI;F%D;P!392!H82!E;&EM:6YA9&\@96P@9W5I\VX@9&4@86-T
M=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N("(E<R(N`$5N=')E9V%R
M(&5N(&UI(&)U>O-N(&1E($5N=')A9&$`16YT<F5G87(@96X@;6D@8G5Z\VX@
M9&4@16YT<F%D82!Y(&-O<&EA<B!A`$5N=')E9V%R(&5N(&UI(&)U>O-N(&1E
M($5N=')A9&$@>2!R961I<FEG:7(@80!%;G1R96=A<B!E;B!E;"!B=7KS;@!(
M;W)A(&1E(&5N=')E9V$Z`$1I;F%M87)C80!$97-C<FEB82!E;"!P<F]B;&5M
M80!$97-C<FEP8VGS;@!$971A;&QE<R`H=&%M8FGI;B!E;B!E;"!A<F-H:79O
M(&1E(')E9VES=')O(&1E($AO<F1E*3H`4V4@:&%N(')E9VES=')A9&\@;&]S
M(&1E=&%L;&5S('!A<F$@96P@861M:6YI<W1R861O<BX`1&5S87)R;VQL;P!0
M=6YT;R!D92!C;VYD96YS86-I\VX`4'5N=&\@9&4@8V]N9&5N<V%C:?-N(&1E
M(&QA(/IL=&EM82!H;W)A.B``4'5N=&\@9&4@8V]N9&5N<V%C:?-N.B``1&4@
M:7IQ=6EE<F1A(&$@9&5R96-H80!$92!D97)E8VAA(&$@:7IQ=6EE<F1A`$1I
M<F5C=&]R:6\`1&5S86-T:79A<B`E<P!$97-A8W1I=F%D80"_36]S=')A<B!E
M;B!F;W)M871O(&1E(#(T+6AO<F%S/P!/<&-I;VYE<R!D92!6:7-U86QI>F%C
M:?-N`$UO<W1R87(@<')O;O-S=&EC;R!D971A;&QA9&\`OTUO<W1R87(@879I
M<V]S(&1E=&%L;&%D;W,@86P@87!L:6-A<B!C861A(&9I;'1R;S\`36]S=')A
M<B!P<F]N\W-T:6-O("A4048I`$9O<FUA=&\@9&4@=FES=7IA;&EZ86-I\VX`
M3F]T:69I8V%C:?-N(&1E(&-O;G-U;'1A`$1J:6)O=71I`%].;R!E;G9I87(@
M<F5S<'5E<W1A<R!A(&UE;G-A:F5S(&1E(&QI<W1A<R!O(&-O<G)E;R!A(&=R
M86YE;`!.;R!E;&EM:6YA<@!.;R!A8V-E9&5R(&1I<F5C=&%M96YT92!A(&UA
M:6YT96YA;F-E+G!H<`!(86=A(.ES=&\Z`+]#;VYT:65N92!L82!P<FEM97)A
M(&9I;&$@;&]S(&YO;6)R97,@9&4@;&]S(&-A;7!O<S\@4VD@97,@87/M+"!S
M96QE8V-I;VYE(&5S=&$@8V%S:6QL83H`3F\@96UP:65Z82!P;W(`3F\@8V]N
M=&EE;F4`3F\@=&5R;6EN82!P;W(`3F\@97AI<W1E`$YO(&-O:6YC:61E("AC
M;VX@8V]M;V1I;F5S*0!$;VUI;FEC80!297#Z8FQI8V$@1&]M:6YI8V%N80"_
M3F\@9&ES<&]N92!D92!C=65N=&$_(%-O;&EC[71E;&$N`$1E<V-A<F=A<@!$
M97-C87)G87(@)7,`1&5S8V%R9V%R(&QA(&-O;F9I9W5R86-I\VX@9V5N97)A
M9&$@8V]M;R!U;B!G=6GS;B!02%`N`$QI<W1A(&1E<W!L96=A8FQE`$1R;V=A
M<P!#;W)R96\`0V]N=')O;&%D;W(@9&4@<&%S87)E;&$@0V]R<F5O+6$M4TU3
M('!A<F$@<')O=F5E9&]R97,@<75E('!R;W!O<F-I;VYE;B!E<W1E('-E<G9I
M8VEO+@!%4E(`16-U861O<@!-;V1I9FEC87(`36]D:69I8V%R("5S`$UO9&EF
M:6-A<B!B;&]Q=64`36]D:69I8V%R(&=R=7!O`$UO9&EF:6-A<B!P<FEV:6QE
M9VEO`$UO9&EF:6-A<B!P<FEV:6QE9VEO<P!-;V1I9FEC87(@<')I=FEL96=I
M;W,@9&4@)7,`36]D:69I8V%R(&]P8VEO;F5S(&1E.@!-;V1I9FEC87(@<')I
M=FEL96=I;W,@9&4@(B5S(@!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,`
M161U8V%C:?-N`$5G:7!T;P!%;"!386QV861O<@!%;&5M96YT;RXN+@!%;0!#
M;W)R96\`1&ER96-C:?-N(&1E(&-O<G)E;P!,87,@9&ER96-C:6]N97,@9&4@
M8V]R<F5O('1I96YE;B!Q=64@8V]I;F-I9&ER+@!#;W)R96\@8V]N(&-O;F9I
M<FUA8VGS;@!087-A<F5L82!#;W)R96\M82U335,`16UO=&EC;VYE<P!-96YS
M86IE(&5N(&)L86YC;P!297-U;'1A9&\@96X@8FQA;F-O+@!,:6UP:6%R('3I
M<FUI;F]S(&1E(&+Z<W%U961A`$%C=&EV87(@)7,`OU!E<FUI=&ER(&EN<V5R
M8VGS;B!D92!I;>%G96YE<R!D92!L87,@1V%L97+M87,@9&4@9F]T;W,_`+]0
M97)M:71I<B!M96[Z(&1E(&-O;G1E>'1O(&1E;"!B;W3S;B!D97)E8VAO(&1E
M;"!R873S;C\`06-T:79A9&\`0?%O(&1E('1E<FUI;F%C:?-N`%1E<FUI;F$@
M<&]R`$%G<F%N9&%R(&5D:71O<@!);G1R;V1U>F-A('5N82!P<F5G=6YT82!D
M92!S96=U<FED860@<75E('-E(&QE(&9O<FUU;&%RX2!S:2!P<F5C:7-A(')E
M86IU<W1A<B!L82!C;VYT<F%S9?%A+"!P+F4N(">_0W7A;"!E<R!E;"!N;VUB
M<F4@9&4@<W4@;6%S8V]T83\G.@!);G1R;V1U>F-A(&%Q=>T@;&$@55),(&1E
M(&QA(&EM86=E;@!);G1R;V1U>F-A(&QA<R!L971R87,@9&4@9&5B86IO.@!)
M9W5A;"!A`$=U:6YE82!%8W5A=&]R:6%L`$5R:71R96$`17)R;W(`17)R;W(@
M86P@8W)E87(@96P@8FQO<75E.B`E<P!%<G)O<B!A;"!E;&EM:6YA<B!A;F-L
M82!D92!S:6YC<F]N:7IA8VGS;CH@)7,`17)R;W(@86P@96QI;6EN87(@96P@
M<F5G:7-T<F\@9&4@<VEN8W)O;FEZ86-I\VXZ("5S`$5R<F]R(&%L(&]B=&5N
M97(@8V]N=&5N:61O<SH@)7,`17)R;W(@86P@<F5C=7!E<F%R(&5L(&=U:?-N
M(&%C='5A;#H@*"5D*2`E<P!%<G)O<B!A;"!G=6%R9&%R(&QO<R!C86UB:6]S
M+@!%<G)O<B!A;"!A8W1U86QI>F%R(&QA(&-O;G1R87-E\6$Z("5S`$5R<F]R
M(&-O;B!E;"!M96YS86IE(&1E(&-O<G)E;RX`17)R;W(@86P@97-C<FEB:7(@
M(B5S(BX`17-T;VYI80!%=&EO<.UA`,ET;FEC;P!%=7)O<&$`0V%D82`Q-2!M
M:6YU=&]S`$-A9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U
M(&UI;G5T;W,`0V%D82!I;FEC:6\@9&4@<V5S:?-N`$-A9&$@;65D:6$@:&]R
M80!#861A(&UI;G5T;P!686QO<F5S(&1E(&5J96UP;&\Z`$5J96-U=&%R`%)E
M9VQA<R!E>&ES=&5N=&5S`$5X:7-T90!%>'!A;F1I<@!-;W-T<F%R(&)A<G)A
M(&QA=&5R86P`<V4@97-P97)A8F$@)RDG`%-E(&5S<&5R86)A(#$@;V)J971O
M+"!S92!O8G1U=F\@)60N`%-E(&5S<&5R86)A('5N82#Z;FEC82!P86QA8G)A
M(&\@=6X@=.ER;6EN;R!D92!B^G-Q=65D82!E;G1R96-O;6EL;&%D;P!&96-H
M82!D92!V96YC:6UI96YT;P!%>'!O;F5N=&4`0V]L;W(@9&4@;&5T<F$`0V%R
M9V%R(&QA(&-O;F9I9W5R86-I\VX@<&]R($944`!&86QL;R!A;"!T<F%E<B!L
M87,@<')E9F5R96YC:6%S+@!);F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@<V5R
M=FED;W(@3$1!4"X`26YC87!A>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R
M(%--0BX`1F%L;&\@86P@8V]P:6%R(&1E("(E<R(N`$9A;&QO(&%L(&-O<&EA
M<B!A("(E<R(N`$9A;&QO(&%L(&-R96%R('5N82!C;VYE>&GS;B!305-,`$9A
M;&QO(&%L('1R87-L861A<B`B)7,B+@!&86QL;R!A;"!R96-U<&5R87(Z("5S
M`$1E<W!E:F%D;P!)<VQA<R!-86QV:6YA<R`H1F%L:VQA;F0I`$ES;&%S($9A
M<F]E`$5R<F]R(&ER<F5C=7!E<F%B;&4Z`$9A>`!&87AE<P!&96)R97)O`%-E
M('-I96YT92!C;VUO`%-E('-I96YT92!C;VUO.B``4&]C87,@;&QU=FEA<P!%
M<V-A<V\@86=U86-E<F\@9&4@;FEE=F4`36%T<FEZ(&1E(&-A;7!O<P!#05!4
M0TA!(&1E($9I9VQE=`!,971R82!D92!&:6=L970`1FEJ:0!!<F-H:79O`$ZZ
M(&1E(&%R8VAI=F]S.B`E<R!A<F-H:79O`$ZZ(&1E(&%R8VAI=F]S.B`E<R!A
M<F-H:79O<P!!<F-H:79O<P!.;VUB<F4@9&4@87)C:&EV;P!396QE8V-I\VX@
M9&4@87)C:&EV;P!#87)G87(@87)C:&EV;P!,82!C87)G82!D92!A<F-H:79O
M<R!N;R!E<W3A('-O<&]R=&%D82X`1FEL=')A<B!T;V1O<R!L;W,@;65N<V%J
M97,`1FEL=')A<B!S\VQO(&QO<R!M96YS86IE<R!L9>UD;W,`1FEL=')A<B!S
M\VQO(&QO<R!M96YS86IE<R!N;R!L9>UD;W,`3W!C:6]N97,@9&4@9FEL=')A
M9&\`4F5G;&$@9&4@9FEL=')A9&\`4F5G;&%S`$UO<W1R87(@9W5I\VX@9&4@
M9FEL=')A9&\`7U)E9VQA<P!!8W1I=FED860@9&5L(&9I;'1R;SH@4V4@:&$H
M;BD@8V]P:6%D;R`E<R!M96YS86IE*',I(&$@;&$@8V%R<&5T82`B)7,B+@!!
M8W1I=FED860@9&5L(&9I;'1R;SH@4V4@:&$H;BD@96QI;6EN861O("5S(&UE
M;G-A:F4H<RDN`$%C=&EV:61A9"!D96P@9FEL=')O.B!392!H82AN*2!T<F%S
M;&%D861O("5S(&UE;G-A:F4H<RD@82!L82!C87)P971A("(E<R(N`$%C=&EV
M:61A9"!D96P@9FEL=')O.B!392!H82AN*2!E;&EM:6YA9&\@)7,@;65N<V%J
M92AS*2!I;F-L=6ED;W,@96X@;&$@;&ES=&$@;F5G<F$N`$%C=&EV:61A9"!D
M96P@9FEL=')O.B!392!H82!C;W!I861O(&5L(&UE;G-A:F4@(B5S(B!D92`B
M)7,B(&$@;&$@8V%R<&5T82`B)7,B+@!!8W1I=FED860@9&5L(&9I;'1R;SH@
M4V4@:&$@96QI;6EN861O(&5L(&UE;G-A:F4@(B5S(B!D92`B)7,B+@!!8W1I
M=FED860@9&5L(&9I;'1R;SH@4V4@:&$@=')A<VQA9&%D;R!E;"!M96YS86IE
M("(E<R(@9&4@(B5S(B!A(&QA(&-A<G!E=&$@(B5S(BX`3F\@<V4@96YC;VYT
M<O,@96P@9FEL=')O+@!&:6QT<F]S`$9I;FQA;F1I80!#=6%R=&\@8W)E8VEE
M;G1E`$-U87)T;R!C<F5C:65N=&4`4F%Z\VX@9FEJ80!6;VQT96%R`$1I<W!O
M<VEC:?-N`$YI96)L80!,82!C87)P971A("5S(&YO(&5X:7-T92X`0V]L;W(@
M9&4@;&5T<F$`0V]M:61A`%!O<B!C861A(&UE;G-A:F4@96YT<F%N=&4@8V]I
M;F-I9&5N=&4@8V]N.@!087)A(&YA=F5G861O<F5S('%U92!N;R!A9&UI=&%N
M(&EMX6=E;F5S`%!R;V[S<W1I8V\@*%1!1BD`1.UA<R!D96P@<')O;O-S=&EC
M;R`H=&5N9V$@96X@8W5E;G1A('%U92!E;"!P<F]N\W-T:6-O(&9A8VEL:71A
M9&\@:6YC;'5Y92!T86YT;R!E;"!D[6$@8V]M;R!L82!N;V-H93L@=6X@;OIM
M97)O(&=R86YD92!S92!T<F%D=6-I<N$@96X@=6X@8FQO<75E(&UU>2!A;F-H
M;RD`OTAA(&]L=FED861O(&QA(&-O;G1R87-E\6$_`$9O<FUU;&%R:6]S`$9O
M<G1U;F$`5&EP;R!D92!F;W)T=6YA`$9O<G1U;F%S`$9O<G1U;F%S(#(`1F]R
M;W,`4F5E;G9I87(`16P@8V]N=')O;&%D;W(@9&4@9FEL=')A9&\@86-T=6%L
M(&YO('-O<&]R=&$@<F5E;G;M;W,N`%)E96YV[6]S`$UO9&EF:6-A<B!R965N
M=NUO<P!6:64`1G)A;65S`$9R86YC:6$`1G)A;F-I82P@365T<F]P;VQI=&%N
M80!'=6%Y86YA(&9R86YC97-A`%!O;&EN97-I82!F<F%N8V5S80!497)R:71O
M<FEO<R!F<F%N8V5S97,@9&5L('-U<@!$90!$96P@`$1E.@!$97-C<FEP8VGS
M;B!C;VUP;&5T80!,=6YA(&QL96YA`$YO;6)R92!C;VUP;&5T;P!'86+S;@!'
M86QE<NUA(&1E(&QA('%U92!O8G1E;F5R(&QA(&EM86=E;@!'86QE<NUA.@!'
M86UB:6$`1V5N97)A<B!C;VYF:6=U<F%C:?-N(&1E("5S`$/S9&EG;R!G96YE
M<F%D;P!'96]R9VEA`$%L96UA;FEA`$=H86YA`$=I8G)A;'1A<@!.;VUB<F4@
M:6YD:6-A9&\`3W!C:6]N97,@9VQO8F%L97,`27(`1V]E9&5L`$UA<&%S(&1E
M($=O;V=L90!"^G-Q=65D82!E;B!';V]G;&4`17-C86QA(&1E(&=R:7-E<P!-
M87EO<B!Q=64`36%Y;W(@;R!I9W5A;"!Q=64`1W)E8VEA`$=R:65G;R`H25-/
M+3@X-3DM-RD`1W)O96YL86YD:6$`1W)A;F%D80!!9&UI;FES=')A8VGS;B!D
M92!G<G5P;W,`3&]S(&YO;6)R97,@9&4@9W)U<&\@;F\@<'5E9&5N(&1E:F%R
M<V4@96X@8FQA;F-O`$=R;W5P7VQD87`Z($YO('-E('!U961E(&'Q861I<B!E
M;"!G<G5P;R`E<RX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<CH@
M`$=R;W5P7VQD87`Z($EN8V%P87H@9&4@96QI;6EN87(@96P@9W)U<&\@)7,`
M1W)O=7!?;&1A<#H@26YC87!A>B!D92!A8W1U86QI>F%R(&5L(&=R=7!O("5S
M`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYE<V5Y`%!R
M:79I;&5G:6]S(&1E(&EN=FET861O`$PN(&EN=FET861O<P!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=6%Y86YA`$A434P`2%1-3"!S92!N:65G82!C;V)A<F1E
M;65N=&4@82!E;&EM:6YA<B!L82#Z;'1I;6$@8V5L9&$@9&4@;&$@9FEL82X`
M2%1-3$%R96$@<V4@;FEE9V$@8V]B87)D96UE;G1E(&$@96QI;6EN87(@;&$@
M^FQT:6UA(&-O;'5M;F$@9&4@;&$@=&%B;&$N`$A434P@<V4@;FEE9V$@8V]B
M87)D96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA(&9I;&$@9&4@;&$@=&%B
M;&$N`$YO('-E(&5N8V]N='+S(&QA(&%U=&5N=&EF:6-A8VGS;B!(5%10+@!(
M86ET[0!!;&=O<FEM;R!(87-H`$YE8FQI;F$`0V%B96-E<F$`0V%B96-E<F%S
M`$ES;&$@2&5A<F0@92!)<VQA<R!-8T1O;F%L9`!4;W)M96YT82!T<F]P:6-A
M;"!I;G1E;G-A`$AE8G)E;R`H25-/+3@X-3DM."U)*0!!;'1U<F$`07EU9&$`
M07EU9&$@9&5L(&5D:71O<@!!>75D86YT90!(96UI<V9E<FEO`$%Q=>T@=&EE
M;F4@96P@8V]M:65N>F\@9&5L(&%R8VAI=F\Z`$%L=&$`7TEN:6-I;P!386YT
M82!3961E("A#:75D860M17-T861O(&1E;"!6871I8V%N;RD`26YI8VEO`$1O
M;6EC:6QI;P!$:7)E8W1O<FEO('!E<G-O;F%L`%1E;.EF;VYO('!A<G1I8W5L
M87(`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!392!H
M86X@96YC;VYT<F%D;R!D871O<R!834P@)7,@;F\@=N%L:61O<R!E;B!E;"!M
M96YS86IE("5S`$AO<F1E+TMO;&%B.B!.:6YG^FX@;65N<V%J92!C;W)R97-P
M;VYD92!A;"!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z($YO('-E(&5N8V]N='+S
M('5N(&]B:F5T;R!D92!T:7!O("5S(&5N(&5L(&UE;G-A:F4@)7,`2&]R9&4O
M2V]L86(Z(%-E(&AA(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E("5S("(E<R(`
M2&]R9&4O2V]L86(Z($5L(&UO=&]R(&1E(&EN=&5G<F%C:?-N('!R96-I<V$@
M9&4@;&$@97AT96YS:?-N(%!(4"`G9&]M>&UL)P!(;W)D92]+;VQA8CH@26YC
M87!A>B!D92!C<F5A<B!N=65V;R#A<F)O;"!834P@9&5L(&]B:F5T;R`E<P!(
M;W)D92]+;VQA8CH@26YC87!A>B!D92!E;&EM:6YA<B`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@26YC87!A>B!D92!O8G1E;F5R($E$($U)344@9&4@;&$@
M<&%R=&4@9&4@=&EP;R`E<P!(;W)D92]+;VQA8CH@26YC87!A>B!D92!S:6YC
M<F]N:7IA<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26YC87!A>B!D92!S
M:6YC<F]N:7IA<B!E;&5M96YT;W,@8V]M<&%R=&ED;W,Z("5S`$AO<F1E+TMO
M;&%B.B!%;&5M96YT;R!C;VUP87)T:61O(&1E<V-O;F]C:61O("(E<R(`3.UN
M96$@:&]R:7IO;G1A;`!-87)G96X@:&]R:7IO;G1A;`!(;W)I>F]N=&%L.@"_
M0_-M;R!L;&5G\R!H87-T82!A<77M/R`HH4-O;75N[7%U96QO+"!P;W(@9F%V
M;W(A*0"_0W5A;G1A<R!C;VQU;6YA<R!D97-E82!C;VUB:6YA<C\`OT-UX6YT
M;W,@8V%M<&]S("AC;VQU;6YA<RD@:&%Y/P"_0W5A;G1A<R!F:6QA<R!D97-E
M82!C;VUB:6YA<C\`2'5M961A9`!(=6UE9&%D.B``2'5M;W)I<W1A<P!(=6YG
M<NUA`$AA(&9A;&QA9&\@;&$@8W)E86-I\VX@9&5L(&)U>O-N($E-05`Z("5S
M`$AA(&9A;&QA9&\@;&$@96QI;6EN86-I\VX@9&5L(&)U>O-N($E-05`Z("5S
M`$AA(&9A;&QA9&\@;&$@8W)E86-I\VX@9&4@97-P86-I;R!A<VEG;F%D;R!D
M96P@8G5Z\VX@24U!4#H@)7,`1&ER96-C:?-N($E0`$QA(&1I<F5C8VGS;B!)
M4"!N;R!E<W3A(&1I<W!O;FEB;&4N`$QA(&1I<F5C8VGS;B!)4"!N;R!E<W3A
M(&5N=')E(&)L;W%U97,@0TE$4B!P97)M:71I9&]S+@!6:6]L86-I\VX@;&]C
M:V1O=VX@25`N`$E?;G-E<G1A<B!F:6QA(&5N8VEM80!)<VQA;F1I80!3\VQO
M(&EC;VYO<P!)8V]N;W,@9&4@)7,`26-O;F]S(&-O;B!T97AT;P!.;VUB<F4@
M9&4@;&$@:61E;G1I9&%D.@!3:2!N;R!S92!M=65S=')A(&-O<G)E8W1A;65N
M=&4L("5S('!A<F$@86)R:7)L;R!E;B!U;F$@=F5N=&%N82!N=65V82X`4VD@
M;F\@=F4@;FEN9_IN(&EC;VYO(&UE9&EA;G1E($EN=&5R;F5T($5X<&QO<F5R
M+"!P=65D92!T96YE<B!Q=64@86-T:79A<B!E<W1A(&-A<VEL;&$@<&%R82!D
M97-A8W1I=F%R(&QA('1R86YS<&%R96YC:6$@4$Y'+@!3:2!V92!E<W1E(&UE
M;G-A:F4@<VEN(&YI;F=U;F$@:6UA9V5N+"!L82!I;6%G96X@<75E('%U:65R
M92!C87)G87(@;F\@<V4@<'5E9&4@;6]S=')A<B!E;B!S=2!N879E9V%D;W(N
M`%9I<W1A('!R979I83H`55),(&1E(&QA(&EM86=E;@!54DP@9&4@;&$@:6UA
M9V5N.@!);6%G96X@9&4@;&$@9V%L97+M80!);6%G96X@9&4@;&$@9V%L97+M
M83H`4V4@:&$@8V%R9V%D;R!L82!I;6%G96X`26WA9V5N97,`26UP;W)T87(L
M('!A<V\@)60`26UP;W)T86YT90!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O
M<R!I;7!O<G1A9&]S.@!);E]S97)T87(@9FEL82!D96)A:F\`4V4@:&$@:6YD
M:6-A9&\@=6X@8_-D:6=O(&1E(&%C8VGS;B!I;F-O<G)E8W1O+@!.;VUB<F4@
M9&4@=7-U87)I;R!Y+V\@8V]N=')A<V7Q82!I;F-O<G)E8W1O<RX`3F]M8G)E
M(&1E('5S=6%R:6\@;R!D:7)E8V-I\VX@86QT97)N871I=F$@:6YC;W)R96-T
M;W,N(%9U96QV82!A(&EN=&5N=&%R;&\@;R!P\VYG87-E(&5N(&-O;G1A8W1O
M(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('!A<F$@;>%S(&EN
M9F]R;6%C:?-N+@!!=6UE;G1A<B!S86YG<F%D;P!);F1I80!5<W5A<FEO<R!I
M;F1I=FED=6%L97,`16P@8V]N=')O;&%D;W(@9&4@9FEL=')A9&\@86-T=6%L
M(&YO('-O<&]R=&$@<F5G;&%S(&EN9&EV:61U86QE<RX`26YD;VYE<VEA`%-E
M(&AA(&EN9&EC861O('5N(&)U>O-N(&EN97AI<W1E;G1E('!A<F$@96YV[6\@
M9&4@8V]R<F5O+@!);F9O<FUA8VGS;@!);F9O<FUA8VGS;@!,82!I;F9O<FUA
M8VGS;B!Y82!N;R!E<W3A(&1I<W!O;FEB;&4N`$EN<V5R=&%R(&-?;VQU;6YA
M(&1E='+A<P!);G-E<G1A<B!I;6%G96X`26YS97)T87(@=&%B;&$`26YS97)T
M87(@=NUN8W5L;R!796(`26YS97)T87(@7V-O;'5M;F$@9&5L86YT90!);G-E
M<G1A('5N82!N=65V82!C;VQU;6YA(&1E='+A<R!D92!L82!A8W1U86P`26YS
M97)T82!U;F$@;G5E=F$@8V]L=6UN82!D96QA;G1E(&1E(&QA(&%C='5A;`!)
M;G-E<G1A('5N82!F:6QA(&YU979A(&1E8F%J;R!D92!L82!A8W1U86P`26YS
M97)T82!U;F$@9FEL82!N=65V82!E;F-I;6$@9&4@;&$@86-T=6%L`$EN<V5R
M=&$@=6X@<.%R<F%F;R!T<F%S(&5L(&YO9&\@86-T=6%L`$EN<V5R=&$@=6X@
M<.%R<F%F;R!A;G1E<R!D96P@;F]D;R!A8W1U86P`26YS97)T87(@<&QA;G1I
M;&QA(&%L=&5R;F%T:79A`$EN<V5R=&%R('5N82!D:7)E8V-I\VX@9&4@8V]R
M<F5O(&5N(&QA('%U92!R96-I8FER(&QA(&-O;G1R87-E\6$Z`$EN<V5R=&%R
M(&-E;&1A(&1E='+A<P!);G-E<G1A<B!C96QD82!A;G1E<P!);G-E<G1A<B!C
M;VQU;6YA(&1E='+A<P!);G-E<G1A<B!C;VQU;6YA(&%N=&5S`$EN<V5R=&%R
M(&UE;G-A:F5S`$EN<V5R=&%R('#A<G)A9F\@9&5T<N%S`$EN<V5R=&%R('#A
M<G)A9F\@86YT97,`26YS97)T87(@9FEL82!D96)A:F\`26YS97)T87(@9FEL
M82!E;F-I;6$`26YS97)T87(@;&$@<F5S<'5E<W1A(&YE8V5S87)I82!A(&QA
M('!R96=U;G1A(&1E('-E9W5R:61A9#H`26YS97)T87(O36]D:69I8V%R(&EM
M86=E;@!);G-E<G1A<B]-;V1I9FEC87(@=NUN8W5L;P!386QD;R!I;G-U9FEC
M:65N=&4@<&%R82!E;G9I87(@82!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN
M`%-A;&1O(&EN<W5F:6-I96YT92X`16YT97)O`$QI<W1A(&1E(&5N=&5R;W,`
M541(("A#86)E8V5R82!D92!$871O<R!D92!5<W5A<FEO*2!N;R!VX6QI9&$N
M`$1A=&]S(%I)4"!N;R!VX6QI9&]S`$%P;&EC86-I\VX@;F\@=N%L:61A+@!)
M1"!D92!L;W1E(&YO(';A;&ED;RX`4V4@:&%N(&5N=FEA9&\@9&%T;W,@;F\@
M=N%L:61O<RX`1&ER96-C:?-N(&1E(&-O<G)E;R!N;R!VX6QI9&$N`$9O<FUA
M=&\@9&4@87)C:&EV;R!N;R!VX6QI9&\`0VQA=F4@9&4@;&EC96YC:6$@;F\@
M=N%L:61A+@!392!H82!I;F1I8V%D;R!U;F$@=6)I8V%C:?-N(&YO(';A;&ED
M82X`;7-G7W1Y<&4@;F\@=N%L:61O+@!A<&E?:60@;F\@=N%L:61O(&\@9&5S
M87!A<F5C:61O+@!087+A;65T<F]S(&YO(';A;&ED;W,@;R!D97-A<&%R96-I
M9&]S+@!0<FEV:6QE9VEO(&1E;"!P861R92!N;R!VX6QI9&]S+@!)1"!D92!A
M<V]C:6%D;R!N;R!VX6QI9&\N`$/S9&EG;R!D92!P<F]D=6-T;R!N;R!VX6QI
M9&\N`%!R;W1O8V]L;R!N;R!VX6QI9&\N`$1E<W1I;F%T87)I;R!N;R!VX6QI
M9&\Z("(E<R(`3V)J971O(&-O;7!A<G1I9&\@;F\@=N%L:61O+@!$:7)E8V-I
M\VX@9&5L(')E;6ET96YT92!N;R!VX6QI9&$`1&%T;W,@=6YI8V]D92!N;R!V
MX6QI9&]S+@!);G9E;G1A<FEO`$EN=F5R=&ER('-E;&5C8VGS;@!)<N%N+"!2
M97#Z8FQI8V$@27-LX6UI8V$@9&4`27)A<0!)<FQA;F1A`$5S`$ES;&$@9&4@
M36%N`$YO(&5S`$)O<G)A<V-A<R!A:7-L861A<P!)<W)A96P`16UI<V]R`$-U
M<G-I=F$`271A;&EA`$IA;6%I8V$`16YE<F\`2F%P\VX`2F%P;V[I<R`H25-/
M+3(P,C(M2E`I`$IE<G-E>0!*;W)DX6X`2G5L:6\`2G5N:6\`2G5S=&EF:6-A
M<@!!;&EN96%R(&%L(&-E;G1R;P!*=7-T:69I8V%R`$%L:6YE87(@82!L82!I
M>G%U:65R9&$`06QI;F5A<B!A(&QA(&1E<F5C:&$`2V%Z86MH<W1A;@"_0V]N
M<V5R=F%R(&5L(&]R:6=I;F%L/P!+96YY80!%;"!S97)V:61O<B!+97)B97)O
M<R!H82!R96-H87IA9&\@;&$@875T96YT:69I8V%C:?-N+@!.;W9A=&]S(&1E
M;"!+97)N96P`0W)E86-I\VX@9&4@8VQA=F4`2'5E;&QA(&1I9VET86P@9&4@
M;&$@8VQA=F4`5&%M8?%O(&1E(&-L879E`%1I<&\@9&4@8VQA=F4`57-O(&1E
M(&QA(&-L879E.@!,82!C;&%V92!Y82!E>&ES=&4@96X@96P@<V5R=FED;W(@
M9&4@8VQA=F5S('#Z8FQI8V\N`$YI\6]S`$MI<FEB871I`$-O<F5A+"!297#Z
M8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D90!#;W)E82P@4F5P^F)L:6-A
M(&1E`$-O<F5A;F\@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`4V4@<')E
M8VES82!E;"!S;W!O<G1E($Q$05`L('!E<F\@;F\@<V4@9&ES<&]N92!D96P@
M;?-D=6QO($Q$05`@;R!N;R!S92!H82!C87)G861O+@!?1&ES=')I8G5C:?-N
M`$ED:6]M80!,86\L(%)E</IB;&EC82!$96UO8W+A=&EC82!0;W!U;&%R`$-U
M87)T;R!M96YG=6%N=&4`VFQT:6UO(&-A;6)I;R!D92!C;VYT<F%S9?%A`$-U
M87)T;R!M96YG=6%N=&4`VFQT:6UA(&%C='5A;&EZ86-I\VXZ`-IL=&EM82!S
M97-I\VXZ("5S`-IL=&EM82!S97-I\VXZ("5S(&1E<V1E("5S`-IL=&EM82!S
M97-I\VXZ($YU;F-A`$QA='9I80!,97EE<P!$:7-T<FEB=6-I\VX`1&5J87(@
M96X@8FQA;F-O('!A<F$@96QI;6EN87(@96P@8F]R9&4`3&5B86YO;@!)>G%U
M:65R9&$`0V%B96-E<F$@:7IQ=6EE<F1A`%9A;&]R97,@9&4@;&$@:7IQ=6EE
M<F1A`$QE<V]T:&\`365N;W(@<75E`$UE;F]R(&\@:6=U86P@<75E`$YI=F5L
M`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN
M`$QI9V5R82!L;&]V:7IN80!,;'5V:6$@;&EG97)A`$QL=79I82!L:6=E<F$@
M;6%T=71I;F$`3&QU=FEA(&QI9V5R82!V97-P97)T:6YA`$%G=6%C97)O(&QI
M9V5R;P!,;'5V:6%S('D@=')U96YO<P!.979A9&$@<W5A=F4`3&EG97)O(&%G
M=6%C97)O(&1E(&YI979E`$-H87-C87)R:6QL;P!6[6YC=6QO`$5L(';M;F-U
M;&\@87!U;G1A(&$Z`%9I;F-U;&%R(&1I<F5C8VGS;B!D92!C;W)R96\@82!L
M82!PX6=I;F$@9&4@8V]M<&]S:6-I\VX@86P@;6]S=')A<@!6[6YC=6QO<P!#
M;V]K:64@3&EN=7@`3&ES=&%R("T@96P@=7-U87)I;R!P=65D92!E>&%M:6YA
M<B!L82!C87)P971A`$QI<W1A<B!B87-E<R!D92!D871O<P!,:7-T87(@=&5M
M87,@9&4@87EU9&$`3&ES=&%R('1A8FQA<P!,:7-T+4%R8VAI=F4`3&ES="U(
M96QP`$QI<W0M240`3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T
M+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$AA(&9A;&QA9&\@96P@;&ES
M=&%D;R!D92!L87,@<V5S:6]N97,Z("5S`$AA(&9A;&QA9&\@96P@;&ES=&%D
M;R!D92!U<W5A<FEO<SH@)7,`16P@;&ES=&%D;R!D92!U<W5A<FEO<R!E<W3A
M(&1E<VAA8FEL:71A9&\N`$QI=&5R871U<F$`3&ET=6%N:6$`3&5Y96YD;RXN
M+@!(;W)A(&QO8V%L.B``261I;VUA('D@:&]R80!58FEC86-I\VX`26YI8VEA
M<B!S97-I\VX`4F5G:7-T<F\@9&4@;&%S('-E<VEO;F5S(&1E('-I;F-R;VYI
M>F%C:?-N(&%N=&5R:6]R97,`4V%L:7(`26YI8VEA<B!S97-I\VX`5&%R96%S
M(&1E(&EN:6-I;R!D92!S97-I\VX`1F%L;/,@96P@:6YI8VEO(&1E('-E<VGS
M;B!P;W)Q=64@:6YT<F]D=6IO(&EN8V]R<F5C=&%M96YT92!S=2!N;VUB<F4@
M9&4@=7-U87)I;R!O(&-O;G1R87-E\6$N`$9A;&SS(&5L(&EN:6-I;R!D92!S
M97-I\VXN`%1E>'1O(&-O;7!L971O`$%M;W(`0F%J80!!;&9A8F5T;R!G<FEE
M9V\@96X@;6EN^G-C+@!!;&9A8F5T;R!L871I;F\@96X@;6EN^G-C+@!.^FUE
M<F]S(')O;6%N;W,@96X@;6EN^G-C+@!,=7AE;6)U<F=O`$U-`$U/5$0`16P@
M861J=6YT;R!-4RU43D5&(&YO(&-O;G1E;NUA(&1A=&]S+@!-4T<`36%C86\`
M36%C961O;FEA+"!!;G1I9W5A(%)E</IB;&EC82!9=6=O<VQA=F$@9&4`36%D
M86=A<V-A<@!-86=I80!#;W)R96\`061M+B!C;W)R96\`0W)E87(@7W;M;F-U
M;&\N+BX`36%L87=I`$UA;&%S:6$`36%L9&EV87,`36%L:0!-86QT80!'97-T
M:6]N82!L82!L:7-T82!D92!C871E9V]R[6%S(&-O;B!L82!Q=64@971I<75E
M=&%R(&5L96UE;G1O<R!Y(&QO<R!C;VQO<F5S(&%S;V-I861O<R!A(&1I8VAA
M<R!C871E9V]R[6%S+@!-87!A(&UA<#(T`$UA<&$@;6%P<75E<W0`0V]R<F5S
M<&]N9&5N8VEA<R!A;&UA8V5N861A<RX`7U-E\6%L87(@;65N<V%J92!C;VUO
M(&5L:6UI;F%D;P!-87)Z;P!-87)G96X`4V7Q86QA<B!M96YS86IE(&-O;6\Z
M`$UA<F-A<B!C;VX@;&%S(&)A;F1E<F%S(&1E($QE[61O+U-I;B!L965R`$UA
M<F-A<B!C;VX@;W1R87(@8F%N9&5R87,@*'`N92X@26UP;W)T86YT92]297-P
M;VYD:61O*0!)<VQA<R!-87)S:&%L;`!-87)T:6YI8V$`0V]I;F-I9&4@*&-O
M;B!C;VUO9&EN97,I`$-A;7!O<R!C;VEN8VED96YT97,`36%U<FET86YI80!-
M875R:6-I;P!386QD;R!MX7AI;6\@<&5R;6ET:61O+@!392!H82!S;V)R97!A
M<V%D;R!E;"!N^FUE<F\@;>%X:6UO(&1E('!A<G1E<R!D92!M96YS86IE+@!4
M96UP+B!MX7AI;6$@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7`N(&WA>&EM82#Z
M;'1I;6%S(#8@:&]R87,Z(`!.^FUE<F\@;>%X:6UO(&1E(&)L;W%U97,@9&5L
M('!O<G1A;`!.^FUE<F\@;>%X:6UO(&1E(')E9VQA<P!,;VYG:71U9"!MX7AI
M;6$`4V4@:&$@<W5P97)A9&\@96P@;OIM97)O(&WA>&EM;R!D92!D:7)E8V-I
M;VYE<R!E;B!U;F$@;&ES=&$@;F5G<F$@*%1O=&%L(&1E(&1I<F5C8VEO;F5S
M.B`E<RP@3KH@;>%X+B!D92!D:7)E8V-I;VYE<SH@)7,I+B!.;R!S92!P=65D
M96X@8?%A9&ER(&WA<R!D:7)E8V-I;VYE<R!A(&QA(&QI<W1A(&YE9W)A+@!3
M92!H82!S=7!E<F%D;R!E;"!N^FUE<F\@;>%X:6UO(&1E(&1I<F5C8VEO;F5S
M(&5N('5N82!L:7-T82!B;&%N8V$@*%1O=&%L(&1E(&1I<F5C8VEO;F5S.B`E
M<RP@3KH@;>%X+B!D92!D:7)E8V-I;VYE<SH@)7,I+B!.;R!S92!P=65D96X@
M8?%A9&ER(&WA<R!D:7)E8V-I;VYE<R!A(&QA(&QI<W1A(&)L86YC82X`36%Y
M;P!-87EO='1E`$UE9&EC:6YA`$UI96UB<F]S`$9O<FUA=&\@9&5L(&UE;OHZ
M`$-O;6)I;F%R(&-E;&1A<P!-96YS86IE`%-E(&AA(&-O;7!R;V)A9&\@8V]R
M<F5C=&%M96YT92!E;"!M96YS86IE('!E<F\@;F\@<V4@<'5E9&4@=F5R:69I
M8V%R(&5L(&-E<G1I9FEC861O(&1E;"!F:7)M86YT92X`365N<V%J92!C861U
M8V%D;RX`5&EP;R!D92!M96YS86IE`%1I96UP;R!D92!-971A<@!";&]Q=64@
M365T87(@;F\@9&ES<&]N:6)L92X`0FQO<75E($UE=&%R(&YO(&1I<W!O;FEB
M;&4N(%-E(&AA;B!R96=I<W1R861O(&QO<R!D971A;&QE<R!P87)A(&5L(&%D
M;6EN:7-T<F%D;W(N`$YO(&5S=.$@8V]N96-T861A(&QA($UE=&%R1$(`3>ET
M;V1O`$5L(&WI=&]D;R`B)7,B(&YO(&5S=.$@9&5F:6YI9&\`3>ET;V1O(&YO
M(&1E9FEN:61O+B!-Z71O9&\@;&QA;6%D;SH@)7,`3>ET<FEC;P!-Z6II8V\`
M36EC<F]N97-I82P@17-T861O<R!&961E<F%D;W,@9&4`16X@;65D:6\`5&EP
M;R!-:6UE`%1E;7`N(&WM;BX@;&%S(/IL=&EM87,@,C0@:&]R87,Z(`!496UP
M+B!M[6XN(&QA<R#Z;'1I;6%S(#8@:&]R87,Z(`!4;V1A=NUA(&YO(&AA(&5X
M<&ER861O(&QA(&%N=&EG_&5D860@;>UN:6UA(&1E(&QA(&-O;G1R87-E\6$`
M4F5F;&5J87(`36ES8V5LX6YE80!087%U971E(%!%05(@2%144%]297%U97-T
M(&1E<V%P87)E8VED;RX`1F%L=&$@;&$@9&ER96-C:?-N(&$@;&$@<75E(&5N
M=FEA<B!L82!N;W1I9FEC86-I\VX`1F%L=&$@;&$@9&ER96-C:?-N(&$@;&$@
M<75E(')E9&ER:6=I<B!E;"!M96YS86IE`$9A;'1A(&QA(&-O;F9I9W5R86-I
M\VXN(%1I96YE('%U92!G96YE<F%R;&$@86AO<F$@<VD@9&5S96$@=71I;&EZ
M87(@97-T82!A<&QI8V%C:?-N+@!)1"!D92!M96YS86IE(&1E<V%P87)E8VED
M;RX`1F%L=&$@96P@;6]T:79O(&1E;"!R96-H87IO`$9A;'1A(&5L(&UO=&EV
M;R!D92!L82!A=7-E;F-I82X`4&%Q=65T92!014%2($UA:6P@9&5S87!A<F5C
M:61O+@!)1"!D92!S97-I\VX@9&5S87!A<F5C:61O+@!,=6X`0V]R<F5O(&WS
M=FEL`$UO9&5R861O`%-E(&AA(&UO9&EF:6-A9&\@;&$@9F5C:&$`36]D:69I
M8V%R(%523`!-\V1U;&\`36]L9&%V:6$L(%)E</IB;&EC82!D90!-\VYA8V\`
M36]N9V]L:6$`365S('D@8?%O`$UE;G-U86QM96YT90!-;VYT<V5R<F%T`$9A
M<V5S(&1E(&QA(&QU;F$`4V4@:&%N(&5N8V]N=')A9&\@;>%S(&-A;7!O<R!E
M;B!L82!L[6YE82`E9"!Q=64@;&]S("5D(&5S<&5R861O<RX`36%R<G5E8V]S
M`$9U;F1A;65N=&%L;65N=&4@9&5S<&5J861O`$9U;F1A;65N=&%L;65N=&4@
M;G5B;W-O`$9U;F1A;65N=&%L;65N=&4@<V]L96%D;P!4<F%S;&%D87(`1&5S
M<&QA>F%R(&AA8VEA(&%B86IO`$1E<W!L87IA<B!A(&QA(&EZ<75I97)D80!$
M97-P;&%Z87(@82!L82!D97)E8VAA`$)A:F%R(&QA(')E9VQA`%-U8FER(&QA
M(')E9VQA`$1E<W!L87IA<B!H86-I82!A<G)I8F$`1&5S<&QA>F%R(&AA8VEA
M(&%B86IO`$1E<W!L87IA<B!H86-I82!A<G)I8F$`36]Z86UB:7%U90!,:7-T
M87,@9&5S<&QE9V%B;&5S(&UU;'1I+6YI=F5L`$UA<&$@54L@;?IL=&EP;&4`
M4V5L96-C:?-N(&WZ;'1I<&QE`$ED96YT:61A9`!-:2!I9&5N=&ED860`36D@
M<&]R=&%L`$1I<W1R:6)U8VGS;B!D92!M:2!P;W)T86P`37EA;FUA<@!.3RP@
M3D\@97-T;WD@9&4@86-U97)D;P!.^FUE<F\@9&4@7V3M87,@96YT<F4@<F5S
M<'5E<W1A<R!P;W(@875S96YC:6$Z`$YO;6)R90!.86UI8FEA`$YA=7)U`$YE
M<&%L`$AO;&%N9&$`06YT:6QL87,@2&]L86YD97-A<P!54DP@8F%S92!D92!.
M971S8V%P90!54DP@9&4@86YU;&%C:?-N(&1E($-!(&1E($YE='-C87!E`%52
M3"!D92!P;VSM=&EC87,@9&4@0T$@9&4@3F5T<V-A<&4`55),(&1E(')E;F]V
M86-I\VX@9&4@3F5T<V-A<&4`55),(&1E(&%N=6QA8VGS;B!D92!.971S8V%P
M90!.;VUB<F4@9&4@<V5R=FED;W(@4U-,(&1E($YE='-C87!E`$-O;65N=&%R
M:6\@9&5L(&-E<G1I9FEC861O(&1E($YE='-C87!E`%1I<&\@9&4@8V5R=&EF
M:6-A9&\@9&4@3F5T<V-A<&4`4F5D`$YU;F-A`$YU979A($-A;&5D;VYI80!.
M=65V82!C871E9V]R[6$`16YV:6%R(&UE;G-A:F4@82`E<P!,=6YA(&YU979A
M`$YU979A(')E9VQA`$YU979O(&YO;6)R92!D92!U<W5A<FEO("AO<&-I;VYA
M;"D`3G5E=F$@6F5L86YD80!#;VYT<F%S9?%A(&YU979A`$QA(&YU979A(&-O
M;G1R87-E\6$@97AP:7)A<N$@96P@)7@N`$QA<R!C;VYT<F%S9?%A<R!N;R!C
M;VEN8VED96XN`$YU979A('9E;G1A;F$@*%]B;&%N:RD`3F]T:6-I87,`1RX@
M9&4@;F]T:6-I87,`4VEG=6EE;G1E`%!R\WAI;6%S(#0@9F%S97,`3W!C:6]N
M97,@<VEG=6EE;G1E<P!3:6=U:65N=&4^`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`$YO8VAE`$YI=64`3F\`3F\@<V4@:&$@96YC;VYT<F%D;R!U;B!E;&5M
M96YT;R`B)7,B(&5N(&QA(&-O;F9I9W5R86-I\VX@9&5L(&UO=&]R+@!.;R!H
M87D@9&%T;W,@9&4@8V]N9FEG=7)A8VGS;B!P87)A(&UO<W1R87(@9&EF97)E
M;F-I87,N`$YO('-E(&1I<W!O;F4@9&4@97-T<F%T96=I82!D92!E;&%B;W)A
M8VGS;B!D92!I;>%G96YE<R!)4T\N`$YO('-E(&AA(&-O;F9I9W5R861O('5N
M(&UO=&]R('!A<F$@97-T92!S97)V:61O<@!.;R!S92!H86X@8V]N9FEG=7)A
M9&\@;6]T;W)E<R!E;B!B86-K96YD<RYP:'``3F\@:&%Y('!L86YT:6QL82!D
M92!L;W1E<P!.;R!H87D@8FQO<75E<R!E;B!L82!P;W-I8VGS;B!I;F1I8V%D
M80!.;R!S92!H82!I;G1R;V1U8VED;R!U;B!N;VUB<F4@9&4@86=E;F1A('!A
M<F$@;&$@875T96YT:69I8V%C:?-N($U#04PN`%-I;B!C86UB:6]S+@!.;R!S
M92!P=65D96X@8?%A9&ER(&1E<V-E;F1I96YT97,@82!E<W1E('!R:79I;&5G
M:6\N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF
M:6=U<F%C:?-N('!A<F$@)7,N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O
M<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!&5%`N`$YO
M('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C
M:?-N('!A<F$@5D93('!O<B!344PN`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I
M;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!A<F-H
M:79O(%-13"X`3F\@<75E9&$@<V%L9&\N`$YO('-E(&AA(&EN=')O9'5C:61O
M(&5L(&1E<W1I;F\N`$YO('-E(&AA(&-A<F=A9&\@;FEN9_IN(&%R8VAI=F\`
M4VEN(&9I;'1R;W,N(%!U;'-E("(E<R(@<&%R82!C<F5A<B!U;F\N`$YO('-E
M(&AA;B!E<W!E8VEF:6-A9&\@8V%B96-E<F%S`$YO('-E(&AA;B!E;F-O;G1R
M861O(&EC;VYO<RX`3F\@<V4@:&$@9&5F:6YI9&\@;&$@=6)I8V%C:?-N+@!.
M;R!S92!H82!D969I;FED;R!L82!U8FEC86-I\VXN`$YO('-E(&AA(&EN=')O
M9'5C:61O('5N(&UE;G-A:F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N
M;VUB<F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N^FUE<F\N`$YO(&]F
M96YS:79A<P!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P
M87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!(5%10+@!.;R!S92!H82!I;G1R;V1U
M8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!)
M34%0+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A
M(&QA(&%U=&5N=&EF:6-A8VGS;B!+97)B97)O<RX`3F\@<V4@:&$@:6YT<F]D
M=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@
M9&4@:6YI8VEO+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q
M82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!005-35T0N`$YO('-E(&AA(&EN
M=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C
M:?-N(%--0BX`3F\@<V4@:&$@:6YD:6-A9&\@=NUA(&1E(&%C8V5S;R!A(&QO
M<R!B:6YA<FEO<R!/<&5N4U-,+B!087)A('1R86)A:F%R(&-O;B!D871O<R!0
M2T-3(#$R(&AA8V5N(&9A;'1A(&QO<R!B:6YA<FEO<R!/<&5N4U-,+@!3:6X@
M86QT87,@<&5N9&EE;G1E<RX`0V%R96-E(&1E('%U;W1A+@!3:6X@<F%Y87,`
M3F\@<V4@:&$@9V5N97)A9&\@;FEN9_IN(&=U:?-N+@!.;R!S92!H82!E<W!E
M8VEF:6-A9&\@=6X@<V5P87)A9&]R+@!.:6YG=6YO`$YO('-E(&AA;B!E<W!E
M8VEF:6-A9&\@8V%D96YA<P!.;R!E>&ES=&4@96P@87)C:&EV;P!.;R!S92!D
M:7-P;VYE(&1E('5N(&1I<F5C=&]R:6\@9&4@86QM86-E;F%M:65N=&\@=&5M
M<&]R86PN`$YO('-E(&AA(&5N=FEA9&\@96P@;F]M8G)E(&1E('5S=6%R:6\@
M>2]O(&QA(&-O;G1R87-E\6$N`$YO('-E(&AA;B!D979U96QT;R!D871O<R!8
M34P@=N%L:61O<P!3:6X@=F%L;W)E<P!.;R!S92!E;F-O;G1R\R!L82!V97)S
M:?-N(&5N(&QA(&-O;F9I9W5R86-I\VX@;W)I9VEN86PN(%)E9V5N97)A<B!L
M82!C;VYF:6=U<F%C:?-N+@!.;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N
M(&QA(&-O;F9I9W5R86-I\VXN(%)E9V5N97)A<B!L82!C;VYF:6=U<F%C:?-N
M+@!.:6YG=6YA`$YI;F=U;F\@*'5S;R!I;7!L[6-I=&\I`$[S<F1I8V\@*$E3
M3RTX.#4Y+3$P*0!)<VQA(&1E($YO<F9O;&L`2&5M:7-F97)I;R!N;W)T90!)
M<VQA<R!-87)I86YA<R!D96P@3F]R=&4`3F]R=65G80!.;R!D97-P=>ES`$YO
M(&%N=&5S`$YO(&5S('5N(&1I<F5C=&]R:6\`1&ES=&EN=&\@9&4`4VEN(&1E
M<V%R<F]L;&%R+@!3:6X@97-T86)L96-E<@!.;R!E<W3A('-O<&]R=&%D;RX`
M3F]T87,`3F\@:&%Y(&YA9&$@=FES=6%L:7IA8FQE+"!R971R;V-E9&$N`$1I
M<F5C8VGS;B!D92!C;W)R96\@9&4@879I<V]S`$YO=FEE;6)R90!.^FUE<F\`
M3OIM97)O(&1E(&-A<F%C=&5R97,`3OIM97)O(&1E(&-O;'5M;F%S`$[Z;65R
M;R!D92!F:6QA<P!.;R!S92!H86X@97-P96-I9FEC861O(&[Z;65R;W,@82!A
M8W1U86QI>F%R(&5N(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX`06-E<'1A
M<@!/8FIE=&\`0W)E861O<B!D92!O8FIE=&]S`$]C=&%L`$]C='5B<F4`1FEL
M=')A<B!O9F5N<V%S`$]F:6-I;F$`3&$@8V]N=')A<V7Q82!A;G1I9W5A('D@
M;&$@;G5E=F$@9&5B96X@<V5R(&1I<W1I;G1A<RX`0V]N=')A<V7Q82!A;G1I
M9W5A`$QA(&-O;G1R87-E\6$@86YT:6=U82!N;R!E<R!C;W)R96-T82X`3VWA
M;@!3\VQO(&QO<R!S97)V:61O<F5S($E-05`@<V]P;W)T86X@;&%S(&-A<G!E
M=&%S(&-O;7!A<G1I9&%S+@!3\VQO(&UA<F-A<B!E;"!M96YS86IE`%/S;&\@
M;V9E;G-I=F%S`%/S;&\@<V4@<&5R;6ET92!U;F$@9&ER96-C:?-N(&1E(&-O
M<G)E;RX`4_-L;R!E;"!P<F]P:65T87)I;R!O('5N(&%D;6EN:7-T<F%D;W(@
M9&4@<VES=&5M87,@<'5E9&4@8V%M8FEA<B!L82!P<F]P:65D860@;R!L;W,@
M<')I=FEL96=I;W,@9&4@<')O<&EE=&%R:6\@9&4@=6X@<F5C=7)S;R!C;VUP
M87)T:61O`$%B<FER(&5N('5N82!N=65V82!V96YT86YA`$5R<F]R($]P96Y3
M4TPZ($YO('-E('!U961E;B!E>'1R865R(&1A=&]S(&1E(&QA('!A<G1E(%,O
M34E-12!F:7)M861A+@!!8G)I<B!E<W1E(';M;F-U;&\@96X@=6YA('9E;G1A
M;F$@;G5E=F$`4VES=&5M82!O<&5R871I=F\`3W!C:6]N97,`3W!C:6]N97,@
M9&4@86-T=6%L:7IA8VGS;B!D92!G=6EO;F5S+@!/<&-I;VYE<R!D92`E<P!,
M:7-T82!O<F1E;F%D80!/<F=A;FEZ86-I\VX`56YI9&%D(&]R9V%N:7IA=&EV
M80!/<F=A;FEZ86-I\VX`4&QA;G1I;&QA(&1E(&%P;&EC86-I\VX@;W)I9VEN
M86P`4&QA;G1I;&QA<R!O<FEG:6YA;&5S(&5N("5S.@!/=')O`$]T<F$@:6YF
M;W)M86-I\VX`3W1R87,@;W!C:6]N97,`26YT<F]D=6-C:?-N`%!R:79I;&5G
M:6]S(&1E;"!P<F]P:65T87)I;P!,82!A=71E;G1I9FEC86-I\VX@4$%-(&YO
M(&5S=.$@9&ES<&]N:6)L92X`4$5!4CHZ36]T;W(@9&4@8V]R<F5O`$9I<FUA
M(&1I9VET86P@4$=0`$1A=&]S(&-I9G)A9&]S(&-O;B!01U``0VQA=F4@4$=0
M('#Z8FQI8V$`1&%T;W,@9FER;6%D;W,O8VEF<F%D;W,@8V]N(%!'4`!#\V1I
M9V\@4$A0`$EN=.ER<'(N(%!(4`!,;&]V:7IN82!V97-P97)T:6YA`$QL=79I
M82!V97-P97)T:6YA`$-H87!A<G)O;F5S('9E<W!E<G1I;F]S`$YI979E('9E
M<W!E<G1I;F$`06=U86-E<F\@9&4@;FEE=F4@=F5S<&5R=&EN;P!3;VP@=F5S
M<&5R=&EN;P!";W)R87-C87,@=F5S<&5R=&EN87,`3F\@<V4@96YC=65N=')A
M(&QA(&5X=&5N<VGS;B!03U-)6`!);G3I<G!R+B!07TA0`$UA<F=E;@!086MI
M<W3A;@!086QA=0!086QE<W1I;F]S+"!497)R:71O<FEO<R!/8W5P861O<P!0
M86YA;>$`4&%P^F$@3G5E=F$@1W5I;F5A`%!A<F%G=6%Y`%!A<F-I86QM96YT
M92!N=6)O<V\`0V]N=')A<V7Q80!,82!C;VYT<F%S9?%A('-E(&-A;6)I861O
M(&-O<G)E8W1A;65N=&4N`$-O;G1R87-E\6$@:6YC;W)R96-T80!(87D@<75E
M(&EN=')O9'5C:7(@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC
M86-I\VX@4D%$2553+@!#;VYT<F%S9?%A(&-O;B!C;VYF:7)M86-I\VX`0V]N
M=')A<V7Q83H`0V]N=')A<V7Q83H@`$QA<R!C;VYT<F%S9?%A<R!T:65N96X@
M<75E(&-O:6YC:61I<BX`4&5G87(`4&5G87(@9&5L('!O<G1A<&%P96QE<P!6
M[6$`06QT87,@<&5N9&EE;G1E<SH`1V5N=&4`4&]R8V5N=&%J90!296%L:7IA
M<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O`+]296%L:7IA<B!O<&5R
M86-I;VYE<R!D92!M86YT96YI;6EE;G1O(&%L(&EN:6-I87(@<V5S:?-N/P!0
M<FEV:6QE9VEO`$YO('-E(&AA(&5L:6UI;F%D;R!E;"!P<FEV:6QE9VEO("(E
M<R(N`%!R:79I;&5G:6\@9&5N96=A9&\`4')I=FEL96=I;W,`061M:6YI<W1R
M86-I\VX@9&4@<')I=FEL96=I;W,`26YF;W)M86-I\VX@<&5R<V]N86P`4&5R
M^@!-87-C;W1A<P!&:6QI<&EN87,`5&5LZ69O;F\`1F]T;V=R86;M87,`4&ET
M8V%I<FX`4.UX96QE<P!4\W!I8V]S`%!U;'-E(&5N('5N82!C96QD80!#;VYF
M:7)M92!Q=64@9&5S96$@96QI;6EN87(@97-T92!E;&5M96YT;SH`0V]N9FER
M;64@<75E(&1E<V5A(&5L:6UI;F%R(&5L(';M;F-U;&\@82!E<W1E(&5L96UE
M;G1O+@!);G1R;V1U>F-A('5N(&UE<R!Y('5N(&'Q;RX`26YT<F]D=7IC82!E
M;"!N;VUB<F4@9&4@;&$@;G5E=F$@8V%T96=O<NUA.@!);G1R;V1U>F-A('5N
M82!D:7)E8V-I\VX@25`@=N%L:61A+@!);G1R;V1U>F-A('5N82!F96-H82!V
MX6QI9&$L(&-O;7!R=65B92!E;"!N^FUE<F\@9&4@9.UA<R!D96P@;65S+@!)
M;G1R;V1U>F-A('5N82!H;W)A(';A;&ED82X`26YT<F]D=7IC82!E;"!N;VUB
M<F4@9&4@;&$@;G5E=F$@8V%R<&5T83H`4')O<&]R8VEO;F4@=6X@<F5S=6UE
M;B!D96P@<')O8FQE;6$N`$EN=')O9'5Z8V$@<W4@;F]M8G)E(&1E('5S=6%R
M:6\@>2!C;VYT<F%S9?%A+@!,96$@96P@=&5X=&\@<VEG=6EE;G1E+B!$14)%
M(&%C97!T87(@;&]S('3I<FUI;F]S('-I('%U:65R92!U<V%R(&5L('-I<W1E
M;6$N`$EN=')O9'5Z8V$@96P@;G5E=F\@;F]M8G)E(&1E(&-A=&5G;W+M83H`
M4&]L;VYI80!0;VSM=&EC80!%;F-U97-T87,`4&]R='5G86P`4&]S:6-I\VX@
M9&4@;&$@:6UA9V5N`%!O<VEC:?-N(&1E(&QA('1A8FQA`$5N=FEA<B!A(&5S
M=&$@8V%R<&5T82`H;F\@;V)L:6=A9&\@<&]R($E-05`I`%!R96-I<&ET86-I
M;VYE<R!D92!L82AS*2#Z;'1I;6$H<RD@)7,@:&]R82AS*3H@`%!R;V)A8FEL
M:61A9#QB<B`O/F1E('!R96-I<&ET86-I\VX`4')E9G-?;&1A<#H@;F\@<V4@
M96YC;VYT<O,@;&$@97AT96YS:?-N($Q$05`@<F5Q=65R:61A+@!0<F5F<U]S
M97-S:6]N.B!N;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@9&4@<V5S:?-N
M(')E<75E<FED82X`4')E<VGS;@!0<F5S:?-N(&%L(&YI=F5L(&1E;"!M87(Z
M(`!0<F5S:?-N.B``5FES=&$@<')E=FEA`%9I<W1A('!R979I82!D92!L82!I
M;6%G96X@96X@=6YA(&YU979A('9E;G1A;F$`3W!C:6]N97,@86YT97)I;W)E
M<P!);7!R:6UI<B!D;V-U;65N=&\`0VQA=F4@<')I=F%D80"_4')O8FQE;6%S
M/P!$97-C<FEP8VGS;B!D96P@<')O8FQE;6$`4')O>65C=&]S`%1E>'1O(&1E
M;"!I;F1U8W1O<@!#;&%V92!01U`@</IB;&EC80!!;&=O<FET;6\@9&4@8VQA
M=F4@</IB;&EC80!);F9O<FUA8VGS;B!D92!C;&%V92!P^F)L:6-A`$YO('-E
M(&=E;F5R87)O;B!C;W)R96-T86UE;G1E(&QA<R!C;&%V97,@4/IB;&EC82]0
M<FEV861A+@!0=65R=&\@4FEC;P!,:6UP:6%R(&UE;G-A:F5S`%%A=&%R`$-O
M;G-U;'1A`%%U;W1A`$-L879E(%)302!P^F)L:6-A("@E9"!B:70I`%]-;W1I
M=F\`0F]T\VX@9&4@;W!C:?-N`$QL=79I80!,;'5V:6$@;6%T=71I;F$`3&QU
M=FEA('9E<W!E<G1I;F$`06=U86-E<F\`3&QU=FEA('D@3FEE=F4`3&QU=FEA
M(&$@3FEE=F4`4G5E9&$@9&4@;&$@9F]R='5N80!287KS;@`F;F)S<#M,965R
M)FYB<W`[`$QE97(@;65N<V%J97,`OT5L:6UI;F%R(')E86QM96YT92`E<S\@
M17-T82!O<&5R86-I\VX@;F\@<V4@<'5E9&4@9&5S:&%C97(N`+]%;&EM:6YA
M<B!R96%L;65N=&4@;&]S(&1A=&]S(&1E;"!U<W5A<FEO("5S/R!%<W1A(&]P
M97)A8VGS;B!N;R!S92!P=65D92!D97-H86-E<BX`4F5C:6)I9&\`4F5D:7)I
M9VER(&$`5G5E;'9E(&$@<F5A;&EZ87(@;&$@^FQT:6UA(&%C8VGS;@!!8W1U
M86QI>F%R`$%C='5A;&EZ87(@96QE;65N=&]S(&1E(&UE;OH@9&ENX6UI8V]S
M.@!!8W1U86QI>F%R('9I<W1A(&1E;"!P;W)T86P`4F5G97@`17AP<F5S:?-N
M(')E9W5L87(`4F5C:&%Z87(@8V]N(&UO=&EV;P!.879E9V%D;W(@9&4@<F5L
M86-I;VYE<P!2969R97-C87(`3V)S97)V86-I;VYE<P!397)V:61O<F5S(')E
M;6]T;W,`55),(')E;6]T82`H:'1T<#HO+W=W=RYE:F5M<&QO+F-O;2]H;W)D
M92DZ`%%U:71A<@!1=6ET87(@8FQO<75E`%%U:71A<B!C;VQU;6YA`$5L:6UI
M;F%R(&9O<FUA=&\`475I=&%R('!A<@!%;&EM:6YA<B!G=6GS;B!G=6%R9&%D
M;R!D96P@9&ER96-T;W)I;R!T96UP;W)A;"!D96P@<V5R=FED;W(N`$5L:6UI
M;F%R(`!%;&EM:6YA<B!E<W1E(&YO9&\@9&5L(&1O8W5M96YT;P!%;&EM:6YA
M<B!U<W5A<FEO`$5L:6UI;F%R('5S=6%R:6\Z("5S`$YO('-E('!U961E(')E
M<W!O;F1E<B!A(&QA('-O;&EC:71U9"X@0_-D:6=O(&1E(&5R<F]R(&1E=G5E
M;'1O.B``3F\@<V4@96YC;VYT<O,@96P@<V5R=FEC:6\@<V]L:6-I=&%D;RX`
M3F\@<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA
M(&-O;F9I9W5R86-I\VX@9&4@)7,N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!E
M;"`B)7,B(')E<75E<FED;R!E;B!L82!C;VYF:6=U<F%C:?-N(&1E(%9&4RX`
M3F\@<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA
M(&-O;F9I9W5R86-I\VXN`$-A;7!O(&YE8V5S87)I;P!2965N=FEA<B!A`%)E
M96YV:6%D;RUP;W(`3&EM<&EA<@!,:6UP:6%R(&-O;G1R87-E\6$`3&EM<&EA
M<B!C;VYT<F%S9?%A`%)E<W1A=7)A<B#Z;'1I;6$@8V]N<W5L=&$`4F5S=6QT
M861O<P!296=R97-A<B!A;"!L:7-T861O(&1E(&9I;'1R;W,`4F5G<F5S87(@
M82!O<&-I;VYE<P!296=R97-A<B!A;"!L:7-T861O(&1E(')E9VQA<P!2965S
M8W)I8FER(&-O;G1R87-E\6$@;G5E=F$`4F5U;FGS;@!297-T875R87(@8V]N
M9FEG=7)A8VGS;@!/<&-I;VYE<R!D92!E9&EC:?-N(&1E('1E>'1O(&5N<FEQ
M=65C:61O`$-R:6)A<P!$97)E8VAA`$-A8F5C97)A(&1E<F5C:&$`5F%L;W)E
M<R!D92!L82!D97)E8VAA`%!R;W!I961A9&5S(&1E(%]F:6QA+BXN`$9U;F-I
M\VX`4G5M86[M80!':7)A<B`Q.#``1VER87(@82!L82!I>G%U:65R9&$`1VER
M87(@82!L82!D97)E8VAA`%!R;W!I961A9&5S(&1E(&9I;&$`4')O<&EE9&%D
M97,@9&4@9FEL80!&:6QA<SH`4F5G;&$`4V4@:&$@8V]P:6%D;R!L82!R96=L
M80!392!H82!E;&EM:6YA9&\@;&$@<F5G;&$`4F5G;&$@9&5S86-T:79A9&$`
M4F5G;&$@86-T:79A9&$`3F]M8G)E(&1E(&QA(')E9VQA`%)E9VQA.@!287EA
M<P!!<&%R96-E<N%N(')A>6%S(&5N=')E('1O9&%S(&QA<R!F:6QA<R!Y(&-O
M;'5M;F%S`$%P87)E8V5RX6X@<F%Y87,@<_-L;R!E;G1R92!L87,@8V]L=6UN
M87,`07!A<F5C97+A;B!R87EA<R!S\VQO(&5N=')E(&QA<R!F:6QA<P!%:F5C
M=71A<@!&961E<F%C:?-N(%)U<V$`4G5A;F1A`$9I<FUA(&-R:7!T;V=RX69I
M8V$@4R]-24U%`$UE;G-A:F4@8VEF<F%D;R!E;B!3+TU)344`3F\@97-TX2!D
M:7-P;VYI8FQE(&QA(&%U=&5N=&EF:6-A8VGS;B!305-,+@!-96YS+B!335,`
M26YTZ7)P<BX@4U%,`%-E;G1E;F-I82!344P@<&%R82!C;VYS=6QT87,@9&4@
M=F%L;W)E<P!34T@`2&$@9F%L;&%D;R!35$%25%1,4SH@*"5S*2`E<P#)6$E4
M3P!);G3I<G!R+B!37U%,`%-A8@!386YT82!(96QE;F$`4V%I;G0@2VET=',@
M>2!.979I<P!386YT82!,=6/M80!386EN="!0:65R<F4@>2!-:7%U96QO;@!3
M86X@5FEC96YT92!Y($=R86YA9&EN87,`36ES;6\@9G)A;64@*%]S96QF*0!3
M86UO80!386X@36%R:6YO`%-A;G1O(%1O;>%S('D@4'+M;F-I<&4`4')O=F5E
M9&]R(&1E('-A=.EL:71E`$%R86)I82!3875D:71A`$=U87)D87(`1W5A<F1A
M<B`B)7,B`$=U87)D87(@)7,`1W5A<F1A<B!O<&-I;VYE<P!'=6%R9&%R(&]P
M8VEO;F5S`$=U87)D87(@;&$@8V]N9FEG=7)A8VGS;B!G96YE<F%D82!C;VUO
M('5N(&=U:?-N(%!(4"!E;B!E;"!D:7)E8W1O<FEO('1E;7!O<F%L(&1E('-U
M('-E<G9I9&]R+@!392!H82!G=6%R9&%D;R!L82!C;VYF:6=U<F%C:?-N(&1E
M("5S+@!'=6%R9&%R(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N
M9FEG=7)A8VGS;B!E;CH@(B5S(BX`0F]R<F%S8V%S(&%I<VQA9&%S`$-I96YC
M:6$`1W5I\VX`06-T=6%L:7IA8VGS;B!D92!G=6GS;@!.;R!S92!H82!A8W1U
M86QI>F%D;R!E;"!G=6GS;BX`4V4@:&$@86-T:79A9&\@8V]R<F5C=&%M96YT
M92!E;"!G=6GS;BX`4V4@:&$@9&5S86-T:79A9&\@8V]R<F5C=&%M96YT92!E
M;"!G=6GS;BX`0G5S8V%R`$TN(&+Z<W%U961A`$QE[61O`%-E;&5C8VEO;F%R
M(&%R8VAI=F]S`%-E;&5C8VEO;F4@=6YA(&9E8VAA`%-E;&5C8VEO;F4@=6X@
M8V%M<&\`4V5L96-C:6]N92!E;"!G<G5P;R!A(&'Q861I<@!396QE8V-I;VYE
M('5N(&YU979O('!R;W!I971A<FEO`%-E;&5C8VEO;F4@=6X@<V5R=FED;W(`
M4V5L96-C:6]N92!E;"!U<W5A<FEO(&$@8?%A9&ER`%-E;&5C8VEO;F%R('1O
M9&\`4V5L96-C:6]N92!T;V1O<R!L;W,@8V]M<&]N96YT97,@9&4@;&$@9F5C
M:&$N`%-E;&5C8VEO;F%R('5N(&]B:F5T;P!3:6X@<V5L96-C:?-N`%-E;&5C
M8VEO;F4@8V%R<&5T82!D97-T:6YO`%-E;&5C8VEO;F4@;&]S(&-A<N%C=&5R
M97,@<75E(&YE8V5S:71E(&1E(&QA<R!C87-I;&QA<R!D92!A8F%J;RX@4'5E
M9&4@8V]P:6%R;&]S('D@<&5G87)L;W,@9&5L(.%R96$@9&4@=&5X=&\N`%-E
M;&5C8VEO;F4@96P@9&5L:6UI=&%D;W(@9&4@9F5C:&%S.@!396QE8V-I;VYE
M(&5L(&9O<FUA=&\@9&4@9F5C:&%S.@!396QE8V-I;VYE(&QA(&ED96YT:61A
M9"!Q=64@<75I97)A(&-A;6)I87(Z`%-E;&5C8VEO;F4@96P@9&5L:6UI=&%D
M;W(@9&4@:&]R87,Z`%-E;&5C8VEO;F4@96P@9F]R;6%T;R!D92!H;W)A<SH`
M4V5L96-C:6]N92!D;W,@8V%M<&]S(&-O:6YC:61E;G1E<RX`4V5L96-C:6]N
M92!S=2!C;VUB:6YA8VGS;B!D92!C;VQO<F5S+@!396QE8V-I;VYE('-U(&ED
M:6]M82!P<F5F97)I9&\Z`$-A8F5C97)A($%U=&\M1&5F:6YI9&$`16YV:6%R
M(&EN9F]R;64@9&4@<')O8FQE;6%S`$5N=FEA<B!335,`4F5M:71E;G1E`%-E
M;F5G86P`4V5N<V]R.B``4V5P=&EE;6)R90!397)B:6$@>2!-;VYT96YE9W)O
M`$[Z;65R;R!D92!S97)I90!$871O<R!D96P@<V5R=FED;W(@97)R\VYE;W,@
M;R!N;R!D:7-P;VYI8FQE<RX`061M:6YI<W1R86-I\VX@9&4@<V5S:?-N`$AA
M(&-A9'5C861O(&5L($E$(&1E('-E<VGS;BX`4V5S:6]N97,`17-T86)L96-E
M<@!%<W1A8FQE8V4@;W!C:6]N97,@<75E(&QE('!E<FUI=&5N(')E86IU<W1A
M<B!S=2!C;VYT<F%S9?%A('-I(&QL96=A<F$@82!O;'9I9&%R;&$N`$-O;F9I
M9W5R82!S97)V:61O<F5S(')E;6]T;W,@82!L;W,@<75E(&1E<V5E(&%C8V5D
M97(@9&5S9&4@96P@<&]R=&%L+@!$969I;F4@;&%S(&]P8VEO;F5S('!R969E
M<FED87,@9&4@:61I;VUA+"!Z;VYA(&AO<F%R:6$@>2!F96-H87,N`$1E9FEN
M92!L82!A<&QI8V%C:?-N(&1E(&EN:6-I;RP@;&$@8V]M8FEN86-I\VX@9&4@
M8V]L;W)E<RP@;&$@86-T=6%L:7IA8VGS;B!D92!PX6=I;F$@>2!O=')A<R!O
M<&-I;VYE<R!D92!V:7-U86QI>F%C:?-N+@!392!H86X@86-T=6%L:7IA9&\@
M8V]R<F5C=&%M96YT92!L87,@;W!C:6]N97,N`$-O;F9I9W5R86-I\VX`2&%Y
M(&=U:6]N97,@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N
M`%9A<FEA<R!U8FEC86-I;VYE<R!D:7-P;VYI8FQE<R!C;VX@96P@<&%RX6UE
M=')O.B``4V5Y8VAE;&QE<P!#;VUP<F%S`%)E<W5M96X@8V]R=&\`OT1E9FEN
M:7(@8VQA=F5S(&1E(&%C8V5S;R!P87)A(&QA(&UA>6]R[6$@9&4@;&]S(';M
M;F-U;&]S/P`F;F)S<#M-;W-T<F%R)FYB<W`[`$UO<W1R87(@9W5I\VX@86-T
M:79O`$UO<W1R87(@9W5I\VX@86-T=6%L`$UU97-T<F$@;&%S(&1I9F5R96YC
M:6%S(&5N=')E(&QA(&YU979A(&-O;F9I9W5R86-I\VX@>2!L82!A;&UA8V5N
M861A`+]-;W-T<F%R(&AO<F$@9&4@;&$@^FQT:6UA('-E<VGS;B!A;"!I;FEC
M:6%R/P!-;W-T<F%R(&]P8VGS;B!D92!C;VYS97)V87(@96P@;W)I9VEN86P`
M36]S=')A<B!S96QE8W1O<@"_36]S=')A<B!L82!B87)R82!D92!M96[Z(&1E
M(&]P97)A8VEO;F5S(&1E('1A8FQA/P"_36]S=')A<B!E;"!M96[Z("5S(&$@
M;&$@:7IQ=6EE<F1A/P!-=65S=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D
M97,@9&4@8V5L9&$@9&4@=&%B;&$`375E<W1R82!E;"!D:>%L;V=O(&1E('!R
M;W!I961A9&5S(&1E('1A8FQA`$UU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P
M:65D861E<R!D92!F:6QA(&1E('1A8FQA`$UU97-T<F$@96P@9&GA;&]G;R!D
M92!P<F]P:65D861E<R!D92!I;6%G96X`36]S=')A<B!C87)G80!!9W5A8V5R
M;W,`3&QU=FEA<R!M871U=&EN87,`3&QU=FEA<R!V97-P97)T:6YA<P!!9W5A
M8V5R;W,@96X@;&$@=F5C:6YD860`4F5D=6-I<@!0<FEM97)O(')E9'5Z8V$@
M;R!Q=6ET92!D92!E;FUE9&EO(&QO<R!B;&]Q=65S(&-E<F-A;F]S`%-I97)R
M82!,96]N80!!;'1A`$9I<FUA`$%L9V]R:71M;R!D92!F:7)M80!3:6YG87!U
M<@!486UA\6\`3VUI=&ER(&UA;G1E;FEM:65N=&\`17-L;W9A<75I80!%<VQO
M=F5N:6$`3FEE=F4`06=U86-E<F\@9&4@;FEE=F4`06=U86-E<F\@9&4@;FEE
M=F4`06=U86-E<F\@9&4@;FEE=F4@;6%T=71I;F\`06=U86-E<F\@9&4@;FEE
M=F4@=F5S<&5R=&EN;P!%<W!E<V]R(&1E(&QA(&YI979E.B``17%U:79A;&5N
M=&4@9&4@;&$@;FEE=F4@96X@86=U83H@`$ES;&%S(%-A;&]M\VX`4V]M86QI
M80!#86YC:6]N97,@)B!0;V5M87,`4V5L96-C:?-N(&1E;"!S96YT:61O(&1E
M(&QA(&-L87-I9FEC86-I\VX`4F5M:71E;G1E`%-U9.%F<FEC80!%=7)O<&$@
M9&5L('-U<B`H25-/+3@X-3DM,RD`1V5O<F=I82!D96P@4W5R(&4@27-L87,@
M4V%N9'=I8V@@9&5L(%-U<@!(96UI<V9E<FEO('-U<@!%<W!A8VEA9&\@96YT
M<F4@8V5L9&%S(&%D>6%C96YT97,`17-P86-I861O(&5N=')E(&5L(&-O;G1E
M;FED;R!Y(&5L(&)O<F1E(&1E('5N82!C96QD80!397!A<F%D;W(`17-P86-I
M861O`$5S<&%C:6%D;R!Y(&UA<F=E;@!%<W!A\6$`4W!A;0!%<V-R:71U<F$@
M9&4@8V%R86-T97)E<R!E<W!E8VEA;&5S`$1I=FED:7(@8V5L9&$`1&EV:61I
M<B!C;VQU;6YA`$1I=FED:7(@9FEL80!$97!O<G1E<P!3<FD@3&%N:V$`17-T
MX6YD87(`4W1A<B!4<F5K`$'Q;R!D92!I;FEC:6\`17-T861O(&\@<')O=FEN
M8VEA`$5S=&%D;P"_1&5T96YE<B!C;VUP<F]B86-I\VX@<VD@97-T82!R96=L
M82!C;VEN8VED93\`1F]R;6%T;R!D92!A;&UA8V5N86UI96YT;P!$:7)E8V-I
M\VX@9&4@;&$@8V%L;&4`5&%C:&%D80!,:7-T82!D92!C861E;F%S`$5L:6UI
M;F%R(&1O;6EN:6\@9&4@;&$@9&ER96-C:?-N`$5S=&EL;R!;0U-370!$;VT`
M3F\@<V4@96YC;VYT<O,@96P@<W5B9&ER96-T;W)I;R`B)7,B+@!?07-U;G1O
M(&1E;"!M96YS86IE(&1E(&%U<V5N8VEA.@!!<W5N=&\`07-U;G1O.@!%;G9I
M87(`4V4@:&$@96YV:6%D;R!U;F$@<V]L:6-I='5D(&1E(&%L=&$@9&4@(B5S
M(B!E;B!E;"!S:7-T96UA+B!.;R!P;V1RX2!I;FEC:6%R('-E<VGS;B!H87-T
M82!Q=64@<V4@:&%Y82!A<')O8F%D;R!L82!S;VQI8VET=60N`%-U8NUN9&EC
M90#)>&ET;P!392!H82!A\6%D:61O(&-O<G)E8W1A;65N=&4@(B5S(B!A;"!S
M:7-T96UA+@!392!H86X@96QI;6EN861O(&-O<G)E8W1A;65N=&4@;&]S(&1A
M=&]S(&1E;"!U<W5A<FEO("(E<R(@9&5L('-I<W1E;6$N`%-E(&AA(&5L:6UI
M;F%D;R!C;W)R96-T86UE;G1E("(E<R(N`%-E(&AA(&5L:6UI;F%D;R!C;W)R
M96-T86UE;G1E("(E<R(@9&5L('-I<W1E;6$N`%-E(&AA(')E<W1A=7)A9&\@
M8V]R<F5C=&%M96YT92!L82!C;VYF:6=U<F%C:?-N+B!2969R97-Q=64@<&%R
M82!V97(@;&]S(&-A;6)I;W,N`%-E(&AA(&=U87)D861O(&-O<G)E8W1A;65N
M=&$@;&$@8V]P:6$@9&4@;&$@8V]N9FEG=7)A8VGS;BX`4V4@:&$@9W5A<F1A
M9&\@8V]R<F5C=&%M96YT92!L82!C;W!I82`E<R!D92!L82!C;VYF:6=U<F%C
M:?-N+@!392!H82!A8W1U86QI>F%D;R!C;W)R96-T86UE;G1E("(E<R(`4V4@
M:&$@97-C<FET;R!C;W)R96-T86UE;G1E("<E<R<`4W5DX6X`4F5S=6UE;@!!
M;6%N96-E<@!!=&%R9&5C97(`4V]L96%D;P!!;6%N96-E<@!!;6%N96-E<B]!
M=&%R9&5C97(`06UA;F5C97(Z(`!!=&%R9&5C97(`071A<F1E8V5R.B``4W5P
M97+M;F1I8V4`4V]P;W)T90!3=7)I;F%M`$%P96QL:61O`%-V86QB87)D('D@
M2F%N($UA>65N`%-W87II;&%N9&EA`%-U96-I80!3=6EZ80!296=I<W1R;R!D
M92!S:6YC<F]N:7IA8VGS;B!E;&EM:6YA9&\`4WEN8TU,`$5R<F]R(&1E('-I
M;G1A>&ES(&5N(&QO<R!TZ7)M:6YO<R!D92!B^G-Q=65D80!297#Z8FQI8V$@
MP7)A8F4@9&4@4VER:6$`0VAU8F%S8V\`0F]R<F%S8V]S;R!Y('9E;G1O<V\`
M0F]R<F%S8V%S`$)O<G)A<V-A<R!M871U=&EN87,`07)C:&EV;R!44U8`5&%B
M;&$`4')O<&EE9&%D97,@9&4@=&%B;&$`5&%B;&$`4')O<&EE9&%D97,@9&4@
M=&%B;&$`5&%I=^%N`%1A:7?A;BP@4')O=FEN8VEA(&1E($-H:6YA`%1A>6EK
M:7-TX6X`5&%N>F%N:6$L(%)E</IB;&EC82!5;FED82!D90!$97-T:6YO.@!4
M87)E87,`3OIM97)O(&1E('1E;.EF;VYO`%1E;7!E<F%T=7)A(&1U<F%N=&4@
M;&$@^FQT:6UA(&AO<F$Z(`!496UP97)A='5R80!496UP97)A='5R83H@`%1E
M;7!E<F%T=7)A/&)R("\^*"5S3>%X)7,O)7--[6XE<RD@)F1E9SLE<P!.;R!S
M92!E;F-O;G1R\R!L82!P;&%N=&EL;&$@(B5S(BX`061M:6YI<W1R86-I\VX@
M9&4@<&QA;G1I;&QA<P!497AT;P!3\VQO('1E>'1O`$%L:6YE86-I\VX@9&4@
M=&5X=&\`0F]R9&4@<W5P97)I;W(@9&5L('1E>'1O`$IU90!486EL86YDZ7,@
M*%1)4RTV,C`I`%1A:6QA;F1I80!.;R!E<W3A(&1I<W!O;FEB;&4@;&$@97AT
M96YS:?-N($944"X`16P@<VES=&5M82!H:7-T\W)I8V\@97-TX2!D97-H86)I
M;&ET861O+@!%;"!M;W1O<B!D92!I;G1E9W)A8VGS;B!(;W)D92]+;VQA8B!N
M;R!S;W!O<G1A("(E<R(`3F\@<V4@<'5E9&4@:6YI8VEA<B!E;"!R96=I<W1R
M;R!D92!)35-0+@!.;R!S92!H82!C87)G861O(&-O<G)E8W1A;65N=&4@;&$@
M8VQA<V4@36%I;G1E;F%N8V4Z.@!392!H82!C97)R861O(&QA('9E;G1A;F$@
M9&4@;W!C:6]N97,N(%-A;&EE;F1O+@!392!H82!A\6%D:61O(&QA(&1I<F5C
M8VGS;B`B)7,B(&$@;&$@;&ES=&$@;F5G<F$N`%-E(&AA(&'Q861I9&\@;&$@
M9&ER96-C:?-N("(E<R(@82!L82!L:7-T82!B;&%N8V$N`%-I(&1E<V5A('5T
M:6QI>F%R('!E<FUI<V]S+"!E;"!A9&UI;FES=')A9&]R('1I96YE('%U92!C
M;VYF:6=U<F%R('5N('-O<&]R=&4@9&4@<&5R;6ES;W,@<&5R;6%N96YT92X`
M4_-L;R!E;"!B;W)D92!I;F9E<FEO<@!%;"!)1"!D96P@8V]N=&%C=&\@;F\@
M<V4@97-P96-I9FEC\RP@<V4@9&5J\R!E;B!B;&%N8V\@;R!N;R!S92!E;F-O
M;G1R\R!E;B!L82!B87-E(&1E(&1A=&]S+@!392!H82!A\6%D:61O(&-O<G)E
M8W1A;65N=&4@96P@8V]N=&%C=&\@82!S=7,@9&ER96-C:6]N97,N`%!A<F$@
M8V]M<')O8F%R(&5L(&UE;G-A:F4@9FER;6%D;R!H86-E(&9A;'1A(&5L(&)L
M;W%U92!D92!F:7)M82!S97!A<F%D;RX`16P@240@9&4@;&$@;&ES=&$@9&4@
M9&ES=')I8G5C:?-N(&YO('-E(&5S<&5C:69I8_,L('-E(&1E:O,@96X@8FQA
M;F-O(&\@;F\@<V4@96YC;VYT<O,@96X@;&$@8F%S92!D92!D871O<RX`3F\@
M<V4@97-P96-I9FEC\R!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN`$5L(&-O
M;G1R;VQA9&]R(&1I:F\Z(`!,87,@8V%R86-T97+M<W1I8V%S(&1E(&-I9G)A
M9&\@;F5C97-I=&%N('5N82!C;VYE>&GS;B!W96(@<V5G=7)A+@!%;"!A<F-H
M:79O("5S('1E;F1R[6$@<75E(&-O;G1E;F5R('5N82!O<&-I\VX@)7,N`$5L
M(&%R8VAI=F\@)7,@=&5N9'+M82!Q=64@8V]N=&5N97(@86QG=6YA<R!O<&-I
M;VYE<R`E<RX`3F\@<V4@<'5E9&4@8V]P:6%R(&5L(&%R8VAI=F\@<V]B<F4@
M<^T@;6ES;6\N`$5L(&%R8VAI=F\@;F\@8V]N=&EE;F4@9&%T;W,N`$$@8V]N
M=&EN=6%C:?-N('1I96YE(&QA<R!C86)E8V5R87,@9&4@97-T92!M96YS86IE
M(&UE<W-A9V4O<F9C.#(R+@!392!S86)E('%U92!E;"!M;V1O(&1E('!A;G1A
M;&QA(&-O;7!L971A(&1A('!R;V)L96UA<R!C;VX@26YT97)N970@17AP;&]R
M97(@9&5B:61O(&$@9F%L;&]S(&1E;"!N879E9V%D;W(@<75E(&YO(&AE;6]S
M('!O9&ED;R!S;W-L87EA<BX@4'5E9&4@<W5F<FER('9I<W5A;&EZ86-I\VX@
M9&4@8F%S=7)A+"!PZ7)D:61A(&1E(&9U;F-I;VYE<R!D96P@961I=&]R('DO
M;R!C=65L9W5E<R!A;&5A=&]R:6]S(&1E;"!N879E9V%D;W(N(%-I('-U('-I
M<W1E;6$@;W!E<F%T:79O(&5S(%=I;F1O=W,@.7@L(&5S(&UU>2!P<F]B86)L
M92!Q=64@<W5F<F$@=6X@9F%L;&\@9&4@<')O=&5C8VGS;B!G96YE<F%L('D@
M=&5N9V$@<75E(')E:6YI8VEA<B!E;"!E<75I<&\N7&Y<;EEA(&5S=.$@879I
M<V%D;RX@4'5L<V4@06-E<'1A<B!S:2!A^FX@9&5S96$@<')O8F%R(&5L(&5D
M:71O<B!E;B!M;V1O(&1E('!A;G1A;&QA(&-O;7!L971A+@!392!H82!E;&EM
M:6YA9&\@;&$@:61E;G1I9&%D("(E<R(N`%/S;&\@96P@8F]R9&4@:7IQ=6EE
M<F1O`$AA>2!Q=64@:6YD:6-A<FQE(&$@;&$@8VQA<V4@0W)Y<'1?<&=P.CH@
M;&$@=6)I8V%C:?-N(&1E(&QO<R!B:6YA<FEO<R!';G501RX`4V4@:&$@;6]S
M=')A9&\@96P@;65N<V%J92!E;G9I861O(&5L("5S(&$@)7,@8V]N(&5L(&%S
M=6YT;R`B)7,B+@K)<W1O(&YO(&=A<F%N=&EZ82!Q=64@96P@;65N<V%J92!H
M87EA('-I9&\@;&5I9&\@;R!C;VUP<F5N9&ED;RX`3F]M8G)E('5T:6QI>F%D
M;R!A;"!V:6YC=6QA<B!A(&QA('#A9VEN82!D92!C;VUP;W-I8VGS;@!%;"!N
M^FUE<F\@9&4@8V%M<&]S('1I96YE('%U92!S97(@=6X@;OIM97)O+@!(86-E
M(&9A;'1A(&5L(&WS9'5L;R!O<&5N<W-L('!A<F$@;&$@8VQA<V4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!P<F5F97)E
M;F-I82`B)7,B('!O<G%U92!S=7,@9&%T;W,@<V]B<F5P87-A;B!E;"!T86UA
M\6\@;>%X:6UO('!E<FUI=&ED;P!.;R!S92!E;F-O;G1R\R!E;B!E;"!S:7-T
M96UA(&5L('!R;V=R86UA('!A<F$@=F5R(&5S=&4@=&EP;R!D92!D871O<R`H
M)7,I+@!%;"!C87+A8W1E<B!D92!C:71A(&1E8F4@<V5R('-E<B!S\VQO('5N
M;RX`4_-L;R!L;W,@;&%D;W,@:7IQ=6EE<F1O('D@9&5R96-H;P!3\VQO(&5L
M(&QA9&\@9&5R96-H;P!%;"!S97!A<F%D;W(@9&5B92!S97(@<_-L;R!U;F\N
M`%-E(&AA(&5L:6UI;F%D;R!E;"!S97)V:61O<B`B)7,B+@!392!H82!G=6%R
M9&%D;R!E;"!S97)V:61O<B`B)7,B+@!392!H82!E;&EM:6YA9&\@;&$@<V]L
M:6-I='5D(&1E(&%L=&$@9&4@)7,N`$QA(&9I;&$@97-P96-I9FEC861A("@E
M9"D@;F\@97AI<W1E+@!%;"!A<F-H:79O('1E;7!O<F%L("(E<R(@;F\@97AI
M<W1E+@!%;"!T97AT;R!Q=64@:&$@:6YT<F]D=6-I9&\@;F\@8V]I;F-I9&4@
M8V]N(&5L(&1E(&QA('!A;G1A;&QA+@!3\VQO(&QO<R!L861O<R!S=7!E<FEO
M<B!E(&EN9F5R:6]R`%/S;&\@96P@;&%D;R!S=7!E<FEO<@!392!P97)D:65R
M;VX@;&]S(&1A=&]S(&-A<F=A9&]S(&1E<V1E(&5L('!A<V\@86YT97)I;W(N
M`$YO('-E('!U9&\@9W5A<F1A<B!E;"!A<F-H:79O(&-A<F=A9&\N`$YO(&5S
M=.$@9&ES<&]N:6)L92!E;"!B;&]Q=64@9&4@=V5A=&AE<BYC;VTN`$YO('-E
M(&5N8V]N='+S(&5L(&1I<F5C=&]R:6\@9&4@5&5M87,@(B5S(BX`3F\@<V4@
M9&ES<&]N92!D92!O<&-I;VYE<RX`3F\@:&%Y('!A<G1E<R!Q=64@<V4@<'5E
M9&%N(&UO<W1R87(@96X@;.UN96$N`$5N(&5S=&4@8V%M<&\@:&%Y(&1E;6%S
M:6%D;W,@8V%R86-T97)E<RX@2&$@:6YT<F]D=6-I9&\@)7,@8V%R86-T97)E
M<R!Y('1I96YE('%U92!I;G1R;V1U8VER(&UE;F]S(&1E("5S+@!392!P<F]D
M=6IO('5N('!R;V)L96UA(&%L(&'Q861I<B!A("(E<R(@86P@<VES=&5M83H@
M)7,`4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!B;W)R87(@;&]S(&1A=&]S
M(&1E;"!U<W5A<FEO("(E<R(@9&5L('-I<W1E;6$Z(`!392!P<F]D=6IO('5N
M('!R;V)L96UA(&%L(&5L:6UI;F%R(&$@(B5S(B!D96P@<VES=&5M83H@`%-E
M('!R;V1U:F\@=6X@<')O8FQE;6$@86P@86-T=6%L:7IA<B`B)7,B.B`E<P!3
M92!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D96P@87)C:&EV
M;SH@3F\@<V4@8V%R9_,@)7,N`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@8V]N
M(&QA(&-A<F=A(&1E;"!A<F-H:79O+B!%;"`E<R!E<F$@;>%S(&=R86YD92!Q
M=64@96P@=&%M8?%O(&WA>&EM;R!P97)M:71I9&\@*"5D(&)Y=&5S*2X`4V4@
M<')O9'5J;R!U;B!P<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N
M(%/S;&\@<V4@8V%R9_,@<&%R8VEA;&UE;G1E(&5L("5S+@!392!P<F]D=6IO
M('5N(&5R<F]R(&%L(&%C=&EV87(@96P@9W5I\VXN`%-E('!R;V1U:F\@=6X@
M97)R;W(@86P@9&5S86-T:79A<B!E;"!G=6GS;BX`4V4@<')O9'5J;R!U;B!E
M<G)O<B!A;"!M;W-T<F%R(&5S=&$@<&%R=&4@9&5L(&UE;G-A:F4`4V4@<')O
M9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L;W,@9&%T;W,@9&5L(&-O;G1A
M8W1O+@!392!P<F]D=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QO<R!D871O
M<R!I0V%L96YD87(N`%-E('!R;V1U:F\@=6X@97)R;W(@96X@96P@9F]R;75L
M87)I;R!D92!C;VYF:6=U<F%C:?-N+B!0=65D92!Q=64@:&%Y82!O;'9I9&%D
M;R!R96QL96YA<B!U;B!C86UP;R!N96-E<V%R:6\N`%-E('!R;V1U:F\@=6X@
M97)R;W(@86P@96IE8W5T87(@;&$@9G5N8VGS;B!E<W!E8VEF:6-A9&$@9&4@
M;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RX@5G5E;'9A(&$@<')O8F%R(&WA
M<R!A9&5L86YT92X`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A8W1U86QI>F%R
M(&QO<R!D971A;&QE<R!D96P@8V]N=&%C=&\N(%9U96QV82!A('!R;V)A<B!M
MX7,@861E;&%N=&4N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L:7IA
M<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN(%9U96QV82!A('!R;V)A<B!M
MX7,@861E;&%N=&4N`$5S=&4@<V5R=FED;W(@24U!4"!N;R!S;W!O<G1A(&QA
M<R!C87)P971A<R!C;VUP87)T:61A<RX`R7-T92!N;R!P87)E8V4@<V5R('5N
M(&%R8VAI=F\@<F%R(';A;&ED;RX`R7-T92!N;R!P87)E8V4@<V5R('5N(&%R
M8VAI=F\@>FEP(';A;&ED;RX`R7-T92!N;R!P87)E8V4@<V5R('5N(&[Z;65R
M;R!D92!T87)J971A(';A;&ED;RX`17-T92!C;VYT<F]L861O<B!P97)M:71E
M(&5N=FEA<B!M96YS86IE<R!A('1R87;I<R!D92!L82!P87-A<F5L82!#;&EC
M:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI+"!M961I86YT92!L82!!
M4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A
M:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI+"!M961I86YT92!L82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R
M('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R
M96QA('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!M961I86YT
M92!L82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R
M(&UE;G-A:F5S('9I82!33510(&$@=')A=NES(&1E(&QA('!A<V%R96QA(&1E
M(%9O9&%F;VYE(&1E($ET86QI82P@<_-L;R!A(&[Z;65R;W,@5F]D869O;F4N
M($AA8V4@9F%L=&$@=6YA(&-U96YT82!D92!C;W)R96\@9&4@5F]D869O;F4@
M9&4@271A;&EA("AH='1P.B\O=W=W+C$Y,"YI="DN`$AA8V4@9F%L=&$@97-T
M92!C86UP;RX`17-T92!C86UP;R!S\VQO('!U961E(&-O;G1E;F5R(&5N=&5R
M;W,N`$5S=&4@8V%M<&\@<_-L;R!P=65D92!C;VYT96YE<B!N^FUE<F]S('D@
M;&]S(&1O<R!P=6YT;W,N`$5S=&4@8V%M<&\@<_-L;R!P=65D92!C;VYT96YE
M<B!V86QO<F5S(&]C=&%L97,N`$5S=&4@8V%M<&\@=&EE;F4@<75E('-E<B!U
M;F$@;&ES=&$@9&4@96YT97)O<R!S97!A<F%D;W,@<&]R(&-O;6%S(&\@97-P
M86-I;W,N`$5S=&4@8V%M<&\@=&EE;F4@<75E('-E<B!U;B!N^FUE<F\@=N%L
M:61O+@!%<W1E(&-A;7!O('1I96YE('%U92!C;VYT96YE<B!U;B!C\V1I9F\@
M9&4@8V]L;W(@96X@9F]R;6%T;R!21T(@2&5X861E8VEM86PL('!O<B!E:F5M
M<&QO("<C,3(S-&%F)RX`66$@<V4@:&$@<')O8V5S861O(&5S=&4@9F]R;75L
M87)I;RX`17-T;R!E<R`E<RX`R7-T;R!E<R!U;B!O8FIE=&\@9&4@2V]L86(@
M1W)O=7!W87)E+B!087)A('9E<FQO(&YE8V5S:71A('5N(&-L:65N=&4@9&4@
M8V]R<F5O("!Q=64@96YT:65N9&$@96P@9F]R;6%T;R!+;VQA8B!'<F]U<'=A
M<F4N(%!A<F$@=F5R('5N82!L:7-T82!D92!D:6-H;W,@8VQI96YT97,@=FES
M:71E("5S`$5S=&4@;65N<V%J92!S92!E<V-R:6)I\R!C;VX@=6X@:G5E9V\@
M9&4@8V%R86-T97)E<R`H)7,I(&1I<W1I;G1O(&%L('-U>6\N`$5S=&4@;OIM
M97)O(&1E8F4@<V5R('!O<B!L;R!M96YO<R!U;B!U;F\N`$5S=&4@<V5R=FED
M;W(@;F\@<'5E9&4@9&5S8V]M<')I;6ER(&%R8VAI=F]S('II<"!Y(&=Z:7`N
M`$5S=&4@<VES=&5M82!A8W1U86QM96YT92!E<W3A(&1E<V%C=&EV861O+@!%
M<W1E('9A;&]R('1I96YE('%U92!S97(@=6X@;OIM97)O+@!%<W1A('9E;G1A
M;F$@<_-L;R!P=65D92!A8G)I<G-E(&1E<V1E('5N82!V96YT86YA(&1E(&]P
M8VEO;F5S`%1R=65N;P!);F-I9&5N8VEA<P!(;W)A`$,N('1I96UP;W,`1F]R
M;6%T;R!H;W)A<FEO`%-E;&5C8VGS;B!D92!H;W)A`%1I;6]R+4QE<W1E`%3M
M='5L;P!4[71U;&\@*&-O;G-E:F\I.@!087)A`%!A<F$@<V5L96-C:6]N87(@
M=F%R:6]S(&-A;7!O<RP@;6%N=&5N9V$@<'5L<V%D82!L82!T96-L82!#;VYT
M<F]L("A00RD@;R!#;VUA;F1O("A-86,I(&%L(&AA8V5R(&-L:6-K+@!087)A
M.@!(;WD`0V]N;75T87(@;W)I9V5N($A434P`5&]G;P!4;VME;&%U`$UA\6%N
M80!4;VYG80!3=7!E<FEO<@!&<F%M92!S=7!E<FEO<B`H7W1O<"D`5')A9'5C
M8VEO;F5S`%1R:6YI9&%D('D@5&]B86=O`%9E<F1A9&5R;R!O(&9A;'-O`$UA
M<@!4^FYE>@!4=7)Q=>UA`%1U<F-O("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T
MX6X`27-L87,@5'5R:W,@>2!#86EC;W,`5'5V86QU`$5S8W)I8F$@<W4@96QE
M8V-I\VXZ(`#-;F1I8V4@52Y6+CH@`%523`!54DP@9&4@<W4@:6YF;W)M92!D
M92!E<W1A9&\@9&4@96YV[6\@9&5L(&=U:?-N`%523#H`56=A;F1A`%5C<F%N
M:6$`26YC87!A>B!D92!A8V-E9&5R(&%L(&1I<F5C=&]R:6\@5D93+@!);F-A
M<&%Z(&1E(&'Q861I<B!I;F9O<FUA8VGS;B!D92!U<W5A<FEO(&%D:6-I;VYA
M;"!A;"!R96%L:7IA<B!E;"!A;'1A+@!);F-A<&%Z(&1E(&-A;6)I87(@;&]S
M('!R:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E
M(&-A;6)I87(@;&]S('!R:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&4R`E<R\E
M<RX`26YC87!A>B!D92!C86UB:6%R(&$@)7,N`$EN8V%P87H@9&4@8V]M<')O
M8F%R(&5L('1A;6'Q;R!D92`B)7,B+@!);F-A<&%Z(&1E(&-O;7!R;V)A<B!E
M;"!T86UA\6\@9&4@(B5S+R5S(BX`26YC87!A>B!D92!C;VYE8W1A<G-E(&%L
M('-E<G9I9&]R(%-13"X`26YC87!A>B!D92!C;VYE8W1A<B!C;VX@4U-,+@!)
M;F-A<&%Z(&1E(&-O<&EA<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!C
M<F5A<B!E;"!D:7)E8W1O<FEO(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&-R96%R
M(&5L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(&-R96%R(&5L(&%R8VAI
M=F\@5D93+@!);F-A<&%Z(&1E(&-R96%R(&QA(&-A<G!E=&$@5D93("(E<R(`
M26YC87!A>B!D92!C<F5A<B!U;B!A<F-H:79O(%9&4R!V86/M;RX`26YC87!A
M>B!D92!D97-C;VUP<FEM:7(@;&]S(&1A=&]S+@!);F-A<&%Z(&1E(&5L:6UI
M;F%R("(E<R(L(&5L(&1I<F5C=&]R:6\@;F\@97-TX2!V86/M;RX`26YC87!A
M>B!D92!E;&EM:6YA<B`B)7,B.B`E<RX`26YC87!A>B!D92!E;&EM:6YA<B`E
M<RP@96P@9&ER96-T;W)I;R!N;R!E<W3A('9A8^UO`$EN8V%P87H@9&4@96QI
M;6EN87(@96P@9&ER96-T;W)I;R!61E,@9&4@9F]R;6$@<F5C=7)S:79A+@!)
M;F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z
M(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93.B`E<RX`26YC87!A>B!D
M92!E;&EM:6YA<B!E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&5L
M:6UI;F%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&QA
M(&-A<G!E=&$@5D93("(E<R(N`$EN8V%P87H@9&4@96QI;6EN87(@96P@5D93
M(&1E(&9O<FUA(')E8W5R<VEV83H@)7,N`$EN8V%P87H@9&4@9&5T97)M:6YA
M<B!E;"!D:7)E8W1O<FEO(&%C='5A;"X`26YC87!A>B!D92!E>'1R865R(&QO
M<R!D971A;&QE<R!D96P@8V5R=&EF:6-A9&\N`$EN8V%P87H@9&4@8V%R9V%R
M(&QA(&1E9FEN:6-I\VX@9&4@)7,N`$EN8V%P87H@9&4@=')A<VQA9&%R(&5L
M(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI=F\@5D93
M("(E<R(N`$EN8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!61E,@<&%R82!E
M<V-R:6)I<BX`26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(%9&4RX`26YC
M87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(&-O;7!R:6UI9&\N`$EN8V%P87H@
M9&4@;&5E<B!U;B!A<F-H:79O(%9&4R`H:&$@9F%L;&%D;R!F:6QE<VEZ92@I
M*2X`26YC87!A>B!D92!L965R('5N(&%R8VAI=F\@5D93("AH82!F86QL861O
M(&=E=$9I;&53:7IE*"DI+@!);F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV;SH@
M`$EN8V%P87H@9&4@;&5E<B!E;"!D:7)E8W1O<FEO('9F<W)O;W0N`$EN8V%P
M87H@9&4@<F5N;VUB<F%R("5S(&-O;6\@)7,Z(&QA(&-A<G!E=&$@9&5S=&EN
M;R!Y82!E>&ES=&4`26YC87!A>B!D92!R96YO;6)R87(@96P@9&ER96-T;W)I
M;R!61E,N`$EN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&1I<F5C=&]R:6\@5D93
M.B`E<RX`26YC87!A>B!D92!R96YO;6)R87(@96P@87)C:&EV;R!61E,@(B5S
M(@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4R`E<R\E<RX`
M26YC87!A>B!D92!R96YO;6)R87(@96P@87)C:&EV;R!61E,N`$EN8V%P87H@
M9&4@96IE8W5T87(@)VUK:7-O9G,G+@!.;R!S92!P=65D92!T<F%D=6-I<B!E
M<W1E(&1O8W5M96YT;R!D92!7;W)D`$EN8V%P87H@9&4@97-C<FEB:7(@96P@
M87)C:&EV;R!61E,@(B5S(BX`26YC87!A>B!D92!E<V-R:6)I<B!U;B!A<F-H
M:79O(%9&4R`H:&$@9F%L;&%D;R!C;W!Y*"DI+@!);F-A<&%Z(&1E(&5S8W)I
M8FER(&QO<R!D871O<R!D96P@87)C:&EV;R!61E,N`$EN8V%P87H@9&4@97-C
M<FEB:7(@=6X@87)C:&EV;R!61E,L('-E('-U<&5R87+A(&QA('%U;W1A+@!3
M=6)R87EA9&$`1&5S:&%C97(@8V%M8FEO<P!$97-H86-E(&QA(/IL=&EM82!A
M8V-I\VX`4F5S<'5E<W1A(&EN97-P97)A9&$@9&5L('-E<G9I9&]R(&5N(&QA
M(&-O;F5X:?-N.B``4F5S<'5E<W1A(&EN97-P97)A9&$@9&5L('-E<G9I9&]R
M(&$Z(`!3:6X@8V%T96=O<NUA`%5N:6-O9&4@*%541BTX*0!%;6ER871O<R#!
M<F%B97,@56YI9&]S`$EN9VQA=&5R<F$`17-T861O<R!5;FED;W,`17-T861O
M<R!5;FED;W,@;65N;W,@;&%S(&ES;&%S('!E<FEFZ7)I8V%S`%5N:61A9&5S
M`$1E<V-O;F]C:61O`$%P:6US9VED(&1E<V-O;F]C:61O("A)1"!D92!M96YS
M86IE(&1E(&QA($%022DN`$-L:6US9VED(&1E<V-O;F]C:61O("A)1"!D92!M
M96YS86IE(&1E;"!C;&EE;G1E*2X`4V4@:&$@9&5F:6YI9&\@=6YA('5B:6-A
M8VGS;B!D97-C;VYO8VED82X`57-U87)I;R!O(&-O;G1R87-E\6$@9&5S8V]N
M;V-I9&]S+@!%;&EM:6YA<B!V[6YC=6QO(&1E;"!E;&5M96YT;R!A8W1U86P`
M4VEN(&YO;6)R90!,;W,@9W5I;VYE<R!S:6X@<')I=FEL96=I;W,@;F\@<'5E
M9&5N(&%C8V5D97(@9&4@9F]R;6$@<')O9W)A;>%T:6-A(&$@0V]R=&%R+T-O
M<&EA<B]096=A<B!P;W(@<F%Z;VYE<R!D92!S96=U<FED860N(%!U;'-E($%C
M97!T87(@<&%R82!V97(@96X@;6]Z:6QL82YO<F<@=6YA(&YO=&$@=.EC;FEC
M82!Q=64@;&4@;75E<W1R92!C\VUO('!E<FUI=&ER('%U92!U;B!G=6GS;B!A
M8V-E9&$@86P@<&]R=&%P87!E;&5S+@!!;G5L87(@8V]L;W(`17AT96YS:?-N
M(&YO('-O<&]R=&%D80!!8W1U86QI>F%R`$%C='5A;&EZ87(@)7,`06-T=6%L
M:7IA<B!U<W5A<FEO`%-E(&AA(&%C='5A;&EZ861O("(E<R(N`%-E(&AA(&5L
M:6UI;F%D;R!E;"!G=6GS;B!D92!A8W1U86QI>F%C:?-N+@!#87)G87(`4V4@
M:&%N(&-A<F=A9&\@96X@96P@<V5R=FED;W(@=&]D;W,@;&]S(&%R8VAI=F]S
M(&1E(&-O;F9I9W5R86-I\VX@9&4@87!L:6-A8VEO;F5S+@!!;&9A8F5T;R!L
M871I;F\@96X@;6%Y^G-C+@!.^FUE<F]S(')O;6%N;W,@96X@;6%Y^G-C+@!5
M<G5G=6%Y`%5S87(@86-T=6%L.B`E<P!5<V%R(%-33`!392!U<V$@<VD@96P@
M=7-U87)I;R]C;VYT<F%S9?%A('-O;B!D:7-T:6YT;W,@96X@96P@<V5R=FED
M;W(@24U34"X`57-U87)I;P!%;"!U<W5A<FEO("5S(&-A<F5C92!D92!A=71O
M<FEZ86-I\VX@<&%R82`E<RX`061M:6YI<W1R86-I\VX@9&4@=7-U87)I;W,`
M3W!C:6]N97,@9&4@=7-U87)I;P!296=I<W1R;R!D92!U<W5A<FEO<P!%<W1A
M('-E9&4@=&EE;F4@9&5S86-T:79A9&\@96P@<F5G:7-T<F\@9&4@=7-U87)I
M;W,N`$YO('-E(&AA(&5N8V]N=')A9&\@;&$@:61E;G1I9&%D`%5S=6%R:6\`
M66$@97AI<W1E(&5L(&YO;6)R92!D92!U<W5A<FEO("(E<R(N`%5S=6%R:6\Z
M`%5S=6%R:6\Z(`!5<W5A<FEO<R!E;B!E;"!S:7-T96UA.@!5>F)E:VES=.%N
M`$YO(&5X:7-T92!E;"!D:7)E8W1O<FEO(%9&4RX`075S96YC:6$`36]D:69I
M8V%R(&YO=&EF:6-A8VGS;B!D92!A=7-E;F-I80!%;"!C;VYT<F]L861O<B!D
M92!F:6QT<F%D;R!A8W1U86P@;F\@<V]P;W)T82!N;W1I9FEC86-I;VYE<R!D
M92!A=7-E;F-I82X`3&%S('5B:6-A8VEO;F5S(';A;&ED87,@96YC;VYT<F%D
M87,@:6YC;'5Y96XZ(`!686QI9&5Z`%9A;&]R(&5N(&UI;G5T;W,@82!P87)T
M:7(@9&4@86AO<F$N`$5L('9A;&]R(&5X8V5D92!E;"!T86UA\6\@;>%X:6UO
M(&1E("5S+@!686QO<F5S`%9A;&]R97,@82!S96QE8V-I;VYA<@!686YU871U
M`%9A<FEA8FQE`%9E;F5Z=65L80!(82!F86QL861O(&QA(&-O;7!R;V)A8VGS
M;B`M(&5S=&4@;65N<V%J92!P=65D92!H86)E<G-E(&9O<GIA9&\N`%9E<G-I
M\VX`0RX@=F5R<VEO;F5S`$%L:6YE86-I\VX@=F5R=&EC86P`36%R9V5N('9E
M<G1I8V%L`%9E<G1I8V%L.@!-=7D@86QT80!6:65T;F%M`%9I971N86UI=&$@
M*%9)4T-)22D`5F5R("5S`%9E<B!U;F$@<.%G:6YA('=E8B!E>'1E<FYA`%9E
M<B!C;VUO("5S`$ES;&%S(%;M<F=E;F5S+"!"<FETX6YI8V%S`$ES;&%S(%;M
M<F=E;F5S+"!5+E,N`%9I<VEB:6QI9&%D`%9I<VEB:6QI9&%D.B``5F]D869O
M;F4@9&4@271A;&EA(&UE9&EA;G1E(%--5%``059)4T\`H:&A041615)414Y#
M24$A(2$@14Q)34E.12!-04Y504Q-14Y412!%3"!'54G33B!$12`E<RX`5TE.
M('!O<B!(5%10`%=A;&QI<R!Y($9U='5N80!!9'9E<G1E;F-I80!-:64`4')E
M=FES:?-N(&1E;"!T:65M<&\`1&%T;W,@9&5L('1I96UP;R!S=6UI;FES=')A
M9&]S('!O<@!796%T:&5R+F-O;0!796(`4V5D92!796(`4V5M86YA;&UE;G1E
M`$)I96YV96YI9&\`0FEE;G9E;FED;W,@82`E<P!":65N=F5N:61O+"`E<P!/
M97-T92`H25-/+3@X-3DM,2D`3V5S=&4@*$E33RTX.#4Y+3$U*0!3X6AA<F$@
M3V-C:61E;G1A;`!$:7)E8V-I;VYE<R!D92!L:7-T82!?8FQA;F-A.@"_477I
M(&%P;&EC86-I\VX@9&5B97+M82!M;W-T<F%R("5S(&%L(&EN:6-I87(@;&$@
M<V5S:?-N/P"_0W7A;"!E<R!E;"!C87+A8W1E<B!D96QI;6ET861O<C\`OT-U
MX6P@97,@96P@8V%RX6-T97(@9&4@8VET861O/P!-87!A(&1E(&QO8V%L:7IA
M8VGS;B!D92!!=7-T<F%L:6$`477I(&9A<V5S`%!L=6=I;G,@:&%B:6QI=&%D
M;W,@9&5L(&5D:71O<B!D92!T97AT;R!E;G)I<75E8VED;RX`3&ES=&$@8FQA
M;F-A`$UO9&EF:6-A<B!L:7-T82!B;&%N8V$`16P@8V]N=')O;&%D;W(@9&4@
M9FEL=')A9&\@86-T=6%L(&YO('-O<&]R=&$@;&ES=&$@8FQA;F-A<RX`1&ER
M96-C:6]N97,@:6YC;'5I9&%S(&5N(&QA(&QI<W1A(&)L86YC80!!;F-H=7)A
M`$%N8VAU<F$@96X@=6YI9&%D97,@0U-3`$%N8VAU<F$@9&5L(&UE;OH@)7,@
M:7IQ=6EE<F1O("AD:7-P;VYI8FQE(&5N(&QA('!R\WAI;6$@<V5S:?-N*3H`
M06YC:'5R82!D92!L82!T86)L80!5;FED861E<R!D92!A;F-H=7)A`$%N8VAU
M<F$Z`%=I:VD`5FEE;G1O`%9I96YT;R!M871U=&EN80!696QO8VED860@9&5L
M('9I96YT;R!E;B!N=61O<P!6:65N=&\Z`%9I96YT;SH@`%-A8FED=7+M80!$
M97-E;W,`16UP;&5O`$1I<F5C8VGS;B!D96P@=')A8F%J;P!496SI9F]N;R!D
M96P@=')A8F%J;P!.^FUE<F\@97)R\VYE;R!D92!C86UP;W,@96X@;&$@;.UN
M96$@)60N(%-E(&5S<&5R86)A;B`E9"!Y(&AA>2`E9"X`3OIM97)O(&5R<O-N
M96\@9&4@8V%M<&]S+B!392!E<W!E<F%B86X@)60@>2!H87D@)60N`$]F9G-E
M="`E9"!E<G+S;F5O(&%L(&QE97(@=6X@87)C:&EV;R!61E,N`%@M4')I;W)I
M='D`6"U2968`6"U3<&%M+4QE=F5L`%@M4W!A;2U38V]R90!8+5-P86TM4W1A
M='5S`$QI;6ET86-I;VYE<R!BX7-I8V%S(%@U,#EV,P!5<V\@9&4@8VQA=F4@
M97AT96YD:61A(%@U,#EV,P!.;VUB<F4@86QT97)N871I=F\@9&4@87-U;G1O
M(%@U,#EV,P!)9&5N=&EF:6-A9&]R(&1E(&-L879E(&1E(&%S=6YT;R!8-3`Y
M=C,`17AT96YS:6]N97,@6#4P.78S`$%!`$%!04$`H4UA<&$@9&4@66%H;V\A
M`$%N=6%L;65N=&4`665M96X`4^T`4^TL(&QO(&%C97!T;P!%<W3A(&5N($U/
M1$\@5$585$\N(%5T:6QI8V4@96P@8F]T\VX@6SP^72!P87)A(')E9W)E<V%R
M(&%L(&UO9&\@5UE325=91RX`3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P
M87)A(&-R96%R(&WA<R!D92`E9"!B;&]Q=65S+@!.;R!D:7-P;VYE(&1E('!R
M:79I;&5G:6]S('!A<F$@8W)E87(@;>%S(&1E("5D(')E9VQA<RX`3F\@9&ES
M<&]N92!D92!P<FEV:6QE9VEO<R!P87)A(&-R96%R(&\@;6]D:69I8V%R(')E
M9VQA<R!P97)S;VYA;&EZ861A<RX`3F\@97-TX2!A=71E;G1I9FEC861O+@!.
M;R!P=65D92!I;F-L=6ER(&5L(&-A<N%C=&5R(")<(B!E;B!E;"!N;VUB<F4@
M8V]M<&QE=&\N`$YO(&EN=')O9'5J;R!U;F$@9&ER96-C:?-N(&1E(&-O<G)E
M;R!VX6QI9&$N`$YO(&%S;V-I\R!N:6YG=6YO(&1E(&QO<R!C86UP;W,@9&5L
M(&%R8VAI=F\@:6UP;W)T861O(&$@;&]S(&-A;7!O<R!C;W)R97-P;VYD:65N
M=&5S(&1E("5S+@!(82!S86QI9&\@9&4@;&$@<V5S:?-N+@!(82!R96-I8FED
M;R!U;B!M96YS86IE(&YU979O`%1I96YE('%U92!I;G1R;V1U8VER('5N(&[Z
M;65R;R!D92!T96SI9F]N;R!M\W9I;"!VX6QI9&\L('/S;&\@9.UG:71O<R!C
M;VX@=6X@)RLG(&]P8VEO;F%L('!A<F$@96P@<')E9FEJ;R!D92!L;&%M861A
M(&EN=&5R;F%C:6]N86PN`%1I96YE('%U92!I;G1R;V1U8VER('5N('9A;&]R
M(';A;&ED;RX`4&%R82!U<V%R($%L=&%S('1I96YE('%U92!C;VYF:6=U<F%R
M('5N(&UO=&]R(&1E($1A=&%4<F5E+@!4:65N92!Q=64@8V]N9FEG=7)A<B!U
M;B!M;W1O<B!61E,N`$1E8F4@9&5S8W)I8FER(&5L('!R;V)L96UA(&%N=&5S
M(&1E(&5N=FEA<B!E;"!I;F9O<FUE+@!4:65N92!Q=64@:6YT<F]D=6-I<B!L
M82!54DP@82!L82!Q=64@87!U;G1A(&5S=&4@=NUN8W5L;P!4:65N92!Q=64@
M<V5L96-C:6]N87(@=6X@<V5R=FED;W(@82!E;&EM:6YA<BX`5&EE;F4@<75E
M(&5S<&5C:69I8V%R('5N('5S=6%R:6\@82!E;&EM:6YA<BX`5&EE;F4@<75E
M(&5S<&5C:69I8V%R('5N('5S=6%R:6\@82!E;&EM:6YA<BX`5&EE;F4@<75E
M(&5S<&5C:69I8V%R(&%L(&UE;F]S('5N82!D:7)E8V-I\VX@9&4@8V]R<F5O
M('!A<F$@;&$@<75E(&%C=&EV87(@;&]S(&UE;G-A:F5S(&1E(&%U<V5N8VEA
M+@!4:65N92!Q=64@97-P96-I9FEC87(@96P@=7-U87)I;R!A(&'Q861I<BX`
M5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S=6%R:6\@82!A8W1U86QI>F%R
M+@!4:65N92!Q=64@97-P96-I9FEC87(@<77I(&%C8VGS;B!S92!E:F5C=71A
M<N$N`%1I96YE('%U92!I;G1R;V1U8VER('5N(&YU979O(&YO;6)R92!D92!C
M871E9V]R[6$N`%1I96YE('%U92!I;G1R;V1U8VER('5N(&[Z;65R;R!D92!T
M96SI9F]N;R!I=&%L:6%N;P!(82!E>'!I<F%D;R!S=2!S97-I\VX@)7,N(%9U
M96QV82!A(&EN:6-I87(@<V5S:?-N+@!3=2!D:7)E8V-I\VX@9&4@8V]R<F5O
M`$1I<F5C8VGS;B!$93H`4W4@:6YF;W)M86-I\VX`2&$@8V%M8FEA9&\@<W4@
M9&ER96-C:?-N(&1E($EN=&5R;F5T(&1E<V1E(&5L(&-O;6EE;GIO(&1E('-U
M('-E<VGS;B`E<RX@4&]R(')A>F]N97,@9&4@<V5G=7)I9&%D('1I96YE('%U
M92!V;VQV97(@82!I;FEC:6%R(&QA('-E<VGS;BX`4W4@;F]M8G)E`%-U(&UO
M=&]R(&1E(&%U=&5N=&EF:6-A8VGS;B!N;R!P97)M:71E(&'Q861I<B!U<W5A
M<FEO<RX@4VD@<75I<VEE<F$@=7-A<B!(;W)D92!P87)A(&%D;6EN:7-T<F%R
M(&-U96YT87,@9&4@=7-U87)I;RP@=&5N9'+A('%U92!U=&EL:7IA<B!U;B!M
M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@9&ES=&EN=&\N`%-U(&UO=&]R(&1E
M(&%U=&5N=&EF:6-A8VGS;B!N;R!P97)M:71E(&QI<W1A<B!U<W5A<FEO<RP@
M;R!S92!H82!D97-H86)I;&ET861O(&QA(&-A<F%C=&5R[7-T:6-A('!O<B!A
M;&?Z;B!M;W1I=F\N`%!A<F5C92!Q=64@:&$@8V%M8FEA9&\@<W4@;F%V96=A
M9&]R(&1E<V1E(&5L(&-O;6EE;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R(')A
M>F]N97,@9&4@<V5G=7)I9&%D('1I96YE('%U92!V;VQV97(@82!I;FEC:6%R
M(&QA('-E<VGS;BX`4W4@;F%V96=A9&]R(&YO(&%D;6ET92!E<W1A(&-A<F%C
M=&5R[7-T:6-A+@!%;"!N879E9V%D;W(@;F\@861M:71E(&5S=&$@;W!C:?-N
M(&1E(&EM<')E<VGS;BX@4')E<VEO;F4@0V]N=')O;"]#;VUA;F1O("L@4"!P
M87)A(&EM<')I;6ER+@!:;VYA(&AO<F%R:6$@86-T=6%L.@!392!H82!C86UB
M:6%D;R!S=2!I9&5N=&ED860@<&]R(&]M:7-I\VXN`$ED96YT:61A9"!P;W(@
M;VUI<VGS;CH`3F]M8G)E(&-O;7!L971O.@!392!H82!A9V]T861O('-U('1I
M96UP;R!D92!C;VYE>&GS;BX`3&$@;G5E=F$@8V]N=')A<V7Q82!P87)A("5S
M(&5S.B`E<P!392!H86X@86-T=6%L:7IA9&\@<W5S(&]P8VEO;F5S('/S;&\@
M<&]R(&QA(&1U<F%C:?-N(&1E(&QA('-E<VGS;BX`4V4@:&%N(&%C='5A;&EZ
M861O('-U<R!O<&-I;VYE<RX`4V4@:&$@<F5A:G5S=&%D;R!S=2!C;VYT<F%S
M9?%A`%-E(&AA(')E86IU<W1A9&\@<W4@8V]N=')A<V7Q82P@8V]M<')U96)E
M(&5L(&-O<G)E;R!E(&EN:6-I92!S97-I\VX@8V]N('-U(&YU979A(&-O;G1R
M87-E\6$N`$QA(&-O;G1R87-E\6$@:&$@97AP:7)A9&\N`%-E<G9I9&]R97,@
M<F5M;W1O<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6T]C=6QT87(@=&5X=&\@8VET861O70!;4VEN(&%S=6YT;UT`6TEN9F]R
M;64@9&4@<')O8FQE;6%=`%M-;W-T<F%R('1E>'1O(&-I=&%D;R`M`%M-;W-T
M<F%R('1E>'1O(&-I=&%D;R`M("5S(&SM;F5A<UT`6VSM;F5A("5S(&1E("5S
M70!$:7)E8V-I;VYE<R!A(&QA<R!Q=64@7W)E96YV:6%R.@!$:7)E8V-I;VYE
M<R!A(&QA<R!Q=64@;F\@<V4@96Y?=NUA;B!R97-P=65S=&%S.@!?061M:6YI
M<W1R86-I\VX`3&ES=&$@7VYE9W)A`%]#3$D`P7)?8F]L(&1A=&]S`$5?;&EM
M:6YA<B!F:6QA`%]%;&EM:6YA<B!C;VUP;&5T86UE;G1E(&5L(&UE;G-A:F4`
M7TEN=')O9'5C:7(@8V%D82!D:7)E8V-I\VX@96X@=6YA(&SM;F5A(&1I<W1I
M;G1A.@!?4F5E;G9I87(`7T=R=7!O<P!!7WEU9&$`4')O<&EE9&%D97,@9&4@
M7VEM86=E;BXN+@"_0V]N<V5R=F%R('5N82!?8V]P:6$@9&4@;&]S(&UE;G-A
M:F5S(&5N(&5S=&$@:61E;G1I9&%D/P!?26YI8VEA<B!S97-I\VX`7U-A;&ER
M`$UO9&EF:6-A<B!?=NUN8W5L;RXN+@!?5')A<VQA9&%R(&UE;G-A:F5S(&$@
M;&$@8V%R<&5T83H`7TUI<R!D:7)E8V-I;VYE<R!D92!C;W)R96\Z`%]/<&-I
M;VYE<P!?4')I=FEL96=I;W,`7T5L:6UI;F%R(';M;F-U;&\N+BX`7T=U:?-N
M`$-O;E]F:6=U<F%C+@!0<F]P:65D861E<R!D92!?=&%B;&$N+BX`7U5S=6%R
M:6]S`$%?=7-E;F-I80!,:7-T82!?8FQA;F-A`&%C=&EV;P!D:7)E8V-I;VYE
M<P!D97-T:6YA=&%R:6\@9&5S8V]N;V-I9&\`>0!A9V5N9&$`8V%L;6$`;F\@
M<V4@<'5E9&4@8W)E87(@96P@87)C:&EV;R!D92!D97-T:6YO`&YO('-E('!U
M961E(&%B<FER(&5L(&]R:6=E;@!P=6QS92!A<77M`&5R<F]R(&1E(&SM;F5A
M(&1E(&-O;6%N9&\`97)R;W(@9&4@8V]N9FEG=7)A8VGS;@!F86QT82!U;B!A
M<F-H:79O(&-R[71I8V\@9&5L('-I<W1E;6$`97)R;W(@9&4@9F]R;6%T;R!D
M92!D871O<P!D97-A8W1I=F%D82`M('!U;'-E('!A<F$@86-T:79A<FQA`&UO
M9&EF:6-A<@!E;G1R861A(&YO(&5N8V]N=')A9&$`9&5S8V5N<V\`8V%M<&\`
M87)C:&EV;P!D96P@)7,@*"5S*2!A(&QA<R`E<R`E<P!V96YT;W-O`&@Z`&AH
M`&YO;6)R92!D92!A;F9I=')I\VX@9&5S8V]N;V-I9&\`:6YM961I871A;65N
M=&4`:6YA8W1I=F\`96X@;.UN96$`97)R;W(@9&4@96YT<F%D82]S86QI9&$`
M97)R;W(@9&4@<V]F='=A<F4@:6YT97)N;P!L[6YE87-=`&=U:?-N(&UA:6QD
M<F]P(&=E;F5R861O('!O<B!);F=O`&-O:6YC:61I<@!C\V1I9V\@9&4@97)R
M;W(@;6MI<V]F<R`E9"!A;"!R96%L:7IA<B!)4T\N`&UM`&YO;6)R90!S:6X@
M9&5S87)R;VQL87(`8?IN(&YO('-E(&AA(&1E<V%R<F]L;&%D;P!N;W1A<P!O
M`'!O<F-E;G1A:F4`<')I=FEL96=I;R!D96YE9V%D;P!P[7AE;&5S`&=U:?-N
M('!R;V-M86EL(&=E;F5R861O('!O<B!);F=O`&5R<F]R(')E;6]T;R!D92!P
M<F]T;V-O;&\`96X@875M96YT;P!S97)V:6-I;R!N;R!D:7-P;VYI8FQE+@!M
M;W-T<F%R(&1I9F5R96YC:6%S`&9I;'1R;R!D92!T86UI>B!G96YE<F%D;R!P
M;W(@26YG;P!S;7,R96UA:6P@<&]R($A45%``<W,`97-T86)L90!E<G)O<B!D
M96P@<VES=&5M80!T87)E87,`9F%L;&\@=&5M<&]R86P`97-C<FEB82!D;W,@
M=F5C97,@;&$@8V]N=')A<V7Q82!P87)A(&-O;F9I<FUA<FQA`'5N:69I8V%D
M;P!S:6X@;F]M8G)E`'5S=6%R:6\@<V5L96-C:6]N861O`'9#87)D`'<Z`'=E
M871H97(N8V]M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;F=O+VQO8V%L92]E<U]%4R]H96QP+GAM;```````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U-C,P`#$P-#$W,S8R-S0W`#`R,3(W
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&EN9V\O;&]C86QE
M+V5S7T53+VAE;'`N>&UL+'8@,2XQ+C(N,R`R,#`V+S`R+S`Q(#$X.C0Q.C(X
M(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)B;&%C:VQI<W0B
M(&UD-3TB-6,Q,F4Q-C)F-C9F-CAC-F,R9#@T8V,W8S(X,&0W,3`B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^3&ES=&$@;F5G<F$\+W1I=&QE/@H@
M("`@/'!A<F$^3&$@;&ES=&$@;F5G<F$@97,@=6X@;&ES=&%D;R!D92!D:7)E
M8V-I;VYE<R!D92!L87,@<75E(&YO(&1E<V5A('9E<B!M96YS86IE<R!E;B!E
M;"!B=7HF(WA&,SMN(&1E($5N=')A9&$N/"]P87)A/@H@(#PO96YT<GD^"B`@
M/&5N=')Y(&ED/2)B;&%C:VQI<W0M86-T:6]N(B!M9#4](C$W,#%F-#$U,F,P
M.3`P,#1E,V(T,#(P-30S.68Y,3`X(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@
M/'1I=&QE/DQI<W1A(&YE9W)A.B!!8V-I)B-X1C,[;CPO=&ET;&4^"B`@("`\
M<&%R83Y%<W1A(&%C8VDF(WA&,SMN(&1E9FEN92!Q=28C>$4Y.R!H86-E<B!A
M;"!R96-I8FER('5N(&UE;G-A:F4@9&4@=6X@<F5M:71E;G1E(&)L;W%U96%D
M;RX@3&]S('9A;&]R97,@<&]S:6)L97,@<V]N(")E;&EM:6YA<B(@;R`B=')A
M<VQA9&%R(&$@8V%R<&5T82(N(%-I('-E('-E;&5C8VEO;F$@(F5L:6UI;F%R
M(BP@;&]S(&UE;G-A:F5S('-E(&1E<V-A<G1A<B8C>$4Q.VX@86YT97,@9&4@
M86QM86-E;F%R;&]S(&5N(&5L(&)U>B8C>$8S.VX@9&4@16YT<F%D82X@4VD@
M<V4@<V5L96-C:6]N82`B=')A<VQA9&%R(&$@8V%R<&5T82(L('-E(&%L;6%C
M96YA<B8C>$4Q.VX@96X@;&$@8V%R<&5T82!S96QE8V-I;VYA9&$N/"]P87)A
M/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)B;&%C:VQI<W0M861D<F5S<V5S
M(B!M9#4](C,T,S%E.3AA.&0Q-6)F838T-6%F,SDT8V5F9#@S-#9D(B!S=&%T
M93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DQI<W1A(&YE9W)A.B!$:7)E8V-I
M;VYE<SPO=&ET;&4^"B`@("`\<&%R83Y,82!L:7-T82!D92!D:7)E8V-I;VYE
M<R!B;&]Q=65A9&%S+B!(87D@<75E(&EN=')O9'5C:7(@8V%D82!D:7)E8V-I
M)B-X1C,[;B!E;B!U;F$@;"8C>$5$.VYE82!D:7-T:6YT82X\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<G-?<G5L97,B(&UD-3TB9#@T
M-C$W83)F-3`P,F0R-&5F,3$U,#EE-68T96(V8S`B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^1FEL=')O<SH@4F5G;&%S/"]T:71L93X*("`@(#QP
M87)A/D5S=&$@97,@;&$@<&%N=&%L;&$@<')I;F-I<&%L(&1E(')E9VQA<RX@
M07%U)B-X140[('-E('!U961E;B!C<F5A<B!R96=L87,@<'5L<V%N9&\@96P@
M8F]T)B-X1C,[;B`B3G5E=F$@<F5G;&$B.R!R96]R9V%N:7IA<B!E;"!O<F1E
M;B!D92!A<&QI8V%C:28C>$8S.VX@9&4@;&%S(')E9VQA<R!P=6QS86YD;R!L
M87,@9FQE8VAA<R!H86-I82!A<G)I8F$@>2!H86-I82!A8F%J;R!O(&EN=')O
M9'5C:65N9&\@;G5E=F%S('!O<VEC:6]N97,@9&4@;&%S(')E9VQA<R!E;B!L
M82!C;VQU;6YA(")4<F%S;&%D87(B.R!A8W1I=F%R(&\@9&5S86-T:79A<B!R
M96=L87,@97-P96,F(WA%1#MF:6-A<R!P=6QS86YD;R!E;"!I8V]N;R!D92!L
M82!C;VQU;6YA(")!8W1I=F%D;R(@>2!M;V1I9FEC87(@<F5G;&%S(&EN9&EV
M:61U86QE<R!P=6QS86YD;R!E;"!I8V]N;R!D92!L82!C;VQU;6YA(")-;V1I
M9FEC87(B(&\@96P@;F]M8G)E(&1E(&QA(')E9VQA+CPO<&%R83X*("`@(#QP
M87)A/@H@("`@("`\=&EP/E1E;F=A(&5N(&-U96YT82!Q=64@;&%S(')E9VQA
M<R!S92!E:F5C=71A;B!E;B!E;"!O<F1E;B!Q=64@<V4@;75E<W1R82!A<74F
M(WA%1#LN(%!O<B!E:F5M<&QO+"!S:2!S92!B;W)R82!U;B!M96YS86IE(&$@
M8V%U<V$@9&4@;&$@;&ES=&$@;F5G<F$L(&QA<R!R96=L87,@<75E('-I9V%N
M('EA(&YO(&%C='5A<B8C>$4Q.VX@96X@9&EC:&\@;65N<V%J93PO=&EP/@H@
M("`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](F9O<G=A<F0B
M(&UD-3TB8SDV-C1B.38P8V5E9C@W8V%B-&%F.#-E.&8S,S0Q,F,B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4F5E;G9I87(\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!0=65D92!O<'1A<B!P;W(@<F5E;G9I87(@9&4@9F]R;6$@
M875T;VTF(WA%,3MT:6-A('-U(&-O<G)E;R!E;G1R86YT92!A('5N82!S97)I
M92!D92!D:7)E8V-I;VYE<R!D92!C;W)R96\@96QE8W1R)B-X1C,[;FEC;RX*
M("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]R=V%R9"UA
M9&1R97-S97,B(&UD-3TB.#$W8S5F,#`R9CDY8S!A9F0P,#$P86%B868P-V,Y
M,6,B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4F5E;G9I87(Z($1I
M<F5C8VEO;F5S/"]T:71L93X*("`@(#QH96%D:6YG/E)E96YV:6%R.B!$:7)E
M8V-I;VYE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4'5E9&4@;W!T87(@
M<&]R(')E96YV:6%R(&5L(&-O<G)E;R!E;G1R86YT92!A(&]T<F$@8W5E;G1A
M+B!0=65D92!I;G1R;V1U8VER('1A;G1A<R!D:7)E8V-I;VYE<R!C;VUO(&1E
M<V5E+"!C861A('5N82!E;B!U;F$@;"8C>$5$.VYE82!D:7-T:6YT82X*("`@
M(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]R=V%R9"UK965P
M8V]P>2(@;60U/2)B93%F,S9C,F8Y83AD8V)A-S4Q-V(X961F-3,Q.60V-"(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y2965N=FEA<CH@0V]N<V5R
M=F%R('5N82!C;W!I83PO=&ET;&4^"B`@("`\:&5A9&EN9SY2965N=FEA<CH@
M0V]N<V5R=F%R('5N82!C;W!I83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M4VD@86-T:79A(&5S=&$@;W!C:28C>$8S.VXL('-E(&-O;G-E<G9A<B8C>$4Q
M.R!U;F$@8V]P:6$@9&4@;&]S(&UE;G-A:F5S(&5N=')A;G1E<R!E;B!E<W1A
M(&-U96YT82!A;"!T:65M<&\@<75E('-E(&5N=B8C>$5$.V%N(&$@;&%S(&1I
M<F5C8VEO;F5S(&$@;&%S('%U92!D97-E82!R965N=FEA<FQO<RX*("`@(#PO
M<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9BUS:&]W7V9I;'1E
M<E]M<V<B(&UD-3TB9#@W.35E-6(W,6,V,C@W960W8F9E,V8X9&,T9C0X-C$B
M('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4')E9F5R96YC:6%S.B`F
M(WA"1CM-;W-T<F%R(&%V:7-O<R!D971A;&QA9&]S(&%L(&%P;&EC87(@8V%D
M82!F:6QT<F\_/"]T:71L93X*("`@(#QP87)A/@H@("`@4VD@<V4@=71I;&EZ
M82!E;"!D<FEV97(@24U!4"!D92!F:6QT<F%D;RP@97-T82!P<F5F97)E;F-I
M82!C;VYT<F]L82!C)B-X1C,[;6\@9&4@:6YF;W)M871I=F\@<V5R)B-X13$[
M(&5L('!R;V-E<V\@9&4@9FEL=')A9&\N(%-I('-E(&%C=&EV82P@<V4@;F]T
M:69I8V%R)B-X13$[('!O<B!P86YT86QL82!C861A(&UE;G-A:F4@9FEL=')A
M9&\@96X@8W5A;G1O('-E(&AA>6$@<')O8V5S861O+B!3:2!S92!D97-A8W1I
M=F$L(',F(WA&,SML;R!S92!V97(F(WA%,3L@96X@;&$@<&%N=&%L;&$@=6X@
M<F5S=6UE;B!D92!L87,@86-C:6]N97,@9&4@9FEL=')A9&\N"B`@("`\+W!A
M<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G!R968M9FEL=&5R7W-E96XB
M(&UD-3TB.#4V.#=C-CED8C8Q-#5D-S<P-3-A.&(V,S`R935A9#(B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4')E9F5R96YC:6%S.B`F(WA"1CM&
M:6QT<F%R(',F(WA&,SML;R!L;W,@;65N<V%J97,@6VYO72!L928C>$5$.V1O
M<S\\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!%<W1A('!R969E<F5N8VEA(&ED
M96YT:69I8V$@8W4F(WA%,3MN9&\@96P@8V]N=')O;&%D;W(@9&4@9FEL=')A
M9&\@24U!4"!I;G1E;G1A<B8C>$4Q.R!A<&QI8V%R(')E9VQA<R!E;B!E;"!B
M=7HF(WA&,SMN(&1E($5N=')A9&$N(%!U961E(&%P;&EC87(@;&]S(&9I;'1R
M;W,@82!T;V1O<R!L;W,@;65N<V%J97,L(%,F(WA$,SM,3R!A(&%Q=65L;&]S
M(&UA<F-A9&]S(&-O;6\@;F\@;&4F(WA%1#MD;W,@;R!3)B-X1#,[3$\@82!A
M<75E;&QO<R!Q=64@<V4@:&%N(&UA<F-A9&\@8V]M;R!L928C>$5$.V1O<RX*
M("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<G5L92(@;60U
M/2)C9C(Q,65C.3<Y-39E.6%D8S-B.&8P,6(R830P.#@X9B(@<W1A=&4](G5P
M=&]D871E(CX*("`@(#QT:71L93Y296=L82!D92!F:6QT<F%D;SPO=&ET;&4^
M"B`@("`\<&%R83X*("`@(%5N82!R96=L82!E<R!E;"!B;&]Q=64@8B8C>$4Q
M.W-I8V\@9&4@96QA8F]R86-I)B-X1C,[;B!D92!S=7,@9FEL=')O<R!D92!C
M;W)R96\L(&-O;G-I<W1E(&5N('5N82!O('9A<FEA<R!C;VYD:6-I;VYE<R!Y
M('5N82!O('9A<FEA<R!A8V-I;VYE<RX@0W5A;F1O('-E(&QE(&5N=B8C>$5$
M.V$@=6X@;65N<V%J92P@<V4@<')O8V5S82!A('1R878F(WA%.3MS(&1E(&QA
M<R!C;VYD:6-I;VYE<R!D92!L87,@<F5G;&%S(&1E(&9I;'1R861O('D@<VD@
M8W5M<&QE(&%L9W5N82P@<V4@96IE8W5T86X@;&%S(&%C8VEO;F5S(&EN9&EC
M861A<R!E;B!D:6-H;R!M96YS86IE+"!,;W,@9FEL=')O<R!P=65D96X@<V5R
M(&UU>2`F(WA&03MT:6QE<R!P87)A(&5L:6UI;F%R(&1E(&9O<FUA(&%U=&]M
M)B-X13$[=&EC82!C;W)R96\@;F\@9&5S96%D;R!O('!A<F$@9F%C:6QI=&%R
M(&QA(&=E<W1I)B-X1C,[;B!D92!S=2!C=65N=&$@9&4@8V]R<F5O(&%L;6%C
M96YA;F1O(&QO<R!M96YS86IE<R!R96QA8VEO;F%D;W,@96X@8V%R<&5T87,@
M9&ES=&EN=&%S+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)R=6QE+6%C=&EO;B(@;60U/2(P9C8V-3<T9F5C,C$V-#4Q-#=B,V-B8CDV
M-V-C,C-B,2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y296=L82!D
M92!F:6QT<F%D;SH@06-C:28C>$8S.VX\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("`F(WA#.3MS=&%S('-O;B!L87,@86-C:6]N97,@<75E('-E('!U961E;B!L
M;&5V87(@82!C86)O('-I('5N(&UE;G-A:F4@96YT<F%N=&4@8W5M<&QE(&QA
M(&-O;F1I8VDF(WA&,SMN(&EN9&EC861A+B!496YG82!E;B!C=65N=&$@<75E
M('!U961E('%U92!N;R!T;V1A<R!E<W1A<R!O<&-I;VYE<R!E<W0F(WA%.3MN
M(&1I<W!O;FEB;&5S("T@<R8C>$8S.VQO('-E(&UO<W1R87(F(WA%,3MN(&QA
M<R!O<&-I;VYE<R!Q=64@9G5N8VEO;F5N(&-O;B!E;"!S;V9T=V%R92!D92!F
M:6QT<F%D;R!U=&EL:7IA9&\N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%
M;G1R96=A<B!E;B!M:2!B=7HF(WA&,SMN(&1E($5N=')A9&$\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($5L(&UE;G-A:F4@<V4@9W5A<F1A<B8C>$4Q.R!E
M;B!S=2!B=7HF(WA&,SMN(&1E($5N=')A9&$N($5S(&QA(&]P8VDF(WA&,SMN
M('!O<B!O;6ES:28C>$8S.VXN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%
M;G1R96=A<B!E;B!E;"!B=7HF(WA&,SMN/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%;"!M96YS86IE('-E(&%L;6%C96YA<B8C>$4Q.R!E;B!L82!C87)P
M971A(&EN9&EC861A+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16QI;6EN
M87(@8V]M<&QE=&%M96YT92!E;"!M96YS86IE/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!392!E;&EM:6YA<B8C>$4Q.R!S:6QE;F-I;W-A;65N=&4@96P@
M;65N<V%J92X@3FD@=7-T960@;FD@96P@<F5M:71E;G1E(')E8VEB:7(F(WA%
M,3MN(&YO=&EF:6-A8VDF(WA&,SMN(&%L9W5N82!D92!Q=64@:&$@<W5C961I
M9&\N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY2961I<FEG:7(@83PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@16P@;65N<V%J92!S92!R965N=FEA<B8C
M>$4Q.R!A(&QA(&1I<F5C8VDF(WA&,SMN(&5S<&5C:69I8V%D82X@3F\@<V4@
M8V]N<V5R=F%R)B-X13$[(&-O<&EA(&%L9W5N82!D96P@;65N<V%J92!E;B!E
M<W1A(&-U96YT82X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N=')E9V%R
M(&5N(&UI(&)U>B8C>$8S.VX@9&4@16YT<F%D82!Y(')E9&ER:6=I<B!A/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;"!M96YS86IE('-E(&5N=FEA<B8C
M>$4Q.R!A(&QA(&1I<F5C8VDF(WA&,SMN(&5S<&5C:69I8V%D82!Y('-E(&-O
M;G-E<G9A<B8C>$4Q.R!U;F$@8V]P:6$@96X@<W4@8G5Z)B-X1C,[;B!D92!%
M;G1R861A+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4F5C:&%Z87(@8V]N
M(&UO=&EV;SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16P@;65N<V%J92!O
M<FEG:6YA;"!S92!E;&EM:6YA<B8C>$4Q.R!Y('-E(&5N=FEA<B8C>$4Q.R!U
M;B!M96YS86IE(&YU979O(&%L(')E;6ET96YT92!C;VX@96P@=&5X=&\@<75E
M(&EN9&EQ=64N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60]
M(G)U;&4M8V]M8FEN92(@;60U/2(R.30X-&,Q96)D9#=C93<Q961C,S1F8S@Q
M,#!E9C8Y8R(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y296=L82!D
M92!F:6QT<F%D;SH@0V]M8FEN87(@;W!C:6]N97,\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!0=65D92!D969I;FER('9A<FEA<R!C;VYD:6-I;VYE<R!E;B!U
M;F$@;6ES;6$@<F5G;&$N(%!U961E(&%G<G5P87)L87,@9&4@9F]R;6$@;"8C
M>$8S.V=I8V$@;65D:6%N=&4@(EDB+R)/(BP@3F\@<'5E9&4@8W)E87(@9FEL
M=')O<R!C;VUP;&5J;W,@<75E(&-O;G1E;F=A;B!A;6)O<R!T:7!O<R!D92!C
M;VYD:6-I;VYE<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/ED\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%-I('-E;&5C8VEO;F$@62P@=6X@;65N<V%J
M92!E;G1R86YT92!T:65N92!Q=64@8W5M<&QI<B!T;V1A<R!Y(&-A9&$@=6YA
M(&1E(&QA<R!C;VYD:6-I;VYE<R!Q=64@97-P96-I9FEQ=64@<&%R82!Q=64@
M<V4@96IE8W5T96X@;&%S(&%C8VEO;F5S+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^3SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4VD@<V5L96-C:6]N
M($\L(&QA<R!A8V-I;VYE<R!I;F1I8V%D87,@<V4@96IE8W5T87(F(WA%,3MN
M('-I('-E(&-U;7!L92!A;"!M96YS;R!U;F$@9&4@;&%S(&-O;F1I8VEO;F5S
M+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)R=6QE+6UA
M<FLB(&UD-3TB,&-B8V,T860T.#4W8C@U,SAC9#1E,SDQ-69B93ED-S,B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4F5G;&$@9&4@9FEL=')A9&\Z
M(%-E)B-X1C$[86QA<B!M96YS86IE/"]T:71L93X*("`@(#QP87)A/@H@("`@
M0V]M;R!U;F$@9&4@;&%S(&%C8VEO;F5S(&1E('5N82!R96=L82P@<'5E9&4@
M:6YD:6-A<B!Q=64@<V4@<V4F(WA&,3MA;&4@=6X@;65N<V%J92!C;VX@=6YO
M(&\@;28C>$4Q.W,@9&4@;&]S(&UA<F-A9&]R97,@24U!4"X@3&]S('9A;&]R
M97,@<&]S:6)L97,@<V]N($QE)B-X140[9&\L($EM<&]R=&%N=&4L(%)E<W!O
M;F1I9&\@>2!%;&EM:6YA9&\N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\
M96YT<GD@:60](G)U;&4M;6%T8VAE<R(@;60U/2(U,3=E,C0Y-S%F,F,U-#0S
M8C)E9#`T93EC-3`T93=E8B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L
M93Y296=L82!D92!F:6QT<F%D;SH@0V]I;F-I9&5N8VEA/"]T:71L93X*("`@
M(#QP87)A/@H@("`@16X@8V%D82!C;VYD:6-I)B-X1C,[;B!D92!U;F$@<F5G
M;&$@:&%Y('1R97,@8V]M<&]N96YT97,N($5L('!R:6UE<F\@96X@96P@8V%M
M<&\@<75E(&AA>2!Q=64@97AA;6EN87(N($5L('-E9W5N9&\@97,@96P@=&EP
M;R!D92!C;VUP87)A8VDF(WA&,SMN(&$@<F5A;&EZ87(N($5L('1E<F-E<F\@
M97,@96P@=F%L;W(@8V]N(&5L('%U92!H87D@<75E(&-O;7!A<F%R(&5L(&-A
M;7!O+@H@("`@17AI<W1E;B!V87)I;W,@=&EP;W,@9&ES=&EN=&]S(&1E(&-O
M;7!A<F%C:6]N97,@<F5A;&EZ86)L97,N($QA<R!C;VUP87)A8VEO;F5S(&1I
M<W!O;FEB;&5S('!A<F$@8V%D82!C86UP;R!D97!E;F1E;B!T86YT;R!D96P@
M=&EP;R!D92!C86UP;R!C;VUO(&1E(&QO('%U92!P=65D82!M86YE:F%R(&5L
M('-O9G1W87)E('5T:6QI>F%D;RX@4&]R(&5L;&\@;F\@=&]D87,@;&%S('-I
M9W5I96YT97,@<&]S:6)L97,@;W!C:6]N97,@9&4@8V]I;F-I9&5N8VEA(&%P
M87)E8V5R)B-X13$[;B!E;B!U;B!C86UP;R!D971E<FUI;F%D;RX*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D-O;G1I96YE/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!392!C;VYS:61E<F%R)B-X13$[(&-I97)T;R!S:2!S92!L;V-A
M;&EZ82!L82!C861E;F$@:6YD:6-A9&$@96X@8W5A;'%U:65R('!A<G1E(&1E
M(&QA(&PF(WA%1#MN96$N"B`@("!%:F5M<&QO.B!J;W-E7W5S=6%R:6]`96IE
M;7!L;RYC;VT@8V]N=&EE;F4@=7-U87)I;T!E:F5M<&QO"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY.;R!C;VYT:65N93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@4V4@8V]N<VED97)A<B8C>$4Q.R!C:65R=&\@<VD@;&$@8V%D96YA
M(&EN9&EC861A(&YO('-E(&5N8W5E;G1R82!E;B!N:6YG=6YA('!A<G1E(&1E
M(&QA(&PF(WA%1#MN96$N"B`@("!%:F5M<&QO.B!J;W-E0&5J96UP;&\N8V]M
M(&YO(&-O;G1I96YE('5S=6%R:6]`96IE;7!L;PH@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^17,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E(&-O;G-I
M9&5R87(F(WA%,3L@8VEE<G1O('-I(&QA(&-A9&5N82!I;F1I8V%D82!C;VEN
M8VED92!E>&%C=&%M96YT92!C;VX@;&$@;"8C>$5$.VYE82X*("`@($5J96UP
M;&\Z('5S=6%R:6]`96IE;7!L;R!E<R!U<W5A<FEO0&5J96UP;&\*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/DYO(&5S/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!392!C;VYS:61E<F%R)B-X13$[(&-I97)T;R!S:2!L82!C861E;F$@
M:6YD:6-A9&$@;F\@8V]I;F-I9&4@97AA8W1A;65N=&4@8V]N(&QA(&PF(WA%
M1#MN96$N"B`@("!%:F5M<&QO.B!U<W5A<FEO0&5J96UP;&\@;F\@97,@=7-U
M87)I;T!E:F5M<&QO+F-O;0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16UP
M:65Z82!P;W(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E(&-O;G-I9&5R
M87(F(WA%,3L@8VEE<G1O('-I(&QA(&-A9&5N82!I;F1I8V%D82!C;VEN8VED
M92!C;VX@96P@8V]M:65N>F\@9&4@;&$@;"8C>$5$.VYE82X*("`@($5J96UP
M;&\Z('5S=6%R:6]`96IE;7!L;RYC;VT@16UP:65Z82!P;W(@=7-U87)I;T!E
M:F5M<&QO"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY.;R!E;7!I97IA('!O
M<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V4@8V]N<VED97)A<B8C>$4Q
M.R!C:65R=&\@<VD@;&$@8V%D96YA(&EN9&EC861A(&YO(&-O:6YC:61E(&-O
M;B!E;"!C;VUI96YZ;R!D92!L82!L)B-X140[;F5A+@H@("`@16IE;7!L;SH@
M:F]S94!E:F5M<&QO+F-O;2!.;R!E;7!I97IA('!O<B!U<W5A<FEO0&5J96UP
M;&\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E1E<FUI;F$@<&]R/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!392!C;VYS:61E<F%R)B-X13$[(&-I97)T
M;R!S:2!L82!C861E;F$@:6YD:6-A9&$@8V]I;F-I9&4@8V]N(&5L(&9I;F%L
M(&1E(&QA(&PF(WA%1#MN96$N"B`@("!%:F5M<&QO.B!U<W5A<FEO0&5J96UP
M;&\@5&5R;6EN82!P;W(@0&5J96UP;&\*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/DYO('1E<FUI;F$@<&]R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3
M92!C;VYS:61E<F%R)B-X13$[(&-I97)T;R!S:2!L82!C861E;F$@:6YD:6-A
M9&$@;F\@8V]I;F-I9&4@8V]N(&5L(&9I;F%L(&1E(&QA(&PF(WA%1#MN96$N
M"B`@("!%:F5M<&QO.B!U<W5A<FEO0&5J96UP;&\@3F\@=&5R;6EN82!P;W(@
M0&5J96UP;&\N8V]M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%>&ES=&4\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E(&-O;G-I9&5R87(F(WA%,3L@
M8VEE<G1O('-I(&QA(&-A9&5N82!I;F1I8V%D82!E>&ES=&4@96X@96P@;65N
M<V%J92P@:6YD97!E;F1I96YT96UE;G1E(&1E(&QO('%U92!C;VYT96YG82X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DYO(&5X:7-T93PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@4V4@8V]N<VED97)A<B8C>$4Q.R!C:65R=&\@<VD@
M;&$@8V%D96YA(&EN9&EC861A(&YO(&5X:7-T92!E;B!E;"!M96YS86IE+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^4F5G97@\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($QE('!E<FUI=&4@=71I;&EZ87(@96X@;&%S(&-O;7!A<F%C
M:6]N97,@9&4@;&%S(&-A8F5C97)A<R!E>'!R97-I;VYE<R!R96=U;&%R97,@
M8V]M<&%T:6)L97,@4$]325@@8V]M<&QE:F%S+@H@("`@16IE;7!L;SH@(E)E
M8VEB:61O(&1E<V1E(%LJ7"XJ7"XJ7"XJ72!P;W(@*&%N9FET<FEO;BUA?&%N
M9FET<FEO;BUB*2YE:F5M<&QO+F-O;2HB('-E(&-U;7!L:7(F(WA%,3L@8V]N
M(")296-I8FED;R!D97-D92!;,3<R+C$V+C$P,"XQ72!P;W(@86YF:71R:6]N
M+6$N96IE;7!L;RYC;VT@96P@36%R=&5S(@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^0V]I;F-I9&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-O:6YC
M:61E(&5S('!A<F5C:61O(&$@0V]N=&EE;F4@8V]N(&QA(&5X8V5P8VDF(WA&
M,SMN(&1E('%U92!P=65D96X@=71I;&EZ87)S92`J('D@/R!C;VUO(&-O;6]D
M:6YE<RX@56X@*B!S=7-T:71U:7(F(WA%,3L@8W5A;'%U:65R(&XF(WA&03MM
M97)O(&1E(&-A<F%C=&5R97,@>2!U;F$@/R!S=7-T:71U:7(F(WA%,3L@97AA
M8W1A;65N=&4@=6YO+@H@("`@16IE;7!L;SH@(BIU<W5A<FEO/T!E:F5M<&QO
M+F-O;2(@<V4@8W5M<&QI<B8C>$4Q.R!T86YT;R!C;VX@(G5S=6%R:6\Q0&5J
M96UP;&\N8V]M(B!C;VUO(&-O;B`B;W1R;W5S=6%R:6\R0&5J96UP;&\N8V]M
M(@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^3F\@8V]I;F-I9&4\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($YO(&-O:6YC:61E(&5S(&QO(&UI<VUO('%U
M92!#;VEN8VED92!E>&-E<'1O('!O<B!Q=64@<V5R)B-X13$[(&9A;'-O('-I
M(&5L('9A;&]R(&EN9&EC861O(&-O:6YC:61E(&-O;B!L82!C861E;F$@9&4@
M;&$@8V%B96-E<F$@9&5L(&UE;G-A:F4N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY-96YO<B!Q=64\+VAE861I;F<^"B`@("`\<&%R83X*("`@("8C>$,Y
M.W-T82!E<R!U;F$@<')U96)A(')E;&%C:6]N86P@<75E(&-O;7!A<F$@;G5M
M)B-X13D[<FEC86UE;G1E(&5L('9A;&]R(&EN9&EC861O('D@96P@=F%L;W(@
M9&4@;&$@8V%B96-E<F$@9&5L(&UE;G-A:F4N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY-96YO<B!O(&EG=6%L('%U93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@)B-X0SD[<W1A(&5S('5N82!P<G5E8F$@<F5L86-I;VYA;"!Q=64@
M8V]M<&%R82!N=6TF(WA%.3MR:6-A;65N=&4@96P@=F%L;W(@:6YD:6-A9&\@
M>2!E;"!V86QO<B!D92!L82!C86)E8V5R82!D96P@;65N<V%J92X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/DEG=6%L('%U93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@)B-X0SD[<W1A(&5S('5N82!P<G5E8F$@<F5L86-I;VYA;"!Q
M=64@8V]M<&%R82!N=6TF(WA%.3MR:6-A;65N=&4@96P@=F%L;W(@:6YD:6-A
M9&\@>2!E;"!V86QO<B!D92!L82!C86)E8V5R82!D96P@;65N<V%J92X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/DUA>6]R(&\@:6=U86P@<75E/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("`F(WA#.3MS=&$@97,@=6YA('!R=65B82!R
M96QA8VEO;F%L('%U92!C;VUP87)A(&YU;28C>$4Y.W)I8V%M96YT92!E;"!V
M86QO<B!I;F1I8V%D;R!Y(&5L('9A;&]R(&1E(&QA(&-A8F5C97)A(&1E;"!M
M96YS86IE+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^36%Y;W(@<75E/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("`F(WA#.3MS=&$@97,@=6YA('!R=65B
M82!R96QA8VEO;F%L('%U92!C;VUP87)A(&YU;28C>$4Y.W)I8V%M96YT92!E
M;"!V86QO<B!I;F1I8V%D;R!Y(&5L('9A;&]R(&1E(&QA(&-A8F5C97)A(&1E
M;"!M96YS86IE+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)R=6QE+6YA;64B(&UD-3TB.&9A868W,64T8F8R9CDQ9#DT,V0W-V8X,#-F
M.6$R9#4B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4F5G;&$@9&4@
M9FEL=')A9&\Z($YO;6)R93PO=&ET;&4^"B`@("`\<&%R83X*("`@(%-E('1R
M871A(&1E('5N(&YO;6)R92!D97-C<FEP=&EV;R!D92!U;F$@<F5G;&$N(%!U
M961E('5S87)L;R!P87)A(&ED96YT:69I8V%R('5N82!R96=L82!D971E<FUI
M;F%D82!E;B!S=2!L:7-T861O(&1E(&9I;'1R;W,N"B`@("`\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](G)U;&4M<W1O<"(@;60U/2(V-S=C.3(P
M969F8V$Y-3DQ,C-B-V0U,SEB,V(P9#@V-"(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93Y296=L82!D92!F:6QT<F%D;SH@1&5T96YE<B!C;VUP<F]B
M86-I)B-X1C,[;CPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-I('-E(&%C=&EV
M82!E<W1A(&]P8VDF(WA&,SMN('D@=6X@;65N<V%J92!C=6UP;&4@;&$@<F5G
M;&$L(&5L(')E<W1O(&1E(&QO<R!M96YS86IE<R!N;R!S92!P<F]C97-A<B8C
M>$4Q.VXN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G9A
M8V%T:6]N(B!M9#4](C)C.64Q,CDW,V0S-F9E.31A96(W,V(S,F1B.6$V-&4V
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%U<V5N8VEA/"]T:71L
M93X*("`@(#QP87)A/@H@("`@3&]S(&UE;G-A:F5S(&1E(&%U<V5N8VEA('-O
M;B!R97-P=65S=&%S(&%U=&]M)B-X13$[=&EC87,@96YV:6%D87,@82!L82!G
M96YT92!Q=64@;&4@96YV)B-X140[92!C;W)R96\N($YO<FUA;&UE;G1E('-E
M('5T:6QI>F%N(&-U86YD;R!V82!A(&5S=&%R(&%U<V5N=&4@<&]R('5N(&QA
M<F=O('!E<FEO9&\@9&4@=&EE;7!O+@H@("`@/"]P87)A/@H@(#PO96YT<GD^
M"B`@/&5N=')Y(&ED/2)V86-A=&EO;BUB=6QK(B!M9#4](C9F-F4T,3<X93@P
M9C0V93<X-S9C-V5E-60P86,U,V(W(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@
M/'1I=&QE/D%U<V5N8VEA.B!.;R!R97-P;VYD97(@82!G<F%N96P\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!!8W1I=F%N9&\@97-T82!O<&-I)B-X1C,[;B!L
M87,@<F5S<'5E<W1A<R!P;W(@875S96YC:6$@;F\@<V4@96YV:6%R)B-X13$[
M;B!C;VX@;65N<V%J97,@<75E('!A<F5Z8V%N('!R;V-E9&5R(&1E(&QI<W1A
M<R!D92!C;W)R96\@;R!Q=64@97-T)B-X13D[;B!M87)C861O<R!C;VUO(&-O
M<G)E;R!A(&=R86YE;"X*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB=F%C871I;VXM9&%Y<R(@;60U/2(R-6)A-S1C,&4W.6-E-S(R,S<W
M.35E8C@P.65E-#4X-2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y!
M=7-E;F-I83H@26YT97)V86QO(&1E(')E<W!U97-T83PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($5S(&5L(&XF(WA&03MM97)O(&1E(&0F(WA%1#MA<R!A(&5S
M<&5R87(@86YT97,@9&4@=F]L=F5R(&$@96YV:6%R('5N82!R97-P=65S=&$@
M875T;VTF(WA%,3MT:6-A(&$@=6YA(&1I<F5C8VD@<75E('EA(&AA>6$@<F5C
M:6)I9&\@=6YA+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)V86-A=&EO;BUM>65M86EL(B!M9#4](F5F,V9A-S!E.30P960Q-#<R,C<V
M8S!F9&4U864R865D(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%U
M<V5N8VEA.B!-:7,@9&ER96-C:6]N97,@9&4@8V]R<F5O/"]T:71L93X*("`@
M(#QP87)A/@H@("`@4VD@=&EE;F4@;28C>$4Q.W,@9&4@=6YA(&1I<F5C8VDF
M(WA&,SMN(&1E(&-O<G)E;R!A<VEG;F%D87,@82!E<W1E(&)U>B8C>$8S.VXL
M(&EN9"8C>$5$.W%U96QA<R!A<74F(WA%1#LN"B`@("`\+W!A<F$^"B`@/"]E
M;G1R>3X*("`\96YT<GD@:60](G9A8V%T:6]N+6YO<F5S<&]N<V4B(&UD-3TB
M,F(W,F4Q,F(V.3@Y8SEE9C$V-C=A-3DP-#!C-S`S,3`B('-T871E/2)U<'1O
M9&%T92(^"B`@("`\=&ET;&4^075S96YC:6$Z(%-I;B!R97-P=65S=&%S/"]T
M:71L93X*("`@(#QP87)A/@H@("`@3F\@96YV:6%R(&QA(&YO=&EF:6-A8VDF
M(WA&,SMN(&1E(&%U<V5N8VEA(&$@97-T;W,@9&5S=&EN871A<FEO<RX@0V%D
M82!D:7)E8V-I)B-X1C,[;B!D96)E(&5S=&%R(&5N('5N82!L)B-X140[;F5A
M(&1I<W1I;G1A+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)V86-A=&EO;BUR96%S;VXB(&UD-3TB9#1D83)F,V$P9#,U-V4P,#DU,&5C
M-3=D.3@T8V)C964B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^075S
M96YC:6$Z($UO=&EV;R!D92!L82!A=7-E;F-I83PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($5S(&5L('1E>'1O('%U92!S92!E;G9I87(F(WA%,3L@96X@<W5S
M(&YO=&EF:6-A8VEO;F5S(&1E(&%U<V5N8VEA+@H@("`@/"]P87)A/@H@(#PO
M96YT<GD^"B`@/&5N=')Y(&ED/2)V86-A=&EO;BUS=6)J96-T(B!M9#4](F-E
M,39C-V,V83`X.3DS.#(Q,C`X8V9B964P8C$X.&$P(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/D%U<V5N8VEA.B!!<W5N=&\@9&4@;&$@875S96YC
M:6$\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!%<R!E;"!A<W5N=&\@<75E('-E
M('5T:6QI>F%R)B-X13$[(&5N(&QA<R!N;W1I9FEC86-I;VYE<R!D92!A=7-E
M;F-I82X*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=VAI
M=&5L:7-T(B!M9#4](F5C8F8W,#`P9C$P-S@S,F0V.&)D-V)A.&8U,3(Q.3`Y
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DQI<W1A(&)L86YC83PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY,:7-T82!B;&%N8V$\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($QA(&QI<W1A(&)L86YC82!E<R!U;B!L:7-T861O(&1E
M(&1I<F5C8VEO;F5S("AL96<F(WA%1#MT:6UA<RD@9&4@;&%S('%U92!S:65M
M<')E(&1E<V5A('!O9&5R('9E<B!L;W,@;65N<V%J97,@96X@96P@8G5Z)B-X
M1C,[;B!D92!%;G1R861A+B!#861A(&1I<F5C8VDF(WA&,SMN(&1E8F4@:6YC
M;'5I<G-E(&5N('5N82!L)B-X140[;F5A(&1I<W1I;G1A+@H@("`@/"]P87)A
M/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)W:&ET96QI<W0M861D<F5S<V5S
M(B!M9#4](CAF93`U-&,Q8C4U939A9&,X,60Q9#@U,C5C,3,Q-C,W(B!S=&%T
M93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DQI<W1A(&)L86YC83H@1&ER96-C
M:6]N97,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!014Y$245.5$4N($-A9&$@
M9&ER96-C:28C>$8S.VX@9&5B92!I;F-L=6ER<V4@96X@=6YA(&PF(WA%1#MN
M961A(&1I<W1I;G1A+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"CPO:&5L<#X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O
M;&]C86QE+V9I7T9)+P``````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#<`,#$W-3<V`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O9FE?1DDO3$-?34534T%'15,O````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P
M,C$S-C,`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]F:5]&
M22],0U]-15-304=%4R]I;F=O+FUO````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#0V
M-S,P`#$P-#$W,S8R-S0W`#`R,C8V-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````%`(```<````G$(``!4+```<
MA0```````'"Q```.````<;$```\```"`L0``#0```)"Q```(````GK$```L`
M``"GL0``#````+.Q```$````P+$```0```#%L0```P```,JQ```8````SK$`
M`!L```#GL0``+0````.R```=````,;(``"0```!/L@``*0```'2R```9````
MGK(``"8```"XL@``#````-^R```D````[+(```\````1LP``"P```"&S```.
M````+;,```4````\LP``*````$*S```(````:[,```H```!TLP``%0```'^S
M```2````E;,```L```"HLP``A0```+2S```.````.K0```H```!)M```#0``
M`%2T```.````8K0``!$```!QM```#0```(.T```,````D;0```T```">M```
M!@```*RT``"4````L[0```H```!(M0``#P```%.U```8````8[4```P```!\
MM0``#@```(FU```.````F+4```@```"GM0``"0```+"U```N````NK4``!H`
M``#IM0``,@````2V```X````-[8``%0```!PM@``40```,6V``!:````%[<`
M`%<```!RMP``-````,JW```)````_[<```T````)N```!P```!>X```*````
M'[@```\````JN```!0```#JX```&````0+@``!$```!'N```"````%FX```)
M````8K@```D```!LN```)0```':X```@````G+@``!,```"]N```$````-&X
M```/````XK@```H```#RN```(0```/VX```/````'[D``"X````ON0```P``
M`%ZY```/````8KD``!0```!RN0``"0```(>Y```-````D;D``!(```"?N0``
M&0```+*Y```>````S+D```\```#KN0``"@```/NY```/````!KH```@````6
MN@``)````!^Z```4````1+H``!8```!9N@``"````'"Z``!.````>;H``"T`
M``#(N@``&0```/:Z```3````$+L```<````DNP``#````"R[```L````.;L`
M``X```!FNP```P```'6[```+````>;L```<```"%NP``!P```(V[```%````
ME;L```4```";NP``"@```*&[```#````K+L``!<```"PNP``"@```,B[```/
M````T[L```X```#CNP``%````/*[```+````![P``!@````3O```(P```"R\
M```.````4+P``!0```!?O```%P```'2\```7````C+P``!<```"DO```$P``
M`+R\```/````T+P```X```#@O```'P```.^\```=````#[T```<````MO0``
M!@```#6]```(````/+T```\```!%O0``!@```%6]```(````7+T```H```!E
MO0``$P```'"]```4````A+T```L```"9O0``$````*6]```5````MKT```T`
M``#,O0``%0```-J]```'````\+T``!````#XO0``!0````F^```5````#[X`
M`!$````EO@``#````#>^```J````1+X``#L```!OO@``.````*N^```)````
MY+X```<```#NO@``%````/:^```#````"[\```4````/OP``$````!6_```)
M````)K\``!,````POP``.0```$2_```2````?K\``"<```"1OP``+````+F_
M```J````YK\``"4````1P```"@```#?````&````0L````D```!)P```!P``
M`%/````O````6\```#<```"+P```+@```,/```!5````\L```"T```!(P0``
M+0```';!```]````I,$``#\```#BP0``+0```"+"``!`````4,(``",```"1
MP@``(P```+7"``!`````V<(``"T````:PP``,P```$C#```E````?,,``!4`
M``"BPP``&0```+C#```I````TL,``"0```#\PP``*````"'$```R````2L0`
M`!$```!]Q```"@```(_$```,````FL0```H```"GQ```$````++$```6````
MP\0``!8```#:Q```!P```/'$```'````^<0``!0````!Q0``"@```!;%```(
M````(<4``"<````JQ0``"````%+%```#````6\4```L```!?Q0``!P```&O%
M```'````<\4```8```![Q0``!0```(+%```'````B,4```8```"0Q0``%```
M`)?%```(````K,4```D```"UQ0``#@```+_%```[````SL4``!4````*Q@``
M*0```"#&```.````2L8```H```!9Q@``!````&3&```$````:<8```<```!N
MQ@``"0```';&```&````@,8``!$```"'Q@``!P```)G&```6````H<8```0`
M``"XQ@``"````+W&```&````QL8```T```#-Q@``!@```-O&```>````XL8`
M`!$````!QP``"````!/'```-````',<```P````JQP``!P```#?'```#````
M/\<```,```!#QP``%P```$?'```3````7\<``!T```!SQP``"````)''```$
M````FL<```@```"?QP``"````*C'``!!````L<<``!H```#SQP``*P````[(
M```@````.L@``!4```!;R```!@```''(```&````>,@``!4```!_R```&```
M`)7(```B````KL@``"X```#1R```'0````#)```A````'LD``%0```!`R0``
M*0```)7)```*````O\D```<```#*R0``!P```-+)```.````VLD``!4```#I
MR0``#@```/_)```"````#LH```H````1R@``#P```!S*```-````+,H```\`
M```ZR@``#0```$K*```)````6,H``!0```!BR@``!@```'?*```8````?LH`
M`!T```"7R@``$P```+7*```1````R<H``!0```#;R@``!````/#*```&````
M]<H``!0```#\R@``5````!'+```.````9LL``&0```!URP``!````-K+```.
M````W\L```4```#NRP``!0```/3+```;````^LL``!H````6S```$P```#',
M```1````1<P``!$```!7S```'````&G,```J````ALP``!````"QS```(0``
M`,+,```%````Y,P``!,```#JS```"P```/[,```2````"LT```H````=S0``
M#P```"C-```-````.,T``!$```!&S0``$P```%C-```,````;,T```8```!Y
MS0``#````(#-```&````C<T``!<```"4S0``$````*S-```1````O<T```@`
M``#/S0``!0```-C-```,````WLT``!````#KS0``!0```/S-```-`````LX`
M``8````0S@``!P```!?.```-````'\X```<````MS@``"P```#7.```'````
M0<X```<```!)S@``"0```%'.```)````6\X```H```!ES@``&0```'#.```]
M````BLX``!T```#(S@``#````.;.```0````\\X```4````$SP``)0````K/
M```2````,,\``!,```!#SP``$@```%?/```K````:L\``#L```"6SP``(```
M`-+/```(````\\\``#8```#\SP``"````#/0```A````/-```!````!>T```
M"````&_0```,````>-````8```"%T```!````(S0```'````D=````\```"9
MT```"@```*G0```.````M-````<```##T```"@```,O0```-````UM```!\`
M``#DT```'`````31```A````(=$``!X```!#T0``&0```&+1```>````?-$`
M`!L```";T0``(0```+?1```N````V=$``"8````(T@``'````"_2```>````
M3-(``!P```!KT@``)@```(C2```K````K](``#,```#;T@``)@````_3```K
M````-M,``#@```!BTP``'0```)O3```5````N=,``"\```#/TP``(````/_3
M```2````(-0``"D````SU```'@```%W4```@````?-0``!(```"=U```H@``
M`+#4```6````4]4``",```!JU0``*````([5```I````M]4``"@```#AU0``
M'P````K6```5````*M8``"````!`U@``)0```&'6```H````A]8``"T```"P
MU@``,````-[6``"2````#]<``"$```"BUP``%@```,37```<````V]<``"8`
M``#XUP``*@```!_8``!!````2M@``$0```",V```#````-'8```'````WM@`
M``<```#FV```!@```.[8```-````]=@``!`````#V0``$0```!39```2````
M)MD``!,````YV0``$@```$W9```'````8-D```0```!HV0``$````&W9```0
M````?MD```P```"/V0``#@```)S9```-````J]D```\```"YV0``$P```,G9
M```-````W=D``"@```#KV0```P```!3:```-````&-H```8````FV@``$0``
M`"W:```7````/]H``!L```!7V@``#@```'/:```"````@MH```H```"%V@``
M20```)#:```%````VMH``!````#@V@``#P```/':```$`````=L```T````&
MVP``#@```!3;```#````(]L```X````GVP``$0```#;;```(````2-L```\`
M``!1VP``#P```&';```'````<=L```T```!YVP``$````(?;```-````F-L`
M``L```"FVP``!@```++;```)````N=L```L```##VP``$````,_;```,````
MX-L```H```#MVP``$0```/C;```9````"MP```L````DW```#0```##<```B
M````/MP``!D```!AW```#P```'O<```;````B]P``#0```"GW```"@```-S<
M```8````Y]P``!(`````W0``&0```!/=```6````+=T```<```!$W0``(@``
M`$S=```5````;]T``"$```"%W0``)0```*?=```1````S=T```T```#?W0``
M!P```.W=```4````]=T```L````*W@``(@```!;>```O````.=X```L```!I
MW@``"0```'7>```9````?]X```L```"9W@``%P```*7>```7````O=X```D`
M``#5W@``"@```-_>```(````ZMX``!8```#SW@``#P````K?```9````&M\`
M`#H````TWP``%@```&_?```.````AM\``!@```"5WP``"````*[?```O````
MM]\```T```#GWP``)@```/7?```(````'.```$,````EX```$@```&G@```/
M````?.```!````",X```#0```)W@```A````J^````@```#-X```$@```-;@
M```?````Z>````@````)X0``"P```!+A```O````'N$```X```!.X0``!0``
M`%WA```&````8^$``$4```!JX0```P```+#A```'````M.$```0```"\X0``
M!P```,'A```*````R>$```H```#4X0``#P```-_A```0````[^$``!<`````
MX@``$0```!CB```9````*N(``!<```!$X@``"0```%SB```%````9N(```L`
M``!LX@``"@```'CB```"````@^(```4```"&X@``#0```(SB```;````FN(`
M`!<```"VX@``%````,[B```)````X^(```X```#MX@``#0```/SB```2````
M"N,```D````=XP``.````"?C```@````8.,```<```"!XP``"````(GC```)
M````DN,```X```"<XP``>P```*OC```8````)^0``!@```!`Y```"````%GD
M```1````8N0```<```!TY```!0```'SD```8````@N0``!X```";Y```&P``
M`+KD```9````UN0``"@```#PY```%0```!GE```;````+^4``!D```!+Y0``
M$P```&7E```'````>>4```@```"!Y0``!@```(KE```&````D>4``!````"8
MY0``#P```*GE```0````N>4```\```#*Y0``"P```-KE```/````YN4```P`
M``#VY0``#P````/F```'````$^8```X````;Y@``!@```"KF```&````,>8`
M``X````XY@``#````$?F```:````5.8``"@```!OY@``#P```)CF```(````
MJ.8```@```"QY@``$P```+KF```>````SN8``"$```#MY@``(`````_G```9
M````,.<``!<```!*YP``)0```&+G```7````B.<``!8```"@YP``!````+?G
M```;````O.<```T```#8YP``#````.;G```#````\^<```4```#WYP``"```
M`/WG```*````!N@```P````1Z```"P```![H```0````*N@```P````[Z```
M#@```$CH```+````5^@```0```!CZ```!````&CH```3````;>@``!0```"!
MZ```#````);H```)````H^@```X```"MZ```"P```+SH```;````R.@``!,`
M``#DZ```&0```/CH```;````$ND```X````NZ0``"P```#WI```,````2>D`
M`!4```!6Z0``#0```&SI``!#````>ND``#$```"^Z0``0@```/#I``!'````
M,^H``$\```![Z@``/0```,OJ``!.````">L``!$```!8ZP``!P```&KK```'
M````<NL```H```!ZZP``#0```(7K```)````D^L```0```"=ZP``!0```*+K
M```#````J.L``!@```"LZP``"@```,7K```$````T.L``"4```#5ZP``)@``
M`/OK```.````(NP``'P````Q[```%0```*[L```%````Q.P```<```#*[```
M#````-+L```(````W^P```H```#H[```!@```//L```'````^NP``#D````"
M[0``"````#SM```-````1>T```(```!3[0``!@```%;M```&````7>T``!0`
M``!D[0``#0```'GM```0````A^T``!L```"8[0``!````+3M```)````N>T`
M``4```##[0``$````,GM```)````VNT```D```#D[0``!0```.[M```:````
M].T```@````/[@``!@```!CN```9````'^X```X````Y[@``+@```$CN```'
M````=^X```<```!_[@``!0```(?N```)````C>X```H```"7[@``#@```*+N
M```"````L>X```8```"T[@``"P```+ON```-````Q^X```D```#5[@``#```
M`-_N```8````[.X```8````%[P``$@````SO```)````'^\```<````I[P``
M%````#'O```=````1N\``$(```!D[P``)0```*?O```E````S>\```8```#S
M[P``"@```/KO```$````!?````D````*\```"````!3P```1````'?````D`
M```O\```!@```#GP```-````0/````8```!.\```!````%7P```Y````6O``
M`#T```"4\```.@```-+P```>````#?$```4````L\0``#@```#+Q```$````
M0?$```8```!&\0``!P```$WQ```A````5?$```T```!W\0``%0```(7Q```&
M````F_$```0```"B\0``$0```*?Q```&````N?$```H```#`\0``(@```,OQ
M```$````[O$```4```#S\0``'0```/GQ```$````%_(```P````<\@``#@``
M`"GR```*````./(```@```!#\@``"0```$SR```%````5O(``#H```!<\@``
M,````)?R```U````R/(``"D```#^\@``1P```"CS```X````</,``"D```"I
M\P``/P```-/S```N````$_0``"T```!"]```'P```'#T```/````D/0``!(`
M``"@]```"P```+/T```F````O_0``"D```#F]```)````!#U```F````-?4`
M``@```!<]0``"@```&7U```)````</4```<```!Z]0``(````(+U```@````
MH_4``"8```#$]0``"@```.OU```9````]O4``"D````0]@``%@```#KV```2
M````4?8```<```!D]@``"@```&SV```,````=_8```\```"$]@``$````)3V
M``!`````I?8``'````#F]@``9@```%?W```.````OO<```D```#-]P``"@``
M`-?W```2````XO<``!,```#U]P``#`````GX```&````%O@```\````=^```
M"0```"WX```2````-_@``!````!*^```$0```%OX```<````;?@``",```"*
M^```:@```*[X```/````&?D```4````I^0``$````"_Y``!#````0/D```D`
M``"$^0``,@```([Y```$````P?D```L```#&^0``(````-+Y```4````\_D`
M``P````(^@``#````!7Z```/````(OH``!4````R^@``*0```$CZ```J````
M<OH``"8```"=^@``)P```,3Z```I````[/H``"H````6^P``&0```$'[``!"
M````6_L``!$```">^P``$@```+#[```3````P_L``!0```#7^P``#P```.S[
M```6````_/L``!<````3_```$````"O\```1````//P``#0```!._```$P``
M`(/\```2````E_P``#4```"J_```%````.#\```'````]?P```P```#]_```
M(`````K]```0````*_T``!0````\_0``$0```%']```7````8_T``!P```![
M_0``$P```)C]```4````K/T``!H```#!_0``$0```-S]```:````[OT``!X`
M```)_@``&@```"C^```3````0_X``!4```!7_@``$0```&W^```7````?_X`
M`!0```"7_@``%P```*S^```5````Q/X```D```#:_@``$````.3^```9````
M]?X```0````/_P``!P```!3_```"````'/\```L````?_P``!0```"O_```1
M````,?\```8```!#_P``!@```$K_```&````4?\```4```!8_P``!P```%[_
M```'````9O\```4```!N_P``%@```'3_```&````B_\```8```"2_P``!```
M`)G_```$````GO\```<```"C_P``#@```*O_```,````NO\```P```#'_P``
M#0```-3_```*````XO\```X```#M_P``!0```/S_```H`````@`!``X````K
M``$`#````#H``0`/````1P`!``H```!7``$`"````&(``0`)````:P`!`"L`
M``!U``$`!````*$``0`(````I@`!`"8```"O``$`$@```-8``0`/````Z0`!
M``8```#Y``$`"@`````!`0!,````"P$!``<```!8`0$`"````&`!`0`@````
M:0$!``D```"*`0$`%````)0!`0`,````J0$!``T```"V`0$`#@```,0!`0`6
M````TP$!`!$```#J`0$`!@```/P!`0`#`````P(!``8````'`@$`&0````X"
M`0`'````*`(!``0````P`@$`"P```#4"`0`+````00(!``<```!-`@$`"0``
M`%4"`0`5````7P(!``4```!U`@$`!P```'L"`0`6````@P(!``T```":`@$`
M#0```*@"`0`*````M@(!`!````#!`@$`#P```-("`0`1````X@(!`!<```#T
M`@$`"@````P#`0`1````%P,!``@````I`P$`!````#(#`0`/````-P,!`#H`
M``!'`P$`!0```((#`0`,````B`,!`!X```"5`P$`#@```+0#`0`0````PP,!
M``L```#4`P$`#````.`#`0`)````[0,!``<```#W`P$`!P```/\#`0`*````
M!P0!``D````2!`$`#@```!P$`0`0````*P0!`!L````\!`$`&````%@$`0`:
M````<00!``H```",!`$`"0```)<$`0`*````H00!``P```"L!`$`#P```+D$
M`0`(````R00!``8```#2!`$`'````-D$`0`'````]@0!``4```#^!`$`"P``
M``0%`0!'````$`4!``T```!8!0$`"0```&8%`0`$````<`4!``,```!U!0$`
M$P```'D%`0`3````C04!`!,```"A!0$`"@```+4%`0`"````P`4!``0```##
M!0$`)0```,@%`0`#````[@4!``4```#R!0$`*@```/@%`0`*````(P8!``4`
M```N!@$`!````#0&`0`*````.08!``T```!$!@$`!@```%(&`0`(````608!
M``@```!B!@$`!````&L&`0`%````<`8!`&@```!V!@$`"0```-\&`0`,````
MZ08!`!````#V!@$`&`````<'`0`%````(`<!``8````F!P$`$````"T'`0`;
M````/@<!`"\```!:!P$`$````(H'`0`*````FP<!`!L```"F!P$`#P```,('
M`0`*````T@<!``D```#=!P$`$P```.<'`0`;````^P<!`!@````7"`$`%P``
M`#`(`0`?````2`@!`!<```!H"`$`#@```(`(`0")````CP@!`(D````9"0$`
M`P```*,)`0`'````IPD!``@```"O"0$`!P```+@)`0`*````P`D!``L```#+
M"0$`!P```-<)`0!1````WPD!`!`````Q"@$`#````$(*`0`-````3PH!`!H`
M``!="@$`2@```'@*`0`9````PPH!``8```#="@$`&@```.0*`0`E````_PH!
M``8````E"P$`!@```"P+`0`?````,PL!``8```!3"P$`"0```%H+`0`8````
M9`L!`!<```!]"P$`*````)4+`0`&````O@L!``T```#%"P$`(@```-,+`0`9
M````]@L!`"8````0#`$`5P```#<,`0`3````CPP!`!D```"C#`$`&P```+T,
M`0`C````V0P!`!,```#]#`$``@```!$-`0`+````%`T!``@````@#0$`#0``
M`"D-`0`*````-PT!``<```!"#0$`%````$H-`0`&````7PT!``@```!F#0$`
M#@```&\-`0`'````?@T!``H```"&#0$`"P```)$-`0`R````G0T!``<```#0
M#0$`#````-@-`0`-````Y0T!`!<```#S#0$`#`````L.`0`$````&`X!``D`
M```=#@$`"0```"<.`0`*````,0X!``X````\#@$`#````$L.`0`'````6`X!
M``D```!@#@$`!P```&H.`0`*````<@X!`!L```!]#@$`#P```)D.`0`2````
MJ0X!``H```"\#@$`%@```,<.`0`)````W@X!`!````#H#@$`!P```/D.`0`2
M`````0\!`"D````4#P$`!````#X/`0`'````0P\!``4```!+#P$`!0```%$/
M`0`+````5P\!`!0```!C#P$`$0```'@/`0`:````B@\!`!8```"E#P$`%```
M`+P/`0`7````T0\!`!@```#I#P$`'`````(0`0`9````'Q`!``<````Y$`$`
M!0```$$0`0`-````1Q`!``P```!5$`$`"````&(0`0`(````:Q`!`!<```!T
M$`$`"P```(P0`0`,````F!`!`!\```"E$`$`&@```,40`0`3````X!`!``0`
M``#T$`$`"@```/D0`0`$````!!$!``T````)$0$`#````!<1`0`%````)!$!
M``D````J$0$`!0```#01`0`'````.A$!``4```!"$0$`!````$@1`0`"````
M31$!`"\```!0$0$`.````(`1`0`L````N1$!`",```#F$0$`)@````H2`0`2
M````,1(!`"D```!$$@$`,@```&X2`0`*````H1(!`"P```"L$@$`+@```-D2
M`0`S````"!,!`#,````\$P$`.````'`3`0`/````J1,!`!@```"Y$P$`$```
M`-(3`0`N````XQ,!`!0````2%`$`#P```"<4`0`3````-Q0!`!4```!+%`$`
M%````&$4`0`2````=A0!`!0```")%`$`%0```)X4`0`M````M!0!`"T```#B
M%`$`,0```!`5`0`N````0A4!`"\```!Q%0$`+````*$5`0!B````SA4!`!,`
M```Q%@$`#0```$46`0`(````4Q8!`!0```!<%@$`%P```'$6`0`(````B18!
M`!0```"2%@$`#````*<6`0`K````M!8!`"$```#@%@$`&@````(7`0`)````
M'1<!`$4````G%P$`00```&T7`0`$````KQ<!`!,```"T%P$`%````,@7`0`.
M````W1<!`!,```#L%P$`&``````8`0`&````&1@!``D````@&`$`"@```"H8
M`0`/````-1@!``P```!%&`$`$````%(8`0`'````8Q@!``X```!K&`$`!0``
M`'H8`0`;````@!@!`!0```"<&`$`"````+$8`0`&````NA@!`!0```#!&`$`
M$0```-88`0`.````Z!@!`#@```#W&`$``@```#`9`0`&````,QD!``X````Z
M&0$`!0```$D9`0`'````3QD!``X```!7&0$`!@```&89`0`H````;1D!``P`
M``"6&0$`'````*,9`0`$````P!D!`"D```#%&0$`%0```.\9`0`7````!1H!
M`!\````=&@$`7````#T:`0`4````FAH!`#X```"O&@$`'P```.X:`0`0````
M#AL!``<````?&P$`'@```"<;`0`.````1AL!``P```!5&P$`#````&(;`0`3
M````;QL!``H```"#&P$`'0```(X;`0`9````K!L!``4```#&&P$`$0```,P;
M`0`-````WAL!``@```#L&P$`$0```/4;`0`D````!QP!`!(````L'`$`%0``
M`#\<`0`2````51P!``X```!H'`$`&0```'<<`0`(````D1P!``D```":'`$`
M#0```*0<`0`'````LAP!``H```"Z'`$`!P```,4<`0`/````S1P!``8```#=
M'`$`"P```.0<`0`:````\!P!``H````+'0$`!P```!8=`0`(````'AT!``4`
M```G'0$`'P```"T=`0`&````31T!`!````!4'0$`"````&4=`0`-````;AT!
M``@```!\'0$`'@```(4=`0`2````I!T!`"P```"W'0$`&@```.0=`0`)````
M_QT!``H````)'@$`%0```!0>`0`%````*AX!`!0````P'@$`!````$4>`0`0
M````2AX!``8```!;'@$`!P```&(>`0`>````:AX!`"@```")'@$`"@```+(>
M`0`<````O1X!`!$```#:'@$`"P```.P>`0`:````^!X!`!0````3'P$`!```
M`"@?`0`$````+1\!``L````R'P$`!0```#X?`0`&````1!\!``@```!+'P$`
M!@```%0?`0`*````6Q\!`!L```!F'P$`-````((?`0`T````MQ\!`"````#L
M'P$`*0````T@`0`@````-R`!`$$```!8(`$`&@```)H@`0`H````M2`!`"@`
M``#>(`$`*0````<A`0!0````,2$!`"(```""(0$`!@```*4A`0`(````K"$!
M``4```"U(0$`"````+LA`0`9````Q"$!`!D```#>(0$`*@```/@A`0`C````
M(R(!`!D```!'(@$`+@```&$B`0`T````D"(!``@```#%(@$`%P```,XB`0`*
M````YB(!``<```#Q(@$`(0```/DB`0`0````&R,!``X````L(P$`"P```#LC
M`0`'````1R,!`!,```!/(P$`"````&,C`0`+````;",!``H```!X(P$`%```
M`(,C`0`/````F",!`#(```"H(P$`"P```-LC`0`.````YR,!``4```#V(P$`
M!0```/PC`0`%`````B0!`!<````()`$`!P```"`D`0`/````*"0!``0````X
M)`$`"@```#TD`0`)````2"0!``L```!2)`$`#0```%XD`0`,````;"0!``X`
M``!Y)`$`!0```(@D`0`$````CB0!``T```"3)`$`,@```*$D`0!%````U"0!
M``@````:)0$`"P```",E`0`7````+R4!``<```!')0$`'@```$\E`0`4````
M;B4!``4```"#)0$`$@```(DE`0`2````G"4!`!0```"O)0$`!@```,0E`0`'
M````RR4!``X```#3)0$`*@```.(E`0`&````#28!``P````4)@$`#0```"$F
M`0`1````+R8!``L```!!)@$`-@```$TF`0`*````A"8!`"(```"/)@$`"P``
M`+(F`0`/````OB8!`#(```#.)@$`)0````$G`0`P````)R<!`#$```!8)P$`
M+0```(HG`0`.````N"<!``D```#')P$`"P```-$G`0`%````W2<!``X```#C
M)P$`$P```/(G`0`2````!B@!``<````9*`$`%@```"$H`0`1````."@!`!0`
M``!**`$`$P```%\H`0`'````<R@!`!0```![*`$`&````)`H`0`'````J2@!
M``4```"Q*`$`#````+<H`0`,````Q"@!`!(```#1*`$`!````.0H`0`'````
MZ2@!``H```#Q*`$`"P```/PH`0`,````""D!``X````5*0$`#@```"0I`0`%
M````,RD!``0````Y*0$`"P```#XI`0`,````2BD!``T```!7*0$`#````&4I
M`0`)````<BD!``4```!\*0$`!0```((I`0`N````B"D!`"8```"W*0$`(P``
M`-XI`0`#`````BH!`!(````&*@$`!@```!DJ`0`>````("H!`!@````_*@$`
M)0```%@J`0`-````?BH!``D```",*@$`'P```)8J`0`#````MBH!`!@```"Z
M*@$`!P```-,J`0`*````VRH!``(```#F*@$`#````.DJ`0`5````]BH!``L`
M```,*P$`&0```!@K`0`@````,BL!`!(```!3*P$`!0```&8K`0`*````;"L!
M`!4```!W*P$`$@```(TK`0`,````H"L!``0```"M*P$`"0```+(K`0`'````
MO"L!``P```#$*P$`#0```-$K`0!2````WRL!`!<````R+`$`)````$HL`0`2
M````;RP!``<```""+`$`!@```(HL`0`/````D2P!`!,```"A+`$`'@```+4L
M`0`@````U"P!``8```#U+`$`#@```/PL`0`$````"RT!``P````0+0$`#0``
M`!TM`0`.````*RT!`!4````Z+0$`$@```%`M`0`/````8RT!`!0```!S+0$`
M"@```(@M`0`;````DRT!`!````"O+0$`"P```,`M`0`4````S"T!`&D```#A
M+0$`&@```$LN`0`7````9BX!`"<```!^+@$`&@```*8N`0`7````P2X!`!L`
M``#9+@$`&0```/4N`0`?````#R\!`!,````O+P$`$P```$,O`0`(````5R\!
M``8```!@+P$`!P```&<O`0`(````;R\!``D```!X+P$`%0```((O`0`-````
MF"\!`",```"F+P$`#0```,HO`0`3````V"\!``@```#L+P$``P```/4O`0!&
M````^2\!`#\```!`,`$`-P```(`P`0!7````N#`!`!X````0,0$`!0```"\Q
M`0`?````-3$!`"\```!5,0$`"@```(4Q`0`(````D#$!``T```"9,0$`+0``
M`*<Q`0`$````U3$!`!(```#:,0$`$P```.TQ`0!/`````3(!`"4```!1,@$`
M'````'<R`0`+````E#(!`!\```"@,@$`'0```,`R`0`E````WC(!`"`````$
M,P$`)````"4S`0`@````2C,!``L```!K,P$`!P```'<S`0`-````?S,!``P`
M``"-,P$`%P```)HS`0`&````LC,!`#D```"Y,P$`#````/,S`0`'`````#0!
M``D````(-`$`$P```!(T`0`)````)C0!``0````P-`$`$````#4T`0`(````
M1C0!``@```!/-`$`!````%@T`0`+````730!``P```!I-`$`$@```'8T`0`1
M````B30!``P```";-`$`&@```*@T`0`/````PS0!``<```#3-`$`#0```-LT
M`0`4````Z30!``X```#^-`$`#`````TU`0`;````&C4!`"P````V-0$`$P``
M`&,U`0`<````=S4!`"@```"4-0$`!@```+TU`0`'````Q#4!`!,```#,-0$`
M!0```.`U`0`$````YC4!`!<```#K-0$`"@````,V`0`,````#C8!``D````;
M-@$`!@```"4V`0`)````+#8!``@````V-@$`"0```#\V`0`*````238!`!$`
M``!4-@$`!@```&8V`0`C````;38!``X```"1-@$`#@```*`V`0`-````KS8!
M``L```"]-@$`'0```,DV`0`+````YS8!``(```#S-@$`'````/8V`0`=````
M$S<!``<````Q-P$`"````#DW`0`&````0C<!`&0```!)-P$`"0```*XW`0`'
M````N#<!`"8```#`-P$`.````.<W`0`:````(#@!`"H````[.`$`.P```&8X
M`0`H````HC@!`#0```#+.`$`&0`````Y`0`5````&CD!``4````P.0$`!P``
M`#8Y`0`(````/CD!``<```!'.0$`!0```$\Y`0`'````53D!``X```!=.0$`
M"0```&PY`0`&````=CD!``@```!].0$`"P```(8Y`0`'````DCD!``@```":
M.0$`!P```*,Y`0`6````JSD!``D```#".0$`!@```,PY`0`+````TSD!`!``
M``#?.0$`!@```/`Y`0`<````]SD!`!0````4.@$`!P```"DZ`0`1````,3H!
M``@```!#.@$`#@```$PZ`0`(````6SH!``4```!D.@$`$````&HZ`0`)````
M>SH!`!````"%.@$`!@```)8Z`0`9````G3H!``H```"W.@$`'````,(Z`0`'
M````WSH!``4```#G.@$`$````.TZ`0`4````_CH!``L````3.P$`#0```!\[
M`0`H````+3L!`!@```!6.P$`%P```&\[`0`$````ASL!``D```",.P$`"@``
M`)8[`0`'````H3L!``(```"I.P$`#@```*P[`0`(````NSL!`",```#$.P$`
M'P```.@[`0`X````"#P!`"8```!!/`$`,0```&@\`0`G````FCP!`#(```#"
M/`$`,@```/4\`0!D````*#T!`!0```"-/0$`50```*(]`0`X````^#T!`$H`
M```Q/@$`6P```'P^`0`H````V#X!`!$````!/P$`.````!,_`0`H````3#\!
M`"P```!U/P$`)@```*(_`0`;````R3\!`#X```#E/P$`J0$``"1``0`C````
MSD$!`!<```#R00$`2`````I"`0"%````4T(!`#````#90@$`)0````I#`0!!
M````,$,!`%L```!R0P$`20```,Y#`0`Q````&$0!`!T```!*1`$`&````&A$
M`0`K````@40!`"$```"M1`$`'P```,]$`0`K````[T0!`"8````;10$`)P``
M`$)%`0`Z````:D4!`!T```"E10$`$0```,-%`0`S````U44!`"4````)1@$`
M)P```"]&`0`@````5T8!`!\```!X1@$`,````)A&`0!I````R48!`#$````S
M1P$`00```&5'`0`S````IT<!`"4```#;1P$`/0````%(`0!E````/T@!`$T`
M``"E2`$`*0```/-(`0`K````'4D!`"\```!)20$`+@```'E)`0`P````J$D!
M`%0```#920$`6@```"Y*`0!(````B4H!`$H```#22@$`,@```!U+`0`O````
M4$L!`"P```"`2P$`+0```*U+`0!Q````VTL!`&8```!-3`$`;P```+1,`0"S
M````)$T!`!<```#830$`)0```/!-`0`R````%DX!`"D```!)3@$`/@```'-.
M`0`B````LDX!`%(```#53@$`)0```"A/`0`+````3D\!`+$```!:3P$`10``
M``Q0`0`A````4E`!`#````!T4`$`)0```*50`0`<````RU`!`#$```#H4`$`
M!P```!I1`0`'````(E$!``0````J40$`#0```"]1`0`+````/5$!``X```!)
M40$`"P```%A1`0`%````9%$!`!````!J40$``@```'M1`0!9````?E$!``,`
M``#840$`!0```-Q1`0`2````XE$!``0```#U40$`!P```/I1`0`(`````E(!
M``4````+4@$`,````!%2`0`#````0E(!`!````!&4@$`#````%=2`0`3````
M9%(!``T```!X4@$``@```(92`0`'````B5(!``8```"14@$`%````)A2`0`,
M````K5(!`!@```"Z4@$`!@```--2`0`2````VE(!``P```#M4@$``P```/I2
M`0`J````_E(!``0````I4P$`!@```"Y3`0`'````-5,!`!\````]4P$`-0``
M`%U3`0`N````DU,!`"\```#"4P$`%P```/)3`0`B````"E0!`"4````M5`$`
M(````%-4`0`;````=%0!`!@```"05`$`)````*E4`0`?````SE0!`!H```#N
M5`$`(0````E5`0`@````*U4!`!H```!,50$`,@```&=5`0`:````FE4!`"\`
M``"U50$`*P```.55`0`?````$58!`",````Q5@$`'P```%56`0`:````=58!
M`"$```"05@$`)0```+)6`0`F````V%8!`"4```#_5@$`)````"57`0`8````
M2E<!`!T```!C5P$`)````(%7`0`8````IE<!`"(```"_5P$`+````.)7`0`O
M````#U@!`!4````_6`$`)0```%58`0`\````>U@!`!\```"X6`$`(P```-A8
M`0`?````_%@!`"`````<60$`&@```#U9`0`8````6%D!`"8```!Q60$`'@``
M`)A9`0`I````MUD!`!X```#A60$`,0````!:`0`)````,EH!``P````\6@$`
M%P```$E:`0`O````85H!`"0```"16@$`!P```+9:`0`/````OEH!`!0```#.
M6@$`#@```.-:`0`-````\EH!`"0`````6P$`!0```"5;`0`'````*UL!`"(`
M```S6P$`)0```%9;`0`:````?%L!`!T```"76P$`&@```+5;`0`'````T%L!
M`,<```#86P$`"P```*!<`0`5````K%P!``8```#"7`$`"0```,E<`0`+````
MTUP!``T```#?7`$`%P```.U<`0`&````!5T!`#,````,70$`$P```$!=`0`3
M````5%T!``<```!H70$`#P```'!=`0`'````@%T!`#(```"(70$`!````+M=
M`0`A````P%T!`!,```#B70$`#````/9=`0`1`````UX!`#(````57@$`%@``
M`$A>`0`(````7UX!`!T```!H7@$`"0```(9>`0`*````D%X!`!0```";7@$`
M"@```+!>`0`=````NUX!``@```#97@$`#0```.)>`0`Z````\%X!`!\````K
M7P$`"````$M?`0`:````5%\!`"<```!O7P$`!@```)=?`0`5````GE\!``<`
M``"T7P$`"````+Q?`0`)````Q5\!`#\```#/7P$`!P````]@`0`/````%V`!
M``X````G8`$`$````#9@`0`)````1V`!``D```!18`$`"````%M@`0`3````
M9&`!``<```!X8`$`&0```(!@`0`*````FF`!`!<```"E8`$`%````+U@`0`*
M````TF`!``P```#=8`$`%P```.I@`0`$`````F$!`"H````'80$`#````#)A
M`0`1````/V$!``<```!180$``@```%EA`0`0````7&$!`!@```!M80$`"P``
M`(9A`0`#````DF$!``@```"680$`!@```)]A`0`'````IF$!``T```"N80$`
M"P```+QA`0`4````R&$!`!4```#=80$`#@```/-A`0`5`````F(!`"\````8
M8@$`(````$AB`0`<````:6(!`!4```"&8@$`#````)QB`0`Q````J6(!``D`
M``#;8@$`#@```.5B`0`[````]&(!`!4````P8P$`!0```$9C`0`2````3&,!
M`#\```!?8P$`$@```)]C`0`*````LF,!``8```"]8P$`!````,1C`0`$````
MR6,!``H```#.8P$`$P```-EC`0`%````[6,!``8```#S8P$`!@```/IC`0`(
M`````60!``0````*9`$`#`````]D`0`*````'&0!`#D````G9`$`+@```&%D
M`0`I````D&0!``H```"Z9`$`!0```,5D`0`,````RV0!``P```#89`$`#0``
M`.5D`0`8````\V0!`!D````,90$`'P```"9E`0`=````1F4!`!$```!D90$`
M`@```'9E`0`$````>64!``H```!^90$`!@```(EE`0`%````D&4!``,```"6
M90$`#````)IE`0!%````IV4!`#(```#M90$`,0```"!F`0`S````4F8!`!H`
M``"&9@$`-````*%F`0`H````UF8!`%,```#_9@$`&0```%-G`0`?````;6<!
M`'(```"-9P$`(`````!H`0`U````(6@!`"$```!7:`$`10```'EH`0`P````
MOV@!`"@```#P:`$`*0```!EI`0`F````0VD!`&````!J:0$`)0```,MI`0`H
M````\6D!`"@````::@$`(@```$-J`0`K````9FH!`#````"2:@$`$@```,-J
M`0`3````UFH!`!````#J:@$`>0```/MJ`0`)````=6L!`*$```!_:P$`<P``
M`"%L`0!\````E6P!`"L````2;0$`5````#YM`0`7````DVT!`"<```"K;0$`
M%@```--M`0`/````ZFT!`!<```#Z;0$`'P```!)N`0!`````,FX!`!\```!S
M;@$`'````)-N`0!1````L&X!`!H````";P$`%````!UO`0`*````,F\!``4`
M```];P$`!@```$-O`0`(````2F\!``4```!3;P$`$@```%EO`0`,````;&\!
M`!````!Y;P$`$P```(IO`0`=````GF\!``\```"\;P$`&P```,QO`0`D````
MZ&\!``\````-<`$`"@```!UP`0`$````*'`!``D````M<`$`"P```#=P`0`:
M````0W`!`"(```!><`$`"````(%P`0`'````BG`!``4```"2<`$`%````)AP
M`0`I````K7`!``<```#7<`$`"````-]P`0`/````Z'`!`!@```#X<`$`%```
M`!%Q`0`(````)G$!``P````O<0$`#P```#QQ`0`'````3'$!``8```!4<0$`
M%````%MQ`0`&````<'$!``D```!W<0$`"@```(%Q`0`&````C'$!``P```"3
M<0$`$0```*!Q`0`#````LG$!``@```"V<0$`!````+]Q`0`9````Q'$!`!$`
M``#><0$`"@```/!Q`0`8````^W$!`!,````4<@$`'````"AR`0`1````17(!
M`!H```!7<@$`!````')R`0`/````=W(!``<```"'<@$`!0```(]R`0`$````
ME7(!`!D```":<@$`!P```+1R`0`"````O'(!``(```"_<@$`$0```,)R`0`)
M````U'(!``@```#><@$`!@```.=R`0`2````[G(!`!<````!<P$`!@```!ES
M`0`A````(',!``4```!"<P$`)P```$AS`0`"````<',!``0```!S<P$`#P``
M`'AS`0`3````B',!``<```"<<P$``@```*1S`0`'````IW,!`!$```"O<P$`
M!@```,%S`0`A````R',!`!@```#J<P$`!@````-T`0`3````"G0!`!`````>
M=`$`$@```"]T`0`"````0G0!``8```!%=`$`#````$QT`0`)````670!`!$`
M``!C=`$`(@```'5T`0`'````F'0!``<```"@=`$`"P```*AT`0`%````M'0!
M``(```"Z=`$`"P```+UT`0!6`0``R70!`!,````@=@$`$0```#1V`0`.````
M1G8!``D```!5=@$`"P```%]V`0`(````:W8!``,```!T=@$``0```'AV`0`$
M````>G8!`!4```!_=@$`&@```)5V`0`J````L'8!`"$```#;=@$`(@```/UV
M`0`:````('<!`!(````[=P$`*@```$YW`0`+````>7<!`"8```"%=P$`$@``
M`*QW`0`-````OW<!``X```#-=P$`!0```-QW`0`C````XG<!``H````&>`$`
M$````!%X`0`.````(G@!`!(````Q>`$`#P```$1X`0!E````5'@!`!````"Z
M>`$`#````,MX`0`/````V'@!``P```#H>`$`$````/5X`0`.````!GD!`!``
M```5>0$`$0```"9Y`0`&````.'D!`,(````_>0$`#P````)Z`0`5````$GH!
M`!4````H>@$`#0```#YZ`0`5````3'H!`!4```!B>@$`"0```'AZ`0`*````
M@GH!`#P```"->@$`%0```,IZ`0`P````X'H!`$,````1>P$`7@```%5[`0!@
M````M'L!`%P````5?`$`9@```')\`0`R````V7P!``D````,?0$`$@```!9]
M`0`'````*7T!``H````Q?0$`#@```#Q]`0`%````2WT!``8```!1?0$`$@``
M`%A]`0`*````:WT!``D```!V?0$`#0```(!]`0`N````CGT!`"T```"]?0$`
M&````.M]`0`:````!'X!`!8````??@$`"@```#9^`0`F````07X!``\```!H
M?@$`,0```'A^`0`%````JGX!``X```"P?@$`#P```+]^`0`,````SWX!`!``
M``#<?@$`$0```.U^`0`;````_WX!`!8````;?P$`%````#)_`0`,````1W\!
M`!,```!4?P$`"@```&A_`0`H````<W\!`!0```"<?P$`%0```+%_`0`.````
MQW\!`%L```#6?P$`.````#*``0`A````:X`!``T```"-@`$`!@```)N``0`+
M````HH`!`#D```"N@`$`"````.B``0`)````\8`!``H```#[@`$`!P````:!
M`0`'````#H$!``4````6@0$`!0```!R!`0`'````(H$!``8````J@0$`'@``
M`#&!`0`-````4($!``\```!>@0$`&0```&Z!`0`0````B($!``T```"9@0$`
M%0```*>!`0`G````O8$!``X```#E@0$`)P```/2!`0`<````'((!`"(````Y
M@@$`(@```%R"`0`5````?X(!`!8```"5@@$`$@```*R"`0`7````OX(!`!H`
M``#7@@$`!P```/*"`0`&````^H(!``@````!@P$`#@````J#`0`'````&8,!
M``@````A@P$`"0```"J#`0`2````-(,!`!$```!'@P$`!P```%F#`0`,````
M88,!`!(```!N@P$`#P```(&#`0`A````D8,!``<```"S@P$`#0```+N#`0`(
M````R8,!`!4```#2@P$`#````.B#`0`,````]8,!`#`````"A`$`/P```#.$
M`0`_````<X0!``D```"SA`$`!P```+V$`0`3````Q80!``4```#9A`$`!0``
M`-^$`0`0````Y80!``L```#VA`$`%@````*%`0`W````&84!`!````!1A0$`
M)0```&*%`0`G````B(4!`"<```"PA0$`)````-B%`0`/````_84!``8````-
MA@$`"0```!2&`0`(````'H8!`#8````GA@$`/P```%Z&`0`U````GH8!`%T`
M``#4A@$`-````#*'`0`T````9X<!`$$```"<AP$`0P```-Z'`0`T````(H@!
M`$<```!7B`$`*````)^(`0`J````R(@!`$4```#SB`$`-````#F)`0`Z````
M;HD!`"P```"IB0$`&0```-:)`0`=````\(D!`"X````.B@$`*P```#V*`0`K
M````:8H!`"L```"5B@$`&P```,&*`0`+````W8H!``\```#IB@$`!@```/F*
M`0`*`````(L!`!@````+BP$`'@```"2+`0`&````0XL!``<```!*BP$`%```
M`%*+`0`*````9XL!``@```!RBP$`+@```'N+`0`*````JHL!``H```"UBP$`
M!0```,"+`0`,````QHL!``8```#3BP$`!@```-J+`0`%````X8L!``<```#G
MBP$`!@```.^+`0`A````]HL!``P````8C`$`"P```"6,`0`6````,8P!`#,`
M``!(C`$`(P```'R,`0`H````H(P!``\```#)C`$`#````-F,`0`'````YHP!
M``D```#NC`$`!P```/B,`0`,`````(T!``4````-C0$`#P```!.-`0`&````
M(XT!`!(````JC0$`"````#V-`0`(````1HT!``0```!/C0$`#0```%2-`0`(
M````8HT!`"<```!KC0$`$````).-`0`(````I(T!``T```"MC0$`#````+N-
M`0`'````R(T!``,```#0C0$``P```-2-`0`3````V(T!`!````#LC0$`(P``
M`/V-`0`)````(8X!``4````KC@$`"0```#&.`0`'````.XX!`$8```!#C@$`
M(0```(J.`0`Z````K(X!`"8```#GC@$`'`````Z/`0`&````*X\!``0````R
MCP$`$@```#>/`0`@````2H\!`"$```!KCP$`+P```(V/`0`A````O8\!`"@`
M``#?CP$`80````B0`0`I````:I`!``D```"4D`$`"@```)Z0`0`0````J9`!
M`!<```"ZD`$`%0```-*0`0`-````Z)`!``4```#VD`$`#````/R0`0`,````
M"9$!``P````6D0$`#````".1`0`,````,)$!``P````]D0$`%````$J1`0`*
M````7Y$!`!<```!JD0$`&P```(*1`0`1````GI$!`!,```"PD0$`%0```,21
M`0`$````VI$!``4```#?D0$`$0```.61`0!+````]Y$!`!<```!#D@$`4P``
M`%N2`0`&````KY(!`!,```"VD@$`!0```,J2`0`%````T)(!`"````#6D@$`
M&````/>2`0`/````$),!`!`````@DP$`%@```#&3`0`?````2),!`#````!H
MDP$`"P```)F3`0`@````I9,!``8```#&DP$`%0```,V3`0`-````XY,!`!,`
M``#QDP$`#P````64`0`7````%90!`!(````ME`$`%````$"4`0`7````590!
M``P```!ME`$`!@```'J4`0`1````@90!``@```"3E`$`%P```)R4`0`4````
MM)0!`!(```#)E`$`"````-R4`0`$````Y90!``P```#JE`$`"P```/>4`0`&
M`````Y4!`!,````*E0$`"@```!Z5`0`'````*94!``T````QE0$`"0```#^5
M`0`,````294!``<```!6E0$`!@```%Z5`0`+````994!``@```!QE0$`"@``
M`'J5`0`/````A94!`$,```"5E0$`&@```-F5`0`2````])4!`"H````'E@$`
M!0```#*6`0`?````.)8!`!,```!8E@$`%````&R6`0`2````@98!`#,```"4
ME@$`0@```,B6`0`D````"Y<!``P````PEP$`)@```#V7`0`(````9)<!`!T`
M``!MEP$`#@```(N7`0`%````FI<!``L```"@EP$`!@```*R7`0`&````LY<!
M``D```"ZEP$`&0```,27`0`*````WI<!``X```#IEP$`!P```/B7`0`*````
M`)@!`!$````+F`$`)0```!V8`0`Q````0Y@!`"<```!UF`$`,P```)V8`0`;
M````T9@!`#````#MF`$`'0```!Z9`0`C````/)D!`#D```!@F0$`'P```)J9
M`0`G````NID!`"D```#BF0$`(0````R:`0`A````+IH!`"<```!0F@$`0@``
M`'B:`0`A````NYH!`"$```#=F@$`*P```/^:`0`?````*YL!`!\```!+FP$`
M.@```&N;`0`B````IIL!`!4```#)FP$`)P```-^;`0`@````!YP!`"L````H
MG`$`%0```%2<`0"2````:IP!`!H```#]G`$`'P```!B=`0`?````.)T!`"``
M``!8G0$`+@```'F=`0`=````J)T!`!\```#&G0$`(````.:=`0`L````!YX!
M`"X````TG@$`,````&.>`0`O````E)X!`*$```#$G@$`*P```&:?`0`@````
MDI\!`"0```"SGP$`(P```-B?`0`L````_)\!`$`````IH`$`1````&J@`0`/
M````KZ`!``,```"_H`$`!P```,.@`0`#````RZ`!``\```#/H`$`"````-^@
M`0`/````Z*`!`!D```#XH`$`$@```!*A`0`2````):$!``<````XH0$`!0``
M`$"A`0`8````1J$!`!8```!?H0$`&0```':A`0`4````D*$!`!<```"EH0$`
M$0```+VA`0`4````SZ$!`!,```#DH0$`3@```/BA`0`'````1Z(!``\```!/
MH@$`!@```%^B`0`3````9J(!`!D```!ZH@$`&P```)2B`0`0````L*(!``(`
M``#!H@$`#````,2B`0!0````T:(!``H````BHP$`#P```"VC`0`.````/:,!
M``<```!,HP$`&````%2C`0`3````;:,!``4```"!HP$`#@```(>C`0`7````
MEJ,!``@```"NHP$`$````+>C`0`3````R*,!``8```#<HP$`"@```..C`0`.
M````[J,!`!0```#]HP$`"P```!*D`0`&````'J0!``D````EI`$`"P```"^D
M`0`-````.Z0!``P```!)I`$`"P```%:D`0`-````8J0!`"H```!PI`$`"P``
M`)ND`0`-````IZ0!`"L```"UI`$`%@```.&D`0`4````^*0!`!<````-I0$`
M00```"6E`0`+````9Z4!`!<```!SI0$`&0```(NE`0`5````I:4!`!,```"[
MI0$`"0```,^E`0`?````V:4!`"$```#YI0$`*P```!NF`0!`````1Z8!`!L`
M``"(I@$`#````*2F`0`&````L:8!``\```"XI@$`!@```,BF`0`Y````SZ8!
M`#@````)IP$`!P```$*G`0`,````2J<!`!\```!7IP$`#@```'>G`0`:````
MAJ<!`!H```"AIP$`"0```+RG`0`2````QJ<!`!(```#9IP$`'0```.RG`0`1
M````"J@!`"0````<J`$`-0```$&H`0`<````=Z@!``H```"4J`$`$P```)^H
M`0`(````LZ@!`$,```"\J`$`#@````"I`0`D````#ZD!``D````TJ0$`0```
M`#ZI`0`&````?ZD!``H```"&J0$`"````)&I`0`/````FJD!`"$```"JJ0$`
M#@```,RI`0`8````VZD!`#````#TJ0$`"````"6J`0`+````+JH!`"0````Z
MJ@$`#P```%^J`0`'````;ZH!`!````!WJ@$`5@```(BJ`0`%````WZH!``<`
M``#EJ@$`!P```.VJ`0`*````]:H!``X`````JP$`#@````^K`0`0````'JL!
M`!$````OJP$`&````$&K`0`2````6JL!`!@```!MJP$`%@```(:K`0`(````
MG:L!``8```"FJP$`"P```*VK`0`,````N:L!``(```#&JP$`"@```,FK`0`0
M````U*L!`"<```#EJP$`&0````VL`0`4````)ZP!``8````\K`$`#0```$.L
M`0`.````4:P!``\```!@K`$`#P```'"L`0`Z````@*P!`"T```"[K`$`!@``
M`.FL`0`.````\*P!``<```#_K`$`$0````>M`0!G````&:T!`!0```"!K0$`
M%````):M`0`0````JZT!`!8```"\K0$`!P```-.M`0`%````VZT!`!\```#A
MK0$`+`````&N`0`B````+JX!`!X```!1K@$`,````'"N`0`?````H:X!`"(`
M``#!K@$`&@```.2N`0`;````_ZX!``4````;KP$`!P```"&O`0`'````*:\!
M``@````QKP$`$@```#JO`0`1````3:\!`!(```!?KP$`$0```'*O`0`@````
MA*\!`!0```"EKP$`#P```+JO`0`/````RJ\!``<```#:KP$`%@```.*O`0`(
M````^:\!``@````"L`$`%`````NP`0`6````(+`!`"$````WL`$`,````%FP
M`0`/````BK`!``L```":L`$`!P```*:P`0`@````KK`!`!L```#/L`$`)```
M`.NP`0`C````$+$!`!\````TL0$`'P```%2Q`0`I````=+$!`!P```">L0$`
M%@```+NQ`0`&````TK$!`!P```#9L0$`"@```/:Q`0`-`````;(!``4````/
ML@$`!@```!6R`0`(````'+(!``L````EL@$`#0```#&R`0`0````/[(!`!0`
M``!0L@$`#@```&6R`0`.````=+(!``\```"#L@$`!0```).R`0`(````F;(!
M`"(```"BL@$`(P```,6R`0`5````Z;(!``X```#_L@$`$0````ZS`0`0````
M(+,!`"@````QLP$`%@```%JS`0`;````<;,!`!H```"-LP$`$@```*BS`0`.
M````N[,!``\```#*LP$`%@```-JS`0`0````\;,!`#@````"M`$`*@```#NT
M`0`X````9K0!`$,```"?M`$`20```..T`0`\````+;4!`$H```!JM0$`%@``
M`+6U`0`+````S+4!``4```#8M0$`%````-ZU`0`5````\[4!``P````)M@$`
M#0```!:V`0`'````)+8!``0````LM@$`'````#&V`0`/````3K8!``4```!>
MM@$`+0```&2V`0`A````DK8!``T```"TM@$`DP```,*V`0`5````5K<!``D`
M``!LMP$`"@```':W`0`3````@;<!``P```"5MP$`#@```**W`0`(````L;<!
M``X```"ZMP$`+@```,FW`0`2````^+<!`!L````+N`$``@```">X`0`(````
M*K@!``8````SN`$`$0```#JX`0`.````3+@!`!$```!;N`$`'0```&VX`0`)
M````B[@!``H```"5N`$`"@```*"X`0`/````J[@!``@```"[N`$`"0```,2X
M`0`%````SK@!`!P```#4N`$`"0```/&X`0`&````^[@!`!`````"N0$`#P``
M`!.Y`0`S````([D!``<```!7N0$`!0```%^Y`0`%````9;D!``D```!KN0$`
M!P```'6Y`0`1````?;D!``0```"/N0$`!0```)2Y`0`-````FKD!``L```"H
MN0$`"@```+2Y`0`-````O[D!`!P```#-N0$`!P```.JY`0`4````\KD!``D`
M```'N@$`!P```!&Z`0`/````&;H!`",````IN@$`2````$VZ`0`K````EKH!
M`"L```#"N@$`!@```.ZZ`0`*````];H!``0`````NP$`"0````6[`0`(````
M#[L!`!0````8NP$`"P```"V[`0`&````.;L!``T```!`NP$`!@```$Z[`0`$
M````5;L!`$8```!:NP$`3P```*&[`0!+````\;L!`"`````]O`$`!0```%Z\
M`0`.````9+P!``0```!SO`$`!@```'B\`0`&````?[P!`!@```"&O`$`%```
M`)^\`0`5````M+P!``<```#*O`$`!````-*\`0`6````U[P!``0```#NO`$`
M#P```/.\`0`;`````[T!``8````?O0$`!0```":]`0`G````++T!``0```!4
MO0$`"@```%F]`0`-````9+T!``X```!RO0$`"````(&]`0`)````BKT!``4`
M``"4O0$`,````)J]`0`R````R[T!`#H```#^O0$`(````#F^`0!)````6KX!
M`#D```"DO@$`*0```-Z^`0`X````"+\!`"H```!!OP$`+````&R_`0`A````
MF;\!`!$```"[OP$`$````,V_`0`+````WK\!`"4```#JOP$`)P```!#``0`A
M````.,`!`",```!:P`$`!P```'[``0`)````AL`!``H```"0P`$`!@```)O`
M`0`I````HL`!`"D```#,P`$`,@```/;``0`)````*<$!`!\````SP0$`+0``
M`%/!`0`6````@<$!`!$```"8P0$`!P```*K!`0`+````LL$!``T```"^P0$`
M$````,S!`0`/````W<$!`$````#MP0$`C0```"["`0!D````O,(!`!$````A
MPP$`"````#/#`0`)````/,,!`!````!&PP$`$0```%?#`0`,````:<,!``4`
M``!VPP$`$````'S#`0`&````C<,!`!````"4PP$`#@```*7#`0`3````M,,!
M`!P```#(PP$`)@```.7#`0!T````#,0!`!````"!Q`$`!0```)+$`0`5````
MF,0!`#D```"NQ`$`"0```.C$`0`R````\L0!``0````EQ0$`"P```"K%`0`>
M````-L4!`!4```!5Q0$`"@```&O%`0`.````=L4!`!````"%Q0$`$P```);%
M`0`B````JL4!`"````#-Q0$`(````.[%`0`>````#\8!`"0````NQ@$`(@``
M`%/&`0`:````=L8!`#4```"1Q@$`$@```,?&`0`0````VL8!`!(```#KQ@$`
M$@```/[&`0`4````$<<!`!4````FQP$`$P```#S'`0`0````4,<!`!(```!A
MQP$`*0```'3'`0`3````GL<!`!4```"RQP$`2@```,C'`0`<````$\@!``P`
M```PR`$`$0```#W(`0`A````3\@!`!4```!QR`$`$0```(?(`0`2````F<@!
M`!T```"LR`$`'P```,K(`0`6````ZL@!`!<````!R0$`%0```!G)`0`3````
M+\D!`!T```!#R0$`(````&')`0`E````@LD!`!,```"HR0$`%````+S)`0`4
M````T<D!`!P```#FR0$`%0````/*`0`5````&<H!`!D````OR@$`"P```$G*
M`0`;````5<H!`!P```!QR@$`!````([*`0`'````D\H!``(```";R@$`"0``
M`)[*`0`&````J,H!`!<```"OR@$`!@```,?*`0`1````SLH!``H```#@R@$`
M!@```.O*`0`'````\LH!``@```#ZR@$`!@````/+`0`4````"LL!``8````?
MRP$`"````";+`0`(````+\L!``<````XRP$`!P```$#+`0`0````2,L!``X`
M``!9RP$`$@```&C+`0`0````>\L!``D```",RP$`%0```);+`0`%````K,L!
M`#````"RRP$`$P```./+`0`.````]\L!`!`````&S`$`#@```!?,`0`.````
M)LP!``X````US`$`*P```$3,`0`&````<,P!``@```!WS`$`-0```(#,`0`>
M````MLP!``X```#5S`$`!@```.3,`0`)````Z\P!`%$```#US`$`"0```$?-
M`0`%````4<T!`"0```!7S0$`%0```'S-`0`9````DLT!`!8```"LS0$`%```
M`,/-`0`A````V,T!`"4```#ZS0$`+0```"#.`0`&````3LX!``0```!5S@$`
M"````%K.`0`<````8\X!``<```"`S@$`!0```(C.`0`,````CLX!``L```";
MS@$`!@```*?.`0`-````KLX!`!P```"\S@$`!````-G.`0`'````WLX!`!4`
M``#FS@$`#````/S.`0`.````"<\!``\````8SP$`&````"C/`0`9````0<\!
M`!,```!;SP$`'0```&_/`0`3````C<\!`!,```"ASP$`"0```+7/`0`&````
MO\\!`!````#&SP$`/P```-?/`0`&````%]`!``\````>T`$`'@```"[0`0`1
M````3=`!`!4```!?T`$`#````'70`0`.````@M`!``L```"1T`$`!P```)W0
M`0`)````I=`!``\```"OT`$`#````+_0`0`-````S-`!`!T```#:T`$`(@``
M`/C0`0`B````&]$!`"@````^T0$`#````&?1`0`'````=-$!``L```!\T0$`
M$P```(C1`0`4````G-$!``8```"QT0$`#P```+C1`0`B````R-$!``T```#K
MT0$`#P```/G1`0`>````"=(!`&4````HT@$`(````([2`0`,````K](!``<`
M``"\T@$`!@```,32`0`>````R](!`!T```#JT@$`&@````C3`0`)````(],!
M``(````MTP$`!````##3`0`@````-=,!``8```!6TP$`!0```%W3`0`J````
M8],!``H```".TP$`!P```)G3`0`*````H=,!``\```"LTP$`#@```+S3`0`&
M````R],!``<```#2TP$`"@```-K3`0`%````Y=,!``4```#KTP$`@P```/'3
M`0`,````==0!``\```""U`$`&````)+4`0`;````J]0!``D```#'U`$`"@``
M`-'4`0`0````W-0!`!X```#MU`$`+`````S5`0`/````.=4!``H```!)U0$`
M'0```%35`0`0````<M4!``H```"#U0$`"0```([5`0`:````F-4!`"D```"S
MU0$`)P```-W5`0`F````!=8!`!X````LU@$`%P```$O6`0`6````8]8!`)X`
M``!ZU@$`I````!G7`0`(````OM<!``D```#'UP$`"@```-'7`0`'````W-<!
M``P```#DUP$`#0```/'7`0`&````_]<!`%(````&V`$`#P```%G8`0`.````
M:=@!``D```!XV`$`(````(+8`0!9````H]@!`!H```#]V`$`!@```!C9`0`>
M````']D!`"T````^V0$`"````&S9`0`'````==D!`!\```!]V0$`"````)W9
M`0`+````IMD!`"<```"RV0$`)@```-K9`0`E`````=H!``D````GV@$`"@``
M`#':`0`B````/-H!`",```!?V@$`+@```(/:`0!<````LMH!`!0````/VP$`
M%P```"3;`0`8````/-L!`"8```!5VP$`%````'S;`0`"````D=L!`!$```"4
MVP$`"P```*;;`0`6````LML!``X```#)VP$`!P```-C;`0`2````X-L!``8`
M``#SVP$`"````/K;`0`1`````]P!``T````5W`$`"@```"/<`0`,````+MP!
M`#,````[W`$`!P```&_<`0`1````=]P!`!(```")W`$`(````)S<`0`7````
MO=P!``8```#5W`$`#P```-S<`0`1````[-P!``\```#^W`$`%P````[=`0`7
M````)MT!``\````^W0$`#P```$[=`0`/````7MT!``@```!NW0$`'````'?=
M`0`>````E-T!``L```"SW0$`$@```+_=`0`=````TMT!``P```#PW0$`%P``
M`/W=`0`/````%=X!``T````EW@$`,@```#/>`0`$````9MX!``<```!KW@$`
M!0```'/>`0`%````>=X!``H```!_W@$`%0```(K>`0`1````H-X!`!H```"R
MW@$`%@```,W>`0`4````Y-X!`!<```#YW@$`'@```!'?`0`=````,-\!`!H`
M``!.WP$`!@```&G?`0`*````<-\!``X```![WP$`#0```(K?`0`'````F-\!
M``L```"@WP$`(P```*S?`0`-````T-\!``T```#>WP$`&@```.S?`0`F````
M!^`!`!0````NX`$`!P```$/@`0`0````2^`!``@```!<X`$`%````&7@`0`3
M````>N`!``D```".X`$`"0```)C@`0`%````HN`!``<```"HX`$``@```+#@
M`0`$````L^`!``(```"XX`$`.P```+O@`0!$````]^`!`$,````\X0$`-P``
M`(#A`0`]````N.$!``T```#VX0$`(@````3B`0`V````)^(!``P```!>X@$`
M*0```&OB`0`=````E>(!`"(```"SX@$`(@```-;B`0`G````^>(!`!`````A
MXP$`%````#+C`0`>````1^,!`#L```!FXP$`'````*+C`0`5````O^,!`!@`
M``#5XP$`%P```.[C`0`3````!N0!`!<````:Y`$`'````#+D`0`:````3^0!
M`"\```!JY`$`+P```)KD`0`S````RN0!`#````#^Y`$`,0```"_E`0`N````
M8>4!`&L```"0Y0$`)0```/SE`0`9````(N8!``L````\Y@$`$@```$CF`0`;
M````6^8!``H```!WY@$`'@```(+F`0`5````H>8!`"H```"WY@$`+````.+F
M`0`H````#^<!``D````XYP$`6P```$+G`0!-````GN<!``D```#LYP$`(```
M`/;G`0`F````%^@!``X````^Z`$`&````$WH`0`;````9N@!``4```""Z`$`
M"@```(CH`0`(````D^@!`!````"<Z`$`#0```*WH`0`2````N^@!``L```#.
MZ`$`"@```-KH`0`-````Y>@!`"4```#SZ`$`'0```!GI`0`)````-^D!``D`
M``!!Z0$`$@```$OI`0`5````7ND!`!````!TZ0$`.0```(7I`0`"````O^D!
M``<```#"Z0$`#@```,KI`0`'````V>D!``<```#AZ0$`$P```.GI`0`(````
M_>D!`#@````&Z@$`#@```#_J`0`9````3NH!``0```!HZ@$`,````&WJ`0`=
M````GNH!`!P```"\Z@$`+````-GJ`0!5````!NL!`!8```!<ZP$`1P```'/K
M`0`C````N^L!`!$```#?ZP$`"0```/'K`0`W````^^L!`!`````S[`$`$0``
M`$3L`0`,````5NP!`!,```!C[`$`#````'?L`0`;````A.P!`!L```"@[`$`
M`P```+SL`0`+````P.P!``X```#,[`$`"0```-OL`0`2````Y>P!`"@```#X
M[`$`'````"'M`0`>````/NT!`!,```!=[0$`$@```''M`0`G````A.T!``D`
M``"L[0$`$0```+;M`0`2````R.T!``<```#;[0$`"@```./M`0`'````[NT!
M``X```#V[0$`!P````7N`0`0````#>X!`!P````>[@$`$@```#ON`0`%````
M3NX!``@```!4[@$`!0```%WN`0`<````8^X!``8```"`[@$`$0```(?N`0`(
M````F>X!`!$```"B[@$`"````+3N`0`:````O>X!``X```#8[@$`*P```.?N
M`0`7````$^\!``D````K[P$`"@```#7O`0`=````0.\!``4```!>[P$`$P``
M`&3O`0`%````>.\!`"@```!^[P$`!P```*?O`0`)````K^\!`!P```"Y[P$`
M/````-;O`0`&````$_`!`!L````:\`$`$````#;P`0`(````1_`!`!,```!0
M\`$`"P```&3P`0`$````</`!``@```!U\`$`"P```'[P`0`'````BO`!``D`
M``"2\`$`"````)SP`0`'````I?`!``<```"M\`$`%0```+7P`0`M````R_`!
M`#L```#Y\`$`%P```#7Q`0`@````3?$!`!4```!N\0$`/@```(3Q`0`<````
MP_$!`!@```#@\0$`'0```/GQ`0`E````%_(!`%@````]\@$`(````);R`0`%
M````M_(!``H```"]\@$`!P```,CR`0`)````T/(!`!(```#:\@$`%0```.WR
M`0`X`````_,!`",````\\P$`'P```&#S`0`U````@/,!`#H```"V\P$`"@``
M`/'S`0`:````_/,!``P````7]`$`"@```"3T`0`A````+_0!`!,```!1]`$`
M$@```&7T`0`.````>/0!``<```"']`$`#P```(_T`0`)````G_0!`!````"I
M]`$`#@```+KT`0`:````R?0!`!<```#D]`$`,````/ST`0`+````+?4!`!\`
M```Y]0$`!0```%GU`0`&````7_4!``<```!F]0$`'@```&[U`0`$````C?4!
M``P```"2]0$`!````)_U`0`0````I/4!``\```"U]0$`"0```,7U`0`,````
MS_4!``X```#<]0$`%@```.OU`0`%`````O8!``0````(]@$`$@````WV`0`Q
M````(/8!`$0```!2]@$`#0```)?V`0`;````I?8!`!<```#!]@$`!P```-GV
M`0`C````X?8!`!@````%]P$`%````![W`0`4````,_<!`!H```!(]P$`#@``
M`&/W`0`/````<O<!``T```""]P$`#0```)#W`0`O````GO<!``8```#.]P$`
M"P```-7W`0`-````X?<!``\```#O]P$`"P```/_W`0`\````"_@!``8```!(
M^`$`'@```$_X`0`/````;O@!`!,```!^^`$`)P```)+X`0`?````NO@!`#L`
M``#:^`$`/````!;Y`0`X````4_D!`!$```",^0$`'0```)[Y`0`>````O/D!
M``@```#;^0$`$0```.3Y`0`3````]OD!`!@````*^@$`"````"/Z`0`5````
M+/H!`!````!"^@$`%@```%/Z`0`6````:OH!``<```"!^@$`$0```(GZ`0`<
M````F_H!``L```"X^@$`!0```,3Z`0`,````ROH!``L```#7^@$`$````./Z
M`0`%````]/H!``<```#Z^@$`"@````+[`0`3````#?L!`!,````A^P$`#```
M`#7[`0`,````0OL!``8```!/^P$`!@```%;[`0`1````7?L!`!(```!O^P$`
M%````(+[`0`/````E_L!``P```"G^P$`!P```+3[`0`)````O/L!`#8```#&
M^P$`*````/W[`0`C````)OP!``<```!*_`$`(````%+\`0`&````<_P!`"0`
M``!Z_`$`%0```)_\`0`H````M?P!`!$```#>_`$`$0```/#\`0`<`````OT!
M``,````?_0$`'0```"/]`0`(````0?T!`!(```!*_0$``@```%W]`0`,````
M8/T!`!0```!M_0$`"P```(+]`0`8````COT!`!P```"G_0$`&````,3]`0`%
M````W?T!``H```#C_0$`%````.[]`0`<`````_X!``T````@_@$`!P```"[^
M`0`,````-OX!``H```!#_@$`$0```$[^`0`1````8/X!`$H```!R_@$`'```
M`+W^`0`W````VOX!`!@````2_P$`!0```"O_`0`'````,?\!`!$````Y_P$`
M%P```$O_`0`=````8_\!`!T```"!_P$`!````)__`0`*````I/\!``4```"O
M_P$`$0```+7_`0`2````Q_\!``X```#:_P$`%P```.G_`0`5`````0`"`!``
M```7``(`&@```"@``@`.````0P`"`"0```!2``(`#P```'<``@`0````AP`"
M`!,```"8``(`:P```*P``@`@````&`$"`!X````Y`0(`'````%@!`@`@````
M=0$"`!@```"6`0(`)````*\!`@`2````U`$"`!D```#G`0(`%0````$"`@`4
M````%P("``H````L`@(`"0```#<"`@`'````00("``L```!)`@(`!P```%4"
M`@`4````70("``L```!R`@(`.@```'X"`@`3````N0("`!H```#-`@(`"```
M`.@"`@`%````\0("`$H```#W`@(`3P```$(#`@!-````D@,"`&0```#@`P(`
M'````$4$`@`'````8@0"`"@```!J!`(`+````),$`@`*````P`0"``@```#+
M!`(`#0```-0$`@`R````X@0"``4````5!0(`&````!L%`@`6````-`4"`%(`
M``!+!0(`+````)X%`@`D````RP4"``X```#P!0(`(````/\%`@`<````(`8"
M`",````]!@(`'0```&$&`@`C````?P8"`!H```"C!@(`#````+X&`@`'````
MRP8"`!````#3!@(`$0```.0&`@`4````]@8"``@````+!P(`0````!0'`@`,
M````50<"``@```!B!P(`#0```&L'`@`:````>0<"``D```"4!P(`!````)X'
M`@`6````HP<"``@```"Z!P(`"````,,'`@`$````S`<"``L```#1!P(`"P``
M`-T'`@`4````Z0<"`!,```#^!P(`#@```!((`@`4````(0@"``X````V"`(`
M!P```$4(`@`0````30@"`!P```!>"`(`"P```'L(`@`-````AP@"`!L```"5
M"`(`*@```+$(`@`8````W`@"`!X```#U"`(`*@```!0)`@`$````/PD"``0`
M``!$"0(`#0```$D)`@`'````5PD"``H```!?"0(`%@```&H)`@`(````@0D"
M``H```"*"0(`"````)4)`@`'````G@D"``D```"F"0(`"0```+`)`@`)````
MN@D"``P```#$"0(`#@```-$)`@`$````X`D"`"<```#E"0(`#@````T*`@`*
M````'`H"``H````G"@(`#P```#(*`@`<````0@H"``L```!?"@(``@```&L*
M`@`?````;@H"`!H```"."@(`!P```*D*`@`(````L0H"``8```"Z"@(`:```
M`,$*`@`,````*@L"``@````W"P(`*````$`+`@!$````:0L"`!\```"N"P(`
M+0```,X+`@!8````_`L"`"8```!5#`(`*0```'P,`@`8````I@P"`!T```"_
M#`(`!0```-T,`@`*````XPP"``T```#N#`(`#0```/P,`@`+````"@T"``T`
M```6#0(`%0```"0-`@`/````.@T"``T```!*#0(`#P```%@-`@`/````:`T"
M``0```!X#0(`!P```'T-`@`(````A0T"`!D```".#0(`"````*@-`@`&````
ML0T"``<```"X#0(`$P```,`-`@`&````U`T"`!L```#;#0(`%@```/<-`@`+
M````#@X"`!D````:#@(`#````#0.`@`6````00X"``P```!8#@(`"````&4.
M`@`/````;@X"`!(```!^#@(`#P```)$.`@`&````H0X"`!<```"H#@(`"P``
M`,`.`@`>````S`X"``8```#K#@(`"````/(.`@`-````^PX"`"`````)#P(`
M"0```"H/`@`+````-`\"`"8```!`#P(`&````&</`@`0````@`\"``8```"1
M#P(`"P```)@/`@`.````I`\"``D```"S#P(``@```+T/`@`.````P`\"``<`
M``#/#P(`)@```-</`@`I````_@\"`"L````H$`(`'````%00`@`L````<1`"
M`"D```">$`(`*P```,@0`@`N````]!`"`%H````C$0(`#0```'X1`@!-````
MC!$"`#0```#:$0(`4P````\2`@!,````8Q("`"$```"P$@(`&@```-(2`@`S
M````[1("`"8````A$P(`,@```$@3`@`K````>Q,"`!,```"G$P(`/0```+L3
M`@"8`@``^1,"`!H```"2%@(`$````*T6`@`_````OA8"`(4```#^%@(`+@``
M`(07`@`E````LQ<"`$0```#9%P(`3P```!X8`@!*````;A@"`"P```"Y&`(`
M&0```.88`@`0`````!D"`"4````1&0(`&P```#<9`@`<````4QD"`"@```!P
M&0(`)P```)D9`@`J````P1D"`#````#L&0(`&0```!T:`@`-````-QH"`"L`
M``!%&@(`)````'$:`@`H````EAH"`"$```"_&@(`'````.$:`@`Z````_AH"
M`&4````Y&P(`-0```)\;`@!+````U1L"`#4````A'`(`*````%<<`@`V````
M@!P"`%P```"W'`(`.@```!0=`@`F````3QT"`"D```!V'0(`+P```*`=`@`H
M````T!T"`"P```#Y'0(`5P```"8>`@!6````?AX"`$<```#5'@(`10```!T?
M`@`O````8Q\"`"D```"3'P(`*0```+T?`@`I````YQ\"`&@````1(`(`8@``
M`'H@`@!K````W2`"`+L```!)(0(`&@````4B`@`N````("("`#<```!/(@(`
M*````(<B`@!D````L"("`!@````5(P(`6````"XC`@`<````AR,"``L```"D
M(P(`S````+`C`@!/````?20"`"(```#-)`(`/````/`D`@`@````+24"`!@`
M``!.)0(`,P```&<E`@`&````FR4"``<```"B)0(`!````*HE`@`,````KR4"
M`!````"\)0(`#````,TE`@`+````VB4"``<```#F)0(`$@```.XE`@`-````
M`28"`((````/)@(`#@```)(F`@`&````H28"`!4```"H)@(`!````+XF`@`'
M````PR8"``@```#+)@(`!0```-0F`@!2````VB8"``0````M)P(`&0```#(G
M`@`*````3"<"`!(```!7)P(`$````&HG`@`"````>R<"``<```!^)P(`!@``
M`(8G`@`3````C2<"``P```"A)P(`%@```*XG`@`&````Q2<"`!0```#,)P(`
M#P```.$G`@`#````\2<"`"X```#U)P(`!````"0H`@`&````*2@"``<````P
M*`(`'@```#@H`@`\````5R@"`"X```"4*`(`+P```,,H`@`6````\R@"`"@`
M```**0(`,````#,I`@`B````9"D"`"H```"'*0(`(````+(I`@`C````TRD"
M`!X```#W*0(`'````!8J`@`L````,RH"`"0```!@*@(`&@```(4J`@`N````
MH"H"`!H```#/*@(`+````.HJ`@`P````%RL"`"````!(*P(`)````&DK`@`D
M````CBL"`!\```"S*P(`(P```-,K`@`L````]RL"`"<````D+`(`)P```$PL
M`@`E````="P"`!\```":+`(`)````+HL`@`P````WRP"`!T````0+0(`*@``
M`"XM`@`V````62T"`#D```"0+0(`&@```,HM`@`G````Y2T"`$T````-+@(`
M*0```%LN`@`M````A2X"`"T```"S+@(`+@```.$N`@`H````$"\"`"8````Y
M+P(`(0```&`O`@`G````@B\"`#@```"J+P(`*@```.,O`@`U````#C`"``P`
M``!$,`(`#@```%$P`@`@````8#`"`"H```"!,`(`(0```*PP`@`/````SC`"
M``\```#>,`(`&@```.XP`@`:````"3$"``L````D,0(`)P```#`Q`@`,````
M6#$"``H```!E,0(`)0```'`Q`@`H````EC$"`"(```"_,0(`)P```.(Q`@`B
M````"C("``<````M,@(`W````#4R`@`+````$C,"`!,````>,P(`!P```#(S
M`@`*````.C,"`!````!%,P(`$@```%8S`@`<````:3,"``,```"&,P(`,P``
M`(HS`@`;````OC,"`!@```#:,P(`!P```/,S`@`2````^S,"`!(````.-`(`
M,P```"$T`@`(````530"`"D```!>-`(`$P```(@T`@`3````G#0"`!D```"P
M-`(`,P```,HT`@`=````_C0"``X````<-0(`(P```"LU`@`/````3S4"`!``
M``!?-0(`%P```'`U`@`*````B#4"`!\```"3-0(`#P```+,U`@`9````PS4"
M`#8```#=-0(`'0```!0V`@`/````,C8"`!X```!"-@(`)@```&$V`@`%````
MB#8"`!````".-@(`!P```)\V`@`+````IS8"``D```"S-@(`.````+TV`@`&
M````]C8"``\```#]-@(`$0````TW`@`0````'S<"``L````P-P(`#P```#PW
M`@`'````3#<"`!````!4-P(`"````&4W`@`;````;C<"``@```"*-P(`&P``
M`),W`@`;````KS<"``L```#+-P(`#0```-<W`@`<````Y3<"``@````".`(`
M,0````LX`@`1````/3@"`!````!/.`(`"````&`X`@`"````:3@"``H```!L
M.`(`&````'<X`@`+````D#@"``,```"<.`(`"P```*`X`@`+````K#@"``H`
M``"X.`(`%P```,,X`@`.````VS@"`!@```#J.`(`'@````,Y`@`,````(CD"
M`!P````O.0(`.0```$PY`@`B````ACD"`",```"I.0(`&0```,TY`@`-````
MYSD"`$4```#U.0(`#P```#LZ`@`9````2SH"`"T```!E.@(`)@```),Z`@`&
M````NCH"`!H```#!.@(`5@```-PZ`@`/````,SL"`!````!#.P(`!P```%0[
M`@`$````7#L"``4```!A.P(`$0```&<[`@`6````>3L"``8```"0.P(`!P``
M`)<[`@`'````GSL"``L```"G.P(``P```+,[`@`,````MSL"``T```#$.P(`
M.0```-([`@`N````##P"`"P````[/`(`"@```&@\`@`%````<SP"``P```!Y
M/`(`#````(8\`@`-````DSP"`!8```"A/`(`)0```+@\`@`B````WCP"`!\`
M```!/0(`$P```"$]`@`"````-3T"``0````X/0(`#0```#T]`@`*````2ST"
M``4```!6/0(`!0```%P]`@`/````8CT"`$T```!R/0(`)````,`]`@`E````
MY3T"`"P````+/@(`%P```#@^`@`B````4#X"`#````!S/@(`3@```*0^`@`6
M````\SX"`!X````*/P(`?@```"D_`@`>````J#\"`%D```#'/P(`*@```"%`
M`@!/````3$`"`#````"<0`(`*````,U``@`M````]D`"`"T````D00(`60``
M`%)!`@`K````K$$"`"X```#800(`*0````="`@`H````,4("`"P```!:0@(`
M-P```(="`@`4````OT("`!H```#40@(`#````.]"`@"H````_$("``8```"E
M0P(`N0```*Q#`@"%````9D0"`*````#L1`(`(````(U%`@!7````KD4"`!``
M```&1@(`'0```!=&`@`1````-48"``<```!'1@(`&0```$]&`@`>````:48"
M`$$```"(1@(`&0```,I&`@`6````Y$8"`%<```#[1@(`&@```%-'`@`/````
M;D<"``H```!^1P(`!0```(E'`@`&````CT<"``@```"61P(`!0```)]'`@`9
M````I4<"``T```"_1P(`"0```,U'`@`8````UT<"`"(```#P1P(`#P```!-(
M`@`=````(T@"`"@```!!2`(`"0```&I(`@`,````=$@"``X```"!2`(`"0``
M`)!(`@`,````FD@"`!<```"G2`(`*````+](`@`/````Z$@"``<```#X2`(`
M!0````!)`@`0````!DD"`"D````720(`$````$%)`@`.````4DD"`!````!A
M20(`&````'))`@`:````BTD"``H```"F20(`"0```+%)`@`0````NTD"``@`
M``#,20(`"````-5)`@`3````WDD"``H```#R20(`$````/U)`@`0````#DH"
M``H````?2@(`"P```"I*`@`8````-DH"``(```!/2@(`"0```%)*`@`&````
M7$H"`!L```!C2@(`&````']*`@`.````F$H"`!0```"G2@(`"P```+Q*`@`F
M````R$H"`!0```#O2@(`*@````1+`@`'````+TL"`!4````W2P(`!P```$U+
M`@`&````54L"``@```!<2P(`(@```&5+`@`+````B$L"``(```"42P(``@``
M`)=+`@`:````FDL"``P```"U2P(`#0```,)+`@`&````T$L"``@```#72P(`
M&@```.!+`@`&````^TL"`!X````"3`(`!@```"%,`@`E````*$P"``(```!.
M3`(`!````%%,`@`1````5DP"`!<```!H3`(`"P```(!,`@`#````C$P"``D`
M``"03`(`$````)I,`@`*````JTP"`"<```"V3`(`%@```-Y,`@`'````]4P"
M`!P```#]3`(`"@```!I-`@`7````)4T"``(````]30(`!0```$!-`@`0````
M1DT"``P```!730(`$@```&1-`@`I````=TT"``<```"A30(`!P```*E-`@`1
M````L4T"``4```##30(``@```,E-`@`+````S$T"``$`````````,0(``(('
M``"Z`@```````$@```#,`0``T0(``"8!``!;`P``V04``'X`````````+`@`
M`,4&``""`0``*@(``,<%``")`P``C`<``&0#``#R!0``Z0,``)`'``#3````
M`````+T!```O!P```````,<!``";!P````````````#?`0``00@``"T%``#Z
M````]`8``$(&``#5`0``/04``&D&```"!0``7@0``*T"``"^``````````P#
M`````````````%$$``!."```A0$``#8&``"N!P``F0(`````````````:`,`
M`.,"``#Q`P```````)$!``!!!```_@,``,0#``#4!@``6`4``%<$``#9`0``
M\P,``%`#``#G!P``<@<``.H&``!-!@``(P<``/L"``"L`P``;`(```````"P
M!0```````,T!``"=!```1`(```````"\`````````/L!``"Y`@``&@,`````
M```7!@``>`0``$T%````````U`$``"`!``!;`0``,@4``-8`````````8`4`
M``````"*!```A0(`````````````\P8`````````````A`<``-T&``!8`0``
M5@```#L#``"'`@``10```$@%``!X!@``>`<``$,#````````JP,``"(!``#;
M`P```````-P$``".`P``[P(``"\(``!R!0```````$$'````````-@0``'\#
M``"M`0``!@@``'H"```O`0``R@0``(,%``"9!P``2@<```````!?`P``I@4`
M```(``!Z`P``W`4``$L%``#P````H`4```````#J`P``$P`````````\"```
M+````"H&````````B0<``%(`````````-`@`````````````@`8``*8```"R
M!P``FP(``&$'``#9````T`(````````&`0``FP8``$,%````````6`,`````
M```O!@``V@(``,T"``"O`0``(P@``#`&``"W!P``M`,```,"``!%"```?0``
M``H$``!B`0``%`<```````#7`@``4P<``&8'``"A!````````,$```#>````
M5`(``"L&``"1!P```````",%````````@P<``.,$``#-`P```````,X!````
M`````````-,"`````````````$@$````````?`<``&\"``!'!@``Q0$``!P(
M````````+`4``%X`````````;@<``#@(``!W!P``\P4`````````````)P<`
M`.L%````````&````&$$``"5!```3@(```````"N`P``"P```%<&``#"````
MX@$``)8'``#^!0``Q`(``'`#``!&````W@4```````#<`P``^`4``&X$```,
M"```&P$```````!J!0``DP$````````'!@``J@(``%<%````````B@8``+X'
M```M!P``?@<```````#Q!@``30,`````````````Q`<```X"``##`@``XP4`
M``````!P`@``3`0``$`&````````QP(``!D$``";````[P$``*\'```;!P``
M"@(``&X"```0!0```````$,(``#T!P````````````#!!0``[P0``+,%````
M````I0<``'0&``"#`@```````.H!``#Y`@``9@,```4(``#W`@``/@,``,L"
M```4"```=@```!0#``#G!0``NP,```````#N!```"@<``)P%````````200`
M``P```#-!```#`0``%8$````````F`````````!$!@``C00``(@%``#_`P``
M!P4```````#H!@``.P8```\&````````AP$``*,'```U``````````````!3
M!```/`,``)0'``#`````L`0``-0#``"W`0``[`4``,X'```5!P``30(``'$!
M````````DP0```````#)!```SP```,8%``"G!@``608``#$(````````!@8`
M`.$%``!Y!0``_@$``#$%``#X``````````````"4`@``/@<``'\"````````
MF@```-4&```*!@``C`,``(,!``"R!```-`,`````````````8`<``.T```"!
M!@``.04``+T'```V`P``^`$``$4#``![`````````"D%``#$!```1@(``#H$
M``!K!P````````````!V`@````````0'``!R`0``B@<``/L````<`0``>P8`
M`"P!``"2!`````````````!T!P``"@$``)$````7!P``3@`````````4!0``
MYP8``)H%````````N@```)D%``"L!```.0@``.P````U!0``\0<```````!\
M!0``+@`````````S!0``B0```.,'````````_`$``'@%``"$!@``1@0`````
M``!Z!0```````"T!```A!0``5@(``&$`````````X@,``)D&``!.!P``004`
M`%0#````````-0$``&0%````````(@<``$X!``#!!```$@8`````````````
M``````P!```G`P``VP8``+0&``#M`@``J0<``,D%``##`0``%@<``"H!``"V
M`P``5`8``%<!``!U`P```````'@!``#F!```<P(``$L```"<!```?`$``+$$
M``!?!@```````,\!``"*`P``P@<``$P&```-````E@0``(\%```,!@``````
M`!4"``!.!@``[`(```````#U!P``>0,``#P"``!)!0``GP<`````````````
MF`(``+`!``#]````V@4```````"V!````````(X!```E````$0```+`#``!8
M`@```````-X!```=!P``'`4``%`"```2`P``+@0``#L$``"J!@``300``-@"
M```1!P``L@```$$#``#H````Y0,``'0!``#D!```Q04```````!A`0``=P$`
M``````!1`0``9P4```````"X````JP4```````!N!@``7P0``$<'````````
M>`(```($```B````Z00``#D$``#O!@``70$``)8%````````T00``,`%``#W
M````7`,``'("``"``0``"0,``!P&``"S`0``<````,@&``#)`P``GP(``*@!
M```X`P``%0,``,P`````````Y@```+$`````````````````````````R0<`
M`(T'```A`0``4P4```````!\!````0,``',!``">!```504```8```"6`0``
MVP4``$8!```B`@``NP````````!9!P``?`8```````"X!P``4@4``(L"``!+
M`P``L@4``*H%``"'!P``,@8```````",`@``ZP````````!W````O@$``)$&
M```\!`````````````!&!P``SP8``````````````````#X%````````````
M`(X%``#:`0``````````````````!P<```````!E!0``V@0```````"_!@``
M)P$``*,&```A`@``00```"P"``#P`0``,@@``)P"``````````````D'````
M````OP,````````C`P``&`0```````"0`@``;0```'P````9!0```````*0#
M``#`!P``JP$`````````````@04``.\'``"7!@``IP$```````";`0``4@$`
M`$`$```L!P``#`<``!X%```2!P``>P<``$("``#P!P````````,#```K"```
M`````#8%```#``````````4!``"T`0``(````!\&``#E````N@0``'L!````
M````*P$````````Q````6P(`````````````.@4```````"'!@``F0```-4"
M`````````````%P!``!K`@``F`,``'D!```?``````````0(``"D````````
M`)@'``!:!````````+L&``#8````NP4``,D&````````A`(```P%``!Y`@``
M````````````````2`<``(`"``".!P``G````*L```"#````U@8``,X%``#K
M!````````/4&``"I`@``F@$```````"U`@``#P(``&D#``#"!@``=00``"0%
M``"H!0```````'T%`````````````#0'```/````2`$``$((``!E````/P(`
M`!\"``"/````0P(``"X&``!W`@`````````````6`@````````````";`P``
MJ`<``-L```!)"```J`(``'P"``"*````;````+4&``!J`@``E@8```8"````
M`````````*$`````````U`<```````"N`0``6P<```````#'````]`,``(8$
M``#T`@```````/4`````````5````"(#```;"```0`,``"X(````````@00`
M```````>!```'`0``$L(``#3!0``[0$````````U`@``A@$```````"L`0``
MW````,@$```X`0``@@(``&L%``"2!@``]@,``#P%``#T````?00````````N
M`P``K0```"0(``#E!P``:`0```X%``"R`0``B`<``.$#``"O!```M`0``*D#
M``!+!```%P0```````#I`@``;`0``"<"``!V!@``=````*<'``#1!0``S`<`
M`(T&``"P`@``]0$```````#V!````````%('``!K!@``*@,`````````````
MH`$```\%``#B!@``L`8``#,!``!"!P``40<``*T#``""!@```````$H(``!1
M`P``R0(``!@(``"5!@``GP,```````!)`@``3`,```````"7!```N0```&0"
M`````````````!L&``"\`P```````(D%`````````````'H$``!("```40``
M`/\```"P!P``K`(```````"(!```6`8``/<&``":!@``S@,```````!/`0``
MF`4``.T$``!0`0```````````````````````"X"``#S!P````````````#Z
M!0``C@```%4$``"J!P``LP0``,4$``#3!```.P@``$$"````````````````
M```:"```>`,``%D$``#]!`````````X&```%````+P(``(L$``!$!0``[0<`
M`,\%``#=`@``A@4``%L%```H`P``C````$8(``!P!0``IP```#$$``!J`0``
M8@````````#B!P``M04``.L"```Y`@``````````````````00$````````0
M`@``3@0```````!9`@``H@0```````!R!@```````%0$``#B`````````!L#
M``#V!@````````````"O`@``2@4``*@```!Z````[P,``+<$``#K`0``$0,`
M`'0$````````P`$``,$'``"W`@``5P,``/<%``#2````1P```"8(``"K!P``
M_P0```````#;`@```````*4#```Q`0``:0<``+X%``#6!P``^P,````````"
M!P``-P```(L#``#\`P```````+D$``"(!@``````````````````"0(``)8`
M````````U@,````````!`@``-00``"0$``"0!@``:@```'X#``!G`P``Q`8`
M`(,#`````````````"D'```C!```EP<```$$``"Y!P``;@$```````#-!@``
M&08``'`'````````2@,```````"+````V@,``(L%``!O!0``0@,`````````
M````(P8``%@$``#V`@```````+P&``"S!@``^`0```L"``!'!0``'0,`````
M```0`````````",!````!@``3P@```````"2`0``90$``"<(````````M0``
M`"<````````````````````3!P````````````!V!P```````%D````M````
MZ@0```````````````````````#<`0```````(8```#G`@``V`8```````!O
M!````````$0!``#[!````````)4!``##!P```````)`%````````K00`````
M```A!````````#`"``!H````?0(``,`#```5!@``PP,``#H```!)!P``R@<`
M`$(!````````-0,``-(!````````OP$``!X(```)!@``10$``-<!``!#!P``
M`````#4(```\!P``8P,```````"[`0``H@$``*T&```[!P``,P,``)P&``#F
M!P`````````#``!0````P0,``!T```#$````IP0``%H'```0`0``+@4``#T'
M````````?`,``(T```#7!````````&T&``"%!@``\0```+T$``#R!```@@4`
M`"L$``"/!P``.P```.`%``#R!P````````````!`````&@<``-,'``#]`@``
MS@8``$\#```*!0```````,,&```W`P``9@$``-$'``"O!0```````"(&````
M````V00``-T```!_!@``)0@```8%```D`@``'P4```````#A`@``A`,``%X#
M``!,`@``,`<``/\'```="```E0(``*P'``#Q!0``,@````````#Q`@``H@(`
M```````#!0``I0(``/T&``"F`@``+08``/@#``#*`P``````````````````
MS`0``-0$``"-`@``Y`(```````!.!0``P`(```````!K!````````-4%``"_
M````D0(``&,"``!,!0``F@,``%L`````````@`4``'X"``#7`P``)@<``%\`
M``#?`@``_@8``&T$``!T`@``G@,``*D$```]````!`$``)$$``"W````<P8`
M`/`$``#-````````````````````F00``/T#``!C!```:P,``#4&``"1!0``
M``````````!J!````````(4'```0!P```````'L%``!A`P``-P8```````"B
M`P```````*<"``#D`0``X08``.,```#0!```CP(``.4$```7`@``10<``"H'
M``#=`P``\0$``'<$``#(`@```````"L'``"_`@```````.H%``!/````D`$`
M``````````````````@%``!X`````````)L$``"A`@``?0$``$,!``"I`0``
M'P@```````!G````<P<```L$``!"`````````#,```#^```````````````(
M!@``*P(```4%``!<!0```````#\%``!=!@``.P(``#X(``#F`P``/08``"`(
M``#M!@```````#@'``!?!0``@`0``'8$````````@0(``,<$``"F!@``Y04`
M`'`!```1"```$@`````````I````CP8``.@!``!F!````````!P```#(!P``
MP@$``/<'```T!0````````````!)`````P8````````_`0````````````#4
M`@``908``&8"``````````````````#0!0``$@$```````##!```````````
M``"2!0``^0<``!@'```(!P`````````````4`````````.X%```R!```Z08`
M````````````$P$```````"L````50(``)`#```0!@``G0````L%`````@``
M`````(X&``#2!P``T08``*,%````````^00``````````````````,H&```Z
M!@``&0@`````````````;`8``/4"``#5````V0(``$4$``#P`P``)@,``.0%
M``"<`0``\@``````````````+P4``$L"````````````````````````;@``
M`-\&``"B!@```````!\#````````ZP<``.X&``"&`P```````#0"````````
M1````!X"````````EP,``!D#``"R`@````````````#O!0``2@(``&L````.
M"```KP8``#@$````````A`4``!X&``!%!@``)@0`````````````.0<``-T$
M``!N!0````````X!``#8`P``@0<``*``````````X0<``%\!```Y`0``````
M````````````T0```$L!````````#P@``!(%```Z`0``O`4``/,```!3`0``
MR0````<```">!@```````*@&````````)@4``%P```!=````SP,``%8!````
M````)08``+8!``#5`P``!@0``'X$``#@`@``M0$````````P````O`0``#8"
M````````^@8``"`#``#\!@``E04`````````````8P$``,T%````````2P8`
M`&,%````````E`$``,<#````````X0```"<%``"``P``^@<``!@%```3"```
M\P(``,X````;````I`$```````!'`P``\@$```````#:````LP<````````X
M````"`$``)T!``"Q!0``"@```.("``"&`@``;0,``(\$``#!!@``G@(``'0%
M``#6`@``8`8```````"\`0```````$\&`````````````&@%````````#P0`
M`*<#``!-````_@(``````````````````+D%``!<!P```````'\!````````
MD@(```````!F!0``\P$``),&````````[@,``%@`````````4@8``'<%``#8
M`0``O@8``$$&```4!@``+00``.L#````````'`<`````````````,P0`````
M``#0!P```````%H#``!U`0``2@8``&\```#J`@``[`$``(T!````````_@<`
M`#P&``!L`P``0P8``/X$``"^!```;04```````#T!0``NP(``&`#``#R`@``
M@0$```0$``"_!P``R`4``,L%``"/`0```````#<(``!3!@``T`8``.`!``!:
M````(@0```````"Y!@``EP(``-L!``#9`P``&P4``&<"````````:`(`````
M``#,!@``!P0``!4```#"`P``C04``(@"``">!P``8`(``$T'```!!P``?@$`
M`"H```#*`@```````"@!``#@!@``U@0``-@%```3`P```````"D!``#.!```
M`````"\````8!@``M`<```````!:!0```P<``!T$``#V!P``]`$``(@```"T
M!0```````&0&```1`@``,0,``'`&``!3`P````$```````"J`P```````#,'
M````````60$``'$&``"E````)@8``-$!``#_`@```````(,$```0`P``!`,`
M`+8'``"(`P``&`,``*X````(````/P0````````L!@```````*,$``"E!@``
M808``$T!````````;P8``"@"````````Q@(``($#```)!0``)0(````````%
M!P````````````"W`P``'04``%T'``"(`0``5`<``/`"````````"0```,$!
M``#J````/P````````"_!0``3P0``"T"``"K`@````````````"D!0``"0@`
M`$L'````````N0$``/8!```?!```#0<``-($``#D````A`0````````.!P``
M\`8``&<$``!G`0``C0,``(D!``!3`@``>P0````'`````````````+8&````
M````F0$``.@%````````$08````````W!P``804```@#````````````````
M``#0`````````)T"```]"`````````L'````````N@,`````````````````
M``````!*`0``70(```````"\!P``C`$```````"D!P``S@(```````"Q!P``
MW`(```````"O`P````````,!``"V!0``/`$``"$&``#N!P``H@````T$``"Y
M`P``S`4```$%```````````````````P!`````````````"N!@```````-("
M``#3!@``(0<``)\!``"N!```-@@```````!0"```G0,```4&``#<!P``7`8`
M`/D!``"B!P``/@```(D"``"A!P``5@,``!\'``!7`@``_04``"\$``#]!P``
M`````-(%``"T````G@4``*8$````````J04``*0&```J!0``BP$``"T(````
M````\@,```````"7````&@```````````````````.H'``"Q`P``````````
M``#I`0``#0@``#X!````````=P,``"P$``#=!P``70,``%4'```N!P``H@4`
M`$T(```7!0``G@````````#\!0``TP$``'T&`````````````!<!```H!P``
MRP0```````#7!P``V0<``)H'``"`!P``W@(``!4(```6`0```````"(%``!Q
M`@``8@<``#T"```X`@``:@,``&<&``#?!P``(`<`````````````J@``````
M````````<04```L#``!9!0``G04```````!7````W0$````````:`0``LP(`
M````````````<P,``!X```"E!0``I0$``#@&``!,"```M`(```````"#!@``
MD````,@!``!5!@``%`$``,H%``"\`@``3@,``"L#```Y`P``>@$```````#I
M!0``)00````````8`0``@````*D```#Z`P```````)@!`````````````'$'
M``#&`0``)`,``!X!``"6`P```````'$```#L!P``"@,``%$&````````````
M`,@#`````````````.$!````````)`$``-T%``!P!```Q@```+8"````````
M=@4``/D#```6````BP8``+H%``"W!0```````&\#````````LP,````%``#L
M!```HP(``!X'``"H`P```````&T!````````7`(``)`$``#C`0``Z`(``*4$
M```V````=0(``(<#``!$"```.@<``"$#``"C`0``%`(``)@$``"4!0``%`0`
M`%L$``"F`P`````````````^`@``!P(``-D&``!>`0````````````"4`P``
M`````%4#``"C````F`8``!H"``#H!````````%0%``#$`0``.@@`````````
M`````````)0&```?`0``(`4``-P&```9````0`@``!4!``!0!0``:0```%T%
M``#W`P``!`````````#N`@``DP<```````#*`0``S0<``+T%``!/`@``````
M`#0`````````8@8``,4`````````=@$``(8&```I`P```````/,$````````
M)`8``*`'``#'!P````````````!E`P```````%X&``!1!0``E@(``(4#```.
M!```60,```0%``"D`@```````!8(```=`0``&0<``,@`````````D@```&`!
M````````<@,``.`'````````<P4```````#5!P`````````````(!```````
M`"D(````````3P4``%`$``"&!P``````````````````&0(```L(``"4````
MD0,``/$$````````#@,``'\%``!D````-`8```@"``"U!P``Q@,````````!
M!@````````\!``#]`0``)P0``/(&``"3````Y`<`````````````2@```!((
M``!$`P``V@8```````!"!0``]`0``%,```")!@``(P(``%4!``"I!@``/@0`
M`(H"````````N@$``%($```1`0``NP0```````!6!P``%@0```````#K!@``
M`@$``#,&```=!@`````````````F```````````````V`0``1@4``%L&``!Z
M!@```````/P"``#6!0``!0,``&D$``#F!@``7P<``#<%``#4````2@0``-L$
M`````````````*8'``!R!```6`<``'4%``"5````L08``-`!``#>!P``)```
M``0"```_"```!P$``*T'``#M`P```````#('```@!```,P(```````!'`@``
MD@,``/\&```I`@```````#<"````````>@<```(#````````>0`````````P
M`0```````'4&```````````````````!`0``T0,``"4'````````$@0``*H$
M````````&`(```````#N````0`(``#(!````````?P0``-X#````````````
M`%\"````````+0,```T"````````W@0``/4$````````C`8``+@#````````
M3`<``&D%``"]!@``Q`4``#<!``!B`@``-@<``#`#````````P@(```````#7
M!0```````"4%```P!0``H`,``/4#``#,`P```````!,$````````1`0``#`(
M````````AP```!8&````````9`<``(\#``!L`0``Y0$`````````````C`0`
M`+@"````````<P0``&<'``"!````#@```%("``!1`@``'@,``.X!````````
MG`,```````!B`P```````-(#```5!```+`,````````"!@``]@4``"H(```'
M"```#0,``#D```"?````8P<``*X"```0"```L0$```````!_!P``]@```-@$
M````````3````(H!``#&!```SP<``!8%````````Y@(``/<$````````DP4`
M`$P!````````/P<```````#D`P```````!<````]`P``20$``-@'````````
M;`<``+<&````````;P<``+X#``#+`P``5`$``#D&````````[`8``#P```#M
M!0``U00``&(%``";!0``!0(``$($````````'`(``+\$`````````````$8&
M`````````````&D!```<`P``X@0``#0$````````X@4``.D`````````````
M`'$#````!````````'L"```H!0``W@8``#4'````````JP8``+````![`P``
M``````````!H`0``K`4``.`$``!U````0`$`````````````2`,``*X%``#[
M!0```````!H%``#_!0```````+@%```;`@``/P,``+@!````````RP8``+$"
M`````````````,($``!W!@````````$(``"U`P```````"((``">`0``Q@8`
M`!$%``#O````-P0``,L'``!$!P```````"D&```C`````````&P%````````
M!P,``!<#````````4`8``-\%```5!0``^`(``-\#``````````````````!(
M!@``6@8``,`&``#G`P``#04``!H$``"]`P``10(`````````````.P4`````
M``````````````````"A`0``E0<``+T```"+!P``L@,```````#\!```!@,`
M`*H!````````*00``"@&``!J!P``_P$``(0`````````P0(```D$``!F````
MF@0````````R`@``]P$``,H`````````"@@``&@&``!Y!```6@(``&8&````
M`````````/`%``!E!P``^P<``+(&```S"```X`,``#T$``"?!```*`@``!,"
M``#Z`@``4@,``'4'````````]04``$,$```"`@```````(4$``#Y!@``RP$`
M``D!``!T`P``UP8``````````````````((```#Z!```O0(``"$(```#!```
M:P$``!T"``#H`P```````(<%```3!0``N@<``"@``````````````.8!``#E
M`@``7@4```````#6`0``HP,``$`%``!M!P```````(H%``````````````0&
M```/`P``:0(``"8"````````=@,``$,`````````(`(``%8&````````1P0`
M`(4````+`0``SP(``)4#``!6!0```````)<!````````WP```&,```#%!P``
M``````P"``!^!@```````$D#``!@!```G08``.4&``!J!@```````.,&```1
M!```:`<`````````````-`$``(X$``"Z!@``&@8````````^!@``Y`8``*`"
M```N`0````````````"H!```P`0``&4$````````9`$``!<(````````````
M`*$#````````^`8``````````````````*8!``!>!P``6@$```````"S````
M`````)P'``""!````````"4!``!Q!```.`4`````````````<@```,8'````
M````8@0``$@"``!Y!P``C@(``,D!````````XP,````````R`P```````-L'
M``!5`````````&X#```&!P``M00```````"'!```U`4``*T%```3!@``RP``
M``L&```#"```Q0,`````````````T@8```````"4!````````"@$````````
M`````*L$``#L`P``.@(``/@'````````*@0``$`'``!0!P``P@4``'\```#'
M!@````````````#@````N`0``"L%````````C`4`````````````````````
M``#A!```1P@```````"^`@``SP0``"4#````````UP```)D#````````````
M````````````/P8`````````````&P0``&0$``#F!0```````#$'``"7!0``
MH`8``(4%````````A`$``#L!````````8```````````````K`8``#T!````
M````;P$``$8#```D!P``(`8``'T'``!^!0``H08```````#Y!0```````',`
M```""```;0(```4$````````700``)T'``"@!```GP4``/H!``!'`0``````
M`&,&```0!```NP<``%<'````````,08```````#3`P``*P```!D!````````
M+P,```````!E`@`````````````Z`P``DP(```````#?!```?0,````````2
M`@``^0```*<%``"V````7@(```````"3`P``7`0```````#,`@``_````*0$
M``!Y!@```@````````":`@``#08```````!)!@``YP0`````````````````
M```````A`````````*\````6`P``GP8``*$%``"X!@``Z`<``)('``##````
M#P<``,4"``#0`P``YP$``(D$``!%!0``)P8``&$"```-`0``Z0<``$\'``#G
M````^P8```````#\!P``PP4```````""`P```````-H'```("````"`H)7,@
M9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D
M87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@86YD`"!A="``(&]R`"(E
M<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H
M;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G
M:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E
M9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I
M`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP
M:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R
M:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE
M;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y
M('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME
M9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y
M;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER
M960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S
M)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S
M)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B
M92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W
M:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E
M<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L
M(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E
M;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R
M<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`
M02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H
M;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES
M(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT
M(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%C=&EO;B!F
M;W(@8FQA8VML:7-T960@861D<F5S<V5S.@!!8W1I=F%T92!38W)I<'0`06-T
M:79A=&EN9R!T:&4@<V-R:7!T(&9O<B`B)7,B(&9A:6QE9#H@*"5D*2`E<P!!
M9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(
M97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C
M:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@
M(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E
M<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O
M;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N
M`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W
M+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@4V5T=&EN
M9W,`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F
M9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE
M;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L
M;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&P@;V8@=&AE(&9O;&QO
M=VEN9P!!;&QO=R!2=6QE<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES
M=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O
M<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D
M9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE
M<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!
M;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N<W=E<F5D`$%N=&%R
M8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!;GD@;V8@=&AE(&9O;&QO=VEN
M9P!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES
M(')E861Y+@!!<'!L>2!&:6QT97)S`$%P<&QY('1O($-H:6QD(%-H87)E<P!!
M<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S
M+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<G5L93\`07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N
M9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@
M*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@
M07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE
M;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T
M<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N
M9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`
M075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E
M<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H
M7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!
M4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I
M;&5D+@!!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&5A
M8V@@8VAA;F=E/P!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@
M17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`
M0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A
M9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"
M87-E;&EN90!"8V,`0F5G:6YS('=I=&@`0F5L87)U<P!"96QG:75M`$)E;&EZ
M90!"96YI;@!"97)M=61A`$)H=71A;@!":6YD(&9A:6QE9#H@*"5S*2`E<P!"
M:7)T:&1A>0!";&%C:VQI<W0`0FQA8VML:7-T($5D:70`0FQA8VML:7-T(&ES
M(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E
M<BX`0FQA8VML:7-T960@061D<F5S<V5S`$)L;V-K("(E<R(@;V8@87!P;&EC
M871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y
M<&4`0F]D>0!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@
M=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T
M:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U
M;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3
M`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S
M+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A
M;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A
M=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N
M(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E
M<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@
M<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E
M;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E
M<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A<V4@4V5N<VET
M:79E`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#8P!#
M96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@
M<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E3
M3RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I
M;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA
M9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG97,@<V%V960N`$-H86YG
M:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C
M=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R
M871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E
M(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG
M-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O
M<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I
M<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R
M(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A
M<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A4
M5%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P
M<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U
M<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N
M9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#
M;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@
M=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A
M=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S
M<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F
M('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#
M;VYN96-T:6]N(&9A:6QU<F4`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&%I
M;G,`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S
M(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O
M<'D@)7,`0V]P>2!F86EL960Z("5S`$-O<'D@;V8@)7,`0V]P>2!S96QE8W1I
M;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S
M<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U
M<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T
M(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#
M;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T
M:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L
M9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y
M(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@
M=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R
M9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@
M9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D
M9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET
M:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T
M(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T
M('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD
M;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S
M:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F
M;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT
M960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`
M0W)E871E(&$@;F5W(&]N90!#<F5A=&4@;F5W(&9O;&1E<@!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S
M:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R
M<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT
M('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I
M`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$25-!0DQ%1#H@`$133B`H<V5E
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O=W-E<@!$
M871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T
M:6]N`$1A>0!$95]L971E($-O;'5M;@!$96%C=&EV871E(%-C<FEP=`!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`
M1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`
M1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92`E<P!$96QE=&4@0V5L;`!$96QE
M=&4@0V]N9&ET:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!0
M97)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E
M;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E
M;7!L871E`$1E;&5T92!M97-S86=E(&-O;7!L971E;'D`1&5L971E(&UE<W-A
M9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T
M92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L
M9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R
M<F5N="!R;W<`1&5L971E9`!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T
M("(E<R(N`$1E;&EV97(@:6YT;R!M>2!);F)O>`!$96QI=F5R(&EN=&\@;7D@
M26YB;W@@86YD(&-O<'D@=&\`1&5L:79E<B!I;G1O(&UY($EN8F]X(&%N9"!R
M961I<F5C="!T;P!$96QI=F5R('1O(&9O;&1E<@!$96QI=F5R>2!T:6UE`$1E
M;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$
M97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z
M(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F=`!$:7)E8W1O<GD`1&ES86)L92`E<P!$:7-A8FQE9`!$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D
M(&9O<F5C87-T`$1I<W!L87D@9&5T86EL960@;F]T:69I8V%T:6]N('=H96X@
M96%C:"!F:6QT97(@:7,@87!P;&EE9#\`1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II
M8F]U=&D`1&\@7VYO="!S96YD(')E<W!O;G-E<R!T;R!B=6QK(&]R(&QI<W0@
M;65S<V%G97,`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;R!T:&ES.@!$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z`$1O97-N)W0@8F5G:6X@=VET:`!$;V5S;B=T(&-O;G1A:6X`1&]E<VXG
M="!E;F0@=VET:`!$;V5S;B=T(&5X:7-T`$1O97-N)W0@;6%T8V@@*'=I=&@@
M<&QA8V5H;VQD97)S*0!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N
M)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A
M9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@
M<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M
M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED
M92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="`E<P!%9&ET
M($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES
M<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O
M<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS
M(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN
M+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T
M(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@
M1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT
M+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE("5S`$5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N86)L960`16YD('EE
M87(`16YD<R!W:71H`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT
M97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%L('1O`$5Q=6%T;W)I86P@1W5I
M;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R
M<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!R
M971R:65V:6YG(&-U<G)E;G0@<V-R:7!T.B`H)60I("5S`$5R<F]R('-A=FEN
M9R!C:&%N9V5S+@!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X:7-T:6YG(%)U;&5S`$5X:7-T<P!%
M>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(#$@
M;V)J96-T+"!G;W0@)60N`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F
M<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@
M(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&
M87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W
M(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T
M($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@
M3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@
M;F]T('-U<'!O<G1E9"X`1FEL=&5R($%L;"!-97-S86=E<P!&:6QT97(@3VYL
M>2!3965N($UE<W-A9V5S`$9I;'1E<B!/;FQY(%5N<V5E;B!-97-S86=E<P!&
M:6QT97(@3W!T:6]N<P!&:6QT97(@4G5L90!&:6QT97(@4G5L97,`1FEL=&5R
M(%-C<FEP="!$:7-P;&%Y`$9I;'1E<B!?4G5L97,`1FEL=&5R(&%C=&EV:71Y
M.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E
M<B`B)7,B+@!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B
M965N(&1E;&5T960N`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H
M879E(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI
M<W0@=V5R92!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E
M("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R
M("(E<R(N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`1FEL=&5R(&%C=&EV:71Y.B!4:&4@
M;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@
M9F]L9&5R("(E<R(N`$9I;'1E<B!N;W0@9F]U;F0N`$9I;'1E<G,`1FEN;&%N
M9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO
M870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O
M;V0`1F]R(&%N(&EN8V]M:6YG(&UE<W-A9V4@=&AA="!M871C:&5S.@!&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H
M5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O
M<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O
M="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&
M;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D`$9O<G=A<F0@:7,@
M;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R
M+@!&;W)W87)D<P!&;W)W87)D<R!%9&ET`$9R`$9R86UE<P!&<F%N8V4`1G)A
M;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE
M<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE
M(`!&<F]M.@!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`
M1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M
M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`
M1V5N97)A=&5D(&)Y($EN9V\@*&AT='`Z+R]W=W<N:&]R9&4N;W)G+VEN9V\O
M*0!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`
M1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!3
M96%R8V@`1W)A>7-C86QE`$=R96%T97(@=&AA;@!'<F5A=&5R('1H86X@;W(@
M97%U86P@=&\`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`
M1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`
M1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O
M:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N
M=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE
M`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG
M:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`
M2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E
M<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO
M;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC
M;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G
M92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B
M:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@
M;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S
M`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2
M=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N
M9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T
M(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"
M969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W
M:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R
M979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R
M>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP
M;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S
M<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA
M`$EN9&EV:61U86P@57-E<G,`26YD:79I9'5A;"!R=6QE<R!A<F4@;F]T('-U
M<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!);F1O
M;F5S:6$`26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G
M92!D96QI=F5R>2X`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L
M;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A
M=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV
M86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN
M`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N
M`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A
M;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED
M('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H
M87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N
M:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27,`27-L92!O9B!-
M86X`27-N)W0`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L
M:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M
M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T
M:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@
M4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B
M:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+
M97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A
M=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+
M;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3$1!4"!S=7!P;W)T
M(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL
M86)L92!O<B!N;W0@;&]A9&5D+@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P
M;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W
M;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO
M9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE
M=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T
M:&\`3&5S<R!T:&%N`$QE<W,@=&AA;B!O<B!E<75A;"!T;P!,979E;`!,:6)E
M<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H
M="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!2
M86EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,
M:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X
M($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$
M871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R
M8VAI=F4`3&ES="U(96QP`$QI<W0M240`3&ES="U)9`!,:7-T+4]W;F5R`$QI
M<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H
M=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE
M`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N
M`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W
M97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O
M;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA
M9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA
M>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T
M(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)?:R!M97-S
M86=E(&%S(&1E;&5T960`36%R8V@`36%R9VEN`$UA<FL@;65S<V%G92!A<SH`
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N
M9',`36%R=&EN:7%U90!-871C:&5S("AW:71H('!L86-E:&]L9&5R<RD`36%T
M8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D
M(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@3G5M8F5R(&]F
M(%)U;&5S`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&)L86-K
M;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E
M<RP@36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W
M(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N`$UA>&EM=6T@;G5M8F5R(&]F('=H
M:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S
M.B`E<RP@36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@
M;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N`$UA>0!-87EO='1E`$UE9&EC
M:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X
M<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B
M(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE
M=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O
M<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O
M=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG
M(&%D9')E<W,@=&\@;F]T:69Y`$UI<W-I;F<@861D<F5S<R!T;R!R961I<F5C
M="!M97-S86=E('1O`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@
M=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P
M<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5A<V]N
M(&9O<B!R96IE8W0`36ES<VEN9R!R96%S;VX@:6X@=F%C871I;VXN`$UI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-
M;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-
M;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%)U;&4@
M1&]W;@!-;W9E(%)U;&4@57``36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-
M;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA
M<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C
M;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!-
M>6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.7W5M8F5R(&]F(&1A>7,@8F5T
M=V5E;B!V86-A=&EO;B!R97!L:65S.@!.86UE`$YA;6EB:6$`3F%U<G4`3F5P
M86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@
M0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2
M979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T
M>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`
M3F5W($UO;VX`3F5W(%)U;&4`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W
M(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER
M92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O
M=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S
M`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.
M:6=H=`!.:75E`$YO`$YO("(E<R(@96QE;65N="!F;W5N9"!I;B!B86-K96YD
M(&-O;F9I9W5R871I;VXN`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A8VME;F0@8V]N9FEG
M=7)E9"!F;W(@=&AI<R!H;W-T`$YO(&)A8VME;F1S(&-O;F9I9W5R960@:6X@
M8F%C:V5N9',N<&AP`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES
M=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N
M`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@
M9FEL=&5R<RX@0VQI8VL@(B5S(B!T;R!C<F5A=&4@82!N97<@9FEL=&5R+@!.
M;R!H96%D97)S('-P96-I9FEE9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I
M;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S
M=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I
M960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H
M('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@
M8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A
M+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`
M3F\@<V-R:7!T(&=E;F5R871E9"X`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`
M3F\@<VED97,`3F\@<W1R:6YG<R!S<&5C:69I960`3F\@<W5C:"!F:6QE`$YO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC
M:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H
M97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A
M>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&5Q
M=6%L('1O`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D
M+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:69Y(&5M
M86EL(&%D9')E<W,`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T
M97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@
M;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI
M<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F
M9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S
M="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@
M;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S
M:&%R960@9F]L9&5R<RX`3VYL>2!F;&%G('1H92!M97-S86=E`$]N;'D@;V9F
M96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U
M;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES
M=&5M`$]P=&EO;G,`3W!T:6]N<R!A8F]U="!S8W)I<'0@=7!D871I;F<N`$]P
M=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI
M<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N
M('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H
M97(@26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!/=F5R=FEE=P!/=VYE<B!0
M97)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!0
M1U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I
M;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`
M4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG
M`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA
M;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A
M`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA
M;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R
M9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R
M9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S
M=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`
M4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B
M(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!0
M97)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO
M;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N
M`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@
M>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R
M>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N
M=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN
M('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E
M(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L
M90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E
M<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@
M870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT
M(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP
M=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+
M97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC
M;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC
M($ME>2`H)60@8FET*0!27V5A<V]N`%)A9&EO('-E;&5C=&EO;@!286EN`%)A
M:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`
M4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M
M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C96EV
M960`4F5D:7)E8W0@=&\`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S
M:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5G97@`4F5G=6QA<B!E>'!R97-S:6]N`%)E:F5C="!W:71H
M(')E87-O;@!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!2
M96UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN
M`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO
M=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M
M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I
M96QD`%)E<V5N="!4;P!297-E;G0M9G)O;0!297-E=`!297-E="!087-S=V]R
M9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U
M;'1S`%)E='5R;B!T;R!&:6QT97)S($QI<W0`4F5T=7)N('1O($]P=&EO;G,`
M4F5T=7)N('1O(%)U;&5S($QI<W0`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N
M:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`
M4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE`%)U;&4@0V]P:65D`%)U;&4@1&5L971E9`!2
M=6QE($1I<V%B;&5D`%)U;&4@16YA8FQE9`!2=6QE($YA;64`4G5L93H`4G5L
M97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA
M;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE
M;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U1!4E14
M3%,@9F%I;&5D.B`H)7,I("5S`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN
M="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I
M;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3
M875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO
M;G,`4V%V92!3971T:6YG<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`
M4V-I96YC90!38W)I<'0`4V-R:7!T(%5P9&%T:6YG`%-C<FEP="!N;W0@=7!D
M871E9"X`4V-R:7!T('-U8V-E<W-F=6QL>2!A8W1I=F%T960N`%-C<FEP="!S
M=6-C97-S9G5L;'D@9&5A8W1I=F%T960N`%-E87)C:`!396%R8V@@16YG:6YE
M<P!3965N`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I
M96QD`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`
M4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A
M;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE
M8W0`4V5L96-T(&YO;F4`4V5L96-T('1A<F=E="!F;VQD97(`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;&8M1&5F:6YE9"!(96%D97(`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YD97(`4V5N96=A;`!396YS;W(Z(`!397!T96UB
M97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!3
M97-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W
M86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E
M="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971T
M:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4V5T=7``4V5T=7`@=7!G<F%D
M92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L
M92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H
M;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!!8W1I=F4@4V-R:7!T`%-H;W<@0W5R
M<F5N="!38W)I<'0`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L
M92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H
M92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R
M;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN
M:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E
M`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN
M=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N
M;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA
M=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O
M;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E
M<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P
M86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG
M(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP
M=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3
M<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@
M;W(@4')O=FEN8V4`4W1A='5S`%-T;W`@8VAE8VMI;F<@:68@=&AI<R!R=6QE
M(&UA=&-H97,_`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK
M971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D
M9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!3=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E.@!3=6)J96-T`%-U
M8FIE8W0Z`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U
M8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R
M96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O
M=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U
M;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z
M(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A
M<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD
M`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M
M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!4
M86)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T
M:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T
M86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS
M`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R
M871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O
M)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP
M;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M
M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861D<F5S<R`B)7,B(&AA<R!B965N
M(&%D9&5D('1O('EO=7(@8FQA8VML:7-T+@!4:&4@861D<F5S<R`B)7,B(&AA
M<R!B965N(&%D9&5D('1O('EO=7(@=VAI=&5L:7-T+@!4:&4@861M:6YI<W1R
M871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO
M;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H
M92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN
M('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S
M:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N
M960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H
M97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@
M=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S
M<&5C:69I960N`%1H92!D<FEV97(@<V%I9#H@`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@
M8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E
M;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N
M970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E
M;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E
M(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N
M9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@
M:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E
M="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@
M3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E
M9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU
M4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L
M87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT
M964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O
M;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O
M<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N
M`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E
M7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V
M:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@
M<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H
M92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE
M('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O
M<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E
M;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`
M5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N
M;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I
M;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E
M9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H
M96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N
M(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R
M86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA
M<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H
M97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B
M(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M
M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S
M*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE('-C<FEP="X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S
M(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O
M;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI
M9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K
M871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6
M;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E
M<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R
M871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T
M868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H
M:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4
M;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI
M96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M
M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V
M:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T
M97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R
M96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E
M<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS
M('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I
M;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I
M=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2!W:&EL92!C;&EC:VEN9RX`5&\Z`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C
M90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O(&UA;GD@:6YV86QI
M9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N`%1O<`!4;W`@9G)A
M;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R
M=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X
M-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4
M=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),
M(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`
M56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E
M("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@
M9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@
M=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T
M;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N
M(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL
M960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E
M<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D
M`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@
M2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E
M<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`
M56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E
M('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5
M<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@
M;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA
M;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``
M57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y
M(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686-A=&EO;B!%9&ET`%9A8V%T
M:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG
M(&1R:79E<BX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S
M96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@
M86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I
M970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X
M=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R
M:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL
M:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10
M`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S
M=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E
M8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I
M`%=E<W1E<FX@4V%H87)A`%=H7VET96QI<W0@861D<F5S<V5S.@!7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S
M97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+@!7:&ET96QI<W0`5VAI=&5L:7-T($5D:70`5VAI=&5L:7-T(&ES
M(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E
M<BX`5VAI=&5L:7-T960@061D<F5S<V5S`%=I9'1H`%=I9'1H(&EN($-34R!U
M;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@
M969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I
M9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E
M960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K
M`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L
M9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG
M(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4')I;W)I
M='D`6"U2968`6"U3<&%M+4QE=F5L`%@M4W!A;2U38V]R90!8+5-P86TM4W1A
M='5S`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@
M2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P
M.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`
M65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G
M<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@<G5L97,N`%EO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&]R(&5D:70@8W5S=&]M(')U;&5S
M+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@
M=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+@!9;W4@:&%V92!R96-E:79E9"!A(&YE=R!M97-S86=E`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R
M('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@870@;&5A
M<W0@;VYE(&5M86EL(&%D9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M
M97-S86=E<R!S:&]U;&0@8F4@86-T:79A=&5D+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB
M97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@
M86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z
M`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@
M<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I
M9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@
M;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R
M(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB
M86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6TYO(%-U8FIE8W1=`%M0
M<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T
M960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D9')E<W,H
M97,I('1O(&9O<G=A<F0@=&\Z`%]!9&1R97-S97,@=&\@;F]T('-E;F0@<F5S
M<&]N<V5S('1O.@!?061M:6YI<W1R871I;VX`7T)L86-K;&ES=`!?0TQ)`%]$
M871A5')E90!?1&5L971E(%)O=P!?1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L
M>0!?16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z`%]&;W)W87)D
M`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TME97`@82!C
M;W!Y(&]F(&UE<W-A9V5S(&EN('1H:7,@86-C;W5N=#\`7TQO9R!I;@!?3&]G
M(&]U=`!?36]D:69Y($QI;FLN+BX`7TUO=F4@;65S<V%G92!T;R!F;VQD97(Z
M`%]->2!E;6%I;"!A9&1R97-S97,Z`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?
M4F5M;W9E($QI;FLN+BX`7U-C<FEP=`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I
M97,N+BX`7U5S97)S`%]686-A=&EO;@!?5VAI=&5L:7-T`&%C=&EV90!A9&1R
M97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`86YD`&-A;&5N9&%R`&-A;&T`
M8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C
M;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T
M:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F
M;W)M870@97)R;W(`9&ES86)L960@+2!C;&EC:R!T;R!E;F%B;&4`961I=`!E
M;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:65L9`!F:6QE`&9R;VT@=&AE("5S
M("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W
M;@!I;6UE9&EA=&4`:6YA8W1I=F4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O
M<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6%I;&1R;W`@<V-R
M:7!T(&=E;F5R871E9"!B>2!);F=O`&UA=&-H`&UK:7-O9G,@97)R;W(@8V]D
M92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;W(`<&5R8V5N=`!P97)M
M:7-S:6]N(&1E;FEE9`!P:7AE;',`<')O8VUA:6P@<V-R:7!T(&=E;F5R871E
M9"!B>2!);F=O`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R
M=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V
M:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP
M;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T
M:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($EN9V\@,2XQ+6-V<PI297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E
M871I;VXM1&%T93H@,C`P-BTP,BTR-B`Q,CHR,2LP,C`P"E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#8M,#(M,C8@,3(Z-3DK,#(P,`I,87-T+51R86YS;&%T;W(Z
M($QE96YA($AE:6YO(#QL:6EN=4!U=&$N9FD^"DQA;F=U86=E+51E86TZ($9I
M;FYI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM
M,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`("@E<R!PY&EV
MY.0@<VET=&5N*0`@*%!I:V%NY'!PY&EN("5S*0`@*"5S('#D:7;D<W/D*0`@
M*'3D;N3D;BD`("AH=6]M96YN82D`("AE:6QE;BD`(&IA`"``('1A:0`B)7,B
M(&5I(&]L92!H86ME;6ES=&\`(B5S(B!E:2!K96QP86$@=F%L:6YN86MS:2X`
M(B5S(B!E:2!O;&4@87-E;FYE='1U($AO<F1E;B!R96MI<W1E<FES<^0N`"(E
M<R(@<'5I9&5N(&MU=F%A:F%A(&5I(&SV>71Y;GET+@`B)7,B(&QI<^1T=&EI
M;B!R>6AMY&KD<FIE<W1E;&WDY&XN`"(E<R(@;&ESY'1T:6EN(&]I:V5U:W-I
M:6XN`"(E<R(@96D@;'5O='4Z("5S+@`E+C)F34(@:^1Y=&5T='D@)2XR9DU"
M('-A;&QI='5S=&$@*"4N,F8E)2D`)60@)7,@:F$@)7,`4V%L87-A;F%S:2!V
M86YH96YT=74@)60@<.1I=N1N('#DY'-TY"X`)60@<.1I=N1N(&5N;G5S='5S
M`"5S("T@26QM;VET=7,`)7,@4V]R;65N:N1L:VD`)7,@2T(`)7,@66QLY'!I
M=&]T;VEM96YP:71E970@+2!687)M:7-T=7,`)7,@87-E;FYU<P`E<R!K:7)J
M875T=6UI;F5N`"5S(&OD>71T]F5H9&]T`"5S(&]N(&IO(&]L96UA<W-A+@`E
M<R!S=75N=&$@)7,@)7,`)7,@;VX@=F%L;6ES('-U;W)I='1A;6%A;B!Y;&SD
M<&ET;W1O:6UE;G!I=&5I=.0N(%9A;&ET<V4@=F%L:6YT87)U=61U:7-T82!S
M=6]R:71E='1A=F%T('1O:6UE;G!I=&5E="X`)7,@;VX@<&%K;VQL:6YE;@`E
M<R!M:6YU=71T:6$`)7,@96D@;/9Y='EN>70N`"5S("T@)7,@+R`E<P`E<SIN
M(&]S;VET96MI<FIA`"5S.FX@:V%L96YT97)I`"5S.FX@;75I<W1I;&ES=&$`
M)7,Z;B!T96ATY';D;&ES=&$`)7,Z("5S`"5S(#H@5.1MY"!V:65S=&D@96D@
M;VQE(';D;'1TY&WD='3D('-I;'3D(&SD:&5T=.1JY&QTY"P@:F]K82!O;B!M
M97)K:71T>2!LY&AE='3D:N1K<VDN(%-U:'1A=61U('9A<F%U:W-E;&QA('9I
M97-T:7-SY"!O;&5V:6EN(&QI;FMK96EH:6X@:F$@=F%R;R!A;G1A;6%S=&$@
M;.1H971TY&KD;&QE(&UI=.3D;B!Y:W-I;/9I=FGD('1I971O:F$N`"P@<'5U
M<VMI='1A:7-T80`L('!U=7-K:71T86ES=&$@)7,@)7,`+"!V86EH=&5L979A
M82`E<R`M("5S`"TM('9A;&ET<V4@+2T`,3(M='5N;FEN(&KD<FIE<W1E;&WD
M`#(T+71U;FYI;B!JY')J97-T96QMY``R-"!T=6YT:6$`/$5D96QL:6YE;@!4
M:65T;VMA;G1A=&%U<W1A:N1R:F5S=&5L;>3D(&5I(&]L92!MY.1R:71E;'1Y
M('3D;&QE(&]S:6]L;&4`5&%P86AT=6D@=F%K879A('9I<FAE`%9I97-T:6X@
M<V%L875K<V5E;B!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+@!!;&QE
M:VER:F]I=&5T=6X@=FEE<W1I;B!T87)K:7-T=6MS965N('1A<G9I=&%A;B!J
M=6QK:6YE;B!01U`M879A:6XN`%-A;&%T=6X@=FEE<W1I;B!A=F%A;6ES965N
M('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'4"UA
M=F%I;B!J82!S86QA<V%N871E:W-T:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A
M;6ES96MS:2!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+"!S86QA:6YE
M;B!01U`M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@879A86UI
M<V5E;B!T87)V:71A86X@:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA:6YE
M;B!3+TU)344M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@86QL
M96MI<FIO:71T86UI<V5K<VD@=&%R=FET86%N(&IU;&MI;F5N(%,O34E-12UA
M=F%I;BP@<V%L86EN96X@4R]-24U%+6%V86EN(&IA('-A;&%S86YA=&5K<W1I
M+@!6:65S=&EN('-A;&%U:W-E96X@=&%R=FET86%N(&IU;&MI;F5N(%--24U%
M+6%V86EN+@!!32!0:6QV:>0`04T@:V5V>71TY"!S861E='1A`$%-('-A9&4`
M04T@<V%T96ET80!!32!L=6UI<V%T96ET80!!32]030!!4$D@240`5&EE=&]J
M82!E9&ET;W)I<W1A`%1I971O:F$N+BX`06)S+B!A;&EN`$%B<RX@:V5S:V5L
M;.0`4VEN=6QL82!E:2!O;&4@;VEK975K<VEA(&QU;V1A(%9&4RUH86ME;6ES
M=&]A+@!3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@;'5O9&$@5D93+71I961O
M<W1O82X`2^1Y='3D:N1T=6YN=6MS96X@=&EE9&]T`$OD>71TY&KD='5N;G5K
M<V5N('-A;&%S86YA`$OD>71TY&KD=&EL:2!S=6QJ971T=2X`2VER:F%N<&ET
M;P!4;VEM:6YT;R!M=7-T86QI<W1A='5I;&QE(&]S;VET=&5I;&QE.@!!:W1I
M=F]I('-K<FEP=&D`4VMR:7!T:6X@86MT:79O:6YT:2`B)7,B.FQL92!E<.1O
M;FYI<W1U:3H@*"5D*2`E<P!,:7/DY`!,:7/DY"!A;&ER>6AMY`!,:7/DY"!A
M;&EO:6ME=7,`3&ESY.0@=.1HY&XZ`$QI<^3D('5U<VD@<GEH;>0`3&ESY.0@
M=75S:2!O:6ME=7,`3&ESY.0@86QI<GEH;>0@<GEH;>3D;B`B)7,B`$QI<^3D
M(&%L:6]I:V5U9&5T("(E<R(`3&ESY.0@=75S:2!KY'ET=.1JY#H`3&ESY.0@
M<V%R86ME`$QI<^3D('5U<VEA(&KD<V5N:>0`3&ESY.0@<&%R:0!,:7/DY"`E
M<R!V86QI:VMO($UO>FEL;&%N(%-I9&5B87(@;W-I;V]N`$QI<^3D(&]S;VET
M96MI<FIA86XZ`$QI<^3D(&]S;VET96MI<FIA86YI.@!,:7/DY"!KY'ET=.1J
MY`!,:7/D='1I:6X@(B5S(B!JY')J97-T96QMY.1N+"!M=71T82!E:2!V;VD@
M;&ESY'3D('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V;B!L:7/D=&EE=&]J83H@
M)7,N`$QI<^1T=&EI;B`B)7,B(&KD<FIE<W1E;&WDY&XN(%9O:70@;GET(&MI
M<FIA=71U82!S:7/DY&XN`$OD>71TY&II96X@;&ESY.1M:6YE;B!O;B!E<W1E
M='1Y+@!,:7/D87-E='5K<V5T`$]S;VET90!/<V]I=&5K:7)J80!6;VD@87-E
M='1A82!T86D@;>3D<FET96QLY"!O:6ME=6MS:6$@=&]I<VEL;&4@:^1Y='3D
M:FEL;&4`66QLY'!I=&\`36%I;F]K<V5T`$%F9V%N:7-T86X`06QB86YI80!!
M;&=E<FEA`$%L:6%S`%1A<V%A`%1A<V%U<SH`2V%I:VMI`$MA:6MK:2!A=71E
M;G1I:V]I9'5T(&OD>71TY&KD=`!+86EK:VD@<GEH;>1T`$MA:6MK:2!O:6ME
M=61E=`!+86EK:6QT82!N96QJY&QTY"!S:79U;'1A`$MA:6MK:2!S975R86%V
M870`4V%L;&D@<^3D;F[V=`!386QL:2!M;VYE="!O<V]I='1E970`4V%L;&D@
M:N1R:F5S=&5T>6X@;&ES=&%N('1Y>7!I;B!A<V5T=7,N`$]N(&IO(&]L96UA
M<W-A`%9A:6AT;V5H=&]I;F5N($E-4U`M<VESY.1N:VER:F%U='5M:6YE;@!6
M86EH=&]E:'1O:6YE;B!)35-0+7-A;&%S86YA`%9A:6AT;V5H=&]I;F5N($E-
M4U`M:^1Y='3D:N1T=6YN=7,`5F%I:'1O96AT;VES970@<^1H:_9P;W-T:6]S
M;VET=&5E=`!686EH=&]E:'1O:7-E="!M86QL:70`5F%I:'1O96AT;VEN96X@
M=&5K<W1I.@!9:&1Y<W9A;'1A:6X@4V%M;V$`06YN971T=2!A<G9O(&5I(&ME
M;'!A82X`=&%P86AT=6D@='5N=&5M871O;B!V:7)H92X`06YD;W)R80!!;F=O
M;&$`06YG=6EL;&$`06YO;GEY;6D@<')O>'D`5F%S=&%U<P!687-T871T=0!!
M;G1A<FMT:7,`06YT:6=U82!J82!"87)B=61A`$IO:VEN('-E=7)A879I<W1A
M`$]H:F5L;6$`3VAJ96QM86QI<W1A`$]H:F5L;6$@;VX@=F%L;6ES+@!3=6]D
M871A('9I97-T:70`3&%I=&$@:^1Y='3V]FX@:V%I:VMI(&%L:6IA:V]I:&EN
M`$AY=N1K<WD`07)V:6]I='4@:V]K;P!H=6AT:6MU=0!!<F%B:6$@*%=I;F1O
M=W,M,3(U-BD`4&%K971I;B!K;VMO`%!A:V5T:6X@;FEM:0!/;&5T:V\@=F%R
M;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@=.1MY&X@<^3D;F[V;C\`3VQE=&MO
M('9A<FUA+"!E='3D(&AA;'5A="!P;VES=&%A('-I<^3D;FMI<FIA=71U;6ES
M<'EY;F[V;B`E<R`_`$]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A
M82`B)7,B(&IA(&MA:6MK:2!S96X@86QI<GEH;>1T/P!!9V5N=&EI;F$`07)M
M96YI80!!<FUE;FEA("A!4DU30TE)+3@I`%1A:61E`$%R=6)A`$%S8V5N<VEO
M;B!S86%R970`07-C:6DM=&%I9&4`07-I86XO5'EY;F5N;65R96X@86QU90!+
M>7-Y('9A<FUI<W1U<R!E;FYE;B!K=6EN('1E:&3DY&X@>6QLY'!I=&]T;VEM
M96YP:71E970N`%1E:'3D=N1S87)A:VME970`67)I=&5T=&EI;B!P;VES=&%A
M(&]L96UA=&]N=&$@<GEH;>3D+@!9<FET971T:6EN('!O:7-T86$@;VQE;6%T
M;VYT82!O:6ME=71T82X`67)I=&5T=&EI;B!M=6]K871A(&]L96UA=&]N=&$@
M;VEK975T=&$N`%ER:71E='1I:6X@;75O:V%T82!O;&5M871O;G1A(&IA:V]A
M+@!,:7/D;>3D<FET>6MS970`96QO:W5U`$%U<W1R86QI80!)=.1V86QT80!!
M=71H7V-Y<G-Q;#H@5&%R=FET=&%V86$@24U!4"UL86%J96YN=7-T82!E:2!L
M]GET>6YY="X`075T:%]C>7)U<SH@5&%U<W1A:N1R:F5S=&5L;>0@96D@='5E
M('1A<G9I='1A=FEA(&]M:6YA:7-U=6MS:6$N`$%U=&A?8WER=7,Z(%1A<G9I
M='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?9G1P
M.B!T87)V:71T879A82!&5%`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N($OD
MY&YNY"!02%`@:^1Y='3D96X@+2UE;F%B;&4M9G1P(&%S971U<W1A+@!!=71H
M7VEM87`Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN
M>70N`$%U=&A?:W)B-3H@5&%R=FET=&%V86$@:W)B-2UL86%J96YN=7-T82!E
M:2!L]GET>6YY="X`075T:%]L9&%P.B!KY'ET=.1J:65N(&QI<^3D;6EN96X@
M06-T:79E($1I<F5C=&]R>7EN(&5I(&]L92!T=65T='4`075T:%]L9&%P.B!+
MY'ET=.1J:65N('!O:7-T86UI96YN($%C=&EV92!$:7)E8W1O<GES=.0@96D@
M;VQE('1U971T=0!!=71H7VQD87`Z(%1A<G9I='1A=F%A($Q$05`M;&%A:F5N
M;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?;&1A<#H@16D@=F]I9&$@;&ESY'3D
M(&OD>71TY&KDY"`E<RX@4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L:3H@
M`$%U=&A?;&1A<#H@16D@=F]I9&$@<&]I<W1A82!KY'ET=.1JY.0@)7,`075T
M:%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D("5S`$%U=&A?
M;&1A<#H@2^1Y='3D:FEE;B!PY&EV:71TY&UI;F5N($%C=&EV92!$:7)E8W1O
M<GEY;B!E:2!O;&4@='5E='1U+@!!=71H7VUC86PZ(%1A<G9I='1A=F%A($U#
M04PM;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?<VUB875T:#H@5&%R
M=FET=&%V86$@<VUB875T:"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T
M96YT:6MO:6YT:2!)34%0+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`075T
M96YT:6MO:6YT:2!E<.1O;FYI<W1U:0!!=71E;G1I:V]I;G1I(&5PY&]N;FES
M='5I+B`E<P!!=71E;G1I:V]I;G1I(%)!1$E54RUP86QV96QI;65L=&$@97#D
M;VYN:7-T=6DN`$%U=&5N=&EK;VEN=&D@1E10+7!A;'9E;&EM96QL92!E<.1O
M;FYI<W1U:2X`075T96YT:6MO:6YT:2!334(M<&%L=F5L:6UE;&QE(&5PY&]N
M;FES='5I+@!0Y&EV:73D('-K<FEP=&D@:F]K86ES96X@;75U=&]K<V5N(&KD
M;&ME96XN`$OD>71E='3D=FES<^1O;&5V870@:V5N=.1T.@!!>F5R8F%I>F1A
M;@!"3T9(('-E;&ET>6MS970`5&%U<W1A`%1A=7-T87;D<FD`5N3D<N0@:V5R
M8F5R;W,@<V%L87-A;F$N`%;DY'+D(&ME<F)E<F]S(&OD>71TY&KD='5N;G5S
M+@!"86AA;6$`0F%H<F%I;@!"86QT:6$@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&]S`$=R869I:6MO:61E;B!P97)U<VAA:V5M:7-T;V$@(B5S
M(B!E:2!L]GET>6YY="X`4&5R=7-V:6EV80!0:6EL;VMO<&EO`$%L:V%A`%9A
M;&MO+59E;N1JY`!"96QG:6$`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N
M`%EH9&ES=.1M:6YE;B!E<.1O;FYI<W1U:3H@*"5S*2`E<P!3>6YT>6WD<.1I
M=N0`375S=&$@;&ES=&$`375S=&%N(&QI<W1A;B!M=6]K:V%U<P!+Y'ET]G-S
MY"!O;&5V82!S=6]D871I;F%J=7)I(&5I('1U92!M=7-T:6$@;&ES=&]J82X`
M375S=&%L;&4@;&ES=&%L;&4@;&ESY'1Y="!O<V]I='1E970`3W-I;W1A("(E
M<R(@;VAJ96QM86QL92`B)7,B(&5I(&SV>71Y;GET+@!/<VEO;B!A<V5T=6MS
M970`3W-I;VX@='EY<'!I`%-I<^1L=/8`3&EH879O:71U`$)O;&EV:6$`2VER
M:F%N;65R:VET`%)E=6YA`%)E=6YA;B!V86AV=75S.@!2975N870`0F]S;FEA
M($AE<GIE9V]V:6YA`$UO;&5M;6%T`$)O='-W86YA`$%L:6X`0F]U=F5T('-A
M87)E=`!"<F%S:6QI80!"<FET86YN:6%N($EN=&EA;B!V86QT86UE<F5N('1E
M<G)I=&]R:6\`0G)U;F5I($1A<G5S86QA;0!"=6QG87)I80!086QL=6MK86QI
M<W1A`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),+6IA:V5L=6]S
M;VET=&5E=`!37V]L=6X@=&EE9&]T+BXN`%;D;&EM=6ES=&EN(&%L=7-T=7,@
M96D@=F%L;6ES='5N=70N`$MA;&5N=&5R:0!4>7EN:0!+86UP=71S96$`2V%M
M97)U;@!386QA<V%N86$@96D@=F]I('1Y:&IE;G3DY"!A=71O;6%A='1I<V5S
M=&DL(&]T82!Y:'1E>71TY"!Y;&SD<&ETY&KDY&XN`$5I('9O:2!K:7)J;VET
M=&%A('1I961O<W1O;VX@(B5S(@!5;&MO:7-I82!I<W1U;G1O:^1S:71T96QI
M:O9I=.0@96D@;VQE(&UA:&1O;&QI<W1A(&AA;&QI=&$N`$E-05`M<&%L=F5L
M:6UE96X@96D@<V%A='4@>6AT97ET=.0Z("5S`$5I('9O:2!A=F%T82!T:65D
M;W-T;V$@(B5S(BX`2V%N861A`%!E<G4`4&5R=2!O;F=E;&UA=FEE<W1I`$5I
M('9O:61A('!O:7-T86$@=&EE9&]S=&]A("(E<R(N`%;D;&EA:6MA:7-H86ME
M;6ES=&]A(&5I(&SV>71Y;GET+@!%:2!V;VED82!J871K86$@:6QM86X@)W1A
M<F=E=$9I;&4G("UP87)A;65T<FEA+@!%:2!V;VED82!P;VES=&%A(&AA:V5M
M:7-T;V$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82P@)60@86QI=&%S;VIA(&]L
M96UA<W-A+@!%:2!V;VD@=75D96QL965N:N1R:F5S=.3D+"!A;FYE='1U:F5N
M('1I971U96ED96X@;>3D<N0@96D@=F%S=&%A('1A;&QE=&5T='5J96X@=&EE
M='5E:61E;B!MY.1RY.0N`$5I('9O:2!O:&IA=&$@=FEE<W1IY"!A;FYE='1U
M=6X@;G5M97)O;VXN`$MA<"!697)D90!+=79A=&5K<W1I`%!A;'9E;'5N=&%R
M:F]A:F$`2VER:F%I;FMO:V]R:6EP<'5V86EN96X`2V%T96=O<FEA="!J82!O
M='-I:V]T`$-A>6UA;B!S86%R970`2V]P:6\`4'5H96QI;BA'4TTI`%-O;'5N
M('1I961O=`!3;VQU;B!TY'ET93H`4V]L=6X@=&EE9&]T`%-O;'5N(';D;'ES
M.@!-871K87!U:&5L:6X`2V5L='1I("A)4T\M.#@U.2TQ-"D`2V5S:VET971T
M>0!+97-K:2U!9G)I:V%N('1A<V%V86QT80!+97-K:2U%=7)O;W!P82`H25-/
M+3@X-3DM,BD`5F%R;65N=&5E;B!T:65D;W0`5F%R;65N=&5E;B!O;6ES=&%J
M80!687)M96YT965N('!O;&ET:6EK870`5'-A9`!-=75T80!686EH9&$@<V%L
M87-A;F%S:0!6;VET(&UU=71T86$@;.1H971TY&UI<W/D<VD@<^1H:_9P;W-T
M96ES<V$@;N1K>79IY"!N:6UI+2!T86D@;W-O:71E=&EE=&]J82X`375U=&]K
M<V5T('1A;&QE=&5T=&EI;BX`4V%L87-A;F%N('9A:6AT;R!E:2!O;&4@:^1Y
M=/9S<^0@;GEK>6ES:6QLY"!A<V5T=6MS:6QL82X@3W1A('EH=&5Y='3D('EL
M;.1P:73D:FEI;BX`365R:VMI`%1A<FMI<W1?82!L:6YK:VDN+BX`0VAI;&4`
M2VEI;F$`2VEI;F$@>6MS:6YK97)T86ES=&5T='4@*$=",C,Q,BD`2VEI;F$@
M<&5R:6YT96EN96X@*$)I9S4I`%9A;&ET<V4@;VAJ96QM80!686QI='-E('-A
M;&%S86YA`%9A;&ET<V4@:^1Y='3D:N1T=6YN=7,`5F%L:71S92!PY&EVY&WD
MY')I96X@97-I='ES87-U.@!686QI='-E(&QI<W1A;B!T>7EP<&D@*&KD<FIE
M<W1E='EI;&QE(&QI<W1O:6QL92D`2F]U;'5S86%R970`3'5O:VMA;>3D<FET
M>7-TY"`E<R!E:2!L]GET>6YY="X`4V5L:V7D`%!O:7-T82!-4T]F9FEC92!T
M86=I=`!0;VES=&$@:WES96QY`%!O:7-T82!KY'ET=.1JY#H@)7,`4&]I<W1A
M(&OD>71TY&KD`%!O:7-T82!KY'ET=.1JY&X@=&EE9&]T`%-E;&ME;F5VY.0@
M;7GV:.3D;@!.87!S875T82!J871K86%K<V5S:0!#;&EK871E;&P@2%144#IN
M(&MA=71T80!3=6QJ92!I:VMU;F$`4&EL=FGD`%!I;'9I;F5N(&%I:V%I<VEN
M`%!I;'9I;F5N`$MO;VMO<R`H2V5E;&EN9RD@<V%A<F5T`%!I96YE;F[D('-I
M=G5V86QI:VMO`%!I96YE;FYE='ET(')E=6YA=`!+;VQU;6)I80!6Y')I`%;D
M<FEV86QI='-I;@!6Y')I=F%L:6YT80!387)A:SH`4V%R86MK96ED96X@;W1S
M:6MO=`!387)J86MU=F%T`$MO;65N=&\`2V]M96YT;W1U;&MK:0!+;VUM96YT
M=&D`66QE:6YE;B!N:6UI`$MO;6]R:70`67)I='ES`%1I971O:V]N965T`$]L
M;W-U:&1E`$]L;W-U:'1E970`07-E='5K<VEE;B!E<F]T`$%S971U:W-E="!0
M1$$M;&%I='1E:61E;BP@Y&QY<'5H96QI;6EE;B!J82!/=71L;V]K:6X@<WEN
M:W)O;F]I=&EI;BX`07-E='5K<VEA('!I=.3D('#D:79I='3DY"X`07-E=&$@
M87-E='5K<V5T("5S`%9A:'9I<W1A(&MI<FIO:71T86UA;&QA('-A;&%S86YA
M('5U9&5S=&%A;@!+;VYG;P!+;VYG;VX@9&5M;VMR86%T=&EN96X@=&%S879A
M;'1A`%EH=&5Y<R!E<.1O;FYI<W1U:2X`66AT97ES(&5PY&]N;FES='5I.B``
M66AT97ES(&5PY&]N;FES='5I`%EH=&5Y<R!J=6QK:7-T96X@879A:6YT96X@
M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!9:'1E>7,@:G5L:VES=&5N(&%V
M86EN=&5N('!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X@5FER:&4Z("5S("@E
M<RD`66AT97ES(&9T<"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN`%EH=&5Y
M<W1I961O=`!9:'1E>7-T:65D;W0@;&ESY'1T:6EN(&]S;VET96MI<FIA87-I
M+@!3:7/D;'3DY`!4:6EV:7-T971Y;B!T:65D;W-T;VX@='EY<'!I.@`B)7,B
M.FX@<VESY&QT]@!*871K80!#;V]K('-A87)E=`!%=N1S=&4`2V]P:6]I`$MO
M<&EO:2`E<P!+;W!I;VEN=&D@97#D;VYN:7-T=6DZ("5S`"5S.FX@:V]P:6\`
M2V]P:6]I('9A;&EN=&$`0V]S="!)1`!#;W-T82!2:6-A`$YO<G-U;FQU=7)A
M;FYI:VMO`%9I97-T:6X@4$=0+7-A;&%U<W1A(&5I('9O:71U('1E:&3D.B``
M5FEE<W1I:6X@96D@=F]I='4@;75O9&]S=&%A(%!'4"UA;&QE:VER:F]I='5S
M=&$Z(`!6:65S=&EN(%,O34E-12US86QA=7-T82!E:2!V;VET=2!T96ADY"X`
M5FEE<W1I:6X@96D@=F]I='4@;75O9&]S=&%A(%,O34E-12UA;&QE:VER:F]I
M='5S=&$N`$5I('9O:71U(&]T=&%A('EH=&5Y='3D+B`E<P!,9&%P+7!A;'9E
M;&EM965N(&5I('-A871U(&%U=&]R:7-O:71U82!Y:'1E>71TY"X`16D@=F]I
M='4@=&%R:VES=&%A('-A;&1O82X@)7,`3$1!4"UP86QV96QI;65E;B!E:2!S
M86%T=2!Y:'1E>71TY"X`16D@=F]I='4@;W1T86$@>6AT97ET=.0@<&%L=F5L
M:6UE96X@(B5S(B!KY'ET=.1E;B!&5%`Z("5S`$5I('9O:71U(&QU;V1A(&IA
M:V5L=6QI<W1A82X@)7,`4$=0+7-A;&%T='5A('1I971O82!E:2!V;VET=2!A
M=6MA:7-T83H@`%,O34E-12US86QA='1U82!T:65T;V$@96D@=F]I='4@875K
M86ES=&$N`$5I('9O:71U('!O:7-T86$@>6AT97ES=&EE=&]A+B`E<P!%:2!V
M;VET=2!P;VES=&%A(&IA:V5L=6QI<W1A82X@)7,`16D@=F]I='4@<&]I<W1A
M82!PY&EV:71Y<W-K<FEP=&GD("(E<R(N`%9I97-T:6X@;.1H971TY&KD;B!S
MY&AK]G!O<W1I;W-O:71E='1A(&5I('!Y<W1Y='1Y(&WDY')I='1E;&5MY.1N
M+@!%:2!V;VET=2!H86ME82!K;VMO(&]S;VET96MI<FIA82X`16D@=F]I='4@
M:&%K96$@:V]K;R!J86ME;'5L:7-T86$N`$5I('9O:71U(&AA:V5A(&MO:V\@
M;&ES=&%A(&IA:V5L=6QI<W1O:7-T82X`16D@=F]I='4@;'5K96$@<W1R871E
M9VEA82`B)7,B+@!+;VUE;G1O(&UK9&ER("(E<R(@97#D;VYN:7-T=6DN`$IU
M;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L=&$@96D@<V%A='4@:G5L:VES
M=&$@879A:6YT82X`5&EE9&]S=&]O;B`B)7,B(&5I('9O:2!K:7)J;VET=&%A
M+@!%:2!V;VET=2!A=6MA:7-T82`E<RX`66QLY'!I=&]M;V1U=6QI;B`E<R!A
M=6MA:7-U(&5PY&]N;FES='5I`$5I('9O:2!A=6MA:7-T82!H86ME;6ES=&]A
M("(E<R(N`$Q$05`M<&%L=F5L:6UE;'1A(&5I(&]L92!M86AD;VQL:7-T82!E
M='-IY"X`)7,ZY.0@96D@=F]I='4@;'5K96$N`$OD>71TY&KD;B!S86QA<V%N
M86$@96D@=F]I='4@;F]L;&%T82X@2F]T:W5T('1A<G9I='1A=F%T('1I961O
M="!O=F%T(';DY')I;BX@67)I=.0@=75D97-T86%N('1A:2!O=&$@>6AT97ET
M=.0@>6QLY'!I=&]O;B!J;W,@=&%R=FET<V5T(&QI<^3D(&%P=6$N`$5I('9O
M:71U(&AA:V5A($%#3"UT:65T;VIA`$5I('9O:71U(&AA:V5A(&]S;VET96MI
M<FIA82X@)7,`16D@=F]I='4@:&%K96$@:F%K96QU;&ES=&%A+B`E<P!%:2!V
M;VET=2!H86ME82!J86ME;'5L:7-T;VIA+B`E<P!%:2!V;VET=2!H86ME82!T
M:65T;VIA('!A;'9E;&EM96X@=&]I;6EN;F]I<W1A`$5I('9O:71U('!A;&%U
M='1A82!A<V5T=6MS:6$N`$MO;65N=&\@<FUD:7(@(B5S(B!E<.1O;FYI<W1U
M:2X`16D@=F]I='4@=&%L;&5T=&%A("5S(&%S971U:W-I82X`16D@=F]I='4@
M=&%L;&5T=&%A(&%S971U<W1E;B!V87)M=75S:V]P:6]T82X`16D@=F]I='4@
M=&%L;&5T=&%A(&%S971U<W1E;B!V87)M=75S:V]P:6]T82`E<P!%:2!V;VET
M=2!T86QL971T86$@87-E='5S<.1I=FET>7-S:W)I<'1IY#H@(B5S(BX`16D@
M=F]I='4@=&%L;&5T=&%A(&%S971U<W1E;B!V87)M=75S:V]P:6]T82`E<RX`
M07-E='5S=&EE9&]S=&]N("5S('1A;&QE='5S(&5PY&]N;FES='5I+B!6;VET
M(&OD>71TY.0@:F]T86MI;B!A<V5T=7-T82!T86QL971T86%K<V5S:2!K;V]D
M:6X@=&%K86ES:6X@)7,@=&%I('1A:2!K;W!I;VED82!KY'-I;B!A;&QA(&]L
M979A;B!K;V]D:6X@=&EE9&]S=&]O;B`E<RX`3$1!4"UP86QV96QI;65L=&$@
M96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD+@!+;VUE;G1O('5N;&EN:R`B)7,B
M(&5PY&]N;FES='5I+@!%:2!V;VET=2!PY&EV:71TY.0@>6AT97ES=&EE=&]J
M82X@)7,`16D@=F]I='4@<.1I=FET=.3D(&IA:V5L=6QI<W1A82X@)7,`5FEE
M<W1E:N0@96D@=F]I='4@<&]I<W1A82!K86YS:6]S=&$@(B5S(CH@)7,`36]Z
M:6QL82!3:61E8F%R(&5I(&SV>71Y;GET+B!687)M:7-T82!E='3D(%-I9&5B
M87(@;W-I;R!O;B!A=6MI+@!+Y'ET=.1JY&QL92`B)7,B(&5I('9O:71U(&%N
M=&%A('-E=7)A879I82!O:6ME=7-I82!K86YS:6]O;B`B)7,B.B`E<P!,87-K
M971T=2!T96MS=&D`36%A`$MU<G-S:70`3'5O`$QU;R!U=7-I(&QI;FMK:0!,
M=6\@=75S:0!,=6\@=75S:2!K86YS:6\`5F]I(&QU;V1A('5U<VEA(&MA;G-I
M;VET80!/:6ME=61E="!T96MI:N1L;.0`3'5O='1O:V]R=&EN;G5M97)O`$MR
M;V%T:6$`2W5U8F$`5.1MY&YH971K:6YE;B`T('9A:6AE='1A`%3D;>1N:&5T
M:VES970@:7-T=6YN;W0`2V5L;&]N86EK82!TY&QLY"!H971K96QLY`!4Y&WD
M;FAE=&MI;F5N(%523"!O;@!4Y&WD;FAE=&MI<V5T(&OD>71TY&KD=`!4Y&WD
M;FAE=&MI;F5N('/DY`!4Y&WD;FAE=&MI;F5N('1I;&$Z(`!4Y&WD;FAE=&MI
M;F5N('1Y>6QI`%9O:70@;75O:V%T82!T96ATY'9IY"P@:F]T:V$@<W5O<FET
M971A86X@:W5N(&MI<FIA=61U=&%A;B!S:7/DY&X@;VAJ96QM86%N("5S+@!,
M96EK:V%A`$QE:6MK86$@=F%L:71T=0!+>7!R;W,`2WER:6QL:6YE;B`H2T])
M."U2*0!+>7)I;&QI;F5N("A7:6YD;W=S+3$R-3$I`$MY<FEL;&EN96XO56MR
M86EN82`H2T])."U5*0!4<V5K:6X@=&%S879A;'1A`%!0`%!/25,@4,3$3%3$
M.@!$4TX@*&QI<^1T:65T;V$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO
M96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!0Y&EV:71T
MY&EN`$1A=&%4<F5E+7-E;&%I;@!4:65T;VMA;G1A:&%K=0!0Y&EVY'ES`%#D
M:7;D;>3D<N0@=F%S=&%A;F]T971T=0!0Y&EVY&WDY'+D;B!V86QI;G1A`%#D
M:7;D`%!O7VES=&$@<V%R86ME`%!O:7-T82!S:W)I<'1I(&OD>73V<W3D`&IO
M=6QU:W5U`$1E<VEM86%L:6YU;65R;W0`4&EE;F5N;N0@<VES96YN>7-TY`!/
M;&5T=7,`3VQE='5S=N1R:0!/;&5T=7-P<F]F:6EL:0!/;&5T=7,@:V]M96YT
M;W1U;&MK:0!-Y.1R:71E;&WD=`!0;VES=&$`4&]I<W1A("5S`%!O:7-T82!S
M;VQU`%!O:7-T82!SY.1N=/8`4&]I<W1A(')Y:&WD`%!O:7-T82!L;VMI`%!O
M:7-T82!O:6ME=7,`5F]I('!O:7-T86$@:F$@='5H;W1A('!O:7-T971T=6IA
M('9I97-T96KD`%!O:7-T82!S;VQU`%!O:7-T82!S87)A:V4`4&]I<W1A(&]L
M96UA<W-A(&]L979A="!V86EH=&]E:'1O:6YE;B!M86QL:0!0;VES=&$@=FEE
M<W1I(&MO:V]N86%N`%9O:2!P;VES=&%A('9I97-T96KD`%!O:7-T82`B)7,B
M.FX@;VEK975K<VEA`$]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A
M82`B)7,B(&IA(&MA:6MK:2!S96X@86QI;VEK975D970_`%!O:7-T82!R:79I
M`%!O:7-T82!V86QI='1U('!R;V9I:6QI`%9O:2!L=6]D82!U=7-I82!K86YS
M:6]I=&$`4&]I<W1A('9A;&ET='4@<V%R86ME`%!O:7-T82!V86QI='1U(')I
M=FD`4&]I<W1E='1U`%!O:7-T971T=2!PY&EV:71Y<W-K<FEP=&D@(B5S(BX`
M3&%I=&$@=FEE<W1I($E.0D]8('!O<W1I:V%N<VEO;VYI`$QA:71A('9I97-T
M:2!)3D)/6"!P;W-T:6MA;G-I;V]N:2!J82!K;W!I;VD`3&%I=&$@=FEE<W1I
M($E.0D]8('!O<W1I:V%N<VEO;VYI(&IA('5U9&5L;&5E;F]H:F%A(&]S;VET
M=&5E<V5E;@!,86ET82!V:65S=&D@=.1HY&X@:V%N<VEO;VX`5&]I;6ET=7-A
M:6MA`%1A;G-K80!/;F=E;&UA;B!K=79A=7,`2W5V875S`%1A<FME;6UA="!T
M:65D;W0@*&SV>71Y=N1T(&UY]G,@2&]R9&4Z;B!L;VMI=&EE9&]S=&]S=&$I
M.@!487)K96UM870@=&EE9&]T(&]N('1A;&QE=&5T='4@>6QLY'!I9&]N(&OD
M<VET96QTY';D:W-I+@!+96AI='ES`$MO<W1E=7-P:7-T90!%9&5L;&ES96X@
M='5N;FEN(&MO<W1E=7-P:7-T93H@`$MO<W1E=7-P:7-T93H@`%-U=6YT82!V
M87-E;6UA;'1A(&]I:V5A;&QE`%-U=6YT82!O:6ME86QT82!V87-E;6UA;&QE
M`$AA:V5M:7-T;P!0;VES=&$@:^1Y=/9S=.0@)7,`4&]I<W1E='1U(&OD>73V
M<W3D`$OD>73D(#(T+71U;FYI;B!A:6MA97-I='ES=.0N`$[D:WEMY&X@87-E
M='5K<V5T`$5S:71Y<W1A<&$@>6MS:71Y:7-K;VAT86EN96X@96YN=7-T90!.
MY'ETY"!I;&UO:71U<R!J;VMA:7-E;&QA('-U;V1A='1I;65N(&OD>71T]FME
M<G)A;&QA+@!%<VET>7-T87!A(&5N;G5S=&5E;&QE("A4048I`$5S:71Y<W1A
M<&$`4&5R:6QL96UE;F]I;&UO:71U<P!$:FEB;W5T:0#$;.0@;.1H973D('9A
M<W1A=7-V:65S=&GD(&IO=6MK;W9I97-T96EH:6X@=&%I('!O<W1I;&ES=&%V
M:65S=&5I:&EN`$5I('-A82!P;VES=&%A`,1LY"!KY'ETY"!S=6]R86%N(&UA
M:6YT96YA;F-E+G!H<#ITY`!4964@=.1MY#H`2F]S(&5N<VEM;>1I;F5N(')I
M=FD@<VESY&QTY.0@<V%R86MK96ED96X@;W1S:6MO="P@;FEI;B!V86QI='-E
M.@!%:2!A;&$`16D@<VESY&QLY`!%:2!PY.1T>0!%:2!O;&4@;VQE;6%S<V$`
M16D@=.1S;>3D("AP;&%C96AO;&1E<FEE;B!K86YS<V$I`$1O;6EN:6MA86YI
M;F5N`$1O;6EN:6MA86YI;F5N('1A<V%V86QT80!%:6OV(&]L92!KY'ET=.1J
MY'1U;FYU<W1A/R!+:7)J875D=2!KY'ET=.1JY&MS:2X`5&%L;&5N;F$`5&%L
M;&5N;F$@)7,`5&%L;&5N;F$@;'5O='4@87-E='5S(%!(4"US:W)I<'1I;N0N
M`$%L87-V971O=F%L:6MK;P!(=75M965T`%/D:&OV<&]S=&EO<V]I=&4`14UA
M:6PM=&\M4TU3(&=A=&5W87D@86IU<FDL(&YI:6QL92!P86QV96QU;G1A<FIO
M86II;&QE+"!J;W1K82!T87)J;V%V870@=.1TY"!P86QV96QU82X`5DE22$4`
M16-U861O<@!-=6]K:V%A`$UU;VMK86$@)7,`375O:VMA82!O<VEO=&$`375O
M:VMA82!R>6AMY.0`375O:VMA82!O:6ME=71T80!-=6]K:V%A(&]I:V5U:W-I
M80!-=6]K:V%A("<E<R<Z;B!O:6ME=6MS:6$`375O:VMA82!A<V5T=6MS:6$Z
M`$UU;VMK86$@(B5S(CIN(&]I:V5U:W-I80!-=6]K:V%A("5S.FX@;VEK975K
M<VEA`$MO=6QU='5S`$5G>7!T:0!%;"!386QV861O<@!%;&5M96YT=&DN+BX`
M16T`4^1H:_9P;W-T:0!3Y&AK]G!O<W1I;W-O:71E`%/D:&OV<&]S=&EO<V]I
M='1E:61E;B!P:73DY"!O;&QA('-A;6%T+@!3Y&AK]G!O<W1I('9A<FUI<W1U
M:W-E;&QA`$5M86EL+71O+5--4R!'871E=V%Y`$AY;6GV=`!4>6AJY"!V:65S
M=&DN`%1Y:&KD('9A<W1A=7,N`%1Y:&KD(&AA:W5T97)M:0!,86ET82!PY.1L
M;&4@)7,`4V%L;&D@:W5V:65N(&QA:71T86UI;F5N(&MU=F%G86QL97)I87-T
M82!T96MS=&EN(&IO=6MK;V]N+@!,86ET82!PY.1L;&4@;VEK96%N('!A:6YI
M:VME96X@:V]N=&5K<W1I;65N=2X`4.3D;&SD`%#DY'1T>6UI<W9U;W-I`%#D
MY'1T>7D`4W5U<F5N;F$@961I=&]R:6$`06YN82!K>7-Y;7ES(&IO:V$@:WES
M>73DY&XL(&IO<R!S86QA<V%N87-I(&IO=61U=&%A;B!N;VQL86%M86%N(&5S
M:6UE<FMI:W-I("=M:6OD(&]N(&QE;6UI:VMI<VD@;FEM:3\G.@!,86ET82!K
M=79A(%523"!TY&CD;@!!;FYA(&MI<FIA:6UE="!A;&QE.@!/;B!Y:'3D<W5U
M<FEK=6EN`$5K=F%T;W)I86%L:6YE;B!'=6EN96$`17)I=')E80!6:7)H90!6
M:7)H92!PY&EV:71E='3D97-SY"!O<VEO=&$Z("5S`%9I<FAE('#D:79I=&5T
M=.1E<W/D('-Y;F,@86YC:&]R("UT:65T;V$Z("5S`%9I<FAE('!O:7-T971T
M865S<V$@<WEN8R!L;VMI83H@)7,`5FER:&4@:&%E='1A97-S82!S:7/D;'3V
MY#H@)7,N`%9I<FAE(&AA971T865S<V$@=.1MY&YH971K:7-TY"!S:W)I<'1I
MY#H@*"5D*2`E<P!6:7)H92!T86QL971E='1A97-S82!M=75T;VMS:6$N`%9I
M<FAE('#D:79I=&5T=.1E<W/D('-A;&%S86YA83H@)7,`5FER:&4@<^1H:_9P
M;W-T:79I97-T:7-SY"X`5FER:&4@:VER:F]I=&5T=&%E<W-A("(E<R(N`$5E
M<W1I`$5T:6]P:6$`171N:6YE;@!%=7)O;W!P80`Q-2!M:6YU=71I;B!VY&QE
M:6X`,B!M:6YU=71I;B!VY&QE:6X`,S`@<V5K=6YN:6X@=N1L96EN`#4@;6EN
M=75T:6X@=N1L96EN`$IO:V%I<V5L;&$@<VESY.1N:VER:F%U='5M:7-E;&QA
M`%!U;VQE;B!T=6YN:6X@=N1L96EN`$UI;G5U=&EN(';D;&5I;@!%<VEM97)K
M:VEA<G9O=#H`4W5O<FET80!/;&5M87-S86]L979A="!SY.1N;O9T`$]L96UA
M<W-A`$QA86IE;FYA`$QA86IE;FYA('-I=G5V86QI:VMO`$]D;W1E='1I:6X@
M;65R:VMIY"`G*2<`3V1O=&5T=&EI;B`Q(&]B:F5K=&DL('-A871I:6X@)60N
M`%-A;F$@<V5L;&%I<V5N86%N('1A:2!H86MU=&5R;6D@;&%I;F%U<VUE<FME
M:7-SY`!,;W!P=7#D:7;D;>3D<N0`16MS<&]N96YT=&D`1D<@=N1R:0!!<V5T
M=7-T:65D;W-T;VIE;B!T=6]N=&D@1E10.FQLY`!!<V5T=7-T96X@:&%K=2!E
M<.1O;FYI<W1U:2X`66AT97ES($Q$05`M<&%L=F5L:6UE96X@97#D;VYN:7-T
M=6DN`%EH=&5Y<R!334(M<&%L=F5L:6UE96X@97#D;VYN:7-T=6DN`$MO<&EO
M:6YT:2`B)7,B.FQTY"!E<.1O;FYI<W1U:2X`2V]P:6]I;G1I("(E<R(Z;&QE
M(&5PY&]N;FES='5I+@!5=61E;B!305-,+7EH=&5Y9&5N(&QU;VUI;F5N(&5P
MY&]N;FES='5I+@!3:6ER=&\@(B5S(CKDY&X@97#D;VYN:7-T=6DN`%-I:7)T
M;R!E<.1O;FYI<W1U:3H@)7,`2V%U;FES`$9A;&ML86YD:6X@<V%A<F5T("A-
M86QV:6YA<RD`1N1R('-A87)E=`!686MA=F$@=FER:&4Z`$9A:W-I`$9A:W-I
M=`!H96QM:6MU=0!4=6YT=74@:W5I;@!4=6YT=74@:W5I;CH@`$UU=71A;6EA
M('-A=&5I=&$`375U=&%M:6$@;'5M:7-A=&5I=&$`2V5N='3D;6%T<FEI<VD`
M1FEG;&5T($-!4%1#2$$`1FEG;&5T(&MI<FIA<VEN`$9I9'II`%1I961O<W1O
M`%1I961O<W1O:F5N(&QU:W5MY.1RY#H@)7,@=&EE9&]S=&\`5&EE9&]S=&]J
M96X@;'5K=6WDY'+D.B`E<R!T:65D;W-T;V$`5&EE9&]S=&]J96X@:^1S:71T
M96QY`%1I961O<W1O;B!N:6UI`%1I961O<W1O;B!V86QI;G1A`%1I961O<W1O
M;B!T=6]N=&D`5&EE9&]S=&]J96X@='5O;G1I(&5I(&]L92!KY'ET971TY'9I
M<W/D+@!3=6]D871A(&MA:6MK:2!V:65S=&ET`%-U;V1A=&$@=F%I;B!V86YH
M870@=FEE<W1I=`!3=6]D871A('9A:6X@=75D970@=FEE<W1I=`!3=6]D871I
M;B!A<V5T=6MS970`4W5O9&%T:6YSY.1N=/8`4W5O9&%T:6YSY.1N;O9T`%-U
M;V1A='5S<VMR:7!T:2!NY&MY;>0`4W5O9&%T:5]N<^3D;F[V=`!3=6]D871I
M;G1O:6UI;G1O.B`E<R!V:65S=&GD(&]N('-I:7)R971T>2!K86YS:6]O;B`B
M)7,B+@!3=6]D871I;G1O:6UI;G1O.B`E<R!V:65S=&GD(&]N('!O:7-T971T
M=2X`4W5O9&%T:6YT;VEM:6YT;SH@)7,@=FEE<W1IY"!O;B!S:6ER<F5T='D@
M:V%N<VEO;VX@(B5S(BX`4W5O9&%T:6YT;VEM:6YT;SH@)7,@;75S=&%L;&$@
M;&ES=&%L;&$@;VQE=F%A('9I97-T:>0@;VX@<&]I<W1E='1U+@!3=6]D871I
M;G1O:6UI;G1O.B!6:65S=&D@(B5S(B!O<V]I='1E97-T82`B)7,B(&]N(&MO
M<&EO:71U(&MA;G-I;V]N("(E<R(N`%-U;V1A=&EN=&]I;6EN=&\Z(%9I97-T
M:2`B)7,B(&]S;VET=&5E<W1A("(E<R(@;VX@<&]I<W1E='1U+@!3=6]D871I
M;G1O:6UI;G1O.B!6:65S=&D@(B5S(B!O<V]I='1E97-T82`B)7,B(&]N('-I
M:7)R971T>2!K86YS:6]O;B`B)7,B+@!3=6]D871I;G1A(&5I(&SV>71Y;GET
M`%-U;V1A='1I;65T`%-U;VUI`$5N<VEM;>1I;F5N('!U;VQI<VMO`$5N<VEM
M;>1I;F5N(&YE;&KD;FYE<P!+;W)J86$@<W5H9&4`2^3D;F[D('EM<.1R:0!+
M96QL=79A`%-U;74`2V%N<VEO=&$@)7,@96D@;VQE(&]L96UA<W-A+@!+:7)J
M87-I;65N(';D<FD`4G5O:V$`2V%I:VEL;&4@='5L979I;&QE('9I97-T96EL
M;&4L(&IO=&MA('-O<&EV870Z`%-E;&%I;6EL;&4L(&IO=&MA(&5I=N1T('1U
M92!K=79I80!%;FYU<W1E("A4048I`$5N;G5S=&5T=&%V870@=G5O<F]K875D
M970@*$AU;VUA871H86X@971TY"!E;FYU<W1U:W-E<W-A(&]N('1I961O="!S
M96OD('#D:79I<W3D(&5T=.0@]FES=.0L(&IO=&5N('-U=7)I(&WDY'+D('#D
M:79IY"!A:6AE=71T86$@;&EI86X@;&5V9>1N(&]S:6]N*0!5;F]H9&ET:V\@
M<V%L87-A;F%S:3\`3&]M86MK965T`$UI971E;&%U<V4`36EE=&5L875S965N
M('1Y>7!P:0!-:65T96QA=7-E970`36EE=&5L875S965T(#(`1F]O<G5M:70`
M575D96QL965N;VAJ86$`2^1Y=/9S<^0@;VQE=F$@86IU<FD@96D@='5E('5U
M9&5L;&5E;F]H:F%U<W1A+@!5=61E;&QE96YO:&IA=6MS970`575D96QL965N
M;VAJ875K<V5N(&UU;VMK875S`'!E`$ME:'EK<V5T`%)A;G-K80!286YS:V$L
M($UE=')O<&]L:0!286YS:V%N($=U>6%N80!286YS:V%N(%!O;'EN97-I80!2
M86YS:V%N(&5T96SD:7-E="!T97)R:71O<FEO=`!,Y&AE='3D:N0`4W5U;FYA
M<W1A(`!,Y&AE='3D:N0Z`%!I9&5M<&D@:W5V875S.@!4Y'ES:6MU=0!+;VMO
M(&YI;6D`1V%B;VX`1V%L;&5R:6$L(&IO<W1A(&MU=F$@;W1E=&%A;@!'86QL
M97)I83H`1V%M8FEA`%1E92`E<R!A<V5T=6MS970`1V5N97)O:71U(&MO;V1I
M`$EN9V\@;VAJ96QM86X@='5O='1A;6$@*&AT='`Z+R]W=W<N:&]R9&4N;W)G
M+VEN9V\O*0!'96]R9VEA`%-A:W-A`$=H86YA`$=I8G)A;'1A<@!%='5N:6UI
M`%EL96ES970@87-E='5K<V5T`$UE;F4`1_9D96P`1V]O9VQE($MA<G1A=`!'
M;V]G;&4@:&%K=0!(87)M86%SY'9Y`%-U=7)E;7!I(&MU:6X`4W5U<F5M<&D@
M=&%I('EH=.0@<W5U<FD@:W5I;@!+<F5I:VMA`$MR96EK:V$@*$E33RTX.#4Y
M+3<I`$=R]FYL86YT:0!'<F5N861A`%)Y:&WD;B!Y;&SD<&ET;P!2>6AM:65N
M(&YI;65T(&5I=N1T('-A82!O;&QA('1Y:&IIY`!'<F]U<%]L9&%P.B!%:2!V
M;VED82!L:7/D=.0@:^1Y='3D:N3D("5S+B!086QV96QI;65N('9I<FAE:6QM
M;VET=7,@;VQI.B``1W)O=7!?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D(&OD
M>71TY&KDY"`E<P!'<F]U<%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y
M='3D:N3D("5S`%)Y:&WD=`!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U
M97)N<V5Y`%9I97)A:6QI:F%N(&]I:V5U9&5T`%9I97)A<VMI<FIA`$=U:6YE
M80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A('!E;&MU<FEM
M86ES97-T:2!K:65L=.1Y='EY('!O:7-T86UA<W1A(')I=FEN('9I:6UE:7-T
MY"!S;VQU82X`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET>7D@
M<&]I<W1A;6%S=&$@=FEI;65I<W3D('-A<F%K971T82!T875L=6MO<W1A+@!(
M5$U,07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T
M82!V:6EM96ES=.0@<FEV:>0@=&%U;'5K;W-T82X`2%144"UA=71E;G1I:V]I
M;G1I82!E:2!L]GET>6YY="X`2&%I=&D`2&%S:"UA;&=O<FET;6D`57-V80!/
M='-A:V4`3W1S86ME`$AE87)D(&IA($UC1&]N86QD('-A87)E=`!6;VEM86MA
M<R!U:VMO<VUY<G-K>0!(97!R96$@*$E33RTX.#4Y+3@M22D`2V]R:V5U<P!/
M:&IE`$%P=6$@961I=&]R:6X@:^1Y='3V]FX`3VAJ90!086QL;VYP=6]L:7-K
M;SH`5.1S<^0@;VX@=&EE9&]S=&]N(&%L:W5O<V$Z`$MO<FME80!+;U]T:0!0
M>6CD(&ES='5I;B`H5F%T:6MA86YI;B!K875P=6YK:79A;'1I;RD`2V]T:0!+
M;W1I;W-O:71E`$MO=&EH86ME;6ES=&\`4'5H96QI;B`H:V]T:2D`2&]N9'5R
M87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!%<.1K96QP;V$@)7,@
M6$U,+61A=&%A('9I97-T:7-SY"`E<P!(;W)D92]+;VQA8CH@66MS:6ODY&X@
M=FEE<W1I(&5I('9A<W1A82!O8FIE:W1I82`E<P!(;W)D92]+;VQA8CH@66AT
MY&ODY&X@;V)J96MT:6$@)7,@96D@;/9Y='EN>70@=FEE<W1I<W3D("5S`$AO
M<F1E+TMO;&%B.B!0;VES=&5T=&EI;B`E<R`B)7,B`$AO<F1E+TMO;&%B.B!)
M;G1E9W)A871I;VMO;F4@=F%A=&EI('1O:6UI86MS965N("=D;VUX;6PG(%!(
M4"UL86%J96YN=6MS96X`2&]R9&4O2V]L86(Z($5I('9O:61A(&QU;V1A('5U
M='1A(%A-3"UP=75T82!O8FIE:W1I;&QE("5S`$AO<F1E+TMO;&%B.B!%:2!V
M;VET=2!P;VES=&%A("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2!V;VED
M82!H86ME82!-24U%($E$.N0@;W-I;VQL92!T>7EP<&GD("5S`$AO<F1E+TMO
M;&%B.B!%:2!V;VD@<WEK<F]N;VED82`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@16D@=F]I9&$@<WEN:W)O;F]I9&$@:F%K;VIA.B`E<P!(;W)D92]+;VQA
M8CH@5'5N=&5M871O;B!J86MO("(E<R(`5F%A:V%S=6]R82!SY.1N=/8`5F%A
M:V%S=6]R82!TY'ET90!686%K87-U;W)A.@!-:71E;B!T=6QI="!TY&YN93\@
M*%)A<&]R=&]I(&MI:71O<R$I`$MU:6YK82!M;VYT82!S87)A:V5T=&$@:&%L
M=6%T('EH9&ES=.3D/P!+96YT=&EE;B`H<V%R86MK96ED96XI(&QU:W5MY.1R
MY"X`2W5I;FMA(&UO;G1A(')I=FGD(&AA;'5A="!Y:&1I<W3DY#\`2V]S=&5U
M<P!+;W-T975S.B``2'5M;W)I<W1I=`!5;FMA<FD`24U!4"UP;W-T:6QA871I
M:V]N(&QU;VYT:2!E<.1O;FYI<W1U:3H@)7,`24U!4"UP;W-T:6QA871I:V]N
M('!O:7-T;R!E<.1O;FYI<W1U:3H@)7,`24U!4"UP;W-T:6QA871I:V]N(&MI
M:6YT:?9N(&QU;VYT:2!E<.1O;FYI<W1U:3H@)7,`25`M;W-O:71E`$E0+6]S
M;VET92!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`25`M;W-O:71E(&5I(&]L92!S
M86QL:71U;B!#2412+6)L;VMI;B!S:7/D;&SD`$E0+7/DY&YN]G-T]FX@<FEK
M:V]M=7,`3%]A:71A(')I=FD@96YN96X`27-L86YT:0!686EN(&EK;VYI=`!)
M:V]N:70@)7,Z;&QE`$EK;VYI="!J82!T96MS=&D`4')O9FEI;&EN(&YI;6DZ
M`$IO<R!S:79U(&5I(&[D>2!K=6YN;VQL82P@;FEI;B!A=6MA:7-E("5S(&5R
M:6QL:7-E<W/D(&EK:W5N87-S82X`2F]S(&5T(&[D92!I:V]N96ET82!KY'ET
M=.1E<W/D<VD@26YT97)N970@17AP;&]R97(@<V5L86EN=&$L(&YI:6X@<VEN
M=6X@<&ETY.0@;W1T86$@<&]I<R!PY.1L=.0@4$Y'(&SD<&ENY&MY=GEY<R!R
M87-T:71T86UA;&QA('3D;>0@;&%A=&EK:V\N`$IO<R!NY&5T('3D;>1N('9I
M97-T:6XL(&UU='1A(&5T(&MU=F%A+"!N:6EN('1U;VUA87-I(&MU=F%A(&5I
M('9O:2!NY'ET=.3D(&OD>71TY&WD<W/D<VD@<V5L86EM97-S82X`2W5V:65N
M(&5S:6MA='-E;'4`2W5V82!54DP`2W5V82!54DPZ`$MU=F$@9V%L;&5R:6%S
M=&$`2W5V82!G86QL97)I87-T83H`2W5V86X@=FEE;G1I`$MU=F%T`%1U;VYT
M:2P@87-K96P@)60`5.1R:V7D`%1U;W1U(&ME;G1TY#H@)7,`5'5O9'5T(&ME
M;G3D=#H`3&%?:71A(')I=FD@:N1L:V5E;@!6Y.1RY"!T;VEM:6YT;VMO;V1I
M(&%N;F5T='4N`$OD>71TY&KD='5N;G5S('1A:2!S86QA<V%N82!O;B!VY.1R
M:6XN`%;DY'+D(&OD>71TY&KD='5N;G5S('1A:2!V86EH=&]E:'1O:6YE;B!O
M<V]I=&4N(%ER:73D('5U9&5S=&%A;B!J82!O=&$@>6AT97ET=.0@>6QLY'!I
M=&]O;B!J;W,@=&%R=FET<V5T(&QI<^3D(&%P=6$N`$QI<^3D('-I<V5N;GES
M=.0`26YT:6$`66MS:71TY&ES970@:^1Y='3D:N1T`$OD>73V<W/D(&]L979A
M(&%J=7)I(&5I('1U92!Y:W-I='3D:7-IY"!S=6]D871I;G/DY&YT]FKD+@!)
M;F1O;F5S:6$`67)I=.1T(&]H:F%T82!V:65S=&5JY"!O;&5M871T;VUA86X@
M<&]S=&EK86YS:6]O;BX`26YF;P!);F9O<FUA871I;P!4:65T;V$@96D@;VQE
M(&5NY.0@<V%A=&%V:6QL82X`3&%I=&$@<U]A<F%K92!JY&QK965N`$QA:71A
M(&MU=F$`3&%I=&$@=&%U;'5K:V\`3&%I=&$@=W=W+6QI;FMK:0!,86ET82!?
M<V%R86ME(&5N;F5N`$QA:71A('5U<VD@<V%R86ME(&YY:WEI<V5N(&KD;&ME
M96X`3&%I=&$@=75S:2!S87)A:V4@96YN96X@;GEK>6ES=.0`3&%I=&$@=75S
M:2!R:79I(&YY:WEI<V5N(&KD;&ME96X`3&%I=&$@=75S:2!R:79I(&5N;F5N
M(&YY:WEI<W3D`$QA:71A(&MA<'!A;&4@;GEK>6ES96X@;F]D96X@:N1L:V5E
M;@!,86ET82!K87!P86QE(&5N;F5N(&YY:WEI<W3D(&YO9&5A`$QA:71A('9A
M:6AT;V5H=&]I;F5N(&UA;&QI`$%N;F$@<^1H:_9P;W-T:6]S;VET92!J;VAO
M;B!U=7-I('-A;&%S86YA(&SD:&5T973DY&XZ`$QA:71A('-O;'4@:N1L:V5E
M;@!,86ET82!S;VQU(&5N;F5N`$QA:71A('-O;'4@:N1L:V5E;@!,86ET82!S
M87)A:V4@96YN96X`5F]I(&QA:71T86$@=FEE<W1E:N0`3&%I=&$@:V%P<&%L
M92!JY&QK965N`$QA:71A(&MA<'!A;&4@96YN96X`3&%I=&$@<FEV:2!E;FYE
M;@!,86ET82!R:79I(&KD;&ME96X`06YN82!V86%D:71T879A('9A<W1A=7,@
M='5R=F%K>7-Y;7EK<V5E;CH`3&EI=.0O375O:VMA82!K=79I80!,:6ETY"]-
M=6]K:V%A(&QI;FMK:>0`4VEN=6QL82!E:2!O;&4@=&%R<&5E:W-I(&MR961I
M:71T96KD(&SD:&5T=.3D:W-E<VD@=FEE<W1I;B!J86ME;'5L:7-T86QL92X`
M4FEI='3D;>1T=/9MY'-T:2!K<F5D:6ET=&5JY`!+;VMO;F%I<VQU:W4`2V]K
M;VYA:7-L=6MU;&ES=&$`17#D:V5L<&\@(%5$2"`H57-E<B!$871A($AE861E
M<BDN`$5PY&ME;'!O82!:25`M=&EE=&]A+@!%<.1K96QP;R!O:&IE;&UA+@!%
M<.1K96QP;R!B871C:"!)1"X`3.1H971E='1I:6X@97#D:V5L<&]A('1I971O
M82X`17#D:V5L<&\@=F%S=&%A;F]T=&%J86X@;W-O:71E+@!%<.1K96QP;R!T
M:65D;W-T;VUU;W1O`$5PY&ME;'!O(&QI<V5N<W-I879A:6XN`$5PY&ME;'!O
M('!A:6MK871I971O+@!%<.1K96QP;R!M<V=?='EP92`N`$5PY&ME;'!O('1A
M:2!P=75T='5V82!A<&E?:60N`$5PY&ME;'!O('1A:2!P=75T='5V82!P87)A
M;65T<FDN`$5PY&ME;'9O="!O:6ME=61E="!Y;&5M;>1L;.0@=&%S;VQL82X`
M17#D:V5L<&\@<&%R;F5R(&ED+@!%<.1K96QP;R!T=6]T96MO;V1I+@!%<.1K
M96QP;R!P<F]T;VMO;&QA+@!%<.1K96QP;R!V87-T86%N;W1T86IA.B`B)7,B
M`$5PY&ME;'!O(&IA:V\M;V)J96MT:0!%<.1K96QP;R!LY&AD96]S;VET92X`
M17#D:V5L<&]A('5N:6-O9&4M=&EE=&]A+@!);G9E;G1A87)I;P!+Y.1N;N0@
M=F%L:6YT82!KY.1N=&5I<V5K<VD`27)A;BP@27-L86UI;&%I;F5N('1A<V%V
M86QT80!)<F%K`$ER;&%N=&D`3VX`36%N+7-A87)I`$5I(&]L90!%<FEL;&ES
M:>0@56MK;W-M>7)S:WEJY`!)<W)A96P`3&EI:VME96QL96QA<VMI:F$`2W5R
M<VEV;VET=0!)=&%L:6$`2F%M86EK80!T86UM:6MU=0!*87!A;FD`2F%P86YI
M("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEA`&AE:6[D:W5U`&ME<^1K
M=74`2V5S:VETY`!+97-K:73D(&ME<VME;&QE`$ME<VMI=.0@=.1Y<VEN`$ME
M<VMI=.0@=F%S96UM86QL90!+97-K:73D(&]I:V5A;&QE`$MA>F%K<W1A;@!3
MY&EL>73D(&%L:W5P97+D:6YE;C\`2V5N:6$`075T96YT:6MO:6YT:2!E<.1O
M;FYI<W1U:2!+97)B97)O<RUP86QV96QI;65L;&4N`$ME<FYE;"!A;&]I='1E
M;&EJ870`079A:6UE;B!L=6]N=&D`079A:6UE;B!T=6YN:7-T90!!=F%I;65N
M('!I='5U<P!!=F%I;65N('1Y>7!P:0!!=F%I;65N(&OD>71T]@!!=F%I;B!O
M;B!J;R!J=6QK:7-T96X@879A:6YT96X@<&%L=F5L:6UE;&QA`$QA<'-E=`!+
M:7)I8F%T:0!+;W)E82P@9&5M;VMR86%T=&EN96X@:V%N<V%N=&%S879A;'1A
M("A0;VAJ;VES+4MO<F5A*0!+;W)E82P@=&%S879A;'1A("A%=&5LY"U+;W)E
M82D`2V]R96$@*$550RU+4BD`2W5W86ET`$MI<F=I<W1A;@!,1$%0+71U:VD@
M;VX@<&%K;VQL:6YE;BP@;75T=&$@3$1!4"UM;V1U=6QI(&5I(&]L92!KY'ET
M971TY'9I<W/D('1A:2!O;&4@;&%D871T=2X`07-?971T96QU`$MI96QI`$QA
M;W,L(&1E;6]K<F%A='1I;F5N(&MA;G-A;G1A<V%V86QT80!*Y&QK:6UMY&EN
M96X@<'5O;&ES:V\`161E;&QI;F5N('-A;&%S86YA;G9A:6AT;P!*Y&QK:6UM
MY&EN96X@;F5L:N1N;F5S`%#D:79I=&5T='D@=FEI;65K<VDZ`$5D96QL:6YE
M;B!S:7/DY&YK:7)J875T=6UI;F5N.B`E<P!%9&5L;&EN96X@<VESY.1N:VER
M:F%U='5M:6YE;CH@)7,L("5S`$5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI
M;F5N.B!%:2!M:6QL;VEN:V%A;@!,871V:6$`3&%K:0!!<V5T=&5L=0!*Y'3D
M('1Y:&KD:W-I(&IO<R!E:2!R975N;VIA`$QI8F%N;VX`5F%S96X`5F%S96X@
M;W1S86ME`%9A<V5N(&%R=F]T`$QE<V]T;P!0:65N96UP:2!K=6EN`%!I96YE
M;7!I('1A:2!Y:'3D('-U=7)I(&MU:6X`5&%S;P!,:6)E<FEA`$QI8GEA($%R
M86(@2F%M86AI<FEY80!,:6-H=&5N<W1A:6X`2V5V>71TY"!RY&YTY.0`2VER
M:F%U9'4@<VESY.1N`$ME=GET=.0@<V%D971T82!A:6MA:7-I;@!+979Y='3D
M('-A9&5T=&$@;7GV:&5M;6EN`$ME=GEI=.0@<V%D96MU=7)O:F$`2V5V>71T
MY"!S861E='1A(&IA(&UY<G-K>6ES=.0`2V5V>71TY"!L=6UI<V%D971T80!+
M979Y:73D(&QU;6EK=75R;VIA`$QI;65R:6MI=`!,:6YK:VD`3&EN:VMI(&]S
M;VET=&%A.@!,:6YK:73D('/D:&OV<&]S=&EO<V]I=&4@:VER:F]I=&$@=75S
M:2!V:65S=&D@<VEV=6QL92!NY&MY;>1S<^0`3&EN:VET`$QI;G5X('!I<&%R
M96ET80!6;VD@;&ES=&%U:W-E<W-A(&[D:&3D(&MA;G-I;VX`3N1Y=.0@=&EE
M=&]K86YN870`3N1Y=.0@;VAJ96ED96X@86EH965T`$[D>73D('1A=6QU=`!,
M:7-T86XM07)K:7-T;P!,:7-T86XM3VAJ90!,:7-T+4E$`$QI<W1A;BU)9`!,
M:7-T86XM3VUI<W1A:F$`3&ES=&$M=FEE<W1I`$QI<W1A;BU4:6QA=7,`3&ES
M=&%N+51I;&%U:W-E;BUL;W!E='1A;6EN96X`27-T=6YT;VIE;B!L:7-T875S
M(&5PY&]N;FES='5I.B`E<P!+Y'ET=.1J:65N(&QI<W1A=7,@97#D;VYN:7-T
M=6DZ("5S`$OD>71TY&KD=&EE=&]J96X@;N1Y='3D;6EN96X@;VX@97-T971T
M>2X`2VER:F%L;&ES=75S`$QI971T=6$`3&%D871A86XN+BX`4&%I:V%L;&ES
M=&$@86EK86$Z(`!,;VMA;&ES86%T:6\@:F$@86EK80!086EK:V$`2VER:F%U
M9'4@<VESY.1N`$5D96QL:7-E;B!S>6YK<F]N;VEN=&ES97-S:6]N(&QO:VD`
M2VER:F%U9'4@=6QO<P!+:7)J875D=2!S:7/DY&X`5&5H=.1VY'0@<VESY.1N
M:VER:F%U='5M:7-E<W-A`%-I<^3D;FMI<FIA=71U;6ES97-I(&5PY&]N;FES
M='5I+B!4;V1E;F[D:_9I<V5S=&D@:VER:F]I=&ET(';DY')I;B!KY'ET=.1J
MY'1U;FYU:W-E<VD@=&%I('-A;&%S86YA<VDN`%-I<^3D;FMI<FIA=71U;6EN
M96X@97#D;VYN:7-T=6DN`%!I=&OD('1E:W-T:0!286MK875S`$UA=&%L80!0
M:65N970@:W)E:6MK86QA:7-E="!K:7)J86EM970`4&EE;F5T(&QA=&EN86QA
M:7-E="!K:7)J86EM970`4&EE;F5T(')O;VUA;&%I<V5T(&YU;65R;W0`3'5X
M96UB=7)G`$M+`$U/5$0`35,M5$Y%1B!L:6ET971I961O<W1O(&]L:2!T>6AJ
MY"X`5DE%4U1)`$UA8V%O`$UA:V5D;VYI82P@16YT:6YE;B!*=6=O<VQA=FEA
M;B!T87-A=F%L;&%N+@!-861A9V%S:V%R`%1A:6MU=7,`4^1H:_9P;W-T:0!0
M;W-T:6X@>6QLY'!I=&\`5&5E(&QI;FM?:VDN+BX`36%L87=I`$UA;&5S:6$`
M36%L961I:79I=`!0;W-T:0!-86QT80!6;VET(&AA;&QI;FYO:61A(&QI<W1A
M82!K871E9V]R:6]I<W1A+"!J;VED96X@879U;&QA('9O:70@;&EI='3DY"!A
M<VEO:71A('EH=&5E;B!S86UO:F5N(&]T<V%K:V5I9&5N(&%L;&4@:F$@;&EI
M='3DY"!N:6EH:6X@=N1R96KD+@!-87`R-"!K87)T=&$`36%P475E<W0@:V%R
M='1A`%9A<W1A879U=61E="!T86QL971E='1U+@!-97)K:71S92!V:65S=&D@
M<&]I<W1E='5K<VD`;6%A;&ES:W5U`$UA<F=I;F%A;&D`365R:VET<V4@=FEE
M<W1I.@!6;VD@;65R:VETY"!686YH82]5=7-I('1I971O:F$`5F]I(&UE<FMI
M=.0@=FEE<W1E:N0@*&5S:6TN(%3D<FMEY"]687-T871T=2D`36%R<VAA;&P@
M<V%A<F5T`$UA<G1I;FEQ=64`5.1S;>3D("AP;&%C96AO;&1E<FEN(&MA;G-S
M82D`5.1S;>3D=N1T(&ME;G3D=`!-875R:71A;FEA`$UA=7)I=&EU<P!3=75R
M:6X@<V%L;&ET='D@:W)E9&EI='1I+@!3=75R:6X@<V%L;&ET='4@=FEE<W1I
M;W-I;VWDY'+D('EL:71E='1Y+@!%9&5L;&ES96X@,C0@='5N;FEN(&MO<FME
M:6X@;.1M</9T:6QA.B``161E;&QI<V5N(#8@='5N;FEN(&MO<FME:6X@;.1M
M</9T:6QA.B``4&]R=&%A;&EO<VEO:61E;B!E;FEM;>1I<VWDY'+D`%/DY&YT
M]FIE;B!E;FEM;>1I<VWDY'+D`%-U=7)I;B!S86QL:71T=2!P:71U=7,`375S
M=&%L;&$@;&ES=&%L;&$@;VX@<W5U<FEN('-A;&QI='1U(&WDY'+D(&]S;VET
M=&5I=&$@*$]S;VET=&5I=&$@>6AT965N<^0Z("5S+"!3=75R:6X@<V%L;&ET
M='4@;>3D<N0Z("5S*2X@575T=&$@;W-O:71E='1A(&5I('9O:71U(&QI<^1T
MY"!M=7-T86QL92!L:7-T86QL92X`5F%L:V]I<V5L;&$@;&ES=&%L;&$@;VX@
M<W5U<FEN('-A;&QI='1U(&WDY'+D(&]S;VET=&5I=&$@*$]S;VET=&5I=&$@
M>6AT965N<^0Z("5S+"!3=75R:6X@<V%L;&ET='4@;>3D<N0Z("5S*2X@575T
M=&$@;W-O:71E='1A(&5I('9O:71U(&QI<^1TY"!V86QK;VES96QL92!L:7-T
M86QL92X`=&]U:V]K=74`36%Y;VYE='1E`$SDY&ME=&EE9&4`2N1S96YE=`!-
M96YU;B!M=6]T;SH`66AD:7-TY"!S;VQU=`!6:65S=&D`5FEE<W1I;B!T87)K
M:7-T=7,@;VYN:7-T=6DL(&UU='1A(&%L;&5K:7)J;VET=&%J86X@=F%R;65N
M;F5T=&$@96D@=F]I='4@=&%R:VES=&%A+@!6:65S=&D@=F%N:&5N:2X`5FEE
M<W1I;B!T>7EP<&D`365T87(@<^3D`$UE=&%R+6]S:6\@96D@;VQE(&OD>71E
M='3D=FES<^0N`$UE=&%R+6]S:6\@96D@;VQE(&OD>71E='3D=FES<^0N(%1A
M<FME;6UA="!T:65D;W0@;VX@=&%L;&5T971T=2!Y;&SD<&ED;VX@:^1S:71E
M;'3D=N1K<VDN`$UE=&%R1$(@96D@;VQE('EH9&ES=&5T='DN`$UE=&]D:0!-
M971O9&EA("(E<R(@96D@;VQE(&WDY')I=&5L='D`365T;V1I82!E:2!O;&4@
M;>3D<FET96QT>2X@2W5T<W5V82!M971O9&DZ("5S`$UE=')I;F5N`$UE:W-I
M:V\`36EK<F]N97-I82P@66AD:7-T>6YE970@=F%L=&EO=`!+97-K96QLY`!-
M:6UE+71Y>7!P:0!%9&5L;&ES96X@,C0@='5N;FEN(&UA=&%L:6X@;.1M</9T
M:6QA.B``161E;&QI<V5N(#8@='5N;FEN(&UA=&%L:6X@;.1M</9T:6QA.B``
M4V%L87-A;F$@96D@;VQE('9I96SD('1A<G!E96MS:2!V86YH80!096EL:6MU
M=F$`4V5K86QA:7-E=`!014%2+7!A:V5T=&D@2%144%]297%U97-T('!U=71T
M=74N`$EL;6]I='5S=FEE<W1I;B!K;VAD96]S;VET92!P=75T='5U`%9I97-T
M:6X@=75D96QL965N;VAJ875K<V5N(&MO:&1E;W-O:71E('!U=71T=74`4'5U
M='1U=F%T(&%S971U<W1I961O<W1O+B!3:6YU;B!P:73DY"!T96ADY"!A<V5T
M=7-T:65D;W-T;R!J;W,@:&%L=6%T(&OD>71TY.0@=.1TY"!O:&IE;&UA82X`
M4'5U='1U=F$@;65S<V%G92!)1"X`2'EL:^3D;6ES=FEE<W1I('!U=71T=74`
M4&]I<W-A;VQO=FEE<W1I('!U=71T=74N`%;D;'1TY&WD=/9N(%!%05(M<&%K
M971T:2!-86EL('!U=71T=74N`%!U=71T=79A('-E<W-I;VX@240N`&UA`$UO
M8FEI;&ESY&AK]G!O<W1I`$MO:'1A;&%I;F5N`$UU;VMK875K<V5N('#D:7;D
M;>3D<N0`375O:VMA82!54DPZ:6$`2V5R<F]I;@!-;VQD;W9A+"!T87-A=F%L
M=&$`36]N86-O`$UO;F=O;&EA`&MU=6MA=7-I(&IA('9U;W-I`$MU=6MA=7-I
M='1A:6X`36]N='-E<G)A=`!+=75N('9A:6AE970`4FEV:6QTY"`E9"!L]GET
M>6D@96YE;6WD;B!K96YT=&GD(&MU:6X@;V1O=&5T='4@)60N`$UA<F]K:V\`
M16YI;6WD:W-I('-E;&MEY.0`16YI;6WD:W-I('!I;'9I<W3D`$5N:6UMY&MS
M965N('!I;'9I<W3D(&IA('1U=6QI<W1A`$5N:6UMY&MS965N(&%U<FEN:V]I
M<W1A`%-I:7)RY`!3:6ER<N0@86QA<W#D:6X`4VEI<G+D('9A<V5M;6%L;&4`
M4VEI<G+D(&]I:V5A;&QE`%-I:7)RY"!SY.1N=/;D(&%L87-PY&EN`%-I:7)R
MY"!SY.1N=/;D('EL]G-PY&EN`%-I:7)RY"!Y;/9S<.1I;@!3:6ER<N0@86QA
M<W#D:6X`4VEI<G+D('EL]G-PY&EN`$UO<V%M8FEK`$UO;FET87-O:6YE;B!A
M;&%S=F5T;W9A;&EK:V\`375L=&EM87`@27-O+4)R:71A;FYI86X@:V%R='1A
M`$UO;FEV86QI;G1A`$OD>71TY&KD='5N;G5K<V5N:0!/;6%N(&OD>71TY&KD
M='5N;G5K<V5N('1I961O=`!/;6$@<&]R=&%A;&D`3VUA;B!P;W)T86%L:6X@
M87-E='1E;'4`37EA;FUA<B`H0G5R;6$I`$5)+"!%3B!S=6]S='4`35]O;F5N
M:V\@<.1I=N1N(';D;&5I;B!LY&AE=&5TY.1N('!O:7-S86]L;W9I97-T:3H`
M3FEM:0!.86UI8FEA`$YA=7)U`$YE<&%L`$%L86YK;VUA870`06QA;FMO;6%I
M9&5N($%N=&EL;&ET`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E
M=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@
M4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M4U-,+7!A;'9E;&EM96X@;W-O:71E`$YE='-C87!E('9A<FUE;G1E96X@:V]M
M;65N='1I`$YE='-C87!E('9A<FUE;G1E96X@='EY<'!I`%9E<FMK;P!%:2!K
M;W-K86%N`%5U<VDM2V%L961O;FEA`%5U<VD@;'5O:VET=7,`575S:6MU=0!5
M=7-I('/DY&YT]@!5=7-I(&OD>71TY&KD='5N;G5S("AV87!A865H=&]I;F5N
M*0!5=7-I+5-E96QA;G1I`%5U<VD@<V%L87-A;F$`575S:2!S86QA<V%N82!V
M86YH96YE92`E>"X`06YT86UA<VD@=75D970@<V%L87-A;F%T(&5I=N1T('3D
M<VWDY"X`575S:2!I:VMU;F$@*%]B;&%N:RD`575T:7-E=`!+97-K=7-T96QU
M<GEH;>1T`%-E=7)A879A`%-E=7)A879A="`T('9A:6AE='1A`%-E=7)A879A
M="!A<V5T=6MS970`4V5U<F%A=F$^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA
M`%GV`$YI=64`16D`16QE;65N='1IY"`B)7,B(&5I(&SV>71Y;GET('1A=7-T
M86KD<FIE<W1E;&WD;B!A<V5T=6MS:7-T82X`07-E='5S=&EE=&]J82!E:2!O
M;&4@<V%A=&%V:6QL82P@:F]S=&$@=F]I<VD@;N1Y='3DY"!E<F]A=F%I<W5U
M:W-I82X`16D@;VQE('-A871A=FEL;&$@<W5U;FYI=&5L;6%A($E33R!L979Y
M:W5V871I961O<W1O:F5N('1E:V5M:7-E:W-I+@!4875S=&%JY')J97-T96QM
MY.0@96D@;VQE(&WDY')I=&5L='D@=.1L;&4@<&%L=F5L:6UE;&QE`%1A=7-T
M86KD<FIE<W1E;&UIY"!E:2!O;&4@;>3D<FET96QT>2!B86-K96YD<RYP:'`@
M=&EE9&]S=&]S<V$`16D@97+D;6%L;&EA+@!/<VEO=&$@96D@;VQE('!Y>61E
M='ES<^0@<&%I:V%S<V$N`$MA;&5N=&5R:6X@;FEM9>0@96D@;VQE(&%N;F5T
M='4@34-!3"UA=71E;G1I:V]I;FYI;&QE+@!%:2!M=75T;W-T82X`06QI=&%S
M;VIA(&5I('9O:2!L:7/D=.0@=.1L;&4@;VEK975D96QL92X`07-E='5K<VEA
M(&5I(&SV>71Y;GET("5S.FQL92X`07-E='5K<VEA(&5I(&SV>71Y;GET($94
M4"!61E,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@4U%,(%9&4SIL;&4N
M`$%S971U:W-I82!E:2!L]GET>6YY="!344PM1FEL92!61E,Z;&QE+@!+<F5D
M:6ET:70@;&]P<'4N`$MO:&1E='1A(&5I(&%N;F5T='4N`$5I('1U;W1U(&%I
M;G5T=&%K86%N('1I961O<W1O80!%:2!S=6]D871T:6UI82X@3F%P<V%U=&$@
M(B5S(B!T96ADY&MS97-I('5U9&5N('-U;V1A='1I;65N+@!/='-A:VME:71A
M(&5I(&]L92!MY.1R:71E;'1Y`$EK;VYE:71A(&5I(&SV>71Y;GET+@!086EK
M:V%A(&5I(&]L92!A<V5T971T=2X`4&%I:VMA82!E:2!O;&4@86YN971T=2X`
M16D@86YN971T=2!V:65S=&GD+@!.:6UEY"!E:2!O;&QU="!A;FYE='1U+@!,
M=6MU;>3D<N3D(&5I(&]L;'5T(&%N;F5T='4N`$5I(&QO=6MK86%V870@;6EE
M=&5L875S965T`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!(5%10+6%U=&5N
M=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!)34%0+6%U
M=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!+97)B
M97)O<RUA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE(&%N;F5T
M='4@3&]G:6X@875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L92!A
M;FYE='1U(%!!4U-71"UA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@
M;VQE(&%N;F5T='4@4TU"+6%U=&5N=&EK;VEN;FES<V$N`%!O;&MU82!/<&5N
M4U-,(&MO;65N=&]O;B!E:2!O;&4@;>3D<FET96QT>2X@3W!E;E-33"!P:73D
MY"!O;&QA(&OD>71E='3D=FES<^0@:F]S(&OD<VET96QLY.1N(%!+0U,@,3(@
M9&%T86$N`$5I('-I<^3D;FMI<FIA=71U;6ES<'EY;G3V:N0@:F]N;W-S82X`
M2VEI;G1I]G3D(&5I(&]L92!A<V5T971T=0!%:2!SY.1N=/9JY`!3:W)I<'1I
MY"!E:2!L=6]T=2X`17)O=&EN=&$@96D@;VQE(&WDY')I=&5L='DN`$5I(')E
M=6YO:F$`365R:VMI:F]N;VIA(&5I(&]L92!MY.1R:71E;'1Y`$5I(&SV>71Y
M;GET('1I961O<W1O80!6Y&QI;75I<W1I;&QE(&5I(&]L92!VY&QI86EK86ES
M:&%K96UI<W1O82X`2^1Y='3D:N1T=6YN=7-T82!T86D@<V%L87-A;F%A(&5I
M(&SD:&5T971T>2X`2V%I:VMI('!A;&%U='5N=70@6$U,+61A=&$@;VQI(&5P
MY&ME;'!O80!%:2!A<G9O:F$`5F5R<VEO=&EE=&]J82!E:2!L]GET>6YY="!A
M;&MU<&5RY&ES:73D(&%S971U:W-I<W1A+B!3:6YU;B!P:73DY"!T96ADY"!A
M<V5T=6MS970@=75D97-T86%N+@!697)S:6]T:65T;VIA(&5I(&SV>71Y;GET
M(&%S971U:W-I<W1A+B!3:6YU;B!P:73DY"!T96ADY"!A<V5T=6MS970@=75D
M97-T86%N+@!%:2!M:73DY&X`16D@;6ETY.1N("A+Y'ETY"!I;7!L:7-I:71T
M:7-TY"D`3&%P<&DO4&]H:F]I<VUA870O17-K:6UO("A)4T\M.#@U.2TQ,"D`
M3F]R9F]L:R!S86%R970`4&]H:F]I;F5N('!A;&QO;G!U;VQI<VMO`%!O:&IO
M:7-E="!-87)I86%N:65N('-A87)E=`!.;W)J80!%:2!JY&QK965N`$5I(&5N
M;F5N`$5I(&]L92!H86ME;6ES=&\`97)I<W5U<FD@:W5I;@!%:2!O;&4@=&]T
M975T971T=2X`16D@87-E=&5T='4`16D@='5E='1U+@!-=6ES=&EI;G!A;F]T
M`$5I(&UI=.3D;B!S96QA='1A=F%A+"!P86QA82!T86MA:7-I;BX`26QM;VET
M=6MS:65N('/D:&OV<&]S=&EO<V]I=&4`;6%R<F%S:W5U`$QU:W5MY.1RY`!-
M97)K:VEE;B!L=6MU;>3D<N0`4V%R86MK96ED96X@;'5K=6WDY'+D`%)I=FEE
M;B!L=6MU;>3D<N0`2F%K96QU;&ES=&%N(&YU;65R;VET82!E:2!O;&4@;>3D
M<FET96QT>2!PY&EV:71E='3D=N1K<VDN`$]+`$]B:F5K=&D`3V)J96MT:6X@
M;'5O:F$`3VMT86%L:0!L;VMA:W5U`$QO=6MK86%V=75S<W5O9&%T:6X`5&]I
M;6ES=&\`575S:2!S86QA<V%N82!E:2!S86$@;VQL82!S86UA(&MU:6X@;GEK
M>6EN96X@<V%L87-A;F%S:2X`5F%N:&$@<V%L87-A;F$`5F%N:&$@<V%L87-A
M;F$@;VX@=N3D<FEN+@!/;6%N`%9A:6X@24U!4"UP86QV96QI;65T('1U:V5V
M870@:F%E='1U:F$@:V%N<VEO:71A+@!-=75T82!V86EN('9I97-T:6X@=&EL
M871I971O80!686EN(&QO=6MK86%V870@;6EE=&5L875S965T`%9O:70@;&%I
M='1A82!V86EN('EH9&5N('/D:&OV<&]S=&EO<V]I='1E96XN`%9A:6X@;VUI
M<W1A:F$@=&%I(&KD<FIE<W1E;&WD;B!Y;&SD<&ETY&KD('9O:2!M=75T=&%A
M(&IA:V]J96X@;VUI<W1A:FEA('1A:2!O:6ME=6MS:6$`079A82!U=61E<W-A
M(&EK:W5N87-S80!/<&5N4U-,('9I<FAE.B!4:65T;VIA(&5I('-A871U(&5S
M:6QL92!A;&QE:VER:F]I=&5T=7-T82!3+TU)344M;W-A<W1A+@!!=F%A('3D
M;>1N(&QI;FMI;B!U=61E<W-A(&EK:W5N87-S80!+Y'ET=/9JY')J97-T96QM
MY`!!<V5T=6MS970`5F]I="!M=75T=&%A('-K<FEP=&EN('#D:79I='EK<V5E
M;B!L:6ET='EV:>0@87-E='5K<VEA+@!!<V5T=6MS970@)7,Z;&QE`$KD<FIE
M<W1E='1Y(&QI<W1A`$]R9V%N:7-A871I;P!/<F=A;FES86%T:6]Y:W-I:VOV
M`$]R9V%N:7-O:6YT:0!!;&MU<&5RY&EN96X@;VAJ96QM86X@;6%L;&D`06QK
M=7!E<N1I<V5T(&UA;&QI="`E<SIS<^0Z`$UU=0!-=75T('1I961O=`!-=75T
M(&%S971U:W-E=`!9;&5I<VMU=F$`3VUI<W1A:F%N(&]I:V5U9&5T`%!!32UA
M=71E;G1I:V]I;G1I82!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`4$5!4CHZ36%I
M;"!T875S=&%JY')J97-T96QMY`!$:6=I=&%A;&EN96X@4$=0+6%L;&5K:7)J
M;VET=7,`4$=0+7-A;&%T='5A('1I971O80!*=6QK:6YE;B!01U`M879A:6X`
M4$=0+6%L;&5K:7)J;VET971T=6$@:F$@<V%L871T=6$@=&EE=&]A`%!(4"UK
M;V]D:0!02%`M:V]M96YT;W1U;&MK:0!032!K979Y='3D('-A9&5T=&$`4$T@
M<V%D90!032!K=75R;VIA`%!-(&QU;6D`4$T@;'5M:7-A=&5I=&$`4$T@;'5M
M:0!032!U:VMO<VUY<G-K>6KD`%!/4TE8+6QA86IE;FYU:W-E="!P=75T='5V
M870`4%](4"UK;VUE;G1O='5L:VMI`%3D>71E`%!A:VES=&%N`%!A;&%U`%!A
M;&5S=&EI;F$@*&UI96AI=&5T='D@86QU92D`4&%N86UA`%!A<'5A(%5U<VDM
M1W5I;F5A`%!A<F%G=6%Y`$]S:71T86EN('!I;'9I<W3D`%-A;&%S86YA`%-A
M;&%S86YA;B!V86EH=&\@;VYN:7-T=6DN`%;DY'+D('-A;&%S86YA`%-A;&%S
M86YA82!T87)V:71A86X@4D%$2553+6%U=&5N=&EK;VEN=&EI;BX`4V%L87-A
M;F$@=F%R;6ES='5K<V5L;&$`4V%L87-A;F$Z`%-A;&%S86YA.B``4V%L87-A
M;F]J96X@<&ETY.0@;VQL82!S86UA="X`3&EI=.0`3&EI=.0@;&5I:V5P]GED
MY&QTY`!0;VQK=0!*;VYO<W-A(&]L979A="!S:7/DY&YK:7)J875T=6UI<W!Y
M>6YN]G0Z`$EH;6ES970`4')O<V5N='1I`%-U;W)I=&$@>6QLY'!I=&]T;VEM
M96YP:71E970`4W5O<FET82!Y;&SD<&ET;W1O:6UE;G!I=&5E="!S:7/DY&YK
M:7)J875T=6UI<V5N('EH=&5Y9&5S<^0N`$]I:V5U<P!/:6ME=71T82`B)7,B
M(&5I('!O:7-T971T=2X`2^1Y='3V(&MI96QL971T>0!/:6ME=61E=`!/:6ME
M=6MS:65N('EL;.1P:71O`$]M870@=&EE9&]T`%!E<G4`3&5M;6EK:70`1FEL
M:7!P:6EN:70`4'5H96QI;@!686QO:W5V870`4&ET8V%I<FX`4&EK<V5L:0!+
M;&ES965T`$YA<'-A=71A(&IO=&%I;B!S;VQU80!687)M:7-T82!E='3D(&AA
M;'5A="!P;VES=&%A('3D;>1N(&5L96UE;G1I;CH`5F%R;6ES=&$@971TY"!H
M86QU870@<&]I<W1A82!L:6YK:71Y:W-E;B!TY&CD;B!E;&5M96YT=&EI;BX`
M06YN82!K=75K875S:2!J82!V=6]S:2X`06YN82!N:6UI('5U9&5L;&4@;'5O
M:VET=6MS96QL93H`06YN82!O:6ME82!)4"UO<V]I=&4N`$%N;F$@;VEK96$@
M<.1I=N1MY.1RY#L@5&%R:VES=&$@<.1I=FEE;B!L=6MU;>3D<N0@:W5U:V%U
M9&5S<V$N`$%N;F$@86EK82!O:6ME87-S82!M=6]D;W-S82X`06YN82!U=61E
M;B!K86YS:6]N(&YI;6DZ`$%N;F$@;'EH>70@:W5V875S(&]N9V5L;6%S=&$N
M`$%N;F$@:^1Y='3D:N1T=6YN=6MS97-I(&IA('-A;&%S86YA<VD`3'5E('-E
M=7)A879A('1E:W-T:2X@4VEN=6X@4$E4Q,0@<W5O<W1U82!KY'ET=/9E:'1O
M:6AI;B!V;VED86MS97-I(&OD>71TY.0@:N1R:F5S=&5L;>3D+@!!;FYA(&YI
M;6D@=75D96QL92!L=6]K:71U:W-E;&QE.@!0=6]L80!0;VQI=&EI:VMA`$MY
M<V5L>70`4&]R='5G86QI`%3D;>1N(&MU=F%N('!A:6MK80!4Y&WD;B!T875L
M=6MO;B!P86EK:V$`5F]I(&SD:&5T=.3D('9I97-T96KD(&MA;G-I;V]N("AE
M:2!K;W-K92!)34%0('EH=&5Y:W-IY"D`4V%D96WDY'+D(&5D96QL:7-I;&QE
M("5S('1U;FYI;&QE.B``2&%I:'1U=G5U<R`\8G(@+SYT;V1E;F[D:_9I<WEY
M<P!0<F5F<U]L9&%P.B!487)V:71T879A82!,1$%0+6QA86IE;FYU<W1A(&5I
M(&SV>71Y;GET+@!0<F5F<U]S97-S:6]N.B!487)V:71T879A82!S97-S:6]N
M+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET`$EL;6%N<&%I;F4`26QM86YP86EN
M92!M97)E;G!I;FYA<W-A.B``26QM86YP86EN93H@`$5S:6MA='-E;'4`17-I
M:V%T<V5L92!K=79A('5U9&5S<V$@:6MK=6YA<W-A`$5D96QL:7-E="!A<V5T
M=6MS970`5'5L;W-T82!D;VMU;65N='1I`%-A;&%I;F5N(&%V86EN`$]N9V5L
M;6$`3VYG96QM86X@:W5V875S`%!R;VIE:W1I=`!+96AO='1E96X@=&5K<W1I
M`$IU;&MI;F5N(&%V86EN`$IU;&MI<V5N(&%V86EM96X@86QG;W)I=&UI`$IU
M;&MI<V5N(&%V86EM96X@=&EE9&]T`$IU;&MI<V5N+W-A;&%I<V5N(&%V86EN
M<&%R:6X@;'5O;G1I(&5PY&]N;FES='5I+@!0=65R=&\@4FEC;P!6;VD@='5H
M;W1A('!O:7-T971T=6IA('9I97-T96KD`%%A=&%R`$MY<V5L90!+:6EN=&GV
M`%)302!*=6QK:6YE;B!A=F%I;B`H)60@8FET=&GD*0!37WEY`%)A9&EO<&%I
M;FEK90!3861E`%-A9&5T=&$@86EK86ES:6X`4V%D971T82!M>?9HY.1N`%-A
M9&5K=75R;P!697-I(&IA(&QU;6D`5F5D97-TY"!L=6UE96X`4V%T=6YN86EN
M96X@;6EE=&5L875S90!3=6AD90!,=6MU`%9O:2!L=6ME82!V:65S=&5JY`!0
M;VES=&5T86%N:V\@)7,_(%3D=.0@=&]I;6EN=&]A(&5I('9O:2!P97)U=71T
M86$N`%!O:7-T971A86YK;R!T:65D;W0@:^1Y='3D:N1S=.0@)7,_(%3D=.0@
M=&]I;6EN=&]A(&5I('9O:2!P97)U=71T86$N`%9A<W1A86YO=&5T='4`575D
M96QL965N;VAJ86$@;W-O:71T965S965N`%1E92!M=75T;VMS970@=75D97-T
M86%N`%#D:79I=.0`4.1I=N1T(&1Y;F%A;6ES970@=F%L:6MK;V5L96UE;G1I
M=#H`4.1I=FETY"!P;W)T86%L:6[D:WEMY.0Z`%/DY&YN]FQL:6YE;B!L875S
M96ME`%/DY&YN]FQL:6YE;B!L875S96ME`$AY;&ODY"!V:65S=&D@=F%S=&%U
M:W-E;&QA`%)E;&%A=&EO<V5L86EN`$QA=&%A('5U9&5L;&5E;@!-=6ES=&EI
M;G!A;F]T`$5TY'!A;'9E;&EM970`173D<&%L=F5L=6X@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4&]I<W1A`%!O:7-T82!O<VEO`%!O
M:7-T82!S87)A:V4`4&]I<W1A(&UU;W1O:6QU`%!O:7-T82!P87)I`%!O:7-T
M82!T86QL971E='1U('-K<FEP=&D@<&%L=F5L:6UE;B!VY&QI86EK86ES:&%K
M96UI<W1O<W1A+@!0;VES=&$`4&]I<W1A('3D;>0@;F]O9&D@9&]K=6UE;G1I
M<W1A`%!O:7-T82!KY'ET=.1JY`!0;VES=&$@:^1Y='3D:N0Z("5S`%!Y>6YT
M]O9N(&5I('9O:71U('9A<W1A=&$N(%9I<FAE:V]O9&DZ(`!0>7ED971T>>0@
M<&%L=F5L=6$@96D@;/9Y='EN>70N`%1A<G9I='1A=F%A("(E<R(M=&EE=&]A
M(&5I(&]L;'5T(&WDY')I=&5L='D@)7,@87-E='5K<VES<V$N`%1A<G9I='1A
M=F%A("(E<R(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@5D93(&%S971U
M:W-I<W-A+@!487)V:71T879A82`B)7,B+71I971O82!E:2!O;&QU="!MY.1R
M:71E;'1Y(&%S971U:W-I<W-A+@!086MO;&QI;F5N(&ME;G1TY`!,Y&AE=.0@
M=75D96QL965N(&]S;VET=&5E<V5E;@!5=61E;&QE96YLY&AE=&5T='D@;W-O
M:71T965S=&$`5'EH:F5N;N0`5'EH:F5N;N0@<V%L87-A;F$`5'EH:F5N;N0@
M<V%L87-A;F%S:0!086QA=71A(&5D96QL:6YE;B!K>7-E;'D`5'5L;VMS970`
M4&%L86$@<W5O9&%T:6YL:7-T86%N`%!A;&%A(&%S971U:W-I:6X`4&%L86$@
M<^3D;F[V<W3V;&ES=&%A;@!686AV:7-T82!U=7-I('-A;&%S86YA`%)E=6YI
M;VX`4&%L875T82!A<V5T=6MS970`4FEC:"!497AT($5D:71O<FEN(&%S971U
M:W-E=`!!<G9O:71U:W-E=`!/:6ME80!/:6ME82!O='-A:V4`3VEK96$@87)V
M;W0`4FEV:5]N('1I961O="XN+@!2;V]L:0!2;VUA;FEA`$ODY&YNY"`Q.#``
M2^3D;F[D('9A<W1A<.1I=N3D;@!+Y.1N;N0@;7GV=.1PY&EVY.1N`%)I=FEN
M('1I961O=`!2:79I;B!T:65D;W0`4FEV:70Z`%/DY&YT]@!3Y.1N=/8@:V]P
M:6]I=&EI;@!3Y.1N=/8@<&]I<W1E='1I:6X`4^3D;G3V('!O:7,@:^1Y=/9S
M=.0`4^3D;G3V(&OD>73V<W/D`%/DY&YN]FX@;FEM:0!3Y.1N=/8Z`%9I:79O
M:71I;@!6:6EV;VET:6X@;N1K>7D@:V%I:VMI96X@<FEV:65N(&IA('-A<F%K
M:V5I9&5N(';D;&EL;.0`5FEI=F]I=&EN(&[D:WEY('9A:6X@<V%R86MK96ED
M96X@=N1L:6QLY`!6:6EV;VET:6X@;N1K>7D@=F%I;B!R:79I96X@=N1L:6QL
MY`!3=6]R:71A`%9E;N1JY&X@1F5D97)A=&EI=FEN96X@=&%S879A;'1A`%)U
M86YD80!3+TU)344@:W)Y<'1O9W)A869I;F5N(&%L;&5K:7)J;VET=7,`4R]-
M24U%('-A;&%T='4@=FEE<W1I`%-!4TPM875T96YT:6MO:6YT:2!E:2!O;&4@
M:^1Y=&5T=.1V:7-SY"X`4TU3(%1E:W-T:79I97-T:70`4U%,+6MO;65N=&]T
M=6QK:VD`4U%,+6QA=7-E(&%R=F]J96X@:&%K96UI<V5E;@!34T@`4U1!4E14
M3%,@97#D;VYN:7-T=6DZ("@E<RD@)7,`3TY.25-454D`4U]13"UK;VUE;G1O
M='5L:VMI`&QA`%-A:6YT($AE;&5N80!386EN="!+:71T<R!J82!.979I<P!3
M86EN="!,=6-I80!386EN="!0:65R<F4@:F$@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="!J82!'<F5N861I:6YI=`!386UA86X@:V5H>6MS965N("A?<V5L9BD`
M4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!J82!0<FEN8VEP90!3871E;&QI
M:71T:2!P86QV96QU;G1A<FIO86IA`%-A=61I82!!<F%B:6$`5&%L;&5T80!4
M86QL971A("(E<R(`5&%L;&5T82`E<P!486QL971A(&%S971U:W-E=`!486QL
M971A(&%S971U:W-E=`!486QL971A(&QU;V1U="!A<V5T=6MS970@4$A0+7-K
M<FEP=&ENY"!P86QV96QI;65S:2!VY&QI86EK86ES:&%K96UI<W1O;VXN(`!4
M86QL971E='1I:6X@)7,Z;B!A<V5T=6MS970N`$%S971U<W1E;B!PY&EV:71Y
M<W-K<FEP=&D@;VX@=&%L;&5T971T=2!P86EK:V%A;CH@(B5S(BX`2&%J86YA
M:7-I82!U:VMO<VUY<G-K>6KD`%1I961E`%-K<FEP=&D`4VMR:7!T:6X@<.1I
M=FET>7,`4VMR:7!T:>0@96D@<.1I=FET971T>2X`4VMR:7!T:6X@86MT:79O
M:6YT:2!O;FYI<W1U:2X`4VMR:7!T:6X@86MT:79O:6YT:2!O;FYI<W1U:2X`
M2&%K=0!(86MU:V]N965T`%9A;FAA`%9A;&ET<V4@=&EE9&]S=&]T`%9A;&ET
M<V4@<.1I=N1MY.1RY`!686QI='-E(&ME;G1TY`!686QI='-E(&QI<^1T=.1V
MY"!R>6AMY`!686QI='-E('5U<VD@;VUI<W1A:F$`5F%L:71S92!P86QV96QI
M;@!686QI='-E(&QI<^1T=.1VY"!KY'ET=.1JY`!686QI='-E(&MA:6MK:0!6
M86QI='-E(&MA:6MK:2!PY&EVY&WDY'+D:V]M<&]N96YT:70`5F%L:71S92!O
M8FIE:W1I`%1Y:&IE;F[D('9A;&EN=&$`5F%L:71S92!K;VAD96MA;G-I;P!6
M86QI='-E('1A<G9I='1A=F%T(&UE<FMI="!A;&QA(&]L979I<W1A('9A;&EK
M;VES=&$N(%9O:70@<V5N(&KD;&ME96X@:V]P:6]I9&$@:F$@;&EI='3DY"!M
M97)K:70@=&5K<W1I:7-I+@!686QI='-E('#D:7;D>6MS96X@97)O=&EN;65R
M:VMI.@!686QI='-E('#D:7;D>6MS96X@97-I='ES=&%P83H`5F%L:71S92!M
M=75T971T879A('!R;V9I:6QI.@!686QI='-E(&ME;&QO;F%J86X@97)O=&EN
M;65R:VMI.@!686QI='-E(&%J86X@97-I='ES=&%P83H`5F%L:71S92!K86MS
M:2!Y:'1E96YS;W!I=F%A(&ME;G1TY.0N`%9A;&ET<V4@=N1R:71E96UA+@!6
M86QI='-E(&OD>71E='3D=N0@:VEE;&DZ`$ET<V5MY.1R:71E;'1Y(&]T<V%K
M90!,Y&AE=.0@;VYG96QM879I97-T:0!,Y&AE=.0@4TU3`$SD:&5T=.1JY`!3
M96YE9V%L`%1U;FYI<W1I;CH@`'-Y>7-K=74`4V5R8FEA(&IA($UO;G1E;F5G
M<F\`4V%R:F%N=6UE<F\`4&%L=F5L:6UE;B!T:65D;W0@;W9A="!VY.1R:>0@
M=&%I(&5I=N1T(&]L92!KY'ET971TY'9I<W/D+@!)<W1U;G1O:F5N(&AA;&QI
M;G1A`%-E<W-I;VX@240@;VX@=F%N:&5N='5N=70N`$ES='5N;F]T`$%S971A
M`%-A;&%S86YA;B!R97-E=&]I;G1I:6X@;&EI='1Y=FGD(&%S971U:W-I82P@
M:F]S(&IO<VMU<R!U;F]H9&%T('-A;&%S86YA<VDN`%9O:70@87-E='1A82!U
M;&MO:7-T96X@<&%L=F5L:6UI96X@87-E='5K<V5T+"!J;VET82!H86QU870@
M:^1Y='3DY"!P;W)T86%L:7-S82X`5F]I="!A<V5T=&%A(&OD>71E='3D=N1N
M(&MI96QE;BP@86EK879Y]FAY:VME96X@:F$@;75I=&$@<.1I=N1MY.1RY&%S
M971U:W-I82X`5F]I="!A<V5T=&%A(&%L;VET=7-O:&IE;&UA;BP@=N1R:71E
M96UA;BP@;N1K>6WD;B!PY&EV:71Y:W-E;B!J82!M=6ET82!NY&MY;>3D;B!L
M:6ET='EV:>0@87-E='5K<VEA+@!!<V5T=7-T96X@<.1I=FET>7,@;VYN:7-T
M=6DN`$%S96YN=7,`07-E;FYU:W-E;B!PY&EV:71Y<W-K<FEP=&D@;VX@<V%A
M=&%V:6QL80!5<V5A="!P86EK870@<V]P:79A="!A;FYE='1U=6X@<&%R86UE
M=')I:6XZ(`!397EC:&5L;&ET`$]S=&]K<V5T`$QY:'ET(&MU=F%U<SH`07-E
M=&5T82!P:6MA=F%L:6YT86[D<'#D:6UE="!U<V5I;6UI;&QE(&QI;FME:6QL
M92X`3N1Y=.0`3N1Y=.0@86MT:6EV:6YE;B!S:W)I<'1I`$[D>73D(&YY:WEI
M;F5N('-K<FEP=&D`3N1Y=.0@97)O879A:7-U=61E="!A<V5T=6MS:65N('1A
M;&QE=&5T=7-S82!J82!U=61E<W-A(&IU=7)I(&UU;VMA='5S<V$@=F5R<VEO
M<W-A+@!.Y'ETY"!E9&5L;&ES96X@<VESY.1N:VER:F%U='5M:7-E;B!PY&EV
MY'ES+@!.Y'ETY"!A<V5T=7,@<&ETY.1K<V5S:2!A;&MU<&5RY&ES96X`3N1Y
M=.0@=F%L:71S:6X`3N1Y=.0@=&%U;'5K:V]T;VEM:6YN;W0@=F%L:6MK;RX`
M3N1Y=.0@=F%S96UM86QL82`E<R!V86QI:VMO+@!.Y'ETY"!T875L=6MO;B!S
M;VQU;B!T:65D;W0@9&EA;&]G:0!.Y'ETY"!T875L=6MO;B!T:65D;W0@9&EA
M;&]G:0!.Y'ETY"!T875L=6MO;B!R:79I;B!T:65D;W0@9&EA;&]G:0!.Y'ET
MY"!K=79A;B!T:65D;W0@9&EA;&]G:0!.Y'ETY"!T=6]N=&D`4V%T96ET80!3
M871E:71A(&%I:V%I<VEN`%-A=&5I=&$@;7GV:&5M;6EN`%-A=&5I=&$@;.1H
M971T>79I;&QA`%!I96YE;F[D`%!I96YE;F[D('1A:2!S:6ER<N0@=FEE<F5I
M<VGD(&]S:6]I=&$L(&IO='1A(&YE(&5I=N1T(&]L92!T:65L;.0`4VEE<G)A
M($QE;VYE`$MI<FIA=61U`$%L;&5K:7)J;VET=7,`06QL96MI<FIO:71U:W-E
M;B!A;&=O<FET;6D`4VEN9V%P;W)E`$MO:V\`3VAI=&$@>6QLY'!I=&]T96AT
MY';D=`!3;&]V86MI80!3;&]V96YI80!,=6UI`$QU;6ES861E='1A`$QU;6ES
M871E:71A`$QU;6ES871E:71A(&%I:V%I<VEN`$QU;6ES871E:71A(&UY]FCD
MY&X`3'5M96X@<WEV>7ES.B``3'5M96X@;>3D<N0@=F5T96[D.B``4V%L;VUO
M;B!S86%R970`4V]M86QI80!,875L=70@:F$@4G5N;W5S`$KD<FIE<W1Y:W-E
M;B!S=75N;F%N('9A;&EN=&$`3.1H9&5O<V]I=&4`171E;.0M069R:6MK80!%
M=&5LY"U%=7)O;W!P82`H25-/+3@X-3DM,RD`171E;.0M1V5O<F=I82!J82!E
M=&5LY&ES970@4V%N9'=I8V@@<V%A<F5T`$5T96SD:6YE;B!P86QL;VYP=6]L
M:7-K;P!6Y&QI('9I97)E:7-E="!S;VQU:F5N(';D;&ES<^0`5N1L:2!S;VQU
M;B!L96EPY'1E:W-T:6X@:F$@<F5U;F%N(';D;&ES<^0@`%;D;&D`5N1L:0!6
MY&QI(&IA('3D>71E`$5S<&%N:F$`4F]S:V%P;W-T:0!%<FEK;VES;65R:VMI
M96X@<WGV='3V`$IA82!S;VQU`$IA82!S87)A:V4`2F%A(')I=FD`57)H96EL
M=0!3<FD@3&%N:V$`4W1A;F1A<F1I`%-T87(@5')E:P!!;&MA;6ES=G5O<VD`
M3.3D;FD@=&%I(&%L=64`5&EL80!,;W!E=&$@=&%R:VES='5S(&IO<R!TY&WD
M('/DY&YT]B!S;W!I:2X`5&%L;&5N;G5S;75O=&\`2V%T=6]S;VET90!,Y'!I
M;'GV;G1I`$UE<FMK:6IO;F]L:7-T80!0;VES=&$@=&]I;6EA;'5E(&]S;VET
M=&5E<W1A`%1Y>6QI(%M#4U-=`'-U`$%L:6AA:V5M:7-T;V$@(B5S(B!E:2!L
M]GET>6YY="X`4%]O:7-S86]L;W9I97-T:6X@;W1S:6MK;SH`3W1S:6MK;P!/
M='-I:VMO.@!,Y&AE=.0`3.1H971E='1I:6X@(B5S(CIN(&QI<^1Y<W!Y>6YT
M]BX@170@=F]I(&MI<FIA=71U82!S:7/DY&X@96YN96X@:W5I;B!P>7EN=/9S
M:2!O;B!KY'-I=&5L='D@:F$@:'EVY&MS>71T>2X`06QI:VER:F]I='5S`$]N
M;FES='5I`"(E<R(Z(&QI<^3D;6EN96X@:N1R:F5S=&5L;>3D;B!O;FYI<W1U
M:2X`2^1Y='3D:N1N("(E<R(@:^1Y='3D:N1T:65T;VIE;B!P;VES=&%M:6YE
M;B!JY')J97-T96QMY'-TY"!O;FYI<W1U:2X`(B5S(B!P;VES=&5T=&EI;B!O
M;FYI<W1U;F5E<W1I+@`B)7,B.B!O;FYI<W1U='1I:6X@<&]I<W1A;6%A;B!J
MY')J97-T96QMY'-TY"X`4&%L871T:6EN(&]N;FES='5N965S=&D@=F%N:&]I
M:&EN(&%S971U:W-I:6XN($QA=&%A('-I=G4@=75D97-T86%N(&[D:&3D:W-E
M<VD@;75U=&]K<V5T+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U
M<VMO<&EO+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U<VMO<&EO
M("5S+@`G)7,G.B!PY&EV:71Y<R!O;FYI<W1U:2X`)7,Z;B!K:7)J;VET=&%M
M:6YE;B!O;FYI<W1U:2X`4W5D86X`66AT965N=F5T;P!!=7)I;F=O;FYO=7-U
M`$%U<FEN9V]N;&%S:W4`075R:6YK;VEN96X`075R:6YG;VYN;W5S=0!!=7)I
M;FMO(&YO=7-E92]L87-K964`075R:6YG;VYN;W5S=3H@`$%U<FEN9V]N;&%S
M:W4`075R:6YG;VYL87-K=3H@`%#DY&QL96MI<FIO:71U<P!4=6MI`%-U<FEN
M86T`4W5K=6YI;6D`2'5I<'!U=G5O<F5T(&IA($IA;B!-87EE;@!3=V%Z:6UA
M80!2=6]T<VD`4W9E:71S:0!3>6YC(&QO:VD@<&]I<W1E='1U`%-Y;F--3`!3
M>6YT86MS:79I<FAE(&AA:W5T97)M96ES<^0`4WEY<FEA+"!A<F%B:71A<V%V
M86QT80!5:VMO<VUY<G-K>0!5:VMO<VUY<G-K>6KD(&IA('1U=6QI<W1A`%5K
M:V]S;7ER<VMY=`!5:VMO<VUY<G-K>6KD(&%I:V%I<VEN`%135BUT:65D;W-T
M;P!4875L=6MK;P!4875L=6MO;B!T:65D;W0`5&%U;'5K;VX@87-E='5K<V5T
M`%1A=6QU:V]N('1I961O=`!486EW86X`5&%I=V%N+"!+:6EN86X@;6%A:W5N
M=&$`5&%D>FEK:7-T86X`5&%N>F%N:6$L(%EH9&ES='EN>70@=&%S879A;'1A
M`$MO:&1E.@!496ATY';D=`!0=6AE;&EN;G5M97)O`$SD;7#V=&EL82!E9&5L
M;&ES96QL92!T=6YN:6QL93H@`$SD;7#V=&EL80!,Y&UP]G1I;&$Z(`!,Y&UP
M]G1I;&$\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!-86QL:6$@(B5S
M(B!E:2!L]GET>6YY="X`36%L;&EE;B!H86QL:6YT80!496MS=&D`5F%I;B!T
M96MS=&D`5&5K<W1I;B!T87-A=7,`5&5K<W1I=&]P`'1O`%1H86D@*%1)4RTV
M,C`I`%1H86EM86$`1E10+6QI<^1T;VEM:6YT;R!E:2!O;&4@:^1Y=&5T=.1V
M:7-SY"X`2&ES=&]R>2!JY')J97-T96QMY"!E:2!O;&4@:^1Y=&5T=.1V:7-S
MY"X`2&]R9&4O2V]L86(@:6YT96=R;VEN=&EM;V]T=&]R:2!E:2!T=64@(B5S
M(@!)35-0(&QO:VEA(&5I('9O:71U(&%L=7-T86$N`$UA:6YT96YA;F-E.CH@
M+6QU;VMA;B!L871A86UI;F5N(&5PY&]N;FES='5I`$%S971U:W-E="!I:VMU
M;F$@;VX@<W5L:F5T='4N(%!O:7-T=71A86XN`$]S;VET92`B)7,B(&]N(&QI
M<^1T='D@;75S=&%L;&4@;&ES=&%L;&5S:2X`3W-O:71E("(E<R(@;VX@;&ES
MY'1T>2!V86QK;VES96QL92!L:7-T86QL97-I+@!9;&SD<&ED;VX@<&ETY.0@
M;W1T86$@:^1Y='3V]FX@<'ES>7;D('1A;&QE='5S='EY<'!I(%!E<FUI<W-I
M;VXL(&IO<R!H86QU870@:^1Y='3DY"!N:6ETY"X`5F%I;B!A;&%P=6]L:0!#
M;VYT86-T(&ED(&YU;65R;V$@96D@;VQE(&WDY')I=&5L='DL(&]N('1Y:&KD
M('1A:2!E:2!L]GET>6YY="!T:65T;VMA;FYA<W1A+@!9:'1E>7-T:65D;W0@
M;&ESY'1T:6EN(&]N;FES='5N965S=&D@;W-O:71E:VER:F%A<VDN`%9I97-T
M:6X@86QL96MI<FIO:71U:W-E;B!T87)K:7-T86UI<V5E;B!T87)V:71A86X@
M97)I;&QI;F5N(%!'4"UA;&QE:VER:F]I='5S;&]H:V\N`$IA:V5L=6QI<W1A
M;B!)1"!E:2!O;&QU="!MY.1R:71E;'1Y+"!O;B!T>6AJY"!T86D@96D@;/9Y
M='EN>70@=&EE=&]K86YN87-T82X`2F%K96QU;&ES=&%A(&5I(&]L;'5T(&WD
MY')I=&5L='DN`$%J=7)I;B!V:7)H96EL;6]I='5S(&]L:3H@`%-A;&%U<W1O
M:6UI;FYO;B!KY'ET=/8@=F%A=&D@<V%L871T=6$@5U=7+7EH=&5Y='3D+@!4
M:65D;W-T;W-S82`E<R!P:73D:7-I(&]L;&$@)7,@87-E='5S+@!4:65D;W-T
M;W-S82`E<R!P:73D:7-I(&]L;&$@:F]I=&%K:6X@)7,@87-E='5K<VEA+@!4
M:65D;W-T;V$@96D@=F]I9&$@:V]P:6]I9&$@:71S96YSY"!PY.1L;&4N`%1I
M961O<W1O(&]L:2!T>6AJY"X`4V5U<F%A=F%S<V$@;VX@;W1S:6MK;W1I961O
M="!TY'-TY"!M97-S86=E+W)F8S@R,B`M=FEE<W1I<W3D+@!+;VMO<G5U9'5N
M(&[D>71T]G1I;&$@86EH975T=&%A(&]N9V5L;6EA(&IO:6QL86MI;B!);G1E
M<FYE="!%>'!L;W)E<B!S96QA:6UE;B!KY'ET=.1J:6QLY"X@5F%L:71E='1A
M=F%S=&D@:WES96EN96X@<V5L86EN('-I<^1L=.3D('!I:7)T96ETY"!J82!V
M:7)H96ETY"!J;VEH:6X@96D@;VQE(&SV>71Y;GET(&MO<FIA=7-T82!T86D@
M:V5I;F]A(&MI97)TY.0@;VYG96QM82X@2'5O;6%A=&AA;B!E='3D(&IO<R!K
MY'ETY'0@=.1TY"!NY'ET=/9T:6QA82!J82!);G1E<FYE="!%>'!L;W)E<B!S
M96QA:6YT82P@;FEI;B!NY'ET=/8@<V%A='1A82!M96YNY"!S96MA:7-I;BP@
M:F]T:W5T('1O:6UI;FYO="!E:7;D="!T;VEM:2!T86D@<V5L86EN('-A871T
M86$@:V%A='5A+B!*;W,@:^1Y=.1T(%=I;F1O=W,@.7@@=&%I($U%('9E<G-I
M;W1A+"!N:6EN(&]N(&UA:&1O;&QI<W1A(&5T=.0@:^1Y='3V:N1R:F5S=&5L
M;>0@:V%A='5U(&YS+B`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R`M=FER
M:&5E<V5E;B!J82!S:6YU;B!P:73DY"!KY'EN;FES=.3D(&MO;F4@=75D97-T
M86%N+EQN7&X@375I<W1A(&5T=.0@<VEN=6$@;VX@=F%R;VET971T=2X@3F%P
M<V%U=&$@3TLM;F%P<'5L86$@:F]S(&AA;'5A="!K;VME:6QL92!E9&ET;W)I
M;B!K;VMO<G5U='4@;N1Y='3V=&EL86$N`%!O:7-T971T:6EN('!R;V9I:6QI
M("(E<R(N`%9A:6X@=F%S96X@<'5O;&D`1VYU4$<@;VAJ96QM86X@<VEJ86EN
M=&D@<&ETY.0@;>3D<FET96QLY"!#<GEP=%]P9W`Z.B`M;'5O:V%S<V$N`%9I
M97-T:2!LY&AE=&5T='D@)7,@=F%S=&%A;F]T=&%J86QL92`E<R!O='-I:VMO
M;F$@(B5S(B!O;B!NY'ET971T>2X*16D@;VQE(&UI=.3D;B!T86ME:71A('-I
M:73D(&5T=.0@=FEE<W1I(&]N(&QU971T=2!T86D@>6UMY')R971T>2X`3FEM
M:2!J;W1A(&OD>71E=.3D;B!L:6YK:71E='3D97-S82!L=6\@<VEV=6QL90!+
M96YT=&EE;B!MY.1RY"!P:73DY"!A;G1A82!N=6UE<F]I;F$N`$UO9'5U;&D@
M;W!E;G-S;"!T87)V:71A86X@2&]R9&5?0W)Y<'1?<VUI;64Z.B`M;'5O:V%N
M(&OD>71TY&UI<V5K<VDN`$%S971U<W1A("(E<R(@:V]S:V$@<V5N('1I961O
M="!Y;&ET=&EVY'0@=&%L;&5T=7-T879A;B!S=75R:6UM86X@<V%L;&ET=6X@
M<F%J86X`3VAJ96QM86$L(&IO;&QA('9O:2!K871S;V$@=FEE<W1I='EY<'!I
MY"`H)7,I+"!E:2!L]GET>6YY="!JY')J97-T96QMY'-TY"X`3&%I;F%U<VUE
M<FMK:2!P:73DY"!O;&QA('EK<VET=.1I;F5N(&UE<FMK:2X`5F%I;B!O:6ME
M82!J82!V87-E;B!P=6]L:0!686EN(&]I:V5A('!U;VQI`$5R;W1I;B!P:73D
MY"!O;&QA('EK<VET=.1I;F5N(&UE<FMK:2X`4&%L=F5L:6X@(B5S(B!O;B!P
M;VES=&5T='4N`%!A;'9E;&EN("(E<R(@;VX@=&%L;&5T971T=2X`4VESY.1N
M:VER:F%U='5M:7-P>7EN=/8@)7,@;VX@<&]I<W1E='1U+@!-Y.1R:71E;'1Y
MY"!R:79IY"`H)60I(&5I(&]L92!O;&5M87-S82X`5F%L:>1A:6MA:7-T:65D
M;W-T;V$@(B5S(B!E:2!O;&4@;VQE;6%S<V$N`$MI<FIO:71T86UA<VD@=&5K
M<W1I(&5I('9A<W1A82!T96MS=&GD(')U=61U;&QA+@!686EN('ELY'!U;VQI
M(&IA(&%L87!U;VQI`%9A:6X@>6SD<'5O;&D`5'5O='4@=&EE=&\@:.1V:7-I
M(&5D96QL:7-E;B!K;VAD86X@86EK86YA+@!4=6]T=6$@=&EE9&]S=&]A(&5I
M('9O:71U('1A;&QE='1A82X`3W-I;W1A('=E871H97(N8V]M(&5I(&]L92!K
MY'ET971TY'9I<W/D+@!4965M86AA:V5M:7-T;V$@(B5S(B!E:2!L]GET>6YY
M="X`07-E='5K<VEA(&5I(&]L92!S86%T879I;&QA+@!%:2!O;&4@;W-I;VET
M82P@:F]T:V$@=F]I9&%A;B!NY'ET=.3D('9I97-T:65N('EH=&5Y9&5S<^0N
M`%3D<W/D(&ME;G3D<W/D(&]N(&QI:6%N(&UO;G1A(&UE<FMK:>0N($%N;F]I
M="`E<R!M97)K:VGD.R!S:6YU;B!P:73DY"!A;G1A82!VY&AE;6WD;B!K=6EN
M("5S(&UE<FMK:>0N`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@;&ESY.1M:7-E
M<W/D(&KD<FIE<W1E;&WDY&XZ("5S`$OD>71TY&KD;B`B)7,B(&OD>71TY&KD
M=&EE=&]J96X@<&]I<W1A;6ES97-S82!JY')J97-T96QMY'-SY"!O;&D@;VYG
M96QM:6$Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('!O:7-T86UI<V5S<V$@
M:N1R:F5S=&5L;>1S=.0Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('#D:79I
M='EK<V5S<^0Z("5S`%1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L;6EA
M+B!9:'3DY&X@)7,Z82!E:2!T=6]T=0!4:65D;W-T;VX@='5O;FYI<W-A(&]L
M:2!O;F=E;&UI82X@)7,@:V]K;R!O;&D@<W5U<F5M<&D@:W5I;B!S=75R:6X@
M<V%L;&ET='4@:V]K;R`H)60@=&%V=6$I+@!4:65D;W-T;VX@='5O;FYI<W-A
M(&]L:2!O;F=E;&UI82X@)7,@;&%T875T=6D@=F%I;B!O<V%K<VDN`%-K<FEP
M=&EN(&%K=&EV;VEN;FES<V$@=&%P86AT=6D@=FER:&4N`%-K<FEP=&EN(&5I
M+6%K=&EV;VEN;FES<V$@=&%P86AT=6D@=FER:&4N`%1A<&%H='5I('9I<FAE
M(&[D>71E='3D97-SY"!V:65S=&EN('3D=.0@;W-I;W1A`%EH=&5Y<W1I971O
M:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`:4-A;&5N9&%R+71I971O
M:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`07-E='5S=&EE=&]L;VUA
M:VME97-S82!O;B!J;VMI;B!V:7)H92X@16AKY"!JY'1I="!J;VYK=6X@<&%K
M;VQL:7-E;B!K;VAD86X@=.1Y='3D;>1T=.0N`%1A<&%H='5I('9I<FAE('ER
M:71E='3D97-SY"!S=6]R:71T86$@;W-O:71E:VER:F%T;VEM:6YT;V$N(%ER
M:73D(&UY]FAE;6UI;B!U=61E<W1A86XN`%EH=&5Y<W1I971O:F5N('#D:79I
M='EK<V5S<^0@=&%P86AT=6D@=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U=61E
M<W1A86XN`$IA:V5L=6QI<W1A;B!PY&EV:71Y:W-E<W/D('1A<&%H='5I('9I
M<FAE+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N+@!4Y&WD($E-05`@<&%L
M=F5L:6X@96D@='5E(&MA;G-I;VED96X@:F%K86UI<W1A+@!4Y&WD('1I961O
M<W1O(&5I('9A:6MU=&$@<F%R+71I961O<W1O;'1A+@!4Y&WD('1I961O<W1O
M(&5I('9A:6MU=&$@>FEP+71I961O<W1O;'1A+@!4Y&WD(&5I('9A:6MU=&$@
M;VEK96%L=&$@:V]R='1I;G5M97)O;'1A+@!4Y&QLY"!A:G5R:6QL82!V;VD@
M;.1H971TY.0@=FEE<W1E:N0@0VQI8VMA=&5L;&EN("AH='1P.B\O8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87D@<&%L=F5L=6$@2%144"!!4$DZ;&QA+@!4Y&QL
MY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@9V%T97=A>2!P86QV96QU;B!K875T=&$@2%144"!!4$DZ
M;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@<VUS
M,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2!P86QV96QU
M;B!K875T=&$@2%144"!!4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H
M971TY.0@=FEE<W1E:N0@5F]D869O;F5N(&YU;65R;VEH:6X@4TU44#IL;.0@
M:^1Y='3D96X@5F]D869O;F4@271A;'D@9V%T97=A>2!P86QV96QU82X@5.1T
MY"!P86QV96QU82!V;VD@:^1Y='3DY"!V86EN(%9O9&%F;VYE($ET86QY("AH
M='1P.B\O=W=W+C$Y,"YI="D@='5N;G5K<VEL;&$N`%3D;>0@:V5N='3D(&]N
M('!A:V]L;&EN96XN`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@=F%I;B!K
M;VMO;F%I<VQU:W5J82X`5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!N=6UE
M<F]I=&$@:F$@<&EL:VMU+6UE<FMK96KD+@!4Y'-SY"!K96YTY'-SY"!P:73D
MY"!O;&QA(&]K=&%A;&EL=6MU:F$N`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L
M;&$@;&ES=&$@:V]K;VYA:7-L=6MU:F$L(&IO=&MA('!I=.3D(&]L;&$@97)O
M=&5T='4@<&EL:W5L;&$@=&%I(';D;&EL>?9N;FEL;.0`07)V;VX@<&ETY.0@
M;VQL82!N=6UE<F\N`%3D<W/D(&ME;G3D<W/D(&]N(';D<FEMY.1R:71Y<RP@
M:F]N:V$@<&ETY.0@;VQL82!21T(@2&5X(&UU;V1O<W,L(&5S:6UE<FMI:W-I
M("<C,3(S-&%F)RX`5.1MY"!L;VUA:V4@;VX@:F\@:^1S:71E;'1Y+@!4Y&WD
M(&]N("5S+@!4Y&WD(&]N($MO;&%B($=R;W5P=V%R92!O8FIE:W1I+B!+871S
M;V%K<V5S:2!TY&WD;B!O8FIE:W1I;B!S:6YU;&QA('!I=.3D(&]L;&$@<^1H
M:_9P;W-T:6]H:F5L;6$L(&IO:V$@>6UMY')TY.0@2V]L86(@1W)O=7!W87)E
M(&9O<FUA871T:6$N($QI<W1A('EH=&5E;G-O<&EV:7-T82!SY&AK]G!O<W1I
M;VAJ96QM:7-T82!L]GET>7D@;W-O:71T965S=&$@)7,`5.1MY"!V:65S=&D@
M;VX@:VER:F]I=&5T='4@97)I(&UE<FMI<W3V;&SD("@E<RD@:W5I;B!M:6OD
M('-I;G5L;&$@;VX@:^1Y=/9S<^0N(`!.=6UE<F]N('!I=.3D(&]L;&$@=N1H
M:6YTY.1N('EK<VDN`%3D;&SD('!A;'9E;&EM96QL82!E:2!V;VD@875K86ES
M=&$@>FEP+2!T86D@9WII<"UT:65D;W-T;VIA+@!4Y&WD(&KD<FIE<W1E;&WD
M(&]N('!O:7,@<.3D;'3D+@!!<G9O;B!P:73DY"!O;&QA(&YU;65R;RX`5.1M
MY&X@:6MK=6YA;B!V;VD@875K86ES=&$@=F%I;B!!<V5T=6MS970@:6MK=6YA
M<W1A`$UY<G-K>0!4:6ME=&ET`$%I:V$`06IA;G-E=7)A;G1A`$%J86X@97-I
M='ES;75O=&\`06IA;B!V86QI;G1A`%1I;6]R+4QE<W1E`%1I='1E;&D`3W1S
M:6MK;R`H=&]O;'1I<"DZ`%9A<W1A86YO='1A:F$`5F]I9&%K<V5S:2!V86QI
M=&$@=7-E86UP:6$@=F%I:'1O96AT;VIA+"!P:63D($-O;G1R;VPM("A00RD@
M=&%I($-O;6UA;F0M("A-86,I(&[D<'#D:6YTY"!P;VAJ87-S82!K=6X@;F%P
M<V%U=&%T(&AI:7)E;B!P86EN:6ME='1A+@!687-T86%N;W1T86IA.@!4Y&[D
MY&X`3N1Y=.0@2%1-3"ULY&AD96MO;V1I`%1O9V\`5&]K96QA=0!(=6]M96YN
M80!4;VYG80!,:6EA;B!M;VYT82!E<.1O;FYI<W1U;G5T=&$@:VER:F%U='5M
M:7-Y<FET>7-TY"!V:6EM96ES:6UP:65N(&UI;G5U='1I96X@:W5L=65S<V$N
M`%EL]G,`66QI;7#DY&X@:V5H>6MS965N("A?=&]P*0!+Y.1N;O9K<V5T`%1R
M:6YI9&%D(&IA(%1O8F%G;P!4;W-I('9A:2!E<.1T;W-I`'1I`%1U;FES:6$`
M5'5R:VMI`%1U<FMK:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS
M(&IA($-A:6-O<R!S86%R970`5'5V86QU`$MI<FIO:71A('9A;&EN=&%S:3H@
M`%4N5BX@+6EN9&5K<VDZ(`!54DP`55),(&IO:&]N('!A;&%U=&5T86%N('-K
M<FEP=&EN('-T871U<R!R87!O<G1T:0!54DPZ`%5G86YD80!5:W)A:6YA`%9&
M4RUH86ME;6ES=&]A(&5I('9O:71U(&QU:V5A+@!+Y'ET=.1JY&X@;&ESY'1I
M971O:F5N(&QI<^1Y<R!E:2!O;FYI<W1U;G5T(&MI<FIA=71U;6ES97-S82X`
M16D@=F]I('9A:6AT86$@;VEK975K<VEA(%9&4RUT:65D;W-T;VQL92`B)7,B
M+@!%:2!V;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE("5S
M+R5S+@!%:2!V;VED82!V86EH=&%A("5S.FXN`%1I961O<W1O;B`B)7,B(&MO
M:V]A(&5I('9O:71U('1A<FMI<W1A82X`16D@=F]I9&$@;FEM973D('5U9&5L
M;&5E;B!61E,M=&EE9&]S=&]A("(E<R\E<R(N`%-13"UP86QV96QI;65E;B!E
M:2!S86%D82!Y:'1E>71TY"X`66AT97ET=.0@96D@=F]I9&$@;75O9&]S=&%A
M(%-33"US86QA='1U;F$N`%9&4RUT:65D;W-T;V$@96D@=F]I9&$@:V]P:6]I
M9&$N`$5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A("(E<R(N`$5I('9O
M:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A+@!%:2!V;VET=2!L=6]D82!61E,M
M=&EE9&]S=&]A`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+6MA;G-I
M;W1A("(E<R(N`$5I('9O:71U(&QU;V1A('1Y:&KDY"!61E,M=&EE9&]S=&]A
M+@!4:65T;V$@96D@=F]I9&$@;&%A:F5N=&%A+@!%:2!V;VED82!P;VES=&%A
M("(E<R(L(&AA:V5M:7-T;R!E:2!O;&4@='EH:N0N`$5I('9O:61A('!O:7-T
M86$@(B5S(CH@)7,N`$5I('9O:61A('!O:7-T86$@)7,L(&AA:V5M:7-T;R!E
M:2!O;&4@='EH:N0N`$5I('9O:61A('!O:7-T86$@5D93+6AA:V5M:7-T;V$@
M<F5K=7)S:6EV:7-E<W1I+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES
M=&]A+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A.B`E<RX`16D@
M=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A('!O
M:7-T86$@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M:V%N
M<VEO=&$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82!61E,ZY.0@<F5K=7)S:6EV
M:7-E<W1I.B`E<RX`3GEK>6ES=.0@:&%K96UI<W1O82!E:2!V;VET=2!S96QV
M:71TY.0N`%9A<FUE;G1E96X@=&EE=&]J82!E:2!V;VED82!E>'1R86MT;VED
M80!-Y.1R:71Y:W-E;B`E<R!L=6ME;6EN96X@97#D;VYN:7-T=6DN`$5I('9O
M:61A('-I:7)TY.0@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!6
M1E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&%V871A(%9&4RUT:65D;W-T
M;V$@:VER:F]I='5S=&$@=F%R=&5N+@!%:2!V;VED82!A=F%T82!61E,M=&EE
M9&]S=&]A+@!4:6EV:7-T971Y;B!T:65D;W-T;VX@875K86ES=2!E<.1O;FYI
M<W1U:2X`16D@=F]I='4@;'5K96$@5D93+71I961O<W1O82`H9FEL97-I>F4H
M*2!E<.1O;FYI<W1U:2DN`$5I('9O:61A(&QU:V5A(%9&4RUT:65D;W-T;V$@
M*&=E=$9I;&53:7IE*"D@97#D;VYN:7-T=6DI+@!%:2!V;VET=2!L=6ME82!T
M:65D;W-T;V$Z(`!V9G-R;V]T(&IU=7)I:&%K96UI<W1O82!E:2!V;VET=2!L
M=6ME82X`575D96QL965N;FEM9>1M:6YE;B`E<R`E<SIK<VD@97#D;VYN:7-T
M=6D@:V]S:V$@:V]H9&5H86ME;6ES=&\@;VX@:F\@;VQE;6%S<V$`16D@=F]I
M9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O82X`16D@=F]I9&$@
M;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O83H@)7,N`$5I('9O:61A
M(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82`B)7,B+@!%:2!V;VED
M82!N:6UE=.0@=75D96QL965N(%9&4RUT:65D;W-T;V$@)7,O)7,N`$5I('9O
M:71U(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82X`16D@=F]I9&$@
M<W5O<FET=&%A(&MO;65N=&]A("=M:VES;V9S)RX`5V]R9"UD;VMU;65N='1I
M82!E:2!V;VET=2!KY.1N=.3D`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I
M961O<W1O82`B)7,B+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T
M;V]N("AC;W!Y*"D@97#D;VYN:7-T=6DI+@!%:2!V;VED82!K:7)J;VET=&%A
M(%9&4RUT:65D;W-T;VX@=&EE=&]J82X`16D@=F]I9&$@:VER:F]I='1A82!6
M1E,M=&EE9&]S=&]A+"!K:6EN=&GV(&]N('3D>6YNY"X`06QL979I:79A='1U
M`%!E<G4@;75U=&]K<V5T`%!E<G5U='1A82!E9&5L;&ES96X@=&]I;65N<&ET
M965N`%1U;G1E;6%T;VX@=F%S=&%U<R!P86QV96QI;65L=&$@>6AT97ET965N
M.@!4=6YT96UA=&]N('9A<W1A=7,@<&%L=F5L:6UE;'1A.B``3'5O:VET=&5L
M96UA=&]N`%5N:6-O9&4@*%541BTX*0!9:&1I<W1Y;F5E="!A<F%B:65M:7)A
M871I=`!9:&1I<W1Y;F5E="!K=6YI;F=A<VMU;FYA=`!9:&1Y<W9A;&QA=`!9
M:&1Y<W9A;'1O:F5N(%1Y>6YE;FUE<F5N(&5R:6QL:7-S86%R970`36ET=&%Y
M:W-I:_9T`%1U;G1E;6%T;VX`5'5N=&5M871O;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+@!4=6YT96UA=&]N(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN`$%N;F5T='4@<&%I:VMA=&EE=&\@;VX@='5N=&5M871O;BX`5'5N
M=&5M871O;B!KY'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$N`%!O:7-T82!N
M>6MY:7-E;B!E;&5M96YT:6X@;&EN:VET>7,`3FEM973V;@!4:65T;W1U<G9A
M<WEI<W3D(&5I+7!R:79I;&5E9VES970@<VMR:7!T:70@96EVY'0@=F]I(&MU
M='-U82!,96EK:V%A+TMO<&EO:2],:6ETY"!T;VEM:6YT;VIA+B!.87!S875T
M82!/2RUN87!P=6QA82!NY&ADY&MS97-I(&UO>FEL;&$N;W)G('-I=G5I;&QA
M(&]L979A;B!O:&IE96XL(&IO<W-A(&YE=79O=&%A;B!M:71E;B!S:W)I<'1I
M<VD@=F]I=F%T(&OD>71TY.0@;&5I:V5P]GETY.0N`%!O:7-T82!VY')I`$5I
M+71U971T=2!L86%J96YN=7,`4.1I=FETY`!0Y&EV:73D("5S`%#D:79I=.0@
M:^1Y='3D:N0`4.1I=FET971T:6EN("(E<R(N`%#D:79I='ES<VMR:7!T:2!P
M;VES=&5T=&EI;BX`5'5O`'1U;R!K86EK:VD@;VAJ96QM:65N(&%S96YN=7-T
M:65D;W-T;W0@<&%L=F5L:6UE;&QE+@!)<V]T(&QA=&EN86QA:7-E="!K:7)J
M86EM970`27-O="!R;V]M86QA:7-E="!N=6UE<F]T`%5R=6=U87D`2^1Y=.0@
M;GEK>6ES=.0Z("5S`$OD>73D(%-33"US86QA=7-T80!+Y'ETY"!J;W,@='5N
M;G5S+W-A;&%S86YA(&]N(&5R:2!)35-0+7!A;'9E;&EM96QL92X`2^1Y='3D
M:N0`2^1Y='3D:N1L;.0@)7,@96D@;VQE(&]I:V5U:W-I82!T96ADY"`E<RX`
M2^1Y='3D:FEE;B!Y;&SD<&ET;P!+Y'ET=.1JY&X@87-E='5K<V5T`$OD>71T
MY&KD;B!R96MI<W1E<O9I;6EN96X`5.1S<^0@:N1R:F5S=&5L;>1S<^0@96D@
M=F]I(')E:VES=&5R]FEDY"!KY'ET=.1J:>0N`$OD>71TY&KD='5N;G5S=&$@
M96D@;/9Y='EN>70N`$OD>71TY&KD='5N;G5S`$OD>71TY&KD='5N;G5S("(E
M<R(@;VX@:F\@;VQE;6%S<V$N`$OD>71TY&KD='5N;G5S.@!+Y'ET=.1JY'1U
M;FYU<SH@`$KD<FIE<W1E;&WD;B!KY'ET=.1JY'0Z`%5Z8F5K:7-T86X`5D93
M+6AA:V5M:7-T;V$@96D@;VQE(&]L96UA<W-A+@!0;VES<V%O;&]V:65S=&D`
M4&]I<W-A;VQO=FEE<W1I;B!M=6]K:V%U<P!+Y'ET]G-SY"!O;&5V82!S=6]D
M871I;F%J=7)I(&5I('1U92!P;VES<V%O;&]V:65S=&5JY"X`4&%I:VMO:F$@
M;/9Y='EI(&5S:6UE<FMI:W-I.B``5F]I;6%S<V%O;&]A:6MA`$%R=F\@;6EN
M=75T96ES<V$@;GEK>6AE=&ME<W3D+@!!<G9O(&]N('EL:2!P:71U=61E;B!M
M86MS:6UI87)V;VX@)7,N/`!!<G9O=`!686QI='1A=F%T(&%R=F]T`%9A;G5A
M='4`5F%I:'1E;&5V86$`5F5N97IU96QA`%1A<FMI<W1U<R!E<.1O;FYI<W1U
M:2`M(%3D=.0@=FEE<W1IY"!O;B!V;VET=2!KY'-I=&5L;.0N`%9E<G-I;P!6
M97)S:6]N:&%L;&EN=&$`4'ES='ES=6]R82!T87-A=7,`4'ES='ES=6]R82!T
MY'ET90!0>7-T>7-U;W)A.@!%<FET=.1I;B!K;W)K96$`5FEE=&YA;0!6:65T
M;F%M("A625-#24DI`$[D>73D("5S`$[D>73D(&5R:6QL:7-E;N0@=W=W+7-I
M=G5N80!.Y'ETY"`E<P!.96ET<WET<V%A<F5T+"!"<FET=&ELY&EN96X`3F5I
M='-Y='-A87)E="P@66AD>7-V86QT86EN`$[D:WEVY&ES>7ES`$[D:WEVY&ES
M>7ES.B``5F]D869O;F4@271A;'D@4TU44#IN(&%V=6QL80!605)/25154P!6
M05)/25154R$A(2!03TE35$$@4TM225!422!+Y%-)3B!004Q614Q)345,5$$@
M)7,N`%=)3B!(5%10.FX@879U;&QA`%=A;&QI<R!J82!&=71U;F$`5F%R;VET
M=7,`:V4`4^3D96YN=7-T90!3Y.1T:65D;W0@;VX@=&]I;6ET=&%N=70`5V5A
M=&AE<BYC;VT`5U=7`%=75RUS:79U<W1O`%9I:6MO:71T86EN`%1E<G9E='5L
M;V$`5&5R=F5T=6QO82!O:&IE;&UA86X@)7,`5&5R=F5T=6QO82P@)7,`3.1N
M<VEM86EN96X@*$E33RTX.#4Y+3$I`$SD;G-I;6%I;F5N+T5U<F\@*$E33RTX
M.#4Y+3$U*0!,Y&YS:2U386AA<F$`5F%L:V]?:7-E;B!L:7-T86X@;W-O:71T
M965T.@!-:6YKY"!O:&IE;&UA;B`E<R!KY'EN;FES=.3D('-I<^3D;FMI<FIA
M=71U;6ES96X@:N1L:V5E;BX`36ETY"!M97)K:VGD(&OD>71E=.3D;B!E<F]T
M=&EM96YA/P!-:73D(&UE<FMK:>0@:^1Y=&5TY.1N(&QA:6YA=6MS965N/P!7
M:&5R96ES($%U<W1R86QI86X@:V%R='1A`$UI=&OD('9A:6AE970`5F]I="!M
MY.1R:71E;&SD(&QI<^1T;VEM:6YT;VIA(&QA:71E=&%A;B!PY.1L;&4@4FEC
M:"!497AT(&5D:71O<FES<V$N`%9A;&MO:6YE;B!L:7-T80!686QK;VES96X@
M;&ES=&%N(&UU;VMK875S`$OD>73V<W/D(&]L979A(&%J=7)I(&5I('1U92!V
M86QK;VES=&$@;&ES=&%A+@!686QK;VES96QL92!L:7-T86QL92!L:7/D='ET
M(&]S;VET=&5E=`!,979E>7,`3&5V97ES($-34R!M:71T87EK<VEK:_9I;N0`
M5F%S96UM86QL82!O;&5V86X@)7,@=F%L:6MO;B!L979E>7,@*'1U;&5E('9O
M:6UA86X@<V5U<F%A=F%L;&$@<VESY.1N:VER:F%U='5M:7-E;&QA*3H`5&%U
M;'5K;VX@;&5V97ES`$QE=F5Y9&5N('EK<VEK:_8`3&5V97ES.@!7:6MI`%1U
M=6QI`%1U=6QI<W1A(&%I:V%I<VEN`%1U=6QE;FYO<&5U<R!S;VQM=6ES<V$`
M5'5U;&DZ`%1U=6QI.B``5FEI<V%U<P!4;VEV96QI<W1A=`!4>?8`3W-O:71E
M("AT>?8I`%!U:&5L:6X@*'1Y]BD`5N3D<N0@;>3D<N0@:V5N='1IY"!R:79I
M;&SD("5D+B!/9&]T971T:6EN("5D+"!L]GET>6D@)60N`%;DY'+D(&WDY'+D
M(&ME;G1T:>0N($]D;W1E='1I:6X@)60L(&SV>71Y:2`E9"X`5N3D<N0@<&]I
M:VME86UA("5D(&QU971T865S<V$@5D93+71I961O<W1O82X`6"U0<FEO<FET
M>0!8+5)E9@!8+5-P86TM3&5V96P`6"U3<&%M+5-C;W)E`%@M4W!A;2U3=&%T
M=7,`6#4P.78S('!E<G5S<F%J;VET=&5E=`!8-3`Y=C,@;&ESY'1O:6UI;FYO
M="!A=F%I;65N(&OD>73V;&QE`%@U,#EV,R!+;VAT965N('9A:6AT;V5H=&]I
M;F5N(&YI;6D`6#4P.78S($MO:'1E96X@879A:6UE;B!T=6YN:7-T90!8-3`Y
M=C,M;&%A:F5N;G5K<V5T`%96`%965E8`66%H;V\A(&MA<G1T80!6=6]S:71T
M86EN`$IE;65N`$MY;&SD`$MY;&SD+"!S=6]S='5N+@!+Y'ETY'0@5$5+4U1)
M5$E,04$N($OD>73D(%L\/ET@;F%P<'5L86$@=F%I:'1A86MS97-I('1A:V%I
M<VEN(%=94TE764<M=&EL86%N+@!%="!V;VD@=&5H9.0@96YE;7#DY"!K=6EN
M("5D(&]S:6]T82X`170@=F]I(&QU;V1A(&5N96UPY.0@:W5I;B`E9"!SY.1N
M=/;D+@!%="!V;VD@;'5O9&$@=&%I(&UU;VMA=&$@97)I='EI<VGD('/DY&YT
M]FKD+@!%="!O;&4@875T96YT:6MO:71U;G5T+@!.:6UE<W/D<VD@96D@<V%A
M(&]L;&$@)UPG+6UE<FMK:>0N`$5T(&%N=&%N=70@;VEK96%N(&UU;W1O:7-T
M82!SY&AK]G!O<W1I;W-O:71E='1A+@!%="!MY.1R:71E;&QY="!M:71KY"!T
M=6]D=6X@=&EE9&]S=&]N(&ME;G3D="!V87-T86%V870@;6ETY&MI;B!K96YT
M=&GD("5S.G-SY"X`3VQE="!K:7)J875T=6YU="!U;&]S+@!3:6YU;&QE(&]N
M('-A87!U;G5T('5U<VD@=FEE<VD`4VEN=6X@<&ETY.0@86YT86$@;VEK96$@
M;6%T:V%P=6AE;&EN;G5M97)O+"!V86EN(&YU;65R;VET82!J82!M86AD;VQL
M:7-E<W1I("<K)R!J;W,@:^1Y=.1T(&MA;G-A:6YVY&QI<W3D('!U:&5L:6YN
M=6UE<F]M=6]T;V$N`%-I;G5N('3D>71Y>2!A;G1A82!O:6ME82!A<G9O+@!3
M:6YU;B!P:73DY"!A<V5N=&%A($1A=&%4<F5E+71A=7-T86KD<FIE<W1E;&WD
M(&5N;F5N(&MU:6X@=F]I="!KY'ET=.3D(%-I9VYU<"UT;VEM:6YT;VIA+@!3
M:6YU;B!P:73DY"!A<V5N=&%A(%9&4RUT875S=&%JY')J97-T96QMY"X`4VEN
M=6X@='5L964@:W5V86EL;&$@;VYG96QM871I;&%N;F5T=&$@96YN96X@:W5I
M;B!V;VET(&SD:&5T=.3D(&]N9V5L;6%V:65S=&EN+@!3:6YU;B!P:73DY"!A
M;G1A82!54DP@;6EH:6X@=.1MY"!L:6YK:VD@;W-O:71T86$`4VEN=6X@<&ET
MY.0@=F%L:71A('!O:7-T971T879A('!A;'9E;&EN+@!3:6YU;B!P:73DY"!A
M;G1A82!P;VES=&5T=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@
M86YT86$@<&]I<W1E='1A=F$@:^1Y='3D:N1T=6YN=7,N`%-I;G5N('!I=.3D
M(&%N=&%A(&%I;F%K:6X@>6MS:2!SY&AK]G!O<W1I;W-O:71E+"!J;VQL92!L
M86ET971A86X@<.3D;&QE('!O:7-S86]L;W9I97-T:70N`%-I;G5N('!I=.3D
M(&%N=&%A(&QI<^1T=.1VY"!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@
M86YT86$@<.1I=FET971TY';D(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73D
MY"!V86QI=&$@<W5O<FET971T879A('1O:6UI;G1O+@!3:6YU;B!P:73DY"!A
M;G1A82!U=61E;B!K871E9V]R:6%N(&YI;6DN`%-I;G5N('!I=.3D(&%N=&%A
M(&ET86QI86QA:6YE;B!P=6AE;&EN;G5M97)O`$ES='5N=&]S:2`E<R!O;B!V
M86YH96YT=6YU="X@2VER:F%U9'4@=75D96QL965N('-I<^3D;BX`4^1H:_9P
M;W-T:6]S;VET=&5E<VD`4VEN=6X@;.1H971TY&KD;W-O:71T965S:3H`3VUA
M="!T:65T;W-I`%-I;G5N('1I971O:V]N965S:2!KY'ET=.1MY"!T:65T;W9E
M<FMK;RUO<V]I=&4@;VX@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T
M(&%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN
M=6X@<&ETY.0@:VER:F%U='5A('5U9&5S=&%A;B!JY')J97-T96QMY.1N+@!.
M:6UE<VD`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J97-T
M96QMY"!E:2!T=64@:^1Y='3D:FEE;B!L:7/DY&UI<W3D+B!*;W,@:&%L=6%T
M(&AA;&QI;FYO:61A(&OD>71TY&KD='5N;G5K<VEA+"!S:6YU;B!P:73DY"!K
MY'ET=.3D(&IO=&%K:6X@=&]I<W1A(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD
M<FIE<W1E;&WDY"X`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%J
MY')J97-T96QMY"!E:2!T=64@:^1Y='3D:N1T:65T;VIE;B!NY'ET=.1M:7-T
MY"!T86D@=.1MY"!P:6ER<F4@96D@;VQE(&IO<W1A:VEN('-Y>7-TY"!KY'ET
M971TY'9I<W/D+@!3:6YU;B!KY'ET=.1MY'-I('=W=RUS96QA:6X@;N1Y='3D
MY"!O;&5V86X@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T(&%L;VET
M=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN=6X@<&ET
MY.0@:VER:F%U='5A('5U9&5S=&%A;FKD<FIE<W1E;&WDY&XN`%-E;&%I;65S
M:2!E:2!T=64@=.1TY"!T;VEM:6YT;V$N`%-E;&%I;65S:2!E:2!T=64@=&%R
M=FET=&%V86$@='5L;W-T=7-T;VEM:6YT;V$N(%!A:6YA($-O;G1R;VPO3W!T
M:6]N("L@4"!T=6QO<W1A86MS97-I+@!!:6MA=GGV:'EK:V5E<VDZ`$]L971U
M<W!R;V9I:6QI<VD@;VX@;75U=&5T='4N`$]L971U<W!R;V9I:6QI<VDZ`$YI
M;65S:3H`27-T=6YT;W-I(&]N('9A;FAE;G1U;G5T+@!3:6YU;B!S86QA<V%N
M87-I("5S.FQL92!O;CH@)7,`07-E='5K<V5S:2!O;B!PY&EV:71E='1Y(&IA
M(&YE(&]V870@=F]I;6%S<V$@=.1MY&X@:7-T=6YN;VX@86IA;BX`07-E='5K
M<V5S:2!O;B!PY&EV:71E='1Y+@!386QA<V%N87-I(&]N(&YO;&QA='1U`%-A
M;&%S86YA<VD@;VX@;F]L;&%T='4L('1A<FMI<W1A('/D:&OV<&]S=&ES:2!J
M82!K:7)J875D=2!S:7/DY&X@=75D96QL82!S86QA<V%N86QL87-I+@!386QA
M<V%N87-I(&]N('9A;FAE;G1U;G5T+@!%=.1P86QV96QI;65S:3H`2G5G;W-L
M879I80!:86ER90!386UB:6$`6FEM8F%B=V4`6FEP<'D`6U!I:6QO=&$@;&%I
M;F%T='4@=&5K<W1I70!;16D@;W1S:6MK;V%=`%M/;F=E;&UA70!;3N1Y=.0@
M;&%I;F%T='4@=&5K<W1I("T`6T[D>73D(&QA:6YA='1U('1E:W-T:2`M("5S
M(')I=FGD70!;<FEV:6QLY"`E<R\E<UT`7U;D;&ETY"!V:65S=&ET(&]S;VET
M=&5I<VEI;CH`7\1LY"!LY&AE=.0@=F%S=&%U<W9I97-T:>0@;W-O:71T96ES
M:6EN.@!?66QLY'!I=&\`7TUU<W1A(&QI<W1A`%]+;VUE;G1O='5L:VMI`%]$
M871A5')E90!?4&]I<W1A(')I=FD`7U!O:7-T82!V:65S=&D@:V]K;VYA86X`
M7TQA:71A(&IO:V%I;F5N(&]S;VET92!O;6%L;&4@<FEV:6QL965N.@!?575D
M96QL965N;VAJ86$`7U)Y:&WD=`!?3VAJ90!?2W5V86X@=&EE9&]T+BXN`%]*
MY'3D('9I97-T:7-TY"!K;W!I;R!TY&CD;B!O<V]I='1E97-E96XN`%]+:7)J
M875D=2!S:7/DY&X`7TMI<FIA=61U('5L;W,`7TUU;VMK86$@;&EN:VMIY`!?
M4VEI<G+D('9I97-T:2!K86YS:6]O;CH`7T]M870@<^1H:_9P;W-T:6]S;VET
M=&5E=#H`7T%S971U:W-E=`!?3VEK975D970`4&]I<W1A(&QI;FMK:2XN+@!?
M4VMR:7!T:0!?07-E;FYU<P!?5&%U;'5K;VX@=&EE9&]T+BXN`%]+Y'ET=.1J
MY'0`7U!O:7-S86]L;W9I97-T:0!?5F%L:V]I;F5N(&QI<W1A`&%K=&EI=FEN
M96X`;W-O:71E:VER:F$`=F%S=&%A;F]T=&%J82!T=6YT96UA=&]N`&IA`&MA
M;&5N=&5R:0!T>7EN=.0`96D@=F]I(&QU;V1A('1U;&]S=&EE9&]S=&]A`&5I
M('9O:2!A=6MA:7-T82!LY&AD971TY`!N87!S875T82!TY'-TY`!V:7)H92!K
M;VUE;G1O<FEV:6QLY`!A<V5T=7-V:7)H90!K<FEI='1I;F5N(&KD<FIE<W1E
M;&WD=&EE9&]S=&\@<'5U='1U=0!M=6]T;W9I<FAE('1I961O:7-S80!P;VES
M('#DY&QTY"`M(&YA<'-A=71A(&QA:71T86%K<V5S:2!PY.1L;&4`;75O:VMA
M80!T:65T=65T=&$@96D@;/9Y='EN>70`;&%S:V5V80!K96YT=.0`=&EE9&]S
M=&\`<W5U;FYA<W1A("5S("@E<RD@;F]P975D96QL82`E<R`E<P!P=75S:VET
M=&%I;@!H.@!H:`!T=6YT96UA=&]N('!A;'9E;&EM96X@;FEM:0!VY&QI='3V
M;>1S=&D`96D@86MT:6EV:6YE;@!I;FQI;F4`:6\M=FER:&4`;VAJ96QM:7-T
M;VX@<VESY&EN96X@=FER:&4`<FEV:71=`$EN9V\@;VAJ96QM86X@='5O='1A
M;6$@<VMR:7!T:0!TY'-MY.0`;6MI<V]F<R!V:7)H96MO;V1I("5D($E33SIA
M('1E:&1E<W/D+@!M;0!N:6UI`&5I(&]L92!T;W1E=71E='1U`&5I(&]L92!V
M:65LY"!T;W1E=71E='1U`&UU:7-T:6QI<W1A`'1A:0!P<F]S96YT=&D`:^1Y
M='3V(&MI96QL971T>0!P:6MS96QE:73D`$EN9V\@;VAJ96QM86X@='5O='1A
M;6$@<')O8VUA:6PM<VMR:7!T:0!E=.1V:7)H92!P<F]T;VMO;&QA<W-A`&YO
M=7-E=F$`<&%L=F5L=2!E:2!O;&4@:^1Y=&5T=.1V:7-SY`!NY'ETY"!E<F]T
M`'-M<S)E;6%I;"!(5%10.FX@879U;&QA`'-S`'9A:V%A`&KD<FIE<W1E;&WD
M=FER:&4`=&5H=.1VY&QI<W1A`';D;&EA:6MA:6YE;B!V:7)H90!V87)M:7-T
M86%K<V5S:2!K:7)J;VET82!S86QA<V%N82!K86AD97-T:0!U;FEF:65D`&YI
M;65T]FX`:^1Y='3D:N1N('9A;&EN=&$`=D-A<F0`=SH`=V5A=&AE<BYC;VT`
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O9FE?1DDO:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-S<P,0`Q,#0Q
M-S,V,C<T-P`P,C$R-34`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E
M.B!I;F=O+VQO8V%L92]F:5]&22]H96QP+GAM;"QV(#$N,2XR+C4@,C`P-B\P
M,B\R."`Q,SHT-#HS-B!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB8FQA8VML:7-T(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-6,Q,F4Q-C)F
M-C9F-CAC-F,R9#@T8V,W8S(X,&0W,3`B/@H@("`@/'1I=&QE/DUU<W1A(&QI
M<W1A/"]T:71L93X*("`@(#QP87)A/@H@("`@375S=&$@;&ES=&$@;VX@;&ES
M=&$@<R8C>$4T.VAK)B-X1C8[<&]S=&EO<V]I='1E:7-T82P@:F]I<W1A('1U
M;&5V:6$@=FEE<W1E:B8C>$4T.R!E="!H86QU82!N)B-X130[:&0F(WA%-#L@
M24Y"3U@@*'-A87!U;F5I9&5N('9I97-T:65N*2`M<&]S=&EL86%T:6MO<W-A
M<VDN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)B;&%C:VQI
M<W0M86-T:6]N(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,3<P,68T,34R8S`Y
M,#`P-&4S8C0P,C`U-#,Y9CDQ,#@B/@H@("`@/'1I=&QE/DUU<W1A(&QI<W1A
M.B!4;VEM:6YT;SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%0F(WA%-#MS<R8C
M>$4T.R!M)B-X130[)B-X130[<FET96QL)B-X130[)B-X130[;B!M:70F(WA%
M-#L@=&5H9"8C>$4T.R8C>$4T.VX@;FEI;&QE('9I97-T96EL;&4L(&IO:61E
M;B!L)B-X130[:&5T="8C>$4T.VHF(WA%-#MN(&]N('-E;&QA:6YE;B!O<V]I
M=&4L(&IO:V$@;VX@;75S=&%L;&$@;&ES=&%L;&$N(%9A:6AT;V5H=&]I;F$@
M;VX@(E!O:7-T82(@=&%I(")3:6ER<B8C>$4T.R!K86YS:6]O;B(N($IO<R!V
M86QI='-E="`B4&]I<W1A(BP@;FEI;B!V:65S=&ET('!O:7-T971A86X@96YN
M96YK=6EN(&YE(&]N(&IA971T=2!)3D)/6"!P;W-T:6MA;G-I;V]S:2X@2F]S
M('9A;&ET<V5T(")3:6ER<B8C>$4T.R!K86YS:6]O;B(L(&YI:6X@=FEE<W1I
M('1O:6UI=&5T86%N('-U;W)A86X@=F%L:71S96UA87-I(&MA;G-I;V]N+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8FQA8VML:7-T+6%D
M9')E<W-E<R(@<W1A=&4](G5P=&]D871E(B!M9#4](C,T,S%E.3AA.&0Q-6)F
M838T-6%F,SDT8V5F9#@S-#9D(CX*("`@(#QT:71L93Y-=7-T82!L:7-T83H@
M3W-O:71T965T/"]T:71L93X*("`@(#QP87)A/@H@("`@3&ES=&$@;W-O:71T
M96ES=&$L(&IO:7-T82!E:2!O=&5T82!V:65S=&5J)B-X130[('9A<W1A86XN
M($IO:V%I;F5N(&]S;VET92!P:70F(WA%-#LF(WA%-#L@;VQL82!O;6%L;&$@
M<FEV:6QL)B-X130[)B-X130[;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F9I;'1E<G-?<G5L97,B('-T871E/2)U<'1O9&%T92(@;60U
M/2)D.#0V,3=A,F8U,#`R9#(T968Q,34P.64U9C1E8C9C,"(^"B`@("`\=&ET
M;&4^4R8C>$4T.R8C>$4T.VYN)B-X1C8[=#H@4W5O9&%T:6YS)B-X130[)B-X
M130[;FXF(WA&-CMT/"]T:71L93X*("`@(#QP87)A/@H@("`@5"8C>$4T.VTF
M(WA%-#L@;VX@<W5O9&%N=&EN<R8C>$4T.R8C>$4T.VYT)B-X1C8[:F5N('`F
M(WA%-#LF(WA%-#MS:79U+B!6;VET('1E:&0F(WA%-#L@=75S:6$@<W5O9&%T
M:6YS)B-X130[)B-X130[;G0F(WA&-CMJ)B-X130[(&YA<&%U='1A;6%L;&$@
M(E5U<VD@<R8C>$4T.R8C>$4T.VYT)B-X1C8[(B`M<&%I;FEK971T83L@375U
M='1A82!S)B-X130[)B-X130[;G0F(WA&-CMJ96X@:B8C>$4T.W)J97-T>7-T
M)B-X130[(&YA<&%U='1A;6%L;&$@;G5O;&D@86QA<R!J82!N=6]L:2!Y;"8C
M>$8V.W,@<&%I;FEK:V5I=&$@(E-I:7)R)B-X130[(B!S87)A:VME97-S83L@
M3&%I='1A82!S)B-X130[)B-X130[;FXF(WA&-CMN('`F(WA%-#LF(WA%-#ML
M;&4@=&%I('!O:7-T86$@<"8C>$4T.R8C>$4T.VQT)B-X130[(',F(WA%-#LF
M(WA%-#MN;B8C>$8V.VX@;F%P875T=&%M86QL82!I:V]N:6$@(E`F(WA%-#LF
M(WA%-#ML;"8C>$4T.R(@<V%R86MK965S<V$[(&UU;VMA=&$@>6MS:71T)B-X
M130[:7-I)B-X130[(',F(WA%-#LF(WA%-#MN="8C>$8V.VHF(WA%-#L@;F%P
M875T=&%M86QL82!I:V]N:6$@(DUU;VMK86$B('-A<F%K:V5E<W-A('1A:2!N
M87!A=71T86UA;&QA(',F(WA%-#LF(WA%-#MN;B8C>$8V.VX@;FEM928C>$4T
M.RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9O<G=A<F0B
M('-T871E/2)U<'1O9&%T92(@;60U/2)C.38V-&(Y-C!C965F.#=C86(T868X
M,V4X9C,S-#$R8R(^"B`@("`\=&ET;&4^575D96QL965N;VAJ86$\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!6;VET(&%U=&]M86%T=&ES97-T:2!U=61E;&QE
M96YO:&IA=&$@='5L979A="!V:65S=&ET('EH=&5E;B!T86D@=7-E86UP86%N
M(',F(WA%-#MH:R8C>$8V.W!O<W1I;W-O:71T965S965N+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]R=V%R9"UA9&1R97-S97,B('-T
M871E/2)U<'1O9&%T92(@;60U/2(X,3=C-68P,#)F.3EC,&%F9#`P,3!A86)A
M9C`W8SDQ8R(^"B`@("`\=&ET;&4^575D96QL965N;VAJ86$Z($]S;VET=&5E
M=#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%9O:70@;VAJ871A('-I;G5L;&4@
M='5L979A="!V:65S=&ET('1O:7-E96X@;W-O:71T965S965N+B!6;VET(&]H
M:F%T82!V:65S=&ET('EH=&5E;B!T86D@=7-E86UP86$@;W-O:71T965S965N
M+B!*;VMA:6YE;B!O<V]I=&4@<&ET)B-X130[)B-X130[(&]L;&$@;VUA;&QA
M(')I=FEL;"8C>$4T.R8C>$4T.VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)F;W)W87)D+6ME97!C;W!Y(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB8F4Q9C,V8S)F.6$X9&-B83<U,3=B.&5D9C4S,3ED-C0B/@H@("`@
M/'1I=&QE/E5U9&5L;&5E;F]H:F%A.B!*)B-X130[="8C>$4T.R!K;W!I;SPO
M=&ET;&4^"B`@("`\<&%R83X*("`@($IO<R!V86QI='-E="!T)B-X130[;28C
M>$4T.VX@87-E='5K<V5N+"!N:6EN(&IO:V%I<V5S=&$@<VEN=6QL92!S86%P
M=79A<W1A('9I97-T:7-T)B-X130[(&HF(WA%-#MT970F(WA%-#LF(WA%-#MN
M(&MO<&EO('!A;'9E;&EM96QL92!J82!V:65S=&D@;VAJ871A86X@961E;&QE
M96X@;28C>$4T.R8C>$4T.W)I='1E;&5M:6ES:2!O<V]I='1E:7-I:6XN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F+7-H;W=?9FEL
M=&5R7VUS9R(@<W1A=&4](G5P=&]D871E(B!M9#4](F0X-SDU935B-S%C-C(X
M-V5D-V)F93-F.&1C-&8T.#8Q(CX*("`@(#QT:71L93Y!<V5T=7,Z($XF(WA%
M-#MY="8C>$4T.R!Y:W-I='EI<VMO:'1A:7-E="!T:6QA=&EE9&]T('9I97-T
M:65N('-U;V1A='5K<V5S=&$N/"]T:71L93X*("`@(#QP87)A/@H@("`@2F]S
M(&LF(WA%-#MY="8C>$4T.W0@24U!4"UA:G5R:6X@<W5O9&%T=7-T82P@;FEI
M;B!T)B-X130[;28C>$4T.R!A<V5T=7,@;28C>$4T.R8C>$4T.W(F(WA%-#LF
M(WA%-#L@;6ET96X@<&%L:F]N('-U;V1A=&EN<')O<V5S<VES=&$@;B8C>$4T
M.WET970F(WA%-#LF(WA%-#MN('1I971O:F$N($IO<R!V86QI='-E="!K>6QL
M)B-X130[+"!N:6EN(&IO:V%I;F5N('-U;V1A=&5T='4@=FEE<W1I('1U;&]S
M=&%A(&%I;F$@>6AD96X@:6QM;VET=6MS96X@<G5U9'5L;&4N($IO<R!V86QI
M='-E="!E:2P@;FEI;B!V:65S=&EE;B!S=6]D871U:W-E<W1A(&XF(WA%-#MY
M=&5T)B-X130[)B-X130[;B!V86EN('EH=&5E;G9E=&]T:65D;W0N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F+69I;'1E<E]S965N
M(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB.#4V.#=C-CED8C8Q-#5D-S<P-3-A
M.&(V,S`R935A9#(B/@H@("`@/'1I=&QE/D%S971U<SH@4W5O9&%T82!V86EN
M(%5U9&5T+U9A;FAA="!V:65S=&ET+CPO=&ET;&4^"B`@("`\<&%R83X*("`@
M(%0F(WA%-#MM)B-X130[(&%S971U<R!M)B-X130[)B-X130[<FET=&5L92!M
M:70F(WA%-#L@=FEE<W1E:B8C>$4T.R!)34%0+6%J=7)I;B!S=6]D871U<R!K
M;W-K964N(%9O:70@;28C>$4T.R8C>$4T.W)I=&5L;"8C>$4T.R!K;W-K965K
M;R!S=6]D871U<R!K86EK:VEA('9I97-T96HF(WA%-#LL('5U<VEA('9I97-T
M96HF(WA%-#L@=&%I('9I97-T96HF(WA%-#L@:F]T:V$@;VX@;65R:VET='D@
M=F%N:&]I:W-I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<G5L92(@<W1A=&4](G5P=&]D871E(B!M9#4](F-F,C$Q96,Y-SDU-F4Y861C
M,V(X9C`Q8C)A-#`X.#AF(CX*("`@(#QT:71L93Y3=6]D871I;G,F(WA%-#LF
M(WA%-#MN="8C>$8V.SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-U;V1A=&EN
M<R8C>$4T.R8C>$4T.VYT)B-X1C8[(&]N('!E<G5S:V]M<&]N96YT=&DL(&IO
M:7-T82!M=6]D;W-T971A86X@<W5O9&%T:6YS)B-X130[)B-X130[;FXF(WA&
M-CMS="8C>$8V.RX@4R8C>$4T.R8C>$4T.VYT)B-X1C8[(&MO;W-T=74@>6AD
M97-T)B-X130[('1A:2!U<V5A;6UA<W1A(&5H9&]S=&$@:F$@>6AD97-T)B-X
M130[('1A:2!U<V5A;6UA<W1A('1O:6UI;FYO<W1A+B!+=6X@<VEN=6QL92!T
M=6QE92!V:65S=&DL(&YI:6X@:F]K86EN96X@=FEE<W1I(&UE;F5E('-U;V1A
M=&EN<')O<V5S<VEN(&PF(WA%-#MV:71S92X@2F]S('9I97-T:2!T)B-X130[
M>71T)B-X130[)B-X130[(&TF(WA%-#LF(WA%-#MR:71T96QE;28C>$4T.W-I
M(&5H9&]T+"!N:6EN('-I;&QE('-U;W)I=&5T86%N(&TF(WA%-#LF(WA%-#MR
M:71T96QE;28C>$4T.W-I('1O:6UI;G1O+B!6;VET(&5S:6UE<FMI:W-I('!O
M:7-T86$@=FEE<W1I="P@:F]I=&$@970@:&%L=6$@=F%S=&%A;F]T=&%A('1A
M:2!O:&IA=&$@=&EE='ET('9I97-T:70@875T;VUA871T:7-E<W1I('1I971T
M>6EH:6X@:V%N<VEO:6AI;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G)U;&4M86-T:6]N(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,&8V
M-C4W-&9E8S(Q-C0U,30W8C-C8F(Y-C=C8S(S8C$B/@H@("`@/'1I=&QE/E-U
M;V1A=&EN<R8C>$4T.R8C>$4T.VYT)B-X1C8[.B!4;VEM:6YT;SPO=&ET;&4^
M"B`@("`\<&%R83X*("`@($IO<R!V:65S=&D@="8C>$4T.WET="8C>$4T.R8C
M>$4T.R!M)B-X130[)B-X130[<FET96QL>70@96AD;W0L(&YI:6X@=F]I="!M
M)B-X130[)B-X130[<FET96QL)B-X130[(&UI="8C>$4T.R!V:65S=&EL;&4@
M=&5H9"8C>$4T.R8C>$4T.VXN($MA:6MK:2!T;VEM:6YN;W0@96EV)B-X130[
M="!O;&4@:R8C>$4T.WET971T)B-X130[=FES<R8C>$4T.W-I('9A86X@;F4@
M;28C>$4T.R8C>$4T.W(F(WA%-#MY='EV)B-X130[="!S96X@;75K86%N(&UI
M="8C>$4T.R!T;VEM:6YT;VIA('-U;V1A='5S;VAJ96QM:7-T;VQL82!O;B!M
M86AD;VQL:7-T82!K)B-X130[>71T)B-X130[)B-X130[+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^3&%I=&$@=FEE<W1I($E.0D]8('!O<W1I:V%N<VEO
M;VYI/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65S=&D@=&%L;&5T971A
M86X@24Y"3U@@<&]S=&EK86YS:6]O<VDN(%0F(WA%-#MM)B-X130[(&]N(&]L
M971U<V%S971U<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DQA:71A('9I
M97-T:2!T)B-X130[:"8C>$4T.VX@:V%N<VEO;VX\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%9I97-T:2!T;VEM:71E=&%A;B!M)B-X130[)B-X130[<FET
M=&5L96TF(WA%-#LF(WA%-#MS:2!K86YS:6]O;BX*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E!O:7-T82!V:65S=&D@:V]K;VYA86X\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%9I97-T:2!P;VES=&5T86%N+B!3:6YU;&QE('1A:2!V
M:65S=&EN('9A<W1A86YO='1A:F%L;&4@96D@='5L92!M:70F(WA%-#LF(WA%
M-#MN(&EL;6]I='5S=&$@<VEI="8C>$4T.R!E='0F(WA%-#L@:F]K:6X@=FEE
M<W1I(&]N('!O:7-T971T=2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5U
M9&5L;&5E;F]H:F%A(&]S;VET=&5E<V5E;CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5FEE<W1I(&]H:F%T86%N(&5D96QL965N(&TF(WA%-#LF(WA%-#MR
M:71T96QE;28C>$4T.R8C>$4T.W-I(&]S;VET=&5E<V5E;BP@<&%L=F5L:6UE
M;&QE(&5I(&HF(WA%-#LF(WA%-#L@=FEE<W1I<W0F(WA%-#L@:V]P:6]T82X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DQA:71A('9I97-T:2!)3D)/6"!P
M;W-T:6MA;G-I;V]N:2!J82!U=61E;&QE96YO:&IA82!O<V]I='1E97-E96X\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9I97-T:2!O:&IA=&%A;B!E9&5L
M;&5E;B!M)B-X130[)B-X130[<FET=&5L96TF(WA%-#LF(WA%-#MS:2!O<V]I
M='1E97-E96XL(&UU='1A('9I97-T:7-T)B-X130[(&HF(WA%-#LF(WA%-#L@
M:V]P:6\@;7DF(WA&-CMS($E.0D]8('!O<W1I:V%N<VEO;W-I+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^2'EL:R8C>$4T.R8C>$4T.R!V:65S=&D@=F%S
M=&%U:W-E;&QA/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!;&MU<&5R)B-X
M130[:6YE;B!V:65S=&D@:"8C>$4T.W9I=&5T)B-X130[)B-X130[;B!J82!L
M)B-X130[:&5T="8C>$4T.VHF(WA%-#ML;&4@;"8C>$4T.VAE=&5T970F(WA%
M-#LF(WA%-#MN(&EL;6]I='5S('-I:70F(WA%-#L@971T)B-X130[('9I97-T
M:2!O;B!H>6PF(WA%-#MT='DN(%9O:70@:71S92!M)B-X130[)B-X130[<FET
M96QL)B-X130[('9A<W1A=7-V:65S=&EN('1E:W-T:6XN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)R=6QE+6-O;6)I;F4B('-T871E/2)U
M<'1O9&%T92(@;60U/2(R.30X-&,Q96)D9#=C93<Q961C,S1F8S@Q,#!E9C8Y
M8R(^"B`@("`\=&ET;&4^4W5O9&%T:6YS)B-X130[)B-X130[;G0F(WA&-CLZ
M(%EH9&ES="8C>$4T.R!A<V5T=6MS:6$\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!9:W-I('-U;V1A=&EN<R8C>$4T.R8C>$4T.VYT)B-X1C8[('9O:2!K;V]S
M='5A(&UO;F5S=&$@96AD;W-T82X@5F]I="!Y:&1I<W0F(WA%-#LF(WA%-#L@
M96AT;VIA(&QO;V=I<VEL;&$@(FIA(B\B=&%I(B!O<&5R86%T=&]R96EL;&$N
M($5T('9O:2!T96AD)B-X130[('-U;V1A=&EN<R8C>$4T.R8C>$4T.VYT)B-X
M1C8[)B-X130[+"!J;W-S82!O;&ES:2!S96LF(WA%-#L@(FIA(B!E='0F(WA%
M-#L@(G1A:2(@;W!E<F%A='1O<F5I=&$N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY*83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@2F]S('9A;&ET<V5T
M($I!+"!N:6EN('1U;&5V86X@=FEE<W1I;B!P:70F(WA%-#LF(WA%-#L@="8C
M>$4T.WET="8C>$4T.R8C>$4T.R!K86EK:VD@<VEL;&4@;28C>$4T.R8C>$4T
M.W)I='1E;&5M)B-X130[<VD@96AD;W0L(&IO='1A('-I;&QE('-U;W)I=&5T
M86%N(&TF(WA%-#LF(WA%-#MR:71E;&QY="!T;VEM96YP:71E970N"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY486D\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($IO<R!V86QI='-E="!404DL(&YI:6X@;28C>$4T.R8C>$4T.W)I=&5L
M;'ET('1O:6UE;G!I=&5E="!S=6]R:71E=&%A;B!J;W,@=B8C>$4T.VAI;G0F
M(WA%-#LF(WA%-#MN('EK<VD@96AT;R!T)B-X130[>71T>7DN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)R=6QE+6UA<FLB('-T871E/2)U
M<'1O9&%T92(@;60U/2(P8V)C8S1A9#0X-3=B.#4S.&-D-&4S.3$U9F)E.60W
M,R(^"B`@("`\=&ET;&4^4W5O9&%T:6YS)B-X130[)B-X130[;G0F(WA&-CLZ
M($UE<FMI='-E('9I97-T:3PO=&ET;&4^"B`@("`\<&%R83X*("`@(%EH=&5N
M)B-X130[('1O:6UI;G1O;F$@=F]I="!V86QI=&$@=FEE<W1I;B!M97)K:6YN
M)B-X130[;BP@:F]L;&]I;B!V;VET(&UE<FMI="8C>$4T.R!V:65S=&EN('EH
M9&5L;"8C>$4T.R!T86D@=7-E86UM86QL82!)34%0('1I;&%T:65D;VQL82X@
M2R8C>$4T.WET971T)B-X130[=FES<R8C>$4T.R!O;B!T:6QA=&EE9&]T.B!6
M86YH82P@5"8C>$4T.W)K928C>$4T.RP@5F%S=&%T='4@:F$@4&]I<W1E='1U
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<G5L92UM871C
M:&5S(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-3$W93(T.3<Q9C)C-30T,V(R
M960P-&4Y8S4P-&4W96(B/@H@("`@/'1I=&QE/E-U;V1A=&EN<R8C>$4T.R8C
M>$4T.VYT)B-X1C8[.B!4)B-X130[<VTF(WA%-#MY<SPO=&ET;&4^"B`@("`\
M<&%R83X*("`@($IO:V%I;F5N('-U;V1A=&EN<R8C>$4T.R8C>$4T.VYT)B-X
M1C8[(&MO;W-T=74@:V]L;65S=&$@:V]M<&]N96YT:7-T82X@16YS:6UM)B-X
M130[:6YE;B!O;B!T=71K:71T879A(&ME;G1T)B-X130[+B!4;VEN96X@;VX@
M=F5R=&%I;'5T87!A+B!+;VQM87,@;VX@87)V;R!J;VAO;B!K96YT)B-X130[
M)B-X130[('9E<G)A=&%A;BX*("`@($ME;G1T:28C>$4T.R!V;VED86%N('9E
M<G1A:6QL82!E<FD@=&%V;VEL;&$N($LF(WA%-#MY=&5T="8C>$4T.W9I<W,F
M(WA%-#L@;VQE=F%T('9E<G1A:6QU=&%V870@<FEI<'!U=F%T(&ME;G0F(WA%
M-#MN('1Y>7!I<W0F(WA%-#L@:F$@<VEI="8C>$4T.R!M:6QL86ES:6$@=F5R
M=&%I;'5T87!O:F$@=&%U<W1A:B8C>$4T.W)J97-T96QM)B-X130[<W,F(WA%
M-#L@;VX@;6%H9&]L;&ES=&$@:R8C>$4T.WET="8C>$4T.R8C>$4T.RX@16QI
M+"!V86EK:V$@86QL82!O;B!L=65T96QT=2!M;VYT82!E<FEL86ES=&$@=F5R
M=&%I;'5T87!A82P@;FEI;B!R:6EP<'5E;B!K96YT)B-X130[;B!T>7EP:7-T
M)B-X130[('9A:6X@:F]T:W5T('9E<G1A:6QU=&%V870@;W9A="!M86AD;VQL
M:7-I82X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E-I<R8C>$4T.VQT)B-X
M130[)B-X130[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4;W-I+"!J;W,@
M;65R:VMI:F]N;R!L)B-X1C8[>71Y>2!J;W-T86MI;B!K;VAT86$@<FEV:28C
M>$4T.RX@17-I;65R:VMI.B!U<V5R0&5X86UP;&4@="8C>$4T.W-M)B-X130[
M)B-X130[(&IO95]U<V5R0&5X86UP;&4N8V]M"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY%:2!S:7,F(WA%-#ML;"8C>$4T.SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&]S:2P@:F]S(&UE<FMK:6IO;F]A(&5I(&PF(WA&-CMY9'D@
M;6ES="8C>$4T.R8C>$4T.VX@:V]H=&%A(')I=FEL="8C>$4T.RX@17-I;65R
M:VMI.B!U<V5R0&5X86UP;&4@96D@="8C>$4T.W-M)B-X130[)B-X130[(&IO
M95]U<V5R0&5X86UP;&4N8V]M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY/
M;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&]S:2P@:F]S(&TF(WA%-#LF
M(WA%-#MR:71E;'1Y(&UE<FMK:6IO;F\@="8C>$4T.W-M)B-X130[)B-X130[
M('0F(WA%-#MY9&5L;&ES97-T:2!R:79I:6XN($5S:6UE<FMK:3H@=7-E<D!E
M>&%M<&QE+F-O;2!T)B-X130[<VTF(WA%-#LF(WA%-#L@=7-E<D!E>&%M<&QE
M+F-O;0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16D@;VQE/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4;W-I+"!J;W,@;28C>$4T.R8C>$4T.W)I=&5L
M='D@;65R:VMI:F]N;R!E:2!T)B-X130[<VTF(WA%-#LF(WA%-#L@="8C>$4T
M.WED96QL:7-E<W1I(')I=FEI;BX@17-I;65R:VMI.B!U<V5R0&5X86UP;&4@
M96D@="8C>$4T.W-M)B-X130[)B-X130[('5S97)`97AA;7!L92YC;VT*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D%L:V%A/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4;W-I+"!J;W,@;28C>$4T.R8C>$4T.W)I=&5L='D@;65R:VMI
M:F]N;R!A;&]I=&%A(')I=FEN+B!%<VEM97)K:VDZ('5S97)`97AA;7!L92!T
M)B-X130[<VTF(WA%-#LF(WA%-#L@=7-E<D!E>&%M<&QE+F-O;0H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^16D@86QA/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!4;W-I+"!J;W,@;28C>$4T.R8C>$4T.W)I=&5L='D@;65R:VMI:F]N
M;R!E:2!A;&]I=&$@<FEV:28C>$4T.RX@17-I;65R:VMI.B!U<V5R0&5X86UP
M;&4N8V]M(&5I('0F(WA%-#MS;28C>$4T.R8C>$4T.R!U<V5R0&5X86UP;&4*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E`F(WA%-#LF(WA%-#MT='EY/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!4;W-I+"!J;W,@<FEV:2!P)B-X130[
M)B-X130[='1Y>2!M)B-X130[)B-X130[<FET96QT>7EN(&UE<FMK:6IO;F]O
M;BX@17-I;65R:VMI.B!E>&%M<&QE+F-O;2!T)B-X130[<VTF(WA%-#LF(WA%
M-#L@=7-E<D!E>&%M<&QE+F-O;0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M16D@<"8C>$4T.R8C>$4T.W1Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M;W-I+"!J;W,@<FEV:2!E:2!P)B-X130[)B-X130[='D@;28C>$4T.R8C>$4T
M.W)I=&5L='EY;B!M97)K:VEJ;VYO;VXN($5S:6UE<FMK:3H@:&]R9&4N;W)G
M(&5I('0F(WA%-#MS;28C>$4T.R8C>$4T.R!R:79I:6X@=7-E<D!E>&%M<&QE
M+F-O;0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^3VQE;6%S<V$\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1O<VDL(&IO<R!V:65S=&ES<R8C>$4T.R!O
M;B!M)B-X130[)B-X130[<FET96QT>2!O='-A:V4N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY%:2!O;&4@;VQE;6%S<V$\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%1O<VDL(&IO<R!V:65S=&ES<R8C>$4T.R!E:2!O;&4@;28C>$4T
M.R8C>$4T.W)I=&5L='DF(WA%-#L@;W1S86ME='1A+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^4R8C>$4T.R8C>$4T.VYN)B-X1C8[;&QI;F5N(&QA=7-E
M:V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%,F(WA%-#LF(WA%-#MN;B8C
M>$8V.VQL:7-E;&QA(&QA=7-E:VME96QL82!V;VET(&TF(WA%-#LF(WA%-#MR
M:71E;&PF(WA%-#L@4$]325@M>6AT965N<V]P:79A(',F(WA%-#LF(WA%-#MN
M;B8C>$8V.VQL:7-I)B-X130[(&QA=7-E:VME:71A+"!J;VET82!V97)R871A
M86X@=FEE<W1I;B!O='-A:VME:6AI;BX@17-I;65R:VEK<VDZ(")296-E:79E
M9"!F<F]M(%LJ7"XJ7"XJ7"XJ72!B>2`H:&]S=&%\:&]S=&(I+F5X86UP;&4N
M8V]M*B(@<V]P:6D@<FEV:6EN(")296-E:79E9"!F<F]M(%LQ-S(N,38N,3`P
M+C%=(&)Y(&AO<W1A+F5X86UP;&4N8V]M(&]N(%1U97-D87DB"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY4)B-X130[<VTF(WA%-#LF(WA%-#L\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%0F(WA%-#MS;28C>$4T.R8C>$4T.R!O;B!S
M86UA;FMA;'1A:6YE;B!S:7,F(WA%-#ML="8C>$4T.R8C>$4T.R!K86YS<V$L
M(&UU='1A('-I;&PF(WA%-#L@97)O='5K<V5L;&$@971T)B-X130[('9O:70@
M:R8C>$4T.WET="8C>$4T.R8C>$4T.R`J(&IA(#\M;65R:VME:B8C>$4T.R!J
M;VME<F5I;F$N("HM;65R:VMI('9A<W1A82!M:6AI;B!T86AA;G-A(&UE<FMK
M:6EN(&UI=&5N(&UO;G1A(&ME<G1A82!T86AA;G-A(&IA(#\M;65R:VMI('9A
M<W1A82!M:70F(WA%-#L@=&%H86YS82!Y:'0F(WA%-#L@;65R:VMI)B-X130[
M('1A:&%N<V$N($5S:6UE<FMI:W-I.B`B*G5S97(_0&5X86UP;&4N8V]M(B!S
M;W!I:2!O<V]I='1E97-E96X@(G5S97(Q0&5X86UP;&4N8V]M(B!T86D@(F]T
M:&5R=7-E<C)`97AA;7!L92YC;VTB+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^16D@="8C>$4T.W-M)B-X130[)B-X130[/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!%:2!T)B-X130[<VTF(WA%-#LF(WA%-#L@;VX@;75U=&5N('-A
M;6$@:W5I;B!T)B-X130[<VTF(WA%-#LF(WA%-#LL('!A:71S:2!E='0F(WA%
M-#L@<V4@<&%L875T=&%A(&%R=F]N(&5P)B-X130[=&]S:2P@:F]S(&UE<FMK
M:6IO;F\@;"8C>$8V.WET>7D@=FEE<W1I;B!O='-A:VME:7-T82X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/E!I96YE;7!I(&MU:6X\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%0F(WA%-#MM)B-X130[('9E<G1A82!A;G1A86UA<VD@
M;'5K=6$@:F$@=FEE<W1I;B!O='-A:VME:7-S82!O;&5V86$@;'5K=6%R=F]A
M(&YU;65E<FES97-T:2!K97-K96XF(WA%-#LF(WA%-#MN+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^4&EE;F5M<&D@=&%I('EH="8C>$4T.W-U=7)I(&MU
M:6X\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%0F(WA%-#MM)B-X130[('9E
M<G1A82!A;G1A86UA<VD@;'5K=6$@:F$@=FEE<W1I;B!O='-A:VME:7-S82!O
M;&5V86$@;'5K=6%R=F]A(&YU;65E<FES97-T:2!K97-K96XF(WA%-#LF(WA%
M-#MN+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^66AT)B-X130[<W5U<FD@
M:W5I;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5"8C>$4T.VTF(WA%-#L@
M=F5R=&%A(&%N=&%A;6%S:2!L=6MU82!J82!V:65S=&EN(&]T<V%K:V5I<W-A
M(&]L979A82!L=6MU87)V;V$@;G5M965R:7-E<W1I(&ME<VME;B8C>$4T.R8C
M>$4T.VXN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3=75R96UP:2!T86D@
M>6AT)B-X130[<W5U<FD@:W5I;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5"8C>$4T.VTF(WA%-#L@=F5R=&%A(&%N=&%A;6%S:2!L=6MU82!J82!V:65S
M=&EN(&]T<V%K:V5I<W-A(&]L979A82!L=6MU87)V;V$@;G5M965R:7-E<W1I
M(&ME<VME;B8C>$4T.R8C>$4T.VXN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY3=75R96UP:2!K=6EN/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4)B-X
M130[;28C>$4T.R!V97)T86$@86YT86%M87-I(&QU:W5A(&IA('9I97-T:6X@
M;W1S86MK96ES<V$@;VQE=F%A(&QU:W5A<G9O82!N=6UE97)I<V5S=&D@:V5S
M:V5N)B-X130[)B-X130[;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G)U;&4M;F%M92(@<W1A=&4](G5P=&]D871E(B!M9#4](CAF86%F
M-S%E-&)F,F8Y,60Y-#-D-S=F.#`S9CEA,F0U(CX*("`@(#QT:71L93Y3=6]D
M871I;G,F(WA%-#LF(WA%-#MN="8C>$8V.SH@3FEM:3PO=&ET;&4^"B`@("`\
M<&%R83X*("`@(%0F(WA%-#MM)B-X130[(&]N('-I;G5N(',F(WA%-#LF(WA%
M-#MN;B8C>$8V.VQL92!A;G1A;6%S:2!K=79A879A(&YI;6DN(%9O:70@:R8C
M>$4T.WET="8C>$4T.R8C>$4T.R!T)B-X130[="8C>$4T.R!T=6YN:7-T86UA
M86X@97)I(',F(WA%-#LF(WA%-#MN="8C>$8V.VHF(WA%-#L@<W5O9&%T:6YS
M)B-X130[)B-X130[;G0F(WA&-CML:7-T87-S82X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G)U;&4M<W1O<"(@<W1A=&4](G5P=&]D871E
M(B!M9#4](C8W-V,Y,C!E9F9C83DU.3$R,V(W9#4S.6(S8C!D.#8T(CX*("`@
M(#QT:71L93Y3=6]D871I;G,F(WA%-#LF(WA%-#MN="8C>$8V.SH@3&]P971A
M('1A<FMI<W1U<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($IO<R!T)B-X130[
M;28C>$4T.R!A<V5T=7,@;VX@=F%L:71T=6YA(&IA(&IO<R!V:65S=&D@="8C
M>$4T.W-M)B-X130[)B-X130[(',F(WA%-#LF(WA%-#MN="8C>$8V.R8C>$8V
M.VXL(&YI:6X@="8C>$4T.VTF(WA%-#MN(&HF(WA%-#ML:V5E;B!T=6QE=FEA
M('-U;V1A='5K<VEA(&5I(&5N)B-X130[)B-X130[(&AU;VUI;VED82X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G9A8V%T:6]N(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB,F,Y93$R.3<S9#,V9F4Y-&%E8C<S8C,R9&(Y
M838T938B/@H@("`@/'1I=&QE/E!O:7-S86]L;W9I97-T:3PO=&ET;&4^"B`@
M("`\<&%R83X*("`@(%!O:7-S86]L;W9I97-T:2!O;B!A=71O;6%A='1I<V5S
M=&D@;"8C>$4T.VAE=&5T="8C>$4T.W8F(WA%-#L@=F%S=&%U<W9I97-T:2P@
M:F]K82!L)B-X130[:&5T970F(WA%-#LF(WA%-#MN(&YI:6QL92!H96YK:6PF
M(WA&-CMI;&QE+"!J;W1K82!O=F%T(&PF(WA%-#MH971T)B-X130[;F5E="!S
M:6YU;&QE(',F(WA%-#MH:R8C>$8V.W!O<W1I82X@4&]I<W-A;VQO=FEE<W1I
M)B-X130[(&LF(WA%-#MY=&5T)B-X130[)B-X130[;B!Y;&5E;G,F(WA%-#L@
M<VEL;&]I;B!K=6X@;VQE="!P;VES<V$@<&ED96UM)B-X130[;B!A:6MA82!T
M86D@970@<"8C>$4T.R8C>$4T.W-E(&QU:V5M86%N('9I97-T96HF(WA%-#MS
M:2!P:61E;7`F(WA%-#LF(WA%-#MN(&%I:V%A;BX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G9A8V%T:6]N+6)U;&LB('-T871E/2)U<'1O
M9&%T92(@;60U/2(V9C9E-#$W.&4X,&8T-F4W.#<V8S=E935D,&%C-3-B-R(^
M"B`@("`\=&ET;&4^4&]I<W-A;VQO=FEE<W1I.B`F(WA#-#ML)B-X130[('9A
M<W1A82!J;W5K:V]V:65S=&5I:&EN/"]T:71L93X*("`@(#QP87)A/@H@("`@
M5F%L:71S96UA;&QA('0F(WA%-#MM)B-X130[;B!A<V5T=6MS96X@=F%S=&%U
M<W9I97-T96HF(WA%-#L@96D@;"8C>$4T.VAE=&5T)B-X130[+"!J;W,@=FEE
M<W1I(&]N('1U;&QU="!P;W-T:6QI<W1A;B!K875T=&$@=&%I(&IO<R!V:65S
M=&D@;VX@;65R:VET='D@:F]U:VMO=FEE<W1I:W-I+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB=F%C871I;VXM9&%Y<R(@<W1A=&4](G5P
M=&]D871E(B!M9#4](C(U8F$W-&,P93<Y8V4W,C(S-S<Y-65B.#`Y964T-3@U
M(CX*("`@(#QT:71L93Y0;VES<V%O;&]V:65S=&DZ(%9A<W1A=7-V)B-X130[
M;&D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!*;W,@;W-O:71T965S965N(&]N
M(&PF(WA%-#MH971E='1Y(&%U=&]M86%T=&EN96X@=F%S=&%U<W9I97-T:2P@
M;FEI;B!S975R86%V82!V:65S=&D@<V%M86%N(&]S;VET=&5E<V5E;B!L)B-X
M130[:&5T970F(WA%-#LF(WA%-#MN('9A<W1A('0F(WA%-#MS<R8C>$4T.R!M
M)B-X130[)B-X130[<FET96QL>6X@<"8C>$4T.VEV)B-X130[;B!P)B-X130[
M)B-X130[<W0F(WA%-#LN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)V86-A=&EO;BUM>65M86EL(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M968S9F$W,&4Y-#!E9#$T-S(R-S9C,&9D935A93)A960B/@H@("`@/'1I=&QE
M/E!O:7-S86]L;W9I97-T:3H@3VUA="!O<V]I='1E970\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!*;W,@<&]S=&EK86YS:6]O<VD@='5L964@=FEE<W1E:B8C
M>$4T.R!U<V5A;6UA;&QA(&5R:2!O<V]I='1E96QL82P@;FEI;B!M)B-X130[
M)B-X130[<FET=&5L92!T)B-X130[<W,F(WA%-#L@;F4@;W-O:71T965T+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=F%C871I;VXM;F]R
M97-P;VYS92(@<W1A=&4](G5P=&]D871E(B!M9#4](C)B-S)E,3)B-CDX.6,Y
M968Q-C8W834Y,#0P8S<P,S$P(CX*("`@(#QT:71L93Y0;VES<V%O;&]V:65S
M=&DZ($5I('9A<W1A=6MS:6$\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`F(WA#
M-#ML)B-X130[(&PF(WA%-#MH970F(WA%-#L@=F%S=&%U:W-I82!N)B-X130[
M:6AI;B!O<V]I='1E:7-I:6XN($IO:V%I;F5N(&]S;VET92!P:70F(WA%-#LF
M(WA%-#L@;&%I='1A82!O;6%L;&4@<FEV:6QL965N+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB=F%C871I;VXM<F5A<V]N(B!S=&%T93TB
M=7!T;V1A=&4B(&UD-3TB9#1D83)F,V$P9#,U-V4P,#DU,&5C-3=D.3@T8V)C
M964B/@H@("`@/'1I=&QE/E!O:7-S86]L;W9I97-T:3HZ(%!O:7-S86]L;VX@
M<WEY/"]T:71L93X*("`@(#QP87)A/@H@("`@5"8C>$4T.W0F(WA%-#L@=&5K
M<W1I)B-X130[(&LF(WA%-#MY=&5T)B-X130[)B-X130[;B!P;VES<V%O;&]V
M:65S=&EE;B!T96MS=&EN)B-X130[+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB=F%C871I;VXM<W5B:F5C="(@<W1A=&4](G5P=&]D871E
M(B!M9#4](F-E,39C-V,V83`X.3DS.#(Q,C`X8V9B964P8C$X.&$P(CX*("`@
M(#QT:71L93Y0;VES<V%O;&]V:65S=&DZ.B!6:65S=&EN(&]T<VEK:V\\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!4)B-X130[="8C>$4T.R!T96MS=&DF(WA%
M-#L@:R8C>$4T.WET970F(WA%-#LF(WA%-#MN('!O:7-S86]L;W9I97-T:65N
M(&]T<VEK:V]N82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G=H:71E;&ES="(@<W1A=&4](G5P=&]D871E(B!M9#4](F5C8F8W,#`P9C$P
M-S@S,F0V.&)D-V)A.&8U,3(Q.3`Y(CX*("`@(#QT:71L93Y686QK;VEN96X@
M;&ES=&$\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!686QK;VEN96X@;&ES=&$@
M;VX@;&ES=&$@;FEI<W0F(WA%-#L@;W-O:71T96ES=&$L(&IO:61E;B!H86QU
M870@='5L979A;B!A:6YA('!E<FEL;&4@<&]S=&EK86YS:6]O<VDN($IO:V%I
M;F5N(&]S;VET92!P:70F(WA%-#LF(WA%-#L@;&%I='1A82!O;6%L;&4@<FEV
M:6QL965N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=VAI
M=&5L:7-T+6%D9')E<W-E<R(@<W1A=&4](G5P=&]D871E(B!M9#4](CAF93`U
M-&,Q8C4U939A9&,X,60Q9#@U,C5C,3,Q-C,W(CX*("`@(#QT:71L93Y686QK
M;VEN96X@;&ES=&$Z($]S;VET=&5E=#PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($IO:V%I;F5N(&]S;VET92!P:70F(WA%-#LF(WA%-#L@;&%I='1A82!O;6%L
M;&4@<FEV:6QL965N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG
M;R]L;V-A;&4O9G)?1E(O````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,3<V,C``(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]F<E]&4B],0U]-15-304=%4R\`
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0W
M`#`R,30P-0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE+V9R
M7T92+TQ#7TU%4U-!1T53+VEN9V\N;6\`````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T
M-34U,C(`,3`T,3<S-C(W-#<`,#(R-S$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-X2!)4`````,0@``!P```"D00``[0H`
M`"R#````````X*X```X```#AK@``#P```/"N```-`````*\```@````.KP``
M"P```!>O```,````(Z\```0````PKP``!````#6O```#````.J\``!@````^
MKP``&P```%>O```M````<Z\``!T```"AKP``)````+^O```I````Y*\``!D`
M```.L```)@```"BP```,````3[```"0```!<L```#P```(&P```+````D;``
M``X```"=L```!0```*RP```H````LK````@```#;L```"@```.2P```5````
M[[```!(````%L0``"P```!BQ``"%````)+$```X```"JL0``"@```+FQ```-
M````Q+$```X```#2L0``$0```.&Q```-````\[$```P````!L@``#0````ZR
M```&````'+(``)0````CL@``"@```+BR```/````P[(``!@```#3L@``#```
M`.RR```.````^;(```X````(LP``"````!>S```)````(+,``"X````JLP``
M&@```%FS```R````=+,``#@```"GLP``5````."S``!1````-;0``%H```"'
MM```5P```.*T```T````.K4```D```!OM0``#0```'FU```'````A[4```H`
M``"/M0``#P```)JU```%````JK4```8```"PM0``$0```+>U```(````R;4`
M``D```#2M0``"0```-RU```E````YK4``"`````,M@``$P```"VV```0````
M0;8```\```!2M@``"@```&*V```A````;;8```\```"/M@```P```)^V```/
M````H[8``!0```"SM@``"0```,BV```-````TK8``!(```#@M@``&0```/.V
M```>````#;<```\````LMP``"@```#RW```/````1[<```@```!7MP``)```
M`&"W```4````A;<``!8```":MP``"````+&W``!.````NK<``"T````)N```
M&0```#>X```3````4;@```<```!EN```#````&VX```L````>K@```X```"G
MN````P```+:X```+````NK@```<```#&N```!P```,ZX```%````UK@```4`
M``#<N```"@```.*X```#````[;@``!<```#QN```"@````FY```/````%+D`
M``X````DN0``%````#.Y```8````2+D``",```!AN0``#@```(6Y```4````
ME+D``!<```"IN0``%P```,&Y```7````V;D``!,```#QN0``#P````6Z```.
M````%;H``!\````DN@``'0```$2Z```'````8KH```8```!JN@``"````'&Z
M```/````>KH```8```"*N@``"````)&Z```*````FKH``!,```"EN@``%```
M`+FZ```+````SKH``!````#:N@``%0```.NZ```-`````;L``!4````/NP``
M!P```"6[```0````+;L```4````^NP``%0```$2[```1````6KL```P```!L
MNP``*@```'F[```[````I+L``#@```#@NP``"0```!F\```'````([P``!0`
M```KO````P```$"\```%````1+P``!````!*O```"0```%N\```3````9;P`
M`#D```!YO```$@```+.\```G````QKP``"P```#NO```*@```!N]```E````
M1KT```H```!LO0``!@```'>]```)````?KT```<```"(O0``+P```)"]```W
M````P+T``"X```#XO0``50```">^```M````?;X``"T```"KO@``/0```-F^
M```_````%[\``"T```!7OP``0````(6_```C````QK\``",```#JOP``0```
M``[````M````3\```#,```!]P```)0```+'````5````U\```!D```#MP```
M*0````?!```D````,<$``"@```!6P0``,@```'_!```1````LL$```H```#$
MP0``#````,_!```*````W,$``!````#GP0``%@```/C!```6````#\(```<`
M```FP@``!P```"["```4````-L(```H```!+P@``"````%;"```G````7\(`
M``@```"'P@```P```)#"```+````E,(```<```"@P@``!P```*C"```&````
ML,(```4```"WP@``!P```+W"```&````Q<(```@```#,P@``"0```-7"```.
M````W\(``#L```#NP@``$P```"K#```5````/L,``"D```!4PP``#@```'[#
M```*````C<,```0```"8PP``!````)W#```'````HL,```D```"JPP``!@``
M`+3#```1````N\,```<```#-PP``%@```-7#```$````[,,```@```#QPP``
M!@```/K#```-`````<0```8````/Q```'@```!;$```1````-<0```@```!'
MQ```#0```%#$```,````7L0```<```!KQ````P```'/$```#````=\0``!<`
M``![Q```$P```)/$```=````I\0```@```#%Q```!````,[$```(````T\0`
M``@```#<Q```00```.7$```:````)\4``"L```!"Q0``(````&[%```5````
MC\4```8```"EQ0``!@```*S%```5````L\4``!@```#)Q0``(@```.+%```N
M````!<8``!T````TQ@``(0```%+&``!4````=,8``"D```#)Q@``"@```//&
M```'````_L8```<````&QP``#@````['```5````'<<```X````SQP```@``
M`$+'```*````1<<```\```!0QP``#0```&#'```/````;L<```T```!^QP``
M"0```(S'```4````EL<```8```"KQP``&````++'```=````R\<``!,```#I
MQP``$0```/W'```4````#\@```0````DR```!@```"G(```4````,,@``%0`
M``!%R```#@```)K(``!D````J<@```0````.R0``#@```!/)```%````(LD`
M``4````HR0``&P```"[)```:````2LD``!,```!ER0``$0```'G)```1````
MB\D``!P```"=R0``*@```+K)```0````Y<D``"$```#VR0``!0```!C*```3
M````'LH```L````RR@``$@```#[*```*````4<H```\```!<R@``#0```&S*
M```1````>LH``!,```",R@``#````*#*```&````K<H```P```"TR@``!@``
M`,'*```7````R,H``!````#@R@``$0```/'*```(`````\L```4````,RP``
M#````!++```0````'\L```4````PRP``#0```#;+```&````1,L```<```!+
MRP``#0```%/+```'````8<L```L```!IRP``!P```'7+```'````?<L```D`
M``"%RP``"0```(_+```*````F<L``!D```"DRP``/0```+[+```=````_,L`
M``P````:S```$````"?,```%````.,P``"4````^S```$@```&3,```3````
M=\P``"L```"+S```.P```+?,```@````\\P```@````4S0``-@```!W-```(
M````5,T``"$```!=S0``$````'_-```(````D,T```P```"9S0``!@```*;-
M```$````K<T```<```"RS0``#P```+K-```*````RLT```X```#5S0``!P``
M`.3-```*````[,T```T```#WS0``'P````7.```<````)<X``"$```!"S@``
M'@```&3.```9````@\X``!X```"=S@``'0```+S.```;````VLX``"````#V
MS@``+@```!?/```F````1L\``!P```!MSP``'@```(K/```<````J<\``"8`
M``#&SP``*P```.W/```S````&=```"8```!-T```*P```'30```X````H-``
M`!T```#9T```%0```/?0```O````#=$``"`````]T0``$@```%[1```I````
M<=$``!X```";T0``(````+K1```2````V]$``*(```#NT0``%@```)'2```C
M````J-(``"@```#,T@``*0```/72```H````'],``!\```!(TP``%0```&C3
M```@````?M,``"4```"?TP``*````,73```M````[M,``#`````<U```D@``
M`$W4```A````X-0``!8````"U0``'````!G5```F````-M4``"H```!=U0``
M00```(C5``!$````RM4```P````/U@``!P```!S6```'````)-8```8````L
MU@``#0```#/6```0````0=8``!$```!2U@``$@```&36```3````=]8``!(`
M``"+U@``!P```)[6```$````IM8``!````"KU@``$````+S6```,````S=8`
M``X```#:U@``#0```.G6```/````]]8``!,````'UP``#0```!O7```H````
M*=<```,```!2UP``#0```%;7```&````9-<``!$```!KUP``%P```'W7```;
M````E=<```X```"QUP```@```,#7```(````P]<```H```#,UP``20```-?7
M```%````(=@``!`````GV```#P```#C8```$````2-@```T```!-V```#@``
M`%O8```#````:M@```X```!NV```$0```'W8```(````C]@```\```"8V```
M#P```*C8```'````N-@```T```#`V```$````,[8```-````W]@```L```#M
MV```!@```/G8```)`````-D```L````*V0``$````!;9```,````)]D```H`
M```TV0``$0```#_9```9````4=D```L```!KV0``#0```'?9```B````A=D`
M`!D```"HV0``&P```,+9```T````WMD```H````3V@``&````![:```9````
M-]H``!8```!1V@``!P```&C:```B````<-H``!4```"3V@``(0```*G:```E
M````R]H``!$```#QV@``#0````/;```'````$=L``!0````9VP``"P```"[;
M```B````.ML``"\```!=VP``"P```(W;```)````F=L``!D```"CVP``"P``
M`+W;```7````R=L``!<```#AVP``"0```/G;```*`````]P```@````.W```
M%@```!?<```/````+MP``!D````^W```.@```%C<```6````D]P```X```"J
MW```&````+G<```(````TMP``"\```#;W```#0````O=```F````&=T```@`
M``!`W0``0P```$G=```2````C=T```\```"@W0``$````+#=```-````P=T`
M`"$```#/W0``"````/'=```2````^MT``!\````-W@``"````"W>```+````
M-MX``"\```!"W@``#@```'+>```%````@=X```8```"'W@``10```([>```#
M````U-X```<```#8W@``!````.#>```'````Y=X```H```#MW@``"@```/C>
M```/`````]\``!`````3WP``%P```"3?```1````/-\``!D```!.WP``%P``
M`&C?```)````@-\```4```"*WP``"P```)#?```*````G-\```(```"GWP``
M!0```*K?```-````L-\``!L```"^WP``%P```-K?```4````\M\```D````'
MX```#@```!'@```-````(.```!(````NX```"0```$'@```X````2^```"``
M``"$X```!P```*7@```(````K>````D```"VX```#@```,#@``![````S^``
M`!@```!+X0``&````&3A```(````?>$``!$```"&X0``!P```)CA```%````
MH.$``!@```"FX0``'@```+_A```;````WN$``!D```#ZX0``&P```!3B```9
M````,.(``!,```!*X@``!P```%[B```(````9N(```8```!OX@``!@```';B
M```0````?>(```\```".X@``$````)[B```/````K^(```L```"_X@``#P``
M`,OB```,````V^(```\```#HX@``!P```/CB```.`````.,```8````/XP``
M!@```!;C```.````'>,```P````LXP``*````#GC```/````8N,```@```!R
MXP``"````'OC```3````A.,``!X```"8XP``(0```+?C```@````V>,``!D`
M``#ZXP``%P```!3D```E````+.0``!<```!2Y```%@```&KD```$````@>0`
M`!L```"&Y```#0```*+D```,````L.0```,```"]Y```!0```,'D```(````
MQ^0```H```#0Y```#````-OD```+````Z.0``!````#TY```#`````7E```.
M````$N4```L````AY0``!````"WE```$````,N4``!,````WY0``%````$OE
M```,````8.4```D```!MY0``#@```'?E```+````AN4``!L```"2Y0``$P``
M`*[E```9````PN4``!L```#<Y0``#@```/CE```+````!^8```P````3Y@``
M%0```"#F```-````-N8``$,```!$Y@``,0```(CF``!"````NN8``$<```#]
MY@``3P```$7G```]````E><``$X```#3YP``$0```"+H```'````-.@```<`
M```\Z```"@```$3H```-````3^@```D```!=Z```!````&?H```%````;.@`
M``,```!RZ```&````';H```*````C^@```0```":Z```)0```)_H```F````
MQ>@```X```#LZ```?````/OH```5````>.D```4```".Z0``!P```)3I```,
M````G.D```@```"IZ0``"@```++I```&````O>D```<```#$Z0``.0```,SI
M```(````!NH```T````/Z@```@```!WJ```&````(.H```8````GZ@``%```
M`"[J```-````0^H``!````!1Z@``&P```&+J```$````?NH```D```"#Z@``
M$````(WJ```)````GNH```D```"HZ@``!0```++J```:````N.H```@```#3
MZ@``!@```-SJ```9````X^H```X```#]Z@``!P````SK```'````%.L```4`
M```<ZP``"0```"+K```*````+.L```(````WZP``!@```#KK```+````0>L`
M``T```!-ZP``"0```%OK```,````9>L``!@```!RZP``!@```(OK```2````
MDNL```D```"EZP``!P```*_K```4````M^L``!T```#,ZP``0@```.KK```E
M````+>P``"4```!3[```!@```'GL```*````@.P```0```"+[```"0```)#L
M```(````FNP``!$```"C[```"0```+7L```&````O^P```T```#&[```!@``
M`-3L```$````V^P``#D```#@[```/0```!KM```Z````6.T``!X```"3[0``
M!0```++M```.````N.T```0```#'[0``!@```,SM```'````T^T``"$```#;
M[0``#0```/WM```5````"^X```8````A[@``!````"CN```1````+>X```8`
M```_[@``"@```$;N```B````4>X```0```!T[@``!0```'GN```=````?^X`
M``0```"=[@``#````*+N```.````K^X```H```"^[@``"````,GN```)````
MTNX```4```#<[@``.@```.+N```P````'>\``#4```!.[P``*0```(3O``!'
M````KN\``#@```#V[P``*0```"_P```_````6?```"X```"9\```+0```,CP
M```?````]O````\````6\0``$@```";Q```+````.?$``"8```!%\0``*0``
M`&SQ```D````EO$``"8```"[\0``"````.+Q```*````Z_$```D```#V\0``
M!P````#R```@````"/(``"`````I\@``)@```$KR```*````<?(``!D```!\
M\@``*0```);R```6````P/(``!(```#7\@``!P```.KR```*````\O(```P`
M``#]\@``#P````KS```0````&O,``$`````K\P``<````&SS``!F````W?,`
M``X```!$]```"0```%/T```*````7?0``!(```!H]```$P```'OT```,````
MC_0```8```"<]```#P```*/T```)````L_0``!(```"]]```$````-#T```1
M````X?0``!P```#S]```(P```!#U``!J````-/4```\```"?]0``!0```*_U
M```0````M?4``$,```#&]0``"0````KV```R````%/8```0```!']@``"P``
M`$SV```@````6/8``!0```!Y]@``#````([V```,````F_8```\```"H]@``
M%0```+CV```I````SO8``"H```#X]@``)@```"/W```G````2O<``"D```!R
M]P``*@```)SW```9````Q_<``$(```#A]P``$0```"3X```2````-O@``!,`
M``!)^```%````%WX```/````<O@``!8```""^```%P```)GX```0````L?@`
M`!$```#"^```-````-3X```3````"?D``!(````=^0``-0```##Y```4````
M9OD```<```![^0``#````(/Y```@````D/D``!````"Q^0``%````,+Y```1
M````U_D``!<```#I^0``'`````'Z```3````'OH``!0````R^@``&@```$?Z
M```1````8OH``!H```!T^@``'@```(_Z```:````KOH``!,```#)^@``%0``
M`-WZ```1````\_H``!<````%^P``%````!W[```7````,OL``!4```!*^P``
M"0```&#[```0````:OL``!D```![^P``!````)7[```'````FOL```(```"B
M^P``"P```*7[```%````L?L``!$```"W^P``!@```,G[```&````T/L```8`
M``#7^P``!0```-[[```'````Y/L```<```#L^P``!0```/3[```6````^OL`
M``8````1_```!@```!C\```$````'_P```0````D_```!P```"G\```.````
M,?P```P```!`_```#````$W\```-````6OP```H```!H_```#@```'/\```%
M````@OP``"@```"(_```#@```+'\```,````P/P```\```#-_```"@```-W\
M```(````Z/P```D```#Q_```*P```/O\```$````)_T```@````L_0``)@``
M`#7]```2````7/T```\```!O_0``!@```'_]```*````AOT```<```"1_0``
M"````)G]```@````HOT```D```##_0``%````,W]```,````XOT```T```#O
M_0``#@```/W]```6````#/X``!$````C_@``!@```#7^```#````//X```8`
M``!`_@``&0```$?^```'````8?X```0```!I_@``"P```&[^```+````>OX`
M``<```"&_@``"0```([^```5````F/X```4```"N_@``!P```+3^```6````
MO/X```T```#3_@``#0```.'^```*````[_X``!````#Z_@``#P````O_```1
M````&_\``!<````M_P``"@```$7_```1````4/\```@```!B_P``!````&O_
M```/````</\``#H```"`_P``!0```+O_```,````P?\``!X```#._P``#@``
M`.W_```0````_/\```L````-``$`#````!D``0`)````)@`!``<````P``$`
M!P```#@``0`*````0``!``D```!+``$`#@```%4``0`0````9``!`!L```!U
M``$`&````)$``0`:````J@`!``H```#%``$`"0```-```0`*````V@`!``P`
M``#E``$`#P```/(``0`(`````@$!``8````+`0$`'````!(!`0`'````+P$!
M``4````W`0$`"P```#T!`0!'````20$!``T```"1`0$`"0```)\!`0`$````
MJ0$!``,```"N`0$`$P```+(!`0`3````Q@$!`!,```#:`0$`"@```.X!`0`"
M````^0$!``0```#\`0$`)0````$"`0`#````)P(!``4````K`@$`*@```#$"
M`0`*````7`(!``4```!G`@$`!````&T"`0`*````<@(!``T```!]`@$`!@``
M`(L"`0`(````D@(!``@```";`@$`!````*0"`0`%````J0(!`&@```"O`@$`
M"0```!@#`0`,````(@,!`!`````O`P$`&````$`#`0`%````60,!``8```!?
M`P$`$````&8#`0`;````=P,!`"\```"3`P$`$````,,#`0`*````U`,!`!L`
M``#?`P$`#P```/L#`0`*````"P0!``D````6!`$`$P```"`$`0`;````-`0!
M`!@```!0!`$`%P```&D$`0`?````@00!``X```"A!`$`B0```+`$`0")````
M.@4!``,```#$!0$`!P```,@%`0`(````T`4!``<```#9!0$`"@```.$%`0`+
M````[`4!``<```#X!0$`40`````&`0`0````4@8!``P```!C!@$`#0```'`&
M`0`:````?@8!`$H```"9!@$`&0```.0&`0`&````_@8!`!H````%!P$`)0``
M`"`'`0`&````1@<!``8```!-!P$`'P```%0'`0`&````=`<!``D```![!P$`
M&````(4'`0`7````G@<!`"@```"V!P$`!@```-\'`0`-````Y@<!`"(```#T
M!P$`)@```!<(`0!7````/@@!`!,```"6"`$`&0```*H(`0`;````Q`@!`",`
M``#@"`$`$P````0)`0`"````&`D!``L````;"0$`"````"<)`0`-````,`D!
M``H````^"0$`!P```$D)`0`4````40D!``8```!F"0$`"````&T)`0`.````
M=@D!``<```"%"0$`"@```(T)`0`+````F`D!`#(```"D"0$`!P```-<)`0`,
M````WPD!``T```#L"0$`#````/H)`0`$````!PH!``D````,"@$`"0```!8*
M`0`*````(`H!``X````K"@$`#````#H*`0`'````1PH!``D```!/"@$`!P``
M`%D*`0`*````80H!`!L```!L"@$`#P```(@*`0`2````F`H!``H```"K"@$`
M%@```+8*`0`)````S0H!`!````#7"@$`!P```.@*`0`2````\`H!`"D````#
M"P$`!````"T+`0`'````,@L!``4````Z"P$`!0```$`+`0`+````1@L!`!0`
M``!2"P$`$0```&<+`0`:````>0L!`!8```"4"P$`%````*L+`0`7````P`L!
M`!@```#8"P$`'````/$+`0`9````#@P!``<````H#`$`!0```#`,`0`-````
M-@P!``P```!$#`$`$0```%$,`0`(````8PP!``@```!L#`$`%P```'4,`0`+
M````C0P!``P```"9#`$`'P```*8,`0`:````Q@P!`!,```#A#`$`!````/4,
M`0`*````^@P!``0````%#0$`#0````H-`0`,````&`T!``4````E#0$`"0``
M`"L-`0`%````-0T!``<````[#0$`!0```$,-`0`$````20T!``(```!.#0$`
M+P```%$-`0`X````@0T!`"P```"Z#0$`(P```.<-`0`F````"PX!`!(````R
M#@$`*0```$4.`0`R````;PX!``H```"B#@$`+````*T.`0`N````V@X!`#,`
M```)#P$`,P```#T/`0`X````<0\!``\```"J#P$`&````+H/`0`0````TP\!
M`"X```#D#P$`%````!,0`0`/````*!`!`!,````X$`$`%0```$P0`0`4````
M8A`!`!(```!W$`$`%````(H0`0`5````GQ`!`"T```"U$`$`+0```.,0`0`Q
M````$1$!`"X```!#$0$`+P```'(1`0`L````HA$!`&(```#/$0$`$P```#(2
M`0`-````1A(!``@```!4$@$`%````%T2`0`7````<A(!``@```"*$@$`%```
M`),2`0`,````J!(!`"L```"U$@$`(0```.$2`0`:`````Q,!``D````>$P$`
M10```"@3`0!!````;A,!``0```"P$P$`$P```+43`0`4````R1,!``X```#>
M$P$`$P```.T3`0`8`````10!``8````:%`$`"0```"$4`0`*````*Q0!``\`
M```V%`$`#````$84`0`0````4Q0!``<```!D%`$`#@```&P4`0`%````>Q0!
M`!L```"!%`$`"````)T4`0`&````IA0!`!0```"M%`$`$0```,(4`0`.````
MU!0!`#@```#C%`$``@```!P5`0`&````'Q4!``X````F%0$`!0```#45`0`'
M````.Q4!``X```!#%0$`!@```%(5`0`H````614!``P```""%0$`'````(\5
M`0`$````K!4!`"D```"Q%0$`%P```-L5`0`?````\Q4!`%P````3%@$`%```
M`'`6`0`^````A18!`!\```#$%@$`$````.06`0`'````]18!`!X```#]%@$`
M#@```!P7`0`,````*Q<!``P````X%P$`$P```$47`0`*````61<!`!T```!D
M%P$`&0```((7`0`%````G!<!`!$```"B%P$`#0```+07`0`1````PA<!`"0`
M``#4%P$`$@```/D7`0`5````#!@!`!(````B&`$`#@```#48`0`9````1!@!
M``@```!>&`$`"0```&<8`0`-````<1@!``H```!_&`$`!P```(H8`0`/````
MDA@!``8```"B&`$`"P```*D8`0`:````M1@!``H```#0&`$`!P```-L8`0`(
M````XQ@!``4```#L&`$`'P```/(8`0`&````$AD!`!`````9&0$`"````"H9
M`0`-````,QD!``@```!!&0$`'@```$H9`0`2````:1D!`"P```!\&0$`&@``
M`*D9`0`)````Q!D!``H```#.&0$`%0```-D9`0`%````[QD!`!0```#U&0$`
M!`````H:`0`0````#QH!``8````@&@$`!P```"<:`0`>````+QH!`"@```!.
M&@$`"@```'<:`0`<````@AH!`!$```"?&@$`"P```+$:`0`:````O1H!`!0`
M``#8&@$`!````.T:`0`$````\AH!``L```#W&@$`!0````,;`0`&````"1L!
M``@````0&P$`!@```!D;`0`*````(!L!`!L````K&P$`-````$<;`0`T````
M?!L!`"````"Q&P$`*0```-(;`0`@````_!L!`$$````='`$`&@```%\<`0`H
M````>AP!`"@```"C'`$`*0```,P<`0!0````]AP!`"(```!''0$`!@```&H=
M`0`(````<1T!``4```!Z'0$`"````(`=`0`9````B1T!`!D```"C'0$`*@``
M`+T=`0`C````Z!T!`!D````,'@$`+@```"8>`0`T````51X!``@```"*'@$`
M%P```),>`0`*````JQX!``<```"V'@$`(0```+X>`0`0````X!X!``X```#Q
M'@$`"P`````?`0`'````#!\!`!,````4'P$`"````"@?`0`+````,1\!``H`
M```]'P$`%````$@?`0`/````71\!`#(```!M'P$`"P```*`?`0`%````K!\!
M``4```"R'P$`!0```+@?`0`7````OA\!``<```#6'P$`#P```-X?`0`$````
M[A\!``H```#S'P$`"0```/X?`0`+````""`!``T````4(`$`#````"(@`0`.
M````+R`!``4````^(`$`!````$0@`0`-````22`!`#(```!7(`$`10```(H@
M`0`(````T"`!``L```#9(`$`%P```.4@`0`'````_2`!`!X````%(0$`%```
M`"0A`0`%````.2$!`!(````_(0$`$@```%(A`0`4````92$!``8```!Z(0$`
M!P```($A`0`.````B2$!`"H```"8(0$`!@```,,A`0`,````RB$!``T```#7
M(0$`$0```.4A`0`+````]R$!`#8````#(@$`"@```#HB`0`B````12(!``L`
M``!H(@$`#P```'0B`0`R````A"(!`"4```"W(@$`,````-TB`0`Q````#B,!
M`"T```!`(P$`#@```&XC`0`)````?2,!``L```"'(P$`!0```),C`0`.````
MF2,!`!,```"H(P$`$@```+PC`0`'````SR,!`!8```#7(P$`$0```.XC`0`4
M`````"0!`!,````5)`$`!P```"DD`0`4````,20!`!@```!&)`$`!P```%\D
M`0`%````9R0!``P```!M)`$`#````'HD`0`2````AR0!``0```":)`$`!P``
M`)\D`0`*````IR0!``L```"R)`$`#````+XD`0`.````RR0!``X```#:)`$`
M!0```.DD`0`$````[R0!``L```#T)`$`#``````E`0`-````#24!``P````;
M)0$`"0```"@E`0`%````,B4!`"X````X)0$`)@```&<E`0`C````CB4!``,`
M``"R)0$`$@```+8E`0`&````R24!`!X```#0)0$`&````.\E`0`E````""8!
M``T````N)@$`"0```#PF`0`?````1B8!``,```!F)@$`!P```&HF`0`*````
M<B8!``(```!])@$`#````(`F`0`5````C28!``L```"C)@$`&0```*\F`0`@
M````R28!`!(```#J)@$`!0```/TF`0`*`````R<!`!4````.)P$`$@```"0G
M`0`,````-R<!``0```!$)P$`"0```$DG`0`'````4R<!``P```!;)P$`#0``
M`&@G`0!2````=B<!`!<```#))P$`)````.$G`0`2````!B@!``<````9*`$`
M!@```"$H`0`/````*"@!`!,````X*`$`'@```$PH`0`@````:R@!``8```",
M*`$`#@```),H`0`$````HB@!``P```"G*`$`#0```+0H`0`.````PB@!`!4`
M``#1*`$`$@```.<H`0`/````^B@!`!0````**0$`"@```!\I`0`;````*BD!
M`!````!&*0$`"P```%<I`0`4````8RD!`&D```!X*0$`&@```.(I`0`7````
M_2D!`"<````5*@$`&@```#TJ`0`7````6"H!`!L```!P*@$`&0```(PJ`0`?
M````IBH!`!,```#&*@$`$P```-HJ`0`(````[BH!``8```#W*@$`!P```/XJ
M`0`(````!BL!``D````/*P$`%0```!DK`0`-````+RL!`",````]*P$`#0``
M`&$K`0`3````;RL!``@```"#*P$``P```(PK`0!&````D"L!`#\```#7*P$`
M-P```!<L`0!7````3RP!`!X```"G+`$`!0```,8L`0`?````S"P!`"\```#L
M+`$`"@```!PM`0`(````)RT!``T````P+0$`+0```#XM`0`$````;"T!`!(`
M``!Q+0$`$P```(0M`0!/````F"T!`"4```#H+0$`'`````XN`0`+````*RX!
M`!\````W+@$`'0```%<N`0`E````=2X!`"````";+@$`)````+PN`0`@````
MX2X!``L````"+P$`!P````XO`0`-````%B\!``P````D+P$`%P```#$O`0`&
M````22\!`#D```!0+P$`#````(HO`0`'````ER\!``D```"?+P$`$P```*DO
M`0`)````O2\!``0```#'+P$`$````,PO`0`(````W2\!``@```#F+P$`!```
M`.\O`0`+````]"\!``P`````,`$`$@````TP`0`1````(#`!``P````R,`$`
M&@```#\P`0`/````6C`!``<```!J,`$`#0```'(P`0`4````@#`!``X```"5
M,`$`#````*0P`0`;````L3`!`"P```#-,`$`$P```/HP`0`<````#C$!`"@`
M```K,0$`!@```%0Q`0`'````6S$!`!,```!C,0$`!0```'<Q`0`$````?3$!
M`!<```"",0$`"@```)HQ`0`,````I3$!``D```"R,0$`!@```+PQ`0`)````
MPS$!``@```#-,0$`"0```-8Q`0`*````X#$!`!$```#K,0$`!@```/TQ`0`C
M````!#(!``X````H,@$`#@```#<R`0`-````1C(!``L```!4,@$`'0```&`R
M`0`+````?C(!``(```"*,@$`'````(TR`0`=````JC(!``<```#(,@$`!@``
M`-`R`0!D````US(!``D````\,P$`!P```$8S`0`F````3C,!`#@```!U,P$`
M&@```*XS`0`J````R3,!`#L```#T,P$`*````#`T`0`T````630!`!D```".
M-`$`%0```*@T`0`%````OC0!``<```#$-`$`"````,PT`0`'````U30!``4`
M``#=-`$`!P```.,T`0`.````ZS0!``D```#Z-`$`!@````0U`0`(````"S4!
M``L````4-0$`!P```"`U`0`(````*#4!``<````Q-0$`%@```#DU`0`)````
M4#4!``8```!:-0$`"P```&$U`0`0````;34!``8```!^-0$`'````(4U`0`4
M````HC4!``<```"W-0$`$0```+\U`0`(````T34!``X```#:-0$`"````.DU
M`0`%````\C4!`!````#X-0$`"0````DV`0`0````$S8!``8````D-@$`&0``
M`"LV`0`*````138!`!P```!0-@$`!P```&TV`0`%````=38!`!````![-@$`
M%````(PV`0`+````H38!``T```"M-@$`*````+LV`0`8````Y#8!`!<```#]
M-@$`!````!4W`0`)````&C<!``H````D-P$`!P```"\W`0`"````-S<!``X`
M```Z-P$`"````$DW`0`C````4C<!`#@```!V-P$`)@```*\W`0`Q````UC<!
M`"<````(.`$`9````#`X`0`4````E3@!`%4```"J.`$`.``````Y`0!*````
M.3D!`%L```"$.0$`*````.`Y`0`1````"3H!`#@````;.@$`*````%0Z`0`L
M````?3H!`"8```"J.@$`&P```-$Z`0`^````[3H!`*D!```L.P$`(P```-8\
M`0`7````^CP!`$@````2/0$`A0```%L]`0`P````X3T!`"4````2/@$`00``
M`#@^`0!;````>CX!`$D```#6/@$`,0```"`_`0`=````4C\!`!@```!P/P$`
M*P```(D_`0`A````M3\!`!\```#7/P$`*P```/<_`0`A````(T`!`"<```!%
M0`$`.@```&U``0`=````J$`!`!$```#&0`$`,P```-A``0`E````#$$!`"<`
M```R00$`(````%I!`0`?````>T$!`#````";00$`:0```,Q!`0`Q````-D(!
M`$$```!H0@$`,P```*I"`0`E````WD(!`#T````$0P$`90```$)#`0!-````
MJ$,!`"D```#V0P$`*P```"!$`0`O````3$0!`"X```!\1`$`,````*M$`0!4
M````W$0!`%H````Q10$`2````(Q%`0!*````U44!`#(````@1@$`+P```%-&
M`0`L````@T8!`"T```"P1@$`<0```-Y&`0!F````4$<!`&\```"W1P$`LP``
M`"=(`0`7````VT@!`"4```#S2`$`,@```!E)`0`I````3$D!`#X```!V20$`
M(@```+5)`0!2````V$D!`"4````K2@$`"P```%%*`0"Q````74H!`$4````/
M2P$`(0```%5+`0`P````=TL!`"4```"H2P$`'````,Y+`0`Q````ZTL!``<`
M```=3`$`!P```"5,`0`$````+4P!``T````R3`$`"P```$!,`0`.````3$P!
M``L```!;3`$`!0```&=,`0`0````;4P!``(```!^3`$`60```(%,`0`%````
MVTP!`!(```#A3`$`!````/1,`0`'````^4P!``@````!30$`!0````I-`0`#
M````$$T!`!`````430$`#````"5-`0`3````,DT!``T```!&30$``@```%1-
M`0`'````5TT!``8```!?30$`%````&9-`0`,````>TT!`!@```"(30$`!@``
M`*%-`0`2````J$T!``P```"[30$``P```,A-`0`J````S$T!``0```#W30$`
M!@```/Q-`0`'`````TX!`!\````+3@$`-0```"M.`0`N````84X!`"\```"0
M3@$`%P```,!.`0`B````V$X!`"4```#[3@$`(````"%/`0`;````0D\!`!@`
M``!>3P$`)````'=/`0`?````G$\!`!H```"\3P$`(0```-=/`0`@````^4\!
M`!H````:4`$`,@```#50`0`:````:%`!`"\```"#4`$`*P```+-0`0`?````
MWU`!`",```#_4`$`'P```"-1`0`:````0U$!`"$```!>40$`)0```(!1`0`F
M````IE$!`"4```#-40$`)````/-1`0`8````&%(!`!T````Q4@$`)````$]2
M`0`8````=%(!`"(```"-4@$`+````+!2`0`O````W5(!`!4````-4P$`)0``
M`"-3`0`\````25,!`!\```"&4P$`(P```*93`0`?````RE,!`"````#J4P$`
M&@````M4`0`8````)E0!`"8````_5`$`'@```&94`0`I````A50!`!X```"O
M5`$`,0```,Y4`0`)`````%4!``P````*50$`%P```!=5`0`O````+U4!`"0`
M``!?50$`!P```(15`0`/````C%4!`!0```"<50$`#@```+%5`0`-````P%4!
M`"0```#.50$`!0```/-5`0`'````^54!`"(````!5@$`)0```"16`0`:````
M2E8!`!T```!E5@$`&@```(-6`0`'````GE8!`,<```"F5@$`"P```&Y7`0`5
M````>E<!``8```"05P$`"0```)=7`0`+````H5<!``T```"M5P$`%P```+M7
M`0`&````TU<!`#,```#:5P$`$P````Y8`0`3````(E@!``<````V6`$`#P``
M`#Y8`0`'````3E@!`#(```!66`$`!````(E8`0`A````CE@!`!,```"P6`$`
M#````,18`0`1````T5@!`#(```#C6`$`%@```!99`0`(````+5D!`!T````V
M60$`"0```%19`0`*````7ED!`!0```!I60$`"@```'Y9`0`=````B5D!``@`
M``"G60$`#0```+!9`0`0````OED!`#H```#/60$`'P````I:`0`(````*EH!
M`!H````S6@$`)P```$Y:`0`&````=EH!`!4```!]6@$`!P```)-:`0`(````
MFUH!``D```"D6@$`/P```*Y:`0`'````[EH!``\```#V6@$`#@````9;`0`0
M````%5L!``D````F6P$`"0```#!;`0`(````.EL!`!,```!#6P$`!P```%=;
M`0`9````7UL!``H```!Y6P$`%P```(1;`0`4````G%L!``H```"Q6P$`#```
M`+Q;`0`7````R5L!``0```#A6P$`*@```.9;`0`,````$5P!`!$````>7`$`
M!P```#!<`0`"````.%P!`!`````[7`$`&````$Q<`0`+````95P!``,```!Q
M7`$`"````'5<`0`&````?EP!``<```"%7`$`#0```(U<`0`+````FUP!`!0`
M``"G7`$`%0```+Q<`0`.````TEP!`!4```#A7`$`+P```/=<`0`@````)UT!
M`!P```!(70$`%0```&5=`0`,````>UT!`#$```"(70$`"0```+I=`0`.````
MQ%T!`#L```#370$`%0````]>`0`%````)5X!`!(````K7@$`/P```#Y>`0`2
M````?EX!``H```"17@$`!@```)Q>`0`$````HUX!``0```"H7@$`"@```*U>
M`0`3````N%X!``4```#,7@$`!@```-)>`0`&````V5X!``@```#@7@$`!```
M`.E>`0`,````[EX!``H```#[7@$`.0````9?`0`N````0%\!`"D```!O7P$`
M"@```)E?`0`%````I%\!``P```"J7P$`#````+=?`0`-````Q%\!`!@```#2
M7P$`&0```.M?`0`?````!6`!`!T````E8`$`$0```$-@`0`"````56`!``0`
M``!88`$`"@```%U@`0`&````:&`!``4```!O8`$``P```'5@`0`,````>6`!
M`$4```"&8`$`,@```,Q@`0`:````_V`!`#0````:80$`*````$]A`0!3````
M>&$!`!D```#,80$`<@```.9A`0`@````66(!`#4```!Z8@$`(0```+!B`0!%
M````TF(!`#`````88P$`*````$EC`0`I````<F,!`"8```"<8P$`8````,-C
M`0`E````)&0!`"@```!*9`$`*````'-D`0`B````G&0!`"L```"_9`$`,```
M`.MD`0`2````'&4!`!,````O90$`$````$-E`0!Y````5&4!``D```#.90$`
MH0```-AE`0!S````>F8!`'P```#N9@$`*P```&MG`0!4````EV<!`!<```#L
M9P$`)P````1H`0`6````+&@!``\```!#:`$`%P```%-H`0`?````:V@!`$``
M``"+:`$`'P```,QH`0`<````[&@!`%$````):0$`&@```%MI`0`4````=FD!
M``H```"+:0$`!0```)9I`0`&````G&D!``@```"C:0$`!0```*QI`0`2````
MLFD!``P```#%:0$`$````-)I`0`3````XVD!`!T```#W:0$`#P```!5J`0`;
M````)6H!`"0```!!:@$`#P```&9J`0`*````=FH!``0```"!:@$`"0```(9J
M`0`+````D&H!`!H```"<:@$`(@```+=J`0`(````VFH!``<```#C:@$`!0``
M`.MJ`0`4````\6H!`"D````&:P$`!P```#!K`0`(````.&L!``\```!!:P$`
M&````%%K`0`4````:FL!``@```!_:P$`#````(AK`0`/````E6L!``<```"E
M:P$`!@```*UK`0`4````M&L!``8```#):P$`"0```-!K`0`*````VFL!``P`
M``#E:P$`$0```/)K`0`#````!&P!``@````(;`$`!````!%L`0`9````%FP!
M`!$````P;`$`"@```$)L`0`8````36P!`!,```!F;`$`'````'IL`0`1````
MEVP!``\```"I;`$`!P```+EL`0`%````P6P!``0```#';`$`&0```,QL`0`'
M````YFP!``(```#N;`$``@```/%L`0`1````]&P!``D````&;0$`!@```!!M
M`0`2````%VT!`!<````J;0$`!@```$)M`0`%````26T!`"<```!/;0$``@``
M`'=M`0`$````>FT!``\```!_;0$`$P```(]M`0`'````HVT!``(```"K;0$`
M!P```*YM`0`1````MFT!``8```#(;0$`(0```,]M`0`8````\6T!``8````*
M;@$`$P```!%N`0`0````)6X!`!X````V;@$`$@```%5N`0`"````:&X!``8`
M``!K;@$`#````')N`0`)````?VX!`!$```");@$`(@```)MN`0`'````OFX!
M``<```#&;@$`"P```,YN`0`%````VFX!``(```#@;@$`"P```.-N`0!U`0``
M[VX!`!(```!E<`$`&P```'AP`0`0````E'`!``X```"E<`$`"0```+1P`0`'
M````OG`!``,```#&<`$``P```,IP`0`#````SG`!`!L```#2<`$`(0```.YP
M`0`U````$'$!`#$```!&<0$`*P```'AQ`0`O````I'$!`!T```#4<0$`+0``
M`/)Q`0`+````('(!`#(````L<@$`%````%]R`0`+````='(!`!,```"`<@$`
M!0```)1R`0`Q````FG(!`!````#,<@$`$0```-UR`0`>````[W(!``\````.
M<P$`"P```!YS`0"6````*G,!`!(```#!<P$`"@```-1S`0`-````WW,!``T`
M``#M<P$`%P```/MS`0`,````$W0!`!`````@=`$`%0```#%T`0`'````1W0!
M`)T```!/=`$`#````.UT`0`,````^G0!`!0````'=0$`$@```!QU`0`0````
M+W4!`!````!`=0$`"0```%%U`0`*````6W4!`$0```!F=0$`(````*MU`0`^
M````S'4!`$T````+=@$`;@```%EV`0!J````R'8!`'0````S=P$`<````*AW
M`0!!````&7@!``\```!;>`$`%0```&MX`0`.````@7@!`!````"0>`$`&```
M`*%X`0`%````NG@!``8```#`>`$`%P```,=X`0`+````WW@!``H```#K>`$`
M#0```/9X`0`T````!'D!`#`````Y>0$`%````&IY`0`6````?WD!``X```"6
M>0$`!P```*5Y`0`H````K7D!`!(```#6>0$`!P```.EY`0`6````\7D!`"0`
M```(>@$`#0```"UZ`0`9````.WH!`!\```!5>@$`'P```'5Z`0`E````E7H!
M`!\```"[>@$`$P```-MZ`0`;````[WH!`!$````+>P$`*````!U[`0`>````
M1GL!`!\```!E>P$`%@```(5[`0!A````G'L!`#````#^>P$`,@```"]\`0`7
M````8GP!``<```!Z?`$`$0```()\`0!#````E'P!``X```#8?`$`!````.=\
M`0`+````['P!``<```#X?`$`!P````!]`0`%````"'T!``<````.?0$`#```
M`!9]`0`$````(WT!`"(````H?0$`$````$M]`0`6````7'T!`!````!S?0$`
M$````(1]`0`L````E7T!`#$```#"?0$`"P```/1]`0`A`````'X!`!P````B
M?@$`(0```#]^`0`?````87X!``X```"!?@$`$@```)!^`0`/````HWX!`"0`
M``"S?@$`(P```-A^`0`'````_'X!``8````$?P$`"`````M_`0`-````%'\!
M``<````B?P$`!P```"I_`0`+````,G\!`!(````^?P$`'````%%_`0`+````
M;G\!`!0```!Z?P$`%P```(]_`0`5````IW\!`!L```"]?P$`"````-E_`0`4
M````XG\!``4```#W?P$`%````/U_`0`9````$H`!`!`````L@`$`-````#V`
M`0!-````<H`!`$$```#`@`$`"0````*!`0`'````#($!`!0````4@0$``P``
M`"F!`0`%````+8$!``\````S@0$`"0```$.!`0`5````38$!`$D```!C@0$`
M$P```*V!`0`N````P8$!`#4```#P@0$`-P```":"`0`R````7H(!``H```"1
M@@$`!````)R"`0`)````H8(!``@```"K@@$`,````+2"`0`W````Y8(!`"\`
M```=@P$`7@```$V#`0`O````K(,!`"\```#<@P$`2P````R$`0!.````6(0!
M`"\```"GA`$`5````->$`0`T````+(4!`#<```!AA0$`5P```)F%`0`O````
M\84!`#4````AA@$`+````%>&`0`;````A(8!`!X```"@A@$`+@```+^&`0`K
M````[H8!`"L````:AP$`0````$:'`0`4````AX<!``L```"<AP$`#````*B'
M`0`/````M8<!``\```#%AP$`'0```-6'`0`A````\X<!``<````5B`$`!P``
M`!V(`0`3````)8@!``H````YB`$`!P```$2(`0`L````3(@!``T```!YB`$`
M`P```(>(`0`,````BX@!``<```"8B`$`"````*"(`0`&````J8@!``4```"P
MB`$`"````+:(`0`'````OX@!``P```#'B`$`"P```-2(`0`5````X(@!`#@`
M``#VB`$`%@```"^)`0`7````1HD!`"H```!>B0$`$P```(F)`0`,````G8D!
M``4```"JB0$`!````+")`0`'````M8D!``<```"]B0$`!P```,6)`0`9````
MS8D!``4```#GB0$`$@```.V)`0`(`````(H!``@````)B@$``P```!**`0`&
M````%HH!``8````=B@$`*@```"2*`0`2````3XH!``@```!BB@$`#0```&N*
M`0`,````>8H!``<```"&B@$`$@```(Z*`0`#````H8H!`$$```"EB@$`&0``
M`.>*`0`P`````8L!``8````RBP$`!0```#F+`0`(````/XL!``@```!(BP$`
M9````%&+`0`J````MHL!`#\```#ABP$`*@```"&,`0`F````3(P!``8```!S
MC`$`!P```'J,`0`>````@HP!`"H```"AC`$`+@```,R,`0`W````^XP!`"T`
M```SC0$`-P```&&-`0!O````F8T!`#,````)C@$`"````#V.`0`'````1HX!
M``P```!.C@$`&````%N.`0`8````=(X!``L```"-C@$``@```)F.`0`4````
MG(X!`!@```"QC@$`(@```,J.`0`8````[8X!`!H````&CP$`%0```"&/`0`3
M````-X\!``<```!+CP$`&0```%./`0`=````;8\!`!4```"+CP$`&@```*&/
M`0`:````O(\!``4```#7CP$`"````-V/`0`;````YH\!`'(````"D`$`&```
M`'60`0!Y````CI`!``0````(D0$`$0````V1`0`%````'Y$!``4````ED0$`
M&@```"N1`0`;````1I$!`!<```!BD0$`%P```'J1`0`;````DI$!`"<```"N
MD0$`-@```-:1`0`.````#9(!`"H````<D@$`!P```$>2`0`>````3Y(!`!(`
M``!ND@$`&0```(&2`0`5````FY(!`"0```"QD@$`'P```-:2`0`7````]I(!
M`!,````.DP$`$0```"*3`0`&````-),!``\````[DP$`!P```$N3`0`*````
M4Y,!`!@```!>DP$`$0```'>3`0`(````B9,!``<```"2DP$`$P```)J3`0`7
M````KI,!``8```#&DP$`$0```,V3`0`$````WY,!``@```#DDP$`#@```.V3
M`0`+````_),!``D````(E`$`!P```!*4`0`'````&I0!``L````BE`$`"0``
M`"Z4`0`*````.)0!`!P```!#E`$`20```&"4`0`B````JI0!``T```#-E`$`
M&0```-N4`0`%````]90!`"````#[E`$`%0```!R5`0`8````,I4!`"T```!+
ME0$`/P```'F5`0`D````N94!``@```#>E0$`/````.>5`0`(````))8!`"<`
M```ME@$`$0```%66`0`*````9Y8!``D```!RE@$`#P```'R6`0`&````C)8!
M``D```"3E@$`%@```)V6`0`+````M)8!`!4```#`E@$`"````-:6`0`*````
MWY8!``T```#JE@$`)````/B6`0`F````'9<!`"X```!$EP$`)P```'.7`0`@
M````FY<!`"4```"\EP$`)````.*7`0`J````!Y@!`"4````RF`$`-````%B8
M`0`P````C9@!`"L```"^F`$`+````.J8`0`C````%YD!`#$````[F0$`-@``
M`&V9`0`V````I)D!`"L```#;F0$`,0````>:`0!!````.9H!`"H```![F@$`
M*0```*::`0!#````T)H!`"L````4FP$`&P```$";`0`Q````7)L!`"<```".
MFP$`)P```+:;`0`:````WIL!`+,```#YFP$`'P```*V<`0`J````S9P!`"X`
M``#XG`$`,````">=`0`M````6)T!`#(```"&G0$`*0```+F=`0`K````XYT!
M`#L````/G@$`.P```$N>`0!`````AYX!`$(```#(G@$`L@````N?`0`G````
MOI\!`"$```#FGP$`)0````B@`0`R````+J`!`#D```!AH`$`1@```)N@`0!/
M````XJ`!``P````RH0$`!````#^A`0`%````1*$!``4```!*H0$`#0```%"A
M`0`0````7J$!`!@```!OH0$`%0```(BA`0`7````GJ$!`!D```"VH0$`!P``
M`-"A`0`$````V*$!`!(```#=H0$`$0```/"A`0`.`````J(!`!H````1H@$`
M%````"RB`0`6````0:(!`!4```!8H@$`#0```&ZB`0`Y````?*(!``8```"V
MH@$`$P```+VB`0`&````T:(!`!,```#8H@$`&0```.RB`0`=````!J,!`!(`
M```DHP$``@```#>C`0`)````.J,!``H```!$HP$`20```$^C`0`+````F:,!
M`!8```"EHP$`$````+RC`0`$````S:,!`!$```#2HP$`%````.2C`0`$````
M^:,!`!4```#^HP$`%````!2D`0`(````*:0!`!`````RI`$`%@```$.D`0`&
M````6J0!`!(```!AI`$`$P```'2D`0`C````B*0!``L```"LI`$`!P```+BD
M`0`*````P*0!`!(```#+I`$`$P```-ZD`0`3````\J0!`!`````&I0$`&```
M`!>E`0`@````,*4!`!(```!1I0$`$@```&2E`0`B````=Z4!`"$```":I0$`
M)0```+RE`0!%````XJ4!`!$````HI@$`(0```#JF`0`;````7*8!`!H```!X
MI@$`!@```).F`0`W````FJ8!`"T```#2I@$`,0````"G`0`T````,J<!`!8`
M``!GIP$`$@```'ZG`0`(````D:<!`!,```":IP$`"P```*ZG`0`T````NJ<!
M`#0```#OIP$`#0```"2H`0`.````,J@!`"@```!!J`$`$0```&JH`0`2````
M?*@!`!(```"/J`$`"@```**H`0`.````K:@!``D```"\J`$`&````,:H`0`3
M````WZ@!`!\```#SJ`$`-@```!.I`0`;````2JD!`!(```!FJ0$`$0```'FI
M`0`(````BZD!`$\```"4J0$`$````.2I`0`L````]:D!``P````BJ@$`8@``
M`"^J`0`4````DJH!`!````"GJ@$`$0```+BJ`0`-````RJH!`!$```#8J@$`
M"0```.JJ`0`6````]*H!`"T````+JP$`"P```#FK`0`.````1:L!`#@```!4
MJP$`$````(VK`0`'````GJL!`!4```"FJP$`20```+RK`0`#````!JP!``@`
M```*K`$`"````!.L`0`)````'*P!``X````FK`$`$````#6L`0`5````1JP!
M`!8```!<K`$`(@```'.L`0`9````EJP!`"(```"PK`$`'@```-.L`0`)````
M\JP!``8```#\K`$`"`````.M`0`*````#*T!``(````7K0$`%````!JM`0`4
M````+ZT!`#````!$K0$`&@```'6M`0`9````D*T!``H```"JK0$`#0```+6M
M`0`.````PZT!`!@```#2K0$`"@```.NM`0!%````]JT!`"\````\K@$`!@``
M`&RN`0`.````<ZX!``H```""K@$`$@```(VN`0"@````H*X!`"8```!!KP$`
M'P```&BO`0`&````B*\!`!(```"/KP$`"````**O`0`&````JZ\!`"<```"R
MKP$`0````-JO`0!`````&[`!`"X```!<L`$`,@```(NP`0`7````OK`!`"H`
M``#6L`$`!P````&Q`0`(````";$!``@````2L0$`!@```!NQ`0`9````(K$!
M`!0````\L0$`%@```%&Q`0`4````:+$!`!(```!]L0$`&@```)"Q`0`2````
MJ[$!`!0```"^L0$`"````-.Q`0`1````W+$!``8```#NL0$`"@```/6Q`0`8
M`````+(!``X````9L@$`,P```"BR`0`1````7+(!``P```!NL@$`%````'NR
M`0`Z````D+(!`",```#+L@$`)@```.^R`0`E````%K,!`"`````\LP$`'P``
M`%VS`0`O````?;,!`"$```"MLP$`(@```,^S`0`$````\K,!`!D```#WLP$`
M"@```!&T`0`/````'+0!``,````LM`$`"@```#"T`0`'````.[0!`!4```!#
MM`$`&````%FT`0`0````<K0!`!@```"#M`$`$@```)RT`0`.````K[0!`!H`
M``"^M`$`!0```-FT`0`'````W[0!`!<```#GM`$`%P```/^T`0`8````%[4!
M``X````PM0$`$````#^U`0`9````4+4!`"T```!JM0$`%@```)BU`0`A````
MK[4!`"8```#1M0$`$P```/BU`0`1````#+8!`!(````>M@$`'0```#&V`0`3
M````3[8!`$L```!CM@$`,P```*^V`0!+````X[8!`%(````OMP$`50```(*W
M`0`_````V+<!`%<````8N`$`$0```'"X`0`'````@K@!``@```"*N`$`#@``
M`).X`0`0````HK@!``X```"SN`$`"0```,*X`0`(````S+@!``H```#5N`$`
M%@```."X`0`1````][@!``H````)N0$`+0```!2Y`0`Q````0KD!``\```!T
MN0$`A````(2Y`0`E````";H!``L````ON@$`"````#NZ`0`0````1+H!``D`
M``!5N@$`"P```%^Z`0`&````:[H!``D```!RN@$`.@```'RZ`0`+````M[H!
M`!4```##N@$``@```-FZ`0`&````W+H!``8```#CN@$`%0```.JZ`0`0````
M`+L!`!,````1NP$`*P```"6[`0`"````4;L!``,```!4NP$`%````%B[`0`+
M````;;L!``L```!YNP$`!0```(6[`0`:````B[L!``<```"FNP$`!@```*Z[
M`0`>````M;L!``L```#4NP$`!P```."[`0`)````Z+L!``4```#RNP$`"0``
M`/B[`0`&`````KP!``4````)O`$`!@````^\`0`-````%KP!`!`````DO`$`
M#@```#6\`0`/````1+P!`!4```!4O`$`!0```&J\`0`1````<+P!``D```""
MO`$`!P```(R\`0`:````E+P!`"P```"OO`$`4````-R\`0`P````+;T!`#$`
M``!>O0$`!P```)"]`0`*````F+T!``0```"CO0$`"0```*B]`0`)````LKT!
M`!<```"\O0$`"@```-2]`0`&````W[T!``T```#FO0$`!@```/2]`0`$````
M^[T!`$8`````O@$`1````$>^`0!#````C+X!`"(```#0O@$`!0```/.^`0`5
M````^;X!``L````/OP$`!P```!N_`0`(````([\!`!8````LOP$`#P```$._
M`0`5````4[\!``<```!IOP$`!````'&_`0`3````=K\!``0```"*OP$`"@``
M`(^_`0`;````FK\!``4```"VOP$`"````+R_`0`/````Q;\!``<```#5OP$`
M$P```-V_`0`4````\;\!`!,````&P`$`"````!K``0`)````(\`!``4````M
MP`$`1````#/``0`U````>,`!`#X```"NP`$`+````.W``0!+````&L$!`$4`
M``!FP0$`,0```*S!`0!2````WL$!`#<````QP@$`.@```&G"`0`D````I,(!
M`!$```#)P@$`%@```-O"`0`,````\L(!`#,```#_P@$`*P```#/#`0`G````
M7\,!`"H```"'PP$`"````++#`0`+````N\,!``H```#'PP$`!P```-+#`0`O
M````VL,!`#(````*Q`$`.0```#W$`0`*````=\0!`!H```""Q`$`)````)W$
M`0`8````PL0!`!4```#;Q`$`!P```/'$`0`0````^<0!``X````*Q0$`$0``
M`!G%`0`/````*\4!`$T````[Q0$`BP```(G%`0!W````%<8!`!,```"-Q@$`
M%@```*'&`0`8````N,8!`!````#1Q@$`$@```.+&`0`7````]<8!``8````-
MQP$`%0```!3'`0`)````*L<!`!(````TQP$`$0```$?'`0`5````6<<!`!@`
M``!OQP$`-0```(C'`0!X````OL<!`!<````WR`$`!````$_(`0`8````5,@!
M`#````!MR`$`"0```)[(`0`B````J,@!``0```#+R`$`#````-#(`0`D````
MW<@!`!8````"R0$`#0```!G)`0`2````)\D!`!,````ZR0$`%@```$[)`0`V
M````9<D!`#8```"<R0$`-````-/)`0`T````",H!`#`````]R@$`,````&[*
M`0`7````G\H!`%0```"WR@$`%0````S+`0`5````(LL!`!4````XRP$`%0``
M`$[+`0`4````9,L!`!@```!YRP$`&````)++`0`4````J\L!`!0```#`RP$`
M,````-7+`0`:````!LP!`!P````AS`$`.P```#[,`0`3````>LP!``8```".
MS`$`#@```)7,`0`?````I,P!`!0```#$S`$`%0```-G,`0`3````[\P!`!L`
M```#S0$`(````!_-`0`;````0,T!`!D```!<S0$`'0```';-`0`4````E,T!
M`!X```"IS0$`(@```,C-`0`4````Z\T!`!L`````S@$`&0```!S.`0`3````
M-LX!`!X```!*S@$`&0```&G.`0`8````@\X!`!@```"<S@$`"@```+7.`0`5
M````P,X!``0```#6S@$`!````-O.`0`'````X,X!``,```#HS@$`"@```.S.
M`0`)````]\X!`!`````!SP$`!@```!+/`0`(````&<\!``@````BSP$`!@``
M`"O/`0`(````,L\!``<````[SP$`!0```$//`0`6````2<\!``8```!@SP$`
M"````&?/`0`'````<,\!``0```!XSP$`"0```'W/`0`'````A\\!``D```"/
MSP$`$````)G/`0`0````JL\!``H```"[SP$`$P```,;/`0`%````VL\!`#``
M``#@SP$`$@```!'0`0`0````)-`!`!0````UT`$`$P```$K0`0`,````7M`!
M`!8```!KT`$`-@```(+0`0`'````N=`!``@```#!T`$`#0```,K0`0`,````
MV-`!``\```#ET`$`!@```/70`0`,````_-`!``T````)T0$`!@```!?1`0`$
M````'M$!``X````CT0$`)0```#+1`0`0````6-$!`!8```!IT0$`%P```(#1
M`0`F````F-$!`!L```"_T0$`"````-O1`0`#````Y-$!``P```#HT0$`*0``
M`/71`0`%````'](!``8````ET@$`#0```"S2`0`1````.M(!``<```!,T@$`
M#@```%32`0`5````8](!``8```!YT@$`!P```(#2`0`%````B-(!``T```".
MT@$`#0```)S2`0`,````JM(!`"````"WT@$`$0```-C2`0`/````ZM(!`!H`
M``#ZT@$`$P```!73`0`6````*=,!``4```!`TP$`!````$;3`0`5````2],!
M`$P```!ATP$`!0```*[3`0`-````M-,!`"@```#"TP$`&@```.O3`0`/````
M!M0!`!,````6U`$`%````"K4`0`0````/]0!``<```!0U`$`#P```%C4`0`8
M````:-0!`!````"!U`$`%0```)+4`0`9````J-0!`",```#"U`$`)P```.;4
M`0`W````#M4!``L```!&U0$`"````%+5`0`-````6]4!``\```!IU0$`#P``
M`'G5`0`$````B=4!``D```".U0$`+P```)C5`0`+````R-4!``D```#4U0$`
M$P```-[5`0!K````\M4!`!,```!>U@$`"@```'+6`0`%````?=8!``8```"#
MU@$`&@```(K6`0`9````I=8!`!D```"_U@$`"@```-G6`0`"````Y-8!`!8`
M``#GU@$`,P```/[6`0`#````,M<!``4````VUP$`%P```#S7`0`*````5-<!
M``4```!?UP$`"````&77`0`:````;M<!``X```")UP$`!@```)C7`0`(````
MG]<!``@```"HUP$`!````+'7`0`%````MM<!`$H```"\UP$`#P````?8`0`2
M````%]@!`!T````JV`$`(@```$C8`0`$````:]@!``4```!PV`$`&P```';8
M`0`E````DM@!`#D```"XV`$`#0```/+8`0`*`````-D!``H````+V0$`$0``
M`!;9`0`*````*-D!``L````SV0$`%@```#_9`0`;````5MD!`"\```!RV0$`
M+@```*+9`0`B````T=D!`!````#TV0$`F`````7:`0"<````GMH!``,````[
MVP$`!P```#_;`0`*````1]L!``<```!2VP$`#@```%K;`0`6````:=L!``<`
M``"`VP$`6@```(C;`0`/````X]L!``\```#SVP$`"P````/<`0`G````#]P!
M`%T````WW`$`&P```)7<`0`'````L=P!`",```"YW`$`*0```-W<`0`(````
M!]T!``<````0W0$`&P```!C=`0`&````--T!``D````[W0$`+@```$7=`0`M
M````=-T!`#<```"BW0$`!@```-K=`0`&````X=T!`"P```#HW0$`+@```!7>
M`0!F````1-X!`!<```"KW@$`&@```,/>`0`H````WMX!`"0````'WP$`%P``
M`"S?`0`"````1-\!`!$```!'WP$`!@```%G?`0`4````8-\!``X```!UWP$`
M!@```(3?`0`(````B]\!``8```"4WP$`"````)O?`0`-````I-\!``T```"R
MWP$`"@```,#?`0`1````R]\!`#L```#=WP$`!0```!G@`0`7````'^`!`!0`
M```WX`$`%P```$S@`0`(````9.`!``L```!MX`$`$0```'G@`0`1````B^`!
M`!(```"=X`$`#P```+#@`0`,````P.`!``L```#-X`$`#````-G@`0`*````
MYN`!`"````#QX`$`%0```!+A`0`2````*.$!`!4````[X0$`&````%'A`0`+
M````:N$!`!L```!VX0$`"````)+A`0`5````F^$!`"X```"QX0$``P```.#A
M`0`'````Y.$!``4```#LX0$`!0```/+A`0`(````^.$!`!8````!X@$`%P``
M`!CB`0`D````,.(!`",```!5X@$`'@```'GB`0`:````F.(!`!L```"SX@$`
M(@```,_B`0`;````\N(!``8````.XP$`!@```!7C`0`2````'.,!`!(````O
MXP$`%````$+C`0`-````5^,!``X```!EXP$`)0```'3C`0`0````FN,!`!0`
M``"KXP$`)P```,#C`0`E````Z.,!`!D````.Y`$`"0```"CD`0`&````,N0!
M``<````YY`$`$@```$'D`0`1````5.0!``@```!FY`$`"0```&_D`0`%````
M>>0!``<```!_Y`$`!````(?D`0`$````C.0!``,```"1Y`$`1P```)7D`0!(
M````W>0!`#8````FY0$`*````%WE`0`I````AN4!`"4```"PY0$`*@```-;E
M`0!!`````>8!``P```!#Y@$`0````%#F`0`V````D>8!`#D```#(Y@$`.0``
M``+G`0`^````/.<!`!@```![YP$`&P```)3G`0`4````L.<!`#@```#%YP$`
M%@```/[G`0`3````%>@!`!P````IZ`$`(````$;H`0`4````9^@!`!,```!\
MZ`$`%@```)#H`0`:````I^@!`#L```#"Z`$`.P```/[H`0`_````.ND!`#0`
M``!ZZ0$`.P```*_I`0`X````Z^D!`'L````DZ@$`'@```*#J`0`8````O^H!
M``T```#8Z@$`%````.;J`0`:````^^H!``P````6ZP$`%P```"/K`0`2````
M.^L!`#@```!.ZP$`,P```(?K`0`J````N^L!``T```#FZP$`4P```/3K`0!,
M````2.P!``4```"5[`$`'@```)OL`0`6````NNP!``L```#1[`$`#P```-WL
M`0`6````[>P!``<````$[0$`"0````SM`0`)````%NT!``X````@[0$`"P``
M`"_M`0`/````.^T!``<```!+[0$`$P```%/M`0`%````9^T!`"8```!M[0$`
M"````)3M`0`&````G>T!`!0```"D[0$`$@```+GM`0`1````S.T!`$0```#>
M[0$``@```"/N`0`%````)NX!`!`````L[@$`!0```#WN`0`'````0^X!`!4`
M``!+[@$`!@```&'N`0`]````:.X!`!,```"F[@$`(P```+KN`0`$````WNX!
M`#@```#C[@$`)@```!SO`0`F````0^\!`%T```!J[P$`(````,CO`0!-````
MZ>\!`"H````W\`$`%@```&+P`0`'````>?`!`"(```"!\`$`#P```*3P`0`/
M````M/`!``P```#$\`$`%P```-'P`0`,````Z?`!`!T```#V\`$`&P```!3Q
M`0`%````,/$!`!,````V\0$`#@```$KQ`0`;````6?$!`"P```!U\0$`$0``
M`*+Q`0`7````M/$!`!4```#,\0$`$0```.+Q`0`=````]/$!``@````2\@$`
M$````!OR`0`9````+/(!`!0```!&\@$`$@```%OR`0`<````;O(!`!,```"+
M\@$`$P```)_R`0`7````L_(!`!$```#+\@$`"P```-WR`0`(````Z?(!``4`
M``#R\@$`'0```/CR`0`&````%O,!`!D````=\P$`"````#?S`0`5````0/,!
M``P```!6\P$`)````&/S`0`6````B/,!`#,```"?\P$`'@```-/S`0`.````
M\O,!``\````!]`$`*@```!'T`0`&````//0!`!\```!#]`$`!@```&/T`0`:
M````:O0!``D```"%]`$`"P```(_T`0`G````F_0!`#@```##]`$`"@```/ST
M`0`I````!_4!`!(````Q]0$`"P```$3U`0`>````4/4!`!0```!O]0$`!0``
M`(3U`0`'````BO4!``L```"2]0$`"0```)[U`0`&````J/4!``@```"O]0$`
M!@```+CU`0`*````O_4!`!P```#*]0$`+0```.?U`0`Q````%?8!`"4```!'
M]@$`,P```&WV`0`F````H?8!`$<```#(]@$`(0```!#W`0`I````,O<!`"<`
M``!<]P$`/@```(3W`0!<````P_<!`#`````@^`$`!P```%'X`0`)````6?@!
M``@```!C^`$`"````&SX`0`7````=?@!`!8```"-^`$`+````*3X`0`N````
MT?@!`!D`````^0$`,````!KY`0`Z````2_D!``@```"&^0$`'P```(_Y`0`+
M````K_D!``8```"[^0$`*P```,+Y`0`3````[OD!`!0````"^@$`"P```!?Z
M`0`(````(_H!`!<````L^@$`!P```$3Z`0`+````3/H!``T```!8^@$`&P``
M`&;Z`0`A````@OH!`#P```"D^@$`"@```.'Z`0`%````[/H!``<```#R^@$`
M!0```/KZ`0`;`````/L!``<````<^P$`#P```"3[`0`%````-/L!`!(````Z
M^P$`&@```$W[`0`'````:/L!``X```!P^P$`$````'_[`0`3````D/L!``0`
M``"D^P$`!````*G[`0`,````KOL!`!X```"[^P$`6@```-K[`0`$````-?P!
M``X````Z_`$`'P```$G\`0`*````:?P!`"L```!T_`$`(````*#\`0`6````
MP?P!`!0```#8_`$`%@```.W\`0`6````!/T!``D````;_0$`"0```"7]`0`1
M````+_T!`"X```!!_0$`!P```'#]`0`/````>/T!`!(```"(_0$`%````)O]
M`0`0````L/T!`$$```#!_0$`"@````/^`0`<````#OX!`!4````K_@$`&@``
M`$'^`0`Y````7/X!`",```"6_@$`3````+K^`0!0````!_\!`$D```!8_P$`
M$0```*+_`0`,````M/\!``\```#!_P$``P```-'_`0`=````U?\!`"(```#S
M_P$`'0```!8``@`)````-``"`"`````^``(`$P```%\``@`?````<P`"`"$`
M``"3``(`!P```+4``@`E````O0`"`!X```#C``(`"@````(!`@`&````#0$"
M`!`````4`0(`$0```"4!`@`<````-P$"``0```!4`0(`"````%D!`@`+````
M8@$"`!````!N`0(`$````'\!`@`7````D`$"`!<```"H`0(`"0```,`!`@`%
M````R@$"``P```#0`0(`#0```-T!`@`0````ZP$"``\```#\`0(`#P````P"
M`@`&````'`("`$`````C`@(`-````&0"`@`S````F0("``8```#-`@(`!@``
M`-0"`@`&````VP("`!T```#B`@(`%@`````#`@`L````%P,"``X```!$`P(`
M$````%,#`@`D````9`,"``,```")`P(`!@```(T#`@`1````E`,"``(```"F
M`P(`#0```*D#`@`:````MP,"``P```#2`P(`&````-\#`@`?````^`,"`!(`
M```8!`(`$@```"L$`@`+````/@0"`!0```!*!`(`%0```%\$`@`/````=00"
M``L```"%!`(`$@```)$$`@`.````I`0"`!<```"S!`(`%P```,L$`@!H````
MXP0"`"(```!,!0(`/P```&\%`@`-````KP4"``<```"]!0(`!@```,4%`@`5
M````S`4"`!4```#B!0(`&@```/@%`@`=````$P8"``D````Q!@(`%````#L&
M`@`"````4`8"`!<```!3!@(`%0```&L&`@`3````@08"`"````"5!@(`)```
M`+8&`@`7````VP8"`"4```#S!@(`$0```!D'`@`O````*P<"`!,```!;!P(`
M%0```&\'`@`;````A0<"`)````"A!P(`)````#((`@`@````5P@"`#$```!X
M"`(`)````*H(`@`C````SP@"`"0```#S"`(`)0```!@)`@`D````/@D"`!D`
M``!C"0(`'0```'T)`@`+````FPD"``H```"G"0(`!P```+()`@`(````N@D"
M``D```##"0(`%````,T)`@`/````X@D"`#<```#R"0(`&P```"H*`@`6````
M1@H"``@```!="@(`#````&8*`@!J````<PH"`$(```#>"@(`2@```"$+`@"`
M````;`L"`"H```#M"P(`#0```!@,`@`Q````)@P"`#$```!8#`(`"@```(H,
M`@`%````E0P"``8```";#`(`10```*(,`@`(````Z`P"`!D```#Q#`(`&@``
M``L-`@!F````)@T"`#4```"-#0(`*````,,-`@`4````[`T"`"<````!#@(`
M'@```"D.`@`M````2`X"`#<```!V#@(`1````*X.`@`W````\PX"`!L````K
M#P(`!P```$</`@`;````3P\"`!<```!K#P(`%0```(,/`@`)````F0\"`#0`
M``"C#P(`#````-@/`@`*````Y0\"``D```#P#P(`%P```/H/`@`)````$A`"
M``8````<$`(`%@```",0`@`)````.A`"``@```!$$`(`!0```$T0`@`/````
M4Q`"`!````!C$`(`)````'00`@`@````F1`"`!,```"Z$`(`-````,X0`@`,
M`````Q$"``<````0$0(`$@```!@1`@`;````*Q$"``X```!'$0(`#@```%81
M`@`9````91$"`"8```!_$0(`#@```*81`@`@````M1$"`#8```#6$0(`"```
M``T2`@`*````%A("`!D````A$@(`!P```#L2`@`(````0Q("`!,```!,$@(`
M$@```&`2`@`2````<Q("`!$```"&$@(`!@```)@2`@`)````GQ("``@```"I
M$@(`"0```+(2`@`.````O!("`!````#+$@(`!@```-P2`@`T````XQ("`!0`
M```8$P(``P```"T3`@`%````,1,"`!`````W$P(`'P```$@3`@`+````:!,"
M``(```!T$P(`(0```'<3`@`<````F1,"``4```"V$P(`!0```+P3`@!R````
MPA,"``8````U%`(`!@```#P4`@`<````0Q0"`$8```!@%`(`'@```*<4`@`<
M````QA0"`%L```#C%`(`.P```#\5`@!/````>Q4"`"````#+%0(`%0```.P5
M`@`&`````A8"``@````)%@(`#P```!(6`@`1````(A8"``H````T%@(`#P``
M`#\6`@`7````3Q8"`!$```!G%@(`$0```'D6`@`4````BQ8"``@```"@%@(`
M"@```*D6`@`=````M!8"``X```#2%@(`&@```.$6`@`)````_!8"``4````&
M%P(`!@````P7`@`C````$Q<"``8````W%P(`+@```#X7`@`%````;1<"``8`
M``!S%P(`#0```'H7`@`&````B!<"``\```"/%P(`"P```)\7`@`'````JQ<"
M`!4```"S%P(`$@```,D7`@`5````W!<"``8```#R%P(`&0```/D7`@`*````
M$Q@"``@````>&`(`!P```"<8`@`&````+Q@"`!,````V&`(`)0```$H8`@`+
M````<!@"``X```!\&`(`*````(L8`@`8````M!@"`!H```#-&`(`!0```.@8
M`@`*````[A@"`!,```#Y&`(`#0````T9`@`"````&QD"``X````>&0(`"0``
M`"T9`@`E````-QD"`#H```!=&0(`*P```)@9`@`X````Q!D"`"P```#]&0(`
M9P```"H:`@`;````DAH"`&````"N&@(`.`````\;`@!*````2!L"`%D```"3
M&P(`+P```.T;`@`<````'1P"`#$````Z'`(`*P```&P<`@`Q````F!P"`"\`
M``#*'`(`)@```/H<`@`]````(1T"`"("``!?'0(`(P```((?`@`8````IA\"
M`$H```"_'P(`@0````H@`@`S````C"`"`"\```#`(`(`0````/`@`@!:````
M,2$"`%````",(0(`.0```-TA`@`C````%R("`!<````[(@(`+````%,B`@`A
M````@"("`",```"B(@(`,P```,8B`@`?````^B("`"H````:(P(`-@```$4C
M`@`;````?","`!$```"8(P(`5````*HC`@`K````_R,"`"T````K)`(`)P``
M`%DD`@`B````@20"`"T```"D)`(`60```-(D`@`U````+"4"`%0```!B)0(`
M.@```+<E`@`\````\B4"`$X````O)@(`;P```'XF`@!8````[B8"`#D```!'
M)P(`/0```($G`@!'````OR<"`$H````'*`(`20```%(H`@!K````G"@"`'4`
M```(*0(`:0```'XI`@!F````Z"D"`#\```!/*@(`+0```(\J`@`L````O2H"
M`#````#J*@(`=P```!LK`@!F````DRL"`'4```#Z*P(`P````'`L`@`9````
M,2T"`"H```!++0(`/0```'8M`@`R````M"T"`%(```#G+0(`)````#HN`@!;
M````7RX"`"````"[+@(`"0```-PN`@"]````YBX"`$H```"D+P(`(P```.\O
M`@`]````$S`"`"8```!1,`(`(0```'@P`@`^````FC`"``@```#9,`(`!P``
M`.(P`@`%````ZC`"``T```#P,`(`#@```/XP`@`4````#3$"``X````B,0(`
M!0```#$Q`@`3````-S$"``$```!+,0(`>0```$TQ`@`+````QS$"`!,```#3
M,0(`!````.<Q`@`'````[#$"``8```#T,0(`!0```/LQ`@`$`````3("`!0`
M```&,@(`"P```!LR`@`1````)S("``P````Y,@(``@```$8R`@`'````23("
M``<```!1,@(`$0```%DR`@`,````:S("`!<```!X,@(`!@```)`R`@`5````
MES("``P```"M,@(``P```+HR`@`M````OC("``0```#L,@(`!P```/$R`@`'
M````^3("`"D````!,P(`1@```"LS`@!"````<C,"`$$```"U,P(`'@```/<S
M`@`V````%C0"`#D```!--`(`)````(<T`@`;````K#0"`"0```#(-`(`+0``
M`.TT`@`F````&S4"`",```!"-0(`+0```&8U`@`I````E#4"`"X```"^-0(`
M/````.TU`@`F````*C8"`#<```!1-@(`,````(DV`@`I````NC8"`"\```#D
M-@(`+0```!0W`@`F````0C<"`#````!I-P(`*@```)HW`@`L````Q3<"`"\`
M``#R-P(`*@```"(X`@`F````33@"`"H```!T.`(`+P```)\X`@`C````SS@"
M`"T```#S.`(`.````"$Y`@`[````6CD"`"````"6.0(`+````+<Y`@`^````
MY#D"`"D````C.@(`+@```$TZ`@`M````?#H"`"P```"J.@(`)@```-<Z`@`@
M````_CH"`"@````?.P(`*@```$@[`@!#````<SL"`"\```"W.P(`/````.<[
M`@`)````)#P"`!<````N/`(`'````$8\`@`U````8SP"`"(```"9/`(`#@``
M`+P\`@`/````RSP"`!,```#;/`(`"P```.\\`@`*````^SP"`!\````&/0(`
M!@```"8]`@`'````+3T"`"(````U/0(`)0```%@]`@`@````?CT"`"H```"?
M/0(`&````,H]`@`(````XST"`/@```#L/0(`&@```.4^`@`=`````#\"``@`
M```>/P(`"P```"<_`@`6````,S\"`!8```!*/P(`)0```&$_`@`'````AS\"
M`%,```"//P(`&@```.,_`@`:````_C\"``<````90`(`&0```"%``@`,````
M.T`"`$P```!(0`(`"P```)5``@`P````H4`"`!\```#20`(`&````/)``@`?
M````"T$"`#P````K00(`'0```&A!`@`1````AD$"`"<```"800(`$P```,!!
M`@`4````U$$"`!8```#I00(`"P````!"`@`:````#$("``<````G0@(`#@``
M`"]"`@`1````/D("`#````!00@(`+````(%"`@`(````KD("`"D```"W0@(`
M+P```.%"`@`'````$4,"`!D````90P(`!P```#-#`@`(````.T,"``D```!$
M0P(`10```$Y#`@`'````E$,"`!,```"<0P(`$P```+!#`@`4````Q$,"``H`
M``#90P(`"@```.1#`@`'````[T,"`!0```#W0P(`!P````Q$`@`9````%$0"
M``T````N1`(`&0```#Q$`@`;````5D0"``H```!R1`(`#0```'U$`@`7````
MBT0"``8```"C1`(`-````*I$`@`,````WT0"`!````#L1`(`"0```/U$`@`"
M````!T4"`!`````*10(`&@```!M%`@`+````-D4"``,```!"10(`"````$9%
M`@`.````3T4"``D```!>10(`#@```&A%`@`-````=T4"`!<```"%10(`&```
M`)U%`@`1````MD4"`!D```#(10(`/````.)%`@`E````'T8"`",```!%1@(`
M%P```&E&`@`.````@48"`#0```"01@(`#0```,5&`@`4````TT8"`#@```#H
M1@(`&````"%'`@`'````.D<"`!4```!"1P(`60```%A'`@`2````LD<"`!``
M``#%1P(`"0```-9'`@`$````X$<"``0```#E1P(`$0```.I'`@`>````_$<"
M``8````;2`(`!P```")(`@`'````*D@"`!,````R2`(`!P```$9(`@`7````
M3D@"`!<```!F2`(`0@```'Y(`@`T````P4@"`#@```#V2`(`"@```"])`@`%
M````.DD"``P```!`20(`(````$U)`@`-````;DD"`!L```!\20(`(0```)A)
M`@`9````NDD"`"(```#420(`$0```/=)`@`"````"4H"``0````,2@(`$0``
M`!%*`@`,````(TH"``4````P2@(``P```#9*`@`.````.DH"`%8```!)2@(`
M,@```*!*`@`<````TTH"`$$```#P2@(`-@```#)+`@!8````:4L"`!D```#"
M2P(`>0```-Q+`@`H````5DP"`$@```!_3`(`)````,A,`@!'````[4P"`"P`
M```U30(`+````&)-`@`O````CTT"`"X```"_30(`8````.Y-`@`N````3TX"
M`#@```!^3@(`+````+=.`@`T````Y$X"`"T````93P(`-0```$=/`@`9````
M?4\"`",```"73P(`&````+M/`@!Z````U$\"``D```!/4`(`RP```%E0`@"0
M````)5$"`'P```"V40(`+0```#-2`@!N````85("`!T```#04@(`)@```.Y2
M`@`3````%5,"`!,````I4P(`%@```#U3`@`J````5%,"`$````!_4P(`(0``
M`,!3`@`E````XE,"`'$````(5`(`'````'I4`@`7````EU0"``L```"O5`(`
M!0```+M4`@`&````P50"``@```#(5`(`!0```-%4`@`6````UU0"``X```#N
M5`(`%0```/U4`@`9````$U4"`"0````M50(`$````%)5`@`=````8U4"`#``
M``"!50(`#P```+)5`@`,````PE4"`!(```#/50(`"0```.)5`@`4````[%4"
M`"(````!5@(`+0```"16`@`*````4E8"``@```!=5@(`!0```&96`@`9````
M;%8"`"X```"&5@(`"@```+56`@`,````P%8"`!@```#-5@(`)````.96`@`7
M````"U<"``@````C5P(`#````"Q7`@`0````.5<"``<```!*5P(`#@```%)7
M`@`6````85<"``T```!X5P(`"0```(97`@`.````D%<"`!$```"?5P(`%```
M`+%7`@`"````QE<"``8```#)5P(`!0```-!7`@`H````UE<"`!P```#_5P(`
M"P```!Q8`@`L````*%@"`!<```!56`(`)0```&U8`@`:````DU@"`!$```"N
M6`(`!P```,!8`@`%````R%@"``<```#.6`(`&0```-98`@`)````\%@"``,`
M``#Z6`(``@```/Y8`@`2`````5D"``T````460(`"@```")9`@`6````+5D"
M`!D```!$60(`!P```%Y9`@`*````9ED"`"8```!Q60(``@```)A9`@`#````
MFUD"`!(```"?60(`&0```+)9`@`*````S%D"``(```#760(`"P```-I9`@`2
M````YED"``8```#Y60(`'P````!:`@`A````(%H"``D```!"6@(`%P```$Q:
M`@`7````9%H"`!P```!\6@(`$@```)E:`@`"````K%H"``0```"O6@(`#@``
M`+1:`@`/````PUH"`!````#36@(`+P```.1:`@`&````%%L"``@````;6P(`
M%P```"1;`@`%````/%L"``,```!"6P(`"P```$9;`@`!````B@```*P$````
M`````````/H&``"M`@```````.(!``#H!P``P@8``%,```#!`P``*@``````
M``!6!P``````````````````@@4``.P!````````PP,``"X&``!0!0``````
M`!\(````````8@<``%<'``!R`@``>00``*0&``#A!@``*04``,<"````````
M"@,``.4'````````7`4``)`!``"'!```E@4``#,!``!N````B`<`````````
M````H`,```````!"!P```````$$'``"0!0``TP<``!4````*"```D`,``!H#
M``"R`P```````*$#``"1`0``I0(````````'!0````````,```!C`@``````
M`%P!````````%`(```````#X!```+@````````"7`P```````#\&``#>!```
M[P$`````````````Z`0``-('``"Y!@``````````````````A@8`````````
M````3@0`````````````;P0```````"+`@``'````*<%``"G`P```````)\$
M```G"````````)$'``#E!@```````.\'``!(`P``?`(```````"J`0``8`$`
M`,0!``""!@````````8%``!&!P```````+\&``"#!P```````(D!``!8`0``
MNP,```````#T!P```````($!````````OP,``*P!```/`0``@`0``-$```!W
M`0``[P(``)H$``!;`0``J`(``%0%````````%`4``'P&````````1`,`````
M``````````````L'````````LP<``((#``!-`0``F@,``-T"````````)`<`
M`!(#```"!P``60$```````"A````6P8``&L%````````^0```&D"````````
M#`(```````#\`@````````````"A!P``C0```'0`````````QP,``&4$``"8
M!@``G@,``#T$``!C````U@$``+4$````````,@(``%<#``"$!```%08`````
M``"J!P`````````````\`@``C`(``$0&``#;````:0```'P#``"_````-`$`
M`"H"``"7!```$0```/,%``!#!@``)0```%H&```R!@```````&@'```;!@``
M*0@``*\&````````C0(``(L$``"$`P``#`@``&P&``#3`0``F`<```4$``!.
M!P``-@$``)\'```+`@```````&P```#I!@```````+H!``!%!```"P4`````
M``#W`P``````````````````>`8``+<&``#@!```*P$``'$!``">!```@```
M`#0"````````G@<``',%``#=`P``FP$``#$%``"/````*P<````'```U`P``
M+P@``&T!``"9`@````````````"C`P``R`0````&``"%!0``70```*L!``#W
M`@``;@4``&\```"#!````````%$#```&`P``>08``%\%``#6`P``Q0,`````
M````````&@$```````#_!````````),!`````````````$8!``"C`@``80<`
M````````````30```/L$``#E!0````````P&``#V!P``4`8``$D!```5!P``
M``````````!O!0``"@4``!$(``!U!```]`0``!$!````````5`$`````````
M````7@0``%H$``"]``````````````#L!0``;`4``&X!````````T`,````#
M``!1`0``F08```,'``#(`P``=`8`````````````!`$```````!2!P``U`<`
M```````!!@``8`0``$T$```1!0``V0````````!'`P``%P8``!<!```2`@``
M`````"X#````````M`$``'`````>`````````'H```!;!P``20``````````
M````B@$``!P'``#A!```@P```.@"```Q!```G0$```````#]`@``````````
M```I`@``0@$```````!J`P``>04```````#W!@``G`4``!,!````````#@``
M`!P$``#4`````````%\"````````^@```,0````V`P``(@4``%$$```&`0``
MK@<```````"Y!0``H@<``"L&``"^`0``E@<``/8&``!E`0````````````#5
M!```B`,``*,$``!-!0``7@<``/\"````````?@$``)\"``#K````R`4``+L'
M``#,!P````````X$``#8`0``P`,```````!0!````````)D$````````\@(`
M`!L!``#R````[P4```````!B!```^08``-$#```Z`0``,P4``','``#L`@``
M`````!8$``#``0``[`0````````@!P```````,$!````````^`,``!\&``"(
M!0``C08``%4&``"6!@````````````#^`@``J04`````````````F`,`````
M```/````B@0``,$```!5`0``%@,``!T'``#'!@``@`4```````#*!```Q`4`
M``,"```V!@``:00``%,"````````=P8`````````````S@8````````P!0``
MQ@<``$<!``!+!P``$0,```````#9`P``/0<``#,```"V`@``B`$``&H"``"U
M`@``K0$``/`"``"0````9@,``!<```#E`@```````/4$``!!!@``````````
M``"V!`````````````#N`0```````-@"````````0P,``(T!``#`!```^P``
M``<"```J"```G00````````:``````````````!W!P``7P<``'L%``#+!0``
M`````+T"````````9`,``-H&````````N00``-<&``!>`P```````&`%``"2
M````P`4`````````````>@,``,T!``#"````?P$``%0#``!A!````````+("
M````````_@````````"L`P``*P4``!8```"-!0``60,``/X%``"[!@``Z`$`
M``T'`````````````#D'``!^!@```````'H'````````R`8```````#Y!```
M?@<``$,!``!T`P``10<```````!C!@````````````##!P``EP(````````J
M`P``E00``/\&``!B!@``:P,``#\$``#C!0```````#$'``!$`@``2P,```P#
M``#@`@``````````````````;0```&`'````````TP8```@%```_````/0(`
M`!<%``#U!0``K0```"T````F`@```````*\```!3!P```````$L"``!6!```
M`````",#``"\!P``[P```#D#``"K!P``M`0```P$``">`@``A@4``+0```"=
M`@``@@0``&8!```S!```/08``*X#``!E!P``#00``+<$``#C````=`$`````
M``#Z!0``(@$``)\```#S!P``&`8``%$"``"S!@``W0$``'X$``#%`@``*P``
M````````````O0<``$$%`````````````+@```!K`@``V@<``%<%``!B`0``
MY0,```X&```Y`0``^`<``$\%``!/!@``N0$``+0%```[`0```````"P#```4
M````&`(`````````````J00``!(&``#`!@```````$P$``#)!P``&`@``*<`
M````````!0,````````X````\P0````````M`0``N`4````````-````(P``
M``````"C````]0(``)H`````````*@$``"P!```/!P``@P8```\$````````
M0@,``(\'``#$!P``;P(``%H```"&!P``H@4````````;`P``YP(```````#+
M`0``2@,``#X&``#7!`````(``+H$``"N!@``S@(```````"@!P```P@``%<$
M```(`P``(P0```````#_`0``OP(``.X%``"I````S@4```````#$`P``BP$`
M`,H```"``@```````!\!``!.!@``Z0<````````[`P``B0(````````B!P``
M`````,0"``#X!@``6@(```````#.`P``@@<``),&``!V````D@,``,T'```+
M"```H0(```D%``#^!```E@$``'D```#)`@``O@(`````````````VP,``,,$
M````````90```$$"``!,`P```````$<```!8````K`(``,$&``!'!0``,P<`
M`-("```````````````````&!````````%4'````````V@,``%@&````````
M#@4``*8%``!E!0````````````#@`0``#P(``%@#``"F`0``````````````
M````CP0````````/!@``T@$``*,'```N!0``Q04``"L$``#Q`P``X0,``#4%
M``!7`@``Z`8``*0%``";!```<0<``/L#```"!```Z0$````````+!```````
M`-,```#T`@``6@<``(H#```"````"`<```````!>`0``KP<```@"````````
M0P<``)H'``#V`0``6@4``*0````M!@``[`,`````````````;00``)P'``#+
M`@```````'\````<!@``\0(``.D$````````Q0<````````E!0```````-0!
M``!&!@```````%8#``#V`@``W@,``,\#```R`0``!@@```````"]!```1P8`
M`!\"``````````````\#````````^@(``$X"``#9!@````````0%``"E`P``
M`````!X"```'"```I08``,$%````````WP,``.$!````````&0$``-\!```Y
M!```%0@``,8#```9````#0@``,@!````````E`$`````````````108`````
M``#Y`0```````)0$``"5!0``\@8``#,&``!^`@``6@$`````````````%@8`
M`*L"``"2`0``"`$``!0#``"1`@``D0,``)`&````````2`8``-P```!8!0``
M]````.X"``"C!@``=`<```````#G!````````+P&``#*`0``<08``%@$``"'
M`P``=P```&4"``#``````````-\"````````TP,``"$%``!V`P```````+<'
M``"V`0``/@<``.8$```)!```A@$``!H$``#.`0````````````".`P``?@4`
M````````````O`,``.8````_`P``.0```+D'```\````H@(``%D&``#,`@``
M`````+@$``#P`P``#@<```````"P`P```````*(&`````````````(4```#K
M!0``M@```'P$```=!@``6P0``-$'```:!0```````.T%````````LP$`````
M````````%@4```````"U!0``=0```$`"```9`@``?04``+L```#E!```I0<`
M`-`&```M!P``*@<``-\'````````C0<``%L%``!M!0``````````````````
MGP4``"P```!_!0``#@@``'('``````````````````"P`0``T0$``'4"``"R
M!P``C````+`````[!@``````````````````20<``/H'````````FP,`````
M``"Z`@````@```````!.`0```````'0"``#_!0``L08``*L&``!&````804`
M``````#6`@``*@0``(0"``!;`P``$@$````````+`0``G@8``,P&``#P`0``
MKP,``%(#``#G!P``YP4``,(#````````'0$``````````````````(X"``!(
M!P`````````````$!````````-`'``#P!P``BP<``-@`````````F`4``*@$
M``#_````E`(``!`&``"9!P``3P$``'4'````````80```/H#``!F!0``Z@0`
M`.T'``#-````D04``.H#`````````````'D#``#M`0``70,``,T$````````
M4P8```````!K````X`4``/<$```R!0``&0,``!T%``#T!@```````"\'``#^
M`0```````+H'````````"````/8#``!N!```_`0````````_!0``?0(``)<%
M``">!0``SP<```````"B`P``HP$``(0&```7!```````````````````D`0`
M`,,%````````+P8``.,#``!R`````0$``-X"``#O`P``9@0```D```"Z````
MS@0```````"<`P``:P<``+$#````````W@$``"0&``#U````#@$``-\`````
M````B@8``*D&``"H`0``W`4``&@%```\`0``V`<``/(#```]`````````&H'
M```B````=`0```````"(`@``#`4``*P%`````````````$4"``#=````````
M```````E`P``AP<```T!````````)`$``(,%````````M`(``.(&````````
M`````,\&``!H!```3P0``(T#``#Y!P``(0(``.H&````````UP$````````'
M`0``H`$``/T````!"```SP$```````!4!@``T`4``)("````````>`,``"4!
M```I!@``-P(``.,$````````H`(``&4&`````````````%H#````````&`4`
M`'L$``#J````Q08``%$````X`0``>@4``+<"``````````$``#8$````````
M2`0``(L%````````B0,```D#``"/!0````````D'``"I`P```````/4&``!\
M`0``-0$`````````````<@,``+X```#S`0``W0<``-($``#&````FP8``,$$
M```>`P```````*````!<!P``#04```````"4!P```````&(#``#8!0``````
M`+L%``!G!````````(@&```"`0``A0(``-(&``#Y!0``,@<``(,"``#C`0``
M60````8````\!P``XP8``-X```".!P``````````````````.`,``-P"````
M````'0,```````!]!@``>0<``)@$``"Q`0``-0<``"`!`````````````%\$
M``"A!````0(```@(``!]!```N`,``"`"``!@`@``-`4``)\!````````````
M`+X#```4!P``2`$``+,```![`P``P0<``)P!```8`0``L`0``!0!``!J!@``
MA08``!X$````````RP0``.$````Q````$`<`````````````=0$``*`%``"=
M!@``R0,``````````````````)D%``!J!```@P$``)$&``"_`0``A@``````
M``#/````-P0````````3`P``'P,```````#M````Y@<``,H&````````````
M`/P'```P`@```````&X'````````LP(``````````````````!T$``"[`@``
M?@```,\"``"4````(08``$T'``!1!0``Q@4``+\'``!%`0``T00``'8&``"M
M!```X`8```\%``!V!0``5`0```0'``!Q!````````'L&```"!@``M@4``-P#
M``!*!```#08``,`'``#(````2P$```````#D!@``PP(``#L"``#"!P``^`4`
M``````!_!@``200```````"Q`@``,@,``#8"````````"@<```````#W````
MY`4``.4`````````&00``"X"````````"P,``$0!````````Y@,````````>
M!@``*`4``",&`````````````,T%``#_!P``'0```+`"``"F!```$`$``*0"
M``"@!@``&P```%\````Y!0``Y@8``$4%```_`0``'P``````````````````
M``(%``"E!```Q`0``%`"````````TP(``$(&``##````=@(``+T#```\`P``
MM0,`````````````1@0``!P!``"!`````````!X%``!J!0``X@<``.`'``"G
M!```N@,````````'````,`,``#4&```2!```9@<`````````````2````"`$
M``##!@``8P,``````````````````+,#``!0`P```````#4$````````V04`
M`+X&``"E!0``J@,````````C!0``3`(``*L```"S!```*`<``*($``"N````
MS`0``*\!``#2`P```````*0$```%`0``<P(``'@"````````D@8``/D"```O
M!```1@4```````!4``````````````!$````>@$``$````#A!P``0`4`````
M``!P`0``@08``-4%``#0`@``(`4``/,&```%!0``)P(```````!4`@``````
M`(X&``#C`@``3@```/@`````````W@8```````"%!`````````````!P`P``
MJ`<``!4%``#<!P``@P,```````"Y`@``9@````````"W````JP0``"8!```#
M!@``(0$```@&````````+P,```````"V!P``M@,``&P"```0````U08``*$!
M``!Q`P``%P@``"<#```'`P``Z0,````````B"````````-0"``"J!```'0@`
M`%T%``"P!P``<`<```````!O!P``JP,```````#\!@```````&T'``"=````
MW@4``*H%```2!P``)0@``!@$``"W`P``)P0````````.`@``$@4```````!W
M`@``8@4```````"'`@``YP,```````!2`@``?`<``$(```#F!0``!0@``)4!
M``!;`@``(0,``-4!``#0!```@`8```````"U!P```````-8'``#5`P``````
M`-H%``":`0````````````!D!@``C@4``*8"``!=!```/@,```,!``!B````
M``````````!G`P```````-H"```I`P``T0(``)T%````````>@(``%@"``#@
M````SP0`````````````G`8``,<'``"3!```-@<``!`(```/"```E08```$'
M``!*`0``C`$``!4#``!O`P``:0<``/````#*!P``)`(```0(````````N0,`
M``H````0`P``2@<``"0```#(!P````````````"7!P```````","``!D!0``
MR@4``&0!`````````````)4#``!O!@``B@<``"$```!)!@``7@4``"\```#M
M`@```````,D`````````$@```"P$```R!```M`<``'L!``!'!P``.P```+T!
M``!R`0``IP<``"P'``"G`@``20,``#P$``#I!0``UP(``$\'``"S!0``.`<`
M`+P%````````[`<```````#+````[00```D"``")`````````!,$````````
MJ0(``#X"``#Q````RP8``&P'``#+!P``7````)$```#I`@``@`<``(T$``!N
M`@``;P$```````!#!0``K@(``!((```*!@``60(``#`$```#`P``/P(``!`$
M````````CP8``$H"``#H````````````````````_00``,H"```L"```V0(`
M`"8``````````````#T#``!7!@```````(L#``"^!P```04``%<!``#:````
M*P,``.@%``"'!@``E@,```````#,````F0```,X```!S`0```````#X!````
M````V`0```0#``#M`P```````$L`````````0@0``'T```"O`@``*P(``,,!
M``#K`P```````)<`````````O04``.L'```6"```]@`````````D!0``EP$`
M````````````AP$```8'``#[`@```````$L%````````FP(``,4!````````
M7`,```````!H!@``+`8``/<'``"^!````````-H!``#%````4P$``),`````
M````U`,````````4!````````#L'``"R!0``@00``&<!```:`@```````)L'
M```>`0``P@(```````"Q!````````"8%`````````````%8"``"+!@``)P8`
M``````#W!0``A``````````L`@``\0$``!<#``"!`@``[@````````"G!@``
M%@$``$$$````````DP4``/D#``!^`P```````.0"``#T`P``S0,``$T&````
M`````````,D&``#=!@```````"`(``#,!0````````````!!`0``'`4``%D$
M``"H!@``3P,``#$(````````H@$``%<```"7!@``^P8``-(%``#,`0``F@8`
M`(X$``!_`P``&@@````````$!@```````#<#``"\````$00`````````````
MB08```````![!P``[````/H$```Z!P``W`$``($%``#J`0``AP4``/X&``!U
M!0``;@,``-,$```H`@``:`````````",`P``+`4```@$```^!```:P0``%`'
M```-`@``%0$``(4!``".````0`8``(8$```C!P``F@(`````````````&@8`
M`*4```"L!@```````-\&``#K`0``<`8``',&````!0``&P@``/P```!_!```
MZ@<``$0'``!G!@``I`$```````"O!```*```````````````_P,``'(&``!,
M!P``9P```/T%````````Y````)D#```H`0``&P4``.0'``!2````V`,``!,(
M````````F````,X'``#*`P``'0(````````X!```'P4````````#!```^`$`
M``````#7!0``3`$``*X%````````5`<``"`#````````<P,``"`&````````
M`````",!```%!@```@@``/@"````````P@0````````M"```(0<``$H```"0
M!P```````"@$``!M!@``80(``$P```"U!@```````'@'````````%`@``$X%
M````````30(``'`"``!H`@``&````"D``````````````#0`````````\@0`
M``D&``#U`0```````!8"```7!P``D@0``"<'````````3@,``(P'````````
M5@```#,"``#"!0```````````````````````#8%``#P!```[@8```````!_
M!P``:`,`````````````,0$```````"<````W04``%($``"/`P``(00``,D!
M``"R!```````````````````P@$``(<`````````)08```````#[!0``````
M````````````TP4``%D'```"`P```````!4$````````80$``.`#``"$!0``
M`````"@&``#&`@```````$`#````````U@```)(%``#$!@``0`<``/0%``"A
M!0``\@<``/T'``"Y````]@0``!L'```E!```&08``/X'````````VP<``)`"
M``#K`@``_@,```$$````````1`0```H!````````;0(````````\!@``````
M`*,%````````VP8``/$'```$`@``2`4```4"````````:`$``"0$``!$!0``
M``````<&````````[`8````````?!P```````"````#]`P``.08`````````
M`````````+L!```Y`@``UP<``&P#`````````````&D!```Q`@``#````"8#
M``!8!P``0@(``%$&````````G@``````````````70<``"H%```X`@``)P4`
M`&0$``"G`0```````'<%``!A!@``6P````````#T`0``+P4``"D$``"?`P``
M`````)0%``#E`0``.@,```````#-!@``,````-P$````````E`,``%$'``"Z
M!@``C@$``-P&``"X!@``00```&D%``"X`0``-`0``%4$``"+````E0<``#,#
M``"<!```7P,``+T&````````M0````````#7````\08``.<&``!Q`@``K```
M``````""````.@8``'$%``"$!P``K0,``*T'``!-`P``00,``&8"``#R!0``
M_`$````````$`````````+P"``"O!0``>0(`````````````3P````````#B
M`P```````+8&``#]`0``,`@``)8"````````+@@````````Z`@``I@8``$8"
M``#P!0``'`@``$,"`````````````%P$```W!@```````+\$````````2P8`
M`!$"`````````````&<'````````X0(``*X!``#J!0``L`8``$,$``#Q!0``
M```````$``!N!@````````````#9!```K`<``"T$``!V!P``F`(``'`$``#1
M!0``$P````<$``!]!P``.@4``)4```#1!@``(@,``(P%``!>````=08``-8$
M```M`@``DP<``*4!``!X`0```````'P`````````.P4``,`"``""`0``I@<`
M``````!Y`0``V@0``)X!```8`P```````"8$``"J`@``QP0``"(&````````
M2@4``'H$``!C!0```0,``(P$````````]0<``#@&````````:P8````````F
M!@```````#0'```````````````````H"```$P(``)P"`````````````!$'
M```D"```J@```#0&``"R`0``H@```-\$``!]`P``QP```-L$``#>!P``/P<`
M`%4`````````(P@`````````````)P```*0'````````]0,``)@!``"!!P``
M`@(``(4'``"I!P``[@<``&0'``!(`@````````````````````````````"_
M!0```````.8"````````N@4````````M`P``T@```&,'``"(!`````````T#
M```9!0``2@8``.L$``!%`P````````````!)!0``B````%8%``"Q````[@,`
M`*8#``!I`P``+P$``.("```W`0``[P0``-L!````````A0,````````3!@``
MWP4``"("```*!```O`$``.T&````````L0<``$<"````````_`4`````````
M````E@0`````````````/`4``"L(``!+!````````!$&``!]`0``^P$`````
M``#8!@``L04```````"&`@``SP4```````"H````Y`,``,L#``#V!0``````
M`-<#``!X!0``J@8````````V`````````$(%```:!P``3P(``+<%````````
M>``````````T`P``5@$``.\&``"H!0``J`,``%(%```)"```X@4``$4```"P
M!0``"0$``%T&```Q`P```````&L!```F"```0P````````"A!@```````,P#
M````````\P```%4%``!,!@``%0(`````````````I`,``),"````````-P<`
M`%T"````````K08``%X&```O`@``(@0``'(%``"*!0``@@(``!X(``!W!```
M`````&0```!_`@``B@(``-L%````````50,````````%!P``9`(``!X'````
M`````````.0!``"I`0``&P0```````#4!``````````````I!P``,`8``/L'
M``#A!0``3`4``+@"``"K!0``7P8```````!'!`````````````"!`P``/@4`
M`%\!````````>P```*T%```R``````````````#I````O`0``%P&``"N!```
M````````````````-0```&````"T`P``604``'8!``"@!```W00``#T%```Z
M!```Z@(``.8!``!\!0``<P```,8!``#H`P``CP$``(0!```'!P```````'8$
M```7`@``;`0``'H&````````VP(``#X`````````"P```/(!``!<`@``]P$`
M`````````````````!,'```W!0``D@<``-`!````````9@8``%,$``#G````
M+@<``.0$````````F0$``-0%```H`P``+@$```````!L`0``B00``+(```#-
M`@``/0$```````![`@``#`$``#`!```%`````````&T#``!3`P```````-8&
M`````````````)8```#'!0``R00``&D&```<`@````````````#5````.`4`
M`'0%``!X!```QP$```X#````````)@<``%`!``!U`P``:@```'$```#&!```
M=P,``!D(```P!P``70$``,$"```W````R04``/H!``!R!```8`,```H"``"X
M!P``@`,``.(````E!P``\`8```L&``!)`@``FP```(P&````````\00``!\$
M```4!@``:@$``'`%``````````````8"````````I@````````#K!@``````
M`)0&``"1!```_`,``-````!C`0```````+L$``!0`````````!L"``";!0``
M*@8```````#C!P``M`8``"$(```8!P```````)\&``#G`0``A@,``(D%``#]
M!@``V0$``#$&``":!0``$`4````````N!```'`,``-4'```E`@``$P4``%(&
M````````G0<``/,"```&!@``@`$``&4#```U`@``#`<```````"3`P``O@4`
M`&<"````````Q@8``',$``!C!````````$`!``#%!```1@,```````#N!```
MMP$``%(!````````)P$```````"U`0```````````````````````&("````
M````80,``#H```!5`@``8`8`````````````G0,````````6!P````````,%
M``#5`@```````-0&````````&0<`````````````*0$``)4"````````````
M`$`$``!3!0``U@4``!`"````````R`(``%8&````````\P,``"T%````````
M`````(D'```D`P``V0<``#L$``#B!```CP(``%X"``"R!@```````&<%````
M`````````````````````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S
M*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R
M9&%Y*0`@86YD`"!A="``(&]R`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B
M)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG
M=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E
M<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES
M=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N
M=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S
M("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5
M<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S
M(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F
M;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H
M:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U
M;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L
M96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4
M:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O
M(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L
M92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R
M-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R
M<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG
M:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-
M+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T
M;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N
M="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N
M+@!!8V-O=6YT:6YG`$%C=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S<V5S
M.@!!8W1I=F%T92!38W)I<'0`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI
M;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W
M(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C
M:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C
M;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N
M=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!
M9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@
M=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N
M=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN
M(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!!9&1I=&EO;F%L(%-E='1I;F=S`$%D9')E<W,`061D<F5S<R!";V]K`$%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D
M;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`
M06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@
M57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED
M97,`06QL(&]F('1H92!F;VQL;W=I;F<`06QL;W<@;75L=&EP;&4@861D<F5S
M<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A
M9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E
M;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E
M>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I
M9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!
M;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G-W97)E
M9`!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`06YY(&]F('1H92!F
M;VQL;W=I;F<`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A
M=&EO;B!I<R!R96%D>2X`07!P;'D@1FEL=&5R<P!!<'!L>2!T;R!#:&EL9"!3
M:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H
M5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`
M07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES(')U;&4_`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R
M;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD
M`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!
M<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S
M=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N
M(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D
M`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R
M=F5R(&9A:6QE9"X`075T;VUA=&EC86QL>2!U<&1A=&4@=&AE('-C<FEP="!A
M9G1E<B!E86-H(&-H86YG93\`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA
M;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A
M9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"
M86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F
M;W5N9"X`0F%S96QI;F4`0F-C`$)E9VEN<R!W:71H`$)E;&%R=7,`0F5L9VEU
M;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQA8VML
M:7-T`$)L86-K;&ES="!%9&ET`$)L86-K;&ES="!I<R!N;W0@<W5P<&]R=&5D
M(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$)L86-K;&ES=&5D
M($%D9')E<W,`0FQA8VML:7-T960@061D<F5S<V5S`$)L;V-K("(E<R(@;V8@
M87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L
M;V-K(%1Y<&4`0F]D>0!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!"
M;W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N
M9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E
M<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A
M`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F
M:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R
M+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E
M+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O
M9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H
M(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A<V4@
M4V5N<VET:79E`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD
M<P!#8P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z
M`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT
M:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E
M($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I
M97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG97,@<V%V960N
M`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H
M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R
M9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y
M`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T
M80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@
M=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO
M=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`
M0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R
M`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`
M0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M
M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#
M;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y
M;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N
M9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I
M<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL
M960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT86EN<P!#;VYT96YT('1Y
M<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT
M:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2`E<P!#;W!Y(&9A
M:6QE9#H@)7,`0V]P>2!O9B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O
M<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L
M9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N
M;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO
M="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E
M<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E
M<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS
M('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY
M('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E
M('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E
M<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T
M90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E(&YE=R!F
M;VQD97(`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`
M0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA
M<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),
M(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N
M9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#
M>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1$E3
M04),140`1$E304),140Z(`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`
M1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU
M;6X`1&5A8W1I=F%T92!38W)I<'0`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S
M`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L
M="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$
M96QE=&4@)7,`1&5L971E($-E;&P`1&5L971E($-O;F1I=&EO;@!$96QE=&4@
M1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD
M('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G
M92!C;VUP;&5T96QY`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$
M96QE=&5D`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L
M:79E<B!I;G1O(&UY($E.0D]8`$1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@
M8V]P>2!T;P!$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(')E9&ER96-T('1O
M`$1E;&EV97(@=&\@9F]L9&5R`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C
M<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO
M;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C
M=&]R>0!$:7-A8FQE("5S`$1I<V%B;&5D`$1I<W!L87D@,C0M:&]U<B!T:6UE
M<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`
M1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E
M<B!I<R!A<'!L:65D/P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@
M9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!?
M;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES="!M97-S86=E<P!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O('1H:7,Z`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]E<VXG
M="!B96=I;B!W:71H`$1O97-N)W0@8V]N=&%I;@!$;V5S;B=T(&5N9"!W:71H
M`$1O97-N)W0@97AI<W0`1&]E<VXG="!M871C:"`H=VET:"!P;&%C96AO;&1E
M<G,I`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N
M(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R
M;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A
M>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R
M=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET("5S`$5D:70@0FQO8VL`161I
M="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E
M<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D
M=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL
M`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M
M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M
M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E
M87)C:"!T97)M<P!%;F%B;&4@)7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G
M97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT
M(&-L:6-K(&-O;G1E>'0@;65N=3\`16YA8FQE9`!%;F0@>65A<@!%;F1S('=I
M=&@`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@
M<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;&5T
M=&5R<R!B96QO=SH`17%U86P@=&\`17%U871O<FEA;"!'=6EN96$`17)I=')E
M80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I
M;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E
M<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T:6YG('!A
M<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R
M:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V
M97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N
M9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U
M<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AI<W1I
M;F<@4G5L97,`17AI<W1S`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E
M9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A
M9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`
M1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL
M960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&
M96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&
M97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&
M:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE
M($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@
M<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+@!&:6QT97(@06QL($UE<W-A9V5S`$9I;'1E<B!/;FQY(%-E96X@365S
M<V%G97,`1FEL=&5R($]N;'D@56YS965N($UE<W-A9V5S`$9I;'1E<B!/<'1I
M;VYS`$9I;'1E<B!2=6QE`$9I;'1E<B!2=6QE<P!&:6QT97(@4V-R:7!T($1I
M<W!L87D`1FEL=&5R(%]2=6QE<P!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A
M9V4H<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I
M;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@9&5L971E
M9"X`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!M
M;W9E9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E<B!A8W1I=FET>3H@)7,@
M;65S<V%G92AS*2!T:&%T(&UA=&-H960@=&AE(&)L86-K;&ES="!W97)E(&1E
M;&5T960N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M
M("(E<R(@:&%S(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@(B5S(BX`1FEL
M=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E("(E
M<R(@9G)O;2`B)7,B(&AA<R!B965N(&UO=F5D('1O('1H92!F;VQD97(@(B5S
M(BX`1FEL=&5R(&YO="!F;W5N9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA
M;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@86X@
M:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z`$9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O
M<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9"!I<R!N;W0@<W5P<&]R
M=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$9O<G=A<F1S
M`$9O<G=A<F1S($5D:70`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O
M<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S
M8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`
M1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!-
M87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R96%T97(@=&AA;@!'<F5A
M=&5R('1H86X@;W(@97%U86P@=&\`1W)E96-E`$=R965K("A)4T\M.#@U.2TW
M*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D
M96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I
M;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-
M3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N
M`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L
M9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@
M36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X
M-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`
M2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD
M=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`
M2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L
M.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N
M>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(
M=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0
M($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)
M7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O
M<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S
M97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E
M(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A
M9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!)
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@
M26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD:79I9'5A;"!R=6QE
M<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@
M9')I=F5R+@!);F1O;F5S:6$`26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE
M9"!F;W(@;65S<V%G92!D96QI=F5R>2X`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN
M=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B
M871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L
M:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C
M;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S
M(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE
M8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27,`27-L92!O9B!-86X`27-N)W0`27-O;&%T960@5"U3=&]R;7,`27-R865L
M`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA
M<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`
M2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,
M969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+
M96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`
M2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!2
M97!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`
M3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R
M=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U
M=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T
M(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE<W,@=&AA;@!,97-S('1H
M86X@;W(@97%U86P@=&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA
M:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN
M`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@
M4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG
M:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4
M;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T
M+4E$`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I
M8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C
M86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G
M(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN
M(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@
M<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE
M9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W
M97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U
M<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`
M36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-
M86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA
M<'!I;F=S('-T;W)E9"X`36%R7VL@;65S<V%G92!A<R!D96QE=&5D`$UA<F-H
M`$UA<F=I;@!-87)K(&UE<W-A9V4@87,Z`$UA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT
M+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAE
M<R`H=VET:"!P;&%C96AO;&1E<G,I`$UA=&-H:6YG(&9I96QD<P!-875R:71A
M;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E
M('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X
M('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L
M($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!B;&%C
M:VQI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@
M)7,L($UA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE
M=R!A9&1R97-S97,@=&\@8FQA8VML:7-T+@!-87AI;75M(&YU;6)E<B!O9B!W
M:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E
M<SH@)7,L($UA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D
M(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+@!-87D`36%Y;W1T90!-961I
M8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E
M>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S
M(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE
M;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN
M9R!A9&1R97-S('1O(')E9&ER96-T(&UE<W-A9V4@=&\`36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G
M92!)1"X`36ES<VEN9R!R96%S;VX@9F]R(')E:F5C=`!-:7-S:6YG(')E87-O
M;B!I;B!V86-A=&EO;BX`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@
M36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E
M<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A
M+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`
M36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O
M=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`
M36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4`
M36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@4G5L92!$;W=N
M`$UO=F4@4G5L92!5<`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M
M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+
M(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT
M($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM
M87(`3D\L($D@1&\@3D]4($%G<F5E`$Y?=6UB97(@;V8@9&%Y<R!B971W965N
M('9A8V%T:6]N(')E<&QI97,Z`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.
M971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E
M(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P
M;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C
M871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`
M3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@
M365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@4G5L90!.97<@57-E<FYA;64@
M*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W
M;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA
M=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT
M`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.
M:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@)R5S)R!E;&5M96YT(&9O
M=6YD(&EN(&)A8VME;F0@8V]N9FEG=7)A=&EO;BX`3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@
M8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0`3F\@8F%C:V5N9',@
M8V]N9FEG=7)E9"!I;B!B86-K96YD<RYP:'``3F\@8F%T8V@@=&5M<&QA=&4N
M`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO
M(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I
M;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO
M(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL
M92!U<&QO861E9`!.;R!F:6QT97)S+B!#;&EC:R`G)7,G('1O(&-R96%T92!A
M(&YE=R!F:6QT97(N`$YO(&AE861E<G,@<W!E8VEF:65D`$YO(&EC;VYS(&9O
M=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D
M+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@
M;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC
M871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D
M+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET
M:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@
M<V5T+@!.;R!R=6QE<P!.;R!S8W)I<'0@9V5N97)A=&5D+@!.;R!S97!A<F%T
M;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=')I;F=S('-P96-I9FEE9`!.
M;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@
M9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO
M;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L
M:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA
M($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I
M<F5C=&]R>0!.;W0@97%U86P@=&\`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T
M`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B
M86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M
M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`
M3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F
M:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R
M<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I
M;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD
M;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@86)O=70@<V-R
M:7!T('5P9&%T:6YG+@!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`
M3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N
M871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI
M9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!0
M32!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`
M4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`
M4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N
M9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W
M;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0
M871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@
M;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N
M`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`
M4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@
M96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI
M;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y
M.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT
M97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@
M=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@
M96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T
M;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@
M9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)?
M96%S;VX`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA
M=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N
M9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-E:79E9`!2961I<F5C="!T;P!2
M961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!2
M96=U;&%R(&5X<')E<W-I;VX`4F5J96-T('=I=&@@<F5A<V]N`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I
M;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S96YT(%1O`%)E
M<V5N="UF<F]M`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S
M<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($9I
M;'1E<G,@3&ES=`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@4G5L97,@
M3&ES=`!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I
M9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG
M:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N
M+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E
M(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U
M;&4`4G5L92!#;W!I960`4G5L92!$96QE=&5D`%)U;&4@1&ES86)L960`4G5L
M92!%;F%B;&5D`%)U;&4@3F%M90!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@
M2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN
M="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'
M<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U
M9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS
M`%-A=F4@4V5T=&EN9W,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C
M:65N8V4`4V-R:7!T`%-C<FEP="!5<&1A=&EN9P!38W)I<'0@;F]T('5P9&%T
M960N`%-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D+@!38W)I<'0@<W5C
M8V5S<V9U;&QY(&1E86-T:79A=&5D+@!396%R8V@`4V5A<F-H($5N9VEN97,`
M4V5E;@!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!F:65L
M9`!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E
M;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL
M`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T
M`%-E;&5C="!N;VYE`%-E;&5C="!T87)G970@9F]L9&5R`%-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A
M<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.@!396QF+41E9FEN960@2&5A9&5R`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N9"!335,`4V5N9&5R`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R
M`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S
M<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@
M>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@
M<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=&EN
M9W,@<W5C8V5S<V9U;&QY('5P9&%T960N`%-E='5P`%-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W`%-H;W<@06-T:79E(%-C<FEP=`!3:&]W($-U<G)E
M;G0@4V-R:7!T`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY
M`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3
M:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E
M;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W
M(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E
M`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO
M;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@
M<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%
M=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C
M92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N
M="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A
M;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I
M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R
M(%!R;W9I;F-E`%-T871U<P!3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M
M871C:&5S/P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T
M:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R
M97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`4W5B:F5?8W0@;V8@=F%C871I;VX@;65S<V%G93H`4W5B:F5C=`!3=6)M
M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B
M965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I
M9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY
M('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F
M=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N
M`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I
M<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I
M<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@
M36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D
M96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y
M<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`
M5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@
M4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@
M3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E
M<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E
M9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI
M<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H
M`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E
M;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L
M9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W
M(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S
M('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD
M(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S
M:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A
M<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`
M5&AE(&1R:79E<B!S86ED.B``5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S
M<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@
M;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S
M(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H
M92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS
M<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI
M;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@
M<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D
M871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H
M92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA
M;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N
M`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D
M(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@
M9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@
M;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U
M<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D
M9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L
M96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z
M("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@
M;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV
M871I;F<@=&AE('-C<FEP="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1E86-T:79A
M=&EN9R!T:&4@<V-R:7!T+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O
M=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4
M:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN
M<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M
M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T
M960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R
M`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@
M<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`
M5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN
M9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO
M<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`
M5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`
M5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z
M(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O
M97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D
M($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK
M;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O
M('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5
M<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G
M<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I
M;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R
M<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T
M:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T
M(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N
M`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z
M8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I
M;VX`5F%C871I;VX@161I=`!686-A=&EO;B!-97-S86=E`%9A8V%T:6]N(&ES
M(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E
M<BX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@
M9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`
M5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M
M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`
M5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``
M5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T
M:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E
M`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S
M=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E
M<FX@4V%H87)A`%=H7VET96QI<W0@861D<F5S<V5S.@!7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R
M86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+@!7:&ET96QI<W0`5VAI=&5L:7-T($5D:70`5VAI=&5L:7-T(&ES(&YO="!S
M=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`5VAI
M=&5L:7-T960@061D<F5S<V5S`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N
M:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@
M:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@
M061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@
M;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E
M="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4')I;W)I='D`6"U2
M968`6"U3<&%M+4QE=F5L`%@M4W!A;2U38V]R90!8+5-P86TM4W1A='5S`%@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E9
M60!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO
M=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S
M=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O
M(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A=71H
M96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@
M:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@
M96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M
M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD
M<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY
M('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D
M:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU
M92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U
M<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T
M(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N
M92!E;6%I;"!A9&1R97-S(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@;65S<V%G
M97,@<VAO=6QD(&)E(&%C=&EV871E9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT
M+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I
M='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9
M;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P
M87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO
M=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`
M6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M.;R!3=6)J96-T70!;4')O8FQE
M;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&1R97-S*&5S*2!T
M;R!F;W)W87)D('1O.@!?061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E
M<R!T;SH`7T%D;6EN:7-T<F%T:6]N`%]";&%C:VQI<W0`7T-,20!?1&%T851R
M964`7T1E;&5T92!2;W<`7T1E;&5T92!M97-S86=E(&-O;7!L971E;'D`7T5N
M=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE.@!?1F]R=V%R9`!?1W)O
M=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%]+965P(&$@8V]P>2!O
M9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_`%],;V<@:6X`7TQO9R!O=70`
M7TUO9&EF>2!,:6YK+BXN`%]-;W9E(&UE<W-A9V4@=&\@9F]L9&5R.@!?37D@
M96UA:6P@861D<F5S<V5S.@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V
M92!,:6YK+BXN`%]38W)I<'0`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN
M`%]5<V5R<P!?5F%C871I;VX`7U=H:71E;&ES=`!A9&1R97-S(&)O;VL`861D
M<F5S<V5E('5N:VYO=VX`86YD`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`
M96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEE;&0`9FEL90!F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO
M=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N
M86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UA=&-H`&UK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE
M;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;W(`<&5R8V5N=`!P
M97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<')O8VUA:6P@<V-R:7!T(&=E;F5R
M871E9"!B>2!);F=O`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`
M<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-I979E(&9I
M;'1E<B!G96YE<F%T960@8GD@26YG;P!S;7,R96UA:6P@=FEA($A45%``<W,`
M<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU
M<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O
M:F5C="U)9"U697)S:6]N.B!F<E]&4@I297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-"TQ
M,BTP-R`Q-3HP,BTP-3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#,M,#<@
M,34Z,#,M,#4P,`I,87-T+51R86YS;&%T;W(Z($)E;F]I="!3="U!;F1R92`\
M8F5N0&)E;F]I='-T+6%N9')E+FYE=#X*3&%N9W5A9V4M5&5A;3H@1G)A;F-A
M:7,@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E@M1V5N97)A=&]R.B!+
M0F%B96P@,2XS"@`@*&EL('D@82`E<R!J;W5R<RD`("A4;W5C:&4@9"=A8V/H
M<R!R87!I9&4@)7,I`"`H9&%N<R`E<R!J;W5R<RD`("AA=6IO=7)D)VAU:2D`
M("AD96UA:6XI`"`H:&EE<BD`(&5T`"#@(``@;W4`JZ`E<Z"[(&XG97-T('!A
M<R!U;B!D;W-S:65R`*N@)7.@NR!N)V5S="!P87,@=6X@8VAO:7@@=F%L:61E
M+@"KH"5SH+L@;B=E<W0@<&%S(&-O;F9I9W5RZ2!D86YS(&QE(')E9VES=')E
M(&1E($AO<F1E+@!,)VEN=&5R<'+I=&5U<B!D)V%R8G)E(*N@)7.@NR!N)V$@
M<&%S(.ETZ2!T<F]U=NDN`*N@)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM
M92!D97,@9W)O=7!E<RX`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S>7-TZ&UE
M(&1E<R!P97)M:7-S:6]N<RX`JZ`E<Z"[(&XG82!P87,@Z73I(&-RZ>F@.B`E
M<RX`)2XR9J!-;R!U=&EL:7/I<R!S=7(@)2XR9J!-;R!P97)M:7,@*"4N,F:@
M)24I`"5D("5S(&5T("5S`"5D(&IO=7)S(&%V86YT(&PG97AP:7)A=&EO;B!D
M92!V;W1R92!M;W0@9&4@<&%S<V4N`"5D+7!RZ79I<VEO;B!D=2!J;W5R`"5S
M("T@3F]T:6-E`$5M<')E:6YT92!01U`@9&4@)7,`)7.@2V\`)7,@;W#I<F%T
M:6]N<R!D92!M86EN=&5N86YC92`F;F1A<V@[($-O;F9I<FUA=&EO;@!#;VYF
M:6=U<F%T:6]N("5S`$EN<V-R:7!T:6]N(&1E("5S`$-O;F1I=&EO;G,@9"=U
M=&EL:7-A=&EO;B!D92`E<P`E<R!E>&ES=&4@9.EJX"X`("5SH.`@)7,@)7,`
M)7,@97-T('!RZG0@X"!E9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I
M;G1E;F%N8V4@8V]C:.EE<R!C:2UD97-S;W5S+B!3Z6QE8W1I;VYN97H@;&$@
M;W4@;&5S(&]PZ7)A=&EO;BAS*2!Q=64@=F]U<R!V;W5L97H@969F96-T=65R
M(&-E='1E(&9O:7,M8VDN`"5S(&5S="!O8FQI9V%T;VER90`E<R!M:6YU=&5S
M`"5S(&YO;B!T<F]U=ND`)7.@X"`E<R!D92`E<P!#87)N970@9"=A9')E<W-E
M<R!D92`E<P!!9V5N9&$@9&4@)7,`0FQO8RUN;W1E<R!D92`E<P!,:7-T92!D
M92!TXF-H97,@9&4@)7,`)7.@.B`E<P`E<Z`Z(&PGZ6UE='1E=7(@9&4@8V4@
M;65S<V%G92!A('!U(.IT<F4@9F%L<VEF:>DN($%T=&5N=&EO;B!E;B!S=6EV
M86YT(&QE<R!L:65N<R!Q=2=I;"!C;VYT:65N="!O=2!E;B!F;W5R;FES<V%N
M="!D97,@:6YF;W)M871I;VYS('!E<G-O;FYE;&QE<R#@(&PGZ6UE='1E=7(N
M`"P@96X@<F%F86QE(`!R869A;&4@)7,@)7,`=F%R:6%B;&4@9'4@)7,@874@
M)7,`+2T@4^EL96-T:6]N;F5R("TM`$9O<FUA="`Q,B!H975R97,`1F]R;6%T
M(#(T(&AE=7)E<P`R-"!H975R97,`/%!RZ6/I9&5N=`!5;F4@8F%S92!D92!D
M;VYNZ65S('!R:6YC:7!A;&4@*&)A8VME;F0I(&5S="!NZ6-E<W-A:7)E('!O
M=7(@8V4@8FQO8P!5;F4@97)R975R(&9A=&%L92!S)V5S="!P<F]D=6ET90!5
M;F4@8VQE9B!P=6)L:7%U92!01U`@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF
M9G)E<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!01U`@97-T(&[I
M8V5S<V%I<F4@<&]U<B!VZ7)I9FEE<B!L82!S:6=N871U<F4@9"=U;B!M97-S
M86=E+@!5;F4@8VQE9B!P=6)L:7%U92!01U`L('5N92!C;&5F('!R:7;I92!0
M1U`L(&5T('5N92!P:')A<V4@<V5C<NAT92!S;VYT(&[I8V5S<V%I<F5S('!O
M=7(@9.EC:&EF9G)E<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!0
M1U`L('5N92!C;&5F('!R:7;I92!01U`L(&5T('5N92!P:')A<V4@<V5C<NAT
M92!S;VYT(&[I8V5S<V%I<F5S('!O=7(@<VEG;F5R('5N(&UE<W-A9V4N`%5N
M92!C;&5F('!U8FQI<75E(%,O34E-12P@=6YE(&-L968@<')I=NEE(%,O34E-
M12P@970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U
M<B!DZ6-H:69F<F5R('5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%,O
M34E-12P@=6YE(&-L968@<')I=NEE(%,O34E-12P@970@=6YE('!H<F%S92!S
M96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U<B!S:6=N97(@=6X@;65S<V%G
M92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%(&5S="!NZ6-E<W-A:7)E('!O
M=7(@8VAI9F9R97(@=6X@;65S<V%G92X`3G5A9V5S(&QE(&UA=&EN`%!L=6EE
M(&SI9^AR92!L92!M871I;@!0;'5I92!L92!M871I;@!!=F5R<V5S(&QE(&UA
M=&EN`$-H=71E<R!D92!N96EG92!L92!M871I;@!!32]030!!4$D@240`P"!P
M<F]P;W,@9&4@8V5T(.ED:71E=7(`P"!P<F]P;W,N+BX`0F%S(&%B<V]L=0!-
M:6QI974@86)S;VQU`$%C8^AS(')E9G5SZ2!L;W)S(&1E(&QA(&-RZ6%T:6]N
M(&1E('+I<&5R=&]I<F4@5D93("X`06-CZ',@<F5F=7/I(&QO<G,@9&4@;&$@
M8W+I871I;VX@9&4@9FEC:&EE<B!61E,N`$1O;F[I97,@<&5R<V]N;F5L;&5S
M`$UO="!D92!P87-S92!D=2!C;VUP=&4`0V]M<'1E(&EN86-T:68`0V]M<'1E
M<P!!8W1I;VX@<&]U<B!L97,@861R97-S97,@96X@;&ES=&4@;F]I<F4Z`$%C
M=&EV97(@8V4@<V-R:7!T(`!!:F]U=&5R`$%J;W5T97(@=6X@<V]U<RUG<F]U
M<&4`06IO=71E<B!U;F4@;F]U=F5L;&4@<V]U<RUP97)M:7-S:6]N`$%J;W5T
M97(@:6-IH#H`06IO=71E<B!U;B!N;W5V96%U(&=R;W5P90!!:F]U=&5R('5N
M92!N;W5V96QL92!P97)M:7-S:6]N`$%J;W5T97(@=6X@9W)O=7!E(&9I;',@
MX""KH"5SH+L`06IO=71E<B!U;F4@<&5R;6ES<VEO;B!F:6QL92#@(*N@)7.@
MNP!!:F]U=&5R('5N(&YO=79E;"!U=&EL:7-A=&5U<J`Z`$%J;W5T97(@=6YE
M(&-O;&]N;F4`06IO=71E<B!D92!N;W5V96%U>"!M96UB<F5S`$%J;W5T97(@
M=6YE('!A:7)E`$%J;W5T97(@;&4@;65N=2`E<R#@(&QA(&)A<G)E(&1E($UO
M>FEL;&$`06IO=71E<B!A=2!C87)N970@9"=A9')E<W-E<Z`Z`$%J;W5T97(@
MX"!M;VX@8V%R;F5T(&0G861R97-S97,`06IO=71E<B!U;B!U=&EL:7-A=&5U
M<@"KH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64L(&UA:7,@;"=A:F]U
M="!D)VEN9F]R;6%T:6]N('-U<'!LZ6UE;G1A:7)E<R`E<R!N)V5S="!P87,@
M<&]S<VEB;&4N`*N@)7.@NR!A(.ETZ2!A:F]U=.DN(%9O=7,@<&]U=F5Z('9O
M=7,@8V]N;F5C=&5R+@!,82!F;VYC=&EO;B!D)V%J;W5T(&0G=71I;&ES871E
M=7)S(&5S="!DZ7-A8W1I=NEE+@!/<'1I;VYS('-U<'!LZ6UE;G1A:7)E<P!!
M9')E<W-E`$-A<FYE="!D)V%D<F5S<V5S`$%D;6EN:7-T<F%T975R("T@86IU
M<W1E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!D)V%U=')E<R!U=&EL:7-A=&5U
M<G,`061M:6YI<W1R871I;VX`4'5B<P!!9F=H86YI<W1A;@!!;&)A;FEE`$%L
M9^ER:64`06QI87,`06QI9VYE<@!!;&EG;F5M96YTH#H`5&]U=`!4;W5S(&QE
M<R!P87)T:6-I<&%N=',@875T:&5N=&EF:>ES`%1O=7,@;&5S(&=R;W5P97,`
M5&]U=&5S(&QE<R!P97)M:7-S:6]N<P!,97,@<75A=')E(&/T=.ES`%1O=70@
M8V4@<75I('-U:70`4&5R;65T=')E(&1E<R!A9')E<W-E<R!D92!C;W5R<FEE
M;"!M=6QT:7!L97,`075T;W)I<V5R(&QA(&UI<V4@96X@<&QA8V4@9&4@;&ES
M=&5S(&YU;>ER;W3I97.@/P!%>&ES=&4@9.EJX`!.;VT@9"=U=&EL:7-A=&5U
M<B!)35-0(&%L=&5R;F%T:68`36]T(&1E('!A<W-E($E-4U`@86QT97)N871I
M9@!.;VT@9"=U=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68`061R97-S92!D
M92!C;W5R<FEE;"!A;'1E<FYA=&EV90!!=71R97,@;6]DZ&QE<P!497AT92!A
M;'1E<FYA=&EFH#H`4V%M;V$@06WI<FEC86EN`%5N92!V86QE=7(@:6QLZ6=A
M;&4@82#I=.D@<W#I8VEF:>EE+@!5;F4@97)R975R(&EN8V]N;G5E(',G97-T
M('!R;V1U:71E+@!!;F1O<G)E`$%N9V]L80!!;F=U:6QL80!0<F]X>2!A;F]N
M>6UE`%+I<&]N<V4`4NEP;VYD=0!!;G1A<F-T:7%U90!!;G1I9W5A+65T+4)A
M<F)U9&$`074@;6]I;G,@;"=U;B!D92!C92!Q=6D@<W5I=`!!<'!L:6-A=&EO
M;@!,:7-T92!D)V%P<&QI8V%T:6]N<P!,)V%P<&QI8V%T:6]N(&5S="!P<NIT
M90!!<'!L:7%U97(@;&5S(&9I;'1R97,`07!P;&EQ=65R(&%U>"!P87)T86=E
M<R!F:6QS`$%P<')O=7;I`%1A:6QL92!A<'!R;WAI;6%T:79E`$%V<FEL`$%R
M86)E("A7:6YD;W=S+3$R-38I`%1A:6QL92!D=2!F:6-H:65R(&%R8VAI=F4`
M3F]M(&1E(&PG87)C:&EV90#*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER
M('-U<'!R:6UE<B!C971T92!RZ&=L9:`_`,IT97,M=F]U<R!C97)T86EN(&1E
M('9O=6QO:7(@<W5P<')I;65R(&-E='1E(')E<77J=&4@9"=I;G-C<FEP=&EO
M;B`@<&]U<B`E<Z`_`,IT97,M=F]U<R!C97)T86EN(&1E('9O=6QO:7(@969F
M86-E<B"KH"5SH+L@970@<V5S('-O=7,M9W)O=7!E<Z`_`$%R9V5N=&EN90!!
M<FWI;FEE`$%R;>EN:65N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I
M;VX@*,YL92D`07)T($%30TE)`%+I9VEO;B!!<VEE+U!A8VEF:7%U90!$96UA
M;F1E<B!U;F4@8V]N9FER;6%T:6]N(&%V86YT(&1E(&QA;F-E<B!L97,@;W#I
M<F%T:6]N<R!D92!M86EN=&5N86YC9:`_`$-O;&]N;F5S(&1E<R!TXF-H97,`
M5&5N=&%T:79E(&0G969F86-E;65N="!D)W5N(&=R;W5P92!I;F5X:7-T86YT
M+@!496YT871I=F4@(&0G969F86-E;65N="!D)W5N92!P97)M:7-S:6]N(&EN
M97AI<W1A;G1E+@!496YT871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6YE('!E
M<FUI<W-I;VX@:6YE>&ES=&%N=&4N`%1E;G1A=&EV92!D92!M;V1I9FEC871I
M;VX@9"=U;B!P87)T86=E(&EN97AI<W1A;G0N`%!R;W!R:>ETZ7,`06_[=`!!
M=7-T<F%L:64`075T<FEC:&4`075T:%]C>7)U<Z`Z($5X=&5N<VEO;B!R97%U
M:7-E($E-05`@;F]N('1R;W5VZ64N`$%U=&A?8WER=7.@.B!L92!B86-K96YD
M(&XG82!P87,@;&5S(&-A<&%C:73I<R!R97%U:7-E<RX`075T:%]C>7)U<Z`Z
M(&5X=&5N<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64`075T:%]F='"@
M.B!E>'1E;G-I;VX@<F5Q=6ES92!&5%`@;F]N('1R;W5VZ64N($EL(&9A=70@
M8V]M<&EL97(@4$A0(&%V96,@;"=O<'1I;VX@+2UE;F%B;&4M9G1P+@!!=71H
M7VEM87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE+@!!
M=71H7VMR8C6@.B!E>'1E;G-I;VX@<F5Q=6ES92!K<F(U(&YO;B!T<F]U=NEE
M+@!!=71H7VQD87"@.B!L)V%J;W5T(&0G=71I;&ES871E=7)S(&XG97-T('!A
M<R!S=7!P;W)TZ2!A=F5C($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%PH#H@
M;&4@<F5T<F%I="!D)W5T:6QI<V%T975R<R!N)V5S="!P87,@<W5P<&]R=.D@
M879E8R!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<*`Z(&5X=&5N<VEO;B!R
M97%U:7-E($Q$05`@;F]N('1R;W5VZ64N`$%U=&A?;&1A<*`Z(&EM<&]S<VEB
M;&4@9"=A:F]U=&5R(&PG=71I;&ES871E=7(@)7,N($-E8VD@97-T(&QA('+I
M<&]N<V4@9'4@<V5R=F5U<J`Z(`!!=71H7VQD87"@.B!I;7!O<W-I8FQE(&1E
M('-U<'!R:6UE<B!L)W5T:6QI<V%T975R("5S`$%U=&A?;&1A<*`Z(&UO9&EF
M:6-A=&EO;B!I;7!O<W-I8FQE(&1E(&PG=71I;&ES871E=7(@)7,`075T:%]L
M9&%PH#H@;&$@;6]D:69I8V%T:6]N(&1E<R!U=&EL:7-A=&5U<G,@;B=E<W0@
M<&%S('-U<'!O<G3I92!A=F5C($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A
M;*`Z(&5X=&5N<VEO;B!R97%U:7-E($U#04P@;F]N('1R;W5VZ64N`$%U=&A?
M<VUB875T:*`Z(&5X=&5N<VEO;B!R97%U:7-E('-M8F%U=&@@;F]N('1R;W5V
MZ64N`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO;B!A=2!S97)V975R($E-
M05`N`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO;@#)8VAE8R!D92!L)V%U
M=&AE;G1I9FEC871I;VX@)7,`3&4@<V5R=F5U<B!2041)55,@82!R96IE=.D@
M;"=A=71H96YT:69I8V%T:6]N+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC871I
M;VX@874@<V5R=F5U<B!&5%`N`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO
M;B!A=2!S97)V975R(%--0BX`365T=')E(.`@:F]U<B!L92!S8W)I<'0@875T
M;VUA=&EQ=65M96YT(&%P<NAS(&-H87%U92!C:&%N9V5M96YT/P!#:&%M<',@
M9&ES<&]N:6)L97.@.@!!>F5R8F'O9&IA;@!%>&-U<V5S($)/1D@`0V]U;&5U
M<B!D92!F;VYD`$-O=6QE=7(@9&4@9F]N9`!-;W0@9&4@<&%S<V4@2V5R8F5R
M;W,@97)R;V[I+@!.;VT@9&4@8V]N;F5X:6]N($ME<F)E<F]S(&5R<F]NZ2X`
M0F%H86UA<P!"86AR9>]N`$)A;'1E("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87)B861E`%+I<&5R=&]I<F4@9&5S(&=R87!H:7%U97,@JZ`E<Z"[(&YO
M;B!T<F]U=NDN`$QI9VYE(&1E(&)A<V4`0V-I`$-O;6UE;F-E('!A<@!"Z6QA
M<G5S`$)E;&=I<75E`$)E;&EZ90!"Z6YI;@!"97)M=61E<P!":&]U=&%N`$%N
M;FEV97)S86ER90!,:7-T92!.;VER90#)9&ET97(@;&$@3&ES=&4@3F]I<F4`
M3&$@;&ES=&4@;F]I<F4@;B=E<W0@<&%S('-U<'!O<G3I(&1A;G,@;&4@9FEL
M=')E(&%C='5E;"X`061R97-S92!E;B!L:7-T92!.;VER90!!9')E<W-E<R!E
M;B!L:7-T92!.;VER90!";&]C(*LE<R"[(&1E(&PG87!P;&EC871I;VX@JZ`E
M<Z"[(&EN8V]N;G4`4'+I9NER96YC97,@9&4@8FQO8P!4>7!E(&1E(&)L;V,`
M0V]R<',`1W)A<P!";VQI=FEE`%-I9VYE=',`0F]R9'5R90#)<&%I<W-E=7(@
M9&4@;&$@8F]R9'5R9:`Z`$)O<F1S`$)O<VYI92U(97)ZZ6=O=FEN90!,97,@
M9&5U>`!";W1S=V%N80!"87,`0F]U=F5T`$)RZ7-I;`!497)R:71O:7)E<R!B
M<FET86YN:7%U97,@9&4@;"=/8^EA;B!);F1I96X`4W5L=&%N870@9'4@0G)U
M;NEI`$)U;&=A<FEE`$QI<W1E(.`@<'5C97,`0G5R:VEN82!&87-O`$)U<G5N
M9&D`1V5S=&EO;B!D92!C;VYT96YU`$-20P!$:7-T<FEB=71I;VX@9&5S('!O
M:6YT<R!,4D,@*$QI<W1E(&1E('+I=F]C871I;VX@9&5S(&-E<G1I9FEC871S
M*0!0<F]P<FGI=.ES(&1E(&QA($-?96QL=6QE`$PG:6YI=&EA;&ES871I;VX@
M9'4@8V%C:&4@;F4@<R=E<W0@<&%S('1E<FUI;NEE+@!!9V5N9&$`0V%L;64`
M0V%M8F]D9V4`0V%M97)O=6X`26UP;W-S:6)L92!D92!RZ6EN:71I86QI<V5R
M(&QE(&UO="!D92!P87-S92!A=71O;6%T:7%U96UE;G0L(&-O;G1A8W1E>B!V
M;W1R92!A9&UI;FES=')A=&5U<B!S>7-TZ&UE+@!);7!O<W-I8FQE(&1E('-U
M<'!R:6UE<B!L92!F:6-H:65R(*N@)7.@NRX`26UP;W-S:6)L92!D)V%D;6EN
M:7-T<F5R(&1E<R!G97-T:6]N;F%I<F5S(&1E('-E<W-I;VX@97AT97)N97,N
M`,EC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R($E-05"@.B`E<P!)
M;7!O<W-I8FQE(&0G;W5V<FER(&QE(&9I8VAI97(@JZ`E<Z"[+@!#86YA9&$`
M06YN=6QE<@!!;FYU;&5R(&QE(')A<'!O<G0@9'4@<')O8FSH;64`26UP;W-S
M:6)L92!D92!S=7!P<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN`$EM<&]S<VEB
M;&4@9&4@=')O=79E<B!U;B!RZ7!E<G1O:7)E('1E;7!O<F%I<F4`26UP;W-S
M:6)L92!D92!P<F]CZ61E<B!S86YS(&QE('!A<F%MZ'1R92"K('1A<F=E=$9I
M;&4@NP!);7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!RZ7!E<G1O:7)E(*N@
M)7.@NRX`4W5P<')E<W-I;VX@:6UP;W-S:6)L92P@:6P@>2!A("5D(&5N<F5G
M:7-T<F5M96YT<R!F:6QS+@!);7!O<W-I8FQE(&1E('+I;W)D;VYN97(L(&QE
M(&YO;6)R92!D)^ELZ6UE;G1S(.`@<NEO<F1O;FYE<B!N92!C;W)R97-P;VYD
M('!A<R!A=2!N;VUB<F4@9"?I;.EM96YT<R!E;G)E9VES='+I<RX`3F4@<&5U
M="!D:7)I9V5R(&QE(&UE<W-A9V4@=F5R<R!L92!N;VUB<F4@<W#I8VEF:>DN
M`$-A<"U697)T`$SI9V5N9&4`5')A;G-P;W)T975R`%1E;FER(&-O;7!T92!D
M92!L82!C87-S90!#873I9V]R:65S(&5T(,ET:7%U971T97,`SFQE<R!#8>]M
M86X`0V,`5.ELZ7!H;VYE(&-E;&QU;&%I<F4`4')O<')IZ73I<R!D92!L82!C
M96QL=6QE`%)E;7!L:7-S86=E(&%U=&]U<B!D92!L82!C96QL=6QEH#H`4')O
M<')IZ73I<R!D92!L82!C96QL=6QE`$5S<&%C96UE;G0@9&4@;&$@8V5L;'5L
M9:`Z`%3I;.EP:&]N92!C96QL=6QA:7)E(`!#96QT92`H25-/+3@X-3DM,30I
M`$-E;G1R97(`4NEP=6)L:7%U92!C96YT<F%F<FEC86EN90!%=7)O<.EE;B!C
M96YT<F%L("A)4T\M.#@U.2TR*0!$Z71A:6QS(&1U(&-E<G1I9FEC870`4')O
M<')IZ71A:7)E(&1U(&-E<G1I9FEC870`4&]L:71I<75E(&1E(&-E<G1I9FEC
M871I;VX`5&-H860`36]D:69I97(`36]D:69I97(@=F]T<F4@;6]T(&1E('!A
M<W-E`$-H86YG97(@;&4@;F]M+"!L)V%D<F5S<V4@970@;&$@<VEG;F%T=7)E
M('%U92!L97,@<&5R<V]N;F5S('9O:65N="!Q=6%N9"!E;&QE<R!L:7-E;G0@
M970@<NEP;VYD96YT(.`@=F]S(&UE<W-A9V5S+@!#:&%N9V5M96YT<R!E;G)E
M9VES='+I<RX`3&$@;6]D:69I8V%T:6]N(&1E('9O=')E(&UO="!D92!P87-S
M92!N)V5S="!P87,@<W5P<&]R=.EE(&%V96,@;&$@8V]N9FEG=7)A=&EO;B!A
M8W1U96QL92X@0V]N=&%C=&5Z('9O=')E(&%D;6EN:7-T<F%T975R+@!#:&%R
M`%;I7W)I9FEE<B!L92!L:65N`$-H:6QI`$-H:6YE`$-H:6YO:7,@<VEM<&QI
M9FGI("A'0C(S,3(I`$-H:6YO:7,@=')A9&ET:6]N;F5L("A":6<U*0!#:&]I
M<VER(&PG87!P;&EC871I;VZ@.@!#:&]I<VER('5N(&UO="!D92!P87-S90!#
M:&]I<VER('5N(&YO;2!D92!C;VYN97AI;VX`0VAO:7-I<B!L92!M;V1E(&0G
M869F:6-H86=E(&1E<R!D871E<Z`Z`$-H;VES:7(@;&4@<W1Y;&4@9&4@;&ES
M=&4@*'!O=7(@;&5S(&QI<W1E<R!N=6WI<FEQ=65S*0#.;&5S($-H<FES=&UA
M<P!$Z69I;FET:6]N(&1E(&QA(&-L87-S92!D92`E<R!N;VX@=')O=7;I92X`
M169F86-E<@!.971T;WEE<B!L97,@8F%L:7-E<R!-4RU/9F9I8V4`169F86-E
M<B!L82!R97%UZG1E`%)E=&ER97(@;"=U=&EL:7-A=&5U<CH@)7,`169F86-E
M<B!L)W5T:6QI<V%T975R`$5F9F%C97(@;&5S(&1O;F[I97,@9&4@;"=U=&EL
M:7-A=&5U<@#)8VQA:7)C:65S('1A<F0@9&%N<R!L82!J;W5R;NEE`$-L:7%U
M97(@<&]U<B!P;W5R<W5I=G)E`$-L:6-K871E;&P@=FEA($A45%``1F5R;65R
M(&QA(&9E;NIT<F4`3G5A9V5S`$YU86=E<R!M871I;F%U>`!.=6%G975X`,YL
M97,@0V]C;W,`4F5P;&EE<B!L82!B87)R92!D92!C]'3I`%+I9'5I<F4@;&5S
M(&)O<F1S`$-O;&]M8FEE`$-O=6QE=7(`4&%L971T92!D92!C;W5L975R<P!3
MZ6QE8W1I;VX@9"=U;F4@8V]U;&5U<@!#;VQSH#H`5&ET<F5S(&1E(&-O;&]N
M;F4`0BY$+@!#;VUM86YD90!#;VUM86YD92!S:&5L;`!#;VUM96YT86ER90!.
M;VT@=7-U96P`0V]M;W)E<P!3;V-IZ73I`$]R9&EN871E=7)S`$-O;F1I=&EO
M;@!#;VYD:71I;VYS`$1I9F;I<F5N8V5S(&1E(&-O;F9I9W5R871I;VX`4WEN
M8VAR;VYI<V%T:6]N(&1E<R!A<W-I<W1A;G1S('!E<G-O;FYE;',L(#Q)/G-M
M87)T<&AO;F5S/"])/B!E="!/=71L;V]K+@!,82!C;VYF:6=U<F%T:6]N(&XG
M97-T('!A<R#@(&IO=7(N`$-O;F9I9W5R97(@)7,`0V]N9FER;65R(&QE(&UO
M="!D92!P87-S90!#;VYG;P!2Z7!U8FQI<75E(&3I;6]C<F%T:7%U92!D=2!#
M;VYG;P#)8VAE8R!D92!L82!C;VYN97AI;VX`R6-H96,@9&4@;&$@8V]N;F5X
M:6]NH#H@`$-O;FYE>&EO;B!A=2!S97)V975R(&1E(&-L969S('!U8FQI8R!R
M969U<^EE+@!#;VYN97AI;VX@874@<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@
M<F5F=7/I92X@4F%I<V]NH#H@("5S("@E<RD`R6-H96,@9&4@;&$@8V]N;F5X
M:6]N(&%U('-E<G9E=7(@1E10`$-O;G1A8W1S`$-E<R!C;VYT86-T<R!O;G0@
M8FEE;B#I=.D@86IO=73I<R#@('9O=')E(&-A<FYE="!D)V%D<F5S<V5S+@!#
M;VYT:65N=`!4>7!E(&1E(&-O;G1E;G4@9'4@9FEC:&EE<B!C;VUP<F5S<^F@
M.B``0V]N=&5N=2!D92"KH"5SH+L`4&]U<G-U:79R90#.;&5S($-O;VL`5.EM
M;VEN("AC;V]K:64I`$-O<&EE<@!#;W!I97(@)7,`R6-H96,@9&4@;&$@8V]P
M:66@.B`E<P!#;W!I92!D92`E<P!3Z6QE8W1I;VX@9"=U;F4@8V]P:64`260N
M(&-O^W0`0V]S=&$@4FEC80!#]'1E(&0G279O:7)E`$EM<&]S<VEB;&4@9&4@
M8VAI9F9R97(@;&4@;65S<V%G9:`Z(`!3:6=N871U<F4@4$=0(&1U(&UE<W-A
M9V4@:6UP;W-S:6)L9:`Z(`!);7!O<W-I8FQE(&1E(&-H:69F<F5R(&QE(&UE
M<W-A9V4@879E8R!3+TU)344N`%-I9VYA='5R92!3+TU)344@9'4@;65S<V%G
M92!I;7!O<W-I8FQE+@!!:F]U="!D=2!C;VYT86-T("5S(&EM<&]S<VEB;&4N
M(`!.92!P975T('-E(&-O;FYE8W1E<B!A=2!S97)V975R($Q$05`N`$YE('!E
M=70@<V4@8V]N;F5C=&5R(&%U('-E<G9E=7(@3$1!4`!6Z7)I9FEC871I;VX@
M9&4@;&$@8F%L86YC92`E<R!I;7!O<W-I8FQE+B``R6-H96,@9&4@;&$@8V]N
M;F5X:6]N(&%U('-E<G9E=7(@3$1!4`#)8VAE8R!D92!L82!C;VYN97AI;VX@
M874@<V5R=F5U<B"KH"5SH+L@=FEA($944*`Z("5S`$-RZ6%T:6]N(&1E(&QI
M<W1E(&1E(&1I<W1R:6)U=&EO;B!I;7!O<W-I8FQE+B`E<P!);7!O<W-I8FQE
M(&1E(&3I8VAI9F9R97(@;&5S(&1O;F[I97,@4$=0H#H@`$EM<&]S<VEB;&4@
M9&4@9.EC:&EF9G)E<B!L97,@9&]N;NEE<R!3+TU)344N`$YE('!E=70@<&%S
M('-U<'!R:6UE<B!L92!C;VYT86-T("5S`$YE('!E=70@<&%S('-U<'!R:6UE
M<B!L82!L:7-T92!D92!D:7-T<FEB=71I;VX@)7,`3F4@<&5U="!P87,@<W5P
M<')I;65R(&QE('-C<FEP="!D92!M:7-E(.`@:F]U<B"KH"5SH+LN`$3I=&5R
M;6EN871I;VX@9&4@;"=A9')E<W-E(&1U(&1E<W1I;F%T86ER92!I;7!O<W-I
M8FQE+@!.92!P975T('+I8W5PZ7)E<B!T;W5T(&QE(&-A<FYE="!D)V%D<F5S
M<V4N`$YE('!E=70@<NEC=7#I<F5R('1O=71E(&QA(&QI<W1E(&1E(&1I<W1R
M:6)U=&EO;BX`3B=A('!A<R!P=2!RZ6-U<.ER97(@;&$@;&ES=&4@8V]M<&SH
M=&4@9&4@;&ES=&5S(&1E(&1I<W1R:6)U=&EO;BX`26UP;W-S:6)L92!D92!C
M:&%R9V5R(&QA('-T<F%TZ6=I92"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@8W+I
M97(@;&4@<NEP97)T;VER92"KH"5SH+LN`$EM<&]S<VEB;&4@9"=O8G1E;FER
M(&QA(&-L968@<'5B;&EQ=64@X"!P87)T:7(@9'4@<V5R=F5U<B!D92!C;&5F
M<RX`3W5V97)T=7)E(&1E(*N@)7.@NR!I;7!O<W-I8FQE(&5N(.EC<FET=7)E
M+@!/=79E<G1U<F4@9&4@)7,@:6UP;W-S:6)L92X`26UP;W-S:6)L92!D)V]U
M=G)I<B!L92!M;V1U;&4@36%I;G1E;F%N8V5?5&%S:R`E<P!/=79E<G1U<F4@
M9'4@9&]S<VEE<B"KH"5SH+L@:6UP;W-S:6)L92X`26UP;W-S:6)L92!D)V%T
M=&5I;F1R92!L92!S97)V975R($Q$05`N`$QE8W1U<F4@9&4@)7,@:6UP;W-S
M:6)L92X@`$XG82!P=2!R96UE='1R92#@('KI<F\@;&4@;6]T(&1E('!A<W-E
M('!O=7(@;"=U=&EL:7-A=&5U<B!D96UA;F3I+B!#97)T86EN<R`H;W4@=&]U
M<RD@;&5S(&3I=&%I;',@;F4@<V]N="!P87,@8V]R<F5C=',N(%+I97-S87EE
M>B!O=2!C;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E=7(@<&]U<B!D92!L
M)V%I9&4N`%+I8W5PZ7)A=&EO;B!D97,@04-,(&EM<&]S<VEB;&4`3F4@<&5U
M="!RZ6-U<.ER97(@;&4@8V%R;F5T(&0G861R97-S97,N("5S`$YE('!E=70@
M<NEC=7#I<F5R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@)7,`3F4@<&5U
M="!RZ6-U<.ER97(@;&5S(&QI<W1E<R!D92!D:7-T<FEB=71I;VXN("5S`$YE
M('!E=70@<NEC=7#I<F5R(&QE<R!P;W-S:6)I;&ETZ7,@9'4@<V5R=F5U<@!.
M92!P975T('!A<R!R979E;FER(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E
M;G1E+@!%9F9A8V5M96YT(&1U(&1O<W-I97(@JZ`E<Z"[(&EM<&]S<VEB;&4N
M(`!.92!P975T('!A<R!E;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N("5S
M`$YE('!E=70@<&%S(&5N<F5G:7-T<F5R('5N92!S875V96=A<F1E(&1E(&QA
M(&-O;F9I9W5R871I;VXN`$EM<&]S<VEB;&4@9"=E;G)E9VES=')E<B!U;F4@
M8V]P:64@9&4@;&$@8V]N9FEG=7)A=&EO;J`Z("5S`$EM<&]S<VEB;&4@9"=E
M;G)E9VES=')E<B!L92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@9&%N<Z`Z(*N@
M)7.@NRX`26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R('5N92!C;W!I92!D=2!F
M:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N`$EM<&]S<VEB;&4@9"=E;G)E
M9VES=')E<B!L92!F:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N(%9O=7,@
M<&]U=F5Z('-O:70@=71I;&ES97(@=6YE(&1E<R!O<'1I;VYS('!O=7(@<V%U
M=F5R(&QE(&-O9&4@<W5R("5S('-O:70@8V]P:65R(&UA;G5E;&QE;65N="!L
M92!C;V1E(&-I+61E<W-O=7,@9&%N<R`E<RX`3F4@<&5U="!P87,@<F5C:&5R
M8VAE<B!L92!S97)V975R($Q$05`N`%-U<'!R97-S:6]N(&1E(*N@)7.@NR!I
M;7!O<W-I8FQE+@!-:7-E(.`@:F]U<B!D=2!C;VYT86-T(&EM<&]S<VEB;&4N
M("5S`$YE('!E=70@;65T=')E(.`@:F]U<B!L82!L:7-T92!D92!D:7-T<FEB
M=71I;VXN("5S`$YE('!E=70@<&%S(&5N<F5G:7-T<F5R(&QA(&-O;F9I9W5R
M871I;VX@<&]U<B"KH"5SH+N@.B`E<P!.92!P975T('1R;W5V97(@;&$@8F%R
M<F4@9&4@36]Z:6QL82X@($%S<W5R97HM=F]U<R!Q=2=E;&QE(&5S="!A8W1I
M=F4N`$YE('!E=70@871T<FEB=65R(&-E<R!D<F]I=',@X"!L)W5T:6QI<V%T
M975R(*N@)7.@NR`@<W5R(&QE(&1O<W-I97(@JZ`E<Z"[H#H@)7,`5&5X=&4@
M8V]M<'3I`%!A>7,`0V]U<G,`0W+I97(`0W+I97(@=6X@;&EE;@!#<NEE<B!U
M;B!N;W5V96%U`$-RZ65R('5N(&YO=79E874@9&]S<VEE<@!#<NEE<B!U;B!S
M;W5S+61O<W-I97(`4&5R;6ES<VEO;G,@1&4@0W+I871E=7(`3G5MZ7)O(&1E
M(&-A<G1E(&1E(&-RZ61I=`!#<F]A=&EE`$-U8F$`-"!P:&%S97,@8V]U<F%N
M=&5S`%-E<W-I;VYS(&5N(&-O=7)S`$AE=7)E(&%C='5E;&QE`$PG861R97-S
M92!54DP@86-T=65L;&4@97-T`%5T:6QI<V%T975R<R!A8W1U96QS`$]B<V5R
M=F%T:6]N<R!A8W1U96QL97,`0V]N9&ET:6]N(&%C='5E;&QEH#H@`%-T>6QE
M(&-O=7)A;G0`1.EF:6YI<B!L97,@=.)C:&5S(.`@969F96-T=65R(&QO<G,@
M9&4@;&$@8V]N;F5X:6]N(.`@)7,N`$-O=7!E<@!#;W5P97(@;&$@<^EL96-T
M:6]N`$-H>7!R90!#>7)I;&QI<75E("A+3TDX+5(I`$-Y<FEL;&EQ=64@*%=I
M;F1O=W,M,3(U,2D`0WER:6QL:7%U92]5:W)A:6YI96X@*$M/23@M52D`4NEP
M=6)L:7%U92!48VCH<75E`$I*`$3)4T%#5$E6R0!$R5-!0U1)5LDZ`$133B`H
M0V8N(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`0VAA<75E(&IO=7(`3F%V:6=A=&5U
M<B!D92!$871A5')E90!!;&EA<R!D92!L82!B87-E`$1A=&4`1&%T92!D92!R
MZ6-E<'1I;VX`4^EL96-T:6]N(&0G=6YE(&1A=&4`2F]U<@!3=7!P<FEM97(@
M7VQA(&-O;&]N;F4`1.ES86-T:79E<B!C92!S8W)I<'0`1.EC96UB<F4`3F]M
M8G)E<R!DZ6-I;6%U>`!$:6UI;G5E<B!L)VEN9&5N=&%T:6]N`$3I9F%U=`!#
M;W5L975R('!A<B!DZ69A=70`261E;G1I=.D@<&%R(&3I9F%U=`!);G1E<G!R
MZ71E=7(@9&4@8V]M;6%N9&4@<&%R(&3I9F%U=`!$Z69I;FET:6]N<P!%9F9A
M8V5R`$5F9F%C97(@)7,`169F86-E<B!L82!C96QL=6QE`$5F9F%C92!L82!C
M;VYD:71I;VX`4W5P<')I;65R('5N(&=R;W5P90!%9F9A8V5R(&QA('1R86-E
M`%-U<'!R:6UE<B!U;F4@<&5R;6ES<VEO;@!3=7!P<FEM97(@970@<'5R9V5R
M(&QE<R!M97-S86=E<P!%9F9A8V5R(&QA(&-E;&QU;&4`169F86-E<B!L82!C
M;VQO;FYE`%-U<'!R:6UE<B!U;B!A=71R92!M;V3H;&4@97AI<W1A;G0`4W5P
M<')I;65R(&QE(&UE<W-A9V4@8V]M<&SH=&5M96YT`%-U<'!R:6UE<B!L97,@
M<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`RG1E<RUV;W5S(&-E<G1A:6X@9&4@
M=F]U;&]I<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U<RUP97)M:7-S:6]N
M<Z`_`$5F9F%C97(@;&$@<F%N9^EE`%-U<'!R:6UE<B!L)VED96YT:73I('/I
M;&5C=&EO;F[I90!%9F9A8V5R(&QA(&-O;&]N;F4@86-T=65L;&4`169F86-E
M<B!L82!R86YGZ64@86-T=65L;&4`169F86/I`%-C<FEP="!D92!C;VYF:6=U
M<F%T:6]N(&1E(&UI<V4@X"!J;W5R('-U<'!R:6WI(*N@)7.@NRX`1.EP;W-E
M<B!C92!M97-S86=E(&1A;G,@;6$@8F]I=&4@9&4@<NEC97!T:6]N`$3I<&]S
M97(@9&%N<R!M82!";VET92!D92!RZ6-E<'1I;VX@970@8V]P:65R(&1A;G,`
M1.EP;W-E<B!D86YS(&UA($)O:71E(&1E('+I8V5P=&EO;B!E="!R961I<FEG
M97(@=F5R<P!0;&%C97(@9&%N<R!L92!D;W-S:65R`$AE=7)E(&1E(&QI=G)A
M:7-O;@!$86YE;6%R:P!$Z6-R:7)E(&QE('!R;V)LZ&UE`$1E<V-R:7!T:6]N
M`$3I=&%I;',@*&%U<W-I(&1A;G,@;&4@9FEC:&EE<B!D92!T<F%C97,@9&4@
M2&]R9&4IH#H`3&5S(&3I=&%I;',@;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L
M)V%D;6EN:7-T<F%T975R+@!$Z79E;&]P<&5M96YT`%!O:6YT(&1E(')O<^EE
M`%!O:6YT(&1E(')O<^EE('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``4&]I
M;G0@9&4@<F]SZ66@.B``1&4@9V%U8VAE(.`@9')O:71E`$1E(&1R;VET92#@
M(&=A=6-H90!2Z7!E<G1O:7)E`$3I<V%C=&EV97(@)7,@`$3I<V%C=&EVZ0!!
M9F9I8VAE<B!S=7(@,C0@:&5U<F5SH#\`3W!T:6]N<R!D)V%F9FEC:&%G90!!
M9F9I8VAE<B!L82!P<NEV:7-I;VX@9.ET86EL;.EE`$%F9FEC:&5R(&QE(&UE
M<W-A9V4@87!RZ',@;"=A<'!L:6-A=&EO;B!D97,@9FEL=')E<Z`_(`!!9F9I
M8VAE<B!L82!P<NEV:7-I;VX@*%1!1BD`1F]R;6%T(&0G869F:6-H86=E`$%V
M:7,@9&4@;&EV<F%I<V]N`$1J:6)O=71I`$YE('!A<R!E;G9O>65R(&1E('+I
M<&]N<V5S(&%U>"!M97-S86=E<R!P<F]V96YA;G0@9&4@;&ES=&5S(&]U(&0G
M96YV;VES(&UA<W-I9G,`3F4@<&%S('-U<'!R:6UE<@!.92!P87,@86-CZ61E
M<B!D:7)E8W1E;65N="#@(&UA:6YT96YA;F-E+G!H<`!&86ER92!C96-I.B``
M3&4@<')E;6EE<B!E;G)E9VES=')E;65N="!C;VYT:65N="UI;"!L92!N;VT@
M9&5S(&-H86UP<Z`_($1A;G,@;"=A9F9I<FUA=&EV92P@8V]C:&5Z(&-E='1E
M(&)O[G1EH#H`3F4@8V]M;65N8V4@<&%S('!A<B``3F4@8V]N=&EE;G0@<&%S
M(`!.92!F:6YI="!P87,@<&%R(`!.)V5X:7-T92!P87,@`$YE(&-O<G)E<W!O
M;F0@<&%S`$1O;6EN:7%U90!2Z7!U8FQI<75E(&1O;6EN:6-A:6YE`%9O=7,@
M;B=A=F5Z('!A<R!D92!C;VUP=&6@/R!%;G)E9VES=')E>BUV;W5S+@!4Z6SI
M8VAA<F=E<@!4Z6SI8VAA<F=E<B`E<P!4Z6SI8VAA<F=E<B!L82!C;VYF:6=U
M<F%T:6]N(&?I;NERZ64@8V]M;64@=6X@<V-R:7!T(%!(4`!,:7-T92!DZ7)O
M=6QA;G1E`$1R;V=U97,`0V]U<G)I97(@Z6QE8W1R;VYI<75E`%!I;&]T92!D
M92!P87-S97)E;&QE(&-O=7)R:65R("\@4TU3+"!P;W5R(&QE<R!F;W5R;FES
M<V5U<G,@9&4@8V4@<V5R=FEC92X`15)2`,EQ=6%T975R`$UO9&EF:65R`$5D
M:71E<B`E<P#)9&ET97(@;&4@8FQO8P#)9&ET97(@=6X@9W)O=7!E`,ED:71E
M<B!U;F4@<&5R;6ES<VEO;@#)9&ET97(@;&5S('!E<FUI<W-I;VYS`,ED:71E
M<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`R61I=&5R(&QE<R!O<'1I
M;VYS('!O=7*@.@#)9&ET97(@;&5S('!E<FUI<W-I;VYS('!O=7(@JZ`E<Z"[
M`,ED:71E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B`E<P#)9'5C871I;VX`R6=Y
M<'1E`%-A;'9A9&]R`,ELZ6UE;G0N+BX`16T`061R97-S92#I;&5C=')O;FEQ
M=64`061R97-S92#I;&5C=')O;FEQ=64`3&5S(&%D<F5S<V5S(.EL96-T<F]N
M:7%U97,@9&]I=F5N="!C;W)R97-P;VYD<F4N`$-O=7)R:65R(&%V96,@8V]N
M9FER;6%T:6]N`%!A<W-E<F5L;&4@8V]U<G)I97(@+R!335,`R6UO=&EC]&YE
M<P!-97-S86=E('9I9&4N`%+I<W5L=&%T('9I9&4N`%1E<FUE<R!D92!R96-H
M97)C:&4@=FED90!!8W1I=F5R("5S`$%C=&EV97(@;"=I;G-E<G1I;VX@9"=I
M;6%G97,@=F5N86YT(&1E<R!A;&)U;7,@<&AO=&]S(&1A;G,@;&4@=&5X=&6@
M/P!!8W1I=F5R(&QE(&UE;G4@8V]N=&5X='5E;"!A=F5C('5N(&-L:6,@9')O
M:72@/P!!8W1I=ND`1FEN(&1E(&PG86YNZ64`($9I;FET('!A<@!!9W)A;F1I
M<B!L)^ED:71E=7(`R6-R:79E>B!U;F4@<75E<W1I;VX@9&4@<^EC=7)I=.D@
M<74G;VX@=F]U<R!P;W-E<F$@<VD@=F]U<R!D979E>B!R96UE='1R92#@('KI
M<F\@=F]T<F4@;6]T(&1E('!A<W-E+"!P87(@97AE;7!L92"K(%%U96P@97-T
M(&QE(&YO;2!D92!V;W1R92!A;FEM86P@<'+I9NERZ:`_H+N@.@!);G-C<FEV
M97H@;"=A9')E<W-E(%523"!D92!L)VEM86=E(&EC:0!%;G1R97H@;&5S(&QE
M='1R97,@8VDM9&5S<V]U<Z`Z`,EG86P@X`!'=6ENZ64@Z7%U871O<FEA;&4`
MR7)Y=&ARZ64`17)R975R`$5R<F5U<B!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1U
M(&)L;V.@.B`E<P!%<G)E=7(@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D92!L
M)V%N8W)E(&1E('-Y;F-H<F]N:7-A=&EO;J`Z("5S`$5R<F5U<B!L;W)S(&1E
M(&QA('-U<'!R97-S:6]N(&1U(&IO=7)N86P@9&4@<WEN8VAR;VYI<V%T:6]N
MH#H@)7,`17)R975R(&QO<G,@9&4@;&$@<NEC=7#I<F%T:6]N(&1U(&-O;G1E
M;G6@.B`E<P!%<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D=2!M;W0@
M9&4@<&%S<V6@.B`E<P!%<G)E=7(@879E8R!L92!M97-S86=E+@!%<G)E=7(@
M;&]R<R!D92!L)V5N<F5G:7-T<F5M96YT(&1E(*N@)7.@NRX`17-T;VYI90#)
M=&AI;W!I90!%=&AN:7%U90!%=7)O<&4`5&]U<R!L97,@)F9R86,Q-#L@9"=H
M975R90!4;W5T97,@;&5S(#(@;6EN=71E<P!4;W5T97,@;&5S(#,P('-E8V]N
M9&5S`%1O=71E<R!L97,@-2!M:6YU=&5S`,`@8VAA<75E(&-O;FYE>&EO;@!4
M;W5T97,@;&5S("9F<F%C,3([(&AE=7)E<P!4;W5T97,@;&5S(&UI;G5T97,`
M17AE;7!L92!D92!V86QE=7)SH#H`17CI8W5T97(`4NAG;&5S(&5X:7-T86YT
M97,`17AI<W1E`$3I=F5L;W!P97(`1.EP;&EE<B!L82!B87)R92!D92!C]'3I
M`*L@*2"[(&%T=&5N9'5E`%5N('-E=6P@;6]T(&]U(&5X<')E<W-I;VX@96YT
M<F4@9W5I;&QE;65T<R!A='1E;F1U<P!$871E(&0G97AP:7)A=&EO;@!297!R
MZ7-E;G1A;G0`0V]U;&5U<B!D)V%V86YT+7!L86X`5.ELZ6-H87)G96UE;G0@
M=F5R<R!L92!S97)V975R(&1E(&QA(&-O;F9I9W5R871I;VX@<&%R($944`!,
M96-T=7)E(&1E<R!P<NEFZ7)E;F-E<R!I;7!O<W-I8FQE+@#)8VAE8R!D92!L
M82!C;VYN97AI;VX@874@<V5R=F5U<B!,1$%0+@#)8VAE8R!D92!L82!C;VYN
M97AI;VX@874@<V5R=F5U<B!334(N`,EC:&5C(&1E(&QA(&-O<&EE(&1E<'5I
M<R"KH"5SH+LN`,EC:&5C(&1E(&QA(&-O<&EE('9E<G,@(*N@)7.@NRX`26UP
M;W-S:6)L92!D92!C<NEE<B!U;F4@;F]U=F5L;&4@8V]N;F5X:6]N(%-!4TP`
MR6-H96,@9'4@9.EP;&%C96UE;G0@=F5R<R"KH"5SH+LN`,EC:&5C(&QO<G,@
M9&4@;&$@<NEC=7#I<F%T:6]NH#H@)7,`0F5A=0#.;&5S($9A;&ML86YD("A-
M86QO=6EN97,I`,YL97,@1NER;^D`17)R975R(&9A=&%L9:`Z`$9A>`!4Z6SI
M8V]P:65S`$;I=G)I97(`5&5M<.ER871U<F4@<F5S<V5N=&EE`%1E;7#I<F%T
M=7)E(')E<W-E;G1I9:`Z(`!1=65L<75E<R!A=F5R<V5S`%%U96QQ=65S(&-H
M=71E<R!D92!N96EG90!-871R:6-E(&1E<R!C:&%M<',`1FEG;&5T($-!4%1#
M2$$`4&]L:6-E(&1E(&QA(#Q)/F9I9VQE=#PO23X`1FED:FD`1FEC:&EE<@!.
M;VUB<F4@9&4@9FEC:&EE<G.@.B`E<P!.;VUB<F4@9&4@9FEC:&EE<G.@.B`E
M<P!'97-T:6]N;F%I<F4@9&4@9FEC:&EE<G,`3F]M(&1U(&9I8VAI97(`0VAO
M:7@@9&4@9FEC:&EE<@!4Z6SI8VAA<F=E;65N="!D92!F:6-H:65R`$PG96YV
M;VD@9&4@9FEC:&EE<G,@;B=E<W0@<&%S('!R:7,@96X@8V]M<'1E+@!&:6QT
M<F5R(&-H87%U92!M97-S86=E`$9I;'1R97(@<V5U;&5M96YT(&QE<R!M97-S
M86=E('9U<P!&:6QT<F5R('-E=6QE;65N="!L97,@;65S<V%G97,@;F]N('9U
M<P!/<'1I;VYS(&1E(&9I;'1R86=E`%+H9VQE(&1E(&9I;'1R86=E`%+H9VQE
M<R!D92!F:6QT<F%G90!!9F9I8VAA9V4@9'4@<V-R:7!T(&1E(&9I;'1R90!?
M4NAG;&5S(&1E(&9I;'1R86=E`$%C=&EV:73I(&1U(&9I;'1R9:`Z("5S(&UE
M<W-A9V4H<RD@;VYT(.ETZ2!DZ7!L86/I<R!V97)S(&QE(&1O<W-I97(@JZ`E
M<Z"[+@!!8W1I=FETZ2!D=2!F:6QT<F6@.B`E<R!M97-S86=E*',I(&]N="#I
M=.D@969F86/I<RX`06-T:79I=.D@9'4@9FEL=')EH#H@)7,@;65S<V%G92AS
M*2!O;G0@Z73I(&3I<&QA8^ES('9E<G,@;&4@9&]S<VEE<B"KH"5SH+LN`$%C
M=&EV:73I(&1U(&9I;'1R9:`Z("5S(&UE<W-A9V4H<RD@8V]R<F5S<&]N9&%N
M="#@(&QA(&QI<W1E(&YO:7)E(&]N="#I=.D@969F86/I<RX`06-T:79I=.D@
M9'4@9FEL=')EH#H@;&4@;65S<V%G92"KH"5SH+L@9&4@JZ`E<Z"[(&$@Z73I
M(&-O<&GI('9E<G,@;&4@9&]S<VEE<B"KH"5SH+LN(`!!8W1I=FETZ2!D=2!F
M:6QT<F6@.B!L92!M97-S86=E(*N@)7.@NR!D92"KH"5SH+L@82#I=.D@969F
M86/I+B``06-T:79I=.D@9'4@9FEL=')EH#H@;&4@;65S<V%G92"KH"5SH+L@
M9&4@JZ`E<Z"[(&$@Z73I(&3I<&QA8^D@=F5R<R!L92!D;W-S:65R(*N@)7.@
MNRX@`$9I;'1R92!N;VX@=')O=7;I`$9I;'1R97,`1FEN;&%N9&4`4')E;6GH
M<F4@9&5M:64`4')E;6EE<B!Q=6%R=&EE<@!&:7AE<B!L92!R871I;P!2971O
M=7)N97(`1FQO='1A;G0`0G)O=6EL;&%R9`!$;W-S:65R("5S(&EN97AI<W1A
M;G0N`$-O=6QE=7(@9&4@<&]L:6-E`$YO=7)R:71U<F4`4&]U<B!L97,@;65S
M<V%G97,@96YT<F%N=',@<75I(&-O<G)E<W!O;F1E;G0Z`%!O=7(@;&5S(&YA
M=FEG871E=7)S(&YE('-U<'!O<G1A;G0@<&%S(&QE<R!I;6%G97,`4'+I=FES
M:6]N("A4048I`$IO=7)S(&1E('!RZ79I<VEO;B`H;F]T97H@<75E(&QE<R!P
M<NEV:7-I;VYS(&9O=7)N:65S(&1O;FYE;G0@;&4@:F]U<B!E="!L82!N=6ET
MH#L@=6X@9W)A;F0@;F]M8G)E(&EC:2!P975T(&9A:7)E('5N(&)L;V,@='+H
M<R!L87)G90!6;W5S(&%V97H@;W5B;&GI('9O=')E(&UO="!D92!P87-S9:`_
M`$9O<FUU;&%I<F5S`$-I=&%T:6]N`%1Y<&4@9&4@8VET871I;VX`0VET871I
M;VYS`$-I=&%T:6]N<R`R`$9O<G5M<P!4<F%N<V9E<G0`3&$@<F5D:7)E8W1I
M;VX@;B=E<W0@<&%S('-U<'!O<G3I92!D86YS(&QE('!RZ7-E;G0@9FEL=')E
M+@!4<F%N<VUE='1R90#)9&ET97(@;&$@<F5D:7)E8W1I;VX`5F4`0V%D<F5S
M`$9R86YC90!&<F%N8V4@;>ET<F]P;VQI=&%I;F4`1W5Y86YE(&9R86[G86ES
M90!0;VQY;NES:64@9G)A;N=A:7-E`%1E<G)E<R!A=7-T<F%L97,@970@86YT
M87)C=&EQ=65S(&9R86[G86ES97,`1&4`1'4@`$1E<V-R:7!T:6]N(&-O;7!L
MZ'1E`%!L96EN92!L=6YE`$YO;2!C;VUP;&5T`$=A8F]N`$%L8G5M(&0G;W)I
M9VEN92!D92!L)VEM86=E`$%L8G5MH#H`1V%M8FEE`$?I;NER97(@;&$@8V]N
M9FEG=7)A=&EO;B!D92`E<P!#;V1E(&?I;NERZ0!'Z6]R9VEE`$%L;&5M86=N
M90!':&%N80!':6)R86QT87(`4'+I;F]M`$%L;&5R`$=O961E;`!#87)T97,@
M1V]O9VQE`%)E8VAE<F-H92!';V]G;&4`3FEV96%U(&1E(&=R:7,`4&QU<R!G
M<F%N9"!Q=64@`%!L=7,@9W)A;F0@;W4@Z6=A;&4@X`!'<NAC90!'<F5C("A)
M4T\M.#@U.2TW*0!'<F_K;FQA;F0`1W)E;F%D90!!9&UI;FES=')A=&EO;B!D
M97,@9W)O=7!E<P!,97,@;F]M<R!D92!G<F]U<&4@;F4@<&5U=F5N="!P87,@
MZG1R92!V:61E<P!'<F]U<%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@
M;&4@9W)O=7!E("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U('-E<G9E=7*@
M.@!'<F]U<%]L9&%PH#H@<W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!G<F]U
M<&4@)7,`1W)O=7!?;&1A<*`Z(&UO9&EF:6-A=&EO;B!I;7!O<W-I8FQE(&1U
M(&=R;W5P92`E<P!'<F]U<&5S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`
M1W5E<FYE<V5Y`%!E<FUI<W-I;VYS(&1E<R!I;G9I=.ES`$QI=G)E(&0G;W(`
M1W5I;NEE`$=U:6[I92U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@<F5F
M=7-E(&+J=&5M96YT(&1E('-U<'!R:6UE<B!L82!D97)N:>AR92!C96QL=6QE
M(&1E(&QA(')A;F?I90!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P
M<')I;65R(&QA(&1E<FYIZ')E(&-O;&]N;F4@9'4@=&%B;&5A=0!(5$U,07)E
M82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I;65R(&QA(&1E<FYIZ')E(')A
M;F?I92!D=2!T86)L96%U`$%U=&AE;G1I9FEC871I;VX@2%144"!N;VX@=')O
M=7;I92X`2&'O=&D`06QG;W)I=&AM92!D92!H86-H86=E`$)R=6UE('/H8VAE
M`$5N+73J=&4`16XM=.IT97,`SFQE<R!(96%R9"!E="!-8T1O;F%L9`!/<F%G
M97,@=FEO;&5N=',`2.EB<F5U("A)4T\M.#@U.2TX+4DI`$AA=71E=7(`06ED
M90!!:61E('!O=7(@;"?I9&ET975R`$%I9&4`2.EM:7-P:.AR90!6;VEC:2!L
M92!DZ6)U="!D=2!F:6-H:65RH#H`2&%U=&4`05]C8W5E:6P`0VETZ2!D=2!6
M871I8V%N`$%C8W5E:6P`061R97-S92!P97)S;VYN96QL90!2Z7!E<G1O:7)E
M('!E<G-O;FYE;`!4Z6SI<&AO;F4@<&5R<V]N;F5L`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92]+;VQA8J`Z(&1O;F[I97,@6$U,("5S(&EN=F%L
M:61E<R!R971R;W5VZ65S(&1A;G,@;&4@;65S<V%G92`E<P!(;W)D92]+;VQA
M8J`Z(&%U8W5N(&UE<W-A9V4@;F4@8V]R<F5S<&]N9"!A=2!S=6IE="`E<P!(
M;W)D92]+;VQA8J`Z('!A<R!D)V]B:F5T(&1E('1Y<&4@)7,@=')O=7;I(&1A
M;G,@;&4@;65S<V%G92`E<P!(;W)D92]+;VQA8J`Z("5S('-U<'!R:6WI(*N@
M)7.@NR!A=F5C('-U8V/H<P!(;W)D92]+;VQA8J`Z(&QE(&UO=&5U<B!D)VEN
M=.EG<F%T:6]N(&[I8V5S<VET92!L)V5X=&5N<VEO;B`G9&]M>&UL)R!D92!0
M2%``2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E(&-RZ65R('5N(&YO=79E
M;"!A<F)R92!834P@<&]U<B!L)V]B:F5T("5S`$AO<F1E+TMO;&%BH#H@:6UP
M;W-S:6)L92!D)V5N;&5V97(@)7,@JZ`E<Z"[H#H@)7,`2&]R9&4O2V]L86*@
M.B!I;7!O<W-I8FQE(&1E('+I8W5PZ7)E<B!L)VED96YT:69I86YT($U)344@
M<&]U<B!L82!P87)T:64@9&4@='EP92`E<P!(;W)D92]+;VQA8J`Z(&EM<&]S
M<VEB;&4@9&4@<WEN8VAR;VYI<V5R("5S(*N@)7.@NZ`Z("5S`$AO<F1E+TMO
M;&%BH#H@:6UP;W-S:6)L92!D92!S>6YC:')O;FES97(@;&5S('!A<G1A9V5S
MH#H@)7,`2&]R9&4O2V]L86*@.B!P87)T86=E(&EN8V]N;G4@JZ`E<Z"[`$QI
M9VYE(&AO<FEZ;VYT86QE`%)E;7!L:7-S86=E(&AO<FEZ;VYT86P`2&]R:7IO
M;G1A;*`Z`$-O;6UE;G0@ZG1E<RUV;W5S(&%R<FEVZ2!I8VF@/R`H4U90(')A
M<'!O<G1E>BUL9:`A*0!#;VUB:65N(&1E(&-O;&]N;F5S('9O=6QE>BUV;W5S
M(&9U<VEO;FYE<J`_`$-O;6)I96X@9&4@8VAA;7!S("AC;VQO;FYE<RD@>2!A
M+70M:6R@/P!#;VUB:65N(&1E(')A;F?I97,@=F]U;&5Z+79O=7,@9G5S:6]N
M;F5RH#\`2'5M:61I=.D`2'5M:61I=.F@.B``2'5M;W)I<W1E<P!(;VYG<FEE
M`,EC:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@;&$@8F_N=&4@24U!4*`Z
M("5S`,EC:&5C(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;&$@8F_N=&4@
M24U!4*`Z("5S`,EC:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@<75O=&$@
M<W5R(&QA(&)O[G1E($E-05"@.B`E<P!!9')E<W-E($E0`$%D<F5S<V4@25`@
M;F]N(&1I<W!O;FEB;&4N`$%D<F5S<V4@25`@:&]R<R!D=2!B;&]C($-)1%(@
M86QL;W7I+@!6:6]L871I;VX@9&4@8FQO8V%G92!)4"X`25]N<^ER97(@<F%N
M9^EE(&%V86YT`$ES;&%N9&4`26/T;F5S('-E=6QE;65N=`!)8_1N97,@<&]U
M<B`E<P!)8_1N97,@<&QU<R!T97AT90!.;VT@9'4@8V]M<'1EH#H`4VD@;"=A
M9F9I8VAA9V4@;B=E<W0@<&%S(&-O<G)E8W0L("5S('!O=7(@;"=O=79R:7(@
M9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R92X`4VD@=F]U<R!N92!V;WEE>B!A
M=6-U;B!I8_1N92!E;B!U=&EL:7-A;G0@26YT97)N970@17AP;&]R97(L('9O
M=7,@<&]U=F5Z(&%V;VER(.`@8V]C:&5R(&-E='1E(&-A<V4@<&]U<B!DZ7-A
M8W1I=F5R(&QA('1R86YS<&%R96YC92!D97,@4$Y'+@!3:2!V;W5S('9O>65Z
M(&-E(&UE<W-A9V4@;6%I<R!A=6-U;F4@:6UA9V4L(&PG:6UA9V4@<75E('9O
M=7,@=F]U;&5Z(&5N=F]Y97(@;F4@<&5U="#J=')E(&%F9FEC:.EE('!A<B!V
M;W1R92!N879I9V%T975R+@!!<&5RYW4@9&4@;"=I;6%G9:`Z`$%D<F5S<V4@
M55),(&1E(&PG:6UA9V4`061R97-S92!54DP@9&4@;"=I;6%G9:`Z`$EM86=E
M(&1E(&PG86QB=6T`26UA9V4@9&4@;"=A;&)U;:`Z`%3I;.EC:&%R9V5M96YT
M(&0G:6UA9V5S`$EM86=E<P!);7!O<G1A=&EO;BP@Z71A<&4@)60`26UP;W)T
M86YT`$-H86UP(&EM<&]R=.F@.B`E<P!#:&%M<',@:6UP;W)TZ7.@.@!);E]S
MZ7)E<B!R86YGZ64@87!RZ',`0V]D92!D)V%C=&EO;B!I;F-O<G)E8W0N`$YO
M;2!D)W5T:6QI<V%T975R(&5T+V]U('9O=')E(&UO="!D92!P87-S92!I;F-O
M<G)E8W0N`$YO;2!D)W5T:6QI<V%T975R(&]U(&%D<F5S<V4@86QT97)N871I
M=F4@:6YC;W)R96-T+B`@4NEE<W-A>65Z(&]U(&-O;G1A8W1E>B!V;W1R92!A
M9&UI;FES=')A=&5U<B!S>7-TZ&UE('!O=7(@9&4@;"=A:61E+@!!=6=M96YT
M97(@;"=I;F1E;G1A=&EO;@!);F1E`%5T:6QI<V%T975R<R!I;F1I=FED=65L
M<P!,97,@<NAG;&5S(&EN9&EV:61U96QL97,@;F4@<V]N="!P87,@<W5P<&]R
M=.EE<RX`26YD;V[I<VEE`$QA(&)O[G1E('-PZ6-I9FGI92!E<W0@:6YE>&ES
M=&%N=&4`26YF;P!);F9O<FUA=&EO;G,`3"=I;F9O<FUA=&EO;B!N)V5S="!P
M;'5S(&1I<W!O;FEB;&4N`$EN<^ER97(@8U]O;&]N;F4@87!RZ',`26YSZ7)E
M<B!I;6%G90!);G/I<F5R('5N('1A8FQE874`26YSZ7)E<B!U;B!L:65N('=E
M8@!);G/I<F5R(%]C;VQO;FYE(&%V86YT`$EN<^ER97(@=6YE(&YO=79E;&QE
M(&-O;&]N;F4@87!RZ',@;&$@8V]L;VYN92!A8W1U96QL90!);G/I<F5R('5N
M92!N;W5V96QL92!C;VQO;FYE(&%V86YT(&QA(&-O;&]N;F4@86-T=65L;&4`
M26YSZ7)E<B!U;F4@;F]U=F5L;&4@<F%N9^EE(&%P<NAS(&QA(')A;F?I92!A
M8W1U96QL90!);G/I<F5R('5N92!N;W5V96QL92!R86YGZ64@879A;G0@;&$@
M<F%N9^EE(&%C='5E;&QE`$EN<^ER97(@=6X@<&%R86=R87!H92!A<'+H<R!L
M92!N)F]E;&EG.W5D(&%C='5E;`!);G/I<F5R('5N('!A<F%G<F%P:&4@879A
M;G0@;&4@;B9O96QI9SMU9"!A8W1U96P`26YSZ7)E<B!U;B!A=71R92!M;V3H
M;&4`26YS8W)I=F5Z('5N92!A9')E<W-E(&1E(&-O=7)R:65R(.`@;&%Q=65L
M;&4@=F]U<R!R96-E=G)E>B!L92!N;W5V96%U(&UO="!D92!P87-S9:`Z`$EN
M<^ER97(@8V5L;'5L92!A<'+H<P!);G/I<F5R(&-E;&QU;&4@879A;G0`26YS
MZ7)E<B!C;VQO;FYE(&%P<NAS`$EN<^ER97(@8V]L;VYN92!A=F%N=`!);G/I
M<F5R(&QE<R!M97-S86=E<P!);G/I<F5R('!A<F%G<F%P:&4@87!RZ',`26YS
MZ7)E<B!P87)A9W)A<&AE(&%V86YT`$EN<^ER97(@<F%N9^EE(&%P<NAS`$EN
M<^ER97(@<F%N9^EE(&%V86YT`$EN<V-R:79E>B!L82!RZ7!O;G-E(.`@;&$@
M<75E<W1I;VX@9&4@<^EC=7)I=.F@.@!);G/I<F5R+TUO9&EF:65R('5N92!I
M;6%G90!);G/I<F5R+TUO9&EF:65R('5N(&QI96X@=V5B`$-RZ61I="!I;G-U
M9F9I<V%N="!P;W5R(&5N=F]Y97(@X"!L82!L:7-T92!D92!D:7-T<FEB=71I
M;VXN`$-RZ61I="!I;G-U9F9I<V%N="X`16YT:65R`$QI<W1E(&-O;7!LZ'1E
M`%5$2"`H57-E<B!$871A($AE861E<BD@:6YV86QI9&4`1&]N;NEE(%I)4"!I
M;G9A;&ED92X`07!P;&EC871I;VX@:6YV86QI9&4N`$=R;W5P92!)1"!I;G9A
M;&ED92X`16YV;VD@9&4@9&]N;NEE<R!I;G9A;&ED97,N`$%D<F5S<V4@9&4@
M9&5S=&EN871I;VX@:6YV86QI9&4N`$9O<FUA="!D92!F:6-H:65R(&EN=F%L
M:61E+@!#;&5F(&1E(&QI8V5N8V4@:6YV86QI9&4N`$5M<&QA8V5M96YT(&EN
M9&EQ=>D@:6YV86QI9&4N`*MM<V=?='EP9;L@:6YV86QI9&4N`*MA<&E?:62[
M(&EN=F%L:61E(&]U(&UA;G%U86YT+@!087)A;>AT<F5S(&EN=F%L:61E<R!O
M=2!M86YQ=6%N=',N`%!E<FUI<W-I;VX@:6YV86QI9&4N`$ED+B!D92!P87)T
M96YA:7)E(&EN=F%L:61E+@!#;V1E(&1E('!R;V1U:70@:6YV86QI9&4N`%!R
M;W1O8V]L92!I;G9A;&ED92X`1&5S=&EN871A:7)E(&EN=F%L:61EH#H@JZ`E
M<Z"[`$]B:F5T(&1E('!A<G1A9V4@:6YV86QI9&4`061R97-S92!S;W5R8V4@
M:6YV86QI9&4N`$1O;F[I92!5;FEC;V1E(&EN=F%L:61E+@!);G9E;G1A:7)E
M`$EN=F5R<V5R(&QA('/I;&5C=&EO;@!)<F%N`$ER86L`27)L86YD90!%<W0`
MSFQE(&1E($UA;@!.)V5S="!P87,`5&5M<.IT97,@:7-O;.EE<P!)<W)AZVP`
MR6UE='1E=7(`271A;&EQ=64`271A;&EE`$IA;6'O<75E`$IA;G9I97(`2F%P
M;VX`2F%P;VYA:7,@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:64`2G5I
M;&QE=`!*=6EN`$IU<W1I9FEE<@!#96YT<F5R`$IU<W1I9FEE<@!!;&EG;F5R
M(.`@9V%U8VAE`$%L:6=N97(@X"!D<F]I=&4`2V%Z86MH<W1A;@!'87)D97(@
M;"=O<FEG:6YA;*`_`$ME;GEA`$QE('-E<G9E=7(@2V5R8F5R;W,@82!R96IE
M=.D@;"=A=71H96YT:69I8V%T:6]N+@!$Z6)U=&%N=',@9'4@;F]Y874`0W+I
M871I;VX@9&4@8VQE9@!%;7!R96EN=&4@9&4@;&$@8VQE9@!,;VYG=65U<B!D
M92!L82!C;&5F`%1Y<&4@9&4@8VQE9@!5=&EL:7-A=&EO;B!D92!L82!C;&5F
M`$QA(&-L968@<V4@=')O=79E(&3I:N`@<W5R(&QE('-E<G9E=7(@9&4@8VQE
M9G,@<'5B;&EC+@!%;F9A;G1S`$MI<FEB871I`$-O<NEE(&1U($YO<F0`0V]R
MZ64@9'4@4W5D`$-O<NEE;B`H155#+4M2*0!+;W=E[W0`2VER9VAI>FES=&%N
M`%!RZ5]S96YT871I;VX`3&%N9W5E`$QA;W,`1&5R;FGH<F4@9&5M:64`1&5R
M;FGH<F4@;6]D:69I8V%T:6]N(&1U(&UO="!D92!P87-S90!$97)N:65R('%U
M87)T:65R`$1E<FYIZ')E(&UI<V4@X"!J;W5RH#H`1&5R;FGH<F4@8V]N;F5X
M:6]NH#H@)7,`1&5R;FGH<F4@8V]N;F5X:6]NH#H@)7,@X"!P87)T:7(@9&4@
M)7,`1&5R;FGH<F4@8V]N;F5X:6]NH#H@:F%M86ES`$QE='1O;FEE`$QO:0!0
M<NES96YT871I;VX`3&%I<W-E<B!V:61E('!O=7(@;F4@<&%S(&%V;VER(&1E
M(&)O<F1U<F4`3&EB86X`1V%U8VAE`$5N=.IT92!G875C:&4`5F%L975R<R!D
M92!G875C:&4`3&5S;W1H;P!0;'5S('!E=&ET('%U90!0;'5S('!E=&ET(&]U
M(.EG86QE(.``3FEV96%U`$QI8NER:6$`3&EB>64`3&EE8VAT96YS=&5I;@!"
M<G5I;F4@;.EGZ')E`%!L=6EE(&SI9^AR90!0;'5I92!LZ6?H<F4@=/1T(&1A
M;G,@;&$@:F]U<F[I90!0;'5I92!LZ6?H<F4@=&%R9`!!=F5R<V5S(&SI9^AR
M97,`4&QU:64@;.EGZ')E(&%V96,@=&]N;F5R<F4`3F5I9V4@:6YT97)M:71T
M96YT90!!=F5R<V4@9&4@;F5I9V4@;.EGZ')E`%)I;65S`$QI96X`3&4@;&EE
M;B!P;VEN=&4@=F5R<Z`Z`$QI92!L)V%D<F5S<V4@9&4@8V]U<G)I96P@X"!L
M82!P86=E(&1E(&-O;7!O<VET:6]N(&1U(&UE<W-A9V4@96X@;"=A9F9I8VAA
M;G0`3&EE;G,`0FES8W5I="!,:6YU>`!,:7-T92`M('5T:6QI<V%T975R('!E
M=70@=F]I<B!L92!D;W-S:65R`$QI<W1E(&1E<R!B87-E<R!D92!D;VYNZ65S
M`$EN9&5X(&1E(&PG86ED90!!9F9I8VAE<B!L97,@=&%B;&5S`$%R8VAI=F5S
M(&1E(&QA(&QI<W1E`$%I9&4@9&4@;&$@;&ES=&4`3&ES="U)1`!)9"X@9&4@
M;&$@;&ES=&4`4')O<')IZ71A:7)E(&1E(&QA(&QI<W1E`$5N=F]I(.`@;&$@
M;&ES=&4`06)O;FYE;65N="#@(&QA(&QI<W1E`$3I<V%B;VYN96UE;G0@9&4@
M;&$@;&ES=&4`R6-H96,@9&4@;&$@;&ES=&4@9&5S('-E<W-I;VYSH#H@)7,`
MR6-H96,@9&4@;&$@;&ES=&4@9&5S('5T:6QI<V%T975R<Z`Z("5S`$PG869F
M:6-H86=E(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G,@97-T(&3I<V%C
M=&EVZ2X`3&ET=.ER871U<F4`3&ET=6%N:64`0VAA<F=E;65N="XN+@!(975R
M92!L;V-A;&6@.B``2&5U<F4@970@;&]C86QE`$QI974`0V]N;F5X:6]N`%1R
M86-E(&1E(&QA(&1E<FYIZ')E('-E<W-I;VX@9&4@<WEN8VAR;VYI<V%T:6]N
M`$3I8V]N;F5X:6]N`$-O;FYE>&EO;@!4XF-H97,@9&4@8V]N;F5X:6]N`$QA
M(&-O;FYE>&EO;B!E<W0@<F5F=7/I92X@26P@97-T('!R;V)A8FQE('%U92!V
M;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!O=2!V;W1R92!M;W0@9&4@<&%S<V4@
M82#I=.D@;6%L('-A:7-I`,EC:&5C(&1E(&-O;FYE>&EO;BX`5&5X=&4@;&]N
M9P!!;6]U<@!&86EB;&4`3&5T=')E(&=R96-Q=65S(&UI;G5S8W5L97,`3&5T
M=')E(&QA=&EN97,@;6EN=7-C=6QE<P!.;VUB<F4@<F]M86EN<R!M:6YU<V-U
M;&5S`$QU>&5M8F]U<F<`34T`365S<V%G92!D=2!J;W5R("A-3U1$*0!,82!P
M:>AC92!J;VEN=&4@35,M5$Y%1B!N92!C;VYT96YA:70@875C=6YE(&1O;F[I
M92X`35-'`$UA8V%O`%+I<'5B;&EQ=64@9&4@36%CZ61O:6YE`$UA9&%G87-C
M87(`36%G:64`0V]U<G)I97(`061M:6YI<W1R871I;VX@9'4@8V]U<G)I96P`
M1F%I<F4@=6X@;&EE7VX`36%L87=I`$UA;&%I<VEE`$UA;&1I=F5S`$UA;&D`
M36%L=&4`061M:6YI<W1R97H@;&$@;&ES=&4@9&4@8V%TZ6=O<FEE<R!E="!L
M97,@8V]U;&5U<G,@;&GI97,@X"!C97,@8V%TZ6=O<FEE<RX`0V%R=&4@JR!-
M87`R-""[`$-A<G1E(*L@36%P<75E<W0@NP!#;W)R97-P;VYD86YC97,@96YR
M96=I<W1RZ65S+@!-87)?<75E<B!L92!M97-S86=E(&-O;6UE('-U<'!R:6WI
M`$UA<G,`36%R9V4`36%R<75E<B!L92!M97-S86=E(&-O;6UE.B`@`$UA<G%U
M97(@879E8R!D97,@Z71I<75E='1E<R!6=2].;VX@=G4`36%R<75E<B!A=F5C
M(&0G875T<F5S(.ET:7%U971T97,@*&5X+CH@26UP;W)T86YT+U+I<&]N9'4I
M`,YL97,@36%R<VAA;&P`36%R=&EN:7%U90!#;W)R97-P;VYD`$-H86UP<R!A
M<'!A<F5N=.ES`$UA=7)I=&%N:64`SFQE($UA=7)I8V4`0W+I9&ET(&UA>&EM
M=6T@86QL;W7I+@!,:6UI=&4@9'4@;65S<V%G92!DZ7!A<W/I92X`5&5M<.ER
M871U<F4@;6%X:6UA;&4@9&5S(#(T(&1E<FYIZ')E<R!H975R97.@.B``5&5M
M<.ER871U<F4@;6%X:6UA;&4@9&5S(#8@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!.
M;VUB<F4@;6%X:6UU;2!D92!B;&]C<R!D=2!P;W)T86EL`$QO;F=U975R(&UA
M>&EM=6T`3F]M8G)E(&UA>&EM=6T@9"=A9')E<W-E<R!E;B!L:7-T92!N;VER
M92!DZ7!A<W/I("A.;VUB<F4@=&]T86PZ("5S+"!.;VUB<F4@;6%X:6UU;2!D
M)V%D<F5S<V5S.B`E<RDN($EM<&]S<VEB;&4@9"=A:F]U=&5R('!L=7,@9"=A
M9')E<W-E<R!E;B!L:7-T92!N;VER92X`3F]M8G)E(&UA>&EM=6T@9"=A9')E
M<W-E<R!E;B!L:7-T92!B;&%N8VAE(&3I<&%S<^D@*$YO;6)R92!T;W1A;#H@
M)7,L($YO;6)R92!M87AI;75M(&0G861R97-S97,Z("5S*2X@26UP;W-S:6)L
M92!D)V%J;W5T97(@<&QU<R!D)V%D<F5S<V5S(&5N(&QI<W1E(&)L86YC:&4N
M`$UA:0!-87EO='1E`$WI9&EC86UE;G0`365M8G)E<P!4>7!E(&1E(&UE;G6@
M.@!&=7-I;VYN97(@;&5S(&-E;&QU;&5S`$UE<W-A9V4`5NER:69I8V%T:6]N
M(&1U(&UE<W-A9V4@<NEU<W-I92P@;6%I<R!L92!C97)T:69I8V%T(&1U('-I
M9VYA=&%I<F4@;B=A('!A<R!P=2#J=')E(';I<FEF:>DN`$UE<W-A9V4@97AP
M:7+I+@!4>7!E(&1E(&UE<W-A9V4`3>ETZ6\@365T87(`3&4@8FQO8R"K($UE
M=&%R(+L@;B=E<W0@<&%S(&1I<W!O;FEB;&4N`$QE(&)L;V,@JR!-971A<B"[
M(&XG97-T('!A<R!D:7-P;VYI8FQE+B`@3&5S(&3I=&%I;',@;VYT(.ETZ2!C
M;VYS:6=NZ7,@<&]U<B!L)V%D;6EN:7-T<F%T975R+@!-971A<D1"(&XG97-T
M('!A<R!C;VYN96-TZ2X`3>ET:&]D90!,82!MZ71H;V1E(*N@)7.@NR!N)V5S
M="!P87,@9.EF:6YI90!-Z71H;V1E(&YO;B!DZ69I;FEE+B!-Z71H;V1E(&%P
M<&5LZ66@.B`E<P!-Z71R:7%U90!-97AI<75E`,ET871S(&;I9.ERZ7,@9&4@
M36EC<F]NZ7-I90!-:6QI974`5'EP92!-24U%`%1E;7#I<F%T=7)E(&UI;FEM
M=6T@9&5S(#(T(&1E<FYIZ')E<R!H975R97.@.B``5&5M<.ER871U<F4@;6EN
M:6UU;2!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@`$QA(&1U<NEE(&UI;FEM
M86QE(&1U(&UO="!D92!P87-S92!N)V$@<&%S(&5N8V]R92!E>'!I<ND`36ER
M;VER`%9A<FGI<P!,92!P87%U971A9V4@2%144%]R97%U97-T(%!%05(@97-T
M(&UA;G%U86YT+@!!9')E<W-E(&UA;G%U86YT92!P;W5R('D@<F5D:7)I9V5R
M(&QE(&UE<W-A9V4@`$-O;F9I9W5R871I;VX@:6YE>&ES=&%N=&4N(%9O=7,@
M9&5V97H@;&$@9^ENZ7)E<B!M86EN=&5N86YT('-I('9O=7,@=F]U;&5Z('5T
M:6QI<V5R(&-E='1E(&%P<&QI8V%T:6]N+@!)1"!D=2!M97-S86=E(&UA;G%U
M86YT+@!286ES;VX@9&4@<F5J970@;6%N<75A;G1E(`!286ES;VX@;6%N<75A
M;G1E(&1A;G,@;&$@<NAG;&4@9"=A8G-E;F-E`$QE('!A<75E=&%G92!014%2
M($UA:6P@97-T(&UA;G%U86YT+@!)1"!D92!S97-S:6]N(&UA;G%U86YT+@!,
M=0!#;W5R<FEE;"!S86YS(&9I;`!-;V3I<ND`1&%T92!D92!M;V1I9FEC871I
M;VX`36]D:69I97(@;"=54DP`36]D=6QO`$UO;&1A=FEE`$UO;F%C;P!-;VYG
M;VQI90!-;VES(&5T(&%N;NEE`$UE;G-U96QL96UE;G0`36]N='-E<G)A=`!0
M:&%S97,@9&4@;&$@;'5N90!#:&%M<',@<W5P<&SI;65N=&%I<F5S('1R;W5V
MZ7,@X"!L82!L:6=N92`E9"`H871T96YD=7,@)60I+@!-87)O8P!'Z6[I<F%L
M96UE;G0@96YS;VQE:6QLZ0!'Z6[I<F%L96UE;G0@;G5A9V5U>`!'Z6[I<F%L
M96UE;G0@96YS;VQE:6QLZ0!$Z7!L86-E<@!697)S(&QE(&)A<P!$Z7!L86-E
M<B#@(&=A=6-H90!$Z7!L86-E<B#@(&1R;VET90!$97-C96YD<F4@;&$@<NAG
M;&4`36]N=&5R(&QA('+H9VQE`%9E<G,@;&4@:&%U=`!697)S(&QE(&)A<P!6
M97)S(&QE(&AA=70`36]Z86UB:7%U90!,:7-T97,@9.ER;W5L86YT97,@;75L
M=&DM;FEV96%U>`!#87)T92"KH$UU;'1I;6%P(%5+H+L`4^EL96-T:6]N(&UU
M;'1I<&QE`%!A<F%MZ71R86=E(&1U(&-O;7!T90!-97,@9&]N;NEE<R!P97)S
M;VYN96QL97,`36]N('!O<G1A:6P`4'+I<V5N=&%T:6]N(&1E(&UO;B!P;W)T
M86EL`$)I<FUA;FEE`$Y/3BP@:F4@;B=A8V-E<'1E('!A<P!.7V]M8G)E(&1E
M(&IO=7)S(&5N=')E(&QE<R!M97-S86=E<R!D)V%B<V5N8V4Z`$YO;0!.86UI
M8FEE`$YA=7)U`$[I<&%L`%!A>7,M0F%S`$%N=&EL;&5S(&[I97)L86YD86ES
M97,`55),(&1E(&)A<V4@9&4@3F5T<V-A<&4`55),(&1E('+I=F]C871I;VX@
M9&4@;"=!+D,N($YE='-C87!E`%523"!D92!L82!P;VQI=&EQ=64@9"=!+D,N
M($YE='-C87!E`%523"!D92!R96YO=79E;&QE;65N="!.971S8V%P90!54DP@
M9&4@<NEV;V-A=&EO;B!.971S8V%P90!.;VT@9'4@<V5R=F5U<B!34TP@3F5T
M<V-A<&4`0V]M;65N=&%I<F4@9'4@8V5R=&EF:6-A="!.971S8V%P90!4>7!E
M(&1U(&-E<G1I9FEC870@3F5T<V-A<&4`4NES96%U`$IA;6%I<P!.;W5V96QL
M92U#86SI9&]N:64`3F]U=F5L;&4@8V%TZ6=O<FEE`$YO=79E874@;65S<V%G
M92#@("5S`$YO=79E;&QE(&QU;F4`3F]U=F5L;&4@<NAG;&4`3F]U=F5A=2!N
M;VT@9&4@8V]N;F5X:6]N("AF86-U;'1A=&EF*0!.;W5V96QL92U:Z6QA;F1E
M`$YO=79E874@;6]T(&1E('!A<W-E`$QE(&YO=79E874@;6]T(&1E('!A<W-E
M(&5X<&ER97)A(&QE("5X+@!,97,@;F]U=F5A=7@@;6]T<R!D92!P87-S92!D
M:69FZ')E;G0N`$YO=79E;&QE(&9E;NIT<F4@*%]B;&%N:RD`3F]U=F5L;&5S
M`$9O<G5M<P!3=6EV86YT`#0@<&AA<V5S('-U:79A;G1E<P!/<'1I;VYS('-U
M:79A;G1E<P!3=6EV86YT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.=6ET
M`$YI=64`3F]N`$QE('!A<F%MZ'1R92!O8FQI9V%T;VER92`@)7,G(&XG97-T
M('!A<R!S<.EC:69IZ2!D86YS(&QA(&-O;F9I9W5R871I;VXN`%!A<R!D92!D
M;VYNZ65S(&1E(&-O;F9I9W5R871I;VX@<&]U<B!L97-Q=65L;&5S(&UO;G1R
M97(@;&5S(&1I9F;I<F5N8V5S+@!087,@9&4@<W1R873I9VEE(&1I<W!O;FEB
M;&4@<&]U<B!F86ER92!D97,@:6UA9V5S($E33RX`4&%S(&1E($)A8VME;F0@
M8V]N9FEG=7+I('!O=7(@8V4@<V5R=F5U<@!087,@9&4@0F%C:V5N9"!C;VYF
M:6=U<ND@<&]U<B!C92!S97)V975R(`!087,@9&4@9V%B87)I="!E;B!T<F%I
M=&5M96YT('!A<B!L;W0N`$%U8W5N(&)L;V,@;B=E>&ES=&4@X"!L82!P;W-I
M=&EO;B!D96UA;F3I90!087,@9&4@;F]M(&1E(&-A;&5N9')I97(@9F]U<FYI
M('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!-0T%,+@!.;VX@;6]D:69I
MZ2X`075C=6YE('-O=7,M<&5R;6ES<VEO;B!N)V$@8F5S;VEN(&0GZG1R92!A
M:F]U=.EE('-O=7,@8V4@;FEV96%U+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@
M8V]N9FEG=7)A=&EO;B!S<.EC:69IZ64@<&]U<B`E<RX`075C=6YE(&EN9F]R
M;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R($944"!61E,N
M`$%U8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N:64@
M<&]U<B!344P@5D93+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A
M=&EO;B!F;W5R;FEE('!O=7(@4U%,+49I;&4@5D93+@!!=6-U;B!C<NED:70@
M9&ES<&]N:6)L92X`075C=6YE(&1E<W1I;F%T:6]N('1R;W5VZ64N`$%U8W5N
M(&9I8VAI97(@96YV;WGI`%!A<R!D92!F:6QT<F4N($-L:7%U97H@)R5S)R!P
M;W5R(&-R965R('5N(&YO=79E874@9FEL=')E`%!A<R!D)V5N('3J=&4@<W#I
M8VEF:>D`075C=6X@:6/T;F4@=')O=7;I+@!!=6-U;B!L:65U(&XG97-T('/I
M;&5C=&EO;F[I`$%U8W5N(&5M<&QA8V5M96YT(&XG97-T(&EN9&EQ=>DN`$%U
M8W5N(&UE<W-A9V4@9F]U<FYI`$%U8W5N(&YO;2!S<.EC:69IZ2X`075C=6X@
M;F]M8G)E('-PZ6-I9FGI+@!087,@9"=A<&AO<FES;65S(&-H;W%U86YT<P!!
M=6-U;B!M;W0@9&4@<&%S<V4@9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T
M:6]N('!A<B!(5%10+@!!=6-U;B!M;W0@9&4@<&%S<V4@9F]U<FYI('!O=7(@
M;"=A=71H96YT:69I8V%T:6]N('!A<B!)34%0+@!!=6-U;B!M;W0@9&4@<&%S
M<V4@9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!+97)B97)O
M<RX`075C=6X@;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT
M:69I8V%T:6]N+@!!=6-U;B!M;W0@9&4@<&%S<V4@<W#I8VEF:>D@<&]U<B!L
M)V%U=&AE;G1I9FEC871I;VX@4$%34U=$+@!!=6-U;B!M;W0@9&4@<&%S<V4@
M<W#I8VEF:>D@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@4TU"+@!!=6-U;B!C
M:&5M:6X@=F5R<R!L92!B:6YA:7)E($]P96Y34TP@9F]U<FYI+B!,92!B:6YA
M:7)E(&0G3W!E;E-33"!E<W0@;NEC97-S86ER92!P;W5R(&9O;F-T:6]N;F5R
M(&%V96,@9&5S(&1O;F[I97,@4$M#4R`Q,BX`075C=6YE(&-O;F9I<FUA=&EO
M;B!E;B!A='1E;G1E`%!A<R!D92!Q=6]T82!P;W-I=&EO;F[I+@!087,@9&4@
M<NAG;&5S`$%U8W5N('-C<FEP="!GZ6[I<NDN`$%U8W5N('/I<&%R871E=7(@
M<W#I8VEF:>DN`%!A<R!D92!C]'3I<P!087,@9&4@8VAA:6YE('-PZ6-I9FGI
M90!&:6-H:65R(&EN97AI<W1A;G0`075C=6X@<NEP97)T;VER92!T96UP;W)A
M:7)E(&5S="!D:7-P;VYI8FQE('!O=7(@;&$@8V%C:&4`075C=6X@;F]M(&0G
M=71I;&ES871E=7(@970@+V]U(&UO="!D92!P87-S92!E;G9O>>DN`$%U8W5N
M92!D;VYNZ64@6$U,('9A;&ED92!N)V$@Z73I(')E=&]U<F[I90!087,@9&4@
M=F%L975R`%!A<R!D92!V97)S:6]N('1R;W5VZ64@9&%N<R!L82!C;VYF:6=U
M<F%T:6]N(&]R:6=I;F%L92X@4NEGZ6[I<F5Z(&QA(&-O;F9I9W5R871I;VXN
M`%!A<R!D92!V97)S:6]N('1R;W5VZ64@9&%N<R!V;W1R92!C;VYF:6=U<F%T
M:6]N+B!2Z6?I;NER97H@;&$@8V]N9FEG=7)A=&EO;BX`075C=6X`075C=6X@
M*'5T:6QI<V5R(&EM<&QI8VET96UE;G0I`$YO<F1I<75E("A)4T\M.#@U.2TQ
M,"D`SFQE($YO<F9O;&L`2.EM:7-P:.AR92!.;W)D`,YL97,@36%R:6%N;F5S
M(&1U(&YO<F0`3F]R=NAG90!087,@87!RZ',`4&%S(&%V86YT`%!A<R!U;B!D
M;W-S:65R`$YO;B#I9V%L92#@`$YO;B!I;7!LZ6UE;G3I+@!);F%C=&EF`$YO
M;B!P<FES(&5N(&-O;7!T92X`3F]T97,`4FEE;B#@(&YA=FEG=65R+"!R971O
M=7)N97H@96X@87)R:>AR92X`3F]V96UB<F4`3F]M8G)E`$YO;6)R92!D92!C
M87)A8W3H<F5S`$YO;6)R92!D92!C;VQO;FYE<P!.;VUB<F4@9&4@<F%N9^EE
M<P!.;VUB<F4@;F]N('-PZ6-I9FGI('!O=7(@;&$@;6ES92#@(&IO=7(@9&4@
M;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+@!/2P!/8FIE=`!#<NEA=&5U<B!D
M)V]B:F5T`$]C=&%L`$]C=&]B<F4`1FEL=')E(&%N=&DM;V9F96YS86YT`$)U
M<F5A=0!,)V%N8VEE;B!E="!L92!N;W5V96%U(&UO=',@9&4@<&%S<V4@9&]I
M=F5N="#J=')E(&1I9F;I<F5N=',N`$%N8VEE;B!M;W0@9&4@<&%S<V4`3"=A
M;F-I96X@;6]T(&1E('!A<W-E(&5S="!I;F-O<G)E8W0`3VUA;@!3975L(&QE
M<R!S97)V975R<R!)34%0('-U<'!O<G1E;G0@;&5S(&1O<W-I97)S('!A<G1A
M9^ES+@!3975L96UE;G0@;&5S(*N@9F]R='5N97.@NR!O9F9E;G-A;G1E<P!5
M;F4@<V5U;&4@861R97-S92!D92!C;W5R<FEE;"!P97)M:7-E+@!3975L<R!L
M92!P<F]P<FGI=&%I<F4@;W4@;"=A9&UI;FES=')A=&5U<B!S>7-TZ&UE('!E
M=70@;6]D:69I97(@;&5S('!E<FUI<W-I;VYS(&0G=6X@<&%R=&%G92X`3W5V
M<FER(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`17)R975R($]P96Y34TR@
M.B!I;7!O<W-I8FQE(&0G97AT<F%I<F4@;&5S(&1O;F[I97,@9&4@;&$@<&%R
M=&EE('-I9V[I92!3+TU)344`3W5V<FER(&QE<R!L:65N<R!D86YS('5N92!N
M;W5V96QL92!F96[J=')E`%-Y<W3H;64@9"=E>'!L;VET871I;VX`3W!T:6]N
M<P!/<'1I;VYS(&1E(&UI<V4@X"!J;W5R(&1E<R!S8W)I<'1S`$]P=&EO;G,@
M<&]U<B`E<P!,:7-T92!N=6WI<F]TZ64`3W)G86YI<V%T:6]N`%5N:73I(&]R
M9V%N:7-A=&EO;FYE;&QE`$]R9V%N:7-A=&EO;@!-;V3H;&4@;W)I9VEN86P@
M9"=A<'!L:6-A=&EO;@!-;V3H;&5S(&]R:6=I;F%U>"!D86YS("5SH#H`075T
M<F4`075T<F5S(&EN9F]R;6%T:6]N<P!!=71R97,@3W!T:6]N<P!097)M:7-S
M:6]N<R!D=2!P<F]P<FGI=&%I<F4`3"=A=71H96YT:69I8V%T:6]N(%!!32!N
M)V5S="!P87,@9&ES<&]N:6)L92X`36]D=6QE(%!%05(Z.DUA:6P`4VEG;F%T
M=7)E(&YU;>ER:7%U92!01U``1&]N;NEE<R!01U`@8VAI9F9RZ65S`$-L968@
M<'5B;&EQ=64@4$=0`$1O;F[I97,@4$=0('-I9V[I97,O8VAI9F9RZ65S`$-O
M9&4@4$A0`$EN=&5R<'+I=&5U<B!02%``4&QU:64@;.EGZ')E(&PG87!RZ',M
M;6ED:0!!=F5R<V5S(&PG87!RZ',M;6ED:0!.96EG92!L)V%P<NAS+6UI9&D`
M0VAU=&5S(&1E(&YE:6=E(&PG87!RZ',M;6ED:0!3;VQE:6P@;"=A<'+H<RUM
M:61I`$]R86=E<R!L)V%P<NAS+6UI9&D`17AT96YS:6]N(%!/4TE8(&%B<V5N
M=&4`26YT97)P<NET975R(%!?2%``4F5M<&QI<W-A9V4`4&%K:7-T86X`0F5L
M874`4&%L97-T:6YE("AT97)R:71O:7)E(&]C8W5PZ2D`4&%N86UA`%!A<&]U
M87-I92U.;W5V96QL92U'=6ENZ64`4&%R86=U87D`4&%R=&EE;&QE;65N="!N
M=6%G975X`$UO="!D92!P87-S90!#:&%N9V5M96YT(&1U(&UO="!D92!P87-S
M92!E9F9E8W1UZ2X`36]T(&1E('!A<W-E(&EN8V]R<F5C=`!-;W0@9&4@<&%S
M<V4@<F5Q=6ES('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%)!1$E54RX`36]T
M(&1E('!A<W-E(&%V96,@8V]N9FER;6%T:6]N`$UO="!D92!P87-S9:`Z`$UO
M="!D92!P87-S9:`Z(`!,97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@
M:61E;G1I<75E<RX`0V]L;&5R`$-O;&QE<B!D97!U:7,@;&4@<')E<W-E+7!A
M<&EE<G,`0VAE;6EN`$-O;F9I<FUA=&EO;G,@96X@871T96YT9:`Z`%!E<G-O
M;FYE<P!0;W5R8V5N=&%G90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@
M;6%I;G1E;F%N8V4`169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT
M96YA;F-E(.`@;&$@8V]N;F5X:6]NH#\`4&5R;6ES<VEO;@!,82!P97)M:7-S
M:6]N(*N@)7.@NR!N)V5S="!P87,@<W5P<')I;>EE+@!097)M:7-S:6]N(')E
M9G5SZ64`4&5R;6ES<VEO;G,`061M:6YI<W1R871I;VX@9&5S('!E<FUI<W-I
M;VYS`$1O;F[I97,@<&5R<V]N;F5L;&5S`%#I<F]U`$%N:6UA=7@`4&AI;&EP
M<&EN97,`5.ELZ7!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET
M=61E<P!35E`@8VQI<75E>B!D86YS('5N92!C96QL=6QE`%-64"!C;VYF:7)M
M97H@;&$@<W5P<')E<W-I;VX@9&4@8V5T(.ELZ6UE;G2@.@!35E`@8V]N9FER
M;65Z('%U92!V;W5S('9O=6QE>B!DZ6QI97(@8V5T(.ELZ6UE;G0N`%9E=6EL
M;&5Z('-A:7-I<B!U;B!M;VES(&5T('5N92!A;F[I92X`5F5U:6QL97H@<V%I
M<VER('5N(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A=.EG;W)I9:`Z`%9E=6EL
M;&5Z(&5N=')E<B!U;F4@861R97-S92!)4"!V86QI9&4N`%9E=6EL;&5Z(&5N
M=')E<B!U;F4@9&%T92!V86QI9&6@.R!VZ7)I9FEE>B!L92!N;VUB<F4@9&4@
M:F]U<G,@9'4@;6]I<RX@`%9E=6EL;&5Z(&5N=')E<B!U;F4@:&5U<F4@=F%L
M:61E+@!6975I;&5Z('-A:7-I<B!L92!N;VT@9'4@;F]U=F5A=2!D;W-S:65R
M.@!6975I;&QE>B!F;W5R;FER('5N('+I<W5MZ2!D=2!P<F]B;.AM92X`5F5U
M:6QL97H@9F]U<FYI<B!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!E="!V;W1R
M92!M;W0@9&4@<&%S<V4`5F5U:6QL97H@;&ER92!L92!T97AT92!S=6EV86YT
M+B!6;W5S(&1E=F5Z(&%C8V5P=&5R(&QE<R!C;VYD:71I;VYS('!O=7(@=71I
M;&ES97(@;&4@<WES=.AM92X`5F5U:6QL97H@96YT<F5R(&QE(&YO=79E874@
M;F]MH&1E(&QA(&-A=.EG;W)I9:`Z`%!O;&]G;F4`4&]L:71I<75E`%-C<G5T
M:6YS`%!O<G1U9V%L`%!O<VET:6]N(&1E(&-E='1E(&EM86=E`%!O<VET:6]N
M(&1E(&-E('1A8FQE874`16YV;WEE<B#@(&-E(&1O<W-I97(@*&YO;B!A<'!L
M:7%UZ2!P87(@24U!4"D`4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@9&5R
M;FGH<F5S(&AE=7)E<Z`Z(`!0<F]B86)I;&ETZ3QB<B`O/F1E('!L=6EE`%!R
M969S7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE
M+@!0<F5F<U]S97-S:6]NH#H@97AT96YS:6]N(')E<75I<V4@JZ!S97-S:6]N
MH+L@;F]N('1R;W5VZ64N`%!R97-S:6]N`%!R97-S:6]N(&%U(&YI=F5A=2!D
M92!L82!M97*@.B``4')E<W-I;VZ@.B``07!E<N=U`$%P97+G=2!D92!L)VEM
M86=E(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`3W!T:6]N<R!P<NECZ61E
M;G1E<P!);7!R:6UE<B!L92!D;V-U;65N=`!#;&5F('!R:7;I90!0<F]B;.AM
M90!$97-C<FEP=&EO;B!D=2!P<F]B;.AM90!0<F]J971S`%1E>'1E(&-O=7)T
M`$-L968@<'5B;&EQ=64`06QG;W)I=&AM92!D92!C;&5F('!U8FQI<75E`$EN
M9F]R;6%T:6]N<R!S=7(@;&$@8VQE9B!P=6)L:7%U90#)8VAE8R!D92!L82!G
MZ6[I<F%T:6]N(&1E(&QA('!A:7)E(&1E(&-L969S('!U8FQI<75E+W!R:7;I
M92X`4&]R=&\@4FEC;P!1871A<@!297%UZG1E`%%U;W1A`$-L968@<'5B;&EQ
M=64@4E-!("@E9"!B:71S*0!?4F%I<V]N`%/I;&5C=&EO;B!R861I;P!0;'5I
M90!0;'5I92!T]'0@;&4@;6%T:6X`4&QU:64@=&%R9"!D86YS(&QA(&IO=7)N
MZ64`079E<G-E<P!0;'5I92!E="!N96EG90!0;'5I92!P=6ES(&YE:6=E`$%P
M:&]R:7-M92!A=2!H87-A<F0`5&%U>`!,:7)E`$UE<W-A9V5S(&QU<P!3=7!P
M<F5S<VEO;B!DZ69I;FET:79E(&1E("5SH#\`4W5P<')E<W-I;VX@9.EF:6YI
M=&EV92!D97,@9&]N;NEE<R!P;W5R(&PG=71I;&ES871E=7(@)7.@/R!#971T
M92!O<.ER871I;VX@97-T(&3I9FEN:71I=F4N`%)EYW4`4F5D:7)I9V5R('9E
M<G,`4F5P<F5N9')E('9O=')E(&1E<FYIZ')E(&%C=&EO;@!2869R8>YC:&ER
M`%)A9G)A[F-H:7(@;&5S(.ELZ6UE;G1S(&1U(&UE;G4@9'EN86UI<75EH#H`
M4F%F<F'N8VAI<B!L)^EC<F%N(&1U('-O;6UA:7)EH#H`17AP<F5S<VEO;B!R
M871I;VYN96QL90!%>'!R97-S:6]N('+I9W5L:>AR90!296IE=&5R(&%V96,@
M;&$@<F%I<V]N`$YA=FEG871E=7(@<F5L871I;VYN96P`4F5C:&%R9V5R`%)E
M;6%R<75E<P!397)V975R<R!D:7-T86YT<P!54DP@9&ES=&%N=&4@*&AT='`Z
M+R]W=W<N97AE;7!L92YC;VTO:&]R9&4O*:`Z`%)E=&ER97(`4F5T:7)E<B!L
M92!B;&]C`%)E=&ER97(@;&$@8V]L;VYN90!2971I<F5R(&QE(&9O<FUA=&%G
M90!2971I<F5R(&QA('!A:7)E`$5N;&5V97(@;&4@<V-R:7!T(&5N<F5G:7-T
M<ND@9'4@<NEP97)T;VER92!T96UP;W)A:7)E(&1U('-E<G9E=7(N`%)E=&ER
M97(@;&4`4F5T:7)E<B!C92!N;V5U9"!D=2!D;V-U;65N=`!2971I<F5R(&PG
M=71I;&ES871E=7(`4F5T:7)E<B!L)W5T:6QI<V%T975RH#H@)7,`075C=6YE
M('+I<&]N<V4@X"!V;W1R92!R97%UZG1E+B!#;V1E(&0G97)R975R(')E=&]U
M<F[IH#H@`$QE('-E<G9I8V4@9&5M86YDZ2!E<W0@:6YT<F]U=F%B;&4N`$QE
M('!A<F%MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@;B=E<W0@<&%S('-PZ6-I
M9FGI(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B`E<RX`3&4@<&%R86WH=')E(&]B
M;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L82!C
M;VYF:6=U<F%T:6]N(&1U(%9&4RX`3&4@<&%R86WH=')E(&]B;&EG871O:7)E
M(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T
M:6]N+@!#:&%M<"!O8FQI9V%T;VER90!296YV;WGI('9E<G,`4F5N=F]Y97(@
M9&5P=6ES`%+`6@!296UI<V4@X"!ZZ7)O(&1U(&UO="!D92!P87-S90!296UE
M='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E`%)E=F5N:7(@X"!L82!D
M97)N:>AR92!R97%UZG1E`%+I<W5L=&%T<P!2971O=7(@=F5R<R!L82!L:7-T
M92!D97,@9FEL=')E<P!2979E;FER(&%U>"!O<'1I;VYS`%)E=&]U<B!V97)S
M(&QA(&QI<W1E(&1E<R!RZ&=L97,`4NDM96YT<F5R(&QE(&YO=79E874@;6]T
M(&1E('!A<W-E`%+I=6YI;VX`4F5V96YI<B#@(&QA(&-O;F9I9W5R871I;VX@
M<'+I8^ED96YT90!/<'1I;VYS(&1E(&PGZ61I=&5U<B!2:6-H(%1E>'0`1&5V
M:6YE='1E<P!$<F]I=&4`16YTZG1E(&1E(&1R;VET90!686QE=7)S(&-O<G)E
M8W1E<P!0<F]P<FGI=.ES(&1E(&QA(')A;E]GZ64@+BXN`%+T;&4`4F]U;6%N
M:64`4&EV;W1E<B`Q.#``4&EV;W1E<B#@(&=A=6-H90!0:79O=&5R(.`@9')O
M:71E`%!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE`%!R;W!R:>ETZ7,@9&4@;&$@
M<F%N9^EE`%)A;F?I97.@.@!2Z&=L90!2Z&=L92!C;W!IZ64`4NAG;&4@969F
M86/I90!2Z&=L92!DZ7-A8W1I=NEE`%+H9VQE(&3I<V%C=&EVZ0!.;VT@9&4@
M;&$@<NAG;&4`4NAG;&5S`$1E<R!F:6QE=',@87!P87)A[G1R;VYT(&5N=')E
M('1O=71E<R!L97,@<F%N9^EE<R!E="!L97,@8V]L;VYN97,`1&5S(&9I;&5T
M<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(&-O;&]N;F5S('-E=6QE;65N=`!$
M97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!L97,@<F%N9^EE<R!S975L
M96UE;G0`3&%N8V5R`%)U<W-I90!2=V%N9&$`4VEG;F%T=7)E(.EL96-T<F]N
M:7%U92!3+TU)344`365S<V%G92!C:&EF9G+I(%,O34E-10!,)V%U=&AE;G1I
M9FEC871I;VX@4T%33"!N)V5S="!P87,@9&ES<&]N:6)L90!-97-S86=E<FEE
M(%--4P!);G1E<G!RZ71E=7(@4U%,`$]R9')E(%-13"!P;W5R(')E=&]U<FYE
M<B!L97,@=F%L975R<P!34T@`4U5#0\A3`$EN=&5R<'+I=&5U<B!37U%,`%-A
M`%-A:6YT92U(Z6SH;F4`4V%I;G0M0VAR:7-T;W!H92UE="U.:>EVZ',`4V%I
M;G1E+4QU8VEE`%-A:6YT+5!I97)R92!E="!-:7%U96QO;@!386EN="U6:6YC
M96YT+65T+6QE<R!'<F5N861I;F5S`$WJ;64@8V%D<F4@*%]S96QF*0!386UO
M82!O8V-I9&5N=&%L97,`4V%I;G0M36%R:6X`4V%O+51O;>DM970M4')I;F-I
M<&4`1F]U<FYI<W-E=7(@<V%T96QL:71E`$%R86)I92!386]U9&ET90!%;G)E
M9VES=')E<@!%;G)E9VES=')E<B"KH"5SH+L`16YR96=I<W1R97(@)7,`16YR
M96=I<W1R97(@;&5S(&]P=&EO;G,`16YR96=I<W1R97(@;&5S(&]P=&EO;G,`
M16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE(&-O;6UE('5N
M('-C<FEP="!02%`@9&%N<R!L92!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@9&4@
M=F]T<F4@<V5R=F5U<BX`16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!D
M92`E<P!38W)I<'0@9&4@;6ES92#@(&IO=7(@9&4@8V]N9FEG=7)A=&EO;B!E
M;G)E9VES='+I('-O=7.@.B"K("5SH+L`3W)A9V5S(&ES;VSI<P!38VEE;F-E
M`%-C<FEP=`!-:7-E(.`@:F]U<B!D=2!S8W)I<'0`4V-R:7!T(&YO;B!M:7,@
MX"!J;W5R`%-C<FEP="!A8W1I=ND@879E8R!S=6-CZ',N`%-C<FEP="!DZ7-A
M8W1I=ND@879E8R!S=6-CZ',N`%)E8VAE<F-H90!-;W1E=7)S(&1E(')E8VAE
M<F-H90!6=0!#:&]I<VES<V5Z(&QE<R!F:6-H:65R<P!3Z6QE8W1I;VYN97H@
M=6YE(&1A=&4`0VAO:7-I<W-E>B!U;B!C:&%M<`!3Z6QE8W1I;VYN97H@=6X@
M9W)O=7!E(.`@86IO=71E<@!3Z6QE8W1I;VYN97H@=6X@;F]U=F5A=2!P<F]P
M<FGI=&%I<F4`4^EL96-T:6]N;F5Z('5N('-E<G9E=7(`4^EL96-T:6]N;F5Z
M('5N('5T:6QI<V%T975R(.`@86IO=71E<@!4;W5T('/I;&5C=&EO;FYE<@!3
MZ6QE8W1I;VYN97H@=&]U=&5S(&QE<R!C;VUP;W-A;G1E<R!D92!L82!D871E
M+@!#:&]I<VES<V5Z('5N(&]B:F5T`$YE('/I;&5C=&EO;FYE<B!A=6-U;@!#
M:&]I<VES<V5Z('5N(&1O<W-I97(@8VEB;&4`4^EL96-T:6]N;F5Z(&QE<R!C
M87)A8W3H<F5S(&1O;G0@=F]U<R!A=F5Z(&)E<V]I;B#@(&PG86ED92!D92!L
M)V]U=&EL(&-I+61E<W-O=7,N(%9O=7,@<&]U=F5Z(&5N<W5I=&4@;&5S(&-O
M<&EE<B!E="!L97,@8V]L;&5R(&1A;G,@=F]T<F4@=&5X=&4N`%/I;&5C=&EO
M;FYE>B!L92!DZ6QI;6ET975R(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97H@;&4@
M9F]R;6%T(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97(@;&4@<')O9FEL('%U92!V
M;W5S(&3I<VER97H@;6]D:69I97(Z`%/I;&5C=&EO;FYE>B!L92!DZ6QI;6ET
M975R(&0G:&5U<F6@.@!3Z6QE8W1I;VYN97H@;&4@9F]R;6%T(&1E(&PG:&5U
M<F6@.@!3Z6QE8W1I;VYN97H@9&5U>"!C:&%M<',@87!P87)E;G3I<RX`4^EL
M96-T:6]N;F5Z('9O=')E('1HZ&UE(&1E(&-O=6QE=7)S+@!3Z6QE8W1I;VYN
M97H@=F]T<F4@;&%N9W5E('!RZ6;I<NEEH#H`16XM=.IT92!A=71O+63I9FEN
M:7-S86)L90!%;G9O>65R(&QE(')A<'!O<G0@9"=A;F]M86QI90!%;G9O>65R
M(%--4P!%>'#I9&ET975R`%/I;NEG86P`4V]N9&6@.B``4V5P=&5M8G)E`%-E
M<F)I92!E="!-;VYT96YE9W)O`$YU;>ER;R!D92!SZ7)I90!,97,@9&]N;NEE
M<R!D=2!S97)V975R('-O;G0@9F%U<W-E<R!O=2!N;VX@9&ES<&]N:6)L97,N
M`$%D;6EN:7-T<F%T:6]N(&1E<R!S97-S:6]N<P!)9"X@9&4@<V5S<VEO;B!E
M>'!I<NDN`%-E<W-I;VYS`%/I;&5C=&EO;FYE<@!#;VYF:6=U<F5R(&QE<R!O
M<'1I;VYS('!O=7(@=F]U<R!P97)M971T<F4@9&4@<F5M971T<F4@X"!ZZ7)O
M('9O=')E(&UO="!D92!P87-S92!S:2!J86UA:7,@=F]U<R!L)V]U8FQI97HN
M`$-O;F9I9W5R97(@;&5S('-E<G9E=7)S(&1I<W1A;G1S(&%C8V5S<VEB;&5S
M(&1E<'5I<R!V;W1R92!P;W)T86EL+@!3Z6QE8W1I;VYN97H@=F]T<F4@;&%N
M9W5E('!RZ6;I<NEE+"!F=7-E874@:&]R86ER92!E="!L97,@;W!T:6]N<R!D
M92!D871E+@!$Z69I;FES<V5Z(&QA('!R96UIZ')E(&%P<&QI8V%T:6]N(&QA
M;F/I92P@;&4@=&CH;64@9&4@8V]U;&5U<G,L(&QE(')A9G)A[F-H:7-S96UE
M;G0@9&5S('!A9V5S+"!E="!D)V%U=')E<R!O<'1I;VYS(&0G869F:6-H86=E
M+@!,97,@<'+I9NER96YC97,@;VYT(&)I96X@Z73I(&UI<V5S(.`@:F]U<BX`
M0V]N9FEG=7)A=&EO;@!38W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E
M(.`@:F]U<B!D:7-P;VYI8FQE`%!L=7-I975R<R!E;F1R;VET<R!P;W-S:6)L
M97,@879E8R!L92!P87)A;>AT<F6@.B``4V5Y8VAE;&QE<P!!8VAA=`!2Z7-U
M;>D`1&]I="UO;B!DZ69I;FER(&1E<R!T;W5C:&5S(&1E(')A8V-O=7)C:7,@
M<&]U<B!L82!P;'5P87)T(&1E<R!L:65N<Z`_`$%F9FEC:&5R`$%F9FEC:&5R
M(&QE('-C<FEP="!A8W1I9C\`069F:6-H97(@;&4@<V-R:7!T(&-O=7)A;G0`
M36]N=')E<B!L97,@9&EF9NER96YC97,@96YT<F4@;&$@8V]N9FEG=7)A=&EO
M;B!E;G)E9VES='+I92!A8W1U96QL96UE;G0@970@8V5L;&4@;F]U=F5L;&5M
M96YT(&?I;NERZ64N`$UO;G1R97(@;"=H975R92!D92!L82!D97)N:>AR92!C
M;VYN97AI;VX@X"!L)V5N='+I9:`_`$UO;G1R97(@;"=O<'1I;VX@9&4@8V]N
M<V5R=F5R(&PG;W)I9VEN86P`36]N=')E<B!L92!SZ6QE8W1E=7(`069F:6-H
M97(@;&$@8F%R<F4@9&4@;65N=2!D92!T86)L96%U>*`_`$%F9FEC:&5R(&QE
M(&UE;G4@)7,@X"!G875C:&6@/P!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L
M;V=U92!T86)L96%U(&-E;&QU;&4`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA
M;&]G=64@9&5S('!R;W!R:>ETZ7,@9'4@=&%B;&5A=0!!9F9I8VAE<B!L82!B
M;^YT92!D92!D:6%L;V=U92!D97,@<')O<')IZ73I<R!D92!L82!R86YGZ64@
M9'4@=&%B;&5A=0!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!D97,@
M<')O<')IZ73I<R!D92!L)VEM86=E`$%F9FEC:&5R(&PG96YV;VD@9&4@9FEC
M:&EE<@!!=F5R<V5S`$%V97)S97,@=/1T(&1A;G,@;&$@:F]U<F[I90!!=F5R
M<V5S('1A<F0@96X@:F]U<F[I90!!=F5R<V5S(&%U>"!A;&5N=&]U<G,`4F5S
M<V5R<F5R`%)E<W-E<G)E<B!O=2!DZ6=A9V5R(&0G86)O<F0@;&4H<RD@8FQO
M8RAS*2!V;VES:6XH<RD`4VEE<G)A($QE;VYE`%,G:6YS8W)I<F4`4VEG;F%T
M=7)E`$%L9V]R:71H;64@9&4@<VEG;F%T=7)E`%-I;F=A<&]U<@!486EL;&4`
M06YN=6QE<B!L82!M86EN=&5N86YC90!3;&]V87%U:64`4VQO=NEN:64`3F5I
M9V4`079E<G-E(&1E(&YE:6=E`$%V97)S97,@9&4@;F5I9V4`079E<G-E<R!D
M92!N96EG92!T]'0@9&%N<R!L82!J;W5R;NEE`$%V97)S97,@9&4@;F5I9V4@
M=&%R9"!E;B!J;W5R;NEE`$AA=71E=7(@9&4@;F5I9V6@.B``475A;G1I=.D@
M9"=E874@Z7%U:79A;&5N=&4@X"!L82!Q=6%N=&ETZ2!D92!N96EG9:`Z(`#.
M;&5S(%-A;&]M;VX`4V]M86QI90!#:&%N<V]N<R!E="!P;^AM97,`4^EL96-T
M:6]N(&1E(&PG;W)D<F4@9&4@=')I`$%D<F5S<V4@<V]U<F-E`$%F<FEQ=64@
M9'4@<W5D`%-U9"UE=7)O<.EE;B`H25-/+3@X-3DM,RD`1^EO<F=I92UD=2US
M=60@970@[FQE<R!386YD=VEC:"UD=2US=60`2.EM:7-P:.AR92!3=60`17-P
M86-E(&5N=')E(&-E;&QU;&5S(&%D:F%C96YT97,`17-P86-E(&5N=')E(&QE
M(&-O;G1E;G4@970@;&$@8F]R9'5R92!D86YS('5N92!C96QL=6QE`$5S<&%C
M975R`$5S<&%C96UE;G0`17-P86-E;65N="!E="!R96UP;&ES<V%G90!%<W!A
M9VYE`%!O=7)R:65L`$-A<F%C=.AR97,@<W#I8VEA=7@`4V-I;F1E<B!L82!C
M96QL=6QE`%-C:6YD97(@;&$@8V]L;VYN90!38VEN9&5R(&QA(')A;F?I90!3
M<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!!;F[I92!D92!D
MZ6)U=`#)=&%T(&]U('!R;W9I;F-E`%-T871U=`!!<G)E=&5R(&QA(';I<FEF
M:6-A=&EO;B!L;W)S<75E(&QA('+H9VQE(&-O<G)E<W!O;F0_`$9O<FUA="!D
M92!S875V96=A<F1E`%)U90!"87)RZ0!,:7-T92!D92!C:&'N;F5S`%)E=&ER
M97(@;&4@9&]M86EN92!D92!L)V%D<F5S<V4`4W1Y;&4@6T-34UT`1&D`4V]U
M<RURZ7!E<G1O:7)E(*N@)7.@NR!N;VX@=')O=7;I`%-U:F5?="!D=2!M97-S
M86=E(&0G86)S96YC93H`4W5J970`16YV;VD`3&$@9&5M86YD92!D)V%J;W5T
M(&1E(*N@)7.@NR!A=2!S>7-TZ&UE(&$@Z73I('-O=6UI<V4N(%9O=7,@;F4@
M<&]U<G)E>B!P87,@=F]U<R!C;VYN96-T97(@:G5S<74GX"!S;VX@87!P<F]B
M871I;VXN`$EN9&EC90!3=6-CZ',`JZ`E<Z"[(&$@8FEE;B#I=.D@86IO=73I
M*&4I+@!,97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R(*N@)7.@NR!O;G0@
M8FEE;B#I=.D@<F5T:7+I97,@9'4@<WES=.AM92XN`*N@)7.@NR!A(&)I96X@
MZ73I('-U<'!R:6WI*&4I+@"KH"5SH+L@82!B:65N(.ETZ2!R971I<NDH92DN
M`%)E=&]U<B#@(&QA(&-O;F9I9W5R871I;VX@:6YI=&EA;&4@<NEU<W-I+B`@
M4F%F<F'N8VAI<B!L82!P86=E('!O=7(@=F]I<B!L97,@;6]D:69I8V%T:6]N
M<RX`16YR96=I<W1R96UE;G0@9&4@;&$@8V]N9FEG=7)A=&EO;B!D92!L82!S
M875V96=A<F1E('+I=7-S:2X`16YR96=I<W1R96UE;G0@<NEU<W-I(&1E(&QA
M(&-O<&EE(&1E('-A=79E9V%R9&4@9'4@9FEC:&EE<B!D92!C;VYF:6=U<F%T
M:6]N("5S+@"KH"5SH+L@82!B:65N(.ETZ2!M:7,H92D@X"!J;W5R+@#)8W)I
M='5R92!D92`E<R!RZ75S<VD`4V]U9&%N`%-O;6UA:7)E`$QE=F5R(&1U(%-O
M;&5I;`!#;W5C:&5R(&1U(%-O;&5I;`!%;G-O;&5I;&SI`$QE=F5R(&1U(%-O
M;&5I;`!,979E<B]#;W5C:&5R(&1U(%-O;&5I;`!,979E<B!D=2!3;VQE:6PZ
M(`!#;W5C:&5R(&1U(%-O;&5I;`!#;W5C:&5R(&1U(%-O;&5I;*`Z(`!%>'!O
M<V%N=`!!<W-I<W1A;F-E`%-U<FEN86T@;W4@1W5Y86YE(&AO;&QA;F1A:7-E
M`$YO;2!D92!F86UI;&QE`,YL97,@4W9A;&)A<F0@970@2F%N($UA>65N`%-W
M87II;&%N9`!3=>AD90!3=6ES<V4`2F]U<FYA;"!D92!S>6YC:')O;FES871I
M;VX@<W5P<')I;>D`4WEN8TU,`$5R<F5U<B!D92!S>6YT87AE(&1A;G,@;&5S
M('1E<FUE<R!D92!R96-H97)C:&4`4WER:64`3W)A9V5S`$]R86=E(&5T('9E
M;G0`3W)A9V5S`$]R86=E<R!M871I;F%U>`!&:6-H:65R(%135@!486)L96%U
M`%!R;W!R:>ETZ7,@9'4@=&%B;&5A=0!486)L96%U(&1E('9A;&5U<G,`4')O
M<')IZ73I<R!D=2!T86)L96%U`%1A[W=A;@!48>]W86XL('!R;W9I;F-E(&1E
M($-H:6YE`%1A:FEK:7-T86X`5&%N>F%N:64`0VEB;&6@.@!4XF-H97,`3G5M
MZ7)O(&1E('3I;.EP:&]N90!496UPZ7)A='5R92!P;W5R(&QA(&1E<FYIZ')E
M(&AE=7)EH#H@`%1E;7#I<F%T=7)E`%1E;7#I<F%T=7)EH#H@`%1E;7#I<F%T
M=7)E/&)R("\^*"5S2&$E<R\E<T)A)7,I("9D96<[)7,`4')O9FEL(*N@)7.@
MNR!N;VX@=')O=7;I`$%D;6EN:7-T<F%T:6]N(&1E<R!M;V3H;&5S`%1E>'1E
M`%1E>'1E('-E=6P`06QI9VYE;65N="!D=2!T97AT90!497AT92!E;B!H875T
M`$IE`%1H8>\@*%1)4RTV,C`I`%1H8>]L86YD90!,)V5X=&5N<VEO;B!&5%`@
M;B=E<W0@<&%S(&1I<W!O;FEB;&4N`$QE(&UO=&5U<B!D)VEN=.EG<F%T:6]N
M($AO<F1E+TMO;&%B(&YE('-U<'!O<G1E('!A<R"KH"5SH+L`3&4@:F]U<FYA
M;"!)35-0(&XG82!P87,@<'4@ZG1R92!I;FET:6%L:7/I+@!,82!C;&%S<V4@
M36%I;G1E;F%N8V4Z.B!N)V$@<&%S(.ETZ2!C:&%R9^EE(&-O<G)E8W1E;65N
M=`!,82!F96[J=')E(&1E<R!O<'1I;VYS(',G97-T(&9E<FWI92X@4V]R=&EE
M+@!,)V%D;6EN:7-T<F%T975R(&1O:70@8V]N9FEG=7)E<B!U;B!B86-K96YD
M('!E<FUA;F5N="!P;W5R(&QE<R!P97)M:7-S:6]N<R!S:2!V;W5S('9O=6QE
M>B!L97,@96UP;&]Y97(N`$QA(&)O<F1U<F4@9'4@8F%S('-E=6QE;65N=`!,
M)TE$(&1U(&-O;G1A8W0@;B=A('!A<R#I=.D@<W#I8VEF:>DL(&QA:7-SZ2!V
M:61E(&]U(&XG82!P87,@Z73I('1R;W5VZ2!D86YS(&QA(&)A<V4@9&4@9&]N
M;NEE<RX`0V4@8V]N=&%C="!A(&)I96X@Z73I(&%J;W5TZ2#@('9O=')E(&-A
M<FYE="!D)V%D<F5S<V5S+B``3&4@8FQO8R!D92!S:6=N871U<F4@4$=0('/I
M<&%RZ2!E<W0@;NEC97-S86ER92!P;W5R(';I<FEF:65R(&QA('-I9VYA='5R
M92X`3"=)1"!D92!L82!L:7-T92!N)V$@<&%S(.ETZ2!S<.EC:69IZ2P@;&%I
M<W/I('9I9&4@;W4@;F]N('1R;W5VZ2!D86YS(&QA(&)A<V4@9&4@9&]N;NEE
M<RX`3&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N(&XG82!P87,@Z73I('-PZ6-I
M9FGI92X`365S<V%G92!D=2!P:6QO=&4@*&1R:79E<BDZ(`!,92!C:&EF9G)E
M;65N="!NZ6-E<W-I=&4@=6YE(&-O;FYE>&EO;B!SZ6-U<FESZ64N`$QE(&9I
M8VAI97(@)7,@9&]I="!C;VYT96YI<B!L97,@;W!T:6]N<R`E<RX`3&4@9FEC
M:&EE<B`E<R!D;VET(&-O;G1E;FER(&-E<G1A:6YE<R!O<'1I;VYS("5S+@!,
M92!F:6-H:65R(&YE('!E=70@<&%S(.IT<F4@8V]P:>D@<W5R(&QU:2UMZFUE
M+@!,92!F:6-H:65R(&YE(&-O;G1E;F%I="!A=6-U;F4@9&]N;NEE+@!#92!Q
M=6D@<W5I="!S;VYT(&QE<R!E;BUTZG1E<R!P;W5R(&-E(&UE<W-A9V4@;65S
M<V%G92]21D,X,C(N`$QE(&UO9&4@<&QE:6X@Z6-R86X@8V%U<V4@9&5S('!R
M;V)LZ&UE<R!A=F5C($EN=&5R;F5T($5X<&QO<F5R(&3[(.`@9&5S(&)O9W5E
M<R!D=2!N879I9V%T975R('%U:2!N)V]N="!P=2#J=')E(&-O;G1O=7)NZ7,N
M(%9O=7,@<&]U=F5Z(.IT<F4@8V]N9G)O;G3I<R#@(&1E(&PG869F:6-H86=E
M(&1E(&-A<F%C=.AR97,@Z71R86YG97,L(&%U(&YO;BUF;VYC=&EO;FYE;65N
M="!D97,@8V5R=&%I;F5S(&9O;F-T:6]N<R!E="]O=2!A=2!P;&%N=&%G92!A
M;.EA=&]I<F4@9'4@;F%V:6=A=&5U<BX@4VD@=F]T<F4@<WES=.AM92!E<W0@
M=6X@5VEN9&]W<R`Y>"P@:6P@97-T('1RZ',@<&]S<VEB;&4@<75E('9O=7,@
M875R97H@=6YE("=&875T92!GZ6[I<F%L92!D92!P<F]T96-T:6]N)R!E="!Q
M=64@=F]U<R!D979R97H@<F5DZ6UA<G)E<B!V;W1R92!O<F1I;F%T975R+EQN
M7&Y6;W5S(&%V97H@Z73I('!RZ79E;G5S+B!35E`@87!P=7EE>B!S=7(@3TL@
M<VD@=F]U<R!V;W5L97H@=&]U:F]U<G,@97-S87EE<B!L92!M;V1E('!L96EN
M(.EC<F%N(&1E(&PGZ61I=&5U<@!,)VED96YT:73I(*N@)7.@NR`@82#I=.D@
M<W5P<')I;>EE+@!,92!C]'3I(&=A=6-H92!S975L96UE;G0`3"=E;7!L86-E
M;65N="!D=2!P<F]G<F%M;64@1VYU4$<@9&]I="#J=')E(&9O=7)N:2#@(&QA
M(&-L87-S92!#<GEP=%]P9W`Z.BX`3&4@;65S<V%G92!E;G9O>>D@;&4@)7,@
MX"`E<R!A=F5C(&-O;6UE('-U:F5T(*N@)7.@NR!A(.ETZ2!A9F9I8VCI+B`*
M26P@;B=Y(&$@875C=6YE(&=A<F%N=&EE('%U92!C92!M97-S86=E(&$@Z73I
M(&QU(&]U(&-O;7!R:7,N`$QE(&YO;2#@('5T:6QI<V5R(&5N(&QI86YT(.`@
M;&$@<&%G92!D92!C;VUP;W-I=&EO;@!,92!N;VUB<F4@9&4@8VAA;7!S(&1O
M:70@ZG1R92!U;B!N;VUB<F4@=F%L:61E+@!,92!M;V1U;&4@3W!E;E-33"!E
M<W0@<F5Q=6ES('!O=7(@;&$@8VQA<W-E($AO<F1E7T-R>7!T7W-M:6UE.CHN
M`$QA('!RZ6;I<F5N8V4@JZ`E<Z"[(&XG82!P87,@<'4@ZG1R92!E;G)E9VES
M='+I92!C87(@<V$@=&%I;&QE(&3I<&%S<V4@;&4@;6%X:6UU;2!A=71O<FES
MZ0!,92!P<F]G<F%M;64@=71I;&ESZ2!P;W5R('9I<W5A;&ES97(@8V4@='EP
M92!D92!D;VYNZ65S("@E<RD@;B=A('!A<R#I=.D@=')O=7;I+@!,92!C87)A
M8W3H<F4@9&4@<')O=&5C=&EO;B!D;VET(.IT<F4@=6X@8V%R86-TZ')E('5N
M:7%U92X`3&5S(&/T=.ES(&=A=6-H92!E="!D<F]I="!S975L96UE;G0`3&4@
M8_1TZ2!D<F]I="!S975L96UE;G0`3&4@<^EP87)A=&5U<B!D;VET(.IT<F4@
M=6X@8V%R86-TZ')E('5N:7%U92X`3&4@<V5R=F5U<B"KH"5SH+L@82#I=.D@
M<W5P<')I;>DN`$QE('-E<G9E=7(@JZ`E<Z"[(&$@Z73I(&5N<F5G:7-T<NDN
M`$QA(')E<77J=&4@9"=E;G)E9VES=')E;65N="!P;W5R("5S(&$@Z73I(&3I
M<&QA8^EE+@!,82!L:6=N92!D96UA;F3I92!N)V5X:7-T92!P87,N`$QE(&9I
M8VAI97(@=&5M<&]R86ER92"K("5SH+L@;B=E>&ES=&4@<&%S+@!,92!T97AT
M92!E;G1RZ2!N92!C;W)R97-P;VYD('!A<R!A=2!T97AT92!S=7(@;"?I8W)A
M;BX`3&4@:&%U="!E="!L92!B87,@<V5U;&5M96YT`$QE(&AA=70@<V5U;&5M
M96YT`$QE<R!D;VYNZ65S('3I;.EC:&%R9^EE<R!V97)S(&QE('-E<G9E=7(@
M;VYT(.ETZ2!P97)D=65S(&1E<'5I<R!L)^ET87!E('!RZ6/I9&5N=&4N(`!,
M92!F:6-H:65R(.EM:7,@;B=A('!A<R!P=2#J=')E(&5N<F5G:7-T<NDN`$QE
M(&)L;V,@JZ!W96%T:&5R+F-O;:"[(&XG97-T('!A<R!D:7-P;VYI8FQE+@!2
MZ7!E<G1O:7)E(&1E<R!T:.AM97,@JZ`E<Z"[(&YO;B!T<F]U=ND`26P@;B=Y
M(&$@<&%S(&0G;W!T:6]N<R!D:7-P;VYI8FQE<P!!=6-U;F4@<&%R=&EE(&YE
M('!E=70@ZG1R92!A9F9I8VCI92!E;B!L:6=N92X`26P@>2`@82!T<F]P(&1E
M(&-A<F%C=.AR97,@9&%N<R!C92!C:&%M<"X@5F]U<R!E;B!A=F5Z(&5N='+I
M("5SH#L@:6P@96X@9F%U="!M;VEN<R!D92`E<RX`56X@<')O8FSH;64@97-T
M(&%P<&%R=2!L;W)S(&1E(&PG86IO=70@9&4@JZ`E<Z"[H#H@)7,`56X@<')O
M8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E<R!D
M;VYNZ65S(&1E(&PG=71I;&ES871E=7(@JZ`E<Z"[H#H@`%5N('!R;V)LZ&UE
M(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D92"KH"5SH+N@
M.B``56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA(&UI<V4@X"!J
M;W5R(&1E(*N@)7.@NZ`Z("5S`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R
M<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!A=6-U;B`E<R!N)V$@Z73I('1R
M86YS;6ES+@!5;F4@97)R975R(&5S="!S=7)V96YU92!L;W)S(&1E(&PG96YV
M;VD@9'4@9FEC:&EE<J`Z(&QE("5S(.ET86ET('!L=7,@9W)O<R!Q=64@;&4@
M;6%X:6UU;2!A=71O<FESZ2`H)60@;V-T971S*2X`56YE(&5R<F5U<B!E<W0@
M<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!L92`E<R!A
M(.ETZ2!T<F%N<VUI<R!P87)T:65L;&5M96YT+@!5;F4@97)R975R(',G97-T
M('!R;V1U:71E(&QO<G,@9&4@;"=A8W1I=F%T:6]N(&1U('-C<FEP="X`56YE
M(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&QA(&3I<V%C=&EV871I
M;VX@9'4@<V-R:7!T+@!5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@
M9&4@;"=A9F9I8VAA9V4@9&4@8V5T=&4@<&%R=&4@9'4@;65S<V%G90!5;F4@
M97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D
M97,@9&]N;NEE<R!D92!C92!C;VYT86-T+@!5;F4@97)R975R(',G97-T('!R
M;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D92!C971T92!C87)T92!I
M0V%L96YD87(N`$EL('D@879A:70@=6YE(&5R<F5U<B!D86YS(&QE(&9O<FUU
M;&%I<F4@9&4@8V]N9FEG=7)A=&EO;BX@4&5U="WJ=')E(&%V97HM=F]U<R!L
M86ES<^D@=6X@8VAA;7`@<F5Q=6ES('9I9&4N`%5N92!E<G)E=7(@<R=E<W0@
M<')O9'5I=&4@;&]R<R!D92!L)V5XZ6-U=&EO;B!D92!C971T92!F;VYC=&EO
M;B!D=2!C87)N970@9"=A9')E<W-E+B!35E`@97-S87EE<B#@(&YO=79E874@
M<&QU<R!T87)D+@!);"!Y(&$@974@=6YE(&5R<F5U<B!L;W)S(&1E(&QA(&UI
M<V4@X"!J;W5R(&1E<R!I;F9O<FUA=&EO;G,@<W5R(&QE(&-O;G1A8W0N("!6
M975I;&QE>B!E<W-A>65R(.`@;F]U=F5A=2X`26P@>2!A(&5U('5N92!E<G)E
M=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D92!L82!L:7-T92!D92!D:7-T
M<FEB=71I;VXN("!6975I;&QE>B!E<W-A>65R(&1E(&YO=79E874N`$QE('!R
MZ7-E;G0@<V5R=F5U<B!)34%0(&YE('-U<'!O<G1E('!A<R!L92!P87)T86=E
M(&1E(&1O<W-I97)S+@#'82!N92!S96UB;&4@<&%S(.IT<F4@=6YE(&%R8VAI
M=F4@4D%2('9A;&ED92X`QV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&9I8VAI
M97(@6DE0('9A;&ED92X`QV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&YU;>ER
M;R!D92!C87)T92!V86QI9&4N`$-E('!I;&]T92!P97)M970@;"=E;G9O:2!D
M92!M97-S86=E<R#@('1R879E<G,@;&$@<&%S<V5R96QL92!#;&EC:V%T96QL
M("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&5N('5T:6QI<V%N="!L)T%022!(
M5%10`$-E('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R!V:6$@
M;&$@<&%S<V5R96QL92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!E;B!U=&EL
M:7-A;G0@;"=!4$D@2%144`!#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@
M;65S<V%G97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@<VUS,F5M86EL("AH
M='1P.B\O<VUS,F5M86EL+F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%``
M0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('!A<B!33510
M(.`@=')A=F5R<R!L82!P87-S97)E;&QE(%9O9&%F;VYE($ET86QI92P@<V5U
M;&5M96YT(&%U>"!N=6WI<F]S(%9O9&%F;VYE+B!#96QA(&[I8V5S<VET92!U
M;B!C;VUP=&4@9&4@8V]U<G)I96P@5F]D869O;F4@271A;&EE("AH='1P.B\O
M=W=W+C$Y,"YI="DN`$-E(&-H86UP(&5S="!O8FQI9V%T;VER92X`0V4@8VAA
M;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S(&5N=&EE<G,N`$-E(&-H86UP
M(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E<R!N;VUB<F5S(&5T(&QE<R!D975X
M+7!O:6YT<RX`0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S('9A
M;&5U<G,@;V-T86QE<RX`0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U;F4@;&ES
M=&4@9"=E;G1I97)S('/I<&%RZ7,@<&%R(&1E<R!V:7)G=6QE<R!O=2!D97,@
M97-P86-E<P!#92!C:&%M<"!D;VET(.IT<F4@=6X@;F]M8G)E('9A;&ED92X`
M0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U;B!C;V1E(&1E(&-O=6QE=7(@874@
M9F]R;6%T(%)'0B!H97AA9.EC:6UA;"P@<&%R(&5X96UP;&4@)R,Q,C,T868G
M+@!#92!F;W)M=6QA:7)E(&$@9.EJX"#I=.D@=')A:73I+@!#)V5S="`E<RX`
M0V5C:2!E<W0@=6X@;V)J970@2V]L86(@1W)O=7!W87)E+B!0;W5R('9O:7(@
M8V5T(&]B:F5T+"!V;W5S(&1E=G)E>B!A=F]I<B!U;B!C;&EE;G0@9&4@8V]U
M<G)I96P@<75I(&-O;7!R96YD(&QE(&9O<FUA="!+;VQA8B!'<F]U<'=A<F4N
M(%!O=7(@=6YE(&QI<W1E(&1E(&-E<R!C;&EE;G1S(&1E(&-O=7)R:65L+"!V
M:7-I=&5Z("5S`$-E(&UE<W-A9V4@82#I=.D@Z6-R:70@9&%N<R!U;B!C;V1E
M(&1E(&-A<F%C=.AR97,@*"5S*2!A=71R92!Q=64@;&4@=O1T<F4N`$-E(&YO
M;6)R92!D;VET(.IT<F4@<W5PZ7)I975R(.`@=6XN`$-E('-E<G9E=7(@;F4@
M<&5U="!P87,@9.EC;VUP<F5S<V5R(&QE<R!F:6-H:65R<R!:25`@970@9WII
M<"X`0V4@<WES=.AM92!E<W0@<'+I<V5N=&5M96YT(&3I<V%C=&EVZ2X`0V5T
M=&4@=F%L975R(&1O:70@ZG1R92!U;B!N;VUB<F4N`$-E='1E(&9E;NIT<F4@
M9&]I="#J=')E(&%P<&5LZ64@9&5P=6ES('5N92!F96[J=')E(&1E<R!O<'1I
M;VYS`%1O;FYE<G)E`%1I8VME=',`2&5U<F4`4W5I=FD@:&]R86ER90!&;W)M
M870@9"=H975R90!3Z6QE8W1I;VX@9&4@;"=H975R90!4:6UO<B!O<FEE;G1A
M;`!4:71R90!4:71R92`H:6YF;V)U;&QE*:`Z`.``4&]U<B!SZ6QE8W1I;VYN
M97(@<&QU<VEE=7)S(&ET96US(.`@;&$@9F]I<RP@;6%I;G1E;F5Z(&5N9F]N
M8^D@;&4@8F]U=&]N(*N@0W1R;*"[("A00RD@;W4@JZ!#;VUM86YD9:"[("A-
M86,I(&5N(&-L:7%U86YT+@!!=6IO=7)D)VAU:0!6;VER(&QA('-O=7)C92!(
M5$U,`%1O9V\`5&]K96QA=0!$96UA:6X`5&]N9V$`2&%U=`!#861R92!D=2!H
M875T("A?=&]P*0!4<F%D=6-T:6]N<P!4<FEN:73I+65T+51O8F%G;P!6<F%I
M(&]U(&9A=7@`36$`5'5N:7-I90!4=7)Q=6EE`%1U<F,@*$E33RTX.#4Y+3DI
M`%1U<FMMZ6YI<W1A;@#.;&5S(%1U<G%U97,@970@0V'O<75E<P!4=79A;'4`
M16YT<F5Z('9O=')E(&-H;VEXH#H@`$EN9&EC92!55J`Z(`!54DP`55),('!O
M=7(@=F]T<F4@<F%P<&]R="!D92!L:79R86ES;VX@9'4@<V-R:7!T`%523#H`
M3W5G86YD80!5:W)A:6YE`$EM<&]S<VEB;&4@9"=A='1E:6YD<F4@;&4@<NEP
M97)T;VER92!61E,N`$EM<&]S<VEB;&4@9"=A:F]U=&5R(&1E<R!I;F9O<FUA
M=&EO;G,@8V]M<&SI;65N=&%I<F5S(.`@;"=I;G-C<FEP=&EO;BX`26UP;W-S
M:6)L92!D92!M;V1I9FEE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!L92!F:6-H
M:65R(%9&4R"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@;6]D:69I97(@;&5S('!E
M<FUI<W-I;VYS('!O=7(@;&4@9FEC:&EE<B!61E,@)7,O)7,N`$EM<&]S<VEB
M;&4@9&4@8VAA;F=E<B!P;W5R("5S+@!);7!O<W-I8FQE(&1E(';I<FEF:65R
M(&QA('1A:6QL92!D=2!F:6-H:65R(&1E(*N@)7.@NRX`26UP;W-S:6)L92!D
M92!VZ7)I9FEE<B!L82!T86EL;&4@9'4@9FEC:&EE<B!D92"K("5S+R5S(+LN
M`$-O;FYE>&EO;B!I;7!O<W-I8FQE(&%U('-E<G9E=7(@4U%,+@!#;VYN97AI
M;VX@:6UP;W-S:6)L92!E;B!34TP`26UP;W-S:6)L92!D92!C;W!I97(@=6X@
M9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@9&4@8W+I97(@=6X@<NEP97)T;VER
M92!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(&-RZ65R('5N('+I<&5R=&]I
M<F4@5D93+@!);7!O<W-I8FQE(&1E(&-RZ65R(&QE(&9I8VAI97(@5D93+@!)
M;7!O<W-I8FQE(&1E(&-RZ65R(&QE('+I<&5R=&]I<F4@5D93(*N@)7.@NRX`
M26UP;W-S:6)L92!D92!C<NEE<B!U;B!F:6-H:65R(%9&4R!V:61E+B``3W5V
M97)T=7)E(&EM<&]S<VEB;&4@9&4@;"=A<F-H:79E(&-O;7!R97-SZ64N(`!3
M=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E(*N@)7.@NRP@;&4@9&]S<VEE<B!N
M)V5S="!P87,@=FED92X`4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92"KH"5S
MH+N@.B`E<RX`4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92`E<RP@;&4@9&]S
M<VEE<B!N)V5S="!P87,@=FED90!3=7!P<F5S<VEO;B!RZ6-U<G-I=F4@9'4@
M9&]S<VEE<B!61E,@:6UP;W-S:6)L92X`4W5P<')E<W-I;VX@9'4@<NEP97)T
M;VER92!61E,@:6UP;W-S:6)L92X`26UP;W-S:6)L92!D92!S=7!P<FEM97(@
M;&4@<NEP97)T;VER92!61E.@.B`E<RX`4W5P<')E<W-I;VX@:6UP;W-S:6)L
M92!D=2!F:6-H:65R(%9&4R"KH"5SH+LN`%-U<'!R97-S:6]N(&EM<&]S<VEB
M;&4@9'4@9FEC:&EE<B!61E,N`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@
M<NEP97)T;VER92!61E,@JZ`E<Z"[+@!3=7!P<F5S<VEO;B!61E,@<NEC=7)S
M:79E(&EM<&]S<VEB;&6@.B`E<RX`26UP;W-S:6)L92!D92!DZ71E<FUI;F5R
M(&QE(&1O<W-I97(@8V]U<F%N="X`26UP;W-S:6)L92!D)V5X=')A:7)E(&QE
M<R!DZ71A:6QS(&1U(&-E<G1I9FEC870`26UP;W-S:6)L92!D92!C:&%R9V5R
M(&QA(&3I9FEN:71I;VX@9&4@)7,N`$EM<&]S<VEB;&4@9&4@9.EP;&%C97(@
M;&4@9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@9"=O=79R:7(@;&4@9FEC:&EE
M<B!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE(&0G;W5V<FER('5N(&9I8VAI97(@
M5D93(&5N(.EC<FET=7)E+@!);7!O<W-I8FQE(&0G;W5V<FER('5N(&9I8VAI
M97(@5D93+@!/=79E<G1U<F4@:6UP;W-S:6)L92!D92!L)V%R8VAI=F4@8V]M
M<')E<W/I92X`26UP;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97(@5D93("CI
M8VAE8R!D92!F:6QE<VEZ92@I*2X`26UP;W-S:6)L92!D92!L:7)E(&QE(&9I
M8VAI97(@5D93("CI8VAE8R!D92!G971&:6QE4VEZ92@I*2X`26UP;W-S:6)L
M92!D92!L:7)E(&QE(&9I8VAI97*@.B``3&5C='5R92!D=2!RZ7!E<G1O:7)E
M(')A8VEN92!61E,@:6UP;W-S:6)L92X`26UP;W-S:6)L92!D92!R96YO;6UE
M<B`E<R!E;B`E<Z`Z(&QE(&1O<W-I97(@8VEB;&4@97AI<W1E(&3I:N``26UP
M;W-S:6)L92!D92!R96YO;6UE<B!L92!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S
M:6)L92!D92!R96YO;6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z("5S+@!);7!O
M<W-I8FQE(&1E(')E;F]M;65R(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP
M;W-S:6)L92!D92!R96YO;6UE<B!L92!F:6-H:65R(%9&4R`E<R\E<RX`26UP
M;W-S:6)L92!D92!R96YO;6UE<B!L92!F:6-H:65R(%9&4RX`26UP;W-S:6)L
M92!D)V5XZ6-U=&5R("=M:VES;V9S)RX`26UP;W-S:6)L92!D92!T<F%D=6ER
M92!C92!D;V-U;65N="!7;W)D+@!);7!O<W-I8FQE(&0GZ6-R:7)E(&QE(&9I
M8VAI97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D)^EC<FER92!L97,@9&]N
M;NEE<R!D=2!F:6-H:65R(%9&4R`H8V]P>2@I(&EM<&]S<VEB;&4I+@!);7!O
M<W-I8FQE(&0GZ6-R:7)E(&QE<R!D;VYNZ65S(&1U(&9I8VAI97(@5D93+@!)
M;7!O<W-I8FQE(&0GZ6-R:7)E(&QE(&9I8VAI97(@5D93+"!L92!Q=6]T82!S
M97)A:70@9.EP87-SZ2X`4V]U;&EG;F5R`$%N;G5L97(@;&5S(&-H86YG96UE
M;G1S`$%N;G5L92!V;W1R92!D97)N:>AR92!A8W1I;VX`4NEP;VYS92!I;F%T
M=&5N9'5E(&1U('-E<G9E=7(@;&]R<R!D92!L82!C;VYN97AI;VZ@.B``4NEP
M;VYS92!I;F%T=&5N9'5E(&1U('-E<G9E=7(@X*`Z(`!(;W)S(&-A=.EG;W)I
M90!5;FEC;V1E("A55$8M."D`R6UI<F%T<R!!<F%B97,@56YI<P!2;WEA=6UE
M+55N:0#)=&%T<RU5;FES`,YL97,@97ATZ7)I975R97,@9&5S(,ET871S+55N
M:7,`56YI=.ES`$EN8V]N;G4`87!I;7-G:60@:6YC;VYN=2`H05!)($UE<W-A
M9V4@240I+@!C;&EM<V=I9"!I;F-O;FYU("A#;&EE;G0@365S<V%G92!)1"DN
M`$5M<&QA8V5M96YT('/I;&5C=&EO;F[I(&EN8V]N;G4N`$YO;2!D)W5T:6QI
M<V%T975R(&]U(&UO="!D92!P87-S92!I;F-O;FYU+@!$Z6QI97(@;"?I;.EM
M96YT(&-O=7)A;G0`4V%N<R!N;VT`3&5S('-C<FEP=',@;F]N+7!R:79I;.EG
M:>ES(&YE('!E=79E;G0@86-CZ61E<B!A=7@@9F]N8W1I;VYS(&-O=7!E<B]C
M;W!I97(O8V]L;&5R('!O=7(@9&5S(')A:7-O;G,@9&4@<^EC=7)I=.DN($%P
M<'5Y97H@<W5R($]+('!O=7(@=F]I<B!U;F4@;F]T92!T96-H;FEQ=64@<W5R
M(&UO>FEL;&$N;W)G('%U:2!V;W5S(&5X<&QI<75E<F$@8V]M;65N="!A=71O
M<FES97(@=6X@<V-R:7!T(.`@=71I;&ES97(@;&4@<')E<W-E+7!A<&EE<G,`
M4F5M971T<F4@;&$@8V]U;&5U<B#@('KI<F\`17AT96YS:6]N(&YO;B!P<FES
M92!E;B!C;VUP=&4`36]D:69I97(`36]D:69I97(@)7,`36]D:69I97(@;"=U
M=&EL:7-A=&5U<@!-:7-E(.`@:F]U<B!D92"KH"5SH+LN`$QE('-C<FEP="!D
M92!M:7-E(.`@:F]U<B!E<W0@<W5P<')I;>D`0VAA<F=E<@!4;W5S(&QE<R!F
M:6-H:65R<R!D92!C;VYF:6=U<F%T:6]N(&1E<R!A<'!L:6-A=&EO;G,@;VYT
M(.ETZ2!E;G9O>>ES('-U<B!L92!S97)V975R+@!,971T<F5S(&QA=&EN97,@
M;6%J=7-C=6QE<P!.;VUB<F5S(')O;6%I;G,@;6%J=7-C=6QE<P!5<G5G=6%Y
M`$5M<&QO>>D@86-T=65L;&5M96YTH#H@)7,`571I;&ES97(@4U-,`%5T:6QI
M<V5R('-I(&QE(&YO;2!D)W5T:6QI<V%T975R+VUO="!D92!P87-S92!E<W0@
M9&EF9NER96YT(&1U('-E<G9E=7(@24U34"X`571I;&ES871E=7(`3"=U=&EL
M:7-A=&5U<B`E<R!N)V$@<&%S(&PG875T;W)I<V%T:6]N('!O=7(@)7,N`$%D
M;6EN:7-T<F%T:6]N(&1E<R!U=&EL:7-A=&5U<G,`4'+I9NER96YC97,@<&5R
M<V]N;F5L;&5S`$5N<F5G:7-T<F5M96YT(&1E<R!U=&EL:7-A=&5U<G,`3"=E
M;G)E9VES=')E;65N="!D)W5T:6QI<V%T975R(&5S="!DZ7-A8W1I=ND@<W5R
M(&-E('-Y<W3H;64N`$-O;7!T92!U=&EL:7-A=&5U<B!N;VX@=')O=7;I`$YO
M;2!D)W5T:6QI<V%T975R`$QE(&YO;2!D92!C;VYN97AI;VX@JZ`E<Z"[(&5X
M:7-T92!DZ6K@+@!.;VT@9"=U=&EL:7-A=&5U<J`Z`$YO;2!D)W5T:6QI<V%T
M975RH#H@`%5T:6QI<V%T975R<R!DZ69I;FESH#H`3W5Z8NEK:7-T86X`4NEP
M97)T;VER92!61E,@:6YE>&ES=&%N="X`06)S96YC90#)9&ET97(@86)S96YC
M90!-97-S86=E(&0G86)S96YC90!!8G-E;F-E(&XG97-T('!A<R!S=7!P;W)T
MZ2!P87(@;&4@<&EL;W1E(&%C='5E;"X`3&5S(&5M<&QA8V5M96YT<R!V86QI
M9&5S('1R;W5VZ7,@:6YC;'5E;G2@.B``5F%L:61I=.D`5F%L975R(&5N(&UI
M;G5T97,@X"!P87)T:7(@9&4@;6%I;G1E;F%N="X`5F%L975R('-U<.ER:65U
M<F4@X"!L82!L;VYG=65U<B!M87AI;6%L92!D92`E<RX`5F%L975R<P!686QE
M=7)S(.`@<^EL96-T:6]N;F5R(&1E`%9A;G5A='4`5F%R:6%B;&4`5NENZ7IU
M96QA`,EC:&5C(&1E(&QA(';I<FEF:6-A=&EO;B`F;61A<V@[(&-E(&UE<W-A
M9V4@82!P975T+>IT<F4@Z73I(&9A;'-I9FGI+@!697)S:6]N`$-O;G1R]&QE
M(&1E('9E<G-I;VX`06QI9VYE;65N="!V97)T:6-A;`!296UP;&ES<V%G92!V
M97)T:6-A;`!697)T:6-A;*`Z`%1RZ',@:&%U=&4`5FEE=&YA;0!6:>IT+6YA
M;6EE;B`H5DE30TE)*0!6;VER("5S`%9O:7(@=6YE('!A9V4@=V5B(&5X=&5R
M;F4`5F]I<B!C;VUM92`E<P#.;&5S(%9I97)G97,@8G)I=&%N;FEQ=65S`,YL
M97,@5FEE<F=E<R!D97,@R71A=',M56YI<P!6:7-I8FEL:73I`%9I<VEB:6QI
M=.F@.B``5F]D869O;F4@271A;'D@=FEA(%--5%``3D]424-%`$%45$5.5$E/
M3B$A(2`@4U504%))3452($Q%(%-#4DE05"!-04Y514Q,14U%3E0@1$4@)7,`
M5TE.('9I82!(5%10`%=A;&QI<R!E="!&=71U;F$`071T96YT:6]N`$UE`%!R
MZ79I<VEO;G,@;>ETZ6\`1&]N;NEE<R!MZ73I;R!F;W5R;FEE<R!P87(`5V5A
M=&AE<BYC;VT`5V5B`%-I=&4@=V5B`$-H87%U92!S96UA:6YE`$)I96YV96YU
M90!":65N=F5N=64@X"`E<P!":65N=F5N=64L("5S`$]C8VED96YT86P@*$E3
M3RTX.#4Y+3$I`$]C8VED96YT86P@*$E33RTX.#4Y+3$U*0!386AA<F$@3V-C
M:61E;G1A;`!!9')E<W-E(&5N(&Q?:7-T92!B;&%N8VAE`%%U96QL92!A<'!L
M:6-A=&EO;B`E<R!D;VET+6EL('!RZ7-E;G1E<B!A<'+H<R!L82!C;VYN97AI
M;VZ@/P!1=65L(&5S="!L92!C87)A8W3H<F4@9&4@<^EP87)A=&EO;J`_`%%U
M96P@97-T(&QE(&-A<F%C=.AR92!D92!C:71A=&EO;J`_`$-A<G1E(%=H97)E
M:7,@075S=')A;&EE`%%U96QL97,@<&AA<V5S`%%U96QL97,@97AT96YS:6]N
M<R!A8W1I=F5R('!O=7(@;"?I9&ET975R(%)I8V@@5&5X="X`3&ES=&4@8FQA
M;F-H90#)9&ET97(@3&ES=&4@8FQA;F-H90!,:7-T92!B;&%N8VAE(&XG97-T
M('!A<R!S=7!P;W)TZ64@<&%S(&QE('!RZ7-E;G0@9FEL=')E+@!!9')E<W-E
M(&5N(&QI<W1E(&)L86YC:&4`3&%R9V5U<@!,87)G975R(&5N('5N:73I<R!#
M4U,`3&%R9V5U<B!D=2!M96YU(&1E(&=A=6-H92`E<R`@*&QA(&-O;F9I9W5R
M871I;VX@<')E;F1R82!E9F9E="#@(&QA('!R;V-H86EN92!C;VYN97AI;VXI
MH#H`3&%R9V5U<B!D=2!T86)L96%U`%5N:73I(&1E(&QA<F=E=7(`3&%R9V5U
M<J`Z`%=I:VD`5F5N=`!696YT('3T="!L92!M871I;@!6:71E<W-E(&1U('9E
M;G0@96X@;B9O96QI9SMU9',`5F5N=*`Z`%9E;G2@.B``4V%G97-S90!,:7-T
M92!D92!V)F]E;&EG.W5X`%1R879A:6P`061R97-S92!P<F]F97-S:6]N;F5L
M;&4`5.ELZ7!H;VYE('!R;V9E<W-I;VYN96P`3F]M8G)E(&1E(&-H86UP<R!I
M;F-O<G)E8W0@X"!L82!L:6=N92`E9"X@)60@871T96YD=7,L("5D('1R;W5V
MZ7,N`$YO;6)R92!D92!C:&%M<',@:6YC;W)R96-T+B`E9"!A='1E;F1U<RP@
M)60@=')O=7;I<RX`1.EC86QA9V4@)60@:6YC;W)R96-T(&QO<G,@9&4@;&$@
M;&5C='5R92!D92!F:6-H:65R(%9&4RX`6"U0<FEO<FET>0!8+5)E9@!8+5-P
M86TM3&5V96P`4V-O<F4@9&4@<&]U<G)I96P@*%@M4W!A;2U38V]R92D`6"U3
M<&%M+5-T871U<P!#;VYT<F%I;G1E<R!B87-I<75E<R!8-3`Y=C,`571I;&ES
M871I;VX@9&4@8VSI(.ET96YD=64@6#4P.78S`$%U=')E(&YO;2!D=2!S=6IE
M="!8-3`Y=C,`261E;G1I9FEA;G0@9&4@8VSI(&1U('-U:F5T(%@U,#EV,P!%
M>'1E;G-I;VYS(%@U,#EV,P!!00!!04%!`$-A<G1E(*N@66%H;V^@(:"[`$%N
M;G5E;&QE;65N=`!9Z6UE;@!/=6D`3W5I+"!J)V%C8V5P=&4`5F]U<R#J=&5S
M(&5N(&UO9&4@JZ!497AT9:"[+B!5=&EL:7-E>B!L92!B;W5T;VX@6SP^72!P
M;W5R(')E=F5N:7(@874@;6]D92"KH%=94TE764>@NRX`5F]U<R!N)^IT97,@
M<&%S(&%U=&]R:7/I(.`@8W+I97(@<&QU<R!D92`E9"!B;&]C<RX`5F]U<R!N
M)^IT97,@<&%S(&%U=&AE;G1I9FGI+@!6;W5S(&YE('!O=79E>B!P87,@879O
M:7(@;&4@8V%R86-TZ')E(*M<NR!D86YS('9O=')E(&YO;2!C;VUP;&5T+@!6
M;W5S(&XG879E>B!P87,@<V%I<VD@=6YE(&%D<F5S<V4@Z6QE8W1R;VYI<75E
M('9A;&ED92X`5F]U<R!N)V%V97H@<&%S(&%S<V]C:>D@;&5S(&-H86UP<R!D
M=2!F:6-H:65R(&EM<&]R=.D@875X(&-H86UP<R!C;W)R97-P;VYD86YT<R!D
M86YS("5S+@!6;W5S(&%V97H@Z73I(&3I8V]N;F5C=.DN`%9O=7,@9&5V97H@
M:6YS8W)I<F4@=6X@;G5MZ7)O(&1E(&-E;&QU;&%I<F4@=F%L:61E+"!S975L
M<R!D97,@;F]M8G)E<R!E="!U;B"K*[L@;W!T:6]N;F5L('!O=7(@;&5S(&%P
M<&5L<R!I;G1E<FYA=&EO;F%U>"X`5F]U<R!N)V%V97H@<&%S('-A:7-I('5N
M92!E;G1RZ64@=F%L:61E+@!6;W5S(&1E=F5Z(&-O;F9I9W5R97(@=6X@8F%C
M:V5N9"!$871A5')E92!P;W5R('5T:6QI<V5R(&QE<R!I;G-C<FEP=&EO;G,`
M5F]U<R!D979E>B!C;VYF:6=U<F5R('5N(&UO9'5L92!61E,N`%9O=7,@9&5V
M97H@9.EC<FER92!L92!P<F]B;.AM92!A=F%N="!D92!N;W5S(&9A:7)E('!A
M<G9E;FER(&QE(')A<'!O<G0N`%9O=7,@9&5V97H@96YT<F5R('5N92!54DP@
M;_D@<&]I;G1E(&1E(&QI96XN`$EL(&9A=70@<^EL96-T:6]N;F5R('5N('-E
M<G9E=7(@X"!S=7!P<FEM97(N`%9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T
M:6QI<V%T975R(.`@<F5T:7)E<BX@`%9O=7,@9&5V97H@<W#I8VEF:65R('5N
M('5T:6QI<V%T975R(.`@<F5T:7)E<BX`5F]U<R!D979E>B!S<.EC:69I97(@
M874@;6]I;G,@=6YE(&%D<F5S<V4@9&4@8V]U<G)I96P@<&]U<B!Q=64@;&4@
M;65S<V%G92!D)V%B<V5N8V4@<V]I="!A8W1I=NDN`%9O=7,@9&5V97H@<W#I
M8VEF:65R('5N('5T:6QI<V%T975R(.`@86IO=71E<BX`5F]U<R!D979E>B!S
M<.EC:69I97(@;&4@;F]M(&1E(&PG=71I;&ES871E=7(@X"!M;V1I9FEE<BX`
M5F]U<R!D979E>B!I;F1I<75E<B!Q=65L;&4@86-T:6]N(&%C8V]M<&QI<BX`
M5F]U<R!D979E>B#I8W)I<F4@=6X@;F]M('!O=7(@;&$@;F]U=F5L;&4@8V%T
MZ6=O<FEE+@!6;W5S(&1E=F5Z(&9O=7)N:7(@=6X@;K`@9&4@=.ELZ7!H;VYE
M(&ET86QI96X`5F]T<F4@<V5S<VEO;B`E<R!A(&5X<&ERZ2X@5F5U:6QL97H@
M=F]U<R!R96-O;FYE8W1E<BX`5F]T<F4@861R97-S92!D92!C;W5R<FEE;`!6
M;W1R92!A9')E<W-E(&1E(&-O=7)R:65L(*L@1&4Z(+N@.@!6;W,@9&]N;NEE
M<R!P97)S;VYN96QL97,`5F]T<F4@861R97-S92!);G1E<FYE="!A(&-H86YG
MZ2!D97!U:7,@;"=O=79E<G1U<F4@9&4@=F]T<F4@<V5S<VEO;B`E<RX@(%!O
M=7(@=F]T<F4@<^EC=7)I=.DL('9O=7,@9&5V97H@=F]U<R!R96-O;FYE8W1E
M<BX`5F]T<F4@;F]M`%9O=')E(&UO9'5L92!D)V%U=&AE;G1I9FEC871I;VX@
M;F4@<W5P<&]R=&4@<&%S(&PG86IO=70@9"=U=&EL:7-A=&5U<G,L(%-I('9O
M=7,@<V]U:&%I=&5Z('5T:6QI<V5Z($AO<F1E('!O=7(@861M:6YI<W1R97(@
M;&5S(&-O;7!T97,@=71I;&ES871E=7)S+"!V;W5S(&1E=F5Z('5T:6QI<V5R
M('5N(&%U=')E(&UO9'5L92!D)V%U=&AE;G1I9FEC871I;VXN`%9O=')E(&UO
M9'5L92!D)V%U=&AE;G1I9FEC871I;VX@;B=E<W0@<&%S(&5N(&UE<W5R92!D
M)^ET86)L:7(@=6YE(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G,L(&]U(&-E='1E
M(&9O;F-T:6]N(&$@Z73I(')E=&ERZ64@<&]U<B!U;F4@875T<F4@<F%I<V]N
M+@!6;W1R92!N879I9V%T975R('-E;6)L92!A=F]I<B!C:&%N9^D@9&5P=6ES
M(&QE(&3I8G5T(&1E('9O=')E('-E<W-I;VX@)7,N("!0;W5R('9O=')E('/I
M8W5R:73I+"!V;W5S(&1E=F5Z('9O=7,@<F5C;VYN96-T97(N`%9O=')E(&YA
M=FEG871E=7(@;F4@<W5P<&]R=&4@<&%S(&-E='1E(&]P=&EO;@!6;W1R92!N
M879I9V%T975R(&YE('!R96YD('!A<R!E;B!C;VUP=&4@8V5T=&4@;W!T:6]N
M(&0G:6UP<F5S<VEO;BX@4')E<W-E>B!#;VYT<O1L92]#;VUM86YD92`K(%`@
M<&]U<B!I;7!R:6UE<@!6;W1R92!F=7-E874@:&]R86ER92!A8W1U96R@.@!6
M;W1R92!P<F]F:6P@<&%R(&3I9F%U="!A(.ETZ2!M;V1I9FGI+@!0<F]F:6P@
M<&%R(&3I9F%U=*`Z`%9O=')E(&YO;2!C;VUP;&5TH#H`5F]T<F4@8V]M<'1E
M(&$@97AP:7+I+@!6;W1R92!N;W5V96%U(&UO="!D92!P87-S92!P;W5R("5S
M(&5S=*`Z)7,`5F]S(&]P=&EO;G,@;VYT(.ETZ2!M:7-E<R#@(&IO=7(@<&]U
M<B!L82!D=7+I92!D92!C971T92!S97-S:6]N+@!6;W,@;W!T:6]N<R!O;G0@
MZ73I(&UI<V5S(.`@:F]U<BX`5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E
M;6ES(.`@>NER;P!6;W1R92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@X"!Z
MZ7)O+"!VZ7)I9FEE<B!V;W1R92!C;W5R<FEE<B!E="!C;VYN96-T97HM=F]U
M<R!A=F5Z('9O=')E(&YO=79E874@;6]T(&1E('!A<W-E+@!6;W1R92!M;W0@
M9&4@<&%S<V4@82!E>'!I<NDN`%9O<R!S97)V975R<R!D:7-T86YT<Z`Z`%EO
M=6=O<VQA=FEE`%IA[W)E`%IA;6)I90!::6UB86)W90!::7!P>0!;0V%C:&5R
M(&QE<R!C:71A=&EO;G-=`%M087,@9&4@<W5J971=`%M287!P;W)T(&1E('!R
M;V)LZ&UE70!;069F:6-H97(@;&4@=&5X=&4@8VETZ2`M`%M!9F9I8VAE<B!L
M92!T97AT92!C:73I("T@)7,@;&EG;F5S70!;;&EG;F4@)7,@9&4@)7-=`$%D
M<F5S<V4H<RD@=F5R<R!O^2!R961I<FEG97(Z`%]!9')E<W-E<R!A=7AQ=65L
M;&5S(&YE('!A<R!E;G9O>65R(&1E('+I<&]N<V5S.@!?061M:6YI<W1R871I
M;VX`3&ES=&4@7VYO:7)E`$QI9VYE(&1E(%]C;VUM86YD90!?1&%T851R964`
M4W5P<')I;65R(&QA(%]R86YGZ64`7U-U<'!R:6UE<B!L92!M97-S86=E(&-O
M;7!LZ'1E;65N=`!?16YT<F5R(&-H87%U92!A9')E<W-E('-U<B!U;F4@;&EG
M;F4@<^EP87+I93H`5')A;G-?9F5R=`!?1W)O=7!E<P!?06ED90!0<F]P<E]I
MZ73I<R!D92!L)VEM86=E+BXN`%]'87)D97(@=6YE(&-O<&EE(&1E<R!M97-S
M86=E<R!D86YS(&-E(&-O;7!T93\`7T-O;FYE>&EO;@!?1.EC;VYN97AI;VX`
M7TUO9&EF:65R('5N(&QI96X@=V5B+BXN`$3I<&QA8V5R(&QE(%]M97-S86=E
M('9E<G,@;&4@9&]S<VEE<@!?365S(&%D<F5S<V5S(&-O=7)R:65L.@!?3W!T
M:6]N<P!?4&5R;6ES<VEO;G,`7U)E=&ER97(@=6X@;&EE;@!?4V-R:7!T`%]#
M;VYF:6=U<F%T:6]N`%!R;W!R:>ETZ7,@9'4@7W1A8FQE874`7U5T:6QI<V%T
M975R<P!?06)S96YC97,`3&E?<W1E(&)L86YC:&4`8V%R;F5T(&0G861R97-S
M97,`9&5S=&EN871A:7)E(&EN8V]N;G4`970`86=E;F1A`&-A;&UE`&EM<&]S
M<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!D92!S;W)T:64`:6UP;W-S:6)L
M92!D)V]U=G)I<B!L)V5N='+I90!C;&EQ=65Z(&EC:0!E<G)E=7(@9"=U=&EL
M:7-A=&EO;B!D92!L82!L:6=N92!D92!C;VUM86YD90!E<G)E=7(@9&4@8V]N
M9FEG=7)A=&EO;@!A8G-E;F-E(&-R:71I<75E(&0G=6X@9FEC:&EE<B!S>7-T
MZ&UE`&5R<F5U<B!D92!F;W)M870@9&4@9&]N;NEE`&5N='+I92!N;VX@=')O
M=7;I`'1O;6)A;G0`8VAA;7``9FEC:&EE<@!D97!U:7,@;&4@)7,@*"5S*2#@
M("5S("5S`&5N(')A9F%L90!HH#H`:&@`;F]M(&0G:/1T92!I;F-O;FYU`&EM
M;>ED:6%T96UE;G0`:6YC;W)P;W+I90!E<G)E=7(@9"=E;G1RZ64O<V]R=&EE
M`&5R<F5U<B!L;V=I8VEE;&QE(&EN=&5R;F4`;&EG;F5S70!C;W)R97-P;VYD
M`&5R<F5U<B!M:VES;V9S(&-O9&4@)60@96X@8W+I86YT(&PG25-/`&UM`&YO
M;0!N;VX@<')I<R!E;B!C;VUP=&4`<&%S(&5N8V]R92!P<FES(&5N(&-O;7!T
M90!B;&]C+6YO=&5S`&]U`'!O=7)C96YT86=E`'!E<FUI<W-I;VX@<F5F=7/I
M90!P:7AE;',`4V-R:7!T('!R;V-M86EL(&?I;NERZ2!P87(@26YG;P!E<G)E
M=7(@9&ES=&%N=&4@9&%N<R!L92!P<F]T;V-O;&4`<R?I;&5V86YT`'-E<G9I
M8V4@;F]N(&1I<W!O;FEB;&4N`&UO;G1R97(@;&5S(&1I9F;I<F5N8V5S`$9I
M;'1R92!S:65V92!GZ6[I<ND@<&%R($EN9V\`<VUS,F5M86EL('9I82!(5%10
M`'-S`&9I>&4`97)R975R('-Y<W3H;64`;&ES=&4@9&4@=.)C:&5S`.EC:&5C
M('1E;7!O<F%I<F4`96YT<F5Z(&QE(&UO="!D92!P87-S92!D975X(&9O:7,@
M<&]U<B!C;VYF:7)M97(`=6YI9FGI`'-A;G,@;F]M`%/I;&5C=&EO;B!D)W5T
M:6QI<V%T975R`'9#87)D`&R@.@!W96%T:&5R+F-O;0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEN9V\O;&]C86QE+VAU7TA5+P``````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#<`,#$W-C,R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O:'5?2%4O3$-?
M34534T%'15,O````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<T-P`P,C$T,3<`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O
M+VQO8V%L92]H=5](52],0U]-15-304=%4R]I;F=O+FUO````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P-#8P,3<P`#$P-#$W,S8R-S0W`#`R,C<Q-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#>$@25`````#((```<
M````K$$``.T*```\@P```````/"N```.````\:X```\`````KP``#0```!"O
M```(````'J\```L````GKP``#````#.O```$````0*\```0```!%KP```P``
M`$JO```8````3J\``!L```!GKP``+0```(.O```=````L:\``"0```#/KP``
M*0```/2O```9````'K```"8````XL```#````%^P```D````;+````\```"1
ML```"P```*&P```.````K;```"@```"\L```"````.6P```*````[K```!4`
M``#YL```$@````^Q```+````(K$``(4````NL0``#@```+2Q```*````P[$`
M``T```#.L0``#@```-RQ```1````Z[$```T```#]L0``#`````NR```-````
M&+(``)0````FL@``"@```+NR```/````QK(``!@```#6L@``#````.^R```.
M````_+(```X````+LP``"````!JS```)````([,``"X````MLP``&@```%RS
M```R````=[,``#@```"JLP``5````..S``!1````.+0``%H```"*M```5P``
M`.6T```T````/;4```D```!RM0``#0```'RU```'````BK4```H```"2M0``
M#P```)VU```%````K;4```8```"SM0``$0```+JU```(````S+4```D```#5
MM0``"0```-^U```E````Z;4``"`````/M@``$P```#"V```0````1+8```\`
M``!5M@``"@```&6V```A````<+8```\```"2M@``+@```**V```#````T;8`
M``\```#5M@``%````.6V```)````^K8```T````$MP``$@```!*W```9````
M);<``!X````_MP``#P```%ZW```*````;K<```\```!YMP``"````(FW```D
M````DK<``!0```"WMP``%@```,RW```(````X[<``$X```#LMP``+0```#NX
M```9````:;@``!,```"#N```!P```)>X```,````G[@``"P```"LN```#@``
M`-FX```#````Z+@```L```#LN```!P```/BX```'`````+D```4````(N0``
M!0````ZY```*````%+D```,````?N0``%P```".Y```*````.[D```\```!&
MN0``#@```%:Y```4````9;D```L```!ZN0``&````(:Y```C````G[D```X`
M``##N0``%````-*Y```7````Y[D``!<```#_N0``%P```!>Z```3````+[H`
M``\```!#N@``#@```%.Z```?````8KH``!T```""N@``!P```*"Z```&````
MJ+H```@```"ON@``#P```+BZ```&````R+H```@```#/N@``"@```-BZ```3
M````X[H``!0```#WN@``"P````R[```0````&+L``!4````INP``#0```#^[
M```5````3;L```<```!CNP``$````&N[```%````?+L``!4```""NP``$0``
M`)B[```,````JKL``"H```"WNP``.P```.*[```X````'KP```D```!7O```
M!P```&&\```4````:;P```,```!^O```!0```(*\```0````B+P```D```"9
MO```$P```*.\```Y````M[P``!(```#QO```)P````2]```L````++T``"H`
M``!9O0``)0```(2]```*````JKT```8```"UO0``"0```+R]```'````QKT`
M`"\```#.O0``-P```/Z]```N````-KX``%4```!EO@``+0```+N^```M````
MZ;X``#T````7OP``/P```%6_```M````E;\``$````##OP``(P````3````C
M````*,```$````!,P```+0```(W````S````N\```"4```#OP```%0```!7!
M```9````*\$``"D```!%P0``)````&_!```H````E,$``#(```"]P0``$0``
M`/#!```*`````L(```P````-P@``"@```!K"```0````)<(``!8````VP@``
M%@```$W"```'````9,(```<```!LP@``%````'3"```*````B<(```@```"4
MP@``)P```)W"```(````Q<(```,```#.P@``"P```-+"```'````WL(```<`
M``#FP@``!@```.["```%````]<(```<```#[P@``!@````/#```4````"L,`
M``@````?PP``"0```"C#```.````,L,``#L```!!PP``%0```'W#```I````
MD\,```X```"]PP``"@```,S#```$````U\,```0```#<PP``!P```.'#```)
M````Z<,```8```#SPP``$0```/K#```'````#,0``!8````4Q```!````"O$
M```(````,,0```8````YQ```#0```$#$```&````3L0``!X```!5Q```$0``
M`'3$```(````AL0```T```"/Q```#````)W$```'````JL0```,```"RQ```
M`P```+;$```7````NL0``!,```#2Q```'0```.;$```(````!,4```0````-
MQ0``"````!+%```(````&\4``$$````DQ0``&@```&;%```K````@<4``"``
M``"MQ0``%0```,[%```&````Y,4```8```#KQ0``%0```/+%```8````",8`
M`"(````AQ@``+@```$3&```=````<\8``"$```"1Q@``5````+/&```I````
M",<```H````RQP``!P```#W'```'````1<<```X```!-QP``%0```%S'```.
M````<L<```(```"!QP``"@```(3'```/````C\<```T```"?QP``#P```*W'
M```-````O<<```D```#+QP``%````-7'```&````ZL<``!@```#QQP``'0``
M``K(```3````*,@``!$````\R```%````$[(```$````8\@```8```!HR```
M%````&_(``!4````A,@```X```#9R```9````.C(```$````3<D```X```!2
MR0``!0```&')```%````9\D``!L```!MR0``&@```(G)```3````I,D``!$`
M``"XR0``$0```,K)```<````W,D``"H```#YR0``$````"3*```A````-<H`
M``4```!7R@``$P```%W*```+````<<H``!(```!]R@``"@```)#*```/````
MF\H```T```"KR@``$0```+G*```3````R\H```P```#?R@``!@```.S*```,
M````\\H```8`````RP``%P````?+```0````'\L``!$````PRP``"````$++
M```%````2\L```P```!1RP``$````%[+```%````;\L```T```!URP``!@``
M`(/+```'````BLL```T```"2RP``!P```*#+```+````J,L```<```"TRP``
M!P```+S+```)````Q,L```D```#.RP``"@```-C+```9````X\L``#T```#]
MRP``'0```#O,```,````6<P``!````!FS```!0```'?,```E````?<P``!(`
M``"CS```$P```+;,```2````RLP``"L```#=S```.P````G-```@````1<T`
M``@```!FS0``-@```&_-```(````ILT``"$```"OS0``$````-'-```(````
MXLT```P```#KS0``!@```/C-```$````_\T```<````$S@``#P````S.```*
M````',X```X````GS@``!P```#;.```*````/LX```T```!)S@``'P```%?.
M```<````=\X``"$```"4S@``'@```+;.```9````U<X``!X```#OS@``&P``
M``[/```A````*L\``"X```!,SP``)@```'O/```<````HL\``!X```"_SP``
M'````-[/```F````^\\``"L````BT```,P```$[0```F````@M```"L```"I
MT```.````-70```=````#M$``!4````LT0``+P```$+1```@````<M$``!(`
M``"3T0``*0```*;1```>````T-$``"````#OT0``$@```!#2``"B````(](`
M`!8```#&T@``(P```-W2```H`````=,``"D````JTP``*````%33```?````
M?=,``!4```"=TP``(````+/3```E````U-,``"@```#ZTP``+0```"/4```P
M````4=0``)(```""U```(0```!75```6````-]4``!P```!.U0``)@```&O5
M```J````DM4``$$```"]U0``1````/_5```,````1-8```<```!1U@``!P``
M`%G6```&````8=8```T```!HU@``$````';6```1````A]8``!(```"9U@``
M$P```*S6```2````P-8```<```#3U@``!````-O6```0````X-8``!````#Q
MU@``#`````+7```.````#]<```T````>UP``#P```"S7```3````/-<```T`
M``!0UP``*````%[7```#````A]<```T```"+UP``!@```)G7```1````H-<`
M`!<```"RUP``&P```,K7```.````YM<```(```#UUP``"@```/C7``!)````
M`]@```4```!-V```$````%/8```/````9-@```0```!TV```#0```'G8```.
M````A]@```,```"6V```#@```)K8```1````J=@```@```"[V```#P```,38
M```/````U-@```<```#DV```#0```.S8```0````^M@```T````+V0``"P``
M`!G9```&````)=D```D````LV0``"P```#;9```0````0MD```P```!3V0``
M"@```&#9```1````:]D``!D```!]V0``"P```)?9```-````H]D``"(```"Q
MV0``&0```-39```/````[MD``!L```#^V0``-````!K:```*````3]H``!@`
M``!:V@``$@```'/:```9````AMH``!8```"@V@``!P```+?:```B````O]H`
M`!4```#BV@``(0```/C:```E````&ML``!$```!`VP``#0```%+;```'````
M8-L``!0```!HVP``"P```'W;```B````B=L``"\```"LVP``"P```-S;```)
M````Z-L``!D```#RVP``"P````S<```7````&-P``!<````PW```"0```$C<
M```*````4MP```@```!=W```%@```&;<```/````?=P``!D```"-W```.@``
M`*?<```6````XMP```X```#YW```&`````C=```(````(=T``"\````JW0``
M#0```%K=```F````:-T```@```"/W0``0P```)C=```2````W-T```\```#O
MW0``$````/_=```-````$-X``"$````>W@``"````$#>```2````2=X``!\`
M``!<W@``"````'S>```+````A=X``"\```"1W@``#@```,'>```%````T-X`
M``8```#6W@``10```-W>```#````(]\```<````GWP``!````"_?```'````
M--\```H````\WP``"@```$??```/````4M\``!````!BWP``%P```'/?```1
M````B]\``!D```"=WP``%P```+??```)````S]\```4```#9WP``"P```-_?
M```*````Z]\```(```#VWP``!0```/G?```-````_]\``!L````-X```%P``
M`"G@```4````0>````D```!6X```#@```&#@```-````;^```!(```!]X```
M"0```)#@```X````FN```"````#3X```!P```/3@```(````_.````D````%
MX0``#@````_A``![````'N$``!@```":X0``&````+/A```(````S.$``!$`
M``#5X0``!P```.?A```%````[^$``!@```#UX0``'@````[B```;````+>(`
M`!D```!)X@``*````&/B```5````C.(``!L```"BX@``&0```+[B```3````
MV.(```<```#LX@``"````/3B```&````_>(```8````$XP``$`````OC```/
M````'.,``!`````LXP``#P```#WC```+````3>,```\```!9XP``#````&GC
M```/````=N,```<```"&XP``#@```([C```&````G>,```8```"DXP``#@``
M`*OC```,````NN,``!H```#'XP``*````.+C```/````"^0```@````;Y```
M"````"3D```3````+>0``!X```!!Y```(0```&#D```@````@N0``!D```"C
MY```%P```+WD```E````U>0``!<```#[Y```%@```!/E```$````*N4``!L`
M```OY0``#0```$OE```,````6>4```,```!FY0``!0```&KE```(````<.4`
M``H```!YY0``#````(3E```+````D>4``!````"=Y0``#````*[E```.````
MN^4```0```#*Y0``!````,_E```3````U.4``!0```#HY0``#````/WE```)
M````"N8```X````4Y@``"P```"/F```;````+^8``!,```!+Y@``&0```%_F
M```;````>>8```X```"5Y@``"P```*3F```,````L.8``!4```"]Y@``#0``
M`-/F``!#````X>8``#$````EYP``0@```%?G``!'````FN<``$\```#BYP``
M/0```#+H``!.````<.@``!$```"_Z```!P```-'H```'````V>@```H```#A
MZ```#0```.SH```)````^N@```0````$Z0```P````GI```8````#>D```H`
M```FZ0``!````#'I```E````-ND``"8```!<Z0``#@```(/I``!\````DND`
M`!4````/Z@``!0```"7J```'````*^H```P````SZ@``"````$#J```*````
M2>H```8```!4Z@``!P```%OJ```Y````8^H```@```"=Z@``#0```*;J```"
M````M.H```8```"WZ@``!@```+[J```4````Q>H```T```#:Z@``$````.CJ
M```;````^>H```0````5ZP``"0```!KK```%````).L``!`````JZP``"0``
M`#OK```)````1>L```4```!/ZP``&@```%7K```(````<.L```8```!YZP``
M&0```(#K```.````FNL```<```"IZP``!P```+'K```%````N>L```D```"_
MZP``"@```,GK```.````U.L```(```#CZP``!@```.;K```+````[>L```T`
M``#YZP``"0````?L```,````$>P``!@````>[```!@```#?L```2````/NP`
M``D```!1[```!P```%OL```4````8^P``!T```!X[```0@```);L```E````
MV>P``"4```#_[```!@```"7M```*````+.T```0````W[0``"0```#SM```(
M````1NT``!$```!/[0``"0```&'M```&````:^T```T```!R[0``!@```(#M
M```Y````A^T``#T```#![0``.@```/_M```>````.NX```4```!9[@``#@``
M`%_N```$````;NX```8```!S[@``!P```'KN```A````@NX```T```"D[@``
M%0```++N```&````R.X```0```#/[@``$0```-3N```&````YNX```H```#M
M[@``(@```/CN```$````&^\```4````@[P``'0```";O```$````1.\```P`
M``!)[P``#@```%;O```*````9>\```@```!P[P``"0```'GO```%````@^\`
M`#H```")[P``,````,3O```U````]>\``"D````K\```1P```%7P```X````
MG?```"D```#6\```/P````#Q```N````0/$``"T```!O\0``'P```)WQ```/
M````O?$``!(```#-\0``"P```.#Q```F````[/$``"D````3\@``)````#WR
M```F````8O(```@```")\@``"@```)+R```)````G?(```<```"G\@``(```
M`*_R```@````T/(``"8```#Q\@``"@```!CS```9````(_,``"D````]\P``
M%@```&?S```2````?O,```<```"1\P``"@```)GS```,````I/,```\```"Q
M\P``$````,'S``!`````TO,``'`````3]```9@```(3T```.````Z_0```D`
M``#Z]```"@````3U```2````#_4``!,````B]0``#````#;U```&````0_4`
M``\```!*]0``"0```%KU```2````9/4``!````!W]0``$0```(CU```<````
MFO4``",```"W]0``:@```-OU```/````1O8```4```!6]@``$````%SV``!#
M````;?8```D```"Q]@``,@```+OV```$````[O8```L```#S]@``(````/_V
M```4````(/<```P````U]P``#````$+W```/````3_<``!4```!?]P``*0``
M`'7W```J````G_<``"8```#*]P``)P```/'W```I````&?@``"H```!#^```
M&0```&[X``!"````B/@``!$```#+^```$@```-WX```3````\/@``!0````$
M^0``#P```!GY```6````*?D``!<```!`^0``$````%CY```1````:?D``#0`
M``![^0``$P```+#Y```2````Q/D``#4```#7^0``%`````WZ```'````(OH`
M``P````J^@``(````#?Z```0````6/H``!0```!I^@``$0```'[Z```7````
MD/H``!P```"H^@``$P```,7Z```4````V?H``!H```#N^@``$0````G[```:
M````&_L``!X````V^P``&@```%7[```3````</L``!4```"$^P``$0```)K[
M```7````K/L``!0```#$^P``%P```-G[```5````\?L```D````'_```$```
M`!'\```9````(OP```0````\_```!P```$'\```"````2?P```L```!,_```
M!0```%C\```1````7OP```8```!P_```!@```'?\```&````?OP```4```"%
M_```!P```(O\```'````D_P```4```";_```%@```*'\```&````N/P```8`
M``"__```!````,;\```$````R_P```<```#0_```#@```-C\```,````Y_P`
M``P```#T_```#0````']```*````#_T```X````:_0``!0```"G]```H````
M+_T```X```!8_0``#````&?]```/````=/T```H```"$_0``"````(_]```)
M````F/T``"L```"B_0``!````,[]```(````T_T``"8```#<_0``$@````/^
M```/````%OX```8````F_@``"@```"W^``!,````./X```<```"%_@``"```
M`(W^```@````EOX```D```"W_@``%````,'^```,````UOX```T```#C_@``
M#@```/'^```6`````/\``!$````7_P``!@```"G_```#````,/\```8````T
M_P``&0```#O_```'````5?\```0```!=_P``"P```&+_```+````;O\```<`
M``!Z_P``"0```(+_```5````C/\```4```"B_P``!P```*C_```6````L/\`
M``T```#'_P``#0```-7_```*````X_\``!````#N_P``#P```/__```1````
M#P`!`!<````A``$`"@```#D``0`1````1``!``0```!6``$`#P```%L``0`Z
M````:P`!``4```"F``$`#````*P``0`>````N0`!``X```#8``$`$````.<`
M`0`+````^``!``P````$`0$`"0```!$!`0`'````&P$!``H````C`0$`"0``
M`"X!`0`.````.`$!`!````!'`0$`&P```%@!`0`8````=`$!`!H```"-`0$`
M"@```*@!`0`)````LP$!``H```"]`0$`#````,@!`0`/````U0$!``@```#E
M`0$`!@```.X!`0`<````]0$!``<````2`@$`!0```!H"`0`+````(`(!`$<`
M```L`@$`#0```'0"`0`)````@@(!``0```",`@$``P```)$"`0`3````E0(!
M`!,```"I`@$`$P```+T"`0`*````T0(!``(```#<`@$`!````-\"`0`E````
MY`(!``,````*`P$`!0````X#`0`J````%`,!``H````_`P$`!0```$H#`0`$
M````4`,!``H```!5`P$`#0```&`#`0`&````;@,!``@```!U`P$`"````'X#
M`0`$````AP,!``4```",`P$`:````)(#`0`)````^P,!``P````%!`$`$```
M`!($`0`8````(P0!``4````\!`$`!@```$($`0`0````200!`!L```!:!`$`
M+P```'8$`0`0````I@0!``H```"W!`$`&P```,($`0`/````W@0!``H```#N
M!`$`"0```/D$`0`3`````P4!`!L````7!0$`&````#,%`0`7````3`4!`!\`
M``!D!0$`%P```(0%`0`.````G`4!`(D```"K!0$`B0```#4&`0`#````OP8!
M``<```##!@$`"````,L&`0`'````U`8!``H```#<!@$`"P```.<&`0`'````
M\P8!`%$```#[!@$`$````$T'`0`,````7@<!``T```!K!P$`&@```'D'`0!*
M````E`<!`!D```#?!P$`!@```/D'`0`:``````@!`"4````;"`$`!@```$$(
M`0`&````2`@!`!\```!/"`$`!@```&\(`0`)````=@@!`!@```"`"`$`%P``
M`)D(`0`H````L0@!``8```#:"`$`#0```.$(`0`B````[P@!`!D````2"0$`
M)@```"P)`0!7````4PD!`!,```"K"0$`&0```+\)`0`;````V0D!`",```#U
M"0$`$P```!D*`0`"````+0H!``L````P"@$`"````#P*`0`-````10H!``H`
M``!3"@$`!P```%X*`0`4````9@H!``8```!["@$`"````((*`0`.````BPH!
M``<```":"@$`"@```*(*`0`+````K0H!`#(```"Y"@$`!P```.P*`0`,````
M]`H!``T````!"P$`#`````\+`0`$````'`L!``D````A"P$`"0```"L+`0`*
M````-0L!``X```!`"P$`#````$\+`0`'````7`L!``D```!D"P$`!P```&X+
M`0`*````=@L!`!L```"!"P$`#P```)T+`0`2````K0L!``H```#`"P$`%@``
M`,L+`0`)````X@L!`!````#L"P$`!P```/T+`0`2````!0P!`"D````8#`$`
M!````$(,`0`'````1PP!``4```!/#`$`!0```%4,`0`+````6PP!`!0```!G
M#`$`$0```'P,`0`:````C@P!`!8```"I#`$`%````,`,`0`7````U0P!`!@`
M``#M#`$`'`````8-`0`9````(PT!``<````]#0$`!0```$4-`0`-````2PT!
M``P```!9#0$`$0```&8-`0`(````>`T!``@```"!#0$`%P```(H-`0`+````
MH@T!``P```"N#0$`'P```+L-`0`:````VPT!`!,```#V#0$`!`````H.`0`*
M````#PX!``0````:#@$`#0```!\.`0`,````+0X!``4````Z#@$`"0```$`.
M`0`%````2@X!``<```!0#@$`!0```%@.`0`$````7@X!``(```!C#@$`+P``
M`&8.`0`X````E@X!`"P```#/#@$`(P```/P.`0`F````(`\!`!(```!'#P$`
M*0```%H/`0`R````A`\!``H```"W#P$`+````,(/`0`N````[P\!`#,````>
M$`$`,P```%(0`0`X````AA`!``\```"_$`$`&````,\0`0`0````Z!`!`"X`
M``#Y$`$`%````"@1`0`/````/1$!`!,```!-$0$`%0```&$1`0`4````=Q$!
M`!(```",$0$`%````)\1`0`5````M!$!`"T```#*$0$`+0```/@1`0`Q````
M)A(!`"X```!8$@$`+P```(<2`0`L````MQ(!`&(```#D$@$`$P```$<3`0`-
M````6Q,!``@```!I$P$`%````'(3`0`7````AQ,!``@```"?$P$`%````*@3
M`0`,````O1,!`"L```#*$P$`(0```/83`0`:````&!0!``D````S%`$`10``
M`#T4`0!!````@Q0!``0```#%%`$`$P```,H4`0`4````WA0!``X```#S%`$`
M$P````(5`0`8````%A4!``8````O%0$`"0```#85`0`*````0!4!``\```!+
M%0$`#````%L5`0`0````:!4!``<```!Y%0$`#@```($5`0`%````D!4!`!L`
M``"6%0$`%````+(5`0`(````QQ4!``8```#0%0$`%````-<5`0`1````[!4!
M``X```#^%0$`.`````T6`0`"````1A8!``8```!)%@$`#@```%`6`0`%````
M7Q8!``<```!E%@$`#@```&T6`0`&````?!8!`"@```"#%@$`#````*P6`0`<
M````N18!``0```#6%@$`*0```-L6`0`5````!1<!`!<````;%P$`'P```#,7
M`0!<````4Q<!`!0```"P%P$`/@```,47`0`?````!!@!`!`````D&`$`!P``
M`#48`0`>````/1@!``X```!<&`$`#````&L8`0`,````>!@!`!,```"%&`$`
M"@```)D8`0`=````I!@!`!D```#"&`$`!0```-P8`0`1````XA@!``T```#T
M&`$`"`````(9`0`1````"QD!`"0````=&0$`$@```$(9`0`5````51D!`!(`
M``!K&0$`#@```'X9`0`9````C1D!``@```"G&0$`#0```+`9`0`'````OAD!
M``H```#&&0$`!P```-$9`0`/````V1D!``8```#I&0$`"P```/`9`0`:````
M_!D!``<````7&@$`"````!\:`0`%````*!H!`!\````N&@$`!@```$X:`0`0
M````51H!``@```!F&@$`#0```&\:`0`(````?1H!`!X```"&&@$`$@```*4:
M`0`L````N!H!`!H```#E&@$`"0`````;`0`*````"AL!`!4````5&P$`!0``
M`"L;`0`4````,1L!``0```!&&P$`$````$L;`0`&````7!L!``<```!C&P$`
M'@```&L;`0`H````BAL!``H```"S&P$`'````+X;`0`1````VQL!``L```#M
M&P$`&@```/D;`0`4````%!P!``0````I'`$`!````"X<`0`+````,QP!``4`
M```_'`$`!@```$4<`0`(````3!P!``8```!5'`$`"@```%P<`0`;````9QP!
M`#0```"#'`$`-````+@<`0`@````[1P!`"D````.'0$`(````#@=`0!!````
M61T!`!H```";'0$`*````+8=`0`H````WQT!`"D````('@$`4````#(>`0`B
M````@QX!``8```"F'@$`"````*T>`0`%````MAX!``@```"\'@$`&0```,4>
M`0`9````WQX!`"H```#Y'@$`(P```"0?`0`9````2!\!`"X```!B'P$`-```
M`)$?`0`(````QA\!`!<```#/'P$`"@```.<?`0`'````\A\!`"$```#Z'P$`
M$````!P@`0`.````+2`!``L````\(`$`!P```$@@`0`3````4"`!``@```!D
M(`$`"P```&T@`0`*````>2`!`!0```"$(`$`#P```)D@`0`R````J2`!``L`
M``#<(`$`#@```.@@`0`%````]R`!``4```#](`$`!0````,A`0`7````"2$!
M``<````A(0$`#P```"DA`0`$````.2$!``H````^(0$`"0```$DA`0`+````
M4R$!``T```!?(0$`#````&TA`0`.````>B$!``4```")(0$`!````(\A`0`-
M````E"$!`#(```"B(0$`10```-4A`0`(````&R(!``L````D(@$`%P```#`B
M`0`'````2"(!`!X```!0(@$`%````&\B`0`2````A"(!`!(```"7(@$`%```
M`*HB`0`&````OR(!``<```#&(@$`#@```,XB`0`J````W2(!``8````((P$`
M#`````\C`0`-````'",!`!$````J(P$`"P```#PC`0`V````2",!``H```!_
M(P$`(@```(HC`0`+````K2,!``\```"Y(P$`,@```,DC`0`E````_",!`#``
M```B)`$`,0```%,D`0`M````A20!``X```"S)`$`!0```,(D`0`.````R"0!
M`!,```#7)`$`$@```.LD`0`'````_B0!`!8````&)0$`$0```!TE`0`4````
M+R4!`!,```!$)0$`!P```%@E`0`4````8"4!`!@```!U)0$`!P```(XE`0`%
M````EB4!``P```"<)0$`#````*DE`0`2````MB4!``0```#))0$`!P```,XE
M`0`*````UB4!``L```#A)0$`#````.TE`0`.````^B4!``X````))@$`!0``
M`!@F`0`$````'B8!``L````C)@$`#````"\F`0`-````/"8!``P```!*)@$`
M"0```%<F`0`%````828!``4```!G)@$`+@```&TF`0`F````G"8!`",```##
M)@$``P```.<F`0`2````ZR8!``8```#^)@$`'@````4G`0`8````)"<!`"4`
M```])P$`#0```&,G`0`?````<2<!``,```"1)P$`&````)4G`0`'````KB<!
M``(```"V)P$`#````+DG`0`5````QB<!``L```#<)P$`&0```.@G`0`@````
M`B@!`!(````C*`$`!0```#8H`0`*````/"@!`!4```!'*`$`$@```%TH`0`,
M````<"@!``0```!]*`$`"0```((H`0`'````C"@!``P```"4*`$`#0```*$H
M`0!2````KR@!`!<````"*0$`)````!HI`0`2````/RD!``<```!2*0$`!@``
M`%HI`0`/````82D!`!,```!Q*0$`'@```(4I`0`@````I"D!``8```#%*0$`
M#@```,PI`0`$````VRD!``P```#@*0$`#0```.TI`0`.````^RD!`!4````*
M*@$`$@```"`J`0`/````,RH!`!0```!#*@$`"@```%@J`0`;````8RH!`!``
M``!_*@$`"P```)`J`0`4````G"H!`&D```"Q*@$`&@```!LK`0`7````-BL!
M`"<```!.*P$`&@```'8K`0`7````D2L!`!L```"I*P$`&0```,4K`0`?````
MWRL!`!,```#_*P$`$P```!,L`0`(````)RP!``8````P+`$`!P```#<L`0`(
M````/RP!``D```!(+`$`%0```%(L`0`-````:"P!`",```!V+`$`#0```)HL
M`0`3````J"P!``@```"\+`$``P```,4L`0!&````R2P!`#\````0+0$`-P``
M`%`M`0!7````B"T!`!X```#@+0$`!0```/\M`0`?````!2X!`"\````E+@$`
M"@```%4N`0`(````8"X!``T```!I+@$`+0```'<N`0`$````I2X!`!(```"J
M+@$`$P```+TN`0!/````T2X!`"4````A+P$`'````$<O`0`+````9"\!`!\`
M``!P+P$`'0```)`O`0`E````KB\!`"````#4+P$`)````/4O`0`@````&C`!
M``L````[,`$`!P```$<P`0`-````3S`!``P```!=,`$`%P```&HP`0`&````
M@C`!`#D```"),`$`#````,,P`0`'````T#`!``D```#8,`$`$P```.(P`0`)
M````]C`!``0`````,0$`$`````4Q`0`(````%C$!``@````?,0$`!````"@Q
M`0`+````+3$!``P````Y,0$`$@```$8Q`0`1````63$!``P```!K,0$`&@``
M`'@Q`0`/````DS$!``<```"C,0$`#0```*LQ`0`4````N3$!``X```#.,0$`
M#````-TQ`0`;````ZC$!`"P````&,@$`$P```#,R`0`<````1S(!`"@```!D
M,@$`!@```(TR`0`'````E#(!`!,```"<,@$`!0```+`R`0`$````MC(!`!<`
M``"[,@$`"@```-,R`0`,````WC(!``D```#K,@$`!@```/4R`0`)````_#(!
M``@````&,P$`"0````\S`0`*````&3,!`!$````D,P$`!@```#8S`0`C````
M/3,!``X```!A,P$`#@```'`S`0`-````?S,!``L```"-,P$`'0```)DS`0`+
M````MS,!``(```##,P$`'````,8S`0`=````XS,!``<````!-`$`"`````DT
M`0`&````$C0!`&0````9-`$`"0```'XT`0`'````B#0!`"8```"0-`$`.```
M`+<T`0`:````\#0!`"H````+-0$`.P```#8U`0`H````<C4!`#0```";-0$`
M&0```-`U`0`5````ZC4!``4`````-@$`!P````8V`0`(````#C8!``<````7
M-@$`!0```!\V`0`'````)38!``X````M-@$`"0```#PV`0`&````1C8!``@`
M``!--@$`"P```%8V`0`'````8C8!``@```!J-@$`!P```',V`0`6````>S8!
M``D```"2-@$`!@```)PV`0`+````HS8!`!````"O-@$`'````,`V`0`4````
MW38!``<```#R-@$`$0```/HV`0`(````##<!``X````5-P$`"````"0W`0`%
M````+3<!`!`````S-P$`$````$0W`0`&````53<!`!D```!<-P$`"@```'8W
M`0`<````@3<!``<```">-P$`!0```*8W`0`0````K#<!`!0```"]-P$`"P``
M`-(W`0`-````WC<!`"@```#L-P$`&````!4X`0`7````+C@!``0```!&.`$`
M"0```$LX`0`*````53@!``<```!@.`$``@```&@X`0`.````:S@!``@```!Z
M.`$`(P```(,X`0`?````IS@!`#@```#'.`$`)@`````Y`0`Q````)SD!`"<`
M``!9.0$`,@```($Y`0`R````M#D!`&0```#G.0$`%````$PZ`0!5````83H!
M`#@```"W.@$`2@```/`Z`0!;````.SL!`"@```"7.P$`$0```,`[`0`X````
MTCL!`"@````+/`$`+````#0\`0`F````83P!`!L```"(/`$`/@```*0\`0"I
M`0``XSP!`",```"-/@$`%P```+$^`0!(````R3X!`(4````2/P$`,````)@_
M`0`E````R3\!`$$```#O/P$`6P```#%``0!)````C4`!`#$```#70`$`'0``
M``E!`0`8````)T$!`"L```!`00$`(0```&Q!`0`?````CD$!`"L```"N00$`
M)@```-I!`0`G`````4(!`#H````I0@$`'0```&1"`0`1````@D(!`#,```"4
M0@$`)0```,A"`0`G````[D(!`"`````60P$`'P```#=#`0`P````5T,!`&D`
M``"(0P$`,0```/)#`0!!````)$0!`#,```!F1`$`)0```)I$`0`]````P$0!
M`&4```#^1`$`30```&1%`0`I````LD4!`"L```#<10$`+P````A&`0`N````
M.$8!`#````!G1@$`5````)A&`0!:````[48!`$@```!(1P$`2@```)%'`0`R
M````W$<!`"\````/2`$`+````#](`0`M````;$@!`'$```":2`$`9@````Q)
M`0!O````<TD!`+,```#C20$`%P```)=*`0`E````KTH!`#(```#52@$`*0``
M``A+`0`^````,DL!`"(```!Q2P$`4@```)1+`0`E````YTL!``L````-3`$`
ML0```!E,`0!%````RTP!`"$````130$`,````#--`0`E````9$T!`!P```"*
M30$`,0```*=-`0`'````V4T!``<```#A30$`!````.E-`0`-````[DT!``L`
M``#\30$`#@````A.`0`+````%TX!``4````C3@$`$````"E.`0`"````.DX!
M`%D````]3@$``P```)=.`0`%````FTX!`!(```"A3@$`!````+1.`0`'````
MN4X!``@```#!3@$`!0```,I.`0`#````T$X!`!````#43@$`#````.5.`0`3
M````\DX!``T````&3P$``@```!1/`0`'````%T\!``8````?3P$`%````"9/
M`0`,````.T\!`!@```!(3P$`!@```&%/`0`2````:$\!``P```![3P$``P``
M`(A/`0`J````C$\!``0```"W3P$`!@```+Q/`0`'````PT\!`!\```#+3P$`
M-0```.M/`0`N````(5`!`"\```!04`$`%P```(!0`0`B````F%`!`"4```"[
M4`$`(````.%0`0`;`````E$!`!@````>40$`)````#=1`0`?````7%$!`!H`
M``!\40$`(0```)=1`0`@````N5$!`!H```#:40$`,@```/51`0`:````*%(!
M`"\```!#4@$`*P```'-2`0`?````GU(!`",```"_4@$`'P```.-2`0`:````
M`U,!`"$````>4P$`)0```$!3`0`F````9E,!`"4```"-4P$`)````+-3`0`8
M````V%,!`!T```#Q4P$`)`````]4`0`8````-%0!`"(```!-5`$`+````'!4
M`0`O````G50!`!4```#-5`$`)0```.-4`0`\````"54!`!\```!&50$`(P``
M`&95`0`?````BE4!`"````"J50$`&@```,M5`0`8````YE4!`"8```#_50$`
M'@```"96`0`I````158!`!X```!O5@$`,0```(Y6`0`)````P%8!``P```#*
M5@$`%P```-=6`0`O````[U8!`"0````?5P$`!P```$17`0`/````3%<!`!0`
M``!<5P$`#@```'%7`0`-````@%<!`"0```".5P$`!0```+-7`0`'````N5<!
M`"(```#!5P$`)0```.17`0`:````"E@!`!T````E6`$`&@```$-8`0`'````
M7E@!`,<```!F6`$`"P```"Y9`0`5````.ED!``8```!060$`"0```%=9`0`+
M````85D!``T```!M60$`%P```'M9`0`&````DUD!`#,```":60$`$P```,Y9
M`0`3````XED!``<```#V60$`#P```/Y9`0`'````#EH!`#(````66@$`!```
M`$E:`0`A````3EH!`!,```!P6@$`#````(1:`0`1````D5H!`#(```"C6@$`
M%@```-9:`0`(````[5H!`!T```#V6@$`"0```!1;`0`*````'EL!`!0````I
M6P$`"@```#Y;`0`=````25L!``@```!G6P$`#0```'!;`0`Z````?EL!`!\`
M``"Y6P$`"````-E;`0`:````XEL!`"<```#]6P$`!@```"5<`0`5````+%P!
M``<```!"7`$`"````$I<`0`)````4UP!`#\```!=7`$`!P```)U<`0`/````
MI5P!``X```"U7`$`$````,1<`0`)````U5P!``D```#?7`$`"````.E<`0`3
M````\EP!``<````&70$`&0````Y=`0`*````*%T!`!<````S70$`%````$M=
M`0`*````8%T!``P```!K70$`%P```'A=`0`$````D%T!`"H```"570$`#```
M`,!=`0`1````S5T!``<```#?70$``@```.==`0`0````ZET!`!@```#[70$`
M`P```!1>`0`(````&%X!``8````A7@$`!P```"A>`0`-````,%X!``L````^
M7@$`%````$I>`0`5````7UX!``X```!U7@$`%0```(1>`0`O````FEX!`"``
M``#*7@$`'````.M>`0`5````"%\!``P````>7P$`,0```"M?`0`)````75\!
M``X```!G7P$`.P```'9?`0`5````LE\!``4```#(7P$`$@```,Y?`0`_````
MX5\!`!(````A8`$`"@```#1@`0`&````/V`!``0```!&8`$`!````$M@`0`*
M````4&`!`!,```!;8`$`!0```&]@`0`&````=6`!``8```!\8`$`"````(-@
M`0`$````C&`!``P```"18`$`"@```)Y@`0`Y````J6`!`"X```#C8`$`*0``
M`!)A`0`%````/&$!`!@```!"80$`&0```%MA`0`?````=6$!`!T```"580$`
M$0```+-A`0`"````Q6$!``0```#(80$`"@```,UA`0`&````V&$!``4```#?
M80$``P```.5A`0`,````Z6$!`$4```#V80$`,@```#QB`0`Q````;V(!`#,`
M``"A8@$`&@```-5B`0`T````\&(!`"@````E8P$`4P```$YC`0`9````HF,!
M`!\```"\8P$`<@```-QC`0`@````3V0!`#4```!P9`$`(0```*9D`0!%````
MR&0!`#`````.90$`*````#]E`0`I````:&4!`"8```"290$`8````+EE`0`E
M````&F8!`"@```!`9@$`*````&EF`0`B````DF8!`"L```"U9@$`,````.%F
M`0`2````$F<!`!,````E9P$`$````#EG`0!Y````2F<!``D```#$9P$`H0``
M`,YG`0!S````<&@!`'P```#D:`$`*P```&%I`0!4````C6D!`!<```#B:0$`
M)P```/II`0`6````(FH!``\````Y:@$`%P```$EJ`0`?````86H!`$````"!
M:@$`'P```,)J`0`<````XFH!`%$```#_:@$`&@```%%K`0`4````;&L!``H`
M``"!:P$`!0```(QK`0`&````DFL!``@```"9:P$`$@```*)K`0`,````M6L!
M`!````#":P$`$P```--K`0`=````YVL!``\````%;`$`&P```!5L`0`D````
M,6P!``\```!6;`$`"@```&9L`0`$````<6P!``L```!V;`$`&@```()L`0`B
M````G6P!``@```#`;`$`!P```,EL`0`%````T6P!`!0```#7;`$`*0```.QL
M`0`'````%FT!``@````>;0$`#P```"=M`0`8````-VT!`!0```!0;0$`"```
M`&5M`0`,````;FT!``\```![;0$`!P```(MM`0`&````DVT!`!0```":;0$`
M!@```*]M`0`)````MFT!``H```#`;0$`!@```,MM`0`,````TFT!`!$```#?
M;0$``P```/%M`0`(````]6T!``0```#^;0$`&0````-N`0`1````'6X!``H`
M```O;@$`&````#IN`0`3````4VX!`!P```!G;@$`$0```(1N`0`:````EFX!
M``0```"Q;@$`#P```+9N`0`'````QFX!``4```#.;@$`!````-1N`0`9````
MV6X!``<```#S;@$``@```/MN`0`1````_FX!``D````0;P$`"````!IO`0`2
M````(V\!`!<````V;P$`!@```$YO`0`A````56\!``4```!W;P$`)P```'UO
M`0`$````I6\!``\```"J;P$`$P```+IO`0`'````SF\!``(```#6;P$`!P``
M`-EO`0`1````X6\!``8```#S;P$`(0```/IO`0`8````''`!``8````U<`$`
M$P```#QP`0`0````4'`!`!X```!A<`$`$@```(!P`0`&````DW`!``P```":
M<`$`"0```*=P`0`1````L7`!`"(```##<`$`!P```.9P`0`+````[G`!``4`
M``#Z<`$``@````!Q`0`_`0```W$!`!0```!#<@$`$P```%AR`0`/````;'(!
M``4```!\<@$`"0```()R`0`)````C'(!``,```"6<@$``P```)IR`0`%````
MGG(!`!0```"D<@$`'````+ER`0`L````UG(!`"L````#<P$`(0```"]S`0`M
M````47,!`!P```!_<P$`,P```)QS`0`+````T',!`"P```#<<P$`%`````ET
M`0`3````'G0!``L````R=`$`*````#YT`0`,````9W0!`!4```!T=`$`&P``
M`(IT`0`A````IG0!``H```#(=`$`@P```--T`0`6````5W4!``<```!N=0$`
M$0```'9U`0`5````B'4!``X```">=0$`"@```*UU`0`/````N'4!`!$```#(
M=0$`F@```-IU`0`-````=78!`!4```"#=@$`&0```)EV`0`/````LW8!`!``
M``##=@$`$````-1V`0`&````Y78!``8```#L=@$`/````/-V`0`>````,'<!
M`#D```!/=P$`3````(EW`0!K````UG<!`&<```!">`$`<0```*IX`0!M````
M''D!`#P```"*>0$`$@```,=Y`0`3````VGD!``P```#N>0$`$0```/MY`0`2
M````#7H!``4````@>@$`*P```"9Z`0`2````4GH!``H```!E>@$`"0```'!Z
M`0`*````>GH!`#,```"%>@$`+0```+EZ`0`9````YWH!``8````!>P$`(0``
M``A[`0`)````*GL!`$D````T>P$`&````'Y[`0`^````EWL!``<```#6>P$`
M%0```-Y[`0`B````]'L!`!$````7?`$`%@```"E\`0`:````0'P!`!T```!;
M?`$`*@```'E\`0`;````I'P!`!0```#`?`$`$@```-5\`0`1````Z'P!`"X`
M``#Z?`$`'````"E]`0`=````1GT!`!D```!D?0$`90```'Y]`0!"````Y'T!
M`#`````G?@$`$P```%A^`0`#````;'X!``H```!P?@$`/````'M^`0`.````
MN'X!``H```#'?@$`"P```-)^`0`'````WGX!``<```#F?@$`!0```.Y^`0`*
M````]'X!``D```#_?@$`"P````E_`0`=````%7\!``X````S?P$`$@```$)_
M`0`@````57\!``T```!V?P$`'@```(1_`0`;````HW\!`#,```"_?P$`"P``
M`/-_`0`?````_W\!`!(````?@`$`'@```#*``0`/````48`!`!,```!A@`$`
M$@```'6``0`/````B(`!`"(```"8@`$`&````+N``0`'````U(`!``8```#<
M@`$`"````..``0`H````[(`!``8````5@0$`#````!R!`0`*````*8$!`!(`
M```T@0$`#@```$>!`0`*````5H$!`!0```!A@0$`$P```':!`0`8````BH$!
M`"T```"C@0$`"@```-&!`0`1````W($!``<```#N@0$`$P```/:!`0`<````
M"H(!`!H````G@@$`*P```$*"`0`]````;H(!`#H```"L@@$`"0```.>"`0`,
M````\8(!`!(```#^@@$`"````!&#`0`%````&H,!``<````@@P$`#````"B#
M`0`:````-8,!`$D```!0@P$`%P```)J#`0`I````LH,!`"T```#<@P$`-```
M``J$`0`Y````/X0!``T```!YA`$`"0```(>$`0`*````D80!``@```"<A`$`
M-````*6$`0!(````VH0!`#,````CA0$`7@```%>%`0`R````MH4!`#(```#I
MA0$`10```!R&`0`^````8H8!`#(```"AA@$`1@```-2&`0`N````&X<!`#L`
M``!*AP$`0@```(:'`0`R````R8<!`#@```#\AP$`.@```#6(`0`E````<(@!
M`"@```"6B`$`.0```+^(`0`Z````^8@!`#D````TB0$`00```&Z)`0`;````
ML(D!``P```#,B0$`(````-F)`0`&````^HD!``L````!B@$`'@````V*`0`F
M````+(H!``<```!3B@$`!P```%N*`0`3````8XH!``D```!WB@$`"````(&*
M`0`U````BHH!``L```#`B@$``P```,R*`0`7````T(H!`!````#HB@$`!P``
M`/F*`0`&`````8L!``4````(BP$`!P````Z+`0`&````%HL!`"L````=BP$`
M"P```$F+`0`-````58L!`!H```!CBP$`+P```'Z+`0`-````KHL!`"T```"\
MBP$`%@```.J+`0`2`````8P!``H````4C`$`"````!^,`0`'````*(P!`!``
M```PC`$`!0```$&,`0`/````1XP!``<```!7C`$`$P```%^,`0`)````<XP!
M``@```!]C`$`!````(:,`0`-````BXP!``@```"9C`$`&@```**,`0`1````
MO8P!``@```#/C`$`"@```-B,`0`,````XXP!``<```#PC`$`%0```/B,`0`#
M````#HT!`"P````2C0$`$P```#^-`0`I````4XT!``8```!]C0$`!P```(2-
M`0`)````C(T!``<```"6C0$`0````)Z-`0`>````WXT!`#L```#^C0$`*@``
M`#J.`0`D````98X!``8```"*C@$`!0```)&.`0`:````EXX!`"$```"RC@$`
M/P```-2.`0`[````%(\!`",```!0CP$`(@```'2/`0!7````EX\!`"P```#O
MCP$`$@```!R0`0`*````+Y`!``L````ZD`$`%0```$:0`0`7````7)`!``\`
M``!TD`$``@```(20`0`-````AY`!`!(```"5D`$`$@```*B0`0`2````NY`!
M`!,```#.D`$`#0```.*0`0`3````\)`!``4````$D0$`&0````J1`0`:````
M))$!`!<````_D0$`&0```%>1`0`D````<9$!``0```"6D0$`"P```)N1`0`3
M````IY$!`$0```"[D0$`%`````"2`0!<````%9(!``@```!RD@$`$@```'N2
M`0`%````CI(!``0```"4D@$`'@```)F2`0`9````N)(!`!T```#2D@$`$0``
M`/"2`0`>`````I,!`"T````ADP$`-@```$^3`0`2````AI,!`"@```"9DP$`
M!@```,*3`0`9````R9,!`!0```#CDP$`%@```/B3`0`5````#Y0!`!\````E
ME`$`$````$64`0`D````5I0!`"@```![E`$`$0```*24`0`)````MI0!`!$`
M``#`E`$`"@```-*4`0`/````W90!`!T```#ME`$`$0````N5`0`(````'94!
M``0````FE0$`#````"N5`0`-````.)4!``D```!&E0$`$0```%"5`0`&````
M8I4!``<```!IE0$`$````'&5`0`*````@I4!``X```"-E0$`#P```)R5`0`#
M````K)4!``P```"PE0$`$0```+V5`0`1````SY4!`!T```#AE0$`6````/^5
M`0`@````6)8!`!$```!YE@$`%0```(N6`0`%````H98!`!\```"GE@$`%P``
M`,>6`0`8````WY8!`!@```#XE@$`-@```!&7`0!#````2)<!`"P```",EP$`
M"0```+F7`0`T````PY<!`!@```#XEP$`'@```!&8`0`-````,)@!``D````^
MF`$`#0```$B8`0`$````5I@!``L```!;F`$`"P```&>8`0`:````<Y@!``L`
M``".F`$`&````)J8`0`4````LY@!``H```#(F`$`$````-.8`0`L````Y)@!
M`"\````1F0$`/@```$&9`0`Q````@)D!`"P```"RF0$`'@```-^9`0!$````
M_ID!`"P```!#F@$`/@```'":`0`L````KYH!`#T```#<F@$`/P```!J;`0`B
M````6IL!`"@```!]FP$`-P```*:;`0`Q````WIL!`"T````0G`$`+P```#Z<
M`0`\````;IP!`"(```"KG`$`)P```,Z<`0`_````]IP!`"L````VG0$`'```
M`&*=`0`I````?YT!`"8```"IG0$`'@```-"=`0`1````[YT!`,0````!G@$`
M.@```,:>`0`I`````9\!`"L````KGP$`+0```%>?`0`O````A9\!`#4```"U
MGP$`(P```.N?`0`H````#Z`!`"X````XH`$`,0```&>@`0`Y````F:`!`#0`
M``#3H`$`D`````BA`0`T````F:$!`!@```#.H0$`+0```.>A`0`K````%:(!
M`"\```!!H@$`1````'&B`0!*````MJ(!``\````!HP$`!@```!&C`0`*````
M&*,!``H````CHP$`$````"ZC`0`.````/Z,!`!<```!.HP$`%````&:C`0`H
M````>Z,!``\```"DHP$`#````+2C`0`$````P:,!`!$```#&HP$`(@```-BC
M`0`*````^Z,!``\````&I`$`%@```!:D`0`2````+:0!`!X```!`I`$`$```
M`%^D`0!+````<*0!``<```"\I`$`&````,2D`0`&````W:0!``\```#DI`$`
M%0```/2D`0`5````"J4!`!`````@I0$``@```#&E`0`)````-*4!`%T````^
MI0$`!P```)RE`0`1````I*4!`!D```"VI0$`!0```-"E`0`1````UJ4!`!(`
M``#HI0$`!@```/NE`0`.`````J8!`!L````1I@$`"````"VF`0`&````-J8!
M`!`````]I@$`#P```$ZF`0`?````7J8!`"$```!^I@$`%0```*"F`0`*````
MMJ8!``8```#!I@$`"@```,BF`0`/````TZ8!`!(```#CI@$`$0```/:F`0`7
M````"*<!`!4````@IP$`#P```#:G`0`/````1J<!`!$```!6IP$`*````&BG
M`0`@````D:<!`!$```"RIP$`'0```,2G`0`^````XJ<!``T````AJ`$`(```
M`"^H`0`3````4*@!`!H```!DJ`$`%P```'^H`0`&````EZ@!`"L```">J`$`
M'@```,JH`0`Q````Z:@!`$$````;J0$`'@```%VI`0`2````?*D!``4```"/
MJ0$`&P```)6I`0`&````L:D!`"\```"XJ0$`00```.BI`0`*````*JH!``H`
M```UJ@$`%0```$"J`0`,````5JH!`!(```!CJ@$`$@```':J`0`&````B:H!
M``H```"0J@$`"0```)NJ`0`R````I:H!`!D```#8J@$`)0```/*J`0!6````
M&*L!`"8```!OJP$`%@```):K`0`F````K:L!``@```#4JP$`.0```-VK`0`+
M````%ZP!`"P````CK`$`"0```%"L`0!`````6JP!`!L```";K`$`'````+>L
M`0`;````U*P!``L```#PK`$`+0```/RL`0`(````*JT!`!4````SK0$`)P``
M`$FM`0`(````<:T!``\```!ZK0$`/0```(JM`0`/````R*T!``P```#8K0$`
M!0```.6M`0!1````ZZT!``0````]K@$`!P```$*N`0`)````2JX!``T```!4
MK@$`#P```&*N`0`1````<JX!`!4```"$K@$`&````)JN`0`>````LZX!`!T`
M``#2K@$`(````/"N`0`>````$:\!``<````PKP$`"````#BO`0`(````0:\!
M``<```!*KP$`%@```%*O`0`%````::\!``D```!OKP$`(0```'FO`0`7````
MFZ\!`!````"SKP$`#@```,2O`0`,````TZ\!``P```#@KP$`&0```.VO`0`0
M````![`!`$,````8L`$`-@```%RP`0`-````D[`!``P```"AL`$`%P```*ZP
M`0`6````QK`!`'H```#=L`$`&@```%BQ`0`:````<[$!`!L```".L0$`$0``
M`*JQ`0`'````O+$!``0```#$L0$`)P```,FQ`0`V````\;$!`#T````HL@$`
M(@```&:R`0`U````B;(!`"H```"_L@$`+````.JR`0`8````%[,!`"<````P
MLP$`"@```%BS`0`'````8[,!``P```!KLP$`!@```'BS`0`-````?[,!``P`
M``"-LP$`$@```)JS`0`,````K;,!`!<```"ZLP$`"P```-*S`0`*````WK,!
M``X```#ILP$`"P```/BS`0`0````!+0!``<````5M`$`#````!VT`0`?````
M*K0!`!L```!*M`$`+@```&:T`0!-````E;0!`!<```#CM`$`!@```/NT`0`$
M`````K4!`"<````'M0$`,0```"^U`0`>````8;4!`!T```"`M0$`*P```)ZU
M`0`J````RK4!`"P```#UM0$`+0```"*V`0`<````4+8!``8```!MM@$`'```
M`'2V`0`.````D;8!`!<```"@M@$``P```+BV`0`#````O+8!``<```#`M@$`
M$````,BV`0`2````V;8!``T```#LM@$`%@```/JV`0`+````$;<!`"8````=
MMP$`!@```$2W`0`$````2[<!`!(```!0MP$`$@```&.W`0`.````=K<!``<`
M``"%MP$`#@```(VW`0`/````G+<!`"$```"LMP$`%````,ZW`0`@````X[<!
M`"(````$N`$`$P```">X`0`/````.[@!``P```!+N`$`'````%BX`0`-````
M=;@!`#,```"#N`$`(P```+>X`0`S````V[@!`$L````/N0$`2P```%NY`0`T
M````I[D!`$L```#<N0$`$@```"BZ`0`&````.[H!``H```!"N@$`"````$VZ
M`0`+````5KH!`!8```!BN@$`$0```'FZ`0`#````B[H!`!0```"/N@$`"```
M`*2Z`0`&````K;H!`%,```"TN@$`.0````B[`0`8````0KL!`(P```!;NP$`
M&0```.B[`0`,`````KP!``8````/O`$`#@```!:\`0`(````);P!``H````N
MO`$`!P```#F\`0`*````0;P!`"X```!,O`$`#````'N\`0`9````B+P!``(`
M``"BO`$`"````*6\`0`-````KKP!``T```"\O`$`#@```,J\`0`1````V;P!
M`!8```#KO`$`!@````*]`0`'````";T!``<````1O0$`$````!F]`0`(````
M*KT!``H````SO0$`!0```#Z]`0`@````1+T!``L```!EO0$`!@```'&]`0`D
M````>+T!`!$```"=O0$`!@```*^]`0`+````MKT!``4```#"O0$`"0```,B]
M`0`*````TKT!`!0```#=O0$`!0```/*]`0`%````^+T!``T```#^O0$`#@``
M``R^`0`,````&[X!``P````HO@$`&@```#6^`0`+````4+X!`!(```!<O@$`
M"````&^^`0`'````>+X!`!8```"`O@$`'````)>^`0!#````M+X!`"L```#X
MO@$`.````"2_`0`)````7;\!``H```!GOP$`!````'*_`0`)````=[\!``@`
M``"!OP$`%````(J_`0`+````G[\!``8```"KOP$`#0```+*_`0`&````P+\!
M`$````#'OP$`10````C``0!"````3L`!`"L```"1P`$`!0```+W``0`/````
MP\`!``,```#3P`$`!@```-?``0`&````WL`!`!L```#EP`$`#`````'!`0`4
M````#L$!``@````CP0$`"````"S!`0`C````-<$!``@```!9P0$`!P```&+!
M`0`0````:L$!``0```![P0$`"````(#!`0`,````B<$!``@```"6P0$`"P``
M`)_!`0`4````J\$!``\```#`P0$`"````-#!`0`(````V<$!``4```#BP0$`
M-````.C!`0`W````'<(!`#<```!5P@$`+````(W"`0!%````NL(!`$,`````
MPP$`+P```$3#`0!8````=,,!`#0```#-PP$`2@````+$`0`M````3<0!`!``
M``![Q`$`$````(S$`0`+````G<0!`",```"IQ`$`)````,W$`0`7````\L0!
M`"`````*Q0$`#````"O%`0`.````.,4!``H```!'Q0$`#````%+%`0`N````
M7\4!`"H```".Q0$`/P```+G%`0`&````^<4!`!X`````Q@$`,````!_&`0`<
M````4,8!`!8```!MQ@$`!@```(3&`0`+````B\8!``H```"7Q@$`$````*+&
M`0`E````L\8!`$8```#9Q@$`D0```"#'`0!T````LL<!``\````GR`$`#```
M`#?(`0`-````1,@!`!L```!2R`$`%P```&[(`0`.````AL@!``4```"5R`$`
M%0```)O(`0`&````L<@!`!4```"XR`$`$P```,[(`0`6````XL@!`!<```#Y
MR`$`-````!')`0"-````1LD!`!````#4R0$`!0```.7)`0`2````Z\D!`"\`
M``#^R0$`"0```"[*`0`L````.,H!``H```!ER@$`"@```'#*`0`H````>\H!
M`!<```"DR@$`$````+S*`0`5````S<H!`!````#CR@$`%@```/3*`0`7````
M"\L!`!8````CRP$`$P```#K+`0`3````3LL!`!P```!BRP$`&P```'_+`0`@
M````F\L!`#\```"\RP$`&0```/S+`0`8````%LP!`!<````OS`$`%@```$?,
M`0`2````7LP!`!P```!QS`$`&P```([,`0`3````JLP!`!,```"^S`$`,```
M`-+,`0`;`````\T!`!P````?S0$`0@```#S-`0`?````?\T!``4```"?S0$`
M%````*7-`0`M````NLT!`",```#HS0$`(0````S.`0`F````+LX!`"4```!5
MS@$`'0```'O.`0`C````F<X!`",```"]S@$`'````.'.`0`B````_LX!`$$`
M```ASP$`(@```&//`0`G````AL\!`"<```"NSP$`(````-;/`0`@````]\\!
M`",````8T`$`*0```#S0`0`B````9M`!`",```")T`$`#0```*W0`0`7````
MN]`!`!@```#3T`$`!````.S0`0`(````\=`!`!4```#ZT`$`"@```!#1`0`9
M````&]$!`!0````UT0$`!@```$K1`0`5````4=$!``0```!GT0$`"P```&S1
M`0`'````>-$!``8```"`T0$`!0```(?1`0`3````C=$!``8```"AT0$`"```
M`*C1`0`&````L=$!``8```"XT0$`"@```+_1`0`0````RM$!`!H```#;T0$`
M$````/;1`0`1````!](!``H````9T@$`&````"32`0`%````/=(!`#D```!#
MT@$`%@```'W2`0`1````E-(!`!$```"FT@$`#@```+C2`0`+````Q](!`!(`
M``#3T@$`+P```.;2`0`(````%M,!``@````?TP$`)````"C3`0`2````3=,!
M``\```!@TP$`!@```'#3`0`,````=],!`%X```"$TP$`"0```./3`0`%````
M[=,!`"0```#STP$`"@```!C4`0`6````(]0!``T````ZU`$`$P```$C4`0`8
M````7-0!`",```!UU`$`)P```)G4`0`*````P=0!``,```#,U`$`"@```-#4
M`0`B````V]0!``<```#^U`$``P````;5`0`1````"M4!`!(````<U0$`!P``
M`"_5`0`.````-]4!`!L```!&U0$`!0```&+5`0`'````:-4!`"H```!PU0$`
M#0```)O5`0`2````J=4!``H```"\U0$`$P```,?5`0`7````V]4!``P```#S
MU0$`#@````#6`0`.````#]8!``X````>U@$`!````"W6`0`1````,M8!`$,`
M``!$U@$`!@```(C6`0`%````C]8!`"<```"5U@$`%@```+W6`0`T````U-8!
M`!4````)UP$`#@```!_7`0`3````+M<!``\```!"UP$`$````%+7`0`/````
M8]<!`!X```!SUP$`'P```)+7`0`U````LM<!`"L```#HUP$`)@```!38`0`(
M````.]@!``@```!$V`$`"P```$W8`0`+````6=@!`!$```!EV`$`!````'?8
M`0`-````?-@!`"H```"*V`$`#0```+78`0`-````P]@!`"8```#1V`$`40``
M`/C8`0`=````2MD!``T```!HV0$`"````';9`0`(````?]D!``X```"(V0$`
M#@```)?9`0`5````IMD!``D```"\V0$``@```,;9`0`-````R=D!`",```#7
MV0$`!@```/O9`0`%`````MH!``D````(V@$`"P```!+:`0`)````'MH!``D`
M```HV@$`%````#+:`0`.````1]H!``8```!6V@$`"````%W:`0`/````9MH!
M``0```!VV@$`!0```'O:`0!K````@=H!``P```#MV@$`#P```/K:`0`@````
M"ML!`"$````KVP$`!P```$W;`0`%````5=L!`"D```!;VP$`*@```(7;`0`Q
M````L-L!`!$```#BVP$`"@```/3;`0`I````_]L!`!D````IW`$`"@```$/<
M`0`)````3MP!`"H```!8W`$`'@```(/<`0`I````HMP!`"@```#,W`$`*P``
M`/7<`0`@````(=T!``\```!"W0$`D````%+=`0"C````X]T!``4```"'W@$`
M!P```(W>`0`-````E=X!``4```"CW@$`$P```*G>`0`6````O=X!``8```#4
MW@$`60```-O>`0`>````-=\!`!````!4WP$`%@```&7?`0`D````?-\!`&8`
M``"AWP$`&`````C@`0`'````(>`!`!\````IX`$`,````$G@`0`(````>N`!
M``8```"#X`$`'@```(K@`0`%````J>`!``H```"OX`$`+@```+K@`0`M````
MZ>`!`#L````7X0$`$P```%/A`0`&````9^$!`"0```!NX0$`,0```)/A`0`U
M````Q>$!`%8```#[X0$`'P```%+B`0`K````<N(!`#0```">X@$`'````-/B
M`0`Y````\.(!``(````JXP$`&0```"WC`0`'````1^,!`!(```!/XP$`$0``
M`&+C`0`'````=.,!`!0```!\XP$`!@```)'C`0`(````F.,!``L```"AXP$`
M!P```*WC`0`*````M>,!``L```#`XP$`+````,SC`0`'````^>,!`!`````!
MY`$`$````!+D`0`/````(^0!``@````SY`$`"0```#SD`0`,````1N0!``T`
M``!3Y`$`&P```&'D`0`;````?>0!``H```"9Y`$`"0```*3D`0`*````KN0!
M``@```"YY`$`&P```,+D`0`>````WN0!`!0```#]Y`$`&@```!+E`0`6````
M+>4!`!8```!$Y0$`(````%OE`0`'````?.4!`!8```"$Y0$`+@```)OE`0`#
M````RN4!``<```#.Y0$`!0```-;E`0`%````W.4!``D```#BY0$`$````.SE
M`0`2````_>4!`#,````0Y@$`+@```$3F`0`B````<^8!`"0```"6Y@$`%P``
M`+OF`0`?````T^8!`!D```#SY@$`!P````WG`0`$````%><!``P````:YP$`
M#````"?G`0`1````-.<!``8```!&YP$`"@```$WG`0`>````6.<!``D```!W
MYP$`"0```('G`0`K````B^<!`"4```"WYP$`#P```-WG`0`%````[><!``P`
M``#SYP$`"0````#H`0`1````"N@!`!`````<Z`$`"@```"WH`0`)````..@!
M``4```!"Z`$`!P```$CH`0`'````4.@!``0```!8Z`$``P```%WH`0`T````
M8>@!`%D```"6Z`$`+0```/#H`0`[````'ND!`#X```!:Z0$`1````)GI`0`;
M````WND!`#T```#ZZ0$`#P```#CJ`0!`````2.H!`"D```")Z@$`'@```+/J
M`0`>````TNH!`",```#QZ@$`-@```!7K`0`-````3.L!`#````!:ZP$`.P``
M`(OK`0`8````Q^L!`!D```#@ZP$`%0```/KK`0`5````$.P!``\````F[`$`
M%````#;L`0`5````2^P!`"$```!A[`$`/0```(/L`0`^````P>P!`$$`````
M[0$`/@```$+M`0`_````@>T!`#T```#![0$`;0```/_M`0`>````;>X!`!8`
M``",[@$`&@```*/N`0`>````ONX!`"4```#=[@$`#P````/O`0`5````$^\!
M`!`````I[P$`.P```#KO`0`K````=N\!`"T```"B[P$`"@```-#O`0`I````
MV^\!`"L````%\`$`!0```#'P`0`F````-_`!`!8```!>\`$`#@```'7P`0`.
M````A/`!`!<```"3\`$`"````*OP`0`*````M/`!``P```"_\`$`#@```,SP
M`0`?````V_`!`"\```#[\`$`#P```"OQ`0`/````._$!``P```!+\0$`)@``
M`%CQ`0`C````?_$!``@```"C\0$`!````*SQ`0`0````L?$!``X```#"\0$`
M"P```-'Q`0`U````W?$!``(````3\@$`"````!;R`0`7````'_(!``P````W
M\@$`!P```$3R`0`&````3/(!`!$```!3\@$`*P```&7R`0`-````D?(!`!P`
M``"?\@$`!````+SR`0`W````P?(!`!L```#Y\@$`(P```!7S`0`>````.?,!
M`'<```!8\P$`%P```-#S`0!(````Z/,!`"<````Q]`$`$@```%GT`0`&````
M;/0!`#,```!S]`$`#@```*?T`0`4````MO0!``D```#+]`$`$0```-7T`0`.
M````Y_0!`!X```#V]`$`%0```!7U`0`%````*_4!`!`````Q]0$`$0```$+U
M`0`*````5/4!`!H```!?]0$`,@```'KU`0`5````K?4!`!4```##]0$`&```
M`-GU`0`3````\O4!`!\````&]@$`!P```";V`0`7````+O8!``L```!&]@$`
M%````%+V`0`4````9_8!`!8```!\]@$`$````)/V`0`6````I/8!`!@```"[
M]@$`"P```-3V`0`)````X/8!``4```#J]@$`'0```/#V`0`&````#O<!``\`
M```5]P$`"````"7W`0`2````+O<!``8```!!]P$`)````$CW`0`4````;?<!
M`#,```""]P$`%0```+;W`0`'````S/<!``@```#4]P$`'@```-WW`0`+````
M_/<!`!L````(^`$`!P```"3X`0`C````+/@!``<```!0^`$`"````%CX`0`D
M````8?@!`#L```"&^`$`"P```,+X`0`E````SO@!`"<```#T^`$`#0```!SY
M`0`:````*OD!`!````!%^0$`!````%;Y`0`.````6_D!``X```!J^0$`!P``
M`'GY`0`.````@?D!``@```"0^0$`!0```)GY`0`)````G_D!`!T```"I^0$`
M)@```,?Y`0`_````[OD!`"@````N^@$`)0```%?Z`0`?````??H!`#L```"=
M^@$`'@```-GZ`0`A````^/H!`"H````:^P$`,@```$7[`0!=````>/L!`"4`
M``#6^P$`#0```/S[`0`(````"OP!``H````3_`$`"@```![\`0`1````*?P!
M`!8````[_`$`1P```%+\`0`E````FOP!`!H```#`_`$`.````-O\`0!`````
M%/T!``D```!5_0$`)@```%_]`0`+````AOT!`!0```"2_0$`)P```*?]`0`,
M````S_T!`!D```#<_0$`#````/;]`0`.`````_X!``X````2_@$`#P```"'^
M`0`0````,?X!``\```!"_@$`&P```%+^`0`:````;OX!`#4```")_@$`"P``
M`+_^`0`:````R_X!``4```#F_@$`%0```.S^`0`%`````O\!`!X````(_P$`
M#0```"?_`0`7````-?\!``,```!-_P$`#````%'_`0`0````7O\!``4```!O
M_P$`#@```'7_`0`(````A/\!``\```"-_P$`!0```)W_`0`'````H_\!`!``
M``"K_P$`20```+S_`0!0````!@`"`!$```!7``(`&````&D``@`G````@@`"
M``D```"J``(`,@```+0``@`K````YP`"`!,````3`0(`*P```"<!`@`1````
M4P$"``D```!E`0(`#````&\!`@`0````?`$"`#(```"-`0(`!@```,`!`@`-
M````QP$"``X```#5`0(`%0```.0!`@`-````^@$"`%P````(`@(`"@```&4"
M`@`E````<`("`!4```"6`@(`%@```*P"`@`L````PP("`"8```#P`@(`/@``
M`!<#`@!!````5@,"`#L```"8`P(`#@```-0#`@`%````XP,"`!,```#I`P(`
M'````/T#`@`@````&@0"``@````[!`(`&````$0$`@`3````700"`!@```!Q
M!`(`&P```(H$`@`'````I@0"`!\```"N!`(`%P```,X$`@`0````Y@0"``0`
M``#W!`(`$@```/P$`@`3````#P4"`!0````C!0(`!@```#@%`@`'````/P4"
M`!,```!'!0(`#@```%L%`@`/````:@4"`!$```!Z!0(`$0```(P%`@`&````
MG@4"``<```"E!0(`%0```*T%`@`3````PP4"`!8```#7!0(`&````.X%`@`,
M````!P8"``@````4!@(`!P```!T&`@`H````)08"`"0```!.!@(`(````',&
M`@`(````E`8"``\```"=!@(`!@```*T&`@`8````M`8"`"D```#-!@(`*0``
M`/<&`@`*````(0<"`!@````L!P(``P```$4'`@`6````20<"``@```!@!P(`
M`P```&D'`@`2````;0<"`!0```"`!P(`"P```)4'`@`8````H0<"`",```"Z
M!P(`%P```-X'`@`&````]@<"``H```#]!P(`%`````@(`@`7````'0@"``P`
M```U"`(`!@```$((`@`,````20@"``H```!6"`(`%0```&$(`@`5````=P@"
M`'D```"-"`(`'P````<)`@`O````)PD"`!0```!7"0(`"````&P)`@`*````
M=0D"`!0```"`"0(`'P```)4)`@`F````M0D"`"D```#<"0(`!P````8*`@`7
M````#@H"``@````F"@(`%P```"\*`@`8````1PH"`!8```!@"@(`(@```'<*
M`@`=````F@H"`!(```"X"@(`)0```,L*`@`1````\0H"`"8````#"P(`&```
M`"H+`@`7````0PL"`!<```!;"P(`@P```',+`@`H````]PL"`!\````@#`(`
M.````$`,`@`G````>0P"`!X```"A#`(`*P```,`,`@`C````[`P"`"<````0
M#0(`%P```#@-`@`4````4`T"``L```!E#0(`!0```'$-`@`(````=PT"``D`
M``"`#0(`"@```(H-`@`5````E0T"``L```"K#0(`.P```+<-`@`I````\PT"
M`#<````=#@(`%@```%4.`@`&````;`X"`$4```!S#@(`50```+D.`@`T````
M#P\"`)P```!$#P(`*@```.$/`@`+````#!`"`#<````8$`(`+P```%`0`@`2
M````@!`"``@```"3$`(`$P```)P0`@!$````L!`"``P```#U$`(`(`````(1
M`@`D````(Q$"`%@```!($0(`2````*$1`@`H````ZA$"`!0````3$@(`(@``
M`"@2`@`B````2Q("`"P```!N$@(`(@```)L2`@`K````OA("`!\```#J$@(`
M%0````H3`@`'````(!,"`!`````H$P(`%````#D3`@`-````3A,"``L```!<
M$P(`40```&@3`@`,````NA,"`!X```#'$P(`$0```.83`@`?````^!,"``D`
M```8%`(`!0```"(4`@`8````*!0"``D```!!%`(`"0```$L4`@`'````510"
M``<```!=%`(`"0```&44`@`2````;Q0"`!P```""%`(`#P```)\4`@`?````
MKQ0"`!````#/%`(`"````.`4`@`-````Z10"`"8```#W%`(`"P```!X5`@`*
M````*A4"`!@````U%0(`)@```$X5`@`,````=14"`"(```""%0(`*P```*45
M`@`+````T14"``@```#=%0(`(0```.85`@`-````"!8"`!D````6%@(`&P``
M`#`6`@`4````3!8"`!8```!A%@(`$@```'@6`@`%````BQ8"``D```"1%@(`
M"````)L6`@`)````I!8"``H```"N%@(`%````+D6`@`'````SA8"`$8```#6
M%@(`$````!T7`@`*````+A<"``@````Y%P(`#````$(7`@`A````3Q<"``P`
M``!Q%P(``@```'X7`@`C````@1<"`!T```"E%P(`!0```,,7`@`&````R1<"
M``H```#0%P(`>@```-L7`@`*````5A@"``@```!A&`(`*@```&H8`@`Z````
ME1@"`!H```#0&`(`+@```.L8`@!=````&AD"`",```!X&0(`,P```)P9`@`O
M````T!D"`"4`````&@(`!@```"8:`@`-````+1H"``@````[&@(`"0```$0:
M`@`%````3AH"``@```!4&@(`$@```%T:`@`*````<!H"``D```![&@(`"P``
M`(4:`@`+````D1H"`!H```"=&@(`"````+@:`@`)````P1H"`!4```#+&@(`
M"@```.$:`@`*````[!H"``4```#W&@(`+@```/T:`@`F````+!L"`!@```!3
M&P(`!P```&P;`@`2````=!L"``D```"'&P(`#P```)$;`@`S````H1L"``@`
M``#5&P(`&````-X;`@`8````]QL"``8````0'`(`!@```!<<`@`-````'AP"
M`!P````L'`(`!@```$D<`@`)````4!P"``L```!:'`(`'````&8<`@`+````
M@QP"``T```"/'`(`*@```)T<`@`?````R!P"`!@```#H'`(`!@````$=`@`+
M````"!T"`!`````4'0(`#0```"4=`@`#````,QT"``X````W'0(`"````$8=
M`@`=````3QT"`"\```!M'0(`,````)T=`@`J````SAT"`"X```#Y'0(`+@``
M`"@>`@`R````5QX"`#L```"*'@(`C@```,8>`@`6````51\"`&,```!L'P(`
M.````-`?`@!A````"2`"`&D```!K(`(`(0```-4@`@`@````]R`"`$T````8
M(0(`/````&8A`@!'````HR$"`!X```#K(0(`&`````HB`@`C````(R("`/T!
M``!'(@(`'0```$4D`@`=````8R0"`$D```"!)`(`H````,LD`@`T````;"4"
M`"D```"A)0(`1P```,LE`@!:````$R8"`&0```!N)@(`,@```-,F`@`@````
M!B<"`!X````G)P(`-````$8G`@`<````>R<"`!\```"8)P(`)````+@G`@`@
M````W2<"`"8```#^)P(`+P```"4H`@`:````52@"`!8```!P*`(`,0```(<H
M`@`J````N2@"`"0```#D*`(`/`````DI`@`:````1BD"`#(```!A*0(`<0``
M`)0I`@`[````!BH"`#H```!"*@(`,@```'TJ`@`I````L"H"`$<```#:*@(`
M;0```"(K`@!?````D"L"`"X```#P*P(`*@```!\L`@`P````2BP"`#````![
M+`(`,P```*PL`@!.````X"P"`&8````O+0(`30```)8M`@!3````Y"T"`$D`
M```X+@(`)P```((N`@`G````JBX"`"0```#2+@(`>````/<N`@!M````<"\"
M`'<```#>+P(`S@```%8P`@`<````)3$"`"P```!",0(`-@```&\Q`@`N````
MIC$"`%````#5,0(`'````"8R`@!`````0S("`#\```"$,@(`!0```,0R`@#(
M````RC("`$8```"3,P(`(@```-HS`@`^````_3,"`"<````\-`(`'````&0T
M`@`L````@30"``D```"N-`(`%@```+@T`@`#````SS0"`!8```#3-`(`#```
M`.HT`@`-````]S0"``L````%-0(`!P```!$U`@`-````&34"``<````G-0(`
M=0```"\U`@`(````I34"``(```"N-0(`%@```+$U`@`$````R#4"``<```#-
M-0(`!@```-4U`@`%````W#4"``4```#B-0(`%0```.@U`@`*````_C4"`!(`
M```)-@(`#P```!PV`@`"````+#8"``<````O-@(`"P```#<V`@`2````0S8"
M``T```!6-@(`&0```&0V`@`&````?C8"`!D```"%-@(`"@```)\V`@`#````
MJC8"`%L```"N-@(`!`````HW`@`&````#S<"``<````6-P(`)P```!XW`@!,
M````1C<"`$8```"3-P(`1P```-HW`@`J````(C@"`"X```!-.`(`,0```'PX
M`@`=````KC@"`"(```#,.`(`'````.\X`@`R````##D"`"H````_.0(`)```
M`&HY`@`F````CSD"`"<```"V.0(`+@```-XY`@`K````#3H"`!X````Y.@(`
M*0```%@Z`@`J````@CH"`!\```"M.@(`(P```,TZ`@`A````\3H"`!D````3
M.P(`(@```"T[`@`L````4#L"`#(```!].P(`,P```+`[`@`G````Y#L"`!T`
M```,/`(`)````"H\`@`I````3SP"`!T```!Y/`(`)P```)<\`@`X````OSP"
M`#L```#X/`(`&0```#0]`@`C````3CT"`#H```!R/0(`(@```*T]`@`F````
MT#T"`"0```#W/0(`)0```!P^`@`<````0CX"`"0```!?/@(`,````(0^`@`>
M````M3X"`#$```#4/@(`(0````8_`@`V````*#\"``D```!?/P(`$````&D_
M`@`B````>C\"`$<```"=/P(`+````.4_`@`,````$D`"``\````?0`(`%P``
M`"]``@`2````1T`"`!````!:0`(`)P```&M``@`&````DT`"``H```":0`(`
M)0```*5``@`H````RT`"`!L```#T0`(`*````!!!`@`<````.4$"``\```!6
M00(`]````&9!`@`5````6T("`!<```!Q0@(`"0```(E"`@`7````DT("`"(`
M``"K0@(`'0```,Y"`@`>````[$("``D````+0P(`/@```!5#`@`/````5$,"
M`!8```!D0P(`!P```'M#`@`;````@T,"`!$```"?0P(`3@```+%#`@`0````
M`$0"`"(````11`(`'````#1$`@`8````440"`",```!J1`(`80```(Y$`@`G
M````\$0"`!`````810(`)P```"E%`@`1````444"`!(```!C10(`&````'9%
M`@`+````CT4"`!T```";10(`%P```+E%`@`G````T44"`$H```#Y10(`'P``
M`$1&`@`+````9$8"`#,```!P1@(`/0```*1&`@`'````XD8"`!,```#J1@(`
M!P```/Y&`@`'````!D<"``D````.1P(`20```!A'`@`&````8D<"``T```!I
M1P(`$````'='`@`6````B$<"``L```"?1P(`#````*M'`@`'````N$<"`!$`
M``#`1P(`#P```-)'`@`<````XD<"`!<```#_1P(`%````!=(`@`8````+$@"
M``P```!%2`(`#@```%)(`@`L````84@"``X```".2`(`-@```)U(`@`:````
MU$@"`!````#O2`(`#@````!)`@`#````#TD"`!0````320(`&P```"A)`@`#
M````1$D"``D```!(20(`!P```%))`@`*````6DD"``X```!E20(`#@```'1)
M`@`;````@TD"`!P```"?20(`#@```+Q)`@`4````RTD"`#0```#@20(`&@``
M`!5*`@`5````,$H"`!D```!&2@(`#0```&!*`@`R````;DH"`!,```"A2@(`
M(````+5*`@`\````UDH"`!,````32P(`"0```"=+`@`7````,4L"`%8```!)
M2P(`%0```*!+`@`9````MDL"``H```#02P(`!````-M+`@`$````X$L"`!8`
M``#E2P(`%0```/Q+`@`%````$DP"``8````83`(`"@```!],`@`-````*DP"
M``4````X3`(`#@```#Y,`@`2````34P"`#\```!@3`(`,@```*!,`@`I````
MTTP"`"````#]3`(`'````!Y-`@`C````.TT"`"@```!?30(`(````(A-`@`5
M````J4T"``(```"_30(`!````,)-`@`-````QTT"``8```#530(`!0```-Q-
M`@`$````XDT"`!$```#G30(`>````/E-`@`D````<DX"`"T```"73@(`-P``
M`,5.`@`M````_4X"`"\````K3P(`(P```%M/`@!(````?T\"`!D```#(3P(`
M%@```.)/`@".````^4\"`"(```"(4`(`5````*M0`@`A`````%$"`%<````B
M40(`+@```'I1`@`I````J5$"`$````#340(`,P```!12`@!4````2%("`"\`
M``"=4@(`/P```,U2`@`=````#5,"`"4````K4P(`*````%%3`@!-````>E,"
M`!````#(4P(`&P```-E3`@`4````]5,"`'4````*5`(`"@```(!4`@#6````
MBU0"`(4```!B50(`?@```.A5`@`X````9U8"`'H```"@5@(`'````!M7`@`W
M````.%<"`"H```!P5P(`$@```)M7`@`E````KE<"`"0```#45P(`1@```/E7
M`@`B````0%@"`!P```!C6`(`60```(!8`@`O````VE@"`"8````*60(`"P``
M`#%9`@`%````/5D"``8```!#60(`"````$I9`@`B````4UD"``X```!V60(`
M#@```(59`@`@````E%D"`"@```"U60(`"P```-Y9`@`L````ZED"`"D````7
M6@(`#P```$%:`@`.````45H"``L```!@6@(`"0```&Q:`@`A````=EH"`"D`
M``"86@(`"P```,):`@`*````SEH"``D```#96@(`%@```.-:`@`D````^EH"
M``T````?6P(`#@```"U;`@`4````/%L"`"L```!16P(`%0```'U;`@`'````
MDUL"``X```";6P(`$0```*I;`@`-````O%L"``P```#*6P(`%@```-=;`@`-
M````[EL"`!@```#\6P(`%````!5<`@`%````*EP"``H````P7`(`%````#M<
M`@`"````4%P"``8```!37`(`!P```%I<`@`E````8EP"`"(```"(7`(`#@``
M`*M<`@`0````NEP"`!(```#+7`(`)````-Y<`@`1`````UT"`"P````570(`
M"0```$)=`@`5````3%T"``<```!B70(`!````&I=`@`$````;UT"`",```!T
M70(`"P```)A=`@`"````I%T"`!4```"G70(`"````+U=`@`'````QET"`!$`
M``#.70(`$0```.!=`@`$````\ET"`"<```#W70(`!P```!]>`@!)````)UX"
M``,```!Q7@(`+P```'5>`@`O````I5X"``L```#57@(`!````.%>`@`(````
MYEX"`!P```#O7@(`!0````Q?`@`G````$E\"`!T````Z7P(`"0```%A?`@`D
M````8E\"`!H```"'7P(`(0```*)?`@`@````Q%\"``L```#E7P(`#````/%?
M`@`,````_E\"``T````+8`(`*0```!E@`@`*````0V`"`!\```!.8`(`!0``
M`&Y@`@`#````=&`"``$```"*````L00``````````````0<``+`"````````
M)`8``.H'``#(!@``4@```,,#```H`````````%P'``````````````````"'
M!0``[0$```````#%`P``,P8``%8%````````(P@```````!H!P``70<``","
M``!]!```J@8``.@&```O!0``RP(````````-`P``YP<```````!B!0``D`$`
M`(L$``":!0``,P$``&T```"-!P````````````"D`P````````````#!!P``
M2`<```````#7!P``%0````\(``"4`P``'0,``+4#````````I0,``)$!``"G
M`@````````T%`````````P```&<"````````70$````````5`@```````/X$
M```L````/00``)L#````````1`8``,$$``#P`0````````````#N!```U@<`
M`+\&``````````````````",!@````````````!2!`````````````!S!```
M`````(X"```;````@@<``*L#````````HP0``"H(````````E@<``.P&````
M````Y00``$L#``!_`@```````*H!``!A`0``PP$``(@&````````#`4``$T'
M````````Q08``-`&``"(!P``B0$``%D!``"]`P``````````````````@0$`
M`(H"``#!`P``K`$```\!``"$!```T0```'<!``#R`@``G@0``%P!``"J`@``
M6@4````````:!0``@@8``(`$``!'`P``````````````````$@<```````"W
M!P``A0,``$T!``">`P``X`(````````K!P``%0,```D'``!:`0```````*$`
M``!>!@``;P4```````#Y````;0(````````-`@```````/\"````````````
M`*('``"-````=`````````#)`P``:00``)X&``"B`P``000``&(```#5`0``
MN@0````````S`@``6@,``(@$```9!@```````*T'`````````````#T"````
M````(0(``-L```!H````?P,``+\````T`0``*P(``)L$```1````]P4``$@&
M```D````708``#<&````````;@<``!\&```L"```M08```````"/`@``CP0`
M`(<#```1"```<@8``-(!````````"`0``%0'```V`0``H`<```P"````````
M:P```/`&`````````````$D$```1!0```````/D#``````````````````!^
M!@``O08``.8$```K`0``M`(``*($``"`````-0(```````"?!P``=P4``-\#
M``";`0``.`4``(\````R!P``!P<``#@#```Q"```;@$``)L"````````````
M`*<#``#.!```!`8``(H%``!<````JP$``/H"``!R!0``;@```(<$````````
M5`,```D#``!_!@```0(``-@#``#'`P`````````````:`0````````4%````
M````DP$`````````````1@$``*4"``!G!P````````````!+`````04``%@!
M````````A`4``/@'``!4!@``20$``!P'`````````````',%```0!0``%0@`
M`'D$``#Z!```$0$```````!4`0````````````!B!```7@0``+T`````````
M/P(``/`%``!P!0``;P$```````#2`P```P,``%$!``"?!@``"@<``,H#``!Z
M!@`````````````$`0```````%@'``#8!P````````4&``!D!```400``!<%
M``#9`````````$H#``#5!```%P$``!,"````````,0,```````"T`0``;P``
M`!T`````````>@```&$'``!'``````````````"*`0``(P<``.<$``"#````
MZP(``#4$``"=`0`````````#`````````````"H"``!"`0```````&T#``!]
M!0```````/X&``"@!0``$P$````````.````(`0``-4`````````8P(`````
M``#Z````Q````#D#```H!0``500```8!``"R!P```````+T%``"C!P``,`8`
M`+T!``":!P``_08``&8!`````````````-P$``"+`P``IP0``%,%``!D!P``
M`@,```````!^`0``H0(``.L```#,!0``OP<``-`'````````$00``-<!``#"
M`P```````%0$````````G00```````#U`@``&P$``/(```#S!0```````&8$
M````````TP,``#H!```Z!0``>`<``.\"````````&00``+\!``#R!```````
M`"<'````````P`$```````#[`P``(P8``(T%``"3!@``6`8``)P&````````
M``````$#``"M!0````````````"<`P````````\```".!```P0```%4!```9
M`P``)`<``,T&``"%!0```````-`$``#(!0``!`(``#L&```A!P``5P(`````
M``!]!@````````````#5!@```````#<%````````1P$``%$'```4`P``````
M`-L#``!$!P``,0```+D"``"(`0``;@(``+@"``"M`0``\P(``)````!I`P``
M%P```.@"````````^P0``$8&`````````````+L$`````````````.\!````
M````VP(```````!&`P``C0$``,8$``#[````"`(``"T(``"A!````````!D`
M`````````````'P'``!E!P``?P4``,\%````````P0(```````!G`P``X08`
M``````"^!```W@8``&$#`````````````)(```#$!0````````````!]`P``
MS`$``,(```!_`0``5P,``&4$````````M0(```````#^`````````*\#```Q
M!0``%@```)$%``!<`P```@8``,$&``#I`0``%`<`````````````0`<``(0&
M````````?P<```````#.!@```````/\$``"#!P``0P$``'<#``!,!P``````
M`&8&`````````````,<'``"9`@``W`<``"T#``"9!```!@<``&4&``!N`P``
M0P0``.<%``#Q!P``.`<``$<"``!.`P``#P,``.,"``````````````````!L
M````9@<```````#:!@``#@4``#T```!``@``'04``/D%``"M````*P```"<"
M````````KP```%D'````````3@(``%H$````````)@,``,`'``#O````/`,`
M`*X'``"Y!```#P0``*`"``"+!0``M````)\"``"&!```9P$``#<$``!"!@``
ML0,``&L'```0!```O`0``.,```!T`0```````/X%```B`0``GP```/4'```<
M!@``5`(``+D&``#=`0``@@0``,D"```I``````````````"N`P``2`4```,(
M````````N````&\"``#=!P``704``&,!``#G`P``$@8``#D!``#Z!P``504`
M`'4"``"Y`0``N`4``#L!````````+P,``!0````9`@````````````"M!```
M%@8``,8&````````4`0``,T'```<"```IP`````````(`P```````#8```#Y
M!````````"T!``"\!0````````T````B`````````*,```#X`@``F@``````
M```J`0``+`$``!8'``")!@``$@0```````!%`P``E`<``,@'``!R`@``60``
M`(L'``"F!0```````!X#``#J`@```````,H!``!-`P``0P8```D(``!R````
MOP0``+0&``#2`@``Z04``*$'```&"```6P0```L#```G!``````````"``##
M`@``\@4``*D```#2!0```````,8#``"+`0``R@```(,"````````'P$``%(&
M``#K!P```````#X#``",`@```````"D'````````R`(``/\&``!>`@``````
M`-`#``"'!P``F08``'8```"6`P``T0<``!`(``"C`@``#P4```0%``"6`0``
M>0```,T"``#"`@````````````#=`P``R00```````!D````1`(``$\#````
M````10```%<```"O`@``QP8````````Z!P``U0(```````````````````D$
M````````6P<```````#<`P``6P8````````4!0``J@4``&D%````````````
M`.$!```0`@``6P,``*8!``````````````````"3!```&@0``!,&``#1`0``
MI`<``#0%``#)!0``+P0``/,#``#C`P``/`4``%L"``#O!@``J`4``)\$``!V
M!P``_@,```4$``#J`0````````X$````````TP```/<"``!@!P``C@,```(`
M```/!P```````%\!``"S!P``"0(```````!*!P``FP<``/<!``!@!0``I```
M`#(&``#N`P````````````!Q!```G0<``,\"````````?P```"`&``#T`@``
M[P0``.0!``#)!P```````"L%````````TP$``$L&````````60,``/D"``#@
M`P``T0,``#(!```+"````````,,$```A"```(`(`````````````$@,`````
M``#]`@``40(``.`&````````"@4``*D#````````'P(```P(``"K!@``Q04`
M``````#A`P``X@$````````9`0``X`$``'8"```:"```R`,``!@`````````
MQP$```````"4`0````````````!9!@```````/H!````````F`0``)D%``#Y
M!@``.`8``($"``!;`0`````````````:!@``K@(``)(!```(`0``%P,``),"
M``"5`P``E@8``%4"``!,!@``W````%X%``#T````\0(``*D&``!Y!P``````
M`.T$````````P@8``,D!``!W!@``7`0``(H#``!W````:0(``,``````````
MX@(```````#5`P``)P4``'D#````````NP<``+8!``!%!P``[`0```P$``"&
M`0``'@0``,T!`````````````)(#``""!0````````````"^`P``Y@```$(#
M```W````O0<``#H```"D`@``7`8``-`"````````O00``/(#```5!P``````
M`+,#````````J`8`````````````A0```.\%``"V``````<``"$&``!?!```
MU0<``"`%````````\04``!0(``"S`0`````````````<!0```````+D%``!U
M````0P(``!H"``"!!0``NP```.L$``"F!P``UP8``#0'```U!0``X@<``&0&
M``"2!P``804``'$%``````````````````"C!0``*@```(,%```2"```=P<`
M`````````````````+`!``#0`0``>`(``+8'``",````L````$`&````````
M``````````!/!P``_0<```````"?`P```````+X"``"$!P```````$X!````
M````=P(```,&``"W!@``L08``$0```!E!0```````-D"```N!```AP(``%X#
M```2`0````````L!``"D!@``TP8``/$!``"R`P``50,``.D'``#K!0``Q`,`
M```````=`0``````````````````D`(``"@(``````````````<$````````
MU`<``/('``"0!P``4`<```````"<!0``K`0``/\```"6`@``%`8```````!/
M`0``>@<```````!@````_0,``&H%``#P!```[P<``,T```"5!0``[`,`````
M````````?`,``.X!``!@`P``TP0```````!6!@```````&H```#D!0``_00`
M`#D%```<`P``(P4``/L&````````-@<``/\!````````O@<````````(````
M^`,``'($```"!0```````$8%``"``@``FP4``*X$``#3!P```````*8#``"C
M`0``B@8``!L$````````N`8```````"4!```QP4``#$'```T!@``Y0,``'$`
M```!`0``X0(``/$#``!J!```"0```+H```#4!````````*`#``!Q!P``M`,`
M``````#?`0``*`8``/4````.`0``WP````````"0!@``KP8``*@!``#@!0``
M;`4``#P!``#;!P``]`,``#L`````````<`<``"$```!X!````````(L"```2
M!0``L`4`````````````2`(``-T``````````````"@#``",!P``#0$`````
M```D`0``B`4```````"W`@``Z08`````````````U@8``&P$``!3!```D0,`
M`/L'```B`@``\08```````#6`0````````<!``"@`0``_0````0(``#.`0``
M`````%<&``#4!0``E`(```````![`P``)0$``"X&```X`@``Z00```````"B
M`@``:`8`````````````70,````````>!0``?P0``.H```#+!@``4````#@!
M``!^!0``NP(``````````0``.@0```````!,!`````````````"-`P``#`,`
M`(8'````````$`<``*T#````````_`8``'P!```U`0````````````!U`P``
MO@```/0!``#@!P``V00``,8```"A!@``QP0``"$#````````H````&('```3
M!0```````)D'````````90,``-P%````````OP4``&L$````````C@8```(!
M``"(`@``V08``/T%```Y!P``A@(```````!8````!@```$,'``#J!@``W@``
M`),'```````````````````[`P``WP(````````@`P```````(,&``!^!P``
MG`0``+$!```\!P``(`$`````````````8P0``*4$```"`@``#0@``($$``"Z
M`P``U````&0"```[!0``GP$`````````````P`,``!L'``!(`0``LP```'X#
M``#%!P``G`$``!@!``"U!```%`$``&X&``"+!@``(@0```````#1!```X0``
M`"\```#D!P````````````!U`0``I`4``*,&``#+`P``````````````````
MG04``&X$``"#`0``EP8``+X!``"&`````````,\````[!````````!8#```B
M`P```````.T```#H!P``T08`````````````_P<``#$"````````<P<`````
M``"V`@``````````````````(00``+\"``!^````TP(``)0````E!@``4P<`
M`%<%``#*!0``/@(``$4!``#8!```?`8``+($``#G!@``%04``'H%``!8!```
M"P<``'4$````````@08```8&``"Z!0``W@,``$X$```1!@``Q`<``,@```!+
M`0```````.L&``#'`@``/`(``,8'``#\!0```````(4&``!-!````````)0%
M```U`P``-P(````````1!P```````/<```#H!0``Y0`````````=!```+P(`
M```````.`P``1`$```````#H`P```````"(&```N!0``)P8`````````````
MT04```((```<````LP(``*H$```0`0``I@(``*8&```:````7@```$`%``#M
M!@``3`4``#\!```>````````````````````"`4``*D$``#*!```4P(`````
M``#6`@``1P8``,,```!Y`@``OP,``#\#``"X`P````````````!*!```'`$`
M`($`````````)`4``&X%``#E!P``XP<``*L$``"\`P````````<````S`P``
M.@8``!4$``!L!P````````````!&````)`0``,D&``!F`P``````````````
M````M@,``%,#````````.00```````#?!```Q`8``*D%``!M!````````"D%
M``!/`@``JP```+@$```O!P``JP4``*X```#2!```KP$``-0#````````J`0`
M``4!``!S`0``>P(```````"8!@``_`(``#,$``!-!0```````%,`````````
M`````$(```!Z`0``/@````````!'!0```````'$!``"'!@``V04``-0"```F
M!0``^@8``(P#```H`@```````%@"````````E`8``.8"``!-````^```````
M``#E!@```````(D$`````````````',#``"K!P``&P4``-\'``"&`P``````
M`+T"``!E````"P4``+<```"P!```)@$```<&```A`0``#`8````````R`P``
M`````+H'````````E08``!````#<!@``H0$``'0#```;"```*@,```H#``#K
M`P```````"8(``"1!@``UP(``*\$````````8P4``+0'``!U!P```````'0'
M``#>`0````````,'````````<@<``)T```#B!0``K@4``!D'```I"```'`0`
M`+D#```K!`````````\"```8!0```````'H"``!F!0```````-D!``#I`P``
M`````%8"``"!!P``0````.H%```("```E0$``%\"```D`P``U`$``-<$``"&
M!@```````+D'````````V@<``-<#````````W@4``)H!`````````````&<&
M``"3!0``J`(``&$$``!!`P```P$``&$``````````````&H#````````W0(`
M`"P#``#V!P``H04```````!]`@``7`(``.````#6!`````````````"B!@``
MRP<``)<$```]!P```````!,(``";!@``"`<``$H!``",`0``&`,``'(#``!O
M!P``\````,X'```E`@``!P@```````"[`P``"@```!,#````````(P```,P'
M````````````````````````)`(``&@%``#.!0``90$`````````````F0,`
M`'4&``"/!P``(````$T&``!D!0``+0```/`"````````R0`````````2````
M,`0``#8$``"X!P``>P$``$X'```Y````O`$``'(!``"H!P``,P<``*D"``!,
M`P``0`0``.T%``#:`@``50<``+<%```_!P``P`4```````#N!P```````,L`
M``#S!```"@(``(D```#\!P``%@0```````"L`@``00(``/$```#2!@``%@@`
M`,\'``!;````D0```.P"````````D00``'$"``!P`0```````$H%``"Q`@``
M``````X&``!=`@``-`0```8#``!"`@``$P0`````````````30(``.@`````
M`````````-T%```#!0``S@(```````#<`@``)0``````````````0`,``%H&
M````````CP,``,('```'!0``5P$``-H````N`P``[`4``(T&``":`P``````
M`,P```"9````S@```%(#````````/@$```````#>!```!P,``.\#````````
M20````````!&!```?0```+("```L`@``P@$``.T#````````EP````````#!
M!0``[0<```````#V`````````"H%``"7`0````````````"'`0``#0<``/X"
M````````404```````"=`@``Q`$```````!?`P```````&P&```Q!@``^0<`
M`,0$````````V@$``,4```!3`0``DP````````#6`P```````!<$````````
M0@<``+8%``"%!```:`$``!L"````````G`<``!X!``#&`@```````+8$````
M````+`4`````````````6@(``"T'```L!@```````/L%``"$`````````"T"
M``#R`0``&@,``(0"``#N````<`8``*T&```6`0``100```````"7!0``_`,`
M`($#````````YP(``/8#``#/`P``408`````````````SP8``.0&````````
M)`@``-`%`````````````$$!```B!0``700``*X&``"F!`````````````"B
M`0``5@```)T&```"!P``U@4``,L!``"@!@``D@0``((#```>"`````````@&
M````````.@,``+P````4!`````````````"/!@```````(`'``#L``````4`
M`$$'``#<`0``A@4``.L!``",!0``!0<``'D%``!Q`P``V@0``"D"``!G````
M`````)`#```R!0``"P0``$($``#Z`P``5@<```X"```5`0``A0$``(X```!%
M!@``B@0``"H'``"<`@`````````````>!@``I0```+(&```*"```Y@8``.P!
M``!V!@``>08```8%```?"```_````(,$``#L!P``2P<``&H&``"D`0``````
M`+0$``#*!P`````````````"!```>`8``%('``!F`````08``!@(``#D````
MG0,``"@!```A!0``Y@<``%$```#:`P``%P@```````"8````T@<``,P#```>
M`@```````#P$```E!0````````8$``#Y`0```````-L%``!,`0``L@4`````
M``!:!P``(P,```````!V`P``20<`````````````(P$```D&```%"```^P(`
M``````#(!````````"\(```H!P``2````)4'````````+`0``',&``!E`@``
M2@```+L&````````?0<````````9"```5`4```````!0`@``<P(``&P"```I
M`P``)P``````````````,@````````#X!```#08``/8!````````%P(``!X'
M``"6!```+@<```````!1`P``D0<```````!5````-`(``,8%````````````
M````````````/04``/8$``#U!@```````&\$``!K`P`````````````Q`0``
M`````)P```#A!0``5@0``),#```E!```R`$``+<$``````````````````#!
M`0``AP`````````I!@```````/\%``"2!0````````````#7!0``7P<```4#
M``!Q!@``&`0```````!B`0``X@,``(D%````````+08``,H"````````0P,`
M``````#7````E@4``,H&``!'!P``^`4``*4%``#T!P````@``+D```#\!```
M(@<``"D$```=!@```0@```````#>!P``D@(``.X"```!!```!`0```````!(
M!```"@$```````!P`@```````$$&````````IP4```````#B!@``\P<```4"
M``!.!0``!@(```````!I`0``*`0``$L%````````"P8```````#S!@``````
M`"8'````````'P`````$```^!@``````````````````N@$``#H"````````
M;P,`````````````:@$``#("```,````XP$``%X'``!%`@````````````">
M``````````````!C!P``,`4``#D"```M!0``:`0``*<!````````>P4``"L&
M``!:`````````/4!```V!0``+00``*,#````````F`4``.8!```]`P``````
M`-0&```N````XP0```````"8`P``5P<``,`&``".`0``XP8``+X&```_````
M;04``+@!```X!```600``(L`````````-@,``*`$``!B`P``PP8```````"U
M`````````-@```#X!@``[@8``'0"``"L`````````((````_!@``=04``(D'
M``"P`P``L0<``%`#``!$`P``:@(``/8%``#]`0````````0```"P!P``P`(`
M`+,%``!\`@``PP<```````!.`````````.0#````````O`8``/X!```R"```
MF`(````````P"````````#L"``"L!@``20(``/0%```@"```1@(`````````
M````8`0``#P&````````Q00```````!/!@``$@(`````````````;0<`````
M``#D`@``K@$``.X%``"V!@``1P0``/4%`````````P0``'0&````````````
M`.`$``"O!P``,00``'L'``":`@``N@(``-4%```3````"@0``(4'``!!!0``
ME0```-@&```E`P``D`4``%T`````````W00``"X"``"8!P``I0$``'@!````
M````?````!`&``!"!0``Q`(``((!``"G!P```````'D!``#A!```G@$``!L#
M````````*@0``*T"``#-!```)@8```````!0!0``?@0``&<%```$`P``D`0`
M``````#W!P``/08```````!O!@``Y0$``"H&````````.P<`````````````
M`````"L(```4`@``G@(`````````````&`<```````"J````.08``+(!``"B
M````2@8``(`#``#'````X@0``.$'``!&!P``5``````````G"```:P8`````
M```F````I0<```````#W`P``F`$````````#`@``B@<``*P'``#P!P``:@<`
M`$L"``!)!@``-08``````````````````,,%````````Z0(```````"^!0``
M`````#`#``#2````:0<``(P$````````$`,``!\%``!.!@``\00``$@#````
M`````````$\%``"(````7`4``+$```#P`P``J@,``&P#```O`0``Y0(``#<!
M``#U!```VP$```````"(`P```````!<&``#C!0``3`````T$``"[`0``]`8`
M``````"U!P``2@(`````````!@````````````":!`````````````!#!0``
M+@@``$\$````````%08``'T!``#\`0```````-\&``"U!0```````(D"``#3
M!0```````*@```#F`P``S0,``/H%````````V0,``'P%``"P!@```````#0`
M````````204``*D'``!2`@``NP4``!L&``!X`````````#<#``!6`0``]@8`
M`*P%``"L`P``6`4```X(``#F!0``0P```+0%```)`0``8`8``#0#````````
M;`$```````!!`````````*<&````````S@,```````#S````6P4``%`&```6
M`@````````````"H`P``E0(````````^!P``80(```````"S!@``808``#`"
M```F!```=@4``(\%``"%`@``(@@``'L$````````8P```(("``"-`@``WP4`
M``````!8`P````````P'``!H`@``)0<`````````````%P<``*D!```?!```
M`````-L$`````````````#`'``"K`@``_@<``.4%``!2!0``O`(``*\%``!B
M!@```````$L$`````````````(0#``!%!0``8`$```````![````L04``#``
M`````````````.D```#"!```7P8``+,$```````````````````S````7P``
M`+<#``!?!0``=@$``*0$``#D!```1`4``#X$``#M`@``YP$``(`%``!S````
MQ0$``.H#``"/`0``A`$```X'````````>@0``!@"``!P!```@`8```````#>
M`@``/``````````+````\P$``&`"``#X`0``````````````````&@<``#X%
M``"7!P``SP$```````!I!@``5P0``.<````U!P``Z@0```````"9`0``V`4`
M`"L#```N`0```````&T!``"-!```L@```-$"```]`0```````'X"```,`0``
M,`$```4`````````<`,``%8#````````W08`````````````E@```,L%``#/
M!```;08``!T"`````````````-8````_!0``>`4``'P$``#&`0``$0,`````
M````````4`$``'@#``!I````<````,P$``!Z`P``'0@``#<'``!>`0``Q0(`
M`#4```#-!0``^P$``'8$``!C`P``"P(``+P'``"#`P``X@```"P'``#W!@``
M#P8``$P"``";````D@8```````#W!```(P0``!@&``!K`0``=`4`````````
M````!P(```````"F`````````/(&````````F@8``)4$``#_`P``T````&0!
M````````P`0``$\`````````'`(``)\%```O!@````````````"Z!@``)0@`
M`!\'````````I08``.@!``")`P``C@4```0'``#8`0``-@8``)X%```6!0``
M=`0``#($```?`P``V0<``"8"```9!0``508```````">!P``]@(```H&``"`
M`0``:`,``#8"```3!P```````)<#``#"!0``:P(``*(%``#,!@``=P0``&<$
M````````0`$``,L$``!)`P```````/0$``"W`0``4@$````````G`0``````
M`+4!````````````````````````9@(```````!D`P``.````%D"``!C!@``
M``````````"A`P```````!T'````````"04``-@"````````VP8````````@
M!P`````````````I`0``EP(`````````````1`0``%D%``#:!0``$0(`````
M``#,`@``>P8```````#U`P``,P4`````````````C@<``"<#``"J!P``/P0`
M`.@$``"1`@``8@(``%,&````````:P4`````````````````````````("@E
M<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT
M;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A;F0`(&%T(``@;W(`
M(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!2
M96=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A
M=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E
M)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E
M>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R
M<')I;G0`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E
M<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E
M<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!
M9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!4
M87-K;&ES=``E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M
M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN
M:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@
M<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S
M("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@
M2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S
M`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--
M24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@
M0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N
M;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O
M=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!
M8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I;VX@9F]R(&)L86-K;&ES
M=&5D(&%D9')E<W-E<SH`06-T:79A=&4@4V-R:7!T`$%C=&EV871I;F<@=&AE
M('-C<FEP="!F;W(@(B5S(B!F86EL960Z("@E9"D@)7,`061D`$%D9"!#:&EL
M9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE
M=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@
M=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@
M;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER
M`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@
M861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R
M`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@
M861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(%-E='1I;F=S`$%D9')E<W,`
M061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!
M;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL
M($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO
M;G,`06QL(&9O=7(@<VED97,`06QL(&]F('1H92!F;VQL;W=I;F<`06QL;W<@
M4G5L97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A
M`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO
M;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G-W97)E9`!!;G1A<F-T:6-A`$%N=&EG
M=6$@86YD($)A<F)U9&$`06YY(&]F('1H92!F;VQL;W=I;F<`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@1FEL=&5R<P!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R
M;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H
M:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&1E;&5T92!T:&ES(')U;&4_`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG
M<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I
M`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A
M8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G
M=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A
M=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A
M:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`075T;VUA
M=&EC86QL>2!U<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\`
M079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L
M=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F-C
M`$)E9VEN<R!W:71H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R
M;75D80!":'5T86X`0FEN9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`0FQA
M8VML:7-T`$)L86-K;&ES="!%9&ET`$)L86-K;&ES="!I<R!N;W0@<W5P<&]R
M=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$)L86-K;&ES
M=&5D($%D9')E<W-E<P!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@
M;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O9'D`0F]L
M9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`
M0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`
M0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL
M971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I
M;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA
M`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@
M=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO
M;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`
M0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E
M(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#87-E(%-E;G-I=&EV90!#871E9V]R
M:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V,`0V5L;"!0:&]N90!#
M96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`
M0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`
M0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC
M871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H
M86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@96UA:6QS+@!#:&%N9V5S('-A=F5D+@!#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`
M0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D
M("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!
M<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA
M;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N
M9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE
M87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I
M;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N
M`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3
M:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP
M=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@
M4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O
M`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C
M=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!F
M86EL=7)E`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1A:6YS`$-O;G1E;G0@
M='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O
M;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y("5S`$-O<'D@
M9F%I;&5D.B`E<P!#;W!Y(&]F("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`
M0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E
M<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E
M=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER
M("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O
M=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`
M0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E
M860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@
M<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B
M+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L
M9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN
M:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET
M92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I
M9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U
M;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE
M=R!O;F4`0W)E871E(&YE=R!F;VQD97(`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@
M<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE
M8V@@4F5P=6)L:6,`1$0`1$E304),140Z(`!$4TX@*'-E92!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O
M:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?
M;&5T92!#;VQU;6X`1&5A8W1I=F%T92!38W)I<'0`1&5C96UB97(`1&5C:6UA
M;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L
M;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS
M`$1E;&5T90!$96QE=&4@)7,`1&5L971E($-E;&P`1&5L971E($-O;F1I=&EO
M;@!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@;65S<V%G92!C;VUP;&5T96QY`$1E;&5T92!M97-S86=E<P!$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T
M92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E
M;&5T960`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI
M=F5R(&EN=&\@;7D@26YB;W@`1&5L:79E<B!I;G1O(&UY($EN8F]X(&%N9"!C
M;W!Y('1O`$1E;&EV97(@:6YT;R!M>2!);F)O>"!A;F0@<F5D:7)E8W0@=&\`
M1&5L:79E<B!T;R!F;VQD97(`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@
M2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E
M=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T
M;W)Y`$1I<V%B;&4@)7,`1&ES86)L960`1&ES<&QA>2`R-"UH;W5R('1I;65S
M/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$
M:7-P;&%Y(&1E=&%I;&5D(&YO=&EF:6-A=&EO;B!W:&5N(&5A8V@@9FEL=&5R
M(&ES(&%P<&QI960_`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F
M;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(%]N
M;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L:R!O<B!L:7-T(&UE<W-A9V5S`$1O
M(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'``1&\@=&AI<SH`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE
M(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;V5S;B=T
M(&)E9VEN('=I=&@`1&]E<VXG="!C;VYT86EN`$1O97-N)W0@96YD('=I=&@`
M1&]E<VXG="!E>&ES=`!$;V5S;B=T(&UA=&-H("AW:71H('!L86-E:&]L9&5R
M<RD`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO
M860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O
M<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y
M(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V
M:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@)7,`161I="!";&]C:P!%9&ET
M($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U
M8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`
M16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA
M:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO
M=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A
M<F-H('1E<FUS`$5N86)L92`E<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/P!%;F%B;&5D`$5N9"!Y96%R`$5N9',@=VET
M:`!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T
M97)S(&)E;&]W.@!%<75A;"!T;P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A
M`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN
M9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@<F5T<FEE=FEN9R!C
M=7)R96YT('-C<FEP=#H@*"5D*2`E<P!%<G)O<B!S879I;F<@8VAA;F=E<RX`
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA
M`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>&ES=&EN9R!2=6QE<P!%>&ES=',`17AP86YD`$5X<&%N
M9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"`Q(&]B:F5C="P@9V]T
M("5D+@!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D
M(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&
M86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE
M9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E
M=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I
M:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I
M;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL
M92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<B!!
M;&P@365S<V%G97,`1FEL=&5R($]N;'D@4V5E;B!-97-S86=E<P!&:6QT97(@
M3VYL>2!5;G-E96X@365S<V%G97,`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%)U
M;&4`1FEL=&5R(%)U;&5S`$9I;'1E<B!38W)I<'0@1&ES<&QA>0!&:6QT97(@
M7U)U;&5S`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E
M96X@8V]P:65D('1O('1H92!F;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y
M.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+@!&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F
M;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I('1H
M870@;6%T8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@9&5L971E9"X`1FEL=&5R
M(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@8F5E
M;B!C;W!I960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I='DZ
M(%1H92!M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&1E;&5T960N
M`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@
M:&%S(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@;F]T
M(&9O=6YD+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R
M=&5R`$9I>"!R871I;P!&;&EP`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!A;B!I;F-O;6EN9R!M97-S86=E('1H
M870@;6%T8VAE<SH`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9`!&;W)W87)D(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@
M9FEL=&5R:6YG(&1R:79E<BX`1F]R=V%R9',`1F]R=V%R9',@161I=`!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA
M;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,`1G)O;0!&<F]M('1H92``1G)O;3H`1G5L;"!$97-C<FEP=&EO;@!&=6QL
M($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F
M<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT
M87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE
M($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E871E<B!T:&%N`$=R
M96%T97(@=&AA;B!O<B!E<75A;"!T;P!'<F5E8V4`1W)E96L@*$E33RTX.#4Y
M+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U
M861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES
M<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R
M:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M
M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI
M9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(
M;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A
M<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R
M9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE
M("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T
M>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S
M:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R
M:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(
M;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N
M>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F
M:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO
M<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D
M9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L
M;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS
M97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E
M<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN
M=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T
M:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@
M=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N
M`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R
M;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!)
M;6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O
M<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA
M=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD
M96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD:79I9'5A;"!R=6QE<R!A
M<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I
M=F5R+@!);F1O;F5S:6$`26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F
M;W(@;65S<V%G92!D96QI=F5R>2X`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA
M=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E
M<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!)
M;G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R
M="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE
M<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P
M:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!)
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK
M`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E
M<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L
M:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C
M:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC
M96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@
M;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E
M+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!)
M;G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!)
M;G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I
M;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27,`
M27-L92!O9B!-86X`27-N)W0`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES
M<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N
M97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S
M=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T
M`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY
M80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME
M<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y
M($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U
M8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3$1!
M4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@
M;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+@!,85]Y;W5T`$QA;F=U86=E
M`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,
M87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D
M.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@
M;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L
M=65S`$QE<V]T:&\`3&5S<R!T:&%N`$QE<W,@=&AA;B!O<B!E<75A;"!T;P!,
M979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS
M=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L
M>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I
M;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,
M:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X
M($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$
M871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R
M8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`
M3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I
M;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO
M861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO
M;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T
M`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L
M9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P
M475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R7VL@;65S<V%G92!A<R!D
M96QE=&5D`$UA<F-H`$UA<F=I;@!-87)K(&UE<W-A9V4@87,Z`$UA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N
M9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I
M;FEQ=64`36%T8VAE<R`H=VET:"!P;&%C96AO;&1E<G,I`$UA=&-H:6YG(&9I
M96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N
M`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T
M(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB
M97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M($YU;6)E<B!O9B!2=6QE<P!-
M87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!B;&%C:VQI<W1E9"!A
M9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L($UA>&EM
M=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A9&1R97-S
M97,@=&\@8FQA8VML:7-T+@!-87AI;75M(&YU;6)E<B!O9B!W:&ET96QI<W1E
M9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L($UA
M>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A9&1R
M97-S97,@=&\@=VAI=&5L:7-T+@!-87D`36%Y;W1T90!-961I8VEN90!-96UB
M97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E
M<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC
M871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-
M97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"
M(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@
M9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S
M`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O
M9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-
M:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H
M87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I
M;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!A9&1R97-S
M('1O(&YO=&EF>0!-:7-S:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G
M92!T;P!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R
M871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO
M;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E87-O;B!F;W(@<F5J
M96-T`$UI<W-I;F<@<F5A<V]N(&EN('9A8V%T:6]N+@!-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO
M`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%52
M3`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI
M80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S
M97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E
M8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-
M;W-T;'D@4W5N;GD`36]V90!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG
M:'0`36]V92!2=6QE($1O=VX`36]V92!2=6QE(%5P`$UO=F4@57``36]V92!D
M;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!
M8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O
M<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3E]U;6)E
M<B!O9B!D87ES(&)E='=E96X@=F%C871I;VX@<F5P;&EE<SH`3F%M90!.86UI
M8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL
M;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`
M3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!2
M=6QE`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P
M87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`
M3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.
M;R`B)7,B(&5L96UE;G0@9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N
M+@!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@!.;R!B86-K96YD(&-O;F9I9W5R960@9F]R('1H:7,@
M:&]S=`!.;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S+G!H<`!.
M;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U
M97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&
M4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N
M('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&9I;'1E<G,N($-L:6-K
M("(E<R(@=&\@8W)E871E(&$@;F5W(&9I;'1E<BX`3F\@:&5A9&5R<R!S<&5C
M:69I960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA
M;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I
M=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E
M<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S
M:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-C<FEP="!G96YE
M<F%T960N`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-T
M<FEN9W,@<W!E8VEF:65D`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.
M;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO
M="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!E<75A;"!T;P!.;W0@:6UP
M;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EF>2!E;6%I;"!A9&1R97-S`$YO
M=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@
M8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@
M9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`
M3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/
M9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT
M+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/
M;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M`$]N;'D@9FQA9R!T:&4@;65S<V%G90!/;FQY(&]F9F5N<VEV92!F;W)T=6YE
M<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W
M;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S
M:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@
M82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T
M(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P
M=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+@!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]T:&5R($]P=&EO;G,`3W9E<G9I97<`3W=N97(@4&5R;6ES<VEO;G,`4$%-
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@
M8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$
M871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`
M4$A0($-O9&4`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@
M4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!A9&1I;F<`4&%K:7-T86X`4&%L874`
M4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@
M3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A
M<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E
M8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N
M=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI
M<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R
M;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@
M26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O
M<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N`%!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CH`
M4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T
M=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E
M`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T
M:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME
M>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`
M4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`475E<GD`475O=&$`
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4E]E87-O;@!2861I;R!S96QE8W1I
M;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN
M(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E8V5I=F5D`%)E9&ER96-T('1O`%)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E
M9G)E<V@@4&]R=&%L(%9I97<Z`%)E9W5L87(@97AP<F5S<VEO;@!296IE8W0@
M=VET:"!R96%S;VX`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R
M:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O
M;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@
M<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W
M;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!&:6QT
M97)S($QI<W0`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O(%)U;&5S($QI
M<W0`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U
M<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT
M`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN
M`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2
M:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE
M`%)U;&4@0V]P:65D`%)U;&4@1&5L971E9`!2=6QE($1I<V%B;&5D`%)U;&4@
M16YA8FQE9`!2=6QE($YA;64`4G5L93H`4G5L97,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD
M80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4TU3($UE<W-A9VEN9P!344P@<W1A=&5M96YT(&9O<B!V86QU92!L
M;V]K=7!S`%-32`!35$%25%1,4R!F86EL960Z("@E<RD@)7,`4U5#0T534P!3
M80!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A
M;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V
M:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E
M($]P=&EO;G,`4V%V92!3971T:6YG<P!3879E(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3
M=&]R;7,`4V-I96YC90!38W)I<'0`4V-R:7!T(%5P9&%T:6YG`%-C<FEP="!N
M;W0@=7!D871E9"X`4V-R:7!T('-U8V-E<W-F=6QL>2!A8W1I=F%T960N`%-C
M<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N`%-E87)C:`!396%R8V@@
M16YG:6YE<P!3965N`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C
M="!A(&9I96QD`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@
M;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E
M;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A
M;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1A<F=E="!F;VQD97(`4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;&8M1&5F:6YE9"!(96%D97(`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!396YD(%--4P!396YD97(`4V5N96=A;`!396YS;W(Z(`!3
M97!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`
M4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!
M9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T
M:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y
M;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO
M;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS
M+@!3971T:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4V5T=7``4V5T=7`@
M=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P
M;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P
M:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!!8W1I=F4@4V-R:7!T`%-H
M;W<@0W5R<F5N="!38W)I<'0`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U
M<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E
M<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y
M`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG
M;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO
M=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W
M97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R
M="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A
M`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H
M97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3
M<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T
M97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P
M;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`
M4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W`@8VAE8VMI;F<@:68@=&AI
M<R!R=6QE(&UA=&-H97,_`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S
M`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@
M=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@
M;F]T(&9O=6YD+@!3=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E.@!3=6)J
M96-T`%-U8FIE8W0Z`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@
M(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C
M97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F
M=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L
M;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z
M97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN=&%X(&5R<F]R(&EN('-E87)C
M:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@
M86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A
M8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@
M3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E
M<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E
M9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI
M<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H
M`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE
M9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET
M:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D
M('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@
M17AI=&EN9RX`5&AE(&%D9')E<W,@(B5S(B!H87,@8F5E;B!A9&1E9"!T;R!Y
M;W5R(&)L86-K;&ES="X`5&AE(&%D9')E<W,@(B5S(B!H87,@8F5E;B!A9&1E
M9"!T;R!Y;W5R('=H:71E;&ES="X`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I
M9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A
M<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L
M;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N
M`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4
M:&4@9')I=F5R('-A:60Z(`!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B92!C
M;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A
M+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S
M86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K
M;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R
M+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I
M<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M
M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S
M=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@
M:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD
M('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@
M8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE
M(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M
M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S
M;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM
M93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L
M;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE
M('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@
M<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B
M)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T
M:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O
M;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B
M)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!A
M8W1I=F%T:6YG('1H92!S8W)I<'0N`%1H97)E('=A<R!A;B!E<G)O<B!D96%C
M=&EV871I;F<@=&AE('-C<FEP="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT
M='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A
M;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU
M;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4
M:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I
M<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI
M8VMI;F<N`%1O.@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME
M;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS
M;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`
M5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R
M(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP
M="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B
M)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5
M;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S
M+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S
M+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF
M:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5
M;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U
M;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O
M8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX
M*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@
M4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5
M;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT
M96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B
M)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y
M`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D
M(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I
M<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`
M57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T
M:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C
M;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y
M(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y
M<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+@!686-A=&EO;@!686-A=&EO;B!%9&ET`%9A8V%T:6]N(&ES(&YO="!S=7!P
M;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M
M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE
M;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU
M871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@
M=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R
M<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@
M<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE
M<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES
M;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@
M271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@
M34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T
M=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@
M<')O=FED960@8GD`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O
M;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S
M=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H7VET96QI<W0@
M861D<F5S<V5S.@!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A
M;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:&ET96QI<W0`5VAI=&5L:7-T
M($5D:70`5VAI=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E
M;G0@9FEL=&5R:6YG(&1R:79E<BX`5VAI=&5L:7-T960@061D<F5S<V5S`%=I
M9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED
M=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7
M:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I
M<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@
M5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S
M(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!9
M97,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS
M+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M<G5L97,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&]R(&5D:70@
M8W5S=&]M(')U;&5S+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@
M8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!R96-E:79E9"!A(&YE=R!M
M97-S86=E`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A
M5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U
M<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L
M96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO
M=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T
M;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P
M96-I9GD@870@;&5A<W0@;VYE(&5M86EL(&%D9')E<W,@9F]R('=H:6-H('1H
M92!V86-A=&EO;B!M97-S86=E<R!S:&]U;&0@8F4@86-T:79A=&5D+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W
M(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA
M;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R
M;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!
M9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y
M;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U
M;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@
M8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M
M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!;2&ED92!1=6]T960@5&5X=%T`6TYO(%-U8FIE
M8W1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO
M=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D
M9')E<W,H97,I('1O(&9O<G=A<F0@=&\Z`%]!9&1R97-S97,@=&\@;F]T('-E
M;F0@<F5S<&]N<V5S('1O.@!?061M:6YI<W1R871I;VX`7T)L86-K;&ES=`!?
M0TQ)`%]$96QE=&4@4F]W`%]$96QE=&4@;65S<V%G92!C;VUP;&5T96QY`%]%
M;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN93H`7T9O<G=A<F0`7T=R
M;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?2V5E<"!A(&-O<'D@
M;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT/P!?3&]G(&EN`%],;V<@;W5T
M`%]-;V1I9GD@3&EN:RXN+@!?36]V92!M97-S86=E('1O(&9O;&1E<CH`7TUY
M(&5M86EL(&%D9')E<W-E<SH`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO
M=F4@3&EN:RXN+@!?4V-R:7!T`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN
M+@!?57-E<G,`7U9A8V%T:6]N`%]7:&ET96QI<W0`86-T:79E`&%D9')E<W,@
M8F]O:P!A9&1R97-S964@=6YK;F]W;@!A;F0`8V%L96YD87(`8V%L;0!C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K
M(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!D:7-A8FQE9"`M(&-L:6-K('1O(&5N86)L90!E9&ET`&5N=')Y
M(&YO="!F;W5N9`!F86QL:6YG`&9I96QD`&9I;&4`9G)O;2!T:&4@)7,@*"5S
M*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D
M:6%T90!I;F%C=&EV90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F
M='=A<F4@97)R;W(`;&EN97-=`&UA:6QD<F]P('-C<FEP="!G96YE<F%T960@
M8GD@26YG;P!M871C:`!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K
M:6YG($E33RX`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE
M;G1E9`!N;W1E<&%D`&]R`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX
M96QS`'!R;V-M86EL('-C<FEP="!G96YE<F%T960@8GD@26YG;P!R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`
M<VAO=R!D:69F97)E;F-E<P!S:65V92!F:6QT97(@9V5N97)A=&5D(&)Y($EN
M9V\`<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!S>7-T96T@97)R;W(`=&%S
M:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FT`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!0
M<F]J96-T+4ED+59E<G-I;VXZ($EN9V\@,2XQ"E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`V+3`R+3$W(#$P.C`P*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP
M,BTQ."`R,#HP,RLP,3`P"DQA<W0M5')A;G-L871O<CH@3&%S>FQO($PN(%1O
M<FYO8VD*3&%N9W5A9V4M5&5A;3H@(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*`"`H)7,@;F%P<&%L(&5Z96SU='0I`"`H06QT+6)I;&QE;G1Y^R`E<RD`
M("@E<R!N87`@;?IL=F$I`"`H;6$I`"`H:&]L;F%P*0`@*'1E9VYA<"D`(.ES
M`"`Z(``@=F%G>0`B)7,B(&YE;2!A;&OV;GEV=.%R+@`B)7,B(&YE;2#I<G;I
M;GEE<R!VX6QA<WITX7,N`"(E<R(@;FEN8W,@:V]N9FEG=7+A;'9A(&$@2&]R
M9&4@4F5G:7-T<GEB96XN`"(E<R(@9F%S=')U:W3Z<F$M;65G:F5L96[M=/4@
M;F5M('1A;.%L:&%T\RX`(B5S(BUT(&AO>GKA861T=6L@82!C<V]P;W)T;VMH
M;WHN`"(E<R(M="!H;WIZX6%D='5K(&$@:F]G;W-U;'1SX6=I(')E;F1S>F5R
M:&5Z+@`B)7,B+70@;F5M(&AO>G1U:R!LZ71R93H@)7,N`"4N,F9-0B!F96QH
M87-Z;N%L="!A("4N,F9-0B!M96=E;F=E9&5T=&+U;"`H)2XR9B4E*0`E9"`E
M<R#I<R`E<P`E9"!N87`@;?IL=F$@;&5JX7(@:F5L<WIA=N%N86L@Z7)VZ6YY
M97-SZ6=E+@`E9"!N87!O<R!E;/5R96IE;'KI<P`E<R`M($9I9WEE;&UE>G1E
M=.ES`"5S(&QE;GEO;6%T`"5S(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K("T@
M;65G97+U<^UTZ7,`)7,@8F7A;&SM=.%S`"5S(&QO9VEN(&[I=B!I9^EN>6SI
M<P`E<R!S>F]L9^%L=&%TX7-I(&9E;'3I=&5L96L`02`B)7,B(&YE=OL@X6QL
M;VWA;GD@;>%R(&SI=&5Z:6LN`"5S(#H@)7,@)7,`02AZ*2`E<R!KZ7-Z96X@
MX6QL(&%Z(&%LX6)B:2!K87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI
M<^ER92Y*96SV;&IE(&MI(&%Z;VMA="!A(&9E;&%D871O*&MA*70L(&%M:2AK
M92ET(&UO<W0@96P@:^UVX6X@=NEG97IN:2X`)7,@:VET]FQTZ7-E('-Z_&MS
MZ6=E<P`E<R!P97)C`"5S(&YE;2!T86SA;&AA=/,N`"5S("T@)7,@*/9S<WIE
M<V5N("5S*0`E<R!C[6UJ96=Y>NEK90`E<R!N87!TX7)A`"5S(&9E;&IE9WEZ
MZ7-E:0`E<R!F96QA9&%T;&ES=.%J80`E<SH@3&5H971SZ6=E<RP@:&]G>2!E
M>B!A(&QE=NEL('9A;/-JX6)A;B!N96T@82!M96=A9&]T="!F96QA9/-T\VP@
M<WKA<FUA>FEK+B!';VYD;VQJ82!M96<L(&UI96SU='0@<N%K871T:6YT('9A
M;&%M:7)E+"!V86=Y('-Z96WI;'EE<R!I;F9O<FWA8VGS="!A9"!M96<N`"P@
M<WKI;&SV:^ES96L`+"`E<R`E<RUS('-ZZ6QL]FOI<V5K`"P@=N%L=&]Z\R`E
M<R#I<R`E<R!K]GKV='0`+2T@=N%L87-S>F]N("TM`#$R(/-RX7,@9F]R;>%T
M=6T`,C0@\W+A<R!F;W)MX71U;0`R-"#S<F$`/$5L]7KU`$5Z96X@8FQO:VL@
M:&%S>F[A;&%TX6AO>B!E9WD@861A=&+A>FES(&%L<F5N9'-Z97(@<WK\:W/I
M9V5S+@!(96QY<F5H;WIH871A=&QA;B!H:6)A('3V<G3I;G0`02!L97;I;"!T
M:71K;W/M=.%SX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<R!S>OQK<^EG
M97,N`$$@9&EG:73A;&ES86X@86SA[7)T(&QE=NEL(&5L;&5N]7)ZZ7/I:&5Z
M(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S('-Z_&MSZ6=E<RX`02!T:71K;W/M
M=&]T="!L97;I;"!D96OS9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU
M;&-S+"!E9WD@=&ET:V]S(%!'4"!K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z
M_&MSZ6=E<RX`02!L97;I;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y(&YY
M:6QVX6YO<R!01U`@:W5L8W,L(&5G>2!T:71K;W,@4$=0(&MU;&-S(.ES(&5G
M>2!J96QM;VYD870@<WK\:W/I9V5S+@!!('1I=&MO<^UT;W1T(&QE=NEL(&1E
M:_-D;VSA<^%H;WH@96=Y(&YY:6QVX6YO<R!3+TU)344@:W5L8W,L(&5G>2!T
M:71K;W,@4R]-24U%(&MU;&-S(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S
M+@!!(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%SX6AO>B!E9WD@;GEI;';A;F]S
M(%,O34E-12!K=6QC<RP@96=Y('1I=&MO<R!3+TU)344@:W5L8W,@Z7,@96=Y
M(&IE;&UO;F1A="!S>OQK<^EG97,N`$$@;&5VZ6P@=&ET:V]S[73A<^%H;WH@
M96=Y(&YY:6QVX6YO<R!3+TU)344@:W5L8W,@<WK\:W/I9V5S+@!$Z6QE;/5T
M="!B;W)U;'0@Z6<`1.EL96SU='0@9WEE;F=E(&5S]0!$Z6QE;/5T="!E<_4`
M1.EL96SU='1I('KA<&]R;VL`1.EL96SU='0@:/-ZX7!O<F]K`&1E+V1U`$%0
M22!)1"`H82!P<F]G<F%M;WKA<VD@9F5L_&QE="!A>F]N;W/M=/-J82D`17)R
M]6P@87H@961I=&]R<O-L`$[I=FIE9WDN+BX`86)S>B!A;'5L`&%B<WH@:_9Z
MZ7``3FEN8W,@:F]G;W-U;'1SX6=A(&$@5D93(&%L:_9N>79TX7(@;.ET<F5H
M;WKA<^%H;WHN`$YI;F-S(&IO9V]S=6QT<^%G82!A(%9&4R!FX6IL(&SI=')E
M:&]ZX7/A:&]Z+@!"96IE;&5N=&ME>NES:2!I;F9O<FWA8VGS`$IE;'-Z\P!!
M(&IO9V]S=6QT<^%G(&9E;"!V86X@9OQG9V5S>G1V92X`4.EN>OQG>65K`$$@
M9F5K971E;&ES=.%N('-Z97)E<&SU(&9E;&%D\W3S;"#I<FME>O4@_'IE;F5T
M=&5L(&$@:_9V971K97KU('3V<G3I;FIE;CH`4WK[<O5L:7-T82#I<G;I;GEE
M<^UTZ7-E`$$@<WK[<O5L:7-TX70@;F5M('-I:V5R_&QT("(E<R(@<NES>NER
M92#I<G;I;GEE<^UT96YI.B`H)60I("5S`$)E=FET96P`06QC<V]P;W)T(&SI
M=')E:&]ZX7-A`$IO9V]S=6QT<^%G:2!A;&-S;W!O<G0@;.ET<F5H;WKA<V$`
M061D:G5K(&AO>GKA(&ET=#H`VFH@8W-O<&]R="!LZ71R96AO>N%S80#::B!J
M;V=O<W5L='/A9R!LZ71R96AO>N%S80!!;&-S;W!O<G0@:&]Z>N%A9.%S82`B
M)7,B+6AE>@!*;V=O<W5L='/A9VD@86QC<V]P;W)T(&AO>GKA863A<V$@(B5S
M(BUH97H`VFH@9F5L:&%S>F[A;/,@;.ET<F5H;WKA<V$Z`-IJ(&]S>FQO<"!H
M;WIZX6%DX7-A`-IJ('1A9V]K(&9E;';I=&5L90#::B!PX7(@:&]Z>N%A9.%S
M80!!*'HI("5S(&UE;OQT(&%D:G5K(&AO>GKA(&$@36]Z:6QL82!M96[\<V]R
M:&]Z`$%D:G5K(&AO>GKA(&$@8^UM:F5G>7KI:VAE>CH`061J=6L@:&]Z>N$@
M82!C[6UJ96=Y>NEK96UH97H`VFH@9F5L:&%S>F[A;/,@:&]Z>N%A9.%S80`B
M)7,B(&9E;&AA<WINX6SS="!H;WIZX6%D='5K(&$@<F5N9'-Z97)H97HL(&1E
M(&YE;2!S:6ME<OQL="!A('3V8F)I(&)E:F5L96YT:V5ZZ7-I(&%D870@=.%R
M;VSA<V$Z("5S+@`B)7,B(&9E;&AA<WINX6SS="!F96QV971TZ6L@82!R96YD
M<WIE<F)E+B!-;W-T(&WA<B!B96IE;&5N=&ME>FAE="X`02!R96YD<WIE<FAE
M>B!N96T@861H873S:R!H;WIZX2#Z:B!F96QH87-Z;N%L\VLN`%1O=N%B8FD@
M8F7A;&SM=.%S;VL`0^UM`$/M;6IE9WEZZ6L`061M:6YI<WIT<N%C:?,@+2!J
M;V=O<W5L='/A9V]K(&%DX7-A('1O=N%B8FD@9F5L:&%S>F[A;/-K;F%K`$%D
M;6EN:7-Z='+A8VGS`$AI<F1E=.ES96L`069G86YI<WITX6X`06QBX6YI80!!
M;&?I<FEA`$%L:6%S`$5L:&5L>65ZZ7,`4F5N9&5ZZ7,Z`&%Z(/9S<WIE<V5T
M`$UI;F1E;B!N96T@=F5N9.EG(&9E;&AA<WINX6SS`$UI;F1E;B!C<V]P;W)T
M`$UI;F1E;B!J;V=O<W5L='/A9P!-:6YD(&$@;NEG>2!O;&1A;&]N(&QE9WEE
M;B!K97)E=`!M:6YD96=Y:6OI;F5K`$$@<WK[<O5S>F%BX6QY;VL@96YG963I
M;'EE>NES90!%;F=E9&K\;FL@;65G('3V8F(@8^UM970@:7,`02!S;W)S>N%M
M;W,@9F5L<V]R;VSA<R!T[7!U<V$@=N%L=&]Z=&%T:&%T\R!L96=Y96X_`$WA
M<B!LZ71E>FEK`$E-4U`@8F5J96QE;G1K97KI<VD@<&%R86WI=&5R96L`3>%S
M:6LL($E-4U`@:F5L<WKS`$WA<VEK+"!)35-0(&)E:F5L96YT:V5ZZ7-I(&[I
M=@!-X7-I:R!E;6%I;"!C[6T`06QT97)N873M=B!S86)L;VYO:P!!;'1E<FYA
M=.UV('-Z]G9E9SH`06UE<FEK86D@4WIA;6]A`$$@;65G861O='0@Z7)TZ6L@
M;F5M(&9O9V%D:&%T\R!E;"X`27-M97)E=&QE;B!H:6)A('3V<G3I;G0N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;2!P<F]X>6X@:V5R97-Z=/QL
M:2!I;G1E<FYE="!E;.ERZ7,`5N%L87-Z`$UE9W;A;&%S>F]L=`!!;G1A<FMT
M:7-Z`$%N=&EG=6$@Z7,@0F%R8G5D80!V86QA;65L>6EKZ6YE:P!!;&MA;&UA
M>N%S`$%L:V%L;6%ZX7-O:R!L:7-TX6IA`$%Z(&%L:V%L;6%ZX7,@:^ES>BX`
M2V%P8W-O;&IU:R!B92!A('-Z^W+U:V5T`$$@:_9Z]G,@=.%R=&5R_&QE="!A
M;&-S;W!O<G1J86ER82!I<R#I<G;I;GEE<P!*\W;A:&%G>>%S`$OV<OQL8F5L
M_&QI(&WI<F5T`.%P<FEL:7,`87)A8B`H5VEN9&]W<RTQ,C4V*0!!('3V;?9R
M[71E='0@X6QL;VWA;GD@;>ER971E`$$@=/9M]G+M=&5T="#A;&QO;>%N>2!N
M979E`$)I>G1O<RP@:&]G>2!T]G+V;&YI(&%K87)J82!E>G0@82!S>F%BX6QY
M=#\`0FEZ=&]S(&)E;FYE+"!H;V=Y('3V<O9L;FD@:^UVX6YJ82`E<R!B96IE
M;&5N=&ME>NES:2!I9^EN>>ET/P!":7IT;W,L(&AO9WD@=/9R]FQN:2!A:V%R
M:F$@(B5S(BUT(&%L8W-O<&]R=&IA:79A;"!E9WG\='0_`$%R9V5N=.UN80#6
M<FWI;GEO<G-ZX6<`]G)MZ6YY("A!4DU30TE)+3@I`$W[=NES>F5T`$%R=6)A
M`%!O:&YP96D`07-C:6D@<F%J>F]K`,%Z<VEA+T-S96YD97,M\V-EX6YI('+I
M9VGS`$OI<FIE;B!A(')E;F1S>F5R(&UE9V5R]7/M=.ES="!A(&MA<F)A;G1A
M<G3A<VD@9F5L861A=&]K(&5L=NEG>NES92!E;/5T=#\`2&]Z>N%R96YD96SI
M<VD@;W-Z;&]P;VL`3F5M;.ET97KU(&-S;W!O<G1O="!K[7/I<F5L="!M96<@
M=/9R]FQN:2X`3F5M;.ET97KU(&IO9V]S=6QT<^%G;W0@:^USZ7)E;'0@;65G
M('3V<O9L;FDN`$YE;6SI=&5Z]2!J;V=O<W5L='/A9V]T(&OM<^ER96QT(&UE
M9R!M96=VX6QT;WIT871N:2X`3F5M;.ET97KU(&OV>O9S('3A<G1E<OQL971E
M="!K[7/I<F5L="!M96<@;65G=N%L=&]Z=&%T;FDN`%1U;&%J9&]N<^%G;VL`
M875G=7-Z='5S`$%U<WIT<N%L:6$`075S>G1R:6$`075T:%]C>7)S<6PZ(&$@
M<WK\:W/I9V5S(&EM87`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H7V-Y
M<G5S.B!A(&CA='3I<G-Z;VQGX6QT873A<R!N96T@<F5N9&5L:V5Z:6L@82!K
M[7;A;G0@:^EP97-SZ6=E:VME;"X`075T:%]C>7)U<SH@82!S>OQK<^EG97,@
M:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?9G1P.B!A('-Z_&MS
MZ6=E<R!F='`@8O5V[73I<R!N96T@=&%LX6QH873S+B!&;W)D[71S82!L92!A
M(%!(4"UT(&%Z("TM96YA8FQE+69T<"!O<&-I\W9A;"X`075T:%]I;6%P.B!A
M('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]K
M<F(U.B!A('-Z_&MSZ6=E<R!K<F(U(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`
M075T:%]L9&%P.B!N96T@:&]Z:&%T\VL@;.ET<F4@^FH@9F5L:&%S>F[A;/-K
M($%C=&EV92!$:7)E8W1O<GD@97-E=.EN`$%U=&A?;&1A<#H@9F5L:&%S>F[A
M;/-K(&YE;2!T]G+V;&AE=/5K($%C=&EV92!$:7)E8W1O<GD@97-E=.EN`$%U
M=&A?;&1A<#H@82!S>OQK<^EG97,@3$1!4"!B]7;M=.ES(&YE;2!T86SA;&AA
M=/,N`$%U=&A?;&1A<#H@)7,@9F5L:&%S>F[A;/,@:&]Z>N%A9.%S82!N96T@
M<VEK97+\;'0N($$@<WIE<G9E<B!VX6QA<WIA.B``075T:%]L9&%P.B`E<R!F
M96QH87-Z;N%L\R!T]G)LZ7-E(&YE;2!S:6ME<OQL=`!!=71H7VQD87`Z("5S
M(&9E;&AA<WINX6SS(&%D871A:6YA:R!M96?Z:NUTX7-A(&YE;2!S:6ME<OQL
M=`!!=71H7VQD87`Z(&$@9F5L:&%S>F[A;/-K(&YE;2!M\V1O<^UT:&%T\VL@
M06-T:79E($1I<F5C=&]R>2!E<V5TZ6X`075T:%]M8V%L.B!A('-Z_&MSZ6=E
M<R!-0T%,(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]S;6)A=71H.B!A
M('-Z_&MSZ6=E<R!S;6)A=71H(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`3F5M
M('-I:V5R_&QT(&%Z($E-05`@<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A
M>F]N;W/M=.%S+@!!(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@<VEK97+\
M;'0N`$$@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!S:6ME<OQL="X@)7,`
M02!F96QH87-Z;N%L\R!A>F]N;W/M=.%SX70@82!2041)55,@<WIE<G9E<B!E
M;'5T87/M=&]T=&$N`$YE;2!S:6ME<OQL="!A>B!&5%`@<WIE<G9E<FAE>B!V
M86SS(&9E;&AA<WINX6SS87IO;F]S[73A<RX`3F5M('-I:V5R_&QT(&%Z(%--
M0B!S>F5R=F5R96X@=F%L\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N`$%U=&]M
M871I:W5S86X@9G)I<W/M='/\:R!A('-Z^W+U<WIA8N%L>70@;6EN9&5N(';A
M;'1O>G1A=.%S('5TX6X_`$$@<F5N9&5L:V5ZZ7-R92#A;&SS(&UE>O5K.@!!
M>F5R8F%J9'ISX6X`02!G;VYO<WH@<F5N9'-Z97)G87ID82!M96YT<^EG96D`
M2.%T=.ER`$CA='3I<B!S>NUN`$YE;2!M96=F96QE;/4@:V5R8F5R;W,@:F5L
M<WKS+@!.96T@;65G9F5L96SU(&ME<F)E<F]S(&9E;&AA<WINX6SS;NEV+@!"
M86AA;>%K`$)A:')E:6X`8F%L=&D@*$E33RTX.#4Y+3$S*0!"86YG;&%D97,`
M0F%R8F%D;W,`02!G<F%F:6MU<R#A;&QO;>%N>6]K("(E<R(@86QK]FYY=G3A
M<F$@;F5M('1A;.%L:&%T\RX`86QA<'9O;F%L;VX`0F-C`$$@:_9V971K97KU
M=F5L(&ME>F3U9&EK`$9E:.ER;W)O<WIO<G-ZX6<`0F5L9VEU;0!"96QI>F4`
M0F5N:6X`0F5R;75D80!":'5TX6X`02!K87!C<V]L870@9F5L=NET96QE(&YE
M;2!S:6ME<OQL=#H@*"5S*2`E<P!3>OQL973I<VYA<`!4:6QT;W1T(&/M;65K
M`%1I;'1O='0@8^UM96L@<WIE<FME<WITZ7-E`$$@9F5K971E;&ES=&$@;F5M
M('3A;6]G871O='0@82!S>OMR]6UE9VAA:G3S8F%N`%1I;'1O='0@8^UM96L`
M02`B)7,B(&)L;VMK(&$@(B5S(B!P<F]G<F%M;6%L(&YE;2!T86SA;&AA=/,N
M`$OI<&5R;GGU<NES>B!B9>%L;.UTX7,`2^EP97)N>?5RZ7-Z('3M<'5S`$QE
M=NEL=/9R>G,`9NEL:_9VZ7(`0F]L[79I80!+961V96YC('=E8F/M;65K`$ME
M<F5T`$ME<F5T=F%S=&%G<^%G.@!+97)E=&5K`$)O<WIN:6$M2&5R8V5G;W9I
M;F$`36EN9&ME='3U`$)O='-W86YA`&%L=6P`0F]U=F5T+7-Z:6=E=`!"<F%Z
M[6QI80!"<FET($EN9&EA:2WS8V7A;FD@5&5R_&QE=`!"<G5N96D@1&%R=7-S
M86QA;0!"=6QGX7)I80!&96QS;W)O;.%S`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`%=E8F]L9&%L(&MA<F)A;G1A<G3A<P!#4D,`02!T86[Z<^UT=N%N>79I<W-Z
M879O;N%S:2!L:7-TX6L@*$-23"D@8^UM96D`0V5L;&$@='5L86ID;VYSX6=O
M:P!!(&-A8VAE(&EN:6-I86QI>N%LX7-A(&YE;2!F96IE>O5D]G1T(&)E+@!.
M87!TX7(`3GEU9V]D=`!+86UB;V1Z<V$`2V%M97)U;@!.96T@<VEK97+\;'0@
M82!J96QS>O-T(.%TX6QL[71A;FDL(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z
M9.%H;WHN`$$H>BD@(B5S(B#A;&QO;>%N>2!N96T@[7)H873S+@!!(&O\;'/U
M(&9E;&AA<WINX6SS:V%P8W-O;&%T+6ME>F5L]6L@;F5M(&%D;6EN:7-Z='+A
M;&AA=/-K+@!!(&OV=F5T:V5Z]2!)34%0('-Z97)V97(@;F5M(.ER:&5T]2!E
M;#H@)7,`02AZ*2`B)7,B(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<N`$MA
M;F%D80!-Z6=S90!-Z6=S92!K_&QD]FL@:&EB86IE;&5N=.ES=`!!*'HI("(E
M<R(@X6QL;VWA;GD@;F5M('3V<O9L:&5T]2X`3F5M('1A;.%L:&%T\R!A>B!I
M9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7(N
M`$$@)W1A<F=E=$9I;&4G('!A<F%MZ71E<B!M96=A9.%S82!NZ6QK_&P@;F5M
M(&9O;'ET871H871J=6LN`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T]G+V
M;&AE=/4N`$YE;2!T]G+V;&AE=/4L("5D(&%L8W-O<&]R=&IA('9A;BX`07H@
M^FH@<V]R8F%R96YD97KI<R!N96T@;&5H971SZ6=E<RP@82!M96=A9&]T="!A
M9&%T;VL@<WKA;6$@;F5M(&5G>65Z:6L@82!TX7)O;'1A:^EV86PN`$$@;65G
M861O='0@<WKA;7)A(&YE;2!K_&QD:&5T]2!E;"!A>B#\>F5N970N`%KV;&0M
M9F]K:2US>FEG971E:P#!8G)A<WKV=F5G`%-Z;VQGX6QT873S`$MI<R]N86=Y
M8F5T^R#I<GKI:V5N>0!+871E9_-R:>%K(.ES(&IE;/9LZ7/\:P!+86IMX6XM
M<WII9V5T96L`0V,`36]B:6P@=&5L969O;@!#96QL871U;&%J9&]N<^%G;VL`
M0V5L;&$@8F5L<_4@;6%R9_,Z`$-E;&QA='5L86ID;VYSX6=O:P!#96QLX6L@
M:_9Z]G1T:2!RZ7,Z`$UO8FEL('1E;&5F;VX`:V5L=&$@*$E33RTX.#4Y+3$T
M*0!K]GKI<`!+]GKI<"UA9G)I:V%I($OV>G3A<G-A<^%G`&ME;&5T+65U<O-P
M86D@*$E33RTX.#4Y+3(I`$$@=&%N^G/M=';A;GD@<NES>FQE=&5I`$$@=&%N
M^G/M=';A;GD@='5L86ID;VYO<V$`5&%N^G/M=';A;GD@9F5L:&%S>F[A;.%S
M:2!I<N%N>65L=F5K`$-SX60`5N%L=&]Z=&%TX7,`02!J96QS>O,@X73A;&SM
M=.%S80!!>B#6;B#A;'1A;"!E;&O\;&3V='0@;&5V96QE:V5N('-Z97)E<&SU
M(&[I=B#I<R!C[6T@;65G=N%L=&]Z=&%TX7-A+@!6X6QT;WKA<V]K(&5L;65N
M='9E+@!!(&IE;&5N(&MO;F9I9W5RX6-I\V)A;B!N96T@;&5H971SZ6=E<R!A
M(&IE;'-Z879A:R!M\V1O<^UTX7-A+B!&;W)D=6QJ;VX@82!R96YD<WIE<F=A
M>F3A:&]Z+@!+87)A:W1E<@!,:6Y?:V5L;&5N]7)ZZ7,N+BX`0VAI;&4`2^UN
M80!K[6YA:2P@96=Y<WIE<OMS[71E='0@*$=",C,Q,BD`:^UN86DL(&AA9WEO
M;>%N>6]S("A":6<U*0!6X6QA<W-Z;VX@:VD@96=Y(&%L:V%L;6%ZX7-T.@!6
MX6QA<W-Z;VX@:F5L<WKS=`!6X6QA<W-Z;VX@96=Y(&9E;&AA<WINX6SS;F5V
M970`5N%L87-S>F$@:VD@82!DX71U;6]K(&UE9VIE;&5N[73I<VD@9F]R;>%J
MX70Z`%;A;&%S<WIA(&MI(&$@9F5L<V]R;VSA<R!T[7!U<^%T("AS>N%M;WIO
M='0@;&ES=.%K;N%L*0!+87+A8W-O;GDM<WII9V5T96L`02AZ*2`E<R!C;&%S
M<R!D969I;NUC:?-J82!N96T@=&%LX6QH873S+@!$97+\;'0`5/9R;&D@87H@
M35-/9F9I8V4@=&%G96ME=`!!(&QE:^ER9&5ZZ7,@=/9R;.ES90`E<R!F96QH
M87-Z;N%L\R!T]G)LZ7-E`$$@9F5L:&%S>F[A;/,@=/9R;.ES90!!(&9E;&AA
M<WINX6SS(&%D871A:6YA:R!T]G)LZ7-E`$5S=.ER92!D97+\;'0@Z6<`02!F
M;VQY=&%TX7-H;WH@:V%T=&EN='-O;B!A>B!E9^ER<F5L`$-L:6-K871E;&P@
M<WIO;&?A;'1A=.%S($A45%`M;B!K97)E<WIT_&P`07H@86)L86L@8F5ZX7+A
M<V$`0F]R=6QT(.EG`%)E9V=E;"!F96QH]7,@:63U`$9E;&CU<R!I9/4`2_-K
M=7-Z+7-Z:6=E=&5K`%3\;G1E<W/\:R!E;"!A>B!O;&1A;'/S(&UE;OQT`-9S
M<WIE>N%R="!K97)E=&5K`$MO;'5M8FEA`%-Z[6X`4WKM;G;A;&%S>G3S`%-Z
M[6YVX6QA<WITX7,`3W-Z;&]P;VLZ`$%Z(&]S>FQO<&]K(&/M;65I`%9I8V-E
M:P!087)A;F-S`%!A<F%N8W/I<G1E;&UE>O4`365G:F5G>7KI<P!.Z78L(&5L
M;F5V97KI<P!#;VUO<F4M<WII9V5T96L`0^EG`%-ZX6WM=/-GZ7!E:P!)9/5J
MX7+A<VD@:&5L>7IE=`!)9/5JX7+A<VD@:&5L>7IE=`!+_&SV;F)SZ6=E:R!A
M(&MO;F9I9W5RX6-I\V)A;@!+Z7II<WKA;>UT\V?I<&5K:V5L+"!O:V]S=&5L
M969O;F]K:V%L+"!/=71L;V]K:V%L('9A;/,@861A='-Z:6YK<F]N:7KA;.%S
M(&MO;F9I9W5RX6-I\VIA`$$@:V]N9FEG=7+A8VGS(&WA<B!N96T@Z7)VZ6YY
M97,N`"5S(&MO;F9I9W5RX6-I\VIA`$$@:F5L<WKS(&UE9V5R]7/M=.ES90!+
M;VYG\P!+;VYG\VD@1&5M;VMR871I:W5S($OV>G3A<G-A<^%G`%-I:V5R=&5L
M96X@82!K87!C<V]L870N`%-I:V5R=&5L96X@82!K87!C<V]L870Z(`!!(&MA
M<&-S;VQA="!N96T@<VEK97+\;'0`02!N>6EL=N%N;W,@:W5L8W-O:R!S>F5R
M=F5R92!E;'5T87/M=&IA(&$@:V%P8W-O;&%T;W0N`$$@;GEI;';A;F]S(&MU
M;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA=&]T+B!/:V$Z
M("5S("@E<RD`4VEK97)T96QE;B!A>B!&5%`@<WIE<G9E<G)E;"!V86SS(&MA
M<&-S;VQA="X`4&%R=&YE<F5K`$$@<&%R=&YE<F5K970@<VEK97)E<V5N(&AO
M>GKA861T=6L@82!C[6UJ96=Y>NEKZ6AE>BX`5&%R=&%L;6%Z>F$@82!K]G9E
M=&ME>O5T`$$@=/9M]G+M=&5T="#A;&QO;>%N>2!T[7!U<V$Z(``B)7,B('1A
M<G1A;&UA`$9O;'ET873A<P!#;V]K+7-Z:6=E=&5K`%/\=&D`3>%S;VQJ=6L@
MX70`)7,@;>%S;VSA<V$`02!MX7-O;.%S(&YE;2!S:6ME<OQL=#H@)7,`)7,@
M;>%S;VQA=&$`02!K:6IE;/9L="!RZ7-Z(&WA<V]LX7-A`%-ZX6ULX7KA<VD@
M87IO;F]S[73S`$-O<W1A(%)I8V$`16QE9N%N=&-S;VYT<&%R=`!.96T@<VEK
M97+\;'0@4$=0+79E;"!T:71K;W/M=&%N:2!A(&QE=F5L970Z(`!!(&QE=F5L
M970@;F5M('-I:V5R_&QT(%!'4"!A;.'M<N%S<V%L(&5L;.%T;FDZ(`!!(&QE
M=F5L970@;F5M('-I:V5R_&QT(&%Z(%,O34E-12!S>F%B=N%N>2!S>F5R:6YT
M('1I=&MO<^UT86YI+@!!(&QE=F5L970@;F5M('-I:V5R_&QT(%,O34E-12!A
M;.'M<N%S<V%L(&5L;.%T;FDN`$$@<&%R=&YE<B!A9&%T86ET(&YE;2!S:6ME
M<OQL="!E;'3A<F]L;FDN("5S`$%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U
M(&5L+@!.96T@<VEK97+\;'0@96QL96[U<FEZ;FD@82!S>N%M;.%JX6X@<F5N
M9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9V5T+B`E<P!.96T@<VEK97+\;'0@87H@
M3$1!4"!S>F5R=F5R:&5Z(&MA<&-S;VSS9&YI+@!.96T@<VEK97+\;'0@82AZ
M*2`B)7,B('-Z97)V97)R96P@1E10(&MA<&-S;VQA=&]T(&9E;'9E;FYI.B`E
M<P!.96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(&OV<FQE=NEL;&ES=.%T+B`E
M<P!!>B!A9&%T;VL@4$=0('1I=&MO<^UTX7-B\VP@=/9R=.EN]2!D96OS9&]L
MX7-A(&YE;2!S:6ME<OQL=#H@`$%Z(&%D871O:R!3+TU)344@=&ET:V]S[73A
M<V+S;"!T]G)TZ6[U(&1E:_-D;VSA<V$@;F5M('-I:V5R_&QT+@!!('!A<G1N
M97(@=/9R;.ES92!N96T@<VEK97+\;'0N("5S`$$@:_9R;&5VZ6QL:7-T82!T
M]G)LZ7-E(&YE;2!S:6ME<OQL="X@)7,`3F5M('-I:V5R_&QT('3V<O9L;FD@
M82AZ*2`B)7,B('-E='5P('5P9W)A9&4@<')O9W)A;6]T+@!.96T@<VEK97+\
M;'0@;65GX6QL87#M=&%N:2!A(&/M;7IE='0@96UA:6P@8^UMZ70N`$YE;2!S
M:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@8^UM:F5G>7KI:V5T+@!.96T@
M<VEK97+\;'0@8F5O;'9A<VYI(&$@=&5L:F5S(&OV<FQE=NEL;&ES=.%T+@!.
M96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5VZ6QL:7-TX6L@=&5L:F5S
M(&9E;'-O<F]LX7/A="X`02AZ*2`B)7,B('-T<F%TZ6=I82!N96T@=&%LX6QH
M873S+@!!*'HI("(E<R(@86QK]FYY=G3A<B!N96T@:&]Z:&%T\R!LZ71R92X`
M02!N>6EL=N%N;W,@:W5L8W-O="!N96T@<VEK97+\;'0@;65G<WIE<F5Z;FD@
M82!K=6QC<W-Z97)V97)R]6PN`$YE;2!S:6ME<OQL="`B)7,B+70@[7+A<VD@
M8^EL;&%L(&UE9VYY:71N:2X`3F5M('-I:V5R_&QT("5S+70@;65G;GEI=&YI
M+@!!("5S(&MA<F)A;G1A<G3A<VD@;6]D=6P@;F5M(&YY:71H873S(&UE9P!!
M*'HI("(E<R(@86QK]FYY=G3A<B!N96T@;GEI=&AA=/,@;65G+@!!>B!,1$%0
M('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`)7,@;F5M(&]L=F%S:&%T\RX`3F5M
M('-I:V5R_&QT(&$@:^UVX6YT(&9E;&AA<WINX6SS(&IE;'-Z87;A="#A=.%L
M;.UT86YI+B!!>B!M96=A9&]T="!A9&%T;VL@;F5M('9A9WD@;F5M('1E;&IE
M<V5N(&9E;&5L;F5K(&UE9RX@4'+S8N%L:F$@^FIR82P@=F%G>2!H82!T;W;A
M8F)I('-E9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+"!F;W)D=6QJ;VX@82!R96YD
M<WIE<F=A>F3A:&]Z+@!.96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&%Z(&5L
MZ7+I<VD@:F]G;W-U;'1SX6=O:V%T("A!0TPI`$YE;2!S:6ME<OQL="!B96]L
M=F%S;FD@82!C[6UJ96=Y>NEK970N("5S`$YE;2!S:6ME<OQL="!B96]L=F%S
M;FD@82!K]G)L97;I;&QI<W3A="X@)7,`3F5M('-I:V5R_&QT(&)E;VQV87-N
M:2!A(&OV<FQE=NEL;&ES=.%K870N("5S`$YE;2!S:6ME<OQL="!M96=H873A
M<F]Z;FD@82!S>F5R=F5R(&OI<&5S<^EG96ET`$YE;2!S:6ME<OQL="!V:7-S
M>F'A;&SM=&%N:2!E>B!E<F5D971I(&MO;F9I9W5RX6-I\W0N`$$H>BD@(B5S
M(B!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N`$YE;2!S:6ME<OQL="!E;&UE
M;G1E;FD@)7,@:V]N9FEG=7+A8VGS="X`3F5M('-I:V5R_&QT(&5L;65N=&5N
M:2!A(&)A8VMU<"!K;VYF:6=U<N%C:?-T+@!.96T@<VEK97+\;'0@96QM96YT
M96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I\W0Z("5S`$YE;2!S:6ME<OQL="!E
M;&UE;G1E;FD@82AZ*2`B)7,B('-E='5P('5P9W)A9&4@<')O9W)A;6]T+@!.
M96T@<VEK97+\;'0@96QM96YT96YI(&$H>BD@)7,@8F%C:W5P(&MO;F9I9W5R
MX6-I\W0N`$$H>BD@)7,@:V]N9FEG=7+A8VGS<R#A;&QO;>%N>70@;F5M('-I
M:V5R_&QT(&5L;65N=&5N:2X@5F%G>2!H87-Z;N%L:F$@82`E<R!O;&1A;&]N
M(&QE=O4@;&5H973U<^EG96ME="P@=F%G>2!MX7-O;&IA(.%T(&%Z(&%LX6)B
M:2!K\V1O="!I9&4Z("5S+@!!>B!,1$%0('-Z97)V97)E;B!N96T@<VEK97+\
M;'0@96QVZ6=E>FYI(&$@:V5R97/I<W0N`"(E<R(@;F5M('9O;'0@=/9R]FQH
M973U+@!!('!A<G1N97(@861A=&%I="!N96T@<VEK97+\;'0@;?-D;W/M=&%N
M:2X@)7,`3F5M('-I:V5R_&QT(&$@:_9R;&5VZ6QL:7-T82!M\V1O<^UTX7-A
M+B`E<P!.96T@<VEK97+\;'0@96QM96YT96YI("(E<R(@:V]N9FEG=7+A8VGS
M:N%T.B`E<P!!($UO>FEL;&$@;65N_'-O<B!N96T@=&%LX6QH873S+B!%;&QE
M;O5R:7IZ92P@:&]G>2!M96<@=F%N+64@;GEI='9A+@!.96T@<VEK97+\;'0@
M(B5S(B!F96QH87-Z;N%L\VYA:R!J;V=O<W5L='/A9V]T(&%D;FD@82AZ*2`B
M)7,B(&UA<'#A:&]Z.B`E<P!+;W)LX71O<R!S>O9V96<`3W)S>N%G`%3A=F]K
M=&%TX7,`3.ET<F5H;WKA<P!,:6YK(&SI=')E:&]ZX7-A`-IJ(&SI=')E:&]Z
MX7-A`$AO>GIU;FL@;.ET<F4@^FH@;6%P<.%T`$%L;6%P<.%K(&SI=')E:&]Z
MX7-A`$%Z(&]B:F5K='5M(&SI=')E:&]Z\VKA;F%K(&IO9V]S=6QT<^%G86D`
M2&ET96QKX7)T>6%S>N%M`$AO<G;A=&]R<WKA9P!+=6)A`$IE;&5N;&5G:2`T
M(&;A>FES`$$@:F5L96YL96=I(&9E;&AA<WINX6SS:V%P8W-O;&%T;VL`4&]N
M=&]S(&ED]0!!(&IE;&5N;&5G:2!54DP`2F5L96YL96=I(&9E;&AA<WINX6SS
M:P!*96QE;FQE9VD@:63U:N%RX7,`02!J96QE;FQE9VD@:63U:N%RX7-I(&AE
M;'EZ970Z`$IE;&5N;&5G:2!S=.UL=7,`36EL>65N('!A<F%N8W-O:R!F=7-S
M86YA:R!L92!A=71O;6%T:6MU<V%N(&$@)7-B92!T]G)TZ6[U(&)E:F5L96YT
M:V5ZZ7-K;W(N`$MI=N%GX7,`02!K:6IE;/9L="!RZ7-Z(&MI=N%GX7-A`$-I
M<')U<P!C:7)I;&P@*$M/23@M4BD`8VER:6QL("A7:6YD;W=S+3$R-3$I`&-I
M<FEL;"UU:W+A;B`H2T])."U5*0!#<V5H($OV>G3A<G-A<^%G`$1$`$Q%5$E,
M5%9!.@!$4TX@*&%D871F;W)RX7-L9>UR\R`M(&SA<V0Z(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<"D`;F%P;VYT80!$871A5')E92!B]FYGZ7-Z]0!!9&%T8N%Z:7-B
M86X@=F%L\R!K97)E<^ES`$3A='5M`$$@8F7I<FME>NES(&YA<&IA`$3A='5M
M(&MI=N%L87-Z=.%S80!N87!P86P`3W-Z;&]P('3V<FSI<V4`4WK[<O5L:7-T
M82#I<G;I;GET96QE;NUTZ7-E`&1E8V5M8F5R`'-ZX6UO:P!"96ME>F3I<R!K
M:6IJ96)B`$%L87#I<G1E;&UE>F5T=`!!>B!A;&%PZ7)T96QM97KI<R!S>F5R
M:6YT:2!S>NUN`$%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\P!!
M;&%PZ7)T96QM97IE='0@<VAE;&P`1&5F:6[M8VGS:P!4]G)LZ7,`)7,@=/9R
M;.ES90!!(&-E;&QA('3V<FSI<V4`02!F96QTZ71E;"!T]G)LZ7-E`$$@8W-O
M<&]R="!T]G)LZ7-E`$$@;F%P;//A;&QO;>%N>2!T]G)LZ7-E`$$@:F]G;W-U
M;'1SX6<@=/9R;.ES90!,979E;&5K('3V<FSI<V4`02!C96QL82!T]G)LZ7-E
M`$%Z(&]S>FQO<"!T]G)LZ7-E`%3V<O9L:OQK(&MI(&$@;65G;.EV]2!A;'1E
M<FYA=.UV('-A8FQO;G0`5NEGZ7)VZ6YY97-E;B!T]G+V;&K\:R!A(&QE=F5L
M970`02!L979E;&5K('3V<FSI<V4`(B5S(B!J;V=O<W5L='/A9V%I;F%K('3V
M<FSI<V4`5/9R]FQJ_&L@(B5S(B!J;V=O<W5L='/A9V%I="#I<R!E;FYE:R!E
M<V5T;&5G97,@86QC<V]P;W)T:F%I=#\`02!S;W(@=/9R;.ES90!!(&MI=N%L
M87-Z=&]T="!A>F]N;W/M=/,@=/9R;.ES90!!>B!A;&UA<'#A:R!T]G)LZ7-E
M`$$@:F5L96YL96=I(&]S>FQO<"!T]G)LZ7-E`$$@:F5L96YL96=I('-O<B!T
M]G)LZ7-E`%3V<O9L=`!4]G+V;'3\:R!A*'HI("(E<R(@<V5T=7`@=7!G<F%D
M92!P<F]G<F%M;W0N`$$@;&5VZ6P@:V5R_&QJ]FX@87H@24Y"3U@M;VUB80!!
M(&QE=NEL(&ME<OQL:O9N(&%Z($E.0D]8+6]M8F$@Z7,@;>%S;VQJ=6L@X70@
M:61E`$$@;&5VZ6P@:V5R_&QJ]FX@87H@24Y"3U@M;VUB82#I<R!I<N%N>>UT
M<W5K(.%T(&$@:_9V971K97KU(&/M;7)E`$OI>F)E<^UTZ7,@82!K]G9E=&ME
M>O4@;6%P<.%B80!!(&OI>F)E<^UTZ7,@:61E:F4`1.%N:6$`061J;VX@;&7M
M<N%S="!A('!R;V)LZ6WA<O-L`$QE[7+A<P!2Z7-Z;&5T96L@*&$@2&]R9&4@
M;&]G9N%J;&)A;B!I<R!M96=T86SA;&AA=/,I.@!!('+I<WIL971E:R!A(')E
M;F1S>F5R9V%Z9&$@<WKA;>%R82!KZ7-Z_&SU(&YA<&SS9N%J;&)A(&ME<OQL
M=&5K+@!&96IL97-Z=.ES`$AA<FUA='!O;G0`2&%R;6%T<&]N="!J96QE;FQE
M9SH@`$AA<FUA='!O;G0Z(`!B86QR\VP@:F]B8G)A(.URX7,`:F]B8G+S;"!B
M86QR82#M<N%S`$/M;73A<@`E<R!T:6QTX7-A`$QE=&EL=&]T=`!!>B!I9/5P
M;VYT;VMA="`R-"#S<N%S(&9O<FWA='5M8F%N(&IE;&5N[71S_&L@;65G/P!-
M96=J96QE;NUTZ7-I(&)EX6QL[73A<V]K`$$@<NES>FQE=&5S(&5L]7)E:F5L
M>NES(&UE9VIE;&5N[73I<V4`2F5L96[M='/\;FL@;65G('+I<WIL971E<R!T
MX6KI:V]Z=&%TX7-T(&%M:6YT(&%Z(&5G>65S('-Z^W+U:R!A;&MA;&UA>N%S
M82!M96=T]G)TZ6YI:S\`16SU<F5J96QZZ7,@;65G:F5L96[M=.ES92`H<F5P
M_&SU=.ER:2D`365G:F5L96[M=.ES:2!F;W)MX71U;0#)<G1E<^UTZ7,@82!K
MZ7IB97/M=&5T="!L97;I;"!S;W)SX7+S;`!$>G-I8G5T:0!4]FUE9V5S(.ES
M(&QE=F5L97KU7VQI<W3A<R#\>F5N971E:W)E(&YE(&O\;&1J_&YK(';A;&%S
M>G0`3F4@=/9R]FQJ_&L`02!M86EN=&5N86YC92YP:'`@;F5M(.ER:&5T]2!E
M;"!K]GIV971L96[\;"X`5&5D9"!E>G0Z`$%Z(&5L<_4@<V]R(&$@;65Z]6L@
M;F5V96ET('1A<G1A;&UA>GIA/R!(82!I9V5N+"!J96SV;&IE(&MI(&5Z=#H`
M3F5M(&$@:_9V971K97KU=F5L(&ME>F3U9&EK`$YE;2!T87)T86QM87IZ82!A
M(&OV=F5T:V5Z]70`3F5M(&$@:_9V971K97KU=F5L(';I9WKU9&EK`$YE;2!L
MZ71E>FEK`$YE;2!T87)T86QM87IZ82!A(&OV=F5T:V5Z]70@*#\O*B!D>G/S
M:V5R<F5L*0!$;VUI;FEK80!$;VUI;FEK86D@2_9Z=.%R<V%SX6<`3FEN8W,@
M;>EG(&QO9VEN(&YE=F4_($EGZ6YY96QJ96X@96=Y970N`$QE=/9L=.ES`%3V
M;'1S_&L@;&4@)7,M=`!4]FQT<_QK(&QE(%!(4"!P<F]G<F%M(&9O<FWA:N%B
M86X@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0N`$QE9_9R9/QL]2!L:7-T
M80!+X6+M=/-S>F5R96L`96UA:6P`16UA:6QB]6P@4TU3+6O\;&3U(&UE9VAA
M:G3S+"!H82!A('1E;&5F;VYTX7)S87/A9R!B:7IT;W/M=&IA(&5Z="!A('-Z
M;VQGX6QT873A<W0N`$A)0D$`16-U861O<@!-\V1O<^UTX7,`)7,@;?-D;W/M
M=.%S80!";&]K:R!M\V1O<^UTX7,`0W-O<&]R="!M\V1O<^UTX7,`2F]G;W-U
M;'1SX6<@;?-D;W/M=.%S`$IO9V]S=6QT<^%G;VL@;?-D;W/M=.%S80`E<R!J
M;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$`365L>6EK(&]P8VGS:V%T(';A
M;'1O>G1A<W-U:SH`(B5S(B!J;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$`
M)7,@:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A`$]K=&%TX7,`16=Y:7!T
M;VT`4V%L=F%D;W(`16QE;2XN+@!A>B`G;2<@8F5T^R!S>NEL97-SZ6=E`$5M
M86EL`$5M86EL(&/M;0!!>B!E;6%I;"!C[6UE:VYE:R!E9WEE>FYI_&L@:V5L
M;"X`16UA:6P@=FES<WIA:6=A>F]LX7-S86P`16UA:6PM4TU3(.%T:N%R\P!(
M86YG=6QA=&EK;VYO:P#<<F5S(/QZ96YE="X`3FEN8W,@:6QY96XN`%3V<O9L
M:OQK(&MI(&$@:V5R97/I<V5K970`)7,@96YG963I;'EE>NES90!%;F=E9&K\
M:R!M96<L(&AO9WD@:^EP96ME="!I;&QE<W-Z_&YK(&$@<WKV=F5G8F4@82!&
M;W3S9V%LZ7)IX6MB\VP_`$QE9WEE;B!J;V)B(&5GZ7)G;VUB8F%L(&5LZ7)H
M973U+"!K;VYT97AT=7-F_&=G]2!M96[\/P!%;F=E9.EL>65Z971T`$%Z('5T
M;VQS\R#I=@!!(&OV=F5T:V5Z]79E;"!VZ6=Z]61I:P#!=';A;'3A<R!K_&SV
M;B!A8FQA:W)A`$%D:F$@;65G(&%Z="!A(&)I>G1O;G/A9VD@:^ER9.ES="P@
M86UE;'ER92!M86ID(';A;&%S>F]L;FEA(&ME;&P@:F5L<WIA=N%N86L@X73A
M;&SM=.%SX6AO>BP@<&PN("=H;V=Y(&CM=FKA:R!A(&MU='GA:N%T/R<Z`$%D
M:F$@;65G(&$@:^EP(%523"UJZ70@:71T`,UR:F$@8F4@87H@86SA8F)I(&)E
M=/MK970Z`$5G>65N;/4@82!K]G9E=&ME>O4@<WKA;6UA;`!%9WEE;FSM=/5I
M+4=U:6YE80!%<FET<F5A`$AI8F$`2&EB82!T]G)TZ6YT(&$@8FQO:VL@;.ET
M<F5H;WKA<V%K;W(Z("5S`$AI8F$@=/9R=.EN="!A>B!A9&%T<WII;FMR;VYI
M>N%C:?-S(&IE;"!T]G)LZ7-E:V]R.B`E<P!!>B!A9&%T<WII;FMR;VYI>N%C
M:?-S(&YA<&SSX6QL;VWA;GD@=/9R;.ES92!N96T@<VEK97+\;'0Z("5S`$AI
M8F$@=/9R=.EN="!A>B!A9&%T;&5KZ7+I<V)E;CH@)7,`2&EB82!T]G)TZ6YT
M(&$@<WK[<O5F96QTZ71E;&5K(&)E;VQV87/A<V%K;W(Z("@E9"D@)7,`2&EB
M82!T]G)TZ6YT(&$@=N%L=&]Z=&%TX7-O:R!E;&UE;G3I<V5K;W(N`$AI8F$@
M=/9R=.EN="!A(&IE;'-Z\R!M96=VX6QT;WIT873A<V%K;W(Z("5S`$AI8F$@
M87H@96UA:6P@_'IE;F5T8F5N+@!!*'HI("(E<R(@X6QL;VWA;GER82!N96T@
M<VEK97+\;'0@[7)N:2X`R7-Z=&]R<WKA9P!%=&GS<&EA`$YE;7IE=&ESZ6=E
M:P!%=7+S<&$`,34@<&5R8V5N:^EN=``R('!E<F-E;FOI;G0`,S`@;>%S;V1P
M97)C96YKZ6YT`#4@<&5R8V5N:^EN=`!M:6YD96X@8F5J96QE;G1K97KI<VMO
M<@!FZ6SS<N%N:^EN=`!P97)C96YKZ6YT`%#I;&1A(.ER=.EK96LZ`%;I9W)E
M:&%J=.%S`$SI=&5Z]2!S>F%BX6QY;VL`3.ET97II:P!.>6ES<W5K('-ZZ70`
M2F5L96[M='/\:R!M96<@87H@;VQD86QS\R!M96[\=`!)='0@)RDG(&ME;&QE
M;F4@:_9V971K97IZ96X`02!VX7)T(#$@:&5L>65T="!A(&MA<&]T="!O8FIE
M:W1U;6]K('-ZX6UA("5D+@!)='0@8W-U<&%S>B!S>O-N86L@=F%G>2!I9.EZ
M]6IE;&)E;B!L97;U(&ME<F5SZ7-I(&MI9F5J97KI<VYE:R!K96QL96YE(&QE
M;FYI90!!>B#I<G;I;GEE<W/I9R!L96KA<F%T80!+:71E=O4`4WKM;@!!(&MO
M;F9I9W5RX6-I\R!&5%`M;B#A="!V86SS(&9E;'3V;'3I<V4`02!S>F5MZ6QY
M97,@8F7A;&SM=.%S;VMA="!N96T@<VEK97+\;'0@8F5O;'9A<VYI+@!!>B!,
M1$%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`07H@4TU"('-Z97)V97(@;F5M
M(.ER:&5T]2!E;"X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(BUB]6P@=/9R=.EN
M]2!MX7-O;.%S+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B+6)E('3V<G3I;O4@
M;>%S;VSA<RX`3F5M('-I:V5R_&QT(/IJ(%-!4TP@:V%P8W-O;&%T;W0@;.ET
M<F5H;WIN:2X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(BUB92!T]G)TZ6[U(.%T
M:&5L>65ZZ7,N`,%L;&]MX6YY:&]Z>N%FZ7+I<VD@:&EB83H@)7,`5&ES>G1A
M`$9A;&ML86YD+7-Z:6=E=&5K("A-86QV:6YA<RD`1F%R;V4M<WII9V5T96L`
M2&5L>7)E:&]Z:&%T871L86X@:&EB83H`1F%X`$9A>`!F96)R=>%R`$CU;>ER
M<^EK;&5TZ7)Z970`2/5MZ7)SZ6ML973I<GIE=#H@`$5G>2UE9WD@>N%P;W(`
M4WKS<G;A;GEO<V%N(&CS>N%P;W)O:P!-97KU(&WA=')I>`!&:6=L970@0T%0
M5$-(02`H8F5T^VMI<F%K\R!H=6WA;G1E<WIT*0!&:61Z<VD`1N%J;`!!(&;A
M:FQO:R!S>N%M83H@)7,`02!FX6IL;VL@<WKA;6$Z("5S`$;A:FP@;65N961Z
M<V5R`$;A:FQNZ78`1N%J;"!K:6IE;/9LZ7,`1N%J;"!F96QT]FQTZ7-E`$;A
M:FQO:R!F96QT]FQTZ7-E(&YE;2!L96AE='/I9V5S+@#6<W-Z97,@;&5VZ6P@
M<WK[<NES90!#<V%K(&%Z(&]L=F%S;W1T(&QE=F5L96L@<WK[<NES90!#<V%K
M(&%Z(&]L=F%S871L86X@;&5V96QE:R!S>OMRZ7-E`%-Z^W+I<VD@8F7A;&SM
M=.%S;VL`4WK[<NES:2!S>F%BX6QY`%-Z86+A;'EL:7-T80!!('-Z^W+U<')O
M9W)A;2!M96=J96QE;NUTZ7-E`%]3>F%BX6QY;&ES=&$`4WK[<O5F=6YK8VGS
M.B`E<R!L979E;&5T(.%T:&5L>65Z=/QN:R!A("5S(&UA<'#A8F$N`%-Z^W+U
M9G5N:V-I\SH@)7,@;&5V96QE="!T]G+V;'3\;FLN`%-Z^W+U9G5N:V-I\SH@
M)7,@;&5V96QE="#A=&AE;'EE>G3\;FL@82`E<R!M87!PX6)A+@!3>OMR]69U
M;FMC:?,Z("5S(&]L>6%N(&QE=F5L970@=/9R]FQT_&YK+"!A;65L>2!M96=F
M96QE;'0@82!F96ME=&5L:7-TX6YA:RX`4WK[<O5F=6YK8VGS.B!!("5S(&QE
M=F5L970L(&%M96QY("5S+73U;"#I<FME>F5T="#A=&AE;'EE>G3\:R!A("5S
M(&UA<'#A8F$N`%-Z^W+U9G5N:V-I\SH@(B5S(BUT]6P@(B5S(BUI9R!A(&QE
M=F5L96ME="!T]G+V;'3\:RX`4WK[<O5F=6YK8VGS.B!!("5S(&QE=F5L970L
M(&%M96QY("5S+73U;"#I<FME>F5T="#A=&AE;'EE>G3\:R!A("5S(&UA<'#A
M8F$N`$YE;2!LZ71E>O4@<WIA8N%L>0!3>OMR]6L`1FEN;F]R<WKA9P!E;'/U
M(&;I;`!E;'/U(&YE9WEE9`!6X6QT;WIA=&QA;B!MZ7)E=&%RX6YY`%3\:W+V
M>NES("AF]FPO;&4I`$OV9``E<R!M87!P82!N96T@;.ET97II:P!"973[<WKM
M;@#)=&5L96L`02!S>F%BX6QY(&%R<F$@82!B96KV=O4@;&5VZ6QR92!L97-Z
M(.ER=NEN>65S+"!A;65L>2!M96=F96QE;"!A>B!A;.%B8FD@9F5L=.ET96QE
M:SH`3VQY86X@8O9N9^ES>O5K('-ZX6WA<F$L(&%M:6L@;F5M(&IE;&5N[71I
M:R!M96<@82!KZ7!E:V5T`$5L]7)E:F5L>NES("AR97#\;/5TZ7)I*0!!>B!E
M;/5R96IE;'KI<R!I9/5T87)T86UA(&YA<&]K8F%N("AA>B!E;/5R96IE;'KI
M<R!N87!P86QI(.ES(.EJ<WIA:V%I(&%D871O:V%T('1A<G1A;&UA>BP@97KI
M<G0@82!N86=Y('-ZX6UO:R!S>NEL97,@8FQO:VMO="!E<F5D;>EN>65Z;F5K
M*0!%;&9E;&5J=&5T=&4@82!J96QS>F%VX70_`-MR;&%P:V5Z96SI<P!)9.EZ
M970`263I>F5T(&9A:G3A:F$`263I>F5T96L`263I>F5T96L@,@!&\W)U;6]K
M`%1O=N%B8NUTX7,`02!T;W;A8F+M=.%S(&YE;2!TX6UO9V%T;W1T(&$@<WK[
M<O5M96=H86IT\V)A;@!4;W;A8F+M=.%S;VL`5&]VX6)B[73A<V]K('-Z97)K
M97-Z=.ES90!0Z0!&<F%M92UE:P!&<F%N8VEA;W)S>N%G`$9R86YC:6%O<G-Z
MX6<`1G)A;F-I82!'=7EA;F$`1G)A;F-I82!0;VQI;NEZ:6$`1G)A;F-I82!$
MZ6QI(%1E<OQL971E:P!&96QA9/,`27+A;GDZ(`!&96QA9/,Z`%+I<WIL971E
M<R!L9>URX7,`=&5L:6AO;&0`5&5L:F5S(&[I=@!'86)O;@!-96QY:6L@9V%L
MZ7)IX6+S;"!V96=Y_&L@82!KZ7!E=`!+Z7!G86SI<FEA.@!'86UB:6$`2&]Z
M>G5K(&SI=')E(&$H>BD@)7,@:V]N9FEG=7+A8VGS:N%T`$$@:V5L971K97IE
M='0@:_-D`$=R^GII80!.Z6UE=&]R<WKA9P!':.%N80!':6)R86QTX7(`2V5R
M97-Z=&[I=@!';&]BX6QI<R!B9>%L;.UTX7-O:P!-96AE=`!']F1E;`!';V]G
M;&4@=.ER:^EP`$=O;V=L92!K97)E<^ES`$9E:V5T92]F96CI<@!.86=Y;V)B
M(&UI;G0`3F%G>6]B8B!M:6YT+"!V86=Y(&5G>65N;/4`1_9R]F=O<G-ZX6<`
M9_9R]F<@*$E33RTX.#4Y+3<I`$=R]FYL86YD`$=R96YA9&$`0W-O<&]R="!A
M9&UI;FES>G1RX6-I\P!!(&-S;W!O<G1NZ78@;6%R861H870@_')E<V5N`$=R
M;W5P7VQD87`Z("5S(&-S;W!O<G0@:&]Z>N%A9.%S82!N96T@<VEK97+\;'0N
M($$@<WIE<G9E<B!VX6QA<WIA.B``1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!T
M]G)LZ7-E(&YE;2!S:6ME<OQL=`!'<F]U<%]L9&%P.B`E<R!C<V]P;W)T(&%D
M871A:6YA:R!M96?Z:NUTX7-A(&YE;2!S:6ME<OQL=`!#<V]P;W)T;VL`1W5A
M9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!696YDZ6<@:F]G;W-U
M;'1SX6=O:P!696YDZ6=K]FYY=@!'=6EN96$`0FES<V%U+4=U:6YE80!'=7EA
M;F$`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA:FQA;F3S(&$@<V]R('5T
M;VQS\R!C96QLX6KA="!T]G+V;&YI+@!(5$U,07)E82!G>>%V87/A9V+S;"!N
M96T@:&%J;&%N9/,@82!TX6)LX7IA="!U=&]L<_,@;W-Z;&]PX70@=/9R]FQN
M:2X`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA:FQA;F3S(&$@=.%B;.%Z
M870@=71O;'/S('-O<N%T('3V<O9L;FDN`$$@2%144"!F96QH87-Z;N%L\V%Z
M;VYO<^UTX7,@;F5M('1A;.%L:&%T\RX`2&%I=&D`2&%S:"!A;&=O<FET;75S
M`$OV9`!&96ILZ6,`1F5J;.EC`$AE87)D+2#I<R!-8T1O;F%L9"US>FEG971E
M:P!%<O5S('II=F%T87(`:.EB97(@*$E33RTX.#4Y+3@M22D`36%G87-SX6<`
M4V5G[71SZ6<`4V5G[71SZ6<@82!S>F5R:V5S>G3U(&AA<WINX6QA=.%H;WH`
M4V5G[71SZ6<`1NEL=&5K90!%>B!A(&;A:FP@96QE:F4Z`&YA9WD`2V5Z9/5L
M87``5F%T:6OA;G;A<F]S`$ME>F3U;&%P`$]T=&AO;FD@8^UM`%-Z96WI;'EE
M<R!A;&OV;GEV=.%R`$]T=&AO;FD@=&5L969O;@!(;VYD=7)A<P!(;VYG:V]N
M9P!(;W)D90!(;W)D92]+;VQA8CH@:&EBX7,@)7,@6$U,(&%D870@=F%N(&$H
M>BD@)7,@_'IE;F5T8F5N`$AO<F1E+TMO;&%B.B!N:6YC<R!A*'HI("5S(&]B
M:F5K='5M;F%K(&UE9V9E;&5L]2#\>F5N970`2&]R9&4O2V]L86(Z(&YI;F-S
M("5S('3M<'5S^B!O8FIE:W1U;2!A*'HI("5S(/QZ96YE=&)E;@!(;W)D92]+
M;VQA8CH@4VEK97)E<V5N('3V<O9L=/QK(&5Z=#H@)7,@(B5S(@!(;W)D92]+
M;VQA8CH@87H@:6YT96=RX6SS('!R;V=R86UH;WH@<WK\:W/I9V5S(&$@)V1O
M;7AM;"<@4$A0(&+U=NUTZ7,`2&]R9&4O2V]L86(Z(&YE;2!S:6ME<OQL="#Z
M:B!834P@9N%T(&SI=')E:&]Z;FD@82AZ*2`E<R!O8FIE:W1U;6AO>@!(;W)D
M92]+;VQA8CH@3F5M('-I:V5R_&QT('3V<O9L;FD@)7,M="`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@;F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A($U)344@
M240M:N%T(&$@:_9V971K97KU('3M<'5S^B!M96QLZ6ML971N96LZ("5S`$AO
M<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@<WII;FMR;VYI>N%L;FD@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z($YE;2!S:6ME<OQL="!A(&OV=F5T:V5Z]2!K
M]GKV<R!TX7)T97+\;&5T('-Z:6YK<F]N:7KA;.%S83H@)7,`2&]R9&4O2V]L
M86(Z(&ES;65R971L96X@:_9Z]G,@=.%R=&5R_&QE="`B)7,B`%;M>G-Z:6YT
M97,@=F]N86P`5NUZ<WII;G1E<R!M87)G\P!6[7IS>FEN=&5S.@!(;V=Y(&IU
M=&]T="!I9&4_("A+Z7)J_&L@[7)J82!M96<A*0!(X6YY(&]S>FQO<&]T(&OM
M=N%N(/9S<WIE;VQV87-Z=&%N:3\`2.%N>2!M97KU("AO<WIL;W`I('9A;C\`
M2.%N>2!S;W)T(&OM=N%N(/9S<WIE;VQV87-Z=&%N:3\`4.%R871A<G1A;&]M
M`%#A<F%T87)T86QO;3H@`$AU;6]R:7-TX6L`36%G>6%R;W)S>N%G`$%Z($E-
M05`@;&5VZ6QLX61A(&SI=')E:&]ZX7-A(&YE;2!S:6ME<OQL=#H@)7,`07H@
M24U!4"!L97;I;&SA9&$@=/9R;.ES92!N96T@<VEK97+\;'0Z("5S`$%Z($E-
M05`@;&5VZ6QLX63A:&]Z('1A<G1O>O,@:W;S=&$@;.ET<F5H;WKA<V$@;F5M
M('-I:V5R_&QT.B`E<P!)4"!C[6T`07H@25`@8^UM(&YE;2!H873A<F]Z:&%T
M\R!M96<N`$%Z($E0(&/M;2!N:6YC<R!A(&UE9V5N9V5D971T($-)1%(@=&%R
M=&]MX6YY8F%N+@!4:6QT;W1T+VUE9W;A;'1O>F]T="!)4"!C[6TN`%-O<B!B
M96EL;&5S>G3I<V4@96;V;.D`27IL86YD`&-S86L@:6MO;F]K`"5S(&EK;VYJ
M86D`:6MO;F]K(.ES('-Z]G9E9P!!>B!A>F]N;W/M=/-H;WH@=N%L87-Z=&]T
M="!E;&YE=F5ZZ7,Z`$AA(&$@;65G:F5L96[M=.ES(&YE;2!M96=F96QE;/4L
M("5S(&5G>2#Z:B!A8FQA:V)A;B!V86SS(&UE9VYY:73A<VAO>BX`2&$@UFX@
M26YT97)N970@17AP;&]R97)T(&AA<WINX6PL(.ES(&YE;2!J96QE;FYE:R!M
M96<@87H@:6MO;F]K+"!A:VMO<B!VX6QA<W-Z82!E>G0@87H@;W!C:?-T+"!M
M96QL>65L(&MI:V%P8W-O;&IA(&$@4$Y'(&OI<&5K('1R86YS>G!A<F5N8VGA
M:N%T+@!(82!LX71J82!E>G0@82!S>O9V96=E="P@9&4@82!KZ7!E="!N96TL
M(&%K:V]R(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!KZ7!E<R!M96=J96QE;NUT
M96YI(&$@<WIE<G9E<G)E(&O\;&1E;F3U(&OI<&5T+@!%;/5Z971E<R!NZ7IE
M=#H`02!KZ7`@55),+6IE`$$@:^EP(%523"UJ93H`365L>6EK(&=A;.ER:>%B
M\VP@=F%N(&$@:^EP`$OI<"!E8F+U;"!A(&=A;.ER:>%B\VPZ`$OI<"!F96QT
M]FQTZ7-E`$OI<&5K`$EM<&]R=.%LX7,L("5D+B!LZ7#I<P!&;VYT;W,`07H@
M:6UP;W)TX6QT(&UE>O4Z("5S`$%Z(&EM<&]R=.%L="!M97KU:SH`4V]R(&)E
M:6QL97-Z=.ES92!E>F%LX0!(:6+A<R!P87)A;F-S<&%R86WI=&5R+@!.96T@
M;65G9F5L96SU(&$@8F5J96QE;G1K97KI<VD@;NEV(.ES+W9A9WD@82!J96QS
M>O,N`$YE;2!M96=F96QE;/4@82!F96QH87-Z;N%L\VD@;NEV('9A9WD@87H@
M86QT97)N873M=B!C[6TN(%!R\V+A;&IA(/IJ<F$@=F%G>2!F;W)D=6QJ;VX@
M82!R96YD<WIE<F=A>F3A:&]Z+"!H82!T;W;A8F)I('-E9^UT<^EG<F4@=F%N
M('-Z_&MSZ6=E+@!"96ME>F3I<R!B96QJ96)B`$EN9&EA`$5G>65S(&9E;&AA
M<WINX6SS:P!!('-Z^W+U;65G:&%J=/,@;F5M('3A;6]G870@96=Y961I('-Z
M86+A;'EO:V%T+@!);F1O;NEZ:6$`3F5M;.ET97KU(&/M;65T(&%D=&%K(&UE
M9R!L97;I;&OI>F)E<^UTZ7-R92X`26YF;W)MX6-I\P!);F9O<FWA8VGS`$%Z
M(&EN9F]R;>%C:?,@;>%R(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X`3W-Z;&]P
M(&)E<WKZ<N%S82!E>G5TX6X`2^EP(&)E:6QL97-Z=.ES90!4X6)LX7IA="!B
M96EL;&5S>G3I<V4`3&EN:R!LZ71R96AO>N%S80!/<WIL;W`@8F5S>OIRX7-A
M(&5Z96SI`$]S>FQO<"!B97-Z^G+A<V$@97IU=.%N`$]S>FQO<"!B97-Z^G+A
M<V$@97IE;.D`4V]R(&)E<WKZ<N%S82!E>F%LX0!3;W(@8F5S>OIRX7-A(&5F
M]FSI`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>G5TX6X`0F5K97IDZ7,@8F5I
M;&QE<WITZ7-E(&5Z96SI`$AO>GIU;FL@;.ET<F4@86QT97)N873M=B!S86)L
M;VYT`$%D:F]N(&UE9R!E9WD@96UA:6P@8^UM970L(&UE;'ER92!E;&O\;&1H
M973U(&%Z(-9N(/IJ(&IE;'-Z879A.@!#96QL82!B96EL;&5S>G3I<V4@97IU
M=.%N`$-E;&QA(&)E:6QL97-Z=.ES92!E>F5LZ0!/<WIL;W`@8F5S>OIRX7-A
M(&5Z=73A;@!/<WIL;W`@8F5S>OIRX7-A(&5Z96SI`$QE=F5L96L@8F5MX7-O
M;.%S80!"96ME>F3I<R!B96EL;&5S>G3I<V4@97IU=.%N`$)E:V5Z9.ES(&)E
M:6QL97-Z=.ES92!E>F5LZ0!3;W(@8F5S>OIRX7-A(&5Z86SA`%-O<B!B97-Z
M^G+A<V$@96;V;.D`061J82!M96<@82!K[7;A;G0@=N%L87-Z="!A(&)I>G1O
M;G/A9VD@:^ER9.ES<F4Z`$OI<"!B96EL;&5S>G3I<V4O;?-D;W/M=.%S80!,
M:6YK(&)E:6QL97-Z=.ES92]M\V1O<^UTX7-A`$$@<WKA;6SA:N%N(&YI;F-S
M(&5LZ6<@9F5D97IE="#\>F5N971E="!K_&QD96YI(&$@:_9R;&5VZ6QL:7-T
MX7)A+@!!('-ZX6ULX6KA;B!N:6YC<R!E;.EG(&9E9&5Z970N`$5GZ7-Z`$5G
MZ7-Z('-ZX6UO:R!L:7-TX6IA`$AI8N%S+V5L9F]G861H871A=&QA;B!51$@@
M*%5S97(@1&%T82!(96%D97(I+@!(:6+A<R]E;&9O9V%D:&%T871L86X@6DE0
M('3V;?9R[73I<P!(:6+A<R]E;&9O9V%D:&%T871L86X@86QK86QM87KA<RX`
M2&EBX7,O96QF;V=A9&AA=&%T;&%N(&)A=&-H(&%Z;VYO<^UT\RX`02!K_&QD
M]G1T(&%D870@:&EBX7,O96QF;V=A9&AA=&%T;&%N+@!(:6+A<R]E;&9O9V%D
M:&%T871L86X@8^UM>NES+@!(:6+A<R]E;&9O9V%D:&%T871L86X@9N%J;"!F
M;W)MX71U;0!(:6+A<R]E;&9O9V%D:&%T871L86X@;&EC96YS>FMU;&-S+@!(
M:6+A<R]E;&9O9V%D:&%T871L86X@=N%R;W,N`$AI8N%S+V5L9F]G861H871A
M=&QA;B#\>F5N971T[7!U<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N('9A9WD@
M:&GA;GEZ\R!P<F]G<F%M;WKA<VEF96S\;&5T+6%Z;VYO<^UT\RX`2&EBX7,O
M96QF;V=A9&AA=&%T;&%N('!A<F%MZ71E<F5K+@!(:6+A<R!A>B!O8FIE:W1U
M;2!E;.ERZ7-I(&IO9V]S=6QT<^%G82X`2&EBX7,O96QF;V=A9&AA=&%T;&%N
M('!A<G1N97)A>F]N;W/M=/,N`$AI8N%S+V5L9F]G861H871A=&QA;B!T97)M
MZ6MK\V0N`$AI8N%S+V5L9F]G861H871A=&QA;B!P<F]T;VMO;&PN`$AI8N%S
M+V5L9F]G861H871A=&QA;B!C[6UZ971T.B`B)7,B`$AI8N%S+V5L9F]G861H
M871A=&QA;B!M96=O<WIT;W1T(&]B:F5K='5M`$AI8N%S+V5L9F]G861H871A
M=&QA;B!F96QA9/-I(&/M;2X`2&EBX7,O96QF;V=A9&AA=&%T;&%N('5N:6-O
M9&4@861A="X`3GEI;';A;G1A<G3A<P!!(&MI:F5L]FSI<R!I;G9E<G3A;.%S
M80!)<N%N:2!)<WILX6T@2_9Z=.%R<V%SX6<`27)A:P#-<F]R<WKA9P!!>F]N
M;W,@82!K]G9E=&ME>O5V96P`36%N+7-Z:6=E=`!.96T@87IO;F]S(&$@:_9V
M971K97KU=F5L`%-Z\W)VX6YY;W,@>FEV871A<F]K`$EZ<F%E;`!!('1A;OIS
M[71VX6YY(&MI863S:F$`9/5L=`!/;&%S>F]R<WKA9P!*86UA:6-A`&IA;G7A
M<@!*87#A;@!J87#A;B`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)DX6YI80!J
M^FQI=7,`:OIN:75S`%-O<FMI>N%RX7,`:_9ZZ7!R92!R96YD97KI<P!S;W)K
M:7KA<N%S(&UI;F1KZ70@;VQD86QR80!S;W)K:7KA<N%S(&)A;')A`'-O<FMI
M>N%RX7,@:F]B8G)A`$MA>F%H<WITX6X`5&%R='-U:R!M96<@87H@97)E9&5T
M:70_`$ME;GEA`$$@:V5R8F5R;W,@<WIE<G9E<B!E;'5T87/M=&]T=&$@82!F
M96QH87-Z;N%L\V%Z;VYO<^UTX7-T+@!+97ID]2!K97)N96QF96IL97-Z=/5K
M`$MU;&-S(&SI=')E:&]ZX7-A`$$@:W5L8W,@;&5N>6]M871A`$MU;&-S:&]S
M<WKZ<^%G`$MU;&-S('3M<'5S`$$@:W5L8W,@:&%S>F[A;&%T80!!(&MU;&-S
M(&WA<B!LZ71E>FEK(&$@;GEI;';A;F]S(&MU;&-S<WIE<G9E<F5N+@!'>65R
M96ME:P!+:7)I8F%T:0!+;W)E86D@3NEP:2!$96UO:W)A=&EK=7,@2_9Z=.%R
M<V%SX6<`2V]R96%I($OV>G3A<G-A<^%G`&MO<F5A:2`H155#+4M2*0!+=79A
M:70`2VER9VEZ:7-Z=.%N`$Q$05`@=.%M;V=A=.%S<F$@;&5N;F4@<WK\:W/I
M9RP@9&4@87H@3$1!4"!M;V1U;"!N96T@X6QL(')E;F1E;&ME>NES<F4L('9A
M9WD@;F5M('3V;'3U9/9T="!B92X`7U1E<G9E>NES`$YY96QV`$QA;W-Z:2!.
MZ7!I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9P!U=&]L<_,@9NEL`$%Z('5T
M;VQS\R!J96QS>O-VX6QTX7,`=71O;'/S(&YE9WEE9`!5=&]L<_,@=N%L=&]Z
M=&%TX7,Z`%5T;VQS\R!B96IE;&5N=&ME>NES.B`E<P!5=&]L<_,@8F5J96QE
M;G1K97KI<SH@)7,L("5S(&/M;7+U;`!5=&]L<_,@8F5J96QE;G1K97KI<SH@
M;>EG('-O:&$@;F5M('9O;'0`3&5T=&]R<WKA9P!*;V<`16QH96QY97KI<P!(
M86=Y:F$@_')E<V5N+"!H82!N96T@86MA<B!K97)E=&5T`$QI8F%N;VX`8F%L
M`$)A;"!O;&1A;&D@9F5J;.EC`$)A;"!O;&1A;&D@Z7)TZ6ME:P!,97-O=&AO
M`$ME=F5S96)B+"!M:6YT`$ME=F5S96)B+"!V86=Y(&5G>65N;/4@;6EN=`!3
M>FEN=`!,:6+I<FEA`$SM8FEA:2!!<F%B(%-Z;V-I86QI<W1A($YA9WD@3NEP
M:2!+]GKV<W/I9P!,:65C:'1E;G-T96EN`$=Y96YG92!S>FETX6SS(&5S]0!'
M>65N9V4@97/U`$3I;&5L]71T(&=Y96YG92!E<_4`1.EL=73A;B]E<W1E(&=Y
M96YG92!E<_4`1WEE;F=E('KA<&]R`$=Y96YG92!Z:79A=&%R`$=Y96YG92!H
M879A>N%S`$=Y96YG92!H\WKA<&]R`$QI;FL`02!L:6YK(&ED92!M=71A=#H`
M365G:F5L96[M=.ES:V]R(&UU=&%S<V]N(&5G>2!L:6YK(&$@;&5VZ6QC[6UR
M]6P@82!L97;I;.UR\R!A8FQA:VAO>@!,:6YK96L`3&EN=7@`3&ES=.%ZX7,@
M+2!A(&9E;&AA<WINX6SS(&SA=&IA(&$@;6%P<.%T`$%Z(&%D871BX7II<V]K
M(&QI<W3A:F$`07IO:VYA:R!A('3I;>%K;F%K(&$@;&ES=.%J82!A;6ER]6P@
M<V5G[71SZ6<@:V%P:&%T\P!!>B!A9&%T=.%B;.%K(&QI<W3A:F$`3&ES=&$@
M87)C:.UV=6T`3&ES=&$@<V5G[71SZ6=KZ7+I<P!,:7-T82!A>F]N;W/M=/,`
M3&ES=&$@='5L86ID;VYO<P!,:7-T82!L97;I;.URX7,`3&ES=&$@9F5L:7)A
M=&MO>N%S("AS=6)S8W)I8F4I`$QI<W1A(&QE:7)A=&MO>N%S("AU;G-U8G-C
M<FEB92D`02!F96QH87-Z;N%L\VMA<&-S;VQA=&]K(&MI;&ES=.%ZX7-A(&YE
M;2!S:6ME<OQL=#H@)7,`02!F96QH87-Z;N%L\VL@:VEL:7-TX7KA<V$@;F5M
M('-I:V5R_&QT.B`E<P!!(&9E;&AA<WINX6SS:R!K:6QI<W3A>N%S82!T:6QT
M=F$@=F%N+@!)<F]D86QO;0!,:71VX6YI80!,973V;'3I<RXN+@!(96QY:2!I
M9/4Z(`!.>65L=BP@9.%T=6TL(&ED]0!(96QY`$)E:F5L96YT:V5ZZ7,`07H@
M96SU>O4@861A='-Z:6YK<F]N:7KA8VGS(&YA<&SSX6QL;VWA;GEA`$MI:F5L
M96YT:V5ZZ7,`0F5J96QE;G1K97KI<P!"96IE;&5N=&ME>NES<V5L(&MA<&-S
M;VQA=&]S(&9E;&%D871O:P!!(&)E:F5L96YT:V5ZZ7,@;F5M('-I:V5R_&QT
M+"!M97)T(')O<W-Z(&9E;&AA<WINX6SS;F5V970@=F%G>2!J96QS>O-T(&%D
M;W1T(&UE9RX`02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="X`2&]S<WKZ
M('-Z]G9E9P!3>F5R96QE;0!A;&%C<V]N>0!G]G+V9R!K:7-B973[:P!L871I
M;B!K:7-B973[:P!K:7-B973[<R!R\VUA:2!S>N%M;VL`3'5X96UB=7)G`$U-
M`$YA<&D@_'IE;F5T96L`07H@35,M5$Y%1B!M96QLZ6ML971B96X@;FEN8W,@
M861A="X`W%I%3D54`$UA:V'S`$UA:V5D\VYI80!-861A9V%S>FOA<@!687+A
M>G-L870`3&5V96QE>NES`$5M86EL(&1O;6%I;B!K97IE;.ES`$QI;FL@:^ES
M>NUTZ7-E`$UA;&%W:0!-86QA:GII80!-86QD[78M<WII9V5T96L`36%L:0!-
MX6QT80!!9&%T86ET(&MA=&5G\W)IX6MB82!S;W)O;&AA=&IA+B!%>F5K(&ET
M="!D969I;FGA;&AA=/-K+"!M\V1O<^UT:&%T\VLL('1O=N%B8N$@<WKM;F5K
M(')E;F1E;&AE=/5K(&AO>GKA:G5K+@!-87`R-"!TZ7)KZ7``36%P475E<W0@
M=.ER:^EP`$$@:&]Z>N%R96YD96SI<V5K970@96QM96YT971T_&LN`%]*96SV
M;&K\:R!M96<@82!L979E;&5T('3V<O9L=&YE:P!MX7)C:75S`$UA<F?S`$IE
M;/9L:OQK(&UE9R!A(&QE=F5L970@82!K]G9E=&ME>O5KZ7!P96XZ`$%Z($]L
M=F%S;W1T+T]L=F%S871L86X@:F5L>F5T96L@:&%S>F[A;&%T80!-X7,@:F5L
M>F5T96L@*'!L+B!&;VYT;W,O365G=N%L87-Z;VQT*2!H87-Z;N%L871A`$UA
M<G-H86QL+7-Z:6=E=&5K`$UA<G1I;FEQ=64`5&%R=&%L;6%Z>F$@82!K]G9E
M=&ME>O5T("@_+RH@9'IS\VME<G)E;"D`16=Y;>%S;F%K(&UE9V9E;&5L]2!M
M97KU:P!-875R:73A;FEA`$UA=7)I=&EU<P!-87AI;>%L:7,@<F5N9&5L:V5Z
MZ7-R92#A;&SS('-ZX6UL8?9S<WIE9RX`07H@_'IE;F5T('3Z;"!S;VL@<NES
M>F+U;"#A;&PN`$%Z(&5L;?IL="`R-"#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK
M;&5T93H@`$%Z(&5L;?IL="`V(/-R82!M87AI;>%L:7,@:/5MZ7)SZ6ML971E
M.B``07H@]G-S>F5G]6]L9&%L(&)L;VMK:F%I;F%K(&UA>&EMX6QI<R!S>N%M
M80!!('-Z^W+U<WIA8N%L>6]K(&UA>&EMX6QI<R!S>N%M80!-87AI;>%L:7,@
M:&]S<WH`5/IL;.EP=&4@82!T:6QT\VQI<W3A;B!TX7)O;&AA=/,@8^UM96L@
M;6%X:6WA;&ES86X@;65G96YG961E='0@<WKA;>%T("AC[6UE:R!S>N%M83H@
M)7,L(&UA>&EMX6QI<R!S>N%M.B`E<RDN($%Z(/IJ(&/M;2!N96T@:V5R_&QT
M(&9E;"!A(&QI<W3A<F$N`%3Z;&SI<'1E(&%Z(&5N9V5DZ6QY97IE='0@8^UM
M96L@;&ES=.%JX6X@=.%R;VQH873S(&5L96UE:R!M87AI;>%L:7-A;B!M96=E
M;F=E9&5T="!S>N%MX70@*&/M;65K('-ZX6UA.B`E<RP@;6%X:6WA;&ES('-Z
MX6TZ("5S*2X@07H@^FH@8^UM(&YE;2!K97+\;'0@9F5L(&$@;&ES=.%R82X`
M;>%J=7,`36%Y;W1T90!/<G9O<W1U9&]MX6YY`%1A9V]K`$$@;65N_"!M96=J
M96QE;NES93H`0V5L;.%K(&5G>6)E;VQV87-Z=.%S80#<>F5N970`02!D:6=I
M=.%L:7-A;B!A;.'M<G0@_'IE;F5T(&AI=&5L97,L(&1E(&%Z(&%LX>UR\R!T
M86[Z<^UT=N%N>>%T(&YE;2!S:6ME<OQL="!E;&QE;O5R:7IN:2X`3&5JX7)T
M(&%Z(/QZ96YE="#I<G;I;GEE<W/I9V4N`$%Z(/QZ96YE="!T[7!U<V$`365T
M87(@:63U:N%RX7-J96QE;G3I<P!!($UE=&%R(&)L;VMK(&YE;2#A;&P@<F5N
M9&5L:V5ZZ7-R92X`02!-971A<B!B;&]K:R!N96T@X6QL(')E;F1E;&ME>NES
M<F4N($$@<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S>N%MX7)A(&OI<WK\
M;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN`$$@365T87)$0B!N96T@Z7)H973U
M(&5L+@!-\V1S>F5R`$$H>BD@(B5S(B!M\V1S>F5R(&1E9FEN:>%L871L86X`
M02!M\V1S>F5R(&1E9FEN:>%L871L86XN($$@;65G:.UV;W1T(&WS9'-Z97(Z
M("5S`$UE=')I:W5S`$UE>&EK\P!-:6MR;V[I>FEA:2!3>O9V971SZ6=I(,%L
M;&%M;VL`:_9ZZ7``34E-12!T[7!U<P!!>B!E;&WZ;'0@,C0@\W)A(&QE9V%L
M86-S;VYY86)B(&CU;>ER<^EK;&5T93H@`$%Z(&5L;?IL="`V(/-R82!L96=A
M;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z(`!-Z6<@;F5M('1E;'0@96P@82!M
M:6YI;>%L:7,@:63U(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%SX6AO>@!4_&MR
M]GKI<R`H:F]B8B]B86PI`%9E9WEE<P!(:>%N>7II:R!A($A45%!?4F5Q=65S
M="!014%2(&-S;VUA9RX`2&GA;GEZ:6L@82!C[6TL(&UE;'ER92#I<G1E<^UT
MZ7-T(&ME;&QE;F4@:_QL9&5N:0!(:>%N>7II:R!A(&/M;2P@86UE;'ER92#A
M="!K96QL(&ERX6YY[71A;F]M(&$@;&5V96QE=`!+;VYF:6=U<N%C:?,@<WK\
M:W/I9V5S+B!%>G0@;6]S="!K96QL(&SI=')E:&]Z;FEA+"!H82!H87-Z;N%L
M;FD@86MA<FIA(&%Z(&%L:V%L;6%ZX7-T+@!(:>%N>7II:R!A>B#\>F5N970@
M87IO;F]S[73S:F$N`$AIX6YY>FEK(&$@=FES<WIA=71A<^UTX7-K;W(@:_QL
M9&5N9/4@:6YD;VL`2&GA;GEZ:6L@87H@875T;VUA=&EK=7,@=N%L87-Z;&5V
MZ6QB92#M<F%N9/,@_'IE;F5T+@!(:>%N>7II:R!A($UA:6P@4$5!4B!C<V]M
M86<N`$AIX6YY>FEK(&$@9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S[73S
M:F$@*'-E<W-I;VX@240I+@!(Z0!,979E;&5ZZ7,@;6]B:6QT96QE9F]N<O-L
M`$OV>F5P97,`02!M\V1O<^UTX7,@9.%T=6UA`$%Z(%523"!M\V1O<^UTX7-A
M`$UO9'5L=7,`36]L9&]V86D@2_9Z=.%R<V%SX6<`36]N86-O`$UO;F?S;&EA
M`$CS;F%P(.ES(.EV`&AA=F]N=&$`36]N='-E<G)A=`!(;VQD9N%Z:7-O:P!!
M("5D+B!S;W)B86X@=/9B8B!M97KU('9O;'0L(&UI;G0@82!VX7)T("5D+@!-
M87)O:VOS`%3V8F)N>6ER92!D97+\;'0`5/9B8FYY:7)E(&)O<G5L=`!4]F)B
M;GEI<F4@;F%P;W,`36]Z9V%TX7,`=FEG>?QK(&QE`'9I9WG\:R!B86QR80!V
M:6=Y_&L@:F]B8G)A`$$@<WIA8N%L>2!L96IJ96)B(&SI<'1E=.ES90!!('-Z
M86+A;'D@9F5J;&5B8B!LZ7!T973I<V4`=FEG>?QK(&;V;`!V:6=Y_&L@;&4`
M=FEG>?QK(&;V;`!-;WIA;6)I:P!4]F)B<WII;G3[(&QE9_9R9/QL]2!L:7-T
MX6L`375L=&EM87`@3F%G>2U"<FET86YN:6$@=.ER:^EP`%3V8F)S>O9R]G,@
M=N%L87-Z=.%S`$)E:F5L96YT:V5ZZ7-I(&)EX6QL[73A<V]K`$)E:F5L96YT
M:V5ZZ7-I(&%D871A:6T`4V%JX70@]G-S>F5G>O4@;VQD86QA;0!386KA="#V
M<W-Z96=Z]2!O;&1A;&%M('1E<G9E>NES90!-:6%N;6%R`$Y%32P@;F5M(&5G
M>65Z96T@8F5L92X`16YN>6D@;F%P;VYKZ6YT(&O\;&1J_&YK(&-S86L@^FIB
M\VP@_%]Z96YE=&5T.@!.Z78`3F%M[6)I80!.875R=0!.97#A;`!(;VQL86YD
M:6$`2&]L;&%N9"!!;G1I;&SA:P!.971S8V%P92!BX7II<RU54DP`3F5T<V-A
M<&4@=&%N^G/M=';A;GEK:6%DX7-I:F]G*$-!*2UV:7-S>F%V;V[A<VD@55),
M`$YE='-C87!E('1A;OIS[71VX6YY9F5L:&%S>F[A;.%S:2!I<N%N>65L=B!5
M4DP`3F5T<V-A<&4@=&%N^G/M=';A;GEM96?Z:NUTX7-I(%523`!.971S8V%P
M92!T86[Z<^UT=N%N>79I<W-Z879O;N%S:2!54DP`3F5T<V-A<&4@4U-,('-Z
M97)V97)NZ78`3F5T<V-A<&4@=&%N^G/M=';A;GD@;65G:F5G>7KI<P!.971S
M8V%P92!T86[Z<^UT=N%N>73M<'5S`$CA;/-Z870`<V]H80#::BU+86QE9/-N
M:6$`VFH@:V%T96?S<FEA`-IJ(&QE=NEL("5S(&/M;7)E`/IJ:&]L9`#::B!S
M>F%BX6QY`-IJ(&9E;&AA<WINX6SS;NEV("AO<&-I;V[A;&ES*0#::BU:Z6QA
M;F0`VFH@:F5L<WKS`$%Z(/IJ(&IE;'-Z\R#I<G;I;GEE<W/I9V4@96MK;W(@
M:N%R(&QE.B`E>"X`02!M96=A9&]T="#Z:B!J96QS>F%V86L@;F5M(&5G>65Z
M;F5K+@#::B!A8FQA:R`H_')E<RD`2.UR96L`2.UR8W-O<&]R=&]K`$OV=F5T
M:V5Z]0!+]G9E=&ME>O4@-"!FX7II<P!+]G9E=&ME>O4@;W!C:?-K`$OV=F5T
M:V5Z]3X`3FEC87)A9W5A`$YI9V5R`$YI9^ER:6$`Z6IS>F%K80!.:75E`$YE
M;0!!(&CA='3I<G-Z;VQGX6QT873A<R!B9>%L;.UTX7-A:6)A;B!N:6YC<R`B
M)7,B(&5L96TN`$YI;F-S(')E;F1E;&ME>NES<F4@X6QL\R!K;VYF:6=U<N%C
M:?,L(&%M:6AE>B!KZ7!E<W0@82!K_&SV;F)SZ6=E:V5T(&UE9R!L96AE=&YE
M(&UU=&%T;FDN`$YI;F-S(&QE:&5T]7/I9R!)4T\@X6QL;VWA;GEO:R!LZ71R
M96AO>N%SX7)A+@!%>F5N(&$@9^EP96X@;FEN8W,@8F7A;&SM='9A(&$@;65G
M9F5L96SU(&CA='3I<G-Z;VQGX6QT873A<P!!(&)A8VME;F0N<&AP(.%L;&]M
MX6YY8F%N(&YI;F-S(&)EX6QL[71V82!A(&CA='3I<G-Z;VQGX6QT873A<P!(
M:>%N>7II:R!A(&OV=&5G96QT(&9E;&1O;&=O>N%S:&]Z('-Z_&MSZ6=E<R!M
M:6YT82`H8F%T8V@@=&5M<&QA=&4I+@!!(&OM=N%N="!H96QY96X@;FEN8W,@
M8FQO:VL`07H@34-!3"!F96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@;FEN8W,@
M;65G861V82!A(&YA<'3A<B!N979E+@!.:6YC<R!VX6QT;WKA<RX`16AH97H@
M82!J;V=O<W5L='/A9VAO>B!N96T@:&]Z:&%T\R!LZ71R92!J;V=O<W5L='/A
M9VD@86QC<V]P;W)T+@!(:>%N>6]Z;F%K(&$@:V]N9FEG=7+A8VGS<R!A9&%T
M;VL@)7,M:&5Z+@!!>B!&5%`@5D93(&YI;F-S(&MO;F9I9W5RX6QV82X`07H@
M4U%,(%9&4R!N:6YC<R!K;VYF:6=U<N%L=F$N`$%Z(%-13"U&:6QE(%9&4R!N
M:6YC<R!K;VYF:6=U<N%L=F$N`$%Z(-9N('-ZX6ULX6KA;B!E;&9O9WEO='0@
M82!R96YD96QK97KI<W)E(.%L;/,@]G-S>F5G+@!.:6YC<R!C[6UZZ7,N`$$@
M<WIE<G9E<G)E(&YE;2!T]FQT]63V='0@9F5L('-E;6UI;'EE;B#A;&QO;>%N
M>0!.:6YC<V5N96L@<WK[<O5K+B!+871T:6YT<V]N("(E<R(M<F4@96=Y(/IJ
M(&SI=')E:&]ZX7/A:&]Z+@!.96T@861O='0@;65G(&9E:FSI8V5K970`07H@
M:6MO;F]K(&YE;2!T86SA;&AA=/-K+@!.:6YC<R!M96=A9'9A(&$@:&5L>2X`
M3FEN8W,@;65G861V82!A(&AE;'DN`$%Z(/QZ96YE="#\<F5S+@!.:6YC<R!M
M96=A9'9A(&$@;NEV+@!.:6YC<R!M96=A9'9A(&$@<WKA;2X`3F4@;&5G>65N
M(&UE9V)O='+A;FMO>G1A=/,@:63I>F5T`$YI;F-S(&IE;'-Z\R!M96=A9'9A
M(&$@2%144"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN
M8W,@:F5L<WKS(&UE9V%D=F$@87H@24U!4"!A;&%P^B!F96QH87-Z;N%L\VD@
M87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!+97)B97)O
M<R!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L
M<WKS(&UE9V%D=F$@82!,;V=I;B!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S
M[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!005-35T0@86QA</H@
M9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN`$YI;F-S(&IE;'-Z\R!M96=A
M9'9A(&%Z(%--0B!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`
M3FEN8W,@;65G861V82!A>B!/<&5N4U-,('!R;V=R86T@96SI<NES:2#Z='9O
M;F%L82X@07H@3W!E;E-33"!P<F]G<F%M('-Z_&MSZ6=E<R!A(%!+0U,@,3(@
M861A=&]K(&ME>F5LZ7/I:&5Z+@!.:6YC<R#Z:B!B96IE;&5N=&ME>NES:2!I
M9^EN>2X`3FEN8W,@:W;S=&$@8F7A;&SM='9A+@!.92!L96=Y96YE:R!V;VYA
M;&%K('-E:&]L+@!!('-Z^W+U;&ES=.%T(&YE;2!F<FES<^UT971T96T`3FEN
M8W,@9&5F:6YIX6QV82!E;';A;&%S>G3S(&MA<F%K=&5R+@!.92!L96=Y96X@
M:V5R970`3F5M(&%D;W1T(&UE9R#I<G3I:V5T`$YI;F-S(&EL>65N(&;A:FP`
M3FEN8W,@:61E:6=L96YE<R#A;&QO;>%N>6]K('3A<F]LX7/A<F$@<WIO;&?A
M;/,@86QK]FYY=G3A<BX`2&GA;GEZ:6L@82!F96QH87-Z;N%L\V[I=B#I<R]V
M86=Y(&$@:F5L<WKS+@!!('9I<W-Z86MA<&]T="!A9&%T;VL@;F5M(.ER=NEN
M>65S(%A-3"!A9&%T;VL`3FEN8W,@861A=`!.:6YC<R!MZ6<@:V]N9FEG=7+A
M8VGS+"!G96YE<N%L:F]N(&5G>65T+@!.:6YC<R!MZ6<@:V]N9FEG=7+A8VGS
M:F$L(&=E;F5RX6QJ;VX@96=Y970N`&YI;F-S`&YI;F-S(&UE9V%D=F$@*&QE
M9WEE;B!A;&%PZ7)T96QM97IE='0I`&YO<F1I:W5S("A)4T\M.#@U.2TQ,"D`
M3F]R9F]L:RUS>FEG970`R7-Z86MI(&;I;'1E:V4`R7-Z86MI+4UA<FEA;F$M
M<WII9V5T96L`3F]R=NEG:6$`3F5M(&OI<_5B8@!.96T@:V]RX6)B86X`3F5M
M(&%L:_9N>79TX7(`3F5M(&5G>65N;/4@82!K]G9E=&ME>O4@<WKA;6UA;`!!
M('!R;V=R86UN86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A
M+@!.:6YC<R!B9>%L;.UT=F$`3F5M('3A;6]G871O='0N`$9E;&IE9WEZZ7-E
M:P!.:6YC<R!B]FYGZ7-Z:&5T]2!A9&%T+"!TZ7)J96X@=FES<WIA+@!+87!J
M86L@Z7)T97/M=.ES="!A(&OV=F5T:V5Z]2!C[6UR90!N;W9E;6)E<@!3>N%M
M`$MA<F%K=&5R96L@<WKA;6$`3W-Z;&]P;VL@<WKA;6$`4V]R;VL@<WKA;6$`
M02!K]G)L97;I;&QI<W1A(&WS9&]S[73A<^%H;WH@;F5M(&%D;W1T(&UE9R!S
M>N%M;VMA="X`3TL`3V)J96MT=6T`07H@;V)J96MT=6T@;.ET<F5H;WKS:F$`
M3VMTX6QI<R!S>N%M`&]K=/-B97(`4WK[<NES`$AI=F%T86PO;75N:V%H96QY
M`$$@<NEG:2#I<R!A>B#Z:B!J96QS>O-N86L@:_QL]FYB]GIN:64@:V5L;"X`
M02!RZ6=I(&IE;'-Z\P!!('+I9VD@:F5L<WKS(&YE;2!M96=F96QE;/4N`$]M
MX6X`0W-A:R!A>B!)34%0('-Z97)V97)E:R!TX6UO9V%T:N%K(&$@;6%P<.%K
M(&UE9V]S>G3A<^%T+@!#<V%K(&IE;/9L:OQK(&UE9R!A(&QE=F5L970`0W-A
M:R!M96=B;W1RX6YK;WIT873S(&EDZ7IE="!L96=Y96X`0W-A:R!E9WD@96UA
M:6P@8^UM(&%D:&%T\R!M96<N`$-S86L@82!T=6QA:F1O;F]S('9A9WD@82!R
M96YD<WIE<F=A>F1A(';A;'1O>G1A=&AA=&IA(&UE9R!E9WD@:_9Z]G,@=.%R
M=&5R_&QE="!T=6QA:F1O;F]SX70@=F%G>2!E;.ERZ7-I(&IO9V]S=6QT<^%G
M86ET`$YY:7-S=6L@;65G(/IJ(&%B;&%K8F%N`$]P96Y34TP@:&EB83H@3F5M
M('-I:V5R_&QT(&MI;GEE<FYI(&%Z(&%D871O:V%T(&%Z(&%LX>UR="!3+TU)
M344@<NES>F+U;`!.>6ES<W5K(&UE9R!E>G0@82!C[6UE="!E9WD@^FH@86)L
M86MB86X`3W!E<N%C:?-S(')E;F1S>F5R`$]P8VGS:P!!('-Z^W+U;&ES=&$@
M9G)I<W/M=.ESZ79E;"!K87!C<V]L871O<R!B9>%L;.UTX7-O:RX`)7,@8F7A
M;&SM=.%S86D`4V]R<WKA;6]S(&9E;'-O<F]LX7,`4WIE<G9E>F5T`%-Z97)V
M97IE=&D@96=Y<^EG`$UU;FMA<WIE<G9E>NES`$%Z(&%L:V%L;6%ZX7,@97)E
M9&5T:2!S86)L;VYJ80`E<R!E<F5D971I('-A8FQO;FIA:3H`16=YZ6(`16=Y
MZ6(@:6YF;W)MX6-I\P!%9WGI8B!B9>%L;.UTX7-O:P#!='1E:VEN=.ES`$$@
M='5L86ID;VYO<R!J;V=O<W5L='/A9V%I`$$@4$%-(&9E;&AA<WINX6SS87IO
M;F]S[73A<R!N96T@X6QL(')E;F1E;&ME>NES<F4N`%!%05(Z.DUA:6P@86QR
M96YD<WIE<@!01U`@9&EG:73A;&ES(&%LX>URX7,`4$=0+79E;"!T:71K;W/M
M=&]T="!A9&%T`%!'4"!N>6EL=N%N;W,@:W5L8W,`4$=0+79E;"!A;.'M<G0O
M=&ET:V]S[71O='0@861A=`!02%`@:_-D`$3I;'5TX6XO97-T92!G>65N9V4@
M97/U`$3I;'5TX6X@97/U`$3I;'5TX6XO97-T92!ZX7!O<F]K`$3I;'5TX6XO
M97-T92!H879A>N%S`$3I;'5TX6XO97-T92!H\WKA<&]R;VL`1.EL=73A;B!N
M87!S_'3I<P!$Z6QU=.%N+V5S=&4@>FEV871A<F]K`$AIX6YY>FEK(&$@4$]3
M25@@8O5V[73I<P!B96QS]2!M87)G\P!086MI<WITX6X`4&%L874`4&%L97-Z
M=&EN(%1E<OQL970@*&UE9W-ZX6QL="D`4&%N86UA`%#A<'5A(-IJ+4=U:6YE
M80!087)A9W5A>0!-Z7)SZ6ME;'1E;B!B;W)U;'0`2F5L<WKS`$$@:F5L<WKS
M="!S:6ME<F5S96X@;65G=N%L=&]Z=&%T='5K+@!.96T@;65G9F5L96SU(&IE
M;'-Z\P!!(%)!1$E54R!F96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@:F5L<WKS
M('-Z_&MSZ6=E<RX`2F5L<WKS(&UE9V5R]7/M=.ES<V5L`$IE;'-Z\SH`2F5L
M<WKS.B``02!J96QS>F%V86MN86L@96=Y97IN:?QK(&ME;&PN`$)E:6QL97-Z
M=.ES`$)E:6QL97-Z=.%S(&$@=N%G\V%S>G1A;'+S;`#:='9O;F%L`-IJ(&9E
M;&AA<WINX6SS;F%K(&)E:F5L96YT:V5Z971T96LZ`$5M8F5R96L`<WKA>F%L
MZ6L`2V%R8F%N=&%R=.%S:2!F96QA9&%T;VL@=NEG<F5H86ITX7-A`$)E:F5L
M96YT:V5ZZ7-K;W(@:&%J='-U:R!VZ6=R92!A(&MA<F)A;G1A<G3A<VD@9F5L
M861A=&]K870_`$IO9V]S=6QT<^%G`$$H>BD@(B5S(B!J;V=O<W5L='/A9V]T
M(&YE;2!T]G+V;'3\:RX`UFYN96L@;FEN8W,@96AH97H@96QE9V5N9/4@:F]G
M;W-U;'1SX6=A`$IO9V]S=6QT<^%G;VL`2F]G;W-U;'1SX6<@861M:6YI<WIT
M<N%C:?,`4WIE;>EL>65S(&%D871O:P!097)U`,%L;&%T:V5D=F5N8V5K`$;\
M;/9P+7-Z:6=E=&5K`%1E;&5F;VX`1NEN>6OI<&=A;.ER:6$`4&ET8V%I<FX`
M<&EX96P`2_9Z:&5L>65K`$MA='1I;G1S;VX@=F%L86UE;'EI:R!C96QLX7)A
M`$)I>G1O<V%N('3V<O9L;FD@86MA<FIA(&5Z="!A>B!E;&5M970Z`$OI<F5M
M(&5R]7/M='-E(&UE9RP@:&]G>2!V86SS8F%N('3V<O9L;FD@:^UVX6YJ82!E
M>G0@87H@96QE;65T+@!+Z7)E;2!A9&IO;B!M96<@96=Y(&CS;F%P;W0@Z7,@
M96=Y(.EV970N`$OI<F5M(&%D:F$@;65G(&%Z(/IJ(&MA=&5G\W)I82!N97;I
M=#H`2^ER96T@=F%L\W,@25`@8^UM970@861J;VX@;65G+@!+Z7)E;2!V86SS
M<R!DX71U;6]T(&%D:F]N(&UE9RP@96QL96[U<FEZ>F4@82!H\VYA<"!N87!J
M86ET+@!+Z7)E;2!V86SS<R!DX71U;6]T(&%D:F]N(&UE9RX`2^ER96T@861J
M82!M96<@87H@^FH@;6%P<&$@;F5VZ70Z`$OI<F5M('+V=FED96X@[7)J82!L
M92!A('!R;V)LZ6UA(&SI;GEE9^ET+@!+Z7)E;2!A9&IA(&UE9R!A(&)E:F5L
M96YT:V5ZZ7-I(&YE=NET(.ES(&IE;'-Z87;A=`!+Z7)E;2!O;'9A<W-A(&5L
M(&$@:_9V971K97KU('-Z]G9E9V5T+B!!(')E;F1S>F5R(&AA<WINX6QA=.%N
M86L@9F5L=.ET96QE:70@96P@2T5,3"!F;V=A9&YI82X`2^ER96T@861J82!M
M96<@87H@^FH@:V%T96?S<FEA(&YE=NET.@!,96YG>65L;W)S>N%G`%!O;&ET
M:6MA`%-Z879A>N%S;VL`4&]R='5GX6QI80!!(&OI<"!E;&AE;'EE>NES90!!
M('3A8FSA>F%T(&5L:&5L>65ZZ7-E`$OV>G9E=&QE;B!L97;I;&O\;&3I<R!E
M8F)E(&$@;6%P<.%B82`H24U!4"!N96T@;6EN9&EG('9E<WII(&9I9WEE;&5M
M8F4I`$%Z(&5L;?IL="`E<R#S<F$@8W-A<&%DZ6MM96YN>6ESZ6=E.B``0W-A
M<&%DZ6L\8G(@+SYV86SS<WKM;OMSZ6<`4')E9G-?;&1A<#H@;F5M('1A;.%L
M:&%T\R!A('-Z_&MSZ6=E<R!,1$%0(&MI=&5R:F5S>G3I<RX`4')E9G-?<V5S
M<VEO;CH@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E<R`H<V5S<VEO;BD@:VET
M97)J97-Z=.ES+@!,Z6=N>6]MX7,`02!T96YG97)S>FEN=&YE:R!M96=F96QE
M;/4@;.EG;GEO;>%S.B``3.EG;GEO;>%S.B``16SU>F5T97,@;65G=&5K:6YT
MZ7,`02!KZ7`@96SU>F5T97,@;65G=&5K:6YTZ7-E(/IJ(&%B;&%K8F%N`$5L
M]7KU(&]P8VGS:P!!(&1O:W5M96YT=6T@:VEN>6]M=&%TX7-A`%1I=&MO<R!K
M=6QC<P!(:6)A8F5J96QE;G3I<P!!(&AI8F$@;&7M<N%S80!0<F]J96MT(&ME
M>F5LZ7,`02!P<F]M<'0@<WKV=F5G90!.>6EL=N%N;W,@:W5L8W,`3GEI;';A
M;F]S(&MU;&-S^B!A;&=O<FET;75S`$YY:6QVX6YO<R!K=6QC<R!I;F9O<FWA
M8VGS`$$@;GEI;';A;F]S+W1I=&MO<R!K=6QC<W#A<G0@;F5M('-I:V5R_&QT
M(&SI=')E:&]Z;FDN`%!U97)T;R!2:6-O`$$@;&5V96QE:R!VZ6=L96=E<R!T
M]G)LZ7-E`$MA=&%R`$ME<F5S]2]P87)A;F-S('-T<FEN9P!+=O-T80!24T$@
M;GEI;';A;F]S(&MU;&-S("@E9"!B:71E<RD`7U;A;&%S>OQZ96YE=`!2X61I
M\V=O;6)O<R!K:7;A;&%S>G3A<P!%<_4`17/U(&3I;&5L]71T`$5S]2!DZ6QU
M=.%N+V5S=&4`6N%P;W(`17/U(.ES(&AA=F%ZX7,`2&%V87-E<_4`5NEL971L
M96X@:63I>F5T`$%RX6YY`$]L=F%SX7,`3&5V96QE:R!O;'9A<^%S80!4Z6YY
M;&5G('3V<O9L:OQK("5S(&9E;&AA<WINX6SS=#\@17H@82!VX6QT;WIT873A
M<R!N96T@9F]R9.UT:&%T\R!V:7-S>F$N`%3I;GEL96<@=/9R]FQJ_&L@)7,@
M9F5L:&%S>F[A;/,@861A=&%I=#\@17H@82!VX6QT;WIT873A<R!N96T@9F]R
M9.UT:&%T\R!V:7-S>F$N`$$@8F7I<FME>NES(&YA<&IA`,%T:7+A;GGM=.%S
M(&5R<F4@82!C[6UR90#::G)A(';I9W)E:&%J=&IA(&%Z('5T;VQS\R!VX6QT
M;WIT873A<W0`1G)I<W/M=.ES`$$@;65N_"!D:6YA;6EK=7,@96QE;65I;F5K
M(&9R:7-S[73I<VD@9WEA:V]R:7/A9V$Z`$%Z(/9S<WIE9WKU;VQD86P@9G)I
M<W/M=.ESZ6YE:R!G>6%K;W)I<^%G83H`4F5G=6SA<FES(&MI9F5J97KI<P!!
M>B#\>F5N970@=FES<WIA9&]BX7-A(&$@:_9V971K97KU(&EN9&]K:V%L`$]B
M:F5K='5M(&+V;F?I<WKU`$9R:7-S[73I<P!-96=J96=Y>NES96L`5.%V;VQI
M('-Z97)V97)E:P!!('3A=F]L:2!54DP@*'!L+B!H='1P.B\O=W=W+G9A;&%M
M:2YH=2]M96=V86QA;6DI.@!4]G)LZ7,`0FQO:VL@=/9R;.ES90!/<WIL;W`@
M=/9R;.ES90!!(&9O<FUA='3A;.%S('3V<FSI<V4`02!PX7(@=/9R;.ES90!4
M]G+V;&K\:R!A>B!E;&UE;G1E='0@<')O9W)A;6]T(&$@<WIE<G9E<B!I9&5I
M9VQE;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7+A8O-L
M+@!696=Y_&L@:VD@`%9E9WG\:R!K:2!E>G0@82!RZ7-Z="!A(&1O:W5M96YT
M=6UB\VP`02!F96QH87-Z;N%L\R!T]G)LZ7-E`"5S(&9E;&AA<WINX6SS('3V
M<FSI<V4`02!KZ7+I<R!N96T@=&5L:F5S[71H973U+B!!(&MA<&]T="!H:6)A
M:_-D.B``02!K97)E<V5T="!S>F]L9^%L=&%TX7,@;F5M('1A;.%L:&%T\RX`
M02!K]G1E;&5Z]65N(&UE9V%D86YD\R`B)7,B(&YE;2!S>F5R97!E;"`E<R!K
M;VYF:6=U<N%C:?-JX6)A;BX`02!K]G1E;&5Z]65N(&UE9V%D86YD\R`B)7,B
M(&YE;2!S>F5R97!E;"!A(%9&4R!K;VYF:6=U<N%C:?-JX6)A;BX`02!K]G1E
M;&5Z]65N(&UE9V%D86YD\R`B)7,B(&YE;2!S>F5R97!E;"!A(&MO;F9I9W5R
MX6-I\V)A;BX`4WK\:W/I9V5S(&UE>O4`4F5S970`02!J96QS>O,@X73A;&SM
M=.%S80!!>B#6;B!J96QS>F%VX6YA:R#A=.%L;.UTX7-A`$%Z('5T;VQS\R!K
M97)E<^ES('9I<W-Z8>%L;.UTX7-A`$5R961MZ6YY`%9I<W-Z82!A('-Z86+A
M;'EL:7-TX6AO>@!6:7-S>F$@87H@;W!C:?-K:&]Z`%9I<W-Z82!A('-Z86+A
M;'EL:7-TX6AO>@!!>B#Z:B!J96QS>O-T(.UR:F$@8F4@:7-MZ70`4NEU;FEO
M;@#!;&SM='-U:R!V:7-S>F$@82!K;VYF:6=U<N%C:?-T`%)I8V@@5&5X="!%
M9&ET;W(@;W!C:?-K`%1A;.%L\W,@:^ER9.ES96L`:F]B8@!*;V)B(&]L9&%L
M:2!F96ILZ6,`2F]B8B!O;&1A;&D@Z7)TZ6ME:P!3;W(@='5L86ID;VYSX6=O
M:RXN+@!3>F5R97``4F]MX6YI80!&;W)G873A<R`Q.#`@9F]K:V%L`$)A;')A
M(&9O<F=A=.%S`$IO8F)R82!F;W)G873A<P!3;W(@='5L86ID;VYSX6=O:P!3
M;W(@='5L86ID;VYSX6=O:P!3;W)O:SH`4WIA8N%L>0!!('-Z86+A;'ET(&QE
M;>%S;VQT86T`02!S>F%BX6QY="!T]G+V;'1E;0!!('-Z86+A;'ET(&QE=&EL
M=&]T='5K`$$@<WIA8N%L>70@96YG963I;'EE>G1E;0!3>F%BX6QY(&YE=F4`
M4WIA8N%L>3H`5F]N86QA:P!-:6YD96X@<V]R(.ES(&]S>FQO<"!K]GKV='0@
M;&5G>65N('9O;F%L`$-S86L@87H@;W-Z;&]P;VL@:_9Z]G1T(&QE9WEE;B!V
M;VYA;`!#<V%K(&$@<V]R;VL@:_9Z]G1T(&QE9WEE;B!V;VYA;`!&=71T873A
M<P!/<F]S>B!&]F1E<N%C:?,`4G5A;F1A`%,O34E-12!D:6=I=.%L:7,@86SA
M[7+A<P!3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&]T="!L97;I
M;`!305-,(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@=&%LX6QH873S+@!3
M35,@:_QL9.ES`%-13"!P87)A;F-S(&$@:V5R97/I<VAE>@!34T@`4U1!4E14
M3%,@:&EB83H@*"5S*2`E<P!324M%4MQ,5`!3>F\`4WIE;G0@26QO;F$M<WII
M9V5T`%-A:6YT($MI='1S(.ES($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92#I<R!-:7%U96QO;@!386EN="!6:6YC96YT(.ES($=R96YA9&EN92US
M>FEG971E:P!59WEA;F%Z(&$@9G)A;64@*%]S96QF*0!3>F%M;V$`4V%N($UA
M<FEN;P!386\@5&]MZ2#I<R!0<NUN8VEP90!-^VAO;&1A<R!I;G1E<FYE=&5L
MZ7+I<P!3>F'Z9"U!<N%B:6$`365N=.ES`"(E<R(@;65N=.ES90`E<R!M96YT
MZ7-E`$$@8F7A;&SM=.%S;VL@;65N=.ES90!"9>%L;.UTX7-O:R!E;&UE;G3I
M<V4`365N='/\:R!E;"!A>B!E;&OI<WK\;'0@:V]N9FEG=7+A8VGS="!02%`@
M<')O9W)A;2!F;W)MX6KA8F%N(&$@<WIE<G9E<B!I9&5I9VQE;F5S(.%L;&]M
MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7+A8F%N+@`E<R!K;VYF:6=U
M<N%C:?-JX70@96QM96YT971T_&LN`$5L;65N=&5T=/QK(&$@<V5T=7`@=7!G
M<F%D92!P<F]G<F%M;W0@:61E.B`B)7,B`%-Z\W)VX6YY;W,@>FEV871A<F]K
M`%1U9&]MX6YY`%-Z^W+U;&ES=&$`4WK[<O5L:7-T82!F<FES<^UTZ7,`02!S
M>OMR]6QI<W3A="!N96T@9G)I<W/M=&5T=&5M+@!!('-Z^W+U;&ES=&$@Z7)V
MZ6YY97/M=.ES92!M96=T]G)TZ6YT+@!!('-Z^W+U;&ES=&$@Z7)VZ6YY=&5L
M96[M=.ES92!M96=T]G)TZ6YT+@!+97)E<^ES`$ME<F5SZ7-I('-Z;VQGX6QT
M873A<V]K`$]L=F%S;W1T`,%L;&]MX6YY;VL@:VEVX6QA<WITX7-A`%;A;&%S
M<WIO;B!K:2!E9WD@9.%T=6UO=`!6X6QA<W-Z;VX@:VD@96=Y(&UE>O5T`$UE
M;'EI:R!C<V]P;W)T;W0@:^UVX6YJ82!H;WIZX6%D;FD`5N%L87-S>F$@:VD@
M87H@^FH@='5L86ID;VYO<W0`5N%L87-S>F]N('-Z97)V97)T`$UE;'EI:R!F
M96QH87-Z;N%L\W0@:^UVX6YJ82!H;WIZX6%D;FD`36EN9&5T(&MI:F5L]FQJ
M_&L`5N%L87-S>F$@:VD@87H@]G-S>F5S(&3A='5M]G-S>F5T97;U="X`5N%L
M87-S>F]N(&5G>2!O8FIE:W1U;6]T`$5G>2!S92!L96=Y96X@:VEJ96SV;'9E
M`%;A;&%S<WIA(&MI(&$@8^EL;6%P<.%T`%;A;&%S<WIA(&MI(&$@:^UVX6YT
M(&MA<F%K=&5R*&5K92ET(&%Z(&%LX6)B:2!L96AE=/5SZ6=E:R!K]GK\;"X@
M17IU=.%N(")C;W!Y+W!A<W1E(B!M\V1S>F5R<F5L(&$@;65G9F5L96SU(&AE
M;'ER92!MX7-O;&AA=&IA(/5K970N`%;A;&%S<WIA(&MI(&$@9.%T=6UE;';A
M;&%S>G3S(&MA<F%K=&5R=#H`5N%L87-S>F$@:VD@82!DX71U;2!F;W)MX71U
M;>%T.@!6X6QA<W-Z82!K:2P@;65L>6EK(&%Z;VYO<^UT\VKA="!K[7;A;FIA
M(&UE9W;A;'1O>G1A=&YI.@!6X6QA<W-Z82!K:2!A>B!I9/5E;';A;&%S>G3S
M(&MA<F%K=&5R=#H`5N%L87-S>F$@:VD@87H@:63U(&9O<FWA='5MX70Z`%;A
M;&%S<WIO;B!K:2!KZ70@96=Y;>%S;F%K(&UE9V9E;&5L]2!M97KU="X`5N%L
M87-S>F$@:VD@82!K[7;A;G0@<WKM;F5G>?QT=&5S="X`5N%L87-S>F$@:VD@
M87H@UFYN96L@;65G9F5L96SU(&YY96QV970Z`,%L=&%L86T@;65G861O='0@
M9F5J;.EC`$AI8F%J96QE;G3I<R!K_&QDZ7-E`%--4R!K_&QDZ7-E`$O\;&3U
M`%-Z96YE9^%L`%-Z96YZ;W(Z(`!S>F5P=&5M8F5R`%-Z97)B:6$@Z7,@36]N
M=&5N96=R\P!3;W)O>F%T<WKA;0!!('-Z97)V97)T]6P@:V%P;W1T(&%D870@
M:&EBX7,L('9A9WD@;F5M(.%L;"!R96YD96QK97KI<W)E+@!!(&9E;&AA<WIN
MX6SS:V%P8W-O;&%T;VL@861M:6YI<WIT<N%C:?-J80!,96KA<G0@82!F96QH
M87-Z;N%L\VMA<&-S;VQA="!A>F]N;W/M=/-J82`H<V5S<VEO;B!)1"DN`$9E
M;&AA<WINX6SS:V%P8W-O;&%T;VL`2&%L;6%Z`$QE:&5T]7/I9R!J96QS>F%V
MX6YA:R#A=.%L;.UTX7/A<F$L(&%B8F%N(&%Z(&5S971B96XL(&AA(&5L9F5L
M96IT96[I+@!4X79O;&D@<WIE<G9E<F5K(&5LZ7+I<V4@X6QL[71H873S(&)E
M+"!M96QY96ME="!A>B!I;F1U;/-O;&1A;.%N(&OM=N%N(&UE9VIE;&5N[71E
M;FDN`$$@:^UVX6YT(&YY96QV+"!I9/5Z\VYA(.ES(&3A='5M9F]R;>%T=6T@
M8F7A;&SM=.%S82X`0F7A;&SM=&AA=/,L(&AO9WD@;65L>6EK(&%L:V%L;6%Z
MX7,@:F5L96YJ96X@;65G(&$@8F5J96QE;G1K97KI<R!U=.%N+"!M:6QY96X@
M<WKM;F5G>?QT=&5S="P@;VQD86QF<FES<^UTZ7-I(&=Y86MO<FESX6=O="!I
M;&PN(&5G>>EB(&)EX6QL[73A<V]K870@<WIE<F5T;F4N`$$@8F7A;&SM=.%S
M;VMA="!S:6ME<F5S96X@Z7)VZ6YY97/M=&5T=&5M+@!"9>%L;.UTX7-O:P!!
M(&)EX6QL[73A<V]K870@;65G^FKM=/,@<')O9W)A;6]K(.%L;&YA:R!R96YD
M96QK97KI<W)E`$$@;65G861O='0@<&%R86WI=&5R('3V8F(@:&5L>65T(&ES
M(&IE;&5N=&AE=#H@`%-E>6-H96QL92US>FEG971E:P!6X7/A<FSA<P!2]G9I
M9"#V<W-Z969O9VQA;.%S`$5L(&OM=N%N:F$@Z7)N:2!A>B!E9WEE<R!F=6YK
M8VGS:V%T($%L="UB:6QL96YT>?LM:V]M8FENX6-I\VMK86P@:7,_`$UE9VIE
M;&5N[73I<P!!:W1UX6QI<R!S>OMR]6QI<W1A(&UE9W1E:VEN=.ES90!!>B!A
M:W1UX6QI<R!S>OMR]6QI<W1A(&UE9VIE;&5N[73I<V4`375T87-S=6L@;65G
M(&$@:_QL]FYB<^EG96ME="!A>B!E;&UE;G1E='0@Z7,@87H@^FIO;FYA;B!L
MZ71R96AO>F]T="!K;VYF:6=U<N%C:?,@:_9Z]G1T+@!-:6YD96X@8F5J96QE
M;G1K97KI<VMO<B#M<O-D:NEK(&MI(&$@:V]RX6)B:2!U=&]L<_,@8F5J96QE
M;G1K97KI<R!I9&5J93\`5N%L87-Z=&AA=/,@;&5G>65N(&%Z(&5R961E=&D@
M;65G=&%R=.%S80!,96=Y96X@9.%T=6UVX6QA<WIT\P!,96=Y96X@96=Y('3A
M8FSA>F%T:V5Z96SU(&UE;OQS;W(_`$UU=&%S<W5K(&$@)7,@;65N_'0@82!B
M86P@;VQD86QO;C\`3NEZ>OQK(&UE9R!TX6)LX7IA="!C96QLX6EN86L@='5L
M86ID;VYSX6=A:70`3NEZ>OQK(&UE9R!TX6)LX7IA="!T=6QA:F1O;G/A9V%I
M=`!.Z7IZ_&L@;65G('3A8FSA>F%T('-O<F%I;F%K('1U;&%J9&]N<^%G86ET
M`$[I>GK\:R!M96<@82!KZ7`@='5L86ID;VYSX6=A:70`375T87-S=6L@82!F
M96QT]FQTZ7-T`%KA<&]R;VL`6N%P;W)O:R!DZ6QE;/5T=`!:X7!O<F]K(&3I
M;'5TX6XO97-T90!(96QY:2!ZX7!O<F]K`$MI8W-I;GGM=.ES`$5L]7-Z]G(@
M:VEC<VEN>>UT96YI92!K96QL+"!V86=Y(&5L(&ME;&P@;6]Z9.UT86YI82!A
M(&AE;'EE="!E;&9O9VQA;/,@8FQO:VMO:V%T+@!3:65R<F$@3&5O;F4`VFH@
M9F5L:&%S>F[A;/-K(&)E:F5L96YT:V5ZZ7-E`$1I9VETX6QI<R!A;.'M<N%S
M`$$@9&EG:73A;&ES(&%LX>URX7,@86QG;W)I=&UU<V$`4WII;F=A</IR`$WI
M<F5T`$$@:V%R8F%N=&%R=.%S(&MI:&%G>>%S80!3>FQO=N%K:6$`4WIL;W;I
M;FEA`$AA=F%ZX7,`2/-ZX7!O<@!(\WKA<&]R;VL`2/-ZX7!O<F]K(&3I;&5L
M]71T`$OI<_4@9.EL=73A;FDO97-T:2!H\WKA<&]R;VL`02!H\R!MZ6QY<^EG
M93H@`$CS(';M>FUE;FYY:7/I9V5B96X@:VEF96IE>G9E.B``4V%L86UO;BUS
M>FEG971E:P!3>F]MX6QI80!$86QO:RP@=F5R<V5K`$$@<V]R8F%R96YD97KI
M<R!I<N%N>>%N86L@:VEVX6QA<WITX7-A`$9E;&%D\VD@8^UM`$3I;"U!9G)I
M:V$`9.EL+65U<O-P86D@*$E33RTX.#4Y+3,I`$3I;&DM1V5O<F=I82#I<R!$
MZ6QI(%-A;F1W:6-H+7-Z:6=E=&5K`$3I;&D@9NEL=&5K90!3>F]M<WKI9&]S
M(&-E;&SA:R!K]GKV='1I('3A=F]L<^%G`$$@8V5L;&$@=&%R=&%L;6$@Z7,@
M:V5R971E(&OV>O9T=&D@=.%V;VQSX6<`2&5L>6MI=/9L=/4`5.%V;VQSX6<`
M5.%V;VQSX6<@Z7,@8F5L<_4@;6%R9_,@8F7A;&SM=.%S`%-P86YY;VQO<G-Z
MX6<`4W!A;6%S<V%S<VEN92!B9>%L;.UTX7-O:P!3<&5C:>%L:7,@:V%R86MT
M97(@8F5V:71E;&4`02!C96QL82!K971TZ6)O;G3A<V$`07H@;W-Z;&]P(&ME
M='3I8F]N=.%S80!!('-O<B!K971TZ6)O;G3A<V$`4W!O<G0`4W+M($QA;FMA
M`%-T86YD87)D`%-T87(@5')E:P!!>B!E;'/U(.EV`,%L;&%M('9A9WD@=&%R
M=&]MX6YY`,%L;&%P;W0`2&$@97H@82!S>F%BX6QY('+A:6QL:6L@87H@_'IE
M;F5T<F4L(&$@=/9B8FD@<WIA8N%L>70@;F4@9&]L9V]Z>G5K(&9E;`!-96YT
MZ7-I(&9O<FWA='5M`$/M;2`H=71C82D`X71H^GIO='0`4W1R:6YG(&QI<W1A
M`%3V<O9L:OQK(&$@8^UM8O5L(&$@0"!U=.%N:2!RZ7-Z=`!3=.UL=7,@6T-3
M4UT`5F$`02AZ*2`B)7,B(&%L:_9N>79TX7(@;F5M('1A;.%L:&%T\RX`02!V
MX6QA<WK\>F5N970@7W3A<F=Y(&UE>O5J93H`5.%R9WD`5.%R9WDZ`$O\;&1J
M_&L@96P`(B5S(B#Z:B!F96QH87-Z;N%L\R!B96IE;&5N=&ME>NES:2!KZ7)E
M;&WI="!T;W;A8F+M=&]T='5K+B#6;B!C<V%K(&OI<F5L;>EN96L@96QF;V=A
M9.%SX70@:_9V973U96X@='5D(&UA:F0@8F5J96QE;G1K97IN:2X`86QS\R!I
M;F1E>`!3:6ME<OQL=`!3:6ME<F5S96X@:&]Z>N%A9'1U:R`B)7,B+70@82!R
M96YD<WIE<FAE>BX`(B5S(B!F96QH87-Z;N%L\R!A9&%T86ET('-I:V5R97-E
M;B!T]G+V;'3\:R!A(')E;F1S>F5R8O5L+@!3:6ME<F5S96X@=/9R]FQT_&L@
M(B5S(BUT+@!3:6ME<F5S96X@96QTX79O;.UT;W1T=6L@(B5S(BUT(&$@<F5N
M9'-Z97)B]6PN`$$@:V]N9FEG=7+A8VGS="!S:6ME<F5S96X@=FES<WIAX6QL
M[71O='1U:RX@02!VX6QT;WKA<V]K(&UE9W1E:VEN=.ESZ6AE>B!F<FES<^UT
M<V4@87H@;VQD86QT+@!!(&)A8VMU<"!K;VYF:6=U<N%C:?-T(&5L;65N=&5T
M=/QK+@!3:6ME<F5S96X@96QM96YT971T_&L@82AZ*2`E<R!B86-K=7`@:V]N
M9FEG=7+A8VGS="X`(B5S(B!A9&%T86EN86L@;?-D;W/M=.%S82!S:6ME<F5S
M96X@;65G=/9R=.EN="X`4VEK97)E<V5N(&5L;65N=&5T=/QK(&$@)7,@X6QL
M;VWA;GET+@!3>G5DX6X`UG-S>F5F;V=L86SA<P!.87!K96QT90!.87!N>75G
M=&$`;F%P;W,`3F%P:V5L=&4`3F%P:V5L=&4O;F%P;GEU9W1A`$YA<&ME;'1E
M.B``3F%P;GEU9W1A`$YA<&YY=6=T83H@`&9E;'/U(&EN9&5X`$]N;&EN92!K
M;VUM=6YI:^%C:?,@*&-H870I`%-U<FEN86UE`$-S86SA9&[I=@!3=F%L8F%R
M9"#I<R!*86X@36%Y96X`4WIVX7II9O9L9`!3=NED;W)S>N%G`%-VX6IC`$%Z
M(&%D871S>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>70@=/9R]FQT_&L`
M4WII;G1A:W1I:V%I(&AI8F$@82!K97)E<_5K:69E:F5ZZ7-B96X`4WKM<FEA
M:2!!<F%B($OV>G3A<G-A<^%G`%II=F%T87(`6FEV871A<BP@97+U<R!S>NEL
M`%II=F%T87)O:P!+;W)A:2!Z:79A=&%R;VL`5%-6("A404(@:V%R86MT97)R
M96P@96QVX6QA<WIT;W1T(.ER=.EK96LI(.%L;&]MX6YY`%3A8FSA>F%T`$$@
M=.%B;.%Z870@='5L86ID;VYSX6=A:0!!('3A8FSA>F%T('1U;&%J9&]N<^%G
M86D`5&%J=F%N`%1A:G9A;@!4861Z<VEK:7-Z=.%N`%1A;GKA;FEA:2!%9WEE
M<_QL="!+:7+A;'ESX6<`02!CZ6PZ`$9E;&%D871O:P!496QE9F]N<WKA;0!!
M>B!E;&WZ;'0@\W)A(&CU;>ER<^EK;&5T93H@`$CU;>ER<^EK;&5T`$CU;>ER
M<^EK;&5T.B``2/5MZ7)SZ6ML970\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F
M9&5G.R5S`$$H>BD@(B5S(B!S86)L;VX@;F5M('1A;.%L:&%T\RX`4V%B;&]N
M;VL@861M:6YI<WITX6-I\VIA`%-Z]G9E9P!C<V%K('-Z]G9E9P!3>O9V96=E
M;&AE;'EE>NES`'-Z]G9E9R!T971E:F4`0W/\`'1H86D@*%1)4RTV,C`I`%1H
M86EF]FQD`$%Z(&9T<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$$@2&ES=&]R
M>2!R96YD<WIE<B!M^VOV9.ES92!N:6YC<R!E;F=E9.EL>65Z=F4N`$$@2&]R
M9&4O2V]L86(@:6YT96=RX6-I\R!E>G0@;F5M('3A;6]G871J83H@(B5S(@!!
M>B!)35-0(&YA<&SS>N%S="!N96T@<VEK97+\;'0@;65G:V5Z9&5N:2X`02!-
M86EN=&5N86YC93HZ(&]S>G3A;'D@8F5T]FQTZ7-E(&YE;2!S:6ME<OQL=`!!
M>B!/<&-I\R!A8FQA:R!B97KA<F]D;W1T+B!+:6SI<.ES(&OV=F5T:V5Z:6LN
M`$$H>BD@(B5S(B!C[6UE="!H;WIZX71E='3\:R!A>B#6;B!T:6QT\VQI<W3A
M:N%H;WHN`$$H>BD@(B5S(B!C[6UE="!H;WIZX71E='3\:R!A>B#6;B!E;F=E
M9.EL>65ZZ7-I(&QI<W3A:N%H;WHN`$$@2F]G;W-U;'1SX6=O:R!H87-Z;N%L
M873A;F%K(&5L]69E;'3I=&5L92P@:&]G>2!A(')E;F1S>F5R9V%Z9&$@:V]N
M9FEG=7+A;&IO;B!E9WD@82!J;V=O<W5L='/A9VD@861A=&]K870@=&%R=/-S
M86X@=.%R;VQN:2!KZ7!E<R!A;')E;F1S>F5R="X`0W-A:R!A;'5L(&QE9WEE
M;B!K97)E=`!!('!A<G1N97(@87IO;F]S[73S<WKA;6$@;F5M('9O;'0@;65G
M861V82_\<F5S96X@;6%R861T('9A9WD@87H@861A=&+A>FES8F%N(&YE;2!V
M;VQT(&UE9W1A;.%L:&%T\RX`02!P87)T;F5R(&%D871A:70@<VEK97)E<V5N
M(&AO>GKA861T=6L@82!C[6UJ96=Y>NEKZ6AE>BX`2_QL]F[A;&SS(%!'4"!A
M;.'M<N%S:2!B;&]K:R!S>OQK<^EG97,@82!D:6=I=.%L:7-A;B!A;.'M<G0@
M_'IE;F5T(&AI=&5L97-SZ6?I;F5K(&5L;&5N]7)ZZ7/I:&5Z+@!!(&OV<FQE
M=NEL;&ES=&$@87IO;F]S[73S<WKA;6$@;F5M('9O;'0@;65G861V82_\<F5S
M96X@;6%R861T('9A9WD@87H@861A=&+A>FES8F%N(&YE;2!V;VQT(&UE9W1A
M;.%L:&%T\RX`02!K]G)L97;I;&QI<W1A(&YE;2!V;VQT(&UE9V%D=F$N`$$@
M;65G:&%J=/,@82!K]G9E=&ME>O5T(/QZ96YT93H@`$$@=&ET:V]S[73A<VD@
M<WIO;&?A;'1A=.%S;VMH;WH@8FEZ=&]N<^%G;W,@*'1I=&MO<^UT;W1T*2!W
M96(@:V%P8W-O;&%T(&ME;&PN`$$H>BD@)7,@X6QL;VWA;GEB86X@<WIE<F5P
M96QN:64@:V5L;&5N92!E9WD@)7,@8F7A;&SM=.%S;F%K+@!!*'HI("5S(.%L
M;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@=F%L86UI;'EE;B`E<R!B
M9>%L;.UTX7,H;VLI;F%K+@!!(&;A:FP@;F5M(&WA<V]L:&%T\R#V;FUA9^%R
M82X`02!FX6IL8F%N(&YE;2!V;VQT(&%D870N`$%Z(/QZ96YE="!F96ILZ6-S
M;W)A:2!A(&OV=F5T:V5Z]6LN`$$@=&5L:F5S(&OI<&5R;GGU<R#\>F5M;?-D
M('!R;V)LZ6WA:V%T(&]K;WIH870@87H@26YT97)N970@17AP;&]R97(@:&%S
M>F[A;&%T82!E<V5TZ6XL(&UE<G0@96)B96X@;VQY86X@<')O9W)A;6AI8N%K
M('9A;FYA:RP@86UI:V5T(&YE;2!T=61T=6YK(&UE9VME<OQL;FDN($$@:^EP
M97)N>?5J92!O;'9A<VAA=&%T;&%N;N$@=N%L:&%T+"!B:7IO;GEO<R!E9&ET
M;W(@9G5N:V-I\VL@:&GA;GEO>FAA=&YA:R#I<R]V86=Y(';A<F%T;&%N=6P@
M;&5F86=Y:&%T(&$@8O9N9^ES>O5P<F]G<F%M+B!7:6YD;W=S(#EX(&AA<WIN
MX6QA=&$@97-E=.EN(&YA9WEO;B!V86SS<WKM;OLL(&AO9WD@)T=E;F5R86P@
M<')O=&5C=&EO;B!F875L="<@:&EB82!M:6%T="#Z:G)A(&ME;&P@:6YD[71A
M;FEA(&UA:F0@82!GZ7#I="Y<;EQN1FEG>65L;65Z=&5T=/QK(2!+871T:6YT
M<V]N(&%Z($]+(&=O;6)R82P@:&$@;>EG:7,@;65G(&OM=N%N:F$@:^USZ7)E
M;&YI(&$@=&5L:F5S(&OI<&5R;GGU<R#\>F5M;?-D;W0N`$$@(B5S(B!A>F]N
M;W/M=/-T(&MI=/9R]FQT_&LN`$-S86L@8F%L(&]L9&%L;VX@;&5G>65N(&ME
M<F5T`$$@1VYU4$<@<')O9W)A;2!H96QYZ70@;65G(&ME;&P@861N:2!A($-R
M>7!T7W!G<#HZ(&]S>G3A;'D@:&%S>F[A;&%TX6AO>BX`02!L97;I;"P@;65L
M>65T("5S(&YA<&KA;B!K_&QD]G1T("5S(&/M;7IE='1N96L@(B5S(B!TX7)G
M>6)A;BP@82!C[6UZ971T('-ZX6WM=/-GZ7#I;B!M96=J96QE;G0N($%R<F$@
M;FEN8W,@9V%R86YC:6$L(&AO9WD@96P@:7,@;VQV87-TX6L@:6QL+B!H;V=Y
M(&UE9^ER=&5T=.EK+@!-:2!L96=Y96X@82!L97;I;.UR\R!A8FQA:VAO>B!M
M=71A=/,@;&EN:R!E;&YE=F5ZZ7-E`$$@;65Z]6L@<WKA;6$@8W-A:R!N=6UE
M<FEK=7,@Z7)TZ6L@;&5H970N`$%Z(&]P96YS<VP@;6]D=6P@<WK\:W/I9V5S
M(&$@2&]R9&5?0W)Y<'1?<VUI;64Z.B!O<WITX6QY(&AA<WINX6QA=.%H;WHN
M`$$@(B5S(B!S>F5MZ6QY97,@8F7A;&SM=.%S(&YE;2!M96YT:&5T]2!E;"P@
M;65R="!MZ7)E=&4@;65G:&%L861J82!A(&UE9V5N9V5D971T(&UA>&EM=6UO
M=`!.96T@=&%LX6QH873S(&%Z(&$@<')O9W)A;2!A('-Z97)V97)E;BP@86UI
M('-Z_&MSZ6=E<R!E;FYE:R!A>B!A9&%T=.UP=7-N86L@*"5S*2!A(&UE9VIE
M;&5N[73I<^EH97HN`$%Z(&EDZ7KU:F5L(&MA<F%K=&5R(&-S86L@96=Y971L
M96X@:V%R86MT97(@;&5H970N`$IO8F(@Z7,@8F%L(&]L9&%L;VX@;&5G>65N
M(&ME<F5T`$-S86L@:F]B8B!O;&1A;&]N(&QE9WEE;B!K97)E=`!!>B!E;';A
M;&%S>G3S(&MA<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT97(@;&5H970N
M`$$H>BD@(B5S(B!S>F5R=F5R="!T]G+V;'3\:RX`02AZ*2`B)7,B('-Z97)V
M97)T(&5L;65N=&5T=/QK+@`E<R!B96IE;&5N=&ME>NES:2!KZ7)E;&WI="!T
M]G+V;'3\:RX`02!M96=A9&]T="!S;W(@*"5D*2!N96T@;.ET97II:RX`02AZ
M*2`B)7,B(&ED96EG;&5N97,@9N%J;"!N96T@;.ET97II:RX`02!B9>UR="!S
M>O9V96<@;F5M(&5G>65Z:6L@82!KZ7!E<FYY]6X@;&5V]79E;"X`06QU;"#I
M<R!F]FS\;"!L96=Y96X@:V5R970`0W-A:R!F96YT(&QE9WEE;B!K97)E=`!!
M(&9E;'3V;'3V='0@861A=&]K(&%Z(&5L]7KU(&SI<.ES(/-T82!E;'9E<WIT
M96LN`$$@9F5L=/9L=/9T="!FX6IL="!N96T@<VEK97+\;'0@96QM96YT96YI
M+@!!('=E871H97(N8V]M(&)L;VMK(&YE;2!H87-Z;N%L:&%T\RX`02!M96=J
M96QE;NES:2!S=.UL=7,@*'1H96UE<RD@86QK]FYY=G3A<B`B)7,B(&YE;2!T
M86SA;&AA=/,N`$YI;F-S96X@=N%L87-Z=&AA=/,@;W!C:?,N`$YI;F-S(&$@
M;&5VZ6P@8F5L<V5JZ6)E;B!M96=J96QE;NUT:&5T]2!M96QLZ6ML970N`%3Z
M;"!S;VL@:V%R86MT97(@=F%N(&5B8F5N(&$@;65Z]6)E;BX@UFX@)7,@:V%R
M86MT97)T(&%D;W1T(&UE9SL@82!M87AI;>%L:7-A;B!M96=A9&AA=/,@<&5D
M:6<@:V5V97-E8F(L(&UI;G0@)7,N`"(E<R(@9F5L:&%S>F[A;/-N86L@82!R
M96YD<WIE<FAE>B!A9.%S86MO<B!H:6)A('3V<G3I;G0N("5S`"(E<R(@9F5L
M:&%S>F[A;/,@861A=&%I;F%K('3V<FSI<V4@<V]RX6X@:&EB82!LZ7!E='0@
M9F5L.B``(B5S(B!R96YD<WIE<F+U;"!V86SS('3V<FSI<V5K;W(@:&EB82!L
MZ7!E='0@9F5L.B``(B5S(B!M\V1O<^UTX7-A('-O<N%N(&AI8F$@;.EP971T
M(&9E;#H@)7,`07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R
M92!F96QT]FQT96YI+B`E<R!N96T@=/9L=/5D]G1T(&9E;"X`07H@X6QL;VWA
M;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI+B`E<R!N
M86=Y;V)B+"!M:6YT(&$@;6%X:6WA;&ES86X@;65G96YG961E='0@;>ER970@
M*"5D(&+A:G0I+@!!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@<WIE<G9E
M<G)E(&9E;'3V;'1E;FDN($$H>BD@)7,@9N%J;&YA:R!C<V%K(&5G>2!RZ7-Z
M92!T]FQT]63V='0@9O9L+@!(:6)A('3V<G3I;G0@82!S>OMR]6QI<W1A(&5N
M9V5DZ6QY97KI<V4@<V]RX6XN`$AI8F$@=/9R=.EN="!A('-Z^W+U;&ES=&$@
M;&5T:6QTX7-A('-O<N%N+@!!(&QE=NEL(&4@<NES>NEN96L@;65G:F5L96[M
M=.ES96MO<B!H:6)A('3V<G3I;G0`02!P87)T;F5R(&%D871O:R!I;7!O<G3A
M;.%S82!S;W+A;B!H:6)A('3V<G3I;G0N`$%Z(&E#86QE;F1A<B!A9&%T;VL@
M:6UP;W)TX6SA<V$@<V]RX6X@:&EB82!T]G)TZ6YT+@!(:6+A<R!A(&UE9V%D
M;W1T(&MO;F9I9W5RX6-I\RX@3&5H970L(&AO9WD@;F5M('3V;'3V='0@:VD@
M96=Y('-Z_&MSZ6=E<R!M97KU="X`02!P87)T;F5R:F5G>7KI:VME;"!K87!C
M<V]L871O<R!F96QA9&%T(';I9W)E:&%J=.%S82!S;W+A;B!H:6)A(&SI<&5T
M="!F96PN($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N`$AI8F$@=/9R=.EN
M="!A('!A<G1N97(@861A=&%I;F%K(&9R:7-S[73I<V4@<V]RX6XN($OI<F5M
M('!R\V+A;&IA(&UE9R!KZ7/U8F(N`$$@:_9R;&5VZ6QL:7-T82!A9&%T86EN
M86L@9G)I<W/M=.ES92!S;W+A;B!H:6)A('3V<G3I;G0N($OI<F5M('!R\V+A
M;&IA(&UE9R!KZ7/U8F(N`$5Z(&%Z($E-05`@<WIE<G9E<B!N96T@=.%M;V=A
M=&IA(&$@;6%P<.%K:&]Z('9A;/,@:&]Z>N%FZ7+I<R!M96=O<WITX7/A="X`
M17H@;F5M('3[;FEK('-Z86+A;'EO<R!R87(@X6QL;VWA;GEN86LN`$5Z(&YE
M;2!T^VYI:R!S>F%BX6QY;W,@>FEP(.%L;&]MX6YY;F%K+@!%>B!N96T@=/MN
M:6L@Z7)VZ6YY97,@:^%R='EA<WKA;6YA:RX`17H@82!M96=H86IT\R!L96AE
M=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J
M_&YK(&$@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!S>F]L
M9^%L=&%T\VX@X70N`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO
M9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A(%=)3B`H:'1T
M<#HO+W=I;G!L8RYC;VTI('-Z;VQGX6QT873S;B#A="X`17H@82!M96=H86IT
M\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT
M(&O\;&1J_&YK(&%Z('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M('-Z;VQGX6QT873S;B#A="X`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z
M:2P@:&]G>2!33510+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(%9O9&%F
M;VYE('-ZX6UO:W)A(&$@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP
M+FET*2!S>F]L9^%L=&%T\VX@X70N($$@<WIO;&?A;'1A=.%S(&EGZ6YY8F5V
MZ71E;.EH97H@5F]D869O;F4@271A;'D@96UA:6P@8^UM('-Z_&MSZ6=E<RX`
M17H@82!M97KU(&YE;2!M87)A9&AA="#\<F5S+@!%8F)E;B!A(&UE>O5B96X@
M8W-A:R!E9^ES>B!S>N%M;VL@X6QL:&%T;F%K+@!%8F)E;B!A(&UE>O5B96X@
M8W-A:R!E9^ES>B!S>N%M;VL@Z7,@:V5T=/5S<&]N="!L96AE="X`16)B96X@
M82!M97KU8F5N(&-S86L@;VMTX6QI<R!S>N%M;VL@X6QL:&%T;F%K+@!%>B!A
M(&UE>O4@8W-A:R!V97-S>O5V96P@=F%G>2!S>O-K]GIZ96P@96QVX6QA<WIT
M;W1T(&5GZ7-Z('-ZX6UO:V%T('1A<G1A;&UA>FAA=`!%>B!A>B#I<G3I:R!C
M<V%K('-ZX6T@;&5H970N`$5B8F5N(&$@;65Z]6)E;B!H97AA9&5C:6WA;&ES
M(%)'0B!S>NUN:_-D(.%L;&AA="P@<&PN("<C,3(S-&%F)RX`17IE;B!A9&%T
M;VMK86P@:V%P8W-O;&%T;W,@9F5L861A=&]K870@82!S>F5R=F5R(&WA<B!E
M;';I9V5Z=&4N`$5Z("5S`$5Z(&5G>2!+;VQA8B!'<F]U<'=A<F4@;V)J96MT
M=6TN($%Z(&EL>65N(&]B:F5K='5M(&UE9VIE;&5N[73I<^EH97H@;VQY86X@
M96UA:6P@:VQI96YS<')O9W)A;2!S>OQK<^EG97,L(&%M96QY(&OI<&5S(&$@
M2V]L86(@1W)O=7!W87)E(&9O<FWA='5M(&ME>F5LZ7/I<F4N($EL>65N(&5M
M86EL(&ML:65N<V5K(&QI<W3A:F$@;.%T:&%T\R!I='0Z("5S`$5Z="!A(&QE
M=F5L970@;>%S(&MA<F%K=&5R:^ES>FQE='1E;"`H)7,I(.UR=.%K+"!M:6YT
M(&%M:70@UFX@:&%S>F[A;"X`17H@82!S>N%M(&YE;2!L96AE="!E9WENZ6P@
M:VES96)B+@!%>B!A('-Z97)V97(@;F5M(&OI<&5S(&MI8F]N=&%N:2!A('II
M<"!I;&PN(&=Z:7`@X6QL;VWA;GEO:V%T+@!%>B!A(')E;F1S>F5R(&IE;&5N
M;&5G(&EN86MT:7;A;'9A('9A;BX`17H@87H@Z7)TZ6L@8W-A:R!S>N%M(&QE
M:&5T+@!%>G0@87H@86)L86L@8W-A:R!A>B!/<&-I\VL@86)L86MB\VP@:.UV
M:&%T\P!6:6QLX6ULX7,`2&EB86)E:F5L96YTZ7,M:V5Z96SI<P!)9/4`375N
M:V%I9/4M;GEI;';A;G1A<G3A<P!)9/4@9F]R;>%T=6T`263U(';A;&%S>G3A
M<P!+96QE="U4:6UO<@!4:71U;'5S`$/M;2`H=&]O;'1I<"D`0^UM>F5T=`!(
M82!T]F)B(&5L96UE="!I<R!K:2!A:V%R(&IE;/9L;FDL('1A<G1S82!L96YY
M;VUV82!A($-O;G1R;VP@*%!#*2!V86=Y(&$@0V]M;6%N9"`H36%C*2!B:6QL
M96YT>?MT(&$@:V%T=&EN=.%S(&OV>F)E;BX`0^UM>F5T=#H`36$`2%1-3"!F
M;W)RX7-NZ7IE="!K:2]B90!4;V=O`%1O:V5L874`2&]L;F%P`%1O;F=A`&;V
M;/QL`$QE9V9E;'/U(&9R86UE("A?=&]P*0!&;W)D[73A<V]K`%1R:6YI9&%D
M(.ES(%1O8F%G;P!)9V%Z('9A9WD@:&%M:7,`2V4`5'5NZ7II80!4]G+V:V]R
M<WKA9P!T]G+V:R`H25-/+3@X-3DM.2D`5/QR:VUE;FES>G3A;@!4=7)K<RT@
MZ7,@0V%I8V]S+7-Z:6=E=&5K`%1U=F%L=0#-<FIA(&)E+"!M:70@=N%L87-Z
M=&]T=#H@`%56(&EN9&5X.B``55),`%523"P@;65L>65N(&5G>2!P<F]G<F%M
M(&5L9F]G861J82!A('-Z;VQGX6QT873S(.%L=&%L(&O\;&3V='0@:_QL9/9T
M="!KZ7IB97/M=.ES:2!J96QE;G3I<W0`55),.@!59V%N9&$`56MR86IN80!.
M96T@<VEK97+\;'0@82!61E,@86QK]FYY=.%R8F$@8F5LZ7!N:2X`02!B96IE
M;&5N=&ME>NES:2!J;V=O<W5L='/A9R!I9^EN>6SI<V5K;W(@;F5M('-I:V5R
M_&QT(&%Z(&%D871O:R!E;'3A<F]LX7-A+@!.96T@<VEK97+\;'0@82AZ*2`B
M)7,B(%9&4R!FX6IL(&5LZ7+I<VD@:F]G;W-U;'1SX6=A:70@;65G=N%L=&]Z
M=&%T;FDN`$YE;2!S:6ME<OQL="!A*'HI("5S+R5S(%9&4R!FX6IL(&5LZ7+I
M<VD@:F]G;W-U;'1SX6=A:70@;65G=N%L=&]Z=&%T;FDN`$YE;2!S:6ME<OQL
M="!A*'HI("5S(&%L:_9N>79TX7)B82!B96SI<&YI+@!!*'HI("(E<R(@X6QL
M;VWA;GD@;>ER971E(&YE;2#A;&QA<.UT:&%T\R!M96<N`$$H>BD@(B5S+R5S
M(B#A;&QO;>%N>2!MZ7)E=&4@;F5M(.%L;&%P[71H873S(&UE9RX`07H@4U%,
M('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`07H@4U-,(&MA<&-S;VQA="!N96T@
MZ7#M=&AE=/4@9F5L+@!!(%9&4R!FX6IL(&YE;2!MX7-O;&AA=/,@X70N`$YE
M;2!S:6ME<OQL="!A*'HI("(E<R(@5D93(&%L:_9N>79TX7)T(&SI=')E:&]Z
M;FDN`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@5D93(&%L:_9N>79TX7)T
M+@!.96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(%9&4R!FX6IL="X`02AZ*2`B
M)7,B(%9&4R!M87!P82!N96T@:&]Z:&%T\R!LZ71R92X`3F5M('-I:V5R_&QT
M(&SI=')E:&]Z;FD@_')E<R!61E,@9N%J;'0N`$$@=/9M]G+M=&5T="#A;&QO
M;>%N>70@;F5M('-I:V5R_&QT(&MI8F]N=&%N:2X`(B5S(B!N96T@=/9R]FQH
M973U+"!A>B!A;&OV;GEV=.%R(&YE;2#\<F5S+@`B)7,B('3V<FSI<V4@;F5M
M('-I:V5R_&QT.B`E<RX`)7,@;F5M('3V<O9L:&5T]2P@87H@86QK]FYY=G3A
M<B!N96T@_')E<RX`02!61E,@86QK]FYY=G3A<B!N96T@=/9R]FQH973U(')E
M:W5R>NUV86XN`$$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2X`02!6
M1E,@86QK]FYY=G3A<B!N96T@=/9R]FQH973U.B`E<RX`02AZ*2`B)7,B(%9&
M4R!FX6IL(&YE;2!T]G+V;&AE=/4N`$$@5D93(&;A:FP@;F5M('3V<O9L:&5T
M]2X`02AZ*2`B)7,B(%9&4R!M87!P82!N96T@=/9R]FQH973U+@!.96T@=NEG
M97IH973S(')E:W5R>NUV('3V<FSI<R!A(%9&4RUB96XZ("5S+@!.96T@:&%T
MX7)O>FAA=/,@;65G(&$@:F5L96YL96<@Z7)VZ6YY97,@86QK]FYY=.%R+@!!
M('1A;OIS[71VX6YY('+I<WIL971E<R!A9&%T86D@;F5M(&AA=.%R;WIH873S
M:R!M96<`3F5M('-I:V5R_&QT(&)E;VQV87-N:2`E<R!D969I;NUC:?-JX70N
M`$$@5D93(&;A:FP@;F5M(&AE;'EE>FAE=/,@X70N`$$H>BD@(B5S(B!61E,@
M9N%J;"!N96T@;GEI=&AA=/,@;65G+@!!(%9&4R!FX6IL(&YE;2!N>6ET:&%T
M\R!M96<@[7+A<VD@8^EL;&%L+@!!(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M
M96<@+@!!('3V;?9R[71E='0@X6QL;VWA;GD@;F5M(&YY:71H873S(&UE9RX`
M02!61E,@9N%J;"!N96T@;VQV87-H873S("AA(&9I;&5S:7IE*"D@<VEK97)T
M96QE;B!V;VQT*2X`02!61E,@9N%J;"!N96T@;VQV87-H873S("AA(&=E=$9I
M;&53:7IE*"D@<VEK97)T96QE;B!V;VQT*2X`17H@82!FX6IL(&YE;2!O;'9A
M<VAA=/,Z(`!!('9F<W)O;W0@86QK]FYY=G3A<B!N96T@;VQV87-H873S+@`E
M<R!N96T@;F5V97IH973U(.%T("5S(&[I=G)E.B!MX7(@;.ET97II:R!I;'EE
M;B!N97;[(&UA<'!A`$$@5D93(&%L:_9N>79TX7(@;F5M(&YE=F5Z:&5T]2#A
M="X`02!61E,@86QK]FYY=G3A<B!N96T@;F5V97IH973U(.%T.B`E<RX`02AZ
M*2`B)7,B(%9&4R!FX6IL(&YE;2!N979E>FAE=/4@X70N`$$H>BD@)7,O)7,@
M5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`02!61E,@9N%J;"!N96T@;F5V
M97IH973U(.%T+@!!>B`G;6MI<V]F<R<@<')O9W)A;2!N96T@9G5T=&%T:&%T
M\RX`3F5M('-I:V5R_&QT(&QE9F]R9.UT86YI(&5Z="!A(%=O<F0@9&]K=6UE
M;G1U;6]T`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@[7)H873S+@!!(%9&4R!F
MX6IL(&YE;2#M<FAA=/,@*&$@8V]P>2@I('-I:V5R=&5L96X@=F]L="DN`$$@
M5D93(&;A:FP@861A=&%I(&YE;2#M<FAA=/-K(&MI+@!!(%9&4R!FX6IL(.UR
MX7-A(&MV\W1A=/IL;.EPZ7,@;6EA='0@;F5M(&9E:F5Z:&5T]2!B92X`86SA
M:/IZ;W1T`$WI9W-E(&UE;G1S_&L@96P`5FES<WIA=F]N:F$@87H@=71O;'/S
M(';A;'1O>G1A=.%S=`!!(&MA<&-S;VQA="!F96QVZ71E;.ET(&OV=F5T]65N
M(';A<F%T;&%N(';A;&%S>B#I<FME>F5T="!A('-Z97)V97)T]6PZ(`!6X7)A
M=&QA;B!VX6QA<WH@Z7)K97IE='0@82!S>F5R=F5R=/5L(&5R<F4Z(`!"97-O
M<F]L871L86X`56YI8V]D92`H551&+3@I`$5G>65S_&QT($%R86(@16WM<G/I
M9V5K`$5G>65S_&QT($MI<N%L>7/A9P!%9WEE<_QL="#!;&QA;6]K`$5G>65S
M_&QT(,%L;&%M;VLL(&MI<V5B8B!K_&QS]2!S>FEG971E:P!E9WESZ6<`27-M
M97)E=&QE;@!)<VUE<F5T;&5N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M`$ES;65R971L96X@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`02!M
M96=A9&]T="!H96QY(&ES;65R971L96XN`$ES;65R971L96X@9F5L:&%S>F[A
M;/-I(&[I=B!V86=Y(&IE;'-Z\RX`5.%V;VSM='-U:R!E;"!I;FYE;B!A(&QI
M;FME=`!.:6YC<R!E;&YE=F5Z=F4`0FEZ=&]N<^%G:2!O:V]K8O-L(&$@9F5L
M:&%S>F[A;/-I('!R;V=R86UO:R!N96T@:&%S>F[A;&AA=&KA:R!A($MI=N%G
MX7,O3>%S;VSA<R]"96EL;&5S>G3I<R!M\V1S>F5R="X@2V%T=&EN='-O;B!A
M>B!/2R!G;VUB<F$L(&AA(&$@;6]Z:6QL82YO<F<@=V5B;VQD86QO;B!E;"!K
M[7;A;FIA(&]L=F%S;FD@82!T96-H;FEK86D@;&7M<N%S="!M96QY(&UE9V%D
M:F$L(&AO9WEA;B!L96AE="!E>G0@;>EG:7,@96YG963I;'EE>FYI+@!!('-Z
M[6X@=FES<WIAX6QL[73A<V$`3F5M('3A;6]G871O='0@97AT96YZ:?,`3?-D
M;W/M=.%S`"5S(&%D871A:6YA:R!M\V1O<^UTX7-A`$$@9F5L:&%S>F[A;/,@
M861A=&%I;F%K(&WS9&]S[73A<V$`(B5S(B!VX6QT;WKA<V%I="!E;&UE;G1E
M='3\:RX`07H@=7!G<F%D92!P<F]G<F%M;W0@=/9R]FQT_&LN`$9E;'3V;'3I
M<P!!>B#V<W-Z97,@86QK86QM87KA<R!K;VYF:6=U<N%C:?-JX70@9F5L=/9L
M=/9T=/QK(&$@<WIE<G9E<G)E+@!L871I;B!N86=Y8F5T^VL`;F%G>6)E=/MS
M('+S;6%I('-ZX6UO:P!5<G5G=6%Y`$AA<WINX6QJ=6L@82!J96QE;FQE9VET
M.B`E<P!(87-Z;N%L:G5N:R!34TPM=`!!:VMO<B!H87-Z;N%L:G5K+"!H82!A
M>B!)35-0('-Z97)V97)E;B!MX7,@82!B96IE;&5N=&ME>NES:2!N97;\;FLO
M:F5L<WIA=G5N:RX`1F5L:&%S>F[A;/-I(&[I=@`E<R!F96QH87-Z;N%L\R!N
M96T@:F]G;W-U;'0@)7,M<F4N`$9E;&AA<WINX6SS:R!A9&UI;FES>G1RX6SA
M<V$`1F5L:&%S>F[A;/-I(&)EX6QL[73A<V]K`$)E:F5L96YT:V5ZZ7,@:F]G
M;W-U;'1SX6<@:6?I;GELZ7-E`$5Z96X@82!R96YD<WIE<F5N(&YI;F-S(&5N
M9V5DZ6QY97IV92!A>B#Z:B!F96QH87-Z;N%L\VL@8F5J96QE;G1K97KI<VD@
M:F]G;W-U;'1SX6?A;F%K(&EGZ6YY;.ES92X`07H@9F5L:&%S>F[A;/-I(&%Z
M;VYO<^UT\R!N96T@=&%LX6QH873S`$9E;&AA<WINX6SS:2!NZ78`02AZ*2`B
M)7,B(&9E;&AA<WINX6SS:2!NZ78@;>%R(&SI=&5Z:6LN`$9E;&AA<WINX6SS
M:2!NZ78Z`$9E;&AA<WINX6SS:2!NZ78Z(`!!(')E;F1S>F5R(&9E;&AA<WIN
MX6SS:3H`W'IB96=I<WITX6X`02!61E,@86QK]FYY=G3A<B!N96T@;.ET97II
M:RX`075T;VUA=&EK=7,@=N%L87-Z;&5VZ6P`07H@875T;VUA=&EK=7,@=N%L
M87-Z;&5VZ6P@<WIE<FME<WITZ7-E`$$@:F5L96YL96=I('-Z^W+U;65G:&%J
M=/-V86P@;F5M(&QE:&5T(&%U=&]M871I:W5S(';A;&%S>OQZ96YE=&5T(&O\
M;&1E;FDN`$$@:_9V971K97KU(&AE;'EE:V5T('1A;.%L='5K.B``R7)VZ6YY
M97-SZ6<`07H@Z7)TZ6ME:V5T('!E<F-B96X@861J=6L@;65G+"!M;W-T86YT
M\VP@<WKA;>UT=F$N`$$@Z7)TZ6L@;F%G>6]B8BP@;6EN="!A(&QE9VYA9WEO
M8F(@;65G96YG961E='0@:&]S<WKZ<^%G.B`E<RX`R7)TZ6ME:P!6X6QA<WIT
M:&%T\R#I<G3I:V5K`%9A;G5A='4`=N%L=&]Z\P!696YE>G5E;&$`02!H:71E
M;&5S[73I<R!N96T@<VEK97+\;'0@+2!L96AE="P@:&]G>2!A(&QE=F5L970@
M=F%L86MI(&UE9W;A;'1O>G1A='1A+@!697)Z:?,`5F5R>FGS:_9V973I<P!&
M_&=G+B!E;&AE;'EE>NES`$;\9V?U;&5G97,@8F5L<_4@;6%R9_,`9OQG9_5L
M96=E<SH`;F%G>6]N(&UA9V%S`%9I971N86T`=FEE=&YA;6D@*%9)4T-)22D`
M)7,@;65G=&5K:6YTZ7-E`$O\;'/U('=E8F]L9&%L(&UE9VIE;&5N[73I<V4`
M2F5L96[M='/\:R!M96<L(&UI;G0@)7,`0G)I="!6:7)G:6XM<WII9V5T96L`
M06UE<FEK86D@5FER9VEN+7-Z:6=E=&5K`$SA=/-TX79O;'/A9P!,X73S=.%V
M;VQSX6<Z(`!6;V1A9F]N92!)=&%L>2!S>F]L9^%L=&%TX7,@4TU44"UN(&ME
M<F5S>G3\;`!&24=914Q-15I4153)4P!&24=914Q-15I4153)4R$@2\E:6D5,
M(%3!5D],S51302!%3"!!(%-#4DE05$54("5S+5+53"X`5TE.('-Z;VQGX6QT
M873A<R!(5%10+6X@X70`5V%L;&ES(.ES($9U='5N80!&:6=Y96QM97IT973I
M<P!3>F4`263U:N%RX7,@96SU<F5J96QZZ7,`07H@:63U:N%RX7-I(&%D871O
M:R!F;W)RX7-A`%=E8@!796)H96QY96L`:&5T96YT90#<9';V>O9L:OQK`-QD
M=O9Z]FQJ_&LZ("5S`-QD=O9Z]FQJ_&LL("5S`&YY=6=A="UE=7+S<&%I("A)
M4T\M.#@U.2TQ*0!N>75G870M975R\W!A:2`H25-/+3@X-3DM,34I`$YY=6=A
M="U3>F%H87)A`%]%;F=E9.EL>65Z971T(&/M;65K`$UI;'EE;B!A;&MA;&UA
M>N%S="!M=71A<W-O;B`E<R!A(&)E:F5L96YT:V5ZZ7,@=73A;C\`36D@87H@
M96QVX6QA<WIT\R!K87)A:W1E<C\`36D@87H@:63I>F5T:V%R86MT97(_`%=H
M97)E:7,@075S>G1RX6QI82!TZ7)KZ7``365L>6EK(&-I:VQU<P!-96QY:6L@
M;6]D=6QO:V%T(&%K=&EVX6QJ=6L@82!2:6-H(%1E>'0@961I=&]R8F%N/P!%
M;F=E9.EL>65Z971T(&/M;65K`$5N9V5DZ6QY97IE='0@8^UM96L@<WIE<FME
M<WITZ7-E`$5G>65D:2!C[6UE:R!E;F=E9.EL>65ZZ7-E(&YE;2!TX6UO9V%T
M;W1T(&$@<WK[<O5M96=H86IT\V)A;@!%;F=E9.EL>65Z971T(&/M;65K`%-Z
MZ6QE<W/I9P!3>NEL97-SZ6<@0U-3(&5G>7/I9V)E;@!!("5S(&UE;OP@<WKI
M;&5S<^EG92!A(&)A;"!O;&1A;&]N("AA(&OV=F5T:V5Z]2!B96IE;&5N=&ME
M>NES="!K]G9E=/5E;B!L97-Z(.ER=NEN>65S*0!!('3A8FSA>F%T('-ZZ6QE
M<W/I9V4`02!S>NEL97-SZ6<@;>ER=.EK96=Y<^EG90!3>NEL97-SZ6<Z`%=I
M:VD`4WKI;`!3>NEL(&$@<F5G9V5L:2#S<N%K8F%N`%-ZZ6QS96)E<W/I9R!C
M<V]M\V)A;@!3>NEL.@!3>NEL.B``0O9L8W-E<W/I9P!+[7;A;G/A9VQI<W1A
M`$UU;FMA`$UU;FMA:&5L>6D@8^UM`$UU;FMA:&5L>6D@=&5L969O;@!!("5D
M+B!S;W)B86X@;F5M(&UE9V9E;&5L]2!A(&UE>O5K('-ZX6UA+B!6X7)T.B`E
M9"P@=&%LX6QT.B`E9"X`3F5M(&UE9V9E;&5L]2!A(&UE>O5K('-ZX6UA+B!6
MX7)T.B`E9"P@=&%LX6QT.B`E9"X`2&EBX7,@;V9F<V5T("@E9"D@82!61E,@
M9N%J;"!O;'9A<^%S86MO<BX`3&EN=7@@9F]R<N%S:_-D(&ME<F5S>G)E9F5R
M96YC:6$`6#4P.78S(&%L87!V973U(&MO<FSA=&]ZX7-O:P!8-3`Y=C,@:VET
M97)J97-Z=&5T="!K=6QC<VAA<WINX6QA=`!8-3`Y=C,@='5L86ID;VYO<R!A
M;'1E<FYA=.UV(&UE9VYE=F5ZZ7-E`%@U,#EV,R!T=6QA:F1O;F]S(&MU;&-S
M87IO;F]S[73S`%@U,#EV,R!K:71E<FIE<WITZ7-E:P!960!965E9`%EA:&]O
M(2!TZ7)KZ7``Z79E;G1E`$IE;65N`$EG96X`26=E;BP@8F5L96=Y97IE;2X`
M36]S="!(5$U,(%1%6%0@;?-D8F%N('9A;BX@2&%S>F[A;&IA(&$@6SP^72!G
M;VUB;W0L(&AA('9I<W-Z82!A:V%R(';A;'1A;FD@82!S>F]KX7-O<R!G<F%F
M:6MU<R`H5UE325=91RD@;65G:F5L96[M=.ES<F4N`$YE;2!H;WIH870@;.ET
M<F4@)60@8FQO:VMNX6P@=/9B8F5T+@!.96T@:&]Z:&%T(&SI=')E('3V8F(L
M(&UI;G0@)60@<WK[<O5S>F%BX6QY="X`3F5M(&AO>FAA="!LZ71R92!I;&PN
M(&YE;2!M\V1O<^UT:&%T('-A:N%T('-Z86+A;'EO:V%T+@!!>B#6;B!F96QH
M87-Z;N%L\V%Z;VYO<^UTX7-A(&YE;2!T]G)TZ6YT(&UE9RX`02!T96QJ97,@
M;NEV8F5N(&YE;2!S>F5R97!E;&AE="!A("=<)R!K87)A:W1E<BX`3F5M(&%D
M;W1T(&UE9R#I<G;I;GEE<R!E;6%I;"!C[6UE="X`3F5M(&%D=&$@;65G(&$@
M;65G9F5L96QT973I<W0@87H@:6UP;W)TX6QT(&;A:FP@Z7,@82AZ*2`E<R!M
M97KU:2!K]GKV='0N`%-I:V5R97-E;B!K:6IE;&5N=&ME>F5T="X`R7)K97IE
M='0@96=Y(/IJ(&QE=F5L90!%9WD@;6]B:6QT96QE9F]N<WKA;6]T(&ME;&P@
M;65G861N:6$L(&-S86L@82!S>N%M:F5G>65K970L(&5S971L96<@96=Y("<K
M)R!K87)A:W1E<G)E;"!K97ID=F4L(&AA(&YE;7IE=&OV>FD@=.%R8W/A>N%S
M:2!M\V1O="!K[7;A;B!H87-Z;N%L;FDN`$5L9F]G861H873S(.ER=.EK970@
M:V5L;"!M96=A9&YI82X`02!$871A5')E92!A;')E;F1S>F5R="!B92!K96QL
M(.%L;.UT86YI(&$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6=O:R!I9^EN
M>6SI<^EH97HN`$$@5D93(&%L<F5N9'-Z97(@;FEN8W,@8F7A;&SM='9A+@!%
M;/5B8B!L92!K96QL(.UR;FEA+"!H;V=Y(&UI;'EE;B!P<F]B;.EMX70@=&%P
M87-Z=&%L="P@;6EE;/5T="!E;&O\;&1I(&$@:&EB86IE;&5N=.ES="X`365G
M(&ME;&P@861N:2!E9WD@55),+70L(&%H;W9A(&5Z(&$@;&EN:R!M=71A=`!+
M:2!K96QL(';A;&%S>G1A;FD@96=Y('3V<FQE;F3U('-Z97)V97)T+@!-96<@
M:V5L;"!A9&YI82P@:&]G>2!M96QY:6L@9F5L:&%S>F[A;/,@861A=&%I="!K
M[7;A;FIA('3V<O9L;FDN`$UE9R!K96QL(&%D;FEA(&%Z(&5L=.%V;VSM=&%N
M9/,@9F5L:&%S>F[A;/-I(&YE=F5T+@!,96=A;.%B8B!E9WD@;VQY86X@8^UM
M970@;65G(&ME;&P@861N:6$L(&%M96QY<F4@82!V86OA8VGS(/QZ96YE=&5K
M970@96YG963I;'EE>GK\:RX`365G(&ME;&P@861N:6$@82!H;WIZX6%D86YD
M\R!F96QH87-Z;N%L\R!N97;I="X`365G(&ME;&P@861N:6$L(&AO9WD@;65L
M>6EK(&9E;&AA<WINX6SS(&%D871A:70@:^UVX6YJ82#A=.UR;FDN`$UE9R!K
M96QL(&%D;FEA(&5G>2!P87)A;F-S;W0N`$UE9R!K96QL(&%D;FEA(&%Z(/IJ
M(&MA=&5G\W)I82!N97;I="X`3VQA<WIO<G-ZX6=I('1E;&5F;VYS>N%M;W0@
M:V5L;"!M96=A9&YI80!!>B#6;B`E<R!K87!C<V]L871A(&ED]73Z;&SI<.ES
M(&UI871T(&UE9W-Z86MA9'0N($OI<F5M(&IE;&5N=&ME>GIE;B!B92#Z:G)A
M+@!!>B#6;B!E;6%I;"!C[6UE`$%Z(-9N(&9E;&%D\VD@*$9R;VTZ*2!C[6UE
M.@!3>F5MZ6QY97,@:6YF;W)MX6-I\P!!>B#6;B`E<R!K87!C<V]L873A;F%K
M(&ME>F1E=&4@\W1A(&UE9W;A;'1O>F]T="!A>B!I;G1E<FYE="!C[6UE+B!"
M:7IT;VYSX6?A;F%K(.ER9&5KZ6)E;B!I<VWI="!B92!K96QL(&IE;&5N=&ME
M>FYI92X`07H@UFX@;F5V90!!>B#6;B!F96QH87-Z;N%L\V%Z;VYO<^UT\R!A
M;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U=ND@87H@^FH@9F5L:&%S>F[A
M;/-K(&SI=')E:&]ZX7/A="X@2&$@82!(;W)D92!R96YD<WIE<G)E;"!K[7;A
M;FIA(&ME>F5L;FD@82!F96QH87-Z;N%L\VD@861A=&]K870L(&%K:V]R(&WA
M<VEK(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z97)R92!V86X@<WK\
M:W/I9V4N`$%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z97)E
M(&YE;2!T97-Z:2!L96AE=/5VZ2!A(&9E;&AA<WINX6SS:R!L:7-TX7KA<^%T
M+"!V86=Y('9A;&%M:2!O:V+S;"!L971I;'1O='3A:R!E>G0@82!L96AE=/5S
MZ6=E="X`07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;65G=N%L=&]Z;W1T(&%Z
M(-9N("5S(&UU;FMA:V%P8W-O;&%TX6YA:R!K97ID971E(/-T82X@0FEZ=&]N
M<^%G82#I<F1E:^EB96X@:7-MZ70@8F4@:V5L;"!J96QE;G1K97IN:64N`$%Z
M(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T:F$@97IT(&$@;&5H
M973U<^EG970N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T
M:F$@97IT(&$@;GEO;71A=.%S:2!O<&-I\W0N(%!R\V+A;&IO;B!A($-T<FPM
M4"`H=F%G>2!#;VUM86YD+5`I(&QE;GEO;>%SX79A;"!N>6]M=&%T;FDN`$$@
M:F5L96YL96<@Z7)VZ6YY97,@:63U>O-N83H`07H@UFX@86QA<.ER=&5L;65Z
MZ7,@<WIE<FEN=&D@87IO;F]S[73S:F$@;65G=N%L=&]Z;W1T+@!!>B#6;B!A
M;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/-J83H`07H@UFX@=&5L
M:F5S(&YE=F4Z`$QE:N%R="!A(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%G
M82X`07H@UFX@)7,M<F4@:&%S>F[A;'0@^FH@:F5L<WIA=F$Z("5S`$%Z(-9N
M(/IJ(&)EX6QL[73A<V%I="#I<G;I;GEE<^UT971T_&L@82!M;W-T86YI(&)E
M:F5L96YT:V5ZZ7,@:61E:NER92X`07H@UFX@^FH@8F7A;&SM=.%S86ET(&5L
M;65N=&5T=/QK+@!!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T='5K`$%Z(-9N
M(&IE;'-Z87;A="#A=.%L;.UT;W1T=6LL(&[I>GIE(&UE9R!A(&QE=F5L96ET
M+"!M86ID(&IE;&5N=&ME>GIE;B!B92!A>B#Z:B!J96QS>O-V86PN`$%Z(-9N
M(&IE;'-Z87;A;F%K(&QE:N%R="!A>B#I<G;I;GEE<W/I9VD@:61E:F4N`$%Z
M(-9N(.%L=&%L(&AA<WINX6QT('3A=F]L:2!S>F5R=F5R96LZ`$IU9V]S>FSA
M=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;3F4@;75T87-S=6L@82!B96ED
MZ7IE='0@<WKV=F5G971=`%M4X7)G>2!NZ6QK_&Q=`%M(:6)A:F5L96YTZ7-=
M`%M-=71A<W-U:R!A(&)E:63I>F5T="!S>O9V96=E="`M`%M-=71A<W-U:R!A
M(&)E:63I>F5T="!S>O9V96=E="`M("5S('-O<ET`6R5S+R5S('-O<ET`7T/M
M;2AE:RDL(&%M96QY96MR92!T;W;A8F+M=&IU:R!A>B#\>F5N971E=#H`02!K
M]G9E=&ME>O4@8^UM96MR92!?;F4@:_QL9&K\;FL@=N%L87-Z=#H`7T%D;6EN
M:7-Z='+A8VGS`%]4:6QT;W1T(&/M;65K`%]087)A;F-S<V]R`%-O<G3V<FSI
M<P!6Z6?I<G;I;GEE<V5N('3V7W+V;&K\:R!A(&QE=F5L970`S7)J82!B92!A
M(%]C[6UE:V5T+"!M:6YD96=Y:6ME="#Z:B!S;W)B82X`5%]O=N%B8NUTX7,`
M7T-S;W!O<G1O:P!395]G[71SZ6<`02!KZ7`@='5L86ID;VYSX6=A:2XN+@!4
M87)T<W5K(&UE9R!A>B#\>F5N970@96=Y(&WA<V]L873A="X`0F5J96QE;G1K
M97KI<P!?2VEJ96QE;G1K97KI<P!!(&QI;FL@;?-D;W/M=.%S82XN+@!496=Y
M_&L@X70@87H@_'IE;F5T970@82!K]G9E=&ME>O4@7VUA<'#A8F$Z`$%Z(.EN
M(&4M;6%I;"!?8^UM96EM.@!?3W!C:?-K`%]*;V=O<W5L='/A9V]K`$$@;&EN
M:R!T]G)LZ7-E+BXN`%-Z^W+U7W!R;V=R86T`7T)EX6QL[73A<V]K`%3A8FSA
M>F%T('1U;&%J9&]N<^%G;VL`7T9E;&AA<WINX6SS:P!?075T;VUA=&EK=7,@
M=N%L87-Z;&5VZ6P`7T5N9V5DZ6QY97IE='0@8^UM96L`86MT[78`8^UM:F5G
M>7KI:P!A(&/M;7IE='0@:7-M97)E=&QE;@#I<P!N87!TX7(`;GEU9V]D=`!A
M(&MI;65N971I(.%L;&]MX6YY(&YE;2!H;WIH873S(&SI=')E`&$@8F5M96[U
M(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<`:V%T=&EN='-O;B!I9&4`<&%R
M86YC<W-O<FD@:&EB80!K;VYF:6=U<N%C:?-S(&AI8F$`:&GA;GEZ:6L@96=Y
M(&9O;G1O<R!R96YD<WIE<N%L;&]MX6YY`&%D871F;W)MX71U;2!H:6)A`&QE
M=&EL='9A("T@87H@96YG963I;'EE>NES:&5Z(&MA='1I;G1S;VX@:61E`&WS
M9&]S[73A<P!A>B!A9&%T(&YE;2!T86SA;&AA=/,`8W/V:VME;@!M97KU`&;A
M:FP`)7,@*"5S*2!I<N%N>6+S;"P@)7,@)7,@<V5B97-SZ6=G96P`<WKI;&SV
M:^ES96L`;3H`82!GZ7`@;F5V92!N96T@:7-M97)T`&%Z;VYN86QI`&EN86MT
M[78`:6YP=70O;W5T<'5T(&AI8F$`8F5L<_4@<')O9W)A;6AI8F$`<V]R70!A
M(&UA:6QD<F]P('-Z:W)I<'1E="!A>B!);F=O(&ME<WII=&5T=&4`96=Y97KI
M<P!!>B!M:W-I;V9S('!R;V=R86T@)60@:&EB86OS9&1A;"!L9>%L;'0@87H@
M25-/(.%L;&]MX6YY(&OI<WKM=.ES92!K]GIB96XN`&[I=@!!('!R;V=R86UN
M86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!!('!R;V=R
M86UN86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!J96=Y
M>F5T=/9M8@!V86=Y`'-ZX7IA;.EK`&YI;F-S(&UE9V9E;&5L]2!J;V=O<W5L
M='/A9V$`<&EX96P`82!P<F]C;6%I;"!S>FMR:7!T970@87H@26YG;R!K97-Z
M:71E='1E`&%D873A='9I=&5L:2`H<')O=&]K;VQL*2!H:6)A`&5M96QK961I
M:P!A('-Z;VQGX6QT873A<R!N96T@X6QL(')E;F1E;&ME>NES<F4`;NEZ>OQK
M(&UE9R!A(&O\;/9N8G/I9V5K970`02!S:65V92!S>G5R;W0@87H@26YG;R!K
M97-Z:71E='1E`'-M<S)E;6%I;"!S>F]L9^%L=&%TX7,@2%144"UN(.%T`';A
M;'1O>F%T;&%N`')E;F1S>F5R:&EB80!F96QA9&%T;&ES=&$`X71M96YE=&D@
M:&EB80!M96=E<O5S[73I<VOI;G0@:^ET<WIE<B#M<FIA(&)E(&$@:F5L<WKS
M=`!NZ78@;NEL:_QL`&$@9F5L:&%S>F[A;/,@X6QT86P@=N%L87-Z=&AA=/,`
M=D-A<F0`<WHZ````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]I=%])5"\`````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S0W`#`Q-S8S,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O
M;&]C86QE+VET7TE4+TQ#7TU%4U-!1T53+P``````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#<`,#(Q-#$W`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O:71?250O3$-?34534T%'15,O:6YG
M;RYM;P`````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$S,#<V-@`Q,#0Q-S,V,C<T-P`P
M,C(W,C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````#M`@``'````(07``#Q`P``["X```````"P/@``!````+$^
M```$````MCX```,```"[/@``#````+\^```+````S#X``"@```#8/@``%0``
M``$_```+````%S\```H````C/P``#0```"X_```.````/#\```\```!+/P``
M&````%L_```.````=#\```X```"#/P``"````)(_```*````FS\```4```"F
M/P``"0```*P_```)````MC\``!````#`/P``"@```-$_```A````W#\```\`
M``#^/P```P````Y````/````$D````D````B0```#0```"Q````/````.D``
M``\```!*0```"````%I````(````8T```!D```!L0```$P```(9````,````
MFD````X```"G0````P```+9````%````ND````H```#`0```%P```,M````*
M````XT````\```#N0```#@```/Y````4````#4$``!<````B00``%P```#I!
M```3````4D$```\```!F00``!@```'9!```(````?4$``!0```"&00``"P``
M`)M!```5````IT$```T```"]00``!0```,M!```J````T4$``#L```#\00``
M.0```#A"```G````<D(``"P```":0@``*@```,="```E````\D(```8````8
M0P``,@```!]#```1````4D,```H```!D0P``"````&]#```#````>$,```L`
M``!\0P``"0```(A#```.````DD,``#L```"A0P``$P```-U#```5````\4,`
M``X````'1```"@```!9$```$````(40```0````F1```"0```"M$```&````
M-40```<````\1```!@```$1$```#````2T0``!,```!/1```"````&-$```$
M````;$0```8```!Q1```%0```'A$```'````CD0```X```"61```%0```*5$
M```"````NT0```\```"^1```#0```,Y$```/````W$0```T```#L1```!@``
M`/I$```&`````44``%0````(10``#@```%U%```$````;$4```X```!Q10``
M'````(!%```2````G44```H```"P10``#P```+M%```1````RT4```P```#=
M10``!@```.I%```&````\44``!$```#X10``!0````I&```,````$$8```4`
M```=1@``!@```"-&```'````*D8```T````R1@``"@```$!&```,````2T8`
M`!````!81@``"````&E&```(````<D8```0```![1@``!P```(!&```*````
MB$8```X```"31@``'P```*)&```@````PD8``"4```#C1@``!P````E'```&
M````$4<```T````81P``$````"9'```1````-T<``!,```!)1P``#````%U'
M```.````:D<```\```!Y1P``$P```(E'```-````G4<``"@```"K1P```P``
M`-1'```-````V$<```(```#F1P``"@```.E'```0````]$<```T````%2```
M`P```!-(```.````%T@``!$````F2```"````#A(```/````04@```T```!1
M2```!@```%](```)````9D@``!````!P2```#````(%(```+````CD@```T`
M``":2```(@```*A(```9````RT@```H```#E2```&````/!(```9````"4D`
M`!8````C20``!P```#I)```5````0DD``"$```!820``)0```'I)```1````
MH$D``!0```"R20``"P```,=)```+````TTD```D```#?20``"0```.E)```*
M````\TD```@```#^20``%@````=*```/````'DH``#H````N2@``+P```&E*
M```-````F4H``"8```"G2@``"````,Y*``!#````UTH``!(````;2P``#P``
M`"Y+```0````/DL```T```!/2P``(0```%U+```O````?TL```0```"O2P``
M!P```+1+```*````O$L```H```#'2P``$````-)+```7````XTL``!$```#[
M2P``%P````U,```-````)4P```D````S3```!P```#U,```)````14P```@`
M``!/3```!0```%A,```0````7DP```\```!O3```$````'],```/````D$P`
M``\```"@3```#````+!,```/````O4P```<```#-3```#@```-5,```&````
MY$P```@```#K3```$P```/1,```$````"$T```@````-30``"@```!9-```,
M````(4T```L````N30``#````#I-```3````1TT``!D```!;30``&P```'5-
M```.````D4T```L```"@30``#````*Q-```5````N4T```T```#/30``0P``
M`-U-```Q````(4X``$(```!33@``1P```)9.``!/````WDX``#T````N3P``
M3@```&Q/```1````NT\```<```#-3P``"@```-5/```-````X$\```4```#N
M3P``"@```/1/```E````_T\``"8````E4```%0```$Q0```%````8E````<`
M``!H4```#````'!0```(````?5````8```"&4```!P```(U0```Y````E5``
M``@```#/4```#0```-A0```"````YE````8```#I4```!````/!0```)````
M]5```!````#_4```"0```!!1```)````&E$``!D````D40``#@```#Y1```"
M````35$```T```!040``#````%Y1```8````:U$``!0```"$40``!@```)E1
M```1````H%$```8```"R40``!````+E1```*````OE$```0```#)40``!0``
M`,Y1```%````U%$``!(```#:40``"P```.U1```I````^5$``"0````C4@``
M)@```$A2```(````;U(``!(```!X4@``"@```(M2```/````EE(``!````"F
M4@``#@```+=2```)````QE(```H```#04@``!@```-M2```/````XE(```D`
M``#R4@``$@```/Q2```0````#U,``!$````@4P``$````#)3``!#````0U,`
M`#(```"'4P``"P```+I3```4````QE,```P```#;4P``#````.A3```/````
M]5,``!4````%5```*0```!M4```J````150``"8```!P5```)P```)=4```9
M````OU0``!$```#95```$@```.M4```3````_E0``!0````250``%@```"=5
M```7````/E4``!````!650``$0```&=5```3````>54``!0```"-50``&@``
M`*)5```)````O54```(```#'50``!0```,I5```&````T%4```<```#750``
M%@```-]5```$````]E4```0```#[50``!P````!6```'````"%8```@````0
M5@``#````!E6```-````)E8```X````T5@``%@```$-6```1````6E8```8`
M``!L5@``!````'-6```)````>%8``!4```""5@``"@```)A6```0````HU8`
M``<```"T5@``&@```+Q6```*````UU8```P```#B5@``#P```.]6```(````
M_U8```8````(5P``!P````]7```+````%U<```,````C5P``$P```"=7```"
M````.U<```0````^5P``"@```$-7``!H````3E<``!@```"W5P``!0```-!7
M```&````UE<``!````#=5P``#P```.Y7```#````_E<```<````"6```"P``
M``I8```-````%E@``!H````D6```2@```#]8```&````BE@```8```"16```
M)@```)A8```9````OU@``!L```#96````@```/58```+````^%@```@````$
M60``"@````U9```,````&%D```0````E60``#@```"I9```,````.5D```H`
M``!&60``"0```%%9```0````6UD``!(```!L60``*0```']9```'````J5D`
M``4```"Q60``#````+=9```(````Q%D``!<```#-60``!````.59```*````
MZED```0```#U60``!0```/I9```C`````%H``"8````D6@``+````$M:```4
M````>%H``!,```"-6@``"````*%:```4````JEH```@```"_6@``%````,A:
M```K````W5H``$4````)6P``00```$];```$````D5L```P```"66P``!P``
M`*-;```%````JUL```@```"Q6P``$0```+I;```.````S%L```(```#;6P``
M#@```-Y;```'````[5L```8```#U6P``%````/Q;```?````$5P```<````Q
M7```'@```#E<```.````6%P```H```!G7```'0```')<```%````D%P``!$`
M``"67```#0```*A<```1````MEP```@```#(7```#0```-%<```(````WUP`
M``D```#H7```"@```/)<```5````_5P```4````370``!````!E=```0````
M'ET```<````O70``'@```#==```H````5ET```H```!_70``&@```(I=```4
M````I5T```8```"Z70``!@```,%=```T````R%T``#0```#]70``*0```#)>
M```H````7%X``"D```"%7@``!0```*]>```9````M5X``!D```#/7@``"```
M`.E>```7````\EX```H````*7P``!P```!5?```A````'5\```X````_7P``
M!P```$Y?```3````5E\```@```!J7P``!0```'-?```'````>5\```0```"!
M7P``"@```(9?```)````D5\```X```";7P``!````*I?```R````KU\``$4`
M``#B7P``"````"A@```+````,6```!0````]8```$@```%)@```2````96``
M``<```!X8```#@```(!@```J````CV````8```"Z8```#````,%@```1````
MSF````L```#@8```"@```.Q@```+````]V````\````#80``"0```!-A```+
M````'6$```4````I80``#@```"]A```3````/F$```<```!280``%@```%IA
M```1````<6$``!0```"#80``%````)AA```8````K6$```<```#&80``!0``
M`,YA```2````U&$```X```#G80``#@```/9A```%````!6(```0````+8@``
M"P```!!B```,````'&(```T````I8@``#````#=B```)````1&(```4```!.
M8@```P```%1B```-````6&(```(```!F8@``!````&EB```'````;F(```P`
M``!V8@``#0```(-B``!2````D6(``!<```#D8@``#P```/QB```3````#&,`
M`!X````@8P``(````#]C```&````8&,```X```!G8P``!````'9C```.````
M>V,``!4```"*8P``$@```*!C```/````LV,``!0```##8P``%````-AC``!I
M````[6,``!H```!79```%P```')D```:````BF0``!<```"E9```&P```+UD
M```9````V60``!\```#S9```$P```!-E```&````)V4```@````N90``"0``
M`#=E```_````064``#<```"!90``5P```+EE```>````$68``!\````P9@``
M"````%!F```-````668``"T```!G9@``!````)5F```2````FF8``!,```"M
M9@``)0```,%F```?````YV8``!T````'9P``)0```"5G```@````2V<``"0`
M``!L9P``!P```)%G```-````F6<```P```"G9P``!````+1G```0````N6<`
M``P```#*9P``!P```-=G```$````WV<``!<```#D9P``"@```/QG```,````
M!V@```D````4:```"````!YH```&````)V@``",````N:````@```%)H```=
M````56@```<```!S:```"0```'MH```'````A6@``"@```"-:```%0```+9H
M```'````S&@```@```#4:```!P```-UH```'````Y6@```X```#M:```"0``
M`/QH```&````!FD```@````-:0``"P```!9I```'````(FD```<````J:0``
M"````#)I```0````.VD``!````!,:0``!P```%UI```%````96D``!0```!K
M:0``"P```(!I```-````C&D``!<```"::0``"0```+)I```*````O&D```<`
M``#':0```@```,]I```?````TFD``!$```#R:0``(P````1J```A````*&H`
M`!\```!*:@``*P```&IJ```G````EFH``"D```"^:@``*P```.AJ```+````
M%&L```<````@:P``!P```"AK```-````,&L```L````^:P``!0```$IK```"
M````4&L```4```!3:P``"````%EK```#````8FL```(```!F:P```P```&EK
M```$````;6L``"0```!R:P``"0```)=K```,````H6L```<```"N:P``!0``
M`+9K```:````O&L```L```#7:P``!@```.-K```)````ZFL```L```#T:P``
M%P````!L```&````&&P``!,````?;```$P```#-L```1````1VP``#(```!9
M;```"````(QL```)````E6P```H```"?;```%````*IL```(````OVP```T`
M``#(;```$````-9L```Z````YVP```@````B;0``#P```"MM```.````.VT`
M`!````!*;0``"0```%MM```)````96T``!D```!O;0``"@```(EM```,````
ME&T```(```"A;0``$````*1M```#````M6T```<```"Y;0``#0```,%M```+
M````SVT``!4```#;;0``+P```/%M```@````(6X``!P```!";@``"0```%]N
M```.````:6X``#L```!X;@``%0```+1N```%````RFX``!(```#0;@``"@``
M`.-N```&````[FX```4```#U;@``!@```/MN```"`````F\```P````%;P``
M&0```!)O```H````+&\``"D```!5;P``)@```']O``!@````IF\``"4````'
M<```*````"UP```2````5G```!,```!I<```$````'UP```)````CG```',`
M``"8<```*P````QQ```7````.'$``!8```!0<0``#P```&=Q```4````=W$`
M``P```",<0``$````)EQ```3````JG$``!L```"^<0``)````-IQ```/````
M_W$```H````/<@``"0```!IR```+````)'(``!H````P<@``(@```$MR```(
M````;G(```<```!W<@``!0```']R```4````A7(``"D```":<@``"````,1R
M```/````S7(``!@```#=<@``%````/9R```(````"W,```P````4<P``#P``
M`"%S```'````,7,``!0````Y<P``!@```$YS```)````57,```H```!?<P``
M`P```&IS```$````;G,```4```!S<P``&0```'ES```&````DW,```4```":
M<P``!````*!S```"````I7,```<```"H<P``!@```+!S```A````MW,```8`
M``#9<P``'@```.!S```&````_W,``"(````&=```"P```"ET``!N`0``-70`
M``(```"D=0``!@```*=U```"````KG4```H```"Q=0``#P```+QU```H````
MS'4``!````#U=0``"@````9V```)````$78```\````;=@``#0```"MV```)
M````.78``!8```!#=@``#@```%IV```.````:78```8```!X=@``"0```']V
M```%````B78```4```"/=@``!@```)5V```0````G'8```P```"M=@``)@``
M`+IV```-````X78```@```#O=@``%0```/AV```-````#G<``!4````<=P``
M&0```#)W```8````3'<```T```!E=P``#P```'-W```L````@W<``!8```"P
M=P``!P```,=W```/````SW<```H```#?=P``#````.IW```-````]W<``!P`
M```%>```#@```")X```0````,7@``!0```!">```$0```%=X```7````:7@`
M`!L```"!>```%P```)UX```2````M7@```@```#(>```"````-%X```<````
MVG@```P```#W>```%P````1Y```0````''D```8````M>0``+````#1Y``!`
M````87D``#P```"B>0``-````-]Y```U````%'H``#````!*>@``,````'MZ
M```&````K'H``#<```"S>@``$@```.MZ```&````_GH```@````%>P```P``
M``Y[```*````$GL```H````=>P``%@```"A[```\````/WL``!H```!\>P``
M&P```)=[```3````LWL```X```#'>P``!0```-9[```)````W'L```D```#F
M>P``!P```/![```'````^'L```4`````?````P````9\```9````"GP```H`
M```D?```!0```"]\```(````-7P``!P````^?```!P```%M\```<````8WP`
M`!4```"`?````@```)9\```5````F7P```\```"O?```%0```+]\```-````
MU7P```8```#C?```"````.I\``!T````\WP``!(```!H?0``!````'M]```1
M````@'T``"0```"2?0``$@```+=]```.````RGT``",```#9?0``%0```/U]
M```2````$WX```8````F?@``!@```"U^```2````-'X```8```!'?@``$```
M`$Y^```(````7WX```@```!H?@``!P```'%^```0````>7X```H```"*?@``
M#````)5^```1````HGX```@```"T?@``"````+U^```%````QGX```L```#,
M?@``"P```-A^```2````Y'X``"@```#W?@``*0```"!_```\````2G\```4`
M``"'?P``!````(U_```4````DG\``!````"G?P``$P```+A_```4````S'\`
M``L```#A?P``$````.U_```-````_G\``!0````,@```#0```"&````U````
M+X````8```!E@```$````&R````"````?8````T```"`@```$````(Z````-
M````GX````8```"M@```$````+2````0````Q8````@```#6@```#P```-^`
M```1````[X````@````!@0``"P````J!```5````%H$```T````L@0``#0``
M`#J!```/````2($``!<```!8@0``'P```'"!```+````D($``!X```"<@0``
M&P```+N!```8````UX$```D```#P@0``&````/J!```E````$X(``"4````Y
M@@``%0```%^"```4````=8(```L```"*@@``"````):"```0````GX(```@`
M``"P@@``#````+F"```+````QH(``!X```#2@@``%P```/&"```^````"8,`
M`#(```!(@P``#0```'N#```K````B8,```L```"U@P``3@```,&#```.````
M$(0```P````?A```#P```"R$```*````/(0```\```!'A```,P```%>$```(
M````BX0```L```"4A```#P```*"$```/````L(0``!$```#`A```&````-*$
M```5````ZX0``!@````!A0``$@```!J%```)````+84```@````WA0``"P``
M`$"%```(````3(4```8```!5A0``#@```%R%```-````:X4```\```!YA0``
M#0```(F%```-````EX4```L```"EA0``$@```+&%```*````Q(4``!````#/
MA0``!@```."%```)````YX4``"D```#QA0``!@```!N&```(````(H8```T`
M```KA@``#P```#F&```0````288```P```!:A@``%P```&>&```:````?X8`
M`!X```":A@``#@```+F&```1````R(8``!$```#:A@``(````.R&```2````
M#8<``$$````@AP``.0```&*'``!!````G(<``%L```#>AP``5````#J(``!!
M````CX@``%0```#1B```$P```":)```&````.HD```L```!!B0``#P```$V)
M```%````78D```L```!CB0``+````&^)```J````G(D``"````#'B0``!@``
M`.B)```(````[XD```P```#XB0``"`````6*```%````#HH```<````4B@``
M&@```!R*```'````-XH``!`````_B@```P```%"*```&````5(H```(```!;
MB@``!````%Z*```4````8XH```H```!XB@``#0```(.*```9````D8H```\`
M``"KB@``!0```+N*```.````P8H```X```#0B@``$@```-^*```6````\HH`
M``8````)BP``#P```!"+```'````((L```4````HBP``"````"Z+```$````
M-XL```8````\BP``!0```$.+```7````28L```P```!ABP``&@```&Z+```?
M````B8L``!@```"IBP``!P```,*+```8````RHL```H```#CBP``#P```.Z+
M```3````_HL``!(````2C```#````"6,```,````,HP```@````_C```$0``
M`$B,```*````6HP``!,```!EC```$````'F,```8````BHP``!(```"CC```
M)@```+:,```^````W8P```P````<C0``&P```"F-```5````18T``!$```!;
MC0``&@```&V-```8````B(T``#````"AC0``-````-*-```M````!XX``#$`
M```UC@``(0```&>.```4````B8X``!4```">C@``%0```+2.```7````RHX`
M`!@```#BC@``&0```/N.```3````%8\``!0````ICP``&P```#Z/```6````
M6H\``!````!QCP``"@```(*/```"````C8\```4```"0CP``!P```):/```'
M````GH\``!@```"FCP``!@```+^/```&````QH\```P```#-CP``"````-J/
M```&````XX\```T```#JCP``%0```/B/```2````#I```!@````AD```$P``
M`#J0```'````3I````@```!6D```!P```%^0```2````9Y````\```!ZD```
M'0```(J0```(````J)```"H```"QD```"@```-R0```,````YY````P```#T
MD```!0````&1```%````!Y$```0````-D0``&@```!*1```%````+9$``!<`
M```SD0```@```$N1```%````3I$``!@```!4D0``5@```&V1```F````Q)$`
M``4```#KD0``!P```/&1```;````^9$``!0````5D@``!@```"J2```&````
M,9(```P````XD@``#0```$62```6````4Y(``"4```!JD@``!P```)"2```&
M````F)(``#(```"?D@``%0```-*2```5````Z)(```,```#^D@``"P````*3
M```(````#I,```P````7DP``%0```"23```&````.I,``!0```!!DP``$P``
M`%:3```+````:I,```L```!VDP``%P```(*3```7````FI,``#@```"RDP``
M!````.N3```#````\),```\```#TDP``#`````24```=````$90```<````O
ME```$0```#>4```(````290```4```!2E```*0```%B4```I````@I0``"@`
M``"LE```(````-64```@````]I0```X````7E0``%P```":5```+````/I4`
M`!L```!*E0``-@```&:5``!4````G94``$X```#RE0``!P```$&6```,````
M298```T```!6E@``!````&26```(````:98``!$```!RE@``#P```(26```"
M````E)8```P```"7E@``!P```*26```'````K)8``!8```"TE@``*@```,N6
M```'````]I8``"X```#^E@``#@```"V7```)````/)<``!0```!&EP``!0``
M`%N7```2````89<```T```!TEP``&0```(*7```*````G)<``!(```"GEP``
M"````+J7```)````PY<```H```#-EP``(0```-B7```'````^I<```@````"
MF```&`````N8```+````))@``"0````PF```+@```%68```(````A)@``!P`
M``"-F```%@```*J8```$````P9@```4```#&F```)P```,R8```C````])@`
M`"D````8F0``)P```$*9```N````:ID```@```"9F0``(@```**9```@````
MQ9D```D```#FF0``'@```/"9```+````#YH```D````;F@``*0```"6:```1
M````3YH```@```!AF@``&````&J:```(````@YH```<```",F@``"````)2:
M```'````G9H```X```"EF@``#0```+2:```/````PIH```4```#2F@``0P``
M`-B:``!.````')L```@```!KFP``"@```'2;```D````?YL``!0```"DFP``
M%0```+F;```$````SYL```T```#4FP``*@```.*;```'````#9P```X````5
MG```%0```"2<```,````.IP```H```!'G```#@```%*<```2````89P```P`
M``!TG```#0```(&<```'````CYP``!````"7G```%P```*B<```)````P)P`
M`!8```#*G```$P```.&<```6````]9P``!D````,G0``&````":=```'````
M/YT```8```!'G0``&````$Z=```4````9YT``!0```!\G0``!@```)&=```&
M````F)T```X```"?G0``$````*Z=```2````OYT```\```#2G0``"P```.*=
M```&````[IT```8```#UG0``#````/R=```#````"9X```4````-G@``"```
M`!.>```-````')X``!(````JG@``6@```#V>```=````F)X``!0```"VG@``
M%@```,N>```=````XIX``"``````GP``!P```"&?```1````*9\```4````[
MGP``$@```$&?```@````5)\``!\```!UGP``$P```)6?```A````J9\``"4`
M``#+GP``<P```/&?```B````9:```!\```"(H```(P```*B@```;````S*``
M`",```#HH```'P````RA```C````+*$``!P```!0H0``"````&VA```)````
M=J$```D```"`H0``/P```(JA```O````RJ$``%X```#ZH0``)0```%FB```M
M````?Z(```@```"MH@``#P```+:B```M````QJ(```8```#TH@``%````/NB
M```5````$*,``"(````FHP``+P```$FC```A````>:,``"$```";HP``&P``
M`+VC```@````V:,```H```#ZHP``$@````6D```0````&*0```H````II```
M$@```#2D```5````1Z0```H```!=I```!````&BD```2````;:0```P```"`
MI```#@```(VD```+````G*0```@```"HI```!0```+&D```M````MZ0```,`
M``#EI```(0```.FD```'````"Z4```L````3I0``"````!^E```:````**4`
M`!<```!#I0``"0```%NE```$````9:4```@```!JI0``!````'.E```-````
M>*4```8```"&I0``"````(VE```*````EJ4```L```"AI0``"````*VE```*
M````MJ4```H```#!I0``$0```,RE```1````WJ4```T```#PI0``"````/ZE
M```8````!Z8```L````@I@``#0```"RF```8````.J8```H```!3I@``$@``
M`%ZF```-````<:8```,```!_I@``(````(.F```7````I*8``",```"\I@``
M(@```."F```@`````Z<``#<````DIP``*````%RG```B````A:<``"4```"H
MIP``#0```,ZG```%````W*<```8```#BIP``$@```.FG```+````_*<```8`
M```(J````0````^H```$````$:@```8````6J```!````!VH```#````(J@`
M``,````FJ```!````"JH```J````+Z@```H```!:J```%````&6H```*````
M>J@```4```"%J```&0```(NH```.````I:@```@```"TJ```"P```+VH```/
M````R:@``"(```#9J```"````/RH```1````!:D``!8````7J0``%````"ZI
M```X````0ZD```L```!\J0``#````(BI```,````E:D``!,```"BJ0``!P``
M`+:I```0````OJD``!$```#/J0``.@```.&I```)````'*H``!(````FJ@``
M#````#FJ```5````1JH```H```!<J@``"@```&>J```A````<JH```H```"4
MJ@``#````)^J```#````K*H``!````"PJ@```P```,&J```)````Q:H```X`
M``#/J@``#0```-ZJ```>````[*H``#`````+JP``'@```#RK```@````6ZL`
M``P```!\JP``&````(FK```:````HJL``!T```"]JP``"0```-NK```6````
MY:L```\```#\JP``"@````RL```&````%ZP```<````>K````@```":L```2
M````*:P``!X````\K```*````%NL```J````A*P``"H```"OK```6````-JL
M```K````,ZT``"L```!?K0``$P```(NM```3````GZT``!,```"SK0``"P``
M`,>M``"'````TZT``"D```!;K@``&P```(6N```3````H:X```P```"UK@``
M%0```,*N```0````V*X``"<```#IK@``%P```!&O```@````*:\``",```!*
MKP``$````&ZO```+````?Z\```D```"+KP``#0```)6O```@````HZ\``"P`
M``#$KP``"````/&O```'````^J\```8````"L```&P````FP```S````);``
M``X```!9L```$@```&BP```?````>[```!D```";L```"````+6P```)````
MOK```!````#(L```!P```-FP```8````X;````<```#ZL```"`````*Q```-
M````"[$```$````9L0``!0```!NQ```%````(;$``!@````GL0``!@```$"Q
M```+````1[$```0```!3L0```0```%BQ```(````6K$```8```!CL0``(```
M`&JQ```+````B[$``!T```"7L0``"````+6Q```K````OK$```L```#JL0``
M`0`````````,````L@$```````!L`@``W`$``!L!````````!0```&D"``"C
M````@0(`````````````G@```)H"``#0`0```````%H!``")`0```````&8`
M``!R`@``L`$````````9`0``KP(````````,`0`````````````L`@``[0$`
M``````!U````Y````!4"```U`0``/P```*`!``!=`0``F0$``'P```!#`@``
M`````.T```````````(```@!``"``@`````````````A`@``00$```````"J
M`````````'````"\`````````-T"``!``0``XP(``+$"````````PP(``%X`
M``!1`@````````````!^````C`$````````J`0```````,\!````````F`(`
M`!(```"[`````````'`"``#=````C````/,!``#Q````,`(``!T```"V`@``
MG`(```@```!Z`@``_P$````````O`@``!@$```<"````````>0```!@"``"G
M`@```````,,```#J`@``MP(``,4!``!^`0``3P$```````#4`@``````````
M`````````````-<```"X`@``Q0(``,\"``!X````8@(```````#V````/`$`
M`,,!``````````````````".`@``"P(````````[`0``ZP$``!8```!\`@``
M'@(``,8!``#H`0````````````"^`0``X0(``````````````````)<"``"K
M`0``D0````````!5`@``OP(``/L!```0`0```````*8!````````B0(`````
M``#T`0``[P```/<!``!.`0``70```"`````C`0``NP$``+<!``!?`@``3```
M```````T`@``/````*4!``!>`@```````)0"``"6`@``\0$``!H```"@````
MG@(````````N`@`````````````5`````````(H!``````````````````"T
M````F@```"8```!1````4`(``&P!```Q`@``2`(``(4!``"Z`@``.````"T"
M```I````=0$``+4```#0`@``!@```%$!``"T`0```````'(!``#7`0``'P(`
M``,!``#@````5@```#T`````````P````$X"``"/`@```````#H`````````
M`@$``%4```#.`````````!$"``"J`@``4`$```X!``#J`0```````'@!```F
M`@``)`(```L!````````I`$``%H```#8`@``K`$```D"``#F````S@$``"4"
M``"6````=`(``#,````5`0```````-4```"'`@``[`(```````#!````^@$`
M`*,!``")`````````!("``#5`0``4@(``#8```!<`@``BP$``'\!````````
M`````-8```!)`0``DP$``*8`````````$`(```````"$`@````````````"Z
M`0``Q0```/X```"-`0``V@(```````"'````````````````````1@(``+<`
M``"&````$@$``"H````^`0``3`$``)P!````````90$`````````````8P``
M`$("``!4````W@`````````+````%@$```````!U`@``Y@(``$T!````````
MB`(```````#[````00(``.`!````````WP(``+@!``!(````]0$``!D"````
M````7````&8"```T````E`$``!0!````````1`(``.$```#3````\P``````
M``"0`@```````-4"``":`0``60```.D!``!6`@``&P(``.\!``#!`0``````
M``````"?`0``V0(```````!W`@``VP$``-8"``"^````>P(``%L!``!T````
M`@``````````````9````&X"``"C`@``D@$``&,!```E````<@```#,"``"-
M````9P$``(8!```Q`0```````!$```#\`0````````````#E````QP$``,L"
M``#;`@``S0$``.@```"#````K@(```,```"L`@```````"(!``!9`0``````
M`&$``````````````````````````````````````````````!8"``!B`0``
M``$```````!L`````````/(``````````````%0"``![````\````.0"```%
M`@``10````````!#````T0(```4!``"9`````````+D!``#2`````````$H"
M```9````*P```.L"````````30(``",```"5`@``;@$``"\```!7`````@(`
M`&,"``!>`0``D0(`````````````O0(``#$```"*`````````/@!``#!`@``
M``````````#]`0``-P(```````"S`0``:``````````?`0``*@(``,\`````
M```````````````8`````````+T!````````C0(``-<"``#?`0``.0$``,L!
M``!&`````````!X```"X````]0```!0```!"`0```````*`"```W`0``!`(`
M`)L"``"P`@``F0(``!0"```````````````````@`0``>P$```D```!M`0``
MAP$``,8"``"``0``*0(``#X`````````'0$``(X```"7`0``W@$``&L"``#8
M`0```````.P```"E`@```````+L"```M````E````/(!````````Z0```*<!
M``#@`@``.`(``#`!````````O0````````"N`0````````````#6`0``I0``
M`%,```#&````6`$``,H"````````'`$```````#B`@``5P$``+8!```$`0``
ME@$``'\"``"<`````````#("``#$````-P```)4!``#2`@```````,<"``!%
M`0``80$``,D!``#1`0``:@```-L```"U`0```````!@!````````Z`(``/`!
M``!_````W0$``+P"``!`````2P````````"O`0``5`$``/@````Y````*`$`
M`&D`````````K0(`````````````H0(``&`!```P````@@$``$<!``"_````
M````````````````YP$```````#``@``9P(``*X```!``@``<0$```````"=
M`@``B@(`````````````.`$``'8!``!<`0``6````#4```#?````H0```"4!
M``"D````W````-,"``#4`0``9P```,("```,`@``^0$``#D"````````_```
M``````"O````G0```#L"``"1`0``'@$`````````````<0``````````````
M`````&H!``#3`0```````"L!``!S````Q`(`````````````S0``````````
M````0P$```\```!!`````````"`"``#_````80(``'8"````````FP$```H!
M``#I`@``)P```#\!``!P`0``QP```(@`````````;0```&@!````````H@$`
M`&L`````````)````,@```"8`0``YP(```````!Y`0``*`(`````````````
M`````(X!````````[0(`````````````T`````````!;`@``[@```-0`````
M````;@```$\"````````=@``````````````;P````````!,`@```````#\"
M```3````-@$``,(```#``0```````"T!``!D`@``V0$``#P"```]`0``EP``
M`*@"`````````````","``!K`0``&P````````#V`0``20````````#K````
M%P$````````N`0``@````+\!````````"`(`````````````8@```)(`````
M````X@````````!'`@``L@`````````3`0``;0(``)T!````````=P$`````
M``"+`@``A0(``'H```"&`@``@P$````````:`@``@0$``&4```#*````````
M``````!6`0``"0$``*<``````````````*L"```G`@```````*T````!`0``
M6P````````#(`0``6@(```````#1````6`(```````"Y````+`$``"("```#
M`@``V@$```````!(`0``L@(``"D!``"3````#P$``',"`````````````*P`
M``!2`0```````'$"``!E`@``+P$```````"Y`@```````!````"I`@``5P(`
M`!P"``!.````D@(``!T"````````O`$``)L```""````S@(``#0!````````
M``````T```!\`0``M0(```````#-`@``4P(``(("``"/`0```````!<```"$
M`0```````$H`````````)P$```X"````````,P$``.,```!Y`@``RP``````
M``!]`0``A0```%D"````````H@(``$(```#]````XP$``)\`````````:0$`
M`.4!```/`@``]`````````"V````$0$``-D`````````LP(``#H!```-`0``
M`````,D"````````=`$```````"P`````````,H!``!S`0``8`(````````Z
M`@``D`$``+X"```3`@````````````!H`@``(0```%,!``!%`@``Q`$``"(`
M``#B`0``&@$``'T"``#E`@`````````````H````50$``+H`````````_@$`
M```````[`````````*D!``"F`@``-@(``*T!```^`@``S`$``,P"``#,````
M@P(``.8!``#"`0``]P```-P"``"I````,@```$\```#2`0``YP`````````F
M`0````````````!Z`0``I`(``$L"``!2````D````)4```"B````20(`````
M```*`````````%\```!*`0```````.P!``!$`0``?@(```T"````````````
M``````!=`@``J@$``"$!``!+`0``!P$``*@!````````V`````````!&`0``
M`````-H```!'`````````+,```!X`@``'````"0!`````````````.$!``!O
M`0``L0$``(P"````````:@(``%\!``!-````JP```"X`````````=P```,D`
M``">`0``A````&8!```R`0``!P```"P```"!````GP(``/D```!]````8```
M`&0!```7`@``'P```-X"``"3`@``H0$``*@```"/````B`$``#4"```*`@``
MZ@```&\"``#(`@``[@$```X````K`@``^@````````"+````1````)@````$
M````M`(``+$```!0````Y`$```8"```]`@```0(````@86YD`"!A="``(&]R
M`"5D("5S(&%N9"`E<P`E<R`M($YO=&EC90`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%1E<FUS(&]F($%G<F5E;65N=``E
M<R!A="`E<R`E<P`E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@
M;V8@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!32!3
M:&]W97)S`$%-+U!-`$%B<V)O='1O;0!!8G-M:61D;&4`06-C;W5N="!087-S
M=V]R9`!!8V-O=6YT:6YG`$%C=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S
M<V5S.@!!8W1I=F%T92!38W)I<'0`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@
M2&5R93H`061D($YE=R!'<F]U<`!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D:71I;VYA;"!3971T:6YG<P!!9&1R97-S($)O;VL`061M:6YI
M<W1R871I;VX`061S`$%L:6=N`$%L:6=N;65N=#H`06QL($%U=&AE;G1I8V%T
M960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@
M<VED97,`06QL(&]F('1H92!F;VQL;W=I;F<`06QT97)N871E($E-4U`@57-E
M<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L
M871E<P!!;'1E<FYA=&4@=&5X=#H`06YS=V5R`$%N<W=E<F5D`$%N>2!O9B!T
M:&4@9F]L;&]W:6YG`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y
M+@!!<'!L>2!&:6QT97)S`$%P<FEL`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!D96QE=&4@=&AI<R!R=6QE/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%U9W5S=`!!=71O
M;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&5A8V@@8VAA;F=E
M/P!!=F%I;&%B;&4@9FEE;&1S.@!"86-K9W)O=6YD`$)A<V5L:6YE`$)C8P!"
M96=I;G,@=VET:`!";&%C:VQI<W0`0FQA8VML:7-T($5D:70`0FQA8VML:7-T
M(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R
M:79E<BX`0FQA8VML:7-T960@061D<F5S<P!";&%C:VQI<W1E9"!!9&1R97-S
M97,`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";V1Y`$)O;&0`0F]O:VUA
M<FMS`$)O<F1E<@!";W)D97)S`$)O='1O;0!#35,`0U]E;&P@4')O<&5R=&EE
M<RXN+@!#86QE;F1A<@!#86QM`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O
M<G0`0V%P=&EO;@!#87-E(%-E;G-I=&EV90!#871E9V]R:65S(&%N9"!,86)E
M;',`0V,`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5N=&5R`$-H86YG90!#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E<R!S879E9"X`
M0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@
M9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D>0!#;VQL87!S960@8F]R9&5R<P!#;VQO<@!#;VQO<B!0:6-K97(`0V]L
M<SH`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VYD:71I;VYS`$-O
M;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;G1A:6YS`$-O;G1I;G5E
M`$-O<'D`0V]P>2`E<P!#;W!Y(&]F("5S`$-O<'D@<V5L96-T:6]N`$-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N+@!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E(&YE=R!F;VQD97(`0W)E871O<B!097)M:7-S:6]N
M<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$1$`$1)4T%"3$5$.B``1&%T851R964@0G)O=W-E<@!$871E(%)E8V5I
M=F5D`$1A>0!$95]L971E($-O;'5M;@!$96%C=&EV871E(%-C<FEP=`!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5F875L="!#;VQO<@!$96QE=&4`1&5L
M971E("5S`$1E;&5T92!#;VYD:71I;VX`1&5L971E($=R;W5P`$1E;&5T92!C
M96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T90!$96QE=&4@;65S<V%G92!C;VUP;&5T96QY`$1E;&5T92!R;W<`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D`$1E;&EV97(@
M:6YT;R!M>2!)3D)/6`!$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(&-O<'D@
M=&\`1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R961I<F5C="!T;P!$96QI
M=F5R('1O(&9O;&1E<@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO
M;@!$979E;&]P;65N=`!$97<@4&]I;G0`1&ER96-T;W)Y`$1I<V%B;&4@)7,`
M1&ES86)L960`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO
M;G,`1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE;B!E86-H(&9I
M;'1E<B!I<R!A<'!L:65D/P!$;R!?;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U
M;&L@;W(@;&ES="!M97-S86=E<P!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('1H:7,Z`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]E<VXG="!B96=I;B!W:71H`$1O97-N)W0@8V]N
M=&%I;@!$;V5S;B=T(&5N9"!W:71H`$1O97-N)W0@97AI<W0`1&]E<VXG="!M
M871C:"`H=VET:"!P;&%C96AO;&1E<G,I`$1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$5D:70`161I="`E<P!%9&ET
M($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`E<P!%;6%I;"!!9&1R97-S`$5N86)L92`E<P!%;F%B;&5D`$5N
M9',@=VET:`!%<75A;"!T;P!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y
M(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%
M>&5C=71E`$5X:7-T:6YG(%)U;&5S`$5X:7-T<P!&1R!#;VQO<@!&5%`@=7!L
M;V%D(&]F('-E='5P`$9A:7(`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L
M:6ME.B``1F5W(%-H;W=E<G,`1FEL92!-86YA9V5R`$9I;'1E<B!!;&P@365S
M<V%G97,`1FEL=&5R($]N;'D@4V5E;B!-97-S86=E<P!&:6QT97(@3VYL>2!5
M;G-E96X@365S<V%G97,`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%)U;&4`1FEL
M=&5R(%)U;&5S`$9I;'1E<B!38W)I<'0@1&ES<&QA>0!&:6QT97(@7U)U;&5S
M`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@8V]P
M:65D('1O('1H92!F;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M
M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ
M("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD97(@
M(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I('1H870@;6%T
M8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@9&5L971E9"X`1FEL=&5R(&%C=&EV
M:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@8F5E;B!C;W!I
M960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&1E;&5T960N`$9I;'1E
M<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@:&%S(&)E
M96X@;6]V960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@;F]T(&9O=6YD
M+@!&:6QT97)S`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&;&]A=`!&;VYT
M($-O;&]R`$9O<B!A;B!I;F-O;6EN9R!M97-S86=E('1H870@;6%T8VAE<SH`
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R9V]T
M('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O
M<G1U;F5S`$9O<G5M<P!&;W)W87)D`$9O<G=A<F0@:7,@;F]T('-U<'!O<G1E
M9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!&;W)W87)D<P!&
M;W)W87)D<R!%9&ET`$9R`$9R86UE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E
M<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!';P!';V]G;&4@4V5A<F-H`$=R
M96%T97(@=&AA;@!'<F5A=&5R('1H86X@;W(@97%U86P@=&\`1W)O=7`@061M
M:6YI<W1R871I;VX`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$AE:6=H=`!(
M96QP`$AE;6ES<&AE<F4`2&EG:`!(;U]M90!(;W)D90!(;W)I>F]N=&%L('!A
M9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@
M=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AU;6ED:71Y`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N<R!/;FQY`$EC;VYS
M('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EM86=E(%!R979I97<Z`$EM
M86=E(%523`!);6%G92!54DPZ`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP
M;W)T86YT`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN
M7W-E<G0@4F]W($%F=&5R`$EN9&EV:61U86P@57-E<G,`26YD:79I9'5A;"!R
M=6QE<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I
M;F<@9')I=F5R+@!);F5X:7-T86YT(&UA:6QB;W@@<W!E8VEF:65D(&9O<B!M
M97-S86=E(&1E;&EV97)Y+@!);F9O<FUA=&EO;@!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!C96QL
M(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R
M`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`
M26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E
M<G0@<F]W(&)E9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN=F%L:60@87!P
M;&EC871I;VXN`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F5N=&]R
M>0!)<P!)<VXG=`!)=&%L:6,`2F%N=6%R>0!*87!A;F5S92`H25-/+3(P,C(M
M2E`I`$IU;'D`2G5N90!*=7-T:69Y`$QA7WEO=70`3&%N9W5A9V4`3&%S="!1
M=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87EO=70`3&5F=`!,
M97-S('1H86X`3&5S<R!T:&%N(&]R(&5Q=6%L('1O`$QI9VAT(%)A:6X`3&ES
M="!(96QP(%1O<&EC<P!,:7-T+4E$`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$QI=&5R871U<F4`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;W<`3&]W97(@
M<F]M86X@;G5M8F5R<P!-30!-86EL`$UA:6P@061M:6X`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%R7VL@;65S<V%G92!A<R!D96QE=&5D`$UA<F-H`$UA<F=I;@!-87)K
M(&UE<W-A9V4@87,Z`$UA=&-H:6YG(&9I96QD<P!-87D`365M8F5R<P!-97)G
M92!C96QL<P!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=')I8P!-:61D
M;&4`36ES<VEN9R!A9&1R97-S('1O(')E9&ER96-T(&UE<W-A9V4@=&\`36ES
M<VEN9R!R96%S;VX@9F]R(')E:F5C=`!-:7-S:6YG(')E87-O;B!I;B!V86-A
M=&EO;BX`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69Y(%523`!-;W-T
M;'D@0VQE87(`36]V90!-;W9E(%)U;&4@1&]W;@!-;W9E(%)U;&4@57``37D@
M06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!.3RP@22!$;R!.
M3U0@06=R964`3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C871I;VX@<F5P
M;&EE<SH`3F5T=V]R:P!.979E<@!.97<@0V%T96=O<GD`3F5W(%)U;&4`3F5W
M(%5S97)N86UE("AO<'1I;VYA;"D`3F5W<P!.97=S9W)O=7!S`$YE>'0`3FEG
M:'0`3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0`3F\@8F%C
M:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K96YD<RYP:'``3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@:&5A9&5R<R!S
M<&5C:69I960`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S8W)I
M<'0@9V5N97)A=&5D+@!.;R!S:61E<P!.;R!S=')I;F=S('-P96-I9FEE9`!.
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO
M=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.
M;VYE`$YO="!E<75A;"!T;P!.;W0@<V5T`$YO=&5S`$YO=F5M8F5R`$YU;6)E
M<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$]+`$]B:F5C="!#<F5A=&]R
M`$]C=&]B97(`3V9F:6-E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96YS('1H
M:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&%B;W5T
M('-C<FEP="!U<&1A=&EN9RX`3W!T:6]N<R!F;W(@)7,`3W)G86YI>FEN9P!/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/=&AE<@!/=&AE<B!);F9O
M<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!(4"!#
M;V1E`%!-($QI9VAT(%)A:6X`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D
M.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A=&@`4&5N9&EN9R!3
M:6=N=7!S.@!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@
M26YF;W)M871I;VX`4&AO=&]S`%!I>&5L<P!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;VQL<P!0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`
M4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0
M<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<FEN
M="!D;V-U;65N=`!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C
M=',`475E<GD`4E]E87-O;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A
M;F1O;2!&;W)T=6YE`%)E860`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E8V5I=F5D`%)E9&ER96-T('1O`%)E9G)E<V@@4&]R=&%L(%9I97<Z
M`%)E9W5L87(@97AP<F5S<VEO;@!296IE8W0@=VET:"!R96%S;VX`4F5M87)K
M<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP
M;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@9F]R
M;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@=&AE`%)E;6]V92!U<V5R`%)E
M;6]V92!U<V5R.B`E<P!297-E;G0@5&\`4F5S96YT+69R;VT`4F5S970`4F5S
M970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E='5R
M;B!T;R!&:6QT97)S($QI<W0`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O
M(%)U;&5S($QI<W0`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4F]?=R!0<F]P97)T:65S+BXN
M`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&4`4G5L
M92!#;W!I960`4G5L92!$96QE=&5D`%)U;&4@1&ES86)L960`4G5L92!%;F%B
M;&5D`%)U;&4@3F%M90!2=6QE<P!2=6X`4TU3($UE<W-A9VEN9P!380!3879E
M`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@4V5T=&EN9W,`4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+@!38W)I<'0@57!D871I;F<`4V-R:7!T(&YO="!U<&1A=&5D+@!3
M8W)I<'0@<W5C8V5S<V9U;&QY(&%C=&EV871E9"X`4V-R:7!T('-U8V-E<W-F
M=6QL>2!D96%C=&EV871E9"X`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E96X`
M4V5L96-T(&$@9FEE;&0`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A
M(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A
M9&0`4V5L96-T('1A<F=E="!F;VQD97(`4V5L96-T('1H92!C:&%R86-T97)S
M('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@
M8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C
M="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z
M`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F
M;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U
M<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD97(`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971T:6YG<R!S=6-C
M97-S9G5L;'D@=7!D871E9"X`4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L90!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@06-T:79E
M(%-C<FEP=`!3:&]W($-U<G)E;G0@4V-R:7!T`%-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9P!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E
M`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;F]W(&1E<'1H.B``4W!A8VEN9P!3
M<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@
M8V]L=6UN`%-P;&ET(')O=P!3=&%N9&%R9`!3=&%T=7,`4W1O<"!C:&5C:VEN
M9R!I9B!T:&ES(')U;&4@;6%T8VAE<S\`4W4`4W5B:F5?8W0@;V8@=F%C871I
M;VX@;65S<V%G93H`4W5B:F5C=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL
M>2!W<F]T92`E<P!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N<FES90!3
M=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R
M<V-R:7!T`%-U<'!O<G0`5"U3=&]R;0!4+5-T;W)M<P!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%R9V5T.@!487-K<P!496UP(&9O<B!L
M87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E
M($%D;6EN:7-T<F%T:6]N`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@9')I=F5R
M('-A:60Z(`!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4
M:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(&AA<R!B965N(')E;6]V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N
M;W0@879A:6QA8FQE+@!4:&5R92!W87,@86X@97)R;W(@86-T:79A=&EN9R!T
M:&4@<V-R:7!T+@!4:&5R92!W87,@86X@97)R;W(@9&5A8W1I=F%T:6YG('1H
M92!S8W)I<'0N`%1H:7,@:7,@)7,N`%1H=6YD97(`5&EC:V5T<P!4:6UE(%1R
M86-K:6YG`%1I;64@9F]R;6%T`%1I=&QE`%1O`%1O9&%Y`%1O;6]R<F]W`%1O
M<`!4=0!54DP`55),.@!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RX`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5N:71S`%5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N<V5T(&-O;&]R`%5P9&%T90!5
M<&1A=&4@)7,`57!D871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`
M57!L;V%D`%5P<&5R(')O;6%N(&YU;6)E<G,`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R;F%M90!5<V5R;F%M93H`
M57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!686-A=&EO;@!686-A
M=&EO;B!%9&ET`%9A8V%T:6]N($UE<W-A9V4`5F%C871I;VX@:7,@;F]T('-U
M<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!687)I
M86)L90!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@
M<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I97<@86X@97AT97)N86P@
M=V5B('!A9V4`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5V4`5V5A=&AE<B!&
M;W)E8V%S=`!796(`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=H7VET96QI<W0@861D<F5S<V5S.@!7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET
M97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H
M:71E;&ES=`!7:&ET96QI<W0@161I=`!7:&ET96QI<W0@:7,@;F]T('-U<'!O
M<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!7:&ET96QI
M<W1E9"!!9&1R97-S97,`5VED=&@`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H
M('5N:70`5VED=&@Z`%=I;F0Z`%=I;F0Z(`!960!997,L($D@06=R964`66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&5M86EL
M(&%D9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M97-S86=E<R!S:&]U
M;&0@8F4@86-T:79A=&5D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P
M9&%T92X`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`
M66]U<B!);F9O<FUA=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I
M9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@<F5M;W1E('-E<G9E<G,Z
M`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!4
M97AT("T`7T%D9')E<W,H97,I('1O(&9O<G=A<F0@=&\Z`%]!9&1R97-S97,@
M=&\@;F]T('-E;F0@<F5S<&]N<V5S('1O.@!?061M:6YI<W1R871I;VX`7T)L
M86-K;&ES=`!?1&%T851R964`7T1E;&5T92!2;W<`7T1E;&5T92!M97-S86=E
M(&-O;7!L971E;'D`7T5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE
M.@!?1F]R=V%R9`!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN
M`%]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_`%],
M;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?36]V92!M97-S86=E('1O(&9O;&1E
M<CH`7TUY(&5M86EL(&%D9')E<W-E<SH`7T]P=&EO;G,`7U!E<FUI<W-I;VYS
M`%]296UO=F4@3&EN:RXN+@!?4V-R:7!T`%]486)L92!0<F]P97)T:65S+BXN
M`%]5<V5R<P!?5F%C871I;VX`7U=H:71E;&ES=`!A;F0`8V%L;0!F:65L9`!F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&QI;F5S70!M871C:`!N86UE`&]R
M`'!E<F-E;G0`<&EX96QS`'!R;V-M86EL('-C<FEP="!G96YE<F%T960@8GD@
M26YG;P!R:7-I;F<`<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!);F=O`'-T
M96%D>0!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'=E871H
M97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@26YG;R`R+C`M8W9S"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P,RTP.2TR."`R,SHU,"TP,3`P"DQA<W0M5')A;G-L871O<CH@
M36%R8V\@4&ER;W9A;F\@/&UA<F-O+G!I<F]V86YO0'5N:6)O8V-O;FDN:70^
M"DQA;F=U86=E+51E86TZ($AO<F1E($ET86QI86X@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET"@`@90`@86QL92``(&\`)60@)7,@92`E<P`E<R`M($%T
M=&5N>FEO;F4`)7,@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO;F4@+2!#;VYF
M97)M80`E<R!497)M:6YI(&0G57-O`"5S(&$@)7,@)7,`)7,@;6EN=71I`"5S
M(&YO;B!T<F]V871O+@`E<R!A("5S(&1I("5S`"P@82`E<R`E<P`L('9A<FEA
M8FEL92!D82`E<R!A("5S`$9O<FUA=&\@,3(@;W)E`$9O<FUA=&\@,C0@;W)E
M`#(T(&]R90!-;W-T<F$@04T`04TO4$T`5F%I(&$`4F5G;VQE`$%C8V]U;G0@
M4&%S<W=O<F0`0V]N=&%B:6QI=&$G`$%Z:6]N92!P97(@:6YD:7)I>GII(&YE
M;&QA(&QI<W1A(&YE<F$Z`$%T=&EV82!38W)I<'0`06=G:75N9VD`06=G:75N
M9VD@4V]T=&\@1W)U<'!O`$%G9VEU;F=I('%U:3H`06=G:75N9VD@3G5O=F\@
M571E;G1E`$%G9VEU;F=I('5N(&YU;W9O('5T96YT93H`06=G:75N9VD@=6X@
M;G5O=F\@;65M8G)O`$%G9VEU;F=I('!A:6\`06=G:75N9VD@=71E;G1E`$QA
M(&9U;GII;VYE(&1I(&%G9VEU;G1A('5T96YT:2!N;VX@Z"!A='1I=F$N`%5L
M=&5R:6]R:2!);7!O<W1A>FEO;FD`4G5B<FEC80!!;6UI;FES=')A>FEO;F4`
M4'5B8FQI8VETX`!!;&QI;F5A;65N=&\`06QL:6YE86UE;G1O.@!4=71T:2!G
M;&D@571E;G1I($%U=&5N=&EC871I`%1U='1I(&D@1W)U<'!I`%1U='1I(&D@
M4&5R;65S<VD`5'5T=&D@:2!Q=6%T=')O(&QA=&D`5'5T=&4@;&4@<V5G=65N
M=&D`571E;GIA($E-4U`@86QT97)N871I=F$`26YD:7)I>GIO(&5M86EL(&%L
M=&5R;F%T:79O`$%V=FES82!S=2!A9V=I;W)N86UE;G1I`%1E<W1O(&%L=&5R
M;F%T:79O.@!2:7-P;W-T80!2:7-P;W-T;P!5;F$@<75A;'5N<75E(&1E;&QE
M('-E9W5E;G1I`$%P<&QI8V%Z:6]N90!!<'!L:6-A>FEO;F4@92<@<')O;G1A
M+@!!<'!L:6-A(&D@1FEL=')I`$%P<FEL90!396D@<VEC=7)O(&1I('9O;&5R
M(&5L:6UI;F%R92!Q=65S=&$@<F5G;VQA/P!396D@<VEC=7)O(&1I('9O;&5R
M(&5L:6UI;F%R92!L82!R:6-H:65S=&$@9&D@:7-C<FEZ:6]N92!P97(@)7,_
M`$-H:65D:2!C;VYF97)M82!P<FEM82!D:2!E<V5G=6ER92!O<&5R87II;VYI
M(&1I(&UA;G5T96YZ:6]N90!496YT871I=F\@9&D@8V%N8V5L;&%Z:6]N92!D
M:2!U;B!G<G5P<&\@:6YE<VES=&5N=&4N`%1E;G1A=&EV;R!D:2!E;&EM:6YA
M>FEO;F4@9&D@=6X@<&5R;65S<V\@:6YE<VES=&5N=&4N`%1E;G1A=&EV;R!D
M:2!M;V1I9FEC82!D:2!U;B!P97)M97-S;R!I;F5S:7-T96YT90!496YT871I
M=F\@9&D@;6]D:69I8V$@9&D@=6X@<&5R;65S<V\@:6YE<VES=&5N=&4`06=O
M<W1O`$%G9VEO<FYA(&%U=&]M871I8V%M96YT92!L;R!S8W)I<'0@9&]P<&\@
M;V=N:2!M;V1I9FEC83\`0V%M<&D@9&ES<&]N:6)I;&DZ`%-F;VYD;P!"87-E
M;&EN90!"8V,`26YI>FEA(&-O;@!,:7-T82!N97)A`$UO9&EF:6-A(&QA($QI
M<W1A($YE<F$`3&$@;&ES=&$@;F5R82!N;VX@Z"!S=7!P;W)T871A(&YE;"!D
M<FEV97(@871T=6%L92!D:2!F:6QT<FDN`$EN9&ER:7IZ;R!N96QL82!,:7-T
M82!.97)A`$EN9&ER:7IZ:2!N96QL82!,:7-T82!.97)A.@!);7!O<W1A>FEO
M;FD@0FQO8V-O`%1I<&\@9&D@0FQO8V-O`$-O<G!O`$=R87-S971T;P!0<F5F
M97)I=&D`36%R9VEN90!-87)G:6YI`$)A<W-O`$--4P!0<F]P<FEE=.`@9&5L
M;&4@0U]E;&QE+BXN`$-A;&5N9&%R:6\`0V%L;6\`0V%N8V5L;&$`16QI;6EN
M82!287!P;W)T;R!D:2!0<F]B;&5M80!/<'II;VYI`%)I<W!E='1A($UA:75S
M8V]L92!M:6YU<V-O;&4`0V%T96=O<FEE(&4@171I8VAE='1E`$-C`%!R;W!R
M:65TX"!D96QL92!C96QL90!3<&5S<V]R92!C96QL93H`4')O<')I973@(&1E
M;&QE(&-E;&QE`%-P87II;R!C96QL93H`0V5N=')A`$UO9&EF:6-A`$UO9&EF
M:6-A(&YO;64L(&EN9&ER:7IZ;R!E(&9I<FUA(&-H92!V97)R86YN;R!V:7-U
M86QI>GIA=&D@9&%L;&4@<&5R<V]N92!C:&4@;&5G9V]N;R!E(')I<W!O;F1O
M;F\@86ET('1U;VD@;65S<V%G9VDN`$UO9&EF:6-H92!S86QV871E+@!#:6%D
M`%9E<FEF:5]C82!,:6YK+BXN`%-E;&5Z:6]N82!C;VUE('9I<W5A;&EZ>F%R
M92!L92!D871E.@!%;&EM:6YA('5T96YT93H@)7,`16QI;6EN82!U=&5N=&4`
M16QI;6EN82!L92!I;F9O<FUA>FEO;FD@9&5L;"=U=&5N=&4`0VQI8V-A('!E
M<B!#;VYT:6YU87)E`$-H:75D:2!L82!&:6YE<W1R80!.=79O;&4`3G5V;VQE
M`$UA<F=I;FD@8V]L;&%S<V%T:0!#;VQO<F4`4V5L97II;VYA($-O;&]R90!#
M;VQO;FYE.@!6:6=N971T90!#;VUA;F1O`%-H96QL(&1I($-O;6%N9&D`0V]N
M9&EZ:6]N:0!#;VYF:6=U<F$@)7,`0V]N9F5R;6$@4&%S<W=O<F0`0V]N=&EE
M;F4`0V]N=&EN=6$`0V]P:6$`0V]P:6$@9&D@)7,`0V]P:6$@9&D@)7,`4V5L
M97II;VYE(&QA(&-O<&EA`$EM<&]S<VEB:6QE(&EN=F5R=&ER92!L82!C;VYF
M:6=U<F%Z:6]N92X`26UP;W-S:6)I;&4@<V%L=F%R92!L82!C;VYF:6=U<F%Z
M:6]N92`E<RX`26UP;W-S:6)I;&4@<V%L=F%R92!U;F$@8V]P:6$@9&D@<V-O
M<G1A(&1E;&QA(&-O;F9I9W5R87II;VYE`$-O<G-I`$-R96$`0W)E82!U;B!C
M;VQL96=A;65N=&\`0W)E86YE('5N;R!N=6]V;P!#<F5A($YU;W9A($-A<G1E
M;&QA`%!E<FUE<W-I(&1I($-R96%T;W)E`$]R82!A='1U86QE`$QA(%523"!A
M='1U86QE(.@`365T96\@071T=6%L90!#;VYD:7II;VYI(&%T='5A;&DZ(`!3
M=&EL92!A='1U86QE`$EM<&]S=&$@;&4@;W!E<F%Z:6]N:2!D82!E<V5G=6ER
M92!Q=6%N9&\@96YT<FD@:6X@)7,N`%1A9VQI80!396QE>FEO;F4@5&%G;&EA
M`$='`$1)4T%"24Q)5$%43SH`0G)O=W-E<B!$871A5')E90!$871A(%)I8V5V
M=71O`$=I;W)N;P!%7VQI;6EN82!#;VQO;FYA`$1I<V%T=&EV82!38W)I<'0`
M1&EC96UB<F4`3G5M97)O(&1E8VEM86QE`$-O;&]R92!D:2!$969A=6QT`$-A
M;F-E;&QA`$-A;F-E;&QA("5S`$5L:6UI;F$@;&$@0V]N9&EZ:6]N90!%;&UI
M;F$@1W)U<'!O`$5L:6UI;F$@8V5L;&$`16QI;6EN82!C;VQO;FYA`$%V=FES
M82!S=2!A9V=I;W)N86UE;G1I`$5L:6UI;F$@;65S<V%G9VEO(&-O;7!L971A
M;65N=&4`16QM:6YA(')I9V$`16QI;6EN82!L)VED96YT:73@('-E;&5Z:6]N
M871A`$5L:6UI;F$@;&$@8V]L;VYN82!C;W)R96YT90!%;&EM:6YA(&QA(')I
M9V$@8V]R<F5N=&4`16QI;6EN871O`$-O;G-E9VYA(&YE;&QA(&UI82!)3D)/
M6`!#;VYS96=N82!N96QL82!M:6$@24Y"3U@@92!R:6UB86QZ82!A`$-O;G-E
M9VYA(&YE;&QA(&UI82!)3D)/6"!E(')I;6)A;'IA(&$`4W!O<W1A(&YE;&QA
M($-A<G1E;&QA`$1E<V-R:79I(&EL(%!R;V)L96UA`$1E<V-R:7II;VYE`%-V
M:6QU<'!O`%!U;G1O(&1I(%)U9VEA9&$`0V%R=&5L;&$`1&ES871T:79A("5S
M`$1I<V%T=&EV871O`%9I<W5A;&EZ>F$@;F5L(&9O<FUA=&\@,C0@;W)E/P!/
M<'II;VYI(%9I<W5A;&EZ>F%Z:6]N90!-;W-T82!N;W1I9FEC82!D971T86=L
M:6%T82!D;W!O(&PG87!P;&EC87II;VYE(&1I(&]G;FD@9FEL=')O/P!.7V]N
M(&EN=FEA<F4@<FES<&]S=&4@82!G<G5P<&D@;R!M97-S86=G:2!D:2!L:7-T
M90!.;VX@96QI;6EN87)E`$YO;B!A8V-E9&5R92!D:7)E='1A;65N=&4@82!M
M86EN=&5N86YC92YP:'``1F%I('%U97-T;SH`3&$@<')I;6$@<FEG82!C;VYT
M:65N92!L92!E=&EC:&5T=&4@9&D@8V%M<&\_($UA<F-A('-E('-I+"!L87-C
M:6$@=G5O=&$@<V4@;F\Z`$YO;B!I;FEZ:6$@8V]N`$YO;B!C;VYT:65N90!.
M;VX@9FEN:7-C92!C;VX`3F]N(&5S:7-T90!.;VX@8V]R<FES<&]N9&4`4V-A
M<FEC82!L82!C;VYF:6=U<F%Z:6]N92!G96YE<F%T82!C;VUE('-C<FEP="!0
M2%`N`$UO9&EF:6-A`$UO9&EF:6-A("5S`$UO9&EF:6-A($)L;V-C;P!-;V1I
M9FEC82!'<G5P<&\`36]D:69I8V$@4&5R;65S<VD`36]D:69I8V$@<&5R;65S
M<VD@<&5R("5S`$UO9&EF:6-A(&]P>FEO;FD@<&5R.@!-;V1I9FEC82!P97)M
M97-S:2!P97(@)7,`26YD:7)I>GIO(&1I(%!O<W1A`$%T=&EV82`E<P!!='1I
M=F%T;P!&:6YI<V-E(&-O;@!59W5A;&4@80!%<G)O<F4`3V=N:2`Q-2!M:6YU
M=&D`3V=N:2`R(&UI;G5T:0!/9VYI(#,P('-E8V]N9&D`3V=N:2`U(&UI;G5T
M:0!/9VYI($UE>GHG;W)A`$]G;FD@;6EN=71O`%9A;&]R:2!D:2!E<V5M<&EO
M.@!%<V5C=7II;VYE`%)E9V]L92!%<VES=&5N=&D`17-I<W1E`$-O;&]R92!&
M1P!5<&QO860@*$-A<FEC86UE;G1O*2!F:6QE(&YO;B!S=7!P;W)T871O+@!'
M:75S=&\`1F5B8G)A:6\`4VD@<V5N=&4@8V]M90!3:2!S96YT92!C;VUE.B``
M4&]C:&D@06-Q=6%Z>F]N:0!&:6QE($UA;F%G97(`1FEL=')A(%1U='1I(&D@
M365S<V%G9VD`1FEL=')A(%-O;&\@365S<V%G9VD@3&5T=&D`1FEL=')A(%-O
M;&\@365S<V%G9VD@3F]N($QE='1I`$]P>FEO;FD@1FEL=')I`%)E9V]L82!D
M96P@1FEL=')O`%)E9V]L92!D96P@1FEL=')O`%9I<W5A;&EZ>F%Z:6]N92!3
M8W)I<'0@9&D@1FEL=')O`%]296=O;&4@9&5L($9I;'1R;P!!='1I=FETX"!D
M96P@9FEL=')O.B`E<R!M97-S86=G:6\O:2!S<&]S=&%T:2!N96QL82!C87)T
M96QL82`B)7,B+@!!='1I=FETX"!D96P@9FEL=')O.B`E<R!M97-S86=G:6\O
M:2!S;VYO('-T871I(&5L:6UI;F%T:2X`071T:79I=.`@9&5L(&9I;'1R;SH@
M)7,@;65S<V%G9VEO+VD@<W!O<W1A=&D@;F5L;&$@8V%R=&5L;&$@(B5S(BX`
M071T:79I=.`@9&5L(&9I;'1R;SH@)7,@;65S<V%G9VEO+VD@8VAE(&-O<G)I
M<W!O;F1A;F\@86QL82!L:7-T82!N97)A('-O;F\@<W1A=&D@96QI;6EN871I
M+@!!='1I=FETX"!D96P@9FEL=')O.B!);"!M97-S86=G:6\@(B5S(B!D82`B
M)7,B(.@@<W1A=&\@<W!O<W1A=&\@;F5L;&$@8V%R=&5L;&$@(B5S(BX`071T
M:79I=.`@9&5L(&9I;'1R;SH@26P@;65S<V%G9VEO("(E<R(@9&$@(B5S(B#H
M('-T871O(&5L:6UI;F%T;RX`071T:79I=.`@9&5L(&9I;'1R;SH@26P@;65S
M<V%G9VEO("(E<R(@9&$@(B5S(B#H('-T871O('-P;W-T871O(&YE;&QA(&-A
M<G1E;&QA("(E<R(N`%5T96YT92!N;VX@=')O=F%T;RX`1FEL=')I`%!R:6UA
M($UE=&$G`%!R:6UO(%1R:6UE<W1R90!&;&]A=`!#;VQO<F4@1F]N=`!097(@
M;65S<V%G9VD@:6X@:6YG<F5S<V\@8VAE(&-O;6)A8VEA;F\@8V]N.@!097(@
M8G)O=W-E<B!C:&4@;F]N('-O<'!O<G1A;F\@;&4@:6UM86=I;FD`2&%I(&1I
M;65N=&EC871O(&QA('1U82!P87-S=V]R9#\`36]D=6QI`$EN9&]V:6YO`$9O
M<G1U;F4@5'EP90!&;W)T=6YE<P!&;W)U;0!);F]L=')A`$PG:6YO;'1R;R!N
M;VX@Z"!S=7!P;W)T871O`$EN;VQT<FD`36]D:69I8V$@26YO;'1R:0!696X`
M1G)A;65S`$1A`$1A;"``1&5S8W)I>FEO;F4@0V]M<&QE=&$`3'5N82!0:65N
M80!.;VUE($-O;7!L971O`$=E;F5R82!#;VYF:6=U<F%Z:6]N92`E<R``0V]D
M:6-E($=E;F5R871O`%9A:2!A`%)I8V5R8V$@1V]O9VQE`%!I=2<@9W)A;F1E
M(&1I`$UE;F\@9&D@;R!U9W5A;&4@80!!;6UI;FES=')A>FEO;F4@1W)U<'!I
M`$=R=7!P:0!097)M97-S:2!/<W!I=&D`06QT97IZ80!!:75T;P!%;6ES9F5R
M;P!!;'1A`$AO7W)D90!(;W)D90!2:65M<&EM96YT;R!/<FEZ>F]N=&%L90!/
M<FEZ>F]N=&%L93H`475A;G1E(&-O;&]N;F4@=G5O:2!U;FER93\`475A;G1I
M(&-A;7!I("AC;VQO;FYE*2!C:2!S;VYO/P!1=6%N=&4@<FEG:&4@=G5O:2!U
M;FER93\`56UI9&ETX`!)7VYS97)I<V-I(&QA(')I9V$@<')I;6$`4V]L;R!)
M8V]N90!)8V]N92!C;VX@5&5S=&\`3F]M92!D96QL)TED96YT:73@.@!!;G1E
M<')I;64@26UM86=I;F4`55),($EM;6%G:6YE`%523"!);6UA9VEN90!);6UA
M9VEN:0!);7!O<G1A+"!087-S;R`E9`!);7!O<G1A;G1E`$-A;7!O(&EM<&]R
M=&%T;SH@)7,`0V%M<&D@:6UP;W)T871I.@!);E]S97)I<V-I('5N82!R:6=A
M(&1O<&\`571E;G1I($EN9&EV:61U86QI`%)E9V]L92!I;F1I=FED=6%L:2!N
M;VX@<V]N;R!S=7!P;W)T871E`$-A<V5L;&$@:6YE<VES=&5N=&4@<W!E8VEF
M:6-A=&$@<&5R(&QA(&-O;G-E9VYA(&1E;"!M97-S86=G:6\N`$EN9F]R;6%Z
M:6]N90!);G-E<FES8VD@=6YA($-?;VQO;FYA(&1O<&\`26YS97)I<V-I('5N
M)VEM;6%G:6YE`$EN<V5R:7-C:2!486)E;&QA`$EN<V5R:7-C:2!#;VQL96=A
M;65N=&\@5V5B`$EN<V5R:7-C:2!?8V]L;VYN82!0<FEM80!);G-E<FES8VD@
M=6YA(&YU;W9A(&-O;&]N;F$@9&]P;R!Q=65L;&$@8V]R<F5N=&4`26YS97)I
M<V-I('5N82!N=6]V82!C;VQO;FYA('!R:6UA(&1I('%U96QL82!C;W)R96YT
M90!);G-E<FES8VD@=6YA(&YU;W9A(')I9V$@9&]P;R!Q=65L;&$@8V]R<F5N
M=&4`26YS97)I<V-I('5N82!N=6]V82!R:6=A('!R:6UA(&1I('%U96QL82!C
M;W)R96YT90!);G-E<FES8VD@=6X@=&5M<&QA=&4@86QT97)N871I=F\`26YS
M97)I<V-I(&-E;&QA(&1O<&\`26YS97)I<V-I(&-E;&QA('!R:6UA`$%G9VEU
M;F=I(&-O;&]N;F$@9&]P;P!);G-E<FES8VD@8V]L;VYN82!P<FEM80!);G-E
M<FES8VD@<&%R86=R869O(&1O<&\`26YS97)I<V-I('!A<F%G<F%F;R!P<FEM
M80!);G-E<FES8VD@<FEG82!D;W!O`$EN<V5R:7-C:2!R:6=A('!R:6UA`$EN
M<V5R:7-C:2]-;V1I9FEC82!);6UA9VEN90!!<'!L:6-A>FEO;F4@:6YV86QI
M9&$N`$1A=&\@;F]N('9A;&ED;RX`26YV96YT87)I;P!%)P!.;VX@Z`!#;W)S
M:79O`$=E;FYA:6\`1VEA<'!O;F5S92`H25-/+3(P,C(M2E`I`$QU9VQI;P!'
M:75G;F\`1VEU<W1I9FEC871O`%]&;W)M871O`$QI;F=U80!5;'1I;6\@475A
M<G1O`%5L=&EM;R!!9V=I;W)N86UE;G1O.@!5;'1I;6\@86-C97-S;SH@)7,`
M56QT:6UO(&%C8V5S<V\Z("5S(&1A("5S`%5L=&EM;R!A8V-E<W-O.B!-86D`
M1F]R;6%T;P!S:6YI<W1R80!-96YO(&1I`$UE;F\@9&D@;R!U9W5A;&4@80!0
M:6]G9VEA($QE9V=E<F$`16QE;F-A(&=L:2!A<F=O;65N=&D@9&D@06EU=&\`
M240@3&ES=&$`3F]N(.@@871T:79A(&QA(&9U;GII;VYE(&1I(&5L96YC;R!U
M=&5N=&DN`$QI=&5R871U<F$`3W)A(&QO8V%L93H@`$QI;F=U82!E($]R80!,
M=6]G;P!%;G1R80!%<V-I`$-O;7!I=&D@9&D@:6YI>FEO('-E<W-I;VYE`$)A
M<W-A`&YU;65R:2!R;VUA;FD@<&GY(&)A<W-I`$U-`%!O<W1A`$EN9&ER:7IZ
M;R!!;6UI;FES=')A=&]R90!'97-T:7-C:2!L82!L:7-T82!D96QL92!C871E
M9V]R:64@9&%N9&\@;&]R;R!U;B=E=&EC:&5T=&$@92!A<W-O8VEA;F1O(&QO
M<F\@=6X@8V]L;W)E+@!#;VY?=')A<W-E9VYA(&UE<W-A9V=I;R!C;VUE(&5L
M:6UI;F%T;P!-87)Z;P!-87)G:6YE`$-O;G1R87-S96=N82!M97-S86=I;R!C
M;VUE.@!#86UP:2!C;W)R:7-P;VYD96YT:0!-86=G:6\`365M8G)I`%5N:7-C
M:2!#96QL90!-971E;R!!='1U86QE`$)L;V-K(&YO;B!D:7-P;VYI8FEL92X`
M1&5T=&%G;&D@;&]G9V%T:2!P97(@;"=A;6UI;FES=')A=&]R90!M971R:6-O
M`$-E;G1R;P!-86YC82!L)VEN9&ER:7IZ;R!A;"!Q=6%L92!R961I<FEG97)E
M(&EL(&UE<W-A9V=I;P!);F9O<FUA>FEO;FD@;6%N8V%N=&4`26YF;W)M87II
M;VYI(&UA;F-A;G1E`$QU;@!-;V)I;&4@36%I;`!-;V1E<F%T;P!-;V1I9FEC
M82!54DP`4')I;F-I<&%L;65N=&4@4V5R96YO`%-P;W-T80!3<&]S=&$@;&$@
M4F5G;VQA($=I^0!3<&]S=&$@;&$@4F5G;VQA(%/Y`$UI;R!!8V-O=6YT`$UI
M;R!0;W)T86QE`$9O<FUA=&\@9&5L($UI;R!0;W)T86QE`$Y/+"!.3TX@4V]N
M;R!D)T%C8V]R9&\N`$Y?=6UE<F\@9&D@9VEO<FYI('1R82!D=64@<FES<&]S
M=&4@86QL;R!S=&5S<V\@:6YD:7)I>GIO`%)E=&4`36%I`$YU;W9A($-A=&5G
M;W)I80!.=6]V82!296=O;&$`3G5O=F\@3F]M92!5=&5N=&4@*$]P>FEO;F%L
M92D`3F]T:7II90!'<G5P<&D@9&D@;F]T:7II90!0<F]S<VEM;P!.;W1T90!.
M97-S=6X@8F%C:V5D(&-O;F9I9W5R871O('!E<B!Q=65S=&\@:&]S=`!.97-S
M=6X@8F%C:V5D(&-O;F9I9W5R871O(&EN(&)A8VME;F1S+G!H<`!.;VX@<'5O
M:2!C<F5A<F4@9FEG;&D@82!Q=65S=&\@<&5R;65S<V\N`$YE<W-U;F$@:6YT
M97-T87II;VYE('-P96-I9FEC871A`$YE<W-U;F$@<F5G:7-T<F%Z:6]N92!I
M;B!A='1E<V$N`$YE<W-U;F$@<F5G;VQA`$YE<W-U;B!S8W)I<'0@9V5N97)A
M=&\N`$YE<W-U;B!L871O`$YE<W-U;F$@<W1R:6YG82!S<&5C:69I8V%T80!.
M97-S=6X@9&ER971T;W)I;R!T96UP;W)A;F5O(&1I<W!O;FEB:6QE('!E<B!L
M82!C86-H92X`3F5S<W5N82!V97)S:6]N92!T<F]V871A(&YE;&QA(&-O;F9I
M9W5R87II;VYE(&]R:6=I;F%L92X@4F5G96YE<F$@;&$@8V]N9FEG=7)A>FEO
M;F4N`$YE<W-U;F$@=F5R<VEO;F4@=')O=F%T82!N96QL82!T=6$@8V]N9FEG
M=7)A>FEO;F4N(%)E9V5N97)A(&QA(&-O;F9I9W5R87II;VYE+@!.97-S=6YO
M`$YO;B!U9W5A;&4@80!.;VX@:6UP;W-T871O`$YO=&4`3F]V96UB<F4`3G5M
M97)O(&1I(&-O;&]N;F4`3G5M97)O(&1I(')I9VAE`$]+`%!R;W!R:65T87)I
M;P!/='1O8G)E`%5F9FEC:6\`07!R:2!I;B!N=6]V82!F:6YE<W1R80!!<')I
M('%U97-T;R!C;VQL96=A;65N=&\@:6X@;G5O=F$@9FEN97-T<F$`3W!Z:6]N
M:0!/<'II;VYI(')I9W5A<F1O(&PG86=G:6]R;F%M96YT;R!D96QL;R!S8W)I
M<'0N`$]P>FEO;FD@9F]R("5S`$=R;W5P5V%R90!A<'!L:6-A>FEO;F4@:6YT
M97)N80!!;'1R;P!!;'1R92!);F9O<FUA>FEO;FD`06QT<F4@3W!Z:6]N:0!0
M97)M97-S:2!D96P@4')O<')I971A<FEO`$-O9&EC92!02%``4$T@4&EO9V=I
M82!,96=G97)A`%!A<W-W;W)D`%!A<W-W;W)D.@!087-S=V]R9#H@`$QE('!A
M<W-W;W)D(&1E=F]N;R!C;W)R:7-P;VYD97)E+@!);F-O;&QA`%!E<F-O<G-O
M`%)E9VES=')A>FEO;FD@:6X@071T97-A.@!097)C96YT=6%L90!%<V5G=6D@
M;&4@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO;F4`17-E9W5I(&QE(&]P97)A
M>FEO;FD@9&D@;6%N=71E;GII;VYE(&%L(&QO9VEN/P!097)M97-S:0!!;6UI
M;FES=')A>FEO;F4@9&5I(%!E<FUE<W-I`$EN9F]R;6%Z:6]N:2!097)S;VYA
M;&D`1F]T;P!0:7AE;`!0<F5G;R!C;VYF97)M87)E(&5L:6UI;F%Z:6]N92!E
M;&5M96YT;SH`4')E9V\@8V]N9F5R;6%R92!E;&EM:6YA>FEO;F4@;&EN:SH`
M26YS97)I<V-I('5N(&YO;64@<&5R(&QA(&YU;W9A(&-A=&5G;W)I83H`26YS
M97)I<V-I(&EL(&YO;64@9&5L;&$@;G5O=F$@8V%R=&5L;&$Z`$1E=FD@:6YS
M97)I<F4@:6P@='5O(&YO;64@=71E;G1E(&4@;&$@<&%S<W=O<F0`4V]N9&%G
M9VD`4&]S:7II;VYA;65N=&\@9&D@<75E<W1A(&EM;6%G:6YE+@!0;W-I>FEO
M;F%M96YT;R!D:2!Q=65S=&$@=&%B96QL80!0<F5S<VEO;F4`4')E<W-I;VYE
M(&%L(&QI=F5L;&\@9&D@;6%R93H@`%!R97-S:6]N93H@`$%N=&5P<FEM80!!
M;G1E<')I;6$@9&5L;"=I;6UA9VEN92!I;B!N=6]V82!F:6YE<W1R80!3=&%M
M<&$@9&]C=6UE;G1O(`!0<F]B;&5M80!$97-C<FEZ:6]N92!D96P@<')O8FQE
M;6$`4')O9V5T=&D`1&]M86YD80!27V%G:6]N90!0:6]G9VEA`%!I;V=G:6$@
M4')E<W1O`%!I;V=G:6$@5&%R9&D`1F]R='5N82!#87-U86QE`$QE9V=I`%-I
M8W5R;R!D:2!V;VQE<B!E;&EM:6-A<F4E<S\@3"=O<&5R87II;VYE(&YO;B!P
M=6\G(&5S<V5R92!A;FYU;&QA=&$`4VEC=7)O(&1I('9O;&5R(&5L:6UI;F%R
M92!I(&1A=&D@9&D@)7,_($PG;W!E<F%Z:6]N92!N;VX@<'5O)R!E<W-E<F4@
M86YN=6QL871A`%)I8V5V=71O`%)E9&ER:6=I(&$`06=G:6]R;F$@;&$@=FES
M=6%L:7IZ87II;VYE(%!O<G1A;&4Z`$5S<')E<W-I;VYE(')E9V]L87)E`%-C
M87)T82!C;VX@=6X@<F%G:6]N90!.;W1E`%-E<G9E<B!296UO=&D`55),(')E
M;6]T82`H:'1T<#HO+W=W=RYE<V5M<&EO+F-O;2]H;W)D92DZ`$5L:6UI;F$`
M16QI;6EN82!B;&]C8V\`4FEM=6]V:2!&;W)M871T87II;VYE`$5L:6UI;F$@
M<&%I;P!%;&EM:6YA(&EL`$5L:6UI;F$@=71E;G1E`$5L:6UI;F$@=71E;G1E
M.B`E<P!2:7-P961I<V-I($$`4FES<&5D:7-C:2!$80!!;FYU;&QA`$%N;G5L
M;&$@4&%S<W=O<F0`06YN=6QL82!L82!T=6$@4&%S<W=O<F0`4FES=6QT871I
M`%1O<FYA(&%L($5L96YC;R!&:6QT<FD`5&]R;F$@86QL92!/<'II;VYI+@!4
M;W)N82!A;"!%;&5N8V\@4F5G;VQE`$EN=F5R=&D@;&$@0V]N9FEG=7)A>FEO
M;F4`3W!Z:6]N:2!%9&ET;W(@4FEC:"!497AT`%)I9&1L97,`1&5S=')A`%!R
M;W!R:65TX"!D96QL82!27VEG82XN+@!0<F]P<FEE=&$@9&5L;&$@<FEG80!0
M<F]P<FEE=.`@9&5L;&$@<FEG80!2:6=H93H`4F5G;VQA`%)E9V]L82!#;W!I
M871A`%)E9V]L82!%;&EM:6YA=&$`4F5G;VQA($1I<V%T=&EV871A`%)E9V]L
M82!!='1I=F%T80!.;VUE(%)E9V]L80!296=O;&4`17-E9W5I`$UE<W-A9V=I
M(%--4P!386(`4V%L=F$`4V%L=F$@)7,`4V%L=F$@3W!Z:6]N:0!386QV82!)
M;7!O<W1A>FEO;FD`4V%L=F$@;&$@8V]N9FEG=7)A>FEO;F4@9V5N97)A=&4@
M8V]M92!S8W)I<'0@4$A0('-U;&QA(&-A<G1E;&QA('1E;7!O<F%N96$@9&5L
M('1U;R!S97)V97(N`%-A;'9A=&\@;&$@8V]N9FEG=7)A>FEO;F4@)7,N`$%G
M9VEO<FYA;65N=&\@4V-R:7!T`%-C<FEP="!N;VX@86=G:6]R;F%T;RX`4V-R
M:7!T(&%T=&EV871O(&-O;B!S=6-C97-S;RX`4V-R:7!T(&1I<V%T=&EV871O
M(&-O;B!S=6-C97-S;RX`4FEC97)C80!-;W1O<F4@9&D@<FEC97)C80!6:7-T
M;P!396QE>FEO;F$@=6X@8V%M<&\`4VQE>FEO;F$@=6X@9W)U<'!O(&1A(&%G
M9VEU;F=E<F4`4V5L97II;VYA('5N(&YU;W9O('!R;W!R:65T87)I;P!396QE
M>FEO;F$@=6X@<V5R=F5R`%-E;&5Z:6]N82!U;B!U=&5N=&4@9&$@86=G:75N
M9V5R90!396QE>FEO;F$@;&$@8V%R=&5L;&$@9&D@9&5S=&EN87II;VYE`%-E
M;&5Z:6]N82!I(&-A<F%T=&5R:2!D:2!C=6D@:&%I(&)I<V]G;F\@9&%L;&4@
M8V%S96QL92!Q=6D@<V]T=&\N(%!U;VD@<75I;F1I(&-O<&EA<FQE(&4@:6YC
M;VQL87)L92!D86QL82!T97AT87)E82X`4V5L97II;VYA(&EL(&1E;&EM:71A
M=&]R92!D:2!D871A.@!397-C96=L:2!I;"!F;W)M871O(&1E;&QA(&1A=&$Z
M`%-E;&5Z:6]N82!I;"!D96QI;6ET871O<F4@9&5L;"=O<F$Z`%-C96=L:2!I
M;"!F;W)M871O(&1E;&PG;W)A.@!396QE>FEO;F$@9'5E(&-A;7!I(&-O<G)I
M<W!O;F1E;G1I+@!396QE>FEO;F$@:6P@='5O('-C:&5M82!C;VQO<FDN`%-E
M;&5Z:6]N82!L82!L:6YG=6$@8VAE('!R969E<FES8VDZ`$EN=FEA(&EL(')E
M<&]R="!D96P@<')O8FQE;6$`36ET=&5N=&4`4V5N<V]R93H@`%-E='1E;6)R
M90!);7!O<W1I(&D@<V5R=F5R(')E;6]T:2!A:2!Q=6%L:2!V=6]I(&%C8V5D
M97)E(&1A;"!T=6\@<&]R=&%L92X`4V5L97II;VYA(&QA(&QI;F=U82!P<F5F
M97)I=&$@92!I;"!F=7-O(&]R87)I;RX`36]D:69I8V$@;&$@='5A(&%P<&QI
M8V%Z:6]N92!D:2!A=G9I;RP@9VQI('-C:&5M:2!C;VQO<F4L(&5D(&%L=')E
M(&]P>FEO;FD@9&D@=FES=6%L:7IZ87II;VYE+@!);7!O<W1A>FEO;FD@86=G
M:6]R;F%T92!C;VX@<W5C8V5S<V\N`%-C<FEP="!D:2!A9V=I;W)N86UE;G1O
M(&1E;"!S971U<"!D:7-P;VYI8FEL90!3:&]P<&EN9P!"<F5V92!2:6%S<W5N
M=&\`1&5F:6YI86UO(&=L:2!A8V-E<W-I(&1A('1A<W1I97)A('!E<B!I(&QI
M;FL_`$UO<W1R80!-;W-T<F$@4V-R:7!T($%T=&EV;P!-;W-T<F$@4V-R:7!T
M($%T='5A;&4`36]S=')A(&PG=6QT:6UO(&QO9VEN(&%L;"=A8V-E<W-O/P!-
M;W-T<F$@=&%B96QL82!O<&5R87II;VYI(&YE;&QA(&)A<G)A(&1E;"!M96YU
M/P!-;W-T<F$@:6P@)7,@365N;R!S=6QL82!S:6YI<W1R83\`36]S=')A(&QE
M(%!R;W!R:65TX"!486)E;&QA($-E;&QA`$UO<W1R82!L92!0<F]P<FEE=.`@
M5&%B96QL80!-;W-T<F$@;&4@4')O<')I973@(%1A8F5L;&$@4FEG80!!8W%U
M87IZ;VYI`$%C<75A>GIO;FD@82!"<F5V90!!8W%U87IZ;VYI(%1A<F1I`$1I
M;65N<VEO;F4`4V%L=&$@36%N=71E;GII;VYE`%!R;V9O;F1I=&$G(&1I(&YE
M=F4Z(`!3<&%Z:6%T=7)A`%-P86T`0V%R871T97)E(%-P96-I86QE`$1I=FED
M:2!#96QL80!$:79I9&D@8V]L;VYN80!$:79I9&D@4FEG80!3=&%N9&%R9`!3
M=&%T;P!%<V-I(&1A:2!F:6QT<FD@<V4@<75E<W1A(')E9V]L82!C;W)R:7-P
M;VYD93\`1&]M`$]G9V5T=&\@9&5L(&UE<W-A9V=I;R!D:2!V86-A;GIE.@!/
M9V=E='1O`%-O='1O<V-R:79I`%-U8V-E<W-O`%-A;'9A=&\@;&$@8V]N9FEG
M=7)A>FEO;F4N`%-C<FET=&\@8V]N('-U8V-E<W-O("5S`%)I87-S=6YT;P!!
M;&)A`%1R86UO;G1O`$%L8F$`06QB82]4<F%M;VYT;P!!;&)A.B``5')A;6]N
M=&\`5')A;6]N=&\Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T;P!4+51E;7!E<W1A
M`%0M5&5M<&5S=&4`4')O<')I973@(%1A8F5L;&$`4')O<')I973@(%1A8F5L
M;&$`1&5S=&EN87II;VYE.@!!='1I=FETX`!496UP97)A='5R82!U;'1I;6$@
M;W)A.B``5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!!;6UI;FES=')A>FEO
M;F4@5&5M<&QA=&4`4V]L;R!497-T;P!!;&QI;F5A;65N=&\@=&5S=&\`5&5S
M=&\@:6X@86QT;P!':6\`1W)A>FEE(&1I(&%V97(@=7-A=&\@:6P@<VES=&5M
M82X`26P@9')I=F5R(&AA(')I<W!O<W1O.B``3"=I9&5N=&ETX"`B)7,B(&4G
M('-T871A(&5L:6UI;F%T82X`26P@<V5R=F5R("(E<R(@92<@<W1A=&\@96QI
M;6EN871O+@!);"!S97)V97(@(B5S(B!E)R!S=&%T;R!S86QV871O+@!,82!R
M:6-H:65S=&$@9&D@<F5G:7-T<F%Z:6]N92!P97(@)7,@Z"!S=&%T82!E;&EM
M:6YA=&$N`$EL(&UO9'5L;R!W96%T:&5R+F-O;2!N;VX@Z"!D:7-P;VYI8FEL
M92X`17)R;W)E(&YE;"!A='1I=F%Z:6]N92!D96P@<V-R:7!T+@!%<G)O<F4@
M;F5L(&1I<V%T=&EV87II;VYE(&1E;"!S8W)I<'0N`%%U97-T;R!E)R`E<RX`
M5'5O;F\`5&EC:V5T`$=E<W1I;VYE(&1E;"!496UP;P!&;W)M871O($]R80!4
M:71O;&\`00!/9V=I`$1O;6%N:0!!;'1O`$UA<@!54DP`55),.@!);7!O<W-I
M8FEL92!C87)I8V%R92!L92!D969I;FEZ:6]N:2!D:2`E<RX`4V]T=&]L:6YE
M80!!;FYU;&QA(&QE($UO9&EF:6-H90!);F1E9FEN:71O`%5N:73@`$5L:6UI
M;F$@16QE;65N=&\@0V]R<F5N=&4`16QI;6EN82!#;VQO<F4`06=G:6]R;F$`
M06=G:6]R;F$@)7,`06=G:6]R;F$@=71E;G1E`%-C<FEP="!D:2!A9V=I;W)N
M86UE;G1O(&5L:6UI;F%T;RX`06=G:6]R;F$`3G5M97(@<F]M86YI(&%L=&D`
M06UM:6YI<W1R87II;VYE(%5T96YT:0!296=I<W1R87II;VYE(%5T96YT90!)
M<V-R:7II;VYE(%5T96YT92!E)R!S=&%T;R!D:7-A8FEL:71A=&\@<&5R('%U
M97-T;R!S:71O+@!.;VUE(%5T96YT90!.;VUE(%5T96YT93H`3F]M92!5=&5N
M=&4Z`%5T96YT:2!N96P@<VES=&5M83H`5F%C86YZ90!-;V1I9FEC82!686-A
M;GIE`$UE<W-A9V=I;R!686-A;GIE`%9A8V%N>F4@;F]N('-O;F\@<W5P<&]R
M=&%T92!N96P@871T=6%L92!D<FEV97(@9&5I(&9I;'1R:2X`5F%R:6%B:6QE
M`$-O;G1R;VQL;R!697)S:6]N90!!;&QI;F5A;65N=&\`4FEE;7!I;65N=&\@
M5F5R=&EC86QE`%9E<G1I8V%L93H`36]L=&\@06QT;P!6:7-U86QI>GIA('5N
M82!P86=I;F$@=V5B(&5S=&5R;F$`5FES:6)I;&ETX`!6:7-I8FEL:73@.B``
M365R`%!R979I<VEO;F4@365T96\`5V5B`$)E;G9E;G5T;P!"96YV96YU=&\@
M82`E<P!"96YV96YU=&\L("5S`$EN9&ER:7IZ:2!D96QL82!,:7-T82!"7VEA
M;F-A.@!#:&4@87!P;&EC87II;VYE("5S(&1E=F4@;6]S=')A<F4@9&]P;R!I
M;"!L;V=I;C\`0V]S82!E)R!C87)A='1E<F4@9&5L:6UI=&%T;W)E`$-O<V$@
M92<@:6P@8V%R871T97)E('9I<F=O;&5T=&4_`$QI<W1A(&)I86YC80!-;V1I
M9FEC82!L82!,:7-T82!":6%N8V$`5VAI=&5L:7-T(&YO;B#H('-U<'!O<G1A
M=&$`26YD:7)I>GII(&YE;&QA($QI<W1A($)I86YC83H`3&%R9VAE>GIA`$%M
M<&EE>GIA(&1E;&QA('1A8F5L;&$`56YI=.`@3&%R9VAE>GIA`$QA<F=H97IZ
M83H`5F5N=&\Z`%9E;G1O.B``04$`4VDL('-O;F\@9"=A8V-O<F1O`$QA('-E
M<W-I;VYE(.@@<W1A=&$@=&5R;6EN871A+@!$979I('-P96-I9FEC87)E(&EL
M('-E<G9E<B!D82!E;&EM:6YA<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E
M<FYA;64@9&$@<FEM=6]V97)E+@!$979I('-P96-I9FEC87)E(&QO('5S97)N
M86UE(&1A(')I;75O=F5R92X`3V-C;W)R92!S<&5C:69I8V%R92!A;&UE;F\@
M=6X@:6YD:7)I>GIO(&5M86EL('!E<B!I;"!Q=6%L92!A='1I=F%R92!L92!R
M96=O;&4@9&D@=F%C86YZ80!$979I('-P96-I9FEC87)E(&QO('5S97)N86UE
M(&1A(&%G9VEU;F=E<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@
M9&$@86=G:6]R;F%R92X`5'5O($EN9&ER:7IZ;R!%;6%I;`!4=6\@26YD:7)I
M>GIO($5M86EL`%9O<W1R82!I;F9O<FUA>FEO;F4`26P@='5O(&YO;64`26P@
M='5O(&)A8VME;F0@9&D@875T96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A(&QA
M(&5L96YC87II;VYE(&1E9VQI('5T96YT:2P@;R!L82!C87)A='1E<FES=&EC
M82#H('-T871A(&1I<V%B:6QI=&%T82!P97(@<75A;&-H92!M;W1I=F\N`$EL
M('1U;R!B<F]W<V5R(&YO;B!H82!Q=65S=&$@8V%P86)I;&ET82<N`$EL('1U
M;R!F=7-O(&]R87)I;R!A='1U86QE.@!)9&5N=&ETX"!D:2!$969A=6QT`$EL
M('1U;R!N;VUE.@!)('1U;VD@<V5R=F5R(')E;6]T:3H`6TYE<W-U;B!/9V=E
M='1O70!;1&]C=6UE;G1O(&1I(&1E<V-R:7II;VYE(&1E;"!P<F]B;&5M85T`
M6TUO<W1R82!497-T;R!Q=6]T871O("T`26YD:7)I>GIO*&DI(&%I('%U86QI
M(&EN;VQT<F%R93H`7TEN9&ER:7IZ:2!A:2!Q=6%L:2!N;VX@<FES<&]N9&5R
M93H`7T%M;6EN:7-T<F%Z:6]N90!?3&ES=&$@;F5R80!?1&%T851R964`7T5L
M:6UI;F$@4FEG80!?16QI;6EN82!M97-S86=G:6\@8V]M<&QE=&%M96YT90!?
M26YS97)I<V-I(&]G;FD@:6YD:7)I>GIO('-U('5N82!N=6]V82!R:6=A.@!?
M26YO;'1R80!?1W)U<'!I`%]!:75T;P!0<F]P<FEE=.`@9&5L;"=?26UM86=I
M;F4N+BX`7TUA;G1I96YI('5N82!C;W!I82!D96D@;65S<V%G9VD@:6X@<75E
M<W1O(&%C8V]U;G0_`%]&:6YE('-E<W-I;VYE`%]-;V1I9FEC82!,:6YK+BXN
M.@!?4W!O<W1A(&UE<W-A9V=I(&%L;&$@8V%R=&5L;&$Z`%]-:65I(&EN9&ER
M:7IZ:2!D:2!P;W-T83H`7T]P>FEO;FD`7U!E<FUE<W-I`%]%;&EM:6YA($QI
M;FLN+BX`7U-C<FEP=`!0<F]P<FEE=.`@9&5L;&$@7U1A8F5L;&$`7U5T96YT
M:0!?5F%C86YZ90!?3&ES=&$@8FEA;F-A`&4`8V%L;6\`8V%M<&\`9&%L;&4@
M)7,@*"5S*2!A;&QE("5S("5S`&QI;F5E70!C;W)R:7-P;VYD90!N;VUE`&\`
M<&5R8V5N=&\`<&EX96QS`'-C<FEP="!P<F]C;6%I;"!G96YE<F%T;R!D82!)
M;F=O`&%U;65N=&%N9&\G`&9I;'1R;R!S:65V92!G96YE<F%T;R!D82!);F=O
M`&-O<W1A;G1E`&1I9VET82!L82!P87-S=V]R9"!D=64@=F]L=&4@<&5R(&-O
M;F9E<FUA<F4`=V5A=&AE<BYC;VT``````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O:V]?2U(O````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P
M,3<V,C<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]K;U]+
M4B],0U]-15-304=%4R\`````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S0W`#`R,30Q-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEN9V\O;&]C86QE+VMO7TM2+TQ#7TU%4U-!1T53+VEN9V\N;6\`````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-C$U,C<`,3`T,3<S-C(W-#<`,#(R-S$U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
MWP$``!P````4#P``@0(```P>````````$"@```\````1*```"````"$H```+
M````*B@```P````V*```!````$,H```#````2"@``"@```!,*```$@```'4H
M```(````B"@```4```"1*```$0```)<H```A````J2@```,```#+*```#P``
M`,\H```(````WR@```@```#H*```&0```/$H```3````"RD```<````?*0``
M#````"<I```.````-"D```4```!#*0``!0```$DI```*````3RD```,```!:
M*0``#@```%XI```4````;2D```\```""*0``'P```)(I```(````LBD``!0`
M``"[*0``#0```-`I```%````WBD``#D```#D*0``!@```!XJ```1````)2H`
M``H````W*@``$````$(J```#````4RH```@```!7*@``"0```&`J```.````
M:BH``!,```!Y*@``%0```(TJ```$````HRH```0```"H*@``!@```*TJ```1
M````M"H```<```#&*@``!````,XJ```&````TRH```T```#:*@``$P```.@J
M```(````_"H```8````%*P``%0````PK```'````(BL```X````J*P```@``
M`#DK```*````/"L```\```!'*P``#0```%<K```/````92L```T```!U*P``
M"0```(,K```&````C2L```8```"4*P``#@```)LK```.````JBL```4```"Y
M*P``*@```+\K```3````ZBL```P```#^*P``$`````LL```1````'"P```4`
M```N+```!0```#0L```&````.BP```<```!!+```$````$DL```(````6BP`
M``0```!C+```!P```&@L```*````<"P```X```![+```*0```(HL```&````
MM"P```T```"[+```$0```,DL```.````VRP```T```#J+````P```/@L```-
M````_"P```(````*+0``"@````TM```%````&"T```0````>+0``#@```",M
M```(````,BT```\````[+0``#P```$LM```'````6RT``!````!C+0``!@``
M`'0M```)````>RT``!````"%+0``"P```)8M```-````HBT``!D```"P+0``
M"@```,HM```9````U2T``!8```#O+0``!P````8N```5````#BX``"$````D
M+@``)0```$8N```1````;"X``!0```!^+@``"P```),N```O````GRX```D`
M``#/+@``"@```-DN```(````Y"X```\```#M+@``.@```/TN```O````."\`
M`"8```!H+P``0P```(\O```(````TR\```L```#<+P``!````.@O```'````
M[2\``!<```#U+P``$0````TP```*````'S````(````J,```!0```"TP```)
M````,S````T````],```"0```$LP```'````53````X```!=,```&````&PP
M```%````A3```!````"+,```$````)PP```/````K3````L```"],```#P``
M`,DP```,````V3````\```#F,```#@```/8P```&````!3$```X````,,0``
M"````!LQ```>````)#$``"$```!#,0```P```&4Q```(````:3$```P```!R
M,0``$P```'\Q```9````DS$``!L```"M,0``#@```,DQ```+````V#$```P`
M``#D,0``#0```/$Q```1````_S$```<````1,@``"@```!DR```'````)#(`
M``@````L,@``#0```#4R```&````0S(```0```!*,@``!P```$\R```"````
M5S(```8```!:,@``!````&$R```1````9C(``"(```!X,@``#````)LR```*
M````J#(```4```"S,@``#P```+DR```2````R3(```L```#<,@``*0```.@R
M```D````$C,``"8````W,P``$@```%XS```*````<3,```\```!\,P``$```
M`(PS```.````G3,```D```"L,P``"@```+8S```)````P3,``!(```#+,P``
M$````-XS```1````[S,```\````!-```%````!$T```,````)C0```P````S
M-```#P```$`T```5````4#0``"D```!F-```*@```)`T```F````NS0``"<`
M``#B-```*0````HU```J````-#4``!$```!?-0``$@```'$U```3````A#4`
M`!0```"8-0``%@```*TU```7````Q#4``!````#<-0``$0```.TU```3````
M_S4``!(````3-@``!@```"8V```'````+38```4````U-@``%@```#LV```$
M````4C8```0```!7-@``!P```%PV```.````9#8```P```!S-@``#````(`V
M```-````C38``!(```";-@``#P```*XV```(````OC8```X```#'-@``%@``
M`-8V```1````[38```8```#_-@``!`````8W```0````"S<``!H````<-P``
M!@```#<W```'````/C<```L```!&-P``$P```%(W```3````9C<``!,```!Z
M-P```@```(XW```$````D3<```T```"6-P``&````*0W```%````O3<```8`
M``##-P``#P```,HW```#````VC<```H```#>-P``"P```.DW```'````]3<`
M``8```#]-P``"@````0X```'````#S@```0````7.```"0```!PX```.````
M)C@```P````U.```!P```$(X```$````2C@```<```!/.```!0```%<X```(
M````73@``!,```!F.```!````'HX```"````?S@``#,```"".```,P```+8X
M```X````ZC@```0````C.0``!0```"@Y```(````+CD``!$````W.0``#@``
M`$DY```'````6#D``!\```!@.0``!P```(`Y```.````B#D```P```"7.0``
M#````*0Y```%````L3D``!$```"W.0``#0```,DY```'````USD```@```#?
M.0``%0```.@Y```%````_CD``!0````$.@``!````!DZ```'````'CH``!X`
M```F.@``%````$4Z```%````6CH```8```!@.@``*````&<Z```H````D#H`
M`"D```"Y.@``!P```.,Z```A````ZSH```X````-.P``$P```!P[```7````
M,#L```L```!(.P``!0```%0[```6````6CL``!$```!Q.P``%````(,[```%
M````F#L``!(```">.P``!````+$[```.````MCL```X```#%.P``!0```-0[
M```$````VCL```L```#?.P``#````.L[```-````^#L```P````&/```"0``
M`!,\```2````'3P```0````P/```#````#4\```-````0CP```8```!0/```
M!````%<\```.````7#P``!0```!K/```:0```(`\```:````ZCP``!<````%
M/0``%P```!T]```;````-3T``!\```!1/0``$P```'$]```)````A3T``!X`
M``"//0``)0```*X]```@````U#T``"0```#U/0``(````!H^```$````.SX`
M`!````!`/@``'````%$^```H````;CX```<```"7/@``$P```)\^```7````
MLSX```H```#+/@``#````-8^```)````XSX```T```#M/@``"P```/L^```'
M````!S\```8````//P``"0```!8_```'````(#\```<````H/P``"P```#`_
M```0````/#\``!````!-/P``!0```%X_```$````9#\```D```!I/P``"@``
M`',_```?````?C\``!L```">/P``/@```+H_```C````^3\``!\````=0```
M/0```#U````A````>T```!P```"=0```!0```+I````0````P$````(```#1
M0```$@```-1````#````YT```!````#K0````P```/Q````O`````$$``"``
M```P00``)````%%!```E````=D$``"````"<00``)@```+U!```)````Y$$`
M``P```#N00``%P```/M!```.````$T(```T````B0@``&@```#!"```'````
M2T(```L```!30@``$P```%]"```3````<T(```P```"'0@``"````)1"```4
M````G4(```X```"R0@``$````,%"```'````TD(```<```#:0@``!@```.)"
M```'````Z4(```T```#Q0@``"P```/]"```5````"T,``"`````A0P``'```
M`$)#```)````7T,```X```!I0P``%0```'A#```%````CD,``!(```"40P``
M"@```*=#```&````LD,```P```"Y0P``"@```,9#```"````T4,```8```#4
M0P```P```-M#``!%````WT,``!D````E1```10```#]$```P````A40``"8`
M``"V1```)0```-U$```P`````T4``!(````T10``$P```$=%```0````6T4`
M``D```!L10``<P```'9%```K````ZD4``!<````61@``%@```"Y&```/````
M148``$````!51@``'P```)9&```2````MD8```P```#)1@``$````-9&```3
M````YT8``!T```#[1@``#P```!E'```/````*4<```H````Y1P``"P```$1'
M```:````4$<``"(```!K1P``"````(Y'```%````ET<``!0```"=1P``"```
M`+)'```/````NT<``!@```#+1P``%````.1'```(````^4<```\````"2```
M%````!)(```*````)T@```8````R2```!````#E(```"````/D@```<```!!
M2```!@```$E(```'````4$@```4```!82```<`$``%Y(```,````STD```<`
M``#<20``!P```.1)```'````[$D```<```#T20``!0```/Q)```7`````DH`
M`!4````:2@``!P```#!*```)````.$H```L```!"2@``&0```$Y*```$````
M:$H``!,```!M2@``#P```(%*```+````D4H``!0```"=2@``#0```+)*```$
M````P$H```8```#%2@``!````,Q*```*````T4H```0```#<2@``!0```.%*
M```)````YTH```@```#Q2@``"P```/I*```'````!DL``!<````.2P``"P``
M`"9+```1````,DL```T```!$2P```P```%)+```7````5DL```,```!N2P``
M#````')+```$````?TL```D```"$2P``"0```(Y+```$````F$L```@```"=
M2P``$@```*9+```/````N4L```\```#)2P``!````-E+```$````WDL```0`
M``#C2P``"0```.A+```$````\DL```0```#W2P``!````/Q+```+`````4P`
M``P````-3```!````!I,```$````'TP``!(````D3```!````#=,```-````
M/$P```0```!*3```!@```$],```'````5DP```<```!>3```!P```&9,```'
M````;DP```8```!V3```!@```'U,```$````A$P```\```")3```#@```)E,
M```$````J$P``!4```"M3```%````,-,```'````V$P```T```#@3```"P``
M`.Y,```$````^DP```,```#_3```!@````--```$````"DT```D````/30``
M!````!E-```$````'DT```<````C30``!P```"M-```$````,TT``"L````X
M30``!@```&1-```+````:TT```X```!W30``"@```(9-```+````D4T```8`
M``"=30``!@```*1-```"````JTT```D```"N30``!````+A-```$````O4T`
M``D```#"30``!````,Q-```$````T4T```@```#630``!````-]-```+````
MY$T```0```#P30``!P```/5-```)````_4T```<````'3@``!P````].```0
M````%TX```<````H3@``#````#!.```,````/4X```L```!*3@``$P```%9.
M```P````:DX``"<```";3@``"P```,-.```)````STX```4```#93@``*@``
M`-].```(````"D\```P````33P``"````"!/```)````*4\``#$````S3P``
M-0```&5/```G````FT\``$,```##3P``"`````=0```+````$%````0````<
M4```"0```"%0```,````*U````X````X4```!P```$=0```"````3U````8`
M``!24```"````%E0```)````8E````P```!L4```!@```'E0```+````@%``
M``T```",4```!````)I0```)````GU````D```"I4```"````+-0```+````
MO%````D```#(4```!````-)0```#````UU````\```#;4```!@```.M0```-
M````\E````8`````40``$P````=1```3````&U$```0````O40```P```#11
M```+````.%$``!````!$40``$````%51```5````9E$```T```!\40``"0``
M`(I1```)````E%$```L```">40``#@```*I1```$````N5$```D```"^40``
M!````,A1```$````S5$```D```#240``!@```-Q1```$````XU$```0```#H
M40``!````.U1```$````\E$```8```#W40``!@```/Y1```>````!5(```<`
M```D4@``"P```"Q2```%````.%(```8````^4@``"0```$52```%````3U(`
M`!,```!54@``#@```&E2```3````>%(```X```",4@``!@```)M2```-````
MHE(```P```"P4@``#@```+U2```(````S%(```D```#54@``"P```-]2```/
M````ZU(```P```#[4@``$`````A3```(````&5,``!`````B4P``"0```#-3
M```'````/5,```P```!%4P``#@```%)3```7````85,``!<```!Y4P``%P``
M`)%3```7````J5,``!@```#!4P``&````-I3```,````\U,```P`````5```
M#`````U4```,````&E0```X````G5```#@```#94```,````150```P```!2
M5```#@```%]4```.````;E0```@```!]5````P```(94```$````BE0``!0`
M``"/5````P```*14```#````J%0```0```"L5```"P```+%4```)````O50`
M``D```#'5```"P```-%4```(````W50```\```#F5```!````/94```1````
M^U0``"`````-50``$P```"Y5```(````0E4```0```!+50``"P```%!5```;
M````7%4```8```!X50``"````']5```/````B%4```T```"850``"P```*95
M```0````LE4```(```##50``!````,95```0````RU4``!8```#<50```P``
M`/-5```(````]U4```T`````5@```P````Y6```)````$E8```D````<5@``
M!@```"96```&````+58```@````T5@``!````#U6```$````0E8```L```!'
M5@``"P```%-6```)````7U8```D```!I5@``!````'-6```(````>%8```@`
M``"!5@``"P```(I6```-````EE8```0```"D5@``!@```*E6```C````L%8`
M`!P```#45@``(0```/%6```-````$U<```0````A5P``!````"97```'````
M*U<```<````S5P``!````#M7```1````0%<```@```!25P``"P```%M7```)
M````9U<```0```!Q5P``!````'97```)````>U<```D```"%5P``!````(]7
M```$````E%<``!D```"95P``!@```+-7```3````NE<```0```#.5P``!@``
M`--7```3````VE<```D```#N5P``"````/A7```$`````5@``"0````&6```
M(0```"M8```>````35@```@```!L6```$````'58```)````AE@```D```"0
M6```$````)I8```/````JU@```D```"[6```%@```,58```1````W%@``!0`
M``#N6```!@````-9```,````"ED```0````760``!P```!Q9```'````)%D`
M``,````L60``!````#!9```+````-5D```L```!!60``#0```$U9```+````
M6UD```D```!G60``$@```'%9```$````A%D```T```")60``"0```)=9```$
M````H5D```D```"F60``"0```+!9```)````NED``#L```#$60``$P````!:
M```.````%%H```X````C6@``&0```#):```?````3%H``!@```!L6@```P``
M`(5:```A````B5H```X```"K6@``#@```+I:```.````R5H``!````#86@``
M!````.E:```-````[EH```8```#\6@``&@````-;```$````'EL```T````C
M6P``#@```#%;```'````0%L```<```!(6P``!P```%!;```(````6%L```L`
M``!A6P``!````&U;```$````<EL```@```!W6P``!````(!;```$````A5L`
M``8```"*6P``!P```)%;```'````F5L```0```"A6P``!@```*9;```$````
MK5L```D```"R6P``&````+Q;```>````U5L``"T```#T6P``'@```")<```?
M````05P``#\```!A7```*0```*%<```8````RUP```0```#D7```#0```.E<
M```)````]UP```X````!70```@```!!=```1````$UT```,````E70``+0``
M`"E=```>````5UT``!L```!V70``)````))=```H````MUT``"$```#@70``
M!`````)>```1````!UX``!`````97@``!````"I>```$````+UX``!4````T
M7@``"0```$I>```)````5%X```T```!>7@``$````&Q>```/````?5X```@`
M``"-7@``$````)9>```)````IUX```D```"Q7@``!P```+M>```$````PUX`
M``0```#(7@``!````,U>```6````TEX```X```#I7@``#P```/A>```7````
M"%\``!<````@7P``"````#A?```2````05\```\```!47P``!````&1?```)
M````:5\```D```!S7P``!0```'U?```*````@U\```T```".7P```@```)Q?
M```$````GU\```(```"D7P``/0```*=?```4````Y5\``#X```#Z7P``*0``
M`#E@```E````8V```"4```")8```+````*]@```,````W&````H```#I8```
M!````/1@```%````^6```',```#_8```)P```'-A```,````FV$```P```"H
M80``"@```+5A```?````P&$``!8```#@80``#0```/=A```+````!6(```\`
M```18@``#````"%B```3````+F(```X```!"8@``!@```%%B```*````6&(`
M``D```!C8@``$@```&UB```A````@&(```8```"B8@``!@```*EB```.````
ML&(```H```"_8@``#@```,IB```.````V6(``!,```#H8@``"@```/QB```-
M````!V,```P````58P``"@```")C```#````+6,```0````Q8P``!````#9C
M```&````.V,```0```!"8P``"0```$=C```%````46,```$````S`0``K`$`
M`+@!```'`0``WP$``(4!``"^`0``=``````````P`0``\0````````!,````
M]````'H!``!$````/0``````````````+P$``"H!```6`0``!`$````````/
M`0``@````/P`````````ZP```-,!``"*`0``)@$``%T!``#!`0``````````
M``!D`0``&@$````````!`0````````````",`0``"`$``*0!``"5````:`$`
M`,X```"_````5`````````##`0``60$``"```````````````"D````"````
M'P$``,L!````````E@$``+,!```Z`0``>0$``'8!````````#0```"$```"]
M`0```````(8!``#X````!0```-H````E````6`````8``````````````!L!
M``"<`0``,P```#<!``!#`0``J0```&<!``!D````YP```"X!``!C`0``````
M`-````!?`0```@$```````"T````N0$``"$!``!5`0```````)T!``"!`0``
M`````%$```!!`0``]@```&D```"%`````````'L```!"`````P````````#5
M`0``>`$``%D```````````````````!6`0``?````,H!``!U````%`$`````
M``!W`0```````"T```#_`````````*8!```U`0``Z@```*X```"V````3`$`
M`'`````.`0```````.$```#[````SP````````````````````````"\````
MQP$``#\`````````TP```'(!````````[@````````"Q`````````!4!````
M````]P````````#-`0````````````!L`0``@P````@`````````1@```,H`
M````````@@$````````7````=0$``*(````K`0``Y````*8```#2````````
M`'X```"0`0``'@```'$!```X`0``J@```.(````,`0``/@$``&<`````````
M$P$````````Z``````````````!/`0``3P```&(```"V`0``R0$``,4```#"
M````_@```'P!````````"@```)X!```%`0``L0$``#D!``#$`0``"0$``*D!
M``"/`0``HP$``*0```````````````````!5````;@```&4````<````2P$`
M``````"]````2`$``$(!```#`0``#````*L```#Z````FP$```````"7````
M[0```-(!``">`````````)4!````````+0$```````!O`````````%@!```R
M`0``Q@$```````"T`0``OP$``,````#!````4`$``!L`````````N@$`````
M````````>0```-D```!J`0``&``````````````````````````=`0``H0$`
M`%P!`````````````+H````2````T0```%X``````````````)D````G````
M/@```$````!3`````````+L````F````<P```#0!```D`0``3@$``*@!``!O
M`0``7@$``)(!```*`0``%P$``,\!```P````+````.4```!^`0``-@$``-<!
M``!$`0``(P$``$X```#(`0``1@$``$<!````````1P```.8``````0``RP``
M`&L`````````%0```#8````2`0``L@$`````````````WP```$4```"4`0``
M`````&,```"1`````````-H!````````H```````````````&0````````!Q
M````KP`````````+````(@$``+L!``"W`````````#(```!7````O`$``%(`
M``#8`0``BP````````!(````K0```+<!``"E````_0```$4!````````GP``
M`'@```"G`0``C0```"L```!S`0```````&8```"B`0``00````````#6`0``
M``````````"9`0``T0$````````=````[```````````````D0$``,D`````
M``````````````"'`````````)@```"P`0``#@```)\!``"U````(@```(H`
M``!1`0```````(P```"G````KP$``(,!````````W`$``-D!````````$`$`
M`!\```!0````4@$``*H!````````PP```%,!``!@`````````(0````]`0``
M`````!D!````````-0```"<!``"(`0```````$`!``#;`````````*L!````
M````$P```"4!````````X````(<!``!+````\`````````!E`0``````````
M``"(`````````%H`````````/`$```````"4````(`$``'(```!M````\P``
M`(0!``!]`0``6P```,(!``"L`````````-T```"+`0``(P```-8```!H````
M"P$``%0!```L`0``!P````````#&``````````0``````````````#\!``!#
M````;@$``$T```":`0``I0$```````!@`0``G````&L!````````+@``````
M```Q`0``@`$``&$!``"=````;````-T!``!B`0``L````+D```#%`0``30$`
M`````````````````#<``````````````*T!``"X````6@$``'0!``#U````
MC@```+X`````````D```````````````7P```'\```!P`0``A@```#D`````
M`````````&$```#Y`````````($`````````W@```!H````-`0``/````.\`
M``#'````&`$``*X!``#8````R````,0```#.`0``20$``),`````````````
M``````!6````?P$``-X!``#4`0```````.D````[`0``70```-<`````````
MDP$``(\```#5````T`$``,P!``#R````*0$````````4````D@```$H!```T
M````H`$``)<!````````*`$``-P````)````B0````````#H````LP```*,`
M```0````7`````````#;`0```````&H``````````````,`!```6````@@``
M`'<````D`````````)@!```O````U`````````!;`0``?0```,T```#C````
M$0```)8`````````;0$`````````````H0```+(```"U`0``2@```%<!``#,
M```````````````1`0``````````````````B0$``(X!``!)````:0$``!P!
M````````FP```)H````>`0```````"H```!V````.````&8!```H````>P$`
M``\```"H`````````#L```"-`0``!@$``#$```!Z`````"`H06-C97-S:V5Y
M("5S*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%N9``@
M;W(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E
M<R!A;')E861Y(&5X:7-T<RX`,C0@:&]U<G,`04TO4$T`06)O=70@=&AI<R!E
M9&ET;W(`06-T:6]N(&9O<B!B;&%C:VQI<W1E9"!A9&1R97-S97,Z`$%D9`!!
M9&0@82!N97<@=7-E<CH`061D('!A:7(`061D('5S97(`061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(%-E='1I;F=S`$%D9')E<W,`061D
M<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%L:6=N`$%L:6=N;65N
M=#H`06QL`$%L;"!F;W5R('-I9&5S`$%L;"!O9B!T:&4@9F]L;&]W:6YG`$%L
M=&5R;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M`$%N<W=E<F5D`$%N>2!O9B!T:&4@9F]L;&]W:6YG`$%P<&QY($9I;'1E<G,`
M07!R:6P`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!"
M86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F-C`$)I<G1H9&%Y`$)L86-K
M;&ES=`!";&%C:VQI<W0@161I=`!";&%C:VQI<W1E9"!!9&1R97-S`$)L86-K
M;&ES=&5D($%D9')E<W-E<P!";V1Y`$)O;&0`0F]R9&5R`$)O<F1E<B!T:&EC
M:VYE<W,Z`$)O<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T960@3&ES=`!#7V5L
M;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;F-E;`!#86YC96P@4')O8FQE
M;2!297!O<G0`0V%P=&EO;@!#87-E(%-E;G-I=&EV90!#8P!#96QL(%!H;VYE
M`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE
M<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96YT97(`0VAA;F=E`$-H86YG
M97,@<V%V960N`$-H96-?:R!,:6YK+BXN`$-H:6YA`$-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#;&5A<B!-4T]F9FEC92!T
M86=S`$-L;W-E(%=I;F1O=P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B
M;W)D97)S`$-O;&]R`$-O;',Z`$-O;6EC<P!#;VUP86YY`$-O;F9I<FT@4&%S
M<W=O<F0`0V]N=&%I;G,`0V]P>0!#;W!Y("5S`$-O<'D@;V8@)7,`0V]P>2!S
M96QE8W1I;VX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&YE=R!F;VQD97(`
M0W5R<F5N="!54DP@:7,`0W5R<F5N="!S='EL90!#=70`0W5T('-E;&5C=&EO
M;@!$1`!$25-!0DQ%1#H@`$1A:6QY`$1A=&4`1&5?;&5T92!#;VQU;6X`1&5C
M96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT
M`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T92`E<P!$96QE=&4@0V]N
M9&ET:6]N`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&UE<W-A
M9V4@8V]M<&QE=&5L>0!$96QE=&4@<F]W`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D`$1E;&EV97(@
M:6YT;R!M>2!)3D)/6`!$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(&-O<'D@
M=&\`1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R961I<F5C="!T;P!$96QI
M=F5R('1O(&9O;&1E<@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO
M;@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$:7)E8W1O<GD`1&ES86)L92`E<P!$:7-A8FQE9`!$:7-P;&%Y($]P
M=&EO;G,`1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE;B!E86-H
M(&9I;'1E<B!I<R!A<'!L:65D/P!$;R!?;F]T('-E;F0@<F5S<&]N<V5S('1O
M(&)U;&L@;W(@;&ES="!M97-S86=E<P!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O=VYL
M;V%D`$1O=VYL;V%D("5S`$5D:70`161I="`E<P!%9&ET(%!E<FUI<W-I;VYS
M(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%;&5M96YT+BXN`$5M`$5M86EL
M`$5M;W1I8V]N<P!%;7!T>2!R97-U;'0N`$5N86)L92`E<P!%;F%B;&5D`$5N
M;&%R9V4@161I=&]R`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<G)O<@!%
M=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU
M=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`
M17AA;7!L92!V86QU97,Z`$5X:7-T:6YG(%)U;&5S`$5X:7-T<P!%>'!A;F0@
M4VED96)A<@!&1R!#;VQO<@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&96)R
M=6%R>0!&:6QE($UA;F%G97(`1FEL=&5R($%L;"!-97-S86=E<P!&:6QT97(@
M3VYL>2!3965N($UE<W-A9V5S`$9I;'1E<B!/;FQY(%5N<V5E;B!-97-S86=E
M<P!&:6QT97(@3W!T:6]N<P!&:6QT97(@4G5L90!&:6QT97(@4G5L97,`1FEL
M=&5R(%]2=6QE<P!&:6QT97(@;F]T(&9O=6YD+@!&:6QT97)S`$9O;G0@0V]L
M;W(`1F]R=V%R9`!&;W)W87)D<P!&;W)W87)D<R!%9&ET`$9R86UE<P!&<F]M
M`$=E<FUA;GD`1V\`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5R
M92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(;VUE($%D9')E<W,`
M2&]M92!0:&]N90!(;W)D90!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P
M861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!)7VYS97)T(%)O=R!"969O<F4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E
M>'0`261E;G1I='DG<R!N86UE.@!);6%G92!0<F5V:65W.@!);6%G92!54DP`
M26UA9V4@55),.@!);7!O<G1A;G0`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R
M=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC<F5A<V4@26YD96YT
M`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B
M;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@
M8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN
M(&)E9F]R90!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A
M<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`
M26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`271A;&EC
M`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*=6QY`$IU
M;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF
M>2!,969T`$IU<W1I9GD@4FEG:'0`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A
M;B`H155#+4M2*0!,86YG=6%G90!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN
M.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA>6]U=`!,969T`$QI
M<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]G
M(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]W97(@9W)E96L@;&5T=&5R<P!,
M;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`34T`36%I
M;`!-86ME(&QI;E]K+BXN`$UA<E]K(&UE<W-A9V4@87,@9&5L971E9`!-87)C
M:`!-87)G:6X`36%T8VAI;F<@9FEE;&1S`$UA>0!-96YU(&UO9&4Z`$UE<F=E
M(&-E;&QS`$UE<W-A9V4`36ED9&QE`$UO9&EF>2!54DP`36]N=&AL>0!-;W9E
M`$UO=F4@1&]W;@!-;W9E(%)U;&4@1&]W;@!-;W9E(%)U;&4@57``36]V92!5
M<`!.86UE`$YE='=O<FL`3F5V97(`3F5W(%)U;&4`3F5W('=I;F1O=R`H7V)L
M86YK*0!.97AT`$YO`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F]N90!.
M;W1E<P!.;W9E;6)E<@!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W
M<P!/8W1O8F5R`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!T
M:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`4&%D9&EN
M9P!087-S=V]R9`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@
M9G)O;2!C;&EP8F]A<F0`4&%T:`!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)S;VYA;"!);F9O<FUA=&EO;@!0:&]N90!0:7AE
M;',`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R979I97<`
M4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R:6YT(&1O8W5M
M96YT`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5D;V5S('EO=7(@;&%S="!A8W1I
M;VX`4F5M;W9E('!A:7(`4F5S970`4F5T=7)N('1O($9I;'1E<G,@3&ES=`!2
M971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@4G5L97,@3&ES=`!2:6=H=`!2
M;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE`%)U;&4@0V]P:65D`%)U;&4@1&5L971E9`!2
M=6QE($1I<V%B;&5D`%)U;&4@16YA8FQE9`!2=6QE($YA;64`4V%M92!F<F%M
M92`H7W-E;&8I`%-A=F4`4V%V92!/<'1I;VYS`%-A=F4@4V5T=&EN9W,`4V5A
M<F-H`%-E96X`4V5L96-T(&$@9FEE;&0`4V5L96-T('1A<F=E="!F;VQD97(`
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5P=&5M8F5R
M`%-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!3:&]W('1H92!486)L
M92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-I
M;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W1R:6ME=&AR
M;W5G:`!3='EL92!;0U-370!3=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C
M8V5S<P!3=6UM87)Y`%-U<&5R<V-R:7!T`%1A8FQE(%!R;W!E<G1I97,`5&%B
M;&4@<')O<&5R=&EE<P!487-K<P!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!I9&5N=&ET
M>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O9V=L92!(5$U,(%-O=7)C
M90!4;W``5&]P(&9R86UE("A?=&]P*0!54DP`56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD97)L:6YE`%5N9&\@
M0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;FET960@2VEN9V1O
M;0!5;FET960@4W1A=&5S`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N
M;F%M960`56YS970@8V]L;W(`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R
M;VUA;B!N=6UB97)S`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5<V5R<R!I;B!T
M:&4@<WES=&5M.@!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9I
M97<@)7,`5V%R;FEN9P!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E
M;&-O;64L("5S`%=H7VET96QI<W0@861D<F5S<V5S.@!7:&%T(&ES('1H92!D
M96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T
M97(_`%=H:71E;&ES=`!7:&ET96QI<W0@161I=`!7:&ET96QI<W1E9"!!9&1R
M97-S97,`5VED=&@`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED
M=&@Z`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U
M(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W
M:71C:"!B86-K('1O(%=94TE764<N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U
M="X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E
M9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U
M<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@3F%M90!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N
M93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N`%M(:61E(%%U;W1E9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`
M7T)L86-K;&ES=`!?1&5L971E(%)O=P!?1&5L971E(&UE<W-A9V4@8V]M<&QE
M=&5L>0!?16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z`%]&;W)W
M87)D`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@;W5T`%]-;V1I
M9GD@3&EN:RXN+@!?36]V92!M97-S86=E('1O(&9O;&1E<CH`7TUY(&5M86EL
M(&%D9')E<W-E<SH`7T]P=&EO;G,`7U)E;6]V92!,:6YK+BXN`%]486)L92!0
M<F]P97)T:65S+BXN`%]7:&ET96QI<W0`;&EN97-=`&YA;64`;W(`<&5R8V5N
M=`!P:7AE;',`=6YN86UE9`!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ(&AO
M<F1E(#,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`U+3`U+3`X(#$V.C0R*S`Y,#`*3&%S="U4
M<F%N<VQA=&]R.B!*:6YH>6]K($AE;R`\;F]V96UB<F5`;W5R;F%T=7)E+F]R
M9SX*3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U6
M97)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/4550RU+4@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A
M;"U&;W)M<SH@;G!L=7)A;',],3L@<&QU<F%L/3`["@`@*+3<P^#%L"`E<RD`
M("B_P+3#*0`@*+.[P,\I`"`HON[!IBD`(+'7N*ZP[0`@ML>TP@`E<R#`K\'V
ML/RXKB#`V[[W("T@R*[`S@`B)7,BM,(@P,RYS"#`UKW`M,^TV2X`,C0@O<.P
MHP"_P,#\+[_`R,0`P,P@OZ&U\,7-M,(`O/:]Q;#%NLX@P=:\TK^A(+3KQ]$@
MN.VWR0##W["A`+OUM\Z_[B"[Y[_KP-H@P]^PH3H`QN2^[BAP86ER*2##W["A
M`+OGO^O`VB##W["A`+OGO^O`VB##W["A(+OGO^N^R,?4`,/?L*'`^\#.(+RS
MP:0`P=:\T@#!UKS2M\\`L/RXK@"^\[;SP,R^[KVZ`,&DM\0`P:2WQ#H`N/"U
MSB"\L<7#`+CPM><@-+CI`+39P+W`QR#`_+K.`+3KP[P@L=L`P-^X^+7((+FN
MP-JPH2#`UKW`M,^TV2X`M.3`Y<?1(+C>P,\`M-G`O2#!WR#'S[.J(,#,N_,`
MQ\K%S2#`^[_KQ\^QX@`TO_D`P*_!]K#\N*Z]Q\?@P/P@R*[`SL?/L>(`.+_Y
M`+"AM,G'T2#'RK7E.@"YZ+#F`+GHL.8@N_:Q\@"\^\"Z(,+\P;8`N_W`SP"\
M]KW%L,6ZS@"\]KW%L,6ZSB"X\;?/(+SVP:0`O/:]Q;#%NLZUR"#!UKS2`+SV
MO<6PQ;K.M<@@P=:\T@"ZN[FN`+&]L-0`L.:PZ`"PYK#H(+7.LK(`L.:PZ`"X
M\+7.`+[&MZ$`L>+(HR"XKKVZQJX`7V6\OR"\T[RZ+BXN`+3>M\(`P^N\T@"_
MP+?Y(+JXL.W'S['B(,/KO-(`Q+B\QP"TZ[S2N:[`VB"QN+K0`,+\P;8`R-ZT
MZ\;Y`+R_(+S3O+H`O+\@QN2U^0"\OR"\T[RZ`+R_(+"CL-T`R-ZTZ\;Y`+"A
MO^ZUI0"ZK[#F`+SVP:2[Y\?7(,#ZP.6UR@!?:[BUQ:D@L,N[YRXN+@#!W[&Y
M`+SXO*T@N*Z]NL:N(,&^M_D@O+'%PP!-4[_`Q\>]NB#%U['7(,'VO^RQX@##
MHB"TW;'B`+_>PLJXM[3K(+3=L>(`Q]7#Q,'X(+#FL.@`N_:Q\@"_K3H`0V]M
M:6-S`,BXN^<`OL_(HR#(KL#.`,;WQ]0`NKF[YP"ZN;OG("5S`"5S(+JYN^<`
MNKF[YP!-86EN=&5N86YC95]487-K(+CPM>(@)7,@N*8@OZT@O/8@OOB]P+3/
MM-DN`+BXM>FQX@"XM<6I(+BXM>FQX@"[]2#&^K3U(+BXM>FQX@#']L#G(%52
M3,"Z`,?VP.<@O;K%N,#/`,#:N*.QX@#`VKBCL>(`1$0`N^>_Z[[(Q]0Z`,#/
MNK``LZ_"I0!?;+^M(+OHP:8`,3*_^0"\_<#:`+.[ONZ^LK'B`+'BNKL`L>*Z
MNR"]Q+JPP-H`N^C!I@"[Z,&F("5S`+OHP:8@P;:PQP"\OR"[Z,&F`+^M(+OH
MP:8`N-Z]P\'V(+_/P/P@N^C!I@#'X""[Z,&F`,?VP.<@OZT@P?:_\@#']L#G
M(,?@(,'VO_(`N^C!IK7((+C>P,\`N=[`NL;MP?;'U,"XM\X@P/RTW@"YWL"Z
MQNW!]L?4P+BWSB#`_+3>Q\^P[2"TV<"](,;MP?;'U,"XM\X@NKF[Y\?/L>(`
MN=[`NL;MP?;'U,"XM\X@P/RTWL?/L.T@M-G`O<'6O-*WSB#`_+3>`,;ZM/6W
MSB#`S+6_`+_`M_D@O+.X[0"\L[CM.@"\O+K.P:2ZN+"A(+#\N*[`VKBF(,"G
MQ]@@L>*WS[7'ON[!L[W`M,^TV2X`M?"WNL7DN*X`N^>_Z[[(Q]0Z("5S`+OG
MO^N^R,?4`,BMN.D@O+/!I`#'RL7-L*$@P/N_Z[7)(+:G(,#:O+S'T2"^R[BR
M(+C>O</!]KBF(,>EO</'U;3/M-DN`%]NN?K%J2#(I,"Z(+BNO;K&KB"XWKW#
MP?:_H2"TZ\?8(,#`M.3`NR"ZN+.[P?8@OLJTPK39`&UA:6YT96YA;F-E+G!H
M<+^A(,'WP:(@P:*QV<?/P?8@N+:\O+_D+@##N;GXPK`@Q^#`NB#'U[CQ(,#,
MN*?`NR"PKK#M(,#6O<"TS['N/R"QU[>XM-FXZ2P@OZFQXKBF(,.\Q:G'S[R\
MO^0Z`+.[M\&YWK'B`"5S(+.[M\&YWK'B`+SVP:0`O/;!I"`G)7,G`"5S(+''
MQ]$@O/;!I`"\L<7#N^?'UR"\]L&D.@"_Y+S2+BXN`&5M`,#,N-[`SP#`S+CP
MQKS$W`"PX;#Z(+[XP+T`N^>_Z\?/L>(Z("5S`+OGO^O!WP#&[<']L>(@R*ZT
MZP"QU[BR(%523"#`U+?"`+_`M_D`,36ZT""XMK39`#,PP\H@N+:TV0`UNM`@
MN+:TV0"X\+7G(+?.L=?`S@`S,+K0(+BVM-D`N,6ZT`"_N3H`P;C`Y\?/M,(@
MQ\K%S;BU`,&XP.?'U`"_WL+*N+>TZR#(KL#E`,#\L.:[]@#(K[#FO+/!I"#`
MT+'B(+_`M_DN`$Q$05`@O*VY]B#!HKS3(+W'QM``QM&]N@`RO_D`QL3`SR"P
M_+BNP-H`N/"UYR"XWKW#P?8@Q\K%S0#`T,"Z(+C>P,^XN"#'RL7-`,#0P?8@
MOLK`NB"XWL#/N+@@Q\K%S0#'RL7-(+RQQ<.[Y\?7`,?*Q<T@Q:7$H@#'RL7-
M(,6EQ*(`7W+'RL7-(,6EQ*(`Q\K%S2##H\'V(+CXQ]0`Q\K%S0"QV\#:(+OV
ML?(`P/RTW@#`_+3>`,#\M-X@O/;!I`#'P;>YP-,`P*?$H0"UML#/`+"AL>(`
ML_3`S`"UM;_RN+L`M;6_\KB[`,;$P,_`QR"]P\#;P,P@M-G`O;#Z(+"PO<"T
MS[39.@#!_2#!UKS2`,'](,#\R*VY^,BC`$AO<F1E`+SVQO*\L0"PH;?.(,.D
MO_(`L*&WSCH`Q]7$H;#M(+W-P+H@OZW`QR"\]@#'U[CQ*+^M*<#'(+SV/P#'
MU<2AL.T@O<W`NB#'X,#'(+SV`%]NOM6_H2#'X"##W["A`+[&P,S$W`"^QL#,
MQ-RP^B"YKL#:`+W$NK#`VB#`S+BG.@"QU[BR(+G,N*ZZN+'B.@"QU[BR(%52
M3`"QU[BR(%523#H`P=^_Y,?1(+C>P,\`L*'!KK_"(,?7N/$Z("5S`+"AP:Z_
MPB#'U[CQ.@!?<[39P+V_H2#'X"##W["A`+7IOZF^LK'B`%]OM-G`O;^A(+^M
M(,/?L*$`L=>XLB##W["A`,>E(,/?L*$`P*4@N+7%J2##W["A`%]COM6_H2"_
MK2##W["A`,?VP.<@OZT@M=J_H2"[]2"_K2##W["A`,?VP.<@OZT@OM6_H2"[
M]2"_K2##W["A`,?VP.<@Q^`@M=J_H2"[]2#'X"##W["A`,?VP.<@Q^`@OM6_
MH2"[]2#'X"##W["A`,?VP.<@P?;!H2"UVK^A(+3<MO0@P]^PH0#']L#G(,'V
MP:$@OM6_H2"TW+;T(,/?L*$`M=J_H2"\OR##W["A`+[5OZ$@O+\@P]^PH0"U
MVK^A(+^M(,/?L*$`OM6_H2"_K2##W["A`+7:OZ$@M-RV]"##W["A`+[5OZ$@
MM-RV]"##W["A`+7:OZ$@Q^`@P]^PH0"^U;^A(,?@(,/?L*$`L=>XLB##W["A
M+[SVP:0`N+7%J2##W["A+[SVP:0`L>*_[\#,L>(`,;_Y`,#/NKL`P,^ZN[[N
M("A)4T\M,C`R,BU*4"D`-[_Y`#:_^0#!I+?$`+"AO^ZUI2#!I+?$`+[GPLH@
MP:2WQ`"_WL+*(,&DM\0`O\"XI<+*(,&DM\0`M.O'T;G.L;D`Q]&QN;[N("A%
M54,M2U(I`+[PONX`N+;!]KBW(+?.L=?`SCH@)7,`N+;!]KBW(+?.L=?`SCH@
M)7,L(,&BO-,@P*?$H3H@)7,`N+;!]KBW(+?.L=?`SCH@OOC`O0"WN<#,OL:_
M]`"_WL+*`+6UO_*^RR"X\<+W`+OGO^O'TB"\]B"^^+3"(+OGO^O`VB"X\;?/
M+@"WSK'7P,X`M\ZQU[[&O_0`M\ZQU\#.(+W#P-O`V[[W`+'7N*Z]NB"\TKFN
MP-H`MO/&OB"\TKFNP-H`M\ZXMB"\TKFNP-H@O/W`V@!-30"XWL#/`%]KN+7%
MJ2"XN+7IL>(N+BX`7VO!]K_VP?@@N-Z]P\'VM\X@QZ6]PP`SO_D`L*'`Y<#:
MN*X`P,_$H<?/M,(@Q]>X\0`UO_D`N-ZTNB"X\+7E`+R_(,?5Q*&QX@"XWKW#
MP?8`L*&_[K6E`%523""\]L&D`+C%O_D`P,RUOP"^QK>AM\X@P,RUOP"^QK>A
MM\X@P,RUOP#`I[?.(,#,M;\`P*>WSB#`S+6_`,#,N*<`L]?&KK_VQ:D`N^>_
MZ[[(Q]0`N_6WSK_N(+'4Q*(`N_4@PZ(H7V)L86YK*0"TV<"]`+[&M,^_P`!&
M5%`@5D93N*8@P*?'T2"\L\&DP:2ZN+"A(+[XO<"TS[39+@!344P@5D93(+RS
MP:3!I+JXL*$@OOB]P+3/M-DN`%-13"U&:6QE(%9&4R"\L\&DP:2ZN+"A(+[X
MO<"TS[39+@"\L<7#Q\_!]B"^RL"]`,+\P;8`,3&_^0"_K<#'(+SV`,?@P,<@
MO/8`,3"_^0"[]2##HK^A(+BUQ:D@OZVQX@"\L<7#N^?'UP`E<R"\L<7#N^?'
MUP"\_<#:(+CQM\\`M-S#O`"QXL6X`+'BQ;@@P:2ZN`"QXL6X(+RSP:0`QN2U
M^0"^S\BC`+[/R*.PH2#`S\2AQ\_!]B"^RKW`M,^TV2X`NMG`S+'B`,6LN+.Z
MN+7EOZ&\K2"ZV<#,L>(`L.:WS@#&V[R^QJX`P*_!]B"P_+BN(,#;OO<@O<?'
MX`"PL\#.(,&DNK@`P/S(K;GXR*,`Q\B\OP!<;KOUM\Z_[B#&^K3UP,<@P,RX
MI\"[(,#4M\+'S[R\O^0Z7&X`N:[!IK^A(+3KQ]$@O^2^X,"[(,#4M\+'V"#!
MUKR\O^0N`+OGO^O`VL#,N*>P^B"^S\BCN*8@P-2WPL?/O+R_Y`"YS+BNNKBQ
MX@"[]2##HK^A(+G,N*ZZN+'B`+FNO*T@P,Z\X@"YKL&F(+RSN.T`N+;!]KBW
M(+CMM\D@N=VZN0#&Y+[N*'!A:7(I(+OHP:8`P-2WPB##Z[S2`,?*Q<T@N/&W
MS\"XM\X@M;F^QK"AL>(`O\F\Q\"XM\X@M;F^QK"AL>(`L=3$HB"X\;?/M\X@
MM;F^QK"AL>(`O\"XI<+*`%]WQ^`@O-.\NBXN+@"_JL?2`,?@(+S3O+H`Q^`@
MO-.\N@#'X#H`L=3$H@"QU,2B(+JYN^>UR@"QU,2B(,'VO_;!_`"QU,2B(+OG
MO^N^R,?4`+'4Q*(@N^>_Z\?4`+'4Q*(@P,RXIP"PL,"Z(,?!M[G`TRA?<V5L
M9BD`P/K`Y0"\L<7#N^?'UR#`^L#E`+RSP:0@P/K`Y0"PR[OV`,#0P+H@N-[`
MSP#'U[CQ(+RQQ<,`QOJT]2"\L<7#`+[&MZ$@N_/`VK^AO*T@Q\J_Y,?1(+FN
MP-JXIB"\L<7#Q\^P[2"ZN;OGQ\^_J2"ZV;^IL];`N+R\O^0N`+.OP-H@L;BZ
MT,>EO<,@O+'%PSH`LZ_`VB#'_+W$(+RQQ<,`O<.PHR#'_+W$(+RQQ<,`M<ZP
ML\#'(,#/Q*''S[3"(,?7N/$@O+'%PP#`VL'6N^>_Z\?/M,(@OO"^[KBF(+RQ
MQ</'S[R\O^0N`+FNP::YW[O](+JXL.V\K2#`_+S;Q\^QX@`YO_D`O+/!I,#,
M(+RZL/C`^\"XM\X@P/K`Y;7'OOJ]P+3/M-DN`+R_(+S3O+K#HB"ZN+'B`,>E
M(+S3O+K#HB"ZN+'B`+^M(+S3O+K#HB"ZN+'B`+'7N+(@O-.\NL.B(+JXL>(`
MQ:FQX@#`K\'VL/RXKB"[_;>K`+R_L*.PW0"\OR"PYK#HO\T@L[N_ZR"[Y\#,
MP,<@L*.PW0"PQ;BN`+#%N*Z_S2##I+_LL>(`QJ^\]B"YKL#:(,#4M\(`O+\@
MNM#'T@"_K2"ZT,?2`,?@(+K0Q](`L*&_[K6EP=D`O;K%N,#/6T-34UT`P::X
M\0#!IL/B`+[&MZ'#M\#:`+RZL/@`O^2^X`#`K<.WP-H`QZ4@O-.\N@#'I2"\
MT[RZ`,#;OO<`N:[`VK^M`+FNP-H`N:[`VB#!I+?$`+OGO^O'V,'6O,6\K2"P
MJ+OGQ]6TS[39+@#&Q,#/OZ$@OL:YJ[>Q(,#:M^&PH2"^^+W`M,^TV2X`OL:W
MH;3"(,#,(&UE<W-A9V4O<F9C.#(R(,;MP?;`QR"XT[BTN+O`U+3/M-DN`+W$
MNK#`VB`B)7,B(+"A(+OHP::UQ[[ZO<"TS[39+@#`S+_KL*&TR<?1(+RQQ<.[
MY\?7P,P@OOB]P+3/M-DN`,;$P,\@O\.XKK'BOZ$@N:[!IK"A(,#6O<"TS[39
M+B`E<R#&Q,#/P,P@OO>WSK7EM<?!]B"^RK[2O<"TS[39+@#`S""\_<#:M,(@
MP]:\TL?1(#'`VKBN(,#,N_/`S+[NOM\@Q]6TS[39+@#`S""PJL"Z(+S]P-J_
MJ;[?(,?5M,^TV2X`P::X\0#%N,#,QK(HQ?C&P2DZ`+G>M,(@N^>V]P!(5$U,
M(+S2O;H@NKBQX@#`IP"[\\"G(,?!M[G`TRA?=&]P*0!54DP`5D93(,;$P,\@
M)7,O)7/`QR#&V[G,O,?`NR"ZK[#FQ](@O/8@OOB]P+3/M-DN`%-13""\K;GV
MOZ$@P:*\T\?2(+SV(+[XO<"TS[39+@`E<R#!I,#'N*8@P-#`NR"\]B"^^+W`
MM,^TV2X`=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN`%9&
M4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2X`P,P@O_:U
MY;FNO*VXIB"ZK[#FQ](@O/8@OOB]P+3/M-DN`+G8P=D`NJ^PYKOGQ]<@M<>U
MN;BNL>(`N+;!]KBW(+CMM\D@P^N\T@"_M;&Y`+G,L;D`Q_;`YR"_Y+S2OZ$@
MN+7%J2#!IK#%`,#,N*<@OOC`O0"[]K'R(,&FL,4`MO/&OK[N(+3KN:[`V@"W
MSKBV(+3KN:[`VB"\_<#:`+OGO^O`VB"\L<7#N^?'UP"[Y[_KP-JX[0"]P[VZ
MQ=O`QR"[Y[_KP-HZ`+SVP?<@P:2WQ`"\]L'W(,.DO_(`)7,@NKBQX@"PYK#M
M`+C%P=8`R*^_M0#(K[^UQ]6TS[39(2`E<R#`U+3/M-DN`,BOO[7'U;3/M-DL
M("5S`%]IO/:]Q;W"P,X@P=:\T@"QN+K0(+FNP-JTPB"YJ[[YP-2TS['N/P#`
MSK_K(+K.R*.TPB"YJ[[YP-2TS['N/P"\]KW%O<+`S@"\]KW%O<+`SB"X\;?/
M(+SVP:0`O/:]Q;W"P,ZUR"#!UKS2`+/*NO$`QZ7`QR"SRKKQ`+/*NO$@M-S`
MIP"SRKKQ.@#!]\#E(,'6O-(Z`,'WP.4@P/S(K;GXR*,`65D`N,6SX@"_N0!4
M15A4N/"UY<#4M,^TV2X@6SP^72"Y]L:PP+L@M*FXH[CI(%=94TE764<@N/"U
MY;?.(+6YOL:PJ;3/M-DN`+?.L=>^QK_T(,?/O[2]P+3/M-DN`+FNP:8@NKBP
M[;RMN*8@NKBSN['BP/R_H2#`S+FNP::_H2"TZ\?1(+RSN.W`NR#`U+?"Q]B^
MWR#'U;3/M-DN`,#,(+BUQ:FPH2"PH;BNQ*&TPB!54DS`NR#`U+?"Q]B^WR#'
MU;3/M-DN`+OHP:;'TB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2X`
MP]^PH<?2(+OGO^O`VB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+@`E<R"\O+S'
MP,P@N+BWX;7'OOJ]P+3/M-DN(+39O<,@M\ZQU\#.Q\^\O+_D+@#`S+C>P,\@
MP=:\TCH`N-[`SR#!UKS2.@#!I+JX`,#,N*<Z`+3GO<7`QR#`SL'UQ:RV\\#,
MOO#&KK"A(+OGO^O`VB"X\;?/NKBQXKBF(,'VO_C'S\'V(+[*O<"TS[39+B"V
MQ[3"(+39N*4@P,S`K[?.(+OGO^O`VB"X\;?/NKBQXKBF(+OGO^O'TB"\]B"^
M^+W`M,^TV2X`NNJV\[_LP/JPH2#`S""QXK3)P+L@P?:_^,?/P?8@OLJ]P+3/
MM-DN`,?VP.<@O<.PH[3K.@"QXKJ[(+W$NK#`VCH`P/S#O"#`S+BG.@#`S""\
MO+S'(+6_OL@@O\F\Q\#,(,#ZP.6UR[3/M-DN`+_)O,?`S"#`^L#EM<>^^KW`
MM,^TV2X`6\#.O^L@O/NQXK'B70!;P::X\2"^^,"]70!;O\"W^2"ZN+#MQ\^Q
MXET`6\#.O^L@NKBQXB`M`%O`SK_K(+JXL>(@+2`E<R#!V5T`6[;SP,X@)7,@
M+R`E<UT`7T&P_+BN`%]"O/:]Q;#%NLX`7T3'X"#!]K_R`%]DN-Z]P\'V(+_/
MP/P@N^C!I@!?9<?1(,'9OZ$@P=:\TB#'S[.JOK\@P-2WPL?/O+R_Y#H`7V;`
M_+3>`+6UO_*XNP!?2;'7N+(@O-.\NBXN+@!?3+?.L=>^QK_T`%]MN+7%J2"\
M]L&D+BXN`%]MQOJT];?.(,#,M;\Z`%]MLZK`QR#`S+C>P,\@P=:\TCH`7T^\
ML<7#N^?'UP!?<KBUQ:D@N^C!IBXN`%]TQZ4@O-.\NBXN+@!?5[SVO<6]PL#.
M`,'970#`S+BG`+;'M,(`QMN\OL:N`,?(O+\`P,RXIR"^^,"]`'9#87)D````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE+VQT7TQ4+P``````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#<`
M,#$W-C0P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O;'1?
M3%0O3$-?34534T%'15,O````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<T-P`P,C$T,C4`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;F=O+VQO8V%L92]L=%],5"],0U]-15-304=%4R]I;F=O+FUO````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,S8R,3,T`#$P-#$W,S8R-S0W`#`R,C<R-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`!\'```<````%#D``(4)```,<@```````""8```.````(9@```\````PF```
M"````$"8```,````29@```0```!6F```!````%N8```#````8)@```P```!D
MF```#P```'&8```+````@9@```X```"-F```!0```)R8```H````HI@```H`
M``#+F```%0```-:8```2````[)@```L```#_F```#@````N9```*````&ID`
M``T````EF0``#@```#.9```1````0ID```T```!4F0``#````&*9```-````
M;YD```8```!]F0``#P```(29```8````E)D```P```"MF0``#@```+J9```.
M````R9D```@```#8F0``+@```.&9```:````$)H``#(````KF@``.````%Z:
M``!4````EYH``%$```#LF@``6@```#Z;``!7````F9L``#0```#QFP``"@``
M`":<```%````,9P```8````WG```$0```#Z<```(````4)P```D```!9G```
M"0```&.<```E````;9P``"````"3G```$````+2<```/````Q9P```H```#5
MG```(0```."<```/`````IT```,````2G0``#P```!:=```4````)IT```D`
M```[G0``#0```$6=```2````4YT```\```!FG0``"@```':=```/````@9T`
M``@```"1G0``)````)J=```4````OYT``!8```#4G0``"````.N=```9````
M])T``!,````.G@``!P```"*>```,````*IX``"P````WG@``#@```&2>```#
M````<YX```L```!WG@``!P```(.>```'````BYX```4```"3G@``!0```)F>
M```*````GYX```,```"JG@``%P```*Z>```*````QIX```\```#1G@``#@``
M`.&>```4````\)X``!@````%GP``(P```!Z?```.````0I\``!0```!1GP``
M%P```&:?```7````?I\``!<```"6GP``$P```*Z?```/````PI\```X```#2
MGP``'P```.&?```'`````:````8````)H```"````!"@```/````&:````8`
M```IH```"````#"@```*````.:```!,```!$H```%````%B@```+````;:``
M`!4```!YH```#0```(^@```5````G:````<```"SH```!0```+N@```5````
MP:```!$```#7H```#````.F@```J````]J```#L````AH0``"0```%VA```'
M````9Z$``!0```!OH0```P```(2A```%````B*$``!````".H0``"0```)^A
M```3````J:$``#D```"]H0``$@```/>A```G````"J(``"P````RH@``*@``
M`%^B```E````BJ(```H```"PH@``!@```+NB```)````PJ(```<```#,H@``
M+P```-2B```W````!*,``"X````\HP``50```&NC```M````P:,``"T```#O
MHP``+0```!VD``!`````2Z0``",```",I```(P```+"D```M````U*0``#,`
M```"I0``%0```#:E```9````3*4``"D```!FI0``)````)"E```R````M:4`
M`!$```#HI0``"@```/JE```,````!:8```H````2I@``$````!VF```6````
M+J8``!8```!%I@``!P```%RF```'````9*8``!0```!LI@``"@```(&F```(
M````C*8```@```"5I@```P```)ZF```+````HJ8```<```"NI@``!P```+:F
M```&````OJ8```4```#%I@``!P```,NF```&````TZ8```@```#:I@``"0``
M`..F```.````[:8``#L```#\I@``$P```#BG```5````3*<```X```!BIP``
M"@```'&G```$````?*<```0```"!IP``!P```(:G```)````CJ<```8```"8
MIP``$0```)^G```'````L:<``!8```"YIP``!````-"G```(````U:<```8`
M``#>IP``#0```.6G```&````\Z<``!X```#ZIP``$0```!FH```(````*Z@`
M``T````TJ```#````$*H```'````3Z@```,```!7J````P```%NH```7````
M7Z@``!,```!WJ```"````(NH```$````E*@```@```"9J```"````**H``!!
M````JZ@``"````#MJ```!@````ZI```&````%:D``!4````<J0``&````#*I
M```B````2ZD``"X```!NJ0``'0```)VI```A````NZD``%0```#=J0``*0``
M`#*J```*````7*H```<```!GJ@``#@```&^J```5````?JH```X```"4J@``
M`@```*.J```*````IJH```\```"QJ@``#0```,&J```/````SZH```T```#?
MJ@``"0```.VJ```4````]ZH```8````,JP``&````!.K```=````+*L``!,`
M``!*JP``%````%ZK```$````<ZL```8```!XJP``5````'^K```.````U*L`
M``0```#CJP``#@```.BK```%````]ZL```4```#]JP``&P````.L```:````
M'ZP``!$````ZK```$0```$RL```<````7JP``"H```![K```$````*:L```A
M````MZP```4```#9K```$P```-^L```2````\ZP```H````&K0``#P```!&M
M```1````(:T``!,````SK0``#````$>M```&````5*T```8```!;K0``%P``
M`&*M```1````>JT```@```",K0``!0```)6M```,````FZT``!````"HK0``
M!0```+FM```-````OZT```8```#-K0``!P```-2M```-````W*T```<```#J
MK0``"P```/*M```'````_JT```<````&K@``"0````ZN```*````&*X``!D`
M```CK@``#````#VN```0````2JX```4```!;K@``)0```&&N```2````AZX`
M`!,```":K@``*P```*ZN```[````VJX``"`````6KP``-@```#>O```(````
M;J\```@```!WKP``#````("O```&````C:\```0```"4KP``!P```)FO```*
M````H:\```X```"LKP``"@```+NO```-````QJ\``!X```#4KP``&P```/.O
M```A````#[```!X````QL```&0```%"P```>````:K```!L```")L```)@``
M`*6P```;````S+```!X```#HL```'`````>Q```F````)+$``#,```!+L0``
M)@```'^Q```K````IK$``#@```#2L0``+P````NR```2````.[(``"D```!.
ML@``$@```'BR``"B````B[(``!8````NLP``(P```$6S```H````:;,``"D`
M``"2LP``*````+RS```?````Y;,``"`````%M```)0```":T```A````3+0`
M`!P```!NM```)@```(NT``!!````LK0```P```#TM```!P````&U```'````
M";4```8````1M0``#0```!BU```0````)K4``!$````WM0``$@```$FU```3
M````7+4``!(```!PM0``!P```(.U```$````B[4```P```"0M0``#@```)VU
M```/````K+4``!,```"\M0``#0```-"U```H````WK4```,````'M@``#0``
M``NV```&````&;8``!$````@M@``%P```#*V```;````2K8```X```!FM@``
M`@```'6V```*````>+8```4```"#M@``$````(FV```$````FK8```T```"?
MM@``#@```*VV```#````O+8```X```#`M@``$0```,^V```(````X;8```\`
M``#JM@``#P```/JV```-````"K<``!`````8MP``"P```"FW```&````-;<`
M``D````\MP``$````$:W```,````5[<``!$```!DMP``&0```':W```+````
MD+<```T```"<MP``(@```*JW```9````S;<```H```#GMP``&````/*W```9
M````"[@``!8````EN```!P```#RX```5````1+@``"$```!:N```)0```'RX
M```1````HK@```T```"TN```!P```,*X```4````RK@```L```#?N```(@``
M`.NX```O````#KD```L````^N0``"0```$JY```9````5+D```L```!NN0``
M%P```'JY```7````DKD```D```"JN0``"@```+2Y```(````O[D``!8```#(
MN0``#P```-^Y```Z````[[D``!8````JN@``#@```$&Z```8````4+H```@`
M``!IN@``+P```'*Z```-````HKH``"8```"PN@``"````->Z``!#````X+H`
M`!(````DNP``#P```#>[```0````1[L```T```!8NP``(0```&:[```(````
MB+L``!(```"1NP``"````*2[```+````K;L``"\```"YNP``#@```.F[```%
M````^+L```8```#^NP```P````6\```'````";P```0````1O```!P```!:\
M```*````'KP```H````IO```#P```#2\```0````1+P``!<```!5O```$0``
M`&V\```7````?[P```D```"7O```!0```*&\```+````I[P```H```"SO```
M`@```+Z\```%````P;P```T```#'O```&P```-6\```7````\;P```D````)
MO0``#@```!.]```-````(KT``!(````PO0``"0```$.]```X````3;T``"``
M``"&O0``!P```*>]```(````K[T```D```"XO0``#@```,*]``![````T;T`
M`!@```!-O@``"````&:^```1````;[X```<```"!O@``!0```(F^```9````
MC[X```<```"IO@``"````+&^```&````NKX```8```#!O@``$````,B^```/
M````V;X``!````#IO@``#P```/J^```+````"K\```\````6OP``#````":_
M```/````,[\```<```!#OP``#@```$N_```&````6K\```8```!AOP``#```
M`&B_```H````=;\```\```">OP``"````*Z_```(````M[\``!,```#`OP``
M'@```-2_```A````\[\``"`````5P```&0```#;````7````4,```"4```!H
MP```%P```([````$````IL```!L```"KP```#0```,?````#````U<````@`
M``#9P```"@```.+````,````[<````L```#ZP```!`````;!```3````"\$`
M`!0````?P0``#````#3!```)````0<$```X```!+P0``"P```%K!```;````
M9L$``!,```""P0``&0```);!```;````L,$```X```#,P0``"P```-O!```,
M````Y\$``!4```#TP0``#0````K"``!#````&,(``#$```!<P@``0@```(["
M``!'````T<(``$\````9PP``/0```&G#``!.````I\,``!$```#VPP``!P``
M``C$```'````$,0```H````8Q```#0```"/$```)````,<0```0````[Q```
M!0```$#$```#````1L0``!@```!*Q```"@```&/$```$````;L0``"4```!S
MQ```)@```)G$```.````P,0``'P```#/Q```%0```$S%```%````8L4```<`
M``!HQ0``#````'#%```(````?<4```H```"&Q0``!@```)'%```'````F,4`
M`#D```"@Q0``"````-K%```-````X\4```(```#QQ0``!@```/3%```&````
M^\4``!0````"Q@``#0```!?&```0````)<8``!L````VQ@``!````%+&```)
M````5\8``!````!AQ@``"0```'+&```)````?,8```4```"&Q@``&@```(S&
M```(````I\8```8```"PQ@``&0```+?&```.````T<8```<```#@Q@``!P``
M`.C&```%````\,8```D```#VQ@``"@````#'```"````"\<```8````.QP``
M#0```!7'```)````(\<```P````MQP``&````#K'```&````4\<``!(```!:
MQP``"0```&W'```'````=\<``!0```!_QP``'0```)3'```&````LL<```H`
M``"YQP``!````,3'```)````R<<```@```#3QP``$0```-S'```)````[L<`
M``8```#XQP``#0```/_'```&````#<@```0````4R```.0```!G(```]````
M4\@``#H```"1R```'@```,S(```%````Z\@```X```#QR```!`````#)```&
M````!<D``"$````,R0``%0```"[)```&````1,D```0```!+R0``$0```%#)
M```&````8LD```H```!IR0``(@```'3)```$````E\D```4```"<R0``'0``
M`*+)```$````P,D```P```#%R0``"@```-+)```(````W<D```D```#FR0``
M!0```/#)```Z````]LD``#`````QR@``-0```&+*```I````F,H``$<```#"
MR@``.`````K+```I````0\L``#\```!MRP``+@```*W+```M````W,L``!\`
M```*S```#P```"K,```2````.LP```L```!-S```)@```%G,```I````@,P`
M`"0```"JS```)@```,_,```(````]LP```H```#_S```"0````K-```'````
M%,T``"`````<S0``(````#W-```F````7LT```H```"%S0``&0```)#-```I
M````JLT``!8```#4S0``$@```.O-```'````_LT```H````&S@``#P```!'.
M```0````(<X``$`````RS@``9@```'/.```.````VLX```D```#IS@``"@``
M`//.```2````_LX``!,````1SP``#````"7/```&````,L\```\````YSP``
M"0```$G/```2````4\\``!````!FSP``$0```'?/```<````B<\``",```"F
MSP``:@```,K/```/````-=````4```!%T```$````$O0``!#````7-````D`
M``"@T```,@```*K0```$````W=````L```#BT```%````.[0```,`````]$`
M``P````0T0``#P```!W1```5````+=$``"D```!#T0``*@```&W1```F````
MF-$``"<```"_T0``*0```.?1```J````$=(``!D````\T@``0@```%;2```1
M````F=(``!(```"KT@``$P```+[2```4````TM(```\```#GT@``%@```/?2
M```7````#M,``!`````FTP``$0```#?3```T````2=,``!,```!^TP``$@``
M`)+3```U````I=,``!0```#;TP``!P```/#3```,````^-,``"`````%U```
M%````";4```1````.]0``!<```!-U```'````&74```3````@M0``!$```"6
MU```&@```*C4```>````P]0``!H```#BU```$0```/W4```4````#]4``!<`
M```DU0``%0```#S5```)````4M4``!D```!<U0``!````';5```'````>]4`
M``(```"#U0``"P```(;5```%````DM4``!$```"8U0``!@```*K5```&````
ML=4```8```"XU0``!0```+_5```'````Q=4```<```#-U0``!0```-75```6
M````V]4```8```#RU0``!@```/G5```$`````-8```0````%U@``!P````K6
M```.````$M8```P````AU@``#````"[6```-````.]8```H```!)U@``#@``
M`%36```%````8]8``"@```!IU@``#@```)+6```,````H=8```\```"NU@``
M"@```+[6```(````R=8```D```#2U@``*P```-S6```$````"-<```@````-
MUP``)@```!;7```2````/=<```\```!0UP``!@```&#7```*````9]<```<`
M``!RUP``"````'K7```@````@]<```D```"DUP``#````*[7```-````N]<`
M``X```#)UP``%@```-C7```1````[]<```8````!V````P````C8```&````
M#-@``!D````3V```!P```"W8```$````-=@```L````ZV```"P```$;8```'
M````4M@```D```!:V```%0```&38```'````>M@``!8```""V```#0```)G8
M```-````I]@```H```"UV```$````,#8```/````T=@``!$```#AV```%P``
M`//8```*````"]D``!$````6V0``"````"C9```$````,=D```\````VV0``
M.@```$;9```%````@=D```P```"'V0``'@```)39```.````L]D``!````#"
MV0``"P```-/9```,````W]D```D```#LV0``!P```/;9```'````_MD```H`
M```&V@``"0```!':```.````&]H``!`````JV@``&@```#O:```*````5MH`
M``D```!AV@``"@```&O:```,````=MH```\```"#V@``"````)/:```&````
MG-H```<```"CV@``"P```*O:``!'````M]H```T```#_V@``"0````W;```$
M````%]L```,````<VP``$P```"#;```3````--L``!,```!(VP``"@```%S;
M```"````9]L```0```!JVP``)0```&_;```#````E=L```4```"9VP``*@``
M`)_;```*````RML```4```#5VP``!````-O;```*````X-L```T```#KVP``
M!@```/G;```(`````-P```@````)W```!````!+<```%````%]P``&@````=
MW```"0```(;<```,````D-P``!@```"=W```!0```+;<```&````O-P``!``
M``##W```&P```-3<```O````\-P``!`````@W0``"@```#'=```;````/-T`
M``\```!8W0``"@```&C=```)````<]T``!,```!]W0``&P```)'=```8````
MK=T``!<```#&W0``#@```-[=``")````[=T``(D```!WW@```P````'?```'
M````!=\```@````-WP``!P```!;?```*````'M\```L````IWP``!P```#7?
M``!1````/=\``!````"/WP``#````*#?```-````K=\``!H```"[WP``2@``
M`-;?```&````(>````8````HX```!@```"_@```?````-N````8```!6X```
M"0```%W@```8````9^```!<```"`X```!@```)C@```-````G^```"(```"M
MX```)@```-#@``!7````]^```!,```!/X0``&0```&/A```;````?>$``",`
M``"9X0``$P```+WA```"````T>$```L```#4X0``"````.#A```-````Z>$`
M``H```#WX0``!P````+B```4````"N(```8````?X@``"````";B```.````
M+^(```<````^X@``"@```$;B```+````4>(```<```!=X@``#````&7B```-
M````<N(```P```"`X@``!````(WB```)````DN(```D```"<X@``"@```*;B
M```.````L>(```P```#`X@``!P```,WB```)````U>(```<```#?X@``"@``
M`.?B```;````\N(``!(````.XP``"@```"'C```)````+.,``!`````VXP``
M!P```$?C```2````3^,``"D```!BXP``!````(SC```'````D>,```4```"9
MXP``!0```)_C```+````I>,``!0```"QXP``$0```,;C```:````V.,``!8`
M``#SXP``%`````KD```7````'^0``!@````WY```'````%#D```9````;>0`
M``<```"'Y```!0```(_D```-````E>0```P```"CY```"````+#D```(````
MN>0``!<```#"Y```"P```-KD```3````YN0```0```#ZY```"@```/_D```$
M````"N4```P````/Y0``"0```!SE```%````)N4```<````LY0``!0```#3E
M```$````.N4```(````_Y0``.````$+E```L````>^4``",```"HY0``)@``
M`,SE```2````\^4``"D````&Y@``,@```##F```*````8^8``"P```!NY@``
M+@```)OF```S````RN8``#,```#^Y@``.````#+G```/````:^<``!@```![
MYP``$````)3G```4````I><``!,```"ZYP``%````,[G```2````X^<``!0`
M``#VYP``%0````OH```M````(>@``"T```!/Z```,0```'WH```N````K^@`
M`"\```#>Z```+`````[I``!B````.^D``!,```">Z0``"````++I```4````
MN^D```@```#0Z0``%````-GI```K````[ND``"$````:Z@``&@```#SJ```)
M````5^H``$4```!AZ@``00```*?J```$````Z>H``!,```#NZ@``%`````+K
M```.````%^L``!,````FZP``&````#KK```&````4^L```D```!:ZP``"@``
M`&3K```/````;^L```P```!_ZP``$````(SK```'````G>L```X```"EZP``
M!0```+3K```;````NNL```@```#6ZP``!@```-_K```4````YNL``!$```#[
MZP``#@````WL```X````'.P```(```!5[```!@```%CL```.````7^P```4`
M``!N[```!P```'3L```.````?.P```8```"+[```!````)+L```I````E^P`
M`!<```#![```'P```-GL``!<````^>P``!0```!6[0``'P```&OM```0````
MB^T```<```"<[0``'@```*3M```.````P^T```P```#2[0``#````-_M```3
M````[.T```H`````[@``'0````ON```9````*>X```4```!#[@``$0```$GN
M```-````6^X``!$```!I[@``)````'ON```5````H.X``!(```"V[@``#@``
M`,GN```9````V.X```@```#R[@``"0```/ON```-````!>\```H````3[P``
M"P```![O```*````*N\```<````U[P``"````#WO```%````1N\``!\```!,
M[P``!@```&SO```0````<^\```@```"$[P``#0```(WO```(````F^\``!(`
M``"D[P``+````+?O```:````Y.\```D```#_[P``"@````GP```5````%/``
M``4````J\```%````##P```$````1?```!````!*\```!@```%OP```'````
M8O```!X```!J\```*````(GP```*````LO```!H```"]\```%````-CP```$
M````[?````0```#R\```"P```/?P```%`````_$```8````)\0``"````!#Q
M```&````&?$```H````@\0``&P```"OQ```T````1_$``#0```!\\0``(```
M`+'Q```I````TO$``"````#\\0``00```!WR```:````7_(``"@```!Z\@``
M*````*/R```I````S/(``"(```#V\@``!@```!GS```(````(/,```4````I
M\P``"````"_S```9````./,``!D```!2\P``*@```&SS```C````E_,``"X`
M``"[\P``-````.KS```(````'_0``!<````H]```"@```$#T```'````2_0`
M`"$```!3]```$````'7T```.````AO0```L```"5]```!P```*'T```3````
MJ?0```@```"]]```"P```,;T```*````TO0``!0```#=]```,@```/+T```+
M````)?4```4````Q]0``!0```#?U```7````/?4```<```!5]0``#P```%WU
M```$````;?4```H```!R]0``"0```'WU```+````A_4```X```"3]0``!0``
M`*+U```$````J/4```T```"M]0``,@```+OU``!%````[O4```@````T]@``
M"P```#WV```7````2?8``!X```!A]@``%````(#V```%````E?8``!(```";
M]@``$@```*[V```4````P?8```<```#6]@``#@```-[V```J````[?8```8`
M```8]P``#````!_W```-````+/<``!$````Z]P``"P```$SW```V````6/<`
M``H```"/]P``(@```)KW```+````O?<```\```#)]P``,@```-GW```)````
M#/@```L````6^```!0```"+X```.````*/@``!,````W^```!P```$OX```6
M````4_@``!$```!J^```%````'SX```'````D?@``!0```"9^```&````*[X
M```'````Q_@```4```#/^```#````-7X```,````XO@``!(```#O^```!```
M``+Y```'````!_D```H````/^0``"P```!KY```,````)OD```X````S^0``
M#@```$+Y```%````4?D```0```!7^0``"P```%SY```,````:/D```T```!U
M^0``#````(/Y```)````D/D```4```":^0``+@```*#Y```F````S_D``",`
M``#V^0```P```!KZ```2````'OH```8````Q^@``'@```#CZ```8````5_H`
M`"4```!P^@``#0```);Z```)````I/H```,```"N^@``!P```++Z```*````
MNOH```(```#%^@``#````,CZ```5````U?H```L```#K^@``&0```/?Z```@
M````$?L``!(````R^P``!0```$7[```*````2_L``!4```!6^P``$@```&S[
M```,````?_L```0```",^P``!P```)'[```,````F?L```T```"F^P``4@``
M`+3[```7````!_P```<````?_```!@```"?\```/````+OP``!,````^_```
M'@```%+\```@````<?P```8```"2_```#@```)G\```$````J/P```P```"M
M_```#0```+K\```.````R/P``!4```#7_```$@```.W\```/`````/T``!0`
M```0_0``&P```"7]```0````0?T``!0```!2_0``:0```&?]```:````T?T`
M`!<```#L_0``)P````3^```:````+/X``!<```!'_@``&P```%_^```9````
M>_X``!\```"5_@``$P```+7^```3````R?X```@```#=_@``!@```.;^```'
M````[?X```@```#U_@``"0```/[^```5````"/\```T````>_P``$P```"S_
M```#````0/\``$8```!$_P``/P```(O_```W````R_\``%<````#``$`'@``
M`%L``0`?````>@`!`"\```":``$`"@```,H``0`(````U0`!``T```#>``$`
M+0```.P``0`$````&@$!`!(````?`0$`$P```#(!`0!/````1@$!`"4```"6
M`0$`'````+P!`0`+````V0$!`!\```#E`0$`'0````4"`0`E````(P(!`"``
M``!)`@$`)````&H"`0`@````CP(!``L```"P`@$`!P```+P"`0`-````Q`(!
M``P```#2`@$`!@```-\"`0`Y````Y@(!``P````@`P$`!P```"T#`0`)````
M-0,!`!,````_`P$`"0```%,#`0`$````70,!`!````!B`P$`"````',#`0`(
M````?`,!``L```"%`P$`#````)$#`0`:````G@,!``\```"Y`P$`!P```,D#
M`0`-````T0,!`!0```#?`P$`#@```/0#`0`,`````P0!`!L````0!`$`+```
M`"P$`0`3````600!`!P```!M!`$`*````(H$`0`&````LP0!``<```"Z!`$`
M$P```,($`0`%````U@0!``0```#<!`$`%P```.$$`0`*````^00!``P````$
M!0$`"0```!$%`0`&````&P4!``D````B!0$`"````"P%`0`)````-04!``H`
M```_!0$`$0```$H%`0`&````7`4!`",```!C!0$`#@```(<%`0`.````E@4!
M``T```"E!0$`"P```+,%`0`=````OP4!``L```#=!0$``@```.D%`0`=````
M[`4!``<````*!@$`!@```!(&`0`)````&08!``<````C!@$`.P```"L&`0`H
M````9P8!`!4```"0!@$`!0```*8&`0`'````K`8!``@```"T!@$`!P```+T&
M`0`%````Q08!``<```#+!@$`#@```-,&`0`)````X@8!``8```#L!@$`"```
M`/,&`0`+````_`8!``<````(!P$`"````!`'`0`'````&0<!`!8````A!P$`
M"0```#@'`0`&````0@<!``L```!)!P$`'````%4'`0`4````<@<!``<```"'
M!P$`"````(\'`0`(````F`<!``4```"A!P$`$````*<'`0`0````N`<!``8`
M``#)!P$`&0```-`'`0`*````Z@<!`!P```#U!P$`!P```!((`0`%````&@@!
M`!`````@"`$`%````#$(`0`+````1@@!``T```!2"`$`%P```&`(`0`$````
M>`@!``D```!]"`$`"@```(<(`0`'````D@@!``(```":"`$`#@```)T(`0`(
M````K`@!`!\```"U"`$`(P```-4(`0`X````^0@!`#$````R"0$`)P```&0)
M`0!D````C`D!`!0```#Q"0$`50````8*`0`X````7`H!`$H```"5"@$`6P``
M`.`*`0`H````/`L!`!$```!E"P$`.````'<+`0`H````L`L!`"P```#9"P$`
M)P````8,`0`;````+@P!`#X```!*#`$`J0$``(D,`0`C````,PX!`!<```!7
M#@$`2````&\.`0"%````N`X!`#`````^#P$`00```&\/`0!;````L0\!`$D`
M```-$`$`'0```%<0`0`8````=1`!`"$```".$`$`'P```+`0`0`K````T!`!
M`"$```#\$`$`'0```!X1`0`1````/!$!`#,```!.$0$`)0```((1`0`G````
MJ!$!`!\```#0$0$`,````/`1`0!I````(1(!`#T```"+$@$`90```,D2`0!-
M````+Q,!`"D```!]$P$`*P```*<3`0`O````TQ,!`"X````#%`$`,````#(4
M`0!4````8Q0!`%H```"X%`$`2````!,5`0!*````7!4!`#(```"G%0$`+P``
M`-H5`0`L````"A8!`"T````W%@$`<0```&46`0!O````UQ8!`+,```!'%P$`
M%P```/L7`0`E````$Q@!`#(````Y&`$`*0```&P8`0`^````EA@!`"(```#5
M&`$`4@```/@8`0`E````2QD!``L```!Q&0$`L0```'T9`0!%````+QH!`"$`
M``!U&@$`,````)<:`0`E````R!H!`!P```#N&@$`,0````L;`0`'````/1L!
M``<```!%&P$`!````$T;`0`-````4AL!``L```!@&P$`#@```&P;`0`+````
M>QL!``4```"'&P$`$````(T;`0`"````GAL!`%D```"A&P$`!0```/L;`0`2
M`````1P!``0````4'`$`!P```!D<`0`(````(1P!``4````J'`$``P```#`<
M`0`0````-!P!``P```!%'`$`$P```%(<`0`-````9AP!``(```!T'`$`!P``
M`'<<`0`&````?QP!`!0```"&'`$`#````)L<`0`8````J!P!``8```#!'`$`
M$@```,@<`0`,````VQP!``,```#H'`$`*@```.P<`0`$````%QT!``8````<
M'0$`!P```",=`0`?````*QT!`#4```!+'0$`+@```($=`0`O````L!T!`!<`
M``#@'0$`(````/@=`0`;````&1X!`!@````U'@$`)````$X>`0`?````<QX!
M`!H```"3'@$`(````*X>`0`:````SQX!`#(```#J'@$`+P```!T?`0`K````
M31\!`!\```!Y'P$`(P```)D?`0`?````O1\!`!H```#='P$`)0```/@?`0`F
M````'B`!`"4```!%(`$`)````&L@`0`8````D"`!`!T```"I(`$`)````,<@
M`0`8````["`!`"(````%(0$`)0```"@A`0`\````3B$!`!\```"+(0$`(P``
M`*LA`0`?````SR$!`"````#O(0$`&@```!`B`0`8````*R(!`"8```!$(@$`
M'@```&LB`0`I````BB(!`!X```"T(@$`"0```-,B`0`,````W2(!`!<```#J
M(@$`+P````(C`0`D````,B,!``<```!7(P$`#P```%\C`0`4````;R,!``X`
M``"$(P$`#0```),C`0`D````H2,!``4```#&(P$`!P```,PC`0`B````U",!
M`"4```#W(P$`'0```!TD`0`:````.R0!``<```!6)`$`QP```%XD`0`+````
M)B4!`!4````R)0$`!@```$@E`0`)````3R4!``L```!9)0$`%P```&4E`0`&
M````?24!`#,```"$)0$`$P```+@E`0`3````S"4!``<```#@)0$`#P```.@E
M`0`'````^"4!`#(`````)@$`(0```#,F`0`3````528!``P```!I)@$`$0``
M`'8F`0`R````B"8!``@```"[)@$`"0```,0F`0`*````SB8!`!0```#9)@$`
M"@```.XF`0`=````^28!``@````7)P$`#0```"`G`0`0````+B<!`#H````_
M)P$`'P```'HG`0`(````FB<!`!H```"C)P$`!@```+XG`0`5````Q2<!``<`
M``#;)P$`"````.,G`0`)````["<!`#\```#V)P$`!P```#8H`0`/````/B@!
M``X```!.*`$`$````%TH`0`)````;B@!``D```!X*`$`"````((H`0`3````
MBR@!``<```"?*`$`&0```*<H`0`*````P2@!`!<```#,*`$`%````.0H`0`*
M````^2@!``P````$*0$`%P```!$I`0`$````*2D!`"H````N*0$`$0```%DI
M`0`'````:RD!``(```!S*0$`$````'8I`0`8````ARD!``L```"@*0$``P``
M`*PI`0`(````L"D!``8```"Y*0$`!P```,`I`0`-````R"D!``L```#6*0$`
M%````.(I`0`5````]RD!``X````-*@$`%0```!PJ`0`O````,BH!`"````!B
M*@$`'````(,J`0`,````H"H!`#$```"M*@$`"0```-\J`0`.````Z2H!`#L`
M``#X*@$`%0```#0K`0`%````2BL!`!(```!0*P$`/P```&,K`0`2````HRL!
M``H```"V*P$`!@```,$K`0`$````R"L!`!,```#-*P$`!0```.$K`0`&````
MYRL!``8```#N*P$`!````/4K`0`,````^BL!``H````'+`$`"@```!(L`0`%
M````'2P!``P````C+`$`#````#`L`0`-````/2P!`!@```!++`$`&0```&0L
M`0`?````?BP!`!T```">+`$`$0```+PL`0`"````SBP!``0```#1+`$`"@``
M`-8L`0`&````X2P!``4```#H+`$``P```.XL`0`,````\BP!`$4```#_+`$`
M&@```$4M`0`U````8"T!`"@```"6+0$`4P```+\M`0`9````$RX!`'(````M
M+@$`(````*`N`0`U````P2X!`$4```#W+@$`,````#TO`0`H````;B\!`"D`
M``"7+P$`)@```,$O`0!@````Z"\!`"4```!),`$`*````&\P`0`H````F#`!
M`"(```#!,`$`,````.0P`0`2````%3$!`!,````H,0$`$````#PQ`0!Y````
M33$!``D```#',0$`<P```-$Q`0!\````13(!`"L```#",@$`%P```.XR`0`6
M````!C,!``\````=,P$`'P```"TS`0`?````33,!`!P```!M,P$`40```(HS
M`0`4````W#,!``H```#Q,P$`!0```/PS`0`&`````C0!``@````)-`$`!0``
M`!(T`0`2````&#0!``P````K-`$`$````#@T`0`3````230!`!T```!=-`$`
M#P```'LT`0`;````BS0!`"0```"G-`$`#P```,PT`0`*````W#0!``0```#G
M-`$`"0```.PT`0`+````]C0!`!H````"-0$`(@```!TU`0`(````0#4!``<`
M``!)-0$`!0```%$U`0`4````5S4!`"D```!L-0$`!P```)8U`0`(````GC4!
M``\```"G-0$`&````+<U`0`4````T#4!``@```#E-0$`#````.XU`0`/````
M^S4!``<````+-@$`!@```!,V`0`4````&C8!``8````O-@$`"0```#8V`0`*
M````0#8!``P```!+-@$``P```%@V`0`(````7#8!``0```!E-@$`"@```&HV
M`0`'````=38!``4```!]-@$`!````(,V`0`9````B#8!``(```"B-@$`"0``
M`*4V`0`&````KS8!``8```"V-@$`!0```+TV`0`G````PS8!``0```#K-@$`
M#P```/`V`0`3`````#<!``<````4-P$``@```!PW`0`'````'S<!``8````G
M-P$`(0```"XW`0`&````4#<!`!````!7-P$`'@```&@W`0`2````AS<!``8`
M``":-P$`"0```*$W`0`B````JS<!``<```#.-P$`!P```-8W`0`+````WC<!
M``4```#J-P$``@```/`W`0`+````\S<!`,`!``#_-P$`$@```,`Y`0`.````
MTSD!``L```#B.0$`"````.XY`0`#````]SD!``$```#[.0$`!0```/TY`0`+
M`````SH!`!$````/.@$`#````"$Z`0`-````+CH!``4````\.@$`*0```$(Z
M`0`/````;#H!``P```!\.@$`$@```(DZ`0`(````G#H!`!$```"E.@$`"@``
M`+<Z`0`,````PCH!`!,```#/.@$`$0```.,Z`0`.````]3H!`!$````$.P$`
M$````!8[`0`&````)SL!``X````N.P$`%0```#T[`0`1````4SL!`!,```!E
M.P$`$P```'D[`0`+````C3L!`"P```"9.P$`$@```,8[`0`]````V3L!`$D`
M```7/`$`90```&$\`0!F````QSP!`&@````N/0$`:0```)<]`0!``````3X!
M``H```!"/@$`!0```$T^`0`&````4SX!`!(```!:/@$`!P```&T^`0`1````
M=3X!`!,```"'/@$`*P```)L^`0`H````QSX!``L```#P/@$`$P```/P^`0`(
M````$#\!`"0````9/P$`#P```#X_`0`'````3C\!``\```!6/P$`$````&8_
M`0`0````=S\!`!,```"(/P$`%0```)P_`0`:````LC\!`!````#-/P$`%@``
M`-X_`0`,````]3\!`"T````"0`$`&@```#!``0`?````2T`!`!$```!K0`$`
M'````'U``0`4````FD`!``<```"O0`$`!P```+=``0`Y````OT`!``@```#Y
M0`$`"`````)!`0`,````"T$!``@````800$`!P```"%!`0`(````*4$!``@`
M```R00$`"P```#M!`0`%````1T$!`!H```!-00$`#````&A!`0`,````=4$!
M`!0```""00$`%P```)=!`0`4````KT$!`"$```#$00$`#@```.9!`0`?````
M]4$!`!T````50@$`(@```#-"`0`>````5D(!`!4```!U0@$`%````(M"`0`.
M````H$(!`!L```"O0@$`!@```,M"`0`&````TD(!``<```#90@$`&0```.%"
M`0`)````^T(!``@````%0P$`"@````Y#`0`2````&4,!`!D````L0P$`!P``
M`$9#`0`5````3D,!``\```!D0P$`%P```'1#`0`+````C$,!``@```"80P$`
M%P```*%#`0`3````N4,!`!D```#-0P$`,@```.=#`0`S````&D0!``D```!.
M1`$`"````%A$`0`5````840!``4```!W1`$`!0```'U$`0`=````@T0!``L`
M``"A1`$`(````*U$`0`N````SD0!`!4```#]1`$`*````!-%`0`J````/$4!
M`"L```!G10$`*P```)-%`0`)````OT4!``D```#)10$`"@```--%`0`(````
MWD4!`"\```#G10$`+````!=&`0`N````1$8!`%````!S1@$`+0```,1&`0`M
M````\D8!`"T````@1P$`/P```$Y'`0`I````CD<!`"L```"X1P$`+0```.1'
M`0`S````$D@!`!0```!&2`$`&````%M(`0`J````=$@!`"<```"?2`$`.0``
M`,=(`0`.`````4D!``T````020$`$0```!Y)`0`%````,$D!``L````V20$`
M(0```$))`0`F````9$D!``<```"+20$`"0```)-)`0`6````G4D!``H```"T
M20$`"@```+])`0`.````RDD!``,```#920$`"0```-U)`0`+````YTD!``<`
M``#S20$`!P```/M)`0`'`````TH!``@````+2@$`!P```!1*`0`+````'$H!
M`!`````H2@$`&@```#E*`0`X````5$H!`"(```"-2@$`(0```+!*`0`0````
MTDH!``L```#C2@$`#@```.]*`0`*````_DH!``@````)2P$`!P```!)+`0`'
M````&DL!`!`````B2P$`!P```#-+`0`6````.TL!``4```!22P$`"````%A+
M`0`(````84L!``H```!J2P$`"0```'5+`0`@````?TL!`!4```"@2P$`"0``
M`+9+`0`1````P$L!``X```#22P$`"0```.%+`0`#````ZTL!``,```#O2P$`
M%P```/-+`0`4````"TP!``L````@3`$`!````"Q,`0`(````,4P!``D````Z
M3`$`3P```$1,`0`J````E$P!``8```"_3`$`"````,9,`0`<````STP!`!P`
M``#L3`$`(0````E-`0`H````*TT!`!\```!430$`*0```'1-`0!8````GDT!
M`"P```#W30$`"@```"1.`0`+````+TX!`"T````[3@$`"P```&E.`0`-````
M=4X!``(```"#3@$`$0```(9.`0`0````F$X!``X```"I3@$`$````+A.`0`2
M````R4X!`!,```#<3@$`$P```/!.`0`&````!$\!`!P````+3P$`'@```"A/
M`0`3````1T\!`!(```!;3P$`!0```&Y/`0`(````=$\!`&(```!]3P$`%0``
M`.!/`0`(````]D\!`!8```#_3P$`!````!90`0`&````&U`!`!P````B4`$`
M&P```#]0`0`6````6U`!`!L```!R4`$`(0```(Y0`0`D````L%`!``L```#5
M4`$`#P```.%0`0`&````\5`!`!@```#X4`$`'0```!%1`0`;````+U$!`!L`
M``!+40$`!0```&=1`0`3````;5$!``X```"!40$`"0```)!1`0`)````FE$!
M`!8```"D40$`&P```+M1`0`)````UU$!``8```#A40$`$@```.A1`0`4````
M^U$!``L````04@$`%0```!Q2`0`(````,E(!``<````[4@$`$````$-2`0`*
M````5%(!``X```!?4@$`!P```&Y2`0`)````=E(!``P```"`4@$`!P```(U2
M`0`4````E5(!``\```"J4@$`%0```+I2`0`&````T%(!`!P```#74@$`%0``
M`/12`0`6````"E,!`#$````A4P$`/@```%-3`0`G````DE,!`#(```"Z4P$`
M!````.U3`0`%````\E,!``H```#X4P$`#@````-4`0`)````$E0!``P````<
M5`$`"0```"E4`0`5````,U0!``H```!)5`$`%@```%14`0`>````:U0!`!\`
M``"*5`$`(0```*I4`0`B````S%0!`!T```#O5`$`*`````U5`0`?````-E4!
M`"D```!650$`'P```(!5`0`B````H%4!`!X```##50$`*@```.)5`0`K````
M#58!`",````Y5@$`*0```%U6`0`P````AU8!`"\```"X5@$`%@```.A6`0`N
M````_U8!`!4````N5P$`MP```$17`0`2````_%<!`"(````/6`$`)P```#)8
M`0`G````6E@!`"4```""6`$`'````*A8`0`@````Q5@!`"\```#F6`$`(```
M`!99`0`@````-UD!`"P```!860$`1P```(59`0`/````S5D!``@```#=60$`
M!@```.99`0`'````[5D!``\```#U60$`%`````5:`0`6````&EH!`!0````Q
M6@$`$````$9:`0`;````5UH!``@```!S6@$`!````'Q:`0`1````@5H!`!$`
M``"36@$`%@```*5:`0`4````O%H!`!(```#16@$`,P```.1:`0`(````&%L!
M`!0````A6P$`!@```#9;`0`1````/5L!`!<```!/6P$`'P```&=;`0`2````
MAUL!``(```":6P$`"@```)U;`0`'````J%L!`!<```"P6P$`!````,A;`0`%
M````S5L!`!(```#36P$`!0```.9;`0`2````[%L!`!````#_6P$`!P```!!<
M`0`5````&%P!`!4````N7`$`$@```$1<`0`4````5UP!``L```!L7`$`"```
M`'A<`0`+````@5P!``\```"-7`$`#@```)U<`0`.````K%P!`!D```"[7`$`
M#0```-5<`0`1````XUP!`"H```#U7`$`&````"!=`0`/````.5T!`!H```!)
M70$`%````&1=`0`3````>5T!``@```"-70$`$@```)9=`0`C````J5T!`"$`
M``#-70$`$P```.]=`0`1`````UX!``8````57@$`$P```!Q>`0`)````,%X!
M`"X````Z7@$`+0```&E>`0`(````EUX!``D```"@7@$`'0```*I>`0`+````
MR%X!`!H```#47@$`&@```.]>`0`)````"E\!``L````47P$`"````"!?`0`:
M````*5\!`!4```!$7P$`,0```%I?`0`5````C%\!`!,```"B7P$`'````+9?
M`0`(````TU\!`#P```#<7P$`"````!E@`0`J````(F`!``P```!-8`$`(@``
M`%I@`0`+````?6`!``8```")8`$`"@```)!@`0`,````FV`!``H```"H8`$`
M"````+-@`0`4````O&`!``H```#18`$`#0```-Q@`0`T````ZF`!`!D````?
M80$`!P```#EA`0`1````06$!``,```!380$`"0```%=A`0`+````86$!``P`
M``!M80$`%P```'IA`0`/````DF$!`!````"B80$`$````+-A`0`5````Q&$!
M`!(```#:80$`%0```.UA`0`'`````V(!``<````+8@$`"@```!-B`0`,````
M'F(!``(````K8@$`"@```"YB`0`1````.6(!`!\```!+8@$`(0```&MB`0`*
M````C6(!``X```"88@$`$P```*=B`0`;````NV(!``H```#78@$`.P```.)B
M`0`F````'F,!``<```!%8P$`#@```$UC`0`(````7&,!`!,```!E8P$`<@``
M`'EC`0`9````[&,!``4````&9`$`$@````QD`0`(````'V0!``8````H9`$`
M#@```"]D`0`&````/F0!``@```!%9`$`!P```$YD`0`&````5F0!``X```!=
M9`$`#0```&QD`0`0````>F0!``T```"+9`$`&P```)ED`0`.````M60!``H`
M``#$9`$`"P```,]D`0`'````VV0!`"````#C9`$`"@````1E`0`*````#V4!
M``\````:90$`/````"IE`0`.````9V4!``H```!V90$`#0```(%E`0`<````
MCV4!`!T```"L90$`*````,IE`0`G````\V4!`!T````;9@$`'````#EF`0`B
M````5F8!`!D```!Y9@$`!P```)-F`0`:````FV8!``P```"V9@$`!@```,-F
M`0`'````RF8!``H```#29@$`#````-UF`0`3````ZF8!``8```#^9@$`&0``
M``5G`0`<````'V<!``\````\9P$`$0```$QG`0`2````7F<!``\```!Q9P$`
M(@```(%G`0`7````I&<!`"(```"\9P$`)````-]G`0`1````!&@!`!,````6
M:`$`%````"IH`0`6````/V@!``@```!6:`$`0@```%]H`0`O````HF@!`#\`
M``#2:`$`4@```!)I`0!`````96D!`"T```"F:0$`/0```-1I`0`2````$FH!
M``<````E:@$`!P```"UJ`0`,````-6H!`!(```!":@$`%P```%5J`0`+````
M;6H!``H```!Y:@$`!0```(1J`0`9````BFH!``T```"D:@$`!P```+)J`0`B
M````NFH!`"D```#=:@$`$@````=K`0"'````&FL!`!H```"B:P$`!@```+UK
M`0`%````Q&L!``P```#*:P$`!@```-=K`0`(````WFL!``H```#G:P$`"0``
M`/)K`0`U````_&L!``P````R;`$`%P```#]L`0`%````5VP!``D```!=;`$`
M"@```&=L`0`6````<FP!`!(```");`$`%@```)QL`0`@````LVP!``,```#4
M;`$`!````-AL`0`0````W6P!``@```#N;`$`#0```/=L`0`'````!6T!`#4`
M```-;0$`"0```$-M`0`'````36T!`!<```!5;0$`$@```&UM`0`'````@&T!
M``D```"(;0$`!````))M`0`+````EVT!``8```"C;0$`!@```*IM`0`'````
ML6T!``X```"Y;0$`"P```,AM`0`+````U&T!`!$```#@;0$`"````/)M`0`6
M````^VT!``L````2;@$`!P```!YN`0`6````)FX!`"$````];@$`!@```%]N
M`0`)````9FX!``4```!P;@$`"0```'9N`0`'````@&X!``T```"(;@$`#```
M`)9N`0`'````HVX!``X```"K;@$`!@```+IN`0`$````P6X!`#,```#&;@$`
M-P```/IN`0`V````,F\!`"````!I;P$`!@```(IO`0`/````D6\!``4```"A
M;P$`"````*=O`0`>````L&\!`!8```#/;P$`!P```.9O`0`'````[F\!`"``
M``#V;P$`#0```!=P`0`)````)7`!`!L````O<`$`!@```$MP`0`)````4G`!
M`"0```!<<`$`"````(%P`0`,````BG`!``X```"7<`$`"````*9P`0`)````
MKW`!``@```"Y<`$`,P```,)P`0`O````]G`!`#(````F<0$`)@```%EQ`0!&
M````@'$!`#H```#'<0$`*@````)R`0`R````+7(!`#(```!@<@$`,P```)-R
M`0`E````QW(!`!(```#M<@$`$P````!S`0`.````%',!`"`````C<P$`'P``
M`$1S`0`?````9',!`!T```"$<P$`"0```*)S`0`+````K',!``H```"X<P$`
M"````,-S`0`G````S',!`"@```#T<P$`,````!UT`0`*````3G0!`!D```!9
M=`$`(P```'-T`0`.````EW0!`!<```"F=`$`"0```+YT`0`/````R'0!`!4`
M``#8=`$`$P```.YT`0`H`````G4!`&D````K=0$`%0```)5U`0`0````JW4!
M`!$```"\=0$`&0```,YU`0`:````Z'4!`!4````#=@$`!P```!EV`0`5````
M(78!``8````W=@$`$@```#YV`0`.````478!`!@```!@=@$`&@```'EV`0`Q
M````E'8!`*,```#&=@$`%0```&IW`0`&````@'<!`!<```"'=P$`/0```)]W
M`0`*````W7<!`#4```#H=P$`"P```!YX`0`+````*G@!`!L````V>`$`$P``
M`%)X`0`/````9G@!``\```!V>`$`&0```(9X`0`O````H'@!`"X```#0>`$`
M+````/]X`0`K````+'D!`",```!8>0$`(@```'QY`0`;````GWD!`$$```"[
M>0$`$@```/UY`0`6````$'H!`!D````G>@$`&````$%Z`0`/````6GH!`!<`
M``!J>@$`&P```()Z`0`4````GGH!`!@```"S>@$`+P```,QZ`0`=````_'H!
M`!D````:>P$`,0```#1[`0`2````9GL!``@```!Y>P$`#P```()[`0`D````
MDGL!`!0```"W>P$`#P```,Q[`0`;````W'L!`!0```#X>P$`&@````U\`0`5
M````*'P!`!T````^?`$`(P```%Q\`0`>````@'P!`!<```"??`$`%````+=\
M`0`=````S'P!`!P```#J?`$`"P````=]`0`:````$WT!``8````N?0$`!@``
M`#5]`0`#````/'T!``D```!`?0$`!````$I]`0`3````3WT!``@```!C?0$`
M"0```&Q]`0`(````=GT!``<```!_?0$`!P```(=]`0`&````CWT!``@```"6
M?0$`%P```)]]`0`'````MWT!``D```"_?0$`!0```,E]`0`(````SWT!``8`
M``#8?0$`#P```-]]`0`.````[WT!`!````#^?0$`$0````]^`0`+````(7X!
M`!0````M?@$`!@```$)^`0`L````27X!`!,```!V?@$`#0```(I^`0`/````
MF'X!``L```"H?@$`"P```+1^`0`2````P'X!`"<```#3?@$`!@```/M^`0`)
M`````G\!`"<````,?P$`$@```#1_`0`5````1W\!``@```!=?P$`"0```&9_
M`0`+````<'\!``4```!\?P$`)0```()_`0`*````J'\!`!0```"S?P$`"P``
M`,A_`0`<````U'\!`"D```#Q?P$`&````!N``0`'````-(`!``4````\@`$`
M"@```$*``0`P````38`!``<```!^@`$`!P```(:``0`1````CH`!`!,```"@
M@`$`!P```+2``0`*````O(`!`!````#'@`$`"````-B``0`6````X8`!``X`
M``#X@`$`#@````>!`0`0````%H$!`!4````G@0$`%P```#V!`0`/````58$!
M`!T```!E@0$`$0```(.!`0`2````E8$!``D```"H@0$`!P```+*!`0`*````
MNH$!`#D```#%@0$`"````/^!`0`4````"((!`"\````=@@$`&P```$V"`0`5
M````:8(!`!8```!_@@$`%@```):"`0`5````K8(!`!````##@@$`$````-2"
M`0`8````Y8(!`!4```#^@@$`'@```!2#`0`<````,X,!`!T```!0@P$`"@``
M`&Z#`0`'````>8,!``D```"!@P$`$0```(N#`0`0````G8,!``4```"N@P$`
M"P```+2#`0`*````P(,!`!,```#+@P$`5````-^#`0`5````-(0!``T```!*
MA`$`!0```%B$`0`(````7H0!`!H```!GA`$`&@```(*$`0`:````G80!``T`
M``"XA`$``@```,:$`0`$````R80!`"@```#.A`$``P```/>$`0`%````^X0!
M``H````!A0$`#`````R%`0`&````&84!``8````@A0$`#@```">%`0`3````
M-H4!``<```!*A0$`"0```%*%`0`(````7(4!``4```!EA0$`!0```&N%`0!7
M````<84!``\```#)A0$`$@```-F%`0`@````[(4!``4````-A@$`!P```!.&
M`0`5````&X8!`",````QA@$`,0```%6&`0`-````AX8!``D```"5A@$`"```
M`)^&`0`/````J(8!``L```"XA@$`"@```,2&`0`4````SX8!`"L```#DA@$`
M&@```!"'`0`9````*X<!`!````!%AP$`B0```%:'`0")````X(<!``8```!J
MB`$`!@```'&(`0`(````>(@!``8```"!B`$`#@```(B(`0`.````EX@!``8`
M``"FB`$`3````*V(`0`2````^H@!``T````-B0$`"P```!N)`0`6````)XD!
M`$0````^B0$`!P```(.)`0`%````BXD!``<```"1B0$`(@```)F)`0`(````
MO(D!``H```#%B0$`&0```-")`0`:````ZHD!``D````%B@$`!0````^*`0`C
M````%8H!`#$````YB@$`20```&N*`0`0````M8H!`!\```#&B@$`*````.:*
M`0`G````#XL!`!`````WBP$`!0```$B+`0`.````3HL!``D```!=BP$`#P``
M`&>+`0`*````=XL!``<```""BP$`$P```(J+`0`'````GHL!``D```"FBP$`
M$0```+"+`0`*````PHL!``H```#-BP$`#0```-B+`0`'````YHL!`!$```#N
MBP$`%`````",`0`2````%8P!``@````HC`$`#P```#&,`0`0````08P!`!$`
M``!2C`$`#@```&2,`0`0````<XP!`!$```"$C`$`$````):,`0`2````IXP!
M``H```"ZC`$`)@```,6,`0`3````[(P!``T`````C0$`#0````Z-`0`7````
M'(T!``D````TC0$`#0```#Z-`0`G````3(T!``8```!TC0$`"````'N-`0`&
M````A(T!``<```"+C0$`"P```).-`0`2````GXT!`!4```"RC0$`(0```,B-
M`0`?````ZHT!`!@````*C@$`%@```"..`0`<````.HX!`!X```!7C@$`&@``
M`':.`0`'````D8X!``<```"9C@$`$@```*&.`0`0````M(X!``X```#%C@$`
M&0```-2.`0`C````[HX!`!$````2CP$`%@```"2/`0`)````.X\!``\```!%
MCP$`"````%6/`0`3````7H\!``D```!RCP$`!P```'R/`0`(````A(\!``8`
M``"-CP$`!0```)2/`0`"````FH\!`"4```"=CP$`(@```,./`0`J````YH\!
M`"T````1D`$`%P```#^0`0`@````5Y`!`#0```!XD`$`#@```*V0`0`C````
MO)`!`"@```#@D`$`+0````F1`0`M````-Y$!`#(```!ED0$`%````)B1`0`2
M````K9$!`!(```#`D0$`'0```-.1`0`4````\9$!`!(````&D@$`$````!F2
M`0`2````*I(!`!P````]D@$`+0```%J2`0`M````B)(!`#$```"VD@$`+@``
M`.B2`0`O````%Y,!`"P```!'DP$`8````'23`0`@````U9,!`!(```#VDP$`
M&`````F4`0`1````(I0!`!(````TE`$`)````$>4`0`Q````;)0!`!D```">
ME`$`#0```+B4`0!`````QI0!`$`````'E0$`"@```$B5`0`$````4Y4!`!4`
M``!8E0$`#@```&Z5`0`2````?94!`!@```"0E0$`"0```*F5`0`(````LY4!
M``P```"\E0$`#````,F5`0`'````UI4!``T```#>E0$`"@```.R5`0`-````
M]Y4!``<````%E@$`(0````V6`0`)````+Y8!``<````YE@$`$0```$&6`0`2
M````4Y8!`!````!FE@$`,P```'>6`0`"````JY8!``@```"NE@$`$@```+>6
M`0`+````RI8!``8```#6E@$`$````-V6`0`&````[I8!``8```#UE@$`+P``
M`/R6`0`8````+)<!`"@```!%EP$`5@```&Z7`0`7````Q9<!`",```#=EP$`
M$@````&8`0`*````%)@!`"D````?F`$`#0```$F8`0`3````5Y@!``P```!K
MF`$`"0```'B8`0`,````@I@!`!\```"/F`$`%P```*^8`0`$````QY@!`!``
M``#,F`$`#P```-V8`0`1````[9@!`"4```#_F`$`&````"69`0`9````/ID!
M`!,```!8F0$`(0```&R9`0`)````CID!``<```"8F0$`$0```*"9`0`)````
MLID!``H```"\F0$`"````,>9`0`-````T)D!``H```#>F0$`!0```.F9`0`>
M````[YD!``8````.F@$`%0```!6:`0`*````*YH!`!$````VF@$`"P```$B:
M`0`7````5)H!`"P```!LF@$`&P```)F:`0`,````M9H!``T```#"F@$`&P``
M`-":`0`&````[)H!`"L```#SF@$`!@```!^;`0`=````)IL!``8```!$FP$`
M"0```$N;`0`?````59L!`#4```!UFP$`!@```*N;`0`6````LIL!`!0```#)
MFP$`!````-Z;`0`'````XYL!``D```#KFP$`"0```/6;`0`*````_YL!``D`
M```*G`$`"0```!2<`0`)````'IP!`!L````HG`$`-0```$2<`0`^````>IP!
M`!D```"YG`$`)P```-.<`0`<````^YP!`#P````8G0$`&````%6=`0`C````
M;IT!`!0```"2G0$`+@```*>=`0`F````UIT!``<```#]G0$`"0````6>`0`*
M````#YX!``L````:G@$`%0```":>`0`1````/)X!`"D```!.G@$`(````'B>
M`0`N````F9X!`#,```#(G@$`!@```/R>`0`5`````Y\!``@````9GP$`"```
M`"*?`0`D````*Y\!`!0```!0GP$`%@```&6?`0`0````?)\!``@```"-GP$`
M$P```):?`0`)````JI\!`!````"TGP$`#P```,6?`0`8````U9\!`"H```#N
MGP$`#````!F@`0`'````)J`!``<````NH`$`'@```#:@`0`+````5:`!`!0`
M``!AH`$`!@```':@`0`+````?:`!``T```")H`$`!@```)>@`0`1````GJ`!
M``@```"PH`$`"````+F@`0`3````PJ`!`#````#6H`$`0P````>A`0`%````
M2Z$!``L```!1H0$`&P```%VA`0`D````>:$!`!H```">H0$`!0```+FA`0`2
M````OZ$!`!8```#2H0$`$````.FA`0`(````^J$!`!`````#H@$`+````!2B
M`0`(````0:(!``\```!*H@$`$P```%JB`0`6````;J(!``T```"%H@$`/```
M`).B`0`)````T*(!`"(```#:H@$`$@```/VB`0`6````$*,!`"P````GHP$`
M#````%2C`0`.````8:,!``@```!PHP$`$P```'FC`0`5````C:,!``H```"C
MHP$`%@```*ZC`0`3````Q:,!`!8```#9HP$`"````/"C`0`7````^:,!`!P`
M```1I`$`!@```"ZD`0`(````-:0!`!(````^I`$`%````%&D`0`6````9J0!
M``0```!]I`$`"````(*D`0`+````BZ0!``X```"7I`$`#P```*:D`0`2````
MMJ0!`!(```#)I`$`"````-RD`0`(````Y:0!`!0```#NI`$`$0````.E`0`1
M````%:4!`!`````GI0$`%0```#BE`0`)````3J4!`"@```!8I0$`'````(&E
M`0`:````GJ4!``<```"YI0$`$@```,&E`0`&````U*4!``X```#;I0$`&0``
M`.JE`0`F````!*8!``L````KI@$`!P```#>F`0`#````/Z8!``8```!#I@$`
M"````$JF`0`%````4Z8!``\```!9I@$`%P```&FF`0`-````@:8!`!T```"/
MI@$`'0```*VF`0`:````RZ8!``4```#FI@$`"P```.RF`0`4````^*8!``D`
M```-IP$`#0```!>G`0`)````):<!``P````OIP$`%````#RG`0`4````4:<!
M`%8```!FIP$`&````+VG`0`'````UJ<!``@```#>IP$`%````.>G`0`7````
M_*<!`!P````4J`$`'0```#&H`0`'````3Z@!``<```!7J`$`"````%^H`0`2
M````:*@!`!````![J`$`$0```(RH`0`1````GJ@!`!L```"PJ`$`$P```,RH
M`0`5````X*@!`"0```#VJ`$`$P```!NI`0`4````+ZD!`&(```!$J0$`&P``
M`*>I`0`:````PZD!`"D```#>J0$`&P````BJ`0`:````)*H!`"0````_J@$`
M&@```&2J`0`9````?ZH!`!<```"9J@$`&@```+&J`0`*````S*H!``D```#7
MJ@$`"0```.&J`0`+````ZZH!``@```#WJ@$`%@````"K`0`/````%ZL!`!4`
M```GJP$`"````#VK`0!0````1JL!`$$```"7JP$`*````-FK`0!/`````JP!
M`"````!2K`$`&P```'.L`0`K````CZP!``@```"[K`$`"@```,2L`0`1````
MSZP!`"D```#AK`$`!@````NM`0`7````$JT!`!@````JK0$`30```$.M`0`E
M````D:T!`"$```"WK0$`$@```-FM`0`@````[*T!`!@````-K@$`'````":N
M`0`?````0ZX!`!X```!CK@$`(P```(*N`0`4````IJX!``8```"[K@$`"P``
M`,*N`0`-````SJX!``D```#<K@$`*@```.:N`0`+````$:\!``P````=KP$`
M!P```"JO`0`1````,J\!``H```!$KP$`!0```$^O`0`6````5:\!``D```!L
MKP$`"0```':O`0`$````@*\!``X```"%KP$`&````)2O`0`.````K:\!``<`
M``"\KP$`%0```,2O`0`>````VJ\!`!````#YKP$`#`````JP`0`:````%[`!
M`"@````RL`$`$0```%NP`0`1````;;`!`"8```!_L`$`!@```*:P`0`1````
MK;`!``8```"_L`$`"````,:P`0`&````S[`!`!T```#6L`$`#@```/2P`0`2
M`````[$!`!`````6L0$`!P```">Q`0`)````+[$!``H````YL0$`#````$2Q
M`0`/````4;$!`!<```!AL0$`!@```'FQ`0`M````@+$!`!(```"NL0$`#@``
M`,&Q`0`)````T+$!``X```#:L0$`&````.FQ`0`-`````K(!``4````0L@$`
M%@```!:R`0`$````+;(!``8````RL@$`"````#FR`0`(````0K(!`%0```!+
ML@$`-````*"R`0`9````U;(!``<```#OL@$`!P```/>R`0`*````_[(!``H`
M```*LP$`!P```!6S`0`*````';,!`!4````HLP$`#````#ZS`0`*````2[,!
M``P```!6LP$`"````&.S`0`,````;+,!``D```!YLP$`!P```(.S`0`8````
MB[,!``L```"DLP$`!P```+"S`0`*````N+,!`"4```##LP$`&````.FS`0`'
M`````K0!``@````*M`$`"@```!.T`0`'````'K0!`!,````FM`$`$P```#JT
M`0`(````3K0!`!P```!7M`$`#0```'2T`0`>````@K0!``D```"AM`$`!@``
M`*NT`0`0````LK0!`!4```##M`$`"P```-FT`0`-````Y;0!`!<```#SM`$`
M!P````NU`0`+````$[4!``\````?M0$`#@```"^U`0`%````/K4!`!@```!$
MM0$`"0```%VU`0`<````9[4!`!$```"$M0$`,P```):U`0`F````RK4!`",`
M``#QM0$`>P```!6V`0`4````D;8!`#\```"FM@$`-````.:V`0!%````&[<!
M`$,```!AMP$`'P```*6W`0`7````Q;<!`&0```#=MP$`)@```$*X`0`S````
M:;@!`"H```"=N`$`$P```,BX`0`8````W+@!`'T!``#UN`$`%P```'.Z`0`2
M````B[H!`#@```">N@$`@0```->Z`0`\````6;L!`#<```"6NP$`20```,Z[
M`0!$````&+P!`!X```!=O`$`$P```'R\`0`8````D+P!`!D```"IO`$`)```
M`,.\`0`=````Z+P!`",````&O0$`%````"J]`0`;````/[T!`"$```!;O0$`
M%P```'V]`0`/````E;T!`#````"EO0$`6P```-:]`0`L````,KX!`%(```!?
MO@$`.0```+*^`0`9````[+X!`!H````&OP$`(P```"&_`0`F````1;\!`",`
M``!LOP$`1P```)"_`0!'````V+\!`#T````@P`$`/````%[``0`P````F\`!
M`"H```#,P`$`*@```/?``0`M````(L$!`&<```!0P0$`90```+C!`0"K````
M'L(!`!8```#*P@$`+0```.'"`0`Q````#\,!`#````!!PP$`20```'+#`0`>
M````O,,!`$X```#;PP$`%@```"K$`0`'````0<0!`+$```!)Q`$`10```/O$
M`0`H````0<4!`#,```!JQ0$`&@```)[%`0`>````N<4!`"X```#8Q0$`"0``
M``?&`0`(````$<8!``8````:Q@$`#@```"'&`0`.````,,8!`!(````_Q@$`
M"@```%+&`0`(````7<8!``P```!FQ@$``P```'/&`0!L````=\8!``@```#D
MQ@$`$````.W&`0`%````_L8!``<````$QP$`!0````S'`0`%````$L<!``<`
M```8QP$`&0```"#'`0`(````.L<!`!4```!#QP$`#````%G'`0`%````9L<!
M``<```!LQP$`!P```'3'`0`5````?,<!``H```"2QP$`%P```)W'`0`&````
MM<<!`!L```"\QP$`#P```-C'`0`#````Z,<!`"8```#LQP$`!````!/(`0`&
M````&,@!``<````?R`$`(@```"?(`0!!````2L@!`"@```",R`$`*@```+7(
M`0`6````X,@!`"<```#WR`$`(````!_)`0`?````0,D!`",```!@R0$`'@``
M`(3)`0`;````H\D!`"(```"_R0$`'@```.+)`0`K`````<H!`"D````MR@$`
M*P```%?*`0`?````@\H!`",```"CR@$`(0```,?*`0`<````Z<H!`"8````&
MRP$`)P```"W+`0`C````5<L!`!T```!YRP$`'````)?+`0`B````M,L!`"4`
M``#7RP$`'0```/W+`0`E````&\P!`"8```!!S`$`.@```&C,`0`A````H\P!
M`"4```#%S`$`(P```.O,`0`D````#\T!`!X````TS0$`'````%/-`0`D````
M<,T!`"````"5S0$`*P```+;-`0`C````XLT!``D````&S@$`$P```!#.`0`:
M````),X!`!H````_S@$`&@```%K.`0`*````=<X!`!````"`S@$`&0```)'.
M`0`2````J\X!`!,```"^S@$`(@```-+.`0`(````]<X!``D```#^S@$`)```
M``C/`0`G````+<\!`"\```!5SP$`(0```(7/`0`,````I\\!`/H```"TSP$`
M$0```*_0`0`5````P=`!``H```#7T`$`#0```.+0`0`4````\-`!`!\````%
MT0$`"````"71`0`Q````+M$!`!P```!@T0$`&@```'W1`0`)````F-$!`!4`
M``"BT0$`"P```+C1`0!%````Q-$!`"\````*T@$`&0```#K2`0`4````5-(!
M`!8```!IT@$`(````(#2`0`0````H=(!`!$```"RT@$`$@```,32`0`;````
MU](!``P```#ST@$`&P````#3`0`)````'-,!`!0````FTP$`$````#O3`0`Z
M````3-,!`!L```"'TP$`"@```*/3`0`<````KM,!``@```#+TP$`(P```-33
M`0`'````^-,!``D`````U`$`"0````K4`0`Q````%-0!``<```!&U`$`$```
M`$[4`0`4````7]0!`!$```!TU`$`"P```(;4`0`-````DM0!``D```"@U`$`
M%P```*K4`0`-````PM0!`!8```#0U`$`$@```.?4`0`7````^M0!`!4````2
MU0$`"0```"C5`0`+````,M4!`!D````^U0$`!````%C5`0`J````7=4!``\`
M``"(U0$`!P```)C5`0`%````H-4!``P```"FU0$`$@```+/5`0`+````QM4!
M``,```#2U0$`#````-;5`0`+````X]4!``8```#OU0$`$@```/;5`0`)````
M"=8!`!,````3U@$`%````"?6`0`.````/-8!`!@```!+U@$`*P```&36`0`7
M````D-8!`!8```"HU@$`#````+_6`0`D````S-8!`!````#QU@$`&@````+7
M`0`X````'=<!`"$```!6UP$`!@```'C7`0`1````?]<!`$8```"1UP$`#P``
M`-C7`0`,````Z-<!``<```#UUP$`!````/W7`0`4`````M@!``8````7V`$`
M!P```![8`0`(````)M@!``8````OV`$`#0```#;8`0`/````1-@!``8```!4
MV`$`!0```%O8`0`,````8=@!``P```!NV`$`#0```'O8`0`>````B=@!`"(`
M``"HV`$`&@```,O8`0`=````YM@!``\````$V0$``@```!39`0`$````%]D!
M`!`````<V0$`!@```"W9`0`'````--D!``0````\V0$`$````$'9`0!'````
M4MD!`!$```":V0$`*0```*S9`0`D````UMD!`$0```#[V0$`$````$#:`0!E
M````4=H!`!L```"WV@$`6````-/:`0`N````+-L!`!8```!;VP$`,````'+;
M`0`S````H]L!`"0```#7VP$`2````/S;`0`C````1=P!`"<```!IW`$`$P``
M`)'<`0`P````I=P!`#````#6W`$`%P````?=`0`2````']T!`!0````RW0$`
M3P```$?=`0`3````E]T!`&T```"KW0$`5````!G>`0`G````;MX!`!(```"6
MW@$`&@```*G>`0`4````Q-X!`"(```#9W@$`&P```/S>`0`:````&-\!`%P`
M```SWP$`%@```)#?`0`+````I]\!``8```"SWP$`!P```+K?`0`(````PM\!
M``H```#+WP$`&P```-;?`0`/````\M\!`!8````"X`$`&@```!G@`0`F````
M-.`!`!$```!;X`$`'````&W@`0`>````BN`!``D```"IX`$`$0```+/@`0`$
M````Q>`!``X```#*X`$`$````-G@`0`9````ZN`!`"P````$X0$`"@```#'A
M`0`'````/.$!``@```!$X0$`&P```$WA`0`N````:>$!``P```"8X0$`"P``
M`*7A`0`1````L>$!`!T```##X0$`%P```.'A`0`+````^>$!``<````%X@$`
M%`````WB`0`)````(N(!``X````LX@$`%P```#OB`0`+````4^(!``H```!?
MX@$`$0```&KB`0`.````?.(!``(```"+X@$`"P```([B`0`%````FN(!``T`
M``"@X@$`!@```*[B`0`&````M>(!``8```"\X@$`$0```,/B`0`"````U>(!
M``H```#8X@$`"````./B`0`(````[.(!``@```#UX@$`)@```/[B`0`&````
M)>,!``P````LXP$`$````#GC`0`.````2N,!``0```!9XP$`"0```%[C`0`)
M````:.,!`"8```!RXP$`!````)GC`0`0````GN,!`"(```"OXP$`$@```-+C
M`0`'````Y>,!``T```#MXP$`(P```/OC`0`*````'^0!``4````JY`$`%@``
M`##D`0`%````1^0!``(```!-Y`$`"P```%#D`0`!````"`0``+4"```Q!0``
MS0(``$<&```Q`````````'D#``"I!````````$0#``!M!```.P8``/8&````
M````0@4```````"G!@``V0$``'P$``"T`````````)P&````````C@$``!D&
M``!N!0``T`4```````#U`@``N`4``#0"``"]!```,P$``!\````7!0``MP(`
M`,P!``!F!@``804``)\#``#^`@``$04``&P%`````````````+T%````````
M``````````#_````0@0```\&`````````````!\%````````0P```)0"``!I
M`@``?P4`````````````-@,``+P%```3`````````$\$``!&!@```````!0#
M```B`@``Y0$``````````````````&X$`````````````((````<`P``>0``
M`*T$``!V!```000``"`%```0!0``8`,``'D!```%`0```````.P"``!J`@``
M``````````#]`0``V@```"\```#$````\P0``(8!```/!```Z0(``&T!``"%
M!0``>P,``*L%``"7!0``1P(``)$```"X`P```````&@"``#*!0``P@0``#L`
M````````"0<``.\&``!1!@```````%8#````````)`$``&4&``#\`@``U```
M```````6!P``004``%,"````````4@$````````H!@``+`$``)(#```@`P``
ML0,```````#N`@```````)`&``#I````)P,``,T%``!)`P``SP(``(,#``!;
M````-P$``%P$````````I`$```````!3!@``&@,```````"V`P```````'0#
M``"(`0``Y@(``($!``#_!0```0$``(L#``"M`0``=`$``*`&```"!P``704`
M`-X"````````6@,`````````````9P(``/,#``#C`P``I0```%`#````````
M`````'4!````````+P0``#($````````*P````````#W!@``<P4```<$``#E
M!@`````````````)````````````````````)`(``/T#``"[````DP```+`$
M````````RP8```````"/!````````#8```"4!```2`(``&L```!7!```````
M``````#.!0``#`(``#<$``!>````FP(```````````````````````#R`P``
M`````'P%````````R@8```````!O!@``PP,``.\%```=`P``9@(``!T%````
M````3`4``!<$``!@`@``8P```.T!``!T!0``IP$``!P$````````E0,``'$#
M````````[`$``)`$````````-0,``"T%``##!@``PP4``+,%```V`@``)@,`
M```````*`@```````(H!``"1!```"`8``%L#````````*0,``$H"``#0`@``
M^P8``'H!```5`@``_@0``/`#```F`0``Z@```,0%```````````````````-
M!P``9@$``&,#````````(00``/<$```8!0`````````````/`P``````````
M``!8!@```````+,!````````U00``%L!```A`@``=P8``*D#``"'`0``W0,`
M```````"!@``Z`8``-`!``"Y`@``:@,``*0#``!?`````````$("``"B`@``
M`````/4%```G!0```````&0!````````3`8``"4!``")`P``\04``,L#````
M`````````#D&````````"````($#``#J`0``90(```````",`P``L@,``-X!
M``#F!```+@0`````````````TP,``'P"``"U``````````````"E`0``=```
M`-L&``"X`0``500``*$"```$!0``.`,``'\"````!P``SP8````````7`P``
M,P```((%``!J`0``T04``.(&``#&!````````%4`````````7P4````````B
M!@``B0$``+$%`````````````*\%``!0!0``!`,```L&````````40(```L$
M``"B`0``CP8```````!L````-`4``/@!``!#`@``0@```&0&````````H@8`
M`%@!``!:!@``>`,``!,"``##`0``P0$``-X#``""!@``6@4`````````````
M`````'H%``#1!@```````*L#``!H!```L`4``*4&```2!@``A@,```X$``!I
M!```50,``$T%``#)!0``=08````````-`````````.@#```6`0``A@4`````
M``"X````L00`````````````'@8``"P$````````W`(``"H%````````````
M`#(&```````````````````/`@``W0(```````"L`P``/P8``%(#````````
M3P4``!$&``#U!````````'<```!Q`0``[0``````````````K08``/\"```<
M!@``SP,``,`%````````Y`,``%L"```!!@``Z0,``)0```#@!```````````
M``"O!@``Q@8``%4!```%!0``&`(```````!7!0``ZP```(D"`````P``````
M`&(#````````T0(```(%````````?P,`````````````JP$``)L```"9!```
M\`0``"H"``"U!@```````%`````S!```3`,```````!S!```IP0````````\
M!0``3`0```````!#!@``A@8``$L%```````````````````*`0``\@```+D!
M``":`P``BP4``%T!```+`0``D`(``#@$````````N@4``&<$``!&````@P0`
M``````#V````]0$``(0```#P!0``40```!H%```N!@``A@```"@!```]`0``
MN@8``$D"``"C````208``$D!````````R`0``$\#```T!```&0<`````````
M`````````,P"````````$P8``)4$``!^``````````````#*`P``$P,``)H%
M```J`0``80```$L$```N````;P,``'P#``!%!@``V@4``/@$```.!0``1```
M`%($``"%`@```````"8"``"O`@```````(<"````````:`$``(T$```;`P``
M+P8```(`````````EP0``,$"``!-!@``=P$````````7`0``JP8``-(!``".
M!0```````,$&```;!P``1`$``.("````````&`<```````#O`P``%`(``&,"
M``!^`P```````-8!``"*!```!`0```````!&!0``\@0``+`&``#\`0``Q`,`
M`(8$```L!@```````-@&````````YP$``%(``````````````*@#``"O````
M`````,X`````````U0(```````#5`P```````"L"```V`0``F`8``(`!```[
M`0``$P<```````#N!````````/$!``!_````NP$``*H$````````>P(``!<`
M``!B!````````$P!``#R!@``R@$``%T```#I`0``8`8```````"7````````
M```````;!@``YP```!T!``#7`P``!@$``)X!``">!@``W08``",!```#!```
M"`(``!$!```1`@``I0,``#H"``"1`@``M04``+4!``#E!````````#`"``!-
M!```_0(``.\```"_````X0```+<$```H!0``5`4```````!5!0``9P$``#\"
M``"]`P```````.($``"5!@``#@```*,$````````]`8``'D$````````U`0`
M`-0%``#3`0``UP0``%H"````````9````#0&````````!@(``+D`````````
MSP0``'$```#5!@```````/0``````````````)(%```S`P``T@8``)8`````
M````@`0``!H```!Y!@``L@0``*0"``"?!@``$@4``)X$``#(`0``60(``'\!
M``#^`0``H00``!`$``#Z`@``^`(``*$%````````I@```*X&```A!@``````
M`'0&``"J`P``(`(``-L#``````````````````#?!```[````(<$```+````
M`````!P"``#G`@``Q0```*8!```?!@```````*H!``#P`0``````````````
M`````````+\"```^`0``!`(`````````````J0$``+P#````````L@(``"T&
M``#C`0``Z@8``"L$``"Y!```+0,``%D#``````````````````#:!@``L```
M``````#B!0``]@,```````#0`P``70(``%@```!3`P```````!$'``"A!@``
M/P$``"P%```B!0``2P8```````"6`0``IP(``(P````]!@```````+0&````
M`````````'L!````````N@```/X#``"1`P``6`,``+8!``!3````A00``,<"
M````````00(```````#2`@``P````',&````````RP```+\&````````````
M`(@```#X````X0,```T!``"2!@``3@(`````````````#`````````#9`P``
MM`0```````!K`P``XP(``-H#```^`@``800``!4%```Q`@````````````"N
M!```7`$```````#:`0``W`8````````2`P``^0```'@&````````R````!0&
M```-`P``A0```(X$```(!0``X04``!$```!G!0``-0$`````````````UP(`
M``````!B````,`0``#@"``"[!@``S`8``!L!``#N`0``,0$``&H&```R````
ML@8``$\&``#R`0``D`````````#=!```YP0``)4!``!.!```M00``&$"``#F
M!0```````+\!````````-00````````6`@``2@4``&4$``!M`@``1`8``(0"
M``"V`@``%@8``.X&``````````````P%````````3@`````````4````````
M`)($``!=`P``*`(``-$!``"^`@``=`(``/,%``!D`@``;@,``!X!``#*````
MDP,``&D``````````````%<#``!D`P``L0```*H%``#S````?P8````````W
M`@``P0```*X#``!C!0```````)D!`````````````.P%``!6!```@04``)0%
M``#U````10````\%`````````````/8!``"S````O`$``'4$```<!0``````
M`)L#````````[P0```````"``P``T@,```````"D!```<04`````````````
M[`,``(@%`````````````#X&```E!@````````````!0`@``GP4``)<&``#6
M!@``.00````````9````00,```$#```>````:P4``$$&```>!P``J04``+(!
M```3!0``[00```````#/`0``;0,``&8```#Q!```1P$``&8$``!9!0``1P4`
M`-\!``!5`@``H@0``+L%``#S!@``Y@8``)8%``"=`@``\P(````````#!P``
M<00``%\!``!'!```200```````````````````````!`!```]`(``#(!````
M````P`$``)`!`````````````,D#``#0````````````````````_`0```8#
M``#"!@``````````````````!00``-P%`````````````)H$``!``@``6`(`
M`"X"``!P````:0,``-\&````````-0(```8'````````_````,<#````````
M-04``"$!`````0``_0````````"\`````````),!````````^`8``/``````
M`````````(D&``!.!@``J@(``"D"``![!@``[P$``!8```"Z`0``E`$``&\`
M``"/`@``5P$``,8%``#1!```B04``-,"``#\`P``$@$``!`"``#^!0``;P$`
M`'<%``"2`@``@P``````````````-0`````````J`````````(0%``"=`0``
M``````````"^!@``U04``#T"``"L`0``$`<`````````````UP$``$,#``#[
M`0`````````"```!!0``LP(```````#M`@``*0````````"-!@``V04``'L`
M``"Y!@````````````!0!```;`$``+D#``!(`P``R@0``.D%``#)!@``````
M`$H$``!C!````@(``%D`````````<08```````"Z`@``Y0```!@$``#Y!@``
M@@$``(T"``![!```)`8``&X!```W!0``AP,``+D%````````,P8``#("````
M````$@<``$\!``"Q`@``'0(```````!U````G`,``*L`````````(P(```<#
M``````````````````"^`0```````!4'``"@`@``=@```.\"``#!`P``C@,`
M`,D!``#D`@``I`4``$\"````````Q@$``"8&````!@``L08```````!Z!@``
M\P$```````!G`P``NP(```````")!```.0,``*\$``!H`P``8`0```````!0
M`0```````)T%``"3!0``)P```,,"````````&P(``,D"``!$!````````$H`
M````````*@8``!<"````````L@4``$L"````````N`8```````!D!```````
M`%X"```_`P``[`8``,T#``#[`P``DP0``.L#``#Z````2````$(#``#"````
MB@4``/`&``#_`0``)`0``"L#``"0!0```````'($```3`0``F@(``&("``#(
M`P```````````````````````)0&```Y````@@,``.4"````````````````
M``!7!@``*0$``````````````````',"````````K0```+4#``!-````1`(`
M`,4%````````+`,```````"D````'@4``%P%````````\08```````!^!@``
MY@$``"D&```I!0```````/4#```#!@``&`$``*@"``!2!@``^04``&H$````
M````S08``"T$``!*`P``V`$``&D&``#1`P```````*,#``#)!```B`8``-L`
M``"L!```[0,``)L!````````,P(``-X`````````E0(``#,%````````6P4`
M`/$``````````````(<```#<````6`4```P!``#1````2@8``.T%``!]`P``
MQ0(``(P%````````$0,``(P&``#8`P``'P0```````#I!```0`,``(L!``#,
M!0``+0$````````7!P````````````!0!@``?08``$P"``#[````-P```#0#
M``!]````[@4````````!`@``X00``#X$``!P!@```````",&```G!@``````
M``````!Z`P```````-8$```V!@``>P4````````A!0```````(L&```I!```
M`````````````````````(@"```P!@``````````````````S````&8#``#Z
M`0``F0`````````[`P```````'8%```G`0``5`````T&``"*````*`0``(X`
M``!K!@``R0````(!``#:!````````&,&``"C`@```````,8"```9`@``V```
M`*$!``!W`@``6P0``$X%```?!P``2`$```````#7!@``U`,``*(```"F`@``
M9P8``*(#``!6`@``#`,``-T!``"!!```(0,``'`$``#@````V0(``,4!```T
M`````````'`"``!9!@``\@4``&P$``#W!0```````'0$`````````````+X$
M``"F!0``(`8``$\```"5!0```````,T```"@!```L`,``&H%```0````=@$`
M`(0&``#@`@```````"4#``#V!0``P@(```0&``"P`0``K@$``"`!``!A`0``
MU@```+0#``#6`P````````0!``#[!0```````.8#``!&`@``&0,``(\%```K
M!@``LP0``)4```````````````````!\`0``>`(`````````````S@(``"4%
M```G!```J@8``/H#``!'`````````(P!```'!0```````*D```!\````7P0`
M``0'````````]@0````$```-!````````)X"````````U@(``(T%``#K`@``
M:04```````"!````J08``/D"``#D`0``J`8```````"G!0```````+\#``!&
M`P``````````````````H`4``'$"``"Z!````````/0!``!C`0``@P4``*@%
M``"L`@``]@(``.X`````````508``)H```"L!0``"P(```````!+`0``/`0`
M`-P$``!J```````````````.!P``P@,``,P#``#;`@``````````````````
MQP````\!````````J`0``,4#``!L`P``/P```#L$``````````````H```"M
M!0``7````-T``````````````(($``#``@```````+T"```O`0``30$``,P$
M``",`@``U`8``%0"````````$@(``$,!`````````````*L$``"!!@``!P$`
M`",```")````O`(``'D%````````0@$``.T&``#Z!@``6P8``(,"```0`P``
M>0(``*4$``#\!@``'P$```````!3!0```````!8#``#=!0``=@(```````!P
M`0````````````"<!0``^0,``(````#B`P``"0$``'(#``"#`0``W@8`````
M````````A@(``)`#``#D!0```````#X```"=!@``K````,<!`````````@,`
M`#$$````````>`````````"1`0``)0(``!T&```2````X`$```D%````````
M+0(```````!%`@```````)T```#Q`P```````!$$``!Z`@``204``,H"``#+
M`0``F``````````)!@``Y`0``&@&````````&`,``!8%``#(!@```````"T`
M```Q!@``,@,``#@%````````*P4```L#```%`@``^`,``/H%``!?`@``P@$`
M`'@$`````````````%,$``!I`0``QP8``/T%``!O!0``MP4``+H#``!>!0``
M`````,X!````````H`````````"2````"`<``%$#```B`0```````#T%```\
M`0``HP4```($```*!0``]P````````"=`P``C`0``.@%``!P`P``E@(``#D!
M```;!````````"0%``"\!```,`4```````!7````MP8````````C!0``````
M`!P'```<`0````````````!4`0``?00``.(`````````>@0``$`%````````
M``````````#Q`@```````$4$``"8`P``0````+\%``"8!```RP(``.@`````
M````P`8``+X#``!@!0```````)H&``!X!0```````!P```!V!@``<`4``#$#
M``!>!@``*@0``$0%``#<`0``0`$``!\"````````0P0```X"````````90,`
M`!H$```R!0``X@$```8```!7`@``IP`````````Z`P``L`(``!D%``"7`@``
M'00``'(%``#K`0``"@0```````!&!````````%("``#2````#@$``/\#````
M````+@4``-8%``"+!```:`````````!:!```C0$````````'`````````.H#
M``"Q`0``I0(`````````````"@8``+<```!1!```_P0``(\#````````````
M``P'``"C`0```````-@"```(`P``5@$``-@$````````M@4``"H#``!1`0``
M+@$``&@%``"X!```X08```````#[`@``2P,```````#"!0``RP4``!D$``!R
M`@```````#X%``!F!0``,`$```8&``#9!```(````,0"````````Z`0``/X`
M``"1!@``C@(`````````````.04``"X#```:!P``I@8``*T"``#<`P``2`0`
M``````"6!```;P(``"4`````````2`8``'8#```/!P```````(0$``#9!@``
MZP4`````````````>@```!X"````````2@$``%P"``#2!0``$P0````````-
M`@```P$```````"8!0``Z@0``%H!````````WP```+L#``"?````_`4``)X#
M````````M@```)<#````````Q@,``*\!``":`0```````*$#```%`P``8@8`
M`!4```!]!0``Z@4``.4%``"?`@``_00``#4&````````YP8``'X!``"'!@``
M)````(@$````````ZP8```H'```H`P``AP4``/T&```B!```DP8``#P#``!4
M!@``(P0````````;!0``8```````````````2`4``(`&```!!````````-L$
M```F!0``5`,```````!L`@``00$``$T#`````````````)0#````````X`,`
M`'X$```+!P``+P(``'\$```4`0```````"(````P`P``<@$````````G`@``
M`````+8&````````P`0``.$"``"$`P````````````!<!@``JP(``!4!``#?
M!0``(@,``)8&```\!@``MP$``/0$``#!!```K`8``/\&``"J````9P``````
M````````ZP0``&T&``!3`0```````(H#````````Z@(``!\#``"T!0``&`8`
M`&$&```Y`@``G`(``'T!``!S`0``O08``"8$``#:`@``PP0```````#7````
MFP4```P&``"<`0``1P,``#H%``#5`0``7@,``$8!``"9!0``&P```,X$``!=
M!````````&T%``"8`@``"`$```````#H`0``-`$``.4#``"F!````````&\$
M````````E@,``)X%`````````````/("``!E!0``@`4``,$%````````IP,`
M````````````MP,``-($``"H````#@8```````#%!```^`4`````````````
MSP```%H```"S`P``Q`8``````````````````&4!``#+!```60$``!T'``"S
M!@`````````````\`````````(X&`````````````````````````````'X"
M``#C!````````"\%````````G`0```````#(`@````````````#L!```````
M`#@````E!```*P$``-\#``!8!```P`,``"`$```````````````````:`0``
M708``%\#``#@!@``#@,``-,$`````````````+\$``#4`0``-@4`````````
M````>`$``#H&```%!@``#04```H#````````%P8```````!%`P``V0```+T`
M``!9!```WP(```8%``!N!@``"P4````````6!```\`(``#\%````````````
M``````!K!```A`$``+L$``#5````!0```(,&````````'@,```8$``#W`0``
MF`$``)T$```Z````<P,```````"R````+`(``$T"`````````````-0"```)
M`P```````$L`````````QP0``&L"````````)`,``%P#````````$@0``(@#
M```L````00```!T```!U!0``XP``````````````T`0``(H"``"/`0``5@4`
M`)P```#W`P``"00``'T"``"+````3@$``.0```#F````K@(``(H&``"F`P``
MZ08``-X$````````%`0``.<#```8`````````!4&````````.@0``-L!````
M`````````!X$`````````````,X&````````O`8``#L%``"@`0``%`<``(4#
M``#W`@```````*T#`````````````'<#``!^!0``V`4``,4&````````-@0`
M``````"?!````````-<%````````G@```#\$``"N`````````-,&``#;!0``
M0`8``&0%``#>!0```````%(%``#3````J`$```,"```[`@``/`(```````!6
M!@``[@,``,8``````````````#```````````````#X#``!"!@``I04``/4&
M````````@@(``/L$``"``@``O@4```````#Z!`````````````"O`P``C0``
M`',````:`@``-P8```D"``"!`@``EP$```,%``";!@````````<&``!>!```
MT`8``%$%``!@`0``104``#H!```X`0``/0```$P````5!````````,@%``!R
M!@``J0(```4'````````*````'(````F````SP4``````````````````.@"
M``"B!0````4``$D````/````````````````````M@0```````"C!@``F0(`
M`+T!```0`0``S00``!0%``!>`0``S@,````````5`P``I`8``'4#``!N`@``
M`````)\!``!M````-P,`````````````^00```````"3`@``M`(```````!.
M`P``8@$``)L$``"2`0```0<``,0!``#T`P``S0$``,<%````````XP4``)D#
M```X!@``7P8``&L!``"1!0``=0(```P$``#C!@``!P<``/X&``!6````F08`
M`#T$```$`````````'<$``!B!0```P,``!D!``#G!0```````'P&``#A`0``
M`````$,%````````A08``!`&``"+`@```````/0%`````````````,,```#Y
M`0``K@4```<"`````````````&P&``"^`````````&$#``!N````10$`````
M````````M`$``.`%````````Y`8``!H&``!4!```TP4``(T#````````Q`0`
M`*`#``"/````H0```+@"``!E````/0,``"$````C`P```````(4!```O`P``
M`P```````````````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@
M*'1O9&%Y*0`@*'EE<W1E<F1A>2D`(&%N9``@870@`"!O<@`E9"`E<R!A;F0@
M)7,`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT
M`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VX`)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D
M>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@
M0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T
M`"5S.B`E<P`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O
M("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA
M=``R-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R
M('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$%-(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I
M=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N
M+@!!8V-O=6YT:6YG`$%C=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S<V5S
M.@!!8W1I=F%T92!38W)I<'0`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI
M;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W
M(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE
M=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D
M<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D:71I;VYA;"!3971T:6YG<P!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI
M;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI
M;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L
M:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S
M97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S
M`$%L;"!O9B!T:&4@9F]L;&]W:6YG`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E
M<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y
M(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!0
M87-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA
M:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT
M.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!
M;G-W97(`06YS=V5R960`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A
M`$%N>2!O9B!T:&4@9F]L;&]W:6YG`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N
M(&ES(')E861Y+@!!<'!L>2!&:6QT97)S`$%P<&QY('1O($-H:6QD(%-H87)E
M<P!!<'!R;W9E`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E
M($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&1E;&5T92!T:&ES(')U;&4_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R9V5N=&EN
M80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E
M;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!
M=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D
M9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO
M;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T;VUA=&EC86QL>2!U<&1A=&4@
M=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\`079A:6QA8FQE(&9I96QD
M<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O
M=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S
M('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN90!"8V,`0F5G:6YS('=I
M=&@`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A
M;@!":7)T:&1A>0!";&%C:VQI<W0`0FQA8VML:7-T($5D:70`0FQA8VML:7-T
M(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R
M:79E<BX`0FQA8VML:7-T960@061D<F5S<P!";&%C:VQI<W1E9"!!9&1R97-S
M97,`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";V1Y`$)O;&0`0F]L:79I
M80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`
M0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!"
M;W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R
M:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES
M=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%L;0!#
M86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E
M;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N
M;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E
M9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO
M=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P
M<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E
M9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`
M0V%P92!697)D90!#87!T:6]N`$-A<V4@4V5N<VET:79E`$-A=&5G;W)I97,@
M86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#8P!#96QL(%!H;VYE`$-E;&P@
M4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL
M('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT
M97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@
M*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@
M4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B!E;6%I;',N`$-H86YG97,@<V%V960N`$-H87(`0VAE8U]K($QI
M;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I
M`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E
M<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I
M`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S
M97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O($-O
M;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D
M<P!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE
M8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY
M`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC
M97,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT86EN
M<P!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2`E<P!#
M;W!Y(&]F("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV
M;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T
M86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@
M;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@
M9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B
M87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A
M=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!N97<@
M9F]L9&5R`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS
M`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE
M`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I
M=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER
M:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1)4T%"
M3$5$.B``1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV
M960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E86-T:79A
M=&4@4V-R:7!T`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!)
M;F1E;G0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9FEN:71I
M;VYS`$1E;&5T90!$96QE=&4@)7,`1&5L971E($-O;F1I=&EO;@!$96QE=&4@
M1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S
M86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L
M>0!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L
M971E9`!$96QI=F5R(&EN=&\@;7D@24Y"3U@`1&5L:79E<B!I;G1O(&UY($E.
M0D]8(&%N9"!C;W!Y('1O`$1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@<F5D
M:7)E8W0@=&\`1&5L:79E<B!T;R!F;VQD97(`1&5L:79E<GD@=&EM90!$96YM
M87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W
M(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0`1&ER96-T;W)Y`$1I<V%B;&4@)7,`1&ES86)L960`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!N
M;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/P!$:7-P
M;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!?;F]T('-E;F0@<F5S<&]N<V5S
M('1O(&)U;&L@;W(@;&ES="!M97-S86=E<P!$;R!N;W0@9&5L971E`$1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('1H:7,Z`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]E<VXG="!B96=I;B!W:71H`$1O97-N
M)W0@8V]N=&%I;@!$;V5S;B=T(&5N9"!W:71H`$1O97-N)W0@97AI<W0`1&]E
M<VXG="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I`$1O;6EN:6-A`$1O;6EN
M:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O
M=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET("5S
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO
M;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y
M<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R
M97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O
M;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S
M=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE("5S`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N86)L960`16YD
M('EE87(`16YD<R!W:71H`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`
M17%U86P@=&\`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N`$5S=&]N:6$`171H:6]P:6$`171H;FEC
M`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C
M=71E`$5X:7-T:6YG(%)U;&5S`$5X:7-T<P!%>'!A;F0`17AP96-T960@)RDG
M`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP
M:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@
M<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE
M9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I<@!&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&87@`1F5B
M<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1FEJ
M:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I
M;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO
M860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<B!!;&P@365S
M<V%G97,`1FEL=&5R($]N;'D@4V5E;B!-97-S86=E<P!&:6QT97(@3VYL>2!5
M;G-E96X@365S<V%G97,`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%)U;&4`1FEL
M=&5R(%)U;&5S`$9I;'1E<B!38W)I<'0@1&ES<&QA>0!&:6QT97(@7U)U;&5S
M`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@8V]P
M:65D('1O('1H92!F;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M
M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ
M("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD97(@
M(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I('1H870@;6%T
M8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@9&5L971E9"X`1FEL=&5R(&%C=&EV
M:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@8F5E;B!C;W!I
M960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&1E;&5T960N`$9I;'1E
M<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@:&%S(&)E
M96X@;6]V960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@;F]T(&9O=6YD
M+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I
M>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!A;B!I;F-O;6EN9R!M97-S86=E('1H
M870@;6%T8VAE<SH`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9`!&;W)W87)D(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@
M9FEL=&5R:6YG(&1R:79E<BX`1F]R=V%R9',`1F]R=V%R9',@161I=`!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA
M;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`
M1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A
M;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R
M871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV
M96X@3F%M90!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E
M871E<B!T:&%N`$=R96%T97(@=&AA;B!O<B!E<75A;"!T;P!'<F5E8V4`1W)E
M96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P
M<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E
M<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA
M;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(
M87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(
M96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(
M;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA
M8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E
M("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D
M:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET
M>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL
M960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S
M`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W
M;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS
M($]N;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@
M:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@
M9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA
M9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R
M;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@
M)60`26UP;W)T86YT`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L
M9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A
M;"!5<V5R<P!);F1I=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN
M('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$EN9&]N97-I80!);F5X
M:7-T86YT(&UA:6QB;W@@<W!E8VEF:65D(&9O<B!M97-S86=E(&1E;&EV97)Y
M+@!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R
M="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?
M0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E
M<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M
M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`
M26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R
M90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T
M:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`
M26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI
M='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A
M;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A
M;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES`$ES;&4@;V8@36%N`$ES;B=T`$ES
M;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA
M;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE
M<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`
M2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K
M:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E
M871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y
M(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M
M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A
M<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO
M=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F
M="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,97-S('1H86X`3&5S<R!T
M:&%N(&]R(&5Q=6%L('1O`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY
M80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H
M="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E
M<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N
M;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S
M964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S
M`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)1`!,
M:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI
M<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET
M97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C
M86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A
M<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`
M3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@
M;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`
M34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N
M`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K
M92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT
M80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<E]K
M(&UE<W-A9V4@87,@9&5L971E9`!-87)C:`!-87)G:6X`36%R:R!M97-S86=E
M(&%S.@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T
M:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@
M27-L86YD<P!-87)T:6YI<75E`$UA=&-H97,@*'=I=&@@<&QA8V5H;VQD97)S
M*0!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L
M;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&)L86-K;&ES=&5D
M(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@36%X
M:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E
M<W-E<R!T;R!B;&%C:VQI<W0N`$UA>&EM=6T@;G5M8F5R(&]F('=H:71E;&ES
M=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@
M36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D
M9')E<W-E<R!T;R!W:&ET96QI<W0N`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE
M;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@
M5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF
M:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N
M`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO
M9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&%D
M9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G92!T;P!-:7-S:6YG(&-O;F9I9W5R
M871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N
M="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$
M+@!-:7-S:6YG(')E87-O;B!F;W(@<F5J96-T`$UI<W-I;F<@<F5A<V]N(&EN
M('9A8V%T:6]N+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL
M+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E
M`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E
M<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT
M:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE
M87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V90!-;W9E($1O=VX`
M36]V92!,969T`$UO=F4@4FEG:'0`36]V92!2=6QE($1O=VX`36]V92!2=6QE
M(%5P`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY
M($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.
M3RP@22!$;R!.3U0@06=R964`3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C
M871I;VX@<F5P;&EE<SH`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE
M<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),
M`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC
M>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W
M;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N
M`$YE=R!2=6QE`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD
M`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X
M="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`
M3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RX`3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES
M(&AO<W0`3F\@8F%C:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K96YD<RYP:'``
M3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R
M($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!6
M1E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!H96%D97)S('-P96-I
M9FEE9`!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N
M`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O
M9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A4
M5%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)
M34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@
M3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I
M<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N
M9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S8W)I<'0@9V5N97)A=&5D+@!.
M;R!S:61E<P!.;R!S=')I;F=S('-P96-I9FEE9`!.;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.
M;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO
M="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!E<75A;"!T;P!.;W0@:6UP
M;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@
M;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W
M<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`
M3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@86)O
M=70@<V-R:7!T('5P9&%T:6YG+@!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI
M<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN
M9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P
M=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC
M<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3
M:&]W97)S`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A
M;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M
M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S
M<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA
M=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@
M4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/
M<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0
M97)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO
M;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C
M;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F
M;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92X`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@
M9F]L9&5R.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O
M;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E
M(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN
M="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@
M2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!2
M4T$@4'5B;&EC($ME>2`H)60@8FET*0!27V5A<V]N`%)A9&EO('-E;&5C=&EO
M;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A;F1O
M;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C96EV960`4F5D:7)E8W0@=&\`4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE
M;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E9W5L87(@97AP
M<F5S<VEO;@!296IE8W0@=VET:"!R96%S;VX`4F5L871I;VYS:&EP($)R;W=S
M97(`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!2
M96UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E
M;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@
M9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@
M8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E
M<V5N="!4;P!297-E;G0M9G)O;0!297-E=`!297-E="!087-S=V]R9`!297-E
M="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($9I;'1E<G,@3&ES
M=`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@4G5L97,@3&ES=`!2975N
M:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`
M4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE`%)U;&4@0V]P:65D`%)U;&4@1&5L971E9`!2
M=6QE($1I<V%B;&5D`%)U;&4@16YA8FQE9`!2=6QE($YA;64`4G5L97,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E
M<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(
M`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET
M=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F
M<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R
M:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3
M879E("5S`%-A=F4@3W!T:6]N<P!3879E(%-E='1I;F=S`%-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BX`4V-I96YC90!38W)I<'0`4V-R:7!T(%5P9&%T:6YG`%-C<FEP="!N
M;W0@=7!D871E9"X`4V-R:7!T('-U8V-E<W-F=6QL>2!A8W1I=F%T960N`%-C
M<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N`%-E87)C:`!396%R8V@@
M16YG:6YE<P!3965N`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C
M="!A(&9I96QD`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@
M;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E
M;&5C="!T87)G970@9F]L9&5R`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C
M:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396QF+41E
M9FEN960@2&5A9&5R`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N
M9&5R`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N
M=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO
M<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W($%C=&EV92!38W)I<'0`
M4VAO=R!#=7)R96YT(%-C<FEP=`!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@
M8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO
M=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAR:6YK`%-H<FEN:R!O<B!M;W9E
M(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3
M:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R
M:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA
M`%-L;W9E;FEA`%-N;W<@4VAO=V5R`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG
M<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S
M`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U
M=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A
M8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN
M`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E
M:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]P(&-H
M96-K:6YG(&EF('1H:7,@<G5L92!M871C:&5S/P!3=&]R86=E(&9O<FUA=`!3
M=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE
M7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z`%-U8FIE8W0`4W5B;6ET`%-U8G-C
M<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S
M`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E
M`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P
M97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N
M9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC
M`%0M4W1O<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R
M=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@
M;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T
M92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E
M>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O
M<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M`%1H92!D<FEV97(@<V%I9#H@`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B
M92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I
M<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO
M<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE
M('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O
M=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N
M97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4
M:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH
M86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R
M>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H
M87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H
M="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C
M:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T
M82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@
M8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE('-C<FEP="X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D
M971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O
M9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A
M9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI
M<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I
M<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM
M92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET
M;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I
M`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L
M<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R
M:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP
M92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R
M('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K
M<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A
M8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N
M`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA
M;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T
M960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!G
M<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I
M;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R
M<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`
M57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`57-E<FYA;64Z`%5S
M97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686-A=&EO;B!%
M9&ET`%9A8V%T:6]N($UE<W-A9V4`5F%C871I;VX@:7,@;F]T('-U<'!O<G1E
M9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T
M97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N
M=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M
M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E
M<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L
M('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M
M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)
M<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE
M($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`
M5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`
M5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O
M;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S
M=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H7VET96QI<W0@
M861D<F5S<V5S.@!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7
M:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET
M;W(N`%=H:71E;&ES=`!7:&ET96QI<W0@161I=`!7:&ET96QI<W0@:7,@;F]T
M('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!7
M:&ET96QI<W1E9"!!9&1R97-S97,`5VED=&@`5VED=&@@:6X@0U-3('5N:71S
M`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@
M=6YI=`!7:61T:#H`5VEK:0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8+5!R
M:6]R:71Y`%@M4F5F`%@M4W!A;2U,979E;`!8+5-P86TM4V-O<F4`6"U3<&%M
M+5-T871U<P!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A
M8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!A="!L96%S="!O;F4@96UA:6P@861D<F5S<R!F;W(@=VAI8V@@=&AE
M('9A8V%T:6]N(&UE<W-A9V5S('-H;W5L9"!B92!A8W1I=F%T960N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@
M8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R
M;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!
M9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U
M<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9
M;W5R(&9U;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E
M<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I
M<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;
M3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X
M="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F
M("5S70!?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SH`7T%D9')E<W-E<R!T
M;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z`%]!9&UI;FES=')A=&EO;@!?0FQA
M8VML:7-T`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]$96QE=&4@;65S
M<V%G92!C;VUP;&5T96QY`%]%;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@
M;&EN93H`7T9O<G=A<F0`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT
M/P!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?36]V92!M97-S
M86=E('1O(&9O;&1E<CH`7TUY(&5M86EL(&%D9')E<W-E<SH`7T]P=&EO;G,`
M7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V-R:7!T`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`7U9A8V%T:6]N`%]7:&ET96QI
M<W0`861D<F5S<R!B;V]K`&%N9`!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`
M9F%L;&EN9P!F:65L9`!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`
M:#H`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6%T8V@`;6MI<V]F<R!E<G)O
M<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N
M=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT`'!I
M>&5L<P!P<F]C;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\`<FES:6YG
M`'-H;W<@9&EF9F5R96YC97,`<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!)
M;F=O`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D
M`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M
M5F5R<VEO;CH@26YG;R`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,2TS,"`Q
M-3HU-"LP,C`P"DQA<W0M5')A;G-L871O<CH@5FEL:75S(%-U;7-K87,@/'9I
M;&EU<T!L;FLN;'0^"DQA;F=U86=E+51E86TZ($QI=&AU86YI86X@/'9I;&EU
M<T!L;FLN;'0^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ,PI#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU
M<F%L/2AN)3$P/3TQ("8F(&XE,3`P(3TQ,2`_(#`@.B!N)3$P/CTR("8F("AN
M)3$P,#PQ,"!\?"!N)3$P,#X],C`I(#\@,2`Z(#(I.PH`("AP<FEE\"`E<R!D
M:65N87,I`"`H;7EG='5K87,@)7,I`"`H\&EA;F1I96XI`"`H=F%K87(I`"!I
M<@`@`"!A<F)A`"5D("5S(&ER("5S`"5D+61I96[X('!R;V=N;WKK`"5S("T@
M<&%S=&%B80`E<R!A;G1S<&%U9&%S`"5S($M"`"5S('!R;V9I;&%K=&EK;W,@
M=F5I:W-M86D@+2!P871V:7)T:6YI;6%S`"5S(')E9VES=')A8VEJ80`E<R!N
M=6]S=&%T;W,`)7,@:F%U(&5G>FES='5O:F$N`"5S("5S("5S`"5S('ER82!P
M<FEV86QO;6%S`"5S(&UI;G5TZW,`)7,@;F5R87-T87,N`&YU;R`E<R!I:VD@
M)7,@:?`@)7,`)7,@861R97/X(&MN>6=E;.L`)7,@:V%L96YD;W)I=7,`)7,@
M=?YR8?#X(&MN>6=E;.L`)7,@9&%R8O@@<^!R8?!A<P`E<SH@)7,`+"!G^W-I
M86D@)7,@)7,`+"!K:6YT82!N=6\@)7,@:6MI("5S`"TM('!A<VER:6YK:71E
M("TM`#$R('9A;&%N9/@@9F]R;6%T87,`,C0@=F%L86YD^"!F;W)M871A<P`R
M-"!V86QA;F1O<P#0:6%M(&)L;VMU:2!R96EK86QI;F=A('9I971A(&1U;VUE
M;O@@8F%ZZVIE+@#!=GEK;R!R:6UT82!K;&%I9&$`3F]RZV1A;6D@=?YK;V1U
M;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4$=0(')A:W3@
M+@!.;W+K9&%M:2!P871I:W)I;G1I('!A<VER8?!Y=.`@;&%I\&O@('!R:79A
M;&]T92!T=7+K=&D@=FEE\.!JX2!01U`@<F%K=.`N`$YO<NMD86UI(&%T:V]D
M=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!T
MX&KA(%!'4"!R86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N`$YO
M<NMD86UI('!A<VER8?!Y=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE
M\.!JX2!I<B!S;&%P=.!JX2!01U`@<F%K='5S+"!B96D@_FEN;W1I('-L87!T
MX&K@(&9R87KF+@!.;W+K9&%M:2!A=&MO9'5O=&D@;&%I\&O@('!R:79A;&]T
M92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!3+TU)344@<F%K='5S+"!B
M96D@_FEN;W1I('-L87!TX&K@(&9R87KF+@!.;W+K9&%M:2!P87-I<F'P>71I
M(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@
M4R]-24U%(')A:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBX`3F]R
MZV1A;6D@=?YK;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@
M:N$@4R]-24U%(')A:W3@+@!!32!R;V1Y;6%S`$%-+U!-`$%022!)1`!!<&EE
M(/#A(')E9&%K=&]R:?@`07!I92XN+@!6:7-I\&MA:2!A<&'H:6]J90!6:7-I
M\&MA:2!P97(@=FED=7+A`%-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I
M(%9&4R!K871A;&]GX"X`4VES=&5M82!N971U<FD@=&5I<VGX('-U:W5R=&D@
M5D93(&9A:6S@+@!3;&%P=&'^;V1I<P!3X'-K86ET82!U_O!A;&1Y=&$N`$%P
M<VMA:71A`%9E:6MS;6%S(&%D<F5S86US(&GP(&IU;V1O:F\@<^!R8?!O.@#!
M:G5N9W1I('-K<FEP=.``4W5K=7)T:0!3=6MU<G1I('!O9W)U<.$`4W5K=7)T
M:2!P;W1E:7-E<P!";&]K;R#A=&5R<&EM87,Z`%-U:W5R=&D@;F%U:N`@9W)U
M<.8`4W5K=7)T:2!N875J87,@=&5I<V5S`$YA=6IO('9A<G1O=&]J;R!S=6O[
M<FEM87,Z`%!R:63K=&D@<W1U;'!E;.$`3F%U:O@@;F%R:?@@<')I9.MJ:6UA
M<P!3=6MU<G1I('!O<N``4')I9.MT:2`E<R!M96YI=2!P<FEE($UO>FEL;W,@
MX7)A;FMI^"!J=6]S=&]S`,%T<F%U:W1I(.$@861R97/X(&MN>6=E;.8Z`,%T
M<F%U:W1I(.$@;6%N;R!A9')E<_@@:VYY9V5LYCH`4W5K=7)T:2!V87)T;W1O
M:N``5F%R=&]T;VKX(&O[<FEM87,@:?!J=6YG=&%S+@!087!I;&1O;6D@;G5S
M=&%T>6UA:0!!9')E<V%S`$%D<F5S86D`061M:6YI<W1R=6]T:2`M(&=A;&D@
M;G5S=&%T>71I('1E:7-E<R!K:71I96US('9A<G1O=&]J86US`%9A;&1Y;6%S
M`$)A;F5R:6%I`$%F9V%N:7-T86YA<P!!;&)A;FEJ80!!;/YY<F%S`%!R879A
M<F3K`$QY9VEU;W1I`$QY9VEA=FEM87,Z`%9I<V]S`%9I<VD@<')I<VEJ=6YG
MYB!V87)T;W1O:F%I`%9I<V]S(&=R=7#K<P!6:7-O<R!T96ESZW,`5FES;W,@
M:V5T=7)I;W,@<'5SZW,`5FES87,@<V5K86[H:6%S('/@;'EG87,`3&5I<W1I
M(&ME;&5TX"!A9')E<_@`3&5I<W1I(&YA=61O=&D@<W5R^_!I=6]TX"!SX')A
M\.`_`$IA=2!E9WII<W1U;VIA`$%L=&5R;F%T>79U<R!)35-0('!R:7-I:G5N
M9VEM87,`06QT97)N871Y=G5S($E-4U`@<VQA<'1A_F]D:7,`06QT97)N871Y
M=G5S($E-4U`@=F%R=&]T;VIO('9A<F1A<P!!;'1E<FYA='EV=7,@96PN('!A
M\'1O(&%D<F5S87,`06QT97)N871Y=OMS(/!A8FQO;F%I`$%L=&5R;F%T>79U
M<R!T96MS=&%S`$%M97)I:V]S(%-A;6]A`,%V963K=&4@;F5L96ES=&ENX"!R
M96EK\&WF+@!!;F1O<F$`06YG;VQA`$%N9VEL86D`06YO;FEM:6YI<R!P<F]X
M>2!S97)V97)I<P!!='-A:WEM87,`071S86MY=&$`06YT87)K=&ED80!!;G1I
M9W5A(&ER($)A<F)U9&$`0F5T(&MU<FG@('-E:V%NZ&G@('/@;'EGX`!-;V1U
M;&ES`$UO9'5L:7,@=F5I:VEA(&=E<F%I+@!486EK>71I(&9I;'1R=7,`4')I
M=&%I:WET:2!I<B!P;_!A:VEA;7,`4&%T=FER=&EN=&D`0F%L86YD:7,`07)A
M8FGP:V$@*%=I;F1O=W,M,3(U-BD`07)C:'EV;R!F86EL;R!D>61I<P!!<F-H
M>79O(&9A:6QO('!A=F%D:6YI;6%S`$%R('1I:W)A:2!N;W)I=&4@:?!T<FEN
M=&D@\&G@(&9I;'1R879I;6\@=&%I<WEK;.8_`$%R('1I:W)A:2!N;W)I=&4@
M:?!T<FEN=&D@)7,@<F5G:7-T<F%C:6IO<R!P<F'P>6W@/P!!<F=E;G1I;F$`
M07)MZVYI:F$`07)MZVYI\&MA("A!4DU30TE)+3@I`$UE;F%S`$%R=6)A`$MR
M:7-T875S(/YE;F=I;6\@X2!D86YG^"!S86QA`$%C<VEI(&UE;F%S`$%Z:6IA
M+U)A;6EO:F\@=F%N9&5N>6YO(')E9VEO;F%S`$%R('!R8?!Y=&D@<&%T=FER
M=&EN=&D@<')O9FEL86MT:6MO<R!V96EK<VUU<S\`4')I<VMY<FEM;R!S='5L
M<&5L:6%I`$)A;F1O=&4@:?!T<FEN=&D@;F5E9WII<W1U;VIA;NAIX"!G<G5P
MYBX`0F%N9&]T92!I\'1R:6YT:2!N965G>FES='5O:F%NZ&EA<R!T96ES97,N
M`$)A;F1O=&4@<F5D86=U;W1I(&YE96=Z:7-T=6]J86[H:6%S('1E:7-E<RX`
M0F%N9&]T92!R961A9W5O=&D@;F5E9WII<W1U;VIA;G3A(&5L96UE;G3@+@!!
M=')I8G5T86D`4G5G<&K[=&ES`$%U<W1R86QI:F$`075S=')I:F$`075T:%]C
M>7)S<6PZ(&YE<F%S=&%S(')E:6MA;&EN9V%S($E-05`@;6]D=6QI<RX`075T
M:%]C>7)U<SH@8WER=7,@;F5T=7)I(')E:6MI86WX(&=A;&EM>6)I^"X`075T
M:%]C>7)U<SH@;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+@!!
M=71H7V9T<#H@;F5R87-T87,@<F5I:V%L:6YG87,@1E10(&UO9'5L:7,N(%-U
M:V]M<&EL:75O:VET92!02%`@<W4@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z
M(&YE<F%S=&%S(')E:6MA;&EN9V%S($E-05`@;6]D=6QI<RX`075T:%]K<F(U
M.B!N97)A<W1A<R!R96EK86QI;F=A<R!K<F(U(&UO9'5L:7,N`$%U=&A?;&1A
M<#H@;F5R87-T87,@<F5I:V%L:6YG87,@3$1!4"!M;V1U;&ES+@!!=71H7VQD
M87`Z('-U:W5R=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO+B!397)V97)I;R!P
M<F%N9?!I;6%S.B``075T:%]L9&%P.B!I\'1R:6YT:2!V87)T;W1O:N`@)7,@
M;F5P879Y:V\`075T:%]L9&%P.B!A=&YA=6II;G1I('9A<G1O=&]JX"`E<R!N
M97!A=GEK;P!!=71H7VUC86PZ(&YE<F%S=&%S(')E:6MA;&EN9V%S($U#04P@
M;6]D=6QI<RX`075T:%]S;6)A=71H.B!N97)A<W1A<R!R96EK86QI;F=A<R!S
M;6)A=71H(&UO9'5L:7,N`%!R:7-I:G5N9W1I(&YE<&%V>6MO`%!R:7-I:G5N
M9W1I(&YE<&%V>6MO+B`E<P!2041)55,@<V5R=F5R:7,@;F5L96ED_FEA(&%U
M=&5N=&EF:6MU;W1I<RX`4')I<VEJ=6YG=&D@<')I92!&5%`@<V5R=F5R:6\@
M;F5P879Y:V\N`$%U=&]M871I\&MA:2!A=&YA=6II;G1I('-K<FEP=.`@<&\@
M:VEE:W9I96YO(&%T;F%U:FEN:6UO/P!'86QI;6D@;&%U:V%I.@!!>F5R8F%I
M9/YA;F%S`$)/1D@@871S:7!R8?!Y;6%I`$9O;F%S`$9O;F\@<W!A;'9A`$YE
M=&5I<VEN9V%S(&ME<F)E<F]S('-L87!T8?YO9&ES+@!.971E:7-I;F=A<R!K
M97)B97)O<R!V87)T;W1O:F\@=F%R9&%S+@!"86AA;6%I`$)A:')E:6YA<P!"
M86QT:?!K82`H25-/+3@X-3DM,3,I`$)A9VQA9&7P87,`0F%R8F%D;W-A<P!0
M86=R+B!L:6YI:F]J90!"8V,`4')A<VED961A`$)A;'1A<G5S:6IA`$)E;&=I
M:F$`0F5L:7IA<P!"96YI;F%S`$)E<FUU9&%I`$)U=&%N87,`1VEM=&%D:65N
M:7,`2G5O9&%S:7,@<^!R8?!A<P!*=6]D;VIO('/@<F'P;R!R961A9V%V:6UA
M<P!$86)A<G1I;NL@9FEL=')A=FEM;R!P;W-I<W1E;>L@;F5P86QA:6MO(&IU
M;V1O:F\@<^!R8?!O+@!!9')E<V%S(.%T<F%U:W1A<R#A(&IU;V3@:N$@<^!R
M8?#@`$%D<F5S86D@X71R875K=&D@X2!J=6]DX&KA('/@<F'PX`!";&]K;R!P
M87)A;65T<F%I`$)L;VMO('1I<&%S`$QA:?!K;R!T=7)I;GES`%!A<W1O<FEN
M=&D`0F]L:79I:F$`073^>6UO<P!+<F'P=&%S`$MR8?!T;R!S=&]R=6UA<SH`
M2W)A\'1A:0!";W-N:6IA(&ER($AE<F-E9V]V:6YA`%9I<V]S`$)O='-V86YA
M`$%P8>AI;VIE`$)U=F5T('-A;&$`0G)A>FEL:6IA`$)R:73X($EN9&EJ;W,@
M=F%N9&5N>6YO('1E<FET;VIA`$)R=6[K:F%U<R!D87)U<V%L96UA<P!"=6QG
M87)I:F$`4W7^>6WK=&%S('/@<F'P87,`0G5R:VEN87,@1F%S87,`0G5R=6YD
M:6IA`%164P!#4D,`0U),('!A<VMI<G-T>6UO('!U;FMT86D`7T-E;.MS(&YU
M<W1A='EM86DN+BX`2V%L96YD;W)I=7,`4F%M=0!+86UB;V3^80!+86UE<OMN
M87,`3F5V96EK:6$@875T;VUA=&EN:7,@<VQA<'1A_F]D_FEO('!A:V5I=&EM
M87,L('-U<VES:65K:71E('-U(&%D;6EN:7-T<F%T;W)I=6UI+@!.96=A;&EU
M('!R:7-I:G5N9W1I('!R:64@24U!4"!S97)V97)I;SH@)7,`2V%N861A`$%T
M\&%U:W1I`$%T\&%U:W1I('!R;V)L96UO<R!P<F%N9?!I;>``3F5G86QI=2!I
M\'1R:6YT:2!F86EL;R`B)7,B+@!.96=A;&EU(')A<W1I(&QA:6MI;F]J;R!K
M871A;&]G;RX`3F5G86QI=2!A<&1O<F]T:2`G=&%R9V5T1FEL92<@<&%R86UE
M=')O+@!.96=A;&EU(&GP=')I;G1I(&MA=&%L;V=O("(E<R(N`$YE9V%L:74@
M:?!T<FEN=&DN($5G>FES='5O:F$@)60@<&_P86MI86DN`$YE9V%L:74@<&5R
M<OOP:75O=&DN(,%V97-T87,@X7)A\/@@<VMA:>AI=7,@;F5S=71A;7!A('-U
M(.%R8?#X('-K86GH:75M:2!D=6]M96[X(&)A>NMJ92X`3F5G86QI=2!N=6MR
M96EP=&D@_FEN=73K<R#A(&YU<F]D>73@(&YU;65RX2X`2V5I<'9E<F1I<P!0
M879A9&EN:6UA<P!!=&MR96EP=&D@9.MM97/A(.$@9&ED_FEA<VEA<R]M8?YA
M<VEA<R!R86ED97,`2V%T96=O<FEJ;W,`2V%I;6%N^"!S86QO<P!#8P!-;V)I
M;'5S('1E;&5F;VYA<P!#96SK<R!N=7-T871Y;6%I`%1A<G!A:2!C96SK<V4Z
M`$-E;.MS(&YU<W1A='EM86D`5&%R<&%I('1A<G`@8V5L:?@Z`$UO8FEL=7-I
M<R!T96QE9F]N87,`2V5L=/@@*$E33RTX.#4Y+3$T*0!#96YT<F4`0V5N=')I
M;NMS($%F<FEK;W,@4F5S<'5B;&EK80!#96YT<FENZW,@175R;W!O<R`H25-/
M+3@X-3DM,BD`4V5R=&EF:6MA=&\@9&5T86SK<P!397)T:69I:V%T;R!T96ES
MZW,`R&%D87,`4&%K96ES=&D`2OMS^"!V87)D;R!I<B!A9')E<V\L(&MU<FEU
M;W,@;6%T>7,@_FUO;NMS+"!S:V%I=&%N='ES(&ER(&%T<V%K:6[K:F%N='ES
M(.$@2OMS^"!L86GP:W5S+"!K96ET:6UA<RX`4&%K96ET:6UA:2!I\'-A=6=O
M=&DN`%-I;6)O;&ES`%!A7W1I:W)I;G1I(&YU;W)O9.`N+BX`R&ELZP!+:6YI
M:F$`2VEN:65T:?!K82!P87!R87-T82`H1T(R,S$R*0!+:6YI971I\&MA('1R
M861I8VENZR`H0FEG-2D`4&%S:7)I;FMI=&4@<VQA<'1A_F]DX0!087-I<FEN
M:VET92!V87)T;W1O:F\@=F%R9.``4&%S:7)I;FMI=&4@:V%I<"!V86EZ9'5O
M=&D@9&%T87,Z`%!A<VER:6YK:71E('-U<OOP:75O=&\@<^!R8?!O('-T:6QI
M^`!+86SK9/@@<V%L80!+;&%SZW,@)7,@;NMR82X`1VEE9')A`$GP=')I;G1I
M($U3($]F9FEC92#^>6UE<P!687)T;W1O:F\@9'5O;65N^"!V86QY;6%S.B`E
M<P!)\'9A;'ET:2!V87)T;W1O:F\@9'5O;65N:7,`2?!V86QY=&D@=F%R=&]T
M;VIO(&1U;VUE;FES`%3F<W1I`$-L:6-K871E;&P@<&5R($A45%``5?YD87)Y
M=&D@;&%N9^``1&5B97-U;W1A`$1E8F5S=6]T80!+;VMO<V\@*$MY;&EN9V\I
M('-A;&]S`%1U\.AI^"!C96QI^"!K<F'P=/@@<F]D>6UA<P!+;VQU;6)I:F$`
M4W!A;'9A`%!A<VER:6YK:71E('-P86QVX`!3<&%L=F]S('!A<VER:6YK:6UA
M<P!3='5L<&5L:6%I.@!3='5L<&5L:?@@<&%V861I;FEM86D`2V]M:6MS86D`
M2V]M86YD80!+;VUA;F1I;NL@96EL=73K`$MO;65N=&%R87,`5F%R9&%S+W!A
M=F%R9.L`2V]M;W)A:0!+;VUP86YI:F$`2V]M<&EU=&5R:6%I`%/@;'EG;W,`
M3G5S=&%T>6WX('!A:V5I=&EM86D`2V]N9FEG^W)U;W1I("5S`%-L87!T8?YO
M9&ES(&1A<B!K87)TX`!+;VYG87,`1&5M;VMR871I;NL@2V]N9V\@4F5S<'5B
M;&EK80!0<FES:6IU;F=T:2!N97!A=GEK;RX`4')I<VEJ=6YG=&D@;F5P879Y
M:V\Z(`!0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R=F5R:6\@
M;F5P879Y:V\N`%!R:7-I:G5N9W1I('!R:64@=FEE\/AJ^"!R86MT^"!S97)V
M97)I;R!N97!A=GEK;RP@;F5S.B`E<R`H)7,I`%!R:7-I:G5N9W1I('!R:64@
M1E10('-E<G9E<FEO(&YE<&%V>6MO+@!+;VYK86MT86D@<^MK;6EN9V%I(.%T
M<F%U:W1I(.$@2OMS^"!A9')E<_@@:VYY9V5LY@!4=7)I`%3F<W1I`$MU:V\@
M<V%L;W,`3&%I;>MS(/YI;G5TZW,`2V]P:6IU;W1I`$MO<&EJ=6]T:2`E<P`E
M<R!K;W!I:F$`2V]P:6IU;W1I('!A<VER:6YK:6W@`$MO<W1A(%)I:V$`1')A
M;6)L:6\@2V%U;&\@2W)A;G1A<P!.97!A=GEK;R!U_FMO9'5O=&D@4$=0(&QA
M:?!K;RX`3F5P879Y:V\@<&%S:7)A\'ET:2!01U`@;&%I\&MO+@!.97!A=GEK
M;R!U_FMO9'5O=&D@4R]-24U%(&QA:?!K;RX`3F5P879Y:V\@<&%S:7)A\'ET
M:2!3+TU)344@;&%I\&MO+@!.97!A=GEK;R!P<FEDZW1I(&MO;G1A:W1O+B`E
M<P!.97!A=GEK;R!A=71E;G1I9FEK=6]T:7,@X2!,1$%0('-E<G9E<N$N`$YE
M<&%V>6MO('!A=&EK<FEN=&D@8F%L86YS;RX@)7,`3F5P879Y:V\@<W5K=7)T
M:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@871K;V1U;W1I
M(%!'4"!D=6]M96[X+@!.97!A=GEK;R!A=&MO9'5O=&D@4R]-24U%(&1U;VUE
M;O@N`$YE<&%V>6MO(&GP=')I;G1I(&MO;G1A:W1O+B`E<P!.97!A=GEK;R!I
M\'1R:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@;G5S
M=&%T>71I(&=A=NMJ;R!E;"X@<&'P=&\@861R97-O+@!0879Y:V\@9V%U=&D@
M=FES;W,@861R97/X(&MN>6=E;.MS+@!.97!A=GEK;R!G875T:2!V:7-O(&1I
M<W1R:6)U8VEJ;W,@<^!R8?!O+@!.97!A=GEK;R!G875T:2!V:7-O(&1I<W1R
M:6)U8VEJ;W,@<^!R8?#X('/@<F'P;RX`3F5P879Y:V\@9V%U=&D@=FEE\&]J
M;R!R86MT;R!I\"!R86MT^"!S97)V97)I;RX`3F5P879Y:V\@871I9&%R>71I
M("5S+@!.97!A=GEK;R!A=&ED87)Y=&D@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&EO("5S`$YE<&%V>6MO('-K86ET>71I("5S+@!.97!A=GEK;R!P86ME:7-T
M:2!S;&%P=&'^;V3^:6\@\&EA;2!V87)T;W1O:G5I+B!+86D@:W5R:2!A<F)A
M('9I<V$@:6YF;W)M86-I:F$@>7)A(&YE=&EK<VQI+B!086)A;F1Y:VET92!D
M87(@:V%R=.`@87)B82!S=7-I<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T
M;W)I=6UI(&IE:6=U(')E:6MA;&EN9V$@<&%G86QB82X`3F5P879Y:V\@9V%U
M=&D@04-,`$YE<&%V>6MO(&=A=71I(&%D<F5S^"!K;GEG96SK<RX@)7,`3F5P
M879Y:V\@9V%U=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO
M(&=A=71I(&1I<W1R:6)U8VEJ;W,@<^!R8?#X+B`E<P!.97!A=GEK;R!N=7-T
M871Y=&D@<V5R=F5R:6\@9V%L:6UY8FGX`$YE<&%V>6MO(&%T:V5I<W1I(&YU
M<W1A='EM^"X`3F5P879Y:V\@:?!S875G;W1I("5S(&YU<W1A='EM^"X`3F5P
M879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R!N=7-T871Y;?@@:V]P:6IO<RX`
M3F5P879Y:V\@<&%I9?!K82!,1$%0('-E<G9E<GEJ92X`3F5P879Y:V\@871N
M875J:6YT:2!K;VYT86MT;RX@)7,`3F5P879Y:V\@871N875J:6YT:2!D:7-T
M<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@<F%S=&D@36]Z:6QO<R#A
M<F%N:VGX(&IU;W-T;W,N(,%S:71I:VEN:VET92P@:V%D(&II(&%T:61A<GET
M82X`4FEB;W1A<R!T96MS=&%S`%9A;'-T>6+K`$MU<G-A:0!3=6MU<G1I`%-U
M:W5R=&D@;G5O<F]DX`!3=6MU<G1I(&YA=6K@(&%P<F'PX`!3=6MU<G1I(&YA
M=6K@(&MA=&%L;V?@`%-U:W5R=&D@<&%K871A;&]G:75S`%-A=FEN:6YK;R!T
M96ESZW,`2W)E9&ET:6[K<R!K;W)T96SK<R!N=6UE<FES`$MR;V%T:6IA`$MU
M8F$`1&%B87)T:6YI<R!L86EK87,`T&EU;R!M971U(%523"!Y<F$`1&%B87)T
M:6[K<R!O<F\@<^!L>6=O<P!$86)A<G1I;NMS('/@;'EG;W,Z(`!$86)A<G1I
M;FES('-T:6QI=7,`5F5I:W-M^"P@871L:65K86WX('!R:7-I:G5N9W5S('!R
M:64@)7,L(&YU<W1A='EM87,N`%!E<FME;'1I`%!E<FME;'1I('!A<VER:6YK
M:6W@`$MI<')A<P!+:7)I;&EC82`H2T])."U2*0!+:7)I;&EC82`H5VEN9&]W
M<RTQ,C4Q*0!+:7)I;&EC82]5:W)A:6YI971I\&MA("A+3TDX+54I`,AE:VEJ
M;W,@4F5S<'5B;&EK80!$1`!)T$I53D=403H@`$MA<V1I96X`1'5O;65N^"!M
M963^:6\@;F%R\'EK;.L`1&%T80!'875T80!$871O<R!P87-I<FEN:VEM87,`
M1&EE;F$`2?!T<FEN=&D@7W-T=6QP96SA`$GP:G5N9W1I('-K<FEP=.``1W)U
M;V1I<P!$9?!I;71A:6YI86D@<VMA:>AI86D`4W5M8?YI;G1I(&%T:71R875K
M:6W@`%-T86YD87)T:6[K('-P86QV80!3=&%N9&%R=&EN:7,@87!R8?!A<P!!
M<&EB<NO^:6UA:0!)\'1R:6YT:0!)\'1R:6YT:2`E<P!)\'1R:6YT:2!SX&QY
M9^``2?!T<FEN=&D@9W)U<.8`2?!T<FEN=&D@=&5I<^8`5FES:?!K86D@:?!T
M<FEN=&D@;&%I\&MU<P!)\'1R:6YT:2!C96SF`$GP=')I;G1I('-T=6QP96SA
M`$GP=')I;G1I(&5G>FES='5O:F%N=.$@86QT97)N871Y=O@@\&%B;&]NX`!6
M:7-I\&MA:2!I\'1R:6YT:2!L86GP:^``2?!T<FEN=&D@96EL=73F`$GP=')I
M;G1I('!A<VER:6YK=.`@87!R8?#@`$GP=')I;G1I(/#A('-T=6QP96SA`$GP
M=')I;G1I(/!IX"!E:6QU=.8`2?!T<FEN=&$`4')I<W1A='ET:2#A($E.0D]8
M`%!R:7-T871Y=&D@X2!)3D)/6"!I<B!N=6MO<&EJ=6]T:2#A`%!R:7-T871Y
M=&D@X2!)3D)/6"!I<B!N=6MR96EP=&D@X0!097)K96QT:2#A(&MA=&%L;V?@
M`%!R:7-T871Y;6\@;&%I:V%S`$1A;FEJ80!0<F]B;&5M;W,@87!R8?!Y;6%S
M`$%P<F'P>6UA<P!$971A;&EA=2`H=&%I<"!P870@_FG[<NMK:71E($AO<F1E
M(&QO9R!F86EL92DZ`$%D;6EN:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L
M=7,@87!R8?!Y;6%S+@!6>7-T>6UA<P!$<NMG;G5M87,`1'+K9VYU;6%S('!A
M<VMU=&ENYB!V86QA;F3@.B``1'+K9VYU;6%S.B``2W)Y<'1I<R!I\"!K86ER
MZW,@X2!D9?!I;N8`2W)Y<'1I<R!I\"!D9?!I;NMS(.$@:V%I<N8`2V%T86QO
M9V%S`$GP:G5N9W1I("5S`$GP:G5N9W1A`%)O9'ET:2`R-"UI^"!V86PN(&9O
M<FUA=.`_`%9A:7ID879I;6\@;G5S=&%T>6UA:0!+86D@<&%N875D;VIA;6%S
M(&9I;'1R87,@<F]D>71I(&1E=&%L^"!P<F%N9?!I;>`_`%)O9'ET:2!P<F]G
M<F]NYB`H5$%&*0!686EZ9&%V:6UO(&9O<FUA=&%S`$QA:?!K;R!P<FES=&%T
M>6UO('!R86YE\&EM86D`1/YI8G5T:7,`3F5S:?AS=&D@871S86MY;?@@X2!A
M='-I=&EK=&EN:75S(&%R8F$@7VMO;F9E<F5N8VEJ^"!L86GP:W5S`$YE=')I
M;G1I`$YE<VEK<F5I<&MI=&4@=&EE<VEO9VEA:2#A(&UA:6YT96YA;F-E+G!H
M<`!6>6MD>71I('1A:3H`07(@<&ER;6%S(.%R8?!A<R!Y<F$@;&%U:V\@=F%R
M9&%I/P!.97!R87-I9&5D80!.971U<FD`3F5S:6)A:6=I80!.965G>FES='5O
M:F$`3F5A=&ET:6YK80!$;VUI;FEK80!$;VUI;FEK;W,@4F5S<'5B;&EK80!!
M='-I<VGX<W1I`$%T<VES:?AS=&D@)7,`071S:7-I^'-T:2!S=6=E;F5R=6]T
M=7,@;G5S=&%T>6UU<R!K86EP(%!(4"!S:W)I<'3@+@!)\'-I<VML96ED_FEA
M;G1I<R!SX')A\&%S`%9A:7-T86D`16PN('!A\'1O(&%D<F5S87,`15)2`$5K
M=F%D;W)A<P!2961A9V%V:6UA<P!2961A9W5O=&D@)7,`2V5I<W1I(&)L;VMO
M('!A<F%M971R=7,`4F5D86=U;W1I(&=R=7#F`%)E9&%G=6]T:2!T96ES97,`
M4F5D86=U;W1I('1E:7-E<P`E<R!T96ES:?@@<F5D86=A=FEM87,`2V5I<W1I
M(&YU<W1A='EM=7,Z`"5S('1E:7-I^"!R961A9V%V:6UA<P!59V1Y;6%S`$5G
M:7!T87,`4V%L=F%D;W)A<P!%;&5M96YT87,N+BX`16T`16PN('!A\'1A<P!%
M;"X@<&'P=&\@861R97-A<P!%;"X@<&'P=&\@861R97-A:2!T=7)I('-U=&%P
M=&DN`$5L+B!P8?!T;R!A9')E<V%S('-U('!A='9I<G1I;FEM=0#0>7!S96[K
M;.MS`-YI;G5TZR!T=?#H:6$N`%)E>G5L=&%T87,@='7PZ&EA<RX`3F5N=7)O
M9.MT92!P86EE\&MO<R!T97)M:6[X`,%J=6YG=&D@)7,`3&5I<W1I('1E:W-T
M92#A=&5R<'1I('!A=F5I:W-LZVQI=7,@:?`@3G5O=')A=6OX(&=A;&5R:6IO
M<S\`P6IU;F=T:2!D9?!I;FEO:F\@<&5LZW,@;7EG='5K;R!M96YI=3\`P6IU
M;F=T80!'86QI;FEA:2!M971A:0!"86EG:6%S:0!)\'!LZW-T:2!R961A:W1O
M<FGX`,%R8?!Y:VET92!K;&%U<VEMX"P@:W5R:7,@:G5M<R!B=7,@=?YD=6]T
M87,@:F5I9W4@<&%M:7+P:71E('-A=F\@<VQA<'1A_F]DX2P@<'9Z+CH@)VMO
M:W,@>7)A($K[<_@@9WEV^VYO('9A<F1A<S\G.@#!=F5S:VET92!P879E:6MS
M;.ML:6\@55),`$QY9W5S`$5K=F%T;W)I;NL@1W9I;NMJ80!%<FET<NMJ80!+
M;&%I9&$`2VQA:61A(&QA:?!K92X`17-T:6IA`$5T:6]P:6IA`$5T;FENZW,`
M175R;W!A`$MA<R`Q-2!M:6YUZ&GX`$MA<R`R(&UI;G5T97,`2V%S(#,P('-E
M:W5N9/YI^`!+87,@-2!M:6YU=&5S`$MI96MV:65N;R!P<FES:6IU;F=I;6\@
M;65T=0!+87,@<'5S=F%L86YDX0!+87,@;6EN=73F`%!A=GEZ9/YI=6DZ`%9Y
M:V1Y=&D`16=Z:7-T=6]J86[H:6]S(&9I;'1R^"!T86ES>6MLZW,`16=Z:7-T
M=6]J80!)\'-K;&5I<W1I`%)E:6MA;&EN9V%S("<I)P!296EK86QI;F=A<R#^
M;V1I<R!A<F)A(&MA8G5TZW-E(.%R8?!Y=&%S('!A:67P:V]S(&MR:71E<FEJ
M=7,`1V%L:6]J:6UO(&1A=&$`16MS<&]N96YTZP!496MS=&\@<W!A;'9A`$YU
M<W1A='EM^"!S:75N=&EM87,@<&5R($944"X`2VQA:61A(&YU<VMA:71A;G0@
M;G5S=&%T>6UU<RX`3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!,1$%0('-E
M<G9E<FEO+@!.97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE(%--0B!S97)V97)I
M;RX`3F5P879Y:V\@;G5K;W!I:G5O=&D@:?`@(B5S(BX`3F5P879Y:V\@;G5K
M;W!I:G5O=&D@X2`B)7,B+@!.97!A=GEK;R!S=6MU<G1I(&YA=6IO(%-!4TP@
M<GGP:6\N`$YE<&%V>6MO('!E<FME;'1I(.$@(B5S(BX`T'9E;&YU<P!&;VQK
M;&%N9/@@<V%L;W,@*$UA;'9I;F%I*0!&87)E<O@@<V%L;W,`1F%K<V%S`%9A
M<V%R:7,`071R;V1O(&QY9P!!=')O9&\@;'EG.B``5')U;7!A;&%I:VES(&QI
M971U<P!&:63^:7,`1F%I;/@@<VMA:>AI=7,Z("5S(&9A:6QA<P!&86EL^"!S
M:V%IZ&EU<SH@)7,@9F%I;&%I*/@I`$9A:6SX('1V87)K>6UA<P!&86EL;R!P
M879A9&EN:6UA<P!&86EL;R!P87-I<FEN:VEM87,`1F%I;&\@<VEU;G1I;6%S
M`$YA<O!Y:VSK(&YE<&%L86EK;R!F86EL^"!S:75N=&EM;RX`1FEL=')U;W1I
M('9I<W5S(&QA:?!K=7,`1FEL=')U;W1I('1I:R!P97)S:V%I='ET=7,@;&%I
M\&MU<P!&:6QT<G5O=&D@=&EK(&YE<&5R<VMA:71Y='5S(&QA:?!K=7,`1FEL
M='+X('!A<F%M971R86D`1FEL=')A=FEM;R!T86ES>6MLZP!&:6QT<F%V:6UO
M('1A:7-Y:VSK<P!&:6QT<F\@<VMR:7!T;R!R;V1Y;6%S`%]&:6QT<F%I`$9I
M;'1R879I;6%S.B`E<R!L86GP:V%S*&%I+"#X*2!N=6MO<&EJ=6]T87,H:2P@
M82D@X2!K871A;&]GX"`B)7,B+@!&:6QT<F%V:6UA<SH@:?!T<FEN=&%S*&DL
M(&$I("5S(&QA:?!K87,H86DL(/@I+@!&:6QT<F%V:6UA<SH@)7,@;&%I\&MA
M<RAA:2P@^"D@<&5R:V5L=&%S*&DL(&$I(.$@:V%T86QO9^`@(B5S(BX`1FEL
M=')A=FEM87,Z("5S(&QA:?!K87,H86DL(/@I(&%T:71I;FMA;G1I<RAY<RP@
M^"D@:G5O9.!JX2!SX')A\.`@:?!T<FEN=&%S*&DL(&$I+@!&:6QT<F%V:6UA
M<SH@;&%I\&MA<R`B)7,B(&YU;R`B)7,B(&YU:V]P:6IU;W1A<R#A(&MA=&%L
M;V?@("(E<R(N`$9I;'1R879I;6%S.B!L86GP:V%S("(E<R(@;G5O("(E<R(@
M:?!T<FEN=&%S+@!&:6QT<F%V:6UA<SH@;&%I\&MA<R`B)7,B(&YU;R`B)7,B
M('!E<FME;'1A<R#A(&MA=&%L;V?@("(E<R(N`%1O:VEO(&9I;'1R;R!NZW)A
M+@!&:6QT<F%I`%-U;VUI:F$`4&ER;6]J:2!P=7/K`%!I<FUA<VES(&ME='9I
M<G1I<P!.=7-T871Y=&%S(&MO969I8VEE;G1A<P!!='9I<FOPZ&EA<P!)\&3K
M<W1Y;6%S`%+[:V%S`$MA=&%L;V=A<R`E<R!N965G>FES='5O:F$`5&5K<W1O
M('-P86QV80!-86ES=&%S`%9I<VEE;7,@9V%U;F%M:65M<R!L86GP:V%M<R!K
M=7)I93H`3F%R\'EK;.MM<RP@:W5R:6]S(&YE<&%L86EK;R!P879E:6MS;.ML
M:?@`3W+X('!R;V=N;WKK("A4048I`$]R^"!P<F]G;F]ZZW,@87!I;71I<R`H
MX7-I9.MMZVMI=&4L(&MA9"#P:2!F=6YK8VEJ82!G<F'^:6YA(&ER(&1I96YO
M<R!I<B!N86MT:65S('!R;V=N;WKF.R!P97(@9&ED96QI<R!S:V%IZ&EU<R!G
M86QI('-U9&%R:WET:2!D:7IA:6[@*0!086UI<O!O=&4@<V%V;R!S;&%P=&'^
M;V3A/P!&;W)M;W,`1G)A>NL`1G)A>FGX('1I<&%S`$9R87KK<P!&<F%ZZW,@
M,@!$:7-K=7-I:F]S`%!E<G-I^'-T:0!$86)A<G1I;NL@9FEL=')A=FEM;R!P
M;W-I<W1E;>L@;F5P86QA:6MO('!E<G-I=6YT:6WX+@!097)S:75N=&EM86D`
M4&5R<VEU;G1I;?@@<F5D86=A=FEM87,`4&5N:RX`2W)A\'1I;NMS`%!R86YC
M^WII:F$`4')A;F/[>FEJ82P@365T<F]P;VQI<P!0<F%N8_MZ:6IO<R!'=FEA
M;F$`4')A;F/[>FEJ;W,@4&]L:6YE>FEJ80!0<F%N8_MZ:6IO<R!P:65T:6[K
M<R!T97)I=&]R:6IO<P!.=6\`3G5O(`!0:6QN87,@87!R8?!Y;6%S`%!I;&YA
M=&ES`%!I;&YA<R!V87)D87,`1V%B;VYA<P!'86QE<FEJ82!I\"!K=7)I;W,@
M:?`@:W5R:6]S(&)U<R!R;V1O;6%S('!A=F5I:W-LZVQI<P!'86QE<FEJ83H`
M1V%M8FEJ80!'96YE<G5O=&D@)7,@;G5S=&%T>6UU<P!3=6=E;F5R=6]T87,@
M:V]D87,`1W)U>FEJ80!6;VMI971I:F$`1V%N80!':6)R86QT87)A<P!687)D
M87,`4F]D>71I`$=A9&5L:7,`1V]O9VQE('!A:67P:V$`3F5S<&%L=F]T87,`
M1&%U9VEA=2!N96D`1&%U9VEA=2!A<F)A(&QY9W4`1W)A:6MI:F$`1W)A:6MI
M\&MA("A)4T\M.#@U.2TW*0!'<F5N;&%N9&EJ80!'<F5N861A`$=R=7!I^"!A
M9&UI;FES=')A=FEM87,`1W)U<.MS('9A<F1A<R!T=7)I(&+[=&D@;F5T=?#H
M:6%S`$=R=7#K<P!'=F%D96QU<.L`1W5A;6$`1W9A=&5M86QA`$=E<FYS:7,`
M4W9EZ&GX('1E:7/K<P!3=F7H:?@@:VYY9V$`1W9I;NMJ80!":7-S874M1W9I
M;NMJ80!'86IA;F$`2%1-3`!(5$U,07)E82!N96=A;&D@:?!T<FEN=&D@<&%S
M:W5T:6[K<R!C96SK<R!E:6QU=.MJ92X`2%1-3$%R96$@;F5G86QI(&GP<FEN
M=&D@<&%S:W5T:6YI;R!S='5L<&5L:6\@;&5N=&5LZVIE+@!(5$U,07)E82!N
M96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!E:6QU=.MS(&QE;G1E;.MJ92X`
M4F5I:V%L:6YG82!(5%10(&%U=&5N=&EF:6MA8VEJ82X`2&%I=&ES`$AA<V@M
M06QG;W)I=&UA<P!-:6=L80!!;G1R8?!TZP!(97)D;R!S86QA(&ER($UA:V1O
M;F%L9&\@<V%L;W,`2&5B<F%J^"`H25-/+3@X-3DM."U)*0!!=6OP=&ES`%!A
M9V%L8F$`4F5D86MT;W)I875S(&YA=61O:FEM;W-I('!A9V%L8F$`4&%G86QB
M:6YI;FMA<P!(96UI<V9E<F$`T'1A:2#H:6$@>7)A(&9A:6QO('!R863^:6$Z
M`%-V87)B=0!?4&]R=&%L87,`T'9E;G1A<VES(%-O<W1A<R`H5F%T:6MA;F\@
M=F%L<W1I:F$I`%!O<G1A;&%S`$YA;?@@861R97-A<P!.86WX('1E;&5F;VYA
M<P!(;VYD^W)A<P!(;VYK;VYG87,`4&]R=&%L87,`2&]R9&4O2V]L86(Z(&YE
M=&5I<VEN9VD@)7,@6$U,(&1U;VUE;GES(/YI;G5TZVIE("5S`$AO<F1E+TMO
M;&%B.B!O8FIE:W1O("5S(&YE871I=&EN:V$@:F]K:6$@_FEN=73K`$AO<F1E
M+TMO;&%B.B!O8FIE:W1O('1I<&%S("5S(&YE<F%S=&%S(/YI;G5TZVIE("5S
M`$AO<F1E+TMO;&%B.B`E<R`B)7,B('/K:VUI;F%I(&GP=')I;G1A`$AO<F1E
M+TMO;&%B.B!I;G1E9W)A8VEJ;W,@=F%R:6ML:75K=6D@<F5I:V%L:6YG87,@
M)V1O;7AM;"<@4$A0(&UO9'5L:7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U
M:W5R=&D@;F%U:F\@6$U,(&UE9/YI;R!O8FIE:W1U:2`E<P!(;W)D92]+;VQA
M8CH@;F5P879Y:V\@:?!T<FEN=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(&YE<&%V>6MO(&=A=71I($U)344@240@9&%L:6%I("5S('1I<&\`2&]R9&4O
M2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O=&D@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O=&D@96QE;65N
M=/@Z("5S`$AO<F1E+TMO;&%B.B!N9?YI;F]M87,@96QE;65N=&%S("(E<R(`
M2&]R:7IO;G1A;&D@;&EN:6IA`$AO<FEZ;VYT86QU<R!T87)P87,`2&]R:7IO
M;G1A;&EA:3H`2V%I<"#H:6$@<&%T96MO=&4_("A0<F%N9?!K:71E(2D`2VEE
M:R!S='5L<&5L:?@@;F]R:71E('-U:G5N9W1I/P!+:65K(&QA=6OX("AS='5L
M<&5L:?@I('1E;B!Y<F$_`$MI96L@96EL=>AI^"!N;W)I=&4@<W5J=6YG=&D_
M`$1RZV=N=6UA<P!$<NMG;G5M87,Z(`!*=6UO<F5S:V]S`%9E;F=R:6IA`$YE
M<&%V>6MO('-U:W5R=&D@24U!4"!P8?!T;R!DZ_YU=.MS.B`E<P!.97!A=GEK
M;R!I\'1R:6YT:2!)34%0('!A\'1O(&3K_G5TZW,Z("5S`$YE<&%V>6MO(&YU
M<W1A='ET:2!)34%0('!A\'1O(&3K_G5TZW,@9'ED_FEO.B`E<P!)4"!A9')E
M<V%S`$YE<&%V>6MO(&=A=71I($E0(&%D<F5S;RX`25`@861R97-A<R!N971E
M:7-I;F=A;64@0TE$4B!B;&]K92X`25`@=?YR86MI;G1A<RX`7\%T97)P=&D@
M96EL=73F('9I<O!U:F4`27-L86YD:6IA`%1I:R!P:6MT;V=R86UO<P!0:6MT
M;V=R86UO<R!S=2!T96MS='4`07!R8?!O('!A=F%D:6YI;6%S.@!*96D@;F5G
M86QI=&4@<&5R<VMA:71Y=&D@\&EO(&QA:?!K;RP@)7,N`$IE:6=U(&UA=&]T
M92#P:>`@_FEN=73F('9I971O:B!P879E:6MS;.ML:6\L(&MU<N$@;F]R:71E
M(.%K96QT:2P@=&%I($K[<_@@;F%R\'EK;.L@;F5G86QI(&IO(&%T=F%I>F1U
M;W1I+@!0879E:6MS;.ML:6\@<&5R_FG[<F$`4&%V96EK<VSK;&EO(%523`!0
M879E:6MS;.ML:6\@55),.@!0879E:6MS;.ML:7,@:?`@9V%L97)I:F]S`%!A
M=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,Z`%!A=F5I:W-LZVQI;R#A:^ML:6UA
M<P!686EZ9&%I`,%KZVQI;6%S+"`E9"#^:6YG<VYI<P!3=F%R8G4`3&%U:V%S
M(.%K96QT87,Z("5S`,%K96QT:2!L875K86DZ`,%?=&5R<'1I(&5I;'5TYB!A
M<&'H:6]J90!.971E:7-I;F=A<R!V96EK<VUO(&MO9&%S+@!.971E:7-I;F=A
M<R!V87)T;W1O:F\@=F%R9&%S(&ER+V%R8F$@<VQA<'1A_F]D:7,N`$YE:71E
M:7-I;F=A<R!V87)T;W1O:F\@=F%R9&%S(&%R8F$@86QT97)N871Y=G5S(&5L
M+B!P8?!T;R!A9')E<V%S+B!"86YD>6MI=&4@9&%R(&MA<G3@(&%R8F$@<W5S
M:7-I96MI=&4@<W4@<V%V;R!A9&UI;FES=')A=&]R:75M:2!J96EG=2!R96EK
M86QI;F=A('1O;&5S;NL@<&%G86QB82X`4&%D:61I;G1I(&%T:71R875K:6W@
M`$EN9&EJ80!);F1I=FED=6%L^W,@=F%R=&]T;VIA:0!$86)A<G1I;NL@9FEL
M=')A=FEM;R!P;W-I<W1E;>L@;F5P86QA:6MO(&EN9&EV:61U86QI^"!F:6QT
M<O@N`$EN9&]N97II:F$`3&%I\&OX(&=A=FEM=6D@;G5R;V1Y=&$@;F5E9WII
M<W1U;VIA;G1I('!A\'1O(&3K_G5TZRX`26YF;W)M86-I:F$`26YF;W)M86-I
M:F$`P71R875K=&D@<W1U;'!E;.$@7V1E\&ENZVIE`,%T97)P=&D@<&%V96EK
M<VSK;.$`P71E<G!T:2!L96YT96SF`,%T97)P=&D@;G5O<F]DX`#!=&5R<'1I
M('-T=6QP96SA(%]K86ERZVIE`,%T97)P=&D@;F%U:N`@<W1U;'!E;.$@97-A
M;6\@<W1U;'!E;&EO(&1E\&ENZVIE`,%T97)P=&D@;F%U:N`@<W1U;'!E;.$@
M97-A;6\@<W1U;'!E;&EO(&MA:7+K:F4`P71E<G!T:2!N875JX"!E:6QU=.8@
M97-A;6]S(&5I;'5TZW,@87!AZ&EO:F4`P71E<G!T:2!N875JX"!E:6QU=.8@
M97-A;6]S(&5I;'5TZW,@=FER\'5J90#!=&5R<'1I('!A<F%G<F%FX"!E;&5M
M96YT;R!A<&'H:6]J90#!=&5R<'1I('!A<F%G<F%GX"!E;&5M96YT;R!V:7+P
M=6IE`,%T97)P=&D@86QT97)N871Y=O@@\&%B;&]NX`#!<F'P>6MI=&4@96PN
M('!A\'1O(&%D<F5SX"P@X2!K=7+A(&YO<FET92!G875T:2!N875JX"!S;&%P
M=&'^;V3A.@#!=&5R<'1I(&-E;.8@<&\@=&\`P71E<G!T:2!C96SF('!R:67P
M('1A:0#!=&5R<'1I('-T=6QP96SA(&1E\&ENZVIE`,%T97)P=&D@<W1U;'!E
M;.$@:V%I<NMJ90#!=&5R<'1I(&QA:?!K=7,`P71E<G!T:2!P87)A9W)A9N`@
M<&\@=&\`P71E<G!T:2!P87)A9W)A9N`@<')I9?`@=&%I`,%T97)P=&D@96EL
M=73F('!O('1O`,%T97)P=&D@96EL=73F('!R:67P('1A:0#!<F'P>6MI=&4@
M<F5I:VEA;>`@871S86MY;>`@X2!K;&%U<VEMX"!V:7+P=6IE.@#!=&5R<'1I
M+W)E9&%G=6]T:2!P879E:6MS;.MLX0#!=&5R<'1I+U)E9&%G=6]T:2!N=6]R
M;V3@`$1I<W1R:6)U8VEJ;W,@<^!R8?!U:2!N=7-I^'-T:2!N977^=&5N:V$@
M:W)E9&ET;RX`3F5U_G1E;FMA(&MR961I=&\N`%-K86GH:75S`%-K86GH:?@@
M<^!R8?!A<P!.971E:7-I;F=A<R!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`
M3F5T96ES:6YG87,@;6]D=6QI<RX`3F5T96ES:6YG87,@240N`,%V97-T:2!N
M971E:7-I;F=I(&1U;VUE;GES+@!.971E:7-I;F=A<R!A9')E<V%S+@!.971E
M:7-I;F=A<R!F86EL;R!F;W)M871A<P!.971E:7-I;F=A<R!M<V=?='EP92X`
M3F5T96ES:6YG87,@87)B82!NZW)A(&%P:5]I9"X`4&%R86UE=')A:2!N971E
M:7-I;F=I(&%R8F$@:O@@;NMR82X`3F5T96ES:6YG;W,@<&%V96QD:6UO<R!T
M96ESZW,N`$YE=&5I<VEN9V%S('!R;W1O:V]L87,N`$YE=&5I<VEN9V%S(&]B
M:F5K=&%S`$YE=&5I<VEN9V%S('-I=6YTZVIO(&%D<F5S87,N`$YE=&5I<VEN
M9VD@=6YI:V]D;R!D=6]M96YY<RX`26YV96YT;W)I=7,`27-L86UI\&MA($ER
M86YO(%)E<W!U8FQI:V$`27)A:V%S`$%I<FEJ80!9<F$`365N;R!S86QA`$[K
M<F$`27IO;&EU;W1O<R!4+6%U9')O<P!)>G)A96QI<P!)\&1A=NMJ87,`2W5R
M<WEV87,`271A;&EJ80!*86UA:6MA`%-A=7-I<P!*87!O;FEJ80!*87!O;FGP
M:V$@*$E33RTR,#(R+4I0*0!$_F5R<VES`$IO<F1A;FEJ80!,:65P80!":7+^
M96QI<P!0:6QN86D`3'EG:75O=&D@8V5N=')E`$QY9W5O=&D@<&EL;F%I`$QY
M9VEU;W1I(&MA:7+K:F4`3'EG:75O=&D@9&7P:6[K:F4`2V%Z86MS=&%N87,`
M2?!S875G;W1I(&]R:6=I;F%LX#\`2V5N:6IA`$YE<&%V>6MO('!R:7-I:G5N
M9W1I('!R:64@2V5R8F5R;W,@<V5R=F5R:6\N`$)R86YD=6]L:6\@;F%U:F]K
M86D`4F%K=&\@:_MR:6UA<P!286MT;R!A='-P875D87,`4F%K=&\@:6QG:7,`
M4F%K=&\@=&EP87,`4F%K=&\@<&%N875D;VII;6%S`%)A:W1A<R!J874@>7)A
M('9I9?#X:O@@<F%K=/@@<V5R=F5R>6IE+@!686EK86D`2VER:6)A=&ES`$1E
M;6]K<F%T:6[K($MO<NMJ;W,@3&EA=61I97,@4F5S<'5B;&EK80!+;W+K:F]S
M(%)E<W!U8FQI:V$`2V]RZVII971I\&MA("A%54,M2U(I`$MU=F5I=&%S`$MI
M<F=I>FEJ80!?2?!DZW-T>6UA<P!+86QB80!,86]S;R!$96UO:W)A=&ENZR!,
M:6%U9&EE<R!297-P=6)L:6MA`$%N=')A('!U<^L`4&%S:W5T:6YI<R!K971V
M:7)T:7,`071N875J:6YT83H`4&%S:W5T:6YI<R!P<FES:6IU;F=I;6%S.B`E
M<P!087-K=71I;FES('!R:7-I:G5N9VEM87,Z("5S(&GP(&%D<F5S;R`E<P!0
M<FES:6IU;F?K=&4@<&ER;>`@:V%R=.``3&%T=FEJ80!496ESZP!)\&3K<W1Y
M;6%S`$IE:6=U(&YE;F]R:71E(&YE;F%U9&]T:2!K<F'P=/@L('!A;&EK:71E
M('1U\.AIX`!,:6)A;F%S`$MA:7+K:F4`2V%I<FEO:FD@86YT<F'P=.L`2V%I
M<FEO<VEO<R!R96EK\&WK<P!,97-O=&%S`$UA_FEA=2!N96D`36'^:6%U(&%R
M8F$@;'EG=0!,:6)E<FEJ80!,:6)I:F]S($%R86+X($5M>7)A=&%I`$QI8VAT
M96[P=&5I;F%S`%-M=6QK=7,@;&EE='5S`$YE9&ED96QI<R!L:65T=7,`3F5D
M:61E;&ES(&QI971U<R!R>71E`$YE9&ED96QI<R!L:65T=7,@=F%K87)E`$YE
M9&ED96SK(&QI^W1I<P!.961I9&5L:7,@;&EE='5S('-U('!E<FO[;FEJ80!.
M961I9&5L:7,@<VYI96=A<P!.961I9&5LZR#P;&%P9')I8F$`3&EM97)I:V%S
M`$YU;W)O9&$`3G5O<F]D82#A.@!0861A<GET:2!E;"X@<&'P=&\@861R97/@
M(&YU;W)O9&$@X2!L86GP:V\@<F'P>6UO('!U<VQA<.$`3G5O<F]D;W,`3&EN
M=7@@;&%I;>MS(/YI;G5TZW,`4F]D>71I("T@=F%R=&]T;VIA<R!G86QI(&UA
M='ET:2!K871A;&]G;R!T=7)I;N$`4F]D>71I(&1U;VUE;O@@8F%Z:?@@<^!R
M8?#@`%)O9'ET:2!P86=A;&)O<R!T96UA<P!2;V1Y=&D@;&5N=&5L:?@@<^!R
M8?#@`$MO;F9E<F5N8VEJ;W,@87)C:'EV87,`2V]N9F5R96YC:6IO<R!P86=A
M;&)A`$MO;F9E<F5N8VEJ;W,@240`2V]N9F5R96YC:6IO<R!)1`!+;VYF97)E
M;F-I:F]S('-A=FEN:6YK87,`4F'P>71I(.$@:V]N9F5R96YC:6K@`%!R:7-I
M:G5N9W1I('!R:64@:V]N9F5R96YC:6IO<P!!='-I:G5N9W1I(&YU;R!K;VYF
M97)E;F-I:F]S`%9A<G1O=&]J^"!SX')A\&%S('7^9')A=7-T87,N`$QI=&5R
M873[<F$`3&EE='5V80!+<F%U;F$N+BX`5FEE=&EN:7,@;&%I:V%S.B``3&]K
M86SK(&ER(&QA:6MA<P!6:65T80!0<FES:6IU;F=T:0!!='-I:G5N9W1I`%!R
M:7-I:G5N9VEM;R!D87)B86D`4')I<VEJ=6YG=&D@;F5P879Y:V\N($YE=&5I
M<VEN9V%S($K[<_@@;G5R;V1Y=&%S('9A<G1O=&]J;R!V87)D87,@:7(O87(@
M<VQA<'1A_F]D:7,N`%!R:7-I:G5N9W1I(&YE<&%V>6MO+@!);&=A<R!T96MS
M=&%S`$UE:6SK`$YE<W9A<F)U`$UA_F]S:6]S(&=R86EK:?!K;W,@<F%I9.MS
M`$UA_F]S:6]S(&QO='EN:?!K;W,@<F%I9.MS`$UA_FEE:FD@<F]MZVYI\&MI
M('-K86GH:6%I`$QI=6MS96UB=7)G87,`34T`34]41`!0<FEK86)I;G1A;64@
M35,M5$Y%1B!F86EL92!NZW)A(&1U;VWK;O@N`$U31P!-86MA;P!-86ME9&]N
M:6IA`$UA9&%G87-K87)A<P!-86=I:F$`4&'P=&%S`%!A\'1O('9A;&1Y;6%S
M`%-U:W5R=&D@7VYU;W)O9.`N+BX`36%L879I<P!-86QA:7II:F$`36%L9'EV
M86D`36%L:7,`36%L=&$`2V%T96=O<FEJ^"!SX')A\&\L(&MU<FEO;7,@<')I
M<VMI<FEA;6D@;V)J96MT86DL(&ER('-U(&IO;6ES('-U<VEJ=7-I^"!S<&%L
M=O@@:V5I=&EM87,N`$UA<#(T(/YE;>ML87!I<P!-87!1=65S="#^96WK;&%P
M:7,`4&'^>6WK=&D@;&%I\%]K=7,@:V%I<"!I\'1R:6YT=7,`2V]V87,`4&%R
M8?!TZP!08?YY;>MT:2!L86GP:^`@:V%I<#H`4&'^>6WK=&D@:V%I<"!S:V%I
M='ET=7,O;F5S:V%I='ET=7,`4&'^>6WK=&D@:VET86ES(&%T<FEB=71A:7,@
M*'!V>BX@<W9A<F)U+V%T<V%K>71A*0!-87+P86QO('-A;&]S`$UA<G1I;FEK
M80!!=&ET:6YK80!3=6IU;F=T:2!L875K86D`36%U<FET86YI:F$`36%U<FEC
M:6IU<P!-86MS:6UA;'5S(&MR961I=&%S+@!-86MS:6UA;'5S(/YI;G7H:?@@
M9&%L:?@@:VEE:VES(&GP96EK=F]T87,N`$UA:W,N('1E;7`N('!A<VLN(#(T
M('9A;#H@`$UA:W,N('1E;7`N('!A<VLN(#8@=F%L.B``36%K<VEM86QU<R!I
M;&=I<P!087-I96MT87,@;6%K<VEM86QU<R!A9')E<_@@<VMA:>AI=7,@:G5O
M9&%J86UE('/@<F'PZRX@*$GP('9I<V\@861R97/X.B`E<RP@;6%K<VEM86QU
M<R!A9')E<_@@:VEE:VES.B`E<RDN($YA=6KX(&%D<F5S^"!P<FEDZW1I(&YE
M9V%L:6UA+@!087-I96MT87,@;6%K<VEM86QU<R!A9')E<_@@<VMA:>AI=7,@
M8F%L=&%J86UE('/@<F'PZRX@*$GP('9I<V\@861R97/X.B`E<RP@;6%K<VEM
M86QU<R!A9')E<_@@:VEE:VES.B`E<RDN($YA=6KX(&%D<F5S^"!P<FEDZW1I
M(&YE9V%L:6UA+@!'96=U_NL`36]J;W3K`$UE9&EC:6YA`$YA<FEA:0!-96YI
M=2!R9?YI;6%S.@!3=6IU;F=T:2!C96QE<P#>:6YU=.L`3&%I\&MA<R!P879I
M<G1I;G1A<RP@=&'H:6%U(&YE<&%T=FER=&EN=&%S('!A<VER8?!I=7-I;R!A
M<VUE;G,@<V5R=&EF:6MA=&%S+@#>:6YU=.L@;F5I\'-I^'-T82X`WFEN=73K
M<R!T:7!A<P!/<F\@<V%L>6=O<P!/<F\@<^!L>6?X(&)L;VMO(&[K<F$N`$]R
M;R!SX&QY9_@@8FQO:V\@;NMR82X@061M:6YI<W1R871O<FEU:2!I\'-I^'-T
M87,@9&5T86QU<R!A<')A\'EM87,N`$UE=&]D87,`36%T86D`365K<VEK80!-
M:6MR;VYE>FEJ;W,@1F5D97)A8VENZW,@5F%L<W1I:F]S`%9I9'5R>6IE`$U)
M344@=&EP87,`36EN+B!T96UP+B!P87-K+B`R-"!V86PZ(`!-:6XN('1E;7`N
M('!A<VLN(#8@:&]U<G,Z(`!!='-P:6YD>7,`2VET;W,`3F5R87-T87,@4$5!
M4B!(5%107U)E<75E<W0@<&%K971A<RX`3&%I\&OX('!E<G-I=6YT:6UU:2!N
M96YU<F]D>71A<R!E;"X@<&'P=&\@861R97-A<P!.=7-T871Y;?@@;NMR82X@
M2F5I9W4@;F]R:71E(&YA=61O=&D@\.$@;6]D=6SA+"!T=7)I=&4@:N$@<W5K
M;VYF:6?[<G5O=&DN`$[K<F$@_FEN=73K<R!)1"X`071M971I;75I(&YE;G5R
M;V1Y=&$@<')I9?YA<W1I<P!!=&]S=&]G^"!M;V1U;'EJ92!N96YU<F]D>71A
M('!R:67^87-T:7,N`$YE<F%S=&%S(')E:6MA;&EN9V%S(%!%05(@36%I;"!P
M86ME=&%S+@!.ZW)A('-E<VEJ;W,@240N`%!I<FTN`$UO8FEL=7,@<&'P=&%S
M`%9I9'5T:6YI<P!2961A9V%V:6UO(&1A=&$`2V5I<W1I(%523`!-;V1U;&ES
M`$UO;&1O=F]S(%)E<W!U8FQI:V$`36]N86MA<P!-;VYG;VQI:F$`3>MN97-I
M86D@:7(@;65T86D`2V%S(&WK;F5SX0!-;VYS97)A=&%S`$WK;G5L:6\@9F%Z
MZW,`36%R;VMA<P!$875G:6%U<VEA(&=I961R80!$875G:6%U<VEA(&%P<VEN
M875KY@!$875G:6%U<VEA('-A=6SK=&$`4&5R:V5L=&D`4&5R:V5L=&D@_F5M
M:6%U`%!E<FME;'1I(&MA:7)I874`4&5R:V5L=&D@9&7P:6YI874`4&5R:V5L
M=&D@_F5M>6X`4&5R:V5L=&D@875K\'1Y;@!097)K96QT:2!A=6OPZ&EA=0!0
M97)KZVQI;6%S(/YE;7EN`%!E<FOK;&EM87,@875K\'1Y;@!-;WIA;6)I:V%S
M`$ME;&5T;R!L>6=I^"!I\'-I<VML96ED_FEA;G1I<R!SX')A\&%S`$ME;&5T
M87,@<&%S:7)I;FMI;?@`36%N;R!SX'-K86ET80!-86YO('!O<G1A;&%S`$UA
M;F\@<&]R=&%L;R!I\&3K<W1Y;6%S`$UA:6YM87)A<P!.12P@3D53551)3DM5
M`$1I96[X('-K86GH:75S('1A<G`@871O<W1O9_@@7V%T<V%K>6WX.@!687)D
M87,`3F%M:6)I:F$`3F%U<F%S`$YE<&%L87,`3GED97)L86YD86D`3GED97)L
M86YD^"!!;G1I;&%I`$YE='-C<&%P92!B87II;FES(%523`!.971S8W!A92!S
M97)I9FEK871O(&%T\&%U:VEM;R!54DP`3F5T<V-P864@<V5R=&EF:6MA=&\@
M=&5I<VGX(%523`!.971S8V%P92!A=&YA=6II;F]M;R!54DP`3F5T<V-A<&4@
M873P875K:6UO(%523`!.971S8V%P92!34TP@<V5R=F5R:6\@=F%R9&%S`$YE
M='-C87!E('-E<G1I9FEK871O(&%P<F'P>6UA<P!.971S8V%P92!S97)T:69I
M:V%T;R!T:7!A<P!4:6YK;&%S`$YI96MA9&$`3F%U:F]J:2!+86QE9&]N:6IA
M`$YA=6IA(&MA=&5G;W)I:F$`3F%U:F%S(&WK;G5L:7,`3F%U:F$@9FEL=')A
M=FEM;R!T86ES>6MLZP!.875J87,@=F%R=&]T;VIO('9A<F1A<R`H;F5B^W1I
M;F%S*0!.875J;VII(%IE;&%N9&EJ80!.875J86UE(&QA;F=E("A?8FQA;FLI
M`$YA=6II96YO<P!.875J:65N^"!G<G5PZW,`4V5K86YT:7,`4V5K86YT>7,@
M;G5S=&%T>6UA:0!.:6MA<F%G=F$`3FEG97)I<P!.:6=E<FEJ80!.86MT:7,`
M3FEU:NL`3F4`3F5U_G1E;FMA(&1U;VUE;O@@<VMI<G1U;?@@<&%R;V1Y;75I
M+@!.96YU<F]D>71A('-T<F%T96=I:F$@25-/(')A\'EM=6DN`-!I86UE('-E
M<G9E<GEJ92!N97-U:V]N9FEG^W)U;W1A('!O<VES=&5MZP!0;W-I<W1E;>L@
M;F5S=6MO;F9I9_MR=6]T82!B86-K96YD<RYP:'`@9F%I;&4`3NMR82!S=63K
M=&EN:6\@\&%B;&]N;RX`3G5R;V1Y=&]J92!P;WII8VEJ;VIE(&)L;VMO(&[K
M<F$`3F7A=F5DZW1E(&MA;&5N9&]R:6%U<R!V87)D;R!-0T%,(&%U=&5N=&EF
M:6MA8VEJ;VIE+@!3:VER='5M^"!NZW)A+@#0:6]S('1E:7/K<R!N96=A;&D@
M='5RZW1I('!O=&5I<VGX+@!.ZW)A(&EN9F]R;6%C:6IO<R!A<&EE("5S(&MO
M;F9I9_MR86-I:N`N`$[K<F$@:6YF;W)M86-I:F]S(&%P:64@1E10(%9&4R!K
M;VYF:6?[<F%C:6K@+@!.ZW)A(&EN9F]R;6%C:6IO<R!A<&EE(%-13"!61E,@
M:V]N9FEG^W)A8VEJX"X`3NMR82!I;F9O<FUA8VEJ;W,@87!I92!344PM1FEL
M92!61E,@:V]N9FEG^W)A8VEJX"X`2W)E9&ET87,@:?!E:6MV;W1A<RX`3F7A
M=F5S=&%S(&=A=NMJ87,N`$9A:6QA<R!N96YU<VGX<W1A<P!.ZW)A(&%N=')A
M\.AI^"!S<&5C:69I:V%C:6IO<P!.96YU<W1A='ET82!V:65T;W;K+@!.9>%R
M8?#K=&4@_FEN=73K<RX`3F7A<F'PZW1E('9A<F1O+@!.9>%R8?#K=&4@;G5M
M97)I;RX`3F5R;V1Y=&D@X?YE:63^:6%NZ&GX(&9R87II^`!.9>%V963K=&4@
M<VQA<'1A_F]D_FEO($A45%`@875T96YT:69I:V%C:6IA:2X`3F7A=F5DZW1E
M('-L87!T8?YO9/YI;R!)34%0(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT
M92!S;&%P=&'^;V3^:6\@2V5R8F5R;W,@875T96YT:69I:V%C:6IA:2X`3F7A
M=F5DZW1E('-L87!T8?YO9/YI;R!,;V=I;B!A=71E;G1I9FEK86-I:F%I+@!.
M9>%V963K=&4@<VQA<'1A_F]D_FEO(%!!4U-71"!A=71E;G1I9FEK86-I:F%I
M+@!.9>%V963K=&4@<VQA<'1A_F]D_FEO(%--0B!A=71E;G1I9FEK86-I:F%I
M+@!.9>%V97-T87,@:V5L:6%S(&EK:2!/<&5N4U-,('!A9W)I;F1I;FGX(&9A
M:6SX+B!/<&5N4U-,(')E:6MA;&EN9V$@9&%R8G5I('-U(%!+0U,@,3(@9'5O
M;65N:6UI<RX`3F5P871V:7)T:6YT^"!R96=I<W1R86-I:O@@;NMR82X`3F5N
M875D;W1I('-K:7)T=6OX`%-K<FEP=&%S(&YE<W5G96YE<G5O=&%S+@!.ZR!V
M:65N;VIE('!U<^MJ90!.9>%V97-T;W,@<F5I:_!MZW,`4W!A<G1I;FEM=6D@
M;NMR82!L86EK:6YO:F\@:V%T86QO9V\N`%9A<G1O=&]J;R!V87)D87,@:7(O
M87)B82!S;&%P=&'^;V1I<R!N96YU<VGX<W1A<RX`5&5I<VEN9_@@6$U,(&1U
M;VUE;O@@;NMR80!.ZW)A(')E:6OP;6GX`$MO;F9I9_MR86-I;FEA;64@9F%I
M;&4@;NMR82!V97)S:6IO<RX@4&5R9V5N97)U;VMI=&4@;G5S=&%T>6UU<RX`
M2V]N9FEG^W)A8VEN:6%M92!F86EL92!NZW)A('9E<G-I:F]S+B!097)G96YE
M<G5O:VET92!N=7-T871Y;75S+@!.96YU<F]D>71A`$[K<F$`T&EA=7+K<R`H
M25-/+3@X-3DM,3`I`$YO<F9O;&MO('-A;&]S`-!I875R:6[K(&AE;6ES9F5R
M80#0:6%U<FENZW,@36%R:6IA;O@@<V%L;W,`3F]R=F5G:6IA`$YE('!O('1O
M`$YE('!R:67P('1A:0!.92!K871A;&]G87,`3F5L>6=U<P!.97)E86QI>G5O
M=&$N`$YE;G5R;V1Y=&$`3F5P86QA:6MO;6%S+@!5_G)A\&%I`$[K<F$@:^`@
M<&5R_FG[<NMT:2P@96EK:71E(&%T9V%L+@!,87!K<FET:7,`3G5M97)I<P!3
M:6UB;VQI^"!S:V%IZ&EU<P!3='5L<&5L:?@@<VMA:>AI=7,`16EL=>AI^"!S
M:V%IZ&EU<P!.9>%V97-T:2!D:7-T<FEB=6-I:F]S('/@<F'P;R!A=&YA=6II
M;FEM;R!S:V%IZ&EA:2X`3TL`3V)J96MT87,`3V)J96MT;R!S879I;FEN:V%S
M`$'P='5N=&%I;FES`%-P86QI<P#>:6%U<G5M;R!F:6QT<F%S`$]F:7-A<P!/
M;6%N87,`2V%T86QO9_@@9&%L:6II;>!S:2!P86QA:6MO('1I:R!)34%0('-E
M<G9E<FEA:2X`5&EK(.'^96ED_FEA;NAI;W,@9G)A>NMS`$QE:63^:6%M87,@
M=&EK('9I96YA<R!E;"X@<&'P=&\@861R97-A<RX`16QE;65N=&\@<V%V:6YI
M;FMO('1E:7-E<R!G86QI(&ME:7-T:2!T:6L@:F\@<V%V:6YI;FMA<R!A<F)A
M('-I<W1E;6]S(&%D;6EN:7-T<F%T;W)I=7,`071I9&%R>71I(&YA=6IA;64@
M;&%N9V4`071I9&%R>71I(/!IX"!N=6]R;V3@(&YA=6IA;64@;&%N9V4`3W!R
M86-I;NMS('-I<W1E;6]S`$YU<W1A='EM86D`3G5S=&%T>6UA:2!S=7-I:N8@
M<W4@<VMR:7!T^"!A=&YA=6II;FEM=2X`)7,@;G5S=&%T>6UA:0!3=7+[\&EU
M;W1A<R!SX')A\&%S`$]R9V%N:7IA8VEJ80!0861A;&EN>7,`4VES=&5M:6YI
M;6%S`$]R:6=I;F%L=7,@87!L:6MA8VEJ;W,@\&%B;&]N87,`3W)I9VEN86SX
M<R#P86)L;VYA:2`E<SH`2VET80!+:71A(&EN9F]R;6%C:6IA`$MI=&D@;G5S
M=&%T>6UA:0!3879I;FEN:6MO('1E:7/K<P!.ZW)A(%!!32!A=71E;G1I9FEK
M86-I:F]S(&UE8VAA;FEZ;6\N`%!'4"!S:V%I=&UE;FEN:7,@<&%R8?!A<P!0
M1U`@=?YK;V1U;W1A(&EN9F]R;6%C:6IA`%!'4"!V:67P87-I<R!R86MT87,`
M4$=0('!A<VER8?!Y=&DO=?YK;V1U;W1I(&1U;VUE;GES`%!(4"!K;V1A<P!0
M2%`@0TQ)`%!-(&QE;F=V87,@;&EE='5S`%!-(&QI^W1I<P!032!4+6%U9')A
M`%!?2%`@0TQ)`%1A<G!A:2!C96SK<V4`4&%K:7-T86YA<P!086QA=0!5_FEM
M=&]J:2!086QE<W1I;F]S('1E<FET;W)I:F$`4&%N86UA`%!A<'5A($YA=6IO
M:FD@1W9I;NMJ80!087)A9W9A:G5S`$1A;&EN86D@9&5B97-U;W1A`%-L87!T
M8?YO9&ES`%-L87!T8?YO9&ES(&YE=&5I<VEN9V%S`%)!1$E54R!A=71E;G1I
M9FEK86-I:F%I(')E:6MI82!S;&%P=&'^;V3^:6\N`%-L87!T8?YO9&ES('-U
M('!A='9I<G1I;FEM=0!3;&%P=&'^;V1I<SH`4VQA<'1A_F]D:7,Z(`!3;&%P
M=&'^;V3^:6%I('1U<FD@<W5T87!T:2X`P6ME;'1I`,%K96QT:2!I\"!L86EK
M:6YO<VEO<R!S875G>6ML;W,@*&-L:7!B;V%R9"D`2V5L:6%S`$YE<&%T=FER
M=&EN=&]S(')E9VES=')A8VEJ;W,Z`-YM;V[K<P!0<F]C96YT86D`071L:6MT
M:2!P<F]F:6QA:W1I;FEU<R!V96EK<VUU<P!!<B!A=&QI:W1I('!R;V9I;&%K
M=&EN:75S('9E:6MS;75S('!R:7-I:G5N9VEM;R!M971U/P!496ESZW,`5&5I
M<VGX(&%D;6EN:7-T<F%V:6UA<P!!<VUE;FENZR!I;F9O<FUA8VEJ80!097)U
M`$=Y=OMN86D`1FEL:7!I;F%I`%1E;&5F;VYA<P!.=6]T<F%U:V]S`%!I=&MR
M86YA<P!0:6MS96QI86D`0F%N86QY8NMS`$GP<VER:6YK:71E(&MU<FG@(&YO
M<G,@8V5LY@!0871V:7)T:6YK:71E+"!A<B!T:6MR86D@;F]R:71E(&GP=')I
M;G1I(/#A(&5L96UE;G3@.@!0871V:7)T:6YK:71E+"!A<B!T:6MR86D@;F]R
M:71E(&GP=')I;G1I(/!I;R!E;&5M96YT;R!N=6]R;V3@+@#!=F5S:VET92!M
MZVYE<^$@:7(@;65T=7,N`,%V97-K:71E(&YA=6IO<R!K871E9V]R:6IO<R!P
M879A9&EN:6W@.@#!=F5S:VET92!T96ES:6YGX"!)4"!A9')E<^`N`,%V97-K
M:71E('1E:7-I;F?@(&1A=.`L('!A=&EK<FEN:VET92!D:65N^"!S:V%IZ&GX
M(&WK;F5S>6IE+@#!=F5S:VET92!T96ES:6YGX"!L86EKX"X`P79E<VMI=&4@
M;F%U:F\@:V%T86QO9V\@<&%V861I;FEMX#H`07!R8?!Y:VET92!P<F]B;&5M
MX"X`3G5R;V1Y:VET92!S879O('9A<G1O=&]J;R!V87)DX"!B96D@<VQA<'1A
M_F]DX0#!=F5S:VET92!N875JX"!K871E9V]R:6IO<R!P879A9&EN:6W@.@!,
M96YK:6IA`%!O;&ET:6MA:0!"86QS879I;6%I`%!O<G1U9V%L:6IA`%!A=F5I
M:W-LZVQI;R!P;WII8VEJ80!,96YT96SK<R!P;WII8VEJ80!)\'-A=6=O=&D@
M\&EA;64@:V%T86QO9V4@*&YE9V%L:6]J82!)34%0*0!+<FET=6QI86D@<&%S
M:RX@)7,@=F%L86YDX"AA<RDZ(`!0<F5F<U]L9&%P.B!N97)A<W1A<R!R96EK
M86QI;F=A<R!,1$%0(&UO9'5L:7,N`%!R969S7W-E<W-I;VXZ(&YE<F%S=&%S
M(')E:6MA;&EN9V%S('-E<VEJ^"!M;V1U;&ES+@!3;.MG:7,`4VSK9VES(&K[
M<F]S(&QY9WEJ93H@`%-LZV=I<SH@`%!E<OYI^W)A`%!E<OYI^W+K=&D@<&%V
M96EK<VSK;.$@;F%U:F%M92!L86YG90!!;FMS=&5S;FD@;G5S=&%T>6UA:0!!
M='-P875S9&EN=&D@9&]K=6UE;G3@`%-L87!T87-I<R!R86MT87,`4')O8FQE
M;6$`4')O8FQE;6]S(&%P<F'P>6UA<P!0<F]J96MT86D`4')A\'EM87,@=&5K
M<W1U:0!6:67P87-I<R!R86MT87,`5FEE\&]J;R!R86MT;R!A;&=O<FET;6%S
M`%9I9?!O:F\O<VQA<'1O:F\@<F%K=/@@<&]R82!N97-U9V5N97)U;W1A+@!0
M=65R=&\@4FEK87,`2V%T87)A<P!386MI;GES`%)302!V:67P87-I<R!R86MT
M87,@*"5D(&)I=&%I*0!0<FEE7_YA<W1I<P`G4F%D:6\G('!A<VER:6YK:6UA
M<P!,:65T=7,`3&EE='5S(')Y=&4`3&EE='5S('9A:V%R90!,:?MT:7,`071S
M:71I:W1I;NL@9G)A>NL`4V%N='EK:7,`4VMA:71Y=&D`4&5R<VMA:71Y=&D@
M;&%I\&MA:0!4:6MR86D@:?!T<FEN=&D@)7,_($=R8?YI;G1I(&%T9V%L(&YE
M8F5G86SK<VET92X`5&EK<F%I(&GP=')I;G1I('9A<G1O=&]J;R`E<R!D=6]M
M96YI<S\@1W)A_FEN=&D@871G86P@;F5B96=A;.MS:71E+@!'875T80!.=6MR
M96EP=&D@X0!086MA<G1O=&D@86YK<W1E<V[A('9E:6MS;>``071N875J:6YT
M:2!K86ER:6]J;R!M96YI=2!E;&5M96YT=7,Z`$%T;F%U:FEN=&D@<&]R=&%L
M;R!V86EZ9.`Z`%)E9V5X`%)E9W5L:6%R:2!I\')A:?!K80!!=&UE<W1I('-U
M('!R:67^87-T:6UI`%/@<GGP:?@@;F%R\'EK;.L`4&%S=&%B;W,`3G5T;VSF
M('-E<G9E<FEA:0!.=71O;.9S(%523"`H:'1T<#HO+W=W=RYP879Y>F1Y<RYC
M;VTO:&]R9&4I.@!)\'1R:6YT:0!08?!A;&EN=&D@8FQO:^``4&%N86EK:6YT
M:2!S='5L<&5LX0!086YA:6MI;G1I(&9O<FUA=&%V:6W@`$GP=')I;G1I('!O
M<N``2?!T<FEN=&D@871N875J:6YI;6\@<VMR:7!TX"!I\"!S97)V97)I;R!L
M86EK:6YO:F\@:V%T86QO9V\N`%!A\&%L:6YT:0!08?!A;&EN=&D@\.$@96QE
M;65N=.`@:?`@9&]K=6UE;G1O`$GP=')I;G1I('9A<G1O=&]JX`!687)T;W1O
M:F\@=')Y;FEM87,Z("5S`$YE9V%L:74@871S86MY=&D@X2!U_FML875SX"X@
M2VQA:61O<R!K;V1A<SH@`%!E<G-I^'-T87,@X0!097)S:?AS=&%S(&YU;P!)
M\"!N875J;P!086ME:7-T:2!S;&%P=&'^;V3A`%-L87!T8?YO9/YI;R!K96ET
M:6UA<P!297IU;'1A=&%I`$=RX?YT:2#A(&9I;'1R^"!SX')A\.``1W+A_G1I
M(.$@;G5S=&%T>6UU<P!'<N'^=&D@X2!F:6QT<O@@<^!R8?#@`%)E:OMN:6IA
M`$%T<W1A='ET:2!K;VYF:6?[<F%C:6K@`$A434P@<F5D86MT;W)I875S(&YU
M<W1A='EM86D`3>%S;.MS`$1E\&ENZVIE`$1E\&EN:6]J:2!A;G1R8?!TZP!$
M9?!I;FEO<VEO<R!R96EK\&WK<P!?16EL=73K<R!N=7-T871Y;6%I+BXN`%)O
M;.L`4G5M=6YI:F$`4&%S=6MT:2`Q.#``4&%S=6MT:2!K86ERZVX`4&%S=6MT
M:2!D9?!I;NMN`$5I;'5TZW,@;G5S=&%T>6UA:0!%:6QU=.MS(&YU<W1A='EM
M86D`16EL=73K<SH`5&%I<WEK;.L`5&%I<WEK;.L@;G5K;W!I:G5O=&$`5&%I
M<WEK;.L@:?!T<FEN=&$`5&%I<WEK;.L@:?!J=6YG=&$`5&%I<WEK;.L@X6IU
M;F=T80!486ES>6MLZW,@<&%V861I;FEM87,`4VMI<G1U:V%I`%-K:7)T=6MA
M:2!T87)P('9I<_@@96EL=>AI^"!I<B!S='5L<&5L:?@`4VMI<G1U:V%I('1I
M:R!T87)P('-T=6QP96QI^`!3:VER='5K86D@=&EK('1A<G`@96EL=>AI^`!6
M>6MD>71I`%)U<VEJ;W,@1F5D97)A8VEJ80!2=6%N9&$`4R]-24U%('!A<F'P
M87,`4R]-24U%('7^:V]D=6]T87,@;&%I\&MA<P!.ZW)A(%-!4TP@875T96YT
M:69I:V%C:6IO<R!M96-H86YI>FUO+@!335,@_FEN=73K<P!344P@0TQ)`%-3
M2`!005992T\`4U]13"!#3$D`T&7P="X`T'9E;G1O:FD@2&5L96YA`%-A:6YT
M($MI='-A<R!I<B!.979I<V%S`%-A:6YT($QI=6-I:F$`T'9E;G1A<VES(%!E
M=')A<R!I<B!-:6=E;&]N87,`4V%I;G0@5FEN8V5N=&%S(&ER($=R96YA9&EN
M86D`5&%M92!P8>AI86UE(&QA;F=E("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN
M87,`4V%O(%1O;64@:7(@4')I;F-I<.L`4&%L>61O=F%S`%-A=61O($%R86)I
M:F$`2?!S875G;W1I`$GP<V%U9V]T:2`E<P!)\'-A=6=O=&D@;G5S=&%T>6UU
M<P!)\'-A=6=O=&D@;G5S=&%T>6UU<P!)\'-A=6=O=&D@<W5G96YE<G5O='5S
M(&YU<W1A='EM=7,@:V%I<"!02%`@<VMR:7!TX"!J^W/X('-E<G9E<FEO(&QA
M:6MI;F%J86UE(&MA=&%L;V=E+@`E<R!N=7-T871Y;6%I(&GP<V%U9V]T:2X`
M36]K<VQA<P!3:W)I<'1A<P!3:W)I<'1O(&%T;F%U:FEN:6UA<P!3:W)I<'1A
M<R!N96%T;F%U:FEN=&%S+@!3:W)I<'1A<R!SZVMM:6YG86D@X6IU;F=T87,N
M`%-K<FEP=&%S('/K:VUI;F=A:2!I\&IU;F=T87,N`$EE\&MO=&D`4&%I9?!K
M80!3:V%I='ET80!087-I<FEN:VET92!F86EL=7,`4&%S:7)I;FMI=&4@9&%T
MX`!087-I<FEN:VET92!L875KX`!087-I<FEN:VET92!G<G5PY@!087-I<FEN
M:VET92!N875JX"!S879I;FEN:^``4&%S:7)I;FMI=&4@<V5R=F5RX0!087-I
M<FEN:VET92!V87)T;W1O:N``4&%S:7)I;FMI=&4@=FES=7,@9&%T;W,@:V]M
M<&]N96YT=7,N`%!A<VER:6YK:71E(&]B:F5K=.``4&%S:7)I;FMI=&4@:V%T
M86QO9^``2?`@_F5M:6%U(&5S86[H:?@@<^!R8?#X('!A<VER:6YK:71E(')E
M:6MI86UU<R!S:6UB;VQI=7,N(%;K;&EA=2!G86QI=&4@:G5O<R!N=6MO<&EJ
M=6]T:2#A(&QA:?!KX"X`4&%S:7)I;FMI=&4@9&%T;W,@<VMI<G1U:^`Z`%!A
M<VER:6YK:71E(&1A=&]S(&9O<FUA=.`Z`%!A<VER:6YK:71E(&%P<F'PX"!K
M=7+A(&YO<FET92!R961A9W5O=&DZ`%!A<VER:6YK:71E(&QA:6MO('-K:7)T
M=6O@.@!087-I<FEN:VET92!L86EK;R!F;W)M873@.@!087-I<FEN:VET92!D
M=2!A=&ET:6YK86[H:75S(&QA=6MU<RX`4&%S:7)I;FMI=&4@<W!A;';X(&1E
M<FENX2X`4&%S:7)I;FMI=&4@;F]R:6W@(&MA;&+@.@!08>AI;R!A<')A\'ET
M82!A;G1R8?!TZP!3:?AS=&D@<')O8FQE;6]S('!R86YE\&EMX`!3:?AS=&D@
M4TU3`%-I=6YTZVIA<P!396YE9V%L87,`4V5N<V]R:75S.B``4G5G<^MJ:7,`
M4V5R8FEJ82!I<B!-;VYT96YE9W)A<P!397)I:F]S(&YU;65R:7,`4V5S:6IO
M<R!)1"!P87-I8F%I9^LN`%)I;FMI;GES`$YU<W1A='EM86D@;&5I9/YI86YT
M>7,@2G5M<R!P87-I:V5I<W1I('-L87!T8?YO9.$L(&IE:6=U(&KA(&MA9&$@
M;F]R<R!P86UI<O!I=&4N`$YU=&]L=7-I^"!S97)V97)I^"P@:W5R:75O<R!N
M;W)I=&4@;6%T>71I(&GP('!O<G1A;&\L(&YU<W1A='EM86DN`$MA;&)O<RP@
M;&%I:V\@>F]N;W,@:7(@9&%T;W,@;G5S=&%T>6UA:2X`4'5S;&%P:6\@<W!A
M;';X+"!A='-I;F%U:FEN:6UO(&1A_FYU;6\@:7(@:VET^"!V86EZ9&%V:6UO
M('!A<F%M971R^"!N=7-T871Y;6%I+@!.=7-T871Y;6%I('/K:VUI;F=A:2!A
M=&YA=6II;G1I+@!287-T87,@871N875J:6YI;6\@<VMR:7!T87,`4W4@\&EU
M;R!P87)A;65T<G4@9V%L:6UO<R!K96QI;W,@=FEE=&]VZW,Z(`!396GP96QA
M:0!087)D=6]T=7;K`%1R=6UP87,@87!R8?!Y;6%S`$%R(&YA=61O=&D@:VQA
M=FEA=/MR;W,@;7EG='5K=7,@=F%L9'EM=6D_`%)O9'ET:0!2;V1Y=&D@86MT
M>7;X:N$@<VMR:7!TX`!2;V1Y=&D@9&%B87)T:6[A('-K<FEP=.``4&%R;V1Y
M=&D@<VMI<G1U;75S('1A<G`@:?!S875G;W1O(&ER(&O@('1I:R!S=6=E;F5R
M=6]T;R!K;VYF:6?[<F%C:6YI;R!F86EL;RX`4F]D>71I('!A<VMU=&EN:6\@
M<')I<VEJ=6YG:6UO(&QA:6O@/P!2;V1Y=&D@9V%L:6UY8N8@<&%L:6MT:2!O
M<FEG:6YA;.``4F]D>71I('!A<FES:6YK:6W@`%)O9'ET:2!L96YT96SK<R!O
M<&5R86-I:O@@;65N:74_`%)O9'ET:2`E<R!M96YI=2!K86ERZVIE/P!2;V1Y
M=&D@8V5LZW,@;G5S=&%T>6WX(&QA;F?@`%)O9'ET:2!L96YT96SK<R!N=7-T
M871Y;?@@;&%N9^``4F]D>71I(&5I;'5TZW,@;G5S=&%T>6WX(&QA;F?@`%)O
M9'ET:2!P879E:6MS;.ML:6\@;G5S=&%T>6WX(&QA;F?@`%)O9'ET:2!F86EL
M^"#A:^ML:6W@`$QI^W1I<P!,:?MT:7,@<GET90!,:?MT:7,@=F%K87)E`%-U
M;6'^:6YT:0!3=6UA_FEN=&D@87)B82!P87-T=6UT:2!K86EM>6YI;FEU<R!B
M;&]K=7,`4VEE<F$@3&5O;NL`4F5G:7-T<F%C:6IA`%!A<F'P87,`4&%R8?!O
M(&%L9V]R:71M87,`4VEN9V%P^W)A<P!$>61I<P!0<F%L96ES=&D@<')O9FEL
M86MT:6O@`%-L;W9A:VEJ80!3;&]VZVYI:F$`4/MG80!3;FEE9V\@9WEL:7,Z
M(`!3;FEE9V\@:VEE:VES('9A;F1E;FEU.B``4V]L;VUO;F\@<V%L;W,`4V]M
M86QI80!$86EN;W,@:7(@16ELZW)A\.AI86D`4OOP:6%V:6UO('1V87)K;W,@
M<&%S:7)I;FMI;6%S`%-I=6YTZVIO(&%D<F5S87,`4&EE=/@@069R:6MA`%!I
M973X($5U<F]P;W,@*$E33RTX.#4Y+3,I`%!I973X($3^;W)D_FEJ;W,@:7(@
M4&EE=/@@4V%N9'9IZ&\@<V%L;W,`4&EE=&ENZR!H96UI<V9E<F$`5&%R<&%S
M('1A<G`@8V5L:?@`5&%R<&%S('1A<G`@8V5LZW,@='5R:6YI;R!I<B!K<F'P
M=&ENZW,`5&%R<&%S`%1A<G!A:2!T87)P(&-E;&GX`%1A<G!A:0!)<W!A;FEJ
M80!3<&%M87,`4W!E8VEF:6YI^"!S:6UB;VQI^"#A=&5R<&EM87,`4&5R<VME
M;'1I(&-E;.8`4&5R<VME;'1I('-T=6QP96SA`%!E<G-K96QT:2!E:6QU=.8`
M4W!O<G1A<P#0<FD@3&%N:V$`4W1A;F1A<G1A<P!3=&%R(%1R96LG87,`4')A
M9&EN:6%I(&UE=&%I`%)A:F]N87,@87)B82!P<F]V:6YC:6IA`$+[<V5N80!.
M=7-T;W1I('1I:W)I;G1I(&IE:6=U(&%T:71I;FMA(/!IX"!T86ES>6MLYC\`
M4V%U9V]J:6UO(&9O<FUA=&%S`$=A=';K<R!A9')E<V%S`%7^8G)A=6MT:0#>
M;V3^:?@@<^!R8?!A<P!.=6EM=&D@9&]M96[@(&YU;R!A9')E<V\`4W1I;&EU
M<R!;0U-370!396MM+@!!=&]S=&]G^"!L86GP:V\@7W1E;6$Z`%1E;6$`P79E
M<W1I`$EN9&5K<V%S`%/K:VUI;F=A`$MO;F9I9_MR86-I:F$@871S=&%T>71A
M('/K:VUI;F=A:2X@4&5R:W)A=6MI=&4@<'5S;&%PX2P@:V%D('!A;6%T>71U
M;>MT92!P86ME:71U;75S+@!!='-A<F=I;NL@:V]N9FEG^W)A8VEJ;W,@:V]P
M:6IA('/K:VUI;F=A:2!I\'-A=6=O=&$N`"<E<R<@<^MK;6EN9V%I('7^<F'P
M>71A<RX`4W5D86YA<P!4=7)I;GES`%-A=6SK=&5K:7,`4V%U;.ML>6=I<P!3
M875LZW1A`%-A=6SK=&5K:7,`4V%U;.MT96MI<R]3875LZVQY9&ES`%-A=6SK
M=&5K:7,Z(`!3875LZVQY9VES`%-A=6SK;'EG:7,Z(`!,86EP<VYI<P!!<'1A
M<FYA=FEM87,`4W5R:6YA;6%S`%!A=F%R9.L`4W9A;&)A<F1A<R!I<B!$_F%N
M;6%I;F%S`%-V87II;&%N9&%S`-!V961I:F$`T'9E:6-A<FEJ80!3:6YT86MS
MZW,@:VQA:61A('!A:67P:V]S(&MR:71E<FEJ=6IE`%-I<FEJ;W,@07)A8O@@
M4F5S<'5B;&EK80!4+6%U9')A`%0M875D<F]S`%135B!F86EL87,`3&5N=&5L
MZP!,96YT96SK<R!N=7-T871Y;6%I`$QE;G1E;.MS(&YU<W1A='EM86D`5&%I
M=F%N87,`5&%I=F%N87,L($MI;FEJ;W,@<')O=FEN8VEJ80!4863^:6MI<W1A
M;F%S`$IU;F=T:6[K(%1A;GIA;FEJ;W,@4F5S<'5B;&EK80!486EK:6YY<SH`
M1&%R8F%I`%1E;&5F;VYO(&YU;65R:7,`5&5M<"X@<&%S:RX@=F%L86YDX#H@
M`%1E;7!E<F%T^W)A`%1E;7!E<F%T^W)A.B``T&%B;&]N^"!A9&UI;FES=')A
M=FEM87,`5&5K<W1A<P!4:6L@=&5K<W1A<P!,>6=I=6]T:2!T96MS=.``5&5K
M<W1O('9I<O!U:F4`2V5T=BX`5&%I;&%N9&EE=&GP:V$@*%1)4RTV,C`I`%1A
M:6QA;F1A<P!!Z&G[(&MA9"!N875D;VIA=.MS('-I<W1E;6$N`$[K<F$@1E10
M(&UO9'5L:6\N`$AO<F1E+TMO;&%B(&EN=&5G<F%C:6IO<R!V87)I:VQI=6MA
M<R!N97!A;&%I:V\@(B5S(@!.97!A=GEK;R!U_FMR875T:2!-86EN=&5N86YC
M93HZ(&ML87/K<P!.=7-T871Y;?@@;&%N9V%S('7^9&%R>71A<RX@2?!E:6YU
M+@!*96EG=2!N;W)I=&4@;F%U9&]T:2!N=7-T871Y;75S+"!P87!R8?!Y:VET
M92!K860@861M:6YI<W1R871O<FEU<R!S=6MO;F9I9_MR=6]T^"!P87-T;W9I
MX"!D=6]M96[X(&)A>N8@;G5S=&%T>6UA;7,@<V%U9V]T:2X`5&EK(&%P871I
M;NMJ92!P=7/K:F4`3F7A<F'PZW1E(&-O;G1A:W1O($E$(&YU;65R:6\@87)B
M82!J:7,@;F5R87-T87,@9'5O;65N^"!B87KK:F4N`$MO;G1A:W1A<R!SZVMM
M:6YG86D@X71R875K=&%S(.$@2OMS^"!A9')E<_@@:VYY9V5LYBX`3F]RZV1A
M;6D@<&%T:6MR:6YT:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!A='-K:7+@
M(%!'4"!P87)A\&\@8FQO:^`N`$YEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@
M<F'P;R!)1"!A<F)A(&II<R!N97)A<W1A<R!D=6]M96[X(&)A>NMJ92X`3F7A
M<F'PZW1E(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+@!0;W-I<W1E;>MS('!R86YE
M\&EM87,Z(`!01U`@=?YK;V1A=FEM;R!G86QI;7EBZR!R96EK86QA=6IA('-A
M=6=A=7,@<')I<VEJ=6YG:6UO+B!"86YD>6MI=&4@<F'P>71I(&AT='!S.B\O
M(&%D<F5S;R!P<F%D_FEO:F4N`$9A:6QA<R`E<R!P<FEV86QO('1U<NMT:2`E
M<R!P87)A;65T<N`N`$9A:6QA<R`E<R!P<FEV86QO('1U<NMT:2!K86D@:W5R
M:75O<R`E<R!P87)A;65T<G5S+@!&86EL87,@;F5G86QI(&+[=&D@;G5K;W!I
M:G5O=&%S(&%N="!S87;F<RX`1F%I;&4@;NMR82!D=6]M96[X+@!21D,X.#(@
M;&%I\&MO(&%N=')A\'3K<RX`2F5I9W4@9&ER8F%T92!);G1E<FYE="!%>'!L
M;W)E<B!N87+P>6ML92P@<&EL;F%E:W)A;FES(')E9&%K=&]R:6%U<R!R9?YI
M;6%S(&=A;&D@<W5K96QT:2!P<F]B;&5M^"P@9.ML(/!I;W,@;F%R\'EK;.MS
M(&ML86ED^"X@1V%L:71E(&YE;6%T>71I(&MA:2!K=7)I^"!R961A:W1O<FEA
M=7,@96QE;65N=/@N($IE:6=U(&YA=61O:F%T92!7:6YD;W=S(#EX($]3(&=R
M96GH:6%U<VEA:2!J^W/X(&MO;7!I=71E<FES('!A<')A\.AI875S:6%I(&YU
M;'7P('!A<VME;&)D86UA<R!A<&EE('!A9W)I;F1I;N8@:VQA:63@+EQN7&Y*
M^W,@8G5V;W1E('!E<G-PZW1A<RX@2F5I9W4@=FES=&EE:R!N;W)I=&4@:?!B
M86YD>71I('!I;&YA96MR86[A(')E_FEMX"!S<&%U<VMI=&4@3TLN`$%P<F'P
M87,@(B5S(B!I\'1R:6YT87,N`%1I:R!K86ERZVIE('!U<^MJ90!#<GEP=%]P
M<7`Z.B!K;&%S96D@<F5I:VEA(&YU<F]D>71I(&MU<B!Y<F$@1VYU4$<@9F%I
M;&%I+@!,86GP:V%S(&GP<VGX<W1A<R`E<R!A9')E<V%T=6D@)7,@=&5M82`B
M)7,B(&)U=F\@<&%R;V1Y=&%S+@I48>AI874@=&%I(&YE9V%R86YT=6]J82!K
M860@;&%I\&MA<R!B=79O('!E<G-K86ET>71A<R!A<F)A('-U<')A<W1A<RX`
M4&%V861I;FEM87,@:W5RX2!N875D;W-I=&4@;G5O<F]D;VIE(.$@;&%I\&MO
M(')A\'EM;R!P=7-L87#A`$AO<F1E7T-R>7!T7W-M:6UE.CH@:VQA<V5I(')E
M:6MA;&EN9V%S($]P96Y34TP@;6]D=6QI<RX`3F5G86QI=2!I\'-A=6=O=&D@
M;G5S=&%T>6UO("(E<R(L(&YE<R!D=6]M96[X(&1Y9&ES('9I<O!Y:F$@;&5I
M<W1I;N`@<FEBX`!0<F]G<F%M82P@<VMI<G1A('!E<OYI^W+K=&D@\.$@9'5O
M;65N^"!T:7#@("@E<RDL(&YE<F%S=&$@<VES=&5M;VIE+@!4:6L@:V%I<NMJ
M92!I<B!D9?!I;NMJ92!P=7/K<V4`5&EK(&1E\&ENZVIE('!U<^MJ90!397)V
M97)I<R`B)7,B(&GP=')I;G1A<RX`4V5R=F5R:7,@(B5S(B!I\'-A=6=O=&%S
M+@`E<R!R96=I<W1R86-I:F]S('!R8?!Y;6%S(&GP=')I;G1A<RX`3G5R;V1Y
M=&$@96EL=73K(&YE96=Z:7-T=6]J82X`5&EK('9I<O!U=&ENZVIE(&ER(&%P
M871I;NMJ92!P=7/K<V4`5&EK(&%P871I;NMJ92!P=7/K:F4`3G5S:?AS=&D@
M9'5O;65N>7,@<')A<F%S=&DN`$YE9V%L:74@:?!S875G;W1I(&YU<VGX<W1O
M(&9A:6QO+@!796%T:&5R+F-O;2!B;&]K;R!NZW)A+@!.=7-T871Y;?@@;NMR
M82X`1&%L:?@L(&MU<FEA<R!G86QI;6$@<F]D>71I(&QA:?!K;R!T96MS=&4L
M(&[K<F$N`-!I86UE(&QA=6ME(.%V97-T82!P97(@9&%U9R!S:6UB;VQI^"X@
M2OMS(.%V963K=&4@)7,L(&\@;6%K<VEM86QU<R!S:V%IZ&EU<R`M("5S('-I
M;6)O;&EA:2X`4')O8FQE;6]S('-U(&9A:6SX('-I=6YT:6UU.B`E<R!N96YU
M<VGX<W1A<RX`3G5S:?AS=&D@9F%I;&\@;F5P879Y:V\N($9A:6QA<R`E<R!Y
M<F$@9&ED97-N:7,@;F5G=2!L96ED_FEA;6%S(&1Y9&ES("@E9"!B86ET86DI
M+@!.=7-I^'-T:2!F86EL;R!N97!A=GEK;RX@1F%I;&%S("5S('1I:R!D86QI
M;F%I(&YU<VGX<W1A<RX`2VQA:61A(.%J=6YG:6%N="!S:W)I<'3@+@!+;&%I
M9&$@:?!J=6YG:6%N="!S:W)I<'3@+@!.96=A;&EU('!A<F]D>71I(/!I;W,@
M;&%I\&MO(&1A;&EE<P!+;&%I9&$@X6ME;&EA;G0@:V]N=&%K=&EN:75S(&1U
M;VUE;FES+@!+;&%I9&$@X6ME;&EA;G0@:4-A;&5N9&%R(&1U;VUE;FES+@!+
M;&%I9&$@:V]N9FEG^W)A8VEJ;W,@9F]R;6]J92X@1W)E:>AI875S:6%I(&YE
M=?YP:6QDZW1E(')E:6MI86WX(&QA=6OX+@!+;&%I9&$@871L:65K86YT(&YU
M<F]D>73@(&%D<F5S^"!K;GEG96SK<R!F=6YK8VEJX"X@4&%B86YD>6MI=&4@
M=NML:6%U+@!+;&%I9&$@871N875J:6YA;G0@:V]N=&%K=&EN:75S(&1U;VUE
M;FES+B!086)A;F1Y:VET92!VZVQI874N`$ML86ED82!A=&YA=6II;F%N="!D
M:7-T<FEB=6-I:F]S('/@<F'PX"X@4&%B86YD>6MI=&4@=NML:6%U+@#0:7,@
M24U!4"!S97)V97)I<R!N97!A;&%I:V\@:V%T86QO9_@@9&%L:6II;6]S:2X`
M071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!205(@87)C:'EV87,N`$%T
M<F]D;RP@:V%D('1A:2!N971V87)K:6YG87,@6DE0(&%R8VAY=F%S+@!!=')O
M9&\L(&MA9"!T86D@;F5T96ES:6YG87,@:V]R=&5LZW,@;G5M97)I<RX`T&D@
M='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I(/YI;G5T97,@<&5R($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<&%S:6YA=61O:F%N="!(5%10
M('!R;W1O:V]L=0#0:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E
M<R!P97(@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@<&%S:6YA
M=61O:F%N="!(5%10('!R;W1O:V]L=0#0:2!T=F%R:WEK;.L@;&5I9/YI82!S
M:?AS=&D@_FEN=71E<R!33510('!R;W1O:V]L=2!P97(@5F]D869O;F4@271A
M;&EJ;W,@=F%R='5S+"!T:6L@5F]D869O;F4@;G5M97)I86US+B!*:2!R96EK
M86QA=6IA(&5L+B!P8?!T;R!A9')E<V\@5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2X`T&ES(&QA=6MA<R!P<FEV86QO;6%S+@#0:6%M92!L
M875K92!G86QI(&+[=&D@=&EK('-V96EK:65J:2!S:V%IZ&EA:2X`T&EA;64@
M;&%U:V4@9V%L:2!B^W1I('1I:R!S:V%IZ&EA:2!I<B!D=FET8?!K:6%I+@#0
M:6%M92!L875K92!G86QI(&+[=&D@=&EK(&'P='5N=&%I;FEA:2!S:V%IZ&EA
M:2X`T&EA;64@;&%U:V4@='5R:2!B^W1I(&MA8FQE;&EA:7,@87)B82!T87)P
M86ES(&%T<VMI<G1I('-V96EK:65J:2!S:V%IZ&EA:0#0:2!R96EK\&WK('1U
M<FD@8OMT:2!S:V%IZ&EU<RX`T&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S
M<&%L=F]S(&MO9&%S(%)'0B!(97@@9F]R;6%T92P@<&%V>7ID_FEU:2`G(S$R
M,S1!1B<N`-!I(&9O<FUA(&IA=2!A<&1O<F]T82X`5&%I("5S+@!486D@2V]L
M86(@1W)O=7!W87)E(&]B:F5K=&%S+B!.;W+K9&%M:2!P97+^:?MRZW1I(&]B
M:F5K=.`@<')I=F%L;W1E('1U<NMT:2!E;"X@<&'P=&\@:VQI96YTX"P@:W5R
M:7,@<W5P<F%N=.`@\.$@9F]R;6%TX"X@5&]K:?@@96PN('!A\'1O(&ML:65N
M=/@@<^!R8?#@(&=A;&ET92!R87-T:2!A<'-I;&%N:^8@)7,`T&ES(&QA:?!K
M87,@8G5V;R!P87)A\'ET87,@)7,@:V]D=6]T92X@2OMS(&YA=61O:F%T92!K
M:71O:VG@(&MO9'5O=.8N`-!I<R!S:V%IZ&EU<R!T=7)I(&+[=&D@9&ED97-N
M:7,@=?X@;G5LX2X`T&ES('-E<G9E<FES(&YE9V%L:2!I\&%R8VAY=G5O=&D@
M>FEP(&ER(&=Z:7`@9F%I;/@N`-!I('-I<W1E;6$@9&%B87(@:?!J=6YG=&$N
M`-!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S+@#0X2!L86YGX"!R96EK
M:6$@871I9&%R:6[K=&D@:?`@;G5S=&%T>6WX(&QA;F=O`%!E<FO[;FEJ80!"
M:6QI971A:0!,86EK87,`3&%I:V\@87!S:V%I=&$`3&%I:V\@9F]R;6%T87,`
M3&%I:V\@<&%S:7)I;FMI;6%S`%1I;6]R;&5S=.L`4&%R96EG;W,`4&%V861I
M;FEM87,Z`$MA;0!.;W+K9&%M:2!P87-I<FEN:W1I(&ME;&5TX"!E;&5M96YT
M^"P@;&%I:WEK:71E($-O;G1R;VP@*%!#*2!A<F)A($-O;6UN860@*$UA8RD@
M:VQA=FGPX"P@:7(@<&%S:7)I;FMI=&4@<&5L92X`T&EA;F1I96X`4F]D>71I
M($A434P@:V]DX`!4;V=A<P!4;VME;&%U`%)Y=&]J`%1O;F=A`%9I<O!U:F4`
M5FER\'5T:6YI86UE(&QA;F=E("A?=&]P*0!697)T:6UA:0!4<FEN:61A9&%S
M(&ER(%1O8F%G87,`5&%I<"!A<F)A(&YE`$%N='(N`%1U;FES87,`5'5R:VEJ
M80!4=7)K:?!K82`H25-/+3@X-3DM.2D`5'5R:VWK;FEJ80!4=7)K<V\@:7(@
M2V%I:V]S;R!S86QO<P!4=79A;'4`P79E<VMI=&4@<V%V;R!P87-I<FEN:VEM
MX#H@`%4N5BX@:6YD96MS87,Z(`!54DP`4VMR:7!T;R!P<FES=&%T>6UO('-T
M871U<V\@<F%P;W)T;R!54DP`55),.@!59V%N9&$`56MR86EN80!.97!A=GEK
M;R!P97)S:V%I='ET:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO('!R:63K=&D@
M<&%P:6QD;VUO<R!V87)T;W1O:F\@<F5G:7-T<F%C:6IO<R!I;F9O<FUA8VEJ
M;W,N`$YE<&%V>6MO('!A:V5I<W1I(%9&4R!F86EL;R`B)7,B('1E:7-I^"X`
M3F5P879Y:V\@<&%K96ES=&D@=&5I<VGX(%9&4R!F86EL=6D@)7,O)7,N`$YE
M<&%V>6MO('!E<F5I=&D@X2`E<RX`3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I
M92!344P@<V5R=F5R:6\N`$YE<&%V>6MO('!R:7-I:G5N9W1I(%-33"!R9?YI
M;74N`$YE<&%V>6MO(&YU:V]P:6IU;W1I(%9&4R!F86EL;RX`3F5P879Y:V\@
M<W5K=7)T:2!61E,@:V%T86QO9V\@(B5S(BX`3F5P879Y:V\@<W5K=7)T:2!6
M1E,@:V%T86QO9V\N`$YE<&%V>6MO('-U:W5R=&D@5D93(&9A:6QO+@!.97!A
M=GEK;R!S=6MU<G1I('1U\.AI;R!61E,@9F%I;&\N`$YE<&%V>6MO(&GP87)C
M:'EV=6]T:2!D=6]M96[X+@!.97!A=GEK;R!I\'1R:6YT:2`B)7,B+"!K871A
M;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO(&GP=')I;G1I("5S+"!K871A;&]G
M87,@;F5T=?#H:6%S`$YE<&%V>6MO(')E:W5R<VGP:V%I(&GP=')I;G1I(%9&
M4R!K871A;&]G;RX`3F5P879Y:V\@:?!T<FEN=&D@5D93(&MA=&%L;V=O+@!.
M97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T86QO9V\Z("5S+@!.97!A=GEK;R!I
M\'1R:6YT:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y:V\@:?!T<FEN=&D@5D93
M(&9A:6QO+@!.97!A=GEK;R!R96MU<G-I\&MA:2!I\'1R:6YT:2!61E,Z("5S
M+@!.97!A=GEK;R!N=7-T871Y=&D@9&%B87)T:6YI;R!K871A;&]G;RX`3F5P
M879Y:V\@9V%U=&D@<V5R=&EF:6MA=&\@87!R8?!Y;6\`3F5G86QI=2!U_FMR
M875T:2`E<R!A<')A\'EM;RX`3F5P879Y:V\@<&5R:V5L=&D@5D93(&9A:6QO
M+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO("(E<R(N`$YE<&%V>6MO
M(&%T:61A<GET:2!61E,@9F%I;&\@<F'P>6UU:2X`3F5P879Y:V\@871I9&%R
M>71I(%9&4R!F86EL;RX`3F5P879Y:V\@871I9&%R>71I('-U<W!A=7-T;R!A
M<F-H>79O+@!.97!A=GEK;R!P97)S:V%I='ET:2!V9G-R;V]T(&MA=&%L;V=O
M+@!.97!A=GEK;R!P97)V861I;G1I("5S(.$@)7,Z('1O:W,@:V%T86QO9V%S
M(&IA=2!E9WII<W1U;VIA`$YE<&%V>6MO('!E<G9A9&EN=&D@5D93(&MA=&%L
M;V=O+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!K871A;&]G;SH@)7,N`$YE
M<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO("(E<R(N`$YE<&%V>6MO('!E
M<G9A9&EN=&D@5D93(&9A:6QO("5S+R5S+@!.97!A=GEK;R!P97)V861I;G1I
M(%9&4R!F86EL;RX`3F5P879Y:V\@<&%L96ES=&D@)VUK:7-O9G,G+@!.97!A
M=GEK;R!I\'9E<G-T:2#P:6\@5V]R9"!D;VMU;65N=&\`3F5P879Y:V\@X7)A
M\'ET:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I
M;&\@*&-O<'DH*2!K;&%I9&$I+@!.97!A=GEK;R#A<F'P>71I(%9&4R!F86EL
M;R!D=6]M96[X+@!086)R875K=&D`073P875K=&D@<&%K96ET:6UU<P!!=/!A
M=6MT:2!A;FMS=&5S;N$@=F5I:W-MX`!.971I:^MT82!S97)V97)I;R!K;&%I
M9&$Z(`!.971I:^MT82!S97)V97)I;R!K;&%I9&$Z(`!.96YU<F]D>71A`%5N
M:6MO9&%S("A55$8M."D`2G5N9W1I;FEA:2!!<F%B^"!%;7ER871A:0!*=6YG
M=&ENZR!+87)A;'ES=.L`2G5N9W1I;NMS(%9A;'-T:6IO<P!*=6YG=&EN:?@@
M5F%L<W1Y:O@@071O:V5S;NMS('-A;&]S`%9I96YE=&%I`$YE_FEN;VUA<P!.
M9?YI;F]M87,@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`3F7^:6YO;6%S
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$YE_FEN;VUA<R!V87)T
M;W1O:F\@=F%R9&%S(&ER+V%R8F$@<VQA<'1A_F]D:7,N`%!A;F%I:VEN=&D@
M;G5O<F]DX"#P:6%M(&5L96UE;G1U:0!.9>%V87)D:6YT87,`4V%U9W5M;R!S
M=6UE=&EM86ES(&YE<')I=FEL96=I:G5O=&D@<VMR:7!T86D@;F5G86QI(&%T
M;&EK=&D@4&5R:^ML:6UO+TMO<&EJ879I;6\OP6OK;&EM;R!P<F]G<F%M:?!K
M86DN($YO<NMD86UI('!E<OYI^W+K=&D@=&5C:&YI;F5S(&1E=&%L97,@;6]Z
M:6QL82YO<F<@=&EN:VQA<'EJ92P@:7(@<W7^:6YO=&D@:V%I<"!S:W)I<'1A
M;7,@;&5I<W1I('!R:65I=&D@<')I92!L86EK:6YO<VEO<R!S875G>6ML;W,L
M('!A<W!A=7-K:71E($]++@!.96YA=61O=&D@<W!A;'9O<P!0;.MT:6YY<R!N
M97!A;&%I:V]M87,`071N875J:6YT:0!!=&YA=6II;G1I("5S`$%T;F%U:FEN
M=&D@=F%R=&]T;VK@`$%T;F%U:FEN:6UO('-K<FEP=&%S(&GP=')I;G1A<RX`
M3G5S:?AS=&D`5FES:2!M;V1U;&GX(&%T;F%U:FEN:6UO(&9A:6QA:2#A:V5L
M=&D@X2!S97)V97+A+@!$:63^:6]S:6]S(&QO=&EN:?!K;W,@<F%I9.MS`$1I
M9&EE:FD@<F]MZVYI\&MI('-K86GH:6%I`%5R=6=V86IU<P!.875D;W1I(&1A
M8F%R=&ENYCH@)7,`3F%U9&]T:2!34TP`3F%U9&]T:2!J96EG=2!V87)T;W1O
M:F\@=F%R9&%S+W-L87!T8?YO9&ES($E-4U`@<V5R=F5R:75I('ER82!K:71O
M:W,N`%9A<G1O=&]J87,@)7,@;F5A=71O<FEZ=6]T87,@<')IZVII;75I('!R
M:64@)7,N`%9A<G1O=&]J^"!A9&UI;FES=')A=FEM87,`5F%R=&]T;VIO(&YU
M<W1A='EM86D`5F%R=&]T;VKX(')E9VES=')A8VEJ80!687)T;W1O:O@@<F5G
M:7-T<F%C:6IA(&GP:G5N9W1A+@!687)T;W1O:F\@=F%R9&%S`%9A<G1O=&]J
M;R!V87)D87,Z`%9A<G1O=&]J;R!V87)D87,Z(`!687)T;W1O:F%I(/!I;VIE
M('-I<W1E;6]J93H`57IB96MI<W1A;F%S`%9&4R!K871A;&]G87,@;F5E9WII
M<W1U;VIA+@!!=&]S=&]G;W,`071O<W1O9_@@<F5D86=A=FEM87,`071O<W1O
M9_@@;&%I\&MA<P!$86)A<G1I;NL@9FEL=')A=FEM;R!P;W-I<W1E;>L@;F5P
M86QA:6MO(&%T;W-T;V?X(&UO9'5L:6\N`%)A<W1O<R!T96ES:6YG;W,@=FEE
M=&]VZW,Z(`!'86QI;VII;6%S`%)E:6OP;>L@;6EN=73K;6ES(&YU;R!D86)A
M<BX`4F5I:_!MZW,`4F5I:_!MZW,@:?`@:W5R:?@@9V%L:6UA('!A<VER:6YK
M=&D`5F%N=6%T=0!+:6YT86YT:7,`5F5N97-U96QA`%!A='9I<G1I;FEM87,@
M;F5B86EG=&%S("T@\&ES(&QA:?!K87,@<W5G861I;G1A<RX`5F5R<VEJ80!6
M97)S:6KX(&MO;G1R;VSK`$QY9VEU;W1I('9E<G1I:V%L:6%I`%9E<G1I:V%L
M=7,@=&%R<&%S`%9E<G1I:V%L=7,Z`$QA8F%I(&1I9&5L:7,`5FEE=&YA;6%S
M`%9I971N86UI971I\&MA("A625-#24DI`%!E<OYI^W+K=&D@)7,`4F]D>71I
M(&GP;W)I;N$@<'5S;&%PX0!097+^:?MRZW1I(&MA:7`@)7,`0G)I=/@@5FER
M9/YI;FEJ;W,@<V%L;W,`2D%6(%9I<F3^:6YI:F]S('-A;&]S`$UA=&]M=6UA
M<P!-871O;75M87,Z(`!6;V1A9F]N92!)=&%L:6IA('!E<B!33510`%=!4DX`
M1,M-15-)3R$A(2!005194R!)T%1224Y+251%(%-+4DE05,`@2=`@)7,N`%9A
M;&ES(&ER($9U='5N80!$ZVUE<VEO`%1R9>@N`$]R^"!P<F]G;F]ZZP!/<O@@
M<')O9VYO>NL@<&%G86P`5V5A=&AE<BYC;VT`5U=7`%=75R!P=7-L87!I<P!+
M87,@<V%V86ETY@!3=F5I:VD`4W9E:6MI(&%T=GEKYB#A("5S`$QA8F%S+"`E
M<P!686MA<O@@*$E33RTX.#4Y+3$I`%9A:V%R^"`H25-/+3@X-3DM,34I`%9A
M:V%R^"!386-H87)A`$)A;'1O:F\@<^!R8?!O(%]A9')E<V%I.@!+;VOA(&UO
M9'5LX2`E<R!T=7)I(')O9'ET:2!P;R!P<FES:6IU;F=I;6\_`$MO:W,@<VMI
M<G1U:V\@<VEM8F]L:7,_`$MO:W,@:V%B=>AI^"!S:6UB;VQI<S\`2W5R:6]S
M(&9A>NMS`$A434P@<F5D86MT;W)I875S(&UO9'5L:?@@X6IU;F=I;6%S+@!"
M86QT87-I<R!SX')A\&%S`$)A;'1O:F\@<^!R8?!O(')E9&%G879I;6%S`$1A
M8F%R=&ENZR!F:6QT<F%V:6UO('!O<VES=&5MZR!N97!A;&%I:V\@8F%L=&]J
M;R!SX')A\&\N`$%D<F5S86D@X71R875K=&D@X2!B86QTX&KA('/@<F'PX`!0
M;&]T:7,`4&QO=&ES($-34R!M871A:7,`)7,@:V%I<FEO:F\@;65N:74@<&QO
M=&ES("AP86ME:71I;6%I(&)U<R!M871Y=&D@<&\@:VET;R!P<FES:6IU;F=I
M;6\I.@!,96YT96SK<R!P;&]T:7,`4&QOZ&EO(&UA=&%S`%!L;W1I<SH`5VEK
M:0!6ZVIO(&=R96ET:7,@;6%Z9V%I<P!6ZVIA<SH`5NMJ87,Z(`!)\&UI;G1I
M<P!$87)B87,`1&%R8F\@861R97-A<P!$87)B;R!T96QE9F]N87,`4W9A<F)A
M`%@M4F5F`%@M4W!A;2U,979E;`!8+5-P86TM4V-O<F4`6"U3<&%M+5-T871U
M<P!8-3`Y=C,@<&%G<FEN9&EN:6%I(&YU<W1A='EM86D`6#4P.78S(&GP<&SK
M<W1O(')A:W1O('!A;F%U9&]J:6UA<P!8-3`Y=C,@86QT97)N871Y=G5S('9A
M<F1A<P!8-3`Y=C,@<F%K=&\@:61E;G1I9FEK871O<FEU<P!8-3`Y=C,@;6]D
M=6QI86D`65D`65E960!986AO;R$@_F5MZVQA<&ES`$MA<VUE=`!*96UE;F%S
M`%1A:7``5&%I<"P@8?`@<W5T:6YK=0!*^W,@97-A=&4@5$5+4U1)3DE!344@
M4D7>24U%+B!.;W+K9&%M:2!G<N'^=&D@X2!765-)5UE'('-P875S:VET92!;
M/#Y=+@!*^W,@;F5P<FES:6IU;F?F+@!3879O('9A<F1E(&YE9V%L:71E(&YA
M=61O=&D@<VEM8F]L:6\@)UPG+@#!=F5DZW1E(&YE=&5I<VEN9^`@96PN('!A
M\'1O(&%D<F5SX"X`3F5P<FEJ=6YGZW1E(&IO:VGX(&QA=6OX(&GP(.%K96QI
M86UO(&9A:6QO('!R:64@)7,@871I=&EN:V%M^"!L875K^"X`2OMS(&%T<VEJ
M=6YGZW1E+@!4=7)I=&4@X79E<W1I('1E:7-I;F?@('1E;&5F;VYO(&YU;65R
MX2`H=&EK('-K86GH:75S(&ER("<K)RP@:F5I9W4@;F]R:71E(&YU<F]D>71I
M('1A<G!T875T:6[A(&MO9.`I+@#!=F5DZW1E(&YE=&5I<VEN9^`@<F5I:_!M
MYBX`3F]RZV1A;6D@;F%U9V]T:7,@<F5G:7-T<F%C:6IO<R!S:7-T96UA+"!T
M=7)I=&4@<W5K;VYF:6?[<G5O=&D@9'5O;65N^"!M963^:6\@<&]S:7-T96WF
M+@!0<FEE\"!S:?AS9&%M:2!P<F%N9?!I;>`L(&%P<F'P>6MI=&4@<')O8FQE
M;>`N`,%R8?!Y:VET92!N=6]R;V1O<R!54DP`5'5R:71E('!A<VER:6YK=&D@
M<V5R=F5RX2P@:W5RX2!N;W)I=&4@:?!T<FEN=&DN`$YU<F]D>6MI=&4@=F%R
M=&]T;VIO('9A<F3@+"!K=7)I;R!D=6]M96YI<R!T<FEN871E+@!.=7)O9'EK
M:71E('9A<G1O=&]J;R!V87)DX"!T<GEN:6UU:2X`071O<W1O9_@@;&%I\&OX
M(&%K='EV879I;75I('1U<FET92!N=7)O9'ET:2!B96YT('9I96[@(&5L+B!P
M8?!T;R!A9')E<^`N`$YU<F]D>6MI=&4@:W5R:6%M;R!V87)T;W1O:F\@=F%R
M9.`N`$YU<F]D>6MI=&4@871N875J:6YA;6\@=F%R=&]T;VIO('9A<F3@+@!.
M=7)O9'EK:71E('9E:6MS;>`N`$K[<R!T=7)I=&4@X79E<W1I(&YA=6IO<R!K
M871E9V]R:6IO<R!P879A9&EN:6W@+@`E<R!S97-I:F$@8F%I9^MS:2X@4')A
M\&]M92!P<FES:6IU;F=T:2!I\"!N875J;RX`2OMS^"!E;"X@<&'P=&\@861R
M97-A<SH`16PN('!A\'1O(&%D<F5S87,Z`$EN9F]R;6%C:6IA(&%P:64@2G5S
M`$YU;R`E<R!S97-I:F]S('!R863^:6]S(&K[<_@@25`@861R97-A<R!P87-I
M:V5I=.LN(%1U<FET92!P<FES:6IU;F=T:2!I\"!N875J;RX`2OMS^"!V87)D
M87,O<&%V87)DZP!*^W/X(&%U=&5N=&EF:6MA=FEM;R!S:7-T96UA(&YE<&%L
M86EK;R!V87)T;W1O:O@@<^!R8?!O+"!A<F)A(/!I(&9U;FMC:6IA('7^9')A
M=7-T82!DZVP@=&%M('1I:W+X('!R:67^87/H:?@N`$YU;R`E<R!S97-I:F]S
M('!R863^:6]S(&K[<_@@;F%R\'EK;.MS('1I<&%S('!A<VEK96ETZRX@5'5R
M:71E('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X(&YA<O!Y:VSK(&YE<&%L
M86EK;R#P:6]S(&=A;&EM>6+K<RX`2OMS^"!L86EK;R!J=6]S=&$Z`$K[<_@@
M<W1A;F1A<G1I;FES(&%P<F'P87,Z`$K[<_@@=F%R9&%S+W!A=F%R9.LZ`$K[
M<_@@;F%U:F%S("5S('-L87!T8?YO9&ES('ER83H@)7,`2OMS^"!N=7-T871Y
M;6%I(&%T;F%U:FEN=&DN`$K[<_@@<VQA<'1A_F]D:7,@<&%K96ES=&%S`$K[
M<_@@<VQA<'1A_F]D:7,@<&%K96ES=&%S+B!087-I=&EK<FEN:VET92!S879O
M('!A\'3@(&ER('!R:7-I:G5N:VET92!S=2!N875J=2!S;&%P=&'^;V3^:74N
M`$K[<_@@;G5T;VSF('-E<G9E<FEA:3H`2G5G;W-L879I:F$`6F%I<F%S`%IA
M;6)I:F$`6FEM8F%B=NL`16YE<F=I;F=O<P!;4&%S;.MP=&D@8VET=6]J86W@
M('1E:W-TX%T`6V)E('!A=F%D:6YI;6]=`%M0<F]B;&5M;W,@<')A;F7P:6UA
M<UT`6U)O9'ET:2!C:71U;VIA;>`@=&5K<W3@("T`6U)O9'ET:2!C:71U;VIA
M;>`@=&5K<W3@("T@)7,@96EL=71E<UT`6V5I;'5TZR`E<R!I\"`E<UT`7T%D
M<F5S87,H86DI('!E<G-I=6[H:6%M:2#A.@!!7V1R97-A:2#A(&MU<FEU;W,@
M;F5A='-A:WET:3H`7U9A;&1Y;6%S`%]*=6]D87-I<R!SX')A\&%S`%]#3$D`
M7T1U;VUE;O@@;65D:7,`7TGP=')I;G1I(&5I;'5TY@!?5FES:?!K86D@:?!T
M<FEN=&D@;&%I\&O@`$MI96MV:65NX"!?861R97/@(')A\'EK:71E(&YA=6IO
M:F4@96EL=73K:F4Z`%!?97)S:?AS=&D`1U]R=7#K<P!085]G86QB80!?4&%V
M96EK<VSK;&EO(&YU<W1A='EM86DN+BX`07(@<&%L:6MT:2!L86GP:V\@:V]P
M:6K@(/!I;VIE('!A\'1O(&3K_G5TZVIE/P!0<FES:5]J=6YG=&D`071S:5]J
M=6YG=&D`7TME:7-T:2!N=6]R;V3@+BX`4&5R:V5L=&D@;&%I\&MU<R#A(%]K
M871A;&]GX#H`7TUA;F\@16PN('!A\'1O(&%D<F5S86D`7TYU<W1A='EM86D`
M7U1E:7/K<P!?2?!T<FEN=&D@;G5O<F]DX"XN+@!?4VMR:7!T87,`7TMO;F9I
M9_MR86-I:F$`7TQE;G1E;.MS(&YU<W1A='EM86DN+BX`5E]A<G1O=&]J86D`
M071?;W-T;V=O<P!?0F%L=&%S:7,@<^!R8?!A<P!A9')E<_@@:VYY9V5LZP!I
M<@!+86QE;F1O<FEU<P!R86UU<P!S<&%U<VMI=&4@Z&EA`&MR96YT80!L875K
M87,`9F%I;&%S`&YU;R`E<R`H)7,I("5S("5S`&$Z`'1U;VIA=2!P870`<&%P
M<F%S=&D`96EL=71E<UT`871I=&EN:V$`;6MI<V]F<R!K;&%I9&]S(&MO9&%S
M("5D(&)E9&%R86YT($E33RX`=F%R9&%S`&YE<F5A;&EZ=6]T80!D87(@;F5R
M96%L:7IU;W1A`'7^<F'P^"!K;GEG96SK`&%R8F$`<')O8V5N=&%I`'!I:W-E
M;&EA:0!P<F]C;6%I;"!S:W)I<'1A<R!S=6=E;F5R=6]T87,@<W4@26YG;P!K
M>6QA`')O9'ET:2!S:VER='5M=7,`<VEE=F4@9FEL=')A<R!S=6=E;F5R=6]T
M87,@<W4@26YG;P!S;7,R96UA:6P@<&5R($A45%``<W1A8FEL:0!D87)B^"!S
MX')A\&%S`'-L87!T8?YO9.$@='5R:71E(.%R8?!Y=&D@9'4@:V%R='5S`'5N
M:69I:W5O=&D`9&%L:7,`=F%R=&]T;VIO('!A<VER:6YK:6UA<P!V0V%R9`!P
M.@!W96%T:&5R+F-O;0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEN9V\O;&]C86QE+VQV7TQ6+P``````````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-#<`,#$W
M-C0T`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O;'9?3%8O
M3$-?34534T%'15,O````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<T-P`P,C$T,S$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;F=O+VQO8V%L92]L=E],5B],0U]-15-304=%4R]I;F=O+FUO````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#0R-S`S`#$P-#$W,S8R-S0W`#`R,C<R-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#>$@25`````!0!
M```<````O`@``'4!``!<$0```````#`7```$````,1<```,````V%P``*```
M`#H7```(````8Q<```4```!L%P``(0```'(7```/````E!<```@```"D%P``
M$P```*T7```'````P1<```4```#)%P``%````,\7```?````Y!<```@````$
M&```%`````T8```-````(A@``"H````P&```,@```%L8```1````CA@```,`
M``"@&```"P```*08```(````L!@```D```"Y&```#@```,,8```[````TA@`
M`!,````.&0``%0```"(9```$````.!D```@````]&0``%0```$89```.````
M7!D```(```!K&0``"@```&X9```.````>1D```P```"(&0``!P```)49```(
M````G1D```<```"F&0``"@```*X9```I````N1D``!$```#C&0```@```/49
M```*````^!D```4````#&@``$0````D:```0````&QH```D````L&@``$```
M`#8:```9````1QH```<```!A&@``%0```&D:```A````?QH``"4```"A&@``
M$0```,<:```4````V1H``"\```#N&@``"@```!X;```(````*1L```\````R
M&P``.@```$(;```O````?1L``"8```"M&P``"````-0;```2````W1L```\`
M``#P&P``$``````<```-````$1P``"$````?'```!````$$<```'````1AP`
M``4```!.'```#0```%0<```)````8AP```<```!L'```"0```'0<```(````
M?AP```4```"''```$````(T<```0````GAP```\```"O'```"P```+\<```/
M````RQP```P```#;'```#P```.@<```.````^!P```8````''0``'@````X=
M```A````+1T```,```!/'0``$P```%,=```9````9QT``!L```"!'0``#@``
M`)T=```+````K!T```P```"X'0``%0```,4=```-````VQT``$,```#I'0``
M,0```"T>``!'````7QX``$\```"G'@``/0```/<>``!.````-1\``!$```"$
M'P``)0```)8?```'````O!\``#D```#$'P``"````/X?```-````!R````0`
M```5(```#````!H@```8````)R````0```!`(```#````$4@```*````4B``
M``4```!=(```"0```&,@```2````;2```!````"`(```0P```)$@```R````
MU2````(````((0``!0````LA```(````$2$```D````:(0``%0```"0A```0
M````.B$```<```!+(0``!@```%,A```'````6B$```(```!B(0``!````&4A
M```8````:B$``!````"#(0``&P```)0A```/````L"$``(D```#`(0``B0``
M`$HB```'````U"(``"8```#<(@``&0````,C```;````'2,```<````Y(P``
M!````$$C```.````1B,```P```!5(P``*0```&(C```$````C",```4```"1
M(P``"````)<C```C````H",``"8```#$(P``%````.LC```4`````"0``!0`
M```5)```#````"HD```%````-R0```<````])```'@```$4D```1````9"0`
M``T```!V)```"````(0D```>````C20```4```"L)```*````+(D```H````
MVR0``"D````$)0``$P```"XE```'````0B4```@```!*)0``"P```%,E```2
M````7R4``!(```!R)0``"P```(4E```)````D24```L```";)0``%@```*<E
M```1````OB4``!0```#0)0``!````.4E```$````ZB4```L```#O)0``#```
M`/LE```-````""8```P````6)@``"0```",F```$````+28```P````R)@``
M#0```#\F```&````328```\```!4)@``$P```&0F```>````>"8``"````"7
M)@``!````+@F```.````O28``!0```#,)@``&@```.$F```7````_"8``!<`
M```4)P``&P```"PG```?````2"<``!,```!H)P``$P```'PG```&````D"<`
M`!X```"7)P``$@```+8G```3````R2<```0```#=)P``$````.(G```7````
M\R<``",````+*```'0```"\H```'````32@```<```!5*```!0```%TH```1
M````8R@``"D```!U*```*P```)\H```A````RR@``!P```#M*```!0````HI
M```"````$"D```,````3*0``(````!<I```D````."D``"8```!=*0``#```
M`(0I```,````D2D```@```">*0``"````*<I```-````L"D``!````"^*0``
M.@```,\I```'````"BH```8````2*@``#0```!DJ```+````)RH``!4````S
M*@``"0```$DJ```.````4RH``#L```!B*@``%0```)XJ```,````M"H```H`
M``#!*@``"@```,PJ```,````URH```P```#D*@``#0```/$J```"````_RH`
M``8````"*P``10````DK``!@````3RL``#````"P*P``$````.$K```?````
M\BL```P````2+```$````!\L```/````,"P``!L```!`+```)````%PL```*
M````@2P``!H```",+```(@```*<L```(````RBP``"D```#3+```&````/TL
M```4````%BT```<````K+0``"0```#,M```*````/2T```,```!(+0``!0``
M`$PM```%````4BT```4```!8+0``EP$``%XM```#````]BX```0```#Z+@``
M*@```/\N```*````*B\```4````U+P``'P```#LO```/````6R\```X```!K
M+P``%````'HO```&````CR\```P```"6+P``#@```*,O```9````LB\```D`
M``#,+P``%0```-8O```1````["\``"0```#^+P``-0```",P```0````63``
M``,```!J,```"````&XP```/````=S```!````"',```%````)@P```Z````
MK3```!@```#H,```%@````$Q```(````&#$```D````A,0``&P```"LQ```-
M````1S$```(```!5,0``$0```%@Q```4````:C$```P```!_,0``"````(PQ
M```%````E3$```@```";,0``"0```*0Q```K````KC$``!,```#:,0```@``
M`.XQ```*````\3$```@```#\,0``$0````4R```2````%S(```@````J,@``
M$P```#,R```5````1S(```@```!=,@``#0```&8R```9````=#(``!L```".
M,@``#````*HR```3````MS(``"\```#+,@``"@```/LR```(````!C,``!(`
M```/,P``/@```"(S```P````83,``"(```"2,P``!P```+4S```*````O3,`
M``<```#(,P``#````-`S```)````W3,``!D```#G,P``!0````$T```(````
M!S0```<````0-```$````!@T```*````*30```@````T-```"@```#TT```*
M````2#0```4```!3-```$0```%DT```2````:S0``!````!^-```&````(\T
M```/````J#0```P```"X-```#@```,4T```2````U#0```<```#G-```'@``
M`.\T```D````#C4```4````S-0``%@```#DU```>````4#4``"$```!O-0``
M#@```)$U```2````H#4``!(```"S-0``%@```,8U```2````W34``#(```#P
M-0``)````",V``!%````2#8``#<```".-@``*@```,8V```Y````\38``!,`
M```K-P``(@```#\W```(````8C<``#<```!K-P``#````*,W```1````L#<`
M``@```#"-P``"P```,LW```6````US<```D```#N-P``#````/@W```.````
M!3@```4````4.```!P```!HX```4````(C@``!`````W.```0````$@X```C
M````B3@```(```"M.````P```+`X```&````M#@```H```"[.```%0```,8X
M```:````W#@```<```#W.```"P```/\X```%````"SD```(````1.0``!0``
M`!0Y```;````&CD``!,````V.0``%P```$HY```0````8CD``(T```!S.0``
MC0````$Z```$````CSH``!P```"4.@``'@```+$Z```E````T#H```P```#V
M.@``"0````,[```/````#3L``!`````=.P``,0```"X[```%````8#L```4`
M``!F.P``#````&P[```?````>3L``"4```"9.P``'````+\[```=````W#L`
M`!,```#Z.P``#@````X\```(````'3P```<````F/```'@```"X\```0````
M33P```T```!>/```!@```&P\```?````<SP```@```"3/```)@```)P\```C
M````PSP``"T```#G/```$@```!4]```'````*#T```<````P/0``"@```#@]
M```3````0ST``!(```!7/0``#````&H]```)````=ST```P```"!/0``'P``
M`(X]```7````KCT``!\```#&/0``!````.8]```&````ZST```\```#R/0``
M#P````(^```/````$CX```\````B/@``$````#(^```(````0SX``!````!,
M/@``$````%T^```'````;CX``!4```!V/@``%P```(P^```;````I#X``!T`
M``#`/@``!P```-X^```1````YCX```\```#X/@``'@````@_```;````)S\`
M`!H```!#/P``(P```%X_```3````@C\``!,```"6/P``'````*H_```(````
MQS\``"(```#0/P``%@```/,_```8````"D````8````C0```$@```"I````4
M````/4```"L```!20```&P```'Y````&````FD````<```"A0```"````*E`
M```0````LD```!@```##0```&@```-Q````?````]T```!\````700``"@``
M`#=!```(````0D$```,```!+00``)P```$]!```=````=T$``"L```"500``
M#P```,%!```1````T4$```\```#C00``"@```/-!```:````_D$``!0````9
M0@``00```"Y"```+````<$(```P```!\0@``$````(E"```0````FD(``!8`
M``"K0@``$````,)"```4````TT(``#H```#H0@``%@```"-#```,````.D,`
M``X```!'0P``"@```%9#```,````84,```P```!N0P``#0```'M#```"````
MB4,```H```",0P``+P```)=#``!*````QT,``#P````21```$````$]$```;
M````8$0```P```!\1```%````(E$```0````GD0``!<```"O1```(````,=$
M```0````Z$0```T```#Y1```(@````=%```(````*D4``"0````S10``&P``
M`%A%```4````=$4```<```")10``"@```)%%```/````G$4```(```"L10``
M!0```*]%```'````M44```4```"]10```0````````!Y`````````-(`````
M``````````````#&`````````*$````#`````````'``````````Z````#8`
M````````<P```#````"#````8@```),```"P````NP````@```"1````XP``
M````````````(````#<`````````9P```+H``````````````"L````.`0``
MB0````````"-`````````!$```"5````^@```,X```#N`````````#T`````
M````^P````H`````````&P````````"4````1@```+,````.````!0$```4`
M````````O@```!<```#T`````````%,`````````ZP```.\```#=````8```
M`$T````'````(@```'H```"&````1P```$0```````````````````!D````
M/````"H`````````'P`````````"`0``U````*8`````````.@```"P`````
M````0P```+0````R````7@````L```"G`````````!8`````````(P```*\`
M```(`0`````````````+`0``$````($```#%````L0```)8```"*````````
M`!(!``!T````.`````D```!0`````````&H```!K````50```*T````,`0``
M`````+P```#Q````,P```/````!%````W@`````````D````%`$``((```#S
M````60````````"U````D````,0````<````!P$``'X```#9````?````'$`
M``"?````#P$``'4``````````````!X```#'````R0`````````4````J@``
M`/4```!F``````````````!4````3@```'T````A````/P````````#,````
M"@$``.<```"N````@````)T`````````CP```/D`````````HP```+(`````
M`````````&,```"I````!`$``(0````````````````````F`````P$``%H`
M````````]P```,$```#B````7P```.0```#;````0```````````````;P``
M`!T````1`0``J````(L```#8````F0```)@````)`0```````-4`````````
M6````#D```"@````SP```)P```!W````2````-``````````3P```.8```!6
M````.P```)(`````````>````,L`````````V@```!(```#-`````````+D`
M```3`0``K````'8````I``````$``)H```"V````N```````````````&```
M``````#E````````````````````PP```'\`````````/@```"@```#`````
M``````````!7````I```````````````2P```&D````Q````)0```)L`````
M````X```````````````80```)X```#(````;````"\`````````I0``````
M```$````90```/@```"(````C````"T```"]````7```````````````````
M`(<````-`0``[0```-$````5````$`$`````````````R@```.H```"W````
M`````/(```!"````_0``````````````_````.$```#3````!@$``.P`````
M````#P```,(````:````````````````````C@```!D```#?````EP```!,`
M``"_````Z0```-P```![````<@```"<````T````-0```$D```#6````+@``
M`*L```"%````#0```/\`````````!@```/X`````````H@```&X```#V````
M4@```$$```!H``````````(``````````````-<````!`0````````````!1
M````70```$H```!;````#````$P`````````;0`````@86YD`"!O<@`E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`#(T(&AO=7)S
M`$%-+U!-`$%C=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S<V5S.@!!8W1I
M=F%T92!38W)I<'0`061D('!A:7(`061D:71I;VYA;"!3971T:6YG<P!!9&1R
M97-S`$%L:6%S`$%L;"!O9B!T:&4@9F]L;&]W:6YG`$%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"X`06YS=V5R960`06YY(&]F('1H92!F;VQL;W=I
M;F<`07!P;'D@1FEL=&5R<P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L
M971E('1H:7,@<G5L93\`075T;VUA=&EC86QL>2!U<&1A=&4@=&AE('-C<FEP
M="!A9G1E<B!E86-H(&-H86YG93\`079A:6QA8FQE(&9I96QD<SH`0F-C`$)E
M9VEN<R!W:71H`$)I<G1H9&%Y`$)L86-K;&ES=`!";&%C:VQI<W0@161I=`!"
M;&%C:VQI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT
M97)I;F<@9')I=F5R+@!";&%C:VQI<W1E9"!!9&1R97-S`$)L86-K;&ES=&5D
M($%D9')E<W-E<P!";V1Y`$-A;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#87-E(%-E;G-I=&EV90!#8P!#96QL(%!H;VYE`$-H86YG97,@<V%V960N
M`$-L;W-E(%=I;F1O=P!#;VUP86YY`$-O;G1A:6YS`$-O<'D@)7,`0V]P>2!O
M9B`E<P!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<P!#<F5A=&4@;F5W(&9O;&1E<@!$1`!$25-!0DQ%1#H@`$1A:6QY`$1E86-T
M:79A=&4@4V-R:7!T`$1E9F%U;'0@261E;G1I='D`1&5L971E("5S`$1E;&5T
M92!#;VYD:71I;VX`1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L>0!$96QE=&5D
M`$1E;&EV97(@:6YT;R!M>2!)3D)/6`!$96QI=F5R(&EN=&\@;7D@24Y"3U@@
M86YD(&-O<'D@=&\`1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R961I<F5C
M="!T;P!$96QI=F5R('1O(&9O;&1E<@!$97-C<FEB92!T:&4@4')O8FQE;0!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!$:7-A8FQE("5S`$1I<V%B;&5D`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&1E=&%I;&5D(&YO=&EF:6-A=&EO;B!W:&5N(&5A8V@@9FEL=&5R(&ES(&%P
M<&QI960_`$1O(%]N;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L:R!O<B!L:7-T
M(&UE<W-A9V5S`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O('1H:7,Z`$1O97-N)W0@8F5G:6X@=VET:`!$;V5S;B=T(&-O;G1A
M:6X`1&]E<VXG="!E;F0@=VET:`!$;V5S;B=T(&5X:7-T`$1O97-N)W0@;6%T
M8V@@*'=I=&@@<&QA8V5H;VQD97)S*0!%9&ET`$5D:70@)7,`16UA:6P`16UP
M='D@<F5S=6QT+@!%;F%B;&4@)7,`16YA8FQE9`!%;F1S('=I=&@`17%U86P@
M=&\`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&ES=&EN9R!2=6QE<P!%>&ES
M=',`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`1FEL=&5R($%L;"!-97-S86=E
M<P!&:6QT97(@3VYL>2!3965N($UE<W-A9V5S`$9I;'1E<B!/;FQY(%5N<V5E
M;B!-97-S86=E<P!&:6QT97(@3W!T:6]N<P!&:6QT97(@4G5L90!&:6QT97(@
M4G5L97,`1FEL=&5R(%-C<FEP="!$:7-P;&%Y`$9I;'1E<B!?4G5L97,`1FEL
M=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!C;W!I960@
M=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A
M9V4H<RD@:&%V92!B965N(&1E;&5T960N`$9I;'1E<B!A8W1I=FET>3H@)7,@
M;65S<V%G92AS*2!T:&%T(&UA=&-H960@=&AE(&)L86-K;&ES="!W97)E(&1E
M;&5T960N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M
M("(E<R(@:&%S(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@(B5S(BX`1FEL
M=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E("(E
M<R(@9G)O;2`B)7,B(&AA<R!B965N(&UO=F5D('1O('1H92!F;VQD97(@(B5S
M(BX`1FEL=&5R(&YO="!F;W5N9"X`1F]R(&%N(&EN8V]M:6YG(&UE<W-A9V4@
M=&AA="!M871C:&5S.@!&;W)W87)D`$9O<G=A<F0@:7,@;F]T('-U<'!O<G1E
M9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!&;W)W87)D<P!&
M;W)W87)D<R!%9&ET`$9R;VT`1W)E871E<B!T:&%N`$=R96%T97(@=&AA;B!O
M<B!E<75A;"!T;P!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E
M`$EM<&]R=&%N=`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);F1I=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H92!C
M=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$EN97AI<W1A;G0@;6%I;&)O>"!S
M<&5C:69I960@9F]R(&UE<W-A9V4@9&5L:79E<GDN`$ES`$ES;B=T`$QA;F=U
M86=E`$QE<W,@=&AA;@!,97-S('1H86X@;W(@97%U86P@=&\`3&ES="!(96QP
M(%1O<&EC<P!,:7-T+4E$`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%R7VL@
M;65S<V%G92!A<R!D96QE=&5D`$UA<FL@;65S<V%G92!A<SH`36%T8VAE<R`H
M=VET:"!P;&%C96AO;&1E<G,I`$UA=&-H:6YG(&9I96QD<P!-87AI;75M(&YU
M;6)E<B!O9B!B;&%C:VQI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L
M(&%D9')E<W-E<SH@)7,L($UA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L
M9"!N;W0@861D(&YE=R!A9&1R97-S97,@=&\@8FQA8VML:7-T+@!-87AI;75M
M(&YU;6)E<B!O9B!W:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O
M=&%L(&%D9')E<W-E<SH@)7,L($UA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#
M;W5L9"!N;W0@861D(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+@!-97-S
M86=E`$UI<W-I;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O`$UI
M<W-I;F<@<F5A<V]N(&9O<B!R96IE8W0`36ES<VEN9R!R96%S;VX@:6X@=F%C
M871I;VXN`$UO;G1H;'D`36]V90!-;W9E(%)U;&4@1&]W;@!-;W9E(%)U;&4@
M57``3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C871I;VX@<F5P;&EE<SH`
M3F%M90!.979E<@!.97<@4G5L90!.;R!B86-K96YD(&-O;F9I9W5R960@9F]R
M('1H:7,@:&]S=`!.;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S
M+G!H<`!.;R!H96%D97)S('-P96-I9FEE9`!.;R!S8W)I<'0@9V5N97)A=&5D
M+@!.;R!S=')I;F=S('-P96-I9FEE9`!.;W0@97%U86P@=&\`3F]T97,`3W!T
M:6]N<P!/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A=&EN9RX`3W1H97(@26YF
M;W)M871I;VX`3W1H97(@3W!T:6]N<P!087-S=V]R9`!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E(&5N=&5R('1H92!N86UE
M(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4E]E87-O;@!296-E
M:79E9`!2961I<F5C="!T;P!296=U;&%R(&5X<')E<W-I;VX`4F5J96-T('=I
M=&@@<F5A<V]N`%)E;6]V92!P86ER`%)E<V5N="!4;P!297-E;G0M9G)O;0!2
M971U<FX@=&\@1FEL=&5R<R!,:7-T`%)E='5R;B!T;R!/<'1I;VYS`%)E='5R
M;B!T;R!2=6QE<R!,:7-T`%)O;&4`4G5L90!2=6QE($-O<&EE9`!2=6QE($1E
M;&5T960`4G5L92!$:7-A8FQE9`!2=6QE($5N86)L960`4G5L92!.86UE`%-A
M=F4`4V%V92!/<'1I;VYS`%-A=F4@4V5T=&EN9W,`4V-R:7!T`%-C<FEP="!5
M<&1A=&EN9P!38W)I<'0@;F]T('5P9&%T960N`%-C<FEP="!S=6-C97-S9G5L
M;'D@86-T:79A=&5D+@!38W)I<'0@<W5C8V5S<V9U;&QY(&1E86-T:79A=&5D
M+@!3965N`%-E;&5C="!A(&9I96QD`%-E;&5C="!T87)G970@9F]L9&5R`%-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M
M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;&8M1&5F:6YE9"!(96%D97(`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD97(`
M4V5T=&EN9W,@<W5C8V5S<V9U;&QY('5P9&%T960N`%-H;W<@06-T:79E(%-C
M<FEP=`!3:&]W($-U<G)E;G0@4V-R:7!T`%-I>F4`4VMI<"!-86EN=&5N86YC
M90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=&]P(&-H96-K:6YG(&EF('1H
M:7,@<G5L92!M871C:&5S/P!3=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E
M.@!3=6)J96-T`%-U8V-E<W,`5&%S:W,`5&AE(&1R:79E<B!S86ED.B``5&AE
M<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE('-C<FEP="X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+@!4:71L90!4;P!54DP`56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BX`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M9&\@0VAA;F=E<P!5<V5R($]P=&EO;G,`57-E<FYA;64`5F%C871I;VX`5F%C
M871I;VX@161I=`!686-A=&EO;B!-97-S86=E`%9A8V%T:6]N(&ES(&YO="!S
M=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`5V%R
M;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:%]I=&5L
M:7-T(&%D9')E<W-E<SH`5VAI=&5L:7-T`%=H:71E;&ES="!%9&ET`%=H:71E
M;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN
M9R!D<FEV97(N`%=H:71E;&ES=&5D($%D9')E<W-E<P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!8+5!R:6]R:71Y`%@M4W!A;2U,979E;`!8+5-P86TM4V-O
M<F4`6"U3<&%M+5-T871U<P!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N`%EO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&5M86EL(&%D
M9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M97-S86=E<R!S:&]U;&0@
M8F4@86-T:79A=&5D+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%M.;R!3=6)J96-T70!;4')O8FQE;2!2
M97!O<G1=`%ML:6YE("5S(&]F("5S70!?061D<F5S<RAE<RD@=&\@9F]R=V%R
M9"!T;SH`7T%D9')E<W-E<R!T;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z`%]"
M;&%C:VQI<W0`7T1E;&5T92!M97-S86=E(&-O;7!L971E;'D`7T5N=&5R(&5A
M8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE.@!?1F]R=V%R9`!?2V5E<"!A(&-O
M<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT/P!?36]V92!M97-S86=E
M('1O(&9O;&1E<CH`7TUY(&5M86EL(&%D9')E<W-E<SH`7U-C<FEP=`!?5F%C
M871I;VX`7U=H:71E;&ES=`!A;F0`9FEE;&0`;6%T8V@`=D-A<F0`4')O:F5C
M="U)9"U697)S:6]N.B!);F=O($@S("@Q+C`M4D,R*0I297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T
M93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#4M,#0M,30@,3@Z,3`K,#(P,`I,87-T+51R86YS;&%T;W(Z($%U=&]M871I
M8V%L;'D@9V5N97)A=&5D"DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#U#4#$R-3<*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3,[('!L=7)A;#TH;B4Q
M,#T],2`F)B!N)3$P,"$],3$@/R`P(#H@;B`A/2`P(#\@,2`Z(#(I.PH`('5N
M`"!V86D`)7,@57IT=7+G\&%N87,@;W!E<N)C:6IA<R`M(&%P<W1I<')I;N)J
M=6US`#(T('-T=6YD87,`04TO4$T`1&%R8NYB82!-96QNXB!S87)A:W-T82!A
M9')E<^=M.@!!:W1I=N=T('-K<FEP='4`4&EE=FEE;F]T('#B<FD`4&%P:6QD
M=7,@:65S=&%T[FIU;6D`061R97-E`$%I>G-TXFIVXG)D<P!6:7-I('-E:V]J
M;_!I90!.;W+B9.YT82!N961E<NYG82!VYW)T[F)A`$%T8FEL9.=T80!*96)K
M=7+P(&YO('-E:V]J;_!I96T`4&EE;&EE=&]T(&9I;'1R=7,`5F%I('1I9?#B
M;2!VYVQA=&EE<R!D>N=S="#P;R!L:6MU;74_`$%U=&]MXG1I<VMI(&%T<W9A
M:61Z:6[B="!S:W)I<'1U('#G8R!K871R87,@:7IM86GR87,_`%!I965J86UI
M92!L875K:3H`0F-C`%/B:V%S(&%R`$1Z:6WP86YA<R!D:65N80!-96QN86ES
M('-A<F%K<W1S`$QA8F]T($UE;&YO('-A<F%K<W1S`%!A\')E:7KG:F%I<R!F
M:6QT<N?P86YA<R!D>FEN:7,@;F5A=&)A;'-T82!-96QN;R!S87)A:W-T=2X`
M061R97-E(&YO($UE;&[B('-A<F%K<W1A`$UE;&[B('-A<F%K<W1A(&%D<F5S
M97,`S65R;65N:7,`2V%L96YDXG)S`$%T8V5L="!P<F]B;.=M87,@<&EE=&5I
M:W5M=0!29>QI<W1R:G5T[F=S`$-C`$UO8FEL86ES('3B;')U;FES`$EZ;6%I
M\F%S('-A9VQA8N)T87,N`$%I>G;G<G0@;&]G=0!5>O+G;75M<P!3871U<@!+
M;W#G="`E<P`E<R!K;W!I:F$`3F5I>F1E=N)S(&%T=N=R="!-86EN=&5N86YC
M95]487-K(&UO9'5L:2`E<P!)>G9E:61O="!J875N=2!M87!I`$1$`$E:4TS'
M1U13.B``26MD:65N87,`1&5A:W1I=N=T('-K<FEP='4`4&%R87-TXB!I9&5N
M=&ETXG1E`$1ZYW-T("5S`$1ZY_!A;F%S(&YO<V%C[FIU;7,`1'KG<W0@=N=S
M='5L:2!P879I<V%M`$EZ9'KG<W1A`$YO9^)DXG0@24Y"3U@`3F]GXF3B="!)
M3D)/6"!U;B!K;W#G="!U>@!.;V?B9.)T($E.0D]8('5N('#B<F%D<F5SYW0`
M3F]GXF3B="!M87#G`$%P<F%K<W1I970@<')O8FSG;74`4^YKXFMA(&EN9F]R
M;>)C:6IA(&ER(&YO<_MT[G1A(&%D;6EN:7-T<F%T;W)A;2X`27IS;.=G="`E
M<P!)>G-LYV=T<P!%:W+B;F$@:65S=&%T[FIU;6D`4&%RXF3N="!D971A;&EZ
MYW1U('!A>FGR;VIU;74@<.=C(&MA=')A(&9I;'1R82!P:65L:65T;_!A;F%S
M/R``3F5S^W3N="!A=&)I;&1I('5Z('9A:7)U;2T@=F%I(';G<W1K;W!U(';G
M<W1U;.=M`$YA=B!T:67P87,@<&EE96IA<R!M86EN=&5N86YC92YP:'``1&%R
M8NYB80!.97/B:V%S(&%R`$YE<V%T=7(`3F5B96ED>F%S(&%R`$YE96MS:7-T
MYP!.96%T8FEL<W0@*&%R('9I971T=7)I96TI`$QA8F]T`$QA8F]T("5S`$4M
M<&%S=',`5'5K\',@<F5Z=6QTXG1S+@!)97-LYV=T("5S`$EE<VSG9W1S`$)E
M:61Z87,@87(`5FEE;N)D<R!A<@!+[_MD80!+871R87,@,34@;6EN^W1E<P!+
M871R87,@,S`@<V5K=6YD97,`2V%T<F%S(#4@;6EN^W1E<P!+871RXB!P:65S
M;.=G\&%NXG,@<F5I>N<`2V%T<G4@<'5S<W1U;F1U`$MA=')U(&UI;OMT:0!0
M87)A=6=VYW)T[F)A<P!&:6QT<N?P86YA<R!L:6MU;6D`16MS:7-TYP!.96EZ
M9&5VXG,@<V'R96UT(&EE<W1A=.YJ=6UU<RX`3F5I>F1E=N)S('!I97-LYV=T
M:65S($Q$05`@<V5R=F5R:6TN`$9A:W-S`$9I;'1RYW0@=FES87,@=N=S='5L
M97,`1FEL='+G="!T:6MA:2!L87/N=.)S(';G<W1U;&5S`$9I;'1RYW0@=&EK
M86D@;F5R961ZYW1A<R!VYW-T=6QE<P!&:6QT<G4@;W!C:6IA<P!&:6QT<N?P
M86YA<R!L:6MU;7,`1FEL='+G\&%N87,@;&EK=6UI`%!A<N)D[G0@9FEL=')A
M('-K<FEP='4`1FEL='+G\&%N87,@;&EK=6UI`$9I;'1RY_!A;F$Z("5S(';G
M<W1U;&4H<RD@;F]K;W#G=&$H<REU>B!M87!I("(E<R(N`$9I;'1RY_!A;F$Z
M("5S(';G<W1U;&5S(&EZ9'KG<W1A*',I+@!&:6QT<N?P86YA.B`E<R!-96QN
M86IA;2!S87)A:W-T86T@871B:6QS=&_P82AS*2!VYW-T=6QE*',I(&EZ9'KG
M<W1A<RX`1FEL='+G\&%N83H@5N=S='5L92`B)7,B(&YO("(E<R(@;F]K;W#G
M=&$@=7H@;6%P:2`B)7,B+@!&:6QT<N?P86YA.B!6YW-T=6QE("(E<R(@;F\@
M(B5S(B!I>F1ZYW-T82X`1FEL='+G\&%N83H@5N=S='5L92`B)7,B(&YO("(E
M<R(@<.)R=FEE=&]T82!U>B!M87!I("(E<R(N`$9I;'1R<R!N878@871R;V1A
M;7,`265NXFMO\&%J86D@=N=S='5L96DL(&MA<R!A=&)I;'-T.@!0XG)S^W3N
M=`!08?!R96EZYVIA:7,@9FEL='+G\&%N87,@9'II;FES(&YE871B86QS=&$@
M<.)R<_MT[O!A;G4N`%#B<G/[=.[P86YA<P!,86)O="!0XG)S^W3N\&%N=0!3
M^W3N=.)J<P!,:65LXFMS('!A<@!,:65LXFMS('9A:2!V:65NXF1S(&%R`%!A
M;.YD>NYB80!-XFIA<R!A9')E<V4`3>)J87,@=&5L969O;G,`2&]R9&4`4W9A
M<NYG80!)96SB9.=T86ES(&QA=6MS.B`E<P!)96SB9.=T:64@;&%U:VDZ`%!A
M\')E:7KG:F%I<R!F:6QT<N?P86YA<R!D>FEN:7,@;F5A=&)A;'-T82!I;F1I
M=FED=>)L=7,@;&EK=6UU<RX`3F]RXF3N=&$@;F5E:W-I<W3G:F_P82!P87-T
M:V%S=.YT92X`27(`3F%V`%9A;&]D80!-87KB:W,@<&%R`$UA>N)K<R!V86D@
M=FEE;N)D<R!A<@!087+B9.YT('!A;.YD>NYB87,@=&5M871U<P!,:7-T+4E$
M`%!I97-LYV=T:65S`$EZ:65T`$U-`%!A<W1S`$%T>NYMYW0@=N=S='5L:2!K
MXB!I>F1ZYW-T=0!!='KN;>=T(';G<W1U;&D@:^(Z`$%T8FEL<W0@*&%R('9I
M971T=7)I96TI`%-A<VMA;F_P:64@;&%U:VD`061R9?!U('-K86ET<R!-96QN
M86KB('-A<F%K<W3B(&EZ<VUE;'1S("A!9')E<V5S(&MO<.(Z("5S+"!M86MS
M:6WB;&%I<R!S:V%I=',Z("5S*2X@4&EE=FEE;F]T(&%D<F5S97,@365L;F%J
M86T@<V%R86MS=&%M('9A:7)S(&YA=B!I97-PYVIA;7,N`$%D<F7P=2!S:V%I
M=',@0F%L=&%JXB!S87)A:W-TXB!I>G-M96QT<R`H061R97-E<R!K;W#B.B`E
M<RP@;6%K<VEMXFQA:7,@<VMA:71S.B`E<RDN(%!I979I96YO="!A9')E<V5S
M($)A;'1A:F%M('-A<F%K<W1A;2!V86ER<R!N878@:65S<.=J86US+@!::?)A
M`$YA=B!N;W+B9.YT<RP@:V%M('#B<F%D<F5SYW0`3F%V(&YO<N)D[G1S(&%T
M=&5I:W5M82!I96UE<VQS`$YA=B!N;W+B9.YT<R!P<F]M8OMT;F5S('!A<VMA
M:61R;VIU;7,`2V%T<G4@;>=N97-I`%#B<G9I971O=`!0XG)V:65T;W0@;&5J
M=7``4.)R=FEE=&]T(&%U9_!U<`!$:65N=2!S:V%I=',@<W1A<G`@8G+N=F1I
M96YU(&%T8FEL9&5S(&YO<_MT[O!A;G4Z`%;B<F1S`$YE:V%D`$IA=6YS(&QI
M:W5M<P!.878@871R;V1A;7,@:V]N9FEG=7+G=',@9'II;FES`$1Z:6YI97,@
M;F%V(&MO;F9I9W5RYW1S(&)A8VME;F1S+G!H<"``3F%V(&YO<N)D[G1A(&YE
M=FEE;F$@9V%L=F5N90!.878@[&5N97+G=',@;F5V:65N<R!S:W)I<'1S+@!.
M878@;F]RXF3N=',@=&5K<W1S`$YA=B!V:65NXF1S(&%R`%!I97KN;65S`$]P
M8VEJ87,`4VMR:7!T=2!A=&IA=6YI;N+P86YA<R!O<&-I:F%S`$-I=&$@:6YF
M;W)MXF-I:F$`0VET87,@;W!C:6IA<P!087)O;&4`27IP:6QD[G0@=7IT=7+G
M\&%N87,@;W!E<N)C:6IA<P!4XFQR=6YI<P!,^V1Z=2!I979A9&EE="!J875N
MXG,@;6%P97,@;F]S875K=6UU.@!,^V1Z=2!N;W+B9&EE="!P<F]B;.=M87,@
M86YO=.)C:6IU+@!,^V1Z=2!N;W+B9&EE="!S879U(&QI971O=.)J82!VXG)D
M=2!U;B!P87)O;&D`4')O8FSG;6%S(&%P<F%K<W1S`$EE;65S;',`4V'R96UT
M80!0XG)A9')E<^=T`$QO[&ES:^)S(&EZ=&5I:W-M97,`071T96EK="!A<B!I
M96UE<VQU`$EZ9'KG<W0@<.)R:0!0XG)S^W3N=',`4.)R<_MT[G1S(&YO`$%T
M9W)I97IT:65S('!I92!F:6QT<G4@<V%R86MS=&$`071G<FEE>G1I97,@<&EE
M(&]P8VEJXFT`071G<FEE>G1I97,@<&EE(&QI:W5M=2!S87)A:W-T80!,;VUA
M`$QI:W5M<P!,:6MU;7,@;F]K;W#G=',`3&EK=6US(&EZ9'KG<W1S`$QI:W5M
M<R!I>G-LYV=T<P!,:6MU;7,@:65S;.=G=',`3&EK=6UA(&YO<V%U:W5M<P!3
M86=L86+B=`!386=L86+B="!O<&-I:F%S`%-A9VQA8N)T(&]P8VEJ87,`4VMR
M:7!T<P!3:W)I<'1A(&%T:F%U;FENXO!A;F$`4VMR:7!T<R!N878@871J875N
M:6[B=',`4VMR:7!T<R!V96EK<VWN9VD@86MT:7;G=',N`%-K<FEP=',@=F5I
M:W-M[F=I(&1E86MT:7;G=',N`%)E9'KG=&$`27IVYVQI971I97,@;&%U:W4`
M:7IVYVSG=&EE<R!M87!I`$EZ=N=L:65T:65S(&1A='5M82!A=&1A;.YTXFIU
M.@!)>G;G;&EE=&EE<R!D871U;6$@9F]R;>)T=3H`27IVYVQI971I97,@;&%I
M:V$@9F]R;>)T=3H`27IVYVQI971I97,@9&EV=7,@<V%D97+N9W5S(&QA=6MU
M<RX`27IVYVQI971I97,@=F%L;V1U.@!08?!D969I;N=T82!G86QV96YE`$YO
M<_MT[G0@<')O8FSG;6%S('!I971E:6MU;74`4_MT[G3B:G,`265S=&%T[FIU
M;6D@=F5I:W-M[F=I(&%T:F%U;FENXG1I+@!2XF3N="!A:W3N=F]S('-K<FEP
M='5S`%+B9.YT('!A\')E:7KG:F\@<VMR:7!T=0!)>FWG<G,`27IL86ES="!U
M>G1U<N?P86YU`,YP8?!O('-I;6)O;'4@:65V861E`%#B<G1R875K="!PXG)B
M875D:2P@:F$@\&ES(&QI:W5M<R!I>G!I;&3B<S\`0G+N=F1I96YU('!A>FGR
M;VIU;6$@=&5M871S`%1E;6%T<P!696EK<VUE`%5Z9&5V=6UI`$1Z:6YI<R!P
M87II\F]J83H`2^_[9&$@86MT:7;G:F]T('-K<FEP='4N`$OO^V1A(&1E86MT
M:7;G:F]T('-K<FEP='4N`-!I;2!S:V%I=&QI;2!I<B!JXF+[="!V:7-M87H@
M,2X`T&%I(';G<G3N8F%I(&ER(&KB8OMT('-K86ET;&EM+@!6:7)S<F%K<W1S
M`%-A\N=MYVIS`%523`!.878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S
M97)V97)I;2X`3F5V87(@:65L87/N="`E<R!N;W-A8^YJ=6UU<RX`3F%V(&EE
M<W#G:F%M<R!I;G1E<G!R973G="#P;R!7;W)D(&1O:W5M96YT=0!!=&-E;'0@
M:7IM86GR87,`3&EE=&]TXFIA(&]P8VEJ87,`3&EE=&]TXFIA(';B<F1S`$)R
M[G9D:65N87,`3&%B;W0@0G+N=F1I96YU('!A>FGR;VIU;74`0G+N=F1I96YU
M('!A>FGR;VIU;7,`4&'P<F5I>N=J86ES(&9I;'1RY_!A;F%S(&1Z:6YI<R!N
M96%T8F%L<W1A(&)R[G9D:65N=2!P87II\O1J=6UU<RX`0G+N9&ENXFIU;7,`
M2V%T<G4@;F5DY^]U`$QA:7!N:2!L^V1Z86T@)7,`3&%I<&YI(&S[9'IM+"`E
M<P!"86QTXB!S87)A:W-T82!A9')E<V5S`$)A;'1A:7,@<V%R86MS=',`3&%B
M;W0@0F%L=&\@<V%R86MS='4`4&'P<F5I>N=J86ES(&9I;'1RY_!A;F%S(&1Z
M:6YI<R!N96%T8F%L<W1A($)A;'1O('-A<F%K<W1U+@!"86QTXB!S87)A:W-T
M82!A9')E<V5S`$1A<F)A(&%D<F5S90!$87)B82!TXFQR=6YI<P!8+5!R:6]R
M:71Y`%@M4W!A;2U,979E;`!8+5-P86TM4V-O<F4`6"U3<&%M+5-T871U<P!'
M1P!+871R=2!G861U`$%P<F%K<W1I970@<')O8FSG;74@<&ER;7,@<&EE=&5I
M:W5M82!S^W3N\&%N87,N`$KB;F]RXF1A('9I<VUA>B!V:65N82!E+7!A<W1A
M(&%D<F5S92P@:W5R86D@86MT:7;G="!"<NYV9&EE;G4@<&%Z:?)O:G5M=7,N
M`$K[<W4@)7,@<V5S:6IA(&ER(&)E:6=U<VEE<RX@3/MD>G4@<&EE<VSG9'II
M971I97,@871KXG)T;W1I+@!*^W-U(&EN9F]R;>)C:6IA`$K[<W4@;W!C:6IA
M<R!I<B!S86=L86+B=&%S+@!;0F5Z('1E;6%T85T`6U!R;V)LYVUA<R!Z:?)O
M:G5M<UT`6W)I;F1A("5S(&YO("5S70!!9')E<V4H<RD@<.)R<_MT[O!A;F%I
M.@!!9')E<V5S+"!K=7+B;2!N97/[=.YT(&%T8FEL9&5S.@!-96QN86ES('-A
M<F%K<W1S`$1ZYW-T(';G<W1U;&D`2V%T<G4@861R97-I(&EE=F%D:65T(&IA
M=6[B(')I;F3B.@!0XG)S^W3N=`!386=L86+B="!VYW-T=>]U(&MO<&EJ87,@
M\&%JXB!K;VYTXC\`4.)R=FEE=&]T(';G<W1U;&5S('5Z(&UA<&DZ`$K[<W4@
M92UP87-T82!A9')E<V4Z`%-K<FEP=',`0G+N=F1I96YA<P!"86QT86ES('-A
M<FMS=',`=6X`;&%U:W,`871B:6QS=`!V0V%R9```````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]L=E],5B]H
M96QP+GAM;```````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3$U-#`T
M`#$P-#$W,S8R-S0W`#`R,3,R,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG
M/2)I<V\M.#@U.2TQ(C\^"CPA+2T@)$AO<F1E.B!I;F=O+VQO8V%L92]L=E],
M5B]H96QP+GAM;"QV(#$N,2XX+C(@,C`P-2\Q,"\Q-R`R,SHS.3HP-2!J86X@
M17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB8FQA8VML:7-T(B!M9#4]
M(C<T8F5E-38W8S$Y.30W83AC.61E-3(V9CDR,3,W,C4V(B!S=&%T93TB8VAA
M;F=E9"(^"B`@("`\=&ET;&4^365L;F%I<R!S87)A:W-T<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY-96QN86ES('-A<F%K<W1S/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!;365L;F%I<R!S87)A:W-T<UT@:7(@12UP87-T82!A9')E\'4@
M<V%R86MS=',L(&YO(&MU<N)M('-A\F5M=.)S(';G<W1U;&5S($K[<R!N97;G
M;&%T:65S(')E9'KG="!S87;B('!A<W1K87-T[G3G("A)3D)/6"DN"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)B;&%C:VQI
M<W0B/@H@("`@/'1I=&QE/D)L86-K;&ES=#PO=&ET;&4^"B`@("`\<&%R83Y4
M:&4@8FQA8VML:7-T(&ES(&$@;&ES="!O9B!E;6%I;"!A9&1R97-S97,@:VYO
M=VX@=&\@<V5N9"!E;6%I;"!T:&%T"B`@("!Y;W4@9&\@;F]T('=I<V@@=&\@
M<V5E(&EN('EO=7(@24Y"3U@N/"]P87)A/@H@(#PO96YT<GD^+2T^/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F)L86-K;&ES="(^"B`@("`\=&ET
M;&4^0FQA8VML:7-T/"]T:71L93X*("`@(#QP87)A/E1H92!B;&%C:VQI<W0@
M:7,@82!L:7-T(&]F(&5M86EL(&%D9')E<W-E<R!K;F]W;B!T;R!S96YD(&5M
M86EL('1H870*("`@('EO=2!D;R!N;W0@=VES:"!T;R!S964@:6X@>6]U<B!)
M3D)/6"X\+W!A<F$^"B`@/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8FQA8VML:7-T+6%C=&EO;B(@;60U/2)D,3%E9#`W9C`V-S%F,V$S-S1D
M,S,P-V5C9#<Q8C9F,B(@<W1A=&4](F-H86YG960B/@H@("`@/'1I=&QE/B!-
M96QN86ES('-A<F%K<W1S.B!$87)B[F)A/"]T:71L93X*("`@(#QP87)A/@H@
M("`@T.X@9&%R8NYB82!N;W-A:V$@<NYC[F)U+"!J82!I<B!S8?)E;71A(';G
M<W1U;&4@;F\@365L;F%JXB!S87)A:W-TXB!U>G-K86ET[G1A:FEE;2!N;W/[
M=.YTXFII96TN($EE<W#G:F%MXG,@9&%R8NYB87,@:7(@6T1ZYW-T72!V86D@
M6U#B<F-E;'0@=7I=+B!*82!I<B!I>G;G;.=T<R!;1'KG<W1=+"!VYW-T=6QE
M<R!T:6MS(&EZ9'KG<W1A<R!VYVP@<&ER;7,@;F]NXFOP86YA<R!*^W-U($E.
M0D]8+B!*82!*^W-U(&EZ=N=L92!I<B!;4.)R=FEE=&]T('5Z72P@:65NXFMU
M<^X@=N=S='5L92!T:6MS('#B<G9I971O=&$@=7H@;F]RXF3N=&\@;6%P:2X*
M("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F)L
M86-K;&ES="UA8W1I;VXB/@H@("`@/'1I=&QE/D)L86-K;&ES=#H@06-T:6]N
M/"]T:71L93X*("`@(#QP87)A/E1H:7,@86-T:6]N(&1E9FEN97,@=VAA="!T
M;R!D;R!W:&5N(&$@;65S<V%G92!F<F]M(&$@8FQO8VME9"!S96YD97(*("`@
M(&ES('-E;G0@=&\@>6]U+B!4:&4@<&]S<VEB;&4@=F%L=65S(&%R92`B9&5L
M971E(B!O<B`B;6]V92!T;R!F;VQD97(B+B!)9@H@("`@(F1E;&5T92(@:7,@
M<V5L96-T960L('1H92!M97-S86=E<R!W:6QL(&)E(&1I<V-A<F1E9"!B969O
M<F4@979E<B!B96EN9PH@("`@<W1O<F5D(&EN('EO=7(@26YB;W@N($EF(")M
M;W9E('1O(&9O;&1E<B(@:7,@<V5L96-T960L('1H97D@=VEL;"!B90H@("`@
M9&5L:79E<F5D('1O('1H92!S96QE8W1E9"!F;VQD97(N/"]P87)A/@H@(#PO
M96YT<GD^+2T^/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F)L86-K
M;&ES="UA8W1I;VXB/@H@("`@/'1I=&QE/D)L86-K;&ES=#H@06-T:6]N/"]T
M:71L93X*("`@(#QP87)A/E1H:7,@86-T:6]N(&1E9FEN97,@=VAA="!T;R!D
M;R!W:&5N(&$@;65S<V%G92!F<F]M(&$@8FQO8VME9"!S96YD97(*("`@(&ES
M('-E;G0@=&\@>6]U+B!4:&4@<&]S<VEB;&4@=F%L=65S(&%R92`B9&5L971E
M(B!O<B`B;6]V92!T;R!F;VQD97(B+B!)9@H@("`@(F1E;&5T92(@:7,@<V5L
M96-T960L('1H92!M97-S86=E<R!W:6QL(&)E(&1I<V-A<F1E9"!B969O<F4@
M979E<B!B96EN9PH@("`@<W1O<F5D(&EN('EO=7(@26YB;W@N($EF(")M;W9E
M('1O(&9O;&1E<B(@:7,@<V5L96-T960L('1H97D@=VEL;"!B90H@("`@9&5L
M:79E<F5D('1O('1H92!S96QE8W1E9"!F;VQD97(N/"]P87)A/@H@(#PO96YT
M<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F)L86-K;&ES="UA9&1R97-S
M97,B(&UD-3TB,6-B9#`U9#=C8C8U,69D8F-C8SDQ.#%B939A-S@Y9#@B('-T
M871E/2)C:&%N9V5D(CX*("`@(#QT:71L93Y-96QN86ES('-A<F%K<W1S.B!!
M9')E<V5S/"]T:71L93X*("`@(#QP87)A/@H@("`@12UP87-T82!A9')E<V5S
M+"!N;R!K=7+B;2!*^W,@;F]T96EK=&D@;F5VYVQA=&EE<R!S8?)E;70@=N=S
M='5L97,N($MA=')U(&%D<F5S:2!I<B!JXFEE=F%D82!A='-E=FGP[>(@<FEN
M9.(N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)B;&%C:VQI<W0M861D<F5S<V5S(CX*("`@(#QT:71L93Y";&%C:VQI<W0Z
M($%D9')E<W-E<SPO=&ET;&4^"B`@("`\<&%R83Y4:&4@;&ES="!O9B!A9&1R
M97-S97,@=&\@8FQO8VLN($5A8V@@861D<F5S<R!S:&]U;&0@8F4@96YT97)E
M9"!O;B!A"B`@("!S97!A<F%T92!L:6YE+CPO<&%R83X*("`\+V5N=')Y/BTM
M/CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)B;&%C:VQI<W0M861D
M<F5S<V5S(CX*("`@(#QT:71L93Y";&%C:VQI<W0Z($%D9')E<W-E<SPO=&ET
M;&4^"B`@("`\<&%R83Y4:&4@;&ES="!O9B!A9&1R97-S97,@=&\@8FQO8VLN
M($5A8V@@861D<F5S<R!S:&]U;&0@8F4@96YT97)E9"!O;B!A"B`@("!S97!A
M<F%T92!L:6YE+CPO<&%R83X*("`\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)F:6QT97)S7W)U;&5S(B!M9#4](C8V.#-B9F1A,6$S96(V,C=A
M8S`R8C1E8S%C-#@V8S@W(B!S=&%T93TB8VAA;F=E9"(^"B`@("`\=&ET;&4^
M3&EK=6UI.B!&:6QT<G4@;&EK=6UI/"]T:71L93X*("`@(#QP87)A/@H@("`@
M5&%S(&ER(&=A;'9E;F%I<R!L:6MU;74@96MRXFYS+B!.;R#P96II96YE<R!*
M^W,@=F%R870@<F%D[G0@:F%U;G4@;&EK=6UU+"!U>FML:6OP[6EN;W0@<&]G
M86D@(DIA=6YS(&QI:W5M<R([(&UA:6[N="!P:65L:65T;VIA;6\@9FEL=')U
M('-E8^YB=2P@=7IK;&EK\.UI;F]T(&)U;'1I\G4@:6MO;N)M('-T86)I\N(@
M(E#B<G9I971O="([(&EE<VSG9W0@=F%I(&EZ<VSG9W0@871S979I\.UU<R!L
M:6MU;75S+"!U>FML:6OP[6EN;W0@:6MO;F%I('-T86)I\N(@(DEE<VSG9W1S
M(CL@;&%B;W0@871S979I\.UU<R!L:6MU;75S+"!U>FML:6OP[6EN;W0@:6MO
M;F%I('-T86)I\N(@(DQA8F]T(B!V86D@;&EK=6UA(&YO<V%U:W5M86TN"B`@
M("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F:6QT
M97)S7W)U;&5S(CX*("`@(#QT:71L93Y2=6QE<SH@1FEL=&5R(%)U;&5S/"]T
M:71L93X*("`@(#QP87)A/E1H:7,@:7,@=&AE(&UA:6X@<G5L97,@<V-R965N
M+B!&<F]M(&AE<F4@>6]U(&-A;B!C<F5A=&4@;F5W(')U;&5S(&)Y"B`@("!C
M;&EC:VEN9R!O;B!T:&4@(DYE=R!2=6QE(B!B=71T;VX[(')E87)R86YG92!T
M:&4@<G5L92!O<F1E<B!B>2!C;&EC:VEN9R!O;@H@("`@=&AE('5P(&%N9"!D
M;W=N(&%R<F]W<R!I;B!T:&4@(DUO=F4B(&-O;'5M;CL@96YA8FQE(&%N9"!D
M:7-A8FQE('-P96-I9FEC"B`@("!R=6QE<R!B>2!C;&EC:VEN9R!O;B!T:&4@
M:6-O;B!I;B!T:&4@(D5N86)L960B(&-O;'5M;CL@86YD(&5D:70@:6YD:79I
M9'5A;`H@("`@<G5L97,@8GD@8VQI8VMI;F<@;VX@=&AE(&EC;VX@:6X@=&AE
M(")%9&ET(B!C;VQU;6X@;W(@;VX@=&AE(')U;&4*("`@(&YA;64N/"]P87)A
M/@H@("`@/'!A<F$^"B`@("`@(#QT:7`^4&QE87-E(&YO=&4L('1H870@=&AE
M(')U;&5S(&%R92!E>&5C=71E9"!I;B!T:&4@;W)D97(@9&ES<&QA>65D"B`@
M("`@(&AE<F4N($9O<B!E>&%M<&QE+"!I9B!A;B!E;6%I;"!I<R!D96QE=&5D
M(&)Y('1H92!B;&%C:VQI<W0L('1H92!F;VQL;W=I;F<*("`@("`@<G5L97,@
M=VEL;"!N;W0@:&%V92!A;GD@:6YF;'5E;F-E(&]N('1H:7,@96UA:6PN/"]T
M:7`^"B`@("`\+W!A<F$^"B`@/"]E;G1R>3XM+3X\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB9FEL=&5R<U]R=6QE<R(^"B`@("`\=&ET;&4^4G5L
M97,Z($9I;'1E<B!2=6QE<SPO=&ET;&4^"B`@("`\<&%R83Y4:&ES(&ES('1H
M92!M86EN(')U;&5S('-C<F5E;BX@1G)O;2!H97)E('EO=2!C86X@8W)E871E
M(&YE=R!R=6QE<R!B>0H@("`@8VQI8VMI;F<@;VX@=&AE(").97<@4G5L92(@
M8G5T=&]N.R!R96%R<F%N9V4@=&AE(')U;&4@;W)D97(@8GD@8VQI8VMI;F<@
M;VX*("`@('1H92!U<"!A;F0@9&]W;B!A<G)O=W,@;W(@96YT97)I;F<@;F5W
M(')U;&4@<&]S:71I;VYS(&EN('1H92`B36]V92(@8V]L=6UN.PH@("`@96YA
M8FQE(&%N9"!D:7-A8FQE('-P96-I9FEC(')U;&5S(&)Y(&-L:6-K:6YG(&]N
M('1H92!I8V]N(&EN('1H92`B16YA8FQE9"(*("`@(&-O;'5M;CL@86YD(&5D
M:70@:6YD:79I9'5A;"!R=6QE<R!B>2!C;&EC:VEN9R!O;B!T:&4@:6-O;B!I
M;B!T:&4@(D5D:70B"B`@("!C;VQU;6X@;W(@;VX@=&AE(')U;&4@;F%M92X\
M+W!A<F$^"B`@("`\<&%R83X*("`@("`@/'1I<#Y0;&5A<V4@;F]T92P@=&AA
M="!T:&4@<G5L97,@87)E(&5X96-U=&5D(&EN('1H92!O<F1E<B!D:7-P;&%Y
M960*("`@("`@:&5R92X@1F]R(&5X86UP;&4L(&EF(&%N(&5M86EL(&ES(&1E
M;&5T960@8GD@=&AE(&)L86-K;&ES="P@=&AE(&9O;&QO=VEN9PH@("`@("!R
M=6QE<R!W:6QL(&YO="!H879E(&%N>2!I;F9L=65N8V4@;VX@=&AI<R!E;6%I
M;"X\+W1I<#X*("`@(#PO<&%R83X*("`\+V5N=')Y/BTM/CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)F;W)W87)D(B!M9#4](C@W-F-D,&-F,C`V-#)E86(Y83`V
M9#4X83)E86%D.35C(B!S=&%T93TB8VAA;F=E9"(^"B`@("`\=&ET;&4^4.)R
M<_MT[G0\+W1I=&QE/@H@("`@/&AE861I;F<^4.)R<_MT[G0\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($K[<R!V87)A="!N;W)A9.YT($4M<&%S=&$@861R
M97-I*"UE<RDL(&MU<G`@875T;VWB=&ES:VD@<.)R<_MT[G0@:F%U;G!I96[B
M:W7PXG,@=N=S='5L97,N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R
M>3H*/&5N=')Y(&ED/2)F;W)W87)D(CX*("`@(#QT:71L93Y&;W)W87)D/"]T
M:71L93X*("`@(#QP87)A/EEO=2!M87D@8VAO;W-E('1O(&%U=&]M871I8V%L
M;'D@9F]R=V%R9"!Y;W5R(&EN8V]M:6YG(&UA:6P@=&\@80H@("`@;G5M8F5R
M(&]F(&]T:&5R(&UA:6P@861D<F5S<V5S+CPO<&%R83X*("`\+V5N=')Y/BTM
M/CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F;W)W87)D(CX*("`@
M(#QT:71L93Y&;W)W87)D/"]T:71L93X*("`@(#QP87)A/EEO=2!M87D@8VAO
M;W-E('1O(&%U=&]M871I8V%L;'D@9F]R=V%R9"!Y;W5R(&EN8V]M:6YG(&UA
M:6P@=&\@80H@("`@;G5M8F5R(&]F(&]T:&5R(&UA:6P@861D<F5S<V5S+CPO
M<&%R83X*("`\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F;W)W
M87)D+6%D9')E<W-E<R(@;60U/2)A8C0P,S-B.3DP,#4P-S5D,V0P.3EC83AC
M.#<Y8S=D,2(@<W1A=&4](F-H86YG960B/@H@("`@/'1I=&QE/E#B<G/[=.YT
M.B!!9')E<V5S/"]T:71L93X*("`@(#QH96%D:6YG/E#B<G/[=.YT.B!!9')E
M<V5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!*^W,@=F%R870@:7IVYVSG
M=&EE<R!PXG)S^W3N="!J875N<&EE;N)K=?#B<R!VYW-T=6QE<R!U>B!C:71U
M($4M<&%S=&$@861R97-I+B!*^W,@=F%R870@;F]RXF3N="!N96EE<F]B9?YO
M='4@861R9?!U('-K86ET=2P@:V%T<G4@861R97-I(&EE=F%D;W0@871S979I
M\.WB(')I;F3B+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB9F]R=V%R9"UA9&1R97-S97,B/@H@("`@/'1I=&QE/D9O<G=A
M<F0Z($%D9')E<W-E<SPO=&ET;&4^"B`@("`\<&%R83Y9;W4@;6%Y(&-H;V]S
M92!T;R!H879E('EO=7(@:6YC;VUI;F<@;6%I;"!R961I<F5C=&5D('1O(&%N
M;W1H97(*("`@(&%C8V]U;G0N(%EO=2!M87D@96YT97(@87,@;6%N>2!A9&1R
M97-S97,@87,@>6]U(&QI:V4N($5N=&5R(&5A8V@@861D<F5S<R!O;@H@("`@
M82!N97<@;&EN92X\+W!A<F$^"B`@/"]E;G1R>3XM+3X\(2TM($5N9VQI<V@@
M96YT<GDZ"CQE;G1R>2!I9#TB9F]R=V%R9"UA9&1R97-S97,B/@H@("`@/'1I
M=&QE/D9O<G=A<F0Z($%D9')E<W-E<SPO=&ET;&4^"B`@("`\<&%R83Y9;W4@
M;6%Y(&-H;V]S92!T;R!H879E('EO=7(@:6YC;VUI;F<@;6%I;"!R961I<F5C
M=&5D('1O(&%N;W1H97(*("`@(&%C8V]U;G0N(%EO=2!M87D@96YT97(@87,@
M;6%N>2!A9&1R97-S97,@87,@>6]U(&QI:V4N($5N=&5R(&5A8V@@861D<F5S
M<R!O;@H@("`@82!N97<@;&EN92X\+W!A<F$^"B`@/"]E;G1R>3XM+3X\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB9F]R=V%R9"UK965P8V]P>2(@;60U/2(S8C<U
M-6(V9&,Y,S1D,F$U93<U8S<T9#4W-V%E,V$X9B(@<W1A=&4](F-H86YG960B
M/@H@("`@/'1I=&QE/E#B<G/[=.YT.B!386=L86+B="!K;W!I:G4\+W1I=&QE
M/@H@("`@/&AE861I;F<^4.)R<_MT[G0Z(%-A9VQA8N)T(&MO<&EJ=3PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@2F$@2OMS(&EZ=N=LYW-I971I97,@\&\@
M;W!C:6IU+"!J875N<&EE;N)K=?!O(';G<W1U[W4@:V]P:6IA<R!T:6MS('-A
M9VQA8N)T87,@\&%JXB!P87-T:V%S=.YTYRP@:^(@87+N('1I:W,@<.)R<_MT
M[G1A<R!U>B!*^W-U(&YO<N)D[G1A:N)M('#B<G/[=.[P86YA<R!A9')E<^=M
M+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB
M9F]R=V%R9"UK965P8V]P>2(^"B`@("`\=&ET;&4^1F]R=V%R9#H@2V5E<"!#
M;W!Y/"]T:71L93X*("`@(#QP87)A/DEF('EO=2!S96QE8W0@=&AI<R!O<'1I
M;VXL(&$@8V]P>2!O9B!Y;W5R(&EN8V]M:6YG(&UE<W-A9V5S('=I;&P@8F4*
M("`@('-A=F5D(&EN('1H:7,@86-C;W5N="!A<R!W96QL(&%S(&)E:6YG('-E
M;G0@=&\@=&AE(&%D9')E<W-E<R!T;R!W:&EC:"!Y;W4*("`@(&AA=F4@>6]U
M<B!M86EL(&9O<G=A<F1E9"X\+W!A<F$^"B`@/"]E;G1R>3XM+3X\(2TM($5N
M9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB9F]R=V%R9"UK965P8V]P>2(^"B`@
M("`\=&ET;&4^1F]R=V%R9#H@2V5E<"!#;W!Y/"]T:71L93X*("`@(#QP87)A
M/DEF('EO=2!S96QE8W0@=&AI<R!O<'1I;VXL(&$@8V]P>2!O9B!Y;W5R(&EN
M8V]M:6YG(&UE<W-A9V5S('=I;&P@8F4*("`@('-A=F5D(&EN('1H:7,@86-C
M;W5N="!A<R!W96QL(&%S(&)E:6YG('-E;G0@=&\@=&AE(&%D9')E<W-E<R!T
M;R!W:&EC:"!Y;W4*("`@(&AA=F4@>6]U<B!M86EL(&9O<G=A<F1E9"X\+W!A
M<F$^"B`@/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9BUS
M:&]W7V9I;'1E<E]M<V<B(&UD-3TB.&%E,6,P.&5E86)E8V4Y,S5B,F(T9C(Q
M,F,T,C,V,6$B('-T871E/2)C:&%N9V5D(CX*("`@(#QT:71L93Y)>G;G;&4Z
M(%+B9.YT(&1E=&%L:7KG='5S(&9I;'1R=2!S=&%T=7-A('!A>FGR;VIU;75S
M/SPO=&ET;&4^"B`@("`\<&%R83X*("`@($IA('1I96L@;&EE=&]T<R!)34%0
M(&9I;'1RY_!A;F%S(&1Z:6YI<RP@\.X@:7IVYVQE(&YO<V%K82P@8VEK('#O
MXG#N9W,@:7(@9FEL='+G\&%N87,@<')O8V5S<RX@2F$@:7(@=7IS=.)D[G1S
M(")*XB(L(&MA=')A(&-A=7(@9FEL=')I96T@:7IGXFIU<^X@=N=S='5L92!I
M>G-A=6MS('5Z(&5K<N)N82!A='-E=FGP[74@:6YF;W)M873N=F\@<&%Z:?)O
M:G5M=2!U>G)E:7H@<.=C(';G<W1U;&5S(&%P<W1RXF1E<RX@2F$@:7(@=7IS
M=.)D[G1S(").YR(L('1I:W,@<&%RXF3N=',@=&EK86D@9FEL=')U(&1A<F+N
M8F%S(&MO<'-A=FEL:W5M<RX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N
M=')Y.@H\96YT<GD@:60](G!R968M<VAO=U]F:6QT97)?;7-G(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E.B!3:&]W(&1E=&%I;&5D(&9I;'1E<B!S=&%T=7,@
M;65S<V%G97,_/"]T:71L93X*("`@(#QP87)A/DEF('5S:6YG('1H92!)34%0
M(&9I;'1E<FEN9R!D<FEV97(L('1H:7,@<')E9F5R96YC92!C;VYT<F]L<R!H
M;W<*("`@('9E<F)O<V4@=&AE(&9I;'1E<FEN9R!P<F]C97-S(&ES+B!)9B!S
M970@=&\@>65S+"!E=F5R>2!M97-S86=E(&9I;'1E<F5D"B`@("!W:6QL(')E
M<W5L="!I;B!A('-E<&%R871E(&YO=&EF:6-A=&EO;B!M97-S86=E(&]U='!U
M="!T;R!T:&4@<V-R965N"B`@("!I;6UE9&EA=&5L>2!A9G1E<B!T:&4@;65S
M<V%G92!I<R!P<F]C97-S960N($EF('-E="!T;R!N;RP@;VYL>2!A('-U;6UA
M<GD@;V8*("`@(&9I;'1E<B!A8W1I;VYS('=I;&P@8F4@;W5T<'5T('1O('1H
M92!S8W)E96XN/"]P87)A/@H@(#PO96YT<GD^+2T^/"$M+2!%;F=L:7-H(&5N
M=')Y.@H\96YT<GD@:60](G!R968M<VAO=U]F:6QT97)?;7-G(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E.B!3:&]W(&1E=&%I;&5D(&9I;'1E<B!S=&%T=7,@
M;65S<V%G97,_/"]T:71L93X*("`@(#QP87)A/DEF('5S:6YG('1H92!)34%0
M(&9I;'1E<FEN9R!D<FEV97(L('1H:7,@<')E9F5R96YC92!C;VYT<F]L<R!H
M;W<*("`@('9E<F)O<V4@=&AE(&9I;'1E<FEN9R!P<F]C97-S(&ES+B!)9B!S
M970@=&\@>65S+"!E=F5R>2!M97-S86=E(&9I;'1E<F5D"B`@("!W:6QL(')E
M<W5L="!I;B!A('-E<&%R871E(&YO=&EF:6-A=&EO;B!M97-S86=E(&]U='!U
M="!T;R!T:&4@<V-R965N"B`@("!I;6UE9&EA=&5L>2!A9G1E<B!T:&4@;65S
M<V%G92!I<R!P<F]C97-S960N($EF('-E="!T;R!N;RP@;VYL>2!A('-U;6UA
M<GD@;V8*("`@(&9I;'1E<B!A8W1I;VYS('=I;&P@8F4@;W5T<'5T('1O('1H
M92!S8W)E96XN/"]P87)A/@H@(#PO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R968M9FEL=&5R7W-E96XB(&UD-3TB9#AE9#)A,C%A8V%C,#AD
M-3!D,&,P93)E,C=A935D-30B('-T871E/2)C:&%N9V5D(CX*("`@(#QT:71L
M93Y)>G;G;&4Z($9I;'1RYW0@=&EK86D@6VYE76QA<^YTXG,@=N=S='5L97,_
M/"]T:71L93X*("`@(#QP87)A/@H@("`@T.X@:7IVYVQE(&YO<V%K82P@:V%D
M($E-05`@9FEL='+G\&%N87,@9'II;FES(&%P<W1RXF3B<R!)3D)/6"!E<V_P
MXG,@=N=S='5L97,N($K[<R!V87)A="!A<'-T<N)DXG0@=FES87,@24Y"3U@@
M97-O\.)S(';G<W1U;&5S('9A:2!424M!22!TXG,L(&MA<R!A='KN;>=T87,@
M:^(@;F5L87/N=&%S('9A:2!A<NX@5$E+04D@=.)S+"!K87,@871Z[FWG=&%S
M(&OB(&QA<^YT87,N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*
M/&5N=')Y(&ED/2)P<F5F+69I;'1E<E]S965N(CX*("`@(#QT:71L93Y0<F5F
M97)E;F-E.B!&:6QT97(@;VYL>2!;=6Y=<V5E;B!M97-S86=E<S\\+W1I=&QE
M/@H@("`@/'!A<F$^5&AI<R!P<F5F97)E;F-E(&ED96YT:69I97,@=VAE;B!T
M:&4@24U!4"!F:6QT97)I;F<@9')I=F5R('=I;&P*("`@(&%T=&5M<'0@=&\@
M87!P;'D@<G5L97,@=&\@=&AE($E.0D]8+B!9;W4@8V%N(&5I=&AE<B!A<'!L
M>2!F:6QT97)S('1O(&%L;`H@("`@;65S<V%G97,L(&%P<&QY(&9I;'1E<G,@
M3TY,62!T;R!M97-S86=E<R!T:&%T(&%R92!M87)K960@=6YS965N+"!O<B!A
M<'!L>0H@("`@9FEL=&5R<R!/3DQ9('1O(&UE<W-A9V4@=&AA="!H879E(&)E
M96X@;6%R:V5D('-E96XN/"]P87)A/@H@(#PO96YT<GD^+2T^/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](G!R968M9FEL=&5R7W-E96XB/@H@("`@
M/'1I=&QE/E!R969E<F5N8V4Z($9I;'1E<B!O;FQY(%MU;EUS965N(&UE<W-A
M9V5S/SPO=&ET;&4^"B`@("`\<&%R83Y4:&ES('!R969E<F5N8V4@:61E;G1I
M9FEE<R!W:&5N('1H92!)34%0(&9I;'1E<FEN9R!D<FEV97(@=VEL;`H@("`@
M871T96UP="!T;R!A<'!L>2!R=6QE<R!T;R!T:&4@24Y"3U@N(%EO=2!C86X@
M96ET:&5R(&%P<&QY(&9I;'1E<G,@=&\@86QL"B`@("!M97-S86=E<RP@87!P
M;'D@9FEL=&5R<R!/3DQ9('1O(&UE<W-A9V5S('1H870@87)E(&UA<FME9"!U
M;G-E96XL(&]R(&%P<&QY"B`@("!F:6QT97)S($].3%D@=&\@;65S<V%G92!T
M:&%T(&AA=F4@8F5E;B!M87)K960@<V5E;BX\+W!A<F$^"B`@/"]E;G1R>3XM
M+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<G5L92(@;60U/2(W,&(X8CDU.3EC
M,&$V.&$R-C)F,#%F8F0W,6,T9&0W82(@<W1A=&4](F-H86YG960B/@H@("`@
M/'1I=&QE/D9I;'1R82!L:6MU;6D\+W1I=&QE/@H@("`@/&AE861I;F<^1FEL
M=')A(&QI:W5M:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3&EK=6US(&ER
M($K[<W4@<&%S=&$@9FEL=')U('5Z8OMV97,@<W3[<F%K;65N<RX@5&%S('-A
M<W3B=B!N;R!V:65N82!V86D@=F%I<N)K:65M(&YO<V%C[FIU;6EE;2!U;B!V
M:65N87,@=F%I('9A:7+B:^)M(&1A<F+N8N)M+B!+860@:G5M<R!P:65NXFL@
M:F%U;F$@=N=S='5L92P@=.(@=&EE:R!A<'-T<N)DXG1A(&%T8FEL<W1O\&D@
M2OMS=2!F:6QT<G4@;F]S86/N:G5M:65M+B!*82!T:65K(&MO;G-T873G=&$@
M871B:6QS=.YB82!F:6QT<F$@;F]S86/N:G5M:65M+"!VYW-T=6QE('1I96L@
M87!S='+B9.)T82!A=&)I;'-T;_!I(&QI:W5MXB!N;W1E:6MT86KB;2!D87)B
M[F+B;2X@1FEL=')I(&ER(.]O=&D@;F]D97+N9VDL(&QA:2!A=&)R[G9O=&]S
M(&YO(&YE=N=L86WB;2!VYW-T=6SG;2!V86D@;W)G86YI>N=T=2!*^W-U('!A
M<W1K87-T[G1I+"!U>F=L86+B:F]T(';G<W1U;&5S('1E;6%T:7-KXG,@;6%P
MYW,N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)R=6QE(CX*("`@(#QT:71L93Y&:6QT97(@4G5L93PO=&ET;&4^"B`@("`\
M<&%R83Y!(')U;&4@:7,@=&AE(&)A<VEC(&)U:6QD:6YG(&)L;V-K(&]F('EO
M=7(@;6%I;"!F:6QT97)S+"!I="!C;VYS:7-T<PH@("`@;V8@;VYE(&]R(&UO
M<F4@8V]N9&ET:6]N<R!A;F0@;VYE(&]R(&UO<F4@86-T:6]N<RX@5VAE;B!A
M(&UE<W-A9V4@:7,@<V5N=`H@("`@=&\@>6]U+"!I="!I<R!P<F]C97-S960@
M=&AR;W5G:"!T:&4@8V]N9&ET:6]N<R!O9B!Y;W5R(&9I;'1E<B!R=6QE<RP@
M:68@=&AE"B`@("!C;VYD:71I;VYS('1H870@>6]U('-P96-I9GD@87)E(&UE
M="P@=&AE;B!T:&4@86-T:6]N<R!T:&%T('EO=2!S<&5C:69Y('=I;&P*("`@
M(&)E('!E<F9O<FUE9"!O;B!T:&%T(&UE<W-A9V4N($9I;'1E<G,@8V%N(&)E
M('9E<GD@=7-E9G5L(&9O<B!A=71O;6%T:6-A;&QY"B`@("!D96QE=&EN9R!U
M;G=A;G1E9"!M86EL+"!O<B!M86MI;F<@>6]U<B!M86EL(&%C8V]U;G0@;6]R
M92!M86YA9V%B;&4@8GD*("`@('-T;W)I;F<@<F5L871E9"!M97-S86=E<R!I
M;G1O(&1I9F9E<F5N="!F;VQD97)S+CPO<&%R83X*("`\+V5N=')Y/BTM/CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)R=6QE(CX*("`@(#QT:71L
M93Y&:6QT97(@4G5L93PO=&ET;&4^"B`@("`\<&%R83Y!(')U;&4@:7,@=&AE
M(&)A<VEC(&)U:6QD:6YG(&)L;V-K(&]F('EO=7(@;6%I;"!F:6QT97)S+"!I
M="!C;VYS:7-T<PH@("`@;V8@;VYE(&]R(&UO<F4@8V]N9&ET:6]N<R!A;F0@
M;VYE(&]R(&UO<F4@86-T:6]N<RX@5VAE;B!A(&UE<W-A9V4@:7,@<V5N=`H@
M("`@=&\@>6]U+"!I="!I<R!P<F]C97-S960@=&AR;W5G:"!T:&4@8V]N9&ET
M:6]N<R!O9B!Y;W5R(&9I;'1E<B!R=6QE<RP@:68@=&AE"B`@("!C;VYD:71I
M;VYS('1H870@>6]U('-P96-I9GD@87)E(&UE="P@=&AE;B!T:&4@86-T:6]N
M<R!T:&%T('EO=2!S<&5C:69Y('=I;&P*("`@(&)E('!E<F9O<FUE9"!O;B!T
M:&%T(&UE<W-A9V4N($9I;'1E<G,@8V%N(&)E('9E<GD@=7-E9G5L(&9O<B!A
M=71O;6%T:6-A;&QY"B`@("!D96QE=&EN9R!U;G=A;G1E9"!M86EL+"!O<B!M
M86MI;F<@>6]U<B!M86EL(&%C8V]U;G0@;6]R92!M86YA9V%B;&4@8GD*("`@
M('-T;W)I;F<@<F5L871E9"!M97-S86=E<R!I;G1O(&1I9F9E<F5N="!F;VQD
M97)S+CPO<&%R83X*("`\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)R=6QE+6%C=&EO;B(@;60U/2(W-S1A8V,U-#EF-F1D9F0U,C@W,68Y-3=D
M93)D965E-2(@<W1A=&4](F-H86YG960B/@H@("`@/'1I=&QE/D9I;'1R82!L
M:6MU;7,Z($1A<F+N8F$\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)<B!I97-P
MYVIA;6%S('9A:7+B:V%S(&1A<F+N8F%S+"!J82!P:65NXFMU<^X@=N=S='5L
M92!A=&)I;'-T(&9I;'1R82!L:6MU;6$@;F]S86/N:G5M:65M+B!)97;G<F]J
M:65T+"!K82!V:7-A<R!Z96WB:R!U>G-K86ET[G3B<R!D87)B[F)A<R!V87(@
M;F5B^W0@2G5M<R!P:65E:F%M87,L(&1A<F+N8G4@<V%R86MS=.(@<&%RXF3N
M<VEE<R!T:6MA:2!S:7-TYVUA<R!F:6QT<N=J;_#B<R!P<F]G<F%M;6%T^W)A
M<R!A=&)A;'-T[G3B<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DYO9^)D
MXG0@;6%NXB!)3D)/6#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5N=S='5L
M92!T:6MS('-A9VQA8N)T82!*^W-U($E.0D]8+B!4XB!I<B!N;VML=7/G=.(@
M;W!C:6IA+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^3F]GXF3B="#P86KB
M(&UA<.<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%;G<W1U;&4@=&EK<R!N
M;V?B9.)T82!N;W+B9.YT86KB(&UA<.<N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY!=&UE<W0@=N=S='5L:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5N=S='5L92!T:6MS(&ML=7/N=.=M(&EZ9'KG<W1A+B!.961Z($K[<RP@;F5D
M>B!N;W/[=.YTXFIS(&YE<V'R96US('!A>FGR;VIU;74@<&%R(&YO=&EK=?!O
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4.)R861R97/G="!VYW-T=6QI
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6YW-T=6QE('1I:W,@<.)R<_MT
M[G1A('5Z($K[<W4@;F]RXF3N=&\@12UP87-T82!A9')E<VDL(&YE<V%G;&%B
MXFIO="!VYW-T=6QE<R!K;W!I:G4@2OMS=2!P87-T:V%S=.YTYRX*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/E!I96?B9.)T(&UA;N(@24Y"3U@@=6X@<.)R
M861R97/G=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5N=S='5L92!T:6MS
M('#B<G/[=.YT82!U>B!*^W-U(&YO<N)D[G1O($4M<&%S=&$@861R97-I+"!S
M86=L86+B:F]T(';G<W1U;&5S(&MO<&EJ=2!*^W-U('!A<W1K87-T[G3G+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^3F]R86ED[G0@=N=S='5L:2!A<B!P
M86UA=&]J=6UU/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<FGL:6[B;.(@
M=N=S='5L92!T:6MS(&ML=7/N=.=M(&EZ9'KG<W1A+"!N;W/[=&]T('3B<R!A
M=71O<F%M(&IA=6YU(';G<W1U;&D@87(@2OMS=2!N;W+B9.YT;R!T96MS='4N
M"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)R
M=6QE+6%C=&EO;B(^"B`@("`\=&ET;&4^1FEL=&5R(%)U;&4Z($%C=&EO;CPO
M=&ET;&4^"B`@("`\<&%R83Y4:&5S92!A<F4@=&AE('!O<W-I8FQE(&%C=&EO
M;G,@=&\@=&%K92!I9B!A;B!I;F-O;6EN9R!M97-S86=E(&UA=&-H97,*("`@
M('1H92!S<&5C:69I960@8V]N9&ET:6]N<RX@3F]T92!T:&%T(&%L;"!O9B!T
M:&5S92!O<'1I;VYS(&UA>2!N;W0@8F4*("`@(&%V86EL86)L92!T;R!Y;W4@
M+2!O;FQY('1H92!O<'1I;VYS('1H870@=V]R:R!W:71H('1H92!U;F1E<FQY
M:6YG(&9I;'1E<FEN9PH@("`@<V]F='=A<F4@=VEL;"!B92!S:&]W;BX\+W!A
M<F$^"B`@("`\:&5A9&EN9SY$96QI=F5R('1H:7,@;65S<V%G92!I;G1O(&UY
M($E.0D]8/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE(&UE<W-A9V4@=VEL;"!B
M92!S879E9"!I;B!Y;W5R($E.0D]8+B!4:&ES(&ES('1H92!D969A=6QT"B`@
M("!O<'1I;VXN/"]P87)A/@H@("`@/&AE861I;F<^1&5L:79E<B!T;R!T:&ES
M(&UA:6QB;W@\+VAE861I;F<^"B`@("`\<&%R83Y4:&4@;65S<V%G92!W:6QL
M(&)E(&1E;&EV97)E9"!T;R!T:&4@<W!E8VEF:65D(&9O;&1E<BX\+W!A<F$^
M"B`@("`\:&5A9&EN9SY$:7-C87)D('1H:7,@;65S<V%G93PO:&5A9&EN9SX*
M("`@(#QP87)A/E1H92!M97-S86=E('=I;&P@8F4@<VEL96YT;'D@9&5L971E
M9"X@3F5I=&AE<B!Y;W4@;F]R('1H92!S96YD97(@=VEL;`H@("`@<F5C96EV
M92!N;W1I9FEC871I;VX@=&AA="!T:&ES(&AA<R!H87!P96YE9"X\+W!A<F$^
M"B`@("`\:&5A9&EN9SY2961I<F5C="!T:&ES(&UE<W-A9V4@=&\\+VAE861I
M;F<^"B`@("`\<&%R83Y4:&4@;65S<V%G92!W:6QL(&)E('-E;G0@=&\@=&AE
M(&5M86EL(&%D9')E<W,@=&AA="!Y;W4@<W!E8VEF>2X@3F\*("`@(&-O<'D@
M;V8@=&AE(&UE<W-A9V4@=VEL;"!R96UA:6X@:6X@=&AI<R!A8V-O=6YT+CPO
M<&%R83X*("`@(#QH96%D:6YG/D1E;&EV97(@=&\@;7D@24Y"3U@@86YD(')E
M9&ER96-T('1O/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE(&UE<W-A9V4@=VEL
M;"!B92!S96YT('1O('1H92!E;6%I;"!A9&1R97-S('1H870@>6]U('-P96-I
M9GDL(&%N9"!A"B`@("!C;W!Y(&]F('1H92!M97-S86=E('=I;&P@<F5M86EN
M(&EN('EO=7(@24Y"3U@N/"]P87)A/@H@("`@/&AE861I;F<^4F5J96-T('1H
M:7,@;65S<V%G92!W:71H(')E87-O;CPO:&5A9&EN9SX*("`@(#QP87)A/E1H
M92!O<FEG:6YA;"!M97-S86=E('=I;&P@8F4@9&ES8V%R9&5D+"!A;F0@82!N
M97<@;65S<V%G92!W:6QL(&)E"B`@("!S96YT('1O('1H92!S96YD97(@=VET
M:"!T:&4@=&5X="!T:&%T('EO=2!S<&5C:69Y+CPO<&%R83X*("`\+V5N=')Y
M/BTM/CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)R=6QE+6%C=&EO
M;B(^"B`@("`\=&ET;&4^1FEL=&5R(%)U;&4Z($%C=&EO;CPO=&ET;&4^"B`@
M("`\<&%R83Y4:&5S92!A<F4@=&AE('!O<W-I8FQE(&%C=&EO;G,@=&\@=&%K
M92!I9B!A;B!I;F-O;6EN9R!M97-S86=E(&UA=&-H97,*("`@('1H92!S<&5C
M:69I960@8V]N9&ET:6]N<RX@3F]T92!T:&%T(&%L;"!O9B!T:&5S92!O<'1I
M;VYS(&UA>2!N;W0@8F4*("`@(&%V86EL86)L92!T;R!Y;W4@+2!O;FQY('1H
M92!O<'1I;VYS('1H870@=V]R:R!W:71H('1H92!U;F1E<FQY:6YG(&9I;'1E
M<FEN9PH@("`@<V]F='=A<F4@=VEL;"!B92!S:&]W;BX\+W!A<F$^"B`@("`\
M:&5A9&EN9SY$96QI=F5R('1H:7,@;65S<V%G92!I;G1O(&UY($E.0D]8/"]H
M96%D:6YG/@H@("`@/'!A<F$^5&AE(&UE<W-A9V4@=VEL;"!B92!S879E9"!I
M;B!Y;W5R($E.0D]8+B!4:&ES(&ES('1H92!D969A=6QT"B`@("!O<'1I;VXN
M/"]P87)A/@H@("`@/&AE861I;F<^1&5L:79E<B!T;R!T:&ES(&UA:6QB;W@\
M+VAE861I;F<^"B`@("`\<&%R83Y4:&4@;65S<V%G92!W:6QL(&)E(&1E;&EV
M97)E9"!T;R!T:&4@<W!E8VEF:65D(&9O;&1E<BX\+W!A<F$^"B`@("`\:&5A
M9&EN9SY$:7-C87)D('1H:7,@;65S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A
M/E1H92!M97-S86=E('=I;&P@8F4@<VEL96YT;'D@9&5L971E9"X@3F5I=&AE
M<B!Y;W4@;F]R('1H92!S96YD97(@=VEL;`H@("`@<F5C96EV92!N;W1I9FEC
M871I;VX@=&AA="!T:&ES(&AA<R!H87!P96YE9"X\+W!A<F$^"B`@("`\:&5A
M9&EN9SY2961I<F5C="!T:&ES(&UE<W-A9V4@=&\\+VAE861I;F<^"B`@("`\
M<&%R83Y4:&4@;65S<V%G92!W:6QL(&)E('-E;G0@=&\@=&AE(&5M86EL(&%D
M9')E<W,@=&AA="!Y;W4@<W!E8VEF>2X@3F\*("`@(&-O<'D@;V8@=&AE(&UE
M<W-A9V4@=VEL;"!R96UA:6X@:6X@=&AI<R!A8V-O=6YT+CPO<&%R83X*("`@
M(#QH96%D:6YG/D1E;&EV97(@=&\@;7D@24Y"3U@@86YD(')E9&ER96-T('1O
M/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE(&UE<W-A9V4@=VEL;"!B92!S96YT
M('1O('1H92!E;6%I;"!A9&1R97-S('1H870@>6]U('-P96-I9GDL(&%N9"!A
M"B`@("!C;W!Y(&]F('1H92!M97-S86=E('=I;&P@<F5M86EN(&EN('EO=7(@
M24Y"3U@N/"]P87)A/@H@("`@/&AE861I;F<^4F5J96-T('1H:7,@;65S<V%G
M92!W:71H(')E87-O;CPO:&5A9&EN9SX*("`@(#QP87)A/E1H92!O<FEG:6YA
M;"!M97-S86=E('=I;&P@8F4@9&ES8V%R9&5D+"!A;F0@82!N97<@;65S<V%G
M92!W:6QL(&)E"B`@("!S96YT('1O('1H92!S96YD97(@=VET:"!T:&4@=&5X
M="!T:&%T('EO=2!S<&5C:69Y+CPO<&%R83X*("`\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)R=6QE+6-O;6)I;F4B(&UD-3TB,35A,6-E93-A
M-S<X8C<R-38P83`S865A-S,X8S1B,C@B('-T871E/2)C:&%N9V5D(CX*("`@
M(#QT:71L93Y&:6QT<F$@;&EK=6US.B!+;VUB:6[G="!O<&-I:F%S/"]T:71L
M93X*("`@(#QP87)A/@H@("`@27(@:65S<.=J86US(&YO<N)D[G0@=F%I<N)K
M=7,@;F]S86/N:G5M=7,@=FEE;F$@;&EK=6UA(&EE='9A<F]S+"!T;W,@;&_L
M:7-K:2!G<G5PYVIO="`H=6XO=F%I*2X@3F%V(&EE<W#G:F%M<R!R863N="!K
M;VUP;&5K<W5S(&9I;'1R=7,L(&EZ;6%N=&]J;W0@=FEE;FQA:6/N9VD@86)U
M<R!L;^QI<VMO<R!N;W-A8^YJ=6UU<RX*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/E5N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!*82!I>G;G;.=S:65T
M:65S(%5.+"!I96[B:V_P86D@=N=S='5L96D@:7(@:N)A=&)I;'-T('9I<VEE
M;2!N;W+B9.YT86II96T@;F]S86/N:G5M:65M+"!L86D@:7IP:6QD[G1O<R!*
M^W-U(&YO<N)D[G3B<R!D87)B[F)A<RX@"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY686D\+VAE861I;F<^"B`@("`\<&%R83X*("`@($IA(&EZ=N=LYW-I
M971I97,@5D%)+"!F:6QT<N(@;F]RXF3N=.)S(&1A<F+N8F%S('1I:W,@:7IP
M:6QD[G1A<RP@:F$@=&EK<R!K;VYS=&%TYW1A(&%T8FEL<W3N8F$@=FES;6%Z
M('9I96YA;2!F:6QT<F$@;F]S86/N:G5M86TN"B`@("`\+W!A<F$^"CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)R=6QE+6-O;6)I;F4B/@H@("`@
M/'1I=&QE/D9I;'1E<B!2=6QE.B!#;VUB:6YE($]P=&EO;G,\+W1I=&QE/@H@
M("`@/'!A<F$^66]U(&UA>2!D969I;F4@;75L=&EP;&4@8V]N9&ET:6]N<R!W
M:71H:6X@82!S:6YG;&4@<G5L92X@66]U(&UA>0H@("`@9W)O=7`@=&AE;2!T
M;V=E=&AE<B!L;V=I8V%L;'D@=7-I;F<@(F%N9"(O(F]R(BX@66]U(&UA>2!N
M;W0@8W)E871E(&-O;7!L97@*("`@(&9I;'1E<G,@8V]N=&%I;F<@8F]T:"!T
M>7!E<R!O9B!C;VYD:71I;VYS+CPO<&%R83X*("`@(#QH96%D:6YG/D%N9#PO
M:&5A9&EN9SX*("`@(#QP87)A/DEF('EO=2!S96QE8W0@04Y$+"!A;B!I;F-O
M;6EN9R!M97-S86=E(&UU<W0@;6%T8V@@979E<GD@8V]N9&ET:6]N"B`@("!T
M:&%T('EO=2!S<&5C:69Y(&EN(&]R9&5R(&9O<B!T:&4@86-T:6]N<R!T;R!B
M92!E>&5C=71E9"X\+W!A<F$^"B`@("`\:&5A9&EN9SY/<CPO:&5A9&EN9SX*
M("`@(#QP87)A/DEF('EO=2!S96QE8W0@3U(L('1H92!S<&5C:69I960@86-T
M:6]N<R!W:6QL(&)E(&5X96-U=&5D(&EF(&%T(&QE87-T"B`@("!O;F4@;V8@
M=&AE(&-O;F1I=&EO;G,@:7,@;65T+CPO<&%R83X*("`\+V5N=')Y/BTM/CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)R=6QE+6-O;6)I;F4B/@H@
M("`@/'1I=&QE/D9I;'1E<B!2=6QE.B!#;VUB:6YE($]P=&EO;G,\+W1I=&QE
M/@H@("`@/'!A<F$^66]U(&UA>2!D969I;F4@;75L=&EP;&4@8V]N9&ET:6]N
M<R!W:71H:6X@82!S:6YG;&4@<G5L92X@66]U(&UA>0H@("`@9W)O=7`@=&AE
M;2!T;V=E=&AE<B!L;V=I8V%L;'D@=7-I;F<@(F%N9"(O(F]R(BX@66]U(&UA
M>2!N;W0@8W)E871E(&-O;7!L97@*("`@(&9I;'1E<G,@8V]N=&%I;F<@8F]T
M:"!T>7!E<R!O9B!C;VYD:71I;VYS+CPO<&%R83X*("`@(#QH96%D:6YG/D%N
M9#PO:&5A9&EN9SX*("`@(#QP87)A/DEF('EO=2!S96QE8W0@04Y$+"!A;B!I
M;F-O;6EN9R!M97-S86=E(&UU<W0@;6%T8V@@979E<GD@8V]N9&ET:6]N"B`@
M("!T:&%T('EO=2!S<&5C:69Y(&EN(&]R9&5R(&9O<B!T:&4@86-T:6]N<R!T
M;R!B92!E>&5C=71E9"X\+W!A<F$^"B`@("`\:&5A9&EN9SY/<CPO:&5A9&EN
M9SX*("`@(#QP87)A/DEF('EO=2!S96QE8W0@3U(L('1H92!S<&5C:69I960@
M86-T:6]N<R!W:6QL(&)E(&5X96-U=&5D(&EF(&%T(&QE87-T"B`@("!O;F4@
M;V8@=&AE(&-O;F1I=&EO;G,@:7,@;65T+CPO<&%R83X*("`\+V5N=')Y/BTM
M/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)R=6QE+6UA<FLB(&UD-3TB96-A8F8W
M86%E9&4Q,#9B-V1D,S)A,F%E93`U8V5E-3<B('-T871E/2)C:&%N9V5D(CX*
M("`@(#QT:71L93Y&:6QT<F$@;&EK=6US.B!!='KN;>=T(';G<W1U;&D\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!)<B!I97-PYVIA;7,@:^(@=FEE;G4@;F\@
M9FEL=')A(&1A<F+N8N)M(&YO<N)D[G0@=N=S='5L97,@871Z[FWG\&%N=2!A
M<B!V:65N=2!V86D@=F%I<N)K:65M($E-05`@:V%R;V1Z:?)I96TN($EE<W#G
M:F%MXG,@=N=R=.YB87,@:7(@3&%S[G1S+"!3=F%R[F=S+"!!=&)I;&3G=',@
M=6X@1'KG<W1S+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB<G5L92UM87)K(CX*("`@(#QT:71L93Y&:6QT97(@4G5L93H@
M36%R:R!-97-S86=E/"]T:71L93X*("`@(#QP87)A/EEO=2!M87D@<W!E8VEF
M>2!M87)K:6YG(&$@;65S<V%G92!W:71H(&]N92!O<B!M;W)E($E-05`@9FQA
M9W,@87,@;VYE"B`@("!O9B!T:&4@86-T:6]N<R!I;B!A(')U;&4N(%1H92!P
M;W-S:6)L92!V86QU97,@87)E(%-E96XL($EM<&]R=&%N="P*("`@($%N<W=E
M<F5D+"!A;F0@1&5L971E9"X\+W!A<F$^"B`@/"]E;G1R>3XM+3X\(2TM($5N
M9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<G5L92UM87)K(CX*("`@(#QT:71L
M93Y&:6QT97(@4G5L93H@36%R:R!-97-S86=E/"]T:71L93X*("`@(#QP87)A
M/EEO=2!M87D@<W!E8VEF>2!M87)K:6YG(&$@;65S<V%G92!W:71H(&]N92!O
M<B!M;W)E($E-05`@9FQA9W,@87,@;VYE"B`@("!O9B!T:&4@86-T:6]N<R!I
M;B!A(')U;&4N(%1H92!P;W-S:6)L92!V86QU97,@87)E(%-E96XL($EM<&]R
M=&%N="P*("`@($%N<W=E<F5D+"!A;F0@1&5L971E9"X\+W!A<F$^"B`@/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<G5L92UM871C:&5S(B!M
M9#4](C)F93!C8V9D.#=F8V$Q-V%E83,W,F4Y.#(Y8V$P93(Q(B!S=&%T93TB
M8VAA;F=E9"(^"B`@("`\=&ET;&4^1FEL=')A(&QI:W5M<SH@071B:6QS=.YB
M87,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!):W9I96YS(&QI:W5M82!N;W-A
M8^YJ=6US('-A<W3B=B!N;R`S(&MO;7!O;F5N=&EE;3H@<&ER;6%I<R!I<B!P
MXG)B875DXFUA:7,@;&%U:W,L(&]T<F%I<R`M('9E:6-A;>)S('-A;.YD>FEN
MXO!A;F%S('9E:61S+"!T<F7P86ES("T@:6YF;W)MXF-I:F$L(&%T8FEL<W3N
M8F$@:W5R86D@:7(@:N)PXG)B875D82X*("`@($ER('9A:7+B:VD@873P[6ER
M[F=I('9E:6-A;>)S('-A;.YD>FENXO!A;F%S('9E:61I+B!)>FUA;G1O:F%M
M:64@=F5I9&D@:6MV:65N86T@;&%U:V%M(&ER(&%T:V%R[F=I(&YO(&QA=6MA
M('1I<&$@=6X@9FEL='+G:F_PXG,@<')O9W)A;6UA=/MR87,@<W#G:N)M+B!4
MXF3G:N)D:2P@=FES87,@>F5MXFL@=7IS:V%I=.YTXG,@871B:6QS=.YB87,@
M;W!C:6IA<R!V87(@;F5P87+B9.YT:65S(&QA=6MA;2!P:65MYW)O:F%M;R!V
M96ED=2!S87)A:W-TXBX@/"]P87)A/@H@("`@/&AE861I;F<^4V%T=7(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%1I:W,@=7IS:V%T[G1S('!A<B!P871I
M97-U+"!J82!N;W+B9.YT86ES('1E:W-T<R!T:6MS(&%T<F%S=',@:F5B:W5R
M(&QA=6OB+B!0:65MYW)A;3H@=7-E<D!E>&%M<&QE(&+[<R!P871I97-S(&IO
M95]U<V5R0&5X86UP;&4N8V]M(&=A9.YJ=6WB+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^3F5S871U<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&EK
M<R!U>G-K873N=',@<&%R('!A=&EE<W4L(&IA(&YO<N)D[G1A:7,@=&5K<W1S
M(&YE=&EK<R!A=')A<W1S(&IE8FMU<B!L875KXBX@4&EE;>=R86TZ('5S97)`
M97AA;7!L92!B^W,@<&%T:65S<R!U<V5R7VIO94!E>&%M<&QE+F-O;2!G863N
M:G5MXBX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DER/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!4:6MS('5Z<VMA=.YT<R!P87(@<&%T:65S=2P@:F$@
M;F]RXF3N=&%I<R!T96MS=',@<')E8^YZ:2!A=&)I;&3N<R!L875K82!S871U
M<F%M+B!0:65MYW)A;3H@=7-E<D!E>&%M<&QE+F-O;2!I<B!P871I97-S('1I
M:V%I('5S97)`97AA;7!L92YC;VT@9V%D[FIU;>(N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY.878\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1I:W,@
M=7IS:V%T[G1S('!A<B!P871I97-U+"!J82!N;W+B9.YT86ES('1E:W-T<R!P
M<F5C[GII(&YE871B:6QD[G,@;&%U:V$@<V%T=7)A;2X@4&EE;>=R86TZ('5S
M97)`97AA;7!L92!N878@=7-E<D!E>&%M<&QE+F-O;2X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/E/B:V%S(&%R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4:6MS('5Z<VMA=.YT<R!P87(@<&%T:65S=2P@:F$@;F]RXF3N=&%I<R!T
M96MS=',@871R863N<VEE<R!L875K82!SXFMU;>(N(%!I96WG<F%M.B!U<V5R
M0&5X86UP;&4@:7(@<&%T:65S<R!U<V5R0&5X86UP;&4N8V]M(&=A9.YJ=6WB
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^3F5SXFMA<R!A<CPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5&EK<R!U>G-K873N=',@<&%R('!A=&EE<W4L
M(&IA(&YO<N)D[G1A:7,@=&5K<W1S(&YE871R863N<VEE<R!L875K82!SXFMU
M;>(N(%!I96WG<F%M.B!`97AA;7!L92YC;VT@:7(@<&%T:65S<R!U<V5R0&5X
M86UP;&4N8V]M(&=A9.YJ=6WB+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M0F5I9'IA<R!A<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&EK<R!U>G-K
M873N=',@<&%R('!A=&EE<W4L(&IA(&YO<N)D[G1A:7,@=&5K<W1S(&%T<F%D
M[G-I97,@;&%U:V$@8F5I9^)S+B!0:65MYW)A;3H@0&5X86UP;&4N8V]M(&ER
M('!A=&EE<W,@=7-E<D!E>&%M<&QE+F-O;2!G863N:G5MXBX*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/DYE8F5I9'IA<R!A<CPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&EK<R!U>G-K873N=',@<&%R('!A=&EE<W4L(&IA(&YO<N)D
M[G1A:7,@=&5K<W1S(&YE871R863N<VEE<R!L875K82!B96EGXG,N(%!I96WG
M<F%M.B!`:&]R9&4N;W)G(&ER('!A=&EE<W,@=7-E<D!E>&%M<&QE+F-O;2!G
M863N:G5MXBX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5K<VES=.<\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%1I:W,@=7IS:V%T[G1S('!A<B!P871I
M97-U+"!J82!N;W+B9.YTXB!G86QV96YE("AH96%D97(I(';G<W1U;.<@96MS
M:7-TYRP@;F5A=&MA<NYG:2!N;R!TXB!S871U<F$N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY.965K<VES=.<\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1I:W,@=7IS:V%T[G1S('!A<B!P871I97-U+"!J82!N;W+B9.YTXB!G86QV
M96YE("AH96%D97(I(';G<W1U;.<@;F5E:W-I<W3G+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^4F5G97@\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%)E
M9V5X(.]A=6H@;&EE=&]T(&MO;7!L96MS87,@4$]325@@<V%V:65T;VIA;6%S
M(&QO[&ES:^)S(&EZ=&5I:W-M97,@=N=S='7O=2!G86QV9?)U('-A;.YD>FEN
MXO!A;F%I+B!0:65MYW)A;3H@(E)E8V5I=F5D(&9R;VT@6RI<+BI<+BI<+BI=
M(&)Y("AH;W-T87QH;W-T8BDN97AA;7!L92YC;VTJ(B!A=&)I;'-T(")296-E
M:79E9"!F<F]M(%LQ-S(N,38N,3`P+C%=(&)Y(&AO<W1A+F5X86UP;&4N8V]M
M(&]N(%1U97-D87DB"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY!=&)I;'-T
M[F)A/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!;071B:6QS=.YB85T@:7(@
M;.YD>NYG82!;4V%T=7)=+"!I>O)E;6]T(&EE<W#G:G4@;&EE=&]T("(J(B!U
M;B`B/R(@:^(@86EZ<W3B:N=J>NYM97,N("(J(B!A:7IS=.)J(&IE8FMU<G4@
M>NYM:G4@<VMA:71U+"`B/R(@86EZ=FEE=&\@=&EK86D@=FEE;G4@>NYM:2X@
M4&EE;>=R86TL("(J=7-E<C]`97AA;7!L92YC;VTB(&%T8FEL9.YS(&=A;B`B
M=7-E<C%`97AA;7!L92YC;VTB(&=A;B`B;W1H97)U<V5R,D!E>&%M<&QE+F-O
M;2(*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DYE871B:6QS=#PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@6TYE871B:6QS=%T@:7(@;.YD>NYG<R!;071B
M:6QS=%TL('1I:V%I('1A<R!I96?[<R!N;VQI961Z;_!U(';G<G3N8G4L(&IA
M(&YO<N)D[G1A:7,@=&5K<W1S(&%T8FEL9.YS(&=A;'9E;F5S(&QA=6MA('-A
M='5R86TN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY-87KB:W,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(-#N('#B<F)A=61E(.]A=6H@<V%L[F1Z:6[B
M="!*^W-U(&YO<N)D[G1O('-K86ET;&ES:V\@;&EE;'5M=2!A<B!VYW)T[F)U
M(';G<W1U;&5S(&=A;'9E;F5S(&QA=6OB+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^36%ZXFMS('9A:2!V:65NXF1S/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("#0[B!PXG)B875D92#O875J('-A;.YD>FENXG0@2OMS=2!N;W+B9.YT
M;R!S:V%I=&QI<VMO(&QI96QU;74@87(@=N=R=.YB=2!VYW-T=6QE<R!G86QV
M96YE<R!L875KXBX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I96[B9',\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(-#N('#B<F)A=61E(.]A=6H@<V%L
M[F1Z:6[B="!*^W-U(&YO<N)D[G1O('-K86ET;&ES:V\@;&EE;'5M=2!A<B!V
MYW)T[F)U(';G<W1U;&5S(&=A;'9E;F5S(&QA=6OB+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^3&EE;.)K<R!V86D@=FEE;N)D<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@T.X@<.)R8F%U9&4@[V%U:B!S86SN9'II;N)T($K[<W4@
M;F]RXF3N=&\@<VMA:71L:7-K;R!L:65L=6UU(&%R(';G<G3N8G4@=N=S='5L
M97,@9V%L=F5N97,@;&%U:^(N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY,
M:65LXFMS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("#0[B!PXG)B875D92#O
M875J('-A;.YD>FENXG0@2OMS=2!N;W+B9.YT;R!S:V%I=&QI<VMO(&QI96QU
M;74@87(@=N=R=.YB=2!VYW-T=6QE<R!G86QV96YE<R!L875KXBX*("`@(#PO
M<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G)U;&4M;6%T
M8VAE<R(^"B`@("`\=&ET;&4^1FEL=&5R(%)U;&4Z($UA=&-H97,\+W1I=&QE
M/@H@("`@/'!A<F$^5&AE<F4@87)E(#,@8V]M<&]N96YT<R!T;R!E86-H(&-O
M;F1I=&EO;B!I;B!A(')U;&4N(%1H92!F:7)S="!I<R!T:&4*("`@(&9I96QD
M('1O(&5X86UI;F4N(%1H92!S96-O;F0@:7,@=&AE('1Y<&4@;V8@8V]M<&%R
M:7-O;B!T;R!P97)F;W)M+B!4:&4*("`@('1H:7)D(&ES('1H92!V86QU92!T
M;R!W:&EC:"!T:&4@9FEE;&0@<VAO=6QD(&)E(&-O;7!A<F5D+B!4:&5R92!A
M<F4@82!F97<*("`@(&1I9F9E<F5N="!T>7!E<R!O9B!C;VUP87)I<V]N<R!T
M:&%T(&-A;B!B92!P97)F;W)M960N(%1H92!C;VUP87)I<V]N<PH@("`@879A
M:6QA8FQE(&9O<B!A;GD@9VEV96X@9FEE;&0@=VEL;"!D97!E;F0@;VX@8F]T
M:"!T:&4@='EP92!O9B!T:&4@9FEE;&0@86YD"B`@("!W:&%T('1H92!U;F1E
M<FQY:6YG(&9I;'1E<FEN9R!S;V9T=V%R92!C86X@:&%N9&QE+B!4:'5S+"!A
M;&P@<&]T96YT:6%L"B`@("!M871C:&EN9R!O<'1I;VYS(&QI<W1E9"!B96QO
M=R!M87D@;F]T(&%P<&5A<B!F;W(@82!G:79E;B!F:65L9"X\+W!A<F$^"B`@
M("`\:&5A9&EN9SY#;VYT86EN<SPO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@
M8F4@8V]N<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R
M:6YG(&ES(&9O=6YD"B`@("!A;GEW:&5R92!O;B!T:&4@;&EN92X@17AA;7!L
M93H@=7-E<D!E>&%M<&QE('=O=6QD(&UA=&-H"B`@("!J;V5?=7-E<D!E>&%M
M<&QE+F-O;3PO<&%R83X*("`@(#QH96%D:6YG/D1O97-N)W0@0V]N=&%I;CPO
M:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@8F4@8V]N<VED97)E9"!T;R!B92!T
M<G5E(&EF('1H92!S<&5C:69I960@<W1R:6YG(&ES(&YO="!F;W5N9`H@("`@
M86YY=VAE<F4@;VX@=&AE(&QI;F4N($5X86UP;&4Z('5S97)`97AA;7!L92!W
M;W5L9"!N;W0@;6%T8V@*("`@(&IO95]U<V5R0&5X86UP;&4N8V]M/"]P87)A
M/@H@("`@/&AE861I;F<^27,\+VAE861I;F<^"B`@("`\<&%R83Y7:6QL(&)E
M(&-O;G-I9&5R960@=&\@8F4@=')U92!I9B!T:&4@<W!E8VEF:65D('-T<FEN
M9R!M871C:&5S('1H90H@("`@;&EN92!E>&%C=&QY+B!%>&%M<&QE.B!U<V5R
M0&5X86UP;&4N8V]M(&ES('5S97)`97AA;7!L92YC;VT\+W!A<F$^"B`@("`\
M:&5A9&EN9SY)<VXG=#PO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@8F4@8V]N
M<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R:6YG(&1O
M97,@;F]T(&UA=&-H"B`@("!T:&4@;&EN92!E>&%C=&QY+B!%>&%M<&QE.B!U
M<V5R0&5X86UP;&4@:7,@;F]T('5S97)`97AA;7!L92YC;VT\+W!A<F$^"B`@
M("`\:&5A9&EN9SY"96=I;G,@=VET:#PO:&5A9&EN9SX*("`@(#QP87)A/E=I
M;&P@8F4@8V]N<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@
M<W1R:6YG(&UA=&-H97,@=&AE"B`@("!B96=I;FYI;F<@;V8@=&AE(&QI;F4N
M($5X86UP;&4Z('5S97)`97AA;7!L92!W:6QL(&UA=&-H"B`@("!U<V5R0&5X
M86UP;&4N8V]M/"]P87)A/@H@("`@/&AE861I;F<^1&]E<VXG="!B96=I;B!W
M:71H/"]H96%D:6YG/@H@("`@/'!A<F$^5VEL;"!B92!C;VYS:61E<F5D('1O
M(&)E('1R=64@:68@=&AE('-P96-I9FEE9"!S=')I;F<@9&]E<R!N;W0@;6%T
M8V@*("`@('1H92!B96=I;FYI;F<@;V8@=&AE(&QI;F4N($5X86UP;&4Z('5S
M97)`97AA;7!L92YC;VT@=VEL;"!N;W0@;6%T8V@*("`@('5S97)`97AA;7!L
M93PO<&%R83X*("`@(#QH96%D:6YG/D5N9',@=VET:#PO:&5A9&EN9SX*("`@
M(#QP87)A/E=I;&P@8F4@8V]N<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S
M<&5C:69I960@<W1R:6YG(&UA=&-H97,@=&AE(&5N9`H@("`@;V8@=&AE(&QI
M;F4N($5X86UP;&4Z(&5X86UP;&4N8V]M('=I;&P@;6%T8V@@=7-E<D!E>&%M
M<&QE+F-O;3PO<&%R83X*("`@(#QH96%D:6YG/D1O97-N)W0@96YD('=I=&@\
M+VAE861I;F<^"B`@("`\<&%R83Y7:6QL(&)E(&-O;G-I9&5R960@=&\@8F4@
M=')U92!I9B!T:&4@<W!E8VEF:65D('-T<FEN9R!D;V5S(&YO="!M871C:`H@
M("`@=&AE(&5N9"!O9B!T:&4@;&EN92X@17AA;7!L93H@:&]R9&4N;W)G('=I
M;&P@;F]T(&UA=&-H"B`@("!U<V5R0&5X86UP;&4N8V]M/"]P87)A/@H@("`@
M/&AE861I;F<^17AI<W1S/"]H96%D:6YG/@H@("`@/'!A<F$^5VEL;"!B92!C
M;VYS:61E<F5D('1O(&)E('1R=64@:68@=&AE('-P96-I9FEE9"!H96%D97(@
M97AI<W1S(&EN('1H90H@("`@;65S<V%G92P@<F5G87)D;&5S<R!O9B!W:&%T
M(&ET<R!V86QU92!I<RX\+W!A<F$^"B`@("`\:&5A9&EN9SY$;V5S;B=T($5X
M:7-T/"]H96%D:6YG/@H@("`@/'!A<F$^5VEL;"!B92!C;VYS:61E<F5D('1O
M(&)E('1R=64@:68@=&AE('-P96-I9FEE9"!H96%D97(@9&]E<R!N;W0@97AI
M<W0*("`@(&EN('1H92!M97-S86=E+CPO<&%R83X*("`@(#QH96%D:6YG/E)E
M9V5X/"]H96%D:6YG/@H@("`@/'!A<F$^4F5G97@@86QL;W=S('EO=2!T;R!U
M<V4@8V]M<&QE>"!03U-)6"!C;VUP871I8FQE(')E9W5L87(@97AP<F5S<VEO
M;G,*("`@('1O(&-O;7!A<F4@86=A:6YS="!M97-S86=E(&AE861E<G,N($5X
M86UP;&4Z(")296-E:79E9"!F<F]M(%LJ7"XJ7"XJ7"XJ72!B>0H@("`@*&AO
M<W1A?&AO<W1B*2YE>&%M<&QE+F-O;2HB('=O=6QD(&UA=&-H(")296-E:79E
M9"!F<F]M(%LQ-S(N,38N,3`P+C%=(&)Y"B`@("!H;W-T82YE>&%M<&QE+F-O
M;2!O;B!4=65S9&%Y(CPO<&%R83X*("`@(#QH96%D:6YG/DUA=&-H97,\+VAE
M861I;F<^"B`@("`\<&%R83Y-871C:&5S(&ES('-I;6EL87(@=&\@8V]N=&%I
M;G,L('=I=&@@=&AE(&5X8V5P=&EO;B!T:&%T('EO=2!M87D@=7-E("H*("`@
M(&%N9"`_(&%S('=I;&1C87)D<RX@06X@*B!W:6QL(&UA=&-H(&%N>2!N=6UB
M97(@;V8@8VAA<F%C=&5R<RP@86YD(&$@/R!W:6QL"B`@("!M871C:"!E>&%C
M=&QY(&]N92!C:&%R871E<BX@17AA;7!L93H@(BIU<V5R/T!E>&%M<&QE+F-O
M;2(@=VEL;"!M871C:"!B;W1H"B`@("`B=7-E<C%`97AA;7!L92YC;VTB(&%N
M9"`B;W1H97)U<V5R,D!E>&%M<&QE+F-O;2(\+W!A<F$^"B`@("`\:&5A9&EN
M9SY$;V5S;B=T(&UA=&-H/"]H96%D:6YG/@H@("`@/'!A<F$^1&]E<VXG="!M
M871C:"!I<R!T:&4@<V%M92!A<R!M871C:&5S(&5X8V5P="!T:&%T(&ET('=I
M;&P@979A;'5A=&4@=&\*("`@(&9A;'-E(&EF('1H92!S<&5C:69I960@=F%L
M=64@;6%T8VAE<R!T:&4@<W1R:6YG(&EN('1H92!M97-S86=E"B`@("!H96%D
M97(N/"]P87)A/@H@("`@/&AE861I;F<^3&5S<R!T:&%N/"]H96%D:6YG/@H@
M("`@/'!A<F$^5&AI<R!I<R!A(')E;&%T:6]N86P@=&5S="!W:&EC:"!W:6QL
M(&-O;7!A<F4@=&AE('9A;'5E('EO=2!S<&5C:69Y"B`@("!A;F0@=&AE('9A
M;'5E(&EN('1H92!M97-S86=E(&AE861E<B!N=6UE<FEC86QL>2X\+W!A<F$^
M"B`@("`\:&5A9&EN9SY,97-S('1H86X@;W(@97%U86P@=&\\+VAE861I;F<^
M"B`@("`\<&%R83Y4:&ES(&ES(&$@<F5L871I;VYA;"!T97-T('=H:6-H('=I
M;&P@8V]M<&%R92!T:&4@=F%L=64@>6]U('-P96-I9GD*("`@(&%N9"!T:&4@
M=F%L=64@:6X@=&AE(&UE<W-A9V4@:&5A9&5R(&YU;65R:6-A;&QY+CPO<&%R
M83X*("`@(#QH96%D:6YG/D5Q=6%L('1O/"]H96%D:6YG/@H@("`@/'!A<F$^
M5&AI<R!I<R!A(')E;&%T:6]N86P@=&5S="!W:&EC:"!W:6QL(&-O;7!A<F4@
M=&AE('9A;'5E('EO=2!S<&5C:69Y"B`@("!A;F0@=&AE('9A;'5E(&EN('1H
M92!M97-S86=E(&AE861E<B!N=6UE<FEC86QL>2X\+W!A<F$^"B`@("`\:&5A
M9&EN9SY'<F5A=&5R('1H86X@;W(@97%U86P@=&\\+VAE861I;F<^"B`@("`\
M<&%R83Y4:&ES(&ES(&$@<F5L871I;VYA;"!T97-T('=H:6-H('=I;&P@8V]M
M<&%R92!T:&4@=F%L=64@>6]U('-P96-I9GD*("`@(&%N9"!T:&4@=F%L=64@
M:6X@=&AE(&UE<W-A9V4@:&5A9&5R(&YU;65R:6-A;&QY+CPO<&%R83X*("`@
M(#QH96%D:6YG/D=R96%T97(@=&AA;CPO:&5A9&EN9SX*("`@(#QP87)A/E1H
M:7,@:7,@82!R96QA=&EO;F%L('1E<W0@=VAI8V@@=VEL;"!C;VUP87)E('1H
M92!V86QU92!Y;W4@<W!E8VEF>0H@("`@86YD('1H92!V86QU92!I;B!T:&4@
M;65S<V%G92!H96%D97(@;G5M97)I8V%L;'DN/"]P87)A/@H@(#PO96YT<GD^
M+2T^/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G)U;&4M;6%T8VAE
M<R(^"B`@("`\=&ET;&4^1FEL=&5R(%)U;&4Z($UA=&-H97,\+W1I=&QE/@H@
M("`@/'!A<F$^5&AE<F4@87)E(#,@8V]M<&]N96YT<R!T;R!E86-H(&-O;F1I
M=&EO;B!I;B!A(')U;&4N(%1H92!F:7)S="!I<R!T:&4*("`@(&9I96QD('1O
M(&5X86UI;F4N(%1H92!S96-O;F0@:7,@=&AE('1Y<&4@;V8@8V]M<&%R:7-O
M;B!T;R!P97)F;W)M+B!4:&4*("`@('1H:7)D(&ES('1H92!V86QU92!T;R!W
M:&EC:"!T:&4@9FEE;&0@<VAO=6QD(&)E(&-O;7!A<F5D+B!4:&5R92!A<F4@
M82!F97<*("`@(&1I9F9E<F5N="!T>7!E<R!O9B!C;VUP87)I<V]N<R!T:&%T
M(&-A;B!B92!P97)F;W)M960N(%1H92!C;VUP87)I<V]N<PH@("`@879A:6QA
M8FQE(&9O<B!A;GD@9VEV96X@9FEE;&0@=VEL;"!D97!E;F0@;VX@8F]T:"!T
M:&4@='EP92!O9B!T:&4@9FEE;&0@86YD"B`@("!W:&%T('1H92!U;F1E<FQY
M:6YG(&9I;'1E<FEN9R!S;V9T=V%R92!C86X@:&%N9&QE+B!4:'5S+"!A;&P@
M<&]T96YT:6%L"B`@("!M871C:&EN9R!O<'1I;VYS(&QI<W1E9"!B96QO=R!M
M87D@;F]T(&%P<&5A<B!F;W(@82!G:79E;B!F:65L9"X\+W!A<F$^"B`@("`\
M:&5A9&EN9SY#;VYT86EN<SPO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@8F4@
M8V]N<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R:6YG
M(&ES(&9O=6YD"B`@("!A;GEW:&5R92!O;B!T:&4@;&EN92X@17AA;7!L93H@
M=7-E<D!E>&%M<&QE('=O=6QD(&UA=&-H"B`@("!J;V5?=7-E<D!E>&%M<&QE
M+F-O;3PO<&%R83X*("`@(#QH96%D:6YG/D1O97-N)W0@0V]N=&%I;CPO:&5A
M9&EN9SX*("`@(#QP87)A/E=I;&P@8F4@8V]N<VED97)E9"!T;R!B92!T<G5E
M(&EF('1H92!S<&5C:69I960@<W1R:6YG(&ES(&YO="!F;W5N9`H@("`@86YY
M=VAE<F4@;VX@=&AE(&QI;F4N($5X86UP;&4Z('5S97)`97AA;7!L92!W;W5L
M9"!N;W0@;6%T8V@*("`@(&IO95]U<V5R0&5X86UP;&4N8V]M/"]P87)A/@H@
M("`@/&AE861I;F<^27,\+VAE861I;F<^"B`@("`\<&%R83Y7:6QL(&)E(&-O
M;G-I9&5R960@=&\@8F4@=')U92!I9B!T:&4@<W!E8VEF:65D('-T<FEN9R!M
M871C:&5S('1H90H@("`@;&EN92!E>&%C=&QY+B!%>&%M<&QE.B!U<V5R0&5X
M86UP;&4N8V]M(&ES('5S97)`97AA;7!L92YC;VT\+W!A<F$^"B`@("`\:&5A
M9&EN9SY)<VXG=#PO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@8F4@8V]N<VED
M97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R:6YG(&1O97,@
M;F]T(&UA=&-H"B`@("!T:&4@;&EN92!E>&%C=&QY+B!%>&%M<&QE.B!U<V5R
M0&5X86UP;&4@:7,@;F]T('5S97)`97AA;7!L92YC;VT\+W!A<F$^"B`@("`\
M:&5A9&EN9SY"96=I;G,@=VET:#PO:&5A9&EN9SX*("`@(#QP87)A/E=I;&P@
M8F4@8V]N<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C:69I960@<W1R
M:6YG(&UA=&-H97,@=&AE"B`@("!B96=I;FYI;F<@;V8@=&AE(&QI;F4N($5X
M86UP;&4Z('5S97)`97AA;7!L92!W:6QL(&UA=&-H"B`@("!U<V5R0&5X86UP
M;&4N8V]M/"]P87)A/@H@("`@/&AE861I;F<^1&]E<VXG="!B96=I;B!W:71H
M/"]H96%D:6YG/@H@("`@/'!A<F$^5VEL;"!B92!C;VYS:61E<F5D('1O(&)E
M('1R=64@:68@=&AE('-P96-I9FEE9"!S=')I;F<@9&]E<R!N;W0@;6%T8V@*
M("`@('1H92!B96=I;FYI;F<@;V8@=&AE(&QI;F4N($5X86UP;&4Z('5S97)`
M97AA;7!L92YC;VT@=VEL;"!N;W0@;6%T8V@*("`@('5S97)`97AA;7!L93PO
M<&%R83X*("`@(#QH96%D:6YG/D5N9',@=VET:#PO:&5A9&EN9SX*("`@(#QP
M87)A/E=I;&P@8F4@8V]N<VED97)E9"!T;R!B92!T<G5E(&EF('1H92!S<&5C
M:69I960@<W1R:6YG(&UA=&-H97,@=&AE(&5N9`H@("`@;V8@=&AE(&QI;F4N
M($5X86UP;&4Z(&5X86UP;&4N8V]M('=I;&P@;6%T8V@@=7-E<D!E>&%M<&QE
M+F-O;3PO<&%R83X*("`@(#QH96%D:6YG/D1O97-N)W0@96YD('=I=&@\+VAE
M861I;F<^"B`@("`\<&%R83Y7:6QL(&)E(&-O;G-I9&5R960@=&\@8F4@=')U
M92!I9B!T:&4@<W!E8VEF:65D('-T<FEN9R!D;V5S(&YO="!M871C:`H@("`@
M=&AE(&5N9"!O9B!T:&4@;&EN92X@17AA;7!L93H@:&]R9&4N;W)G('=I;&P@
M;F]T(&UA=&-H"B`@("!U<V5R0&5X86UP;&4N8V]M/"]P87)A/@H@("`@/&AE
M861I;F<^17AI<W1S/"]H96%D:6YG/@H@("`@/'!A<F$^5VEL;"!B92!C;VYS
M:61E<F5D('1O(&)E('1R=64@:68@=&AE('-P96-I9FEE9"!H96%D97(@97AI
M<W1S(&EN('1H90H@("`@;65S<V%G92P@<F5G87)D;&5S<R!O9B!W:&%T(&ET
M<R!V86QU92!I<RX\+W!A<F$^"B`@("`\:&5A9&EN9SY$;V5S;B=T($5X:7-T
M/"]H96%D:6YG/@H@("`@/'!A<F$^5VEL;"!B92!C;VYS:61E<F5D('1O(&)E
M('1R=64@:68@=&AE('-P96-I9FEE9"!H96%D97(@9&]E<R!N;W0@97AI<W0*
M("`@(&EN('1H92!M97-S86=E+CPO<&%R83X*("`@(#QH96%D:6YG/E)E9V5X
M/"]H96%D:6YG/@H@("`@/'!A<F$^4F5G97@@86QL;W=S('EO=2!T;R!U<V4@
M8V]M<&QE>"!03U-)6"!C;VUP871I8FQE(')E9W5L87(@97AP<F5S<VEO;G,*
M("`@('1O(&-O;7!A<F4@86=A:6YS="!M97-S86=E(&AE861E<G,N($5X86UP
M;&4Z(")296-E:79E9"!F<F]M(%LJ7"XJ7"XJ7"XJ72!B>0H@("`@*&AO<W1A
M?&AO<W1B*2YE>&%M<&QE+F-O;2HB('=O=6QD(&UA=&-H(")296-E:79E9"!F
M<F]M(%LQ-S(N,38N,3`P+C%=(&)Y"B`@("!H;W-T82YE>&%M<&QE+F-O;2!O
M;B!4=65S9&%Y(CPO<&%R83X*("`@(#QH96%D:6YG/DUA=&-H97,\+VAE861I
M;F<^"B`@("`\<&%R83Y-871C:&5S(&ES('-I;6EL87(@=&\@8V]N=&%I;G,L
M('=I=&@@=&AE(&5X8V5P=&EO;B!T:&%T('EO=2!M87D@=7-E("H*("`@(&%N
M9"`_(&%S('=I;&1C87)D<RX@06X@*B!W:6QL(&UA=&-H(&%N>2!N=6UB97(@
M;V8@8VAA<F%C=&5R<RP@86YD(&$@/R!W:6QL"B`@("!M871C:"!E>&%C=&QY
M(&]N92!C:&%R871E<BX@17AA;7!L93H@(BIU<V5R/T!E>&%M<&QE+F-O;2(@
M=VEL;"!M871C:"!B;W1H"B`@("`B=7-E<C%`97AA;7!L92YC;VTB(&%N9"`B
M;W1H97)U<V5R,D!E>&%M<&QE+F-O;2(\+W!A<F$^"B`@("`\:&5A9&EN9SY$
M;V5S;B=T(&UA=&-H/"]H96%D:6YG/@H@("`@/'!A<F$^1&]E<VXG="!M871C
M:"!I<R!T:&4@<V%M92!A<R!M871C:&5S(&5X8V5P="!T:&%T(&ET('=I;&P@
M979A;'5A=&4@=&\*("`@(&9A;'-E(&EF('1H92!S<&5C:69I960@=F%L=64@
M;6%T8VAE<R!T:&4@<W1R:6YG(&EN('1H92!M97-S86=E"B`@("!H96%D97(N
M/"]P87)A/@H@("`@/&AE861I;F<^3&5S<R!T:&%N/"]H96%D:6YG/@H@("`@
M/'!A<F$^5&AI<R!I<R!A(')E;&%T:6]N86P@=&5S="!W:&EC:"!W:6QL(&-O
M;7!A<F4@=&AE('9A;'5E('EO=2!S<&5C:69Y"B`@("!A;F0@=&AE('9A;'5E
M(&EN('1H92!M97-S86=E(&AE861E<B!N=6UE<FEC86QL>2X\+W!A<F$^"B`@
M("`\:&5A9&EN9SY,97-S('1H86X@;W(@97%U86P@=&\\+VAE861I;F<^"B`@
M("`\<&%R83Y4:&ES(&ES(&$@<F5L871I;VYA;"!T97-T('=H:6-H('=I;&P@
M8V]M<&%R92!T:&4@=F%L=64@>6]U('-P96-I9GD*("`@(&%N9"!T:&4@=F%L
M=64@:6X@=&AE(&UE<W-A9V4@:&5A9&5R(&YU;65R:6-A;&QY+CPO<&%R83X*
M("`@(#QH96%D:6YG/D5Q=6%L('1O/"]H96%D:6YG/@H@("`@/'!A<F$^5&AI
M<R!I<R!A(')E;&%T:6]N86P@=&5S="!W:&EC:"!W:6QL(&-O;7!A<F4@=&AE
M('9A;'5E('EO=2!S<&5C:69Y"B`@("!A;F0@=&AE('9A;'5E(&EN('1H92!M
M97-S86=E(&AE861E<B!N=6UE<FEC86QL>2X\+W!A<F$^"B`@("`\:&5A9&EN
M9SY'<F5A=&5R('1H86X@;W(@97%U86P@=&\\+VAE861I;F<^"B`@("`\<&%R
M83Y4:&ES(&ES(&$@<F5L871I;VYA;"!T97-T('=H:6-H('=I;&P@8V]M<&%R
M92!T:&4@=F%L=64@>6]U('-P96-I9GD*("`@(&%N9"!T:&4@=F%L=64@:6X@
M=&AE(&UE<W-A9V4@:&5A9&5R(&YU;65R:6-A;&QY+CPO<&%R83X*("`@(#QH
M96%D:6YG/D=R96%T97(@=&AA;CPO:&5A9&EN9SX*("`@(#QP87)A/E1H:7,@
M:7,@82!R96QA=&EO;F%L('1E<W0@=VAI8V@@=VEL;"!C;VUP87)E('1H92!V
M86QU92!Y;W4@<W!E8VEF>0H@("`@86YD('1H92!V86QU92!I;B!T:&4@;65S
M<V%G92!H96%D97(@;G5M97)I8V%L;'DN/"]P87)A/@H@(#PO96YT<GD^+2T^
M/"]E;G1R>3X*("`\96YT<GD@:60](G)U;&4M;F%M92(@;60U/2)E9#AE,V(X
M,#0T8C=E,6$V.#%B,C4Y9F$V,#5D8SEE92(@<W1A=&4](F-H86YG960B/@H@
M("`@/'1I=&QE/D9I;'1R82!L:6MU;7,Z($YO<V%U:W5M<SPO=&ET;&4^"B`@
M("`\<&%R83X*("`@($9I;'1R82!L:6MU;6$@;F]S875K=6US+B!4;R!V87(@
M;&EE=&]T+"!L86D@:61E;G1I9FECYW1U(&QI:W5M=2!F:6QT<G4@<V%R86MS
M=.(N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)R=6QE+6YA;64B/@H@("`@/'1I=&QE/D9I;'1E<B!2=6QE.B!.86UE/"]T
M:71L93X*("`@(#QP87)A/E1H:7,@:7,@82!D97-C<FEP=&EV92!N86UE(&9O
M<B!A(')U;&4N(%EO=2!M87D@=7-E(&ET('1O(&ED96YT:69Y(&$*("`@(')U
M;&4@:6X@>6]U<B!F:6QT97(@;&ES=&EN9RX\+W!A<F$^"B`@/"]E;G1R>3XM
M+3X\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<G5L92UN86UE(CX*
M("`@(#QT:71L93Y&:6QT97(@4G5L93H@3F%M93PO=&ET;&4^"B`@("`\<&%R
M83Y4:&ES(&ES(&$@9&5S8W)I<'1I=F4@;F%M92!F;W(@82!R=6QE+B!9;W4@
M;6%Y('5S92!I="!T;R!I9&5N=&EF>2!A"B`@("!R=6QE(&EN('EO=7(@9FEL
M=&5R(&QI<W1I;F<N/"]P87)A/@H@(#PO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](G)U;&4M<W1O<"(@;60U/2(P-#)F.3,U.30Q,C<U9&1F9CDR
M9#4S,C4Y,3$X83)D,B(@<W1A=&4](F-H86YG960B/@H@("`@/'1I=&QE/D9I
M;'1R82!L:6MU;7,Z($)E:6=T('#B<F)A=61I/"]T:71L93X*("`@(#QP87)A
M/@H@("`@2F$@:7(@871Z[FWG=&$@\.X@;W!C:6IA('5N(';G<W1U;&4@871B
M:6QS="#P:6T@;&EK=6UA;2P@<.)RYVII92!F:6QT<FD@;F5T:6MS('!I96QI
M971O=&DN(`H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB<G5L92US=&]P(CX*("`@(#QT:71L93Y&:6QT97(@4G5L93H@4W1O
M<"!#:&5C:VEN9SPO=&ET;&4^"B`@("`\<&%R83Y)9B!T:&ES(&]P=&EO;B!I
M<R!C:&5C:V5D+"!A;F0@82!M97-S86=E(&UA=&-H97,@=&AI<R!R=6QE+"!T
M:&4*("`@(')E;6%I;FEN9R!F:6QT97)S('=I;&P@;F]T(&)E('!R;V-E<W-E
M9"X\+W!A<F$^"B`@/"]E;G1R>3XM+3X\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB<G5L92US=&]P(CX*("`@(#QT:71L93Y&:6QT97(@4G5L93H@
M4W1O<"!#:&5C:VEN9SPO=&ET;&4^"B`@("`\<&%R83Y)9B!T:&ES(&]P=&EO
M;B!I<R!C:&5C:V5D+"!A;F0@82!M97-S86=E(&UA=&-H97,@=&AI<R!R=6QE
M+"!T:&4*("`@(')E;6%I;FEN9R!F:6QT97)S('=I;&P@;F]T(&)E('!R;V-E
M<W-E9"X\+W!A<F$^"B`@/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB=F%C871I;VXB(&UD-3TB,S,P8F(P,CEE,V4P-S,Y,F)C,6,Q,C=B8C%D
M.6(Y-&,B('-T871E/2)C:&%N9V5D(CX*("`@(#QT:71L93Y"<NYV9&EE;F%S
M/"]T:71L93X*("`@(#QH96%D:6YG/D)R[G9D:65N87,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($)R[G9D:65N=2!Z:?)A<R!I<B!A=71O;>)T:7-K:2!N
M;W/[=.YT87,@871B:6QD97,@8VEL=N=K:65M+"!K87,@:7(@<F%K<W3N:G7P
M:2!*=6US+B!4XG,@<&%R87-T:2!L:65T;RP@:F$@871R;V1A=&EE<R!I;&=S
M=&_PXB!P<F]M8OMT;N<N(`H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB=F%C871I;VXB/@H@("`@/'1I=&QE/E9A8V%T:6]N
M/"]T:71L93X*("`@(#QP87)A/E9A8V%T:6]N(&UE<W-A9V5S(&%R92!A=71O
M;6%T:6,@<F5S<&]N<V5S('-E;G0@=&\@<&5O<&QE('=H96X@=&AE>0H@("`@
M96UA:6P@>6]U+B!4:&5Y(&%R92!N;W)M86QL>2!U<V5D('=H96X@>6]U(&%R
M92!A=V%Y(&9O<B!A(&QO;F<@<&5R:6]D(&]F"B`@("!T:6UE+CPO<&%R83X*
M("`\+V5N=')Y/BTM/CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)V
M86-A=&EO;B(^"B`@("`\=&ET;&4^5F%C871I;VX\+W1I=&QE/@H@("`@/'!A
M<F$^5F%C871I;VX@;65S<V%G97,@87)E(&%U=&]M871I8R!R97-P;VYS97,@
M<V5N="!T;R!P96]P;&4@=VAE;B!T:&5Y"B`@("!E;6%I;"!Y;W4N(%1H97D@
M87)E(&YO<FUA;&QY('5S960@=VAE;B!Y;W4@87)E(&%W87D@9F]R(&$@;&]N
M9R!P97)I;V0@;V8*("`@('1I;64N/"]P87)A/@H@(#PO96YT<GD^+2T^/"]E
M;G1R>3X*("`\96YT<GD@:60](G9A8V%T:6]N+6)U;&LB(&UD-3TB83DR83=A
M8CAE8S=B93@R-F8Y,&4U-#1F938T93ED,V$B('-T871E/2)C:&%N9V5D(CX*
M("`@(#QT:71L93Y"<NYV9&EE;F%S.B!.96%T8FEL9.=T('5Z('9A:7)U;79E
M<W1U;.=M/"]T:71L93X*("`@(#QP87)A/@H@("`@T.X@;W!C:6IA(.]A=6H@
M:7IV86ER[G1I97,@;F\@0G+N=F1I96YU('!A>FGR;VIU;6$@;F]S^W3N\&%N
M=2P@:F$@=N=S='5L92!NXFL@;F\@=N=S=&MO<.)M('9A:2!A<NX@:7(@:61E
M;G1I9FECYW1A(&OB('9A:7)U;7;G<W1U;&4@*&)U;&L@;6%I;"DN"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)V86-A=&EO
M;BUB=6QK(CX*("`@(#QT:71L93Y686-A=&EO;CH@3F\@4F5S<&]N9"!T;R!"
M=6QK/"]T:71L93X*("`@(#QP87)A/D-H96-K:6YG('1H:7,@;W!T:6]N('=I
M;&P@8V%U<V4@=F%C871I;VX@<F5S<&]N<V5S('1O(&YO="!B92!S96YT('1O
M"B`@("!M97-S86=E<R!T:&%T(&%P<&5A<B!T;R!C;VUE(&9R;VT@;6%I;&EN
M9R!L:7-T<R!O<B!T:&%T(&%R92!M87)K960@87,@8G5L:PH@("`@;6%I;"X\
M+W!A<F$^"B`@/"]E;G1R>3XM+3X\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB=F%C871I;VXM8G5L:R(^"B`@("`\=&ET;&4^5F%C871I;VXZ($YO
M(%)E<W!O;F0@=&\@0G5L:SPO=&ET;&4^"B`@("`\<&%R83Y#:&5C:VEN9R!T
M:&ES(&]P=&EO;B!W:6QL(&-A=7-E('9A8V%T:6]N(')E<W!O;G-E<R!T;R!N
M;W0@8F4@<V5N="!T;PH@("`@;65S<V%G97,@=&AA="!A<'!E87(@=&\@8V]M
M92!F<F]M(&UA:6QI;F<@;&ES=',@;W(@=&AA="!A<F4@;6%R:V5D(&%S(&)U
M;&L*("`@(&UA:6PN/"]P87)A/@H@(#PO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](G9A8V%T:6]N+61A>7,B(&UD-3TB,F$R-#4R-V$R,C-D,64Q
M,S,X931F-S,Y.#(V9#)E,F(B('-T871E/2)C:&%N9V5D(CX*("`@(#QT:71L
M93Y"<NYV9&EE;F%S.B!!=&)I;&1E<R!I;G1E<G;B;',\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!.;W-A:V$L(&-I:R!D:65N87,@:N)G86ED82!L[F1Z(&%T
M:^)R=&]T82!"<NYV9&EE;G4@<&%Z:?)O:G5M82!N;W/[=.[P86YA:2!A9')E
M<^)T86TL(&MA<R!TXF1U(&IA=2!I<B!S8?+G;6ES+@H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB=F%C871I;VXM9&%Y<R(^
M"B`@("`\=&ET;&4^5F%C871I;VXZ(%)E<&QY($EN=&5R=F%L/"]T:71L93X*
M("`@(#QP87)A/E1H:7,@:7,@=&AE(&YU;6)E<B!O9B!D87ES('1O('=A:70@
M8F5F;W)E('-E;F1I;F<@86X@875T;W)E<W!O;G-E('1O"B`@("!A;B!A9&1R
M97-S('1H870@:&%S(&%L<F5A9'D@<F5C96EV960@;VYE+CPO<&%R83X*("`\
M+V5N=')Y/BTM/CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)V86-A
M=&EO;BUD87ES(CX*("`@(#QT:71L93Y686-A=&EO;CH@4F5P;'D@26YT97)V
M86P\+W1I=&QE/@H@("`@/'!A<F$^5&AI<R!I<R!T:&4@;G5M8F5R(&]F(&1A
M>7,@=&\@=V%I="!B969O<F4@<V5N9&EN9R!A;B!A=71O<F5S<&]N<V4@=&\*
M("`@(&%N(&%D9')E<W,@=&AA="!H87,@86QR96%D>2!R96-E:79E9"!O;F4N
M/"]P87)A/@H@(#PO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G9A
M8V%T:6]N+6UY96UA:6PB(&UD-3TB,C-C,3$X8C(Y8C,X,V)A-6%B9C<P,C8Y
M8V,W9#<R,C<B('-T871E/2)C:&%N9V5D(CX*("`@(#QT:71L93Y"<NYV9&EE
M;F%S.B!-86YA<R!A9')E<V5S/"]T:71L93X*("`@(#QP87)A/@H@("`@2F$@
M=7H@2OMS=2!P87-T:V%S=.YT:2!P:65NXFL@=N=S='5L97,@=F%I<N)K(&YE
M:^(@=FEE;F%I(&%D<F5S96DL(&YO<N)D:65T('3B<R#P96ET+B!0:65MYW)A
M;2P@2G5M<R!I<B!%+7!A<W1A(&%D<F5S97,@=7-E<D!S97)V97(Q+FYE="!U
M;B!U<V5R0'-E<G9E<C(N8V]M+"!K=7+B;2!A9')E<^=TXG,@=N=S='5L97,@
M<&EE;N)K(/!A:N(@<&%S=&MA<W3N=.<N"B`@("`\+W!A<F$^"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)V86-A=&EO;BUM>65M86EL(CX*("`@
M(#QT:71L93Y686-A=&EO;CH@37D@16UA:6P@061D<F5S<V5S/"]T:71L93X*
M("`@(#QP87)A/DEF('EO=2!H879E(&UO<F4@=&AA;B!O;F4@96UA:6P@861D
M<F5S<R!C;VUI;F<@=&\@=&AI<R!M86EL8F]X('1H96X*("`@('-P96-I9GD@
M=&AE;2!H97)E+CPO<&%R83X*("`\+V5N=')Y/BTM/CPA+2T@16YG;&ES:"!E
M;G1R>3H*/&5N=')Y(&ED/2)V86-A=&EO;BUM>65M86EL(CX*("`@(#QT:71L
M93Y686-A=&EO;CH@37D@16UA:6P@061D<F5S<V5S/"]T:71L93X*("`@(#QP
M87)A/DEF('EO=2!H879E(&UO<F4@=&AA;B!O;F4@96UA:6P@861D<F5S<R!C
M;VUI;F<@=&\@=&AI<R!M86EL8F]X('1H96X*("`@('-P96-I9GD@=&AE;2!H
M97)E+CPO<&%R83X*("`\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)V86-A=&EO;BUN;W)E<W!O;G-E(B!M9#4](CEE-V%C931A8C@S.31B.&0V
M93<P8F(S.3EB964T,#(R(B!S=&%T93TB8VAA;F=E9"(^"B`@("`\=&ET;&4^
M0G+N=F1I96YA<SH@3F5S^W3N=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($YE
M<_MT[G0@0G+N=F1I96YU('!A>FGR;VIU;74@\&5I="!N;W+B9.YT86II96T@
M861R97/B=&EE;2X@2V%T<G4@861R97-I(&KB;F]RXF1A(&IA=6YAXB!R:6YD
MXBX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60]
M(G9A8V%T:6]N+6YO<F5S<&]N<V4B/@H@("`@/'1I=&QE/E9A8V%T:6]N.B!.
M;R!297-P;VYS97,\+W1I=&QE/@H@("`@/'!A<F$^1&]N)W0@<V5N9"!T:&4@
M=F%C871I;VX@;65S<V%G92!T;R!T:&5S92!R96-I<&EE;G1S+B!%86-H(&%D
M9')E<W,*("`@('-H;W5L9"!B92!O;B!I=',@;W=N(&QI;F4N/"]P87)A/@H@
M(#PO96YT<GD^+2T^/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G9A
M8V%T:6]N+6YO<F5S<&]N<V4B/@H@("`@/'1I=&QE/E9A8V%T:6]N.B!.;R!2
M97-P;VYS97,\+W1I=&QE/@H@("`@/'!A<F$^1&]N)W0@<V5N9"!T:&4@=F%C
M871I;VX@;65S<V%G92!T;R!T:&5S92!R96-I<&EE;G1S+B!%86-H(&%D9')E
M<W,*("`@('-H;W5L9"!B92!O;B!I=',@;W=N(&QI;F4N/"]P87)A/@H@(#PO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G9A8V%T:6]N+7)E87-O
M;B(@;60U/2(P8SED-CDU-C,V9C0P.65B-S%C,C$W93(Y.6)F,F5D8R(@<W1A
M=&4](F-H86YG960B/@H@("`@/'1I=&QE/D)R[G9D:65N87,Z($EE;65S;',\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("#096ET(&EE=F%D[G1A:7,@=&5K<W1S
M('1I:W,@;F]S^W3N=',@2OMS=2!"<NYV9&EE;G4@<&%Z:?)O:G5MXBX*("`@
M(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G9A8V%T
M:6]N+7)E87-O;B(^"B`@("`\=&ET;&4^5F%C871I;VXZ(%9A8V%T:6]N(%)E
M87-O;CPO=&ET;&4^"B`@("`\<&%R83Y4:&ES(&ES('1H92!T97AT('1H870@
M=VEL;"!B92!S96YT(&EN('EO=7(@=F%C871I;VX@<F5S<&]N<V5S+CPO<&%R
M83X*("`\+V5N=')Y/BTM/CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)V86-A=&EO;BUR96%S;VXB/@H@("`@/'1I=&QE/E9A8V%T:6]N.B!686-A
M=&EO;B!296%S;VX\+W1I=&QE/@H@("`@/'!A<F$^5&AI<R!I<R!T:&4@=&5X
M="!T:&%T('=I;&P@8F4@<V5N="!I;B!Y;W5R('9A8V%T:6]N(')E<W!O;G-E
M<RX\+W!A<F$^"B`@/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M=F%C871I;VXM<W5B:F5C="(@;60U/2(W,S,S,C@R96-E,#5B,S`Q-3<W-3`S
M-3=A,SDY96,P.2(@<W1A=&4](F-H86YG960B/@H@("`@/'1I=&QE/D)R[G9D
M:65N87,Z(%1E;6%T<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(-!E:70@:65V
M863N=&%I<R!T96MS=',@=&EK<R!I>FUA;G1O=',@:^(@2OMS=2!"<NYV9&EE
M;G4@<&%Z:?)O:G5M82!T96UA=',N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES
M:"!E;G1R>3H*/&5N=')Y(&ED/2)V86-A=&EO;BUS=6)J96-T(CX*("`@(#QT
M:71L93Y686-A=&EO;CH@5F%C871I;VX@4W5B:F5C=#PO=&ET;&4^"B`@("`\
M<&%R83Y4:&ES(&ES('1H92!S=6)J96-T('1H870@=VEL;"!B92!U<V5D(&9O
M<B!V86-A=&EO;B!R97-P;VYS97,N/"]P87)A/@H@(#PO96YT<GD^+2T^/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G9A8V%T:6]N+7-U8FIE8W0B
M/@H@("`@/'1I=&QE/E9A8V%T:6]N.B!686-A=&EO;B!3=6)J96-T/"]T:71L
M93X*("`@(#QP87)A/E1H:7,@:7,@=&AE('-U8FIE8W0@=&AA="!W:6QL(&)E
M('5S960@9F]R('9A8V%T:6]N(')E<W!O;G-E<RX\+W!A<F$^"B`@/"]E;G1R
M>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=VAI=&5L:7-T(B!M9#4](F-B
M9&4W839E,3@U8C(Y,C8Y,S<V9#$U,30Q-C-D,C%F(B!S=&%T93TB8VAA;F=E
M9"(^"B`@("`\=&ET;&4^0F%L=&%I<R!S87)A:W-T<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY"86QT86ES('-A<F%K<W1S/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!;0F%L=&%I<R!S87)A:W-T<UT@:7(@12UP87-T82!A9')E\'4@<V%R
M86MS=',L(&YO(&MU<N)M('-A\F5M=.)S(';G<W1U;&5S($K[<R!N;W1E:6MT
M:2!VYVQA=&EE<R!R961ZYW0@<V%VXB!P87-T:V%S=.YTYR`H24Y"3U@I+B!+
M871R=2!A9')E<VD@:7(@:N)I979A9&$@871S979I\.WB(')I;F3B+@H@("`@
M/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB=VAI=&5L
M:7-T(CX*("`@(#QT:71L93Y7:&ET96QI<W0\+W1I=&QE/@H@("`@/'!A<F$^
M5&AE('=H:71E;&ES="!I<R!A(&QI<W0@;V8@*&QE9VET:6UA=&4I(&5M86EL
M(&%D9')E<W-E<R!T:&%T('EO=0H@("`@86QW87ES('=I<V@@=&\@<V5E(&EN
M('EO=7(@24Y"3U@N($5A8V@@861D<F5S<R!S:&]U;&0@8F4@96YT97)E9"!O
M;B!A"B`@("!S97!A<F%T92!L:6YE+CPO<&%R83X*("`\+V5N=')Y/BTM/CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)W:&ET96QI<W0B/@H@("`@
M/'1I=&QE/E=H:71E;&ES=#PO=&ET;&4^"B`@("`\<&%R83Y4:&4@=VAI=&5L
M:7-T(&ES(&$@;&ES="!O9B`H;&5G:71I;6%T92D@96UA:6P@861D<F5S<V5S
M('1H870@>6]U"B`@("!A;'=A>7,@=VES:"!T;R!S964@:6X@>6]U<B!)3D)/
M6"X@16%C:"!A9&1R97-S('-H;W5L9"!B92!E;G1E<F5D(&]N(&$*("`@('-E
M<&%R871E(&QI;F4N/"]P87)A/@H@(#PO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](G=H:71E;&ES="UA9&1R97-S97,B(&UD-3TB,C)F8S@S-S@X
M.&8T939B,64Y-V8X-C!E865E,C4V93DB('-T871E/2)C:&%N9V5D(CX*("`@
M(#QT:71L93X@0F%L=&%I<R!S87)A:W-T<SH@061R97-E<SPO=&ET;&4^"B`@
M("`\<&%R83X*("`@("A$87)B<R!T=7)P:6[B<RD@2V%T<F$@861R97-E(&ER
M(&KB:65V861A(&%T<V5V:?#MXB!R:6YDXBX*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G=H:71E;&ES="UA9&1R97-S97,B
M/@H@("`@/'1I=&QE/E=H:71E;&ES=#H@061D<F5S<V5S/"]T:71L93X*("`@
M(#QP87)A/E1/1$\N($5A8V@@861D<F5S<R!S:&]U;&0@8F4@96YT97)E9"!O
M;B!A('-E<&%R871E(&QI;F4N/"]P87)A/@H@(#PO96YT<GD^+2T^/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G=H:71E;&ES="UA9&1R97-S97,B
M/@H@("`@/'1I=&QE/E=H:71E;&ES=#H@061D<F5S<V5S/"]T:71L93X*("`@
M(#QP87)A/E1/1$\N($5A8V@@861D<F5S<R!S:&]U;&0@8F4@96YT97)E9"!O
M;B!A('-E<&%R871E(&QI;F4N/"]P87)A/@H@(#PO96YT<GD^+2T^/"]E;G1R
M>3X*/"]H96QP/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE+VYB7TY/+P``````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-#<`,#$W-C$U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A
M;&4O;F)?3D\O3$-?34534T%'15,O````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,C$T,#(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;F=O+VQO8V%L92]N8E].3R],0U]-15-304=%4R]I;F=O+FUO
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,S,S8W`#$P-#$W,S8R-S0W`#`R,C<P
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````/8````<````S`<``$L!``!\#P```````*@4```$````J10```,`
M``"N%```*````+(4```(````VQ0```4```#D%```(0```.H4```/````#!4`
M``@````<%0``$P```"45```'````.14```P```!!%0``!0```$X5```4````
M5!4``!\```!I%0``"````(D5```4````DA4```T```"G%0``*@```+45```R
M````X!4``!$````3%@```P```"46```+````*18```@````U%@``"0```#X6
M```.````2!8``#L```!7%@``$P```),6```5````IQ8```0```"]%@``"```
M`,(6```5````RQ8```(```#A%@``"@```.06```.````[Q8```P```#^%@``
M!P````L7```(````$Q<```<````<%P``"@```"07```I````+Q<``!$```!9
M%P```@```&L7```*````;A<```4```!Y%P``$0```'\7```0````D1<```D`
M``"B%P``$````*P7```9````O1<```<```#7%P``%0```-\7```A````]1<`
M`"4````7&```$0```#T8```4````3Q@``"\```!D&```"@```)08```(````
MGQ@```\```"H&```.@```+@8```O````\Q@``"8````C&0``"````$H9```2
M````4QD```\```!F&0``$````'89```-````AQD```0```"5&0``!P```)H9
M```%````HAD```T```"H&0``"0```+89```'````P!D```D```#(&0``"```
M`-(9```%````VQD``!````#A&0``$````/(9```/`````QH```L````3&@``
M#P```!\:```,````+QH```\````\&@``#@```$P:```&````6QH``!X```!B
M&@``(0```($:```#````HQH``!,```"G&@``&0```+L:```;````U1H```X`
M``#Q&@``"P`````;```,````#!L``!4````9&P``#0```"\;```Q````/1L`
M`!$```!O&P``!P```($;```E````B1L```<```"O&P``.0```+<;```(````
M\1L```T```#Z&P``!`````@<```,````#1P``!@````:'```!````#,<```%
M````.!P```P````^'```"@```$L<```%````5AP```H```!<'```#P```&<<
M```)````=QP``!(```"!'```$````)0<```R````I1P```(```#8'```!0``
M`-L<```'````X1P```@```#I'```"0```/(<```,````_!P```T````)'0``
M#@```!<=```6````)AT``!$````]'0``"0```$\=```5````61T``!````!O
M'0``!P```(`=```&````B!T```<```"/'0```@```)<=```$````FAT``!@`
M``"?'0``$````+@=```/````R1T```H```#9'0``!P```.0=```'````[!T`
M``0```#T'0``#@```/D=```,````"!X``"D````5'@``!````#\>```%````
M1!X```@```!*'@``!````%,>```C````6!X``!0```!\'@``%````)$>```4
M````IAX```P```"['@``!0```,@>```'````SAX```H```#6'@``$0```.$>
M```-````\QX```@````!'P``'@````H?```%````*1\``"@````O'P``*```
M`%@?```I````@1\``!,```"K'P``!P```+\?```2````QQ\``!(```#:'P``
M"P```.T?```6````^1\``!$````0(```%````"(@```$````-R````0````\
M(```"P```$$@```,````32````T```!:(```#````&@@```)````=2````0`
M``!_(```#````(0@```-````D2````8```"?(```#P```*8@```3````MB``
M`!X```#*(```!````.D@```.````[B```!0```#](```&@```!(A```7````
M+2$``!<```!%(0``&P```%TA```?````>2$``!,```"9(0``!@```*TA```3
M````M"$```0```#((0``$````,TA```7````WB$``",```#V(0``!P```!HB
M```'````(B(```4````J(@``"0```#`B```A````.B(``!P```!<(@``!0``
M`'DB```"````?R(```,```""(@``(````(8B```D````IR(``"8```#,(@``
M#````/,B```,`````",```@````-(P``!P```!8C```&````'B,```T````E
M(P``"P```#,C```5````/R,```D```!5(P``#````%\C```*````;",```(`
M``!W(P``!@```'HC``!%````@2,``#````#'(P``$````/@C```?````"20`
M``P````I)```$````#8D```/````1R0```H```!7)```&@```&(D```B````
M?20```4```"@)```"````*8D```8````KR0```@```#()```"@```-$D```"
M````W"0```4```#?)```=`$``.4D```"````6B8```4```!=)@``*````&,F
M```(````C"8```4```"5)@``(@```)LF```.````OB8```P```#-)@``"@``
M`-HF```'````Y28```L```#M)@``!0```/DF```0````_R8``!T````0)P``
M!P```"XG```3````-B<``!````!*)P``-````%LG```S````D"<``!,```#$
M)P``"@```-@G```,````XR<```<```#P)P``"P```/@G```+````!"@``#4`
M```0*```%````$8H```5````6R@```T```!Q*```"````'\H```5````B"@`
M``@```">*```#````*<H```0````M"@```H```#%*```!0```-`H```*````
MUB@```D```#A*```"@```.LH```I````]B@``!`````@*0```@```#$I```,
M````-"D```8```!!*0``$````$@I```1````62D```@```!K*0``"P```'0I
M```2````@"D```<```"3*0``%0```)LI```C````L2D``"8```#5*0``#P``
M`/PI```1````#"H``"X````>*@``#````$TJ```*````6BH```P```!E*@``
M.````'(J```P````JRH``!\```#<*@``"P```/PJ```5````""L``!,````>
M*P``%````#(K```/````1RL```<```!7*P``"@```%\K```%````:BL```X`
M``!P*P``"@```'\K```(````BBL```L```"3*P``!P```)\K```$````IRL`
M`!````"L*P``$````+TK```/````SBL```\```#>*P``#0```.XK```,````
M_"L``!`````)+```$P```!HL```*````+BP``!T````Y+```(@```%<L```#
M````>BP``!8```!^+```'````)4L```=````LBP```L```#0+```#````-PL
M```,````Z2P``!4```#V+```#`````PM```G````&2T``!(```!!+0``!@``
M`%0M```F````6RT```H```""+0``,````(TM```/````OBT``!,```#.+0``
M`P```.(M```*````YBT``!@```#Q+0``!0````HN```$````$"X```T````5
M+@``#@```",N```%````,BX```H````X+@``$````$,N```&````5"X``!,`
M``!;+@``$````&\N```\````@"X```(```"]+@``!P```,`N```(````R"X`
M``4```#1+@``#0```-<N```-````Y2X``!(```#S+@``%`````8O```;````
M&R\``!<````W+P``"@```$\O```8````6B\```T```!S+P``"````($O```(
M````BB\```<```"3+P```@```)LO```$````GB\``!H```"C+P``$P```+XO
M```0````TB\```H```#C+P``!P```.XO```)````]B\```4`````,```#P``
M``8P```/````%C```"@````F,```!````$\P```%````5#````@```!:,```
M!P```&,P```J````:S```!@```"6,```%0```*\P```:````Q3````P```#@
M,```!P```.TP```$````]3````P```#Z,```$0````<Q```*````&3$```<`
M```D,0``'0```"PQ```'````2C$``"P```!2,0``*````'\Q```H````J#$`
M`!(```#1,0``!0```.0Q```-````ZC$``!0```#X,0``"0````TR```8````
M%S(``!`````P,@``%P```$$R```%````63(```4```!?,@``#0```&4R```-
M````<S(``!````"!,@``#@```)(R```*````H3(```4```"L,@``"@```+(R
M```2````O3(```8```#0,@``$@```-<R```5````ZC(```\`````,P``!```
M`!`S```-````%3,```H````C,P``%````"XS```/````0S,``!````!3,P``
M&0```&0S```2````?C,``!,```"1,P``!@```*4S```8````K#,```D```#%
M,P``%0```,\S```5````Y3,``"D```#[,P``!````"4T```'````*C0```@`
M```R-```"0```#LT```=````130``!8```!C-```!@```'HT```#````@30`
M``,```"%-```'P```(DT```C````J30``"@```#--```#P```/8T```*````
M!C4```H````1-0``"````!PU```(````)34```T````N-0``#0```#PU```5
M````2C4```H```!@-0``#````&LU```,````>#4```(```"%-0``!0```(@U
M```\````CC4``#8```#+-0``#P````(V```=````$C8```P````P-@``$```
M`#TV```0````3C8``!,```!?-@``$@```',V```F````AC8```4```"M-@``
M!P```+,V```8````NS8```0```#4-@``$0```-DV```%````ZS8```4```#Q
M-@```0```&$````P````:@```)$``````````````(H```"E````\@```"``
M``"+````%P```'\```"N````````````````````M@```'H````N````````
M`%,```"8````\`````H`````````Z`````````!`````&@```(4`````````
M``````L``````````````#L```!D````'````'<```!>````$0```!8```!C
M````Q0```%(```#'`````````!(```!8````$````-T``````````````%P`
M```V`````````!D```#+````I`````````!+````60````````!N````#```
M`',```!=````T0```#T`````````&````",`````````````````````````
M5P```%0````````````````````.````:P```+P``````````````.$```")
M````'0````\```!0````Y@```!0`````````K````,\`````````IP```&P`
M``````````````T```#K`````````$$```"K````,P````````#:````````
M``````#?`````````&@`````````@0```+L``````````````.0`````````
MR@``````````````PP````````#E``````````````#4````N````-<```!T
M````C@```-`````Q````;P```$P```"^````]0```+\````L````EP```"4`
M```Z````Z0````````"C````XP```'$````#`````````#\````$````R0``
M````````````@@```+H````%`````````"L```!\````0@```$,```!E````
MQ@```&D`````````M````)D````\````KP```(,```"'````30```"$```"P
M``````````````#>```````````````T````!P```#X```#9````W```````
M```R````Q````(T```"F```````````````)````LP```-(`````````E@``
M`"0```#"````10```(\```!V````G@````(``````````````$D```#(````
M`````$\```#N````X````$X```#-````J````$H```#T````?@``````````
M````N0```(P````H````@```````````````MP```*$```"0````\0```+4`
M````````[P```-,````M````A@````````#J````L0```!4````?````A```
M``````!G```````````````O````]@````````!R````*@```!X`````````
MVP```-8```!@````;0```%\````U````.````,X```#M````.0```.<````F
M````E````*H```"M````H```````````````FP```%8```!'````>P```,P`
M``"I````H@```)4```"R````"````!,```!]`````````'````!X````V```
M```````B````1@``````````````6P```.(````&````9@```),```!1````
M=0```,````"=````F@```/,```"]````U0```$@```#!`````````.P````;
M````>0```(@```!B```````````````I````D@```"<```!:`````````#<`
M``"<````GP````````!$````50`````@86YD`"!O<@`E<R!-86EN=&5N86YC
M92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`#(T(&AO=7)S`$%-+U!-`$%C
M=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S<V5S.@!!8W1I=F%T92!38W)I
M<'0`061D('!A:7(`061D:71I;VYA;"!3971T:6YG<P!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!;&EA<P!!;&P@;V8@=&AE(&9O;&QO=VEN9P!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%N<W=E<F5D`$%N>2!O9B!T:&4@9F]L
M;&]W:6YG`$%P<&QY($9I;'1E<G,`07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(&1E;&5T92!T:&ES(')U;&4_`$%U=&]M871I8V%L;'D@=7!D871E('1H92!S
M8W)I<'0@869T97(@96%C:"!C:&%N9V4_`$%V86EL86)L92!F:65L9',Z`$)C
M8P!"96=I;G,@=VET:`!":7)T:&1A>0!";&%C:VQI<W0`0FQA8VML:7-T($5D
M:70`0FQA8VML:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@
M9FEL=&5R:6YG(&1R:79E<BX`0FQA8VML:7-T960@061D<F5S<P!";&%C:VQI
M<W1E9"!!9&1R97-S97,`0F]D>0!#86QE;F1A<@!#86YC96P@4')O8FQE;2!2
M97!O<G0`0V,`0V5L;"!0:&]N90!#:&%N9V5S('-A=F5D+@!#;&]S92!7:6YD
M;W<`0V]M<&%N>0!#;VYT86EN<P!#;W!Y("5S`$-O<'D@;V8@)7,`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0W)E871E(&YE
M=R!F;VQD97(`1$0`1$E304),140Z(`!$86EL>0!$96%C=&EV871E(%-C<FEP
M=`!$969A=6QT($ED96YT:71Y`$1E;&5T92`E<P!$96QE=&4@0V]N9&ET:6]N
M`$1E;&5T92!M97-S86=E(&-O;7!L971E;'D`1&5L971E9`!$96QI=F5R(&EN
M=&\@;7D@24Y"3U@`1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!C;W!Y('1O
M`$1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@<F5D:7)E8W0@=&\`1&5L:79E
M<B!T;R!F;VQD97(`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ES86)L92`E
M<P!$:7-A8FQE9`!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!N
M;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/P!$;R!?
M;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES="!M97-S86=E<P!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!T:&ES
M.@!$;V5S;B=T(&)E9VEN('=I=&@`1&]E<VXG="!C;VYT86EN`$1O97-N)W0@
M96YD('=I=&@`1&]E<VXG="!E>&ES=`!%9&ET`$5D:70@)7,`16UA:6P`16UP
M='D@<F5S=6QT+@!%;F%B;&4@)7,`16YA8FQE9`!%;F1S('=I=&@`17%U86P@
M=&\`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&ES=&EN9R!2=6QE<P!%>&ES
M=',`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`1FEL=&5R($%L;"!-97-S86=E
M<P!&:6QT97(@3VYL>2!3965N($UE<W-A9V5S`$9I;'1E<B!/;FQY(%5N<V5E
M;B!-97-S86=E<P!&:6QT97(@3W!T:6]N<P!&:6QT97(@4G5L90!&:6QT97(@
M4G5L97,`1FEL=&5R(%-C<FEP="!$:7-P;&%Y`$9I;'1E<B!?4G5L97,`1FEL
M=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D
M+@!&:6QT97(@;F]T(&9O=6YD+@!&:6QT97)S`$9O<B!A;B!I;F-O;6EN9R!M
M97-S86=E('1H870@;6%T8VAE<SH`1F]R=V%R9`!&;W)W87)D(&ES(&YO="!S
M=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`1F]R
M=V%R9',`1F]R=V%R9',@161I=`!&<F]M`$=R96%T97(@=&AA;@!'<F5A=&5R
M('1H86X@;W(@97%U86P@=&\`2&5L<`!(;U]M90!(;VUE($%D9')E<W,`2&]M
M92!0:&]N90!(;W)D90!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!);7!O
M<G1A;G0`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YE
M>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G92!D96QI=F5R
M>2X`27,`27-N)W0`3&%?>6]U=`!,86YG=6%G90!,87-T($AA;&8`3&%S="!1
M=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,97-S('1H86X`3&5S
M<R!T:&%N(&]R(&5Q=6%L('1O`$QI<W0@2&5L<"!4;W!I8W,`3&ES="U)1`!,
M;V<@:6X`3&]G(&]U=`!-30!-86EL`$UA<E]K(&UE<W-A9V4@87,@9&5L971E
M9`!-87)K(&UE<W-A9V4@87,Z`$UA=&-H:6YG(&9I96QD<P!-96YU(&UO9&4Z
M`$UE<W-A9V4`36]N=&AL>0!-;W9E`$UO=F4@4G5L92!$;W=N`$UO=F4@4G5L
M92!5<`!.7W5M8F5R(&]F(&1A>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S
M.@!.86UE`$YE=F5R`$YE=R!2=6QE`$YE=W,`3F\@8F%C:V5N9"!C;VYF:6=U
M<F5D(&9O<B!T:&ES(&AO<W0`3F\@:&5A9&5R<R!S<&5C:69I960`3F\@<V-R
M:7!T(&=E;F5R871E9"X`3F\@<W1R:6YG<R!S<&5C:69I960`3F]T(&5Q=6%L
M('1O`$YO=&5S`$]P=&EO;G,`3W)G86YI>FEN9P!/=&AE<B!);F9O<FUA=&EO
M;@!/=&AE<B!/<'1I;VYS`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE
M(&YE=R!F;VQD97(Z`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4')O8FQE;2!$97-C<FEP=&EO;@!27V5A<V]N`%)E9W5L87(@97AP
M<F5S<VEO;@!296IE8W0@=VET:"!R96%S;VX`4F5M;W9E('!A:7(`4F5T=7)N
M('1O($9I;'1E<G,@3&ES=`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@
M4G5L97,@3&ES=`!2;VQE`%)U;&4`4G5L92!#;W!I960`4G5L92!$96QE=&5D
M`%)U;&4@1&ES86)L960`4G5L92!%;F%B;&5D`%)U;&4@3F%M90!3879E`%-A
M=F4@3W!T:6]N<P!3879E(%-E='1I;F=S`%-C<FEP=`!38W)I<'0@57!D871I
M;F<`4V-R:7!T(&YO="!U<&1A=&5D+@!38W)I<'0@<W5C8V5S<V9U;&QY(&%C
M=&EV871E9"X`4V5E;@!396QE8W0@82!F:65L9`!396QE8W0@=&%R9V5T(&9O
M;&1E<@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F1E<@!3:&]W($-U<G)E;G0@
M4V-R:7!T`%-I>F4`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E
M<B!);G!U=`!3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M871C:&5S/P!3
M=6)J96-T`%-U8V-E<W,`5&%S:W,`5&5X="!/;FQY`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N`%1I=&QE`%1O`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA
M8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N
M9V5S`%5S97(@3W!T:6]N<P!5<V5R;F%M90!787)N:6YG`%=E96ML>0!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=H7VET96QI<W0@861D<F5S<V5S.@!7
M:&ET96QI<W0`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M.;R!3=6)J96-T70!;
M4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!?0FQA8VML:7-T`%]$
M96QE=&4@;65S<V%G92!C;VUP;&5T96QY`%]%;G1E<B!E86-H(&%D9')E<W,@
M;VX@82!N97<@;&EN93H`7TAE;'``7TQO9R!O=70`7TUO=F4@;65S<V%G92!T
M;R!F;VQD97(Z`%]/<'1I;VYS`%]7:&ET96QI<W0`;W(`=D-A<F0`4')O:F5C
M="U)9"U697)S:6]N.B!);F=O($@S("@Q+C`I"E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP
M,2TQ,2`Q-3HS."LP,3`P"DQA<W0M5')A;G-L871O<CH@075T;VUA=&EC86QL
M>2!G96YE<F%T960*3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO
M<F<*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A
M/2`Q*3L*`&]G`&5L;&5R`"5S('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R("T@
M0F5K<F5F=&5L<V4`,C0@=&EM97(`04TO4$T`06MS:F]N(&9O<B!S=F%R=&5L
M:7-T961E(&%D<F5S<V5R.@!!:W1I=F5R('-C<FEP=`!,96=G('1I;"!P87(`
M06YD<F4@=F%L9P!!9')E<W-E`$%D<F5S<V4@0F]K`$%L:6%S`$%L;&4@9&4@
M9OAL9V5N9&4`16X@=6QO=FQI9R!V97)D:2!V87(@;W!P9VET="X`0F5S=F%R
M=`!.;V5N(&%V(&1E(&;X;&=E;F1E`%1A(&9I;'1E<B!I(&)R=6L`17(@9'4@
M4TE+2T52('#E(&%T(&1U(/AN<VME<B#E('-L971T92!D96YN92!R96=E;&5N
M/P!!=71O;6%T:7-K(&]P<&1A=&5R('-C<FEP=&5T(&5T=&5R(&AV97(@9F]R
M86YD<FEN9S\`5&EL9VIE;F=E;&EG92!F96QT.@!";&EN9"!K;W!I`$)E9WEN
M;F5R(&UE9`!"=7)S9&%G`%-V87)T96QI<W1E`%-V87)T96QI<W1E`%-V87)T
M96QI<W1I;F<@97(@:6MK92!S=/AT=&5T(&D@9&5N;F4@9FEL=&5R(&1R:79E
M<F5N`%-V87)T96QI<W1E="!A9')E<W-E`%-V87)T96QI<W1E="!A9')E<W-E
M<@!-96QD:6YG<W1E:W-T`$MA;&5N9&5R`$%V8G)Y="!P<F]B;&5M<F%P<&]R
M=`!+;W!I('1I;`!-;V)I;'1E;&5F;VX`16YD<FEN9V5R(&QA9W)E=`!,=6MK
M('9I;F1U`$9I<FUA`$EN;F5H;VQD97(`2V]P:65R("5S`$MO<&D@878@)7,`
M2V%N(&EK:V4@Y7!N92!-86EN=&5N86YC95]487-K+6UO9'5L970@)7,`3W!P
M<F5T="!N>2!M87!P90!$1`!$96%K=&EV97)T.B``1&%G;&EG`$1E86MT:79E
M<B!S8W)I<'0`4W1A;F1A<F1I9&5N=&ET970`4VQE='0@)7,`1FIE<FX@<F5G
M96P`4VQE='0@;65L9&EN9R!H96QT`%-L971T970`3&5V97(@=&EL(&UI;B!)
M;FYB;VMS`$QE=F5R('1I;"!M:6X@26YN8F]K<R!O9R!K;W!I97(@=&EL`$QE
M=F5R('1I;"!M:6X@26YN8F]K<R!O9R!R961E<FEG97(@=&EL`$QE=F5R('1I
M;"!M87!P90!"97-K<FEV('!R;V)L96UE=`!$971A;&IE<B!H87(@8FQI='0@
M;&]G9V5T(&9O<B!A9&UI;FES=')A=&]R96XN`$1E86MT:79E<B`E<P!$96%K
M=&EV97)T`%9I<VYI;F=S=F%L9P!6:7,@9&5T86QJ97)T(&UE;&1I;F<@;N5R
M(&AV97)T(&9I;'1E<B!B;&ER('1A='0@:2!B<G5K/P!):VME('-E;F0@<F5S
M<&]N<R!T:6P@8G5L:R!E;&QE<B!L:7-T92!M96QD:6YG97(`26MK92#E<&X@
M;6%I;F5N86YC92YP:'`@9&ER96MT90!':OAR(&1E='1E.@!3;VT@:6MK92!B
M96=Y;FYE<B!M960`4V]M(&EK:V4@:6YN96AO;&1E<@!3;VT@:6MK92!S;'5T
M=&5R(&UE9`!%:W-I<W1E<F5R(&EK:V4`4F5D:6=E<@!2961I9V5R("5S`&5P
M;W-T`%1O;70@<F5S=6QT870N`$%K=&EV97(@)7,`06MT:79E<G0`4VQU='1E
M<B!M960`3&EK('-O;0!&96EL`$AV97)T(#$U+B!M:6YU='0`2'9E<G0@,S`N
M('-E:W5N9`!(=F5R="`U+B!M:6YU='0`2'9E<B!I;FYL;V=G:6YG`$AV97(@
M:&%L=G1I;64`2'9E<G0@;6EN=71T`$5K<V5M<&5L=F5R9&EE<CH`16MS:7-T
M97)E;F1E(')E9VQE<@!%:W-I<W1E<F5R`$MA;B!I:VME(&5N9')E(&EN<W1I
M;&QE:6YG97(N`%1I;&MO8FQI;F<@=&EL($Q$05`M<V5R=F5R(&9E:6QE="X`
M1F%X`$9I;'1R97(@86QL92!M96QD:6YG97(`1FEL=')E<B!B87)E(&QE<W1E
M(&UE;&1I;F=E<@!&:6QT<F5R(&)A<F4@=6QE<W1E(&UE;&1I;F=E<@!&:6QT
M97(@=F%L9P!&:6QT97)R96=L97(`1FEL=&5R<F5G;&5R`$9I;'1E<B!S8W)I
M<'0@=FES;FEN9P!&:6QT97)R96=L97(`1FEL=')E<F]M9SH@)7,@;65L9&EN
M9RAE;BD@8FQE('-L971T970N`$9I;'1E<B!I:VME(&9U;FYE=`!&:6QT97(`
M1F]R(&5N(&EN;FMO;6UE;F1E(&UE;&1I;F<@<V]M('!A<W-E<CH`5FED97)E
M<V5N9`!6:61E<F5S96YD(&5R(&EK:V4@<W3X='1E="!I('9A;&=T(&9I;'1E
M<B!D<FEV97(`5FED97)E<V5N9&EN9V5R`%9I9&5R97-E;F1I;F=S('9A;&<`
M1G)A`%-T^')R92!E;FX`4W3X<G)E(&5N;B!E;&QE<B!L:6L@<V]M`$AJ96QP
M`$AJ96T`2&IE;6UE861R97-S90!496QE9F]N(&AJ96UM90!(;W)D90!+=6X@
M:6MO;F5R`$EK;VYE<B!M960@=&5K<W0`5FEK=&EG`$EM<&]R=&5R=&4@9F5L
M=#H@)7,`26UP;W)T97)T92!F96QT.@!):VME(&5K<VES=&5R96YD92!M86EL
M8F]K<R!S<&5S:69I<V5R="!F;W(@;65L9&EN9W,@;&5V97)I;F<`17(`17(@
M:6MK90!5='-E96YD90!3<'+E:P!3:7-T92!H86QT:6UE`%-I<W1E(&MV87)T
M97(`4VES=&4@;W!P9&%T97)I;F<Z`%-I<W1E(&EN;FQO9V=I;F<Z("5S`%-I
M<W1E(&EN;FQO9V=I;F<Z("5S(&9R82`E<P!3:7-T92!I;FYL;V=G:6YG.B!!
M;&1R:0!-:6YD<F4@96YN`$UI;F1R92!E;FX@96QL97(@;&EK('-O;0!%;6YE
M<B!I($AJ96QP`$QI<W1E+4E$`$QO9V<@:6YN`$QO9V<@=70`34T`4&]S=`!-
M87)K97(@;65L9&EN9R!S;VT@<VQE='1E=`!-87)K97(@;65L9&EN9R!S;VTZ
M`%-A;7-V87)E;F1E(&9E;'0`365N>6UO9'5S.@!-96QD:6YG`$WE;F5D=&QI
M9P!&;'ET=`!&;'ET="!R96=E;"!N960`1FQY='0@<F5G96P@;W!P`$%N=&%L
M;"!D86=E<B!M96QL;VT@<W9A<B!PY2!F97)I96UE;&1I;F<`3F%V;@!!;&1R
M:0!.>2!R96=E;`!.>6AE=&5R`$EN9V5N(&)A8VME;F0@:V]N9FEG=7)E<G0@
M9F]R(&1E;FYE(&AO<W1E;@!);F=E;B!H96%D97(@<W!E<VEF:7-E<G0`26YG
M96X@<V-R:7!T(&=E;F5R97)T`$EN9V5N('-T<F5N9V5R('-P97-I9FES97)T
M`$EK:V4@;&EK('-O;0!.;W1A=&5R`%9A;&<`3W)G86YI<V5R:6YG`$%N;F5N
M(&EN9F]R;6%S:F]N`$%N9')E('9A;&<`4&%S<V]R9`!5=&;X<B!V961L:6ME
M:&]L9'-O<&5R87-J;VYE<@!496QE9F]N`%9E;FYL:6=S="!S:W)I=B!I;FX@
M;F%V;F5T('`@9&5N(&YY92!M87!P96XZ`%9E;FYL:6=S="!G:2!E="!S86UM
M96YD<F%G(&%V('!R;V)L96UE="X`5F5N;FQI<W0@<VMR:78@:6YN(&)R=6ME
M<FYA=FX@;V<@<&%S<V]R9`!0<F]B;&5M8F5S:W)I=F5L<V4`1W)U;FX`5F%N
M;&EG('5T<GEK:P!):VME(&UO='1A(&UE9"!G<G5N;@!&:F5R;B!P87(`5&EL
M8F%K92!T:6P@1FEL=&5R(&QI<W1E`%1I;&)A:V4@=&EL(%9A;&<`5&EL8F%K
M92!T:6P@4F5G96P@;&ES=&4`4F]L;&4`4F5G96P`4F5G96P@:V]P:65R=`!2
M96=E;"!S;&5T=&5T`%)E9V5L(&1E86MT:79E<G0`4F5G96P@86MT:79E<G0`
M4F5G96P@;F%V;@!,86=R90!,86=R92!686QG`$QA9W)E(&EN<W1I;&QI;F=E
M<@!38W)I<'0`4V-R:7!T(&]P<&1A=&5R:6YG`%-C<FEP="!I:VME(&]P<&1A
M=&5R=`!38W)I<'0@86MT:79E<G0`3&5S=`!696QG(&5T="!F96QT`'9E;&<@
M;6%P<&4`5F5L9R!D871O<VMI;&QE=&5G;CH`5F5L9R!D871O9F]R;6%T`%9E
M;&<@=&ED<V9O<FUA=#H`5F5L9R!T;R!S86US=F%R96YD92!F96QT+@!696QG
M(/AN<VME="!S<'+E:SH`4V5N9"!P<F]B;&5M<F%P<&]R=`!396YD97(`5FES
M('-C<FEP="!S;VT@97(@:2!B<G5K`%-T^')R96QS90!(;W!P(&]V97(@=F5D
M;&EK96AO;&0`4W!E<VEA;'1E9VYI;FYT87-T:6YG`%-T;W!P('-J96MK(&1E
M<G-O;2!D96YN92!R96=E;&5N('-T96UM97(_`$5M;F4`4W5K<V5S<P!/<'!G
M879E<@!+=6X@=&5K<W0`1&5T=&4@=&%L;&5T(&WE(';F<F4@;6EN<W0@,2X`
M1&5T=&4@;>4@=N9R92!E="!T86QL+@!4:71T96P`5&EL`%523`!+86X@:6MK
M92!K;V)L92!T:6P@4U%,<V5R=F5R96XN`$MA;B!I:VME(&QA<W1E(&1E=&9I
M;FES:F]N96X@878@)7,N`$MA;B!I:VME(&]V97)S971T92!D971T92!7;W)D
M+61O:W5M96YT970`06YG<F4@96YD<FEN9V5R`$QA9W)E(%9A;&<`0G)U:V5R
M;F%V;@!!9'9A<G-E;`!5:V5N=&QI9P!696QK;VUM96XL("5S`%9E;&MO;6UE
M;BP@)7,`2'9I=&QI<W1E=&4@861R97-S97(Z`$AV:71L:7-T970`1FER;6%A
M9')E<W-E`$9I<FUA=&5L969O;@#EY0#E<FQI9P!$=2!MY2!B97-K<FEV92!P
M<F]B;&5M970@9OAR(&1U(&MA;B!S96YD92!E;B!P<F]B;&5M<F%P<&]R="X`
M1&EN("5S('1I;&MO8FEN9R!H87(@9^5T="!U="X@5F5N;FQI9W-T(&QO9R!I
M;FX@:6=J96XN`$1I;B!I;F9O<FUA<VIO;@!$:6YE('9A;&<@:&%R(&)L:71T
M(&]P<&1A=&5R=`!;26YT970@96UN95T`6U!R;V)L96UR87!P;W)T70!;;&EN
M:F4@)7,@878@)7-=`%-V87)T96QI<W0@879S96YD97(`4VQE='0@;65L9&EN
M9R!H96QT`%-K<FEV(&EN;B!H=F5R(&%D<F5S<V4@<.4@96X@;GD@;&EN:F4Z
M`$AJ96QP`$QO9V<@=70`1FQY='0@;65L9&EN9R!T:6P@;6%P<&4Z`%9A;&<`
M2'9I=&QI<W0@879S96YD97(`96QL97(`=D-A<F0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6YG;R]L;V-A;&4O;FQ?3DPO````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,3<V,C0`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]N;%].3"],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S0W`#`R,30Q,0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O
M;&]C86QE+VYL7TY,+TQ#7TU%4U-!1T53+VEN9V\N;6\`````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`S-S`T,3$`,3`T,3<S-C(W-#<`,#(R-S`U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````)@<``!P`
M``!,.0``B0D``'QR````````H)@```X```"AF```#P```+"8```(````P)@`
M``P```#)F```!````-:8```$````VY@```,```#@F```#````.28```/````
M\9@```L````!F0``#@````V9```%````')D``"@````BF0``"@```$N9```5
M````5ID``!(```!LF0``"P```'^9```.````BYD```H```":F0``#0```*69
M```.````LYD``!$```#"F0``#0```-29```,````XID```T```#OF0``!@``
M`/V9```/````!)H``!@````4F@``#````"V:```.````.IH```X```!)F@``
M"````%B:```N````89H``!H```"0F@``,@```*N:```X````WIH``%0````7
MFP``40```&R;``!:````OIL``%<````9G```-````'&<```*````IIP```4`
M``"QG```!@```+><```1````OIP```@```#0G```"0```-F<```)````XYP`
M`"4```#MG```(````!.=```0````-)T```\```!%G0``"@```%6=```A````
M8)T```\```""G0```P```)*=```/````EIT``!0```"FG0``"0```+N=```-
M````Q9T``!(```#3G0``#P```.:=```*````]IT```\````!G@``"````!&>
M```D````&IX``!0````_G@``%@```%2>```(````:YX``!D```!TG@``$P``
M`(Z>```'````HIX```P```"JG@``+````+>>```.````Y)X```,```#SG@``
M"P```/>>```'`````Y\```<````+GP``!0```!.?```%````&9\```H````?
MGP```P```"J?```7````+I\```H```!&GP``#P```%&?```.````89\``!0`
M``!PGP``&````(6?```C````GI\```X```#"GP``%````-&?```7````YI\`
M`!<```#^GP``%P```!:@```3````+J````\```!"H```#@```%*@```?````
M8:````<```"!H```!@```(F@```(````D*````\```"9H```!@```*F@```(
M````L*````H```"YH```$P```,2@```4````V*````L```#MH```%0```/F@
M```-````#Z$``!4````=H0``!P```#.A```%````.Z$``!4```!!H0``$0``
M`%>A```,````::$``"H```!VH0``.P```*&A```)````W:$```<```#GH0``
M%````.^A```#````!*(```4````(H@``$`````ZB```)````'Z(``!,````I
MH@``.0```#VB```2````=Z(``"<```"*H@``+````+*B```J````WZ(``"4`
M```*HP``"@```#"C```&````.Z,```D```!"HP``!P```$RC```O````5*,`
M`#<```"$HP``+@```+RC``!5````ZZ,``"T```!!I```+0```&^D```M````
MG:0``$````#+I```(P````RE```C````,*4``"T```!4I0``,P```(*E```5
M````MJ4``!D```#,I0``*0```.:E```D````$*8``#(````UI@``$0```&BF
M```*````>J8```P```"%I@``"@```)*F```0````G:8``!8```"NI@``%@``
M`,6F```'````W*8```<```#DI@``%````.RF```*`````:<```@````,IP``
M"````!6G```#````'J<```L````BIP``!P```"ZG```'````-J<```8````^
MIP``!0```$6G```'````2Z<```8```!3IP``"````%JG```)````8Z<```X`
M``!MIP``.P```'RG```3````N*<``!4```#,IP``*0```.*G```.````#*@`
M``H````;J```!````":H```$````*Z@```<````PJ```"0```#BH```&````
M0J@``!$```!)J```!P```%NH```6````8Z@```0```!ZJ```"````'^H```&
M````B*@```T```"/J```!@```)VH```>````I*@``!$```##J```"````-6H
M```-````WJ@```P```#LJ```!P```/FH```#`````:D```,````%J0``%P``
M``FI```3````(:D```@````UJ0``!````#ZI```(````0ZD```@```!,J0``
M00```%6I```@````EZD```8```"XJ0``!@```+^I```5````QJD``!@```#<
MJ0``(@```/6I```N````&*H``!T```!'J@``(0```&6J``!4````AZH``"D`
M``#<J@``"@````:K```'````$:L```X````9JP``%0```"BK```.````/JL`
M``(```!-JP``"@```%"K```/````6ZL```T```!KJP``#P```'FK```-````
MB:L```D```"7JP``%````*&K```&````MJL``!@```"]JP``'0```-:K```3
M````]*L``!0````(K```!````!VL```&````(JP``%0````IK```#@```'ZL
M```$````C:P```X```"2K```!0```*&L```%````IZP``!L```"MK```&@``
M`,FL```1````Y*P``!$```#VK```'`````BM```J````):T``!````!0K0``
M(0```&&M```%````@ZT``!,```")K0``$@```)VM```*````L*T```\```"[
MK0``$0```,NM```3````W:T```P```#QK0``!@```/ZM```&````!:X``!<`
M```,K@``$0```"2N```(````-JX```4````_K@``#````$6N```0````4JX`
M``4```!CK@``#0```&FN```&````=ZX```<```!^K@``#0```(:N```'````
ME*X```L```"<K@``!P```*BN```'````L*X```D```"XK@``"@```,*N```9
M````S:X```P```#GK@``$````/2N```%````!:\``"4````+KP``$@```#&O
M```3````1*\``"L```!8KP``.P```(2O```@````P*\``#8```#AKP``"```
M`!BP```(````(;````P````JL```!@```#>P```$````/K````<```!#L```
M"@```$NP```.````5K````H```!EL```#0```'"P```>````?K```!L```"=
ML```(0```+FP```>````V[```!D```#ZL```'@```!2Q```;````,[$``"8`
M``!/L0``&P```':Q```>````DK$``!P```"QL0``)@```,ZQ```S````];$`
M`"8````IL@``*P```%"R```X````?+(``"\```"UL@``$@```.6R```I````
M^+(``!(````BLP``H@```#6S```6````V+,``",```#OLP``*````!.T```I
M````/+0``"@```!FM```'P```(^T```@````K[0``"4```#0M```(0```/:T
M```<````&+4``"8````UM0``00```%RU```,````GK4```<```"KM0``!P``
M`+.U```&````N[4```T```#"M0``$````-"U```1````X;4``!(```#SM0``
M$P````:V```2````&K8```<````MM@``!````#6V```,````.K8```X```!'
MM@``#P```%:V```3````9K8```T```!ZM@``*````(BV```#````L;8```T`
M``"UM@``!@```,.V```1````RK8``!<```#<M@``&P```/2V```.````$+<`
M``(````?MP``"@```"*W```%````+;<``!`````SMP``!````$2W```-````
M2;<```X```!7MP```P```&:W```.````:K<``!$```!YMP``"````(NW```/
M````E+<```\```"DMP``#0```+2W```0````PK<```L```#3MP``!@```-^W
M```)````YK<``!````#PMP``#`````&X```1````#K@``!D````@N```"P``
M`#JX```-````1K@``"(```!4N```&0```'>X```*````D;@``!@```"<N```
M&0```+6X```6````S[@```<```#FN```%0```.ZX```A````!+D``"4````F
MN0``$0```$RY```-````7KD```<```!LN0``%````'2Y```+````B;D``"(`
M``"5N0``+P```+BY```+````Z+D```D```#TN0``&0```/ZY```+````&+H`
M`!<````DN@``%P```#RZ```)````5+H```H```!>N@``"````&FZ```6````
M<KH```\```")N@``.@```)FZ```6````U+H```X```#KN@``&````/JZ```(
M````$[L``"\````<NP``#0```$R[```F````6KL```@```"!NP``0P```(J[
M```2````SKL```\```#ANP``$````/&[```-`````KP``"$````0O```"```
M`#*\```2````.[P```@```!.O```"P```%>\```O````8[P```X```"3O```
M!0```**\```&````J+P```,```"OO```!P```+.\```$````N[P```<```#`
MO```"@```,B\```*````T[P```\```#>O```$````.Z\```7````_[P``!$`
M```7O0``%P```"F]```)````0;T```4```!+O0``"P```%&]```*````7;T`
M``(```!HO0``!0```&N]```-````<;T``!L```!_O0``%P```)N]```)````
ML[T```X```"]O0``#0```,R]```2````VKT```D```#MO0``.````/>]```@
M````,+X```<```!1O@``"````%F^```)````8KX```X```!LO@``>P```'N^
M```8````][X```@````0OP``$0```!F_```'````*[\```4````SOP``&0``
M`#F_```'````4[\```@```!;OP``!@```&2_```&````:[\``!````!ROP``
M#P```(._```0````D[\```\```"DOP``"P```+2_```/````P+\```P```#0
MOP``#P```-V_```'````[;\```X```#UOP``!@````3````&````"\````P`
M```2P```*````!_````/````2,````@```!8P```"````&'````3````:L``
M`!X```!^P```(0```)W````@````O\```!D```#@P```%P```/K````E````
M$L$``!<````XP0``!````%#!```;````5<$```T```!QP0```P```'_!```(
M````@\$```H```",P0``#````)?!```+````I,$```0```"PP0``$P```+7!
M```4````R<$```P```#>P0``"0```.O!```.````]<$```L````$P@``&P``
M`!#"```3````+,(``!D```!`P@``&P```%K"```.````=L(```L```"%P@``
M#````)'"```5````GL(```T```"TP@``0P```,+"```Q````!L,``$(````X
MPP``1P```'O#``!/````P\,``#T````3Q```3@```%'$```1````H,0```<`
M``"RQ```!P```+K$```*````PL0```T```#-Q```"0```-O$```$````Y<0`
M``4```#JQ````P```/#$```8````],0```H````-Q0``!````!C%```E````
M'<4``"8```!#Q0``#@```&K%``!\````><4``!4```#VQ0``!0````S&```'
M````$L8```P````:Q@``"````"?&```*````,,8```8````[Q@``!P```$+&
M```Y````2L8```@```"$Q@``#0```(W&```"````F\8```8```">Q@``!@``
M`*7&```4````K,8```T```#!Q@``$````,_&```;````X,8```0```#\Q@``
M"0````''```0````"\<```D````<QP``"0```";'```%````,,<``!H````V
MQP``"````%''```&````6L<``!D```!AQP``#@```'O'```'````BL<```<`
M``"2QP``!0```)K'```)````H,<```H```"JQP```@```+7'```&````N,<`
M``T```"_QP``"0```,W'```,````U\<``!@```#DQP``!@```/W'```2````
M!,@```D````7R```!P```"'(```4````*<@``!T````^R```!@```%S(```*
M````8\@```0```!NR```"0```'/(```(````?<@``!$```"&R```"0```)C(
M```&````HL@```T```"IR```!@```+?(```$````OL@``#D```##R```/0``
M`/W(```Z````.\D``!X```!VR0``!0```)7)```.````F\D```0```"JR0``
M!@```*_)```A````MLD``!4```#8R0``!@```.[)```$````]<D``!$```#Z
MR0``!@````S*```*````$\H``"(````>R@``!````$'*```%````1LH``!T`
M``!,R@``!````&K*```,````;\H```H```!\R@``"````(?*```)````D,H`
M``4```":R@``.@```*#*```P````V\H``#4````,RP``*0```$++``!'````
M;,L``#@```"TRP``*0```.W+```_````%\P``"X```!7S```+0```(;,```?
M````M,P```\```#4S```$@```.3,```+````]\P``"8````#S0``*0```"K-
M```D````5,T``"8```!YS0``"````*#-```*````J<T```D```"TS0``!P``
M`+[-```@````QLT``"````#GS0``)@````C.```*````+\X``!D````ZS@``
M*0```%3.```6````?LX``!(```"5S@``!P```*C.```*````L,X```\```"[
MS@``$````,O.``!`````W,X``'`````=SP``9@```([/```.````]<\```D`
M```$T```"@````[0```2````&=```!,````LT```#````$#0```&````3=``
M``\```!4T```"0```&30```2````;M```!````"!T```$0```)+0```<````
MI-```",```#!T```:@```.70```/````4-$```4```!@T0``$````&;1``!#
M````=]$```D```"[T0``,@```,71```$````^-$```L```#]T0``%`````G2
M```,````'M(```P````KT@``#P```#C2```5````2-(``"D```!>T@``*@``
M`(C2```F````L](``"<```#:T@``*0````+3```J````+-,``!D```!7TP``
M0@```''3```1````M-,``!(```#&TP``$P```-G3```4````[=,```\````"
MU```%@```!+4```7````*=0``!````!!U```$0```%+4```T````9-0``!,`
M``"9U```$@```*W4```U````P-0``!0```#VU```!P````O5```,````$]4`
M`"`````@U0``%````$'5```1````5M4``!<```!HU0``'````(#5```3````
MG=4``!$```"QU0``&@```,/5```>````WM4``!H```#]U0``$0```!C6```4
M````*M8``!<````_U@``%0```%?6```)````;=8``!D```!WU@``!````)'6
M```'````EM8```(```">U@``"P```*'6```%````K=8``!$```"SU@``!@``
M`,76```&````S-8```8```#3U@``!0```-K6```'````X-8```<```#HU@``
M!0```/#6```6````]M8```8````-UP``!@```!37```$````&]<```0````@
MUP``!P```"77```.````+=<```P````\UP``#````$G7```-````5M<```H`
M``!DUP``#@```&_7```%````?M<``"@```"$UP``#@```*W7```,````O-<`
M``\```#)UP``"@```-G7```(````Y-<```D```#MUP``*P```/?7```$````
M(]@```@````HV```)@```#'8```2````6-@```\```!KV```!@```'O8```*
M````@M@```<```"-V```"````)78```@````GM@```D```"_V```#````,G8
M```-````UM@```X```#DV```%@```//8```1````"MD```8````<V0```P``
M`"/9```&````)]D``!D````NV0``!P```$C9```$````4-D```L```!5V0``
M"P```&'9```'````;=D```D```!UV0``%0```'_9```'````E=D``!8```"=
MV0``#0```+39```-````PMD```H```#0V0``$````-O9```/````[-D``!$`
M``#\V0``%P````[:```*````)MH``!$````QV@``"````$/:```$````3-H`
M``\```!1V@``.@```&':```%````G-H```P```"BV@``'@```*_:```.````
MSMH``!````#=V@``"P```.[:```,````^MH```D````'VP``!P```!';```'
M````&=L```H````AVP``"0```"S;```.````-ML``!````!%VP``&@```%;;
M```*````<=L```D```!\VP``"@```(;;```,````D=L```\```">VP``"```
M`*[;```&````M]L```<```"^VP``"P```,;;``!'````TML```T````:W```
M"0```"C<```$````,MP```,````WW```$P```#O<```3````3]P``!,```!C
MW```"@```'?<```"````@MP```0```"%W```)0```(K<```#````L-P```4`
M``"TW```*@```+K<```*````Y=P```4```#PW```!````/;<```*````^]P`
M``T````&W0``!@```!3=```(````&]T```@````DW0``!````"W=```%````
M,MT``&@````XW0``"0```*'=```,````J]T``!@```"XW0``!0```-'=```&
M````U]T``!````#>W0``&P```._=```O````"]X``!`````[W@``"@```$S>
M```;````5]X```\```!SW@``"@```(/>```)````CMX``!,```"8W@``&P``
M`*S>```8````R-X``!<```#AW@``#@```/G>``")````"-\``(D```"2WP``
M`P```!S@```'````(.````@````HX```!P```#'@```*````.>````L```!$
MX```!P```%#@``!1````6.```!````"JX```#````+O@```-````R.```!H`
M``#6X```2@```/'@```&````/.$```8```!#X0``!@```$KA```?````4>$`
M``8```!QX0``"0```'CA```8````@N$``!<```";X0``!@```+/A```-````
MNN$``"(```#(X0``)@```.OA``!7````$N(``!,```!JX@``&0```'[B```;
M````F.(``",```"TX@``$P```-CB```"````[.(```L```#OX@``"````/OB
M```-````!.,```H````2XP``!P```!WC```4````)>,```8````ZXP``"```
M`$'C```.````2N,```<```!9XP``"@```&'C```+````;.,```<```!XXP``
M#````(#C```-````C>,```P```";XP``!````*CC```)````K>,```D```"W
MXP``"@```,'C```.````S.,```P```#;XP``!P```.CC```)````\.,```<`
M``#ZXP``"@````+D```;````#>0``!(````IY```"@```#SD```)````1^0`
M`!````!1Y```!P```&+D```2````:N0``"D```!]Y```!````*?D```'````
MK.0```4```"TY```!0```+KD```+````P.0``!0```#,Y```$0```.'D```:
M````\^0``!8````.Y0``%````"7E```7````.N4``!@```!2Y0``'````&OE
M```9````B.4```<```"BY0``!0```*KE```-````L.4```P```"^Y0``"```
M`,OE```(````U.4``!<```#=Y0``"P```/7E```3`````>8```0````5Y@``
M"@```!KF```$````)>8```P````JY@``"0```#?F```%````0>8```<```!'
MY@``!0```$_F```$````5>8```(```!:Y@``.````%WF```L````EN8``",`
M``##Y@``)@```.?F```2````#N<``"D````AYP``,@```$OG```*````?N<`
M`"P```")YP``+@```+;G```S````Y><``#,````9Z```.````$WH```/````
MAN@``!@```"6Z```$````*_H```4````P.@``!,```#5Z```%````.GH```2
M````_N@``!0````1Z0``%0```";I```M````/.D``"T```!JZ0``,0```)CI
M```N````RND``"\```#YZ0``+````"GJ``!B````5NH``!,```"YZ@``"```
M`,WJ```4````UNH```@```#KZ@``%````/3J```K````">L``"$````UZP``
M&@```%?K```)````<NL``$4```!\ZP``00```,+K```$````!.P``!,````)
M[```%````!WL```.````,NP``!,```!![```&````%7L```&````;NP```D`
M``!U[```"@```'_L```/````BNP```P```":[```$````*?L```'````N.P`
M``X```#`[```!0```,_L```;````U>P```@```#Q[```!@```/KL```4````
M`>T``!$````6[0``#@```"CM```X````-^T```(```!P[0``!@```'/M```.
M````>NT```4```")[0``!P```(_M```.````E^T```8```"F[0``!````*WM
M```I````LNT``!<```#<[0``'P```/3M``!<````%.X``!0```!Q[@``/@``
M`(;N```?````Q>X``!````#E[@``!P```/;N```>````_NX```X````=[P``
M#````"SO```,````.>\``!,```!&[P``"@```%KO```=````9>\``!D```"#
M[P``!0```)WO```1````H^\```T```"U[P``$0```,/O```D````U>\``!4`
M``#Z[P``$@```!#P```.````(_```!D````R\```"````$SP```)````5?``
M``T```!?\```"@```&WP```+````>/````H```"$\```!P```(_P```(````
ME_````4```"@\```'P```*;P```&````QO```!````#-\```"````-[P```-
M````Y_````@```#U\```$@```/[P```L````$?$``!H````^\0``"0```%GQ
M```*````8_$``!4```!N\0``!0```(3Q```4````BO$```0```"?\0``$```
M`*3Q```&````M?$```<```"\\0``'@```,3Q```H````X_$```H````,\@``
M&@```!?R```4````,O(```0```!'\@``!````$SR```+````4?(```4```!=
M\@``!@```&/R```(````:O(```8```!S\@``"@```'KR```;````A?(``#0`
M``"A\@``-````-;R```@````"_,``"D````L\P``(````%;S``!!````=_,`
M`!H```"Y\P``*````-3S```H````_?,``"D````F]```(@```%#T```&````
M<_0```@```!Z]```!0```(/T```(````B?0``!D```"2]```&0```*ST```J
M````QO0``",```#Q]```+@```!7U```T````1/4```@```!Y]0``%P```(+U
M```*````FO4```<```"E]0``(0```*WU```0````S_4```X```#@]0``"P``
M`._U```'````^_4``!,````#]@``"````!?V```+````(/8```H````L]@``
M%````#?V```R````3/8```L```!_]@``!0```(OV```%````D?8``!<```"7
M]@``!P```*_V```/````M_8```0```#']@``"@```,SV```)````U_8```L`
M``#A]@``#@```.WV```%````_/8```0````"]P``#0````?W```R````%?<`
M`$4```!(]P``"````([W```+````E_<``!<```"C]P``'@```+OW```4````
MVO<```4```#O]P``$@```/7W```2````"/@``!0````;^```!P```##X```.
M````./@``"H```!'^```!@```'+X```,````>?@```T```"&^```$0```)3X
M```+````IO@``#8```"R^```"@```.GX```B````]/@```L````7^0``#P``
M`"/Y```R````,_D```D```!F^0``"P```'#Y```%````?/D```X```""^0``
M$P```)'Y```'````I?D``!8```"M^0``$0```,3Y```4````UOD```<```#K
M^0``%````//Y```8````"/H```<````A^@``!0```"GZ```,````+_H```P`
M```\^@``$@```$GZ```$````7/H```<```!A^@``"@```&GZ```+````=/H`
M``P```"`^@``#@```(WZ```.````G/H```4```"K^@``!````+'Z```+````
MMOH```P```#"^@``#0```,_Z```,````W?H```D```#J^@``!0```/3Z```N
M````^OH``"8````I^P``(P```%#[```#````=/L``!(```!X^P``!@```(O[
M```>````DOL``!@```"Q^P``)0```,K[```-````\/L```D```#^^P```P``
M``C\```'````#/P```H````4_````@```!_\```,````(OP``!4````O_```
M"P```$7\```9````4?P``"````!K_```$@```(S\```%````G_P```H```"E
M_```%0```+#\```2````QOP```P```#9_```!````.;\```'````Z_P```P`
M``#S_```#0````#]``!2````#OT``!<```!A_0``!P```'G]```&````@?T`
M``\```"(_0``$P```)C]```>````K/T``"````#+_0``!@```.S]```.````
M\_T```0````"_@``#`````?^```-````%/X```X````B_@``%0```#'^```2
M````1_X```\```!:_@``%````&K^```;````?_X``!````";_@``%````*S^
M``!I````P?X``!H````K_P``%P```$;_```G````7O\``!H```"&_P``%P``
M`*'_```;````N?\``!D```#5_P``'P```.__```3````#P`!`!,````C``$`
M"````#<``0`&````0``!``<```!'``$`"````$\``0`)````6``!`!4```!B
M``$`#0```'@``0`3````A@`!``,```":``$`1@```)X``0`_````Y0`!`#<`
M```E`0$`5P```%T!`0`>````M0$!`!\```#4`0$`+P```/0!`0`*````)`(!
M``@````O`@$`#0```#@"`0`M````1@(!``0```!T`@$`$@```'D"`0`3````
MC`(!`$\```"@`@$`)0```/`"`0`<````%@,!``L````S`P$`'P```#\#`0`=
M````7P,!`"4```!]`P$`(````*,#`0`D````Q`,!`"````#I`P$`"P````H$
M`0`'````%@0!``T````>!`$`#````"P$`0`&````.00!`#D```!`!`$`#```
M`'H$`0`'````AP0!``D```"/!`$`$P```)D$`0`)````K00!``0```"W!`$`
M$````+P$`0`(````S00!``@```#6!`$`!````-\$`0`+````Y`0!``P```#P
M!`$`$0```/T$`0`,````#P4!`!H````<!0$`#P```#<%`0`'````1P4!``T`
M``!/!0$`%````%T%`0`.````<@4!``P```"!!0$`&P```(X%`0`L````J@4!
M`!,```#7!0$`'````.L%`0`H````"`8!``8````Q!@$`!P```#@&`0`3````
M0`8!``4```!4!@$`!````%H&`0`7````7P8!``H```!W!@$`#````((&`0`)
M````CP8!``8```"9!@$`"0```*`&`0`(````J@8!``D```"S!@$`"@```+T&
M`0`1````R`8!``8```#:!@$`(P```.$&`0`.````!0<!``X````4!P$`#0``
M`",'`0`+````,0<!`!T````]!P$`"P```%L'`0`"````9P<!`!T```!J!P$`
M!P```(@'`0`&````D`<!``D```"7!P$`!P```*$'`0`[````J0<!`"@```#E
M!P$`%0````X(`0`%````)`@!``<````J"`$`"````#((`0`'````.P@!``4`
M``!#"`$`!P```$D(`0`.````40@!``D```!@"`$`!@```&H(`0`(````<0@!
M``L```!Z"`$`!P```(8(`0`(````C@@!``<```"7"`$`%@```)\(`0`)````
MM@@!``8```#`"`$`"P```,<(`0`<````TP@!`!0```#P"`$`!P````4)`0`(
M````#0D!``@````6"0$`!0```!\)`0`0````)0D!`!`````V"0$`!@```$<)
M`0`9````3@D!``H```!H"0$`'````',)`0`'````D`D!``4```"8"0$`$```
M`)X)`0`4````KPD!``L```#$"0$`#0```-`)`0`7````W@D!``0```#V"0$`
M"0```/L)`0`*````!0H!``<````0"@$``@```!@*`0`.````&PH!``@````J
M"@$`'P```#,*`0`C````4PH!`#@```!W"@$`,0```+`*`0`G````X@H!`&0`
M```*"P$`%````&\+`0!5````A`L!`#@```#:"P$`2@```!,,`0!;````7@P!
M`"@```"Z#`$`$0```.,,`0`X````]0P!`"@````N#0$`+````%<-`0`G````
MA`T!`!L```"L#0$`/@```,@-`0"I`0``!PX!`",```"Q#P$`%P```-4/`0!(
M````[0\!`(4````V$`$`,````+P0`0!!````[1`!`%L````O$0$`20```(L1
M`0`=````U1$!`!@```#S$0$`(0````P2`0`?````+A(!`"L```!.$@$`(0``
M`'H2`0`=````G!(!`!$```"Z$@$`,P```,P2`0`E`````!,!`"<````F$P$`
M'P```$X3`0`P````;A,!`&D```"?$P$`/0````D4`0!E````1Q0!`$T```"M
M%`$`*0```/L4`0`K````)14!`"\```!1%0$`+@```($5`0`P````L!4!`%0`
M``#A%0$`6@```#86`0!(````D18!`$H```#:%@$`,@```"47`0`O````6!<!
M`"P```"(%P$`+0```+47`0!Q````XQ<!`&\```!5&`$`LP```,48`0`7````
M>1D!`"4```"1&0$`,@```+<9`0`I````ZAD!`#X````4&@$`(@```%,:`0!2
M````=AH!`"4```#)&@$`"P```.\:`0"Q````^QH!`$4```"M&P$`(0```/,;
M`0`P````%1P!`"4```!&'`$`'````&P<`0`Q````B1P!``<```"['`$`!P``
M`,,<`0`$````RQP!``T```#0'`$`"P```-X<`0`.````ZAP!``L```#Y'`$`
M!0````4=`0`0````"QT!``(````<'0$`60```!\=`0`%````>1T!`!(```!_
M'0$`!````)(=`0`'````EQT!``@```"?'0$`!0```*@=`0`#````KAT!`!``
M``"R'0$`#````,,=`0`3````T!T!``T```#D'0$``@```/(=`0`'````]1T!
M``8```#]'0$`%`````0>`0`,````&1X!`!@````F'@$`!@```#\>`0`2````
M1AX!``P```!9'@$``P```&8>`0`J````:AX!``0```"5'@$`!@```)H>`0`'
M````H1X!`!\```"I'@$`-0```,D>`0`N````_QX!`"\````N'P$`%P```%X?
M`0`@````=A\!`!L```"7'P$`&````+,?`0`D````S!\!`!\```#Q'P$`&@``
M`!$@`0`@````+"`!`!H```!-(`$`,@```&@@`0`O````FR`!`"L```#+(`$`
M'P```/<@`0`C````%R$!`!\````[(0$`&@```%LA`0`E````=B$!`"8```"<
M(0$`)0```,,A`0`D````Z2$!`!@````.(@$`'0```"<B`0`D````12(!`!@`
M``!J(@$`(@```(,B`0`E````IB(!`#P```#,(@$`'P````DC`0`C````*2,!
M`!\```!-(P$`(````&TC`0`:````CB,!`!@```"I(P$`)@```,(C`0`>````
MZ2,!`"D````()`$`'@```#(D`0`)````420!``P```!;)`$`%P```&@D`0`O
M````@"0!`"0```"P)`$`!P```-4D`0`/````W20!`!0```#M)`$`#@````(E
M`0`-````$24!`"0````?)0$`!0```$0E`0`'````2B4!`"(```!2)0$`)0``
M`'4E`0`=````FR4!`!H```"Y)0$`!P```-0E`0#'````W"4!``L```"D)@$`
M%0```+`F`0`&````QB8!``D```#-)@$`"P```-<F`0`7````XR8!``8```#[
M)@$`,P````(G`0`3````-B<!`!,```!*)P$`!P```%XG`0`/````9B<!``<`
M``!V)P$`,@```'XG`0`A````L2<!`!,```#3)P$`#````.<G`0`1````]"<!
M`#(````&*`$`"````#DH`0`)````0B@!``H```!,*`$`%````%<H`0`*````
M;"@!`!T```!W*`$`"````)4H`0`-````GB@!`!````"L*`$`.@```+TH`0`?
M````^"@!``@````8*0$`&@```"$I`0`&````/"D!`!4```!#*0$`!P```%DI
M`0`(````82D!``D```!J*0$`/P```'0I`0`'````M"D!``\```"\*0$`#@``
M`,PI`0`0````VRD!``D```#L*0$`"0```/8I`0`(`````"H!`!,````)*@$`
M!P```!TJ`0`9````)2H!``H````_*@$`%P```$HJ`0`4````8BH!``H```!W
M*@$`#````((J`0`7````CRH!``0```"G*@$`*@```*PJ`0`1````URH!``<`
M``#I*@$``@```/$J`0`0````]"H!`!@````%*P$`"P```!XK`0`#````*BL!
M``@````N*P$`!@```#<K`0`'````/BL!``T```!&*P$`"P```%0K`0`4````
M8"L!`!4```!U*P$`#@```(LK`0`5````FBL!`"\```"P*P$`(````.`K`0`<
M`````2P!``P````>+`$`,0```"LL`0`)````72P!``X```!G+`$`.P```'8L
M`0`5````LBP!``4```#(+`$`$@```,XL`0`_````X2P!`!(````A+0$`"@``
M`#0M`0`&````/RT!``0```!&+0$`!````$LM`0`3````4"T!``4```!D+0$`
M!@```&HM`0`&````<2T!``0```!X+0$`#````'TM`0`*````BBT!``H```"5
M+0$`!0```*`M`0`,````IBT!``P```"S+0$`#0```,`M`0`8````SBT!`!D`
M``#G+0$`'P````$N`0`=````(2X!`!$````_+@$``@```%$N`0`$````5"X!
M``H```!9+@$`!@```&0N`0`%````:RX!``,```!Q+@$`#````'4N`0!%````
M@BX!`!H```#(+@$`-0```.,N`0`H````&2\!`%,```!"+P$`&0```)8O`0!R
M````L"\!`"`````C,`$`-0```$0P`0!%````>C`!`#````#`,`$`*````/$P
M`0`I````&C$!`"8```!$,0$`8````&LQ`0`E````S#$!`"@```#R,0$`*```
M`!LR`0`B````1#(!`#````!G,@$`$@```)@R`0`3````JS(!`!````"_,@$`
M>0```-`R`0`)````2C,!`',```!4,P$`?````,@S`0`K````130!`!<```!Q
M-`$`%@```(DT`0`/````H#0!`!\```"P-`$`'P```-`T`0`<````\#0!`%$`
M```--0$`%````%\U`0`*````=#4!``4```!_-0$`!@```(4U`0`(````C#4!
M``4```"5-0$`$@```)LU`0`,````KC4!`!````"[-0$`$P```,PU`0`=````
MX#4!``\```#^-0$`&P````XV`0`D````*C8!``\```!/-@$`"@```%\V`0`$
M````:C8!``D```!O-@$`"P```'DV`0`:````A38!`"(```"@-@$`"````,,V
M`0`'````S#8!``4```#4-@$`%````-HV`0`I````[S8!``<````9-P$`"```
M`"$W`0`/````*C<!`!@````Z-P$`%````%,W`0`(````:#<!``P```!Q-P$`
M#P```'XW`0`'````CC<!``8```"6-P$`%````)TW`0`&````LC<!``D```"Y
M-P$`"@```,,W`0`,````SC<!``,```#;-P$`"````-\W`0`$````Z#<!``H`
M``#M-P$`!P```/@W`0`%`````#@!``0````&.`$`&0````LX`0`"````)3@!
M``D````H.`$`!@```#(X`0`&````.3@!``4```!`.`$`)P```$8X`0`$````
M;C@!``\```!S.`$`$P```(,X`0`'````ES@!``(```"?.`$`!P```*(X`0`&
M````JC@!`"$```"Q.`$`!@```-,X`0`0````VC@!`!X```#K.`$`$@````HY
M`0`&````'3D!``D````D.0$`(@```"XY`0`'````43D!``<```!9.0$`"P``
M`&$Y`0`%````;3D!``(```!S.0$`"P```'8Y`0"%`0``@CD!`!,````(.P$`
M#P```!P[`0`*````+#L!``L````W.P$``P```$,[`0`$````1SL!``,```!,
M.P$`"P```%`[`0`3````7#L!``X```!P.P$`#P```'\[`0`%````CSL!`"@`
M``"5.P$`#@```+X[`0`9````S3L!``X```#G.P$`"P```/8[`0`-`````CP!
M``H````0/`$`$0```!L\`0`0````+3P!``X````^/`$`"P```$T\`0`0````
M63P!``\```!J/`$`!@```'H\`0`2````@3P!`!@```"4/`$`$````*T\`0`/
M````OCP!``\```#./`$`!P```-X\`0`N````YCP!`"@````5/0$`/@```#X]
M`0!-````?3T!`&@```#+/0$`:P```#0^`0!N````H#X!`'$````//P$`0```
M`($_`0`4````PC\!``4```#7/P$`!@```-T_`0`0````Y#\!``<```#U/P$`
M"0```/T_`0`)````!T`!`#(````10`$`,````$1``0`1````=4`!`!$```"'
M0`$`#@```)E``0`E````J$`!`!````#.0`$`"0```-]``0`5````Z4`!`!4`
M``#_0`$`#P```!5!`0`6````)4$!`!4````\00$`&P```%)!`0`/````;D$!
M`!8```!^00$`#@```)5!`0`M````I$$!`!<```#200$`&P```.I!`0`3````
M!D(!`"H````:0@$`$@```$5"`0`%````6$(!``D```!>0@$`,0```&A"`0`&
M````FD(!``P```"A0@$`"@```*Y"`0`'````N4(!``@```#!0@$`!0```,I"
M`0`)````T$(!``L```#:0@$`!````.9"`0`@````ZT(!``P````,0P$`#```
M`!E#`0`0````)D,!`!4````W0P$`&@```$U#`0`L````:$,!``H```"50P$`
M'````*!#`0`;````O4,!`"````#90P$`%P```/I#`0`6````$D0!`!,````I
M1`$`$````#U$`0`?````3D0!``<```!N1`$`!@```'9$`0`(````?40!``X`
M``"&1`$`"````)5$`0`*````GD0!``H```"I1`$`$@```+1$`0`3````QT0!
M``H```#;1`$`%0```.9$`0`1````_$0!`!@````.10$`"@```"=%`0`%````
M,D4!`!<````X10$`%@```%!%`0`+````9T4!`"\```!S10$`0@```*-%`0`*
M````YD4!``<```#Q10$`$P```/E%`0`%````#48!``4````31@$`$````!E&
M`0`+````*D8!`!4````V1@$`10```$Q&`0`1````DD8!`#(```"D1@$`,0``
M`-=&`0`N````"4<!`"\````X1P$`"@```&A'`0`(````<T<!``D```!\1P$`
M"@```(9'`0`R````D4<!`#@```#$1P$`,0```/U'`0!7````+T@!`#````"'
M2`$`,````+A(`0`P````Z4@!`$8````:20$`-````&%)`0`S````EDD!`#``
M``#*20$`-@```/M)`0`5````,DH!`!D```!(2@$`+@```&)*`0`D````D4H!
M`#<```"V2@$`$P```.Y*`0`,`````DL!``P````/2P$`"P```!Q+`0`0````
M*$L!`!@````Y2P$`'0```%)+`0`'````<$L!``<```!X2P$`%@```(!+`0`*
M````ETL!``@```"B2P$`"0```*M+`0`#````M4L!``H```"Y2P$`"P```,1+
M`0`&````T$L!``8```#72P$`!0```-Y+`0`'````Y$L!``8```#L2P$`"@``
M`/-+`0`,````_DL!`!4````+3`$`2````"%,`0`2````:DP!`!4```!]3`$`
M+````)-,`0`0````P$P!``@```#13`$`!````-I,`0`#````WTP!``<```#C
M3`$`"0```.M,`0`$````]4P!``H```#Z3`$`!@````5-`0`5````#$T!``8`
M```B30$`"````"E-`0`)````,DT!``T````\30$`"````$I-`0`A````4TT!
M`!$```!U30$`"0```(=-`0`1````D4T!``P```"C30$`!P```+!-`0`#````
MN$T!``,```"\30$`%0```,!-`0`4````UDT!``8```#K30$`!````/)-`0`(
M````]TT!``@`````3@$`4@````E.`0`F````7$X!``8```"#3@$`"````(I.
M`0`8````DTX!`"(```"L3@$`)0```,].`0`P````]4X!`"0````F3P$`*@``
M`$M/`0!Z````=D\!`#4```#Q3P$`"@```"=0`0`)````,E`!`!,````\4`$`
M%0```%!0`0`/````9E`!``(```!V4`$`#0```'E0`0`0````AU`!`!$```"8
M4`$`$````*I0`0`.````NU`!``T```#*4`$`%@```-A0`0`&````[U`!`!T`
M``#V4`$`'@```!11`0`2````,U$!`!$```!&40$`!@```%A1`0`(````7U$!
M`&$```!H40$`&````,I1`0`(````XU$!`!,```#L40$`!0````!2`0`%````
M!E(!`!X````,4@$`&P```"M2`0`3````1U(!`!<```!;4@$`$P```'-2`0`L
M````AU(!`!````"T4@$`)````,52`0`&````ZE(!`!0```#Q4@$`$0````93
M`0`-````&%,!`!(````F4P$`%@```#E3`0`3````4%,!``P```!D4P$`!@``
M`'%3`0`'````>%,!`!@```"`4P$`$0```)E3`0`(````JU,!``4```"T4P$`
M#0```+I3`0`-````R%,!``D```#64P$`"P```.!3`0`&````[%,!``@```#S
M4P$`#0```/Q3`0`)````"E0!``T````45`$`!P```")4`0`'````*E0!``D`
M```R5`$`"0```#Q4`0`;````1E0!``\```!B5`$`$P```')4`0`%````AE0!
M`"@```",5`$`$P```+54`0`4````R50!`#@```#>5`$`1P```!=5`0`B````
M7U4!`#4```""50$`!0```+A5`0`(````OE4!``T```#'50$`!@```-55`0`(
M````W%4!``L```#E50$`#````/%5`0`0````_E4!``H````/5@$`"0```!I6
M`0`=````)%8!`"(```!"5@$`(````&56`0`E````AE8!`!P```"L5@$`+0``
M`,E6`0`?````]U8!`",````75P$`'````#M7`0`?````6%<!`!X```!X5P$`
M*0```)=7`0`R````P5<!`"0```#T5P$`*P```!E8`0`W````15@!`#T```!]
M6`$`$P```+M8`0`H````SU@!`!(```#X6`$`Q`````M9`0`4````T%D!`!X`
M``#E60$`)0````1:`0`G````*EH!`",```!26@$`(@```'9:`0`A````F5H!
M`"0```"[6@$`(P```.!:`0`<````!%L!`"<````A6P$`1P```$E;`0`-````
MD5L!``0```"?6P$`"0```*1;`0`%````KEL!``T```"T6P$`#P```,);`0`0
M````TEL!``X```#C6P$`#P```/);`0`0`````EP!``<````37`$`!````!M<
M`0`,````(%P!``X````M7`$`"P```#Q<`0`2````2%P!``T```!;7`$`+@``
M`&E<`0`'````F%P!`!````"@7`$`!@```+%<`0`3````N%P!`!D```#,7`$`
M&P```.9<`0`5`````ET!``(````870$`#P```!M=`0`)````*UT!`!`````U
M70$`!0```$9=`0`/````3%T!``X```!<70$``P```&M=`0`0````;UT!`!(`
M``"`70$`"````)-=`0`1````G%T!`!4```"N70$`#P```,1=`0`4````U%T!
M``H```#I70$`"P```/1=`0`,`````%X!`!L````-7@$`$0```"E>`0`1````
M.UX!`!H```!-7@$`#0```&A>`0`/````=EX!`"D```"&7@$`%P```+!>`0`-
M````R%X!`"0```#67@$`&@```/M>`0`8````%E\!``H````O7P$`(P```#I?
M`0`H````7E\!`"P```"'7P$`$````+1?`0`+````Q5\!``H```#17P$`%@``
M`-Q?`0`,````\U\!`"0`````8`$`+0```"5@`0`,````4V`!``@```!@8`$`
M(0```&E@`0`*````BV`!`!D```"68`$`&@```+!@`0`)````RV`!``\```#5
M8`$`#0```.5@`0`5````\V`!``X````)80$`-0```!AA`0`=````3F$!``\`
M``!L80$`&0```'QA`0`(````EF$!`$8```"?80$`$````.9A`0`F````]V$!
M``@````>8@$`/0```"=B`0`/````96(!``H```!U8@$`$````(!B`0`,````
MD6(!`"0```">8@$`"````,-B`0`6````S&(!``H```#C8@$`#0```.YB`0`R
M````_&(!``\````O8P$`!0```#]C`0`&````16,!``,```!,8P$`!P```%!C
M`0`(````6&,!``L```!A8P$`#0```&UC`0`.````>V,!``X```"*8P$`$```
M`)EC`0`9````JF,!`!4```#$8P$`%P```-IC`0`)````\F,!``8```#\8P$`
M"P````-D`0`*````#V0!``(````:9`$`!@```!UD`0`+````)&0!`",````P
M9`$`%@```%1D`0`)````:V0!``T```!U9`$`#P```(-D`0`/````DV0!``L`
M``"C9`$`/@```*]D`0`F````[F0!``L````590$`"````"%E`0`+````*F4!
M``\````V90$`BP```$9E`0`>````TF4!``H```#Q90$`$@```/QE`0`'````
M#V8!``0````79@$`%P```!QF`0`'````-&8!``@````\9@$`!P```$5F`0`&
M````368!``\```!49@$`#@```&1F`0`0````<V8!``X```"$9@$`#P```)-F
M`0`,````HV8!``L```"P9@$`$0```+QF`0`)````SF8!`!````#89@$`!P``
M`.EF`0`*````\68!``X```#\9@$`+@````MG`0`+````.F<!``@```!&9P$`
M#@```$]G`0`4````7F<!`"8```!S9P$`*0```)IG`0`H````Q&<!`!T```#M
M9P$`'@````MH`0`L````*F@!`"$```!7:`$`!````'EH`0`<````?F@!``\`
M``";:`$``P```*MH`0`(````KV@!``D```"X:`$`"P```,)H`0`,````SF@!
M``0```#;:`$`'````.!H`0`>````_6@!``T````<:0$`#````"II`0`.````
M-VD!``T```!&:0$`)P```%1I`0`5````?&D!`"````"2:0$`(@```+-I`0`,
M````UFD!``L```#C:0$`#````.]I`0`4````_&D!``T````1:@$`/@```!]J
M`0`P````7FH!`#X```"/:@$`40```,YJ`0!*````(&L!`#D```!K:P$`2@``
M`*5K`0`5````\&L!``<````&;`$`!P````YL`0`,````%FP!``\````C;`$`
M%0```#-L`0`'````26P!``<```!1;`$`!````%EL`0`3````7FP!``D```!R
M;`$`!P```'QL`0`L````A&P!`#````"Q;`$`%P```.)L`0""````^FP!`!<`
M``!];0$`"P```)5M`0`'````H6T!``L```"I;0$`"````+5M`0`*````OFT!
M``8```#);0$`"@```-!M`0!&````VVT!``H````B;@$`$P```"UN`0`"````
M06X!``8```!$;@$`"0```$MN`0`9````56X!``P```!O;@$`#P```'QN`0`<
M````C&X!``,```"I;@$`!P```*UN`0`6````M6X!``H```#,;@$`#@```-=N
M`0`%````YFX!`#,```#L;@$`!@```"!O`0`&````)V\!`!@````N;P$`$0``
M`$=O`0`'````66\!``D```!A;P$`!0```&MO`0`)````<6\!``@```![;P$`
M`@```(1O`0`&````AV\!``T```".;P$`"P```)QO`0`*````J&\!`!@```"S
M;P$`"P```,QO`0`3````V&\!``D```#L;P$`!P```/9O`0`,````_F\!`!\`
M```+<`$`!P```"MP`0`*````,W`!``0````^<`$`"0```$-P`0`(````37`!
M``P```!6<`$`"@```&-P`0`&````;G`!``T```!U<`$`!@```(-P`0`$````
MBG`!`$````"/<`$`1````-!P`0!"````%7$!`"$```!8<0$`!0```'IQ`0`/
M````@'$!``4```"0<0$``P```)9Q`0`A````FG$!`!@```"\<0$`!@```-5Q
M`0`$````W'$!`!L```#A<0$`!@```/UQ`0`(````!'(!`"(````-<@$`!```
M`#!R`0`%````-7(!`!<````[<@$`!````%-R`0`-````6'(!``\```!F<@$`
M"````'9R`0`)````?W(!``4```")<@$`/0```(]R`0`V````S7(!`#L````$
M<P$`*@```$!S`0`X````:W,!`#H```"D<P$`+0```-]S`0!2````#70!`#``
M``!@=`$`.0```)%T`0`I````RW0!`!````#U=`$`&`````9U`0`,````'W4!
M`"0````L=0$`)````%%U`0`B````=G4!`"$```"9=0$`"P```+MU`0`-````
MQW4!``H```#5=0$`"0```.!U`0`B````ZG4!`"@````-=@$`*````#9V`0`(
M````7W8!`!H```!H=@$`,P```(-V`0`8````MW8!`!(```#0=@$`!P```.-V
M`0`3````ZW8!`!8```#_=@$`$````!9W`0!1````)W<!`)$```!Y=P$`A```
M``MX`0`7````D'@!``X```"H>`$`#P```+=X`0`4````QW@!`!4```#<>`$`
M$0```/)X`0`,````!'D!`!,````1>0$`"@```"5Y`0`5````,'D!`!4```!&
M>0$`#P```%QY`0`B````;'D!`"D```"/>0$`C0```+EY`0`4````1WH!``4`
M``!<>@$`%@```&)Z`0!/````>7H!``D```#)>@$`.````--Z`0`$````#'L!
M``H````1>P$`$0```!Q[`0`3````+GL!``X```!">P$`$````%%[`0`4````
M8GL!`"<```!W>P$`*0```)][`0`E````R7L!`"4```#O>P$`,````!5\`0`P
M````1GP!`!T```!W?`$`10```)5\`0`/````VWP!`!$```#K?`$`$0```/U\
M`0`3````#WT!`!(````C?0$`%0```#9]`0`7````3'T!``\```!D?0$`$0``
M`'1]`0`Y````AGT!`!T```#`?0$`%P```-Y]`0`Z````]GT!`!,````Q?@$`
M!P```$5^`0`-````37X!`"(```!;?@$`%0```'Y^`0`2````E'X!`!D```"G
M?@$`&0```,%^`0`4````VWX!`!(```#P?@$`'@````-_`0`D````(G\!`!8`
M``!'?P$`$@```%Y_`0`7````<7\!`!,```")?P$`%P```)U_`0`*````M7\!
M`"````#`?P$`!````.%_`0`'````YG\!``(```#N?P$`"@```/%_`0`'````
M_'\!`!@````$@`$`!@```!V``0`(````)(`!``<````M@`$`!@```#6``0`'
M````/(`!``<```!$@`$`!0```$R``0`4````4H`!``8```!G@`$`"````&Z`
M`0`$````=X`!``0```!\@`$`"0```(&``0`5````BX`!`!(```"A@`$`#P``
M`+2``0`0````Q(`!``H```#5@`$`$P```."``0`%````](`!`"<```#Z@`$`
M#@```"*!`0`-````,8$!`!,````_@0$`#0```%.!`0`+````88$!``X```!M
M@0$`,P```'R!`0`(````L($!``@```"Y@0$`)P```,*!`0`4````ZH$!`!$`
M``#_@0$`!P```!&"`0`)````&8(!``<````C@@$`!````"N"`0`@````,((!
M``T```!1@@$`$````%^"`0`2````<((!`!8```"#@@$`'0```)J"`0`9````
MN((!``<```#2@@$`!P```-J"`0`&````XH(!`!@```#I@@$`!P````*#`0`%
M````"H,!``H````0@P$`#@```!N#`0`'````*H,!``H````R@P$`&````#V#
M`0`'````5H,!`!T```!>@P$`#0```'R#`0`,````BH,!``P```"7@P$`$@``
M`*2#`0`,````MX,!``\```#$@P$`%P```-2#`0`-````[(,!`!````#Z@P$`
M"`````N$`0`$````%(0!`!`````9A`$`00```"J$`0`%````;(0!``P```!R
MA`$`(0```'^$`0`-````H80!`!D```"OA`$`"@```,F$`0`-````U(0!``H`
M``#BA`$`!P```.V$`0`(````]80!``X```#^A`$`"@````V%`0`1````&(4!
M`!(````JA0$`+P```#V%`0`*````;84!``@```!XA0$`"````(&%`0`,````
MBH4!`!8```"7A0$`!P```*Z%`0`)````MH4!``@```#`A0$`#````,F%`0!.
M````UH4!`!,````EA@$`"P```#F&`0`&````188!``0```!,A@$`%@```%&&
M`0`7````:(8!`!@```"`A@$`"0```)F&`0`"````HX8!``0```"FA@$`(@``
M`*N&`0`#````SH8!``4```#2A@$`,P```-B&`0`*````#(<!``4````7AP$`
M!@```!V'`0`-````)(<!``T````RAP$`!@```$"'`0`(````1X<!``D```!0
MAP$`!````%J'`0`%````7X<!`&(```!EAP$`"P```,B'`0`-````U(<!`!P`
M``#BAP$`!0```/^'`0`%````!8@!`!4````+B`$`)@```"&(`0`W````2(@!
M`!$```"`B`$`"@```)*(`0`?````G8@!`!4```"]B`$`"@```-.(`0`)````
MWH@!`!P```#HB`$`)P````6)`0`M````+8D!`"P```!;B0$`#P```(B)`0"D
M````F(D!`*(````]B@$``P```."*`0`'````Y(H!``L```#LB@$`!0```/B*
M`0`*````_HH!`!(````)BP$`!P```!R+`0!I````)(L!`!$```".BP$`"P``
M`*"+`0`*````K(L!`!\```"WBP$`30```->+`0`'````)8P!``@````MC`$`
M!@```#:,`0`?````/8P!``8```!=C`$`"0```&2,`0`M````;HP!`"P```"<
MC`$`!@```,F,`0`*````T(P!`"4```#;C`$`1`````&-`0!A````1HT!`!8`
M``"HC0$`(0```+^-`0`X````X8T!`"@````:C@$`%0```$..`0`"````68X!
M``X```!<C@$`"0```&N.`0`/````=8X!``H```"%C@$`!P```)".`0`7````
MF(X!``8```"PC@$`"````+>.`0`-````P(X!``L```#.C@$`"@```-J.`0`)
M````Y8X!``<```#OC@$`%@```/>.`0`4````#H\!`!,````CCP$`"P```#>/
M`0`,````0X\!``H```!0CP$`"P```%N/`0`>````9X\!`!P```"&CP$`"@``
M`*./`0`,````KH\!``H```"[CP$`"@```,:/`0`=````T8\!`!0```#OCP$`
M#`````20`0`,````$9`!`!(````>D`$`!0```#&0`0`E````-Y`!`"P```!=
MD`$`!````(J0`0`'````CY`!``4```"7D`$`!0```)V0`0`)````HY`!`!,`
M``"MD`$`$@```,&0`0`:````U)`!`!8```#OD`$`&`````:1`0`7````'Y$!
M`!<````WD0$`'@```$^1`0`8````;I$!``<```"'D0$`!0```(^1`0`/````
ME9$!`!````"ED0$`"P```+:1`0`,````PI$!`"$```#/D0$`#0```/&1`0`5
M````_Y$!``8````5D@$`#0```!R2`0`(````*I(!``\````SD@$`"0```$.2
M`0`%````39(!``<```!3D@$`!0```%N2`0`$````89(!``,```!FD@$`/P``
M`&J2`0`Y````JI(!`#$```#DD@$`+````!:3`0`3````0Y,!`"P```!7DP$`
M,@```(23`0`1````MY,!`#H```#)DP$`+@````24`0`S````,Y0!`#,```!G
ME`$`.P```)N4`0`2````UY0!`!H```#JE`$`%0````65`0`6````&Y4!`!T`
M```RE0$`%@```%"5`0`4````9Y4!`!4```!\E0$`&0```)*5`0`R````K)4!
M`#(```#?E0$`-0```!*6`0`S````2)8!`#0```!\E@$`,0```+&6`0!K````
MXY8!`!T```!/EP$`#@```&V7`0`4````?)<!``L```"1EP$`%````)V7`0`P
M````LI<!`"\```#CEP$`(P```!.8`0`,````-Y@!`$D```!$F`$`0@```(Z8
M`0`$````T9@!`!````#6F`$`'````.>8`0`.````!)D!`!,````3F0$`"```
M`">9`0`)````,)D!``<````ZF0$`"0```$*9`0`.````3)D!``\```!;F0$`
M%0```&N9`0`.````@9D!`!$```"0F0$`"````**9`0`<````JYD!``@```#(
MF0$`!0```-&9`0`0````UYD!``\```#HF0$`#````/B9`0`_````!9H!``(`
M``!%F@$`!@```$B:`0`.````3YH!``8```!>F@$`!P```&6:`0`0````;9H!
M``<```!^F@$`!````(::`0`Q````BYH!`!L```"]F@$`(@```-F:`0!8````
M_)H!`!@```!5FP$`2````&Z;`0`C````MYL!`!````#;FP$`!@```.R;`0`=
M````\YL!``X````1G`$`#P```""<`0`,````,)P!`!,````]G`$`"P```%&<
M`0`=````79P!`!H```![G`$`!@```):<`0`1````G9P!``T```"OG`$`#P``
M`+V<`0`F````S9P!`!D```#TG`$`$P````Z=`0`4````(IT!`"`````WG0$`
M"````%B=`0`)````89T!`!D```!KG0$`$@```(6=`0`9````F)T!``H```"R
MG0$`#````+V=`0`(````RIT!``4```#3G0$`'0```-F=`0`&````]YT!`!(`
M``#^G0$`"````!&>`0`4````&IX!``H````OG@$`$@```#J>`0`P````39X!
M`!H```!^G@$`"P```)F>`0`,````I9X!`"$```"RG@$`!P```-2>`0`6````
MW)X!``,```#SG@$`&````/>>`0`&````$)\!``<````7GP$`(0```!^?`0`Q
M````09\!``4```!SGP$`#0```'F?`0`7````AY\!``0```"?GP$`"@```*2?
M`0`,````KY\!``@```"\GP$`!@```,6?`0`(````S)\!``8```#5GP$`"@``
M`-R?`0`7````YY\!`#0```#_GP$`-````#2@`0`B````::`!`#,```",H`$`
M(````,"@`0!'````X:`!`!T````IH0$`)P```$>A`0`N````;Z$!`"P```">
MH0$`)0```,NA`0`%````\:$!``@```#WH0$`"0````"B`0`(````"J(!`"$`
M```3H@$`'````#6B`0`P````4J(!`",```"#H@$`,0```*>B`0`V````V:(!
M``D````0HP$`&````!JC`0`+````,Z,!``H````_HP$`*P```$JC`0`-````
M=J,!`!(```"$HP$`#0```)>C`0`(````I:,!`!0```"NHP$`"0```,.C`0`,
M````S:,!`!````#:HP$`&P```.NC`0`L````!Z0!``L````TI`$`!@```$"D
M`0`%````1Z0!`!T```!-I`$`!@```&ND`0`4````<J0!``4```"'I`$`"P``
M`(VD`0`*````F:0!``@```"DI`$`#@```*VD`0`*````O*0!``4```#'I`$`
M#@```,VD`0!%````W*0!`&(````BI0$`%````(6E`0`2````FJ4!`!P```"M
MI0$`(P```,JE`0`9````[J4!``4````(I@$`$P````ZF`0`2````(J8!`!0`
M```UI@$`"P```$JF`0`2````5J8!`"X```!II@$`"P```)BF`0`0````I*8!
M`!$```"UI@$`$@```,>F`0`0````VJ8!`$D```#KI@$`#````#6G`0`D````
M0J<!`!4```!GIP$`%P```'VG`0`]````E:<!`"$```#3IP$`)````/6G`0`*
M````&J@!`!`````EJ`$`$P```#:H`0`*````2J@!`!8```!5J`$`$0```&RH
M`0`5````?J@!``<```"4J`$`&````)RH`0`7````M:@!``@```#-J`$`!@``
M`-:H`0`+````W:@!``\```#IJ`$`%````/FH`0`#````#JD!``@````2J0$`
M"P```!NI`0`2````)ZD!`!,````ZJ0$`$0```$ZI`0`1````8*D!``8```!R
MJ0$`!0```'FI`0`0````?ZD!``P```"0J0$`$P```)VI`0`2````L:D!``D`
M``#$J0$`"0```,ZI`0`W````V*D!`#`````0J@$`+0```$&J`0`'````;ZH!
M`!,```!WJ@$`!@```(NJ`0`C````DJH!`!@```"VJ@$`)P```,^J`0`-````
M]ZH!``D````%JP$``P````^K`0`&````$ZL!``H````:JP$``@```"6K`0`)
M````**L!`!$````RJP$`"````$2K`0`5````3:L!`!L```!CJP$`%````'^K
M`0`%````E*L!``H```":JP$`%````*6K`0`1````NJL!``P```#,JP$`!P``
M`-FK`0`*````X:L!``X```#LJP$`%````/NK`0!=````$*P!`!H```!NK`$`
M"@```(FL`0`&````E*P!`!````";K`$`%P```*RL`0`=````Q*P!`!\```#B
MK`$`!@````*M`0`,````":T!``8````6K0$`#@```!VM`0`3````+*T!`!(`
M``!`K0$`)````%.M`0`=````>*T!`!0```"6K0$`*````*NM`0`@````U*T!
M`!0```#UK0$`$@````JN`0!T````':X!`",```"2K@$`&P```+:N`0`L````
MTJX!`"(```#_K@$`&P```"*O`0`E````/J\!`!D```!DKP$`&P```'ZO`0`9
M````FJ\!`!D```"TKP$`"P```,ZO`0`1````VJ\!``<```#LKP$`"````/2O
M`0`)````_:\!`!0````'L`$`"P```!RP`0`3````*+`!``D````\L`$`7@``
M`$:P`0!'````I;`!`#@```#ML`$`6P```":Q`0`C````@K$!`"$```"FL0$`
M,@```,BQ`0`*````^[$!``@````&L@$`$@````^R`0`_````(K(!``D```!B
ML@$`%P```&RR`0`7````A+(!`&@```"<L@$`,`````6S`0`G````-K,!`!``
M``!>LP$`(@```&^S`0`D````DK,!`"X```"WLP$`*P```.:S`0`N````$K0!
M`#$```!!M`$`$````'.T`0`%````A+0!``L```"*M`$`"@```):T`0`*````
MH;0!`"P```"LM`$`#````-FT`0`)````YK0!``P```#PM`$`%P```/VT`0`)
M````%;4!``<````?M0$`$P```">U`0`)````.[4!``@```!%M0$`!@```$ZU
M`0`+````5;4!``L```!AM0$`$````&VU`0`.````?K4!`!L```"-M0$`$```
M`*FU`0`'````NK4!`!4```#"M0$`&````-BU`0`)````\;4!``L```#[M0$`
M&@````>V`0`I````(K8!`!(```!,M@$`)0```%^V`0`G````A;8!``\```"M
MM@$`"@```+VV`0`:````R+8!``8```#CM@$`!````.JV`0`8````[[8!``X`
M```(MP$`$````!>W`0`.````*+<!``4````WMP$`"0```#VW`0`)````1[<!
M``D```!1MP$`"0```%NW`0`2````9;<!``8```!XMP$`0@```'^W`0`-````
MPK<!``4```#0MP$`"0```-:W`0`+````X+<!`!H```#LMP$`"P````>X`0`"
M````$[@!`",````6N`$`"0```#JX`0`*````1+@!``D```!/N`$`!@```%FX
M`0!$````8+@!`"H```"EN`$`&````-"X`0`&````Z;@!``P```#PN`$`"@``
M`/VX`0`-````"+D!``8````6N0$`"@```!VY`0`8````*+D!``P```!!N0$`
M#0```$ZY`0`/````7+D!``L```!LN0$`#0```'BY`0`(````AKD!``H```"/
MN0$`&````)JY`0`)````L[D!``8```"]N0$`"P```,2Y`0`8````T+D!`!P`
M``#IN0$`"@````:Z`0`,````$;H!``L````>N@$`!0```"JZ`0`2````,+H!
M`!(```!#N@$`!@```%:Z`0`;````7;H!``P```!YN@$`(0```(:Z`0`%````
MJ+H!``4```"NN@$`#@```+2Z`0`C````P[H!``L```#GN@$`#0```/.Z`0`.
M`````;L!``4````0NP$`#````!:[`0`/````([L!``X````SNP$``@```$*[
M`0`/````1;L!``@```!5NP$`*P```%Z[`0`D````BKL!`"\```"ONP$`*```
M`-^[`0`H````"+P!`%T````QO`$`$P```(^\`0!9````H[P!`#0```#]O`$`
M7@```#*]`0!;````D;T!`"8```#MO0$`&@```!2^`0`]````+[X!`#,```!M
MO@$`-P```*&^`0`U````V;X!`!X````/OP$`.P```"Z_`0#D`0``:K\!`"$`
M``!/P0$`%````''!`0!4````AL$!`((```#;P0$`0@```%["`0`_````H<(!
M`'(```#AP@$`4@```%3#`0`@````I\,!`!4```#(PP$`'0```-[#`0`=````
M_,,!`"T````:Q`$`'@```$C$`0`=````9\0!`!,```"%Q`$`.@```)G$`0`H
M````U,0!`"D```#]Q`$`&````"?%`0!`````0,4!`&D```"!Q0$`.@```.O%
M`0!C````)L8!`$P```"*Q@$`,0```-?&`0`S````"<<!`#(````]QP$`+0``
M`'#'`0`Q````GL<!`%0```#0QP$`6P```"7(`0!-````@<@!`%$```#/R`$`
M-````"')`0`N````5LD!`"X```"%R0$`+@```+3)`0"(````X\D!`(8```!L
MR@$`T````//*`0`3````Q,L!`"8```#8RP$`.0```/_+`0`L````.<P!`$@`
M``!FS`$`*P```*_,`0!,````V\P!`"`````HS0$`"@```$G-`0#!````5,T!
M`$<````6S@$`)@```%[.`0`U````A<X!`"<```"[S@$`)````./.`0`^````
M",\!``8```!'SP$`!P```$[/`0`$````5L\!``P```!;SP$`"P```&C/`0`,
M````=,\!``L```"!SP$`!0```(W/`0`0````D\\!``,```"DSP$`9P```*C/
M`0`'````$-`!`!4````8T`$`!````"[0`0`'````,]`!``8````[T`$`!0``
M`$+0`0`)````2-`!`!4```!2T`$`"P```&C0`0`2````=-`!``T```"'T`$`
M`@```)70`0`'````F-`!``<```"@T`$`$@```*C0`0`,````N]`!`!@```#(
MT`$`!@```.'0`0`.````Z-`!``P```#WT`$``P````31`0`K````"-$!``0`
M```TT0$`!P```#G1`0`(````0=$!`"L```!*T0$`1P```';1`0`Z````OM$!
M`#L```#YT0$`(@```#72`0`M````6-(!`",```"&T@$`)@```*K2`0`J````
MT=(!`"4```#\T@$`(P```"+3`0`L````1M,!`"$```!STP$`/````)73`0`Z
M````TM,!`#4````-U`$`*P```$/4`0`N````;]0!`"X```">U`$`*0```,W4
M`0`N````]]0!`"L````FU0$`,````%+5`0`N````@]4!`"D```"RU0$`*0``
M`-S5`0`S````!M8!`"0````ZU@$`+@```%_6`0`J````CM8!`$,```"YU@$`
M*0```/W6`0`L````)]<!`"P```!4UP$`+0```('7`0`G````K]<!`!T```#7
MUP$`*P```/77`0`L````(=@!`#<```!.V`$`+````(;8`0`,````L]@!`!,`
M``#`V`$`(````-38`0`Q````]=@!`"0````GV0$`"0```$S9`0`/````5MD!
M`!P```!FV0$`%````(/9`0`0````F-D!`#$```"IV0$`"````-O9`0`(````
MY-D!`",```#MV0$`)@```!':`0`G````.-H!`!\```!@V@$`"0```(#:`0#A
M````BMH!`!(```!LVP$`&@```'_;`0`)````FML!``P```"DVP$`%````+';
M`0`:````QML!``8```#AVP$`-P```.C;`0`5````(-P!`!<````VW`$`!P``
M`$[<`0`3````5MP!``L```!JW`$`/````';<`0`K````L]P!`!````#?W`$`
M$````/#<`0`5`````=T!`#0````7W0$`#@```$S=`0`/````6]T!`!````!K
MW0$`&@```'S=`0`+````E]T!`!L```"CW0$`"P```+_=`0`4````R]T!`!,`
M``#@W0$`1````/3=`0`D````.=X!``H```!>W@$`&P```&G>`0`'````A=X!
M`"<```"-W@$`!P```+7>`0`)````O=X!``D```#'W@$`.P```-'>`0`&````
M#=\!``X````4WP$`$P```"/?`0`6````-]\!``H```!.WP$`"````%G?`0`'
M````8M\!`!,```!JWP$`"P```'[?`0`<````BM\!``\```"GWP$`&````+??
M`0`6````T-\!``4```#GWP$`!P```.W?`0`7````]=\!``0````-X`$`,P``
M`!+@`0`0````1N`!``P```!7X`$``@```&3@`0`1````9^`!`"(```!YX`$`
M"P```)S@`0`#````J.`!``<```"LX`$`"0```+3@`0`&````ON`!``T```#%
MX`$`"@```-/@`0`4````WN`!`!4```#SX`$`$0````GA`0`5````&^$!`#8`
M```QX0$`'@```&CA`0`:````A^$!``L```"BX0$`,P```*[A`0`+````XN$!
M`!0```#NX0$`1P````/B`0`4````2^(!``<```!@X@$`%P```&CB`0!+````
M@.(!`!0```#,X@$`#P```.'B`0`(````\>(!``0```#ZX@$`!````/_B`0`6
M````!.,!``4````;XP$`!@```"'C`0`(````*.,!``0````QXP$`"0```#;C
M`0`.````0.,!``H```!/XP$`!0```%KC`0`,````8.,!``P```!MXP$`#0``
M`'KC`0`7````B.,!`"````"@XP$`(0```,'C`0`E````X^,!`!`````)Y`$`
M`@```!KD`0`$````'>0!``H````BY`$`"0```"WD`0`%````-^0!``(````]
MY`$`'P```$#D`0!.````8.0!`!X```"OY`$`,P```,[D`0`J`````N4!`&``
M```MY0$`$````([E`0!\````G^4!`"<````<Y@$`4P```$3F`0!2````F.8!
M`#@```#KY@$`,P```"3G`0`T````6.<!`#D```"-YP$`8P```,?G`0`X````
M*^@!`#\```!DZ`$`/P```*3H`0`M````Y.@!`#,````2Z0$`#@```$;I`0`.
M````5>D!``T```!DZ0$`@P```'+I`0`(````]ND!`(T```#_Z0$`B````(WJ
M`0`N````%NL!`!0```!%ZP$`&````%KK`0`2````<^L!`",```"&ZP$`&@``
M`*KK`0`8````Q>L!`%8```#>ZP$`%@```#7L`0`+````3.P!``4```!8[`$`
M!@```%[L`0`(````9>P!``4```!N[`$`&P```'3L`0`0````D.P!`!$```"A
M[`$`'@```+/L`0`?````TNP!`!$```#R[`$`+`````3M`0`W````,>T!``<`
M``!I[0$`#0```''M`0`$````?^T!``D```"$[0$`#@```([M`0`8````G>T!
M`"<```"V[0$`"P```-[M`0`(````ZNT!``4```#S[0$`'````/GM`0`O````
M%NX!``H```!&[@$`"0```%'N`0`/````6^X!`",```!K[@$`%@```(_N`0`'
M````INX!``@```"N[@$`$@```+?N`0`'````RNX!``H```#2[@$`%@```-WN
M`0`+````].X!``D`````[P$`#`````KO`0`)````%^\!``(````A[P$`"```
M`"3O`0`$````+>\!``D````R[P$`!@```#SO`0`$````0^\!``<```!([P$`
M%P```%#O`0`"````:.\!``L```!K[P$`!@```'?O`0`'````?N\!`!$```"&
M[P$`+0```)CO`0`$````QN\!`!,```#+[P$`%P```-_O`0`+````]^\!``(`
M```#\`$`!P````;P`0`&````#O`!`"0````5\`$`"````#KP`0`0````0_`!
M`"(```!4\`$`$@```'?P`0`'````BO`!``H```"2\`$`,@```)WP`0`'````
MT/`!``D```#8\`$`$0```.+P`0`%````]/`!``(```#Z\`$`"P```/WP`0`!
M````QP8``$(&``"0!```;`4``"8&``!M!```5`4```````#C`````````-@$
M``"Q!```N@$````````E!````````-,$```R!0``U````'X"```9`P``6@$`
M`%D%``#S````?0(``)T$``![`P``/@$`````````````K`$``((!``#F!0``
MS````#4!````````#`,``/<```"]!```E`(``$$````_!```+04``'(%``#1
M!0``<P4``)\`````````[08``-T!````````F@0```````!`!@```````)P"
M``"N!0``I0```&8"````````J@$``),!``"Z!@``[`$```````"1`P``````
M`(0&``"J````"0<```````#5!0```````+(#````````_P(``)($``#H!```
MF````($%`````````````'0"``"N!@```````*P&```_````D@$``(4!```.
M`0``A`````````#S!0``,P$``"$%``!L`0``40`````````(!0``X`8``%P!
M````````5@4```````!C`@``````````````````A04``+<&``"<`P``1P8`
M`.0&``!;!0````````8'``#O`0``3P4``*("``"]`P``9P4``/L```#N!0``
M``````````#G`@``)0$``*4"``#'!```(P0``+`%```-!@``,@(``+<$````
M`````````)L&``"1!```B````)P!``!V``````````````#/!@``_@$``($&
M````````\`$``#<$``````````````````!(!0``L`(``'`!````````````
M`*(%``#G!@``T@,``+X$``">!0````(``'$&``"`!0``B0$```````#:!@``
M)04``%,#``"T````8@4``/`#```@!@``/@8``+L%``"E`0``4@,``/X%``"?
M!0``X@0``"\%`````````````*L&``#]`P``%P$``%(```"*!0``,08`````
M``!Q`0``;0```&\%``````````````````"Z!0````````````#+!0``````
M`%0!``"6!0``FP0``%D!``````````````````!*`@``Q`(``#H"``"&!0``
M`````/H#``!&!0``6@(``$P```"U!@``^0````````!E`P``M04``"8$````
M````7`,``'(!``!R!@``YP0``+H```"V!@```````!X$``#T!@```P8`````
M````````?`$```````#K`P``_0```&<#``"L`@``D@8``*<#``#C!@``*P$`
M`/H```!.`````@8``.,#``!3`@```````)D&``#S!@``.P8``%$#``#G`0``
M]08``+P```#/````$`,``($!````````#P```'H&```(`P```````(@$``#!
M!@``(@(``%H#``#W`P``90(````````5!P``#0<``-\$``!B`P```````$L`
M`````````````&4!``"U`0``#`<`````````````%`(``%T!``##!@``O@``
M`!`"``!/!@``&08``&,$```@!P```````(H#```X`0``V0```'D%``!(`0``
M<P,``%0&````````20,``(0"```:`@``5@,``-P```"]!0``<@,``/\```#G
M!0``3`8``&`#```(`````````"T```!5`0``Y0(``'P$``#A`0```````%D`
M```N`@``F00``,H!``#V`0``8P8`````````````\`8``&8$``"K`P``NP``
M``````#S!```KP```%`%``#V!```P`````````#$`P``7````(<`````````
M.P,`````````````30(``.8$````````F@8``#<&``#B`@``G08````````@
M`@```````"@&``"R!@```````,X"``!U`@``4P0``!H$``!@`@``````````
M````````H0$``)<"``#J`P``.P$``*(&```[`@``BP,```````!A````9P8`
M`+P!````````F04``%P$``#M!0``_`,``!8#````````5P4``#@#````````
M8@(``'P%``!N`@```````((&``!B`0``T@8`````````````\`(``)L````E
M`P``-`8``,T#``"'!0``?@0``'`$````````ZP8```````!]!0```````/X$
M````````&P,```````#K`@``_P4```````#5!@``[@```-D%``!$!```````
M`,$````0`0``^`,```````"C!````````#$#``#=!```U`,``!,!```B!0``
M&`$```````!Q!````````*\&``!,!````````*$&``!'`P```````-4```"?
M!```2`0````````^````WP(`````````````*@4``'0&```\`@``````````
M````````#````*<"```>!P``!0<```````#8`0``P@```!<#````````J00`
M`)0```#8!@``%@4``.4#``"C!@``!`0``%<!````````(`,``&<$``"I!0``
M`````$$#```,!```Z0```',"``!O`0````````````"T!@``E0$``-,"````
M``````````````#I`@``F`4``/8"```0!```:P,``,@&``#:`@```````"P&
M``#D`@```````.`$``"-!@``:04``/@```"U`P``1P$``&\#``"(!@``W@(`
M`#`!````````G0$``)L"``"S!@``P0(``-H`````````D`,``%($```N````
M&`(``,0`````````,P,``&$#``!!!@``2P,``,\$``"@`P``,P```/T&```-
M````+@4``/H$``"M!@``\0```%@&```7````&0(``!<%`````````````%P"
M````````2@8``*8&``!1!0``J0$``*T````?````3P$``%T#```F!0``````
M`/4```#1````1P4`````````````0@0```````"-`P``C`,``.4`````````
M#04``#T&```(!P``Q@,``$8#`````````@<````````1!P``7P,``'`"``"9
M`@``L08``````````````````$X!```6!@``!`8``/D"``#'`@``N00``!\$
M``!9!```OP0```````!Y!@```````+0#```^`@```````%X"``#9`@``'04`
M`"L#```C!0``J`(``)T#``#2!```$@0``$<`````````K`,``"\&``#M````
M`````+T&``"Y!0``Q`8``%\$````````2P0``,P$```R!```>00``)@&``":
M!0``VP```#(!``"J!@``#P<``*`!``!;````JP$``#0!```.`@``EP``````
M``#-!0`````````````U`P``.0(``(,"```(!````@,```````!Q`P``````
M`*$%````````)P0``!@&```+!0``=P,``.(#```=`@``.0$``!L$``!``0``
M``````P&``!5````CP0```````````````````````#)!@``M`4``-X#``!=
M!0`````````````1!```V@0````````P!```S`,```````#``@``#P8``/H&
M```W`P``;0(``/0``````0``T08``!H```"N`0``%P<`````````````F`(`
M`&4$``#;`@``Y@,``!D!```#!````````"8"`````````````'$%``!L````
M&0<``"\#``"1````W`(``'($``"$`0``0@(``$4"``"G!``````````````$
M`P```````-`"``"L!0``9P````````"O`P``4@4``(L````_`0```````"<#
M````````?P8```````#1`@``.````%@%```!`P``*@8``(D$``#1`P``W@8`
M``````#]`@```````!0'````````K0,``"(````6`@``:00``&\`````````
M-@4``!(%```B`0``H00```4!``!W!```IP$```````#J!```6`,````&``#J
M!0``9`````````#B`0``_P8``$<$```#`0``%P8``&H$``#U`0``R0$``&(&
M```?`@``#`4``"<`````````2P8``,@!`````````````-P%````````I08`
M`)$"````````KP0``#8#`````````````-\%````````6`(```````#7!```
MCP8``)0#``!_!0``&````)X#``!T`P``@P$``.<``````````````&L$```A
M`0``+@0``&T&```]`P``10,``%$!````````AP8`````````````6P8``"L"
M````````LP$``*@!```U!0```````-<&``"E!```?`,``"0"``"6!@``A`,`
M`&H#``!>!@```````(,$`````````````!$%``"E`P```````(<$````````
M`````-D#``#7`@````````````#@`P``:P(```````#"`@``308``/H!``"-
M````0P$```````#2``````````8$``!3!0``X`$``"(&````````DP0``#8"
M``#`!0``?@$```````!C!0````````````#(!0``!`$``$P%``"W````(P``
M````````````G@0``/<$``##!0``>P8```T$``````````````````!``P``
M$P<``'@```!6````?0```&0!``!G`0``8`0``!T#``#.!0``^P$````````Q
M!0```````!X```!=!@``IP8``/L"``!7`@``I`$``-T"```=`0``,0```)<$
M``!=!```:0```%L$```3````M@``````````````%@0``&4&``!U!```104`
M`#D%``!?`0```````+@"``#R`@``U00````````4!@``M0(``(X#```4`P``
MK`0```````#H!0````````````!/`@```````&@!```^!````````(L%```P
M!0``)`8``%4%```8!P``S`4``+H$``!#!@``MP4``"L$````````````````
M````````L@0```````!&!@``````````````!0``?@8``#0%``##`0``]@8`
M`````````````````'L$``#N!@``(0```(H`````````&@,``!8````R!@``
M*@0`````````````@P,``.(&````````W@0``'H%``"*!````@$```````":
M`0``LP0``.0#````````*08``"P#``")`@``=@$``"P!```S`@``6@0`````
M``#H`@``H0,``/P$``!.!```MP,``-P#``"F`P````````````!8!```(0<`
M`"L%``#R!@```````$D%````````Z00``"8#```@`````08``/\$````````
MWP8`````````````````````````````3P0``%D"``!E````$P4``"T#``!_
M`@``U0(```````!)````@@(````````U````SP,``+D```"3`P``.`4``(X"
M``"@`````````#H!``!R````[`4``+L"`````````````)("````````````
M`&`%``""!0``CP```````````````````,$%``!)!```@@,``*T$````````
M9@````````"H!@```````*8!``"X!0``=P8``#<"```\!0``!0``````````
M`````````%L"```'!0``$P(``!@%``#W!@``2@$``#T!``"0`````````+\`
M````````P0,``'P"````````,P8```H&``#Y!0``P0$``(P%````````!@4`
M`'L%````````)`<``%L#``#Q!0``F`$``(\%``"6`P``O0$``(P&``"-!```
MZP4``/(!```0!P``V`(``/0!````````HP$````'``#J!@``````````````
M````W0````````"[!````````$$$``!^`P``S@,``#4$```.`P``4P8`````
M``!4`@``JP4```L'```@!```)@$``(<#```(`@``Q@```#\#``!0!```I`4`
M`%8"``#L!```@`$``!X!`````````````*<```!"`0``;0$``-L&````````
M:`````````")!0``S0$``+P$```A!```.`8```````"S`@``MP$``/L&```2
M`@``Y@```%<#``#X`0``U`$``)T%```.!P``R04``+8#```&!@``[@(``.\`
M```I!```<0(``/,#````````2@4`````````````00(```````#O`@``KP4`
M`/,!```+`````````+`#``#R````S@$``+\#`````````````*X#```F!P``
M`````.X#```H`@```````'T#``#M!````0(`````````````QP$```````".
M!@```````+`&``!!`0```````'X%````````A`0``-L#``!1`@```````(X$
M`````````P,```@&``#_`0``E@$``+4```#V!0``-0(``#(#```_!@``````
M`-L%```\`0``1`(``$4!```2!P``6@8``+(%````````:P4``$P"````````
MZ@$``(0%``#U`@``500``#D`````````I`,``"H````;````8`$`````````
M````X08``!$```#``P``5P```!`%```A`@```````$T```#*!@``;@$``+@`
M``!X`@``2`(``+@#``#4!@``2P$```````#%`0````````````"5!0``)```
M`"@!``"C`@``_@````````"?`0``=08``%<&``!V!``````````````\!@``
MNP,``*H"``"+`@``2@```,\!```%`@```````'@!``"B`0```````,L"````
M````W`$``'8"``!@!@``H@```%<$``!X!```.@4``-H%``!#!0```````%4"
M``!:!0```````)L#``#"`P```````.P#`````````````"<%````````H`(`
M`````````````````.8!```I`@``@P4```````"9`P``%`$```````".!0``
M&00``!8'````````@00``)<#``"@!@````````````#E!0````````````#%
M!0``"04``,,"``"M!0````````````#O!0``B`4```````#:`P``10``````
M```+!@``!08``%,```#+!````````"P$````````;0,``-`$````````````
M`/L$```3!````````$H$```*`@``L0```(P"``#-````FP$```````!N````
MCP,``$\```#%`````````%`#``!4````.@```/````#``0``+00``#,%``!D
M!0``M@4``!\&````````M`0``&L````P!@````````````#0`P``!P(``!(&
M````````IP4```````"@!0```````-@%``!J`````````"$&````````L@(`
M``````!8````%`4``'8&````````U@```-4#``"N!``````````````5!@``
M#0,``$X"````````NP$```X%```<!0```````,8&``#Z`@```````!P````[
M!````````'D"``!)`0``S@```,P"``!S!```.P```)<%````````60,`````
M````````%````&0#``#P!0```````(@#``!1!```PP```%8$``!6`0``X00`
M`)4$``#\`0``/P4``*0$```G!@``J0,``+T````P`P``E@```+P"```I````
M`````+D#``````````````````#;`0``[@$``+8$````````JP0`````````
M````*0,````````H!0``#0(``(@!```3!@``J0```'P```"M`@```````!4$
M``#*````G@8```````"``@``100``"8```#(!```808`````````````>0$`
M`*\"``#D`0```````"$#``"%`@``>`8``/P```"5`````````/8#``!D!@``
M``````````!1!@``H@,````````<`@``E@0``'`#``"F!```D`8```````#"
M!@``DP(``'<!``!H`@```````"\$``#Y`0````````4#``#V````!@```/D#
M``!``@``&P$``/X#``!N!0````````````"%!```^08```````"/`0``````
M````````````8P,``/0"```Q!```9P(`````````````U@(``%T```"!`P``
M"08```````!#`@``=P4```<`````````:0(``#$"```/`P``G0````L#```S
M!``````````````H````-`(````````:!@``0@4``%4#``"?!@``C`$``.L`
M````````X0(``$`$```1`0``D08``,($```#!P``Q@0``$D&```2`P``````
M`$D"```8`P``D@,```````!Y````U`0```L$``"D`@```0$``$0#``"K`@``
M.0,``-X```"2!0``A08``&D!``!#!````````*@#``````````````````!+
M`@```P```*0`````````7@,``.,%``"Y!@``#P$``*L`````````````````
M``!4`P``A@8`````````````!`(``%`!``"5`@``$``````````Z`P``;@8`
M`(@"``#U`P``80$``'4!``"C!0``?P``````````````'P,``)0!``"<!@``
M)08``)\#``!8`0``U@$``"\!````````E`8``)P$``#I`0```````+$!``#0
M`0``:P$```````![`@``J@4``$0%``!>````P00`````````````<P$``,D"
M``#,`0````````T!``!F`0``"0```,8%``#R!0``AP$``)`"````````\@,`
M`,<#```J`P``804``(L$````````)P$```````!$````?P$``/4%````````
MR00``.X$``#^`@``^P4```````"I`@```````)L%```.!```%`0``+`!``"Q
M`@``(`4```($``#A`P``>P````H``````````````)D```!$`0``#P0`````
M``",````9`(``.D#``"J`P``R0,``#P```#U!```+@8```````!M!0``````
M`'D#``!F`P``>@,``"('````````"0,``/($``"+`0```````/@&````````
MXP(``%8&``"``P```````*@```"N````TP$```````!<!@``'P$```````"_
M`0```````.D%````````@`````````"M`0```````"4`````````R`,``'`%
M```N`P````,``'T$```P`@`````````````W`0```````!D```#O`P``_`8`
M`(8!``")````=@4``"\`````````4@$````````'`0``@@0``,0$````````
M>@````````!X!0``A@,``-\!``#E!```X0```","```%!0``/@4``)4#``!V
M`P``TP,``$4&``#>`0```````!P&```<`0``B08``-$$```:`0``N@,``%D&
M``#W!0````````$$``#Q!@``-P```+8"``!,`0``<P```!8!```]````,```
M`$T#``#;!```-`0``+$%``#F!@``````````````````;`,``-````!*`P``
MO`8``,T$```$````(@0``,(!``#T!0``>@0```````#I!@``BP8``)(````=
M!```@@```%X$```9!0```````-<!```2`0``F@,```````#=`P``?`8`````
M``!X`P``8````+(````?!P````````````````````````````#X!0``@`8`
M````````````A@(``+@&`````````````'````#+`P``:`,``#D&``#9`0``
M.P4`````````````W`0``+,%``!L!````````-D&````````PP0``&H"``#B
M````508```````#7````@0(``(X```!E!0``4@(``+X#````````_P,``&L&
M`````````````'H!```&`@``C0$```8#``#X!```'0<``!P'``">`0``````
M`*@%``"3!@``O@(``.L!```M`@``(P8``#$!``"C`P``8@```-\````=!@``
M```````````I!0``/00```````#4`@``E`4``*D&``#M`P``+`4`````````
M````0@```&P"``"Q`P```````.L$``!?````OP8``+T"``#]!```````````
M``#&`0``;P0``.$%``#9!```]P(``'L!```R``````````D"````````O@4`
M`+,````8!````````*0&```E!P``T@(``*4%````````Z`8```````#*`P``
MF`,```````"X`0``LP,``(T%````````$0(``!4!``#-!@``1@$````````B
M`P```````"P`````````7@$``"L&`````````````#T"````````2P4``$@#
M```&`0``2`8``'0!``!T````;`8``&D&``#$`0````````4$``!-`0``B@8`
M``H$``#'````_@8``&\&``##`P``Q0,``(\"``"F````:`0``.@!```5`@``
MT`8``&$"``#Y!```[P0`````````````OP4```````"X!```E@(```````"=
M`@``Y0$``(D#```J`0``1@```#<%``#Z!0``UP4``%`&``#`!@```````.T"
M``#6!@```@(``,<%``#6!0``%04``!P#``"Y`@``3@4``(`$````````R@(`
M`.T!``!C`````````+4$````````K`````,"``#=!0``%0````````!:````
M`````'<"````````'P4```````!N!```U@,````````^`P```````+<"````
M````B@$```````#2!0```````'0$```)`0``+0$``#T%````````L`0``(,&
M````````]`0``-\#````````#@````$%``#*!0``KP$````````;`@``F@(`
M`#8```"0!0``.`0``%X%````````5`0``"L```",!````````+P%``#"!0``
MS0(``)$%````````4P$```H'```````````````$``"4!```9`0```````#8
M`P``.@8``!X%``"P``````````````#3!@``7`4``"4"```1`P``?08`````
M``#,!@````````\%``#W`0``H`0````````G`@````````P"``"A`@``@0``
M```````V`0``````````````````"@$```0'``!-!````````&($``#J````
M`````.H"``#C!```304``),%``!(````_`(`````````````Y`4```<&````
M`````````)4&```D!0``0````$$%``#E!@``W08``#8$``"?`@``#`$``',&
M``#X`@``@P```#P#````````G`4``'4```#D````<@(``$0&``#Q!```Z```
M`,\%``#4!0``/`0``+X&````````8P$``````````````````!,#````````
MS@0```````!T!0``X@4`````````````OP(`````````````R@0``"0#```D
M`0``(P<````````>!@``RP8``/$#``!]`0``?P0````````T````"00`````
M``"&````!`4``+X!```(`0``7P8``*($````````````````````````+08`
M``````">`````````,@"``!&!```EP8```L!``#5`0``W`8``'4%````````
MD`$``)H```#Q`0``A@0```<#````````"@4````````@`0```````%L!```5
M`P``*`,```````"*`@``9@8``'X````C`P``M`(``,L!````````N@(``&8%
M````````I@4`````````````D0$``+D!``#6!```J@0````````+`@``!P<`
M```````;!@````````````".`0``(P$``!X"````````;P(``.,!``!H!@``
MV@$``.8"``!J`0```````&@%``#@````F0$``*@$``!0``````````<$````
M`````````````````````P4```````#L`````````-$!``"C````Q08``'`&
M`````````````/$"```_`@```````$8"```L`@```@```&$$````````TP4`
M`+8!``#L`@``$08```````"8!```.`(```````!_`P``70(``%`"``#7`P``
M1P(``$,```#L!@```````(<"``#G`P``G@(``'H"```H!```K@(``&H%``#%
M!```&@4````````:!P``:@8``!P$```Y!```'@,``"0$``"R`0``R````),`
M````````'0```,4"``#>!0``NP8``-,`````````A0,``.\&``"7`0``=P``
M``````#\!0``3@,```````"A````RP```.`%```V!@```````"H"```7`@``
M]`,````````I`0``"@,``+0!``#@`@````````````!U`P``_0$``+P#```"
M!0``&P4``$X&```U!@``Q`4``,D`````````\P(``"X!```/`@``&P<``,X&
M``#[`P``Q@(```````#P!```%P0``$P#``!/`P``-`,``)P```!?!0``````
M`,`$````````````````````````7P(``(T"```0!@``+P(``,\"``!2!@``
M0P,``.0$``!"`P``T`4```````"%````:0,``.@#``#]!0``<0```!(`````
M`````````-@````!!P``T@$``&X#``"F`@``#@8```````!`!0``.@0````@
M*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AY97-T
M97)D87DI`"!A;F0`(&%T(``@;W(`)60@)7,@86YD("5S`"5D+61A>2!F;W)E
M8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-I9VX@57``
M)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A
M="`E<R`E<P`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE
M;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G=7-T
M:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@
M+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D
M871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!3:&]W
M97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!
M8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`
M06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!
M8W1I;VX@9F]R(&)L86-K;&ES=&5D(&%D9')E<W-E<SH`06-T:79A=&4@4V-R
M:7!T`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`
M061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D
M9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@
M<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D
M('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@
M=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@4V5T
M=&EN9W,`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S
M`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&P@;V8@=&AE(&9O
M;&QO=VEN9P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M
M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N
M9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N<W=E<F5D
M`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!;GD@;V8@=&AE(&9O
M;&QO=VEN9P!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@1FEL=&5R<P!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I
M;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C
M:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI
M<R!R=6QE/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F=E;G1I;F$`07)M96YI80!!<FUE
M;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!
M<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S
M:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I
M=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE
M('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$%U=&]M871I8V%L;'D@=7!D871E('1H92!S8W)I<'0@869T
M97(@96%C:"!C:&%N9V4_`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`
M0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@
M:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H
M86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`
M0F%R8F%D;W,`0F%S96QI;F4`0F-C`$)E9VEN<R!W:71H`$)E;&%R=7,`0F5L
M9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQA
M8VML:7-T`$)L86-K;&ES="!%9&ET`$)L86-K;&ES="!I<R!N;W0@<W5P<&]R
M=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$)L86-K;&ES
M=&5D($%D9')E<W,`0FQA8VML:7-T960@061D<F5S<V5S`$)L;V-K("(E<R(@
M;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S
M`$)L;V-K(%1Y<&4`0F]D>0!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E
M<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z
M:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U
M<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U
M<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0
M<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`
M0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`
M0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B
M+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO
M;@!#87-E(%-E;G-I=&EV90!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N
M($ES;&%N9',`0V,`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P
M861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO
M;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A
M;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T
M:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA
M;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#
M:&%N9V5S('-A=F5D+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M
M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A
M<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R
M`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL
M('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O
M;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M
M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT
M`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET
M:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#
M;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@
M9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&%I;G,`0V]N=&EN=64`0V]O:R!)
M<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@)7,`0V]P>2!O9B`E<P!#;W!Y('-E
M;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E
M+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C
M:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL
M(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R
M:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO
M="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R
M96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@
M<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T
M(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT
M960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`
M0W)E871E(&$@;F5W(&]N90!#<F5A=&4@;F5W(&9O;&1E<@!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#
M=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T
M>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`
M0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y
M<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*0!#>F5C:"!297!U8FQI8P!$1`!$25-!0DQ%1#H@`$1A:6QY`$1A=&%4
M<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N
M`$1A>0!$95]L971E($-O;'5M;@!$96%C=&EV871E(%-C<FEP=`!$96-E;6)E
M<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@0V]L
M;W(`1&5F875L="!)9&5N=&ET>0!$969I;FET:6]N<P!$96QE=&4`1&5L971E
M("5S`$1E;&5T92!#;VYD:71I;VX`1&5L971E($=R;W5P`$1E;&5T92!097)M
M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`
M1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E`$1E;&5T92!M97-S86=E(&-O;7!L971E;'D`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960`1&5L:79E<B!I;G1O
M(&UY($E.0D]8`$1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@8V]P>2!T;P!$
M96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(')E9&ER96-T('1O`$1E;&EV97(@
M=&\@9F]L9&5R`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@
M4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@
M;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@
M9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O
M(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-A
M8FQE("5S`$1I<V%B;&5D`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA
M>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@;F]T:69I8V%T:6]N('=H96X@
M96%C:"!F:6QT97(@:7,@87!P;&EE9#\`1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II
M8F]U=&D`1&\@7VYO="!S96YD(')E<W!O;G-E<R!T;R!B=6QK(&]R(&QI<W0@
M;65S<V%G97,`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;R!T:&ES.@!$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z`$1O97-N)W0@8F5G:6X@=VET:`!$;V5S;B=T(&-O;G1A:6X`1&]E<VXG
M="!E;F0@=VET:`!$;V5S;B=T(&5X:7-T`$1O97-N)W0@;6%T8V@@*'=I=&@@
M<&QA8V5H;VQD97)S*0!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W
M;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-
M86EL`$524@!%8W5A9&]R`$5D:70`161I="`E<P!%9&ET($)L;V-K`$5D:70@
M1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M
M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L
M96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC
M;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N86)L92`E<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F
M<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/P!%;F%B;&5D`$5N9"!Y96%R`$5N9',@=VET:`!%
M;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H
M('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_
M)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%L('1O`$5Q=6%T;W)I
M86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>&ES=&EN9R!2=6QE
M<P!%>&ES=',`17AP86YD`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O
M;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I
M;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B
M+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE
M9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`
M1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9I:FD`1FEL92!#;W5N=#H@)7,@
M9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.
M86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+@!&:6QT97(@06QL($UE<W-A9V5S`$9I;'1E<B!/;FQY
M(%-E96X@365S<V%G97,`1FEL=&5R($]N;'D@56YS965N($UE<W-A9V5S`$9I
M;'1E<B!/<'1I;VYS`$9I;'1E<B!2=6QE`$9I;'1E<B!2=6QE<P!&:6QT97(@
M4V-R:7!T($1I<W!L87D`1FEL=&5R(%]2=6QE<P!&:6QT97(@86-T:79I='DZ
M("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R
M("(E<R(N`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E
M96X@9&5L971E9"X`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA
M=F4@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E<B!A8W1I
M=FET>3H@)7,@;65S<V%G92AS*2!T:&%T(&UA=&-H960@=&AE(&)L86-K;&ES
M="!W97)E(&1E;&5T960N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@
M(B5S(B!F<F]M("(E<R(@:&%S(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@
M(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&UO=F5D('1O('1H92!F
M;VQD97(@(B5S(BX`1FEL=&5R(&YO="!F;W5N9"X`1FEL=&5R<P!&:6YL86YD
M`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A
M=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O
M9`!&;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z`$9O<B!B
M<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4
M048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R
M96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M
M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T
M('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O
M<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9"!I<R!N
M;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N
M`$9O<G=A<F1S`$9O<G=A<F1S($5D:70`1G(`1G)A;65S`$9R86YC90!&<F%N
M8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S
M:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@
M`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'
M86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA
M`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L
M`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R96%T97(@=&AA;@!'<F5A=&5R
M('1H86X@;W(@97%U86P@=&\`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'
M<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'=6%M
M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O
M;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R
M;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z
M90!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE
M8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D
M:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A
M<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R
M9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE
M("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T
M>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S
M:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R
M:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(
M;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N
M>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F
M:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO
M<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D
M9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L
M;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS
M97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@
M=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE
M=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM
M86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L
M(%-T97`@)60`26UP;W)T86YT`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD
M:79I9'5A;"!5<V5R<P!);F1I=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R
M=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$EN9&]N97-I
M80!);F5X:7-T86YT(&UA:6QB;W@@<W!E8VEF:65D(&9O<B!M97-S86=E(&1E
M;&EV97)Y+@!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R
M`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN
M<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T
M(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S
M<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H
M(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN
M<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S
M=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`
M26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I
M;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R
M(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI
M9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A
M('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A
M;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L
M+@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES`$ES;&4@;V8@36%N`$ES
M;B=T`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET
M86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M
M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#
M96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT
M`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+
M97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y
M<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N
M("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`
M3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA
M<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@
M;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA
M=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE
M9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,97-S('1H86X`
M3&5S<R!T:&%N(&]R(&5Q=6%L('1O`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M
M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I
M;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN
M(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI
M9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z
M`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W
M:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@
M5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES
M="U)1`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R
M:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE
M.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO
M9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A
M:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`
M3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M
M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L
M878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M
M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L
M:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P
M`$UA<E]K(&UE<W-A9V4@87,@9&5L971E9`!-87)C:`!-87)G:6X`36%R:R!M
M97-S86=E(&%S.@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W
M:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R
M<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H97,@*'=I=&@@<&QA8V5H
M;VQD97)S*0!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`
M36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&)L86-K
M;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E
M<RP@36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W
M(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N`$UA>&EM=6T@;G5M8F5R(&]F('=H
M:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S
M.B`E<RP@36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@
M;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N`$UA>0!-87EO='1E`$UE9&EC
M:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X
M<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$UE=&AO9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO
M=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA
M;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S
M:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G92!T;P!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E87-O;B!F;W(@<F5J96-T`$UI<W-I;F<@<F5A
M<V]N(&EN('9A8V%T:6]N+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G
M92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO
M9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O
M=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A
M<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-;W-T
M;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V90!-;W9E
M($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!2=6QE($1O=VX`36]V
M92!2=6QE(%5P`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U
M90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T
M:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA
M;FUA<@!.3RP@22!$;R!.3U0@06=R964`3E]U;6)E<B!O9B!D87ES(&)E='=E
M96X@=F%C871I;VX@<F5P;&EE<SH`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L
M`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A
M<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!
M('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E
M(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP
M90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE
M=R!-;V]N`$YE=R!2=6QE`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:
M96%L86YD`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE
M>'0`3F5X="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT
M`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O
M<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O
M<B!T:&ES(&AO<W0`3F\@8F%C:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K96YD
M<RYP:'``3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T
M:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED
M960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI
M;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&
M4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T
M:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!H96%D97)S
M('-P96-I9FEE9`!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P
M<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D
M+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T
M;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I
M;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`
M3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S8W)I<'0@9V5N97)A
M=&5D+@!.;R!S:61E<P!.;R!S=')I;F=S('-P96-I9FEE9`!.;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D
M:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI
M<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F
M=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!E<75A;"!T;P!.
M;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`
M3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.
M=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@
M;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN
M(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`
M3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY
M($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F
M9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A
M('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y
M<W1E;0!/<'1I;VYS`$]P=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+@!/
M<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N
M:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO
M;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$
M:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI
M8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@
M4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%0M4W1O<FUS`%!?
M2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!4
M97)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A
M<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R
M96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S
M=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M
M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E
M;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M
M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!0
M97)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I
M>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A
M<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&5N
M=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L
M`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI
M<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@
M24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S
M=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME
M>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T
M('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O
M4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0
M=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET
M*0!27V5A<V]N`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I
M;B!,871E`%)A:6X@4VAO=V5R`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5C96EV960`4F5D:7)E8W0@=&\`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L
M(%9I97<Z`%)E9V5X`%)E9W5L87(@97AP<F5S<VEO;@!296IE8W0@=VET:"!R
M96%S;VX`4F5L871I;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UO=&4@4V5R
M=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F
M;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`
M4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N
M(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<V5N="!4;P!297-E;G0M9G)O;0!2
M97-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L
M=',`4F5T=7)N('1O($9I;'1E<G,@3&ES=`!2971U<FX@=&\@3W!T:6]N<P!2
M971U<FX@=&\@4G5L97,@3&ES=`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T
M:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I
M9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O
M;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H
M=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE`%)U
M;&4@0V]P:65D`%)U;&4@1&5L971E9`!2=6QE($1I<V%B;&5D`%)U;&4@16YA
M8FQE9`!2=6QE($YA;64`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@
M0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3
M($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!3
M80!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A
M;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V
M:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3
M879E(%-E='1I;F=S`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V-I96YC90!38W)I<'0`
M4V-R:7!T(%5P9&%T:6YG`%-C<FEP="!N;W0@=7!D871E9"X`4V-R:7!T('-U
M8V-E<W-F=6QL>2!A8W1I=F%T960N`%-C<FEP="!S=6-C97-S9G5L;'D@9&5A
M8W1I=F%T960N`%-E87)C:`!396%R8V@@16YG:6YE<P!3965N`%-E;&5C="!&
M:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A(&=R
M;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R
M`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T87)G970@9F]L9&5R`%-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W
M86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396QF+41E9FEN960@2&5A9&5R`%-E;F0@4')O
M8FQE;2!297!O<G0`4V5N9"!335,`4V5N9&5R`%-E;F5G86P`4V5N<V]R.B``
M4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='1I;F=S('-U
M8V-E<W-F=6QL>2!U<&1A=&5D+@!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`
M4VAO=P!3:&]W($%C=&EV92!38W)I<'0`4VAO=R!#=7)R96YT(%-C<FEP=`!3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@
M=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA
M=&4`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS
M*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3
M:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3
M:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3
M:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P
M=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N
M9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N
M`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN
M9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E
M;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E
M`%-T871U<P!3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M871C:&5S/P!3
M=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T
M<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE
M(%M#4U-=`%-U`%-U8FIE7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z`%-U8FIE
M8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!R979E
M<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U
M8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S
M<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E
M=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS
M970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N
M86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3
M=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA
M;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B
M;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!4
M86EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L
M(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.
M=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R
M871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL
M>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA
M;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N`%1H92!D<FEV97(@<V%I9#H@`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE
M(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H
M('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E
M<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I
M;F<@=&AE('-C<FEP="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN
M9R!T:&4@<V-R:7!T+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI
M;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R
M=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES
M(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510
M('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@
M5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N
M="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@
M;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L
M9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N
M=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@
M97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N
M('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@
M1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L
M:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V
M97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I
M;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M
M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@
M2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4
M;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B
M86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H
M25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L
M86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!5
M4DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S
M:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#
M:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%54
M1BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET
M960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD
M<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E
M($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@
M8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`
M57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<FYA
M;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`
M57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A
M=&EO;@!686-A=&EO;B!%9&ET`%9A8V%T:6]N($UE<W-A9V4`5F%C871I;VX@
M:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I
M=F5R+@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y
M`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@
M<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L
M(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6
M:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I
M;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@
M1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A
M=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML
M>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H
M25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H
M87)A`%=H7VET96QI<W0@861D<F5S<V5S.@!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:&ET96QI<W0@161I=`!7
M:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT
M97)I;F<@9')I=F5R+@!7:&ET96QI<W1E9"!!9&1R97-S97,`5VED=&@`5VED
M=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T
M:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@<W!E
M960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7;W)K`%=O<FL@061D
M<F5S<P!7;W)K(%!H;VYE`%@M4')I;W)I='D`6"U2968`6"U3<&%M+4QE=F5L
M`%@M4W!A;2U38V]R90!8+5-P86TM4W1A='5S`%@U,#EV,R!"87-I8R!#;VYS
M=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE
M87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO
M="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E
M96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!E;6%I;"!A
M9&1R97-S(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@;65S<V%G97,@<VAO=6QD
M(&)E(&%C=&EV871E9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%
M;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA
M=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M
M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L
M;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R
M=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`
M6TAI9&4@475O=&5D(%1E>'1=`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&1R97-S*&5S*2!T;R!F;W)W
M87)D('1O.@!?061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SH`
M7T%D;6EN:7-T<F%T:6]N`%]";&%C:VQI<W0`7T-,20!?1&%T851R964`7T1E
M;&5T92!2;W<`7T1E;&5T92!M97-S86=E(&-O;7!L971E;'D`7T5N=&5R(&5A
M8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE.@!?1F]R=V%R9`!?1W)O=7!S`%](
M96QP`%]);6%G92!0<F]P97)T:65S+BXN`%]+965P(&$@8V]P>2!O9B!M97-S
M86=E<R!I;B!T:&ES(&%C8V]U;G0_`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF
M>2!,:6YK+BXN`%]-;W9E(&UE<W-A9V4@=&\@9F]L9&5R.@!?37D@96UA:6P@
M861D<F5S<V5S.@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK
M+BXN`%]38W)I<'0`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R
M<P!?5F%C871I;VX`7U=H:71E;&ES=`!A9&1R97-S(&)O;VL`86YD`&-A;&5N
M9&%R`&-A;&T`8VQI8VL@:&5R90!F86QL:6YG`&9I96QD`&9I;&4`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S
M70!M871C:`!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RX`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N
M;W1E<&%D`&]R`'!E<F-E;G0`<&EX96QS`'!R;V-M86EL('-C<FEP="!G96YE
M<F%T960@8GD@26YG;P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S:65V92!F
M:6QT97(@9V5N97)A=&5D(&)Y($EN9V\`<VUS,F5M86EL('9I82!(5%10`'-T
M96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N
M9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A
M=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!);F=O(#$N,"UC=G,*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO
M;BU$871E.B`R,#`T+3$Q+3(W(#(Q.C,W*S`Q,#`*3&%S="U4<F%N<VQA=&]R
M.B!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL/@I,
M86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I
M;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/
M+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A
M;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN("$](#$I.PH`("@E<R!D
M86=E;B!G96QE9&5N*0`@*%-N96QT;V5T<R`E<RD`("AV86YD86%G*0`@*&=I
M<W1E<F5N*0`@96X`(&]P(``@;V8`)60@)7,@96X@)7,`)60M9&%G('9O;W)U
M:71Z:6-H=``E<R`M($]P;65R:VEN9P`E<R!V:6YG97)A9F1R=6L`)7,@2T(`
M)7,@3VYD97)H;W5D<W=E<FMZ86%M:&5D96X@+2!"979E<W1I9VEN9P`E<R!I
M;G-C:')I:G9E;@`E<R!G96)R=6EK97)S;W9E<F5E;FMO;7-T`"5S(&)E<W1A
M870@86PN`"5S(&]P("5S("5S`"5S(&ES('9E<F5I<W0`)7,@;6EN=71E;@`E
M<R!N:65T(&=E=F]N9&5N+@`E<R!T;W0@)7,@=F%N("5S`"5S)W,@861R97-B
M;V5K`"5S)W,@86=E;F1A`"5S)W,@;F]T:71I96)O96L`)7,G<R!T86ME;FQI
M:G-T`"5S.B`E<P`L('=I;F1V;&%G96X@)7,@)7,`+"!V87)I86)E;"!V86X@
M)7,@=&]T("5S`"TM('-E;&5C=&5R96X@+2T`,3(@=75R<W=E97)G879E`#(T
M('5U<G-W965R9V%V90`R-"!U=7)S`$5E;B!D871A8F%S92!B86-K96YD(&ES
M('9E<F5I<W0@=F]O<B!D:70@8FQO:RX`17(@:&5E9G0@>FEC:"!E96X@9F%T
M86QE(&9O=70@=F]O<F=E9&%A;@!%96X@;W!E;F)A<F4@4$=0('-L975T96P@
M:7,@=F5R96ES="!O;2!E96X@8F5R:6-H="!T92!C;V1E<F5N+@!%96X@;W!E
M;F)A<F4@4$=0('-L975T96P@:7,@=F5R96ES="!O;2!E96X@;VYD97)T96ME
M;F0@8F5R:6-H="!T92!V97)I9FGK<F5N+@!%96X@;W!E;F)A<F4@4$=0('-L
M975T96PL('!R:7;I(%!'4"!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z
M:6IN('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@9&5C;V1E<F5N+@!%96X@
M;W!E;F)A<F4@4$=0('-L975T96PL('!R:7;I(%!'4"!S;&5U=&5L(&5N('=A
M8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@
M;VYD97)T96ME;F5N+@!%96X@;W!E;F)A<F4@4R]-24U%('-L975T96PL('!R
M:7;I(%,O34E-12!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E
M<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@9&5C;V1E<F5N+@!%96X@;W!E;F)A
M<F4@4R]-24U%('-L975T96PL('!R:7;I(%,O34E-12!S;&5U=&5L(&5N('=A
M8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@
M;VYD97)T96ME;F5N+@!%96X@;W!E;F)A<F4@4TU)344@<VQE=71E;"!I<R!V
M97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&-O9&5R96XN`$)U:65N('9O;W(@
M,3(N,#`@=75R`$%-+U!-`$%022!)1`!/=F5R(&1E>F4@961I=&]R`$]V97(N
M+BX`06)S8F]T=&]M`$%B<VUI9&1L90!4;V5G86YG(&=E=V5I9V5R9"!B:6H@
M:&5T(&UA:V5N('9A;B!61E,@9&ER96-T;W)Y+@!4;V5G86YG(&=E=V5I9V5R
M9"!B:6H@:&5T(&UA:V5N('9A;B!61E,@8F5S=&%N9"X`06-C;W5N='=A8VAT
M=V]O<F0`06-C;W5N="!B979R;W)E;BX`5F5R86YT=V]O<F1I;F<`0F5W97)K
M:6YG('9O;W(@>G=A<G1E(&QI:G-T(&%D<F5S<V5N.@!38W)I<'0@86-T:79E
M<F5N`%1O979O96=E;@!#:&EL9"!G<F]E<"!T;V5V;V5G96X`0VAI;&0@<F5C
M:'0@=&]E=F]E9V5N`$AI97(@=&]E=F]E9V5N.@!.:65U=V4@9W)O97`@=&]E
M=F]E9V5N`$YI975W(')E8VAT('1O979O96=E;@!.:65U=V4@9V5B<G5I:V5R
M('1O979O96=E;CH`2V]L;VT@=&]E=F]E9V5N`$YI975W92!L961E;B!T;V5V
M;V5G96X`4&%A<B!T;V5V;V5G96X`2&5T("5S(&UE;G4@=&]E=F]E9V5N(&%L
M<R!E96X@36]Z:6QL82!3:61E8F%R`%9O96<@=&]E(&%A;B!A9')E<V)O96LZ
M`%9O96<@=&]E(&%A;B!M:6IN(&%D<F5S8F]E:P!'96)R=6EK97(@=&]E=F]E
M9V5N`%1O979O96=E;B!V86X@9V5B<G5I:V5R<R!I<R!U:71G97-C:&%K96QD
M+@!%>'1R82!I;G-T96QL:6YG96X`061R97,`061R97-B;V5K`$)E:&5E<B`M
M(')E8VAT96X@=F]O<B!A;F1E<F4@9V5B<G5I:V5R<R!I;G-T96QL96X`0F5H
M965R`$%D=F5R=&5N=&EE<P!!9F=A;FES=&%N`$%L8F%N:>L`06QG97)I:F4`
M06QI87,`56ET;&EJ;F5N`%5I=&QI:FYI;F<Z`$%L;&4`06QL92!G96%U=&AE
M;G1I8V5E<F1E(&=E8G)U:6ME<G,`06QL92!G<F]E<&5N`$%L;&4@<F5C:'1E
M;@!!;&QE('9I97(@>FEJ9&5N`$EE9&5R('9A;B!D92!V;VQG96YD90!-965R
M9&5R92!A9')E<W-E;B!T;V5S=&%A;@!);G-T96QL96X@=F%N(&=E;W)D96YD
M92!L:6IS="!T>7!E('1O97-T86%N/P!"97-T86%T(&%L`$%L=&5R;F%T:65V
M92!)35-0(&%A;FUE;&1I;F<`06QT97)N871I968@24U34"!W86-H='=O;W)D
M`$%L=&5R;F%T:65V92!)35-0(&=E8G)U:6ME<G-N86%M`$%L=&5R;F%T:65F
M(&4M;6%I;&%D<F5S`$%L=&5R;F%T:65V92!S:F%B;&]N96X`06QT97)N871I
M979E('1E:W-T.@!!;65R:6MA86YS(%-A;6]A`$5E;B!O;F=E;&1I9V4@=V%A
M<F1E(&]P9V5G979E;BX`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;FEE
M;64@<')O>'D`06YT=V]O<F0`0F5A;G1W;V]R9`!!;G1A<F-T:6-A`$%N=&EG
M=6$@96X@0F%R8G5D80!%96X@=F%N(&1E('9O;&=E;F1E`%1O97!A<W-I;F<`
M5&]E<&%S<VEN9R!I<R!G97)E960N`$9I;'1E<G,@=&]E<&%S<V5N`$]P(&-H
M:6QD<VAA<F5S('1O97!A<W-E;@!';V5D:V5U<F5N`$%P<FEL`$%R86)I<V-H
M("A7:6YD;W=S+3$R-38I`$%R8VAI969B97-T86YD<V=R;V]T=&4`07)C:&EE
M9FYA86T`5V5E="!U('IE:V5R(&1A="!U(&1E>F4@<F5G96P@=VEL="!V97)W
M:6ID97)E;C\`5V5E="!U('IE:V5R(&1A="!U(&AE="!A86YM96QD:6YG<W9E
M<GIO96L@=F%N("5S('=I;'0@=F5R=VEJ9&5R96X_`$%R9V5N=&EN:>L`07)M
M96YIZP!!<FUE96YS("A!4DU30TE)+3@I`$MU;G-T`$%R=6)A`$%S8V5N<VEO
M;B!E:6QA;F0`07-C:6D@:W5N<W0`07IIZR]086-I9FES8VAE(%)E9VEO`$]M
M(&)E=F5S=&EG:6YG('9R86=E;B!V;V]R(&AE="!U:71V;V5R96X@=F%N(&]N
M9&5R:&]U9'-W97)K>F%A;6AE9&5N/P!/<&1R86-H="!K;VQO;6UE;@!0;V=I
M;F<@;VT@965N(&YI970@8F5S=&%A;F1E(&=R;V5P('1E('9E<G=I:F1E<F5N
M+@!0;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@=F5R=VEJ
M9&5R96XN`%!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9"!R96-H="!T92!B
M97=E<FME;BX`4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD92!S:&%R92!T
M92!B97=E<FME;BX`071T<FEB=71E;@!!=6=U<W1U<P!!=7-T<F%L:>L`3V]S
M=&5N<FEJ:P!!=71H7V-Y<G-Q;#H@=F5R96ES=&4@:6UA<"!E>'1E;G1I92!N
M:65T(&=E=F]N9&5N+@!!=71H7V-Y<G5S.B!B86-K96YD(&AE969T(&YI970@
M9&4@=F5R96ES=&4@8F5K=V%A;6AE9&5N+@!!=71H7V-Y<G5S.B!V97)E:7-T
M92!I;6%P(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?9G1P.B!V97)E
M:7-T92!&5%`@97AT96YT:64@;FEE="!G979O;F1E;BX@0V]M<&EL965R(%!(
M4"!M970@9&4@+2UE;F%B;&4M9G1P(&]P=&EE+@!!=71H7VEM87`Z('9E<F5I
M<W1E($E-05`@97AT96YT:64@;FEE="!G979O;F1E;BX`075T:%]K<F(U.B!V
M97)E:7-T92!K<F(U(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?;&1A
M<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H
M7VQD87`Z($YI970@:6X@<W1A870@9V5B<G5I:V5R("5S('1O92!T92!V;V5G
M96XN($1E('-E<G9E<B!M96QD=#H@`$%U=&A?;&1A<#H@3FEE="!I;B!S=&%A
M="!G96)R=6EK97(@)7,@=&4@=F5R=VEJ9&5R96X`075T:%]L9&%P.B!.:65T
M(&EN('-T86%T(&=E8G)U:6ME<B`E<R!B:6H@=&4@=V5R:V5N`$%U=&A?;6-A
M;#H@=F5R96ES=&4@34-!3"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H
M7W-M8F%U=&@Z('9E<F5I<W1E('-M8F%U=&@@97AT96YT:64@;FEE="!G979O
M;F1E;BX`075T:&5N=&EC871I92!M:7-L=6MT`$%U=&AE;G1I8V%T:64@;6ES
M;'5K="X@)7,`075T:&5N=&EC871I92!G97=E:6=E<F0@9&]O<B!D92!2041)
M55,@<V5R=F5R+@!!=71H96YT:6-A=&EE(&]P($944"!S97)V97(@;6ES;'5K
M="X`2&5T('-C<FEP="!N82!I961E<F4@=F5R86YD97)I;F<@875T;VUA=&ES
M8V@@8FEJ=V5R:V5N/P!"97-C:&EK8F%R92!V96QD96XZ`$%Z97)B86ED>FIA
M;@!"3T9(($5X8W5S97,`06-H=&5R9W)O;F0`06-H=&5R9W)O;F1K;&5U<@!&
M;W5T(&ME<F)E<F]S=V%C:'1W;V]R9"X`1F]U=&4@:V5R8F5R;W-G96)R=6EK
M97)S;F%A;2X`0F%H86UA<P!"86AR96EN`$)A;'1I<V-H("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-I<VQI:FX`0F-C`$)E9VEN="!M
M970`5VET(')U<VQA;F0`0F5L9VGK`$)E;&EZ90!"96YI;@!"97)M=61A`$)H
M=71A;@!697)J86%R9&%G`%IW87)T92!L:6IS=`!:=V%R=&4@;&EJ<W0@8F5W
M97)K96X`6G=A<G1E(&QI:G-T('=O<F1T(&YI970@;VYD97)S=&5U;F0@:6X@
M:&5T(&AU:61I9V4@9FEL=&5R<W1U=7)P<F]G<F%M;6$N`%IW87)T92!L:6IS
M="!A9')E<P!:=V%R=&4@;&EJ<W0@861R97-S96X`0FQO:R`B)7,B('9A;B!T
M;V5P87-S:6YG("(E<R(@;FEE="!G979O;F1E;BX`0FQO:VEN<W1E;&QI;F=E
M;@!";&]K='EP90!";V1Y`%9E=`!";VQI=FEA`$)O;VMM87)K<P!286YD`%)A
M;F1D:6MT93H`4F%N9&5N`$)O<VYIZR!E;B!(97)Z96=O=FEN80!"96ED96X`
M0F]T<W=A;F$`3VYD97)K86YT`$)O=79E="!E:6QA;F0`0G)A>FEL:>L`0G)I
M=',@26YD:7-C:&4@3V-E86%N(%1E<G)I=&]R:75M`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEJ90!/;F=E;W)D96YD92!L:6IS=`!"=7)K:6YA($9A<V\`
M0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I97!U;G1E;@!#7V5L96EG
M96YS8VAA<'!E;BXN+@!!9V5N9&$`2V%L;0!#86UB;V1J80!+86UE<F]E;@!+
M86X@=V%C:'1W;V]R9"!N:65T(&%U=&]M871I<V-H(')E<V5T=&5N+"!N965M
M(&-O;G1A8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(N`$MA;B!N:65T
M('9E<F)I;F1E;B!M970@24U!4"!S97)V97(Z("5S`$-A;F%D80!!9F)R96ME
M;@!0<F]B;&5E;7)A<'!O<G0@869B<F5K96X`2V%N(&)E<W1A;F0@(B5S(B!N
M:65T('9E<G=I:F1E<F5N+@!+86X@9V5E;B!T:6ID96QI:FME(&1I<F5C=&]R
M>2!V:6YD96XN`$MA;B!N:65T(&1O;W)G86%N('IO;F1E<B`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+@!+86X@9&ER96-T;W)Y("(E<R(@;FEE="!V97)W:6ID
M97)E;BX`2V%N(&YI970@=F5R=VEJ9&5R96X[("5D(&-H:6QD<F5N(&)E<W1A
M86XN`$MA;B!N:65T(&]P;FEE=7<@<F%N9W-C:&EK:V5N+"!H970@86%N=&%L
M(&EN=F]E<F5N(&]M(&]P;FEE=7<@=&4@<F%N9W-C:&EK:V5N(&MO;70@;FEE
M="!O=F5R965N(&UE="!H970@;W!G97-L86=E;B!A86YT86PN`$MA;B!B97)I
M8VAT(&YI970@;F%A<B!H970@;W!G96=E=F5N(&YU;6UE<B!V97)S='5R96XN
M`$MA87`@5F5R9&4`3W!S8VAR:69T`$AO;V9D;&5T=&5R9V5V;V5L:6<`0V%T
M96=O<FEEZVX@96X@;&%B96QS`$-A>6UA;B!E:6QA;F1E;@!#8P!496PN;G(N
M;6]B:65L`$-E;&5I9V5N<V-H87!P96X`0V5L('9R:6IE(')U:6UT93H`0V5L
M96EG96YS8VAA<'!E;@!#96QS<&%T:>MR:6YG.@!496PN;G(N;6]B:65L`$ME
M;'1I<V-H("A)4T\M.#@U.2TQ-"D`36ED9&5N`$-E;G1R86%L($%F<FEK86%N
M<V4@4F5P=6)L:65K`$-E;G1R86%L($5U<F]P965S("A)4T\M.#@U.2TR*0!#
M97)T:69I8V%A=&1E=&%I;',`0V5R=&EF:6-A871B96QE:60`5'-J86%D`%=I
M:GII9V5N`%=I:GII9R!D92!N86%M+"!A9')E<R!E;B!O;F1E<G1E:V5N:6YG
M(&1I92!M96X@>FEE="!B:6H@:&5T(&QE>F5N(&5N(&)E86YT=V]O<F1E;B!V
M86X@=7<@92UM86EL<RX`5F5R86YD97)I;F=E;B!O<&=E<VQA9V5N`$MA<F%K
M=&5R`$-O;G1?<F]L965R(&QI;FLN+BX`0VAI;&D`0VAI;F$`0VAI;F5E<R!V
M97)E96YV;W5D:6=D("A'0C(S,3(I`$-H:6YE97,@=')A9&ET:6]N965L("A"
M:6<U*0!+:65S(&5E;B!W86-H='=O;W)D`$MI97,@965N(&=E8G)U:6ME<G-N
M86%M`$MI97,@9&%T=6UW965R9V%V93H`2VEE<R!L:6IS='-T:6IL='EP92`H
M=F]O<B!G96]R9&5N9&4@;&EJ<W1E;BD`0VAR:7-T;6%S(&5I;&%N9`!#;&%S
M<V1E9FEN:71I92!V86X@)7,@;FEE="!G979O;F1E;BX`2&5L9&5R`$U33V9F
M:6-E('1A9W,@=VES<V5N`%=I<R!G96)R=6EK97(Z("5S`%=I<R!G96)R=6EK
M97(`5VES(&=E8G)U:6ME<G-D871A`$ML:6L@;VT@=F5R9&5R('1E(&=A86X`
M0VQI8VMA=&5L;"!V:6$@2%144`!3;'5I="!S8VAE<FT`5V]L:V5N`$)E=V]L
M:W0`0V]C;W,@*$ME96QI;F<I(&5I;&%N9&5N`$EN9V5K;&%P=&4@<F%N9&5N
M`$-O;&]M8FEA`$ML975R`$ML975R96YK:65Z97(`2VQE=7)S96QE8W1I90!+
M;VQO;6UE;CH`2V]L;VUT:71E;',`4W1R:7!S`$]P9')A8VAT`$]P9')A8VAT
M<VAE;&P`3W!M97)K:6YG`$%L9V5M96YE(&YA86T`0V]M;W)E;@!"961R:6IF
M`$-O;7!U=&5R<P!#;VYD:71I97,`5F5R<V-H:6QL96X@:6X@8V]N9FEG=7)A
M=&EE`"5S(&-O;F9I9W5R97)E;@!"979E<W1I9R!W86-H='=O;W)D`$MO;F=O
M`$MO;F=O+"!$92!$96UO8W)A=&ES8VAE(%)E<'5B;&EE:R!V86X@9&4`5F5R
M8FEN9&EN9R!M:7-L=6MT+@!697)B:6YD:6YG(&UI<VQU:W0Z(`!697)B:6YD
M:6YG+"!M970@9&4@;W!E;F)A<F4@<VQE=71E;'-E<G9E<BP@:7,@9V5W96EG
M97)D+@!697)B:6YD:6YG+"!M970@9&4@;W!E;F)A<F4@<VQE=71E;'-E<G9E
M<BP@:7,@9V5W96EG97)D+B!2961E;CH@)7,@*"5S*0!697)B:6YD:6YG(&UE
M="!&5%`@<V5R=F5R(&UI<VQU:W0N`$%D<F5S<V5N('II:FX@;65T('-U8V-E
M<R!A86X@=7<@861R97-B;V5K('1O96=E=F]E9V0N`$)E=F%T`$1O;W)G86%N
M`$-O;VL@96EL86YD96X`0V]O:VEE`$MO<&GK<F5N`"5S(&MO<&GK<F5N`$MO
M<&EE('9A;B`E<P!+;W!I965R('-E;&5C=&EE`$-O<W1A(%)I8V$`279O;W)K
M=7-T`$MO;B!01U`@8F5R:6-H="!N:65T(&-O9&5R96XN`$MO;B!01U`@8F5R
M:6-H="!N:65T(&]N9&5R=&5K96YE;BX`2V]N(&)E<FEC:'0@;FEE="!3+TU)
M344@8V]D97)E;BX`2V]N(&)E<FEC:'0@;FEE="!3+TU)344@;VYD97)T96ME
M;F5N+@!+;VX@861R97,@)7,@;FEE="!T;V5V;V5G96XN`$MO;B!G965N('9E
M<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&UA:V5N+@!+;VX@=&5G;V5D
M("5S(&YI970@8V]N=')O;&5R96XN`$MO;B!G965N(&1I<W1R:6)U=&EE;&EJ
M<W0@)7,@;6%K96XN`$MO;B!01U`@9&%T82!N:65T(&1E8V]D97)E;BX`2V]N
M(%,O34E-12!D871A(&YI970@9&5C;V1E<F5N+@!+;VX@861R97,@)7,@;FEE
M="!V97)W:6ID97)E;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!V
M97)W:6ID97)E;BX`2V]N(&AE="!E+6UA:6QA9')E<R!V86X@9&4@;VYT=F%N
M9V5R(&YI970@8F5P86QE;BX`2V]N(&-O;7!L971E(&%D<F5S8F]E:R!N:65T
M(&]P:&%L96XN`$MO;B!C;VUP;&5T92!D:7-T<FEB=71I96QI:G-T(&YI970@
M;W!H86QE;BX`2V]N(&-O;7!L971E(&QI:G-T('9A;B!D:7-T<FEB=71I96QI
M:G-T96X@;FEE="!O<&AA;&5N+@!+;VX@9&4@;W!E;F)A<F4@<VQE=71E;"!N
M:65T('9E<FMR:6IG96X@=F%N(&1E('-L975T96QS97)V97(N`$MO;B`E<R!N
M:65T(&]P96YE;BX`2V]N(&]N9&5R:&]U9'-T86ME;FUO9'5L92`E<R!N:65T
M(&]P96YE;@!+;VX@)7,@;FEE="!L97IE;BX`2V]N(&AE="!W86-H='=O;W)D
M('9A;B!D92!G97=E;G-T92!G96)R=6EK97(@;FEE="!R97-E='1E;BX@4V]M
M;6EG92!O9B!A;&QE(&1E=&%I;',@>FEJ;B!N:65T(&IU:7-T+B!0<F]B965R
M(&]P;FEE=7<@;V8@;F5E;2!C;VYT86-T(&]P(&UE="!D92!S>7-T965M8F5H
M965R9&5R+"!W86YN965R('4@=F5R9&5R92!H=6QP(&YO9&EG(&AE969T+@!+
M;VX@04-,(&YI970@;W!H86QE;@!+;VX@861R97-B;V5K("5S(&YI970@;W!H
M86QE;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!O<&AA;&5N+@!+
M;VX@9&ES=')I8G5T:65L:6IS=&5N("5S(&YI970@;W!H86QE;BX`2V]N('-E
M<G9E<F)E:W=A86UH961E;B!N:65T(&]P:&%L96X`2V]N(&-O;F9I9W5R871I
M92!N:65T('1E<G5G>F5T=&5N+@!+;VX@8V]N9FEG=7)A=&EE("5S(&YI970@
M;W!S;&%A;BX`2V]N(&=E96X@8F%C:W5P8V]N9FEG=7)A=&EE(&]P<VQA86XN
M`$MO;B!D92!,1$%0+7-E<G9E<B!N:65T(&1O;W)Z;V5K96XN`$MO;B!A9')E
M<R`E<R!N:65T(&)I:G=E<FME;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@
M;FEE="!B:6IW97)K96XN`$MO;B!D92!-;WII;&QA(%-I9&5B87(@;FEE="!V
M:6YD96XN(%IO<F<@97)V;V]R(&1A="!D92!S:61E8F%R(&]P96X@:7,N`$=E
M=&5L9&4@=&5K<W0`3&%N9`!#=7)S=7-S96X`36%K96X`36%A:R!E96X@;&EN
M:P!-86%K(&5E;B!N:65U=V4`3FEE=7=E(&UA<"!M86ME;@!-86%K('-U8FUA
M<'!E;@!%:6=E;F%A<G)E8VAT96X`0W)E9&ET8V%R9&YU;6UE<@!+<F]A=&GK
M`$-U8F$`2'5I9&EG92!T:6ID`$AU:61I9V4@55),(&ES`$AU:61I9R!W965R
M`$AU:61I9V4@8V]N9&ET:64Z(`!(=6ED:6=E('-T:6IL`$%A;G!A<W-E;B!V
M86X@=&%K96X@=&EJ9&5N<R!A86YM96QD:6YG(&)I:B`E<RX`2VYI<'!E;@!3
M96QE8W1I92!K;FEP<&5N`$-Y<')U<P!#>7)I;&QI<V-H("A+3TDX+5(I`$-Y
M<FEL;&ES8V@@*%=I;F1O=W,M,3(U,2D`0WER:6QL:7-C:"]5:W)A:6YS("A+
M3TDX+54I`%1S:F5C:&ES8VAE(%)E<'5B;&EE:P!$1`!5:71G97-C:&%K96QD
M.B``1&%G96QI:FMS`$1A=&%4<F5E(&)R;W=S97(`1&%T=6T`1&%T=6T@3VYT
M=F%N9V5N`$1A='5M('-E;&5C=&EE`$1A9P!697)?=VEJ9&5R(&MO;&]M`%-C
M<FEP="!D96%C=&EV97)E;@!$96-E;6)E<@!$96-I;6%L92!G971A;&QE;@!)
M;G-P<FEN9V5N('9E<FML96EN96X`4W1A;F1A87)D(&ML975R`%-T86YD86%R
M9"!I9&5N=&ET96ET`$1E9FEN:71I97,`5F5R=VEJ9&5R96X`5F5R=VEJ9&5R
M("5S`%9O;W)W86%R9&4@=F]O<B!V97)W:6ID97)E;@!'<F]E<"!V97)W:6ID
M97)E;@!296-H="!V97)W:6ID97)E;@!697)W:6ID97(@96X@=VES(&)E<FEC
M:'1E;@!697)W:6ID97(@8V5L`%9E<G=I:F1E<B!K;VQO;0!"97-T86%N9"!A
M;'1E<FYA=&EE9B!S:F%B;&]O;B!V97)W:6ID97)E;@!"97)I8VAT('9O;&QE
M9&EG('=I<W-E;@!697)W:6ID97(@<FEJ`$=E<V5L96-T965R9&4@:61E;G1I
M=&5I="!V97)W:6ID97)E;@!697)W:6ID97(@9&4@:'5I9&EG92!K;VQO;0!6
M97)W:6ID97(@9&4@:'5I9&EG92!R:6H`5F5R=VEJ9&5R9`!$:70@8F5R:6-H
M="!I;B!M:6IN($E.0D]8(&%F;&5V97)E;@!!9FQE=F5R96X@:6X@;6EJ;B!)
M3D)/6"!E;B!K;W!IZW)E;B!N86%R`$%F;&5V97)E;B!I;B!M:6IN($E.0D]8
M(&5N('9E<F1E<G-T=7)E;B!N86%R`$%F;&5V97)E;B!I;B!M87``069L979E
M<G1I:F0`1&5N96UA<FME;@!"97-C:')I:F8@:&5T('!R;V)L965M`$)E<V-H
M<FEJ=FEN9P!$971A:6QS("AO;VL@:6X@2&]R9&4G<R!L;V=B97-T86YD*3H`
M1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E96UB96AE97)D97(N
M`$]N='=I:VME;&EN9P!$875W<'5N=`!$875W<'5N="!V;V]R(&AE="!A9F=E
M;&]P96X@=75R.B``1&%U=W!U;G0Z(`!2:6-H=&EN9R!L:6YK<R!N86%R(')E
M8VAT`%)I8VAT:6YG(')E8VAT<R!N86%R(&QI;FMS`$1I<F5C=&]R>0`E<R!U
M:71S8VAA:V5L96X`56ET9V5S8VAA:V5L9``R-"UU=7)S('1I:F1W965R9V%V
M93\`5V5E<F=A=F5O<'1I97,`5V5E<F=E=F5N('9A;B!B97)I8VAT('=A;FYE
M97(@9FEL=&5R<R!Z:6IN('1O96=E<&%S=#\`5V5E<G-V;V]R<W!E;&QI;F<@
M=&]N96X@*%1!1BD`5V5E<F=A=F5F;W)M86%T`%9O;W)B97)E:61I;F=S;F]T
M:69I8V%T:64`1&II8F]U=&D`7T=E96X@86YT=V]O<F1E;B!V97)S='5R96X@
M;W`@8F5R:6-H=&5N(&1I92!M86EL:6YG;&ES="UH96%D97)S(&AE8F)E;@!.
M:65T('9E<G=I:F1E<F5N`&UA:6YT96YA;F-E+G!H<"!N:65T(&1I<F5C="!A
M86YS<')E:V5N`$1O92!D:70Z`$)E=F%T(&1E(&5E<G-T92!R:6H@9&4@=F5L
M9&YA;65N/R!:;R!J82P@9&ET(&AO:VIE(&%A;G9I;FME;CH`0F5G:6YT(&YI
M970@;65T`$)E=F%T(&YI970`16EN9&EG="!N:65T(&UE=`!"97-T86%T(&YI
M970`2V]M="!N:65T(&]V97)E96X@*&UE="!P;&%C96AO;&1E<G,I`$1O;6EN
M:6-A`$1O;6EN:6-A86YS92!297!U8FQI96L`1&]W;FQO861E;@`E<R!D;W=N
M;&]A9&5N`$1O=VYL;V%D(&=E9V5N97)E97)D92!C;VYF:6=U<F%T:64@86QS
M(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:6IS=`!$<G5G<P!%+4UA:6P`15)2
M`$5C=6%D;W(`0F5W97)K96X`)7,@8F5W97)K96X`0FQO:R!B97=E<FME;@!'
M<F]E<"!B97=E<FME;@!296-H="!B97=E<FME;@!296-H=&5N(&)E=V5R:V5N
M`%)E8VAT96X@=F%N("<E<R<@8F5W97)K96X`3W!T:65S(&)E=V5R:V5N('9O
M;W(Z`%)E8VAT96X@=F%N("5S(&)E=V5R:V5N`$]N9&5R=VEJ<P!%9WEP=&4`
M16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%+6UA:6P`12UM86EL861R97,`
M12UM86EL861R97-S96X@;6]E=&5N(&]V97)E96YK;VUE;BX`12UM86EL(&UE
M="!B979E<W1I9VEN9P!%;6]T:6-O;G,`3&5E9R!B97)I8VAT+@!'965N(')E
M<W5L=&%A="X`3&5G92!Z;V5K=&5R;65N`$%C=&EV965R("5S`$EN=F]E9V5N
M('9A;B!A9F)E96QD:6YG96X@=6ET(&9O=&]A;&)U;7,@:6X@=&5K<W0@:6YS
M8VAA:V5L96X_`%)E8VAT:VQI:VME;B!C;VYT97AT(&UE;G4@:6YS8VAA:V5L
M96X_`$=E86-T:79E97)D`$5I;F1J86%R`$5I;F1I9W0@;65T`%9E<F=R;V]T
M(&5D:71O<@!'965F(&5E;B!B979E:6QI9VEN9W-V<F%A9R!D:64@=2!G979R
M86%G9"!W;W)D="P@=V%N;F5E<B!H970@;F]D:6<@:7,@;VT@=7<@=V%C:'1W
M;V]R9"!T92!R97-E='1E;BP@8BYV+B`G=V%T(&ES(&1E(&YA86T@=F%N('5W
M(&AU:7-D:65R/R<Z`%9O97(@9&4@869B965L9&EN9R!54DP@:&EE<B!I;@!'
M96QI:FL@86%N`$5Q=6%T;W)I86%L($=U:6YE90!%<FET<F5A`$9O=70`1F]U
M="!M970@92UM86EL8F5R:6-H="X`17-T;&%N9`!%=&AI;W!IZP!%=&YI<V-H
M`$5U<F]P80!%;&ME(#$U(&UI;G5T96X`16QK92`R(&UI;G5T96X`16QK92`S
M,"!S96-O;F1E;@!%;&ME(#4@;6EN=71E;@!%;&ME(&%A;FUE;&1I;F<`16QK
M(&AA;&8@=75R`$5L:V4@;6EN=75T`%9O;W)B965L9'=A87)D96XZ`%5I='9O
M97)E;@!"97-T86%N9&4@<F5G96QS`$)E<W1A870`56ET:VQA<'!E;@!697)W
M86-H='1E("<I)P!697)W86-H='1E(&5N:V5L('=O;W)D(&]F(&%A;F=E:&%A
M;&1E('IO96MT97)M`%9E<G9A;&1A='5M`$5X<&]N96YT`%9O;W)G<F]N9&ML
M975R`$944"!U<&QO860@=F%N('-E='5P`$]P:&%L96X@=F]O<FME=7)S:6YS
M=&5L;&EN9V5N(&UI<VQU:W0N`%9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R
M=F5R(&ES(&UI<VQU:W0N`%9E<F)I;F1I;F<@;65T(&1E(%--0BUS97)V97(@
M:7,@;6ES;'5K="X`2V]P:>MR96X@=6ET("(E<R(@:7,@;6ES;'5K="X`2V]P
M:>MR96X@;F%A<B`B)7,B(&ES(&UI<VQU:W0N`$UA:V5N('9A;B!N:65U=V4@
M4T%33"!V97)B:6YD:6YG(&ES(&UI<VQU:W0N`%9E<G!L86%T<V5N(&YA87(@
M(B5S(B!I<R!M:7-L=6MT+@!-;V]I`$9A;&ML86YD(&5I;&%N9&5N("A-86QV
M:6YA<RD`1F%R;^MR(&5I;&%N9&5N`$9A>`!&96)R=6%R:0!6;V5L="!A;',`
M5F]E;'0@86QS.B``16YK96QE(&)U:65N`$9I:FD`06%N=&%L(&)E<W1A;F1E
M;CH@)7,@8F5S=&%N9`!!86YT86P@8F5S=&%N9&5N.B`E<R!B97-T86YD96X`
M0F5S=&%N9&)E:&5E<@!"97-T86YD<VYA86T`0F5S=&%N9"!K:65Z96X`0F5S
M=&%N9'5P;&]A9`!"97-T86YD=7!L;V%D<R!W;W)D96X@;FEE="!O;F1E<G-T
M975N9"X`1FEL=&5R(&%L;&4@8F5R:6-H=&5N`$9I;'1E<B!A;&QE96X@9V5O
M<&5N9&4@8F5R:6-H=&5N`$9I;'1E<B!A;&QE96X@;VYG96]P96YD92!B97)I
M8VAT96X`1FEL=&5R;W!T:65S`$9I;'1E<G)E9V5L`$9I;'1E<G)E9V5L<P!&
M:6QT97)S8W)I<'1W965R9V%V90!&:6QT97)?<F5G96QS`$9I;'1E<F)E=V5R
M:VEN9SH@)7,@8F5R:6-H="AE;BD@>FEJ;B!G96MO<&EE97)D(&YA87(@;6%P
M("(E<R(N`$9I;'1E<F)E=V5R:VEN9SH@)7,@8F5R:6-H="AE;BD@>FEJ;B!V
M97)W:6ID97)D+@!&:6QT97)B97=E<FMI;F<Z("5S(&)E<FEC:'0H96XI('II
M:FX@=F5R<&QA871S="!N86%R(&UA<"`B)7,B+@!&:6QT97)B97=E<FMI;F<Z
M("5S(&)E<FEC:'0H96XI+"!D:64@;W`@9&4@>G=A<G1E(&QI:G-T('-T;VYD
M96XL('II:FX@=F5R=VEJ9&5R9"X`1FEL=&5R8F5W97)K:6YG.B!(970@8F5R
M:6-H="`B)7,B('9A;B`B)7,B(&ES(&YA87(@9&4@;6%P("(E<R(@9V5K;W!I
M965R9"X`1FEL=&5R8F5W97)K:6YG.B!(970@8F5R:6-H="`B)7,B('9A;B`B
M)7,B(&ES('9E<G=I:F1E<F0N`$9I;'1E<F)E=V5R:VEN9SH@2&5T(&)E<FEC
M:'0@(B5S(B!V86X@(B5S(B!I<R!N86%R(&1E(&UA<"`B)7,B('9E<G!L86%T
M<W0N`$9I;'1E<B!N:65T(&=E=F]N9&5N+@!&:6QT97)S`$9I;FQA;F0`165R
M<W1E(&AE;&9T`$5E<G-T92!K=V%R=&%A;`!697)H;W5D:6YG(&AE<G-T96QL
M96X`3VUK97)E;@!$<FEJ=F5N`$UI<W0`36%P("5S(&)E<W1A870@;FEE=`!&
M;VYT:VQE=7(`5F]E9'-E;`!6;V]R(&5E;B!I;FMO;65N9"!B97)I8VAT96X@
M9&%T('9O;&1O970@86%N.@!6;V]R(&)R;W=S97)S(&1I92!G965N(&%F8F5E
M;&1I;F=E;B!O;F1E<G-T975N96X`5V5E<G-V;V]R<W!E;&QI;F<@*%1!1BD`
M5F]O<G5I='II8VAT9&%G96X@*&UE<FL@;W`@9&%T(&AE="!G96=E=F5N('9O
M;W)U:71Z:6-H="!D86=E;B!E;B!N86-H=&5N(&=E969T.R!E96X@9W)O;W0@
M86%N=&%L(&MA;B!R97-U;'1E<F5N(&EN(&5E;B!B<F5E9"!B;&]K*0!5=R!W
M86-H='=O;W)D('9E<F=E=&5N/P!&;W)M=6QI97)E;@!&;W)T=6YE`$9O<G1U
M;F5T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$1O;W)S='5R96X`
M1&]O<G-T=7)E;B!W;W)D="!N:65T(&]N9&5R<W1E=6YD(&EN(&AE="!H=6ED
M:6=E(&9I;'1E<G-T=75R<')O9W)A;6UA+@!$;V]R<W1U<F5N`$1O;W)S='5R
M96X@8F5W97)K96X`5G(`1G)A;65S`$9R86YK<FEJ:P!&<F%N:W)I:FLL($AO
M;V9D<W1E9&5L:6IK`$9R86YS($=U>6%N80!&<F%N<R!0;VQY;F5S:>L`1G)A
M;G-E(%IU:61E;&EJ:V4@5&5R<FET;W)I80!686X`5F%N(&1E(`!6;VQL961I
M9V4@8F5S8VAR:6IV:6YG`%9O;&QE(&UA86X`5F]L;&5D:6=E(&YA86T`1V%B
M;VX`06QB=6T@=V%A<G5I="!D92!A9F)E96QD:6YG(&=E:&%A;&0@9&EE;G0@
M=&4@=V]R9&5N`$%L8G5M.@!'86UB:6$`1V5N97)E97(@)7,@8V]N9FEG=7)A
M=&EE`$=E9V5N97)E97)D92!C;V1E`$=E;W)G:>L`1'5I='-L86YD`$=H86YA
M`$=I8G)A;'1A<@!6;V]R;F%A;0!'80!';V5D96P`1V]O9VQE('IO96ME;@!'
M<FEJ<W-C:&%A;`!'<F]T97(@9&%N`$=R;W1E<B!D86X@;V8@9V5L:6IK(&%A
M;@!'<FEE:V5N;&%N9`!'<FEE:W,@*$E33RTX.#4Y+3<I`$=R;V5N;&%N9`!'
M<F5N861A`$=R;V5P<V)E:&5E<@!'<F]E<&YA;65N(&UO9V5N(&YI970@;&5E
M9R!Z:6IN`$=R;V5P96X`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R
M;G-E>0!'87-T(')E8VAT96X`1V%S=&5N8F]E:P!'=6EN964`1W5I;F5E+4)I
M<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!W96EG97)T(&QA9B!O;2!D92!L
M86%T<W1E(&-E;"!I;B!D92!R:6H@=&4@=F5R=VEJ9&5R96XN`$A434Q!<F5A
M('=E:6=E<G0@;&%F(&]M(&1E(&QA871S=&4@:V]L;VT@:6X@9&4@=&%B96P@
M=&4@=F5R=VEJ9&5R96XN`$A434Q!<F5A('=E:6=E<G0@;&%F(&]M(&1E(&QA
M871S=&4@<FEJ(&EN(&1E('1A8F5L('1E('9E<G=I:F1E<F5N+@!(5%10(&%U
M=&AE;G1I8V%T:64@;FEE="!G979O;F1E;BX`2&%I=&D`2&%S:"UA;&=O<FET
M:&UE`$YE=F5L`$MO<`!(96%R9"!E:6QA;F0@96X@36-$;VYA;&0@96EL86YD
M96X`2&5B<F5E=7=S("A)4T\M.#@U.2TX+4DI`$AO;V=T90!(96QP`$AE;'`@
M8FEJ(&=E8G)U:6L@=F%N(&5D:71O<@!(96QP97(`2&%L9G)O;F0`2&EE<B!I
M<R!H970@8F5G:6X@=F%N(&AE="!B97-T86YD.@!(;V]G`$AO7VUE`$AO;'D@
M4V5E("A6871I8V%A;G-T860I`$AO;64`061R97,@*'!R:7;I*0!496PN;G(N
M("AP<FEVZ2D`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!/;F=E;&1I9V4@)7,@6$U,(&1A=&$@=&5G96YG96MO;65N(&EN(&)E<FEC
M:'0@)7,`2&]R9&4O2V]L86(Z($=E96X@8F5R:6-H="!C;W)R97-P;VYD965R
M="!M970@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!'965N(&]B:F5C="!V86X@
M='EP92`E<R!G979O;F1E;B!I;B!B97)I8VAT("5S`$AO<F1E+TMO;&%B.B`E
M<R!M970@<W5C8V5S('9E<G=I:F1E<F0@(B5S(@!(;W)D92]+;VQA8CH@1&4@
M:6YT97)G<F%T:64@=F5R96ES="!D92`G9&]M>&UL)R!E>'1E;G-I90!(;W)D
M92]+;VQA8CH@2V%N(&=E96X@;FEE=7=E(%A-3"!B;V]M(&UA:V5N('9O;W(@
M;V)J96-T("5S`$AO<F1E+TMO;&%B.B!+86X@)7,@(B5S(B!N:65T('9E<G=I
M:F1E<F5N.B`E<P!(;W)D92]+;VQA8CH@3FEE="!I;B!S=&%A="!H970@34E-
M12!)1"P@=F]O<B!H970@9V5D965L=&4@;65T('1Y<&4@)7,L(&]P('1E(&AA
M;&5N`$AO<F1E+TMO;&%B.B!+86X@)7,@(B5S(B!N:65T('-Y;F-H<F]N:7-E
M<F5N.B`E<P!(;W)D92]+;VQA8CH@2V%N(&=E9&5E;&1E(&)R;VYN96X@;FEE
M="!S>6YC:')O;FES97)E;CH@)7,`2&]R9&4O2V]L86(Z($]N8F5K96YD92!G
M961E96QD92!B<F]N("(E<R(`2&]R:7IO;G1A;&4@;&EJ;@!(;W)I>F]N=&%L
M92!V<FEJ92!R=6EM=&4`2&]R:7IO;G1A86PZ`$AO92!K=V%M('4@:&EE<C\@
M*$=R86%G(')A<'!O<G1A9V4A*0!(;V5V965L(&MO;&]M;65N('=I;'0@=2!S
M86UE;G9O96=E;C\`2&]E=F5E;"!V96QD96X@*&MO;&]M;65N*2!Z:6IN(&5R
M/P!(;V5V965L(')I:F5N('=I;'0@=2!S86UE;G9O96=E;C\`5F]C:'1I9VAE
M:60`5F]C:'1I9VAE:60Z(`!(=6UO<FES=&5N`$AO;F=A<FEJ90!-86ME;B!V
M86X@24U!4"!M86EL8F]X(&UI<VQU:W0Z("5S`%9E<G=I:F1E<F5N('9A;B!)
M34%0(&UA:6QB;W@@;6ES;'5K=#H@)7,`36%K96X@=F%N($E-05`@;6%I;&)O
M>"!Q=6]T82!M:7-L=6MT.B`E<P!)4"!!9')E<P!)4"!A9')E<R!N:65T(&)E
M<V-H:6MB86%R+@!)4"!A9')E<R!V86QT(&YI970@8FEN;F5N(&AE="!T;V5G
M97-T86YE($-)1%(@8FQO:RX`25`@;&]C:V1O=VX@;W9E<G1R961I;F<N`%)I
M:B!I7VYV;V5G96X@=F]O<@!)2G-L86YD`$%L;&5E;B!P:6-T;V=R86UM96X`
M4&EC=&]G<F%M;65N(&UE="!T96MS=`!)9&5N=&ET96ET<VYA86TZ`%=A;FYE
M97(@:&5T(&YI970@9V]E9"!W;W)D="!W965R9V5G979E;BP@)7,@;VT@:&5T
M(&EN(&5E;B!N:65U=R!S8VAE<FT@=&4@;W!E;F5N+@!!;',@=2!G965N('!I
M8W1O9W)A;6UE;B!Z:65T+"!B:6H@9V5B<G5I:R!V86X@26YT97)N970@17AP
M;&]R97(L(&MA;B!H970@;F]D:6<@>FEJ;B!D:70@=F%K:F4@86%N('1E('9I
M;FME;B!O;2!03D<@=')A;G-P87)A=&EE('5I="!T92!S8VAA:V5L96XN`%=A
M;FYE97(@=2!D:70@8F5R:6-H="!Z:65T+"!M86%R(&=E96X@869B965L9&EN
M9RP@9&%N(&MA;B!D92!A9F)E96QD:6YG(&1I92!U('=I;'0@=7!L;V%D96X@
M;FEE="!D;V]R('5W(&)R;W=S97(@=V]R9&5N('=E97)G96=E=F5N+@!!9F)E
M96QD:6YG<V)E;V]R9&5L:6YG.@!!9F)E96QD:6YG(%523`!!9F)E96QD:6YG
M(%523#H`069B965L9&EN9R!U:70@86QB=6T`069B965L9&EN9R!U:70@86QB
M=6TZ`$%F8F5E;&1I;F=S=7!L;V%D`$%F8F5E;&1I;F=E;@!);7!O<G1E<F5N
M+"!S=&%P("5D`$)E;&%N9W)I:FL`1V5I;7!O<G1E97)D('9E;&0Z("5S`$=E
M:6UP;W)T965R9&4@=F5L9&5N.@!2:6H@:6YV;V5G96X@;F$`3VYJ=6ES=&4@
M8F5W97)K:6YG<V-O9&4@;W!G96=E=F5N+@!/;FIU:7-T92!G96)R=6EK97)S
M;F%A;2!E;B]O9B!W86-H='=O;W)D+@!/;FIU:7-T92!G96)R=6EK97)S;F%A
M;2!O9B!A;'1E<FYA=&EE9B!A9')E<RX@4')O8F5E<B!O<&YI975W(&]F(&YE
M96T@8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E<BP@=V%N;F5E
M<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H965F="X`5F5R9W)O;W0@:6YS<')I
M;F=I;F<`26YD:6$`26YD:79I9'5E;&4@9V5B<G5I:V5R<P!);F1I=FED=65L
M92!R96=E;',@=V]R9&5N(&YI970@;VYD97)S=&5U;F0@:6X@:&5T(&AU:61I
M9V4@9FEL=&5R<W1U=7)P<F]G<F%M;6$N`$EN9&]N97-IZP!.:65T(&)E<W1A
M86YD92!M86EL8F]X(&]P9V5G979E;B!V;V]R(&)E<FEC:'1A9FQE=F5R:6YG
M+@!);F9O`$EN9F]R;6%T:64`2V]L;VT@:6YV;V5G96X@;F$`069B965L9&EN
M9R!I;G9O96=E;@!486)E;"!I;G9O96=E;@!796)L:6YK(&EN=F]E9V5N`%]+
M;VQO;2!I;G9O96=E;B!V;V]R`$5E;B!N:65U=V4@:V]L;VT@:6YV;V5G96X@
M;F$@9&4@:'5I9&EG90!%96X@;FEE=7=E(&MO;&]M(&EN=F]E9V5N('9O;W(@
M9&4@:'5I9&EG90!%96X@;FEE=7=E(')I:B!I;G9O96=E;B!N82!D92!H=6ED
M:6=E`$5E;B!N:65U=V4@<FEJ(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4`165N
M(&YI975W92!P87)A9W)A868@:6YV;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E
M`$5E;B!N:65U=V4@<&%R86=R86%F(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4@
M;F]D90!!;'1E<FYA=&EE9B!S:F%B;&]O;B!I;G9O96=E;@!%96X@92UM86EL
M861R97,@:6YV;V5G96XL('=A87(@=2!H970@;FEE=7=E('=A8VAT=V]O<F0@
M:V%N(&]N='9A;F=E;CH`0V5L(&EN=F]E9V5N(&YA`$-E;"!I;G9O96=E;B!V
M;V]R`$MO;&]M(&EN=F]E9V5N(&YA`$MO;&]M(&EN=F]E9V5N('9O;W(`0F5R
M:6-H=&5N(&EN=F]E9V5N`%!A<F%G<F%A9B!I;G9O96=E;B!N80!087)A9W)A
M868@:6YV;V5G96X@=F]O<@!2:6H@:6YV;V5G96X@;F$`4FEJ(&EN=F]E9V5N
M('9O;W(`2&5T(&=E=V5N<W1E(&%N='=O;W)D('9O;W(@9&4@8F5V96EL:6=I
M;F=S=G)A86<@:6YV;V5G96XZ`$%F8F5E;&1I;F<@:6YV;V5G96XO86%N<&%S
M<V5N`$QI;FL@:6YV;V5G96XO86%N<&%S<V5N`$]N=F]L9&]E;F1E(&MR961I
M970@;VT@;F%A<B!D92!D:7-T<FEB=71I96QI:G-T('1E('IE;F1E;BX`3VYV
M;VQD;V5N9&4@:W)E9&EE=`!);G1E9V5R`$EN=&5G97(@;&EJ<W0`3VYG96QD
M:6=E(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!/;F=E;&1I9V4@=&]E<&%S
M<VEN9RX`3VYG96QD:6<@8F%T8V@@240N`$]N9V5L9&EG92!D871A(&]P9V5G
M979E;BX`3VYG96QD:6<@8F5S=&5M;6EN9V%D<F5S+@!/;F=E;&1I9R!T:6ID
M9F]R;6%A=`!/;F=E;&1I9R!M<V=?='EP92X`3VYG96QD:6<@;V8@;VYT8G)E
M:V5N9"!A<&E?:60N`$]N9V5L9&EG92!O9B!O;G1B<F5K96YD92!P87)A;65T
M97)S+@!/;F=E;&1I9R!P87)E;G0@<F5C:'0N`$]N9V5L9&EG('!R;W1O8V]L
M+@!/;F=E;&1I9V4@9V5D965L9&4@8G)O;@!/;F=E;&1I9R!B<F]N861R97,N
M`$]N9V5L9&EG92!U;FEC;V1E(&1A=&$N`$EN=F5N=&%R:7,`27)A;BP@27-L
M86UI=&ES8VAE(%)E<'5B;&EE:R!V86X`27)A:P!)97)L86YD`$ES`$5I;&%N
M9"!-86X`27,@;FEE=`!'96ES;VQE97)D92!O;G=E97)S8G5I96X`27-R8>ML
M`%5I=&=E=F5R`$-U<G-I968`271A;&GK`$IA;6%I8V$`2F%N=6%R:0!*87!A
M;@!*87!A;G,@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:>L`2G5L:0!*
M=6YI`'5I=&QI:FYE;@!'96-E;G1R965R9"!U:71L:6IN96X`5F]L;&5D:6<@
M=6ET;&EJ;F5N`$QI;FMS('5I=&QI:FYE;@!296-H=',@=6ET;&EJ;F5N`$MA
M>F%C:'-T86X`3W)I9VEN965L(&)E:&]U9&5N/P!+96YI80!+97)B97)O<R!S
M97)V97(@=V5I9V5R9&4@875T:&5N=&EC871I92X`2V5R;F5L($YE=V)I97,`
M4VQE=71E;"!M86ME;@!3;&5U=&5L=FEN9V5R869D<G5K`%-L975T96QL96YG
M=&4`4VQE=71E;'1Y<&4`4VQE=71E;&=E8G)U:6L`1&4@<VQE=71E;"!B97-T
M86%T(&%L(&]P(&1E(&]P96YB87)E('-L975T96QS97)V97(N`$MI;F1E<F5N
M`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K
M('9A;@!+;W)E82P@4F5P=6)L:65K('9A;@!+;W)E86%N<R`H155#+4M2*0!+
M;V5W96ET`$MY<F=I97-IZP!/7W!M86%K`%1A86P`1&5M;V-R871I<V-H92!6
M;VQK<W)E<'5B;&EE:R!,86\`3&%A='-T92!H96QF=`!,86%T<W1E(&MW87)T
M:65R`$QA871S="!B:6IG97=E<FMT.@!,86%T<W1E(&%A;FUE;&1I;F<Z("5S
M`$QA871S=&4@86%N;65L9&EN9SH@)7,@=F%N("5S`$QA871S=&4@86%N;65L
M9&EN9SH@3F]O:70`3&5T;&%N9`!296-H=&5N`$]P;6%A:P!,86%T(&QE96<@
M=F]O<B!G965N(')A;F0`3&EB86YO;@!,:6YK<P!,:6YK<V4@:V]P`$QI;FMS
M92!W86%R9&5N`$QE<V]T:&\`36EN9&5R(&1A;@!-:6YD97(@9&%N(&]F(&=E
M;&EJ:R!A86X`3&EB97)I80!,:6)I<V-H92!!<F%B:7-C:&4@2F%M86AI<FEY
M80!,:65C:'1E;G-T96EN`%IA8VAT(&)U:71J90!,:6-H=&4@<F5G96X`5G)O
M96<@;&EC:'1E(')E9V5N`$QI8VAT92!R96=E;@!,:6-H=&4@<F5G96YB=6D`
M3&EC:'1E(')E9V5N(&UE="!O;G=E97(`3&EC:'1E('-N965U=P!,:6-H=&4@
M<VYE975W8G5I`$QI;65R:6-K`$QI;FL`3&EN:R!W:6IS="!N86%R.@!,:6YK
M(&AE="!E+6UA:6QA9')E<R!A86X@9&4@;FEE=7<@8F5R:6-H="!P86=I;F$@
M=&EJ9&5N<R!W965R9V%V90!,:6YK<P!,:6YU>"!#;V]K:64`3&EJ<W0@+2!G
M96)R=6EK97(@:V%N(&1E(&UA<"!Z:65N`$1A=&%B87-E;&EJ<W0`3&EJ<W0@
M=F%N(&AE;'`@;VYD97)D96QE;@!486)E;&QI:G-T`$QI:G-T+4%R8VAI968`
M3&EJ<W0M2&5L<`!,:7-T+4E$`$QI:G-T+4ED`$QI:G-T+45I9V5N86%R`$QI
M:G-T+5!O<W0`3&EJ<W0M26YS8VAR:6IV96X`3&EJ<W0M56ET<V-H<FEJ=F5N
M`%=E97)G979E;B!V86X@9V5B<G5I:V5R<VQI:G-T(&ES('5I=&=E<V-H86ME
M;&0N`$QI=&5R871U=7(`3&ET;W5W96X`3&%D96XN+BX`3&]K86QE('1I:F0Z
M`$QA;F1I;G-T96QL:6YG(&5N('1I:F0`3&]C871I90!!86YM96QD96X`069M
M96QD96X`06%N;65L9'1A:V5N`$%A;FUE;&1I;F<@;6ES;'5K="!O;61A="!U
M=R!G96)R=6EK97)S;F%A;2!O9B!W86-H='=O;W)D(&]N:G5I<W0@:7,@:6YG
M979O97)D+@!!86YM96QD:6YG(&UI<VQU:W0N`$QA;F=E('1E:W-T`$QI969D
M90!,86%G`$=R:65K<V4@:VQE:6YE(&QE='1E<G,`3&%T:6IN<V4@:VQE:6YE
M(&QE='1E<G,`2VQE:6YE(%)O;65I;G-E(&=E=&%L;&5N`$QU>&5M8G5R9P!-
M30!-3U1$`$U3+51.148@8FEJ;&%G92!B979A='1E(&=E96X@9&%T82X`35-'
M`$UA8V%O`$UA8V5D;VYIZRP@1&4@=G)O96=E<F4@2F]E9V]S;&%V:7-C:&4@
M4F5P=6)L:65K('9A;@!-861A9V%S8V%R`$UA9VEE`$4M;6%I;`!-86EL8F5H
M965R9&5R`$UA86L@;&EN7VLN+BX`36%L87=I`$UA;&5I<VGK`$UA;&%D:79E
M;@!-86QI`$UA;'1A`$)E:&5E<B!U=R!L:6IS="!M970@8V%T96=O<FEEZVX@
M96X@9&4@8V]R<F5S<&]N9&5R96YD92!K;&5U<F5N+"!W86%R;65E(&]N9&5R
M9&5L96X@=V]R9&5N(&=E;&%B96QD`$UA<#(T(&MA87)T`$UA<%%U97-T:V%A
M<G0`0F5R:6-H="!A;',@9V5W:7-T(&UA<E]K97)E;@!-86%R=`!-87)G90!"
M97)I8VAT(&UA<FME<F5N(&%L<SH`36%R:V5E<B!M970@1V5Z:65N+TYI970@
M1V5Z:65N('9L86=G96X`36%R:V5E<B!M970@86YD97)E('9L86=G96X@*&(N
M=BX@0F5L86YG<FEJ:R]"96%N='=O;W)D*0!-87)C:&%L;"!E:6QA;F1E;@!-
M87)T:6YI<75E`$MO;70@;W9E<F5E;B`H;65T('!L86-E:&]L9&5R<RD`3W9E
M<F5E;FMO;65N9&4@=F5L9&5N`$UA=7)E=&%N:>L`36%U<FET:75S`$UA>&EM
M86%L('1O96=E<W1A86X@:W)E9&EE="X`36%X:6UU;2!B97)I8VAT;VYD97)D
M96QE;B!O=F5R<V-H<F5D96XN`$UA>&EM=6T@=&5M<&5R871U=7(@=F%N(&1E
M(&%F9V5L;W!E;B`R-"!U=7(Z(`!-87AI;75M('1E;7!E<F%T=75R('9A;B!D
M92!A9F=E;&]P96X@-B!U=7(Z(`!-87AI;6%L92!L96YG=&4`36%X:6UU;2!A
M86YT86P@>G=A<G1E(&QI:G-T(&%D<F5S<V5N(&]V97)S8VAR961E;B`H5&]T
M86%L(&%A;G1A;"!A9')E<W-E;CH@)7,L(&UA>&EM=6T@86%N=&%L(&%D<F5S
M<V5N.B`E<RDN($MO;B!G965N(&YI975W92!A9')E<W-E;B!A86X@9&4@>G=A
M<G1E(&QI:G-T('1O979O96=E;BX`36%X:6UU;2!A86YT86P@=VET=&4@;&EJ
M<W0@861R97-S96X@;W9E<G-C:')E9&5N("A4;W1A86P@86%N=&%L(&%D<F5S
M<V5N.B`E<RP@;6%X:6UU;2!A86YT86P@861R97-S96XZ("5S*2X@2V]N(&=E
M96X@;FEE=7=E(&%D<F5S<V5N(&%A;B!D92!W:71T92!L:6IS="!T;V5V;V5G
M96XN`$UE:0!-87EO='1E`$=E;F5E<VMU;F1E`$QE9&5N`$UE;G4@;6]D93H`
M0V5L;&5N('-A;65N=F]E9V5N`$)E<FEC:'0`0F5R:6-H="!M970@<W5C8V5S
M(&=E=F5R:69I965R9"P@;6%A<B!H970@8V5R=&EF:6-A870@=F%N(&1E(&]N
M9&5R9V5T96ME;F1E(&MO;B!N:65T('=O<F1E;B!G979E<FEF:65E<F0N`$)E
M<FEC:'0@=F5R;&]P96XN`$)E<FEC:'1T>7!E`$UE=&%R(%=E97(`345405(@
M8FQO:R!I<R!N:65T(&)E<V-H:6MB86%R+@!-151!4B!B;&]K(&ES(&YI970@
M8F5S8VAI:V)A87(N($1E=&%I;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S>7-T
M965M8F5H965R9&5R+@!-971H;V1E`$UE=')I<V-H`$UE>&EC;P!-:6-R;VYE
M<VGK+"!&961E<F%L92!3=&%T96X@=F%N`$UI9&1E;@!-:6UE('1Y<&4`36EN
M:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N(#(T('5U<CH@`$UI
M;FEM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L;W!E;B`V('5U<CH@`$UI
M<G)O<@!!;&QE<FAA;F1E`$]N=&)R96ME;F1E(%!%05(@;6]D=6QE($A45%!?
M4F5Q=65S="X`2&5T(&%D<F5S+"!W86%R(&1I="!B97)I8VAT(&AE96X@;6]E
M="!W;W)D96X@9&]O<F=E>F]N9&5N+"!O;G1B<F5E:W0`3VYT8G)E:V5N9&4@
M8V]N9FEG=7)A=&EE+B!5(&1I96YT(&1E>F4@;G4@=&4@9V5N97)E<F5N+"!W
M86YN965R('4@9&5Z92!T;V5P87-S:6YG('=I;'0@9V5B<G5I:V5N+@!/;G1B
M<F5K96YD(&)E<FEC:'0@240N`$1E(')E9&5N('9O;W(@869W:6IZ:6YG(&]N
M=&)R965K=`!$92!R961E;B!V;V]R(&AE="!A9G=E>FEG:&5I9&)E<FEC:'0@
M=V5R9"!N:65T(&]P9V5G979E;@!/;G1B<F5K96YD92P@=F5R96ES=&4L(%!%
M05(@;6]D=6QE($UA:6PN`$]N=&)R96ME;F0@<V5S<VEE($E$+@!-80!-;V)I
M96QE(&4M;6%I;`!'96UI9&1E;&0`5VEJ>FEG:6YG<V1A='5M`%=I:GII9R!5
M4DP`36]D=6QU<P!-;VQD879IZRP@4F5P=6)L:65K('9A;@!-;VYA8V\`36]N
M9V]L:>L`36%A;F0@96X@:F%A<@!-86%N9&5L:6IK<P!-;VYT<V5R<F%T`$UA
M86YF87-E;@!-87)O:VMO`%9O;W)N86UE;&EJ:R!O;F)E=V]L:W0`5F]O<FYA
M;65L:6IK(&)E=V]L:W0`5F]O<FYA;65L:6IK('IO;FYI9P!697)P;&%A='-E
M;@!.86%R(&)E;F5D96X`3F%A<B!L:6YK<P!.86%R(')E8VAT<P!296=E;"!N
M86%R(&)E;F5D96X@=F5R<V-H=6EV96X`4F5G96P@;F%A<B!B;W9E;B!V97)S
M8VAU:79E;@!.86%R(&)O=F5N`$YA87(@8F5N961E;@!.86%R(&)O=F5N`$UO
M>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI:G-T96X`365E<G9O
M=61I9V4@<V5L96-T:64`36EJ;B!A8V-O=6YT`$UI:FX@<&]R=&%A;`!-:6IN
M('!O<G1A86QL87EO=70`0FER;6$`3F5E+"!I:R!A8V-E<'1E97(@9&4@=F]O
M<G=A87)D96X@3DE%5`!?06%N=&%L(&1A9V5N('1U<W-E;B!A9G=E>FEG:&5I
M9'-A;G1W;V]R9&5N.@!.86%M`$YA;6EB:>L`3F%U<G4`3F5P86P`3F5D97)L
M86YD`$YE9&5R;&%N9',@06YT:6QL96X`3F5T<V-A<&4@0F%S:7,@55),`$YE
M='-C87!E($-!(&EN=')E:VMI;F<@55),`$YE='-C87!E($-!(&)E;&5I9"!5
M4DP`3F5T<V-A<&4@=F5R;FEE=7=I;F<@55),`$YE='-C87!E(&EN=')E:VMI
M;F<@55),`$YE='-C87!E(%-33"!S97)V97)N86%M`$YE='-C87!E(&-E<G1I
M9FEC86%T8V]M;65N=&%A<@!.971S8V%P92!C97)T:69I8V%A='1Y<&4`3F5T
M=V5R:P!.;V]I=`!.:65U=R!#86QE9&]N:>L`3FEE=7=E(&-A=&5G;W)I90!.
M:65U=V4@;6%A;@!.:65U=V4@4F5G96P`3FEE=7=E(&=E8G)U:6ME<G-N86%M
M("AO<'1I;VYE96PI`$YI975W(%IE96QA;F0`3FEE=7<@<V-H97)M("A?8FQA
M;FLI`$YI975W<P!.:65U=W-G<F]E<&5N`%9O;&=E;F1E`%9O;&=E;F1E(&]P
M=&EE<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.86-H=`!.:75E`$YE90!'
M965N(&)E<V-H:6MB87)E(&-O;F9I9W5R871I961A=&$@;VT@=F5R<V-H:6QL
M96X@=&4@;&%T96X@>FEE;BX`1V5E;B!B97-C:&EK8F%R92!S=')A=&5G:64@
M=F]O<B!H970@;6%K96X@=F%N($E33R!I;6%G97,N`$=E96X@0F%C:V5N9&-O
M;F9I9W5R871I92!V;V]R(&1E>F4@2&]S="!O<&=E9V5V96X`1V5E;B!B86-K
M96YD<R!G96-O;F9I9W5R965R9"!I;B!B86-K96YD<RYP:'``1V5E;B!B871C
M:'-J86)L;V]N+@!%<B!B97-T86%T(&=E96X@8FQO:R!O<"!D92!G979R86%G
M9&4@<&]S:71I90!'965N(&%G96YD86YA86T@;W!G96=E=F5N('9O;W(@34-!
M3"!A=71H96YT:6-A=&EE+@!'965N('=I:GII9VEN9V5N+@!!86X@9&ET(')E
M8VAT(&MU;FYE;B!G965N(&-H:6QD(')E8VAT96X@=V]R9&5N('1O96=E=F]E
M9V0N`$=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O
M<B`E<RX`1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V
M;V]R($944"!61E,N`$=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E
M9V5V96X@=F]O<B!344P@5D93+@!'965N(&-O;F9I9W5R871I96EN9F]R;6%T
M:64@;W!G96=E=F5N('9O;W(@4U%,+6)E<W1A;F0@5D93+@!'965N(&MR961I
M970@;65E<BX`1V5E;B!B97-T96UM:6YG(&]P9V5G979E;BX`1V5E;B!B97-T
M86YD('5P;&]A9&5D`$=E96X@:&5A9&5R<R!O<&=E9V5V96X`17(@:7,@9V5E
M;B!L;V-A=&EE(&EN9V5S=&5L9"X`1V5E;B!B97)I8VAT(&=E;&5V97)D+@!'
M965N(&YA86T@;W!G96=E=F5N+@!'965N(&=E=&%L(&]P9V5G979E;BX`1V5E
M;B!B96QE9&EG96YD92!F;W)T=6YE<P!'965N('=A8VAT=V]O<F0@;W!G96=E
M=F5N('9O;W(@2%144"!A=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@
M;W!G96=E=F5N('9O;W(@24U!4"!A=71H96YT:6-A=&EE+@!'965N('=A8VAT
M=V]O<F0@;W!G96=E=F5N('9A;B!+97)B97)O<R!A=71H96YT:6-A=&EE+@!'
M965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@3&]G:6X@875T:&5N=&EC
M871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R(%!!4U-71"!A
M=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@
M4TU"(&%U=&AE;G1I8V%T:64N`$=E96X@<&%D(&YA87(@9&4@3W!E;E-33"!B
M:6YA<GD@;W!G96=E=F5N+B!$92!/<&5N4U-,(&)I;F%R>2!I<R!N;V1I9R!O
M;2!T92!K=6YN96X@=V5R:V5N(&UE="!02T-3(#$R(&1A=&$N`$=E96X@:&%N
M9V5N9&4@:6YS8VAR:6IV:6YG96XN`$=E96X@;&EN:>MR:6YG`%-C<FEP="!N
M:65T(&=E;6%A:W0N`$=E96X@>FEJ9&5N`$=E96X@=&5K<W0@;W!G96=E=F5N
M`$=E96X@=&EJ9&5L:6IK(&1I<F5C=&]R>2!B97-C:&EK8F%A<B!V;V]R(&-A
M8VAE+@!'965N(&=E8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT=V]O<F0@=F5R
M>F]N9&5N+@!'965N(&=E;&1I9V4@6$U,(&1A=&$@=&5R=6=G97-T=75R9`!'
M965N('=A87)D96X`1V5E;B!V97)S:64@9V5V;VYD96X@:6X@;W)I9VEN96QE
M(&-O;F9I9W5R871I92X@2&5R9V5N97)E97(@8V]N9FEG=7)A=&EE+@!'965N
M('9E<G-I92!G979O;F1E;B!I;B!U=R!C;VYF:6=U<F%T:64N($AE<F=E;F5R
M965R(&-O;F9I9W5R871I92X`1V5E;@!'965N("AV97)P;&EC:'0I`$YO;W)D
M($5U<F]P965S("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!E:6QA;F0`3F]O<F1E
M;&EJ:R!H86QF<F]N9`!-87)I86YE;@!.;V]R=V5G96X`3FEE="!N80!.:65T
M('9O;W(`1V5E;B!D:7)E8W1O<GD`3FEE="!G96QI:FL@86%N`$YI970@9V5I
M;7!L96UE;G1E97)D+@!.:65T(&EN9V5S=&5L9`!.:65T(&]N9&5R<W1E=6YD
M+@!.;W1I=&EE<P!.:65T<R!T92!B;&%D97)E;BP@9V$@=&5R=6<N`$YO=F5M
M8F5R`$=E=&%L`$%A;G1A;"!K87)A:W1E<G,`06%N=&%L(&MO;&]M;65N`$%A
M;G1A;"!R:6IE;@!'971A;&QE;B!N:65T(&]P9V5G979E;B!V;V]R(&)I:G=E
M<FME;B!I;B!E96X@9&ES=')I8G5T:65L:6IS="X`3TL`3V)J96-T`$]B:F5C
M=&5I9V5N86%R`$]C=&%A;`!/:W1O8F5R`$)E;&5D:6=I;F=F:6QT97(`2V%N
M=&]O<@!/;6%N`$%L;&5E;B!)34%0('-E<G9E<G,@;VYD97)S=&5U;F5N(&=E
M9&5E;&1E(&UA<'!E;BX`06QL965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S`%-L
M96-H="#IZ6X@92UM86EL861R97,@=&]E9V5S=&%A;BX`06QL965N(&1E(&5I
M9V5N86%R(&]F(&5E;B!S>7-T965M8F5H965R9&5R(&UA9R!D92!E:6=E;F%A
M<G)E8VAT96X@=F%N(&5E;B!S:&%R92!W:6IZ:6=E;@!/<&5N(&EN(&5E;B!N
M:65U=R!S8VAE<FT`3W!E;E-33"!F;W5T.B!K;VX@9V5E;B!D871A('5I="!H
M970@;VYD97)T96ME;F1E(%,O34E-12!O;F1E<F1E96P@:&%L96XN`$]P96YT
M(&1E>F4@;&EN:R!I;B!E96X@;FEE=7<@<V-H97)M`$)E<W1U<FEN9W-S>71E
M96T`3W!T:65S`$]P=&EE<R!M8G0@<V-R:7!T<R!B:6IW97)K96XN`$]P=&EE
M<R!V;V]R("5S`$=E;W)D96YD92!L:6IS=`!/<F=A;FES=&%T:64`3W)G86YI
M<V%T:64@965N:&5I9`!/<F=A;FES97)E;@!/<FEG:6YE96P@=&]E<&%S<VEN
M9W-S:F%B;&]O;@!/<FEG:6YE;&4@<VIA8FQO;F5N(&EN("5S.@!!;F1E<F4`
M06YD97)E(&EN9F]R;6%T:64`06YD97)E(&]P=&EE<P!%:6=E;F%A<G)E8VAT
M96X`4$%-(&%U=&AE;G1I8V%T:64@:7,@;FEE="!B97-C:&EK8F%A<BX`1&EG
M:71A;&4@4$=0(&AA;F1T96ME;FEN9P!'96-O9&5E<F1E(%!'4"!D871A`$]P
M96YB87)E(%!'4"!S;&5U=&5L`$]N9&5R=&5K96YD92]G96-O9&5E<F1E(%!'
M4"!D871A`%!(4"!C;V1E`%!(4"!S:&5L;`!,:6-H=&4@<F5G96X@;F$@,3(N
M,#`@=75R`$)U:65N(&YA(#$R+C`P('5U<@!/;G=E97)S8G5I96X@;F$@,3(N
M,#`@=75R`%!(4"!?4VAE;&P`5G)I:F4@<G5I;71E`%!A:VES=&%N`%!A;&%U
M`%!A;&5S=&EJ;G,@5&5R<FET;W)I=6TL($)E>F5T`%!A;F%M80!087!U82!.
M:65U=R!'=6EN96$`4&%R86=U87D`1V5D965L=&5L:6IK(&)E=V]L:W0`5V%C
M:'1W;V]R9`!786-H='=O;W)D(&]N:G5I<W0`5V%C:'1W;V]R9"!I<R!V97)E
M:7-T('9O;W(@4D%$2553(&%U=&AE;G1I8V%T:64N`%=A8VAT=V]O<F0@;65T
M(&)E=F5S=&EG:6YG`%=A8VAT=V]O<F0Z`%=A8VAT=V]O<F0Z(`!786-H='=O
M;W)D96X@;6]E=&5N(&]V97)E96YK;VUE;BX`4&QA:VME;@!0;&%K:V5N('9A
M;F%F('!R:6MB;W)D`%!A9`!(86YG96YD92!I;G-C:')I:G9I;F=E;CH`365N
M<V5N`%!R;V-E;G0`3VYD97)H;W5D<W=E<FMZ86%M:&5D96X@=6ET=F]E<F5N
M`$]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I='9O97)E;B!B:6H@86%N;65L
M9&EN9S\`4F5C:'0`4F5C:'1E;F)E:&5E<@!097)S;V]N;&EJ:V4@:6YF;W)M
M871I90!097)U`$AU:7-D:65R96X`4&AI;&EP<&EJ;F5N`%1E;&5F;V]N`$9O
M=&\G<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!+;&EK(&EN(&5E;B!C
M96PL(&$N=2YB+@!"979E<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!V
M97)W:6ID97)E;BP@82YU+F(Z`$)E=F5S=&EG+"!D870@=2!D:70@96QE;65N
M="!W:6QT(&QO<VMO<'!E;&5N+"!A+G4N8BX`1V5E9B!E96X@;6%A;F0@96X@
M965N(&IA87(L(&$N=2YB+@!%96X@;F%A;2!V;V]R(&1E(&YI975W92!C871E
M9V]R:64@:6YV;V5R96XL(&$N=2YB+CH`1V5E9B!E96X@9V5L9&EG($E0(&%D
M<F5S+"!A+G4N8BX`1V5E9B!E96X@9V5L9&EG92!D871U;2!A+G4N8BXL(&-O
M;G1R;VQE97(@:&5T(&%A;G1A;"!D86=E;B!I;B!D92!M86%N9"X`1V5E9B!E
M96X@9V5L9&EG92!T:6ID+"!A+G4N8BX`1V5E9B!D92!N86%M('9A;B!D92!N
M:65U=V4@;6%P+"!A+G4N8BXZ`$=E968@965N('-A;65N=F%T=&EN9R!V86X@
M:&5T('!R;V)L965M+"!A+G4N8BX`1V5E9B!U=R!G96)R=6EK97)S;F%A;2!E
M;B!W86-H='=O;W)D+"!A+G4N8BX`1V5E9B!D92!N:65U=V4@8V%T96=O<FEE
M;F%A;2P@82YU+F(N.@!0;VQE;@!0;VQI=&EE:P!096EL:6YG96X`4&]R='5G
M86P`4&]S:71I;VYE<FEN9R!V86X@9&5Z92!A9F)E96QD:6YG`%!O<VET:6]N
M97)I;F<@=F%N(&1E>F4@=&%B96P`4W1U=7(@;F%A<B!D97IE(&UA<"`H;FEE
M="!A9F=E9'=O;F=E;B!D;V]R($E-05`I`$YE97)S;&%G('9A;B!D92!A9F=E
M;&]P96X@)7,@=7)E;CH@`%!R969S7VQD87`Z('9E<F5I<W1E($Q$05`@97AT
M96YT:64@;FEE="!G979O;F1E;BX`4')E9G-?<V5S<VEO;CH@=F5R96ES=&4@
M<V5S<VEE(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$QU8VAT9')U:P!,=6-H
M=&1R=6L@;W`@>F5E;FEV96%U.B``3'5C:'1D<G5K.B``0F5O;W)D96QE;@!"
M96]O<F1E96P@9&4@869B965L9&EN9R!I;B!E96X@;FEE=7<@<V-H97)M`%9O
M<FEG92!O<'1I97,`1&]C=6UE;G0@869D<G5K:V5N`%!R:79E('-L975T96P`
M4')O8FQE96T`4')O8FQE96UB97-C:')I:G9I;F<`4')O:F5C=&5N`%!R;VUP
M="!T96MS=`!/<&5N8F%R92!S;&5U=&5L`$]P96YB87)E('-L975T96P@86QG
M;W)I=&AM90!/<&5N8F%A<B]0<FEV92!S;&5U=&5L<&%A<B!N:65T(&=E9V5N
M97)E97)D+@!0=65R=&\@4FEC;P!1=6%T87(`475E<GD`4E-!(&]P96YB87)E
M('-L975T96P@*"5D(&)I="D`<E]E9&5N`$ME=7IE<F]N9&IE('-E;&5C=&EE
M`%)E9V5N`%9R;V5G(')E9V5N`$QA870@<F5G96X`4F5G96YB=6D`4F%N9&]M
M($9O<G1U;F4`5F5R:&]U9&EN9P!,97IE;@!,965S(&)E<FEC:'1E;@`E<R!E
M8VAT('9E<G=I:F1E<F5N/R!$97IE(&)E=V5R:VEN9R!K86X@;FEE="!O;F=E
M9&%A;B!G96UA86MT('=O<F1E;BX`1V5B<G5I:V5R<V1A=&$@=F%N(&=E8G)U
M:6ME<B`E<R!E8VAT('9E<G=I:F1E<F5N/R!$97IE(&)E=V5R:VEN9R!K86X@
M;FEE="!O;F=E9&%A;B!G96UA86MT('=O<F1E;BX`3VYT=F%N9V5N("A296-E
M:79E9"D`5F5R9&5R('-T=7)E;B!N86%R`$AE<FAA86QT('5W('9O<FEG92!B
M97=E<FMI;F<`5F5R=F5R<R!D>6YA;6ES8VAE(&UE;G4@;VYD97)D96QE;CH`
M4&]R=&%L=V5E<F=A=F4@=F5R=F5R<V5N.@!296=E>`!296=U;&EE<F4@97AP
M<F5S<VEE`$%F=VEJ>F5N(&UE="!R961E;@!"971R96MK:6YG96X@8G)O=W-E
M<@!/<&UE<FMI;F=E;@!397)V97)S(&]P(&%F<W1A;F0`55),(&]P(&%F<W1A
M;F0@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!697)W:6ID97)E
M;@!";&]K('9E<G=I:F1E<F5N`$MO;&]M('9E<G=I:F1E<F5N`$]P;6%A:R!V
M97)W:6ID97)E;@!086%R('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!H970@;W!G
M97-L86=E;B!S8W)I<'0@=6ET(&1E('1I:F1E;&EJ:V4@9&ER96-T;W)Y(&]P
M(&1E('-E<G9E<BX`5F5R=VEJ9&5R(&1E`%9E<G=I:F1E<B!D97IE(&YO9&4@
M=6ET(&AE="!D;V-U;65N=`!'96)R=6EK97(@=F5R=VEJ9&5R96X`5F5R=VEJ
M9&5R(&=E8G)U:6ME<CH@)7,`5F5R>F]E:R!K;VX@;FEE="!W;W)D96X@8F5A
M;G1W;V]R9"X@1V5R971O=7)N965R9&4@9F]U=&-O9&4Z(`!/<&YI975W('9E
M<GIO;F1E;B!A86X@*%)E<V5N="!T;RD`3W!N:65U=R!V97)Z;VYD96X@9&]O
M<B`H4F5S96YT+69R;VTI`$AE<G-T96QL96X`4F5S970@=V%C:'1W;V]R9`!2
M97-E="!U=R!W86-H='=O;W)D`%)E<W5L=&%T96X`5&5R=6<@;F%A<B!F:6QT
M97)L:6IS=`!497)U9R!N86%R(&]P=&EE<P!497)U9R!N86%R(')E9V5L;&EJ
M<W0`4F5U;FEO;@!#;VYF:6=U<F%T:64@=&5R=6=Z971T96X`4FEC:"!497AT
M($5D:71O<B!O<'1I97,`4F%A9'-E;',`4F5C:'1S`%)E8VAT<V4@:V]P`%)E
M8VAT<V4@=V%A<F1E;@!2:5]J96EG96YS8VAA<'!E;BXN+@!2;VP`4F]E;65N
M:>L`,3@P(&1R86%I96X`3F%A<B!L:6YK<R!D<F%A:65N`$YA87(@<F5C:'1S
M(&1R86%I96X`4FEJ(&5I9V5N<V-H87!P96X`4FEJ(&5I9V5N<V-H87!P96X`
M4FEJ96XZ`%)E9V5L`%)E9V5L(&=E8V]P:65E<F0`4F5G96P@9V5W:7-T`%)E
M9V5L('5I=&=E<V-H86ME;&0`4F5G96P@:6YG97-C:&%K96QD`%)E9V5L;F%A
M;0!,:6YIZW)I;F<`3&EN:>MR:6YG('IA;"!V97)S8VAI:FYE;B!T=7-S96X@
M86QL92!R:6IE;B!E;B!K;VQO;6UE;@!,:6YIZW)I;F<@>F%L(&%L;&5E;B!T
M=7-S96X@:V]L;VUM96X@=F5R<V-H:6IN96X`3&EN:>MR:6YG('IA;"!A;&QE
M96X@='5S<V5N(')I:F5N('9E<G-C:&EJ;F5N`%-T87)T96X`4G5S<VES8VAE
M($9E9&5R871I90!2=V%N9&$`0W)Y<'1O9W)A9FES8VAE(%,O34E-12!H86YD
M=&5K96YI;F<`4R]-24U%(&=E8V]D965R9"!B97)I8VAT`%-!4TP@875T:&5N
M=&EC871I92!I<R!N:65T(&)E<V-H:6MB86%R+@!335,@=F5R<W1U<F5N`%-1
M3"!S:&5L;`!34T@`4U5#0T53`%-?44P@<VAE;&P`6F$`4W0@2&5L96YA`%-T
M($MI='1S(&5N($YE=FES`%-T($QU8VEA`%-T(%!I97)R92!E;B!-:7%U96QO
M;@!3="!6:6YC96YT(&5N(&1E($=R96YA9&EN97,`6F5L9F1E(&9R86UE("A?
M<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!E;B!0<FEN8VEP90!3
M871E;&QI971P<F]V:61E<@!3875D:2!!<F%B:>L`3W!S;&%A;@`E<R!O<'-L
M86%N`$]P=&EE<R!O<'-L86%N`$EN<W1E;&QI;F=E;B!O<'-L86%N`$=E9V5N
M97)E97)D92!C;VYF:6=U<F%T:64@86QS(%!(4"!S8W)I<'0@;W!G97-L86=E
M;B!I;B!D92!T:6ID96QI:FME(&1I<F5C=&]R>2!V86X@=7<@<V5R=F5R+@`E
M<R!C;VYF:6=U<F%T:64@;W!G97-L86=E;@!7971E;G-C:&%P`%-C<FEP=`!3
M8W)I<'0M8FEJ=V5R:V5N`%-C<FEP="!N:65T(&)I:F=E=V5R:W0N`%-C<FEP
M="!S=6-C97-V;VP@9V5A8W1I=F5E<F0N`%-C<FEP="!S=6-C97-V;VP@9V5D
M96%C=&EV965R9"X`6F]E:V5N`%IO96MM86-H:6YE<P!'97II96X`2VEE<R!B
M97-T86YD96X`4V5L96-T965R(&5E;B!D871U;0!396QE8W1E97(@965N('9E
M;&0`4V5L96-T965R(&5E;B!G<F]E<"!O;2!T;V4@=&4@=F]E9V5N`%-E;&5C
M=&5E<B!E96X@;FEE=7=E(&5I9V5N86%R`%-E;&5C=&5E<B!E96X@<V5R=F5R
M`%-E;&5C=&5E<B!E96X@9V5B<G5I:V5R(&]M('1O92!T92!V;V5G96X`4V5L
M96-T965R(&%L;&4@9&%T=6UC;VUP;VYE;G1E;BX`4V5L96-T965R(&5E;B!O
M8FIE8W0`1&]E;&UA<"!S96QE8W1E<F5N`%-E;&5C=&5E<B!D92!B96YO9&EG
M9&4@:V%R86MT97)S('5I="!D92!O;F1E<G-T86%N9&4@=F%K:F5S+B!5(&MU
M;G0@9&5Z92!D86X@:V]P:>MR96X@96X@<&QA:VME;B!I;B!H970@=&5K<W1G
M96)I960N`%-E;&5C=&5E<B!H970@9&%T=6US8VAE:61I;F=S=&5K96XZ`%-E
M;&5C=&5E<B!H970@9&%T=6UF;W)M86%T.@!396QE8W1E97(@9&4@:61E;G1I
M=&5I="!D:64@=2!W:6QT('=I:GII9V5N.@!396QE8W1E97(@:&5T('1I:F1S
M8VAE:61I;F=S=&5K96XZ`%-E;&5C=&5E<B!H970@=&EJ9'-F;W)M86%T.@!3
M96QE8W1E97(@='=E92!O=F5R965N:V]M96YD92!V96QD96XN`%-E;&5C=&5E
M<B!U=R!K;&5U<G-C:&5M82X`4V5L96-T965R('5W(&=E=V5N<W1E('1A86PZ
M`%IE;&8@9V5D969I;FEE97)D92!H96%D97(`4')O8FQE96UR87!P;W)T('9E
M<GIE;F1E;@!697)Z96YD(%--4P!!9GIE;F1E<B`H4V5N9&5R*0!396YE9V%L
M`%-E;G-O<CH@`%-E<'1E;6)E<@!397)V:>L@96X@36]N=&5N96=R;P!397)I
M96YU;6UE<@!397-S:64@240@=F5R;&]P96XN`$EN<W1E;&QE;@!);G-T96QL
M96X@=F%N(&]P=&EE<R!O;2!U('1O92!T92!S=&%A;B!U=R!W86-H='=O;W)D
M('1E(')E<V5T=&5N+"!W86YN965R('4@9&ET(&)E;G0@=F5R9V5T96XN`$EN
M<W1E;&QE;B!V86X@<V5R=F5R<R!O<"!A9G-T86YD(&1I92!U('=I;'0@8F5N
M861E<F5N('9A;G5I="!U=R!P;W)T86PN`$EN<W1E;&QE;B!V86X@=7<@9V5W
M96YS=&4@=&%A;"P@=&EJ9'IO;F4@96X@9&%T=6UO<'1I97,N`$EN<W1E;&QE
M;B!V86X@=7<@;W!S=&%R='1O97!A<W-I;F<L(&ML975R<V-H96UA+"!P86=I
M;F%V97)V97)S:6YG(&5N(&%N9&5R92!W965R9V%V96]P=&EE<RX`26YS=&5L
M;&EN9V5N(&UE="!S=6-C97,@8FEJ9V5W97)K="X`4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&)E<V-H:6MB86%R`%9E<G-C:&EL;&5N9&4@;&]C871I97,@;6]G
M96QI:FL@;65T(&1E('!A<F%M871E<CH@`%-E>6-H96QL96X`5VEN:V5L96X`
M2V]R=&4@<V%M96YV871T:6YG`$1I96YE;B!S;F5L=&]E='-E;B!V;V]R(&1E
M(&UE97-T92!L:6YK<R!G961E9FEN:65E<F0@=&4@=V]R9&5N/P!7965R9V5V
M96X`06-T:65F('-C<FEP="!W965R9V5V96X`2'5I9&EG('-C<FEP="!W965R
M9V5V96X`5F5R<V-H:6QL96X@;&%T96X@>FEE;B!T=7-S96X@9&4@:'5I9&EG
M92!O<&=E<VQA9V5N(&-O;F9I9W5R871I92!E;B!D92!N:65U=V4@9V5G96YE
M<F5E<F1E(&-O;F9I9W5R871I92X`3&%A='-T92!A86YM96QD:6YG<W1I:F0@
M=V5E<F=E=F5N(&)I:B!A86YM96QD96X_`$]P=&EE('=E97)G979E;B!O;2!O
M<FEG:6YE96P@=&4@8F5W87)E;@!+:65Z97(@=V5E<F=E=F5N`%1A8F5L8F5W
M97)K:6YG<W1A86MB86QK('=E97)G979E;C\`)7,@;65N=2!A86X@9&4@;&EN
M:V5R:V%N="!W965R9V5V96X_`%1A8F5L8V5L96EG96YS8VAA<'!E;B!D:6%L
M;V]G=F5N<W1E<B!W965R9V5V96X`5&%B96QE:6=E;G-C:&%P<&5N(&1I86QO
M;V=V96YS=&5R('=E97)G979E;@!486)E;')I:F5I9V5N<V-H87!P96X@9&EA
M;&]O9W9E;G-T97(@=V5E<F=E=F5N`$%F8F5E;&1I;F=S96EG96YS8VAA<'!E
M;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96X`57!L;V%D('=E97)G979E;@!"
M=6EE;@!"=6EE;B!V<F]E9P!"=6EE;B!L86%T`%9E<FML96EN96X`5F5R:VQE
M:6X@;V8@=F5R<&QA871S(&YA8G5R:6=E(&)L;VMK96X@965R<W0`4VEE<G)A
M($QE;VYE`$EN=&5K96YE;@!(86YD=&5K96YI;F<`2&%N9'1E:V5N:6YG(&%L
M9V]R:71H;64`4VEN9V%P;W)E`$=R;V]T=&4`3VYD97)H;W5D(&]V97)S;&%A
M;@!3;&]W86MI:F4`4VQO=F5N:>L`4VYE975W`%-N965U=W9L86%G`%-N965U
M=V)U:65N`%-N965U=V)U:65N(&QA870`4VYE975W9&EE<'1E.B``4VYE975W
M97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@96EL86YD96X`4V]M86QI
MZP!,:65D97)E;B!E;B!G961I8VAT96X`4V]R=&5E<G9O;&=O<F1E('-E;&5C
M=&EE`$)R;VYA9')E<P!:=6ED($%F<FEK80!:=6ED($5U<F]P965S("A)4T\M
M.#@U.2TS*0!:=6ED($=E;W)G:>L@96X@9&4@6G5I9"!386YD=VEC:"!E:6QA
M;F1E;@!:=6ED96QI:FL@:&%L9G)O;F0`4W!A=&GK<FEN9R!T=7-S96X@86%N
M9W)E;GIE;F1E(&-E;&QE;@!3<&%T:>MR:6YG('1U<W-E;B!I;FAO=60@96X@
M<F%N9"!I;B!C96P`4V-H96ED:6YG<W1E:V5N`%-P871IZW)I;F<`4W!A=&GK
M<FEN9R!E;B!V<FEJ92!R=6EM=&4`4W!A;FIE`%-P86T`4W!E8VEA86P@:V%R
M86MT97(@:6YV;V5R`$-E;"!O<'-P;&ET<V5N`$MO;&]M(&]P<W!L:71S96X`
M4FEJ(&]P<W!L:71S96X`4W!O<G0`4W)I($QA;FMA`%-T86YD86%R9`!3=&%R
M(%1R96L`4W1A<G1J86%R`%-T86%T(&]F('!R;W9I;F-I90!3=&%T=7,`1V5E
M;B!V97)D97)E(&-O;G1R;VQE<R!U:71V;V5R96X@86QS(&1E>F4@<F5G96P@
M=F%N('1O97!A<W-I;F<@:7,_`$]P<VQA9V9O<FUA870`061R97,`1&]O<FAA
M;&5N`%-T<FEN9VQI:G-T`%-T<FEP(&1O;65I;B!V86X@:&5T(&%D<F5S`%-T
M:6IL(%M#4U-=`%IO`$]N9&5R7W=E<G`@=F%N(&AE="!V86MA;G1I96)E<FEC
M:'0Z`$]N9&5R=V5R<`!"979E<W1I9V5N`%-U8G-C<FEP=`!3=6-C97,`0V]N
M9FEG=7)A=&EE(&UE="!S=6-C97,@=&5R=6=G97IE="X@5F5R;FEE=7<@;VT@
M=VEJ>FEG:6YG96X@=&4@>FEE;BX`0F%C:W5P8V]N9FEG=7)A=&EE(&UE="!S
M=6-C97-S(&]P9V5S;&%G96XN`"5S(&UE="!S=6-C97,@9V5S8VAR979E;@!3
M;V5D86X`4V%M96YV871T:6YG`%IO;G-O<&=A;F<`6F]N<V]N9&5R9V%N9P!:
M;VYN:6<`6F]N<V]P9V%N9P!:;VYS;W!G86YG+UIO;G-O;F1E<F=A;F<`6F]N
M<V]P9V%N9SH@`%IO;G-O;F1E<F=A;F<`6F]N<V]N9&5R9V%N9SH@`%-U<&5R
M<V-R:7!T`$]N9&5R<W1E=6YI;F<`4W5R:6YA;64`06-H=&5R;F%A;0!3<&ET
M<V)E<F=E;B!E;B!*86X@36%Y96X`4W=A>FEL86YD`%IW961E;@!:=VET<V5R
M;&%N9`!3>6YT87AF;W5T(&EN('IO96MT97)M96X`4WER:7-C:&4@07)A8FES
M8VAE(%)E<'5B;&EE:P!/;G=E97)S8G5I`$]N=V5E<G-B=6EE;@!44U8@8F5S
M=&%N9`!486)E;`!486)E;&5I9V5N<V-H87!P96X`5&%B96QE:6=E;G-C:&%P
M<&5N`%1A:7=A;@!486EW86XL(%!R;W9I;F-I92!V86X@0VAI;F$`5&%D>FII
M:VES=&%N`%1A;GIA;FEA+"!697)E;FEG9&4@4F5P=6)L:65K('9A;@!$;V5L
M.@!486ME;@!496QE9F]O;FYU;6UE<@!496UP97)A='5U<B!V86X@:&5T(&%F
M9V5L;W!E;B!U=7(Z(`!496UP97)A='5U<@!496UP97)A='5U<CH@`%-J86)L
M;V]N8F5H965R`%1E:W-T`$%L;&5E;B!T96MS=`!496MS="!U:71L:6IN96X`
M5&5K<W1B;W9E;FMA;G0`1&\`5&AA:7,@*%1)4RTV,C`I`%1H86EL86YD`$)E
M9&%N:W0@=F]O<B!H970@9V5B<G5I:V5N('9A;B!H970@<WES=&5E;2X`1&4@
M1E10(&5X=&5N=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`$1E($AO<F1E+TMO
M;&%B(&EN=&5G<F%T:64@;VYD97)S=&5U;G0@(B5S(B!N:65T`$1E($UA:6YT
M96YA;F-E.CH@8VQA<W,@=V5R9"!N:65T(&=E;&%D96X`2&5T($]P=&EE<W-C
M:&5R;2!I<R!G97-L;W1E;BX@069S;'5I=&5N+@!$92!B96AE97)D97(@9&EE
M;G0@965N('!E<FUA;F5N="!R96-H=&5N8F%C:V5N9"!T92!C;VYF:6=U<F5R
M96X@86QS('4@<F5C:'1E;B!W:6QT(&=E8G)U:6ME;BX`06QL965N(&1E(&]N
M9&5R:V%N=`!(970@8V]N=&%C="!)1"!N=6UM97(@:7,@;FEE="!O<&=E9V5V
M96XL(&QE96<@9V5L871E;B!O9B!I<R!N:65T(&=E=F]N9&5N(&EN(&1E(&1A
M=&%B87-E+@!(970@861R97,@:7,@;65T('-U8V-E<R!A86X@=7<@861R97-B
M;V5K('1O96=E=F]E9V0N`$AE="!L;W-G96MO<'!E;&1E(%!'4"!O;F1E<G1E
M:V5N:6YG<V)L;VL@:7,@=F5R96ES="!O;2!H970@;VYD97)T96ME;F1E(&)E
M<FEC:'0@=&4@=F5R:69IZW)E;BX`2&5T(&1I<W1R=6)U=&EE;&EJ<W0@240@
M:7,@;FEE="!O<&=E9V5V96XL(&QE96<@9V5L871E;B!O9B!I<R!N:65T(&=E
M=F]N9&5N(&EN(&1E(&1A=&%B87-E+@!$92!D:7-T<FEB=71I96QI:G-T(&ES
M(&YI970@;W!G96=E=F5N+@!(970@<W1U=7)P<F]G<F%M;6$@;65L9'0Z(`!$
M92!C;V1E97)M;V=E;&EJ:VAE9&5N('9E<F5I<V5N(&5E;B!B979E:6QI9V1E
M('=E8G9E<F)I;F1I;F<N`$AE="!B97-T86YD("5S(&1I96YT(&5E;B`E<R!I
M;G-T96QL:6YG('1E(&)E=F%T=&5N+@!(970@8F5S=&%N9"`E<R!D:65N="!E
M;FEG92`E<R!I;G-T96QL:6YG96X@=&4@8F5V871T96XN`$AE="!B97-T86YD
M(&MA;B!N:65T(&YA87(@>FEC:'IE;&8@9V5K;W!I965R9"!W;W)D96XN`$AE
M="!B97-T86YD(&)E=F%T=&4@9V5E;B!D871A+@!(970@=F]L9V5N9&4@>FEJ
M;B!D92!K;W!P96X@=F%N(&1I="!M97-S86=E+W)F8S@R,B!B97)I8VAT+@!6
M86X@9&4@=F]L;&5D:6<@<V-H97)M(&UO9&4@:7,@8F5K96YD+"!D870@9&ET
M('!R;V)L96UE;B!K86X@=F5R;V]R>F%K96X@;65T($EN=&5R;F5T($5X<&QO
M<F5R+"!V86YW96=E(&)R;W=S97)B=6=S('=A87(@=VEJ(&YI970@;VUH965N
M(&MU;FYE;BX@2&5T(&ES(&UO9V5L:6IK(&1A="!U(')O;6UE;"!I;B!H970@
M8F5E;&1S8VAE<FTL(&=E8G)E:R!A86X@961I=&]R9G5N8W1I97,@96XO;V8@
M<F%N9&]M(&)R;W=S97(M(&-R87-H97,@97)V86%R="X@5V%N;F5E<B!U=R!S
M>7-T965M(%=I;F1O=W,@.7@@:7,L(&ES(&AE="!W86%R<V-H:6IN;&EJ:R!D
M870@=2!E96X@)T%L9V5M96YE($)E=F5I;&EG:6YG<R!&;W5T)R!K<FEJ9W0L
M(&5N(&]P;FEE=7<@9&EE;G0@=&4@:&5R<W1A<G1E;BY<;EQN52!B96YT(&=E
M=V%A<G-C:'5W9"X@1')U:R!O<"!/2R!W86YN965R('4@=&]C:"!D92!V;VQL
M961I9R!S8VAE<FT@961I=&]R('=I;'0@<')O8F5R96XN`$1E(&ED96YT:71E
M:70@(B5S(B!I<R!V97)W:6ID97)D+@!!;&QE96X@9&4@;&EN:V5R:V%N=`!$
M92!P;&%A=',@=F%N(&AE="!';G501R!P<F]G<F%M;6$@9&EE;G0@;W!G96=E
M=F5N('1E('=O<F1E;B!I;B!D92!#<GEP=%]P9W`Z.B!C;&%S<RX`2&5T(&)E
M<FEC:'0@=F5R<W1U=7)D(&]P("5S(&%A;B`E<R!M970@;VYD97)W97)P("(E
M<R(@:7,@=V5E<F=E9V5V96XN"D1I="!I<R!G965N(&=A<F%N=&EE(&1A="!H
M970@8F5R:6-H="!I<R!G96QE>F5N(&]F(&)E9W)E<&5N+@!$92!N86%M(&1I
M92!G96)R=6EK="!W;W)D="!B:6H@;&EN:V5N(&YA87(@9&4@;FEE=7<@8F5R
M:6-H="!P86=I;F$`1&4@;W!E;G-S;"!M;V1U;&4@:7,@=F5R96ES="!V;V]R
M(&1E($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`$1E('9O;W)K975R<VEN
M<W1E;&QI;F<@(B5S(B!K;VX@;FEE="!W;W)D96X@;W!G97-L86=E;BP@;VUD
M870@9&4@9&%T82!D92!M87AI;75M('1O96QA871B87)E(&=R;V]T=&4@;W9E
M<G-C:')I:F1T+@!(970@<')O9W)A;6UA(&]M(&1I="!D871A='EP92`H)7,I
M('1E(&)E:VEJ:V5N+"!W97)D(&YI970@;W`@:&5T('-Y<W1E96T@9V5V;VYD
M96XN`$%L;&5E;B!D92!R96-H=&5R+2!E;B!L:6YK97)K86YT`$%L;&5E;B!D
M92!R96-H=&5R:V%N=`!$92!S97)V97(@(B5S(B!I<R!V97)W:6ID97)D+@!$
M92!S97)V97(@(B5S(B!I<R!O<&=E<VQA9V5N+@!(970@86%N;65L9&EN9W-V
M97)Z;V5K('9O;W(@)7,@:7,@=F5R=VEJ9&5R9"X`1&4@;W!G96=E=F5N(')I
M:B!B97-T86%T(&YI970N`$%L;&5E;B!D92!B;W9E;BT@96X@;VYD97)K86YT
M`$%L;&5E;B!D92!B;W9E;FMA;G0`1&4@=7!L;V%D960@9&%T82!I<R!N82!D
M92!V;V]R9V%A;F1E('-T87`@=F5R;&]R96X@9V5G86%N+@!(970@=7!L;V%D
M960@8F5S=&%N9"!I<R!N:65T(&]P9V5S;&%G96XN`$AE="!W96%T:&5R+F-O
M;2!B;&]K(&ES(&YI970@8F5S8VAI:V)A87(N`$=E96X@;W!T:65S(&)E<V-H
M:6MB86%R+@!%<B!Z:6IN(&=E96X@;VYD97)D96QE;BP@=V5L:V4@:6YL:6YE
M('=E97)G96=E=F5N(&MU;FYE;B!W;W)D96XN`$5R('II:FX@=&4@=F5E;"!K
M87)A:W1E<G,@:6X@9&ET('9E;&0N(%4@:&5E9G0@)7,@:V%R86MT97)S(&]P
M9V5G979E;CL@=2!D:65N="!M:6YD97(@9&%N("5S(&]P('1E(&=E=F5N+@!%
M96X@<')O8FQE96T@;65T(&1E(&)E<W1A;F1S=7!L;V%D.B!'965N("5S('=E
M<F0@9V5U<&QO860N`$5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO
M860Z($AE="`E<R!I<R!G<F]T97(@9&%N(&1E(&UA>&EM=6T@=&]E;&%A=&)A
M<F4@9W)O;W1T92`H)60@8GET97,I+@!%96X@<')O8FQE96T@;65T(&1E(&)E
M<W1A;F1S=7!L;V%D.B!(970@)7,@:7,@<VQE8VAT<R!G961E96QT96QI:FL@
M9V5U<&QO860N`$5R('=A<R!E96X@9F]U="!B:6H@:&5T(&%C=&EV97)E;B!V
M86X@:&5T('-C<FEP="X`17(@=V%S(&5E;B!F;W5T(&)I:B!H970@9&5A8W1I
M=F5R96X@=F%N(&AE="!S8W)I<'0N`$5E;B!F;W5T(&)I:B!H970@8F5K:6IK
M96X@=F%N(&1I="!B97)I8VAT;VYD97)D965L`$5E;B!F;W5T(&)I:B!H970@
M:6UP;W)T97)E;B!V86X@9&4@861R97-D871A+@!%96X@9F]U="!B:6H@:&5T
M(&EM<&]R=&5R96X@=F%N(&1E(&E#86QE;F1A<F1A=&$N`$5E;B!F;W5T(&EN
M(&AE="!C;VYF:6=U<F%T:65F;W)M=6QI97(N($UI<W-C:&EE;B!B96YT('4@
M965N('9E<G!L:6-H="!V96QD('9E<F=E=&5N+@!%96X@9F]U="!B:6H@:&5T
M('5I='9O97)E;B!V86X@9&4@;W!G96=E=F5N(&%D<F5S8F]E:V9U;F-T:64N
M(%!R;V)E97(@;&%T97(@;W!N:65U=RP@82YU+F(N`$5E;B!F;W5T(&UE="!H
M970@8FEJ=V5R:V5N('9A;B!D92!A9')E<V1E=&%I;',N(%!R;V)E97(@;&%T
M97(@;W!N:65U=RP@82YU+F(N`$5E;B!F;W5T(&UE="!H970@8FEJ=V5R:V5N
M('9A;B!D92!D:7-T<FEB=71I96QI:G-T+B!0<F]B965R(&QA=&5R(&]P;FEE
M=7<L(&$N=2YB+@!$97IE($E-05`@<V5R=F5R(&]N9&5R<W1E=6YT(&=E96X@
M9&5L:6YG('9A;B!M87!P96XN`$1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@
M<F%R(&)E<W1A;F0@=&4@>FEJ;BX`1&ET(&QI:FMT(&YI970@965N(&=E;&1I
M9R!Z:7`@8F5S=&%N9"!T92!Z:6IN+@!$:70@;&EJ:W0@;FEE="!E96X@9V5L
M9&EG(&MA87)T;G5M;65R('1E('II:FXN`$1I="!S='5U<G!R;V=R86UM82!G
M965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!#;&EC
M:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87D@=&4@=F5R
M>F5N9&5N+"!D+FTN=BX@9&4@2%144"!!4$D`1&ET('-T=75R<')O9W)A;6UA
M(&=E969T(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E('-M
M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87D@=&4@=F5R
M>F5N9&5N+"!D+FTN=BX@9&4@2%144"!!4$D`1&ET('-T=75R<')O9W)A;6UA
M(&=E969T(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(%--5%`@
M9"YM+G8N(&1E(%9O9&%F;VYE($ET86QY(&=A=&5W87D@=&4@=F5R>F5N9&5N
M(&YA87(@5F]D869O;F4@;G5M;65R<RX@2&EE<G9O;W(@:7,@965N(%9O9&%F
M;VYE($ET86QY(&4M;6%I;&%D<F5S("AH='1P.B\O=W=W+C$Y,"YI="D@;F]O
M9'IA:V5L:6IK+@!$:70@=F5L9"!I<R!V97)E:7-T`$1I="!V96QD(&UA9R!A
M;&QE96X@:6YT96=E<G,@8F5V871T96XN`$1I="!V96QD(&UA9R!A;&QE96X@
M9V5T86QL96X@96X@9&4@9'5B8F5L92!P=6YT(&)E=F%T=&5N+@!$:70@=F5L
M9"!M86<@86QL965N(&]C=&%A;"!W86%R9&5N(&)E=F%T=&5N+@!$:70@=F5L
M9"!D:65N="!E96X@:V]M;6$@;V8@<W!A=&EE(&=E<V-H96ED96X@;&EJ<W0@
M;65T(&EN=&5G97)S('1E('II:FX`1&5Z92!W86%R9&4@9&EE;G0@965N(&=E
M;&1I9R!G971A;"!T92!Z:6IN+@!$:70@=F5L9"!D:65N="!E96X@:VQE=7)C
M;V1E(&EN(%)'0B!(15@M9F]R;6%A="!T92!B979A='1E;BP@8BYV+B`G(S$R
M,S1A9B<N`$1I="!F;W)M=6QI97(@:7,@<F5E9',@=F5R=V5R:W0N`$1I="!I
M<R`E<RX`1&ET(&ES(&5E;B!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!/;2!D
M:70@;V)J96-T('=E97(@=&4@9V5V96X@:&5E9G0@=2!E96X@92UM86EL(&-L
M:65N="!N;V1I9R!D:64@:&5T($MO;&%B($=R;W5P=V%R92!F;W)M86%T(&)E
M9W)I:G!T+B!6;V]R(&5E;B!L:6IS="!M970@9&5Z92!E+6UA:6QC;&EE;G1S
M+"!B97IO96L@)7,L(&$N=2YB+@!$:70@8F5R:6-H="!I<R!I;B!E96X@86YD
M97)E(&MA<F%K=&5R<V5T("@E<RD@9V5S8VAR979E;BP@9&%N('5W(&5I9V5N
M+@!$:70@9V5T86P@9&EE;G0@=&5N;6EN<W1E(.GI;B!T92!Z:6IN+@!$97IE
M('-E<G9E<B!K86X@9V5E;B!Z:7`@96X@9WII<"!B97-T86YD96X@=6ET<&%K
M:V5N+@!(970@<WES=&5E;2!I<R!M;VUE;G1E96P@=6ET9V5S8VAA:V5L9"X`
M1&5Z92!W86%R9&4@9&EE;G0@965N(&=E=&%L('1E('II:FXN`$1I="!S8VAE
M<FT@9&EE;G0@86%N9V5R;V5P96X@=&4@=V]R9&5N('9A;G5I="!E96X@3W!T
M:65S<V-H97)M`$]N=V5E<@!4:6-K971S`%1I:F0`5&EJ9'!L86YN:6YG`%1I
M:F1F;W)M86%T`%1I:F1S96QE8W1I90!4:6UO<BU,97-T90!4:71E;`!4:71E
M;"`H=&]O;'1I<"DZ`$%A;@!/;2!M965R9&5R92!O;F1E<F1E;&5N('1E('-E
M;&5C=&5R96XL(&AO=60@9&4@0V]N=')O;"`H4$,I(&]F($-O;6UA;F0@*$UA
M8RD@=&]E=',@=F%S="!T:6ID96YS(&ML:6MK96XN`%9A;F1A86<`2%1-3"!B
M<F]N(&]M<V-H86ME;&5N`%1O9V\`5&]K96QA=0!-;W)G96X`5&]N9V$`0F]V
M96YK86YT`$)O=F5N<W1E(&9R86UE("A?=&]P*0!697)T86QI;F=E;@!4<FEN
M:61A9"!E;B!4;V)A9V\`5')U92!O9B!F86QS90!$:0!4=6YE<VGK`%1U<FMI
M:F4`5'5R:W,@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!E;B!#
M86EC;W,@96EL86YD96X`5'5V86QU`%1Y<"!U=R!K975Z93H@`%4N5BX@:6YD
M97@Z(`!54DP`55),('9O;W(@=7<@869L979E<FEN9W-S=&%T=7-R87!P;W)T
M('-C<FEP=`!54DPZ`$]E9V%N9&$`3V5K<F'O;F4`3FEE="!I;B!S=&%A="!6
M1E,@9&ER96-T;W)Y(&%A;B!T92!S<')E:V5N+@!.:65T(&EN('-T86%T(&5X
M=')A(&=E8G)U:6ME<G-I;F9O<FUA=&EE('1O92!T92!V;V5G96X@8FEJ(&EN
M<V-H<FEJ=F5N+@!.:65T(&EN('-T86%T(&1E(')E8VAT96X@=F%N(%9&4R!B
M97-T86YD("(E<R(@=&4@=VEJ>FEG96XN`$YI970@:6X@<W1A870@9&4@<F5C
M:'1E;B!V86X@5D93(&)E<W1A;F0@)7,O)7,@=&4@=VEJ>FEG96XN`$YI970@
M:6X@<W1A870@=&4@=VEJ>FEG96X@;F%A<B`E<RX`3FEE="!I;B!S=&%A="!M
M970@9&4@4U%,('-E<G9E<B!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@
M;65T(%-33"!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A
M;F0@=&4@:V]P:>MR96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`B
M)7,B('1E(&UA:V5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@
M;6%K96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI
M970@:6X@<W1A870@965N(&QE96<@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI
M970@:6X@<W1A870@9&%T82!U:70@=&4@<&%K:V5N+@!.:65T(&EN('-T86%T
M("(E<R(@=&4@=F5R=VEJ9&5R96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE
M96<`3FEE="!I;B!S=&%A="`E<R!T92!V97)W:6ID97)E;BP@9&4@9&ER96-T
M;W)Y(&ES(&YI970@;&5E9P!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:65F('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R!D
M:7)E8W1O<GD@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@5D93(&1I
M<F5C=&]R>2`E<R!T92!V97)W:6ID97)E;BX`3FEE="!I;B!S=&%A="!61E,@
M8F5S=&%N9"`B)7,B('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&
M4R!B97-T86YD('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R`E
M<R!R96-U<G-I968@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@:'5I
M9&EG92!D:7)E8W1O<GD@=&4@8F5P86QE;BX`3FEE="!I;B!S=&%A="!C97)T
M:69I8V%A=&1E=&%I;',@=6ET('1E(&9I;'1E<F5N`$YI970@:6X@<W1A870@
M;VT@9&4@9&5F:6YI=&EE('9A;B`E<R!T92!L861E;BX`3FEE="!I;B!S=&%A
M="!61E,@8F5S=&%N9"!T92!V97)P;&%A='-E;BX`3FEE="!I;B!S=&%A="!6
M1E,@8F5S=&%N9"`B)7,B('1E(&]P96YE;BX`3FEE="!I;B!S=&%A="!61E,@
M8F5S=&%N9"!T92!O<&5N96X@=F]O<B!S8VAR:6IV96XN`$YI970@:6X@<W1A
M870@5D93(&)E<W1A;F0@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&AE="!I
M;F=E<&%K=&4@8F5S=&%N9"!T92!O<&5N96XN`$YI970@:6X@<W1A870@=F9S
M<F]O="!D:7)E8W1O<GD@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&]M("5S
M('1E(&AE<FYO96UE;B!N86%R("5S.B!B97-T96UM:6YG<VUA<"!B97-T86%T
M(&%L`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!H97)N;V5M96XN
M`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!H97)N;V5M96XN
M`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!H97)N;V5M96XN
M`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@)7,O)7,@=&4@:&5R;F]E;65N
M+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&AE<FYO96UE;BX`2V%N
M("=M:VES;V9S)R!N:65T('5I='9O97)E;BX`3FEE="!I;B!S=&%A="!D:70@
M5V]R9"!D;V-U;65N="!T92!V97)T86QE;@!.:65T(&EN('-T86%T(%9&4R!B
M97-T86YD("(E<R(@=&4@<V-H<FEJ=F5N+@!.:65T(&EN('-T86%T(%9&4R!B
M97-T86YD('1E('-C:')I:G9E;B`H8V]P>2@I(&9A:6QE9"DN`$YI970@:6X@
M<W1A870@5D93(&)E<W1A;F1S9&%T82!T92!S8VAR:6IV96XN`$]N9&5R<W1R
M97!E;@!(97)S=&5L('=I:GII9VEN9V5N`$1O970@=7<@;&%A='-T92!B97=E
M<FMI;F<@=&5N:65T`$]N=F5R=V%C:'0@86YT=V]O<F0@=F%N(&1E('-E<G9E
M<B!O<"!V97)B:6YD:6YG.B``3VYV97)W86-H="!A;G1W;V]R9"!V86X@<V5R
M=F5R(&%A;CH@`$]N8F5N;V5M9`!5;FEC;V1E("A55$8M."D`5F5R96YI9V1E
M($%R86)I<V-H92!%;6ER871E;@!697)E;FEG9"!+;VYI;F=K<FEJ:P!697)E
M;FEG9&4@4W1A=&5N`%9E<F5N:6=D92!3=&%T96XL(&ML96EN92!B=6ET96X@
M;&EG9V5N9&4@96EL86YD96X`165N:&5D96X`3VYB96ME;F0`3VYB96ME;F0@
M87!I;7-G:60@*$%022!-97-S86=E($E$*2X`3VYB96ME;F0@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2X`3VYB96ME;F1E(&=E8G)U:6ME<G-N86%M
M(&]F('=A8VAT=V]O<F0N`$AE="!H=6ED:6=E(&5L96UE;G0@;&]S:V]P<&5L
M96X`3VYB96YO96UD`$YI970@9V5R96-H=&EG9&4@<V-R:7!T<R!K=6YN96X@
M<')O9W)A;6UA;6%T:6<@;FEE="!+;FEP<&5N+TMO<&GK<F5N+U!L86MK96XL
M('9A;G=E9V4@8F5V96EL:6=I;F=S<F5D96YE;BX@2VQI:R!O<"!/2R!O;2!E
M96X@=&5C:&YI<V-H92!O<&UE<FMI;F<@;W`@;6]Z:6QL82YO<F<@=&4@8F5K
M:6IK96X@:&]E('4@965N('-C<FEP="!T;V5S=&%A="!H970@<')I:V)O<F0@
M=&4@8F5N861E<F5N+@!+;&5U<B!T97)U9W-T96QL96X`3FEE="!O;F1E<G-T
M975N9&4@97AT96YT:64`0FEJ=V5R:V5N`"5S(&)I:G=E<FME;@!'96)R=6EK
M97(@8FEJ=V5R:V5N+@!5<&=R861E('-C<FEP="!V97)W:6ID97)D+@!5<&QO
M860`06QL92!T;V5P87-S:6YG('-E='5P8F5S=&%N9&5N(&YA87(@9&4@<V5R
M=F5R(&=E=7!L;V%D+@!,871I:FYS92!H;V]F9&QE='1E<G,`1W)O=&4@4F]M
M96EN<V4@9V5T86QL96X`57)U9W5A>0!'96)R=6EK(&AU:61I9V4Z("5S`$=E
M8G)U:6L@4U-,`$=E8G)U:6ME;B!W86YN965R(&YA86TO=V%C:'1W;V]R9"!V
M97)S8VAI;'0@;65T($E-4U`@<V5R=F5R+@!'96)R=6EK97(@)7,@:7,@;FEE
M="!G96%U=&]R:7-E97)D('9O;W(@)7,N`$=E8G)U:6ME<G-B96AE97(`1V5B
M<G5I:V5R<V]P=&EE<P!'96)R=6EK97)S<F5G:7-T<F%T:64`1V5B<G5I:V5R
M<W)E9VES=')A=&EE(&ES('5I=&=E<V-H86ME;&0@;W`@9&5Z92!S:71E+@!'
M96)R=6EK97)S;F%A;0!'96)R=6EK97)S;F%A;3H`1V5B<G5I:V5R<VYA86TZ
M(`!'96)R=6EK97)S(&EN(&AE="!S>7-T965M.@!/97IB96MI<W1A;@!61E,@
M9&ER96-T;W)Y(&)E<W1A870@;FEE="X`069W97II9VAE:60`069W97II9VAE
M:60@8F5W97)K96X`069W97II9VAE:61S8F5R:6-H=`!686MA;G1I92!W;W)D
M="!N:65T(&]N9&5R<W1E=6YD(&EN(&AE="!H=6ED:6=E(&9I;'1E<G-T=75R
M<')O9W)A;6UA+@!'979O;F1E;B!G96QD:6=E(&QO8V%T:65S(&)E=F%T=&5N
M.B``1V5L9&EG:&5I9`!786%R9&4@:6X@;6EN=71E;B!V86YA9B!N=2X`5V%A
M<F1E;@!786%R9&5N('=A87)U:70@9V5S96QE8W1E97)D(&MA;B!W;W)D96X`
M5F%N=6%T=0!687)I86)E;&4`5F5N97IU96QA`%9E<FEF:6-A=&EE(&UI<VQU
M:W0@+2!E<B!K86X@;65T(&1I="!B97)I8VAT(&=E:VYO96ED('II:FXN`%9E
M<G-I90!697)S:65C;VYT<F]L90!697)T:6MA86P@=6ET;&EJ;F5N`%9E<G1I
M:V%L92!V<FEJ92!R=6EM=&4`5F5R=&EK86%L.@!%<F<@:&]O9P!6:65T;F%M
M`%9I971N86UE97,@*%9)4T-)22D`)7,@8F5K:6IK96X`0F5K:6IK(&5E;B!E
M>'1E<FYE('=E8G!A9VEN80!"96MI:FME;B!A;',@)7,`36%A9V1E;B!E:6QA
M;F1E;BP@0G)I='-E`$UA86=D96X@96EL86YD96XL(%8N4RX`6FEC:'0`6FEC
M:'0Z(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!05)30TA55TE.
M1R$A(2`@5D525TE*1$52(%-#4DE05"!(04Y$34%424<@54E4("5S+@!786QL
M:7,@96X@1G5T=6YA`%=A87)S8VAU=VEN9P!7;P!7965R<W9O;W)U:71Z:6-H
M=`!7965R8F5R:6-H="!G96=E=F5N<R!G96QE=F5R9"!D;V]R`%=E871H97(N
M8V]M`%=E8@!796)S:71E`%=E:V5L:6IK<P!796QK;VT`5V5L:V]M(&)I:B`E
M<P!796QK;VTL("5S`%=E<W1E<G,@*$E33RTX.#4Y+3$I`%=E<W1E<G,@*$E3
M3RTX.#4Y+3$U*0!797-T96QI:FME(%-A:&%R80!77VET=&4@;&EJ<W0@861R
M97-S96X`5V5L:V4@=&]E<&%S<VEN9R!D:65N="`E<R!W965R('1E(&=E=F5N
M(&YA(&%A;FUE;&1I;F<_`%=A="!I<R!H970@<V-H96ED:6YG<VMA<F%K=&5R
M/P!7870@:7,@:&5T(&-I=&%A=&MA<F%K=&5R/P!796QK92!F87-E;@!796QK
M92!P;'5G:6YS('9O;W(@9&4@4FEC:"!497AT(&5D:71O<B!I;G-C:&%K96QE
M;BX`5VET=&4@;&EJ<W0`5VET=&4@;&EJ<W0@8F5W97)K96X`5VET=&4@;&EJ
M<W0@=V]R9'0@;FEE="!O;F1E<G-T975N9"!I;B!H970@:'5I9&EG92!F:6QT
M97)S='5U<G!R;V=R86UM82X`5VET=&4@;&EJ<W0@861R97-S96X`0G)E961T
M90!"<F5E9'1E(&EN($-34R!E96YH961E;@!"<F5E9'1E('9A;B!H970@)7,@
M;65N=2!A86X@9&4@;&EN:V5R:V%N="`H86MT:65F(&)I:B!V;VQG96YD92!A
M86YM96QD:6YG*3H`0G)E961T92!V86X@9&4@=&%B96P`0G)E961T92!E96YH
M96ED`$)R965D=&4Z`%=I:VD`5VEN9`!7:6YD<VYE;&AE:60@:6X@:VYO<&5N
M`%=I;F0Z`%=I;F0Z(`!7:6IS:&5I9`!797)K`%=E<FMA9')E<P!496PN;G(N
M("AW97)K*0!8+5!R:6]R:71Y`%@M4F5F`%@M4W!A;2U,979E;`!8+5-P86TM
M4V-O<F4`6"U3<&%M+5-T871U<P!8-3`Y=C,@8F%S:7-B97!E<FMI;F=E;@!8
M-3`Y=C,@=6ET9V5B<F5I9"!S;&5U=&5L9V5B<G5I:P!8-3`Y=C,@86QT97)N
M871I979E(&]N9&5R=V5R<&YA86T`6#4P.78S(&]N9&5R=V5R<"!S;&5U=&5L
M:61E;G1I9FEC871O<@!8-3`Y=C,@97AT96YT:65S`$I*`$I*2DH`66%H;V\A
M(&UA<`!*86%R;&EJ:W,`2F5M96X`2F$`2F$L(&EK(&%C8V5P=&5E<B!D92!V
M;V]R=V%A<F1E;@!5(&)E;G0@:6X@5$5+4U0@34]$12X@1V5B<G5I:R!D92!;
M/#Y=(&MN;W`@;VT@;F%A<B!765-)5UE'('1E<G5G('1E('-C:&%K96QE;BX`
M52!B96YT(&YI970@9V5A=71H96YT:69I8V5E<F0N`%4@:W5N="!G965N("=<
M)R!K87)A:W1E<B!I;B!U=R!V;VQL96=E(&YA86T@:&5B8F5N+@!5(&AE969T
M(&=E96X@9V5L9&EG(&4M;6%I;&%D<F5S(&]P9V5G979E;BX`52!H965F="!G
M965N('9E;&1E;B!U:70@:&5T(&=E:6UP;W)T965R9&4@8F5S=&%N9"!G96MO
M<'!E;&0@;65T(&1E(&]V97)E96YK;VUS=&EG92!V96QD96X@:6X@)7,N`%4@
M8F5N="!A9F=E;65L9"X`52!D:65N="!E96X@9V5L9&EG(&UO8FEE;"!N=6UM
M97(@:6X@=&4@=F]E<F5N+"!A;&QE96X@8VEJ9F5R<R!M970@965N(&]P=&EO
M;F5L92`G*R<@=F]O<B!H970@:6YT97)N871I;VYA;&4@:VEE<W9O;W)V;V5G
M<V5L+@!5(&1I96YT(&5E;B!G96QD:6=E('=A87)D92!O<"!T92!G979E;BX`
M52!D:65N="!E96X@1&%T851R964@8F%C:V5N9"!T92!C;VYF:6=U<F5R96X@
M;VT@:6YS8VAR:6IV:6YG96X@=&4@:W5N;F5N(&=E8G)U:6ME;BX`52!D:65N
M="!H970@<')O8FQE96T@=&4@8F5S8VAR:6IV96XL('9O;W)D870@=2!H970@
M<')O8FQE96UR87!P;W)T(&MU;G0@=F5R>F5N9&5N+@!5(&1I96YT(&5E;B!5
M4DP@:6X@=&4@=F]E<F5N('=A87)N86%R(&1E>F4@;&EN:R!V97)W:6IS=`!5
M(&1I96YT(&5E;B!S97)V97(@=&4@<V5L96-T97)E;B!O;2!T92!V97)W:6ID
M97)E;BX`52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@
M;VT@=&4@=VES<V5N+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T
M92!G979E;B!O;2!T92!V97)W:6ID97)E;BX`52!M;V5T('1E;FUI;G-T92#I
MZ6X@12U-86EL(&%D<F5S(&]P9V5V96X@=V%A<G9O;W(@:&5T(&%F=V5Z:6=H
M96ED<R!F:6QT97(@;6]E="!W;W)D96X@9V5A8W1I=F5E<F0N`%4@9&EE;G0@
M965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M('1O92!T92!V;V5G
M96XN`%4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M
M(&)I:B!T92!K=6YN96X@=V5R:V5N+@!5(&1I96YT(&5E;B!B97=E<FMI;F<@
M;W`@=&4@9V5V96X@=V5L:V4@=6ET9V5V;V5R9"!M;V5T('=O<F1E;BX`52!D
M:65N="!E96X@;FEE=7=E(&-A=&5G;W)I96YA86T@;W`@=&4@9V5V96XN`%5W
M("5S('-E<W-I92!I<R!V97)L;W!E;BX@3W!N:65U=R!A86YM96QD96XL(&$N
M=2YB+@!5=R!E+6UA:6QA9')E<P!5=R!686XZ(&%D<F5S.@!5=R!I;F9O<FUA
M=&EE`%5W(&EN=&5R;F5T861R97,@:7,@9V5W:6IZ:6=D('-I;F1S(&AE="!B
M96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U=R!V96EL:6=H96ED('1E(&)E
M<V-H97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T92!M96QD96XN
M`%5W(&YA86TZ`$AE="!W965R9V5V96X@=F%N(&5E;B!G96)R=6EK97)S;&EJ
M<W0@=V]R9'0@;FEE="!O;F1E<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T
M:64@8F%C:V5N9"P@;V8@9&5Z92!O<'1I92!I<R!O;2!A;F1E<F4@<F5D96YE
M;B!U:71G97-C:&%K96QD+@!5=R!B<F]W<V5R(&QI:FMT('1E('II:FX@9V5W
M:6IZ:6=D('-I;F1S(&AE="!B96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U
M=R!V96EL:6=H96ED('1E(&)E<V-H97)M96XL(&1I96YT('4@>FEC:"!O<&YI
M975W(&%A;B!T92!M96QD96XN`%5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z
M92!M;V=E;&EJ:VAE:60@;FEE="X`57<@:'5I9&EG92!T:6ID>F]N93H`57<@
M<W1A;F1A87)D(&ED96YT:71E:70Z`%5W('9O;&QE9&EG92!N86%M.@!5=R!N
M:65U=V4@=V%C:'1W;V]R9"!V;V]R("5S(&ES.B`E<P!5=R!O<'1I97,@>FEJ
M;B!B:6IG97=E<FMT+@!5=R!W86-H='=O;W)D(&ES(&=E<F5S970`57<@=V%C
M:'1W;V]R9"!I<R!V97)N:65U=V0L(&-O;G1R;VQE97(@=7<@92UM86EL(&5N
M(&UE;&0@86%N(&UE="!U=R!N:65U=V4@=V%C:'1W;V]R9"X`57<@<V5R=F5R
M<R!O<"!A9G-T86YD.@!*;V5G;W-L879IZP!:8>]R90!:86UB:6$`6FEM8F%B
M=V4`6FEP<'D`6U9E<F)E<F<@86%N9V5H86%L9&4@=&5K<W1=`%M'965N(&]N
M9&5R=V5R<%T`6U!R;V)L965M<F%P<&]R=%T`6T%A;F=E:&%A;&1E('1E:W-T
M('=E97)G979E;B`M`%M!86YG96AA86QD92!T96MS="`M("5S(')E9V5L<UT`
M6W)E9V5L("5S('9A;B`E<UT`7T%D<F5S<V5N('=A87)N86%R(&UO970@=V]R
M9&5N(&1O;W)G97-T=75R9#H`7T%D<F5S<V5N('=A87(@9V5E;B!A;G1W;V]R
M9"!N86%R(&=E<W1U=7)D(&UO970@=V]R9&5N.@!"7V5H965R`%I?=V%R=&4@
M;&EJ<W0`7T-,20!?1&%T851R964`5F5R7W=I:F1E<B!R:6H`0F5R:6-H="!V
M;VQL961I9R!?=VES<V5N`%!L86%T<R!?:65D97(@861R97,@;W`@965N(&YI
M975W92!R96=E;`!?1&]O<G-T=7)E;@!?1W)O97!E;@!?2&5L<`!?069B965L
M9&EN9W-E:6=E;G-C:&%P<&5N+BXN`%]"97=A87(@965N(&MO<&EE('9A;B!B
M97)I8VAT96X@:6X@9&ET(&%C8V]U;G0_`%]!86YM96QD96X`7T%F;65L9&5N
M`%]7:6IZ:6<@;&EN:RXN+@!"97)I8VAT(&YA87(@9&5Z92!M87`@7W9E<G!L
M86%T<V5N.@!?36EJ;B!E+6UA:6P@861R97-S96XZ`%]/<'1I97,`7U)E8VAT
M96X`7U9E<G=I:F1E<B!L:6YK+BXN`%]38W)I<'0`7TEN<W1E;&QE;@!?5&%B
M96QE:6=E;G-C:&%P<&5N+BXN`$=E7V)R=6EK97)S`%]686MA;G1I90!7:71T
M92!L:5]J<W0`061R97-B;V5K`&5N`$MA;&5N9&5R`$MA;&T`2VQI:R!H:65R
M`&1A;&5N9`!V96QD`&)E<W1A;F0`=F%N(&1E("5S("@E<RD@;W`@)7,@)7,`
M:#H`;VYM:61D96QI:FL`:6YL:6YE`')E9V5L<UT`;W9E<F5E;FMO;65N9"!M
M970`;6MI<V]F<R!F;W5T8V]D92`E9"!B:6H@:&5T(&%A;FUA:V5N('9A;B!)
M4T\N`&YA86T`;FEE="!V86X@=&]E<&%S<VEN9P!.;V<@;FEE="!V86X@=&]E
M<&%S<VEN9P!N;W1I=&EE8F]E:P!O9@!P<F]C96YT`'!I>&5L<P!P<F]C;6%I
M;'-C<FEP="!G96=E;F5R965R9"!D;V]R($EN9V\`<W1I:F=E;F0`=&]O;B!V
M97)S8VAI;&QE;@!3:65V92!F:6QT97(@9V5G96YE<F5E<F0@9&]O<B!);F=O
M`'-M<S)E;6%I;"!V:6$@2%144`!S=&%B:65L`'1A:V5N;&EJ<W0`5F]E<BP@
M=&5R(&)E=F5S=&EG:6YG+"!H970@=V%C:'1W;V]R9"!T=V5E(&UA86P@:6X`
M=6YI9FEE9`!O;F)E;F]E;60`1V5B<G5I:V5R<V5L96-T:64`=D-A<F0`=SH`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A;&4O<&Q?4$PO````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T
M-P`P,3<V,S``(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]P
M;%]03"],0U]-15-304=%4R\`````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S0W`#`R,30Q-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEN9V\O;&]C86QE+W!L7U!,+TQ#7TU%4U-!1T53+VEN9V\N;6\`````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`Q-C8T-S4`,3`T,3<S-C(W-#<`,#(R-S(V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-X2!)4`
M````Y`,``!P````\'P``404``%P^````````H%,``$@```"A4P``#@```.I3
M```/````^5,```T````)5```"````!=4```+````(%0```P````L5```!```
M`#E4```#````/E0``!L```!"5```+0```%Y4```D````C%0``"D```"Q5```
M&0```-M4```,````]50```L````"50``$0````Y5```.````(%4```4````O
M50``*````#55```(````7E4```H```!G50``$@```')5```.````A54```H`
M``"450``#0```)]5```.````K54``!$```"\50``#0```,Y5```,````W%4`
M``T```#I50``!@```/=5```,````_E4```X````+5@``#@```!I6```(````
M*58```D````R5@``&@```#Q6```R````5U8``#@```"*5@``5````,-6``!1
M````&%<``%H```!J5P``5P```,57```T````'5@```4```!26```$0```%A8
M```(````:E@``!````!S6```#P```(18```*````E%@``"$```"?6```#P``
M`,%8```#````T5@```D```#56```#0```-]8```2````[5@```\`````60``
M"@```!!9```/````&UD```@````K60``)````#19```4````65D``!8```!N
M60``"````(59```M````CED``!D```"\60``$P```-99```'````ZED```P`
M``#R60``#@```/]9```#````#EH```L````26@``!P```!Y:```'````)EH`
M``4````N6@```P```#1:```7````.%H```H```!06@``#P```%M:```4````
M:UH``!@```"`6@``#@```)E:```4````J%H``!<```"]6@``%P```-5:```7
M````[5H```\````%6P``'P```!5;```'````-5L```8````]6P``"````$1;
M```/````35L```8```!=6P``"````&1;```*````;5L``!0```!X6P``"P``
M`(U;```5````F5L```T```"O6P``!P```+U;```%````Q5L``!$```#+6P``
M#````-U;```J````ZEL```D````57```!P```!]<```%````)UP``#D````M
M7```"@```&=<```&````<EP```D```!Y7```!P```(-<```O````BUP``"X`
M``"[7```50```.I<```M````0%T``"T```!N70``+0```)Q=```C````RET`
M`",```#N70``+0```!)>```S````0%X``!4```!T7@``&0```(I>```I````
MI%X``"0```#.7@``,@```/->```1````)E\```H````X7P``#````$-?```*
M````4%\``!````!;7P``%@```&Q?```6````@U\```<```":7P``!P```*)?
M```4````JE\```H```"_7P```P```,I?```+````SE\```<```#:7P``!P``
M`.)?```&````ZE\```4```#Q7P``!P```/=?```&````_U\```@````&8```
M"0````]@```.````&6```#L````H8```$P```&1@```5````>&````X```".
M8```"@```)U@```$````J&````<```"M8```"0```+5@```6````OV````0`
M``#68```!@```-M@```(````XF````,```#K8````P```.]@```3````\V``
M``@````'80``"````!!A```(````&6$``$$````B80``(````&1A```&````
MA6$```8```",80``%0```)-A```8````J6$``"(```#"80``'0```.5A```*
M`````V(```X````.8@``%0```!UB```"````,V(```H````V8@``#P```$%B
M```/````46(```D```!A8@``%````&MB```8````@&(``!T```"98@``$P``
M`+=B```1````RV(```0```#=8@``!@```.)B``!4````Z6(```X````^8P``
M#@```$UC``!$````7&,```4```"A8P``!0```*=C```1````K6,``!$```"_
M8P``'````-%C```0````[F,``!$```#_8P``#````!%D```7````'F0``!``
M```V9```"````$=D```%````4&0```P```!69```$````&-D```-````=&0`
M``<```""9```#0```(ID```'````F&0```<```"@9```!P```*AD```4````
ML&0```D```#%9```"@```,]D```,````VF0``!````#G9```!0```/AD```E
M````_F0``!(````D90``$P```#=E```K````2V4``#L```!W90``(````+-E
M```V````U&4```@````+9@``$````!1F```(````)68```P````N9@``!```
M`#MF```'````0&8```H```!(9@``#@```%-F```>````8F8``!L```"!9@``
M(0```)UF```>````OV8``!X```#>9@``+@```/UF```;````+&<``!X```!(
M9P``,P```&=G```O````FV<``"````#+9P``$@```.QG```I````_V<``!X`
M```I:```%@```$AH``!!````7V@```<```"A:```!@```*EH```-````L&@`
M`!````"^:```$0```,]H```2````X6@```<```#T:```!````/QH```,````
M`6D``"@````.:0```P```#=I```&````.VD```X```!":0```@```%%I```(
M````5&D```H```!=:0``!0```&AI```$````;FD```X```!S:0``$0```()I
M```(````E&D```T```"=:0``$````*MI```3````O&D``!,```#0:0``!@``
M`.1I```)````ZVD``!````#U:0``#`````9J```1````$VH``!D````E:@``
M"P```#]J```-````2VH``!D```!9:@``&P```'-J```T````CVH```H```#$
M:@``&````,]J```9````Z&H``!8````":P``+P```!EK```'````26L``!4`
M``!1:P``(0```&=K```E````B6L``!$```"O:P``!P```,%K```4````R6L`
M`"\```#>:P``"0````YL```*````&&P```@````C;```%@```"QL```/````
M0VP``#H```!3;```"````(YL```O````EVP```T```#';```)@```-5L```(
M````_&P``!(````%;0``#P```!AM```0````*&T```T````Y;0``"````$=M
M```2````4&T```@```!C;0``"P```&QM```%````>&T```8```!^;0``!P``
M`(5M```$````C6T```<```"2;0``"@```)IM```/````I6T``!````"U;0``
M%P```,9M```1````WFT``!<```#P;0``!0````AN```+````#FX```4````:
M;@``#0```"!N```;````+FX```D```!*;@``#@```%1N```-````8VX```D`
M``!Q;@``(````'MN```'````G&X```D```"D;@``$0```*YN```'````P&X`
M``4```#(;@``%0```,YN```3````Y&X```<```#X;@``"`````!O```&````
M"6\``!`````0;P``#P```"%O```0````,6\```\```!";P``"P```%)O```/
M````7F\```P```!N;P``#P```'MO```'````BV\```X```"3;P``!@```*)O
M```&````J6\```X```"P;P``(0```+]O```9````X6\``!<```#[;P``%P``
M`!-P```;````*W````T```!'<```#````%5P```#````8G````@```!F<```
M!````&]P```,````='````D```"!<```#@```(MP```+````FG```!L```"F
M<```$P```,)P```9````UG```!L```#P<```#@````QQ```+````&W$```P`
M```G<0``#0```#1Q``!#````0G$``#$```"&<0``0@```+AQ``!'````^W$`
M`$\```!#<@``/0```)-R``!.````T7(``!$````@<P``!P```#)S```'````
M.G,```0```!"<P``)0```$=S```5````;7,```<```"#<P``!@```(MS```-
M````DG,``!````"@<P``&P```+%S```$````S7,```4```#2<P``!@```-AS
M```'````WW,```4```#G<P``"0```.US```"````]W,```T```#Z<P``#```
M``AT```8````%70```8````N=```"0```#5T```'````/W0```8```!'=```
M"@```$YT```$````670```D```!>=```"````&AT```&````<70```T```!X
M=```!@```(9T```$````C70```4```"2=```(0```)AT```$````NG0```0`
M``"_=```!0```,1T```=````RG0```0```#H=```#````.UT```*````^G0`
M``@````%=0``"0````YU```%````&'4``"D````>=0``!P```$AU```'````
M4'4```H```!8=0``#P```&-U```0````<W4```8```"$=0``"0```(MU```2
M````E74``!````"H=0``!0```+EU```)````OW4``#(```#)=0``!````/QU
M```,`````78``!<````.=@``'````"9V```3````0W8``!0```!7=@``&0``
M`&QV```$````AG8```<```"+=@```@```)-V```%````EG8```8```"<=@``
M!@```*-V```%````JG8```<```"P=@``!P```+AV```%````P'8```8```#&
M=@``!````,UV```$````TG8```H```#7=@``!0```.)V```,````Z'8```\`
M``#U=@``"@````5W```(````$'<``"L````9=P``!````$5W```(````2G<`
M`"8```!3=P``$@```'IW```&````C7<```H```"4=P``!P```)]W```(````
MIW<``"````"P=P``#@```-%W```6````X'<``!$```#W=P``!@````EX```'
M````$'@```D````8>```%0```")X```'````.'@``!8```!`>```#0```%=X
M```0````97@```<```!V>```&@```'YX```)````F7@```H```"C>```#```
M`*YX```/````NW@```8```#+>```!P```-)X```+````VG@``$<```#F>```
M#0```"YY```#````/'D```H```!`>0```@```$MY```$````3GD```,```!3
M>0``!0```%=Y```J````77D```H```"(>0``!````)-Y```&````F'D```@`
M``"?>0``"````*AY```$````L7D```4```"V>0``:````+QY```8````)7H`
M``4````^>@``!@```$1Z```0````2WH``!````!<>@``"@```&UZ```/````
M>'H```H```"(>@``"0```)-Z```#````G7H```<```"A>@``"@```*EZ```+
M````M'H```<```#`>@``&@```,AZ``!*````XWH```8````N>P``"0```#5[
M```F````/WL``!D```!F>P``&P```(![```-````G'L```H```"J>P``!P``
M`+5[```4````O7L```8```#2>P``"````-E[```'````XGL```H```#J>P``
M"P```/5[```'`````7P```0````)?```"0````Y\```)````&'P```H````B
M?```#@```"U\```,````/'P```<```!)?```"0```%%\```'````6WP```H`
M``!C?```"@```&Y\```)````>7P```<```"#?```*0```(M\```$````M7P`
M``<```"Z?```!0```,)\```%````R'P```L```#.?```%````-I\```'````
M[WP```4```#W?```#0```/U\```,````"WT```@````8?0``"P```"%]```$
M````+7T```0````R?0``#````#=]```)````1'T```4```!.?0``!P```%1]
M```$````7'T``",```!A?0``"@```(5]```N````D'T``!````"_?0``+@``
M`-!]```4````_WT``"T````4?@``+0```$)^```Q````<'X``"T```"B?@``
M+@```-!^```O````_WX``"P````O?P``%````%Q_```4````<7\```0```"&
M?P``#@```(M_```&````FG\```P```"A?P``$````*Y_```'````OW\```X`
M``#'?P``!0```-9_```&````W'\```@```#C?P``$0```.Q_```.````_G\`
M``(````-@```!P```!"````&````&(````0````?@```'P```"2````4````
M1(````<```!9@```'@```&&````.````@(````P```"/@```$P```)R````*
M````L(````4```"[@```$0```,&````-````TX```!$```#A@```)````/.`
M```5````&($``!(````N@0``#@```$&!```9````4($```@```!J@0``"0``
M`'.!```*````?8$```@```"(@0``!0```)&!```&````EX$``!````">@0``
M"````*^!```(````N($``!(```#!@0``&@```-2!```)````[X$```H```#Y
M@0``%0````2"```%````&H(``!0````@@@``'@```#6"```H````5((```H`
M``!]@@``#P```(B"```4````F((```0```"M@@``"P```+*"```%````OH(`
M``@```#$@@``-````,V"```T`````H,``"`````W@P``&@```%B#```H````
M<X,``"@```"<@P``*0```,6#```&````[X,```@```#V@P``!P```/^#```+
M````!X0```<````3A```$P```!N$```*````+X0``!0````ZA```#P```$^$
M```R````7X0```L```"2A```!0```)Z$```%````I(0``!<```"JA```!P``
M`,*$```(````RH0```L```#3A```'@```-^$```4````_H0``!(````3A0``
M$@```":%```.````.84```8```!(A0``#````$^%```-````7(4```L```!J
MA0``"@```':%```+````@84```\```"-A0``"0```)V%```+````IX4```4`
M``"SA0``#@```+F%```3````R(4```<```#<A0``%@```.2%```1````^X4`
M`!0````-A@``!P```"*&```8````*H8```0```!#A@``!P```$B&```*````
M4(8```L```!;A@``#````&>&```.````=(8```0```"#A@``"P```(B&```,
M````E(8```T```"AA@``#````*^&```)````O(8``!(```#&A@``!@```-F&
M```8````X(8``"4```#YA@``"0```!^'```#````*8<```H````MAP``#```
M`#B'```5````18<```L```!;AP``&0```&>'```@````@8<```4```"BAP``
M"@```*B'```,````LX<```0```#`AP``"0```,6'```'````SX<```P```#7
MAP``#0```.2'```&````\H<```\```#YAP``$P````F(```>````'8@``"``
M```\B```!@```%V(```$````9(@```P```!IB```#@```':(```4````A8@`
M`!H```":B```%P```+6(```G````S8@``!H```#UB```%P```!")```;````
M*(D``!D```!$B0``'P```%Z)```3````?HD``!,```"2B0``!@```*:)```'
M````K8D```D```"UB0``#0```+^)```#````S8D``#\```#1B0``-P```!&*
M``!7````28H``!X```"AB@``!0```,"*```*````QHH```T```#1B@``!```
M`-^*```2````Y(H``!,```#WB@``)0````N+```=````,8L```P```!/BP``
M&0```%R+```)````=HL``!,```"`BP``"0```)2+```$````GHL``!````"C
MBP``"````+2+```(````O8L```\```#&BP``!P```-:+```,````WHL``!L`
M``#KBP``+`````>,```%````-(P```0````ZC```%P```#^,```*````5XP`
M``P```!BC```"0```&^,```)````>8P``!$```"#C```!@```)6,```C````
MG(P```X```#`C```'0```,^,```'````[8P```8```#UC```!P```/R,```F
M````!(T``#@````KC0``&@```&2-```J````?XT``!D```"JC0``!0```,2-
M```.````RHT```@```#9C0``"0```.*-```&````[(T```L```#SC0``%```
M`/^-```&````%(X``!D````;C@``"@```#6.```<````0(X```4```!=C@``
M$````&..```)````=(X```@```!^C@``'P```(>.```1````IXX``",```"Y
MC@``(0```-V.```?````_XX``"<````?CP``'P```$>/```Q````9X\``$$`
M``"9CP``,P```-N/```E````#Y```"D````UD```*P```%^0```O````BY``
M`#````"[D```+P```.R0```L````')$``!<```!)D0``(@```&&1``!%````
MA)$``#````#*D0``!````/N1```+`````)(```4````,D@```@```!*2``!9
M````%9(```4```!OD@``!````'62```'````>I(```@```""D@``!0```(N2
M```3````D9(```T```"ED@``!P```+.2```&````NY(``!0```#"D@``#```
M`->2```&````Y)(```,```#KD@``!````.^2```&````])(```<```#[D@``
M%P````.3```@````&Y,``!H````\DP``)````%>3```F````?),```P```"C
MDP``%````+"3```.````Q9,```T```#4DP``!P```.*3```'````ZI,``!4`
M``#RDP``!@````B4```&````#Y0```<````6E```#````!Z4```1````*Y0`
M``@````]E```'0```$:4```)````9)0```H```!NE```%````'F4```*````
MCI0```@```"9E```#0```**4```0````L)0``#H```#!E```!P```/R4```)
M````!)4```<````.E0``"````!:5```'````'Y4``!D````GE0``"@```$&5
M```7````3)4``!0```!DE0``$0```'F5```'````BY4```,```"3E0``!@``
M`)>5```'````GI4```T```"FE0``"P```+25```4````P)4``!4```#5E0``
M#@```.N5```5````^I4``"\````0E@``,0```$"6```)````<I8```X```!\
ME@``.P```(N6```5````QY8``#\```#=E@``#````!V7```*````*I<```H`
M```UEP``#````$"7```,````39<```T```!:EP```@```&B7```$````:Y<`
M``8```!PEP``!0```'>7```#````?9<```P```"!EP``&0```(Z7``!%````
MJ)<``"8```#NEP``)0```!68```2````.Y@``!,```!.F```$````&*8``!Y
M````<Y@```D```#MF```<@```/>8``!S````:ID``!<```#>F0``%@```/:9
M```/````#9H``!\````=F@``0````#V:```?````?IH``!0```">F@``"@``
M`+.:```%````OIH```8```#$F@``"````,N:```,````U)H``!````#AF@``
M&P```/*:```D````#IL```\````SFP``"@```$.;```$````3IL```L```!3
MFP``&@```%^;```B````>IL```@```"=FP``!P```*:;```%````KIL``"D`
M``"TFP``!P```-Z;```(````YIL```\```#OFP``&````/^;```4````&)P`
M``@````MG```#````#:<```/````0YP```<```!3G```!@```%N<```&````
M8IP```D```!IG```"@```'.<```,````?IP```,```"+G```"````(^<```%
M````F)P```0```">G```!0```*.<```$````J9P```<```"NG````@```+:<
M```A````N9P```<```#;G```!0```..<``!4`0``Z9P``$,````^G@``#@``
M`(*>```2````D9X``!$```"DG@``!P```+:>```(````OIX```H```#'G@``
M`@```-*>```$````U9X``"(```#:G@``+P```/V>```=````+9\``"(```!+
MGP``'@```&Z?```*````C9\```H```"8GP``$````*.?```/````M)\```4`
M``#$GP``)P```,J?```/````\I\```X````"H```$````!&@```0````(J``
M``@````SH```$0```#R@```-````3J```!,```!<H```#````'"@```+````
M?:````X```")H```!@```)B@```-````GZ```!(```"MH```$@```,"@```(
M````TZ````H```#<H```%P```.>@```_````_Z```$@````_H0``7````(BA
M``!9````Y:$``&(````_H@``7P```**B``!!`````J,```4```!$HP``#@``
M`$JC```.````6:,```X```!HHP``$@```'>C```%````BJ,``"0```"0HP``
M#@```+6C```%````Q*,```P```#*HP``$````->C```6````Z*,``!D```#_
MHP``#0```!FD```5````)Z0```H````]I```'@```$BD```;````9Z0``"``
M``"#I```$0```*2D```M````MJ0``"8```#DI```%`````NE```%````(*4`
M`!`````FI0``#0```#>E```'````1:4```H```!-I0``!P```%BE```(````
M8*4```4```!II0``"````&^E```C````>*4```\```"<I0``%0```*RE```H
M````PJ4``!<```#KI0``#`````.F```7````$*8``!<````HI@``(P```$"F
M```8````9*8``!,```!]I@``)0```)&F```&````MZ8```8```"^I@``"```
M`,6F```/````SJ8```D```#>I@``#0```.BF```*````]J8```T````!IP``
M"0````^G```0````&:<```\````JIP``"0```#JG```(````1*<``!$```!-
MIP``#@```%^G```E````;J<```D```"4IP``!P```)ZG```%````IJ<``#T`
M``"LIP``"````.JG```(````\Z<```D```#\IP``!P````:H```X````#J@`
M`#@```!'J```6P```("H```W````W*@``#<````4J0``-P```$RI```N````
MA*D``#(```"SJ0``-P```.:I```]````'JH``"$```!<J@``)0```'ZJ```O
M````I*H``#$```#4J@``,P````:K```.````.JL```L```!)JP``#````%6K
M```#````8JL```D```!FJP``%````'"K```?````A:L```P```"EJP``!P``
M`+*K```6````NJL```H```#1JP```P```-RK```2````X*L```@```#SJP``
M!@```/RK```&`````ZP```4````*K```!P```!"L```&````&*P```X````?
MK```#````"ZL```4````.ZP``$4```!0K```%P```):L```8````KJP``!``
M``#'K```"0```-BL```%````XJP```<```#HK```"````/"L```4````^:P`
M``,````.K0``"````!*M```(````&ZT```,````DK0```P```"BM```;````
M+*T```D```!(K0``"````%*M```'````6ZT``$\```!CK0``+0```+.M```&
M````X:T```8```#HK0``&0```.^M```=````":X``"P````GK@``(````%2N
M```9````=:X```<```"/K@``%@```)>N```"````KJX```D```"QK@``$P``
M`+NN```3````SZX```D```#CK@``%@```.VN```:````!*\``!\````?KP``
M%0```#^O```6````5:\```0```!LKP``!0```'&O``!&````=Z\``!````"^
MKP``#P```,^O```S````WZ\```4````3L```!0```!FP```+````'[```!<`
M```KL```(````$.P```7````9+```!8```!\L```#````).P```9````H+``
M``T```"ZL```"````,BP```%````T;````T```#7L```#````.6P```-````
M\K````<`````L0``!P````BQ```)````$+$```8````:L0``!0```"&Q```5
M````)[$```D````]L0``!P```$>Q```.````3[$```\```!>L0``!0```&ZQ
M```=````=+$``!P```"2L0``'0```*^Q```L````S;$``#L```#ZL0``*0``
M`#:R```^````8+(```<```"?L@``#@```*>R```(````MK(```L```"_L@``
M!P```,NR```)````T[(```\```#=L@``#0```.VR```K````^[(``"@````G
MLP``+@```%"S```K````?[,``"H```"KLP``.0```-:S```E````$+0``"@`
M```VM```+0```%^T```S````C;0``"8```#!M```%@```.BT```M````_[0`
M`"`````MM0``(@```$ZU``!%````<;4```0```"WM0``!@```+RU```+````
MP[4```L```#/M0``$@```-NU```6````[K4```D````%M@``!`````^V```+
M````%+8``#<````@M@``!@```%BV```$````7[8```\```!DM@```@```'2V
M```)````=[8```L```"!M@``"@```(VV```$````F+8```T```"=M@``$```
M`*NV```(````O+8```X```#%M@``$@```-2V```4````Y[8``!0```#\M@``
M!````!&W```'````%K<```\````>MP``"@```"ZW```0````.;<``!D```!*
MMP``#````&2W```,````<;<``!D```!^MP``&P```)BW```Z````M+<```L`
M``#OMP``&````/NW```5````%+@``!0````JN```-````#^X```(````=+@`
M`!D```!]N```)@```)>X```I````OK@``!,```#HN```!0```/RX```-````
M`KD``#`````0N0``!P```$&Y```)````2;D```D```!3N0``)@```%VY```2
M````A+D``#T```"7N0``!P```-6Y```]````W;D```D````;N@``+@```"6Z
M```(````5+H``!(```!=N@``"P```'"Z```1````?+H```T```".N@``'0``
M`)RZ```C````NKH```@```#>N@``"P```.>Z```)````\[H```8```#]N@``
M!P````2[```&````#+L```D````3NP``"@```!V[```1````*+L``!$````Z
MNP``&````$R[```5````9;L``!@```![NP``!0```)2[```(````FKL```4`
M``"CNP``"P```*F[```E````M;L```D```#;NP``$````.6[```0````]KL`
M``@````'O```-@```!"\```(````1[P```\```!0O```$````&"\```'````
M<;P```0```!YO```'````'Z\```7````F[P```<```"SO```!P```+N\```&
M````P[P``!$```#*O```$0```-R\```2````[KP``!`````!O0``%````!*]
M```4````)[T```\````\O0``%0```$R]```'````8KT```\```!JO0``"0``
M`'J]```&````A+T```P```"+O0``*@```)B]```?````P[T``"````#CO0``
M(@````2^```3````)[X```L````[O@``$````$>^```$````6+X```0```!=
MO@``!0```&*^```/````:+X```L```!XO@``"P```(2^```/````D+X``"8`
M``"@O@``'````,>^```A````Y+X``"0````&OP``$0```"N_```2````/;\`
M`!(```!0OP``$P```&._```[````=[\``"D```"SOP``/0```-V_``!&````
M&\```$P```!BP```.P```*_```!.````Z\```!0````ZP0``!@```$_!```)
M````5L$```@```!@P0``/0```&G!```2````I\$```<```"ZP0``!P```,+!
M```0````RL$``!,```#;P0``+@```._!```"````'L(```4````AP@``!@``
M`"?"```&````+L(```4````UP@``"0```#O"```#````1<(``!,```!)P@``
M"P```%W"```5````:<(```8```!_P@``"@```(;"```'````D<(``!````"9
MP@``"0```*K"```$````M,(```D```"YP@``"````,/"```&````S,(```T`
M``#3P@``!@```.'"```$````Z,(```4```#MP@``%P```//"```%````"\,`
M``8````1PP``!@```!C#```<````'\,```@````\PP``#````$7#```)````
M4L,```@```!<PP``"````&7#```%````;L,``"4```!TPP``!0```)K#```(
M````H,,```L```"IPP``#P```+7#```1````Q<,```<```#7PP``!0```-_#
M```4````Y<,``!$```#ZPP``!0````S$```)````$L0``#H````<Q```!```
M`%?$```-````7,0``!L```!JQ```'0```(;$```:````I,0``!T```"_Q```
M!````-W$```$````XL0```@```#GQ```!````/#$```(````]<0```8```#^
MQ```!P````7%```&````#<4```<````4Q0``!P```!S%```'````),4```8`
M```LQ0``!@```#/%```(````.L4```H```!#Q0``!0```$[%```0````5,4`
M``T```!EQ0``#@```'/%```*````@L4``#$```"-Q0``!@```+_%```(````
MQL4``"@```#/Q0``#P```/C%```&````",8```D````/Q@``"P```!G&```%
M````)<8```0````KQ@``%@```##&```;````1\8``!D```!CQ@``!0```'W&
M```'````@\8```D```"+Q@``$P```)7&```'````J<8```4```"QQ@``#0``
M`+?&```6````Q<8```L```#<Q@``)P```.C&```%````$,<```P````6QP``
M#@```"/'```9````,L<```<```!,QP``!P```%3'```6````7,<``%<```!S
MQP``&P```,O'```%````Y\<```H```#MQP```@```/C'```$````^\<```,`
M````R```!0````3(```)````"L@```H````4R```!@```!_(```&````)L@`
M``<````MR```"````#7(```$````/L@```4```!#R```6P```$G(```C````
MI<@```8```#)R```"````-#(```6````V<@```\```#PR```"0````#)```-
M````"LD```H````8R0``"0```"/)```#````+<D```<````QR0``"@```#G)
M```.````1,D```D```!3R0``'P```%W)``!:````?<D```8```#8R0``"```
M`-_)```Y````Z,D``"P````BR@``*P```$_*```4````>\H```H```"0R@``
M"````)O*```2````I,H```8```"WR@``"````+[*```*````Q\H```H```#2
MR@``#0```-W*```&````Z\H```<```#RR@``#0```/K*```.````",L```\`
M```7RP``%0```"?+```5````/<L```X```!3RP``#@```&++```.````<<L`
M``@```"`RP``!0```(G+```*````C\L```4```":RP``-P```*#+```(````
MV,L```<```#ARP``!0```.G+```%````[\L```@```#URP``$P```/[+```$
M````$LP```4````7S```#@```!W,```.````+,P```L````[S```#0```$?,
M```*````5<P```@```!@S```#@```&G,```)````>,P```4```""S```!P``
M`(C,```$````D,P``"P```"5S```"@```,+,```9````S<P``!````#GS```
M+@```/C,```:````)\T``"L```!"S0``*P```&[-```O````FLT``"L```#*
MS0``+````/;-```M````(\X``"H```!1S@``(0```'S.```6````GLX```4`
M``"US@``!P```+O.```(````P\X```@```#,S@``%0```-7.```,````Z\X`
M``X```#XS@``!0````?/```%````#<\```@````3SP``#0```!S/```.````
M*L\```(````YSP``"P```#S/```%````2,\```0```!.SP``)P```%//```4
M````>\\```4```"0SP``&@```);/```(````L<\```L```"ZSP``%P```,;/
M```+````WL\```0```#JSP``#P```._/```*````_\\``!`````*T```)P``
M`!O0```2````0]```!H```!6T```$P```''0```L````A=````<```"RT```
M"P```+K0```,````QM````@```#3T```!0```-S0```&````XM```!$```#I
MT```"````/O0```%````!-$``!,````*T0``%@```![1```&````-=$```<`
M```\T0``$P```$31```%````6-$``!````!>T0``&@```&_1```M````BM$`
M``L```"XT0``#P```,31```3````U-$```0```#HT0``"````.W1```'````
M]M$```@```#^T0``)`````?2```@````+-(``!\```!-T@``&P```&W2```B
M````B=(``!8```"LT@``)@```,/2```&````ZM(```H```#QT@``!P```/S2
M```.````!-,```<````3TP``#0```!O3```/````*=,``!L````YTP``'@``
M`%73```Z````=-,```D```"OTP``!0```+G3```)````O],``!X```#)TP``
M"@```.C3```)````\],```T```#]TP``(0````O4```6````+=0``!,```!$
MU```(@```%C4```.````>]0```0```"*U```"0```(_4```,````F=0```D`
M``"FU```!````+#4```0````M=0``!8```#&U```"@```-W4```)````Z-0`
M``4```#RU```#0```/C4```3````!M4```8````:U0``'0```"'5```/````
M/]4``!4```!/U0``!P```&75```9````;=4```H```"'U0``!P```)+5```2
M````FM4```P```"MU0``#0```+K5```<````R-4```8```#EU0``$0```.S5
M```/````_M4``!`````.U@``#P```!_6```,````+]8```4````\U@``!@``
M`$+6```=````2=8``"@```!GU@``"P```)#6```#````G-8```P```"@U@``
M#0```*W6```3````N]8```L```#/U@``%P```-O6```9````\]8```4````-
MUP``"@```!/7```0````'M<```8````OUP``"P```#;7```)````0M<```P`
M``!,UP``#````%G7```&````9M<``!4```!MUP``%P```(/7```<````F]<`
M`!X```"XUP``!@```-?7```(````WM<```T```#GUP``#````/77```7````
M`M@``!L````:V```%````#;8```<````2]@``!L```!HV```%0```(38```:
M````FM@``!@```"UV```'P```,[8```B````[M@``!D````1V0``!P```"O9
M```'````,]D```@````[V0``#0```$39```%````4MD``#X```!8V0``-0``
M`)?9``!6````S=D``!T````DV@``#````$+:```(````3]H```L```!8V@``
M!0```&3:```4````:MH``!,```!_V@``,P```)/:```7````Q]H```P```#?
MV@``,````.S:```&````'=L``!`````DVP``"````#7;```'````/ML``!@`
M``!&VP``"````%_;```(````:-L```X```!QVP``!P```(#;```1````B-L`
M`"$```":VP``$@```+S;```)````S]L```0```#9VP``&0```-[;```/````
M^-L```\````(W```#@```!C<```)````)]P``!0````QW```!@```$;<```S
M````3=P```P```"!W```&P```([<```%````JMP```8```"PW```"@```+?<
M```@````PMP``"````#CW```%@````3=```@````&]T``!D````\W0``!0``
M`%;=```4````7-T```<```!QW0``!0```'G=```'````?]T```H```"'W0``
M!0```)+=```&````F-T```8```"?W0``"P```*;=```(````LMT```<```"[
MW0``#@```,/=```+````TMT```D```#>W0``)````.C=```2````#=X``"``
M```@W@``'````$'>```<````7MX``",```![W@``(````)_>```S````P-X`
M`$<```#TW@``+@```#S?```L````:]\``!\```"8WP``(0```+C?```X````
MVM\``#,````3X```*@```$?@```J````<N```!8```"=X```(0```+3@``!"
M````UN```#@````9X0``!````%+A```,````5^$```4```!DX0```@```&KA
M``!>````;>$```0```#,X0``!````-'A```'````UN$```4```#>X0``!0``
M`.3A```1````ZN$``!````#\X0``!P````WB```&````%>(``!0````<X@``
M#````#'B```&````/N(```,```!%X@``!````$GB```&````3N(```<```!5
MX@``&@```%WB```I````>.(``",```"BX@``'@```,;B```M````Y>(```T`
M```3XP``'````"'C```/````/N,```,```!.XP``"````%+C```)````6^,`
M`!L```!EXP``"@```('C```'````C.,```<```"4XP``$0```)SC```7````
MKN,``!$```#&XP``)@```-CC```2````_^,``!,````2Y```%P```";D```*
M````/N0```<```!)Y```%@```%'D```.````:.0``$<```!WY```!P```+_D
M```)````Q^0```8```#1Y```!P```-CD```(````X.0``!````#IY```#0``
M`/KD```:````".4``"0````CY0``#P```$CE```+````6.4```,```!DY0``
M"@```&CE```&````<^4```L```!ZY0``"@```(;E```5````D>4``!8```"G
MY0``$````+[E```=````S^4``#,```#MY0``-P```"'F```+````6>8``!,`
M``!EY@``1````'GF```7````ON8``$\```#6Y@``#@```";G```-````-><`
M``L```!#YP``#@```$_G```.````7N<```X```!MYP```@```'SG```$````
M?^<```8```"$YP``!0```(OG```#````D><``!````"5YP``$````*;G```G
M````M^<``#,```#?YP``,@```!/H```1````1N@```X```!8Z```$````&?H
M``"!````>.@```H```#ZZ```70````7I``!>````8^D``!P```#"Z0``$P``
M`-_I```<````\^D``"`````0Z@``0````#'J```F````<NH``!4```"9Z@``
M"@```*_J```$````NNH```8```"_Z@``"````,;J```-````S^H``!0```#=
MZ@``'@```/+J```O````$>L```X```!!ZP``$0```%#K```$````8NL```P`
M``!GZP``'@```'3K```J````D^L```P```"^ZP``!@```,OK```&````TNL`
M`"T```#9ZP``"`````?L```(````$.P```T````9[```(P```"?L```3````
M2^P```8```!?[```#````&;L```,````<^P```<```"`[```#0```(CL```,
M````ENP```P```"C[```$````+#L```0````P>P```$```#2[```"0```-3L
M```$````WNP```0```#C[```!@```.CL```(````[^P```@```#X[````P``
M``'M```G````!>T```D````M[0``!0```#?M```!````/0$``/@"``#F````
M!0```)L"`````````````,8"``")`@``[`$``&X!``"W`P``<`(````````=
M`@```````!T`````````(`$``"4!````````S````"D!``",````#@```&\`
M````````3`$``-D#```A`@```````/X````````````````````D`0``*@,`
M`*L#`````````````!8`````````+`$``,X#```H````B0```!4!````````
M`````!D#``"N`0``S0,``#\#``">`0``N0,``!$!``!B`P``K@(``$$#```^
M`P```````!H"``"X`@```````%(#``!F`0```````,8!``#3`0``$`,``)\"
M```=`P``M0(``!,!``#R`@```````"D```"2````)@,``+H```!\`0``KP(`
M`-0```!0`P``)`,```@!```1`@``XP(``$L```"^`@``^0$```````"(````
M7@(```````!(`````````&0"```%`0``WP```)T"````````+0(```````"6
M`@``[@$``%D```!#`@``&@,```4"``!1`0``20(```````#4`0``80$``!@`
M```T`P````````,#``!S`P````(``.\!````````A0```*8#``"]`@``;P$`
M`'@`````````;0$``,X"``!T`0```````,(`````````=P````0!````````
MW0(```````!``0``9@(``-@``````````````"$!``#@`@``$0,``"@!````
M`````````.,!``"'`@``D0```.4`````````"`````````"C`0``````````
M```2`@``PP(``"\!``"L`0``^@$`````````````]@$```````!B`@``R`(`
M```````7`0``;@,```````#=`P``N````&H!````````U`,``,`"``#,`@``
MI`(``%("``"4`0``L0```/H"````````/0,``"0```"W`0``(P(``"$```"+
M`````````&L!``!/`0``,@```$8#````````Q`,```````!_`@``````````
M```5````TP```%H`````````X@$``,$```"F`@``C0(`````````````-`$`
M`$L"```'`0```````&T#``"E`@```````#D"``"7`P``$P(``-8"````````
MU@```%8#``#S````3@`````````^`@``=0(``.4"``````````````````#]
M````<0(```````!U```````````````-`0``OP,``(X``````````````"X`
M``!8`0``!````$H!````````X0``````````````A````"4"````````-`(`
M`,H#``!7`@``?0$``+P"````````V`,```````#M`0```````*P````X`P``
MP@,``*P#````````'@```$0#``!A`P``G0,`````````````:@(````````O
M`P``%`,``+H"``!4`P````````````!]````N@,``+,"``#^`0``=@``````
M``"8`0``F`,``.(```"#````,`(``(P"``"#`0``'P(``!\````L`P``10``
M`$<"``#(`P```````)X"````````?@```+H!`````````````%T!````````
M`````%4!````````H`$``'D!```Q`@``2`(````````3`P``JP$``((#``!9
M`0``10(``,$"``"9````W0$``)T!`````````````,L#````````R`$``,D`
M```L`````````/0!``!M````(@(``/````!6``````````````#\````8P$`
M`-8#``"J`0``B@,``%\#``!<`0``@`(``!8"``!]`@```````*L`````````
M`````*,"``!+`P``&P(```````"J````X````*`#``"Y`````````*L"````
M````-@```*("``#0````^P$``!(````)`P``2`$``#(!``";`P``W@```#P"
M``!:`0```````(,"`````````````)8#``"P`0``!P,``+8"``#A`@``````
M`'8#``#>`0``AP$``#$!``!K`P``-P(````````)`0``+0$```H#``!=`P``
MUP```(4!``"V````&0```/T!``"T`@```````(8``````````````',!````
M````AP,``,D#```B`P```````*`"````````;`,``-4"``#F`@``N0(``%P"
M``!Q````R0(``"@"``!X`P``-0```)4```#W`@``P@$``-X"``"4`P``````
M`.H"````````Q0````L"``#'````VP````````"M`P```````(D!```/`0``
M`````*8!``":`@``20,``)8!``"E`P``GP$``*0#``"B`P``````````````
M````F0,``,\```#2`P```````#`!```[`@``8`(``%L```!$`@``RP```"<!
M`````````````$("```"`P``.`$``&(````W`0``K`(````````%`P``````
M`%8!````````L````%T"``#D````@0,```````#,`0``QP$``($"``!8````
M`````/<!`````````````%X````0````U@$``#`#```L`@`````````````I
M`P``T0$``$`"``#]`@``UP$```````#3`P``50(```````!%`P```````$,#
M````````````````````````````````````````ZP(``'P```!?`0``,0,`
M`",!````````^P(``'<#``"8`@``=0$``%\"``!8`@``[@(```8"``#V`@``
MM`$``!L`````````&0(``*<```!*`P``R````'P"``#T````EP`````````*
M``````````````"/`0````````````"A`P``#0(``%4```!X`0```````+\`
M`````````````.0#``!U`P``50,``,<#```J`````````%0```"V`0``````
M````````````KP,````````.`0``]@````0#``"U`0``\0$``&4"``#U````
M``````````"1`0``T0,````````*`@``K@```+T!```W`P``E`````L```!P
M`0``$P```'P#``"0`P``O`$``$0```#2`@``00$``*@!`````````````%,`
M``"'`````````%$"````````T@$```P!``":`0```````#(#``!L````J```
M`+\"``!E`0``4P,``'L"``"+`@``-@(``!<```!>`P``C@$``/,!````````
M6P$`````````````80```#\```#Q````8````&@!``"6`````````+`"````
M````YP(``#<`````````X0$``),"``!L`@``G````.D!``!V`@``_P(`````
M```S`@``'`(``#````!R`0``.@(``$D```````````````X#``#/`0``$`(`
M`.0"```U`@``9@````````#<`@``,P```)`!````````9`$```,!````````
MH0```-P!````````*@$``&L```"(`P``1@```#L#``#*````X@,``%\````O
M````CP````````#?`0```````+(````#`@```````#H#```=`0``+@(``&D`
M``#?`@``.@$``(("```B`0``4@$``!H```#^`@```@$`````````````RP$`
M`"L```"2`P``V`$`````````````@`,`````````````]P```((!``#5`P``
MLP,``,0!`````````````````````````````.D"```$`@``[````+@!``!F
M`P``H``````````K`0```````,T```":````>`(``,$!``"F````2P$``-(`
M````````2`,``)4#``".`@``3@,``#@"```]`@``1P```$`#``"A`0``!@$`
M`-`"``##`0```````+$#```[````8P```(X#```_`0```````%X!``!/`@``
M$@$``%H#```C`P```````'H#``"D````9````&<#```K`P``>0```+T```"%
M`P``^0(```````!!`````````&$"`````````````+\!``![````C`$``$D!
M``"?`P``[P(``"L"``#J`0```````(8#``#&`P``UP,`````````````@0$`
M`*H#````````O0,``%````"W`@``SP,``#@````<`P``K0```)<!``#``P``
M5`(`````````````0````*@#````````J0$``(@"````````<@```+D!````
M````E0$``*<!``#``0``H0(``'D"````````V@$``-H#````````!@```,,#
M``"Q`0``I0```(L#`````````````$\```#\`@``3````+L```"P`P``(`,`
M`(T#```;`P``*0(``&T"``!E`````````(\#````````P```````````````
M0P````L#```"`@``<0$``)\```">````'````%D"``""`````````/(!``#M
M`@```````-<"```!`P``1@$``$X!````````W@,``````````````````!P!
M````````````````````````C0```-\#``````````````````"B`0``&`$`
M`$X"``!H````$`$```D"```Y`P``?P,``$0!```@`@``#``````````'````
MDP,``*@"```[`0``+@,```````"I`P``(@```"@#```M``````````````#F
M`0```````$(`````````#P(```````#)`0``EP(``+P#``!'`0``4P(``*0!
M``"9`@````````````";`0```````&(!``#Y````&`(``)$"``#_`0``>@(`
M`'$#````````FP````````!@`P```````'L!``!^`P``90,```````!_````
M8P(```````#0`P``"P$``+8#``!;`P```````!0``````````````&<!````
M````#`,``)X#``":`P`````````````\`0``ZP$``&H`````````%P(`````
M``!S`@``QP(``,L"``"T`P``V0(```````#%`0``#P```*T!```^`0``U0``
M`)4"```Q``````,```````"O`0``]0(``.`!``#E`0``O@,``-D!````````
M`````"4```#;`0``U`(``"8`````````O@$``````````````````,0````!
M`0`````````````4`0```````'<!````````Q`(``/H`````````IP,``$P#
M```&`P```````,$#``!:`@``'@(``!4"```Y````W````&P!``#*`0``U0$`
M`%(```#"`@``&P$``/P!``"Q`@``?0,``,4#``!G````%0,``&L"``#H`0``
M30$`````````````>@```!(#`````````````$\#````````4`$``'("```D
M`@``HP```"X!```@`````@``````````````J0```.D``````````````.$#
M``"[`@``R@(``(0"`````````````$(!```J`@````````````#=````````
M`$4!````````SP(``"<"````````:`(``%`"``#.````X`,`````````````
MXP```/@```````````````````#,`P``S0$``)(!``"G`@``=@$``(@!````
M``````````P"``!O`P``+P(``(\"````````=`(``&H#``!1````VP,``#("
M``"X`P```````-`!``#B`@``-@$```````!"`P````````````",`P``````
M`(D#``!^`@``5`$``!@#````````MP```*,#``!&`@``A`$```````!T`P``
M`````)@```!_`0``F0$````````M`P``L@(`````````````D`(``"8!``!8
M`P````````````"&`@```````````````0``60,``(0#````````PP```#8#
M``"*`0```````-L"````````[0```$H"```G`P``-`````````!-`P``#0``
M`!\#``"U`P``Z````````````````````-D```#G`0``M0````````!!`@``
M"`(``-$"```Y`0``YP`````````(`P``KP```!\!``"&`0```````.@"``"!
M````@`$```````"=````7`,``(`````*`0```````#X```#X`0``]`(`````
M````````(P`````````S`0````````````#O````ZP```````````````0(`
M`/`!``#:````8P,``!X#```A`P```````(4"```\`P``)P```&<"``!#`0``
M```````````6`P``>P,``'<"````````3`(```\#``"I`@``#0,``/\```"3
M`0``/0```(T!``"E`0```````+,```!1`P``D@(``#4#``"1`P``XP,``(L!
M``!^`0``\P(``!X!``!O`@``@P,``)P!````````"0````````"<`@``````
M`$<#````````L@$``#,#``"J`@``Z@```!8!``!I`0``LP$``'0```!N````
M$0```)P#```E`P````````````#<`P````````````#&````B@```)0"``!N
M`@``:0(``*T"```4`@``4P$``$T```#-`@``L@,``,X!``!7````-0$``$T"
M`````````````&@#`````````````',```"[`P``O@```-$```#:`@``/P(`
M`/4!``#N``````````````!<````:0,``'`#```'`@``B@(``+P`````````
MD````&`!``#Q`@```````'H!``#R````V`(`````````````&@$````````#
M`````````.P"``#%`@``K@,``%<#````````````````````````Y`$``'D#
M``!6`@``&0$```````!;`@```````%<!```7`P``<````),`````````````
M`#P```#P`@``#@(``+0`````````<@,``"8"``"[`0``9`,``/L```#3`@``
M.@```````````````````*(```!*````70`````@)B,Q-3$[("5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H
M:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI
M`"!A;F0`(&]R`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A
M=&5D.B`E<RX`)60@)7,@86YD("5S`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T
M<F%T:6]N`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E
M<R!A;')E861Y(&5X:7-T<RX`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E
M<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K
M`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z
M("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA
M=``R-"!H;W5R<P`\4')E=FEO=7,`02!F871A;"!E<G)O<B!H87,@;V-C=7)R
M960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92X`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`06)O=70N
M+BX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN
M9P!!8W1I;VX@9F]R(&)L86-K;&ES=&5D(&%D9')E<W-E<SH`06-T:79A=&4@
M4V-R:7!T`$%D9`!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E
M<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D
M9&ET:6]N86P@4V5T=&EN9W,`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI
M<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA
M<P!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@
M4&5R;6ES<VEO;G,`06QL(&]F('1H92!F;VQL;W=I;F<`06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO
M9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S
M97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T97AT
M.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`
M06YT87)C=&EC80!!;GD@;V8@=&AE(&9O;&QO=VEN9P!!<'!L:6-A=&EO;@!!
M<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@1FEL=&5R<P!!<'!R;W9E`$%P
M<FEL`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<G5L93\`07)G96YT:6YA`$%R
M;65N:6$`07)U8F$`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=')I8G5T97,`075G=7-T`$%U
M<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO
M;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&5A8V@@
M8VAA;F=E/P!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC
M=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H
M<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)C8P!"96=I
M;G,@=VET:`!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`
M0FAU=&%N`$)I<G1H9&%Y`$)L86-K;&ES=`!";&%C:VQI<W0@161I=`!";&%C
M:VQI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I
M;F<@9')I=F5R+@!";&%C:VQI<W1E9"!!9&1R97-S`$)L86-K;&ES=&5D($%D
M9')E<W-E<P!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O9'D`0F]L:79I
M80!";V]K;6%R:W,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)R87II
M;`!"=6QG87)I80!#35,`0U)#`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD
M87(`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A
M=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N
M)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#
M86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T(')E
M;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%P92!697)D90!#87-E(%-E;G-I=&EV
M90!#871E9V]R:65S(&%N9"!,86)E;',`0V,`0V5L;"!0:&]N90!#96QL(%!R
M;W!E<G1I97,`0V5L;"!P<F]P97)T:65S`$-E;&QP:&]N90!#96QT:6,@*$E3
M3RTX.#4Y+3$T*0!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T
M:69I8V%T92!/=VYE<@!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E<R!S879E9"X`0VAE8U]K($QI
M;FLN+BX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAO
M;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.@!#:')I<W1M87,@27-L86YD`$-L:6-K('1O($-O
M;G1I;G5E`$-L;W-E(%=I;F1O=P!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#
M;VQL87!S92!3:61E8F%R`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#
M;VQO=7(@<V5L96-T:6]N`$-O;'5M;B!T:71L97,`0V]M;6%N9`!#;VUM86YD
M(%-H96QL`$-O;6UE;G0`0V]M;W)O<P!#;VUP86YY`$-O;7!O<V4@365S<V%G
M92`H)7,I`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R92`E<P!#;VYF
M:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I
M;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`0V]N=&%I;G,`0V]N=&5N=',@;V8@(B5S(@!#
M;VYT:6YU90!#;V]K($ES;&%N9',`0V]P>0!#;W!Y("5S`$-O<'D@;V8@)7,`
M0V]P>2!S96QE8W1I;VX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO
M="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82X`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I
M;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M(B5S(BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+@!#;W5N=')Y`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE
M=R!O;F4`0W)E871E(&YE=R!F;VQD97(`0W)E9&ET(&-A<F0@;G5M8F5R`$-R
M;V%T:6$`0W5B80!#=7)R96YT(%1I;64`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0WEP<G5S`$-Z96-H(%)E<'5B;&EC
M`$1$`$1)4T%"3$5$`$1)4T%"3$5$.B``1&%I;'D`1&%T90!$95]L971E($-O
M;'5M;@!$96%C=&EV871E(%-C<FEP=`!$96-E;6)E<@!$969A=6QT($-O;&]R
M`$1E9F%U;'0@261E;G1I='D`1&5F875L="!097)M:7-S:6]N<P!$969A=6QT
M('!E<FUI<W-I;VYS`$1E;&5T90!$96QE=&4@)7,`1&5L971E($-O;F1I=&EO
M;@!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T
M92!M97-S86=E(&-O;7!L971E;'D`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I
M='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W`$1E;&5T92!T:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_`$1E;&5T960`1&5L:79E<B!I;G1O(&UY($E.0D]8`$1E;&EV
M97(@:6YT;R!M>2!)3D)/6"!A;F0@8V]P>2!T;P!$96QI=F5R(&EN=&\@;7D@
M24Y"3U@@86YD(')E9&ER96-T('1O`$1E;&EV97(@=&\@9F]L9&5R`$1E;FUA
M<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<V%B;&4@
M)7,`1&ES86)L960`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P
M=&EO;G,`1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE;B!E86-H
M(&9I;'1E<B!I<R!A<'!L:65D/P!$:FEB;W5T:0!$;R!?;F]T('-E;F0@<F5S
M<&]N<V5S('1O(&)U;&L@;W(@;&ES="!M97-S86=E<P!$;R!N;W0@9&5L971E
M`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('1H
M:7,Z`$1O97-N)W0@8F5G:6X@=VET:`!$;V5S;B=T(&-O;G1A:6X`1&]E<VXG
M="!E;F0@=VET:`!$;V5S;B=T(&5X:7-T`$1O;6EN:6-A`$1O;6EN:6-A;B!2
M97!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$<G5G<P!%+4UA:6P`16-U
M861O<@!%9&ET`$5D:70@)7,`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`
M161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET
M(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9WEP=`!%
M;"!386QV861O<@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@
M<F5S=6QT+@!%;F%B;&4@)7,`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@
M;65N=3\`16YA8FQE9`!%;F1S('=I=&@`17%U871O<FEA;"!'=6EN96$`17)I
M=')E80!%<G)O<@!%<G)O<B!S879I;F<@8VAA;F=E<RX`17)R;W(@=W)I=&EN
M9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X:7-T:6YG(%)U;&5S`$5X
M:7-T<P!%>'!A;F0`17AP86YD(%-I9&5B87(`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I
M;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T
M86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&:6II`$9I;&4@36%N86=E<@!&:6QE
M($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S
M(&YO="!S=7!P;W)T960N`$9I;'1E<B!!;&P@365S<V%G97,`1FEL=&5R($]N
M;'D@4V5E;B!-97-S86=E<P!&:6QT97(@3VYL>2!5;G-E96X@365S<V%G97,`
M1FEL=&5R($]P=&EO;G,`1FEL=&5R(%)U;&4`1FEL=&5R(%)U;&5S`$9I;'1E
M<B!?4G5L97,`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@
M8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I
M='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&1E;&5T960N`$9I;'1E<B!A
M8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@;6]V960@=&\@=&AE
M(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@
M=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@=V5R92!D96QE=&5D+@!&:6QT
M97(@86-T:79I='DZ(%1H92!M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B
M965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E<B!A8W1I=FET
M>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S
M(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E<B!N
M;W0@9F]U;F0N`$9I;'1E<G,`1FEN;&%N9`!&;V]D`$9O<B!A;B!I;F-O;6EN
M9R!M97-S86=E('1H870@;6%T8VAE<SH`1F]R9V]T('EO=7(@<&%S<W=O<F0_
M`$9O<G=A<F0`1G)A;F-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I
M80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!'86)O;@!'86UB
M:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1V\`1V]O9VQE(%-E87)C:`!'
M<F5A=&5R('1H86X`1W)E871E<B!T:&%N(&]R(&5Q=6%L('1O`$=R965C90!'
M<F5E;FQA;F0`1W)E;F%D80!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E
M;6%L80!'=65R;G-E>0!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-
M3`!(86ET:0!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5L
M<`!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO
M;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B
M)7,B`$AU;F=A<GD`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X
M=`!)9&5N=&ET>2=S(&YA;64Z`$EM86=E<P!);7!O<G1A;G0`26UP;W)T960@
M9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YD:6$`26YD;VYE<VEA`$EN
M97AI<W1A;G0@;6%I;&)O>"!S<&5C:69I960@9F]R(&UE<W-A9V4@9&5L:79E
M<GDN`$EN9F\`26YS97)T($EM86=E`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F`$ER87$`27)E;&%N9`!)<P!)<VXG=`!)<W)A96P`27-S=65R`$ET
M86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*;W)D86X`2G5L>0!*=6YE`$MA
M>F%K:'-T86X`2V5N>6$`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+
M97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`
M2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T(&QO9VEN.B`E<P!,87-T(&QO
M9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,97-O
M=&AO`$QE<W,@=&AA;@!,97-S('1H86X@;W(@97%U86P@=&\`3&EB97)I80!,
M:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&ES="!(96QP
M(%1O<&EC<P!,:7-T+4E$`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI
M=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I
M;64`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;W<`3'5X96UB;W5R9P!-30!-
M3U1$`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86EL`$UA;&%W:0!-86QA>7-I80!-
M86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<E]K(&UE<W-A
M9V4@87,@9&5L971E9`!-87)C:`!-87)G:6X`36%R:R!M97-S86=E(&%S.@!-
M87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA
M=7)I=&%N:6$`36%U<FET:75S`$UA>0!-87EO='1E`$UE;G4@;6]D93H`365R
M9V4@8V5L;',`365S<V%G90!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-97AI8V\`36EM92!4>7!E
M`$UI<W-I;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O`$UI<W-I
M;F<@<F5A<V]N(&9O<B!R96IE8W0`36ES<VEN9R!R96%S;VX@:6X@=F%C871I
M;VXN`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L
M(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:&QY`$UO;G1S97)R
M870`36]O;B!0:&%S97,`36]R;V-C;P!-;W9E`$UO=F4@1&]W;@!-;W9E($QE
M9G0`36]V92!2:6=H=`!-;W9E(%)U;&4@1&]W;@!-;W9E(%)U;&4@57``36]V
M92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UY($%C8V]U;G0`
M37D@4&]R=&%L`$UY86YM87(`3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C
M871I;VX@<F5P;&EE<SH`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE
M<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='=O<FL`3F5V97(`3F5W
M($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W(%)U;&4`3F5W(%IE86QA;F0`
M3F5W<P!.97AT`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I
M80!.:75E`$YO(&)A8VME;F0@8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T`$YO
M(&-H86YG92X`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R("5S+@!.;R!F:6QE('5P;&]A9&5D`$YO(&9I;'1E<G,N($-L:6-K
M("(E<R(@=&\@8W)E871E(&$@;F5W(&9I;'1E<BX`3F\@:&5A9&5R<R!S<&5C
M:69I960`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-3
M5T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN`$YO('-C<FEP="!G96YE<F%T960N`$YO('-T
M<FEN9W,@<W!E8VEF:65D`$YO;F4`3F]R9F]L:R!)<VQA;F0`3F]R=V%Y`$YO
M="!E<75A;"!T;P!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O
M<G1E9"X`3F]T97,`3F]T:6-E`$YO=F5M8F5R`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$]+`$]C=&]B97(`3V9F:6-E`$]M86X`3VYL>2!O
M;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/<&5N(&EN(&$@;F5W('=I;F1O
M=P!/<'1I;VYS`$]P=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+@!/<'1I
M;VYS(&9O<B`E<P!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/
M<F=A;FEZ:6YG`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO
M;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP
M=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T80!02%`@0V]D90!02%`@4VAE;&P`4%](4"!3:&5L;`!086MI<W1A;@!0
M86QA=0!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087-S=V]R
M9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@9F]R`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`4&AO;F4`4&ET8V%I<FX`
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E
M;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN
M:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!E;G1E<B!T
M:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E('!R;W9I9&4@82!S
M=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S
M97)N86UE(&%N9"!P87-S=V]R9`!0;VQA;F0`4&]R='5G86P`4')E=FEE=P!0
M<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4'5B;&EC
M($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="D`4E]E87-O;@!296-E:79E9`!2961I<F5C="!T;P!2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G
M=6QA<B!E>'!R97-S:6]N`%)E:F5C="!W:71H(')E87-O;@!296UO=&4@4V5R
M=F5R<P!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E
M('!A:7(`4F5M;W9E('1H90!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`
M4F5S96YT(%1O`%)E<V5N="UF<F]M`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E
M<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@1FEL=&5R<R!,
M:7-T`%)E='5R;B!T;R!/<'1I;VYS`%)E='5R;B!T;R!2=6QE<R!,:7-T`%)E
M=6YI;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)O;&4`4F]M86YI80!2
M;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@<')O<&5R
M=&EE<P!2=6QE`%)U;&4@0V]P:65D`%)U;&4@1&5L971E9`!2=6QE($1I<V%B
M;&5D`%)U;&4@16YA8FQE9`!2=6QE($YA;64`4G5S<VEA;B!&961E<F%T:6]N
M`%)W86YD80!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!344P@4VAE;&P`4U-(`%-?44P@
M4VAE;&P`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN
M="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E
M;G0@86YD('1H92!'<F5N861I;F5S`%-A;6]A`%-A;B!-87)I;F\`4V%U9&D@
M07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A
M=F4@4V5T=&EN9W,`4V-R:7!T`%-C<FEP="!5<&1A=&EN9P!38W)I<'0@;F]T
M('5P9&%T960N`%-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D+@!38W)I
M<'0@<W5C8V5S<V9U;&QY(&1E86-T:79A=&5D+@!396%R8V@`4V5E;@!396QE
M8W0@1FEL97,`4V5L96-T(&$@9FEE;&0`4V5L96-T('1A<F=E="!F;VQD97(`
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O
M<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F
M;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U
M<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93H`4V5L9BU$969I;F5D($AE861E<@!396YD(%!R;V)L96T@4F5P;W)T`%-E
M;F1E<@!396YE9V%L`%-E<'1E;6)E<@!397)I86P@3G5M8F5R`%-E=`!3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=&EN9W,@<W5C8V5S<V9U;&QY
M('5P9&%T960N`%-E='5P`%-E>6-H96QL97,`4VAO<G0@4W5M;6%R>0!3:&]W
M`%-H;W<@06-T:79E(%-C<FEP=`!3:&]W($-U<G)E;G0@4V-R:7!T`%-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\`4VEE<G)A($QE;VYE`%-I9VX@=7`@:68@;F]T
M(')E9VES=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN
M9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI
M80!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;W5T:"!!9G)I8V$`4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W
M`%-R:2!,86YK80!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<"!C:&5C
M:VEN9R!I9B!T:&ES(')U;&4@;6%T8VAE<S\`4W1R965T($%D9')E<W,`4W5B
M:F5?8W0@;V8@=F%C871I;VX@;65S<V%G93H`4W5B:F5C=`!3=6)M:70`4W5C
M8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U
M;&QY('5P9&%T960@(B5S(@!3=61A;@!3=6YR:7-E+U-U;G-E=`!3=7)I;F%M
M90!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y<FEA;B!!<F%B(%)E
M<'5B;&EC`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK
M:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487-K<P!496QE
M<&AO;F4@3G5M8F5R`%1E>'0@3VYL>0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R
M('5S:6YG('1H92!S>7-T96TN`%1H92!D<FEV97(@<V%I9#H@`%1H92!I9&5N
M=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V
M960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T
M:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B
M(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I
M;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE
M('-C<FEP="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@
M<V-R:7!T+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BX`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@
M86YD(&=Z:7`@9FEL97,N`%1I;64`5&EM92!F;W)M870`5&ET;&4`5&\`5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D
M87D`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1R:6YI9&%D(&%N9"!4
M;V)A9V\`5')U92!O<B!F86QS90!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)
M4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5V86QU`%523`!54DPZ`%5G86YD
M80!5:W)A:6YE`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG
M97,`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D
M(%-T871E<P!5;FMN;W=N`%5N;F%M960`56YS=7!P;W)T960@17AT96YS:6]N
M`%5P9&%T90!5<&QO860`57)U9W5A>0!5<V5R($]P=&EO;G,`57-E<B!296=I
M<W1R871I;VX`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T
M<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`
M57IB96MI<W1A;@!686-A=&EO;@!686-A=&EO;B!%9&ET`%9A8V%T:6]N($UE
M<W-A9V4`5F%C871I;VX@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N
M="!F:6QT97)I;F<@9')I=F5R+@!686YU871U`%9E;F5Z=65L80!697)S:6]N
M`%9I970@3F%M`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V5B`%=E96ML
M>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H
M25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H
M87)A`%=H7VET96QI<W0@861D<F5S<V5S.@!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7
M:&ET96QI<W0@161I=`!7:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!7:&ET96QI<W1E9"!!9&1R
M97-S97,`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=O<FL@061D<F5S<P!7;W)K(%!H
M;VYE`%@M4')I;W)I='D`6"U3<&%M+4QE=F5L`%@M4W!A;2U38V]R90!8+5-P
M86TM4W1A='5S`%E9`%E965D`665A<FQY`%EE;65N`%EE<P!997,L($D@06=R
M964`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W5R
M($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.
M86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU
M9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%M.;R!3=6)J96-T70!;
M4')O8FQE;2!297!O<G1=`%]!9&1R97-S*&5S*2!T;R!F;W)W87)D('1O.@!?
M061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SH`7T%D;6EN:7-T
M<F%T:6]N`%]";&%C:VQI<W0`7T-,20!?1&5L971E(%)O=P!?1&5L971E(&UE
M<W-A9V4@8V]M<&QE=&5L>0!?16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W
M(&QI;F4Z`%]&;W)W87)D`%]'<F]U<',`7TAE;'``7TME97`@82!C;W!Y(&]F
M(&UE<W-A9V5S(&EN('1H:7,@86-C;W5N=#\`7TQO9R!I;@!?3&]G(&]U=`!?
M36]D:69Y($QI;FLN+BX`7TUO=F4@;65S<V%G92!T;R!F;VQD97(Z`%]->2!E
M;6%I;"!A9&1R97-S97,Z`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E
M($QI;FLN+BX`7U-C<FEP=`!?4V5T=7``7U5S97)S`%]686-A=&EO;@!?5VAI
M=&5L:7-T`&%D9')E<W,@8F]O:P!A;F0`8V%L96YD87(`9FEE;&0`9FEL90!M
M871C:`!N86UE`&YO=&5P860`;W(`<')O8VUA:6P@<V-R:7!T(&=E;F5R871E
M9"!B>2!);F=O`'5N;F%M960`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!)
M;F=O(&@S+3$N,"XQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$Q+3(T(#(P.C$Y
M*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TQ,2TR-"`R,#HS,RLP,3`P
M"DQA<W0M5')A;G-L871O<CH@2W)Z>7-Z=&]F($MO>FQO=W-K:2`\:V]Z:6LQ
M0&\R+G!L/@I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-
M24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]:7-O+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET"@`E<R`M(&=O=&]W>2!D;R!W>6MO;F%N:6$@8WEK;&EC>FYY8V@@;W!E
M<F%C:FD@>F%Z;F%C>F]N>6-H('!O;FF_96HN`"`H)7,@9&YI('1E;74I`"AK
M;'5C>B!D;W-TZG!U("5S*0`@*'<@8VFQ9W4@)7,@9&YI*0`@*&1Z:;8I`"`H
M:G5T<F\I`"`H=V-Z;W)A:BD`(&D`(&QU8@`B)7,B(&YI92!J97-T('!R87=I
M9+-O=WEM('=Y8F]R96TN`"(E<R(@;FEE(&IE<W0@<VMO;F9I9W5R;W=A;GD@
M=R!R96IE<W1R>F4@2&]R9&4N`%5D8;-O('-IZB!D;V1AYB`B)7,B(&1O(&=R
M=7`N`%5D8;-O('-IZB!D;V1AYB`B)7,B(&1O('5P<F%W;FEE\2X`(B5S(B!N
M:64@>F]S=&&S('5T=V]R>F]N>3H@)7,N`"5D("5S(&D@)7,`)7,@+2!5=V%G
M80!!9&UI;FES=')A8VIA("5S`"5S(&]D8VES:R!P86QC80`E<R!K0@`E<R`M
M(&]P97)A8VIE(&-Y:VQI8WIN92`M('!O='=I97)D>F5N:64`2V]N9FEG=7)A
M8VIA("5S`%)E:F5S=')A8VIA("5S`"5S(&IUOR!I<W1N:65J92X`)7,@:F5S
M="!W>6UA9V%N>0`E<R!M:6YU=``E<R!N:65Z;F%L97II;VYY+@`E<R!D;R`E
M<R!Z("5S`$MS:;&_:V$@861R97-O=V$@)7,`2V%L96YD87)Z("5S`$YO=&%T
M;FEK("5S`$QI<W1A('IA9&'Q("5S`"5S.B`E<P`M+2!W>6)I97)Z("TM`#$R
M+6=O9'II;FYY(&9O<FUA=``R-"UG;V1Z:6YN>2!F;W)M870`,C0@9V]D>BX`
M/%!O<')Z961N:0!.87-TL7!ILR!BL[%D(&MR>71Y8WIN>0!0;W1R>F5B;GD@
M:F5S="!K;'5C>B!P=6)L:6-Z;GD@4$=0(&1O('IA<WIY9G)O=V%N:6$@=VEA
M9&]M;[9C:2X`4&]T<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D
M;R!S<')A=V1Z96YI82!P;V1P:7-A;F5J('=I861O;6^V8VDN`%!O=')Z96)N
M92!SL2!K;'5C>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@
M;W)A>B!H87.S;R!D;R!O9'-Z>69R;W=A;FEA('=I861O;6^V8VDN`%!O=')Z
M96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!0
M1U`@;W)A>B!H87.S;R!D;R!P;V1P:7-A;FEA('=I861O;6^V8VDN`%!O=')Z
M96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C>B!P<GEW871N
M>2!3+TU)344@;W)A>B!H87.S;R!D;R!O9'-Z>69R;W=A;FEA('=I861O;6^V
M8VDN`%!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C
M>B!P<GEW871N>2!3+TU)344@;W)A>B!H87.S;R!D;R!P;V1P:7-A;FEA('=I
M861O;6^V8VDN`%!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!334E-
M12!D;R!Z87-Z>69R;W=A;FEA('=I861O;6^V8VDN`$%-+U!-`$\@='EM(&5D
M>71O<GIE`$\@<')O9W)A;6EE+BXN`$AA<[-O(&1O(&MO;G1A`$MO;G1O('IA
M8FQO:V]W86YE+@!+;VYT80!!:V-J82!D;&$@861R9?-W>2!N82!C>F%R;F5J
M(&QIMF-I93H`06MT>7=U:B!S:W)Y<'0`1&]D86H`1&]D86H@='5T86HZ`$1O
M9&%J(&YO=[$@9W)U<.H`1&]D86H@;F]W92!U<')A=VYI96YI90!$;V1A:B!N
M;W=E9V\@=;]Y=&MO=VYI:V$Z`$1O9&%J(&MO;'5M;NH`1&]D86H@;F]W>6-H
M(&-ZLV]N:_-W`$1O9&%J('!A<NH`1&]D86H@;65N=2`E<R!D;R!P87-K82!-
M;WII;&QI`$1O9&%J(&1O(&MS:;&_:VD@861R97-O=V5J.@!$;V1A:B!D;R!M
M;VIE:B!K<VFQ>FMI(&%D<F5S;W=E:@!$;V1A:B!UOWET:V]W;FEK80!$;V1A
M;F\@(B5S(B!D;R!S>7-T96UU+B!-;[]E<WH@<VGJ('IA;&]G;W=AYBX`1&]D
M87=A;FEE('6_>71K;W=N:6OS=R!J97-T('=YLV%C>F]N92X`1&]D871K;W=E
M('5S=&%W:65N:6$`061R97,`2W-IL;]K82!A9')E<V]W80!!9&UI;FES=')A
M8VIA`%)E:VQA;7D`069G86YI<W1A;@!!;&)A;FEA`$%L9VEE<FEA`$%L:6%S
M`%=S>GES=&MO`%=S>GES8WD@=7=I97)Z>71E;&YI96YI('6_>71K;W=N:6-Y
M`%=S>GES=&MI92!G<G5P>0!7<WIY<W1K:64@=7!R87=N:65N:6$`6F%S=&]S
M;W=A;FEE('=S>GES=&MI8V@@<&]N:;]S>GEC:"!R96=ULP!0;WIW\VP@;F$@
M=VEE;&4@861R97/S=P!*=;\@:7-T;FEE:F4`06QT97)N871Y=VYY(&QO9VEN
M($E-4U``06QT97)N871Y=VYY(&AA<[-O($E-4U``06QT97)N871Y=VYA(&YA
M>G=A('6_>71K;W=N:6MA($E-4U``06QT97)N871Y=VYY(&%D<F5S(&5M86EL
M`$%L=&5R;F%T>7=N>2!T96MS=#H`6F]S=&&S82!P;V1A;F$@;FEE<')A=VED
MLV]W82!W87)T;[;F+@!!;F1O<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;6]W
M92!0<F]X>0!/9'!O=VEE9+P`3V1P;W=I961Z:6%N90!!;G1A<FMT>61A`$-Z
MZK9C:2!Z(&YI8V@`07!L:6MA8VIA`$%P;&EK86-J82!G;W1O=V$`6F%S=&]S
M=6H@9FEL=')Y`%IA='=I97)DO`!+=VEE8VEE\0!7:65L:V^VYB!A<F-H:7=U
M;0!.87IW82!A<F-H:7=U;0!#>GD@;F$@<&5W;F\@8VAC97-Z('5S=6ZQYB!T
MZB!R96=UL^H_`$%R9V5N='EN80!!<FUE;FEA`$%R=6)A`%!O<')OMB!O('!O
M='=I97)D>F5N:64@<')Z960@=WEK;VYA;FEE;2!O<&5R86-J:2!C>6ML:6-Z
M;GEC:#\`071R>6)U='D`4VEE<G!I9?$`075S=')A;&EA`$%U<W1R:6$`075T
M:%]C>7)U<SH@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N
M:6$@:6UA<"X`075T:%]C>7)U<SH@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G
M;R!R;WIS>F5R>F5N:6$@:6UA<"X`075T:%]F='`Z($YI92!Z;F%L97II;VYO
M('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA($944"X@4VMO;7!I;'5J(%!(4"!Z
M('!A<F%M971R96T@+2UE;F%B;&4@+@!!=71H7VEM87`Z($YI92!Z;F%L97II
M;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA($E-05`N`$%U=&A?:W)B-3H@
M3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@:W)B-2X`
M075T:%]L9&%P.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z
M96YI82!,1$%0+@!!=71H7VQD87`Z($YI92!U9&&S;R!S:>H@=7-U;K'F('6_
M>71K;W=N:6MA("5S`$%U=&A?;&1A<#H@3FEE('5D8;-O('-IZB!U86MT=6%L
M;FGF('6_>71K;W=N:6MA("5S`$%U=&A?;6-A;#H@3FEE('IN86QE>FEO;F\@
M=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@34-!3"X`075T:%]S;6)A=71H.B!.
M:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!S;6)A=71H
M+@!5=VEE<GIY=&5L;FEE;FEE(&YI92!P;W=I;V2S;R!S:>H`57=I97)Z>71E
M;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ+B`E<P!5=VEE<GIY=&5L;FEE;FEE
M(&]D<GIU8V]N92!P<GIE>B!S97)W97(@4D%$2553+@!5=VEE<GIY=&5L;FEE
M;FEE(&1O('-E<G=E<F$@1E10(&YI92!P;W=I;V2S;R!S:>HN`$%U=&]M871Y
M8WIN:64@=6%K='5A;&YI8>8@<VMR>7!T('!O(&MAOV1E:B!Z;6EA;FEE/P!$
M;W-TZG!N92!P;VQA.@!!>F5R8F5J9+]A;@!7>6WS=VMI($)/1D@`5+-O`$MO
M;&]R('2S80!:LV4@:&%SLV\@2V5R8F5R;W-A+@!:LV$@;F%Z=V$@=;]Y=&MO
M=VYI:V$@2V5R8F5R;W-A`%=Y<W!Y($)A:&%M80!"86AR86IN`$)ALW1Y8VMI
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S>@!"8V,`6F%C>GEN86JQ8V4@<VGJ
M(&]D`$)I8;-O<G6V`$)E;&=I80!"96QI>F4`0F5N:6X`0F5R;75D>0!":'5T
M86X`1&%T82!U<F]D>F5N:6$`0WIA<FYA(&QI<W1A`$5D>6-J82!C>F%R;F5J
M(&QI<W1Y`$-Z87)N82!L:7-T82!N:64@:F5S="!O8G.S=6=I=V%N82!P<GIE
M>B!O8F5C;GD@<W1E<F]W;FEK(&9I;'1R;W=A;FEA+@!!9')E<R!N82!C>F%R
M;F5J(&QIMF-I90!!9')E<WD@;F$@8WIA<FYE:B!L:;9C:64`57-T87=I96YI
M82!B;&]K=0!4>7`@8FQO:W4`5')EMN8`0F]L:7=I80!:86NS861K:0!";[9N
M:6$@:2!(97)C96=O=VEN80!/8F$`0G)A>GEL:6$`0G6S9V%R:6$`0TU3`$-2
M0P!7LV&V8VEW;[9C:2!K;VWS<FMI+BXN("A?8RD`2V%L96YD87)Z`$MA;6)O
M9+]A`$MA;65R=6X`3FEE('5D8;-O('-IZB!Z<F5S971O=V'F(&AA<[-A(&%U
M=&]M871Y8WIN:64L('-K;VYT86MT=6H@<VGJ('H@861M:6YI<W1R871O<F5M
M+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@24U!4#H@
M)7,`2V%N861A`$%N=6QU:@!!;G5L=6H@<F%P;W)T(&\@<')O8FQE;6EE`$YI
M92!M;[]N82!S:V%S;W=AYB!P;&EK=2`B)7,B`$YI92!U9&&S;R!S:>H@>FYA
M;&6\YB!K871A;&]G=2!T>6UC>F%S;W=E9V\N`$YI92!M;[]N82!S:V%S;W=A
MYB!K871A;&]G=2`B)7,B`%=Y<W!Y(%II96QO;F5G;R!0<GIY;+%D:V$`4[-A
M9&YI80!+871E9V]R:64@:2!O>FYA8WIE;FEA`$-C`%1E;"X@:V]M+@!7LV&V
M8VEW;[9C:2!K;VWS<FMI`%>S8;9C:7=OMF-I(&MO;?-R:VD`5&5L+B!K;VTN
M`$-E;'1Y8VMI("A)4T\M.#@U.2TQ-"D`4F5P=6)L:6MA(*9R;V1K;W=E:B!!
M9G)Y:VD`IG)O9&MO=V]E=7)O<&5J<VMI("A)4T\M.#@U.2TR*0!3>F-Z96?S
MLWD@8V5R='EF:6MA='4`5[-AMF-I8VEE;"!C97)T>69I:V%T=0!#>F%D`%IM
M:67Q`%IM:67Q(&EM:>HL(&YA>G=I<VMO(&D@861R97,L(&MT\W)Y(&EN;FD@
M=VED>K$@=R!4=V]I8V@@;&ES=&%C:"!E;6%I;"X`6FUI86YY('IA<&ES86YE
M+@!3<')A=V2\(&QI;FLN+BX`6F%Z;F%C>B!P;WIY8VKJ(&1L82!K=/-R96H@
M8VAC97-Z('=Y:V]N8>8@;W!E<F%C:NHN`$-H:6QE`$-H:6YY`%!O9&%J(&AA
M<[-O`%!O9&%J(&YA>G?J('6_>71K;W=N:6MA`%=Y8FEE<GH@<W!O<_-B('=Y
MMG=I971L86YI82!D870Z`%=Y<W!A($)OOV5G;R!.87)O9'IE;FEA`$ML:6MN
M:6H@8GD@:V]N='EN=6]W8>8`6F%M:VYI:B!O:VYO`%=Y<W!Y($MO:V]S;W=E
M("A+965L:6YG82D`4V-H;W=A:B!P87-E:P!+;VQU;6)I80!+;VQO<@!7>6)I
M97)Z(&MO;&]R`%=Y8O-R(&MO;&]R=0!4>71ULWD@:V]L=6UN`$MO;65N9&$`
M4&]WLV]K80!+;VUE;G1A<GH`2V]M;W)Y`$9I<FUA`%-T=_-R>B!W:6%D;VUO
MMN8@*"5S*0!+;VUP=71E<GD`5V%R=6YK:0!3:V]N9FEG=7)U:B`E<P!0;W1W
M:65R9+P@:&%SLV\`2V]N9V\`1&5M;VMR871Y8WIN82!297!U8FQI:V$@2V]N
M9V\`4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@<VGJ+@!0;[.Q8WIE;FEE(&YI
M92!P;W=I;V2S;R!S:>HZ(`!/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L
M:6-Z;F5G;R!S97)W97)A+@!/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L
M:6-Z;F5G;R!S97)W97)A+B!0;W?S9#H@)7,@*"5S*0!"L[%D('!O9&-Z87,@
ML[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@1E10+@!+;VYT86MT>2!Z;W-T8;-Y
M('!O;7FV;&YI92!D;V1A;F4@9&\@5'=O:F5J(&MS:;&_:VD@861R97-O=V5J
M+@!:87=I97)A`%IA=V%R=&^VYB`B)7,B`$MO;GEN=75J`%=Y<W!Y($-O;VMA
M`%-K;W!I=6H`2V]P:75J("5S`%-K;W!I;W=A;F\@>B`E<P!3:V]P:75J('=Y
M8O-R`$YI92!U9&&S;R!S:>H@>F%S>GEF<F]W8>8@*%!'4"D@=VEA9&]M;[9C
M:2X`3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4$=0*2!W:6%D;VUOMF-I+@!.
M:64@=61ALV\@<VGJ('IA<WIY9G)O=V'F("A3+TU)344I('=I861O;6^V8VDN
M`$YI92!U9&&S;R!S:>H@<&]D<&ES8>8@*%,O34E-12D@=VEA9&]M;[9C:2X`
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`N`$*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2`B)7,B('!O<')Z
M97H@1E10.B`E<P!.:64@=61ALV\@<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!0
M1U`N`$YI92!U9&&S;R!S:>H@;V1S>GEF<F]W8>8@9&%N>6-H(%,O34E-12X`
M3FEE('5D8;-O('-IZB!U<W1A;&GF(&%D<F5S=2!E+6UA:6P@;V1B:6]R8WDN
M`$YI92!U9&&S;R!S:>H@=7IY<VMAYB!Z('-E<G=E<F$@:VQU8WIA('!B=6QI
M8WIN96=O+@!.:64@=61ALV\@<VGJ(&]T=V]R>GGF("(E<R(@9&\@>F%P:7-U
M+@!.:64@;6^_;F$@;W1W;W)Z>>8@)7,N`$YI92!M;[]N82!O='=O<GIYYB!M
M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<P!.:64@;6^_;F$@;W1W;W)Z>>8@
M:V%T86QO9W4@(B5S(@!.:64@=61ALV\@<VGJ('-K87-O=V'F('!L:6MU("(E
M<R(N`$YI92!U9&&S;R!S:>H@>FYA;&6\YB!P87-K82!-;WII;&QI+B!5<&5W
M;FEJ('-IZBP@OV4@:F5S="!O;B!O='=A<G1Y+@!+<F%J`%-T=_-R>@!3='?S
M<GH@;&EN:P!3='?S<GH@;F]WL0!5='?S<GH@;F]W>2!F;VQD97(`3G5M97(@
M:V%R='D@:W)E9'ET;W=E:@!#:&]R=V%C:F$`2W5B80!/8F5C;GD@8WIA<P!3
M<&5R<V]N86QI>G5J('IA9&%N:6$@=7)U8VAA;6EA;F4@<')Z>2!L;V=O=V%N
M:74@9&\@)7,N`%=Y=&YI:@!#>7!R`%)E<'5B;&EK82!#>F5C:`!$1`!76:.A
M0UI/3D4`5UFC04-:3TY%.B``0V]D>FEE;FYI90!$871A`%]5<W7Q(&MO;'5M
M;NH`1&5A:W1Y=W5J('-K<GEP=`!'<G5D>FEE\0!$;VUYMFQN>2!K;VQO<@!$
M;VUYMFQN82!T;[]S86UOMN8`1&]M>;9L;F4@=7!R87=N:65N:6$`1&]M>;9L
M;F4@=7!R87=N:65N:6$`57-U\0!5<W7Q("5S`%)E9W6S82!U<W5W86YI80!5
M<W7Q($=R=7#J`%5S=?$@=7!R87=N:65N:6$`57-U\2!I('=Y8WIYMN8@=VEA
M9&]M;[9C:0!5<W7Q(&MO;?-R:^H`57-U\2!K;VQU;6[J`%5S=?$@8V&S:V]W
M:6-I92!W:6%D;VUOMN8`4VMA<W5J('5P<F%W;FEE;FEA(&1L82`B)7,B`%-K
M87-O=V'F('5P<F%W;FEE;FEA(&1L82`B)7,B(&D@=W-Z>7-T:VEE('!O9"UU
M<')A=VYI96YI83\`57-U\2!W:65R<WH`4VMA<W5J('=Y8G)A;K$@=&^_<V%M
M;[;F`%5S=?$@86MT=6%L;K$@:V]L=6UNZ@!5<W7Q(&%K='5A;&YY('=I97)S
M>@!3:V%S;W=AYB!T;R!U<')A=VYI96YI92!I('=S>GES=&MI92!P;V0M=7!R
M87=N:65N:6$_`%5S=6YIZG1O`%!R>F6V;&EJ(&YA(&UO:K$@<VMR>GEN:^H`
M4')Z9;9L:6H@;F$@;6]JL2!S:W)Z>6YKZB!I('-K;W!I=6H@9&\`4')Z9;9L
M:6H@;F$@;6]JL2!S:W)Z>6YKZB!I('!R>F5K:65R=6H@9&\`4')Z96YI9;8@
M9&\@9F]L9&5R=0!$86YI80!/<&ES>B!P<F]B;&5M`%-Z8WIE9_.S>2!Z;W-T
M8;-Y('IA;&]G;W=A;F4@9&QA(&%D;6EN:7-T<F%T;W)A+@!+871A;&]G`%=Y
ML[%C>B`E<P!7>;.Q8WIO;F4`5WFV=VEE=&P@8WIA<R!W(&9O<FUA8VEE(#(T
M+6=O9'II;FYY;3\`57-T87=I96YI82!W>6=LL61U`%=YMG=I971L8>8@9&]K
MLV%D;F4@<&]W:6%D;VUI96YI92!P<GIY('6_>6-I=2!K8;]D96=O(&9I;'1R
M=3\`1+]I8G5T:0!?3FEE('=Y<WFS86H@;V1P;W=I961Z:2!N82!L:7-T>2!M
M87-O=V4@:2!G<G5P>2!S=6)S:W)Y<&-Y:FYE`$YI92!K87-U:@!"<F%K(&)E
M>G!OMG)E9&YI96=O(&1O<W3J<'4@9&\@;6%I;G1E;F%N8V4N<&AP`%=Y:V]N
M86HZ`$YI92!Z86-Z>6YA('-IZB!O9`!.:64@>F%W:65R80!.:64@:V_Q8WIY
M('-IZB!N80!.:64@=WES=.IP=6IE`$1O;6EN:6MA("A7<W#S;&YO=&$@1&]M
M:6YI:VDI`$1O;6EN:6MA;F$@*%)E<'5B;&EK82!$;VUI;FEK8?%S:V$I`*9C
M:;%G;FEJ`*9C:;%G;FEJ("5S`$YA<FMO='EK:0!%+6UA:6P`16MW861O<@!%
M9'ET=6H`161Y='5J("5S`%5S=?$@1W)U<.H`6FUI9?$@=7!R87=N:65N:64`
M6FUI9?$@=7!R87=N:65N:6$`6FUI9?$@=7!R87=N:65N:6$@9&QA("5S`%IM
M:67Q('5S=&%W:65N:6$@9&QA.@!:;6EE\2!U<')A=VYI96YI82!D;&$@)7,`
M16=I<'0`4V%L=V%D;W(`16UA:6P`061R97,@96UA:6P`061R97-Y(&5M86EL
M(&UU<WJQ(&1O('-I96)I92!P87-O=V'F+@!%;6]T:6MO;GD`4'5S=&$@=VEA
M9&]M;[;F+@!"<F%K(')E>G5L=&%T\W<N`%>SL6-Z("5S`%>SL6-Z>>8@;65N
M=2!K;VYT96MS=&]W92!P;V0@<')A=WEM('!R>GEC:7-K:65M(&UY<WIY/P!7
ML[%C>F]N90!+;_%C>K%C92!S:>H@;F$`1W=I;F5A(%+S=VYI:V]W80!%<GET
M<F5A`$*SL60`0K.Q9"!P<GIY('IA<&ES>7=A;FEU('IM:6%N+@!"L[%D('!R
M>GD@>F%P:7-I92`B)7,B+@!%<W1O;FEA`$5T:6]P:6$`175R;W!A`$-O(&MA
MOV1E(#$U(&UI;G5T`$-O(&MAOV1E(#(@;6EN=71Y`$-O(&MAOV1E(#,P('-E
M:W5N9`!#;R!K8;]D92`U(&UI;G5T`$-O(&MAOV1E('IA;&]G;W=A;FEE`$-O
M(&MAOV1E('#SLR!G;V1Z:6YY`$-O(&MAOV2Q(&UI;G5TZ@!0<GIY:[-A9&]W
M92!W87)T;[9C:3H`5WEK;VYA:@!!:W1U86QN92!R96=ULWD`5W-Y=.IP=6IE
M`%)O>G=I\0!2;WIW:?$@<&%S96L`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-I
MZB!Z('-E<G=E<F5M($Q$05`N`$*SL60@<&]D8WIA<R!K;W!I;W=A;FEA('H@
M(B5S(BX`0K.Q9"!P;V1C>F%S(&MO<&EO=V%N:6$@9&\@(B5S(BX`0K.Q9"!P
M;V1C>F%S('!R>F5N;W-Z96YI82!D;R`B)7,B+@!&86QK;&%N9'D@*$UA;'=I
M;GDI`%=Y<W!Y($]W8WIE`$*SL60@:W)Y='EC>FYY.B``1F%K<P!,=71Y`$9I
M9+]I`$UE;F5DOV5R('!L:6OS=P!.87IW82!P;&EK=0!7>6+S<B!P;&EK=0!7
M9W)Y=V%N:64@<&QI:W4`5V=R>7=A;FEE('!L:6OS=R!N:64@:F5S="!O8G.S
M=6=I=V%N92X`1FEL=')U:B!W<WIY<W1K:64@=VEA9&]M;[9C:0!&:6QT<G5J
M('1Y;&MO('=I9'II86YE('=I861O;6^V8VD`1FEL=')U:B!T>6QK;R!N:65W
M:61Z:6%N92!W:6%D;VUOMF-I`$]P8VIE(&9I;'1R;W=A;FEA`%)E9W6S82!&
M:6QT<F]W86YI80!296=ULWD@1FEL=')O=V%N:6$`7U)E9W6S>2!&:6QT<F]W
M86YI80!$>FEALV%N:64@9FEL=')U.B!S:V]P:6]W86YO("5S('=I861O;6^V
M8VD@9&\@9F]L9&5R=2`B)7,B+@!$>FEALV%N:64@9FEL=')U.B!U<W5N:>IT
M;R`E<R!W:6%D;VUOMF-I+@!$>FEALV%N:64@9FEL=')U.B!P<GIE;FEE<VEO
M;F\@)7,@=VEA9&]M;[9C:2!D;R!F;VQD97)U("(E<R(N`$1Z:6&S86YI92!F
M:6QT<G4Z('-K87-O=V%N;R`E<R!W:6%D;VUOMF-I('!A<W5JL6-Y8V@@9&\@
M8WIA<FYE:B!L:7-T>2X`1'II8;-A;FEE(&9I;'1R=3H@5VEA9&]M;[;F("(E
M<R(@;V0@(B5S(B!Z;W-T8;-A('-K;W!I;W=A;F$@9&\@9F]L9&5R=2`B)7,B
M+@!$>FEALV%N:64@9FEL=')U.B!7:6%D;VUOMN8@(B5S(B!O9"`B)7,B('IO
M<W1ALV$@<VMA<V]W86YA+@!$>FEALV%N:64@9FEL=')U.B!7:6%D;VUOMN8@
M(B5S(B!O9"`B)7,B('IO<W1ALV$@<')Z96YI97-I;VYA(&1O(&9O;&1E<G4@
M(B5S(BX`1FEL='(@;FEE>FYA;&5Z:6]N>2X`1FEL=')Y`$9I;FQA;F1I80!*
M961Z96YI90!$;&$@=VEA9&]M;[9C:2!P<GIY8VAO9'JQ8WEC:"P@:W3S<F4@
M;V1P;W=I861A:K$@=7-T87=I96YI;VTZ`%IA<&]M;FEALV6V(&AA<[-A/P!0
M<GIE:V&_`$9R86YC:F$`1W5J86YA($9R86YC=7-K80!0;VQI;F5Z:F$@1G)A
M;F-U<VMA`$9R86YC=7-K:64@5&5R>71O<FEA(%!OLW5D;FEO=V4@:2!!;G1A
M<FMT>6-Z;F4`3V0`1V%B;VX`1V%M8FEA`$YI96UC>0!':&%N80!':6)R86QT
M87(`262\`%=Y<WIU:VEW87)K82!';V]G;&4`5VGJ:W-Z92!N:;\`5VGJ:W-Z
M92!N:;\@;'5B('+S=VYE`$=R96-J80!'<F5N;&%N9&EA`$=R96YA9&$`1W)U
M<'D@9'ES:W5S>6IN90!'=V%D96QU<&$`1W5A;0!'=V%T96UA;&$`1W5E<FYS
M97D`1W=I;F5A`$=W:6YE82!":7-S874`1W5J86YA`$A434P`2&%I=&D`5WES
M<'D@2&5A<F0@:2!-8T1O;F%L9&$`4&]M;V,`5WES;VMI`%]3=&%R=`!7871Y
M:V%N("A3=&]L:6-A($%P;W-T;VQS:V$I`%!O8WJQ=&5K`$%D<F5S(&1O;6]W
M>0!496PN(&1O;2X`2&]N9'5R87,`2&]N9TMO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z(%5D8;-O('-IZB!U<W5NL>8@)7,@(B5S(@!7ZF=R>0!)<VQA;F1I80!4
M>6QK;R!I:V]N>0!):V]N>2!Z('1E:W-T96T`3F%Z=V$@=&^_<V%M;[9C:3H`
M1W)A9FEK80!78;]N90!);7!O<G1O=V%N92!P;VQE.B`E<P!);7!O<G1O=V%N
M92!P;VQA.@!);F1I90!);F1O;F5Z:F$`2F%K;R!M:65J<V-E(&]D:6]R=2!Z
M;W-T8;-A('!O9&%N82!N:65I<W1N:65JL6-A('-K<GIY;FMA+@!);F9O`%=K
M;&5J(&]B<F%Z96L`5WESLV%N92!N:65P<F%W:62S;W=E(&1A;F4N`$YI97!R
M87=I9+-O=WD@861R97,@9&]C96QO=WDN`$YI97!R87=I9+-O=WD@9F]R;6%T
M('!L:6MU`$YI97!R87=I9+-O=WD@:VQU8WH@;&EC96YC:FDN`$ER86X`27)A
M:P!)<FQA;F1I80!*97-T`$YI92!J97-T`$EZ<F%E;`!7>61A=V-A`%>S;V-H
M>0!*86UA:FMA`%-T>6-Z9?$`2F%P;VYI80!*;W)D86X`3&EP:65C`$-Z97)W
M:65C`$MA>F%C:'-T86X`2V5N:6$`5'=O<GIE;FEE(&ML=6-Z80!/9&-I<VL@
M:VQU8WIA`$2S=6=OMN8@:VQU8WIA`%1Y<"!K;'5C>F$`2VQU8WH@:G6_(&ES
M=&YI96IE(&YA('!U8FQI8WIN>6T@<V5R=V5R>F4@:VQU8WIY+@!$>FEE8VD`
M2VER:6)A=&D`2V]R96'Q<VMA(%)E<'5B;&EK82!,=61O=V\M1&5M;VMR871Y
M8WIN80!297!U8FQI:V$@2V]R96D`2W5W96IT`$MI<F=I<W1A;@!7>6=LL60@
M*%]Y*0!*ZGIY:P!,86]S`$]S=&%T;FEE(&QO9V]W86YI93H@)7,`3W-T871N
M:64@;&]G;W=A;FEE.B`E<R!Z("5S`$]S=&%T;FEE(&QO9V]W86YI93H@;FEG
M9'D`HV]T=V$`3&5S;W1H;P!-;FEE:B!N:;\`36YI96H@;FF_(&QU8B!R\W=N
M90!,:6)E<FEA`$QI8FEA`$QI96-H=&5N<W1E:6X`5WFV=VEE=&P@=&5M871Y
M('!O;6]C>0!7>;9W:65T;"U)1`!,:7-T;W=A;FEE('6_>71K;W=N:6OS=R!J
M97-T('=YL[%C>F]N92X`3&ET=V$`HV%D;W=A;FEE+BXN`$-Z87,@;&]K86QN
M>3H@`%5S=&%W:65N:6$@;&]K86QN92!I(&-Z87,`6F%L;V=U:@!7>6QO9W5J
M`%IA9&%N:6$@<')Z>2!L;V=O=V%N:74`3&]G;W=A;FEE(&YI92!P;W=I;V2S
M;R!S:>HL('!O;FEE=V&_('!O9&&S9;8@;FEE<')A=VEDLV]W92!H87.S;R!L
M=6(@;F%Z=^H@=;]Y=&MO=VYI:V$N`$QO9V]W86YI92!N:64@<&]W:6]DLV\@
M<VGJ+@!.:7-K:0!,=6MS96UB=7)G`$U-`$U/5$0`35-'`$UA:V%U`$UA8V5D
M;VYI80!-861A9V%S:V%R`%!O8WIT80!-86QA=VD`36%L97IJ80!-86QE9&EW
M>0!-86QI`$UA;'1A`%IA<GJQ9'IA:B!L:7-TL2!K871E9V]R:6DL(&MT\W)Y
M;6D@8NID>FEE<WH@;WIN86-Z8;,@<&]Z>6-J92P@:2!K;VQO<F%M:2!Z(&YI
M;6D@>G=IL7IA;GEM:2X`3WIN86-Z('=I861O;6^VYB!J86MO('5S=6YIZG2Q
M("A?:RD`36%R>F5C`$UA<F=I;F5S`$]Z;F%C>B!W:6%D;VUOMN8@:F%K;SH`
M5WES<'D@36%R<VAA;&QA`$UA<G1Y;FEK80!087-U:K%C92!P;VQA`$UA=7)E
M=&%N:6$`36%U<FET:75S`$UA:@!-86IO='1A`%1R>6(@;65N=3H`4&^SL6-Z
M(&MO;?-R:VD`5VEA9&]M;[;F`$)L;VL@(DUE=&%R(B!N:64@:F5S="!D;W-T
MZG!N>2X`0FQO:R`B365T87(B(&YI92!J97-T(&1O<W3J<&YY+B!3>F-Z96?S
MLWD@>F1A<GIE;FEA('IO<W1ALWD@>F%L;V=O=V%N92!D;&$@861M:6YI<W1R
M871O<F$N`$UE:W-Y:P!4>7`@36EM90!"<F%K(&%D<F5S=2P@;F$@:W3S<GD@
M;6%JL2!B>>8@<')Z96MI97)O=WEW86YE('=I861O;6^V8VD`3FEE('ID969I
M;FEO=V%N>2!P;W?S9"!O9')Z=6-E;FEA('=I861O;6^V8VD`3FEE('ID969I
M;FEO=V%N;R!T96MS='4@=R!N;V-I92!W86MA8WEJ;F5J+@!/<W1A=&YI82!M
M;V1Y9FEK86-J80!:;6EE\2!L:6YK`$UOLV1A=VEA`%)E<'5B;&EK82!-;[-D
M87=I:0!-;VYA:V\`36]N9V]L:6$`0V\@;6EE<VFQ8P!-;VYT<V5R<F%T`$9A
M>GD@:W-IZK]Y8V$`36%R;VMO`%!R>F5S=?$`4')Z97-U\2!W(&3SLP!0<GIE
M<W7Q('<@;&5W;P!0<GIE<W7Q('<@<')A=V\`4')Z96YI9;8@<F5G=;/J(&YI
MOV5J`%!R>F5N:66V(')E9W6SZB!W>;]E:@!0<GIE<W7Q('<@9_-RZ@!0<GIE
M;FEEMB!W(&3SLP!0<GIE<W7Q('<@9_-RZ@!-;WIA;6)I:P!+;VYT;P!-\VH@
M<&]R=&%L`$)I<FUA`$QI8WIB82!D;FD@<&]M:>ID>GD@;V1P;W=I961Z:6%M
M:2!N;W1Y('=A:V%C>6IN96HZ("A?;BD`3F%Z=VES:V\`3F%M:6)I80!.875R
M=0!.97!A;`!(;VQA;F1I80!!;G1Y;&4@2&]L96YD97)S:VEE`%-I9>8`3FEG
M9'D`3F]W82!+86QE9&]N:6$`3F]W82!K871E9V]R:6$`3F]W82!R96=ULV$`
M3F]W82!:96QA;F1I80!7:6%D;VUOMF-I`$YA<W3J<&YE`$YA<W3J<&YE(&]P
M8VIE`$YI:V%R86=U80!.:6=E<@!.:6=E<FEA`$YI=64`0G)A:R!K;VYF:6=U
M<F%C:FD@=V5W;NIT<GIN96H@9&QA('1E9V\@:&]S=&$`0F5Z('IM:6%N+@!"
M<F%K(&MO;F9I9W5R86-J:2!D;&$@)7,N`$YI92!W9W)A;F\@<&QI:W4`0G)A
M:R!F:6QT<O-W+B!+;&EK;FEJ("(E<R(L(&%B>2!U='=O<GIYYB!N;W=Y+@!.
M:64@>F1E9FEN:6]W86YO(&YA9[/S=VOS=P!.:64@<&]D86YO(&AA<[-A(&1L
M82!U=VEE<GIY=&5L;FEE;FEA($A45%`N`$YI92!P;V1A;F\@:&%SLV$@9&QA
M('5W:65R>GET96QN:65N:6$@24U!4"X`3FEE('!O9&%N;R!H87.S82!D;&$@
M=7=I97)Z>71E;&YI96YI82!+97)B97)O<RX`3FEE('!O9&%N;R!H87.S82!D
M;&$@=7=I97)Z>71E;&YI96YI82!,1$%0+@!.:64@<&]D86YO(&AA<[-A(&1L
M82!U=VEE<GIY=&5L;FEE;FEA($Q/1TE.+@!.:64@<&]D86YO(&AA<[-A(&1L
M82!U=VEE<GIY=&5L;FEE;FEA(%!!4U-71"X`3FEE('!O9&%N;R!H87.S82!D
M;&$@=7=I97)Z>71E;&YI96YI82!334(N`$YI92!W>6=E;F5R;W=A;F\@OV%D
M;F5G;R!S:W)Y<'1U+@!.:64@>F1F:6YI;W=A;F\@8VFQ9_-W`*]A9&YA`$YO
M<F9O;&L`3F]R=V5G:6$`4O._;F4@;V0`3FEE('IA:6UP;&5M96YT;W=A;F\N
M`$YI975S=&%W:6]N90!.:65O8G.S=6=I=V%N90!5=V%G:0!5=V%G80!,:7-T
M;W!A9`!,:6-Z8F$@:V]L=6UN`$QI8WIB82!W:65R<WIY`$]+`%!AO&1Z:65R
M;FEK`$)I=7)O`$]M86X`5'?S:B!J961E;B!A9')E<R!E+6UA:6P@:F5S="!D
M;WIW;VQO;GDN`$]T=_-R>B!W(&YO=WEM(&]K;FEE`$]P8VIE`$]P8VIE(&%K
M='5A;&EZ86-J:2!S:W)Y<'1U`$]P8VIE("5S`$]R9V%N:7IA8VIA`$IE9&YO
M<W1K82!O<F=A;FEZ86-Y:FYA`$]R9V%N:7IA=&]R`$EN;F4`26YN92!I;F9O
M<FUA8VIE`$EN;F4@;W!C:F4`26YN92!U<')A=VYI96YI80!5=VEE<GIY=&5L
M;FEE;FEE(%!!32!N:64@:F5S="!D;W-TZG!N92X`0WEF<F]W>2!P;V1P:7,@
M4$=0`%=I861O;6^VYB!Z87-Z>69R;W=A;F$@4$=0`$ML=6-Z('!U8FQI8WIN
M>2!01U``5VEA9&]M;[;F('IA<WIY9G)O=V%N82]P;V1P:7-A;F$@:VQU8WIE
M;2!01U``2V]D(%!(4`!0;W>S;VMA(%!(4`!0;W>S;VMA(%!?2%``4&%K:7-T
M86X`4&%L874`4&%N86UA`%!A<'5A+4YO=V$@1W=I;F5A`%!A<F%G=V%J`$AA
M<[-O`$AA<[-O(&YI97!R87=I9+-O=V4`2&%SLV\@>B!P;W1W:65R9'IE;FEE
M;0!(87.S;SH`2&%SLV\Z(`!(87.S;R!M=7-I('!A<V]W8>8N`%=K;&5J`%=K
M;&5J('IE('-C:&]W:V$`5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4`5WEK
M;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4@<&]D8WIA<R!L;V=O=V%N:6$_`%5P
M<F%W;FEE;FEE`%5P<F%W;FEE;FEA(&1L80!);F9O<FUA8VIE(&]S;V)I<W1E
M`%!E<G4`1FEL:7!I;GD`5&5L969O;@!0:71C86ER;@!.82!P97=N;R!U<W5N
ML>8@=&5N('=Y8G)A;GD@96QE;65N=#H`3F$@<&5W;F\@=7-U;K'F('=Y8G)A
M;GD@96QE;65N=#H`4')O<WKJ('!O9&'F('!O<')A=VYY(&%D<F5S($E0+@!0
M<F]S>NH@<&]D8>8@<&]P<F%W;GD@8WIA<RX`4')O<WKJ('!O9&'F(&YA>G?J
M(&YO=V5G;R!F;VQD97)U.@!0<F]S>NH@;W!I<V'F('!R;V)L96TN`%!R;W-Z
MZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O`%!O;'-K80!0;W)T
M=6=A;&EA`%!O9&=LL60`2VQU8WH@<')Y=V%T;GD`4')O8FQE;0!/<&ES('!R
M;V)L96UU`$ML=6-Z('!U8FQI8WIN>0!!;&=O<GET;2!K;'5C>F$@<'5B;&EC
M>FYE9V\`26YF;W)M86-J92!O(&ML=6-Z=2!P=6)L:6-Z;GEM`%!A<F$@:VQU
M8WIY(&]S;V)I<W1Y8V@@;FEE('IO<W1ALV$@=WEG96YE<F]W86YA('!O;7FV
M;&YI92X`4&]R=&]R>6MO`$MA=&%R`%IA<'ET86YI90!+;'5C>B!P=6)L:6-Z
M;GD@4E-!("@E9"!B:73S=RD`4&]W\V0@*%]R*0!/=')Z>6UA;F4`4')Z96MI
M97)U:B!D;P!/9+9W:66_(&1Y;F%M:6-Z;F4@96QE;65N='D@;65N=3H`3V2V
M=VEEOR!W:61O:R!S97)W:7-U.@!7>7)AOV5N:64@<F5G=6QA<FYE`$]D<GIU
MYB!W:6%D;VUOMN8@>B!P;V1A;FEE;2!P;W=O9'4`6F1A;&YE('-E<G=E<GD`
M57-U\0!5<W7Q(&)L;VL`57-U\2!K;VQU;6[J`%5S=?$@<&%RZ@!5<W7Q`%5S
M=?$@=;]Y=&MO=VYI:V$`6F1A;&YE('6_>71K;W=N:6MA.B`E<P!/9&6V;&EJ
M(&1O`$]D9;9L:6H@>@!+87-U:@!7>6-Z>;;F(&AA<[-O`%=Y8WIYMN8@5'=O
M:F4@:&%SLV\`5WEN:6MI`%!O=W+S="!D;R!O<&-J:2!L:7-T>2!F:6QT<O-W
M`%!O=W+S="!D;R!O<&-J:0!0;W=R\W0@9&\@;&ES='D@<F5G=;,`4F5U;FEO
M;@!2;WIB=61O=V%N>2!E9'ET;W(@=&5K<W1U`%-T86YO=VES:V\`4G5M=6YI
M80!/8G+SYB!O(#$X,"!S=&]P;FD`3V)R\^8@=R!L97=O`$]B<O/F('<@<')A
M=V\`5[-AMF-I=V^V8VD@<GKJ9'4@4')O<&5R=&EE<P!296=ULV$`4F5G=;-A
M('-K;W!I;W=A;F$`4F5G=;-A('5S=6YIZG1A`%)E9W6S82!W>;.Q8WIO;F$`
M4F5G=;-A('>SL6-Z;VYA`$YA>G=A(')E9W6S>0!2;W-J80!2=6%N9&$`5VEA
M9&]M;[;F('IA<WIY9G)O=V%N82!3+TU)344`57=I97)Z>71E;&YI96YI92!3
M05-,(&YI92!J97-T(&1O<W3J<&YE+@!0;W=L;VMA(%-13`!34T@`4&]WLV]K
M82!37U%,`*9W:>IT82!(96QE;F$`4V%I;G0@2VET=',@:2!.979I<P!386EN
M="!,=6-I80!386EN="U0:65R<F4@:2!-:7%U96QO;@!386EN="!6:6YC96YT
M(&D@1W)E;F%D>6YY`%-A;6]A`%-A;B!-87)I;F\`07)A8FEA(%-A=61Y:G-K
M80!:87!I<WH`6F%P:7-Z("(E<R(`6F%P:7-Z("5S`%IA<&ES>B!O<&-J90!:
M87!I<WH@;W!C:F4`4VMR>7!T`%5A:W1U86QN:65N:64@<VMR>7!T=0!3:W)Y
M<'0@;FEE=6%K='5A;&YI;VYY+@!3:W)Y<'0@86MT>7=O=V%N>2!P;W!R87=N
M:64N`%-K<GEP="!D96%K='EW;W=A;GD@<&]P<F%W;FEE+@!3>G5K86H`5VED
M>FEA;F4`5WEB:65R>B!P;&EK:0!7>6)I97)Z('!O;&4`5WEB:65R>B!F;VQD
M97(@9&]C96QO=WD`5WEB:65R>B!Z;F%K('!O9'II8;-U(&1A='DZ`%=Y8FEE
M<GH@9F]R;6%T(&1A='DZ`%=Y8FEE<GH@=&^_<V%M;[;F(&1O('IM:6%N>3H`
M5WEB:65R>B!Z;F%K('!O9'II8;-U(&1A='DZ`%=Y8FEE<GH@9F]R;6%T(&-Z
M87-U.@!7>6)I97)Z(&1W82!P87-U:K%C92!P;VQA+@!7>6)I97)Z('-C:&5M
M870@:V]L;W+S=RX`5WEB:65R>B!T=_-J('!R969E<F]W86YY(&KJ>GEK.@!3
M86UO9'II96QN:64@>F1E9FEN:6]W86YY(&YA9[/S=V5K`%=YMFQI:B!R87!O
M<G0@;R!P<F]B;&5M:64`3F%D87=C80!396YE9V%L`%=R>F5S:67Q`$YU;65R
M('-E<GEJ;GD`57-T87<`57-T87<@>F1A;&YE('-E<G=E<GDL(&1O(&MT\W)Y
M8V@@8VAC97-Z(&UI9>8@9&]S=.IP('H@<V5R=VES=2X`57-T87<@<')E9F5R
M;W=A;GD@:NIZ>6LL('-T<F5FZB!C>F%S;W>Q(&D@;W!C:F4@9&%T>2X`57-T
M87<@=7.S=6?J('!O8WJQ=&MO=[$L('-C:&5M870@:V]L;W+S=RP@;V2V=VEE
MOV%N:64@<W1R;VYY(&D@:6YN92!O<&-J92!W>;9W:65T;&%N:6$`57-T87=I
M96YI82!Z;W-T8;-Y('IM:65N:6]N92X`2V]N9FEG=7)A8VIA`%-Z97-Z96QE
M`$MR\W1K:2!O<&ES`%!O:V&_`%!O:V&_(&%K='EW;GD@<VMR>7!T`%!O:V&_
M(&]B96-N>2!S:W)Y<'0`4&]K87IY=V'F(&-Z87,@;W-T871N:65G;R!Z86QO
M9V]W86YI82!P;R!L;V=O=V%N:74_`%!O:V&_(&UE;G4@)7,@<&\@;&5W96H_
M`%-I97)R82!,96]N90!:87)E:F5S=')U:B!S:>HL(&IEMFQI(&IE<WIC>F4@
M=&5G;R!N:64@>G)O8FFS9;8`4&]D<&ES`$%L9V]R>71M('!O9'!I<W4`4VEN
M9V%P=7(`4F]Z;6EA<@!0;VUI\2!O<&5R86-J92!C>6ML:6-Z;F4`4[-O=V%C
M:F$`4[-O=V5N:6$`5WES<'D@4V%L;VUO;F$`4V]M86QI80!0;[-U9&YI;W=A
M($%F<GEK80!0;[-U9&YI;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,RD`1V5O
M<F=I82!0;[-U9&YI;W=A`$AI<WIP86YI80!3<&%M`$5D>6-J82!Z;F%K\W<@
M<W!E8VIA;&YY8V@`4&]D>FEE;"!K;VWS<FOJ`%!O9'II96P@:V]L=6UNZ@!0
M;V1Z:65L('=I97)S>@!3<FD@3&%N:V$`5V]J97?S9+QT=V\@;'5B('-T86X`
M4W1A='5S`%IA=')Z>6UA:B!S<')A=V1Z86YI92!G9'D@=&$@<F5G=;-A(&+J
M9'II92!P87-O=V'F/P!!9')E<R!D;VUO=WD`5&5M870@;F]T>2!W86MA8WEJ
M;F5J("A?8RDZ`%1E;6%T`%=YMFQI:@!0;W=O9'IE;FEE`%5D8;-O('-IZB!D
M;V1AYB`B)7,B(&1O('-Y<W1E;74N`%5D8;-O('-IZB!U<W5NL>8@(B5S(B!Z
M('-Y<W1E;74N`%5D8;-O('-IZB!U<W5NL>8@(B5S(BX`561ALV\@<VGJ('5S
M=6ZQYB`B)7,B('H@<WES=&5M=2X`561ALV\@<VGJ('5A:W1U86QN:>8@(B5S
M(@!3=61A;@!7<V-H\V0O>F%C:/-D('.S;_%C80!3=7)I;F%M`%-U87II`%-Z
M=V5C:F$`4WIW86IC87)I80!3>7)I80!486IW86X`5&%J=V%N`%1A9+]Y:VES
M=&%N`%1A;GIA;FEA`%IA9&%N:6$`3G5M97(@=&5L969O;G4`5'EL:V\@=&5K
M<W0`5&%J;&%N9&EA`$1Z:>IK=6IE;7D@>F$@:V]R>GES=&%N:64@>B!S97)W
M:7-U+@!3=&5R;W=N:6L@=WEP;'6S.B``5&^_<V%M;[;F("(E<R(@>F]S=&&S
M82!U<W5N:>IT82X`4V5R=V5R("(E<R(@>F]S=&&S('5S=6YIZG1Y+@!397)W
M97(@(B5S(B!Z;W-T8;,@>F%P:7-A;GDN`$)L;VL@=V5A=&AE<BYC;VT@;FEE
M(&IE<W0@9&]S=.IP;GDN`$YI92!M82"_861N>6-H(&1O<W3J<&YY8V@@;W!C
M:FDN`%=Y<W2Q<&FS('!R;V)L96T@<')Z>2!D;V1A=V%N:74@(B5S(B!D;R!S
M>7-T96UU.B`E<P!7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@9&%N
M>6-H(&1L82!UOWET:V]W;FEK82`B)7,B('<@<WES=&5M:64Z(`!7>7-TL7!I
MLR!P<F]B;&5M('!R>GD@=7-U=V%N:74@(B5S(B!Z('-Y<W1E;74N`%=Y<W2Q
M<&FS('!R;V)L96T@<')Z>2!U86MT=6%L;FEA;FEU("(E<R(Z("5S`$*SL60@
M<&]D8WIA<R!A:W1Y=V%C:FD@<VMR>7!T=2X`0K.Q9"!P;V1C>F%S(&1E86MT
M>7=A8VII('-K<GEP='4N`%=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!W>;9W:65T
M;&%N:6$@=&5J(&-ZZK9C:2!W:6%D;VUOMF-I`%=Y<W2Q<&FS(&*SL60@<&]C
M>F%S(&EM<&]R=&]W86YI82!D86YY8V@@:4-A;&5N9&%R+@!0;&EK(&YI92!W
M>6=LL61A(&YA('!O<')A=VYE(&%R8VAI=W5M(%)!4BX`4&QI:R!N:64@=WEG
M;+%D82!N82!P;W!R87=N92!A<F-H:7=U;2!:25`N`%1O('!O;&4@:F5S="!W
M>6UA9V%N92X`5&\@<&]L92!M=7-I(&)YYB!P;W!R87=NL2!L:6-Z8K$N`%=I
M861O;6^VYB!Z;W-T8;-A(&YA<&ES86YA('<@:6YN96H@;FF_('1W;VIA('-T
M<F]N:64@:V]D;W=E:B`H)7,I+@!496X@<V5R=V5R(&YI92!P;W1R869I(')O
M>G!A:V]W>7=AYB!A<F-H:7?S=R!Z:7`@:2!G>FEP+@!#>F%S`$9O<FUA="!C
M>F%S=0!4>71ULP!$;P!!8GD@=WEB<F'F('=I96QO:W)O=&YE('!O;&$@<')Z
M>71R>GEM86H@<')Z>6-I<VL@0W1R;"`H4$,I(&QU8B!#;VUM86YD("A-86,I
M('!O9&-Z87,@:VQI:V%N:6$N`$1Z:;8`5&]G;P!4;VME;&%U`$IU=')O`%1O
M;F=A`%1R>6YI9&%D(&D@5&]B86=O`%!R87=D82!L=6(@9F&S<WH`5'5N97IJ
M80!4=7)C:F$`5'5R96-K:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U
M=F%L=0!54DP`55),.@!59V%N9&$`56MR86EN80!"L[%D('!O9&-Z87,@>FUI
M86YY(&1O("5S+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@4U%,+@!"L[%D('!O9&-Z87,@<F]Z<&%K;W=Y=V%N:6$@9&%N>6-H+@!.
M:64@;6]GZB!W8WIY=&'F(&1E9FEN:6-J:2`E<RX`3FEE(&UOOVYA('!R>F5T
MLW5M86-Z>>8@=&5G;R!D;VMU;65N='4@5V]R9"UA`$-O9FYI:B!Z;6EA;GD`
M6FIE9&YO8WIO;F4@16UI<F%T>2!!<F%B<VMI90!7:65L:V$@0G)Y=&%N:6$`
M55-!`$YI97IN86YE`$)E>B!N87IW>0!.:65O8G.S=6=I=V%N92!R;WIS>F5R
M>F5N:64`56%K='5A;&YI:@!:8;-A9'5J`%5R=6=W86H`3W!C:F4@=;]Y=&MO
M=VYI:V$`4F5J97-T<F%C:F$@=;]Y=&MO=VYI:V$`3F%Z=V$@=;]Y=&MO=VYI
M:V$`5;]Y=&MO=VYI:R!O(&YA>G=I92`B)7,B(&IUOR!I<W1N:65J92X`3F%Z
M=V$@=;]Y=&MO=VYI:V$Z`$YA>G=A('6_>71K;W=N:6MA.B``5;]Y=&MO=VYI
M8WD@=R!S>7-T96UI93H`57IB96MI<W1A;@!786MA8VIE`$5D>6-J82!N;W1Y
M('=A:V%C>6IN96H`3F]T82!W86MA8WEJ;F$`3F]T82!W86MA8WEJ;F$@;FEE
M(&IE<W0@;V)SLW5G:7=A;F$@<')Z97H@;V)E8VYY('-T97)O=VYI:R!F:6QT
M<F]W86YI82X`5F%N=6%T=0!796YE>G5E;&$`5V5R<VIA`%=I971N86T`5VED
M;VL@)7,`4&]K8;\@<W1R;V[J(%=75P!0;VMAOR!J86MO("5S`$)R>71Y:G-K
M:64@5WES<'D@1'II97=I8WIE`%=Y<W!Y($1Z:65W:6-Z92!3=&%N\W<@6FIE
M9&YO8WIO;GEC:`!786QL:7,@:2!&=71U;F$`3W-T<GIEOV5N:64`5U=7`$-O
M('1Y9'II9?$`5VET86UY`%=I=&%M>2!W("5S`%=I=&%M>2P@)7,`6F%C:&]D
M;FD@*$E33RTX.#4Y+3$I`%IA8VAO9&YI("A)4T\M.#@U.2TQ-2D`4V%H87)A
M(%IA8VAO9&YI80!!9')E<WD@;F$@8FEALV5J(&QIMF-I92`H7VDI.@!*86NQ
M(&%P;&EK86-JZB!M82`E<R!W>;9W:65T;&'F('!O('IA;&]G;W=A;FEU('-I
MZC\`2F%K:64@=W1Y8WIK:2!A:W1Y=V]W8>8@=R!2;WIB=61O=V%N>6T@961Y
M=&]R>F4@=&5K<W1U+@!":6&S82!L:7-T80!%9'EC:F$@8FEALV5J(&QI<W1Y
M`$)I8;-A(&QI<W1A(&YI92!J97-T(&]B<[-U9VEW86YA('!R>F5Z(&]B96-N
M>2!S=&5R;W=N:6L@9FEL=')O=V%N:6$N`$%D<F5S>2!N82!B:6&S96H@;&FV
M8VEE`%-Z97)O:V^VYB!L97=E9V\@;65N=2`E<R`H>FUI86YA('IA8WIN:64@
M;V)O=VFQ>GEW8>8@<')Z>2!N87-TZG!N>6T@;&]G;W=A;FEU*3H`061R97,@
M9&\@<')A8WD`5&5L+B!D;R!P<F%C>0!8+5!R:6]R>71E=`!8+5!O>FEO;2U3
M<&%M=0!8+5!U;FMT>2U3<&%M=0!8+5-T871U<RU3<&%M=0!24@!24E)2`$-O
M(')O:P!*96UE;@!486L`5&%K+"!Z9V%D>F%M('-IZ@!7>6QO9V]W8;-EMB!S
M:>HN`$UU<VES>B!O<&ES8>8@<')O8FQE;2!Z86YI;2!G;R!W>;9L97-Z+@!-
M=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z('5S
M=6ZQYBX`375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H
M8V5S>B!D;V1AYBX`5'?S:B!A9')E<R!E+6UA:6P`5'?S:B!A9')E<R!/9#H`
M5'=O:F4@:6YF;W)M86-J90!4=_-J(&%D<F5S(&EN=&5R;F5T;W=Y('-IZB!Z
M;6EE;FFS(&]D('!O8WJQ=&MU('-E<VII("5S+B!7('IW:;%Z:W4@>B!B97IP
M:65C>F7Q<W1W96T@5'=O:F5G;R!K;VYT82!M=7-I<WH@>F%L;V=O=V'F('-I
MZB!P;VYO=VYI92X`5'=O:F4@:6UIZ@!496X@<WES=&5M(&%U=&5N='EK86-J
M:2!N:64@;V)SLW5G=6IE(&1O9&%W86YI82!UOWET:V]W;FEK\W<L(&QU8B!T
M82!O<&-J82!Z;W-T8;-A('=YL[%C>F]N82X`5&5N('-Y<W1E;2!A=71E;G1Y
M:V%C:FD@;FEE(&]B<[-U9W5J92!L:7-T;W=A;FEA('6_>71K;W=N:6OS=RP@
M;'5B('1A(&]P8VIA('IO<W1ALV$@=WFSL6-Z;VYA+@!4=V]J82!O8F5C;F$@
M<W1R969A(&-Z87-O=V$Z`$1O;7FV;&YA('1OOW-A;6^VYCH`5'=O:F4@<&6S
M;F4@:6UIZB!I(&YA>G=I<VMO.@!4=V]I;2!N;W=Y;2!H87.S96T@=R`E<R!J
M97-T.B`E<P!4=V]J92!U<W1A=VEE;FEA('IO<W1ALWD@=6%K='5A;&YI;VYE
M(&YA(&-Z87,@=')W86YI82!T96H@<V5S:FDN`%1W;VIE('5S=&%W:65N:6$@
M>F]S=&&S>2!U86MT=6%L;FEO;F4N`%1W;VIE('ID86QN92!S97)W97)Y.@!*
M=6=O<[-A=VEA`%IA:7(`6F%M8FEA`%II;6)A8G=E`%MB<F%K('1E;6%T=5T`
M6U)A<&]R="!O('!R;V)L96UI95T`7T%D<F5S>2P@;F$@:W3S<F4@<')Z96MA
M>GEW8>8Z`%]!9')E<WDL(&YA(&MT\W)E(&YI92!BZF2Q('=Y<WFS86YE(&]D
M<&]W:65D>FDZ`%]!9&UI;FES=')A8VIA`$-Z87)N82!L:7-T82`H7V(I`%]#
M3$D`7U5S=?$@=VEE<G-Z`%5S=?$@8V&S:V]W:6-I92!W:6%D;VUOMN8@*%]D
M*0!7<')O=V%D>F%J(&MAOV1Y(&%D<F5S('<@;F]W96H@;&EN:6D@*%]E*3H`
M4')Z96MAOR`H7V8I`%]'<G5P>0!?4&]M;V,`6F%C:&]W86H@:V]P:>H@=VEA
M9&]M;[9C:2!N82!T>6T@:V]N8VEE/R`H7VLI`%]:86QO9W5J`%]7>6QO9W5J
M`%IM:67Q(&QI;FLN+BX`4')Z96YI9;8@=VEA9&]M;[;F(&1O(&9O;&1E<G4@
M*%]M*3H`7TUO:F4@861R97-Y(&5M86EL.@!?3W!C:F4`7U5P<F%W;FEE;FEA
M`%5S=?$@;&EN:RXN+@!?4VMR>7!T`%]+;VYF:6=U<F%C:F$`7U6_>71K;W=N
M:6-Y`%=A:V%C:F4@*%]V*0!":6&S82!L:7-T82`H7W<I`&MS:;&_:V$@861R
M97-O=V$`:0!K86QE;F1A<GH`<&]L90!P;&EK`'!A<W5J90!.87IW:7-K;P!N
M;W1A=&YI:P!L=6(`4VMR>7!T('!R;V-M86EL('=Y9V5N97)O=V%N>2!P<GIE
M>B!);F=O`&)E>B!N87IW>0!V0V%R9```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE+W!T7T)2+P``````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-#<`,#$W-C,P`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A
M;&4O<'1?0E(O3$-?34534T%'15,O````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,C$T,34`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;F=O+VQO8V%L92]P=%]"4B],0U]-15-304=%4R]I;F=O+FUO
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#4Q-S(R`#$P-#$W,S8R-S0W`#`R,C<Q
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````$X(```<````C$(``!4+``#\A````````%"Q```.````4;$```\`
M``!@L0``#0```'"Q```(````?K$```L```"'L0``#````).Q```$````H+$`
M``0```"EL0```P```*JQ```8````KK$``!L```#'L0``+0```..Q```=````
M$;(``"0````OL@``*0```%2R```9````?K(``"8```"8L@``#````+^R```D
M````S+(```\```#QL@``"P````&S```.````#;,```4````<LP``*````"*S
M```(````2[,```H```!4LP``%0```%^S```2````=;,```L```"(LP``A0``
M`)2S```.````&K0```H````IM```#0```#2T```.````0K0``!$```!1M```
M#0```&.T```,````<;0```T```!^M```!@```(RT``"4````D[0```H````H
MM0``#P```#.U```8````0[4```P```!<M0``#@```&FU```.````>+4```@`
M``"'M0``"0```)"U```N````FK4``!H```#)M0``,@```.2U```X````%[8`
M`%0```!0M@``40```*6V``!:````][8``%<```!2MP``-````*JW```)````
MW[<```T```#IMP``!P```/>W```*````_[<```\````*N```!0```!JX```&
M````(+@``!$````GN```"````#FX```)````0K@```D```!,N```)0```%:X
M```@````?+@``!,```"=N```$````+&X```/````PK@```H```#2N```(0``
M`-VX```/````_[@``"X````/N0```P```#ZY```/````0KD``!0```!2N0``
M"0```&>Y```-````<;D``!(```!_N0``&0```)*Y```>````K+D```\```#+
MN0``"@```-NY```/````YKD```@```#VN0``)````/^Y```4````)+H``!8`
M```YN@``"````%"Z``!.````6;H``"T```"HN@``&0```-:Z```3````\+H`
M``<````$NP``#`````R[```L````&;L```X```!&NP```P```%6[```+````
M6;L```<```!ENP``!P```&V[```%````=;L```4```![NP``"@```(&[```#
M````C+L``!<```"0NP``"@```*B[```/````L[L```X```##NP``%````-*[
M```+````Y[L``!@```#SNP``(P````R\```.````,+P``!0````_O```%P``
M`%2\```7````;+P``!<```"$O```$P```)R\```/````L+P```X```#`O```
M'P```,^\```=````[[P```<````-O0``!@```!6]```(````'+T```\````E
MO0``!@```#6]```(````/+T```H```!%O0``$P```%"]```4````9+T```L`
M``!YO0``$````(6]```5````EKT```T```"LO0``%0```+J]```'````T+T`
M`!````#8O0``!0```.F]```5````[[T``!$````%O@``#````!>^```J````
M)+X``#L```!/O@``.````(N^```)````Q+X```<```#.O@``%````-:^```#
M````Z[X```4```#OO@``$````/6^```)````!K\``!,````0OP``.0```"2_
M```2````7K\``"<```!QOP``+````)F_```J````QK\``"4```#QOP``"@``
M`!?````&````(L````D````IP```!P```#/````O````.\```#<```!KP```
M+@```*/```!5````TL```"T````HP0``+0```%;!```]````A,$``#\```#"
MP0``+0````+"``!`````,,(``",```!QP@``(P```)7"``!`````N<(``"T`
M``#ZP@``,P```"C#```E````7,,``!4```""PP``&0```)C#```I````LL,`
M`"0```#<PP``*`````'$```R````*L0``!$```!=Q```"@```&_$```,````
M>L0```H```"'Q```$````)+$```6````H\0``!8```"ZQ```!P```-'$```'
M````V<0``!0```#AQ```"@```/;$```(`````<4``"<````*Q0``"````#+%
M```#````.\4```L````_Q0``!P```$O%```'````4\4```8```!;Q0``!0``
M`&+%```'````:,4```8```!PQ0``%````'?%```(````C,4```D```"5Q0``
M#@```)_%```[````KL4``!4```#JQ0``*0````#&```.````*L8```H````Y
MQ@``!````$3&```$````2<8```<```!.Q@``"0```%;&```&````8,8``!$`
M``!GQ@``!P```'G&```6````@<8```0```"8Q@``"````)W&```&````IL8`
M``T```"MQ@``!@```+O&```>````PL8``!$```#AQ@``"````//&```-````
M_,8```P````*QP``!P```!?'```#````'\<```,````CQP``%P```"?'```3
M````/\<``!T```!3QP``"````'''```$````>L<```@```!_QP``"````(C'
M``!!````D<<``!H```#3QP``*P```.['```@````&L@``!4````[R```!@``
M`%'(```&````6,@``!4```!?R```&````'7(```B````CL@``"X```"QR```
M'0```.#(```A````_L@``%0````@R0``*0```'7)```*````G\D```<```"J
MR0``!P```++)```.````NLD``!4```#)R0``#@```-_)```"````[LD```H`
M``#QR0``#P```/S)```-````#,H```\````:R@``#0```"K*```)````.,H`
M`!0```!"R@``!@```%?*```8````7LH``!T```!WR@``$P```)7*```1````
MJ<H``!0```"[R@``!````-#*```&````U<H``!0```#<R@``5````/'*```.
M````1LL``&0```!5RP``!````+K+```.````O\L```4```#.RP``!0```-3+
M```;````VLL``!H```#VRP``$P```!',```1````)<P``!$````WS```'```
M`$G,```J````9LP``!````"1S```(0```*+,```%````Q,P``!,```#*S```
M"P```-[,```2````ZLP```H```#]S```#P````C-```-````&,T``!$````F
MS0``$P```#C-```,````3,T```8```!9S0``#````&#-```&````;<T``!<`
M``!TS0``$````(S-```1````G<T```@```"OS0``!0```+C-```,````OLT`
M`!````#+S0``!0```-S-```-````XLT```8```#PS0``!P```/?-```-````
M_\T```<````-S@``"P```!7.```'````(<X```<````IS@``"0```#'.```)
M````.\X```H```!%S@``&0```%#.```]````:LX``!T```"HS@``#````,;.
M```0````T\X```4```#DS@``)0```.K.```2````$,\``!,````CSP``$@``
M`#?/```K````2L\``#L```!VSP``(````++/```(````T\\``#8```#<SP``
M"````!/0```A````'-```!`````^T```"````$_0```,````6-````8```!E
MT```!````&S0```'````<=````\```!YT```"@```(G0```.````E-````<`
M``"CT```"@```*O0```-````MM```!\```#$T```'````.30```A`````=$`
M`!X````CT0``&0```$+1```>````7-$``!L```![T0``(0```)?1```N````
MN=$``"8```#HT0``'`````_2```>````+-(``!P```!+T@``)@```&C2```K
M````C](``#,```"[T@``)@```._2```K````%M,``#@```!"TP``'0```'O3
M```5````F=,``"\```"OTP``(````-_3```2`````-0``"D````3U```'@``
M`#W4```@````7-0``!(```!]U```H@```)#4```6````,]4``",```!*U0``
M*````&[5```I````E]4``"@```#!U0``'P```.K5```5````"M8``"`````@
MU@``)0```$'6```H````9]8``"T```"0U@``,````+[6``"2````[]8``"$`
M``""UP``%@```*37```<````N]<``"8```#8UP``*@```/_7``!!````*M@`
M`$0```!LV```#````+'8```'````OM@```<```#&V```!@```,[8```-````
MU=@``!````#CV```$0```/38```2````!MD``!,````9V0``$@```"W9```'
M````0-D```0```!(V0``$````$W9```0````7MD```P```!OV0``#@```'S9
M```-````B]D```\```"9V0``$P```*G9```-````O=D``"@```#+V0```P``
M`/39```-````^-D```8````&V@``$0````W:```7````']H``!L````WV@``
M#@```%/:```"````8MH```H```!EV@``20```'#:```%````NMH``!````#`
MV@``#P```-':```$````X=H```T```#FV@``#@```/3:```#`````]L```X`
M```'VP``$0```!;;```(````*-L```\````QVP``#P```$';```'````4=L`
M``T```!9VP``$````&?;```-````>-L```L```"&VP``!@```)+;```)````
MF=L```L```"CVP``$````*_;```,````P-L```H```#-VP``$0```-C;```9
M````ZML```L````$W```#0```!#<```B````'MP``!D```!!W```&P```%O<
M```T````=]P```H```"LW```&````+?<```9````T-P``!8```#JW```!P``
M``'=```B````"=T``!4````LW0``(0```$+=```E````9-T``!$```"*W0``
M#0```)S=```'````JMT``!0```"RW0``"P```,?=```B````T]T``"\```#V
MW0``"P```";>```)````,MX``!D````\W@``"P```%;>```7````8MX``!<`
M``!ZW@``"0```)+>```*````G-X```@```"GW@``%@```+#>```/````Q]X`
M`!D```#7W@``.@```/'>```6````+-\```X```!#WP``&````%+?```(````
M:]\``"\```!TWP``#0```*3?```F````LM\```@```#9WP``0P```.+?```2
M````)N````\````YX```$````$G@```-````6N```"$```!HX```"````(K@
M```2````D^```!\```"FX```"````,;@```+````S^```"\```#;X```#@``
M``OA```%````&N$```8````@X0``10```"?A```#````;>$```<```!QX0``
M!````'GA```'````?N$```H```"&X0``"@```)'A```/````G.$``!````"L
MX0``%P```+WA```1````U>$``!D```#GX0``%P````'B```)````&>(```4`
M```CX@``"P```"GB```*````->(```(```!`X@``!0```$/B```-````2>(`
M`!L```!7X@``%P```'/B```4````B^(```D```"@X@``#@```*KB```-````
MN>(``!(```#'X@``"0```-KB```X````Y.(``"`````=XP``!P```#[C```(
M````1N,```D```!/XP``#@```%GC``![````:.,``!@```#DXP``&````/WC
M```(````%N0``!$````?Y```!P```#'D```%````.>0``!@````_Y```'@``
M`%CD```;````=^0``!D```"3Y```*````*WD```5````UN0``!L```#LY```
M&0````CE```3````(N4```<````VY0``"````#[E```&````1^4```8```!.
MY0``$````%7E```/````9N4``!````!VY0``#P```(?E```+````E^4```\`
M``"CY0``#````+/E```/````P.4```<```#0Y0``#@```-CE```&````Y^4`
M``8```#NY0``#@```/7E```,````!.8``!H````1Y@``*````"SF```/````
M5>8```@```!EY@``"````&[F```3````=^8``!X```"+Y@``(0```*KF```@
M````S.8``!D```#MY@``%P````?G```E````'^<``!<```!%YP``%@```%WG
M```$````=.<``!L```!YYP``#0```)7G```,````H^<```,```"PYP``!0``
M`+3G```(````NN<```H```##YP``#````,[G```+````V^<``!````#GYP``
M#````/CG```.````!>@```L````4Z```!````"#H```$````)>@``!,````J
MZ```%````#[H```,````4^@```D```!@Z```#@```&KH```+````>>@``!L`
M``"%Z```$P```*'H```9````M>@``!L```#/Z```#@```.OH```+````^N@`
M``P````&Z0``%0```!/I```-````*>D``$,````WZ0``,0```'OI``!"````
MK>D``$<```#PZ0``3P```#CJ```]````B.H``$X```#&Z@``$0```!7K```'
M````)^L```<````OZP``"@```#?K```-````0NL```D```!0ZP``!````%KK
M```%````7^L```,```!EZP``&````&GK```*````@NL```0```"-ZP``)0``
M`)+K```F````N.L```X```#?ZP``?````.[K```5````:^P```4```"![```
M!P```(?L```,````C^P```@```"<[```"@```*7L```&````L.P```<```"W
M[```.0```+_L```(````^>P```T````"[0```@```!#M```&````$^T```8`
M```:[0``%````"'M```-````-NT``!````!$[0``&P```%7M```$````<>T`
M``D```!V[0``!0```(#M```0````ANT```D```"7[0``"0```*'M```%````
MJ^T``!H```"Q[0``"````,SM```&````U>T``!D```#<[0``#@```/;M```'
M````!>X```<````-[@``!0```!7N```)````&^X```H````E[@``#@```##N
M```"````/^X```8```!"[@``"P```$GN```-````5>X```D```!C[@``#```
M`&WN```8````>NX```8```"3[@``$@```)KN```)````K>X```<```"W[@``
M%````+_N```=````U.X``$(```#R[@``)0```#7O```E````6^\```8```"!
M[P``"@```(CO```$````D^\```D```"8[P``"````*+O```1````J^\```D`
M``"][P``!@```,?O```-````SN\```8```#<[P``!````./O```Y````Z.\`
M`#T````B\```.@```&#P```>````F_````4```"Z\```#@```,#P```$````
MS_````8```#4\```!P```-OP```A````X_````T````%\0``%0```!/Q```&
M````*?$```0````P\0``$0```#7Q```&````1_$```H```!.\0``(@```%GQ
M```$````?/$```4```"!\0``'0```(?Q```$````I?$```P```"J\0``#@``
M`+?Q```*````QO$```@```#1\0``"0```-KQ```%````Y/$``#H```#J\0``
M,````"7R```U````5O(``"D```",\@``1P```+;R```X````_O(``"D````W
M\P``/P```&'S```N````H?,``"T```#0\P``'P```/[S```/````'O0``!(`
M```N]```"P```$'T```F````3?0``"D```!T]```)````)[T```F````P_0`
M``@```#J]```"@```//T```)````_O0```<````(]0``(````!#U```@````
M,?4``"8```!2]0``"@```'GU```9````A/4``"D```">]0``%@```,CU```2
M````W_4```<```#R]0``"@```/KU```,````!?8```\````2]@``$````"+V
M``!`````,_8``'````!T]@``9@```.7V```.````3/<```D```!;]P``"@``
M`&7W```2````</<``!,```"#]P``#````)?W```&````I/<```\```"K]P``
M"0```+OW```2````Q?<``!````#8]P``$0```.GW```<````^_<``",````8
M^```:@```#SX```/````I_@```4```"W^```$````+WX``!#````SO@```D`
M```2^0``,@```!SY```$````3_D```L```!4^0``(````&#Y```4````@?D`
M``P```"6^0``#````*/Y```/````L/D``!4```#`^0``*0```-;Y```J````
M`/H``"8````K^@``)P```%+Z```I````>OH``"H```"D^@``&0```,_Z``!"
M````Z?H``!$````L^P``$@```#[[```3````4?L``!0```!E^P``#P```'K[
M```6````BOL``!<```"A^P``$````+G[```1````ROL``#0```#<^P``$P``
M`!'\```2````)?P``#4````X_```%````&[\```'````@_P```P```"+_```
M(````)C\```0````N?P``!0```#*_```$0```-_\```7````\?P``!P````)
M_0``$P```";]```4````.OT``!H```!/_0``$0```&K]```:````?/T``!X`
M``"7_0``&@```+;]```3````T?T``!4```#E_0``$0```/O]```7````#?X`
M`!0````E_@``%P```#K^```5````4OX```D```!H_@``$````'+^```9````
M@_X```0```"=_@``!P```*+^```"````JOX```L```"M_@``!0```+G^```1
M````O_X```8```#1_@``!@```-C^```&````W_X```4```#F_@``!P```.S^
M```'````]/X```4```#\_@``%@````+_```&````&?\```8````@_P``!```
M`"?_```$````+/\```<````Q_P``#@```#G_```,````2/\```P```!5_P``
M#0```&+_```*````</\```X```![_P``!0```(K_```H````D/\```X```"Y
M_P``#````,C_```/````U?\```H```#E_P``"````/#_```)````^?\``"L`
M```#``$`!````"\``0`(````-``!`"8````]``$`$@```&0``0`/````=P`!
M``8```"'``$`"@```(X``0!,````F0`!``<```#F``$`"````.X``0`@````
M]P`!``D````8`0$`%````"(!`0`,````-P$!``T```!$`0$`#@```%(!`0`6
M````80$!`!$```!X`0$`!@```(H!`0`#````D0$!``8```"5`0$`&0```)P!
M`0`'````M@$!``0```"^`0$`"P```,,!`0`+````SP$!``<```#;`0$`"0``
M`.,!`0`5````[0$!``4````#`@$`!P````D"`0`6````$0(!``T````H`@$`
M#0```#8"`0`*````1`(!`!````!/`@$`#P```&`"`0`1````<`(!`!<```""
M`@$`"@```)H"`0`1````I0(!``@```"W`@$`!````,`"`0`/````Q0(!`#H`
M``#5`@$`!0```!`#`0`,````%@,!`!X````C`P$`#@```$(#`0`0````40,!
M``L```!B`P$`#````&X#`0`)````>P,!``<```"%`P$`!P```(T#`0`*````
ME0,!``D```"@`P$`#@```*H#`0`0````N0,!`!L```#*`P$`&````.8#`0`:
M````_P,!``H````:!`$`"0```"4$`0`*````+P0!``P````Z!`$`#P```$<$
M`0`(````5P0!``8```!@!`$`'````&<$`0`'````A`0!``4```",!`$`"P``
M`)($`0!'````G@0!``T```#F!`$`"0```/0$`0`$````_@0!``,````#!0$`
M$P````<%`0`3````&P4!`!,````O!0$`"@```$,%`0`"````3@4!``0```!1
M!0$`)0```%8%`0`#````?`4!``4```"`!0$`*@```(8%`0`*````L04!``4`
M``"\!0$`!````,(%`0`*````QP4!``T```#2!0$`!@```.`%`0`(````YP4!
M``@```#P!0$`!````/D%`0`%````_@4!`&@````$!@$`"0```&T&`0`,````
M=P8!`!````"$!@$`&````)4&`0`%````K@8!``8```"T!@$`$````+L&`0`;
M````S`8!`"\```#H!@$`$````!@'`0`*````*0<!`!L````T!P$`#P```%`'
M`0`*````8`<!``D```!K!P$`$P```'4'`0`;````B0<!`!@```"E!P$`%P``
M`+X'`0`?````U@<!`!<```#V!P$`#@````X(`0")````'0@!`(D```"G"`$`
M`P```#$)`0`'````-0D!``@````]"0$`!P```$8)`0`*````3@D!``L```!9
M"0$`!P```&4)`0!1````;0D!`!````"_"0$`#````-`)`0`-````W0D!`!H`
M``#K"0$`2@````8*`0`9````40H!``8```!K"@$`&@```'(*`0`E````C0H!
M``8```"S"@$`!@```+H*`0`?````P0H!``8```#A"@$`"0```.@*`0`8````
M\@H!`!<````+"P$`*````",+`0`&````3`L!``T```!3"P$`(@```&$+`0`9
M````A`L!`"8```">"P$`5P```,4+`0`3````'0P!`!D````Q#`$`&P```$L,
M`0`C````9PP!`!,```"+#`$``@```)\,`0`+````H@P!``@```"N#`$`#0``
M`+<,`0`*````Q0P!``<```#0#`$`%````-@,`0`&````[0P!``@```#T#`$`
M#@```/T,`0`'````#`T!``H````4#0$`"P```!\-`0`R````*PT!``<```!>
M#0$`#````&8-`0`-````<PT!``P```"!#0$`!````(X-`0`)````DPT!``D`
M``"=#0$`"@```*<-`0`.````L@T!``P```#!#0$`!P```,X-`0`)````U@T!
M``<```#@#0$`"@```.@-`0`;````\PT!``\````/#@$`$@```!\.`0`*````
M,@X!`!8````]#@$`"0```%0.`0`0````7@X!``<```!O#@$`$@```'<.`0`I
M````B@X!``0```"T#@$`!P```+D.`0`%````P0X!``4```#'#@$`"P```,T.
M`0`4````V0X!`!$```#N#@$`&@`````/`0`6````&P\!`!0````R#P$`%P``
M`$</`0`8````7P\!`!P```!X#P$`&0```)4/`0`'````KP\!``4```"W#P$`
M#0```+T/`0`,````RP\!`!$```#8#P$`"````.H/`0`(````\P\!`!<```#\
M#P$`"P```!00`0`,````(!`!`!\````M$`$`&@```$T0`0`3````:!`!``0`
M``!\$`$`"@```($0`0`$````C!`!``T```"1$`$`#````)\0`0`%````K!`!
M``D```"R$`$`!0```+P0`0`'````PA`!``4```#*$`$`!````-`0`0`"````
MU1`!`"\```#8$`$`.`````@1`0`L````01$!`",```!N$0$`)@```)(1`0`2
M````N1$!`"D```#,$0$`,@```/81`0`*````*1(!`"P````T$@$`+@```&$2
M`0`S````D!(!`#,```#$$@$`.````/@2`0`/````,1,!`!@```!!$P$`$```
M`%H3`0`N````:Q,!`!0```":$P$`#P```*\3`0`3````OQ,!`!4```#3$P$`
M%````.D3`0`2````_A,!`!0````1%`$`%0```"84`0`M````/!0!`"T```!J
M%`$`,0```)@4`0`N````RA0!`"\```#Y%`$`+````"D5`0!B````5A4!`!,`
M``"Y%0$`#0```,T5`0`(````VQ4!`!0```#D%0$`%P```/D5`0`(````$18!
M`!0````:%@$`#````"\6`0`K````/!8!`"$```!H%@$`&@```(H6`0`)````
MI18!`$4```"O%@$`00```/46`0`$````-Q<!`!,````\%P$`%````%`7`0`.
M````91<!`!,```!T%P$`&````(@7`0`&````H1<!``D```"H%P$`"@```+(7
M`0`/````O1<!``P```#-%P$`$````-H7`0`'````ZQ<!``X```#S%P$`!0``
M``(8`0`;````"!@!`!0````D&`$`"````#D8`0`&````0A@!`!0```!)&`$`
M$0```%X8`0`.````<!@!`#@```!_&`$``@```+@8`0`&````NQ@!``X```#"
M&`$`!0```-$8`0`'````UQ@!``X```#?&`$`!@```.X8`0`H````]1@!``P`
M```>&0$`'````"L9`0`$````2!D!`"D```!-&0$`%0```'<9`0`7````C1D!
M`!\```"E&0$`7````,49`0`4````(AH!`#X````W&@$`'P```'8:`0`0````
MEAH!``<```"G&@$`'@```*\:`0`.````SAH!``P```#=&@$`#````.H:`0`3
M````]QH!``H````+&P$`'0```!8;`0`9````-!L!``4```!.&P$`$0```%0;
M`0`-````9AL!``@```!T&P$`$0```'T;`0`D````CQL!`!(```"T&P$`%0``
M`,<;`0`2````W1L!``X```#P&P$`&0```/\;`0`(````&1P!``D````B'`$`
M#0```"P<`0`'````.AP!``H```!"'`$`!P```$T<`0`/````51P!``8```!E
M'`$`"P```&P<`0`:````>!P!``H```"3'`$`!P```)X<`0`(````IAP!``4`
M``"O'`$`'P```+4<`0`&````U1P!`!````#<'`$`"````.T<`0`-````]AP!
M``@````$'0$`'@````T=`0`2````+!T!`"P````_'0$`&@```&P=`0`)````
MAQT!``H```"1'0$`%0```)P=`0`%````LAT!`!0```"X'0$`!````,T=`0`0
M````TAT!``8```#C'0$`!P```.H=`0`>````\AT!`"@````1'@$`"@```#H>
M`0`<````11X!`!$```!B'@$`"P```'0>`0`:````@!X!`!0```";'@$`!```
M`+`>`0`$````M1X!``L```"Z'@$`!0```,8>`0`&````S!X!``@```#3'@$`
M!@```-P>`0`*````XQX!`!L```#N'@$`-`````H?`0`T````/Q\!`"````!T
M'P$`*0```)4?`0`@````OQ\!`$$```#@'P$`&@```"(@`0`H````/2`!`"@`
M``!F(`$`*0```(\@`0!0````N2`!`"(````*(0$`!@```"TA`0`(````-"$!
M``4````](0$`"````$,A`0`9````3"$!`!D```!F(0$`*@```(`A`0`C````
MJR$!`!D```#/(0$`+@```.DA`0`T````&"(!``@```!-(@$`%P```%8B`0`*
M````;B(!``<```!Y(@$`(0```($B`0`0````HR(!``X```"T(@$`"P```,,B
M`0`'````SR(!`!,```#7(@$`"````.LB`0`+````]"(!``H`````(P$`%```
M``LC`0`/````(",!`#(````P(P$`"P```&,C`0`%````;R,!``4```!U(P$`
M!0```'LC`0`7````@2,!``<```"9(P$`#P```*$C`0`$````L2,!``H```"V
M(P$`"0```,$C`0`+````RR,!``T```#7(P$`#````.4C`0`.````\B,!``4`
M```!)`$`!`````<D`0`-````#"0!`#(````:)`$`10```$TD`0`(````DR0!
M``L```"<)`$`%P```*@D`0`'````P"0!`!X```#()`$`%````.<D`0`%````
M_"0!`!(````")0$`$@```!4E`0`4````*"4!``8````])0$`!P```$0E`0`.
M````3"4!`"H```!;)0$`!@```(8E`0`,````C24!``T```":)0$`$0```*@E
M`0`+````NB4!`#8```#&)0$`"@```/TE`0`B````""8!``L````K)@$`#P``
M`#<F`0`R````1R8!`"4```!Z)@$`,````*`F`0`Q````T28!`"T````#)P$`
M#@```#$G`0`)````0"<!``L```!*)P$`!0```%8G`0`.````7"<!`!,```!K
M)P$`$@```'\G`0`'````DB<!`!8```":)P$`$0```+$G`0`4````PR<!`!,`
M``#8)P$`!P```.PG`0`4````]"<!`!@````)*`$`!P```"(H`0`%````*B@!
M``P````P*`$`#````#TH`0`2````2B@!``0```!=*`$`!P```&(H`0`*````
M:B@!``L```!U*`$`#````($H`0`.````CB@!``X```"=*`$`!0```*PH`0`$
M````LB@!``L```"W*`$`#````,,H`0`-````T"@!``P```#>*`$`"0```.LH
M`0`%````]2@!``4```#[*`$`+@````$I`0`F````,"D!`",```!7*0$``P``
M`'LI`0`2````?RD!``8```"2*0$`'@```)DI`0`8````N"D!`"4```#1*0$`
M#0```/<I`0`)````!2H!`!\````/*@$``P```"\J`0`8````,RH!``<```!,
M*@$`"@```%0J`0`"````7RH!``P```!B*@$`%0```&\J`0`+````A2H!`!D`
M``"1*@$`(````*LJ`0`2````S"H!``4```#?*@$`"@```.4J`0`5````\"H!
M`!(````&*P$`#````!DK`0`$````)BL!``D````K*P$`!P```#4K`0`,````
M/2L!``T```!**P$`4@```%@K`0`7````JRL!`"0```##*P$`$@```.@K`0`'
M````^RL!``8````#+`$`#P````HL`0`3````&BP!`!X````N+`$`(````$TL
M`0`&````;BP!``X```!U+`$`!````(0L`0`,````B2P!``T```"6+`$`#@``
M`*0L`0`5````LRP!`!(```#)+`$`#P```-PL`0`4````["P!``H````!+0$`
M&P````PM`0`0````*"T!``L````Y+0$`%````$4M`0!I````6BT!`!H```#$
M+0$`%P```-\M`0`G````]RT!`!H````?+@$`%P```#HN`0`;````4BX!`!D`
M``!N+@$`'P```(@N`0`3````J"X!`!,```"\+@$`"````-`N`0`&````V2X!
M``<```#@+@$`"````.@N`0`)````\2X!`!4```#[+@$`#0```!$O`0`C````
M'R\!``T```!#+P$`$P```%$O`0`(````92\!``,```!N+P$`1@```'(O`0`_
M````N2\!`#<```#Y+P$`5P```#$P`0`>````B3`!``4```"H,`$`'P```*XP
M`0`O````SC`!``H```#^,`$`"`````DQ`0`-````$C$!`"T````@,0$`!```
M`$XQ`0`2````4S$!`!,```!F,0$`3P```'HQ`0`E````RC$!`!P```#P,0$`
M"P````TR`0`?````&3(!`!T````Y,@$`)0```%<R`0`@````?3(!`"0```">
M,@$`(````,,R`0`+````Y#(!``<```#P,@$`#0```/@R`0`,````!C,!`!<`
M```3,P$`!@```"LS`0`Y````,C,!``P```!L,P$`!P```'DS`0`)````@3,!
M`!,```"+,P$`1P```)\S`0`)````YS,!``0```#Q,P$`$````/8S`0`(````
M!S0!``@````0-`$`!````!DT`0`+````'C0!``P````J-`$`$@```#<T`0`1
M````2C0!``P```!<-`$`&@```&DT`0`/````A#0!``<```"4-`$`#0```)PT
M`0`4````JC0!``X```"_-`$`#````,XT`0`;````VS0!`"P```#W-`$`$P``
M`"0U`0`<````.#4!`"@```!5-0$`!@```'XU`0`'````A34!`!,```"--0$`
M!0```*$U`0`$````IS4!``X```"L-0$`%P```+LU`0`*````TS4!``P```#>
M-0$`"0```.LU`0`&````]34!``D```#\-0$`"`````8V`0`)````#S8!``H`
M```9-@$`$0```"0V`0`&````-C8!`",````]-@$`#@```&$V`0`.````<#8!
M``T```!_-@$`"P```(TV`0`=````F38!``L```"W-@$``@```,,V`0`<````
MQC8!`!T```#C-@$`!P````$W`0`(````"3<!``8````2-P$`9````!DW`0`)
M````?C<!``<```"(-P$`)@```)`W`0`X````MS<!`!H```#P-P$`*@````LX
M`0`[````-C@!`"@```!R.`$`-````)LX`0`9````T#@!`!4```#J.`$`!0``
M```Y`0`'````!CD!``@````..0$`!P```!<Y`0`%````'SD!``<````E.0$`
M#@```"TY`0`)````/#D!``8```!&.0$`"````$TY`0`+````5CD!``<```!B
M.0$`"````&HY`0`'````<SD!`!8```![.0$`"0```)(Y`0`&````G#D!``L`
M``"C.0$`$````*\Y`0`&````P#D!`!P```#'.0$`%````.0Y`0`'````^3D!
M`!$````!.@$`"````!,Z`0`.````'#H!``@````K.@$`!0```#0Z`0`0````
M.CH!``D```!+.@$`$````%4Z`0`&````9CH!`!D```!M.@$`"@```(<Z`0`<
M````DCH!``<```"O.@$`!0```+<Z`0`0````O3H!`!0```#..@$`"P```.,Z
M`0`-````[SH!`"@```#].@$`&````"8[`0`7````/SL!``0```!7.P$`"0``
M`%P[`0`*````9CL!``<```!Q.P$``@```'D[`0`.````?#L!``@```"+.P$`
M(P```)0[`0`?````N#L!`#@```#8.P$`)@```!$\`0`Q````.#P!`"<```!J
M/`$`,@```)(\`0`R````Q3P!`&0```#X/`$`%````%T]`0!5````<CT!`#@`
M``#(/0$`2@````$^`0!;````3#X!`"@```"H/@$`$0```-$^`0`X````XSX!
M`"@````</P$`+````$4_`0`F````<C\!`!L```"9/P$`/@```+4_`0"I`0``
M]#\!`",```">00$`%P```,)!`0!(````VD$!`(4````C0@$`,````*E"`0`E
M````VD(!`$$`````0P$`6P```$)#`0!)````GD,!`#$```#H0P$`'0```!I$
M`0`8````.$0!`"L```!11`$`(0```'U$`0`?````GT0!`"L```"_1`$`)@``
M`.M$`0`G````$D4!`#H````Z10$`'0```'5%`0`1````DT4!`#,```"E10$`
M)0```-E%`0`G````_T4!`"`````G1@$`'P```$A&`0`P````:$8!`&D```"9
M1@$`,0````-'`0!!````-4<!`#,```!W1P$`)0```*M'`0`]````T4<!`&4`
M```/2`$`30```'5(`0`I````PT@!`"L```#M2`$`+P```!E)`0`N````24D!
M`#````!X20$`5````*E)`0!:````_DD!`$@```!92@$`2@```*)*`0`R````
M[4H!`"\````@2P$`+````%!+`0`M````?4L!`'$```"K2P$`9@```!U,`0!O
M````A$P!`+,```#T3`$`%P```*A-`0`E````P$T!`#(```#F30$`*0```!E.
M`0`^````0TX!`"(```""3@$`4@```*5.`0`E````^$X!``L````>3P$`L0``
M`"I/`0!%````W$\!`"$````B4`$`,````$10`0`E````=5`!`!P```";4`$`
M,0```+A0`0`'````ZE`!``<```#R4`$`!````/I0`0`-````_U`!``L````-
M40$`#@```!E1`0`+````*%$!``4````T40$`$````#I1`0`"````2U$!`%D`
M``!.40$``P```*A1`0`%````K%$!`!(```"R40$`!````,51`0`'````RE$!
M``@```#240$`!0```-M1`0`#````X5$!`!````#E40$`#````/91`0`3````
M`U(!``T````74@$``@```"52`0`'````*%(!``8````P4@$`%````#=2`0`,
M````3%(!`!@```!94@$`!@```')2`0`2````>5(!``P```",4@$``P```)E2
M`0`J````G5(!``0```#(4@$`!@```,U2`0`'````U%(!`!\```#<4@$`-0``
M`/Q2`0`N````,E,!`"\```!A4P$`%P```)%3`0`B````J5,!`"4```#,4P$`
M(````/)3`0`;````$U0!`!@````O5`$`)````$A4`0`?````;50!`!H```"-
M5`$`(0```*A4`0`@````RE0!`!H```#K5`$`,@````95`0`:````.54!`"\`
M``!450$`*P```(15`0`?````L%4!`",```#050$`'P```/15`0`:````%%8!
M`"$````O5@$`)0```%%6`0`F````=U8!`"4```">5@$`)````,16`0`8````
MZ58!`!T````"5P$`)````"!7`0`8````15<!`"(```!>5P$`+````(%7`0`O
M````KE<!`!4```#>5P$`)0```/17`0`\````&E@!`!\```!76`$`(P```'=8
M`0`?````FU@!`"````"[6`$`&@```-Q8`0`8````]U@!`"8````060$`'@``
M`#=9`0`I````5ED!`!X```"`60$`,0```)]9`0`)````T5D!``P```#;60$`
M%P```.A9`0`O`````%H!`"0````P6@$`!P```%5:`0`/````75H!`!0```!M
M6@$`#@```():`0`-````D5H!`"0```"?6@$`!0```,1:`0`'````REH!`"(`
M``#26@$`)0```/5:`0`:````&UL!`!T````V6P$`&@```%1;`0`'````;UL!
M`,<```!W6P$`"P```#]<`0`5````2UP!``8```!A7`$`"0```&A<`0`+````
M<EP!``T```!^7`$`%P```(Q<`0`&````I%P!`#,```"K7`$`$P```-]<`0`3
M````\UP!``<````'70$`#P````]=`0`'````'UT!`#(````G70$`!````%I=
M`0`A````7UT!`!,```"!70$`#````)5=`0`1````HET!`#(```"T70$`%@``
M`.==`0`(````_ET!`!T````'7@$`"0```"5>`0`*````+UX!`!0````Z7@$`
M"@```$]>`0`=````6EX!``@```!X7@$`#0```(%>`0`Z````CUX!`!\```#*
M7@$`"````.I>`0`:````\UX!`"<````.7P$`!@```#9?`0`5````/5\!``<`
M``!37P$`"````%M?`0`)````9%\!`#\```!N7P$`!P```*Y?`0`/````ME\!
M``X```#&7P$`$````-5?`0`)````YE\!``D```#P7P$`"````/I?`0`3````
M`V`!``<````78`$`&0```!]@`0`*````.6`!`!<```!$8`$`%````%Q@`0`*
M````<6`!``P```!\8`$`%P```(E@`0`$````H6`!`"H```"F8`$`#````-%@
M`0`1````WF`!``<```#P8`$``@```/A@`0`0````^V`!`!@````,80$`"P``
M`"5A`0`#````,6$!``@````U80$`!@```#YA`0`'````16$!``T```!-80$`
M"P```%MA`0`4````9V$!`!4```!\80$`#@```))A`0`5````H6$!`"\```"W
M80$`(````.=A`0`<````"&(!`!4````E8@$`#````#MB`0`Q````2&(!``D`
M``!Z8@$`#@```(1B`0`[````DV(!`!4```#/8@$`!0```.5B`0`2````ZV(!
M`#\```#^8@$`$@```#YC`0`*````46,!``8```!<8P$`!````&-C`0`$````
M:&,!``H```!M8P$`$P```'AC`0`%````C&,!``8```"28P$`!@```)EC`0`(
M````H&,!``0```"I8P$`#````*YC`0`*````NV,!`#D```#&8P$`+@````!D
M`0`I````+V0!``H```!99`$`!0```&1D`0`,````:F0!``P```!W9`$`#0``
M`(1D`0`8````DF0!`!D```"K9`$`'P```,5D`0`=````Y60!`!$````#90$`
M`@```!5E`0`$````&&4!``H````=90$`!@```"AE`0`%````+V4!``,````U
M90$`#````#EE`0!%````1F4!`#(```",90$`,0```+]E`0`S````\64!`!H`
M```E9@$`-````$!F`0`H````=68!`%,```">9@$`&0```/)F`0`?````#&<!
M`'(````L9P$`(````)]G`0`U````P&<!`"$```#V9P$`10```!AH`0`P````
M7F@!`"@```"/:`$`*0```+AH`0`F````XF@!`&`````):0$`)0```&II`0`H
M````D&D!`"@```"Y:0$`(@```.)I`0`K````!6H!`#`````Q:@$`$@```&)J
M`0`3````=6H!`!````"):@$`>0```)IJ`0`)````%&L!`*$````>:P$`<P``
M`,!K`0!\````-&P!`"L```"Q;`$`5````-UL`0`7````,FT!`"<```!*;0$`
M%@```')M`0`/````B6T!`!<```"9;0$`'P```+%M`0!`````T6T!`!\````2
M;@$`'````#)N`0!1````3VX!`!H```"A;@$`%````+QN`0`*````T6X!``4`
M``#<;@$`!@```.)N`0`(````Z6X!``4```#R;@$`$@```/AN`0`,````"V\!
M`!`````8;P$`$P```"EO`0`=````/6\!``\```!;;P$`&P```&MO`0`D````
MAV\!``\```"L;P$`"@```+QO`0`$````QV\!``D```#,;P$`"P```-9O`0`:
M````XF\!`"(```#];P$`"````"!P`0`'````*7`!``4````Q<`$`%````#=P
M`0`I````3'`!``<```!V<`$`"````'YP`0`/````AW`!`!@```"7<`$`%```
M`+!P`0`(````Q7`!``P```#.<`$`#P```-MP`0`'````ZW`!``8```#S<`$`
M%````/IP`0`&````#W$!``D````6<0$`"@```"!Q`0`&````*W$!``P````R
M<0$`$0```#]Q`0`#````47$!``@```!5<0$`!````%YQ`0`9````8W$!`!$`
M``!]<0$`"@```(]Q`0`8````FG$!`!,```"S<0$`'````,=Q`0`1````Y'$!
M`!H```#V<0$`!````!%R`0`/````%G(!``<````F<@$`!0```"YR`0`$````
M-'(!`!D````Y<@$`!P```%-R`0`"````6W(!``(```!><@$`$0```&%R`0`)
M````<W(!``@```!]<@$`!@```(9R`0`2````C7(!`!<```"@<@$`!@```+AR
M`0`A````OW(!``4```#A<@$`)P```.=R`0`"````#W,!``0````2<P$`#P``
M`!=S`0`3````)W,!``<````[<P$``@```$-S`0`'````1G,!`!$```!.<P$`
M!@```&!S`0`A````9W,!`!@```")<P$`!@```*)S`0`3````J7,!`!````"]
M<P$`'@```,YS`0`2````[7,!``(`````=`$`!@````-T`0`,````"G0!``D`
M```7=`$`$0```"%T`0`B````,W0!``<```!6=`$`!P```%YT`0`+````9G0!
M``4```!R=`$``@```'AT`0`+````>W0!`*0!``"'=`$`$````"QV`0`5````
M/78!``T```!3=@$`!P```&%V`0`)````:78!``@```!S=@$``@```'QV`0`#
M````?W8!``,```"#=@$`&````(=V`0`>````H'8!`"\```"_=@$`*P```.]V
M`0`I````&W<!`"T```!%=P$`&0```'-W`0`J````C7<!``H```"X=P$`'@``
M`,-W`0`2````XG<!``H```#U=P$`%P````!X`0`%````&'@!`"@````>>`$`
M$@```$=X`0`.````6G@!`!,```!I>`$`#0```'UX`0`*````BW@!`)(```"6
M>`$`$````"EY`0`*````.GD!`!(```!%>0$`#0```%AY`0`;````9GD!``P`
M``"">0$`#P```(]Y`0`6````GWD!``8```"V>0$`F0```+UY`0`(````5WH!
M``T```!@>@$`&````&YZ`0`/````AWH!`!````"7>@$`$````*AZ`0`(````
MN7H!`!````#">@$`/````--Z`0`5````$'L!`$,````F>P$`20```&I[`0!5
M````M'L!`$T````*?`$`<@```%A\`0!J````RWP!`$8````V?0$`$````'U]
M`0`6````CGT!``X```"E?0$`$````+1]`0`2````Q7T!``4```#8?0$`!@``
M`-Y]`0`1````Y7T!``@```#W?0$`"0````!^`0`)````"GX!`"4````4?@$`
M(P```#I^`0`0````7GX!``X```!O?@$`$0```'Y^`0`&````D'X!`",```"7
M?@$`#0```+M^`0`M````R7X!``D```#W?@$`&P````%_`0`A````'7\!``X`
M```_?P$`%````$Y_`0`8````8W\!`"4```!\?P$`*@```*)_`0`:````S7\!
M`!````#H?P$`%P```/E_`0`-````$8`!`#4````?@`$`(P```%6``0`F````
M>8`!`!$```"@@`$`6````+*``0`V````"X$!`"4```!"@0$`&````&B!`0`(
M````@8$!`!4```"*@0$`-P```*"!`0`-````V($!``@```#F@0$`"P```.^!
M`0`'````^X$!``<````#@@$`!P````N"`0`'````$X(!``P````;@@$`!0``
M`"B"`0`;````+H(!``P```!*@@$`$````%>"`0`2````:((!`!(```![@@$`
M"@```(Z"`0`<````F8(!`"\```"V@@$`"0```.:"`0`6````\((!`!8````'
M@P$`&````!Z#`0`>````-X,!`!0```!6@P$`$@```&N#`0`/````?H,!`"$`
M``".@P$`'0```+"#`0`'````SH,!``8```#6@P$`"````-V#`0`-````YH,!
M``@```#T@P$`"@```/V#`0`)````"(0!`!(````2A`$`&0```"6$`0`)````
M/X0!`!,```!)A`$`&````%V$`0`/````=H0!`"H```"&A`$`!P```+&$`0`2
M````N80!``4```#,A`$`%@```-*$`0`2````Z80!``\```#\A`$`+0````R%
M`0!"````.H4!`#H```!]A0$`"0```+B%`0`'````PH4!`!,```#*A0$`!```
M`-Z%`0`%````XX4!``T```#IA0$`"@```/>%`0`7`````H8!`$,````:A@$`
M%0```%Z&`0`D````=(8!`"L```"9A@$`*@```,6&`0`P````\(8!``D````A
MAP$`!@```"N'`0`)````,H<!``<````\AP$`.P```$2'`0`]````@(<!`#H`
M``"^AP$`7P```/F'`0`Y````68@!`#D```"3B`$`10```,V(`0!%````$XD!
M`#D```!9B0$`4@```).)`0`J````YHD!`"P````1B@$`20```#Z*`0`Y````
MB(H!`#\```#"B@$`)0````*+`0`5````*(L!`!D````^BP$`+````%B+`0`F
M````A8L!`"8```"LBP$`/````-.+`0`3````$(P!``H````DC`$`$0```"^,
M`0`%````08P!``P```!'C`$`&0```%2,`0`;````;HP!``<```"*C`$`!P``
M`)*,`0`5````FHP!``H```"PC`$`"````+N,`0`T````Q(P!`!````#YC`$`
M`P````J-`0`*````#HT!``H````9C0$`!P```"2-`0`&````+(T!``4````S
MC0$`"````#F-`0`%````0HT!`!X```!(C0$`"P```&>-`0`+````<XT!`!(`
M``!_C0$`.@```)*-`0`8````S8T!`#(```#FC0$`%@```!F.`0`-````,(X!
M``4````^C@$`!P```$2.`0`'````3(X!``D```!4C@$`!0```%Z.`0`1````
M9(X!``8```!VC@$`%````'V.`0`%````DHX!``@```"8C@$`!@```*&.`0`+
M````J(X!``8```"TC@$`(@```+N.`0`&````WHX!``@```#EC@$`%````.Z.
M`0`,`````X\!``<````0CP$``P```!B/`0`#````'(\!`!H````@CP$`&@``
M`#N/`0`M````5H\!``8```"$CP$`!0```(N/`0`(````D8\!``@```":CP$`
M6@```*./`0`A````_H\!`#P````@D`$`+````%V0`0`A````BI`!``8```"L
MD`$`"````+.0`0`>````O)`!`"8```#;D`$`,0````*1`0`V````-)$!`"@`
M``!KD0$`+P```)21`0!M````Q)$!`#H````RD@$`"@```&V2`0`&````>)(!
M``D```!_D@$`$````(F2`0`2````FI(!``P```"MD@$``@```+J2`0`0````
MO9(!`!8```#.D@$`$0```.62`0`6````]Y(!`!8````.DP$`$````"63`0`5
M````-I,!``8```!,DP$`&P```%.3`0`;````;Y,!`!<```"+DP$`&P```*.3
M`0`8````OY,!``8```#8DP$`!P```-^3`0`0````YY,!`%P```#XDP$`$@``
M`%64`0!@````:)0!``0```#)E`$`$@```,Z4`0`%````X90!``4```#GE`$`
M'````.V4`0`9````"I4!`!0````DE0$`$0```#F5`0`2````2Y4!`!H```!>
ME0$`.@```'F5`0`/````M)4!`"\```#$E0$`!@```/25`0`4````^Y4!``\`
M```0E@$`$P```""6`0`/````-)8!`!@```!$E@$`$@```%V6`0`5````<)8!
M`!,```"&E@$`#0```)J6`0`&````J)8!`!(```"OE@$`!P```,*6`0`.````
MRI8!`!8```#9E@$`#P```/"6`0`(`````)<!``,````)EP$`$`````V7`0`.
M````'I<!``4````MEP$`$P```#.7`0`*````1Y<!``<```!2EP$`$````%J7
M`0`(````:Y<!``0```!TEP$`!P```'F7`0`'````@9<!``P```")EP$`"```
M`):7`0`)````GY<!`!H```"IEP$`/@```,27`0`F`````Y@!``T````JF`$`
M$````#B8`0`%````29@!`!\```!/F`$`$0```&^8`0`2````@9@!`!````"4
MF`$`,@```*68`0!"````V)@!`"$````;F0$`"````#V9`0!'````1ID!``8`
M``".F0$`*````)69`0`0````OID!``D```#/F0$`"@```-F9`0`&````Y)D!
M``8```#KF0$`"0```/*9`0`2````_)D!``P````/F@$`#@```!R:`0`+````
M*YH!``H````WF@$`#P```$*:`0`L````4IH!`"<```!_F@$`-````*>:`0`O
M````W)H!`"8````,FP$`*P```#.;`0`F````7YL!`"4```"&FP$`/0```*R;
M`0`R````ZIL!`"D````=G`$`+P```$><`0`F````=YP!`#0```">G`$`1@``
M`-.<`0!!````&IT!`#T```!<G0$`/0```)J=`0!'````V)T!`"P````@G@$`
M*````$V>`0!&````=IX!`"H```"]G@$`&@```.B>`0`U`````Y\!`"@````Y
MGP$`+````&*?`0`8````CY\!`,D```"HGP$`'````'*@`0`R````CZ`!`#(`
M``#"H`$`-````/6@`0`Q````*J$!`"D```!<H0$`*@```(:A`0`J````L:$!
M`#(```#<H0$`-0````^B`0!)````1:(!`#L```"/H@$`J0```,NB`0`L````
M=:,!`"4```"BHP$`*````,BC`0`V````\:,!`#(````HI`$`60```%ND`0!.
M````M:0!``T````$I0$`!````!*E`0`&````%Z4!``4````>I0$`#0```"2E
M`0`.````,J4!`!````!!I0$`$````%*E`0`5````8Z4!`!L```!YI0$`!P``
M`)6E`0`$````G:4!``X```"BI0$`#@```+&E`0`*````P*4!``T```#+I0$`
M$P```-FE`0`+````[:4!`!````#YI0$`#`````JF`0`V````%Z8!``8```!.
MI@$`#@```%6F`0`&````9*8!`!$```!KI@$`%P```'VF`0`;````E:8!`!``
M``"QI@$``@```,*F`0`,````Q:8!`$H```#2I@$`"P```!VG`0`5````*:<!
M`!H````_IP$`!````%JG`0`3````7Z<!``\```!SIP$``P```(.G`0`/````
MAZ<!`!````"7IP$`"````*BG`0`0````L:<!`!````#"IP$`!@```-.G`0`*
M````VJ<!`!$```#EIP$`#````/>G`0`*````!*@!``<````/J`$`"@```!>H
M`0`.````(J@!`!`````QJ`$`#0```$*H`0`+````4*@!`!$```!<J`$`&@``
M`&ZH`0`.````B:@!``X```"8J`$`(P```*>H`0`>````RZ@!`!P```#JJ`$`
M/`````>I`0`-````1*D!`!X```!2J0$`%@```'&I`0`5````B*D!``@```">
MJ0$`-````*>I`0`B````W*D!`#````#_J0$`-@```#"J`0`1````9ZH!``\`
M``!YJ@$`"0```(FJ`0`3````DZH!``D```"GJ@$`-0```+&J`0`W````YZH!
M``\````?JP$`$````"^K`0`E````0*L!`!(```!FJP$`(````'FK`0`@````
MFJL!``D```"[JP$`#0```,6K`0`*````TZL!`!L```#>JP$`$@```/JK`0`9
M````#:P!`#T````GK`$`%0```&6L`0`.````>ZP!`!D```"*K`$`!P```*2L
M`0!$````K*P!``L```#QK`$`)@```/VL`0`*````)*T!`$@````OK0$`#@``
M`'BM`0`*````AZT!``\```"2K0$`"@```**M`0`@````K:T!``H```#.K0$`
M%````-FM`0`?````[JT!``8````.K@$`"0```!6N`0`P````'ZX!`!````!0
MK@$`!@```&&N`0`'````:*X!`%0```!PK@$``P```,6N`0`'````R:X!``8`
M``#1K@$`"0```-BN`0`,````XJX!``P```#OK@$`$````/RN`0`1````#:\!
M`!D````?KP$`$0```#FO`0`9````2Z\!`!D```!EKP$`"````'^O`0`%````
MB*\!``L```".KP$`"P```)JO`0`"````IJ\!``8```"IKP$`$@```+"O`0`G
M````PZ\!`!@```#KKP$`&0````2P`0`)````'K`!`!,````HL`$`%````#RP
M`0`<````4;`!``P```!NL`$`1@```'NP`0`O````PK`!``H```#RL`$`#```
M`/VP`0`+````"K$!``\````6L0$`B@```":Q`0`<````L;$!`!@```#.L0$`
M!P```.>Q`0`0````[[$!``@`````L@$`!`````FR`0`7````#K(!`"L````F
ML@$`*````%*R`0`:````>[(!`"4```"6L@$`&@```+RR`0`=````U[(!`!$`
M``#UL@$`$P````>S`0`'````&[,!``<````CLP$`!@```"NS`0`&````,K,!
M``\````YLP$`#@```$FS`0`0````6+,!``X```!ILP$`#````'BS`0`.````
MA;,!``L```"4LP$`$P```*"S`0`(````M+,!`!$```"]LP$`!@```,^S`0`(
M````UK,!`!8```#?LP$`#````/:S`0`>`````[0!`#4````BM`$`$0```%BT
M`0`(````:K0!`!4```!SM`$`)0```(FT`0`;````K[0!`",```#+M`$`(@``
M`.^T`0`8````$K4!`!H````KM0$`)0```$:U`0`9````;+4!`!(```"&M0$`
M!0```)FU`0`9````G[4!``L```"YM0$`"P```,6U`0`#````T;4!``4```#5
MM0$`"0```-NU`0`0````Y;4!`!(```#VM0$`$0````FV`0`*````&[8!``\`
M```FM@$`#@```#:V`0`,````1;8!``0```!2M@$`!P```%>V`0`@````7[8!
M`"$```"`M@$`%P```**V`0`/````NK8!`!(```#*M@$`$````-VV`0`B````
M[K8!`!<````1MP$`'P```"FW`0`C````2;<!`!````!MMP$`#P```'ZW`0`0
M````CK<!`!P```"?MP$`$0```+RW`0!"````SK<!`#$````1N`$`00```$.X
M`0!>````A;@!`$L```#DN`$`.@```#"Y`0!)````:[D!`!8```"UN0$`!P``
M`,RY`0`)````U+D!``\```#>N0$`#P```.ZY`0`)````_KD!``4````(N@$`
M"@````ZZ`0`%````&;H!`!,````?N@$`#````#.Z`0`&````0+H!`"<```!'
MN@$`*0```&^Z`0`.````F;H!`(,```"HN@$`$0```"R[`0`+````/KL!``4`
M``!*NP$`#0```%"[`0`&````7KL!``@```!ENP$`!@```&Z[`0`*````=;L!
M`#L```"`NP$`$0```+R[`0`8````SKL!``,```#GNP$`!P```.N[`0`&````
M\[L!`!0```#ZNP$`#P````^\`0`2````'[P!`!P````RO`$``@```$^\`0`%
M````4KP!``,```!8O`$`$@```%R\`0`)````;[P!``T```!YO`$`!0```(>\
M`0`@````C;P!``@```"NO`$`!@```+>\`0`:````OKP!``T```#9O`$`!P``
M`.>\`0`(````[[P!``0```#XO`$`"0```/V\`0`-````![T!``X````5O0$`
M`@```"2]`0`&````)[T!``P````NO0$`$P```#N]`0`0````3[T!``D```!@
MO0$`$````&J]`0`&````>[T!`!(```""O0$`"@```)6]`0`'````H+T!`!<`
M``"HO0$`*0```,"]`0!*````ZKT!`"<````UO@$`*0```%V^`0`&````A[X!
M``D```".O@$`!````)B^`0`)````G;X!``@```"GO@$`%P```+"^`0`0````
MR+X!``4```#9O@$`#````-^^`0`&````[+X!``0```#SO@$`00```/B^`0!"
M````.K\!`$$```!]OP$`(0```+^_`0`%````X;\!``X```#GOP$`!P```/:_
M`0`)````_K\!``D````(P`$`&P```!+``0`0````+L`!`!4````_P`$`!@``
M`%7``0`%````7,`!``\```!BP`$`"@```'+``0`*````?<`!`!X```"(P`$`
M!````*?``0`'````K,`!`"0```"TP`$`!@```-G``0`4````X,`!`!$```#U
MP`$`$`````?!`0`(````&,$!``D````AP0$`!0```"O!`0`[````,<$!`#8`
M``!MP0$`0P```*3!`0`I````Z,$!`$(````2P@$`0@```%7"`0`K````F,(!
M`$H```#$P@$`+P````_#`0`Y````/\,!`"\```!YPP$`$````*G#`0`1````
MNL,!``L```#,PP$`+0```-C#`0`I````!L0!`"$````PQ`$`*````%+$`0`'
M````>\0!``D```"#Q`$`"@```(W$`0`'````F,0!`"0```"@Q`$`)@```,7$
M`0`M````[,0!``L````:Q0$`&P```";%`0`M````0L4!`!@```!PQ0$`$P``
M`(G%`0`(````G<4!``X```"FQ0$`#@```+7%`0`.````Q,4!`!,```#3Q0$`
M1````.?%`0!^````+,8!`'$```"KQ@$`&P```!W'`0`-````.<<!``X```!'
MQP$`$0```%;'`0`2````:,<!``\```![QP$`!P```(O'`0`2````D\<!``H`
M``"FQP$`$P```+''`0`2````Q<<!`!,```#8QP$`*````.S'`0`>````%<@!
M`(0````TR`$`$@```+G(`0`%````S,@!`!0```#2R`$`0@```.?(`0`)````
M*LD!`"L````TR0$`"@```&#)`0`*````:\D!`!\```!VR0$`%````);)`0`.
M````J\D!``X```"ZR0$`$P```,G)`0`5````W<D!`"0```#SR0$`)@```!C*
M`0`C````/\H!`"4```!CR@$`(0```(G*`0`C````J\H!`!T```#/R@$`10``
M`.W*`0`3````,\L!`!0```!'RP$`$P```%S+`0`4````<,L!`!$```"%RP$`
M%@```)?+`0`7````KLL!`!(```#&RP$`$P```-G+`0`\````[<L!`!8````J
MS`$`%````$',`0`^````5LP!`!4```"5S`$`#@```*O,`0`1````NLP!`"T`
M``#,S`$`$P```/K,`0`3````#LT!`"`````BS0$`'0```$/-`0`?````8<T!
M`!T```"!S0$`&P```)_-`0`A````N\T!`!P```#=S0$`(P```/K-`0`A````
M'LX!`"````!`S@$`(````&'.`0`=````@LX!`!,```"@S@$`&P```+3.`0`=
M````T,X!`!L```#NS@$`&`````K/`0`*````(\\!`!`````NSP$`&@```#_/
M`0`&````6L\!``<```!ASP$``0```&G/`0`-````:\\!``4```!YSP$`%```
M`'_/`0`&````E,\!``<```";SP$`!P```*//`0`&````J\\!``<```"RSP$`
M!P```+K/`0`%````PL\!`!4```#(SP$`!@```-[/`0`(````Y<\!``4```#N
MSP$`!0```/3/`0`*````^L\!`!$````%T`$`"@```!?0`0`2````(M`!`!$`
M```UT`$`"P```$?0`0`2````4]`!``8```!FT`$`*@```&W0`0`1````F-`!
M`!````"JT`$`&@```+O0`0`0````UM`!``T```#GT`$`#````/70`0`O````
M`M$!``@````RT0$`"````#O1`0`H````1-$!`!0```!MT0$`$````(+1`0`&
M````D]$!``L```":T0$`5P```*;1`0`'````_M$!``8````&T@$`(0````W2
M`0`-````+](!`!`````]T@$`#0```$[2`0`3````7-(!`!````!PT@$`'P``
M`('2`0`3````H=(!``<```"UT@$``P```+W2`0`&````P=(!`!\```#(T@$`
M!@```.C2`0`(````[](!`!(```#XT@$`$P````O3`0`&````'],!``D````F
MTP$`$````##3`0`$````0=,!``<```!&TP$`%@```$[3`0`-````9=,!``T`
M``!STP$`"P```('3`0`4````C=,!`!8```"BTP$`%P```+G3`0`9````T=,!
M``H```#KTP$`#0```/;3`0`&````!-0!``0````+U`$`$0```!#4`0`[````
M(M0!``4```!>U`$`#P```&34`0`A````=-0!`!8```"6U`$`%P```*W4`0`.
M````Q=0!``P```#4U`$`"0```.'4`0`'````Z]0!``<```#SU`$`"@```/O4
M`0`)````!M4!``X````0U0$`$````!_5`0`@````,-4!`"$```!1U0$`)P``
M`'/5`0`*````F]4!``@```"FU0$`#0```*_5`0`,````O=4!`!(```#*U0$`
M!@```-W5`0`(````Y-4!`"<```#MU0$`"P```!76`0`(````(=8!`!(````J
MU@$`/````#W6`0`/````>M8!``L```"*U@$`!````);6`0`%````F]8!`!L`
M``"AU@$`'````+W6`0`<````VM8!``H```#WU@$``@````+7`0`$````!=<!
M`"$````*UP$``P```"S7`0`%````,-<!`"D````VUP$`"@```&#7`0`&````
M:]<!``<```!RUP$`&````'K7`0`.````D]<!``8```"BUP$`!P```*G7`0`(
M````L=<!``0```"ZUP$`!0```+_7`0`\````Q=<!`!`````"V`$`$P```!/8
M`0`5````)]@!`!X````]V`$`!0```%S8`0`&````8M@!`!4```!IV`$`'@``
M`'_8`0`S````GM@!``X```#2V`$`"0```.'8`0`<````Z]@!`!8````(V0$`
M"@```!_9`0`(````*MD!`!D````SV0$`+````$W9`0`I````>MD!`"@```"D
MV0$`(0```,W9`0`7````[]D!``X````'V@$`G0```!;:`0"?````M-H!``0`
M``!4VP$`!P```%G;`0`(````8=L!``<```!JVP$`#0```'+;`0`/````@-L!
M``@```"0VP$`5P```)G;`0`2````\=L!`!`````$W`$`"P```!7<`0`;````
M(=P!`%`````]W`$`'0```([<`0`&````K-P!`!T```"SW`$`)P```-'<`0`'
M````^=P!``8````!W0$`(`````C=`0`$````*=T!``D````NW0$`*0```#C=
M`0`H````8MT!`"<```"+W0$`!P```+/=`0`(````N]T!`"(```#$W0$`)```
M`.?=`0`L````#-X!`%D````YW@$`&````)/>`0`A````K-X!`"P```#.W@$`
M)@```/O>`0`6````(M\!``,````YWP$`#0```#W?`0`'````2]\!``\```!3
MWP$`"P```&/?`0`&````;]\!`!4```!VWP$`!@```(S?`0`(````D]\!``D`
M``"<WP$`"P```*;?`0`*````LM\!``P```"]WP$`/0```,K?`0`(````".`!
M`!(````1X`$`%````"3@`0`7````.>`!``4```!1X`$`#````%?@`0`0````
M9.`!``\```!UX`$`$@```(7@`0`1````F.`!``L```"JX`$`!@```+;@`0`%
M````O>`!``H```##X`$`)0```,[@`0`7````].`!`!`````,X0$`"P```!WA
M`0`0````*>$!``H````ZX0$`%````$7A`0`(````6N$!`!0```!CX0$`+0``
M`'CA`0`$````IN$!``<```"KX0$`!0```+/A`0`%````N>$!``<```"_X0$`
M$P```,?A`0`4````V^$!`"(```#PX0$`(@```!/B`0`<````-N(!`!P```!3
MX@$`(````'#B`0`E````D>(!`!\```"WX@$`!````-?B`0`%````W.(!``X`
M``#BX@$`#@```/'B`0`5`````.,!``@````6XP$`"@```!_C`0`7````*N,!
M``T```!"XP$`"@```%#C`0`:````6^,!`!\```!VXP$`%````);C`0`(````
MJ^,!`!(```"TXP$`!P```,?C`0`0````S^,!``\```#@XP$`"````/#C`0`)
M````^>,!``4````#Y`$`!P````GD`0`%````$>0!``0````7Y`$``P```!SD
M`0`^````(.0!`$$```!?Y`$`-0```*'D`0`P````U^0!`"D````(Y0$`%P``
M`#+E`0`I````2N4!`#D```!TY0$`$@```*[E`0`X````P>4!`#@```#ZY0$`
M/0```#/F`0`]````<>8!`$(```"OY@$`&````/+F`0`9````"^<!`!8````E
MYP$`.````#SG`0`=````=><!`!@```"3YP$`(````*SG`0`@````S><!`!L`
M``#NYP$`&0````KH`0`;````).@!`!0```!`Z`$`,0```%7H`0`Q````A^@!
M`#4```"YZ`$`,@```._H`0`S````(ND!`#````!6Z0$`=P```(?I`0`9````
M_^D!`!8````9Z@$`"@```##J`0`6````.^H!`"(```!2Z@$`"0```'7J`0`I
M````?^H!`!,```"IZ@$`-````+WJ`0`E````\NH!`"`````8ZP$`"P```#GK
M`0!1````1>L!`$T```"7ZP$`!P```.7K`0`7````[>L!`!4````%[`$`#```
M`!OL`0`0````*.P!`!8````Y[`$`!P```%#L`0`(````6.P!``D```!A[`$`
M$@```&OL`0`,````?NP!`!$```"+[`$`#P```)WL`0`.````K>P!``D```"\
M[`$`&````,;L`0`C````W^P!``@````#[0$`!@````SM`0`4````$^T!`!$`
M```H[0$`$````#KM`0!"````2^T!``(```".[0$`!@```)'M`0`1````F.T!
M``4```"J[0$`!P```+#M`0`/````N.T!``H```#([0$`*@```-/M`0`,````
M_NT!`!X````+[@$``P```"KN`0`W````+NX!`!@```!F[@$`&````'_N`0`H
M````F.X!`(8```#![@$`&````$CO`0!!````8>\!`"$```"C[P$`$P```,7O
M`0`&````V>\!`",```#@[P$`#`````3P`0`.````$?`!``L````@\`$`%@``
M`"SP`0`+````0_`!`!P```!/\`$`%@```&SP`0`%````@_`!`!(```")\`$`
M#0```)SP`0`+````JO`!`!H```"V\`$`)0```-'P`0`3````]_`!`!8````+
M\0$`'````"+Q`0`1````/_$!`"8```!1\0$`"@```'CQ`0`4````@_$!`!8`
M``"8\0$`$````*_Q`0`2````P/$!``\```#3\0$`$@```./Q`0`/````]O$!
M`!4````&\@$`'@```!SR`0`5````._(!``8```!1\@$`"0```%CR`0`%````
M8O(!`!T```!H\@$`!@```(;R`0`0````C?(!``@```">\@$`%````*?R`0`%
M````O/(!`!L```#"\@$`#P```-[R`0`M````[O(!`!4````<\P$`!@```#+S
M`0`'````.?,!`!@```!!\P$`!0```%KS`0`>````8/,!``0```!_\P$`%```
M`(3S`0`'````F?,!``L```"A\P$`(````*WS`0`M````SO,!``D```#\\P$`
M'`````;T`0`0````(_0!``H````T]`$`&P```#_T`0`4````6_0!``0```!P
M]`$`%````'7T`0`)````BO0!``@```"4]`$`!0```)WT`0`(````H_0!``8`
M``"L]`$`!@```+/T`0`A````NO0!`#<```#<]`$`/P```!3U`0`B````5/4!
M`#````!W]0$`*````*CU`0!%````T?4!`"(````7]@$`*P```#KV`0`H````
M9O8!`"4```"/]@$`50```+7V`0`J````"_<!``<````V]P$`"````#[W`0`'
M````1_<!``@```!/]P$`%````%CW`0`4````;?<!`#````""]P$`+0```+/W
M`0`8````X?<!`#4```#Z]P$`/0```##X`0`'````;O@!`!D```!V^`$`"0``
M`)#X`0`0````FO@!`"(```"K^`$`$0```,[X`0`2````X/@!``T```#S^`$`
M"`````'Y`0`5````"OD!``@````@^0$`"P```"GY`0`-````-?D!`!H```!#
M^0$`#0```%[Y`0`\````;/D!``H```"I^0$`!0```+3Y`0`)````NOD!``4`
M``#$^0$`&@```,KY`0`&````Y?D!`!$```#L^0$`!0```/[Y`0`.````!/H!
M`!`````3^@$`$0```"3Z`0`,````-OH!``\```!#^@$`#P```%/Z`0`'````
M8_H!``,```!K^@$`#0```&_Z`0`Z````??H!`$X```"X^@$`"`````?[`0`1
M````$/L!`!4````B^P$`"0```#C[`0`F````0OL!`!T```!I^P$`!0```(?[
M`0`1````C?L!`!0```"?^P$`%0```+3[`0`#````ROL!``L```#.^P$`$@``
M`-K[`0`J````[?L!``<````8_`$`#0```"#\`0`.````+OP!`!(````]_`$`
M"P```%#\`0`[````7/P!``D```"8_`$`'````*+\`0`/````O_P!`!,```#/
M_`$`/P```./\`0`N````(_T!`#D```!2_0$`.@```(S]`0`V````Q_T!`!$`
M``#^_0$`"0```!#^`0`+````&OX!``8````F_@$`$````"W^`0`0````/OX!
M``T```!/_@$`"@```%W^`0`@````:/X!`!$```")_@$`'P```)O^`0`=````
MN_X!``<```#9_@$`%0```.'^`0`:````]_X!``@````2_P$`!P```!O_`0`1
M````(_\!`!(````U_P$`&0```$C_`0`&````8O\!``<```!I_P$`#P```''_
M`0`5````@?\!`!0```"7_P$`%0```*S_`0`5````PO\!``<```#8_P$`!0``
M`.#_`0`-````YO\!``X```#T_P$`$`````,``@`-````%``"``T````B``(`
M!@```#```@`&````-P`"`#$````^``(`)P```'```@`F````F``"``@```"_
M``(`#P```,@``@`&````V``"`!\```#?``(`(0```/\``@`F````(0$"``L`
M``!(`0(`%````%0!`@`F````:0$"``,```"0`0(`&@```)0!`@`'````KP$"
M`!4```"W`0(``P```,T!`@`,````T0$"`!$```#>`0(`"P```/`!`@`4````
M_`$"`!@````1`@(`%````"H"`@`%````/P("``H```!%`@(`$P```%`"`@`4
M````9`("``X```!Y`@(`!@```(@"`@`)````CP("``D```"9`@(`#0```*,"
M`@`4````L0("`%H```#&`@(`%@```"$#`@`U````.`,"`!0```!N`P(`!P``
M`(,#`@`&````BP,"`!(```"2`P(`%@```*4#`@`;````O`,"`!X```#8`P(`
M"0```/<#`@`4`````00"``0````6!`(`%0```!L$`@`2````,00"`!(```!$
M!`(`(0```%<$`@`8````>00"`!4```"2!`(`(P```*@$`@`0````S`0"`"<`
M``#=!`(`$P````4%`@`5````&04"`!D````O!0(`<````$D%`@`A````N@4"
M`!P```#<!0(`+0```/D%`@`A````)P8"`!P```!)!@(`)@```&8&`@`?````
MC08"`!\```"M!@(`%P```,T&`@`<````Y08"``H````"!P(`"0````T'`@`'
M````%P<"``@````?!P(`"````"@'`@`3````,0<"``\```!%!P(`+0```%4'
M`@`7````@P<"`!4```";!P(`!P```+$'`@`'````N0<"`$\```#!!P(`20``
M`!$(`@`^````6P@"`&8```":"`(`)@````$)`@`,````*`D"`#(````U"0(`
M,````&@)`@`)````F0D"``<```"C"0(`!@```*L)`@!`````L@D"``8```#S
M"0(`$P```/H)`@`3````#@H"`$`````B"@(`-````&,*`@`C````F`H"``X`
M``"\"@(`+0```,L*`@`<````^0H"`#,````6"P(`*````$H+`@`R````<PL"
M`"@```"F"P(`#0```,\+`@`&````W0L"``\```#D"P(`$@```/0+`@`5````
M!PP"``<````=#`(`0@```"4,`@`*````:`P"``D```!S#`(`"@```'T,`@`7
M````B`P"`$@```"@#`(`"0```.D,`@`'````\PP"`!(```#[#`(`"@````X-
M`@`)````&0T"``0````C#0(`!P```"@-`@`(````,`T"``\````Y#0(`%```
M`$D-`@`6````7@T"`!T```!U#0(`#0```),-`@`'````H0T"`!````"I#0(`
M#P```+H-`@`2````R@T"``T```#=#0(`&````.L-`@`H````!`X"``X````M
M#@(`'P```#P.`@`I````7`X"``D```"&#@(`"P```)`.`@`4````G`X"``<`
M``"Q#@(`!````+D.`@`.````O@X"`!\```#-#@(`#@```.T.`@`.````_`X"
M``T````+#P(`"````!D/`@`)````(@\"``8````L#P(`"0```#,/`@`+````
M/0\"`!,```!)#P(`"````%T/`@`L````9@\"`!@```"3#P(`"P```*P/`@`'
M````N`\"`!X```#`#P(`)@```-\/`@`,````!A`"``,````3$`(`(0```!<0
M`@`?````.1`"``<```!9$`(`"````&$0`@`&````:A`"`'0```!Q$`(`"@``
M`.80`@`'````\1`"`"<```#Y$`(`0````"$1`@`:````8A$"`"4```!]$0(`
M1````*,1`@`I````Z!$"`#T````2$@(`&P```%`2`@`6````;!("``4```"#
M$@(`!@```(D2`@`)````D!("``H```":$@(`"@```*42`@`)````L!("`!0`
M``"Z$@(`"P```,\2`@`*````VQ("``P```#F$@(`#````/,2`@`'`````!,"
M``@````($P(`"0```!$3`@`4````&Q,"``L````P$P(`!@```#P3`@`%````
M0Q,"``L```!)$P(`!@```%43`@`F````7!,"`!@```"#$P(`"@```)P3`@`6
M````IQ,"``L```"^$P(`%````,H3`@`+````WQ,"``8```#K$P(`%@```/(3
M`@`&````"10"`!8````0%`(`!@```"<4`@`:````+A0"``L```!)%`(`%@``
M`%44`@`%````;!0"``<```!R%`(`$@```'H4`@`@````C10"``L```"N%`(`
M#0```+H4`@`M````R!0"`!L```#V%`(`&````!(5`@`%````*Q4"``T````Q
M%0(`%````#\5`@`7````5!4"``,```!L%0(`$P```'`5`@`)````A!4"`",`
M``".%0(`*0```+(5`@`S````W!4"`"4````0%@(`-````#86`@`G````:Q8"
M`#$```"3%@(`,@```,46`@!I````^!8"`!<```!B%P(`9P```'H7`@!"````
MXA<"`%0````E&`(`;@```'H8`@`M````Z1@"`!(````7&0(`.P```"H9`@`S
M````9AD"`#@```":&0(`+@```-,9`@`;`````AH"`#0````>&@(`UP$``%,:
M`@`?````*QP"`!<```!+'`(`2@```&,<`@!W````KAP"`#,````F'0(`)0``
M`%H=`@!!````@!T"`%P```#"'0(`6@```!\>`@`J````>AX"`",```"E'@(`
M%@```,D>`@`H````X!X"`!T````)'P(`&@```"<?`@`M````0A\"`"4```!P
M'P(`)0```)8?`@`Z````O!\"`",```#W'P(`%@```!L@`@`X````,B`"`"4`
M``!K(`(`*@```)$@`@`M````O"`"`!\```#J(`(`.`````HA`@!M````0R$"
M`#$```"Q(0(`0@```.,A`@`N````)B("`"<```!5(@(`0````'TB`@!C````
MOB("`$@````B(P(`(0```&LC`@`D````C2,"`"X```"R(P(`+@```.$C`@`P
M````$"0"`%\```!!)`(`;P```*$D`@!8````$24"`%D```!J)0(`-0```,0E
M`@`J````^B4"`"H````E)@(`+P```%`F`@!K````@"8"`'$```#L)@(`<0``
M`%XG`@"Y````T"<"`!D```"**`(`+P```*0H`@`P````U"@"`"T````%*0(`
M4@```#,I`@`E````ABD"`%,```"L*0(`(@`````J`@`*````(RH"`-@````N
M*@(`6`````<K`@`C````8"L"`#@```"$*P(`*````+TK`@`>````YBL"`#D`
M```%+`(`!````#\L`@`(````1"P"``0```!-+`(`&0```%(L`@`/````;"P"
M``\```!\+`(`"P```(PL`@`&````F"P"``\```"?+`(`!````*\L`@!8````
MM"P"``4````-+0(`!````!,M`@`7````&"T"``0````P+0(`!P```#4M`@`&
M````/2T"``4```!$+0(`!````$HM`@`5````3RT"``D```!E+0(`$0```&\M
M`@`3````@2T"``,```"5+0(`!P```)DM`@`'````H2T"`!(```"I+0(`#0``
M`+PM`@`4````RBT"``8```#?+0(`&@```.8M`@`-`````2X"``,````/+@(`
M*P```!,N`@`$````/RX"``8```!$+@(`!P```$LN`@`A````4RX"`$````!U
M+@(`,0```+8N`@`R````Z"X"`!L````;+P(`,@```#<O`@`U````:B\"`"0`
M``"@+P(`(P```,4O`@`>````Z2\"`"0````(,`(`'P```"TP`@`=````33`"
M`"4```!K,`(`(P```)$P`@`>````M3`"`#0```#4,`(`'`````DQ`@`Q````
M)C$"`#(```!8,0(`(0```(LQ`@`E````K3$"`"0```#3,0(`'P```/@Q`@`D
M````&#("`"H````],@(`*````&@R`@`J````D3("`"8```"\,@(`'P```.,R
M`@`B`````S,"`"L````F,P(`'0```%(S`@`D````<#,"`"\```"5,P(`,@``
M`,4S`@`:````^#,"`"<````3-`(`/````#LT`@`D````>#0"`"8```"=-`(`
M)0```,0T`@`F````ZC0"`"`````1-0(`'@```#(U`@`G````434"`",```!Y
M-0(`+@```)TU`@`G````S#4"`"X```#T-0(`"@```",V`@`3````+C8"`!8`
M``!"-@(`,P```%DV`@`F````C38"``T```"T-@(`#P```,(V`@`6````TC8"
M``L```#I-@(`#@```/4V`@`L````!#<"``@````Q-P(`#````#HW`@`G````
M1S<"`"H```!O-P(`(````)HW`@`?````NS<"`!P```#;-P(`"````/@W`@#4
M`````3@"``T```#6.`(`%@```.0X`@`)````^S@"``T````%.0(`$0```!,Y
M`@`0````)3D"`!\````V.0(`!@```%8Y`@!+````73D"`!P```"I.0(`'```
M`,8Y`@`'````XSD"`!(```#K.0(`#````/XY`@`V````"SH"``@```!".@(`
M)P```$LZ`@`9````<SH"`!(```"-.@(`%````*`Z`@`R````M3H"`!\```#H
M.@(`!P````@[`@`7````$#L"``@````H.P(`"0```#$[`@`4````.SL"``L`
M``!0.P(`&P```%P[`@`&````>#L"`!<```!_.P(`/@```)<[`@`J````UCL"
M``@````!/`(`(P````H\`@`K````+CP"``<```!:/`(`%P```&(\`@`'````
M>CP"``@```""/`(`"0```(L\`@`^````E3P"``8```#4/`(`$@```-L\`@`4
M````[CP"``\````#/0(`"0```!,]`@`*````'3T"``8````H/0(`$P```"\]
M`@`&````0ST"`"$```!*/0(`$@```&P]`@`9````?ST"`!4```"9/0(`#```
M`*\]`@`.````O#T"`!H```#+/0(`!P```.8]`@`M````[CT"``P````</@(`
M#P```"D^`@`'````.3X"``,```!!/@(`$0```$4^`@`<````5SX"``L```!T
M/@(``P```(`^`@`(````A#X"``P```"-/@(`"0```)H^`@`/````I#X"``T`
M``"T/@(`%@```,(^`@`7````V3X"`!````#Q/@(`&P````(_`@`O````'C\"
M`!T```!./P(`'````&P_`@`:````B3\"``L```"D/P(`,````+`_`@`,````
MX3\"`!,```#N/P(`.0````)``@`9````/$`"``<```!60`(`%P```%Y``@!%
M````=D`"`!$```"\0`(`$@```,Y``@`(````X4`"``0```#J0`(`!0```.]`
M`@`1````]4`"`!H````'00(`!@```")!`@`'````*4$"``D````Q00(`$```
M`#M!`@`(````3$$"`!(```!500(`#@```&A!`@!%````=T$"`#8```"]00(`
M*0```/1!`@`*````'D("``4````I0@(`#````"]"`@`,````/$("``T```!)
M0@(`&0```%="`@`D````<4("`"(```"60@(`*````+E"`@`0````XD("``(`
M``#S0@(`!````/9"`@`+````^T("``H````'0P(`!0```!)#`@`#````&$,"
M`!`````<0P(`3P```"U#`@`S````?4,"`#,```"Q0P(`00```.5#`@`:````
M)T0"`"L```!"1`(`+P```&Y$`@!3````GD0"`!8```#R1`(`'@````E%`@"%
M````*$4"`"0```"N10(`0@```--%`@`E````%D8"`$<````\1@(`*P```(1&
M`@`S````L$8"`"X```#D1@(`+@```!-'`@!B````0D<"`#````"E1P(`,```
M`-9'`@`M````!T@"`#(````U2`(`-````&A(`@`W````G4@"`!8```#52`(`
M(````.Q(`@`0````#4D"`'P````>20(`"````)M)`@!P````I$D"`'(````5
M2@(`@````(A*`@`F````"4L"`%X````P2P(`%P```(]+`@`C````ITL"`!8`
M``#+2P(`$@```.)+`@`4````]4L"`!P````*3`(`0````"=,`@`>````:$P"
M`!D```"'3`(`4````*%,`@`2````\DP"`!@````%30(`"@```!Y-`@`%````
M*4T"``8````O30(`"````#9-`@`%````/TT"`!8```!%30(`#0```%Q-`@`7
M````:DT"`!8```""30(`(0```)E-`@`0````NTT"`!\```#,30(`)P```.Q-
M`@`.````%$X"``P````C3@(`!````#!.`@`)````-4X"``\````_3@(`'P``
M`$].`@`J````;TX"``L```":3@(`!P```*9.`@`&````KDX"`!H```"U3@(`
M+````-!.`@`)````_4X"``P````'3P(`$````!1/`@`=````)4\"`!H```!#
M3P(`!P```%Y/`@`+````9D\"`!````!R3P(`!P```(-/`@`+````BT\"`!H`
M``"73P(`"0```+)/`@`'````O$\"``T```#$3P(`!0```-)/`@`5````V$\"
M`!4```#N3P(``0````10`@`&````!E`"``4````-4`(`(P```!-0`@`9````
M-U`"``L```!14`(`(P```%U0`@`4````@5`"`"L```"64`(`&0```,)0`@`D
M````W%`"``8````!40(`%P````A1`@`%````(%$"``4````F40(`!P```"Q1
M`@`;````-%$"``4```!040(``@```%91`@`"````65$"`!L```!<40(`"```
M`'A1`@`'````@5$"``L```")40(`%0```)51`@`8````JU$"``<```#$40(`
M(P```,Q1`@`+````\%$"`#,```#\40(``@```#!2`@`$````,U("`!`````X
M4@(`%@```$E2`@`.````8%("``(```!O4@(`"P```')2`@`)````?E("``8`
M``"(4@(`(P```(]2`@`8````LU("``@```#,4@(`%````-52`@`1````ZE("
M`!T```#\4@(`$@```!I3`@`"````+5,"``<````P4P(`#P```#A3`@`0````
M2%,"`!````!94P(`+````&I3`@`)````EU,"``@```"A4P(`$@```*I3`@`%
M````O5,"``(```##4P(`"P```,93`@`!`````````"\"``!_!P``MP(`````
M``!(````S`$``,X"```F`0``6`,``-4%``!^`````````"D(``##!@``@@$`
M`"@"``##!0``A@,``(D'``!A`P``[@4``.8#``"-!P``TP````````"]`0``
M+`<```````#'`0``F`<`````````````W@$``#X(```J!0``^@```/$&``!`
M!@``U0$``#H%``!G!@``_P0``%H$``"K`@``O@`````````)`P``````````
M``!-!```3`@``(4!```T!@``JP<``)<"`````````````&4#``#@`@``[@,`
M``P'``"1`0``/00``/L#``#!`P``T@8``%0%``!3!```V0$``/`#``!-`P``
MY`<``&\'``#G!@``2P8``"`'``#X`@``J0,``&H"````````K`4```````#-
M`0``F@0``$("``!!"```O`````````#Y`0``104``!<#````````%`8``'4$
M``!)!0```````-0!```@`0``6P$``"\%``#6`````````%P%````````AP0`
M`(,"`````````````/`&``````````````````#;!@``6`$``%8````X`P``
MA0(``$4```!$!0``=@8``'4'``!``P```````*@#```B`0``V`,```````#9
M!```BP,``.P"```L"```;@4````````^!P```````#,$``!\`P``K0$```,(
M``!X`@``+P$``,<$``!_!0``E@<``$<'````````7`,``*(%``#]!P``=P,`
M`-@%``!'!0``\````)P%````````YP,``!,`````````.0@``"P````H!@``
M`````(8'``!2`````````#$(`````````````'X&``"F````KP<``)D"``!>
M!P``V0```,T"````````!@$``)D&```_!0```````%4#````````+08``-<"
M``#*`@``KP$``"`(```N!@``M`<``+$#```!`@``0P@``'T````'!```8@$`
M`!$'````````U`(``%`'``!C!P``G@0```````#!````W@```%("```I!@``
MC@<````````@!0```````(`'``#@!```R@,```````#.`0````````````#0
M`@````````````!$!````````'D'``!M`@``108``,4!```9"````````"D%
M``!>`````````&L'```U"```=`<``.\%`````````````"0'``#G!0``````
M`!@```!=!```D@0``$P"````````JP,```L```!5!@``P@```.`!``"3!P``
M^@4``,$"``!M`P``1@```-H%````````V0,``/0%``!K!```"0@``!L!````
M````9@4``),!`````````P8``*@"``!3!0```````(@&``"[!P``*@<``'L'
M````````[@8``$H#`````````````,$'```,`@``P`(``-\%````````;@(`
M`$@$```^!@```````,0"```6!```FP```.T!``"L!P``&`<```@"``!L`@``
M#04```````!`"```\0<`````````````O04``.P$``"O!0```````*('``!R
M!@``@0(```````#H`0``]@(``&,#```""```]`(``#L#``#(`@``$0@``'8`
M```1`P``XP4``+@#``#*!```ZP0```<'``"8!0```````$4$```,````7P0`
M``D$``!2!````````)@`````````0@8``(H$``"$!0``_`,```0%````````
M$P@``#D&```,!@```````(<!``"@!P``-0``````````````3P0``#D#``"1
M!P``P````*T$``#1`P``MP$``.@%``#+!P``$@<``$L"``!Q`0```````)`$
M````````Q@0``,\```#"!0``I08``%<&```N"`````````(&``#=!0``=04`
M`/P!```N!0``^```````````````D@(``#L'``!]`@```````)H```#3!@``
M!P8``(D#``"#`0``KP0``#$#`````````````%T'``#M````?P8``#8%``"Z
M!P``,P,``/8!``!"`P``>P`````````F!0``P00``$0"```W!```:`<`````
M````````=`(````````!!P``<@$``(<'``#[````'`$``'D&```L`0``CP0`
M````````````<0<```H!``"1````%`<``$X`````````$04``.4&``"6!0``
M`````+H```"5!0``J00``#8(``#L````,@4``.X'````````>`4``"X`````
M````,`4``(D```#@!P```````/H!``!T!0``@@8``$($````````=@4`````
M```M`0``'@4``%0"``!A`````````-\#``"7!@``2P<``#T%``!1`P``````
M`#4!``!@!0```````!\'``!.`0``O@0```\&```````````````````,`0``
M)`,``-D&``"R!@``Z@(``*8'``#%!0``PP$``!,'```J`0``LP,``%(&``!7
M`0``<@,```````!X`0``XP0``'$"``!+````F00``'P!``"N!```708`````
M``#/`0``AP,``+\'``!*!@``#0```),$``"+!0``"08````````3`@``3`8`
M`.D"````````\@<``'8#```Z`@``@0<``)P'`````````````)8"``"P`0``
M_0```-8%````````LP0```````".`0``)0```!$```"M`P``5@(```````#=
M`0``&@<``!D%``!.`@``#P,``"L$````````J`8``$D$``#5`@``#@<``+(`
M```^`P``Z````.(#``!T`0``X00``,$%````````80$``'<!````````40$`
M`&,%````````N````*<%````````;`8``%L$``!$!P```````'8"``#_`P``
M(@```.8$```V!```[`8``%T!``"2!0```````,X$``"\!0``]P```%D#``!P
M`@``@`$```8#```9!@``LP$``'````#&!@``Q@,``)T"``"H`0``-0,``!(#
M``#,`````````.8```"Q`````````````````````````,8'``"*!P``(0$`
M`$\%````````>00``/X"``!S`0``FP0``%$%```&````E@$``-<%``!&`0``
M(`(``+L`````````5@<``'H&````````M0<``$X%``")`@``2`,``*X%``"F
M!0``A`<``#`&````````B@(``.L`````````=P```+X!``"/!@``.`0`````
M````````0P<``,T&```````````````````[!0````````````"*!0``V@$`
M``````````````````0'````````804``-<$````````O08``"<!``"A!@``
M'P(``$$````J`@``[@$``"\(``":`@`````````````&!P```````+P#````
M````(`,``!4$````````C@(``&T```!\````%@4```````"A`P``O0<``*L!
M`````````````'T%``#L!P``E08``*<!````````FP$``%(!```\!```*0<`
M``D'```;!0``#P<``'@'``!``@``[0<``````````P``*`@````````S!0``
M`P`````````%`0``M`$``"`````<!@``Y0```+<$``![`0```````"L!````
M````,0```%D"`````````````#<%````````A08``)D```#2`@``````````
M``!<`0``:0(``)4#``!Y`0``'P`````````!"```I`````````"5!P``5@0`
M``````"Y!@``V````+<%``#'!@```````(("```)!0``=P(`````````````
M`````$4'``!^`@```````)P```"K````@P```-0&``#*!0``Z`0```````#R
M!@``IP(``)H!````````LP(```T"``!F`P``P`8``'($```A!0``I`4`````
M``!Y!0`````````````Q!P``#P```$@!```_"```90```#T"```=`@``CP``
M`$$"```L!@``=0(`````````````%`(`````````````F`,``*4'``#;````
M1P@``*8"``!Z`@``B@```&P```"S!@``:`(``)0&```$`@````````````"A
M`````````-$'````````K@$``%@'````````QP```/$#``"#!```\0(`````
M``#U`````````%0````?`P``&`@``#T#```K"````````'X$````````&P0`
M`!D$``!)"```SP4``.L!````````,P(``(8!````````K`$``-P```#%!```
M.`$``(`"``!G!0``D`8``/,#```Y!0``]````'H$````````*P,``*T````A
M"```X@<``&4$```+!0``L@$``(4'``#>`P``K`0``+$$``"F`P``1P0``!0$
M````````Y@(``&D$```E`@``=`8``'0```"D!P``S04``,D'``"+!@``K@(`
M`/,!````````\P0```````!/!P``:08``"<#`````````````*`!```,!0``
MX`8``*X&```S`0``/P<``$X'``"J`P``@`8```````!("```3@,``,8"```5
M"```DP8``)P#````````1P(``$D#````````E`0``+D```!B`@``````````
M```8!@``N0,```````"%!0````````````!W!```1@@``%$```#_````K0<`
M`*H"````````A00``%8&``#T!@``F`8``,L#````````3P$``)0%``#J!```
M4`$````````````````````````L`@``\`<`````````````]@4``(X```!1
M!```IP<``+`$``#"!```T`0``#@(```_`@``````````````````%P@``'4#
M``!5!```^@0````````+!@``!0```"T"``"(!```0`4``.H'``#+!0``V@(`
M`((%``!7!0``)0,``(P```!$"```;`4``*<````N!```:@$``&(`````````
MWP<``+$%``#H`@``-P(``````````````````$$!````````#@(``$H$````
M````5P(``)\$````````<`8```````!0!```X@`````````8`P``\P8`````
M````````K0(``$8%``"H````>@```.P#``"T!```Z0$```X#``!Q!```````
M`,`!``"^!P``M0(``%0#``#S!0``T@```$<````C"```J`<``/P$````````
MV`(```````"B`P``,0$``&8'``"Z!0``TP<``/@#````````_P8``#<```"(
M`P``^0,```````"V!```A@8```````````````````<"``"6`````````-,#
M````````_P$``#($```A!```C@8``&H```![`P``9`,``,(&``"``P``````
M```````F!P``(`0``)0'``#^`P``M@<``&X!````````RP8``!8&``!M!P``
M`````$<#````````BP```-<#``"'!0``:P4``#\#`````````````"`&``!4
M!```\P(```````"Z!@``L08``/4$```)`@``0P4``!H#````````$```````
M```C`0``_`4``$T(````````D@$``&4!```D"````````+4````G````````
M````````````$`<`````````````<P<```````!9````+0```.<$````````
M````````````````VP$```````"&````Y`(``-8&````````;`0```````!$
M`0``^`0```````"5`0``P`<```````",!0```````*H$````````'@0`````
M```N`@``:````'L"``"]`P``$@8``,`#```Z````1@<``,<'``!"`0``````
M`#(#``#2`0```````+\!```;"```!@8``$4!``#7`0``0`<````````R"```
M.0<``&`#````````NP$``*(!``"K!@``.`<``#`#``":!@``XP<```````#]
M`@``4````+X#```=````Q````*0$``!7!P``$`$``"L%```Z!P```````'D#
M``"-````U`0```````!K!@``@P8``/$```"Z!```[P0``'X%```H!```C`<`
M`#L```#<!0``[P<`````````````0````(L'``#0!P``^@(``,P&``!,`P``
M!P4```````#!!@``-`,``&8!``#.!P``JP4````````?!@```````-8$``#=
M````?08``"((```#!0``(@(``!P%````````W@(``($#``!;`P``2@(``"T'
M``#\!P``&@@``),"``"I!P``[04``#(`````````[@(``*`"``````````4`
M`*,"``#Z!@``I`(``"L&``#U`P``QP,``````````````````,D$``#1!```
MBP(``.$"````````2@4``+T"````````:`0```````#1!0``OP```(\"``!A
M`@``2`4``)<#``!;`````````'P%``!\`@``U`,``",'``!?````W`(``/L&
M``!J!```<@(``)L#``"F!```/0````0!``".!```MP```'$&``#M!```S0``
M`````````````````)8$``#Z`P``8`0``&@#```S!@``C04`````````````
M9P0```````""!P``#0<```````!W!0``7@,``#4&````````GP,```````"E
M`@``X@$``-\&``#C````S00``(T"``#B!```%0(``$('```G!P``V@,``.\!
M``!T!```Q0(````````H!P``O`(```````#F!0``3P```)`!````````````
M```````%!0``>`````````"8!```GP(``'T!``!#`0``J0$``!P(````````
M9P```'`'```(!```0@`````````S````_@``````````````!08``"D"```"
M!0``6`4`````````````6P8``#D"```["```XP,``#L&```="```Z@8`````
M```U!P``6P4``'T$``!S!````````'\"``#$!```I`8``.$%``!P`0``#@@`
M`!(`````````*0```(T&``#F`0``8P0````````<````Q0<``,(!``#T!P``
M,04`````````````20```/\%````````/P$`````````````T0(``&,&``!D
M`@``````````````````S`4``!(!````````P`0`````````````C@4``/8'
M```5!P``!0<`````````````%`````````#J!0``+P0``.8&````````````
M`!,!````````K````%,"``"-`P``#08``)T````(!0``_@$```````",!@``
MSP<``,\&``"?!0```````/8$``````````````````#(!@``.`8``!8(````
M`````````&H&``#R`@``U0```-8"``!!!```[0,``",#``#@!0``G`$``/(`
M`````````````"P%``!)`@```````````````````````&X```#=!@``H`8`
M```````<`P```````.@'``#K!@``@P,````````R`@```````$0````<`@``
M`````)0#```6`P``L`(`````````````ZP4``$@"``!K````"P@``*T&```U
M!````````(`%```;!@``0P8``",$`````````````#8'``#:!```:@4`````
M```.`0``U0,``'X'``"@`````````-X'``!?`0``.0$`````````````````
M`-$```!+`0````````P(```/!0``.@$``+@%``#S````4P$``,D````'````
MG`8```````"F!@```````",%``!<````70```,P#``!6`0```````",&``"V
M`0``T@,```,$``![!```W0(``+4!````````,````+D$```T`@```````/<&
M```=`P``^08``)$%`````````````&,!``#)!0```````$D&``!?!0``````
M`)0!``#$`P```````.$````D!0``?0,``/<'```5!0``$`@``/`"``#.````
M&P```*0!````````1`,``/`!````````V@```+`'````````.`````@!``"=
M`0``K04```H```#?`@``A`(``&H#``",!```OP8``)P"``!P!0``TP(``%X&
M````````O`$```````!-!@````````````!D!0````````P$``"D`P``30``
M`/L"``````````````````"U!0``60<```````!_`0```````)`"````````
M8@4``/$!``"1!@```````.L#``!8`````````%`&``!S!0``V`$``+P&```_
M!@``$08``"H$``#H`P```````!D'`````````````#`$````````S0<`````
M``!7`P``=0$``$@&``!O````YP(``.H!``"-`0```````/L'```Z!@``:0,`
M`$$&``#[!```NP0``&D%````````\`4``+@"``!=`P``[P(``($!```!!```
MO`<``,0%``#'!0``CP$````````T"```408``,X&```7!P``6@```!\$````
M````MP8``)4"``"8`@``U@,``!@%``!E`@```````&8"````````R@8```0$
M```5````OP,``(D%``"&`@``FP<``%X"``!*!P``_@8``'X!```J````QP(`
M```````H`0``W@8``-,$``#4!0``$`,````````I`0``RP0````````O````
M%08``+$'````````5@4````'```:!```\P<``/(!``"(````L`4```````!B
M!@``#P(``"X#``!N!@``4`,````!````````IP,````````P!P```````%D!
M``!O!@``I0```"0&``#1`0``_`(```````"`!```#0,```$#``"S!P``A0,`
M`!4#``"N````"````#L$````````*@8```````"@!```HP8``%\&``!-`0``
M`````&T&```F`@```````,,"``!^`P``!@4``","`````````@<`````````
M````M`,``!H%``!:!P``B`$``%$'``#M`@````````D```#!`0``Z@```#\`
M````````NP4``$L$```K`@``J0(`````````````H`4```8(``!(!P``````
M`+D!``#T`0``'`0```H'``#/!```Y````($$````````"P<``.T&``!D!```
M9P$``(H#``")`0``40(``'@$``#]!@````````````"T!@```````)D!``#D
M!0````````X&````````-`<``%T%```%`P``````````````````T```````
M``";`@``.@@````````(!P```````+<#````````````````````````2@$`
M`%L"````````N0<``(P!````````H0<``,L"````````K@<``-D"````````
MK`,```@(```#`0``L@4``#P!```>!@``ZP<``*(````*!```M@,``,@%``#^
M!```````````````````+00`````````````K`8```````#/`@``T08``!X'
M``"?`0``JP0``#,(````````3@@``)H#```!!@``V0<``%H&``#W`0``GP<`
M`#X```"'`@``G@<``%,#```<!P``50(``/D%```L!```^@<```````#.!0``
MM````)H%``"C!````````*4%``"B!@``)P4``(L!```J"````````.\#````
M````EP```!H```````````````````#G!P``K@,`````````````YP$```H(
M```^`0```````'0#```I!```V@<``%H#``!2!P``*P<``)X%``!+"```%`4`
M`)X`````````^`4``-,!``![!@`````````````7`0``)0<``,@$````````
MU`<``-8'``"7!P``?0<``-L"```2"```%@$````````?!0``;P(``%\'```[
M`@``-@(``&<#``!E!@``W`<``!T'`````````````*H``````````````&T%
M```(`P``504``)D%````````5P```-P!````````&@$``+$"````````````
M`'`#```>````H04``*4!```V!@``2@@``+("````````@08``)````#(`0``
M4P8``!0!``#&!0``N0(``$L#```H`P``-@,``'H!````````Y04``"($````
M````&`$``(````"I````]P,```````"8`0````````````!N!P``Q@$``"$#
M```>`0``DP,```````!Q````Z0<```<#``!/!@````````````#%`P``````
M``````#?`0```````"0!``#9!0``;00``,8```"T`@```````'(%``#V`P``
M%@```(D&``"V!0``LP4```````!L`P```````+`#``#]!```Z00``*$"```;
M!P``I0,```````!M`0```````%H"``"-!```X0$``.4"``"B!```-@```',"
M``"$`P``0@@``#<'```>`P``HP$``!("``"5!```D`4``!$$``!7!```HP,`
M````````````/`(```4"``#7!@``7@$`````````````D0,```````!2`P``
MHP```)8&```8`@``Y00```````!0!0``Q`$``#<(``````````````````"2
M!@``'P$``!T%``#:!@``&0```#T(```5`0``3`4``&D```!9!0``]`,```0`
M````````ZP(``)`'````````R@$``,H'``"Y!0``30(````````T````````
M`&`&``#%`````````'8!``"$!@``)@,```````#P!````````"(&``"=!P``
MQ`<`````````````8@,```````!<!@``304``)0"``""`P``"P0``%8#```!
M!0``H@(`````````````'0$``!8'``#(`````````)(```!@`0```````&\#
M``#=!P```````&\%````````T@<`````````````!00````````F"```````
M`$L%``!,!```@P<``````````````````!<"```A!@``E````(X#``#N!```
M``````L#``![!0``9````#(&```&`@``L@<``,,#````````_04````````/
M`0``^P$``"0$``#O!@``DP```.$'`````````````$H````/"```00,``-@&
M````````/@4``/$$``!3````AP8``"$"``!5`0``IP8``#H$``"(`@``````
M`+H!``!.!```$0$``+@$````````4P<``!,$````````Z`8```(!```Q!@``
M&@8`````````````)@``````````````-@$``$(%``!9!@``>`8```````#Y
M`@``T@4```(#``!F!```Y`8``%P'```T!0``U````$8$``#8!```````````
M``"C!P``;P0``%4'``!Q!0``E0```*\&``#0`0``VP<``"0````"`@``/`@`
M``<!``"J!P``Z@,````````O!P``'00``#$"````````10(``(\#``#\!@``
M)P(````````U`@```````'<'``#_`@```````'D`````````,`$```````!S
M!@```````````````````0$``,X#```B!P````````\$``"G!````````!8"
M````````[@```#X"```R`0```````'P$``#;`P````````````!=`@``````
M`"H#```+`@```````-L$``#R!````````(H&``"U`P```````$D'``!E!0``
MNP8``,`%```W`0``8`(``#,'```M`P```````+\"````````TP4````````B
M!0``+04``)T#``#R`P``R0,````````0!````````$`$```M"````````(<`
M```3!@```````&$'``",`P``;`$``.,!`````````````(D$``"V`@``````
M`'`$``!D!P``@0````X```!0`@``3P(``!L#``#L`0```````)D#````````
M7P,```````#/`P``$@0``"D#````````_@4``/(%```G"```!`@```H#```Y
M````GP```&`'``"L`@``#0@``+$!````````?`<``/8```#5!````````$P`
M``"*`0``PP0``,P'```3!0```````.,"``#T!````````(\%``!,`0``````
M`#P'````````X0,````````7````.@,``$D!``#5!P```````&D'``"U!@``
M`````&P'``"[`P``R`,``%0!```W!@```````.D&```\````Z04``-($``!>
M!0``EP4```,"```^!````````!H"``"\!`````````````!$!@``````````
M``!I`0``&0,``-\$```Q!````````-X%``#I``````````````!N`P``_0,`
M``````!Y`@``)04``-P&```R!P```````*D&``"P````>`,`````````````
M:`$``*@%``#=!```=0```$`!`````````````$4#``"J!0``]P4````````7
M!0``^P4```````"T!0``&0(``#P#``"X`0```````,D&``"O`@``````````
M``"_!```=08```````#^!P``L@,````````?"```G@$``,0&```.!0``[P``
M`#0$``#(!P``00<````````G!@``(P````````!H!0````````0#```4`P``
M`````$X&``#;!0``$@4``/4"``#<`P``````````````````1@8``%@&``"^
M!@``Y`,```H%```7!```N@,``$,"`````````````#@%````````````````
M````````H0$``)('``"]````B`<``*\#````````^00```,#``"J`0``````
M`"8$```F!@``9P<``/T!``"$`````````+X"```&!```9@```)<$````````
M,`(``/4!``#*``````````<(``!F!@``=@0``%@"``!D!@````````````#L
M!0``8@<``/@'``"P!@``,`@``-T#```Y!```G`0``"4(```1`@``]P(``$\#
M``!R!P```````/$%```_!`````(```````""!```]@8``,L!```)`0``<0,`
M`-4&``````````````````""````]P0``+H"```>"`````0``&L!```;`@``
MY0,```````"#!0``$`4``+<'```H``````````````#D`0``X@(``%H%````
M````U@$``*`#```\!0``:@<```````"&!0``````````````!@``#`,``&<"
M```D`@```````',#``!#`````````!X"``!4!@```````$,$``"%````"P$`
M`,P"``"2`P``4@4```````"7`0```````-\```!C````P@<````````*`@``
M?`8```````!&`P``7`0``)L&``#C!@``:`8```````#A!@``#@0``&4'````
M`````````#0!``"+!```N`8``!<&````````/`8``.(&``">`@``+@$`````
M````````I00``+T$``!B!````````&0!```4"`````````````">`P``````
M`/4&``````````````````"F`0``6P<``%H!````````LP````````"9!P``
M?P0````````E`0``;@0``#4%`````````````'(```##!P```````%X$``!&
M`@``=@<``(P"``#)`0```````.`#````````+P,```````#8!P``50``````
M``!K`P```P<``+($````````A`0``-`%``"I!0``$`8``,L````(!@````@`
M`,(#`````````````-`&````````D00````````E!`````````````"H!```
MZ0,``#@"``#U!P```````"<$```]!P``30<``+X%``!_````Q08`````````
M````X````+4$```H!0```````(@%````````````````````````W@0``$4(
M````````NP(``,P$```B`P```````-<```"6`P``````````````````````
M`#T&`````````````!@$``!A!```X@4````````N!P``DP4``)X&``"!!0``
M`````(0!```[`0```````&```````````````*H&```]`0```````&\!``!#
M`P``(0<``!T&``!Z!P``>@4``)\&````````]04```````!S````_P<``&L"
M```"!````````%D$``":!P``G00``)L%``#X`0``1P$```````!A!@``#00`
M`+@'``!4!P```````"\&````````T`,``"L````9`0```````"P#````````
M8P(`````````````-P,``)$"````````W`0``'H#````````$`(``/D```"C
M!0``M@```%P"````````D`,``%@$````````R0(``/P```"A!```=P8```(`
M``````````````H&````````1P8``.0$````````````````````````(0``
M``````"O````$P,``)T&``"=!0``M@8``.4'``"/!P``PP````0&``#"`@``
MS0,``.4!``"&!```004``"4&``!?`@``#0$``.8'``!,!P``YP```/@&````
M````^0<``+\%````````?P,```````#7!P``!0@````@*"5S(&1A>7,@86=O
M*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O
M;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%N9``@870@`"!O<@`B)7,B(&ES(&YO
M="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E
M<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B
M)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E
M+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A
M;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D
M+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+
M0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S
M(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L
M<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F
M;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N
M($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI
M;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E
M<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML
M:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W
M:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@
M;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A
M;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG
M("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`
M,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I
M;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-
M(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`
M06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R
M9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I;VX@9F]R(&)L86-K
M;&ES=&5D(&%D9')E<W-E<SH`06-T:79A=&4@4V-R:7!T`$%C=&EV871I;F<@
M=&AE('-C<FEP="!F;W(@(B5S(B!F86EL960Z("@E9"D@)7,`061D`$%D9"!#
M:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D
M($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O
M=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D
M(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P
M86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@
M=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U
M<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B
M)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG
M('5S97)S(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(%-E='1I;F=S`$%D9')E
M<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A
M;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`
M06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES
M<VEO;G,`06QL(&9O=7(@<VED97,`06QL(&]F('1H92!F;VQL;W=I;F<`06QL
M;W<@4G5L97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R
M;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R
M;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L
M=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A
M;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G-W97)E9`!!;G1A<F-T:6-A`$%N
M=&EG=6$@86YD($)A<F)U9&$`06YY(&]F('1H92!F;VQL;W=I;F<`07!P;&EC
M871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`
M07!P;'D@1FEL=&5R<P!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!
M<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!
M<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(&1E;&5T92!T:&ES(')U;&4_`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U
M8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)
M+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA
M+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M
M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`
M075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T
M:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5
M<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R
M(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`075T
M;VUA=&EC86QL>2!U<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG
M93\`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`
M0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S
M=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`
M0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E
M(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`
M0F-C`$)E9VEN<R!W:71H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`
M0F5R;75D80!":'5T86X`0FEN9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`
M0FQA8VML:7-T`$)L86-K;&ES="!%9&ET`$)L86-K;&ES="!I<R!N;W0@<W5P
M<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$)L86-K
M;&ES=&5D($%D9')E<W-E<P!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E
M<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O9'D`
M0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S
M<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A
M;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"
M=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H
M92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O
M9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I
M=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L
M(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V
M92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@
M97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D
M+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#
M87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#87-E(%-E;G-I=&EV90!#871E
M9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V,`0V5L;"!0:&]N
M90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I
M97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ
M-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I
M9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E
M`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@96UA:6QS+@!#:&%N9V5S('-A=F5D+@!#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H
M87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF
M:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S
M92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E
M<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES
M="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES
M;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`
M0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E
M<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T
M90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E
M(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D
M97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T
M:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N
M9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#
M;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!
M<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@
M;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O
M;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N
M;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO
M;B!F86EL=7)E`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1A:6YS`$-O;G1E
M;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B
M`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y("5S`$-O
M<'D@9F%I;&5D.B`E<P!#;W!Y(&]F("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@
M240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK
M9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S
M(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N
M;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`
M0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E(&YE=R!F;VQD97(`0W)E871E('-U8B!F;VQD97)S
M`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T
M:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R
M<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N
M="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#
M=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`
M0WIE8V@@4F5P=6)L:6,`1$0`1$E304),140Z(`!$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@
M3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`
M1&5?;&5T92!#;VQU;6X`1&5A8W1I=F%T92!38W)I<'0`1&5C96UB97(`1&5C
M:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I
M;VYS`$1E;&5T90!$96QE=&4@)7,`1&5L971E($-E;&P`1&5L971E($-O;F1I
M=&EO;@!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO
M;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T
M92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$
M96QE=&4@;65S<V%G92!C;VUP;&5T96QY`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C
M=7)R96YT(')O=P!$96QE=&5D`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@(B5S(BX`1&5L:79E<B!I;G1O(&UY($EN8F]X`$1E;&EV97(@:6YT;R!M
M>2!);F)O>"!A;F0@8V]P>2!T;P!$96QI=F5R(&EN=&\@;7D@26YB;W@@86YD
M(')E9&ER96-T('1O`$1E;&EV97(@=&\@9F]L9&5R`$1E;&EV97)Y('1I;64`
M1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A
M:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT
M`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN
M=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T
M;R!L969T`$1I<F5C=&]R>0!$:7-A8FQE("5S`$1I<V%B;&5D`$1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL
M960@9F]R96-A<W0`1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE
M;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/P!$:7-P;&%Y(&9O<F5C87-T("A4
M048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$
M:FEB;W5T:0!$;R!?;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES
M="!M97-S86=E<P!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP`$1O('1H:7,Z`$1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#H`1&]E<VXG="!B96=I;B!W:71H`$1O97-N)W0@8V]N=&%I;@!$;V5S
M;B=T(&5N9"!W:71H`$1O97-N)W0@97AI<W0`1&]E<VXG="!M871C:"`H=VET
M:"!P;&%C96AO;&1E<G,I`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$
M;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL
M;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET("5S`$5D
M:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M
M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@
M9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT
M+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--
M4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U
M;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@)7,`16YA8FQE(&EN<V5R
M=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YA8FQE9`!%;F0@
M>65A<@!%;F1S('=I=&@`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET
M>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E
M9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N
M86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%
M;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U86P@=&\`17%U871O<FEA;"!'
M=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`
M17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R
M(')E=')I979I;F<@8W5R<F5N="!S8W)I<'0Z("@E9"D@)7,`17)R;W(@<V%V
M:6YG(&-H86YG97,N`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T
M;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU
M=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`
M17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AI<W1I;F<@4G5L97,`17AI<W1S
M`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@
M,2!O8FIE8W0L(&=O="`E9"X`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L
M;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y
M(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T
M;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z
M`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&
M97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L
M970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@
M)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL
M92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+@!&:6QT97(@06QL($UE<W-A9V5S`$9I;'1E<B!/
M;FQY(%-E96X@365S<V%G97,`1FEL=&5R($]N;'D@56YS965N($UE<W-A9V5S
M`$9I;'1E<B!/<'1I;VYS`$9I;'1E<B!2=6QE`$9I;'1E<B!2=6QE<P!&:6QT
M97(@4V-R:7!T($1I<W!L87D`1FEL=&5R(%]2=6QE<P!&:6QT97(@86-T:79I
M='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L
M9&5R("(E<R(N`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E
M(&)E96X@9&5L971E9"X`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I
M(&AA=F4@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E<B!A
M8W1I=FET>3H@)7,@;65S<V%G92AS*2!T:&%T(&UA=&-H960@=&AE(&)L86-K
M;&ES="!W97)E(&1E;&5T960N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A
M9V4@(B5S(B!F<F]M("(E<R(@:&%S(&)E96X@8V]P:65D('1O('1H92!F;VQD
M97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R
M;VT@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ(%1H
M92!M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA<R!B965N(&UO=F5D('1O('1H
M92!F;VQD97(@(B5S(BX`1FEL=&5R(&YO="!F;W5N9"X`1FEL=&5R<P!&:6YL
M86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&
M;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`
M1F]O9`!&;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9"!I
M<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV
M97(N`$9O<G=A<F1S`$9O<G=A<F1S($5D:70`1G(`1G)A;65S`$9R86YC90!&
M<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY
M;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T
M:&4@`$9R;VTZ`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M
M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'
M86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D
M90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`
M1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!3
M96%R8V@`1W)A>7-C86QE`$=R96%T97(@=&AA;@!'<F5A=&5R('1H86X@;W(@
M97%U86P@=&\`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`
M1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`
M1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O
M:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N
M=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE
M`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG
M:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`
M2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E
M<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO
M;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC
M;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G
M92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B
M:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@
M;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S
M`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2
M=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N
M9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T
M(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"
M969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W
M:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R
M979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R
M>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP
M;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S
M<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA
M`$EN9&EV:61U86P@57-E<G,`26YD:79I9'5A;"!R=6QE<R!A<F4@;F]T('-U
M<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!);F1O
M;F5S:6$`26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G
M92!D96QI=F5R>2X`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L
M;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A
M=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV
M86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN
M`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N
M`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A
M;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED
M('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H
M87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N
M:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27,`27-L92!O9B!-
M86X`27-N)W0`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L
M:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M
M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T
M:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@
M4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B
M:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+
M97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A
M=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+
M;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3$1!4"!S=7!P;W)T
M(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL
M86)L92!O<B!N;W0@;&]A9&5D+@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P
M;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W
M;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO
M9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE
M=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T
M:&\`3&5S<R!T:&%N`$QE<W,@=&AA;B!O<B!E<75A;"!T;P!,979E;`!,:6)E
M<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H
M="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!2
M86EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,
M:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X
M($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$
M871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R
M8VAI=F4`3&ES="U(96QP`$QI<W0M240`3&ES="U)9`!,:7-T+4]W;F5R`$QI
M<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H
M=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE
M`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N
M`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W
M97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O
M;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA
M9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA
M>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T
M(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)?:R!M97-S
M86=E(&%S(&1E;&5T960`36%R8V@`36%R9VEN`$UA<FL@;65S<V%G92!A<SH`
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N
M9',`36%R=&EN:7%U90!-871C:&5S("AW:71H('!L86-E:&]L9&5R<RD`36%T
M8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D
M(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@3G5M8F5R(&]F
M(%)U;&5S`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&)L86-K
M;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E
M<RP@36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W
M(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N`$UA>&EM=6T@;G5M8F5R(&]F('=H
M:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S
M.B`E<RP@36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@
M;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N`$UA>0!-87EO='1E`$UE9&EC
M:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X
M<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B
M(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE
M=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O
M<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O
M=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG
M(&%D9')E<W,@=&\@;F]T:69Y`$UI<W-I;F<@861D<F5S<R!T;R!R961I<F5C
M="!M97-S86=E('1O`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@
M=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P
M<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5A<V]N
M(&9O<B!R96IE8W0`36ES<VEN9R!R96%S;VX@:6X@=F%C871I;VXN`$UI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-
M;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`
M36]V92!2:6=H=`!-;W9E(%)U;&4@1&]W;@!-;W9E(%)U;&4@57``36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T
M:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T
M86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E
M90!.7W5M8F5R(&]F(&1A>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S.@!.
M86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N
M9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!2
M96YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!3
M4TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.
M971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A
M;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO
M;VX`3F5W(%)U;&4`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA
M;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E
M>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L
M86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@
M;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.
M:75E`$YO`$YO("(E<R(@96QE;65N="!F;W5N9"!I;B!B86-K96YD(&-O;F9I
M9W5R871I;VXN`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A8VME;F0@8V]N9FEG=7)E9"!F
M;W(@=&AI<R!H;W-T`$YO(&)A8VME;F1S(&-O;F9I9W5R960@:6X@8F%C:V5N
M9',N<&AP`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@
M=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!6
M1E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@9FEL=&5R
M<RX@0VQI8VL@(B5S(B!T;R!C<F5A=&4@82!N97<@9FEL=&5R+@!.;R!H96%D
M97)S('-P96-I9FEE9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@
M<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE
M9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO
M(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P
M96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V-R
M:7!T(&=E;F5R871E9"X`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED
M97,`3F\@<W1R:6YG<R!S<&5C:69I960`3F\@<W5C:"!F:6QE`$YO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO
M<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE
M;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@
M069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&5Q=6%L('1O
M`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E
M<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:69Y(&5M86EL(&%D
M9')E<W,`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+
M`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@
M9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RX`3VYL>2!F;&%G('1H92!M97-S86=E`$]N;'D@;V9F96YS:79E
M(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL
M>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG
M92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`
M3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T
M(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@
M=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P
M=&EO;G,`3W!T:6]N<R!A8F]U="!S8W)I<'0@=7!D871I;F<N`$]P=&EO;G,@
M9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N
M86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF
M;W)M871I;VX`3W1H97(@3W!T:6]N<P!/=F5R=FEE=P!/=VYE<B!097)M:7-S
M:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!
M4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC
M<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!2
M86EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N
M`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@
M4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G
M=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S
M=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U
M:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@
M;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0
M96YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D
M96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U
M`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L
M<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE
M;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H
M:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE
M87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&5N=&5R
M('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E
M('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M
M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG
M(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB
M<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@
M97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A
M(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E
M(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M
M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0
M<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG
M;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A
M<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!27V5A<V]N
M`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A
M:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&
M;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@
M<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5C96EV960`4F5D:7)E8W0@=&\`4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5G=6QA
M<B!E>'!R97-S:6]N`%)E:F5C="!W:71H(')E87-O;@!296QA=&EO;G-H:7`@
M0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E
M;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO
M9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z
M("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N
M9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5N="!4;P!297-E;G0M
M9G)O;0!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D
M`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!&:6QT97)S
M($QI<W0`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O(%)U;&5S($QI<W0`
M4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T
M:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I
M9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O
M;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H
M=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE`%)U
M;&4@0V]P:65D`%)U;&4@1&5L971E9`!2=6QE($1I<V%B;&5D`%)U;&4@16YA
M8FQE9`!2=6QE($YA;64`4G5L93H`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<P!34T@`4U1!4E143%,@9F%I;&5D.B`H)7,I("5S`%-5
M0T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@
M86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M
M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC
M:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E
M("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!3971T:6YG<P!3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O
M;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!38W)I<'0`4V-R:7!T
M(%5P9&%T:6YG`%-C<FEP="!N;W0@=7!D871E9"X`4V-R:7!T('-U8V-E<W-F
M=6QL>2!A8W1I=F%T960N`%-C<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T
M960N`%-E87)C:`!396%R8V@@16YG:6YE<P!3965N`%-E;&5C="!&:6QE<P!3
M96QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A(&=R;W5P('1O
M(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C
M="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T
M('1A<F=E="!F;VQD97(`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D
M(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I
M;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&8M1&5F:6YE
M9"!(96%D97(`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YD97(`
M4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE
M9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E
M<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@9&ES<&QA>2!O<'1I;VYS+@!3971T:6YG<R!S=6-C97-S9G5L;'D@=7!D
M871E9"X`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO
M=R!!8W1I=F4@4V-R:7!T`%-H;W<@0W5R<F5N="!38W)I<'0`4VAO=R!D:69F
M97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN
M86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R
M/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L
M92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P
M;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E
M<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A
M($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`
M4VEM<&QE('-P86T@9FEL=&5R:6YG(&ES(&YO="!S=7!P;W)T960@:6X@=&AE
M(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`4VEN9V%P;W)E`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO
M=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W
M97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R
M="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A
M`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H
M97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3
M<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!A;2!&:6QT97)I;F<`
M4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU
M;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4
M<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W`@
M8VAE8VMI;F<@:68@=&AI<R!R=6QE(&UA=&-H97,_`%-T;W)A9V4@9F]R;6%T
M`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B
M9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J95]C="!O9B!V86-A=&EO
M;B!M97-S86=E.@!3=6)J96-T`%-U8FIE8W0Z`%-U8FUI=`!3=6)M:71T960@
M<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T
M(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N
M`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D
M("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L
M;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@
M(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@
M4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N
M<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U
M<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA
M;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,
M`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P
M=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T
M;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A
M8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I
M;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F
M;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E
M("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L
M92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S
M(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@
M861D<F5S<R`B)7,B(&AA<R!B965N(&%D9&5D('1O('EO=7(@8FQA8VML:7-T
M+@!4:&4@861D<F5S<R`B)7,B(&AA<R!B965N(&%D9&5D('1O('EO=7(@=VAI
M=&5L:7-T+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!D<FEV97(@<V%I
M9#H@`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N
M("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE
M9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I
M96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H
M92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@
M:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C
M=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4
M:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H
M92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S
M(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@
M97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE
M('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S
M(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@
M9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@
M;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B
M('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I
M;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E
M('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ
M(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A
M<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A
M;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE
M('-C<FEP="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@
M<V-R:7!T+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U
M:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@
M;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`
M5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N
M`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&\Z`%1O
M9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`
M5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI
M9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME
M>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD
M($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6
M+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H
M86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B
M+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T
M('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A
M=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I
M=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I
M;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@
M9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T
M;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@
M8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO
M=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B
M($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`
M56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@
M<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN
M:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@
M82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y
M;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O
M87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E
M`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@
M<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I
M;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T
M=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z
M("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`
M57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N
M9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R
M;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES
M=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A
M8V%T:6]N($5D:70`5F%C871I;VX@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@
M8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!6
M86QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@
M0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I
M8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6
M:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6
M:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!7
M90!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!7
M96%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M
M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T
M97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VA?:71E;&ES="!A
M9&1R97-S97,Z`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L
M:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:&ET96QI<W0@
M161I=`!7:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N
M="!F:6QT97)I;F<@9')I=F5R+@!7:&ET96QI<W1E9"!!9&1R97-S97,`5VED
M=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T
M:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I
M;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES
M9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!6
M1E,@9FEL92X`6"U0<FEO<FET>0!8+5)E9@!8+5-P86TM3&5V96P`6"U3<&%M
M+5-C;W)E`%@M4W!A;2U3=&%T=7,`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S
M`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT
M97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8
M-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE
M;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B
M;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!R=6QE<RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;W(@
M961I="!C=7-T;VT@<G5L97,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E(')E8V5I=F5D(&$@
M;F5W(&UE<W-A9V4`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU
M<W0@<W!E8VEF>2!A="!L96%S="!O;F4@96UA:6P@861D<F5S<R!F;W(@=VAI
M8V@@=&AE('9A8V%T:6]N(&UE<W-A9V5S('-H;W5L9"!B92!A8W1I=F%T960N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)
M=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO
M=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@
M86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A
M=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N
M93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO
M=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G
M:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@
M:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`
M6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT
M70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@
M5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S
M(&]F("5S70!?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SH`7T%D9')E<W-E
M<R!T;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z`%]!9&UI;FES=')A=&EO;@!?
M0FQA8VML:7-T`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]$96QE=&4@
M;65S<V%G92!C;VUP;&5T96QY`%]%;G1E<B!E86-H(&%D9')E<W,@;VX@82!N
M97<@;&EN93H`7T9O<G=A<F0`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R
M=&EE<RXN+@!?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O
M=6YT/P!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?36]V92!M
M97-S86=E('1O(&9O;&1E<CH`7TUY(&5M86EL(&%D9')E<W-E<SH`7T]P=&EO
M;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V-R:7!T`%]3971U
M<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`7U9A8V%T:6]N`%]7:&ET
M96QI<W0`86-T:79E`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!A
M;F0`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A
M;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I
M;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!D:7-A8FQE9"`M(&-L:6-K
M('1O(&5N86)L90!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I96QD
M`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH
M`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;F%C=&EV90!I;FQI;F4`
M:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI
M;F5S70!M86EL9')O<"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\`;6%T8V@`
M;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA
M;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A
M9`!O<@!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!P<F]C;6%I
M;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\`<F5M;W1E(&5R<F]R(&EN('!R
M;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R
M96YC97,`<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!);F=O`'-M<S)E;6%I
M;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T
M96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C
M;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W
M96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($EN9V\*4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E
M.B`R,#`V+3`R+3$U(#$X.C`T+3`R,#`*3&%S="U4<F%N<VQA=&]R.B!&86)I
M;R!';VUE<R`\9FQG;VUS0'5O;"YC;VTN8G(^"DQA;F=U86=E+51E86TZ($)R
M87II;&EA;B!0;W)T=6=U97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-
M12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=`I8+4=E;F5R871O<CH@2T)A8F5L(#$N,RXQ"E!L=7)A;"U&;W)M<SH@(&YP
M;'5R86QS/3([('!L=7)A;#TH;B`^(#$I.PH`("@E<R!D:6%S(&%T<N%S*0`@
M*%1E8VQA(&1E($%T86QH;R`E<RD`("AE;2`E<R!D:6%S*0`@*&AO:F4I`"`H
M86UA;FCC*0`@*&]N=&5M*0`@90`@82``(&]U`"(E<R(@3N-O(.D@=6T@9&ER
M973S<FEO+@`G)7,G(&[C;R#I('5M82!E<V-O;&AA(';A;&ED82X`)R5S)R!N
MXV\@97-TX2!C;VYF:6=U<F%D;R!N;R!296=I<W1R;R!D;R!(;W)D92X`<F5N
M9&5R:7IA9&]R(&1E(.%R=F]R92`B)7,B(&[C;R!E;F-O;G1R861O+@`B)7,B
M(&9O:2!A9&EC:6]N861O(&%O('-I<W1E;6$@9&4@9W)U<&]S+@`B)7,B(&9O
M:2!A9&EC:6]N861O(&%O('-I<W1E;6$@9&4@<&5R;6ES<_5E<RX`(B<E<R(@
M;N-O(&9O:2!C<FEA9&\Z("5S+@`E+C)F34(@=7-A9&]S(&1E)2XR9DU"('!E
M<FUI=&ED;W,@*"4N,F8E)2D`)60@)7,@92`E<P`E9"!D:6%S(&%TZ2!S=6$@
M<V5N:&$@97AP:7)A<BX`)60@<')E=FESXV\@9&\@9&EA`"5S("T@079I<V\`
M26UP<F5S<^-O($1I9VET86P@9&4@)7,`)7,@2T(`)7,@3W!E<F'G]65S(&1E
M($UA;G5T96[GXV\@+2!#;VYF:7)M8>?C;P!#;VYF:6=U<F'GXV\@9&4@)7,`
M0V%D87-T<F\@9&4@)7,`)7,@5&5R;6]S(&1O($%C;W)D;P`E<R!JX2!E>&ES
M=&4N`"5S(&$@)7,@)7,`)7,@97-TX2!P<F]N=&\@<&%R82!E>&5C=71A<B!A
M<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!M87)C861A<R!A8F%I>&\N($UA
M<G%U92!A(&-A:7AA('!A<F$@<75A;'%U97(@;W!E<F'GXV\@<75E('9O8^H@
M<75E:7)A(&5X96-U=&%R(&1E<W1A('9E>BX`)7,@Z2!O8G)I9V%T\W)I;P`E
M<R!M:6YU=&]S`"5S(&[C;R!E;F-O;G1R861O+@`E<R!A("5S(&1E("5S`$-A
M=.%L;V=O(&1E($5N9&5R9>=O<R!D92`E<P!!9V5N9&$@9&4@)7,`06YO=&'G
M]65S(&1E("5S`$QI<W1A(&1E(%1A<F5F87,@9&4@)7,`)7,Z("5S`"5S.B!%
M<W1A(&UE;G-A9V5M('!O9&4@;N-O('-E<B!D92!Q=65M(&5L82!D:7H@<V5R
M+B!4;VUE(&-U:61A9&\@8V]M('%U86QQ=65R(&QI;FL@<')E<V5N=&4@;F5L
M82!O=2!E;2!F;W)N96-E<B!A;R!R96UE=&5N=&4@<75A;'%U97(@:6YF;W)M
M8>?C;R!P97-S;V%L+@`L(&)R:7-A(``L(&)R:7-A("5S("5S`"P@=F%R:>%V
M96P@9&4@)7,@<&%R82`E<P`M+2!S96QE8VEO;F4@+2T`1F]R;6%T;R`Q,B!(
M;W)A<P!&;W)M871O(#(T($AO<F%S`#(T(&AO<F%S`#Q0X6=I;F$@06YT97)I
M;W(`56T@8V]N96-T;W(@9&4@8F%N8V\@9&4@9&%D;W,@Z2!O8G)I9V%T\W)I
M;R!P87)A(&5S=&4@8FQO8V\N`%5M(&5R<F\@9F%T86P@;V-O<G)E=0!5;6$@
M8VAA=F4@</IB;&EC82!01U`@Z2!O8G)I9V%T\W)I82!P87)A(&-R:7!T;V=R
M869A<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%!'4"#I(&]B
M<FEG873S<FEA('!A<F$@=F5R:69I8V%R('5M82!M96YS86=E;2!A<W-I;F%D
M82X`56UA(&-H879E('!R:79A9&$@4$=0(&4@=6UA('-E;FAA('/C;R!O8G)I
M9V%T\W)I87,@<&%R82!D97-C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+@!5
M;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S
M<FEA<R!P87)A(&%S<VEN87(@=6UA(&UE;G-A9V5M+@!5;6$@8VAA=F4@</IB
M;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M82!S
M96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@9&5S8W)I<'1O9W)A9F%R('5M
M82!M96YS86=E;2X`56UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@8VAA
M=F4@<')I=F%D82!3+TU)344@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA
M<R!P87)A(&%S<VEN87(@=6UA(&UE;G-A9V5M+@!5;6$@8VAA=F4@</IB;&EC
M82!3+TU)344@Z2!O8G)I9V%T\W)I82!P87)A(&-R:7!T;V=R869A<B!U;6$@
M;65N<V%G96TN`$YU=F5N<R!M871U=&EN87,`0VAU=F$@1G)A8V$@5F5S<&5R
M=&EN80!#:'5V82!M871U=&EN80!#:'5V87,@;6%T=71I;F%S`$YE=F%S8V%S
M($UA='5T:6YA<P!!32]030!!4$D@240`4V]B<F4@97-T92!E9&ET;W(`4V]B
M<F4N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V5S<V\@;F5G861O(&%O(&-R
M:6%R(&1I<F5T\W)I;R!61E,N`$%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q
M=6EV;R!61E,N`%-U87,@26YF;W)M8>?U97,`4V5N:&$@9&$@0V]N=&$`0V]N
M=&$@9&5S871I=F%D82X`0V]N=&%S`$'GXV\@<&%R82!E;F1E<F7G;W,@;F$@
M;&ES=&$@;F5G<F$Z`$%T:79A<B!2;W1I;F$`02!A=&EV8>?C;R!D;R!S8W)I
M<'0@<&%R82`B)7,B(&9A;&AO=2`H)60I("5S`$%D:6-I;VYA<@!!9&EC:6]N
M87(@1W)U<&\@4W5B;W)D:6YA9&\`061I8VEO;F%R(%!E<FUI<W/U97,@4W5B
M;W)D:6YA9&%S`$%D:6-I;VYE($%Q=6DZ`$%D:6-I;VYA<B!.;W9O($=R=7!O
M`$%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C;P!!9&EC:6]N87(@=6T@9W)U<&\@
M<W5B;W)D:6YA9&\@82`G)7,G`$%D:6-I;VYA<B!U;6$@<&5R;6ES<^-O('-U
M8F]R9&EN861A(&$@)R5S)P!!9&EC:6]N87(@=6T@;F]V;R!U<W7A<FEO.@!!
M9&EC:6]N87(@8V]L=6YA`$%D:6-I;VYA<B!N;W9O<R!M96UB<F]S`$%D:6-I
M;VYA<B!P87(`061I8VEO;F%R(&\@365N=2`E<R!C;VUO('5M82!"87)R82!,
M871E<F%L(&1O($UO>FEL;&$`061I8VEO;F%R(&%O(&-A=.%L;V=O(&1E(&5N
M9&5R9>=O<SH`061I8VEO;F%R(&%O(&UE=2!C873A;&]G;R!D92!E;F1E<F7G
M;W,`061I8VEO;F%R('5S=>%R:6\`)R5S)R!A9&EC:6]N861O(&%O('-I<W1E
M;6$L(&UA<R!NXV\@<'5D92!I;F-L=6ER(&EN9F]R;6'G]65S(&%D:6-I;VYA
M:7,@9&\@8V%D87-T<F\Z("5S+@`E<R!A9&EC:6]N861O(&%O('-I<W1E;6$N
M(%9O8^H@<&]D92!S92!C;VYE8W1A<B!A9V]R82X`061IY^-O(&1E('5S=>%R
M:6]S(&5S=.$@9&5S86)I;&ET861A+@!#;VYF:6=U<F'G]65S($%D:6-I;VYA
M:7,`16YD97)EYV\`0V%TX6QO9V\@9&4@16YD97)EYV]S`$%D;6EN:7-T<F%R
M("T@8V]N9FEG=7)A('!E<FUI<W/U97,@<&%R82!O=71R;W,@=7-UX7)I;W,`
M061M:6YI<W1R8>?C;P!!;OIN8VEO<P!!9F5G86YI<W3C;P!!;&+B;FEA`$%R
M9^ER:6$`07!E;&ED;P!!;&EN:&%R`$%L:6YH86UE;G1O.@!4;V1O<P!4;V1O
M<R!5<W7A<FEO<R!!=71E;G1I8V%D;W,`5&]D;W,@1W)U<&]S`%1O9&%S(%!E
M<FUI<W/U97,`5&]D;W,@<75A=')O(&QA9&]S`%1O9&]S(&]S('-E9W5I;G1E
M<P!.;W9A(%)E9W)A`%!E<FUI=&ER(&WZ;'1I<&QO<R!E;F1E<F7G;W,`4&5R
M;6ET:7(@8V]N9FEG=7)A<B!O('1I<&\@9&4@;&ES=&%S(&]R9&5N861A<S\`
M2N$@97AI<W1E`$QO9VEN($E-4U`@06QT97)N871I=F\`4V5N:&$@24U34"!!
M;'1E<FYA=&EV80!5<W7A<FEO($E-4U`@06QT97)N871I=F\`16YD97)EYV\@
M9&4@92UM86EL(&%L=&5R;F%T:79O`$UO9&5L;W,@86QT97)N871I=F]S`%1E
M>'1O(&%L=&5R;F%T:79O.@!386UO82!!;65R:6-A;F$`56T@=F%L;W(@:6QE
M9V%L(&9O:2!E<W!E8VEF:6-A9&\N`$]C;W)R974@=6T@97)R;R!D97-C;VYH
M96-I9&\N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`%!R;WAY(&%N]&YI;6\`
M4F5S<&]S=&$`4F5S<&]N9&ED80!!;G3A<G1I9&$`06YT:6=U82!E($)A<F)A
M9&]S`%%U86QQ=65R('5M(&1O<R!S96=U:6YT97,`07!L:6-AY^-O`$QI<W1A
M(&1E($%P;&EC8>?U97,`02!A<&QI8V'GXV\@97-TX2!P<F]N=&$N`$%P;&EC
M87(@1FEL=')O<P!!<&QI8V%R(&%O<R!#;VUP87)T:6QH86UE;G1O<R!3=6)O
M<F1I;F%D;W,`07!R;W9A<@!486UA;FAO($%P<F]X:6UA9&\`06)R:6P`07+A
M8FEC;R`H5VEN9&]W<RTQ,C4V*0!486UA;FAO(&1O($%R<75I=F\`3F]M92!D
M;R!!<G%U:79O`%9O8^H@=&5M(&-E<G1E>F$@<75E('%U97(@97AC;'5I<B!E
M<W1A(')E9W)A/P!6;V/J('1E;2!C97)T97IA('%U92!Q=65R(')E;6]V97(@
M82!S;VQI8VET8>?C;R!D92!C861A<W1R;R!D92`E<S\`5F]CZB!T96T@8V5R
M=&5Z82!Q=64@9&5S96IA(&5X8VQU:7(@)R5S)R!E('-E=7,@<W5B9W)U<&]S
M/P!!<F=E;G1I;F$`07)MZFYI80!!<FWJ;FEO("A!4DU30TE)+3@I`$%R=&4`
M07)U8F$`26QH82!!<V-E;G/C;P!!<G1E($%S8VEI`,%S:6$O4F5G:>-O(&1O
M(%!A8^UF:6-O`%-O;&EC:71A<B!C;VYF:7)M8>?C;R!A;G1E<R!D92!E>&5C
M=71A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;S\`0V]L=6YA<R!D92!D
M97-I9VYAY^-O`%1E;G1O=2!E>&-L=6ER('5M(&=R=7!O(&EN97AI<W1E;G1E
M+@!496YT;W4@97AC;'5I<B!U;6$@<&5R;6ES<^-O(&[C;R!E>&ES=&5N=&4N
M`%1E;G1O=2!E9&ET87(@=6UA('!E<FUI<W/C;R!NXV\@97AI<W1E;G1E+@!4
M96YT;W4@961I=&%R('5M(&-O;7!A<G1I;&AA;65N=&\@;N-O(&5X:7-T96YT
M92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<N%L:6$`P75S=')I80!!=71H7V-Y
M<G-Q;#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:6UA<"!N96-E
M<W/A<FEA+@!!=71H7V-Y<G5S.B!/(&-O;F5C=&]R(&[C;R!P;W-S=6D@87,@
M8V%P86-I9&%D97,@;F5C97-SX7)I87,N`$%U=&A?8WER=7,Z($[C;R!F;VD@
M96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82X`075T:%]F
M='`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($944"!N96-E<W/A
M<FEA+B!#;VUP:6QE(&\@4$A0(&-O;2!A(&]PY^-O("TM96YA8FQE+69T<"X`
M075T:%]I;6%P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I;6%P
M(&YE8V5S<^%R:6$N`$%U=&A?:W)B-3H@3N-O(&9O:2!E;F-O;G1R861A(&$@
M97AT96YSXV\@:W)B-2!N96-E<W/A<FEA+@!!=71H7VQD87`Z($EN8VQU<^-O
M(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!%>&-L=7/C;R!D92!U<W7A<FEO<R!NXV\@Z2!S
M=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@3N-O
M(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA+@!!
M=71H7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R(&\@=7-UX7)I;R`E<RX@
M27-T;R!F;VD@;R!Q=64@;R!S97)V:61O<B!R97!O<G1O=3H@`$%U=&A?;&1A
M<#H@26UP;W-S[79E;"!R96UO=F5R(&\@=7-UX7)I;R`E<P!!=71H7VQD87`Z
M($EM<&]S<^UV96P@871U86QI>F%R(&\@=7-UX7)I;R`E<P!!=71H7VQD87`Z
M($%T=6%L:7IAY^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A
M($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@3N-O(&9O:2!E;F-O;G1R
M861A(&$@97AT96YSXV\@34-!3"!N96-E<W/A<FEA+@!!=71H7W-M8F%U=&@Z
M($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O('-M8F%U=&@@;F5C97-S
MX7)I82X`075T96YT:6-AY^-O(&YO('-E<G9I9&]R($E-05`@9F%L:&]U+@!&
M86QH82!N82!A=71E;G1I8V'GXV\`1F%L:&$@;F$@875T96YT:6-AY^-O.B`E
M<P!!=71E;G1I8V'GXV\@<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$2553
M+@!!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U+@!!(&%U
M=&5N=&EC8>?C;R!N;R!S97)V:61O<B!334(@9F%L:&]U+@!!='5A;&EZ87(@
M875T;VUA=&EC86UE;G1E(&$@<F]T:6YA(&1E<&]I<R!D92!C861A(&%L=&5R
M8>?C;S\`0V%M<&]S(&1I<W!O;NUV96ES.@!!>F5R8F%I:N-O`$1E<V-U;'!A
M<R!D;R!"3T9(`$9U;F1O`$-O<B!D92!&=6YD;P!396YH82!K97)B97)O<R!I
M;F-O<G)E=&$N`%5S=>%R:6\@:V5R8F5R;W,@:6YC;W)R971O+@!"86AA;6%S
M`$)A:')A:6X`0N%L=&EC;R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R
M8F%D;W,`3N-O(&9O:2!E;F-O;G1R861O(&\@9&ER973S<FEO(&)A<V4@9&4@
M:6UA9V5N<R`G)7,G+@!,:6YH82!D92!087)T:61A`$-C;P!#;VUEYV$@8V]M
M`$)E;&]R^G-S:6$`0NEL9VEC80!"96QI>F4`0F5N:6X`0F5R;75D87,`0G5T
MXV\`1F%L:&$@;F$@875T96YT:6-AY^-O.B`H)7,I("5S`$%N:79E<G/A<FEO
M`$QI<W1A($YE9W)A`$5D:71A<B!,:7-T82!.96=R80!,:7-T82!.96=R82!N
MXV\@Z2!S=7!O<G1A9&$@<&5L;R!C;VYE8W1O<B!D92!F:6QT<F\@871U86PN
M`$5N9&5R9>=O<R!N82!,:7-T82!.96=R80!.XV\@9F]I(&5N8V]N=')A9&\@
M;R!B;&]C;R`B)7,B(&1A(&%P;&EC8>?C;R`B)7,B+@!#;VYF:6=U<F'G]65S
M(&1O($)L;V-O`%1I<&\@9&4@0FQO8V\`0V]R<&\`3F5G<FET;P!";VSM=FEA
M`$9A=F]R:71O<P!";W)D80!,87)G=7)A(&1A(&)O<F1A.@!";W)D87,`0O-S
M;FEA(&4@2&5R>F5G;W9I;F$`06UB;W,`0F]T<W5A;F$`4F]D87#I`$EL:&$@
M0F]U=F5T`$)R87-I;`!497)R:73S<FEO(&1O($]C96%N;R#-;F1I8V\@26YG
M;.IS`$)R=6YE:0!"=6QGX7)I80!,:7-T82!C;VT@36%R8V%D;W)E<P!"=7)K
M:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`%!O;G1O<R!D92!$:7-T<FEB=6GG
MXV\@0U),`%!R;W!R:65D861E<R!D82!#Z5]L=6QA+BXN`$$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861A+@!!9V5N9&$`0V%L
M;6\`0V%M8F]D:F$`0V%M87+U97,`3N-O(.D@<&]S<^UV96P@9V5R87(@=6UA
M(&YO=F$@<V5N:&$@875T;VUA=&EC86UE;G1E+"!E;G1R92!E;2!C;VYT871O
M(&-O;2!O(&%D;6EN:7-T<F%D;W(N`$[C;R!C;VYS:6=O(&=R879A<B!O(&%R
M<75I=F\@(B5S(@!.XV\@Z2!P;W-S[79E;"!A9&UI;FES=')A<B!G97)E;F-I
M861O<F5S(&5X=&5R;F]S(&1E('-E<W/C;RX`3N-O(.D@<&]S<^UV96P@8V]N
M96-T87(@86\@<V5R=FED;W(@24U!4#H@)7,`3N-O(&-O;G-I9V\@86)R:7(@
M;R!A<G%U:79O("(E<R(N`$-A;F%DX0!#86YC96QA<@!#86YC96QA<B!296QA
M=/-R:6\@9&4@4')O8FQE;6$`3N-O(.D@<&]S<^UV96P@97AC;'5I<B!O(&%R
M<75I=F\@(B5S(BX`3N-O(.D@<&]S<^UV96P@96YC;VYT<F%R('5M(&1I<F5T
M\W)I;R!T96UP;W+A<FEO+@!.XV\@Z2!P;W-S[79E;"!C;VYT:6YU87(@<V5M
M(&\@<&%RXFUE=')O("=T87)G971&:6QE)RX`3N-O(.D@<&]S<^UV96P@97AC
M;'5I<B!O(&1I<F5T\W)I;R`B)7,B+@!.XV\@Z2!P;W-S[79E;"!E>&-L=6ER
M+"`E9"!P;W-S=6D@<W5B;W)D:6YA9&]S+@!.XV\@Z2!P;W-S[79E;"!R96]R
M9&5N87(L(&[Z;65R;R!D92!R96=I<W1R;W,@9F]R;F5C:61O<R!P87)A(')E
M;W)D96YA<B!NXV\@8V]R<F5S<&]N9&4@86\@;OIM97)O(&%R;6%Z96YA9&\N
M`$[C;R#I('!O<W/M=F5L(')O=&5A<B!M96YS86=E;2!P87)A(&\@;OIM97)O
M(&5S<&5C:69I8V%D;RX`0V%B;R!697)D90!4[71U;&\`3W!E<F%D;W)A`%-E
M;G/M=F5L(.`@0V%I>&$`0V%T96=O<FEA<R!E($YO;65S`$EL:&%S($-A>6UA
M;@!#8P!496QE9F]N92!#96QU;&%R`%!R;W!R:65D861E<R!D82!#Z6QU;&$`
M36%R9V5M(&1A(&/I;'5L83H`4')O<')I961A9&5S(&1A($/I;'5L80!%<W!A
MYV%M96YT;R!D82!CZ6QU;&$Z`%1E;&5F;VYE(&-E;'5L87(`0^EL=&EC;R`H
M25-/+3@X-3DM,30I`$-E;G1R;P!297#Z8FQI8V$@9&$@P69R:6-A($-E;G1R
M86P`175R;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I`$1E=&%L:&5S(&1O($-E
M<G1I9FEC861O`%!R;W!R:65TX7)I;R!D;R!#97)T:69I8V%D;P!0;VSM=&EC
M87,@9&\@0V5R=&EF:6-A9&\`5&-H861E`$%L=&5R87(`06QT97)E(%-U82!3
M96YH80!!;'1E<F%R(&\@;F]M92!E(&\@96YD97)EYV\@<75E(&%S('!E<W-O
M87,@=NIE;2!Q=6%N9&\@96QA<R!LZF5M(&4@<F5S<&]N9&5M('-U87,@;65N
M<V%G96YS+@!!;'1E<F'G]65S('-A;'9A<RX`06QT97)AY^-O(&1E('-E;FAA
M(&[C;R#I('-U<&]R=&%D82!N82!C;VYF:6=U<F'GXV\@871U86PN("!%;G1R
M92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(N`$-H87(`5F5R:69I
M8V%R($QI;E]K+BXN`$-H:6QE`$-H:6YA`$-H:6[J<R!3:6UP;&EF:6-A9&\@
M*$=",C,Q,BD`0VAI;NIS(%1R861I8VEO;F%L("A":6<U*0!%<V-O;&AA(&$@
M07!L:6-AY^-O.@!%<V-O;&AA('5M82!S96YH80!%<V-O;&AA('5M('5S=>%R
M:6\`17-C;VQH82!C;VUO(&5X:6)I<B!D871A<SH`17-C;VQH82!O('1I<&\@
M9&4@97-T:6QO(&1E(&QI<W1A<R`H<&%R82!L:7-T87,@;W)D96YA9&%S*0!)
M;&AA<R!#:')I<W1M87,`3N-O(&9O:2!E;F-O;G1R861A(&$@9&5F:6YIY^-O
M(&1E(&-L87-S92!D92`E<RX`3&EM<&%R`$QI;7!A<B!T86=S($U33V9F:6-E
M`$5X8VQU:7(@=7-UX7)I;P!%>&-L=6ER('5S=>%R:6\Z("5S`$5X8VQU:7(@
M=7-UX7)I;P!%>&-L=6ER(&1A9&]S(&1O('5S=>%R:6\`0^EU(&%B97)T;R!A
M(%1A<F1E`$-L:7%U92!P87)A($-O;G1I;G5A<@!#;&EC:V%T96QL('9I82!(
M5%10`$9E8VAA<B!*86YE;&$`3G5V96YS`$YU8FQA9&\@<&5L82!-86YHXP!.
M=6)L861O`$EL:&%S(&1E($-O8V]S`$-O;G1R86ER($)A<G)A($QA=&5R86P`
M0V]N=')A:7(@8F]R9&%S`$-O;/1M8FEA`$-O<@!086QH971A(&1E($-O<F5S
M`%-E;&7GXV\@9&4@0V]R`$-O;',Z`%3M='5L;W,@9&%S($-O;'5N87,`475A
M9')I;FAO<P!#;VUA;F1O`$QI;FAA(&1E($-O;6%N9&\`0V]M96YT87(`3F]M
M90!#;VUO<F]S`$5M<')E<V$`0V]M<'5T861O<F5S`$-O;F1IY^-O`$-O;F1I
MY_5E<P!$:69E<F5NYV%S(&1E($-O;F9I9W5R8>?C;P!#;VYF:6=U<F'GXV\@
M9&4@<VEN8W)O;FEZ8>?C;R!C;VT@4$1!<RP@4VUA<G1P:&]N97,@92!/=71L
M;V]K+@!#;VYF:6=U<F'GXV\@;F5C97-S:71A(&1E(&%T=6%L:7IAY^-O+@!#
M;VYF:6=U<F%R("5S`$-O;F9I<FUE(&$@4V5N:&$`0V]N9V\`0V]N9V\L(%)E
M</IB;&EC82!$96UO8W+A=&EC82!D;P!&86QH82!N82!C;VYE>.-O+@!&86QH
M82!N82!C;VYE>.-O.B``1F%L:&$@;F$@8V]N97CC;P!#;VYE>.-O(')E8W5S
M861A('!E;&\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!#;VYE>.-O
M(')E8W5S861A('!E;&\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+B!-
M;W1I=F\Z("5S("@E<RD`02!C;VYE>.-O(&%O('-E<G9I9&]R($944"!F86QH
M;W4N`$-O;G1A=&]S`$]S(&-O;G1A=&]S(&9O<F%M(&%D:6-I;VYA9&]S(&-O
M;2!S=6-E<W-O(&%O('-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,N`$-O;G3I
M;0!4:7!E(&1E(&-O;G1E^F1O(&1O(&%R<75I=F\@8V]M<')I;6ED;SH@`$-O
M;G1E^F1O(&1E("<E<R<`0V]N=&EN=6%R`$EL:&%S($-O;VL`0V]O:VEE`$-O
M<&EA<@!#;W!I87(@)7,`1F%L:&$@;F$@8_-P:6$Z("5S`$-O<&EA<B!D92`E
M<P!#;W!I87(@<V5L9>?C;P!)1"!D92!#=7-T;P!#;W-T82!2:6-A`$-O<W1A
M(&1O($UA<F9I;0!);7!O<W/M=F5L(&-R:7!T;V=R869A<B!A(&UE;G-A9V5M
M(&-O;2!01U`Z(`!);7!O<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@
M4$=0.B``3N-O(&9O:2!P;W-S[79E;"!C<FEP=&]G<F%F87(@82!M96YS86=E
M;2!C;VT@4R]-24U%+@!.XV\@9F]I('!O<W/M=F5L(&%S<VEN87(@82!M96YS
M86=E;2!C;VT@4R]-24U%+@!.XV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA<B!C
M;VYT871O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I
M9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@=F5R:69I8V%R(&\@<V%L9&\N
M("5S`$EM<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@3$1!4"X`3N-O
M(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B`G)7,G('5T:6QI
M>F%N9&\@1E10.B`E<P!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@;&ES=&$@
M9&4@9&ES=')I8G5IY^-O+B`E<P!);7!O<W/M=F5L(&1E<V-R:7!T;V=R869A
M<B!O<R!D861O<R!01U`Z(`!.XV\@9F]I('!O<W/M=F5L(&1E<V-R:7!T;V=R
M869A<B!O(&1A9&\@4R]-24U%+@!.XV\@9F]I('!O<W/M=F5L(&5X8VQU:7(@
M;R!C;VYT871O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&5X8VQU:7(@82!L:7-T
M82!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I
M<B!O('-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@)R5S
M)RX`3N-O(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&\@96YD97)EYV\@9&4@
M92UM86EL(&1O(&1E<W1I;F%TX7)I;RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E
M<B!C;VUP;&5T86UE;G1E(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S+@!.XV\@
M9F]I('!O<W/M=F5L(&]B=&5R(&-O;7!L971A;65N=&4@82!L:7-T82!D92!D
M:7-T<FEB=6GGXV\N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M
M96YT92!A(&QI<W1A(&1E(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N`$[C;R!F
M;VD@<&]S<^UV96P@8V%R<F5G87(@82!E<W1R873I9VEA("<E<R<N`$[C;R!F
M;VD@<&]S<^UV96P@8W)I87(@;R!D:7)E=/-R:6\@)R5S)RX`3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!A(&-H879E('#Z8FQI8V$@82!P87)T:7(@9&\@<V5R
M=FED;W(@9&4@8VAA=F5S+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER("<E<R<@
M<&%R82!G<F%V8>?C;RX`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B`E<RX`3N-O
M(&9O:2!P;W-S[79E;"!A8G)I<B!O(&WS9'5L;R`G36%I;G1E;F%N8V5?5&%S
M:R<@)7,`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&1I<F5T\W)I;R`G)7,G
M+@!.XV\@9F]I('!O<W/M=F5L('!E<W%U:7-A<B!N;R!S97)V:61O<B!,1$%0
M+@!.XV\@9F]I('!O<W/M=F5L(&QE<B`E<RX`3N-O(&9O:2!P;W-S[79E;"!G
M97)A<B!U;6$@;F]V82!S96YH82!P87)A(&\@=7-UX7)I;R!S;VQI8VET861O
M+B!!;&=U;G,@;W4@=&]D;W,@;W,@9&5T86QH97,@;N-O(&5S=.-O(&-O<G)E
M=&]S+B!496YT92!N;W9A;65N=&4@;W4@96YT<F4@96T@8V]N=&%T;R!C;VT@
M;R!A9&UI;FES=')A9&]R('-E('9O8^H@;F5C97-S:71A(&1E(&UA:7,@86IU
M9&$N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!!0TP`3N-O(&9O:2!P;W-S
M[79E;"!O8G1E<B!O(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RX@)7,`3N-O(&9O
M:2!P;W-S[79E;"!O8G1E<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`
M3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A<R!L:7-T87,@9&4@9&ES=')I8G5I
MY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&-A<&%C:61A9&5S
M(&1O('-E<G9I9&]R`$[C;R!F;VD@<&]S<^UV96P@<F5V97)T97(@82!C;VYF
M:6=U<F'GXV\N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&1I<F5T\W)I
M;R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!A(&-O;F9I9W5R8>?C
M;R`E<RX`3N-O(&9O:2!P;W-S[79E;"!S86QV87(@=6T@8F%C:W5P(&1A(&-O
M;F9I9W5R8>?C;RX`3N-O(&9O:2!P;W-S[79E;"!S86QV87(@=6T@8F%C:W5P
M(&1A(&-O;F9I9W5R8>?C;SH@)7,`3N-O(&9O:2!P;W-S[79E;"!S86QV87(@
M;R!S8W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O(&5M.B`G
M)7,G+@!.XV\@8V]N<V5G=6D@<V%L=F%R(&\@8F%C:W5P(&1O(&%R<75I=F\@
M9&4@8V]N9FEG=7)AY^-O("5S+@!.XV\@8V]N<V5G=6D@<V%L=F%R(&\@87)Q
M=6EV;R!D92!C;VYF:6=U<F'GXV\@)7,N(%9O8^H@<&]D92!O=2!U=&EL:7IA
M<B!U;6$@9&%S(&]PY_5E<R!P87)A('-A;'9A<B!O(&/S9&EG;R!D92!V;VQT
M82!E;2`E<R!O=2!C;W!I87(@;6%N=6%L;65N=&4@;R!C\V1I9V\@86)A:7AO
M('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV96P@<&5S<75I<V%R(&YO('-E<G9I
M9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&QI;FL@)R5S
M)RX`3N-O(&9O:2!P;W-S[79E;"!A='5A;&EZ87(@;R!C;VYT871O+B`E<P!.
MXV\@9F]I('!O<W/M=F5L(&%T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U
M:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!G<F%V87(@82!C;VYF:6=U<F'G
MXV\@9&4@)R5S)SH@)7,`3N-O(&9O:2!P;W-S[79E;"!E;F-O;G1R87(@82!"
M87)R82!,871E<F%L(&1O($UO>FEL;&$N($-E<G1I9FEQ=64M<V4@<75E(&5L
M82!E<W3A(&%B97)T82X`3N-O(&9O:2!P;W-S[79E;"!D87(@86\@=7-UX7)I
M;R`E<R!O<R!S96=U:6YT97,@9&ER96ET;W,@<&%R82!A('!A<W1A("<E<R<Z
M("5S`%1E>'1O(&-O;G1A9&\`4&'M<P!#=7)S;W,`0W)I87(`0W)I87(@=6T@
M;&EN:P!#<FEA<B!U;6$@;F]V80!#<FEA<B!N;W9A('!A<W1A`$-R:6%R('-U
M8B!P87-T87,`4&5R;6ES<_5E<R!D;R!C<FEA9&]R`$[Z;65R;R!D;R!C87)T
MXV\@9&4@8W+I9&ET;P!#<F_A8VEA`$-U8F$`-"!&87-E<R!!='5A:7,`4V5S
M<_5E<R!!='5A:7,`2&]R82!!='5A;`!!(%523"!A='5A;"#I`%5S=>%R:6]S
M(&YO(&UO;65N=&\`0VQI;6$@071U86P`0V]N9&GGXV\@871U86PZ(`!%<W1I
M;&\@871U86P`0W5S=&]M:7IA('1A<F5F87,@82!S97)E;2!E>&5C=71A9&%S
M(&%O(&-O;F5C=&%R(&$@)7,N`$-O<G1A<@!#;W)T87(@<V5L9>?C;P!#:&EP
M<F4`0VER[6QI8V\@*$M/23@M4BD`0VER[6QI8V\@*%=I;F1O=W,M,3(U,2D`
M0VER[6QI8V\O56-R86YI86YO("A+3TDX+54I`%)E</IB;&EC82!48VAE8V$`
M1$0`1$53051)5D%$03H@`$133B`H=F5J82!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M`$1I87)I86UE;G1E`$YA=F5G861O<B!D92!$871A5')E90!097-Q=6ES82!N
M;R!"86YC;R!D92!$861O<P!$871A`$1A=&$@9&4@4F5C96)I;65N=&\`4V5L
M9>?C;R!D92!D871A`$1I80!%7WAC;'5I<B!#;VQU;F$`1&5S871I=F%R(%)O
M=&EN80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E8W5A<B!)9&5N=&'G
MXV\`4&%D<N-O`$-O<B!0861RXV\`261E;G1I9&%D92!0861RXV\`4VAE;&P@
M4&%D<N-O`$1E9FEN:>?U97,`17AC;'5I<@!%>&-L=6ER("5S`$5X8VQU:7(@
M8^EL=6QA`$5X8VQU:7(@0V]N9&GGXV\`17AC;'5I<B!'<G5P;P!%>&-L=6ER
M($QO9P!%>&-L=6ER(%!E<FUI<W/C;P!%>&-L=6ER(&4@<'5R9V%R(&UE;G-A
M9V5N<P!%>&-L=6ER(&/I;'5L80!%>&-L=6ER(&-O;'5N80!%>&-L=6ER(&UO
M9&5L;R!S=6)S=&ET=71O(&5X:7-T96YT90!%>&-L=6ER(&UE;G-A9V5M(&-O
M;7!L971A;65N=&4`17AC;'5I<B!P97)M:7-S]65S('!A<F$@)R5S)P!%>&-L
M=6ER('!E<FUI<W/U97,@<&%R82`G)7,G(&4@<75A;'%U97(@;W5T<F$@<W5B
M+7!E<FUI<W/C;S\`17AC;'5I<B!L:6YH80!%>&-L=6ER(&ED96YT:61A9&4@
M<V5L96-I;VYA9&$`17AC;'5I<B!A(&-O;'5N82!A='5A;`!%>&-L=6ER(&$@
M;&EN:&$@871U86P`17AC;'7M9&$`4V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E
M(&-O;F9I9W5R8>?C;R`G)7,G(&5X8VQU[61O+@!%;G1R96=A<B!N82!M:6YH
M82!#86EX82!D92!%;G1R861A`$5N=')E9V%R(&YA(&UI;FAA($-A:7AA(&1E
M($5N=')A9&$@92!C;W!I87(@<&%R80!%;G1R96=A<B!N82!M:6YH82!#86EX
M82!D92!%;G1R861A(&4@<F5D:7)E8VEO;F%R('!A<F$`16YT<F5G87(@;F$@
M<&%S=&$`2&]R82!D92!E;G1R96=A`$1I;F%M87)C80!$97-C<F5V82!O('!R
M;V)L96UA`$1E<V-R:>?C;P!$971A;&AE<R`H=&%M8NEM(&YO(')E9VES=')O
M(&1E(&%T:79I9&%D97,@9&\@2&]R9&4I.@!/<R!D971A;&AE<R!F;W)A;2!G
M<F%V861O<R!E;2!L;V<@<&%R82!O(&%D;6EN:7-T<F%D;W(N`$1E<V5N=F]L
M=FEM96YT;P!0;VYT;R!D92!/<G9A;&AO`%!O;G1O(&1E($]R=F%L:&\@<&%R
M82!A(/IL=&EM82!H;W)A.B``4&]N=&\@9&4@3W)V86QH;SH@`$1I<F7GXV\@
M9&$@97-Q=65R9&$@<&%R82!D:7)E:71A`$1I<F7GXV\@9&$@9&ER96ET82!P
M87)A(&5S<75E<F1A`$1I<F5T\W)I;P!$97-A=&EV87(@)7,@`$1E<V%T:79A
M9&\`17AI8FER(&5M(&9O<FUA=&\@,C0@:&]R87,_`$]PY_5E<R!D92!%>&EB
M:>?C;P!%>&EB:7(@<')E=FESXV\@9&5T86QH861A`$5X:6)I<B!N;W1I9FEC
M8>?C;R!D971A;&AA9&$@<75A;F1O(&-A9&$@9FEL=')O(&9O<B!A<&QI8V%D
M;S\`17AI8FER('!R979I<^-O("A4048I`$5X:6)I<B!F;W)M871O`$YO=&EF
M:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!?3N-O(&5N=FEA<B!R97-P
M;W-T87,@<&%R82!M96YS86=E;G,@96T@;6%S<V$@;W4@;&ES=&%S(&1E(&UE
M;G-A9V5N<P!.XV\@97AC;'5I<@!.XV\@86-E<W-E(&1I<F5T86UE;G1E(&UA
M:6YT96YA;F-E+G!H<`!&8>=A(&ES=&\Z`$$@<')I;65I<F$@;&EN:&$@8V]N
M=.EM(&]S(&YO;65S(&1O<R!C86UP;W,_(%-E('-I;2P@8VQI<75E(&YE<W1A
M(&-A:7AA.@!.XV\@8V]M9>=A(&-O;0!.XV\@8V]N=.EM`$[C;R!T97)M:6YA
M(&-O;0!.XV\@97AI<W1E`$[C;R!C;W)R97-P;VYD92!A("AC;VT@8V]R:6YG
M87,I`$1O;6EN:6-A;F$`4F5P^F)L:6-A($1O;6EN:6-A;F$`3N-O('1E;2!U
M;6$@8V]N=&$_($-A9&%S=')E+7-E+@!"86EX87(`0F%I>&%R("5S`$)A:7AA
M<B!A(&-O;F9I9W5R8>?C;R!G97)A9&$@8V]M;R!U;2!S8W)I<'0@4$A0+@!,
M:7-T82!D92!S96QEY^-O`$1R;V=A<P!#;W)R96EO`$-O;F5C=&]R(&1O(&=A
M=&5W87D@14UA:6PM<&%R82U335,L('!A<F$@;W!E<F%D;W)A<R!Q=64@9&ES
M<&]N:6)I;&EZ86T@97-T92!S97)V:>=O+@!%4E(`17%U861O<@!%9&ET87(`
M161I=&%R("5S`$5D:71A<B!";&]C;P!%9&ET87(@1W)U<&\`161I=&%R(%!E
M<FUI<W/C;P!%9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@4&5R;6ES<_5E<R!P
M87)A("5S`$5D:71A<B!O<.?U97,@9&4Z`$5D:71A<B!P97)M:7-S]65S('!A
M<F$@)7,`161I=&%R('!E<FUI<W/U97,@<&%R82`E<P!%9'5C8>?C;P!%9VET
M;P!%;"!386QV861O<@!%;&5M96YT;RXN+@!%;0!%+6UA:6P`16YD97)EYV\@
M9&4@12U-86EL`$\@96YD97)EYV\@9&4@92UM86EL(&1E=F4@8V]R<F5S<&]N
M9&5R+@!-96YS86=E;2!C;VT@8V]N9FER;6'GXV\`1V%T97=A>2!D92!%36%I
M;"UP87)A+5--4P!%;6]T:6-O;G,`365N<V%G96T@96T@8G)A;F-O+@!297-U
M;'1A9&\@96T@8G)A;F-O+@!497)M;W,@9&4@<&5S<75I<V$@96T@8G)A;F-O
M`$AA8FEL:71A<B`E<P!(86)I;&ET87(@:6YS97+GXV\@9&4@:6UA9V5N<R!A
M('!A<G1I<B!D82!'86QE<FEA(&1E($EM86=E;G,@;F\@=&5X=&\_`$AA8FEL
M:71A<B!M96YU(&1E(&-O;G1E>'1O(&-O;2!O(&)O=.-O(&1I<F5I=&\_`$AA
M8FEL:71A9&\`1FEN86P@9&\@86YO`%1E<FUI;F$@8V]M`$%U;65N=&%R($5D
M:71O<@!&;W)N9>=A('5M82!P97)G=6YT82!D92!S96=U<F%NYV$@82!Q=6%L
M('9O8^H@<V5RX2!P97)G=6YT861O('-E('9O8^H@;F5C97-S:71A<B!G97)A
M<B!U;6$@;F]V82!S96YH82P@97@N("=Q=6%L(&\@;F]M92!D;R!S974@8V%C
M:&]R<F\_)SH`1F]R;F7G82!A(%523"!D82!I;6%G96T@87%U:0!$:6=I=&4@
M87,@;&5T<F%S(&%B86EX;SH`26=U86P@80!'=6ENZ2!%<75A=&]R:6%L`$5R
M:71RZ6EA`$5R<F\`17)R;R!A;R!C<FEA<B!B;&]C;SH@)7,`17)R;R!A;R!E
M>&-L=6ER(.)N8V]R82!D92!S:6YC<F]N:7IAY^-O.B`E<P!%<G)O(&%O(&5X
M8VQU:7(@;&]G(&1E('-I;F-R;VYI>F'GXV\Z("5S`$5R<F\@86\@;V)T97(@
M8V]N=&7Z9&\Z("5S`$5R<F\@86\@;V)T97(@;R!S8W)I<'0@871U86PZ("@E
M9"D@)7,`17)R;R!A;R!S86QV87(@86QT97)AY_5E<RX`17)R;R!A;R!A='5A
M;&EZ87(@82!S96YH83H@)7,`17)R;R!N82!M96YS86=E;2X`17)R;R!G<F%V
M86YD;R`G)7,G+@!%<W3T;FEA`$5T:?-P:6$`R71N:6-O`$5U<F]P80!#861A
M(#$U(&UI;G5T;W,`0V%D82`R(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#
M861A(#4@;6EN=71O<P!#861A($-O;F5XXV\`0V%D82!M96EA(&AO<F$`0V%D
M82!M:6YU=&\`5F%L;W)E<R!D92!E>&5M<&QO.@!%>&5C=71A<@!296=R87,@
M17AI<W1E;G1E<P!%>&ES=&4`17AP86YD:7(`17AP86YD:7(@0F%R<F$@3&%T
M97)A;`!%<W!E<F%D;R`G*2<`,2!O8FIE=&\@97-P97)A9&\L(&]B=&ED;W,@
M)60N`$5S<&5R861O('5M82!P86QA=G)A(&]U('1E<FUO(&1E('!E<W%U:7-A
M(&5N=')E(&%S<&%S`$1A=&$@9&4@17AP:7)AY^-O`$5X<&]E;G1E`$-O<B!D
M;R!P<FEM96ER;R!P;&%N;P!#;VYF:6=U<F'GXV\@9&4@96YV:6\@9&4@87)Q
M=6EV;W,@1E10`$9A;&AA(&]B=&5N9&\@<')E9F5RZFYC:6%S+@!&86QH82!A
M;R!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+@!&86QH82!A;R!C;VYE8W1A
M<B!A;R!S97)V:61O<B!334(N`$9A;&AA(&%O(&-O<&EA<B!D92`B)7,B+@!&
M86QH82!A;R!C;W!I87(@<&%R82`B)7,B+@!&86QH82!A;R!C<FEA<B!U;6$@
M;F]V82!C;VYE>.-O(%-!4TPN`$9A;&AA(&%O(&UO=F5R('!A<F$@(B5S(BX`
M1F%L:&$@86\@;V)T97(Z("5S`$IU<W1O`$EL:&%S($9A;&ML86YD("A-86QV
M:6YA<RD`26QH87,@1F%R;V4`17)R;R!&871A;#H`1F%X`$9A>&5S`$9E=F5R
M96ER;P!396YS8>?C;R!4Z7)M:6-A`%-E;G-AY^-O('3I<FUI8V$Z(`!086YC
M861A<R!D92!#:'5V80!.979E($9R86-A`$UA=')I>B!D;R!C86UP;P!&:6=L
M970@0T%05$-(00!&;VYT92!&:6=L970`1FEJ:0!A<G%U:79O`$-O;G1A9V5M
M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O`$-O;G1A9V5M(&1E($%R<75I=F]S
M.B`E<R!A<G%U:79O<P!'97)E;F-I861O<B!D92!!<G%U:79O<P!.;VUE(&1O
M($%R<75I=F\`4V5L9>?C;R!D92!A<G%U:79O`$5N=FEO(&1E(&%R<75I=F\`
M16YV:6\@9&4@87)Q=6EV;W,@;N-O(.D@<W5P;W)T861O+@!&:6QT<F%R(%1O
M9&%S($UE;G-A9V5N<P!&:6QT<F%R(%-O;65N=&4@365N<V%G96YS($QI9&%S
M`$9I;'1R87(@4V]M96YT92!-96YS86=E;G,@3N-O($QI9&%S`$]PY_5E<R!D
M92!&:6QT<F\`4F5G<F$@9&\@1FEL=')O`%)E9W)A<R!D92!&:6QT<F\`17AI
M8FGGXV\@9&$@4F]T:6YA(&1O($9I;'1R;P!?4F5G<F%S(&1E($9I;'1R;P!!
M=&EV:61A9&4@9&\@1FEL=')O.B`E<R!M96YS86=E;2AN<RD@8V]P:6%D82AS
M*2!P87)A(&$@<&%S=&$@(B5S(BX`071I=FED861E(&1O($9I;'1R;SH@)7,@
M;65N<V%G96TH;G,I(&5X8VQU[61A*',I+@!!=&EV:61A9&4@9&\@1FEL=')O
M.B`E<R!M96YS86=E;2AN<RD@;6]V:61A*',I('!A<F$@82!P87-T82`B)7,B
M+@!!=&EV:61A9&4@9&\@1FEL=')O.B`E<R!M96YS86=E;2AN<RD@<75E(&-O
M<G)E<W!O;F1E=2AR86TI(&$@;&ES=&$@;F5G<F$@9F]I*')A;2D@97AC;'7M
M9&$H<RDN`$%T:79I9&%D92!D;R!F:6QT<F\Z($$@;65N<V%G96T@(B5S(B!D
M92`B)7,B(&9O:2!C;W!I861A('!A<F$@82!P87-T82`B)7,B+@!!=&EV:61A
M9&4@9&\@1FEL=')O.B!!(&UE;G-A9V5M("(E<R(@9&4@(B5S(B!F;VD@97AC
M;'7M9&$N`$%T:79I9&%D92!D;R!&:6QT<F\Z($$@;65N<V%G96T@(B5S(B!D
M92`B)7,B9F]I(&UO=FED82!P87)A(&$@<&%S=&$@(B5S(BX`1FEL=')O(&[C
M;R!E;F-O;G1R861O+@!&:6QT<F]S`$9I;FSB;F1I80!0<FEM96ER82!-971A
M9&4`4')I;65I<F\@475A<G1O`%1A>&$@9FEX80!':7)A<@!$:7-P;W-IY^-O
M`$[I=F]A`%!A<W1A("5S(&[C;R!E>&ES=&4`0V]R(&1A($9O;G1E`$-O;6ED
M80!087)A('5M82!N;W9A(&UE;G-A9V5M('%U92!C;W)R97-P;VYD83H`4&%R
M82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R=&%M(&EM86=E;G,`4')E=FES
MXV\@*%1!1BD`1&EA<R!0<F5V:7-T;W,@*$YO=&4@<75E(&$@<')E=FESXV\@
M<F5T;W)N861A(&5X:6)E(&%M8F]S(&1I82!E(&YO:71E.R!U;2!N^FUE<F\@
M;75I=&\@86QT;R!A<75I('!O9&4@<F5S=6QT87(@96T@=6T@8FQO8V\@97AT
M96YS;RD`17-Q=65C974@82!S96YH83\`1F]R;75LX7)I;W,`4V]R=&4`5&EP
M;R!D92!3;W)T90!3;W)T97,`4V]R=&5S(#(`1O-R=6YS`$5N8V%M:6YH87(`
M16YC86UI;FAA;65N=&\@;N-O(.D@<W5P;W)T861O('!E;&\@9')I=F5R(&1E
M(&9I;'1R;R!A='5A;"X`4F5D:7)E8VEO;F%M96YT;W,`161I=&%R(%)E9&ER
M96-I;VYA;65N=&]S`%-E>`!1=6%D<F]S`$9R86[G80!&<F%NYV$@365T<F]P
M;VQI=&%N80!'=6EA;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A`%1E
M<G)I=/-R:6]S($9R86YC97-E<R!D;R!3=6P`1&4`1&\H82D`1&4Z`$1E<V-R
M:>?C;R!#;VUP;&5T80!,=6$@0VAE:6$`3F]M92!#;VUP;&5T;P!'86+C;P!'
M86QE<FEA(&1E(&]N9&4@;V)T97(@87,@:6UA9V5N<P!'86QE<FEA.@!'XFUB
M:6$`1V5R87(@82!#;VYF:6=U<F'GXV\@9&4@)7,`0_-D:6=O($=E<F%D;P!'
M9?-R9VEA`$%L96UA;FAA`$=A;F$`1VEB<F%L=&%R`%!R:6UE:7)O($YO;64`
M3W#G]65S($=L;V)A:7,`27(`1V]E9&5L`$=O;V=L92!-87!A<P!097-Q=6ES
M87(@;F\@1V]O9VQE`$5S8V%L82!D92!#:6YZ87,`36%I;W(@<75E`$UA:6]R
M(&]U(&EG=6%L(&$`1W+I8VEA`$=R96=O("A)4T\M.#@U.2TW*0!'<F]E;.)N
M9&EA`$=R86YA9&$`061M:6YI<W1R8>?C;R!D92!'<G5P;W,`3F]M97,@9&4@
M9W)U<&]S(&[C;R!D979E;2!E<W1A<B!E;2!B<F%N8V\`1W)O=7!?;&1A<#H@
M26UP;W-S[79E;"!A9&EC:6]N87(@9W)U<&\@)7,N($ES=&\@Z2!O('%U92!O
M('-E<G9I9&]R(&1I<W-E.B``1W)O=7!?;&1A<#H@26UP;W-S[79E;"!E>&-L
M=6ER(&=R=7!O("5S`$=R;W5P7VQD87`Z($EM<&]S<^UV96P@871U86QI>F%R
M(&=R=7!O("5S`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!'=6%T96QA;6$`1W5E
M<FYS97D`4&5R;6ES<_5E<R!D92!#;VYV:61A9&\`3&EV<F\@9&4@5FES:71A
M<P!'=6ENZ0!'=6ENZ2U":7-S874`1W5I86YA`$A434P`2%1-3$%R96$@<V4@
M;F5G82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA(&/I;'5L82!D
M82!L:6YH82X`2%1-3$%R96$@<V4@;F5G82!C;W9A<F1E;65N=&4@82!E>&-L
M=6ER(&$@^FQT:6UA(&-O;'5N82!D82!T86)E;&$N`$A434Q!<F5A('-E(&YE
M9V$@8V]V87)D96UE;G1E(&$@97AC;'5I<B!A(/IL=&EM82!L:6YH82!D82!T
M86)E;&$N`$%U=&5N=&EC8>?C;R!(5%10(&[C;R!E;F-O;G1R861A+@!(86ET
M:0!!;&=O<FET;6\@2&%S:`!.96)L:6YA`$-A8F7G86QH;P!#86)EYV%L:&\`
M26QH82!(96%R9"!E($EL:&%S($UC1&]N86QD`%1E;7!E<W1A9&4@1F]R=&4`
M2&5B<F5U("A)4T\M.#@U.2TX+4DI`$%L='5R80!!:G5D80!!:G5D82!D;R!E
M9&ET;W(`07-S:7-T96YT90!(96UI<V;I<FEO`$%Q=6D@97-TX2!O(&EN[6-I
M;R!D;R!A<G%U:79O.@!!;'1A`$E?;NUC:6\`4V%N=&$@4^D@*$-I9&%D92U%
M<W1A9&\@9&\@5F%T:6-A;F\I`$EN[6-I;P!%;F1E<F7G;R!297-I9&5N8VEA
M;`!$:7)E=/-R:6\@4&5S<V]A;`!&;VYE(%)E<VED96YC:6%L`$AO;F1U<F%S
M`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@1&%D;R!834P@)7,@:6YV
MX6QI9&\@96YC;VYT<F%D;R!N82!M96YS86=E;2`E<P!(;W)D92]+;VQA8CH@
M3F5N:'5M82!M96YS86=E;2!C;W)R97-P;VYD92!A;R!O8FIE=&\@)7,`2&]R
M9&4O2V]L86(Z($YE;FAU;2!O8FIE=&\@9&\@=&EP;R`E<R!F;VD@96YC;VYT
M<F%D;R!N82!M96YS86=E;2`E<P!(;W)D92]+;VQA8CH@4F5M;W9I9&\@8V]M
M('-U8V5S<V\@)7,@(B5S(@!(;W)D92]+;VQA8CH@02!E;F=I;F4@9&4@:6YT
M96=R8>?C;R!R97%U97(@82!E>'1E;G/C;R!02%`@)V1O;7AM;"<`2&]R9&4O
M2V]L86(Z($EM<&]S<^UV96P@8W)I87(@=6UA(&YO=F$@X7)V;W)E(%A-3"!P
M87)A(&\@;V)J971O("5S`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L(')E;6]V
M97(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@;V)T97(@
M82!I9&5N=&EF:6-AY^-O($U)344@<&%R82!A('!A<G1E(&1O('1I<&\@)7,`
M2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@<VEN8W)O;FEZ87(@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@<VEN8W)O;FEZ87(@8V]M<&%R
M=&EL:&%M96YT;W,Z("5S`$AO<F1E+TMO;&%B.B!#;VUP87)T:6QH86UE;G1O
M(&1E<V-O;FAE8VED;R`B)7,B`$QI;FAA($AO<FEZ;VYT86P`36%R9V5M(&AO
M<FEZ;VYT86P`2&]R:7IO;G1A;#H`0V]M;R!V;V/J(&-H96=O=2!A<75I/R`H
M4&]R(&9A=F]R(&-O;75N:7%U92$I`%%U86YT87,@8V]L=6YA<R!V;V/J(&=O
M<W1A<FEA(&1E(&UE<V-L87(_`%%U86YT;W,@8V%M<&]S("AC;VQU;F%S*2!E
M>&ES=&5M/P!1=6%N=&%S(&QI;FAA<R!V;V/J(&=O<W1A<FEA(&1E(&UE<V-L
M87(_`%5M:61A9&4`56UI9&%D93H@`$AU;6]R:7-T87,`2'5N9W+M80!&86QH
M82!A;R!C<FEA<B!C86EX82!P;W-T86P@24U!4#H@)7,`1F%L:&$@86\@97AC
M;'5I<B!C86EX82!P;W-T86P@24U!4#H@)7,`1F%L:&$@86\@8W)I87(@<75O
M=&$@9&$@8V%I>&$@<&]S=&%L($E-05`Z("5S`$5N9&5R9>=O($E0`$5N9&5R
M9>=O($E0(&[C;R!D:7-P;V[M=F5L+@!%;F1E<F7G;R!)4"!NXV\@97-TX2!N
M;R!B;&]C;R!P97)M:71I9&\@0TE$4BX`5FEO;&'GXV\@9&\@8FQO<75E:6\@
M25`N`$E?;G-I<F$@3&EN:&$@06YT97,`27-LXFYD:6$`4V]M96YT92#-8V]N
M97,`S6-O;F5S('!A<F$@)7,`S6-O;F5S(&4@=&5X=&\`3F]M92!D82!I9&5N
M=&ED861E.@!392!NXV\@9F]R(&5X:6)I9&\@8V]R<F5T86UE;G1E+"`E<R!P
M87)A(&%B<NTM;&\@96T@=6UA(&YO=F$@:F%N96QA+@!392!V;V/J(&[C;R!V
MZB!N96YH=6T@[6-O;F4@86\@=71I;&EZ87(@;R!);G1E<FYE="!%>'!L;W)E
M<BP@=F]CZB!P;V1E(&-H96-A<B!E<W1A(&-A:7AA('!A<F$@9&5S86)I;&ET
M87(@82!T<F%N<W!A<NIN8VEA(%!.1RX`4V4@=F]CZB!VZB!E<W1A(&UE;G-A
M9V5M(&UA<R!NXV\@82!I;6%G96TL(&$@:6UA9V5M('%U92!V;V/J('%U97(@
M96YV:6%R(&[C;R!P;V1E('-E<B!E>&EB:61A('!E;&\@<V5U(&YA=F5G861O
M<BX`4'+I+79I<W5A;&EZ8>?C;R!D82!);6%G96TZ`%523"!D82!);6%G96T`
M55),(&1A($EM86=E;3H`26UA9V5M(&1A(&=A;&5R:6$`26UA9V5M(&1A(&=A
M;&5R:6$Z`$5N=FEO(&1E($EM86=E;0!);6%G96YS`$EM<&]R=&%R+"!087-S
M;R`E9`!);7!O<G1A;G1E`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM
M<&]R=&%D;W,Z`$EN7W-E<FER($QI;FAA($%P\W,`0_-D:6=O(&1E(&'GXV\@
M9F]R;F5C:61O(&5S=.$@:6YC;W)R971O+@!5<W7A<FEO(&4O;W4@<V5N:&$@
M:6YC;W)R971O<RX`57-UX7)I;R!O=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!I
M;F-O<G)E=&]S+B!496YT92!N;W9A;65N=&4@;W4@96YT<F4@96T@8V]N=&%T
M;R!C;VT@;R!A9&UI;FES=')A9&]R('-E('9O8^H@;F5C97-S:71A(&1E(&UA
M:7,@86IU9&$N`$%U;65N=&%R($ED96YT8>?C;P#-;F1I80!5<W7A<FEO<R!I
M;F1I=FED=6%I<P!296=R87,@:6YD:79I9'5A:7,@;N-O('/C;R!S=7!O<G1A
M9&%S('!E;&\@9')I=F5R(&1E(&9I;'1R;R!A='5A;"X`26YD;V[I<VEA`%!A
M<W1A(&5S<&5C:69I8V%D82!P87)A(&5N=')E9V$@;N-O(&5X:7-T92X`26YF
M;W)M8>?C;P!);F9O<FUAY^-O`$[C;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M
M=F5I<RX`26YS97)I<B!#7V]L=6YA($%P\W,`26YS97)I<B!);6%G96T`26YS
M97)I<B!486)E;&$`26YS97)I<B!,:6YK(&1A(%=E8@!);G-E<FER(%]#;VQU
M;F$@06YT97,`26YS97)I<B!U;6$@;F]V82!C;VQU;F$@87#S<R!A(&%T=6%L
M`$EN<V5R:7(@=6UA(&YO=F$@8V]L=6YA(&%N=&5S(&1A(&%T=6%L`$EN<V5R
M:7(@=6UA(&YO=F$@;&EN:&$@87#S<R!A(&%T=6%L`$EN<V5R:7(@=6UA(&YO
M=F$@;&EN:&$@86YT97,@9&$@871U86P`26YS97)I<B!U;2!P87+A9W)A9F\@
M87#S<R!O(&%T=6%L`$EN<V5R:7(@=6T@<&%RX6=R869O(&%N=&5S(&1O(&%T
M=6%L`$EN<V5R:7(@=6T@;6]D96QO(&%L=&5R;F%T:79O`$9O<FYEYV$@=6T@
M96YD97)EYV\@9&4@92UM86EL(&YO('%U86P@=F]CZB!P;V1E(')E8V5B97(@
M82!N;W9A('-E;FAA.@!);G-E<FER(&/I;'5L82!A</-S`$EN<V5R:7(@8^EL
M=6QA(&%N=&5S`$EN<V5R:7(@8V]L=6YA(&%P\W,`26YS97)I<B!C;VQU;F$@
M86YT97,`26YS97)I<B!M96YS86=E;G,`26YS97)I<B!P87+A9W)A9F\@87#S
M<P!);G-E<FER('!A<N%G<F%F;R!A;G1E<P!);G-E<FER(&QI;FAA(&%P\W,`
M26YS97)I<B!L:6YH82!A;G1E<P!&;W)N9>=A(&$@<F5S<&]S=&$@;V)R:6=A
M=/-R:6$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R86[G83H`26YS97)I<B]!
M;'1E<F%R($EM86=E;0!);G-E<FER+T%L=&5R87(@3&EN:P!#<NED:71O(&EN
M<W5F:6-I96YT92!P87)A(&5N=FEA<B!P87)A(&$@;&ES=&$@9&4@9&ES=')I
M8G5IY^-O+@!#<NED:71O(&EN<W5F:6-I96YT92X`3OIM97)O($EN=&5I<F\`
M3&ES=&$@9&4@26YT96ER;W,`0T15("A#86)EYV%L:&\@9&4@1&%D;W,@9&4@
M57-UX7)I;RD@:6YVX6QI9&\N`$1A9&]S(%I)4"!I;G;A;&ED;W,`07!L:6-A
MY^-O(&EN=N%L:61A+@!)9&5N=&EF:6-AY^-O(&1O(&)A=&-H(&EN=N%L:61A
M+@!$861O<R!E;G9I861O<R!SXV\@:6YVX6QI9&]S+@!%;F1E<F7G;R!D92!D
M97-T:6YO(.D@:6YVX6QI9&\N`$9O<FUA=&\@9&\@87)Q=6EV;R#I(&EN=N%L
M:61O`$[Z;65R;R!D92!L:6-E;N=A(&EN=N%L:61O+@!,;V-A;&EZ8>?C;R!F
M;W)N96-I9&$@Z2!I;G;A;&ED82X`5&EP;R!D82!M96YS86=E;2#I(&EN=N%L
M:61O+@!!<&E?:60@Z2!I;G;A;&ED;R!O=2!E<W3A(&9A;'1A;F1O+@!087+B
M;65T<F]S(&EN=N%L:61O<R!O=2!F86QT86YD;RX`4&5R;6ES<_5E<R!D;R!P
M86D@<^-O(&EN=N%L:61A<RX`4&5R;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L
M:61A<RX`0_-D:6=O(&1O('!R;V1U=&\@Z2!I;G;A;&ED;RX`4')O=&]C;VQO
M(&EN=N%L:61O+@!$97-T:6YA=.%R:6\@:6YVX6QI9&\Z("<E<R<`3V)J971O
M(&-O;7!A<G1I;&AA9&\@:6YVX6QI9&\`1F]N=&4@9&\@96YD97)EYV\@:6YV
MX6QI9&$N`$1A9&]S('5N:6-O9&4@:6YVX6QI9&]S+@!);G9E;G3A<FEO`$EN
M=F5R=&5R('-E;&7GXV\`27+C+"!297#Z8FQI8V$@27-LXFUI8V$@9&\`27)A
M<75E`$ER;&%N9&$`R0!);&AA(&1O($AO;65M`$[C;R#I`%1E;7!E<W1A9&5S
M($ES;VQA9&%S`$ES<F%E;`!%;6ES<V]R`$ETX6QI8V\`273A;&EA`$IA;6%I
M8V$`2F%N96ER;P!*87#C;P!*87!O;NIS("A)4T\M,C`R,BU*4"D`2F5R<V5Y
M`$IO<F3B;FEA`$IU;&AO`$IU;FAO`$IU<W1I9FEC87(`06QI;FAA<B!A;R!#
M96YT<F\`2G5S=&EF:6-A<@!!;&EN:&%R(.`@17-Q=65R9&$`06QI;FAA<B#@
M($1I<F5I=&$`0V%Z87%U:7-TXV\`36%N=&5R(&\@;W)I9VEN86P_`%%UZFYI
M80!397)V:61O<B!K97)B97)O<R!R96IE:71O=2!A(&%U=&5N=&EC8>?C;RX`
M3F]V871O<R!D92!+97)N96P`0W)I8>?C;R!D92!#:&%V90!);7!R97-SXV\@
M1&EG:71A;"!D82!#:&%V90!486UA;FAO(&1A($-H879E`%1I<&\@9&$@0VAA
M=F4`57-O(&1A($-H879E`$-H879E(&KA(&5X:7-T92!N;R!S97)V:61O<B!D
M92!C:&%V97,@</IB;&EC87,N`$-R:6%NYV%S`$MI<FEB871I`$-O<NEI82P@
M4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@9&$`0V]RZ6EA+"!297#Z
M8FQI8V$@9&$`0V]R96%N;R`H155#+4M2*0!+=7=A:70`475I<F=U:7-TXV\`
M4W5P;W)T92!A($Q$05`@Z2!N96-E<W/A<FEO(&UA<R!O(&WS9'5L;R!,1$%0
M(&[C;R!E<W3A(&1I<W!O;NUV96P@;W4@;N-O(&9O:2!C87)R96=A9&\N`$QA
M7WEO=70`261I;VUA`$QA;R!297#Z8FQI8V$@1&5M;V-RX71I8V$@4&]P=6QA
M<@#:;'1I;6$@365T861E`$=E<F%R($YO=F$@4V5N:&$`VFQT:6UO(%%U87)T
M;P#:;'1I;6$@071U86QI>F'GXV\Z`-IL=&EM;R!L;V=I;CH@)7,`VFQT:6UO
M(&QO9VEN.B`E<R#@('!A<G1I<B!D92`E<P#:;'1I;6\@;&]G:6XZ($YU;F-A
M`$QE=/1N:6$`3&5I`$QA>6]U=`!$96EX82!V87II;R!S92!Q=6ES97(@<V5M
M(&)O<F1A`$SM8F%N;P!%<W%U97)D80!#86)EYV%L:&\@97-Q=65R9&\`5F%L
M;W)E<R!D82!E<W%U97)D80!,97-O=&\`365N;W(@<75E`$UE;F]R(&]U(&EG
M=6%L(&$`06UO<@!,:6+I<FEA`$SM8FEA(,%R86)E($IA;6%H:7)I>6$`3&EE
M8VAT96YS=&5I;@!#:&EV:7-C;T9R86-O`$-H=79A($9R86-A`$-H=79A($9R
M86-A($UA='5T:6YA`$-H=79A($9R86-A(%9E<W!E<G1I;F$`3&5V97,@4&%N
M8V%D87,@9&4@0VAU=F$`0VAU=F%S($9R86-A<R!C;VT@5')O=O5E<P!.979E
M($9R86-A`$)R979E($YE=F%S8V$`4&_J;6%S`$QI;FL`3&EN:R!A<&]N=&$@
M<&%R83H`3&EG87(@;R!E;F1E<F7G;R!D92!E+6UA:6P@X"!PX6=I;F$@9&4@
M8V]M<&]S:>?C;R!A;R!E>&EB:7(`3&EN:W,`0V]O:VEE(&1O($QI;G5X`$QI
M<W1A<B`M('5S=>%R:6\@<&]D92!V97(@82!P87-T80!,:7-T87(@0F%N8V]S
M(&1E($1A9&]S`$QI<W1A<B!4\W!I8V]S(&1E($%J=61A`$QI<W1A<B!486)E
M;&%S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)1`!,:7-T+4ED`$QI
M<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S
M8W)I8F4`02!L:7-T86=E;2!D92!S97-S]65S(&9A;&AO=3H@)7,`02!L:7-T
M86=E;2!D92!U<W7A<FEO<R!F86QH;W4Z("5S`$QI<W1A9V5M(&1E('5S=>%R
M:6]S(&5S=.$@9&5S86)I;&ET861A+@!,:71E<F%T=7)A`$QI='7B;FEA`$-A
M<G)E9V%N9&\N+BX`2&]R82!L;V-A;#H@`$QO8V%L:7IAY^-O(&4@2&]R80!2
M96=IXV\`0V]N96-T87(`3&]G(&1A('-E<W/C;R!D92!S:6YC<F]N:7IAY^-O
M(&%N=&5R:6]R`$1E<V-O;F5C=&%R`$-O;F5C=&%R`%1A<F5F87,@9&4@0V]N
M97CC;P!/(&QO9VEN(&9A;&AO=2!P;W)Q=64@<V5U('5S=>%R:6\@;W4@<V5N
M:&$@97-T879A(&EN8V]R<F5T82X`1F%L:&$@9&4@3&]G:6XN`%1E>'1O(&QO
M;F=O`$%M;W(`0F%I>&$`06QF86)E=&\@9W)E9V\@96T@;6EN^G-C=6QO`$%L
M9F%B971O(&QA=&EN;R!E;2!M:6[Z<V-U;&\`3OIM97)O<R!R;VUA;F]S(&5M
M(&UI;OIS8W5L;P!,=7AE;6)U<F=O`$U-`$U/5$0`3R!A;F5X;R!-4RU43D5&
M(&[C;R!C;VYTZ6T@9&%D;W,N`$U31P!-86-A;P!-86-E9&]N:6$L($%N=&EG
M82!297#Z8FQI8V$@275G;W-LX79I82!D80!-861A9V%S8V%R`$WA9VEC;P!#
M;W)R96EO`$%D;6EN:7-T<F%D;W(@9&\@0V]R<F5I;P!#<FEA<B!L:6Y?:RXN
M+@!-86QA=VD`36%LX7-I80!-86QD:79A<P!-86QI`$UA;'1A`$=E<F5N8VEA
M(&$@;&ES=&$@9&4@8V%T96=O<FEA<R!E(&%S(&-O<F5S(&%S<V]C:6%D87,@
M82!E;&%S+@!-87!E86UE;G1O($UA<#(T`$UA<&5A;65N=&\@36%P475E<W0`
M36%P96%M96YT;W,@9W)A=F%D;W,N`$UA<E]C87(@;65N<V%G96T@8V]M;R!E
M>&-L=>UD80!-87+G;P!-87)G96T`36%R8V%R(&UE;G-A9V5M(&-O;6\Z`$UA
M<F-A<B!C;VT@9FQA9W,@3&ED82].XV\@3&ED80!-87)C87(@8V]M(&]U=')O
M<R!F;&%G<R`H97@N($EM<&]R=&%N=&4O4F5S<&]N9&ED82D`26QH87,@36%R
M<VAA;&P`36%R=&EN:6-A`$-O<G)E<W!O;F1E(&$@*&-O;2!C;W)I;F=A<RD`
M0V%M<&]S(&-O<G)E<W!O;F1E;G1E<P!-875R:73B;FEA`$UA=7+M8VEO`$-R
MZ61I=&\@;>%X:6UO('!E<FUI=&ED;RX`3OIM97)O(&WA>&EM;R!D92!P87)T
M97,@9&$@;65N<V%G96T@97AC961E=2X`5&5M<&5R871U<F$@;>%X:6UA(&YA
M<R#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z
M;'1I;6%S(#8@:&]R87,Z(`!.^FUE<F\@3>%X:6UO(&1E($)L;V-O<R!D92!0
M;W)T86P`3OIM97)O($WA>&EM;R!D92!296=R87,`5&%M86YH;R!MX7AI;6\`
M17AC961E=2!O(&[Z;65R;R!MX7AI;6\@9&4@96YD97)EYV]S(&YA(&QI<W1A
M(&YE9W)A("A4;W1A;"!D92!E;F1E<F7G;W,Z("5S+"!-X7AI;6\@9&4@96YD
M97)EYV]S.B`E<RDN("!.XV\@8V]N<V5G=6D@861I8VEO;F%R(&YO=F]S(&5N
M9&5R9>=O<R#@(&QI<W1A(&YE9W)A+@!%>&-E9&5U(&\@;OIM97)O(&WA>&EM
M;R!D92!E;F1E<F7G;W,@;F$@;&ES=&$@8G)A;F-A("A4;W1A;"!D92!E;F1E
M<F7G;W,Z("5S+"!-X7AI;6\@9&4@96YD97)EYV]S.B`E<RDN("!.XV\@8V]N
M<V5G=6D@861I8VEO;F%R(&YO=F]S(&5N9&5R9>=O<R#@(&QI<W1A(&)R86YC
M82X`36%I;P!-87EO='1E`$UE9&EC:6YA`$UE;6)R;W,`36]D;R!D;R!M96YU
M.@!-97-C;&%R(&/I;'5L87,`365N<V%G96T`365N<V%G96T@5F5R:69I8V%D
M82!C;VT@4W5C97-S;R!M87,@;R!C97)T:69I8V%D;R!D;R!A<W-I;F%N=&4@
M;N-O('#T9&4@<V5R('9E<FEF:6-A9&\N`$UE;G-A9V5M(&5X<&ER861A+@!4
M:7!O(&1E(&UE;G-A9V5M`$-L:6UA($UE=&%R`$)L;V-O($UE=&%R(&[C;R!D
M:7-P;V[M=F5L+@!";&]C;R!-971A<B!NXV\@9&ES<&]N[79E;"X@1&5T86QH
M97,@9F]R86T@9W)A=F%D;W,@96T@;&]G('!A<F$@;R!A9&UI;FES=')A9&]R
M+@!/($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861O+@!-Z71O9&\`3>ET;V1O
M("<E<R<@;N-O(&5S=.$@9&5F:6YI9&\`3>ET;V1O(&[C;R!D969I;FED;RX@
M3>ET;V1O(&-H86UA9&\Z("5S`$WI=')I8V$`3>EX:6-O`$UI8W)O;NES:6$L
M($5S=&%D;W,@1F5D97)A9&]S(&1A`$UE:6\`5&EP;R!-:6UE`%1E;7!E<F%T
M=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E<F%T=7)A
M(&WM;FEM82!N87,@^FQT:6UA<R`V(&AO<F%S.B``261A9&4@;>UN:6UA(&1A
M('-E;FAA(&%I;F1A(&[C;R!E>'!I<F]U`$5S<&5L:&\`1&EV97)S;W,`4&%C
M;W1E(%!%05(@2%144%]297%U97-T(&9A;'1A;F1O+@!&86QT86YD;R!O<R!E
M;F1E<F7G;W,@<&%R82!N;W1I9FEC87(`16YD97)EYV\@<&%R82!R961I<F5C
M:6]N86UE;G1O(&[C;R!I;F9O<FUA9&\`0V]N9FEG=7)AY^-O(&9A;'1A;F1O
M+B!6;V/J('1E;2!Q=64@9V5R87(@96QA(&%G;W)A('-E('9O8^H@<75E<B!U
M=&EL:7IA<B!E<W1A(&%P;&EC8>?C;RX`240@9&$@;65N<V%G96T@9F%L=&%N
M9&\N`%)A>N-O('!A<F$@<F5J96GGXV\@;N-O(&EN9F]R;6%D80!287KC;R!P
M87)A(&UE;G-A9V5M(&1E(&;I<FEA<R!NXV\@:6YF;W)M861A+@!086-O=&4@
M;V)R:6=A=/-R:6\@4$5!4B!-86EL(&9A;'1A;F1O+@!)1"!D82!S97-SXV\@
M9F%L=&%N9&\N`%-E9P!#;W)R96EO($WS=F5L`$UO9&5R87(`1&%T82!-;V1I
M9FEC861A`$%L=&5R87(@55),`$WS9'5L;P!-;VQD;W9A+"!297#Z8FQI8V$@
M9&$`3?1N86-O`$UO;F?S;&EA`$WJ<R!E(&%N;P!-96YS86QM96YT90!-;VYT
M<V5R<F%T`$9A<V5S(&1A($QU80!-86ES(&-A;7!O<R!E;F-O;G1R861O<R!N
M82!L:6YH82`E9"!Q=64@;R!N^FUE<F\@97-P97)A9&\@)60N`$UA<G)O8V]S
M`$=R86YD92!087)T92!,:6UP80!'<F%N9&4@4&%R=&4@3G5B;&%D;P!'<F%N
M9&4@4&%R=&4@16YS;VQA<F%D;P!-;W9E<@!-;W9E<B!!8F%I>&\`36]V97(@
MX"!%<W%U97)D80!-;W9E<B#@($1I<F5I=&$`36]V97(@4F5G<F$@06)A:7AO
M`$UO=F5R(%)E9W)A($%C:6UA`$UO=F5R($%C:6UA`$%B86EX;P!!8VEM80!-
M;^=A;6)I<75E`$QI<W1A<R!D92!S96QEY^-O(&1E(&WZ;'1I<&QO<R!N[79E
M:7,`36%P87,@26YG;&5S97,@375L=&EM87``4V5L9>?C;R!M^FQT:7!L80!-
M:6YH82!#;VYT80!3=6%S($EN9F]R;6'G]65S`$UE=2!0;W)T86P`365U($QA
M>6]U="!D92!0;W)T86P`0FER;>)N:6$`3L-/+"!%=2!.PT\@0V]N8V]R9&\`
M7T[Z;65R;R!D92!D:6%S(&5N=')E(&%S(')E<W!O<W1A<R!D92!FZ7)I87,Z
M`$YO;64`3F%M[6)I80!.875R=0!.97!A;`!(;VQA;F1A`$%N=&EL:&%S($AO
M;&%N9&5S87,`55),($)A<V4@9&\@3F5T<V-A<&4`55),(&1E(%)E=F]G8>?C
M;R!D92!#02!D;R!.971S8V%P90!54DP@9&4@<&]L[71I8V%S(&1E($-!(&1O
M($YE='-C87!E`%523"!D92!296YO=F'GXV\@9&\@3F5T<V-A<&4`55),(&1E
M(%)E=F]G8>?C;R!D;R!.971S8V%P90!.;VUE(&1O('-E<G9I9&]R(%-33"!D
M;R!.971S8V%P90!#;VUE;G3A<FEO(&1O(&-E<G1I9FEC861O(&1O($YE='-C
M87!E`%1I<&\@9&4@8V5R=&EF:6-A9&\@9&\@3F5T<V-A<&4`4F5D90!.=6YC
M80!.;W9A($-A;&5D]&YI80!.;W9A($-A=&5G;W)I80!.;W9A($UE;G-A9V5M
M('!A<F$@)7,`3'5A($YO=F$`3F]V82!296=R80!.;W9O(%5S=>%R:6\@*&]P
M8VEO;F%L*0!.;W9A(%IE;.)N9&EA`$YO=F$@<V5N:&$`3F]V82!S96YH82!E
M>'!I<F%RX2!E;2`E>"X`07,@;F]V87,@<V5N:&%S(&[C;R!SXV\@:6=U86ES
M+@!.;W9A(&IA;F5L82`H7V)L86YK*0!.;W3M8VEA<P!'<G5P;W,@9&4@3F]T
M[6-I87,`4'+S>&EM80!0<O-X:6UA<R`T($9A<V5S`%!R\WAI;6%S(&]PY_5E
M<P!0<O-X:6UA/@!.:6-A<N%G=6$`3FEG97(`3FEGZ7)I80!.;VET90!.:75E
M`$[C;P!/('!A<N)M971R;R`G)7,G(&[C;R!F;VD@96YC;VYT<F%D;R!N82!C
M;VYF:6=U<F'GXV\@9&\@9')I=F5R+@!.96YH=6T@9&%D;R!D92!C;VYF:6=U
M<F'GXV\@9&ES<&]N[79E;"!P87)A(&5X:6)I<B!A<R!D:69E<F5NYV%S+@!.
M96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(&-R:6%R(&EM86=E
M;G,@25-/+@!.XV\@9F]I(&-O;F9I9W5R861O('5M(&1R:79E<B!P87)A(&5S
M=&4@<V5R=FED;W(`3F5N:'5M(&1R:79E<B!C;VYF:6=U<F%D;R!E;2!B86-K
M96YD<RYP:'``3F5N:'5M(&UO9&5L;R!D92!B871C:"X`3F5N:'5M(&)L;V-O
M(&5X:7-T92!N82!P;W-IY^-O('-O;&EC:71A9&$`3F5N:'5M(&YO;64@9&4@
M86=E;F1A(&9O<FYE8VED;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN`$YE
M;FAU;6$@86QT97)AY^-O+@!.96YH=6T@<W5B;W)D:6YA9&\@<&]D92!S97(@
M861I8VEO;F%D;R!A(&5S=&$@<&5R;6ES<^-O+@!.96YH=6UA(&EN9F]R;6'G
MXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A("5S+@!.96YH
M=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P
M87)A($944"!61E,N`$YE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'G
MXV\@97-P96-I9FEC861A('!A<F$@4U%,(%9&4RX`3F5N:'5M82!I;F9O<FUA
MY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@<&%R82!344PM1FEL
M92!61E,N`$YE;FAU;2!C<NED:71O(')E<W1A;G1E+@!.96YH=6T@9&5S=&EN
M;R!F;W)N96-I9&\N`$YE;FAU;2!A<G%U:79O(&5N=FEA9&\`3F5N:'5M(&9I
M;'1R;RX@0VQI<75E(&5M("<E<R<@<&%R82!C<FEA<B!U;2!N;W9O(&9I;'1R
M;RX`3F5N:'5M(&-A8F7G86QH;R!E<W!E8VEF:6-A9&\`3F5N:'5M(.UC;VYE
M(&5N8V]N=')A9&\N`$YE;FAU;6$@;&]C86QI>F'GXV\@8V]N9FEG=7)A9&$N
M`$YE;FAU;6$@;&]C86QI>F'GXV\@8V]N9FEG=7)A9&$N`$YE;FAU;6$@;65N
M<V%G96T@9F]R;F5C:61A+@!.96YH=6T@;F]M92!E<W!E8VEF:6-A9&\N`$YE
M;FAU;2!N^FUE<F\@97-P96-I9FEC861O+@!396T@<V]R=&5S(&]F96YS:79A
M<P!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O
M($A45%`N`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I
M8V'GXV\@24U!4"X`3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U
M=&5N=&EC8>?C;R!+97)B97)O<RX`3F5N:'5M82!S96YH82!F;W)N96-I9&$@
M<&%R82!A(&%U=&5N=&EC8>?C;R!,;V=I;BX`3F5N:'5M82!S96YH82!F;W)N
M96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!005-35T0N`$YE;FAU;6$@<V5N
M:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@4TU"+@!.96YH=6T@
M<&%T:"!P87)A(&\@8FENX7)I;R!D;R!/<&5N4U-,(&9O:2!F;W)N96-I9&\N
M($\@8FENX7)I;R!D;R!/<&5N4U-,(.D@;F5C97-SX7)I;R!P87)A(&UA;FEP
M=6QA<B!O<R!D861O<R!02T-3(#$R+@!.96YH=6T@8V%D87-T<F\@<&5N9&5N
M=&4N`%%U;W1A(&[C;R!C;VYF:6=U<F%D82X`4V5M(&QI;FAA<P!.96YH=6UA
M(')O=&EN82!G97)A9&$N`$YE;FAU;2!S97!A<F%D;W(@9F]I(&5S<&5C:69I
M8V%D;RX`4V5M(&QA9&]S`$YE;FAU;6$@8V%D96EA(&1E(&-A<F%C=&5R97,@
M97-P96-I9FEC861A`$%R<75I=F\@:6YE>&ES=&5N=&4`3F5N:'5M(&1I<F5T
M\W)I;R!T96UP;W+A<FEO(&1I<W!O;NUV96P@<&%R82!O(&-A8VAE+@!.96YH
M=6T@=7-UX7)I;R!E+V]U('-E;FAA(&9O<FYE8VED;W,N`$YE;FAU;2!D861O
M(%A-3"!VX6QI9&\@<F5T;W)N861O`%-E;2!V86QO<F5S`$YE;FAU;2!V97)S
MXV\@96YC;VYT<F%D82!N82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN($=E<F4@
M;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O+@!.96YH=6UA('9E<G/C;R!E;F-O
M;G1R861A(&YA('-U82!C;VYF:6=U<F'GXV\N($=E<F4@;F]V86UE;G1E(&$@
M8V]N9FEG=7)AY^-O+@!.96YH=6UA`$YE;FAU;6$@*'5S;R!I;7!L[6-I=&\I
M`$[S<F1I8V\@*$E33RTX.#4Y+3$P*0!);&AA($YO<F9O;&L`2&5M:7-FZ7)I
M;R!.;W)T90!);&AA<R!-87)I86YA(&1O($YO<G1E`$YO<G5E9V$`3N-O($%P
M\W,`3N-O($%N=&5S`$[C;R#I('5M(&1I<F5T\W)I;P!$:69E<F5N=&4@9&4`
M3N-O($EM<&QE;65N=&%D;RX`3N-O(&-O;F9I9W5R861O`$[C;R!S=7!O<G1A
M9&\N`$%N;W1AY_5E<P!.861A('!A<F$@97AI8FER+"!V;VQT92X`16YD97)E
MYV\@9&4@92UM86EL('!A<F$@;F]T:69I8V'GXV\`3F]V96UB<F\`3OIM97)O
M`$[Z;65R;R!D92!C87)A8W1E<F5S`$[Z;65R;R!D92!C;VQU;F%S`$[Z;65R
M;R!D92!L:6YH87,`3OIM97)O(&[C;R!E<W!E8VEF:6-A9&\@<&%R82!A='5A
M;&EZ8>?C;R!N82!L:7-T82!D92!D:7-T<FEB=6GGXV\N`$]+`$]B:F5T;P!#
M<FEA9&]R(&1O($]B:F5T;P!/8W1A;`!/=71U8G)O`$9I;'1R;R!O9F5N<VEV
M;P!%<V-R:73S<FEO`%-E;FAA<R!A;G1I9V$@92!N;W9A(&1E=F5M('-E<B!D
M:69E<F5N=&5S+@!396YH82!A;G1I9V$`4V5N:&$@86YT:6=A(&[C;R!E<W3A
M(&-O<G)E=&$N`$]MXP!3;VUE;G1E('-E<G9I9&]R97,@24U!4"!S=7!O<G1A
M;2!P87-T87,@8V]M<&%R=&EL:&%D87,N`$%P96YA<R!M87)Q=64@82!M96YS
M86=E;0!3;VUE;G1E('-O<G1E<R!O9F5N<VEV87,`4V]M96YT92!U;2!E;F1E
M<F7G;R!D92!E+6UA:6P@<&5R;6ET:61O+@!3;VUE;G1E(&\@<')O<')I973A
M<FEO(&]U(&\@861M:6YI<W1R861O<B!D;R!S:7-T96UA('!O9&5M(&%L=&5R
M87(@87,@<&5R;6ES<_5E<R!D92!P<F]P<FEE9&%D92!O=2!P<F]P<FEE=.%R
M:6\@9&4@=6T@8V]M<&%R=&EL:&%M96YT;P!!8G)I<B!E;2!U;6$@;F]V82!J
M86YE;&$`17)R;R!D;R!/<&5N4U-,.B!.XV\@<'5D92!E>'1R86ER(&1A9&]S
M(&1A('!A<G1E(&%S<VEN861A(%,O34E-12X`06)R92!E<W1E(&QI;FL@96T@
M=6UA(&YO=F$@:F%N96QA`%-I<W1E;6$@3W!E<F%C:6]N86P`3W#G]65S`$]P
MY_5E<R!S;V)R92!A='5A;&EZ8>?C;R!D82!R;W1I;F$N`$]PY_5E<R!D92`E
M<P!,:7-T82!/<F1E;F%D80!/<F=A;FEZ8>?C;P!5;FED861E($]R9V%N:7IA
M8VEO;F%L`$]R9V%N:7IA;F1O`$UO9&5L;R!O<FEG:6YA;"!D92!A<&QI8V'G
MXV\`36]D96QO(&]R:6=I;F%L(&5M("5S.@!/=71R;P!/=71R87,@26YF;W)M
M8>?U97,`3W5T<F%S($]PY_5E<P!6:7/C;R!'97)A;`!097)M:7-S]65S(&1O
M(%!R;W!R:65TX7)I;P!!=71E;G1I8V'GXV\@4$%-(&[C;R!E<W3A(&1I<W!O
M;NUV96PN`$-O;F5C=&]R(%!%05(Z.DUA:6P`07-S:6YA='5R82!$:6=I=&%L
M(%!'4`!$861O<R!#<FEP=&]G<F%F861O<R!C;VT@4$=0`$-H879E(%#Z8FQI
M8V$@4$=0`$1A9&]S($%S<VEN861O<R]#<FEP=&]G<F%F861O<R!C;VT@4$=0
M`$/S9&EG;R!02%``3&EN:&$@9&4@0V]M86YD;R!02%``0VAU=F$@1G)A8V$@
M5F5S<&5R=&EN80!#:'5V82!697-P97)T:6YA`$-H=79A<R!697-P97)T:6YA
M<P!.979E(%9E<W!E<G1I;F$`3F5V87-C82!697-P97)T:6YA`$YE=F4@5F5S
M<&5R=&EN80!4<F]V;V%D87,@5F5S<&5R=&EN87,`17-TX2!F86QT86YD;R!A
M(&5X=&5N<^-O(%!/4TE8`$QI;FAA(&1E($-O;6%N9&\@4%](4`!-87)G96T`
M4&%Q=6ES=.-O`%!A;&%U`%!A;&5S=&EN;RP@5&5R<FET\W)I;R!/8W5P861O
M`%!A;F%MX0!0X7!U82!.;W9A($=U:6[I`%!A<F%G=6%I`%!A<F-I86QM96YT
M92!.=6)L861O`%-E;FAA`%-E;FAA(&%L=&5R861A(&-O;2!S=6-E<W-O+@!3
M96YH82!I;F-O<G)E=&$`4V5N:&$@;V)R:6=A=/-R:6$@<&%R82!A(&%U=&5N
M=&EC8>?C;R!2041)55,N`%-E;FAA(&-O;2!C;VYF:7)M8>?C;P!396YH83H`
M4V5N:&$Z(`!396YH87,@9&5V96T@<V5R(&EG=6%I<RX`0V]L87(`0V]L87(@
M9&$@X7)E82!D92!T<F%N<V9E<NIN8VEA`%!A=&@`0V%D87-T<F]S(%!E;F1E
M;G1E<SH`4&5S<V]A<P!0;W)C96YT86=E;0!%>&5C=71A<B!/<&5R8>?U97,@
M9&4@36%N=71E;N?C;P!%>&5C=71A<B!O<&5R8>?U97,@9&4@;6%N=71E;N?C
M;R!A;R!C;VYE8W1A<C\`4&5R;6ES<^-O`%!E<FUI<W/C;R`B)7,B(&[C;R!E
M>&-L=>UD82X`4&5R;6ES<^-O($YE9V%D80!097)M:7-S]65S`$%D;6EN:7-T
M<F'GXV\@9&4@4&5R;6ES<_5E<P!);F9O<FUAY_5E<R!097-S;V%I<P!097)U
M`$%N:6UA:7,@9&4@17-T:6UAY^-O`$9I;&EP:6YA<P!496QE9F]N90!&;W1O
M<P!0:71C86ER;@!0:7AE;',`0VQI8VCI`%!O<B!F879O<B!C;&EQ=64@96T@
M86QG=6UA(&/I;'5L80!0;W(@9F%V;W(@8V]N9FER;64@<75E('9O8^H@<75E
M<B!R96UO=F5R(&5S=&4@96QE;65N=&\Z`%!O<B!F879O<B!C;VYF:7)M92!Q
M=64@=F]CZB!Q=65R(')E;6]V97(@;R!L:6YK(&1E<W1E(&5L96UE;G1O+@!0
M;W(@9F%V;W(@9F]R;F7G82!U;2!MZG,@92!U;2!A;F\N`%!O<B!F879O<B!F
M;W)N9>=A('5M(&YO;64@<&%R82!A(&YO=F$@8V%T96=O<FEA.@!0;W(@9F%V
M;W(@9F]R;F7G82!U;2!E;F1E<F7G;R!)4"!VX6QI9&\N`%!O<B!F879O<B!F
M;W)N9>=A('5M82!D871A(';A;&ED82P@=F5R:69I<75E(&\@;OIM97)O(&1E
M(&1I87,@;F\@;>IS+@!0;W(@9F%V;W(@9F]R;F7G82!U;6$@:&]R82!VX6QI
M9&$N`%!O<B!F879O<B!F;W)N9>=A(&\@;F]M92!P87)A(&$@;F]V82!P87-T
M83H`4&]R(&9A=F]R(&9O<FYEYV$@=6T@<F5S=6UO(&1O('!R;V)L96UA+@!0
M;W(@9F%V;W(@9F]R;F7G82!S974@=7-UX7)I;R!E('-E;FAA`%!O<B!F879O
M<B!L96EA(&\@=&5X=&\@82!S96=U:7(N(%9O8^H@1$5612!C;VYC;W)D87(@
M8V]M(&]S('1E<FUO<R!D92!U<V\@9&\@<VES=&5M82X`4&]R(&9A=F]R(&1I
M9VET92!O(&YO;64@9&$@;F]V82!C871E9V]R:6$Z`%!O;/1N:6$`4&]L[71I
M8V$`16YQ=65T90!0;W)T=6=A;`!0;W-IY^-O(&1E<W1A(&EM86=E;0!0;W-I
MY^-O(&1E<W1A('1A8F5L80!%;G9I92!P87)A(&5S=&$@<&%S=&$@*&[C;R#I
M(&]B<FEG861O('!E;&\@24U!4"D`4')E8VEP:71AY^-O('!A<F$@82AS*2#Z
M;'1I;6$H<RD@)7,@:&]R82AS*3H@`%!R96-I<&ET8>?C;SQB<B`O/F-H86YC
M90!0<F5F<U]L9&%P.B!%>'1E;G/C;R!,1$%0(&]B<FEG873S<FEA(&[C;R!E
M;F-O;G1R861A+@!0<F5F<U]S97-S:6]N.B!%>'1E;G/C;R!D92!S97-SXV\@
M;V)R:6=A=/-R:6$@;N-O(&5N8V]N=')A9&$N`%!R97-SXV\`4')E<W/C;R!E
M;2!N[79E;"!D;R!M87(Z(`!0<F5S<^-O.B``4'+I+79I<W5A;&EZ8>?C;P!0
M<F5V97(@82!I;6%G96T@96T@=6UA(&YO=F$@:F%N96QA`$]PY_5E<R!A;G1E
M<FEO<F5S`$EM<')I;6ER(&1O8W5M96YT;P!#:&%V92!0<FEV861A`%!R;V)L
M96UA`$1E<V-R:>?C;R!D;R!0<F]B;&5M80!0<F]J971O<P!497AT;R!B<F5V
M90!#:&%V92!0^F)L:6-A`$%L9V]R:71M;R!D82!#:&%V92!0^F)L:6-A`$-H
M879E(%#Z8FQI8V$`4&%R(&1E(&-H879E<R!0^F)L:6-A+U!R:79A9&$@;N-O
M(&9O<F%M(&=E<F%D;W,@8V]M('-U8V5S<V\N`%!O<G1O(%)I8V\`46%T87(`
M0V]N<W5L=&%R`%%A=&%R`$-H879E(%#Z8FQI8V$@4E-!("@E9"!B:70I`%)?
M87KC;P!";W3U97,@9&4@<V5L9>?C;P!#:'5V80!#:'5V82!-871U=&EN80!#
M:'5V82!697-P97)T:6YA`%!A;F-A9&%S(&1E($-H=79A`$-H=79A(&4@3F5V
M90!#:'5V82!P87)A($YE=F4`4V]R=&4@06QE873S<FEA`%)E;&'GXV\`3&5R
M`$QE<B!M96YS86=E;G,`17AC;'5I<B!R96%L;65N=&4@)7,_($5S=&$@;W!E
M<F'GXV\@;N-O('!O9&4@<V5R(&1E<V9E:71A+@!296UO=F5R(')E86QM96YT
M92!O<R!D861O<R!D;R!U<W7A<FEO("5S/R!%<W1A(&]P97)AY^-O(&[C;R!P
M;V1E('-E<B!D97-F96ET82X`4F5C96EV960`4F5D:7)E8VEO;F%R('!A<F$`
M4F5F87H@<W5A(/IL=&EM82!AY^-O`$%T=6%L:7IA<@!!='5A;&EZ87(@365N
M=2!D92!%;&5M96YT;W,@1&ENXFUI8V]S.@!!='5A;&EZ87(@17AI8FGGXV\@
M9&\@4&]R=&%L.@!296=E>`!%>'!R97-SXV\@<F5G=6QA<@!296IE:71A<B!C
M;VT@82!R87KC;P!.879E9V%D;W(@9&4@4F5L8>?U97,`3&5R`$]B<V5R=F'G
M]65S`%-E<G9I9&]R97,@4F5M;W1O<P!54DP@4F5M;W1A("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E<@!296UO=F5R($)L;V-O`%)E
M;6]V97(@8V]L=6YA`%)E;6]V97(@9F]R;6%T8>?C;P!296UO=F5R('!A<@!2
M96UO=F5R('-C<FEP="!G<F%V861O(&YO(&1I<F5T\W)I;R!T96UP;W+A<FEO
M(&1O('-E<G9I9&]R+@!296UO=F5R(&\`4F5M;W9E<B!E<W1E(&[S(&1O(&1O
M8W5M96YT;P!296UO=F5R('5S=>%R:6\`4F5M;W9E<B!U<W7A<FEO.B`E<P!3
M;VQI8VET8>?C;R!NXV\@</1D92!S97(@<F5S<&]N9&ED82X@0_-D:6=O(&1E
M(&5R<F\@<F5T;W)N861O.B``3R!S97)V:>=O(')E<75I<VET861O(&[C;R!P
M;V1E('-E<B!E;F-O;G1R861O+@`G)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@
M97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R`E<RX`)R5S)R!O8G)I9V%T
M\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@5D93
M+@`G)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O
M;F9I9W5R8>?C;RX`0V%M<&\@3V)R:6=A=/-R:6\`4F5S96YT(%1O`%)E<V5N
M="UF<F]M`$QI;7!A<@!'97)A<B!.;W9A(%-E;FAA`$=E<F%R($YO=F$@4V5N
M:&$`VFQT:6UO(%%U87)T;P!297-U;'1A9&]S`%)E=&]R;F%R('!A<F$@82!,
M:7-T82!D92!&:6QT<F]S`%)E=&]R;F%R(.`@3W#G]65S`%)E=&]R;F%R('!A
M<F$@82!,:7-T82!D92!296=R87,`1&EG:71E(&$@;F]V82!S96YH82!N;W9A
M;65N=&4`4F5U;FGC;P!2979E<G1E<B!#;VYF:6=U<F'GXV\`3W#G]65S(&1O
M($5D:71O<B!2:6-H(%1E>'0`0VAA<F%D87,`1&ER96ET80!#86)EYV%L:&\@
M9&ER96ET;P!686QO<F5S(&1A(&1I<F5I=&$`4')O<')I961A9&5S(&1A(%],
M:6YH82XN+@!&=6[GXV\`4F]MZFYI80!':7)A<B`Q.#`@9W)A=7,`1VER87(@
M<&%R82!A($5S<75E<F1A`$=I<F%R('!A<F$@82!$:7)E:71A`%!R;W!R:65D
M861E<R!D82!,:6YH80!0<F]P<FEE9&%D97,@9&$@;&EN:&$`3&EN:&%S.@!2
M96=R80!296=R82!#;W!I861A`%)E9W)A($5X8VQU[61A`%)E9W)A($1E<V%T
M:79A9&$`4F5G<F$@071I=F%D80!.;VUE(&1A(%)E9W)A`%)E9W)A.@!,:6YH
M87,`3&EN:&%S(&%P87)E8V5RXV\@96YT<F4@=&]D87,@87,@;&EN:&%S(&4@
M8V]L=6YA<P!,:6YH87,@87!A<F5C97+C;R!S;VUE;G1E(&5N=')E(&-O;'5N
M87,`3&EN:&%S(&%P87)E8V5RXV\@<V]M96YT92!E;G1R92!L:6YH87,`17AE
M8W5T87(`1F5D97)AY^-O(%)U<W-A`%)U86YD80!!<W-I;F%T=7)A($-R:7!T
M;V=RX69I8V$@4R]-24U%`$UE;G-A9V5M($-R:7!T;V=R869A9&$@8V]M(%,O
M34E-10!!=71E;G1I8V'GXV\@4T%33"!NXV\@97-TX2!D:7-P;V[M=F5L+@!#
M;W)R96EO(%--4P!,:6YH82!D92!C;VUA;F1O(%-13`!396YT96[G82!344P@
M<&%R82!P97-Q=6ES87,@9&4@=F%L;W)E<P!34T@`3R!35$%25%1,4R!F86QH
M;W4Z("@E<RD@)7,`4U5#15-33P!,:6YH82!D92!C;VUA;F1O(%-?44P`4V%B
M`%-A;G1A($AE;&5N80!3XV\@2VET=',@92!.979I<P!386YT82!,=7II80!3
MXV\@4&5D<F\@92!-:7%U96QO;@!3XV\@5FEC96YT92!E($=R86YA9&EN87,`
M365S;6\@<75A9')O("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3XV\@5&]M
MZ2!E(%!R[6YC:7!E`%!R;W9E9&]R(&1E(%-A=.EL:71E`$%RX6)I82!3875D
M:71A`%-A;'9A<@!386QV87(@)7,`4V%L=F%R("5S`%-A;'9A<B!/<.?U97,`
M4V%L=F%R($-O;F9I9W5R8>?U97,`4V%L=F%R(&-O;F9I9W5R8>?C;R!G97)A
M9&$@8V]M;R!U;2!S8W)I<'0@4$A0('!A<F$@;R!D:7)E=/-R:6\@=&5M<&]R
MX7)I;R!D;R!S974@<V5R=FED;W(N`$-O;F9I9W5R8>?C;R`E<R!S86QV82X`
M4V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!S86QV;R!E
M;3H@)R5S)RX`5&5M<&5S=&%D97,@27-O;&%D87,`0VGJ;F-I80!2;W1I;F$`
M071U86QI>F%N9&\@4F]T:6YA`%)O=&EN82!NXV\@071U86QI>F%D82X`4F]T
M:6YA(&%T:79A9&$@8V]M('-U8V5S<V\N`%)O=&EN82!D97-A=&EV861A(&-O
M;2!S=6-E<W-O+@!097-Q=6ES87(`16YG:6YE<R!D92!097-Q=6ES82``3&ED
M80!396QE8VEO;F4@;W,@07)Q=6EV;W,`4V5L96-I;VYE('5M82!D871A`%-E
M;&5C:6]N92!U;2!C86UP;P!396QE8VEO;F4@=6T@9W)U<&\@<&%R82!A9&EC
M:6]N87(`4V5L96-I;VYE('5M(&YO=F\@;65M8G)O`%-E;&5C:6]N92!U;2!S
M97)V:61O<@!396QE8VEO;F4@=6T@=7-UX7)I;R!P87)A(&%D:6-I;VYA<@!3
M96QE8VEO;F%R('1O9&]S`%-E;&5C:6]N92!T;V1O<R!O<R!C;VUP;VYE;G1E
M<R!D92!D871A+@!396QE8VEO;F4@=6T@;V)J971O`$[C;R!S96QE8VEO;F%R
M(&YE;FAU;0!396QE8VEO;F4@82!P87-T82!D97-T:6YO`%-E;&5C:6]N92!O
M<R!C87)A8W1E<F5S('%U92!V;V/J('!R96-I<V$@;F$@8V%I>&$@86)A:7AO
M+B!6;V/J('!O9&4@96YTXV\@8V]P:>$M;&]S(&4@8V]LX2UL;W,@;F$@X7)E
M82!D92!T97AT;RX`4V5L96-I;VYE('5M(&1E;&EM:71A9&]R(&1E(&1A=&$Z
M`%-E;&5C:6]N92!O(&9O<FUA=&\@9&4@9&%T83H`4V5L96-I;VYE(&$@:61E
M;G1I9&%D92!Q=64@=F]CZB!Q=65R(&%L=&5R87(Z`%-E;&5C:6]N92!U;2!D
M96QI;6ET861O<B!D92!H;W)A.@!396QE8VEO;F4@;R!F;W)M871O(&1E(&AO
M<F$Z`%-E;&5C:6]N92!D;VES(&-A;7!O<R!C;W)R97-P;VYD96YT97,N`%-E
M;&5C:6]N92!S974@97-Q=65M82!D92!C;W)E<RX`4V5L96-I;VYE('-E=2!I
M9&EO;6$@<')E9F5R:61O.@!#86)EYV%L:&\@4&5R<V]N86QI>F%D;P!%;G9I
M87(@4F5L873S<FEO(&1E(%!R;V)L96UA`$5N=FEA<B!335,`4F5M971E;G1E
M`%-E;F5G86P`4V5N<V]R.B``4V5T96UB<F\`4V5R=FEA(&4@36]N=&5N96=R
M;P!.^FUE<F\@9&4@4^ER:64`1&%D;W,@9&\@<V5R=FED;W(@97)R861O<R!O
M=2!NXV\@9&ES<&]N[79E:7,N`$%D;6EN:7-T<F%D;W(@9&4@4V5S<^-O`$E$
M(&1A(%-E<W/C;R!E>'!I<F]U+@!397-S]65S`$%J=7-T87(`0V]N9FEG=7)A
M(&%S(&]PY_5E<R!P87)A('!E<FUI=&ER('9O8^H@9V5R87(@=6UA(&YO=F$@
M<V5N:&$@<V4@=F]CZB!E<W%U96/J+6QA+@!#;VYF:6=U<F$@;W,@<V5R=FED
M;W)E<R!R96UO=&]S('%U92!V;V/J('%U97(@86-E<W-A<B#@('!A<G1I<B!D
M;R!P;W)T86PN`$-O;F9I9W5R82!S974@:61I;VUA('!R969E<FED;RP@9G5S
M;R!H;W+A<FEO(&4@;W#G]65S(&1E(&1A=&$N`$-O;F9I9W5R82!S=6$@87!L
M:6-AY^-O(&EN:6-I86PL(&5S<75E;6$@9&4@8V]R97,L(&%T=6%L:7IAY^-O
M(&1E('#A9VEN87,@92!O=71R87,@;W#G]65S(&1E(&5X:6)IY^-O+@!#;VYF
M:6=U<F'G]65S(&%T=6%L:7IA9&%S(&-O;2!S=6-E<W-O+@!#;VYF:6=U<F'G
MXV\`4V-R:7!T<R!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@9&ES
M<&]N[79E:7,`1&EV97)S87,@;&]C86QI9&%D97,@<&]S<^UV96ES(&-O;2!O
M('!A<N)M971R;SH@`%-E:6-H96QE<P!#;VUP<F%S`%)E<W5M;P!496-L87,@
M9&4@871A;&AO(&1E=F5RXV\@<V5R(&1E9FEN:61A<R!P87)A(&$@;6%I;W)I
M82!D;W,@;&EN:W,_`$5X:6)I<@!%>&EB:7(@4F]T:6YA($%T:79A`$5X:6)I
M<B!2;W1I;F$@071U86P`17AI8FER(&%S(&1I9F5R96[G87,@96YT<F4@82!C
M;VYF:6=U<F'GXV\@871U86P@92!A(&YO=F$@9V5R861A+@!%>&EB:7(@9&%T
M82!E(&AO<F$@9&$@^FQT:6UA(&-O;F5XXV\@86\@<V4@8V]N96-T87(_`$5X
M:6)I<B!A(&]PY^-O(&1E(&UA;G1E<B!O(&]R:6=I;F%L`$5X:6)I<B!S96QE
M=&]R`$5X:6)I<B!B87)R82!D92!M96YU(&-O;2!O<&5R8>?U97,@9&4@=&%B
M96QA/P!%>&EB:7(@;R!-96YU("5S(.`@97-Q=65R9&$_`$5X:6)I<B!D:>%L
M;V=O(&1E(%!R;W!R:65D861E<R!D92!#Z6QU;&%S(&1A(%1A8F5L80!%>&EB
M:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&$@5&%B96QA`$5X:6)I<B!D
M:>%L;V=O(&1E(%!R;W!R:65D861E<R!D92!,:6YH87,@9&$@5&%B96QA`$5X
M:6)I<B!D:>%L;V=O(&1E('!R;W!R:65D861E<R!D92!I;6%G96T`17AI8FER
M('5P;&]A9`!#:'5V87,`0VAU=F%S(&UA=&EN86ES`$-H=79A<R!697-P97)T
M:6YA<P!#:'5V87,@;F%S(')E9&]N9&5Z87,`4F5D=7II<@!0<FEM96ER86UE
M;G1E(')E9'5Z82!O=2!T:7)E(&1O(&-A;6EN:&\@;RAS*2!B;&]C;RAS*2!A
M9&IA8V5N=&4H<RD`4V5R<F$@3&5O80!296=I<W1R87(`07-S:6YA='5R80!!
M;&=O<FET;6\@9&$@07-S:6YA='5R80!&:6QT<F%G96T@<VEM<&QE<R!D92!S
M<&%M(&[C;R#I('-U<&]R=&%D82!P96QO(&-O;F5C=&]R(&1E(&9I;'1R;R!A
M='5A;"X`0VEN9V%P=7)A`%1A;6%N:&\`26=N;W)A<B!-86YU=&5NY^-O`$5S
M;&]VX7%U:6$`17-L;W9E;FEA`$YE=F4`3F5V87-C80!.979A<V-A<P!#:'5V
M87,@;6%T:6YA:7,`3F5V87-C87,@5F5S<&5R=&EN87,`4')O9G5N9&ED861E
M(&1A($YE=F4Z(`!%<75I=F%L96YT92!D92!N979E(&5M(.%G=6$Z(`!);&AA
M<R!386QO;>-O`%-O;>%L:6$`0V%NY_5E<R`F(%!O96UA<P!/<F1E;F%R('-E
M;&7GXV\`16YD97)EYV\@9&4@;W)I9V5M`,%F<FEC82!D;R!3=6P`4W5L($5U
M<F]P974@*$E33RTX.#4Y+3,I`%-U;"!D82!'96]R9VEA(&4@4W5L(&1A<R!)
M;&AA<R!386YD=>UC:&4`2&5M:7-FZ7)I;R!3=6P`17-P8>=O(&5N=')E(&/I
M;'5L87,@861J86-E;G1E<P!%<W!AYV\@96YT<F4@;R!C;VYT9?ID;R!E(&)O
M<F1A(&1A(&/I;'5L80!%<W!AYV%D;W(`17-P8>=A;65N=&\`17-P8>=A;65N
M=&\@92!M87)G96T`17-P86YH80!3<&%M`$9I;'1R;R!D92!3<&%M`$5N=')A
M9&$@9&4@0V%R86-T97)E<R!%<W!E8VEA:7,`1&EV:61I<B!CZ6QU;&$`1&EV
M:61I<B!C;VQU;F$`1&EV:61I<B!L:6YH80!%<W!O<G1E<P!3<FD@3&%N:V$`
M4&%D<N-O`%-T87(@5')E:P!!;F\@:6YI8VEA;`!%<W1A9&\@;W4@4')O=NUN
M8VEA`%-I='5AY^-O`%!A<F%R(&$@8VAE8V%G96T@<V4@97-T82!R96=R82!C
M;W)R97-P;VYD97(_`$9O<FUA=&\@9&\@87)M87IE;F%M96YT;P!.;VUE(&1A
M(%)U80!4<F'G861O`$QI<W1A(&1E(&-A9&5I87,@9&4@8V%R86-T97)E<P!2
M971I<F%R(&$@<&%R=&4@9&\@9&]M[6YI;R!D;R!E;F1E<F7G;P!%<W1I;&\@
M6T-34UT`1&]M`%-U8F1I<F5T\W)I;R`G)7,G(&[C;R!E;F-O;G1R861O+@!!
M7W-S=6YT;R!D82!M96YS86=E;2!D92!FZ7)I87,Z`$%S<W5N=&\`07-S=6YT
M;SH`16YV:6%R`$5N=FEA9&$@82!S;VQI8VET8>?C;R!D92!A9&EC:6]N87(@
M(B5S(B!A;R!S:7-T96UA+B!6;V/J(&[C;R!P;V1E(&-O;F5C=&%R+7-E(&%T
MZ2!Q=64@<W5A('-O;&EC:71AY^-O('-E:F$@87!R;W9A9&$N`%-U8G-C<F5V
M97(`4W5C97-S;P`G)7,G(&%D:6-I;VYA9&\@8V]M('-U8V5S<V\@86\@<VES
M=&5M82X`3W,@9&%D;W,@9&\@=7-UX7)I;R`G)7,G(&9O<F%M(')E;6]V:61O
M<R!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+@`G)7,G(&5X8VQU[61O(&-O;2!S
M=6-E<W-O+@!%>&-L=>UD;R`G)7,G(&1O('-I<W1E;6$@8V]M('-U8V5S<V\N
M`$-O;F9I9W5R8>?C;R!R979E<G1I9&$@8V]M('-U8V5S<V\N($%T=6%L:7IE
M('!A<F$@=F5R(&%S(&%L=&5R8>?U97,N`$)A8VMU<"!D82!C;VYF:6=U<F'G
MXV\@<V%L=F$@8V]M('-U8V5S<V\N`$\@8F%C:W5P(&1O(&%R<75I=F\@9&4@
M8V]N9FEG=7)AY^-O("5S(&9O:2!S86QV;R!C;VT@<W5C97-S;RX`)R5S)R!A
M='5A;&EZ861O(&-O;2!S=6-E<W-O`"5S(&=R879A9&\@8V]M('-U8V5S<V\`
M4W5DXV\`4F5S=6UO`$%M86YH96-E<@!0]'(M9&\M4V]L`$5N<V]L87)A9&\`
M06UA;FAE8V5R`$%M86YH96-E<B]0]'(M9&\M4V]L`$%M86YH96-E<CH@`%#T
M<BUD;RU3;VP`4/1R+61O+5-O;#H@`%-O8G)E<V-R979E<@!3=7!O<G1E`%-U
M<FEN86UE`%-O8G)E;F]M90!3=F%L8F%R9"!E($IA;B!-87EE;@!3=6%Z:6SB
M;F1I80!3=>EC:6$`4W7MYV$`3N-O(&5X8VQU:7(`4WEN8TU,`$5R<F\@9&4@
M<VEN=&%X92!N;W,@=&5R;6]S(&1A('!E<W%U:7-A`%)E</IB;&EC82#!<F%B
M92!D82!3[7)I80!496UP97-T861E`%1E;7!E<W1A9&5S(&4@5F5N=&%N:6$`
M5&5M<&5S=&%D97,`5&5M<&5S=&%D97,@36%T:6YA:7,`07)Q=6EV;R!44U8`
M5&%B96QA`%!R;W!R:65D861E<R!D82!486)E;&$`5&%B96QA`%!R;W!R:65D
M861E<R!D82!T86)E;&$`5&%I=V%N`%1A:7=A;BP@4')O=NUN8VEA(&1A($-H
M:6YA`%1A:FEQ=6ES=.-O`%1A;GKB;FEA+"!297#Z8FQI8V$@9&$`06QV;SH`
M5&%R969A<P!.^FUE<F\@9&4@5&5L969O;F4`5&5M<&5R871U<F$@<&%R82!A
M(/IL=&EM82!H;W)A.B``5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!496UP
M97)A='5R83QB<B`O/B@E<T%L=&$E<R\E<T)A:7AA)7,I("9D96<[)7,`36]D
M96QO("<E<R<@;N-O(&5N8V]N=')A9&\N`$%D;6EN:7-T<F'GXV\@9&4@36]D
M96QO<P!497AT;P!3;VUE;G1E(%1E>'1O`$%L:6YH86UE;G1O(&1E(%1E>'1O
M`$)O<F1A('-U<&5R:6]R(&1O(%1E>'1O`%%U:0!486EL86YDZG,@*%1)4RTV
M,C`I`%1A:6SB;F1I80!!(&5X=&5N<^-O($944"!NXV\@97-TX2!D:7-P;V[M
M=F5L+@!/(&AI<W3S<FEC;R!D;R!S:7-T96UA(&5S=.$@9&5S86)I;&ET861O
M+@!!(&5N9VEN92!D92!I;G1E9W)AY^-O($AO<F1E+TMO;&%B(&[C;R!S=7!O
M<G1A("(E<R(`3R!L;V<@24U34"!NXV\@<&]D92!S97(@:6YI8VEA;&EZ861O
M+@!!(&-L87-S92`B36%I;G1E;F%N8V4B(&[C;R!F;VD@8V%R<F5G861A(&-O
M;2!S=6-E<W-O`$$@:F%N96QA(&1E($]PY_5E<R!F;VD@9F5C:&%D82X@4V%I
M;F1O+@!/(&5N9&5R9>=O("(E<R(@9F]I(&%D:6-I;VYA9&\@82!S=6$@;&ES
M=&$@;F5G<F$N`$\@96YD97)EYV\@(B5S(B!F;VD@861I8VEO;F%D;R!A('-U
M82!L:7-T82!B<F%N8V$N`$\@861M:6YI<W1R861O<B!P<F5C:7-A(&-O;F9I
M9W5R87(@=6T@8V]N96-T;W(@<&5R;6%N96YT92!D92!097)M:7-S]65S('-E
M('9O8^H@<75E<B!U=&EL:7IA<B!097)M:7-S]65S+@!3;VUE;G1E(&\@;&%D
M;R!D92!B86EX;P!/(&[Z;65R;R!)1"!D;R!C;VYT871O(&[C;R!F;VD@97-P
M96-I9FEC861O+"!D96EX861O(&5M(&)R86YC;R!O=2!NXV\@9F]I(&5N8V]N
M=')A9&\@;F\@8F%N8V\@9&4@9&%D;W,N`$\@8V]N=&%T;R!F;VD@861I8VEO
M;F%D;R!C;VT@<W5C97-S;R!A;R!S974@8V%TX6QO9V\@9&4@96YD97)EYV]S
M+@!087)A('9E<FEF:6-A<B!A(&UE;G-A9V5M(&%S<VEN861A(.D@;F5C97-S
MX7)I;R!U;2!B;&]C;R!S97!A<F%D;R!D82!A<W-I;F%T=7)A(%!'4"X`3R!)
M1"!D82!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF:6-A
M9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@96YC;VYT<F%D;R!N
M;R!B86YC;R!D92!D861O<RX`02!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O
M(&9O:2!E<W!E8VEF:6-A9&$N`$\@8V]N96-T;W(@9&ES<V4Z(`!!<R!F=6[G
M]65S(&1E(&-R:7!T;V=R869I82!R97%U97)E;2!U;6$@8V]N97CC;R!W96(@
M<V5G=7)A+@!/(&%R<75I=F\@)7,@9&5V97)I82!C;VYT97(@=6UA(&-O;F9I
M9W5R8>?C;R!D92`E<RX`3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N=&5R(&%L
M9W5M87,@8V]N9FEG=7)AY_5E<R!D92`E<RX`3R!A<G%U:79O(&[C;R!P;V1E
M('-E<B!C;W!I861O('!A<F$@96QE(&UE<VUO+@!/(&%R<75I=F\@;N-O(&-O
M;G3I;2!D861O<RX`4V5G=65M(&]S(&-A8F7G86QH;W,@9&5S=&$@;65N<V%G
M96TO;65N<V%G96T@<F9C.#(R+@#)('-A8FED;R!Q=64@;R!M;V1O('1E;&$@
M8VAE:6$@8V%U<V$@<')O8FQE;6%S(&-O;2!O($EN=&5R;F5T($5X<&QO<F5R
M+"!E;2!V:7)T=61E(&1E(&)U9W,@9&\@;F%V96=A9&]R('%U92!N\W,@;N-O
M(&5S=&%M;W,@87!T;W,@82!C;VYT;W)N87(N(%9O8^H@<&]D92!O8G-E<G9A
M<B!E<G)O<R!D92!E>&EB:>?C;RP@9F%L=&$@9&4@9G5NY_5E<R!D;R!E9&ET
M;W(@92]O=2!T<F%V86UE;G1O<R!A;&5A=/-R:6]S(&1O(&YA=F5G861O<BX@
M4V4@<V5U('-I<W1E;6$@Z2!7:6YD;W=S(#EX(.D@;75I=&\@<')O=N%V96P@
M<75E('9O8^H@<F5C96)A('5M(&5R<F\@9&4@)T9A;&AA($=E<F%L(&1E(%!R
M;W1EY^-O)R!E('!R96-I<V%RX2!R96EN:6-I87(N(%QN7&X@5F]CZB!F;VD@
M879I<V%D;RX@4&]R(&9A=F]R('!R97-S:6]N92!/2R!S92!V;V/J(&%I;F1A
M('%U97(@=&5N=&%R('5S87(@;R!E9&ET;W(@9&4@=&5L82!C:&5I82X`02!I
M9&5N=&ED861E("(E<R(@9F]I(&5X8VQU[61A+@!3;VUE;G1E(&\@;&%D;R!E
M<W%U97)D;P!!(&QO8V%L:7IAY^-O(&1O(&)I;N%R:6\@9&\@1VYU4$<@9&5V
M92!S97(@9F]R;F5C:61A(.`@8VQA<W-E(")#<GEP=%]P9W`B+@!!(&UE;G-A
M9V5M(&5N=FEA9&$@96T@)7,@<&%R82`E<R!C;VT@;R!A<W-U;G1O("(E<R(@
M9F]I(&5X:6)I9&$N"DES=&\@;N-O(&=A<F%N=&4@<75E(&$@;65N<V%G96T@
M9F]I(&QI9&$@;W4@96YT96YD:61A+@!/(&YO;64@=71I;&EZ861O(&%O('9I
M;F-U;&%R(&$@<.%G:6YA(&1E(&-O;7!O<VGGXV\`3R!N^FUE<F\@9&4@8V%M
M<&]S(&1E=F4@<V5R(&YU;>ER:6-O+@!/(&WS9'5L;R!O<&5N<W-L(.D@;V)R
M:6=A=/-R:6\@<&%R82!A(&-L87-S92`B2&]R9&5?0W)Y<'1?<VUI;64B+@!!
M('!R969E<NIN8VEA("(E<R(@;N-O('!O9&4@<V5R('-A;'9A('!O<G%U92!S
M975S(&1A9&]S(&5X8V5D97)A;2!O('1A;6%N:&\@;>%X:6UO('!E<FUI=&ED
M;P!/('!R;V=R86UA('5T:6QI>F%D;R!P87)A('9I<W5A;&EZ87(@97-T92!T
M:7!O(&1E(&1A9&\@*"5S*2!NXV\@9F]I(&5N8V]N=')A9&\@;F\@<VES=&5M
M82X`3R!C87)A8W1E<F4@<&%R82!C:71AY^-O(&1E('-E<B!A<&5N87,@=6TN
M`%-O;65N=&4@;W,@;&%D;W,@9&ER96ET;R!E(&5S<75E<F1O`%-O;65N=&4@
M;R!L861O(&1I<F5I=&\`3R!S97!A<F%D;W(@9&5V92!S97(@=6T@^FYI8V\@
M8V%R86-T97)E+@!/('-E<G9I9&]R("(E<R(@9F]I(&5X8VQU[61O+@!/('-E
M<G9I9&]R("(E<R(@9F]I('-A;'9O+@!!('-O;&EC:71AY^-O(&1E(&-A9&%S
M=')O(&1E("5S(&9O:2!E>&-L=>UD82X`02!L:6YH82!E<W!E8VEF:6-A9&$@
M*"5D*2!NXV\@97AI<W1E+@!/(&%R<75I=F\@=&5M<&]RX7)I;R`B)7,B(&[C
M;R!E>&ES=&4N`$\@=&5X=&\@<75E('9O8^H@9&EG:71O=2!NXV\@8V]R<F5S
M<&]N9&4@86\@=&5X=&\@;F$@=&5L82X`4V]M96YT92!O<R!L861O<R!D92!C
M:6UA(&4@9&4@8F%I>&\`4V]M96YT92!O(&QA9&\@9&4@8VEM80!/<R!D861O
M<R!E;G9I861O<R!F;W)A;2!P97)D:61O<R!D97-D92!O('!A<W-O(&%N=&5R
M:6]R+@!/(&%R<75I=F\@96YV:6%D;R!NXV\@</1D92!S97(@<V%L=F\N`$\@
M8FQO8V\@(G=E871H97(N8V]M(B!NXV\@97-TX2!D:7-P;V[M=F5L+@!/(&1I
M<F5T\W)I;R!D92!T96UA<R`G)7,G(&[C;R!F;VD@96YC;VYT<F%D;RX`3N-O
M(&5X:7-T96T@;W#G]65S(&1I<W!O;NUV96ES+@!.XV\@97AI<W1E;2!P87)T
M97,@<75E('!O<W-A;2!S97(@97AI8FED87,@:6YC;W)P;W)A9&%S+@!%>&ES
M=&5M(&UU:71O<R!C87)A8W1E<F5S(&YE<W1E(&-A;7!O+B!6;V/J('!R965N
M8VAE=2!C;VT@)7,@8V%R86-T97)E<SL@=F]CZB!D979E('!R965N8VAE<B!C
M;VT@)7,@;W4@;65N;W,N`$AO=79E('5M('!R;V)L96UA(&%D:6-I;VYA;F1O
M("<E<R<@86\@<VES=&5M83H@)7,`2&]U=F4@=6T@<')O8FQE;6$@86\@97AC
M;'5I<B!D;R!S:7-T96UA(&]S(&1A9&]S(&1O('5S=>%R:6\@)R5S)SH@`$AO
M=79E('5M('!R;V)L96UA(&%O(&5X8VQU:7(@)R5S)R!D;R!S:7-T96UA.B``
M2&]U=F4@=6T@<')O8FQE;6$@86\@871U86QI>F%R("<E<R<Z("5S`$AO=79E
M('5M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\Z($YE;FAU;2`E
M<R!F;VD@96YV:6%D;RX`2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@96YV:6\@
M9&\@87)Q=6EV;RX@3R`E<R!E<F$@;6%I;W(@<75E(&\@=&%M86YH;R!MX7AI
M;6\@<&5R;6ET:61O("@E9"!B>71E<RDN`$AO=79E('5M('!R;V)L96UA(&-O
M;2!O(&5N=FEO(&1O(&%R<75I=F\N($\@)7,@9F]I(&5N=FEA9&\@<&%R8VEA
M;&UE;G1E+@!(;W5V92!U;2!E<G)O(&%O(&%T:79A<B!A(')O=&EN82X`2&]U
M=F4@=6T@97)R;R!A;R!D97-A=&EV87(@82!R;W1I;F$N`$AO=79E('5M(&5R
M<F\@86\@97AI8FER(&5S=&$@<&%R=&4@9&$@;65N<V%G96T`2&]U=F4@=6T@
M97)R;R!A;R!I;7!O<G1A<B!O<R!D861O<R!D;R!C;VYT871O+@!(;W5V92!U
M;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S(&1O(&E#86QE;F1A<BX`2&]U
M=F4@=6T@97)R;R!N;R!F;W)M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@5&%L
M=F5Z('9O8^H@9&5I>&]U('5M(&-A;7!O(&]B<FEG873S<FEO(&5M(&)R86YC
M;RX`2&]U=F4@=6T@97)R;R!A;R!E>&5C=71A<B!A(&9U;N?C;R!D92!C873A
M;&]G;R!D92!E;F1E<F7G;W,@97-P96-I9FEC861A+B!0;W(@9F%V;W(@=&5N
M=&4@;F]V86UE;G1E(&UA:7,@=&%R9&4N`$AO=79E('5M(&5R<F\@86\@871U
M86QI>F%R(&]S(&1E=&%L:&5S(&1O(&-O;G1A=&\N(%!O<B!F879O<B!T96YT
M92!N;W9A;65N=&4@;6%I<R!T87)D92X`2&]U=F4@=6T@97)R;R!A;R!A='5A
M;&EZ87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N(%!O<B!F879O<B!T96YT
M92!N;W9A;65N=&4@;6%I<R!T87)D92X`17-T92!S97)V:61O<B!)34%0(&[C
M;R!S=7!O<G1A('!A<W1A<R!C;VUP87)T:6QH861A<RX`17-T92!NXV\@<&%R
M96-E('-E<B!U;2!A<G%U:79O(')A<B!VX6QI9&\N`$5S=&4@;N-O('!A<F5C
M92!S97(@=6T@87)Q=6EV;R!Z:7`@=N%L:61O+@!%<W1E(&[C;R!P87)E8V4@
M<V5R('5M(&[Z;65R;R!D92!C87)TXV\@=N%L:61O+@!%<W1E(&-O;F5C=&]R
M('!E<FUI=&4@96YV:6%R(&UE;G-A9V5N<R!A=')A=NES(&1O($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2DL('5T:6QI>F%N9&\@82!!4$D@
M2%144`!%<W1E(&-O;F5C=&]R('!E<FUI=&4@96YV:6%R(&UE;G-A9V5N<R!A
M=')A=NES(&1O(&=A=&5W87D@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2DL('5T:6QI>F%N9&\@;R!!4$D@2%144`!%<W1E(&-O;F5C=&]R('!E
M<FUI=&4@96YV:6%R(&UE;G-A9V5N<R!A=')A=NES(&1O(&=A=&5W87D@<VUS
M,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2DL('5T:6QI>F%N9&\@;R!!
M4$D@2%144`!%<W1E(&-O;F5C=&]R('!E<FUI=&4@96YV:6%R('5M82!M96YS
M86=E;2!V:6$@4TU44"!A=')A=NES(&1O(%9O9&%F;VYE($ET86QI86YO+"!S
M;VUE;G1E('!A<F$@;OIM97)O<R!6;V1A9F]N92X@R2!O8G)I9V%T\W)I;R!P
M;W-S=6ER('5M82!C;VYT82!N;R!6;V1A9F]N92!)=&%L:6%N;R`H:'1T<#HO
M+W=W=RXQ.3`N:70I+@!%<W1E(&-A;7!O(.D@;V)R:6=A=/-R:6\N`$5S=&4@
M8V%M<&\@<&]D92!C;VYT97(@87!E;F%S(&[Z;65R;W,@:6YT96ER;W,N`$5S
M=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S(&[Z;65R;W,@92!V[7)G=6QA
M+@!%<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!V86QO<F5S(&]C=&%I
M<RX`17-T92!C86UP;R!D979E('-E<B!U;6$@;&ES=&$@9&4@;OIM97)O<R!I
M;G1E:7)O<R!S97!A<F%D82!P;W(@=NUR9W5L87,@;W4@97-P8>=O<P!%<W1E
M(&-A;7!O(&1E=F4@<V5R('5M(&[Z;65R;R!VX6QI9&\N`$5S=&4@8V%M<&\@
M9&5V92!C;VYT97(@=6T@8_-D:6=O(&1E(&-O<B!E;2!F;W)M871O(%)'0B!(
M97AA+"!P;W(@97AE;7!L;R`G(S$R,S1A9B<N`$5S=&4@9F]R;75LX7)I;R!J
MX2!F;VD@<')O8V5S<V%D;RX`27-T;R#I("5S+@!%<W1E(.D@=6T@;V)J971O
M($MO;&%B($=R;W5P=V%R92X@4&%R82!V:7-U86QI>F%R(&5S=&4@;V)J971O
M('9O8^H@<')E8VES87+A(&1E('5M(&-L:65N=&4@9&4@8V]R<F5I;R!Q=64@
M96YT96YD82!O(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E+B!087)A('5M82!L
M:7-T82!D92!C;&EE;G1E<R!D92!C;W)R96EO(&-O;2!E<W1A<R!F=6[G]65S
M('!O<B!F879O<B!V:7-I=&4@)7,`17-T82!M96YS86=E;2!F;VD@97-C<FET
M82!E;2!U;2!C;VYJ=6YT;R!D92!C87)A8W1E<F5S("@E<RD@<75E(&[C;R#I
M(&\@;65S;6\@<75E(&\@<V5U+@!%<W1E(&[Z;65R;R!D979E('-E<B!P96QO
M(&UE;F]S('5M+@!%<W1E('-E<G9I9&]R(&[C;R!P;V1E(&1E<V-O;7!R:6UI
M<B!A<G%U:79O<R!Z:7`@92!G>FEP+@!%<W1E('-I<W1E;6$@97-TX2!A='5A
M;&UE;G1E(&1E<V%T:79A9&\N`$5S=&4@=F%L;W(@9&5V92!S97(@=6T@;OIM
M97)O+@!%<W1A(&IA;F5L82!D979E('-E<B!C:&%M861A(&$@<&%R=&ER(&1A
M(&IA;F5L82!D92!/<.?U97,`4F%I;P!":6QH971E<P!(;W)A`$%C;VUP86YH
M86UE;G1O(&1E($AO<N%R:6\`1F]R;6%T;R!D92!H;W)A`%-E;&7GXV\@9&4@
M:&]R80!4:6UO<B!,97-T90!4[71U;&\`07-S=6YT;R`H9&EC82DZ`%!A<F$`
M4&%R82!S96QE8VEO;F%R(&WZ;'1I<&QO<R#M=&5N<RP@<V5G=7)E(&$@=&5C
M;&$@0V]N=')O;"`H4$,I(&]U($-O;6UA;F0@*$UA8RD@86\@8VQI8V%R+@!0
M87)A.@!(;VIE`%1R;V-A<B!P87)A(&/S9&EG;R!(5$U,`%1O9V\`5&]K96QA
M=0!!;6%N:.,`5&]N9V$`5&]P;P!1=6%D<F\@9&\@5&]P;R`H7W1O<"D`5')A
M9'7G]65S`%1R:6YD861E(&4@5&]B86=O`%9E<F1A9&5I<F\@;W4@9F%L<V\`
M5&5R`%1U;NUS:6$`5'5R<75I80!4=7)C;R`H25-/+3@X-3DM.2D`5'5R8V]M
M96YI<W3C;P!);&AA<R!4=7)K<R!E($-A:6-O<P!4=79A;'4`4')E96YC:&$@
M8V]M('-U82!E<V-O;&AA.B``S6YD:6-E(%4N5BXZ(`!54DP`55),(&1O('-E
M=2!R96QA=/-R:6\@9&4@<VET=6'GXV\@9&4@96YT<F5G80!54DPZ`%5G86YD
M80!58W+B;FEA`$EM<&]S<^UV96P@86-E<W-A<B!D:7)E=/-R:6\@5D93+@!)
M;7!O<W/M=F5L(&%D:6-I;VYA<B!I;F9O<FUAY_5E<R!E>'1R87,@9&4@=7-U
MX7)I;R!A;R!R96=I<W1R87(N`$EM<&]S<^UV96P@86QT97)A<B!P97)M:7-S
MXV\@9&\@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!A;'1E<F%R('!E
M<FUI<W/C;R!D;R!A<G%U:79O(%9&4R`E<R\E<RX`26UP;W-S[79E;"!A;'1E
M<F%R('!A<F$@)7,N`$EM<&]S<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D
M;R!A<G%U:79O(&1E("(E<R(N`$EM<&]S<^UV96P@=F5R:69I8V%R(&\@=&%M
M86YH;R!D;R!A<G%U:79O(&1E("(E<R\E<R(N`$EM<&]S<^UV96P@8V]N96-T
M87(@86\@<V5R=FED;W(@4U%,+@!);7!O<W/M=F5L(&-O;F5C=&%R('5T:6QI
M>F%N9&\@4U-,+@!);7!O<W/M=F5L(&-O<&EA<B!A<G%U:79O(%9&4RX`26UP
M;W-S[79E;"!C<FEA<B!D:7)E=/-R:6\@5D93("(E<R(N`$EM<&]S<^UV96P@
M8W)I87(@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!C<FEA<B!A<G%U:79O
M(%9&4RX`26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O(%9&4R`B)7,B+@!)
M;7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@5D93('9A>FEO+@!);7!O<W/M=F5L
M(&1E<V-O;7!R:6UI<B!D861O<RX`26UP;W-S[79E;"!E>&-L=6ER("(E<R(L
M(&\@9&ER973S<FEO(&[C;R!E<W3A('9A>FEO+@!);7!O<W/M=F5L(&5X8VQU
M:7(@(B5S(CH@)7,N`$EM<&]S<^UV96P@97AC;'5I<B`E<RP@;R!D:7)E=/-R
M:6\@;N-O(&5S=.$@=F%Z:6\`26UP;W-S[79E;"!E>&-L=6ER(')E8W5R<VEV
M86UE;G1E(&\@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!E>&-L=6ER(&1I
M<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@97AC;'5I<B!D:7)E=/-R:6\@5D93
M.B`E<RX`26UP;W-S[79E;"!E>&-L=6ER(&%R<75I=F\@5D93("(E<R(N`$EM
M<&]S<^UV96P@97AC;'5I<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!E>&-L
M=6ER(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@97AC;'5I<B!61E,@
M<F5C=7)S:79A;65N=&4Z("5S+@!);7!O<W/M=F5L(&1E=&5R;6EN87(@;R!D
M:7)E=/-R:6\@871U86PN`$EM<&]S<^UV96P@97AT<F%I<B!D971A;&AE<R!D
M;R!C97)T:69I8V%D;P!);7!O<W/M=F5L(&-A<G)E9V%R(&$@9&5F:6YIY^-O
M(&1E("5S+@!);7!O<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!61E,N`$EM<&]S
M<^UV96P@86)R:7(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!A8G)I
M<B!A<G%U:79O(%9&4R!P87)A(&=R879AY^-O+@!);7!O<W/M=F5L(&%B<FER
M(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&%B<FER(&%R<75I=F\@8V]M<')I
M;6ED;RX`26UP;W-S[79E;"!L97(@87)Q=6EV;R!61E,@*&9I;&5S:7IE*"D@
M9F%L:&]U*2X`26UP;W-S[79E;"!L97(@87)Q=6EV;R!61E,@*&=E=$9I;&53
M:7IE*"D@9F%L:&]U*2X`26UP;W-S[79E;"!L97(@;R!A<G%U:79O.B``26UP
M;W-S[79E;"!L97(@82!R86EZ(&1O(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV
M96P@<F5N;VUE87(@)7,@<&%R82`E<SH@82!P87-T82!D92!D97-T:6YO(&KA
M(&5X:7-T90!);7!O<W/M=F5L(')E;F]M96%R(&\@9&ER973S<FEO(%9&4RX`
M26UP;W-S[79E;"!R96YO;65A<B!D:7)E=/-R:6\@5D93.B`E<RX`26UP;W-S
M[79E;"!R96YO;65A<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(')E
M;F]M96%R(&%R<75I=F\@5D93("5S+R5S+@!);7!O<W/M=F5L(')E;F]M96%R
M(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&5X96-U=&%R("=M:VES;V9S)RX`
M26UP;W-S[79E;"!T<F%D=7II<B!E<W1E(&1O8W5M96YT;R!7;W)D`$EM<&]S
M<^UV96P@9W)A=F%R(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@9W)A
M=F%R(&%R<75I=F\@5D93("AC;W!Y*"D@9F%L:&]U*2X`26UP;W-S[79E;"!G
M<F%V87(@9&%D;W,@9&\@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@9W)A=F%R
M(&%R<75I=F\@5D93+"!Q=6]T82!E>&-E9&5RX2X`4W5B;&EN:&%D;P!$97-F
M87IE<B!!;'1E<F'G]65S`$1E<V9A>B!S=6$@^FQT:6UA(&'GXV\`4F5S<&]S
M=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!D=7)A;G1E(&$@8V]N97CC;SH@
M`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@<&%R83H@`%-E;2!C
M871E9V]R:6$`56YI8V]D92`H551&+3@I`$5M:7)A9&]S(,%R86)E<R!5;FED
M;W,`4F5I;F\@56YI9&\`17-T861O<R!5;FED;W,`26QH87,@4&5R:6;I<FEC
M87,@365N;W)E<R!D;W,@17-T861O<R!5;FED;W,`56YI9&%D97,`1&5S8V]N
M:&5C:61O`&%P:6US9VED(&1E<V-O;FAE8VED;R`H05!)($UE<W-A9V4@240I
M+@!C;&EM<V=I9"!D97-C;VYH96-I9&\@*$-L:65N="!-97-S86=E($E$*2X`
M3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82X`57-UX7)I;R!O=2!S
M96YH82!D97-C;VYH96-I9&]S+@!$97-V:6YC=6QA<B!O(&5L96UE;G1O(&%T
M=6%L`%-E;2!.;VUE`%-C<FEP=',@;N-O('!R:79I;&5G:6%D;W,@;N-O('!O
M9&5M('5T:6QI>F%R($-O<G1A<B]#;W!I87(O0V]L87(@<&]R(')A>O5E<R!D
M92!S96=U<F%NYV$N($-L:7%U92!E;2!/2R!P87)A('9E<B!A(&YO=&$@=.EC
M;FEC82!E;2!M;WII;&QA+F]R9R!A('%U86P@96YS:6YA(&-O;6\@<&5R;6ET
M:7(@<V-R:7!T<R!A8V5S<V%R96T@82#A<F5A(&1E('1R86YS9F5RZFYC:6$N
M`$1E<VUA<F-A<B!C;W(`17AT96YSXV\@3N-O(%-U<&]R=&%D80!!='5A;&EZ
M87(`)7,@871U86QI>F%D;P!!='5A;&EZ87(@=7-UX7)I;P`G)7,G(&%T=6%L
M:7IA9&\N`%-C<FEP="!D92!A='5A;&EZ8>?C;R!R96UO=FED;RX`16YV:6%R
M`%1O9&]S(&%R<75I=F]S(&1E("!C;VYF:6=U<F'G]65S(&1A<R!A<&QI8V'G
M]65S(&9O<F%M(&5N=FEA9&]S(&%O('-E<G9I9&]R+@!!;&9A8F5T;R!L871I
M;F\@96T@;6%I^G-C=6QO`$[Z;65R;W,@<F]M86YO<R!E;2!M86GZ<V-U;&\`
M57)U9W5A:0!5=&EL:7IA<B!!='5A;#H@)7,`571I;&EZ87(@4U-,`%5T:6QI
M>F%R('-E(&\@;F]M92]S96YH82#I(&1I9F5R96YT92!N;R!S97)V:61O<B!)
M35-0+@!5<W7A<FEO<P!5<W7A<FEO("5S(&[C;R!E<W3A(&%U=&]R:7IA9&\@
M<&%R82`E<RX`061M:6YI<W1R8>?C;R!D92!5<W7A<FEO<P!/<.?U97,@9&4@
M57-UX7)I;W,`4F5G:7-T<F\@9&4@57-UX7)I;W,`4F5G:7-T<F\@9&4@57-U
MX7)I;W,@97-TX2!D97-A8FEL:71A9&\@;F5S=&4@<VET92X`0V]N=&$@9&4@
M=7-UX7)I;R!NXV\@96YC;VYT<F%D80!5<W7A<FEO`%5S=>%R:6\@)R5S)R!J
MX2!E>&ES=&4N`%5S=>%R:6\Z`%5S=>%R:6\Z(`!5<W7A<FEO<R!N;R!S:7-T
M96UA.@!5>F)E<75I<W3C;P!/(&1I<F5T\W)I;R!61E,@;N-O(&5X:7-T92X`
M1NER:6%S`$5D:71A<B!/<.?U97,@9&4@1NER:6%S`$]PY_5E<R!D92!FZ7)I
M87,@;N-O('/C;R!S=7!O<G1A9&%S(&YO(&1R:79E<B!D92!F:6QT<F\@871U
M86PN`$QO8V%L:7IAY_5E<R!VX6QI9&%S(&5N8V]N=')A9&%S(&EN8VQU96TZ
M(`!686QI9&%D90!686QO<B!E;2!M:6YU=&]S(&$@<&%R=&ER(&1E(&%G;W)A
M+@!/('9A;&]R(&5S=.$@86-I;6$@9&\@=&%M86YH;R!MX7AI;6\@9&4@)7,N
M`%9A;&]R97,`5F%L;W)E<R!P87)A('-E;&5C:6]N87(`5F%N=6%T=0!687)I
MX79E;`!696YE>G5E;&$`1F%L:&$@;F$@=F5R:69I8V'GXV\@+2!E<W1A(&UE
M;G-A9V5M('!O9&4@=&5R('-I9&\@861U;'1E<F%D82X`5F5R<^-O`$-O;G1R
M;VQE(&1E(%9E<G/C;P!!;&EN:&%M96YT;R!V97)T:6-A;`!-87)G96T@=F5R
M=&EC86P`5F5R=&EC86PZ`$UU:71O($%L=&$`5FEE=&[C`%9I971N86UI=&$@
M*%9)4T-)22D`5F5R("5S`%9I<W5A;&EZ87(@=6UA('#A9VEN82!W96(@97AT
M97)N80!6:7-U86QI>F%R(&-O;6\@)7,`26QH87,@5FER9V5N<RP@0G)I=.)N
M:6-A<P!);&AA<R!6:7)G96YS+"!%+E4N02X`5FES:6)I;&ED861E`%9I<VEB
M:6QI9&%D93H@`%9O9&%F;VYE($ET86QI86YO('9I82!33510`$%414['PT\`
M051%3L?#3R$A(2!214U/5D$@3R!30U))4%0@34%.54%,345.5$4@1$4@)7,N
M`%=)3B!V:6$@2%144`!786QL:7,@92!&=71U;F$`071E;N?C;P!1=6$`4')E
M=FESXV\@9&\@5&5M<&\`1&%D;W,@9&\@0VQI;6$@9F]R;F5C:61O('!O<@!7
M96%T:&5R+F-O;0!796(`4VET92!796(`4V5M86YA;&UE;G1E`$)E;2UV:6YD
M;P!"96TM=FEN9&\@86\@)7,`0F5M+79I;F1O+"`E<P!/8VED96YT86P@*$E3
M3RTX.#4Y+3$I`$]C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A:&%R82!/8VED
M96YT86P`16YD97)EYV]S(&YA(%],:7-T82!"<F%N8V$Z`%%U92!A<&QI8V'G
MXV\@)7,@9&5V97)I82!E>&EB:7(@87#S<R!A(&-O;F5XXV\_`%%U86P@;R!C
M87)A8W1E<F4@9&5L:6UI=&%D;W(_`%%U86P@;R!C87)A8W1E<F4@9&4@8VET
M8>?C;S\`36%P87,@075S=')A;&EA;F]S(%=H97)E:7,`475A:7,@9F%S97,`
M475A:7,@<&QU9VEN<R!H86)I;&ET87(@<&%R82!O(&5D:71O<B!2:6-H(%1E
M>'0N`$QI<W1A($)R86YC80!%9&ET87(@3&ES=&$@0G)A;F-A`$QI<W1A($)R
M86YC82!NXV\@Z2!S=7!O<G1A9&$@<&5L;R!D<FEV97(@9&4@9FEL=')O(&%T
M=6%L+@!%;F1E<F7G;W,@;F$@3&ES=&$@0G)A;F-A`$QA<F=U<F$`3&%R9W5R
M82!E;2!U;FED861E<R!#4U,`3&%R9W5R82!D;R!M96YU("5S(&1O(&QA9&\@
M97-Q=65R9&\@*'1E<N$@969E:71O(&YA('!R\WAI;6$@8V]N97CC;RDZ`$QA
M<F=U<F$@9&$@=&%B96QA`%5N:61A9&4@9&4@3&%R9W5R80!,87)G=7)A.@!7
M:6MI`%9E;G1O`%9E;G1O<R!P96QA(&UA;FCC`%9E;&]C:61A9&4@9&\@=F5N
M=&\@96T@;O-S`%9E;G1O.@!696YT;SH@`%-A8F5D;W)I80!,:7-T82!D92!P
M961I9&]S`%1R86)A;&AO`$5N9&5R9>=O($-O;65R8VEA;`!&;VYE($-O;65R
M8VEA;`!.^FUE<F\@:6YC;W)R971O(&1E(&-A;7!O<R!N82!L:6YH82`E9"X@
M17-P97)A9&]S("5D+"!E;F-O;G1R861O<R`E9"X`3OIM97)O(&5R<F%D;R!D
M92!C86UP;W,N($5S<&5R861O<R`E9"P@96YC;VYT<F%D;W,@)60N`$]F9G-E
M="`E9"!I;F-O<G)E=&\@86\@;&5R(&\@87)Q=6EV;R!61E,N`%@M4')I;W)I
M='D`6"U2968`6"U3<&%M+4QE=F5L`%@M4W!A;2U38V]R90!8+5-P86TM4W1A
M='5S`%)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y=C,`571I;&EZ8>?C;R!D92!#
M:&%V92!%>'1E;F1I9&$@6#4P.78S`$YO;64@06QT97)N871I=F\@9&4@07-S
M=6YT;R!8-3`Y=C,`261E;G1I9FEC861O<B!D82!#:&%V92!D92!!<W-U;G1O
M(%@U,#EV,P!%>'1E;G/U97,@6#4P.78S`$%!`$%!04$`36%P82!986AO;R$`
M06YU86QM96YT90!,ZFUE;@!3:6T`4VEM+"!%=2!#;VYC;W)D;P!6;V/J(&5S
M=.$@96T@34]$3R!415A43RX@(%5T:6QI>F$@;R!B;W3C;R!;/#Y=('!A<F$@
M=F]L=&%R('!A<F$@;R!M;V1O(%=94TE764<N`%9O8^H@;N-O(&5S=.$@875T
M;W)I>F%D;R!A(&-R:6%R(&UA:7,@9&4@)60@8FQO8V]S+@!6;V/J(&[C;R!E
M<W3A(&%U=&]R:7IA9&\@82!C<FEA<B!M86ES(&1E("5D(')E9W)A<RX`5F]C
MZB!NXV\@97-TX2!A=71O<FEZ861O(&$@8W)I87(@;W4@961I=&%R(')E9W)A
M<R!P97)S;VYA;&EZ861A<RX`5F]CZB!NXV\@97-TX2!A=71E;G1I8V%D;RX`
M5F]CZB!NXV\@<&]D92!T97(@;R!C87)A8W1E<B!<(&YO('-E=2!N;VUE+@!6
M;V/J(&[C;R!F;W)N96-E=2!U;2!E;F1E<F7G;R!D92!E+6UA:6P@=N%L:61O
M+@!6;V/J(&[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R<75I=F\@:6UP
M;W)T861O(&%O<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S(&5M("5S+@!6;V/J
M(&9O:2!D97-C;VYE8W1A9&\N`%9O8^H@<F5C96)E=2!U;6$@;F]V82!M96YS
M86=E;0!6;V/J(&1E=F4@<')E96YC:&5R('5M(&[Z;65R;R!D92!T96QE9F]N
M92!C96QU;&%R(';A;&ED;RP@<V]M96YT92!D[6=I=&]S(&-O;2!U;2!O<&-I
M;VYA;"`G*R<@<&%R82!D:7-C86=E;2!D92!P<F5F:7AO(&EN=&5R;F%C:6]N
M86PN`%9O8^H@9&5V92!P<F5E;F-H97(@=6T@=F%L;W(@=N%L:61O+@!6;V/J
M(&1E=F4@8V]N9FEG=7)A<B!U;2!C;VYE8W1O<B!$871A5')E92!P87)A('5T
M:6QI>F%R($-A9&%S=')O<RX`5F]CZB!D979E(&-O;F9I9W5R87(@=6T@8V]N
M96-T;W(@5D93+@!6;V/J(&1E=F4@9&5S8W)E=F5R(&\@<')O8FQE;6$@86YT
M97,@9&4@96YV:6%R(&\@<F5L873S<FEO(&1E('!R;V)L96UA+@!6;V/J(&1E
M=F4@9F]R;F5C97(@82!54DP@;VYD92!O(&QI;FL@87!O;G1A`%9O8^H@9&5V
M92!S96QE8VEO;F%R('5M('-E<G9I9&]R('!A<F$@<V5R(&5X8VQU[61O+@!6
M;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(&5X8VQU:7(N
M`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@<F5M;W9E
M<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('!E;&\@;65N;W,@=6T@96YD97)E
MYV\@9&4@92UM86EL('!A<F$@<75E(&$@;65N<V%G96T@9&4@9NER:6%S('-E
M:F$@871I=F%D82X`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@
M<&%R82!A9&EC:6]N87(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A
M<FEO('!A<F$@871U86QI>F%R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6UA
M(&'GXV\@<&%R82!E>&5C=71A<BX`5F]CZB!D979E('!R965N8VAE<B!U;2!N
M;VUE('!A<F$@82!N;W9A(&-A=&5G;W)I82X`5F]CZB!P<F5C:7-A(&9O<FYE
M8V5R('5M(&[Z;65R;R!D92!T96QE9F]N92!I=&%L:6%N;P!3=6$@<V5S<^-O
M("5S(&5X<&ER;W4N(%!O<B!F879O<BP@8V]N96-T92US92!N;W9A;65N=&4N
M`%-E=2!%;F1E<F7G;R!D92!%+6UA:6P`4V5U($5N9&5R9>=O(&1E(%)E;65T
M96YT92`H1&4Z*3H`4W5A<R!);F9O<FUAY_5E<P!3974@16YD97)EYV\@9&4@
M26YT97)N970@;75D;W4@9&5S9&4@;R!I;NUC:6\@9&4@<W5A('-E<W/C;R`E
M<RX@4&%R82!P<F]T96=E<B!S=6$@<V5G=7)A;N=A('9O8^H@9&5V92!C;VYE
M8W1A<BUS92!N;W9A;65N=&4N`%-E=2!.;VUE`%-E=2!B86-K96YD(&1E(&%U
M=&5N=&EC8>?C;R!NXV\@<W5P;W)T82!A9&GGXV\@9&4@=7-UX7)I;W,L(&]U
M(&$@9G5NY^-O(&9O:2!D97-A8FEL:71A9&$@<&]R(&%L9W5M82!O=71R82!R
M87KC;RX`4V5U(&)A8VME;F0@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A
M(&QI<W1A9V5M(&1E('5S=>%R:6]S+"!O=2!A(&9U;N?C;R!F;VD@9&5S86)I
M;&ET861A('!O<B!A;&=U;6$@;W5T<F$@<F%ZXV\N`%-E=2!N879E9V%D;W(@
M<&%R96-E('1E<B!A;'1E<F%D;R!D97-D92!O(&EN[6-I;R!D92!S=6$@<V5S
M<^-O("5S+B!087)A('!R;W1E9V5R('-U82!S96=U<F%NYV$L('9O8^H@9&5V
M92!C;VYE8W1A<BUS92!N;W9A;65N=&4N`%-E=2!N879E9V%D;W(@;N-O('-U
M<&]R=&$@97-T82!F=6[GXV\N`%-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@
M97-T82!O<.?C;R!D92!I;7!R97-SXV\N(%!R97-S:6]N92!#;VYT<F]L+T]P
M=&EO;B`K(%`@<&%R82!I;7!R:6UI<BX`4V5U(&9U<V\@:&]RX7)I;R!A='5A
M;#H`4W5A(&ED96YT:61A9&4@<&%D<N-O(&9O:2!A;'1E<F%D82X`4W5A(&ED
M96YT:61A9&4@<&%D<N-O.@!3974@;F]M92!C;VUP;&5T;SH`4W5A(&-O;F5X
MXV\@97AP:7)O=2X`4W5A(&YO=F$@<V5N:&$@<&%R82`E<R#I.B`E<P!3=6%S
M(&]PY_5E<R!F;W)A;2!A='5A;&EZ861A<R!P;W(@8V%U<V$@9&$@9'5R8>?C
M;R!D97-T82!S97-SXV\N`%-U87,@;W#G]65S(&9O<F%M(&%T=6%L:7IA9&%S
M+@!3=6$@;F]V82!S96YH82!F;VD@9V5R861A`%-U82!N;W9A('-E;FAA(&9O
M:2!G97)A9&$L('9E<FEF:7%U92!S974@92UM86EL(&4@8V]N96-T92US92!C
M;VT@<W5A(&YO=F$@<V5N:&$N`%-U82!S96YH82!E>'!I<F]U+@!3975S('-E
M<G9I9&]R97,@<F5M;W1O<SH`275G;W-LX79I80!:86ER90!:XFUB:6$`6FEM
M8F%B=V4`6FEP<'D`6T]C=6QT87(@5&5X=&\@0VET861O70!;4V5M($%S<W5N
M=&]=`%M296QA=/-R:6\@9&4@4')O8FQE;6%=`%M%>&EB:7(@5&5X=&\@0VET
M861O("T`6T5X:6)I<B!497AT;R!#:71A9&\@+2`E<R!L:6YH87-=`%ML:6YH
M82`E<R!D92`E<UT`7T5N9&5R9>=O*',I('!A<F$@<F5D:7)E8VEO;F%R.@!?
M16YD97)EYV\H<RD@<&%R82!NXV\@96YV:6%R(')E<W!O<W1A<SH`7T%D;6EN
M:7-T<F'GXV\`3&ES=&$@7TYE9W)A`%]#3$D`1&%T85]4<F5E`$5?>&-L=6ER
M($-O;'5N80!%7WAC;'5I<B!M96YS86=E;2!C;VUP;&5T86UE;G1E`%]0<F5E
M;F-H82!C861A(&5N9&5R9>=O(&5M('5M82!N;W9A(&QI;FAA.@!?16YC86UI
M;FAA<@!?1W)U<&]S`$%?:G5D80!0<F]P<FEE9&%D97,@9&$@7TEM86=E;2XN
M+@!?36%N=&5R('5M82!C\W!I82!D87,@;65N<V%G96YS(&YE<W1A(&-O;G1A
M/P!?0V]N96-T87(`7T1E<V-O;F5C=&%R`$%?;'1E<F%R($QI;FLN+BX`7TUO
M=F5R(&UE;G-A9V5M('!A<F$@82!P87-T83H`7TUE=7,@96YD97)EYV]S(&1E
M(&4M;6%I;#H`7T]PY_5E<P!?4&5R;6ES<_5E<P!?4F5M;W9E<B!,:6YK+BXN
M`%]2;W1I;F$`0V]N9FEG=7)A7W(`4')O<')I961A9&5S(&1A(%]486)E;&$N
M+BX`7U5S=>%R:6]S`%]&Z7)I87,`3&ES=&$@7T)R86YC80!A=&EV;P!C873A
M;&]G;R!D92!E;F1E<F7G;W,`8V%TX6QO9V\@9&4@96YD97)EYV]S`&4`86=E
M;F1A`&-A;&UO`&EM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!D92!D97-T:6YO
M`&EM<&]S<^UV96P@86)R:7(@82!O<FEG96T`8VQI<75E(&%Q=6D`97)R;R!D
M92!S:6YT87AE(&1A(&QI;FAA(&1E(&-O;6%N9&\`97)R;R!D92!C;VYF:6=U
M<F'GXV\`=6T@87)Q=6EV;R!C<NUT:6-O(&1O('-I<W1E;6$@97-TX2!F86QT
M86YD;P!E<G)O(&YO(&9O<FUA=&\@9&]S(&1A9&]S`&1E<V%B:6QI=&%D;R`M
M(&-L:7%U92!P87)A(&AA8FEL:71A<@!E9&ET87(`<F5G:7-T<F\@;N-O(&5N
M8V]N=')A9&\`<75E9&$`8V%M<&\`87)Q=6EV;P!A('!A<G1I<B!D92`E<R`H
M)7,I(.`@)7,@)7,`8G)I<V$`:#H`:&@`;F]M92!D;R!H;W-T(.D@9&5S8V]N
M:&5C:61O`&EM961I871O`&EN871I=F\`:6YC;W)P;W)A9&\`97)R;R!D92!E
M;G1R861A+W-A[61A`&5R<F\@:6YT97)N;R!D;R!P<F]G<F%M80!L:6YH87-=
M`')O=&EN82!D;R!P<F]C;6%I;"!G97)A9&$@<&5L;R!);F=O`&-O<G)E<W!O
M;F1E`&/S9&EG;R!D92!E<G)O("5D(&1O(&UK:7-O9G,@96YQ=6%N=&\@9V5R
M879A(&$@25-/+@!M;0!N;VUE`&[C;R!I;7!L96UE;G1A9&\`;N-O(&EM<&QE
M;65N=&%D;R!A:6YD80!B;&]C;R!D92!N;W1A<P!O=0!P;W)C96YT86=E;0!0
M97)M:7-SXV\`<&EX96QS`')O=&EN82!D;R!P<F]C;6%I;"!G97)A9&$@<&5L
M;R!);F=O`&5R<F\@<F5M;W1O(&YO('!R;W1O8V]L;P!N87-C96YT90!S97)V
M:>=O(&EN9&ES<&]N[79E;`!E>&EB:7(@9&EF97)E;N=A<P!F:6QT<F\@<VEE
M=F4@9V5R861O('!E;&\@26YG;P!S;7,R96UA:6P@=FEA($A45%``<W,`97-T
MX79E;`!E<G)O(&1E('-I<W1E;6$`;&ES=&$@9&4@=&%R969A<P!F86QH82!T
M96UP;W+A<FEA`'!R965N8VAA('-U82!S96YH82!D=6%S('9E>F5S('!A<F$@
M8V]N9FER;6%R`'5N:69I8V%D;P!S96T@;F]M90!S96QEY^-O(&1E('5S=>%R
M:6\`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6YG;R]L;V-A;&4O<'1?4%0O````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,3<V-3``
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]P=%]05"],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S0W`#`R,30S-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O
M;&]C86QE+W!T7U!4+TQ#7TU%4U-!1T53+VEN9V\N;6\`````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`T-C`W-C4`,3`T,3<S-C(W-#<`,#(R-S0U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````(@@``!P`
M```L00``V0H``#R"````````H*T``$T```"AK0``OP```.^M``!D````KZX`
M`+X````4KP``D````-.O``!#````9+```#P```"HL```*P```.6P```N````
M$;$``"D```!`L0``*````&JQ``!%````D[$``$<```#9L0``2@```"&R``!'
M````;+(``$4```"TL@``2````/JR```Y````0[,``$8```!]LP``2````,2S
M```P````#;0``$4````^M```1@```(2T``!,````R[0``#0````8M0``,@``
M`$VU``!I````@+4``#````#JM0``)0```!NV``"(````0;8``$````#*M@``
M]@````NW``!*`````K@``"P```!-N```A0```'JX``!(`````+D```X```!)
MN0``#P```%BY```-````:+D```@```!VN0``"P```'^Y```,````B[D```0`
M``"8N0``!````)VY```#````HKD``!L```"FN0``+0```,*Y```=````\+D`
M`"0````.N@``*0```#.Z```9````7;H```P```!WN@``$0```(2Z```E````
MEKH```\```"\N@``"P```,RZ```1````V+H```X```#JN@``!0```/FZ```H
M````_[H```@````HNP``"@```#&[```5````/+L``!(```!2NP``"P```&6[
M```3````<;L```X```"%NP``"@```)2[```-````G[L``"X```"MNP``#@``
M`-R[```1````Z[L```T```#]NP``#`````N\```-````&+P```8````FO```
M"@```"V\```/````.+P``!@```!(O```#````&&\```;````;KP```X```"*
MO```#@```)F\```(````J+P```D```"QO```0@```+N\```N````_KP``!H`
M```MO0``,@```$B]```X````>[T``%0```"TO0``40````F^``!:````6[X`
M`%<```"VO@``-`````Z_```)````0[\```T```!-OP``!P```%N_```*````
M8[\```\```!NOP``!0```'Z_```&````A+\``!$```"+OP``"````)V_```)
M````IK\```D```"POP``)0```+J_```@````X+\``!`````!P```#P```!+`
M```*````(L```"$````MP```#P```$_````#````7\````\```!CP```%```
M`'/````)````B,````T```"2P```$@```*#````9````L\```!X```#-P```
M#P```.S````*````_,````\````'P0``"````!?!```D````(,$``!0```!%
MP0``%@```%K!```(````<<$``$X```!ZP0``+0```,G!```?````]\$``!D`
M```7P@``$P```#'"```'````1<(```P```!-P@``+````%K"```.````A\(`
M``,```"6P@``"P```)K"```'````IL(```<```"NP@``!0```+;"```%````
MO,(```H```#"P@```P```,W"```7````T<(```H```#IP@``#P```/3"```.
M````!,,``!0````3PP``&````"C#```C````0<,```X```!EPP``%````'3#
M```7````B<,``!<```"APP``%P```+G#```3````T<,```\```#EPP``#@``
M`/7#```?````!,0``!T````DQ```!P```$+$```&````2L0```@```!1Q```
M#P```%K$```&````:L0```@```!QQ```"@```'K$```3````A<0``!0```"9
MQ```"P```*[$```5````NL0```T```#0Q```%0```-[$```'````],0``!``
M``#\Q```!0````W%```5````$\4``!$````IQ0``#````#O%```J````2,4`
M`#L```!SQ0``.````*_%```)````Z,4```<```#RQ0``%````/K%```#````
M#\8```4````3Q@``$````!G&```)````*L8``!,````TQ@``.0```$C&```2
M````@L8``"<```"5Q@``+````+W&```J````ZL8``"4````5QP``"@```#O'
M```&````1L<```D```!-QP``!P```%?'```O````7\<``#<```"/QP``+@``
M`,?'``!5````]L<``"T```!,R```+0```'K(```M````J,@``$````#6R```
M(P```!?)```C````.\D``"T```!?R0``,P```(W)```5````P<D``!D```#7
MR0``*0```/')```D````&\H``#(```!`R@``$0```'/*```*````A<H```P`
M``"0R@``"@```)W*```0````J,H``!8```"YR@``%@```-#*```'````Y\H`
M``<```#OR@``%````/?*```*````#,L```@````7RP``"````"#+```#````
M*<L```L````MRP``!P```#G+```'````0<L```8```!)RP``!0```%#+```'
M````5LL```8```!>RP``"````&7+```)````;LL```X```!XRP``.P```(?+
M```3````P\L``!4```#7RP``*0```.W+```.````%\P```H````FS```!```
M`#',```$````-LP```<````[S```"0```$/,```&````3<P``!$```!4S```
M!P```&;,```6````;LP```0```"%S```"````(K,```&````D\P```T```":
MS```!@```*C,```>````K\P``!$```#.S```(@```.#,```6`````\T```@`
M```:S0``#0```"/-```,````,<T```<````^S0```P```$;-```#````2LT`
M`!<```!.S0``$P```&;-```=````>LT```@```"8S0``!````*'-```(````
MILT```@```"OS0``00```+C-```@````^LT```8````;S@``!@```"+.```5
M````*<X``!@````_S@``(@```%C.```N````>\X``!T```"JS@``(0```,C.
M``!4````ZLX``"D````_SP``"@```&G/```'````=,\```X```!\SP``%0``
M`(O/```.````H<\```(```"PSP``"@```+//```/````OL\```T```#.SP``
M#P```-S/```-````[,\```D```#ZSP``%`````30```&````&=```!@````@
MT```'0```#G0```3````5]```!$```!KT```%````'W0```$````DM````8`
M``"7T```5````)[0```.````\]````0````"T0``#@````?1``!$````%M$`
M``4```!;T0``!0```&'1```;````9]$``!H```"#T0``$0```)[1```1````
ML-$``!P```#"T0``*@```-_1```0````"M(``"$````;T@``)0```#W2```9
M````8](```4```!]T@``$P```(/2```2````E](```H```"JT@``#P```+72
M```-````Q=(``!$```#3T@``$P```.72```,````^=(```8````&TP``#```
M``W3```&````&M,``!<````ATP``$````#G3```1````2M,```@```!<TP``
M!0```&73```,````:],``!````!XTP``!0```(G3```-````C],```8```"=
MTP``!P```*33```-````K-,``!````"ZTP``"0```,O3```'````U=,```L`
M``#=TP``"P```.G3```'````]=,```<```#]TP``%`````74```)````&M0`
M``D````DU```"@```"[4```9````.=0``!T```!3U```#````''4```0````
M?M0```4```"/U```)0```)74```2````N]0``!,```#.U```*P```.+4```[
M````#M4``"````!*U0``-@```&O5```(````HM4``"$```"KU0``$````,W5
M```(````WM4```P```#GU0``!@```/35```$````^]4```<`````U@``"@``
M``C6```.````$]8``!`````BU@``"@```#/6```-````/M8``!X```!,U@``
M&P```&O6```A````A]8``!X```"IU@``&0```,C6```>````XM8``!L````!
MUP``+@```!W7```7````3-<``"8```!DUP``,````(O7```;````O-<``!X`
M``#8UP``'````/?7```F````%-@``"L````[V```,P```&?8```F````F]@`
M`"L```#"V```.````.[8```=````)]D``!4```!%V0``+P```%O9```@````
MB]D``!(```"LV0``*0```+_9```>````Z=D``!(````(V@``H@```!O:```6
M````OMH``",```#5V@``*````/G:```I````(ML``"@```!,VP``'P```'7;
M```5````E=L``"````"KVP``)0```,S;```H````\ML``"T````;W```,```
M`$G<``"2````>MP``"$````-W0``%@```"_=```<````1MT``"8```!CW0``
M*@```(K=``!!````M=T``$0```#WW0``#````#S>```'````2=X```<```!1
MW@``!@```%G>```-````8-X``!````!NW@``$0```'_>```2````D=X``!,`
M``"DW@``$@```+C>```'````R]X```0```#3W@``$````-C>```,````Z=X`
M``X```#VW@``#P````7?```3````%=\```T````IWP``*````#??```#````
M8-\```T```!DWP``!@```'+?```1````>=\``!<```"+WP``&P```*/?```.
M````O]\```(```#.WP``"````-'?```*````VM\```4```#EWP``$````.O?
M```$````_-\```T````!X```#@````_@```#````'N````X````BX```$0``
M`#'@```(````0^````\```!,X```#P```%S@```'````;.````T```!TX```
M$````(+@```3````D^```!,```"GX```"P```+O@```&````Q^````D```#.
MX```$````-C@```,````Z>```!$```#VX```&0````CA```+````(N$```T`
M```NX0``(@```#SA```9````7^$``!L```!YX0``-````)7A```*````RN$`
M`!@```#5X0``&0```.[A```6````".(``"\````?X@``!P```$_B```B````
M5^(``!4```!ZX@``(0```)#B```E````LN(``!$```#8X@``#0```.KB```'
M````^.(``!0`````XP``"P```!7C```B````(>,``"\```!$XP``"P```'3C
M```)````@.,``!D```"*XP``"P```*3C```7````L.,``!<```#(XP``"0``
M`.#C```*````ZN,```@```#UXP``%@```/[C```/````%>0``!D````EY```
M.@```#_D```6````>N0```X```"1Y```&````*#D```(````N>0``"\```#"
MY```#0```/+D```F`````.4```@````GY0``0P```##E```2````=.4```\`
M``"'Y0``$````)?E```-````J.4``"$```"VY0``"````-CE```2````X>4`
M``@```#TY0``"P```/WE```O````">8```X````YY@``!0```$CF```&````
M3N8```,```!5Y@``!P```%GF```$````8>8```<```!FY@``"@```&[F```*
M````>>8```\```"$Y@``$````)3F```7````I>8``!$```"]Y@``&0```,_F
M```7````Z>8```D````!YP``!0````OG```+````$><```H````=YP```@``
M`"CG```%````*^<```T````QYP``&P```#_G```7````6^<```D```!SYP``
M#@```'WG```-````C.<``!(```":YP``"0```*WG```X````M^<``"````#P
MYP``!P```!'H```(````&>@```D````BZ```#@```"SH``![````.^@``!@`
M``"WZ```0````-#H```(````$>D``!$````:Z0``!P```"SI```%````-.D`
M`!4````ZZ0``&0```%#I```3````:ND```<```!^Z0``!P```(;I```(````
MCND```8```"7Z0``!@```)[I```0````I>D```\```"VZ0``$````,;I```/
M````U^D```L```#GZ0``#P```//I```,`````^H```\````0Z@``!P```"#J
M```*````*.H```X````SZ@``!@```$+J```&````2>H```X```!0Z@``#```
M`%_J```H````;.H```\```"5Z@``"````*7J```6````KNH```@```#%Z@``
M$P```,[J```>````XNH``"$````!ZP``(````"/K```9````1.L``!<```!>
MZP``)0```';K```7````G.L```0```"TZP``&P```+GK```-````U>L```P`
M``#CZP```P```/#K```(````].L```H```#]ZP``#`````CL```+````%>P`
M`!`````A[```#````#+L```$````/^P``!,```!$[```%````%CL```,````
M;>P```D```!Z[```#@```(3L```+````D^P``!L```"?[```$P```+OL```9
M````S^P``!L```#I[```#@````7M```+````%.T```P````@[0``%0```"WM
M```-````0^T``$,```!1[0``,0```)7M``!"````Q^T``$<````*[@``3P``
M`%+N```]````HNX``$X```#@[@``$0```"_O```'````0>\```<```!)[P``
M"@```%'O```-````7.\```D```!J[P``!````'3O```%````>>\```,```!_
M[P``&````(/O```*````G.\```0```"G[P``)0```*SO```F````TN\```X`
M``#Y[P``?`````CP```5````A?````4```";\```!P```*'P```,````J?``
M``@```"V\```"@```+_P```&````RO````<```#1\```.0```-GP```(````
M$_$```T````<\0``%@```"KQ```2````0?$```(```!4\0``!@```%?Q```&
M````7O$``!0```!E\0``#0```'KQ```0````B/$``!L```"9\0``!````+7Q
M```)````NO$``!````#$\0``"0```-7Q```)````W_$```4```#I\0``!0``
M`._Q```:````]?$```@````0\@``!@```!GR```9````(/(```X````Z\@``
M(@```$GR```'````;/(```<```!T\@``#@```'SR```%````B_(```D```"1
M\@``"@```)OR```"````IO(```8```"I\@``#0```+#R```)````OO(```P`
M``#(\@``&````-7R```&````[O(``!(```#U\@``"0````CS```'````$O,`
M`!0````:\P``'0```"_S```1````3?,```8```!?\P``"@```&;S```$````
M<?,```D```!V\P``"````(#S```1````B?,``!$```";\P``"0```*WS```&
M````M_,```T```"^\P``!@```,SS```$````T_,``#D```#8\P``/0```!+T
M```Z````4/0``!X```"+]```!0```*KT```.````L/0```0```"_]```!@``
M`,3T```A````R_0```T```#M]```%0```/OT```&````$?4```0````8]0``
M$0```!WU```&````+_4``*`````V]0``"@```-?U```B````XO4```0````%
M]@``)0````KV```%````,/8``!T````V]@``!````%3V```,````6?8```H`
M``!F]@``"````''V```)````>O8```4```"$]@``&P```(KV```Z````IO8`
M`#````#A]@``-0```!+W```I````2/<``"X```!R]P``1P```*'W```X````
MZ?<``"D````B^```/P```$SX```N````C/@``"T```"[^```'P```.GX```/
M````"?D``!(````9^0``"P```"SY```F````./D``"D```!?^0``)````(GY
M```F````KOD```@```#5^0``"@```-[Y```)````Z?D```<```#S^0``(```
M`/OY```@````'/H``"8````]^@``"@```&3Z```9````;_H``"D```")^@``
M%@```+/Z```2````ROH```<```#=^@``"@```.7Z```/````\/H``!``````
M^P``0````!'[``!P````4OL``&8```##^P``#@```"K\```)````.?P```H`
M``!#_```$@```$[\```3````8?P```P```!U_```!@```(+\```/````B?P`
M``D```"9_```$@```*/\```0````MOP``!$```#'_```'````-G\```C````
M]OP``&H````:_0``#P```(7]```%````E?T``!````";_0``0P```*S]```)
M````\/T``#(```#Z_0``!````"W^```+````,OX``"`````^_@``&@```%_^
M```4````>OX```P```"/_@``#````)S^```/````J?X``!4```"Y_@``*0``
M`,_^```J````^?X``"8````D_P``)P```$O_```I````<_\``"H```"=_P``
M&0```,C_``!"````XO\``!$````E``$`$@```#<``0`3````2@`!`!0```!>
M``$`#P```',``0`6````@P`!`!<```":``$`$````+(``0`1````PP`!`#0`
M``#5``$`$P````H!`0`2````'@$!`#4````Q`0$`%````&<!`0`'````?`$!
M``P```"$`0$`(````)$!`0`0````L@$!`!0```##`0$`$0```-@!`0`7````
MZ@$!`!P````"`@$`$P```!\"`0`4````,P(!`!H```!(`@$`$0```&,"`0`:
M````=0(!`!X```"0`@$`&@```*\"`0`3````R@(!`!4```#>`@$`$0```/0"
M`0`7````!@,!`!0````>`P$`%P```#,#`0`5````2P,!``D```!A`P$`&0``
M`&L#`0`$````A0,!``<```"*`P$``@```)(#`0`+````E0,!``4```"A`P$`
M$0```*<#`0`&````N0,!``8```#``P$`!@```,<#`0`%````S@,!``<```#4
M`P$`!P```-P#`0`%````Y`,!`!8```#J`P$`!@````$$`0`&````"`0!``0`
M```/!`$`!````!0$`0`'````&00!``X````A!`$`#````#`$`0`,````/00!
M``T```!*!`$`"@```%@$`0`.````8P0!``4```!R!`$`*````'@$`0`.````
MH00!``P```"P!`$`#P```+T$`0`*````S00!``@```#8!`$`"0```.$$`0`K
M````ZP0!``0````7!0$`"````!P%`0`F````)04!`!(```!,!0$`#P```%\%
M`0`&````;P4!``H```!V!0$`!P```($%`0`(````B04!`"````"2!0$`"0``
M`+,%`0`,````O04!``T```#*!0$`#@```-@%`0`6````YP4!`!$```#^!0$`
M!@```!`&`0`#````%P8!``8````;!@$`&0```"(&`0`'````/`8!``0```!$
M!@$`"P```$D&`0`+````508!``<```!A!@$`"0```&D&`0`5````<P8!``<`
M``")!@$`%@```)$&`0`-````J`8!``T```"V!@$`"@```,0&`0`0````SP8!
M``\```#@!@$`$0```/`&`0`7`````@<!``H````:!P$`$0```"4'`0`(````
M-P<!``0```!`!P$`#P```$4'`0`Z````50<!``4```"0!P$`#````)8'`0`>
M````HP<!``X```#"!P$`$````-$'`0`+````X@<!``P```#N!P$`"0```/L'
M`0`'````!0@!``<````-"`$`"@```!4(`0`)````(`@!``X````J"`$`$```
M`#D(`0`:````2@@!``H```!E"`$`"0```'`(`0`4````>@@!``H```"/"`$`
M#````)H(`0`/````IP@!``@```"W"`$`!@```,`(`0`'````QP@!``L```#/
M"`$`1P```-L(`0`-````(PD!``D````Q"0$`!````#L)`0`#````0`D!`!,`
M``!$"0$`$P```%@)`0`3````;`D!``H```"`"0$``@```(L)`0`$````C@D!
M`"4```"3"0$``P```+D)`0`%````O0D!`"H```##"0$`"@```.X)`0`%````
M^0D!``0```#_"0$`"@````0*`0`-````#PH!`$`````="@$`$P```%X*`0`&
M````<@H!``@```!Y"@$`"````((*`0`$````BPH!``4```"0"@$`:````)8*
M`0`)````_PH!``P````)"P$`&````!8+`0`%````+PL!``8````U"P$`$```
M`#P+`0`;````30L!`"\```!I"P$`$````)D+`0`*````J@L!`!L```"U"P$`
M#P```-$+`0`*````X0L!``D```#L"P$`$P```/8+`0`;````"@P!`!@````F
M#`$`%P```#\,`0`.````5PP!`(D```!F#`$`B0```/`,`0`#````>@T!``<`
M``!^#0$`"````(8-`0`'````CPT!``H```"7#0$`"P```*(-`0`M````K@T!
M`!4```#<#0$`,````/(-`0`D````(PX!``<```!(#@$`40```%`.`0`0````
MH@X!``P```"S#@$`#0```,`.`0`:````S@X!`$H```#I#@$`&0```#0/`0`&
M````3@\!`!H```!5#P$`!@```'`/`0`&````=P\!`!\```!^#P$`!@```)X/
M`0`)````I0\!`!@```"O#P$`%P```,@/`0`&````X`\!``T```#G#P$`(@``
M`/4/`0`F````&!`!`%<````_$`$`$P```)<0`0`9````JQ`!`!L```#%$`$`
M(P```.$0`0`3````!1$!``(````9$0$`"P```!P1`0`(````*!$!``T````Q
M$0$`"@```#\1`0`&````2A$!``<```!1$0$`%````%D1`0`&````;A$!``@`
M``!U$0$`#@```'X1`0`'````C1$!``H```"5$0$`"P```*`1`0`'````K!$!
M``P```"T$0$`#0```,$1`0`,````SQ$!``0```#<$0$`"0```.$1`0`)````
MZQ$!``H```#U$0$`#@`````2`0`,````#Q(!``<````<$@$`"0```"02`0`'
M````+A(!``H````V$@$`&P```$$2`0`2````71(!``H```!P$@$`"0```'L2
M`0`0````A1(!``<```"6$@$`$@```)X2`0`I````L1(!``0```#;$@$`!P``
M`.`2`0`%````Z!(!``4```#N$@$`"P```/02`0`4`````!,!`!$````5$P$`
M&@```"<3`0`6````0A,!`!0```!9$P$`%P```&X3`0`8````AA,!`!P```"?
M$P$`&0```+P3`0`'````UA,!``4```#>$P$`#0```.03`0`,````\A,!``@`
M``#_$P$`"`````@4`0`7````$10!``L````I%`$`$P```#44`0`$````210!
M``H```!.%`$`!````%D4`0`-````7A0!``P```!L%`$`!0```'D4`0`)````
M?Q0!``4```")%`$`!P```(\4`0`%````EQ0!``0```"=%`$``@```*(4`0`O
M````I10!`#@```#5%`$`+`````X5`0`C````.Q4!`"8```!?%0$`$@```(85
M`0`I````F14!`#(```##%0$`"@```/85`0`V`````18!`"P````X%@$`%0``
M`&46`0`N````>Q8!`#,```"J%@$`,P```-X6`0`X````$A<!``\```!+%P$`
M&````%L7`0`[````=!<!`!````"P%P$`+@```,$7`0`4````\!<!`!0````%
M&`$`$P```!H8`0`5````+A@!`!0```!$&`$`$@```%D8`0`4````;!@!`!4`
M``"!&`$`+0```)<8`0`M````Q1@!`#$```#S&`$`+0```"49`0`N````4QD!
M`"\```""&0$`+````+(9`0!B````WQD!`!,```!"&@$`"````%8:`0`4````
M7QH!``@```!T&@$`%````'T:`0`K````DAH!`"$```"^&@$`&@```.`:`0`)
M````^QH!`$4````%&P$`00```$L;`0`$````C1L!`!,```"2&P$`%````*8;
M`0`.````NQL!`!,```#*&P$`&````-X;`0`&````]QL!``D```#^&P$`"@``
M``@<`0`/````$QP!``P````C'`$`$````#`<`0`'````01P!``X```!)'`$`
M!0```%@<`0`;````7AP!``8```!Z'`$`"````($<`0`&````BAP!`!0```"1
M'`$`$0```*8<`0`.````N!P!`#@```#''`$``@`````=`0`&`````QT!``X`
M```*'0$`&@```!D=`0`%````-!T!``<````Z'0$`#@```$(=`0`&````41T!
M``0```!8'0$`*0```%T=`0`7````AQT!`!\```"?'0$`7````+\=`0`4````
M'!X!`#X````Q'@$`'P```'`>`0`0````D!X!``<```"A'@$`'@```*D>`0`.
M````R!X!``@```#7'@$`#````.`>`0`,````[1X!`!,```#Z'@$`"@````X?
M`0`=````&1\!`!D````W'P$`!0```%$?`0`1````5Q\!``T```!I'P$`$0``
M`'<?`0`D````B1\!`!4```"N'P$`$@```,0?`0`.````UQ\!`!D```#F'P$`
M"``````@`0`)````"2`!``T````3(`$`"@```"$@`0`'````+"`!``\````T
M(`$`!@```$0@`0`+````2R`!``H```!7(`$`!P```&(@`0`(````:B`!``4`
M``!S(`$`'P```'D@`0`&````F2`!`!````"@(`$`"````+$@`0`-````NB`!
M``@```#((`$`$@```-$@`0`L````Y"`!`!H````1(0$`"0```"PA`0`*````
M-B$!`!4```!!(0$`!0```%<A`0`4````72$!``0```!R(0$`$````'<A`0`&
M````B"$!``<```"/(0$`'@```)<A`0`H````MB$!``H```#?(0$`'````.HA
M`0`:````!R(!``\````B(@$`%````#(B`0`$````1R(!``0```!,(@$`"P``
M`%$B`0`%````72(!``8```!C(@$`"````&HB`0`&````<R(!``H```!Z(@$`
M&P```(4B`0`T````H2(!`#0```#6(@$`(`````LC`0`I````+",!`"````!6
M(P$`00```'<C`0`:````N2,!`"@```#4(P$`*````/TC`0`I````)B0!`%$`
M``!0)`$`+P```*(D`0`B````TB0!``8```#U)`$`"````/PD`0`%````!24!
M``@````+)0$`&0```!0E`0`9````+B4!`"H```!()0$`(P```',E`0`9````
MER4!`"X```"Q)0$`-````.`E`0`(````%28!`!<````>)@$`"@```#8F`0`'
M````028!`"$```!))@$`$````&LF`0`.````?"8!``L```"+)@$`!P```)<F
M`0`3````GR8!``@```"S)@$`"P```+PF`0`*````R"8!`!0```#3)@$`#P``
M`.@F`0`R````^"8!``L````K)P$`!0```#<G`0`%````/2<!`!<```!#)P$`
M!P```%LG`0`/````8R<!``0```!S)P$`"@```'@G`0`)````@R<!``L```"-
M)P$`#0```)DG`0`,````IR<!``X```"T)P$`!0```,,G`0`$````R2<!``T`
M``#.)P$`,@```-PG`0!%````#R@!``@```!5*`$`"P```%XH`0`7````:B@!
M`!X```""*`$`%````*$H`0`%````MB@!`!(```"\*`$`$@```,\H`0`4````
MXB@!``<```#W*`$`#@```/\H`0`J````#BD!``8````Y*0$`#````$`I`0`-
M````32D!`!$```!;*0$`"P```&TI`0`V````>2D!``H```"P*0$`(@```+LI
M`0`+````WBD!``\```#J*0$`,@```/HI`0`E````+2H!`#````!3*@$`,0``
M`(0J`0`M````MBH!``X```#D*@$`"0```/,J`0`+````_2H!``4````)*P$`
M#@````\K`0`3````'BL!``<````R*P$`&@```#HK`0`(````52L!`!8```!>
M*P$`$0```'4K`0`4````ARL!``<```"<*P$`%````*0K`0`8````N2L!``<`
M``#2*P$`!0```-HK`0`,````X"L!``P```#M*P$`$@```/HK`0`$````#2P!
M``<````2+`$`"@```!HL`0`+````)2P!``P````Q+`$`#@```#XL`0`.````
M32P!``4```!<+`$`!````&(L`0`+````9RP!``P```!S+`$`#0```(`L`0`,
M````CBP!``D```";+`$`!0```*4L`0`N````JRP!`"8```#:+`$`(P````$M
M`0`#````)2T!`!(````I+0$`!@```#PM`0`>````0RT!`!@```!B+0$`)0``
M`'LM`0`-````H2T!``D```"O+0$``P```+DM`0`'````O2T!``H```#%+0$`
M`@```-`M`0`,````TRT!`!4```#@+0$`"P```/8M`0`9`````BX!`"`````<
M+@$`$@```#TN`0`%````4"X!``H```!6+@$`%0```&$N`0`2````=RX!``P`
M``"*+@$`!````)<N`0`'````G"X!``D```"D+@$`#````*XN`0`-````NRX!
M`%(```#)+@$`%P```!PO`0`D````-"\!`!(```!9+P$`!P```&PO`0`&````
M="\!``\```![+P$`$P```(LO`0`>````GR\!`"````"^+P$`!@```-\O`0`.
M````YB\!`"(```#U+P$`'0```!@P`0`$````-C`!``P````[,`$`#0```$@P
M`0`.````5C`!`!4```!E,`$`$@```'LP`0`/````CC`!`!0```">,`$`&P``
M`+,P`0`0````SS`!`!0```#@,`$`:0```/4P`0`:````7S$!`!<```!Z,0$`
M)P```)(Q`0`:````NC$!`!<```#5,0$`&P```.TQ`0`9````"3(!`!\````C
M,@$`$P```$,R`0`3````5S(!``@```!K,@$`!@```'0R`0`'````>S(!``@`
M``"#,@$`"0```(PR`0`5````EC(!``T```"L,@$`(P```+HR`0`3````WC(!
M``,```#R,@$`1@```/8R`0`_````/3,!`#<```!],P$`5P```+4S`0`>````
M#30!``4````L-`$`'P```#(T`0`O````4C0!``H```""-`$`"````(TT`0`-
M````EC0!`"T```"D-`$`!````-(T`0`2````US0!`!,```#J-`$`3P```/XT
M`0`E````3C4!`!P```!T-0$`"P```)$U`0`?````G34!`!T```"]-0$`)0``
M`-LU`0`@`````38!`"0````B-@$`(````$<V`0`+````:#8!``<```!T-@$`
M#0```'PV`0`,````BC8!`!<```"7-@$`!@```*\V`0`Y````MC8!``P```#P
M-@$`!P```/TV`0`9````!3<!``D````?-P$`$P```"DW`0`)````/3<!``0`
M``!'-P$`$````$PW`0`*````73<!``@```!H-P$`"````'$W`0`$````>C<!
M``L```!_-P$`#````(LW`0`2````F#<!`!$```"K-P$`#````+TW`0`:````
MRC<!``\```#E-P$`!P```/4W`0`-````_3<!`!0````+.`$`#@```"`X`0`,
M````+S@!`!L````\.`$`+````%@X`0`3````A3@!`!P```"9.`$`*````+8X
M`0`&````WS@!``<```#F.`$`$P```.XX`0`%`````CD!``0````(.0$`%P``
M``TY`0`*````)3D!``P````P.0$`"0```#TY`0`&````1SD!``D```!..0$`
M"````%@Y`0`)````83D!``H```!K.0$`$0```'8Y`0`&````B#D!`!@```"/
M.0$`(P```*@Y`0`.````S#D!``X```#;.0$`#0```.HY`0`+````^#D!`!T`
M```$.@$`"P```"(Z`0`"````+CH!`!T````Q.@$`!P```$\Z`0`&````5SH!
M`&4```!>.@$`"0```,0Z`0`'````SCH!`"8```#6.@$`.````/TZ`0`:````
M-CL!`"H```!1.P$`.P```'P[`0`H````N#L!`#0```#A.P$`&0```!8\`0`5
M````,#P!``4```!&/`$`!P```$P\`0`(````5#P!``<```!=/`$`!0```&4\
M`0`'````:SP!``X```!S/`$`"0```((\`0`&````C#P!``@```"3/`$`"P``
M`)P\`0`'````J#P!``@```"P/`$`!P```+D\`0`6````P3P!``D```#8/`$`
M!@```.(\`0`+````Z3P!`!P```#U/`$`%````!(]`0`'````)ST!`!$````O
M/0$`"````$$]`0`.````2CT!``@```!9/0$`!0```&(]`0`0````:#T!`!``
M``!Y/0$`!@```(H]`0`9````D3T!``H```"K/0$`'````+8]`0`'````TST!
M``4```#;/0$`$````.$]`0`4````\CT!``L````'/@$`#0```!,^`0`H````
M(3X!`!@```!*/@$`%P```&,^`0`$````>SX!``D```"`/@$`"@```(H^`0`'
M````E3X!``(```"=/@$`#@```*`^`0`(````KSX!`!\```"X/@$`/@```-@^
M`0`C````%S\!`#@````[/P$`)@```'0_`0`Q````FS\!`"<```#-/P$`9```
M`/4_`0`4````6D`!`%4```!O0`$`.````,5``0!*````_D`!`%L```!)00$`
M*````*5!`0`1````SD$!`#@```#@00$`*````!E"`0`L````0D(!`"<```!O
M0@$`&P```)="`0`^````LT(!`*D!``#R0@$`*````)Q$`0`C````Q40!`!<`
M``#I1`$`2`````%%`0"%````2D4!`#````#010$`00````%&`0!;````0T8!
M`$D```"?1@$`'0```.E&`0`8````!T<!`"$````@1P$`'P```$)'`0`K````
M8D<!`"$```".1P$`)P```+!'`0`=````V$<!`!$```#V1P$`,P````A(`0`E
M````/$@!`"<```!B2`$`'P```(I(`0`P````JD@!`&D```#;2`$`*P```$5)
M`0`Q````<4D!`$$```"C20$`,P```.5)`0`E````&4H!`#T````_2@$`90``
M`'U*`0!-````XTH!`"D````Q2P$`*P```%M+`0`O````ATL!`"X```"W2P$`
M,````.9+`0!4````%TP!`(,```!L3`$`6@```/!,`0!(````2TT!`$H```"4
M30$`,@```-]-`0`O````$DX!`"P```!"3@$`+0```&].`0!Q````G4X!`&\`
M```/3P$`LP```']/`0`7````,U`!`"4```!+4`$`,@```'%0`0`I````I%`!
M`#X```#.4`$`(@````U1`0!2````,%$!`"4```"#40$`"P```*E1`0"Q````
MM5$!`$4```!G4@$`(0```*U2`0`N````SU(!`#````#^4@$`)0```"]3`0`<
M````55,!`#$```!R4P$`!P```*13`0`'````K%,!``0```"T4P$`#0```+E3
M`0`+````QU,!``X```#34P$`"P```.)3`0`%````[E,!`!````#T4P$``@``
M``54`0!9````"%0!``4```!B5`$`$@```&A4`0`$````>U0!``<```"`5`$`
M"````(A4`0`%````D50!``,```"75`$`$````)M4`0`*````K%0!``P```"W
M5`$`$P```,14`0`-````V%0!``(```#F5`$`!P```.E4`0`&````\50!`!0`
M``#X5`$`#`````U5`0`8````&E4!``8````S50$`$@```#I5`0`,````354!
M``,```!:50$`*@```%Y5`0`$````B54!``8```".50$`!P```)55`0`?````
MG54!`#4```"]50$`+@```/-5`0`O````(E8!`!<```!25@$`(````&I6`0`;
M````BU8!`!@```"G5@$`)````,!6`0`?````Y58!`!H````%5P$`(````"!7
M`0`:````05<!`#(```!<5P$`&@```(]7`0`O````JE<!`"L```#:5P$`'P``
M``98`0`C````)E@!`!\```!*6`$`&@```&I8`0`E````A5@!`"8```"K6`$`
M)0```-)8`0`D````^%@!`!@````=60$`'0```#99`0`D````5%D!`!@```!Y
M60$`(@```))9`0`5````M5D!`"4```#+60$`/````/%9`0`?````+EH!`",`
M``!.6@$`'P```'):`0`@````DEH!`!H```"S6@$`&````,Y:`0`F````YUH!
M`!X````.6P$`*0```"U;`0`>````5UL!``D```!V6P$`#````(!;`0`7````
MC5L!`"\```"E6P$`)````-5;`0`'````^EL!``\````"7`$`%````!)<`0`.
M````)UP!``T````V7`$`)````$1<`0`%````:5P!``<```!O7`$`(@```'=<
M`0`E````FEP!`!,```#`7`$`&@```-1<`0`=````[UP!`!H````-70$`!P``
M`"A=`0#'````,%T!``L```#X70$`%0````1>`0`,````&EX!``8````G7@$`
M"0```"Y>`0`+````.%X!``T```!$7@$`'0```%)>`0`7````<%X!``8```"(
M7@$`,P```(]>`0`3````PUX!`!,```#77@$`!P```.M>`0`&````\UX!``\`
M``#Z7@$`!P````I?`0`R````$E\!`"$```!%7P$`$P```&=?`0`,````>U\!
M`!$```"(7P$`,@```)I?`0`0````S5\!``@```#>7P$`'0```.=?`0`)````
M!6`!``H````/8`$`!0```!I@`0`4````(&`!``H````U8`$`'0```$!@`0`(
M````7F`!``T```!G8`$`$````'5@`0`Z````AF`!`!\```#!8`$`"````.%@
M`0`:````ZF`!`"<````%80$`!@```"UA`0`5````-&$!``<```!*80$`"```
M`%)A`0`)````6V$!`#\```!E80$`!P```*5A`0`/````K6$!``X```"]80$`
M$````,QA`0`)````W6$!``D```#G80$`"````/%A`0`3````^F$!``<````.
M8@$`&0```!9B`0`*````,&(!`!<````[8@$`%````%-B`0`*````:&(!``P`
M``!S8@$`%P```(!B`0`$````F&(!`"H```"=8@$`$0```,AB`0`'````VF(!
M``D```#B8@$``@```.QB`0`0````[V(!`!@`````8P$`"P```!EC`0`#````
M)6,!``@````I8P$`!@```#)C`0`'````.6,!``T```!!8P$`"P```$]C`0`4
M````6V,!`!4```!P8P$`#@```(9C`0`5````E6,!`"\```"K8P$`(````-MC
M`0`<````_&,!``P````99`$`,0```"9D`0`)````6&0!``X```!B9`$`.P``
M`'%D`0`5````K60!``4```##9`$`$@```,ED`0`_````W&0!`!(````<90$`
M"@```"]E`0`&````.F4!``0```!!90$`!````$9E`0`*````2V4!`!,```!6
M90$`!0```&IE`0`&````<&4!``8```!W90$`"0```'YE`0`$````B&4!``P`
M``"-90$`"@```)IE`0`@````I64!``H```#&90$`!0```-%E`0`,````UV4!
M``P```#D90$`#0```/%E`0`8````_V4!`!D````89@$`'P```#)F`0`=````
M4F8!`!$```!P9@$``@```()F`0`$````A68!``H```"*9@$`!@```)5F`0`%
M````G&8!``,```"B9@$`#````*9F`0!%````LV8!`!H```#Y9@$`-0```!1G
M`0`H````2F<!`%,```!S9P$`&0```,=G`0!R````X6<!`"````!4:`$`-0``
M`'5H`0`A````JV@!`$4```#-:`$`,````!-I`0`H````1&D!`"D```!M:0$`
M)@```)=I`0!@````OFD!`"4````?:@$`*````$5J`0`H````;FH!`"(```"7
M:@$`*P```+IJ`0`P````YFH!`!(````7:P$`$P```"IK`0`0````/FL!`'D`
M``!/:P$`"0```,EK`0!R````TVL!`',```!&;`$`?````+IL`0`K````-VT!
M`%0```!C;0$`%P```+AM`0`6````T&T!``\```#G;0$`90```/=M`0`?````
M76X!`$````!];@$`'P```+YN`0`<````WFX!`%$```#[;@$`%````$UO`0`*
M````8F\!``4```!M;P$`!@```'-O`0`(````>F\!``4```"#;P$`$@```(EO
M`0`,````G&\!`!````"I;P$`$P```+IO`0`=````SF\!``\```#L;P$`&P``
M`/QO`0`D````&'`!``\````]<`$`"@```$UP`0`$````6'`!``D```!=<`$`
M"P```&=P`0`:````<W`!`"(```".<`$`"````+%P`0`'````NG`!``4```#"
M<`$`%````,AP`0`I````W7`!``<````'<0$`"`````]Q`0`/````&'$!`!@`
M```H<0$`%````$%Q`0`(````5G$!``P```!?<0$`#P```&QQ`0`'````?'$!
M``8```"$<0$`%````(MQ`0`&````H'$!``D```"G<0$`"@```+%Q`0`,````
MO'$!`!4```#)<0$``P```-]Q`0`(````XW$!``0```#L<0$`"@```/%Q`0`$
M````_'$!``8````!<@$`!P````AR`0`%````$'(!``0````6<@$`!P```!MR
M`0`9````(W(!``<````]<@$``@```$5R`0`"````2'(!``D```!+<@$`!@``
M`%5R`0`&````7'(!``4```!C<@$`)P```&ER`0`"````D7(!``0```"4<@$`
M"P```)ER`0`)````I7(!``\```"O<@$`$P```+]R`0`'````TW(!``(```#;
M<@$`!P```-YR`0`&````YG(!`"$```#M<@$`!@````]S`0`0````%G,!`!X`
M```G<P$`$@```$9S`0`"````67,!``8```!<<P$`"0```&-S`0`S````;7,!
M`"(```"A<P$`!P```,1S`0`'````S',!``<```#4<P$`"P```-QS`0`%````
MZ',!``(```#N<P$`"P```/%S`0"M`0``_7,!`',```"K=0$`N````!]V`0!"
M````V'8!`,`````;=P$`D````-QW`0!&````;7@!`#<```"T>`$`,P```.QX
M`0`V````('D!`"\```!7>0$`+@```(=Y`0!H````MGD!`&4````?>@$`9P``
M`(5Z`0!E````[7H!`&<```!3>P$`;P```+M[`0`_````*WP!`&0```!K?`$`
M0P```-!\`0`O````%'T!`$T```!$?0$`1````))]`0!*````UWT!`#,````B
M?@$`.````%9^`0!N````CWX!`"X```#^?@$`+0```"U_`0"(````6W\!`&(`
M``#D?P$`#P$``$>``0!.````5X$!`#0```"F@0$`BP```-N!`0!0````9X(!
M`!````"X@@$`%0```,F"`0`4````WX(!``<```#T@@$`"0```/R"`0`(````
M!H,!``(````/@P$`!0```!*#`0`#````&(,!`!X````<@P$`+@```#N#`0`L
M````:H,!`"D```"7@P$`+@```,&#`0`8````\(,!``H````)A`$`$0```!2$
M`0`K````)H0!`!,```!2A`$`$````&:$`0`0````=X0!`!0```"(A`$`!0``
M`)V$`0`H````HX0!``T```#,A`$`#0```-J$`0`3````Z(0!``T```#\A`$`
M"P````J%`0`;````%H4!`!`````RA0$`"@```$.%`0`6````3H4!`#\```!E
MA0$`#0```*6%`0`/````LX4!`!````##A0$`"P```-2%`0`-````X(4!``8`
M``#NA0$`#0```/6%`0`3`````X8!`!4````7A@$`#0```"V&`0`;````.X8!
M`!L```!7A@$`$P```'.&`0`(````AX8!``D```"0A@$`6````)J&`0`T````
M\X8!`!4````HAP$`/0```#Z'`0!.````?(<!`&H```#+AP$`:0```#:(`0!P
M````H(@!`&\````1B0$`0@```(&)`0`/````Q(D!`!(```#4B0$`#@```.>)
M`0`3````]HD!``\````*B@$`!0```!J*`0`&````((H!`!,````GB@$`"0``
M`#N*`0`/````18H!`!$```!5B@$`(0```&>*`0`C````B8H!`!8```"MB@$`
M$````,2*`0`-````U8H!`"0```#CB@$`$`````B+`0`)````&8L!`!4````C
MBP$`&0```#F+`0`1````4XL!`!4```!EBP$`&````'N+`0`?````E(L!`"0`
M``"TBP$`&@```-F+`0`0````](L!`!<````%C`$`$@```!V,`0`N````,(P!
M`!@```!?C`$`'````'B,`0`4````E8P!`%D```"JC`$`*@````2-`0`J````
M+XT!`"H```!:C0$`&````(6-`0`(````GHT!``D```"GC0$`-P```+&-`0`-
M````Z8T!``@```#WC0$`"P````".`0`'````#(X!``<````4C@$`!P```!R.
M`0`'````)(X!``P````LC@$`!````#F.`0`B````/HX!``\```!AC@$`$P``
M`'&.`0`7````A8X!`!(```"=C@$`'````+".`0`P````S8X!``D```#^C@$`
M&`````B/`0`>````(8\!`",```!`CP$`$0```&2/`0`4````=H\!`!(```"+
MCP$`#P```)Z/`0`C````KH\!`!T```#2CP$`!P```/"/`0`&````^(\!``<`
M``#_CP$`&@````>0`0`(````(I`!``H````KD`$`"@```#:0`0`1````09`!
M`!8```!3D`$`"0```&J0`0`1````=)`!``\```"&D`$`&@```):0`0`'````
ML9`!`!(```"YD`$`!0```,R0`0`6````TI`!`!X```#ID`$`#P````B1`0`J
M````&)$!`#\```!#D0$`.P```(.1`0`)````OY$!``<```#)D0$`$P```-&1
M`0`$````Y9$!``4```#JD0$`$````/"1`0`*`````9(!`!0````,D@$`/```
M`"&2`0`5````7I(!`"T```!TD@$`,@```**2`0`Q````U9(!`#`````'DP$`
M"0```#B3`0`&````0I,!``D```!)DP$`!P```%.3`0`[````6Y,!`#L```"7
MDP$`.@```-.3`0!?````#I0!`#D```!NE`$`.0```*B4`0`Y````XI0!`$L`
M```<E0$`+0```&B5`0`P````EI4!`#D```#'E0$`/P````&6`0`5````098!
M`!D```!7E@$`,@```'&6`0`F````I)8!`#\```#+E@$`$P````N7`0`*````
M'Y<!`!`````JEP$`!0```#N7`0`,````09<!`!X```!.EP$`(P```&V7`0`&
M````D9<!``4```"8EP$`%0```)Z7`0`+````M)<!``@```#`EP$`"@```,F7
M`0`#````U)<!``H```#8EP$`#````..7`0`'````\)<!``8```#XEP$`!0``
M`/^7`0`'````!9@!``4````-F`$`"P```!.8`0`+````'Y@!`!(````KF`$`
M0P```#Z8`0`7````@I@!`!@```":F`$`,@```+.8`0`7````YI@!``T```#^
MF`$`!0````R9`0`'````$ID!``<````:F0$`"@```"*9`0`%````+9D!`!,`
M```SF0$`!@```$>9`0`2````3ID!``4```!AF0$`"````&>9`0`$````<)D!
M``L```!UF0$`!@```(&9`0`E````B)D!`!$```"NF0$`*P```,"9`0`>````
M[)D!``@````+F@$`#@```!2:`0`-````(YH!``<````QF@$``P```#F:`0`#
M````/9H!`!H```!!F@$`(````%R:`0`K````?9H!``H```"IF@$`!0```+2:
M`0`(````NIH!``@```##F@$`7@```,R:`0`H````*YL!``8```!4FP$`"```
M`%N;`0`?````9)L!`"0```"$FP$`+P```*F;`0`R````V9L!`"8````,G`$`
M)@```#.<`0!=````6IP!`#X```"XG`$`%P```/><`0`'````#YT!`",````7
MG0$`$@```#N=`0`,````3IT!``(```!;G0$`$````%Z=`0`8````;YT!`!<`
M``"(G0$`&````*"=`0`8````N9T!``D```#2G0$`%0```-R=`0`'````\IT!
M`!D```#ZG0$`&P```!2>`0`9````,)X!`!,```!*G@$`&````%Z>`0`2````
M=YX!``<```"*G@$`6P```)*>`0`5````[IX!``D````$GP$`%0````Z?`0`V
M````))\!`!(```!;GP$`&@```&Z?`0`=````B9\!`!D```"GGP$`%P```,&?
M`0`=````V9\!`!X```#WGP$`,@```!:@`0`-````2:`!`"P```!7H`$`)P``
M`(2@`0`=````K*`!``8```#*H`$`'````-&@`0`>````[J`!`!H````-H0$`
M&@```"BA`0`+````0Z$!`!4```!/H0$`$P```&6A`0`-````>:$!``8```"'
MH0$`#P```(ZA`0`(````GJ$!`!4```"GH0$`%@```+VA`0`1````U*$!`!4`
M``#FH0$`!0```/RA`0`&`````J(!`!$````)H@$`"````!NB`0`3````)*(!
M``(````XH@$`!P```#NB`0`3````0Z(!`!(```!7H@$`"0```&JB`0`*````
M=*(!``D```!_H@$`"@```(FB`0`'````E*(!``<```"<H@$`#0```*2B`0`,
M````LJ(!``@```"_H@$`"0```,BB`0`:````TJ(!`"(```#MH@$`#0```!"C
M`0`8````'J,!`!X````WHP$`'@```%:C`0`/````=:,!`!````"%HP$`,```
M`):C`0`_````QZ,!`"$````'I`$`/````"FD`0`&````9J0!`"@```!MI`$`
M#@```):D`0`)````I:0!``H```"OI`$`#@```+JD`0`&````R:0!``D```#0
MI`$`"P```-JD`0`/````YJ0!`!8```#VI`$`%P````VE`0`<````):4!`"X`
M``!"I0$`+````'&E`0`P````GJ4!`"\```#/I0$`*0```/^E`0`I````*:8!
M`"8```!3I@$`.0```'JF`0`B````M*8!`#````#7I@$`0@````BG`0`Q````
M2Z<!`#(```!]IP$`)0```+"G`0`R````UJ<!`#D````)J`$`3@```$.H`0`U
M````DJ@!`#@```#(J`$`0P````&I`0`D````1:D!`!8```!JJ0$`3P```(&I
M`0`I````T:D!`!H```#[J0$`.P```!:J`0`B````4JH!`!@```!UJ@$`U0``
M`(ZJ`0`:````9*L!`"T```!_JP$`,````*VK`0`Q````WJL!`#(````0K`$`
M*0```$.L`0`6````;:P!`"X```"$K`$`-P```+.L`0`Z````ZZP!`#T````F
MK0$`.@```&2M`0":````GZT!`"L````ZK@$`'P```&:N`0`H````AJX!`#<`
M``"OK@$`-@```.>N`0!6````'J\!`%D```!UKP$`#0```,^O`0`$````W:\!
M``8```#BKP$`!0```.FO`0`1````[Z\!``X````!L`$`$````!"P`0`0````
M(;`!`!4````RL`$`&P```$BP`0`4````9+`!`!$```!YL`$`%@```(NP`0`)
M````HK`!``X```"LL`$`#P```+NP`0`1````R[`!``T```#=L`$`0P```.NP
M`0`&````+[$!`!$````VL0$`$P```$BQ`0`1````7+$!`!<```!NL0$`&P``
M`(:Q`0`/````HK$!``(```"RL0$`"P```+6Q`0`-````P;$!``L```#/L0$`
M'````-NQ`0`$````^+$!`!````#]L0$`$`````ZR`0`#````'[(!``\````C
ML@$`$P```#.R`0`(````1[(!`!````!0L@$`$@```&&R`0`+````=+(!``\`
M``"`L@$`$0```)"R`0`6````HK(!`!8```"YL@$`"@```-"R`0`'````V[(!
M``H```#CL@$`$````.ZR`0`-````_[(!`!$````-LP$`&@```!^S`0`.````
M.K,!``X```!)LP$`)````%BS`0`>````?;,!`!H```"<LP$`.````+>S`0`-
M````\+,!`!\```#^LP$`&0```!ZT`0`8````.+0!`#8```!1M`$`"````(BT
M`0`G````D;0!`"(```"YM`$`,````-RT`0`W````#;4!`!$```!%M0$`$@``
M`%>U`0`)````:K4!`!,```!TM0$`"0```(BU`0`P````DK4!`#L```##M0$`
M#P```/^U`0`0````#[8!`"$````@M@$`$@```$*V`0`C````5;8!`",```!Y
MM@$`"@```)VV`0`-````J+8!``H```"VM@$`'````,&V`0`6````WK8!`!X`
M``#UM@$`0@```!2W`0`6````5[<!`!<```!NMP$`&0```(:W`0`'````H+<!
M`%$```"HMP$`"P```/JW`0`J````!K@!``L````QN`$`2@```#VX`0`.````
MB+@!``H```"7N`$`#P```**X`0`*````LK@!`"$```"]N`$`"````-^X`0`4
M````Z+@!``<```#]N`$`"@````6Y`0`W````$+D!`!,```!(N0$`!@```%RY
M`0`3````8[D!``,```!WN0$`%````'NY`0`&````D+D!``D```"7N0$`#```
M`*&Y`0`,````KKD!`!$```"[N0$`$0```,VY`0`7````W[D!`!$```#WN0$`
M&0````FZ`0`7````([H!``@````[N@$`!@```$2Z`0`8````2[H!``L```!D
MN@$``@```'"Z`0`3````<[H!`!\```"'N@$`'P```*>Z`0`8````Q[H!`!(`
M``#@N@$`#P```/.Z`0`/`````[L!`!4````3NP$`"@```"F[`0`^````-+L!
M`#(```!SNP$`"````*:[`0`*````K[L!``L```"ZNP$`#P```,:[`0"B````
MUKL!`!X```!YO`$`30```)B\`0`'````YKP!`!````#NO`$`$@```/^\`0`$
M````$KT!`!X````7O0$`*````#:]`0`6````7[T!``8```!VO0$`%````'V]
M`0`H````DKT!``4```"[O0$`!@```,&]`0`/````R+T!``X```#8O0$`$```
M`.>]`0`.````^+T!``P````'O@$`#@```!2^`0`+````([X!`!`````OO@$`
M"````$"^`0`+````2;X!`!$```!5O@$`!@```&>^`0`(````;KX!`!4```!W
MO@$`#````(V^`0`_````FKX!`!$```#:O@$`"````.R^`0`3````];X!`!4`
M```)OP$`*P```!^_`0`G````2[\!`"(```!SOP$`(0```):_`0`8````N+\!
M`!H```#1OP$`)0```.R_`0`9````$L`!``,````LP`$`&0```##``0`+````
M2L`!``L```!6P`$``P```&+``0`)````9L`!``@```!PP`$`"@```'G``0`1
M````A,`!``T```"6P`$`$````*3``0`$````M<`!`"````"ZP`$`(0```-O`
M`0`3````_<`!``\````1P0$`$P```"'!`0`7````-<$!`"X```!-P0$`&@``
M`'S!`0`>````E\$!`"````"VP0$`$P```-?!`0`2````Z\$!`!,```#^P0$`
M)0```!+"`0`4````.,(!`$\```!-P@$`/P```)W"`0!.````W<(!`&$````L
MPP$`3P```([#`0`^````WL,!`$X````=Q`$`%@```&S$`0`'````@\0!``D`
M``"+Q`$`$````)7$`0`0````IL0!``L```"WQ`$`"````,/$`0`)````S,0!
M``@```#6Q`$`%@```-_$`0`,````]L0!``8````#Q0$`,`````K%`0`I````
M.\4!``X```!EQ0$`B0```'3%`0`=````_L4!``<````<Q@$`!0```"3&`0`-
M````*L8!``4````XQ@$`!P```#[&`0`&````1L8!`!````!-Q@$`20```%[&
M`0`2````J,8!`!D```"[Q@$`)````-7&`0`3````^L8!``(````.QP$`"```
M`!''`0`2````&L<!`!4````MQP$`#P```$/'`0`2````4\<!`"<```!FQP$`
M`@```(['`0`#````D<<!`!(```"5QP$`"0```*C'`0`-````LL<!``<```#`
MQP$`$@```,C'`0`@````V\<!``@```#\QP$`$P````7(`0`5````&<@!``T`
M```OR`$`(````#W(`0`'````7L@!`!T```!FR`$`#P```(3(`0`1````E,@!
M``D```"FR`$`#````+#(`0`"````O<@!``4```#`R`$`#P```,;(`0`2````
MUL@!``D```#IR`$`$````//(`0`&````!,D!`!(````+R0$`"P```![)`0`'
M````*LD!`!<````RR0$`)@```$K)`0`3````<<D!``8```"%R0$`"0```(S)
M`0`$````ELD!`!8```";R0$`"````++)`0`6````N\D!`!8```#2R0$`$```
M`.G)`0`%````^LD!``P`````R@$`(`````W*`0`$````+LH!`$4````SR@$`
M1@```'G*`0!%````P,H!`"4````&RP$`$@```"S+`0`3````/\L!``<```!3
MRP$`"0```%O+`0`6````9<L!`!````!\RP$`%0```(W+`0`&````H\L!``4`
M``"JRP$`%````+#+`0`%````Q<L!`)P```#+RP$`"@```&C,`0`>````<\P!
M``0```"2S`$`,P```)?,`0`%````R\P!`!P```#1S`$`!````.[,`0`0````
M\\P!`!`````$S0$`%@```!7-`0`,````+,T!``4````YS0$`&@```#_-`0`R
M````6LT!`#<```"-S0$`0````,7-`0`L````!LX!`#(````SS@$`00```&;.
M`0!*````J,X!`#$```#SS@$`10```"7/`0`U````:\\!`#<```"ASP$`)P``
M`-G/`0`0`````=`!`!4````2T`$`"P```"C0`0`H````--`!`"````!=T`$`
M(0```'[0`0`?````H-`!``@```#`T`$`"@```,G0`0`*````U-`!`!0```#?
MT`$`*0```/30`0`G````'M$!`#````!&T0$`"P```'?1`0`9````@]$!`"D`
M``"=T0$`&@```,?1`0`4````XM$!`!0```#WT0$`#0````S2`0`0````&M(!
M`!,````KT@$`1````#_2`0!]````A-(!`((````"TP$`$P```(73`0`-````
MF=,!``X```"GTP$`$0```+;3`0`2````R-,!`!8```#;TP$`!P```/+3`0`2
M````^M,!``H````-U`$`$P```!C4`0`2````+-0!`!4````_U`$`+````%74
M`0`L````@M0!`&T```"OU`$`%0```!W5`0`2````,]4!`!@```!&U0$`2P``
M`%_5`0`6````J]4!`#(```#"U0$`"@```/75`0`*`````-8!`"$````+U@$`
M'0```"W6`0`6````2]8!``X```!BU@$`#@```''6`0`5````@-8!`!4```"6
MU@$`*@```*S6`0`I````U]8!`"D````!UP$`*````"O7`0`G````5-<!`"D`
M``!\UP$`&@```*;7`0!5````P=<!`!,````7V`$`%0```"O8`0`5````0=@!
M`!0```!7V`$`$0```&S8`0`7````?M@!`!<```"6V`$`%````*[8`0`3````
MP]@!`#H```#7V`$`&````!+9`0`9````*]D!`#X```!%V0$`%0```(39`0`'
M````FMD!`!$```"BV0$`(````+39`0`3````U=D!`!,```#IV0$`'@```/W9
M`0`B````'-H!`!T````_V@$`&P```%W:`0`:````>=H!`"(```"4V@$`$@``
M`+?:`0`<````RMH!`"$```#GV@$`'`````G;`0`8````)ML!`!L````_VP$`
M$P```%O;`0`;````;]L!`!P```"+VP$`'````*C;`0`8````Q=L!``H```#>
MVP$`&@```.G;`0`3````!-P!`!0````8W`$``0```"W<`0`+````+]P!``4`
M```[W`$`%````$'<`0`0````5MP!``<```!GW`$`!P```&_<`0`2````=]P!
M``<```"*W`$`!P```)+<`0`%````FMP!`!4```"@W`$`!@```+;<`0`;````
MO=P!``4```#9W`$`!0```-_<`0`*````Y=P!``<```#PW`$`"@```/C<`0`5
M`````]T!`!0````9W0$`&````"[=`0`5````1]T!`!,```!=W0$`+````''=
M`0`3````GMT!`!````"RW0$`&@```,/=`0`4````WMT!``T```#SW0$`$P``
M``'>`0`Q````%=X!``8```!'W@$`"0```$[>`0`G````6-X!`!,```"`W@$`
M$````)3>`0`&````I=X!`!,```"LW@$`"P```,#>`0`&````S-X!`"$```#3
MW@$`$@```/7>`0`2````"-\!`!0````;WP$`$@```##?`0`8````0]\!`!4`
M``!<WP$`%````'+?`0`#````A]\!``H```"+WP$`(0```);?`0`&````N-\!
M``@```"_WP$`%0```,C?`0`2````WM\!``8```#QWP$`"0```/C?`0`0````
M`N`!``<````3X`$`,P```!O@`0`,````3^`!`!,```!<X`$`"0```'#@`0`2
M````>N`!`!4```"-X`$`$0```*/@`0`5````M>`!``T```#+X`$`!````-G@
M`0`*````WN`!``<```#IX`$`%````/'@`0!)````!N$!``@```!0X0$`#P``
M`%GA`0`E````:>$!`!4```"/X0$`&````*7A`0`.````ON$!`!````#-X0$`
M#@```-[A`0`+````[>$!``L```#YX0$`#0````7B`0`3````$^(!`!,````G
MX@$`%P```#OB`0`L````4^(!``L```"`X@$`%0```(SB`0`9````HN(!``T`
M``"\X@$`#````,KB`0`:````U^(!``L```#RX@$`!@```/[B`0`$````!>,!
M`!(````*XP$`5@```!WC`0`6````=.,!``L```"+XP$`!````)?C`0`%````
MG.,!`!@```"BXP$`&0```+OC`0`:````U>,!``H```#PXP$``@```/OC`0`$
M````_N,!`",````#Y`$``P```"?D`0`%````*^0!`"@````QY`$`"@```%KD
M`0`%````9>0!``<```!KY`$`&````'/D`0`1````C.0!`%$```">Y`$`$@``
M`/#D`0`&`````^4!``<````*Y0$`"````!+E`0`$````&^4!``4````@Y0$`
M9````";E`0`*````B^4!``T```"6Y0$`'@```*3E`0`%````P^4!``8```#)
MY0$`%0```-#E`0`9````YN4!`#@`````Y@$`#@```#GF`0`)````2.8!`!X`
M``!2Y@$`%P```''F`0`*````B>8!``@```"4Y@$`&0```)WF`0`O````M^8!
M`"D```#GY@$`*````!'G`0`2````.N<!`)P```!-YP$`G@```.KG`0`$````
MB>@!``<```".Z`$`"````);H`0`'````G^@!``T```"GZ`$`#````+7H`0`V
M````PN@!`!\```#YZ`$`,0```!GI`0`E````2^D!``@```!QZ0$`60```'KI
M`0`1````U.D!`!````#FZ0$`$@```/?I`0`9````"NH!`$X````DZ@$`'0``
M`'/J`0`&````D>H!`!\```"8Z@$`!P```+CJ`0`&````P.H!`"````#'Z@$`
M!@```.CJ`0`)````[^H!`"<```#YZ@$`)@```"'K`0`'````2.L!``H```!0
MZP$`)0```%OK`0`F````@>L!`$L```"HZP$`&````/3K`0`<````#>P!`"D`
M```J[`$`'0```%3L`0`6````<NP!``(```")[`$`#0```(SL`0`(````FNP!
M`!,```"C[`$`#0```+?L`0`&````Q>P!``8```#,[`$`%````-/L`0`4````
MZ.P!``@```#][`$`"0````;M`0`+````$.T!``H````<[0$`"P```"?M`0`1
M````,^T!``\```!%[0$`$@```%7M`0`3````:.T!``4```!\[0$`!@```(+M
M`0`5````B>T!`!0```"?[0$`%@```+3M`0`5````R^T!``4```#A[0$`!@``
M`.?M`0`%````[NT!`!<```#T[0$`(`````SN`0`1````+>X!``T````_[@$`
M#````$WN`0`4````6NX!`!````!O[@$`$0```(#N`0`O````DNX!``0```#"
M[@$`%````,?N`0`%````W.X!``4```#B[@$`%P```.CN`0`3`````.\!`!0`
M```4[P$`'````"GO`0`A````1N\!`!D```!H[P$`&0```(+O`0`=````G.\!
M`"(```"Z[P$`'````-WO`0`$````^N\!``4```#_[P$`#@````7P`0`.````
M%/`!``@````C\`$`"@```"SP`0`B````-_`!``T```!:\`$`%````&CP`0`(
M````??`!`!(```"&\`$`!P```)GP`0`0````H?`!``\```"R\`$`"````,+P
M`0`6````R_`!`!(```#B\`$`'````/7P`0`%````$O$!``0````8\0$``P``
M`!WQ`0`[````(?$!`%$```!=\0$`/P```*_Q`0`R````[_$!`"P````B\@$`
M'@```$_R`0`D````;O(!`$$```"3\@$`$0```-7R`0`^````Y_(!`"X````F
M\P$`'````%7S`0`Z````<O,!`$H```"M\P$`5P```/CS`0!<````4/0!`!``
M``"M]`$`(@```+[T`0!'````X?0!`!4````I]0$`.0```#_U`0`=````>?4!
M`"$```"7]0$`'@```+GU`0`C````V/4!`!\```#\]0$`&0```!SV`0`;````
M-O8!`!,```!2]@$`.0```&;V`0`Y````H/8!`#T```#:]@$`.0```!CW`0`Z
M````4O<!`#L```"-]P$`.````,GW`0!Q`````O@!`!T```!T^`$`"@```)+X
M`0`7````G?@!``D```"U^`$`*0```+_X`0`P````Z?@!`#L````:^0$`*0``
M`%;Y`0`+````@/D!`$L```",^0$`1@```-CY`0`'````'_H!`!<````G^@$`
M%0```#_Z`0`/````5?H!`!````!E^@$`%P```';Z`0`0````COH!``\```"?
M^@$`#@```*_Z`0`3````OOH!``P```#2^@$`$0```-_Z`0`,````\?H!``X`
M``#^^@$`!0````W[`0`C````$_L!``0````W^P$`"````#S[`0`&````1?L!
M`!0```!,^P$`$0```&'[`0`0````<_L!`%(```"$^P$``@```-?[`0`'````
MVOL!`!(```#B^P$`(````/7[`0`%````%OP!``<````<_`$`&P```"3\`0`(
M````0/P!`!````!)_`$`,@```%K\`0`6````C?P!`#(```"D_`$`=@```-?\
M`0`5````3OT!`$X```!D_0$`(@```+/]`0`1````UOT!``8```#H_0$`)P``
M`._]`0`,````%_X!``<````D_@$`#@```"S^`0`+````._X!`!8```!'_@$`
M"P```%[^`0`<````:OX!`!@```"'_@$`!0```*#^`0`2````IOX!``T```"Y
M_@$`$@```,?^`0`E````VOX!`!8`````_P$`%0```!?_`0`1````+?\!`",`
M```__P$`"@```&/_`0`,````;O\!`!0```![_P$`$P```)#_`0`,````I/\!
M``X```"Q_P$`"P```,#_`0`3````S/\!``T```#@_P$`"@```.[_`0`?````
M^?\!`!(````9``(`%P```"P``@`&````1``"`!````!+``(`%0```%P``@`6
M````<@`"``T```")``(`&````)<``@`Q````L``"`!T```#B``(`#@`````!
M`@`/````#P$"`"0````?`0(`!0```$0!`@`1````2@$"``<```!<`0(`%@``
M`&0!`@`'````>P$"``L```"#`0(`(````(\!`@`T````L`$"``D```#E`0(`
M(@```.\!`@`;````$@("``T````N`@(`%````#P"`@`$````40("`!0```!6
M`@(`"0```&L"`@`(````=0("``L```!^`@(`#@```(H"`@`&````F0("``H`
M``"@`@(`(0```*L"`@`_````S0("`$`````-`P(`)````$X#`@`M````<P,"
M`"H```"A`P(`1P```,P#`@`D````%`0"`"D````Y!`(`,P```&,$`@!#````
MEP0"`&$```#;!`(`-````#T%`@`M````<@4"``<```"@!0(`"````*@%`@`)
M````L04"`!0```"[!0(`&P```-`%`@`;````[`4"`#`````(!@(`)0```#D&
M`@`B````7P8"`#H```""!@(`0@```+T&`@`'``````<"`!D````(!P(`"0``
M`"('`@`(````+`<"`"`````U!P(`$0```%8'`@`4````:`<"``T```!]!P(`
M"````(L'`@`5````E`<"``D```"J!P(`#P```+0'`@`-````Q`<"`!H```#2
M!P(`&````.T'`@`[````!@@"``H```!""`(`#P```$T(`@`&````70@"`!H`
M``!D"`(`!@```'\(`@`0````A@@"``4```"7"`(`#0```)T(`@`0````JP@"
M``D```"\"`(`#````,8(`@`,````TP@"``X```#@"`(`!P```.\(`@`#````
M]P@"``T```#["`(`-@````D)`@!(````0`D"``@```")"0(`$0```)()`@`8
M````I`D"`"4```"]"0(`(0```.,)`@`1````!0H"`!$````7"@(`$@```"D*
M`@`5````/`H"``L```!2"@(`$@```%X*`@`I````<0H"``<```";"@(`#0``
M`*,*`@`.````L0H"`!(```#`"@(`"P```-,*`@`\````WPH"``D````<"P(`
M'````"8+`@`2````0PL"`!8```!6"P(`0````&T+`@`D````K@L"`#P```#3
M"P(`.@```!`,`@`V````2PP"`!$```""#`(`#@```)0,`@`,````HPP"``8`
M``"P#`(`%P```+<,`@`<````SPP"``H```#L#`(`'0```/<,`@`+````%0T"
M`!D````A#0(`$````#L-`@`8````3`T"``<```!E#0(`%0```&T-`@`5````
M@PT"``D```"9#0(`!P```*,-`@`4````JPT"`!$```#`#0(`&0```-(-`@`%
M````[`T"``<```#R#0(`"0```/H-`@`0````!`X"``\````5#@(`%0```"4.
M`@`5````.PX"``<```!1#@(`!0```%D.`@`-````7PX"``X```!M#@(`$0``
M`'P.`@`.````C@X"``T```"=#@(`!@```*L.`@`Q````L@X"`"D```#D#@(`
M)0````X/`@`(````-`\"``\````]#P(`$P```$T/`@`?````80\"`!X```"!
M#P(`'P```*`/`@`-````P`\"``P```#.#P(``P```-L/`@`'````WP\"``T`
M``#G#P(``@```/4/`@`,````^`\"`!$````%$`(`"P```!<0`@`4````(Q`"
M`!@````X$`(`%0```%$0`@`<````9Q`"`",```"$$`(`$P```*@0`@`6````
MO!`"``X```#3$`(`!P```.(0`@`*````ZA`"``P```#U$`(`#@````(1`@`5
M````$1$"`%H````G$0(`&````((1`@`L````FQ$"`!4```#($0(`!P```-X1
M`@`(````YA$"`!@```#O$0(`'0````@2`@`>````)A("`"````!%$@(`"```
M`&82`@`2````;Q("`"L```""$@(`)````*X2`@`$````TQ("`!0```#8$@(`
M$P```.T2`@`2`````1,"`"$````4$P(`&````#83`@`6````3Q,"`"0```!F
M$P(`*````(L3`@`5````M!,"`!<```#*$P(`7P```.(3`@`A````0A0"`!T`
M``!D%`(`+0```((4`@`C````L!0"`!T```#4%`(`)````/(4`@`@````%Q4"
M`"(````X%0(`%P```%L5`@`=````<Q4"``H```"1%0(`"0```)P5`@`4````
MIA4"``D```"[%0(`"````,45`@`3````SA4"``\```#B%0(`*P```/(5`@`5
M````'A8"``@````T%@(`8````#T6`@`_````GA8"`%````#>%@(`<````"\7
M`@`G````H!<"``H```#(%P(`)0```-,7`@`O````^1<"``D````I&`(`!P``
M`#,8`@`-````.Q@"`#X```!)&`(`!P```(@8`@`7````D!@"`!D```"H&`(`
M20```,(8`@`M````#!D"`"<````Z&0(`#@```&(9`@`W````<1D"`!T```"I
M&0(`00```,<9`@`V````"1H"`#\```!`&@(`-0```(`:`@`4````MAH"``H`
M``#+&@(`$P```-8:`@`6````ZAH"`!@````!&P(`"````!H;`@`Q````(QL"
M``H```!5&P(`"@```&`;`@`F````:QL"``H```"2&P(`%P```)T;`@`6````
MM1L"``<```#,&P(`$0```-0;`@`1````YAL"``H```#X&P(`%@````,<`@`$
M````&AP"``4````?'`(`!@```"4<`@`/````+!P"`!(````\'`(`$````$\<
M`@`=````8!P"``T```!^'`(`!P```(P<`@`0````E!P"`"````"E'`(`$@``
M`,8<`@`-````V1P"`!H```#G'`(`)@````(=`@`.````*1T"`!\````X'0(`
M+P```%@=`@`)````B!T"``L```"2'0(`&````)X=`@`0````MQT"`!8```#(
M'0(`&0```-\=`@`.````^1T"`!`````('@(`#0```!D>`@`)````)QX"`"T`
M```Q'@(`!@```%\>`@`)````9AX"``T```!P'@(`$P```'X>`@`&````DAX"
M`!P```"9'@(`-````+8>`@`8````ZQX"``\````$'P(`"````!0?`@`>````
M'1\"`!L````\'P(`#````%@?`@`"````91\"`"$```!H'P(`!P```(H?`@`(
M````DA\"`&X```";'P(`$`````H@`@`'````&R`"`"<````C(`(`1@```$L@
M`@`<````DB`"`"<```"O(`(`1````-<@`@`Q````'"$"`$````!.(0(`'```
M`(\A`@`6````K"$"`!(```##(0(`!@```-8A`@`-````W2$"``H```#K(0(`
M"0```/8A`@`-`````"("`!$````.(@(`#P```"`B`@`*````,"("``P````[
M(@(`$````$@B`@`'````62("``@```!A(@(`!P```&HB`@`4````<B("`!0`
M``"'(@(`#P```)PB`@`%````K"("`"4```"R(@(`%0```-@B`@`*````[B("
M`!0```#Y(@(`"P````XC`@`4````&B,"``L````O(P(`!@```#LC`@`6````
M0B,"`!8```!9(P(`!P```'`C`@`'````>","`!D```"`(P(`"````)HC`@`%
M````HR,"``<```"I(P(`$@```+$C`@`;````Q","``L```#@(P(`#0```.PC
M`@`M````^B,"`"$````H)`(`&````$HD`@`%````8R0"``P```!I)`(`%```
M`'8D`@`-````BR0"``(```"9)`(`$P```)PD`@`2````L"0"`!\```##)`(`
M0````.,D`@`C````)"4"`#0```!()0(`,0```'TE`@`T````KR4"`"(```#D
M)0(`8@````<F`@`6````:B8"`&X```"!)@(`.P```/`F`@!6````+"<"`'$`
M``"#)P(`+0```/4G`@`3````(R@"`#P````W*`(`*P```'0H`@`P````H"@"
M`#````#1*`(`'`````(I`@`Z````'RD"`+\!``!:*0(`*P```!HK`@`?````
M1BL"`!8```!F*P(`5@```'TK`@",````U"L"`#,```!A+`(`0````)4L`@!:
M````UBP"`%`````Q+0(`(@```((M`@`5````I2T"`!T```"[+0(`'0```-DM
M`@`J````]RT"`!P````B+@(`)0```#\N`@`C````92X"`!8```")+@(`-P``
M`*`N`@`J````V"X"`"@````#+P(`&@```"PO`@`P````1R\"`&(```!X+P(`
M+0```-LO`@`T````"3`"`$4````^,`(`,@```(0P`@`K````MS`"`$<```#C
M,`(`90```"LQ`@!:````D3$"`"8```#L,0(`*````!,R`@`Q````/#("`"X`
M``!N,@(`+````)TR`@!9````RC("`)4````D,P(`;````+HS`@!<````)S0"
M`%H```"$-`(`,@```-\T`@`E````$C4"`"4````X-0(`*P```%XU`@!N````
MBC4"`&L```#Y-0(`P````&4V`@`9````)C<"`"<```!`-P(`/@```&@W`@`M
M````IS<"`%$```#5-P(`)P```"<X`@!<````3S@"`!X```"L.`(`"@```,LX
M`@#>````UC@"`#L```"U.0(`*0```/$Y`@!"````&SH"`#T```!>.@(`)0``
M`)PZ`@`@````PCH"`#\```#C.@(`"````",[`@`(````+#L"``D````U.P(`
M$P```#\[`@`0````4SL"`!(```!D.P(`"P```'<[`@`&````@SL"``X```"*
M.P(`!````)D[`@!<````GCL"``0```#[.P(`$0`````\`@`2````$CP"``@`
M```E/`(`!@```"X\`@`.````-3P"``0```!$/`(`%@```$D\`@`*````8#P"
M``D```!K/`(`$0```'4\`@`3````ASP"``(```";/`(`%````)X\`@`4````
MLSP"`!(```#(/`(`#@```-L\`@`5````ZCP"``8`````/0(`%@````<]`@`-
M````'CT"``,````L/0(`-````#`]`@`$````93T"`!,```!J/0(`!P```'X]
M`@`D````ACT"`%````"K/0(`.0```/P]`@`Z````-CX"`!\```!Q/@(`)P``
M`)$^`@`B````N3X"`"8```#</@(`*`````,_`@`C````+#\"`"4```!0/P(`
M+````'8_`@`G````HS\"`#L```#+/P(`(@````=``@`X````*D`"`#0```!C
M0`(`)0```)A``@`I````OD`"`"P```#H0`(`)P```!5!`@`L````/4$"`"T`
M``!J00(`-0```)A!`@`H````SD$"`"4```#W00(`*@```!U"`@`R````2$("
M`"4```![0@(`+````*%"`@`;````SD("`"4```#J0@(`0@```!!#`@`F````
M4T,"`"H```!Z0P(`+0```*5#`@`N````TT,"`"8````"1`(`)````"E$`@`N
M````3D0"`"L```!]1`(`.````*E$`@`=````XD0"``H`````10(`$P````M%
M`@`9````'T4"`"P````Y10(`(P```&9%`@`-````BD4"``\```"810(`%@``
M`*A%`@`+````OT4"`!D```#+10(`*@```.5%`@`(````$$8"``P````91@(`
M(0```"9&`@`R````2$8"`!@```![1@(`*P```)1&`@`K````P$8"`"0```#L
M1@(`"````!%'`@#F````&D<"`!$````!2`(`%@```!-(`@`,````*D@"``D`
M```W2`(`#0```$%(`@`5````3T@"`!$```!E2`(`*0```'=(`@`B````H4@"
M``8```#$2`(`10```,M(`@`<````$4D"`!T````N20(`'0```$Q)`@`+````
M:DD"`!,```!V20(`"0```(I)`@!2````E$D"`"H```#G20(`'0```!)*`@`4
M````,$H"`!<```!%2@(`*````%U*`@`8````ADH"`!(```"?2@(`)````+)*
M`@`3````UTH"`!0```#K2@(`#`````!+`@`8````#4L"`!@````F2P(`%P``
M`#]+`@`5````5TL"`!P```!M2P(`%````(I+`@!.````GTL"`"P```#N2P(`
M"0```!M,`@`I````)4P"`"@```!/3`(`!P```'A,`@`;````@$P"``<```"<
M3`(`"````*1,`@`)````K4P"`#P```"W3`(`!@```/1,`@`3````^TP"`!0`
M```/30(`#@```"1-`@`)````,TT"``H````]30(`(````$A-`@`3````:4T"
M``T```!]30(`%@```(M-`@`2````HDT"`!@```"U30(`&````,Y-`@`,````
MYTT"``X```#T30(`&`````-.`@`$````'$X"`"\````A3@(`#P```%%.`@`%
M````84X"``<```!G3@(``@```&].`@`1````<DX"`",```"$3@(`"P```*A.
M`@`#````M$X"``8```"X3@(`#````+].`@`,````S$X"`!$```#93@(`$```
M`.M.`@`6````_$X"`!<````33P(`!0```"M/`@`;````,4\"`"\```!-3P(`
M'P```'U/`@`>````G4\"``D```"\3P(`*0```,9/`@`,````\$\"`!,```#]
M3P(`0P```!%0`@`9````55`"``<```!O4`(`%P```'=0`@`^````CU`"`!$`
M``#.4`(`$@```.!0`@`(````\U`"``0```#\4`(`!0````%1`@`-````!U$"
M`!H````540(`!@```#!1`@`'````-U$"``D````_40(`$0```$E1`@`(````
M6U$"`!(```!D40(`$@```'=1`@`P````BE$"``P```"[40(`%````,A1`@`/
M````W5$"`!<```#M40(`$`````52`@`9````%E("`"0````P4@(`(@```%52
M`@`E````>%("`!````">4@(``@```*]2`@`$````LE("``L```"W4@(`"@``
M`,-2`@`%````SE("``,```#44@(`#0```-A2`@!'````YE("`!4````N4P(`
M,@```$13`@`Y````=U,"`%(```"Q4P(`#P````14`@!V````%%0"`"(```"+
M5`(`3@```*Y4`@`O````_50"`#8````M50(`/0```&15`@`I````HE4"`"<`
M``#,50(`,````/15`@!O````)58"`#0```"55@(`+0```,I6`@`I````^%8"
M`"P````B5P(`+@```$]7`@`Q````?E<"`"8```"P5P(`%````-=7`@`0````
M[%<"`'L```#]5P(`"@```'E8`@!X````A%@"`'H```#]6`(`>0```'A9`@`P
M````\ED"`&$````C6@(`%````(5:`@`2````FEH"``T```"M6@(`@P```+M:
M`@`F````/UL"`#D```!F6P(`(@```*!;`@`@````PUL"`&L```#D6P(`&P``
M`%!<`@`*````;%P"``4```!W7`(`!@```'U<`@`(````A%P"``4```"-7`(`
M%P```)-<`@`-````JUP"`!D```"Y7`(`%P```--<`@`B````ZUP"`!`````.
M70(`*````!]=`@`Q````2%T"``X```!Z70(`#````(E=`@`(````EET"``<`
M``"?70(`#@```*==`@`?````MET"`"8```#670(`$0```/U=`@`'````#UX"
M``8````77@(`%P```!Y>`@`L````-EX"``<```!C7@(`!0```&M>`@`2````
M<5X"`!T```"$7@(`*P```*)>`@`'````SEX"``L```#67@(`$P```.)>`@`)
M````]EX"``T`````7P(`%P````Y?`@`-````)E\"``H````T7P(`#0```#]?
M`@`)````35\"`!````!77P(``0```&A?`@`*````:E\"``4```!U7P(`"P``
M`'M?`@`%````AU\"``8```"-7P(`"@```)1?`@`%````GU\"``@```"E7P(`
M#````*Y?`@`3````NU\"``<```#/7P(``@```-=?`@`"````VE\"``@```#=
M7P(`"````.9?`@`'````[U\"``L```#W7P(`+`````-@`@`"````,&`"``0`
M```S8`(`#@```#A@`@`.````1V`"`!````!68`(`%0```&=@`@`0````?6`"
M``(```".8`(`"P```)%@`@`&````G6`"`"4```"D8`(`!P```,I@`@`2````
MTF`"`"D```#E8`(`$@````]A`@`"````(F$"``<````E80(`$````"UA`@`J
M````/F$"`#8```!I80(`"0```*!A`@`(````JF$"``L```"S80(`'````+]A
M`@`%````W&$"``8```#B80(`"P```.EA`@`!`````````+H$````````$`8`
M``H#``"7````;@$``*,'```"````_`0```0$```V!``````````````Y`0``
M,@(``%L$```\`0``AP8``*X&```L!```R@$```````"5!@````````````!Y
M`@``K0(``#T!``!]`0``I04`````````````4P```.D"```J`````````"H%
M````````=0```,,!````````K0,``)H'``!:`P``QP4``!,(``"]````F0,`
M`-4````&!0``MP0``'`"```T!0``<00``$,!``#]`P``90(````````-!```
ML0$```````#E`0``S0$``$T%````````]00````````0"````````"0#````
M``````````````".!````````'0```#>!P``8`,``*<"````````4`(`````
M``#_!0``4@4``*<&``!+`0``A0```,<'``"C`0``1P,``%@'``!*!```````
M````````````````````````````4`8```````"O`0```````)$$```5!P``
M*`$```````"-!0``&````-$$``#L`@``5@<``(\'```Q!P```````!P```#8
M!P``_04``#@#``"6````)0,``!D(``#=`P``'P8``````````````````+<'
M```O`0``CP$```````#*`@```````)4```"6`@``$`0``.H$``!+!0``X@4`
M`(H#``!^!P```````````````````0,``-<&``#:`P``SP0``,L`````````
M80(``(0!``!V`@```````-(#````````&@@``$P'``#H!0```````.8#````
M````Z@<``)D!````````<`8````'``"!!@``]P0``*\'``"3`@``"````"8"
M``#V!````````$``````````(`8``'\!``#M!0`````````````K!```<`,`
M`%L%``#-!@``]0,``.T!``!M!````````+H````U`@``40<``!`!``#:!```
M'@(``````````````````$X%``#X````M`8```````!<````Z04``%`#```%
M`0``&@0``#H'``"@`0````````````"Y!@``]0$``-4&`````````````)4!
M``#P!```>@8``(P'``#Q!0``:0,``'L```#``P``#P$``&8#``#[`0``008`
M`%(!``",`@``9`4``'0&``!@!@``,0```#T%``"0!@``:00``,(`````````
M6`````````````````````````"8`P```````,4&````````FP<``*P'````
M````[@<``$@"``!6`@```````)4"``!#!P``A@4``+0!``!#`P``N`$``(D#
M``#Z`@```````'D$```.!```T0<``'\#```.!@``708``)4%``!]!```````
M`/H'``"<!@``JP8``)L"``"N`````P$```````#%`0``/P0``!`'````````
MH0$``,8#``!-!P```````+`!`````````````((!``"_!@``]P(```````#:
M`@````````4%````````K@4``*\#````````2````$0'```U`````00`````
M````````P`$``%T```#*````I08``.0$``")!P``-P,``+H!````````)@,`
M`%X%``"D`@``]`<``.(!````````+@,```<%``#S````````````````````
M)@````D"````````R`,``,8"````````N@4``,4$``!A!P``NP8````````.
M`@``CP,``&L'``!'!P``=0<``)L!```?`P``O@0``&X```#=!0``100`````
M``!%!@``HP8``&D"``!'!0``C@,``"\&``"<`@``C@```&4%``#A!```````
M`(T$``#6!P``^`4````````'"```D`$``$$````T`@``A@0```````#6!0``
M`````"H$``!L``````````````"_`0``O0$``,$$``#%`@```````-H```"R
M`````````"(%```#!@`````````````4!```X0(``#L!`````````````)(!
M``!K`P```````-@%``!X````JP4``)0'``"6!P````````````"(`P``(00`
M`-P%```X!0```````)`$``#?!P``X08```\&```$!0``EP<``!4!````````
MZ@$`````````````I`,``#@&````````%04``(H"````````&P$``#\"```'
M`P```````)T!``!$````LP4````````!`@``A04```````"G````````````
M```+"```"P0``&L&``"Z!@``@0(````````T````=`4``#P%````````S0,`
M`*0!``!;````WP(```8!`````````````'D&``!K`@``L`,```````"U`P``
M*P````````!/!0``A0<``)$'``#$!```HP0````````_`0``_@(``/`"``#*
M!0```````.L"``!S!0``"@8``&,#``#=`@````````````#Q`P```````+<!
M``````````````````"8`@``7@8``.8$````````G0,``-0"````````#```
M`'8&``"O!@``]P8``.P$````````^P0``#T'``#;`P``BP(``)D```"\````
ML@$``'P```"$!P`````````````"!@``W@(``$X!``##`P``7P4`````````
M````U@$``!<$```#!0```````"<```!F!P```````+8%```\!```10$``!('
M``!U!0``F`8```````")!@``;0,``!($``"0`P``50(``(<$``"+````M00`
M`-$%``"O!````````%L&`````````````!\'``#G`0``*P(``(8````T!@``
M)0```/P```#T`@```````/X!``#V````.@4``,D$``"D!0``C@$```````#V
M!P``LP<``#L'`````````````%@%``!^!````````%,#``"C!0``P````-<`
M``#$`0````````````#D`P``R@8`````````````9`0``&P'```\````U```
M`'$#```C!````````#`&````````,@8```````!)!0``HP(````````"!0``
MGP$``)8&```K!0``\@,``-("`````````````.D&``![`@``#0<``"4$``!X
M`@```````(H!````````F08``*D'``#D!P``L@,``+(&``!7`P``T`4``$$#
M``"/!@````````````!E!P```````*\"```V`P````````\'```C!0``O@4`
M`*T!````````M0<``/4&````````]0<``(<#``!`!0``70<```````#]!```
MZ````/L&```=`P``)@0``-D$```?`@``````````````````7P(``"D'````
M````20$``,T$``"_`P````````P%````````_0```&$$````````P`<```$(
M``#;!```'@```,(&``!3!P```````$8&``!+!```>P<``!8```#_`0``60(`
M``<"```!`0``Z0```+\"```\!@```````,$%``!(!P``0P8```````#M`P``
MUP(``!4#``";````M08``"P&``#^!```\P0``-0'``!@!P``2`,```````#V
M`P``"P$``.($``"^`0``J00```````#H`0``#@@``.4"```U!0```````.('
M``"-````H`4``'@&````````;@8``+X'``!,`@``JP,``+@&```H`@``T0``
M```````W!```!0@```````!"!P````````D```#0!@``700``(H'``##`@``
M%`,```@%``#2!@``J`8``(,&``#D````7@0````````#`P``G`<``!@%```0
M`@``G08``````````````````.X$```.`P``#0```#`'````````G`$``(D%
M``"H!```'04``&L$````````"P(``-(%``!A`P``8@$``'H#````````M`0`
M````````````)P8```````"9`@`````````"````````,P0``%H!```B!```
MM@````(#``!!`@``+@8``-L````&!```Q@$````````,`0``<0(``"@```#K
M`0```0<``%@#````````!`$``#T```#S!@``*`,`````````````&`@``-T`
M```Q!@`````````````A!0``J@,``)H```#%!P``P@,``($$````````!@8`
M``````#A!P``&0<``(0#``!O`0```````!P%``#.````I@$`````````````
M`````+$&````````!00``$L&``"K`@``Q`,```````#S`P``SP<```````"=
M`@```````!8(``"'!0```````),!````````<@,```@'``!8`@``5P<`````
M```N!0``#`(``,(%```8!P``@````$T#``"-`0``/00``*L$``!<!0``````
M`.P&``"I`@```````(4"``!/`P``300```X!``"]!P``#`,``/@"``!0`0``
MD@<``'X&```6`P``K0```*8````V!P``,0$``-L&``#I!````````)$%````
M````?`,````````9!@```````(X'`````````````'T#``#7`P``>@4``+,$
M``"T````X`$``&T"``#P`0``5`0```````#/`0``.P0`````````````Q@<`
M``````"A`@``"0$```L#`````````````%T!````````\````$(```"1`0``
MQ`8`````````````S@,```H'``"W!0``LP,``'<'`````````````)P%``"G
M`0``U`4```````""!0``QP$``.`&```^!0``1@,``%<"``"``P``G````#X`
M```E`@```````&('``"(!```VP(``+@```#3`@```````.("``"B!@``````
M```````2`@``WP8```````"J!P``^`0``!,%``!M!0``@P<``"0%```4!@``
MCP4``$`#``#-````?P(``!8&````````M04``.4#```=`@``DP<``-$"````
M`````````!(!``!0!P``.P8``)H&``!A`0```````),%```S!0```````!X!
M```]!@``8@8``+X"``"N`P``'@,``/<#```O`@``S`<``"L#``",`0``````
M`$8$``#+!0``^0(```````#4`0``#`0``*\%````````>P8``,X$``!F!0``
M(@<``/(```!Q!0``:0<``"D#```$`@``X@8``-4!````````(P8``%P#``!F
M``````````````"R!P````````````"3!@``VP<``"0&``"%`P``E@4`````
M````````#@<````````L!P``,`0``$X#```+!0``J@8```````!>````3@<`
M`+0'``#H`P```````!8%``#_`@``6@(``"`(````````+`,``%,&``""!@``
M`````$P!``">`0``:@8``"T&``#"!P``10<``'4$``#P!@``'0```+P"``!"
M`@``HP```.H%``"Y!0``T`,``!,!``#4`P``'`@``(<'``!W!@```````&@%
M```M!```2`8``&<$``!U`@```````+H'``!F`0``S`````````#G!P``308`
M`%4#````````]`,``*<%``!_!0````8``+T"````````&P``````````````
MCP0``)\"``#)`0``WP,```````"/````Y00`````````````0`8``%($``#7
M`0``(`0```````#:!@``&@$```````````````````\#``#U!0``-`,`````
M``"T`P``F04`````````````_0$``$L#``!*````ZP<```,'``#-!P``Z0,`
M``````!E`P``&@8``+4````7"````````%0'```B"```(08``/H```#2!```
M`````!H#````````A00``+P$``#C`@```````*(#```)!P``=`(``%\&``#A
M`P``(@(```````#O````TP$``%L#``">````H0,``+D$``!4!@``^@4``'(`
M``#\!0``&P(```````#N!@``A@,``%,$````"```V0```/8!```9`0``R0(`
M`/$```#1!@``4@```,\&``!C!````````&X$```4`0``004``-,'```7`0``
M\08```````#,!@````````````#G`@```````'L$``"P!P``B0$``#<!``!L
M`P``5P$``+L$``#_`P``3P0``/$'``````````````````!F!@``^P```)L$
M``#<````:`(```\`````````-P(```````#4!@``<P0```0&```D````/`(`
M`$H&````````\00``$0&````````/`,``*P"````````00<```````!#!```
M`````-<%``!V`P``L0(```````!\!@``'@4``$,"``"]!0```````&H!``!J
M!```,@<``'('``"J!```(P,``,L"```5"```O`,`````````````(`4`````
M```N!```A````,(!````````V`8``*('````````:04```````"8!```````
M`.0"```%````G@(``"@%``#M!```"`$``.`#`````````````,<"````````
M``````````#(`0``M@8```````#?`0```````'4#````````@0````D%```S
M````20<``%$&```B````3`8```````#N!0``<`<``"T"``!Y`0``,0,`````
M``!$`0````````P&``#D!@````````````!\!0``I0,``!T$```E!0``>`$`
M`"P"``"R!````````,P"```*`0```````$<$````````^P,```````"7`P``
M6P<``&P%````````/P,``)8!```?"```V0$`````````````1@4`````````
M````=P(``$D"```'!P````````````"`!0``W@$``"X!`````````````","
M``#O!@``W`(``*@'``!%`@````````````"(!P```````(L#````````0@8`
M`,8$``#W`0``R@0```````!T!```.@`````````/!````````"<#``!D`@``
MX`4``!0`````````%@$````````8!```S04``+$'````````````````````
M````%P(``'L!```-`@```````&\`````````U0<`````````````1P$``/,'
M``#A!0``W`0``*0$````````404``"D%````````/`<``'L%``#R`@``````
M`+\````;"`````````````#-`@``7`(```8#```0!0``@0<``"4&``!X!P``
M.@,``/8"``##````?`0``"`'``"5!```=`<``*\```!\`0````````````!-
M`0```````*X!``"4!0````````````!(`0``.00```````#G`````````(`!
M```8`@```````.$```"#`0``9P(``(8!````!0```````"$```"I`0``Q04`
M`"@&``#U````P0(``%8&``!`!```@@,``"<'``!N!0````````````#)!@``
MO`8````````Y`@``I@0``"D&``!C`@``'0@``!(#``"=!0````````````"E
M!P``]P<``#\%````````7`$````````O!P``+04``&T'```W`````````"``
M``!?`0``O08```````"4````(0@``$P````@`0``Y@4``#4'````````+@<`
M``````#'!```S`,``&@'```*````W@,``$L"```O````H@````````!^!0``
MA`0```````#6`@``[@$```````#/`P``:0$``*@#````````<@8`````````
M````]@4``````````````````.H#````````N0(``#0$```3!@```````/L"
M``"0````&00``-4%``""`@``````````````````$````*8%``"4!```````
M`'0!`````````````+,```#<`0````````````!H!```H@0``'````"P!```
M=08``````````````````)\```"A!@```````)L%`````````````.$!````
M````(P<`````````````(`,``'T```"(!0``(0<``,D%``#S`0``*@$`````
M``"I`P``9P4``"@'``!P!````````.4'`````````````+@%````````````
M```````R`0```````/('```_!@````````\"````````7@,``!L#``!8!```
M6@<```````#F````W`<``&X#``#J````@`<``/D#``#B````?0(``!\!``!G
M!P``R`(```````#T!````````&\"``#I`0``A@8```````!Q`0```````%\#
M``#(!0``D0```+,&```:!P``3P```*X"``````````,``&<`````````C`8`
M``````"Q`````````(L&``#C!P``3`,``/X%````````QP8``)X'````````
M*0```$L````+````60<```````!C!@```````!0%``#,!```+P4``,L'``"8
M````1@$``*H%``!L`0``&04``.L$``!:!```.@8``%X!```R````?@$``)(#
M```'``````````````#!`0````````$&``"#`P``````````````````````
M`*4!``!%````2@(``*L!``!"`P```````',"``!U`0``<P```$<"``#9!@``
M<P<``/@&```1"```$P0``&\%``#E`````P@``*8#``#_!P``D@```/P&``"[
M!P``C```````````````L@(``+$#``""````_08``*`$````````````````
M``#P`P```````/$"```&`@```````%4!``#H!@``8@,``#$%``#^!@``2@4`
M`#L````K!@``C`0``'`%````````I`<```````";`P``V@<```````!C`0``
M`````-T&``"F!P```````)<$``!?!P``*0$``",!``"=!```G@0``*`#```@
M`@``R`8``(@&``!H````Z`(``&4!````````/@,``'T'```>"```MP``````
M```=!@``400``"X`````````?P<``*4`````````W@8``*`"``!/`@``)@$`
M```````9`P```````-,%```F!P``W@```'(%``!6````^0`````````-`P``
MQ`4``%T"```I`@```````,D```"-`P```````-`!```P!0``\P4```````!9
M`0```````/P#``".!0``>0```"L'```Y!@```````'T%````````/P```/H$
M``!>`@``9`````P(``!@````30````D&```%`@````````````"F`@``````
M`!$!`````````````%0"```A`P``Q0,``&4&``!T`P``IP,``),````7!P``
M`````-@"`````````````/,"```B`P```````&H%``!6`0``0P4``.<&```U
M!````````#H$````````)P$``$\'````````V0(``#8```!5!```-@4``)0&
M````````?P8``&@!````````3@8``+`"``"L`0``5@,``)8$```#`@``\@8`
M`!\$``"P````<P$```@(``!L!@``[`$```````!$`P``\@0``+8"```6!```
MJ@(``+<&``#C!0``D`<```````!K`````````!X&``#2``````````````!$
M`@```````,$&``##!0``J@$``"4!``!3!0````````````!,!0``B0```#4&
M``"9!P``;`0```H%``#C`0``8@(``)<"``!M````4@(``-$!``#/````````
M```````V!@``^@8``!P'``````````$```````#3`````````(X&``#;!0``
MLP(``,X&```1`@```````'T&``"?`P``W`,````````'!```'P```*<'``#K
M````O@```$\&```"`0```````#@'``#?!0``M@<``+0%````````^`$``!P#
M``"H````'`$``"8%```1`P``H``````````8`P``@`(```````!2`P``-`$`
M`+(%````````O`$```````#W````LP$```D$``#'````R`````````#F!P``
MF@4```('````````H@$``&($```[`@``>`0``)<%``#I!P``_P8``,X!``!M
M`0``0@$``!<&```1!0``/0,``%`$```J`P```````.P```!=!0``I`8`````
M``#/!0```````&@#``"$!@``S`4``,$#```P`0``W0$``#,"``"A!```````
M````````````]P4``!4$```^!P``$P(``(,``````````````*D````$`P``
MHP,```````#Z`P```````.L#``"J````W00``$L'````````,```````````
M````$00```\(``#9`P``I@8```<&``"N!```0`(````````S!P````````8(
M``!-`@``8P<``%4%```X`@``K08``'H$``!%!0``RP,```````!G`0``F`<`
M`-D%````````Y08``%8%``!'````2`0```````#K!@```````%X'```X!```
M$0<``!P&``#M!@``BP<``+P'```S`P``OP<```````",!0``@P(``!H%````
M`````````*X'``````````````````##!@``F@,``'8%```.!0```````#X"
M``##!```,0(``(4!``#Y`0``@0$``)@%```J!P``Q0```!<%``"L!```AP(`
M````````````;P<```````#$!P```````'H'```:```````````````.````
M_0(````````S!@``)@8````````^!@``,`,`````````````40$`````````
M````!`@```````"4`P``&0(```````"[`P``]`````H$``!B````!`<``),$
M``"Z`@``%0(``#8"``!*`P``U@,``-``````````MP,``%0!```G!0``;P,`
M`+<"``!G`P``2`4``(L$``````````````````!)!````````'H```"Y`0``
M`````!@&````````H`8``#D%``!V!P``&P<``'(!``!_````-P4``+D#``!5
M!P``AP$``*D&``"L`P``=P4``.,$``#U`@``+`$```````!.`````````.@'
M``"Q!0```````,($```2!0``?@,``#(%``#:`0``P@(``.`$````````:@(`
M`&4````>!P```````-H%```O`P```````',#````````G@4``%L"``"M!```
M$P,``%,!``#.!0``D@4``.0%``#]!P``E@,``%$"``"$`@``:@<``'<$````
M````8P4``.X#````````H0<``*(%``!P`0``Q````$$$```8`0``50```&$%
M```&````0`<```````!%`P``5@0``/8&```-`0``0@0`````````````-P<`
M`&`!``";!@``1@````````!W`P```````&L%``!O!@``NP$```<!````````
M.0,`````````````P`(``*@%````````Y04``!\%```D`@``T`0``#<&``"3
M`P```````.,````1````%0```(L%``#1`P```````````````````````'\$
M``!W````$P<```````````````````($``#M!P``L00``"P````%`P``````
M`-0$``",`P``"@(``#`"```````````````````Z`@``R@,``"(!``#B`P``
M`````,`$``"#!```20````````"9!```^`<``($#``"Y!P``C@(``+8#``#0
M!P```````-<$```M````B0(``#\'``"L````X````&X'``#(!````````$H'
M``"-`@``A@(``"$"``"U`@``0P```#4!````````#0@``',&``!Z`0``H`<`
M`+`&``!J````'@0``/\````^!`````````D(``#K!0``$08`````````````
M````````````````[`<`````````````^P4```````!<!```G0<``)\$``!R
M`@``Y`$```````#9!P``TP8```````!9!0``WP0``"T#``"D````````````
M````````;P0``*T%``#Y!0``4P(````````0`P```````#($```K`0``[P$`
M`(@!``!@!0``N0```#0'````````%P,``.`'``"<!```+0$``+P%``!2!P``
M`@(``(0%``"(`@``F@(``",`````````5P4``)`%``"A````WP```-('````
M````F`$``-X$``!$!0``"@@```````!C````^P<```0````6!P``N`0``!D`
M```S`0``W`8````````2"```6@8```````#`!0``Z`0``/(!``!.!```5P8`
M`'D#``````````````````"%!@``%P```"<"``!Y!P``U@0``"P%````````
M````````````````/0(````````(!````04``/D$``">!@``]`$```````!F
M`@``"`8``!P$``#&!@``1@(``*4"``"7`0``VP$```````!"!0``3@(`````
M``!9!@``6P$``,$'``#0`@```````!T'``"I!0``D@8````````Y!P``````
M`%````""!P``TP0``%0#``#O`P``-0,``)0"``#J`@``U00```````">`P``
M[P0``%$```"]!```9`$``&@&``!^`@``_@<``+@#``"T`@``[`,``$P$``#Z
M`0``D0(```\%``!1`P````````````#C`P````````4'``#@`@``[P4``!0"
M```=`0``@P4``$8'``!V!```D@0``%<$``!)!@```````#$$``#,`0``````
M`#L%```2````+@(`````````````"`,``-8&````````7P0`````````!```
M`````,$`````````K`4``'$```#3`P```````"D$````````=@```)\'``"U
M`0``70,``-X%``!E!```"0,`````````````@`0``/0&````````YP4`````
M`````````````*$%``!``0``RP8``%`%``#N`@``[0````````#Y!@``?@``
M`(($````````=@$``%0%```""`````````T%`````````````/X#``":`0``
M)`$``"@$``!8`0``^0<``#X!``!D!P``;`(``"H&``#P!0``00$```````"?
M!@``#08``"T'`````````````&(%``#6`````````)4#`````````````'@#
M````````B@8```````"B`@`````````````B!@``M@0``&L!```A`0``%`<`
M`%\```!2!@``J`(``%P&```2!@``K`8`````````````QP,``#@```"*!0``
MB@0``!H"``!Z`@```````,L!````````_@```(<```!D!@``Y@(``%@&``"[
M````G`,````````Z`0``V````)`"`````````````$<&``#`!@``V`0``/`'
M``!\`@``D@(```````#O!P``R0,``(@```!J`P``U0(`````````````D08`
M`!,```#$`@``Q@```(L!``"K``````````L&``"`!@```````-@!````````
M[`4``"4'``"5!P``R0<```````#/`@``7`<``&<&``!)`P``EP8```````"!
M!0``L`4``$H!``"E!```_`(``&`$``!A````.P,``'$&``"-!P``_`$``#D`
M``"^!@``)P0``+@"``!W`0``-@$``*L'````````S@(``(H```"=````^`,`
M``````##!P``"`(``"0$```&!P```````+L%``#2`0``YP0```````!I!@``
M;08```4&````````Q@4``*@!`````````````.\"``"1`P``8`(```````"Z
M`P``NP(```````!9`P``IP0``+8!````````N`<```````#5`P``%`@``#(#
M```<`@```````!L$````````S@<``.X```!F!```Y@$````````;!0``1`0`
M``````")!```%@(```L'``#+!`````````````#7!P```P````````"]`P``
M`````'L#````````)`<``/(%``"_!0``808```````!Q!P``5P````````"/
M`@``E`$``.<#````````60```'P'``#*!P``K0<``'D%``"^`P```````!4&
M``#_!````P0``(8'``#Q`0``F@0``'@%```J`@``:0```,@'``!:!0``GP4`
M`&0#``!N`@``3P$``(T&``#C!@``V`,``+\$``#T!0``Y@8``%H```!5!@``
M``````````!R!```#`<``"\$``#M`@``600``%0```#\!P``.`$``!L&````
M`````````-T'````````Z@8````@("U-+"`M+6UE<W-A9V4]34534T%'12`@
M57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F875L
M="!O;F5S+@`@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F
M:6QE('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&\*("`@("`@("`@("`@
M("`@("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A(&1I9F9E
M<F5N="!B<F%N8V@@=&\*("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E
M;F5R871E9"!C;VUP96YD:75M+@`@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@
M<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L
M9"!B90H@("`@("`@("`@("`@("`@("`@('5S960N`"`@+6,L("TM8V]M<&5N
M9&EU;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M
M<&5N9&EU;2!F:6QE"B`@("`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D
M(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4*("`@
M("`@("`@("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2X`("`M
M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL
M92!I;G-T96%D(&]F('1H92!D969A=6QT"B`@("`@("`@("`@("`@("`@("`@
M("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C
M=&]R>2DN`"`@+60L("TM9&5B=6<@("`@("`@4VAO=R!E<G)O<B!M97-S86=E
M<R!F<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RX`("`M9"P@+2UD:7)E8W1O
M<GD]1$E2("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN
M`"`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY('1H:7,@;&]C86QE
M+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+@`@
M("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T
M:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@
M0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE
M+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R86YS;&%T:6]N
M<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@
M4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@
M+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S(&]N;'D@9F]R
M('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M("!5<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO
M9'5L93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@
M*$AO<F1E*2!M;V1U;&4N`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG
M="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP96YD:75M+@`@
M("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU
M;2X`("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A;G-L871I;VX@
M<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N`"`@+70L("TM=&5S="`@("`@
M("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U;B!A
M;GET:&EN9RX`("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P
M(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+@`@(&-O
M;6UI="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V
M97(N`"`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE($-6
M4R!S97)V97(N`"`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU
M;2!F:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE"B`@("`@("`@
M("`@("`@8W5R<F5N="!C;VUP96YD:75M+@`@(&5X=')A8W0@("`@($=E;F5R
M871E(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RX`("!H96QP("`@("`@("!3
M:&]W('1H:7,@:&5L<"!M97-S86=E+@`@(&EN:70@("`@("`@($-R96%T92!O
M;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG
M.B!4:&ES"B`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@
M4$\@9FEL97,@;V8@=&AI<R!L;V-A;&4N`"`@;6%K92`@("`@("`@0G5I;&0@
M8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!03R!F:6QE<RX`
M("!M86ME+6AE;'`@("!-87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L
M<"!F:6QE(&)E:6YG('5P+71O+61A=&4@86YD"B`@("`@("`@("`@("`@<')E
M<&%R92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T
M92UH96QP+B!9;W4*("`@("`@("`@("`@("!S:&]U;&0@;VYL>2!R=6X@;6%K
M92UH96QP($%&5$52('5P9&%T92UH96QP(&%N9"!R979I<VEN9R!T:&4*("`@
M("`@("`@("`@("!H96QP(&9I;&4N`"`@;65R9V4@("`@("`@365R9V4@=&AE
M(&-U<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E
M(&9I;&4N`"`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E
M<75E;G0N`"`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N
M9V5D(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<`H@("`@("`@
M("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@
M;VYE<RX`("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN
M=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A
M9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H
M=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@86YD`"!A="``(&]R`"(E<R(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@
M=V%S(&YO="!C<F5A=&5D.B`E<RX`)60@)7,@86YD("5S`"5D(&)Y=&5S('=R
M:71T96XN`"5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4`
M)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N
M`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M
M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S
M`"5S(&ES(&YO="!W<FET86)L92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E
M<P`E<R!N;W0@9F]U;F0N`"5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO
M;B!E>'1R86-T)R!F:7)S="X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L
M92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@
M:&]U<G,`/%!R979I;W5S`#QG971T97AT/B!T86<@;F]T(&-L;W-E9"!I;B!F
M:6QE("5S+@I/<&5N:6YG('1A9R!F;W5N9"!I;B!L:6YE("5D+@!!(&1A=&%B
M87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!
M32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E
M<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B
M<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!
M8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%C
M=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S<V5S.@!!8W1I=F%T92!38W)I
M<'0`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!
M9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D
M(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RX`061D:6YG(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.@!!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@4V5T=&EN9W,`061D<F5S
M<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F
M;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N
M`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!
M;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S
M:6]N<P!!;&P@9F]U<B!S:61E<P!!;&P@;V8@=&AE(&9O;&QO=VEN9P!!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G
M:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E
M<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L
M871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O
M>'D`06YS=V5R`$%N<W=E<F5D`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R
M8G5D80!!;GD@;V8@=&AE(&9O;&QO=VEN9P!!<'!L:6-A=&EO;@!!<'!L:6-A
M=&EO;B!I<R!R96%D>2X`07!P;'D@1FEL=&5R<P!!<'!L>2!T;R!#:&EL9"!3
M:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H
M5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`
M07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES(')U;&4_`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R
M;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD
M`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!
M<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S
M=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`075T;VUA=&EC86QL>2!U<&1A=&4@=&AE('-C<FEP="!A
M9G1E<B!E86-H(&-H86YG93\`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA
M;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A
M9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"
M86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87)B861O<P!"87-E;&EN90!"8V,`0F5G:6YS('=I=&@`0F5L87)U<P!"
M96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!"
M;&%C:VQI<W0`0FQA8VML:7-T($5D:70`0FQA8VML:7-T(&ES(&YO="!S=7!P
M;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`0FQA8VML
M:7-T960@061D<F5S<P!";&%C:VQI<W1E9"!!9&1R97-S97,`0FQO8VL@(B5S
M(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";V1Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R
M9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z
M96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R
M87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A
M<G5S<V%L86T`0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!"
M=6EL9&EN9R!L;V-A;&4@)7,N+BX@`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`
M0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`
M0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`
M0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B
M+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO
M;@!#87-E(%-E;G-I=&EV90!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N
M($ES;&%N9',`0V,`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P
M861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO
M;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A
M;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T
M:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E
M(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@96UA:6QS+@!#:&%N9V5S('-A=F5D+@!#:&%R`$-H96-?:R!,
M:6YK+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#
M:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A;FEN9R!U<"!0
M3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN`$-L96%N:6YG('5P(&QO8V%L92`E
M<RXN+B``0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E
M<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T
M90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E
M(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D
M97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T
M:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N
M9"!3:&5L;`!#;VUM86YD(&]P=&EO;G,Z`$-O;6UA;F1S.@!#;VUM96YT`$-O
M;6UI='1I;F<Z`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;W-E
M($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`
M0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U
M="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG
M;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE
M8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E
M<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`$-O;G1A:6YS`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#
M;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`
M0V]P>0!#;W!Y("5S`$-O<'D@;V8@)7,`0V]P>2!S96QE8W1I;VX`0V]P>6EN
M9R`E<R!T;R`E<P!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C;W!Y("5S('1O("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!C<F5A=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.@!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD
M:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`
M0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B
M+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S
M=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T
M:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E
M(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I
M;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N
M;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@
M;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O
M=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C
M86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O
M=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H
M92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O
M=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI
M;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@;F5W(&9O;&1E<@!#<F5A=&4@
M<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N
M=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!4
M:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O
M;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`
M0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1)
M4T%"3$5$`$1)4T%"3$5$.B``1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E
M`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L
M=6UN`$1E86-T:79A=&4@4V-R:7!T`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R
M<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U
M;'0@261E;G1I='D`1&5F875L="!097)M:7-S:6]N<P!$969A=6QT('!E<FUI
M<W-I;VYS`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@)7,`1&5L971E($-O
M;F1I=&EO;@!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE
M<W-A9V4@8V]M<&QE=&5L>0!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`
M1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI
M<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$
M96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R
M;W<`1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\`1&5L971E9`!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E
M<R(N`$1E;&EV97(@:6YT;R!M>2!)3D)/6`!$96QI=F5R(&EN=&\@;7D@24Y"
M3U@@86YD(&-O<'D@=&\`1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R961I
M<F5C="!T;P!$96QI=F5R('1O(&9O;&1E<@!$96QI=F5R>2!T:6UE`$1E;FUA
M<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H
M86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@
M4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$
M:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M=`!$:7)E8W1O<GD`1&ES86)L92`E<P!$:7-A8FQE9`!$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O
M<F5C87-T`$1I<W!L87D@9&5T86EL960@;F]T:69I8V%T:6]N('=H96X@96%C
M:"!F:6QT97(@:7,@87!P;&EE9#\`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$
M:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U
M=&D`1&\@7VYO="!S96YD(')E<W!O;G-E<R!T;R!B=6QK(&]R(&QI<W0@;65S
M<V%G97,`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<`!$;R!T:&ES.@!$;V5S('1H92!F:7)S="!R;W<@8V]N
M=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z
M`$1O97-N)W0@8F5G:6X@=VET:`!$;V5S;B=T(&-O;G1A:6X`1&]E<VXG="!E
M;F0@=VET:`!$;V5S;B=T(&5X:7-T`$1O97-N)W0@;6%T8V@@*'=I=&@@<&QA
M8V5H;VQD97)S*0!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO
M860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL
M`$524@!%8W5A9&]R`$5D:70`161I="`E<P!%9&ET($)L;V-K`$5D:70@1W)O
M=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M
M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S
M:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I
M;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I
M;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP
M='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE("5S`$5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N86)L
M960`16YD('EE87(`16YD<R!W:71H`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I
M<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4`16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE
M=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;@!%<75A;"!T;P!%<75A=&]R:6%L
M($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R('-A=FEN9R!C:&%N9V5S+@!%
M<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`
M17)R;W(Z(`!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%
M=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V
M97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>&5C=71I;F<Z
M`$5X:7-T:6YG(%)U;&5S`$5X:7-T<P!%>'!A;F0`17AP86YD(%-I9&5B87(`
M17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A
M<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X=')A8W1I;F<@
M9G)O;2`E<RXN+B``1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@
M=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N
M+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86ER`$9A;&ML86YD($ES;&%N
M9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`
M1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`
M1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE($-O=6YT
M.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&
M:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO
M861S(&YO="!S=7!P;W)T960N`$9I;'1E<B!!;&P@365S<V%G97,`1FEL=&5R
M($]N;'D@4V5E;B!-97-S86=E<P!&:6QT97(@3VYL>2!5;G-E96X@365S<V%G
M97,`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%)U;&4`1FEL=&5R(%)U;&5S`$9I
M;'1E<B!38W)I<'0@1&ES<&QA>0!&:6QT97(@7U)U;&5S`$9I;'1E<B!A8W1I
M=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@8V]P:65D('1O('1H92!F
M;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA
M=F4@8F5E;B!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H
M<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD97(@(B5S(BX`1FEL=&5R
M(&%C=&EV:71Y.B`E<R!M97-S86=E*',I('1H870@;6%T8VAE9"!T:&4@8FQA
M8VML:7-T('=E<F4@9&5L971E9"X`1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S
M<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@8F5E;B!C;W!I960@=&\@=&AE(&9O
M;&1E<B`B)7,B+@!&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E("(E<R(@
M9G)O;2`B)7,B(&AA<R!B965N(&1E;&5T960N`$9I;'1E<B!A8W1I=FET>3H@
M5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@:&%S(&)E96X@;6]V960@=&\@
M=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@;F]T(&9O=6YD+@!&:6QT97)S`$9I
M;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP
M`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO
M<@!&;V]D`$9O<B!A;B!I;F-O;6EN9R!M97-S86=E('1H870@;6%T8VAE<SH`
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A
M<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE
M9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&
M;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y
M<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9`!&;W)W87)D
M(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R
M:79E<BX`1F]R=V%R9',`1F]R=V%R9',@161I=`!&;W5N9"!A<'!L:6-A=&EO
M;G,Z("5S`$9O=6YD(&1I<F5C=&]R:65S.@!&<@!&<F%M97,`1G)A;F-E`$9R
M86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN
M97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H
M92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9U>GIY
M`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A
M;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E
M`$=E;F5R871I;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BX`1V5O<F=I80!'
M97)M86YY`$=E=&]P="!%<G)O<CH@`$=H86YA`$=I8G)A;'1A<@!':79E;B!.
M86UE`$=O`$=O961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5A=&5R
M('1H86X`1W)E871E<B!T:&%N(&]R(&5Q=6%L('1O`$=R965C90!'<F5E:R`H
M25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R
M871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R
M;6ES<VEO;G,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E
M<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W0@<&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM
M`$AA>F4`2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`
M2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5L<&5R(&%P<&QI8V%T
M:6]N('1O(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T
M:&4@2&]R9&4*9G)A;65W;W)K(&%N9"!I=',@87!P;&EC871I;VYS+@I&;W(@
M86X@:6YT<F]D=6-T:6]N(')E860@=&AE(&9I;&4@4D5!1$U%(&EN('1H:7,@
M9&ER96-T;W)Y+@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O
M9B!T:&4@9FEL93H`2&EG:`!(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I
M`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E('1R86YS;&%T:6]N(&=E;F5R871O<@!(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY('-Y
M;F-H<F]N:7-E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F
M;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-
M12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@
M56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L
M('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0
M;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE
M<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU
M;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL
M8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO
M8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`
M26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS
M('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE
M8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@
M>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@
M>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ
M`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E
M('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O
M<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!
M9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC
M<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD:79I9'5A
M;"!R=6QE<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT
M97)I;F<@9')I=F5R+@!);F1O;F5S:6$`26YE>&ES=&%N="!M86EL8F]X('-P
M96-I9FEE9"!F;W(@;65S<V%G92!D96QI=F5R>2X`26YF;P!);F9O<FUA=&EO
M;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);FET:6%L:7II
M;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A
M=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV
M86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN
M`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N
M`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A
M;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED
M('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H
M87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N
M:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8`27)A<0!)<F5L86YD`$ES`$ES;&4@;V8@36%N`$ES;B=T`$ES;VQA=&5D
M(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`
M2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*
M;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF
M>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`
M2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D
M(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`
M2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E
M`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U
M8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU
M=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,
M87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R
M;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A
M=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D
M97(`3&5F="!V86QU97,`3&5S;W1H;P!,97-S('1H86X`3&5S<R!T:&%N(&]R
M(&5Q=6%L('1O`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C
M:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN
M($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H
M="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO
M=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M
M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI
M;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE
M(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@
M5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)1`!,:7-T+4ED
M`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS
M=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R
M90!,:71H=6%N:6$`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN+@!,
M;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,
M;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86ME('-U<F4@=&AA="!Y;W4@
M:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N
M`$UA:VEN9R!D:7)E8W1O<GD@)7,`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S
M`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T
M(&UA<`!-87)?:R!M97-S86=E(&%S(&1E;&5T960`36%R8V@`36%R9VEN`$UA
M<FL@;65S<V%G92!A<SH`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&5S("AW:71H('!L
M86-E:&]L9&5R<RD`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET
M:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T
M(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!B
M;&%C:VQI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E
M<SH@)7,L($UA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D
M(&YE=R!A9&1R97-S97,@=&\@8FQA8VML:7-T+@!-87AI;75M(&YU;6)E<B!O
M9B!W:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E
M<W-E<SH@)7,L($UA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@
M861D(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+@!-87D`36%Y;W1T90!-
M961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365R9VEN
M9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@`$UE<F=I
M;F<@;&]C86QE("5S+BXN(`!-97)G:6YG('1H92!03R!F:6QE(&9O<B`E<R!T
M;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@
M;6]D=6QE("5S+BXN`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S
M9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@
M8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE
M=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C
M=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T<FEC
M`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L
M90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@
M4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!A9&1R97-S('1O
M(')E9&ER96-T(&UE<W-A9V4@=&\`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN
M9R!R96%S;VX@9F]R(')E:F5C=`!-:7-S:6YG(')E87-O;B!I;B!V86-A=&EO
M;BX`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN
M9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE
M9"!$871E`$UO9&EF>2!54DP`36]D=6QE`$UO9'5L=7,`36]L9&]V82P@4F5P
M=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H
M;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A
M<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-
M;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%)U;&4@1&]W;@!-;W9E(%)U;&4@
M57``36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I
M+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@
M06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/
M+"!)($1O($Y/5"!!9W)E90!.7W5M8F5R(&]F(&1A>7,@8F5T=V5E;B!V86-A
M=&EO;B!R97!L:65S.@!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R
M;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`
M3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N
M(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O
M<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`
M3F5W(%)U;&4`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`
M3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT
M(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`
M3FEG97)I80!.:6=H=`!.:75E`$YO`$YO("(E<R(@96QE;65N="!F;W5N9"!I
M;B!B86-K96YD(&-O;F9I9W5R871I;VXN`$YO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A8VME
M;F0@8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T`$YO(&)A8VME;F1S(&-O;F9I
M9W5R960@:6X@8F%C:V5N9',N<&AP`$YO(&)A=&-H('1E;7!L871E+@!.;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE
M;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.
M;R!C:&%N9V4N`$YO(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E
M9"!B96QO=R!T:&ES(&QE=F5L+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VUM86YD('-P96-I9FEE9"X`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@96YT<GD@=VET:"!T:&4@:60@(B5S
M(B!E>&ES=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92X`3F\@9FEL92!U
M<&QO861E9`!.;R!F:6QT97)S+B!#;&EC:R`B)7,B('1O(&-R96%T92!A(&YE
M=R!F:6QT97(N`$YO(&AE861E<G,@<W!E8VEF:65D`$YO(&QO8V%L92!S<&5C
M:69I960N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED
M960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.
M;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N
M=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@
M=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L
M97,`3F\@<V-R:7!T(&=E;F5R871E9"X`3F\@<VED97,`3F\@<W1R:6YG<R!S
M<&5C:69I960`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@
M=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@
M9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@
M*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)
M<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES
M;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C
M=&]R>0!.;W0@97%U86P@=&\`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO
M="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+@!.;W1I8V4`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S
M`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T
M('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N
M`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8FIE8W0@8W)E871O<B!P97)M
M:7-S:6]N<P!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/
M;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E
M<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E
M<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)
M344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R
M871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!A8F]U="!S8W)I<'0@=7!D
M871I;F<N`$]P=&EO;G,@9F]R("5S`$]P=&EO;G,Z`$]R9&5R960@3&ES=`!/
M<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@3W!T:6]N
M<P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T
M960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$
M871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E
M<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS
M`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA
M;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A
M`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC
M;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC
M871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!0
M87-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F
M<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E
M<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!0
M97)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O<FUA=&EO
M;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N
M`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@
M>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R
M>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N
M=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN
M('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E
M(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O
M(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I
M<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S
M=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W
M('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0
M<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L
M:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A
M=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O
M(%)I8V\`46%T87(`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4E]E
M87-O;@!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T
M90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD
M;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A
M;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8V5I=F5D`%)E9&ER96-T('1O`%)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296=U;&%R(&5X
M<')E<W-I;VX`4F5J96-T('=I=&@@<F5A<V]N`%)E;&%T:6]N<VAI<"!"<F]W
M<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`
M4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE
M(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T
M(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"!&:65L9`!297-E;G0@5&\`4F5S96YT+69R;VT`4F5S970`
M4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E
M<W5L=',@*&EN8VQU9&EN9R!(;W)D92DZ`%)E<W5L=',Z`%)E='5R;B!T;R!&
M:6QT97)S($QI<W0`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O(%)U;&5S
M($QI<W0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG
M:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T
M871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I
M97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L90!2=6QE($-O<&EE9`!2=6QE
M($1E;&5T960`4G5L92!$:7-A8FQE9`!2=6QE($5N86)L960`4G5L92!.86UE
M`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD
M(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U
M<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,
M(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA
M`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R
M<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4
M;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A
M8FEA`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/<'1I;VYS`%-A=F4@
M4V5T=&EN9W,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`
M4V-R:7!T`%-C<FEP="!5<&1A=&EN9P!38W)I<'0@;F]T('5P9&%T960N`%-C
M<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D+@!38W)I<'0@<W5C8V5S<V9U
M;&QY(&1E86-T:79A=&5D+@!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H
M:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<P!396%R8VAI;F<@9V5T=&5X
M="!B:6YA<FEE<RXN+@!3965N`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E
M`%-E;&5C="!A(&9I96QD`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@
M82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@
M861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J
M96-T`%-E;&5C="!T87)G970@9F]L9&5R`%-E;&5C="!T:&4@8VAA<F%C=&5R
M<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N
M(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L
M96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA
M=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3
M96QF+41E9FEN960@2&5A9&5R`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!3
M35,`4V5N9&5R`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A
M;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E
M="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D
M(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@
M;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P
M=&EO;G,N`%-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!3971U<`!3
M971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`
M4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W($%C=&EV92!38W)I
M<'0`4VAO=R!#=7)R96YT(%-C<FEP=`!3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME
M<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`
M4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC
M:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U
M<`!3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U
M<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`
M4VMI<'!E9"XN+@!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R
M`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S
M($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O
M<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E
M`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C
M:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T
M<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A
M=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T871U<R!F;W(@;&]C86QE("5S+BXN
M(`!3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M871C:&5S/P!3=&]R86=E
M(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L
M:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=
M`%-U`%-U8FIE7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z`%-U8FIE8W0`4W5B
M;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S
M(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL
M>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E
M<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N
M9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L
M;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S
M<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D
M86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N
M<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C
M<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA
M;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E
M<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3
M=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L
M>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E
M<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI
M<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S
M:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP
M97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E
M;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI
M9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H96QP(&9I;&4@9F]R
M("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N`%1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+
M;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B
M`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S
M:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M
M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@
M9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"X`5&AE(&1R:79E<B!S86ED.B``5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N`%1H92!H96QP(&9I;&4@)7,@9&ED;B=T('-T87)T
M('=I=&@@/#]X;6P`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H
M92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P
M.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S
M=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U
M87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD
M97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@
M8V]M<&]S92!P86=E`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F
M;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E
M;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@
M97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R
M86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F
M;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@
M;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S
M879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E
M;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@
M;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA
M<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H
M87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@
M9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+@!4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H
M97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B
M(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M
M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S
M*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE('-C<FEP="X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN:6YG('1R
M86YS;&%T:6]N+G!H<"!W:71H('1H92!F;&%G("UD('1O('-E92!A;GD@97)R
M;W(@;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F
M;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A
M<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C
M87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS
M,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I
M<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE
M8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T
M86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O
M9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92X`5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N
M9"!L:6YE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E
M<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE
M('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ
M`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#
M;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI
M;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M
M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871E9`!4
M<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E
M`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM
M96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@
M>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A
M:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S
M('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@8V]M;6%N
M9#H@)7,`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R
M;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`
M56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U
M="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P
M<&]R=&5D($5X=&5N<VEO;@!5;G1R86YS;&%T960`57!D871E`%5P9&%T92`E
M<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9&%T:6YG("5S(&AE;'`@
M9FEL92!F;W(@)7,N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S
M`%5R=6=U87D`57-A9V4Z`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN
M:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+@!5<V5R('!E<FUI<W-I;VYS`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR
M96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S`%5S97)S
M(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S
M(&YO="!E>&ES="X`5F%C871I;VX`5F%C871I;VX@161I=`!686-A=&EO;B!-
M97-S86=E`%9A8V%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E
M;G0@9FEL=&5R:6YG(&1R:79E<BX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!6
M86QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S
M`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z
M=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H
M879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R
M;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`
M5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E
M<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN
M($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I
M;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%2
M3@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`
M5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!787)N:6YG.B``5V4`5V5A=&AE
M<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC
M;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/
M+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H7VET96QI<W0@861D<F5S<V5S
M.@!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO
M9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E
M;&ES=`!7:&ET96QI<W0@161I=`!7:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E
M9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!7:&ET96QI<W1E
M9"!!9&1R97-S97,`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T
M:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7
M:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T<P!7;W)K`%=O<FL@061D<F5S
M<P!7;W)K(%!H;VYE`%=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@)7,N
M`%@M4')I;W)I='D`6"U2968`6"U3<&%M+4QE=F5L`%@M4W!A;2U38V]R90!8
M+5-P86TM4W1A='5S`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X
M=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`
M665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!A
M="!L96%S="!O;F4@96UA:6P@861D<F5S<R!F;W(@=VAI8V@@=&AE('9A8V%T
M:6]N(&UE<W-A9V5S('-H;W5L9"!B92!A8W1I=F%T960N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@
M86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O
M<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L
M;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D
M<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R
M<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V97)S
M:6]N(&ES('1O;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV
M96QY+@I.;W0@86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I
M<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;
M3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X
M="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F
M("5S70!?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SH`7T%D9')E<W-E<R!T
M;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z`%]!9&UI;FES=')A=&EO;@!?0FQA
M8VML:7-T`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]$96QE=&4@;65S
M<V%G92!C;VUP;&5T96QY`%]%;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@
M;&EN93H`7T9O<G=A<F0`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT
M/P!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?36]V92!M97-S
M86=E('1O(&9O;&1E<CH`7TUY(&5M86EL(&%D9')E<W-E<SH`7T]P=&EO;G,`
M7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V-R:7!T`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`7U9A8V%T:6]N`%]7:&ET96QI
M<W0`861D<F5S<R!B;V]K`&%N(&5R<F]R(&AA<R!O8V-U<F5D.@!A;F0`8V%L
M96YD87(`8V%L;0!C;&EC:R!H97)E`&1O;F4`9F%I;&5D`&9A;&QI;F<`9FEE
M;&0`9FEL90!F;W5N9#H@`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S
M=&EN9P!H.@!H:`!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S70!M871C:`!M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N
M;W0@8VAA;F=E9`!N;W0@9F]U;F0`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@
M:6UP;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT`'!I>&5L<P!P<F]C;6%I
M;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\`<FES:6YG`'-H;W<@9&EF9F5R
M96YC97,`<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!);F=O`'-M<S)E;6%I
M;"!V:6$@2%144`!S<P!S=&5A9'D`=&%S:R!L:7-T`'1H92!(;W)D92!03R!F
M:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T(&5X:7-T.@!T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U
M<&1A=&5D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@<'1?4%0*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,#@M
M,S`@,3$Z,C@K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`S+3`Q(#$R
M.C(X+3`S,#`*3&%S="U4<F%N<VQA=&]R.B!&86)I;R!';VUE<R`\9FQG;VUE
M<T!F87IE;F1A+G-P+F=O=BYB<CX*3&%N9W5A9V4M5&5A;3H@0G)A>FEL:6%N
M(%!O<G1U9W5E<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I
M;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/
M+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E@M1V5N
M97)A=&]R.B!+0F%B96P@,2XS+C$*4&QU<F%L+49O<FUS.B`@;G!L=7)A;',]
M,CL@<&QU<F%L/2AN(#X@,2D["@`@("U-+"`M+6UE<W-A9V4]345.4T%'14T@
M57-A<B!E<W1A(&UE;G-A9V5M(&1E(&-O;65T:6UE;G1O(&5M('9E>B!D80H@
M("`@("`@("`@("`@("`@("`@("`@("`@;65N<V%G96T@<&]R(&]M:7-SXV\N
M`"`@+6$L("TM861D/4%2455)5D\@("`@($%D:6-I;VYA<B!E<W1E(&%R<75I
M=F\@4$\@86\@8V]M<.IN9&EO+B!5=&EL('!A<F$*("`@("`@("`@("`@("`@
M("`@("`@("`@:6YC;'5I<B!U;2!C;VUPZFYD:6\@9&4@=6T@<F%M;R!D:69E
M<F5N=&4@;F\*("`@("`@("`@("`@("`@("`@("`@("`@8V]M<.IN9&EO(&=E
M<F%D;RX`("`M8BP@+2UB87-E/2]#04U)("!#86UI;FAO('!A<F$@;R!D:7)E
M8W3S<FEO(&)A<V4@*$AO<F1E*2!A('5S87(N`"`@+6,L("TM8V]M<&5N9&EU
M;3U!4E%5("!);G1E9W)A<B!N;W9A<R!T<F%D=>?U97,@82!E<W1E(&%R<75I
M=F\@9&4@8V]M<.IN9&EO"B`@("`@("`@("`@("`@("`@("`@("`@("!E(&[C
M;R!A;R!C;VUPZFYD:6\@<&]R(&]M:7-SXV\@*&-O;7!E;F1I=6TN<&\@;F$*
M("`@("`@("`@("`@("`@("`@("`@("`@('!A<W1A(&AO<F1E+W!O+@`@("UC
M+"`M+6-O;7!E;F1I=6T]05)152`@57-A<B!E<W1E(&%R<75I=F\@9&4@8V]M
M<.IN9&EO(&5M('9E>B!D;R!A<G%U:79O"B`@("`@("`@("`@("`@("`@("`@
M("`@("!P;W(@;VUI<W/C;R`H8V]M<&5N9&EU;2YP;R!N82!P87-T82!H;W)D
M92]P;RX`("`M9"P@+2UD96)U9R`@("`@("!-;W-T<F%R(&UE;G-A9V5N<R!D
M92!E<G)O(&1O<R!B:6[A<FEO<R!E>&5C=71A9&]S+@`@("UD+"`M+61I<F5C
M=&]R>3U005-402!#<FEA<B!U;2!C;VUPZFYD:6\@;F5S=&$@<&%S=&$N`"`@
M+6@L("TM:&5L<"`@("`@("`@36]S=')A<B!E<W1A(&UE;G-A9V5M(&1E(&%J
M=61A+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-A<B!A<&5N87,@97-T
M82!L;V-A;&EZ8>?C;RX`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S87(@
M97-T82!L;V-A;&EZ8>?C;RX`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-A
M<B!E<W1A(&QO8V%L:7IAY^-O+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@
M0V]N<W1R=6ER(&%R<75I=F]S($U/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO
M"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO
M9'5L93U-TT153$\@("`@3&EM<&%R(&%R<75I=F]S(%!/(&%P96YA<R!P87)A
M(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I
M+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@0V]M971E<B!A<R!T<F%D=>?U
M97,@87!E;F%S('!A<F$@97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@
M("`@("`@("A(;W)D92DN`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#<FEA
M<B!O(&%R<75I=F\@4$\@87!E;F%S('!A<F$@97-T92!M\V1U;&\*("`@("`@
M("`@("`@("`@("`@("`@("`@("A(;W)D92DN`"`@+6TL("TM;6]D=6QE/4W3
M1%5,3R`@("!);G1E9W)A<B!A<G%U:79O<R!03R!A<&5N87,@<&%R82!E<W1E
M(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M
M;2P@+2UM;V1U;&4]3=-$54Q/("`@($%C='5A;&EZ87(@87)Q=6EV;W,@9&4@
M86IU9&$@87!E;F%S('!A<F$@97-T90H@("`@("`@("`@("`@("`@("`@("`@
M("`@;?-D=6QO("A(;W)D92DN`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!!
M8W1U86QI>F%R(&%P96YA<R!E<W1E(&WS9'5L;R`H2&]R9&4I+@`@("UM+"`M
M+6UO9'5L93U-3T153$4@("`@1V5R87(@87)C:&EV;R!03U0@87!E;F%S('!A
M<F$@97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D
M92DN`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!.XV\@:6YT96=R87(@;F]V
M87,@=')A9'7G]65S(&YO(&-O;7#J;F1I;RX`("`M;BP@+2UN;RUC;VUP96YD
M:75M("`@($[C;R!U<V%R('5M(&-O;7#J;F1I;RX`("`M<RP@+2US=&%T:7-T
M:6-S("`@("`@($=U87)D87(@97-T873M<W1I8V%S(&1E('1R861UY^-O(&YU
M;2!F:6-H96ER;R!L;V-A;"X`("`M="P@+2UT97-T("`@("`@("!-;W-T<F%R
M(&]S('!R;V=R86UA<R!A(&5X96-U=&%R(&UA<R!NXV\@;R!F87IE<BX`("!C
M;&5A;G5P("`@("!,:6UP87(@;V8@87)Q=6EV;W,@4$\@9&4@96YT<F%D87,@
M<&]R('1R861U>FER(&]U(&]B<V]L971A<RX`("!C;VUM:70@("`@("!#;VUE
M=&5R(&%S('1R861UY_5E<R!N;R!S97)V:61O<B!#5E,N`"`@8V]M;6ET+6AE
M;'`@0V]M971E<B!A<G%U:79O<R!D92!A:G5D82!N;R!S97)V:61O<B!#5E,N
M`"`@8V]M<&5N9&EU;2`@4F5C;VYS=')U:7(@;R!A<G%U:79O(&1E(&-O;7#J
M;F1I;RX@071E;N?C;SH@3R!N;W9O(&%R<75I=F\*("`@("`@("`@("`@("!S
M;V)R97#U92US92!A;R!A;G1I9V\N`"`@97AT<F%C="`@("`@1V5R87(@87)Q
M=6EV;W,@;6]D96QO(%!/("@N<&]T*2X`("!H96QP("`@("`@("!-;W-T<F%R
M(&5S=&$@;65N<V%G96T@9&4@86IU9&$N`"`@:6YI="`@("`@("`@0W)I87(@
M=6T@;W4@;6%I<R!A<G%U:79O<R!03R!P87)A('5M82!N;W9A(&QO8V%L:7IA
MY^-O+@H@("`@("`@("`@("`@($%T96[GXV\Z($]S(&YO=F]S(&%R<75I=F]S
M('-O<')E</5E;2US92!A;W,@86YT:6=O<RX`("!M86ME("`@("`@("!#;VYS
M=')U:7(@87)Q=6EV;W,@8FENX7)I;W,@34\@82!P87)T:7(@9&]S(&%R<75I
M=F]S"B`@("`@("`@("`@("`@4$\@97-P96-I9FEC861O<RX`("!M86ME+6AE
M;'`@("!-87)C87(@=&]D87,@87,@96YT<F%D87,@;F\@87)Q=6EV;R!834P@
M9&4@86IU9&$@8V]M;R!E<W1A;F1O"B`@("`@("`@("`@("`@86-T=6%L:7IA
M9&%S(&4@<')E<&%R87(@;R!A<G%U:79O('!A<F$@82!P<O-X:6UA(&5X96-U
MY^-O"B`@("`@("`@("`@("`@9&4@=7!D871E+6AE;'`N($1E=F4M<V4@97AE
M8W5T87(@;6%K92UH96QP($1%4$])4R!D90H@("`@("`@("`@("`@('5P9&%T
M92UH96QP(&4@9&4@<F5V97(@;R!A<G%U:79O(&1E(&%J=61A+@`@(&UE<F=E
M("`@("`@($EN=&5G<F%R(&\@87)Q=6EV;R!03R!C;W)R96YT92!C;VT@;R!A
M<G%U:79O(&UO9&5L;R!03R!C;W)R96YT92X`("!U<&1A=&4@("`@("!%>&5C
M=71A<B!E>'1R86-T(&4@;65R9V4@96T@<V5Q=>IN8VEA+@`@('5P9&%T92UH
M96QP($5X=')A:7(@=&]D87,@87,@96YT<F%D87,@;F]V87,@92!M;V1I9FEC
M861A<R!D;R!A<G%U:79O(&1E"B`@("`@("`@("`@("`@86IU9&$@6$U,(&5M
M(&EN9VSJ<R!E(&EN=&5G<N$M;&%S(&-O;2!A<R!E>&ES=&5N=&4N`"`F(S$U
M,3L@)7,@97-TX2!P<F]N=&\@<&%R82!E9F5C='5A<B!A<R!O<&5R8>?U97,@
M9&4@;6%N=71E;N?C;R!M87)C861A<R!A8F%I>&\N`"`H)7,@9&EA<R!A='+A
M<RD`("A#:&%V92!D92!A8V5S<V\@)7,I`"`H9&5N=')O(&1E("5S(&1I87,I
M`"`H:&]J92D`("AA;6%N:.,I`"`H;VYT96TI`"!E`"!C;VT@`"!O=0`B)7,B
M(&[C;R#I('5M82!E<V-O;&AA(';A;&ED82X`(B5S(B!NXV\@97-TX2!C;VYF
M:6=U<F%D;R!N;R!296=I<W1O(&1O($AO<F1E+@`B)7,B(')E<')E<V5N=&%D
M;W(@9&4@X7)V;W)E(&[C;R!E;F-O;G1R861O+@`B)7,B(&9O:2!A9&EC:6]N
M861O(&%O('-I<W1E;6$@9&4@9W)U<&]S+@`B)7,B)R!F;VD@861I8VEO;F%D
M;R!A;R!S:7-T96UA(&1E('!E<FUI<W/U97,N`"(E<R(@;N-O(&9O:2!C<FEA
M9&\Z("5S+@`E9"`E<R!E("5S`"5D(&)Y=&5S(&5S8W)I=&]S`"5D(&1E("5D
M(&5N=')A9&$@;6%R8V%D87,@8V]M;R!A8W1U86QI>F%D87,`<')E=FESXV\@
M9&4@)60@9&EA<P`E<R`M($YO=&EF:6-AY^-O`"5S($%D;6EN:7-T<F'GXV\`
M)7,@26UP<F5S<^-O($1I9VET86P`)7,@2T(`)7,@3W!E<F'G]65S(&1E($UA
M;G5T96[GXV\@+2!#;VYF:7)M8>?C;P!#;VYF:6=U<F%R("5S`"5S(%-U8G-C
M<F5V97(`)7,@5&5R;6]S(&1O($%C;W)D;P`E<R!JX2!E>&ES=&4N`"5S(&5M
M("5S("5S`&[C;R!S92!P;V1E(&5S8W)E=F5R(&5M("5S+@`E<R#I(&]B<FEG
M873S<FEO`"5S(&UI;G5T;W,`)7,@;N-O(&9O:2!E;F-O;G1R861O+@`E<R!N
MXV\@9F]I(&5N8V]N=')A9&\N($5X96-U=&%R("=T<F%N<VQA=&EO;B!E>'1R
M86-T)R!P<FEM96ER;RX`)7,@82`E<R!D92`E<P!#;VYT86-T;W,@9&4@)7,`
M0V%L96YDX7)I;R!D92`E<P!.;W1A<R!D92`E<P!487)E9F%S(&1E("5S`"5S
M.B`E<P`L(&-O;2!R86IA9&%S`"P@8V]M(')A:F%D87,@)7,@)7,`+"!V87)I
MX79E;"!D92`E<R!A("5S`"TM(&5S8V]L:&$@+2T`+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM`$9O<FUA=&\@9&4@,3(@:&]R87,@*$%-+U!-*0!&;W)M
M871O(&1E(#(T(&AO<F%S`#(T(&AO<F%S`#Q!;G1E<FEO<@!E=&EQ=65T82`\
M9V5T=&5X=#X@<&]R(&9E8VAA<B!N;R!F:6-H96ER;R`E<RX*06)R:6YD;R!A
M(&5T:7%U971A(&5N8V]N=')A9&$@;F$@;&EN:&$@)60N`$5S=&4@8FQO8V\@
M97AI9V4@=6T@;65C86YI<VUO('5S86YD;R!B87-E<R!D92!D861O<RX`3V-O
M<G)E=2!U;2!E<G)O(&9A=&%L`,D@;F5C97-SX7)I82!U;6$@8VAA=F4@</IB
M;&EC82!01U`@<&%R82!E;F-R:7!T87(@82!M96YS86=E;2X`R2!N96-E<W/A
M<FEA('5M82!C:&%V92!P^F)L:6-A(%!'4"!P87)A('9E<FEF:6-A<B!A(&%S
M<VEN871U<F$@9&4@=6UA(&UE;G-A9V5M`%!A<F$@9&5C:69R87(@=6UA(&UE
M;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!01U`L
M('5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!F<F%S92UP87-S92X`4&%R
M82!A<W-I;F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H
M879E('#Z8FQI8V$@4$=0+"!U;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@
M9G)A<V4M<&%S<V4N`%!A<F$@9&5C:69R87(@=6UA(&UE;G-A9V5M('/C;R!N
M96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82!C:&%V
M92!P<FEV861A(%,O34E-12!E('5M82!F<F%S92UP87-S92X`4&%R82!A<W-I
M;F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z
M8FQI8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@
M9G)A<V4M<&%S<V4N`,D@;F5C97-SX7)I82!U;6$@8VAA=F4@</IB;&EC82!3
M+TU)344@<&%R82!E;F-R:7!T87(@=6UA(&UE;G-A9V5M+@!.^G9E;G,@9&4@
M;6%N:.,`0VAU=FES8V]S(&1E($UA;FCC`$-H=79A(&1E(&UA;FCC`$%G=6%C
M96ER;W,@9&4@;6%N:.,`3F5V]65S(&1E(&UA;FCC`$%-+U!-`$%022!)1`!!
M8V5R8V$@9&5S=&4@961I=&]R`$%C97)C82XN+@!"87-E<R!A;&EN:&%D87,`
M0V5N=')O<R!A;&EN:&%D;W,`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!P87-T
M82!61E,N`$%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q=6EV;R!61E,N`%!A
M;&%V<F$M4&%S<V4@9&$@0V]N=&$`0V]N=&$@8V]N9V5L861A+@!#;VYT86)I
M;&ED861E`$%CY^-O('!A<F$@96YD97)EYV]S(&YA(&QI<W1A(&YE9W)A.@!!
M8W1I=F%R(")38W)I<'0B`$%D:6-I;VYA<@!!9&EC:6]N87(@1W)U<&\@1FEL
M:&\`061I8VEO;F%R(%!E<FUI<W/C;R!&:6QH80!!8W)E<V-E;G1A<B!!<75I
M.@!!9&1I8VEO;F%R($YO=F\@1W)U<&\`061I8VEO;F%R($YO=F$@4&5R;6ES
M<^-O`$%D:6-I;VYA<B!U;2!G<G5P;R!F:6QH;R!A("(E<R(`061I8VEO;F%R
M('5M82!P97)M:7-SXV\@9FEL:&$@82`B)7,B`$%D:6-I;VYA<B!N;W9O('5T
M:6QI>F%D;W(Z`$%D:6-I;VYA<B!C;VQU;F$`061I8VEO;F%R(&YO=F]S(&UE
M;6)R;W,`061I8VEO;F%R('!A<F-E:7)O`$%D:6-I;VYA<B!O($UE;G4@)7,@
M8V]M;R!"87)R82!,871E<F%L($UO>FEL;&$`061I8VEO;F%R(&%O<R!#;VYT
M86-T;W,Z`$%D:6-I;VYA<B!A;W,@;65U<R!C;VYT86-T;W,`061I8VEO;F%R
M('5T:6QI>F%D;W(`061I8VEO;F5I("(E<R(@86\@<VES=&5M82P@;6%S(&[C
M;R!P=61E(&%D:6-I;VYA<B!I;F9O<FUAY^-O(&1E('-U8G-C<FGGXV\@861I
M8VEO;F%L.B`E<RX`061I8VEO;F5I("(E<R(@86\@<VES=&5M82X@2N$@<&]D
M92!E;G1R87(N`$%D:6-I;VYA;F1O(&YO=F]S(&%R<75I=F]S(&%O(')E<&]S
M:73S<FEO.@!!(&%D:>?C;R!D92!U=&EL:7IA9&]R97,@97-TX2!D97-A8W1I
M=F%D82X`0V]N9FEG=7)AY_5E<R!!9&EC:6]N86ES`$5N9&5R9>=O`$-O;G1A
M8W1O<P!!9&UI;FES=')A<B`M(&%T<FEB=6ER('!E<FUI<W/U97,@82!O=71R
M;W,@=71I;&EZ861O<F5S`$%D;6EN:7-T<F'GXV\`06[Z;F-I;W,`069E9V%N
M:7-TXV\`06QBXFYI80!!<F?I;&EA`$%L8W5N:&$`06QI;FAA<@!!;&EN:&%M
M96YT;SH`5'5D;P!4;V1O<R!O<R!5=&EL:7IA9&]R97,@075T96YT:6-A9&]S
M`%1O9&]S(&]S($=R=7!O<P!4;V1A<R!A<R!097)M:7-S]65S`%1O9&]S(&]S
M("AQ=6%T<F\I(&QA9&]S`%1O9&]S(&]S('-E9W5I;G1E<P!097)M:71I<B!M
M^FQT:7!L;W,@96YD97)EYV]S`%!E<FUI=&ER(&%T<FEB=6GGXV\@9&\@=&EP
M;R!D92!L:7-T87,@;W)D96YA9&%S/P!*X2!E>&ES=&4`16YT<F%D82!)35-0
M($%L=&5R;F%T:79A`%!A;&%V<F$M4&%S<V4@24U34"!!;'1E<FYA=&EV80!.
M;VUE(&1E(%5T:6QI>F%D;W(@24U34"!!;'1E<FYA=&EV;P!%;F1E<F7G;R!I
M;G;A;&ED;P!-;V1E;&]S(&%L=&5R;F%T:79O<P!497AT;R!A;'1E<FYA=&EV
M;SH`4V%M;V$@06UE<FEC86YA`$9O:2!E<W!E8VEF:6-A9&\@=6T@=F%L;W(@
M:6YVX6QI9&\N`$]C;W)R974@=6T@97)R;R!D97-C;VYH96-I9&\N`$%N9&]R
M<F$`06YG;VQA`$%N9W5I;&$`16YT<F5P;W-T;R`H<')O>'DI($%N\VYI;6\`
M4F5S<&]S=&$`4F5S<&]N9&ED;P!!;G3A<F-T:6-O`$%N=.UG=6$@92!"87)B
M=61A`%%U86QQ=65R(&1O<R!S96=U:6YT97,`07!L:6-AY^-O`$%P;&EC8>?C
M;R!P<F]N=&$N`$%P;&EC87(@1FEL=')O<P!!<&QI8V%R(&$@4&%R=&EL:&%S
M($9I;&AA<P!!<')O=F%R`%1A;6%N:&\@07!R;WAI;6%D;P!!8G)I;`!!<N%B
M:6-O("A7:6YD;W=S+3$R-38I`%1A;6%N:&\@9&\@1FEC:&5I<F\@9&4@07)Q
M=6EV;P!.;VUE(&1O($%R<75I=F\`5&5M(&$@8V5R=&5Z82!Q=64@<75E<B!R
M96UO=F5R(&5S=&$@<F5G<F$_`%1E;2!A(&-E<G1E>F$@<75E('%U97(@<F5M
M;W9E<B!O('!E9&ED;R!D92!S=6)S8W)IY^-O('!A<F$@)7,@/P!496T@82!C
M97)T97IA('%U92!Q=65R(')E;6]V97(@(B5S(B!E('%U86ES<75E<B!S=6(M
M9W)U<&]S/P!!<F=E;G1I;F$`07)MZ6YI80!!<FWI;FEO("A!4DU30TE)+3@I
M`$%R=&4`07)U8F$`26QH82!D92!!<V-E;G/C;P!!<G1E($%30TE)`%)E9VGC
M;R#!<VEA+U!A8^UF:6-O`%!E9&ER(&-O;F9I<FUAY^-O(&%N=&5S(&1E(')E
M86QI>F%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O/P!#;VQU;F%S(&1E(&%T
M<FEB=6GGXV\`5&5N=&%T:79A(&1E(')E;6_GXV\@9&4@=6T@9W)U<&\@:6YE
M>&ES=&5N=&4N`%1E;G1A=&EV82!D92!R96UOY^-O(&1E('5M82!P97)M:7-S
MXV\@:6YE>&ES=&5N=&4N`%1E;G1A=&EV82!D92!E9&GGXV\@9&4@=6UA('!E
M<FUI<W/C;R!I;F5X:7-T96YT92X`5&5N=&%T:79A(&1E(&5D:>?C;R!D92!U
M;6$@<&%R=&EL:&$@:6YE>&ES=&5N=&4N`$%T<FEB=71O<P!!9V]S=&\`075S
M='+A;&EA`,%U<W1R:6$`075T:%]C>7)S<6PZ($$@97AT96YSXV\@:6UA<"!N
M96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]C>7)U<SH@3R!M
M96-A;FES;6\@;N-O('1E;2!A<R!C87!A8VED861E<R!N96-E<W/A<FEA<RX`
M075T:%]C>7)U<SH@02!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@;N-O(&9O
M:2!E;F-O;G1R861A+@!!=71H7V9T<#H@02!E>'1E;G/C;R!&5%`@;F5C97-S
MX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N($-O;7!I;&4@;R!02%`@8V]M(&$@
M;W#GXV\@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z($$@97AT96YSXV\@24U!
M4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]K<F(U.B!!
M(&5X=&5N<^-O(&MR8C4@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N
M`$%U=&A?;&1A<#H@02!E>'1E;G/C;R!,1$%0(&YE8V5S<^%R:6$@;N-O(&9O
M:2!E;F-O;G1R861A+@!!=71H7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R
M('5T:6QI>F%D;W(@)7,N($5I<R!O('%U92!O('-E<G9I9&]R(&1I<W-E.B``
M075T:%]L9&%P.B!);7!O<W/M=F5L(')E;6]V97(@;R!U=&EL:7IA9&]R("5S
M`$%U=&A?;&1A<#H@26UP;W-S[79E;"!A8W1U86QI>F%R(&\@=71I;&EZ861O
M<B`E<P!!=71H7VUC86PZ($$@97AT96YSXV\@34-!3"!N96-E<W/A<FEA(&[C
M;R!F;VD@96YC;VYT<F%D82X`075T:%]S;6)A=71H.B!!(&5X=&5N<^-O('-M
M8F%U=&@@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`$$@875T96YT
M:6-AY^-O(&9A;&AO=0!!(&%U=&5N=&EC8>?C;R!F86QH;W4N("5S`$$@875T
M96YT:6-AY^-O(&9O:2!R96IE:71A9&$@<&5L;R!S97)V:61O<B!2041)55,N
M`$$@875T96YT:6-AY^-O(&YO('-E<G9I9&]R($944"!F86QH;W4N`$%C='5A
M;&EZ87(@875T;VUA=&EC86UE;G1E(&\@(G-C<FEP="(@9&5P;VES(&1E(&-A
M9&$@86QT97)AY^-O/P!#86UP;W,@9&ES<&]N[79E:7,Z`$%Z97)B86EJXV\`
M1&5S8W5L<&%S(")"3T9((@!&=6YD;P!#;W(@9&\@1G5N9&\`4&%L879R82U0
M87-S92!K97)B97)O<R!E<G)A9&$N`$YO;64@9&4@571I;&EZ861O<B!K97)B
M97)O<R!E<G)A9&\N`$)A86UA<P!"87+I;0!"X6QT:6-O("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5C:&4`0F%R8F%D;W,`3&EN:&$@8F%S90!#8V\`0V]M9>=A
M(&-O;0!":65L;W)R^G-S:6$`0NEL9VEC80!"96QI>F4`0F5N:6T`0F5R;75D
M80!"=73C;P!!;FEV97)SX7)I;P!,:7-T82!.96=R80!%9&ET87(@3&ES=&$@
M3F5G<F$`02!,:7-T82!.96=R82!NXV\@Z2!S=7!O<G1A9&$@<&5L;R!M96-A
M;FES;6\@9&4@9FEL=')A9V5M(&-O<G)E;G1E+@!%;F1E<F7G;R!N82!,:7-T
M82!.96=R80!%;F1E<F7G;W,@;F$@3&ES=&$@3F5G<F$`3R!B;&]C;R`B)7,B
M(&1A(&%P;&EC8>?C;R`B)7,B(&[C;R!F;VD@96YC;VYT<F%D;RX`0V]N9FEG
M=7)AY_5E<R!D92!";&]C;W,`5&EP;R!D92!";&]C;P!#;W)P;P!.96=R:71O
M`$)O;.UV:6$`36%R8V%D;W)E<P!";W)D80!%<W!E<W-U<F$@9&$@8F]R9&$Z
M`$)O<F1A<P!"\W-N:6$M2&5R>F5G;W9I;F$`06UB87,`0F]T<W5A;F$`0F%S
M90!);&AA($)O=79E=`!"<F%S:6P`5&5R<FET\W)I;R!"<FETXFYI8V\@9&\@
M3V-E86YO(,UN9&EC;P!"<G5N96D@1&%R=7-S86QA;0!#;VYS=')U:6YD;R!A
M<G%U:79O<R!-3R!P87)A(&\@;?-D=6QO("5S+BXN`$-O;G-T<G5I;F1O(&QO
M8V%L:7IAY^-O("5S+BXN(`!"=6QGX7)I80!,:7-T($ET96UI>F%D80!"=7)Q
M=6EN82!&87-O`$)U<OIN9&D`0TU3`$-20P!0;VYT;W,@9&4@1&ES=')I8G5I
MY^-O($-23`!0<F]P<FEE9&%D97,@9&$H<RD@0^E?;'5L82AS*2XN+@!);FEC
M:6%L:7IAY^-O(&1A(")C86-H92(@;N-O(&9O:2!C;VYC;'7M9&$N`$-A;&5N
M9.%R:6\`0V%L;6\`0V%M8F]D:F$`0V%M87+U97,`3N-O('!O<W-O(')E:6YI
M8VEA<B!A('!A;&%V<F$M<&%S<V4@875T;VUA=&EC86UE;G1E+"!C;VYT86-T
M92!O('-E=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S+@!);7!O<W/M=F5L
M(&-O;F5C=&%R(&%O('-E<G9I9&]R($E-05`Z("5S`$-A;F%DX0!#86YC96QA
M<@!#86YC96QA<B!296QA=/-R:6\@9&4@4')O8FQE;6%S`$[C;R!C;VYS:6=O
M(')E;6]V97(@;R!F:6-H96ER;R`B)7,B+@!.XV\@8V]N<VEG;R!E;F-O;G1R
M87(@=6T@9&ER96-T\W)I;R!T96UP;W+A<FEO+@!);7!O<W/M=F5L(&-O;G1I
M;G5A<B!S96T@;R!P87+B;65T<F\@)W1A<F=E=$9I;&4G+@!.XV\@9F]I('!O
M<W/M=F5L(')E;6]V97(@82!P87-T82`B)7,B+@!);7!O<W/M=F5L(')E;6]V
M97(L(&5X:7-T96T@)60@9FEL:&]S+@!.XV\@Z2!P;W-S[79E;"!R96]R9&5N
M87(Z(&\@;OIM97)O(&1E(&5N=')A9&%S(&9O<FYE8VED87,@;N-O(&-O<G)E
M<W!O;F1E(&%O(&[Z;65R;R!G=6%R9&%D;RX`3N-O(&9O:2!P;W-S[79E;"!E
M;F-A;6EN:&%R(&$@;65N<V%G96T@<&%R82!O(&[Z;65R;R!I;F1I8V%D;RX`
M4F5P^F)L:6-A(&1E($-A8F\@5F5R9&4`3&5G96YD80!$:7-C<FEM:6YA($UA
M:?IS8W5L87,@9&4@36EN^G-C=6QA<P!#871E9V]R:6%S(&4@0V]R97,`26QH
M87,@0V%I;>-O`$-C`%1E;&5F;VYE($-E;'5L87(`4')O<')I961A9&5S(&1A
M<R!#Z6QU;&%S`$5N8VAI;65N=&\@9&%S($/I;'5L87,Z`%!R;W!R:65D861E
M<R!D87,@8^EL=6QA<P!%<W!AYV%M96YT;R!D87,@8^EL=6QA<SH`5&5L96WS
M=F5L`$/I;'1I8V\@*$E33RTX.#4Y+3$T*0!#96YT<F%R`%)E</IB;&EC82!#
M96YT<F\@069R:6-A;F$`175R;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I`%!O
M<FUE;F]R97,@9&\@0V5R=&EF:6-A9&\`1&]N;R!D;R!#97)T:69I8V%D;P!0
M;VSM=&EC87,@9&4@0V5R=&EF:6-A9&\`4F5P^F)L:6-A(&1O($-H861E`$%L
M=&5R87(`06QT97)E(&\@;F]M92!E(&5N9&5R9>=O('%U92!A<R!P97-S;V%S
M('9E<N-O('%U86YD;R!L97)E;2!E(')E<W!O;F1E<F5M(.!S('-U87,@;65N
M<V%G96YS+@!!;'1E<F'G]65S(&=U87)D861A<RX`0V%R86-T97)E`%9E<FE?
M9FEC87(@3&EG8>?C;RXN+@!-87)Q=64@87,@;W!E<F'G]65S('%U92!D97-E
M:F$@97AE8W5T87(@;F5S=&4@;6]M96YT;RX`4F5P^F)L:6-A(&1O($-H:6QE
M`%)E</IB;&EC82!0;W!U;&%R(&1A($-H:6YA`$-H:6[J<R!3:6UP;&EF:6-A
M9&]S("A'0C(S,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2D`17-C;VQH
M82!A('!A;&%V<F$M<&%S<V4`17-C;VQH82!U;2!.;VUE(&1E(%5T:6QI>F%D
M;W(`17-C;VQH82!C;VUO(&UO<W1R87(@87,@9&%T87,Z`$5S8V]L:&$@;R!E
M<W1I;&\@9&%S(&QI<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D87,I`$EL:&$@
M9&\@3F%T86P`3N-O(&9O:2!E;F-O;G1R861A(&$@9&5F:6YIY^-O(&1A(&-L
M87-S92`E<RX`3&EM<&%N9&\@;W,@87)Q=6EV;W,@4$\@9&\@;?-D=6QO("5S
M+BXN`$QI;7!A;F1O(&$@;&]C86QI>F'GXV\@)7,N+BX@`$QI;7!A<@!,:6UP
M87(@971I<75E=&%S(&1O($U33V9F:6-E`$QI;7!A<B!D861O<R!D;R!U=&EL
M:7IA9&]R.B`E<P!,:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<@!,:6UP87(@
M9&%D;W,@9&\@=71I;&EZ861O<@!,:6UP82!487)D90!#;&EQ=64@<&%R82!#
M;VYT:6YU87(`0VQI8VMA=&5L;"!V:6$@2%144`!&96-H87(@:F%N96QA`$[Z
M=F5N<P!.^G9E;G,@36%T:6YA:7,`16YE=F]A9&\`26QH87,@0V]C;W,@*$ME
M96QI;F<I`$-O;&%P<V%R($)A<G)A($QA=&5R86P`0F]R9&%S($-O;&%P<V%D
M87,`4F5P^F)L:6-A(&1A($-O;/1M8FEA`$-O<F5S`%!A;&5T90!396QE8^?C
M;R!D92!C;W)E<@!#;VQU;F%S.@!4[71U;&]S(&1A<R!C;VQU;F%S`$)$`$-O
M;6%N9&\`0V]N<V]L82!D92!#;VUA;F1O<P!/<.?U97,@9&\@8V]M86YD;SH`
M0V]M86YD;W,Z`$-O;65N=.%R:6\`0V]M971E;F1O`$YO;64@0V]M=6T`0V]M
M;W)O<P!%;7!R97-A`$5S8W)E=F5R("@E<RD`0V]M<'5T861O<F5S`$-O;F1I
MY^-O`$-O;F1IY_5E<P!$:69E<F5NYV%S(&1E($-O;F9I9W5R8>?C;P!!(&-O
M;F9I9W5R8>?C;R!E<W3A(&1E<V%C='5A;&EZ861A`$-O;F9I9W5R87(@)7,`
M0V]N9FER;64@82!086QA=G)A+5!A<W-E`%)E</IB;&EC82!$96UO8W+A=&EC
M82!D;R!#;VYG;P!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\@0V]N9V\`0V]N
M97CC;R!F86QH;W4N`$-O;F5XXV\@9F%L:&]U.B``0V]N97CC;R!A;R!S97)V
M:61O<B!D92!C:&%V97,@</IB;&EC87,@<F5C=7-A9&$N`$-O;F5XXV\@86\@
M<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S(')E8W5S861A+B!287KC;SH@
M)7,@*"5S*0!#;VYE>.-O(&%O('-E<G9I9&]R($944"!R96-U<V%D82X`0V]N
M=&%C=&]S(&%D:6-I;VYA9&]S(&-O;2!S=6-E<W-O(&%O('-E=2!L:79R;R!D
M92!E;F1E<F7G;W,N`$-O;G3I;0!4:7!O(&1E(&-O;G1E^F1O(&1O(&%R<75I
M=F\@8V]M<')I;6ED;SH@`$-O;G1E^F1O(&1E("5S`$-O;G1I;G5A<@!);&AA
M<R!#;V]K`$)O;&EN:&\@8VAI;NIS`$-O<&EA<@!#;W!I87(@)7,`0_-P:6$@
M9&4@)7,`0V]P:6%R('-E;&5CY^-O`$-O<&EA;F1O(&1E("5S('!A<F$@)7,`
M4F5P^F)L:6-A(&1A($-O<W1A(%)I8V$`4F5P^F)L:6-A(&1A($-O<W1A(&1O
M($UA<F9I;0!.XV\@9F]I('!O<W/M=F5L(&5N8W)I<'1A<B!A(&UE;G-A9V5M
M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M
M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV96P@96YC<FEP87(@82!M96YS86=E
M;2!C;VT@4R]-24U%+@!.XV\@9F]I('!O<W/M=F5L(&%S<VEN87(@82!M96YS
M86=E;2!C;VT@4R]-24U%+@!.XV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA<B!O
M(&-O;G1A8W1O+B`E<P!&86QH82!N82!L:6=AY^-O("AB:6YD*2!A;R!S97)V
M:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L('9E<FEF:6-A<B!O('-A;&1O
M+B`E<P!.XV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R("(E
M<R(@=7-A;F1O($944#H@)7,`3N-O(&9O:2!P;W-S[79E;"!C;W!I87(@)7,@
M<&%R82`E<P!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&QI<W1A(&1E(&1I<W1R
M:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!P87-T82!D92!L
M;V-A;&EZ8>?C;R!P87)A(&$@;&]C86QI>F'GXV\@)7,Z`$[C;R!F;VD@<&]S
M<^UV96P@9&5S96YC<FEP=&%R(&]S(&1A9&]S(&-O;2!O(%!'4"X`3N-O(&9O
M:2!P;W-S[79E;"!D97-E;F-R:7!T87(@;W,@9&%D;W,@8V]M(%,O34E-12X`
M3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&-O;G1A8W1O+B`E<P!.XV\@9F]I
M('!O<W/M=F5L(')E;6]V97(@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.
MXV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R`B<V-R:7!T(B!D92!A8W1U86QI
M>F'GXV\@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&\@96YD
M97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!D;R!D97-T:6YA=.%R:6\N
M`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@;R!L:79R;R!D92!E;F1E<F7G;W,@
M8V]M<&QE=&\N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!L:7-T82!D92!D
M:7-T<FEB=6GGXV\@8V]M<&QE=&$N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@
M82!L:7-T82!C;VUP;&5T82!D87,@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX`
M26UP;W-S[79E;"!C87)R96=A<B!E<W1R873I9VEA("(E<R(N`$EM<&]S<^UV
M96P@;6MD:7(@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&-H879E
M('#Z8FQI8V$@82!P87)T:7(@9&\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI
M8V%S+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER("(E<R(@<&%R82!E<V-R:71A
M+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER("5S+@!.XV\@9F]I('!O<W/M=F5L
M(&%B<FER(&\@;?-D=6QO(&1E($UA;G5T96[GXV\@9&4@5&%R969A<R`E<P!.
MXV\@9F]I('!O<W/M=F5L(&%B<FER('!A<W1A("(E<R(N`$[C;R!F;VD@<&]S
M<^UV96P@;&5R("5S+@!.XV\@9F]I('!O<W/M=F5L(')E:6YI8VEA<B!A('!A
M;&%V<F$M<&%S<V4@9&\@=71I;&EZ861O<B!I;F1I8V%D;RX@06QG=6T@;W4@
M=&]D;W,@;W,@<&]R;65N;W)E<R!NXV\@97-T879A;2!C;W)R96-T;W,N(%!O
M<B!F879O<B!T96YT92!D92!N;W9O(&]U(&-O;G1A8W1E(&\@<V5U(&%D;6EN
M:7-T<F%D;W(@9&4@<VES=&5M87,@<V4@<')E8VES87(@9&4@;6%I<R!A:G5D
M82X`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!!0TP`3N-O(&9O:2!P;W-S[79E
M;"!O8G1E<B!L:79R;R!D92!E;F1E<F7G;W,N("5S`$[C;R!F;VD@<&]S<^UV
M96P@;V)T97(@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O
M<W/M=F5L(&]B=&5R(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@87,@8V]M<&5TZFYC:6%S(&1O('-E<G9I9&]R
M`$[C;R!F;VD@<&]S<^UV96P@<F5V97)T97(@82!C;VYF:6=U<F'GXV\N`$EM
M<&]S<^UV96P@<FUD:7(@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R
M(&$@8V]N9FEG=7)AY^-O(&1E("5S+@!.XV\@9F]I('!O<W/M=F5L(&=U87)D
M87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R9&$N`$[C;R!F;VD@<&]S
M<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R8>?C;R!D92!S86QV86=U87)D83H@
M)7,`3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&\@(G-C<FEP="(@9&4@86-T
M=6%L:7IAY^-O(&5M.B`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&=U87)D87(@
M82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R9&$@)7,N`$[C;R!F;VD@<&]S
M<^UV96P@9W5A<F1A<B!O(&%R<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+B!0
M;V1E('5S87(@=6UA(&1A<R!O<.?U97,@<&%R82!G=6%R9&%R(&\@8_-D:6=O
M(&5M("5S(&]U(&-O<&EA<B!M86YU86QM96YT92!O(&/S9&EG;R!A8F%I>&\@
M<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!P<F]C=7)A<B!N;R!S97)V:61O
M<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L(&1E<VQI9V%R("(E<R(N`$[C;R!F
M;VD@<&]S<^UV96P@86-T=6%L:7IA<B!C;VYT86-T;RX@)7,`3N-O(&9O:2!P
M;W-S[79E;"!A8W1U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E
M<P!.XV\@9F]I('!O<W/M=F5L(&5S8W)E=F5R(&$@8V]N9FEG=7)AY^-O('!A
M<F$@(B5S(CH@)7,`3N-O(&5N8V]N=')E:2!A($)A<G)A($QA=&5R86P@9&\@
M36]Z:6QL82X@07-S96=U<F4M<V4@<75E(&$@8F%R<F$@;&%T97)A;"!E<W3A
M(&%B97)T82X`3N-O(&9O:2!P;W-S[79E;"!A=')I8G5I<B!A;R!U=&EL:7IA
M9&]R("(E<R(@;W,@<V5G=6EN=&5S(&1I<F5I=&]S('-O8G)E(&$@<&%S=&$@
M(B5S(CH@)7,`5&5X=&\@0V]N=&%D;P!08>US`$-U<G-O<P!#<FEA<@!#<FEA
M<B!U;6$@;&EG8>?C;P!#<FEA<B!U;6$@;F]V80!#<FEA<B!N;W9A('!A<W1A
M`$-R:6%R('-U8BUP87-T87,`4&5R;6ES<_5E<R!D;R!#<FEA9&]R`$[Z;65R
M;R!D;R!C87)TXV\@9&4@8W+I9&ET;P!297#Z8FQI8V$@9&$@0W)OX6-I80!2
M97#Z8FQI8V$@9&4@0W5B80!1=6%T<F\@9F%S97,@8V]R<F5N=&5S`$1A=&$O
M2&]R80!54DP@8V]R<F5N=&4@Z0!%<W1A9&\@9&\@5&5M<&\`4VET=6'GXV\@
M86-T=6%L.B``17-T:6QO(&%C='5A;`!097)S;VYA;&EZ87(@87,@=&%R969A
M<R!Q=64@<V5RXV\@97AE8W5T861A<R!A<75A;F1O(&\@;&]G:6X@;F\@)7,N
M`$-O<G1A<@!#;W)T87(@82!S96QE8^?C;P!297#Z8FQI8V$@9&4@0VAI<')E
M`$-I<NUL:6-O("A+3TDX+5(I`$-I<NUL:6-O("A7:6YD;W=S+3$R-38I`$-I
M<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5*0!297#Z8FQI8V$@0VAE8V$`1$0`
M1$5304-4259!1$$`1$5304-4259!1$$Z(`!$:6%R:6%M96YT90!.879E9V%D
M;W(@9&4@P7)V;W)E(&1E($1A9&]S`$1A=&$`1&%T82!D92!296-E<.?C;P!3
M96QE8^?C;R!D92!D871A`$1I80!296UO=F5R($-O7VQU;F$`1&5S86-T:79A
M<B`B4V-R:7!T(@!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E9'5Z:7(@
M:6YD96YT8>?C;P!0;W(@3VUI<W/C;P!#;W(@4&]R($]M:7-SXV\`261E;G1I
M9&%D92!0861RXV\`4&5R;6ES<_5E<R!0;W(@3VUI<W/C;P!097)M:7-S]65S
M('!O<B!O;6ES<^-O`$1E9FEN:>?U97,`4F5M;W9E<@!296UO=F5R("5S`%)E
M;6]V97(@0V]N9&GGXV\`4F5M;W9E<B!'<G5P;P!296UO=F5R(%!E<FUI<W/C
M;P!296UO=F5R(&4@<'5R9V%R(&UE;G-A9V5N<P!296UO=F5R(&/I;'5L80!2
M96UO=F5R(&-O;'5N80!296UO=F5R(&UO9&5L;R!A;'1E<FYA=&EV;R!E>&ES
M=&5N=&4`4F5M;W9E<B!M96YS86=E;2!C;VUP;&5T86UE;G1E`%)E;6]V97(@
M<&5R;6ES<_5E<R!D92`B)7,B`%)E;6]V97(@<&5R;6ES<_5E<R!P87)A("<E
M<R<@92!Q=6%I<W%U97(@<W5B+7!E<FUI<W/U97,_`%)E;6]V97(@;&EN:&$`
M4F5M;W9E<B!I9&5N=&ED861E('-E;&5C8VEO;F%D80!296UO=F5R(&$@8V]L
M=6YA(&-O<G)E;G1E`%)E;6]V97(@82!L:6YH82!C;W)R96YT90!296UO=F5R
M(&5S=&$@<&5R;6ES<^-O(&4@=&]D87,@87,@<W5A<R!S=6(M<&5R;6ES<_5E
M<S\`4F5M;W9I9&$`(E-C<FEP="(@9&4@86-T=6%L:7IAY^-O("(E<R(@<F5M
M;W9I9&\N`$5N=')E9V%R(&YA(&UI;FAA($-A:7AA(&1E($5N=')A9&$`16YT
M<F5G87(@;F$@;6EN:&$@0V%I>&$@9&4@16YT<F%D82!E(&-O<&EA<B!P87)A
M`$5N=')E9V%R(&YA(&UI;FAA($-A:7AA(&1E($5N=')A9&$@92!R961I<F5C
M8VEO;F%R('!A<F$`16YT<F5G87(@;F$@<&%S=&$`36]M96YT;R!D92!E;G1R
M96=A`$1I;F%M87)C80!$97-C<F5V82!O(%!R;V)L96UA`$1E<V-R:>?C;P!0
M;W)M96YO<F5S("AT86UBZ6T@;F\@<F5G:7-T;RP@(FQO9R(L(&1O($AO<F1E
M*3H`3W,@9&5T86QH97,@9F]R86T@96YV:6%D;W,@<&%R82!O(&%D;6EN:7-T
M<F%D;W(@9&\@<VES=&5M82X`1&5S96YV;VQV:6UE;G1O`%!O;G1O(&1E($]R
M=F%L:&\`4&]N=&\@9&4@3W)V86QH;R!N82#Z;'1I;6$@:&]R83H@`%!O;G1O
M(&1E(&]R=F%L:&\Z(`!$:7)E8^?C;R!D82!E<W%U97)D82!P87)A(&$@9&ER
M96ET80!$:7)E8^?C;R!D82!D:7)E:71A('!A<F$@82!E<W%U97)D80!$:7)E
M8W3S<FEO`$1E<V%T:79A<B`E<R``1&5S871I=F%D;P!-;W-T<F%R('1E;7!O
M<R!C;VT@,C0@:&]R87,_`$]PY_5E<R!D92!6:7-U86QI>F'GXV\`36]S=')A
M<B!P<F5V:7/C;R!P;W)M96YO<FEZ861A`$UO<W1R87(@;F]T:69I8V'GXV\@
M<&]R;65N;W)I>F%D82!Q=6%N9&\@8V%D82!F:6QT<F\@9F]R(&%P;&EC861O
M/P!-;W-T<F%R('!R979I<^-O("A4048I`$9O<FUA=&\@9&4@=FES=6%L:7IA
MY^-O`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!?3N-O(&5N
M=FEA<B!R97-P;W-T87,@<&%R82!M96YS86=E;G,@96T@;6%S<V$@;W4@9&4@
M;&ES=&%S(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\`3N-O(')E;6]V97(`3N-O
M('5T:6QI>F4@;R!M86EN=&5N86YC92YP:'`@9&ER96-T86UE;G1E`$9A>F5R
M(&ES=&\Z`$$@<')I;65I<F$@;&EN:&$@8V]N=.EM(&]S(&YO;65S(&1O<R!C
M86UP;W,_(%-E('-I;2P@87-S:6YA;&%R(&5S=&$@8V%I>&$Z`$[C;R!C;VUE
MYV$@8V]M`$[C;R!C;VYTZ6T`3N-O('1E<FUI;F$@8V]M`$[C;R!E>&ES=&4`
M3N-O(&-O<G)E<W!O;F1E(&$@*&-O;2!M87)C8>?U97,I`$1O;6EN:6-A`%)E
M</IB;&EC82!$;VUI;FEC86YA`%)E8V5B97(`4F5C96)E<B`E<P!$97-C87)R
M96=A<B!A(&-O;F9I9W5R8>?C;R!G97)A9&$@8V]M;R!U;2`B<V-R:7!T(B!0
M2%`N`$QI<W1A(&1E(&1E<V5N<F]L87(`1')O9V%S`$-O<G)E:6\@96QE8W1R
M\VYI8V\`15)2`%)E</IB;&EC82!D;R!%<75A9&]R`$5D:71A<@!%9&ET87(@
M)7,`161I=&%R($)L;V-O`$5D:71A<B!'<G5P;P!%9&ET87(@4&5R;6ES<_5E
M<P!%9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@<&5R;6ES<_5E<R!D92`E<P!%
M9&ET87(@;W#G]65S(&1E.@!%9&ET87(@<&5R;6ES<_5E<R!D92`B)7,B`$5D
M:71A<B!P97)M:7-S]65S(&1E("5S`$5D=6-AY^-O`$5G:7!T;P!297#Z8FQI
M8V$@9&4@16P@4V%L=F%D;W(`16QE;65N=&\N+BX`16T`0V]R<F5I;R!%;&5C
M='+S;FEC;P!%;F1E<F7G;R!D92!#;W)R96EO($5L96-T<O-N:6-O`$]S(&5N
M9&5R9>=O<R!TZFT@<75E(&-O:6YC:61I<BX`365N<V%G96T@8V]M(&-O;F9I
M<FUAY^-O`%/M;6)O;&]S(&1E($5M;^?C;P!-96YS86=E;2!V87II82X`4V5M
M(')E<W5L=&%D;W,N`%-E;2!T97)M;W,@9&4@<')O8W5R80!!8W1I=F%R("5S
M`$%C=&EV87(@:6YS97+GXV\@9&4@:6UA9V5N<R!D92!'86QE<FEA<R!&;W1O
M9W+A9FEC87,@;F\@=&5X=&\_`$%C=&EV87(@;65N=2!D92!C;VYT97AT;R!N
M;R!B;W3C;R!D:7)E:71O(&1O(')A=&\_`$%C=&EV861O`$%N;R!D92!F:6T`
M5&5R;6EN82!C;VT`075M96YT87(@161I=&]R`$EN=')O9'5Z82!U;6$@<&5R
M9W5N=&$@9&4@<V5G=7)A;N=A('%U92!S97+A(&-O;G9I9&%D;R!A(')E<W!O
M;F1E<B!S92!P<F5C:7-A<B!D92!R96EN:6-I87(@82!S=6$@<&%L879R82UP
M87-S92P@92YG+BP@)V-O;6\@<V4@8VAA;6$@;R!S974@86YI;6%L(&1E(&5S
M=&EM8>?C;S\G.@!);G1R;V1U>F$@;R!54DP@9&$@:6UA9V5M(&%Q=6D`16YT
M<F%D87,Z("5D('1O=&%L+"`E9"!A8W1U86QI>F%D87,L("5D(&YO=F%S+"`E
M9"!A;'1E<F%D87,L("5D(&1E<V-O;FAE8VED87,`26=U86P@80!'=6ENZ2!%
M<75A=&]R:6%L`$5S=&%D;R!D82!%<FET<F5I80!%<G)O`$5R<F\@86\@9W5A
M<F1A<B!A<R!A;'1E<F'G]65S+@!%<G)O(&YA(&UE;G-A9V5M(&1E(&-O<G)E
M:6\@96QE8W1R\VYI8V\N`$5R<F\@86\@97-C<F5V97(@(B5S(BX`17)R;SH@
M`%)E</IB;&EC82!D82!%<W3S;FEA`%)E</IB;&EC82!$96UO8W+A=&EC82!&
M961E<F%L(&1A($5T:?-P:6$`R71I8V\`175R;W!A`$-A9&$@,34@;6EN=71O
M<P!#861A(#(@;6EN=71O<P!#861A(#,P('-E9W5N9&]S`$-A9&$@-2!M:6YU
M=&]S`$-A9&$@16YT<F%D80!#861A(&UE:6$@:&]R80!#861A(&UI;G5T;P!6
M86QO<F5S(&5X96UP;&\Z`$5X96-U=&%R`$5X96-U=&%N9&\Z`%)E9W)A<R!%
M>&ES=&5N=&5S`$5X:7-T90!%>'!A;F1I<@!-;W-T<F%R($)A<G)A($QA=&5R
M86P`)RDG(&5S<&5R861O`$5S<&5R879A('5M82!S:6UP;&5S('!A;&%V<F$@
M;W4@=6T@=&5R;6\@9&4@<')O8W5R82!E;G1R92!A<W!A<P!$871A(&1E($5X
M<&ER8>?C;P!%>'!O96YT90!%>'1R86EN9&\@9&4@)7,N+BX@`$-O<B!D;R!0
M<FEM96ER;R!0;&%N;P!#87)R96=A<B!C;VYF:6=U<F'GXV\@9&4@:6YS=&%L
M8>?C;R!P;W(@1E10`$[C;R!F;VD@<&]S<^UV96P@<'5X87(@87,@<')E9F5R
MZFYC:6%S+@!&86QH82!N82!L:6=AY^-O(&%O('-E<G9I9&]R($Q$05`N`$9A
M;&AA(&YA(&QI9V'GXV\@86\@<V5R=FED;W(@4TU"+@!&86QH82!A;R!C;W!I
M87(@9&4@(B5S(BX`1F%L:&$@86\@8V]P:6%R('!A<F$@(B5S(BX`1F%L:&$@
M86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!305-,+@!&86QH82!A;R!M;W9E
M<B!P87)A("(E<R(N`$)O;0!);&AA<R!&86QK;&%N9"`H36%L=FEN87,I`$EL
M:&%S($9A<F]E`$5R<F\@1F%T86PZ`$9A>`!&979E<F5I<F\`07!A<F5N=&$`
M07!A<F5N=&$Z(`!!;&=U;G,@06=U86-E:7)O<P!!;&=U;G,@3F5V]65S`$UA
M=')I>B!D92!C86UP;W,`1FEJ:0!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@
M87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,`1V5S
M=.-O(&1E($9I8VAE:7)O<P!.;VUE(&1O($%R<75I=F\`4V5L96/GXV\@9&\@
M87)Q=6EV;P!#87)R96=A;65N=&\@9&4@87)Q=6EV;P!#87)R96=A;65N=&]S
M(&1E(&9I8VAE:7)O<R!NXV\@<^-O('-U<&]R=&%D;W,N`$9I;'1R87(@5&]D
M87,@87,@365N<V%G96YS`$9I;'1R87(@07!E;F%S($UE;G-A9V5N<R!,:61A
M<P!&:6QT<F%R($%P96YA<R!-96YS86=E;G,@4&]R($QE<@!/<.?U97,@9&4@
M1FEL=')A9V5M`%)E9W)A(&1E($9I;'1R86=E;0!296=R87,@9&4@1FEL=')A
M9V5M`%9I<W5A;&EZ8>?C;R!D;R`B4V-R:7!T(B!D92!&:6QT<F%G96T`7U)E
M9W)A<R!D92!&:6QT<F%G96T`06-T:79I9&%D92!D92!F:6QT<F%G96TZ("5S
M(&UE;G-A9V5M*&YS*2!F;VDH<F%M*2!C;W!I861A*',I('!A<F$@82!P87-T
M82`B)7,B+@!!8W1I=FED861E(&1E(&9I;'1R86=E;3H@)7,@;65N<V%G96TH
M;G,I(&9O:2AR86TI(')E;6]V:61A<RAS*2X`06-T:79I9&%D92!D92!F:6QT
M<F%G96TZ("5S(&UE;G-A9V5M*&YS*2!F;VDH<F%M*2!M;W9I9&$H<RD@<&%R
M82!A('!A<W1A("(E<R(N`$%C=&EV:61A9&4@9&4@9FEL=')A9V5M.B`E<R!M
M96YS86=E;2AN<RD@8V]M(&-O<G)E<W!O;F1E;G1E(&YA(&QI<W1A(&YE9W)A
M(&9O:2AR86TI(')E;6]V:61A<RAS*2X`06-T:79I9&%D92!D92!F:6QT<F%G
M96TZ($$@;65N<V%G96T@(B5S(B!D92`B)7,B(&9O:2!C;W!I861A('!A<F$@
M82!P87-T82`B)7,B+@!!8W1I=FED861E(&1E(&9I;'1R86=E;3H@02!M96YS
M86=E;2`B)7,B(&1E("(E<R(@9F]I(')E;6]V:61A+@!!8W1I=FED861E(&1E
M($9I;'1R86=E;3H@02!M96YS86=E;2`B)7,B(&1E("(E<R(@9F]I(&UO=FED
M82!P87)A(&$@<&%S=&$@(B5S(BX`1FEL=')O(&[C;R!E;F-O;G1R861O+@!&
M:6QT<F]S`$9I;FSB;F1I80!1=6%R=&\@0W)E<V-E;G1E`%%U87)T;R!#<F5S
M8V5N=&4`1FEX87(@<N%C:6\`26YV97)T97(`1FQU='5A;G1E`$YE=F]E:7)O
M`$$@<&%S=&$@)7,@;N-O(&5X:7-T92X`0V]R(&1O(%1E>'1O`$-O;6ED80!0
M87)A('5M82!M96YS86=E;2!R96/I;2UC:&5G861A('%U92!C;W)R97-P;VYD
M83H`4&%R82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R=&%M(&EM86=E;G,`
M4')E=FESXV\@*%1!1BD`1&EA<R!D92!0<F5V:7/C;R`H;F]T92US92!Q=64@
M87,@<')E=FES]65S(&EN8VQU96T@=&%N=&\@9&EA<R!C;VUO(&YO:71E<SL@
M=6T@=F%L;W(@9&5M87-I861O(&=R86YD92!P;V1E(')E<W5L=&%R(&YU;2!B
M;&]C;R!M=6ET;R!L87)G;RD`17-Q=65C974M<V4@9&$@<&%L879R82UP87-S
M93\`36]D96QO<P!$:71O<P!4:7!O(&1E(&1I=&]S`$1I=&]S`$1I=&]S(#(`
M1O-R=6YS`%)E9&ER96-I;VYA;65N=&\`3R!R961I<F5C8VEO;F%M96YT;R!N
MXV\@Z2!S=7!O<G1A9&\@<&5L;R!M96-A;FES;6\@9&4@9FEL=')A9V5M(&-O
M<G)E;G1E+@!2961I<F5C8VEO;F%M96YT;W,`161I=&%R(%)E9&ER96-C:6]N
M86UE;G1O<P!!<&QI8V'G]65S("AM\V1U;&]S*2!E;F-O;G1R861A<SH@)7,`
M4&%S=&%S(&5N8V]N=')A9&%S.@`VJ@!-;VQD=7)A<P!297#Z8FQI8V$@1G)A
M;F-E<V$`1G)A;N=A+"!-971R;W!O;&ET86YA`$=U:6%N82!&<F%N8V5S80!0
M;VQI;NES:6$@1G)A;F-E<V$`5&5R<F%S($%U<W1R86ES(&4@06YTX7)C=&EC
M87,@1G)A;F-E<V%S`$1E`$1E(`!$97-C<FGGXV\@0V]M<&QE=&$`3'5A($-H
M96EA`$YO;64@0V]M<&QE=&\`1&EF=7-A<P!297#Z8FQI8V$@1V%B;VYE<V$`
M1V%L97)I82!D92!O;F1E(')E=&ER87(@82!I;6%G96T`1V%L97)I83H`4F5P
M^F)L:6-A(&1A($?B;6)I80!'97)A<B!#;VYF:6=U<F'GXV\@)7,`0_-D:6=O
M($=E<F%D;P!'97)A;F1O(&\@97-T861O(&1O(&WS9'5L;R`E<RXN+@!'9?-R
M9VEA`%)E</IB;&EC82!&961E<F%L(&1A($%L96UA;FAA`$5R<F\@96T@9V5T
M;W!T.@!297#Z8FQI8V$@9&\@1V%N80!':6)R86QT87(`3F]M92!0<O-P<FEO
M`$ER`$?V9&5L`%!E<W%U:7-A($=O;V=L90!.[79E:7,@9&4@8VEN>F5N=&\`
M36%I;W(@<75E`$UA:6]R(&]U(&EG=6%L(&$`1W+I8VEA`$=R96=O("A)4T\M
M.#@U.2TW*0!'<F]N96SB;F1I80!'<F%N861A`$%D;6EN:7-T<F'GXV\@9&4@
M1W)U<&]S`$YO;65S(&1E(&=R=7!O<R!NXV\@<&]D96T@97-T87(@=F%Z:6]S
M`%!E<FUI<W/U97,@9&4@9W)U<&\`1W)U<&]S`$=U861A;'5P90!'=6%M`%)E
M</IB;&EC82!D82!'=6%T96UA;&$`1W5E<FYS97D`4&5R;6ES<_5E<R!D87,@
M5FES:71A<P!097)M:7-S]65S(&1A<R!6:7-I=&%S`$QI=G)O(&1E(%9I<VET
M87,`1W5I;ND`1W5I;NDM0FES<V%U`%)E</IB;&EC82!#;RUO<&5R871I=F$@
M9&$@1W5I86YA`$A434P`3R!(5$U,07)E82!R96-U<V$M<V4@8V]B87)D96UE
M;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!CZ6QU;&$@9&$@;&EN:&$N`$\@2%1-
M3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@82#Z;'1I
M;6$@8V]L=6YA(&1A('1A8F5L82X`3R!(5$U,07)E82!R96-U<V$M<V4@8V]B
M87)D96UE;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!L:6YH82!D82!T86)E;&$N
M`$%U=&5N=&EC8>?C;R!(5%!0(&[C;R!F;VD@96YC;VYT<F%D82X`4F5P^F)L
M:6-A(&1O($AA:71I`$%L9V]R:71M;R!D92`B2&%S:"(`3F5B;&EN80!#86)E
MYV%L:&\`26QH87,@2&5A<F0@92!-8T1O;F%L9`!496UP;W)A;"U4($9O<G1E
M`$AE8G)E=2`H25-/+3@X-3DM."U)*0!!;'1U<F$`06IU9&$`06IU9&$@<V]B
M<F4@;R!E9&ET;W(`06IU9&$`07!L:6-AY^-O(&%U>&EL:6%R('!A<F$@8W)I
M87(@92!M86YT97(@=')A9'7G]65S(&1A('!L871A9F]R;6$*2&]R9&4@92!D
M87,@<W5A<R!A<&QI8V'G]65S("AM\V1U;&]S*2X*4&%R82!U;6$@:6YT<F]D
M=>?C;R!L97(@;R!F:6-H96ER;R!214%$344@;F5S=&$@<&%S=&$N`$AE;6ES
M9NER:6\`07%U:2!E<W3A(&\@:6[M8VEO(&1O(&%R<75I=F\Z`$%L=&$`3F]M
M97,@9&%S(&5N=')A9&%S(&AI<W3S<FEA<R!NXV\@<&]D96T@97-T87(@=F%Z
M:6]S`$-A7W-A`$5S=&%D;R!D82!#:61A9&4@9&\@5F%T:6-A;F\`0V%S80!%
M;F1E<F7G;R!D92!#87-A`%1E;&5F;VYE(&1E($-A<V$`4F5P^F)L:6-A(&1A
M<R!(;VYD=7)A<P!(;VYG=65C;VYG=64`2&]R9&4`1V5R861O<B!D92!T<F%D
M=>?U97,@2&]R9&4`2&]R9&4O2V]L86(Z($1A9&]S(%A-3"`E<R!I;G;A;&ED
M;W,@;F$@;65N<V%G96T@)7,`2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G
M96T@8V]R<F5S<&]N9&4@86\@;V)J96-T;R`E<P!(;W)D92]+;VQA8CH@3F5N
M:'5M(&]B:F5C=&\@9&\@=&EP;R`E<R!E;F-O;G1R861O(&YA(&UE;G-A9V5M
M("5S`$AO<F1E+TMO;&%B.B!296UOY^-O(&1E("5S("(E<R(@=&5V92!S=6-E
M<W-O`$AO<F1E+TMO;&%B.B!3:6YC<F]N:7IAY^-O(&1E("5S("(E<R(@=&5V
M92!S=6-E<W-O`$AO<F1E+TMO;&%B.B!/(&UO=&]R(&1E(&EN=&5G<F'GXV\@
M<F5Q=65R(&$@97AT96YSXV\@4$A0("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!.
MXV\@9F]I('!O<W/M=F5L(&-R:6%R('5M82!N;W9A(.%R=F]R97,@6$U,('!A
M<F$@;R!O8FIE8W1O("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S
M<^UV96P@;V)T97(@;R!)1"!-24U%('!A<F$@82!P87)T92!D92!T:7!O("5S
M`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L('-I;F-R;VYI>F%R("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L('-I;F-R
M;VYI>F%R('!A<G1I;&AA<SH@)7,`2&]R9&4O2V]L86(Z(%!A<G1I;&AA("(E
M<R(@9&5S8V]N:&5C:61A`%1R8>=O($AO<FEZ;VYT86P`16YC:&EM96YT;R!H
M;W)I>F]N=&%L`$AO<FEZ;VYT86PZ`$-O;6\@8VAE9V]U(&%Q=6D_("A0;W(@
M9F%V;W(@<F5P;W)T92UO(2D`475A;G1A<R!C;VQU;F%S('!R971E;F1E(&IU
M;G1A<C\`475A;G1O<R!C86UP;W,@*&-O;'5N87,I(&5X:7-T96T_`%%U86YT
M87,@;&EN:&%S('!R971E;F1E(&IU;G1A<C\`2'5M:61A9&4`2'5M:61A9&4Z
M(`!(=6UO<FES=&%S`%)E</IB;&EC82!D82!(=6YG<FEA`$$@8W)I8>?C;R!D
M82!C86EX82!P;W-T86P@24U!4"!F86QH;W4Z("5S`%)E;6_GXV\@9&$@8V%I
M>&$@<&]S=&%L($E-05`@9F%L:&]U.B`E<P!#<FEAY^-O(&1E('%U;W1A(&1E
M(&-A:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,`16YD97)EYV\@25``16YD
M97)EYV\@25`@:6YD:7-P;V[M=F5L+@!%;F1E<F7G;R!)4"!F;W)A(&1O(&)L
M;V-O($-)1%(@<&5R;6ET:61O+@!6:6]L8>?C;R!D92!B;&]Q=65I;R!D92!)
M4`!)7VYS97)I<B!,:6YH82!!;G1E<P!297#Z8FQI8V$@9&$@27-LXFYD:0!!
M<&5N87,@S6-O;F5S`,UC;VYE<R!C;VT@5&5X=&\`3F]M92!D82!I9&5N=&ED
M861E.@!392!NXV\@9F]R(&UO<W1R861O(&-O<G)E8W1A;65N=&4L("5S('!A
M<F$@;R!A8G)I<B!N=6UA(&YO=F$@:F%N96QA+@!392!NXV\@=FER('%U86QQ
M=65R(.UC;VYE(&%O('5S87(@;R!);G1E<FYE="!%>'!L;W)E<BP@<&]D92!P
M<F5C:7-A<B!D92!S96QE8V-I;VYA<B!E<W1A(&-A:7AA('!A<F$@9&5S;&EG
M87(@82!T<F%N<W!A<NIN8VEA+@!392!V:7(@97-T82!M96YS86=E;2!N;6%S
M(&[C;R!A(&EM86=E;2!P<F]P<FEA;65N=&4@9&ET82P@82!I;6%G96T@<75E
M('!R971E;F1E(&-A<G)E9V%R(&[C;R!P;V1E('-E<B!M;W-T<F%D82!P96QO
M('-E=2!N879E9V%D;W(N`%!R979I<^-O(&1A($EM86=E;3H`55),(&1A(&EM
M86=E;0!54DP@9&$@:6UA9V5M.@!);6%G96T@9&4@9V%L97)I80!);6%G96T@
M9&4@9V%L97)I83H`0V%R<F5G86UE;G1O(&1A(&EM86=E;0!);6%G96YS`$EM
M<&]R=&%R+"!087-S;R`E9`!);7!O<G1A;G1E`$-A;7!O(&EM<&]R=&%D;SH@
M)7,`0V%M<&]S(&EM<&]R=&%D;W,Z`$EN7W-E<FER($QI;FAA($1E<&]I<P!#
M\V1I9V\@9&4@86/GXV\@:6YT<F]D=7II9&\@97-TX2!I;F-O<G)E8W1O+@!.
M;VUE(&1E('5T:6QI>F%D;W(@;W4@<&%L879R82UP87-S92!E<G)A9&]S+@!.
M;VUE(&1E('5T:6QI>F%D;W(@;W4@96YD97)EYV\@86QT97)N871I=F\@97)R
M861O<RX@0V]N=&%C=&4@;R!S974@861M:6YI<W1R861O<B!D92!S:7-T96UA
M('!A<F$@;V)T97(@86IU9&$N`$%U;65N=&%R(&$@26YD96YT8>?C;P!297#Z
M8FQI8V$@9&$@S6YD:6$`571I;&EZ861O<F5S($EN9&EV:61U86ES`%)E9W)A
M<R!I;F1I=FED=6%I<R!NXV\@<^-O('-U<&]R=&%D87,@<&5L;R!M96-A;FES
M;6\@9&4@9FEL=')A9V5M(&-O<G)E;G1E+@!297#Z8FQI8V$@9&$@26YD;V[I
M<VEA`$-A:7AA('!O<W1A;"!E<W!E8VEF:6-A9&$@<&%R82!E;G1R96=A(&[C
M;R!E>&ES=&4N`$EN9F]R;6'GXV\`26YF;W)M8>?C;P!);F9O<FUAY^-O(&KA
M(&[C;R!E<W3A(&1I<W!O;NUV96P`26YI8VEA;&EZ86YD;R!O(&WS9'5L;R`E
M<RXN+B``26YS97)I<B!#7V]L=6YA($1E<&]I<P!);G-E<FER($EM86=E;0!)
M;G-E<FER(%1A8F5L80!);G-E<FER($QI9V'GXV\@X"!796(`26YS97)I<B!?
M0V]L=6YA($%N=&5S`$EN<VER:7(@=6UA(&YO=F$@8V]L=6YA(&1E<&]I<R!D
M82!C;W)R96YT90!);G-I<FER('5M82!N;W9A(&-O;'5N82!A;G1E<R!D82!C
M;W)R96YT90!);G-I<FER('5M82!N;W9A(&QI;FAA(&1E<&]I<R!D82!C;W)R
M96YT90!);G-I<FER('5M82!N;W9A(&QI;FAA(&%N=&5S(&1A(&-O<G)E;G1E
M`$EN<V5R:7(@=6T@<&%RX6=R869O(&%P\W,@;R!N\R!C;W)R96YT90!);G-E
M<FER('5M('!A<N%G<F%F;R!A;G1E<R!D;R!N\R!C;W)R96YT90!);G-I<FER
M(&UO9&5L;R!A;'1E<FYA=&EV;P!);G1R;V1U>F$@=6T@96YD97)EYV\@9&4@
M8V]R<F5I;R!E;&5C='+S;FEC;R!O;F1E('!O<W-A(')E8V5B97(@82!N;W9A
M('!A;&%V<F$M<&%S<V4Z`$EN<VER:7(@8^EL=6QA(&%P\W,`26YS97)I<B!C
MZ6QU;&%S(&%N=&5S`$EN<V5R:7(@8^EL=6QA(&1E<&]I<P!);G-E<FER(&-O
M;'5N82!A;G1E<P!);G-E<FER(&UE;G-A9V5N<P!);G-E<FER('!A<N%G<F%F
M;R!A;G1E<P!);G-E<FER('!A<N%G<F%F;R!A;G1E<P!);G-E<FER(&QI;FAA
M(&1E<&]I<P!);G-E<FER(&QI;FAA(&%N=&5S`$EN=')O9'5Z82!A(')E<W!O
M<W1A(&5X:6=I9&$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R86[G83H`26YS
M97)I<B]-;V1I9FEC87(@26UA9V5M`$EN<V5R:7(O36]D:69I8V%R($QI9V'G
MXV\`0W+I9&ET;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I87(@<&%R82!A(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;RX`0W+I9&ET;R!I;G-U9FEC:65N=&4N`$EN
M=&5I<F\`3&ES=&$@9&4@:6YT96ER;W,`541(("A5<V5R($1A=&$@2&5A9&5R
M*2!I;G;A;&ED;RX`1&%D;W,@6DE0(&EN=N%L:61O<P!!<&QI8V'GXV\@:6YV
MX6QI9&$N`$E$(&1E(&QO=&4@*")B871C:"(I(&EN=N%L:61O+@!/<R!D861O
M<R!S=6)M971I9&]S('/C;R!I;G;A;&ED;W,N`$5N9&5R9>=O(&1E(&1E<W1I
M;F\@:6YVX6QI9&\N`$9O<FUA=&\@9&\@87)Q=6EV;R!I;G;A;&ED;P!#:&%V
M92!D82!L:6-E;N=A(&EN=N%L:61A+@!,;V-A;&EZ8>?C;R!I;G;A;&ED82!E
M<W!E8VEF:6-A9&$N`&US9U]T>7!E(&EN=N%L:61O+@!A<&E?:60@:6YVX6QI
M9&\@;W4@96T@9F%L=&$N`%!A<N)M971R;W,@:6YVX6QI9&]S(&]U(&5M(&9A
M;'1A+@!097)M:7-SXV\@<&%R96YT86P@:6YVX6QI9&$N`$E$(&1E('!A<F-E
M:7)O(&EN=N%L:61O+@!#\V1I9V\@9&4@<')O9'5T;R!I;G;A;&ED;RX`4')O
M=&]C;VQO(&EN=N%L:61O+@!$97-T:6YA=.%R:6\@:6YVX6QI9&\Z("(E<R(`
M3V)J96-T;R!D92!P87)T:6QH82!I;G;A;&ED;P!%;F1E<F7G;R!D82!O<FEG
M96T@:6YVX6QI9&\N`$1A9&]S('5N:6-O9&4@:6YVX6QI9&]S+@!);G9E;G3A
M<FEO`%)E</IB;&EC82!)<VSB;6EC82!D;R!)<N-O`%)E</IB;&EC82!D;R!)
M<F%Q=64`4F5P^F)L:6-A(&1A($ER;&%N9&$`R0!);&AA(&1E($UA;@!.XV\@
MZ0!496UP;W)A:7,M5"!)<V]L861O<P!%<W1A9&\@9&4@27-R865L`$5M:7-S
M;W(`273A;&EC;P!297#Z8FQI8V$@271A;&EA;F$`2F%M86EC80!*86YE:7)O
M`$IA<.-O`$IA<&]NZG,@*$E33RTR,#(R+4I0*0!*97)S97D`4F5I;F\@2&%S
M:&5M:71A(&1A($IO<F3B;FEA`$IU;&AO`$IU;FAO`$IU<W1I9FEC87(`0V5N
M=')A<@!*=7-T:69I8V%R`$IU<W1I9FEC87(@X"!%<W%U97)D80!*=7-T:69I
M8V%R(.`@1&ER96ET80!297#Z8FQI8V$@9&\@0V%Z87%U:7-TXV\`4')E<V5R
M=F%R(&\@;W)I9VEN86P_`%)E</IB;&EC82!D;R!1=>EN:6$`3R!S97)V:61O
M<B!+97)B97)O<R!R96IE:71O=2!A(&%U=&5N=&EC8>?C;RX`3F]V871O<R!N
M;R`B2V5R;F5L(@!#<FEAY^-O(&1A($-H879E`$EM<')E<W/C;R!D:6=I=&%L
M(&1A(&-H879E`$-O;7!R:6UE;G1O(&1A(&-H879E`%1I<&\@9&$@0VAA=F4`
M571I;&EZ8>?C;R!D82!#:&%V90!!(&-H879E(&KA(&5X:7-T92!N;R!S97)V
M:61O<B!D92!C:&%V97,@</IB;&EC87,N`$UI^F1O<P!1=6ER:6)A=&D`4F5P
M^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@9&$@0V]R96EA`%)E</IB;&EC
M82!D82!#;W)E:6$`0V]R96%N;R`H155#+4M2*0!+=7=A:70`4F5P^F)L:6-A
M(%%U:7)G=6EZ90!?1&ES<&]S:>?C;P!)9&EO;6$`4F5P^F)L:6-A(%!O<'5L
M87(@1&5M;V-RX71I8V$@3&%O`%%U87)T;R!$96-R97-C96YT90!1=6%R=&\@
M1&5C<F5S8V5N=&4`VFQT:6UA($%C='5A;&EZ8>?C;SH`VFQT:6UA(&5N=')A
M9&$Z("5S`-IL=&EM82!E;G1R861A.B`E<R!D92`E<P#:;'1I;6$@96YT<F%D
M83H@3G5N8V$`4F5P^F)L:6-A(&1A($QE=/-N:6$`3&5I`$1I<W!O<VGGXV\`
M1&5I>&%R('9A>FEO('!A<F$@9FEC87(@<V5M(&)O<F1A`$SM8F%N;P!%<W%U
M97)D80!#86)EYV%L:&\@9&$@97-Q=65R9&$`5F%L;W)E<R#@(&5S<75E<F1A
M`$QE<V]T;P!-96YO<B!Q=64`365N;W(@;W4@:6=U86P@80!,:6+I<FEA`$=R
M86YD92!*86UA:&ER:7EA(%-O8VEA;&ES=&$@4&]P=6QA<B#!<F%B92!D82!,
M[6)I80!,:7-T96YS=&%I;F4`0VAU=F$@(DUO;&AA+51O;&]S(@!#:'5V:7-C
M;W,`0VAU=FES8V]S($UA=&EN86ES`$-H=79I<V-O<R!697-P97)T:6YO<P!0
M97%U96YO($%G=6%C96ER;P!#:'5V:7-C;R!C;VT@5')O=F]A9&$`475E9&$@
M9&4@3F5V90!.979E`"),:6UE<FEC:R(`3&EG8>?C;P!,:6=AY^-O(&%P;VYT
M82!P87)A.@!,:6=A<B!O(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R\VYI
M8V\@X"!PX6=I;F$@9&4@8V]M<&]S:>?C;R!A;R!M;W-T<F%R`$QI9V'G]65S
M`$)O;&EN:&\@;&EN=7CJ<P!,:7-T82`M(&\@=71I;&EZ861O<B!P;V1E('9E
M<B!A('!A<W1A`$QI<W1A<B!"87-E<R!D92!$861O<P!-;W-T<F%R(%3S<&EC
M;W,@9&4@06IU9&$`3&ES=&%R(%1A8F5L87,`3&ES=&%G96TM07)Q=6EV;P!,
M:7-T86=E;2U!:G5D80!)1"!D82!,:7-T80!)1"!D82!,:7-T80!,:7-T86=E
M;2U$;VYO`$QI<W1A9V5M+5-U8FUI<W/U97,`3&ES=&%G96TM4W5B<V-R:71A
M<P!,:7-T86=E;2U.XV\@<W5B<V-R:71A<P!!(&QI<W1A9V5M(&1E('5T:6QI
M>F%D;W)E<R!E<W3A(&1E<V%C=&EV861A+@!,:71E<F%T=7)A.@!297#Z8FQI
M8V$@9&$@3&ET=>)N:6$`0V%R<F5G86YD;R!B:6)L:6]T96-A<RXN+@!#87)R
M96=A;F1O+BXN`%1E;7!O(&QO8V%L.@!,;V-A;&EZ8>?C;R!E($9U<V\@2&]R
MX7)I;P!,;V-A;&EZ8>?C;P!%;G1R87(`4V%I<@!487)E9F%S(&1E($5N=')A
M9&$`02!A=71E;G1I8V'GXV\@9F%L:&]U('!O<B!O($YO;64@9&4@571I;&EZ
M861O<B!O=2!A(%!A;&%V<F$M4&%S<V4@97-T87)E;2!I;F-O<G)E8W1O<RX`
M02!A=71E;G1I8V'GXV\@9F%L:&]U+@!497AT;R!L;VYG;P!!;6]R`$)A:7AO
M`$QE=')A<R!G<F5G87,@;6EN^G-C=6QA<P!,971R87,@;&%T:6YA<R!M:6[Z
M<V-U;&%S`$[Z;65R;W,@<F]M86YO<R!M:6[Z<V-U;&]S`$QU>&5M8G5R9V\`
M34T`34]41`!/(&%N97AO($U3+51.148@;N-O(&-O;G1I;FAA(&1A9&]S+@!-
M4T<`36%C874`36%C963S;FEA+"!!;G1I9V$@4F5P^F)L:6-A($IU9V]S;&%V
M82!D80!-861A9^%S8V%R`$UA9VEA`$-O<G)E:6\`061M:6YI<W1R8>?C;R!D
M92!#;W)R96EO`$9A>F5R(&QI7V=AY^-O+BXN`$%S<V5G=7)E+7-E(&1E('%U
M92!T96T@;R!014%2(&EN<W1A;&%D;R!E(&YO(&-A;6EN:&\@9&4@:6YC;'5S
M]65S("AI;F-L=61E('!A=&@I+@!#<FEA;F1O(&$@<&%S=&$@)7,`36%L875I
M`$UA;.%S:6$`36%L9&EV87,`36%L:0!-86QT80!':7)A(&$@;&ES=&$@9&4@
M8V%T96=O<FEA<R!Q=64@<&]D92!A=')I8G5I<B!A;W,@:71E;G,L(&)E;2!C
M;VUO(&%S(&-O<F5S('%U92!L:&5S(&5S=.-O(&%S<V]C:6%D87,N`$UA<&$@
M36%P,C0`36%P82!-87!1=65S=`!-87)?8V%R(&UE;G-A9V5M(&-O;6\@<F5M
M;W9I9&$`36%RYV\`36%R9V5M`$UA<F-A<B!M96YS86=E;2!C;VUO.@!-87)C
M87(@8V]M;R!,:61A+T[C;R!L:61A`$UA<F-A<B!D92!O=71R87,@9F]R;6%S
M("AE+F<N+"!);7!O<G1A;G1E+U!O<B!R97-P;VYD97(I`$EL:&%S($UA<G-H
M86QL`$UA<G1I;FEC80!#;W)R97-P;VYD92!A("AC;VT@;6%R8V%D;W)E<RD`
M0V%M<&]S('%U92!C;W)R97-P;VYD96T`36%U<FETXFYI80!-875R[6-I;P!-
MX7AI;6\@8W+I9&ET;R!P97)M:71I9&\N`$WA>&EM;R!N^FUE<F\@9&4@<&%R
M=&5S(&YU;6$@;65N<V%G96T@97AC961I9&\N`%1E;7!E<F%T=7)A(&WA>&EM
M82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E<F%T=7)A(&WA>&EM82!N
M87,@^FQT:6UA<R`V(&AO<F%S.B``0V]M<')I;65N=&\@;>%X:6UO`$5X8V5D
M:61O(&\@;OIM97)O(&WA>&EM;R!D92!E;F1E<F7G;W,@;F$@;&ES=&$@;F5G
M<F$@*%1O=&%L(&1E(&5N9&5R9>=O<SH@)7,L($WA>&EM;R!D92!E;F1E<F7G
M;W,Z("5S*2X@($EM<&]S<^UV96P@861I8VEO;F%R(&YO=F]S(&5N9&5R9>=O
M<R#@(&QI<W1A(&YE9W)A+@!%>&-E9&ED;R!O(&[Z;65R;R!MX7AI;6\@9&4@
M96YD97)EYV]S(&YA(&QI<W1A(&)R86YC82`H5&]T86P@9&4@96YD97)EYV]S
M.B`E<RP@3>%X:6UO(&1E(&5N9&5R9>=O<SH@)7,I+B`@26UP;W-S[79E;"!A
M9&EC:6]N87(@;F]V;W,@96YD97)EYV]S(.`@;&ES=&$@8G)A;F-A+@!-86EO
M`$UA>6]T=&4`365D:6-I;F$`365M8G)O<P!-;V1O(&1O(&UE;G4Z`%5N:7(@
M8^EL=6QA<P!);G1E9W)A;F1O('1O9&]S(&]S(&9I8VAE:7)O<R`E<RYP;R!C
M;VT@;R!C;VUPZFYD:6\N+BX`26YT96=R86YD;R!A(&QO8V%L:7IAY^-O("5S
M+BXN(`!);G1E9W)A;F1O(&\@87)Q=6EV;R!03R!D92`E<R!C;VT@;R!C;VUP
MZFYD:6\N+BX@`$EN=&5G<F%N9&\@82!T<F%D=>?C;R!D;R!M\V1U;&\@)7,N
M+BX`365N<V%G96T`365N<V%G96X@5F5R:69I8V%D82!C;VT@4W5C97-S;RP@
M;6%S(&\@8V5R=&EF:6-A9&\@9&\@<W5B<V-R:71O<B!NXV\@</1D92!S97(@
M=F5R:69I8V%D;RX`365N<V%G96T@97AP:7)O=2X`5&EP;R!D92!M96YS86=E
M;0!-971E;W)O;&]G:6$@345405(`0FQO8V\@345405(@:6YD:7-P;V[M=F5L
M+@!";&]C;R!-151!4B!I;F1I<W!O;NUV96PN($]S('!O<FUE;F]R97,@9F]R
M86T@<F5G:7-T861O<R!P87)A(&\@861M:6YI<W1R861O<BX`02!-971A<D1"
M(&[C;R!E<W3A(&-O;F5C=&%D82X`3>ET;V1O`$\@;>ET;V1O("(E<R(@;N-O
M(&5S=.$@9&5F:6YI9&\`3>ET<FEC;P!-Z7AI8V\`36EC<F]NZ7-I82P@17-T
M861O<R!&961E<F%D;W,@9&$`0V5N=')O`%1I<&\@34E-10!496UP97)A='5R
M82!M[6YI;6$@;F%S(/IL=&EM87,@,C0@:&]R87,`5&5M<&5R871U<F$@;>UN
M:6UA(&YA<R#Z;'1I;6%S(#8@:&]R87,`17-P96QH;P!-:7-C96SB;F5A`%!A
M8V]T92!(5%107U)E<75E<W0@9&\@4$5!4B!E;2!F86QT82X`16YD97)EYV\@
M9&4@<F5D:7)E8V-I;VYA;65N=&\@96T@9F%L=&$`0V]N9FEG=7)AY^-O(&5M
M(&9A;'1A+B!497+A(&1E(&$@9V5R87(@86=O<F$@<V4@<75I<V5R('5S87(@
M97-T82!A<&QI8V'GXV\N`$E$(&1A(&UE;G-A9V5M(&5M(&9A;'1A+@!287KC
M;R!P87)A(')E:F5IY^-O(&5M(&9A;'1A`%)A>N-O('!A<F$@;65N<V%G96T@
M9&4@875SZFYC:6$@96T@9F%L=&$N`%!A8V]T92!-86EL(&1O(%!%05(@96T@
M9F%L=&$N`$E$(&1A('-E<W/C;R!E;2!F86QT82X`,JH`0V]R<F5I;R!-\W9E
M;`!-;V1E<F%D;P!$871A(&1E($UO9&EF:6-AY^-O`$UO9&EF:6-A<B!54DP`
M3?-D=6QO`$WS9'5L;P!297#Z8FQI8V$@9&$@36]L9&]V80!0<FEN8VEP861O
M(&1O($WS;F%C;P!-;VYG\VQI80!-ZG,@92!A;F\`365N<V%L;65N=&4`36]N
M='-E<G)A=`!&87-E(&1A($QU80!296EN;R!D92!-87)R;V-O<P!3;V)R971U
M9&\@3&EM<&\`4V]B<F5T=61O($5N979O861O`%-O8G)E='5D;R!3;VQA<F5N
M9V\`36]V97(`1&5S8V5R`$UO=F5R('!A<F$@82!%<W%U97)D80!-;W9E<B!P
M87)A(&$@1&ER96ET80!-;W9E<B!296=R82!P87)A($)A:7AO`$UO=F5R(%)E
M9W)A('!A<F$@0VEM80!3=6)I<@!$97-C97(`4W5B:7(`4F5P^F)L:6-A(&1E
M($UOYV%M8FEQ=64`3&ES=&%S(&1E(&1E<V5N<F]L87(@;75L=&DM;NUV96P`
M4V5L96/GXV\@;?IL=&EP;&$`02!-:6YH82!#;VYT80!/($UE=2!0;W)T86P`
M1&ES<&]S:>?C;R!D;R!0;W)T86P`56YIXV\@9&4@37EA;FUA<@!.XV\L(&[C
M;R!C;VYC;W)D;P!?3OIM97)O(&1E(&1I87,@96YT<F4@87,@;65N<V%G96YS
M(&1E(&%U<^IN8VEA.@!.;VUE`%)E</IB;&EC82!D82!.86WM8FEA`$YA=7)U
M`$YE<&%L`%)E:6YO(&1O<R!08>US97,@0F%I>&]S`$%N=&EL:&%S($AO;&%N
M9&5S87,`55),(&1E($)A<V4@3F5T<V-A<&4`55),(&1E(%)E=F]G8>?C;R!#
M02!.971S8V%P90!54DP@8V]M(&$@<&]L[71I8V$@9&4@0T$@3F5T<V-A<&4`
M55),(&1E(%)E;F]V8>?C;R!.971S8V%P90!54DP@9&4@4F5V;V=AY^-O($YE
M='-C87!E`$YO;64@9&\@<V5R=FED;W(@4U-,($YE='-C87!E`$-O;65N=.%R
M:6\@9&4@8V5R=&EF:6-A9&\@3F5T<V-A<&4`5&EP;R!D92!C97)T:69I8V%D
M;R!.971S8V%P90!2961E`$YU;F-A`$YO=F$@0V%L963S;FEA`$YO=F$@0V%T
M96=O<FEA`$QU82!.;W9A`$YO=F$@4F5G<F$`3F]V;R!.;VUE(&1E(%5T:6QI
M>F%D;W(@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA`$YO=F$@:F%N96QA("A?
M8FQA;FLI`$YO=.UC:6%S`$=R=7!O<R!D92!.;W3M8VEA<P!0<O-X:6UA`%!R
M\WAI;6%S(#0@1F%S97,`4'+S>&EM87,@;W#G]65S`%!R\WAI;6$^`%)E</IB
M;&EC82!D82!.:6-A<N%G=6$`4F5P^F)L:6-A(&1O($[M9V5R`%)E</IB;&EC
M82!&961E<F%L(&1A($YI9V5R:6$`3F]I=&4`3FEU90!.XV\`3R!E;&5M96YT
M;R`B)7,B(&[C;R!F;VD@96YC;VYT<F%D;R!N82!C;VYF:6=U<F'GXV\@9&4@
M8F%S92X`3N-O(&CA(&1A9&]S(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I
M<R!E;2!R96QAY^-O(&%O<R!Q=6%I<R!M;W-T<F%R(&1I9F5R96[G87,N`$[C
M;R!HX2!N96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(')E86QI
M>F%R(&EM86=E;G,@25-/+@!.XV\@:.$@=6UA(&-O;F9I9W5R8>?C;R!D92!B
M87-E('!A<F$@97-T92!S97)V:61O<@!.96YH=6UA(&-O;F9I9W5R8>?C;R!D
M92!B87-E(&5M(&)A8VME;F1S+G!H<`!.XV\@:.$@;6]D96QO(&1E(&QO=&4@
M(F)A=&-H(BX`3N-O(&5X:7-T92!B;&]C;R!N82!P;W-IY^-O(&EN9&EC861A
M`$[C;R!F;VD@9F]R;F5C:61O('5M(&YO;64@9&4@8V%L96YDX7)I;R!P87)A
M(&$@875T96YT:6-AY^-O($U#04PN`%-E;2!M;V1I9FEC8>?U97,N`$[C;R!S
M92!P;V1E(&%D:6-I;VYA<B!P97)M:7-S]65S(&1E(&9I;&AO<R!A8F%I>&\@
M9&5S=&4@;NUV96PN`$[C;R!S92!P;V1E(&%D:6-I;VYA<B!F:6QH;W,@82!E
M<W1A('!E<FUI<W/C;RX`3F5N:'5M(&-O;6%N9&\@97-P96-I9FEC861O+@!.
MXV\@9F]I(&5S<&5C:69I8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)A
MY^-O('!A<F$@)7,N`$[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C
M;R!D92!C;VYF:6=U<F'GXV\@<&%R82!61E,@8F%S96%D;R!E;2!&5%`N`$[C
M;R!F;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'G
MXV\@;F5C97-SX7)I82!P87)A(&\@5D93(&)A<V5A9&\@96T@4U%,+@!.XV\@
M9F]I(&5S<&5C:69I8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O
M(&YE8V5S<^%R:6$@<&%R82!O(%9&4R!B87-E861O(&5M(%-13"U&:6QE+@!#
M<NED:71O(&5S9V]T;W4N`$YE;FAU;2!D97-T:6YA=.%R:6\@9F]I(&9O<FYE
M8VED;RX`3N-O(&5X:7-T92!Q=6%L<75E<B!E;G1R861A(&-O;2!O(&ED("(E
M<R(@;F\@87)Q=6EV;R!D92!A:G5D82!O<FEG:6YA;"X`3N-O('-E(&-A<G)E
M9V]U(&YA9&$N`$YE;FAU;2!F:6QT<F\N($-L:7%U92!E;2`B)7,B)R!P87)A
M(&-R:6%R('5M(&YO=F\@9FEL=')O+@!.96YH=6T@8V%B9>=A;&AO(&5S<&5C
M:69I8V%D;P!.96YH=6UA(&QO8V%L:7IAY^-O(&5S<&5C:69I8V%D82X`1F%L
M=&$@:6YD:6-A<B!U;6$@;&]C86QI>F'GXV\N`$$@;&]C86QI>F'GXV\@;N-O
M(&9O:2!E<W!E8VEF:6-A9&$N`$YE;FAU;6$@;65N<V%G96T@9F]I(&9O<FYE
M8VED82X`3F5N:'5M(&YO;64@97-P96-I9FEC861O+@!.96YH=6T@;OIM97)O
M(&5S<&5C:69I8V%D;RX`4V5M(&1I=&]S(&]F96YS:79O<P!.XV\@9F]I(&9O
M<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@2%14
M4"X`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T
M96YT:6-AY^-O($E-05`N`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S
M<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!+97)B97)O<RX`3N-O(&9O:2!F;W)N
M96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($Q$05`N
M`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N
M=&EC8>?C;R!,;V=I;BX`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S
M92!P87)A(&$@875T96YT:6-AY^-O(%!!4U-71"X`3N-O(&9O:2!F;W)N96-I
M9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O(%--0BX`3N-O
M(&9O:2!I;F1I8V%D;R!C86UI;FAO('!A<F$@;R!B:6[A<FEO($]P96Y34TPN
M($\@8FENX7)I;R!/<&5N4U-,(.D@;F5C97-SX7)I;R!P87)A('1R86)A;&AA
M<B!C;VT@9&%D;W,@4$M#4R`Q,BX`3N-O(&CA('-U8G-C<FGG]65S('!E;F1E
M;G1E<RX`4V5M('1R8>=O<P!.96YH=6T@(G-C<FEP="(@9V5R861O+@!396T@
M;&%D;W,`3F5N:'5M82!C861E:6$@9&4@8V%R86-T97)E<R!E<W!E8VEF:6-A
M9&$`3N-O(&CA('!A<W1A('1E;7!O<N%R:6$@9&ES<&]N[79E;"!P87)A(")C
M86-H92(N`$[C;R!F;W)A;2!E;G9I861O<R!O(&YO;64@9&\@=71I;&EZ861O
M<B!O=2!A('!A;&%V<F$M<&%S<V4N`$[C;R!F;W)A;2!R971O<FYA9&]S(&1A
M9&]S(&5M(%A-3"!VX6QI9&]S`%-E;2!V86QO<F5S`$[C;R!F;VD@96YC;VYT
M<F%D82!V97)SXV\@;F$@8V]N9FEG=7)AY^-O(&]R:6=I;F%L+B!296=E;F5R
M87(@8V]N9FEG=7)AY^-O+@!.XV\@9F]I(&5N8V]N=')A9&$@=F5R<^-O(&YA
M('-U82!C;VYF:6=U<F'GXV\N(%)E9V5N97)A<B!C;VYF:6=U<F'GXV\N`$YE
M;FAU;6$`3F5N:'5M("AU<V%R(&EM<&SM8VET;RD`3O-R9&EC;R`H25-/+3@X
M-3DM,3`I`$EL:&$@9&4@3F]R9F]L:P!(96UI<V;I<FEO($YO<G1E`$EL:&%S
M($UA<FEA;F%S(&1O($YO<G1E`%)E:6YO(&1A($YO<G5E9V$`3G5N8V$@1&5P
M;VES(&1E`$YU;F-A($%N=&5S(&1E`$[C;R#I('5M(&1I<F5C=/-R:6\`1&EF
M97)E;G1E(&1E`$[C;R!I;7!L96UE;G1A9&$N`%!O<B!A=')I8G5I<@!.XV\@
M<W5P;W)T861O+@!.;W1A<P!.861A('!A<F$@;F%V96=A<BP@=F]L=&4@<&%R
M82!T<N%S+@!.;W1A`$YO=F5M8G)O`$[Z;65R;P!.^FUE<F\@9&4@8V%R86-T
M97)E<P!.^FUE<F\@9&4@8V]L=6YA<P!.^FUE<F\@9&4@;&EN:&%S`$YA(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;R!HX2!N^FUE<F]S('%U92!NXV\@9F]R86T@
M97-P96-I9FEC861O<R!P87)A(&%C='5A;&EZ8>?C;RX`3TL`3V)J96-T;P!#
M<FEA9&]R(&1O($]B:F5C=&\`4&5R;6ES<_5E<R!D;R!C<FEA9&]R(&1O(&]B
M:F5C=&\`3V-T86P`3W5T=6)R;P!&:6QT<F\@9&4@;6%T97)I86P@;V9E;G-I
M=F\`1V%B:6YE=&4`4W5L=&%N871O(&1O($]MXP!3\R!O<R!S97)V:61O<F5S
M($E-05`@<W5P;W)T86T@<&%S=&%S('!A<G1I;&AA9&%S+@!!<&5N87,@9&ET
M;W,@;V9E;G-I=F]S`%/S(.D@<&5R;6ET:61O('5M(&5N9&5R9>=O(&1E(&-O
M<G)E:6\@96QE8W1R\VYI8V\N`$%P96YA<R!O(&1O;F\@;W4@=6T@861M:6YI
M<W1R861O<B!D92!S:7-T96UA<R!P;V1E(&%L=&5R87(@82!T:71U;&%R:61A
M9&4@9&4@=6UA('!A<G1I;&AA(&]U(&%S('!E<FUI<W/U97,@9&\@<V5U(&1O
M;F\`06)R92!N=6UA(&YO=F$@:F%N96QA`$5R<F\@3W!E;E-33#H@3N-O(&9O
M:2!P;W-S[79E;"!E>'1R86ER(&1A9&]S(&1E('5M82!P87)T92!A<W-I;F%D
M82!C;VT@4R]-24U%+@!!8G)E(&5S=&$@;&EG8>?C;R!N=6UA(&YO=F$@:F%N
M96QA`%-I<W1E;6$@3W!E<F%T:79O`$]PY_5E<P!/<.?U97,@<V]B<F4@86-T
M=6%L:7IAY^-O(&1E(")S8W)I<'1S(BX`3W#G]65S(&1O("5S`$]PY_5E<SH`
M3&ES=&$@3W)D96YA9&$`3W)G86YI>F'GXV\`56YI9&%D92!/<F=A;FEZ86-I
M;VYA;`!/<F=A;FEZ8>?C;P!-;V1E;&\@;W)I9VEN86P@9&$@87!L:6-AY^-O
M`$UO9&5L;W,@;W)I9VEN86ES(&5M("5S.@!/=71R;P!/=71R87,@26YF;W)M
M8>?U97,`3W5T<F%S($]PY_5E<P!097)M:7-S]65S(&1O($1O;F\`075T96YT
M:6-AY^-O(%!!32!NXV\@97-TX2!D:7-P;V[M=F5L+@!!<W-I;F%T=7)A($1I
M9VET86P@4$=0`$1A9&]S(&5N8W)I<'1A9&]S(%!'4`!#:&%V92!0^F)L:6-A
M(%!'4`!$861O<R!!<W-I;F%D;W,O16YC<FEP=&%D;W,@8V]M(%!'4`!#\V1I
M9V\@4$A0`$-O;6%N9&]S(%!(4`!#:'5V:7-C;W,@<&5L82!487)D90!!9W5A
M8V5I<F]S(&1E(%1A<F1E`$YE=F4@X"!487)D90!.97;U97,@X"!487)D90!3
M;VP@X"!487)D90!496UP;W)A:7,M5"#@(%1A<F1E`$-O;6%N9&]S(%!?2%``
M16YC:&EM96YT;P!297#Z8FQI8V$@27-LXFUI8V$@9&\@4&%Q=6ES=.-O`%)E
M</IB;&EC82!D92!086QA=0!497)R:73S<FEO(%!A;&5S=&EN:6%N;P!086YA
M;>$`4&%P=6$@3F]V82!'=6ENZ0!297#Z8FQI8V$@9&\@4&%R86=U86D`4&%R
M8VEA;&UE;G1E($5N8V]B97)T;P!086QA=G)A+5!A<W-E`%!A;&%V<F$M4&%S
M<V4@:6YC;W)R96-T80!086QA=G)A+5!A<W-E(&YE8V5S<^%R:6$@<&%R82!A
M=71E;G1I8V'GXV\@4D%$2553`%!A;&%V<F$M4&%S<V4@8V]M(&-O;F9I<FUA
MY^-O`%!A;&%V<F$M4&%S<V4Z`%!A;&%V<F$M4&%S<V4Z(`!!<R!P86QA=G)A
M<RUP87-S92!TZFT@9&4@<V5R(&EG=6%I<RX`0V]L87(`0V]L87(@9&4@<F5C
M;W)T97,`0V%M:6YH;P!3=6)S8W)IY_5E<R!096YD96YT97,Z`%!E<W-O87,`
M4&5R8V5N=&%G96T`17AE8W5T87(@3W!E<F'G]65S(&1E($UA;G5T96[GXV\`
M17AE8W5T87(@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\@87%U86YD;R!D82!E
M;G1R861A/P!097)M:7-SXV\`02!P97)M:7-SXV\@(B5S(B!NXV\@9F]I(')E
M;6]V:61A+@!!9&UI;FES=')AY^-O(&1E(%!E<FUI<W/U97,`4&5R;6ES<_5E
M<R!D90!);F9O<FUAY_5E<R!097-S;V%I<P!097+Z`$%N:6UA:7,@9&4@17-T
M:6UAY^-O`$9I;&EP:6YA<P!496QE9F]N90!&;W1O9W)A9FEA<P!);&AA<R!0
M:71C86ER;@!0[7AE:7,`4&QA=&ET=61E<P!0;W(@9F%V;W(@8VQI<75E('-O
M8G)E('5M82!CZ6QU;&$`4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E86QM96YT
M92!P<F5T96YD92!R96UO=F5R(&5S=&4@96QE;65N=&\Z`%!O<B!F879O<B!C
M;VYF:7)M92!S92!R96%L;65N=&4@<')E=&5N9&4@9&5S;&EG87(@97-T92!E
M;&5M96YT;RX`4&]R(&9A=F]R(&EN=')O9'5Z82!U;2!MZG,@92!U;2!A;F\N
M`%!O<B!F879O<B!I;G1R;V1U>F$@;R!N;VUE(&1A(&YO=F$@8V%T96=O<FEA
M.@!0;W(@9F%V;W(@:6YT<F]D=7IA('5M(&5N9&5R9>=O($E0(';A;&ED;RX`
M4&]R(&9A=F]R(&EN=')O9'5Z82!U;6$@9&%T82!VX6QI9&$[('9E<FEF:7%U
M92!O(&[Z;65R;R!D92!D:6%S(&1O(&WJ<RX`4&]R(&9A=F]R(&EN=')O9'5Z
M82!U;6$@:&]R82!VX6QI9&$N`%!O<B!F879O<B!I;G1R;V1U>F$@;R!N;VUE
M(&1A(&YO=F$@<&%S=&$Z`%!O<B!F879O<BP@9F]R;F7G82!U;6$@8G)E=F4@
M9&5S8W)IY^-O(&1O('!R;V)L96UA+@!0;W(@9F%V;W(L(&EN=')O9'5Z82!O
M('-E=2!.;VUE(&1E(%5T:6QI>F%D;W(@92!A('-U82!086QA=G)A+5!A<W-E
M`%!O<B!F879O<B!L96EA(&\@=&5X=&\@<V5G=6EN=&4N(%1E;2!D92!#3TY#
M3U)$05(@8V]M(&]S('1E<FUO<R!D97-T92!A8V]R9&\@<&%R82!U<V%R(&\@
M<VES=&5M82X`4&]R(&9A=F]R(')E<&]R=&4@;W,@97)R;W,@<&%R82!I,3AN
M0&QI<W1S+FAO<F1E+F]R9P!0;W(@9F%V;W(@:6YT<F]D=7IA(&\@;F]M92!D
M82!N;W9A(&-A=&5G;W)I83H`4&]L\VYI80!0;VSM=&EC80!3;VYD86=E;G,`
M4F5P^F)L:6-A(%!O<G1U9W5E<V$`4&]S:6-I;VYA;65N=&\@9&5S=&$@:6UA
M9V5M`%!O<VEC:6]N86UE;G1O(&1E<W1A('1A8F5L80`B4&]S="(@<&%R82!E
M<W1A('!A<W1A("ANXV\@Z2!R97%U:7-I=&\@9&\@24U!4"D`4')E8VEP:71A
MY^-O(&YA<R#Z;'1I;6%S("5S(&AO<F$H<RDZ(`!0<F]B86)I;&ED861E(&1E
M/&)R("\^4')E8VEP:71AY^-O`%!R969S7VQD87`Z($$@97AT96YSXV\@3$1!
M4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`4')E9G-?<V5S<VEO
M;CH@02!E>'1E;G/C;R!D92!S97-SXV\@;F5C97-SX7)I82!NXV\@9F]I(&5N
M8V]N=')A9&$N`%!R97-SXV\`4')E<W/C;R!A;R!N[79E;"!D;R!M87(Z(`!0
M<F5S<^-O.B``4')E=FESXV\`4')E=F5R(&$@:6UA9V5M(&YU;6$@;F]V82!J
M86YE;&$`3W#G]65S(&%N=&5R:6]R97,`26UP<FEM:7(@;R!D;V-U;65N=&\`
M0VAA=F4@4')I=F%D80!0<F]B;&5M80!$97-C<FGGXV\@9&\@4')O8FQE;6$`
M4')O:F5C=&]S`$UE;G-A9V5M+7!R;VYT;P!#:&%V92!0^F)L:6-A`$%L9V]R
M:71M;R!D92!#:&%V92!0^F)L:6-A`$EN9F]R;6'GXV\@4V]B<F4@82!#:&%V
M90!/('!A<B!D92!C:&%V97,@4'5B;&EC82]0<FEV861A(&[C;R!F;VD@9V5R
M861A(&-O;2!S=6-E<W-O+@!0;W)T;R!2:6-O`$5S=&%D;R!D;R!1871A<@!0
M961I9&\`0VAA=F4@4/IB;&EC82!24T$@*"5D(&)I="D`4E]A>N-O`%-E;&5C
MY^-O(")RX61I;R(`0VAU=F$`0VAU=F$@36%T:6YA;`!#:'5V82!697-P97)T
M:6YA`$%G=6%C96ER;P!#:'5V82!E($YE=F4`0VAU=F$@82!.979E`$1I=&\@
M06QE873S<FEO`%)E;&'GXV\`3&5R`$QE<B!M96YS86=E;G,`475E<B!M97-M
M;R!R96UO=F5R("5S/R!%<W1A(&]P97)AY^-O(&[C;R!T96T@<F5G<F5S<V\N
M`%)E;6]V97(@;65S;6\@;W,@9&%D;W,@9&\@=71I;&EZ861O<B`E<S\@17-T
M82!O<&5R8>?C;R!NXV\@=&5M(')E9W)E<W-O+@!296-E8FED80!2961I<F5C
M:6]N87(@<&%R80!2969A>B!A('-U82#Z;'1I;6$@86/GXV\`4F5F<F5S8V%R
M($5L96UE;G1O<R!D92!-96YU($1I;N)M:6-O.@!2969R97-C87(@5FES=6%L
M:7IAY^-O(&1O(%!O<G1A;#H`17AP<F5S<^-O(%)E9W5L87(`17AP<F5S<^-O
M(')E9W5L87(`4F5J96ET87(@8V]M(')A>N-O`$YA=F5G861O<B!D92!296QA
MY_5E<P!/8G-E<G9AY_5E<P!397)V:61O<F5S(%)E;6]T;W,`55),(%)E;6]T
M;R`H:'1T<#HO+W=W=RYE>&5M<&QO+G!T+VAO<F1E*3H`4F5M;W9E<@!296UO
M=F5R($)L;V-O`%)E;6]V97(@8V]L=6YA`%)E;6]V97(@9F]R;6%T8>?C;P!2
M96UO=F5R('!A<@!296UO=F5R(&\@(G-C<FEP="(@9W5A<F1A9&\@9&$@<&%S
M=&$@=&5M<&]RX7)I82!D;R!S97)V:61O<BX`4F5M;W9E<B!O`%)E;6]V97(@
M97-T92!N\R!D;R!D;V-U;65N=&\`4F5M;W9E<B!5=&EL:7IA9&]R`%)E;6]V
M97(@=71I;&EZ861O<CH@)7,`3N-O(&9O:2!P;W-S[79E;"!R97-P;VYD97(@
M86\@<&5D:61O+B!#\V1I9V\@9&4@97)R;R!D979O;'9I9&\Z(`!/('-E<G9I
MYV\@<&5D:61O(&[C;R!F;VD@96YC;VYT<F%D82X`(B5S(B!O8G)I9V%T\W)I
M;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@9&4@)7,N
M`"(E<R(@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N
M9FEG=7)AY^-O(%9&4RX`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C
M:69I8V%D;R!N82!C;VYF:6=U<F'GXV\N`$-A;7!O($]B<FEG873S<FEO`%)E
M96YV:6%D82!087)A`%)E96YV:6%D82!$90!,:6UP87(`4F5I;FEC:6%R(%!A
M;&%V<F$M4&%S<V4`4F5I;FEC:64@82!3=6$@4&%L879R82U087-S90!297-U
M;'1A9&]S`%)E<W5L=&%D;W,@*&EN8VQU:6YD;R!(;W)D92DZ`%)E<W5L=&%D
M;W,Z`%9O;'1A<B#@($QI<W1A(&1E($9I;'1R;W,`5F]L=&%R(.!S($]PY_5E
M<P!6;VQT87(@X"!,:7-T82!D92!296=R87,`4F5U;FGC;P!2179E<G1E<B!#
M;VYF:6=U<F'GXV\`3W#G]65S(&1E($5D:>?C;R!2:6-A`$%D:79I;FAA<P!$
M:7)E:71A`$-A8F7G86QH;R!D82!D:7)E:71A`%9A;&]R97,@X"!D:7)E:71A
M`%!R;W!R:65D861E<R!D82!,:6Y?:&$N+BX`4F5G<F$`4F]MZ6YI80!2;V1A
M<B`Q.#``4F]D87(@X"!%<W%U97)D80!2;V1A<B#@(&1I<F5I=&$`4')O<')I
M961A9&5S(&1A($QI;FAA`%!R;W!R:65D861E<R!D82!L:6YH80!,:6YH87,Z
M`%)E9W)A`%)E9W)A($-O<&EA9&$`4F5G<F$@4F5M;W9I9&$`4F5G<F$@1&5S
M86-T:79A9&$`4F5G<F$@06-T:79A9&$`3F]M92!D82!296=R80!4<F'G;W,`
M5')AYV]S(&%P87)E8V5RXV\@96YT<F4@=&]D87,@87,@;&EN:&%S(&4@8V]L
M=6YA<P!4<F'G;W,@87!A<F5C97+C;R!A<&5N87,@96YT<F4@87,@8V]L=6YA
M<P!4<F'G;W,@87!A<F5C97+C;R!A<&5N87,@96YT<F4@;&EN:&%S`$5X96-U
M=&%R`$9E9&5R8>?C;R!2=7-S80!297#Z8FQI8V$@9&\@4G5A;F1A`$%S<VEN
M871U<F$@0W)I<'1O9W+A9FEC82!3+TU)344`365N<V%G96T@16YC<FEP=&%D
M82!C;VT@4R]-24U%`$%U=&5N=&EC8>?C;R!305-,(&EN9&ES<&]N[79E;"X`
M365N<V%G96YS(%--4P!#;VUA;F1O<R!344P`4U-(`%-50T534T\`0V]M86YD
M;W,@4U]13`!SX0!386YT82!(96QE;F$`4^-O($MI='1S(&4@3F5V:7,`4V%N
M=&$@3/IC:6$`4^-O(%!E9')O(&4@36EQ=65L;VX`4^-O(%9I8V5N=&4@92!'
M<F5N861I;F5S`$UE<VUA(&UO;&1U<F$@*%]S96QF*0!%<W1A9&\@26YD97!E
M;F1E;G1E(&1A(%-A;6]A`%)E</IB;&EC82!397)E;NUS<VEM82!D92!3XV\@
M36%R:6YO`%/C;R!4;VWI(&4@4'+M;F-I<&4`1F]R;F5C961O<B!D;R!3873I
M;&ET90!!<N%B:6$@4V%U9&ET80!'=6%R9&%R`$=U87)D87(@)7,`1W5A<F1A
M<B`G)7,G`$=U87)D87(@3W#G]65S`$=U87)D87(@0V]N9FEG=7)AY_5E<P!'
M=6%R9&%R(&-O;F9I9W5R8>?C;R!G97)A9&$@8V]M;R!U;2`B<V-R:7!T(B!0
M2%`@;F\@9&ER96-T\W)I;R!T96UP;W+A<FEO(&1O('-E=2!S97)V:61O<BX`
M1W5A<F1E:2!C;VYF:6=U<F'GXV\@)7,N`$=U87)D96D@;R`B<V-R:7!T(B!D
M92!A8W1U86QI>F'GXV\@96TZ("(E<R(N`%1E;7!O<F%I<RU4($1I<W!E<G-O
M<P!#:>IN8VEA`")38W)I<'0B`$%T=6%L:7IAY^-O(&1E(")38W)I<'1S(@`B
M4V-R:7!T<R(@;N-O(&9O:2!A='5A;&EZ861O+@`B4V-R:7!T(B!A8W1I=F%D
M;R!C;VT@<W5C97-S;RX`(E-C<FEP="(@9&5S871I=F%D;R!C;VT@<W5C97-S
M;RX`4')O8W5R87(`36]T;W)E<R!D92!0<F]C=7)A`%!R;V-U<F%N9&\@87!L
M:6-AY_5E<R`H;?-D=6QO<RD@2&]R9&4@96T@)7,`4')O8W5R86YD;R!O<R!B
M:6[A<FEO<R!D92!G971T97AT+BXN`$QI9&\`4V5L96-C:6]N87(@07)Q=6EV
M;W,`4V5L96-C:6]N92!U;6$@9&%T80!396QE8V-I;VYE(&\@8V%M<&\`4V5L
M96-C:6]N92!U;2!G<G5P;R!A(&%C<F5S8V5N=&%R`%-E;&5C8VEO;F%R('5M
M(&YO=F\@9&]N;P!396QE8V-I;VYE('5M('-E<G9I9&]R`%-E;&5C8VEO;F4@
M=6T@=71I;&EZ861O<B!A(&%D:6-I;VYA<@!396QE8V-I;VYE('1O9&]S(&]S
M(&-O;7!O;F5N=&5S(&1A(&1A=&$N`%-E;&5C8VEO;F4@=6T@;V)J96-T;P!3
M96QE8V-I;VYE(&$@<&%S=&$@86QV;P!396QE8V-I;VYE(&]S(&-A<F%C=&5R
M97,@;F%S(&-A:7AA<R!A8F%I>&\N(%!O9&5RX2!E;G3C;R!C;W!IX2UL;W,@
M92!C;VSA+6QO<R!N82#A<F5A(&1E('1E>'1O+@!396QE8V-I;VYE(&\@9&5L
M:6UI=&%D;W(@9&$@9&%T83H`4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@9&%T
M83H`4V5L96-C:6]N92!A(&ED96YT:61A9&4@<75E('!R971E;F1E(&%L=&5R
M87(Z`%-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D87,@:&]R87,Z`%-E;&5C
M8VEO;F4@;R!F;W)M871O(&1A(&AO<F$Z`%-E;&5C8VEO;F4@9&]I<R!C86UP
M;W,@<F5L86-I;VYA9&]S+@!%<V-O;&AA(&\@<V5U(&-O;FIU;G1O(&1E(&-O
M<F5S+@!396QE8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F97)I9&\Z`$-A8F7G
M86QH;R!097)S;VYA;&EZ861O`$5N=FEA<B!296QA=/-R:6\@9&4@4')O8FQE
M;6%S`$5N=FEA<B!335,`4F5M971E;G1E`%)E</IB;&EC82!D;R!396YE9V%L
M`"!396YS;W(Z(`!3971E;6)R;P!3Z7)V:6$@92!-;VYT96YE9W)O`$[Z;65R
M;R!D92!3Z7)I90!$861O<R!D;R!S97)V:61O<B!E<G)A9&]S(&]U(&EN9&ES
M<&]N[79E:7,N`$E$(&1E('-E<W/C;R!E>'!I<F]U+@!!=')I8G5I<@!%<W1A
M8F5L9>=A(&]PY_5E<R!Q=64@;&AE('!E<FUI=&%M(')E:6YI8VEA<B!A('-U
M82!P86QA=G)A+7!A<W-E('-E(&%L9W5M82!V97H@9&5L82!S92!E<W%U96-E
M<BX`17-P96-I9FEC87(@<V5R=FED;W)E<R!R96UO=&]S('%U92!D97-E:F$@
M86-E9&5R(&YO('-E=2!P;W)T86PN`%-E;&5C8VEO;F4@;R!S974@:61I;VUA
M('!R969E<FED;RP@;R!S974@9G5S;R!H;W+A<FEO(&4@87,@<W5A<R!O<.?U
M97,@9&4@9&%T87,N`$5S8V]L:&$@82!S=6$@87!L:6-AY^-O(&EN:6-I86PL
M(&\@97-Q=65M82!D92!C;W)E<RP@;R!R969R97-C86UE;G1O(&1E('#A9VEN
M87,@92!O=71R87,@;W#G]65S(&1E('9I<W5A;&EZ8>?C;RX`0V]N9FEG=7)A
MY_5E<R!A8W1U86QI>F%D87,@8V]M('-U8V5S<V\N`$-O;F9I9W5R87(`(E-C
M<FEP=',B(&1E(&%C='5A;&EZ8>?C;R!D:7-P;V[M=F5I<P!6X7)I87,@;&]C
M86QI>F'G]65S('!O<W/M=F5I<R!C;VT@;R!P87+B;65T<F\Z(`!396EC:&5L
M97,`0V]M<')A<P!"<F5V92!3=6WA<FEO`$1E=F5M+7-E(&1E9FEN:7(@=&5C
M;&%S(&1E(&%C97-S;R!P87)A(&$@;6%I;W)I82!D87,@;&EG8>?U97,_`$UO
M<W1R87(`36]S=')A<B`B4V-R:7!T(B!!8W1I=F\`36]S=')A<B`B4V-R:7!T
M(B!#;W)R96YT90!-;W-T<F%R(&1I9F5R96[G87,@96YT<F4@82!C;VYF:6=U
M<F'GXV\@9W5A<F1A9&$@92!A<75E(&9O:2!A9V]R82!G97)A9&$N`$UO<W1R
M87(@;6]M96YT;R!D82#Z;'1I;6$@96YT<F%D82!N;R!S:7-T96UA/P!-;W-T
M<F%R(&]PY^-O('!A<F$@<')E<V5R=F%R(&\@;W)I9VEN86P`36]S=')A<B!P
M86QE=&4`36]S=')A<B!A(&)A<G)A(&1E(&UE;G4@8V]M(&%S(&]P97)AY_5E
M<R!S;V)R92!T86)E;&%S/P!-;W-T<F%R(&\@365N=2`E<R#@(&5S<75E<F1A
M/P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I961A9&5S
M(&1E($/I;'5L87,@9&4@5&%B96QA/P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA
M;&]G;R!D87,@4')O<')I961A9&5S(&1E(%1A8F5L87,`36]S=')A<B!A(&-A
M:7AA(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!,:6YH87,@9&4@
M5&%B96QA`$UO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE
M9&%D97,@9&4@26UA9V5M`$UO<W1R87(@8V%R<F5G86UE;G1O`$%G=6%C96ER
M;W,`06=U86-E:7)O<R!-871I;F%I<P!!9W5A8V5I<F]S(%9E<W!E<G1I;F]S
M`$%G=6%C96ER;W,@;F$@5FEZ:6YH86[G80!%;F-O;&AE<@!%;F-O;&AA(&]U
M(&UO=F$@;RAS*2!B;&]C;RAS*2!V:7II;FAO*',I('!R:6UE:7)O`%-E<G)A
M($QEXV\`4W5B<V-R979E<@!3=6)S8W)E=F$L('-E(&%I;F1A(&[C;R!E<W3A
M(')E9VES=&%D;P!!<W-I;F%T=7)A`$%L9V]R:71M;R!D92!!<W-I;F%T=7)A
M`%)E</IB;&EC82!D92!3:6YG87!U<F$`5&%M86YH;P!386QT87(@36%N=71E
M;N?C;P!.XV\@<')O8V5S<V%D;RXN+@!%<VQO=N%Q=6EA`%)E</IB;&EC82!D
M82!%<VQO=NEN:6$`3F5V90!.97;C;P!.97;U97,`3F5V]65S($UA=&EN86ES
M`$YE=O5E<R!697-P97)T:6YO<P!!;'1U<F$@9&4@;F5V93H@`$UO<W1R87(@
M97%U:79A;&5N=&4@;F$@X6=U83H@`$EL:&%S(%-A;&]MXV\`4V]MX6QI80!#
M86[G]65S(&4@4&]E;6%S`%-E;&5CY^-O(&1O('-E;G1I9&\@9&$@;W)D96YA
MY^-O`$5N9&5R9>=O(&1E(&]R:6=E;0#!9G)I8V$@9&\@4W5L`$5U<F]P82!D
M;R!3=6P@*$E33RTX.#4Y+3,I`$=E\W)G:6$@9&\@4W5L(&4@26QH87,@4V%N
M9'=I8V@@9&\@4W5L`$AE;6ES9NER:6\@4W5L`$5S<&'G;R!E;G1R92!CZ6QU
M;&%S(&%D:F%C96YT97,`17-P8>=O(&5N=')E(&\@8V]N=&7Z9&\@92!A(&)O
M<F1A(&1E('5M82!CZ6QU;&$`17-P8>=A9&]R`$5S<&'G86UE;G1O`$5S<&'G
M86UE;G1O(&4@96YC:&EM96YT;P!296EN;R!D92!%<W!A;FAA`$-O<G)E:6\@
M;N-O('-O;&EC:71A9&\`26YS97)I<B!#87)A8W1E<B!%<W!E8VEA;`!$:79I
M9&ER(&/I;'5L80!!9&EC:6]N87(@8V]L=6YA`$1I=FED:7(@;&EN:&$`1&5S
M<&]R=&]S`%)E</IB;&EC82!$96UO8W+A=&EC82!3;V-I86QI<W1A(&1O(%-R
M:2!,86YK80!0861RXV\`4W1A<B!4<F5K`$%N;R!D92!I;NUC:6\`17-T861O
M(&]U(%!R;W;M;F-I80!3=&%T=7,`17-T861O(&1A(&QO8V%L:7IAY^-O("5S
M+BXN(`!087)A<B!A('9E<FEF:6-AY^-O('%U86YD;R!E<W1A(')E9W)A(&9O
M<B!E>&5C=71A9&$_`$9O<FUA=&\@9&4@87)M87IE;F%M96YT;P!%;F1E<F7G
M;R!D92!2=6$`4F%S=7)A9&\`3&ES=&$@9&4@8V%D96EA<R!D92!C87)A8W1E
M<F5S`%)E=&ER87(@9&]M[6YI;R!D;R!E;F1E<F7G;P!%<W1I;&\@6T-34UT`
M9&\`05]S<W5N=&\@9&$@;65N<V%G96T@9&4@875SZFYC:6$Z`$%S<W5N=&\`
M4W5B;65T97(`1F]I('-U8FUE=&ED;R!P961I9&\@<&%R82!A9&EC:6]N87(@
M(B5S(B!A;R!S:7-T96UA+B!.XV\@<&]D97+A(&5N=')A<B!E;G%U86YT;R!O
M('-E=2!P961I9&\@;N-O(&9O<B!A<')O=F%D;RX`26YF97)I;W(@X"!L:6YH
M80!3=6-E<W-O`"(E<R(@861I8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S:7-T
M96UA+@!,:6UP97IA(&1O('-I<W1E;6$@9&]S(&1A9&]S(&1O('5T:6QI>F%D
M;W(@(B5S(B!R96%L:7IA9&$@8V]M('-U8V5S<V\N`%)E;6_GXV\@9&4@(B5S
M(B!C;VT@<W5C97-S;RX`4F5M;^?C;R!D92`B)7,B(&1O('-I<W1E;6$@8V]M
M('-U8V5S<V\N`$-O;F9I9W5R8>?C;R!R979E<G1I9&$@8V]M('-U8V5S<V\N
M(%)E8V%R<F5G=64@<&%R82!V97(@87,@;75D86[G87,N`$-O;F9I9W5R8>?C
M;R!D92!S86QV86=U87)D82!G=6%R9&%D82!C;VT@<W5C97-S;RX`1FEC:&5I
M<F\@9&4@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A("5S(&=U87)D861O
M(&-O;2!S=6-E<W-O+@`B)7,B(&%C='5A;&EZ861O(&-O;2!S=6-E<W-O`"5S
M(&5S8W)I=&\@8V]M('-U8V5S<V\`4F5P^F)L:6-A(&1O(%-U9.-O`%)E<W5M
M;P!.87-C97(@9&\@4V]L`%#T<B!D;R!3;VP`4V]L87)E;F=O`$YA<V-E<B!D
M;R!3;VP`3F%S8V5R+U#T<B!D;R!3;VP`3F%S8V5R(&1O(%-O;#H@`%#T<B!D
M;R!3;VP`4/1R(&1O(%-O;#H@`%-U<&5R:6]R(.`@;&EN:&$`4W5P;W)T90!3
M=7)I;F%M90!!<&5L:61O`%-V86QB87)D(&4@2F%N($UA>65N`%)E:6YO(&1A
M(%-U87II;.)N9&EA`%)E:6YO(&1A(%-UZ6-I80!3=>WG80!%<G)O(&1E('-I
M;G1A>&4@;F]S('1E<FUO<R!D92!P<F]C=7)A`%)E</IB;&EC82#!<F%B92!3
M[7)I80!496UP;W)A;"U4`%1E;7!O<F%L+50@92!696YT;W-O`%1E;7!O<F%I
M<RU4`%1E;7!O<F%I<RU4($UA=&EN86ES`$%R<75I=F\@5%-6`%1A8F5L80!0
M<F]P<FEE9&%D97,@9&$@5&%B96QA`%!R;W!R:65D861E<R!D82!T86)E;&$`
M1F]R;6]S80!&;W)M;W-A`%)E</IB;&EC82!D;R!4861J:7%U:7-TXV\`5&%N
M>N)N:6$`06QV;SH`5&%R969A<P!.^FUE<F\@9&4@5&5L969O;F4`5&5M<&5R
M871U<F$@9&$@^FQT:6UA(&AO<F$Z`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A
M.B``5&5M<&5R871U<F$\8G(@+SXH)7-!;'1A)7,O)7-"86EX825S*2`F9&5G
M.R5S`$\@;6]D96QO("(E<R(@;N-O(&9O:2!E;F-O;G1R861O+@!!9&UI;FES
M=')AY^-O(&1E($UO9&5L;W,`5&5X=&\`07!E;F%S(%1E>'1O`$%L:6YH86UE
M;G1O(&1O('1E>'1O`%1O<&\@9&\@=&5X=&\`-:H`5&%I;&%N9.IS("A425,M
M-C(P*0!296EN;R!D82!486ELXFYD:6$`3V)R:6=A9&\@<&]R('5S87(@97-T
M92!S:7-T96UA+@!/(&%R<75I=F\@9&4@86IU9&$@)7,@<&%R82`E<R!NXV\@
M97AI<W1E(&%I;F1A+B!#<FEA;F1O('5M(&YO=F\N`$$@97AT96YSXV\@1E10
M(&[C;R!E<W3A(&1I<W!O;NUV96PN`$\@96YG96YH;R!D92!I;G1E9W)AY^-O
M($AO<F1E+TMO;&%B(&[C;R!S=7!O<G1A("(E<R(`3R!R96=I<W1O("@B;&]G
M(BD@24U34"!NXV\@</1D92!S97(@:6YI8VEA;&EZ861O+@!!(&-L87-S92!-
M86EN=&5N86YC93HZ(&[C;R!F;VD@8V%R<F5G861A(&-O;2!S=6-E<W-O`$$@
M:F%N96QA(&1E($]PY_5E<R!F96-H;W4N(%-A[6YD;RX`3R!A9&UI;FES=')A
M9&]R('1E;2!D92!C;VYF:6=U<F%R('5M(&UE8V%N:7-M;R!D92!P97)M:7-S
M]65S('!E<FUA;F5N=&4@<V4@<75I<V5R('5S87(@4&5R;6ES<_5E<RX`07!E
M;F%S(&\@;&%D;R!I;F9E<FEO<@!/(&[Z;65R;R!D92!)1"!D;R!C;VYT86-T
M;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@9F]I(&1E:7AA9&\@96T@8G)A;F-O
M(&]U(&[C;R!F;VD@96YC;VYT<F%D;R!N82!B87-E(&1E(&1A9&]S+@!/(&-O
M;G1A8W1O(&9O:2!A9&EC:6]N861O(.`@;&ES=&$@9&4@8V]N=&%C=&]S(&-O
M;2!S=6-E<W-O+@!/(&)L;V-O(&1E(&%S<VEN871U<F$@4$=0(&1E<W1A8V%D
M;R#I(&YE8V5S<^%R:6\@<&%R82!V97)I9FEC87(@=6UA(&UE;G-A9V5M(&%S
M<VEN861A+@!/($E$(&1A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I
M(&5S<&5C:69I8V%D;RP@9F]I(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F
M;VD@96YC;VYT<F%D;R!N82!B87-E(&1E(&1A9&]S+@!!(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82X`3R!M96-A;FES;6\@
M9&ES<V4Z(`!!<R!F=6YC:6]N86QI9&%D97,@9&4@96YC<FEP=&'GXV\@97AI
M9V5M('5M82!L:6=AY^-O('-E9W5R82X`3R!A<G%U:79O("5S(&1E=F5R:6$@
M8V]N=&5R('5M(&%T<FEB=71O("5S+@!/(&%R<75I=F\@)7,@9&5V97)I82!C
M;VYT97(@86QG=6YS(&%T<FEB=71O<R`E<RX`3R!F:6-H96ER;R!NXV\@<&]D
M92!S97(@8V]P:6%D;R!P87)A('-I('!R\W!R:6\N`$\@9FEC:&5I<F\@;N-O
M(&-O;G3I;2!D861O<RX`06)A:7AO(&5S=.-O(&]S(&-A8F7G86QH;W,@9&5S
M=&$@;65N<V%G96TO;65N<V%G96T@<F9C.#(R+@!/(&UO9&\@9&4@96-RXR!I
M;G1E:7)O(&-A=7-A('!R;V)L96UA<R!N;R!);G1E<FYE="!%>'!L;W)E<BP@
M9&5V:61O(&$@97)R;W,@;F\@;F%V96=A9&]R('%U92!NXV\@8V]N<V5G=6EM
M;W,@=6QT<F%P87-S87(N("!0;V1E('-U<F=I<B!L:7AO+"!P;V1E;2!D97-A
M<&%R96-E<B!F=6YC:6]N86QI9&%D97,@9&\@961I=&]R(&4O;W4@;R!S974@
M;F%V96=A9&]R('!O9&4@86)O<G1A<BX@4V4@;R!S974@<VES=&5M82#I('5M
M(%=I;F1O=W,@.7@L(.D@;75I=&\@<')O=N%V96P@<75E(&]B=&5N:&$@=6T@
M)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@92!P<F5C:7-E(&1E(')E:6YI
M8VEA<B!O('-I<W1E;6$N7&Y<;D9O:2!A=FES861O+B`@4&]R(&9A=F]R('!R
M97-S:6]N92!/2R!S92!A:6YD82!A<W-I;2!Q=6ES97(@97AP97)I;65N=&%R
M(&\@961I=&]R(&1E(&5C<N,@:6YT96ER;RX`3R!F:6-H96ER;R!D92!A:G5D
M82`E<R!NXV\@8V]M9>=A(&-O;2`\/WAM;`!!(&ED96YT:61A9&4@(B5S(B!F
M;VD@<F5M;W9I9&$N`$%P96YA<R!O(&QA9&\@97-Q=65R9&\`02!L;V-A;&EZ
M8>?C;R!D;R!A<G%U:79O(&5X96-U=.%V96P@9&4@1VYU4$<@=&5M(&1E('-E
M<B!I;F1I8V%D82#@(&-L87-S92!#<GEP=%]P9W`Z.BX`02!M96YS86=E;2!E
M;G9I861A(&5M("5S('!A<F$@)7,@8V]M(&%S<W5N=&\@(B5S(B!F;VD@;6]S
M=')A9&$N"D[C;R!HX2!G87)A;G1I82!D92!Q=64@82!M96YS86=E;2!T96YH
M82!S:61O(')E86QM96YT92!L:61A(&]U(&-O;7!R965N9&ED82X`3R!N;VUE
M(&$@=7-A<B!Q=6%N9&\@;&EG86YD;R#@('#A9VEN82!D92!C;VUP;W-IY^-O
M`$\@;?-D=6QO(&]P96YS<VP@Z2!N96-E<W/A<FEO('!A<F$@82!C;&%S<V4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.BX`02!O<.?C;R`B)7,B(&[C;R!P]&1E('-E
M<B!G=6%R9&%D82P@<&]I<R!O<R!S975S(&1A9&]S(&5X8V5D96T@82!D:6UE
M;G/C;R!MX7AI;6$@<&5R;6ET:61A`$\@<')O9W)A;6$@=7-A9&\@<&%R82!V
M97(@97-T92!T:7!O(&1E(&1A9&]S("@E<RD@;N-O(&9O:2!E;F-O;G1R861O
M(&YO('-I<W1E;6$N`$%P96YA<R!O<R!L861O<R!E<W%U97)D;R!E(&1I<F5I
M=&\`07!E;F%S(&\@;&%D;R!D:7)E:71O`$\@<V5R=FED;W(@(B5S(B!F;VD@
M<F5M;W9I9&\N`$\@<V5R=FED;W(@(B5S(B!F;VD@9W5A<F1A9&\N`$\@<&5D
M:61O(&1E('-U8G-C<FGGXV\@9&4@)7,@9F]I(')E;6]V:61O+@!!(&QI;FAA
M(&EN9&EC861A(&[C;R!E>&ES=&4N`$\@87)Q=6EV;R!T96UP;W+A<FEO("(E
M<R(@;N-O(&5X:7-T92X`07!E;F%S(&]S(&QA9&]S('-U<&5R:6]R(&4@:6YF
M97)I;W(`07!E;F%S(&\@;&%D;R!S=7!E<FEO<@!/<R!D861O<R!C87)R96=A
M9&]S('!E<F1E<F%M+7-E(&1E<V1E(&\@<&%S<V\@86YT97)I;W(N`$\@87)Q
M=6EV;R!C87)R96=A9&\@;N-O('#T9&4@<V5R(&=U87)D861O+@!/(&)L;V-O
M('=E871H97(N8V]M(&[C;R!E<W3A(&1I<W!O;NUV96PN`$[C;R!HX2!O<.?U
M97,@9&ES<&]N[79E:7,N`$[C;R!HX2!P87)T97,@<75E('!O<W-A;2!S97(@
M;6]S=')A9&%S(&5M(&QI;FAA+@!(X2!D96UA<VEA9&]S(&-A<F%C=&5R97,@
M;F5S=&4@8V%M<&\N($EN=')O9'5Z:74@)7,@8V%R86-T97)E<SL@=&5M(&1E
M(&EN=')O9'5Z:7(@;65N;W,@9&\@<75E("5S+@!.XV\@97AI<W1E(&%I;F1A
M('5M(&%R<75I=F\@9&4@86IU9&$@<&%R82`E<RX`3V-O<G)E=2!U;2!P<F]B
M;&5M82!N82!A9&GGXV\@9&4@(B5S(B!A;R!S:7-T96UA.B`E<P!/8V]R<F5U
M('5M('!R;V)L96UA(&%O(&QI;7!A<B!O<R!D861O<R!D;R!U=&EL:7IA9&]R
M("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B;&5M82!N82!R96UO
MY^-O(&1E("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B;&5M82!A
M;R!A8W1U86QI>F%R("(E<R(Z("5S+@!(;W5V92!U;2!P<F]B;&5M82!C;VT@
M;R!C87)R96=A;65N=&\@9&\@9FEC:&5I<F\Z("5S(&[C;R!F;VD@8V%R<F5G
M861O+@!/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M96YT;R!D
M;R!A<G%U:79O.B!/("5S(&5X8V5D92!O('1A;6%N:&\@;>%X:6UO('!E<FUI
M=&ED;R`H)60@8GET97,I+@!/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A
M<G)E9V%M96YT;R!D;R!A<G%U:79O.B!/("5S(&9O:2!A<&5N87,@<&%R8VEA
M;&UE;G1E(&-A<G)E9V%D;RX`3V-O<G)E=2!U;2!E<G)O(&%O(&%C=&EV87(@
M;R`B<V-R:7!T(BX`3V-O<G)E=2!U;2!E<G)O(&%O(&1E<V%T:79A<B!O(")S
M8W)I<'0B+@!/8V]R<F5U('5M(&5R<F\@86\@;6]S=')A<B!E<W1A('!A<G1E
M(&1A(&UE;G-A9V5M`$]C;W)R974@=6T@97)R;R!A;R!I;7!O<G1A<B!D861O
M<R!D92!C;VYT86-T;RX`3V-O<G)E=2!U;2!E<G)O(&%O(&EM<&]R=&%R(&1A
M9&]S(&E#86QE;F1A<BX`3V-O<G)E=2!U;2!E<G)O(&YO(&9O<FUU;.%R:6\@
M9&4@8V]N9FEG=7)AY^-O+B!486QV97H@=&5N:&$@;VUI=&ED;R!U;2!C86UP
M;R!O8G)I9V%T\W)I;RX`3V-O<G)E=2!U;2!E<G)O(&%O(&%B<FER(&\@87)Q
M=6EV;R`E<RX@17AP97)I;65N=&4@97AE8W5T87(@=')A;G-L871I;VXN<&AP
M(&-O;2!A(&]PY^-O("UD('!A<F$@8V]N<V5G=6ER('9E<B!A<R!M96YS86=E
M;G,@9&4@97)R;R!D;R!A;F%L:7-A9&]R(%A-3"X`3V-O<G)E=2!U;2!E<G)O
M(&%O(')E86QI>F%R(&$@9G5NY^-O(&1E(&QI=G)O(&1E(&5N9&5R9>=O<R!E
M<W!E8VEF:6-A9&$N(%!O<B!F879O<B!T96YT92!D92!N;W9O(&UA:7,@=&%R
M9&4N`$]C;W)R974@=6T@97)R;R!A;R!A8W1U86QI>F%R(&]S('!O<FUE;F]R
M97,@9&\@8V]N=&%C=&\N(%!O<B!F879O<B!T96YT92!D92!N;W9O(&UA:7,@
M=&%R9&4N`$]C;W)R974@=6T@97)R;R!A;R!A8W1U86QI>F%R(&$@;&ES=&$@
M9&4@9&ES=')I8G5IY^-O+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!M86ES
M('1A<F1E+@!%<W1E('-E<G9I9&]R($E-05`@;N-O('-U<&]R=&$@<&%R=&EL
M:&$@9&4@<&%S=&%S+@!.XV\@<&%R96-E('-E<B!U;2!A<G%U:79O(')A<B!V
MX6QI9&\N`$[C;R!P87)E8V4@<V5R('5M(&%R<75I=F\@>FEP(';A;&ED;RX`
M3N-O('!A<F5C92!S97(@=6UA(&[Z;65R;R!D92!C87)TXV\@=N%L:61O+@!%
M<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@
M871R87;I<R!D;R!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI
M+"!U<V%N9&\@82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@
M;R!E;G9I;R!D92!M96YS86=E;G,@871R87;I<R!D;R!S;7,R;6%I;"`H:'1T
M<#HO+W-M<S)E;6%I;"YC;VTI+"!U<V%N9&\@82!!4$D@2%144`!%<W1E(&-O
M;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@=FEA(%--
M5%`@871R87;I<R!D82!6;V1A9F]N92!)=.%L:6$@92!A<&5N87,@<&%R82!N
M^FUE<F]S(%9O9&%F;VYE+B!%>&EG92!U;6$@8V]N=&$@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;R!N82!6;V1A9F]N92!)=.%L:6$@*&AT='`Z+R]W=W<N,3DP
M+FET*2X`17-T92!C86UP;R#I(&]B<FEG873S<FEO+@!%<W1E(&-A;7!O('!O
M9&4@8V]N=&5R(&%P96YA<R!I;G1E:7)O<RX`17-T92!C86UP;R!P;V1E(&%P
M96YA<R!C;VYT97(@;OIM97)O<R!E(&\@<^UM8F]L;R!D;VES+7!O;G1O<RX`
M17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O8W1A:7,N
M`$5S=&4@8V%M<&\@=&5M(&1E(&-O;G1E<B!U;6$@;&ES=&$@9&4@:6YT96ER
M;W,@<V5P87)A9&]S('!O<B!E<W!AYV]S(&]U(';M<F=U;&%S+@!%<W1E(&-A
M;7!O('1E;2!D92!S97(@=6T@;OIM97)O(';A;&ED;RX`17-T92!C86UP;R!T
M96T@9&4@8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@;F\@9F]R;6%T;R!21T(@
M:&5X861E8VEM86PL('!O<B!E>&5M<&QO("<C,3(S-&%F)RX`17-T92!M;V1E
M;&\@:N$@9F]I('!R;V-E<W-A9&\N`$ES=&\@Z2`E<RX`17-T92#I('5M(&]B
M:F5C=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!E<W1E(&]B:F5C=&\@
M<')E8VES82!D92!U;2!C;&EE;G1E(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@
M<75E(&-O;FAEYV$@;R!F;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R82!U
M;6$@;&ES=&$@9&4@8VQI96YT97,@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!N
M97-S87,@8VER8W5N<W3B;F-I87,@=FES:71E("5S`$5S=&$@;65N<V%G96T@
M9F]I(&5S8W)I=&$@;G5M(&/S9&EG;R`H)7,I(&1I9F5R96YT92!D;R!S974N
M`$5S=&4@;OIM97)O('!R96-I<V$@9&4@<V5R('!E;&\@;65N;W,@=6TN`$5S
M=&4@(G-C<FEP="(@=&5M('-E<B!E>&5C=71A9&\@82!P87)T:7(@9&4@=6UA
M(&QI;FAA(&1E(&-O;6%N9&]S+@!%<W1E('-E<G9I9&]R(&[C;R!C;VYS96=U
M92!D97-C;VUP<FEM:7(@87)Q=6EV;W,@>FEP(&]U(&=Z:7`N`$5S=&4@<VES
M=&5M82!E;F-O;G1R82US92!D97-A8W1I=F%D;RX`17-T82!V86QO<B!T96T@
M9&4@<V5R('5M(&[Z;65R;RX`17-T82!J86YE;&$@=&5M(&1E('-E<B!C:&%M
M861A(&$@<&%R=&ER(&1E('5M82!J86YE;&$@9&4@3W#G]65S`%1R;W9O861A
M`$)I;&AE=&5S`$1A=&$O2&]R80!396=U:6UE;G1O(%1E;7!O<F%L`$9O<FUA
M=&\@9&\@=&5M<&\`4V5L96/GXV\@9&%T82]H;W)A`%1I;6]R+4QE<W1E`%3M
M='5L;P!4[71U;&\@*&1I8V$I.@!087)A`%!A<F$@<V5L96-C:6]N87(@;?IL
M=&EP;&]S(&ET96YS+"!C87)R96=U92!E;2!#;VYT<F]L("A00RD@;W4@0V]M
M;6%N9"`H36%C*2!E;G%U86YT;R!C;&EC87(N`$AO:F4`5')O8V%R($9O;G1E
M($A434P`4F5P^F)L:6-A(%1O9V]L97-A`%1O<75E;&%U`$%M86YHXP!296EN
M;R!D;R!4;VYG80!4;W!O`$UO;&1U<F$@9&4@=&]P;R`H7W1O<"D`5')A9'5Z
M:61A<P!4<F%D=>?U97,`5')I;F1A9&4@92!4;V)A9V\`5F5R9&%D96ER;R!O
M=2!F86QS;P`SJ@!297#Z8FQI8V$@9&$@5'5N[7-I80!297#Z8FQI8V$@9&$@
M5'5R<75I80!4=7)C;R`H25-/+3@X-3DM.2D`5'5R<75E;65N:7-TXV\`26QH
M87,@5'5R8V%S(&4@0V%I8V]S`%1U=F%L=0!%<V-R979A(&$@<W5A(&5S8V]L
M:&$Z`,UN9&EC92!5+E8N.B``55),`%523"!D;R!S974@<F5L873S<FEO(&1E
M(&5S=&%D;R!D;R!E;G9I;R!D92`B<V-R:7!T<R(`55),.@!297#Z8FQI8V$@
M9&\@56=A;F1A`%5C<N)N:6$`3N-O(&9O:2!P;W-S[79E;"!A8V5D97(@X"!P
M87-T82!61E,N`$[C;R!F;VD@<&]S<^UV96P@861I8VEO;F%R(&EN9F]R;6'G
MXV\@9&4@=71I;&EZ861O<B!E>'1R82!A<75A;F1O(&1A('-U8G-C<FGGXV\N
M`$[C;R!F;VD@<&]S<^UV96P@;75D87(@87,@<&5R;6ES<_5E<R!D;R!A<G%U
M:79O(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&UU9&%R(&%S('!E<FUI
M<W/U97,@9&\@87)Q=6EV;R!61E,@)7,O)7,N`$[C;R!F;VD@<&]S<^UV96P@
M;75D87(@<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!L:6=A<B!A;R!S97)V
M:61O<B!344PN`$[C;R!F;VD@<&]S<^UV96P@;&EG87(@=7-A;F1O(%-33"X`
M3N-O(&9O:2!P;W-S[79E;"!C;W!I87(@;R!A<G%U:79O(%9&4RX`3N-O(&9O
M:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4R`B)7,B+@!.XV\@9F]I('!O
M<W/M=F5L(&-R:6%R(&$@<&%S=&$@5D93+@!.XV\@9F]I('!O<W/M=F5L(&-R
M:6%R(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@=6T@
M87)Q=6EV;R!61E,@=F%Z:6\N`$[C;R!F;VD@<&]S<^UV96P@9&5S8V]M<')I
M;6ER(&]S(&1A9&]S+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@(B5S(BP@
M<&]I<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA+@!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@(B5S(CH@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B`E
M<RP@<&]I<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA`$[C;R!F;VD@<&]S<^UV
M96P@<F5M;W9E<B!A('!A<W1A(%9&4R!R96-U<G-I=F%M96YT92X`3N-O(&9O
M:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@5D93+@!.XV\@9F]I('!O<W/M
M=F5L(')E;6]V97(@82!P87-T82!61E,Z("5S+@!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@;R!A<G%U:79O(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!R96UO
M=F5R(')E8W5R<VEV86UE;G1E.B`E<RX`3N-O(&9O:2!P;W-S[79E;"!D971E
M<FUI;F%R(&$@<&%S=&$@8V]R<F5N=&4N`$[C;R!F;VD@<&]S<^UV96P@97AT
M<F%I<B!O<R!P;W)M96YO<F5S(&1O(&-E<G1I9FEC861O`$EM<&]S<^UV96P@
M86-T=6%L:7IA<B!A(&1E9FEN:>?C;R!D92`E<RX`3N-O(&9O:2!P;W-S[79E
M;"!M;W9E<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER
M(&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O
M(&%R<75I=F\@5D93('!A<F$@97-C<FET82X`3N-O(&9O:2!P;W-S[79E;"!A
M8G)I<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@
M87)Q=6EV;R!C;VUP<FEM:61O+@!.XV\@8V]N<VEG;R!L97(@;R!A<G%U:79O
M.B``3N-O(&9O:2!P;W-S[79E;"!L97(@82!P87-T82!V9G-R;V]T+@!.XV\@
M9F]I('!O<W/M=F5L(')E;F]M96%R("5S(&-O;6\@)7,Z(&$@<&%S=&$@9&4@
M9&5S=&EN;R!JX2!E>&ES=&4`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A
M('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A('!A<W1A
M(%9&4SH@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@;R!A<G%U:79O
M(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&\@87)Q=6EV
M;R!61E,@)7,O)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV
M;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G+@!.
MXV\@9F]I('!O<W/M=F5L(&-O;G9E<G1E<B!E<W1E(&1O8W5M96YT;R!7;W)D
M`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@87)Q=6EV;R!61E,@(B5S(BX`
M3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!O(&%R<75I=F\@5D93("AC;W!Y
M*"D@9F%L:&]U*2X`3N-O(&-O;G-I9V\@<F5M;W9E<B`G)7,G.B`E<RX`4W5B
M;&EN:&%D;P!$97-F87IE<B!!;'1E<F'G]65S`$1E<V9A>B!A('-U82#Z;'1I
M;6$@86/GXV\`4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!N82!C
M;VYE>.-O.B``4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!A.B``
M4V5M(&-A=&5G;W)I80!5;FEC;V1E("A55$8M."D`16UI<F%D;W,@P7)A8F5S
M(%5N:61O<P!296EN;R!5;FED;P!%<W1A9&]S(%5N:61O<R!D82!!;>ER:6-A
M`$EL:&%S($UE;F]R97,@1&ES=&%N=&5S(&1O<R!%<W1A9&]S(%5N:61O<P!5
M;FED861E<P!$97-C;VYH96-I9&\`87!I;7-G:60@*$E$(&1E($UE;G-A9V5M
M(&1E($%022DN`&-L:6US9VED(&1E<V-O;FAE8VED;R`H240@9&4@365N<V%G
M96T@9&4@0VQI96YT92DN`$-O;6%N9&\@9&5S8V]N:&5C:61O.B`E<P!&;VD@
M9F]R;F5C:61A('5M82!L;V-A;&EZ8>?C;R!D97-C;VYH96-I9&$N`$YO;64@
M9&4@=71I;&EZ861O<B!O=2!P86QA=G)A+7!A<W-E(&5R<F%D;W,`4F5M;W9E
M<B!L:6=AY^-O(&1O(&5L96UE;G1O(&-O<G)E;G1E`%-E;2!N;VUE`%!O<B!R
M87KU97,@9&4@<V5G=7)A;N=A+"`B<V-R:7!T<R(@<V5M('!R:79I;.EG:6\@
M;N-O('!O9&5M(&%C961E<B!A($-O<G1A<B]#;W!I87(O0V]L87(@<')O9W)A
M;6%T:6-A;65N=&4N($-A<G)E9W5E(&5M($]+('!A<F$@=F5R('5M82!N;W1A
M('3I8VYI8V$@96T@;6]Z:6QL82YO<F<@<75E(&QH92!M;W-T<F%RX2!C;VUO
M(&%U=&]R:7IA<B!U;2`B<V-R:7!T(B!A(&%C961E<B!A;W,@<F5C;W)T97,N
M`%)E;6]V97(@8V]L;W)AY^-O`$5X=&5N<^-O(&[C;R!3=7!O<G1A9&$`4&]R
M('1R861U>FER`$UO9&EF:6-A<@!!8W1U86QI>F%R("5S`$%C='5A;&EZ87(@
M=71I;&EZ861O<@`B)7,B(&%C='5A;&EZ861O+@!!8W1U86QI>F%N9&\@87)Q
M=6EV;R!D92!A:G5D82`E<R!P87)A("5S+@`B4V-R:7!T(B!D92!A8W1U86QI
M>F'GXV\@<F5M;W9I9&\N`%5P;&]A9`!#87)R96=A9&]S(&YO('-E<G9I9&]R
M('1O9&]S(&]S(&%R<75I=F]S(&1E(&EN<W1A;&'GXV\@9&4@87!L:6-AY_5E
M<RX`3&5T<F%S(&QA=&EN87,@96T@;6%I^G-C=6QA<P!.^FUE<F]S(')O;6%N
M;W,@96T@;6%I^G-C=6QA<P!297#Z8FQI8V$@3W)I96YT86P@9&\@57)U9W5A
M:0!5=&EL:7IAY^-O.@!5<V%R(&\@0V]R<F5N=&4Z("5S`%5S87(@4U-,+@!5
M<V%R('-E(&\@;F]M92!D92!U=&EL:7IA9&]R(&]U(&$@<&%L879R82UP87-S
M92!F;W)E;2!D:69E<F5N=&5S(&YO('-E<G9I9&]R($E-4U`N`%5T:6QI>F%D
M;W(@)7,@;N-O(&5S=.$@875T;W)I<V%D;R!P87)A("5S+@!!9&UI;FES=')A
MY^-O(&1E(%5T:6QI>F%D;W)E<P!/<.?U97,@9&\@571I;&EZ861O<@!296=I
M<W1O(&1E(%5T:6QI>F%D;W)E<P!/(%)E9VES=&\@9&4@571I;&EZ861O<F5S
M(&5S=.$@:6YA8W1I=F\N`%!E<FUI<W/U97,@9&\@=71I;&EZ861O<@!.;VUE
M(&1E(%5T:6QI>F%D;W(`3R!.;VUE(&1E(%5T:6QI>F%D;W(@(B5S(B!JX2!E
M>&ES=&4N`$YO;64@9&4@571I;&EZ861O<CH`3F]M92!D92!5=&EL:7IA9&]R
M.B``571I;&EZ861O<F5S`%5T:6QI>F%D;W)E<R!D;R!S:7-T96UA.@!297#Z
M8FQI8V$@9&\@57IB97%U:7-TXV\`02!P87-T82!61E,@;N-O(&5X:7-T92X`
M365N<V%G96YS(&1E($%U<^IN8VEA`$5D:71A<B!-96YS86=E;G,@9&4@075S
MZFYC:6$`365N<V%G96T@9&4@075SZFYC:6$`365N<V%G96YS(&1E(&%U<^IN
M8VEA(&[C;R!SXV\@<W5P;W)T861A<R!P96QO(&UE8V%N:7-M;R!D92!F:6QT
M<F%G96T@8V]R<F5N=&4N`$%S(&QO8V%L:7IAY_5E<R!VX6QI9&%S(&5N8V]N
M=')A9&%S(&EN8VQU96TZ`%9A;&ED861E+@!686QO<B!E;2!M:6YU=&]S(&$@
M<&%R=&ER(&1E<W1E(&EN<W1A;G1E+@!686QO<B!E>&-E9&4@;R!C;VUP<FEM
M96YT;R!MX7AI;6\@9&4@)7,N`%9A;&]R97,`4&]S<^UV96P@=F%L;W)E<R!A
M(&5S8V]L:&5R`%9A;G5A='4`5F%R:>%V96P`5F5N97IU96QA`%9E<FEF:6-A
MY^-O(&9A;&AO=2`M(&5S=&$@;65N<V%G96T@<&]D92!T97(@<VED;R!A9'5L
M=&5R861A+@!697)SXV\`0V]N=')O;&\@9&4@5F5R<_5E<P!!;&EN:&%M96YT
M;R!697)T:6-A;`!#86SG;R!697)T:6-A;`!697)T:6-A;#H`375I=&\@06QT
M;P!297#Z8FQI8V$@4V]C:6%L:7-T82!D;R!6:65T;F%M90!6:65T;F%M:71A
M("A625-#24DI`%9I<W5A;&EZ87(@)7,`5F5R('5M82!PX6=I;F$@97AT97)N
M80!6:7-U86QI>F%R(&-O;6\@)7,`26QH87,@5FER9V5N<R!"<FETXFYI8V%S
M`$EL:&%S(%9I<F=E;G,@06UE<FEC86YA<P!6:7-I8FEL:61A9&4`5FES:6)I
M;&ED861E.B``5F]D869O;F4@273A;&EA('9I82!33510`$%625,`051%3L?#
M3R$A(2!214U/5D$@3R`B4T-225!4(B!-04Y504Q-14Y412!$12`E<RX`5V%L
M;&ES(&4@1G5T=6YA`$%V:7-O`$%V:7-O.B``-*H`4')E=FESXV\@9&\@5&5M
M<&\`1&%D;W,@;65T96]R;VSS9VEC;W,@9F]R;F5C:61O<R!P;W(`5V5A=&AE
M<BYC;VT`5V5B`%#A9VEN80!396UA;F%L;65N=&4`0F5M+79I;F1A*&\I`$)E
M;2UV:6YD82AO*2!A("5S`$)E;2UV:6YD82AO*2P@)7,`3V-I9&5N=&%L("A)
M4T\M.#@U.2TQ*0!/8VED96YT86P@*$E33RTX.#4Y+3$U*0!386%R80!%;F1E
M<F7G;W,@;F$@3&ES=&$@7T)R86YC83H`475E(&%P;&EC8>?C;R!D979E(&\@
M)7,@;6]S=')A<B!A</-S(&$@96YT<F%D83\`475A;"#I(&\@8V%R86-T97)E
M(&1E;&EM:71A9&]R/P!1=6%L(.D@;R!C87)A8W1E<F4@9&4@8VET8>?C;S\`
M475E(&9A<V5S`%%U92`B<&QU9VEN<R(@86-T:79A<B!P87)A(&$@161IY^-O
M(%)I8V$N`$QI<W1A($)R86YC80!%9&ET87(@3&ES=&$@0G)A;F-A`$QI<W1A
M($)R86YC82!NXV\@Z2!S=7!P;W)T861A('!E;&\@;65C86YI<VUO(&1E(&9I
M;'1R86=E;2!C;W)R96YT92X`16YD97)EYV]S(&YA($QI<W1A($)R86YC80!,
M87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D97,@0U-3`$QA<F=U<F$@9&\@365N
M=2`E<R#@(&5S<75E<F1A("AT96T@969E:71O(&YA('!R\WAI;6$@96YT<F%D
M82DZ`$QA<F=U<F$@9&$@=&%B96QA`%5N:61A9&4@9&4@;&%R9W5R80!,87)G
M=7)A.@!7:6MI`%9E;G1O`%9E;G1O($UA=&EN86P`5F5L;V-I9&%D92!D;R!V
M96YT;R!E;2!N\W,`5F5N=&\Z`%9E;G1O.B``4V%B961O<FEA`$QI<W1A<R!D
M92!$97-E:F]S`%1R86)A;&AO`$5N9&5R9>=O("A%;7!R96=O*0!496QE9F]N
M92`H16UP<F5G;RD`17-C<F5V96YD;R!A<G%U:79O(&1E(&%J=61A(&%C='5A
M;&EZ861O('!A<F$@)7,N`%@M4')I;W)I9&%D90!2969E<NIN8VEA<R!C<G5Z
M861A<P!8+4[M=F5L+61E+5-P86T`6"U#;&%S<VEF:6-AY^-O+61E+5-P86T`
M6"U%<W1A9&\M9&4M4W!A;0!297-T<FGG]65S($+A<VEC87,@6#4P.78S`%5T
M:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U,#EV,P!.;VUE($%L=&5R
M;F%T:79O(&1E(%-U:F5I=&\@6#4P.78S`$ED96YT:69I8V%D;W(@0VAA=F4@
M9&4@4W5J96ET;R!8-3`Y=C,`17AT96YS]65S(%@U,#EV,P!!00!!04%!`$UA
M<&$@66%H;V\A`$%N=6%L;65N=&4`2>EM96X`4VEM`%-I;2P@0V]N8V]R9&\`
M17-TX2!E;2!-3T1/(&1E(%1%6%0N("!5<V4@;R!B;W3C;R!;/#Y=('!A<F$@
M=')O8V%R('!A<F$@;R!M;V1O(%9)4U5!3"X`3N-O(&5S=.$@875T96YT:6-A
M9&\N`$[C;R!P;V1E('1E<B!O(&-A<F%C=&5R92`G7"<@;F\@<V5U(&YO;64@
M8V]M<&QE=&\N`$[C;R!I;G1R;V1U>FEU('5M(&5N9&5R9>=O(&1E(&-O<G)E
M:6\@96QE8W1R\VYI8V\@=N%L:61O+@!.XV\@;6%P96]U(&YE;FAU;2!C86UP
M;R!D;R!A<G%U:79O(&EM<&]R=&%D;R!P87)A(&]S(&-A;7!O<R!C;W)R97-P
M;VYD96YT97,@96T@)7,N`$%C86)O=2!D92!S86ER+@!496T@9&4@:6YT<F]D
M=7II<B!U;2!N^FUE<F\@9&4@=&5L96WS=F5L(';A;&ED;RP@<_,@8V]M(&3M
M9VET;W,L(&UA<R!C;VT@=6T@)RLG(&]P8VEO;F%L('!A<F$@;R!P<F5F:7AO
M(&EN=&5R;F%C:6]N86PN`%1E;2!D92!I;G1R;V1U>FER('5M('9A;&]R(';A
M;&ED;RX`5&5M(&1E(&-O;F9I9W5R87(@=6T@;65C86YI<VUO(&+A<VEC;R!P
M87)A($1A=&%4<F5E('-E('%U:7-E<B!U<V%R(%-U8G-C<FGG]65S`%1E;2!D
M92!C;VYF:6=U<F%R('5M(&UE8V%N:7-M;R!B87-E('!A<F$@;R!61E,N`$1E
M=F4@9&5S8W)E=F5R(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@<F5L
M873S<FEO+@!496T@9&4@:6YT<F]D=7II<B!O(%523"!D;R!R96-U<G-O('%U
M92!E<W1A(&QI9V'GXV\@<V4@<F5F97)E`%1E;2!D92!S96QE8V-I;VYA<B!U
M;2!S97)V:61O<B!A(')E;6]V97(N`$1E=F4@97-P96-I9FEC87(@;R!U=&EL
M:7IA9&]R(&$@;&EM<&%R+@!$979E(&5S<&5C:69I8V%R(&\@;F]M92!D;R!U
M=&EL:7IA9&]R(&$@<F5M;W9E<BX`5&5M(&1E(&5S<&5C:69I8V%R('!E;&\@
M;65N;W,@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!P87)A
M('%U92!A(&UE;G-A9V5M(&1E(&%U<^IN8VEA('-E:F$@86-T:79A9&$N`%1E
M;2!D92!E<W!E8VEF:6-A<B!O(&YO;64@9&\@=71I;&EZ861O<B!A(&%D:6-I
M;VYA<BX`5&5M(&1E(&5S<&5C:69I8V%R(&\@=71I;&EZ861O<B!A(&%C='5A
M;&EZ87(N`%1E;2!D92!E<W!E8VEF:6-A<B!A(&%CY^-O(&$@9&5S96UP96YH
M87(N`%1E;2!D92!I;G1R;V1U>FER('5M(&YO=F\@;F]M92!D92!C871E9V]R
M:6$N`%1E;2!D92!F;W)N96-E<B!U;2!N^FUE<F\@9&4@=&5L969O;F4@:71A
M;&EA;F\`02!S=6$@<V5S<^-O("5S(&5X<&ER;W4N(%!O<B!F879O<B!E;G1R
M92!D92!N;W9O+@!/('-E=2!%;F1E<F7G;R!D92!#;W)R96EO($5L96-T<O-N
M:6-O.@!/('-E=2!E;F1E<F7G;R`B1&4Z(@!!('-U82!);F9O<FUAY^-O`$\@
M<V5U(&5N9&5R9>=O($E0('!A<F5C92!T97(@;75D861O(&1E<V1E(&\@:6[M
M8VEO(&1A('-E<W/C;R`E<RX@4&%R82!G87)A;G1I<B!A('-U82!S96=U<F%N
MYV$L(&1E=F4@875T96YT:6-A<BUS92!D92!N;W9O+@!/(%-E=2!.;VUE`$\@
M<V5U(&UE8V%N:7-M;R!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@861I
MY^-O(&1E('5T:6QI>F%D;W)E<R!O=2!E<W1A(&]PY^-O(&9O:2!D97-A8W1I
M=F%D82!P;W(@86QG=6T@;W5T<F\@;6]T:79O+@!/('-E=2!M96-A;FES;6\@
M9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&QI<W1A9V5M(&1E('5T:6QI
M>F%D;W)E<R!O=2!E<W1A(&]PY^-O(&9O:2!D97-A8W1I=F%D82!P;W(@86QG
M=6T@;W5T<F\@;6]T:79O+@!/('-E=2!N879E9V%D;W(@<&%R96-E('1E<B!M
M=61A9&\@9&5S9&4@;R!I;NUC:6\@9&$@<V5S<^-O("5S+B!087)A(&=A<F%N
M=&ER(&$@<W5A('-E9W5R86[G82P@9&5V92!A=71E;G1I8V%R+7-E(&1E(&YO
M=F\N`$\@<V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&9U;F-I;VYA
M;&ED861E+@!/('-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@97-T82!O<.?C
M;R!D92!I;7!R97-SXV\N(%!R97-S:6]N92!#;VYT<F]L+T-O;6UA;F0@*R!0
M('!A<F$@:6UP<FEM:7(N`$9U<V\@:&]RX7)I;R!A8W1U86PZ`$ED96YT:61A
M9&4@<&%D<N-O.@!.;VUE(&-O;7!L971O`$$@<W5A('9E<G/C;R!D;R!G971T
M97AT(.D@9&5M87-I861O(&%N=&EG82P@;N-O('-U<&]R=&%N9&\@4$A0(&1E
M(&9O<FUA(&YA=&EV82X@3F5M('1O9&%S(&%S(&-A9&5I87,@9&4@8V%R86-T
M97)E<R!S97+C;R!E>'1R8>UD87,N`$$@<W5A(&YO=F$@<&%L879R82UP87-S
M92!P87)A("5S(.DZ("5S`$%S('-U87,@;W#G]65S(&9O<F%M(&%L=&5R861A
M<R!A=.D@86\@9FEN86P@9&5S=&$@<V5S<^-O+@!!<R!S=6%S(&]PY_5E<R!F
M;W)A;2!A8W1U86QI>F%D87,N`$$@<W5A('!A;&%V<F$M<&%S<V4@9F]I(')E
M8W)I861A`$$@<W5A('!A;&%V<F$M<&%S<V4@9F]I(')E8W)I861A+"!V97)I
M9FEQ=64@;R!S974@8V]R<F5I;R!E;&5C='+S;FEC;R!E(&5N=')E(&-O;2!A
M('-U82!N;W9A('!A;&%V<F$M<&%S<V4N`$]S('-E=7,@<V5R=FED;W)E<R!R
M96UO=&]S.@!*=6=O<VSA=FEA`%IA:7)E`%KB;6)I80!::6UB86)UZ0!::7!P
M>0!;17-C;VYD97(@5&5X=&\@0VET861O70!;4V5M($%S<W5N=&]=`%M296QA
M=/-R:6\@9&4@4')O8FQE;6%S72``6TUO<W1R87(@5&5X=&\@0VET861O("T`
M6TUO<W1R87(@5&5X=&\@0VET861O("T@)7,@;&EN:&%S70!;;&EN:&$@)7,@
M9&4@)7-=`%]%;F1E<F7G;RAS*2!P87)A(&]S('%U86ES(')E9&ER96-I;VYA
M<CH`7T5N9&5R9>=O*',I(&%O*',I('%U86PH:7,I(&[C;R!E;G9I87(@<F5S
M<&]S=&%S.@!?061M:6YI<W1R8>?C;P!,:7-T82!?3F5G<F$`7T-O;G-O;&$`
MP7)?=F]R90!?4F5M;W9E<B!,:6YH80!296UO7W9E<B!M96YS86=E;2!C;VUP
M;&5T86UE;G1E`%]);G1R;V1U>F$@8V%D82!E;F1E<F7G;R!E;2!S=6$@;&EN
M:&$Z`%]2961I<F5C:6]N86UE;G1O`%]'<G5P;W,`05]J=61A`%!R;W!R:65D
M861E<R!D82!?26UA9V5M`%]-86YT97(@=6UA(&/S<&EA(&1A<R!M96YS86=E
M;G,@;F5S=&$@8V]N=&$_`%]%;G1R87(`7U-A:7(`7TUO9&EF:6-A<B!,:6=A
MY^-O`%]-;W9E<B!M96YS86=E;2!P87)A(&$@<&%S=&$Z`%]-974H<RD@96YD
M97)EYV\H<RD@9&4@8V]R<F5I;R!E;&5C='+S;FEC;SH`7T]PY_5E<P!?4&5R
M;6ES<_5E<P!?4F5M;W9E<B!,:6=AY^-O+BXN`")?4V-R:7!T(@!?0V]N9FEG
M=7)AY^-O`%!R;W!R:65D861E<R!D82!?5&%B96QA`%]5=&EL:7IA9&]R97,`
M7T%U<^IN8VEA<P!,:7-T82!?0G)A;F-A`&-O;G1A8W1O<P!O8V]R<F5U('5M
M(&5R<F\Z`&4`8V%L96YDX7)I;P!C86QM;P!C;&EQ=64@87%U:0!F96ET;P!F
M86QH;W4`9&EM:6YU:6YD;P!C86UP;P!F:6-H96ER;P!E;F-O;G1R861O.B``
M9&\@)7,@*"5S*2#@<R`E<R`E<P!R86IA9&%S`&@Z`&AH`&EM961I871O`&5M
M(&QI;FAA`&QI;FAA<UT`8V]R<F5S<&]N9&4`17)R;R!M:VES;V9S(&-O;2!C
M\V1I9V\@)60@86\@8V]N<W1R=6ER($E33RX`;6T`;F]M90!S96T@86QT97)A
MY_5E<P!NXV\@96YC;VYT<F%D;P!NXV\@:6UP;&5M96YT861A`&%I;F1A('!O
M<B!I;7!L96UE;G1A<@!C861E<FYO(&1E(&YO=&%S`&]U`'!E<F-E;G1A9V5M
M`'#M>&5I<P`B4V-R:7!T(B!D;R!P<F]C;6%I;"!G97)A9&\@<&5L;R!);F=O
M`'-U8FEN9&\`;6]S=')A<B!D:69E<F5NYV%S`$9I;'1R;R!P96YE:7)A("@B
M<VEE=F4B*2!G97)A9&\@<&5L;R!);F=O`'-M<S)E;6%I;"!V:6$@2%144`!S
M<P!E<W3A=F5L`&QI<W1A(&1E('1A<F5F87,`3R!F:6-H96ER;R!03R!P87)A
M(&\@;&]C86QE("5S(&[C;R!E>&ES=&4N`&EN=')O9'5Z82!A('!A;&%V<F$M
M<&%S<V4@9'5A<R!V97IE<RP@<&%R82!C;VYF:7)M8>?C;P!U;FEF:6-A9&\`
M<V5M(&YO;64`86-T=6%L:7IA9&\`<V5L96-C:6]N861A('!E;&\@=71I;&EZ
M861O<@!V0V%R9`!2965N8SH`=V5A=&AE<BYC;VT````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE+W)O7U)/+P``````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-#<`,#$W-C0R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L
M;V-A;&4O<F]?4D\O3$-?34534T%'15,O````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,C$T,C<`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;F=O+VQO8V%L92]R;U]23R],0U]-15-304=%4R]I;F=O
M+FUO`````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P-S(T`#$P-#$W,S8R-S0W`#`R
M,C<R,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25`````)<````<````U`0``-,```","0```````-@,```H````V0P`
M``@````"#0``!0````L-```(````$0T```<````:#0``!0```"(-```4````
M*`T``!\````]#0``"````%T-```4````9@T``#(```![#0``$0```*X-```#
M````P`T```@```#$#0``"0```,T-```5````UPT```@```#M#0``%0```/8-
M```.````#`X```(````;#@``"@```!X.```,````*0X```<````V#@``"```
M`#X.```'````1PX```H```!/#@``*0```%H.```"````A`X```4```"'#@``
M$````(T.```)````G@X``!````"H#@``&0```+D.```'````TPX``!0```#;
M#@``+P```/`.```/````(`\``"8````P#P``!P```%</```%````7P\```T`
M``!E#P``!0```',/```0````>0\``!````"*#P``#P```)L/```+````JP\`
M``\```"W#P``#````,</```/````U`\```X```#D#P``!@```/,/```>````
M^@\``"$````9$````P```#L0```+````/Q````0```!+$```!````%`0```,
M````51````H```!B$```!0```&T0```)````<Q```!(```!]$```$````)`0
M```"````H1````4```"D$```"````*H0```0````LQ````<```#$$```!@``
M`,P0```'````TQ````(```#;$```!````-X0```/````XQ````<```#S$```
M&P```/L0```'````%Q$```X````?$0``#````"X1```$````.Q$```4```!`
M$0``"````$81```C````3Q$```4```!S$0``!P```'D1```>````@1$``!$`
M``"@$0``#0```+(1```(````P!$``!X```#)$0``!0```.@1```H````[A$`
M`"D````7$@``$P```$$2```+````51(```D```!A$@``"P```&L2```1````
M=Q(```0```")$@``#````(X2```)````FQ(```0```"E$@``#````*H2```&
M````MQ(```\```"^$@``'@```,X2```$````[1(```X```#R$@``&@````$3
M```7````'!,``!<````T$P``&P```$P3```?````:!,``!,```"($P``!@``
M`)P3```$````HQ,``!````"H$P``%P```+D3```'````T1,```<```#9$P``
M!0```.$3```A````YQ,``!P````)%```!0```"84```"````+!0```,````O
M%```(````#,4```F````5!0```P```![%```#````(@4```(````E10```@`
M``">%```$````*<4```'````N!0```8```#`%```#0```,<4```+````U10`
M``P```#A%```"@```.X4```*````^10```P````$%0``#0```!$5```"````
M'Q4```8````B%0``10```"D5```P````;Q4``!````"@%0``'P```+$5```0
M````T14```\```#B%0``!0```/(5``!<`0``^!4``"@```!5%P``"0```'X7
M```%````B!<```\```".%P``!@```)X7```%````I1<``!@```"K%P``(P``
M`,07```(````Z!<``!<```#Q%P``.@````D8```4````1!@```,```!9&```
M#P```%T8```,````;1@``!<```!Z&```"````)(8```1````FQ@```P```"M
M&````@```+H8```-````O1@``!$```#+&```"````-T8```)````YA@```H`
M``#P&```"@```/L8```H````!AD```(````O&0``!@```#(9```4````.1D`
M``L```!.&0``$0```%H9```7````;!D```@```"$&0``$````(T9```Q````
MGAD``!(```#0&0``)P```.,9```*````"QH```4````6&@``&0```!P:```&
M````-AH``!,````]&@``%````%$:```3````9AH``!0```!Z&@``$P```(\:
M```0````HQH``!(```"T&@``$````,<:```&````V!H``!D```#?&@``)@``
M`/D:```#````(!L```T````D&P``!0```#(;```$````.!L```\````]&P``
M$@```$T;```%````8!L```D```!F&P``$0```'`;```2````@AL```0```"5
M&P``!P```)H;```%````HAL``!H```"H&P``"````,,;```)````S!L```L`
M``#6&P```@```.(;```-````Y1L``!T```#S&P``!0```!$<```D````%QP`
M``4````\'```$@```$(<```2````51P```0```!H'```"0```&T<```+````
M=QP``"T```"#'```!````+$<```'````MAP``",```"^'```#P```.(<```,
M````\AP```8```#_'```(@````8=```'````*1T``"<````Q'0``,````%D=
M```4````BAT```\```"?'0``$0```*\=```1````P1T``!$```#3'0``$```
M`.4=```.````]AT```L````%'@``!P```!$>```/````&1X```8````I'@``
M$P```#`>```9````1!X```@```!>'@``#@```&<>```4````=AX``!P```"+
M'@``&P```*@>```B````Q!X``!L```#G'@``&`````,?```)````'!\```8`
M```F'P``%0```"T?```6````0Q\```<```!:'P``!@```&(?```'````:1\`
M`!8```!Q'P``*````(@?```%````L1\```4```"W'P```P```+T?```B````
MP1\``"X```#D'P``%````!,@```2````*"````H````[(```!P```$8@```-
M````3B````<```!<(```"@```&0@```<````;R```!$```",(```$@```)X@
M```3````L2````P```#%(```#````-(@```,````WR````(```#L(```!0``
M`.\@```Z````]2```#L````P(0``%@```&PA```:````@R$``!$```">(0``
M$0```+`A```1````PB$```$```!N````8@```$\````$````8```````````
M````70``````````````#@````````"4`````````!,```!+````-````!8`
M``!U````!0```'8`````````'P````,```!6```````````````R````/0``
M`'````!;````!@```"$```".````9````(\````_````7P```"8```!L````
M`````#$```!&`````````"@```!"````00````````!>`````````$````"!
M````*@```'P```"$````5P```)$````0````#0````````!4````EP``````
M```7`````@```$4```"&````6````"````!I````9@```'D```!T````)0``
M`(@```"*``````````L```!.`````````&4````,`````````)8`````````
M``````````!S````"@``````````````$0````````!W````BP```%,```!^
M````"0```$@````D````'0```#L````````````````````X````````````
M``!,````<@````````"0````````````````````%0```'H````L````>```
M```````9````'````$H```!1````)P```!L````4````1``````````N````
M30```(T````K``````````<`````````A0````````""````D@```(P````Y
M````0P````````!J````?P```%H````M````+P``````````````;0``````
M``!A````&```````````````,``````````>`````````'T`````````;P``
M`(<`````````/@`````````B````(P```!H`````````<0```(D```!2````
M1P````\```"``````````#<```"#````:````%P`````````9P````````!0
M````-@```'L`````````8P```$D```"5`````````#,`````````50```#4`
M``!K````.@```````````````````),````2````/`````@```!9````````
M`"D`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`R-"!H;W5R<P!!32]030!!9&0@<&%I<@!!9&1R97-S`$%L:6%S`$%L;"!O
M9B!T:&4@9F]L;&]W:6YG`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`06YS=V5R960`06YY(&]F('1H92!F;VQL;W=I;F<`075T;VUA=&EC86QL
M>2!U<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\`079A:6QA
M8FQE(&9I96QD<SH`0F-C`$)I<G1H9&%Y`$)L86-K;&ES=`!";&%C:VQI<W1E
M9"!!9&1R97-S97,`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A
M<V4@4V5N<VET:79E`$-C`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A
M;GD`0V]N=&%I;G,`0V]P>2`E<P!#;W!Y(&]F("5S`$-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U;'0@
M261E;G1I='D`1&5L971E("5S`$1E;&5T92!#;VYD:71I;VX`1&5L971E(&UE
M<W-A9V4@8V]M<&QE=&5L>0!$96QE=&5D`$1E<V-R:6)E('1H92!0<F]B;&5M
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<`!%9&ET("5S`$5M86EL`$5M<'1Y(')E<W5L="X`17)R
M;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!%>&ES=&EN9R!2=6QE<P!%>&ES=',`1F%I
M;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+@!&87@`1FEL=&5R(%)U;&4`1G)O;0!(96QP`$AO
M;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&%N=`!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!)<P!)<VXG=`!,86YG=6%G
M90!,:7-T($AE;'`@5&]P:6-S`$QI<W0M240`3&]G(&EN`$QO9R!O=70`34T`
M36%I;`!-871C:&EN9R!F:65L9',`365S<V%G90!-:7-S:6YG(')E87-O;B!I
M;B!V86-A=&EO;BX`36]N=&AL>0!-;W9E(%)U;&4@1&]W;@!-;W9E(%)U;&4@
M57``3F%M90!.979E<@!.97<@4G5L90!.;R!B86-K96YD(&-O;F9I9W5R960@
M9F]R('1H:7,@:&]S=`!.;W1E<P!/<'1I;VYS`$]P=&EO;G,@86)O=70@<V-R
M:7!T('5P9&%T:6YG+@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS
M`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N
M90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5S96YT(%1O`%)E<V5N="UF
M<F]M`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4G5L92!$96QE=&5D`%)U;&4@
M3F%M90!3879E`%-A=F4@3W!T:6]N<P!38W)I<'0`4V-R:7!T(%5P9&%T:6YG
M`%-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D+@!3965N`%-E;&5C="!A
M(&9I96QD`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9&5R`%-I>F4`4VMI<"!-
M86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6)J96-T`%-U
M8V-E<W,`5&%S:W,`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET;&4`5&\`55),`%5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R($]P
M=&EO;G,`57-E<FYA;64`5F%C871I;VX`5F%C871I;VX@365S<V%G90!787)N
M:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=O<FL@061D
M<F5S<P!7;W)K(%!H;VYE`%@M4')I;W)I='D`6"U3<&%M+4QE=F5L`%@M4W!A
M;2U3=&%T=7,`65D`665A<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`'9#87)D
M`%!R;VIE8W0M260M5F5R<VEO;CH@26YG;R`P+C$*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U
M+3`U+3(X(#$S.C`Q*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!%=6=E;B!(;V%N
M8V$@/&5U9V5N:$!U<F)A;BUG<F%F>"YR;SX*3&%N9W5A9V4M5&5A;3H@4F]M
M86YI86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`E<R!/<&5R871I
M=6YI(&1E(&UE;G1E;F%N=&$@+2!#;VYF:7)M87)E`#(T(&1E(&]R90!!32]0
M30!!9&%U9V$@<&5R96-H96$`061R97-A`$%L:6%S`%1O871E(&1I;B!C96QE
M('5R;6%T;V%R90!3+6$@<W!E8VEF:6-A="!O('9A;&]A<F4@:6YC;W)E8W1A
M+@!287-P=6YS90!/<FEC87)E(&1I;B!U<FUA=&]A<F5L90!);7!R;W-P871A
M<F4@875T;VUA=&$@82!S8W)I<'1U;'5I(&1U<&$@9FEE8V%R92!S8VAI;6)A
M<F4_`$-I;7!U<FD@9&ES<&]N:6)I;&4Z`$)C8P!::75A(&1E(&YA<W1E<F4`
M3&ES=&$@;F5A9W)A`$%D<F5S92!D:6X@;&ES=&$@;F5A9W)A`$-A;&5N9&%R
M`%)E;G5N=&$@;&$@4F%P;W)T`$-A>B!S96YZ:71I=@!#8P!496QE9F]N($UO
M8FEL`$EN8VAI9&4@9F5R96%S=')A`$-O;7!A;FEA`$-O;G1I;BAE*0!#;W!I
M97)E("5S`$-O<&EE(&$@)7,`3G4@<&]T(&1E<V-H:61E(&UO9'5L=6P@9&4@
M365N=&5N86YT82`E<P!:6@!::6QN:6,`261E;G1I=&%T92!);7!L:6-I=&$`
M4W1E<F=E<F4@)7,`4W1E<F=E<F4@8V]N9&ET:64`4W1E<F=E<F4@8V]M<&QE
M=&$@;65S86H`4W1E<G,H92D`1&5S8W)I92!P<F]B;&5M80!$971A;&EI(&EN
M<F5G:7-T<F%T92!I;B!,3T<@<&5N=')U(&%D;6EN:7-T<F%T;W(N`$]P=&EU
M;FD@9&4@069I<V%R90!492!R;V<@;G4@86-C97-A(&1I<F5C="!M86EN=&5N
M86YC92YP:'``161I=&%R92`E<P!%;6%I;`!%;7!T>2!R97-U;'0N("T@9&4@
M=')A9'5S`$5R;V%R90!/(&1A=&$@;&$@,34@;6EN=71E`$\@9&%T82!L82`S
M,"!S96-U;F1E`$QA(&9I96-A<F4@-2!M:6YU=&4`3&$@9FEE8V%R92!#;VYE
M8W1A<F4`3R!D871A(&QA(#,P(&UI;G5T90!);B!F:65C87)E(&UI;G5T`$5X
M96UP;&4@9&4@=F%L;W)I.@!296=U;&D@97AI<W1E;G1E`$5X:7-T80!.=2!P
M;W0@8VET:2!P<F5F97)I;G1E;&4N`$YU(&UA('!O="!C;VYE8W1A(&QA('-E
M<G9E<G5L(&1E($Q$05`N`$9A>`!296=U;&$@9FEL=')U`$1E(&QA`$AE;'``
M061R97-A(&1E(&%C87-A`%1E;&5F;VYU;"!D92!A8V%S80!(;W)D90!);7!O
M<G1A;G0`0VEM<"!I;7!O<G1A=#H@)7,`0VEM<'5R:2!I;7!O<G1A=&4Z`$5S
M=&4`3G4@97-T90!,:6UB80!,:7-T82!S=6)I96-T96QO<B!D:6X@2&5L<`!)
M9"UL:7-T80!#;VYE8W1A<F4`1&5C;VYE8W1A<F4`3$P`0V]R97-P;VYD96YT
M80!#:6UP=7)I('!O=')I=FET92`M(&1E('1R861U<P!-97-A:@!.=2!E>&ES
M=&$@97AP;&EC871I92!P96YT<G4@=F%C86YT82X`3'5N87(`375T82!R96=U
M;&$@:6X@:F]S`$UU=&$@<F5G=6QA(&EN('-U<P!.=6UE`$YI8VEO9&%T80!2
M96=U;&$@;F]U80!.=2!E>&ES=&$@<W5P;W)T(&-O;F9I9W5R870@<&5N=')U
M(&%C97-T(&AO<W0`3F]T90!/<'1I=6YI`$]P=&EU;FD@<&5N=')U(&EM<')O
M<W!A=&%R92!S8W)I<'0N`$%L=&4@:6YF;W)M871I:0!!;'1E(&]P=&EU;FD`
M4&%R;VQA`$5X96-U=&$@3W!E<F%T:75N:6QE(&1E($UE;G1E;F%N=&$`5&5L
M969O;@!492!R;V<@<W!E8VEF:6-A('5N('-U;6%R(&%L('!R;V)L96UE:2X`
M5&4@<F]G(&EN=')O9'4@=6X@;G5M92!D92!U=&EL:7IA=&]R('-I(&\@<&%R
M;VQA`$1E<V-R:65R96$@<')O8FQE;65I`%-T97)G92!P97)E8VAE80!2971R
M:6UI=&5R92!C871R90!2971R:6UI=&5R92UD92!L80!);F%P;VD@;&$@;W!T
M:75N:0!2;VQE("T@9&4@=')A9'5S`%)E9W5L82!S=&5A<G-A`$YU;64@<F5G
M=6QA`%-A;'9A<F4`4V%L=F%Z82!/<'1I=6YI`%-C<FEP=`!);7!R;W-P871A
M<F4@<V-R:7!T`%-C<FEP="!A8W1I=F%T(&-U('-U8V-E<RX`5F%Z=70H92D`
M4V5L96-T87)E(&-A;7``1&5L:6UI=&%T;W(@9&4@9&%T83H`1F]R;6%T=6P@
M9&4@869I<V%R92!A(&1A=&5I.@!&;W)M871U;"!D92!A9FES87)E(&$@;W)E
M:3H`4V5L96-T96%Z82!D;W5A(&-I;7!U<FD@<&]T<FEV:71E+@!396QE8W1E
M87IA(&QI;6)A('!R969E<F%T83H`5')I;6ET92!287!O<G0@9&4@17)O87)E
M`$5X<&5D:71O<@!-87)I;64`4V%R:2!P97-T92!-96YT96YA;G1A`$-A<F%C
M=&5R92!3<&5C:6%L92`N+BX`4W5B:65C=`!3=6-C97,`4V%R8VEN:0!686QO
M87)E82!M:6YI;6$@97-T92`Q`$%C96%S=&$@=F%L;V%R92!T<F5B=6EE('-A
M(&9I92!N=6UE<FEC82X`5&ET;'4`0V%T<F4`55),`$YU(&UA('!O="!C;VYE
M8W1A(&QA('-E<G9E<G5L(%-13"X`3G4@<&]T('1R861U8V4@86-E<W0@9&]C
M=6UE;G0@5V]R9"`M(&1E('1R861U<P!!;G5L96%Z82!38VAI;6)A<FEL90!/
M<'1I=6YI(%5T:6QI>F%T;W(`571I;&EZ871O<@!686-A;G1A`$UE<V%J('9A
M8V%N=&$`071E;G1I90!387!T86UI;F%L`$)I;F4@86D@=F5N:70@:6X@<VES
M=&5M=6P@)7,`0FEN92!A:2!V96YI="P@)7,`061R97-A(&QA(%-E<G9I8VEU
M`%1E;&5F;VX@;&$@4V5R=FEC:74`6"U0<FEO<FET871E`%@M3FEV96PM4W!A
M;0!8+5-T87)E+5-P86T`04$`06YU86P`5')E8G5I92!S82!D97-C<FEI('!R
M;V)L96UA(&EN86EN=&4@9&4@82!T<FEM:71E(')A<&]R='5L+@!397-I=6YE
M82!T82!D92`E<R!A(&5X<&ER870N(%1E(')O9R!S82!F86-I($QO9R!);B!D
M:6X@;F]U+@!);F9O<FUA=&EI(&1E<W!R92!T:6YE`$]P=&EU;FEL92!A=2!F
M;W-T('-A;'9A=&4N`%M287!O<G0@4')O8FQE;6%=`%ML:6YI82`E<R!D:6X@
M)7-=`'9#87)D("T@9&4@=')A9'5S````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;F=O+VQO8V%L92]S=E]312\`````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0W`#`Q-S8T,0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE+W-V7U-%+TQ#7TU%4U-!
M1T53+P``````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-#<`,#(Q-#(V`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L;V-A
M;&4O<W9?4T4O3$-?34534T%'15,O:6YG;RYM;P``````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#0T-S(R-@`Q,#0Q-S,V,C<T-P`P,C(W,S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````WA($E0````"K"```'````'1%
M``"3"P``S(H````````8N0``2````!FY```.````8KD```\```!QN0``#```
M`(&Y```-````CKD```@```"<N0``"P```*6Y```,````L;D```0```"^N0``
M!````,.Y```#````R+D``!@```#,N0``&P```.6Y```M`````;H``!T````O
MN@``)````$VZ```I````<KH``!D```"<N@``)@```+:Z```,````W;H``"0`
M``#JN@``#P````^[```+````'[L```X````KNP``!0```#J[```H````0+L`
M``@```!INP``"@```'*[```5````?;L``!(```"3NP``"P```*:[```4````
MLKL``"8```#'NP``)P```.Z[```F````%KP``(4````]O```#@```,.\```*
M````TKP```T```#=O```)P```.N\```@````$[T```X````TO0``%P```$.]
M```B````6[T``#4```!^O0``$0```+2]```-````QKT```P```#4O0``#0``
M`.&]```&````[[T``)0```#VO0``"@```(N^```/````EKX``!@```"FO@``
M#````+^^```.````S+X```X```#;O@``"````.J^```)````\[X``"X```#]
MO@``&@```"R_```R````1[\``#@```!ZOP``5````+._``!1````",```%H`
M``!:P```5P```+7````T````#<$```D```!"P0``#0```$S!```'````6L$`
M``H```!BP0``#P```&W!```%````?<$```8```"#P0``$0```(K!```(````
MG,$```D```"EP0``"0```*_!```.````N<$```@```#(P0``)0```-'!```@
M````]\$``!,````8P@``$````"S"```/````/<(```H```!-P@``(0```%C"
M```'````>L(```\```""P@``+@```)+"```#````P<(```8```#%P@``#P``
M`,S"```4````W,(```D```#QP@``#0```/O"```2````"<,``!D````<PP``
M'@```#;#```/````5<,```H```!EPP``#P```'##```(````@,,``"0```")
MPP``%P```*[#```4````QL,``!8```#;PP``"````/+#``!.````^\,``"T`
M``!*Q```&0```'C$```3````DL0```<```"FQ```#````*[$```L````N\0`
M``X```#HQ````P```/?$```+````^\0```<````'Q0``!P````_%```%````
M%\4```4````=Q0``"@```"/%```#````+L4``!<````RQ0``"@```$K%```/
M````5<4```X```!EQ0``%````'3%```+````B<4``!@```"5Q0``(P```*[%
M```.````TL4``!0```#AQ0``%P```/;%```7````#L8``!<````FQ@``$P``
M`#[&```/````4L8```X```!BQ@``*0```''&```?````F\8``!T```"[Q@``
M!P```-G&```&````X<8```@```#HQ@``#P```/'&```&`````<<```@````(
MQP``"@```!''```3````',<``!0````PQP``"P```$7'```0````4<<``!4`
M``!BQP``#0```'C'```5````AL<```<```"<QP``$````*3'```%````M<<`
M`!4```"[QP``$0```-''```,````X\<``"H```#PQP``.P```!O(```X````
M5\@```D```"0R```!P```)K(```4````HL@```,```"WR```!0```+O(```0
M````P<@```D```#2R```$P```-S(```Y````\,@``!(````JR0``.0```#W)
M```G````=\D``"P```"?R0``*@```,S)```E````]\D```D````=R@``"@``
M`"?*```&````,LH```D````YR@``!P```$/*```O````2\H``#<```![R@``
M+@```+/*``!5````XLH``"T````XRP``+0```&;+```]````E,L``#\```#2
MRP``+0```!+,``!`````0,P``",```"!S```(P```*7,``!`````R<P``"T`
M```*S0``,P```#C-```E````;,T``!4```"2S0``&0```*C-```I````PLT`
M`"0```#LS0``*````!'.```R````.LX``!$```!MS@``$0```'_.```*````
MD<X```0```"<S@``#````*'.```*````KLX``!````"YS@``%@```,K.```6
M````X<X```<```#XS@``!P````#/```4````",\```H````=SP``"````"C/
M```(````,<\```@````ZSP``!@```$//```G````2L\```@```!RSP```P``
M`'O/```+````?\\```<```"+SP``!P```)//```&````F\\```4```"BSP``
M!P```*C/```&````L,\``!0```"WSP``"````,S/```)````U<\```X```#?
MSP``.P```.[/```5````*M```"D```!`T```#@```&K0```*````>=````D`
M``"$T```#@```([0```$````G=````0```"BT```!P```*?0```)````K]``
M``8```"YT```$0```,#0```'````TM```!8```#:T```!````/'0```(````
M]M````8```#_T```#0````;1```&````%-$``!X````;T0``!0```#K1```1
M````0-$```@```!2T0``#0```%O1```,````:=$```P```!VT0``!P```(/1
M```#````B]$```,```"/T0``%P```)/1```3````J]$``!T```"_T0``"```
M`-W1```$````YM$```@```#KT0``"````/31```*````_=$``$$````(T@``
M&@```$K2```K````9=(``"````"1T@``%0```++2```&````R-(```8```#/
MT@``%0```-;2```8````[-(``"(````%TP``+@```"C3```=````5],``"$`
M``!UTP``*0```)?3```*````P=,```<```#,TP``!P```-33```.````W-,`
M`!4```#KTP``#@````'4```"````$-0```H````3U```#P```![4```-````
M+M0```\````\U```#0```$S4```)````6M0``!0```!DU```!@```'G4```8
M````@-0``!T```"9U```$P```+?4```1````R]0``!0```#=U```!````/+4
M```,````]]0```8````$U0``%`````O5```7````(-4``%0````XU0``#@``
M`(W5``!D````G-4```0````!U@``#@````;6``!$````%=8```4```!:U@``
M!0```&#6```;````9M8``!H```""U@``$P```)W6```1````L=8``!$```##
MU@``$0```-76```<````Y]8``"H````$UP``$````"_7```A````0-<```4`
M``!BUP``$P```&C7```+````?-<``!(```"(UP``"@```)O7```/````IM<`
M``T```"VUP``$0```,37```3````UM<```P```#JUP``!@```/?7```,````
M_M<```8````+V```%P```!+8```0````*M@``!$````[V```"````$W8```%
M````5M@```P```!<V```$````&G8```%````>M@```T```"`V```!@```([8
M```'````E=@```T```"=V```!P```*O8```+````L]@```<```"_V```!P``
M`,?8```)````S]@``!0```#9V```"0```.[8```)````^-@```H````"V0``
M&0````W9```]````)]D``!T```!EV0``#````(/9```0````D-D```4```"A
MV0``)0```*?9```2````S=D``!,```#@V0``$@```/39```K````!]H``#L`
M```SV@``(````&_:```(````D-H``#8```"9V@``"````-#:```A````V=H`
M`!````#[V@``"`````S;```,````%=L```8````BVP``!````"G;```'````
M+ML```\````VVP``"@```$;;```.````4=L```H```!@VP``!P```&O;```*
M````<]L```T```!^VP``'@```(S;```?````J]L``!L```#+VP``'````.?;
M```A````!-P``!X````FW```&0```$7<```>````7]P``!L```!^W```(0``
M`)K<```N````O-P``"8```#KW```&P```!+=```<````+MT``!X```!+W0``
M'````&K=```F````A]T``"L```"NW0``,P```-K=```F````#MX``"L````U
MW@``.````&'>```=````FMX``!T```"XW@``%0```-;>```5````[-X``"\`
M```"WP``(````#+?```2````4]\``"````!FWP``*0```(??```>````L=\`
M`!X```#0WP``(````._?```2````$.```*(````CX```%@```,;@```C````
MW>```"@````!X0``*0```"KA```H````5.$``!\```!]X0``%0```)WA```5
M````L^$``"````#)X0``)0```.KA```H````$.(``"T````YX@``,````&?B
M``"2````F.(``"$````KXP``%@```$WC```6````9.,``!P```![XP``)@``
M`)CC```J````O^,``$$```#JXP``1````"SD```,````<>0```<```!^Y```
M!P```(;D```&````CN0```T```"5Y```$````*/D```1````M.0``!(```#&
MY```$P```-GD```2````[>0```<`````Y0``!`````CE```0````#>4``!``
M```>Y0``#````"_E```.````/.4```T```!+Y0``#P```%GE```3````:>4`
M``T```!]Y0``*````(OE```#````M.4```T```"XY0``!@```,;E```1````
MS>4``!<```#?Y0``&P```/?E```.````$^8```(````BY@``"@```"7F```%
M````,.8``!`````VY@``#P```$?F```$````5^8```T```!<Y@``#@```&KF
M```#````>>8```X```!]Y@``$0```(SF```(````GN8```\```"GY@``"```
M`+?F```/````P.8```<```#0Y@``#0```-CF```0````YN8```T```#WY@``
M"P````7G```1````$><```D````CYP``!@```"WG```)````-.<```L````^
MYP``$````$KG```,````6^<```H```!HYP``$0```'/G```9````A><```L`
M``"?YP``#0```*OG```B````N><``!D```#<YP``#P```/;G```;````!N@`
M`#0````BZ```"@```%?H```8````8N@``!(```![Z```&0```([H```6````
MJ.@``!````"_Z```!P```-#H```B````V.@``!4```#[Z```(0```!'I```E
M````,^D``!$```!9Z0``#0```&OI```'````>>D```P```"!Z0``)@```([I
M```4````M>D```L```#*Z0``(@```-;I```O````^>D```L````IZ@``"0``
M`#7J```9````/^H```L```!9Z@``%P```&7J```7````?>H```D```"5Z@``
M"@```)_J```(````JNH``!8```"SZ@``#P```,KJ```9````VNH``#H```#T
MZ@``%@```"_K```.````1NL```<```!5ZP``"````%WK```O````9NL```T`
M``"6ZP``)@```*3K```(````R^L``$,```#4ZP``$@```!CL```/````*^P`
M`!`````[[```#0```$SL```A````6NP``!(```!\[```'P```(_L```(````
MK^P```L```"X[```+P```,3L```.````].P```4````#[0``!@````GM``!%
M````$.T```,```!6[0``!P```%KM```$````8NT```<```!G[0``"@```&_M
M```*````>NT```\```"%[0``$````)7M```7````INT``!$```"^[0``&0``
M`-#M```7````ZNT```D````"[@``!0````SN```+````$NX```H````>[@``
M`@```"GN```%````+.X```T````R[@``&P```$#N```7````7.X``!0```!T
M[@``"0```(GN```.````D^X```T```"B[@``$@```+#N```)````P^X```<`
M``#-[@```P```-7N```(````V>X```D```#B[@``#@```.SN```8````^^X`
M`!@````4[P``"````"WO```%````-N\``!@````\[P``'@```%7O```;````
M=.\``!D```"0[P``*````*KO```5````T^\``!@```#I[P``&P````+P```3
M````'O```!,````R\```!P```$;P```(````3O````8```!7\```!@```%[P
M```0````9?````\```!V\```$````(;P```/````E_````L```"G\```#P``
M`+/P```,````P_````\```#0\```!P```.#P```.````Z/````8```#W\```
M!@```/[P```.````!?$```P````4\0``&@```"'Q```H````//$```\```!E
M\0``"````'7Q```(````?O$``!,```"'\0``'@```)OQ```A````NO$``"``
M``#<\0``&0```/WQ```7````%_(``"4````O\@``%P```%7R```6````;?(`
M``0```"$\@``&P```(GR```-````I?(```P```"S\@```P```,#R```%````
MQ/(```@```#*\@``"@```-/R```,````WO(```L```#K\@``$````/?R```,
M````"/,```X````5\P``"P```"3S```$````,/,```0````U\P``$P```#KS
M```4````3O,```P```!C\P``"0```'#S```.````>O,```L```")\P``&P``
M`)7S```3````L?,``!D```#%\P``&P```-_S```.````^_,```L````*]```
M#````!;T```5````(_0```T````Y]```0P```$?T```Q````B_0``$(```"]
M]```1P````#U``!/````2/4``#T```"8]0``3@```-;U```1````)?8```<`
M```W]@``!P```#_V```*````1_8```T```!2]@``&````&#V```*````>?8`
M``0```"$]@``)0```(GV```F````K_8```X```#6]@``?````.7V```5````
M8O<```4```!X]P``!P```'[W```,````AO<```@```"3]P``"@```)SW```&
M````I_<```<```"N]P``.0```+;W```(````\/<```T```#Y]P```@````?X
M```&````"O@```8````1^```%````!CX```5````+?@```\```!#^```$0``
M`%/X```:````9?@```T```"`^```$````([X```;````G_@```0```"[^```
M"0```,#X```%````RO@``!````#0^```"0```.'X```)````Z_@```4```#U
M^```&@```/OX```(````%OD```8````?^0``&0```";Y```.````0/D```<`
M``!/^0``!P```%?Y```%````7_D```D```!E^0``"@```&_Y```.````>OD`
M``(```")^0``!@```(SY```+````D_D```T```"?^0``"0```*WY```,````
MM_D``!@```#$^0``!@```-WY```%````Y/D```D```#J^0``!P```/3Y```$
M````_/D``!0````!^@``0@```!;Z```E````6?H``"4```!_^@``!@```*7Z
M```$````K/H```D```"Q^@``"````+OZ```1````Q/H```X```#6^@``"0``
M`.7Z```&````[_H```T```#V^@``!@````3[```$````"_L``#D````0^P``
M/0```$K[```Z````B/L``!X```##^P``!0```.+[```.````Z/L```0```#W
M^P``!@```/S[```'`````_P``"$````+_```#0```"W\```5````._P```8`
M``!1_```$@```%C\```$````:_P``!$```!P_```!@```(+\```*````B?P`
M`"(```"4_```!````+?\```%````O/P```0```#"_```#````,?\```.````
MU/P```H```#C_```"````.[\```)````]_P```4````!_0``.@````?]```P
M````0OT``#4```!S_0``*0```*G]``!'````T_T``#@````;_@``*0```%3^
M```_````?OX``"X```"^_@``+0```.W^```?````&_\```\````[_P``$@``
M`$O_```+````7O\``"8```!J_P``*0```)'_```D````N_\``"8```#@_P``
M"`````<``0`*````$``!``D````;``$`!P```"4``0`@````+0`!`"````!.
M``$`)@```&\``0`*````E@`!`!D```"A``$`*0```+L``0`6````Y0`!`!(`
M``#\``$`!P````\!`0`*````%P$!``P````B`0$`#P```"\!`0`0````/P$!
M`$````!0`0$`<````)$!`0!F`````@(!``X```!I`@$`"0```'@"`0`*````
M@@(!`!(```"-`@$`$P```*`"`0`,````M`(!``8```#!`@$`#P```,@"`0`)
M````V`(!`!(```#B`@$`$````/4"`0`*````!@,!`!$````1`P$`'````",#
M`0`C````0`,!`&H```!D`P$`#P```,\#`0`%````WP,!`!````#E`P$`0P``
M`/8#`0`)````.@0!`#(```!$!`$`!````'<$`0`+````?`0!`"````"(!`$`
M%````*D$`0`,````O@0!``P```#+!`$`#P```-@$`0`5````Z`0!`"D```#^
M!`$`*@```"@%`0`F````4P4!`"<```!Z!0$`*0```*(%`0`J````S`4!`!D`
M``#W!0$`$0```!$&`0`2````(P8!`!,````V!@$`%````$H&`0`/````7P8!
M`!8```!O!@$`%P```(8&`0`0````G@8!`!$```"O!@$`-````,$&`0`3````
M]@8!`!(````*!P$`-0```!T'`0`4````4P<!``<```!H!P$`#````'`'`0`K
M````?0<!`"````"I!P$`$````,H'`0`4````VP<!`!$```#P!P$`%P````((
M`0`<````&@@!`!,````W"`$`%````$L(`0`:````8`@!`!$```!["`$`&@``
M`(T(`0`>````J`@!`!H```#'"`$`$P```.((`0`5````]@@!`!$````,"0$`
M%P```!X)`0`4````-@D!`!<```!+"0$`%0```&,)`0`)````>0D!`!````"#
M"0$`&0```)0)`0`$````K@D!``<```"S"0$``@```+L)`0`+````O@D!``4`
M``#*"0$`$0```-`)`0`&````X@D!``8```#I"0$`!@```/`)`0`%````]PD!
M``<```#]"0$`!P````4*`0`%````#0H!`!8````3"@$`!@```"H*`0`&````
M,0H!``0````X"@$`!````#T*`0`'````0@H!``X```!*"@$`#````%D*`0`,
M````9@H!``T```!S"@$`!0```($*`0`H````APH!``P```"P"@$`#P```+T*
M`0`*````S0H!``@```#8"@$`"0```.$*`0`K````ZPH!``0````7"P$`"```
M`!P+`0`%````)0L!`"8````K"P$`$@```%(+`0`/````90L!``8```!U"P$`
M"@```'P+`0!,````APL!``<```#4"P$`"````-P+`0`@````Y0L!``D````&
M#`$`%````!`,`0`,````)0P!``T````R#`$`#@```$`,`0`6````3PP!`!$`
M``!F#`$`!@```'@,`0`(````?PP!``,```"(#`$`!@```(P,`0`9````DPP!
M``<```"M#`$`!````+4,`0`+````N@P!``L```#&#`$`!P```-(,`0`)````
MV@P!`!4```#D#`$`!0```/H,`0`'``````T!`!8````(#0$`#0```!\-`0`*
M````+0T!``T````X#0$`"@```$8-`0`0````40T!``\```!B#0$`$0```'(-
M`0`7````A`T!``H```"<#0$`$0```*<-`0`(````N0T!``0```#"#0$`#P``
M`,<-`0`Z````UPT!``4````2#@$`#````!@.`0`>````)0X!``X```!$#@$`
M$````%,.`0`+````9`X!``P```!P#@$`"0```'T.`0`'````APX!``<```"/
M#@$`"@```)<.`0`)````H@X!``X```"L#@$`$````+L.`0`;````S`X!`!@`
M``#H#@$`&@````$/`0`*````'`\!``D````G#P$`"@```#$/`0`,````/`\!
M``\```!)#P$`"````%D/`0`&````8@\!``<```!I#P$`!0```'$/`0`+````
M=P\!`$<```"##P$`#0```,L/`0`)````V0\!``0```#C#P$``P```.@/`0`3
M````[`\!`!,`````$`$`$P```!00`0`&````*!`!``L````O$`$`"@```#L0
M`0`"````1A`!``0```!)$`$`)0```$X0`0`#````=!`!``4```!X$`$`*@``
M`'X0`0`*````J1`!``4```"T$`$`!````+H0`0`*````OQ`!``T```#*$`$`
M!@```-@0`0`(````WQ`!``@```#H$`$`!````/$0`0`%````]A`!`&@```#\
M$`$`"0```&41`0`,````;Q$!`!````!\$0$`&````(T1`0`%````IA$!``8`
M``"L$0$`$````+,1`0`;````Q!$!`"\```#@$0$`$````!`2`0`*````(1(!
M`!L````L$@$`#P```$@2`0`*````6!(!``D```!C$@$`$P```&T2`0`;````
M@1(!`!@```"=$@$`%P```+82`0`?````SA(!`!<```#N$@$`#@````83`0")
M````%1,!`(D```"?$P$``P```"D4`0`'````+10!``@````U%`$`%````#X4
M`0`3````4Q0!`!````!G%`$`#0```'@4`0`.````AA0!`!8```"5%`$`!P``
M`*P4`0`*````M!0!``L```"_%`$`!P```,L4`0!1````TQ0!`!`````E%0$`
M#````#85`0`-````0Q4!`!H```!1%0$`2@```&P5`0`9````MQ4!``8```#1
M%0$`&@```-@5`0`E````\Q4!``8````9%@$`!@```"`6`0`?````)Q8!``8`
M``!'%@$`"0```$X6`0`8````6!8!`!<```!Q%@$`*````(D6`0`&````LA8!
M``T```"Y%@$`(@```,<6`0`9````ZA8!`"8````$%P$`5P```"L7`0`3````
M@Q<!`!D```"7%P$`&P```+$7`0`C````S1<!`!,```#Q%P$``@````48`0`+
M````"!@!``@````4&`$`#0```!T8`0`*````*Q@!``<````V&`$`%````#X8
M`0`&````4Q@!``@```!:&`$`#@```&,8`0`'````<A@!``H```!Z&`$`"P``
M`(48`0`R````D1@!``<```#$&`$`#````,P8`0`-````V1@!``P```#G&`$`
M!````/08`0`)````^1@!``D````#&0$`"@````T9`0`.````&!D!``P````G
M&0$`!P```#09`0`)````/!D!``<```!&&0$`"@```$X9`0`'````61D!`!L`
M``!A&0$`#P```'T9`0`2````C1D!``H```"@&0$`%@```*L9`0`)````PAD!
M`!````#,&0$`!P```-T9`0`2````Y1D!`"D```#X&0$`!````"(:`0`'````
M)QH!``4````O&@$`!````#4:`0`,````.AH!``4```!'&@$`"P```$T:`0`4
M````61H!`!$```!N&@$`%````(`:`0`7````E1H!`!@```"M&@$`'````,8:
M`0`9````XQH!``<```#]&@$`!0````4;`0`-````"QL!``P````9&P$`$0``
M`"8;`0`(````.!L!``@```!!&P$`%P```$H;`0`+````8AL!``P```!N&P$`
M'P```'L;`0`:````FQL!`!,```"V&P$`!````,H;`0`*````SQL!``0```#:
M&P$`#0```-\;`0`,````[1L!``4```#Z&P$`"0`````<`0`%````"AP!``<`
M```0'`$`!0```!@<`0`$````'AP!``(````C'`$`+P```"8<`0`X````5AP!
M`"P```"/'`$`(P```+P<`0`F````X!P!`!(````''0$`*0```!H=`0`R````
M1!T!``H```!W'0$`+````((=`0`N````KQT!`#,```#>'0$`,P```!(>`0`X
M````1AX!``\```!_'@$`%````(\>`0`8````I!X!`!````"]'@$`+@```,X>
M`0`4````_1X!``\````2'P$`$P```"(?`0`5````-A\!`!0```!,'P$`$@``
M`&$?`0`4````=!\!`!4```")'P$`+0```)\?`0`M````S1\!`#$```#['P$`
M+@```"T@`0`O````7"`!`"P```",(`$`$P```+D@`0`,````S2`!``T```#:
M(`$`"````.@@`0`4````\2`!`!<````&(0$`"````!XA`0`4````)R$!``P`
M```\(0$`*P```$DA`0`A````=2$!`!H```"7(0$`"0```+(A`0!%````O"$!
M`$$````"(@$`#P```$0B`0`$````5"(!`!,```!9(@$`#@```&TB`0`3````
M?"(!`!@```"0(@$`!@```*DB`0`)````L"(!``H```"Z(@$`#P```,4B`0`,
M````U2(!`!````#B(@$`!P```/,B`0`.````^R(!``4````*(P$`&P```!`C
M`0`&````+",!`!0````S(P$`"````$@C`0`&````42,!`!0```!8(P$`$0``
M`&TC`0`.````?R,!`#@```".(P$``@```,<C`0`&````RB,!``X```#1(P$`
M!0```.`C`0`'````YB,!``X```#N(P$`!@```/TC`0`H````!"0!``P````M
M)`$`'````#HD`0`$````5R0!`"D```!<)`$`%0```(8D`0`7````G"0!`!\`
M``"T)`$`7````-0D`0`4````,24!`#X```!&)0$`'P```(4E`0`0````I24!
M`!0```"V)0$`!P```,LE`0`>````TR4!``X```#R)0$`#`````$F`0`,````
M#B8!`!,````;)@$`"@```"\F`0`=````.B8!`!D```!8)@$`!0```'(F`0`1
M````>"8!``T```"*)@$`"````)@F`0`1````H28!`"0```"S)@$`$@```-@F
M`0`5````ZR8!`!(````!)P$`#@```!0G`0`9````(R<!``@````])P$`"0``
M`$8G`0`-````4"<!``<```!>)P$`"@```&8G`0`'````<2<!``\```!Y)P$`
M!@```(DG`0`+````D"<!`!H```"<)P$`"@```+<G`0`'````PB<!``@```#*
M)P$`!0```-,G`0`?````V2<!``8```#Y)P$`$``````H`0`(````$2@!``T`
M```:*`$`"````"@H`0`>````,2@!`!(```!0*`$`+````&,H`0`:````D"@!
M``D```"K*`$`"@```+4H`0`5````P"@!``4```#6*`$`%````-PH`0`$````
M\2@!`!````#V*`$`!@````<I`0`'````#BD!`!X````6*0$`*````#4I`0`*
M````7BD!`!P```!I*0$`$0```(8I`0`+````F"D!`!H```"D*0$`%````+\I
M`0`$````U"D!``0```#9*0$`"P```-XI`0`%````ZBD!``8```#P*0$`"```
M`/<I`0`&`````"H!``H````'*@$`&P```!(J`0`T````+BH!`#0```!C*@$`
M(````)@J`0`I````N2H!`"````#C*@$`00````0K`0`:````1BL!`"@```!A
M*P$`*````(HK`0`I````LRL!`%$```#=*P$`4````"\L`0!7````@"P!`"P`
M``#8+`$`(@````4M`0`&````*"T!``@````O+0$`!0```#@M`0`(````/BT!
M`!D```!'+0$`&0```&$M`0`J````>RT!``@```"F+0$`(P```*\M`0`9````
MTRT!`"X```#M+0$`-````!PN`0`(````42X!`!<```!:+@$`"@```'(N`0`'
M````?2X!`"$```"%+@$`$````*<N`0`.````N"X!``L```#'+@$`!P```-,N
M`0`3````VRX!``@```#O+@$`"P```/@N`0`*````!"\!`!0````/+P$`#P``
M`"0O`0`R````-"\!``L```!G+P$`#@```',O`0`%````@B\!``4```"(+P$`
M!0```(XO`0`7````E"\!``<```"L+P$`#P```+0O`0`$````Q"\!``H```#)
M+P$`"0```-0O`0`+````WB\!``T```#J+P$`#````/@O`0`.````!3`!``4`
M```4,`$`!````!HP`0`-````'S`!`#(````M,`$`10```&`P`0`(````IC`!
M``L```"O,`$`%P```+LP`0`'````TS`!`!X```#;,`$`%````/HP`0`%````
M#S$!`!(````5,0$`$@```"@Q`0`4````.S$!``8```!0,0$`!P```%<Q`0`C
M````7S$!``X```"#,0$`*@```)(Q`0`&````O3$!``P```#$,0$`#0```-$Q
M`0`1````WS$!`!<```#Q,0$`"P````DR`0`V````%3(!``H```!,,@$`(@``
M`%<R`0`+````>C(!``\```"&,@$`"P```)8R`0`@````HC(!`"<```##,@$`
M*P```.LR`0`)````%S,!`#(````A,P$`)0```%0S`0`P````>C,!`#$```"K
M,P$`+0```-TS`0`.````"S0!`!0````:-`$`"0```"\T`0`+````.30!``4`
M``!%-`$`#@```$LT`0`3````6C0!`!(```!N-`$`!P```($T`0`6````B30!
M`!$```"@-`$`%````+(T`0`3````QS0!``<```#;-`$`%````.,T`0`8````
M^#0!``<````1-0$`!0```!DU`0`,````'S4!``P````L-0$`$@```#DU`0`$
M````3#4!``<```!1-0$`"@```%DU`0`+````9#4!``P```!P-0$`#@```'TU
M`0`.````C#4!``4```";-0$`!````*$U`0`+````IC4!``P```"R-0$`#0``
M`+\U`0`,````S34!``D```#:-0$`!0```.0U`0`%````ZC4!`"X```#P-0$`
M)@```!\V`0`C````1C8!``,```!J-@$`$@```&XV`0`&````@38!`!X```"(
M-@$`&````*<V`0`E````P#8!``T```#F-@$`"0```/0V`0`?````_C8!``,`
M```>-P$`&````"(W`0`'````.S<!``H```!#-P$``@```$XW`0`,````43<!
M`!4```!>-P$`"P```'0W`0`9````@#<!`"````":-P$`$@```+LW`0`%````
MSC<!``H```#4-P$`%0```-\W`0`2````]3<!``P````(.`$`!````!4X`0`)
M````&C@!``<````D.`$`#````"PX`0`-````.3@!`%(```!'.`$`%P```)HX
M`0`D````LC@!`!(```#7.`$`!P```.HX`0`&````\C@!``\```#Y.`$`$P``
M``DY`0`>````'3D!`"`````\.0$`!@```%TY`0`.````9#D!``0```!S.0$`
M#````'@Y`0`-````A3D!``X```"3.0$`%0```*(Y`0`2````N#D!``\```#+
M.0$`%````-LY`0`*````\#D!`!L```#[.0$`$````!<Z`0`+````*#H!`!0`
M```T.@$`:0```$DZ`0`:````LSH!`!<```#..@$`)P```.8Z`0`:````#CL!
M`!<````I.P$`&P```$$[`0`9````73L!`!\```!W.P$`$P```)<[`0`7````
MJSL!`!,```##.P$`"````-<[`0`&````X#L!``<```#G.P$`"````.\[`0`)
M````^#L!`!4````"/`$`#0```!@\`0`C````)CP!``T```!*/`$`$P```%@\
M`0`(````;#P!``,```!U/`$`1@```'D\`0`_````P#P!`#<`````/0$`5P``
M`#@]`0`>````D#T!``4```"O/0$`'P```+4]`0`O````U3T!``H````%/@$`
M"````!`^`0`-````&3X!`"T````G/@$`!````%4^`0`2````6CX!`!,```!M
M/@$`3P```($^`0`E````T3X!`!P```#W/@$`"P```!0_`0`?````(#\!`!T`
M``!`/P$`)0```%X_`0`@````A#\!`"0```"E/P$`(````,H_`0`+````ZS\!
M``<```#W/P$`#0```/\_`0`,````#4`!`!<````:0`$`!@```#)``0`Y````
M.4`!``P```!S0`$`!P```(!``0`)````B$`!`!,```"20`$`!P```*9``0`)
M````KD`!``0```"X0`$`$````+U``0`(````SD`!``@```#70`$`!````.!`
M`0`+````Y4`!``P```#Q0`$`$@```/Y``0`1````$4$!``P````C00$`&@``
M`#!!`0`/````2T$!``<```!;00$`#0```&-!`0`4````<4$!``X```"&00$`
M#````)5!`0`L````HD$!`!,```#/00$`'````.-!`0`H`````$(!``8````I
M0@$`!P```#!"`0`3````.$(!``4```!,0@$`!````%)"`0`7````5T(!``H`
M``!O0@$`#````'I"`0`)````AT(!``8```"10@$`"0```)A"`0`(````HD(!
M``D```"K0@$`!0```+5"`0`*````NT(!`!$```#&0@$`!@```-A"`0`C````
MWT(!``X````#0P$`#@```!)#`0`-````(4,!``L````O0P$`'0```#M#`0`+
M````64,!``(```!E0P$`'````&A#`0`=````A4,!``<```"C0P$`"````*M#
M`0`&````M$,!`&0```"[0P$`"0```"!$`0`'````*D0!`"8````R1`$`.```
M`%E$`0`:````DD0!`"H```"M1`$`.P```-A$`0`H````%$4!`#0````]10$`
M&0```')%`0`5````C$4!``4```"B10$`!P```*A%`0`(````L$4!``<```"Y
M10$`!0```,%%`0`'````QT4!``X```#/10$`"0```-Y%`0`&````Z$4!``@`
M``#O10$`"P```/A%`0`'````!$8!``@````,1@$`!P```!5&`0`6````'48!
M``D````T1@$`!@```#Y&`0`+````148!`!````!11@$`!@```&)&`0`<````
M:48!`!0```"&1@$`!P```)M&`0`1````HT8!``@```"U1@$`#@```+Y&`0`(
M````S48!``4```#61@$`$````-Q&`0`)````[48!`!````#W1@$`!@````A'
M`0`9````#T<!``H````I1P$`'````#1'`0`'````44<!``4```!91P$`!```
M`%]'`0`0````9$<!`!0```!U1P$`"P```(I'`0`-````ED<!`"@```"D1P$`
M&````,U'`0`7````YD<!`!H```#^1P$`%````!E(`0`$````+D@!``D````S
M2`$`"@```#U(`0`'````2$@!``(```!02`$`#@```%-(`0`(````8D@!`!\`
M``!K2`$`(P```(M(`0`C````KT@!`!\```#32`$`.````/-(`0`F````+$D!
M`#$```!320$`)P```(5)`0`R````K4D!`#(```#@20$`9````!-*`0`4````
M>$H!`!P```"-2@$`50```*I*`0`X`````$L!`$H````Y2P$`6P```(1+`0`H
M````X$L!`!$````)3`$`.````!M,`0`J````5$P!`"@```!_3`$`+````*A,
M`0`G````U4P!`"8```#]3`$`&P```"1-`0`^````0$T!`",```!_30$`%P``
M`*--`0`9````NTT!`$@```#530$`A0```!Y.`0`P````I$X!`"4```#53@$`
M00```/M.`0!;````/4\!`$D```"93P$`,0```.-/`0`=````%5`!`!@````S
M4`$`*P```$Q0`0`A````>%`!`!\```":4`$`*P```+I0`0`F````YE`!`"$`
M```-40$`*0```"]1`0`G````65$!`#H```"!40$`'0```+Q1`0`1````VE$!
M`#,```#L40$`)0```"!2`0`X````1E(!`"<```!_4@$`(````*=2`0`?````
MR%(!`#````#H4@$`:0```!E3`0`Q````@U,!`$$```"U4P$`,P```/=3`0`E
M````*U0!`#T```!15`$`90```(]4`0!-````]50!`"D```!#50$`*P```&U5
M`0`O````F54!`"X```#)50$`*P```/A5`0`P````)%8!`"H```!55@$`/@``
M`(!6`0!4````OU8!`%H````45P$`2````&]7`0!*````N%<!`#(````#6`$`
M'0```#98`0`C````5%@!`"\```!X6`$`+````*A8`0`M````U5@!`'$````#
M60$`9@```'59`0!O````W%D!`+,```!,6@$`%P````!;`0`E````&%L!`#(`
M```^6P$`*0```'%;`0`^````FUL!`"(```#:6P$`4@```/U;`0`E````4%P!
M``L```!V7`$`10```()<`0`A````R%P!`#````#J7`$`)0```!M=`0`<````
M05T!`#$```!>70$`!P```)!=`0`'````F%T!``0```"@70$`#0```*5=`0`+
M````LUT!``X```"_70$`"P```,Y=`0`%````VET!`!````#@70$``@```/%=
M`0!9````]%T!``,```!.7@$`!0```%)>`0`2````6%X!``0```!K7@$`!P``
M`'!>`0`(````>%X!``4```"!7@$``P```(=>`0`0````BUX!``P```"<7@$`
M$P```*E>`0`-````O5X!``(```#+7@$`!P```,Y>`0`&````UEX!`!0```#=
M7@$`#````/)>`0`8````_UX!``8````87P$`$@```!]?`0`,````,E\!``,`
M```_7P$`*@```$-?`0`$````;E\!``8```!S7P$`!P```'I?`0`?````@E\!
M`#4```"B7P$`+@```-A?`0`O````!V`!`!<````W8`$`'P```$]@`0`B````
M;V`!`"4```"28`$`(````+A@`0`;````V6`!`!@```#U8`$`)`````YA`0`?
M````,V$!`!H```!380$`(0```&YA`0`@````D&$!`!H```"Q80$`,@```,QA
M`0`:````_V$!`"\````:8@$`*P```$IB`0`?````=F(!`",```"68@$`'P``
M`+IB`0`:````VF(!`"$```#U8@$`)0```!=C`0`F````/6,!`"4```!D8P$`
M)````(IC`0`8````KV,!`!T```#(8P$`)````.9C`0`8````"V0!`"(````D
M9`$`+````$=D`0`O````=&0!`!4```"D9`$`)0```+ID`0`\````X&0!`!\`
M```=90$`(P```#UE`0`?````864!`"````"!90$`&@```*)E`0`8````O64!
M`"8```#690$`'@```/UE`0`I````'&8!`!X```!&9@$`,0```&5F`0`)````
MEV8!``P```"A9@$`%P```*YF`0`O````QF8!`"0```#V9@$`!P```!MG`0`?
M````(V<!``\```!#9P$`%````%-G`0`.````:&<!``T```!W9P$`)````(5G
M`0`%````JF<!``<```"P9P$`(@```+AG`0`E````VV<!`!H````!:`$`'0``
M`!QH`0`:````.F@!``<```!5:`$`QP```%UH`0`+````)6D!`!4````Q:0$`
M!@```$=I`0`)````3FD!`!@```!8:0$`"P```'%I`0`-````?6D!`!<```"+
M:0$`!@```*-I`0`S````JFD!`!,```#>:0$`$P```/)I`0`'````!FH!``\`
M```.:@$`!P```!YJ`0`R````)FH!``0```!9:@$`(0```%YJ`0`3````@&H!
M``P```"4:@$`$0```*%J`0`R````LVH!`!8```#F:@$`"````/UJ`0`=````
M!FL!``D````D:P$`"@```"YK`0`4````.6L!``H```!.:P$`'0```%EK`0`(
M````=VL!``T```"`:P$`.@```(YK`0`?````R6L!``@```#I:P$`&@```/)K
M`0`G````#6P!``8````U;`$`%0```#QL`0`'````4FP!``@```!:;`$`"0``
M`&-L`0`_````;6P!``<```"M;`$`#P```+5L`0`.````Q6P!`!````#4;`$`
M"0```.5L`0`)````[VP!``@```#Y;`$`$P````)M`0`'````%FT!`!D````>
M;0$`"@```#AM`0`*````0VT!``D```!.;0$`%P```%AM`0`4````<&T!``H`
M``"%;0$`#````)!M`0`7````G6T!``0```"U;0$`*@```+IM`0`,````Y6T!
M`!$```#R;0$`!P````1N`0`"````#&X!`!`````/;@$`&````"!N`0`+````
M.6X!``,```!%;@$`"````$EN`0`3````4FX!`!<```!F;@$`!@```'YN`0`'
M````A6X!``T```"-;@$`"P```)MN`0`4````IVX!`!4```"\;@$`#@```-)N
M`0`5````X6X!`"\```#W;@$`(````"=O`0`<````2&\!`!4```!E;P$`#```
M`'MO`0`Q````B&\!``D```"Z;P$`#@```,1O`0`[````TV\!`!4````/<`$`
M!0```"5P`0`2````*W`!`#\````^<`$`$@```'YP`0`*````D7`!``8```"<
M<`$`!````*-P`0`$````J'`!``H```"M<`$`$P```+AP`0`%````S'`!``8`
M``#2<`$`!@```-EP`0`(````X'`!``0```#I<`$`#````.YP`0`*````^W`!
M`#D````&<0$`+@```$!Q`0`I````;W$!``H```"9<0$`!0```*1Q`0`,````
MJG$!``P```"W<0$`#0```,1Q`0`9````TG$!`!$```#L<0$``@```/YQ`0`$
M`````7(!``H````&<@$`!@```!%R`0`%````&'(!``,````><@$`#````")R
M`0!%````+W(!`#(```!U<@$`,0```*AR`0`S````VG(!`!H````.<P$`-0``
M`"ES`0`T````7W,!`"@```"4<P$`&0```+US`0`?````UW,!`'(```#W<P$`
M(````&IT`0`U````BW0!`"$```#!=`$`10```.-T`0`P````*74!`"@```!:
M=0$`*0```(-U`0`F````K74!`&````#4=0$`)0```#5V`0`H````6W8!`"@`
M``"$=@$`(@```*UV`0`K````T'8!`#````#\=@$`$@```"UW`0`3````0'<!
M`!````!4=P$`>0```&5W`0`)````WW<!`*$```#I=P$`<P```(MX`0!\````
M_W@!`"L```!\>0$`5````*AY`0`7````_7D!`"<````5>@$`%@```#UZ`0`/
M````5'H!`!<```!D>@$`'P```'QZ`0!`````G'H!`!\```#=>@$`'````/UZ
M`0!1````&GL!`!H```!L>P$`%````(=[`0`*````G'L!``4```"G>P$`!@``
M`*U[`0`(````M'L!``4```"]>P$`$@```,-[`0`,````UGL!`!````#C>P$`
M$P```/1[`0`=````"'P!``\````F?`$`&P```#9\`0`D````4GP!``\```!W
M?`$`"@```(=\`0`$````DGP!``D```"7?`$`"P```*%\`0`:````K7P!`"(`
M``#(?`$`"````.M\`0`'````]'P!``4```#\?`$`%`````)]`0`I````%WT!
M``<```!!?0$`"````$E]`0`/````4GT!`!@```!B?0$`%````'M]`0`(````
MD'T!``P```"9?0$`#P```*9]`0`&````MGT!``<```"]?0$`!@```,5]`0`4
M````S'T!``8```#A?0$`"0```.A]`0`*````\GT!``8```#]?0$`#`````1^
M`0`1````$7X!``,````C?@$`"````"=^`0`$````,'X!`!D````U?@$`$0``
M`$]^`0`*````87X!``4```!L?@$`&````')^`0`3````BWX!`!P```"??@$`
M$0```+Q^`0`:````SGX!``0```#I?@$`#P```.Y^`0`'````_GX!``4````&
M?P$`!`````Q_`0`9````$7\!``<````K?P$``@```#-_`0`"````-G\!`!$`
M```Y?P$`"0```$M_`0`(````57\!``8```!>?P$`$@```&5_`0`7````>'\!
M``8```"0?P$`(0```)=_`0`%````N7\!`"<```"_?P$``@```.=_`0`$````
MZG\!``\```#O?P$`$P```/]_`0`'````$X`!``(````;@`$`!P```!Z``0`1
M````)H`!``8````X@`$`(0```#^``0`8````88`!``8```!Z@`$`$P```(&`
M`0`0````E8`!`!X```"F@`$`$@```,6``0`"````V(`!``8```#;@`$`#```
M`.*``0`)````[X`!`!$```#Y@`$`(@````N!`0`'````+H$!``<````V@0$`
M"P```#Z!`0`%````2H$!``(```!0@0$`"P```%.!`0",`0``7X$!`$P```#L
M@@$`$0```#F#`0`2````2X,!``\```!>@P$`#@```&Z#`0`'````?8,!``H`
M``"%@P$`!P```)"#`0`$````F(,!``0```"=@P$`!@```**#`0`8````J8,!
M`!T```#"@P$`+````."#`0`=````#80!`"`````KA`$`)@```$R$`0`7````
M<X0!`"@```"+A`$`#````+2$`0`K````P80!``X```#MA`$`$0```/R$`0`2
M````#H4!``4````AA0$`(P```">%`0`(````2X4!``H```!4A0$`$P```%^%
M`0`/````<X4!``L```"#A0$`%0```(^%`0!#````I84!`"(```#IA0$`,0``
M``R&`0!O````/H8!``@```"NA@$`"@```+>&`0`*````PH8!`#<```#-A@$`
M(@````6'`0`0````*(<!`!L````YAP$`(````%6'`0`P````=H<!`!````"G
MAP$`#P```+B'`0`3````R(<!`!````#<AP$`!@```.V'`0")````](<!``L`
M``!^B`$`$0```(J(`0`=````G(@!``H```"ZB`$`$````,6(`0`0````UH@!
M``D```#GB`$`"P```/&(`0`L````_8@!`!P````JB0$`.P```$>)`0!%````
M@XD!`%8```#)B0$`4P```""*`0!9````=(H!`%8```#.B@$`/@```"6+`0`.
M````9(L!`!,```!SBP$`#@```(>+`0`0````EHL!`!@```"GBP$`!0```,"+
M`0`&````QHL!``H```#-BP$`!0```-B+`0`&````WHL!``8```#EBP$`$0``
M`.R+`0`*````_HL!`"4````)C`$`)````"^,`0`0````5(P!`!(```!EC`$`
M#````'B,`0`&````A8P!`!P```",C`$`"````*F,`0`/````LHP!`#4```#"
MC`$`"0```/B,`0`,`````HT!`!0````/C0$`&0```"2-`0`.````/HT!`!(`
M``!-C0$`%P```&"-`0`>````>(T!`",```"7C0$`&@```+N-`0`0````UHT!
M`!<```#GC0$`#0```/^-`0`J````#8X!`!@````XC@$`%@```%&.`0`9````
M:(X!`!,```""C@$`3P```):.`0`Q````YHX!`"0````8CP$`&0```#V/`0`&
M````5X\!``D```!>CP$`-````&B/`0`.````G8\!``8```"LCP$`"@```+./
M`0`(````OH\!``@```#'CP$`!0```-"/`0`'````UH\!``H```#>CP$`!```
M`.F/`0`<````[H\!``P````+D`$`$0```!B0`0`/````*I`!``T````ZD`$`
M#0```$B0`0`5````5I`!`"8```!LD`$`"P```).0`0`:````GY`!`!T```"Z
MD`$`(0```-B0`0`8````^I`!``\````3D0$`$````".1`0`1````-)$!`"\`
M``!&D0$`&P```':1`0`;````DI$!``<```"ND0$`!@```+:1`0`(````O9$!
M``P```#&D0$`!````-.1`0`(````V)$!``D```#AD0$`$P```.N1`0`1````
M_Y$!``L````1D@$`$0```!V2`0`6````+Y(!`!````!&D@$`'P```%>2`0`'
M````=Y(!`!(```!_D@$`!0```)*2`0`6````F)(!``\```"OD@$`#````+^2
M`0`M````S)(!`#$```#ZD@$`0@```"R3`0`)````;Y,!``@```!YDP$`%```
M`(*3`0`%````EY,!``4```"=DP$`$````*.3`0`+````M),!`!D```#`DP$`
M.P```-J3`0`2````%I0!`$8````IE`$`+P```'"4`0`T````H)0!`"X```#5
ME`$`+0````25`0`)````,I4!``@````\E0$`!P```$65`0`*````394!``D`
M``!8E0$`(P```&*5`0`T````AI4!`"(```"[E0$`1@```-Z5`0`A````)98!
M`"$```!'E@$`0P```&F6`0!"````K98!`!\```#PE@$`0````!"7`0`G````
M49<!`"H```!YEP$`0P```*27`0`A````Z)<!`"<````*F`$`+````#*8`0`:
M````7Y@!`!X```!ZF`$`*@```)F8`0`K````Q)@!`"L```#PF`$`)P```!R9
M`0`2````1)D!``X```!7F0$`"@```&:9`0`'````<9D!``T```!YF0$`"```
M`(>9`0`-````D)D!`!\```">F0$`(P```+Z9`0`'````XID!``<```#JF0$`
M%0```/*9`0`*````")H!``8````3F@$`!@```!J:`0`(````(9H!``8````J
MF@$`*0```#&:`0`(````6YH!``,```!DF@$`"@```&B:`0`+````<YH!``<`
M``!_F@$`!@```(>:`0`%````CIH!``<```"4F@$`!@```)R:`0`:````HYH!
M``H```"^F@$`$0```,F:`0`7````VYH!`#P```#SF@$`$0```#";`0`G````
M0IL!`!(```!JFP$`"````'V;`0`(````AIL!``X```"/FP$`#@```)Z;`0`#
M````K9L!``<```"QFP$`"0```+F;`0`#````PYL!``D```#'FP$`!0```-&;
M`0`7````UYL!``0```#OFP$`"````/2;`0`&````_9L!``T````$G`$`"0``
M`!*<`0`G````')P!``0```!$G`$`!@```$F<`0`)````4)P!``H```!:G`$`
M#````&6<`0`,````<IP!``<```!_G`$``P```(><`0`#````BYP!`!<```"/
MG`$`%@```*><`0`D````OIP!``@```#CG`$`!0```.R<`0`(````\IP!``<`
M``#[G`$`"@````.=`0!%````#IT!`!T```!4G0$`.````'*=`0`B````JYT!
M`!<```#.G0$`!@```.:=`0`&````[9T!`!4```#TG0$`%0````J>`0`?````
M()X!`"L```!`G@$`&@```&R>`0`C````AYX!`#$```"KG@$`"0```-V>`0`&
M````YYX!``@```#NG@$`$0```/>>`0`7````"9\!``X````AGP$``@```#"?
M`0`,````,Y\!`!$```!`GP$`#@```%*?`0`1````89\!``X```!SGP$`#```
M`(*?`0`5````CY\!``D```"EGP$`'````*^?`0`=````S)\!`!(```#JGP$`
M#P```/V?`0`2````#:`!``4````@H`$`"@```":@`0`%````,:`!`!,````W
MH`$`%P```$N@`0!5````8Z`!`!(```"YH`$`8@```,R@`0`#````+Z$!`!,`
M```SH0$`*0```$>A`0`%````<:$!``0```!WH0$`'````'RA`0`>````F:$!
M`!$```"XH0$`#0```,JA`0`1````V*$!``P```#JH0$`&P```/>A`0`D````
M$Z(!``4````XH@$`'@```#ZB`0`%````7:(!`!4```!CH@$`"P```'FB`0`3
M````A:(!``\```"9H@$`$@```*FB`0`3````O*(!`!@```#0H@$`$P```.FB
M`0`-````_:(!``0````+HP$`"P```!"C`0`(````'*,!`!<````EHP$`%0``
M`#VC`0`2````4Z,!``@```!FHP$`!````&^C`0`-````=*,!``<```""HP$`
M"0```(JC`0`/````E*,!``L```"DHP$`"````+"C`0`/````N:,!``D```#)
MHP$`!````-.C`0`'````V*,!``<```#@HP$`"````.BC`0`5````\:,!``<`
M```'I`$`!0````^D`0`%````%:0!`!@````;I`$`4````#2D`0`A````A:0!
M``X```"GI`$`$0```+:D`0`%````R*0!``4```#.I`$`&0```-2D`0`:````
M[J0!`"0````)I0$`+````"ZE`0`T````6Z4!`"@```"0I0$`"0```+FE`0`E
M````PZ4!``H```#II0$`(@```/2E`0`/````%Z8!``@````GI@$`#````#"F
M`0`&````/:8!``<```!$I@$`"@```$RF`0`:````5Z8!``L```!RI@$`$0``
M`'ZF`0`*````D*8!``L```";I@$`"@```*>F`0`/````LJ8!`"$```#"I@$`
M(@```.2F`0`@````!Z<!`"$````HIP$`)````$JG`0`C````;Z<!`!\```"3
MIP$`)@```+.G`0`A````VJ<!`"0```#\IP$`*0```"&H`0`E````2Z@!`!T`
M``!QJ`$`'@```(^H`0`@````KJ@!`!L```#/J`$`)@```.NH`0`M````$JD!
M`"L```!`J0$`(@```&RI`0`K````CZD!`#<```"[J0$`'0```/.I`0`=````
M$:H!`!D````OJ@$`&0```$FJ`0`P````8ZH!`"$```"4J@$`$@```+:J`0`A
M````R:H!`"@```#KJ@$`&@```!2K`0`8````+ZL!`!X```!(JP$`$0```&>K
M`0"V````>:L!`!(````PK`$`'````$.L`0`E````8*P!`"8```"&K`$`(```
M`*VL`0`D````SJP!`!H```#SK`$`&@````ZM`0`D````*:T!`"0```!.K0$`
M*P```'.M`0`L````GZT!`"<```#,K0$`C````/2M`0`?````@:X!`!4```"A
MK@$`%0```+>N`0`>````S:X!`"D```#LK@$`*0```!:O`0!$````0*\!`$0`
M``"%KP$`"P```,JO`0`$````UJ\!``8```#;KP$`!0```.*O`0`*````Z*\!
M``@```#SKP$`#0```/RO`0`/````"K`!`!8````:L`$`$0```#&P`0`(````
M0[`!``0```!,L`$`$````%&P`0`/````8K`!``L```!RL`$`#@```'ZP`0`0
M````C;`!``X```">L`$`$@```*VP`0`,````P+`!`#8```#-L`$`"`````2Q
M`0`+````#;$!``8````9L0$`$@```""Q`0`8````,[$!`!L```!,L0$`"```
M`&BQ`0`"````<;$!``H```!TL0$`!@```'^Q`0`2````AK$!``X```"9L0$`
M!0```*BQ`0`.````KK$!``@```"]L0$``P```,:Q`0`.````RK$!`!$```#9
ML0$`"````.NQ`0`)````]+$!``8```#^L0$`#0````6R`0`'````$[(!``P`
M```;L@$`$0```"BR`0`,````.K(!``P```!'L@$`$0```%2R`0`)````9K(!
M``8```!PL@$`"0```'>R`0`+````@;(!``X```"-L@$`#````)RR`0`+````
MJ;(!`!$```"UL@$`'````,>R`0`+````Y+(!``T```#PL@$`'P```/ZR`0`6
M````'K,!`!0````ULP$`&@```$JS`0`Q````9;,!``H```"7LP$`%0```**S
M`0`2````N+,!`!4```#+LP$`$@```.&S`0`5````]+,!``<````*M`$`)```
M`!*T`0`8````-[0!`"D```!0M`$`+````'JT`0`2````I[0!``L```"ZM`$`
M!P```,:T`0`-````SK0!`"L```#<M`$`$0````BU`0`+````&K4!`"(````F
MM0$`+P```$FU`0`*````>;4!``D```"$M0$`'@```(ZU`0`+````K;4!`!L`
M``"YM0$`&P```-6U`0`'````\;4!``T```#YM0$`"P````>V`0`7````$[8!
M`!4````KM@$`'````$&V`0`Z````7K8!`!<```"9M@$`#@```+&V`0`*````
MP+8!``@```#+M@$`+@```-2V`0`+`````[<!`"(````/MP$`"@```#*W`0`Y
M````/;<!``\```!WMP$`#P```(>W`0`/````E[<!``H```"GMP$`#````+*W
M`0`7````O[<!`",```#7MP$`!0```/NW`0`(`````;@!`"T````*N`$`"@``
M`#BX`0`&````0[@!``8```!*N`$`5@```%&X`0`#````J+@!``<```"LN`$`
M!0```+2X`0`(````NK@!``L```##N`$`"P```,^X`0`0````V[@!`!(```#L
MN`$`&0```/^X`0`8````&;D!`!L````RN0$`&P```$ZY`0`*````:KD!``<`
M``!UN0$`"P```'VY`0`*````B;D!``(```"4N0$`!@```)>Y`0`,````GKD!
M`"4```"KN0$`(````-&Y`0`6````\KD!``P````)N@$`$````!:Z`0`.````
M)[H!`!`````VN@$`"P```$>Z`0`)````4[H!``0```!=N@$`!P```&*Z`0`*
M````:KH!``\```!UN@$`(0```(6Z`0`8````I[H!``@```#`N@$``P```,FZ
M`0`=````S;H!`"P```#KN@$`*P```!B[`0`<````1+L!`"<```!ANP$`)```
M`(F[`0`I````KKL!`",```#8NP$`%P```/R[`0`:````%+P!``<````OO`$`
M"````#>\`0`&````0+P!``8```!'O`$`#@```$Z\`0`.````7;P!``\```!L
MO`$`#0```'R\`0`0````BKP!``\```";O`$`"P```*N\`0`2````M[P!``,`
M``#*O`$`$0```,Z\`0`%````X+P!``D```#FO`$`$@```/"\`0`.`````[T!
M`!<````2O0$`+P```"J]`0`-````6KT!``@```!HO0$`#0```'&]`0`@````
M?[T!`"4```"@O0$`)@```,:]`0`E````[;T!`",````3O@$`(P```#>^`0`K
M````6[X!`"(```"'O@$`&@```*J^`0`#````Q;X!``X```#)O@$`"````-B^
M`0`+````X;X!``,```#MO@$`!0```/&^`0`(````][X!``D`````OP$`"P``
M``J_`0`/````%K\!`!(````FOP$`"@```#F_`0`.````1+\!``X```!3OP$`
M!````&*_`0`#````9[\!`!,```!KOP$`%0```'^_`0`,````E;\!``<```"B
MOP$`!@```*J_`0`.````L;\!`!H```#`OP$`&0```-N_`0`A````];\!`"(`
M```7P`$`$P```#K``0`+````3L`!``P```!:P`$`&0```&?``0`-````@<`!
M`$````"/P`$`+P```-#``0!``````,$!`$D```!!P0$`2P```(O!`0`Z````
MU\$!`$H````2P@$`#@```%W"`0`&````;,(!``<```!SP@$`#0```'O"`0`.
M````B<(!`!<```"8P@$`"````+#"`0`#````N<(!`"<```"]P@$`)0```.7"
M`0`-````"\,!`$X````9PP$`%````&C#`0`(````?<,!``H```"&PP$`$0``
M`)'#`0`*````H\,!``P```"NPP$`!0```+O#`0`-````P<,!`#,```#/PP$`
M#@````/$`0`4````$L0!``(````GQ`$`!0```"K$`0`)````,,0!`!,````Z
MQ`$`&@```$[$`0`3````:<0!`!@```!]Q`$`(````);$`0`.````M\0!`!(`
M``#&Q`$`&0```-G$`0`$````\\0!``D```#XQ`$`!0````+%`0`7````",4!
M``@````@Q0$`$0```"G%`0`%````.\4!`!@```!!Q0$`"````%K%`0`&````
M8\4!`!T```!JQ0$`#0```(C%`0`(````EL4!``@```"?Q0$`!0```*C%`0`)
M````KL4!``<```"XQ0$`%0```,#%`0`"````UL4!``8```#9Q0$`#````.#%
M`0`-````[<4!``@```#[Q0$`"0````3&`0`8````#L8!`!0````GQ@$`!```
M`#S&`0`(````0<8!``<```!*Q@$``P```%+&`0`3````5L8!`#T```!JQ@$`
M)@```*C&`0`I````S\8!``<```#YQ@$`!`````''`0`)````!L<!``@````0
MQP$`$````!G'`0`3````*L<!``<````^QP$`!@```$;'`0`-````3<<!``8`
M``!;QP$`!````&+'`0`Q````9\<!`#8```"9QP$`,P```-#'`0`:````!,@!
M``4````?R`$`#````"7(`0`%````,L@!``8````XR`$`"````#_(`0`8````
M2,@!`!(```!AR`$`%P```'3(`0`$````C,@!``T```"1R`$`!0```)_(`0`1
M````I<@!``T```"WR`$`"````,7(`0`7````SL@!``,```#FR`$`!````.K(
M`0`#````[\@!``L```#SR`$`"@```/_(`0`,````"LD!``@````7R0$`"0``
M`"#)`0`%````*LD!`#T````PR0$`,0```&[)`0`_````H,D!`!T```#@R0$`
M00```/[)`0`W````0,H!`"@```!XR@$`.0```*'*`0`N````V\H!`#(````*
MRP$`(0```#W+`0`1````7\L!`!4```!QRP$`#````(?+`0`O````E,L!`"0`
M``#$RP$`)````.G+`0`C````#LP!``D````RS`$`"@```#S,`0`*````1\P!
M``8```!2S`$`)0```%G,`0`F````?\P!`#````"FS`$`"0```-?,`0`>````
MX<P!`"H`````S0$`&@```"O-`0`0````1LT!``8```!7S0$`#0```%[-`0`-
M````;,T!``\```!ZS0$`$@```(K-`0`[````G<T!`)$```#9S0$`9````&O.
M`0`5````T,X!``H```#FS@$`"P```/'.`0`1````_<X!`!(````/SP$`#@``
M`"+/`0`&````,<\!`!(````XSP$`!P```$O/`0`4````4\\!`!$```!HSP$`
M"````'K/`0`1````@\\!`"0```"5SP$`*@```+K/`0!N````Y<\!``H```!4
MT`$`!@```%_0`0`6````9M`!`#D```!]T`$`"@```+?0`0`H````PM`!``0`
M``#KT`$`"P```/#0`0`G````_-`!`!0````DT0$`"P```#G1`0`-````1=$!
M``\```!3T0$`$P```&/1`0`E````=]$!`"0```"=T0$`'````,+1`0`>````
MW]$!`"$```#^T0$`(````"#2`0`6````0=(!`!$```!8T@$`$````&K2`0`3
M````>](!`!(```"/T@$`$@```*+2`0`5````M=(!`!0```#+T@$`$````.#2
M`0`/````\=(!`"D````!TP$`$0```"O3`0`1````/=,!`#L```!/TP$`%```
M`(O3`0`&````H-,!``P```"GTP$`)P```+33`0`A````W-,!`!8```#^TP$`
M%0```!74`0`2````*]0!`!8````^U`$`'````%74`0`3````<M0!`!4```"&
MU`$`&@```)S4`0`8````M]0!`!T```#0U`$`(0```.[4`0`A````$-4!`!4`
M```RU0$`%````$C5`0`4````7=4!`!@```!RU0$`&@```(O5`0`8````IM4!
M`!8```"_U0$`"P```-;5`0`/````XM4!``0```#RU0$`!````/?5`0`&````
M_-4!``(````#U@$`"P````;6`0`'````$M8!`!$````:U@$`!@```"S6`0`+
M````,]8!``8````_U@$`!P```$;6`0`'````3M8!``<```!6U@$`!0```%[6
M`0`5````9-8!``8```!ZU@$`"0```('6`0`$````B]8!``0```"0U@$`!P``
M`)76`0`-````G=8!``P```"KU@$`#@```+C6`0`,````Q]8!``4```#4U@$`
M*0```-K6`0`-````!-<!``L````2UP$`"P```![7`0`)````*M<!`!`````T
MUP$`,````$77`0`$````=M<!``@```![UP$`!0```(37`0`)````BM<!``@`
M``"4UP$`$0```)W7`0`&````K]<!``D```"VUP$`0P```,#7`0`'````!-@!
M``4````,V`$`!````!+8`0`,````%]@!`!$````DV`$`#P```#;8`0`2````
M1M@!`!8```!9V`$`'@```'#8`0`:````C]@!``@```"JV`$`"````+/8`0`#
M````O-@!``8```#`V`$`)0```,?8`0`'````[=@!``<```#UV`$`#0```/W8
M`0`-````"]D!``<````9V0$`"0```"'9`0`8````*]D!``0```!$V0$`!P``
M`$G9`0`&````4=D!``T```!8V0$`!P```&;9`0`(````;MD!``D```!WV0$`
M$P```('9`0`5````E=D!``T```"KV0$`$@```+G9`0`(````S-D!``P```#5
MV0$`"````.+9`0`$````Z]D!`!````#PV0$`0@````':`0`&````1-H!``0`
M``!+V@$`'P```%#:`0`.````<-H!``\```!_V@$`#@```(_:`0`,````GMH!
M``D```"KV@$`!P```+7:`0`'````O=H!``H```#%V@$`"0```-#:`0`.````
MVMH!`!````#IV@$`)0```/K:`0`E````(-L!`"(```!&VP$`"@```&G;`0`'
M````=-L!``D```!\VP$`"P```(;;`0`)````DML!``4```"<VP$`"````*+;
M`0`(````J]L!``4```"TVP$`$````+K;`0!.````R]L!`!@````:W`$`"0``
M`#/<`0`&````/=P!``,```!$W`$`$````$C<`0`0````6=P!`!0```!JW`$`
M!@```'_<`0`*````AMP!``D```"1W`$``@```)O<`0`$````GMP!`",```"C
MW`$``P```,?<`0`%````R]P!``H```#1W`$`"@```-S<`0`&````Y]P!``8`
M``#NW`$`"P```/7<`0`-`````=T!``8````/W0$`"````!;=`0`*````']T!
M``0````JW0$`!0```"_=`0!V````-=T!``L```"LW0$`#@```+C=`0`7````
MQ]T!`!\```#?W0$`!````/_=`0`(````!-X!`!<````-W@$`%0```"7>`0`O
M````.]X!``T```!KW@$`"@```'G>`0`'````A-X!``X```",W@$`"P```)O>
M`0`)````I]X!`!0```"QW@$`,P```,;>`0`H````^MX!`"<````CWP$`&@``
M`$O?`0`0````9M\!``T```!WWP$`B````(7?`0"'````#N`!``,```"6X`$`
M!P```)K@`0`'````HN`!``L```"JX`$`$````+;@`0`.````Q^`!``D```#6
MX`$`$````.#@`0`;````\>`!``D````-X0$`"0```!?A`0`/````(>$!``H`
M```QX0$`30```#SA`0`>````BN$!``T```"IX0$`"@```+?A`0`A````PN$!
M`$P```#DX0$`&0```#'B`0`%````2^(!`!\```!1X@$`+@```''B`0`'````
MH.(!``8```"HX@$`"P```*_B`0`&````N^(!``<```#"X@$`)P```,KB`0`F
M````\N(!`"H````9XP$`!@```$3C`0`'````2^,!`"\```!3XP$`*P```(/C
M`0`D````K^,!`%4```#4XP$`%0```"KD`0`B````0.0!`!@```!CY`$`)P``
M`'SD`0`3````I.0!``(```"XY`$`#````+OD`0`(````R.0!``P```#1Y`$`
M"@```-[D`0`'````Z>0!``D```#QY`$`!@```/OD`0`)`````N4!``P````,
MY0$`"````!GE`0`)````(N4!``@````LY0$`,@```#7E`0`'````:.4!``\`
M``!PY0$`$0```(#E`0`0````DN4!``8```"CY0$`"@```*KE`0`.````M>4!
M``P```#$Y0$`$````-'E`0`0````XN4!``H```#SY0$`"@```/[E`0`*````
M">8!``H````4Y@$`!P```!_F`0`.````)^8!`!P````VY@$`!P```%/F`0`*
M````6^8!`!0```!FY@$`"@```'OF`0`0````AN8!``<```"7Y@$`&````)_F
M`0`A````N.8!``0```#:Y@$`!P```-_F`0`%````Y^8!``0```#MY@$`#@``
M`/+F`0`%`````><!``T````'YP$`%P```!7G`0`/````+><!`!8````]YP$`
M&0```%3G`0`7````;N<!`!P```"&YP$`%@```*/G`0`'````NN<!``8```#"
MYP$`#@```,GG`0`+````V.<!`!<```#DYP$`!@```/SG`0`(`````^@!`!P`
M```,Z`$`"P```"GH`0`-````->@!`"(```!#Z`$`&@```&;H`0`5````@>@!
M``<```"7Z`$`#0```)_H`0`%````K>@!`!````"SZ`$`$P```,3H`0`&````
MV.@!``D```#?Z`$`!0```.GH`0`'````[^@!``0```#WZ`$`!````/SH`0`#
M`````>D!`#,````%Z0$`.P```#GI`0`S````=>D!`"P```"IZ0$`'0```-;I
M`0`2````].D!`"\````'Z@$`,@```#?J`0`.````:NH!`#P```!YZ@$`+P``
M`+;J`0`T````YNH!`#0````;ZP$`.````%#K`0`2````B>L!`!,```"<ZP$`
M&````+#K`0`3````R>L!`#4```#=ZP$`&P```!/L`0`5````+^P!`!(```!%
M[`$`$@```%CL`0`;````:^P!`!,```"'[`$`%0```)OL`0`:````L>P!`"X`
M``#,[`$`+@```/OL`0`R````*NT!`"\```!=[0$`,````(WM`0`M````ONT!
M`!T```#L[0$`$P````KN`0`4````'NX!``L````S[@$`%@```#_N`0`9````
M5NX!``H```!P[@$`&P```'ON`0`/````E^X!`"P```"G[@$`+@```-3N`0`B
M`````^\!``L````F[P$`50```#+O`0!&````B.\!``X```#/[P$`!0```-[O
M`0`<````Y.\!``P````!\`$`$`````[P`0`2````'_`!``4````R\`$`"@``
M`#CP`0`)````0_`!``\```!-\`$`#0```%WP`0`1````:_`!``H```!]\`$`
M"P```(CP`0`,````E/`!`"````"A\`$``P```,+P`0`>````QO`!``@```#E
M\`$`!@```.[P`0`,````]?`!``X````"\0$`"P```!'Q`0!"````'?$!``(`
M``!@\0$`!@```&/Q`0`-````:O$!``4```!X\0$`!P```'[Q`0`9````AO$!
M``8```"@\0$`+@```*?Q`0`0````UO$!`!T```#G\0$`!`````7R`0`J````
M"O(!`!D````U\@$`'````$_R`0`@````;/(!`%D```"-\@$`%````.?R`0!'
M````_/(!`!D```!$\P$`#@```%[S`0`<````;?,!``T```"*\P$`(P```)CS
M`0`4````O/,!``X```#1\P$`#````.#S`0`2````[?,!``H`````]`$`'```
M``OT`0`9````*/0!``4```!"]`$`$P```$CT`0`3````7/0!``@```!P]`$`
M$````'GT`0`F````BO0!`!,```"Q]`$`%0```,7T`0`2````V_0!`!$```#N
M]`$`&0````#U`0`'````&O4!``@````B]0$`$P```"OU`0`.````/_4!`!(`
M``!.]0$`#P```&'U`0`:````<?4!``\```",]0$`&@```)SU`0`4````M_4!
M``D```#,]0$`"@```-;U`0`(````X?4!``4```#J]0$`"0```/#U`0`&````
M^O4!`!`````!]@$`"````!+V`0`.````&_8!``@````J]@$`$@```#/V`0`2
M````1O8!`"@```!9]@$`&````(+V`0`)````F_8!``H```"E]@$`&0```+#V
M`0`*````RO8!`"(```#5]@$`!@```/CV`0`8````__8!``D````8]P$`!P``
M`"+W`0`:````*O<!`"L```!%]P$`"@```''W`0`?````?/<!``T```"<]P$`
M#````*KW`0`9````M_<!`!4```#1]P$`!````.?W`0`'````[/<!``P```#T
M]P$`!P````'X`0`%````"?@!``@````/^`$`!@```!CX`0`(````'_@!`!@`
M```H^`$`)@```$'X`0`M````:/@!`!H```"6^`$`(````+'X`0`?````TO@!
M`$0```#R^`$`'````#?Y`0`5````5/D!`!T```!J^0$`)````(CY`0!;````
MK?D!`%L````)^@$`2@```&7Z`0`B````L/H!`!<```#3^@$`!0```.OZ`0`'
M````\?H!``X```#Y^@$`"`````C[`0`7````$?L!`!D````I^P$`+@```$/[
M`0`(````<OL!`"(```![^P$`&````)[[`0`?````M_L!`#L```#7^P$`!0``
M`!/\`0`5````&?P!``L````O_`$`#P```#O\`0`C````2_P!`!@```!O_`$`
M$0```(C\`0`.````FOP!``<```"I_`$`$@```+'\`0`'````Q/P!``0```#,
M_`$`#0```-'\`0`5````W_P!`!@```#U_`$`+P````[]`0`+````/OT!`!$`
M``!*_0$`!0```%S]`0`%````8OT!``4```!H_0$`'````&[]`0`&````B_T!
M``L```"2_0$`!````)[]`0`+````H_T!``D```"O_0$`"@```+G]`0`,````
MQ/T!``T```#1_0$`%P```-_]`0`+````]_T!``,````#_@$`#P````?^`0`Y
M````%_X!`$H```!1_@$`"````)S^`0`.````I?X!`!P```"T_@$`"0```-'^
M`0`@````V_X!`!,```#\_@$`!0```!#_`0`1````%O\!`!0````H_P$`$0``
M`#W_`0`(````3_\!``L```!8_P$`)P```&3_`0`,````C/\!`",```"9_P$`
M!P```+W_`0`-````Q?\!``X```#3_P$`$P```.+_`0`9````]O\!``L````0
M``(`,P```!P``@`'````4``"`"````!8``(`$0```'D``@`5````BP`"``T`
M``"A``(`'````*\``@!!````S``"`#,````.`0(`"````$(!`@`P````2P$"
M`"P```!\`0(`-@```*D!`@`W````X`$"`#`````8`@(`$P```$D"`@`6````
M70("``T```!T`@(`#0```(("`@`)````D`("`!(```":`@(`$@```*T"`@`8
M````P`("``@```#9`@(`&0```.("`@`;````_`("`!@````8`P(`$@```#$#
M`@`'````1`,"`!<```!,`P(`(@```&0#`@`%````AP,"``4```"-`P(`"P``
M`),#`@`+````GP,"`!0```"K`P(`!````,`#`@`(````Q0,"``H```#.`P(`
M#@```-D#`@`,````Z`,"`!````#U`P(`$`````8$`@`&````%P0"``4````>
M!`(`#@```"0$`@`-````,P0"`!$```!!!`(`#P```%,$`@`)````8P0"``8`
M``!M!`(`!@```'0$`@`K````>P0"`",```"G!`(`(````,L$`@`#````[`0"
M``@```#P!`(`!@```/D$`@`/``````4"`!L````0!0(`)P```"P%`@`/````
M5`4"``@```!D!0(`(0```&T%`@`#````CP4"`!X```"3!0(`!@```+(%`@`)
M````N04"``(```##!0(`#````,8%`@`5````TP4"``L```#I!0(`&0```/4%
M`@`>````#P8"`!$````N!@(`!0```$`&`@`*````1@8"`!4```!1!@(`$@``
M`&<&`@`,````>@8"``4```"'!@(`"@```(T&`@`(````F`8"`!,```"A!@(`
M$P```+4&`@!,````R08"`!T````6!P(`)0```#0'`@`1````6@<"``D```!L
M!P(`!@```'8'`@`1````?0<"`!H```"/!P(`$@```*H'`@`4````O0<"``,`
M``#2!P(`"@```-8'`@`$````X0<"``H```#F!P(`#@```/$'`@`-``````@"
M`!D````."`(`#0```"@(`@`+````-@@"`!T```!""`(`"0```&`(`@`6````
M:@@"``\```"!"`(`"@```)$(`@`,````G`@"`&````"I"`(`&@````H)`@`1
M````)0D"`!T````W"0(`&````%4)`@`0````;@D"`!@```!_"0(`%0```)@)
M`@`9````K@D"`!@```#("0(`'````.$)`@`5````_@D"``H````4"@(`"0``
M`!\*`@`'````*0H"``@````Q"@(`"0```#H*`@`6````1`H"``L```!;"@(`
M,P```&<*`@`6````FPH"`!@```"R"@(`"0```,L*`@`$````U0H"`$D```#:
M"@(`/@```"0+`@`Y````8PL"`%L```"="P(`&@```/D+`@`%````%`P"`#0`
M```:#`(`)0```$\,`@`,````=0P"``8```""#`(`#@```(D,`@`V````F`P"
M``0```#/#`(`$@```-0,`@`4````YPP"`$P```#\#`(`*P```$D-`@`I````
M=0T"``L```"?#0(`(0```*L-`@`>````S0T"`!<```#L#0(`$P````0.`@`3
M````&`X"`"(````L#@(`$````$\.`@`&````8`X"``T```!G#@(`"P```'4.
M`@`1````@0X"``D```"3#@(`+P```)T.`@`,````S0X"``H```#:#@(`"```
M`.4.`@`0````[@X"``<```#_#@(`"0````</`@`'````$0\"`!`````9#P(`
M"0```"H/`@`)````-`\"``,````^#P(`!P```$(/`@`)````2@\"`!````!4
M#P(`#@```&4/`@`)````=`\"`!H```!^#P(`#````)D/`@`'````I@\"`!$`
M``"N#P(`%@```,`/`@`*````UP\"``D```#B#P(`(@```.P/`@`0````#Q`"
M`",````@$`(`*P```$00`@`)````<!`"``D```!Z$`(`%P```(00`@`'````
MG!`"``0```"D$`(`'0```*D0`@`)````QQ`"``L```#1$`(`"````-T0`@`'
M````YA`"``D```#N$`(`"````/@0`@`)`````1$"``4````+$0(`!P```!$1
M`@`1````&1$"``8````K$0(`*0```#(1`@`.````7!$"``H```!K$0(`#```
M`'81`@`+````@Q$"`!L```"/$0(`"@```*L1`@`"````MA$"`"$```"Y$0(`
M&@```-L1`@`&````]A$"``<```#]$0(`!@````42`@!S````#!("``@```"`
M$@(`!@```(D2`@`;````D!("`"<```"L$@(`#P```-02`@`=````Y!("`$@`
M```"$P(`'````$L3`@`?````:!,"`!(```"($P(`"````)L3`@`%````I!,"
M``\```"J$P(`"@```+H3`@`*````Q1,"``8```#0$P(`"@```-<3`@`2````
MXA,"``P```#U$P(`"@````(4`@`,````#10"``<````:%`(`!P```"(4`@`(
M````*A0"``D````S%`(`%@```#T4`@`)````5!0"``<```!>%`(`!P```&84
M`@`:````;A0"``8```")%`(`%P```)`4`@`&````J!0"``<```"O%`(`%0``
M`+<4`@`)````S10"`!````#7%`(`!P```.@4`@`&````\!0"`!,```#W%`(`
M$0````L5`@`3````'14"``8````Q%0(`!@```#@5`@`*````/Q4"``@```!*
M%0(`!````%,5`@`)````6!4"``0```!B%0(`#0```&<5`@`B````=14"``H`
M``"8%0(`#````*,5`@`I````L!4"`!<```#:%0(`%@```/(5`@`;````"18"
M`!8````E%@(`!````#P6`@`+````018"``T```!-%@(`!P```%L6`@`"````
M8Q8"``X```!F%@(`"````'46`@`B````?A8"`!\```"A%@(`(P```,$6`@`@
M````Y18"`#4````&%P(`(0```#P7`@`G````7A<"`"L```"&%P(`+@```+(7
M`@`W````X1<"`&0````9&`(`$@```'X8`@`A````D1@"`#X```"S&`(`(P``
M`/(8`@!/````%AD"`$@```!F&0(`)@```*\9`@`5````UAD"`#\```#L&0(`
M(0```"P:`@`O````3AH"`"X```!^&@(`)P```*T:`@`G````U1H"`"$```#]
M&@(`-@```!\;`@`;````5AL"`!$```!R&P(`%@```(0;`@!+````FQL"`'``
M``#G&P(`.````%@<`@`J````D1P"`#4```"\'`(`8@```/(<`@!4````51T"
M`"L```"J'0(`'````-8=`@`/````\QT"`"$````#'@(`%@```"4>`@`5````
M/!X"`"T```!2'@(`'````(`>`@`;````G1X"`"T```"Y'@(`'0```.<>`@`]
M````!1\"`!D```!#'P(`#0```%T?`@`N````:Q\"`"<```":'P(`-@```,(?
M`@`I````^1\"`!P````C(`(`(````$`@`@`V````82`"`%````"8(`(`,0``
M`.D@`@!#````&R$"`"P```!?(0(`(P```(PA`@`W````L"$"`&,```#H(0(`
M3````$PB`@`?````F2("`"$```"Y(@(`,P```-LB`@`>````#R,"`"`````N
M(P(`(0```$\C`@`@````<2,"`#0```"2(P(`7P```,<C`@!1````)R0"`#P`
M``!Y)`(`/P```+8D`@`J````]B0"`!H````A)0(`*````#PE`@`M````924"
M`"T```"3)0(`%0```,$E`@"#````UR4"`'<```!;)@(`@````-,F`@#(````
M5"<"`!D````=*`(`(P```#<H`@`N````6R@"`"<```"**`(`1P```+(H`@`B
M````^B@"`%`````=*0(`)````&XI`@`.````DRD"`$$```"B*0(`)````.0I
M`@`N````"2H"`"<````X*@(`)````&`J`@`Z````A2H"``0```#`*@(`!P``
M`,4J`@`#````S2H"``\```#1*@(`"@```.$J`@`'````["H"``@```#T*@(`
M!@```/TJ`@`1````!"L"``0````6*P(`6P```!LK`@`%````=RL"``0```!]
M*P(`#P```((K`@`$````DBL"``<```"7*P(`!P```)\K`@`%````IRL"``,`
M``"M*P(`$````+$K`@`.````PBL"`!,```#1*P(`$0```.4K`@`"````]RL"
M``@```#Z*P(`!P````,L`@`4````"RP"``P````@+`(`%@```"TL`@`&````
M1"P"``\```!++`(`"@```%LL`@`#````9BP"`"@```!J+`(`!````),L`@`&
M````F"P"``<```"?+`(`%P```*<L`@!(````ORP"`"D````(+0(`+````#(M
M`@`7````7RT"`"4```!W+0(`)@```)TM`@`I````Q"T"`!T```#N+0(`&@``
M``PN`@`9````)RX"`!L```!!+@(`&````%TN`@`7````=BX"`!T```".+@(`
M&P```*PN`@`8````R"X"`"<```#A+@(`&`````DO`@`G````(B\"`",```!*
M+P(`&0```&XO`@`=````B"\"`!L```"F+P(`&````,(O`@`>````VR\"`"(`
M``#Z+P(`'0```!TP`@`F````.S`"`"(```!B,`(`&````(4P`@`:````GC`"
M`"4```"Y,`(`%P```-\P`@`A````]S`"`#`````9,0(`,P```$HQ`@`3````
M?C$"`"8```"2,0(`/@```+DQ`@`?````^#$"`",````8,@(`(0```#PR`@`D
M````7C("`!X```"#,@(`&````*(R`@`A````NS("`"````#=,@(`,P```/XR
M`@`B````,C,"`#<```!5,P(`#````(TS`@`/````FC,"`!D```"J,P(`*0``
M`,0S`@`?````[C,"`!`````.-`(`(@```!\T`@`/````0C0"`!4```!2-`(`
M#@```&@T`@`0````=S0"`!L```"(-`(`!P```*0T`@`%````K#0"`"D```"R
M-`(`)````-PT`@`7`````34"`"(````9-0(`)````#PU`@`'````834"`-0`
M``!I-0(`#````#XV`@`4````2S8"``D```!@-@(`#````&HV`@`<````=S8"
M`!,```"4-@(`$0```*@V`@`;````NC8"``D```#6-@(`,@```.`V`@`(````
M$S<"`!`````<-P(`!P```"TW`@`2````-3<"``H```!(-P(`-@```%,W`@`)
M````BC<"`"0```"4-P(`%@```+DW`@`5````T#<"`!0```#F-P(`)@```/LW
M`@`<````(C@"``P````_.`(`'````$PX`@`-````:3@"``X```!W.`(`%0``
M`(8X`@`*````G#@"`!@```"G.`(`"````,`X`@`.````R3@"`"\```#8.`(`
M*0````@Y`@`)````,CD"``\````\.0(`*@```$PY`@`&````=SD"`!4```!^
M.0(`!P```)0Y`@`(````G#D"``D```"E.0(`.P```*\Y`@`'````ZSD"`!``
M``#S.0(`$@````0Z`@`2````%SH"``D````J.@(`"P```#0Z`@`'````0#H"
M`!4```!(.@(`!P```%XZ`@`7````9CH"``L```!^.@(`#0```(HZ`@`,````
MF#H"`!<```"E.@(`&0```+TZ`@`$````USH"``4```#<.@(`&0```.(Z`@`$
M````_#H"`"P````!.P(`#````"X[`@`1````.SL"``<```!-.P(``@```%4[
M`@`,````6#L"``X```!E.P(`"P```'0[`@`$````@#L"``D```"%.P(`$P``
M`(\[`@`6````HSL"``@```"Z.P(`"0```,,[`@`1````S3L"``T```#?.P(`
M&0```.T[`@`:````!SP"``T````B/`(`$P```#`\`@`R````1#P"`!X```!W
M/`(`(P```)8\`@`7````NCP"``L```#2/`(`,P```-X\`@`1````$CT"``X`
M```D/0(`.@```#,]`@`1````;CT"``4```"`/0(`$0```(8]`@!"````F#T"
M``L```#;/0(`"@```.<]`@`&````\CT"``0```#Y/0(`!````/X]`@`*````
M`SX"`!0````./@(`!0```",^`@`&````*3X"``8````P/@(`"@```#<^`@`&
M````0CX"``X```!)/@(`#P```%@^`@`T````:#X"`"H```"=/@(`)P```,@^
M`@`*````\#X"``4```#[/@(`#`````$_`@`,````#C\"``T````;/P(`'@``
M`"D_`@`.````2#\"``(```!7/P(`!````%H_`@`*````7S\"``4```!J/P(`
M!0```'`_`@`"````=C\"`!$```!Y/P(`0P```(L_`@`N````SS\"`",```#^
M/P(`,@```")``@`8````54`"`",```!N0`(`(P```))``@`F````MD`"``\`
M``#=0`(`(````.U``@!>````#D$"`"````!M00(`1P```(Y!`@`D````UD$"
M`$$```#[00(`*````#U"`@`J````9D("`#````"10@(`,0```,)"`@!2````
M]$("`#4```!'0P(`-````'U#`@`J````LD,"`"0```#=0P(`*@````)$`@`R
M````+40"`!````!@1`(`$0```'%$`@`/````@T0"`&P```"31`(`"0````!%
M`@"I````"D4"`%\```"T10(`=P```!1&`@`N````C$8"`%@```"[1@(`%0``
M`!1'`@`C````*D<"`!<```!.1P(`%P```&9'`@`;````?D<"`!\```":1P(`
M.0```+I'`@`C````]$<"`",````82`(`6````#Q(`@`:````E4@"`!(```"P
M2`(`"P```,-(`@`%````ST@"``8```#52`(`"````-Q(`@`%````Y4@"`!(`
M``#K2`(`#@```/Y(`@`,````#4D"`!0````:20(`'@```"])`@`.````3DD"
M`"(```!=20(`(P```(!)`@`/````I$D"``D```"T20(`!````+Y)`@`)````
MPTD"``L```#-20(`%P```-E)`@`?````\4D"``X````12@(`"````"!*`@`&
M````*4H"`!4````P2@(`,@```$9*`@`)````>4H"``D```"#2@(`#@```(U*
M`@`=````G$H"`!0```"Z2@(`#@```,]*`@`-````WDH"`!````#L2@(`!P``
M`/U*`@`'````!4L"``8````-2P(`%P```!1+`@`*````+$L"``D````W2P(`
M"0```$%+`@`%````2TL"``D```!12P(`#P```%M+`@`#````:TL"``@```!O
M2P(`!0```'A+`@`4````?DL"`!4```"32P(`"@```*E+`@`&````M$L"``\`
M``"[2P(`$0```,M+`@`8````W4L"``T```#V2P(`)0````1,`@`%````*DP"
M`!@````P3`(`"````$E,`@`$````4DP"``,```!73`(`&0```%M,`@`)````
M=4P"``(```!_3`(``@```(),`@`/````A4P"``8```"53`(`!P```)Q,`@`&
M````I$P"``\```"K3`(`%P```+M,`@`&````TTP"`!X```#:3`(`!P```/E,
M`@`6`````4T"``(````830(`!````!M-`@`2````($T"`!(````S30(`$```
M`$9-`@`%````5TT"``<```!=30(`#0```&5-`@`&````<TT"`!X```!Z30(`
M#````)E-`@`(````IDT"`!H```"O30(`#P```,I-`@`;````VDT"`!(```#V
M30(``@````E.`@`'````#$X"``D````43@(`#0```!Y.`@`/````+$X"`"L`
M```\3@(`!````&A.`@`'````;4X"``L```!U3@(`!0```(%.`@`"````ATX"
M``L```"*3@(``0```/H$````````1`<```````##!0``V@$``#('```X!```
MK@8```````"`!````````*@```"=````HP<````````E!0``@0````````"(
M!@``K`0```(```";`@``:04``%4#``!+`0``Z@<````````Z`@``4P0``*`'
M``"F!0````````````#)`@``VP8``"P&``#$!```:P@``-T!``#H!0``A`(`
M``````!8!```=00``%$````&!````````.4"````````%`8``/\$````````
MDP4```X'``!T`P```````+4!``!C````:08``#<`````````U@4````````_
M`@``J@$```````!<!@``<0@``````````````````!<%```4!P``1@4``/H%
M```R`@``9P<``,@$``"K!P``)`<``&$!``"X`@``^@(```$%``",`0``90@`
M````````````AP$``)D(``#B`````````"8$``!8`0````````````"G`P``
M'0```%L'````````V0(`````````````100``````````````````%L#``"U
M!```JP,```````!E!0``````````````````X`0``)`'``#A!P``'P<``+0&
M```F````UP$``````````````````*X```#L`0```@,```````!-`P``D`4`
M`,D'``#I!@``3@@``'@$```"!0``!`8``'L!``!2!P````````````!H`0``
M/P@``',`````````ZP$``-@$``"M!@``JP```-\!```C````4P(```````#T
M!0``=P(``+\"`````````````"4!``"Q!0``N00``,D%``!G!0``B`0``#4$
M````````+P4``&T&````````\`<``'$"````````W`(``+L#``!B"```````
M`/$!````````U`4```````!5!0``!`@`````````````:P````````"_!@``
M5P(``/4```!W`P``GP8``$X```"1"```U@```%X#````````000```````!U
M!P``G`<``.$#``"+````JP$``'L'```R!@``H@,``$\(```*`P```````(H$
M``!1!P````<``"@(``"'"```A08``/X&```&`@```````'L%````````8`,`
M``0%``"D!````````'H#````````^P<```0```#0`P``,`,``'X#````````
M`````!D!``#4!```(@@```````!^!```(00``,\%``#?!P``.P$`````````
M````5@@``*L&``!#!@``"````*T"````````(0```.$!````````+0```,0`
M``".`P``)P$``*4!```+!0````````@!```K!P``S`$``(\#``#F`P``BP,`
M````````````````````````````B@<``%`$``#V!P``E00```8!````````
MEP,``.X!``!L!0``"00```8&``!*`@```````'<'````````NP0``'L"``!M
M`0``IP8``#P!````````]08``$<(``![`P```````#,#``"?!0``ZP0``.('
M```=`0``&@$``#,(````````=0@``.\&````````O@,``)0#``#.!P``E0@`
M`-T&````````>0```)P#```2!P``M0```)X(``#5`P```````!D#``"4`0``
M/`<```````#D````\`(``!8"````````WP0``'P'```/!0``MP$``#X"````
M````+P@``"L`````````50$``$\!````````H04``-$```"D`P``/0$``"X&
M```E!P``+@@``(X%``!]!@``A@<``+0```!>!0``S`8``.@!``"V`P``2P(`
M`&P$``![!```O04``+H"`````````````*@&```2`0``#@````$#``"Z`0``
M``````X$``"'`@```````+X$````````20```%0$``!Y!```K`(``*@%````
M````I0<``&$'``````````````````#*`P``]0(````````8!0```````-4`
M``!A`P``I`8``/T!````````$P@```@"````````I@,`````````````@0,`
M`$X"``!_!0``(P4````````X!0``^`,``.X&``".!P``VP<```````!3`0``
M`````!4&````````Q@4```8%```3`P``)P```#T#``#M`@``S@`````````#
M!@```````)D"````````V0<``!P%``"T`0``"@0``$8&````````G0@`````
M``"A!```N@<``+H#```_!P``=`<``#L#``!S!P```````&4````F"```````
M`&P```!"`@``X04``$D(``!W"```@`<``!L`````````3@8``.L%``"+`0``
M`````+<$``"O`P``*0$``.4!``!B!P``>04``)H'````````I@@``)\```"*
M!@``&0<```````#A`@``U`<```````````````````````#Q````7````&$`
M```Z`0``3P(``(8&``!;````/P```$`!```Z!P````````````#<!```````
M``````!3!P``&0@``$(!`````````````-T$``"O`@``=P0``$0%````````
MD0,```````#Q!P``QP(``/T%``"W!@``3`,``!L%```0!0``(@4``(@`````
M`````````),&``"P````B@$``-0"``"_!```,@,````````:!```800`````
M``"H!```S04``(`#``!H!0``80(``/X!````````B08````````4````(@0`
M`/X%````````EP8``-D```!@`@``?0$``&8"``#3!0```````-P```"X!0``
M)P(``($&``"2!````````.,#````````8P(``/$#``#``````````*@(````
M````G@$``%T```#%`@```````.D%`````````````+<#```F!0```````"8!
M``!=!```VP4``,D&``#5!@``O`$``'<```"#!```00@``)D!``!Q!@``````
M`$0`````````B0<``-H&``!(`0````````L"```>!```I@8``+@````K!```
M?@<``!4%``!Y"```!0```/@'``!D`0``10`````````?!0``,08``%,%```2
M"```]@4``'\'````````.P````0$````````=0,``.<#```5!```*0,``.H#
M```M"```O`4``"`%``#'!0``1@```*T$``#S`0``>0,``$0!````````````
M`!\"``#E`````````#<%``!H"```.@@``(T%``"H`@``+P0``,P"``#H!@``
M[````%D#``!)!@``BP<````````T!```(0<``*$&```'!````````)T#``!\
M`0``Y`4```H%``"U!@``B`<``$T'``"^!0``708``,T'````````C0``````
M``#6!@``5`$``)4&```(!`````````````#A````R`,``"L"``````````4`
M`#0!``#N!0``U0<``&T%````````]`,``(4"``!G`@``K@<```````!^`0``
M`````&\(``!U!@```````'D'```.`0``9@8``+`'``"@!```7P<``.,$````
M````LP```,`$``!^``````````````"=!```#P(``*,%````````IP@`````
M````````?P(``*($`````````````*@'``"7!0```P,``&D````\"```````
M`+P&``#Q!0```````(\&``!\!0``C`(````````*`````````$<$````````
M$`(``,L"``!#`0``F0```-`"````````J`$``````````````````$X%``!7
M!```5@$``#<"````````T````````````````````-H"````````GP$``'('
M``">!@``"P````````#'!P``#0<```````#^!````````%0&````````````
M`!(%```@"```T0<`````````````=0```````````````````/,$``"=`0``
M``````````#1!0``-P0```````#.`@``AP8``.8!`````````````*D#``!+
M!```L0$`````````````&@@``%`"`````````````*D(```\````X@$``/8`
M```(!0```````,0!````````Y@```*P```"6!@``TP```.D````E!```'@(`
M`&\%````````]@8``!\!``#P`0``C`4``*("``"J``````````````!7"```
MEP```$8'```H!@```````(\'````````9@$``````````````````(0%```#
M`0``A0$``"<&``#E!@``M@(``'\&``"N`P```````)T&````````5P,``!X!
M```V!P``!0,````````J!```:`<``/@%````````L@0``",&``#T`@``>`<`
M`-H$``#D`P``V0,``'````!2!```@@(``/($``#6`0``:00````````E"```
M7P````````!L`0```````-("`````````@(````!``##!```.P<``$H'``!X
M"```O`<``',"``"F`0``J0<``-X'``!P!0``W`<```````!"`P```````$`%
M`````````````,`%``!9!0``O@<``#\#```/!```$`,``%((``!("```````
M``````#?!0``C00``#D'``"[!P``1P8```X(``````````````````#+!P``
ML`4``&(`````````9P```````````````@8``&4$````````R`4``#$%``!<
M!P``UP0```````">`@``EP(``/````"?"```*`0``-`%````````70@``)$'
M``"8"````````/$&``"<"```L@,``!T$``"N`@``00$`````````````QP``
M````````````9`@``(,%```)`0``H`@````````K`0``U04``+L%``!F!P``
M/@4````````#!```Y@4``!4"```.`P```````%X"``"5````%`0``"D```!#
M!````````&L$`````````````)@&```3````!P4``$$```!-````!@<``+4#
M```+`P``I@<``&4!``#``@``)@8``%\#```C!```^P,``"X"``!$!@``6@(`
M`#H#``#_!0``.@8``(`"``!N````&`$``#P$``"8````(`$```X&``"-`P``
M[`<``/`&```!!P``*````"0```#-!@``!0(``!8%````````@@4``"8#``"4
M!P``+0(````````B````%@0``.P%`````````````'\#````````J@<`````
M````````[0```$@"```J!0``E0<```````#6`@``.P4```````"\`P``AP4`
M`-X#```L````'P0```,(````````\@<``)H#``"8!0``*@,```````#B!```
M?@8``%D'````````9P0``)8%````````5`4```````!C`P```````-('``#\
M````*`,``%4$``"Q`````00``(,"``##`P``<0,``)P$``"5!0``?0<``$@$
M``````````````T```"*!0``400``#<#``#2!````````#4&````````````
M`#,"```I!@`````````````[!@``Y04``)\'``````````````````"0`0``
MP@$```````#U`0``%@@``*$#``"3"```T00``"0%``"/!`````````````!%
M`0````````````",!```^P$``"(#``#_````60````P!``"E!@``.@```-0#
M``"0````8````"$&``#[!@``;P,``$`(``#.`P``:0@``.H%````````ZP(`
M`%8$```'!P``=`8``$X!````````1@$```````"B"```;0@``#D%````````
M.0$``)H%``#,!P``#P```"$"````````Q0```#$`````````80@``*@#````
M````Y`8``,(````=!P``D@4``#@&``#I`P``0`(```````!<`0``]P4``.<!
M```)!@``-04``(D```"]`@````````````#.!```XP(``-8#````````FP8`
M`$P````9!@``!00``"P!``!F`````````/T'``!A!@``+P<`````````````
M`````&L'`````````````&H!``!9!```M`0``(<$``"A"````````%H```"&
M!0``JP(````````,`````````/(&````````"0,``*4(```A`0``=@<`````
M``"1!0``704``*8````>````'`0``.,'``#]!````````/D`````````````
M`%0"`````````````)\"``"P!@``O0```%`%`````````````&D!``#Z`P``
M[@0``&$%`````````````)4"``!9`@````````````#0!P``E`(``,\"``#-
M`0```````&<#````````3P,``($"``!:!```=04``-X"````````$P<``!X&
M``#L`@````````X"`````````````&L%```P````L@4``#`(``#/!```````
M````````````.`@``#@!````````3P4``*X!``#3`@``5`,``/\"``#B!@``
M=P8```````"8!P```````!,&``#&!@```````#8"`````````````"(!``!$
M`@``_`$``$H```"8`P``L`0``),```!H`P``P00``"(&```Y`P``G`$`````
M``!)!0````@``(H(``!;!```_@,``"D$````````!04``$,"````````9`0`
M``4!``#M!```````````````````:P,```L$``#``0``X@(``!D$````````
M``````,%````````^@````````!V````T08```````"Z!```H`(``&8%``!+
M!P```````"P'``#*!`````````````"9`P````````L(````````7`,`````
M````````Y00``.,!```R"```L0(```4&``!9`0``O@8``'4"``!N!P``+08`
M``P"``#^````5P4``*$"``!X`0``=P4``+D````S!P```````+8&```-"```
MJP0```````!L!@``J0$``$,````P!P````````4(```3`@``?@@``%``````
M```````````````:`P``E`@``'P$````````V@,```````#%!0``H`8``%T"
M``"_!P``P08``#8#``#[!0``9@,``*L%````````9`<``+D'```)````````
M`)P"``"#"```C08``#\!````````,@$``#($````````#00```````!%`@``
M`````,H%``#0!@````````L&``#Z`0``60@``*\!````````_0,```````#]
M!@``MP4``,L$``!@"```00,``/<&``!&"```X`,``+,"``#)`P``YP4``&`&
M```>!P``.`,`````````````L08``%<'``#(`0``40@``+8'``"U!0``-0@`
M``````!;!@``W@4```D%``"+"```)P0``&\!``!\!@``Z`(```````!P!```
M`0$``)8$``!#!P```````/X'````````&@8```````#\!```8@8``,L!```;
M`@``Q`(``#L$``"3`0``G@<``%L%``"4````J0```,4#``""`P``Q@,``#P&
M```I!P````````````"I`@``IP4``*T'````!@```08``.8&```B!P``40$`
M``````"9!@``````````````````&````$\&```Q`@```````*\$```X````
M_`,```````#_`P``O00``#D$``#V!```+`@```````#-````"@<``-P!``#W
M!P````````P%`````````@@``-(#``!_"`````````\(```0!P``(`(``,H&
M``"@`P``U`$``$``````````'P,``.$&``!1`P``8`$``#T%``!$!```\P``
M`%(#````````K0$``````````````0(``%L!``!M!````````$<#``#G!P``
M`````%T!``"!!0```````-H'``!4`````````,0#``"2"```<`,``&H```#8
M!0`````````````^`P``TP8``.L```".````/`(``,T"````````YP8``.P$
M`````````````-L#````````<@```$$%``#\!P````````<#``#>`0``````
M````````````CP```-T"````````*`<```@(``!Q````!@,``"4&``!R`P``
M`````)L(``````````````````!2````&@```$T!````````)`8````````G
M"```SP,``/8!``#?!@``,`(``-0```!:!0```````+L```!D````O@(```0"
M````````4`$``&H#``"6!P``HP$``.D"``!,!@``6`(```8```#(!@``J@(`
M`"L(``!M!P``'`8``'L&``")`0``I@(```````!J!0```P<``"X'```<"```
M`````-0&``!T"````````.T'``!(!@````````````"S!P``E@@``!4```!_
M`````````-,#```@!P``F`0``&X!``"E!0```````'X%```^````HP0``.\'
M``"=`@````````('``"."```'@,``%X&``!P`0```````%P$``"L!0``.P@`
M`$H!``"D!P```````*`%``#?`@``'`,``%\(``"J!```4@8``/$"```R!0``
M8@0`````````````L@8``(`````7`P``<P,````````,!````````"<%``"E
M````6P(``"0#``!T`0``\P(``)P&``#R`P``7`4``#<'````````>@```'X"
M`````````````!D"``#(`@``-P8````````V`0``I`$``/\!```Q!P``````
M`,$%``"/`@```````,`#`````````````"<'``!(!P``[P(```````!T````
M`````!0"``"=!P``Q@0``.`"````````9P8``#\%``!E!@````````````")
M!0``70<``-H```#W`@``<P@``"("```1`@``>`````````!3`P```````-<`
M``!*!0``&@<``!$'````````]P$``.X```"C`P``6@8``*H%```Y"```Z@(`
M`)X```!-!0``VP````````"1`@``T@8``)L$``"`!0``LP4``&D#``#'!@``
MN@8```D"```(`P``A`,``/`$````````B@(``#0#````````SP8``.D$```&
M"```QP0`````````````)0(```````#J`0``ZP,``%4'````````,`8``.X"
M``"%!0```````'H$`````````````!$&```-`P```````"`$```_!@``IP<`
M``````".`0```````"T%``"8`0``O@````````##!@```````'L```!F!```
M`````(H``````````````.0"``"6`@````````````"4!````````-,$````
M````/P0``.L'```S!```;0(``($!``";!0``,00``(X"``"S`P``)0,`````
M``"%`P``'````+\```!V"```AP```'T#```4`0``C0<``(4```#?`P``````
M`.P&``!5"```[08```````""!P``.@0``+P"``#+````F00``+T&``"0"```
MRP,```````!%!0```````"$%```2````F@@``&,'````````$`8``!$!````
M``````(``-(```!&`@``0`8``!8#``#Y!0``:`(``)`#``"B!@``.@4``"X#
M```U`P``@00``%$"```W`0``L`$``$,(```W"```NP(``)P%``"&"```A`8`
M`"4```#-!```$0,``````````````````/8#``!0!@```````$L```!\````
M<0$``*<!````````\P8``+$$````````P@0```````#C!0``5`<``%@&````
M`````````-@#``!,!P```````+,!``#=````L0<``$L#``!Z!0``5@8``,$"
M```C`0```````!@(```F!P``V`8``&T#```^"```?0(````````8`@``````
M`,H'```*"```D`0``&0"````````90,``$T$``"2`0```````'8&````````
M``````````!*"```%P<````````'`0`````````````<`0``6P@``$@%```$
M!P``H0```,0%```N!```[P4````````L`P``+`0```P'``!X!0``XP8``*0%
M`````````````&P"``!:!P``U0(``/@````>!0``%`,```P&``"P`P``Q@$`
M``X%```0!````````(L&``"\!```\@````````"M`P``K04```````!`!```
M5@,``*,&```K!0``WP```.@'```D`0``]`8``#0%````````"P$`````````
M````@`8``/<`````````;`@```````!I!P````````````````````````\'
M```=`@``X`<``(\%```?!@```````!$````C!P``E@```"\```#,`P``U@<`
M`"H&````````BP(``$P"````````2P8``$L%```T!@``J@,````````2!```
M`````'((````````,`4``/@&```6`0``Q00````````C"```?04``-X$``"]
M!P``P@8``)H$`````````````+8```"!"```K@0``)`&``">`P``,P8``%P(
M``"-`@``/`4``#,`````````-0```%8'```Q`P``$@8``"\"``!N`@``````
M```````Y`@``````````````````\00````````X!P``8P4``!<&``"&`@``
M:P8``"H(``"Z!0``SP$``*X%``"C`````````(@#``"""```YP(``+(```#U
M!0``7@@``,,!``!3"```+P8``,P````'`@``[0,```````!I`@``0@8`````
M``!Q!0``S0,``"\!```<`@``\`,```````")`@```````/H&``"`"```20$`
M`$D#````````Z`````<```!T!````````!<(```L`@``P0$``)X%``"X!P``
M]00``$8#```:`@````````,```#N`P```````%P"``""````D@8``"P%``!"
M!0``!`,``#4"````````:@(``(0(``"$`0``(0@``*\%``"1!````````)H&
M``"G````*P8```````#1`0``E@,``#8&```(!@``70,``!P'```8!P``````
M`,$#````````\P<``(<#``":`0``<P8```````"#!@``Z@```.0'``!R!@``
MN`0``#$!``"Y!0``N`8``"X``````````````-T'``"T!0``O````'<!``"<
M`````````.4#````````=@(``!0%``#*`@``*04``"@!```V!```F@(`````
M``"S!```E0$```````!\`P``>@@``(D(``!]!```!P8``!8'``"W!P``CP$`
M``````!V!0``[`,``,<!``!7````404``.8"``#K!@```````)('``!0!P``
M@P```(0`````````*`4```@'`````````````)$&``#%!P``9@@``#4!```M
M!```D@,``#T```!!!@``N0(``,H```"2`@```````-H%```N`0``M0(`````
M``!X`@``]P,``/0`````````S@$```````#E!P``6@$``/D$``"[`0``>`,`
M`',!```%!P``6@@``,`&``#@!0```````(P#````````'P@``(@(````````
M[P```,8"``#B`P``"0<``'8!``#J!@``:@0``*0"````````Z`,``#X!```*
M`0``Y@0``&(!``!O!P```````.T%`````````````)$`````````308``"D"
M``#W!```+@4``,\````/`0````````````!>`0``P0<``!$(```V"```I`@`
M`'D!``!R`@```````&`$````````T`0``!<"``!V`P``<`<```````!Z!@``
MVP0````````M`P```````)8!``"A`0```````!L#````````0P4``)X$````
M````^`0``+@#``!!!P`````````````[`@``EP<`````````````200``$$"
M``"(!0```````*$'``!T!0``"@8``&0#````````/0(``/4'``#8````````
M`$4#````````\P4``&@```#D`0``A0@`````````````E`4```````!-`@``
M`````*,"``#_!@````````````#[!`````````````"&`P```@$````````^
M!```108``*D%```;!@``*`(``!<```#&````M@$``-$#````!```\`4``)L'
M``##!P``M`(```````#*`0``8P@``,('````````YP`````````=!0``````
M`!4!``"?!````````.H$```T`@``(````/,#```0````KP``````````````
MYP0```````#+!@```````'D"``#<`P``S@8``-X&``#Y!P``H@4```L'````
M````HP@``'T```"4!@``6`,``$H&````````;@8``%4"```M!P``&`8``!$%
M``"J!@``S`0````````A`P``;@,```````"#`P```````/T"``"L!P``,0@`
M`.D!```;`0``C@0``.0$```P!```O0$``)`"``#<!@```````,,"````````
MN@```,\'``#^`@````````````!G"```&`,``+(!``!N"````````)D%``#5
M!```!`$``!$$```@!@``@@8````````T````A00``'H'``"D````S@4``'D&
M``!$"```_`8``"H!``!""````````!0(``!E`@```````'T(``!["```````
M````````````3`4``(,'``!?!@``;@4```````!S!```8P$``!8`````````
M`````'`(````````H`$``+("``!9!@```````(<'````````;P(``%\!````
M````0@0``+$#```7`0``:P(``/8"````````;0```&\$```D"```%0@``%<&
M``!P!@``4P8``(D$```2`@``8`4``*\&``"U!P```````%@%````````I00`
M`!H%``"3`P``/0@```````#\`@``8@(``%8`````````P@(``/("``"B`0``
M&0```,8'``#X`0``3@,``/L"````````B`$``!@$``#C````X00``/\'``#3
M`0``?P$```````!B`P```````&4'``#M`0``$P$``%`#`````````````$D'
M``!4"```DP<``!<$``"(`@``>@(``),"``#8!P``J00``)4#``""`0``#08`
M`,,``````````````"\#``!(````4@4```P#``!R!```````````````````
M```````````J`@``1@0``(L$``","```P`<``````````````````*8$``"T
M!P``X`8``'8$```J`````````!`(``!+"`````````````"B!P``0P,``(P&
M``#"!0```@0``-D$````````7@<```````#]````%0,``%("``!C!```UP(`
M`%4`````````W`4``",#````````;`<```````#)````'@@``),$````````
M[P$``)<$````````5@4``#@"``#=!0```````%`(````````N0$`````````
M````\@4``'4!``!O`````````%@```!/````.0```*P&``#2`0``````````
M````````-@4``%<!````````L@<``#8```"#`0`````````````]!P``"0@`
M`$(```",`````````$D"``#T`0``V04```````#%!@``LP8``%(!``#"`P``
MW0,```````"V!````````"0"`````````````+L&```;!```A0<``%X`````
M````#P,``-D!````````]`0```````#7!P```````&@$````````UP4``(L%
M``!>!```/08````````K`P``408```````````````````````#$!@``````
M`$4(``!,"````0@``-<#``!G`0``#0$``%4&``!3````D@````````"&!```
MC`<``#T$`````````````!8&``":````<0<``&H(`````````````+D&``"]
M`P``G04``$X'``#Y`P``:P$`````````````#04```````#3!P``,@```(T!
M```````````````````="````````.`!``#8`0``30@``%H#``!Z`0``QP,`
M`-@"``#O`P``10<``-L!``!.!```<P4``#X&``#1`@```````+X!``!'`0``
M/`,``"0$``"*`P```````+\%``"7"```N0,``,@'``!_!````````'$$```3
M!```I0(``,L%``"W````Q`<``-<&``"L`0``#P8``'(!`````````````$<"
M````````'0,``+`"`````````````/P%```5!P``/@<``&0%``"M````Y@<`
M````````````9`8``,P%``#Y`0```````(X&`````````````*L(````````
MA`<``,@```#>````*0@```H"```?````-0<``$('``#[````;P8`````````
M````7P4``#0(``";`P``P0```'(%````````CP@``+\!``#;`@``$@,`````
M``#Z!P```````"H'````````,P4``,4!``#0`0```````)L``````P``````
M`/D&``"X`0``OP,`````````````H@```$<`````````7P(```````#I!P``
MM`,``)L!````````2@0``"`#``"``0```````-D&``"&````)P,```````"G
M!```K`,``/(!````````Z`0``````````````````%\$``!8"```U@0``)<!
M``!6`@``IP(``&(%```,"```2@,``.\$``"O!P``<`(```````!\`@``````
M`!,%```9!0``^`(```````!J!P``&P@``$0#``"$!```:@8```````"J"```
M:`8````````;!P```````&`'``!\"```.08```````"1`0``^0(``*````!X
M!@``[@<``-4!``"!!P```````!T&``#2!0``M@4```,"``"8`@``1P4``#0'
M``!T`@``6`<```<(``"9!P``GP,``*4#```````````````````-`@``3`$`
M`","````````)@(```````!C!@``0`,``$P$````````X`````````#B!0``
M,`$``$<'```0`0```````$`'``!(`P``A@$``,D!`````````````/0'``#)
M!```B0,``/4#``!N!`````````````!L`P``C0@``$\$``"I!@```````#,!
M```M`0``@@0``+<"````````3P<`````````("8C,34Q.R`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*%)E
M860@;VYL>2D`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@
M*'EE<W1E<F1A>2D`(&%N9``@870@`"!O<@`B)7,B(&ES(&YO="!A(&1I<F5C
M=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@
M<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS
M('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@
M9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E
M8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S
M(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI
M<W1S+@`E<R!A="`E<R`E<P`E<R!H87,@8V%N8V5L;&5D("5S+@`E<R!H87,@
M<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E<R!H87,@<F5P;&EE
M9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S('-E;G0@>6]U(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T
M:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C
M:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E
M<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S
M`"5S(&YO="!F;W5N9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S
M('1O("5S(&]F("5S`"5S('=I<VAE<R!T;R!A9&0@=&\@)7,N`"5S('=I<VAE
M<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I
M=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R
M97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K
M;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@
M=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY
M(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@
M86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN
M9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM
M`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V
M:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@
M8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!
M32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97!T(')E<75E<W0`
M06-C97!T960`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN
M9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C
M8V]U;G1I;F<`06-T:6]N(&9O<B!B;&%C:VQI<W1E9"!A9&1R97-S97,Z`$%C
M=&EO;G,`06-T:79A=&4@4V-R:7!T`$%C=&EV871I;F<@=&AE('-C<FEP="!F
M;W(@(B5S(B!F86EL960Z("@E9"D@)7,`061D`$%D9"`E<P!!9&0@0VAI;&0@
M1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@
M1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O
M("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1H:7,@
M=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY
M(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D:71I
M;VYA;"!3971T:6YG<P!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A
M=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L
M:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;"!O
M9B!T:&4@9F]L;&]W:6YG`$%L;&]W(%)U;&5S`$%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!
M;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@
M24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA
M=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T
M92!T97AT.@!!;65R:6-A;B!386UO80!!;B!E<G)O<B!O8V-U<G)E9"!F;VQL
M;W=I;F<@=&AI<R!L:6YK.B`E<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`
M06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R
M960`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%N>2!O9B!T:&4@
M9F]L;&]W:6YG`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%P<&QY($9I;'1E<G,`07!P;'D@=&\@0VAI;&0@
M4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@
M*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE
M`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/P!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!
M<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N
M9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`
M07-S:6=N;65N="!C;VQU;6YS`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F
M:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@<V5N=`!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92X`071T96YD965S`$%T=')I8G5T97,`075G=7-T
M`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E
M<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q
M=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E
M<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!
M9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O
M(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE
M9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE
M;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`075T;VUA=&EC
M86QL>2!U<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\`079A
M:6QA8FQE(&9I96QD<SH`07=A:71I;F<@4F5S<&]N<V4`07IE<F)A:6IA;@!!
M>G5R`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N
M`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<B!4:6UE`$)A<B!T:6UE`$)A<F)A9&]S`$)A<F)I90!"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F-C
M`$)E9VEN<R!W:71H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R
M;75D80!":'5T86X`0FEN9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`0FQA
M8VML:7-T`$)L86-K;&ES="!%9&ET`$)L86-K;&ES="!I<R!N;W0@<W5P<&]R
M=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$)L86-K;&ES
M=&5D($%D9')E<W-E<P!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@
M;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)L=64@36]O
M;@!";'5E(&%N9"!7:&ET90!";V1Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`
M0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(
M97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD
M`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)O=VX`
M0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K
M:6YA($9A<V\`0G5R;G0@3W)A;F=E`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`
M0V%M97)O;VX`0V%M;W5F;&%G90!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@
M;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S
M(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#87-E(%-E
M;G-I=&EV90!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`
M0V,`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#
M96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC
M("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI
M8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$
M971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S
M`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R
M9`!#:&%N9V4@9&5F875L="!I9&5N=&ET>0!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E<R!S879E9"X`0VAA;F=I;F<@
M>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E
M;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O
M<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N
M`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H
M;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A
M8W1I;VXZ`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI
M<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)
M<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R
M`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S
M97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA
M=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S
M92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME
M96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R
M9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C
M=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA
M;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`
M0V]M<&QE=&5D`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U=&5R<P!#;VYD
M:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O
M;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE
M<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`
M0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H
M92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE
M9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(&9A:6QU<F4`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`0V]N=&%I;G,`0V]N=&5N="!T>7!E(&]F(&-O
M;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O
M:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@)7,`0V]P>2!F86EL960Z("5S
M`$-O<'D@;V8@)7,`0V]P>2!S96QE8W1I;VX`0V]R;F9L;W=E<@!#;W-T($E$
M`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E
M<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!L;V%D('-T
M<F%T96=Y("<E<R<N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@
M;6MD:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN
M9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@9F]R
M('=R:71I;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<FUD:7(@)R5S
M)RX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@
M=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E
M(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@
M)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U
M;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI
M;FL@(B5S(BX`0V]U;&0@;F]T('5N;&EN:R`G)7,G+@!#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B
M)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S
M97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B
M)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#
M<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E(&YE=R!F;VQD
M97(`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E
M9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S
M`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES
M`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET
M:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I
M;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI
M8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1$E304),
M140Z(`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$
M871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@
M0V]L=6UN`$1E86-T:79A=&4@4V-R:7!T`$1E8V5M8F5R`$1E8VEM86P@;G5M
M8F5R<P!$96-L:6YE9`!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT
M($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET
M:6]N<P!$96QE9V%T92!P;W-I=&EO;@!$96QE9V%T960`1&5L971E`$1E;&5T
M92`E<P!$96QE=&4@0V5L;`!$96QE=&4@0V]N9&ET:6]N`$1E;&5T92!'<F]U
M<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R
M9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E(&-O
M;7!L971E;'D`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@;&EN
M:P!$96QE=&5D`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`
M1&5L:79E<B!I;G1O(&UY($EN8F]X`$1E;&EV97(@:6YT;R!M>2!);F)O>"!A
M;F0@8V]P>2!T;P!$96QI=F5R(&EN=&\@;7D@26YB;W@@86YD(')E9&ER96-T
M('1O`$1E;&EV97(@=&\@9F]L9&5R`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$
M96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$
M97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z
M(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F=`!$:7)E8W1O<GD`1&ES86)L92`E<P!$:7-A8FQE9`!$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D
M(&9O<F5C87-T`$1I<W!L87D@9&5T86EL960@;F]T:69I8V%T:6]N('=H96X@
M96%C:"!F:6QT97(@:7,@87!P;&EE9#\`1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*0!$:7-P;&%Y(&9O<FUA=`!$:79I9&5R`$1J:6)O=71I`$1O(%]N;W0@<V5N
M9"!R97-P;VYS97,@=&\@8G5L:R!O<B!L:7-T(&UE<W-A9V5S`$1O(&YO="!D
M96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``
M1&\@=&AI<SH`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;V5S;B=T(&)E9VEN
M('=I=&@`1&]E<VXG="!C;VYT86EN`$1O97-N)W0@96YD('=I=&@`1&]E<VXG
M="!E>&ES=`!$;V5S;B=T(&UA=&-H("AW:71H('!L86-E:&]L9&5R<RD`1&]M
M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U
M<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U
M9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A
M<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O
M<@!%9&ET`$5D:70@)7,`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R
M;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E
M<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L
M(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M
M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE
M<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L
M92`E<P!%;F%B;&5D`$5N9`!%;F0@>65A<@!%;F1S('=I=&@`16YL87)G92!%
M9&ET;W(`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T
M97)S(&)E;&]W.@!%<75A;"!T;P!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C
M:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E
M;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S
M`$5R<F]R(')E=')I979I;F<@8W5R<F5N="!S8W)I<'0Z("@E9"D@)7,`17)R
M;W(@<V%V:6YG(&-H86YG97,N`$5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+@!%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=W)I=&EN9R`B)7,B
M+@!%<G)O<B!W<FET:6YG("<E<R<N`$5S=&]N:6$`171H:6]P:6$`171H;FEC
M`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C
M=71E`$5X:7-T:6YG(%)U;&5S`$5X:7-T<P!%>'!A;F0`17AP86YD(%-I9&5B
M87(`17AP96-T960@)RDG`$5X<&5C=&5D(#$@;V)J96-T+"!G;W0@)60N`$5X
M<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A
M=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T
M=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T
M;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N
M;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E
M=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&
M87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`
M1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@
M4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O
M;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@
M)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO
M;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL
M=&5R($%L;"!-97-S86=E<P!&:6QT97(@3VYL>2!3965N($UE<W-A9V5S`$9I
M;'1E<B!/;FQY(%5N<V5E;B!-97-S86=E<P!&:6QT97(@3W!T:6]N<P!&:6QT
M97(@4G5L90!&:6QT97(@4G5L97,`1FEL=&5R(%-C<FEP="!$:7-P;&%Y`$9I
M;'1E<B!?4G5L97,`1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA
M=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&1E;&5T960N`$9I;'1E
M<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@;6]V960@=&\@
M=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H
M<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@=V5R92!D96QE=&5D+@!&
M:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA
M<R!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E<B!A8W1I
M=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R;VT@
M(B5S(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R("(E<R(N`$9I;'1E
M<B!N;W0@9F]U;F0N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T
M(%%U87)T97(`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`
M1F]O9`!&;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9"!I
M<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV
M97(N`$9O<G=A<F1S`$9O<G=A<F1S($5D:70`1G(`1G)A;65S`$9R86YC90!&
M<F%N8V4L($UE=')O<&]L:71A;@!&<F5E+T)U<WD@26YF;W)M871I;VX`1G)E
M92]"=7-Y(%)E<&QY`$9R964O0G5S>2!297%U97-T`$9R964O0G5S>2!297%U
M97-T(%)E<W!O;G-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&
M<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G)O
M;3H`1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N
M`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G
M:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@
M3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'
M<F%Y<V-A;&4`1W)E871E<B!T:&%N`$=R96%T97(@=&AA;B!O<B!E<75A;"!T
M;P!'<F5E8V4`1W)E96X`1W)E96YL86YD`$=R96YA9&$`1W)E>0!'<F]U<"!!
M9&UI;FES=')A=&EO;@!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%M`$=U871E;6%L80!'
M=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S="!397)V:6-E<P!'=65S
M=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`
M2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`
M2&5I9VAT`$AE:6=H="`H:6X@<&EX96QS*0!(96QP`$AE;'`@=7-I;F<@961I
M=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O
M9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE
M($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R
M:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K
M+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)
M8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X
M=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R
M<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`
M26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E
M(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T
M97`@)60`26UP;W)T86YT`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T
M(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!)
M;F1I80!);F1I=FED=6%L(%5S97)S`$EN9&EV:61U86P@<G5L97,@87)E(&YO
M="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`
M26YD;VYE<VEA`$EN97AI<W1A;G0@;6%I;&)O>"!S<&5C:69I960@9F]R(&UE
M<W-A9V4@9&5L:79E<GDN`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@
M;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS
M97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T
M(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&-E;&P@869T97(`26YS97)T
M(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M
M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T
M97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!)
M;G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`
M26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N
M9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D
M:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C
M=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV86QI9"!51$@N("A5<V5R($1A
M=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T
M:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D
M+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F
M;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P
M<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG
M(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L
M:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV
M86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@
M<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@
M<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O
M<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M`$ER87$`27)E;&%N9`!)<P!)<VQE(&]F($UA;@!)<VXG=`!)<V]L871E9"!4
M+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA
M;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R
M9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@
M1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+96YY80!+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME>2!#<F5A=&EO
M;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A
M9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!+:61S`$MI<FEB871I`$MO;&%B`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$55
M0RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3$1!4"!S=7!P;W)T(&ES(')E<75I
M<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N
M;W0@;&]A9&5D+@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG
M90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I
M80!,879E;F1E<@!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T
M:&\`3&5S<R!T:&%N`$QE<W,@=&AA;B!O<B!E<75A;"!T;P!,979E;`!,:6)E
M<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H
M="!";'5E`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A
M<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!2
M86EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R
M`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`
M3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B
M;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)1`!,:7-T+4ED`$QI
M<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S
M8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E
M<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A
M;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G
M:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I
M;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,
M;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3&]Y;VQA
M`$QO>6]L82!";'5E`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C
M:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L
M(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-
M86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L
M87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R
M-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R7VL@;65S
M<V%G92!A<R!D96QE=&5D`$UA<F-H`$UA<F=I;@!-87)K(&UE<W-A9V4@87,Z
M`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA
M;F1S`$UA<G1I;FEQ=64`36%T8VAE<R`H=VET:"!P;&%C96AO;&1E<G,I`$UA
M=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E
M9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M($YU;6)E<B!O
M9B!2=6QE<P!-87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!B;&%C
M:VQI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@
M)7,L($UA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE
M=R!A9&1R97-S97,@=&\@8FQA8VML:7-T+@!-87AI;75M(&YU;6)E<B!O9B!W
M:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E
M<SH@)7,L($UA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D
M(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+@!-87D`36%Y;W1T90!-961I
M8VEN90!-965T:6YG($-A;F-E;&QA=&EO;@!-965T:6YG($EN9F]R;6%T:6]N
M`$UE971I;F<@4')O<&]S86P`365E=&EN9R!297!L>0!-965T:6YG(%5P9&%T
M90!-965T:6YG(%5P9&%T92!297%U97-T`$UE;6)E<G,`365N=2!M;V1E.@!-
M97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U
M;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E
M('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A
M<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N
M;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y
M<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER
M960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@
M2%144%]297%U97-T+@!-:7-S:6YG(&%D9')E<W,@=&\@;F]T:69Y`$UI<W-I
M;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O`$UI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A
M9V4@240N`$UI<W-I;F<@<F5A<V]N(&9O<B!R96IE8W0`36ES<VEN9R!R96%S
M;VX@:6X@=F%C871I;VXN`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D
M97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V
M82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R
M`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F
M;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O
M`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%)U;&4@1&]W
M;@!-;W9E(%)U;&4@57``36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA
M;6)I<75E`$UO>FEL;&$`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU
M;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y
M;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$Y?=6UB97(@;V8@9&%Y
M<R!B971W965N('9A8V%T:6]N(')E<&QI97,Z`$YA;64`3F%M:6)I80!.875R
M=0!.95A4`$YE961S($%C=&EO;@!.97!A;`!.971H97)L86YD<P!.971H97)L
M86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!296YE
M=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@
M<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S
M8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D
M;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`
M3F5W(%)U;&4`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`
M3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`
M3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK
M*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T
M:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E
M`$YO`$YO("(E<R(@96QE;65N="!F;W5N9"!I;B!B86-K96YD(&-O;F9I9W5R
M871I;VXN`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N`$YO(&)A8VME;F0@8V]N9FEG=7)E9"!F;W(@
M=&AI<R!H;W-T`$YO(&)A8VME;F1S(&-O;F9I9W5R960@:6X@8F%C:V5N9',N
M<&AP`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE
M(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D
M(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD
M<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S8W)I
M<'1I;VX@9F]U;F0`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@
M=7!L;V%D960`3F\@9FEL=&5R<RX@0VQI8VL@(B5S(B!T;R!C<F5A=&4@82!N
M97<@9FEL=&5R+@!.;R!H96%D97)S('-P96-I9FEE9`!.;R!I8V]N<R!F;W5N
M9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`
M3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU
M;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E=`!.;R!Q=6]T
M82!S970N`$YO(')U;&5S`$YO('-C<FEP="!G96YE<F%T960N`$YO('-E<&%R
M871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-T<FEN9W,@<W!E8VEF:65D
M`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!0
M87)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9F]L:R!)
M<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES
M;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C
M=&]R>0!.;W0@97%U86P@=&\`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO
M="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+@!.;W1I8V4`3F]T:69Y(&5M86EL(&%D9')E<W,`3F]V96UB97(`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R
M9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0
M('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!F;&%G('1H
M92!M97-S86=E`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M
M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`
M3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I
M9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;F%L(%!A<G1I8VEP86YT`$]P
M=&EO;G,`3W!T:6]N<R!A8F]U="!S8W)I<'0@=7!D871I;F<N`$]P=&EO;G,@
M9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N
M86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF
M;W)M871I;VX`3W1H97(@3W!T:6]N<P!/=F5R=FEE=P!/=VYE<B!097)M:7-S
M:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!
M4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC
M<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!2
M86EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N
M`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@
M4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G
M=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S
M=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U
M:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@
M;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0
M96YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D
M96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U
M`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L
M<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE
M;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H
M:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE
M87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&5N=&5R
M('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@<WES=&5M+@!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES
M=&5M+@!0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL
M(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO
M=RX`4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO
M=RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`
M4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F
M;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0;W-T;G5K90!0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R
M("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@
M;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE
M;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R
M;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O
M<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E
M(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E
M9"!B:70I`%)?96%S;VX`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L
M>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O
M(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S
M`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-E:79E9`!2961I
M<F5C="!T;P!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W
M.@!296=E>`!296=U;&%R(&5X<')E<W-I;VX`4F5J96-T('=I=&@@<F5A<V]N
M`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;65M8F5R
M('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I
M;F<`4F5M;W9E(&9R;VT@;7D@8V%L96YD87(`4F5M;W9E('!A:7(`4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5P;'D@4V5N="X`
M4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F
M<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S
M=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DZ("5S`%)E<75E<W0@
M8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E
M<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@
M(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D($9I96QD`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5N="!4
M;P!297-E;G0M9G)O;0!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R
M(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T
M;R!&:6QT97)S($QI<W0`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O(%)U
M;&5S($QI<W0`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#
M;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S
M`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T
M:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O
M=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S
M.@!2=6QE`%)U;&4@0V]P:65D`%)U;&4@1&5L971E9`!2=6QE($1I<V%B;&5D
M`%)U;&4@16YA8FQE9`!2=6QE($YA;64`4G5L93H`4G5L97,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N
M`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%
M($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U1!4E143%,@9F%I;&5D.B`H
M)7,I("5S`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I
M;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A
M;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`
M4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@
M86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`
M4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!3971T
M:6YG<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C
M<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A
M=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!38W)I
M<'0`4V-R:7!T(%5P9&%T:6YG`%-C<FEP="!N;W0@=7!D871E9"X`4V-R:7!T
M('-U8V-E<W-F=6QL>2!A8W1I=F%T960N`%-C<FEP="!S=6-C97-S9G5L;'D@
M9&5A8W1I=F%T960N`%-E87)C:`!396%R8V@@16YG:6YE<P!3965N`%-E;&5C
M="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A
M(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R
M=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO
M;F4`4V5L96-T('1A<F=E="!F;VQD97(`4V5L96-T('1H92!C:&%R86-T97)S
M('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@
M8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C
M="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z
M`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;&8M1&5F:6YE9"!(96%D97(`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N
M9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YD97(`4V5N96=A;`!396YS
M;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.
M=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S
M<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3
M970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O
M<'1I;VYS+@!3971T:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4V5T=7``
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S
M`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E
M(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!!8W1I=F4@4V-R
M:7!T`%-H;W<@0W5R<F5N="!38W)I<'0`4VAO=R!D:69F97)E;F-E<R!B971W
M965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I
M;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K
M97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S
M`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@
M=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEM<&QE>`!3:6YG
M87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA
M`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%
M87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I
M=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N
M9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S
M<P!3;W5T:"!!9G)I8V$`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@
M8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D
M9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET
M(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA
M`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!Y96%R`%-T871E(&]R
M(%!R;W9I;F-E`%-T871U<P!3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M
M871C:&5S/P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T
M:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R
M97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`4W5B:F5?8W0@;V8@=F%C871I;VX@;65S<V%G93H`4W5B:F5C=`!3=6)J
M96-T.@!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U
M97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C
M97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M
M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M
M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C
M8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E
M("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR
M:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``
M4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D
M(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3
M>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H
M('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A
M;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B
M;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE
M<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N
M`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!4
M96%L`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M
M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI
M)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!4
M96UP;&%T92!!9&UI;FES=')A=&EO;@!496YT871I=F5L>2!!8V-E<'0@<F5Q
M=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497AT`%1E>'0@3VYL>0!497AT
M(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA
M;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@)7,@;&EN:R!T;R`E
M<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ
M960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N`%1H92!A9&1R97-S("(E<R(@:&%S(&)E96X@861D960@=&\@>6]U<B!B
M;&%C:VQI<W0N`%1H92!A9&1R97-S("(E<R(@:&%S(&)E96X@861D960@=&\@
M>6]U<B!W:&ET96QI<W0N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9`!4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES
M="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@9')I=F5R('-A:60Z(`!4:&4@
M96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN
M96-T:6]N+@!4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U<B!C86QE
M;F1A<BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!I9&5N
M=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED
M92!O;FQY`%1H92!L:6YK(&AA<R!B965N(')E;6]V960`5&AE(&QO8V%T:6]N
M(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y
M<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T
M;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@
M8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N
M8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T
M;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R
M96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T
M+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1A<VL@
M:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="X`5&AE('1E;7!O<F%R
M>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E
M<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE
M('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`
M5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S
M('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`
M5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U
M;&QY('-T;W)E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E
M(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T
M96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@
M=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE('-C<FEP="X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RX`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S
M+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U
M<WD@:6YF;W)M871I;VXZ("5S+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE
M(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R
M97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@
M=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&%C=&EO
M;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM
M<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI
M9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K
M871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6
M;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E
M<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R
M871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T
M868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H
M:7,@:7,@)7,N`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A
M8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`
M5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`
M5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y('=H:6QE(&-L:6-K:6YG+@!4;SH`5&]D87D`5&]G9VQE($A434P@4V]U
M<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE
M("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E
M(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y
M+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V
M86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G
M86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE("5S+R5S`%5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B
M)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5
M;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S
M+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S
M+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF
M:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5
M;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U
M;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O
M8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N9&QE9"!C;VUP
M;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B
M($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`
M56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@
M<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN
M:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@
M82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y
M;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O
M87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E
M`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S
M97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO
M860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M
M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S
M97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M
M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S
M97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I
M=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@
M(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E
M<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O
M97,@;F]T(&5X:7-T+@!686-A=&EO;@!686-A=&EO;B!%9&ET`%9A8V%T:6]N
M(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R
M:79E<BX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET
M>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H
M92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE
M8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I
M;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R
M960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI
M9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@
M3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!E=F5N=`!6:65W('1A<VL`
M5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`
M5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--
M5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/
M32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`
M5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`
M5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E8F)P;&%T<V5N("T@4V]B97(`
M5V5B8G!L871S96X@+2!3;V)E<B!.15<`5V5E:VQY`%=E;&-O;64`5V5L8V]M
M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T
M97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VA?:71E;&ES="!A
M9&1R97-S97,Z`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L
M:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:&ET96QI<W0@
M161I=`!7:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N
M="!F:6QT97)I;F<@9')I=F5R+@!7:&ET96QI<W1E9"!!9&1R97-S97,`5VED
M=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T
M:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I
M;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES
M9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!6
M1E,@9FEL92X`6"U0<FEO<FET>0!8+5)E9@!8+5-P86TM3&5V96P`6"U3<&%M
M+5-C;W)E`%@M4W!A;2U3=&%T=7,`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M90!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY
M`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!R=6QE<RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;W(@961I="!C=7-T;VT@<G5L97,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T
M960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U
M<B!F=6QL(&YA;64N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO
M=2!H879E(')E8V5I=F5D(&$@;F5W(&UE<W-A9V4`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@96UA
M:6P@861D<F5S<R!F;W(@=VAI8V@@=&AE('9A8V%T:6]N(&UE<W-A9V5S('-H
M;W5L9"!B92!A8W1I=F%T960N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U
M<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O
M<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@
M3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T
M;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I
M9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S
M+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U
M<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA
M<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F
M=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A
M<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O
M<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E
M<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y
M`%M(:61E(%%U;W1E9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061D<F5S<RAE<RD@=&\@9F]R
M=V%R9"!T;SH`7T%D9')E<W-E<R!T;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z
M`%]!9&UI;FES=')A=&EO;@!?0FQA8VML:7-T`%]#3$D`7T1A=&%4<F5E`%]$
M96QE=&4@4F]W`%]$96QE=&4@;65S<V%G92!C;VUP;&5T96QY`%]%;G1E<B!E
M86-H(&%D9')E<W,@;VX@82!N97<@;&EN93H`7T9O<G=A<F0`7T=R;W5P<P!?
M2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?2V5E<"!A(&-O<'D@;V8@;65S
M<V%G97,@:6X@=&AI<R!A8V-O=6YT/P!?3&]G(&EN`%],;V<@;W5T`%]-;V1I
M9GD@3&EN:RXN+@!?36]V92!M97-S86=E('1O(&9O;&1E<CH`7TUY(&5M86EL
M(&%D9')E<W-E<SH`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN
M:RXN+@!?4G5L97,`7U-C<FEP=`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N
M+BX`7U5S97)S`%]686-A=&EO;@!?5VAI=&5L:7-T`&%C=&EV90!A9&1R97-S
M(&)O;VL`861D<F5S<V5E('5N:VYO=VX`86YD`&-A;&5N9&%R`&-A;&T`8V%N
M;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC
M:R!H97)E`&-L;V-K`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U
M<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T
M82!F;W)M870@97)R;W(`9&ES86)L960@+2!C;&EC:R!T;R!E;F%B;&4`961I
M=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:65L9`!F:6QE`&9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK
M;F]W;@!I;6UE9&EA=&4`:6YA8W1I=F4`:6YL:6YE`&EN<'5T+V]U='!U="!E
M<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6%I;&1R;W`@
M<V-R:7!T(&=E;F5R871E9"!B>2!);F=O`&UA=&-H`&UK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE
M;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;W(`<&5R8V5N=`!P
M97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<')O8VUA:6P@<V-R:7!T(&=E;F5R
M871E9"!B>2!);F=O`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`
M<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-I979E(&9I
M;'1E<B!G96YE<F%T960@8GD@26YG;P!S;7,R96UA:6P@=FEA($A45%``<W,`
M<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU
M<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O
M:F5C="U)9"U697)S:6]N.B!)3D=/(#$N,0I297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-BTP,BTQ-"`Q-CHR,RLP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M
M,30@,38Z,S`K,#$P,`I,87-T+51R86YS;&%T;W(Z($IO87%U:6T@2&]M<FEG
M:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/@I,86YG=6%G92U496%M.B!3
M=V5D:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R
M;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3L*`"`F(S$U,3L@)7,@
M:V]M;65R(&%T="!U=&;V<F$@9&4@=6YD97)HY6QL<V%K=&EV:71E=&5R;F$@
M<V]M(&UA<FME<F%T<R!N961A;BX`("@E<R!D86=A<B!S961A;BD`("AS;F%B
M8G1A;F=E;G0@)7,I`"`H4VMR:79S:WED9&%D*0`@*&]M("5S(&1A9V%R*0`@
M*&ED86<I`"`H:6UO<F=O;BD`("AI9^5R*0`@;V-H`"!K;"``(&5L;&5R`"<E
M<R<@Y'(@:6YT92!E;B!K871A;&]G+@`G)7,G(.1R(&EN=&4@971T(&=O9&OD
M;G0@=F%L+@`G)7,G(.1R(&EN=&4@:V]N9FEG=7)E<F%T(&D@2&]R9&5R96=I
M<W1R97)T+@!4<N1D:&%N=&5R87)E;B!F]G(@)7,@<V%K;F%S+@`G)7,G(&QA
M9&5S('1I;&P@:2!G<G5P<'-Y<W1E;65T+@`G)7,G(&QA9&5S('1I;&P@:2!B
M96CV<FEG:&5T<W-Y<W1E;65T+@`G)7,G('-K87!A9&5S(&EN=&4Z("5S+@`E
M+C)F34(@86YVY&YT(&%V("4N,F9-0B!T:6QLY71E="`H)3)F)24I`"5D("5S
M(&]C:"`E<P!$:71T(&SV<V5N;W)D('5P<&CV<B!A='0@9^1L;&$@;VT@)60@
M9&%G87(N`"5D+61A9W-P<F]G;F]S`"5S("T@1O9R(&OD;FYE9&]M`$9I;F=E
M<G!R:6YT(&;V<B`E<P`E<R!+0@`E<R!5;F1E<FCE;&QS9G5N:W1I;VX@+2!"
M96MRY&9T96QS90`E<R!3971U<``E<R!A;FWD;&%N`%1JY&YS=&5A=G1A;"!F
M]G(@)7,`)7,@9FEN;G,@<F5D86XN`"5S(&ML("5S("5S`"5S(&AA<B!A;FYU
M;&QE<F%T("5S+@`E<R!H87(@<W9A<F%T('#E(&5N(&)E9^1R86X@;VT@:6YF
M;W)M871I;VX@86YGY65N9&4@;&5D:6<O=7!P=&%G96XN`"5S(&AA<B!S=F%R
M870@<.4@:6YB:G5D86X@=&EL;"`E<RX`)7,@:&%R('-K:6-K870@9&EG(&EN
M9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N+@`E<R!K;VUM97(@871T('5T
M9O9R82!D92!U;F1E<FCE;&QS86MT:79I=&5T97)N82!S;VT@;6%R:V5R871S
M(&YE9&%N+B!-87)K97)A(&1E(&%K=&EV:71E=&5R('-O;2!D=2!V:6QL('5T
M9O9R82X`)7,@:W+D=G,`)7,@;6EN=71E<@`E<R!S86MN87,N`"5S(&5F=&5R
M9G+E9V%R(&EN9F]R;6%T:6]N(&]M(&[D<B!D=2#D<B!L961I9R]U<'!T86=E
M;BX`)7,@969T97)F<N5G87(@9&EN(&[D<G9A<F\@=FED("5S+@`E<R!T:6QL
M("5S(&%V("5S`"5S('9I;&P@;.1G9V$@=&EL;"!T:6QL("5S+@`E<R!V:6QL
M(&?V<F$@9&EG(&UE9'9E=&5N(&]M("5S+@`E<R!V:6QL(&5R:.5L;&$@9&5N
M('-E;F%S=&4@:6YF;W)M871I;VYE;B!O;2`E<RX`061R97-S8F]K(&;V<B`E
M<P!+86QE;F1E<B!F]G(@)7,`06YT96-K;FEN9V%R(&;V<B`E<P!5<'!G:69T
M97(@9O9R("5S`"5S.B`E<P`E<SH@365D9&5L86YD970@:V%N<VME(&EN=&4@
MY'(@9G+E;B!D96X@<V]M(&1E="!V97)K87(N(%9A<B!F]G)S:6MT:6<@;65D
M(&%T="!F]FQJ82!LY&YK87(@96QL97(@<VMI8VMA(&%V<^1N9&%R96X@<&5R
M<V]N;&EG(&EN9F]R;6%T:6]N+@`L('-T;W)M8GEA<@`L('-T;W)M8GEA<B`E
M<R`E<P`L('9A<FEE<F%N9&4@;65L;&%N("5S(&]C:"`E<P`M+2!VY&QJ("TM
M`#$R+71I;6UA<G-F;W)M870`,C0M=&EM;6%R<V9O<FUA=``R-"!T:6UM87(`
M/$;V<F5GY65N9&4`16X@9&%T86)A<VMO<'!L:6YG(&MRY'9S(&;V<B!A:W1U
M96QL="!B;&]C:RX`171T(&9A=&%L="!F96P@:&%R(&EN='+D9F9A=`!%;B!P
M=6)L:6L@4$=0+6YY8VME;"!K<N1V<R!F]G(@871T(&MR>7!T97)A(&5T="!M
M961D96QA;F1E+@!%;B!P=6)L:6L@4$=0+6YY8VME;"!K<N1V<R!F]G(@871T
M('9E<FEF:65R82!E='0@<VEG;F5R870@;65D9&5L86YD92X`16X@<'5B;&EK
M(&]C:"!P<FEV870@4$=0+6YY8VME;"!S86UT(&SV<V5N;W)D(&MRY'9S(&;V
M<B!A='0@9&5K<GEP=&5R82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK(&]C
M:"!P<FEV870@4$=0+6YY8VME;"!S86UT(&SV<V5N;W)D(&MRY'9S(&;V<B!A
M='0@<VEG;F5R82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK(&]C:"!P<FEV
M870@4R]-24U%+6YY8VME;"!S86UT(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@
M9&5K<GEP=&5R82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK(&]C:"!P<FEV
M870@4R]-24U%+6YY8VME;"!S86UT(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@
M<VEG;F5R82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK(%,O34E-12UN>6-K
M96P@:W+D=G,@9O9R(&%T="!K<GEP=&5R82!E='0@;65D9&5L86YD92X`1O9R
M;6ED9&%G<VUO;&X`3.1T="!F]G)M:61D86=S<F5G;@!&]G)M:61D86=S<F5G
M;@!&]G)M:61D86=S<VMU<F%R`$;V<FUI9&1A9W-S:W5R87(@;65D('-N]@!!
M32]030!!4$D@240`3VT@961I=&]R;@!/;2XN+@!";W1T96X`36ET=&5N`$%C
M8V5P=&5R82!B96?D<F%N`$%C8V5P=&5R860`0F5H]G)I9VAE="!S86MN87,@
M871T('-K87!A(%9&4RUM87!P+@!"96CV<FEG:&5T('-A:VYA<R!A='0@<VMA
M<&$@5D93+69I;"X`2V]N=&]I;F9O<FUA=&EO;@!,]G-E;F]R9"!F]G(@:V]N
M=&\`2V]N=&]T(&9R>7-T`$)U9&=E=`#%=&?D<F0@9O9R('-PY')R861E(&%D
M<F5S<V5R`,5T9^1R9&5R`$%K=&EV97)A('-K<FEP=`!$970@9VEC:R!I;G1E
M(&%T="!A:W1I=F5R82!S:W)I<'1E="!F]G(@)R5S)SH@*"5D*2`E<P!,Y&=G
M('1I;&P`3.1G9R!T:6QL("5S`$SD9V<@=&EL;"!U;F1E<F=R=7!P`&SD9V<@
M=&EL;"!U;F1E<F)E:/9R:6=H970`3.1G9R!T:6QL(&CD<CH`3.1G9R!T:6QL
M(&YY(&=R=7!P`$SD9V<@=&EL;"!N>2!B96CV<FEG:&5T`$SD9V<@=&EL;"!U
M;F1E<F=R=7!P('1I;&P@)R5S)P!,Y&=G('1I;&P@=6YD97)B96CV<FEG:&5T
M('1I;&P@)R5S)P!,Y&=G('1I;&P@96X@;GD@86YVY&YD87)E.@!,Y&=G('1I
M;&P@:V]L=6UN`$SD9V<@=&EL;"!N>6$@;65D;&5M;6%R`$SD9V<@=&EL;"!P
M87(`3.1G9R!T:6QL(&UE;GEN(&;V<B`E<R!S;VT@36]Z:6QL82!3:61E8F%R
M`$SD9V<@=&EL;"!I(&UI;B!K86QE;F1E<@!,Y&=G('1I;&P@:2!A9')E<W-B
M;VLZ`$SD9V<@=&EL;"!I(&UI;B!A9')E<W-B;VL`3.1G9R!T:6QL(&%N=N1N
M9&%R90!,861E('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+"!M96X@:W5N9&4@
M:6YT92!LY&=G82!T:6QL(&5X=')A("!I;F9O<FUA=&EO;CH@)7,N`$QA9&4@
M=&EL;"`G)7,G('1I;&P@<WES=&5M970N($1U(&MA;B!L;V=G82!I;B!N=2X`
M57!P;.1G9R!A=B!A;G;D;F1A<F4@Y'(@:6YA:W1I=F5R870N`%ET=&5R;&EG
M87)E(&EN<W3D;&QN:6YG87(`061R97-S`$%D<F5S<V)O:P!!9&UI;FES=')A
M=&EO;B`M(&%N9V4@8F5H]G)I9VAE="!F]G(@86YD<F$@86YVY&YD87)E`$%D
M;6EN:7-T<F%T:6]N`%)E:VQA;0!!9F=A;FES=&%N`$%L8F%N:65N`$%L9V5R
M:65T`$%L:6%S`$IU<W1E<F$`2G5S=&5R:6YG.@!!;&QA`$%L;&$@875T96YT
M:7-E<F%D92!A;G;D;F1A<F4`06QL82!G<G5P<&5R`$%L;&$@8F5H]G)I9VAE
M=&5R`$%L;&$@9GER82!S:61O<@!!;&QA(&;V;&IA;F1E`%1I;&SE="!R96=L
M97(`5&EL;.5T(&9L97)A(&%D<F5S<V5R`%1I;&SE="!I;G-TY&QL;FEN9R!F
M]G(@<V]R=&5R860@;&ES=&$_`$9I;FYS(')E9&%N`$%L=&5R;F%T:78@24U3
M4"UI;FQO9V=N:6YG`$%L=&5R;F%T:79T(&SV<V5N;W)D(&;V<B!)35-0`$%L
M=&5R;F%T:79T(&%N=N1N9&%R;F%M;B!F]G(@24U34`!!;'1E<FYA=&EV(&4M
M<&]S="!A9')E<W,`06QT97)N871I=B!M86QL`$%L=&5R;F%T:78@=&5X=#H`
M06UE<FEK86YS:V$@4V%M;V$`171T(&9E;"!U<'!S=&]D(&[D<B!LY&YK96X@
M*"5S*2!S:W5L;&4@86YVY&YD87,`171T(&9E;&%K=&EG="!VY')D92!A;F=A
M=G,N`$5T="!O:^1N="!F96P@:&%R(&EN='+D9F9A=`!!;F1O<G)A`$%N9V]L
M80!!;F=U:6QL80!!;F]N>6T@<')O>'D`4W9A<@!"97-V87)A=`!!;G1A<FMT
M:7,`06YT:6=U82!O8V@@0F%R8G5D80!.Y6=O;B!A=B!F]FQJ86YD90!!<'!L
M:6MA=&EO;@!!<'!L:6MA=&EO;G-L:7-T80!!<'!L:6MA=&EO;F5N(.1R(&ML
M87(N`%9E<FMS=.1L;"!F:6QT97(`5F5R:W-TY&QL('1I;&P@=6YD97)U=&1E
M;&YI;F=A<@!';V1KY&YN`%5N9V5FY')L:6<@<W1O<FQE:P!A<')I;`!!<F%B
M:7-K("A7:6YD;W=S+3$R-38I`$%R:VEV9FEL<W1O<FQE:P!!<FMI=F9I;&YA
M;6X`Q'(@9'4@<^1K97(@871T(&1U('9I;&P@<F%D97)A(&%K='5E;&P@<F5G
M96P_`,1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@=&$@8F]R="!B96?D<F%N
M(&;V<B`E<S\`Q'(@9&5T('/D:V5R="!A='0@9'4@=FEL;"!R861E<F$@)R5S
M)R!O8V@@979E;G1U96QL82!U;F1E<F=R=7!P97(_`$%R9V5N=&EN80!!<FUA
M;FEE;@!!<FUE;FES:R`H05)-4T-)22TX*0!+;VYS=`!!<G5B80!!<V-E;G-I
M;VX@27-L86YD`$%S8VEI(&MO;G-T`$%S:65N+U-T:6QL82!H879S<F5G:6]N
M96X`1G+E9V$@969T97(@8F5K<N1F=&5L<V4@:6YN86X@=6YD97)HY6QL<V%K
M=&EV:71E=&5R('5T9O9R<S\`5&EL;&1E;&YI;F=S:V]L=6UN`$)I9F]G860@
MY'(@96X@:4-A;&5N9&5R(&9I;"!M960@971T('-V87(@<.4@96X@8F5GY')A
M;B!S;VT@9'4@<VMI8VMA="P`1O9R<_9K('1I;&P@871T(')A9&5R82!E;B!G
M<G5P<"!S;VT@:6YT92!F:6YN<RX`1O9R<_9K('1I;&P@871T(')A9&5R82!E
M;B!B96CV<FEG:&5T('-O;2!I;G1E(&9I;FYS+@!&]G)S]FL@871T(.1N9')A
M(&5N(&)E:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N`$;V<G/V:R!A='0@Y&YD
M<F$@96X@=71D96QN:6YG('-O;2!I;G1E(&9I;FYS+@!$96QT86=A<F4`071T
M<FEB=70`875G=7-T:0!!=7-T<F%L:65N`-9S=&5R<FEK90!!=71H7V-Y<G-Q
M;#H@24U!4"UE>'1E;G-I;VX@<V%K;F%S+@!!=71H7V-Y<G-Q;#H@2V]P<&QI
M;F=E;B!S86MN87(@9G5N:W1I;VYE<B!S;VT@:W+D=G,N`$%U=&A?8WER=7,Z
M($E-05`M97AT96YS:6]N('-A:VYA<RX`075T:%]F='`Z($944"UT:6QLY&=G
M('-A:VYA<RX@2V]M<&EL97)A(%!(4"!M960@<W=I=&-H96X@+2UE;F%B;&4M
M9G1P+@!!=71H7VEM87`Z($E-05`M97AT96YS:6]N('-A:VYA<RX`075T:%]K
M<F(U.B!K<F(U+65X=&5N<VEO;B!S86MN87,N`$%U=&A?;&1A<#H@1&5T(&?E
M<B!I;G1E(&%T="!LY&=G82!T:6QL(&%N=N1N9&%R92!I($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!$970@9^5R(&EN=&4@871T(')A9&5R82!A;G;D
M;F1A<F4@9G+E;B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@3$1!4"UT
M:6QLY&=G('-A:VYA<RX`075T:%]L9&%P.B!+86X@:6YT92!LY&=G82!T:6QL
M(&%N=N1N9&%R92`G)7,G+B!397)V97)N('-V87)A9&4Z(`!!=71H7VQD87`Z
M($MA;B!I;G1E(')A9&5R82!A;G;D;F1A<F4@)7,`075T:%]L9&%P.B!+86X@
M:6YT92!U<'!D871E<F$@86YVY&YD87)E("5S`$%U=&A?;&1A<#H@1&5T(&?E
M<B!I;G1E(&%T="!U<'!D871E<F$@86YVY&YD87)E(&D@06-T:79E($1I<F5C
M=&]R>2X`075T:%]M8V%L.B!-0T%,+65X=&5N<VEO;B!S86MN87,N`$%U=&A?
M<VUB875T:#H@<VUB875T:"UE>'1E;G-I;VX@<V%K;F%S+@!!=71E;G1I<V5R
M:6YG('1I;&P@24U!4"US97)V97(@;6ES<VQY8VMA9&5S+@!!=71E;G1I<V5R
M:6YG(&UI<W-L>6-K861E<P!!=71E;G1I<V5R:6YG(&UI<W-L>6-K861E<RX@
M)7,`075T96YT:7-E<FEN9R!A=G9I<V%D97,@878@4D%$2553+7-E<G9E<FXN
M`$%U=&5N=&ES97)I;F<@=&EL;"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RX`
M075T96YT:7-E<FEN9R!T:6QL(%--0BUS97)V97(@;6ES<VQY8VMA9&5S+@!5
M<'!D871E<F$@<VMR:7!T970@969T97(@=F%R:F4@Y&YD<FEN9S\`5&EL;&?D
M;F=L:6=A(&;D;'0Z`%;D;G1A<B!PY2!S=F%R`$%Z97)B86EJ86X`07IU<F)L
MY0!"3T9(+75R<^1K=&5R`$)A:V=R=6YD`$)A:V=R=6YD<V;D<F<`1F5L86MT
M:6=T(&SV<V5N;W)D(&;V<B!+97)B97)O<P!&96QA:W1I9W0@86YVY&YD87)N
M86UN(&;V<B!+97)B97)O<P!"86AA;6%S`$)A:')A:6X`0F%L=&ES:R`H25-/
M+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R=&ED`%)A9'1I9`!"87)B861O<P!"
M87)B:64`0F%S:V%T86QO9R`G)7,G(&;V<B!B:6QD97(@:&ET=&%D97,@:6YT
M92X`0F%S;&EN:F4`0F-C`$+V<FIA<B!M960`5FET<GES<VQA;F0`0F5L9VEE
M;@!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FEN9"!M:7-S;'EC:V%D
M97,Z("@E<RD@)7,`1O9D96QS961A9P!3<.1R<F%D92!A9')E<W-E<@#$;F1R
M82!S<.1R<F%D92!A9')E<W-E<@!3<.1R<FYI;F<@878@861R97-S97(@<W3V
M9',@:6YT92!A=B!A:W1U96QL(&9I;'1E<F1R:79R=71I;BX`4W#D<G)A9&4@
M861R97-S97(`0FQO8VL@)R5S)R!F]G(@87!P;&EK871I;VX@)R5S)R!S86MN
M87,N`$)L;V-K:6YS=.1L;&YI;F=A<@!";&]C:W1Y<`!";.4@;>5N90!";.5T
M="!O8V@@=FET=`!-961D96QA;F1E=&5X=`!&970`0F]L:79I80!";VMMY')K
M96X`4F%M`%)A;6)R961D.@!286UA<@!";W-N:65N(&]C:"!(97)Z96=O=FEN
M80!"Y61A`$)O='-W86YA`$)O='1E;@!";W5V970@27-L86YD`$)R87-I;&EE
M;@!"<FET=&ES:V$@=&5R<FET;W)I970@:2!);F1I<VMA(&]C96%N96X`0G)U
M;@!"<G5N96D`0G5L9V%R:65N`%!U;FMT;&ES=&$`0G5R:VEN82!&87-O`$)R
MY&YD($]R86YG90!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0
M;VEN=',`0U]E;&P@:6YS=.1L;&YI;F=A<BXN+@!#86-H96EN:71I97)I;F<@
MY'(@:6YT92!F=6QL<W3D;F1I9RX`2V%L96YD97(`3'5G;G0`2V%M8F]D:F$`
M2V%M97)U;@!+86UO=69L86=E`$MA;B!I;G1E(&YO;&QS=.1L;&$@;/9S96YO
M<F0@875T;VUA=&ES:W0L(&MO;G1A:W1A(&1I;B!A9&UI;FES=')A=/9R+@!+
M86X@:6YT92!S:W)I=F$@=&EL;"!F:6P@)R5S)P!$970@9^5R(&EN=&4@871T
M(&%D;6EN:7-T<F5R82!E>'1E<FYA('-E<W-I;VYS:&%N=&5R87)E+@!+86X@
M:6YT92!K;VYT86MT82!)34%0+7-E<G9E<FXZ("5S`$MA;B!I;G1E(/9P<&YA
M(&9I;"`G)7,G`$MA;F%D80!!=F)R>70`079B<GET('!R;V)L96UR87!P;W)T
M`$MA;B!I;G1E(')A9&5R82`G)7,G+@!+86X@:6YT92!H:71T82!E;B!T96UP
M<N1R(&UA<'`N`$MA;B!I;G1E(&9O<G1SY'1T82!U=&%N("=MY6QF:6PG+7!A
M<F%M971E<BX`2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RX`2V%N(&EN=&4@
M<F%D97)A.R`E9"!B87)N(&5X:7-T97)A<BX`2V%N(&EN=&4@9&ER:6=E<F$@
M;65D9&5L86YD92!T:6QL(&%N9VEV970@;G5M;65R+@!+87`@5F5R9&4`4G5B
M<FEK`$]P97)A=/9R`%-K:69T;.1G97-KY&YS;&EG`$MA=&5G;W)I97(@;V-H
M(')U8G)I:V5R`$-A>6UA;B!)<VQA;F1S`$-C`$UO8FEL=&5L969O;@!#96QL
M:6YS=.1L;&YI;F=A<@!#96QL=71F>6QL;F%D.@!#96QL:6YS=.1L;&YI;F=A
M<@!#96QL;65L;&%N<G5M.@!-;V)I;'1E;&5F;VX`0V5L=&ES:R`H25-/+3@X
M-3DM,30I`$-E;G1R97)A9`!#96YT<F%L869R:6MA;G-K82!R97!U8FQI:V5N
M`$-E;G1R86QE=7)O<&5I<VL@*$E33RTX.#4Y+3(I`$-E<G1I9FEK871D971A
M;&IE<@!#97)T:69I:V%TY&=A<F4`0V5R=&EF:6MA='!O;&EC:65S`%1C:&%D
M`$]R9&;V<F%N9&4`Q&YD<F$`Q&YD<F$@9&ET="!L]G-E;F]R9`#$;F1R82!F
M]G)V86QD(&ED96YT:71E=`#$;F1R82!N86UN(&]C:"!A9')E<W,@<V]M(&UO
M='1A9V%R;F$@<V5R(&[D<B!D92!LY'-E<B!O8V@@<W9A<F%R('#E(&1I;F$@
M;65D9&5L86YD96XN`,1N9')I;F=A<B!S<&%R861E+@!!='0@8GET82!L]G-E
M;F]R9"!S=/9D<R!I;G1E(&UE9"!D96X@;G5V87)A;F1E(&MO;F9I9W5R871I
M;VYE;BX@(%9A<B!G;V0@:V]N=&%K=&$@861M:6YI<W1R873V<F5N+@!4:VX`
M2V]N=')O;&QE<F$@;.1N:RXN+@!-87)K97)A(&1E(&%K=&EV:71E=&5R(&1U
M('9I;&P@=71F]G)A(&YU+@!#:&EL90!+:6YA`$MI;F5S:7-K="!F]G)E;FML
M870@*$=",C,Q,BD`2VEN97-I<VMT('1R861I=&EO;F5L;'0@*$)I9S4I`%;D
M;&H@87!P;&EK871I;VXZ`%;D;&H@;/9S96YO<F0`5N1L:B!A;G;D;F1A<FYA
M;6X`5N1L:B#E=&?D<F0Z`%;D;&H@:'5R(&1A='5M('-K86QL('9I<V%S.@!6
MY&QJ(&QI<W1S=&EL("AF]G(@<V]R=&5R861E(&QI<W1O<BD`2G5L]FX`2VQA
M<W-D969I;FET:6]N(&;V<B`E<R!S86MN87,N`%)E;G-A`%)E;G-A($U33V9F
M:6-E+71A9V=A<@!296YS82!F<N5G80!296YS82!A;G;D;F1A<F4Z("5S`%)E
M;G-A(&%N=N1D;F%R90!296YS82!A;G;D;F1A<F1A=&$`4V5N87)E('5P<&ML
M87)N86YD90!+;&EC:V$@9O9R(&%T="!F;W)T<^1T=&$`0VQI8VMA=&5L;"!V
M:6$@2%144`!3=.1N9R!F]FYS=&5R`$UO;&X`5&ED:6=A(&UO;&X`36]L;FEN
M9W0`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`2V]M<')I;65R82!S:61O9N1L
M=&5T`$MO;7!R:6UE<F%D92!R86UA<@!+;VQO;6)I80!&Y')G`$;D<F=H86YT
M97)A<F4`1N1R9W9A;`!+;VQU;6YE<CH`2V]L=6UN(')U8G)I:V5R`$QU<W1I
M9VAE=&5R`$MO;6UA;F1O`$MO;6UA;F1O9O9N<W1E<@!+;VUM96YT87(`3F%M
M;@!#;VUO<F]S`$;V<F5T86<`4VQU=&;V<F0`4VMR:78@;65D9&5L86YD92`H
M)7,I`$1A=&]R97(`5N1D97(`5N1D97(`2V]N9FEG=7)A=&EO;G-S:VEL;&YA
M9&5R`$EN<W3D;&QN:6YG87(@9O9R(&%T="!S>6YK<F]N:7-E<F$@;65D(&AA
M;F1D871O<F5R+"!S;6%R=&$@=&5L969O;F5R(&]C:"!/=71L;V]K`$MO;F9I
M9W5R871I;VX@8F5H]G9E<B!U<'!D871E<F%S+@!+;VYF:6=U<F5R82`E<P!"
M96MRY&9T82!L]G-E;F]R9`!+;VYG;P!+;VYG;P!&]G)B:6YD96QS92!M:7-S
M;'EC:V%D97,N`$;V<F)I;F1E;'-E(&UI<W-L>6-K861E<SH@`$;V<F)I;F1E
M;'-E('1I;&P@<V5R=F5R(&UI<W-L>6-K861E<P!&]G)B:6YD96QS92!M960@
M<'5B;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S+@!&]G)B:6YD96QS92!M960@
M<'5B;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S.B`E<R`H)7,I`$;V<F)I;F1E
M;'-E(&UE9"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RX`2V]N=&%K=&5R`$MO
M;G1A:W1E<B!L861E<R!T:6QL(&D@9&EN(&%D<F5S<V)O:RX`26YN96CE;&QE
M<@!);FYE:.5L;'-T>7`@9O9R(&MO;7!R:6UE<F%D(&9I;#H@`$EN;F5HY6QL
M(&D@)R5S)P!&;W)T<^1T=`!#;V]K($ES;&%N9',`0V]O:VEE`$MO<&EE<F$`
M2V]P:65R82`E<P!+;W!I97)I;F<@;6ES<VQY8VMA9&5S.B`E<P!+;W!I82!A
M=B`E<P!+;W!I97)A(&UA<FME<FEN9P!-86IS8FQO;6UA`$MO<W1N861S+4E$
M`$-O<W1A(%)I8V$`16QF96YB96YS:W5S=&5N`$MA;B!I;G1E(%!'4"UK<GEP
M=&5R82!M961D96QA;F1E+@!+86X@:6YT92!01U`M:W)Y<'1E<F$@;65D9&5L
M86YD93H@`$MA;B!I;G1E(%!'4"US:6=N97)A(&UE9&1E;&%N9&4N`$MA;B!I
M;G1E(%!'4"US:6=N97)A(&UE9&1E;&%N9&4Z(`!+86X@:6YT92!3+TU)344M
M:W)Y<'1E<F$@;65D9&5L86YD92X`2V%N(&EN=&4@4R]-24U%+7-I9VYE<F$@
M;65D9&5L86YD92X`2V%N(&EN=&4@;.1G9V$@=&EL;"!K;VYT86MT+B`E<P!-
M:7-S;'EC:V%D97,@871T(&MO;G1A:W1A($Q$05`@<V5R=F5R+@!+86X@:6YT
M92!V97)I9FEE<F$@:V]N=&]S86QD;RX@)7,`2W5N9&4@:6YT92!A;G-L=71A
M('1I;&P@3$1!4"US97)V97(N`$MA;B!I;G1E(&MO;G1A:W1A('-E<G9E<B`G
M)7,G('9I82!&5%`Z("5S`$MA;B!I;G1E('-K87!A(&1I<W1R:6)U=&EO;G-L
M:7-T82X@)7,`2V%N(&EN=&4@9&5K<GEP=&5R82!01U`M9&%T82X`2V%N(&EN
M=&4@9&5K<GEP=&5R82!01U`M9&%T83H@`$MA;B!I;G1E(&1E:W)Y<'1E<F$@
M4R]-24U%+61A=&$N`$MA;B!I;G1E(')A9&5R82!K;VYT86MT+B`E<P!+86X@
M:6YT92!R861E<F$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<P!+86X@:6YT92!R
M861E<F$@=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RX`2V%N(&EN=&4@
M8F5S=.1M;6$@;6]T=&%G87)E;G,@95!O<W0M861R97-S+@!+86X@:6YT92!H
MY&UT82!K;VUP;&5T="!A9')E<W-B;VLN`$MA;B!I;G1E(&CD;71A(&MO;7!L
M971T(&1I<W1R:6)U=&EO;G-L:7-T82X`2V%N(&EN=&4@:.1M=&$@:V]M<&QE
M='0@;&ES=&$@]G9E<B!D:7-T<FEB=71I;VYS;&ES=&]R+@!+86X@:6YT92!L
M861D82!S=')A=&5G:2`G)7,G+@!+86X@:6YT92!L861D82!S=')A=&5G:2`G
M)7,G+@!+86X@:6YT92!S:V%P82!M87!P("<E<R<N`$MA;B!I;G1E('-K87!A
M(&UA<'`@)R5S)RX`2V%N(&EN=&4@:.1M=&$@<'5B;&EK(&YY8VME;"!F<N5N
M(&YY8VME;'-E<G9E<FXN`$MA;B!I;G1E(/9P<&YA("<E<R<@9O9R('-K<FEV
M:6YG+@!+86X@:6YT92#V<'!N82`E<RX`2V%N(&EN=&4@]G!P;F$@)R5S)R!F
M]G(@<VMR:79I;F<N`$MA;B!I;G1E(/9P<&YA($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6P@)7,`2V%N(&EN=&4@]G!P;F$@;6%P<&5N("<E<R<`2V%N(&EN=&4@
M]G!P;F$@;6%P<"`G)7,G`$MA;B!I;G1E(&MO;G1A:W1A($Q$05`@<V5R=F5R
M+@!+86X@:6YT92!LY'-A("5S+@!$970@9VEC:R!I;G1E(&%T="#E=&5R<W3D
M;&QA(&SV<V5N;W)D970@9O9R(&1E;B!A;F=I=FYA(&%N=N1N9&%R96XN($[E
M9V]N(&5L;&5R(&[E9W)A(&%V('5P<&=I9G1E<FYA(.1R(&EN=&4@:V]R<F5K
M=&$N($;V<G/V:R!I9V5N(&5L;&5R(&MO;G1A:W1A(&%D;6EN:7-T<F%T]G)E
M;B!O;2!D=2!B96CV=F5R(&AJY&QP+@!+86X@:6YT92!HY&UT82!!0TP`2V%N
M(&EN=&4@:.1M=&$@861R97-S8F]K+B`E<P!+86X@:6YT92!HY&UT82!D:7-T
M<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I;G1E(&CD;71A(&1I<W1R:6)U=&EO
M;G-L:7-T;W(N("5S`$MA;B!I;G1E(&CD;71A(&1S97)V97)F=6YK=&EO;F5R
M`$MA;B!I;G1E(.5T97)S=.1L;&$@:V]N9FEG=7)A=&EO;F5N+@!+86X@:6YT
M92!R861E<F$@;6%P<"`G)7,G+@!+86X@:6YT92!R861E<F$@;6%P<"`G)7,G
M+@!+86X@:6YT92!S<&%R82!K;VYF:6=U<F%T:6]N(&;V<B`E<RX`2V%N(&EN
M=&4@<W!A<F$@8F%C:W5P+6MO;F9I9W5R871I;VXN`$MA;B!I;G1E('-P87)A
M(&5N(&)A8VMU<"UK;VYF:6=U<F%T:6]N.B`E<RX`2V%N(&EN=&4@<W!A<F$@
M=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RX`2V%N(&EN=&4@<W!A<F$@
M8F%C:W5P+6MO;F9I9W5R871I;VX@)7,N`$MA;B!I;G1E('-P87)A(&MO;F9I
M9W5R871I;VYS9FEL96X@)7,N($1U(&MA;B!A;G1I;F=E;B!A;G;D;F1A(&5N
M(&%V(&%L=&5R;F%T:79E;B!A='0@<W!A<F$@:V]D96X@=&EL;"`E<R!E;&QE
M<B!K;W!I97)A(&MO9&5N(&YE9&%N('1I;&P@)7,N`$MA;B!I;G1E('/V:V$@
M:2!,1$%0+6MA=&%L;V=E;BX`2V%N(&EN=&4@<F%D97)A("<E<R<N`$MA;B!I
M;G1E(')A9&5R82`G)7,G+@!+86X@:6YT92!U<'!D871E<F$@:V]N=&%K="X@
M)7,`2V%N(&EN=&4@=7!P9&%T97)A(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,`
M2V%N(&EN=&$@<W!A<F$@:V]N9FEG=7)A=&EO;B!F]G(@)R5S)SH@)7,`2V%N
M(&EN=&4@:&ET=&$@36]Z:6QL87,@<VED;V;D;'0N(%9E<FEF:65R82!A='0@
M<VED;V;D;'1E="#D<B#V<'!E="X`2V%N(&EN=&4@9V4@86YVY&YD87)E;B`G
M)7,G(&%N9VEV;F$@<N1T=&EG:&5T97(@=&EL;"!M87!P96X@)R5S)SH@)7,`
M4N1K;F%D('1E>'0`3&%N9`!+=7)S97(`4VMA<&$`4VMA<&$@;.1N:P!3:V%P
M82!N>0!3:V%P82!N>2!M87!P`%-K87!A('5N9&5R;6%P<`!"96CV<FEG:&5T
M97(@9O9R(.1G87)A`$MR961I=&MO<G1S;G5M;65R`$MR;V%T:65N`$MU8F$`
M06MT=65L;&$@-"!F87-E<@!!:W1U96QL('-E<W-I;VX`06MT=65L;"!T:60`
M06MT=65L;"!54DP@Y'(`06MT:79A(&%N=N1N9&%R90!!:W1U96QL="!VY&1E
M<@!!:W1U96QL82!V:6QL:V]R.B``06MT=65L;"!S=&EL`%-K<N1D9&%R<WD@
M86MT:79I=&5T97(@<V]M(&OV<G,@=FED(&EN;&]G;FEN9R!T:6QL("5S+@!+
M;&EP<"!U=`!+;&EP<"!U<G9A;`!#>7!E<FX`2WER:6QL:7-K("A+3TDX+5(I
M`$MY<FEL;&ES:R`H5VEN9&]W<RTQ,C4Q*0!+>7)I;&QI<VLO56MR86EN<VL@
M*$M/23@M52D`5&IE8VMI96X`1$0`05935,1.1T0Z(`!$86=L:6<`1&%T851R
M964@8FSD9&1R87)E`$1A=&%B87-U<'!S;&%G`$1A='5M`$1A='5M(&UO='1A
M9V5T`$1A='5M=F%L`$1A9P!?4F%D97)A(&MO;'5M;@!!=F%K=&EV97)A('-K
M<FEP=`!D96-E;6)E<@!$96-I;6%L97(`079B]FIT`$UI;G-K82!I;F1R86<`
M1O9R=F%L=`!&]G)V86QD(&;D<F<`1O9R=F%L9"!I9&5N=&ET970`1O9R=F%L
M="!S:V%L`$1E9FEN:71I;VYE<@!$96QE9V5R82!P;W-I=&EO;@!$96QE9V5R
M860`4F%D97)A`%)A9&5R82`E<P!2861E<F$@8V5L;`!2861E<F$@=FEL;&MO
M<@!2861E<F$@9W)U<'``4F%D97)A(&QO9V<`4F%D97)A(&)E:/9R:6=H970`
M4F%D97)A(&]C:"!R96YS82!M961D96QA;F1E;@!2861E<F$@8V5L;`!2861E
M<F$@:V]L=6UN`%)A9&5R82!B969I;G1L:6<@86QT97)N871I=FUA;&P`4F%D
M97)A(&UE9&1E;&%N9&4@:&5L=`!2861E<F%D92!M961D96QA;F1E;@!2861E
M<F$@8F5H]G)I9VAE="!F]G(@)R5S)P!2861E<F$@8F5H]G)I9VAE="!F]G(@
M)R5S)R!O8V@@=6YD97)B96CV<FEG:&5T97(_`%)A9&5R82!R860`4F%D97)A
M('9A;&0@:61E;G1I=&5T`%)A9&5R82!U;F1E<FUA<'!A<@!2861E<F$@86MT
M=65L;"!K;VQU;6X`4F%D97)A(&%K='5E;&P@<F%D`%)A9&5R82!D96X@:.1R
M(&SD;FME;@!2861E<F%D`%)A9&5R861E('5P<&=R861E<FEN9W-S8W)I<'1E
M="`G)7,G+@!,979E<F5R82!T:6QL(&UI;B!I;FMO<F<`3&5V97)E<F$@=&EL
M;"!M:6X@:6YK;W)G(&]C:"!K;W!I97)A('1I;&P`3&5V97)E<F$@=&EL;"!M
M:6X@:6YK;W)G(&]C:"!O;61I<FEG97)A('1I;&P`3&5V97)E<F$@=&EL;"!M
M87!P`$QE=F5R86YS=&ED`$1A;FUA<FL`079S;.4@8F5GY')A;@!!=G-LY2!B
M96?D<F%N(&]M(&QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N`$)E<VMR:78@
M<')O8FQE;65T`$)E<VMR:79N:6YG`$1E=&%L:F5R("AO8VMSY2!I($AO<F1E
M<R!L;V=G9FEL*3H`1&5T86QJ97(@:&%R(&QO9V=A=',@9O9R('-Y<W1E;6%D
M;6EN:7-T<F%T]G)E;BX`571V96-K;&EN9P!$86=G<'5N:W0`1&%G9W!U;FMT
M(&;V<B!S96YA<W1E('1I;6UE;CH@`$1A9V=P=6YK=#H@`%)I:W1N:6YG(';D
M;G-T97(@=&EL;"!H]F=E<@!2:6MT;FEN9R!H]F=E<B!T:6QL(';D;G-T97(`
M2V%T86QO9P!!=F%K=&EV97)A("5S`$%V86MT:79E<F%D`%9I<V$@,C0M=&EM
M;6%R<R!K;&]C:V$_`%9I<VYI;F=S:6YS=.1L;&YI;F=A<@!6:7-A(&1E=&%L
M:F5R860@9O9R=71SY&=E;'-E`%9I<V$@9&5T86QJ97)A9"!N;W1I9FEE<FEN
M9R!F]G(@=F%R:F4@9FEL=&5R(&[D<B!D970@:_9R<S\`5FES82!F]G)U='/D
M9V5L<V4@*%1!1BD`5FES;FEN9W-F;W)M870`079S:VEL:F%R90!$:FEB;W5T
M:0!3:VEC:V$@7VEN9V$@<W9A<B!PY2!L:7-T+2!O8V@@8G5L:VUE9&1E;&%N
M9&5N`%)A9&5R82!I;G1E`$%N=N1N9"!I;G1E(&UA:6YT96YA;F-E+G!H<"!D
M:7)E:W0`1_9R(&1E='1A.@!);FYE:.5L;&5R(&;V<G-T82!R861E;B!FY&QT
M;F%M;F5N/R!/;2`G:F$G+"!M87)K97)A(&CD<CH`26YT92!B]G)J87(@;65D
M`$EN=&4@:6YN96CE;&QE<@!);G1E('-L=71A<B!M960`1FEN;G,@:6YT90!-
M871C:&%R(&EN=&4`1&]M:6YI:V%N<VMA(')E<'5B;&EK96X`2&%R(&1U(&EN
M9V5T(&MO;G1O/R!296=I<W1R97)A(&1I9RX`2.1M=&$`2.1M=&$@)7,`2.1M
M=&$@9V5N97)E<F%D(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I<'0N`$1R
M;W!P;&ES=&$`1')O9V5R`$4M<&]S=`!$<FEV<G5T:6X@9O9R($4M<&]S="!T
M:6QL(%--4RUB<GEG9V$[(&;V<B!O<&5R873V<F5R('-O;2!T:6QL:&%N9&%H
MY6QL97(@9&5N;F$@=&KD;G-T+@!&14P`16MU861O<@#$;F1R80#$;F1R82`E
M<P#$;F1R82!B;&]C:P#$;F1R82!G<G5P<`#$;F1R82!B96CV<FEG:&5T`,1N
M9')A(&)E:/9R:6=H971E<@#$;F1R82!B96CV<FEG:&5T97(@9O9R("5S`,1N
M9')A(&EN<W3D;&QN:6YG87(@9O9R.@#$;F1R82!B96CV<FEG:&5T97(@9O9R
M("<E<R<`Q&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`G)7,G`%5T8FEL9&YI;F<`
M16=Y<'1E;@!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$4M<&]S=`!%+7!O
M<W1A9')E<W,`12UP;W-T861R97-S97(@;>5S=&4@<W3D;6UA(/9V97)R96YS
M+@!%+7!O<W1M961D96QA;F1E(&UE9"!B96MRY&9T96QS90!%+7!O<W0@=&EL
M;"!335,M8G)Y9V=A`$OD;G-L;VEK;VYE<@!4;VUT(&UE9&1E;&%N9&4N`%1O
M;70@<F5S=6QT870N`%1O;70@<_9K:W)I=&5R:6$`06MT:79E<F$@)7,`06MT
M:79E<F%D`%-L=70`4VQU="#E<@!3;'5T87(@;65D`$;V<G-T;W)A(&5D:71O
M<@!!;F=E('/V:W;D9R`H55),*2!T:6QL(&)I;&1E;B!HY'(`4TMR:78@8F]K
M<W3D=F5R;F$@;F5D86XZ`$QI:V$@;65D`$9E;`!&96P@=FED('-K87!A;F1E
M(&%V(&)L;V-K.B`E<P!&96P@=FED(')A9&5R:6YG(&%V('-Y;FMR;VYI<V5R
M:6YG<VWD<FME.B`E<P!&96P@=FED(')A9&5R:6YG(&%V('-Y;FMR;VYI<V5R
M:6YG<VQO9V<Z("5S`$9E;"!NY'(@:6YN96CE;"!HY&UT861E<SH@)7,`2V%N
M(&EN=&4@:.1M=&$@86MT=65L;'0@<VMR:7!T.B`H)60I("5S`$1E="!G:6-K
M(&EN=&4@871T('-P87)A(.1N9')I;F=A<FYA+@!&96P@=6YD97(@<^1N9&YI
M;F<@878@<W9A<G-M961D96QA;F1E.B`E<P!&96P@=FED('5P<&1A=&5R:6YG
M(&%V(&SV<V5N;W)D.B`E<P!&96P@=FED('-K<FEV;FEN9R`G)7,G+@!&96P@
M=FED('-K<FEV;FEN9R!A=B`G)7,G+@!%<W1L86YD`$5T:6]P:65N`$5T;FES
M:P!%=7)O<&$`5F%R(#$U.F4@;6EN=70`5F%R86YN86X@;6EN=70`5F%R(#,P
M.F4@<V5K=6YD`%9A<B`U.F4@;6EN=70`5F%R:F4@:6YL;V=G;FEN9P!687)J
M92!H86QV=&EM;64`5F%R:F4@;6EN=70`17AE;7!E;"!PY2!VY')D96XZ`$OV
M<@!"969I;G1L:6=A(')E9VQE<@!&:6YN<P!%>'!A;F1E<F$`17AP86YD97)A
M('-I9&]FY&QT`$;V<G;D;G1A9&4@)RDG`$9I8VL@,2!O8FIE:W0L(&9I8VL@
M)60N`$;V<G;D;G1A9&4@96YS:VEL="!O<F0@96QL97(@8VET97)A="!S]FMB
M96=R97!P`$;V<F9A;&QO9&%T=6T`17AP;VYE;G0`1O9R9W)U;F1S9N1R9P!,
M861D82!U<'`@:V]N9FEG=7)A=&EO;B!V:6$@1E10+@!-:7-S;'EC:V%D97,@
M871T(&CD;71A(&EN<W3D;&QN:6YG87(N`$UI<W-L>6-K861E<R!A='0@:V]N
M=&%K=&$@3$1!4"!S97)V97(N`$UI<W-L>6-K861E<R!A='0@:V]N=&%K=&$@
M4TU"('-E<G9E<BX`36ES<VQY8VMA9&5S(&%T="!K;W!I97)A(&9RY6X@)R5S
M)RX`36ES<VQY8VMA9&5S(&%T="!K;W!I97)A('1I;&P@)R5S)RX`36ES<VQY
M8VMA9&5S(&%T="!S:V%P82!N>2!305-,+6;V<F)I;F1E;'-E+@!-:7-S;'EC
M:V%D97,@871T(&9L>71T82!T:6QL("<E<R<N`$UI<W-L>6-K861E<R!A='0@
M:.1M=&$Z("5S`$)R80!&86QK;&%N9'/V87)N80!&Y'+V87)N80!&871A;'0@
M9F5L.@!&87@`1F%X87(`9F5B<G5A<FD`2^1N;G,@<V]M`$OD;FYS('-O;3H@
M`$;E=&%L:6=A('-K=7)A<@!&Y71A;&EG82!S;O9S:W5R87(`1N1L=&UA=')I
M<P!&:6=L970@0T%05$-(00!&:6=L971T>7!S;FET=`!&:6II`$9I;`!!;G1A
M;"!F:6QE<CH@)7,@9FEL`$%N=&%L(&9I;&5R.B`E<R!F:6QE<@!&:6QH86YT
M97)A<F4`1FEL;F%M;@!&:6QV86P`1FEL=7!P;&%D9&YI;F<`1FEL=7!P;&%D
M9&YI;F<@<W3V9',@:6YT92X`1FEL=')E<F$@86QL82!M961D96QA;F1E;@!&
M:6QT<F5R82!E;F)A<G0@;.1S=&$@;65D9&5L86YD96X`1FEL=')E<F$@96YB
M87)T(&]LY'-T82!M961D96QA;F1E;@!&:6QT97)I;G-TY&QL;FEN9V%R`$9I
M;'1E<G)E9V5L`$9I;'1E<G)E9VQE<@!38W)I<'1F:6QT97)I;G-TY&QL;FEN
M9V%R`$9I;'1E<E]R96=L97(`1FEL=&5R86MT:79I=&5T.B`E<R!M961D96QA
M;F1E*&XI(&AA<B!F;'ET=&%T<R!T:6QL(&UA<'!E;B`G)7,G+@!&:6QT97)A
M:W1I=FET970Z("5S(&UE9&1E;&%N9&4H;BD@:&%R(')A9&5R871S+@!&:6QT
M97)A:W1I=FET970Z("5S(&UE9&1E;&%N9&4H;BD@:&%R(&9L>71T871S('1I
M;&P@;6%P<&5N("<E<R<N`$9I;'1E<F%K=&EV:71E=#H@)7,@;65D9&5L86YD
M92AN*2!S;VT@;6]T<W9A<F%R('-PY')R;&ES=&%N(&AA<B!R861E<F%T<RX`
M1FEL=&5R86MT:79I=&5T.B!-961D96QA;F1E="`G)7,G(&9RY6X@)R5S)R!H
M87(@:V]P:65R871S('1I;&P@;6%P<&5N("<E<R<N`$9I;'1E<F%K=&EV:71E
M=#H@365D9&5L86YD970@)R5S)R`@9G+E;B`G)7,G(&AA<B!R861E<F%T<RX`
M1FEL=&5R86MT:79I=&5T.B!-961D96QA;F1E="`G)7,G(&9RY6X@)R5S)R!H
M87(@9FQY='1A=',@=&EL;"!M87!P96X@)R5S)RX`1FEL=&5R('-A:VYA<RX`
M1FEL=&5R`$9I;FQA;F0`1O9R<W1A(&AA;'9A;@!&]G)S=&$@:W9A<G1E;@!-
M87!P("5S(&5X:7-T97)A<B!I;G1E+@!&;VYT9N1R9P!-870`1O9R(&EN:V]M
M;6%N9&4@;65D9&5L86YD96X@<V]M(&UA=&-H87(Z`$;V<B!W96)B;.1S87)E
M('-O;2!I;G1E('-T]F1E<B!B:6QD97(`4')O9VYO<R`H5$%&*0!!;G1A;"!D
M86=A<B!F]G(@<')O9VYO<R`H=F%R:F4@9&%G(&)E='ED97(@96X@<')O9VYO
M<R!F]G(@9&%G(&]C:"!E;B!F]G(@;F%T="D`1VSV;70@9&ET="!L]G-E;F]R
M9#\`1F]R;75LY'(`5FES:&5T<V]R9`!4>7`@878@=FES:&5T<V]R9`!6:7-H
M971S;W)D`%9I<VAE='-O<F0@,@!&;W)U;0!6:61A<F)E9F]R9')A`%9I9&%R
M8F]R9')A;B!S=/9D<R!I;G1E(&%V(&%K='5E;&P@9FEL=&5R9')I=G)U=&EN
M+@!6:61A<F)E9F]R9')A<@#$;F1R82!V:61A<F)E9F]R9')A;@!&<@!286UA
M<@!&<F%N:W)I:V4`1G)A;FMR:6ME+"!-971R;W!O;`!,961I9R]5<'!T86=E
M;B!I;F9O<FUA=&EO;@!,961I9R]5<'!T86=E;B!S=F%R`$QE9&EG+W5P<'1A
M9V5N+6;V<F9RY6=A;@!3=F%R('#E(&QE9&EG+W5P<'1A9V5N+6;V<F9RY6=A
M;@!&<F%N<VMA($=U:6%N80!&<F%N<VMA(%!O;'EN97-I96X`1G)A;G-K82!S
M]F1R82!T97)R:71O<FEE<@!&<N5N`$9RY6X@9&5N(`!&<N5N.@!&=6QL<W3D
M;F1I9R!B97-K<FEV;FEN9P!&=6QL;>5N90!&=6QL<W3D;F1I9W0@;F%M;@!'
M86)O;@!'86QL97)I(&%T="!T82!B:6QD(&9RY6X`1V%L;&5R:3H`1V%M8FEA
M`$=E;F5R97)A(&MO;F9I9W5R871I;VX@9O9R("5S`$=E;F5R97)A9"!K;V0`
M1V5O<F=I96X`5'ES:VQA;F0`1VAA;F$`1VEB<F%L=&%R`$;V<FYA;6X`1VQO
M8F%L82!I;G-TY&QL;FEN9V%R`$]+`$=O961E;`!';V]G;&5K87)T;W(`1V]O
M9VQE<_9K;FEN9P!'<N5S:V%L80!3=/9R<F4@Y&X`4W3V<G)E(.1N(&5L;&5R
M(&QI:V$@;65D`$=R96MI<VL@*$E33RTX.#4Y+3<I`$=R]FX`1W+V;FQA;F0`
M1W)A;F%D80!'<N4`1W)U<'!A9&UI;FES=')A=&EO;@!'<F]U<%]L9&%P.B!+
M86X@:6YT92!LY&=G82!T:6QL(&=R=7!P("<E<R<N(%-E<G9E<FX@<W9A<F%D
M93H@`$=R;W5P7VQD87`Z($MA;B!I;G1E(')A9&5R82!G<G5P<"`G)7,G`$=R
M;W5P7VQD87`Z($MA;B!I;G1E('5P<&1A=&5R82!G<G5P<"`G)7,G`$=R=7!P
M97(`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1^1S=&)E:/9R:6=H971E<@!4
M:N1N<W1E<B!F]G(@9^1S=&5R`$?D<W1B;VL`1W5I;F5A`$=U:6YE82U":7-S
M874`1W5I;F5A`$A434P`2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@<VES
M=&$@8V5L;&5N(&D@96X@<F%D+@!(5$U,07)E82!VY&=R87(@871T(')A9&5R
M82!S:7-T82!K;VQU;6YE;B!I(&5N('1A8F5L;"X`2%1-3$%R96$@=N1G<F%R
M(&%T="!R861E<F$@<VES=&$@<F%D96X@:2!E;B!T86)E;&PN`$A45%`@075T
M96YT:7-E<FEN9R!S86MN87,N`$AA:71I`$AA<VAA;&=O<FET;0!$:6UM80!2
M=6)R:6L`4G5B<FEK97(`2&5A<F0M(&]C:"!-8T1O;F%L9/9A<FYA`$MR869T
M:6=A(.5S:W-K=7)A<@!(96)R96ES:R`H25-/+3@X-3DM."U)*0!(]FID`$CV
M:F0@*'!I>&QA<BD`2&KD;'``2&KD;'`@;65D(&5D:71O<FX`2&KD;'!F=6YK
M=&EO;@!(96UI<V;D<@!(Y'(@Y'(@8O9R:F%N(&%V(&9I;&5N.@!(]F<`2&5?
M;0!(96T`061R97-S+"!H96T`2&5M:V%T86QO9P!496QE9F]N+"!H96T`2&]N
M9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!/9VEL=&EG="`E
M<R!834PM9&%T82!PY71RY&9F861E<R!I(&UE9&1E;&%N9&4@)7,`2&]R9&4O
M2V]L86(Z($EN9V5T(&UE9&1E;&%N9&4@;6%T8VAA<B!O8FIE:W1E="`E<P!(
M;W)D92]+;VQA;CH@26YG970@;V)J96MT(&%V('1Y<&5N("5S(&AI='1A9&5S
M(&D@;65D9&5L86YD970@)7,`2&]R9&4O2V]L86(Z(%)A9&5R861E("5S("<E
M<R<`2&]R9&4O2V]L86(Z($EN=&5G<F%T:6]N<VUO=&]R;B!K<N1V97(@)V1O
M;7AM;"<M=&EL;.1G9V5T(&;V<B!02%``2&]R9&4O2V]L86(Z($MA;B!I;G1E
M('-K87!A(&YY='0@6$U,+71RY&0@9O9R(&]B:F5K="`E<P!(;W)D92]+;VQA
M8CH@2V%N(&EN=&4@<F%D97)A("5S("<E<R<Z("5S`$AO<F1E+TMO;&%B.B!+
M86X@:6YT92!HY&UT82!-24U$12U)1"!F]G(@9&5L96X@;65D('1Y<"`E<P!(
M;W)D92]+;VQA8CH@2V%N(&EN=&4@<WEN:W)O;FES97)A("5S("<E<R<Z("5S
M`$AO<F1E+TMO;&%B.B!+86X@:6YT92!S>6YK<F]N:7-E<F$@=71D96QN:6YG
M87(Z("5S`$AO<F1E+TMO;&%B.B!/:^1N9"!U=&1E;&YI;F<@)R5S)P!(;W)I
M<V]N=&5L;"!L:6YJ90!(;W)I<V]N=&5L;"!U=&9Y;&QN860`2&]R:7-O;G1E
M;&PZ`$AU<B!H86UN861E(&1U(&CD<C\@*%9A<B!G;V0@<F%P<&]R=&5R82!D
M971T82$I`$AU<B!MY6YG82!K;VQU;6YE<B!V:6QL(&1U('-LY2!I:&]P/P!(
M=7(@;>5N9V$@9N1L="`H:V]L=6UN97(I(&9I;FYS(&1E=#\`2'5R(&WE;F=A
M(')A9&5R('9I;&P@9'4@<VSE('-A;6UA;C\`1G5K=&EG:&5T`$9U:W1I9VAE
M=#H`2'5M;W)I<W1E<@!5;F=E<FX`4VMA<&%N9&4@878@24U!4"UM87!P(&UI
M<W-L>6-K861E.B`E<P!2861E<FEN9R!A=B!)34%0+6UA<'`@;6ES<VQY8VMA
M9&5S.B`E<P!3:V%P86YD92!A=B!Q=6]T82!F]G(@24U!4"UM87!P(&UI<W-L
M>6-K861E<SH@)7,`25`M861R97-S`$E0+6%D<F5S<R#D<B!I;G1E('1I;&QG
MY&YG;&EG+@!)4"UA9')E<W,@Y'(@:6YT92!I;F]M(&=O9&OD;G0@0TE$4BUB
M;&]C:RX`1O9R<_9K(&%T="!K<FEN9V?E($E0+6SE<RX`25]N9F]G82!R860@
M9O9R90!)<VQA;F0`16YB87)T(&EK;VYE<@!):V]N97(@9O9R("5S`$EK;VYE
M<B!M960@=&5X=`!)9&5N=&ET971E;G,@;F%M;CH`3VT@9&5T(&EN=&4@=FES
M87,@:V]R<F5K="P@)7,@9O9R(&%T="#V<'!N82!I(&YY='0@9O9N<W1E<BX`
M3VT@9'4@:6YT92!S97(@;N5G<F$@:6MO;F5R(&[D<B!D=2!A;G;D;F1E<B!)
M;G1E<FYE="!%>'!L;W)E<BP@<^4@:V%N(&1U(&)E:/9V82!M87)K97)A(&1E
M;FYA(')U=&$@9O9R(&%T="!S=.1N9V$@878@9V5N;VUS:VEN;&EG82!03D<M
M8FEL9&9I;&5R+@!/;2!D=2!S97(@9&5N;F$@=&5X="!M96X@:6YG96X@8FEL
M9"P@<^4@:V%N(&EN=&4@9&EN('=E8F)LY'-A<F4@=FES82!D96X@8FEL9"!D
M=2!F]G)S]FME<B!L861D82!U<'`N`$;V<FAA;F1S9W)A;G-K82!B:6QD.@!"
M:6QD861R97-S`$)I;&1A9')E<W,Z`$)I;&0@9G+E;B!G86QL97)I`$)I;&0@
M9G+E;B!G86QL97)I.@!,861D82!U<'`@8FEL9`!":6QD97(`26UP;W)T97)A
M+"!S=&5G("5D`%9I:W1I9W0`26UP;W)T97)A9&4@9N1L=#H@)7,`26UP;W)T
M97)A9&4@9N1L=#H`4.5GY65N9&4`26Y?9F]G82!R860@969T97(`1F5L86MT
M:78@86MT:79I=&5T<VMO9"!S<&5C:69I8V5R860N`$9E;&%K=&EG="!A;G;D
M;F1A<FYA;6X@;V-H+V5L;&5R(&SV<V5N;W)D+@!/9VEL=&EG="!A;G;D;F1A
M<FYA;6X@96QL97(@86QT97)N871I=B!A9')E<W,N($;V<G/V:R!I9V5N(&5L
M;&5R(&MO;G1A:W1A(&%D;6EN:7-T<F%T]G)E;B!O;2!D=2!B96CV=F5R(&AJ
MY&QP+@#6:V$@:6YD<F%G`$EN9&EE;@!);F1I=FED=65L;&$@86YVY&YD87)E
M`%!E<G-O;FQI9V$@<F5G;&5R('-T]F1S(&EN=&4@878@86MT=65L;"!F:6QT
M<F5R:6YG<W)U=&EN+@!);F1O;F5S:65N`$%N9VEV96X@;6%P<"!F]G(@92U0
M;W-T(&QE=F5R86YS('-A:VYA<RX`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA
M=&EO;B#D<B!I;G1E('1I;&QGY&YG;&EG(&SD;F=R92X`26YF;V=A(&M?;VQU
M;6X@969T97(`26YF;V=A(&)I;&0`26YF;V=A('1A8F5L;`!);F9O9V$@=V5B
M8FSD;FL`26YF;V=A(%]K;VQU;6X@9O9R90!);F9O9V$@;GD@:V]L=6UN(&5F
M=&5R(&%K='5E;&P@:V]L=6UN`$EN9F]G82!N>2!K;VQU;6X@9O9R92!A:W1U
M96QL(&MO;'5M;@!);F9O9V$@<F%D(&5F=&5R(&%K='5E;&P@<F%D`$EN9F]G
M82!N>2!R860@9O9R92!E:W1U96QL(')A9`!);F9O9V$@<&%R86=R868@969T
M97(@86MT=65L;"!N;V0`26YF;V=A('!A<F%G<F%F(&;V<F4@86MT=65L;"!N
M;V0`26YF;V=A(&%L=&5R;F%T:78@;6%L;`!);F9O9V$@8V5L;"!E9G1E<@!)
M;F9O9V$@8V5L;"!F]G)E`$EN9F]G82!K;VQU;6X@969T97(`26YF;V=A(&MO
M;'5M;B!F]G)E`$EN9F]G82!M961D96QA;F1E;@!);F9O9V$@<&%R86=R868@
M969T97(`26YF;V=A('!A<F%G<F%F(&;V<F4`26YF;V=A(')A9"!E9G1E<@!)
M;F9O9V$@<F%D(&;V<F4`06YG92!E<F9O<F1R870@<W9A<B!T:6QL('/D:V5R
M:&5T<V9RY6=A;CH`26YF;V=A+\1N9')A(&)I;&0`26YF;V=A+\1N9')A(&SD
M;FL`3W1I;&QRY&-K;&EG(&MR961I="!F]G(@871T('-K:6-K82!T:6QL(&1I
M<W1R:6)U=&EO;G-L:7-T82X`3W1I;&QRY&-K;&EG(&MR961I="X`2&5L=&%L
M`$AE;'1A;'-L:7-T80!/9VEL=&EG(.5T9^1R9"!F]G(@9&5N(&CD<B!K;VUP
M;VYE;G1E;BX`3V=I;'1I9R!51$@@*"=U<V5R(&1A=&$@:&5A9&5R)RDN`$]G
M:6QT:6=T(%I)4"UA<FMI=F1A=&$`1F5L86MT:6<@87!P;&EK871I;VXN`$9E
M;&%K=&EG="!B871C:"U)1`!&96QA:W1I9R!D871A('-K:6-K860N`$9E;&%K
M=&EG(&1E<W1I;F%T:6]N<V%D<F5S<RX`1F5L86MT:6=T(&9I;&9O<FUA=`!/
M9VEL=&EG(&QI8V5N<VYY8VME;"X`1F5L86MT:6<@;W)T('-P96-I9FEC97)A
M9"X`1F5L86MT:6<@;65D9&5L86YD95]T>7`N`$9E;&%K=&EG(&5L;&5R('-A
M:VYA9"!A<&E?:60N`$9E;&%K=&EG="!E;&QE<B!S86MN860@<&%R86UE=&5R
M+@!&96QA:W1I9R#V=F5R;&EG9V%N9&4@8F5H]G)I9VAE="X`1F5L86MT:6=T
M('!A<G1N97(M:60N`$9E;&%K=&EG('!R;V1U:W1K;V0N`$9E;&%K=&EG="!P
M<F]T;VMO;&PN`$9E;&%K=&EG(&UO='1A9V%R93H@)R5S)P!&96QA:W1I9W0@
M=71D96QN:6YG<V]B:F5K=`!&96QA:W1I9R!A=G/D;F1A<F%D<F5S<RX`1F5L
M86MT:6=T('5N:6-O9&4M9&%T80!);G9E;G1A<FEE<@!);G9E<G1E<F$@=7)V
M86P`27)A;@!)<F%K`$ER;&%N9`#$<@!)<VQE(&]F($UA;@#$<B!I;G1E`$5N
M<W1A:V$@Y7-K<VMU<F%R`$ES<F%E;`!5=&;D<F1A="!A=@!+=7)S:78`271A
M;&EE;@!*86UA:6-A`&IA;G5A<FD`2F%P86X`2F%P86YS:R`H25-/+3(P,C(M
M2E`I`$IE<G-E>0!*;W)D86YI96X`:G5L:0!J=6YI`$IU<W1E<F$`0V5N=&5R
M:G5S=&5R80!*=7-T97)A(&KD;70`5N1N<W1E<FIU<W1E<F$`2/9G97)J=7-T
M97)A`$ME;GEA`$ME<F)E<F]S<V5R=F5R;B!A=G9I<V%D92!A=71E;G1I<V5R
M:6YG96XN`$YY8VME;"!S:V%P860`1FEN9V5R<')I;G0`3GEC:V5L;.1N9V0`
M3GEC:V5L='EP`$YY8VME;&%N=N1N9&%N9&4`3GEC:V5L(&9I;FYS(')E9&%N
M('#E(&1E;B!P=6)L:6MA(&YY8VME;'-E<G9E<FXN`$)A<FX`2VER:6)A=&D`
M2V]L86(`3F]R9&MO<F5A`%-Y9&MO<F5A`$MO<F5A;G-K("A%54,M2U(I`$MU
M=V%I=`!+:7)G:7-T86X`3$1!4"US=/9D(&MRY'9S+"!M96X@3$1!4"UM;V1U
M;&5N(.1R(&EN=&4@=&EL;&?D;F=L:6<@96QL97(@;&%D9&%D+@!,85]Y;W5T
M`%-P<N5K`$QA;W,`4VES=&$@:&%L=F%N`$SV<V5N;W)D(.1N9')A9&5S`%-I
M<W1A(&MV87)T86QE=`!396YA<W0@=7!P9&%T97)A9#H`4V5N87-T92!I;FQO
M9V=N:6YG.B`E<P!396YA<W1E(&EN;&]G9VYI;F<Z("5S(&9RY6X@)7,`4V5N
M87-T92!I;FQO9V=N:6YG.B!!;&1R:6<`3&5T=&QA;F0`3&%V96YD97(`3&%G
M`$QA>6]U=`!,Y&UN82!T;VT@9O9R(&%T="!S=.1N9V$@878@:V%N=&QI;FIE
M`$QI8F%N;VX`5N1N<W1E<@!6Y&YS=&5R<G5B<FEK`%;D;G-T97)VY')D96X`
M3&5S;W1H;P!-:6YD<F4@Y&X`36EN9')E(.1N(&5L;&5R(&QI:V$@;65D`$YI
M=N4`3&EB97)I80!,:6)Y96X`3&EE8VAT96YS=&5I;@!,:G5S8FSE`$1U9V=R
M96=N`$SD='0@<F5G;@!,Y'1T(&;V<FUI9&1A9W-R96=N`$SD='0@969T97)M
M:61D86=S<F5G;@!,Y'1T(')E9VYS:W5R`$SD='0@<F5G;B!M960@Y7-K80!,
MY'1T('-N]@!,Y'1T('-N]G-K=7(`3&EM97)I8VL`3.1N:P!,Y&YK96X@<&5K
M87(@<.4Z`$SD;FMA(&4M<&]S=&%D<F5S<V5N('1I;&P@9G5N:W1I;VYE;B!F
M]G(@871T('-K87!A(&YY='0@;65D9&5L86YD90!,Y&YK87(`2V%K80!,:7-T
M82`M(&%N=N1N9&%R92!K86X@<V4@;6%P<&5N`%9I<V$@9&%T86)A<V5R`%9I
M<V$@:&KD;'#D;6YE;@!,:7-T82!T86)E;&QE<@!,:7-T+4%R8VAI=F4`3&ES
M="U(96QP`$QI<W0M240`3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,
M:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$1E="!G:6-K(&EN=&4@
M871T(&QI<W1A('-E<W-I;VYE<CH@)7,`1&5T(&=I8VL@:6YT92!A='0@;&ES
M=&$@86YVY&YD87)E.B`E<P!,:7-T;FEN9R!A=B!A;G;D;F1A<F4@879A:W1I
M=F5R860N`$QI='1E<F%T=7(`3&ET875E;@!,861D87(N+BX`3&]K86P@=&ED
M.B``4F5G:6]N86QT`%!L871S`$QO9V=A(&EN`$QO9V=A('5T`$QO9VEN`$QO
M9VEN86MT:79I=&5T97(`26YL;V=G;FEN9R!M:7-S;'EC:V%D97,N(%1R;VQI
M9W1V:7,@=F%R(&%N=N1N9&%R;F%M;B!E;&QE<B!L]G-E;F]R9"!F96QA:W1I
M9W0N`$EN;&]G9VYI;F<@;6ES<VQY8VMA9&5S+@!,Y6YG('1E>'0`2^1R;&5K
M`$SE9P!'<F5K:7-K82!G96UE;F5R`$QA=&EN<VMA(&=E;65N97(`4VWE(')O
M;65R<VMA('-I9F9R;W(`3&]Y;VQA`$QO>6]L82!";.4`3'5X96UB=7)G`$U-
M`$U/5$0`35,M5$Y%1B!B:6QA9V$@:6YN96CV;&P@:6YG96X@9&%T82X`35-'
M`$UA8V%O`$UA8V5D;VYI96X`36%G86=A<VMA<@!-86=I<VL`12UP;W-T`$4M
M<&]S=&%D;6EN`%-K87!A(&SD;FLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I
M=F5R;F$`36%L:0!-86QT80!5;F1E<FCE;&P@;&ES=&%N(&UE9"!K871E9V]R
M:65R(&1U(&%N=N1N9&5R(&;V<B!A='0@:V%T96=O<FES97)A('!O<W1E<B!M
M960@;V-H(&;D<F=E<FYA('-O;2!T:6QL:/9R(&1E<W-A(&MA=&5G;W)I97(N
M`$UA<#(T+6MA<G1A`$UA<%%U97-T+6MA<G1A`-9V97)SY'1T;FEN9V%R('-P
M87)A9&4N`$UA<E]K97)A(&UE9&1E;&%N9&4@<V]M(')A9&5R870`;6%R<P!-
M87)G:6YA;`!-87)K97)A(&UE9&1E;&%N9&4@<V]M.@!&;&%G9V$@<V]M(&SD
M<W0O;VSD<W0`1FQA9V=A(&UE9"!A;FYA;B!S=&%T=7,@*'0@97@@=FEK=&EG
M="]B97-V87)A="D`36%R<VAA;&SV87)N80!-87)T:6YI<75E`$UA=&-H87(`
M36%T8VAA;F1E(&;D;'0`36%U<FET86YI96X`36%U<FET:75S`$UA>"!T:6QL
MY71E;B!K<F5D:70N`$=RY&YS(&;V<B!M87@@86YT86P@9&5L87(@:2!M961D
M96QA;F1E(/9V97)S:W)I9&5N+@!(]F=S=&$@=&5M<&5R871U<F4@<V5N87-T
M92`R-"!T:6UM87)N83H@`$CV9W-T82!T96UP97)A='5R92!S96YA<W1E(#8@
M=&EM;6%R;F$Z(`!-87AI;6%L="!A;G1A;"!P;W)T86QB;&]C:P!-87@@86YT
M86P@<F5G;&5R`$UA>&EM86P@;.1N9V0`36%X:6UA;'0@86YT86P@<W#D<G)A
M9&4@861R97-S97(@Y'(@]G9E<G-K<FED96X@*%1O=&%L=#H@)7,L($UA>&EM
M86QT.B`E<RDN($MA;B!I;G1E(&SD9V=A('1I;&P@861R97-S96X@:2!L:7-T
M86X@;65D('-PY')R861E(&%D<F5S<V5R+@!-87AI;6%L="!A;G1A;"!B971R
M;V1D82!A9')E<W-E<B#D<B#V=F5R<VMR:61E;B`H5&]T86QT.B`E<RP@36%X
M:6UA;'0Z("5S*2X@2V%N(&EN=&4@;.1G9V$@=&EL;"!A9')E<W-E;B!L:7-T
M86X@]G9E<B!B971R;V1D82!A9')E<W-E<BX`;6%J`$UA>6]T=&4`365D:6-I
M;@!!=F)O:V$@;?9T90!-]G1E<VEN9F]R;6%T:6]N`$WV=&5S9O9R9G+E9V%N
M`$WV=&5S<W9A<@!-]G1E<W5P<&1A=&5R:6YG`%5P<&1A=&5R:6YG<V)E9^1R
M86X@;VT@;?9T90!-961L96UM87(`365N>6SD9V4Z`%-LY2!I:&]P(&-E;&QE
M<@!-961D96QA;F1E`$UE9&1E;&%N9&5T('9E<FEF:65R861E<R!M96X@9&5N
M('-I9VYE<F%D97,@8V5R=&EF:6MA="!K=6YD92!I;G1E('9E<FEF:65R87,N
M`$UE9&1E;&%N9&4@9^1L;&5R(&EN=&4@;.1N9W)E+@!-961D96QA;F1E='EP
M`$UE=&%R=N1D97(`365T87)B;&]C:V5T(.1R(&EN=&4@=&EL;&?D;F=L:70N
M`$UE=&%R+6)L;V-K(&5J('1I;&QGY&YG;&EG="X@1&5T86QJ97(@:&%R(&QO
M9V=A=',@9O9R('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BX`365T87)$0B#D<B!I
M;G1E(&%N<VQU=&5N+@!-971O9`!-971O9&5N("<E<R<@Y'(@:6YT92!D969I
M;FEE<F%D`$UE=&]D96X@:&%R(&EN=&4@9&5F:6YE<F%T<RX@06YR;W!A9"!M
M971O9#H@)7,`365T<FES:P!-97AI:V\`36EK<F]N97-I96X`36ET=&5N`$UI
M;65T>7``3.1G<W1A('1E;7!E<F%T=7(@<V5N87-T92`R-"!T:6UM87)N83H@
M`$SD9W-T82!T96UP97)A='5R('-E;F%S=&4@-B!T:6UM87)N83H@`$UI;G-T
M82!L]G-E;F]R9'/E;&1E<B!H87(@:6YT92!U<'!NY71T<R#D;@!3<&5G;&$`
M1&EV97)S90!/8FQI9V%T;W)I<VMT('!A:V5T('-A:VYA<R`H4$5!4B!(5%10
M7U)E<75E<W0I+@!!9')E<W,@871T('-K:6-K82!N;W1I9FEE<FEN9V%R('1I
M;&P@<V%K;F%S`$%D<F5S<R!A='0@<VMI8VMA('9I9&%R92!T:6QL('-A:VYA
M<P!+;VYF:6=U<F%T:6]N('-A:VYA<RX@1'4@;>5S=&4@<VMA<&$@9&5N(&YU
M(&]M(&1U('9I;&P@86YVY&YD82!D96X@:.1R(&%P<&QI:V%T:6]N96XN`%-A
M:VYA<B!M961D96QA;F1E+4E$+@!!;FQE9&YI;F<@=&EL;"!A='0@9O9R:V%S
M=&$@<V%K;F%S`%-E;65S=&5R;F]T97)I;F<@<V%K;F%S+@!/8FQI9V%T;W)I
M<VMT('!A:V5T('-A:VYA<R`H4$5!4B!-86EL*2X`4V%K;F%R('-E<W-I;VYS
M+4E$+@!-Y0!-;V)I;"!E+7!O<W0`36]D97)E<F$`Q&YD<F%D(&1A='5M`,1N
M9')A(&SD;FL`36]D=6QU<P!-;VQD879I96X`36]N86-O`$UO;F=O;&EE=`!-
MY6YA9"!O8V@@Y7(`3>5N871L:6<`36]T<V5R<F%T`$WE;F9A<V5R`$9L97(@
M9N1L="!H:71T861E<R!PY2!R860@)60@Y&X@9&5T(&;V<G;D;G1A9&4@)60N
M`$UA<F]C:V\`365S=&%D96QS(&ML87)T`$UE<W1A9&5L<R!M;VQN:6=T`$UE
M<W1A9&5L<R!S;VQI9W0`1FQY='1A`$9L>71T82!N960`1FQY='1A(';D;G-T
M97(`1FQY='1A(&CV9V5R`$9L>71T82!N97(@<F5G96P`1FQY='1A('5P<"!R
M96=E;`!&;'ET=&$@=7!P`$9L>71T82!N960`1FQY='1A('5P<`!-;^=A;6)I
M<75E`$UO>FEL;&$`1FQE<FYI=N5S;&ES=&$`375L=&EM87`@4W1O<F)R:71A
M;FYI96YK87)T80!&;&5R=F%L`$UI='0@:V]N=&\`36EN(&MO;G1O:6YF;W)M
M871I;VX`36EN('!O<G1A;`!-:6X@<&]R=&%L;&%Y;W5T`$UY86YM87(`3D5*
M+"!*86<@86-C97!T97)A<B!I;G1E`%]!;G1A;"!D86=A<B!M96QL86X@<V5M
M97-T97)S=F%R.@!.86UN`$YA;6EB:6$`3F%U<G4`3F585`!"96CV=F5R(.5T
M9^1R9`!.97!A;`!.961E<FSD;F1E<FYA`$YE9&5R;.1N9'-K82!!;G1I;&QE
M<FYA`$YE<V-A<&4@8F%S+5523`!.971S8V%P92!F]G)N>65L<V4M55),`$YE
M='-C87!E(.5T97)K86QL96QS92U54DP`3F5T<V-A<&4@4U-,+7-E<G9E<FYA
M;6X`3F5T<V%P92!C97)T:69I:V%T<VMO;6UE;G1A<@!.971S87!E(&-E<G1I
M9FEK871S='EP`$[D='9E<FL`06QD<FEG`$YY82!+86QE9&]N:65N`$YY(&MA
M=&5G;W)I`$YY='0@;65D9&5L86YD92!T:6QL("5S`$YY;>5N90!.>2!R96=E
M;`!.>71T(&%N=N1N9&%R;F%M;B`H=F%L9G)I='0I`$YY82!:965L86YD`$YY
M='0@;/9S96YO<F0`3GET="!L]G-E;F]R9"!K;VUM97(@871T(&?E('5T("5X
M+@!,]G-E;F]R9"!MY7-T92!V87)A('-A;6UA+@!.>71T(&;V;G-T97(@*%]B
M;&%N:RD`3GEH971E<@!.>6AE='-G<G5P<&5R`$[D<W1A`$MO;6UA;F1E(#0@
M9F%S97(`3N1S=&$@:6YS=.1L;&YI;F=A<@!.Y'-T83X`3FEC87)A9W5A`$YI
M9V5R`$YI9V5R:6$`3F%T=`!.:75E`$YE:@!);F=E="`G)7,G+6]B:F5K="!F
M:6YN<R!I("=B86-K96YD)RUK;VYF:6=U<F%T:6]N96X`1&5T(&9I;FYS(&EN
M9V5T(&MO;F9I9W5R871I;VYS9&%T82!A='0@=FES82!S:VEL;&YA9&5R(&;V
M<BX`26YG96X@=&EL;&?D;F=L:6<@<W1R871E9VD@9O9R(&%T="!S:V%P82!)
M4T\M:6UA9V4N`$EN9V5N("=B86-K96YD)R!K;VYF:6=U<F5R861E(&;V<B!D
M96YN82!VY')D`$EN9V$@)V)A8VME;F1S)R!K;VYF:6=U<F5R861E`$EN=&4@
M96X@8F%T8VAM86QL+@!$970@9FEN;G,@:6YG970@8FQO8VL@<.4@9&5N(&)E
M9^1R9&$@<&]S:71I;VYE;@!);F=E="!K86QE;F1E<FYA;6X@9O9R($U#04P@
M875T96YT:7-E<FEN9R!A;F=I=F5T+@!);F=E;B#D;F1R:6YG+@!);F=A('5N
M9&5R8F5H]G)I9VAE=&5R(&MA;B!LY&=G87,@=&EL;"!D96X@:.1R(&)E:/9R
M:6=H971E;BX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I
M=F5N(&;V<B`E<RX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A
M;F=I=F5N(&;V<B!&5%`@5D93+@!);F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R
M;6%T:6]N(&%N9VEV96X@9O9R(%-13"!61E,N`$EN9V5N(&MO;F9I9W5R97)I
M;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@4U%,+69I;"!61E,N`$EN9V5N
M(&MR961I="!K=F%R+@!"97-K<FEV;FEN9R!S86MN87,N`$EN9V5N(&UO='1A
M9V%R92!A;F=I=F5N+@!);F=E;B!F:6P@=7!P;&%D9&%D`$9I;'1E<B!S86MN
M87,N($ML:6-K82!PY2`G)7,G(&;V<B!A='0@<VMA<&$@971T(&YY='0N`$EN
M=&4@<G5B<FEK97(@<W!E8VEF:6-E<F%D90!);F=A(&EK;VYE<B!H:71T861E
M<RX`26YG96X@;W)T(&%N9VEV96XN`$EN9V5N(&]R="!A;F=I=F5N+@!);F=E
M="!M961D96QA;F1E(&)I9F]G861E<RX`26YG970@;F%M;B!A;F=I=F5T+@!)
M;F=E;B!N=6UM97(@86YG:79E="X`26YG82!O9O9R<VOD;61A('9I<VAE='-O
M<F0`26YG970@;/9S96YO<F0@9O9R($A45%`M875T96YT:7-E<FEN9R!A;F=I
M=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@24U!4"UA=71E;G1I<V5R:6YG(&%N
M9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!+97)B97)O<RUA=71E;G1I<V5R
M:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!,;V=I;BUA=71E;G1I
M<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!005-35T0M875T
M96YT:7-E<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@4TU"+6%U
M=&5N=&ES97)I;F<@86YG:79E="X`26YG82!VY&YT86YD92!R96=I<W1R97)I
M;F=A<BX`26YG96X@:W9O=&$@86YG:79E;@!);F=E;B!K=F]T82!A;F=I=F5N
M+@!);F=A(')E9VQE<@!3:W)I<'1E="!S:V%P861E<R!I;G1E`$EN9V5N(&%V
M9W+D;G-A<F4@86YG:79E;BX`26YG82!S:61O<@!);F=A('-T<N1N9V%R('-P
M96-I9FEC97)A9&4`26YG96X@<^5D86X@9FEL`$EN9V5N('1E;7!O<N1R:V%T
M86QO9R!T:6QL9^1N9VQI9R!F]G(@8V%C:&4N`$EN9V5T(&%N=N1N9&%R;F%M
M;B!O8V@O96QL97(@;/9S96YO<F0@<VMI8VMA="X`26YG970@9VEL=&EG(%A-
M3"UD871A(')E='5R;F5R861E<P!);F=A(';D<F1E;@!);F=E;B!V97)S:6]N
M(&AI='1A9&5S(&D@9&5N('5R<W!R=6YG;&EG82!K;VYF:6=U<F%T:6]N96XN
M(,5T97)S:V%P82!K;VYF:6=U<F%T:6]N96XN`$EN9V5N('9E<G-I;VX@:&ET
M=&%D97,@:2!D:6X@:V]N9FEG=7)A=&EO;BX@Q71E<G-K87!A(&MO;F9I9W5R
M871I;VYE;BX`26-K92UD96QT86=A<F4`26YG96X`26YG96X@*&%N=N1N9"!U
M;F1E<F;V<G-TY61D*0!.;W)F;VQK]F%R;F$`3F]R<F$@:&5M:7-FY')E;@!.
M;W)R82!-87)I86YA]F%R;F$`3F]R9V4`26YT92!E9G1E<@!);G1E(&;V<F4`
M26YT92!E;B!K871A;&]G`$EN=&4@;&EK82!M960`16H@:6UP;&5M96YT97)A
M9"X`16H@86YG:79E;@!3=/9D<R!I;G1E+@!!;G1E8VMN:6YG87(`26YG96YT
M:6YG(&%T="!V:7-A+"!GY2!T:6QL8F%K82X`3T)3`$4M<&]S=&%D<F5S<R!F
M]G(@;F]T:69I97)I;F=A<@!N;W9E;6)E<@!.=6UM97(`06YT86P@=&5C:V5N
M`$%N=&%L(&MO;'5M;F5R`$%N=&%L(')A9&5R`$YU;6UE<B!I;G1E('-P96-I
M9FEC97)A9&4@9O9R(&%T="!U<'!D871E<F$@:2!D:7-T<FEB=71I;VYS;&ES
M=&%N+@!/2P!/8FIE:W0`3V)J96MT<VMA<&%R90!/:W1A;`!O:W1O8F5R`$9I
M;'1E<B!F]G(@;V;V<G-KY&UD:&5T97(`2V]N=&]R`$=A;6UA;'0@;V-H(&YY
M='0@;/9S96YO<F0@9N5R(&EN=&4@=F%R82!S86UM82X`1V%M;6%L="!L]G-E
M;F]R9`!'86UM86QT(&SV<V5N;W)D(.1R(&9E;&%K=&EG=`!/;6%N`$1E;&%D
M92!M87!P87(@<W3V9',@96YB87)T(&%V($E-05`M<V5R=G)A<@!&;&%G9V$@
M96YD87-T(&UE9&1E;&%N9&5T`$5N8F%R="!O9O9R<VOD;61A('9I<VAE='-O
M<F0`16YD87-T(&5N(&4M<&]S=&%D<F5S<R!T:6QLY71E;BX`16YD87-T(.1G
M87)E(&5L;&5R('-Y<W1E;6%D;6EN:7-T<F%T]G(@:V%N(.1N9')A(.1G87)E
M(&5L;&5R(&)E:/9R:6=H971E<B!PY2!E;B!U=&1E;&YI;F<`UG!P;F$@:2!N
M>71T(&;V;G-T97(`3W!E;E-33"UF96PZ($1E="!G:6-K(&EN=&4@871T(&5X
M=')A:&5R82!D871A(&9RY6X@<VEG;F5R860@4R]-24U%+61E;"X`UG!P;F$@
M;.1N:R!I(&YY='0@9O9N<W1E<@!/<&5R871I=G-Y<W1E;0!)8VME(&]B;&EG
M871O<FES:V$@9&5L=&%G87)E`$EN<W3D;&QN:6YG87(`06QT97)N871I=B!O
M;2!U<'!D871E<FEN9R!A=B!S:W)I<'0`26YS=.1L;&YI;F=A<B!F]G(@)7,`
M4V]R=&5R860@;&ES=&$`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;G-E;FAE
M=`!/<F=A;FES97)A`%5R<W!R=6YG;&EG(&%P<&QI:V%T:6]N<VUA;&P`57)S
M<')U;F=L:6=A(&UA;&QA<B!I("5S.@!!;FYA;@!!;F1R82!I;G-TY&QL;FEN
M9V%R`$%N9')A(&EN<W3D;&QN:6YG87(`UG9E<G-I:W0`Q&=A<F)E:/9R:6=H
M971E<@!004TM075T96YT:7-E<FEN9R#D<B!I;G1E('1I;&QGY&YG;&EG+@!0
M14%2.CI-86EL+6MO<'!L:6YG`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@
M16YC<GEP=&5D($1A=&$`4'5B;&EK(%!'4"UN>6-K96P`4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T80!02%`M:V]D`%!(4"US:V%L`$SD='0@9O9R;6ED9&%G
M<W)E9VX`1O9R;6ED9&%G<W)E9VX`169T97)M:61D86=S<VMU<F%R`$5F=&5R
M;6ED9&%G<W-N]@!%9G1E<FUI9&1A9W-S:W5R87(@;65D('-N]@!%9G1E<FUI
M9&1A9W-S;VP`Q7-K<VMU<F%R('#E(&5F=&5R;6ED9&%G96X`4$]325@M=&EL
M;.1G9R!S86MN87,`4%](4"US:V%L`%5T9GEL;&YA9#H`4&%K:7-T86X`4&%L
M874`4&%L97-T:6YA`%!A;F%M80!087!U82U.>6$@1W5I;F5A`%!A<F%G=6%Y
M`$1E;'9I<R!M;VQN:6=T`$SV<V5N;W)D`$SV<V5N;W)D(.1N9')A9&5S+@!,
M]G-E;F]R9"!F96QA:W1I9W0`3/9S96YO<F0@:W+D=G,@9O9R(%)!1$E54R!A
M=71E;G1I<V5R:6YG+@!,]G-E;F]R9"!M960@8F5K<N1F=&5L<V4`3/9S96YO
M<F0Z`$SV<V5N;W)D.B``3/9S96YO<F0@;>5S=&4@=F%R82!L:6MA+@!+;&ES
M=')A(&EN`$ML:7-T<F$@:6X@9G+E;B!U<FML:7!P<VAA;G1E<F%R96X`4_9K
M=N1G`%;D;G1A;F1E(')E9VES=')E<FEN9V%R.@!-Y&YN:7-K;W(`4')O8V5N
M=`!5=&;V<B!U;F1E<FCE;&QS9G5N:W1I;VYE<@!5=&;V<B!U;F1E<FCE;&QS
M86MT:79I=&5T97(@=FED(&EN;&]G9VYI;F<_`$)E:/9R:6=H970`0F5H]G)I
M9VAE="`G)7,G(')A9&5R861E<R!I;G1E+@#%=&MO;7-T(&YE:V%D`&)E:/9R
M:6=H971E<@!"96CV<FEG:&5T<V%D;6EN:7-T<F%T:6]N`%!E<G-O;FQI9R!I
M;F9O<FUA=&EO;@!097)U`$AU<V1J=7(`1FEL:7!P:6YE<FYA`%1E;&5F;VX`
M1F]T;VX`4&ET8V%I<FX`4&EX;&%R`$ML:6-HZ65R`%9A<B!G;V0@:VQI8VMA
M(&D@96X@8V5L;`!"96MRY&9T82!A='0@9'4@=FEL;"!R861E<F$@=F%L9"!P
M;W-T/P!"96MRY&9T82!A='0@9'4@=FEL;"!R861E<F$@86MT=65L;'0@96QE
M;65N="X`5F%R(&=O9"!A;F=E(&WE;F%D(&]C:"#E<BX`5F%R(&=O9"!A;F=E
M(&YA;6X@9O9R(&MA=&5G;W)I;CH`5F%R(&=O9"!A;F=E(&=O9&OD;F0@25`M
M861R97-S+@!687(@9V]D(&%N9V4@971T(&=I;'1I9W0@9&%T=6T[(&MO;G1R
M;VQL97)A(&%N=&%L970@9&%G87(@:2!MY6YA9&5N+@!687(@9V]D(&%N9V4@
M96X@9V]D:^1N9"!T:60N`$%N9V4@;F%M;B!PY2!N>2!M87!P.@!687(@9V]D
M('-U;6UE<F$@9&ET="!P<F]B;&5M+@!!;F=E(&1I='0@86YVY&YD87)N86UN
M(&]C:"!L]G-E;F]R9"X`5F%R(&=O9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E
M>'0N($1U($W%4U1%('-A;71Y8VMA(&UE9"!V:6QL:V]R96X@9O9R(&%T="!A
M;G;D;F1A('-Y<W1E;65T+@!687(@9V]D(&SD<R!I9V5N;VT@9O9L:F%N9&4@
M=&5X="X@1'4@3<535$4@<V%M='EC:V$@;65D('9I;&QK;W)E;B!F]G(@871T
M(&%N=N1N9&$@<WES=&5M970N`$MO;G1R;VQL97)A(&;V;&IA;F1E(&EN9F]R
M;6%T:6]N(&]C:"!VY&QJ('-E9&%N(&5N(&AA;F1L:6YG(&D@;65N>6X*;F5D
M86XN`%;D;&H@96X@:&%N9&QI;F<@9G+E;B!M96YY;B!N961A;BX`06YG92!N
M>71T(&MA=&5G;W)I;F%M;CH`4&]L96X`4&]L:71I:P!5;F1E<G/V:VYI;F=A
M<@!0;W)T=6=A;`!0;W-I=&EO;F5R:6YG(&%V(&)I;&1E;@!0;W-I=&EO;F5R
M:6YG(&%V('1A8F5L;&5N`%-K<FEV('1I;&P@9&5N(&CD<B!M87!P96X@*&5J
M('1V:6YG870@878@24U!4"D`4&]S=&YU:V4`3F5D97)B]G)D(&1E('-E;F%S
M=&4@)7,@=&EM;6%R;F$Z(`!#:&%N<R!T:6QL/&)R+SYN961E<F+V<F0`075T
M:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K;F%S+@!0<F5F<U]S97-S:6]N.B!/
M8FQI9V%T;W)I<VMT('-E<W-I;VYS=&EL;.1G9R!H:71T861E<R!I;G1E+@!4
M<GEC:P!,=69T=')Y8VL@=FED(&AA=F5T.B``3'5F='1R>6-K.B``1O9R:&%N
M9'-V:7-N:6YG`$;V<FAA;F1S9W)A;G-K82!B:6QD(&D@;GET="!F]FYS=&5R
M`$;V<F5GY65N9&4@:6YS=.1L;&YI;F=A<@!3:W)I=B!U="!D;VMU;65N=`!0
M<FEV871A(&YY8VME;`!0<F]B;&5M`%!R;V)L96UB97-K<FEV;FEN9P!0<F]J
M96MT`%1E>'0`4'5B;&EK(&YY8VME;`!0=6)L:6L@;GEC:V5L86QG;W)I=&T`
M4'5B;&EK(&YY8VME;&EN9F]R;6%T:6]N`$9E;"!V:60@9V5N97)E<FEN9R!A
M=B!P=6)L:6MT+W!R:79A="!N>6-K96QP87(N`%!U97)T;R!2:6-O`%)E;G-A
M(&UE9&1E;&%N9&5N`%%A=&%R`$9RY6=A`$MV;W1A`%!U8FQI:R!24T$M;GEC
M:V5L("@E9"!B:71A<BD`7T]R<V%K`$5N<VMI;'0@=F%L`%)E9VX`5&ED:6=T
M(')E9VX`4V5N="!R96=N`%)E9VYS:W5R87(`4F5G;B!O8V@@<V[V`%)E9VX@
M=&EL;"!S;O8`4VQU;7!MY'-S:6=T('9I<VAE='-O<F0`1O9R:.5L;&%N9&4`
M3.1S`$SD<R!M961D96QA;F1E;@!3Y&ME<G0@871T(&1U('9I;&P@<F%D97)A
M("5S/R!2861E<FEN9V5N(&MA;B!I;G1E(.5N9W)A<RX`4^1K97)T(&%T="!D
M=2!V:6QL(')A9&5R82!A;G;D;F1A<F1A=&$@9O9R("5S/R!2861E<FEN9V5N
M(&MA;B!I;G1E(.5N9W)A<RX`36]T=&%G970`169T97)SY&YD('1I;&P`1_9R
M(&]M(&1I;B!S96YA<W1E(&EN;6%T;FEN9P!5<'!D871E<F$`57!P9&%T97)A
M(&1Y;F%M:7-K82!M96YY96QE;65N=#H`57!P9&%T97)A('!O<G1A;'9Y.@!2
M96=E>`!296=U;&KD<F$@=71T<GEC:P!&]G)K87-T82!M960@;W)S86ME;@!6
M:7-A(&;V<FCE;&QA;F1E;@!,861D82!O;0!+;VUM96YT87)E<@!+;VT@:6CE
M9R!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;BX`1FKD<G)S97)V<F%R
M`%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%1A(&)O<G0`
M5&$@8F]R="!B;&]C:P!482!B;W)T(&MO;'5M;@!482!B;W)T(&9O<FUA=&5R
M:6YG`%1A(&)O<G0@9G+E;B!M:6X@:V%L96YD97(`5&$@8F]R="!P87(`4F%D
M97)A('-P87)A="!S:W)I<'0@9G+E;B!S97)V97)N<R!T96UP;W+D<FMA=&%L
M;V<N`%1A(&)O<G0`4F%D97)A(&1E;FYA(&YO9"!F<N5N(&1O:W5M96YT970`
M5&$@8F]R="!A;G;D;F1A<F4`5&$@8F]R="!A;G;D;F1A<F4Z("5S`%-V87(@
M<VMI8VMA="X`4W9A<F$@871T(&)E9^1R86X@:6YT92!S=/9D<P!3=F%R82!M
M960@:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96X@9O9R(&MO;6UA;F1E
M('1VY2!MY6YA9&5R+@!3=F%R82!M960@9&5N(&)E9^1R9&$@;&5D:6<O=7!P
M=&%G96XM:6YF;W)M871I;VYE;BX`4W9A<CH@)7,`0F5GY')A;B!K=6YD92!I
M;G1E(&)E<W9A<F%S+B!2971U<FYE<F%D(&9E;&MO9#H@`$1E;B!E9G1E<F9R
MY6=A9&4@=&KD;G-T96X@:W5N9&4@:6YT92!H:71T87,N`$5R9F]D<F%D("<E
M<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)A=&EO;F5N(&%V("5S+@!%
M<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R97)I;F=E
M;B!A=B!61E,N`$5R9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N
M9FEG=7)E<FEN9V5N+@!/8FQI9V%T;W)I<VMT="!FY&QT`$]B;&EG871O<FES
M:R!D96QT86=A<F4`Q71E<G/D;G0@=&EL;`#%=&5R<^1N="!F<N5N`,5T97)S
M=.1L;`#%=&5R<W3D;&P@;/9S96YO<F0`Q71E<G-TY&QL(&SV<V5N;W)D`,5S
M=&5R=.1L;"!S96YA<W1E(&9RY6=A;@!297-U;'1A=`#%=&5R=N1N="!T:6QL
M(&9I;'1E<FQI<W1A`,5T97)VY&YD('1I;&P@:6YS=.1L;&YI;F=A<@#%=&5R
M=N1N9"!T:6QL(')E9V5L;&ES=&$`06YG92!N>71T(&SV<V5N;W)D`%+I=6YI
M;VX`Q71E<G-TY&QL(&MO;F9I9W5R871I;VX`26YS=.1L;&YI;F=A<B!F]G(@
M4FEC:"!497AT($5D:71O<@!'Y71O<@!(]F=E<@!(]F=E<G)U8G)I:P!(]F=E
M<G;D<F1E;@!285]D:6YS=.1L;&YI;F=A<BXN+@!2;VQL`%)U;>1N:65N`%)O
M=&5R82`Q.#``4F]T97)A(';D;G-T97(`4F]T97)A(&CV9V5R`%)A9&EN<W3D
M;&QN:6YG87(`4F%D:6YS=.1L;&YI;F=A<@!2861E<CH`4F5G96P`4F5G96P@
M:V]P:65R860`4F5G96P@<F%D97)A9`!296=E;"!A=F%K=&EV97)A9`!296=E
M;"!A:W1I=F5R860`4F5G96QN86UN`%)E9V5L.@!,:6YJ97(`3&EN:F5R('9I
M<V%S(&UE;&QA;B!A;&QA(')A9&5R(&]C:"!K;VQU;6YE<@!,:6YJ97(@=FES
M87,@96YB87)T(&UE;&QA;B!K;VQU;6YE<@!,:6YJ97(@=FES87,@96YB87)T
M(&UE;&QA;B!R861E<@!+]G(`4GES<VQA;F0`4G=A;F1A`%,O34E-12!S:6=N
M871U<@!3+TU)344M:W)Y<'1E<F%T(&UE9&1E;&%N9&4`4T%33"UA=71E;G1I
M<V5R:6YG(.1R(&EN=&4@=&EL;&?D;F=L:6<N`%--4R!M961D96QA;F1E;@!3
M44PM<VMA;`!344PM<V5K=F5N<R!F]G(@=7!P<VQA9R!A=B!VY')D96X`4U-(
M`%-405)45$Q3(&UI<W-L>6-K861E<SH@*"5S*2`E<P!,64-+050`4U]13"US
M:V%L`$SV`%-A:6YT($AE;&5N80!386EN="!+:71T<R!O8V@@3F5V:7,`4V%I
M;G0@3'5C:6$`4V%I;G0M4&EE<G)E(&]C:"!-:7%U96QO;@!386EN="!6:6YC
M96YT(&]C:"!'<F5N861I;F5R;F$`4V%M;6$@<F%M("A?<V5L9BD`4V%M;V$`
M4V%N($UA<FEN;P!386\@5&]M92!O8V@@4')I;F-I<&4`4V%T=&5L:71L979E
M<F%N=/9R`%-A=61I87)A8FEE;@!3<&%R80!3<&%R82`G)7,G`%-P87)A("5S
M`%-P87)A(&EN<W3D;&QN:6YG87(`4W!A<F$@:6YS=.1L;&YI;F=A<@!3<&%R
M82!G96YE<F5R860@:V]N9FEG=7)A=&EO;B!S;VT@4$A0+7-K<FEP="!T:6QL
M(&1I;B!S97)V97)S("!T96UP+6MA=&%L;V<N`%-P87)A9&4@:V]N9FEG=7)A
M=&EO;B!F]G(@)7,N`%-P87)A9&4@=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL
M.B`E<RX`4W!R:61D82#E<VMS:W5R87(`5F5T96YS:V%P`%-K<FEP=`!5<'!D
M871E<F%R('-K<FEP=`!3:W)I<'1E="!U<'!D871E<F%D97,@:6YT90!3:W)I
M<'1E="!A:W1I=F5R870`4VMR:7!T970@879A:W1I=F5R870`4_9K`%/V:VUO
M=&]R97(`4V5D9`!6Y&QJ(&9I;&5R`%;D;&H@971T(&1A='5M`%;D;&H@971T
M(&;D;'0`5N1L:B!G<G5P<"!A='0@;.1G9V$@=&EL;`!6Y&QJ(&YY(.1G87)E
M`%;D;&H@<V5R=F5R`%;D;&H@86YVY&YD87)E(&%T="!LY&=G82!T:6QL`%;D
M;&H@86QL80!6Y&QJ(&1A='5M:V]M<&]N96YT97(N`%;D;&H@971T(&]B:F5K
M=`!6Y&QJ(&EN9V5N`%;D;&H@;>5L;6%P<`!!;F=E(&1E('1E8VME;B!D=2!B
M96CV=F5R(&D@<G5T;W)N82!N961A;BX@1'4@:V%N('-E9&%N(&MO<&EE<F$@
M;V-H(&ML:7-T<F$@:6X@9&5M(&D@=&5X=&%R=71A;BX`5N1L:B!A=F=RY&YS
M87)E(&;V<B!D871U;3H`5N1L:B!D871U;69O<FUA=#H`5N1L:B!I9&5N=&ET
M970@9'4@=FEL;"#D;F1R83H`5N1L:B!A=F=RY&YS87)E(&;V<B!T:60Z`%;D
M;&H@=&ED<V9O<FUA=#H`5N1L:B!T=N4@;6%T8VAA;F1E(&;D;'0Z`%;D;&H@
M9&ET="!FY')G<V-H96UA+@!!;F=E(&1I='0@9O9R=F%L9&$@<W!RY6LZ`$5G
M96YD969I;FEE<F%D92!R=6)R:6ME<@!3:VEC:V$@<V5N87-T92!I;F9O<FUA
M=&EO;F5N`%-K:6-K82!P<F]B;&5M<F%P<&]R=`!3:VEC:V$@4TU3`$%V<^1N
M9&%R90!396YE9V%L`%-E;G-O<CH@`'-E<'1E;6)E<@!397)B:65N(&]C:"!-
M;VYT96YE9W)O`%-E<FEE;G5M;65R`%-E<G9E<FEN<W3D;&QN:6YG87(@9F5L
M86MT:6=A(&5L;&5R(&EN86MT:78@<V5R=F5R+@!397-S:6]N<V%D;6EN:7-T
M<F%T:6]N`%-E<W-I;VYS+4E$(&AA<B!GY71T('5T+@!397-S:6]N97(`4^1T
M=`!+;VYF:6=U<F5R82!A;'1E<FYA=&EV('-O;2!M]FIL:6=G]G(@Y71E<G-T
MY&QL;FEN9R!A=B!B;W)T9VSV;70@;/9S96YO<F0N`$MO;F9I9W5R97)A(&9J
MY')R<V5R=G)A<B!S;VT@9'4@=FEL;"!K;VUM82#E="!F<N5N(&1I;B!P;W)T
M86PN`$%N9V4@9&ET="!F]G)V86QD82!S<'+E:RP@=&ED<WIO;B!C;V@@9&%T
M=6UI;G-TY&QL;FEN9V%R+@!3Y'1T(&1I='0@:6YI=&EA;&$@87!P;&EK871I
M;VXL(&;D<F=S8VAE;6$L('-I9'5P<&1A=&5R:6YG(&]C:"!A;F1R82!V:7-N
M:6YG<VEN<W3D;&QN:6YG87(N`$EN<W3D;&QN:6YG87(@=7!P9&%T97)A9&4N
M`%-E='5P`$MO;F9I9W5R871I;VYS=7!P9W)A9&5R:6YG<W-K<FEP="!F:6YN
M<R!T:6QL9^1N9VQI9V$`1&5T(&9I;FYS(&9L97)A(&]R=&5R(&UE9"!P87)A
M;65T97)N.@!397EC:&5L;&5R;F$`2&%N9&5L`$MO<G0@<W5M;65R:6YG`%-K
M86QL(&=E;G;D9W-T86YG96YT97(@9&5F:6YE<F%S(&;V<B!D92!F;&5S=&$@
M;.1N:V%R/P!6:7-A`%9I<V$@86MT:79A('-K<FEP=`!6:7-A(&%K='5E;&QT
M('-K<FEP=`!6:7-A('-K:6QL;F%D97(@;65L;&%N(&1E;B!A:W1U96QL82!O
M8V@@9&5N(&YY;&EG96X@<VMA<&%D92!K;VYF:6=U<F%T:6]N96XN`%9I<V$@
M<V5N87-T92!I;FQO9V=N:6YG<W1I9"!V:60@:6YL;V=G;FEN9S\`5FES82!I
M;G-TY&QL;FEN9R!F]G(@871T(&)E:.5L;&$@;W)I9VEN86P`5FES82!P86QE
M='0`5FES82`G=&%B96QL86MT:79I=&5T97(G(&D@;65N>6X_`%9I<V$@;65N
M>2!F]G(@)7,@=&EL;"!VY&YS=&5R/P!486)E;&QC96QL:6YS=.1L;&YI;F=A
M<@!486)E;&QI;G-TY&QL;FEN9V%R`%1A8F5L;&EN<W3D;&QN:6YG87(`5FES
M82!D:6%L;V=R=71A(&;V<B!B:6QD96=E;G-K87!E<@!6:7-A('5P<&QA9&1N
M:6YG`%-K=7)A<@!4:61I9V$@<VMU<F%R`%-E;F$@<VMU<F%R`%-K=7)A<B!I
M(&[D<FAE=&5N`$;V<FUI;G-K80!+<GEM<"!E;&QE<B!F;'ET=&$@8F]R="!N
MY')L:6=G86YD92!B;&]C:R!F]G)S=`!3:65R<F$@3&5O;F4`4F5G:7-T<F5R
M80!3:6=N871U<@!3:6=N871U<F%L9V]R:71M`%-I;7!L97@`4VEN9V%P;W)E
M`%-T;W)L96L`079B<GET('5N9&5R:.5L;`!3;&]V86MI96X`4VQO=F5N:65N
M`%-N]@!3;O9S:W5R`%-N]G-K=7)A<@!4:61I9V$@<V[V<VMU<F%R`%-E;F$@
M<V[V<VMU<F%R`%-N]F1J=7`Z(`!-;W1S=F%R86YD92!S;O8@:2!V871T96XZ
M(`!386QO;6]N]F%R;F$`4V]M86QI80!3Y6YG97(@;V-H(&1I:W1E<@!3;W)T
M97)I;F=S:6]R9&YI;F=S=F%L`&OD;&QA9')E<W,`4WED869R:6MA`%/V9')A
M($=E;W)G:6$@;V-H(%-Y<W-A;F1W:6-H]F%R;F$`4^1D<F$@:&5M:7-FY')E
M;@!5=')Y;6UE(&UE;&QA;B!I;G1I;&QI9V=A;F1E(&-E;&QE<@!5=')Y;6UE
M(&UE;&QA;B!I;FYE:.5L;"!O8V@@:V%N=&5N(&D@8V5L;&5N`$UE;&QA;G)U
M;0!-96QL86YR=6T`365L;&%N<G5M(&]C:"!U=&KD;6YI;F<`4W!A;FEE;@!3
M<&%M`$EN;6%T;FEN9R!A=B!S<&5C:65L;&$@=&5C:V5N`$1E;&$@8V5L;`!$
M96QA(&MO;'5M;@!$96QA(')A9`!3<&]R=&5R`%-R:2!,86YK80!3=&%N9&%R
M9`!3=&%R(%1R96L`4W1A<G0`4W1A<G3E<@!3=&%T(&5L;&5R(')E9VEO;@!3
M=&%T=7,`4VQU=&$@:V]N=')O;&QE<F$@;VT@9&5N;F$@<F5G96P@;6%T8VAA
M<C\`3&%G<FEN9W-F;W)M870`1V%T=6%D<F5S<P!'96YO;7-T<G5K96X`4W1R
MY&YG;&ES=&$`5&$@8F]R="!D;VWD;B!F<N5N(&%D<F5S<V5N`%-T:6P@6T-3
M4UT`4_8`2V%N(&EN=&4@:&ET=&$@=6YD97)K871A;&]G("<E<R<N`,1?;6YE
M(&;V<B!S=F%R<VUE9&1E;&%N9&4Z`,1R96YD90#$<F5N9&4Z`%-K:6-K80!$
M:6X@8F5GY')A;B!A='0@;.1G9V$@=&EL;"`B)7,B('1I;&P@<WES=&5M970@
M:&%R('-K:6-K871S+B!$=2!K86X@:6YT92!L;V=G82!I;B!I;FYA;B!D:6X@
M8F5GY')A;B!H87(@86-C97!T97)A=',N`$YE9'/D;FMT`$QY8VMA=``G)7,G
M(&QA9&5S('1I;&P@:2!S>7-T96UE="X`4F%D97)A9&4@:6YF;W)M871I;VX@
M;VT@86YVY&YD87)E("<E<R<N`"<E<R<@<F%D97)A9&5S+@`G)7,G('1O9W,@
M8F]R="!F<N5N('-Y<W1E;65T+@!+;VYF:6=U<F%T:6]N96X@:&%R(.5T97)S
M=.1L;'1S+B!,861D82!O;2!S:61A;B!F]G(@871T('-E(&;V<N1N9')I;F=A
M<BX`4W!A<F%D92!B86-K=7!K;VYF:6=U<F%T:6]N+@!3<&%R861E(&)A8VMU
M<&MO;F9I9W5R871I;VX@)7,N`"<E<R<@=7!P9&%T97)A9&5S+@!3:W)E=B`E
M<P!3=61A;@!386UM86YS=.1L;&YI;F<`4V]L=7!P9^5N9P!3;VQN961GY6YG
M`%-O;&EG=`!3;VQU<'!GY6YG`%-O;'5P<&?E;F<O;F5D9^5N9P!3;VQU<'!G
MY6YG.B``4V]L;F5D9^5N9P!3;VQN961GY6YG.B``57!P:/9J9`!3=7!P;W)T
M`%-U<FEN86UE`$5F=&5R;F%M;@!3=F%L8F%R9"!O8V@@2F%N($UA>65N`%-W
M87II;&%N9`!3=F5R:6=E`%-C:'=E:7H`4WEK<F]N:7-E<FEN9W-L;V=G(')A
M9&5R860`4WEN8TU,`%-Y;G1A>&9E;"!I('/V:VMR:71E<FEA`%-Y<FEE;@#%
M<VMS:W5R`,5S:W-K=7)A<B!O8V@@8FSE<VEG=`#%<VMS:W5R87(`5&ED:6=A
M(.5S:W-K=7)A<@!44U8M9FEL`%1A8F5L;`!486)E;&QI;G-TY&QL;FEN9V%R
M`%1A8F5L;'5P<'/D='1N:6YG`%1A8F5L;&EN<W3D;&QN:6YG87(`5&%I=V%N
M`%1A:7=A;@!486II:VES=&%N`%1A;GIA;FEA`$WE;#H`57!P9VEF=&5R`%1E
M86P`5&5L969O;FYU;6UE<@!(]F=S=&$@=&5M<&5R871U<B!S96YA<W1E('1I
M;6UE;CH@`%1E;7!E<F%T=7(`5&5M<&5R871U<CH@`%1E;7!E<F%T=7(\8G(@
M+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S`$MA;B!I;G1E(&AI='1A(&UA
M;&P@)7,N`$%N=N1N9&%R861M:6YI<W1R871I;VX`1V]D:^1N;B!B96?D<F%N
M('!R96QI;6ENY')T`%!R96QI;6ENY')T(&%C8V5P=&5R870`5&5X=`!%;F)A
M<G0@=&5X=`!497AT:G5S=&5R:6YG`%1E>'1T;W``5&\`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&%C:R!F]G(@871T(&1U(&%N=N1N9&5R('-Y<W1E;65T
M+@!,Y&YK96X@)7,@=&EL;"`E<R!H87(@<F%D97)A=',N`$944"UT:6QLY&=G
M970@Y'(@:6YT92!T:6QL9^1N9VQI9W0N`$AI<W1O<FEK<WES=&5M970@Y'(@
M879A:W1I=F5R870N`$AO<F1E+TMO;&%B+6EN=&5G<F%T:6]N<V=RY&YS<VYI
M='1E="!S=/9D97(@:6YT92`B)7,B`$E-4U`M;&]G9V5N(&MU;F1E(&EN=&4@
M:6YI=&EE<F%S+@!+;&%S<V5N($UA:6YT96YA;F-E.CH@:W5N9&4@:6YT92!L
M861D87,`26YS=.1L;&YI;F=S9O9N<W1R970@:&%R('-TY&YG=',N($%V<VQU
M=&%R+@!!9')E<W-E;B`G)7,G(&AA<B!L86=T<R!T:6QL(&D@9&EN('-PY')R
M;&ES=&$N`$%D<F5S<V5N("<E<R<@:&%R(&QA9W1S('1I;&P@:2!D:6X@;&ES
M=&$@]G9E<B!B971R;V1D82X`061M:6YI<W1R873V<F5N(&WE<W1E(&MO;F9I
M9W5R97)A(&5N('!E<FUA;F5N="!"96CV<FEG:&5T<RUK;W!P;&EN9R!O;2!D
M=2!V:6QL(&%N=N1N9&$@0F5H]G)I9VAE=&5R+@!%;F)A<G0@;F5D<F4@<VED
M86X`2V%L96YD97)I;F9O<FUA=&EO;F5N(.1R(&9E;&%K=&EG`$MO;G1A:W1E
M;G,@240@86YG879S(&EN=&4@96QL97(@:W5N9&4@:6YT92!H:71T87,@:2!D
M871A8F%S96XN`$MO;G1A:W1E;B!L861E<R!T:6QL(&D@861R97-S8F]K96XN
M`$1E;B!L]G-G:F]R9&$@4$=0+7-I9VYA='5R96X@:W+D=G,@9O9R(&%T="!V
M97)I9FEE<F$@9&5T('-I9VYE<F%D92!M961D96QA;F1E="X`1&ES=')I8G5T
M:6]N<VQI<W1A;G,@240@86YG879S(&EN=&4@96QL97(@:W5N9&4@:6YT92!H
M:71T87,@:2!D871A8F%S96XN`$1I<W1R:6)U=&EO;G-L:7-T86X@:&%R(&EN
M=&4@86YG:79I=',N`$1R:79R=71I;F5N('-V87)A9&4Z(`!+<GEP=&5R:6YG
M<V9U;FMT:6]N97)N82!K<N1V97(@96X@<^1K97(@=V5B9O9R8FEN9&5L<V4@
M*$A45%!3*2X`2.1N9&5L<V5N(&QA9&5S('1I;&P@:2!K86QE;F1E<FXN`$9I
M;&5N("5S('-K86QL(&EN;F5HY6QL82!E;B!I;G-TY&QL;FEN9R!F]G(@)7,N
M`$9I;&5N("5S('-K86QL(&EN;F5HY6QL82!I;G-TY&QL;FEN9V%R(&;V<B`E
M<RX`1FEL96X@:V%N(&EN=&4@:V]P:65R87,@=&EL;"!S:6<@<VKD;'8N`$9I
M;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I;&P@<VEG('-JY&QV+@!&:6QE;B!I
M;FYE:/9L;"!I;F=E;B!I;F9O<FUA=&EO;BX`2'5V=61FY&QT(&;V<B!D971T
M82!M961D96QA;F1E+W)F8S@R,FUE9&1E;&%N9&4@9O9L:F5R`$ED96YT:71E
M=&5N("<E<R<@<F%D97)A9&5S+@!"87)A(';D;G-T97(@<VED80!,Y&YK96X@
M:&%R('1A9VET<R!B;W)T`%/V:W;D9V5N('1I;&P@1VYU4$<M<')O9W)A;6UE
M="!MY7-T92!V87)A(&%N9VEV96X@=&EL;"!K;&%S<V5N($-R>7!T7W!G<#HZ
M+@!-961D96QA;F1E="!S:VEC:V%T("5S('1I;&P@)7,@;65D(.1R96YD92`B
M)7,B(&AA<B!V:7-A=',N"D1E='1A(.1R(&EN9V5N(&=A<F%N=&D@9O9R(&%T
M="!M961D96QA;F1E="!H87(@;.1S=',N`$YA;6YE="!S;VT@<VMA;&P@86YV
MY&YD87,@9O9R(&%T="!LY&YK82!T:6QL('-K87!A+7-I9&%N`$%N=&%L(&;D
M;'0@;>5S=&4@=F%R82!E='0@;G5M97)I<VMT(';D<F1E+@!-;V1U;&5N(&]P
M96YS<VP@:W+D=G,@878@:VQA<W-E;B!(;W)D95]#<GEP=%]S;6EM93HZ+@!)
M;G-TY&QL;FEN9V5N("(E<R(@:W5N9&4@:6YT92!S<&%R87,@<.4@9W)U;F0@
M878@871T(&1A=&%MY&YG9&5N(/9V97)S:W)I=F5R(&1E;B!M87AI;6%L="!T
M:6QLY71N80!0<F]G<F%M;65T('-O;2!A;G;D;F1S(&;V<B!A='0@=FES82!D
M96X@:.1R(&UE9&1E;&%N9&5T>7!E;B`H)7,I('-A:VYA<R!PY2!S>7-T96UE
M="X`5&5C:VYE="!F]G(@8VET97)I;F<@;>5S=&4@=F%R82!E='0@=&5C:V5N
M+@!"87)A(&CV9V5R(&]C:"!VY&YS=&5R('-I9&]R`$)A<F$@:/9G97(@<VED
M80!397!A<F%T;W)N(&WE<W1E('9A<F$@971T('1E8VME;BX`4V5R=F5R("<E
M<R<@<F%D97)A9&5S+@!397)V97(@)R5S)R!S<&%R861E<RX`4')E;G5M97)A
M=&EO;G-B96?D<F%N(&;V<B`E<R!H87(@=&%G:71S(&)O<G0N`$%N9VEV96X@
M<F%D("@E9"D@9FEN;G,@:6YT92X`06YG:79E;B!R860@97AI<W1E<F%R(&EN
M=&4N`%5P<&=I9G1E;B!H87(@;&%G=',@=&EL;"!I(&1I;B!U<'!G:69T<VQI
M<W1A+@!496UP;W+D<B!F:6P@)R5S)R!F:6YN<R!I;G1E+@!497AT96X@9'4@
M;6%T870@:6X@<W3D;6UE<B!I;G1E(/9V97)E;G,@;65D('1E>'1E;B!PY2!S
M:^1R;65N`$)A<F$@=&]P<"!O8V@@8F]T=&5N('-I9&$`0F%R82!T;W!P<VED
M80!5<'!L861D870@9&%T82!F]G)S=F%N;B!S961A;B!F]G)E9^5E;F1E('-T
M96<N`$1E;B!U<'!L861D861E(&9I;&5N(&MU;F1E(&EN=&4@<W!A<F%S+@!,
M961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;B!F]G(@86YVY&YD87)E;B!H87(@
M<W!A<F%T<RX`5V5A=&AE<BYC;VTM8FQO8VME="#D<B!I;G1E('1I;&QGY&YG
M;&EG="X`5&5M86MA=&%L;V<@)R5S)R!F:6YN<R!I;G1E+@!);F=A(&EN<W3D
M;&QN:6YG87(@=&EL;&?D;F=L:6=A+@!$970@9FEN;G,@:6YG82!A;'1E<FYA
M=&EV82!D96QA<B!S;VT@:V%N('9I<V%S(&EN;&EN92X`1O9R(&WE;F=A('1E
M8VME;B!I(&;D;'1E="X@1'4@:&%R(&%N9V5T="`E<R!T96-K96X[(&UA>&EM
M86QT(&%N=&%L('1E8VME;B#D<B`E<RX`4')O8FQE;2!M960@871T(&SD9V=A
M('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T.B`E<P!0<F]B;&5M(&UE9"!A='0@
M<F5N<V$@:6YF;W)M871I;VX@;VT@86YVY&YD87)E("<E<R<@9G+E;B!S>7-T
M96UE=#H@`%!R;V)L96T@;65D(&%T="!T82!B;W)T("<E<R<@9G+E;B!S>7-T
M96UE=#H@`%!R;V)L96T@=FED('5P<&1A=&5R:6YG(&%V("<E<R<Z("5S`%!R
M;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N+B!);F=A("5S(&QA9&1A
M9&5S('5P<"X`1&5T('5P<'-T;V0@<')O8FQE;2!V:60@=7!P;&%D9&YI;F<@
M878@9FEL96XZ("5S(.1R('-T]G)R92#D;B!M87AI;6%L="!T:6QLY71E;B!S
M=&]R;&5K("@E9"!B>71E<RDN`$1E="!U<'!S=&]D('!R;V)L96T@=FED('5P
M<&QA9&1N:6YG(&%V(&9I;&5N.B`E<R!L861D861E<R!E;F)A<G0@=7!P(&1E
M;'9I<RX`1F5L('9I9"!A:W1I=F5R:6YG(&%V('-K<FEP=&5T+@!&96P@=FED
M(&%V86MT:79E<FEN9R!A=B!S:W)I<'1E="X`1&5T('5P<'-T;V0@971T(&9E
M;"!V:60@=FES;FEN9R!A=B!M961D96QA;F1E9&5L96XN`$9E;"!V:60@:6UP
M;W)T(&%V(&MO;G1A:W1D871A+@!&96P@=FED(&EM<&]R="!A=B!HY&YD96QS
M96XZ("5S+@!&96P@=FED(&EM<&]R="!A=B!I0V%L96YD87(@9&%T82X`1F5L
M('9I9"!I;7!O<G0@878@=7!P9VEF=&5N.B`E<RX`1F5L('9I9"!I;7!O<G0@
M878@:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96XZ("5S+@!%='0@9F5L
M('#E='+D9F9A9&5S(&D@9F]R;75LY')E="X@2V]N=')O;&QE<F$@871T(&1U
M(&EN=&4@9VSV;70@9GEL;&$@:2!E='0@;V)L:6=A=&]R:7-K="!FY&QT+@!$
M970@9VEC:R!I;G1E(&%T="!U=&;V<F$@9&5N(&)E9^1R9&$@861R97-S8F]K
M<V9U;FMT:6]N96XN(%9A<B!G;V0@9O9R<_9K('-E;F%R92X`1F5L('9I9"!U
M<'!D871E<FEN9R!A=B!K;VYT86MT=7!P9VEF=&5R+B!&]G)S]FL@:6=E;B!S
M96YA<F4N`$9E;"!V:60@=7!P9&%T97)I;F<@878@9&ES=')I8G5T:6]N<VQI
M<W1A;BX@1O9R<_9K(&EG96X@<V5N87)E+@!$:6X@24U!4"US97)V97(@<W3V
M9&5R(&EN=&4@9&5L861E(&UA<'!A<BX`1&5N;F$@:&%N9&QI;F<@<W3V9',@
M:6YT92X`1&5N;F$@9G5N:W1I;VX@Y'(@:6YT92!I;7!L96UE;G1E<F%D(.1N
M+@!&:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%)!4BUA<FMI
M=BX`1FEL96X@=F5R:V%R(&EN=&4@=F%R82!E='0@9VEL=&EG="!:25`M87)K
M:78N`$9E;&%K=&EG="!K;W)T;G5M;65R+@!$96YN82!D<FEV<G5T:6X@9_9R
M(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA($-L:6-K
M871E;&PM8G)Y9V=A;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G96YO;2!A
M='0@86YVY&YD82!(5%10($%023IT+@!$96YN82!D<FEV<G5T:6X@9_9R(&1E
M="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA(%=)3BUB<GEG
M9V%N("AH='1P.B\O=VEN<&QC+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%14
M4"!!4$DZ=`!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S
M:VEC:V$@;65D9&5L86YD96X@=FEA('-M<S)E;6%I;"UB<GEG9V%N("AH='1P
M.B\O<VUS,F5M86EL+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%144"!!4$DZ
M=`!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@
M;65D9&5L86YD96X@=FEA(%--5%`@9V5N;VT@5F]D869O;F4@271A;&EE;BUB
M<GEG9V%N("AE;F)A<G0@=&EL;"!6;V1A9F]N;G5M;65R*2X@1')I=G)U=&EN
M96X@:W+D=F5R(&5T="!E+7!O<W1K;VYT;R!H;W,@5F]D869O;F4@271A;&EE
M;B`H:'1T<#HO+W=W=RXQ.3`N:70I+@!&Y&QT970@;>5S=&4@=F%R82!I9GEL
M;'0N`$;D;'1E="!FY7(@96YB87)T(&EN;F5HY6QL82!H96QT86PN`$;D;'1E
M="!FY7(@96YB87)T(&EN;F5HY6QL82!S:69F<F]R(&]C:"!K;VQO;BX`1N1L
M=&5T(&;E<B!E;F)A<G0@:6YN96CE;&QA(&]K=&%L82!T86PN`$;D;'1E="!S
M:V%L;"!V87)A(&5N(&MO;6UA+2!E;&QE<B!M96QL86YS;&%G<W-E<&%R87)A
M9"!L:7-T82!M960@:&5L=&%L`$;D;'1E="!MY7-T92!V87)A(&5T="!G;V1K
MY&YT('1A;"X`1&5T=&$@9N1L="!MY7-T92!I;FYE:.5L;&$@96X@4D="+6;D
M<F=K;V0@:2!H97AA9&5C:6UA;'0@9F]R;6%T+"!T(&5X("<C,3(S-&%F)RX`
M1&5T=&$@9F]R;75LY'(@:&%R(')E9&%N(&)E87)B971A=',N`$1E="!HY'(@
MY'(@)7,N`$UE9&1E;&%N9&5T('-K<F5V<R!I(&5N(&%N;F%N('1E8VME;G5P
M<'/D='1N:6YG("@E<RD@Y&X@9&EN(&5G96XN`$1E="!HY'(@;G5M<F5T(&WE
M<W1E('9A<F$@;6EN<W0@971T+@!397)V97)N(&MA;B!I;G1E('!A8VMA('5P
M<"!Z:7`@;V-H(&=Z:7`@9FEL97(N`%-Y<W1E;65T(.1R(&;V<B!T:6QL9N1L
M;&5T(&%V86MT:79E<F%T+@!$970@:.1R(';D<F1E="!MY7-T92!V87)A(&YU
M;65R:7-K="X`1&5T=&$@9O9N<W1E<B!MY7-T92!A;G)O<&%S(&9RY6X@971T
M(&MO;F9I9W5R871I;VYS9O9N<W1E<@#%<VMA`,1R96YD96X`5&ED`%1I9'-R
M961O=FES;FEN9P!4:61S9F]R;6%T`%1I9'-V86P`UG-T=&EM;W(`4G5B<FEK
M`%)U8G)I:R`H=&]O;'1I<"DZ`%1I;&P`1O9R(&%T="!M87)K97)A(&9L97)A
M('9A;"P@:.5L;"!N960@0W1R;"`H4$,I(&5L;&5R($-O;6UA;F0@*$UA8RD@
M=&%N9V5N=&5N(&[D<B!D=2!K;&EC:V%R+@!4:6QL.@!)9&%G`%9I<V$@2%1-
M3"UKY&QL80!4;V=O`%1O:V5L874`26UO<F=O;@!4;VYG80!4;W``5&]P(&9R
M86UE("A?=&]P*0#6=F5R<^1T=&YI;F=A<@!4<FEN:61A9"!O8V@@5&]B86=O
M`%-A;G0@96QL97(@9F%L<VMT`%1I`%1U;FES:65N`%1U<FMI970`5'5R:VES
M:R`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS+2!O8V@@0V%I8V]S
M]F%R;F$`5'5V86QU`$%N9V4@9&ET="!V86PZ(`!55BUI;F1E>#H@`%523`!5
M4DP@9O9R(&1I='0@;&5V97)A;G-R87!P;W)T97)I;F=S<VMR:7!T`%523#H`
M56=A;F1A`%5K<F%I;F$`2V%N(&EN=&4@;.1S82!61E,M;6%P<"X`1&5T(&=I
M8VL@:6YT92!A='0@;.1G9V$@=&EL;"!U=/9K860@86YVY&YD87)I;F9O<FUA
M=&EO;B!V:60@<F5G:7-T97)I;F<N`$MA;B!I;G1E(.1N9')A(&)E:/9R:6=H
M970@9O9R(%9&4RUF:6P@)7,N`$MA;B!I;G1E(.1N9')A(&)E:/9R:6=H970@
M9O9R(%9&4RUF:6P@)7,O)7,N`$MA;B!I;G1E(.1N9')A('1I;&P@)7,N`$MA
M;B!I;G1E(&MO;G1R;VQL97)A(&9I;'-T;W)L96L@)7,O)7,`2V%N(&EN=&4@
M:V]N=')O;&QE<F$@9FEL<W1O<FQE:R!PY2`E<RX`2V%N(&EN=&4@:V]N=')O
M;&QE<F$@9FEL<W1O<FQE:R!PY2`E<R\E<RX`2V%N(&EN=&4@:V]N=&%K=&$@
M4U%,+7-E<G9E<BX`2V%N(&EN=&4@:V]N=&%K=&$@=FEA(%-33"X`2V%N(&EN
M=&4@:V]P:65R82!61E,M9FEL+@!+86X@:6YT92!S:V%P82!61E,M;6%P<"`E
M<RX`2V%N(&EN=&4@<VMA<&$@5D93+6UA<'`N`$MA;B!I;G1E('-K87!A(%9&
M4RUF:6PN`$MA;B!I;G1E('-K87!A(%9&4RUM87!P("<E<R<N`$MA;B!I;G1E
M('-K87!A('1O;2!61E,M9FEL+@!+86X@:6YT92!P86-K82!U<'`@9&%T82X`
M2V%N(&EN=&4@<F%D97)A("5S+"!M87!P96X@Y'(@:6YT92!T;VTN`$MA;B!I
M;G1E(')A9&5R82`G)7,G.B`E<P!+86X@:6YT92!R861E<F$@)7,L(&UA<'!E
M;B#D<B!I;G1E('1O;2X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P(')E:W5R
M<VEV="X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P+@!+86X@:6YT92!R861E
M<F$@5D93+6UA<'`Z("5S+@!+86X@:6YT92!R861E<F$@5D93+69I;"`E<RX`
M2V%N(&EN=&4@<F%D97)A(%9&4RUF:6PN`$MA;B!I;G1E(')A9&5R82!61E,M
M;6%P<"`G)7,G+@!+86X@:6YT92!R861E<F$@5D93(')E:W5R<VEV=#H@)7,N
M`$MA;B!I;G1E(&%V9_9R82!A:W1U96QL(&UA<'`N`$MA;B!I;G1E(&5X=')A
M:&5R82!#97)T:69I:V%T<V1E=&%L:F5R`$MA;B!I;G1E(&QA9&1A(&1E9FEN
M:71I;VYE;B!A=B`E<RX`2V%N(&EN=&4@9FQY='1A(%9&4RUF:6PN`$MA;B!I
M;G1E(/9P<&YA(%9&4RUF:6P@)7,N`$MA;B!I;G1E(/9P<&YA(%9&4RUF:6P@
M9O9R('-K<FEV;FEN9RX`2V%N(&EN=&4@]G!P;F$@5D93+69I;"X`2V%N(&EN
M=&4@]G!P;F$@:V]M<')I;65R870@87)K:78N`$MA;B!I;G1E(&SD<V$@5D93
M+69I;"`H9FEL97-I>F4H*2!M:7-S;'EC:V%D97,I+@!+86X@:6YT92!LY'-A
M(%9&4RUF:6P@*&=E=$9I;&53:7IE*"D@;6ES<VQY8VMA9&5S*2X`2V%N(&EN
M=&4@;.1S82!F:6PZ(`!+86X@:6YT92!LY'-A(&MA=&%L;V=E;B!F]G(@)W9F
M<W)O;W0G+@!+86X@:6YT92!B>71A(&YA;6X@<.4@)7,@=&EL;"`E<SH@9&5S
M=&EN871I;VYS;6%P<"!F:6YN<R!R961A;@!+86X@:6YT92!B>71A(&YA;6X@
M<.4@5D93+6UA<'`N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M;6%P<#H@
M)7,N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+@!+86X@:6YT
M92!B>71A(&YA;6X@<.4@5D93+69I;"`E<R\E<RX`2V%N(&EN=&4@8GET82!N
M86UN('#E(%9&4RUF:6PN`$MA;B!I;G1E(&OV<F$@)VUK:7-O9G,G+@!+86X@
M:6YT92#V=F5R<^1T=&$@5V]R9&1O:W5M96YT970`2V%N(&EN=&4@<VMR:79A
M('1I;&P@5D93+69I;"`E<RX`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I
M;"`H8V]P>2@I(&UI<W-L>6-K861E<RDN`$MA;B!I;G1E('-K<FEV82!D871A
M('1I;&P@5D93+69I;"X`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"P@
M:W9O=&$@<VMU;&QE(/9V97)S:W)I9&%S+@!5;F1E<G-T<G5K96X`Q6YG<F$@
MY&YD<FEN9V%R`,5N9W)A<B!D:6X@<V5N87-T92#E=&?D<F0`3W;D;G1A="!S
M=F%R(&9RY6X@<V5R=F5R('#E(&;V<F)I;F1E;'-E.B``3W;D;G1A="!S=F%R
M(&9RY6X@<V5R=F5R('1I;&PZ(`!%:B!K871E9V]R:7-E<F%D`$EC:V4@:&%N
M=&5R860@:V]M<&]N96YT(&%V('1Y<#H@)7,`56YI8V]D92`H551&+3@I`$;V
M<F5N861E($%R86)E;6ER871E;@!3=&]R8G)I=&%N;FEE;@!&]G)E;G1A(%-T
M871E<FYA`$%M97)I:V%N<VMA(%-T:6QL86AA=G/V87)N80!%;FAE=&5R`$]K
MY&YD`$]KY&YT(&=RY&YS<VYI='1S;65D9&5L86YD96ED("AA<&EM<V=I9"DN
M`$]KY&YT(&ML:65N=&UE9&1E;&%N9&5I9"`H8VQI;7-G:60I+@!/:^1N9"!O
M<G0@<W!E8VEF:6-E<F%D+@!/:^1N="!A;G;D;F1A<FYA;6X@96QL97(@;/9S
M96YO<F0N`%1A(&)O<G0@;.1N:V5N(&9RY6X@;G5V<F%N9&4@96QE;65N=`!.
M86UN;/9S`$EC:V4M<')I=FEL:6=E<F%D92!S:W)I<'0@:V%N(&EN=&4@:V]M
M;6$@Y70@2VQI<'`@=70O2V]P:65R82]+;&ES=')A+69U;FMT:6]N97)N82!A
M=B!SY&ME<FAE='-S:^1L+B!+;&EC:V$@3TL@9O9R(&%T="!S92!E;B!T96MN
M:7-K(&)E<VMR:79N:6YG(&9RY6X@;6]Z:6QL82YO<F<@;VT@:'5R(&1U(&MA
M;B!T:6QLY71A(&%T="!S:W)I<'0@:V]M;65R(.5T('5R:VQI<'`N`%1A(&)O
M<G0@9N1R9P!4:6QLY&=G970@<W3V9',@:6YT90!5<'!D871E<F$`57!P9&%T
M97)A("5S`%5P<&1A=&5R82!S=&%T=7,@<.4@<W9A<F%N9&4`57!P9&%T97)A
M(&%N=N1N9&%R90!5<'!D871E<F%D92`G)7,G+@!5<'!D871E<FEN9W-S8W)I
M<'0@<F%D97)A="X`3&%D9&$@=7!P`$QA9&1A9&4@=7!P(&%L;&$@:V]N9FEG
M=7)A=&EO;G-F:6QE<B!T:6QL('-E<G9E<FXN`%9E<G-A;&5R`%)O;65R<VMA
M('-I9F9R;W(`57)U9W5A>0!!;G;D;F0@86MT=65L;#H@)7,`06YVY&YD(%-3
M3`!!;G;D;F0@;VT@;F%M;B]L]G-E;F]R9"#D<B!A;FYO<FQU;F1A(&;V<B!)
M35-0+7-E<G9E<BX`06YVY&YD87)E`$%N=N1N9&%R92`E<R#D<B!I;G1E(&)E
M:/9R:6<@9O9R("5S+@!!;G;D;F1A<F%D;6EN:7-T<F%T:6]N`$%N=N1N9&%R
M:6YS=.1L;&YI;F=A<@!!;G;D;F1A<G)E9VES=')E<FEN9P!!;G;D;F1A<G)E
M9VES=')E<FEN9R!H87(@879A:W1I=F5R871S+@!!;G;D;F1A<FMO;G1O="!H
M:71T861E<R!I;G1E`$%N=N1N9&%R;F%M;@!!;G;D;F1A<FYA;6X@)7,@9FEN
M;G,@<F5D86XN`$%N=N1N9&%R;F%M;CH`06YVY&YD87)N86UN.B``06YVY&YD
M87)E(&D@<WES=&5M970Z`%5Z8F5K:7-T86X`5D93+6UA<'`@97AI<W1E<F%R
M(&EN=&4N`%-E;65S=&5R`,1N9')A('-E;65S=&5R`%-E;65S=&5R('-T]F1S
M(&EN=&4@878@86MT=65L;"!F:6QT97)D<FEV<G5T:6XN`$=I;'1I9V$@<&QA
M='-E<B!S;VT@:&ET=&%D97,@:6YK;'5D97)A<CH@`$=I;'1I9VAE=`!-:6YU
M=&5R(&9RY6X@;G4`5N1R9&5T(/9V97)S=&EG97(@9&5T(&CV9W-T82!T:6QL
MY71N82`H)7,I`%;D<F1E;@!6Y')D96X@871T(';D;&IA(&9RY6X`5F%N=71A
M=0!687)I86)E;`!696YE>G5E;&$`5F5R:69I97)I;F<@;6ES<VQY8VMA9&5S
M("T@;65D9&5L86YD970@:V%N(&AA(&UA;FEP=6QE<F%T<RX`5F5R<VEO;@!6
M97)S:6]N:&%N=&5R:6YG`%9E<G1I:V%L(&IU<W1E<FEN9P!697)T:6MA;"!U
M=&9Y;&QN860`5F5R=&EK86PZ`%;D;&1I9W0@:/9G`%9I971N86T`5FEE=&YA
M;65S:7-K("A625-#24DI`%9I<V$@)7,`5FES82!E;B!E>'1E<FX@=V5B8G-I
M9&$`5FES82!S;VT@)7,`5FES82!HY&YD96QS90!6:7-A('5P<&=I9G0`2G5N
M9V9R=?9A<FYA+"!"<FET=&ES:V$`2G5N9V9R=?9A<FYA+"!!;65R:6MA;G-K
M80!3:6MT`%-I:W0Z`%9O9&%F;VYE($ET86QI96X@=FEA(%--5%``5D%23@!6
M05).24Y'(2$A(%)!1$5202!32U))4%1%5"!-04Y514Q,5"!&4L5.("5S+@!7
M24X@=FEA($A45%``5V%L;&ES(&]C:"!&=71U;F$`5F%R;FEN9P!/;@!6Y&1E
M<G!R;V=N;W,`5N1D97)D871A(&9RY6X`=V5A=&AE<BYC;VT`5V5B8@!796)B
M<&QA=',`5V5B8G!L871S96X@+2!3;V)E<@!796)B<&QA='-E;B`M(%-O8F5R
M($Y9`%9E8VMO=FES`%;D;&MO;6UE;@!6Y&QK;VUM96X@=&EL;"`E<P!6Y&QK
M;VUM96XL("5S`%;D<W1E<FSD;F1S:R`H25-/+3@X-3DM,2D`5N1S=&5R;.1N
M9'-K("A)4T\M.#@U.2TQ-2D`5N1S=')A(%-A:&%R80!?0F5T<F]D9&$@861R
M97-S97(Z`%9I;&ME;B!A<'!L:6MA=&EO;B!S:V%L;"`E<R!V:7-A(&5F=&5R
M(&EN;&]G9VYI;F<_`%9I;&ME;B#D<B!A=F=RY&YS;FEN9W-T96-K;F5T/P!6
M:6QK970@Y'(@=&5C:VYE="!F]G(@8VET97)A9"!T97AT/P!7:&5R96ES($%U
M<W1R86QI96YK87)T80!6:6QK82!F87-E<@!6:6QK82!P;'5G:6X@<VMA;&P@
M86MT:79E<F%S(&;V<B!2:6-H(%1E>'0@961I=&]R;BX`0F5T<F]D9&$@861R
M97-S97(`Q&YD<F$@8F5T<F]D9&$`)T)E=')O9&1A(&%D<F5S<V5R)R!S=/9D
M<R!I;G1E(&%V(&%K='5E;&P@9FEL=&5R9')I=G)U=&EN+@!"971R;V1D82!A
M9')E<W-E<@!"<F5D9`!"<F5D9"!I($-34RUU;FET<P!"<F5D9"!PY2!M96YY
M;B!F]G(@)R5S)R!T:6QL(';D;G-T97(@*&?D;&QE<B!F<N5N(&[D<W1A(&EN
M;&]G9VYI;F<`5&%B96QL8G)E9&0`0G)E9&1E;FAE=`!"<F5D9#H`5VEK:0!6
M:6YD`%1I9&EG('9I;F0`5FEN9&AA<W1I9VAE="!I(&MN;W``5FEN9#H`5FEN
M9#H@`%9I<V1O;0#6;G-K96QI<W1A`$%R8F5T90!!9')E<W,L(&%R8F5T90!4
M96QE9F]N+"!A<F)E=&4`1F5L(&%N=&%L(&;D;'0@<.4@<F%D("5D+B!&]G)V
MY&YT861E("5D+"!H:71T861E("5D+@!&96P@86YT86P@9N1L="X@1O9R=N1N
M=&%D92`E9"P@:&ET=&%D92`E9"X`1F5L('!O<VET:6]N("5D('9I9"!LY'-N
M:6YG(&%V(%9&4RUF:6PN`%@M4')I;W)I='D`6"U2968`6"U3<&%M+4QE=F5L
M`%@M4W!A;2U38V]R90!8+5-P86TM4W1A='5S`%@U,#E6,R!5=/9K860@;GEC
M:V5L86YVY&YD;FEN9P!8-3`Y5C,M=&EL;.1G9P!960!965E9`%EA:&]O(2!M
M87``Q7)L:6<`665M96X`2F$`2F$L(&IA9R!S86UT>6-K97(`1'4@:&%R(&%K
M=&EV97)A="!T97AT;.1G92X@06YVY&YD(%L\/ET@9O9R(&%T="#E=&5R9^4@
M=&EL;"!765-)5UE'+@!$=2!H87(@:6YT92!B96CV<FEG:&5T('-K87!A(&9L
M97(@Y&X@)60@8FQO8VLN`$1U(&;E<B!I;G1E('-K87!A(&UE<B#D;B`E9"!R
M96=L97(N`$1U(&;E<B!I;G1E('-K87!A(&5L;&5R(')E9&EG97)A(&%N<&%S
M<V%D92!R96=L97(N`$1U(.1R(&EN=&4@875T96YT:7-E<F%D+@!$=2!K86X@
M:6YT92!A;G;D;F1A("=<)R!I(&1I='0@;F%M;@!$=2!K86X@:6YT92!A;G;D
M;F1A("=<)R!I(&1I='0@;F%M;@!$=2!A;F=A=B!I;G1E(&5N(&=O9&OD;F0@
M92UP;W-T861R97-S+@!$=2#D<B!U=&QO9V=A9"X`1'4@:&%R(&;E='0@971T
M(&YY='0@;65D9&5L86YD92X`1'4@;>5S=&4@86YG92!E='0@9VEL=&EG="!M
M;V)I;&YU;6UE<CL@96YB87)T('-I9F9R;W(@;V-H(&5T="`G*R<@9O9R92!I
M;G1E<FYA=&EO;F5L;'0@<')E9FEX+@!$=2!A;F=A=B!I;G1E(&5T="!G;V1K
MY&YT(';D<F1E+@!$=2!MY7-T92!K;VYF:6=U<F5R82!E;B!$871A5'+D9',M
M:V]P<&QI;F<@9O9R(&%T="!A;G;D;F1A(')E9VES=')E<FEN9P!$=2!MY7-T
M92!K;VYF:6=U<F5R82!E;B!61E,M:V]P<&QI;F<`1'4@;>5S=&4@8F5S:W)I
M=F$@<')O8FQE;65N+"!I;FYA;B!D=2!K86X@<F%P<&]R=&5R82!E='0@<')O
M8FQE;2X`1'4@;>5S=&4@86YG92!E;B!54DP@<V]M(&SD;FME;B!P96MA<B!P
MY0!$=2!MY7-T92!A;F=E(&5N('-E<G9E<B!S;VT@<VMA;&P@<F%D97)A<RX`
M1'4@;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L;"!R96YS
M87,N`$1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@
M<F%D97)A<RX`1'4@;>5S=&4@86YG92!M:6YS="!E;B!E+7!O<W1A9')E<W,@
M9O9R('9I;&ME;B!S96UE<W1E<FUE9&1E;&%N9&4@<VMA;&P@86MT:79E<F%S
M+@!$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(&SD
M9V=A<R!T:6QL+@!$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M
M('-K86QL('5P<&1A=&5R87,N`$1U(&WE<W1E(&%N9V4@96X@Y71GY')D('-O
M;2!S:V%L;"!U=&;V<F%S+@!$=2!MY7-T92!A;F=E(&5T="!N>71T(&MA=&5G
M;W)I;F%M;BX`1'4@;>5S=&4@86YG92!E='0@:71A;&EE;G-K="!T96QE9F]N
M;G5M;65R`$1I;B`E<R!S97-S:6]N(&AA<B!U<'!H]G)T+B!687(@9V]D(&QO
M9V=A(&EN(&EG96XN`$1I;B!E+7!O<W1A9')E<W,`1&EN($9RY6XZ(&%D<F5S
M<SH`1&EN(&EN9F]R;6%T:6]N`$1I;B!I;G1E<FYE=&%D<F5S<R!H87(@Y&YD
M<F%T<R!E9G1E<B!A='0@9'4@;&]G9V%T(&EN('1I;&P@)R5S)RX@1O9R(&%T
M="!S:WED9&$@9&EG+"!MY7-T92!D=2!L;V=G82!I;B!I9V5N+@!$:71T(&YA
M;6X`1&EN(&%U=&5N=&ES97)I;F=S:V]P<&QI;F<@<W3V9&5R(&EN=&4@=7!P
M;.1G9R!A=B!A;G;D;F1A<F4N($]M(&1U('9I;&P@86YVY&YD82!(;W)D92!F
M]G(@871T(&%D;6EN:7-T<F5R82!A;G;D;F1A<F4@<^4@;>5S=&4@9'4@86YV
MY&YD82!E;B!A;FYA;B!A=71E;G1I<V5R:6YG<VMO<'!L:6YG+@!$:71T(&%U
M=&5N=&ES97)I;F=S:V]P<&QI;F<@<W3V9&5R(&EN=&4@;&ES=&YI;F<@878@
M86YVY&YD87)E+"!E;&QE<B!SY2#D<B!F=6YK=&EO;F5N(&%V<W3D;F=D+@!$
M:6X@=V5B8FSD<V%R92]I;G1E<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E9G1E
M<B!A='0@9'4@;&]G9V%T(&EN('1I;&P@)R5S)RX@1O9R(&%T="!S:WED9&$@
M9&EG+"!MY7-T92!D=2!L;V=G82!I;B!I9V5N+@!$:6X@=V5B8FSD<V%R92!S
M=/9D97(@:6YT92!D96X@:.1R(&9U;FMT:6]N96XN`$1I;B!W96)B;.1S87)E
M('-T]F1E<B!I;G1E('5T<VMR:69T<V9U;FMT:6]N96XN(%1R>6-K($-T<FPO
M3W!T:6]N("L@4"!F]G(@871T('-K<FEV82!U="X`1&EN(&%K='5E;&QA('1I
M9'-Z;VXZ`$1I;B!F]G)V86QD82!I9&5N=&ET970@:&%R(.1N9')A=',N`$1I
M;B!F]G)V86QD82!I9&5N=&ET970Z`$1I='0@9G5L;'-TY&YD:6=A(&YA;6XZ
M`$1I;B!I;FQO9V=N:6YG(&AA<B!GY71T('5T+@!$:71T(&YY82!L]G-E;F]R
M9"!F]G(@)7,@Y'(Z("5S`$1I;F$@:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T
M97)A=',@9O9R(&1E;B!HY'(@<V5S<VEO;F5N+@!$:6YA(&EN<W3D;&QN:6YG
M87(@:&%R('5P<&1A=&5R871S+@!$:71T(&SV<V5N;W)D(&AA<B!B;&EV:70@
MY71E<G-TY&QL=`!$:71T(&SV<VYO<F0@:&%R(.5T97)S=.1L;'1S+"!K;VYT
M<F]L;&5R82!D:6X@92UP;W-T(&]C:"!L;V=G82!I;B!M960@9&ET="!N>6$@
M;/9S96YO<F0N`$1I='0@;/9S96YO<F0@:&%R(&?E='0@=70N`$1I;F$@9FKD
M<G)S97)V<F%R.@!*=6=O<VQA=FEE;@!:86ER90!:86UB:6$`6FEM8F%B=V4`
M6FEP<'D`6T?V;2!C:71E<F%D('1E>'1=`%M);F=E="#D<F5N9&5=`%M&96QR
M87!P;W)T70!;5FES82!C:71E<F%D('1E>'0@+0!;5FES82!C:71E<F%D('1E
M>'0@+2`E<R!R861E<ET`6W)A9"`E<R!A=B`E<UT`7T%D<F5S<RAE<BD@871T
M('9I9&%R8F5F;V1R82!T:6QL.@!?061R97-S97(@871T(&EN=&4@<VMI8VMA
M('-V87(@=&EL;`!?061M:6YI<W1R871I;VX`7U-PY')R861E`%]#3$D`7T1A
M=&%4<N1D`%]2861E<F$@<F%D`%]2861E<F$@;65D9&5L86YD92!H96QT`%]!
M;F=E('9A<FIE(&%D<F5S<R!PY2!E;B!N>2!R860`7U9I9&%R8F5F;W)D<F$`
M7T=R=7!P97(`7TAJY&QP`%]":6QD:6YS=.1L;&YI;F=A<BXN+@!?4W!A<F$@
M96X@:V]P:6$@878@;65D9&5L86YD970@9O9R(&1E="!HY'(@:V]N=&]T/P!?
M3&]G9V$@:6X`7TQO9V=A('5T`,1?;F1R82!LY&YK+BXN`%]&;'ET=&$@;65D
M9&5L86YD92!T:6QL(&UA<'`Z`%]-:6YA(&4M<&]S=&%D<F5S<V5R`%]);G-T
MY&QL;FEN9V%R`%]"96CV<FEG:&5T97(`7U1A(&)O<G0@;.1N:RXN+@!?4F5G
M;&5R`%]3:W)I<'0`7U-E='5P`%]486)E;&QI;G-TY&QL;FEN9V%R+BXN`%]!
M;G;D;F1A<F4`7U-E;65S=&5R`%]"971R;V1D80!A:W1I=@!A9')E<W-B;VL`
M;VOD;F0@;6]T=&%G87)E`&]C:`!K86QE;F1E<@!L=6=N=`!K86X@:6YT92!S
M:V%P82!U=&9I;`!K86X@:6YT92#V<'!N82!I;F1A=&$`:VQI8VMA(&CD<@!K
M;&]C:V$`:V]M;6%N9&]R861S9F5L`&MO;F9I9W5R871I;VYS9F5L`&MR:71I
M<VL@<WES=&5M9FEL('-A:VYA<P!D871A9F]R;6%T9F5L`&%V86MT:79E<F%T
M("T@:VQI8VMA(&;V<B!A='0@86MT:79E<F$`Y&YD<F$`<&]S=&5N(&MU;F1E
M(&EN=&4@:&ET=&%S`&9A;&QA;F1E`&;D;'0`9FEL`&9RY6X@9&5N("5S("@E
M<RD@:VP@)7,@)7,`<W1O<FUB>6%R`&@Z`&AH`&]KY&YD(';D<F1D871O<@!G
M96YA<W0`:6YA:W1I=@!I;FQI;F4`8F5A<F)E=&YI;F=S9F5L`$EN=&5R;G0@
M87!P;&EK871I;VYS9F5L`')A9&5R70!M86EL9')O<"US:W)I<'0@<VMA<&%T
M(&%V($EN9V\`;6%T8VAA<@!F96QK;V0@)60@9G+E;B!M:VES;V9S`&UM`&YA
M;6X`:6YT92!I;7!L96UE;G1E<F%D`&EN=&4@:6UP;&5M96YT97)A9`!A;G1E
M8VMN:6YG<V)L;V-K`&5L;&5R`'!R;V-E;G0`Y71K;VUS="!N96MA9`!P:7AL
M87(`<')O8VUA:6P@<VMR:7!T('-K87!A="!A=B!);F=O`'!R;W1O:V]L;&9E
M;`!S=&EG86YD90!4:N1N<W1E;B#D<B!E:B!T:6QL9^1N9VQI9P!V:7-A('-K
M:6QL;F%D97(`4VEE=F4@9FEL=&5R('-K87!A="!A=B!);F=O`'-M<S)E;6%I
M;"!V:6$@2%144`!S<P!S=&%D:6=T`'-Y<W1E;69E;`!U<'!G:69T<VQI<W1A
M`'1I;&QFY&QL:6=T(&9E;`!A;F=E(&SV<V5N;W)D970@=';E(&?E;F=E<B!F
M]G(@871T(&)E:W+D9G1A`&5N860`;F%M;FSV<P!A;G;D;F1A<G9A;`!V0V%R
M9`!W.@!W96%T:&5R+F-O;0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6YG;R]L;V-A;&4O=')?5%(O````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,3<V-30`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]T<E]44B],0U]-15-304=%
M4R\`````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S0W`#`R,30T,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C86QE
M+W1R7U12+TQ#7TU%4U-!1T53+VEN9V\N;6\`````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`S-C4W,S$`,3`T,3<S-C(W-#<`,#(R-S0V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````2`<``!P```!<.@``
MQPD``)QT````````N)L```X```"YFP``#P```,B;```-````V)L```@```#F
MFP``"P```.^;```,````^YL```0````(G```!`````V<```#````$IP```P`
M```6G```#P```".<```+````,YP```X````_G```!0```$Z<```H````5)P`
M``@```!]G```"@```(:<```5````D9P``!(```"GG```"P```+J<```.````
MQIP```H```#5G```#0```."<```.````[IP``!$```#]G```#0````^=```,
M````'9T```T````JG0``!@```#B=```/````/YT``!@```!/G0``#````&B=
M```.````=9T```X```"$G0``"````).=```N````G)T``!H```#+G0``,@``
M`.:=```X````&9X``%0```!2G@``40```*>>``!:````^9X``%<```!4GP``
M-````*R?```'````X9\```H```#IGP``#P```/2?```%````!*````8````*
MH```$0```!&@```(````(Z````D````LH```"0```#:@```E````0*```"``
M``!FH```$````(>@```/````F*````H```"HH```(0```+.@```/````U:``
M``,```#EH```#P```.F@```4````^:````D````.H0``#0```!BA```2````
M)J$```\````YH0``"@```$FA```/````5*$```@```!DH0``)````&VA```4
M````DJ$``!8```"GH0``"````+ZA```9````QZ$``!,```#AH0``!P```/6A
M```,````_:$``"P````*H@``#@```#>B```#````1J(```L```!*H@``!P``
M`%:B```'````7J(```4```!FH@``!0```&RB```*````<J(```,```!]H@``
M%P```(&B```*````F:(```\```"DH@``#@```+2B```4````PZ(``!@```#8
MH@``(P```/&B```.````%:,``!0````DHP``%P```#FC```7````4:,``!<`
M``!IHP``$P```(&C```/````E:,```X```"EHP``'P```+2C```'````U*,`
M``8```#<HP``"````..C```/````[*,```8```#\HP``"`````.D```*````
M#*0``!,````7I```%````"ND```+````0*0``!````!,I```%0```%VD```-
M````<Z0``!4```"!I```!P```)>D```0````GZ0```4```"PI```%0```+:D
M```1````S*0```P```#>I```*@```.ND```[````%J4```D```!2I0``!P``
M`%RE```4````9*4```,```!YI0``!0```'VE```0````@Z4```D```"4I0``
M$P```)ZE```Y````LJ4``!(```#LI0``)P```/^E```L````)Z8``"H```!4
MI@``)0```'^F```*````I:8```8```"PI@``"0```+>F```'````P:8``"\`
M``#)I@``-P```/FF```N````,:<``%4```!@IP``+0```+:G```M````Y*<`
M`"T````2J```0````$"H```C````@:@``",```"EJ```+0```,FH```S````
M]Z@``!4````KJ0``&0```$&I```I````6ZD``"0```"%J0``,@```*JI```1
M````W:D```H```#OJ0``#````/JI```*````!ZH``!`````2J@``%@```".J
M```6````.JH```<```!1J@``!P```%FJ```4````8:H```H```!VJ@``"```
M`(&J```(````BJH```,```"3J@``"P```)>J```'````HZH```<```"KJ@``
M!@```+.J```%````NJH```<```#`J@``!@```,BJ```(````SZH```D```#8
MJ@``#@```.*J```[````\:H``!,````MJP``%0```$&K```I````5ZL```X`
M``"!JP``"@```)"K```$````FZL```0```"@JP``!P```*6K```)````K:L`
M``8```"WJP``$0```+ZK```'````T*L``!8```#8JP``!````.^K```(````
M]*L```8```#]JP``#0````2L```&````$JP``!X````9K```$0```#BL```(
M````2JP```T```!3K```#````&&L```'````;JP```,```!VK````P```'JL
M```7````?JP``!,```"6K```"````*JL```$````LZP```@```"XK```"```
M`,&L``!!````RJP``"`````,K0``!@```"VM```&````-*T``!4````[K0``
M&````%&M```B````:JT``"X```"-K0``'0```+RM```A````VJT``%0```#\
MK0``*0```%&N```*````>ZX```<```"&K@``#@```(ZN```5````G:X```X`
M``"SK@```@```,*N```*````Q:X```\```#0K@``#0```."N```/````[JX`
M``T```#^K@``"0````RO```4````%J\```8````KKP``&````#*O```=````
M2Z\``!,```!IKP``%````'VO```$````DJ\```8```"7KP``5````)ZO```.
M````\Z\```0````"L```#@````>P```%````%K````4````<L```&P```"*P
M```:````/K```!$```!9L```$0```&NP```<````?;```"H```":L```$```
M`,6P```A````UK````4```#XL```$P```/ZP```2````$K$```H````EL0``
M#P```#"Q```1````0+$``!,```!2L0``#````&:Q```&````<[$```8```!Z
ML0``%P```(&Q```0````F;$``!$```"JL0``"````+RQ```%````Q;$```P`
M``#+L0``$````-BQ```%````Z;$```T```#OL0``!@```/VQ```'````!+(`
M``T````,L@``!P```!JR```+````(K(```<````NL@``!P```#:R```)````
M/K(```H```!(L@``&0```%.R```,````;;(``!````!ZL@``!0```(NR```E
M````D;(``!(```"WL@``$P```,JR```K````WK(``#L````*LP``(````$:S
M```V````9[,```@```">LP``"````*>S```,````L+,```8```"]LP``!```
M`,2S```'````R;,```H```#1LP``#@```-RS```*````Z[,```T```#VLP``
M'@````2T```;````([0``"$````_M```'@```&&T```9````@+0``!X```":
MM```&P```+FT```F````U;0``!L```#\M```'@```!BU```<````-[4``"8`
M``!4M0``,P```'NU```F````K[4``"L```#6M0``.`````*V```O````.[8`
M`!(```!KM@``*0```'ZV```2````J+8``*(```"[M@``%@```%ZW```C````
M=;<``"@```"9MP``*0```,*W```H````[+<``!\````5N```(````#6X```E
M````5K@``"@```!\N```,````*6X``"2````UK@``"$```!IN0``'````(NY
M```F````J+D``$$```#/N0``#````!&Z```'````'KH```<````FN@``!@``
M`"ZZ```-````-;H``!````!#N@``$0```%2Z```2````9KH``!,```!YN@``
M$@```(VZ```'````H+H```0```"HN@``#````*VZ```.````NKH```\```#)
MN@``$P```-FZ```-````[;H``"@```#[N@```P```"2[```-````*+L```8`
M```VNP``$0```#V[```7````3[L``!L```!GNP``#@```(.[```"````DKL`
M``@```"5NP``"@```)Z[```%````J;L``!````"ONP``!````,"[```-````
MQ;L```X```#3NP```P```.*[```.````YKL``!$```#UNP``"`````>\```/
M````$+P```\````@O```!P```#"\```-````.+P``!````!&O```"P```%>\
M```&````8[P```D```!JO```$````'2\```,````A;P``!$```"2O```&0``
M`*2\```+````OKP```T```#*O```(@```-B\```9````^[P```H````5O0``
M&````""]```9````.;T``!8```!3O0``!P```&J]```5````<KT``"$```"(
MO0``)0```*J]```1````T+T```T```#BO0``!P```/"]```4````^+T```L`
M```-O@``(@```!F^```O````/+X```L```!LO@``"0```'B^```9````@KX`
M``L```"<O@``%P```*B^```7````P+X```D```#8O@``"@```.*^```(````
M[;X``!8```#VO@``#P````V_```Z````';\``!8```!8OP``#@```&^_```8
M````?K\```@```"7OP``+P```*"_```-````T+\``"8```#>OP``"`````7`
M``!#````#L```!(```!2P```#P```&7````0````=<````T```"&P```(0``
M`)3````(````ML```!(```"_P```"````-+````+````V\```"\```#GP```
M#@```!?!```%````)L$```8````LP0```P```#/!```'````-\$```0````_
MP0``!P```$3!```*````3,$```H```!7P0``#P```&+!```0````<L$``!<`
M``"#P0``$0```)O!```7````K<$```D```#%P0``!0```,_!```+````U<$`
M``H```#AP0```@```.S!```%````[\$```T```#UP0``&P````/"```7````
M'\(```D````WP@``#@```$'"```-````4,(``!(```!>P@``"0```''"```X
M````>\(``"````"TP@``!P```-7"```(````W<(```D```#FP@``#@```/#"
M``![````_\(``!@```![PP``"````)3#```1````G<,```<```"OPP``!0``
M`+?#```9````O<,```<```#7PP``"````-_#```&````Z,,```8```#OPP``
M$````/;#```/````!\0``!`````7Q```#P```"C$```+````.,0```\```!$
MQ```#````%3$```/````8<0```<```!QQ```#@```'G$```&````B,0```8`
M``"/Q```#@```);$```,````I<0``"@```"RQ```#P```-O$```(````Z\0`
M``@```#TQ```$P```/W$```>````$<4``"$````PQ0``(````%+%```9````
M<\4``!<```"-Q0``)0```*7%```7````R\4```0```#CQ0``&P```.C%```-
M````!,8```P````2Q@```P```!_&```(````(\8```H````LQ@``#````#?&
M```+````1,8``!````!0Q@``#````&'&```$````;L8``!,```!SQ@``%```
M`(?&```,````G,8```D```"IQ@``#@```+/&```+````PL8``!L```#.Q@``
M$P```.K&```9````_L8``!L````8QP``#@```#3'```+````0\<```P```!/
MQP``%0```%S'```-````<L<``$,```"`QP``,0```,3'``!"````]L<``$<`
M```YR```3P```('(```]````T<@``$X````/R0``$0```%[)```'````<,D`
M``<```!XR0``"@```(#)```-````B\D```D```"9R0``!````*/)```%````
MJ,D```,```"NR0``&````++)```*````R\D```0```#6R0``)0```-O)```F
M`````<H```X````HR@``?````#?*```5````M,H```4```#*R@``!P```-#*
M```,````V,H```@```#ER@``"@```.[*```&````^<H```<`````RP``.0``
M``C+```(````0LL```T```!+RP```@```%G+```&````7,L```8```!CRP``
M%````&K+```-````?\L``!````"-RP``&P```)[+```$````NLL```D```"_
MRP``$````,G+```)````VLL```D```#DRP``!0```.[+```:````],L```@`
M```/S```!@```!C,```9````'\P```X````YS```!P```$C,```'````4,P`
M``4```!8S```"0```%[,```*````:,P```(```!SS```!@```';,```-````
M?<P```D```"+S```#````)7,```8````HLP```8```"[S```$@```,+,```)
M````U<P```<```#?S```%````.?,```=````_,P```8````:S0``"@```"'-
M```$````+,T```D````QS0``"````#O-```1````1,T```D```!6S0``!@``
M`&#-```-````9\T```8```!US0``!````'S-```Y````@<T``#T```"[S0``
M.@```/G-```>````-,X```4```!3S@``#@```%G.```$````:,X```8```!M
MS@``(0```'3.```5````ELX```8```"LS@``!````+/.```1````N,X```8`
M``#*S@``"@```-'.```B````W,X```0```#_S@``!0````3/```=````"L\`
M``0````HSP``#````"W/```*````.L\```@```!%SP``"0```$[/```%````
M6,\``#H```!>SP``,````)G/```U````RL\``"D`````T```1P```"K0```X
M````<M```"D```"KT```/P```-70```N````%=$``"T```!$T0``'P```'+1
M```/````DM$``!(```"BT0``"P```+71```F````P=$``"D```#HT0``)```
M`!+2```F````-](```@```!>T@``"@```&?2```)````<M(```<```!\T@``
M(````(32```@````I=(``"8```#&T@``"@```.W2```9````^-(``"D````2
MTP``%@```#S3```2````4],```<```!FTP``"@```&[3```,````>=,```\`
M``"&TP``$````);3``!`````I],``'````#HTP``9@```%G4```.````P-0`
M``D```#/U```"@```-G4```2````Y-0``!,```#WU```#`````O5```&````
M&-4```\````?U0``"0```"_5```2````.=4``!````!,U0``$0```%W5```<
M````;]4``",```",U0``:@```+#5```/````&]8```4````KU@``$````#'6
M``!#````0M8```D```"&U@``,@```)#6```$````P]8```L```#(U@``%```
M`-36```,````Z=8```P```#VU@``#P````/7```5````$]<``"D````IUP``
M*@```%/7```F````?M<``"<```"EUP``*0```,W7```J````]]<``!D````B
MV```0@```#S8```1````?]@``!(```"1V```$P```*38```4````N-@```\`
M``#-V```%@```-W8```7````]-@``!`````,V0``$0```!W9```T````+]D`
M`!,```!DV0``$@```'C9```U````B]D``!0```#!V0``!P```-;9```,````
MWMD``"````#KV0``%`````S:```1````(=H``!<````SV@``'````$O:```3
M````:-H``!$```!\V@``&@```([:```>````J=H``!H```#(V@``$0```./:
M```4````]=H``!<````*VP``%0```"+;```)````.-L``!D```!"VP``!```
M`%S;```'````8=L```(```!IVP``"P```&S;```%````>-L``!$```!^VP``
M!@```)#;```&````E]L```8```">VP``!0```*7;```'````J]L```<```"S
MVP``!0```+O;```6````P=L```8```#8VP``!@```-_;```$````YML```0`
M``#KVP``!P```/#;```.````^-L```P````'W```#````!3<```-````(=P`
M``H````OW```#@```#K<```%````2=P``"@```!/W```#@```'C<```,````
MA]P```\```"4W```"@```*3<```(````K]P```D```"XW```*P```,+<```$
M````[MP```@```#SW```)@```/S<```2````(]T```\````VW0``!@```$;=
M```*````3=T```<```!8W0``"````&#=```@````:=T```D```"*W0``#```
M`)3=```-````H=T```X```"OW0``%@```+[=```1````U=T```8```#GW0``
M`P```.[=```&````\MT``!D```#YW0``!P```!/>```$````&]X```L````@
MW@``"P```"S>```'````.-X```D```!`W@``%0```$K>```'````8-X``!8`
M``!HW@``#0```'_>```-````C=X```H```";W@``$````*;>```/````M]X`
M`!$```#'W@``%P```-G>```*````\=X``!$```#\W@``"`````[?```$````
M%]\```\````<WP``.@```"S?```%````9]\```P```!MWP``'@```'K?```.
M````F=\``!````"HWP``"P```+G?```,````Q=\```D```#2WP``!P```-S?
M```'````Y-\```H```#LWP``"0```/??```.`````>```!`````0X```&@``
M`"'@```*````/.````D```!'X```"@```%'@```,````7.````\```!IX```
M"````'G@```&````@N````<```")X```"P```)'@``!'````G>````T```#E
MX```"0```//@```$````_>````,````"X0``$P````;A```3````&N$``!,`
M```NX0``"@```$+A```"````3>$```0```!0X0``)0```%7A```#````>^$`
M``4```!_X0``*@```(7A```*````L.$```4```"[X0``!````,'A```*````
MQN$```T```#1X0``!@```-_A```(````YN$```@```#OX0``!````/CA```%
M````_>$``&@````#X@``"0```&SB```,````=N(``!@```"#X@``!0```)SB
M```&````HN(``!````"IX@``&P```+KB```O````UN(``!`````&XP``"@``
M`!?C```;````(N,```\````^XP``"@```$[C```)````6>,``!,```!CXP``
M&P```'?C```8````D^,``!<```"LXP``#@```,3C``")````T^,``(D```!=
MY````P```.?D```'````Z^0```@```#SY```!P```/SD```*````!.4```L`
M```/Y0``!P```!OE``!1````(^4``!````!UY0``#````(;E```-````D^4`
M`!H```"AY0``2@```+SE```&````!^8```8````.Y@``!@```!7F```?````
M'.8```8````\Y@``"0```$/F```8````3>8``!<```!FY@``!@```'[F```-
M````A>8``"(```"3Y@``)@```+;F``!7````W>8``!,````UYP``&0```$GG
M```;````8^<``",```!_YP``$P```*/G```"````M^<```L```"ZYP``"```
M`,;G```-````S^<```H```#=YP``!P```.CG```4````\.<```8````%Z```
M"`````SH```.````%>@```<````DZ```"@```"SH```+````-^@```<```!#
MZ```#````$OH```-````6.@```P```!FZ```!````'/H```)````>.@```D`
M``""Z```"@```(SH```.````E^@```P```"FZ```!P```+/H```)````N^@`
M``<```#%Z```"@```,WH```;````V.@``!(```#TZ```"@````?I```)````
M$ND``!`````<Z0``!P```"WI```2````->D``"D```!(Z0``!````'+I```'
M````=^D```4```!_Z0``!0```(7I```+````B^D``!0```"7Z0``$0```*SI
M```:````OND``!8```#9Z0``%````/#I```7````!>H``!@````=Z@``'```
M`#;J```9````4^H```<```!MZ@``!0```'7J```-````>^H```P```")Z@``
M"````);J```(````G^H``!<```"HZ@``"P```,#J```3````S.H```0```#@
MZ@``"@```.7J```$````\.H```P```#UZ@``"0````+K```%````#.L```<`
M```2ZP``!0```!KK```$````(.L```(````EZP``+P```"CK```X````6.L`
M`"P```"1ZP``(P```+[K```F````XNL``!(````)[```*0```!SL```R````
M1NP```H```!Y[```+````(3L```N````L>P``#,```#@[```,P```!3M```X
M````2.T```\```"![0``&````)'M```0````JNT``"X```"[[0``%````.KM
M```/````_^T``!,````/[@``%````"/N```2````..X``!0```!+[@``%0``
M`&#N```M````=NX``"T```"D[@``,0```-+N```N````!.\``"\````S[P``
M+````&/O``!B````D.\``!,```#S[P``"`````?P```4````$/````@````E
M\```%````"[P```K````0_```"$```!O\```&@```)'P```)````K/```$4`
M``"V\```00```/SP```$````/O$``!,```!#\0``%````%?Q```.````;/$`
M`!,```![\0``&````(_Q```&````J/$```D```"O\0``"@```+GQ```/````
MQ/$```P```#4\0``$````.'Q```'````\O$```X```#Z\0``!0````GR```;
M````#_(```@````K\@``!@```#3R```4````._(``!$```!0\@``#@```&+R
M```X````<?(```(```"J\@``!@```*WR```.````M/(```4```##\@``!P``
M`,GR```.````T?(```8```#@\@``!````.?R```I````[/(``!<````6\P``
M'P```"[S``!<````3O,``!0```"K\P``/@```,#S```?````__,``!`````?
M]```!P```##T```>````./0```X```!7]```#````&;T```,````<_0``!,`
M``"`]```"@```)3T```=````G_0``!D```"]]```!0```-?T```1````W?0`
M``T```#O]```$0```/WT```D````#_4``!4````T]0``$@```$KU```.````
M7?4``!D```!L]0``"````(;U```)````C_4```T```"9]0``"@```*?U```'
M````LO4```\```"Z]0``"P```,KU```*````UO4```<```#A]0``"````.GU
M```%````\O4``!\```#X]0``!@```!CV```0````'_8```@````P]@``#0``
M`#GV```(````1_8``!(```!0]@``+````&/V```:````D/8```D```"K]@``
M"@```+7V```5````P/8```4```#6]@``%````-SV```$````\?8``!````#V
M]@``!@````?W```'````#O<``!X````6]P``*````#7W```*````7O<``!H`
M``!I]P``%````(3W```$````F?<```0```">]P``"P```*/W```%````K_<`
M``8```"U]P``"````+SW```&````Q?<```H```#,]P``&P```-?W```T````
M\_<``#0````H^```(````%WX```I````?O@``"````"H^```00```,GX```:
M````"_D``"@````F^0``*````$_Y```I````>/D``"(```"B^0``!@```,7Y
M```(````S/D```4```#5^0``"````-OY```9````Y/D``!D```#^^0``*@``
M`!CZ```C````0_H``"X```!G^@``-````);Z```(````R_H``!<```#4^@``
M"@```.SZ```'````]_H``"$```#_^@``$````"'[```.````,OL```L```!!
M^P``!P```$W[```3````5?L```@```!I^P``"P```'+[```*````?OL``!0`
M``")^P``,@```)[[```+````T?L```4```#=^P``!0```./[```7````Z?L`
M``<````!_```#P````G\```$````&?P```H````>_```"0```"G\```+````
M,_P```T````__```#````$W\```.````6OP```4```!I_```!````&_\```-
M````=/P``#(```""_```10```+7\```(````^_P```L````$_0``%P```!#]
M```>````*/T``!0```!'_0``!0```%S]```2````8OT``!(```!U_0``%```
M`(C]```'````G?T```X```"E_0``*@```+3]```&````W_T```P```#F_0``
M#0```//]```1`````?X```L````3_@``-@```!_^```*````5OX``"(```!A
M_@``"P```(3^```/````D/X``#(```"@_@``#@```-/^```)````XOX```L`
M``#L_@``!0```/C^```.````_OX``!,````-_P``!P```"'_```6````*?\`
M`!$```!`_P``%````%+_```'````9_\``!0```!O_P``&````(3_```'````
MG?\```4```"E_P``#````*O_```,````N/\``!(```#%_P``!````-C_```'
M````W?\```H```#E_P``"P```/#_```,````_/\```X````)``$`#@```!@`
M`0`%````)P`!``0````M``$`"P```#(``0`,````/@`!``T```!+``$`#```
M`%D``0`)````9@`!``4```!P``$`+@```'8``0`F````I0`!`",```#,``$`
M`P```/```0`2````]``!``8````'`0$`'@````X!`0`8````+0$!`"4```!&
M`0$`#0```&P!`0`)````>@$!``,```"$`0$`!P```(@!`0`*````D`$!``(`
M``";`0$`#````)X!`0`5````JP$!``L```#!`0$`&0```,T!`0`@````YP$!
M`!(````(`@$`!0```!L"`0`*````(0(!`!4````L`@$`$@```$("`0`,````
M50(!``0```!B`@$`!P```&<"`0`,````;P(!``T```!\`@$`4@```(H"`0`7
M````W0(!``<```#U`@$`!@```/T"`0`/````!`,!`!,````4`P$`'@```"@#
M`0`@````1P,!``8```!H`P$`#@```&\#`0`$````?@,!``P```"#`P$`#0``
M`)`#`0`.````G@,!`!4```"M`P$`$@```,,#`0`/````U@,!`!0```#F`P$`
M&P```/L#`0`0````%P0!`!0````H!`$`:0```#T$`0`:````IP0!`!<```#"
M!`$`)P```-H$`0`:`````@4!`!<````=!0$`&P```#4%`0`9````404!`!\`
M``!K!0$`$P```(L%`0`3````GP4!``@```"S!0$`!@```+P%`0`'````PP4!
M``@```#+!0$`"0```-0%`0`5````W@4!``T```#T!0$`$P````(&`0`#````
M%@8!`$8````:!@$`/P```&$&`0`W````H08!`%<```#9!@$`'@```#$'`0`%
M````4`<!`!\```!6!P$`+P```'8'`0`*````I@<!``@```"Q!P$`#0```+H'
M`0`M````R`<!``0```#V!P$`$@```/L'`0`3````#@@!`$\````B"`$`)0``
M`'((`0`<````F`@!``L```"U"`$`'P```,$(`0`=````X0@!`"4```#_"`$`
M(````"4)`0`D````1@D!`"````!K"0$`"P```(P)`0`'````F`D!``T```"@
M"0$`#````*X)`0`7````NPD!``8```#3"0$`.0```-H)`0`,````%`H!``<`
M```A"@$`"0```"D*`0`3````,PH!``D```!'"@$`!````%$*`0`0````5@H!
M``@```!G"@$`"````'`*`0`$````>0H!``L```!^"@$`#````(H*`0`2````
MEPH!`!$```"J"@$`#````+P*`0`:````R0H!``\```#D"@$`!P```/0*`0`-
M````_`H!`!0````*"P$`#@```!\+`0`,````+@L!`!L````["P$`+````%<+
M`0`3````A`L!`!P```"8"P$`*````+4+`0`&````W@L!``<```#E"P$`$P``
M`.T+`0`%`````0P!``0````'#`$`%P````P,`0`*````)`P!``P````O#`$`
M"0```#P,`0`&````1@P!``D```!-#`$`"````%<,`0`)````8`P!``H```!J
M#`$`$0```'4,`0`&````APP!`",```".#`$`#@```+(,`0`.````P0P!``T`
M``#0#`$`"P```-X,`0`=````Z@P!``L````(#0$``@```!0-`0`=````%PT!
M``<````U#0$`!@```#T-`0`)````1`T!``<```!.#0$`.P```%8-`0`H````
MD@T!`#0```"[#0$`%0```/`-`0`%````!@X!``<````,#@$`"````!0.`0`'
M````'0X!``4````E#@$`!P```"L.`0`.````,PX!``D```!"#@$`!@```$P.
M`0`(````4PX!``L```!<#@$`!P```&@.`0`(````<`X!``<```!Y#@$`%@``
M`($.`0`)````F`X!``8```"B#@$`"P```*D.`0`<````M0X!`!0```#2#@$`
M!P```.<.`0`(````[PX!``@```#X#@$`!0````$/`0`0````!P\!`!`````8
M#P$`!@```"D/`0`9````,`\!``H```!*#P$`'````%4/`0`'````<@\!``4`
M``!Z#P$`$````(`/`0`4````D0\!``L```"F#P$`#0```+(/`0`7````P`\!
M``0```#8#P$`"0```-T/`0`*````YP\!``<```#R#P$``@```/H/`0`.````
M_0\!``@````,$`$`'P```!40`0`C````-1`!`#@```!9$`$`,0```)(0`0`G
M````Q!`!`&0```#L$`$`%````%$1`0!5````9A$!`#@```"\$0$`2@```/41
M`0!;````0!(!`"@```"<$@$`$0```,42`0`X````UQ(!`"@````0$P$`+```
M`#D3`0`G````9A,!`!L```".$P$`/@```*H3`0"I`0``Z1,!`",```"3%0$`
M%P```+<5`0!(````SQ4!`(4````8%@$`,````)X6`0!!````SQ8!`%L````1
M%P$`20```&T7`0`=````MQ<!`!@```#5%P$`(0```.X7`0`?````$!@!`"L`
M```P&`$`(0```%P8`0`G````?A@!`!T```"F&`$`$0```,08`0`S````UA@!
M`"4````*&0$`)P```#`9`0`?````6!D!`#````!X&0$`:0```*D9`0`]````
M$QH!`&4```!1&@$`30```+<:`0`I````!1L!`"L````O&P$`+P```%L;`0`N
M````BQL!`#````"Z&P$`5````.L;`0!:````0!P!`$@```";'`$`2@```.0<
M`0`R````+QT!`"\```!B'0$`+````)(=`0`M````OQT!`'$```#M'0$`;P``
M`%\>`0"S````SQX!`!<```"#'P$`)0```)L?`0`R````P1\!`"D```#T'P$`
M/@```!X@`0`B````72`!`%(```"`(`$`)0```-,@`0`+````^2`!`+$````%
M(0$`10```+<A`0`A````_2$!`#`````?(@$`)0```%`B`0`<````=B(!`#$`
M``"3(@$`!P```,4B`0`'````S2(!``0```#5(@$`#0```-HB`0`+````Z"(!
M``X```#T(@$`"P````,C`0`%````#R,!`!`````5(P$``@```"8C`0!9````
M*2,!``4```"#(P$`$@```(DC`0`$````G",!``<```"A(P$`"````*DC`0`%
M````LB,!``,```"X(P$`$````+PC`0`,````S2,!`!,```#:(P$`#0```.XC
M`0`"````_",!``<```#_(P$`!@````<D`0`4````#B0!``P````C)`$`&```
M`#`D`0`&````220!`!(```!0)`$`#````&,D`0`#````<"0!`"H```!T)`$`
M!````)\D`0`&````I"0!``<```"K)`$`'P```+,D`0`U````TR0!`"X````)
M)0$`+P```#@E`0`7````:"4!`"````"`)0$`&P```*$E`0`8````O24!`"0`
M``#6)0$`'P```/LE`0`:````&R8!`"`````V)@$`&@```%<F`0`R````<B8!
M`"\```"E)@$`*P```-4F`0`?`````2<!`",````A)P$`'P```$4G`0`:````
M92<!`"4```"`)P$`)@```*8G`0`E````S2<!`"0```#S)P$`&````!@H`0`=
M````,2@!`"0```!/*`$`&````'0H`0`B````C2@!`"4```"P*`$`/````-8H
M`0`?````$RD!`",````S*0$`'P```%<I`0`@````=RD!`!H```"8*0$`&```
M`+,I`0`F````S"D!`!X```#S*0$`*0```!(J`0`>````/"H!``D```!;*@$`
M#````&4J`0`7````<BH!`"\```"**@$`)````+HJ`0`'````WRH!``\```#G
M*@$`%````/<J`0`.````#"L!``T````;*P$`)````"DK`0`%````3BL!``<`
M``!4*P$`(@```%PK`0`E````?RL!`!T```"E*P$`&@```,,K`0`'````WBL!
M`,<```#F*P$`"P```*XL`0`5````NBP!``8```#0+`$`"0```-<L`0`+````
MX2P!`!<```#M+`$`!@````4M`0`S````#"T!`!,```!`+0$`$P```%0M`0`'
M````:"T!``\```!P+0$`!P```(`M`0`R````B"T!`"$```"[+0$`$P```-TM
M`0`,````\2T!`!$```#^+0$`,@```!`N`0`(````0RX!``D```!,+@$`"@``
M`%8N`0`4````82X!``H```!V+@$`'0```($N`0`(````GRX!``T```"H+@$`
M$````+8N`0`Z````QRX!`!\````"+P$`"````"(O`0`:````*R\!``8```!&
M+P$`%0```$TO`0`'````8R\!``@```!K+P$`"0```'0O`0`_````?B\!``<`
M``"^+P$`#P```,8O`0`.````UB\!`!````#E+P$`"0```/8O`0`)`````#`!
M``@````*,`$`$P```!,P`0`'````)S`!`!D````O,`$`"@```$DP`0`7````
M5#`!`!0```!L,`$`"@```($P`0`,````C#`!`!<```"9,`$`!````+$P`0`J
M````MC`!`!$```#A,`$`!P```/,P`0`"````^S`!`!````#^,`$`&`````\Q
M`0`+````*#$!``,````T,0$`"````#@Q`0`&````03$!``<```!(,0$`#0``
M`%`Q`0`+````7C$!`!0```!J,0$`%0```'\Q`0`.````E3$!`!4```"D,0$`
M+P```+HQ`0`@````ZC$!`!P````+,@$`#````"@R`0`Q````-3(!``D```!G
M,@$`#@```'$R`0`[````@#(!`!4```"\,@$`!0```-(R`0`2````V#(!`#\`
M``#K,@$`$@```"LS`0`*````/C,!``8```!),P$`!````%`S`0`$````53,!
M``H```!:,P$`$P```&4S`0`%````>3,!``8```!_,P$`!@```(8S`0`$````
MC3,!``P```"2,P$`"@```)\S`0`*````JC,!``4```"U,P$`#````+LS`0`,
M````R#,!``T```#5,P$`&````.,S`0`9````_#,!`!\````6-`$`'0```#8T
M`0`1````5#0!``(```!F-`$`!````&DT`0`*````;C0!``8```!Y-`$`!0``
M`(`T`0`#````AC0!``P```"*-`$`10```)<T`0`:````W30!`#4```#X-`$`
M*````"XU`0!3````5S4!`!D```"K-0$`<@```,4U`0`@````.#8!`#4```!9
M-@$`(0```(\V`0!%````L38!`#````#W-@$`*````"@W`0`I````43<!`"8`
M``![-P$`8````*(W`0`E`````S@!`"@````I.`$`*````%(X`0`B````>S@!
M`#````">.`$`$@```,\X`0`3````XC@!`!````#V.`$`>0````<Y`0`)````
M@3D!`',```"+.0$`?````/\Y`0`K````?#H!`!<```"H.@$`%@```,`Z`0`/
M````USH!`!\```#G.@$`0`````<[`0`?````2#L!`!P```!H.P$`40```(4[
M`0`4````USL!``H```#L.P$`!0```/<[`0`&````_3L!``@````$/`$`!0``
M``T\`0`2````$SP!``P````F/`$`$````#,\`0`3````1#P!`!T```!8/`$`
M#P```'8\`0`;````ACP!`"0```"B/`$`#P```,<\`0`*````USP!``0```#B
M/`$`"0```.<\`0`+````\3P!`!H```#]/`$`(@```!@]`0`(````.ST!``<`
M``!$/0$`!0```$P]`0`4````4CT!`"D```!G/0$`!P```)$]`0`(````F3T!
M``\```"B/0$`&````+(]`0`4````RST!``@```#@/0$`#````.D]`0`/````
M]CT!``<````&/@$`!@````X^`0`4````%3X!``8````J/@$`"0```#$^`0`*
M````.SX!``P```!&/@$``P```%,^`0`(````5SX!``0```!@/@$`"@```&4^
M`0`'````<#X!``4```!X/@$`!````'X^`0`9````@SX!``(```"=/@$`"0``
M`*`^`0`&````JCX!``8```"Q/@$`!0```+@^`0`G````OCX!``0```#F/@$`
M#P```.L^`0`3````^SX!``<````//P$``@```!<_`0`'````&C\!``8````B
M/P$`(0```"D_`0`&````2S\!`!````!2/P$`'@```&,_`0`2````@C\!``8`
M``"5/P$`"0```)P_`0`B````IC\!``<```#)/P$`!P```-$_`0`+````V3\!
M``4```#E/P$``@```.L_`0`+````[C\!`&P!``#Z/P$`#@```&=!`0`4````
M=D$!``L```"+00$`"````)=!`0`(````H$$!``8```"I00$``P```+!!`0`(
M````M$$!``4```"]00$`"P```,-!`0`6````ST$!``T```#F00$`#0```/1!
M`0`%`````D(!`!T````(0@$`"@```"9"`0`(````,4(!`!0````Z0@$`#0``
M`$]"`0`+````74(!`!$```!I0@$`"0```'M"`0`.````A4(!``T```"40@$`
M$````*)"`0`)````LT(!``X```"]0@$`$````,Q"`0`&````W4(!`!$```#D
M0@$`$@```/9"`0`)````"4,!`!<````30P$`%P```"M#`0`'````0T,!`#,`
M``!+0P$`%P```']#`0`]````ET,!`$T```#50P$`9````"-$`0!<````B$0!
M`&L```#E1`$`8P```%%%`0`_````M44!``D```#U10$`"0```/]%`0`,````
M"48!``4````61@$`!@```!Q&`0`4````(T8!``P````X1@$`!0```$5&`0`&
M````2T8!`"@```!21@$`*@```'M&`0`.````ID8!`!$```"U1@$`#````,=&
M`0`E````U$8!`!4```#Z1@$`!````!!'`0`-````%4<!``T````C1P$`#```
M`#%'`0`.````/D<!``X```!-1P$`%````%Q'`0`*````<4<!``T```!\1P$`
M"@```(I'`0`L````E4<!`!4```#"1P$`%````-A'`0`.````[4<!`",```#\
M1P$`#0```"!(`0`%````+D@!``T````T2`$`,@```$)(`0`'````=4@!``,`
M``!]2`$`"@```(%(`0`*````C$@!``<```"72`$`"````)](`0`&````J$@!
M``H```"O2`$`!````+I(`0`<````OT@!``L```#<2`$`"P```.A(`0`,````
M]$@!`!4````!20$`&````!=)`0`T````,$D!``D```!E20$`$0```&])`0`3
M````@4D!`!@```"520$`'0```*Y)`0`/````S$D!``P```#<20$`#@```.E)
M`0`:````^$D!``8````32@$`!@```!I*`0`(````(4H!``P````J2@$`!0``
M`#=*`0`+````/4H!``D```!)2@$`$@```%-*`0`=````9DH!``@```"$2@$`
M$````(U*`0`.````GDH!`!$```"M2@$`%P```+]*`0`&````UTH!``X```#>
M2@$`!0```.U*`0`5````\TH!`!4````)2P$`#````!]+`0`K````+$L!`#H`
M``!82P$`"````)-+`0`*````G$L!`!0```"G2P$`!0```+Q+`0`%````PDL!
M`!$```#(2P$`#````-I+`0`4````YTL!`"\```#\2P$`#P```"Q,`0`E````
M/$P!`"0```!B3`$`*0```(=,`0`M````L4P!``P```#?3`$`!P```.Q,`0`+
M````]$P!``D`````30$`+P````I-`0`L````.DT!`"T```!G30$`7P```)5-
M`0`L````]4T!`"P````B3@$`+````$].`0`N````?$X!`"0```"K3@$`*```
M`-!.`0`L````^4X!`#(````F3P$`&0```%E/`0`<````<T\!`#,```"03P$`
M*````,1/`0`^````[4\!`!,````L4`$`"@```$!0`0`1````2U`!``<```!=
M4`$`#0```&50`0`7````<U`!`!P```"+4`$`"0```*A0`0`'````LE`!`!0`
M``"Z4`$`"0```,]0`0`(````V5`!``T```#B4`$`"@```/!0`0`+````^U`!
M``L````'40$`!P```!-1`0`&````&U$!``4````B40$`!P```"A1`0`&````
M,%$!``D````W40$`"0```$%1`0`3````2U$!`$0```!?40$`&0```*11`0`<
M````OE$!`#$```#;40$`#0````U2`0`)````&U(!``8````E4@$`!````"Q2
M`0`'````,5(!``H````Y4@$`!0```$12`0`0````2E(!``@```!;4@$`#```
M`&12`0`)````<5(!``@```![4@$``P```(12`0`.````B%(!``@```"74@$`
M'@```*!2`0`&````OU(!``L```#&4@$`$````-)2`0`,````XU(!``<```#P
M4@$``P```/A2`0`#````_%(!`!4`````4P$`%0```!93`0`&````+%,!``8`
M```S4P$`"````#I3`0`'````0U,!`$P```!+4P$`'P```)A3`0`&````N%,!
M``4```"_4P$`%P```,53`0`8````W5,!`!@```#V4P$`,0````]4`0`:````
M050!`!\```!<5`$`=P```'Q4`0`L````]%0!``H````A50$`!@```"Q5`0`8
M````,U4!`!@```!,50$`#@```&55`0`(````=%4!``P```!]50$`$0```(I5
M`0`3````G%4!`!$```"P50$`$0```,)5`0`,````U%4!`!0```#A50$`!```
M`/95`0`7````^U4!`!@````35@$`&````"Q6`0`6````158!``,```!<5@$`
M"````&!6`0!K````:58!`!D```#55@$`"````.]6`0`6````^%8!``0````/
M5P$``P```!17`0`?````&%<!`!<````X5P$`#````%!7`0`3````75<!`"<`
M``!Q5P$`,P```)E7`0`1````S5<!`!H```#?5P$`!P```/I7`0`?`````E@!
M`!<````B6`$`$0```#I8`0`8````3%@!`!D```!E6`$`%P```']8`0`/````
MEU@!``@```"G6`$`!P```+!8`0`-````N%@!`!4```#&6`$`%````-Q8`0`)
M````\5@!``0```#[6`$`"P````!9`0`+````#%D!``D````860$`$````")9
M`0`%````,UD!``4````Y60$`#````#]9`0`(````3%D!``D```!560$`!P``
M`%]9`0`&````9UD!``T```!N60$`"````'Q9`0`5````A5D!``T```";60$`
M$````*E9`0`%````NED!`!P```#`60$`&````-U9`0`8````]ED!`"P````/
M6@$`.P```#Q:`0`E````>%H!`#<```">6@$`#````-9:`0`%````XUH!``P`
M``#I6@$`!0```/9:`0`'````_%H!``H````$6P$`"P````];`0`.````&UL!
M``H````J6P$`#0```#5;`0`<````0UL!`!L```!@6P$`'P```'Q;`0`>````
MG%L!`!\```"[6P$`'@```-M;`0`8````^EL!`"`````37`$`(0```#1<`0`D
M````5EP!`!\```![7`$`'@```)M<`0`O````NEP!`",```#J7`$`)0````Y=
M`0`Q````-%T!`"X```!F70$`#0```)5=`0`E````HUT!``T```#)70$`F0``
M`-==`0`0````<5X!`!\```""7@$`(0```*)>`0`C````Q%X!`"0```#H7@$`
M(0````U?`0`>````+U\!`"4```!.7P$`*````'1?`0`L````G5\!`*,```#*
M7P$`&````&Y@`0`C````AV`!`"(```"K8`$`2P```,Y@`0`.````&F$!``0`
M```I80$`!P```"YA`0`%````-F$!``X````\80$`"@```$MA`0`0````5F$!
M``\```!G80$`$0```'=A`0`3````B6$!``L```"=80$`!````*EA`0`/````
MKF$!``T```"^80$`%0```,QA`0`2````XF$!`!(```#U80$`,`````AB`0`#
M````.6(!`!,````]8@$`!@```%%B`0`.````6&(!`!0```!G8@$`%@```'QB
M`0`/````DV(!``(```"C8@$`$````*9B`0`2````MV(!``8```#*8@$`%0``
M`-%B`0`%````YV(!``P```#M8@$`#````/IB`0`#````!V,!``L````+8P$`
M&@```!=C`0`&````,F,!``\````Y8P$`#P```$EC`0`*````66,!``\```!D
M8P$`$0```'1C`0`(````AF,!``,```"/8P$`!P```)-C`0`*````FV,!``@`
M``"F8P$`"````*]C`0`8````N&,!``D```#18P$`"0```-MC`0`9````Y6,!
M`!,```#_8P$`"@```!-D`0`4````'F0!`!0````S9`$`%````$AD`0`'````
M760!`!4```!E9`$`)````'MD`0`C````H&0!``T```#$9`$`#0```-)D`0`)
M````X&0!`!$```#J9`$`"````/QD`0`\````!64!`#(```!"90$`!P```'5E
M`0`+````?64!`!H```")90$`#0```*1E`0`1````LF4!`!$```#$90$`!0``
M`-9E`0`1````W&4!`!````#N90$`(````/]E`0`7````(&8!`$0````X9@$`
M'@```'UF`0`2````G&8!``\```"O9@$`!@```+]F`0`L````QF8!``@```#S
M9@$`+0```/QF`0`$````*F<!`#X````O9P$`"@```&YG`0`)````>6<!``@`
M``"#9P$`"@```(QG`0`+````EV<!``<```"C9P$`$P```*MG`0`%````OV<!
M``@```#%9P$`,P```,YG`0`2`````F@!``<````5:`$`!P```!UH`0`#````
M)6@!``<````I:`$`!P```#%H`0`*````.6@!``P```!$:`$`#````%%H`0`,
M````7F@!`!````!K:`$`&````'QH`0`4````E6@!`!@```"J:`$`!@```,-H
M`0`%````RF@!``L```#0:`$`!@```-QH`0`"````XV@!`!````#F:`$`%P``
M`/=H`0`E````#VD!`!<````U:0$`$````$UI`0`*````7FD!``H```!I:0$`
M$P```'1I`0`/````B&D!`$X```"8:0$`*@```.=I`0`/````$FH!``H````B
M:@$`!0```"UJ`0`6````,VH!`'(```!*:@$`'0```+UJ`0`'````VVH!``X`
M``#C:@$`!@```/)J`0`$````^6H!`"````#^:@$`!P```!]K`0`(````)VL!
M``4````P:P$`!@```#9K`0`-````/6L!``P```!+:P$`#0```%AK`0`,````
M9FL!``L```!S:P$`#@```']K`0`*````CFL!``\```"9:P$`"````*EK`0`0
M````LFL!``,```##:P$`"````,=K`0`7````T&L!``X```#H:P$`+P```/=K
M`0`5````)VP!``,````];`$`#0```$%L`0`:````3VP!`"````!J;`$`(P``
M`(ML`0`B````KVP!`"0```#2;`$`(@```/=L`0`D````&FT!`!\````_;0$`
M"@```%]M`0`:````:FT!``T```"%;0$`#0```)-M`0`$````H6T!``4```"F
M;0$`#````*QM`0`.````N6T!``T```#(;0$`$@```-9M`0`,````Z6T!``0`
M``#V;0$`%@```/MM`0`6````$FX!`!`````I;@$`"0```#IN`0`,````1&X!
M``T```!1;@$`'0```%]N`0`8````?6X!`"(```"6;@$`)````+EN`0`2````
MWFX!``T```#Q;@$`$````/]N`0`8````$&\!`!$````I;P$`*P```#MO`0`C
M````9V\!`#(```"+;P$`.````+YO`0`Z````]V\!`#L````R<`$`1P```&YP
M`0`2````MG`!``D```#)<`$`"@```--P`0`(````WG`!``H```#G<`$`#0``
M`/)P`0`%`````'$!``4````&<0$``P````QQ`0`-````$'$!``H````><0$`
M!0```"EQ`0`=````+W$!`"H```!-<0$`#````'AQ`0![````A7$!`!<````!
M<@$`!P```!ER`0`%````(7(!``H````G<@$`"````#)R`0`*````.W(!``@`
M``!&<@$`!````$]R`0!'````5'(!``0```"<<@$`%@```*%R`0`"````N'(!
M``H```"[<@$`!@```,9R`0`4````S7(!`!````#B<@$`$P```/-R`0`5````
M!W,!``8````=<P$`!@```"1S`0`-````*W,!``<````Y<P$`!P```$%S`0`%
M````27,!`!T```!/<P$`!P```&US`0`'````=7,!`!L```!]<P$`#P```)ES
M`0`)````J7,!``<```"S<P$`!````+MS`0`+````P',!``H```#,<P$``P``
M`-=S`0`&````VW,!``P```#B<P$`"P```.]S`0`(````^W,!`!(````$=`$`
M"@```!=T`0`4````(G0!``@````W=`$`!P```$!T`0`-````2'0!`!P```!6
M=`$`!P```'-T`0`(````>W0!``0```"$=`$`"0```(ET`0`(````DW0!``X`
M``"<=`$`#0```*MT`0`$````N70!``P```"^=`$`!@```,MT`0`$````TG0!
M`#(```#7=`$`,P````IU`0`S````/G4!`"````!R=0$`!0```)-U`0`0````
MF74!``D```"J=0$`!@```+1U`0`?````NW4!`!<```#;=0$`"0```/-U`0`&
M````_74!`!L````$=@$`"````"!V`0`(````*78!`!4````R=@$`!@```$AV
M`0`)````3W8!``<```!9=@$`"````&%V`0`)````:G8!``L```!T=@$`"```
M`(!V`0`)````B78!``4```"3=@$`2````)EV`0`W````XG8!`#L````:=P$`
M)P```%9W`0!)````?G<!`#L```#(=P$`(P````1X`0`W````*'@!`",```!@
M>`$`&@```(1X`0`8````GW@!``L```"X>`$`$````,1X`0`&````U7@!`"L`
M``#<>`$`*@````AY`0`5````,WD!`"H```!)>0$``P```'1Y`0`%````>'D!
M``H```!^>0$`"@```(EY`0`D````E'D!`"````"Y>0$`*P```-IY`0`)````
M!GH!`!@````0>@$`+P```"EZ`0`4````67H!`!<```!N>@$`!P```(9Z`0`/
M````CGH!`!````">>@$`&P```*]Z`0`-````RWH!`$4```#9>@$`:@```!][
M`0"!````BGL!`!`````,?`$`"P```!U\`0`,````*7P!`!`````V?`$`$0``
M`$=\`0`0````67P!``H```!J?`$`%````'5\`0`&````BGP!`!@```"1?`$`
M&````*I\`0`3````PWP!`!H```#7?`$`)````/)\`0!H````%WT!`!````"`
M?0$`"0```)%]`0`5````FWT!`$8```"Q?0$`"0```/A]`0`[`````GX!``4`
M```^?@$`!0```$1^`0`3````2GX!`!$```!>?@$`$0```'!^`0`8````@GX!
M`!(```";?@$`+@```*Y^`0`O````W7X!`#`````-?P$`+P```#Y_`0`S````
M;G\!`#(```"B?P$`%@```-5_`0!#````['\!`!L````P@`$`&@```$R``0`:
M````9X`!`!D```""@`$`"0```)R``0`=````IH`!`!P```#$@`$`&@```.&`
M`0`9````_(`!`!H````6@0$`'````#&!`0`;````3H$!`"X```!J@0$`#@``
M`)F!`0`'````J($!``\```"P@0$`+0```,"!`0`2````[H$!`!<````!@@$`
M&0```!F"`0`6````,X(!`!4```!*@@$`$0```&""`0`=````<H(!`"0```"0
M@@$`$@```+6"`0`;````R((!`!D```#D@@$`%P```/Z"`0`8````%H,!``0`
M```O@P$`%@```#2#`0`$````2X,!``<```!0@P$`!````%B#`0`/````78,!
M``<```!M@P$`(````'6#`0`&````EH,!``<```"=@P$`!@```*6#`0`&````
MK(,!``<```"S@P$`!````+N#`0`'````P(,!`!4```#(@P$`!@```-Z#`0`%
M````Y8,!``8```#K@P$`!P```/*#`0`%````^H,!``P`````A`$`#0````V$
M`0`*````&X0!``H````FA`$`"@```#&$`0`8````/(0!``4```!5A`$`)0``
M`%N$`0`2````@80!``T```"4A`$`$0```**$`0`0````M(0!``P```#%A`$`
M$0```-*$`0`K````Y(0!``@````0A0$`"````!F%`0`*````(H4!``H````M
MA0$`#P```#B%`0`&````2(4!``L```!/A0$`#0```%N%`0`#````:84!`!\`
M``!MA0$`"@```(V%`0`)````F(4!``\```"BA0$`#0```+*%`0`:````P(4!
M``\```#;A0$`!P```.N%`0`$````\X4!``4```#XA0$`'0```/Z%`0`&````
M'(8!``,````CA@$`$@```">&`0`0````.H8!``<```!+A@$`"````%.&`0`1
M````7(8!``<```!NA@$`!0```':&`0`-````?(8!``D```"*A@$`#````)2&
M`0`<````H88!`!H```"^A@$`%0```-F&`0`:````[X8!``D````*AP$`$@``
M`!2'`0`,````)X<!``@````TAP$`$0```#V'`0!!````3X<!``L```"1AP$`
M#````)V'`0`D````JH<!`!@```#/AP$`&0```.B'`0`3`````H@!``T````6
MB`$`#@```"2(`0`(````,X@!``H````\B`$`#0```$>(`0`:````58@!`!4`
M``!PB`$`'0```(:(`0`F````I(@!``@```#+B`$`"````-2(`0`-````W8@!
M``P```#KB`$`#````/B(`0`#````!8D!``4````)B0$`!0````^)`0`/````
M%8D!`$,````EB0$`%0```&F)`0`*````?XD!``,```"*B0$`!0```(Z)`0`4
M````E(D!`!0```"IB0$`%````+Z)`0`*````TXD!``(```#>B0$`!````.&)
M`0`@````YHD!``,````'B@$`!0````N*`0`)````$8H!``H````;B@$`!```
M`":*`0`%````*XH!`!`````QB@$`$@```$**`0`&````58H!``<```!<B@$`
M"0```&2*`0`$````;HH!``4```!SB@$`8P```'F*`0`.````W8H!`!$```#L
MB@$`(@```/Z*`0`$````(8L!``T````FBP$`$0```#2+`0`A````1HL!`#\`
M``!HBP$`$````*B+`0`(````N8L!``<```#"BP$`#P```,J+`0`)````VHL!
M``@```#DBP$`'0```.V+`0`F````"XP!`"0````RC`$`(P```%>,`0`1````
M>XP!`(0```"-C`$`A````!*-`0`%````EXT!``<```"=C0$``P```*6-`0`&
M````J8T!``H```"PC0$`$P```+N-`0`%````SXT!`$@```#5C0$`%0```!Z.
M`0`*````-(X!``L````_C@$`)P```$N.`0!,````<XX!``8```#`C@$`!@``
M`,>.`0`'````SHX!``H```#6C@$`!````.&.`0`)````YHX!`",```#PC@$`
M(@```!2/`0`%````-X\!``@````]CP$`)@```$:/`0`E````;8\!`&````"3
MCP$`$@```/2/`0`9````!Y`!`!,````AD`$`)P```#60`0`8````79`!``,`
M``!VD`$`#````'J0`0`%````AY`!``X```"-D`$`#````)R0`0`*````J9`!
M``@```"TD`$`!@```+V0`0`*````Q)`!``D```#/D`$`!0```-F0`0`*````
MWY`!``L```#JD`$``P```/:0`0`/````^I`!`!(````*D0$`$@```!V1`0`$
M````,)$!``H````UD0$`"0```$"1`0`)````2I$!`!$```!4D0$`$@```&:1
M`0`+````>9$!``H```"%D0$`"P```)"1`0`(````G)$!`"$```"ED0$`"P``
M`,>1`0`'````TY$!``@```#;D0$`#@```.21`0`'````\Y$!``\```#[D0$`
M)@````N2`0`"````,I(!``<````UD@$`!0```#V2`0`%````0Y(!``@```!)
MD@$`$@```%*2`0`2````99(!`!4```!XD@$`%0```(Z2`0`4````I)(!`!(`
M``"YD@$`%P```,R2`0`@````Y)(!`!H````%DP$``@```""3`0`$````(Y,!
M``X````HDP$`#0```#>3`0`'````19,!``H```!-DP$`'````%B3`0`-````
M=9,!`!,```"#DP$`"````)>3`0`.````H),!``<```"ODP$`$@```+>3`0`)
M````RI,!``<```#4DP$`!P```-R3`0`$````Y),!``0```#IDP$`!0```.Z3
M`0`F````]),!`$,````;E`$`.@```%^4`0`E````FI0!`"T```#`E`$`$@``
M`.Z4`0`K`````94!`#@````ME0$`#@```&:5`0`I````=94!`#$```"?E0$`
M-@```-&5`0`V````")8!`#L````_E@$`"@```'N6`0`G````AI8!`!@```"N
ME@$`)@```,>6`0`;````[I8!`!@````*EP$`&````".7`0`8````/)<!`!``
M``!5EP$`%````&:7`0`8````>Y<!`"<```"4EP$`)P```+R7`0`K````Y)<!
M`"@````0F`$`*0```#F8`0`F````8Y@!`&````"*F`$`'````.N8`0`)````
M")D!`!(````2F0$`!P```"69`0`4````+9D!`"8```!"F0$`*@```&F9`0`@
M````E)D!``D```"UF0$`0P```+^9`0!&`````YH!``<```!*F@$`&0```%*:
M`0`<````;)H!``T```")F@$`#P```)>:`0`5````IYH!``8```"]F@$`$```
M`,2:`0`/````U9H!``L```#EF@$`"@```/&:`0`3````_)H!``T````0FP$`
M#P```!Z;`0`&````+IL!`"0````UFP$`!0```%J;`0`$````8)L!``\```!E
MFP$`#````'6;`0`,````@IL!`$````"/FP$`!````-";`0`%````U9L!`!``
M``#;FP$`#P```.R;`0`$````_)L!`!0````!G`$`!````!:<`0`%````&YP!
M`#T````AG`$`&0```%^<`0`X````>9P!`%T```"RG`$`$0```!"=`0!%````
M(IT!`!\```!HG0$`#P```(B=`0`*````F)T!`!T```"CG0$`$@```,&=`0`0
M````U)T!``<```#EG0$`#@```.V=`0`)````_)T!`!8````&G@$`'````!V>
M`0`%````.IX!``X```!`G@$`$0```$^>`0`.````89X!`!T```!PG@$`$```
M`(Z>`0`4````GYX!`!$```"TG@$`(P```,:>`0`(````ZIX!``H```#SG@$`
M#P```/Z>`0`.````#I\!``8````=GP$`$@```"2?`0`8````-Y\!``L```!0
MGP$`"@```%R?`0`(````9Y\!``4```!PGP$`'@```':?`0`&````E9\!``\`
M``"<GP$`"````*R?`0`.````M9\!``8```#$GP$`#0```,N?`0`M````V9\!
M``T````'H`$`!P```!6@`0`'````':`!`!X````EH`$`"````$2@`0`0````
M3:`!``,```!>H`$`$P```&*@`0`(````=J`!``4```!_H`$`'@```(6@`0`M
M````I*`!``0```#2H`$`#0```->@`0`0````Y:`!``0```#VH`$`#P```/N@
M`0`*````"Z$!``<````6H0$`"P```!ZA`0`(````*J$!``P````SH0$`#0``
M`$"A`0`>````3J$!`#$```!MH0$`-@```)^A`0`?````UJ$!`"0```#VH0$`
M(P```!NB`0`_````/Z(!`!\```!_H@$`(````)^B`0`A````P*(!`"@```#B
MH@$`(0````NC`0`'````+:,!``@````UHP$`"0```#ZC`0`(````2*,!`!D`
M``!1HP$`&0```&NC`0`S````A:,!`"H```"YHP$`+0```.2C`0`R````$J0!
M``8```!%I`$`&P```$RD`0`'````:*0!``@```!PI`$`'P```'FD`0`1````
MF:0!``X```"KI`$`#````+JD`0`%````QZ0!`!$```#-I`$`"````-^D`0`2
M````Z*0!``P```#[I`$`&`````BE`0`Q````(:4!``H```!3I0$`!0```%ZE
M`0`%````9*4!`!H```!JI0$`!P```(6E`0`,````C:4!``8```":I0$`%@``
M`*&E`0`4````N*4!``T```#-I0$`#0```-NE`0`5````Z:4!``X```#_I0$`
M!`````ZF`0`%````$Z8!``T````9I@$`2````">F`0!C````<*8!``8```#4
MI@$`"0```-NF`0`3````Y:8!`!\```#YI@$`&0```!FG`0`-````,Z<!`!``
M``!!IP$`$0```%*G`0`/````9*<!``L```!TIP$`$@```("G`0`L````DZ<!
M``,```#`IP$`"0```,2G`0`*````SJ<!``\```#9IP$`"P```.FG`0`R````
M]:<!``,````HJ`$`&@```"RH`0`-````1Z@!`!,```!5J`$`)P```&FH`0`,
M````D:@!``X```">J`$`$@```*VH`0`'````P*@!`!````#(J`$`%0```-FH
M`0`(````[Z@!`!D```#XJ`$`$0```!*I`0`;````)*D!``<```!`J0$`&@``
M`$BI`0`F````8ZD!``H```"*J0$``P```)6I`0`2````F:D!``X```"LJ0$`
M%0```+NI`0`%````T:D!``<```#7J0$`$0```-^I`0`+````\:D!``L```#]
MJ0$`$0````FJ`0`1````&ZH!``D````MJ@$`!0```#>J`0`0````/:H!``T`
M``!.J@$`%@```%RJ`0`5````<ZH!``D```")J@$`"````).J`0`T````G*H!
M`"X```#1J@$`+@````"K`0`(````+ZL!`!$````XJP$`!@```$JK`0`7````
M4:L!`!P```!IJP$`'@```(:K`0`.````I:L!``H```"TJP$``P```+^K`0`(
M````PZL!``L```#,JP$``P```-BK`0`,````W*L!`!0```#IJP$`"P```/ZK
M`0`8````"JP!`!L````CK`$`%P```#^L`0`%````5ZP!``H```!=K`$`%```
M`&BL`0`.````?:P!``\```",K`$`!@```)RL`0`)````HZP!`!(```"MK`$`
M#P```,"L`0!.````T*P!`!T````?K0$`!0```#VM`0`%````0ZT!`!,```!)
MK0$`%````%VM`0`@````<JT!`"<```"3K0$`!0```+NM`0`/````P:T!``@`
M``#1K0$`#0```-JM`0`/````Z*T!``X```#XK0$`&P````>N`0`1````(ZX!
M`!`````UK@$`(````$:N`0`?````9ZX!``\```"'K@$`%0```)>N`0!N````
MK:X!`!P````<KP$`%0```#FO`0`F````3Z\!`!L```!VKP$`%````)*O`0`8
M````IZ\!`!8```#`KP$`'````->O`0`@````]*\!`!,````5L`$`"@```"FP
M`0`(````-+`!``<````]L`$`"P```$6P`0`%````4;`!`!<```!7L`$`#0``
M`&^P`0`?````?;`!``8```"=L`$`2@```*2P`0`Q````[[`!`$0````AL0$`
M8P```&:Q`0`>````RK$!``<```#IL0$`-````/&Q`0`H````)K(!``8```!/
ML@$`"@```%:R`0`)````8;(!`#(```!KL@$`!@```)ZR`0`3````I;(!`!H`
M``"YL@$`6P```-2R`0`K````,+,!`"4```!<LP$`#P```(*S`0`P````DK,!
M`!\```##LP$`)P```..S`0`A````"[0!`"<````MM`$`(P```%6T`0`0````
M>;0!``<```"*M`$`%P```)*T`0`5````JK0!``\```#`M`$`!@```-"T`0`O
M````U[0!``P````'M0$`!@```!2U`0`$````&[4!`!`````@M0$`"````#&U
M`0`%````.K4!``L```!`M0$`"````$RU`0`(````5;4!``,```!>M0$`#```
M`&*U`0`/````;[4!`!\```!_M0$`'0```)^U`0`/````O;4!`!8```#-M0$`
M#P```.2U`0`&````]+4!`!(```#[M0$`%@````ZV`0`-````);8!``P````S
MM@$`&0```$"V`0`G````6K8!``\```""M@$`(@```)*V`0`K````M;8!`!$`
M``#AM@$`#@```/.V`0`<`````K<!``<````?MP$`$````">W`0`4````.+<!
M``L```!-MP$`"@```%FW`0`*````9+<!``<```!OMP$`"0```'>W`0`(````
M@;<!``D```"*MP$`#@```)2W`0`.````H[<!``4```"RMP$`$````+BW`0`/
M````R;<!``P```#9MP$`#````.:W`0`-````\[<!`!H````!N`$`"P```!RX
M`0`#````*+@!`!@````LN`$`!````$6X`0`&````2K@!``@```!1N`$`!@``
M`%JX`0!4````8;@!`"@```"VN`$`,P```-^X`0`5````$[D!``4````IN0$`
M!````"^Y`0`*````-+D!``H````_N0$`!P```$JY`0`*````4KD!`!4```!=
MN0$`#````'.Y`0`*````@+D!``P```"+N0$`"````)BY`0`&````H;D!``<`
M``"HN0$`!@```+"Y`0`5````M[D!``D```#-N0$`!0```->Y`0`'````W;D!
M`"(```#EN0$`!@````BZ`0`5````#[H!`!@````EN@$`"P```#ZZ`0`'````
M2KH!`!,```!2N@$`$P```&:Z`0`&````>KH!`!,```"!N@$`"@```)6Z`0`(
M````H+H!``8```"IN@$`"````+"Z`0`0````N;H!`!@```#*N@$`"````..Z
M`0`*````[+H!``\```#WN@$`!0````>[`0`,````#;L!`!`````:NP$`"P``
M`"N[`0`#````-[L!``T````[NP$`!P```$F[`0`L````4;L!`"H```!^NP$`
M.0```*F[`0`D````X[L!`"T````(O`$`7P```#:\`0`0````EKP!`%<```"G
MO`$`-0```/^\`0!:````-;T!`%,```"0O0$`'@```.2]`0`3`````[X!`$(`
M```7O@$`(````%J^`0`C````>[X!`"$```"?O@$`%0```,&^`0`_````U[X!
M`-(!```7OP$`%````.K``0`0````_\`!`$$````0P0$`>0```%+!`0`Q````
MS,$!`#P```#^P0$`4P```#O"`0!/````C\(!`!H```#?P@$`$````/K"`0`6
M````"\,!`!D````BPP$`(P```#S#`0`A````8,,!`"(```""PP$`&@```*7#
M`0`0````P,,!`#,```#1PP$`'0````7$`0`A````(\0!`!P```!%Q`$`+@``
M`&+$`0!=````D<0!`#D```#OQ`$`6P```"G%`0!$````A<4!`"@```#*Q0$`
M,0```//%`0`R````)<8!`#X```!8Q@$`,@```)?&`0!0````RL8!`&\````;
MQP$`70```(O'`0!1````Z<<!`#0````[R`$`(````'#(`0`A````D<@!`",`
M``"SR`$`;P```-?(`0!I````1\D!`+\```"QR0$`%P```''*`0`@````B<H!
M`#P```"JR@$`/````.?*`0`[````),L!`"4```!@RP$`10```(;+`0`6````
MS,L!``8```#CRP$`Q0```.K+`0!!````L,P!`",```#RS`$`,````!;-`0`B
M````1\T!`!P```!JS0$`,@```(?-`0`-````NLT!``@```#(S0$`!0```-'-
M`0`,````U\T!``P```#DS0$`#````/'-`0`+````_LT!``8````*S@$`$@``
M`!'.`0`$````),X!`$X````IS@$`!0```'C.`0`4````?LX!``0```"3S@$`
M!P```)C.`0`%````H,X!``4```"FS@$``P```*S.`0`2````L,X!``D```##
MS@$`$@```,W.`0`1````X,X!``(```#RS@$`!0```/7.`0`'````^\X!`!,`
M```#SP$`#````!?/`0`7````),\!``8````\SP$`$0```$//`0`-````5<\!
M``,```!CSP$`,@```&?/`0`$````FL\!``8```"?SP$`!P```*;/`0`<````
MKL\!`"T```#+SP$`+@```/G/`0`O````*-`!`!,```!8T`$`'@```&S0`0`7
M````B]`!`!L```"CT`$`'@```+_0`0`9````WM`!`!H```#XT`$`'@```!/1
M`0`6````,M$!`"D```!)T0$`'P```'/1`0`G````D]$!`!<```"[T0$`&P``
M`-/1`0`=````[]$!`!@````-T@$`)````";2`0`F````2](!`"<```!RT@$`
M&0```)K2`0`8````M-(!`!P```#-T@$`(@```.K2`0`7````#=,!`!X````E
MTP$`&@```$33`0`^````7],!`"0```">TP$`)P```,/3`0`J````Z],!`"L`
M```6U`$`)0```$+4`0`;````:-0!`"````"$U`$`'0```*74`0`P````P]0!
M`!T```#TU`$`"@```!+5`0`6````'=4!`!(````TU0$`*````$?5`0`=````
M<-4!``T```".U0$`#P```)S5`0`9````K-4!`!````#&U0$`&P```-?5`0`Q
M````\]4!``@````EU@$`"@```"[6`0`B````.=8!`"8```!<U@$`)0```(/6
M`0`9````J=8!``<```##U@$`P@```,O6`0`:````CM<!`!4```"IUP$`"```
M`+_7`0`,````R-<!`!0```#5UP$`&@```.K7`0`%````!=@!`#4````+V`$`
M%````$'8`0`4````5M@!``<```!KV`$`"@```'/8`0`*````?M@!`$````")
MV`$`)0```,K8`0`2````\-@!`!4````#V0$`#P```!G9`0`R````*=D!``T`
M``!<V0$`#@```&K9`0`/````>=D!`!@```")V0$`"@```*+9`0`/````K=D!
M``4```"]V0$`#0```,/9`0`,````T=D!`$(```#>V0$`'P```"':`0`*````
M0=H!`!\```!,V@$`"````&S:`0`5````==H!``<```"+V@$`"````)/:`0`*
M````G-H!`#L```"GV@$`!0```./:`0`-````Z=H!``H```#WV@$`$`````+;
M`0`&````$]L!``H````:VP$`!P```"7;`0`2````+=L!``P```!`VP$`'0``
M`$W;`0`3````:]L!`!X```!_VP$`,@```)[;`0`%````T=L!``8```#7VP$`
M'````-[;`0`$````^]L!`"H`````W`$`$````"O<`0`%````/-P!``,```!"
MW`$`#````$;<`0`7````4]P!``L```!KW`$``P```'?<`0`*````>]P!``@`
M``"&W`$`"P```(_<`0`.````F]P!``\```"JW`$`$0```+K<`0`2````S-P!
M``H```#?W`$`%@```.K<`0`P`````=T!`!L````RW0$`&````$[=`0`*````
M9]T!`$@```!RW0$`"P```+O=`0`5````Q]T!`$@```#=W0$`&````";>`0`(
M````/]X!`!8```!(W@$`0@```%_>`0`4````HMX!``\```"WW@$`"0```,?>
M`0`$````T=X!``8```#6W@$`%@```-W>`0`:````]-X!``<````/WP$`"```
M`!??`0`(````(-\!``(````IWP$`"0```"S?`0`+````-M\!``H```!"WP$`
M!0```$W?`0`-````4]\!``\```!AWP$`#0```''?`0`:````?]\!`"8```":
MWP$`%0```,'?`0`>````U]\!`!$```#VWP$``@````C@`0`$````"^`!``\`
M```0X`$`!@```"#@`0`%````)^`!``0````MX`$`%````#+@`0!)````1^`!
M`!$```"1X`$`)0```*/@`0`O````R>`!`%@```#YX`$`$0```%+A`0!I````
M9.$!`!\```#.X0$`/````.[A`0`F````*^(!`#D```!2X@$`+@```(SB`0`G
M````N^(!`#4```#CX@$`,0```!GC`0!@````2^,!`#$```"LXP$`-0```-[C
M`0`M````%.0!`!\```!"Y`$`-@```&+D`0`:````F>0!``X```"TY`$`#```
M`,/D`0!S````T.0!``8```!$Y0$`=0```$OE`0!J````P>4!`"L````LY@$`
M$````%CF`0`6````:>8!``L```"`Y@$`&@```(SF`0`U````I^8!`!L```#=
MY@$`%0```/GF`0!7````#^<!`!<```!GYP$`"@```'_G`0`%````BN<!``8`
M``"0YP$`"````)?G`0`%````H.<!`!0```"FYP$`"@```+OG`0`0````QN<!
M`!8```#7YP$`(````.[G`0`+````#^@!`!4````;Z`$`(````#'H`0`(````
M4N@!``L```!;Z`$`!````&?H`0`*````;.@!``L```!WZ`$`%````(/H`0`C
M````F.@!``4```"\Z`$`"````,+H`0`'````R^@!`!<```#3Z`$`+````.OH
M`0`&````&.D!``8````?Z0$`%P```";I`0`5````/ND!`!H```!4Z0$`"P``
M`&_I`0`'````>^D!`!(```"#Z0$`!@```);I`0`(````G>D!`!<```"FZ0$`
M#0```+[I`0`&````S.D!``P```#3Z0$`#0```.#I`0`"````[ND!``8```#Q
MZ0$`!@```/CI`0`/````_^D!``<````/Z@$`!````!?J`0`%````'.H!`!0`
M```BZ@$``@```#?J`0`$````.NH!``P````_Z@$`"0```$SJ`0`'````5NH!
M`"(```!>Z@$``@```('J`0`2````A.H!`!@```"7Z@$`"P```+#J`0`$````
MO.H!``4```#!Z@$`#````,?J`0`I````U.H!``H```#^Z@$`#P````GK`0`G
M````&>L!`!8```!!ZP$`!0```%CK`0`-````7NL!`"<```!LZP$`#@```)3K
M`0`/````H^L!`!````"SZP$`!0```,3K`0`"````RNL!``L```#-ZP$``0``
M`%<%``!H!@``V@8``(H%``!0!```.08``+0```"3`@``H`0``,P%```V!```
M=0$````````K`````````````````````````(\!``![`P``%P0``&,"``"/
M````W0$``-@!``"K!```Q0```*\&````````RP$``&\$``#F`````````,T`
M`````````````-8$````````IP4```````!G!@```````$0'``!-!@``^`(`
M``````"H!0``"`$```````#9`0``0````(X%````````.`<``.,$```"!```
M^00``%@!```D!@``D@8`````````````'P(``$4$``"N`P``.@(``,`#```V
M!P``]@8```H`````````X00``$4#```B`P``"````$@%```G!P``.0(``+`&
M``!X!@``<P0``&\&``!*`@``_`(``%8```!W````E`,``'`"``#J!@``````
M`-4&```!`P``?08```````!8````X`8```````"&!0```````/4"```<`P``
MXP8```D``````````````&$```!K!0``````````````````108```````#!
M``````````D&```D`@``+P0``$H#``#^`0```````/0$````````(`0``+$%
M```=!P``OP$``!D"````````L`$``````````````````#$&``":`P``8@8`
M````````````!P4``,P&````````XP4``"D&`````````````!$`````````
M`````+0#```]!0``C@(`````````````/P$``(D!``#\!```:P```!($``#9
M!```'@0```<&``!X`P``/P(``(@$```Y!```?@```+,"``!.!0``P```````
M``!Z`0```````&0%``!K`P``S`0``"4!``!7````FP(``,D$``#!!0``HP8`
M`(4"```F`@``M`$``/0&``#I!```A00```````"0`@``J@,``)P!``#<`P``
M'`4````````[`@``?04``#\%``!@!@``A````%,#``#&!```/@4````````4
M!````````.X!````````>0$``"\#``!=`````````($#`````````````%H$
M``"#`P``!`````````!<!@``*@(``,(`````````D`0```````!M````@@$`
M`-D%```F````*@<``!0'```B!@``-P8``%D&````````/@<``/L"```U````
M`````-H%``!Y!0```````)@%```V!0``H08```````!N!0``:0(``)8&```T
M`P```````%0$```R!0``;`$``"4`````````C04``$`&```5!0``D0,``,`&
M``#)!0``80(``*`%``````````````@&```-!```%0<``-X$````````%P$`
M````````````]````/X%``"8`P``W0```%P```"5````YP4``&,&```5!@``
M9`$``!H````/!P````````````!I`P``3P,`````````````BP8`````````
M````O`8``#T&```P`P``FP8``!8%```4`@`````````````)`P``Z@0`````
M```Z`0``D@,``&L$``#^`P````````````"+!```$@```&T!``#I`P``EP,`
M``0#``"Y`@````````H$``!6`@``[P$``"L&``#D`@``.P```+8%``!>!@``
M```````````#````B@(`````````````00,``"`#``!_`P`````````````P
M!P``C00``/\#``#/````<00``$\&``#@`0```````#@````U!0``6P````4#
M```?!0``N@8``,D````4!0``I`0``%T#``#I`@``XP```%````!1!@``Q`0`
M`$0"````````&@(``$0#```$!P``'P,``)0%``!B````F0$```````#4!```
M!`$``#4&``!)`P```````(`#``!,`````````.<!```3!@``(`8```````"Z
M`P````````````!\`P``R0(``+X`````````@0(``,8!``"F`0``&0,``*X`
M``!(````C`(``*,"```.`P``.@4```````!%!P```````!`$```_`P``````
M`+H%``#K`````````,X"``!#`P``B````#(````O!@``=04``,T$``!%!0``
M``````````#@`P``!@8```H%``"$`P``.`0``.L#``````````````P```#!
M`P```````+<#```````````````````)`0``>08```````!$!@``>P0``-4%
M````````[P4``!\'``!D!@``1`0``/P#``#A`P``[`0``$H%```^!```!@<`
M`,X!````````+P4``,@#```4`P``OP4``-L&``"[!0```````"P"``#B`@``
ML08``#L'````````J0(```@"``!#`@``7`$``+P!``!V`P``"0(```````!O
M!0``M`8```````"O!0``````````````````RP8``,H#```3!0```````)D"
M````````C`,``'(#``#-`0``A@$``',!``"^`0```````(,"````````````
M``D%``"7!@``,@,``/4````_!@``JP,``'X&``#A!@```````/L#``"U!```
M`````+<&`````````````*\#``"%!@``Z`0``)P$``!``@```````.P&````
M````K08``(`$```/!````````&\!``"V`0``W08``````````````````!4#
M````````$`<```4````2`0``1@8``#8#``#N!@``J08````````3`0``<P4`
M`"\'``!W!@``$P<``(X&``#W!0``/`4``%8%``!]`@``=`$``$L$``"#`0``
M,P8``!T%``!I````'P8``,H&````````J@$`````````````#P,```````"D
M`@``````````````````&P,`````````````[P(``!H%```4`0```````&P&
M````````$P0``-\$`````````````'H"```+`P``GP4```````!_!0``````
M`-,!````````404````````"`P``3`8```P$`````````````+8"````````
MT@4``$0```#Q`0``90(````````:!@``&`(``%@&````````(0$``,<&```W
M!0```````#\$`````````````&$&``"D````E04```4!``"A!0``FP,``(X!
M``!Q!@``)08``#$```"!!0``@`(``%(#``!_!@``8@,``%4&````````````
M`)T$```W!P```````&@```"S!```M@0``"`'````````'0$```````"G`P``
M`````-$"``"S!0``,`$````````7````IP$``!8$``#2!```+@<``/X&````
M````0P<``"L"``#(!@``A`(``.P`````````I@(``.@`````````0P0```L"
M````````Q04``!<%``#;!````````,X#``#B!@````````P"````````9@(`
M``````#&!@``2`0``-H$``!E!```70$``/D```!J`0``W@$`````````````
MN04```````!/!```J@````````!7!@````````````"=`@```````#X&```L
M`````````*D````T!```L@(``#,#```@`@````````````"K`@```````/,%
M``!J`````````,$&``##!@```````)X!`````````````"8#``#E!0``R0,`
M`/8$``#$!@``<@0````````:`P``Q@(```4%``""````TP0``#`$````````
M`````,<````\`0``+@4``#@"```U!````````"@```#:`0``V0````````"'
M!````````-,%``">!```D`,``)@&`````````````$T#``!N!@```````+0"
M``!<`P``Z0````````"E!@``PP(``-`#````````C@0``!T&```6`@``,0$`
M`"(%``"R````3@0``!8```",````G`````````"K!@`````````````8!@``
M@@4```````"O`0```````)8$``"@`0```````/H#``"G`@``T`8``!(&``!+
M````PP``````````````T0$``'D$``!(`0``T0```#@!``"L!```GP8``((&
M```A`P``````````````````@@,``%8$``")!0``M0```.P"``"Y!```BP4`
M`%L#``"&!```M@8``*(#``#C`0``X0$```````!1!```/@```)$%````````
MGP0````````.!0```````/P%``!'!0``Q````(@&```\`@```````'L```!C
M!0``4@```$D!``!W!0`````````$```:`0``;````%4$````````)04`````
M``#]!```]`4```````"?````=P0``-,#`````````````!D&```6!@``[P8`
M`$("``#`!```Y`$``/D!````````Z@,``"\`````````T@$``!<&``!^`@``
M`````$$!```[`0```````%L$``#=`@``L`,``)X&``#[`0``M0,``,X````?
M````3@$``(,%````````I`,```````!3`@```````*T$``"D!@```````!P$
M```W!```6`,``$T$``!`!0``5`,``(0$``#Z!0``<@$``%<"``!\`0``'@,`
M`+P```#M`@``^04```````#%!````````,(#``#M`P``YP0``-<%```H!0``
MN`$``"P&``!Q!0``-````$8%```7`P```````'\!```B!```+`4`````````
M````CP8``-D"``!P!0``Y0(``"D#``#T`P```````#8```"B!@``;@(``%X"
M``!A`P``Y@4``+<!```C`0````````````#!!```K`$``(L!``!=!0``````
M`-0````=`P``YP8``&L&``#4`@```````.@!````!P``6@$``%D````K!P``
M````````````````M0(`````````````IP0``+D#``#(!0``!@0```(%``">
M``````````````#L`0``C0,```````#J`@````````4&``"B````&0$`````
M``!8!```504```````#Q!````````$(````#`P``8`4````````J!@``#@0`
M`+(%``!I!@``9@0````````N`P``U@8```````!,`@```````#T$``!Q`@``
MBP```&4```!$`0```````#T"``!0`P``0@,``#,```#5`````````%,!````
M````!@,``+T```#,`@``?P0``!$!``"B`0``*0(`````````````FP```"L#
M``!]!```;@0```````"*`0``C@,``"$````X`P``3@,``'8!```=`@``````
M`"8%````````VP(``````````````````$L"````````HP$``!$'``!Q````
MD@```.4$``!<!0```````'H$``#D!````````#@%```\!```C0````````"P
M````@P```$4"``#U`0``HP,``!D'``"L!@``\`(```X'``#D!0``40```#P`
M```9````30$````````1`P```````````````````````!8#``#B!0``>`(`
M`*D$````````1P8```@%``#P`P```````&<#``#<````UP8```P!``"Q`@``
MB08``)D$``#@!0```````/\"``!B!```)P8```````!>`0``*00``#,$```J
M`P```````,,%``#_!@``````````````````'@4``!("```L!P``4@4`````
M``#M!@``5@,`````````````(04``&L!``"I!0````````````"H````````
M```````0!0``,P<``&D%``!-!0``M`4``+H```"]`0``H0$```````"#!@``
MV`4````````-````@00``$@"```C!@``3@8``!X!```X!@```````(($``#"
M`0``$@4```````#E`````````)L%````````:@,``'@!``"-`@``C`0``#<"
M````````[0$``+@%```B!P```````)0"```:!P``2@0``/``````````LP8`
M`.T```"L````3P$``+X%``#F`P``/@,``*8#````````4P```/(```#A`@``
M=`4``"8$``!/`@``!P(`````````````%P<```$&``!9`@``6P(``/$#``"1
M`@```````&8%``#_`0``(````'0"``!D`@``.P0``&X```````````4``"(!
M```'`0````````````!>!0``N@0```````!U!@```````-0!```G!0``.@,`
M`!X"```L!```NP(````````]`0````````````!%````;@$`````````````
M`````.8!``"F!```,@<```````!+!0``_````$8"````````%0```)P"```;
M!0``!0(``%8!````````O08`````````````&@0```````!=`@``%P(``(<&
M``#<`@`````````````#!```"@,`````````````6P8``%("```D`P``=@8`
M`(0%``!5``````````````#3````#@8```````!1`0``:@0``+L$``#N!```
M``````````!V!```5@8``%D$````````_@0``-X```#3!@``00(``,D&``#Y
M`@````````('``#Y!@``"0<````````C`````````!4!``!D````'````(H`
M``"(`0```````#H&``"&`@``0P```'P&``"S`P``[P```#4#``#D````.04`
M``$"``"^`P```````&0#``"&`P``T`(``,(%`````````````!D%```>!@``
M[@(``-X#``#3`@``1@$``",#````````3P````````!4!@``.P,``(8`````
M````N````+X$``#H`P``I0(```X"``#L!0``W`$``$@&````````-@$``"X$
M``````````````````"I`P``EP```/8%````````'P0``#L&``#+!0```00`
M``,%``"F`````````,(&``!,!0``8P0``(P%``#6`0``[`,``-(```"*`P``
M,`8``,L#``"J!@``0@<`````````````\P0``+D&```/!0```````#4'``!Z
M`````````%T&````````1P```,H!```'!```^`8```````#D`P``.@<``,@!
M``#9!@```````&P$``"X`@``2`<`````````````YP(`````````````````
M`"@"``#'!0``?@$````````%!P``,`4``#X"`````````````%<#````````
MN`0``.X#```R`@``,@0``(\$````````$P(`````````````#@$``,$"``"@
M`````````!T$````````Z08````````%!```]P0``!$%````````F`0``,4&
M``"S`0``SP(``-8```#/!@``&00``&(%```D!```)0<``!(#````````_P4`
M``````"'````CP(```````#;`P``T04```T#``"U!0``Q`4``%P"``#S`P``
M;0(``(<!``"K!0``#P8`````````````V`(``*P#``#V````'`8``+@&```!
M!0``GP$```````!@`0```````%`!``"6!0````````````!1`P``^`,``#<`
M``"7`0``-0(``*$#``!5`0```````'(%```;!``````````````V!@``OP0`
M`"H$``#I`0``K0(``/`%``"+`@``D0```&`"``">`@``UP$``!@'```A!P``
M2P$``.\$```\!@```````'`&``!.````G0$`````````````P`4```````#0
M`0```````'H%```\!P``7P,```(&```,!P``,0<``"4#````````+@8``*P"
M````````S@0``+T"``#.!@``.0$```````#4!0``1P0```````!'`P``HP4`
M`)8```#>!@``U`,``+T#``"?`P``!P```,4!````````,@8``"T%```A`@``
M!@````````!;`0``N`,``-T#```.````K`4``&D$```"`0``````````````
M````200``(H$``!^!```H`(`````````````@`$``#D'````````2@8`````
M``!$!0``S08``+<$``#@`````````$$$```H!@``"P0``%P$``#1!@``B0,`
M`'$#````````F@```,H"``!H!0```````!````#5`0``5P0``'8%``#:`@``
MB0(``%0```````````````P&``"\`@```````-4"``#Z!````````.D%```J
M````4@$```````!O`P``L@$``"4$``!L`P``H00``",'``"$`0```````%<!
M``#,````+P$``!('```&`@``9P0``*8%```"````I0,``/,&``!Q`0``[00`
M``````"4``````````L&````````+0$``',#``!L!0``P`(```````!3!@``
MS@4``)`%```V`@``(P4```````!)`````````'L!``#'!```W@(```````!F
M`P``Y@0```````!M`P``D`8``%\"``!J`@``&````.L%```1!```````````
M``"M`P``SP$``"@'```Q`P```````+8```!0`@``)@<``-L!````````````
M`#X!```T!P``#04``"<$``##`0``PP,```P%``"R!```4P0``),#````````
M4@8``.4&``#/`P``*0<```````````````````````!C````Z@$``!L"``#W
M`@``+`$``)<$``!#!0````````````#8`P````````````!E`P``T`4`````
M````````G@,``(4%``!?!0``6`(``&T$`````````````"0!``#Q!@``LP``
M`/(&``!C`P``=0```%0"``"J!```F`$```````"0`````````.@"``"B`@``
MH0(``(P&```<`0``>@,``*4%`````````````)H"```(!P``0`<``#H```!N
M`P``OP```!@%``#Y`P````````````"!!@``\@,```````"4!````````%X`
M``">!0```````/H&````````0@8```,!````````H@4``"X!````````````
M`)D#``#\`0``.P4``'T````W`0``*`,``.L!```Y````D00``!@!````````
MN@$``*8&````````Y@8``-````"0`0``&P$````````G````9`0``*T%```+
M!P``S`,```````````````````````"!`0```````"<#```Z!```A0``````
M````````J0$``/$%``"-`0``Z@4```````!.`@``1P(``+`%``#<!@``````
M`%4"`````````````"L%``":!@``@@(``%0%``#7!```=@(``/T```"%`P``
MCP4``)T#``#+!```SP0````````Q`@``WP````````!#`0``S04```````!%
M`0````````````!;!0``G`8`````````````/`,``"H%``".`````````%\!
M````````L00````````1!@```````#,!````````4P4``)4"````````(P0`
M`-L`````````&`0```0"```/``````(```,"``!F`0``Z@```/T#```F!@``
M`````#,"``#K`@``````````````````8`````8!````````U@,``)@"``#Z
M`@```````-\%``#M!0````````````!T````)P(``"H!```_````M`0`````
M``!U`@``H`,``&<%``!L`@``6@,``-4$``!!!0``_08``.X%``#C`@``E`$`
M``````!O````E@$`````````````EP4````````U`0``L`(``($```#W!@``
MX`0```````!W`P``8`,``/("````````J`(``(@"````````\@0``'(&``#1
M!``````````````T`0``F@0``(4!``!H`0``U@4``/$"``!>`P``(00``)@`
M``#W`P``RP(``,("``"V`P``WP$``-P%``#-`P``908````````D!0``+0<`
M`#$$``"-!@```````$$&``````````````````!@!```O@8``.`"````````
MX0````````#C`P````````````#8`````````"$&``"[````604```````##
M!```E@,```````!!!P``1P<```````#'`@``_`8``.4#``"R`P``^P0``,$!
M``!&````K@(`````````````(@(`````````````L@8``*`&``!F````#08`
M`'D"``#T`0``:`(``&H%``!+!@``\P```.<#``!1`@```````"`%``"3````
M&P```"X"``"'!0``*P$``(,$```M````R0$```````!4`0``)``````````L
M`P``-`4````````'`P``O04``%H```!'`0``^P8````````H!```>`4``-<"
M``"[`P``_P0``*\"```(`P``]@(``+`$``#>!0``````````````````E@(`
M`),!````````700```````!U`P``@````````````````0<`````````````
M`````'L&```#!P``?`4``*0!`````````````.\#``!K`@``;P(``),&``#8
M!```/0<```L%``#S`0``,@$```````"?`@``CP,``+4&`````````````"(`
M```O`@``Z`8``*4$``#2!@``W00``!L'``!S!@``E00``#T```#:````NP8`
M``T"``"C!````````.0&```-!P``IP```$,&````````/P<``!$"````````
M?P```),%``#(!```J@4```````!:!@``"P```,8#``#S`@``U@(``!X```#T
M`@```````/@%``!9`P``)@$``,8%````````]@,``+\&````````P@0``)$&
M``!&!```L0```'`#``#*!```,`(```````!^`P``6@(````````0`P``````
M`,@`````````$`8``)D```";`0```P8``+P%``#X````6@4``)4&``#R`0``
MV`8```````!-``````8``)(!````````800````````S!0```````#<#``!`
M`P``9P(``%($``#W`0``^`$``/`$``#1`P``#P(``"D!`````````````,H`
M``!&!P``QP$``'0&````````H0````H"``!)!0``Q`(``.L$``#A!0``"P$`
M`*($````````<@```%\$````````_0$``*L`````````>`0```````!F!@``
MKP```/(%``#[````2`,``)T`````````,`````````#*!0``F@$``'P```!P
M!```(`$```H&````````E`8`````````````X@,``/T"```,`P```````.(!
M`````````````(P!``"]!```*P0``&D!``!W`@```````)T&```]`P``>@8`
M`%X$```'!P``X@```"D```#^`@``EP(``*@!``!]`P```````.($``#$`0``
M?`(``/$````````````````````0`@```````'\"``#X!```'@<``.<```"9
M!@``=`,``#0&````````.0,``(<#``!A`0```````*H"``#K!@``MP4``"@!
M``````````````````````````````````````````````````"N!```0@0`
M`'D```!,!```D@0``)D%``#]!0``3P4``&("``"N!@``D0$``$P!``!8!0``
M`````/8!``"$!@``T`0``&$%```4!@```````*X%``";!`````````````!W
M`0``B00````#``!C`0```````","``"5`0``)0(``&T&``"=!0``````````
M``#Z`0``>````-0&``````````````````!G`0``:`0``)(%``#%`@``````
M`.4!``"E`````````,@"`````0``)P$``(L#``"`!0```````+D!``!P`0``
M`````)4#```$!0```````(8&```6!P``=00```0$```M!```K@$``+L!``#,
M`0```````(@%``#-`@``>P(````````N````Y@(``&4!`````````0$``!4$
M``"'`@````````````!?`````````!,#``"W`@``G`,````````$!@``````
M`+H"``"Q`P``]00``'L%``!`!```#P$```````#Z````P`$```````"Q`0``
MT@,```8%``#P!@``F@4``*<&``#$`P``<`````````#9`P``0`$``/X````)
M!```0@$``*@#``"H!````````'("``!9`0``?@4``/L%```Q!0``MP```/4%
M``!)`@``<P```!P"`````````````-<#````````M0$``$D&```;!@``````
M`+P#``"_`P``%@$``````````````````'8```!0!@``WP,``!@#``#'`P``
M"`0``+\"``#P`0``*04``%4#``#H!0``WP(``!`!``#N`````````+P$``#<
M!```1@,``"T#``!-`@````````````!\!```B`,``$H!````````V@,``"T"
M````````)`<``*0%````````Q0,``$L#``"3!```T@(``)P%````````B@8`
M``````#7````N0````````!!````JP$```````#?!@``K0```!,```!H`P``
MK0$```````!S`@``'0```&<`````````'P$``-T%``#_`````````!0````5
M`@``?0$``$H````<!P``3`,``,L````T`@```````%`%``#W````"@<``'D#
M````````]08``$(%``")`````````*@&`````````````*4!``#/!0``KP0`
M````````````D@(```H!`````````@(``%\&````````904```T!``!M!0``
MQ@````````"`!@```````-4#``!J!@`````````````M!@``HP```&(!``!T
M!```VP4```````#U`P``O@(````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME
M>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE
M<W1E<F1A>2D`(&%N9``@870@`"!O<@`E9"`E<R!A;F0@)7,`)60M9&%Y(&9O
M<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``
M)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E
M>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`
M)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O
M:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S
M.B`E<P`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S
M`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R
M-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`
M05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!
M8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A
M<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%C=&EO;B!F;W(@
M8FQA8VML:7-T960@861D<F5S<V5S.@!!8W1I=F%T92!38W)I<'0`061D`$%D
M9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`
M061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S
M97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T
M:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S
M<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D:71I;VYA;"!3971T:6YG<P!!9&1R
M97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS
M(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T
M86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL
M`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI
M<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;"!O9B!T:&4@9F]L;&]W:6YG`$%L
M;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,
M;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5
M<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M
M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I
M;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`06YT87)C=&EC
M80!!;G1I9W5A(&%N9"!"87)B=61A`$%N>2!O9B!T:&4@9F]L;&]W:6YG`$%P
M<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A
M9'DN`$%P<&QY($9I;'1E<G,`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O
M=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U
M-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/P!!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`
M07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC
M(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!
M=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@
M;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E
M<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W
M:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I
M<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U
M:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@
M4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&]M871I8V%L
M;'D@=7!D871E('1H92!S8W)I<'0@869T97(@96%C:"!C:&%N9V4_`$%V86EL
M86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U
M;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A
M9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F-C
M`$)E9VEN<R!W:71H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R
M;75D80!":'5T86X`0FER=&AD87D`0FQA8VML:7-T`$)L86-K;&ES="!%9&ET
M`$)L86-K;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I
M;'1E<FEN9R!D<FEV97(N`$)L86-K;&ES=&5D($%D9')E<W,`0FQA8VML:7-T
M960@061D<F5S<V5S`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N
M;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]D>0!";VQD
M`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!"
M;W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!"
M;W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE
M=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E
M;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E
M<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87-E(%-E;G-I=&EV90!#871E
M9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V,`0V5L;"!0:&]N
M90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I
M97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ
M-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I
M9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A
M;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V5S('-A=F5D+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P
M87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D
M(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R
M(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC
M:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O
M=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA
M<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`
M0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I
M=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M
M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VYS
M`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)E("5S`$-O;F9I
M<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL
M960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+@!#;VYT86EN<P!#;VYT:6YU90!#;V]K($ES;&%N
M9',`0V]O:VEE`$-O<'D`0V]P>2`E<P!#;W!Y(&]F("5S`$-O<'D@<V5L96-T
M:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K
M(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@
M9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#
M;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T
M:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@
M)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@
M66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E
M(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!N97<@9F]L9&5R`$-R
M96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C
M87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@
M55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U
M<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/
M23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN
M:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1)4T%"3$5$`$1)4T%"
M3$5$.B``1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV
M960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E86-T:79A
M=&4@4V-R:7!T`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!)
M;F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92`E<P!$96QE=&4@0V]N9&ET:6]N
M`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G92!C
M;VUP;&5T96QY`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y
M`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT
M(')O=P!$96QE=&5D`$1E;&EV97(@:6YT;R!M>2!)3D)/6`!$96QI=F5R(&EN
M=&\@;7D@24Y"3U@@86YD(&-O<'D@=&\`1&5L:79E<B!I;G1O(&UY($E.0D]8
M(&%N9"!R961I<F5C="!T;P!$96QI=F5R('1O(&9O;&1E<@!$96QI=F5R>2!T
M:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`
M1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P
M;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@
M<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES86)L92`E<P!$:7-A8FQE9`!$:7-P
M;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E
M=&%I;&5D(&YO=&EF:6-A=&EO;B!W:&5N(&5A8V@@9FEL=&5R(&ES(&%P<&QI
M960_`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(%]N;W0@<V5N9"!R
M97-P;VYS97,@=&\@8G5L:R!O<B!L:7-T(&UE<W-A9V5S`$1O(&YO="!D96QE
M=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&\@
M=&AI<SH`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;V5S;B=T(&)E9VEN('=I
M=&@`1&]E<VXG="!C;VYT86EN`$1O97-N)W0@96YD('=I=&@`1&]E<VXG="!E
M>&ES=`!$;V5S;B=T(&UA=&-H("AW:71H('!L86-E:&]L9&5R<RD`1&]M:6YI
M8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET
M`$5D:70@)7,`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO
M;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D
M:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A
M=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%
M;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@)7,`16YA
M8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@
M:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YA
M8FQE9`!%;F0@>65A<@!%;F1S('=I=&@`16YL87)G92!%9&ET;W(`16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!5
M4DP@:&5R90!%<75A;"!T;P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17-T;VYI80!%=&AI;W!I
M80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$5X96-U=&4`17AI<W1I;F<@4G5L97,`17AI<W1S`$5X<&%N9`!%>'!A
M;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`
M1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T
M;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@
M;6]V92!T;R`B)7,B+@!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S
M*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`1F5E
M;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO
M=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I
M;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL
M92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N`$9I;'1E<B!!;&P@365S<V%G97,`1FEL=&5R($]N;'D@4V5E;B!-
M97-S86=E<P!&:6QT97(@3VYL>2!5;G-E96X@365S<V%G97,`1FEL=&5R($]P
M=&EO;G,`1FEL=&5R(%)U;&4`1FEL=&5R(%)U;&5S`$9I;'1E<B!38W)I<'0@
M1&ES<&QA>0!&:6QT97(@7U)U;&5S`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S
M<V%G92AS*2!H879E(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@(B5S(BX`
M1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!D96QE
M=&5D+@!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N
M(&UO=F5D('1O('1H92!F;VQD97(@(B5S(BX`1FEL=&5R(&%C=&EV:71Y.B`E
M<R!M97-S86=E*',I('1H870@;6%T8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@
M9&5L971E9"X`1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92`B)7,B(&9R
M;VT@(B5S(B!H87,@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&
M:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E("(E<R(@9G)O;2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@
M(B5S(B!F<F]M("(E<R(@:&%S(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B`B
M)7,B+@!&:6QT97(@;F]T(&9O=6YD+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@
M2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&
M;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!A
M;B!I;F-O;6EN9R!M97-S86=E('1H870@;6%T8VAE<SH`1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P
M87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`
M1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9`!&;W)W87)D(&ES(&YO="!S=7!P
M;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`1F]R=V%R
M9',`1F]R=V%R9',@161I=`!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T
M<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$
M97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N
M>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE
M(%-E87)C:`!'<F%Y<V-A;&4`1W)E871E<B!T:&%N`$=R96%T97(@=&AA;B!O
M<B!E<75A;"!T;P!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N
M9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M
M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E
M<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S
M86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@
M;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L
M(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M
M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H
M8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(
M=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W
M($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS
M('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@
M17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T
M=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@
M4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL
M97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!)
M;7!O<G0L(%-T97`@)60`26UP;W)T86YT`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD
M:6$`26YD:79I9'5A;"!5<V5R<P!);F1I=FED=6%L(')U;&5S(&%R92!N;W0@
M<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`$EN
M9&]N97-I80!);F5X:7-T86YT(&UA:6QB;W@@<W!E8VEF:65D(&9O<B!M97-S
M86=E(&1E;&EV97)Y+@!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN
M($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,
M:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`
M26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E
M<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R
M86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F
M;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y
M($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!)
M;G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`
M26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI
M9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S
M+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R
M;W1O8V]L+@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A
M9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES`$ES;&4@;V8@
M36%N`$ES;B=T`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A
M;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/
M+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S
M=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y
M(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W
M8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`
M2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`
M2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N
M9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(
M86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T
M=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A
M;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,97-S
M('1H86X`3&5S<R!T:&%N(&]R(&5Q=6%L('1O`$QI8F5R:6$`3&EB>6%N($%R
M86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG
M:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H
M="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3
M;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN
M=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T
M($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE
M;'``3&ES="U)1`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M
M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A
M;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@
M;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA
M:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV
M97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E
M<W0@;6%P`$UA<E]K(&UE<W-A9V4@87,@9&5L971E9`!-87)C:`!-87)G:6X`
M36%R:R!M97-S86=E(&%S.@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H97,@*'=I=&@@
M<&QA8V5H;VQD97)S*0!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R
M:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA
M<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F
M(&)L86-K;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S
M<V5S.B`E<RP@36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A
M9&0@;F5W(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N`$UA>&EM=6T@;G5M8F5R
M(&]F('=H:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D
M<F5S<V5S.B`E<RP@36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO
M="!A9&0@;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N`$UA>0!-87EO='1E
M`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S
M86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG
M;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S
M86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N`$UE=&AO9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI
M<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+@!-:7-S:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G92!T;P!-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN
M9R!M97-S86=E($E$+@!-:7-S:6YG(')E87-O;B!F;W(@<F5J96-T`$UI<W-I
M;F<@<F5A<V]N(&EN('9A8V%T:6]N+@!-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-
M86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S
M`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A
M;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C
M;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V
M90!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!2=6QE($1O
M=VX`36]V92!2=6QE(%5P`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z
M86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@
M<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO
M=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3E]U;6)E<B!O9B!D87ES
M(&)E='=E96X@=F%C871I;VX@<F5P;&EE<SH`3F%M90!.86UI8FEA`$YA=7)U
M`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C
M87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C
M87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A
M<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE
M='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G
M;W)Y`$YE=R!-;V]N`$YE=R!2=6QE`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI
M`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O
M=7!S`$YE>'0`3F5X="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA
M`$YI9VAT`$YI=64`3F\`3F\@)R5S)R!E;&5M96YT(&9O=6YD(&EN(&)A8VME
M;F0@8V]N9FEG=7)A=&EO;BX`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@
M9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%C:V5N9"!C;VYF
M:6=U<F5D(&9O<B!T:&ES(&AO<W0`3F\@8F%C:V5N9',@8V]N9FEG=7)E9"!I
M;B!B86-K96YD<RYP:'``3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X
M:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA
M;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG
M92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO
M;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T
M+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.
M;R!F:6QT97)S+B!#;&EC:R`G)7,G('1O(&-R96%T92!A(&YE=R!F:6QT97(N
M`$YO(&AE861E<G,@<W!E8VEF:65D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A
M=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E
M8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R
M='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!R=6QE<P!.;R!S8W)I<'0@9V5N97)A=&5D+@!.;R!S:61E<P!.;R!S
M=')I;F=S('-P96-I9FEE9`!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S
M96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U
M<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.
M;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA
M<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T
M(&$@9&ER96-T;W)Y`$YO="!E<75A;"!T;P!.;W0@:6UP;&5M96YT960N`$YO
M="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R
M<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E
M;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P
M;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO
M;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+@!/<'1I;VYS(&9O<B`E<P!/<F1E
M<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G
M86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T
M:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!0
M1U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I
M;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%0M4W1O
M<FUS`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I
M;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@
M:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N
M=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D
M.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T
M92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE
M`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO
M;@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A
M:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE
M87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O
M<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@
M`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV
M871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`
M4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H
M)60@8FET*0!27V5A<V]N`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R
M;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T
M;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C96EV960`4F5D
M:7)E8W0@=&\`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X
M`%)E9W5L87(@97AP<F5S<VEO;@!296IE8W0@=VET:"!R96%S;VX`4F5L871I
M;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E
M;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO
M9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z
M("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@`%)E<75I<F5D($9I96QD`%)E<V5N="!4;P!297-E;G0M9G)O
M;0!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E
M<W5L=',`4F5T=7)N('1O($9I;'1E<G,@3&ES=`!2971U<FX@=&\@3W!T:6]N
M<P!2971U<FX@=&\@4G5L97,@3&ES=`!2975N:6]N`%)E=F5R="!#;VYF:6=U
M<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT
M`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN
M`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2
M:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE
M`%)U;&4@0V]P:65D`%)U;&4@1&5L971E9`!2=6QE($1I<V%B;&5D`%)U;&4@
M16YA8FQE9`!2=6QE($YA;64`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`
M4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L
M;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT
M($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N
M="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A
M`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0
M<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N
M<P!3879E(%-E='1I;F=S`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V-I96YC90!38W)I
M<'0`4V-R:7!T(%5P9&%T:6YG`%-C<FEP="!N;W0@=7!D871E9"X`4V-R:7!T
M('-U8V-E<W-F=6QL>2!A8W1I=F%T960N`%-C<FEP="!S=6-C97-S9G5L;'D@
M9&5A8W1I=F%T960N`%-E87)C:`!396%R8V@@16YG:6YE<P!3965N`%-E;&5C
M="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A
M(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R
M=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP
M;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T87)G970@9F]L9&5R
M`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO
M=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`
M4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.@!396QF+41E9FEN960@2&5A9&5R`%-E;F0@
M4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N9&5R`%-E;F5G86P`4V5N<V]R
M.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M
M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='1I;F=S
M('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W($%C=&EV92!38W)I<'0`4VAO=R!#=7)R96YT
M(%-C<FEP=`!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3
M:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3
M:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3
M;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO
M;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E
M;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R
M;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T
M:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@
M86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD
M('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,
M86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0
M<F]V:6YC90!3=&%T=7,`4W1O<"!C:&5C:VEN9R!I9B!T:&ES(')U;&4@;6%T
M8VAE<S\`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR
M;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<P!3='EL92!;0U-370!3=0!3=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E
M.@!3=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`
M4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T
M`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R
M=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A
M>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R
M;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P
M97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK
M:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A
M<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M
M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO
M;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H
M5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@
M<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%
M>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!D<FEV97(@<V%I
M9#H@`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I
M='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W
M:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M
M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S
M92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@
M;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A
M<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y
M(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N
M($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O
M('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4
M:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N
M('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O
M;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y
M960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL
M>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E
M<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@
M;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E
M>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S
M:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B
M;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E
M(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H
M879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S
M<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!A8W1I=F%T:6YG('1H92!S8W)I<'0N`%1H97)E('=A<R!A;B!E<G)O<B!D
M96%C=&EV871I;F<@=&AE('-C<FEP="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C
M:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N
M=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L
M9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O
M<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME
M=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T
M:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D
M87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4
M;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED
M860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y
M`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N
M(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E
M<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN
M9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA
M;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5
M;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93
M(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A
M=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@
M(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L
M:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5
M;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`
M57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA
M;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M
M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S
M97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I
M=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H
M92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E
M>&ES="X`5F%C871I;VX`5F%C871I;VX@161I=`!686-A=&EO;B!-97-S86=E
M`%9A8V%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL
M=&5R:6YG(&1R:79E<BX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z
M(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`
M5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU
M96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O
M;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!6
M97)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S
M`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL
M:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).
M`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!7
M86QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@
M4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7
M97-T97)N(%-A:&%R80!7:%]I=&5L:7-T(&%D9')E<W-E<SH`5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B
M;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:&ET96QI<W0`5VAI=&5L
M:7-T($5D:70`5VAI=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U
M<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`5VAI=&5L:7-T960@061D<F5S<V5S
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%@M4')I;W)I
M='D`6"U2968`6"U3<&%M+4QE=F5L`%@M4W!A;2U38V]R90!8+5-P86TM4W1A
M='5S`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@
M2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P
M.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`
M65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G
M<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H
M96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED
M(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O
M;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L
M9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O
M;F4@96UA:6P@861D<F5S<R!F;W(@=VAI8V@@=&AE('9A8V%T:6]N(&UE<W-A
M9V5S('-H;W5L9"!B92!A8W1I=F%T960N`%EO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O
M('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO
M=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@
M>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`
M66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R
M(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I
M80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E
M>'1=`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E
M9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@
M)7,@;V8@)7-=`%]!9&1R97-S*&5S*2!T;R!F;W)W87)D('1O.@!?061D<F5S
M<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SH`7T%D;6EN:7-T<F%T:6]N
M`%]";&%C:VQI<W0`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T1E;&5T
M92!M97-S86=E(&-O;7!L971E;'D`7T5N=&5R(&5A8V@@861D<F5S<R!O;B!A
M(&YE=R!L:6YE.@!?1F]R=V%R9`!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P
M97)T:65S+BXN`%]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C
M8V]U;G0_`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]-;W9E
M(&UE<W-A9V4@=&\@9F]L9&5R.@!?37D@96UA:6P@861D<F5S<V5S.@!?3W!T
M:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]38W)I<'0`7U-E
M='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!?5F%C871I;VX`7U=H
M:71E;&ES=`!A9&1R97-S(&)O;VL`86YD`&-A;&5N9&%R`&-A;&T`8VQI8VL@
M:&5R90!F86QL:6YG`&9I96QD`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S70!M871C:`!M:VES;V9S
M(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M90!N;W0@:6UP
M;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`&]R`'!E<F-E
M;G0`<&EX96QS`'!R;V-M86EL('-C<FEP="!G96YE<F%T960@8GD@26YG;P!R
M:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S:65V92!F:6QT97(@9V5N97)A=&5D
M(&)Y($EN9V\`<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!T87-K(&QI<W0`
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N
M;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C
M="U)9"U697)S:6]N.B!);F=O("@Q+C`N,2D*4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,#$M,C4@,3@Z-#8K,#$P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`Q
M+3(U(#$X.C0V*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!!=71O;6%T:6-A;&QY
M(&=E;F5R871E9`I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R
M9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM.0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],3L@<&QU<F%L/3`["@`@
M*"5S(&?\;B#V;F-E*0`H17)I_FEM($%N86AT87+]("5S*0`@*"5S(&?\;F1E
M*0`@*&)U9_QN*0`@*'EA<OUN*0`@*&3\;BD`('9E`"!D92AD82D@`"!V97EA
M`"5D("5S('9E("5S`"5D+6?\;FS\:R!H879A('1A:&UI;FD`)7,@+2!":6QD
M:7)I;0`E<R!087)M86L@W7II`"5S($M"`"5S($)A:_UM(-W^;&5M;&5R:2`M
M($]N87EL86UA`"5S($%Y87)L87(`)7,@1VER:?X`)7,@06YL8?YM82!+;_YU
M;&QA<OT`)7,@>F%T96X@=F%R+@`E<R!D92`E<R`E<P`E<R!I<W1E;FUE:W1E
M9&ER+@`E<R!D86MI:V$`)7,@8G5L=6YA;6%D_2X`)7,@+2`E<R`O("5S(``E
M<R!!9')E<R!$969T97)I`"5S(%1A:W9I;0`E<R!.;W0@1&5F=&5R:0`E<R!'
M]G)E=B!,:7-T97-I`"5S.B`E<P`L(&;]<G3];F%L_2`E<R`E<P`L(&1E\&G^
M:6T@)7,@+3X@)7,`+2T@4V7G("TM`#$R(%-A871L:6L@6F%M86X@0FGG:6UI
M`#(T(%-A871L:6L@6F%M86X@0FGG:6UI`#(T('-A870`0G4@]F)E:R!IYVEN
M('9E<FET86)A;OT@<V]N('5Z86YT_7/](&=E<F5K;65K=&5D:7(N`$]N=6QM
M87H@8FER(&AA=&$@;VQU_G1U`-UL971I>6D@_FEF<F5L97EE8FEL;65K(&GG
M:6X@4$=0(&'G_6L@86YA:'1A<OT@9V5R96MM96MT961I<BX`W6UZ86QA;FW]
M_B!I;&5T:7EI(&1O\')U;'7P=6YU('-A\&QA;6%K(&GG:6X@4$=0(&'G_6L@
M86YA:'1A<OT@9V5R96MM96MT961I<BX`W6QE=&EN:6X@_FEF<F5S:6YI(.?V
M>FUE:R!IYVEN(&'G_6L@4$=0(&%N86AT87+]+/9Z96P@4$=0(&%N86AT87+]
M('9E(&=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=;&5T:7EI(&EM
M>F%L86UA:R!IYVEN(&'G_6L@4$=0(&%N86AT87+]+/9Z96P@4$=0(&%N86AT
M87+]('9E(&=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=;&5T:6YI
M;B#^:69R97-I;FD@Y_9Z;65K(&GG:6X@8>?]:R!3+TU)344@86YA:'1A<OTL
M(/9Z96P@4R]-24U%(&%N86AT87+]('9E(&=EYVG^('3\;6-E8VGP:2!G97)E
M:VUE:W1E9&ER+@#=;&5T:7EI(&EM>F%L86UA:R!IYVEN(&'G_6L@4R]-24U%
M(&%N86AT87+]+"#V>F5L(%,O34E-12!A;F%H=&%R_2!V92!G9>=I_B!T_&UC
M96-I\&D@9V5R96MM96MT961I<BX`W6QE=&EY:2#^:69R96QE>65B:6QM96L@
M:>=I;B!AY_UK(%--24U%(&%N86AT87+](&=E<F5K;65K=&5D:7(N`-;6(%EA
M\&UU<@#6UB!38?!N86L`UM8@2&%F:68@2V%R`-;6+]93`$%022!)1`!$_'IE
M;FQE>6EC:2!H86MK_6YD80!(86MK_6YD82XN+BX`16YA;'0`3W)T87EA`%9&
M4R!D:7II;FD@>6%R873]<FME;B!E<FG^:6T@96YG96QL96YD:2X`5D93(&1I
M>FEN:2!Y87)A=/UL_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN`$AE<V%P(%!A
M<F%L;W/]`$AE<V%P($1O;F1U<G5L9'4N`$AE<V%P;&%N_7EO<@!+87)A;&ES
M=&5D96MI(&%D<F5S;&5R(&GG:6X@97EL96UL97(Z`$)E=&EK;&5R:2!%=&MI
M;FQE_G1I<@!%:VQE`$%L="!'<G5P($5+;&4`06QT(-UZ:6X@14ML90!"=7)A
M>6$@16ML93H`665N:2!'<G5P($5K;&4`665N:2#=>FEN($5K;&4`665N:2!K
M=6QL86[]8_T@96ML93H`2V]L;VX@16ML90!996YI(/QY92!E:VQE`-UK:6QI
M($5K;&4`)7,@365N_'/\;OP@36]Z:6QL82!+96YA<B#'=6)U\'4@3VQA<F%K
M($5K;&4`061R97,@9&5F=&5R:6YE(&5K;&4Z`$%D<F5S(&1E9G1E<FEM92!E
M:VQE`$MU;&QA;OUC_2!%:VQE`$MU;&QA;OUC_2!E:VQE;64@<V7G:6QE;65Z
M(&O];/UN9/TN`-UL879E($%Y87)L87(`061R97,`061R97,@1&5F=&5R:0!9
M]FYE=&EM+2U$:?!E<B!K=6QL86[];&%R(&GG:6X@:7II;FQE<FD@8F5L:7)L
M97EI;@!9]FYE=&EM`$%D<P!!9F=A;FES=&%N`$%R;F%V=71L=6L`0V5Z87EI
M<@#6=&5K:2!A9`!(:7IA;&$`2&EZ86QA;6%K.@!4_&W\`%3\;2!$;_!R=6QA
M;FW]_B!+=6QL86[]8_UL87(`5/QM($=R=7!L87(`5/QM(-UZ:6YL97(`5/QM
M(&3V<G0@>?QZ`%1A:VEP(&5D96YL97)I;B!H97!S:0#';VML=2!A9')E<VQE
M<F4@:7II;B!V97(`4_UR86QA;FW]_B!L:7-T92!T_'+\;OP@87EA<FQA;6%Y
M82!I>FEN('9E<FEL<VEN(&UI/P!:871E;B!V87(`UG1E:VD@24U34"!':7)I
M_FD`UG1E:VD@24U34"!087)O;&%S_0#6=&5K:2!)35-0($MU;&QA;OUC_2!!
M9/T`UG1E:VD@96QE:W1R;VYI:R!P;W-T82!A9')E<VD`UG1E:VD@=&%S;&%K
M;&%R`-9T96MI(&UE=&EN.@!!;65R:6MA;B!386UO80!'9>=E<G-I>B!D9?!E
M<B!B96QI<G1I;&1I+@!!;F1O<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;2!0
M<F]X>0!#979A<`!#979A<&QA;FW]_@!!;G1A<G1I:V$`06YT:6=U82!V92!"
M87)B=61A`%1A:VEP(&5D96YL97)I;B!H97)H86YG:2!B:7)I`%5Y9W5L86UA
M`%5Y9W5L86UA($QI<W1E<VD`57EG=6QA;6$@2&%Z_7(`4_QZ9V7G;&5R:2!5
M>6=U;&$`06QT('!A>6QA_OUM;&%R82!U>6=U;&$`3VYA>6QA`%EA:VQA_OUK
M($)O>75T`$YI<V%N`$%R87#G82`H5VEN9&]W<RTQ,C4V*0!"96QG96QI:R!$
M;W-Y82!"=7EU='4`0F5L9V5L:6L@063]`$)U(&MU<F%L_2!S:6QM96L@:7-T
M961I\&EN:7IE(&5M:6X@;6ES:6YI>C\`)7,@:>=I;B!G:7)I_B!I<W1E\&EN
M:2!K86QD_7)M86L@:7-T961I\&EN>F4@96UI;B!M:7-I;FEZ/P!!<FIA;G1I
M;@!%<FUE;FES=&%N`$5R;65N:6-E("A!4DU30TE)+3@I`%-A;F%T`$%R=6)A
M`$%S8V5N<VEO;B!!9&%L87+]`$%S8VEI(%-A;F%T_0!!<WEA+U!A<VEF:6L@
M0O9L9V5S:0!"86O];2!I_FQE;6QE<FEN9&5N(/9N8V4@9&_P<G5L86UA('-O
M<G5L<W5N(&UU/P!!=&%M82!+;VQO;FQA<OT`5F%R(&]L;6%Y86X@8FER(&=R
M=6)U('-I;&UE(&=I<FG^:6UI+@!687(@;VQM87EA;B!B:7(@:7IN:2!S:6QM
M92!G:7)I_FEM:2X`5F%R(&]L;6%Y86X@8FER(&=R=6)U(&3\>F5N;&5M92!G
M:7)I_FEM:2X`5F%R(&]L;6%Y86X@8FER('!A>6QA_OUM_2!D_'IE;FQE;64@
M9VER:?YI;6DN`-9Z;FET96QI:VQE<@!!\'5S=&]S`$%V=7-T=7)A;'EA`$%V
M=7-T=7)Y80!!=71H7V-Y<G-Q;#H@W7-T96YE;B!I;6%P('5Z871A=/US_2!B
M=6QU;F%M863]+@!!=71H7V-Y<G5S.B#=<W1E;F5N('EE=&5N96ML97)E('-A
M:&EP(&1E\&EL+@!!=71H7V-Y<G5S.B#=<W1E;F5N(&EM87`@=7IA;G3]<_T@
M8G5L=6YA;6%D_2X`075T:%]F='`Z(-US=&5N96X@1E10('5Z86YT_7/](&)U
M;'5N86UA9/TN(%!(4"=Y:2`M+65N86)L92UF='`@<W=I=&-H(&1E\&G^=&ER
M9V5S:7EL92!D97)L97EI;BX`075T:%]I;6%P.B#=<W1E;F5N($E-05`@=7IA
M;G3]<_T@8G5L=6YA;6%D_2X`075T:%]K<F(U.B#=<W1E;F5N(&MR8C4@=7IA
M;G3]<_T@8G5L=6YA;6%D_2X`075T:%]L9&%P.B#=<W1E;F5N($Q$05`@=7IA
M;G3]<_T@8G5L=6YA;6%D_2X`075T:%]I;6%P.B`E<R!K=6QL86[]8_US_2!E
M:VQE;F5M961I+B!3=6YU8W4Z(`!!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/]
M('-I;&EN96UE9&D`075T:%]L9&%P.B`E<R!K=6QL86[]8_US_2!G_&YC96QL
M96YE;65D:0!!=71H7VUC86PZ(-US=&5N96X@34-!3"!U>F%N=/US_2!B=6QU
M;F%M863]+@!!=71H7W-M8F%U=&@Z(-US=&5N96X@<VUB875T:"!U>F%N=/US
M_2!B=6QU;F%M863]+@!$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N`$1O\')U
M;&%M82!B8?YA<OUS_7H@;VQD=2X@)7,`1&_P<G5L86UA(%)!1$E54R!S=6YU
M8W5S=2!T87)A9OUN9&%N(&=E<FD@YV5V<FEL9&DN`$944"!S=6YU8W5S=6YA
M(&1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2X`0F5T:6L@:&5R(&1E\&G^:6UD
M96X@<V]N<F$@]GID979I;FEM;&D@;VQA<F%K(&?\;F-E;&QE;G-I;B!M:3\`
M2W5L;&%N_6S]<B!A;&%N;&%R.@!!>F5R8F%Y8V%N`$)/1D@@0>?]:VQA;6%L
M87+]`$%R=&%L86X`07)T86QA;B!296YG:0!+]G3\(&ME<F)E<F]S('!A<F]L
M87/]+@!+]G3\(&ME<F)E<F]S(&MU;&QA;OUC_2!A9/TN`$)A:&%M86QA<@!"
M86AR97EN`$)A;'3]:R`H25-/+3@X-3DM,3,I`$)A;F=L861E_@!"87)B861O
M<P!486)A;B#G:7IG:7-I`$=I>FQI($LN2RX`0F'^;&%N9_UC_3H`0F5Y87H@
M4G5S>6$`0F5LYVEK80!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`1&_P
M=6UG_&[\`$MA<F%L:7-T90!+87)A;&ES=&5Y:2!$_'IE;FQE`$MA<F%L:7-T
M92!Y_'+\<FS\:W1E(&]L86X@<_QZ9V7G('/\<OQC_'/\('1A<F%F_6YD86X@
M9&5S=&5K;&5N;6EY;W(N`$MA<F%L:7-T97EE($%L_6YM_?X@061R97,`2V%R
M86QI<W1E>64@06S];FW]_B!!9')E<VQE<@!5>6=U;&%M82`B)7,B('-A:&EP
M(&]L9'7P=2`B)7,B(/9B9?!I(&)U;'5N86UA9/TN`-9B96L@07EA<FQA<OT`
MUF)E:R!4_'+\`-WG97)I:P!+;WEU`$)O;&EV>6$`665R(-UM;&5R:0!3_6[]
M<@!3_6[]<B!+86S];FS]\/TZ`%/];OUR;&%R`$)O<VYA($AE<G-E:P!(97(@
M26MI<VD`0F]T<W9A;F$`06QT`$)O=79E="!!9&%L87+]`$)R97II;'EA`$)R
M:71A;GEA($AI;G0@3VMY86YU<W4@0O9L9V5S:0!"<G5N96D`0G5L9V%R:7-T
M86X`36%D9&4@W6UL:2!,:7-T90!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`
M0U)3`$-23"!$8?#]=/UM($YO:W1A;&%R_0!?2/QC<F4@UGIE;&QI:VQE<FDN
M+BX`5&%K=FEM`$1U<F=U;@!+86UB;^=Y80!+86UE<G5N`%!A<F]L82#V>F1E
M=FEN:6UL:2!O;&%R86L@<_UF_7)L86YA;6%M86MT863]<BP@;/QT9F5N('GV
M;F5T:6-I;FEZ;&4@9_9R_/[\;BX`24U!4"!S=6YU8W5S=6YA(&)A\&QA;OUL
M863].B`E<P!+86YA9&$`W7!T86P`4V]R=6X@4F%P;W)U;G4@W7!T86P@170`
M(B5S(B!D;W-Y87/]('-I;&EN96UE9&DN`$=EYVEC:2!D:7II;B!B=6QU;F%M
M863]+@`G=&%R9V5T1FEL92<@9&7P:?YT:7)G97-I(&]L;6%D86X@9&5V86T@
M961I;&5M97HN`"(E<R(@9&EZ:6YI(&MA;&3]<OUL86UA9/TN`$MA;&3]<OUL
M86UA9/T@+"5D(&%L="!Y87#]('9A<BX`665N:61E;B!D_'IE;FQE;65D:2P@
M>65N:61E;B!D_'IE;FQE;64@:>=I;B!S8?!L86YA;B!K87G]=&QA<OUN('-A
M>?US_2!I;&4@9&5P;VQA;FW]_B!O;&%N;&%R_6X@<V%Y_7/](&7^;&7^;65M
M96MT961I<BX`0F5L:7)T:6QM:?X@;G5M87)A>6$@:6QE=&D@>?9N;&5N9&ER
M:6QE;65D:2X`0V%P92!697)D90!"8?YL_6L`0OQY_&LO2_SG_&L@2&%R9B!$
M=7EA<FS]`$MA=&5G;W)I;&5R('9E($5T:6ME=&QE<@!#87EM86X@061A;&%R
M_0!++B!+;W!Y80!#97`@5&5L969O;G4`2/QC<F4@UGIE;&QI:VQE<FD`2/QC
M<F4@>6%S=/UK;&%M87/].@!(_&-R92#6>F5L;&EK;&5R:0!(_&-R92!";_YL
M=6ML87+].@!#97`@5&5L969O;G4`2V5L=&EK("A)4T\M.#@U.2TQ-"D`3W)T
M80!/<G1A($%F<FEK82!#=6UH=7)I>65T:0!/<G1A($%V<G5P82`H25-/+3@X
M-3DM,BD`3VYA>2!"96QG97-I($%Y<OUN=/UL87+]`$]N87D@0F5L9V5S:2!+
M=7)A;&QA<OT`QV%D`$1E\&G^=&ER`-UN<V%N;&%R_6X@<VEZ9&5N(&=E;&5N
M(&5L96MT<F]N:6L@<&]S=&%L87+](&]K=7)K96X@=F4@8V5V87!L87)K96X@
M9_9R9/QK;&5R:2!A9"!V92!A9')E<VEN:7II(&1E\&G^=&ER:6XN`$1E\&G^
M:6ML:6ML97(@:V%Y9&5D:6QD:2X`2V%R86MT97(`0F'P;&%N=/UY_2!$95]N
M971L92XN+@#>:6QI`,=I;@!"87-I=&QE_G1I<FEL;6G^(,=I;F-E("A'0C(S
M,3(I`$=E;&5N96MS96P@QVEN8V4@*$)I9S4I`%!A<F]L82!S9>=I;@!+=6QL
M86[]8_T@863]('-EYVEN`%1A<FEH;&5R:6X@;F%S_6P@9_9S=&5R:6QE8V7P
M:6YI('-EYVEN.@!,:7-T92!":>=E;2!4_'+\;OP@4V7G:6X@*'/]<F%L86YM
M_?X@;&ES=&5L97(@:>=I;BD`0VAR:7-T;6%S($%D86QA<_T`4_UN_68@=&%N
M_6W](&)U;'5N86UA9/TZ)7,`5&5M:7IL90!-4T]F9FEC92!B:>=I;2!I;6QE
M<FEN:2!T96UI>FQE`$MU;&QA;OUC_7G]('1E;6EZ;&4Z("5S`$MU;&QA;OUC
M_2!T96UI>FQE`$MU;&QA;OUC_2!V97)I<VD@=&5M:7IL90!$979A;2!E=&UE
M:R!IYVEN('3]:VQA>?UN`$A45%`@>6]L=7EL82!#;&EC:V%T96QL`%!E;F-E
M<F5Y:2!+87!A=`!"=6QU=&QA<@!"=6QU=&QU`$-O8V]S($%D86QA<OT`2V5N
M87(@QW5B=?!U;G4@1&%R86QT`$1A<F%L=/UL;?W^(%/];OUR;&%R`$MO;&]M
M8FEY80!296YK`%)E;FL@4V7G:6-I`%)E;FL@4V7G:6UI`$MO;&]N;&%R.@!+
M;VQO;B!"8?YL_6ML87+]`$MO;6EK`$MO;75T`$MO;75T($MA8G7P=0!!Y_UK
M;&%M80!/<G1A:R!!9/T`0V]M;W)O<P#>:7)K970`0FEL9VES87EA<FQA<@!+
M;_YU;&QA<@!987#];&%N9/UR;6$@1F%R:VQA<OT`66%P_6QA;F3]<CHE<P!0
M87)A;&]Y_2!$;_!R=6QA`$MO;F=O`$1E;6]K<F%T:6L@2V]N9V\@0W5M:'5R
M:7EE=&D`0F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4N`$)A\&QA;G3](&)A_F%R
M_7/]>B!O;&1U.@!!Y_UK(&%N86AT87(@<W5N=6-U<W5N82!B8?!L86YT_2!R
M961D961I;&1I+@!!Y_UK(&%N86AT87(@<W5N=6-U<W5N82!B8?!L86YT_2!R
M961D961I;&1I+B!396)E8CH@)7,@*"5S*0!&5%`@<W5N=6-U;F$@8F'P;&%N
M=/T@8F'^87+]<_UZ(&]L9'4N`-UL971I_FEM(&YO:W1A;&%R_2!B8?YA<OUY
M;&$@861R97,@9&5F=&5R:6YI>F4@96ML96YD:2X`W>=E<FUE:W1E9&ER`$1E
M=F%M`$-O;VL@061A;&%R_0#'97)E>@!+;W!Y86QA`$MO<'EA;&$Z)7,`2V]P
M>6%S_3H@)7,`4V7G:6UI($MO<'EA;&$`2V]S=&$@4FEK80!#;W1E(&0G279O
M:7)E`-UL971I(%!'4"!I;&4@_FEF<F5L96YE;65D:2X`W6QE=&D@4$=0(&EL
M92!I;7IA;&%N86UA9/TN`-UL971I(%,O34E-12!I;&4@<VEF<F5L96YE;65D
M:2X`W6QE=&D@4R]-24U%(&EL92!I;7IA;&%N86UA9/TN`-UL971I_FEM(&YO
M:W1A<_T@96ML96YE;65D:2X@)7,`3$1!4"!S=6YU8W5S=6YA(&)A\&QA;OUL
M86UA9/TN`$)A:VEY92!D96YE=&QE;F5M961I+B`E<P!$8?#]=/UM(&QI<W1E
M<VD@>6%R873];&%M863]+B`E<P!01U`@=F5R:7-I;FEN(/YI9G)E<VD@Y_9Z
M_&QE;65D:2X`4R]-24U%('9E<FES:6YI;B#^:69R97-I(.?V>OQL96UE9&DN
M`-UL971I_FEM(&YO:W1A<_T@<VEL:6YE;65D:2X@)7,`1&'P_73];2!L:7-T
M97-I('-I;&EN96UE9&DN("5S`$%L_6/];OUN(&5L96MT<F]N:6L@<&]S=&$@
M861R97-I(&)E;&ER;&5N96UE9&DN`$%D<F5S(&1E9G1E<FD@=&%M86UE;B!G
M971I<FEL96UE9&DN`$1A\/UT_6T@;&ES=&5S:2!T86UA;65N(&=E=&ER:6QE
M;65D:2X`1&'P_73];2!L:7-T96QE<FEN:6X@;&ES=&5S:2!T86UA;65N(&=E
M=&ER;&5M961I+@!!;F%H=&%R('-U;G5C=7-U;F1A;B!AY_UK(&%N86AT87(@
M961I;FEL96UE9&DN`"5S(&'G_6QA;6%D_2X`36%I;G1E;F%N8V5?5&%S:R!B
M:7)I;6D@)7,@8>?];&%M863]+@`E<R!O:W5N86UA9/TN`-US=&5N96X@:W5L
M;&%N8_T@:>=I;B!P87)O;&$@<_UF_7)L86YA;6%D_2X@0F%Z_2!Y861A('3\
M;2!A>7+];G3];&%R(&1O\')U(&1E\&EL+B!996YI9&5N(&1E;F5Y:6X@>6%D
M82!D86AA(&9A>FQA('EA<F3];2!IYVEN('-I<W1E;2!Y]FYE=&EN:7IL92!G
M]G+\_OQN+@!!0TP@97)I_FEL96UE9&DN`$%D<F5S(&1E9G1E<FEN92!E<FG^
M:6QE;65D:2X@)7,`1&'P_73];2!L:7-T97-I;F4@97)I_FEL96UE9&DN("5S
M`$1A\/UT_6T@;&ES=&5L97)I;F4@97)I_FEL96UE9&DN("5S`%-U;G5C=6YU
M;B!Y971E;F5K;&5R:6YE(&5R:?YI;&5M961I+@!987#];&%N9/UR;6$@9V5R
M:2!D]FYD_'+\;&5M961I+BX`)7,@>6%P_6QA;F3]<FUA(&MA>61E9&EL96UE
M9&DN`%EE9&5K(&)I<B!Y87#];&%N9/UR;6$@:V%Y9&5D:6QE;65D:2X`665D
M96L@8FER('EA</UL86YD_7)M82!K87ED961I;&5M961I.B`E<P!9961E:R!Y
M87#];&%N9/UR;6$@9&]S>6%S_2`E<R!K87ED961I;&5M961I+@!987#];&%N
M9/UR;6$@9&]S>6%S_2`E<R!K87ED961I;&5M961I+B!"=2!D=7)U;61A+"!K
M;V1U('1E:W)A<B`E<R!IYVEN92!K87ED971M96L@>6%D82!T86MI<"!E9&5N
M(&MO9'4@96P@:6QE("5S(&GG:6YE(&MO<'EA;&%M86LL('-EYV5N96ML97)I
M;FD@:W5L;&%N86)I;&ER<VEN:7HN`$Q$05`@<W5N=6-U<W4@87)A;F%M863]
M+@#=;&5T:?YI;2!N;VMT87/](&?\;F-E;&QE;F5M961I+B`E<P!$8?#]=/UM
M(&QI<W1E<VD@9_QN8V5L;&5N96UE9&DN("5S`$UO>FEL;&$@:V5N87(@YW5B
M=?!U(&)U;'5N86UA9/TN($ME;F%R(.=U8G7P=6YU;B!AY_UK(&]L9'7P=6YD
M86X@96UI;B!O;'5N+@!387G];&W]_B!M971I;@#<;&ME`$1E<G-L97(`66%R
M870`0F'P;&%N=/T@>6%R870`665N:2!987)A=`!996YI(&1I>FEN('EA<F%T
M`$%L="!D:7II;B!Y87)A=`!987)A=/UC_2#=>FEN;&5R:0!+<F5D:2!K87)T
M(&YU;6%R87/]`$C]<G9A=&ES=&%N`$O\8F$`WG4@06YD86MI(%IA;6%N`-YU
M(&%N9&%K:2!54DP`WG4@06YD86MI($AA=F$@1'5R=6UU`-YU($%N9&%K:2#>
M87)T;&%R.@!9_'+\<FS\:W1E:VD@<VET:6P`)7,@92!G:7)I_G1E(.=A;/W^
M86-A:R!G]G)E=FQE<FD@:VG^:7-E;&QE_G1I<FEN`$ME<P#>9>=I;&D@;VQA
M;FQA<OT@:V5S`$O]8G+]<P!+:7)I;"`H2T])."U2*0!+:7)I;"`H5VEN9&]W
M<RTQ,C4Q*0!+:7)I;"]5:W)A>6YA("A+3TDX+54I`,=E:R!#=6UH=7)I>65T
M:0!'1P!31<?=3$U%6B!+24Q)3D1)`%-%Q]U,345:($M)3$E.1$DZ(`!'_&YL
M_&L`5F5R:2!!\&%C_2!487)A>?UC_7/]`%1A<FEH`$=E;&G^(%1A<FEH:0!4
M87)I:"!39>=I;6D`1_QN`$M?;VQO;G4@4VEL`$)E=&GP:6X@171K:6YL:?!I
M;FD@2V%L9/UR`$%R86S]:P!/;F1A;/UK('-A>?UL87(`1VER:6YT:7EI($%Z
M86QT`-9N('1A;OUM;/T`UFX@5&%N_6UL_2!296YK`-9N(%1A;OUM;/T@2VEM
M;&EK`%1A;OUM;&%R`%-I;`!3:6PZ("5S`$MO_G5L=2!3:6P`1W)U<"!3:6P`
MW7II;B!3:6P`W6QE=&EL97)I('-I;"!V92!T96UI>FQE`$C\8W)E(%-I;`!+
M;VQO;B!3:6P`5F%R;VQA;B#V=&5K:2!T87-L8?#]('-I;`#=;&5T:7EI('1A
M;6%M96X@<VEL`%-A=/UR_2!S:6P`4V7G:6QM:?X@:VEM;&GP:2!S:6P`WG4@
M86YD86MI(&MO;&]N=2!S:6P`WG4@86YD86MI('-A=/UR_2!S:6P`4VEL:6YD
M:0!'14Q%3B!+55154U5.02!G]FYD97(`1T5,14X@2U5455-53D$@9_9N9&5R
M('9E(&MO<'EA;&%N<_UN`$=%3$5.($M55%5354Y!(&?V;F1E<B!V92!Y]FYL
M96YD:7(@`$1I>FEN92!G]FYD97(`5&5S;&EM('IA;6%N_0!$86YI;6%R:V$`
M4V]R=6YU(%1A;OUM;&%Y_6X`0>?]:VQA;6$`07ER_6YT_6QA<B`H07EN_2!Z
M86UA;F1A($AO<F1E)W5N(&?\;FS\:R!D;W-Y87/];OUN(&GG:6YD92DZ`$%Y
M<OUN=/UL87(@>?9N971I8VD@:>=I;B!G_&YL_&L@;VQA<F%K(&MA>61E9&EL
M9&DN`$=E;&G^:6T`3F5M($UI:W1A<OT`4V]N('-A871T96MI(&YE;2!M:6MT
M87+].B``3F5M(&UI:W1A<OTZ(`!3;VQD86X@<V'P82!Y]FYL_`!38?!D86X@
M<V]L82!Y]FYL_`!$:7II;@!39>=I;&5M97H@2_UL.B`E<P!39>=I;&UE>B!+
M_6S];F3]`#(T('-A871L:6L@>F%M86X@;?T@9_9S=&5R:6QS:6X_`$?V<OQN
M=/QL96UE(%-EYV5N96ML97)I`$AE<B!S_'IG96-I;B!N92!Z86UA;B!U>6=U
M;&%N86-A\/UN82!D86ER(&1E=&%Y;/T@8FEL9VD@=F5R:6QS:6X@;6D_`$AA
M=F$@=&%H;6EN:6YI(&?V<OQN=/QL92`H5$%&*0!']G+\;G3\;&5M92!":>=I
M;6D`1/QZ96X@0FEL9&ER:6UI`$-I8G5T:0!9_?#];B!Y861A(&QI<W1E(&EL
M97)I;&5R:6YE(%]C979A<"!G]FYD97)M90!3:6QM97EI;@!M86EN=&5N86YC
M92YP:'`@9&]S>6%S_6YA(&1O\')U9&%N(&5R:?YM97EI;BX`66%P.@#=;&L@
M<V%T_7(@86QA;B!A9&QA<OUN_2!IYV5R:7EO<B!M=3\@179E="!I<V4@8G4@
M:W5T=7EU('-EYVEN.@!"8?YL86UA>6%N`-WG97)M97EE;@!":71M97EE;@!"
M=6QU;FUA>6%N`$7^;&7^;65Y96X@`$1O;6EN:6L`1&]M:6YI:R!#=6UH=7)I
M>65T:0#=;F1I<@`E<R#=;F1I<@!/;'7^='5R=6QA;B!Y87#];&%N9/UR;6%Y
M_2!02%`@8F5T:?!I(&]L87)A:R!I;F1I<BX`0?YA\/T@8>?];/UR(&QI<W1E
M`-UL8>=L87(`12U0;W-T80!%4E(`16MV871O<@!$_'IE;FQE`$3\>F5N;&4@
M)7,`0FQO:R!$_'IE;FQE`$=R=7`@1/QZ96YL90#=>FEN($3\>F5N;&4`W7II
M;FQE<FD@1/QZ96YL90`E<R#=YVEN(-UZ:6YL97)I($3\>F5N;&4`4V7G96YE
M:VQE<FD@9/QZ96YL93H`)7,@:>=I;B!I>FEN;&5R:2!D_'IE;FQE`$7P:71I
M;0!-_7/]<@!%;"!386QV861O<@#6\&4N+BX`16T`16QE:W1R;VYI:R!0;W-T
M80!%;&5K=')O;FEK(%!O<W1A($%D<F5S:0!%;&5K=')O;FEK('!O<W1A(&%S
M<F5S;&5R:2!E_FQE_FUE;&DN`$]N87EL_2!E;&5K=')O;FEK('!O<W1A`$1U
M>6=U('-I;6=E<FQE<FD`0F_^(&EL971I+@!";_X@<V]N=><N`$)O_B!A<F%M
M82!T97)I;6QE<FD`4V7G:6QI<B!K_6PZ("5S`$9O=&_P<F%F($=A;&5R:7-I
M;F1E;B!M971I;FQE<FEN(&GG97)I<VEN92!G]G+\;G3\(&5K;&5M92!E=&MI
M;FQE_G1I<FEL<VEN(&UI/P!38?`@=/UK(&GG97)I:R!M96[\<_P@971K:6YL
M9?YT:7)I;'-I;B!M:3\`4V7G:6QI<B!K_6S];F3]`$)I=&G^('G];/T`0FET
M96X`1/QZ96YL97EI8VEY:2!'96YI_FQE=`!087)O;&%N_7K]('/]9OUR;&%M
M86L@:7-T961I\&EN:7ID92!S;W)U;&UA:R#\>F5R92!B:7(@9_QV96YL:6L@
M<V]R=7-U(&=I<FEN+"#6<BX@)T5V8VEL(&AA>79A;OUN_7K];B!A9/T@;F5D
M:7(_)SH`1_9R_&YT_"!A9')E<VEN:2!B=7)A>6$@9VER:6X`1?YI='1I<@!%
M:W9A=&]R($=I;F5S:0!%<FET<F4`2&%T80!%;&5T<F]N:6L@<&]S=&$@9/9N
M9&5R;65D92!H871A+@!%<W1O;GEA`$5T:7EO<'EA`$5T;FEK`$%V<G5P80!(
M97(@,34@9&%K:6MA`$AE<B`R(&1A:VEK80!(97(@,S`@<V%N:7EE`$AE<B`U
M(&1A:VEK80!(97(@1VER:?YT90!(97(@>6%R_6T@<V%A=`!(97(@9&%K:6MA
M`-9R;F5K(&1E\&5R;&5R.@#'86S]_G3]<@!687)O;&%N($MU<F%L;&%R`%9A
M<@!'96YI_FQE=`!+96YA<B#'=6)U\'5N=2!'96YI_FQE=``G*2<@0F5K;&5N
M:7EO<@!3861E(&ME;&EM92!V97EA(&%L_6YT_2!A<F%M82!T97)I;6D@8F5K
M;&5N:7EO<@!'9>=E<FQI;&EK(%-O;B!487)I:&D`W'-T`-9N($%L86X@4F5N
M9VD`07EA<FQA<B!IYVEN($944"!Y_&ML96UE<VD`5&5R8VEH;&5R:6X@9V5T
M:6QM97-I(&)A_F%R_7/]>BX`3$1!4"!S=6YU8W5S=6YA(&)A\&QA;G3](&)A
M_F%R_7/]>BX`4TU"('-U;G5C=7-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ+@`B
M)7,B(&MO;G5M=6YD86X@:V]P>6%L86UA(&)A_F%R_7/]>BX`(B5S(B!K;VYU
M;75N82!K;W!Y86QA;6$@8F'^87+]<_UZ+@!996YI(%-!4TP@8F'P;&%N=/US
M_2!O;'7^='5R=6QA;6%D_2X`(B5S(B!K;VYU;75N82!T8?[];6$@8F'^87+]
M<_UZ+@!5>6=U;B!(879A`$9A;&ML86YD($%D86QA<OT@*$UA;'9I;F$I`$9A
M<F]E($%D86QA<OT`3VYU;&UA>B!(871A.@!&86MS`-YU8F%T`$AI<W-E9&EL
M:7EO<@!(:7-S961I;&EY;W(Z(`!(869I9B!38?!A;F%K`$AA9FEF($MA<B!3
M8?!A;F'P_0!!;&%N(&UA=')I<VD`1FEJ:0!$;W-Y82!387G]<_TZ("5S(&1O
M<WEA`$1O<WEA(%-A>?US_3H@)7,@9&]S>6$`1&]S>6$@6?9N971I8VES:0!$
M;W-Y82!!9/T`1&]S>6$@<V7G:6UI`$1O<WEA('G\:VQE;64`1&]S>6$@>?QK
M;&5M92!D97-T96ML96YM:7EO<BX`0OQT_&X@:6QE=&EL97)I(%/\>F=EYVQE
M`%-A9&5C92!']G+\;&W\_B#=;&5T:6QE<FD@4_QZ9V7G;&4`4V%D96-E($?V
M<OQL;65M:?X@W6QE=&EL97)I(%/\>F=EYVQE`%/\>F=EYR!39>=E;F5K;&5R
M:0!3_'IG9><@2W5R86S]`%/\>F=EYR!+=7)A;&QA<OT`4_QZ9V7G($)E=&EK
M($?V<OQN=/QL96UE`%/\>F=EYR!?2W5R86QL87+]`%/\>F=EYR!E=&MI;FQI
M\&DZ("5S(&EL971I(&MO<'EA;&%N9/TZ(B5S(BX`4_QZ9V7G(&5T:VEN;&GP
M:3H@)7,@:6QE=&D@<VEL:6YD:2X`4_QZ9V7G(&5T:VEN;&GP:3H@)7,@:6QE
M=&D@=&'^_6YD_3H@(B5S(B!D:7II;FEN92X`4_QZ9V7G(&5T:VEN;&GP:3H@
M:V%R86QI<W1E>6QE(&7^;&7^96X@)7,@:6QE=&D@<VEL:6YD:2X`(B5S(B!I
M;&5T:7-I("@B)7,B(&1E;B!G96QM96MT92D@(B5S(B!D:7II;FEN92!K;W!Y
M86QA;F3]+@!3_'IG9><@971K:6YL:?!I.B`B)7,B(&EL971I<VD@*"(E<R(@
M9&5N(&=E;&UE:W1E*2!S:6QI;F1I+@!3_'IG9><@971K:6YL:?!I.B`B)7,B
M(&EL971I<VD@*"(E<R(@9&5N(&=E;&UE:W1E*2`B)7,B(&1I>FEN92!T8?[]
M;F3]+@!3_'IG9><@8G5L=6YA;6%D_2X`4_QZ9V7G;&5R`$9I;FQA;F1I>6$`
MW6QK(%EA<OT`W6QK(,=E>7)E:P!/<F%N_2!S86)I=&QE`,=E=FER`$MA>6%N
M`%-I<P`E<R!D:7II;FD@>6]K`%EA>OT@4F5N9VD`665M96L`1V5L96X@:6QE
M=&EL97(@:>=I;B!E_FQE_FUE.B``1_9R_&YT_&QE<FD@9&5S=&5K;&5M97EE
M;B!T87)A>?UC_6QA<B!IYVEN`%1A:&UI;B`H5$%&*0!486AM:6X@1_QN;&5R
M:2`H3F]T.B!'97)I(&3V;OQL96-E:VQE<B!H96T@9_QN(&AE;2!G96-E(&]L
M87)A:R!D]F[\;&5C96L[("EB_'G\:R!B:7(@<V%Y_2!G96YI_B!B:7(@]F)E
M:VQE('-O;G7G;&%N86-A:W3]<BD`4&%R;VQA;OUZ_2!M_2!U;G1T=6YU>C\`
M1F]R;6QA<@!$97EI_@!$97EI_B!T_'+\`$1E>6G^;&5R`$1E>6G^;&5R(#(`
M1F]R=6UL87(`W6QE=`#=;&5T:6QE;B!I;&5T:6QE<B!Y_'+\<FS\:W1E:VD@
M<_QZ9V7G('/\<OQC_"!T87)A9OUN9&%N(&1E<W1E:VQE;FUI>6]R+@#=;&5T
M`-UL971I;&5C96ML97)I($3\>F5N;&4`0W4`QV5RYV5V96QE<@!&<F%N<V$`
M1G)A;G-A+"!-97)T;W!O;&ET86X`1G)A;G/]>B!'=7EA;F%S_0!&<F%N<_UZ
M(%!O;&EN97IY87/]`$9R86YS_7H@1_QN97D@0O9L9V5S:0!+:6UD96X`2VEM
M9&5N`%1A;2!"971I;6QE;64`1&]L=6YA>0!!Y_UK($%D`$=A8F]N`$?V<OQN
M=/QL97)I;B!A;/UN86-A\/T@9V%L97)I`$=A;&5R:3H`1V%M8FEY80`E<R!9
M87#];&%N9/UR;6%S_6[]($]L=?YT=7(`3VQU_G1U<G5L86X@2V]D`$?\<F-I
M<W1A;@!!;&UA;GEA`$=A;F$`0V5B96QI=&%R_6L`5F5R:6QE;B!!9`!':70`
M1V]E9&5L`$=O;V=L92!!<F%M80!3:7EA:"!"97EA>@!"_'G\:W3\<@!"_'G\
M:R!Y861A(&7^:71T:7(`675N86YI<W1A;@!9=6YA;F-A("A)4T\M.#@U.2TW
M*0!'<O9N;&%N9`!'<F5N861A`$=R=7`@6?9N971I;6D`1W)U<"!I<VEM;&5R
M:2!D;VQU(&]L;6%L_63]<@!'<G5P;&%R`$=U861A;'5P`$=U86T`1W5A=&5M
M86QA`$=U97)N<V5Y`$MO;G5K(-UZ:6YL97)I`$MO;G5K($1E9G1E<FD`1VEN
M90!'=6EN92!":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@<V%T_7)D86MI
M('-O;B!H_&-R97EI('-I;&UE>6D@<F5D9&5D:7EO<BX`2%1-3$%R96$@YVEZ
M96QG961E:VD@<V]N(&MO;&]N=2!S:6QM97EI(')E9&1E9&EY;W(N`$A434Q!
M<F5A(.=I>F5L9V5D96MI('-O;B!S873]<OT@<VEL;65Y:2!R961D961I>6]R
M+@!(5%10($MI;6QI:R!$96YE=&EM:2!B=6QA;F%M863]+@!(86ET:0!(87-H
M($%L9V]R:71M87/]`$AA9FEF(%-I<P!"8?YL_6L`2&5A<F0@061A<_T@=F4@
M36-$;VYA;&0@061A;&%R_0#=8G)A;FEC92`H25-/+3@X-3DM."U)*0!9_&MS
M96ML:6L`66%R9/UM`$3\>F5N;&5Y:6-I(&MU;&QA<F%K('EA<F3];0!987)D
M_6UC_0!987+]:_QR90!$;W-Y86[];B!B8?YL86YG_6/].B``6?QK<V5K`%]!
M;F%S87EF80!6871I:V%N`$%N87-A>69A`$5V($%D<F5S:0!%=B!496QE9F]N
M=0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($)U(&UE
M<V%J(&GG:6YD92!G9>=E<G-I>B`E<R!834P@=F5R:7-I(&EL92!K87+^_6QA
M_OUL9/TZ("5S`$AO<F1E+TMO;&%B.B`E<R!N97-N97-I(&EL92!I;&=I;&D@
M8FER(&EL971I(&)U;'5N86UA9/T`2&]R9&4O2V]L86(Z("5S('3\<OQN9&4@
M:&GG(&)I<B!N97-N92`E<R!M97-A:OT@:>=I;F1E('EO:RX`2&]R9&4O2V]L
M86(Z("5S("(E<R(@8F'^87+](&EL92!S:6QI;F1I`$AO<F1E+TMO;&%B.B!"
M_'3\;FQE;64@;6]T;W)U("=D;VUX;6PG(%!(4"!U>F%N=/US_6YA(&EH=&EY
M8><@9'5Y;6%K=&%D_7(`2&]R9&4O2V]L86(Z("5S(&YE<VYE<VD@:>=I;B!Y
M96YI(%A-3"!A\&%C_2!O;'7^='5R=6QA;?UY;W(`2&]R9&4O2V]L86(Z(%-I
M;&EN96UE9&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z("5S('3\<OQN9&5K
M:2!K_7/];2!IYVEN($U)344@240@8G5L=6YA;6%D_0!(;W)D92]+;VQA8CH@
M1?YL96YE;65D:2`E<R`B)7,B.B`E<P!087EL8?[];6QA<B!E_FQE;F5M961I
M.B`E<P!":6QI;FUE>65N('!A>6QA_OUM("(E<R(`66%T87D@QVEZ9VD`66%T
M87D@>6%S=/UK;&%M80!9871A>3H`0G5R87EA(&YA<_UL(&=E;&1I;FEZ/R`H
M3/QT9F5N(')A<&]R(&5D:6XA*0!+8><@861E="!K;VQO;G4@8FER;&7^=&ER
M;65K(&ES=&EY;W)S=6YU>C\`2V'G(&%L86X@*&MO;&]N*2!V87(_`$MAYR!A
M9&5T('-A=/UR_2!B:7)L9?YT:7)M96L@:7-T:7EO<G-U;G5Z/P!.96T`3F5M
M.B``36EZ86CG_6QA<@!-86-A<FES=&%N`$E-05`@<&]S=&$@:W5T=7-U(&]L
M=?YT=7)U;&%M863].B`E<P!)34%0('!O<W1A(&MU='5S=2!S:6QI;F5M961I
M.B`E<P!)34%0('!O<W1A(&MU='5S=2!K;W1A<_T@;VQU_G1U<G5L86UA9/TZ
M("5S`$E0($%D<F5S:0!)4"!A9')E<VD@;65V8W5T(&1E\&EL+B``25`@061R
M97-I(&EZ:6X@=F5R:6QE;B!#2412(&)L;_!U(&GG:6YD92!D9?!I;"X`25`@
M:VEL:71L96UE(&EH;&%L:2X`UFY?8V5Y92!3873]<B!997)L9?YT:7(`W7IL
M86YD80!3861E8V4@4VEM9V5L97(`)7,@:>=I;B!S:6UG96QE<@!-971I;B!I
M;&4@8FER;&EK=&4@<VEM9V5L97(`2VEM;&GP:6X@863].@!%\&5R(&1O\')U
M(&?V<OQN=/QL96YE;6EY;W)S82P@>65N:2!P96YC97)E9&4@8>=M86L@:>=I
M;B!T_6ML87G];B`E<RX`1?!E<B!);G1E<FYE="!%>'!L;W)E<B!I;&4@<VEM
M9V5L97)I(&?V<F5M:7EO<G-A;OUZ(&)U(&MU='5Y=2!S9>=E<F5K(%!.1R!S
M87ED86UL_?#];OT@:V%P871M86[]>B!G97)E:VER+@!']G+\;G3\;&5R:2!G
M]G)E;6EY;W(@9F%K870@8G4@;65S86K](&?V<F5B:6QI<GEO<G-A;OUZ+"!Y
M_&ML96UE:R!I<W1E9&GP:6YI>B!G]G+\;G3\('1A<F%Y_6/];OUZ('1A<F%F
M_6YD86X@9_9S=&5R:6QE;65M96MT961I<BX`1_9R_&YT_"#6;FEZ;&5M90!'
M]G+\;G3\(%523`!']G+\;G3\(%523#H`4V5R9VED96X@9_9R_&YT_`!397)G
M:61E;B!G]G+\;G3\.@!']G+\;G3\('G\:VQE;65K`$?V<OQN=/QL97(`W>=E
M<FD@06MT87(L($%D_6T@)60`UFYE;6QI`-WG97)I(&%K=&%R_6QA;B!A;&%N
M.B`E<P#=YV5R:2!A:W1A<OUL86X@86QA;FQA<CH`4V]N7W)A>6$@4V%T_7(@
M16ML90!986YL_?X@97EL96T@:V]D=2!G:7)I;&1I+@!986YL_?X@:W5L;&%N
M_6/](&%D_2!V92]V97EA('!A<F]L82X`66%N;/W^(&MU;&QA;OUC_2!A9/T@
M=F5Y82#V=&5K:2!A9')E<RY996YI9&5N(&1E;F5Y:6X@=F5Y82!D86AA(&9A
M>FQA('EA<F3];2!IYVEN('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BX`1VER:6YT
M:7EI($%R='3]<@!(:6YD:7-T86X`0FER97ES96P@2W5L;&%N_6/];&%R`$MI
M_FES96P@:W5R86QL87(@>?QR_')L_&MT96MI('/\>F=EYR!S_'+\8_P@=&%R
M86;];F1A;B!D97-T96ML96YM:7EO<BX`16YD;VYE>GEA`&EL971I('1E<VQI
M;6D@:>=I;B!V87(@;VQM87EA;B!B:7(@<&]S=&$@:W5T=7-U(&)E;&ER=&EL
M9&DN`$)I;&=I`$)I;&=I`%-O;G)A>6$@2V]?;&]N($5K;&4`1_9R_&YT_"!9
M97)L9?YT:7(`QVEZ96QG92!997)L9?YT:7(`5V5B($)A\&QA;G3]<_T@665R
M;&7^=&ER`-9N8V5Y92!+;VQO7VX@16ML90!996YI(&MO;&]N=2#^=2!A;F1A
M:VD@:V]L;VYD86X@<V]N<F$@>65R;&7^=&ER`%EE;FD@:V]L;VYU(/YU(&%N
M9&%K:2!K;VQO;F1A;B#V;F-E>64@>65R;&7^=&ER`%EE;FD@<V%T_7+](/YU
M(&%N9&%K:2!S873]<F1A;B!S;VYR87EA('EE<FQE_G1I<@!996YI('-A=/UR
M_2#^=2!A;F1A:VD@<V%T_7)D86X@]FYC97EE('EE<FQE_G1I<@!996YI('!A
M<F%G<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@<V]N<F%Y82!Y97)L9?YT:7(`
M665N:2!P87)A9W)A9OT@_G4@86YD86MI(&3\\/QM9&5N(/9N8V5Y92!Y97)L
M9?YT:7(`UG1E:VD@=&%S;&%K('EE<FQE_G1I<@!996YI(&)I<B!P87)A;&]Y
M_2!A;&%B:6QE8V7P:6YI>B!B:7(@96QE:W1R;VYI:R!P;W-T82!A9')E<VD@
M9VER:6XZ`$C\8W)E>6D@<V]N<F%S_6YA('EE<FQE_G1I<@!(_&-R97EI(/9N
M8V5S:6YE('EE<FQE_G1I<@!+;VQO;G4@<V]N<F%S_6YA('EE<FQE_G1I<@!+
M;VQO;G4@]FYC97-I;F4@>65R;&7^=&ER`$UE<V%J(&=I<@!087)A9W)A9OT@
M<V]N<F%S_6YA('EE<FQE_G1I<@!087)A9W)A9OT@]FYC97-I;F4@>65R;&7^
M=&ER`%-A=/UR_2!S;VYR87/];F$@>65R;&7^=&ER`%-A=/UR_2#V;F-E<VEN
M92!Y97)L9?YT:7(`1_QV96YL:6L@<V]R=7-U;G5N(&-E=F%B_3H`1_9R_&YT
M_'G\(%EE<FQE_G1I<B]$9?!I_G1I<@!"8?!L86YT_2!997)L9?YT:7(O1&7P
M:?YT:7(`1&'P_73];2!L:7-T97-I(&?V;F1E<FUE:R!IYVEN('EE=&5R<VEZ
M(&MR961I+@!9971E<G-I>B!K<F5D:0!486US87G]`%1A;7-A>?T@;&ES=&5S
M:0!'9>=E<G-I>B!51$@N("A+=6QL86[]8_T@5F5R:2!"8?YL_6L@0FEL9VES
M:2D`1V7G97)S:7H@=7EG=6QA;6$N`$=EYV5R<VEZ('G]\/UN(&MI;6QI\&DN
M`$=EYV5R<VEZ('9E<FD@9_9N9&5R:6QD:2X`1V7G97)S:7H@=&5S;&EM(&%D
M<F5S:0!'9>=E<G-I>B!D;W-Y82!B:>=I;6D`1V7G97)S:7H@;7-G7W1Y<&4`
M1V7G97)S:7H@>6%D82!A=&QA;FW]_B!A<&E?:60`1V7G97)S:7H@>6%D82!A
M=&QA;FW]_B!D9?!I_G1I<F=E;&5R`$=EYV5R<VEZ(/QS="!I>FEN+@!'9>=E
M<G-I>B!I;&5T:?YI;2!K=7)A;&QA<OT`1V7G97)S:7H@<&%Y;&'^_6QA;B!N
M97-N90!'9>=E<G-I>B!K87EN86L@861R97-I+@!'9>=E<G-I>B!U;FEC;V1E
M('9E<FES:2X`4W1O:P#=<F%N(-US;&%M($-U;6AU<FEY971I`$ER86L`W7)L
M86YD80!/;&%N`$UA;B!!9&$@1&5V;&5T:0!/;&UA>6%N`%EA;/UT_6QM_?X@
M9_9K(&?\<OQL=/QL_"!F_7)T_6YA`-US<F%I;`#'_6MA<F%N`-UT86QI:P#=
M=&%L>6$`2F%M86EK80!/8V%K`$IA<&]N>6$`2F%P;VYC82`H25-/+3(P,C(M
M2E`I`$IE<G-E>0#<<F3\;@!496UM=7H`2&%Z:7)A;@!987-L80!/<G1A>6$@
M66%S;&$`5&%M86UE;B!987-L80!3;VQA(%EA<VQA`%-A\&$@66%S;&$`2V%Z
M86MI<W1A;@#6>F?\;B!O;&%N('-A:VQA;G/];B!M_3\`2V5N>6$`2V5R8F5R
M;W,@<W5N=6-U(&1O\')U;&%M87G](')E9&1E='1I+@#'96MI<F1E:R!!8V5M
M:6QE<FD`06YA:'1A<B!987)A=`!!;F%H=&%R(%!A<FUA:VEZ:0!!;F%H=&%R
M(%5Z=6YL=?!U`$%N86AT87(@5&EP:0!!;F%H=&%R($MU;&QA;OUM_0!!Y_UK
M(&%N86AT87(@<W5N=6-U<W5N9&$@86YA:'1A<B!Z871E;B!V87(N`,=O8W5K
M;&%R`$MI<FEB871I`$MU>F5Y($MO<F4`1_QN97D@2V]R90!+;W)E8V4@*&5U
M8RU+4BD`2W5V97ET`$O]<F?]>FES=&%N`%-A>69A(%]$_'IE;FD`1&EL`$QA
M;R!$96UO:W)A=&EC($AA;&L@0W5M:'5R:7EE=&D`4V]N($3V<F3\;@#>:?YK
M:6X@07D`4V]N($?\;F-E;&QE;64Z`%-O;B!':7)I_CH@)7,`4V]N($=I<FG^
M.B`E<R#\>F5R:6YD96X@)7,`4V]N($=I<FG^.B!!<VQA`$QE=&]N>6$`66%S
M80!$_'IE;@!(:>=B:7(@<_UN_7(@:>=I;B!B;_X@8OUR86MM80!,_&)N86X`
M4V]L`%-O;"!B8?YL_6L@8FEL9VES:0!3;VQD86MI(&1E\&5R;&5R`$QE<V]T
M:&\`2_SG_&MT_'(`2_SG_&L@>6%D82!E_FET:7(`3&EB97)Y80!,:6)Y80!,
M:65C:'1E;G-T96EN`,=I<V5L:7EO<@!(869I9B!98?!M=7(`17)K96X@4V%A
M=&QE<F1E($AA9FEF(%EA\&UU<@!'9><@4V%A=&QE<F1E($AA9FEF(%EA\&UU
M<@!(869I9B!98?!M=7(@4V'P86YA\/T`1_9K(&?\<OQL=/QL_"!H869I9B!Y
M8?!M=7(`2&%F:68@2V%R`$AA9FEF($MA<B!38?!A;F'P_0!._&MT96QI(-YI
M:7(`0F'P;&%N=/T`0F'P;&%N=/T@;F]K=&%S_3H`1_9R_&YT_&QE<FME;B!E
M;&5K=')O;FEK('!O<W1A(&%D<F5S:6YI(&]L=?YT=7)M82!S87EF87/];F$@
M8F'P;&$`0F'P;&%N=/UL87(`3&EN=7@@QV5R97II`$QI<W1E;&4@+2!K=6QL
M86[]8_T@9&EZ:6YI(&?V<F5B:6QI<@!697)I(%1A8F%N;&%R_6[]($QI<W1E
M;&4`66%R9/UM($MO;G5L87+];OT@3&ES=&5L90#':7IE;&=E;&5R:2!,:7-T
M96QE`$QI<W1E;&4M07+^:78`3&ES=&5L92U987)D_6T`3&ES=&4M240`3&ES
M=&5L92U)9`!,:7-T96QE+5-A:&EP`$QI<W1E;&4M1_9N9&5R:6QM:?X@UO!E
M;&5R`$QI<W1E;&4M4_QR9/QR_&UC_&QE<@!,:7-T96QE+5/\<F3\<OQM8_P@
M3VQM87EA;FQA<@!+=6QL86[]8_T@;&ES=&5L96UE('-EYVEL96UE>B!K_6S]
M;F3]+@!%9&5B:7EA=`!,:71V86YY80!9_&ML96YI>6]R+BXN`%EE<F5L('IA
M;6%N.@!997(@=F4@6F%M86X`665R`$=I<FG^`,?]:_W^`$=I<FG^($?V<F5V
M;&5R:0!+=6QL86[]8_T@863]('9E>6$@<&]R;VQA(&1O\')U(&]L;6%D_?#]
M(&GG:6X@9VER:?X@8F'^87+]<_UZ(&]L9'4N`$=I<FG^(&)A_F%R_7/]>B!O
M;&1U+@!5>G5N(&UE=&EN`$'^:P!$_/[\:P!+_.?\:R!Y=6YA;B!H87)F;&5R
M:0!+_.?\:R!L871I;B!H87)F;&5R:0!+_.?\:R!R;VUA(')A:V%M;&%R_0!,
M_&MS96UB=7)G`$%!`$U/5$0`35,M5$Y%1B!%:VD@=F5R:2!IYV5R;65M96MT
M961I<BX`35-'`$UA8V%O`$UA:V5D;VYY80!-861A9V%S:V%R`$+\>?P`4&]S
M=&$`4&]S=&$@6?9N971I8VES:0!"8?!L85]N=/T@66%R870N+BX`36%L879I
M`$UA;&5Z>6$`36%L9&EV;&5R`$UA;&D`36%L=&$`UO!E;&5R:2!E=&EK971L
M97EE8V7P:6YI>B!K871E9V]R:2!L:7-T97-I;FD@=F4@:V%T96=O<FEL97)I
M(&EL:?YK:6QE;F1I<F5C9?!I;FEZ(')E;FML97)I('GV;F5T:6XN`$UA<#(T
M(&AA<FET87/]`$UA<%%U97-T(&AA<FET87/]`-UL971I>6D@<VEL:6YE8V5?
M:R!O;&%R86L@:?YA<F5T;&4`36%R=`!+96YA<B!B;_YL=?!U`-UL971I>6D@
M:?YA<F5T;&4Z`$]K=6YM=?XO3VMU;FUA;?W^(&]L87)A:R!I_F%R971L90!$
M:?!E<B!I;&5T:2!I_F%R971L97)I>6QE(&G^87)E=&QE("CV<FYE:SH@UFYE
M;6QI+T-E=F%P;&%N;?W^*2``36%R<VAA;&P@061A;&%R_0!-87)T:6YI:P!%
M_FQE_F5N`$7^;&5L96X@86QA;FQA<@!-;W)I=&%N>6$`36%U<FET=7,`W7II
M;B!V97)I;&5N(&5N('G\:W-E:R!K<F5D:2X`16X@>?QK<V5K(&UE<V%J('!A
M<N=A<_T@<V%Y_7/](&'^_6QD_2X`4V]N(#(T('-A871T96MI(&5N('G\:W-E
M:R!S_6-A:VS]:SH@`%-O;B`V('-A871T96MI(&5N('G\:W-E:R!S_6-A:VS]
M:SH@`$5N('G\:W-E:R!U>G5N;'5K`$5N('G\:W-E:R!K87)A;&ES=&4@861R
M97,@<V%Y_7/](&'^_6QD_2A4;W!L86T@861R97-L97(Z("5S+"!%;B!Y_&MS
M96L@861R97,@<V%Y_7/].B`E<RDN($MA<F%L:7-T97EE('EE;FD@8FER(&%D
M<F5S(&5K;&5Y96UE>G-I;FEZ+@!%;B!Y_&MS96L@=&5M:7H@861R97,@<V%Y
M_7/](&'^_6QD_2A4;W!L86T@861R97-L97(Z("5S+"!%;B!Y_&MS96L@861R
M97,@<V%Y_7/].B`E<RDN(%1E;6EZ(&QI<W1E<VEN92!Y96YI(&)I<B!A9')E
M<R!E:VQE>65M97IS:6YI>BX`36%Y_7,`36%Y;W1T90!4_7``W'EE;&5R`$UE
M;OP@2VEP:3H`2/QC<F5L97)I(&)I<FQE_G1I<@#=;&5T:0#=;&5R:2!B8?YA
M<OUY;&$@9&_P<G5L86YD_2!A;6$@:6UZ86QA>?UC_6[];B!O;F%Y(&)E;&=E
M<VD@9&_P<G5L86YA;6%D_2X`365S86K];B!S_')E<VD@8FET=&DN`$UE<V%J
M('1I<&D`2&%V82!287!O<G4`2&%V82!R87!O<G4@]F)E\&D@:W5L;&%N_6QA
M8FEL:7(@9&7P:6PN`$AA=F$@<F%P;W)U(/9B9?!I(&MU;&QA;OUL86)I;&ER
M(&1E\&EL+B!!>7+];G3];&%R('GV;F5T:6-I(&GG:6X@9_QN;/QK;&5N9&D`
M6?9N=&5M`$UE=')I:P!-96MS:6MA`$UI:W)O;F5S>6$`3W)T80!-:6UE(%3\
M<OP`4V]N(#(T('-A871T96MI(&5N(&3\_OQK('/]8V%K;/UK.B``4V]N(#8@
M<V%A='1E:VD@96X@9/S^_&L@<_UC86ML_6LZ(`!986YS_0!-=6AT96QI9@!"
M=6QU;F%M87EA;B!014%2('!A:V5T:3H@2%144%]297%U97-T+@#=;&5T:6YI
M;B!Y]FYL96YD:7)I;&5C9?!I(&%D<F5S(&5K<VEK`$%T;&%N;?W^('EA</UL
M86YD_7)M82X@0G4@=7EG=6QA;6%Y_2!K=6QL86YM86L@:7-T:7EO<G-A;OUZ
M('EA</UL86YD_7)M87G](/QR971M96L@>F]R=6YD87/];OUZ+@!!=&QA;FW]
M_B!M97-A:B!)1"X`1V5R:2#G979I<FUE('-E8F5B:2!E:W-I:P!4871I;"!S
M96)E8FD@96MS:6LN`$%T;&%N;?W^(&]L86X@9V5R96ML:2!014%2('!A:V5T
M:2!-86EL+@!!=&QA;FW]_B!O='5R=6UA(&%I="!)1"X`4'IT`$=E>FEC:2!0
M;W-T80!386MI;@!$9?!I_FEM(%1A<FEH:0!$9?!I_G1I<CI54DP`36]D(%1A
M8F%N_0!-;VQD;W9Y80!-;VYA8V\`36_P;VQI<W1A;@!!>2!V92!Y_6P`07EL
M_6L`36]N='-E<G)A=`!!>2!%=G)E;&5R:0!&87,`1V5N96QL:6ML92!!Y_UK
M`$=E;F5L;&EK;&4@0G5L=71L=0!'96YE;&QI:VQE($?\;F7^;&D`5&'^_0!!
M_F'P_2!48?[]`%-O;&$@5&'^_0!38?!A(%1A_OT`2W5R86S]($'^8?#](%1A
M_OT`2W5R86S](%EU:V%R_2!48?[]`%EU:V%R_2!48?[]`$'^8?#]('1A_OT`
M675K87+]('1A_OT`36]Z86UB:6L`QV]K;'4@9/QZ97D@8?YA\/T@8>?];/UR
M(&QI<W1E;&5R`,=O:VQU(%-EYVEM`$AE<V%B_6T`4&]R=&%L_6T`4&]R=&%L
M($3\>F5N:6T`37EA;FUA<@!+86)U;"!%5$U)64]254T`5&%T:6P@8V5V87!L
M87+](&%R87/];F1A:VD@9_Q?;B!S87G]<_T`060`3F%M:6)Y80!.875R=0!.
M97!A;`!(;VQL86YD80!(;VQL86YD82!!;G1I;&QE<FD`3F5T<V-A<&4@5&%B
M86X@55),`$YE='-C87!E($-!(-UP=&%L(%523`!.971S8V%P92!#02!K=7)A
M;"!54DP`3F5T<V-A<&4@665N:6QE;64@4DP`3F5T<V-A<&4@W7!T86P@55),
M`$YE='-C87!E(%-33"!S=6YU8W4@863]`$YE='-C87!E(&]N87D@8F5L9V5S
M:2!AY_UK;&%M87/]`$YE='-C87!E(&]N87D@8F5L9V5S:2!T_'+\`$'P`$%S
M;&$`665N:2!+86QE9&]N>6$`665N:2!+871E9V]R:0!996YI($%Y`%EE;FD@
M2W5R86P`665N:2!+=6QL86[]8_T@063]("A39>=I;6QI*0!996YI(%IE;&QA
M;F1A`%EE;FD@4&5N8V5R92`H7V)O_BD`2&%B97)L97(`2&%B97(@1W)U<&QA
M<OT`4V]N<F%K:0!3;VYR86MI(%-EYV5N96ML97(`3FEK87)A9W5A`$YI:F5R
M>6$`3FEJ97)Y80!'96-E`$YI=64`2&%Y_7(`)R5S)R#V\&5S:2!S;VX@>6%P
M_6QA;OW^=&$@8G5L=6YA;6%D_2X`1F%R:VQA<OUN(&?V<W1E<FEL96)I;&5C
M9?!I(&MU;&QA;OUL86)I;&ER('EA</UL86YD_7)M82!V97)I<VD@>6]K+@!)
M4T\@:6UA:FQA<OT@;W7^='5R;6%K(&GG:6X@:W5L;&%N_6QA8FEL:7(@8FER
M('GV;G1E;2!Y;VLN`$)U(&%N87-I<W1E;2!IYVEN('-O;B!Y87#];&%N_?X@
M96MS:6L`8F%C:V5N9',N<&AP(&1O<WEA<_UN9&$@<V]N('7G('EA</UL86[]
M_OT@>6]K`%G]\/UN('1A<VQA\/T@>6]K+@#=<W1E;F5N(&MO;G5M9&$@:&GG
M8FER(/9B96L@8G5L=6YM86UA:W1A9/UR`$U#04P@9&_P<G5L86UA<_T@:>=I
M;B!H:>=B:7(@=&%K=FEM(&%D_2!S8?!L86YM86W]_G3]<BX@`$1E\&G^:6ML
M:6L@66]K`$)U(&EZ;F4@:&GG8FER(&%L="!I>FEN(&5K;&5N96UE>65C96MT
M:7(N`"5S(&GG:6X@:&GG8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER
M=&EL;65D:2X`1E10(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL
M9VES:2!B96QI<G1I;&UE9&DN`%-13"!61E,@:>=I;B!H:>=B:7(@>6%P_6QA
M;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+@!344PM1FEL92!61E,@:>=I
M;B!H:>=B:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+@!+
M<F5D:2!Y;VLN`$AIYV)I<B!T97-L:6T@;F]K=&%S_2!B96QI<G1I;&UE;6G^
M=&ER+@!(:>=B:7(@9&]S>6$@>?QK;&5N96UE9&D`4_QZ9V7G('EO:RY987)A
M=&UA:R!IYVEN("<E<R=T_6ML87G];BX`0F'^;/UK(&)I;&=I<VD@8F5L:7)T
M:6QM961I`$AIYV)I<B!S:6UG92!B=6QU;F%M863]+@!(:>=B:7(@>65R(&)E
M;&ER=&EL;65D:2X`2&GG8FER(&UE<V%J('-A\&QA;FUA9/TN`$%D(&)E;&ER
M=&EL;65D:2X`3G5M87)A(&)E;&ER=&EL;65D:2X`4V%L9/UR9V%N(&1E>6G^
M(&MU;&QA;FUA`$A45%`@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM
M961I+@!)34%0(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2X`
M2V5R8F5R;W,@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+@!,
M;V=I;B!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G:7)I;&UE9&DN`%!!4U-7
M1"!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G:7)I;&UE9&DN`%--0B!D;_!R
M=6QA;6%S_2!IYVEN('!A<F]L82!G:7)I;&UE9&DN`$]P96Y34TP@:6MI;&ES
M:6YE(&AIYV)I<B!Y;VP@8G5L=6YA;6%D_2Y/<&5N4U-,(&EK:6QI<VD@4$M#
M4R`Q,B!V97)I<VEY;&4@8V%L_?YM86L@:>=I;B!G97)E:VQI+@#<>64@;VQM
M86L@:>=I;B!B96ML97EE;B!Y;VLN`$MU<F%L('EO:P!"971I:R!Y87)A=/UL
M;6%D_2X`66%N('EO:P!$:7IG:2`@8F5L:7)T:6QM961I+@#6;F)E;&QE:R!I
MYVEN(&=EYVEC:2!D:7II;B!B=6QU;F%M863]+@!+=6QL86[]8_T@863]('9E
M+W9E>6$@<&%R;VQA(&?V;F1E<FEL;65D:2X`1V7G97)L:2!834P@=F5R:7-I
M(&=E<FD@9/9N;65D:2X`1&7P97(@>6]K`-9Z9_QN('EA</UL86YD_7)M861A
M('/\<OQM(&)U;'5N86UA9/TN66%P_6QA;F3]<FUA>?T@=&5K<F%R(/QR971I
M;BX`UGIG_&X@>6%P_6QA;F3]<FUA;OUZ9&$@<_QR_&T@8G5L=6YA;6%D_2Y9
M87#];&%N9/UR;6%Y_2!T96MR87(@_')E=&EN+@!(:>=B:7)I`$AIYV)I<FD@
M*-9R=/QL_"!K=6QL86[];BD`2W5Z97D@079R=7!A;/T@*$E33RTX.#4Y+3$P
M*0!.;W)F;VQK($%D87/]`$MU>F5Y(%EA<OUM:_QR90!+=7IE>2!-87)I86YA
M($%D86QA<OT`3F]R=F7G`%-O;G)A<_UN9&$@1&7P:6P`UFYC97-I;F1E($1E
M\&EL`$1I>FEN(&1E\&EL`$7^:70@9&7P:6P`1V5RYV5K;&7^=&ER:6QM96UI
M_@!"96QI<G1I;&UE;6G^`$1E<W1E:VQE;FUI>6]R+@!.;W1L87(`1_9Z(&%T
M_6QA8V%K(&)I<OYE>2!Y;VLL(&=E<FD@9/9N_&XN`$MA<_UM`%-A>?T`2V%R
M86MT97(@<V%Y_7/]`$MO;&]N('-A>?US_0!3873]<B!S87G]<_T`1&'P_73]
M;2!L:7-T96QE<FEN:6X@9_QN8V5L;&5N;65S:2!IYVEN(&YU;6%R86QA<B!B
M96QI<G1I;&UE;6G^+@!%=F5T`$YE<VYE`$YE<VYE(%EA<F%T_6/]<_T`4V5K
M:7IL:6L@4VES=&5M`$5K:6T`4V%L9/UR9V%N;/UK('/\>F=E8VD`3V9I<P!5
M;6UA;@!3861E8V4@24U!4"!S=6YU8W5L87+]('!A>6QA_OUL86X@9&EZ:6YL
M97)I(&1E<W1E:VQE;65K=&5D:7(N`%-A9&5C92!S86QD_7)G86X@9&5Y:?YL
M97(`4V%D96-E(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:6YE(&EZ:6X@
M=F5R:6QM96MT961I<BX`0FER('!A>6QA_OUM_6X@<V%H:7!L:?!I;FD@=F5Y
M82!S86AI8FEN:2!S861E8V4@<VES>65M('GV;F5T:6-I<VD@=F5Y82!S86AI
M8FD@9&7P:?YT:7)E8FEL:7(N`%EE;FD@<&5N8V5R961E(&'G`$]P96Y34TP@
M:&%T87/].MUM>F%L86YM_?X@4R]-24U%('!A<N=A<_UN9&%N('9E<FD@<V7G
M:7`@Y_UK873];&%M863]+@!"=2!B8?!L86YT_7G]('EE;FD@<&5N8V5R961E
M(&'G`-W^;&5T:6T@4VES=&5M:0!39>=E;F5K;&5R`$)E=&EK(&?\;F-E;&QE
M;64@<V7G96YE:VQE<FDN`"5S(&GG:6X@<V7G96YE:VQE<@!3_7)A;&%N;?W^
M($QI<W1E`$MU<G5L=?X`2W5R=6US86P@0FER:6T`1/QZ96YL96UE`-9Z9_QN
M('5Y9W5L86UA('1A<VQA\/T`)7,@:>=I;F1E:VD@]GIG_&X@=&%S;&%K;&%R
M.@!$:?!E<@!$:?!E<B!":6QG:6QE<@!$:?!E<B!S9>=E;F5K;&5R:0!386AI
M<"!I>FEN;&5R:0!004T@9&_P<G5L86UA<_T@;65V8W5T(&1E\&EL+@!01U`@
M4V%Y_7-A;"#=;7IA`%!'4"#>:69R96QE;FUI_B!697)I`%!'4"!!Y_UK($%N
M86AT87+]`%!'4"!I;&4@W6UZ86QA;FW]_B_>:69R96QE;FUI_B!697)I`%!(
M4"!+;V1U`%!(4"!+86)U\'4`UE,@2&%F:68@66'P;75R`-93(%-A\&%N86ML
M87+]`-93($MA<@#64R!+87(@4V'P86YA:VQA<OT`UE,@1_9K(&?\<OQL=/QL
M_"!F_7)T_6YA`%!?2%`@2V%B=?!U`%EA<W3]:VQA;6$`4&%K:7-T86X`4&%L
M874`W?YG86P@161I;&UI_B!&:6QI<W1I;B!"]FQG97-I`%!A;F%M80!087!U
M82!996YI($=I;F4`4&%R86=U87D`2_US;65N($)U;'5T;'4`4&%R;VQA`%EA
M;FS]_B!P87)O;&$`4D%$2553(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=E
M<F5K;65K=&5D:7(N`$]N87EL_2!087)O;&$`4&%R;VQA.@!087)O;&$Z`%!A
M<F]L86QA<B!E_FQE_FUE:R!Z;W)U;F1A9/UR+@!987#]_G3]<@!086YO9&%N
M('EA</W^=/UR`%EO;`!"96ML97EE;B#<>65L:6ML97(Z`-UN<V%N;&%R`%G\
M>F1E`$)A:_UM(-W^;&5M;&5R:6YI($=E<N=E:VQE_G1I<@!"86O];2!I_FQE
M;6QE<FD@9VER:?YT92!G97+G96ML9?YT:7)I;'-I;B!M:3\`W7II;@#=>FEN
M(%GV;F5T:6UI`$MI_FES96P@0FEL9VEL97(`4&5R=0!%=F-I;"!(87EV86YL
M87(`1FEL:7!I;FQE<@!496QE9F]N`$9O=&_P<F%F;&%R`%!I=&-A:7)N`%)E
M<VEM($)I<FEM:0!"97EL:6L@4_9Z;&5R`$S\=&9E;B!B:7)K8><@:/QC<F5Y
M92!T_6ML87G];@!,_'1F96X@8G4@]O!E>6D@Y_UK87)M86L@:7-T961I\&EN
M:7II(&1O\')U;&%Y_6XZ`$S\=&9E;B!B=2#V\&5N:6X@8F'P_6[](.?V>FUE
M:R!I<W1E9&GP:6YI>B!D;_!R=6QA>?UN+@!,_'1F96X@8FER(&%Y('9E(&)I
M<B!Y_6P@9VER:6XN`$S\=&9E;B!Y96YI(&MA=&5G;W)I;FEN(&%D_6[](&=I
M<FEN.@!,_'1F96X@9V7G97)L:2!B:7(@25`@861R97-I(&=I<FEN+@!,_'1F
M96X@9V7G97)L:2!B:7(@9_QN(&=I<FEN+"!A>61A:VD@9_QN('-A>?US_6[]
M(&MO;G1R;VP@961I;BX`3/QT9F5N(&=EYV5R;&D@8FER('IA;6%N(&=I<FEN
M+@!,_'1F96X@>65N:2!D:7II;FEN(&%D_6[](&=I<FEN.@!,_'1F96X@<V]R
M=6YU;B!B:7(@]GIE=&EN:2!Y87#];BX`3/QT9F5N(&MU;&QA;OUC_2!A9/T@
M=F4@<&%R;VQA;OUZ_2!G:7)I;@!,_'1F96X@>65N:2!K871E9V]R:6YI(&%D
M_2!G:7)I;CH`4&]L;VYY80!0;VQI=&EK80!/>6QA;6%L87(`4&]R=&5K:7H`
M1_9R_&YT_"!K;VYU;6QA;F3]<OUL_7EO<@#':7IE;&=E(&MO;G5M;&%N9/UR
M_6S]>6]R`$)U(&1I>FEN92!G]FYD97(@*$E-05`@=&%R86;];F1A;B!Z;W)L
M86YM86UA:W1A9/UR*0!3;VX@)7,@<V%A='1E(&3\_F5N('EA\&UU<B!V92!K
M87(@;6EK=&%R_3H`4')E9G-?;&1A<#H@W7-T96YE;B!,1$%0('5Z86YT_7/]
M(&)U;'5N86UA9/TN`%!R969S7W-E<W-I;VXZ(-US=&5N96X@;W1U<G5M('5Z
M86YT_7/](&)U;'5N86UA9/TN`$)A<_UNYP!$96YI>B!S979I>65S:6YD96MI
M(&)A<_UNYSH`0F%S_6[G.@#6;FEZ;&5M90!']G+\;G3\>?P@>65N:2!P96YC
M97)E9&4@]FYI>FQE`-9N8V5K:2!S9>=E;F5K;&5R`$)E;&=E>6D@>6%Z9/UR
M`-9Z96P@06YA:'1A<@!3;W)U;@!3;W)U;B!486[];6QA;6%S_0!0<F]J96QE
M<@!-971I;B!B:6QG:2!I<W1E;6D`0>?]:R!!;F%H=&%R`$'G_6L@06YA:'1A
M<B!A;&=O<FET;6%S_0!!Y_UK+]9Z96P@86YA:'1A<B!I:VEL:7-I(&)A_F%R
M_7EL82!Y87)A=/UL86UA9/TN`%!O<G1O(%)I:V\`2V%T87(`4V]R9W4`4E-!
M($'G_6L@06YA:'1A<OT@*"5D(&)I="D`1V5R96OG90!2861Y;R!39>=I;6D`
M66'P;75R`$5R:V5N(%-A871L97)D92!98?!M=7(`1V7G(%-A871L97)D92!9
M8?!M=7(`4V'P86YA:R!98?#]_@!98?!M=7(@=F4@2V%R`$MA<F$@9/9N_/YE
M8V5K('EA\&UU<@!287-T9V5L92!$97EI_@!/<F%N`$]K=6UA`-UL971I;&5R
M:2!/:W4`4VEL;65K(&ES=&5D:?!I;FEZ92!G97+G96MT96X@96UI;B!M:7-I
M;FEZ/RA"=2!I_FQE;2!G97)I(.=E=G)I;&5M97HI.B5S`$MU;&QA;OUC_2`E
M<R!E(&%I="!K=6QL86[]8_T@=F5R:6QE<FEN:2!S:6QM96L@:7-T961I\&EN
M:7IE(&5M:6X@;6ES:6YI>BX@0G4@:?YL96T@9V5R:2#G979R:6QE;65Z+@!5
M;&'^=/T`6?9N;&5N9&ER`%-O;B!E>6QE;6D@=&5K<F%R;&$`1&5V:6YG96X@
M365N_"#6\&5L97)I;FD@5&%Z96QE.@!0;W)T86P@1_9R_&[\;?QN_"!487IE
M;&4Z`$3\>F5N;&D@W69A9&4`1/QZ96YL:2#=9F%D96QE<@!'97)E:^=E>6QE
M(')E9&1E=`#=;&G^:VD@5&%R87G]8_T`0>?]:VQA;6%L87(`57IA:W1A:VD@
M4W5N=6-U;&%R`%5Z86MT86MI(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%-I;`#68F7P:2!3:6P`2V]L;VYU(%-I;`!":>=I;6QE;65Y
M:2!3:6P`26MI;&EY:2!3:6P`2V%Y9&5D:6QM:?X@8F5T:?!I('-U;G5C=6YU
M(&=EYVEC:2!D:7II;FEN9&5N('-I;"X`4VEL`$)U('!A<N=A>?T@8F5L9V5D
M96X@Y_UK87)T`$MU;&QA;OUC_2!3:6P`2W5L;&%N_6/]>?T@<VEL.B`E<P#=
M<W1E:R!C979A<&QA;F%M863]+D3V;OQL96X@:&%T82!K;V1U.B``1V5R96ME
M;B!!;&%N`%EE;FED96X@1_9N9&5R`%EE;FED96X@1_9N9&5R:6QE;@!496UI
M>FQE`%!A<F]L87G]('/]9OUR;&$`4&%R;VQA;OUZ_2!S_6;]<FQA>?UN`%-O
M;G7G;&%R`%/\>F=EYR!,:7-T97-I;F4@1V5R:2!$]FX`4V7G96YE:VQE<F4@
M1/9N_&X`2W5R86QL87(@3&ES=&5S:6YE($=E<FD@1/9N`%)E=6YI;VX`66%P
M_6QA;F3]<FUA>?T@1V5R:2!$]FYD_'(`6F5N9VEN($UE=&EN($3\>F5N;&5Y
M:6-I<VD@4V7G96YE:VQE<FD`0FEL;65C96QE<@!38?``4V'P(&)A_FS]:R!B
M:6QG:7-I`$1O\')U(&1E\&5R;&5R`%-A7W3]<B#6>F5L;&EK;&5R:2XN+@!'
M]G)E=@!2;VUA;GEA`#$X,"!D97)E8V4@9/9N9/QR`%-O;&$@1/9N9/QR`%-A
M\&$@1/9N9/QR`%-A=/UR(-9Z96QL:6ML97)I`%-A=/UR(/9Z96QL:6ML97)I
M`%-A=/UR;&%R.@!+=7)A;`!+=7)A;"!+;W!Y86QA;F3]`$MU<F%L(%-I;&EN
M9&D`2W5R86P@1V7G97)S:7H@2_UL_6YD_0!+=7)A;"!'9>=E<FQI($O];/UN
M9/T`2W5R86P@063]`,=I>F=I;&5R`,=I>F=I;&5R('3\;2!S873]<B!V92!K
M;VQO;FQA<B!A<F%S_6YD82!B96QI<F5C96MT:7(`QVEZ9VEL97(@<V%D96-E
M(&MO;&]N;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<@#':7IG:6QE<B!S861E
M8V4@<V%T_7)L87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER`,=A;/W^=/UR`%)U
M<WEA($9E9&5R87-Y;VYU`%)U86YD80!3+TU)344@WFEF<F5L96UE(-UM>F%S
M_0!3+TU)344@:6QE(-YI9G)E;&5N;6G^(-UL971I`%-!4TP@9&_P<G5L86UA
M<_T@;65V8W5T(&1E\&EL+@!335,@365S86IL8?YM80!344P@2V%B=?!U`%-3
M2`!"0=Y!4DE,20!37U%,($MA8G7P=0!#=',`4V%I;G0@2&5L96YA`%-A:6YT
M($MI='1S('9E($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!V92!-
M:7%U96QO;@!386EN="!6:6YC96YT('9E($=R96YA9&EN97,`07EN_2#G97+G
M979E("AK96Y?9&ES:2D`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!V92!0
M<FEN8VEP90!5>61U(%-A\&QA>?UC_0!3=75D:2!!<F%B:7-T86X`2V%Y9&5T
M`$MA>61E="`E<P!39>=E;F5K;&5R:2!+87ED970`07EA<FQA<OT@2V%Y9&5T
M`$]L=?YT=7)U;&%N('EA</UL86YD_7)M87G](%!(4"!B971I\&D@;VQA<F%K
M('-U;G5C=6YU;B!G9>=I8VD@9&EZ:6YI;F4@:V%Y9&5T+@`E<R!Y87#];&%N
M9/UR;6%S_2!K87ED961I;&1I+@!":6QI;0!"971I:P!"971I:R!'_&YC96QL
M96YI>6]R`$)E=&EK($?\;F-E;&QE;FUE9&DN`$)E=&EK(&)A_F%R_7EL82!E
M=&MI;FQE_G1I<FEL9&DN`$)E=&GP:6X@971K:6YL:?!I(&)A_F%R_7EL82!K
M86QD_7+];&3]+@!!<F%M80!!<F%M82!-;W1O<FQA<OT`1_9R_&QM_/X`1&]S
M>6%L87+](%-EYP!":7(@=&%R:6@@<V7G:6X`0FER(&%L86X@<V7G:6X`16ML
M96UE:R!IYVEN(&)I<B!G<G5P('-EYVEN`%EE;FD@<V%H:6)I('-EYVEN`$)I
M<B!S=6YU8W4@<V7G:6X`16ML96UE:R!IYVEN(&)I<B!K=6QL86[]8_T@<V7G
M:6X`0OQT_&X@=&%R:6@@8FEL9?YE;FQE<FEN:2!S9>=I;@!":7(@;F5S;F4@
M<V7G:6X`0FER(&AE9&5F(&1I>FEN('-EYVEN`-US=&5D:?!N:7H@:V%R86MT
M97)L97)I(&'^8?#]9&%K:2!K=71U;&%R9&%N('-EYVEN+B!$86AA('-O;G)A
M(&UE=&EN(&%L86[];F1A;B!K;W!Y86QA>?UP('EA</W^=/UR86)I;&ER<VEN
M:7HN`%1A<FEH('/];OUR;&%Y_6/]<_UN_2!S9>?];CH`5&%R:6@@8FGG:6UI
M;FD@<V7G:6XZ`$1E\&G^=&ER;65K(&ES=&5D:?!I;FEZ(&MI;6QI\&D@<V7G
M:6XZ`%-A870@<_UN_7)L87G]8_US_6[]('-EYVEN.@!386%T(&)IYVEM:6YI
M('-EYVEN.@!%_FQE_F5N(&EK:2!A;&%N_2!S9>=I;BX`4F5N:R!D_'IE;FEN
M:7II('-EYVEN+@!497)C:6@@971T:?!I;FEZ(&1I;&D@<V7G:6XZ`$ME;F1I
M;F1E;B!486[];6S]($)A_FS]:R!":6QG:7-I`%-O<G5N(%)A<&]R=2!']FYD
M97(`4TU3($?V;F1E<@!']FYD97)E;@!396YE9V%L`$%L9_UL87G]8_TZ`$5Y
M;/QL`%/]<F)I<W1A;B!V92!-;VYT96YE9W)O`%-E<FD@3G5M87)A<_T`3W1U
M<G5M(&MI;6QI\&EN:6X@<_QR97-I(&1O;&1U+@!"96QI<G0`4&%R;VQA;OUZ
M_6[]('5N=71U<G-A;OUZ('/]9OUR;&%M86[]>F$@:7II;B!V97)E8V5K('-E
MYV5N96ML97)I(&)E;&ER=&EN+B``56QA_FUA:R!I<W1E\&EN:7H@=7IA:W1A
M:VD@<W5N=6-U;&%R_2!B96QI<FQE>6EN+@!497)C:6@@971T:?!I;FEZ(&1I
M;"P@<V%A="!D:6QI;6D@=F4@=&%R:6@@<V7G96YE:VQE<FEN:2!B96QI<FQE
M>6EN+@!"8?YL86YG_><@=7EG=6QA;6%N_7K]+"!R96YK(&3\>F5N:6YI>FDL
M('-A>69A('1A>F5L96UE+"!V92!D:?!E<B!G]G+\;G3\('-EYV5N96ML97)I
M;FD@8F5L:7)L97EI;BX`07EA<FQA<B!B8?YA<OUY;&$@9_QN8V5L;&5N9&DN
M`$%Y87)L87(`2W5R=6QU;2!G_&YC96QL96UE(&)E=&EK;&5R:2!K=6QL86[]
M;&%B:6QI<B!D=7)U;61A+@!$9?!I_G1I<F=E(&EL92!B:7)D96X@9F%Z;&$@
M>65R(&W\;6O\;CH@`%-E>?YE;`!!;/W^('9E<FG^`$O]<V$@UGIE=`#';_!U
M(&)A\&QA;G3](&GG:6X@97)I_FEM(&%N86AT87+]('1A;OUM;&%N<_UN(&W]
M/P!']G-T97(`171K:6X@0F5T:?!I($?V<W1E<@!9_'+\<FS\:W1E:VD@0F5T
M:?!I($?V<W1E<@!(86QE;B!K87G]=&S](&]L86X@>6%P_6QA;F3]<FUA(&EL
M92!Y96YI('EA<F%T_6QA;B!Y87#];&%N9/UR;6$@87)A<_UN9&%K:2!F87)K
M;&%R_2!G]G-T97(N`$=I<FG^=&4@96X@<V]N(&=I<FG^('1A<FEH:2!G]G-T
M97)I;'-I;B!M:3\`UGIG_&X@;VQA;OT@<V%K;&%M82!S9>=E;F7P:6YI(&?V
M<W1E<@!39>=I8VEY:2!G]G-T97(`QVEZ96QG92!I_FQE;6QE<FD@;65N_"#G
M=6)U\'5N9&$@9_9S=&5R:6QS:6X@;6D_`"5S($UE;OQS_"!S;VQD82!G]G-T
M97)I;'-I;B!M:3\`5&%B;&\@2/QC<F4@UGIE;&QI:VQE<FD@2W5T=7-U;G4@
M9_9S=&5R`%1A8FQO(-9Z96QL:6ML97)I($MU='5S=6YU(&?V<W1E<@!486)L
M;R!3873]<B#6>F5L;&EK;&5R:2!+=71U<W5N=2!G]G-T97(`1_9R_&YT_"#V
M>F5L;&EK;&5R:2!K=71U<W5N=2!G]G-T97(`6?QK;&5M97EI(&?V<W1E<@!3
M8?!A;F%K`$5R:V5N(%-A871L97)D92!38?!A;F%K`$=EYR!386%T;&5R9&4@
M4V'P86YA:P#'979R961E(%-A\&%N86L`2_SG_&QT`-UL:R!O;&%R86L@:V]M
M_G4@]O!E;&5R(&O\Y_QL='/\;B!Y861A('1A_OUN<_UN`%-I97)R82!,96]N
M90#<>64@;VP`W6UZ80#=;7IA($%L9V]R:71M87/]`%-I;F=A<'5R`$)O>75T
M`$)A:_UM_2!!=&QA`%-L;W9A:WEA`%-L;W9E;GEA`$MA<@!+87(@4V'P86YA
M\/T`2V%R(%-A\&%N86ML87+]`$5R:V5N(%-A871L97)D92!+87(@4V'P86YA
M:VQA<OT`1V7G(%-A871L97)D92!+87(@4V'P86YA:VQA<OT`2V%R($1E<FEN
M;&GP:3H@`%EA\&%N(&MA<OUN('-U(&7^:71I.B``4V]L;VUO;B!!9&%L87+]
M`%-O;6%L:0#>87)K_6QA<B`F(-YI:7)L97(`4_UR86QA;6$@9/QZ96YI('-E
MYVEM:0!+87EN86L@861R97-I`$?\;F5Y($%F<FEK80!'_&YE>2!!=G)U<&$@
M*$E33RTX.#4Y+3,I`$?\;F5Y($=E;W)G:6$@=F4@1_QN97D@4V%N9'=I8V@@
M061A;&%R_0!'_&YE>2!987+];6O\<F4`0FET:?YI:R!H_&-R96QE<B!A<F%S
M_6YD86MI(&)O_FQU:P!(_&-R961E:VD@<_UN_7(@=F4@:>=E<FEK(&%R87/]
M;F1A:VD@8F_^;'5K`$)O_FQU:R!!>6%R;&%Y_6/]`$%R86S]:R!B_7)A:VUA
M`$%R86S]:R!B_7)A:VUA('9E('EA<W3]:VQA;6$`W7-P86YY80#=<W1E;FUE
M>65N(-UL971I`-9Z96P@2V%R86MT97(@1VER:?YI`$C\8W)E>6D@8O9L`$MO
M;&]N=2!B]FP`4V%T_7+](&+V;`!3<&]R;&%R`%-R:2!,86YK80!3=&%N9&%R
M=`!5>F%Y(%EO;'4`0F'^;&%N9_WG('G];/T`17EA;&5T('9E>6$@W6P`1'5R
M=6T`0G4@:W5R86P@9?YL9?YI<@!$97!O;&%M82!B:>=I;6D`4V]K86L@061R
M97-I`-QS=/P@YVEZ9VEL:0!$:7IG:2!L:7-T97-I`$%D<F5S=&5N(&%L86X@
M863];OT@Y_UK87)T`%-I=&EL(%M#4U-=`%!Z<@!4871I;"!M97-A:OUN_6X@
M2V]N7W5S=3H`2V]N=0!']FYD97(`06QT<VEM9V4`0F'^87+]`%EA</UL86YD
M_7)M82!B8?YA<OUY;&$@9V5R:2!D]FYD_'+\;&3\+B!$9?!I_FEK;&EK;&5R
M:2!G]G)M96L@:>=I;B!Y96YI9&5N('G\:VQE>6EN+@!9961E:R!Y87#];&%N
M9/UR;6$@8F'^87+]>6QA(&MA>61E9&EL9&DN`%EE9&5K('EA</UL86YD_7)M
M82!D;W-Y87/]("5S(&)A_F%R_7EL82!K87ED961I;&1I+@`E<R!B8?YA<OUY
M;&$@>6%Z_6QD_2X`4W5D86X`UGIE=`!'_&X@1&_P=6UU`$?\;B!B873];?T`
M1_QN9?YL:0!'_&X@9&_P=6UU`$?\;B!D;_!U;74O1_QN(&)A=/UM_0!'_&X@
M9&_P=6UU.B``1_QN(&)A=/UM_0!'_&X@8F%T_6W].B``W'-T<VEM9V4`1&5S
M=&5K`%-U<FEN86T`4V]Y863]`%-V86QB87)D('9E($IA;B!-87EE;@!3=F%Z
M:6QA;F0`W7-V9><`W7-V:>=R90!!<F%M82!T97)I;6QE<FEN9&4@<_9Z9&EZ
M:6T@:&%T87/]`%-U<FEY90!']FL@9_QR_&QT_&S\(&;]<G3];F$`1_9K(&?\
M<OQL=/QL_"!F_7)T_6YA;&%R`%135B!D;W-Y87/]`,=I>F5L9V4`QTEZ96QG
M92#6>F5L;&EK;&5R:0#':7IE;&=E(/9Z96QL:6ML97)I`%1A>79A;@!487EV
M86XL(,=I;B!E>6%L971I`%1A8VEK:7-T86X`5&%N>F%N>6$`2&5D968Z`$?V
M<F5V;&5R`%1E;&5F;VX@3G5M87)A<_T`4V]N('-A870@:>=I;B!S_6-A:VS]
M:SH@`%/]8V%K;/UK`%/]8V%K;/UK.B``5&%S;&%K(%GV;F5T:6UI`$UE=&EN
M`%-A9&5C92!-971I;@!-971I;B!H:7IA;&%M87/]`$UE=&YI;B#<<W3\`%!R
M_@!486D@*%1)4RTV,C`I`%1A>6QA;F0`4VES=&5M:2!K=6QL86[]9/WP_6[]
M>B!IYVEN('1E_F5K:_QR(&5D97)I>BX`1E10('5Z86YT_7/](&MU;&QA;OUL
M86)I;&ER(&1U<G5M9&$@9&7P:6PN`$AO<F1E+TMO;&%B(&+\=/QN;&7^=&ER
M;64@;6]T;W)U(&1E<W1E:VQE;65M96MT961I<CH@(B5S(@!"86O];3HZ('/]
M;OUF(&)A_F%R_7EL82!Y_&ML96YE;65D:2X`WF7G96YE:VQE<B!P96YC97)E
M<VD@:V%P86YD_2['_6O]_B!Y87#];/UY;W(N`$7P97(@:7II;FQE<FD@:W5L
M;&%N;6%K(&ES=&EY;W)S86[]>B!Y]FYE=&EC:6YI>FEN(-UZ:6X@<VES=&5M
M:6YI('EA</UL86YD_7)M87/](&=E<F5K;65K=&5D:7(N`%-A9&5C92!A;'0@
M=&%R868`W6QE=&G^:6T@;F]K=&%S_6[];B!)1"=S:2!B96QI<FQE;F5M961I
M+"!B;_X@8OUR86O];&W]_B!V97EA('9E<FD@=&%B86[];F1A(&)U;'5N86UA
M9/TN`-UL971I_FEM(&YO:W1A<_T@8F'^87+]>6QA(&%D<F5S(&1E9G1E<FEN
M:7IE(&5K;&5N9&DN`,?]:V%R=/UL;?W^(%!'4"!I;7IA(/9B9?!I(&EM>F%L
M86YM_?X@:6QE=&EN:6X@9&_P<G5L=?!U;G5N('-A\&QA;FUA<_T@:>=I;B!G
M97)E:VUE:W1E9&ER+@!$8?#]=/UM(&QI<W1E<VD@240G<VD@8F5L:7)L96YE
M;65D:2P@8F_^(&+]<F%K_6QM_?X@=F5Y82!V97)I('1A8F%N_6YD82!B=6QU
M;F%M863]+@!$8?#]=/UM(&QI<W1E<VD@8F5L:7)L96YE;65D:2X`4_QR_&/\
M(&)E;&ER=&EY;W(Z(`#>:69R96QE;64@]GIE;&QI:VQE<FD@9_QV96YL:2!B
M:7(@=V5B(&)A\&QA;G3]<_T@9V5R96MT:7)M96MT961I<BX`)7,@9&]S>6%S
M_2`E<R!A>6%R_2!IYV5R;65L:61I<BX`)7,@9&]S>6%S_2`E<R!A>6%R;&%R
M_2!IYV5R;65L:61I<BX`1&]S>6$@:V5N9&D@_'IE<FEN92!K;W!Y86QA;F%M
M87HN`$1O<WEA('9E<FD@:>=E<FUI>6]R+@!486MI<"!E9&5N;&5R(&)U(&EL
M971I+W)F8S@R,B!I;&5T:7-I(&GG:6X@8F'^;/UK(&)I;&=I;&5R:61I<BX`
M0?YA;6%D_?#];?UZ('1A<F%Y_6/](&AA=&%L87+]('-E8F5B:7EL92!T86T@
M96MR86X@:VEP:6YI;B!);G1E<FYE="!%>'!L;W)E<B=L82!B:7)L:6MT92!S
M;W)U;B#G_6MA<F3]\/T@8FEL:6YM96MT961I<BX@06YL86US_7H@9_9R_&YT
M_&QE<FQE+"#G86S]_FUA>6%N(&UE=&EN(&3\>F5N;&5Y:6-I(&G^;&5R:7EL
M92!V92]V97EA('1A<F%Y_6/];OUN(')A<W1G96QE(.?V:VUE<VEY;&4@:V%R
M_OUL8?YA8FEL:7)S:6YI>BX@1?!E<B!S:7-T96UI;FEZ(%=I;F1O=W,@.7@@
M:7-E('G\:W-E:R!I:'1I;6%L("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G
M(&AA=&%S_2!A;/UP('-I<W1E;6D@>65N:61E;B!B8?YL871M86[]>B!G97)E
M:V5C96LN7&Y<;D)U(&)I<B!U>6%R_7ED_2X@1?!E<B!H86QA('1A;2!E:W)A
M;B!M971I;B!D_'IE;FQE>6EC:7-I;FD@9&5N96UE:R!I<W1I>6]R<V%N_7H@
M179E="=I('3]:VQA>?UN+@!+:6UL:6L@(B5S(B!S:6QI;F1I+@!3861E8V4@
M<V]L('1A<F%F`$-R>7!T7W!G<#HZ('/];OUF_6YA($=N=5!'(&EK:6QI<VEN
M:6X@:V]N=6UU('9E<FEL;65K('IO<G5N9&%D_7(N`"5S('1A<FEH:6YD92`E
M<R!E(&?V;F1E<FEL96X@(B5S(B!K;VYU;'4@:6QE=&D@9_9R_&YT_&QE;F1I
M+@I"=2!I;&5T:6YI;B!O:W5N9'7P=2!V97EA(&%N;&'^_6QD_?#];OT@9V%R
M86YT:6QE;65M96MT961I<BX`3VQU_G1U<B!P96YC97)E<VEN92!B8?!L86[]
M<FME;B!K=6QL86[];&%C86L@:7-I;0!(;W)D95]#<GEP=%]S:6UE.CH@<_UN
M_6;](&]P96YS<VP@8FER:6UI(&GG:6X@9V5R96MM96MT961I<BX`(B5S(B!T
M97)C:6AI('9E<FES:2!I>FEN('9E<FEL96X@96X@>?QK<V5K(&)O>75T=2!G
M9>=T:?!I(&GG:6X@:V%Y9&5D:6QE;65M96MT961I<BX`0G4@=F5R:2!Y87!S
M_6[]*"5S*2!G]G-T97)M96L@:>=I;B!K=6QL86[];&%N('!R;V=R86T@<VES
M=&5M9&4@8G5L=6YM86UA:W1A9/UR+@!3861E8V4@<V]L('9E('-A\"!T87)A
M9FQA<@!3861E8V4@<V'P('1A<F%F`"(E<R(@<W5N=6-U<W4@<VEL:6YD:2X`
M(B5S(B!S=6YU8W5S=2!K87ED961I;&1I+@`E<R!IYVEN(&]L86X@_'EE;&EK
M(&ES=&7P:2!S:6QI;F1I+@!"96QI<G1I;&5N('-A=/UR(&)U;'5N;6%M86MT
M863]<BX`1V7G:6-I(&1O<WEA("(E<R(@8G5L=6YM86UA:W1A9/UR+@!3861E
M8V4@_'-T('9E(&%L="!T87)A9FQA<@!3861E8V4@_'-T('1A<F%F`$)I<B#V
M;F-E:VD@863];2!S_7)A<_UN9&$@>?QK;&5N96X@=F5R:2!K87EB961I;&1I
M+@!9_&ML96YE;B!D;W-Y82!K87ED961I;&5M961I+@!W96%T:&5R+F-O;2!K
M=6QL86[];&%B:6QI<B!D9?!I;"X`2&GG8FER('-EYV5N96L@;65V8W5T(&1E
M\&EL+@!-971N92!G]FW\;/P@;VQA<F%K(&?V<W1E<FEL96)I;&5C96L@:_US
M_6T@>6]K`$)U(&%L86YD82#G;VL@9F%Z;&$@:V%R86MT97(@=F%R+B5S('1A
M;F4@:V%R86MT97(@9VER9&EN:7H[("5S('1A;F5D96X@87H@9VER;65N:7H@
M9V5R96MI<F1I+@!$;W-Y82`H:V%R_OUD86XI('G\:VQE;FUE<VEN9&4@<V]R
M=6X@=F%R.B`E<R!Y_&ML96YE;65D:2X`1&]S>6$@>?QK;&5N:7)K96X@8FER
M('-O<G5N(&]L=?YT=3H@)7,@96X@8OQY_&L@:7II;B!V97)I;&5N(&)O>75T
M=&%N("@E9"!B>71E*2!D86AA(&+\>?QK+@!$;W-Y82!Y_&ML96YI<FME;B!B
M:7(@<V]R=6X@;VQU_G1U.B`E<R!S861E8V4@:_US;6D@;VQA<F%K('G\:VQE
M;F1I+@!"971I:R!E=&MI;FQE_G1I<FQI<FME;B!B:7(@:&%T82!O;'7^='4N
M`$)E=&GP:6X@971K:6YL:?!I(&MA;&3]<OUL_7)K96X@8FER(&AA=&$@;VQU
M_G1U+B``26QE=&EN:6X@8G4@:_US;?UN_2!G]G+\;G3\;&5N;65S:6YD92!H
M871A(&]L=?YT=2X`W6QE=&G^:6T@;F]K=&%S_6[];B!V97)I;&5R:2`H:>=E
M<FDI(&%K=&%R_6S]<FME;B!H871A(&]L=?YT=2X`:4-A;&5N9&%R('9E<FES
M:2`H:>=E<FDI(&%K=&%R_6S]<FME;B!H871A(&]L=?YT=2X`66%P_6QA;F3]
M<FUA(&9O<FUU;F1A(&)I<B!H871A('9A<BX@1V5R96ML:2!B:7(@86QA;OT@
M9&]L9'5R;6%M_?X@;VQA8FEL:7)S:6YI>BX`0F5L:7)T:6QE;B!A9')E<R!D
M969T97)I(&G^;&5V:6YI;B!G97+G96ML9?YT:7)I;&UE<VD@<_UR87/];F1A
M('-O<G5N(&]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K<F%R(&1E;F5Y
M:6XN`-UL971I_FEM(&YO:W1A<_UN_6X@87ER_6YT_6QA<OUN_2!G_&YC96QL
M97)K96X@:&%T82!O;'7^='4N($S\=&9E;B!D86AA('-O;G)A('1E:W)A<B!D
M96YE>6EN+@!$8?#]=/UM(&QI<W1E<VEN:2!G_&YC96QL97)K96X@8FER(&AA
M=&$@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@9&5N97EI;BX`
M0G4@24U!4"!S=6YU8W5S=2!P87EL8?[];&%N(&1I>FEN;&5R:2!D97-T96ML
M96UI>6]R+@!"=2!G9>=E<FQI(&)I<B!R87(@87+^:79I(&1E\&EL+@!"=2!G
M9>=E<FQI(&)I<B!Z:7`@9&]S>6%S_2!D9?!I;"X`0G4@9V7G97)L:2!B:7(@
M:V%R="!N=6UA<F%S_2!D9?!I;"X`0G4@<_QR_&/\($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@8?`@9V7G:61I(/QZ97)I;F1E;B!(5%10
M($%022!K=6QL86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N`$)U
M('/\<OQC_"!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PI(&'P(&=EYVED
M:2#\>F5R:6YD96X@2%144"!!4$D@:W5L;&%N87)A:R!M97-A:B!A=&UA;OUZ
M82!I>FEN('9E<FER+@!"=2!S_'+\8_P@4TU44"!Y;VQU>6QA(%9O9&%F;VYE
M($ET86QY(&'P(&=EYVED:2#\>F5R:6YD96XL('-A9&5C92!6;V1E9F]N92!N
M=6UA<F%L87+];F$@;65S86H@871M86[]>F$@:7II;B!V97)I<BX@5F]D969O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!E;&5K=')O;FEK('!O<W1A
M(&%D<F5S:2!G97)E:W1I<FUE:W1E9&ER+@!"=2!G97)E:VQI(&)I<B!A;&%N
M9/UR+@!"=2!A;&%N('-A9&5C92!S87G](&GG97)M96QI9&ER+@!"=2!A;&%N
M('-A9&5C92!S87G]('9E(&EK:2!N;VMT82#\<W3\<W1E(&G^87)E=&D@:>=E
M<F5B:6QI<BX`0G4@86QA;B!S861E8V4@<V5K:7IL:6L@<V%Y_2!S:7-T96UI
M;F1E;B!D9?!E<FQE(&GG97)E8FEL:7(N`$)U(&%L86X@=FER9_QL('9E>6$@
M8F_^;'5K;&$@87ER_6QM_?X@<V%Y_2!L:7-T92!O;&UA;/UD_7(N`$)U(&%L
M86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L_63]<BX`0G4@86QA;B!21T(@
M2&5X(&)IYVEM:6YD92!B:7(@<F5N:R!K;V1U(&GG97)M96QI9&ER+"#V<FYE
M:SH@)R,Q,C,T868G`$)U(&9O<FT@>F%T96X@:?YL96YD:2X`0G4@)7,N`$)U
M(&)I<B!+;VQA8B!'<F]U<'=A<F4@;F5S;F5S:61I<BX@0G4@;F5S;F5Y:2!G
M]G)E8FEL;65K(&GG:6X@2V]L86(@1W)O=7!W87)E(&)IYVEM:6YI(&%N;&%Y
M86)I;&5N(&)I<B!E;&5K=')O;FEK('!O<W1A(&ES=&5M8VES:6YE(&=E<F5K
M('9A<BY"=2!E;&5K=')O;FEK(&ES=&5M8VD@;&ES=&5S:2!IYVEN("5S(&%D
M<F5S:6YE('7P<F%Y_6XN`$)U(&EL971I('-I>FEN(&MA<F%K=&5R(&O\;65N
M:7ID96X@9F%R:VS](&]L87)A:R@E<RD@>6%Z_6QM_?YT_7(N`$)U(&YU;6%R
M82!E;B!A>OUN9&%N(&)I<B!O;&UA;/UD_7(N`$)U('-U;G5C=2!Z:7`@=F4@
M9WII<"!D;W-Y86QA<OUN_2!AYV%M86UA:W1A9/UR+@!3:7-T96UI;B!E=&MI
M;FQI\&D@:V%L9/UR_6QM_?YT_7(N`$)U(&1E\&5R(&)I<B!S87G](&]L;6%L
M_63]<BX`0G4@<&5N8V5R92!39>=E;F5K;&5R('!E;F-E<F5S:6YD96X@YV'P
M<OUL;6%L_63]<BX`1_9K(&?\<OQL=/QS_`!":6QE=&QE<@!:86UA;@!:86UA
M;B#=>FQE;64`6F%M86X@0FGG:6UI`%IA;6%N(%-EYVEM:0!4:6UO<BU,97-T
M90!"8?YL_6L`0F'^;/UK("AAY_UK;&%M82DZ`$MI;64`QV]K;'4@]O!E('-E
MYVEM:2!IYVEN+"!T_6ML87)K96X@0V]N=')O;"`H4$,I('9E>6$@0V]M;6%N
M9"`H36%C*2!T=?YU;F$@8F%S_6XN`$)U9_QN`$A434P@2V%Y;F'P_6YA($=E
MYVEN`%1O9V\`5&]K96QA=0!987+];@!4;VYG80#<<W0`W'-T(,=E<N=E=F4@
M*-Q?<W0I`,=E=FER:6QE<@!4<FEN:61A9"!V92!4;V)A9V\`1&_P<G4@=F5Y
M82!986YL_?X`4V$`5'5N=7,`5/QR:VEY90!4_')KYV4@*$E33RTX.#4Y+3DI
M`%3\<FMM96YI<W1A;@!4=7)K<R!V92!#86EC;W,@061A;&%R_0!4=79A;'4`
M4V7G:6UI;FEZ:2!G:7)I;CH`52Y6+B!E;F1E:W,Z(`!54DP`0F5T:6ML97)I
M;B!D=7)U;2!R87!O<FQA<OUN_6X@=&5S;&EM(&5D:6QE8V7P:2!54DP`55),
M.@!59V%N9&$`56MR87EN80!61E,@9&EZ:6YI;F4@97)I_FEL96UE;6EY;W(N
M`-QY92!O;'5R:V5N(&5K(&MU;&QA;OUC_2!B:6QG:7-I(&5K;&5N96UI>6]R
M+@`B)7,B(%9&4R!D;W-Y87/];OUN(&EZ:6YL97)I(&1E\&G^=&ER:6QE;6EY
M;W(N`"5S+R5S(%9&4R!D;W-Y87/];OUN(&EZ:6YL97)I(&1E\&G^=&ER:6QE
M;6EY;W(N`"5S(&1E\&G^=&ER:6QE;65D:2X`4U%,('-U;G5C=7-U;F$@8F'P
M;&%N_6QA;?UY;W(N`%-33"!I;&4@8F'P;&%N_6QA;?UY;W(N`%9&4R!D;W-Y
M87/](&MO<'EA;&%N86W]>6]R+@`B)7,B(%9&4R!D:7II;FD@>6%R873];&%M
M_7EO<BX`5D93(&1I>FEN:2!Y87)A=/UL86W]>6]R+@!61E,@9&]S>6%S_2!Y
M87)A=/UL86W]>6]R+@!";_X@5D93(&1O<WEA<_T@>6%R873];&%M_7EO<BX`
M5F5R:2!S_6O]_G3]<OUL86W]>6]R+@`B)7,B(&1I>FEN:2!S:6QI;F5M:7EO
M<BP@9&EZ:6X@8F_^(&1E\&EL+@`E<R!S:6QI;F5M:7EO<BP@9&EZ:6X@8F_^
M(&1E\&EL`%9&4R!D:7II;FD@]GIY:6YE;&D@;VQA<F%K('-I;&EN96UI>6]R
M+@!61E,@9&EZ:6YI('-I;&EN96UI>6]R+@!61E,@9&EZ:6YI('-I;&EN96UI
M>6]R.B`E<RX`5D93(&1O<WEA<_T@(B5S(B!S:6QI;F5M:7EO<BX`5D93(&1O
M<WEA<_T@<VEL:6YE;6EY;W(N`%9&4R#V>GEI;F5L:2!O;&%R86L@<VEL:6YE
M;6EY;W(Z("5S+@!9_'+\<FS\:W1E:VD@9&EZ:6YE(&MA<F%R('9E<FEL96UI
M>6]R+@!/;F%Y(&)E;&=E<VD@87ER_6YT_6QA<OT@Y_UK87)T_6QA;?UY;W(`
M)7,@:6X@=&%N_6W]('G\:VQE;F5M961I+@!61E,@9&]S>6%S_2!T8?[];F%M
M_7EO<BX`5D93(&1O<WEA<_T@(B5S(B!AY_UL86W]>6]R+@!61E,@9&]S>6%S
M_2!Y86UA:R!IYVEN(&'G_6QA;?UY;W(N`%9&4R!D;W-Y87/](&'G_6QA;?UY
M;W(N`%/]:_W^=/UL_6W]_B!A<OYI=B!AY_UL86W]>6]R+@!69G-R;V]T(&1I
M>FEN:2!O:W5N86W]>6]R+@`E<RT^)7,@;VQA<F%K('EE;FED96X@861L86YD
M_7+];&%M_7EO<CH@:&5D968@9&EZ:6X@>F%T96X@=F%R+@!61E,@9&EZ:6YI
M('EE;FED96X@861L86YD_7+];&%M_7EO<BX`5D93(&1I>FEN:2!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(Z("5S`%9&4R!D;W-Y87/]("(E<R(@>65N:61E
M;B!A9&QA;F3]<OUL86W]>6]R+@`E<R\E<R!61E,@9&]S>6%S_2!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(N`%9&4R!D;W-Y87/]('EE;FED96X@861L86YD
M_7+];&%M_7EO<BX`)VUK:7-O9G,G(.=A;/W^=/UR_6QA;?UY;W(N`$)U(%=O
M<F0@8F5L9V5S:2#G979I<FEL:6QE;6EY;W(N`%9&4R!D;W-Y87/]("(E<R(@
M>6%Z_6QA;?UY;W(N`%9&4R!D;W-Y87/]('EA>OUL86W]>6]R("AC;W!Y*"D@
M8F'^87+]<_UZ(&]L9'4I+@!61E,@9&]S>6$@=F5R:7-I('EA>OUL86W]>6]R
M+@!!;'3];OT@YVEZ`$1E\&G^:6ML:6ML97)I($=E<FD@06P`4V]N(&5Y;&5M
M:2!G97)I(&%L`$)A\&QA;G3]9&$@<W5N=6-U9&%N(&)E:VQE;FUE>65N('EA
M;OUT.B``4W5N=6-U9&%N(&)E:VQE;FUE>65N('EA;OUT.B``1&]L9'5R=6QM
M86W]_@!5;FEC;V1E("A55$8M."D`0FER;&7^:6L@07)A<"!%;6ER;&EK;&5R
M:0!":7)L9?YI:R!+<F%L;/UK`$%M97)I:V$@0FER;&7^:6L@1&5V;&5T;&5R
M:0!!;65R:6MA($)I<FQE_FEK($1E=FQE=&QE<FEN:6X@2_SG_&L@57IA:R!!
M9&%L87+]`$)I<FEM;&5R`$)I;&EN;65Y96X`0FEL:6YM97EE;B!A<&EM<V=I
M9"`H05!)($UE<V%J($E$*0!":6QI;FUE>65N(&-L:6US9VED("C=<W1E;6-I
M(&UE<V%J($E$*0!":6QI;FUE>65N(&MU;&QA;OUC_2!A9/T@=F5Y82!P87)O
M;&$N`-YU(&%N:VD@]O!E;FEN(&)A\/UN_2#G]GH`W7-I;7-I>@!!>7+]8V%L
M_6MS_7H@8F5T:6ML97(@<')O9W)A;7-A;"!O;&%R86L@2V5S+TMO<'EA;&$O
M66%P_?YT_7(G82!G_'9E;FQI:R!N961E;FEY;&4@97)I_F5M97IL97(N($)E
M=&EK;&5R:6X@<&%N;WEA(&YA<_UL('5L8?YA8V'P_6[](&?V<W1E<F5N(&UO
M>FEL;&$N;W)G('1E:VYI:R!N;W1U;G4@9_9R;65K(&GG:6X@159%5"!I('3]
M:VQA>?UN+@!"96QI<G1I;&UI_B!R96YK=&5N('9A>F=EYP!$97-T96ML96YM
M97EE;B!5>F%N=/T`1_QN8V5L;&4`1_QN8V5L;&4Z("5S`$MU;&QA;OUC_7G]
M(&?\;F-E;&QE`%G\:W-E;'1M92!B971I\&D@<VEL:6QN9&DN`%G\:VQE`$+\
M=/QN('5Y9W5L86UA;&%R_6X@87EA<B!D;W-Y86QA<OT@<W5N=6-U>6$@>?QK
M;&5N9&DN`$+\>?QK(&QA=&EN(&AA<F9L97)I`$+\>?QK(')O;6$@<F%K86UL
M87+]`%5R=6=U87D`2W5L;&%N.B`E<P!34TP@:W5L;&%N`$MU;&QA;OUC_2!A
M9/UN_7HO<&%R;VQA;OUZ($E-4U`@<W5N=6-U(&GG:6X@9F%R:VS](&ES92!K
M=6QL86[];BX`)7,@:W5L;&%N_6/]<_T@)7,@:>=I;B!D;_!R=6QA;F%M863]
M+@!+=6QL86[]8_T@6?9N971I;6D`2W5L;&%N_6/](%-EYV5N96ML97)I`$MU
M;&QA;OUC_2!+87G]=`!"=2!S:71E(&GG:6X@:W5L;&%N_6/](&MA>63]('-E
MYVEL;65Z(&O];/UN;?W^=/UR+@!+=6QL86[]8_T@063]`$MU;&QA;OUC_2!!
M9/TZ`$MU;&QA;OUC_2!A9/TZ(`!3:7-T96UD96MI(&MU;&QA;OUC_6QA<CH`
MUGIB96MI<W1A;@!61E,@9&EZ:6YI('EO:RX`5&%T:6P`5&%T:6P@1/QZ96YL
M90!4871I;"!-97-A:OT`5&%T:6P@>?QR_')L_&MT96MI('/\>F=EYR!S_'+\
M8_QS_"!T87)A9OUN9&%N(&1E<W1E:VQE;FUE;65K=&5D:7(N`$=EYV5R;&D@
M:V]N=6UL87+];B!IYV5R9&EK;&5R:3H`1V7G97)L:6QI:P#>=2!A;F1A;B!I
M=&EB87)E;B!D86MI:V$@9&7P97)I`$1E\&5R;&5R`$1E\&5R;&5R:6X@<V7G
M:6QE8V7P:0!686YU871U`$1E\&G^:V5N`%9E;F5Z=65L;&$`1&_P<G5L86UA
M(&)A_F%R_7/]>B!O;&1U("T@8G4@:6QE=&D@:W5R8V%L86YM_?X@;VQA8FEL
M:7(N("``4_QR_&T`4_QR_&T@2V]N=&]L_`!$_/YE>2!(:7IA`$3\_F5Y('EA
M<W3]:VQA;6$`1/S^97DZ`,=O:R!9_&MS96L`5FEE=&YA;0!6:65T;F%M8V$@
M*%9)4T-)22D`1_9R_&YT_&QE("5S`$)I<B!D_?X@=V5B('-A>69A<_T@9_9R
M_&YT_&QE`"5S(&]L87)A:R!G]G+\;G3\;&4`0G)I=&%N>6$G>6$@86ET(%9I
M<F=I;B!!9&%L87+]`$%M97)I:V$@0FER;&5R_FEK($1E=FQE=&QE<FDG;F4@
M86ET(%9I<F=I;B!!9&%L87+]`$?V<OS^`$?V<OS^.@!33510('EO;'5Y;&$@
M5F]D869O;F4@W71A;'EA`%=!4DX`55E!4DDA(2$E<R#=Q]U.1$5.($)%5-W0
MW2!%3"#=3$4@QTE+05)424XN`%=A;&QI<R!V92!&=71U;F$`57EA<OT`QW+^
M`$AA=F$@5&%H;6EN:0!(879A('9E<FES:2!S8?!L87G]8_US_0!796%T:&5R
M+F-O;0!796(`5V5B(%-I=&5S:0!(869T86S]:P!(;_YG96QD:6YI>@`E<R!(
M;_YG96QD:6YI>@!(;_YG96QD:6YI>BP@)7,`0F%T_2`H25-/+3@X-3DM,2D`
M0F%T_2`H25-/+3@X-3DM,34I`$)A=/T@4V%H<F$`0F5Y85]Z;&ES=&4@061R
M97-L97)I.@`E<R!G:7)I_G1E;B!S;VYR82!H86YG:2!U>6=U;&%M87G](&?V
M<OQN=/QL97-I;C\`4_UN_7)L87G]8_T@:V%R86MT97(@;F5D:7(_`$%K=&%R
M_6T@:V%R86MT97)I(&YE9&ER/P!(86YG:2!%=G)E`%IE;F=I;B!-971I;B!D
M_'IE;FQE>6EC:7-I(&GG:6X@:&%N9VD@=7EU;6QU(&5K;&5R('-EYVEL96)I
M;&ER(&O];/UN<_UN+@!"97EA>B!,:7-T90!"97EA>B!,:7-T97EI($3\>F5N
M;&4`0F5Y87H@3&ES=&4@>?QR_')L_&MT96MI('/\>F=EYR!S_'+\8_QS_"!T
M87)A9OUN9&%N(&1E<W1E:VQE;FUE;65K=&5D:7(N`$)E>6%Z($QI<W1E9&5K
M:2!!9')E<VQE<@!'96YI_FQI:P!#4U,@8FER:6UI>6QE(&=E;FG^;&EK`%-O
M;&1A:VD@)7,@;65N_'/\;OQN(&=E;FG^;&GP:2`H8FER('-O;G)A:VD@9VER
M:?YT92!E=&MI;B!O;&%C86LI.@#':7IE;&=E;FEN(&=E;FG^;&GP:0!'96YI
M_FQI:R!B:7)I;6D`1V5N:?YL:6LZ`%=I:VD`4OQZ9V%R`$5R:V5N(%-A871L
M97)D92!2_'IG87(`2VYO="!B:7)I;6EN9&4@<OQZ9V%R(&C]>OT`4OQZ9V%R
M.@!2_'IG87(Z(`!":6QG96QI:P#=_@#=_B!!9')E<VD`W?X@5&5L969O;G4`
M6"W6;F-E;&GP:0!8+5)E9@!8+5-P86TM1/QZ97EI`%@M4W!A;2U$97)E8V5S
M:0!8+5-P86TM1'5R=6UU`%@U,#EV,R!496UE;"!+_7/]=&QA;6%L87+]`%@U
M,#EV,R!'96YI_FQE=&EL;6G^($%N86AT87(@2W5L;&%N_6W]`%@U,#EV,R#6
M=&5K:2!+;VYU($%D_0!8-3`Y=C,@2V]N=2!!;F%H=&%R(%1A;OUT_6/]<_T`
M6#4P.78S('5Z86YT_6QA<OT`65D`65E960!986AO;R$@:&%R:71A<_T`6?UL
M;/UK`%EE;65N`$5V970`179E="P@2V%B=6P@161I>6]R=6T`3454W4X@34]$
M54Y$05-)3DE:+B!;/#Y=(&3\\&UE;&5R:6YI(&MU;&QA;F%R86L@5UE325=9
M1R!G]G+\;OQM_&YE(&3V;OQN+@!$;_!R=6QA;F%M863];OUZ+@`G7"<@:V%R
M86MT97)I('1A;2!A9/UN_7ID82!B=6QU;F%M87HN`$=EYV5R;&D@8FER(&5L
M96MT<F]N:6L@<&]S=&$@861R97-I(&=I<FUE9&EN:7HN`"5S(&GG:6YD92!K
M87+^_6S]:R!G96QE;B!A;&%N;&%R;&$@*&GG97)I*2!A:W1A<OUL86X@9&]S
M>6%D86MI(&%L86YL87+](&7^;&7^=&ER;65D:6YI>BX`Q_UK_?X@>6%P;6%D
M_6[]>BX`1V7G97)L:2!B:7(@8V5P('1E;&5F;VYU(&YU;6%R87/](&=I<FUE
M;&ES:6YI>BP@<V%Y_6QA<B!V92!S9>=E;F5K;&D@;VQA<F%K('5L=7-L87)A
M<F%S_2!A<F%M82#V;F5K:2`G*R<@`$=EYV5R;&D@8FER(&1E\&5R(&=I<FUE
M;&ES:6YI>BX`W'EE(&MA>63]('EA<&%B:6QM96L@:>=I;B!B:7(@5F5R:4'P
M86/]('EA</UL86YD_7)M86S]<_UN_7HN`%9&4R!S;VX@8?YA;6%S_6[]('EA
M</UL86YD_7)M86S]<_UN_7HN`%!R;V)L96T@<F%P;W)U(&?V;F1E<FUE9&5N
M(/9N8V4@<V]R=6YU('1A<F9I(&5T;65L:7-I;FEZ+@!"=2!B8?!L86YT_6[]
M;B!G]G-T97)D:?!I(&)I<B!54DP@9VER;65L:7-I;FEZ`%-I;&EN;65S:2!I
MYVEN(&)I<B!S=6YU8W4@<V7G;65L:7-I;FEZ+@!496UI>FQE;FUE<VEN(&GG
M:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ+@!3:6QI;FUE
M<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI<G1M96QI<VEN:7HN`%1A
M=&EL(&UE<V%J;&%R_6[];OUN(&5T:VEN;&7^;65S:2!IYVEN(&5N(&%Z(&)I
M<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!B96QI<G1M96YI>B!G97)E:VQI
M9&ER+@!%:VQE;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI<G1M
M96QI<VEN:7HN`$?\;F-E;&QE;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D
M_2!B96QI<G1M96QI<VEN:7HN`$=E<N=E:VQE_G1I<FEL96-E:R!B:7(@97EL
M96T@8F5L:7)T;65L:7-I;FEZ+@!996YI(&MA=&5G;W)Y(&%D_2!G:7)M96QI
M<VEN:7HN`"5S(&]T=7)U;75N=6X@<_QR97-I(&1O;&1U+B!,_'1F96X@=&5K
M<F%R(&=I<FG^('EA</UN+@!%;&5K=')O;FEK(%!O<W1A($%D<F5S:6YI>@!+
M:6UD96XZ(&%D<F5S.@!":6QG:6QE<FEN:7H`)7,@;W1U<G5M=6YU>G5N(&)A
M_FQA;F?]8_UN9&$@W6YT97)N970@061R97-I;FEN:7H@9&7P:?YT:2X@1_QV
M96YL:?!I;FEZ:2!K;W)U;6%K(&GG:6XL('EE;FED96X@9VER:?X@>6%P;6%L
M_7/];OUZ+@!!9/UN_7H`2VEM;&EK(&1E;F5T:6UI;FEZ(&MU;&QA;OUC_2!L
M:7-T96QE;65Y:2!D97-T96ML96UE;65K=&5D:7(@=F5Y82!B=2#V>F5L;&EK
M(&)I<B!N961E;B!Y_'K\;F1E;B!S9>=I;&5M97H@:_UL_6YM_?YT_7(N`"5S
M(&]T=7)U;75N=7IU;B!B8?YL86YG_6/];F1A('1A<F%Y_6/];OUZ(&1E\&G^
M=&DN($?\=F5N;&GP:6YI>FD@:V]R=6UA:R!IYVEN+"!Y96YI9&5N(&=I<FG^
M('EA<&UA;/US_6[]>BX`5&%R87G]8_UN_7H@8G4@]GIE;&QI\&D@9&5S=&5K
M;&5M96UE:W1E9&ER+@!:86UA;B!$:6QI;6EN:7HZ`-9N('1A;OUM;/T@:VEM
M;&GP:6YI>CH`5&%M($%D_6[]>CH`)7,@:>=I;B!Y96YI('!A<F]L86[]>CH@
M)7,`4V7G96YE:VQE<FEN:7H@8G4@;W1U<G5M=6X@<_QR97-I(&GG:6YD92!G
M_&YC96QL96YD:2X`4V7G96YE:VQE<FEN:7H@9_QN8V5L;&5N9&DN`%!A<F]L
M86[]>B!S_6;]<FQA;F3]+@!087)O;&%N_7H@<_UF_7)L86YD_2P@96QE:W1R
M;VYI:R!P;W-T86[]>OT@:V]N=&]L(&5D:6X@=F4@>65N:2!P87)O;&%N_7IL
M82!G:7)I_B!Y87#];BX`57IA:W1A:VD@<W5N=6-U;&%R_6[]>CH`675G;W-L
M879Y80!:86ER90!:86UB:6$`6FEM8F%B=F4`2/UZ;/T`6T%L_6YT_2!-971N
M:2!386ML85T`6TMO;G4@66]K70!;4')O8FQE;2!287!O<G5=`%M!;/UN=/T@
M365T;FD@1_9S=&5R("T`6T%L_6YT_2!-971N:2!']G-T97(@+2`E<R!S873]
M<ET`)7,O)7,@<V%T_7(`W6QE=&EL96-E:R!?061R97-L97(Z`%EA;OUT(&?V
M;F1E<FEL;65Y96-E:R!?061R97-L97(Z`%]9]FYE=&EM`%]+87)A($QI<W1E
M`%]#3$D`7U9E<FE!\&%C_0!3873]<OT@7U-I;`#=;&5T:71I('1A;6%M96X@
M7U-I;`!?2&5R(&%D<F5S:2!Y96YI(&)I<B!S873]<F1A(&=I<FEN.@#=7VQE
M=`!?1W)U<&QA<@!987)?9/UM`$?V<OQN=/P@UE]Z96QL:6ML97)I+BXN`%_=
M;&5T:6QE<FEN(&)I<B!K;W!Y87/](&AE<V%P=&$@='5T=6QS=6X@;74_`$=I
M7W)I_@#'_5]K_?X`7T)A\&QA;G3]>?T@1&7P:?YT:7(N+BX`W6QE=&EY:2!D
M:7II;F4@7U1A_OTZ`$5L96MT<F]N:6L@4&]S=&$@061R97-I7VTZ`%]39>=E
M;F5K;&5R`%](86ML87(`0F'P;&%?;G3]>?T@4VEL+BXN`%]"971I:P!?07EA
M<FQA<@#':7IE7VQG92#6>F5L;&EK;&5R:2XN+@!+7W5L;&%N_6/];&%R`%]4
M871I;`!?0F5Y87H@3&ES=&4`861R97,@9&5F=&5R:0!V90!T86MV:6T`_6S]
M;6S]`&)U<F%Y82!T_6ML87G];@!D_/[\>6]R`&%L86X`9&]S>6$`)7,@*"5S
M*2!D96X@)7,@)7,@9&4`:#H`06-I;`!-971N92!G]FW\;/P`<V%T_7)L87)=
M`&7^;&7^96X`;6MI<V]F<R!)4T\@>6%P87)K96X@:&%T82!K;V1U.B5D+@!A
M9`!G97+G96ML9?YT:7)I;&UE9&D`:&5N_'H@9V5RYV5K;&7^=&ER:6QM961I
M`&YO="!D969T97)I`'9E>6$`>?QZ9&4`<F5S:6T@8FER:6UI`$EN9V\@=&%R
M86;];F1A;B!Y87)A=/UL86X@<')O8VUA:6P@8F5T:?!I`'G\:W-E;&EY;W(`
M9F%R:VQA<OT@9_9S=&5R`$EN9V\@=&%R86;];F1A;B!Y87)A=/UL86X@<VEE
M=F4@<_QZ9V5C:0!(5%10('EO;'5Y;&$@<VUS,F5M86EL`'-A8FET`&?V<F5V
M(&QI<W1E<VD`<&%R;VQA>?T@9&_P<G5L86UA:R!IYVEN(&EK:2!D969A(&=I
M<FEN`&)I<FQE_G1I<FEL;6G^`&%D;&%N9/UR_6QM86W]_@!K=6QL86[]8_T@
M<V7G:6UI`'9#87)D`'<Z`'=E871H97(N8V]M````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6YG;R]L;V-A;&4O>FA?5%<O````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T-P`P,3<V-34`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQO8V%L92]Z:%]45R],0U]-15-3
M04=%4R\`````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8R-S0W`#`R,30T,@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&]C
M86QE+WIH7U17+TQ#7TU%4U-!1T53+VEN9V\N;6\`````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`S-S$R-34`,3`T,3<S-C(W-#<`,#(R-S0U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-X2!)4`````#P@``!P```"4
M0```P0H```R!````````$*P```X````1K```#P```""L```-````,*P```@`
M```^K```"P```$>L```,````4ZP```0```!@K```!````&6L```#````:JP`
M`!@```!NK```&P```(>L```M````HZP``!T```#1K```)````.^L```I````
M%*T``!D````^K0``)@```%BM```,````?ZT``"0```",K0``#P```+&M```+
M````P:T```X```#-K0``!0```-RM```H````XJT```@````+K@``"@```!2N
M```5````'ZX``!(````UK@``"P```$BN``"%````5*X```X```#:K@``"@``
M`.FN```-````]*X```X````"KP``$0```!&O```-````(Z\```P````QKP``
M#0```#ZO```&````3*\``)0```!3KP``"@```.BO```/````\Z\``!@````#
ML```#````!RP```.````*;````X````XL```"````$>P```)````4+```"X`
M``!:L```&@```(FP```R````I+```#@```#7L```5````!"Q``!1````9;$`
M`%H```"WL0``5P```!*R```T````:K(```D```"?L@``#0```*FR```'````
MM[(```H```"_L@``#P```,JR```%````VK(```8```#@L@``$0```.>R```(
M````^;(```D````"LP``"0````RS```E````%K,``"`````\LP``$P```%VS
M```0````<;,```\```""LP``"@```)*S```A````G;,```\```"_LP``+@``
M`,^S```#````_K,```\````"M```%````!*T```)````)[0```T````QM```
M$@```#^T```9````4K0``!X```!LM```#P```(NT```*````F[0```\```"F
MM```"````+:T```D````O[0``!0```#DM```%@```/FT```(````$+4``$X`
M```9M0``+0```&BU```9````EK4``!,```"PM0``!P```,2U```,````S+4`
M`"P```#9M0``#@````:V```#````%;8```L````9M@``!P```"6V```'````
M+;8```4````UM@``!0```#NV```*````0;8```,```!,M@``%P```%"V```*
M````:+8```\```!SM@``#@```(.V```4````DK8```L```"GM@``&````+.V
M```C````S+8```X```#PM@``%````/^V```7````%+<``!<````LMP``%P``
M`$2W```3````7+<```\```!PMP``#@```("W```?````C[<``!T```"OMP``
M!P```,VW```&````U;<```@```#<MP``#P```.6W```&````];<```@```#\
MMP``"@````6X```3````$+@``!0````DN```"P```#FX```0````1;@``!4`
M``!6N```#0```&RX```5````>K@```<```"0N```$````)BX```%````J;@`
M`!4```"ON```$0```,6X```,````U[@``"H```#DN```.P````^Y```X````
M2[D```D```"$N0``!P```(ZY```4````EKD```,```"KN0``!0```*^Y```0
M````M;D```D```#&N0``$P```-"Y```Y````Y+D``!(````>N@``)P```#&Z
M```L````6;H``"H```"&N@``)0```+&Z```*````U[H```8```#BN@``"0``
M`.FZ```'````\[H``"\```#[N@``-P```"N[```N````8[L``%4```"2NP``
M+0```.B[```M````%KP``#T```!$O```/P```(*\```M````PKP``$````#P
MO```(P```#&]```C````5;T``$````!YO0``+0```+J]```S````Z+T``"4`
M```<O@``%0```$*^```9````6+X``"D```!RO@``)````)R^```H````P;X`
M`#(```#JO@``$0```!V_```*````+[\```H````ZOP``$````$6_```6````
M5K\``!8```!MOP``!P```(2_```'````C+\``!0```"4OP``"@```*F_```(
M````M+\``"<```"]OP``"````.6_```#````[K\```L```#ROP``!P```/Z_
M```'````!L````8````.P```!0```!7````'````&\````8````CP```%```
M`"K````(````/\````D```!(P```#@```%+````[````8<```!4```"=P```
M*0```+/````.````W<````H```#LP```!````/?````$````_,````<````!
MP0``"0````G!```&````$\$``!$````:P0``!P```"S!```6````-,$```0`
M``!+P0``"````%#!```&````6<$```T```!@P0``!@```&[!```>````=<$`
M`!$```"4P0``"````*;!```-````K\$```P```"]P0``!P```,K!```#````
MTL$```,```#6P0``%P```-K!```3````\L$``!T````&P@``"````"3"```$
M````+<(```@````RP@``"````#O"``!!````1,(``!H```"&P@``(````*'"
M```5````PL(```8```#8P@``!@```-_"```5````YL(``!@```#\P@``(@``
M`!7#```N````.,,``!T```!GPP``(0```(7#``!4````I\,``"D```#\PP``
M"@```";$```'````,<0```X````YQ```%0```$C$```.````7L0```(```!M
MQ```"@```'#$```/````>\0```T```"+Q```#P```)G$```-````J<0```D`
M``"WQ```%````,'$```&````UL0``!@```#=Q```'0```/;$```3````%,4`
M`!$````HQ0``%````#K%```$````3\4```8```!4Q0``%````%O%``!4````
M<,4```X```#%Q0``9````-3%```$````.<8```X````^Q@``!0```$W&```%
M````4\8``!L```!9Q@``&@```'7&```3````D,8``!$```"DQ@``$0```+;&
M```<````R,8``"H```#EQ@``$````!#'```A````(<<```4```!#QP``$P``
M`$G'```+````7<<``!(```!IQP``"@```'S'```/````A\<```T```"7QP``
M$0```*7'```3````M\<```P```#+QP``!@```-C'```,````W\<```8```#L
MQP``%P```//'```0````"\@``!$````<R```"````"[(```%````-\@```P`
M```]R```$````$K(```%````6\@```T```!AR```!@```&_(```'````=L@`
M``T```!^R```!P```(S(```+````E,@```<```"@R```!P```*C(```)````
ML,@```D```"ZR```"@```,3(```9````S\@``#T```#IR```'0```"?)```,
M````1<D``!````!2R0``!0```&/)```E````:<D``!(```"/R0``$P```*+)
M```2````MLD``"L```#)R0``.P```/7)```@````,<H```@```!2R@``-@``
M`%O*```(````DLH``"$```";R@``$````+W*```(````SLH```P```#7R@``
M!````.3*```'````Z<H```\```#QR@``"@````'+```.````#,L```H````;
MRP``#0```";+```?````-,L``!P```!4RP``(0```''+```>````D\L``!D`
M``"RRP``'@```,S+```=````Z\L``!L````)S```(````"7,```N````1LP`
M`"8```!US```'````)S,```>````N<P``!P```#8S```)@```/7,```K````
M',T``#,```!(S0``)@```'S-```K````H\T``#@```#/S0``'0````C.```5
M````)LX``"\````\S@``(````&S.```2````C<X``"D```"@S@``'@```,K.
M```@````Z<X``!(````*SP``H@```!W/```6````P,\``",```#7SP``*```
M`/O/```I````)-```"@```!.T```'P```'?0```5````E]```"````"MT```
M)0```,[0```H````]-```"T````=T0``,````$O1``"2````?-$``"$````/
MT@``%@```#'2```<````2-(``"8```!ET@``*@```(S2``!!````M](``$0`
M``#YT@``#````#[3```'````2],```<```!3TP``!@```%O3```-````8M,`
M`!````!PTP``$0```('3```2````D],``!,```"FTP``$@```+K3```'````
MS=,```0```#5TP``$````-K3```,````Z],```X```#XTP``#0````?4```/
M````%=0``!,````EU```#0```#G4```H````1]0```,```!PU```#0```'34
M```&````@M0``!$```")U```%P```)O4```;````L]0```X```#/U````@``
M`-[4```*````X=0``$D```#LU```!0```#;5```0````/-4```\```!-U0``
M!````%W5```-````8M4```X```!PU0```P```'_5```.````@]4``!$```"2
MU0``"````*35```/````K=4```\```"]U0``!P```,W5```-````U=4``!``
M``#CU0``#0```/35```+`````M8```8````.U@``"0```!76```+````']8`
M`!`````KU@``#````#S6```*````2=8``!$```!4U@``&0```&;6```+````
M@-8```T```",U@``(@```)K6```9````O=8``!L```#7U@``-````//6```*
M````*-<``!@````SUP``&0```$S7```6````9M<```<```!]UP``(@```(77
M```5````J-<``"$```"^UP``)0```.#7```1````!M@```T````8V```!P``
M`";8```4````+M@```L```!#V```(@```$_8```O````<M@```L```"BV```
M"0```*[8```9````N-@```L```#2V```%P```-[8```7````]M@```D````.
MV0``"@```!C9```(````(]D``!8````LV0``#P```$/9```9````4]D``#H`
M``!MV0``%@```*C9```.````O]D``!@```#.V0``"````.?9```O````\-D`
M``T````@V@``)@```"[:```(````5=H``$,```!>V@``$@```*+:```/````
MM=H``!````#%V@``#0```-;:```A````Y-H```@````&VP``$@````_;```?
M````(ML```@```!"VP``"P```$O;```O````5]L```X```"'VP``!0```);;
M```&````G-L```,```"CVP``!P```*?;```$````K]L```<```"TVP``"@``
M`+S;```*````Q]L```\```#2VP``$````.+;```7````\]L``!$````+W```
M&0```!W<```7````-]P```D```!/W```!0```%G<```+````7]P```H```!K
MW```!0```';<```-````?-P``!L```"*W```%P```*;<```4````OMP```D`
M``#3W```#@```-W<```-````[-P``!(```#ZW```"0````W=```X````%]T`
M`"````!0W0``!P```''=```(````>=T```D```""W0``#@```(S=``![````
MF]T``!@````7W@``"````##>```1````.=X```<```!+W@``!0```%/>```8
M````6=X``!X```!RW@``&P```)'>```9````K=X``"@```#'W@``%0```/#>
M```;````!M\``!,````BWP``!P```#;?```(````/M\```8```!'WP``!@``
M`$[?```0````5=\```\```!FWP``$````';?```/````A]\```L```"7WP``
M#P```*/?```,````L]\```\```#`WP``!P```-#?```.````V-\```8```#G
MWP``!@```.[?```.````]=\```P````$X```&@```!'@```/````+.````@`
M```\X```"````$7@```3````3N```!X```!BX```(0```('@```@````H^``
M`!D```#$X```%P```-[@```E````]N```!<````<X0``%@```#3A```$````
M2^$``!L```!0X0``#0```&SA```,````>N$```,```"'X0``!0```(OA```(
M````D>$```H```":X0``#````*7A```+````LN$``!````"^X0``#````,_A
M```$````W.$``!,```#AX0``%````/7A```,````"N(```D````7X@``#@``
M`"'B```+````,.(``!L````\X@``$P```%CB```9````;.(``!L```"&X@``
M#@```*+B```+````L>(```P```"]X@``%0```,KB```-````X.(``$,```#N
MX@``,0```#+C``!"````9.,``$<```"GXP``3P```._C```]````/^0``$X`
M``!]Y```$0```,SD```'````WN0```<```#FY```"@```.[D```-````^>0`
M``D````'Y0``!````!'E```%````%N4```,````<Y0``&````"#E```*````
M.>4```0```!$Y0``)0```$GE```F````;^4```X```"6Y0``?````*7E```5
M````(N8```4````XY@``!P```#[F```,````1N8```@```!3Y@``"@```%SF
M```&````9^8```<```!NY@``.0```';F```(````L.8```T```"YY@```@``
M`,?F```&````RN8```8```#1Y@``%````-CF```-````[>8``!````#[Y@``
M&P````SG```$````*.<```D````MYP``$````#?G```)````2.<```D```!2
MYP``!0```%SG```(````8N<```8```!KYP``&0```'+G```.````C.<```<`
M``";YP``!P```*/G```%````J^<```D```"QYP``"@```+OG```"````QN<`
M``8```#)YP``"P```-#G```-````W.<```D```#JYP``#````/3G```8````
M`>@```8````:Z```$@```"'H```)````-.@```<````^Z```%````$;H```=
M````6^@``$(```!YZ```)0```+SH```E````XN@```8````(Z0``"@````_I
M```$````&ND```D````?Z0``"````"GI```1````,ND```D```!$Z0``!@``
M`$[I```-````5>D```8```!CZ0``!````&KI```>````;^D```4```".Z0``
M#@```)3I```$````H^D```8```"HZ0``!P```*_I```A````M^D```T```#9
MZ0``%0```.?I```&````_>D```0````$Z@``$0````GJ```&````&^H```H`
M```BZ@``(@```"WJ```$````4.H```4```!5Z@``'0```%OJ```$````>>H`
M``P```!^Z@``#@```(OJ```*````FNH```@```"EZ@``"0```*[J```%````
MN.H``#H```"^Z@``,````/GJ```U````*NL``"D```!@ZP``1P```(KK```X
M````TNL``"D````+[```/P```#7L```N````=>P``"T```"D[```'P```-+L
M```/````\NP``!(````"[0``"P```!7M```F````(>T``"D```!([0``)```
M`'+M```F````E^T```@```"^[0``"@```,?M```)````TNT```<```#<[0``
M(````.3M```@````!>X``"8````F[@``"@```$WN```9````6.X``"D```!R
M[@``$@```)SN```'````K^X```H```"W[@``#````,+N```/````S^X``!``
M``#?[@``0````/#N``!P````,>\``&8```"B[P``#@````GP```)````&/``
M``H````B\```$@```"WP```3````0/````P```!4\```!@```&'P```/````
M:/````D```!X\```$@```(+P```0````E?```!$```"F\```'````+CP```C
M````U?```&H```#Y\```#P```&3Q```%````=/$``!````!Z\0``0P```(OQ
M```)````S_$``#(```#9\0``!`````SR```+````$?(``"`````=\@``%```
M`#[R```,````4_(```P```!@\@``#P```&WR```5````??(``"D```"3\@``
M*@```+WR```F````Z/(``"<````/\P``*0```#?S```J````8?,``!D```",
M\P``0@```*;S```1````Z?,``!(```#[\P``$P````[T```4````(O0```\`
M```W]```%@```$?T```7````7O0``!````!V]```$0```(?T```T````F?0`
M`!,```#.]```$@```.+T```U````]?0``!0````K]0``!P```$#U```,````
M2/4``"````!5]0``$````';U```4````A_4``!$```"<]0``%P```*[U```<
M````QO4``!,```#C]0``%````/?U```:````#/8``!$````G]@``&@```#GV
M```>````5/8``!H```!S]@``$P```([V```5````HO8``!$```"X]@``%P``
M`,KV```4````XO8``!<```#W]@``%0````_W```)````)?<``!`````O]P``
M&0```$#W```$````6O<```<```!?]P```@```&?W```+````:O<```4```!V
M]P``$0```'SW```&````CO<```8```"5]P``!@```)SW```%````H_<```<`
M``"I]P``!P```+'W```%````N?<``!8```"_]P``!@```-;W```&````W?<`
M``0```#D]P``!````.GW```'````[O<```X```#V]P``#`````7X```,````
M$O@```T````?^```"@```"WX```.````./@```4```!'^```*````$WX```.
M````=O@```P```"%^```#P```)+X```*````HO@```@```"M^```"0```+;X
M```K````P/@```0```#L^```"````/'X```F````^O@``!(````A^0``#P``
M`#3Y```&````1/D```H```!+^0``3````%;Y```'````H_D```@```"K^0``
M(````+3Y```)````U?D``!0```#?^0``#````/3Y```-`````?H```X````/
M^@``%@```![Z```1````-?H```8```!'^@```P```$[Z```&````4OH```<`
M``!9^@``!````&'Z```+````9OH```L```!R^@``!P```'[Z```)````AOH`
M`!4```"0^@``!P```*;Z```6````KOH```T```#%^@``#0```-/Z```*````
MX?H``!````#L^@``#P```/WZ```1````#?L``!<````?^P``"@```#?[```1
M````0OL```@```!4^P``!````%W[```/````8OL``#H```!R^P``!0```*W[
M```>````L_L```X```#2^P``$````.'[```+````\OL```P```#^^P``"0``
M``O\```'````%?P```<````=_```"@```"7\```)````,/P```X````Z_```
M$````$G\```;````6OP``!@```!V_```&@```(_\```*````JOP```D```"U
M_```"@```+_\```,````ROP```\```#7_```"````.?\```&````\/P```<`
M``#W_```!0```/_\```+````!?T``$<````1_0``#0```%G]```)````9_T`
M``0```!Q_0```P```';]```3````>OT``!,```"._0``$P```*+]```*````
MMOT```(```#!_0``!````,3]```E````R?T```,```#O_0``!0```//]```J
M````^?T```H````D_@``!0```"_^```$````-?X```H````Z_@``#0```$7^
M```&````4_X```@```!:_@``"````&/^```$````;/X```4```!Q_@``:```
M`'?^```)````X/X```P```#J_@``&````/?^```%````$/\```8````6_P``
M$````!W_```;````+O\``"\```!*_P``$````'K_```*````B_\``!L```"6
M_P``#P```++_```*````PO\```D```#-_P``$P```-?_```;````Z_\``!@`
M```'``$`%P```"```0`?````.``!`!<```!8``$`#@```'```0")````?P`!
M`(D````)`0$``P```),!`0`'````EP$!``@```"?`0$`!P```*@!`0`*````
ML`$!``L```"[`0$`!P```,<!`0!1````SP$!`!`````A`@$`#````#("`0`:
M````/P(!`$H```!:`@$`&0```*4"`0`&````OP(!`!H```#&`@$`)0```.$"
M`0`&````!P,!``8````.`P$`'P```!4#`0`&````-0,!``D````\`P$`&```
M`$8#`0`7````7P,!`"@```!W`P$`!@```*`#`0`-````IP,!`"(```"U`P$`
M&0```-@#`0`F````\@,!`%<````9!`$`$P```'$$`0`9````A00!`!L```"?
M!`$`(P```+L$`0`3````WP0!``(```#S!`$`"P```/8$`0`(`````@4!``T`
M```+!0$`"@```!D%`0`'````)`4!`!0````L!0$`!@```$$%`0`(````2`4!
M``X```!1!0$`!P```&`%`0`*````:`4!``L```!S!0$`,@```'\%`0`'````
ML@4!``P```"Z!0$`#0```,<%`0`,````U04!``0```#B!0$`"0```.<%`0`)
M````\04!``H```#[!0$`#@````8&`0`,````%08!``<````B!@$`"0```"H&
M`0`'````-`8!``H````\!@$`&P```$<&`0`2````8P8!``H```!V!@$`%@``
M`($&`0`)````F`8!`!````"B!@$`!P```+,&`0`2````NP8!`"D```#.!@$`
M!````/@&`0`'````_08!``4````%!P$`!0````L'`0`+````$0<!`!0````=
M!P$`$0```#('`0`:````1`<!`!8```!?!P$`%````'8'`0`7````BP<!`!@`
M``"C!P$`'````+P'`0`9````V0<!``<```#S!P$`!0```/L'`0`-`````0@!
M``P````/"`$`$0```!P(`0`(````+@@!``@````W"`$`%P```$`(`0`+````
M6`@!``P```!D"`$`'P```'$(`0`:````D0@!`!,```"L"`$`!````,`(`0`*
M````Q0@!``0```#0"`$`#````-4(`0`%````X@@!``D```#H"`$`!0```/((
M`0`'````^`@!``4`````"0$`!`````8)`0`"````"PD!`"\````."0$`.```
M`#X)`0`L````=PD!`",```"D"0$`)@```,@)`0`2````[PD!`"D````""@$`
M,@```"P*`0`*````7PH!`"P```!J"@$`+@```)<*`0`S````Q@H!`#,```#Z
M"@$`.````"X+`0`/````9PL!`!@```!W"P$`$````)`+`0`N````H0L!`!0`
M``#0"P$`#P```.4+`0`3````]0L!`!4````)#`$`%````!\,`0`2````-`P!
M`!0```!'#`$`+0```%P,`0`M````B@P!`#$```"X#`$`+@```.H,`0`O````
M&0T!`"P```!)#0$`8@```'8-`0`3````V0T!``T```#M#0$`"````/L-`0`4
M````!`X!`!<````9#@$`"````#$.`0`4````.@X!``P```!/#@$`*P```%P.
M`0`A````B`X!`!H```"J#@$`"0```,4.`0!%````SPX!`$$````5#P$`!```
M`%</`0`3````7`\!`!0```!P#P$`#@```(4/`0`3````E`\!`!@```"H#P$`
M!@```,$/`0`)````R`\!``H```#2#P$`#P```-T/`0`,````[0\!`!````#Z
M#P$`!P````L0`0`.````$Q`!``4````B$`$`&P```"@0`0`&````1!`!``@`
M``!+$`$`!@```%00`0`4````6Q`!`!$```!P$`$`#@```((0`0`X````D1`!
M``(```#*$`$`!@```,T0`0`.````U!`!``4```#C$`$`!P```.D0`0`&````
M\1`!`"@```#X$`$`#````"$1`0`<````+A$!``0```!+$0$`*0```%`1`0`5
M````>A$!`!\```"0$0$`7````+`1`0`4````#1(!`#X````B$@$`'P```&$2
M`0`0````@1(!``<```"2$@$`'@```)H2`0`.````N1(!``P```#($@$`#```
M`-42`0`3````XA(!``H```#V$@$`'0````$3`0`9````'Q,!``4````Y$P$`
M$0```#\3`0`-````41,!``@```!?$P$`$0```&@3`0`D````>A,!`!(```"?
M$P$`%0```+(3`0`2````R!,!``X```#;$P$`&0```.H3`0`(````!!0!``D`
M```-%`$`#0```!<4`0`*````)10!``<````P%`$`#P```#@4`0`&````2!0!
M``L```!/%`$`&@```%L4`0`*````=A0!``<```"!%`$`"````(D4`0`%````
MDA0!`!\```"8%`$`!@```+@4`0`0````OQ0!``@```#0%`$`#0```-D4`0`(
M````YQ0!`!X```#P%`$`$@````\5`0`L````(A4!`!H```!/%0$`"0```&H5
M`0`*````=!4!`!4```!_%0$`!0```)45`0`4````FQ4!``0```"P%0$`$```
M`+45`0`&````QA4!``<```#-%0$`'@```-45`0`H````]!4!``H````=%@$`
M'````"@6`0`1````118!``L```!7%@$`&@```&,6`0`4````?A8!``0```"3
M%@$`!````)@6`0`+````G18!``4```"I%@$`!@```*\6`0`(````MA8!``8`
M``"_%@$`&P```,86`0`T````XA8!`#0````7%P$`(````$P7`0`I````;1<!
M`"````"7%P$`00```+@7`0`:````^A<!`"@````5&`$`*````#X8`0`I````
M9Q@!`%````"1&`$`(@```.(8`0`&````!1D!``@````,&0$`!0```!49`0`(
M````&QD!`!D````D&0$`&0```#X9`0`J````6!D!`",```"#&0$`&0```*<9
M`0`N````P1D!`#0```#P&0$`"````"4:`0`7````+AH!``H```!&&@$`!P``
M`%$:`0`A````61H!`!````![&@$`#@```(P:`0`+````FQH!``<```"G&@$`
M$P```*\:`0`(````PQH!``L```#,&@$`"@```-@:`0`4````XQH!``\```#X
M&@$`,@````@;`0`+````.QL!``4```!'&P$`!0```$T;`0`%````4QL!`!<`
M``!9&P$`!P```'$;`0`/````>1L!``0```")&P$`"@```(X;`0`)````F1L!
M``L```"C&P$`#0```*\;`0`,````O1L!``X```#*&P$`!0```-D;`0`$````
MWQL!``T```#D&P$`,@```/(;`0!%````)1P!``@```!K'`$`"P```'0<`0`7
M````@!P!``<```"8'`$`'@```*`<`0`4````OQP!``4```#4'`$`$@```-H<
M`0`2````[1P!`!0`````'0$`!@```!4=`0`'````'!T!``X````D'0$`*@``
M`#,=`0`&````7AT!``P```!E'0$`#0```'(=`0`1````@!T!``L```"2'0$`
M-@```)X=`0`*````U1T!`"(```#@'0$`"P````,>`0`/````#QX!`#(````?
M'@$`)0```%(>`0`P````>!X!`#$```"I'@$`+0```-L>`0`.````"1\!``D`
M```8'P$`"P```"(?`0`%````+A\!``X````T'P$`$P```$,?`0`2````5Q\!
M``<```!J'P$`%@```'(?`0`1````B1\!`!0```";'P$`$P```+`?`0`'````
MQ!\!`!0```#,'P$`&````.$?`0`'````^A\!``4````"(`$`#`````@@`0`,
M````%2`!`!(````B(`$`!````#4@`0`'````.B`!``H```!"(`$`"P```$T@
M`0`,````62`!``X```!F(`$`#@```'4@`0`%````A"`!``0```"*(`$`"P``
M`(\@`0`,````FR`!``T```"H(`$`#````+8@`0`)````PR`!``4```#-(`$`
M+@```-,@`0`F`````B$!`",````I(0$``P```$TA`0`2````42$!``8```!D
M(0$`'@```&LA`0`8````BB$!`"4```"C(0$`#0```,DA`0`)````UR$!``,`
M``#A(0$`&````.4A`0`'````_B$!``H````&(@$``@```!$B`0`,````%"(!
M`!4````A(@$`"P```#<B`0`9````0R(!`"````!=(@$`$@```'XB`0`%````
MD2(!``H```"7(@$`%0```*(B`0`2````N"(!``P```#+(@$`!````-@B`0`)
M````W2(!``<```#G(@$`#````.\B`0`-````_"(!`%(````*(P$`%P```%TC
M`0`D````=2,!`!(```":(P$`!P```*TC`0`&````M2,!``\```"\(P$`$P``
M`,PC`0`>````X",!`"````#_(P$`!@```"`D`0`.````)R0!``0````V)`$`
M#````#LD`0`-````2"0!``X```!6)`$`%0```&4D`0`2````>R0!``\```".
M)`$`%````)XD`0`*````LR0!`!L```"^)`$`$````-HD`0`+````ZR0!`!0`
M``#W)`$`:0````PE`0`:````=B4!`!<```"1)0$`)P```*DE`0`:````T24!
M`!<```#L)0$`&P````0F`0`9````("8!`!\````Z)@$`$P```%HF`0`3````
M;B8!``@```"")@$`!@```(LF`0`'````DB8!``@```":)@$`"0```*,F`0`5
M````K28!``T```##)@$`(P```-$F`0`-````]28!`!,````#)P$`"````!<G
M`0`#````("<!`$8````D)P$`/P```&LG`0`W````JR<!`%<```#C)P$`'@``
M`#LH`0`%````6B@!`!\```!@*`$`+P```(`H`0`*````L"@!``@```"[*`$`
M#0```,0H`0`M````TB@!``0`````*0$`$@````4I`0`3````&"D!`$\````L
M*0$`)0```'PI`0`+````HBD!`!\```"N*0$`'0```,XI`0`E````["D!`"``
M```2*@$`)````#,J`0`@````6"H!``L```!Y*@$`!P```(4J`0`-````C2H!
M``P```";*@$`%P```*@J`0`&````P"H!``P```#'*@$`!P```-0J`0`)````
MW"H!`!,```#F*@$`"0```/HJ`0`$````!"L!`!`````)*P$`"````!HK`0`(
M````(RL!``0````L*P$`"P```#$K`0`,````/2L!`!(```!**P$`$0```%TK
M`0`,````;RL!``\```!\*P$`!P```(PK`0`-````E"L!`!0```"B*P$`#@``
M`+<K`0`,````QBL!`!L```#3*P$`+````.\K`0`3````'"P!``8````P+`$`
M!P```#<L`0`3````/RP!``4```!3+`$`!````%DL`0`7````7BP!``H```!V
M+`$`#````($L`0`)````CBP!``8```"8+`$`"0```)\L`0`(````J2P!``D`
M``"R+`$`"@```+PL`0`1````QRP!``8```#9+`$`(P```.`L`0`.````!"T!
M``X````3+0$`#0```"(M`0`+````,"T!`!T````\+0$`"P```%HM`0`"````
M9BT!`!P```!I+0$`'0```(8M`0`'````I"T!``8```"L+0$`9````+,M`0`)
M````&"X!``<````B+@$`)@```"HN`0`X````42X!`!H```"*+@$`*@```*4N
M`0`[````T"X!`"@````,+P$`-````#4O`0`9````:B\!`!4```"$+P$`!0``
M`)HO`0`'````H"\!``@```"H+P$`!P```+$O`0`%````N2\!``<```"_+P$`
M#@```,<O`0`)````UB\!``8```#@+P$`"````.<O`0`+````\"\!``<```#\
M+P$`"`````0P`0`'````#3`!`!8````5,`$`"0```"PP`0`&````-C`!``L`
M```],`$`$````$DP`0`&````6C`!`!P```!A,`$`%````'XP`0`'````DS`!
M`!$```";,`$`"````*TP`0`.````MC`!``@```#%,`$`!0```,XP`0`0````
MU#`!`!````#E,`$`!@```/8P`0`9````_3`!``H````7,0$`'````"(Q`0`'
M````/S$!``4```!',0$`$````$TQ`0`4````7C$!``L```!S,0$`#0```'\Q
M`0`H````C3$!`!@```"V,0$`%P```,\Q`0`$````YS$!``D```#L,0$`"@``
M`/8Q`0`'`````3(!``(````),@$`#@````PR`0`(````&S(!`",````D,@$`
M.````$@R`0`F````@3(!`#$```"H,@$`)P```-HR`0`R`````C,!`#(````U
M,P$`9````&@S`0`4````S3,!`%4```#B,P$`.````#@T`0!*````<30!`%L`
M``"\-`$`*````!@U`0`1````034!`#@```!3-0$`*````(PU`0`L````M34!
M`"8```#B-0$`&P````DV`0`^````)38!`",```!D-@$`%P```(@V`0!(````
MH#8!`(4```#I-@$`,````&\W`0`E````H#<!`$$```#&-P$`6P````@X`0!)
M````9#@!`#$```"N.`$`'0```.`X`0`8````_C@!`"L````7.0$`(0```$,Y
M`0`?````93D!`"L```"%.0$`(0```+$Y`0`G````TSD!`#H```#[.0$`'0``
M`#8Z`0`1````5#H!`#,```!F.@$`)0```)HZ`0`G````P#H!`"````#H.@$`
M'P````D[`0`P````*3L!`&D```!:.P$`,0```,0[`0!!````]CL!`#,````X
M/`$`)0```&P\`0`]````DCP!`&4```#0/`$`30```#8]`0`I````A#T!`"L`
M``"N/0$`+P```-H]`0`N````"CX!`#`````Y/@$`5````&H^`0!:````OSX!
M`$@````:/P$`2@```&,_`0`R````KC\!`"\```#A/P$`+````!%``0`M````
M/D`!`!<```!L0`$`)0```(1``0`R````JD`!`"D```#=0`$`/@````=!`0`B
M````1D$!`%(```!I00$`)0```+Q!`0`+````XD$!`+$```#N00$`10```*!"
M`0`A````YD(!`#`````(0P$`)0```#E#`0`<````7T,!`#$```!\0P$`!P``
M`*Y#`0`'````MD,!``0```"^0P$`#0```,-#`0`+````T4,!``X```#=0P$`
M"P```.Q#`0`%````^$,!`!````#^0P$``@````]$`0!9````$D0!``,```!L
M1`$`!0```'!$`0`2````=D0!``0```")1`$`!P```(Y$`0`(````ED0!``4`
M``"?1`$``P```*5$`0`0````J40!`!,```"Z1`$`#0```,Y$`0`"````W$0!
M``<```#?1`$`!@```.=$`0`4````[D0!``P````#10$`&````!!%`0`&````
M*44!`!(````P10$`#````$-%`0`#````4$4!``0```!410$`!@```%E%`0`'
M````8$4!`!\```!H10$`-0```(A%`0`N````OD4!`"\```#M10$`%P```!U&
M`0`B````-48!`"4```!81@$`(````'Y&`0`;````GT8!`!@```"[1@$`)```
M`-1&`0`?````^48!`!H````91P$`(0```#1'`0`@````5D<!`!H```!W1P$`
M,@```))'`0`:````Q4<!`"\```#@1P$`*P```!!(`0`?````/$@!`",```!<
M2`$`'P```(!(`0`:````H$@!`"$```"[2`$`)0```-U(`0`F`````TD!`"4`
M```J20$`)````%!)`0`8````=4D!`!T```".20$`)````*Q)`0`8````T4D!
M`"(```#J20$`+`````U*`0`O````.DH!`!4```!J2@$`)0```(!*`0`\````
MIDH!`!\```#C2@$`(P````-+`0`?````)TL!`"````!'2P$`&@```&A+`0`8
M````@TL!`"8```"<2P$`'@```,-+`0`I````XDL!`!X````,3`$`,0```"M,
M`0`)````74P!``P```!G3`$`%P```'1,`0`O````C$P!`"0```"\3`$`!P``
M`.%,`0`/````Z4P!`!0```#Y3`$`#@````Y-`0`-````'4T!`"0````K30$`
M!0```%!-`0`'````5DT!`"(```!>30$`)0```(%-`0`:````ITT!`!T```#"
M30$`&@```.!-`0`'````^TT!`,<````#3@$`"P```,M.`0`5````UTX!``8`
M``#M3@$`"0```/1.`0`+````_DX!``T````*3P$`%P```!A/`0`&````,$\!
M`#,````W3P$`$P```&M/`0`3````?T\!``<```"33P$`#P```)M/`0`'````
MJT\!`#(```"S3P$`!````.9/`0`A````ZT\!`!,````-4`$`#````"%0`0`1
M````+E`!`#(```!`4`$`%@```'-0`0`(````BE`!`!T```"34`$`"0```+%0
M`0`*````NU`!`!0```#&4`$`"@```-M0`0`=````YE`!``@````$40$`#0``
M``U1`0`Z````&U$!`!\```!640$`"````'91`0`:````?U$!``8```":40$`
M%0```*%1`0`'````MU$!``@```"_40$`"0```,A1`0`_````TE$!``<````2
M4@$`#P```!I2`0`.````*E(!`!`````Y4@$`"0```$I2`0`)````5%(!``@`
M``!>4@$`$P```&=2`0`'````>U(!`!D```"#4@$`"@```)U2`0`7````J%(!
M`!0```#`4@$`"@```-52`0`,````X%(!`!<```#M4@$`!`````53`0`J````
M"E,!``P````U4P$`$0```$)3`0`'````5%,!``(```!<4P$`$````%]3`0`8
M````<%,!``L```")4P$``P```)53`0`(````F5,!``8```"B4P$`!P```*E3
M`0`-````L5,!``L```"_4P$`%````,M3`0`5````X%,!``X```#V4P$`%0``
M``54`0`O````&U0!`"````!+5`$`'````&Q4`0`5````B50!``P```"?5`$`
M,0```*Q4`0`)````WE0!``X```#H5`$`.P```/=4`0`5````,U4!``4```!)
M50$`$@```$]5`0`_````8E4!`!(```"B50$`"@```+55`0`&````P%4!``0`
M``#'50$`!````,Q5`0`*````T54!`!,```#<50$`!0```/!5`0`&````]E4!
M``8```#]50$`"`````16`0`$````#58!``P````25@$`"@```!]6`0`Y````
M*E8!`"X```!D5@$`"@```)-6`0`,````GE8!``P```"K5@$`#0```+A6`0`9
M````QE8!`!\```#@5@$`'0````!7`0`1````'E<!``(````P5P$`!````#-7
M`0`*````.%<!``8```!#5P$`!0```$I7`0`#````4%<!``P```!45P$`10``
M`&%7`0`R````IU<!`#$```#:5P$`,P````Q8`0`:````0%@!`#0```!;6`$`
M*````)!8`0!3````N5@!`!D````-60$`<@```"=9`0`@````FED!`#4```"[
M60$`(0```/%9`0!%````$UH!`#````!96@$`*````(I:`0`I````LUH!`"8`
M``#=6@$`8`````1;`0`E````95L!`"@```"+6P$`*````+1;`0`B````W5L!
M`"L`````7`$`,````"Q<`0`2````75P!`!,```!P7`$`$````(1<`0!Y````
ME5P!``D````/70$`H0```!E=`0!S````NUT!`'P````O7@$`*P```*Q>`0!4
M````V%X!`!<````M7P$`)P```$5?`0`6````;5\!``\```"$7P$`%P```)1?
M`0`?````K%\!`$````#,7P$`'P````U@`0`<````+6`!`%$```!*8`$`&@``
M`)Q@`0`4````MV`!``H```#,8`$`!0```-=@`0`&````W6`!``@```#D8`$`
M$@```.U@`0`,`````&$!`!`````-80$`$P```!YA`0`=````,F$!``\```!0
M80$`&P```&!A`0`D````?&$!``\```"A80$`"@```+%A`0`$````O&$!``D`
M``#!80$`"P```,MA`0`:````UV$!`"(```#R80$`"````!5B`0`'````'F(!
M``4````F8@$`%````"QB`0`I````06(!``<```!K8@$`"````'-B`0`/````
M?&(!`!@```",8@$`%````*5B`0`(````NF(!``P```##8@$`#P```-!B`0`'
M````X&(!``8```#H8@$`%````.]B`0`&````!&,!``D````+8P$`"@```!5C
M`0`&````(&,!``P````G8P$``P```#1C`0`(````.&,!`!D```!!8P$`$0``
M`%MC`0`*````;6,!`!@```!X8P$`$P```)%C`0`<````I6,!`!$```#"8P$`
M&@```-1C`0`/````[V,!``4```#_8P$`!`````5D`0`9````"F0!``<````D
M9`$``@```"QD`0`"````+V0!`!$````R9`$`"0```$1D`0`(````3F0!``8`
M``!79`$`$@```%YD`0`7````<60!``8```")9`$`(0```)!D`0`%````LF0!
M``(```"X9`$`!````+MD`0`/````P&0!`!,```#09`$`!P```.1D`0`"````
M[&0!``<```#O9`$`$0```/=D`0`&````"64!`"$````090$`&````#)E`0`&
M````2V4!`!,```!290$`$````&9E`0`>````=V4!`!(```"690$``@```*EE
M`0`&````K&4!``P```"S90$`"0```,!E`0`1````RF4!`"(```#<90$`!P``
M`/]E`0`'````!V8!``L````/9@$`!0```!MF`0`"````(68!``L````D9@$`
M7P$``#!F`0`*````D&<!``P```";9P$`"@```*AG`0`'````LV<!``<```"[
M9P$`!P```,-G`0`%````RV<!``(```#19P$`!0```-1G`0`1````VF<!`!@`
M``#L9P$`*P````5H`0`:````,6@!`!T```!,:`$`$P```&IH`0`1````?F@!
M`"D```"0:`$`#0```+IH`0`;````R&@!`!(```#D:`$`"P```/=H`0`'````
M`VD!``4````+:0$`$@```!%I`0`'````)&D!``<````L:0$`"P```#1I`0`)
M````0&D!``L```!*:0$`/````%9I`0`)````DVD!``4```"=:0$`"@```*-I
M`0`/````KFD!``H```"^:0$`"@```,EI`0`*````U&D!``H```#?:0$`!@``
M`.II`0!9````\6D!``<```!+:@$`#````%-J`0`2````8&H!``H```!S:@$`
M"0```'YJ`0`)````B&H!``D```"2:@$`!@```)QJ`0`=````HVH!`!0```#!
M:@$`)0```-9J`0`M````_&H!`$`````J:P$`1````&MK`0!$````L&L!`$H`
M``#U:P$`)P```$!L`0`(````:&P!``@```!Q;`$`"````'IL`0`(````@VP!
M``@```",;`$`"0```)5L`0`(````GVP!``X```"H;`$`!P```+=L`0`&````
MOVP!``8```#&;`$`&P```,UL`0`;````Z6P!``@````%;0$`"@````YM`0`+
M````&6T!``0````E;0$`&0```"IM`0`$````1&T!`"$```!);0$`!````&MM
M`0`*````<&T!``H```![;0$`"0```(9M`0`(````D&T!``@```"9;0$`$0``
M`*)M`0`0````M&T!``\```#%;0$`"````-5M`0`-````WFT!``8```#L;0$`
M&0```/-M`0`/````#6X!`!`````=;@$`"@```"YN`0`S````.6X!`"L```!M
M;@$`&P```)EN`0`$````M6X!``0```"Z;@$`!@```+]N`0`A````QFX!``0`
M``#H;@$`!````.UN`0`4````\FX!`!0````';P$`%````!QO`0`(````,6\!
M``0````Z;P$`"0```#]O`0`$````26\!`!(```!.;P$`"````&%O`0`(````
M:F\!``8```!S;P$`#````'IO`0`(````AV\!`!8```"0;P$`%P```*=O`0`&
M````OV\!``X```#&;P$`#@```-5O`0`0````Y&\!`!````#U;P$`"`````9P
M`0`(````#W`!`!T````8<`$`$P```#9P`0`5````2G`!`!````!@<`$`#P``
M`'%P`0`3````@7`!``P```"5<`$`!````*)P`0`&````IW`!`!4```"N<`$`
M*@```,1P`0`,````[W`!``@```#\<`$`#`````5Q`0`.````$G$!``P````A
M<0$`$@```"YQ`0`$````07$!``@```!&<0$`!````$]Q`0`7````5'$!``H`
M``!L<0$`"@```'=Q`0`7````@G$!`!H```":<0$`)````+5Q`0`2````VG$!
M`!(```#M<0$`%@````!R`0`$````%W(!`!`````<<@$`$````"UR`0`(````
M/G(!``\```!'<@$`&P```%=R`0`(````<W(!`!D```!\<@$`&0```)9R`0`9
M````L'(!`!D```#*<@$`!````.1R`0`$````Z7(!`!0```#N<@$`$`````-S
M`0`J````%',!`",````_<P$`*0```&-S`0!K````C7,!`"@```#Y<P$`*```
M`")T`0`Q````2W0!`#$```!]=`$`*````*]T`0`I````V'0!`!P````"=0$`
M'````!]U`0`Q````/'4!`"@```!N=0$`+@```)=U`0`4````QG4!``D```#;
M=0$`#````.5U`0`0````\G4!``T````#=@$`#0```!%V`0`C````'W8!``L`
M``!#=@$`%0```$]V`0`$````978!``@```!J=@$`$@```'-V`0`8````AG8!
M`!````"?=@$`#@```+!V`0`8````OW8!`!,```#8=@$`$0```.QV`0`4````
M_G8!``0````3=P$`"````!AW`0`&````(7<!``<````H=P$`$````#!W`0`/
M````07<!``P```!1=P$`$````%YW`0`-````;W<!`!$```!]=P$`!````(]W
M`0`&````E'<!``H```";=P$`*0```*9W`0`8````T'<!`"$```#I=P$`"```
M``MX`0`(````%'@!``0````=>`$`!````")X`0`2````)W@!``0````Z>`$`
M!````#]X`0`(````1'@!``0```!->`$`+0```%)X`0`$````@'@!`!$```"%
M>`$`!````)=X`0`-````G'@!``T```"J>`$`'@```+AX`0`8````UW@!`!,`
M``#P>`$`"`````1Y`0`9````#7D!`!`````G>0$`"````#AY`0`#````07D!
M``H```!%>0$`#P```%!Y`0`3````8'D!``8```!T>0$`!@```'MY`0`1````
M@GD!`!$```"4>0$`)@```*9Y`0`1````S7D!`!H```#?>0$`$@```/IY`0`/
M````#7H!``0````=>@$`#````")Z`0`2````+WH!``\```!">@$`(P```%)Z
M`0`2````=GH!`!H```")>@$`,0```*1Z`0`9````UGH!`!,```#P>@$`"```
M``1[`0`*````#7L!``H````8>P$`&0```"-[`0`$````/7L!``@```!">P$`
M"@```$M[`0`+````5GL!``H```!B>P$`"P```&U[`0`(````>7L!`!8```""
M>P$`!````)E[`0`E````GGL!`!$```#$>P$`"````-9[`0`*````WWL!``@`
M``#J>P$`"P```/-[`0`$````_WL!``P````$?`$`&P```!%\`0`*````+7P!
M`"T````X?`$`!````&9\`0`-````:WP!``P```!Y?`$`#````(9\`0`1````
MDWP!``\```"E?`$`#0```+5\`0`(````PWP!`!(```#,?`$`#0```-]\`0`2
M````[7P!`!D`````?0$`%0```!I]`0`"````,'T!`!0````S?0$`"````$A]
M`0`.````47T!``H```!@?0$`$````&M]`0`&````?'T!``X```"#?0$`%```
M`))]`0`(````IWT!``0```"P?0$`!@```+5]`0`"````O'T!`!<```"_?0$`
M"@```-=]`0`(````XGT!`!,```#K?0$`!````/]]`0`&````!'X!``X````+
M?@$``P```!I^`0`(````'GX!``0````G?@$`!````"Q^`0`(````,7X!``0`
M```Z?@$`!````#]^`0`0````1'X!``0```!5?@$`!````%I^`0`$````7WX!
M``0```!D?@$`!````&E^`0`T````;GX!``T```"C?@$`!P```+%^`0`(````
MN7X!``P```#"?@$`,@```,]^`0`)`````G\!``H````,?P$`"````!=_`0`;
M````('\!`"D````\?P$`&@```&9_`0`&````@7\!`!\```"(?P$`!````*A_
M`0`4````K7\!``T```#"?P$`!````-!_`0`7````U7\!``0```#M?P$`!P``
M`/)_`0`,````^G\!``D````'@`$`!````!&``0`7````%H`!`!@````N@`$`
M%0```$>``0`9````78`!`!<```!W@`$`%P```(^``0`2````IX`!`!0```"Z
M@`$`%````,^``0`0````Y(`!`!8```#U@`$`(@````R!`0`4````+X$!`!,`
M``!$@0$`%0```%B!`0`2````;H$!`!0```"!@0$`%@```):!`0`=````K8$!
M`!4```#+@0$`%P```.&!`0`9````^8$!`!(````3@@$`$@```":"`0`=````
M.8(!`!4```!7@@$`#````&V"`0`7````>H(!`!(```"2@@$`%@```*6"`0`,
M````O((!`$L```#)@@$`)P```!6#`0`2````/8,!`!0```!0@P$`%````&6#
M`0`8````>H,!``T```"3@P$`$@```*&#`0`3````M(,!`!$```#(@P$`%0``
M`-J#`0`9````\(,!`!0````*A`$`3````!^$`0`6````;(0!``X```"#A`$`
M$@```)*$`0`4````I80!`!D```"ZA`$`*@```-2$`0`M````_X0!``8````M
MA0$`!````#2%`0`$````.84!``0````^A0$`#````$.%`0`,````4(4!``P`
M``!=A0$`#````&J%`0`,````=X4!``H```"$A0$`$@```(^%`0`+````HH4!
M``@```"NA0$`"````+>%`0`(````P(4!``P```#)A0$`"````-:%`0`,````
MWX4!``H```#LA0$`'P```/>%`0`$````%X8!``0````<A@$`$0```"&&`0`1
M````,X8!`!<```!%A@$`&@```%V&`0`;````>(8!``(```"4A@$`"````)>&
M`0!5````H(8!``0```#VA@$`#````/N&`0`*````"(<!``0````3AP$`"```
M`!B'`0`(````(8<!``0````JAP$`"@```"^'`0`$````.H<!``8````_AP$`
M"@```$:'`0`(````48<!``0```!:AP$`"````%^'`0`.````:(<!`!4```!W
MAP$`!````(V'`0`$````DH<!``<```"7AP$`"@```)^'`0`(````JH<!``@`
M``"SAP$`"````+R'`0`(````Q8<!``X```#.AP$`"@```-V'`0`(````Z(<!
M`!(```#QAP$`#`````2(`0`.````$8@!`"`````@B`$`!@```$&(`0`8````
M2(@!``X```!AB`$`#````'"(`0`&````?8@!`!4```"$B`$`$````)J(`0`:
M````JX@!`!X```#&B`$`#````.6(`0`(````\H@!``X```#[B`$`"`````J)
M`0`$````$XD!`!T````8B0$`%P```#:)`0`$````3HD!``@```!3B0$`%@``
M`%R)`0`*````<XD!``@```!^B0$`"````(>)`0`$````D(D!``<```"5B0$`
M!@```)V)`0`1````I(D!``@```"VB0$`#@```+^)`0`K````SHD!``X```#Z
MB0$`"`````F*`0`(````$HH!`!$````;B@$`*P```"V*`0`&````68H!`!P`
M``!@B@$`#0```'V*`0`I````BXH!``@```"UB@$`!@```+Z*`0`(````Q8H!
M``8```#.B@$`%P```-6*`0`3````[8H!`",````!BP$`$P```"6+`0`$````
M.8L!``<````^BP$`'````$:+`0`*````8XL!``0```!NBP$`"````'.+`0`$
M````?(L!`!(```"!BP$`!````)2+`0`'````F8L!``@```"ABP$`"````*J+
M`0`(````LXL!``@```"\BP$`#````,6+`0`(````THL!``X```#;BP$`#```
M`.J+`0`$````]XL!``P```#\BP$`%@````F,`0`'````((P!``@````HC`$`
M#````#&,`0`5````/HP!``P```!4C`$`$P```&&,`0`(````=8P!``D```!^
MC`$`"0```(B,`0`,````DHP!``<```"?C`$`*@```*>,`0`3````THP!``8`
M``#FC`$`"````.V,`0`&````]HP!``H```#]C`$`/`````B-`0`2````18T!
M``0```!8C0$`'@```%V-`0`4````?(T!``0```"1C0$`%````):-`0`;````
MJXT!`!L```#'C0$`%@```..-`0`E````^HT!`!,````@C@$`%P```#2.`0`5
M````3(X!`!(```!BC@$`$P```'6.`0`$````B8X!``T```".C@$`"@```)R.
M`0`)````IXX!``H```"QC@$`"0```+R.`0`(````QHX!``H```#/C@$`"0``
M`-J.`0`'````Y(X!``0```#LC@$`#````/&.`0`$````_HX!``0````#CP$`
M"@````B/`0`(````$X\!`!<````<CP$`!@```#2/`0`&````.X\!``@```!"
MCP$`#0```$N/`0`0````68\!`!<```!JCP$`%@```(*/`0`0````F8\!`!``
M``"JCP$`&P```+N/`0`0````UX\!``P```#HCP$`!````/6/`0`N````^H\!
M``T````ID`$`"0```#>0`0`$````09`!``0```!&D`$`!````$N0`0`$````
M4)`!``8```!5D`$`!@```%R0`0`(````8Y`!``@```!LD`$`"P```'60`0`3
M````@9`!`!$```"5D`$`"````*>0`0`(````L)`!``@```"YD`$`"````,*0
M`0`5````RY`!`!(```#AD`$`%@```/20`0`8````"Y$!``H````DD0$`"```
M`"^1`0`(````.)$!``X```!!D0$`"@```%"1`0`H````6Y$!`!L```"$D0$`
M*````*"1`0`K````R9$!`#P```#UD0$`)P```#*2`0`\````6I(!``T```"7
MD@$`!@```*62`0`.````K)(!``8```"[D@$`!````,*2`0`(````QY(!``@`
M``#0D@$`!````-F2`0`"````WI(!``X```#AD@$`"````/"2`0`$````^9(!
M`!D```#^D@$`&P```!B3`0`.````-),!`$X```!#DP$`"@```)*3`0`$````
MG9,!``0```"BDP$`"````*>3`0`$````L),!``8```"UDP$`!````+R3`0`(
M````P9,!`"L```#*DP$`"````/:3`0`,````_Y,!``8````,E`$`!````!.4
M`0`-````&)0!`!0````FE`$`&@```#N4`0`A````5I0!`!L```!XE`$`!@``
M`)24`0`"````FY0!``@```">E`$`!````*>4`0`$````K)0!``P```"QE`$`
M!0```+Z4`0`/````Q)0!`!(```#4E`$`$````.>4`0`6````^)0!``X````/
ME0$`#````!Z5`0`4````*Y4!``0```!`E0$`!````$65`0`&````2I4!``L`
M``!1E0$`"P```%V5`0`$````:94!``0```!NE0$`"@```'.5`0`-````?I4!
M`!,```",E0$`%````*"5`0`2````M94!``@```#(E0$`$````-&5`0`I````
MXI4!`!L````,E@$`&P```"B6`0`$````1)8!`!4```!)E@$`"P```%^6`0`4
M````:Y8!``@```"`E@$`"````(F6`0`(````DI8!``\```";E@$`(````*N6
M`0`/````S)8!``P```#<E@$`$0```.F6`0`,````^Y8!``D````(EP$``@``
M`!*7`0`$````%9<!``0````:EP$`(0```!^7`0`&````09<!`!<```!(EP$`
M!````&"7`0`$````99<!``X```!JEP$`!````'F7`0`$````?I<!`!$```"#
MEP$``@```)67`0`$````F)<!`!$```"=EP$``@```*^7`0`(````LI<!``8`
M``"[EP$`"````,*7`0`3````RY<!`!````#?EP$`!0```/"7`0`P````]I<!
M`!X````GF`$`+````$:8`0`A````<Y@!`"X```"5F`$`)@```,28`0`A````
MZY@!`#$````-F0$`(0```#^9`0`=````89D!`!P```!_F0$`!@```)R9`0`(
M````HYD!``4```"LF0$`%@```+*9`0`5````R9D!``T```#?F0$`$0```.V9
M`0`$````_YD!``8````$F@$`"`````N:`0`0````%)H!`!4````EF@$`%0``
M`#N:`0`=````49H!``<```!OF@$`$````'>:`0`@````B)H!``X```"IF@$`
M#@```+B:`0`&````QYH!``@```#.F@$`"@```->:`0`/````XIH!`#````#R
MF@$`:0```".;`0`^````C9L!``D```#,FP$`"````-:;`0`)````WYL!``P`
M``#IFP$`#0```/:;`0`(````!)P!``0````-G`$`#0```!*<`0`$````()P!
M``P````EG`$`"0```#*<`0`.````/)P!`!,```!+G`$`&@```%^<`0!&````
M>IP!``@```#!G`$`#````,J<`0`*````UYP!`"4```#BG`$`$`````B=`0`=
M````&9T!``0````WG0$`!````#R=`0`-````09T!`!````!/G0$`"````&"=
M`0`(````:9T!``P```!RG0$`$````'^=`0`<````D)T!`!P```"MG0$`&```
M`,J=`0`8````XYT!`!H```#\G0$`&@```!>>`0`.````,IX!`!L```!!G@$`
M$````%V>`0`0````;IX!``X```!_G@$`#@```(Z>`0`(````G9X!``X```"F
MG@$`#@```+6>`0`,````Q)X!``P```#1G@$`#P```-Z>`0`-````[IX!`!$`
M``#\G@$`(0````Z?`0`)````,)\!``0````ZGP$`!@```#^?`0`;````1I\!
M`!````!BGP$`#P```'.?`0`/````@Y\!``\```"3GP$`#@```*.?`0`.````
MLI\!``T```#!GP$`"P```,^?`0`0````VY\!`!8```#LGP$`$P````.@`0`-
M````%Z`!`!$````EH`$`#0```#>@`0`/````1:`!`!$```!5H`$`#P```&>@
M`0`/````=Z`!`!$```"'H`$`!````)F@`0`(````GJ`!`"````"GH`$`#0``
M`,B@`0`0````UJ`!``(```#GH`$`$@```.J@`0`$````_:`!``@````"H0$`
M#P````NA`0`&````&Z$!``0````BH0$`#@```">A`0`0````-J$!``0```!'
MH0$`#````$RA`0`2````6:$!``8```!LH0$`#0```'.A`0`$````@:$!``0`
M``"&H0$`!````(NA`0`$````D*$!``@```"5H0$`"````)ZA`0`(````IZ$!
M``H```"PH0$`"@```+NA`0`,````QJ$!`!(```#3H0$`"````.:A`0`(````
M[Z$!``@```#XH0$`"`````&B`0`(````"J(!``@````3H@$`*````!RB`0`$
M````1:(!`!,```!*H@$`+0```%ZB`0`9````C*(!``T```"FH@$`#P```+2B
M`0`*````Q*(!`#H```#/H@$`"@````JC`0`$````%:,!`"<````:HP$`!@``
M`$*C`0`2````2:,!``8```!<HP$`"0```&.C`0`.````;:,!`!0```!\HP$`
M%@```)&C`0`1````J*,!``0```"ZHP$`"````+^C`0`0````R*,!``0```#9
MHP$`"````-ZC`0`&````YZ,!`!````#NHP$`!````/^C`0`*````!*0!`!(`
M```/I`$`'P```"*D`0`:````0J0!``0```!=I`$`!````&*D`0`(````9Z0!
M``@```!PI`$`!@```'FD`0`(````@*0!``0```")I`$`!@```(ZD`0`&````
ME:0!``0```"<I`$`"0```*&D`0`@````JZ0!``0```#,I`$`'P```-&D`0`*
M````\:0!``P```#\I`$`"`````FE`0`/````$J4!``T````BI0$`$0```#"E
M`0`1````0J4!``\```!4I0$`#P```&2E`0`-````=*4!`!$```""I0$`$```
M`)2E`0`2````I:4!`!8```"XI0$`!````,^E`0`2````U*4!``D```#GI0$`
M"@```/&E`0`*````_*4!``0````'I@$`!`````RF`0`$````$:8!``0````6
MI@$`"````!NF`0`M````)*8!``D```!2I@$`!````%RF`0`$````8:8!``(`
M``!FI@$`#````&FF`0`,````=J8!``P```"#I@$`$P```)"F`0`"````I*8!
M``@```"GI@$`&P```+"F`0`#````S*8!``P```#0I@$`.0```-VF`0`7````
M%Z<!``0````OIP$`!````#2G`0`(````.:<!``T```!"IP$`#P```%"G`0`3
M````8*<!`!,```!TIP$`"P```(BG`0`.````E*<!`"````"CIP$`"@```,2G
M`0`-````SZ<!`!(```#=IP$`!````/"G`0`$````]:<!``L```#ZIP$`$@``
M``:H`0`D````&:@!`!T````^J`$`%P```%RH`0`5````=*@!``H```"*J`$`
M%P```)6H`0`4````K:@!``\```#"J`$`%P```-*H`0`8````ZJ@!`!<````#
MJ0$`#````!NI`0`,````**D!``P````UJ0$`/0```$*I`0!!````@*D!``0`
M``#"J0$`$@```,>I`0`$````VJD!``0```#?J0$`"0```.2I`0`*````[JD!
M``0```#YJ0$`+@```/ZI`0`+````+:H!``@````YJ@$`$P```$*J`0`K````
M5JH!`!$```""J@$`!````)2J`0`2````F:H!`!H```"LJ@$`!````,>J`0`/
M````S*H!`"X```#<J@$`!`````NK`0`)````$*L!`!@````:JP$`%P```#.K
M`0`4````2ZL!``0```!@JP$`!````&6K`0`>````:JL!`!````")JP$`'```
M`)JK`0`U````MZL!`!````#MJP$`&````/ZK`0`8````%ZP!`!P````PK`$`
M$````$VL`0`&````7JP!``@```!EK`$`!````&ZL`0`(````<ZP!``@```!\
MK`$`!````(6L`0`?````BJP!``\```"JK`$`#P```+JL`0`&````RJP!``0`
M``#1K`$`"````-:L`0`$````WZP!`",```#DK`$`!@````BM`0`(````#ZT!
M``@````8K0$`"````"&M`0`$````*JT!``0````OK0$`!````#2M`0`$````
M.:T!``X````^K0$`#@```$VM`0`$````7*T!``0```!AK0$`!````&:M`0`5
M````:ZT!`!````"!K0$`!````)*M`0`(````EZT!``P```"@K0$`"````*VM
M`0`0````MJT!``X```#'K0$`"P```-:M`0`3````XJT!``0```#VK0$`$@``
M`/NM`0`,````#JX!``X````;K@$`$@```"JN`0`C````/:X!`!4```!AK@$`
M%0```'>N`0`5````C:X!`!$```"CK@$`$0```+6N`0`7````QZX!`!,```#?
MK@$`$0```/.N`0`(````!:\!``0````.KP$`'````!.O`0`(````,*\!``D`
M```YKP$`!````$.O`0`(````2*\!`!4```!1KP$`%````&>O`0`&````?*\!
M`!$```"#KP$`#0```)6O`0`/````HZ\!``0```"SKP$`"````+BO`0`&````
MP:\!``H```#(KP$`!@```-.O`0`4````VJ\!``P```#OKP$`$@```/RO`0`$
M````#[`!``T````4L`$``@```"*P`0`K````);`!`!D```!1L`$`&@```&NP
M`0`4````AK`!`"0```";L`$`#0```,"P`0`:````SK`!`"$```#IL`$`"0``
M``NQ`0`;````%;$!`!<````QL0$`'````$FQ`0`;````9K$!`"````""L0$`
M"P```*.Q`0`+````K[$!``H```"[L0$`(@```,:Q`0`*````Z;$!``L```#T
ML0$`$`````"R`0`1````$;(!``L````CL@$`"P```"^R`0`+````.[(!`!L`
M``!'L@$`&P```&.R`0`?````?[(!`!P```"?L@$`'0```+RR`0`:````VK(!
M`$@```#UL@$`$P```#ZS`0`.````4K,!``8```!ALP$`#P```&BS`0`5````
M>+,!``8```".LP$`"@```)6S`0`(````H+,!`!,```"ILP$`%P```+VS`0`7
M````U;,!``8```#MLP$`*P```/2S`0`M````(+0!``(```!.M`$`$0```%&T
M`0`6````8[0!`!D```!ZM`$`!@```)2T`0`8````F[0!``T```"TM`$`!@``
M`,*T`0`&````R;0!``P```#0M`$`!@```-VT`0`-````Y+0!``8```#RM`$`
M"````/FT`0`&`````K4!`!(````)M0$`!````!RU`0`&````(;4!``0````H
MM0$`!@```"VU`0`(````-+4!``0````]M0$`&0```$*U`0`"````7+4!``0`
M``!?M0$`"@```&2U`0`&````;[4!``0```!VM0$`!@```'NU`0`7````@K4!
M``8```":M0$`#````*&U`0`+````KK4!`",```"ZM0$`"@```-ZU`0`3````
MZ;4!`"8```#]M0$`#@```"2V`0`M````,[8!`!(```!AM@$`"````'2V`0`$
M````?;8!`!<```""M@$`!@```)JV`0`(````H;8!``0```"JM@$`"````*^V
M`0`$````N+8!`!````"]M@$`%````,ZV`0`$````X[8!``@```#HM@$`"```
M`/&V`0`$````^K8!``H```#_M@$`#0````JW`0`0````&+<!``P````IMP$`
M#````#:W`0`,````0[<!`!8```!0MP$`"@```&>W`0`(````<K<!``@```![
MMP$`"````(2W`0`(````C;<!``@```"6MP$`!@```)^W`0`(````IK<!`!0`
M``"OMP$`"@```,2W`0`$````S[<!`!,```#4MP$`#````.BW`0`P````];<!
M``\````FN`$`(0```#:X`0`1````6+@!``0```!JN`$`!````&^X`0`-````
M=+@!``H```""N`$`'0```(VX`0`(````J[@!``4```"TN`$`!@```+JX`0`-
M````P;@!``0```#/N`$`!````-2X`0`$````V;@!``H```#>N`$`!````.FX
M`0`&````[K@!``P```#UN`$`$P````*Y`0`$````%KD!`!,````;N0$`"```
M`"^Y`0`$````.+D!``@````]N0$`!````$:Y`0`+````2[D!``0```!7N0$`
M%````%RY`0`$````<;D!``0```!VN0$`"````'NY`0`$````A+D!`!````")
MN0$`$P```)JY`0`;````KKD!`!4```#*N0$`%0```."Y`0`8````]KD!`"8`
M```/N@$`%0```#:Z`0`5````3+H!`!$```!BN@$`&@```'2Z`0`N````C[H!
M`!,```"^N@$`#0```-*Z`0`$````X+H!``0```#EN@$`$0```.JZ`0`(````
M_+H!``@````%NP$`*P````Z[`0`6````.KL!``X```!1NP$`*0```&"[`0`O
M````BKL!``0```"ZNP$`#````+^[`0`&````S+L!``0```#3NP$`$@```-B[
M`0`*````Z[L!``@```#VNP$`"````/^[`0`$````"+P!``@````-O`$`!```
M`!:\`0`(````&[P!``@````DO`$`#````"V\`0`,````.KP!`!H```!'O`$`
M%@```&*\`0`,````>;P!``0```"&O`$`"````(N\`0`6````E+P!``8```"K
MO`$`!@```+*\`0`"````N;P!``8```"\O`$`!@```,.\`0`$````RKP!``8`
M``#/O`$`!@```-:\`0`(````W;P!``0```#FO`$`!````.N\`0`(````\+P!
M`"4```#YO`$`,@```!^]`0`6````4KT!``H```!IO0$`"````'2]`0`(````
M?;T!`!4```"&O0$`%0```)R]`0`*````LKT!``@```"]O0$`#````,:]`0`*
M````T[T!``0```#>O0$`!````..]`0`*````Z+T!`"@```#SO0$`!````!R^
M`0`(````(;X!``@````JO@$`"````#.^`0`&````/+X!`"<```!#O@$`!```
M`&N^`0`4````<+X!``H```"%O@$`#@```)"^`0`7````G[X!`!$```"WO@$`
M&@```,F^`0`7````Y+X!`!4```#\O@$`"````!*_`0`*````&[\!``P````F
MOP$`!````#._`0`(````.+\!``T```!!OP$`$````$^_`0`$````8+\!``P`
M``!EOP$`"````'*_`0`,````>[\!``X```"(OP$`$@```)>_`0`(````JK\!
M``X```"SOP$`!````,*_`0`$````Q[\!``@```#,OP$`!@```-6_`0`+````
MW+\!``0```#HOP$`$@```.V_`0`+`````,`!`!`````,P`$`$````!W``0`&
M````+L`!``8````UP`$``@```#S``0`$````/\`!``H```!$P`$`"@```$_`
M`0`*````6L`!``H```!EP`$`"````'#``0`$````><`!``P```!^P`$`"```
M`(O``0`&````E,`!``0```";P`$`&P```*#``0`/````O,`!``\```#,P`$`
M%@```-S``0`.````\\`!``0````"P0$`"@````?!`0`*````$L$!`!8````=
MP0$`!````#3!`0`,````.<$!``8```!&P0$`%P```$W!`0`L````9<$!`!8`
M``"2P0$`&0```*G!`0`S````P\$!`!(```#WP0$`$@````K"`0`5````'<(!
M`"@````SP@$`"@```%S"`0`;````9\(!``0```"#P@$`"0```(C"`0`'````
MDL(!``@```":P@$`"````*/"`0`X````K,(!``\```#EP@$`%P```/7"`0`(
M````#<,!``0````6PP$`"````!O#`0`,````),,!`!`````QPP$`$P```$+#
M`0`/````5L,!``0```!FPP$`"````&O#`0`$````=,,!``@```!YPP$`#```
M`(+#`0`,````C\,!`!0```"<PP$`$@```+'#`0`.````Q,,!`!8```#3PP$`
M"````.K#`0`1````\\,!``P````%Q`$`!@```!+$`0`.````&<0!`$,````H
MQ`$`#0```&S$`0`1````>L0!`!4```",Q`$`#0```*+$`0`1````L,0!`!<`
M``#"Q`$`$````-K$`0`-````Z\0!``@```#YQ`$`#`````+%`0`(````#\4!
M`!0````8Q0$`$@```"W%`0`(````0,4!``0```!)Q0$`+````$[%`0`$````
M>\4!`!L```"`Q0$`"````)S%`0`/````I<4!``0```"UQ0$`"````+K%`0`H
M````P\4!`"$```#LQ0$`(P````[&`0`Z````,L8!``\```!MQ@$`!````'W&
M`0`,````@L8!`!P```"/Q@$`$P```*S&`0`$````P,8!``@```#%Q@$`(0``
M`,[&`0`$````\,8!`!8```#UQ@$`%`````S'`0`?````(<<!`"````!!QP$`
M"@```&+'`0`4````;<<!`!4```""QP$`%@```)C'`0`4````K\<!`!(```#$
MQP$`%````-?'`0`(````[,<!``@```#UQP$`"````/['`0`(````!\@!``H`
M```0R`$`!````!O(`0`7````(,@!``0````XR`$`!````#W(`0`(````0L@!
M`!(```!+R`$`!````%[(`0`(````8\@!`!,```!LR`$`%0```(#(`0`"````
MEL@!``0```"9R`$`!````)[(`0`(````H\@!``@```"LR`$`"@```+7(`0`<
M````P,@!`!(```#=R`$`!@```/#(`0`,````]\@!``@````$R0$`$P````W)
M`0`1````(<D!`"P````SR0$`!@```&#)`0`&````9\D!``0```!NR0$`"@``
M`'/)`0`.````?LD!``@```"-R0$`#````);)`0`(````H\D!``@```"LR0$`
M!@```+7)`0`$````O,D!`!0```#!R0$`!````-;)`0`*````V\D!``@```#F
MR0$``@```._)`0`$````\LD!`"P```#WR0$`"````"3*`0`$````+<H!``8`
M```RR@$`!@```#G*`0`8````0,H!``H```!9R@$`!@```&3*`0`1````:\H!
M`!$```!]R@$`!````(_*`0`$````E,H!`#\```"9R@$`!````-G*`0`$````
MWLH!`!D```#CR@$`)0```/W*`0`/````(\L!`!@````SRP$`)0```$S+`0`5
M````<LL!`!@```"(RP$`#P```*'+`0`/````L<L!``P```#!RP$`!````,[+
M`0`$````T\L!``0```#8RP$``@```-W+`0`$````X,L!``D```#ERP$`!@``
M`._+`0`$````]LL!``8```#[RP$`!`````+,`0`$````!\P!`!$````,S`$`
M!````![,`0`6````(\P!`!0````ZS`$`#0```$_,`0`2````7<P!``X```!P
MS`$`#````'_,`0`4````C,P!`!T```"AS`$`!````+_,`0`(````Q,P!``0`
M``#-S`$`#````-+,`0`0````W\P!``0```#PS`$`"````/7,`0`(````_LP!
M``0````'S0$`!`````S-`0`5````$<T!`"<````GS0$`!0```$_-`0`(````
M5<T!``@```!>S0$`$@```&?-`0`$````>LT!``8```!_S0$`(0```(;-`0`0
M````J,T!``@```"YS0$`!````,+-`0`&````Q\T!``@```#.S0$`#````-?-
M`0`&````Y,T!``X```#KS0$`#P```/K-`0`8````"LX!`"$````CS@$`%```
M`$7.`0`<````6LX!`!8```!WS@$`(P```([.`0`E````LLX!`#L```#8S@$`
M!@```!3/`0`F````&\\!`!\```!"SP$`*````&+/`0`Z````B\\!``\```#&
MSP$`$````-;/`0`;````Y\\!`!T````#T`$`'0```"'0`0`3````/]`!`!$`
M``!3T`$`&0```&70`0`5````?]`!``8```"5T`$`,````)S0`0!E````S=`!
M`!X````ST0$`#P```%+1`0`O````8M$!`#$```"2T0$`+P```,31`0`5````
M]-$!``@````*T@$`!@```!/2`0`9````&M(!`!<````TT@$`%P```$S2`0`6
M````9-(!`!,```![T@$`$P```(_2`0`=````H](!``@```#!T@$`!@```,K2
M`0`?````T=(!`!,```#QT@$`&0````73`0`8````'],!``T````XTP$`$0``
M`$;3`0!"````6-,!`"0```";TP$`)0```,#3`0`?````YM,!`!P````&U`$`
M)````"/4`0`Y````2-0!`"\```""U`$`&P```++4`0`;````SM0!`!<```#J
MU`$`&P````+5`0`B````'M4!`#@```!!U0$`,0```'K5`0`K````K-4!`"D`
M``#8U0$`)0````+6`0`>````*-8!`!X```!'U@$`&P```&;6`0`1````@M8!
M`!D```"4U@$`&P```*[6`0`;````RM8!`"0```#FU@$`#P````O7`0`]````
M&]<!`!,```!9UP$`"````&W7`0!J````=M<!`#,```#AUP$`$P```!78`0`M
M````*=@!`!<```!7V`$`#P```&_8`0`D````?]@!``(```"DV`$`"````*?8
M`0`$````L-@!``@```"UV`$`"````+[8`0`(````Q]@!``L```#0V`$`!```
M`-S8`0`/````X=@!``8```#QV`$`2P```/C8`0`%````1-D!``0```!*V0$`
M"P```$_9`0`+````6]D!``<```!GV0$`!````&_9`0`,````=-D!``0```"!
MV0$`$0```(;9`0`.````F-D!``8```"GV0$`!@```*[9`0`2````M=D!``\`
M``#(V0$`%0```-C9`0`,````[MD!`!@```#[V0$`#P```!3:`0`.````)-H!
M``P````SV@$`!````$#:`0`%````1=H!``\```!+V@$`$````%O:`0`2````
M;-H!`!\```!_V@$`'@```)_:`0`?````OMH!``X```#>V@$`%@```.W:`0`9
M````!-L!`!0````>VP$`$@```#/;`0`2````1ML!`!<```!9VP$`$@```'';
M`0`2````A-L!`!<```"7VP$`&````*_;`0`1````R-L!`!T```#:VP$`$0``
M`/C;`0`:````"MP!`!$````EW`$`$@```#?<`0`6````2MP!`!<```!AW`$`
M$@```'G<`0`7````C-P!`!4```"DW`$`$P```+K<`0`0````SMP!`!,```#?
MW`$`$@```//<`0`7````!MT!`!(````>W0$`$@```#'=`0`/````1-T!`"8`
M``!4W0$`*0```'O=`0`.````I=T!`!8```"TW0$`)P```,O=`0`8````\]T!
M`!8````,W@$`'@```"/>`0`?````0MX!`!@```!BW@$`$P```'O>`0`2````
MC]X!`!<```"BW@$`(@```+K>`0`6````W=X!`"````#TW@$`!````!7?`0`(
M````&M\!``0````CWP$`'@```"C?`0`;````1]\!``8```!CWP$`#@```&K?
M`0`G````>=\!`!4```"AWP$`%````+??`0`D````S-\!``0```#QWP$`!@``
M`/;?`0`E````_=\!`"0````CX`$`#P```$C@`0`7````6.`!`!(```!PX`$`
M!@```(/@`0"-````BN`!``@````8X0$`#@```"'A`0`$````,.$!``<````U
MX0$`"@```#WA`0`+````2.$!``\```!4X0$`!````&3A`0`C````:>$!``P`
M``"-X0$`#````)KA`0`0````I^$!``X```"XX0$`"````,?A`0`U````T.$!
M``8````&X@$`'P````WB`0`*````+>(!``H````XX@$`"@```$/B`0`=````
M3N(!`!````!LX@$`"@```'WB`0`7````B.(!``L```"@X@$`"````*SB`0`/
M````M>(!`!4```#%X@$`$0```-OB`0`(````[>(!``P```#VX@$`*P````/C
M`0`2````+^,!``8```!"XP$`&````$GC`0`"````8N,!``@```!EXP$`$@``
M`&[C`0`$````@>,!`!0```"&XP$`)````)OC`0`$````P.,!``@```#%XP$`
M"````,[C`0`(````U^,!``4```#@XP$`!@```.;C`0`/````[>,!``\```#]
MXP$`!P````WD`0`,````%>0!``H````BY`$`)@```"WD`0`C````5.0!``8`
M``!XY`$`"````'_D`0`=````B.0!``0```"FY`$`&P```*OD`0`-````Q^0!
M`!$```#5Y`$`!````.?D`0`&````[.0!``@```#SY`$`#````/SD`0`0````
M">4!``0````:Y0$`!````!_E`0`$````).4!``0````IY0$`"0```"[E`0`(
M````..4!`!$```!!Y0$`$@```%/E`0`9````9N4!`!4```"`Y0$`(P```);E
M`0`/````NN4!``\```#*Y0$`%@```-KE`0`(````\>4!`"(```#ZY0$`"```
M`!WF`0`,````)N8!`"L````SY@$`&@```%_F`0`$````>N8!`!,```!_Y@$`
M(P```)/F`0`(````M^8!``@```#`Y@$`!0```,GF`0`(````S^8!``(```#8
MY@$`!@```-OF`0`(````XN8!``4```#KY@$`!@```/'F`0`$````^.8!``@`
M``#]Y@$`!`````;G`0`*````"^<!``H````6YP$`.````"'G`0`P````6N<!
M``@```"+YP$`"P```)3G`0`+````H.<!``L```"LYP$`$P```+CG`0`3````
MS.<!`!4```#@YP$`#0```/;G`0`"````!.@!``(````'Z`$`#`````KH`0`$
M````%^@!``P````<Z`$``@```"GH`0`+````+.@!`#T````XZ`$`&0```';H
M`0`?````D.@!`!L```"PZ`$`"P```,SH`0`A````V.@!`"$```#ZZ`$`)0``
M`!SI`0`+````0ND!`%,```!.Z0$`%P```*+I`0!!````NND!`"@```#\Z0$`
M(0```"7J`0`<````1^H!`!4```!DZ@$`%0```'KJ`0`5````D.H!`#0```"F
MZ@$`%0```-OJ`0`5````\>H!`!,````'ZP$`%P```!OK`0`B````,^L!`!X`
M``!6ZP$`$````'7K`0`7````ANL!``@```">ZP$`4P```*?K`0`(````^^L!
M`%8````$[`$`+0```%OL`0!1````B>P!`!L```#;[`$`-@```/?L`0`3````
M+NT!`!D```!"[0$`$P```%SM`0`)````<.T!``\```!Z[0$`&````(KM`0`;
M````H^T!``\```"_[0$`$@```,_M`0`Z````XNT!``\````=[@$`#P```"WN
M`0`5````/>X!``P```!3[@$`#P```&#N`0`1````<.X!``H```""[@$`"```
M`(WN`0`*````ENX!``L```"A[@$`$@```*WN`0`4````P.X!`!\```#5[@$`
M&P```/7N`0`&````$>\!``@````8[P$`"````"'O`0`*````*N\!``@````U
M[P$`#@```#[O`0`E````3>\!``H```!S[P$`!@```'[O`0`&````A>\!``T`
M``",[P$`%P```)KO`0`&````LN\!``8```"Y[P$`#0```,#O`0`3````SN\!
M`!,```#B[P$`!@```/;O`0`&````_>\!``\````$\`$`"@```!3P`0`&````
M'_`!``T````F\`$`"````#3P`0`*````/?`!``H```!(\`$`!````%/P`0`&
M````6/`!``0```!?\`$`!@```&3P`0`0````:_`!``P```!\\`$`!````(GP
M`0`.````CO`!``@```"=\`$`$@```*;P`0`,````N?`!`!D```#&\`$`"@``
M`.#P`0`$````Z_`!``0```#P\`$`$P```/7P`0`$````"?$!``,````.\0$`
M`@```!+Q`0`2````%?$!``0````H\0$`!````"WQ`0`0````,O$!``T```!#
M\0$`#````%'Q`0`#````7O$!`"````!B\0$`!````(/Q`0`"````B/$!``0`
M``"+\0$`"0```)#Q`0`)````FO$!``8```"D\0$`!````*OQ`0`&````L/$!
M``@```"W\0$`!````,#Q`0`8````Q?$!`!````#>\0$`!````._Q`0`,````
M]/$!``@````!\@$`&@````KR`0`3````)?(!``(````Y\@$`!````#SR`0`(
M````0?(!``8```!*\@$`#````%'R`0`:````7O(!``0```!Y\@$`!@```'[R
M`0`*````A?(!``4```"0\@$`!0```);R`0`0````G/(!``$```!:!@``N0(`
M``````!5!@``(0$``'('``!^!````````+`'```C!0```````*0'``"F````
M`````#0%````````=P$``(8%````````3P$````````[!```2`<``$,%``#(
M`@``$0,```````!&`P``R`$``/H'``````````````````#F`0``J`0``'$#
M``!X!P``+P```*@#``"L!@``FP8```````#T!`````````````"B````````
M`$D#``#C!0``,@````\&``!0`P````````````"Y!P```````'0'```.!@``
M'0(``$8%```_`P```````/<#```:`P```````$D"````````O@8``/(&``#9
M`0``L`4```````"#!0``/P4``#D'``````````````````!4!```````````
M````````,08````````S`0``;P<``.@#```%!@```@(````````&!@``1`8`
M``P(``#%`0``A````'8```!S`P``?`4```````#A`@``````````````````
M+P,``(4#``",!`````````````"6````N@<``%`&``"V!P``/@$``-,&``#*
M!```70$``,`'``#+!0```````%@&```M!````````,P#``!U!0``U`4`````
M``#P!```"P@``)4!``"K`@``5`(`````````````A@0``/<!``"T!```30``
M`-`!``#]!@``$P```#,&``#,````U@4``$H&``"P`0``,`(``-4!````````
M````````````````V0,`````````````P@(``/$%``"Z!```JP8```````!6
M`0``&@(``/D$```<!```HP,```````#Y!P``/`0`````````````N`8``.X'
M```Y`@``AP8```(`````````H0<``"8'``"5`P```````,$$``!C!P``````
M`)X'``#$!P``]P(``)P%```_`````````"D`````````DP4``,L```!2!@``
M7@8``)(#``#?`P``9`8``*8&``!2````X`0``$,'```W!P``7@4``!0&``!@
M`@``H`$``````````````````%,````X!0```````(0&````````````````
M``"!!```-0(``#P"``"X!0``T0,``.`!````````5P4``*8#``"X`@``#0@`
M`'`"``!0!0```````"X%``#9`@``U04``+H%```2!P``T`0```````!:`0``
M=P````````!5!0``0`$``*L!``!,`@``CP````4(``#`!0``G`$````````@
M!@``?P,``%<!```@````B@```'L"````````L0```*\%````````A@```-D`
M````````B@(```H"``"O!```H08```````#E`0``%08``+D#``!9`0``+0``
M```````2!````````+T'``#1!0``(`<`````````````B@,``#4$``"(`@``
M5P(``````````````````!$`````````L@(``+D```"'!0``!P```*D`````
M````````````````````^`4```````!!`P``9P,``.4"``"[``````````X!
M``#C`P```P$``/L```#U!@``,0```#`%`````````````(D"```2!0``````
M``````#:`@``D0,``%T"````````.P$````````C`0``Q`(``)T%``"_`@``
MO`,```D(``#`!@``````````````````@0,``$$'``!C`0```````'0$```^
M`@``_0(```````!;!```:P8```8$``!-!0```````/P$`````````````'\%
M``!V!```)`$```@"``!E!P```````!<%```."```)04``&T!``#A`0``CP,`
M`*D"````````;P8```````!>`0``DP````````!3`@``PP$```````"T`P``
MP@```+,&```C`P`````````````X!@``J0$```````!9````@P,``#,#```,
M````C@,``"0#```B!@``)@8````````$`@``8@4``"4'``""!```L````-X`
M`````````0(``)X%```I!@``]0```&4!``!X!```6P$``#(&``#V!0``404`
M`/4#``!^`0``C@4``(,!```-!0``C@<`````````````&@```(<"``#3`0``
M$08``"0%`````````````(`$``"8!````````-T%````````Y@,``#$!```M
M!P``[@0``-(&``#'````>@0``.\"``#&!P``D04``'\"``"$!```HP4``*8'
M``!?`0``T0<``!`%``#/`@``:@````````#O!````````$8$````````````
M``````"_!```[`4``/L$``!6`P``V````-L```"7`0``RP8````````>`@``
M&`<``/P&``!\````>08```````!*!0``P`(```````"V`P``_@,``(0%``"6
M`P``@P8``/P!``#7`0```````"@&```^!```]`$``)4"````````300``#`!
M``#C!P``1P0``$$%``"1`@``F@<``!T!``"B!```W`````````#0!0``````
M````````````5`4```````!/!```WP```-,`````````<P$``.T```";`@``
MMP```)0'``"H!0`````````````7`@``Y@<``&('````````1P,``/,!````
M`````````+0`````````=0````<"``!Y!0```````"(!``"4!@``604``/(%
M``#3!`````````````"W!@```````,L!``"R!```X0````````#]!P``.P``
M````````````I`,````#``!'`@``M0`````````Y!0``CP(``/@!``"4````
M`````/@#```P!P``/`````````"P!@``C@8``)@&``#B`0````@``,(&```]
M!P``IP(```````````````````<#````````,@$``"$%``#Y`P``"@@`````
M``"]!0```````!T%```E`0``O@0````````^!@``-0<``*<%``";`P``J08`
M`````````````````#,'``!N!0``1@(``*X$``!.!```2P8``%@!```M!0``
MW@<`````````````2`8``)\"``!;`````````',%```<`0``)P4``.X"``#B
M!P``0@(```````!S!```"04`````````````U0,``-8&``"S!```Z`<```D$
M````````]`8```P%``!8`@```P```-,%```?!@``1`$``&("```M!@``7`8`
M`.8"```&````Y@```(D&``!H!@``%@(``)$```#Y`0``/@,``!("```W`@``
M\`,``,,$``#N````8P(``````````````````'\'``!G`@```````-H!```2
M`0``_P,`````````````.0$``,$```#:!@``'08``',"``#D````<@,`````
M``!D`P``>P4```L```#@`P```````+@`````````80```#,$````````R@(`
M`'\$```(!0``5@(``$$&`````````````'8%``#0`P``CP4`````````````
M<P<``,H'```#"```=@8``((#``#\````B0<``"$#``"<!@``708``%D&```\
M`P``>P8``$0%``!W!@``_`4``/@'```,!```@@4``!X$`````````````-0!
M``!(!0``N@(``,D&``!-!@``LP<``%4$`````````````,`$````````!0,`
M``0(``#!`@``$`$```````"4!0````````````"6!P```````+\%```0!@``
M*@4``+L'````````5P<``,@#``!5`0``(P0``/`&``"U!0```````($%``!Y
M!P```````'`#``!]!```3@(````````O`@```00`````````````I@4``#X%
M``!M!P``0P(``````````````````/<&``#/````%P0``#H&``"+````D`0`
M``````#F!@``+P<``&,$``"L!0``X0<``/,``````````````!4%````````
MSP0``'H%```(!P``:0$```````"&`0```````.$&```!!0``'@4```<$````
M````%P,```````#J!0``70,``"0'``!M!0```````#4!```$!P```````,4'
M``!]!@``GP8``*4````L!0```````,<$````````O@4``,H!```$!```WP<`
M````````````````````````````JP,``#8$``!5!P```````&L%``"(````
M)@````````#2````+P0```````#D`@``'`,``),!``"&!@```````)(%``#&
M`P```````*`$``!A`@``^@,`````````````'P0```@````G`P``M@(``&``
M``````````````L&``!Y`P``$`(``-<#```1`0```````-4`````````````
M``````!R!```3@<``)0#```I`@``$P,``,$'``!-`0```````,X$``"5!```
M10$``$<&```)````S08``$,````L`0``@`,``+$$``"I!0````8```X%``!U
M`P``!`$``%T```"Y`0``A@<``%L"``#H!0``2`,``&D$```I`0``2`(``,,&
M``#@``````````````"T!0````````<!````````````````````````````
M`/$'```Z!````````.(`````````Z0```((```"%!P``KP<````````V!0``
M.@<``!@````4`P````````````!!`@``L04```````"(!@```````$4#``!G
M!0``PP(``%H"```@`P``408``)@````E`P```````"X$``"D!0``P04``*T'
M``#3`@``>`8``.L$`````````````!X```"8!0``:`$```((````````'`4`
M`/<$````````<`4```````#C!```N`,``)8"``!'````O`4``)H#``"E!```
MW@4```````!>!P``T@$``.`"``"@!P```````+T"````````]0<``'T%``#A
M!```^08```````!0`@``AP,``-4$``!4!P``SP4``-X"``#B!@``YP0```L$
M``````````````T#``#T`@``U`(``````````````````'0"````````H`(`
M``````#,!P````````H!``"_`P```````"<$``!<!0``^`8``&L"``#Q`P``
M`````!@#````````[0$``%4"```Q!P``]`<``"`$``##``````````````#V
M`@````````````">!@``UP<``/\!``!:`P````````D#``#W`````````)H$
M````````(@,```````!W!```7`,```````!1`@```````%\$```\!@``#08`
M``4!``!,!`````````````"4!```W`(``"X&````````PP4``)\!``"V````
MFP0``%,$``#,`@```````.D%``#O!0``80,``%(!``"\`@``90`````````J
M````:@(``&T&``"K!P```````&P"``!2`@``:`4``'<%````````^P,``'\`
M``"<!P```````'0!``#S`@```````&D%``"#`````@$```````#E!@``O@(`
M`-T#````````D`<``"D$`````````````)D#``"7````E@0``/T$``#0`@``
MD`4``&\````_!@``)@$````````G````Z@```&L```#K!0```````!<!````
M````%00````````E!@``J@```"L!``"$`P```````*H$```B!```RP,``!$"
M``#8!@``,P`````````X!P``Y`4``/D%```+`0``K`(``&<&```<`@``K@(`
M``````#'`@``<04`````````````T````*$!```(!```V@4`````````````
M-@$``````````````````.4#``#>!@``C@$``'H!```_!```9@,``*H!````
M````K04``&@```",`P``Y0<``*8!``"V`0``&0```(T!```]!0``@P0``#0'
M``"R`P``J@,``,H%``"G!P``80<``$H#`````````````"`"```-`0``M00`
M````````````/P(`````````````)`0``)("````````DP<``%P"``#(````
M1@```+H#````````30(``)4%``")``````````,#``!L`````````)X"``"_
M!P``GP```#<#``":!0````````````#4`P``_`(``/T#````````"P,``!8!
M``"=!@```````&`&````````#P@``.4```#T!0``H`4`````````````G```
M`'\!``"0`@``*@0``.L"````````(P(```````!8!0````````````!+````
MH04``'$$```5`@```````"8%``"4`@``=P,``/D"``!\`0``````````````
M````80$``$D%```L`P``````````````````K0(``$L$``#2`@``"@<``!,$
M``#J`@``EP8``'L'```8!0``[08``(D%``!J!0``]00````````\!P``Y`0`
M`&P$``#_!P``KP```%\"``!!`0``_0````<(````````I08``'("````````
M`````%@#``"E`0``2`0``(P"``#.`P``B0$``"8"````````,0(``,\'``!A
M!@``'@,``%`'````````RP0``)<%````````4P,``#@$``!1!P```````"L&
M``"8`P```P(``+`#```P`P`````````````X````&P,``(H!``#E!```10(`
M`!4```#"`P``V@``````````````7P4``*T&````````[0(``%X"``"-!```
M\P,``(`!````````:`(``-\!```(`0```````%H%`````````````!L````B
M!P``Z0,``````````````````'<'````!0``Y`<```````"=!````````-('
M```R`P``#00````````A!P``W0```,4%```T````X0,``/L'```E`@``3`8`
M`,<&``!Y````'P<```<&``"!`````````%<$````````#`$````````/!```
M`````&<$``#!`0``;`,``#<$```R!0``!P4``.P'``"^`P``[@,``*$````1
M!```Q````&H!``"T!P```````#<%``#J!```(`$``.,!``!4`0``M`8``"X'
M```^!P```````-(#```8!@``GP<``(P%```L`@```````+@$````````GP0`
M`$4```#W!0``\@,``)D%``"Q`P``;@8``+4#``!C!@``U`8```X$``#&!0``
M"0$``.$%```%!P``60<``````````````````.($````````!@$``+8%```V
M````L0<``/0#````````G`,``&8!````````>P```%``````````Z`0`````
M``"J!0``,P(``)<'```8`@``A04``.<```!V`0``BP4``#8'```?````S0$`
M`-<"``#.`@``"@8``.8$````````"P(```````"A`@``\`4``"D'```.!P``
M`````-T"``!K!```U@,``*\"````````S@```-4"``!Q!P``5@0``/("```M
M`@``?0```!$%```````````````````/!0``<P```.<'```E!```;P(``'T"
M``!<!```L`(```````"'`````````$4%```;!```50```$H$``#[`0``JP0`
M`-`&``#I`0``8P4```,'``#I`@``E@4``)X$```R!P``AP<````````6!0``
M`````%T%``!<`0``9@```#P%``!,````O00``-D$````````=@,``%,%````
M````R@8````````&`P```````$0#``#P`0``2@<``)X```"N````R0,`````
M``!(````)P$``&8"``!R!0``3P4``#X```":!@``R@,````````9`P``D@0`
M``````"%`@``ZP$``'4$``#_!````````*\#````````7@0```````!D````
M```````````5!P``I`0```````!X`0``Z08``"<'```4!P```````.L'```S
M!0``3@4``)D&``#M!0``90(``.<"``"J!@``S00``/L%``!0`0```````!T`
M``#G`P``.P<``(8#````````/08``````````````````,D'``"G`0``IP``
M`)H"``#/!@```````$`$``"\!P``2@(``%T'``#'`P``CP$``%@`````````
M``````````!I`@``>P$``````````````````$X```"A!```MP,``'H#``"?
M`P``L@<``)X#```B`@``$P$``%\'``````````0``$`#``#$!0``WP(`````
M````````?`0``(0"``";!0```@,`````````````?0<``*,&``#;`@``A08`
M``````````````````($```!`P``[`0``&0'``"W`0``#P,````````?`P``
M`````'<"``!/!@``:@0``-@#``#P````"@,```````#M`P``O@$``#<&````
M````&P8``!8```"D`@```````+4&``!@!P```````.@"`````````````&T$
M```H!```NP0``&4&````````F`<``#@"``#>`0``Q@8```````"G!@``J@(`
M`/8#``!\`@``C@(```````"S`P``RP<``+(!```L!@``^@4``(L&``!"!@``
M<0(``$X#```?!0``A00````````.`@``*P0``%<#``"7`P``800``%\```"+
M`0``3@$```````#S!0``$P<``$($``"B!0``&P(``$0$```7!@``-`,`````
M``"1!@``U````(@!```!!P``<08``-<%```C!P```````"T#``"0!@``5`8`
M`!8&`````````````%<```"9!```]P<``-@$```!!@``0@4``.D'````````
M90,``$T#``#O!@``Q`0``,P$```/`@``;P4```4"``"*!@``[@$````````T
M`@``V`<```````#<!P``\08``!H%``!#`P``ZP8``(8"``"W`@``R0$``%H$
M``#9!P``.@,``-@"```>!@``:P,``.,"```(`P```````(H$````````+@$`
M`"0&``#>!````````-L$``!2!0``(0(``-4&``"L`P``S@8``&D'```:`0``
MZ@8``````````````````+T!````````^@$``'L#``#U`@``1P4``),$````
M```````````````C!@``'00``,T"```Z!0```````'P'``"F!```7@``````
M``!B`P``J````'0`````````LP(``%$`````````]````,('``!U!@``````
M`*D'``!C`P``K@4```````!Y!`````````````"2`0``Q08``*`#``#]`0``
MIP,``/X'``!/`@```````!,"``"B`P``#`<``,T'``!/````"@```&P!```[
M`P```````.<%``!6!@``%@<``.\#````````:@,```````!+`P```````!D'
M``!G`````````/@"``#%`P``%`4``-P%````````2P<``"L#``#^!```20``
M`````````````````'``````````R`0``-$$```R`@``LP$``,H`````````
MJ`(``!H'``#9!@```````!`$`````````````-P!```D````$`,`````````
M````E@$``/T%``#3`P``208```````#B`P``6@<``+D$``#;!P```````!D&
M``#-`P``P@0``&(````[!@``_@$``,X%``!!!````@8``+$!``"0`P``$P8`
M`*@&```V`P``E`$``.H!``"T`0``&P<``"P````9`0``D@<````````C````
MWP4``*0!```6!```+@````````!'`0``B00``+D&``#7!@``600``&$%``#:
M!P```````!P&``!J!@```````/X```"[`P```````#T$```P!@``#P$``%P`
M````````'````!4#````````8@$``(L'``#O!P``O`0``$,$``#V!```````
M`*,!``````````````````#Z!@``@`<````````````````````!````````
M\0```.X%``#5!P``@`4``$\'````````/0```.H'``",!P``;@```+X'``"[
M!@``M0<``$T'``#^`@``K0````````"N`P```````$<'``"L!````````'T#
M``#;!@``*`<````````Z````[P```#0$`````````````&@$```Q!```````
M``````!"````HP0```$!`````````````)@!``#&!````````.`'```/!P``
M````````````````)0```$8!`````````````($'```P````(0``````````
M````.08```X#````````Z`8``&P'``"(!```Y`,``/(```"K!0``*P<``(@#
M``!&!@``T08``"@"``#:`P``Y`8``&8'````````<P8``/H"``#U!0``B`<`
M``H%``"V!```@`8``,@&`````````````!T#````````^P(``+`$```T`0``
MQ`,``#($```_!P``N@8``.L#```V!@````````````!Z!@```````+T```!U
M`0``O````&P&````````D00```````#C!@```````"L```!N!P``!@@``,T`
M``";`````````.(%``"$!P``(@```*X'``#\`P``[`$``'D"``!@`P``K`<`
M``````!N`@```````/8!``#6`@```0@``'H'``"]`P``?@,``'(```#Z!```
M`````!D"````````?`,``-\$```1!P``I04``&\#````````:P$``!T'````
M````WP8```````!F!`````````````"3`@``108```0`````````#P```+(&
M``#P`@``R`4``+L"`````@```````,8"``!O!```Z@,``'`!```]`0``````
M`-(%``!V!P````````````#X!```0````*,'````````````````````````
M=0<``'L$``!,`0```````,<'````````$````%,&``!B!````````"H&````
M````R0(``!@!``#U`0```````(L$````````BP,````````N`@``.0,`````
M``#=!P```@<```````!L!0```````(P!```>!P```````(T&````````X@(`
M`&X$``"$`0``J`$``$H!``"C````-08``&4$``````````````````!#!@``
M\0$``-$"```O!0``LP```!D$``#"!0``*`4`````````````3`,`````````
M`````````$L"``#=!````````,D%````````I0,``#4```!^`@``'P$``#4#
M``!2!P``20<``"H!````````$`<``+\&```@!0``W0$``*P`````````"0<`
M`)$'``"_`0```````#L%``"B!@```````(\'```-````D0$``/8'``".````
MY`$``,4"``"O!@```````*$#````````7`<```````#L`````````'X'````
M````@0(``!0!``#_`@``P`,``(('``!I````&@8``%D#``"]!@``````````
M``#/`P``#@```&X#``"*!0``0`(``&`!``!1`P``L@4``%(#````````:`,`
M``````#)````Q0```!0$``!9`@```````,X!``!F!@``MP4``-P#``#P!P``
M*`$``,$&``"^````W`8```````"=`0``YP8``)X!```2!@``=0(`````````
M````Z`$```````!H!P``;0,``+@!``"8`@```````,X'``!&!P``1`(``"0"
M``!6!P``U@$``(T'``!0!```%P````````!F!0``L@```+<$```_`0``````
M`"@#````````C`8``-X#````````&04``$(!``!@!```2@````````"+`@``
MP0,```````#G`0``C````#$%````````2P4``'X%``"B`@``@@(```````"U
M`@``?@8```````#(!P``6P4``/(!``"Z`0``R00````````U!0``-P```'H"
M`````````````)T````O!@```````.@```"S!0```P0``%@'````````\0(`
M``````!B!@``\P8```````#_!0``0`4``-P$``"G!`````````````#K````
ME0<``$(#``"'`0``-`8``&L'``"I`P````````````"=`P``9`(``/,$````
M````U`<``'@"````````[`8``"H#```8!```!@<``)8&``#7`````````%H`
M````````B0,``,<!``#,!@``<@$``&<'``"L`0```````*(!``!G`0``(08`
M`)4`````````DP,````````M`0``4@0``'$!````````I`````````"E`@``
M%`(``+\```!=!```6`0``)D'``#V!@```````"H"``#4!```3`<``,0!``!%
M!P``5@```"@```!3!P``@08````````$`P``:@<``````````````````"P$
M```>`0```````/H````)!@``<`8``'@``````````@4``.8%``!X`P``20$`
M``,%``!)!```<`<````````?`@``T`<``-L!``"V!@``;@$`````````````
M'`<``"L"`````````````)P"``#+`@``:0,```````"N`0``#0(``(@%````
M```````````````2`P``_P```(4```#@!@``Q@$``!(```#$!@``)P(``*T!
M````````$P4``)<"``!.!@``/0(`````````````#`,```4%````````"`@`
M`.X&````````F@$``'0&````!P```````$`&````````[`,``+P!````````
MM`(```````"9`@```````.,`````````PP<```D"``!I!@```````+H```!$
M````7P8````````%!```KP$``#@!``"-````@@8``"\!``!C````SP$``#H!
M````````C0,``,````!;!P```````*H'``"'!````P8````````$!@``````
M``````!,!0``\@0``*`&``#9!0``%P<``*D$```N`P```````)T"``"2!@``
M#0<``&T```!6!0``&@0``*@'``"3!@``#`(``/('``"K````CP0``&T"``!T
M!0``K00``'@%``````````````````#1`0``U@<``"(%```*!```U@0`````
M``"*!P``HP(```<'````````.0```%X#``"9````T0````````#[!@``5`,`
M`'H```"-`@```````+4!``#:!```[`(``)4&``"B!P```````)H```"E!P``
MNP$``$4$```+!P``5````(\&``!@!0``,0,``&4%``#X````400``#@#``!]
M`0``&P4``'`$````````)P8````````Y!```"`8``%$!````````9`4``+<'
M``".!`````````P&``#Q!```/0,``*````"2````0@<``'P&``"0`0``%0$`
M`#<!````````*@<``/P'`````````````"D#``"?!0``P`$``((!``";!P``
MEP0``/D`````````]@```-@%``!(`0``PP,``!L!``"Y!0``>0$```````"[
M!0``"P4``!8#`````````````/X&````````!@4``,P!````````%````*T#
M``!5`P``.@(``)P$`````````````%\#``!^````2P$``%<&``#'!0``9`0`
M`'\&``"Q!@``[0<```````"0````G0<``"8#````````S`4``'$```#O`0``
MS04``%L&``";`0``Q00```````"F`@````````````!3`0``3P,`````````
M`````````'0#``#2!```@P<``(````!D`0``00```,(!``#^!0```````)D!
M```F!```*P4``-@!````````Y04``+@'```[`@``A0$`````````````````
M`,8`````````@`(``-L#`````````````*X&``"D!@``@P(````````L!P``
MVP4``($!````````!`4``"$$```P!```!@(```4```!#`0``UP0``/,'````
M````Z00``$0'``#M!`````````````"-!0```````'(&````````6P,``/\&
M```I!0``;P$``-T&````````U@````````!`!P``=@(````````\`0``TP<`
M`+$"```V`@``O`8```````#@!0```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S
M:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H
M>65S=&5R9&%Y*0`@86YD`"!A="``(&]R`"(E<R(@:7,@;F]T(&$@9&ER96-T
M;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@
M8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U
M<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@
M<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@
M4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES
M=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N
M;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S
M)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S
M`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA
M:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I
M="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA
M;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V
M87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O
M<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A
M8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`
M04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W
M97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!
M8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`
M06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@
M9G)O>F5N+@!!8V-O=6YT:6YG`$%C=&EO;B!F;W(@8FQA8VML:7-T960@861D
M<F5S<V5S.@!!8W1I=F%T92!38W)I<'0`06-T:79A=&EN9R!T:&4@<V-R:7!T
M(&9O<B`B)7,B(&9A:6QE9#H@*"5D*2`E<P!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P
M`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B
M`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E
M<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S
M(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9&ET:6]N86P@4V5T=&EN9W,`061D<F5S<P!!9&1R97-S
M($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`
M06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N
M=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@
M9F]U<B!S:61E<P!!;&P@;V8@=&AE(&9O;&QO=VEN9P!!;&QO=R!2=6QE<P!!
M;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@
M3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@
M57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E
M;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA
M<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@
M4')O>'D`06YS=V5R`$%N<W=E<F5D`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@
M0F%R8G5D80!!;GD@;V8@=&AE(&9O;&QO=VEN9P!!<'!L:6-A=&EO;@!!<'!L
M:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!&:6QT
M97)S`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E
M(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL
M92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&5L971E('1H:7,@<G5L93\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`
M07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R
M=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!2
M96=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S
M=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U
M:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET
M:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=71O;6%T:6-A;&QY
M('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&5A8V@@8VAA;F=E/P!!=F%I;&%B
M;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#
M;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R
M;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A
M;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S
M(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)C8P!"96=I;G,@=VET:`!"96QA<G5S
M`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I;F0@9F%I
M;&5D.B`H)7,I("5S`$)I<G1H9&%Y`$)L86-K;&ES=`!";&%C:VQI<W0@161I
M=`!";&%C:VQI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F
M:6QT97)I;F<@9')I=F5R+@!";&%C:VQI<W1E9"!!9&1R97-S97,`0FQO8VL@
M(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T
M=&EN9W,`0FQO8VL@5'EP90!";V1Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`
M0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(
M97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD
M`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I
M($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A
M<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?
M96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E
M9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E
M<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S
M(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T
M(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@
M<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L
M(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@
M;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E
M('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87-E
M(%-E;G-I=&EV90!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N
M9',`0V,`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG
M.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L
M=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U
M8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T
M92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC
M:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V5S('-A=F5D
M+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET
M:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O
M<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R
M>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A
M=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL
M('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L
M;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R
M`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O
M;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`
M0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S
M>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O
M;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF
M:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I
M;&5D.B``0V]N;F5C=&EO;B!F86EL=7)E`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`$-O;G1A:6YS`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#
M;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;W!Y`$-O
M<'D@)7,`0V]P>2!F86EL960Z("5S`$-O<'D@;V8@)7,`0V]P>2!S96QE8W1I
M;VX`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!B:6YD
M('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N
M;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O
M=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A
M9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U
M;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@
M)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A
M8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`
M0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P
M=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N
M=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@
M=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD
M(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I
M;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED
M96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T
M(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`
M0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@
M;F5W(&9O;&1E<@!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S
M:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@
M4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@
M57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R
M<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])
M."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1$E304),140Z(`!$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S
M97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E
M;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5A8W1I=F%T92!38W)I<'0`
M1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A
M=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H
M96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@)7,`1&5L971E($-E;&P`
M1&5L971E($-O;F1I=&EO;@!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE
M=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T
M92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T90!$96QE=&4@;65S<V%G92!C;VUP;&5T96QY`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E
M<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`
M1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<B!I;G1O(&UY($E.0D]8`$1E
M;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@8V]P>2!T;P!$96QI=F5R(&EN=&\@
M;7D@24Y"3U@@86YD(')E9&ER96-T('1O`$1E;&EV97(@=&\@9F]L9&5R`$1E
M;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C
M=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-A8FQE("5S`$1I<V%B
M;&5D`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!D971A:6QE9"!N;W1I
M9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/P!$:7-P;&%Y
M(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!?;F]T('-E;F0@<F5S<&]N<V5S('1O
M(&)U;&L@;W(@;&ES="!M97-S86=E<P!$;R!N;W0@9&5L971E`$1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('1H:7,Z`$1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#H`1&]E<VXG="!B96=I;B!W:71H`$1O97-N)W0@
M8V]N=&%I;@!$;V5S;B=T(&5N9"!W:71H`$1O97-N)W0@97AI<W0`1&]E<VXG
M="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I`$1O;6EN:6-A`$1O;6EN:6-A
M;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O
M=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M
M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@)7,`161I="!";&]C:P!%9&ET
M($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U
M8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16UA:6P`16UA
M:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@
M=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC
M;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N86)L92`E<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F
M<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/P!%;F%B;&5D`$5N9"!Y96%R`$5N9',@=VET:`!%
M;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H
M('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_
M)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%L('1O`$5Q=6%T;W)I
M86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ
M("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE
M=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%
M<G)O<B!R971R:65V:6YG(&-U<G)E;G0@<V-R:7!T.B`H)60I("5S`$5R<F]R
M('-A=FEN9R!C:&%N9V5S+@!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`
M17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%
M=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@
M,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@
M:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T
M90!%>&ES=&EN9R!2=6QE<P!%>&ES=',`17AP86YD`$5X<&%N9"!3:61E8F%R
M`$5X<&5C=&5D("<I)P!%>'!E8W1E9"`Q(&]B:F5C="P@9V]T("5D+@!%>'!I
M<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S
M971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D
M('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@
M<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I
M`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R
M>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO
M=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I
M;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M
M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"X`1FEL=&5R($%L;"!-97-S86=E<P!&:6QT97(@3VYL>2!3
M965N($UE<W-A9V5S`$9I;'1E<B!/;FQY(%5N<V5E;B!-97-S86=E<P!&:6QT
M97(@3W!T:6]N<P!&:6QT97(@4G5L90!&:6QT97(@4G5L97,`1FEL=&5R(%-C
M<FEP="!$:7-P;&%Y`$9I;'1E<B!?4G5L97,`1FEL=&5R(&%C=&EV:71Y.B`E
M<R!M97-S86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B`B
M)7,B+@!&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N
M(&1E;&5T960N`$9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E
M(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B`B)7,B+@!&:6QT97(@86-T:79I
M='DZ("5S(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@
M=V5R92!D96QE=&5D+@!&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E("(E
M<R(@9G)O;2`B)7,B(&AA<R!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R("(E
M<R(N`$9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S
M<V%G92`B)7,B(&9R;VT@(B5S(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@9F]L
M9&5R("(E<R(N`$9I;'1E<B!N;W0@9F]U;F0N`$9I;'1E<G,`1FEN;&%N9`!&
M:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`
M1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`
M1F]R(&%N(&EN8V]M:6YG(&UE<W-A9V4@=&AA="!M871C:&5S.@!&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&
M*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y
M;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T
M=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D`$9O<G=A<F0@:7,@;F]T
M('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+@!&
M;W)W87)D<P!&;W)W87)D<R!%9&ET`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E
M+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA
M`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&
M=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L
M;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A
M=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E
M;B!.86UE`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R
M87ES8V%L90!'<F5A=&5R('1H86X`1W)E871E<B!T:&%N(&]R(&5Q=6%L('1O
M`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`
M1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM
M96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L
M80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A
M`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%144"!!=71H96YT:6-A=&EO
M;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R
M`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE
M879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP
M`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE
M($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R
M:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K
M+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS
M(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM
M86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P
M;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E
M<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A
M<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD:79I9'5A;"!R
M=6QE<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I
M;F<@9')I=F5R+@!);F1O;F5S:6$`26YE>&ES=&%N="!M86EL8F]X('-P96-I
M9FEE9"!F;W(@;65S<V%G92!D96QI=F5R>2X`26YF;P!);F9O<FUA=&EO;@!)
M;F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M
M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@
M3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA
M:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P
M87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E
M`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS
M97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A
M<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E
M9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF
M>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`
M26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN
M`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI
M9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L
M:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN
M=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN
M=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P
M97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C
M="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@
M(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R
M97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S
M96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA
M;F0`27,`27-L92!O9B!-86X`27-N)W0`27-O;&%T960@5"U3=&]R;7,`27-R
M865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N
M`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU
M;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF
M>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L
M/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I
M;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I
M`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A
M+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T
M86X`3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U
M;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+@!,85]Y;W5T`$QA
M;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@
M2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5
M<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S
M`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE8F%N;VX`
M3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE<W,@=&AA
M;@!,97-S('1H86X@;W(@97%U86P@=&\`3&EB97)I80!,:6)Y86X@07)A8B!*
M86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!2
M86EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A
M:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`
M3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T
M;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T
M(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M240`3&ES="U)
M9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N
M<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG
M('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``
M3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN
M`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN
M(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E
M<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU
M>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D
M(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@
M061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`
M36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@
M:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@
M;6%P`$UA<E]K(&UE<W-A9V4@87,@9&5L971E9`!-87)C:`!-87)G:6X`36%R
M:R!M97-S86=E(&%S.@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`
M36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H97,@*'=I=&@@<&QA
M8V5H;VQD97)S*0!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I
M=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X
M:6UU;2!.=6UB97(@;V8@4G5L97,`36%X:6UU;2!L96YG=&@`36%X:6UU;2!N
M=6UB97(@;V8@8FQA8VML:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A
M;"!A9&1R97-S97,Z("5S+"!-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U
M;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O(&)L86-K;&ES="X`36%X:6UU
M;2!N=6UB97(@;V8@=VAI=&5L:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4
M;W1A;"!A9&1R97-S97,Z("5S+"!-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@
M0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O('=H:71E;&ES="X`36%Y
M`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I
M960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B
M(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE
M=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O
M<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O
M=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG
M(&%D9')E<W,@=&\@;F]T:69Y`$UI<W-I;F<@861D<F5S<R!T;R!R961I<F5C
M="!M97-S86=E('1O`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@
M=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P
M<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5A<V]N
M(&9O<B!R96IE8W0`36ES<VEN9R!R96%S;VX@:6X@=F%C871I;VXN`$UI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-
M;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`
M36]V92!2:6=H=`!-;W9E(%)U;&4@1&]W;@!-;W9E(%)U;&4@57``36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y
M;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$Y?=6UB97(@;V8@9&%Y
M<R!B971W965N('9A8V%T:6]N(')E<&QI97,Z`$YA;64`3F%M:6)I80!.875R
M=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S
M8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S
M8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C
M87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.
M971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E
M9V]R>0!.97<@365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@4G5L90!.97<@
M57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R
M;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`
M3FEG97)I80!.:6=H=`!.:75E`$YO`$YO("(E<R(@96QE;65N="!F;W5N9"!I
M;B!B86-K96YD(&-O;F9I9W5R871I;VXN`$YO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A8VME
M;F0@8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T`$YO(&)A8VME;F1S(&-O;F9I
M9W5R960@:6X@8F%C:V5N9',N<&AP`$YO(&)A=&-H('1E;7!L871E+@!.;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE
M;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.
M;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D
M:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L
M;V%D960`3F\@9FEL=&5R<RX@0VQI8VL@(B5S(B!T;R!C<F5A=&4@82!N97<@
M9FEL=&5R+@!.;R!H96%D97)S('-P96-I9FEE9`!.;R!I8V]N<R!F;W5N9"X`
M3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@
M;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E
M<B!S<&5C:69I960N`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y3
M4TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C
M97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@
M<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S8W)I<'0@9V5N
M97)A=&5D+@!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S
M=')I;F=S('-P96-I9FEE9`!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`
M3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)
M4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R
M90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.
M;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@97%U86P@=&\`3F]T(&EM
M<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I9GD`3F]V96UB97(`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@
M;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@
M:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RX`3VYL>2!F;&%G('1H92!M97-S86=E`$]N;'D@
M;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!A
M8F]U="!S8W)I<'0@=7!D871I;F<N`$]P=&EO;G,@9F]R("5S`$]R9&5R960@
M3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ
M:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@
M3W!T:6]N<P!/=F5R=FEE=P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD
M`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0
M(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D
M90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`
M4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`
M4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`
M4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W
M;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I
M;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E
M(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI
M960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R
M<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE
M`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A
M<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A
M>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0
M;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z`%!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C
M:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S
M<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`
M4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E
M<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B
M;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T
M;R!2:6-O`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)?96%S;VX`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!2
M86EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N
M;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-E:79E9`!2961I<F5C
M="!T;P!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!2
M96=E>`!296=U;&%R(&5X<')E<W-I;VX`4F5J96-T('=I=&@@<F5A<V]N`%)E
M;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V
M97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!2
M96UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@
M;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S96YT
M(%1O`%)E<V5N="UF<F]M`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO
M=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N
M('1O($9I;'1E<G,@3&ES=`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@
M4G5L97,@3&ES=`!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T
M($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L
M97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E
M<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`
M4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O
M=W,Z`%)U;&4`4G5L92!#;W!I960`4G5L92!$96QE=&5D`%)U;&4@1&ES86)L
M960`4G5L92!%;F%B;&5D`%)U;&4@3F%M90!2=6QE<P!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A
M;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U1!4E143%,@
M9F%I;&5D.B`H)7,I("5S`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(
M96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D
M:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`
M4V%V92!3971T:6YG<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I
M96YC90!38W)I<'0`4V-R:7!T(%5P9&%T:6YG`%-C<FEP="!N;W0@=7!D871E
M9"X`4V-R:7!T('-U8V-E<W-F=6QL>2!A8W1I=F%T960N`%-C<FEP="!S=6-C
M97-S9G5L;'D@9&5A8W1I=F%T960N`%-E87)C:`!396%R8V@@16YG:6YE<P!3
M965N`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD
M`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L
M96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`
M4V5L96-T(&YO;F4`4V5L96-T('1A<F=E="!F;VQD97(`4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R
M96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T
M92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I
M;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T
M('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z`%-E;&8M1&5F:6YE9"!(96%D97(`4V5N9"!0<F]B;&5M(%)E<&]R
M=`!396YD(%--4P!396YD97(`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`
M4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A
M=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S
M:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A
M;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F
M;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y
M;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R
M969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971T:6YG
M<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4V5T=7``4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W
M:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T
M(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_`%-H;W<`4VAO=R!!8W1I=F4@4V-R:7!T`%-H;W<@0W5R<F5N
M="!38W)I<'0`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3
M:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@<&EC
M:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R
M<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6
M:6-I;FET>0!3:')I;FL`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E
M`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN
M=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N
M;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA
M=&4`4VYO=R!D97!T:#H@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S
M("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`
M4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T
M:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T
M:&5R;B!(96UI<W!H97)E`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A
M9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI
M="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK
M80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V
M:6YC90!3=&%T=7,`4W1O<"!C:&5C:VEN9R!I9B!T:&ES(')U;&4@;6%T8VAE
M<S\`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G
M:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3
M='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U
M8FIE7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z`%-U8FIE8W0`4W5B;6ET`%-U
M8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO
M=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A
M<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@
M=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM
M87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U
M;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U
M<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N
M`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E
M9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@
M07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O
M<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E
M<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R
M(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R
M871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B
M)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!4
M97AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I
M`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA
M;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N`%1H92!A9&1R97-S("(E<R(@:&%S(&)E96X@861D960@=&\@>6]U
M<B!B;&%C:VQI<W0N`%1H92!A9&1R97-S("(E<R(@:&%S(&)E96X@861D960@
M=&\@>6]U<B!W:&ET96QI<W0N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E
M(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N
M`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE
M(&1R:79E<B!S86ED.B``5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P
M:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92X`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N
M(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y
M<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T
M;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@
M8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N
M8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T
M;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R
M96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE
M('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT
M('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C
M<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S
M:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B
M;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R
M92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ
M("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE('-C<FEP="X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+@!4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R
M97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@
M82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T
M:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI
M<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S
M+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T
M:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`
M5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O
M;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@
M8VQI8VMI;F<N`%1O.@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4
M;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R
M:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U
M<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``
M52Y6+B!I;F1E>#H@`%523`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O
M97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D
M($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK
M;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O
M('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5
M<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G
M<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I
M;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R
M<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T
M:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T
M(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N
M`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z
M8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I
M;VX`5F%C871I;VX@161I=`!686-A=&EO;B!I<R!N;W0@<W5P<&]R=&5D(&EN
M('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N`%9A;&ED(&QO8V%T:6]N
M<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F
M<F]M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U
M`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@
M*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I
M97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N
M9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A
M;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.
M54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA
M`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O
M=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC
M;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X
M-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H
M7VET96QI<W0@861D<F5S<V5S.@!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E
M:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T
M;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:&ET96QI<W0`
M5VAI=&5L:7-T($5D:70`5VAI=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@
M=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BX`5VAI=&5L:7-T960@061D
M<F5S<V5S`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I
M:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`
M5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K
M(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP
M96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N`%@M4')I;W)I='D`6"U3<&%M+4QE=F5L
M`%@M4W!A;2U38V]R90!8+5-P86TM4W1A='5S`%@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!9
M60!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R
M964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!R=6QE<RX`66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;W(@961I="!C=7-T;VT@<G5L97,N
M`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T
M:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N
M;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA
M<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O
M<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A
M5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U
M<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L
M96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO
M=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T
M;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P
M96-I9GD@870@;&5A<W0@;VYE(&5M86EL(&%D9')E<W,@9F]R('=H:6-H('1H
M92!V86-A=&EO;B!M97-S86=E<R!S:&]U;&0@8F4@86-T:79A=&5D+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W
M(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA
M;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R
M;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!
M9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y
M;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U
M;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@
M8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M
M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!;2&ED92!1=6]T960@5&5X=%T`6TYO(%-U8FIE
M8W1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO
M=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D
M9')E<W,H97,I('1O(&9O<G=A<F0@=&\Z`%]!9&1R97-S97,@=&\@;F]T('-E
M;F0@<F5S<&]N<V5S('1O.@!?061M:6YI<W1R871I;VX`7T)L86-K;&ES=`!?
M0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1&5L971E(&UE<W-A9V4@8V]M
M<&QE=&5L>0!?16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z`%]&
M;W)W87)D`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TME
M97`@82!C;W!Y(&]F(&UE<W-A9V5S(&EN('1H:7,@86-C;W5N=#\`7TQO9R!I
M;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7TUO=F4@;65S<V%G92!T;R!F
M;VQD97(Z`%]->2!E;6%I;"!A9&1R97-S97,Z`%]/<'1I;VYS`%]097)M:7-S
M:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-C<FEP=`!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U5S97)S`%]686-A=&EO;@!?5VAI=&5L:7-T`&%C=&EV
M90!A9&1R97-S(&)O;VL`86YD`&-A;&5N9&%R`&-A;FYO="!C<F5A=&4@;W5T
M<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD
M(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A
M;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&1I<V%B
M;&5D("T@8VQI8VL@=&\@96YA8FQE`&5N=')Y(&YO="!F;W5N9`!F:65L9`!F
M:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H
M;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YA8W1I=F4`:6YL:6YE`&EN
M<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE
M<UT`;6%I;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O`&UA=&-H`&UM
M`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T
M97!A9`!O<@!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!P<F]C
M;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\`<F5M;W1E(&5R<F]R(&EN
M('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF
M9F5R96YC97,`<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!);F=O`'-M<S)E
M;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES
M=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W
M.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(&EN9V\M,"XQ(&-V
M<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI0
M3U0M0W)E871I;VXM1&%T93H@,C`P-BTP,2TP-2`Q-3HP-"LP.#`P"E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#,M,#(M,3$@,#<Z-3,K,#@P,`I,87-T+51R86YS
M;&%T;W(Z($1A=FED($-H86YG(#QD879I9$!T;78N9V]V+G1W/@I,86YG=6%G
M92U496%M.B!4<F%D:71I;VYA;"!#:&EN97-E(#QI,3AN0&QI<W1S+FAO<F1E
M+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/4))1S4*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=`H`("@E<R"DT:ME*0`@**?6L;;!Y"`E<RD`("@E<R"DT:2Z*0`@**2U
MI-$I`"`HJ?JDT2D`("BL4:31*0`@IM.E0@"I\P`@J<ZJS``B)7,B(*2CK$^D
M0*W3I=B__0`B)7,B(*2CK$^D0*W3IK.NQ*JZO^^^W"X`(B5S(B"I?*6\IF(@
M2$]21$4@JKJU^:55P,DH4F5G:7-T<GDII*2S7:EW+@"GY*2CJ.P@(B5S(B!T
M<F5E(')E;F1E<F5R+@`B)7,BI'>FJ*5<JKJE6Z1*J.RX<[+5J'2RSJ2D+@`B
M)7,BI'>E6Z1*Q7:MK:ATLLXN`"(E<R*HPZ6\J]BEWSH@)7,N`*1WJ,^ESB`E
M+C)F34(@+*YEMG$@)2XR9DU"("RST;YL("@E+C)F)24I`"5D("5S(*5(I,X@
M)7,`L\RJ\:1`IKBQ2[U8Q=RG\ZGS("5D(*31JV4N`+/,JO$@)60@I-&N\+9(
MN7>S^``E<R`M(+/&I]&__0`E<R"K_*^^`"5S($M"`"5S(+K[Q4"^WJ=`("T@
MO52[>P`E<R"S7:EW`"5S(+7YI54`)7,@IE"W3K:UI=@`)7,@I'>F<Z9B`"5S
M(*9B("5S("5S`"5S(*1WM$ZD5:9#J,:VM:JZNOO%0+[>IT"T3KK\+B"]T*GS
MIKFNR:3$O^^G0;=1K6Z^WJ=`JKJVM:78+@"ELKO=K6X@)7,`)7,@I,``I^2D
MHZCL("5S+@`@)7,@J.P@)7,@ID`@)7,`)7.JNK-QL%2__0`E<ZJZIN:HQK[D
M`"5SJKJSQJ?1O_T`)7.JNJO=O^S#KP`E<SH@)7,`)7,Z(+-OJ\JK2*7SI*.D
M0*EWKW6ET:M(I*2JNK%(I?.D2*G2L4BU;RX@O="J8+=.I%6F0ZG2IK.JNKKT
MN/2S<[6RIK.E::_@K*JZ?*=!JKJMTZ1(N.JNQBX`+""P?:VW(``L(+!]K;<@
M)7,@)7,`+,7<I,:V<;%Q("5S(*CL("5S`"TM(+_OOMP@+2T`,3(@I'"NR:CN
M`#(T(*1PKLFH[@`R-""D<*[)J.X`I%>D0*VV`*:YL,^V]*6RMK>M;JO\J7>X
MZJ[&KG>F^*I!NMTN`+5OI<VD1J1`K=/$6:VKJKJ_^;M^`+']I5NQ2[9LI?,L
MP=F[W:UNIK.D0*W3(%!'4""DO;9]JO?&7RX`L?W%Y\/2I'?#L;.YJKJV;*7S
M+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N`+']N-&Q2[9LI?,LP=F[W:UN
MIK.D0*W3I+VV?2!01U`@JO?&7RRH<+%+(%!'4""J]\9?+*5(I,ZS<</VI&:E
M3RX`L?VP]:;FMFRE\\.QL[DLP=F[W:UNIK.D0*W3I+VV?2!01U`@JO?&7RRH
M<+%+(%!'4""J]\9?+*5(I,ZS<</VI&:E3RX`L?VXT;%+MFRE\RS!V;O=K6ZF
MLZ1`K=.DO;9](%--24U%(*KWQE\LJ'"Q2R!334E-12"J]\9?+*5(I,ZS<</V
MI&:E3RX`L?VP]:;FMFRE\\.QL[DLP=F[W:UNIK.D0*W3I+VV?2!3+TU)344@
MJO?&7RRH<+%+(%,O34E-12"J]\9?+*5(I,ZS<</VI&:E3RX`L?VE6[%+MFRE
M\RS!V;O=K6ZFLZ1`K=,@4TU)344@I+VV?:KWQE\N`*3(JV6FL[:S`*3(JV6D
M<*M"`*3(JV6FLZM"`*3(JV6P?:M"`*3(JV6P?;.W`*3(JV4OI,BKX0!!4$D@
MO7.XN0##]JGSLV^MT[USO^B^N0##]JGS+BXN`*6_I%6DZ`"EOZ2DI:$`Q7:M
MK:2CJ*PLM4RJ:ZO8I=\@5D93(*78O_TN`,5VK:VDHZBL++5,JFNKV*7?(%9&
M4R#`R:[7+@"Q8KBYN.JP5`"Q8KBYNU"Q2[U8`+%BN+FD=ZWAM;(N`+6RL6(`
MID.D2K;"IE>SYJM(I?.JNK-"LGJDZ*:A.@"QTJ7.`+'2I<ZY3,)OM7NFH2`B
M)7,B(*[)I:*QT3H@*"5D*2`E<P"W<[Q7`+=SO%>FN+ASLM4`MW.\5Z1LQ7:M
MK0"F8J:YMW.\5SH`MW.\5[ASLM4`MW.\5\5VK:T`MW.\5Z:XN'.RU:CL("(E
M<R(`MW.\5Z:XQ7:MK:;<(B5S(@"W<[Q7I$"MTZC/I<ZJS#H`MW.\5\3FINP`
MMW.\5Z1`K=.FJ*W[.@"W<[Q7N>\`MW.\5R`E<R"LL"!-;WII;&QA(*JZI,"M
MM@"W<[Q7J.RJNK-QL%2__3H`MW.\5ZCLI]JJNK-QL%2__0"W<[Q7J,^ESJK,
M`*1WMW.\5R`B)7,B(*CLJ'2RSJ2D+B"F_;5,JFNW<[Q7PT*E?JJZM?FE5;CJ
ML%0Z("5S+@"D=[=SO%<@(B5S(B"H[*ATLLZDI"X@IT&R>Z9BI6FE2+9IIN:U
M;J1*I$8N`+=SO%>HSZ7.JLRJNJ5<K^"EV*MELU'#]K.L+@"V:;:E`*9AIWT`
MLW&P5+_]`*:HK+"ZWK)ZK?L@+2"LL*CDI4RHSZ7.JLRS7:EWQ7:MK0"ZWK)Z
M`+QSIVD`069G:&%N:7-T86X@**K\M$FFO2D`06QB86YI82`HJORZN*3:I:>H
MR"D`06QG97)I82`HJORZN*3.IU&HR"D`MFRE\Z=/IE<`N>^[]`"Y[[OTI.BF
MH3H`J=*FLP"ITJ:SI'?%Y\/2JKJHSZ7.JLP`J=*FL[ASLM4`J=*FL\5VK:T`
MI7ZNV+UU`*G2IK.D5:9#L?BE\P"DN;-<LU>K:`"DN;-<IFZT6*W3N7&D;+9L
MI?.F8:=]`*2YLUS%W*?SMK6EV+USN+FJNJNLND$_`*1WIG.F8@#%W*?S($E-
M4U`@M6ZD2@#%W*?S($E-4U`@L4N]6`#%W*?S($E-4U`@J,^ESJK,`,7<I_.Y
M<:1LMFRE\Z;MIWT`Q=RG\[S+JD\`M,"E3J3EIG(`06UE<FEC86X@4V%M;V$@
M**S\Q%*P[<+$O*^HR"D`I$"MT[5,KL2JNJW(LU&HSZ7.+@"U;Z7-I$:D0*W3
MI;RJOJJZO_F[?BX`06YD;W)R82`HIG>Y1*;5*0!!;F=O;&$@**9WK?2IU"D`
M06YG=6EL;&$@**9WIF.IU*YQ*0"PSJ97I4ZR>J9SJ/H`M:JNUP"D=Z9>PM``
M06YT87)C=&EC82`HJVZWI:1JL[`I`$%N=&EG=6$@86YD($)A<F)U9&$@**9W
MM*.ERJYQI,ZDVKJXI:RY1JYQ*0"E]*;SI%6F0['XI?,`P+.ESK5[IJ$`P+.E
MSK5[IJ&R3;/F`,"SI<ZU>Z:AI'>T3KK\`*Y-I<ZK2*7SN4S";P"N3:7.J.RI
MTJ:SJKJFN*9`J,D`I^6MXP"Y=Z;TI&JD<`"E?*3K`*K\J=2G0J3E("A7:6YD
M;W=S+3$R-38I`,"CP5G`R:1JI'``P*/!6<#)IE>ZV0"G0;U4J7>M;J=2L*.S
M;ZW3LU>K:+;</P"G0;U4J7>M;J=2L*,@)7,@JKJU^:55MMP@/P"G0;U4J7>M
M;J=2L*,@(B5S(B"E2*3.I?2F\ZJZIKBX<[+5(#\`07)G96YT:6YA("BJ_*[:
MI\HI`$%R;65N:6$@**C(K/REIZC(*0"HR*S\I:>HR*3E("A!4DU30TE)+3@I
M`,/`LTX`07)U8F$@**K\OGRDVJYQ*0!!<V-E;G-I;VX@27-L86YD`*3EIG+#
MP+-.`*C(K'<OI-.EK:QVIF&PSP"P]:;FOMZG0+K[Q4"K9<7CI=R]5+M[N>^X
MW#\`I,"P=,3FINP`P'RXU:=2L*.D0*W3I*.F<Z9BJKJX<[+5+@#`?+C5IU*P
MHZ1`K=.DHZ9SIF*JNL5VK:TN`,!\N-6]<[_HI$"MTZ2CIG.F8JJZN'.RU2X`
MP'RXU;USO^BD0*W3I*.F<Z9BJKJF0*C)+@#$W:G*`*1+I.L`075S=')A;&EA
M("B_1*1JIU&HR"D`075S=')I82`HMOBF8:=1*0!!=71H7V-R>7-Q;#H@I^2D
MHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RX`075T:%]C>7)U<SH@IOBJ0;K=
MJ,.EO+2CJ-&XT[:UI.2TJ2X`075T:%]C<GEU<SH@I^2DHZCLJ=*[W:UNJKH@
M:6UA<""IM:;YKDVE\RX`075T:%]F='`Z(*?DI*.H[*G2N]VM;JJZ($944""I
MM:;YKDVE\RZ]T*VKMW.]<\2V(%!(4""HPZ5"I5ND2B`M+65N86)L92UF='`@
MO^^VM2RHTJ9P(&-O;F9I9W5R92`M+65N86)L92UF='``075T:%]I;6%P.B"G
MY*2CJ.RITKO=K6ZJNB!)34%0(*FUIOFN3:7S+@!!=71H7VMR8C4Z(*?DI*.H
M[*G2N]VM;JJZ(&MR8C4@J;6F^:Y-I?,N`$%U=&A?;&1A<#H@MW.\5ZC/I<ZJ
MS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!L,@`075T:%]L9&%P.B"G4K"C
MJ,^ESJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]JD&PR`!!=71H7VQD87`Z
M(*?DI*.H[*G2N]VM;JJZ($Q$05`@J;6F^:Y-I?,N`$%U=&A?;&1A<#H@M4RJ
M:[=SO%>HSZ7.JLP@)7,N(*;XJD&^N:9>P+,Z`$%U=&A?;&1A<#H@M4RJ:[*^
ML*.HSZ7.JLP@)7,`075T:%]L9&%P.B"U3*IKI_.W<ZC/I<ZJS"`E<P!!=71H
M7VQD87`Z(*?SMW.HSZ7.JLRS;[:UI5ROX*78JV6HPZ2CI.2TJ:78O_VJ0;#(
M`$%U=&A?;6-A;#H@I^2DHZCLJ=*[W:UNJKH@34-!3""IM:;YKDVE\RX`075T
M:%]S;6)A=71H.B"GY*2CJ.RITKO=K6ZJNB!S;6)A=71H(*FUIOFN3:7S+@!)
M34%0(*;XJD&^N<7GP]*_^;M^+@#%Y\/2I:*QT2X`Q>?#TJ6BL=$N("5S`%)!
M1$E54R#%Y\/2O_F[?BX`1E10(,7GP]*_^;M^+@!334(@Q>?#TK_YNWXN`*A#
MM^VFL[*GL,JNR:Q/IU^FV[#*I_.W<Z:YN4S";[5[IJ$_`*5II<ZJNL3FINPZ
M`$%Z97)B86EJ86X@**C(MNNK]+5-*0"M2;2Z`*U)M+K#0Z;B`&ME<F)E<F]S
M(+%+O5B_^;M^+@!K97)B97)O<R"HSZ7.JLRF5[K9O_F[?BX`0F%H86UA<R`H
MI-JKHK"H*0!"86AR86EN("BDVJI,*0"J:<.YJKJN_*3E("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:"`HJ7.E6ZG4*0!"87)B861O<R`HI-JHJ:9H*0"GY*2C
MJ.RYSZ7<I=B__2`B)7,B+@"P\KUU`*^UI?.PQJ6[`+9]P%FL3P!"96QA<G5S
M`$)E;&=I=6T@**3QIU&NR2D`0F5L:7IE("BHJ:B]M+4I`$)E;FEN("BHJ;GG
M*0!"97)M=61A("BFRKQ]N48I`$)H=71A;B`HI*.DIBD`LW.ULJ6BL=$Z("@E
M<RD@)7,`I<VDZ0"VPJ97L^8`O7._Z+;"IE>SY@"EV*MEJKJY3,)OOKG%6+#*
MM7NFH:C#I;RDY+2IML*F5[/FJKJE7*_@+@"D=[-1ID.LL+;"IE>SYJJZMFRE
M\Z9AIWT`I^2DHZCLP+.ESK5[IJ$B)3(D<R*JNK#/MO0B)3$D<R(N`+#/MO2S
M7:EW`+#/MO2KK+I!`*6[I.4`LLK%Z0!";VQI=FEA("BLP:=1NONHR"D`KM'%
MT@"NV+UU`*[8O76D:J1P`*[8O74`0F]S;FEA(&%N9"!(97)Z96=O=FEN82`H
MJFFD:*6GJ,BDSK;"P<FM]+K[J+HI`*7^LZ$`0F]T<W=A;F$@**III;ZHNBD`
MJ;.SH0!";W5V970@27-L86YD`$)R87II;"`HI-JFZ"D`0G)I=&ES:"!);F1I
M86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M("BH6K7<*0!"
M=6QG87)I82`HJT^E6Z=1J,@I`+:UI=BRQ;BY`$)U<FMI;F$@1F%S;R`HI:RT
M6*_'JFNOP2D`0G5R=6YD:2`HNUJVJ:9A*0"JJ:VQNMZR>@!#4D,`0U),(*3`
MLZ'"20#`>*9SKN:DNJYE+BXN7V4`I]:H^JKLJ6RDQJE\I;RGN::H+@"FYJC&
MON0`N7.OQ:VW`$-A;6)O9&EA("BL6JY(N>LI`$-A;65R;V]N("BSV+/!MJDI
M`+5,JFNFV[#*K:NX;;%+O5@LO=#!<+6XIT&JNJATLLZZWK)ZK?LN`+5,JFN\
M9Z1*P,FNUR`B)7,B`+5,JFNS<[UUIMP@24U!4""F^*I!OKDZ("5S`+5,JFNV
M?;'2P,FNUR`B)7,B+@!#86YA9&$@**5;KK.D:BD`J/JN^`"H^J[XL-W#1*9>
ML_@`M4RJ:Z=2L*/`R:[7("(E<R(N`*?DI*.H[+S(IG.EV+_]+@"ORJ36("=T
M87)G971&:6QE)R"PT;S&M4RJ:\1^Q/*S0K)Z+@"U3*IKLKZPHZ78O_T@(B5S
M(BX`M4RJ:[*^L*,[("5D(*W3I&RVL*1WIG.F8BX`M4RJ:ZVKLM6A0ZG2M*.H
MT:JZL$^__;S&I=B[4*7]JV6ITL!XIG.JNKCJKL:DH[+%+@"U3*IKML>P9<*R
ML%2H[*O\J7>JNKBYO5@N`$-A<&4@5F5R9&4@*+K[O'>HI"D`NZ&I^J3EIG(`
ML,^DP*1JI'"\9P"DP,/^NU"\T,72`$-A>6UA;B!)<VQA;F1S("BV?;#2N'.N
M<2D`L,:ENP"FYK#*N7&XW`#`>*9SKN:DNJYE`,!XIG.NYKG4I5(Z`,!XIG.N
MYJ2ZKF4`P'BF<Z[FMJ&V6CH`IN:PRKEQN-P`MNNZN*]3I.4@*$E33RTX.#4Y
M+3$T*0"X;:2D`$-E;G1R86P@069R:6-A;B!297!U8FQI8R`HI*2K1*9`J4VP
MZBD`I*2\VB`H25-/+3@X-3DM,C``OLS#TK+3N&``OLS#TK[6IK.JS`"^S,/2
MK$:UI@!#:&%D("BL9+QW*0"G\Z?O`*?SI^^G0:JZL4N]6`"G\Z?OIT&JNJJZ
MI?ZF5Z5(I,ZF7K9LIF&G?2X`I'?`>*9SQ=RG\P"EV*MEJKJS7:EWJ,.EO*3D
MM*FQ2[U8Q=RG\RX@O=#!<+6XIT&JNKK>LGJM^RX`IG*DN`#`RZQDLW.ULBXN
M+E]K`$-H:6QE("BTO*=1*0!#:&EN82`HI*2PZBD`PK+%Z:2DI.4@*$=",C,Q
M,BD`I;_%Z:2DI.4@*$)I9S4I`+_OOMS`LZ7.M7NFH3H`O^^^W+%+O5@`O^^^
MW*1`K=.HSZ7.JLRF5[K9`*3IM,'%XZ7<I.BFH3H`O^^^W+:UI=BKK+I!JKJM
MMZ[F`$-H<FES=&UA<R!)<VQA;F0@*+ATO<^N<2D`I^2DHZCL("5S(*JZP_ZG
M3ZEWN'$N`+2X`+)-L*.W3+-N($]F9FEC92"\T,72`+)-L*.L9+C?`+)-L*.H
MSZ7.JLPZ("5S`+)-L*.HSZ7.JLP`LDVPHZC/I<ZJS*JZN.JNQ@"QW\+@M+@`
MJ_:WQKFKP>2E2,1^Q/(`0VQI8VMA=&5L;""S>KE,($A45%``P_:SK+7XM:$`
MMK.V<0"FK:9HMK,`L[$`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`I^G%?+CJ
MKL:GJ`"GZ<5\P^2LR0!#;VQO;6)I82`HK?2MVZ3QJ,@I`,-#IN(`O=6FXKU,
M`#$VMFFF[,-#IN*E3KU8`,3F.@#$YJ;LO-##1`"E9+-Q`*E2I4\`I^6FN*E2
MI4\`M?N]UP"ZV:E)`$-O;6]R;W,@**SLO*_#N2D`I+VE<0"Y<;BC`,#TN=(`
ML?BE\P"N=+*G`+M0(%!$02"T>*17JZRY<;BC++2\O'JKK*3BOO>E2*3.($]U
M=&QO;VL@JKJF4*A"LUVI=RX`LUVI=[CJKL:Y3+3!+@"S7:EW("5S`+U4NWNQ
M2[U8`$-O;F=O("BMZ*I'*0!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE("BMZ*I'ID"I3;#J*0"S<[6RI:*QT2X`LW.ULJ6BL=$Z(`"S
M<[6RI:*QT0"S<[6RIMRDO;9]JO?&7Z;XJD&^N:[)OD2IVBX`LW.ULJ;<I+VV
M?:KWQE^F^*I!OKFNR;Y$J=HN(*WLIETZ("5S("@E<RD`LW.ULJ;<($944"#`
MR:[7IOBJ0;ZYI:*QT2X`LW.UN*1(`+!/O_VD=Z:HI5RF8;=SO%>FW*=!JKJS
M<;!4O_VDI"X`I5VG=`#`H\%9P,FNUZJZI+JN9:NLND$Z(``B)7,B(,#)KM>D
MNJYE`,1^Q/(`0V]O:R!)<VQA;F1S("BL[*=*N'.N<2D`O<:[<P"]QKMS("5S
M`+W&NW.EHK'1.B`E<P`E<R"JNKW&NW,`O<:[<P!#;W-T82!2:6-A("BM]+2U
MI&J^I*5;*0!#;W1E(&0G279O:7)E("BV2*3ZKORII"D`M4RJ:Z5((%!'4""E
M6[%+MFRE\SH@`+5,JFNE2"!01U`@L/6FYK9LI?/#L;.Y.B``M4RJ:Z5((%,O
M34E-12"E6[%+MFRE\RX`M4RJ:ZRP(%,O34E-12"V;*7SP[&SN2X`M4RJ:[=S
MO%>S<[6XI$@N("5S`+5,JFO#M+6R($Q$05`@IOBJ0;ZY`+5,JFO#M+6R(&QD
M87`@IOBJ0;ZY`+5,JFO`RZQDMVRO<2X@)7,`M4RJ:[-SM;*FW"!L9&%P(*;X
MJD&^N0"U3*IKLW.ULJ;<IOBJ0;ZY("(E<R(@J,^ESB!&5%`Z("5S`+5,JFNK
MV*7?L'2X;;ASLM4N("5S`+5,JFNXT;%+(%!'4""XZJ[&.B``M4RJ:[C1L4L@
M4R]-24U%(+CJKL8N`+5,JFNG4K"CLW.UN*1(+B`E<P"U3*IKIU*PH[!TN&VR
M3;/F+B`E<P"U3*IKIU*PHZ?SMW.U>Z:A("(E<R(N`+5,JFNH3:EWIJRE\Z1(
MJKJY<:1LMFRE\Z;LIWTN`+5,JFO`\JCZI[F^XZJZLW&P5+_]+@"U3*IKP/*H
M^J>YON.JNK!TN&VR3;/F+@"U3*IKP/*H^K!TN&VR3;/FI*2JNKASLM4N`+5,
MJFNX_*1*M::RI"`B)7,B+@"U3*IKJ]BEWZ78O_T@(B5S(BX`M4RJ:Z;;JO?&
M7Z;XJD&^N:CZL6^DO;9]JO?&7RX`M4RJ:[9]L=(@(B5S(B"E2+QGI$HN`+5,
MJFNV?;'2("5S+@"U3*IKMGVQTKK[Q4"D=:=`O-*RU2`E<P"U3*IKMGVQTJ78
MO_T@(B5S(BX`M4RJ:[-SL;4@3$1!4"`@IOBJ0;ZY+@"U3*IKQ:JH^B`E<RX`
MM4RJ:ZVKMW.S7:EWJ,^ESJK,JKJQ2[U8+B"SH:3`JKJRT[A@I*.EO[U4+B"]
MT,%PM;BG0:JZJ'2RSKK>LGJM^Z5(J/.G5;-"LGHN`+5,JFO%JJCZIG.H^K&Q
MJ.ZJ[2A!8V-E<W,@0V]N=')O;"!,:7-T*0"U3*IKQ:JH^K-QL%2__2X@)7,`
MM4RJ:\6JJ/JP=+AMLDVE52X@)7,`M4RJ:\6JJ/JP=+AMLDVE52X@)7,`M4RJ
M:\6JJ/JF^*I!OKFJNJS;P_:O4ZG*`+5,JFNF7K1?LUVI=RX`M4RJ:Z=2L*.E
MV+_]("(E<R(N`+5,JFO`>*9S("5S(*JZLUVI=RX`M4RJ:\!XIG.SQJ7WLUVI
M=RX`M4RJ:\!XIG.SQJ7WLUVI=SH@)7,N`+5,JFO`>*9SI_.W<[5[IJ&H[#H@
M(B5S(BX`M4RJ:\!XIG.SQJ7WLUVI=R`E<RX`M4RJ:\!XIG.S7:EWP,DE<RX@
MIT&E::5(J,^ESB5SI*2JNJCDI4RE7*_@P'BF<[-=J7>ISJ3BL,J]QKMSI%6M
ML;5[IJ&]6*CL("5S+@"U3*IKMVJT32!,1$%0(""F^*I!OKDN`+5,JFNG4K"C
M("(E<R(N`+5,JFNG\[=SLW.UN*1(+B`E<P"U3*IKI_.W<[!TN&VR3:55+B`E
M<P"U3*IKPM"\9R`B)7,B.B`E<R"JNK-=J7<N`*?DI*.H["!-;WII;&QA(*JZ
MI,"MMBX@O="]5+M[I,"MMJQ/IU^V?;'2+@"U3*IKO>&DJ:C/I<ZJS"`B)7,B
M(*15ID/%=JVMJ.RK2*7SIU@@(B5S(CH@)7,`I]ZS3J5Y`+#JKF$`O=*J[0"K
MV*7?`*O8I=^D0*W3LW.UL@"KV*7?I$"MT[=SJKH`J]BEW[=SJTBE\Z=8`*O8
MI=^FN*M(I?.G6`"KV*7?JLRJNL5VK:T`JTBESJ5DN+F]6`!#<F]A=&EA("BG
M2L.YINBHR"D`0W5B82`HI6JDVBD`I=BK9;=\M,$`I=BK9:[)MJ$`I=BK9;KT
MIWT`I=BK9:JZJ,^ESJK,`*78JV6DT:[P`*78JV6JNJJLJG`Z(`"EV*MEJKJM
MMZ[F`*;;K7&D0*C'M6ZD2B5SJ^&ITJUNL/6FYJJZI'6G0"X`L,6D50"PQ:15
M`$-Y<')U<R`HP<FTMK#'M+4I`*;HJ+VZN*3E("A+3TDX+5(I`*;HJ+VZN*3E
M("A7:6YD;W=S+3$R-3$I`*;HJ+VZN*3E+Z]1ITK$]:3E("A+3TDX+54I`$-Z
M96-H(%)E<'5B;&EC("BQMJ=*ID"I3;#J*0"DZ0"D=["QI<XZ(`"XZJ[&J-.W
MO:97NMD@*+W0L-&FTB!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`*A#I.D`OO"JK+CJ
MKL;"<\3]`+CJKL:N=[=JM$T`I.FTP0"FK*CLI.FTP0"_[[[<I.FTP0"EU:31
M`*=2L*/$YJ;L7VP`L+&ES@"D4:1'I.L`I%&V::;LO,:F<@"T[J36P5FQQ@"Y
M=[-=`+EWLUW#0Z;B`+EWLUVJNJBMI??#T:=/`+EWLUVI4J5/N-&J4KZY*%-H
M96QL*0"I=[AQ`*=2L*,`IU*PHR`E<P"G4K"CP'BF<Z[F`*=2L*.Q^*7S`*=2
ML*.X<[+5`*=2L*.L]K_]`*=2L*/%=JVM`*=2L*.A0K)-JL6V;*7S`*=2L*/`
M>*9SKN8`IU*PH\3FINP`IU*PH[)[IG.JNK3`I4Z\RZI/`+G]J;.G4K"CJTBE
M\P"G4K"C(B5S(JJZQ7:MK0"]5*EWK6ZG4K"C(B5S(JJZQ7:MK:5(I,ZFN,5V
MK:T@/P"G4K"CID,`IU*PHZG2O^^^W*JZJ*VE]\/1IT^XZJ[&`*=2L*.EV*ME
MJKK$YJ;L`*=2L*.EV*MEJKJF0P"D=Z=2L*,`I_.W<[5[IJ$@(B5S(B"D=Z=2
ML*,N`+N\L&6H[*?:JKJFK*7SO6,`N[RP9:CLI]JJNJ:LI?.]8ZC#I4*]QKMS
MJ.P`N[RP9:CLI]JJNJ:LI?.]8ZC#I4+"X*=]N[RP9:CL`+N\L&6H[*M(I?.G
M6`"[O+!EKLFVH0!$96YM87)K("BDIK/!*0"PW<-$M'FM>@"T>:UZ`++3N&`@
M*+W0L-&FTB!(;W)D92"P3[_]P,FNURDZ`++3N&"]T+#1IM*H=++.NMZR>K5N
MO_TN`*SCM6\`Q5/"2;?%J]<`L\RKX:1`I'"NR:JZQ5/"2;?%J]<Z(`#%4\))
MM\6KUSH@`+%QI:JFW*5K`+%QI6NFW*6J`*78O_T`L+&ESB`E<P"D=["QI<X`
MI4@@,C0@I'"NR:CNQ>.EW#\`Q>.EW+_OMK4`Q>.EW+C4LM.JNKEWL_@`M^VR
MQ:98N4S";[-7JVBJNJM(I?.S4:Y-I<ZNR:%!Q>.EW++3N&"DNJYE/P#%XZ7<
MN7>S^"`H5$%&*0#%XZ7<KN:FH0"VQ[!EIEZQ^`!$:FEB;W5T:2`HIDZEK*9A
M*0"F<*I'K$^P4;W7N'.RU:G.O'.G::M(I?,LJVBDH[;'L&6PLK3!IE[`LU]N
M`*2CIU*PHP"DHZUNJKVQM:9SJ/H@;6%I;G1E;F%N8V4N<&AP`+#UIN:FN:1`
ML,JG0#H`LL2D0+6GL$^__:Q/IU^E7:=TQ.:F[*97NMD_(*9PJD>L3[W0I,2_
M[RX`MGW`6:2CK$\`I*.E7:=T`+6RI\"DHZQ/`*2CIG.F8@"DH[+%IE@@**5(
MIONF[++%N+FJ[:7<*0!$;VUI;FEC82`HIFBI^J6GI5LI`$1O;6EN:6-A;B!2
M97!U8FQI8R`HIFBI^J6GI5NF0*E-L.HI`,'9J%.FL[%BN+FVW#\@M?FE52X`
MI%6X_`"D5;C\("5S`*15N/RS7:EWP,FNUZ5TIG.LL"!02%`@M7NFH2X`I%6I
MU*5<K^"J[0##Q*M^`+EQI&RV;*7S`+_YNWX`16-U861O<B`HI,RERJ9HNK@I
M`+USO^@`O7._Z"`E<P"]<[_HL,^V]`"]<[_HN'.RU0"]<[_HQ7:MK0"]<[_H
MQ7:MK0"]<[_H)7.JNL5VK:T`O7._Z+_OMK4`O7._Z"(E<R*JNL5VK:T`O7._
MZ"5SJKK%=JVM`+'0J'P`16=Y<'0@**Y*I,XI`$5L(%-A;'9A9&]R("C"Q+JX
MI<NF:"D`I+BE\RXN+@"Y<:1LMFRE\P"Y<:1LMFRE\Z;MIWT`N7&D;+9LI?.F
M[:=]I;*VMZ=KIE@N`+EQI&RV;*7SO52[>P!%;6%I;"UT;RU335,@N6BY1+ZY
M`*KML:&RQ;BY`*K%I=6K2*7S+@"JQ:75M;*J1RX`JL6EU;=JM$VVM:78`+'2
MI<X@)7,`I+FS7*;;P\"T6;2AI$JWTZ3YJ.RK2*7SI*0HNO2MMKUSO&>\TJ:A
M*2`_`+'2L,JWQKFKI6O!Y*5<K^"J[3\`I'>QTJ7.`+6RI_2F?J7W`+6RI\"L
M3P"I\:1JO7._Z+ZY`*9PJD>G0;O=K6ZMJ[-=L4N]6"R]T+_II$JD0*W3IG>E
M_K#=I7DLJ-*F<"`GIT'#9*JKJKJF5[K9(#\G.@"F8J:YO^FD2KQVN;.JNKKT
MIWT`M:6I\P!%<75A=&]R:6%L($=U:6YE82`HJ*JY1+18I+JHR"D`17)I=')E
M82`HI,REWZ]3J+VF=RD`O_F[?@"KV*7?L,^V]"5SKLFU;Z7-O_F[?@"G4K"C
MIE"H0L'CPDDZ("5S(*[)M6^ES;_YNWX`IU*PHZ90J$*P3[_].B`E<R"NR;5O
MI<V_^;M^`,6JJ/JDNJYE.B5S(*[)M6^ES;_YNWX`Q:JH^K)[IN:Y3,)OM7NF
MH3H@*"5D*2`@)7,@KLFU;Z7-O_F[?@#`>*9SQ=RG\Z[)M6^ES;_YNWXN`*?S
MMW.Q2[U8.B`E<R"NR;5OI<V_^;M^`+QGI$H@(B5S(B"NR;5OI<V_^;M^+@!%
M<W1O;FEA("BW4JA&I:>HR"D`171H:6]P:6$@**;GK\&D\:C(*0"ZV+':`$5U
M<F]P92`HO-JL=RD`J$,@,34@I,#$P0"H0R`R(*3`Q,$`J$,@,S`@K.W$P0"H
M0R`U(*3`Q,$`J$.FN+5NI$H`J$,@,S`@I,#$P0"H0R`Q(*3`Q,$`O62HTJW(
M.@"P]:;F`*1WJ]BEWZJZLU>K:`"F<Z9B`*YIMGT`KFFV?;CJKL:GJ`"M;JA$
M("<I)P"TP:O=(#$@K=.JJZ7S+""Q;ZCL("5D+@"H[+3!I.D`N-&[H:W[`*ME
MM+K#0Z;B`$944""D5[;'LUVI=RX`Q:JH^K"^IFZS7:EWI:*QT0"U3*IKLW.]
M=:;<($Q$05`@IOBJ0;ZY+@"U3*IKLW.]=:;<(%--0B"F^*I!OKDN`+W&NW.E
MHK'1IML@(B5S(BX`O<:[<Z6BL=&H["`B)7,B+@"U3*IKJ]BEWZ1`K=.W<ZJZ
M(%-!4TP@LW.QM2X`MVBROJ6BL=&H["`B)7,B+@#"7JCZI:*QT3H@)7,`M+:S
M<0!&86QK;&%N9"!)<VQA;F1S(*IKQ/6G2KK6N'.N<2`HL*BZN+K[K\>TM;AS
MKG$I`$9A<F]E($ES;&%N9',`Q%FMJ[_YNWXZ`+;'KW4`ML>O=0"D1Z3K`+=0
MQ+$`MU#$L3H@`*3RI/*K0@"U=;S(L'VSMP#$YJ;LL'VF0P!&:6II("BTM,#9
M*0#`R:[7O,:EV#H@)7,@K=/`R:[7`,#)KM>\QJ78.B`E<R#`R:[7`,#)KM?!
M8+K>`,#)KM>F5[K9`,#)KM>_[[[<`,#)KM>D5[;'`,#)KM>D5[;'I5ROX*6\
MLU&DY+2I+@"N3:7.N4S";ZGSJ=*FLZM(I?,`I76N3:7.N4S";ZGSK-VY3*JZ
MJTBE\P"E=:Y-I<ZY3,)OJ?.EO*S=N4RJNJM(I?,`N4S";[ZYO^^VM0"Y3,)O
MLU>K:`"Y3,)OLU>K:`#%XZ7<N4S";[ZYM7NFH0"Y3,)OLU>K:%]2`+E,PF^E
MS:[$.B"D=[W&NW,@)7,@J\JK2*7SIMRK2*7SIU@@(B5S(BX`N4S";Z7-KL0Z
M(*1WIU*PHR`E<R"KRJM(I?,N`+E,PF^ES:[$.B"D=[=HLKX@)7,@J\JK2*7S
MJ.RK2*7SIU@@(B5S(BX`N4S";Z7-KL0Z(*1WIU*PHR`E<R"KRK+%IEBVPJ97
ML^:Q^*7SJKJK2*7S+@"Y3,)OI<VNQ#H@L4BFVR`B)3(D<R(@JKJK2*7S("(E
M,21S(B"D=[-1O<:[<ZCLJTBE\Z=8("(E,R1S(BX`N4S";Z7-KL0Z(*M(I?,@
M(B5S(B"Q2*;;("(E<R(@I'>S4:=2L*,N`+E,PF^ES:[$.B"Q2*;;("(E,B1S
M(B"JNJM(I?,@(B4Q)',B(*1WLU&W:+*^IMRK2*7SIU@@(B4S)',B+@"GY*2C
MJ.RY3,)OOKDN`+E,PF^^N0!&:6YL86YD("BJXL3U*0"D5Z5BI.L`I%>IM@"I
M5*EWI/&HT@"D5Z15Q$&MRP"O0K#*`,/Z`*78O_T@)7,@I*.F<Z9B`*9RJZS#
M0Z;B`*VYJJL`J=*FL[%(M;FGVJJZJTBE\Z5UK6ZRQ:98.@"F7:RPPG/$_;ZY
MJ,.EO*3DM*F\=KFSI5ROX"X`KO"V2+EWL_@@*%1!1BD`N7>S^*31O,8@*+EW
ML_BDT;S&I5VL0:75I-&E2*3.J5VVH:JZN.JNQCNF<*I'N7>S^*31O,:X^ZKX
ML4ZF^Z7.I/&X^[QEM%2JNJJIK;$I`*?1L$^Q2[U8(#\`JNVSY@"D<+MY`*1P
MNWG#_JNL`*1PNWD`I'"[>2`R`+W7OL(`IMNPRL+@L4@`I=BK9:JZN4S";[ZY
MQ5BPRK5[IJ&HPZ6\I.2TJ:;;L,K"X+%(JKJE7*_@+@"FV[#*PN"K2`"]<[_H
MIMNPRL+@JT@`K%"TP:2M`*[8K%L`1G)A;F-E("BJ:[#J*0!&<F%N8V4L($UE
M=')O<&]L:71A;@!&<F5N8V@@1W5I86YA("BJ:\3=NURHR*BZ*0!&<F5N8V@@
M4&]L>6YE<VEA("BJ:\3=K,&G4:6GINBHR"D`1G)E;F-H(%-O=71H97)N(%1E
M<G)I=&]R:65S`+%(I?.D2`"Q<0"GN;[CM'FM>@"ZH:3K`*7^IE<`1V%B;VX@
M**5;M%XI`,/`M%DZ`$=A;6)I82`HI<RD\:C(*0"RHZ7-("5S(*W3J'2RSK-=
MJ7<`I'>RHZ7-JKJS7:EWN.JNQ@!'96]R9VEA("BS[*IVJ,BF0*E-L.HI`$=E
M<FUA;GD@*+QWL.HI`$=H86YA("BM>Z_'*0!':6)R86QT87(@**J]I:S#N:K[
M*0"F5[K9`*MEJ;D`K?2\=[JX`$=O;V=L92"F8;G/`$=O;V=L92"W:K1-`*;'
MMJ4`I&JI\P"D:JGSJ<ZUI:GS`$=R965C92`HI\;#OBD`I\;#OJ3E("A)4T\M
M.#@U.2TW*0!'<F5E;FQA;F0@**[FLZ[$]:YQ*0!G<F5N861A("BNYK?GK\>Y
M1BD`N'.RU;K>LGH`N'.RU:97NMFDH[%OJL6EU0!'<F]U<%]L9&%P.B"U3*IK
MMW.\5[ASLM4@)7,N(*;XJD&^N:9>P+,Z(`!'<F]U<%]L9&%P.B"U3*IKIU*P
MH[ASLM4@)7,`1W)O=7!?;&1A<#H@M4RJ:Z?SMW.X<[+5("5S`+ASLM4`1W5A
M9&5L;W5P92`HK?2\=ZREM+8I`$=U86T@*,/VKG$I`$=U871E;6%L82`HI<JF
M8;"HJ=0I`*[FKJ:FZ*YQ`*C3NZO%=JVM`+-8J\BO9*BE`$=U:6YE82`HM%BD
MNJC(*0!'=6EN96$M0FES<V%U("BT6*2ZJ,BD\:_!ID"I3;#J*0!'=7EA;F$@
M*+M<J,BHNBD`ME>DY;-SM;*[>:BE`*?DI*.H["!(5%10(,7GP](N`$AA:71I
M("BN_*9A*0#"^+3J+;ITNN(`QD<`JNW`60"J[<!9`$AE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<P"D:KEPJT(`I\:G0JC3I.4@*$E33RTX.#4Y
M+3@M22D`L*JKUP"[H:GZ`+USO^B^N:C/I<Z[H:GZ`+NAJ?H`I6*R>0"S;[C,
MK$_`R:[7JKJV?:EL.@"PJ@"N85]M`$AO;'D@4V5E("BQZ[_-J:,I`*YA`*;M
MKF&F8:=]`*YAI=B__0"F[:YAN7&XW`!(;VYD=7)A<R`HI[NSHZG4M+4I`$AO
M;F<@2V]N9R`HK;NTY"D`2&]R9&4`2&]R9&4O2V]L86(Z(+9LI?,@)3(D<R"D
MI+E*J.RU3*[$JKH@)3$D<R!834RXZJ[&`$AO<F1E+TMO;&%B.B"U3+9LI?.^
M0:98JJNE\R`E<P!(;W)D92]+;VQA8CH@MFRE\R`E,B1S(*2DI^2DHZCLJJNE
M\ZNLND$@)3$D<P!(;W)D92]+;VQA8CH@I'>FJ*5<JKJROK"C("5S("(E<R(`
M2&]R9&4O2V]L86(Z(+[CIEBD=;5[N]VM;B`G9&]M>&UL)R"JNB!02%`@J;6F
M^0!(;W)D92]+;VQA8CH@M4RJ:ZO8I=\@)7,@JJNE\ZJZ(%A-3""^\`!(;W)D
M92]+;VQA8CH@M4RJ:[*^L*,@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(+5,
MJFO`\JCZLZ&E]R`E<R"KK+I!JKH@34E-12##T:=/N+F]6`!(;W)D92]+;VQA
M8CH@M4RJ:Z90J$(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(+5,JFNF4*A"
MI,"HR3H@)7,`2&]R9&4O2V]L86(Z(*6\JKZJNJ3`J,D@(B5S(@"D]*6MO74`
MI/2EK;G4I5(`I/2EK3H`IT&F<*;SJ.RFN2`_("B]T+'4K7HA*0"G0:UNIEBH
MUJ9HI-:MT\3FINRI3S\`Q.:F[+S&I=BF0*UP/P"G0:UNIEBHUJ9HI-:F0ZE/
M/P"WPZO7`+?#J]<Z(`"WQKU=I&JN=@!(=6YG87)Y("BF2:3ZIU$I`$E-05`@
MMFR]8ZO8I=^EHK'1.B`E<P!)34%0(+9LO6.G4K"CI:*QT3H@)7,`24U!4""V
M;+UCNL^ZT+!TN&VKV*7?I:*QT3H@)7,`25`@INRG?0!)4""F[*=]M4RJ:ZC/
MI<XN`$E0(*;LIWVHPZ2CIF(@0TE$4B"JNJ2YLURPS[;TI*0N`*9BJ^&ML;2A
MI$JF0U]N`$EC96QA;F0@**9"KG$I`*_"N<^EW``E<ZJZN<^EW`"YSZ7<I,ZD
MY:9R`*BMI??#T:=/JKJF5[K9.@"F<*I'M4RJ:Z6_O52F8<7CI=PL("5S(*5(
MI72V?;'2MFRE\ZGSMW.U^+6AM^VDI"X`J,^ESB!);G1E<FYE="!%>'!L;W)E
M<B#"<\3]OKFNR:9PJD>H4Z:SK-VH[*7TIO.JNJ1PN<^EW"P@IT&E::_@N]VM
M;J3$O^^S;ZW3MK6EV*5(P_:SK"!03D<@O':YLZJZP?3"PZ[$JD<N`*9PJD>L
MW:CLLV^K:*A3IK.\=KFSJKJP5*ZG++-OJNVEW*=!JKK"<\3]OKFU3*IKQ>.E
MW*17ML>JNKQVN;,N`+QVN;.Y=\3].@"\=KFSNO2G?0"\=KFSNO2G?3H`O':Y
MLZC3IMO#P+19`+QVN;.HTZ;;P\"T63H`I%>VQ[QVN;,`O':YLP"VUZ1*+""H
M0L9*("5D`*VKK6X`MM>D2L3FINPZ("5S`+;7I$K$YJ;L.@"F8JOAK;&TH:1*
MID-?<P"_Z:1*I*.EO[U4JKJG0*7.O5@N`+W0P,NL9*=!JKJHSZ7.JLRF5[K9
MI,ZQ2[U8`*C/I<ZJS*97NMFDHZ6_O52ISJK,N7&D;+9LI?.F[:=]I'?%W*?S
M+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BX`O%>E6\%9L<8`26YD
M:6$@**9,J]<I`*W3IT^HSZ7.JLP`I=BK9:JZN4S";[ZYQ5BPRK5[IJ&HPZ6\
MI.2TJ:W3IT^S5ZMH+@!);F1O;F5S:6$@**9,I:<I`*O\J7>[O+!EJTBE\ZJZ
MJTBE\Z=8J,.DHZ9SIF(N`+CJL%0`N.JP5`"U3*5II<ZJNKCJL%0N`*9BJ^&M
ML;2AI$K$YJ;L7V\`M*&D2KG/I/D`M*&D2JKMKN8`M*&D2KKTN/2S<[6R`*9B
MJV6ML;2AI$K$YJ;L7T,`IF*EV*MEQ.:F[*OAK;&TH:1*I$"MT[=SQ.:F[`"F
M8J78JV7$YJ;LJV6ML;2AI$JD0*W3MW/$YJ;L`*9BI=BK9:9#J^&ML;2AI$JD
M0*W3MW.F0P"F8J78JV6F0ZMEK;&TH:1*I$"MT[=SID,`IF*EV*MEN&#"2:OA
MK;&TH:1*I$"MTZQQN*@`IF*EV*MEN&#"2:MEK;&TH:1*I$"MTZQQN*@`M*&D
M2J5IM,"E3KS+JD\`MW.Q2[U8L4ZQ2+5OJ.RS;ZW3MFRE\Z9AIWTZ`*9BJ^&M
ML;2AI$K`>*9SKN8`IF*K9:VQM*&D2L!XIG.NY@"F8JOAK;&TH:1*Q.:F[`"F
M8JMEK;&TH:1*Q.:F[`"TH:1*MFRE\P"F8JOAK;&TH:1*K'&XJ`"F8JMEK;&T
MH:1*K'&XJ`"F8JOAK;&TH:1*ID,`IF*K9:VQM*&D2J9#`*9WI?ZPW:5YJKJU
MJJ[7.@"TH:1*+\7<I_.\=KFS`+2AI$HOQ=RG\[KTN/2S<[6R`,))O,:DHZBL
MI4BFW*GSM4RJ:[;'L&6UN;!TN&VX<[+5+@#"2;S&I*.HK"X`ON.\Q@"^X[S&
MID,`M4RNQ*JZ(%5$2"BHSZ7.JLRXZJ[&JNW`62DN`+5,KL2JNB!:25`@N.JN
MQBX`M4RNQ*JZP+.ESK5[IJ$N`+5,KL2JNJ?EIKBXN;U8+@"P9:58JKJXZJ[&
MM4RNQ"X`M4RNQ*JZI=B\T*;MIWT`M4RNQ*JZP,FNUZ[FIJ$`M4RNQ*JZL<+%
M=KU8+@"U3*[$JKJF8;#/+@"U3*[$JKH@;7-G7W1Y<&4N`+5,KL2JNJG.I^2D
MHZCL(&%P:5]I9"X`M4RNQ*JZJ<ZGY*2CJ.RPT;S&+@"U3*[$JKJD]\5VK:TN
M`+5,KL2JNKG9IO'#T:=/O5@N`+5,KL2JNK*CJWZ]6"X`M4RNQ*JZLW&P5*CS
MJ7<N`+5,KL2JNJ:LI?.D2#HB)7,B`+5,KL2JNJ3`J,FJJZ7S+@"U3*[$JKJH
MT[>]INVG?2X`M4RNQ*JZN%6PZKU8N.JNQBX`N.JRHP"F7K1?O^^^W`!)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F("BE[*[4*0!)<F%Q("BE[*G4ITHI`$ER
M96QA;F0@*+=2NKC$]2D`K$\`27-L92!O9B!-86X@*+#2KG$I`*2CK$\`I[VS
MH;EPJT(`27-R865L("BE2*;BID,I`,.QM6^JS`"QU\7I`$ET86QY("BX<:1J
MIU$I`$IA;6%I8V$@**3ZME*E6RD`I$"DZP!*87!A;B`HI.FENRD`I.FDY2`H
M25-/+3(P,C(M2E`I`+]!INBN<0!*;W)D86X@**SYI;DI`*1#I.L`I+NDZP"Y
M[[OT`+AMI*0`I:JE:[GON_0`OF&EJKGON_0`OF&E:[GON_0`2V%Z86MH<W1A
M;@"K3Z]DK>R\RR`_`$ME;GEA("BJUJC(*0!+97)B97)O<R"[>\/2O_F[?BX`
MKM:DW[=SI.(`JO?&7ZO8I=\`JO?&7Z]3O'@`JO?&7ZKXJ]<`JO?&7ZNLND$`
MJO?&7[MYJFL`I=BK9:JZI+VV?:KWQE^F^*I!OKFDI"RD=[AGIG.F8J=!JKJJ
M]\9?+@"HX+6C`$MI<FEB871I("BP\JB]I-JTM2D`2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8@**5?P?HI`$MO<F5A+"!297!U8FQI
M8R!O9B`HJV[!^BD`P?JDY2`H155#+4M2*0!+=7=A:70@**SLJ\*O4RD`2WER
M9WEZ<W1A;@"ELK:WK6ZFLR!,1$%0(*JZI.2TJ2RF_:Q/($Q$05`@O-*RU:2C
MK$^EO*9WN,NT3JQ/J%.FL[C\I$HN`*JIK;&P=+AM7WD`NWFHI0!,86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R`HO&2PZBD`I%6E8J3K`+/,JO&D
M0*:XL4N]6,7<I_.I\P"D5:FVI.L`I%>FN*?SMW,Z`*17I$"FN+5NI$HZ("5S
M`*17I$"FN+5NI$HZ("5S(*;;("5S`*17I$"FN+5NI$HZ(++$I$"FN+5NI$H`
M3&%T=FEA("BIU++FNONHR"D`JFNKWP"JJ:VQL'2X;0!,96)A;F]N("B^I*3:
MN>`I`*6JP^0`I:K#Y*KMP%D`I:K#Y*W(`$QE<V]T:&\@*+_@K\&FJRD`I'"I
M\P"D<*GSJ<ZUI:GS`$QI8F5R:6$@*+_@I/&WYZC(*0!,:6)Y86X@07)A8B!*
M86UA:&ER:7EA("BG4:3QJ,@I`$QI96-H=&5N<W1E:6X@**9#I.2TL+2UM6XI
M`+=,JT(`I'"K0@"FK::SI'"K0@"QWZ:SI'"K0@"D<+!]JT(`I'"K0J:SN7``
MI'"SMP"D<+!]L[<`I;2J;[C6`+-SM;(`LW.ULL))J.PZ`,7CI=RNR;-SM;*V
M;*7SINVG?:CLO7.\9[9LI?.MMJVQ`+-SM;(`ID.E6"`M(*C/I<ZJS*5II4BL
MW:CLLV^MTZM(I?.G6`"F0Z58N.JNQJYW`*9#I5B[H:GZO-##1`"F0Z58JNVN
MY@"P4;W7N'.RU2W`R:[7PF0`L%&]U[ASLM4MJ$2G50"P4;W7N'.RU2W#T:=/
MN+F]6`"P4;W7N'.RU2W#T:=/N+F]6`"P4;W7N'.RU2V^UJ:SJLP`L%&]U[AS
MLM4ML4BE\Z1(`+!1O=>X<[+5+:UQOEP`L%&]U[ASLM4MJ/JN^*UQOEP`ID.E
M6+=\M,&EHK'1.B`E<P"F0Z58J,^ESJK,I:*QT3H@)7,`ID.E6*C/I<ZJS*JZ
MI5ROX+-1P_:SK`"DY;['`$QI=&AU86YI82`HI=^SLZE[*0"X_*1*I*0N+BX`
MM^VF8:[)MJ$Z(`"F8;#/NU"NR;:A`*9AL,\`M6ZD2@"U;J58`+5NI$H`M6ZD
M2J1UIT``M6ZD2J6BL=$L(+W0P,NL9+O5I%6JNJ7.I.&F5ZE-L4N]6"P@M4VK
MX:VKN-4N`+5NI$JEHK'1+@"J^*5Y`+=2L:$`IT,`I'"\9Z?&P[Z\QJ9R`*1P
MO&>IU*1"O,:F<@"D<+QGP[FPJ+S&IG(`3'5X96UB;W5R9R`HOV.TR[/Y*0"D
MZP"H0Z3IL%2NIP!-4RU43D5&(*K^I5O`R:[7I*2H4Z:SN.JNQBX`35-'`$UA
M8V%O("B_1*KY*0!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8@*+"HJ.2Y>:9`J4VPZBD`36%D86=A<V-A<B`HL*BY1J5;M+6E
M6RD`Q5VS3@"V;*7S`+9LI?.ZWK)Z`*O8I=^S<[6R7VLN+BX`36%L87=I("BP
MJ*G4J\(I`$UA;&%Y<VEA("BPJ*C3INBHR"D`36%L9&EV97,@*+"HNKBF8:32
M*0!-86QI("BPJ*=1*0!-86QT82`HL*BZN*5,*0"ZWK)ZIT&JNJ3`P_XLJ,.E
M0JRPI,##_K-=J7?#0Z;B+@!-87`R-""F8;G/`$UA<%%U97-T(*9AN<\`O-"[
M>*M(I?.LL*1WIU*PHU]K`*14I.L`P^2LR0"\T+MXJTBE\ZRP.@"\T+!/IJ@@
MK-VY3"^EO*S=N4P`O-"P3Z:HJ.2E3*JZP]&G3R`HJ-*F<"X@K:NM;B^D=Z9>
MPM`I`$UA<G-H86QL($ES;&%N9',@*+"HKDRZN+ASKG$I`$UA<G1I;FEQ=64@
M*+"HM*.EIZ=*KG$I`++%IE@@**5(IONF[++%N+FJ[:7<*0"DQ[!TQ.:F[*2D
M`$UA=7)I=&%N:6$@**U4IU&V\*6GJ,@I`$UA=7)I=&EU<R`HO*^HO:;HM+4I
M`*2YLURJNK/,I&K"2;S&+@"J_J7SO,:EV*1WME>E6*2YLURD5ZVM+@"SS*KQ
M(#(T(*1PKLFJNK/,L*JWQ:O7.B``L\RJ\2`V(*1PKLFJNK/,L*JWQ:O7.B``
ML,^V]*17K:V\QJ78`+-7JVB\QJ78I%>MK0"DN;-<L\RD:JKXJ]<`ML*F5[/F
MO,:EV*1WN4:D5ZVM**1WI<XZ("5S+""D5ZVM.B`E<RDN(+5,JFNW<[Q7IF&G
M?:CLML*F5[/F+@"DS;6]IE>SYKS&I=BD=[E&I%>MK2BD=Z7..B`E<RP@I%>M
MK3H@)7,I+B"U3*IKMW.\5Z9AIWVH[*3-M;VF5[/F+@"DK:3K`$UA>6]T=&4@
M*+"HK/FO4ZYQ*0#"Y;['`*:HK?L`O^^SYKS2IJ$Z`*98J-;`>*9SKN8`MFRE
M\P"V;*7SQ>?#TJ1WI[FFJ"RF_:Q/J,^ESJK,JKK#L;.YJV^U3*IKLW&Y3,7G
MP](N`,*RL%2D=[E,M,$N`,*RL%2KK+I!`$UE=&%R(+#/MO2U3*IKJ,^ESBX`
M365T87(@L,^V]+5,JFNHSZ7.+B"RT[A@O="PT:;2J'2RSKK>LGJU;K_]+@!-
M971A<D1"(*E\I;RS<[&U+@"DZ*IK`*3HJFL@(B5S(B"EO+-1J7>X<0"DZ*IK
MI;RI=[AQ+B"E2*E)I7.DZ*IK.B`E<P"DO:CN`$UE>&EC;R`HOJ6FZ*WT*0!-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F("BQ2Z=*P[FEIZ;HJ,@I
M`*2DMJ$`36EM92"KK+I!`+/,JO$@,C0@I'"NR:JZL\RG0[?%J]<Z(`"SS*KQ
M(#8@I'"NR:JZL\RPJK?%J]<Z(`"SS+5UL4N]6*[$M,&I?*6\J.RTP0"L3:YG
M`,+XMK4`I^2DHZCL(%!%05(@I5VXRR!(5%107U)E<75E<W0N`*_*I-:V;*7S
MLW&JOJ9AIWT`K\JDUL+@IWV[O+!EJ=*[W:UNJKJK2*7SIF&G?0"S7:EWP,F_
M\J6B+B"F<*I'K6ZHSZ7.LV^MT\"SI<ZU>Z:AIT&ELK:WLGNF8K1.LJ.ES:5,
M+@"GY*2CJ.S"LK!4JKH@240N`*_*I-:P:*9>JTBE\ZG2N]VM;JJZLGJET0"O
MRJ36L+*TP;-QJKZITKO=K6ZJNK)ZI=$`I^2DHZCLI;*VMZJZ(%!%05(@I5VX
MRR!-86EL+@"GY*2CJ.RW?+3!JKH@240N`*Q0M,&D0`"FYK#*MFRE\P"WQ:E-
M`*?SMW.DZ;3!`*W7I^^Z]*=]`+S2LM4`36]L9&]V82P@4F5P=6)L:6,@;V8@
M*+RONKBF:*7+*0!-;VYA8V\@*+ROK\>M]"D`36]N9V]L:6$@*+M8I6HI`*3K
MI,ZF?@"H0Z3K`+M8MNNIU*]3`*3KK-L`IF*RQ"5DIN:GY*CLJKK$YJ;LO,:E
MV*1WME>E6+EWM,$E9"X`O*^LI:WT`*9HMK.NR;2X`*9HMK.NR;.Q`+2XKLFF
M:+:S`+=HLKX`I%6RO@"EJK*^`*5KLKX`I%6ROBBIM:OAKDVESBD`I%>ROBC`
M=:7]KDVESBD`I%>RO@"D5;*^`*17LKX`36]Z86UB:7%U92`HLO:D5*3QITHI
M`+W&O^^FH:15J=2E7*_@JNT`O<:_[P"GVJJZL6*XN0"GVJJZL6*XN;CJL%0`
MK=.D2*^XI7@`K=.D2*^XI7BMMJVQL'2X;0!->6%N;6%R("B]<:AL*0"DHRRG
MVJ2CIE"W3@"PLK3!IE["T+6EJ]VDT;S&.E]U`*97NMD`3F%M:6)I82`HJ+JF
MS*3QJ,@I`$YA=7)U("B_U;Y\*0!.97!A;"`HI:>J>;JX*0!.971H97)L86YD
M<R`HLOS$]2D`3F5T:&5R;&%N9',@06YT:6QL97,@*++\Q-VF=Z9AID.TM2D`
M3F5T<V-A<&4@K+"P\L*FJKJZ]*=]`$YE='-C87!E(+[,P]*G0+QONO2G?0!.
M971S8V%P92"^S,/2K$:UIKKTIWT`3F5T<V-A<&4@I_.W<[KTIWT`3F5T<V-A
M<&4@IT"\;[KTIWT`3F5T<V-A<&4@4U-,(*;XJD&^N:97NMD`3F5T<V-A<&4@
MOLS#TJJZM?FXT0!.971S8V%P92"^S,/2JZRZ00"Z]+CTI'6HXP"Q<:6\`$YE
M=R!#86QE9&]N:6$@*+=SL]BHO:9HI:>HR"D`MW.\5Z3`P_X`O&>K2+6Y("5S
M`+=SI.L`MW.\5[-7JV@`MW.HSZ7.JLRF5[K9("BK1*6RK6XI`$YE=R!:96%L
M86YD("BOPZ;HQ/4I`+=SL4N]6`"W<[%+O5BQ3JGS)7BH[+3!+@"W<[%+O5BD
MH[+%IE@N`+=SM?BUH2`H7V)L86YK*0"W<[M$`+=SNT2X<[+5`*15I$"H0@"D
M5:1`K=._[[:U`*15I$"MM@!.:6-A<F%G=6$@**6GI5NIU*7**0!.:6=E<B`H
MI:>DZ2D`3FEG97)I82`HJ6"DSJ=1J,@I`+'?I%<`3FEU92`HK\.N2JYQ*0"G
M7P"F8J;XJD&ZW:JZLUVI=[CJKL:DI*?DI*.H[,/VJ?,@(B5S(B"JNJ2XI?,N
M`+5,I6FHT<7CI=RN=+*GJKJS7:EWN.JNQBX`M4RE::7.JKJUIK*DJ]BS>2!)
M4T\@O':YLRX`IKFE1+[WJKJF^*I!NMVEO+-=J7<`J7REO*9B(&)A8VME;F1S
M+G!H<""DI+-=J7>F^*I!NMVXZK!4`*A3IK.GY::XO,NFH2X`J=*K_*EWJKJF
M[+AMI%>H4Z:SL,^V]*9SIF(`J%.FL[2CJ-&FYJC&ON2F5[K9I4BHT2!-0T%,
M(,7GP](N`*A3IK/%W*?S+@"U3*IKIF*EV*MEQ7:MK:2DO%>E6Z:XQ7:MK2X`
MJ%.FLZO\J7>JNB`E<R"S7:EWN.JP5"X`J%.FLZO\J7>JNB!&5%`@5D93(+-=
MJ7>XZK!4+@"H4Z:SJ_RI=ZJZ(%-13"!61E.S7:EWN.JP5"X`J%.FLZO\J7>J
MNB!344PM1FEL92!61E.S7:EWN.JP5"X`M4RST;YLPDF\QBX`I;RTHZC1I=BJ
MNBX`P,FNUZ6\I%>VQP"U3+-7JV@N(,))O^\@(B5S(B"KV*7?MW.JNKE,PF^S
M5ZMH`*6\J_RI=ZKMP%D`I^2DHZCLN<^EW"X`INRX;;CJL%2I?*6\LUVI=P"I
M?*6\M*.HT:;LN&VXZK!4+@"EO+2CJ-'"LK!4+@"EO*O\J7>F5[K9+@"EO*O\
MJ7>XN;U8+@"H4Z:SJ_RI=[%+O5BE2*C1($A45%`@Q>?#TBX`J%.FLZO\J7>Q
M2[U8I4BHT2!)34%0(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@2V5R8F5R;W,@
MQ>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!,;V=I;B#%Y\/2+@"H4Z:SJ_RI=[%+
MO5BE2*C1(%!!4U-71"#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1(%--0B#%Y\/2
M+@"EO+_II$H@3W!E;E-33""D1Z2XL/6FYL#)JKJE_KCTKGPN(%!+0U,@,3(@
MLU>NYJJZI5NQ2[CJKL:[W:UNI<ZH[+C3M7NFH2X`J%.FLZO=O&:JNK7YI56E
MT[W0+@"ZS[K0L'3#0J6\LUVI=P"U3*[FO74`N4S";[5[IJ&EO+*CI<TN`*E\
MI;RK_*EWQ.:F[*3`N6JF<J2X+@"U3*[8O74`I;RK_*EWIG*FZ@"U3*:YP,FN
MUP"U3+S(IG.EV+_]I6FHT:?6J/HN`*6\ML>P9:C/I<ZJS*97NMFISK%+O5@N
M`+5,I6FESJJZ(%A-3""XZJ[&LU&VQZ9>`*K%I=6MR`"M[*ELLUVI=\#)I*2G
MY*2CJ.RJJ:6[N.JP5"X@K:NW<[*CI<VS7:EWP,DN`*9BIT&JNK-=J7?`R:2D
MI^2DHZCLJJFEN[CJL%0N(*VKMW.RHZ7-LUVI=\#)+@"U3`"U3"`H=7-E(&EM
M<&QI8VET*0"DZ:;5L-*DY2`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD
M("B_U;K6ITJN<2D`I5^E8K)Y`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.
M;W)W87D@**Z_J\(I`*M$I*>KX0"K1*2GJV4`I*.L3Z1`K=.EV+_]`*2CM:6I
M\P"U>Z:AJ7REO*>YIJ@N`*2CLUVI=P"EO+-1I.2TJ0"SQJ?1O_T`J%.FLZ5I
MPG/$_:JZ+*9>I6@N`+-QJKX`I%&D0*3K`+S&IG(`IG*DN+S&`*9RI+B\9:O7
M`*;FO,8`I_.W<[!TN&VX<[+5KLFEO*O\J7>\QJ78+@!/2P"JJZ7S`*JKI?.K
MV*7?JLP`I$NV::;L`*11I.L`O^RDO:O'`+=SL4N]6*6RMK>[4,+"L4N]6*2C
MIE`N`,+"L4N]6`#"PK%+O5BDHZ6_O50`3VUA;B`HJORPTBD`I76FLR!)34%0
M(*;XJD&^N:3DM*FK2*7SIUBDP*C)I5ROX"X`MLB\T+!/MFRE\P"E=:2YLURD
M0*W3MFRE\Z;MIWTN`*5UIK.^UJ:SJLR[4*ATLLZZWK)ZK?NE::5(Q=RG\Z9`
MJ,G%=JVM`*9BMW.JNK7XM:&V?;'2`$]P96Y34TP@O_F[?CH@M4RJ:[%Q(%,O
M34E-12##L;.YJOZE\[C1MGVXZJ[&+@"F8K=SJKJU^+6AMGVQTK-SM;(`IT"W
M?JATLLX`O^^VM0##]JGSN4S";[5[IJ&G\[=SJKJ_[[:U+@`E<[_OMK4`MK6E
MV+USN+D`LM7"M`"RU<*TL^:F[`"RU<*T`*WLJ6S`LZ7.M7NFH;S+JD\`IF(@
M)7,Z(*2DJKJM[*ELO,NJ3RX`J.2E3`"HY*5,N.JP5`"HY*5,O^^VM0"WI\9;
M`+[6IK.JS,5VK:T`4$%-(,7GP]*U3*[$+@!014%2.CJV;*7SIOBJ0;K=`%!'
M4""\QJ;LP[&SN0!01U`@I5NQ2[CJKL8`4$=0(*2]MGVJ]\9?`%!'4""D=\.Q
ML[DOI'>E6[%+(+CJKL8`4$A0(+5[IJ&]6`!02%`@K_.]6@"DR*OAI'"K0@"D
MR*OAL'VK0@"DR*OAIK.SMP"DR*OAL'VSMP"DR*OAM+@`I,BKX;EPJT(`4$]3
M25@@97AT96YS:6]N(+_RI:(`4$A0(*_SO5I?2`"YU*52`%!A:VES=&%N("BD
MVK#RM+6I6BD`4&%L874@**FMKULI`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960@**3:L,>TM:E:ION[XK#/*0!086YA;6$@**3:KK.PJ"D`4&%P
M=6$@3F5W($=U:6YE82`HI-JEK*C(MW.T6*2ZJ,@I`%!A<F%G=6%Y("BDVJG4
MIF,I`*9HMK,`L4N]6`"Q2[U8Q=RG\Z>YIJ@N`+%+O5BDHZ6_O50`J%.FLZO\
MJ7>Q2[U8I4BHT2!2041)55,@Q>?#TBX`L4N]6+U4NWL`L4N]6#H`L4N]6#H@
M`+%+O5BELK:WIVNF6"X`MDND5P"V2Z17`+CTKGP`J]V\9K5NO_VA1P"FJ*W[
M`*;*I,"D\0"P]:;FNOO%0+[>IT``M6ZD2JOAL/6FYKK[Q4"^WJ=`/P#%=JVM
M`"(E<R*JNL5VK:VEO+-1IU*PHRX`IG.H^KY$J=H`Q7:MK0#%=JVMNMZR>@"G
MVJJZ`%!E<G4@**^UOGPI`,-DJJL`4&AI;&EP<&EN97,@*+7AJ]^[JRD`N7&X
MW`##P+19`%!I=&-A:7)N`+FSK\``O="V::1*P'BF<Z[FPDF_[P"]T+U4J7>M
M;K*^L*.FN:2XI?,Z`+W0O52I=Z=!K6ZDI,)?IKFDN*7SJKJS<[6R+@"]T+_I
MI$JD0*W3I.NE]Z3.IGZE]RX`O="_Z:1*MW.\5Z3`P_ZJNJ97NMDZ`+W0O^FD
M2J1`K=.FLZ[$JKH@25`@INRG?0"]T+_II$JD0*W3IK.NQ*JZI.FTP3NDQ+_O
MIKFDZZ7WJKJDZ;3!+@"]T+_II$JD0*W3IK.NQ*JZKLFVH2X`O="_Z:1*MW.K
M2*7SIUBJNJ97NMDZ`+W0M*.HT;#=PT2JNKI+K6XN`+W0O^FD2J=!JKJHSZ7.
MJLRF5[K9I,ZQ2[U8`+W0OES%JJ15ID.DNJYE+J=!I;*VMZ90MTZS;ZC'J,:V
MM:1^K^"HSZ7.J'2RSBX`O="_Z:1*MW.JNJ3`P_ZF5[K9.@!0;VQA;F0@**II
MQ/4I`*Q&JG8`I^NRO`!0;W)T=6=A;"`HN+*UY:3Z*0"\=KFSINRX;0"J[:[F
MINRX;0"[O+!EMFRE\ZCLLV^MTZM(I?.G6"`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I`+/,JO$@)7,@I'"NR:JZK;"K0K9Q.B``K;"K0CQB<B`O/K[WLG8`4')E
M9G-?;&1A<#H@I^2DHZCLJ=*[W:UNJKH@3$1!4""IM:;YKDVE\RX`4')E9G-?
M<V5S<VEO;CH@I^2DHZCLJ=*[W:UNJKH@<V5S<VEO;B"IM:;YKDVE\RX`KO#`
MHP"N_*6MK;&N\,"C.B``KO#`HSH@`+EWQ/T`IF*W<ZJZM?BUH;EWQ/V\=KFS
M`*17I$"MT[_OMK4`ID.F3*3EI?,`J'"Q2ZKWQE\`L-W#1`"PW<-$M'FM>@"Q
M3:[7`+2CI=RDNJYE`*2]MGVJ]\9?`*2]MGVJ]\9?NG2ZX@"DO;9]JO?&7[CJ
ML%0`I+VV?2^H<+%+JO?&7[GOJ,.EO+-1LJ.ES2X`4'5E<G1O(%)I8V\@**II
MIFB^I*95*0!1871A<B`HI62Y1BD`K&2XWP"ZS[K0L'2X;0!24T$@I+VV?:KW
MQE\@*"5D(*;LI+@I`*WLIEU?90"_[[[<MG,`JT(`IJVFLZM"`+'?IK.K0@"P
M?:M"`*M"IK.SMP"K0L+@L[<`P$B^]Z1PNWD`I/&R=@#%JJCZ`,6JJ/JV;*7S
M`*]UJKJM;J=2L*,@)7,@MMP_(+-OMK6^WJ=`L4ZU3*IKJ^RT7RX`KW6JNJUN
MLDVPHZC/I<ZJS"`E<R"JNKCJKL:VW"`_(+-OMK6^WJ=`L4ZU3*IKJ^RT7RX`
MJNW`6:2DJKH@4F5C96EV960@Q.:F[`#"X*=]N[RP9:CL`*CZKOBT7ZWL`*VK
MMW.^X[)Z`*VKMW.^X[)ZL,JZ0:78O_VDN*7S.@"MJ[=SON.R>JW3I$BON*5X
MI+JN93H`L6"S5ZKMI=RFH0"EO[-7L6"FH0"E2*:YK>RF7;!HJT@`P_;!<,)S
MQ/V^N0"MJ\6J`+7[O=<`N[>ZW:;XJD&^N0"[M[K=NO2G?2`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ`+*^L*,`LKZPH[#/MO0`LKZPH\3FINP`
MI6BPHZ[FIJ$`LKZPH[GO`*;;IOBJ0;ZYO,BF<Z78O_VDI+*^L*.D=\!XIG.J
MNK-=J7>U>Z:A+@"ROK"C`*;;I.6E\Z2DLKZPHZ:YI$"X8,))`+*^L*.HSZ7.
MJLP`LKZPHZC/I<ZJS#H@)7,`N]VH1*6\LU&F7L"S.B"_^;M^N+F]6#H`I^2D
MHZCLJ=*[W:JZJD&PR"X`)3(D<R"JNK-=J7>ELK:WJ_RI=R`B)3$D<R(`5D93
M(*JZLUVI=Z6RMK>K_*EW("(E<R(`LUVI=[CJKL:ELK:WJ_RI=R`B)7,B`*6R
MMK?$YJ;L`*VKMW.Q2+!EJ.P`K:NW<[%(L&4M+:;;`*VKLUT`K:NS7;%+O5@`
MK:NS7:=!JKJQ2[U8.@"F7J9SL\RKX:1`K=.L9+C?`+6RJD<`IEZH[+-7JVBJ
M[:9#`*KPIEZ_[[:U`*9>J.RS5ZMHJNVF0P"F0::XO^FD2K=SL4N]6`!2975N
M:6]N("BO9*6GJ?2N<2D`IEZT7[-=J7<`NO2MMKUSO^B^N;_OMK4`P;R[>0"E
M:\/D`*5KP^2J[<!9`*5KP^2MR`"F0Z2ZKF5?=RXN+@"HI*;B`%)O;6%N:6$@
M*,.YL*BEIZC(*0"QV\+@(#$X,""KUP"P9J[)L'<@.3`@J]>QV\+@`+:VKLFP
M=R`Y,""KU[';PN``ID.DNJYE`*9#I+JN90"F0P"S5ZMH`+-7JVBD=[W&NW,`
MLU>K:*1WIU*PHP"S5ZMHI'>PL:7.`+-7JVBD=['2I<X`LU>K:*97NMD`KN:]
M=0#$YJ;LNU"F0Z[FO74`Q.:F[*[FO74`ID.NYKUU`+#UIN8`4G5S<VEA;B!&
M961E<F%T:6]N("BK6,.YM+4I`%)W86YD82`HOV.F=[E&*0!3+TU)344@I5NQ
M2\.QL[D`MFRE\Z1WJ,^ESB!3+TU)344@I5NQ2P!305-,(,7GP]*U3*[$+@#"
MLK!4`+CJKL:N=Z_SO5H`I5NQ2[+7NMV^]P!35$%25%1,4R"EHK'1.B`H)7,I
M("5S`*:HI5P`N.JNQJYWK_.]6E]1`*Q0M,&DNP!386EN="!(96QE;F$@*+AT
MNZZPQZ_'*0!386EN="!+:71T<R!A;F0@3F5V:7,@*+ATITJHO;2UIFBZUJ3.
MI:>Z^[2U*0!386EN="!,=6-I82`HN'3%4Z;HJ,@I`%-A:6YT(%!I97)R92!A
M;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,@
M*+ATI.6TRZ3.KN:WYZBZI$(I`*90I$"MT[7XM:$@*%]S96QF*0!386UO82`H
MPL2\KZC(N'.N<2D`4V%N($UA<FEN;R`HN'2PJ*=1O]4I`%-A;R!4;VUE(&%N
M9"!0<FEN8VEP92`HN'2F:*S\I,ZTMJI,INBD\2D`O<.L4+2CJ-&JS`!3875D
M:2!!<F%B:6$@**A&KU&F8:K\J=2G0BD`P'BF<P#`>*9S("(E<R(`P'BF<R`E
M<P#`>*9SO^^VM0#`>*9SLUVI=P"Q3K*CI<VJNK-=J7?`R:5((%!(4""[>:BE
MKN:FH<!XIG.H[*=!JKJF^*I!OKF\R*9SI=B__:2D+@"S7:EW("5S(*1WP'BF
M<RX`I_.W<[5[IJ&D=\!XIG.H[#H@(B5S(BX`N7.L4+EPJT(`K.R^QP"Y3,)O
MM7NFH0"Y3,)OM7NFH:?SMW,`N4S";[5[IJ&EO+-1I_.W<P"Y3,)OM7NFH:1W
MI[FFJ+'2I<XN`+E,PF^U>Z:AI'>PL:7.+@"W:K1-`+=JM$VDWL"Z`*S=N4P`
MO^^^W,#)KM<`O^^^W*1`K=.DZ;3!`+_OOMRD0*W3Q.:F[`"_[[[<I$"MT[AS
MLM6ESJ5(MW.\5P"_[[[<I$"F[+=SJKJ^UJ:SJLP`O^^^W*1`LZ&F^*I!OKD`
MO^^^W*1`INRHSZ7.JLRESJ5(MW.\5P"_[[[<J=*FLP"_[[[<J=*FLZ3IM,&D
MN*7S+@"_[[[<I$"MTZJKI?,`I*._[[[<`+_OOMREV+S0JTBE\Z=8`*GSI4BD
M5:JZM?BUH:2DO^^H^J=!K6ZJNJ9RI+@NI4BWQKFKO<:[<ZG2O^^DY:9R++5-
MJ^&V2Z17I.6E\[USO^BPSRX`O^^^W*3IM,&DP+EJ.@"_[[[<I.FTP:3IM,&N
MYJ:A.@"_[[[<L?W%W*?SJKJHK:7WP]&G3SH`O^^^W*[)MJ&DP+EJ.@"_[[[<
MI.FTP:[)MJ&NYJ:A.@"_[[[<K-NDK*3'L'2JNJ1'K=/$YJ;L+@"_[[[<IT&J
MNL-#IN*P=+AM`+_OOMRPOJ9NNWFHI3H`IMNM<:KMP%D`ML>P9;#=PT2DS\"S
M`+;'L&7"LK!4`*KMP%FDI*JZ(%-E;F1E<B#$YJ;L`%-E;F5G86P@*+;KI+JE
M6[JX*0"W4+3ZOKDZ(`"D1:3K`%-E<F)I82!A;F0@36]N=&5N96=R;R`HMNNZ
MN+K[J,B[4+M8KU.EIZWTP[DI`*?'N+D`IOBJ0;ZYN.JNQK_YNWZISJK,M4RJ
M:ZC/I<XN`+=\M,&ZWK)Z`+=\M,$@240@I'>Y3+3!+@"W?+3!`*[6J/JDZ+;T
M`*2YLURG0:GSI]&P3[%+O5BJNJ[)K=0LI6FE2*;;IN:MJ[-=L4N]6"X`LUVI
M=[NWNMVF^*I!OKFD5\3=J?.G0:JZK=.D2*^XI7@N`+-=J7>G0:JZL+ZF;KMY
MJ*4L(*[)L,^E2*3.I.FTP:[FIJ$N`+-=J7>G0:JZL=*I;,"SI<ZU>Z:A+,-#
MIN*P=+AM+*VVK;&G\[=SP%>R=BRDSJCDI4S%XZ7<O^^VM2X`LUVI=Z1WI_.W
M<Z>YIJ@N`+-=J7<`I_.W<[5[IJ&T3KK\`*:SIFZT6*W3IF'"2:E-LV^MT[#1
MO,:FL\/V.B``4V5Y8VAE;&QE<R`HMNNI];JX*0#!RJJK`,*RM76Z2ZUN`*Q/
MIU^LL*1JLZ&E]ZJZLW.ULJEWN'&GUK&VI5ROX,'D/P#%XZ7<`,7CI=REOZ9B
ML/6FYJ2DN4S";[5[IJ$`Q>.EW+USO^BDI*JZN4S";[5[IJ$`Q>.EW+=SLJ.E
MS;M0K>S`>*9SLUVI=\#)JKJN=+*G+@"H0Z:XM6ZD2JOAQ>.EW*17I$"FN*JZ
MM6ZD2J[)MJ$@/P#%XZ7<PDF_[[ZY`,7CI=RJ[:[FOMZG0*5<K^"J[2`_`*GS
MI:K#Y,7CI=P@)7,@I5ROX*KM/P#%XZ7<P'BF<Z[FI+JN9;GON-RDZ+;T`,7C
MI=RJ[:[FI+JN9;GON-RDZ+;T`,7CI=RF0Z2ZKF6Y[[C<I.BV]`#%XZ7<O':Y
MLZ2ZKF6Y[[C<I.BV]`#%XZ7<I%>VQP"K^<3RL'VK0@"FK::SL'VK0@"QWZ:S
ML'VK0@"[MZ3HIK.P?:M"`*:LP5D`4VEE<G)A($QE;VYE("BWX*1LI'.PZBD`
MM?FE50##L;.Y`,.QL[FZ=+KB`%-I;F=A<&]R92`HMW.E6ZE9*0"D:J1P`+*D
MN4RZ^\5``%-L;W9A:VEA("BTM:REI>^G2BD`4VQO=F5N:6$@*+2UK*6E[Z6G
MJ,@I`+.W`+!]L[<`L'VSMP"FK::SL'VSMP"QWZ:SL'VSMP"_;K.WLF"KUSH@
M`%-O;&]M;VX@27-L86YD<R`HK\'#N:KYN'.N<2D`4V]M86QI82`HK\&PJ*=1
MJ,@I`+IQNU"XU@"QQJ9#I.BF5K_OOMP`J-.WO:9AIWT`4V]U=&@@069R:6-A
M("BK;JM$*0"K;KS:("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P"K;J5BLGD`JL6EU:;F`+:AMEH`
MMJ&V6KM0N=2E4@!3<&%I;B`HINBO6J3Z*0"I5:>CMFRE\P"O4Z[MIG*DN+_I
MI$H`I,"SSL!XIG,`I,"SSL3FINP`I,"SSJ9#`+E"L,H`4W)I($QA;FMA("BT
MM:B]Q/6E9"D`O-"WQP"L4+O:JJ?%4;[4`+'2J6RF?J7W`*S9`*JLND$`JTBE
M\Z1`I;FRQ:98LV^Q^+-7JVBT3K"QI.[$?L3RP,NL9*CDOFRJNK-7JV@`P'BF
M<Z[FIJ$`M?.Y1`"G4K"CO74`IG*FZJ9#`*;;MFRE\Z9AIWVDI*5HL*.Z]+#L
MIE>ZV0"\RZ:A(%M#4U-=`*Q0M,&DT0"GY*2CJ.RFN*78O_T@(B5S(@"PLK3!
MKV2HI:JZI42FKCI?8P"E1*:N`+!EI5@`O%>E6R`B)7,B(*CLJ'2RSJJZI=.]
MT*1WL&6E6"X@IT&ELK:WM:6H[+C3I=.]T+-1KM:MXZOAI'ZOX+5NI$HN`*15
MO-``IJBE7`"FJ*5<JKJE6Z1*("(E<R(@J.RH=++.I*0N`*:HI5RJNJ;;J'2R
MSJ2DLDVPHZC/I<ZJS"`B)7,B(*JZN.JNQBX`(B5S(J1WIU*PHZ>YIJ@N`*:H
MI5RJNJ;;J'2RSJ2DLKZPHR`B)7,B+@"D=Z:HI5RJNJ9>M%^S7:EW+B"]T*VK
MMW.X_*1*P,NU^*YTLJ<N`*1WIJBE7*JZL\:E][-=J7>XZJ[&+@"D=Z:HI5RJ
MNK/&I?>S7:EWN.JNQB`E<RX`IJBE7*JZI_.W<R`B)7,B`*1WIJBE7*JZPM"\
M9R`E<P!3=61A;B`HQ*RDIBD`NDNM;@"DZ:58`*3IN*@`M+@`I.FE6`"DZ:58
M+Z3IN*@`I.FE6#H@`*3IN*@`I.FXJ#H@`*17O-``I.2TJ0!3=7)I;F%M92`H
MQ*RG4:MN*0"Z[[BY`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD
M("BE=J7+P-G$]2D`4W=E9&5N("BWYZCE*0!3=VET>F5R;&%N9"`HM^>D:"D`
MIE"H0K!/O_VD=Z=2L*,`IE"H0J;FL,JXR[AM`+=JM$VVM:78I*2JNKMYJFN_
M^;M^`%-Y<FEA;B!!<F%B(%)E<'5B;&EC("BQU*=1J,@I`+EPJT(`N7"K0J:S
MK;<`N7"K0@"FK::SJ_G$\KEPJT(`5$%"(*3`N6JNYJ:AP,FNUP"J[;/F`*KM
MKN:DNJYE`*KMKN:DNJYE`*5XQE<`I7C&5P!486II:VES=&%N("BV\*9.M+6I
M6BD`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B`HJ5JI?*6GJ,@I`*78
MO-`Z`*O=O^RHQK:U`+EQN-RXN;U8`+/,JO&D0*1PKLFJNK?%J]<Z(`"WQ:O7
M`+?%J]<Z(`"WQ:O7/&)R("\^*"5SL*HE<R\E<Z=#)7,I("9D96<[)7,`I^2D
MHZCLO,NJ3R`B)7,B+@"\RZI/NMZR>@"DNJYE`*_"I.6F<@"Y[[OTI.6F<@"Y
M[[OTI.6F<K.[NMT`K%"TP:5\`*[UI.4@*%1)4RTV,C`I`%1H86EL86YD("BN
M];#J*0!&5%`@J;6F^2AE>'1E;G-I;VXIM4RNQ"X`2&]R9&4O2V]L86(@ON.F
M6*1UM7NHPZ6\I.2TJ2`B)7,B`$E-4U`@K/:__;5,JFNS4:KLJ6PN`$UA:6YT
M96YA;F-E(,/^IT^HPZ6\IJBE7+C\I$H`O^^VM;7XM:&E2,/VLZPNPO>V?:2D
M+@"Y<:1LMFRE\Z;MIWT@(B5S(B"D=Z5;I$JH[+;"IE>SYJ2D+@"Y<:1LMFRE
M\Z;MIWT@(B5S(B"D=Z5;I$JH[*3-M;VF5[/FI*0N`*=!JKJH=++.NMZR>JW[
MI;*VMZ7]LUVI=Z9NI$"MT\5VK:VKX;K=I'ZOX,7]IT&HSZ7.Q7:MK:ATLLXN
M`*FSKMB]=0#!<+6XN+F]6*6\J_RI=RRJQ:75J<ZF8KCJKL:N=Z2DI^2DHZCL
M+@"D=Z:HI5RJNK%.P7"UN*1(MW.\5Z;<LW&P5+_]I*0N`,7GP]*V;*7SP[&S
MN;O=K6ZFLZ1`K=.D=[C1MGVJNB!01U`@L,^V]"X`L'2X;;ASLM6JNL/1IT^X
MN;U8*$E$*:2CK$^EO*O\J7<LM$ZL3ZK%I=6ISJK,I*.F8KCJKL:N=Z2D+@"P
M=+AMN'.RU:6\J_RI=RX`Q5BPRK5[IJ&F7L"S.B`E<P"[W:UNI$"MT[AGN4RE
M6[%+JKJZ]+CTLW.ULBX`P,FNUR`E<R#`L[C3I5VG=*1`K=,@)7,@LUVI=RX`
MP,FNUR`E<R#`L[C3I5VG=*1`J,<@)7,@LUVI=RX`M4RJ:[W&NW.H[*;;J*W`
MR:[7+@"FN<#)KM>DI*A3IK.XZJ[&+@"E2*15K$\@<F9C.#(R(+9LI?.JNJKM
MP%DN`*BMI??#T:=/("5S(*1WLU&G4K"C+@"EJJ[8O74`1VYU4$<@I$>DN,#)
MJKJX]*Y\I;*VMZEWN'&F8B!#<GEP=%]P9W`Z.B##_J=/I*0N`*=!M+^I\R`E
M<R"Q2+6Y("5S(*1`J\JE1*:NK+`@(B5S(B"JNJM(I?.D=[-1MGVQTBX*IOVS
M;ZC#I*.OX*M/P]*XTZM(I?.JNJ2ZKF6D=Z>YI?ZS4::LI?.D2*S=I[FISJ1&
MN-$N`+-SM;*H[+USO&>V;*7SK;:ML:G2J,^ESJJZIE>ZV0"ELK:WK$^D0*W3
MO,:F<BX`2&]R9&5?0W)Y<'1?<VUI;64Z.B##_J=/+*6RN]VM;J:S(&]P96YS
M<VP@O-*RU2X`IKFPOJ9N("(E<R(@N.JNQJ9=K+"V5[E,L\RD:J2YLURMR"RI
MTJ5(M4RJ:[-1P'BF<P"ESJ5(P,NU^*:YN.JNQL/^JZP@*"5S*2"JNK5[IJ&H
MPZ2CIG.F8JGSJ'2RSJ17+@"DWJUZIG*ELK:WK+"SYJ1`IG*DN"X`I:JE:Z[8
MO74`I6NNV+UU`,3FINRDP+EJIG*ELK:WK+"SYJ1`IG*DN"X`IKFF^*I!OKD@
M(B5S(B"D=[-1IU*PHRX`IKFF^*I!OKD@(B5S(B"D=[-1P'BF<RX`)7,@JKJU
M^:55N]VH1*1WLU&ROK"C+@"K_*EWJKJP3[_]J,.DHZ9SIF(N`+S(IG/`R:[7
M(B5S(J2CIG.F8BX`IT&ITK_II$JJNKCJKL:[4+5EK;&XZJ[&I*.RQ2X`I%>D
M5:[8O74`I%>NV+UU`+%QI%>D0*W3J$+&2J2GJ^&D5[;'JKJXZJ[&O_*EHBX`
MI%>VQ\#)KM>HPZ6\LU'`>*9S+@!W96%T:&5R+F-O;2"PS[;TM4RJ:ZC/I<XN
M`*?DI*.H[+S+IJ&P=+AMI=B__2`B)7,B+@"U3*5II<ZJNK_OMK4N`+5,JOZE
M\Z5IJKVQM;9]L=(N`*:YQ.:F[*2DI5VG=*33IFBJNJ9RO,8NIT&D=[_II$H@
M)7,@K=.F<KS&.Z=!O^FD2JJZIG*\QJ6RMK>D<*GS("5S+@"W<[Q7("(E<R(@
MJ.RH=++..B`E<R"NR;5OI<VD0*W3L-W#1"X`IMNH=++.LDVPHR`B)7,B(*JZ
MN.JNQJ[)M6^ES:1`K=.PW<-$.@"FVZATLLZROK"C("(E<R(@KLFU;Z7-I$"M
MT[#=PT0Z`*?SMW,@(B5S(CH@)7,@KLFU;Z7-I$"MT[#=PT0`I%>VQ\#)KM>N
MR;5OI<VD0*W3L-W#1#H@)7,@I;RS4:17ML<N`*17ML?`R:[7KLFU;Z7-I$"M
MT[#=PT0Z("5S(*1JI'"V5[E,I+FS7+/,I&JMR"`H)60@8GET97,I+@"D5[;'
MP,FNUZ[)M6^ES:1`K=.PW<-$.B"VR+.AI,"JNB`E<R#`R:[7LU&D5[;'+@"Q
MTJ7.N4S";[5[IJ&NR;5OI<VD0*W3O_F[?BX`L+&ESKE,PF^U>Z:AKLFU;Z7-
MI$"MT[_YNWXN`,#+M?BV;*7SKLFU;Z7-I$"MT[_YNWXN`+;7I$JFN;-QL%2_
M_;CJKL:NR;5OI<V_^;M^+@"VUZ1*(&E#86QE;F1A<B"XZJ[&KLFU;Z7-I$"M
MT[_YNWXN`*9BLUVI=ZKML^:DI+5OI<VD1J1`K=._^;M^+J:SI6FOX*=!O_*Z
M?*1&I;*VM[;QO&>JNL3FINPN`+#UIN:S<;!4O_VK_*EWI5ROX*[)M6^ES:1`
MK=._^;M^+B"]T+5YJ^&F0;C5I$"FN"X`I_.W<\%PM;BD2+CJKL:NR;5OI<VD
M1J1`K=._^;M^+B"]T+5YJ^&F0;C5+@"G\[=SL'2X;;ASLM6NR;5OI<VD1J1`
MK=._^;M^+B"]T+5YJ^&F0;C5+@"FN2!)34%0(*;XJD&^N:C#I;RDY+2IJTBE
M\Z=8I,"HR:5<K^`N`+-OIORE1Z2CK$^EO[U4JKH@<F%R(,"CP5G`R:[7+@"S
M;Z;\I4>DHZQ/I;^]5*JZ('II<"#`H\%9P,FNURX`LV^F_*5'I*.L3Z6_O52J
MNJM(I<ZE9+BYO5@N`*:YQ.:F[*Q/I;*[W:UNJKHN`*:YQ.:F[*2ZKF6E=:2Y
MLUR^X[S&O,:F<BX`IKG$YJ;LI+JN9:5UI+FS7+S&IG*DSJM?N+DN`*:YQ.:F
M[*2ZKF6E=:2YLURD2[9IINR\QJW(+@"FN<3FINRDNJYEI;*VMZRPLW*XN:G.
MJL6EU:3`N6JJNKS&IG(`I;*VMZQ/I$"MT[S&IG(N`*:YQ.:F[*2ZKF6ELK:W
MI5VG=*1`LM6D4:2[MFFF[*JZ(%)'0B##0Z;BI4Z]6"RHTJ9P("<C,3(S-&%F
M)RX`LV^MTZKML^:D=[-1LT*R>KE,+@"S;ZQ/("5S+@"S;ZQ/($MO;&%B(+AS
MLM6JNJ1`K=.JJZ7S+B"Q_<#+M?BFN:JKI?.[W:UNK^"DY+2I2V]L86(@N'.R
MU:[FIJ&JNKEQI&RV;*7SLV[%Z2Z]T+#1IM(@)7,@I4BD1KC1LV^HQ[9LI?.S
M;L7I`+-OJ\JV;*7SJ,.K1*5(IT&Z1*7.JKJF<J2XMK"FTZQ/J,^ESB`H)7,I
M(*[1O&>FTZ:H+@"FN;S&K<BSS*36I;*VMZQ/(#$N`*:YIOBJ0;ZYM4RJ:[GO
M('II<""DSB!G>FEP(*[FIJ'`R:[7MFFFYKC1P*/!60"FN:ATLLZEV*MEK$^P
ML:7.JKJJK+I!+@"ELK:WK$^D0*W3O,:F<BX`IKFU^+6AI;*VMZUNI=&_[[:U
MM?BUH2A/<'1I;VXIJ=*I2:5S`+EP`+#=PT2P;,+<`*[)MJ$`KLFVH:O\JVX`
MKLFVH:[FIJ$`KLFPS[_OOMP`5&EM;W(M3&5S=&4`O-##1`"\T,-$("AT;V]L
M=&EP*3H`IJRE\Z1(`*9PJD>M;KW&O^\LO="F8L))O^^WQKFKJKJF4*[)J_8@
M0V]N=')O;,'D**W3I$BY<;BC*2"ISB!#;VUM86YDP>0HQ*NJ1[EQN*,I+@"R
MOJCL.@"DM:31`$A434P@K>RI;,#)`%1O9V\@**9HK?0I`%1O:V5L874`J?JD
MT0!4;VYG82`HJD:E6RD`L[NSH0"SS*17O&BNV*Q;("A?=&]P*0"D9*B]N4:D
MSJ:KJ*FM]`"O=:G.L+``K%"TP:1'`%1U;FES:6$@**SPI:>FZ*C(*0!4=7)K
M97D@**1GIM6HY"D`I&>FU:CDI.4@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A
M;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU("BD9Z7+OGPI`+_I
MI$JG0:JZO^^^W#H@`+6UI7Z]=:O\O,8Z(`"Z]*=]`+KTIWTZ`%5G86YD82`H
MKU&D>KE&*0!5:W)A:6YE("BO4:=*Q/4I`+5,JFNF<ZCZ(%9&4R"EV+_]+@"U
M^:55KLFU3*IKO%>E6\-"I7ZJNJC/I<ZJS+CJL%0N`+5,JFNG[\7<(%9&4R#`
MR:[7("(E<R(@JKK%=JVM+@"U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNL5V
MK:TN`+5,JFO%W*?SK+`@)7,N`+5,JFO`RZQDP,FNUZ1JI'`@(B5S(BX`M4RJ
M:\#+K&3`R:[7I&JD<"`B)7,O)7,B+@"U3*IKLW.ULB!344P@IOBJ0;ZY+@"U
M3*IKJ,^ESB!34TP@LW.ULBX`M4RJ:[W&NW,@5D93(,#)KM<N`+5,JFNKV*7?
M(%9&4R"EV+_]("(E<R(N`+5,JFNKV*7?(%9&4R"EV+_]+@"U3*IKJ]BEWR!6
M1E,@P,FNURX`M4RJ:ZO8I=\@5D93(*78O_T@(B5S(BX`M4RJ:ZO8I=^JQ:75
MJKH@5D93(,#)KM<N`+5,JFNQ3KCJKL:XT<"CP5DN`+5,JFNG4K"C("(E<R(L
MIKFEV+_]J,.K1*K%I=4N`+5,JFNG4K"C("(E<R(Z("5S`+5,JFNG4K"C("5S
M+*:YI=B__:C#JT2JQ:75`+5,JFN[O+!JIU*PHZ78O_TN`+5,JFNG4K"C(%9&
M4R"EV+_]+@"U3*IKIU*PHR!61E,@I=B__3H@)7,N`+5,JFNG4K"C(%9&4R#`
MR:[7("(E<R(N`+5,JFNG4K"C(%9&4R#`R:[7+@"U3*IKIU*PHR!61E,@I=B_
M_2`B)7,B+@"U3*IKN[RP:J=2L*,@5D93.B`E<RX`M4RJ:Z=0PE^EV*MEJKJE
MV+_]+@"U3*IKN-&V?;[,P]*RT[A@`+5,JFNX_*1*("5S(*JZJ7>X<2X`M4RJ
M:[=HLKX@5D93(,#)KM<N`+5,JFNV?;'2(%9&4R#`R:[7("(E<R(N`+5,JFN\
M9Z1*(%9&4R#`R:[7+@"U3*IKMGVQTB!61E,@P,FNURX`M4RJ:[9]L=+`H\%9
MP,DN`+5,JFO%JJCZ(%9&4R#`R:[7("AF:6QE<VEZ92@I(&9A:6QE9"DN`+5,
MJFO%JJCZ(%9&4R#`R:[7("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`+5,JFO%
MJJCZP,FNUSH@`+5,JFO%JJCZ('9F<W)O;W0@I=B__2X`M4RJ:Z?SIE<@)7,@
MK+`@)7,Z(*9=K+"EV+S0JTBE\Z=8I'>F<Z9B`+5,JFO%W*?S(%9&4R"EV+_]
MJKJF5[K9+@"U3*IKLKZPHR!61E,@I=B__3H@)7,N`+5,JFO%W*?S(%9&4R#`
MR:[7("(E<R(@JKJF5[K9+@"U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNJ97
MNMDN`+5,JFO%W*?S(%9&4R#`R:[7JKJF5[K9+@"U3*IKL/6FYB`G;6MI<V]F
M<R<N`+5,JFO"X+2K(%=O<F0@I.6E\P"U3*IKO&>D2B!61E,@(B5S(B#`R:[7
M+@"U3*IKO&>D2B!61E,@P,FNUR`H8V]P>2@I(&9A:6QE9"DN`+5,JFN\9Z1*
M(%9&4R#`R:[7N.JNQBX`M4RJ:[QGI$H@5D93(,#)KM<L(+K/NM"P=,-"I'>Z
MH2X`J;.]=0"H^J[XI_.G[P"T7ZWL`*;XJD&^N;-SM;*NR;5OI<VEO+EWM,&J
MNJ9>P+,Z(`"U;Z7-I;RY=[3!JKJF7L"S+*71IOBJ0;ZY.B``I;RDP,/^`+A5
ML.J]6"`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S("BJ_*G4IT+!<*98
MI&JDO;#J*0!5;FET960@2VEN9V1O;2`HK5ZPZBD`56YI=&5D(%-T871E<R`H
MK/RPZBD`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`+/F
MINP`I;RJOJJZ`*6\JKZJNB!!4$D@L%2NI[USN+D@*$%022!-97-S86=E($E$
M*2X`I;RJOJJZJ\BDX;!4KJ>]<[BY("A!4$D@365S<V%G92!)1"DN`*6\JKZJ
MNJ;LN&VXZK!4+@"EO*J^JKJHSZ7.JLRF5[K9J<ZQ2[U8+@"DI,)?I=BK9:2X
MI?.JNK-SM;(`I;RI4J97`*9=IG>E_L55O'NDHZ2YLUREO+'"Q7:JNK5[IJ&P
M]:;FL,6D52^]QKMS+[9+I%<N(,))O^^]5*EWI4C`R[7X(&UO>FEL;&$N;W)G
M(*G2M*.HT:JZK-O#]J?>LTZDY:7S+,7]IT&E::5(N-&PHZ:YI$"MK:CNJ,.F
MVZ;FMGVI\;5[IJ&F<ZCZL,6V2\.O+@"H^J[XPT.FX@"EO*3DM*FJNK#&P,FF
M5P#%W*?S`*?SMW,@)7,`I_.W<ZC/I<ZJS``B)7,BI'>G\[=S+@"G\[=SM7NF
MH:1WIU*PHRX`I%>VQP"D=Z17ML>ITJ:SP+.ESK5[IJ&JNK-=J7?`R:CLIOBJ
M0;ZY+@"D:KQGJ=2D0KS&IG(`I&J\9\.YL*B\QJ9R`%5R=6=U87D@**]1J=2F
M8RD`J,^ESJ78JV6JNCH@)7,`J,^ESB!34TP`IG"J1Z=!JKJHSZ7.JLRF5[K9
M+[%+O5B[4"!)35-0(*;XJD&^N:2CIE`LI6FF8J:YLUVI=RX`J,^ESJK,`*C/
MI<ZJS"`E<R"EO+-QN4P@)7,@JKJQPL5VQ>?#TBX`J,^ESJK,NMZR>@"HSZ7.
MJLR_[[:U`*C/I<ZJS+7YI54`IKFON*5XJKJHSZ7.JLRU^:55J'2RSJ1WL+&E
MSBX`I^2DHZCLJ,^ESJK,L6*XN0"HSZ7.JLRF5[K9`*C/I<ZJS*97NMD@(B5S
M(B"D=Z9SIF(N`*C/I<ZJS*97NMDZ`*C/I<ZJS#H@`*ATLLZDI*JZJ,^ESJK,
M.@!5>F)E:VES=&%N("BO4:_WIT^G2BD`5D93(*78O_VHPZ2CIG.F8BX`L+*T
MP;-QJKX`O7._Z+"RM,&S<:J^`*78JV6JNKE,PF^^N<58L,JU>Z:AJ,.EO*3D
MM*FPLK3!LW&JOJJZI5ROX"X`I'>GY*CLIK.NQ*JZIF'"23H@`*:SKL2IR@"E
M2*3`Q,&LL+/FINPHL7&R>Z9BL%^ZXBD`K<@`O^^H^JW(IML`5F%N=6%T=2`H
MI<NEHZK\N<\I`,7<I,8`5F5N97IU96QA("BI9:2ZM^>IU"D`Q>?#TJ6BL=$@
M+2"FN;9LI?.E::_@I'>^1*1(OM6FV[]YI^\N`*JII;L`JJFEN[&QJ.X`JZNJ
MO;GON_0`JZNJO;G4I5(`JZNJO3H`JT2Q8+"J`%9I970@3F%M("BV5JMN*0"V
M5JMNI.4@*%9)4T-)22D`P,NU^"`E<P"F8K=SM?BUH;9]L=(`I4@@)7,@P,NU
M^`!6:7)G:6X@27-L86YD<RP@0G)I=&ES:"`HK5[$W;K[J,JX<ZYQ*0!6:7)G
M:6X@27-L86YD<RP@52Y3+B`HK/S$W;K[J,JX<ZYQ*0"OX*BCJ]<`K^"HHZO7
M.B``N'&D:J=1I?&\=ZVWN7&K2*2]I7&S>KE,(%--5%``Q+6G:0#$M:=I(2$A
M(+%Q("5S(*3BL,JROK"CM7NFH2X`5TE.(+AGI=$@2%144`!786QL:7,@86YD
M($9U='5N80#$M:=I`*Q0M,&D5`"DT:[PN7>T^@"N\+9(N.JNQK2CJ-$`=V5A
M=&AE<BYC;VT@NO2ON`"Z]*^X`+KTK[@`J$.V9P#%=ZKO`,5WJN^H["`E<P#%
M=ZKO+"`E<P"FZ+S:("A)4T\M.#@U.2TQ*0"FZ+S:("A)4T\M.#@U.2TQ-2D`
M5V5S=&5R;B!386AA<F$@**;HO+NKHJG4*0"DS;6]IE>SYJJZMFRE\Z9AIWTZ
M7VD`M6ZD2JOAP+.XTZ7]Q>.EW"`E<R"M_J1`K=/`LZ7.M7NFH3\`Q.:F[*JZ
MI,"Y:J9RI+@_`*3>K7JJNJMEN&VF<J2X/P!7:&5R96ES($%U<W1R86QI82"F
M8;G/`*W^K=.DZZS;`+KTK;:]<[_HOKFJNK2AI?,H<&QU9VEN<RFQTK#*L;&H
M[BX`I,VUO:97L^8`O7._Z*3-M;VF5[/F`*78JV6JNKE,PF^^N<58L,JU>Z:A
MJ,.EO*3DM*FDS;6]IE>SYJJZI5ROX"X`I'>S4:9#K+"DS;6]IE>SYJJZMFRE
M\Z9AIWT`O&6KUP"E2"!#4U,@K+"SYJ;LJKJ\9:O7`*6JP^0E<Z5<K^"J[:JZ
MO&6KURBD5::XM6ZD2JELI<VNQ"DZ`*KMKN:\9:O7`+QEJ]>SYJ;L`+QEJ]<Z
M`+:PQ>FST*=``*VW`*:MIK.MMP"MM[-T*+A@*0"MM[-T.@"MM[-T.B``M+R\
M>@"TP:O=PJ>JJP"D=:=``+_LI+VKQZ9AIWT`O^RDO:O'N7&XW`"RQ"5DIN:J
MNL3FINR\QJ78I*.EO[U4+B#`L[C3K6ZFLR5DK=/$YJ;L+*5UI^2H["5DK=/$
MYJ;L+@#$YJ;LO,:EV*2CI;^]5"X@P+.XTZUNIK,E9*W3Q.:F["RE=:?DJ.PE
M9*W3Q.:F["X`P'6E_;:VI\<`6"U3<&%M(+6EK\4`6"U3<&%M(*3`O,8`6"U3
M<&%M(*JLND$`6#4P.78S(*FUIOFJ]\9?NWFJ:P!8-3`Y=C,@I42FKK3`I4ZF
M5[K9`%@U,#EV,R"E1*:NJO?&7\/1IT^JS`!8-3`Y=C,@L,;`R:97`*9^`*9^
M`%EA:&]O("$@IF&YSP"H0Z9^`%EE;65N("BXK:KY*0"L3P"L3ZJZ+*?:IE"W
M3@"G0:78JV6HSZ7.K\*DY:9RO7.\9[S2IJ$N(*C/I<X@6SP^72"K]K9SI6FD
MP;2KK+"Z]*VVO7.\9[S2IJ$N`*2CI+FS7*=!J]BEWR5DI4BD5ZJZL,^V]"X`
MIT&H4Z:SJ]BEW[97N4P@)60@K=.S5ZMHJKK%=JVM+@"DHZ2YLURG0:O8I=^I
MSKUSO^BFVZUQLU>K:"X`IT&EO+-1L<+%=BX`IT&JNJ7^IE>DI*2CI6FFLR`G
M7"<@LV^\RZJZIG*DN"X@`*=!J,.EO+_II$JD0*W3IK.NQ*JZN7&D;+9LI?.F
M[*=]+@"G0:C#I;RET;;7I$JJNL#)KM>DI+GOK$VE]*;SQ.:F[*CL("5S`*=!
MI'>X9[5NI5@N`+W0O^FD2J1`K=.FLZ[$JKJY<;C<N+F]6"RPZKO:N7&XW+BY
MO5BVR*5UI+FS7+S&IG*XN;U8+*C#M?BQH:IPI6FI\ZMEK;&F0:5;I$"MTR`G
M*R<N`*=!I;*VM[_II$JD0*W3IK.NQ*JZK<@N`*=!I;*VMZ7]LU>YNJ9NOO"J
MK+CJKL8H1&%T851R964IIOBJ0;K=I'ZOX,1^Q/*HSZ7.MW.ESJ3AM?FE5:I!
ML,@N`*=!I;*VMZ7]LU>YNJ1`K=.UZL#`P,FNUZATLLXH5D93*:;XJD&ZW2X`
MO="T>:UZL-W#1*%!IF*G0;;'L&6PW<-$L_BG::2GJV4N`*=!I;*VM[_II$JF
MN;-SM;*ITJO\IE:JNKKTIWT`O="K_*EWK6ZG4K"CJKJF^*I!OKDN`+W0J_RI
M=ZUNLDVPHZJZJ,^ESJK,+@"]T*O\J7>M;K*^L*.JNJC/I<ZJS"X`IT&ELK:W
MJ_RI=Z;<I-:D0*W3N7&D;+9LI?.F8:=]+*5(JTNQTJ7.L+*TP;-QJKZJ0;#(
M+@"]T*O\J7>M;K=SO%>JNJC/I<ZJS"X`O="K_*EWK6ZG\[=SJKJHSZ7.JLPN
M`+W0J_RI=ZUNL/6FYJJZIT"ESBX`IT&ELK:WO^FD2K=SI,##_JJZIE>ZV2X`
MIT&ELK:WM*.HT:1`K=.X<:1JIU&YTJ2ZJKJY<;C<N+F]6`"G0:JZ("5S(+=\
MM,&D=[E,KLDNO="MJ[=SM6ZD2BX`IT&JNKEQI&RV;*7SINVG?0"G0:JZL4BE
M\Z1(N7&D;+9LI?.F[:=].@"G0:JZN.JP5`"FV[%QIT&JNB`E<R"W?+3!MGVI
M;*5(J-.G0:JZNO2[VKKTN/2F[*=]I'?%W*?S+B"LL*M/Q4"G0:JZIG>E_K!?
MJ*.A0:=!I;*VMZVKMW.U;J1*+@"G0:JZIE>ZV0"G0:JZQ>?#TJ;XJD&ZW:C#
MI*.DY+2IMW.\5ZC/I<ZJS"X@IG"J1Z=!I\:QYKK>LGJHSZ7.JLRQ8KBY+*=!
MI;*VMZ5TO^^HY*5,JKK%Y\/2IOBJ0;K=+@"G0:JZQ>?#TKK=J,.EO*3DM*FF
M0Z58J,^ESJK,J<ZXTZ5<K^"D=[-1P_:SK"X`IMNQ<:=!JKH@)7,@MWRTP;9]
MJ6RE2*C3IT&JNL)SQ/V^N:;\I4>D=\7<I_,N(*RPJT_%0*=!JKJF=Z7^L%^H
MHZ%!IT&ELK:WK:NW<[5NI$HN`*=!JKK"<\3]OKFHPZ6\I.2TJ;-OK=.E7*_@
M+@"G0:JZPG/$_;ZYJ,.EO*3DM*FF0Z9,O^^VM2Z]T*OV($-44DPO0V]M;6%N
M9"`K(%`@ID.F3"X`IT&EV*MEJ=*S7:EWJKJNR;#/.@"[U:15N7>S7:JZJ*VE
M]\/1IT^D=\7<I_,N`+O5I%6Y=[-=JKJHK:7WP]&G3SH`IT&JNJ7^IE<Z`*=!
MJKJU;J1*I'>H[+3!+@"G0:9B("5S(*2DJKJW<[%+O5BL3SH@)7,`IT&F8K5N
MI$JTP;:AJKJ_[[:UI'>S4:?SMW,N`*=!JKJ_[[:UI'>G\[=S+@"G0:JZL4N]
M6*1WK:NW<[-=J7<`L4N]6*1WLU&MJ[=SLUVI=RRW<ZJZL4N]6*1WLWJY3+EQ
MI&RV;*7SL4BU;[W0I4BXT[%+O5BU;J1*+@"G0:JZL4N]6*1WJ.RTP2X`IT&J
MNKNWNMVF^*I!OKDZ`%EU9V]S;&%V:6$@**MNM+6IU*32*0!:86ER92`HPL2E
M["D`6F%M8FEA("BI?*3QJ,@I`%II;6)A8G=E("BHKZ3:J\(I`%O!],+#I-ZM
M>ET`6[5,I42FKET`6[#=PT2DSZQ-70!;Q>.EW*3>K7H@+0!;Q>.EW*3>K7H@
M+2`E<R"FYET`6Z;LJ?.FYB`E<R"F0"`E<R"FYET`IMNPRL+@L4BH[*15ID.J
MNKEQI&RV;*7SINVG?3I?00"E2*15JKJY<:1LMFRE\Z;MIWVDHZ9>P+,Z7T$`
MNMZR>E]!`+;"IE>SYE]"`*E2I4^F0U]#`+[PJJRXZJ[&7T0`IU*PHZ9#7T0`
MN?VILZ=2L*.K2*7S7T0`IF*H0Z1`JL6EU:;FI*2_Z:1*I$"MT[EQI&RV;*7S
MIF&G?3I?10"FV[#*PN"Q2%]&`+ASLM5?1P"[H:GZ7T@`O':YLZ2ZKF5?22XN
M+@"K3Z]DLV^MT[%BN+FDI*JZJTBE\S]?2P"U;J1*7TP`M6ZE6%],`*W7I^^S
M<[6R7TTN+BX`MVBROJM(I?.H[*M(I?.Y:#I?30"GVJJZN7&D;+9LI?.F8:=]
M.E]-`+_OMK5?3P#%=JVM7U``LKZPH[GOLW.ULE]2+BXN`+E,PF^U>Z:A7U,`
MLUVI=U]3`*KMKN:DNJYE7U0N+BX`J,^ESJK,7U4`L+*TP;-QJKY?5@"DS;6]
MIE>SYE]7`+'2I<X`LW&P5+_]`*;3I4(`IN:HQK[D`+5,JFNKV*7?O^FE6,#)
MKM<`M4RJ:[9]L=*_Z:1*`*OVIKD`L4NE3Z9#NWFJ:[_YNWX`LUVI=[_YNWX`
MO_*EHJVKK6ZJNJATLL[`R:[7`+CJKL:NYJ:AO_F[?@"D=["QI<X@+2"Q_;'2
MI<Z]T,))O^^S;[C,`*?DI*.H[+!/O_T`Q.:F[`#`R:[7`+%Q("5S("@E<RD@
MJ?,@)7,@)7,`L'VMMP"NR3H`KLD`I;RJOJJZMFRE\Z5$OO>F5[K9`*7?IUD`
ML+&ES@"JO;&UQ>.EW*GSI;NDY;#/`+_II$HOO^FE6+_YNWX`I+JSH;-NQ>F_
M^;M^`*;F70!M86EL9')O<""Y3,)OM7NFH:1W($EN9V\@J=*RHZ7-+@"DQ[!T
M`*3``*97NMD`J7REO+GJIT`N`*E\I;RYZJ=`+@"SQJ?1O_T`J<ZJS`"FRJ3`
MI/$`IG.H^KY$J=H`N;.OP`!P<F]C;6%I;""Y3,)OM7NFH:1WLJ.ES2X`LW&K
M2*CSJ7>[M[K=O_F[?@"D5Z3)`+5,I6FESJJZJD&PR`#%XZ7<KG2RIP!S:65V
M92"Y3,)OOKFD=[-1($EN9V\@LJ.ES0!S;7,R96UA:6P@N&>ET2!(5%10`*SM
M`,.MJ7<`J'2RSK_YNWX`J]V_[,.O`+S(KLFIRJJZI:*QT0"F0::XO^FD2J=!
MJKJQ2[U8I4B]5+M[M4R[?@"^XZ98`*6\J5*F5P"HSZ7.JLR_[[[<`'9#87)D
M`*Q0M,$Z`'=E871H97(N8V]M(+KTK[@`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+W!O+P``````````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S0W`#`Q-C`P,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEN9V\O<&\O:V]?2U(N<&\`````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`Q,#4U-C<`,3`T,3<S-C(W-#<`,#$W,S8Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@2V]R96%N
M('1R86YS;&%T:6]N<R!F;W(@:&]R9&4@<&%C:V%G90HC(&AO<F1E(,;0Q;#!
M]K^A(+3KQ]$@Q]&QN;[N(+GXOZJYKBX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@
M2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E
M<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K86=E+@HC"FUS
M9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!H;W)D92`S
M7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P
M,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-2TP."`Q-CHT,BLP.3`P
M7&XB"B),87-T+51R86YS;&%T;W(Z($II;FAY;VL@2&5O(#QN;W9E;6)R94!O
M=7)N871U<F4N;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH
M;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]155#+4M27&XB"B)#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R
M86QS/3$[('!L=7)A;#TP.UQN(@H*(SH@9FEL=&5R<RYP:'`Z,3@U"FUS9VED
M("(@86YD(@IM<V=S='(@(B"QU[BNL.TB"@HC.B!F:6QT97)S+G!H<#HQ.#4*
M;7-G:60@(B!O<B(*;7-G<W1R("(@ML>TPB(*"B,Z('1E;7!L871E<R]B;&%C
M:VQI<W0O8FQA8VML:7-T+FEN8SHQ-PIM<V=I9"`B06-T:6]N(&9O<B!B;&%C
M:VQI<W1E9"!A9&1R97-S97,Z(@IM<V=S='(@(KSVO<6PQ;K.(,'6O-*_H2"T
MZ\?1(+CMM\DB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ
M,`IM<V=I9"`B06-T:79A=&4@4V-R:7!T(@IM<V=S='(@(B(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G:60@(D%C=&EV
M871I;F<@=&AE('-C<FEP="!F;W(@7"(E<UPB(&9A:6QE9#H@*"5D*2`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z
M-@IM<V=I9"`B061D:71I;VYA;"!3971T:6YG<R(*;7-G<W1R("+#W["AP/O`
MSB"\L\&D(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHT-`IM<V=I
M9"`B06QL(&]F('1H92!F;VQL;W=I;F<B"FUS9W-T<B`BM-G`O<#'(,#\NLXB
M"@HC.B!L:6(O87!I+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B06QL;W<@4G5L
M97,B"FUS9W-T<B`BN_6WSK_N(+'4Q*(B"@HC.B!T96UP;&%T97,O<G5L92]F
M;V]T97(N:6YC.C,S"FUS9VED(")!;G-W97)E9"(*;7-G<W1R("*TY,#EQ]$@
MN-[`SR(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#4*;7-G:60@
M(D%N>2!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@(K39P+T@P=\@Q\^SJB#`
MS+OS(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHQ,0IM<V=I
M9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R("+'RL7-(,#[O^O'S['B(@H*(SH@
M9FEL=&5R<RYP:'`Z,C$T"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@9&5L971E('1H:7,@<G5L93\B"FUS9W-T<B`B(@HB(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBP,P@N-Z]P\'VN*8@
MO[6_^,CW(+OHP:;'S[W#L-J]P+3/L>X_7&XB"B(C+2,M(RTC+2,@(&MO7TM2
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBP,P@N-Z]P\'VN*8@
MO[6_^,CW(+OHP:;'S[W#L-J]P+3/L>X_7&XB"B(C+2,M(RTC+2,@(&MO7TM2
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBP,P@N-Z]P\'VN*8@
MO[6_^,CW(+OHP:;'S[W#L-J]P+3/L>X_7&XB"B(C+2,M(RTC+2,@(&MO7TM2
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBP,P@N-Z]P\'VN*8@
MO[6_^,CW(+OHP:;'S[W#L-J]P+3/L>X_7&XB"B(C+2,M(RTC+2,@(&MO7TM2
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBP,P@N-Z]P\'VN*8@
MO[6_^,CW(+OHP:;'S[W#L-J]P+3/L>X_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S"FUS9VED(")!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R
M:7!T(&%F=&5R(&5A8V@@8VAA;F=E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M9FEE;&1S+G!H<"YD:7-T.C0W"FUS9VED(")"8V,B"FUS9W-T<B`BO/O`NB#"
M_,&V(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B
M0F5G:6YS('=I=&@B"FUS9W-T<B`BO/;!I"(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,3`V(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3$Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z
M(&9I;'1E<G,N<&AP.C$T-"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES
M="YI;F,Z-PIM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(KSVO<6PQ;K.(@H*
M(SH@8FQA8VML:7-T+G!H<#HQ,#`*;7-G:60@(D)L86-K;&ES="!%9&ET(@IM
M<V=S='(@(KSVO<6PQ;K.(+CQM\\@O/;!I"(*"B,Z(&)L86-K;&ES="YP:'`Z
M,3<*;7-G:60@(D)L86-K;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C
M=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M8W)I<'0O<')O8VUA:6PN<&AP.C(P-R!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H
M<#HQ-S4*;7-G:60@(D)L86-K;&ES=&5D($%D9')E<W,B"FUS9W-T<B`BO/:]
MQ;#%NLZUR"#!UKS2(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C0S"FUS
M9VED(")";&%C:VQI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`BO/:]Q;#%NLZU
MR"#!UKS2(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HX.`IM<V=I9"`B
M0F]D>2(*;7-G<W1R("*ZN[FN(@H*(SH@9FEL=&5R<RYP:'`Z,3@R(')U;&4N
M<&AP.C(X,0IM<V=I9"`B0V%S92!396YS:71I=F4B"FUS9W-T<B`BM.N\TKFN
MP-H@L;BZT"(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-#,*;7-G:60@
M(D-C(@IM<V=S='(@(L+\P;8B"@HC.B!R=6QE+G!H<#HQ,C(@=VAI=&5L:7-T
M+G!H<#HS-B!F;W)W87)D+G!H<#HS,R!V86-A=&EO;BYP:'`Z-#$*(SH@8FQA
M8VML:7-T+G!H<#HV.0IM<V=I9"`B0VAA;F=E<R!S879E9"XB"FUS9W-T<B`B
MO/;!I+OGQ]<@P/K`Y;7*(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-0IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS-#`*;7-G:60@(D-O;G1A:6YS(@IM<V=S='(@(L;WQ]0B
M"@HC.B!F:6QT97)S+G!H<#HR,C4@9FEL=&5R<RYP:'`Z,C(V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O<'D@)7,B"FUS9W-T<B`BNKF[YR`E<R(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HW-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!O
M9B`E<R(*;7-G<W1R("(E<R"ZN;OG(@H*(SH@;&EB+TEN9V\N<&AP.C4R"FUS
M9VED(")#<F5A=&4@;F5W(&9O;&1E<B(*;7-G<W1R("*[]2#&^K3U(+BXM>FQ
MXB(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C,S-B!L:6(O4V-R:7!T
M+VUA:6QD<F]P+G!H<#HR-SD*;7-G:60@(D1)4T%"3$5$.B`B"FUS9W-T<B`B
MN^>_Z[[(Q]0Z(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z
M,3<*;7-G:60@(D1E86-T:79A=&4@4V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9I
M;'1E<G,N<&AP.C(Q-"!F:6QT97)S+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E("5S(@IM<V=S='(@(KOHP:8@)7,B"@HC.B!T96UP;&%T
M97,O<G5L92]F:6QT97(N:6YC.C,P"FUS9VED(")$96QE=&4@0V]N9&ET:6]N
M(@IM<V=S='(@(KOHP:8@P;:PQR(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.3(*
M;7-G:60@(D1E;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`BN-Z]
MP\'V(+_/P/P@N^C!IB(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z
M,S4*;7-G:60@(D1E;&5T960B"FUS9W-T<B`BN^C!IK7((+C>P,\B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,C@P"FUS9VED(")$96QI=F5R(&EN=&\@;7D@24Y"
M3U@B"FUS9W-T<B`BN=[`NL;MP?;'U,"XM\X@P/RTWB(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS,#8*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@
M8V]P>2!T;R(*;7-G<W1R("*YWL"ZQNW!]L?4P+BWSB#`_+3>Q\^P[2"TV<"]
M(,;MP?;'U,"XM\X@NKF[Y\?/L>(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S`Q
M"FUS9VED(")$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(')E9&ER96-T('1O
M(@IM<V=S='(@(KG>P+K&[<'VQ]3`N+?.(,#\M-['S[#M(+39P+W!UKS2M\X@
MP/RTWB(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.#8*;7-G:60@(D1E;&EV97(@
M=&\@9F]L9&5R(@IM<V=S='(@(L;ZM/6WSB#`S+6_(@H*(SH@9FEL=&5R<RYP
M:'`Z,C0Q(&9I;'1E<G,N<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M:7-A8FQE("5S(@IM<V=S='(@(KOGO^N^R,?4.B`E<R(*"B,Z('1E;7!L871E
M<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHQ,"!T96UP;&%T97,O8FQA8VML
M:7-T+V)L86-K;&ES="YI;F,Z,3`*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A
M8V%T:6]N+FEN8SHV('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C$P
M"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,C8*;7-G:60@(D1I<V%B
M;&5D(@IM<V=S='(@(KOGO^N^R,?4(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<V5T=&EN9W,N:6YC.C$S"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&YO=&EF
M:6-A=&EO;B!W:&5N(&5A8V@@9FEL=&5R(&ES(&%P<&QI960_(@IM<V=S='(@
M(L?*Q<VPH2#`^[_KM<D@MJ<@P-J\O,?1(+[+N+(@N-Z]P\'VN*8@QZ6]P\?5
MM,^TV2XB"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C,T
M"FUS9VED(")$;R!?;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES
M="!M97-S86=E<R(*;7-G<W1R(")?;KGZQ:D@R*3`NB"XKKVZQJX@N-Z]P\'V
MOZ$@M.O'V"#`P+3DP+L@NKBSN\'V(+[*M,*TV2(*"B,Z('1E;7!L871E<R]R
M=6QE+V9O;W1E<BYI;F,Z,3`*;7-G:60@(D1O('1H:7,Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#4*;7-G:60@(D1O97-N)W0@8F5G:6X@
M=VET:"(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0Q"FUS9VED
M(")$;V5S;B=T(&-O;G1A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,T-PIM<V=I9"`B1&]E<VXG="!E;F0@=VET:"(*;7-G<W1R("(B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S0Y"FUS9VED(")$;V5S;B=T(&5X:7-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3(*;7-G:60@(D1O97-N
M)W0@;6%T8V@@*'=I=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C,Q"FUS9VED(")%9&ET(@IM
M<V=S='(@(KSVP:0B"@HC.B!F:6QT97)S+G!H<#HR,#,@9FEL=&5R<RYP:'`Z
M,C`U(&9I;'1E<G,N<&AP.C(P.2!F:6QT97)S+G!H<#HR,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R("*\]L&D("<E<R<B"@HC.B!F
M:6QT97)S+G!H<#HR-#4@9FEL=&5R<RYP:'`Z,C0V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5N86)L92`E<R(*;7-G<W1R("*[Y[_KQ\^QXCH@)7,B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C,W"FUS9VED(")%;F%B;&5D
M(@IM<V=S='(@(KOGO^O!WR(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#8*(RP@
M9G5Z>GD*;7-G:60@(D5N9',@=VET:"(*;7-G<W1R("*\]L&D(@H*(SH@;&EB
M+U-T;W)A9V4N<&AP.C,U-PHC+"!F=7IZ>0IM<V=I9"`B17%U86P@=&\B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V
M<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V
M<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V
M<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V
M<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC
M+2,M(UQN(@HBP::X\2"^^+V_7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(
M;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M
M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<
M;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@
M,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M(RTC
M+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!
MIKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC
M=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K
M;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^
M^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S*2`@
M(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?2U(N
M<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN
M(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC
M+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(
M;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M
M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<
M;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@
M,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M(RTC
M+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!
MIKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC
M=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K
M;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^
M^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S*2`@
M(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?2U(N
M<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN
M(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC
M+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(
M;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M
M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<
M;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@
M,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^^,"](@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HQ,SD@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#D@;&EB
M+T1R:79E<B]L9&%P+G!H<#HQ-3@*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5T<FEE=FEN9R!C=7)R
M96YT('-C<FEP=#H@*"5D*2`E<R(*;7-G<W1R("(B"@HC.B!B;&%C:VQI<W0N
M<&AP.C8W"FUS9VED(")%<G)O<B!S879I;F<@8VAA;F=E<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR,@IM<V=I9"`B
M17AI<W1I;F<@4G5L97,B"FUS9W-T<B`BP;C`Y\?/M,(@Q\K%S;BU(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,T.`IM<V=I9"`B17AI<W1S(@IM<V=S='(@(L&X
MP.?'U"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30T"B,L('!H<"UF;W)M
M870*;7-G:60@(D5X<&5C=&5D(#$@;V)J96-T+"!G;W0@)60N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,`IM<V=I
M9"`B1FEL=&5R($%L;"!-97-S86=E<R(*;7-G<W1R("*X\+7G(+C>O</!]B#'
MRL7-(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(R"FUS
M9VED(")&:6QT97(@3VYL>2!3965N($UE<W-A9V5S(@IM<V=S='(@(L#0P+H@
MN-[`S[BX(,?*Q<TB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI
M;F,Z,C$*;7-G:60@(D9I;'1E<B!/;FQY(%5N<V5E;B!-97-S86=E<R(*;7-G
M<W1R("+`T,'V(+[*P+H@N-[`S[BX(,?*Q<TB"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]S971T:6YG<RYI;F,Z,3@*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM
M<V=S='(@(L?*Q<T@O+'%P[OGQ]<B"@HC.B!T96UP;&%T97,O<G5L92]H96%D
M97(N:6YC.C(U"FUS9VED(")&:6QT97(@4G5L92(*;7-G<W1R("+'RL7-(,6E
MQ*(B"@HC.B!F:6QT97)S+G!H<#HQ,#D*;7-G:60@(D9I;'1E<B!2=6QE<R(*
M;7-G<W1R("+'RL7-(,6EQ*(B"@HC.B!S8W)I<'0N<&AP.C4R"B,L(&9U>GIY
M"FUS9VED(")&:6QT97(@4V-R:7!T($1I<W!L87DB"FUS9W-T<B`BL>+%N""\
ML\&D(@H*(SH@;&EB+TEN9V\N<&AP.C,P,`IM<V=I9"`B1FEL=&5R(%]2=6QE
M<R(*;7-G<W1R(")?<L?*Q<T@Q:7$HB(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP
M:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B)62PLR"XWKW#P?8@P?:_]L'\+B`B
M"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,P-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA
M=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(E9+"S(+C>O</!]B#!]K_VP?PN
M("(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C@S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@
M:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("(E9+"S(+C>O</!]B#!]K_VP?PN("(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP
M:'`Z,3@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI
M<W0@=V5R92!D96QE=&5D+B(*;7-G<W1R("(E9+"S(+C>O</!]B#!]K_VP?PN
M("(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E
M(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I960@=&\@=&AE("(*
M(F9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(KC>O</!]B#!]K_VP?PB"@HC.B!L
M:6(O4V-R:7!T+VEM87`N<&AP.C,P,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O
M;2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BN-Z]P\'V(,'V
MO_;!_"(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M97-S
M86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@
M9F]L9&5R("(*(EPB)7-<(BXB"FUS9W-T<B`BN-Z]P\'V(,'VO_;!_"(*"B,Z
M(')U;&4N<&AP.C$V,`IM<V=I9"`B1FEL=&5R(&YO="!F;W5N9"XB"FUS9W-T
M<B`BQ\K%S2##H\'V(+CXQ]0B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N
M:6YC.C0R"FUS9VED(")&;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA
M=&-H97,Z(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C$V,B!T96UP;&%T
M97,O9F]R=V%R9"]F;W)W87)D+FEN8SHX"FUS9VED(")&;W)W87)D(@IM<V=S
M='(@(L#\M-XB"@HC.B!F;W)W87)D+G!H<#HQ-@IM<V=I9"`B1F]R=V%R9"!I
M<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV
M97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(X
M,B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HR,C0*;7-G:60@(D9O<G=A<F1S
M(@IM<V=S='(@(L#\M-XB"@HC.B!F;W)W87)D+G!H<#HT-@IM<V=I9"`B1F]R
M=V%R9',@161I="(*;7-G<W1R("+`_+3>(+SVP:0B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C,Y"FUS9VED(")&<F]M(@IM<V=S='(@(L"GQ*$B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S4U"B,L(&9U>GIY"FUS9VED(")'<F5A=&5R
M('1H86XB"FUS9W-T<B`BN+7%J2"XN+7IL>(B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S4V"B,L(&9U>GIY"FUS9VED(")'<F5A=&5R('1H86X@;W(@97%U86P@
M=&\B"FUS9W-T<B`BN+7%J2"XN+7IL>(B"@HC.B!T96UP;&%T97,O<G5L92]F
M;V]T97(N:6YC.C,Q"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`BP=^_Y,?1
M(+C>P,\B"@HC.B!R=6QE+G!H<#HS-@IM<V=I9"`B26YD:79I9'5A;"!R=6QE
M<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@
M9')I=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ
M.#4U"FUS9VED("));F5X:7-T86YT(&UA:6QB;W@@<W!E8VEF:65D(&9O<B!M
M97-S86=E(&1E;&EV97)Y+B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S0R"FUS9VED("))<R(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S0S"FUS9VED("))<VXG="(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C(S"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER
M960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO
M="!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3,*
M;7-G:60@(DQE<W,@=&AA;B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S4T"B,L(&9U>GIY"FUS9VED("),97-S('1H86X@;W(@97%U86P@=&\B
M"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP
M+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP
M+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP
M+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP
M+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@-"XP+6-V<RD@(",M
M(RTC+2,M(UQN(@HBP::X\2"^^+V_7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O
M("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*
M(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC
M+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R
M9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M
M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N
M,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC
M("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X
M\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?
M2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`
MO5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M
M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O
M("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*
M(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC
M+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R
M9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M
M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N
M,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC
M("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X
M\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?
M2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`
MO5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M
M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O
M("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*
M(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC
M+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R
M9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^^,"](@H*(SH@8V]N
M9FEG+V9I96QD<RYP:'`N9&ES=#HU.0IM<V=I9"`B3&ES="U)1"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,C`*
M;7-G:60@(DUA<E]K(&UE<W-A9V4@87,@9&5L971E9"(*;7-G<W1R(")?:\'V
MO_;!^""XWKW#P?:WSB#'I;W#(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R
M+FEN8SHR-`HC+"!F=7IZ>0IM<V=I9"`B36%R:R!M97-S86=E(&%S.B(*;7-G
M<W1R("*XWKW#P?8@L;BZT"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3$*;7-G
M:60@(DUA=&-H97,@*'=I=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HU-PIM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4G5L
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C0W.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O9B!B;&%C:VQI<W1E
M9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L("(*
M(DUA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A
M9&1R97-S97,@=&\@8FQA8VML:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z-3,Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@
M;G5M8F5R(&]F('=H:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T
M86P@861D<F5S<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@
M($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W,C,*;7-G:60@
M(DUI<W-I;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O(@IM<V=S
M='(@(B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W-34*;7-G:60@(DUI
M<W-I;F<@<F5A<V]N(&9O<B!R96IE8W0B"FUS9W-T<B`B(@H*(SH@;&EB+U-C
M<FEP="]S:65V92YP:'`Z,3DR,@IM<V=I9"`B36ES<VEN9R!R96%S;VX@:6X@
M=F%C871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE
M861E<BYI;F,Z-#`*;7-G:60@(DUO=F4B"FUS9W-T<B`BP,RUOR(*"B,Z(&9I
M;'1E<G,N<&AP.C$R-B!F:6QT97)S+G!H<#HR,S@*;7-G:60@(DUO=F4@4G5L
M92!$;W=N(@IM<V=S='(@(K[&MZ&WSB#`S+6_(@H*(SH@9FEL=&5R<RYP:'`Z
M,3(W(&9I;'1E<G,N<&AP.C(S-PIM<V=I9"`B36]V92!2=6QE(%5P(@IM<V=S
M='(@(L"GM\X@P,RUOR(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO
M;BYI;F,Z-#(*;7-G:60@(DY?=6UB97(@;V8@9&%Y<R!B971W965N('9A8V%T
M:6]N(')E<&QI97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+V9I;'1E<BUN;VYE+FEN8SHT('1E;7!L871E<R]F:6QT97)S+V9O;W1E<BYI
M;F,Z.`HC.B!L:6(O4W1O<F%G92YP:'`Z-S$T"FUS9VED(").97<@4G5L92(*
M;7-G<W1R("*[];?.O^X@L=3$HB(*"B,Z(&QI8B]);F=O+G!H<#HQ.30@;&EB
M+TEN9V\N<&AP.C$Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M7"(E<UPB(&5L96UE;G0@9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`M,^T
MV2XB"@HC.B!L:6(O26YG;RYP:'`Z,3DR"FUS9VED(").;R!B86-K96YD(&-O
M;F9I9W5R960@9F]R('1H:7,@:&]S="(*;7-G<W1R("(B"@HC.B!L:6(O26YG
M;RYP:'`Z,38Y"FUS9VED(").;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A
M8VME;F1S+G!H<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F
M:6QT97(M;F]N92YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@9FEL=&5R<RX@0VQI8VL@7"(E<UPB('1O(&-R96%T92!A(&YE=R!F:6QT
M97(N(@IM<V=S='(@(L?*Q<VPH2"^^,"]+B`G)7,GN*8@M*VWKR"[]2#'RL7-
MN*8@N+BUY;R\O^0N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3,R-R!L
M:6(O4V-R:7!T+W-I979E+G!H<#HQ-#(P"B,Z(&QI8B]38W)I<'0O<VEE=F4N
M<&AP.C$U.30*(RP@9G5Z>GD*;7-G:60@(DYO(&AE861E<G,@<W!E8VEF:65D
M(@IM<V=S='(@(KFNP-J_K2#`U+?"(+_`M_DB"@HC.B!S8W)I<'0N<&AP.C8W
M"B,L(&9U>GIY"FUS9VED(").;R!S8W)I<'0@9V5N97)A=&5D+B(*;7-G<W1R
M("*[Z,&FM<?!]B"^RL"Z(+C>P,\B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HQ-C`Y"B,L(&9U>GIY"FUS9VED(").;R!S=')I;F=S('-P96-I9FEE9"(*
M;7-G<W1R("+&^K3UN*8@O+'%P\?/O+R_Y"(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS-3@*(RP@9G5Z>GD*;7-G:60@(DYO="!E<75A;"!T;R(*;7-G<W1R("(B
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B+!IKCQ(+[XO;]<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N
M,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC
M("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X
M\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?
M2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`
MO5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M
M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O
M("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*
M(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC
M+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R
M9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M
M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N
M,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC
M("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X
M\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?
M2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`
MO5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M
M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O
M("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+U<;B(*
M(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N,"UC=G,I("`C+2,M(RTC
M+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H2&]R
M9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X\2"^^,"]7&XB"B(C+2,M
M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B+!IKCQ(+[XP+U<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$AO<F1E(#,N
M,"UC=G,I("`C+2,M(RTC+2-<;B(*(L&FN/$@OOC`O5QN(@HB(RTC+2,M(RTC
M("!K;U]+4BYP;R`H2&]R9&4@,RXP+6-V<RD@(",M(RTC+2,M(UQN(@HBP::X
M\2"^^,"]7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A(;W)D92`S+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B+!IKCQ(+[XP+TB"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S$V"FUS9VED(")/;FQY(&9L86<@=&AE(&UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y"FUS9VED(")/<'1I;VYS
M(&%B;W5T('-C<FEP="!U<&1A=&EN9RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S
M='(@(K'BQ;@@O+/!I"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VYE=U]F
M;VQD97(N:G,Z-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H
M92!N97<@9F]L9&5R.B(*;7-G<W1R(")<7&Z[];?.O^X@QOJT]<#'(,#,N*?`
MNR#`U+?"Q\^\O+_D.EQ<;B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A
M=&EO;BYI;F,Z-C`*;7-G:60@(E)?96%S;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+V9I96QD<RYP:'`N9&ES=#HV,PIM<V=I9"`B4F5C96EV960B"FUS9W-T
M<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C(Y-PIM<V=I9"`B4F5D:7)E8W0@
M=&\B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,`IM<V=I9"`B
M4F5G=6QA<B!E>'!R97-S:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS,3(*;7-G:60@(E)E:F5C="!W:71H(')E87-O;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4U"FUS9VED(")297-E;G0@
M5&\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU,0IM
M<V=I9"`B4F5S96YT+69R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O9F]O=&5R+FEN8SHV,`IM<V=I9"`B4F5T=7)N('1O($9I;'1E<G,@3&ES
M="(*;7-G<W1R("+'RL7-(+CQM\_`N+?.(+6YOL:PH;'B(@H*(SH@=&5M<&QA
M=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C(T('1E;7!L871E<R]B;&%C
M:VQI<W0O8FQA8VML:7-T+FEN8SHT,0HC.B!T96UP;&%T97,O=F%C871I;VXO
M=F%C871I;VXN:6YC.C<Q('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC
M.C,T"FUS9VED(")2971U<FX@=&\@4G5L97,@3&ES="(*;7-G<W1R("*QU,2B
M(+CQM\^WSB"UN;[&L*&QXB(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E
M<BYI;F,Z,S0*;7-G:60@(E)U;&4B"FUS9W-T<B`BL=3$HB(*"B,Z(&9I;'1E
M<G,N<&AP.C8P"FUS9VED(")2=6QE($-O<&EE9"(*;7-G<W1R("*QU,2B(+JY
MN^>URB(*"B,Z(&9I;'1E<G,N<&AP.C,Y"FUS9VED(")2=6QE($1E;&5T960B
M"FUS9W-T<B`BL=3$HB#!]K_VP?PB"@HC.B!F:6QT97)S+G!H<#HW-@IM<V=I
M9"`B4G5L92!$:7-A8FQE9"(*;7-G<W1R("*QU,2B(+OGO^N^R,?4(@H*(SH@
M9FEL=&5R<RYP:'`Z.#$*;7-G:60@(E)U;&4@16YA8FQE9"(*;7-G<W1R("*Q
MU,2B(+OGO^O'U"(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,S,*
M;7-G:60@(E)U;&4@3F%M92(*;7-G<W1R("*QU,2B(,#,N*<B"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E-405)4
M5$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,C,@=&5M<&QA=&5S+V)L86-K;&ES
M="]B;&%C:VQI<W0N:6YC.C0P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A
M=&EO;BYI;F,Z-S`@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,S,*
M(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHU.0IM<V=I9"`B4V%V92(*
M;7-G<W1R("+`^L#E(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N
M:6YC.C(Y"FUS9VED(")3879E(%-E='1I;F=S(@IM<V=S='(@(KRSP:0@P/K`
MY2(*"B,Z('1E;7!L871E<R]S8W)I<'0O:&5A9&5R+FEN8SHR"B,L(&9U>GIY
M"FUS9VED(")38W)I<'0B"FUS9W-T<B`BOL:WH<.WP-HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@*(RP@9G5Z>GD*;7-G:60@(E-C<FEP="!5<&1A
M=&EN9R(*;7-G<W1R("(E<R"\]L&DM<HB"@HC.B!L:6(O26YG;RYP:'`Z,C$W
M"B,L(&9U>GIY"FUS9VED(")38W)I<'0@;F]T('5P9&%T960N(@IM<V=S='(@
M(B5S(+SVP:2URB(*"B,Z(&QI8B]);F=O+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G
M:60@(E-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D+B(*;7-G<W1R("(B
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B*XWL#/Q]0@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB
M"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M
M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC
M+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&
M^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K
M;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E
M<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O
M("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[
MZ,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T
M+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[Z
MO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I
M("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN
M7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC
M+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M
M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC
M("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@
M7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`
MS""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::U
MQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC
M=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/
MM-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M
M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*
M(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC
M7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M
M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;Z
MM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO
M7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S
M7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OH
MP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N
M,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]
MP+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@
M(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<
M;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC
M+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*
M(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@
M(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<
M(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N
M<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,
M(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0
M(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'
MOOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V
M<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^T
MV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC
M+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB
M(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<
M;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC
M+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT
M]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?
M2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<
M(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H
M24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!
MIK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP
M+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`
MM,^TV2XB"@HC.B!L:6(O26YG;RYP:'`Z,3(Y"B,L(&9U>GIY"FUS9VED(")3
M8W)I<'0@<W5C8V5S<V9U;&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B*XWL#/Q]0@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C
M+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN
M(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M
M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U
M(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+
M4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPB
MP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)
M35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&F
MM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M
M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"T
MS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C
M+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB
M"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M
M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC
M+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&
M^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K
M;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E
M<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O
M("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[
MZ,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T
M+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[Z
MO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I
M("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN
M7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC
M+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M
M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB
M"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC
M("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@
M7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`
MS""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::U
MQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC
M=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/
MM-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M
M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*
M(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC
M7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M
M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;Z
MM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO
M7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S
M7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@
M*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OH
MP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N
M,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]
MP+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@
M(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<
M;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B+&^K3U(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC
M+2,M(RTC("!K;U]+4BYP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*
M(L;ZM/4@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@
M(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<
M(B5S7"+`S""[Z,&FM<>^^KW`M,^TV2Y<;B(*(B,M(RTC+2,M(R`@:V]?2U(N
M<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+&^K3U(%PB)7-<(L#,
M(+OHP::UQ[[ZO<"TS[39+EQN(@HB(RTC+2,M(RTC("!K;U]+4BYP;R`H24U0
M(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(L;ZM/4@7"(E<UPBP,P@N^C!IK7'
MOOJ]P+3/M-DN7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V
M<RD@(",M(RTC+2,M(UQN(@HBQOJT]2!<(B5S7"+`S""[Z,&FM<>^^KW`M,^T
MV2XB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C(Y"FUS9VED(")3
M965N(@IM<V=S='(@(L#0P+H@N-[`SR(*"B,Z(')U;&4N<&AP.C$Y,`IM<V=I
M9"`B4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`BQ]>X\2"\L<7#(@H*(SH@;&EB
M+TEN9V\N<&AP.C0Y"FUS9VED(")396QE8W0@=&%R9V5T(&9O;&1E<B(*;7-G
M<W1R("+&^K3U(+RQQ<,B"@HC.B!R=6QE+G!H<#HR,C<*;7-G:60@(E-E;&8M
M1&5F:6YE9"!(96%D97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V9I96QD<RYP
M:'`N9&ES=#HS-0HC+"!F=7IZ>0IM<V=I9"`B4V5N9&5R(@IM<V=S='(@(L#0
MP+H@N-[`SR(*"B,Z(&9I;'1E<G,N<&AP.CDU"FUS9VED(")3971T:6YG<R!S
M=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`BO+/!I,#,(+RZL/C`^\"X
MM\X@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I
M=F%T92YI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E-H;W<@06-T:79E(%-C<FEP
M="(*;7-G<W1R("*_K+;TP[,@NKBQXB(*"B,Z('1E;7!L871E<R]S8W)I<'0O
M86-T:79A=&4N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")3:&]W($-U<G)E;G0@
M4V-R:7!T(@IM<V=S='(@(K^LMO3#LR"ZN+'B(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HX,PIM<V=I9"`B4VEZ92(*;7-G<W1R("+%J;'B(@H*(SH@
M=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHT.0IM<V=I9"`B4W1O<"!C:&5C
M:VEN9R!I9B!T:&ES(')U;&4@;6%T8VAE<S\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHU,0HC+"!F=7IZ>0IM<V=I
M9"`B4W5B:F5?8W0@;V8@=F%C871I;VX@;65S<V%G93HB"FUS9W-T<B`BN-Z]
MP\'VM\X@L*&QXB(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S$*;7-G
M:60@(E-U8FIE8W0B"FUS9W-T<B`BP::X\2(*"B,Z(&QI8B]A<&DN<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(%PB)7-<(B!H87,@
M8F5E;B!A9&1E9"!T;R!Y;W5R(&)L86-K;&ES="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,3`T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R
M97-S(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('=H:71E;&ES="XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TEN9V\N<&AP.C$R-0IM<V=I9"`B5&AE(&1R
M:79E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TEN9V\N<&AP.C$R-`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@
M=&AE('-C<FEP="XB"FUS9W-T<B`BM:7`S,6X(,#3QO?&KB"_P+?Y(@H*(SH@
M;&EB+TEN9V\N<&AP.C$R,PHC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B*XWKW#P?8@P/R\VR"_P+?Y7&XB"B(C+2,M(RTC+2,@(&MO7TM2
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBN-Z]P\'V(+JXL[NQ
MXB"_P+?Y7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@
M(",M(RTC+2,M(UQN(@HBN-Z]P\'V(+JXL[NQXB"_P+?Y7&XB"B(C+2,M(RTC
M+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBN-Z]
MP\'V(+JXL[NQXB"_P+?Y7&XB"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@
M-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBN-Z]P\'V(+JXL[NQXB"_P+?Y7&XB
M"B(C+2,M(RTC+2,@(&MO7TM2+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M
M(UQN(@HBN-Z]P\'V(+JXL[NQXB"_P+?Y7&XB"B(C+2,M(RTC+2,@(&MO7TM2
M+G!O("A)35`@-"XP+6-V<RD@(",M(RTC+2,M(UQN(@HBN-Z]P\'V(+JXL[NQ
MXB"_P+?Y(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HR-PIM<V=I9"`B
M5&\B"FUS9W-T<B`BN=ZTPB"[Y[;W(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M9FEL=&5R+FAT;6PZ,C@*(RP@9G5Z>GD*;7-G:60@(E1O.B(*;7-G<W1R("*Y
MWK3"(+OGMO<B"@HC.B!L:6(O4V-R:7!T+G!H<#HQ,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M(@IM<V=S='(@(B5S(,&DP,>XIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9I
M;'1E<G,N<&AP.C$U-B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC
M.C4*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C8R"B,L(&9U>GIY"FUS
M9VED(")686-A=&EO;B(*;7-G<W1R("*]Q\?@(@H*(SH@=F%C871I;VXN<&AP
M.C<R"B,L(&9U>GIY"FUS9VED(")686-A=&EO;B!%9&ET(@IM<V=S='(@(KW'
MQ^`B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HS-3$*(RP@9G5Z>GD*;7-G
M:60@(E9A8V%T:6]N($UE<W-A9V4B"FUS9W-T<B`BN-Z]P\'VM\X@L*&QXB(*
M"B,Z('9A8V%T:6]N+G!H<#HQ-@IM<V=I9"`B5F%C871I;VX@:7,@;F]T('-U
M<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z
M,38*;7-G:60@(E=H7VET96QI<W0@861D<F5S<V5S.B(*;7-G<W1R(")?:;SV
MO<6]PL#.(,'6O-(B"@HC.B!F:6QT97)S+G!H<#HQ-3`@=&5M<&QA=&5S+W=H
M:71E;&ES="]W:&ET96QI<W0N:6YC.C@*;7-G:60@(E=H:71E;&ES="(*;7-G
M<W1R("*\]KW%O<+`SB(*"B,Z('=H:71E;&ES="YP:'`Z-34*;7-G:60@(E=H
M:71E;&ES="!%9&ET(@IM<V=S='(@(KSVO<6]PL#.(+CQM\\@O/;!I"(*"B,Z
M('=H:71E;&ES="YP:'`Z,3@*;7-G:60@(E=H:71E;&ES="!I<R!N;W0@<W5P
M<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(S-"!L:6(O4V-R
M:7!T+W-I979E+G!H<#HR.3<*(SH@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z
M,C`R"FUS9VED(")7:&ET96QI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`BO/:]
MQ;W"P,ZUR"#!UKS2(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW.0IM
M<V=I9"`B6"U0<FEO<FET>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C8W"FUS9VED(")8+5-P86TM3&5V96PB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3<&%M+5-C
M;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-S4*
M;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP
M:'`Z-3,@<G5L92YP:'`Z,30T"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!R=6QE<RXB
M"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z-#4@<G5L92YP:'`Z,C$*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&]R(&5D:70@8W5S
M=&]M(')U;&5S+B(*;7-G<W1R("(B"@HC.B!V86-A=&EO;BYP:'`Z,S`*;7-G
M:60@(B(*(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&5M86EL(&%D
M9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M97-S86=E<R`B"B)S:&]U
M;&0@8F4@86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+VEM
M87`N<&AP.C(W."!L:6(O4V-R:7!T+VEM87`N<&AP.C,P,2!L:6(O4V-R:7!T
M+VEM87`N<&AP.C,Q-0IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EO!
MIKCQ(+[XP+U=(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z
M,C0*;7-G:60@(E]!9&1R97-S*&5S*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C(S"FUS
M9VED(")?061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SHB"FUS
M9W-T<B`B(@H*(SH@;&EB+TEN9V\N<&AP.C,P-0IM<V=I9"`B7T)L86-K;&ES
M="(*;7-G<W1R(")?0KSVO<6PQ;K.(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES
M="]B;&%C:VQI<W0N:6YC.C$X"FUS9VED(")?1&5L971E(&UE<W-A9V4@8V]M
M<&QE=&5L>2(*;7-G<W1R(")?9+C>O</!]B"_S\#\(+OHP:8B"@HC.B!T96UP
M;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,S$*;7-G:60@(E]%;G1E
M<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN93HB"FUS9W-T<B`B7V7'T2#!
MV;^A(,'6O-(@Q\^SJKZ_(,#4M\+'S[R\O^0Z(@H*(SH@;&EB+TEN9V\N<&AP
M.C,Q,0IM<V=I9"`B7T9O<G=A<F0B"FUS9W-T<B`B7V;`_+3>(@H*(SH@=&5M
M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@
M(E]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_(@IM
M<V=S='(@(L#,(,;ZM/6_H2"XWKW#P?:PH2"^^+W`M,^TV2XB"@HC.B!T96UP
M;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,C(*;7-G:60@(E]-;W9E
M(&UE<W-A9V4@=&\@9F]L9&5R.B(*;7-G<W1R(")?;<;ZM/6WSB#`S+6_.B(*
M"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,3,*;7-G:60@
M(E]->2!E;6%I;"!A9&1R97-S97,Z(@IM<V=S='(@(E]MLZK`QR#`S+C>P,\@
MP=:\TCHB"@HC.B!L:6(O26YG;RYP:'`Z,S$T"B,L(&9U>GIY"FUS9VED(")?
M4V-R:7!T(@IM<V=S='(@(K[&MZ'#M\#:(@H*(SH@;&EB+TEN9V\N<&AP.C,P
M.`HC+"!F=7IZ>0IM<V=I9"`B7U9A8V%T:6]N(@IM<V=S='(@(KW'Q^`B"@HC
M.B!L:6(O26YG;RYP:'`Z,S`R"FUS9VED(")?5VAI=&5L:7-T(@IM<V=S='(@
M(E]7O/:]Q;W"P,XB"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C0*
M(RP@9G5Z>GD*;7-G:60@(F%N9"(*;7-G<W1R("+(KL#E(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O9FEL=&5R+FAT;6PZ,38*;7-G:60@(F1I<V%B;&5D("T@
M8VQI8VL@=&\@96YA8FQE(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C$X
M,`HC+"!F=7IZ>0IM<V=I9"`B9FEE;&0B"FUS9W-T<B`BQ\JUY2(*"B,Z(&QI
M8B]38W)I<'0O;6%I;&1R;W`N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B;6%I
M;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O(@IM<V=S='(@(KOHP::U
MQ\'V(+[*P+H@N-[`SR(*"B,Z(&9I;'1E<G,N<&AP.C$X,`HC+"!F=7IZ>0IM
M<V=I9"`B;6%T8V@B"FUS9W-T<B`BPZ.TPB"YKL#:OZTB"@HC.B!T96UP;&%T
M97,O<G5L92]F:6QT97(N:6YC.C0*;7-G:60@(F]R(@IM<V=S='(@(K;'M,(B
M"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G
M:60@(G!R;V-M86EL('-C<FEP="!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R
M("*[Z,&FM<?!]B"^RL"Z(+C>P,\B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HQ,#D*;7-G:60@(G-I979E(&9I;'1E<B!G96YE<F%T960@8GD@26YG;R(*
M;7-G<W1R("(B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+W!O
M+V5S7T53+G!O````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#4T-34T`#$P-#$W,S8R-S0W`#`Q-S,U,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C(%-P86YI<V@@=')A;G-L
M871I;VYS(&9O<B!H;W)D92!P86-K86=E"B,@5')A9'5C8VEO;F5S(&%L(&5S
M<&'Q;VP@<&%R82!E;"!P87%U971E(&AO<F1E+@HC($-O<'ER:6=H="`H0RD@
M,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D
M('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(&AO<F1E('!A8VMA9V4N
M"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P,#0N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($EN9V\@,2XP+6-V<UQN
M(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<
M;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$U(#$W.C0V*S`Q,#!<
M;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,34@,3<Z-#8K,#$P,%QN
M(@HB3&%S="U4<F%N<VQA=&]R.B!-86YU96P@4"X@07EA;&$@/&UA>6%L84!U
M;F5X+F5S/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO
M<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L
M<STR.R!P;'5R86P]*&X@(3T@,2D[7&XB"@HC.B!F:6QT97)S+G!H<#HQ.3`*
M;7-G:60@(B!A;F0B"FUS9W-T<B`B('DB"@HC.B!F:6QT97)S+G!H<#HQ.3`*
M;7-G:60@(B!O<B(*;7-G<W1R(")O(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES
M="]B;&%C:VQI<W0N:6YC.C$W"FUS9VED(")!8W1I;VX@9F]R(&)L86-K;&ES
M=&5D(&%D9')E<W-E<SHB"FUS9W-T<B`B06-C:?-N('!A<F$@9&ER96-C:6]N
M97,@9&4@;&$@;&ES=&$@;F5G<F$Z(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A
M8W1I=F%T92YI;F,Z,3`*;7-G:60@(D%C=&EV871E(%-C<FEP="(*;7-G<W1R
M(")!8W1I=F%R(&=U:?-N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B06-T:79A=&EN9R!T:&4@<V-R:7!T(&9O
M<B!<(B5S7"(@9F%I;&5D.B`H)60I("5S(@IM<V=S='(@(DAA(&9A;&QA9&\@
M;&$@86-T:79A8VGS;B!D96P@9W5I\VX@<&%R82!<(B5S7"(Z("@E9"D@)7,B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z-@IM<V=I9"`B
M061D:71I;VYA;"!3971T:6YG<R(*;7-G<W1R(")/<&-I;VYE<R!A9&EC:6]N
M86QE<R(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#0*;7-G:60@
M(D%L;"!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@(E1O9&\@;&\@<75E('-I
M9W5E(@H*(SH@;&EB+V%P:2YP:'`Z-30*;7-G:60@(D%L;&]W(%)U;&5S(@IM
M<V=S='(@(E!E<FUI=&ER(')E9VQA<R(*"B,Z('1E;7!L871E<R]R=6QE+V9O
M;W1E<BYI;F,Z,S,*;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(E)E<W!O;F1I
M9&\B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C0U"FUS9VED(")!
M;GD@;V8@=&AE(&9O;&QO=VEN9R(*;7-G<W1R(")#=6%L<75I97)A(&1E(&QO
M('%U92!S:6=U92(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z
M-PIM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R(")!<&QI8V%R(&9I;'1R
M;W,B"@HC.B!F:6QT97)S+G!H<#HR,3D*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/R(*;7-G<W1R("*_17-TX2!S
M96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&5S=&$@<F5G;&$_(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S,*;7-G:60@(D%U=&]M871I
M8V%L;'D@=7!D871E('1H92!S8W)I<'0@869T97(@96%C:"!C:&%N9V4_(@IM
M<V=S='(@(K]!8W1U86QI>F%R(&%U=&]MX71I8V%M96YT92!E;"!G=6GS;B!T
M<F%S(&-A9&$@8V%M8FEO/R(*"B,Z(&-O;F9I9R\N8F%K+V9I96QD<RYP:'`N
M9&ES=#HT-PIM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-SD*;7-G:60@(D)E9VEN<R!W:71H(@IM<V=S='(@(D5M<&EE
M>F$@<&]R(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,#8@;&EB+T1R:79E
M<B]L9&%P+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL
M960Z("@E<RD@)7,B"FUS9W-T<B`B2&$@9F%L;&%D;R!L82!V:6YC=6QA8VGS
M;CH@*"5S*2`E<R(*"B,Z(&9I;'1E<G,N<&AP.C$T.2!T96UP;&%T97,O8FQA
M8VML:7-T+V)L86-K;&ES="YI;F,Z-PHC.B!L:6(O0FQO8VLO;W9E<G9I97<N
M<&AP.C@W(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z.3`*;7-G:60@(D)L86-K
M;&ES="(*;7-G<W1R("),:7-T82!N96=R82(*"B,Z(&)L86-K;&ES="YP:'`Z
M,3`W"FUS9VED(")";&%C:VQI<W0@161I="(*;7-G<W1R(")-;V1I9FEC87(@
M;&ES=&$@;F5G<F$B"@HC.B!B;&%C:VQI<W0N<&AP.C$W"FUS9VED(")";&%C
M:VQI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I
M;F<@9')I=F5R+B(*;7-G<W1R(")%;"!C;VYT<F]L861O<B!D92!F:6QT<F%D
M;R!A8W1U86P@;F\@<V]P;W)T82!L:7-T87,@;F5G<F%S+B(*"B,Z(&QI8B]3
M8W)I<'0O<')O8VUA:6PN<&AP.C(P-R!L:6(O4V-R:7!T+W-I979E+G!H<#HR
M-#0*(SH@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,3<V"FUS9VED(")";&%C
M:VQI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B1&ER96-C:6]N97,@:6YC;'5I
M9&%S(&5N(&QA(&QI<W1A(&YE9W)A(@H*(SH@8V]N9FEG+RYB86LO9FEE;&1S
M+G!H<"YD:7-T.C@X"FUS9VED(")";V1Y(@IM<V=S='(@(D-U97)P;R(*"B,Z
M(&9I;'1E<G,N<&AP.C$X-R!R=6QE+G!H<#HR.#$*;7-G:60@(D-A<V4@4V5N
M<VET:79E(@IM<V=S='(@(D1I<W1I;F=U:7(@;6%Y+B]M:6XN(@H*(SH@8V]N
M9FEG+RYB86LO9FEE;&1S+G!H<"YD:7-T.C0S"FUS9VED(")#8R(*;7-G<W1R
M(")#8R(*"B,Z(')U;&4N<&AP.C$R,B!W:&ET96QI<W0N<&AP.C,V(&9O<G=A
M<F0N<&AP.C,S('9A8V%T:6]N+G!H<#HT,0HC.B!B;&%C:VQI<W0N<&AP.C<S
M"FUS9VED(")#:&%N9V5S('-A=F5D+B(*;7-G<W1R(")392!H86X@9W5A<F1A
M9&\@;&]S(&-A;6)I;W,N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-0IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(D9A;&QO(&1E(&-O
M;F5X:?-N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W-0IM<V=I9"`B0V]N=&%I
M;G,B"FUS9W-T<B`B0V]N=&EE;F4B"@HC.B!F:6QT97)S+G!H<#HR,S`@9FEL
M=&5R<RYP:'`Z,C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@)7,B"FUS
M9W-T<B`B0V]P:6%R("5S(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C@W-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W!Y(&]F("5S(@IM<V=S='(@(D-O<&EA(&1E
M("5S(@H*(SH@;&EB+TEN9V\N<&AP.C8R"FUS9VED(")#<F5A=&4@;F5W(&9O
M;&1E<B(*;7-G<W1R(")#<F5A<B!C87)P971A(@H*(SH@;&EB+U-C<FEP="]P
M<F]C;6%I;"YP:'`Z,S,V(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(X,`IM
M<V=I9"`B1$E304),140Z("(*;7-G<W1R(")$15-!0U1)5D%$3SH@(@H*(SH@
M=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,3<*;7-G:60@(D1E86-T
M:79A=&4@4V-R:7!T(@IM<V=S='(@(D1E<V%C=&EV87(@9W5I\VXB"@HC.B!F
M:6QT97)S+G!H<#HR,3D@9FEL=&5R<RYP:'`Z,C(P"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R(")%;&EM:6YA<B`E<R(*"B,Z('1E
M;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z,S`*;7-G:60@(D1E;&5T92!#;VYD
M:71I;VXB"FUS9W-T<B`B16QI;6EN87(@8V]N9&EC:?-N(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C,R,PIM<V=I9"`B1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L
M>2(*;7-G<W1R(")%;&EM:6YA<B!C;VUP;&5T86UE;G1E(&5L(&UE;G-A:F4B
M"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C,U"FUS9VED(")$96QE
M=&5D(@IM<V=S='(@(D5L:6UI;F%D;R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS
M,3$*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!);F)O>"(*;7-G<W1R(")%;G1R
M96=A<B!E;B!M:2!B=7KS;B!D92!%;G1R861A(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,S-PIM<V=I9"`B1&5L:79E<B!I;G1O(&UY($EN8F]X(&%N9"!C;W!Y
M('1O(@IM<V=S='(@(D5N=')E9V%R(&5N(&UI(&)U>O-N(&1E($5N=')A9&$@
M>2!C;W!I87(@82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,S(*;7-G:60@(D1E
M;&EV97(@:6YT;R!M>2!);F)O>"!A;F0@<F5D:7)E8W0@=&\B"FUS9W-T<B`B
M16YT<F5G87(@96X@;6D@8G5Z\VX@9&4@16YT<F%D82!Y(')E9&ER:6=I<B!A
M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Q-PIM<V=I9"`B1&5L:79E<B!T;R!F
M;VQD97(B"FUS9W-T<B`B16YT<F5G87(@96X@96P@8G5Z\VXB"@HC.B!F:6QT
M97)S+G!H<#HR-#,@9FEL=&5R<RYP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G
M:60@(D1I<V%B;&4@)7,B"FUS9W-T<B`B1&5S86-T:79A<B`E<R(*"B,Z('1E
M;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHQ,"!T96UP;&%T97,O
M8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,3`*(SH@=&5M<&QA=&5S+W9A8V%T
M:6]N+W9A8V%T:6]N+FEN8SHV('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N
M:6YC.C$P"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,C8*;7-G:60@
M(D1I<V%B;&5D(@IM<V=S='(@(D1E<V%C=&EV861A(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C$S"FUS9VED(")$:7-P;&%Y(&1E=&%I
M;&5D(&YO=&EF:6-A=&EO;B!W:&5N(&5A8V@@9FEL=&5R(&ES(&%P<&QI960_
M(@IM<V=S='(@(K]-;W-T<F%R(&%V:7-O<R!D971A;&QA9&]S(&%L(&%P;&EC
M87(@8V%D82!F:6QT<F\_(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T
M:6]N+FEN8SHS-`IM<V=I9"`B1&\@7VYO="!S96YD(')E<W!O;G-E<R!T;R!B
M=6QK(&]R(&QI<W0@;65S<V%G97,B"FUS9W-T<B`B7TYO(&5N=FEA<B!R97-P
M=65S=&%S(&$@;65N<V%J97,@9&4@;&ES=&%S(&\@8V]R<F5O(&$@9W)A;F5L
M(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@
M=&AI<SHB"FUS9W-T<B`B2&%G82#I<W1O.B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS.#`*;7-G:60@(D1O97-N)W0@8F5G:6X@=VET:"(*;7-G<W1R(").;R!E
M;7!I97IA('!O<B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-S8*;7-G:60@(D1O
M97-N)W0@8V]N=&%I;B(*;7-G<W1R(").;R!C;VYT:65N92(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS.#(*;7-G:60@(D1O97-N)W0@96YD('=I=&@B"FUS9W-T
M<B`B3F\@=&5R;6EN82!P;W(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@T"FUS
M9VED(")$;V5S;B=T(&5X:7-T(@IM<V=S='(@(DYO(&5X:7-T92(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HS.#<*;7-G:60@(D1O97-N)W0@;6%T8V@@*'=I=&@@
M<&QA8V5H;VQD97)S*2(*;7-G<W1R(").;R!C;VEN8VED92`H8V]N(&-O;6]D
M:6YE<RDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(V(&QI
M8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C$*(SH@;&EB+T)L;V-K+V]V97)V:65W
M+G!H<#HV."!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C@Q"B,Z(&QI8B]";&]C
M:R]O=F5R=FEE=RYP:'`Z.#D*;7-G:60@(D5D:70B"FUS9W-T<B`B36]D:69I
M8V%R(@H*(SH@9FEL=&5R<RYP:'`Z,C`X(&9I;'1E<G,N<&AP.C(Q,"!F:6QT
M97)S+G!H<#HR,30@9FEL=&5R<RYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@)7,B"FUS9W-T<B`B36]D:69I8V%R("5S(@H*(SH@9FEL=&5R
M<RYP:'`Z,C0W(&9I;'1E<G,N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%;F%B;&4@)7,B"FUS9W-T<B`B06-T:79A<B`E<R(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+VAE861E<BYI;F,Z,C@*;7-G:60@(D5N86)L960B"FUS9W-T
M<B`B06-T:79A9&\B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@Q"FUS9VED(")%
M;F1S('=I=&@B"FUS9W-T<B`B5&5R;6EN82!P;W(B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,SDR"FUS9VED(")%<75A;"!T;R(*;7-G<W1R("))9W5A;"!A(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,SD@;&EB+T1R:79E<B]L9&%P+G!H
M<#HQ-#D@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-3@*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5T<FEE
M=FEN9R!C=7)R96YT('-C<FEP=#H@*"5D*2`E<R(*;7-G<W1R(")%<G)O<B!A
M;"!R96-U<&5R87(@96P@9W5I\VX@86-T=6%L.B`H)60I("5S(@H*(SH@8FQA
M8VML:7-T+G!H<#HW,0IM<V=I9"`B17)R;W(@<V%V:6YG(&-H86YG97,N(@IM
M<V=S='(@(D5R<F]R(&%L(&=U87)D87(@;&]S(&-A;6)I;W,N(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR,@IM<V=I9"`B17AI<W1I;F<@
M4G5L97,B"FUS9W-T<B`B4F5G;&%S(&5X:7-T96YT97,B"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,S@S"FUS9VED(")%>&ES=',B"FUS9W-T<B`B17AI<W1E(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17AP96-T960@,2!O8FIE8W0L(&=O="`E9"XB"FUS9W-T<B`B4V4@97-P
M97)A8F$@,2!O8FIE=&\L('-E(&]B='5V;R`E9"XB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]S971T:6YG<RYI;F,Z,C`*;7-G:60@(D9I;'1E<B!!;&P@365S
M<V%G97,B"FUS9W-T<B`B1FEL=')A<B!T;V1O<R!L;W,@;65N<V%J97,B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,C(*;7-G:60@(D9I
M;'1E<B!/;FQY(%-E96X@365S<V%G97,B"FUS9W-T<B`B1FEL=')A<B!S\VQO
M(&QO<R!M96YS86IE<R!L9>UD;W,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S
M971T:6YG<RYI;F,Z,C$*;7-G:60@(D9I;'1E<B!/;FQY(%5N<V5E;B!-97-S
M86=E<R(*;7-G<W1R(")&:6QT<F%R('/S;&\@;&]S(&UE;G-A:F5S(&YO(&QE
M[61O<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHQ.`IM
M<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N97,@9&4@9FEL
M=')A9&\B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C(U"FUS9VED
M(")&:6QT97(@4G5L92(*;7-G<W1R(")296=L82!D92!F:6QT<F%D;R(*"B,Z
M(&9I;'1E<G,N<&AP.C$Q,PIM<V=I9"`B1FEL=&5R(%)U;&5S(@IM<V=S='(@
M(E)E9VQA<R(*"B,Z('-C<FEP="YP:'`Z-3(*;7-G:60@(D9I;'1E<B!38W)I
M<'0@1&ES<&QA>2(*;7-G<W1R(")-;W-T<F%R(&=U:?-N(&1E(&9I;'1R861O
M(@H*(SH@;&EB+TEN9V\N<&AP.C,R,@IM<V=I9"`B1FEL=&5R(%]2=6QE<R(*
M;7-G<W1R(")?4F5G;&%S(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S
M86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(B(*(D%C=&EV:61A9"!D96P@9FEL=')O.B!392!H82AN*2!C
M;W!I861O("5S(&UE;G-A:F4H<RD@82!L82!C87)P971A(%PB)7-<(BXB"@HC
M.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&1E
M;&5T960N(@IM<V=S='(@(D%C=&EV:61A9"!D96P@9FEL=')O.B!392!H82AN
M*2!E;&EM:6YA9&\@)7,@;65N<V%J92AS*2XB"@HC.B!L:6(O4V-R:7!T+VEM
M87`N<&AP.C(W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I
M='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD
M97(@7"(E<UPB+B(*;7-G<W1R("(B"B)!8W1I=FED860@9&5L(&9I;'1R;SH@
M4V4@:&$H;BD@=')A<VQA9&%D;R`E<R!M96YS86IE*',I(&$@;&$@8V%R<&5T
M82!<(B5S7"(N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HQ.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I
M('1H870@;6%T8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@9&5L971E9"XB"FUS
M9W-T<B`B(@HB06-T:79I9&%D(&1E;"!F:6QT<F\Z(%-E(&AA*&XI(&5L:6UI
M;F%D;R`E<R!M96YS86IE*',I(&EN8VQU:61O<R!E;B!L82!L:7-T82`B"B)N
M96=R82XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB
M)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I960@=&\@=&AE("(*(F9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*(D%C=&EV:61A9"!D96P@9FEL=')O
M.B!392!H82!C;W!I861O(&5L(&UE;G-A:F4@7"(E<UPB(&1E(%PB)7-<(B!A
M(&QA(&-A<G!E=&$@(@HB7"(E<UPB+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP
M:'`Z,CDV"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@
M5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(D%C=&EV:61A9"!D96P@9FEL=')O.B!392!H82!E;&EM
M:6YA9&\@96P@;65N<V%J92!<(B5S7"(@9&4@7"(E<UPB+B(*"B,Z(&QI8B]3
M8W)I<'0O:6UA<"YP:'`Z,C<S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D9I
M;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB
M(&AA<R!B965N(&UO=F5D('1O('1H92!F;VQD97(@(@HB7"(E<UPB+B(*;7-G
M<W1R("(B"B)!8W1I=FED860@9&5L(&9I;'1R;SH@4V4@:&$@=')A<VQA9&%D
M;R!E;"!M96YS86IE(%PB)7-<(B!D92!<(B5S7"(@82!L82`B"B)C87)P971A
M(%PB)7-<(BXB"@HC.B!R=6QE+G!H<#HQ-C`*;7-G:60@(D9I;'1E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N='+S(&5L(&9I;'1R;RXB"@HC
M.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C0R"FUS9VED(")&;W(@86X@
M:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z(@IM<V=S='(@(E!O<B!C
M861A(&UE;G-A:F4@96YT<F%N=&4@8V]I;F-I9&5N=&4@8V]N.B(*"B,Z(&9I
M;'1E<G,N<&AP.C$V-R!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHX
M(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C<*(SH@;&EB+T)L;V-K+V]V97)V
M:65W+G!H<#HV.0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")2965N=FEA<B(*
M"B,Z(&9O<G=A<F0N<&AP.C$V"FUS9VED(")&;W)W87)D(&ES(&YO="!S=7!P
M;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T
M<B`B16P@8V]N=')O;&%D;W(@9&4@9FEL=')A9&\@86-T=6%L(&YO('-O<&]R
M=&$@<F5E;G;M;W,N(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C@R
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(Q-`HC.B!L:6(O4V-R:7!T+VUA:6QD
M<F]P+G!H<#HR,C4*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E)E96YV[6]S
M(@H*(SH@9F]R=V%R9"YP:'`Z-#4*;7-G:60@(D9O<G=A<F1S($5D:70B"FUS
M9W-T<B`B36]D:69I8V%R(')E96YV[6]S(@H*(SH@8V]N9FEG+RYB86LO9FEE
M;&1S+G!H<"YD:7-T.C,Y"FUS9VED(")&<F]M(@IM<V=S='(@(D1E(@H*(SH@
M;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V,@IM<V=I9"`B1G)O;3HB"FUS9W-T
M<B`B1&4Z(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Y,`IM<V=I9"`B1W)E871E
M<B!T:&%N(@IM<V=S='(@(DUA>6]R('%U92(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS.3$*;7-G:60@(D=R96%T97(@=&AA;B!O<B!E<75A;"!T;R(*;7-G<W1R
M(")-87EO<B!O(&EG=6%L('%U92(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E
M<BYI;F,Z,S$*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R("));7!O<G1A;G1E
M(@H*(SH@<G5L92YP:'`Z,S8*;7-G:60@(DEN9&EV:61U86P@<G5L97,@87)E
M(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E
M<BXB"FUS9W-T<B`B16P@8V]N=')O;&%D;W(@9&4@9FEL=')A9&\@86-T=6%L
M(&YO('-O<&]R=&$@<F5G;&%S(&EN9&EV:61U86QE<RXB"@HC.B!L:6(O4V-R
M:7!T+W-I979E+G!H<#HQ.#8P"FUS9VED("));F5X:7-T86YT(&UA:6QB;W@@
M<W!E8VEF:65D(&9O<B!M97-S86=E(&1E;&EV97)Y+B(*;7-G<W1R(")392!H
M82!I;F1I8V%D;R!U;B!B=7KS;B!I;F5X:7-T96YT92!P87)A(&5N=NUO(&1E
M(&-O<G)E;RXB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S<W"FUS9VED("))<R(*
M;7-G<W1R(")%<R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-S@*;7-G:60@(DES
M;B=T(@IM<V=S='(@(DYO(&5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR
M,PIM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@
M3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+B(*
M;7-G<W1R("(B"B)392!P<F5C:7-A(&5L('-O<&]R=&4@3$1!4"P@<&5R;R!N
M;R!S92!D:7-P;VYE(&1E;"!M\V1U;&\@3$1!4"!O(&YO('-E(&AA("(*(F-A
M<F=A9&\N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X.`IM<V=I9"`B3&5S<R!T
M:&%N(@IM<V=S='(@(DUE;F]R('%U92(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS
M.#D*;7-G:60@(DQE<W,@=&AA;B!O<B!E<75A;"!T;R(*;7-G<W1R(")-96YO
M<B!O(&EG=6%L('%U92(*"B,Z(&-O;F9I9R\N8F%K+V9I96QD<RYP:'`N9&ES
M=#HU.0IM<V=I9"`B3&ES="U)1"(*;7-G<W1R("),:7-T+4E$(@H*(SH@=&5M
M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(P"FUS9VED(")-87)?
M:R!M97-S86=E(&%S(&1E;&5T960B"FUS9W-T<B`B7U-E\6%L87(@;65N<V%J
M92!C;VUO(&5L:6UI;F%D;R(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI
M;F,Z,C0*;7-G:60@(DUA<FL@;65S<V%G92!A<SHB"FUS9W-T<B`B4V7Q86QA
M<B!M96YS86IE(&-O;6\Z(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X-@IM<V=I
M9"`B36%T8VAE<R`H=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S='(@(D-O:6YC
M:61E("AC;VX@8V]M;V1I;F5S*2(*"B,Z(&QI8B]A<&DN<&AP.C4W"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!2=6QE<R(*;7-G<W1R(").^FUE<F\@;>%X
M:6UO(&1E(')E9VQA<R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HU,3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@8FQA8VML:7-T
M960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S97,Z("5S+"`B
M"B)-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@
M861D<F5S<V5S('1O(&)L86-K;&ES="XB"FUS9W-T<B`B(@HB4V4@:&$@<W5P
M97)A9&\@96P@;OIM97)O(&WA>&EM;R!D92!D:7)E8V-I;VYE<R!E;B!U;F$@
M;&ES=&$@;F5G<F$@*%1O=&%L(&1E("(*(F1I<F5C8VEO;F5S.B`E<RP@3KH@
M;>%X+B!D92!D:7)E8V-I;VYE<SH@)7,I+B!.;R!S92!P=65D96X@8?%A9&ER
M(&WA<R`B"B)D:7)E8V-I;VYE<R!A(&QA(&QI<W1A(&YE9W)A+B(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HU-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X
M:6UU;2!N=6UB97(@;V8@=VAI=&5L:7-T960@861D<F5S<V5S(&5X8V5E9&5D
M("A4;W1A;"!A9&1R97-S97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@
M)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O('=H:71E;&ES
M="XB"FUS9W-T<B`B(@HB4V4@:&$@<W5P97)A9&\@96P@;OIM97)O(&WA>&EM
M;R!D92!D:7)E8V-I;VYE<R!E;B!U;F$@;&ES=&$@8FQA;F-A("A4;W1A;"!D
M92`B"B)D:7)E8V-I;VYE<SH@)7,L($ZZ(&WA>"X@9&4@9&ER96-C:6]N97,Z
M("5S*2X@3F\@<V4@<'5E9&5N(&'Q861I<B!MX7,@(@HB9&ER96-C:6]N97,@
M82!L82!L:7-T82!B;&%N8V$N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,C`W,`IM<V=I9"`B36ES<VEN9R!A9&1R97-S('1O(&YO=&EF>2(*;7-G<W1R
M(")&86QT82!L82!D:7)E8V-I\VX@82!L82!Q=64@96YV:6%R(&QA(&YO=&EF
M:6-A8VGS;B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W,C@*;7-G:60@
M(DUI<W-I;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O(@IM<V=S
M='(@(D9A;'1A(&QA(&1I<F5C8VGS;B!A(&QA('%U92!R961I<FEG:7(@96P@
M;65N<V%J92(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W-C`*;7-G:60@
M(DUI<W-I;F<@<F5A<V]N(&9O<B!R96IE8W0B"FUS9W-T<B`B1F%L=&$@96P@
M;6]T:79O(&1E;"!R96-H87IO(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,3DR-PIM<V=I9"`B36ES<VEN9R!R96%S;VX@:6X@=F%C871I;VXN(@IM<V=S
M='(@(D9A;'1A(&5L(&UO=&EV;R!D92!L82!A=7-E;F-I82XB"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(Y"FUS9VED(")-;W9E(@IM<V=S
M='(@(E1R87-L861A<B(*"B,Z(&9I;'1E<G,N<&AP.C$S,2!F:6QT97)S+G!H
M<#HR-#`*;7-G:60@(DUO=F4@4G5L92!$;W=N(@IM<V=S='(@(D)A:F%R(&QA
M(')E9VQA(@H*(SH@9FEL=&5R<RYP:'`Z,3,R(&9I;'1E<G,N<&AP.C(S.0IM
M<V=I9"`B36]V92!2=6QE(%5P(@IM<V=S='(@(E-U8FER(&QA(')E9VQA(@H*
M(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHT,@IM<V=I9"`B
M3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C871I;VX@<F5P;&EE<SHB"FUS
M9W-T<B`B3OIM97)O(&1E(%]D[6%S(&5N=')E(')E<W!U97-T87,@<&]R(&%U
M<V5N8VEA.B(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN
M8SHS('1E;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z-0HC.B!L:6(O4W1O
M<F%G92YP:'`Z-S<Q"FUS9VED(").97<@4G5L92(*;7-G<W1R(").=65V82!R
M96=L82(*"B,Z(&QI8B]);F=O+G!H<#HR,38@;&EB+TEN9V\N<&AP.C(Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!<(B5S7"(@96QE;65N="!F;W5N9"!I
M;B!B86-K96YD(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&5N
M8V]N=')A9&\@=6X@96QE;65N=&\@7"(E<UPB(&5N(&QA(&-O;F9I9W5R86-I
M\VX@9&5L(&UO=&]R+B(*"B,Z(&QI8B]);F=O+G!H<#HR,30*;7-G:60@(DYO
M(&)A8VME;F0@8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T(@IM<V=S='(@(DYO
M('-E(&AA(&-O;F9I9W5R861O('5N(&UO=&]R('!A<F$@97-T92!S97)V:61O
M<B(*"B,Z(&QI8B]);F=O+G!H<#HQ.3$*;7-G:60@(DYO(&)A8VME;F1S(&-O
M;F9I9W5R960@:6X@8F%C:V5N9',N<&AP(@IM<V=S='(@(DYO('-E(&AA;B!C
M;VYF:6=U<F%D;R!M;W1O<F5S(&5N(&)A8VME;F1S+G!H<"(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHS"B,L('!H<"UF;W)M870*
M;7-G:60@(DYO(&9I;'1E<G,N($-L:6-K(%PB)7-<(B!T;R!C<F5A=&4@82!N
M97<@9FEL=&5R+B(*;7-G<W1R(")3:6X@9FEL=')O<RX@4'5L<V4@7"(E<UPB
M('!A<F$@8W)E87(@=6YO+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$S
M,S(@;&EB+U-C<FEP="]S:65V92YP:'`Z,30R-0HC.B!L:6(O4V-R:7!T+W-I
M979E+G!H<#HQ-3DY"FUS9VED(").;R!H96%D97)S('-P96-I9FEE9"(*;7-G
M<W1R(").;R!S92!H86X@97-P96-I9FEC861O(&-A8F5C97)A<R(*"B,Z('-C
M<FEP="YP:'`Z-C<*;7-G:60@(DYO('-C<FEP="!G96YE<F%T960N(@IM<V=S
M='(@(DYO('-E(&AA(&=E;F5R861O(&YI;F?Z;B!G=6GS;BXB"@HC.B!L:6(O
M4V-R:7!T+W-I979E+G!H<#HQ-C$T"FUS9VED(").;R!S=')I;F=S('-P96-I
M9FEE9"(*;7-G<W1R(").;R!S92!H86X@97-P96-I9FEC861O(&-A9&5N87,B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,SDS"FUS9VED(").;W0@97%U86P@=&\B
M"FUS9W-T<B`B1&ES=&EN=&\@9&4B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4S
M"FUS9VED(").;W1I9GD@96UA:6P@861D<F5S<R(*;7-G<W1R(")$:7)E8V-I
M\VX@9&4@8V]R<F5O(&1E(&%V:7-O<R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS
M-#<*;7-G:60@(D]N;'D@9FQA9R!T:&4@;65S<V%G92(*;7-G<W1R(")3\VQO
M(&UA<F-A<B!E;"!M96YS86IE(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,3D*;7-G:60@(D]P=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG
M+B(*;7-G<W1R(")/<&-I;VYE<R!D92!A8W1U86QI>F%C:?-N(&1E(&=U:6]N
M97,N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@
M(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B3W1R87,@;W!C:6]N97,B"@HC.B!L
M:6(O0FQO8VLO;W9E<G9I97<N<&AP.C,*;7-G:60@(D]V97)V:65W(@IM<V=S
M='(@(DEN=')O9'5C8VGS;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VYE
M=U]F;VQD97(N:G,Z-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F
M('1H92!N97<@9F]L9&5R.B(*;7-G<W1R("));G1R;V1U>F-A(&5L(&YO;6)R
M92!D92!L82!N=65V82!C87)P971A.B(*"B,Z('1E;7!L871E<R]V86-A=&EO
M;B]V86-A=&EO;BYI;F,Z-C`*;7-G:60@(E)?96%S;VXB"FUS9W-T<B`B7TUO
M=&EV;R(*"B,Z(&-O;F9I9R\N8F%K+V9I96QD<RYP:'`N9&ES=#HV,PIM<V=I
M9"`B4F5C96EV960B"FUS9W-T<B`B4F5C:6)I9&\B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S(X"FUS9VED(")2961I<F5C="!T;R(*;7-G<W1R(")2961I<FEG
M:7(@82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#4*;7-G:60@(E)E9W5L87(@
M97AP<F5S<VEO;B(*;7-G<W1R(")%>'!R97-I\VX@<F5G=6QA<B(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HS-#,*;7-G:60@(E)E:F5C="!W:71H(')E87-O;B(*
M;7-G<W1R(")296-H87IA<B!C;VX@;6]T:79O(@H*(SH@8V]N9FEG+RYB86LO
M9FEE;&1S+G!H<"YD:7-T.C4U"FUS9VED(")297-E;G0@5&\B"FUS9W-T<B`B
M4F5E;G9I87(@82(*"B,Z(&-O;F9I9R\N8F%K+V9I96QD<RYP:'`N9&ES=#HU
M,0IM<V=I9"`B4F5S96YT+69R;VTB"FUS9W-T<B`B4F5E;G9I861O+7!O<B(*
M"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-C`*;7-G:60@(E)E='5R
M;B!T;R!&:6QT97)S($QI<W0B"FUS9W-T<B`B4F5G<F5S87(@86P@;&ES=&%D
M;R!D92!F:6QT<F]S(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI
M<W0N:6YC.C(T('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT
M,0HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C<Q('1E;7!L
M871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,T"FUS9VED(")2971U<FX@=&\@
M4G5L97,@3&ES="(*;7-G<W1R(")296=R97-A<B!A;"!L:7-T861O(&1E(')E
M9VQA<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C<*;7-G
M:60@(E)U;&4B"FUS9W-T<B`B4F5G;&$B"@HC.B!F:6QT97)S+G!H<#HV,PIM
M<V=I9"`B4G5L92!#;W!I960B"FUS9W-T<B`B4V4@:&$@8V]P:6%D;R!L82!R
M96=L82(*"B,Z(&9I;'1E<G,N<&AP.C0R"FUS9VED(")2=6QE($1E;&5T960B
M"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&QA(')E9VQA(@H*(SH@9FEL=&5R
M<RYP:'`Z-SD*;7-G:60@(E)U;&4@1&ES86)L960B"FUS9W-T<B`B4F5G;&$@
M9&5S86-T:79A9&$B"@HC.B!F:6QT97)S+G!H<#HX-`IM<V=I9"`B4G5L92!%
M;F%B;&5D(@IM<V=S='(@(E)E9VQA(&%C=&EV861A(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O:&5A9&5R+FEN8SHS,PIM<V=I9"`B4G5L92!.86UE(@IM<V=S='(@
M(DYO;6)R92!D92!L82!R96=L82(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP
M.C(P-C0*;7-G:60@(E)U;&4Z(@IM<V=S='(@(E)E9VQA.B(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E14
M3%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(DAA(&9A;&QA9&\@4U1!4E14
M3%,Z("@E<RD@)7,B"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES
M="YI;F,Z,C,@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C0P
M"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-S`@=&5M<&QA
M=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,S,*(SH@=&5M<&QA=&5S+W)U;&4O
M9F]O=&5R+FEN8SHU.0IM<V=I9"`B4V%V92(*;7-G<W1R(")'=6%R9&%R(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(Y"FUS9VED(")3
M879E(%-E='1I;F=S(@IM<V=S='(@(D=U87)D87(@;W!C:6]N97,B"@HC(+]$
M\VYD92!E<W3A/PHC.B!T96UP;&%T97,O<V-R:7!T+VAE861E<BYI;F,Z,@IM
M<V=I9"`B4V-R:7!T(@IM<V=S='(@(D=U:?-N(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*;7-G
M<W1R(")!8W1U86QI>F%C:?-N(&1E(&=U:?-N(@H*(SH@;&EB+TEN9V\N<&AP
M.C(S.0IM<V=I9"`B4V-R:7!T(&YO="!U<&1A=&5D+B(*;7-G<W1R(").;R!S
M92!H82!A8W1U86QI>F%D;R!E;"!G=6GS;BXB"@HC.B!L:6(O26YG;RYP:'`Z
M,30Q"FUS9VED(")38W)I<'0@<W5C8V5S<V9U;&QY(&%C=&EV871E9"XB"FUS
M9W-T<B`B4V4@:&$@86-T:79A9&\@8V]R<F5C=&%M96YT92!E;"!G=6GS;BXB
M"@HC.B!L:6(O26YG;RYP:'`Z,30P"FUS9VED(")38W)I<'0@<W5C8V5S<V9U
M;&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")392!H82!D97-A8W1I=F%D;R!C
M;W)R96-T86UE;G1E(&5L(&=U:?-N+B(*"B,Z('1E;7!L871E<R]R=6QE+V9O
M;W1E<BYI;F,Z,CD*;7-G:60@(E-E96XB"FUS9W-T<B`B3&7M9&\B"@HC.B!R
M=6QE+G!H<#HQ.3`*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(E-E
M;&5C8VEO;F4@=6X@8V%M<&\B"@HC.B!L:6(O26YG;RYP:'`Z-3D*;7-G:60@
M(E-E;&5C="!T87)G970@9F]L9&5R(@IM<V=S='(@(E-E;&5C8VEO;F4@8V%R
M<&5T82!D97-T:6YO(@H*(SH@<G5L92YP:'`Z,C(W"FUS9VED(")396QF+41E
M9FEN960@2&5A9&5R(@IM<V=S='(@(D-A8F5C97)A($%U=&\M1&5F:6YI9&$B
M"@HC.B!C;VYF:6<O+F)A:R]F:65L9',N<&AP+F1I<W0Z,S4*;7-G:60@(E-E
M;F1E<B(*;7-G<W1R(")296UI=&5N=&4B"@HC.B!F:6QT97)S+G!H<#HY.`IM
M<V=I9"`B4V5T=&EN9W,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S='(@
M(E-E(&AA;B!A8W1U86QI>F%D;R!C;W)R96-T86UE;G1E(&QA<R!O<&-I;VYE
M<RXB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHR-`IM<V=I
M9"`B4VAO=R!!8W1I=F4@4V-R:7!T(@IM<V=S='(@(DUO<W1R87(@9W5I\VX@
M86-T:79O(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,S$*
M;7-G:60@(E-H;W<@0W5R<F5N="!38W)I<'0B"FUS9W-T<B`B36]S=')A<B!G
M=6GS;B!A8W1U86PB"@HC.B!C;VYF:6<O+F)A:R]F:65L9',N<&AP+F1I<W0Z
M.#,*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%M8?%O(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O9F]O=&5R+FEN8SHT.0IM<V=I9"`B4W1O<"!C:&5C:VEN9R!I9B!T
M:&ES(')U;&4@;6%T8VAE<S\B"FUS9W-T<B`BOT1E=&5N97(@8V]M<')O8F%C
M:?-N('-I(&5S=&$@<F5G;&$@8V]I;F-I9&4_(@H*(SH@=&5M<&QA=&5S+W9A
M8V%T:6]N+W9A8V%T:6]N+FEN8SHU,0IM<V=I9"`B4W5B:F5?8W0@;V8@=F%C
M871I;VX@;65S<V%G93HB"FUS9W-T<B`B7T%S=6YT;R!D96P@;65N<V%J92!D
M92!A=7-E;F-I83HB"@HC.B!C;VYF:6<O+F)A:R]F:65L9',N<&AP+F1I<W0Z
M,S$*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B07-U;G1O(@H*(SH@;&EB+U-C
M<FEP="]S:65V92YP:'`Z,C`V,PIM<V=I9"`B4W5B:F5C=#HB"FUS9W-T<B`B
M07-U;G1O.B(*"B,Z(&QI8B]A<&DN<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!A9&1R97-S(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R
M(&)L86-K;&ES="XB"FUS9W-T<B`B4V4@:&$@8?%A9&ED;R!L82!D:7)E8V-I
M\VX@7"(E<UPB(&$@;&$@;&ES=&$@;F5G<F$N(@H*(SH@;&EB+V%P:2YP:'`Z
M,3`T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(%PB)7-<(B!H
M87,@8F5E;B!A9&1E9"!T;R!Y;W5R('=H:71E;&ES="XB"FUS9W-T<B`B4V4@
M:&$@8?%A9&ED;R!L82!D:7)E8V-I\VX@7"(E<UPB(&$@;&$@;&ES=&$@8FQA
M;F-A+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S8*;7-G:60@(E1H92!D<FEV97(@
M<V%I9#H@(@IM<V=S='(@(D5L(&-O;G1R;VQA9&]R(&1I:F\Z("(*"B,Z(&QI
M8B]);F=O+G!H<#HQ,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8W1I
M=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@97)R
M;W(@86P@86-T:79A<B!E;"!G=6GS;BXB"@HC.B!L:6(O26YG;RYP:'`Z,3,T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5A8W1I=F%T:6YG('1H92!S
M8W)I<'0N(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@9&5S86-T
M:79A<B!E;"!G=6GS;BXB"@HC.B!C;VYF:6<O+F)A:R]F:65L9',N<&AP+F1I
M<W0Z,C<*;7-G:60@(E1O(@IM<V=S='(@(E!A<F$B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]F:6QT97(N:'1M;#HR,0IM<V=I9"`B5&\Z(@IM<V=S='(@(E!A
M<F$Z(@H*(SH@;&EB+U-C<FEP="YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R("));F-A<&%Z(&1E(&-A<F=A<B!L82!D969I;FEC:?-N(&1E("5S+B(*
M"B,Z(&9I;'1E<G,N<&AP.C$V,2!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C4*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C8R(&QI8B]3
M8W)I<'0O<VEE=F4N<&AP.C,U,@HC.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP
M.C8P(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C(*;7-G:60@(E9A8V%T:6]N
M(@IM<V=S='(@(D%U<V5N8VEA(@H*(SH@=F%C871I;VXN<&AP.C<Q"FUS9VED
M(")686-A=&EO;B!%9&ET(@IM<V=S='(@(DUO9&EF:6-A<B!N;W1I9FEC86-I
M\VX@9&4@875S96YC:6$B"@HC.B!V86-A=&EO;BYP:'`Z,38*;7-G:60@(E9A
M8V%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R
M:6YG(&1R:79E<BXB"FUS9W-T<B`B(@HB16P@8V]N=')O;&%D;W(@9&4@9FEL
M=')A9&\@86-T=6%L(&YO('-O<&]R=&$@;F]T:69I8V%C:6]N97,@9&4@875S
M96YC:6$N(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC
M.C$V"FUS9VED(")7:%]I=&5L:7-T(&%D9')E<W-E<SHB"FUS9W-T<B`B1&ER
M96-C:6]N97,@9&4@;&ES=&$@7V)L86YC83HB"@HC.B!F:6QT97)S+G!H<#HQ
M-34@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C@*(SH@;&EB
M+T)L;V-K+V]V97)V:65W+G!H<#HW.2!L:6(O0FQO8VLO;W9E<G9I97<N<&AP
M.C@R"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B3&ES=&$@8FQA;F-A(@H*
M(SH@=VAI=&5L:7-T+G!H<#HU-0IM<V=I9"`B5VAI=&5L:7-T($5D:70B"FUS
M9W-T<B`B36]D:69I8V%R(&QI<W1A(&)L86YC82(*"B,Z('=H:71E;&ES="YP
M:'`Z,3@*;7-G:60@(E=H:71E;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H
M92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(D5L(&-O;G1R
M;VQA9&]R(&1E(&9I;'1R861O(&%C='5A;"!N;R!S;W!O<G1A(&QI<W1A(&)L
M86YC87,N(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C,T(&QI8B]3
M8W)I<'0O<VEE=F4N<&AP.C(Y.`HC.B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H
M<#HR,#,*;7-G:60@(E=H:71E;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R(")$
M:7)E8V-I;VYE<R!I;F-L=6ED87,@96X@;&$@;&ES=&$@8FQA;F-A(@H*(SH@
M8V]N9FEG+RYB86LO9FEE;&1S+G!H<"YD:7-T.C<Y"FUS9VED(")8+5!R:6]R
M:71Y(@IM<V=S='(@(E@M4')I;W)I='DB"@HC.B!C;VYF:6<O+F)A:R]F:65L
M9',N<&AP+F1I<W0Z-C<*;7-G:60@(E@M4W!A;2U,979E;"(*;7-G<W1R(")8
M+5-P86TM3&5V96PB"@HC.B!C;VYF:6<O+F)A:R]F:65L9',N<&AP+F1I<W0Z
M-S$*;7-G:60@(E@M4W!A;2U38V]R92(*;7-G<W1R(")8+5-P86TM4V-O<F4B
M"@HC.B!C;VYF:6<O+F)A:R]F:65L9',N<&AP+F1I<W0Z-S4*;7-G:60@(E@M
M4W!A;2U3=&%T=7,B"FUS9W-T<B`B6"U3<&%M+5-T871U<R(*"B,Z(&9I;'1E
M<G,N<&AP.C4V(')U;&4N<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@<G5L
M97,N(@IM<V=S='(@(DYO(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!C
M<F5A<B!MX7,@9&4@)60@<F5G;&%S+B(*"B,Z(&9I;'1E<G,N<&AP.C0X(')U
M;&4N<&AP.C(Q"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T
M92!O<B!E9&ET(&-U<W1O;2!R=6QE<RXB"FUS9W-T<B`B(@HB3F\@9&ES<&]N
M92!D92!P<FEV:6QE9VEO<R!P87)A(&-R96%R(&\@;6]D:69I8V%R(')E9VQA
M<R!P97)S;VYA;&EZ861A<RXB"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HR
M,#8Q"FUS9VED(")9;W4@:&%V92!R96-E:79E9"!A(&YE=R!M97-S86=E(@IM
M<V=S='(@(DAA(')E8VEB:61O('5N(&UE;G-A:F4@;G5E=F\B"@HC.B!V86-A
M=&EO;BYP:'`Z,S`*;7-G:60@(B(*(EEO=2!M=7-T('-P96-I9GD@870@;&5A
M<W0@;VYE(&5M86EL(&%D9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M
M97-S86=E<R`B"B)S:&]U;&0@8F4@86-T:79A=&5D+B(*;7-G<W1R("(B"B)4
M:65N92!Q=64@97-P96-I9FEC87(@86P@;65N;W,@=6YA(&1I<F5C8VGS;B!D
M92!C;W)R96\@<&%R82!L82!Q=64@86-T:79A<B`B"B)L;W,@;65N<V%J97,@
M9&4@875S96YC:6$N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR-S0@;&EB
M+U-C<FEP="]I;6%P+G!H<#HR.3<@;&EB+U-C<FEP="]I;6%P+G!H<#HS,3$*
M;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");4VEN(&%S=6YT;UTB"@HC
M.B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHR-`IM<V=I9"`B7T%D
M9')E<W,H97,I('1O(&9O<G=A<F0@=&\Z(@IM<V=S='(@(D1I<F5C8VEO;F5S
M(&$@;&%S('%U92!?<F5E;G9I87(Z(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N
M+W9A8V%T:6]N+FEN8SHR,PIM<V=I9"`B7T%D9')E<W-E<R!T;R!N;W0@<V5N
M9"!R97-P;VYS97,@=&\Z(@IM<V=S='(@(D1I<F5C8VEO;F5S(&$@;&%S('%U
M92!N;R!S92!E;E]V[6%N(')E<W!U97-T87,Z(@H*(SH@;&EB+TEN9V\N<&AP
M.C,R-PIM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R("),:7-T82!?;F5G<F$B
M"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,3@*;7-G
M:60@(E]$96QE=&4@;65S<V%G92!C;VUP;&5T96QY(@IM<V=S='(@(E]%;&EM
M:6YA<B!C;VUP;&5T86UE;G1E(&5L(&UE;G-A:F4B"@HC.B!T96UP;&%T97,O
M8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,S$*;7-G:60@(E]%;G1E<B!E86-H
M(&%D9')E<W,@;VX@82!N97<@;&EN93HB"FUS9W-T<B`B7TEN=')O9'5C:7(@
M8V%D82!D:7)E8V-I\VX@96X@=6YA(&SM;F5A(&1I<W1I;G1A.B(*"B,Z(&QI
M8B]);F=O+G!H<#HS,S,*;7-G:60@(E]&;W)W87)D(@IM<V=S='(@(E]2965N
M=FEA<B(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C$W"FUS
M9VED(")?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT
M/R(*;7-G<W1R("*_0V]N<V5R=F%R('5N82!?8V]P:6$@9&4@;&]S(&UE;G-A
M:F5S(&5N(&5S=&$@:61E;G1I9&%D/R(*"B,Z('1E;7!L871E<R]B;&%C:VQI
M<W0O8FQA8VML:7-T+FEN8SHR,@IM<V=I9"`B7TUO=F4@;65S<V%G92!T;R!F
M;VQD97(Z(@IM<V=S='(@(E]4<F%S;&%D87(@;65N<V%J97,@82!L82!C87)P
M971A.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,3,*
M;7-G:60@(E]->2!E;6%I;"!A9&1R97-S97,Z(@IM<V=S='(@(E]-:7,@9&ER
M96-C:6]N97,@9&4@8V]R<F5O.B(*"B,@OT3S;F1E(&5S=.$_"B,Z(&QI8B])
M;F=O+G!H<#HS,S8*;7-G:60@(E]38W)I<'0B"FUS9W-T<B`B7T=U:?-N(@H*
M(SH@;&EB+TEN9V\N<&AP.C,S,`IM<V=I9"`B7U9A8V%T:6]N(@IM<V=S='(@
M(D%?=7-E;F-I82(*"B,Z(&QI8B]);F=O+G!H<#HS,C0*;7-G:60@(E]7:&ET
M96QI<W0B"FUS9W-T<B`B3&ES=&$@7V)L86YC82(*"B,Z(&QI8B]";&]C:R]O
M=F5R=FEE=RYP:'`Z-30*;7-G:60@(F%C=&EV92(*;7-G<W1R(")A8W1I=F\B
M"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C0*;7-G:60@(F%N9"(*
M;7-G<W1R(")Y(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+FAT;6PZ
M,3,*;7-G:60@(F1I<V%B;&5D("T@8VQI8VL@=&\@96YA8FQE(@IM<V=S='(@
M(F1E<V%C=&EV861A("T@<'5L<V4@<&%R82!A8W1I=F%R;&$B"@HC.B!F:6QT
M97)S+G!H<#HQ.#4*;7-G:60@(F9I96QD(@IM<V=S='(@(F-A;7!O(@H*(SH@
M;&EB+T)L;V-K+V]V97)V:65W+G!H<#HU,@IM<V=I9"`B:6YA8W1I=F4B"FUS
M9W-T<B`B:6YA8W1I=F\B"@HC.B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HQ
M,C$*;7-G:60@(FUA:6QD<F]P('-C<FEP="!G96YE<F%T960@8GD@26YG;R(*
M;7-G<W1R(")G=6GS;B!M86EL9')O<"!G96YE<F%D;R!P;W(@26YG;R(*"B,Z
M(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B;6%T8V@B"FUS9W-T<B`B8V]I;F-I
M9&ER(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")O
M<B(*;7-G<W1R(")O(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,3(X
M"FUS9VED(")P<F]C;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\B"FUS
M9W-T<B`B9W5I\VX@<')O8VUA:6P@9V5N97)A9&\@<&]R($EN9V\B"@HC.B!L
M:6(O4V-R:7!T+W-I979E+G!H<#HQ,3`*;7-G:60@(G-I979E(&9I;'1E<B!G
M96YE<F%T960@8GD@26YG;R(*;7-G<W1R(")F:6QT<F\@9&4@=&%M:7H@9V5N
M97)A9&\@<&]R($EN9V\B"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEN9V\O<&\O>FA?5%<N<&\`````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#<S-C,`,3`T,3<S-C(W-#<`,#$W
M-#`V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",@24Y'3R!4<F%D:71I;VYA;"!#:&EN97-E(%1R86YS;&%T:6]N"B,@0V]P
M>7)I9VAT("A#*2`R,#`R($1A=FED($-H86YG+K%IJ'VDY2RE>,97"B,@5&AI
M<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@
M87,@=&AE($E.1T\@<&%C:V%G92X*(R!$879I9"!#:&%N9R`\9&%V:61`=&UV
M+F=O=BYT=SXL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T
M+4ED+59E<G-I;VXZ(&EN9V\M,"XQ(&-V<UQN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`Q+3`U(#$U.C`T*S`X,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#,M,#(M,3$@,#<Z-3,K,#@P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!$879I9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SY<;B(*(DQA;F=U86=E
M+51E86TZ(%1R861I=&EO;F%L($-H:6YE<V4@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U"24<U7&XB"B)#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F:6QT97)S+G!H<#HQ.#4*;7-G:60@
M(B!A;F0B"FUS9W-T<B`B(*;3I4(B"@HC.B!F:6QT97)S+G!H<#HQ.#4*;7-G
M:60@(B!O<B(*;7-G<W1R("(@J<ZJS"(*"B,Z('1E;7!L871E<R]B;&%C:VQI
M<W0O8FQA8VML:7-T+FEN8SHQ-PIM<V=I9"`B06-T:6]N(&9O<B!B;&%C:VQI
M<W1E9"!A9&1R97-S97,Z(@IM<V=S='(@(J9#I$JVPJ97L^:K2*7SJKJS0K)Z
MI.BFH3HB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ,`IM
M<V=I9"`B06-T:79A=&4@4V-R:7!T(@IM<V=S='(@(K'2I<XB"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!8W1I
M=F%T:6YG('1H92!S8W)I<'0@9F]R(%PB)7-<(B!F86EL960Z("@E9"D@)7,B
M"FUS9W-T<B`BL=*ESKE,PF^U>Z:A(%PB)7-<(B"NR:6BL=$Z("@E9"D@)7,B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z-@IM<V=I9"`B
M061D:71I;VYA;"!3971T:6YG<R(*;7-G<W1R("*V:;:E(@H*(SH@=&5M<&QA
M=&5S+W)U;&4O:&5A9&5R+FEN8SHT-`IM<V=I9"`B06QL(&]F('1H92!F;VQL
M;W=I;F<B"FUS9W-T<B`BJ=*FLZ15ID.Q^*7S(@H*(SH@;&EB+V%P:2YP:'`Z
M-30*;7-G:60@(D%L;&]W(%)U;&5S(@IM<V=S='(@(J2YLURS5ZMH(@H*(SH@
M=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,PIM<V=I9"`B06YS=V5R960B
M"FUS9W-T<B`BI'>F7L+0(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN
M8SHT-0IM<V=I9"`B06YY(&]F('1H92!F;VQL;W=I;F<B"FUS9W-T<B`BI?2F
M\Z15ID.Q^*7S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHQ
M,0IM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R("*N3:7.JTBE\[E,PF\B
M"@HC.B!F:6QT97)S+G!H<#HR,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/R(*;7-G<W1R("*G0;U4J7>M;J=2
ML*.S;ZW3LU>K:+;</R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM
M<V=I9"`B075T;VUA=&EC86QL>2!U<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E
M86-H(&-H86YG93\B"FUS9W-T<B`BJ$.W[::SLJ>PRJ[)K$^G7Z;;L,JG\[=S
MIKFY3,)OM7NFH3\B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C0W"FUS
M9VED(")"8V,B"FUS9W-T<B`BK[6E\[#&I;LB"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S4Q"FUS9VED(")"96=I;G,@=VET:"(*;7-G<W1R("*V?<!9K$\B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C$P-B!L:6(O1')I=F5R+VQD87`N<&AP
M.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@*"5S*2`E
M<R(*;7-G<W1R("*S<[6RI:*QT3H@*"5S*2`E<R(*"B,Z(&9I;'1E<G,N<&AP
M.C$T-"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z-PHC.B!L
M:6(O0FQO8VLO;W9E<G9I97<N<&AP.C@T(&QI8B]";&]C:R]O=F5R=FEE=RYP
M:'`Z.#<*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R("*VPJ97L^8B"@HC.B!B
M;&%C:VQI<W0N<&AP.C$P,`IM<V=I9"`B0FQA8VML:7-T($5D:70B"FUS9W-T
M<B`BO7._Z+;"IE>SYB(*"B,Z(&)L86-K;&ES="YP:'`Z,3<*;7-G:60@(D)L
M86-K;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E
M<FEN9R!D<FEV97(N(@IM<V=S='(@(J78JV6JNKE,PF^^N<58L,JU>Z:AJ,.E
MO*3DM*FVPJ97L^:JNJ5<K^`N(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP
M:'`Z,C`W(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(T-`HC.B!L:6(O4V-R:7!T
M+VUA:6QD<F]P+G!H<#HQ-S4*;7-G:60@(D)L86-K;&ES=&5D($%D9')E<W-E
M<R(*;7-G<W1R("*D=[-1ID.LL+;"IE>SYJJZMFRE\Z9AIWTB"@HC.B!C;VYF
M:6<O9FEE;&1S+G!H<"YD:7-T.C@X"FUS9VED(")";V1Y(@IM<V=S='(@(J6[
MI.4B"@HC.B!F:6QT97)S+G!H<#HQ.#(@<G5L92YP:'`Z,C@Q"FUS9VED(")#
M87-E(%-E;G-I=&EV92(*;7-G<W1R("*PSZ3`I&JD<+QG(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HT,PIM<V=I9"`B0V,B"FUS9W-T<B`BL,:ENR(*
M"B,Z(')U;&4N<&AP.C$R,B!W:&ET96QI<W0N<&AP.C,V(&9O<G=A<F0N<&AP
M.C,S('9A8V%T:6]N+G!H<#HT,0HC.B!B;&%C:VQI<W0N<&AP.C8Y"FUS9VED
M(")#:&%N9V5S('-A=F5D+B(*;7-G<W1R("*D=\!XIG/%W*?S(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HW-0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E
M(@IM<V=S='(@(K-SM;*EHK'1(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-PIM
M<V=I9"`B0V]N=&%I;G,B"FUS9W-T<B`BI5VG="(*"B,Z(&9I;'1E<G,N<&AP
M.C(R-2!F:6QT97)S+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P
M>2`E<R(*;7-G<W1R("*]QKMS("5S(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C<Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&]F("5S(@IM<V=S='(@(B5S
M(*JZO<:[<R(*"B,Z(&QI8B]);F=O+G!H<#HU,@IM<V=I9"`B0W)E871E(&YE
M=R!F;VQD97(B"FUS9W-T<B`BJ]BEW[=SJTBE\Z=8(@H*(SH@;&EB+U-C<FEP
M="]P<F]C;6%I;"YP:'`Z,S,V(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(W
M.0IM<V=I9"`B1$E304),140Z("(*;7-G<W1R("*D=["QI<XZ("(*"B,Z('1E
M;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$W"FUS9VED(")$96%C=&EV
M871E(%-C<FEP="(*;7-G<W1R("*PL:7.(@H*(SH@9FEL=&5R<RYP:'`Z,C$T
M(&9I;'1E<G,N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M)7,B"FUS9W-T<B`BIU*PHR`E<R(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E
M<BYI;F,Z,S`*;7-G:60@(D1E;&5T92!#;VYD:71I;VXB"FUS9W-T<B`BIU*P
MH['XI?,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,CDU"FUS9VED(")$96QE=&4@
M;65S<V%G92!C;VUP;&5T96QY(@IM<V=S='(@(KG]J;.G4K"CJTBE\R(*"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S4*;7-G:60@(D1E;&5T960B
M"FUS9W-T<B`BI'>G4K"C(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C(X,PIM<V=I
M9"`B1&5L:79E<B!I;G1O(&UY($E.0D]8(@IM<V=S='(@(KN\L&6H[*?:JKJF
MK*7SO6,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S`Y"FUS9VED(")$96QI=F5R
M(&EN=&\@;7D@24Y"3U@@86YD(&-O<'D@=&\B"FUS9W-T<B`BN[RP9:CLI]JJ
MNJ:LI?.]8ZC#I4*]QKMSJ.PB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S`T"FUS
M9VED(")$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(')E9&ER96-T('1O(@IM
M<V=S='(@(KN\L&6H[*?:JKJFK*7SO6.HPZ5"PN"G?;N\L&6H["(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HR.#D*;7-G:60@(D1E;&EV97(@=&\@9F]L9&5R(@IM
M<V=S='(@(KN\L&6H[*M(I?.G6"(*"B,Z(&9I;'1E<G,N<&AP.C(T,2!F:6QT
M97)S+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ES86)L92`E<R(*
M;7-G<W1R("*PL:7.("5S(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET
M96QI<W0N:6YC.C$P('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN
M8SHQ,`HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C8@=&5M
M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W)U
M;&4O:&5A9&5R+FEN8SHR-@IM<V=I9"`B1&ES86)L960B"FUS9W-T<B`BI'>P
ML:7.(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C$S"FUS
M9VED(")$:7-P;&%Y(&1E=&%I;&5D(&YO=&EF:6-A=&EO;B!W:&5N(&5A8V@@
M9FEL=&5R(&ES(&%P<&QI960_(@IM<V=S='(@(K?MLL6F6+E,PF^S5ZMHJKJK
M2*7SLU&N3:7.KLFA0<7CI=RRT[A@I+JN93\B"@HC.B!T96UP;&%T97,O=F%C
M871I;VXO=F%C871I;VXN:6YC.C,T"FUS9VED(")$;R!?;F]T('-E;F0@<F5S
M<&]N<V5S('1O(&)U;&L@;W(@;&ES="!M97-S86=E<R(*;7-G<W1R("*F<*I'
MK$^P4;W7N'.RU:G.O'.G::M(I?,LJVBDH[;'L&6PLK3!IE[`LU]N(@H*(SH@
M=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@=&AI<SHB
M"FUS9W-T<B`BL/6FYJ:YI$"PRJ=`.B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS
M-3(*;7-G:60@(D1O97-N)W0@8F5G:6X@=VET:"(*;7-G<W1R("*V?<!9I*.L
M3R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#@*;7-G:60@(D1O97-N)W0@8V]N
M=&%I;B(*;7-G<W1R("*DHZ5=IW0B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4T
M"FUS9VED(")$;V5S;B=T(&5N9"!W:71H(@IM<V=S='(@(K6RI\"DHZQ/(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,U-@IM<V=I9"`B1&]E<VXG="!E>&ES="(*
M;7-G<W1R("*DHZ9SIF(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4Y"FUS9VED
M(")$;V5S;B=T(&UA=&-H("AW:71H('!L86-E:&]L9&5R<RDB"FUS9W-T<B`B
MI*.RQ:98("BE2*;[INRRQ;BYJNVEW"DB"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]H96%D97(N:6YC.C,Q(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-3@*(SH@
M;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV-2!L:6(O0FQO8VLO;W9E<G9I97<N
M<&AP.C<X"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z.#8*;7-G:60@(D5D
M:70B"FUS9W-T<B`BO7._Z"(*"B,Z(&9I;'1E<G,N<&AP.C(P,R!F:6QT97)S
M+G!H<#HR,#4@9FEL=&5R<RYP:'`Z,C`Y(&9I;'1E<G,N<&AP.C(Q,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@(KUSO^@@)7,B"@HC
M.B!F:6QT97)S+G!H<#HR-#4@9FEL=&5R<RYP:'`Z,C0V"B,L('!H<"UF;W)M
M870*;7-G:60@(D5N86)L92`E<R(*;7-G<W1R("*QTJ7.("5S(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHS-PIM<V=I9"`B16YA8FQE9"(*
M;7-G<W1R("*D=['2I<XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4S"FUS9VED
M(")%;F1S('=I=&@B"FUS9W-T<B`BM;*GP*Q/(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,V-`IM<V=I9"`B17%U86P@=&\B"FUS9W-T<B`BM:6I\R(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,3,Y(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30Y
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,34X"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@
M8W5R<F5N="!S8W)I<'0Z("@E9"D@)7,B"FUS9W-T<B`BQ:JH^K)[IN:Y3,)O
MM7NFH3H@*"5D*2`@)7,@KLFU;Z7-O_F[?B(*"B,Z(&)L86-K;&ES="YP:'`Z
M-C<*;7-G:60@(D5R<F]R('-A=FEN9R!C:&%N9V5S+B(*;7-G<W1R("+`>*9S
MQ=RG\Z[)M6^ES;_YNWXN(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R
M+FEN8SHR,@IM<V=I9"`B17AI<W1I;F<@4G5L97,B"FUS9W-T<B`BI'>KV*7?
MJKJS5ZMH(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-0IM<V=I9"`B17AI<W1S
M(@IM<V=S='(@(J9SIF(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%>'!E8W1E9"`Q(&]B:F5C="P@9V]T("5D
M+B(*;7-G<W1R("*TP:O=(#$@K=.JJZ7S+""Q;ZCL("5D+B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,`IM<V=I9"`B1FEL=&5R($%L
M;"!-97-S86=E<R(*;7-G<W1R("*N3:7.N4S";ZGSJ=*FLZM(I?,B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,C(*;7-G:60@(D9I;'1E
M<B!/;FQY(%-E96X@365S<V%G97,B"FUS9W-T<B`BI76N3:7.N4S";ZGSK-VY
M3*JZJTBE\R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR
M,0IM<V=I9"`B1FEL=&5R($]N;'D@56YS965N($UE<W-A9V5S(@IM<V=S='(@
M(J5UKDVESKE,PF^I\Z6\K-VY3*JZJTBE\R(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W-E='1I;F=S+FEN8SHQ.`IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS
M9W-T<B`BN4S";[ZYO^^VM2(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI
M;F,Z,C4*;7-G:60@(D9I;'1E<B!2=6QE(@IM<V=S='(@(KE,PF^S5ZMH(@H*
M(SH@9FEL=&5R<RYP:'`Z,3`Y"FUS9VED(")&:6QT97(@4G5L97,B"FUS9W-T
M<B`BN4S";[-7JV@B"@HC.B!S8W)I<'0N<&AP.C4R"FUS9VED(")&:6QT97(@
M4V-R:7!T($1I<W!L87DB"FUS9W-T<B`BQ>.EW+E,PF^^N;5[IJ$B"@HC.B!L
M:6(O26YG;RYP:'`Z,S$Q"FUS9VED(")&:6QT97(@7U)U;&5S(@IM<V=S='(@
M(KE,PF^S5ZMH7U(B"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H
M<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`BN4S";Z7-KL0Z(*1WO<:[<R`E<R"KRJM(I?.FW*M(I?.G6"!<(B5S
M7"(N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("*Y3,)OI<VNQ#H@I'>G4K"C("5S(*O*
MJTBE\RXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C(X,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V
M92!B965N(&UO=F5D('1O('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("*Y
M3,)OI<VNQ#H@I'>W:+*^("5S(*O*JTBE\ZCLJTBE\Z=8(%PB)7-<(BXB"@HC
M.B!L:6(O4V-R:7!T+VEM87`N<&AP.C$X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@=&AA="!M871C:&5D
M('1H92!B;&%C:VQI<W0@=V5R92!D96QE=&5D+B(*;7-G<W1R("*Y3,)OI<VN
MQ#H@I'>G4K"C("5S(*O*LL6F6+;"IE>SYK'XI?.JNJM(I?,N(@H*(SH@;&EB
M+U-C<FEP="]I;6%P+G!H<#HS,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S
M7"(@:&%S(&)E96X@8V]P:65D('1O('1H92`B"B)F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R("*Y3,)OI<VNQ#H@L4BFVR!<(B4R)'-<(B"JNJM(I?,@7"(E,21S
M7"(@I'>S4;W&NW.H[*M(I?.G6"!<(B4S)'-<(BXB"@HC.B!L:6(O4V-R:7!T
M+VEM87`N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R("*Y3,)OI<VNQ#H@JTBE\R!<(B5S7"(@L4BF
MVR!<(B5S7"(@I'>S4:=2L*,N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB1FEL=&5R(&%C=&EV:71Y.B!4
M:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@;6]V960@
M=&\@=&AE(&9O;&1E<B`B"B)<(B5S7"(N(@IM<V=S='(@(KE,PF^ES:[$.B"Q
M2*;;(%PB)3(D<UPB(*JZJTBE\R!<(B4Q)'-<(B"D=[-1MVBROJ;<JTBE\Z=8
M(%PB)3,D<UPB+B(*"B,Z(')U;&4N<&AP.C$V,`IM<V=I9"`B1FEL=&5R(&YO
M="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLN4S";[ZY+B(*"B,Z('1E;7!L871E
M<R]R=6QE+VAE861E<BYI;F,Z-#(*;7-G:60@(D9O<B!A;B!I;F-O;6EN9R!M
M97-S86=E('1H870@;6%T8VAE<SHB"FUS9W-T<B`BJ=*FL[%(M;FGVJJZJTBE
M\Z5UK6ZRQ:98.B(*"B,Z(&9I;'1E<G,N<&AP.C$V,B!T96UP;&%T97,O9F]R
M=V%R9"]F;W)W87)D+FEN8SHX(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C0*
M(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV-@IM<V=I9"`B1F]R=V%R9"(*
M;7-G<W1R("*FV[#*PN"Q2"(*"B,Z(&9O<G=A<F0N<&AP.C$V"FUS9VED(")&
M;W)W87)D(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R
M:6YG(&1R:79E<BXB"FUS9W-T<B`BI=BK9:JZN4S";[ZYQ5BPRK5[IJ&HPZ6\
MI.2TJ:;;L,K"X+%(JKJE7*_@+B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN
M<&AP.C(X,B!L:6(O4V-R:7!T+W-I979E+G!H<#HR,30*(SH@;&EB+U-C<FEP
M="]M86EL9')O<"YP:'`Z,C(T"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("*F
MV[#*PN"K2"(*"B,Z(&9O<G=A<F0N<&AP.C0V"FUS9VED(")&;W)W87)D<R!%
M9&ET(@IM<V=S='(@(KUSO^BFV[#*PN"K2"(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z,SD*;7-G:60@(D9R;VTB"FUS9W-T<B`BL4BE\Z1((@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,V,@IM<V=I9"`B1W)E871E<B!T:&%N(@IM<V=S
M='(@(J1JJ?,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S8S"FUS9VED(")'<F5A
M=&5R('1H86X@;W(@97%U86P@=&\B"FUS9W-T<B`BI&JI\ZG.M:6I\R(*"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S$*;7-G:60@(DEM<&]R=&%N
M="(*;7-G<W1R("*MJZUN(@H*(SH@<G5L92YP:'`Z,S8*;7-G:60@(DEN9&EV
M:61U86P@<G5L97,@87)E(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@
M9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`BI=BK9:JZN4S";[ZYQ5BPRK5[
MIJ&HPZ6\I.2TJ:W3IT^S5ZMH+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP
M.C$X-C`*;7-G:60@(DEN97AI<W1A;G0@;6%I;&)O>"!S<&5C:69I960@9F]R
M(&UE<W-A9V4@9&5L:79E<GDN(@IM<V=S='(@(JO\J7>[O+!EJTBE\ZJZJTBE
M\Z=8J,.DHZ9SIF(N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T.0IM<V=I9"`B
M27,B"FUS9W-T<B`BK$\B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4P"FUS9VED
M("))<VXG="(*;7-G<W1R("*DHZQ/(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HR,PIM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T
M:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D
M+B(*;7-G<W1R("*ELK:WK6ZFLR!,1$%0(*JZI.2TJ2RF_:Q/($Q$05`@O-*R
MU:2CK$^EO*9WN,NT3JQ/J%.FL[C\I$HN(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,V,`IM<V=I9"`B3&5S<R!T:&%N(@IM<V=S='(@(J1PJ?,B"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z,S8Q"FUS9VED("),97-S('1H86X@;W(@97%U86P@=&\B
M"FUS9W-T<B`BI'"I\ZG.M:6I\R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I
M<W0Z-3D*;7-G:60@(DQI<W0M240B"FUS9W-T<B`BL%&]U[ASLM4MP]&G3[BY
MO5@B"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,C`*
M;7-G:60@(DUA<E]K(&UE<W-A9V4@87,@9&5L971E9"(*;7-G<W1R("*\T+MX
MJTBE\ZRPI'>G4K"C7VLB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC
M.C(T"FUS9VED(")-87)K(&UE<W-A9V4@87,Z(@IM<V=S='(@(KS0NWBK2*7S
MK+`Z(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U.`IM<V=I9"`B36%T8VAE<R`H
M=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S='(@(K+%IE@@**5(IONF[++%N+FJ
M[:7<*2(*"B,Z(&QI8B]A<&DN<&AP.C4W"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!2=6QE<R(*;7-G<W1R("*S5ZMHO,:EV*17K:TB"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z-#@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@
M;G5M8F5R(&]F(&)L86-K;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T
M86P@861D<F5S<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@
M($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N(@IM
M<V=S='(@(K;"IE>SYKS&I=BD=[E&I%>MK2BD=Z7..B`E<RP@I%>MK3H@)7,I
M+B"U3*IKMW.\5Z9AIWVH[+;"IE>SYBXB"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M-3,X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@;G5M8F5R(&]F
M('=H:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S
M<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO
M="!A9&0@;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N(@IM<V=S='(@(J3-
MM;VF5[/FO,:EV*1WN4:D5ZVM**1WI<XZ("5S+""D5ZVM.B`E<RDN(+5,JFNW
M<[Q7IF&G?:CLI,VUO:97L^8N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,C`W-0IM<V=I9"`B36ES<VEN9R!A9&1R97-S('1O(&YO=&EF>2(*;7-G<W1R
M("*ORJ36MFRE\[-QJKZF8:=](@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,3<R.`IM<V=I9"`B36ES<VEN9R!A9&1R97-S('1O(')E9&ER96-T(&UE<W-A
M9V4@=&\B"FUS9W-T<B`BK\JDUL+@IWV[O+!EJ=*[W:UNJKJK2*7SIF&G?2(*
M"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W-C`*;7-G:60@(DUI<W-I;F<@
M<F5A<V]N(&9O<B!R96IE8W0B"FUS9W-T<B`BK\JDUK!HIEZK2*7SJ=*[W:UN
MJKJR>J71(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3DR-PIM<V=I9"`B
M36ES<VEN9R!R96%S;VX@:6X@=F%C871I;VXN(@IM<V=S='(@(J_*I-:PLK3!
MLW&JOJG2N]VM;JJZLGJET2(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E
M<BYI;F,Z-#`*;7-G:60@(DUO=F4B"FUS9W-T<B`BMVBROB(*"B,Z(&9I;'1E
M<G,N<&AP.C$R-B!F:6QT97)S+G!H<#HR,S@*;7-G:60@(DUO=F4@4G5L92!$
M;W=N(@IM<V=S='(@(J15LKXHJ;6KX:Y-I<XI(@H*(SH@9FEL=&5R<RYP:'`Z
M,3(W(&9I;'1E<G,N<&AP.C(S-PIM<V=I9"`B36]V92!2=6QE(%5P(@IM<V=S
M='(@(J17LKXHP'6E_:Y-I<XI(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A
M8V%T:6]N+FEN8SHT,@IM<V=I9"`B3E]U;6)E<B!O9B!D87ES(&)E='=E96X@
M=F%C871I;VX@<F5P;&EE<SHB"FUS9W-T<B`BL+*TP:9>PM"UI:O=I-&\QCI?
M=2(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHS('1E
M;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z.`HC.B!L:6(O4W1O<F%G92YP
M:'`Z-S0V"FUS9VED(").97<@4G5L92(*;7-G<W1R("*W<[Q7LU>K:"(*"B,Z
M(&QI8B]);F=O+G!H<#HR,#4@;&EB+TEN9V\N<&AP.C(P-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!<(B5S7"(@96QE;65N="!F;W5N9"!I;B!B86-K96YD
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(J9BIOBJ0;K=JKJS7:EWN.JNQJ2D
MI^2DHZCLP_:I\R!<(B5S7"(@JKJDN*7S+B(*"B,Z(&QI8B]);F=O+G!H<#HR
M,#,*;7-G:60@(DYO(&)A8VME;F0@8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T
M(@IM<V=S='(@(J:YI42^]ZJZIOBJ0;K=I;RS7:EW(@H*(SH@;&EB+TEN9V\N
M<&AP.C$X,`IM<V=I9"`B3F\@8F%C:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K
M96YD<RYP:'`B"FUS9W-T<B`BJ7REO*9B(&)A8VME;F1S+G!H<""DI+-=J7>F
M^*I!NMVXZK!4(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+6YO;F4N
M:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@9FEL=&5R<RX@0VQI8VL@
M7"(E<UPB('1O(&-R96%T92!A(&YE=R!F:6QT97(N(@IM<V=S='(@(K5,LU>K
M:"X@PDF_[R!<(B5S7"(@J]BEW[=SJKJY3,)OLU>K:"(*"B,Z(&QI8B]38W)I
M<'0O<VEE=F4N<&AP.C$S,S(@;&EB+U-C<FEP="]S:65V92YP:'`Z,30R-0HC
M.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-3DY"FUS9VED(").;R!H96%D97)S
M('-P96-I9FEE9"(*;7-G<W1R("*EO*O\J7>J[<!9(@H*(SH@<V-R:7!T+G!H
M<#HV-PIM<V=I9"`B3F\@<V-R:7!T(&=E;F5R871E9"XB"FUS9W-T<B`BN4S"
M;[5[IJ&EO+*CI<TN(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,38Q-`IM
M<V=I9"`B3F\@<W1R:6YG<R!S<&5C:69I960B"FUS9W-T<B`BI;RK_*EWIG*F
MZB(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-C4*;7-G:60@(DYO="!E<75A;"!T
M;R(*;7-G<W1R("*DH[6EJ?,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S(U"FUS
M9VED(").;W1I9GDB"FUS9W-T<B`BLW&JOB(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS,3D*;7-G:60@(D]N;'D@9FQA9R!T:&4@;65S<V%G92(*;7-G<W1R("*V
MR+S0L$^V;*7S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y"FUS9VED
M(")/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A=&EN9RXB"FUS9W-T<B`BP_:I
M\[E,PF^U>Z:AI_.W<ZJZO^^VM2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3<*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`BJ.2E3+_OMK4B
M"@HC.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C,*;7-G:60@(D]V97)V:65W
M(@IM<V=S='(@(K>GQELB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]N97=?
M9F]L9&5R+FIS.C8*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T
M:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`BO="_Z:1*MW.K2*7SIUBJNJ97NMDZ
M(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHV,`IM<V=I
M9"`B4E]E87-O;B(*;7-G<W1R("*M[*9=7V4B"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C8S"FUS9VED(")296-E:79E9"(*;7-G<W1R("*J[<!9I*2J
MNB!296-E:79E9"#$YJ;L(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,P,`IM<V=I
M9"`B4F5D:7)E8W0@=&\B"FUS9W-T<B`BPN"G?;N\L&6H["(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS-3<*;7-G:60@(E)E9W5L87(@97AP<F5S<VEO;B(*;7-G
M<W1R("*EO[-7L6"FH2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,34*;7-G:60@
M(E)E:F5C="!W:71H(')E87-O;B(*;7-G<W1R("*E2*:YK>RF7;!HJT@B"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4U"FUS9VED(")297-E;G0@5&\B
M"FUS9W-T<B`BK:NW<[%(L&6H["(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I
M<W0Z-3$*;7-G:60@(E)E<V5N="UF<F]M(@IM<V=S='(@(JVKMW.Q2+!E+2VF
MVR(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-C`*;7-G:60@(E)E
M='5R;B!T;R!&:6QT97)S($QI<W0B"FUS9W-T<B`BIEZH[+-7JVBJ[:9#(@H*
M(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C(T('1E;7!L
M871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT,0HC.B!T96UP;&%T97,O
M=F%C871I;VXO=F%C871I;VXN:6YC.C<Q('1E;7!L871E<R]F;W)W87)D+V9O
M<G=A<F0N:6YC.C,T"FUS9VED(")2971U<FX@=&\@4G5L97,@3&ES="(*;7-G
M<W1R("*F7JCLLU>K:*KMID,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D
M97(N:6YC.C,T"FUS9VED(")2=6QE(@IM<V=S='(@(K-7JV@B"@HC.B!F:6QT
M97)S+G!H<#HV,`IM<V=I9"`B4G5L92!#;W!I960B"FUS9W-T<B`BLU>K:*1W
MO<:[<R(*"B,Z(&9I;'1E<G,N<&AP.C,Y"FUS9VED(")2=6QE($1E;&5T960B
M"FUS9W-T<B`BLU>K:*1WIU*PHR(*"B,Z(&9I;'1E<G,N<&AP.C<V"FUS9VED
M(")2=6QE($1I<V%B;&5D(@IM<V=S='(@(K-7JVBD=["QI<XB"@HC.B!F:6QT
M97)S+G!H<#HX,0IM<V=I9"`B4G5L92!%;F%B;&5D(@IM<V=S='(@(K-7JVBD
M=['2I<XB"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C,S"FUS9VED
M(")2=6QE($YA;64B"FUS9W-T<B`BLU>K:*97NMDB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A
M:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")35$%25%1,4R"EHK'1.B`H)7,I("5S
M(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C(S('1E
M;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT,`HC.B!T96UP;&%T
M97,O=F%C871I;VXO=F%C871I;VXN:6YC.C<P('1E;7!L871E<R]F;W)W87)D
M+V9O<G=A<F0N:6YC.C,S"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z
M-3D*;7-G:60@(E-A=F4B"FUS9W-T<B`BP'BF<R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W-E='1I;F=S+FEN8SHR.0IM<V=I9"`B4V%V92!3971T:6YG<R(*
M;7-G<W1R("+`>*9SLUVI=R(*"B,Z('1E;7!L871E<R]S8W)I<'0O:&5A9&5R
M+FEN8SHR"FUS9VED(")38W)I<'0B"FUS9W-T<B`BN4S";[5[IJ$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN
M9R(*;7-G<W1R("*Y3,)OM7NFH:?SMW,B"@HC.B!L:6(O26YG;RYP:'`Z,C(X
M"FUS9VED(")38W)I<'0@;F]T('5P9&%T960N(@IM<V=S='(@(KE,PF^U>Z:A
MI;RS4:?SMW,B"@HC.B!L:6(O26YG;RYP:'`Z,3,P"FUS9VED(")38W)I<'0@
M<W5C8V5S<V9U;&QY(&%C=&EV871E9"XB"FUS9W-T<B`BN4S";[5[IJ&D=Z>Y
MIJBQTJ7.+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,CD*;7-G:60@(E-C<FEP="!S
M=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(KE,PF^U>Z:AI'>P
ML:7.+B(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,CD*;7-G:60@
M(E-E96XB"FUS9W-T<B`BK-VY3"(*"B,Z(')U;&4N<&AP.C$Y,`IM<V=I9"`B
M4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`BO^^^W*1`K=/$YJ;L(@H*(SH@;&EB
M+TEN9V\N<&AP.C0Y"FUS9VED(")396QE8W0@=&%R9V5T(&9O;&1E<B(*;7-G
M<W1R("*_[[[<I=B\T*M(I?.G6"(*"B,Z(')U;&4N<&AP.C(R-PIM<V=I9"`B
M4V5L9BU$969I;F5D($AE861E<B(*;7-G<W1R("*FVZUQJNW`62(*"B,Z(&-O
M;F9I9R]F:65L9',N<&AP+F1I<W0Z,S4*;7-G:60@(E-E;F1E<B(*;7-G<W1R
M("*J[<!9I*2JNB!396YD97(@Q.:F["(*"B,Z(&9I;'1E<G,N<&AP.CDU"FUS
M9VED(")3971T:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B
MLUVI=Z1WI_.W<Z>YIJ@N(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T
M92YI;F,Z,C0*;7-G:60@(E-H;W<@06-T:79E(%-C<FEP="(*;7-G<W1R("+%
MXZ7<I;^F8K#UIN:DI+E,PF^U>Z:A(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A
M8W1I=F%T92YI;F,Z,S$*;7-G:60@(E-H;W<@0W5R<F5N="!38W)I<'0B"FUS
M9W-T<B`BQ>.EW+USO^BDI*JZN4S";[5[IJ$B"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C@S"FUS9VED(")3:7IE(@IM<V=S='(@(J1JI'`B"@HC.B!T
M96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C0Y"FUS9VED(")3=&]P(&-H96-K
M:6YG(&EF('1H:7,@<G5L92!M871C:&5S/R(*;7-G<W1R("*K2*7SI$"EN;+%
MIEBS;['XLU>K:+1.L+&D[L1^Q/+`RZQDJ.2^;*JZLU>K:"(*"B,Z('1E;7!L
M871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-3$*;7-G:60@(E-U8FIE7V-T
M(&]F('9A8V%T:6]N(&UE<W-A9V4Z(@IM<V=S='(@(K"RM,&O9*BEJKJE1*:N
M.E]C(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HS,0IM<V=I9"`B4W5B
M:F5C="(*;7-G<W1R("*E1*:N(@H*(SH@;&EB+V%P:2YP:'`Z.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@7"(E<UPB(&AA<R!B965N(&%D
M9&5D('1O('EO=7(@8FQA8VML:7-T+B(*;7-G<W1R("*Y<:1LMFRE\Z;MIWT@
M7"(E<UPB(*1WI5ND2JCLML*F5[/FI*0N(@H*(SH@;&EB+V%P:2YP:'`Z,3`T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(%PB)7-<(B!H87,@
M8F5E;B!A9&1E9"!T;R!Y;W5R('=H:71E;&ES="XB"FUS9W-T<B`BN7&D;+9L
MI?.F[:=](%PB)7-<(B"D=Z5;I$JH[*3-M;VF5[/FI*0N(@H*(SH@;&EB+TEN
M9V\N<&AP.C$R-0IM<V=I9"`B5&AE(&1R:79E<B!S86ED.B`B"FUS9W-T<B`B
MQ5BPRK5[IJ&F7L"S.B`E<R(*"B,Z(&QI8B]);F=O+G!H<#HQ,C0*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!A8W1I=F%T:6YG('1H92!S8W)I<'0N(@IM
M<V=S='(@(K'2I<ZY3,)OM7NFH:[)M6^ES:1`K=._^;M^+B(*"B,Z(&QI8B])
M;F=O+G!H<#HQ,C,*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96%C=&EV
M871I;F<@=&AE('-C<FEP="XB"FUS9W-T<B`BL+&ESKE,PF^U>Z:AKLFU;Z7-
MI$"MT[_YNWXN(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HR-PIM<V=I
M9"`B5&\B"FUS9W-T<B`BIJRE\Z1((@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M9FEL=&5R+FAT;6PZ,C@*;7-G:60@(E1O.B(*;7-G<W1R("*ROJCL.B(*"B,Z
M(&QI8B]38W)I<'0N<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`BM4RJ
M:[C\I$H@)7,@JKJI=[AQ+B(*"B,Z(&9I;'1E<G,N<&AP.C$U-B!T96UP;&%T
M97,O=F%C871I;VXO=F%C871I;VXN:6YC.C4*(SH@;&EB+U-C<FEP="]P<F]C
M;6%I;"YP:'`Z,C8R(&QI8B]38W)I<'0O<VEE=F4N<&AP.C,U,@HC.B!L:6(O
M0FQO8VLO;W9E<G9I97<N<&AP.C4W(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z
M-3D*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(K"RM,&S<:J^(@H*(SH@=F%C
M871I;VXN<&AP.C<R"FUS9VED(")686-A=&EO;B!%9&ET(@IM<V=S='(@(KUS
MO^BPLK3!LW&JOB(*"B,Z('9A8V%T:6]N+G!H<#HQ-@IM<V=I9"`B5F%C871I
M;VX@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@
M9')I=F5R+B(*;7-G<W1R("*EV*MEJKJY3,)OOKG%6+#*M7NFH:C#I;RDY+2I
ML+*TP;-QJKZJNJ5<K^`N(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET
M96QI<W0N:6YC.C$V"FUS9VED(")7:%]I=&5L:7-T(&%D9')E<W-E<SHB"FUS
M9W-T<B`BI,VUO:97L^:JNK9LI?.F8:=].E]I(@H*(SH@9FEL=&5R<RYP:'`Z
M,34P('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHX"B,Z(&QI
M8B]";&]C:R]O=F5R=FEE=RYP:'`Z-S8@;&EB+T)L;V-K+V]V97)V:65W+G!H
M<#HW.0IM<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@(J3-M;VF5[/F(@H*(SH@
M=VAI=&5L:7-T+G!H<#HU-0IM<V=I9"`B5VAI=&5L:7-T($5D:70B"FUS9W-T
M<B`BO7._Z*3-M;VF5[/F(@H*(SH@=VAI=&5L:7-T+G!H<#HQ.`IM<V=I9"`B
M5VAI=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL
M=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`BI=BK9:JZN4S";[ZYQ5BPRK5[IJ&H
MPZ6\I.2TJ:3-M;VF5[/FJKJE7*_@+B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA
M:6PN<&AP.C(S-"!L:6(O4V-R:7!T+W-I979E+G!H<#HR.3@*(SH@;&EB+U-C
M<FEP="]M86EL9')O<"YP:'`Z,C`R"FUS9VED(")7:&ET96QI<W1E9"!!9&1R
M97-S97,B"FUS9W-T<B`BI'>S4:9#K+"DS;6]IE>SYJJZMFRE\Z9AIWTB"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C<Y"FUS9VED(")8+5!R:6]R:71Y
M(@IM<V=S='(@(L!UI?VVMJ?'(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES
M=#HV-PIM<V=I9"`B6"U3<&%M+4QE=F5L(@IM<V=S='(@(E@M4W!A;2"UI:_%
M(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3<&%M
M+5-C;W)E(@IM<V=S='(@(E@M4W!A;2"DP+S&(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HW-0IM<V=I9"`B6"U3<&%M+5-T871U<R(*;7-G<W1R(")8
M+5-P86T@JJRZ02(*"B,Z(&9I;'1E<G,N<&AP.C4S(')U;&4N<&AP.C$T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@<G5L97,N(@IM<V=S='(@(J=!J%.FLZO8I=^V
M5[E,("5D(*W3LU>K:*JZQ7:MK2XB"@HC.B!F:6QT97)S+G!H<#HT-2!R=6QE
M+G!H<#HR,0IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;W(@961I="!C=7-T;VT@<G5L97,N(@IM<V=S='(@(J2CI+FS7*=!J]BEWZG.
MO7._Z*;;K7&S5ZMH+B(*"B,Z('9A8V%T:6]N+G!H<#HS,`IM<V=I9"`B(@HB
M66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@96UA:6P@861D<F5S<R!F
M;W(@=VAI8V@@=&AE('9A8V%T:6]N(&UE<W-A9V5S("(*(G-H;W5L9"!B92!A
M8W1I=F%T960N(@IM<V=S='(@(J=!I;*VMZO\J7>FW*36I$"MT[EQI&RV;*7S
MIF&G?2RE2*M+L=*ESK"RM,&S<:J^JD&PR"XB"@HC.B!L:6(O4V-R:7!T+VEM
M87`N<&AP.C(W."!L:6(O4V-R:7!T+VEM87`N<&AP.C,P,2!L:6(O4V-R:7!T
M+VEM87`N<&AP.C,Q-0IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(ENU
M3*5$IJY=(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,C0*
M;7-G:60@(E]!9&1R97-S*&5S*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R("*F
MV[#*PN"Q2*CLI%6F0ZJZN7&D;+9LI?.F[:=].E]!(@H*(SH@=&5M<&QA=&5S
M+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHR,PIM<V=I9"`B7T%D9')E<W-E<R!T
M;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z(@IM<V=S='(@(J5(I%6JNKEQI&RV
M;*7SINVG?:2CIE[`LSI?02(*"B,Z(&QI8B]);F=O+G!H<#HS,38*;7-G:60@
M(E]";&%C:VQI<W0B"FUS9W-T<B`BML*F5[/F7T(B"@HC.B!T96UP;&%T97,O
M8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,3@*;7-G:60@(E]$96QE=&4@;65S
M<V%G92!C;VUP;&5T96QY(@IM<V=S='(@(KG]J;.G4K"CJTBE\U]$(@H*(SH@
M=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C,Q"FUS9VED(")?
M16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z(@IM<V=S='(@(J9B
MJ$.D0*K%I=6FYJ2DO^FD2J1`K=.Y<:1LMFRE\Z9AIWTZ7T4B"@HC.B!L:6(O
M26YG;RYP:'`Z,S(R"FUS9VED(")?1F]R=V%R9"(*;7-G<W1R("*FV[#*PN"Q
M2%]&(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3<*;7-G
M:60@(E]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_
M(@IM<V=S='(@(JM/KV2S;ZW3L6*XN:2DJKJK2*7S/U]+(@H*(SH@=&5M<&QA
M=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(R"FUS9VED(")?36]V92!M
M97-S86=E('1O(&9O;&1E<CHB"FUS9W-T<B`BMVBROJM(I?.H[*M(I?.Y:#I?
M32(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,3,*;7-G
M:60@(E]->2!E;6%I;"!A9&1R97-S97,Z(@IM<V=S='(@(J?:JKJY<:1LMFRE
M\Z9AIWTZ7TTB"@HC.B!L:6(O26YG;RYP:'`Z,S(U"FUS9VED(")?4V-R:7!T
M(@IM<V=S='(@(KE,PF^U>Z:A7U,B"@HC.B!L:6(O26YG;RYP:'`Z,S$Y"FUS
M9VED(")?5F%C871I;VXB"FUS9W-T<B`BL+*TP;-QJKY?5B(*"B,Z(&QI8B])
M;F=O+G!H<#HS,3,*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`BI,VUO:97
ML^9?5R(*"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-3$*;7-G:60@(F%C
M=&EV92(*;7-G<W1R("*QTJ7.(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R
M+FEN8SHT"FUS9VED(")A;F0B"FUS9W-T<B`BIM.E0B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+V9I;'1E<BYH=&UL.C$V"FUS9VED(")D:7-A8FQE9"`M(&-L
M:6-K('1O(&5N86)L92(*;7-G<W1R("*D=["QI<X@+2"Q_;'2I<Z]T,))O^^S
M;[C,(@H*(SH@9FEL=&5R<RYP:'`Z,3@P"FUS9VED(")F:65L9"(*;7-G<W1R
M("+$YJ;L(@H*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HT.0IM<V=I9"`B
M:6YA8W1I=F4B"FUS9W-T<B`BL+&ESB(*"B,Z(&QI8B]38W)I<'0O;6%I;&1R
M;W`N<&AP.C$R,`IM<V=I9"`B;6%I;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B
M>2!);F=O(@IM<V=S='(@(FUA:6QD<F]P(+E,PF^U>Z:AI'<@26YG;R"ITK*C
MI<TN(@H*(SH@9FEL=&5R<RYP:'`Z,3@P"FUS9VED(")M871C:"(*;7-G<W1R
M("*DQ[!T(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED
M(")O<B(*;7-G<W1R("*ISJK,(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP
M:'`Z,3(X"FUS9VED(")P<F]C;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN
M9V\B"FUS9W-T<B`B<')O8VUA:6P@N4S";[5[IJ&D=[*CI<TN(@H*(SH@;&EB
M+U-C<FEP="]S:65V92YP:'`Z,3$P"FUS9VED(")S:65V92!F:6QT97(@9V5N
M97)A=&5D(&)Y($EN9V\B"FUS9W-T<B`B<VEE=F4@N4S";[ZYI'>S42!);F=O
M(+*CI<TB"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+W!O+VAU7TA5
M+G!O````````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#4U,3$R`#$P-#$W,S8R-S0W`#`Q-S,U,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($AU;F=A<FEA;B!T<F%N<VQA=&EO
M;G,@9F]R($EN9V\@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0M,C`P
M-B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N
M9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($EN9V\@<&%C:V%G92X*(R!!
M='1I;&$@3F%G>2`\8G)A0&9S;BYH=3XL(#(P,#0N"B,@"FUS9VED("(B"FUS
M9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!);F=O(#$N,5QN(@HB4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$W(#$P.C`P*S`Q,#!<;B(*(E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,3@@,C`Z,#,K,#$P,%QN(@HB3&%S
M="U4<F%N<VQA=&]R.B!,87-Z;&\@3"X@5&]R;F]C:5QN(@HB3&%N9W5A9V4M
M5&5A;3H@(&DQ.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B)-24U%+59E<G-I;VXZ
M(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E3
M3RTX.#4Y+3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<
M;B(*"B,Z(&9I;'1E<G,N<&AP.C$Y,`IM<V=I9"`B(&%N9"(*;7-G<W1R("(@
MZ7,B"@HC.B!F:6QT97)S+G!H<#HQ.3`*;7-G:60@(B!O<B(*;7-G<W1R("(@
M=F%G>2(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ
M-PIM<V=I9"`B06-T:6]N(&9O<B!B;&%C:VQI<W1E9"!A9&1R97-S97,Z(@IM
M<V=S='(@(B(*(D$@9F5K971E;&ES=.%N('-Z97)E<&SU(&9E;&%D\W3S;"#I
M<FME>O4@_'IE;F5T=&5L(&$@:_9V971K97KU('3V<G3I;FIE;CHB"@HC.B!T
M96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ,`IM<V=I9"`B06-T:79A
M=&4@4V-R:7!T(@IM<V=S='(@(E-Z^W+U;&ES=&$@Z7)VZ6YY97/M=.ES92(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G
M:60@(D%C=&EV871I;F<@=&AE('-C<FEP="!F;W(@7"(E<UPB(&9A:6QE9#H@
M*"5D*2`E<R(*;7-G<W1R(")!('-Z^W+U;&ES=.%T(&YE;2!S:6ME<OQL="!<
M(B5S7"(@<NES>NER92#I<G;I;GEE<^UT96YI.B`H)60I("5S(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C8*;7-G:60@(D%D9&ET:6]N
M86P@4V5T=&EN9W,B"FUS9W-T<B`B5&]VX6)B:2!B9>%L;.UTX7-O:R(*"B,Z
M('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#0*;7-G:60@(D%L;"!O9B!T
M:&4@9F]L;&]W:6YG(@IM<V=S='(@(FUI;F1E9WEI:^EN96LB"@HC.B!L:6(O
M87!I+G!H<#HU-`IM<V=I9"`B06QL;W<@4G5L97,B"FUS9W-T<B`B02!S>OMR
M]7-Z86+A;'EO:R!E;F=E9.EL>65ZZ7-E(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M9F]O=&5R+FEN8SHS,PIM<V=I9"`B06YS=V5R960B"FUS9W-T<B`B365G=N%L
M87-Z;VQT(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHT-0IM<V=I
M9"`B06YY(&]F('1H92!F;VQL;W=I;F<B"FUS9W-T<B`B=F%L86UE;'EI:^EN
M96LB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F;V]T97(N:6YC.C<*;7-G:60@
M(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B2V%P8W-O;&IU:R!B92!A('-Z^W+U
M:V5T(@H*(SH@9FEL=&5R<RYP:'`Z,C$Y"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@9&5L971E('1H:7,@<G5L93\B"FUS9W-T<B`B0FEZ=&]S
M+"!H;V=Y('3V<O9L;FD@86MA<FIA(&5Z="!A('-Z86+A;'ET/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B075T;VUA=&EC86QL>2!U
M<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\B"FUS9W-T<B`B
M075T;VUA=&EK=7-A;B!F<FES<^UT<_QK(&$@<WK[<O5S>F%BX6QY="!M:6YD
M96X@=N%L=&]Z=&%TX7,@=73A;C\B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD
M:7-T.C0W"FUS9VED(")"8V,B"FUS9W-T<B`B0F-C(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,W.0IM<V=I9"`B0F5G:6YS('=I=&@B"FUS9W-T<B`B02!K]G9E
M=&ME>O5V96P@:V5Z9/5D:6LB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$P
M-B!L:6(O1')I=F5R+VQD87`N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")!(&MA<&-S;VQA="!F
M96QVZ71E;&4@;F5M('-I:V5R_&QT.B`H)7,I("5S(@H*(SH@9FEL=&5R<RYP
M:'`Z,30Y('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHW"B,Z
M(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z.#<@;&EB+T)L;V-K+V]V97)V:65W
M+G!H<#HY,`IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(E1I;'1O='0@8^UM
M96LB"@HC.B!B;&%C:VQI<W0N<&AP.C$P-PIM<V=I9"`B0FQA8VML:7-T($5D
M:70B"FUS9W-T<B`B5&EL=&]T="!C[6UE:R!S>F5R:V5S>G3I<V4B"@HC.B!B
M;&%C:VQI<W0N<&AP.C$W"FUS9VED(")";&%C:VQI<W0@:7,@;F]T('-U<'!O
M<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R
M(")!(&9E:V5T96QI<W1A(&YE;2!TX6UO9V%T;W1T(&$@<WK[<O5M96=H86IT
M\V)A;B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(P-R!L:6(O4V-R
M:7!T+W-I979E+G!H<#HR-#0*(SH@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z
M,3<V"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B5&EL
M=&]T="!C[6UE:R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z.#@*;7-G
M:60@(D)O9'DB"FUS9W-T<B`B3&5VZ6QT]G)Z<R(*"B,Z(&9I;'1E<G,N<&AP
M.C$X-R!R=6QE+G!H<#HR.#$*;7-G:60@(D-A<V4@4V5N<VET:79E(@IM<V=S
M='(@(DMI<R]N86=Y8F5T^R#I<GKI:V5N>2(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z-#,*;7-G:60@(D-C(@IM<V=S='(@(D-C(@H*(SH@<G5L92YP
M:'`Z,3(R('=H:71E;&ES="YP:'`Z,S8@9F]R=V%R9"YP:'`Z,S,@=F%C871I
M;VXN<&AP.C0Q"B,Z(&)L86-K;&ES="YP:'`Z-S,*;7-G:60@(D-H86YG97,@
M<V%V960N(@IM<V=S='(@(E;A;'1O>N%S;VL@96QM96YT=F4N(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HW-0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E
M(@IM<V=S='(@(D$@:V%P8W-O;&%T(&YE;2!S:6ME<OQL="(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS-S4*;7-G:60@(D-O;G1A:6YS(@IM<V=S='(@(E1A<G1A
M;&UA>GIA(&$@:_9V971K97KU="(*"B,Z(&9I;'1E<G,N<&AP.C(S,"!F:6QT
M97)S+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2`E<R(*;7-G
M<W1R("(E<R!MX7-O;.%S82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HX-S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!O9B`E<R(*;7-G<W1R("(E<R!MX7-O
M;&%T82(*"B,Z(&QI8B]);F=O+G!H<#HV,@IM<V=I9"`B0W)E871E(&YE=R!F
M;VQD97(B"FUS9W-T<B`B2&]Z>G5N:R!LZ71R92#Z:B!M87!PX70B"@HC.B!L
M:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HS,S8@;&EB+U-C<FEP="]M86EL9')O
M<"YP:'`Z,C@P"FUS9VED(")$25-!0DQ%1#H@(@IM<V=S='(@(DQ%5$E,5%9!
M.B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$W"FUS9VED
M(")$96%C=&EV871E(%-C<FEP="(*;7-G<W1R(")3>OMR]6QI<W1A(.ER=NEN
M>71E;&5N[73I<V4B"@HC.B!F:6QT97)S+G!H<#HR,3D@9FEL=&5R<RYP:'`Z
M,C(P"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R("(E
M<R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHS,`IM
M<V=I9"`B1&5L971E($-O;F1I=&EO;B(*;7-G<W1R(")!(&9E;'3I=&5L('3V
M<FSI<V4B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S(S"FUS9VED(")$96QE=&4@
M;65S<V%G92!C;VUP;&5T96QY(@IM<V=S='(@(E;I9^ER=NEN>65S96X@=/9R
M]FQJ_&L@82!L979E;&5T(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN
M8SHS-0IM<V=I9"`B1&5L971E9"(*;7-G<W1R(")4]G+V;'0B"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z,S$Q"FUS9VED(")$96QI=F5R(&EN=&\@;7D@26YB;W@B
M"FUS9W-T<B`B02!L97;I;"!K97+\;&KV;B!A>B!)3D)/6"UO;6)A(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,S-PIM<V=I9"`B1&5L:79E<B!I;G1O(&UY($EN
M8F]X(&%N9"!C;W!Y('1O(@IM<V=S='(@(D$@;&5VZ6P@:V5R_&QJ]FX@87H@
M24Y"3U@M;VUB82#I<R!MX7-O;&IU:R#A="!I9&4B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S,R"FUS9VED(")$96QI=F5R(&EN=&\@;7D@26YB;W@@86YD(')E
M9&ER96-T('1O(@IM<V=S='(@(D$@;&5VZ6P@:V5R_&QJ]FX@87H@24Y"3U@M
M;VUB82#I<R!I<N%N>>UT<W5K(.%T(&$@:_9V971K97KU(&/M;7)E(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,Q-PIM<V=I9"`B1&5L:79E<B!T;R!F;VQD97(B
M"FUS9W-T<B`B2^EZ8F5S[73I<R!A(&OV=F5T:V5Z]2!M87!PX6)A(@H*(SH@
M9FEL=&5R<RYP:'`Z,C0S(&9I;'1E<G,N<&AP.C(T-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$:7-A8FQE("5S(@IM<V=S='(@(B5S('1I;'3A<V$B"@HC.B!T
M96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,3`@=&5M<&QA=&5S
M+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C$P"B,Z('1E;7!L871E<R]V86-A
M=&EO;B]V86-A=&EO;BYI;F,Z-B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D
M+FEN8SHQ,`HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C(V"FUS9VED
M(")$:7-A8FQE9"(*;7-G<W1R("),971I;'1O='0B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]S971T:6YG<RYI;F,Z,3,*;7-G:60@(D1I<W!L87D@9&5T86EL
M960@;F]T:69I8V%T:6]N('=H96X@96%C:"!F:6QT97(@:7,@87!P;&EE9#\B
M"FUS9W-T<B`B(@HB2F5L96[M='/\;FL@;65G('+I<WIL971E<R!TX6KI:V]Z
M=&%TX7-T(&%M:6YT(&%Z(&5G>65S('-Z^W+U:R!A;&MA;&UA>N%S82`B"B)M
M96=T]G)TZ6YI:S\B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN
M:6YC.C,T"FUS9VED(")$;R!?;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@
M;W(@;&ES="!M97-S86=E<R(*;7-G<W1R(")4]FUE9V5S(.ES(&QE=F5L97KU
M7VQI<W3A<R#\>F5N971E:W)E(&YE(&O\;&1J_&YK(';A;&%S>G0B"@HC.B!T
M96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C$P"FUS9VED(")$;R!T:&ES.B(*
M;7-G<W1R(")4961D(&5Z=#HB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@P"FUS
M9VED(")$;V5S;B=T(&)E9VEN('=I=&@B"FUS9W-T<B`B3F5M(&$@:_9V971K
M97KU=F5L(&ME>F3U9&EK(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W-@IM<V=I
M9"`B1&]E<VXG="!C;VYT86EN(@IM<V=S='(@(DYE;2!T87)T86QM87IZ82!A
M(&OV=F5T:V5Z]70B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@R"FUS9VED(")$
M;V5S;B=T(&5N9"!W:71H(@IM<V=S='(@(DYE;2!A(&OV=F5T:V5Z]79E;"!V
MZ6=Z]61I:R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#0*;7-G:60@(D1O97-N
M)W0@97AI<W0B"FUS9W-T<B`B3F5M(&SI=&5Z:6LB"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S@W"FUS9VED(")$;V5S;B=T(&UA=&-H("AW:71H('!L86-E:&]L
M9&5R<RDB"FUS9W-T<B`B3F5M('1A<G1A;&UA>GIA(&$@:_9V971K97KU="`H
M/R\J(&1Z<_-K97)R96PI(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R
M+FEN8SHR-B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C8Q"B,Z(&QI8B]";&]C
M:R]O=F5R=FEE=RYP:'`Z-C@@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HX,0HC
M.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C@Y"FUS9VED(")%9&ET(@IM<V=S
M='(@(DWS9&]S[73A<R(*"B,Z(&9I;'1E<G,N<&AP.C(P."!F:6QT97)S+G!H
M<#HR,3`@9FEL=&5R<RYP:'`Z,C$T(&9I;'1E<G,N<&AP.C(Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@(B5S(&WS9&]S[73A<V$B
M"@HC.B!F:6QT97)S+G!H<#HR-#<@9FEL=&5R<RYP:'`Z,C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5N86)L92`E<R(*;7-G<W1R("(E<R!E;F=E9.EL>65Z
MZ7-E(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR.`IM<V=I
M9"`B16YA8FQE9"(*;7-G<W1R(")%;F=E9.EL>65Z971T(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C,X,0IM<V=I9"`B16YD<R!W:71H(@IM<V=S='(@(D$@:_9V
M971K97KU=F5L(';I9WKU9&EK(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Y,@IM
M<V=I9"`B17%U86P@=&\B"FUS9W-T<B`B16=Y96YL]2!A(&OV=F5T:V5Z]2!S
M>N%M;6%L(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,SD@;&EB+T1R:79E
M<B]L9&%P+G!H<#HQ-#D@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-3@*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@<F5T<FEE=FEN9R!C=7)R96YT('-C<FEP=#H@*"5D*2`E<R(*;7-G<W1R
M(")(:6)A('3V<G3I;G0@82!S>OMR]69E;'3I=&5L96L@8F5O;'9A<^%S86MO
M<CH@*"5D*2`E<R(*"B,Z(&)L86-K;&ES="YP:'`Z-S$*;7-G:60@(D5R<F]R
M('-A=FEN9R!C:&%N9V5S+B(*;7-G<W1R(")(:6)A('3V<G3I;G0@82!VX6QT
M;WIT873A<V]K(&5L;65N=.ES96MO<BXB"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]H96%D97(N:6YC.C(R"FUS9VED(")%>&ES=&EN9R!2=6QE<R(*;7-G<W1R
M("),Z71E>O4@<WIA8N%L>6]K(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X,PIM
M<V=I9"`B17AI<W1S(@IM<V=S='(@(DSI=&5Z:6LB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%>'!E8W1E9"`Q
M(&]B:F5C="P@9V]T("5D+B(*;7-G<W1R(")!(';A<G0@,2!H96QY971T(&$@
M:V%P;W1T(&]B:F5K='5M;VL@<WKA;6$@)60N(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<V5T=&EN9W,N:6YC.C(P"FUS9VED(")&:6QT97(@06QL($UE<W-A
M9V5S(@IM<V=S='(@(M9S<WIE<R!L97;I;"!S>OMRZ7-E(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(R"FUS9VED(")&:6QT97(@3VYL
M>2!3965N($UE<W-A9V5S(@IM<V=S='(@(D-S86L@87H@;VQV87-O='0@;&5V
M96QE:R!S>OMRZ7-E(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N
M:6YC.C(Q"FUS9VED(")&:6QT97(@3VYL>2!5;G-E96X@365S<V%G97,B"FUS
M9W-T<B`B0W-A:R!A>B!O;'9A<V%T;&%N(&QE=F5L96L@<WK[<NES92(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHQ.`IM<V=I9"`B1FEL
M=&5R($]P=&EO;G,B"FUS9W-T<B`B4WK[<NES:2!B9>%L;.UTX7-O:R(*"B,Z
M('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,C4*;7-G:60@(D9I;'1E<B!2
M=6QE(@IM<V=S='(@(E-Z^W+I<VD@<WIA8N%L>2(*"B,Z(&9I;'1E<G,N<&AP
M.C$Q,PIM<V=I9"`B1FEL=&5R(%)U;&5S(@IM<V=S='(@(E-Z86+A;'EL:7-T
M82(*"B,Z('-C<FEP="YP:'`Z-3(*;7-G:60@(D9I;'1E<B!38W)I<'0@1&ES
M<&QA>2(*;7-G<W1R(")!('-Z^W+U<')O9W)A;2!M96=J96QE;NUTZ7-E(@H*
M(SH@;&EB+TEN9V\N<&AP.C,R,@IM<V=I9"`B1FEL=&5R(%]2=6QE<R(*;7-G
M<W1R(")?4WIA8N%L>6QI<W1A(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M
M97-S86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(E-Z^W+U9G5N:V-I\SH@)7,@;&5V96QE="#A=&AE;'EE
M>G3\;FL@82`E<R!M87!PX6)A+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z
M,S`Q"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@
M;65S<V%G92AS*2!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4WK[<O5F
M=6YK8VGS.B`E<R!L979E;&5T('3V<O9L=/QN:RXB"@HC.B!L:6(O4V-R:7!T
M+VEM87`N<&AP.C(W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R(")3>OMR]69U;FMC:?,Z("5S(&QE=F5L
M970@X71H96QY97IT_&YK(&$@)7,@;6%P<.%B82XB"@HC.B!L:6(O4V-R:7!T
M+VEM87`N<&AP.C$X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI
M<W0@=V5R92!D96QE=&5D+B(*;7-G<W1R("(B"B)3>OMR]69U;FMC:?,Z("5S
M(&]L>6%N(&QE=F5L970@=/9R]FQT_&YK+"!A;65L>2!M96=F96QE;'0@82!F
M96ME=&5L:7-TX6YA:RXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I960@=&\@
M=&AE("(*(F9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*(E-Z^W+U9G5N:V-I
M\SH@02`E<R!L979E;&5T+"!A;65L>2`E<RUT]6P@Z7)K97IE='0@X71H96QY
M97IT_&L@82`E<R!M87!PX6)A+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z
M,CDV"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@5&AE
M(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(E-Z^W+U9G5N:V-I\SH@7"(E<UPB+73U;"!<(B5S7"(M:6<@
M82!L979E;&5K970@=/9R]FQT_&LN(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H
M<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB1FEL=&5R(&%C=&EV:71Y
M.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@;6]V
M960@=&\@=&AE(&9O;&1E<B`B"B)<(B5S7"(N(@IM<V=S='(@(B(*(E-Z^W+U
M9G5N:V-I\SH@02`E<R!L979E;&5T+"!A;65L>2`E<RUT]6P@Z7)K97IE='0@
MX71H96QY97IT_&L@82`E<R!M87!PX6)A+B(*"B,Z(')U;&4N<&AP.C$V,`IM
M<V=I9"`B1FEL=&5R(&YO="!F;W5N9"XB"FUS9W-T<B`B3F5M(&SI=&5Z]2!S
M>F%BX6QY(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHT,@IM<V=I
M9"`B1F]R(&%N(&EN8V]M:6YG(&UE<W-A9V4@=&AA="!M871C:&5S.B(*;7-G
M<W1R("(B"B)!('-Z86+A;'D@87)R82!A(&)E:O9V]2!L97;I;')E(&QE<WH@
MZ7)VZ6YY97,L(&%M96QY(&UE9V9E;&5L(&%Z(&%LX6)B:2`B"B)F96QTZ71E
M;&5K.B(*"B,Z(&9I;'1E<G,N<&AP.C$V-R!T96UP;&%T97,O9F]R=V%R9"]F
M;W)W87)D+FEN8SHX(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C<*(SH@;&EB
M+T)L;V-K+V]V97)V:65W+G!H<#HV.0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R
M(")4;W;A8F+M=.%S(@H*(SH@9F]R=V%R9"YP:'`Z,38*;7-G:60@(D9O<G=A
M<F0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@
M9')I=F5R+B(*;7-G<W1R(")!('1O=N%B8NUTX7,@;F5M('3A;6]G871O='0@
M82!S>OMR]6UE9VAA:G3S8F%N(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP
M:'`Z,C@R(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(Q-`HC.B!L:6(O4V-R:7!T
M+VUA:6QD<F]P+G!H<#HR,C4*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E1O
M=N%B8NUTX7-O:R(*"B,Z(&9O<G=A<F0N<&AP.C0U"FUS9VED(")&;W)W87)D
M<R!%9&ET(@IM<V=S='(@(E1O=N%B8NUTX7-O:R!S>F5R:V5S>G3I<V4B"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,Y"FUS9VED(")&<F]M(@IM<V=S
M='(@(D9E;&%D\R(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(P-C(*;7-G
M:60@(D9R;VTZ(@IM<V=S='(@(D9E;&%D\SHB"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,SDP"FUS9VED(")'<F5A=&5R('1H86XB"FUS9W-T<B`B3F%G>6]B8B!M
M:6YT(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Y,0IM<V=I9"`B1W)E871E<B!T
M:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(DYA9WEO8F(@;6EN="P@=F%G>2!E
M9WEE;FSU(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,0IM<V=I
M9"`B26UP;W)T86YT(@IM<V=S='(@(D9O;G1O<R(*"B,Z(')U;&4N<&AP.C,V
M"FUS9VED("));F1I=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN
M('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(D$@<WK[
M<O5M96=H86IT\R!N96T@=.%M;V=A="!E9WEE9&D@<WIA8N%L>6]K870N(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3@V,`IM<V=I9"`B26YE>&ES=&%N
M="!M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G92!D96QI=F5R>2XB"FUS
M9W-T<B`B3F5M;.ET97KU(&/M;65T(&%D=&%K(&UE9R!L97;I;&OI>F)E<^UT
MZ7-R92XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S<W"FUS9VED("))<R(*;7-G
M<W1R(")!>F]N;W,@82!K]G9E=&ME>O5V96PB"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S<X"FUS9VED("))<VXG="(*;7-G<W1R(").96T@87IO;F]S(&$@:_9V
M971K97KU=F5L(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,PIM<V=I9"`B
M(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U
M;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+B(*;7-G<W1R("(B
M"B),1$%0('3A;6]G873A<W)A(&QE;FYE('-Z_&MSZ6<L(&1E(&%Z($Q$05`@
M;6]D=6P@;F5M(.%L;"!R96YD96QK97KI<W)E+"!V86=Y("(*(FYE;2!T]FQT
M]63V='0@8F4N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X.`IM<V=I9"`B3&5S
M<R!T:&%N(@IM<V=S='(@(DME=F5S96)B+"!M:6YT(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,X.0IM<V=I9"`B3&5S<R!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S
M='(@(DME=F5S96)B+"!V86=Y(&5G>65N;/4@;6EN="(*"B,Z(&-O;F9I9R]F
M:65L9',N<&AP+F1I<W0Z-3D*;7-G:60@(DQI<W0M240B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(P"FUS9VED
M(")-87)?:R!M97-S86=E(&%S(&1E;&5T960B"FUS9W-T<B`B7TIE;/9L:OQK
M(&UE9R!A(&QE=F5L970@=/9R]FQT;F5K(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M9F]O=&5R+FEN8SHR-`IM<V=I9"`B36%R:R!M97-S86=E(&%S.B(*;7-G<W1R
M(")*96SV;&K\:R!M96<@82!L979E;&5T(&$@:_9V971K97KU:^EP<&5N.B(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#8*;7-G:60@(DUA=&-H97,@*'=I=&@@
M<&QA8V5H;VQD97)S*2(*;7-G<W1R(")487)T86QM87IZ82!A(&OV=F5T:V5Z
M]70@*#\O*B!D>G/S:V5R<F5L*2(*"B,Z(&QI8B]A<&DN<&AP.C4W"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!2=6QE<R(*;7-G<W1R(")!('-Z^W+U<WIA
M8N%L>6]K(&UA>&EMX6QI<R!S>N%M82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HU
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@
M8FQA8VML:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S
M97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T
M(&%D9"!N97<@861D<F5S<V5S('1O(&)L86-K;&ES="XB"FUS9W-T<B`B(@HB
M5/IL;.EP=&4@82!T:6QT\VQI<W3A;B!TX7)O;&AA=/,@8^UM96L@;6%X:6WA
M;&ES86X@;65G96YG961E='0@<WKA;>%T("AC[6UE:R`B"B)S>N%M83H@)7,L
M(&UA>&EMX6QI<R!S>N%M.B`E<RDN($%Z(/IJ(&/M;2!N96T@:V5R_&QT(&9E
M;"!A(&QI<W3A<F$N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C4V-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O9B!W:&ET96QI<W1E
M9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L("(*
M(DUA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A
M9&1R97-S97,@=&\@=VAI=&5L:7-T+B(*;7-G<W1R("(B"B)4^FQLZ7!T92!A
M>B!E;F=E9.EL>65Z971T(&/M;65K(&QI<W3A:N%N('3A<F]L:&%T\R!E;&5M
M96L@;6%X:6WA;&ES86X@(@HB;65G96YG961E='0@<WKA;>%T("AC[6UE:R!S
M>N%M83H@)7,L(&UA>&EMX6QI<R!S>N%M.B`E<RDN($%Z(/IJ(&/M;2!N96T@
M(@HB:V5R_&QT(&9E;"!A(&QI<W3A<F$N(@H*(SH@;&EB+U-C<FEP="]S:65V
M92YP:'`Z,C`W,`IM<V=I9"`B36ES<VEN9R!A9&1R97-S('1O(&YO=&EF>2(*
M;7-G<W1R(")(:>%N>7II:R!A(&/M;2P@;65L>7)E(.ER=&5S[73I<W0@:V5L
M;&5N92!K_&QD96YI(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3<R.`IM
M<V=I9"`B36ES<VEN9R!A9&1R97-S('1O(')E9&ER96-T(&UE<W-A9V4@=&\B
M"FUS9W-T<B`B2&GA;GEZ:6L@82!C[6TL(&%M96QY<F4@X70@:V5L;"!I<N%N
M>>UT86YO;2!A(&QE=F5L970B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ
M-S8P"FUS9VED(")-:7-S:6YG(')E87-O;B!F;W(@<F5J96-T(@IM<V=S='(@
M(DAIX6YY>FEK(&$@=FES<WIA=71A<^UTX7-K;W(@:_QL9&5N9/4@:6YD;VLB
M"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ.3(W"FUS9VED(")-:7-S:6YG
M(')E87-O;B!I;B!V86-A=&EO;BXB"FUS9W-T<B`B2&GA;GEZ:6L@87H@875T
M;VUA=&EK=7,@=N%L87-Z;&5VZ6QB92#M<F%N9/,@_'IE;F5T+B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,CD*;7-G:60@(DUO=F4B"FUS
M9W-T<B`B36]Z9V%TX7,B"@HC.B!F:6QT97)S+G!H<#HQ,S$@9FEL=&5R<RYP
M:'`Z,C0P"FUS9VED(")-;W9E(%)U;&4@1&]W;B(*;7-G<W1R(")!('-Z86+A
M;'D@;&5J:F5B8B!LZ7!T973I<V4B"@HC.B!F:6QT97)S+G!H<#HQ,S(@9FEL
M=&5R<RYP:'`Z,C,Y"FUS9VED(")-;W9E(%)U;&4@57`B"FUS9W-T<B`B02!S
M>F%BX6QY(&9E:FQE8F(@;.EP=&5TZ7-E(@H*(SH@=&5M<&QA=&5S+W9A8V%T
M:6]N+W9A8V%T:6]N+FEN8SHT,@IM<V=I9"`B3E]U;6)E<B!O9B!D87ES(&)E
M='=E96X@=F%C871I;VX@<F5P;&EE<SHB"FUS9W-T<B`B16YN>6D@;F%P;VYK
MZ6YT(&O\;&1J_&YK(&-S86L@^FIB\VP@_%]Z96YE=&5T.B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHS('1E;7!L871E<R]F:6QT
M97)S+V9O;W1E<BYI;F,Z-0HC.B!L:6(O4W1O<F%G92YP:'`Z-S<Q"FUS9VED
M(").97<@4G5L92(*;7-G<W1R("+::B!S>F%BX6QY(@H*(SH@;&EB+TEN9V\N
M<&AP.C(Q-B!L:6(O26YG;RYP:'`Z,C$X"B,L('!H<"UF;W)M870*;7-G:60@
M(DYO(%PB)7-<(B!E;&5M96YT(&9O=6YD(&EN(&)A8VME;F0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B02!HX71TZ7)S>F]L9^%L=&%TX7,@8F7A;&SM=.%S
M86EB86X@;FEN8W,@7"(E<UPB(&5L96TN(@H*(SH@;&EB+TEN9V\N<&AP.C(Q
M-`IM<V=I9"`B3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0B
M"FUS9W-T<B`B17IE;B!A(&?I<&5N(&YI;F-S(&)EX6QL[71V82!A(&UE9V9E
M;&5L]2!HX71TZ7)S>F]L9^%L=&%TX7,B"@HC.B!L:6(O26YG;RYP:'`Z,3DQ
M"FUS9VED(").;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S+G!H
M<"(*;7-G<W1R(")!(&)A8VME;F0N<&AP(.%L;&]MX6YY8F%N(&YI;F-S(&)E
MX6QL[71V82!A(&CA='3I<G-Z;VQGX6QT873A<R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHS"B,L('!H<"UF;W)M870*;7-G:60@
M(DYO(&9I;'1E<G,N($-L:6-K(%PB)7-<(B!T;R!C<F5A=&4@82!N97<@9FEL
M=&5R+B(*;7-G<W1R(").:6YC<V5N96L@<WK[<O5K+B!+871T:6YT<V]N(%PB
M)7-<(BUR92!E9WD@^FH@;.ET<F5H;WKA<^%H;WHN(@H*(SH@;&EB+U-C<FEP
M="]S:65V92YP:'`Z,3,S,B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-#(U"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$U.3D*;7-G:60@(DYO(&AE861E<G,@
M<W!E8VEF:65D(@IM<V=S='(@(DYE;2!A9&]T="!M96<@9F5J;.EC96ME="(*
M"B,Z('-C<FEP="YP:'`Z-C<*;7-G:60@(DYO('-C<FEP="!G96YE<F%T960N
M(@IM<V=S='(@(D$@<WK[<O5L:7-TX70@;F5M(&9R:7-S[71E='1E;2(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$V,30*;7-G:60@(DYO('-T<FEN9W,@
M<W!E8VEF:65D(@IM<V=S='(@(DYE;2!A9&]T="!M96<@Z7)TZ6ME="(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS.3,*;7-G:60@(DYO="!E<75A;"!T;R(*;7-G
M<W1R(").96T@96=Y96YL]2!A(&OV=F5T:V5Z]2!S>N%M;6%L(@H*(SH@;&EB
M+U-T;W)A9V4N<&AP.C,U,PIM<V=I9"`B3F]T:69Y(&5M86EL(&%D9')E<W,B
M"FUS9W-T<B`B2V%P:F%K(.ER=&5S[73I<W0@82!K]G9E=&ME>O4@8^UM<F4B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0W"FUS9VED(")/;FQY(&9L86<@=&AE
M(&UE<W-A9V4B"FUS9W-T<B`B0W-A:R!J96SV;&K\:R!M96<@82!L979E;&5T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y"FUS9VED(")/<'1I;VYS
M(&%B;W5T('-C<FEP="!U<&1A=&EN9RXB"FUS9W-T<B`B02!S>OMR]6QI<W1A
M(&9R:7-S[73I<^EV96P@:V%P8W-O;&%T;W,@8F7A;&SM=.%S;VLN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/=&AE<B!/<'1I;VYS
M(@IM<V=S='(@(D5G>>EB(&)EX6QL[73A<V]K(@H*(SH@;&EB+T)L;V-K+V]V
M97)V:65W+G!H<#HS"FUS9VED(")/=F5R=FEE=R(*;7-G<W1R("+!='1E:VEN
M=.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;F5W7V9O;&1E<BYJ<SHV
M"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD
M97(Z(@IM<V=S='(@(DOI<F5M(&%D:F$@;65G(&%Z(/IJ(&UA<'!A(&YE=NET
M.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-C`*;7-G
M:60@(E)?96%S;VXB"FUS9W-T<B`B7U;A;&%S>OQZ96YE="(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z-C,*;7-G:60@(E)E8V5I=F5D(@IM<V=S='(@
M(D$@8F7I<FME>NES(&YA<&IA(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,R.`IM
M<V=I9"`B4F5D:7)E8W0@=&\B"FUS9W-T<B`BP71I<N%N>>UTX7,@97)R92!A
M(&/M;7)E(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X-0IM<V=I9"`B4F5G=6QA
M<B!E>'!R97-S:6]N(@IM<V=S='(@(E)E9W5LX7)I<R!K:69E:F5ZZ7,B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S0S"FUS9VED(")296IE8W0@=VET:"!R96%S
M;VXB"FUS9W-T<B`B07H@_'IE;F5T('9I<W-Z861O8N%S82!A(&OV=F5T:V5Z
M]2!I;F1O:VMA;"(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-34*;7-G
M:60@(E)E<V5N="!4;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O9FEE;&1S+G!H
M<"YD:7-T.C4Q"FUS9VED(")297-E;G0M9G)O;2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C8P"FUS9VED(")2971U<FX@=&\@
M1FEL=&5R<R!,:7-T(@IM<V=S='(@(E9I<W-Z82!A('-Z86+A;'EL:7-TX6AO
M>B(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR-"!T
M96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z-#$*(SH@=&5M<&QA
M=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHW,2!T96UP;&%T97,O9F]R=V%R
M9"]F;W)W87)D+FEN8SHS-`IM<V=I9"`B4F5T=7)N('1O(%)U;&5S($QI<W0B
M"FUS9W-T<B`B5FES<WIA(&$@<WIA8N%L>6QI<W3A:&]Z(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR-PIM<V=I9"`B4G5L92(*;7-G<W1R
M(")3>F%BX6QY(@H*(SH@9FEL=&5R<RYP:'`Z-C,*;7-G:60@(E)U;&4@0V]P
M:65D(@IM<V=S='(@(D$@<WIA8N%L>70@;&5MX7-O;'1A;2(*"B,Z(&9I;'1E
M<G,N<&AP.C0R"FUS9VED(")2=6QE($1E;&5T960B"FUS9W-T<B`B02!S>F%B
MX6QY="!T]G+V;'1E;2(*"B,Z(&9I;'1E<G,N<&AP.C<Y"FUS9VED(")2=6QE
M($1I<V%B;&5D(@IM<V=S='(@(D$@<WIA8N%L>70@;&5T:6QT;W1T=6LB"@HC
M.B!F:6QT97)S+G!H<#HX-`IM<V=I9"`B4G5L92!%;F%B;&5D(@IM<V=S='(@
M(D$@<WIA8N%L>70@96YG963I;'EE>G1E;2(*"B,Z('1E;7!L871E<R]R=6QE
M+VAE861E<BYI;F,Z,S,*;7-G:60@(E)U;&4@3F%M92(*;7-G<W1R(")3>F%B
MX6QY(&YE=F4B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HR,#8T"FUS9VED
M(")2=6QE.B(*;7-G<W1R(")3>F%BX6QY.B(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(E-405)45$Q3(&AI8F$Z("@E<RD@)7,B"@HC
M.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,C,@=&5M<&QA
M=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C0P"B,Z('1E;7!L871E<R]V
M86-A=&EO;B]V86-A=&EO;BYI;F,Z-S`@=&5M<&QA=&5S+V9O<G=A<F0O9F]R
M=V%R9"YI;F,Z,S,*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHU.0IM
M<V=I9"`B4V%V92(*;7-G<W1R(")-96YTZ7,B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]S971T:6YG<RYI;F,Z,CD*;7-G:60@(E-A=F4@4V5T=&EN9W,B"FUS
M9W-T<B`B0F7A;&SM=.%S;VL@96QM96YTZ7-E(@H*(SH@=&5M<&QA=&5S+W-C
M<FEP="]H96%D97(N:6YC.C(*;7-G:60@(E-C<FEP="(*;7-G<W1R(")3>OMR
M]6QI<W1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")3
M8W)I<'0@57!D871I;F<B"FUS9W-T<B`B4WK[<O5L:7-T82!F<FES<^UTZ7,B
M"@HC.B!L:6(O26YG;RYP:'`Z,C,Y"FUS9VED(")38W)I<'0@;F]T('5P9&%T
M960N(@IM<V=S='(@(D$@<WK[<O5L:7-TX70@;F5M(&9R:7-S[71E='1E;2XB
M"@HC.B!L:6(O26YG;RYP:'`Z,30Q"FUS9VED(")38W)I<'0@<W5C8V5S<V9U
M;&QY(&%C=&EV871E9"XB"FUS9W-T<B`B02!S>OMR]6QI<W1A(.ER=NEN>65S
M[73I<V4@;65G=/9R=.EN="XB"@HC.B!L:6(O26YG;RYP:'`Z,30P"FUS9VED
M(")38W)I<'0@<W5C8V5S<V9U;&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")!
M('-Z^W+U;&ES=&$@Z7)VZ6YY=&5L96[M=.ES92!M96=T]G)TZ6YT+B(*"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,CD*;7-G:60@(E-E96XB"FUS
M9W-T<B`B3VQV87-O='0B"@HC.B!R=6QE+G!H<#HQ.3`*;7-G:60@(E-E;&5C
M="!A(&9I96QD(@IM<V=S='(@(E;A;&%S<WIO;B!K:2!E9WD@;65Z]70B"@HC
M.B!L:6(O26YG;RYP:'`Z-3D*;7-G:60@(E-E;&5C="!T87)G970@9F]L9&5R
M(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@8^EL;6%P<.%T(@H*(SH@<G5L92YP
M:'`Z,C(W"FUS9VED(")396QF+41E9FEN960@2&5A9&5R(@IM<V=S='(@(L%L
M=&%L86T@;65G861O='0@9F5J;.EC(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HS-0IM<V=I9"`B4V5N9&5R(@IM<V=S='(@(DO\;&3U(@H*(SH@9FEL
M=&5R<RYP:'`Z.3@*;7-G:60@(E-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A
M=&5D+B(*;7-G<W1R(")!(&)EX6QL[73A<V]K870@<VEK97)E<V5N(.ER=NEN
M>65S[71E='1E;2XB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN
M8SHR-`IM<V=I9"`B4VAO=R!!8W1I=F4@4V-R:7!T(@IM<V=S='(@(D%K='7A
M;&ES('-Z^W+U;&ES=&$@;65G=&5K:6YTZ7-E(@H*(SH@=&5M<&QA=&5S+W-C
M<FEP="]A8W1I=F%T92YI;F,Z,S$*;7-G:60@(E-H;W<@0W5R<F5N="!38W)I
M<'0B"FUS9W-T<B`B07H@86MT=>%L:7,@<WK[<O5L:7-T82!M96=J96QE;NUT
MZ7-E(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HX,PIM<V=I9"`B4VEZ
M92(*;7-G<W1R(")-Z7)E="(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI
M;F,Z-#D*;7-G:60@(E-T;W`@8VAE8VMI;F<@:68@=&AI<R!R=6QE(&UA=&-H
M97,_(@IM<V=S='(@(DAA(&5Z(&$@<WIA8N%L>2!RX6EL;&EK(&%Z(/QZ96YE
M=')E+"!A('3V8F)I('-Z86+A;'ET(&YE(&1O;&=O>GIU:R!F96PB"@HC.B!T
M96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C4Q"FUS9VED(")3=6)J
M95]C="!O9B!V86-A=&EO;B!M97-S86=E.B(*;7-G<W1R(")!(';A;&%S>OQZ
M96YE="!?=.%R9WD@;65Z]6IE.B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I
M<W0Z,S$*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B5.%R9WDB"@HC.B!L:6(O
M4V-R:7!T+W-I979E+G!H<#HR,#8S"FUS9VED(")3=6)J96-T.B(*;7-G<W1R
M(")4X7)G>3HB"@HC.B!L:6(O87!I+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@861D<F5S<R!<(B5S7"(@:&%S(&)E96X@861D960@=&\@>6]U
M<B!B;&%C:VQI<W0N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&/M;65T(&AO>GKA
M=&5T=/QK(&%Z(-9N('1I;'3S;&ES=.%JX6AO>BXB"@HC.B!L:6(O87!I+G!H
M<#HQ,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@7"(E<UPB
M(&AA<R!B965N(&%D9&5D('1O('EO=7(@=VAI=&5L:7-T+B(*;7-G<W1R(")!
M*'HI(%PB)7-<(B!C[6UE="!H;WIZX71E='3\:R!A>B#6;B!E;F=E9.EL>65Z
MZ7-I(&QI<W3A:N%H;WHN(@H*(SH@;&EB+TEN9V\N<&AP.C$S-@IM<V=I9"`B
M5&AE(&1R:79E<B!S86ED.B`B"FUS9W-T<B`B02!M96=H86IT\R!A(&OV=F5T
M:V5Z]70@_'IE;G1E.B`B"@HC.B!L:6(O26YG;RYP:'`Z,3,U"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*;7-G
M<W1R(")(:6)A('3V<G3I;G0@82!S>OMR]6QI<W1A(&5N9V5DZ6QY97KI<V4@
M<V]RX6XN(@H*(SH@;&EB+TEN9V\N<&AP.C$S-`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*;7-G<W1R(")(
M:6)A('3V<G3I;G0@82!S>OMR]6QI<W1A(&QE=&EL=.%S82!S;W+A;BXB"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C(W"FUS9VED(")4;R(*;7-G<W1R
M(")#[6UZ971T(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+FAT;6PZ
M,C$*;7-G:60@(E1O.B(*;7-G<W1R(")#[6UZ971T.B(*"B,Z(&QI8B]38W)I
M<'0N<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT
M(&)E;VQV87-N:2`E<R!D969I;NUC:?-JX70N(@H*(SH@9FEL=&5R<RYP:'`Z
M,38Q('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-0HC.B!L:6(O
M4V-R:7!T+W!R;V-M86EL+G!H<#HR-C(@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,S4R"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C`@;&EB+T)L;V-K+V]V
M97)V:65W+G!H<#HV,@IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B075T;VUA
M=&EK=7,@=N%L87-Z;&5VZ6PB"@HC.B!V86-A=&EO;BYP:'`Z-S$*;7-G:60@
M(E9A8V%T:6]N($5D:70B"FUS9W-T<B`B07H@875T;VUA=&EK=7,@=N%L87-Z
M;&5VZ6P@<WIE<FME<WITZ7-E(@H*(SH@=F%C871I;VXN<&AP.C$V"FUS9VED
M(")686-A=&EO;B!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I
M;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(B(*(D$@:F5L96YL96=I('-Z^W+U
M;65G:&%J=/-V86P@;F5M(&QE:&5T(&%U=&]M871I:W5S(';A;&%S>OQZ96YE
M=&5T(&O\;&1E;FDN(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI
M<W0N:6YC.C$V"FUS9VED(")7:%]I=&5L:7-T(&%D9')E<W-E<SHB"FUS9W-T
M<B`B7T5N9V5DZ6QY97IE='0@8^UM96LB"@HC.B!F:6QT97)S+G!H<#HQ-34@
M=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C@*(SH@;&EB+T)L
M;V-K+V]V97)V:65W+G!H<#HW.2!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C@R
M"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B16YG963I;'EE>F5T="!C[6UE
M:R(*"B,Z('=H:71E;&ES="YP:'`Z-34*;7-G:60@(E=H:71E;&ES="!%9&ET
M(@IM<V=S='(@(D5N9V5DZ6QY97IE='0@8^UM96L@<WIE<FME<WITZ7-E(@H*
M(SH@=VAI=&5L:7-T+G!H<#HQ.`IM<V=I9"`B5VAI=&5L:7-T(&ES(&YO="!S
M=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS
M9W-T<B`B16=Y961I(&/M;65K(&5N9V5DZ6QY97KI<V4@;F5M('3A;6]G871O
M='0@82!S>OMR]6UE9VAA:G3S8F%N(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I
M;"YP:'`Z,C,T(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(Y.`HC.B!L:6(O4V-R
M:7!T+VUA:6QD<F]P+G!H<#HR,#,*;7-G:60@(E=H:71E;&ES=&5D($%D9')E
M<W-E<R(*;7-G<W1R(")%;F=E9.EL>65Z971T(&/M;65K(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HW.0IM<V=I9"`B6"U0<FEO<FET>2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C8W"FUS9VED(")8+5-P
M86TM3&5V96PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES
M=#HW,0IM<V=I9"`B6"U3<&%M+5-C;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z-S4*;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS
M9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z-38@<G5L92YP:'`Z,30T"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!R=6QE<RXB"FUS9W-T<B`B3F5M(&AO>FAA="!LZ71R
M92!T]F)B+"!M:6YT("5D('-Z^W+U<WIA8N%L>70N(@H*(SH@9FEL=&5R<RYP
M:'`Z-#@@<G5L92YP:'`Z,C$*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&]R(&5D:70@8W5S=&]M(')U;&5S+B(*;7-G<W1R(").96T@
M:&]Z:&%T(&SI=')E(&EL;"X@;F5M(&WS9&]S[71H870@<V%JX70@<WIA8N%L
M>6]K870N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V,0IM<V=I9"`B
M66]U(&AA=F4@<F5C96EV960@82!N97<@;65S<V%G92(*;7-G<W1R("+)<FME
M>F5T="!E9WD@^FH@;&5V96QE(@H*(SH@=F%C871I;VXN<&AP.C,P"FUS9VED
M("(B"B)9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!E;6%I;"!A9&1R
M97-S(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@;65S<V%G97,@(@HB<VAO=6QD
M(&)E(&%C=&EV871E9"XB"FUS9W-T<B`B(@HB3&5G86SA8F(@96=Y(&]L>6%N
M(&/M;65T(&UE9R!K96QL(&%D;FEA+"!A;65L>7)E(&$@=F%KX6-I\R#\>F5N
M971E:V5T("(*(F5N9V5DZ6QY97IZ_&LN(@H*(SH@;&EB+U-C<FEP="]I;6%P
M+G!H<#HR-S0@;&EB+U-C<FEP="]I;6%P+G!H<#HR.3<@;&EB+U-C<FEP="]I
M;6%P+G!H<#HS,3$*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");5.%R
M9WD@;NEL:_QL72(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC
M.C(T"FUS9VED(")?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SHB"FUS9W-T
M<B`B7T/M;2AE:RDL(&%M96QY96MR92!T;W;A8F+M=&IU:R!A>B#\>F5N971E
M=#HB"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C(S"FUS
M9VED(")?061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SHB"FUS
M9W-T<B`B02!K]G9E=&ME>O4@8^UM96MR92!?;F4@:_QL9&K\;FL@=N%L87-Z
M=#HB"@HC.B!L:6(O26YG;RYP:'`Z,S(W"FUS9VED(")?0FQA8VML:7-T(@IM
M<V=S='(@(E]4:6QT;W1T(&/M;65K(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES
M="]B;&%C:VQI<W0N:6YC.C$X"FUS9VED(")?1&5L971E(&UE<W-A9V4@8V]M
M<&QE=&5L>2(*;7-G<W1R(")6Z6?I<G;I;GEE<V5N('3V7W+V;&K\:R!A(&QE
M=F5L970B"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M,S$*;7-G:60@(E]%;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN93HB
M"FUS9W-T<B`BS7)J82!B92!A(%]C[6UE:V5T+"!M:6YD96=Y:6ME="#Z:B!S
M;W)B82XB"@HC.B!L:6(O26YG;RYP:'`Z,S,S"FUS9VED(")?1F]R=V%R9"(*
M;7-G<W1R(")47V]VX6)B[73A<R(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O
M<G=A<F0N:6YC.C$W"FUS9VED(")?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@
M:6X@=&AI<R!A8V-O=6YT/R(*;7-G<W1R(")487)T<W5K(&UE9R!A>B#\>F5N
M970@96=Y(&WA<V]L873A="XB"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L
M86-K;&ES="YI;F,Z,C(*;7-G:60@(E]-;W9E(&UE<W-A9V4@=&\@9F]L9&5R
M.B(*;7-G<W1R(")496=Y_&L@X70@87H@_'IE;F5T970@82!K]G9E=&ME>O4@
M7VUA<'#A8F$Z(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN
M8SHQ,PIM<V=I9"`B7TUY(&5M86EL(&%D9')E<W-E<SHB"FUS9W-T<B`B07H@
MZ6X@92UM86EL(%]C[6UE:6TZ(@H*(SH@;&EB+TEN9V\N<&AP.C,S-@IM<V=I
M9"`B7U-C<FEP="(*;7-G<W1R(")3>OMR]5]P<F]G<F%M(@H*(SH@;&EB+TEN
M9V\N<&AP.C,S,`IM<V=I9"`B7U9A8V%T:6]N(@IM<V=S='(@(E]!=71O;6%T
M:6MU<R!VX6QA<WIL97;I;"(*"B,Z(&QI8B]);F=O+G!H<#HS,C0*;7-G:60@
M(E]7:&ET96QI<W0B"FUS9W-T<B`B7T5N9V5DZ6QY97IE='0@8^UM96LB"@HC
M.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C4T"FUS9VED(")A8W1I=F4B"FUS
M9W-T<B`B86MT[78B"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C0*
M;7-G:60@(F%N9"(*;7-G<W1R("+I<R(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+V9I;'1E<BYH=&UL.C$S"FUS9VED(")D:7-A8FQE9"`M(&-L:6-K('1O(&5N
M86)L92(*;7-G<W1R(")L971I;'1V82`M(&%Z(&5N9V5DZ6QY97KI<VAE>B!K
M871T:6YT<V]N(&ED92(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B9FEE
M;&0B"FUS9W-T<B`B;65Z]2(*"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z
M-3(*;7-G:60@(FEN86-T:79E(@IM<V=S='(@(FEN86MT[78B"@HC.B!L:6(O
M4V-R:7!T+VUA:6QD<F]P+G!H<#HQ,C$*;7-G:60@(FUA:6QD<F]P('-C<FEP
M="!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R(")A(&UA:6QD<F]P('-Z:W)I
M<'1E="!A>B!);F=O(&ME<WII=&5T=&4B"@HC.B!F:6QT97)S+G!H<#HQ.#4*
M;7-G:60@(FUA=&-H(@IM<V=S='(@(F5G>65ZZ7,B"@HC.B!T96UP;&%T97,O
M<G5L92]F:6QT97(N:6YC.C0*;7-G:60@(F]R(@IM<V=S='(@(G9A9WDB"@HC
M.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HQ,C@*;7-G:60@(G!R;V-M86EL
M('-C<FEP="!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R(")A('!R;V-M86EL
M('-Z:W)I<'1E="!A>B!);F=O(&ME<WII=&5T=&4B"@HC.B!L:6(O4V-R:7!T
M+W-I979E+G!H<#HQ,3`*;7-G:60@(G-I979E(&9I;'1E<B!G96YE<F%T960@
M8GD@26YG;R(*;7-G<W1R(")!('-I979E('-Z=7)O="!A>B!);F=O(&ME<WII
M=&5T=&4B"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]P;R]F:5]&22YP;P``````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U,S8S-0`Q,#0Q
M-S,V,C<T-P`P,3<S,C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!&:6YN:7-H('1R86YS;&%T:6]N(&9O<B!);F=O+@HC
M($-O<'ER:6=H="`H0RD*(R!,965N82!(96EN;R`\;&EI;G5`=71A+F9I/BP@
M,C`P,RTR,#`V+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U6
M97)S:6]N.B!);F=O(#$N,2UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-BTP,BTR-B`Q,CHR,2LP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R
M,#`V+3`R+3(V(#$R.C4Y*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@3&5E
M;F$@2&5I;F\@/&QI:6YU0'5T82YF:3Y<;B(*(DQA;F=U86=E+51E86TZ($9I
M;FYI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI
M<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I
M=%QN(@H*(SH@9FEL=&5R<RYP:'`Z,3DP"FUS9VED("(@86YD(@IM<V=S='(@
M(B!J82(*"B,Z(&9I;'1E<G,N<&AP.C$Y,`IM<V=I9"`B(&]R(@IM<V=S='(@
M(B!T86DB"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M,3<*;7-G:60@(D%C=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S<V5S.B(*
M;7-G<W1R(")4;VEM:6YT;R!M=7-T86QI<W1A='5I;&QE(&]S;VET=&5I;&QE
M.B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$P"FUS9VED
M(")!8W1I=F%T92!38W)I<'0B"FUS9W-T<B`B06MT:79O:2!S:W)I<'1I(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B06-T:79A=&EN9R!T:&4@<V-R:7!T(&9O<B!<(B5S7"(@9F%I;&5D.B`H
M)60I("5S(@IM<V=S='(@(E-K<FEP=&EN(&%K=&EV;VEN=&D@7"(E<UPB.FQL
M92!E<.1O;FYI<W1U:3H@*"5D*2`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W-E='1I;F=S+FEN8SHV"FUS9VED(")!9&1I=&EO;F%L(%-E='1I;F=S(@IM
M<V=S='(@(DQI<^1A<V5T=6MS970B"@HC.B!T96UP;&%T97,O<G5L92]H96%D
M97(N:6YC.C0T"FUS9VED(")!;&P@;V8@=&AE(&9O;&QO=VEN9R(*;7-G<W1R
M(")+86EK:VD@<V5U<F%A=F%T(@H*(SH@;&EB+V%P:2YP:'`Z-30*;7-G:60@
M(D%L;&]W(%)U;&5S(@IM<V=S='(@(E-A;&QI('/DY&YN]G0B"@HC.B!T96UP
M;&%T97,O<G5L92]F;V]T97(N:6YC.C,S"FUS9VED(")!;G-W97)E9"(*;7-G
M<W1R(")687-T871T=2(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z
M-#4*;7-G:60@(D%N>2!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@(DIO:VEN
M('-E=7)A879I<W1A(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN
M8SHW"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(E-U;V1A=&$@=FEE
M<W1I="(*"B,Z(&9I;'1E<G,N<&AP.C(Q.0IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1E;&5T92!T:&ES(')U;&4_(@IM<V=S='(@(D]L971K
M;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82!TY&WD;B!SY.1N;O9N/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B075T;VUA=&EC
M86QL>2!U<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\B"FUS
M9W-T<B`B4.1I=FETY"!S:W)I<'1I(&IO:V%I<V5N(&UU=71O:W-E;B!JY&QK
M965N+B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-#<*;7-G:60@(D)C
M8R(*;7-G<W1R(")0:6EL;VMO<&EO(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W
M.0IM<V=I9"`B0F5G:6YS('=I=&@B"FUS9W-T<B`B06QK86$B"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C$P-B!L:6(O1')I=F5R+VQD87`N<&AP.C$Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G
M<W1R(")9:&1I<W3D;6EN96X@97#D;VYN:7-T=6DZ("@E<RD@)7,B"@HC.B!F
M:6QT97)S+G!H<#HQ-#D@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N
M:6YC.C<*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HX-R!L:6(O0FQO8VLO
M;W9E<G9I97<N<&AP.CDP"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`B375S
M=&$@;&ES=&$B"@HC.B!B;&%C:VQI<W0N<&AP.C$P-PIM<V=I9"`B0FQA8VML
M:7-T($5D:70B"FUS9W-T<B`B375S=&%N(&QI<W1A;B!M=6]K:V%U<R(*"B,Z
M(&)L86-K;&ES="YP:'`Z,3<*;7-G:60@(D)L86-K;&ES="!I<R!N;W0@<W5P
M<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S
M='(@(DOD>73V<W/D(&]L979A('-U;V1A=&EN86IU<FD@96D@='5E(&UU<W1I
M82!L:7-T;VIA+B(*"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C$W-B!L
M:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR,#<*(SH@;&EB+U-C<FEP="]S:65V
M92YP:'`Z,C0T"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S97,B"FUS9W-T
M<B`B375S=&%L;&4@;&ES=&%L;&4@;&ESY'1Y="!O<V]I='1E970B"@HC.B!C
M;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C@X"FUS9VED(")";V1Y(@IM<V=S='(@
M(E-I<^1L=/8B"@HC.B!F:6QT97)S+G!H<#HQ.#<@<G5L92YP:'`Z,C@Q"FUS
M9VED(")#87-E(%-E;G-I=&EV92(*;7-G<W1R(")+:7)J86EN:V]K;W)I:7!P
M=79A:6YE;B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-#,*;7-G:60@
M(D-C(@IM<V=S='(@(DMO<&EO(@H*(SH@8FQA8VML:7-T+G!H<#HW,R!F;W)W
M87)D+G!H<#HS,R!R=6QE+G!H<#HQ,C(@=F%C871I;VXN<&AP.C0Q"B,Z('=H
M:71E;&ES="YP:'`Z,S8*;7-G:60@(D-H86YG97,@<V%V960N(@IM<V=S='(@
M(DUU=71O:W-E="!T86QL971E='1I:6XN(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HW-0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(EEH
M=&5Y<R!E<.1O;FYI<W1U:2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-S4*;7-G
M:60@(D-O;G1A:6YS(@IM<V=S='(@(E-I<^1L=.3D(@H*(SH@9FEL=&5R<RYP
M:'`Z,C,P(&9I;'1E<G,N<&AP.C(S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W!Y("5S(@IM<V=S='(@(DMO<&EO:2`E<R(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HX-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!O9B`E<R(*;7-G<W1R
M("(E<SIN(&MO<&EO(@H*(SH@;&EB+TEN9V\N<&AP.C8R"FUS9VED(")#<F5A
M=&4@;F5W(&9O;&1E<B(*;7-G<W1R("),=6\@=75S:2!K86YS:6\B"@HC.B!L
M:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HR.#`@;&EB+U-C<FEP="]P<F]C;6%I
M;"YP:'`Z,S,V"FUS9VED(")$25-!0DQ%1#H@(@IM<V=S='(@(E!/25,@4,3$
M3%3$.B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$W"FUS
M9VED(")$96%C=&EV871E(%-C<FEP="(*;7-G<W1R(")0;VES=&$@<VMR:7!T
M:2!KY'ET]G-TY"(*"B,Z(&9I;'1E<G,N<&AP.C(Q.2!F:6QT97)S+G!H<#HR
M,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(@IM<V=S='(@(E!O
M:7-T82`E<R(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z,S`*;7-G
M:60@(D1E;&5T92!#;VYD:71I;VXB"FUS9W-T<B`B4&]I<W1A('/DY&YT]B(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS,C,*;7-G:60@(D1E;&5T92!M97-S86=E
M(&-O;7!L971E;'DB"FUS9W-T<B`B4&]I<W1A('9I97-T:2!K;VMO;F%A;B(*
M"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S4*;7-G:60@(D1E;&5T
M960B"FUS9W-T<B`B4&]I<W1E='1U(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Q
M,0IM<V=I9"`B1&5L:79E<B!I;G1O(&UY($EN8F]X(@IM<V=S='(@(DQA:71A
M('9I97-T:2!)3D)/6"!P;W-T:6MA;G-I;V]N:2(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS,S<*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!);F)O>"!A;F0@8V]P
M>2!T;R(*;7-G<W1R("),86ET82!V:65S=&D@24Y"3U@@<&]S=&EK86YS:6]O
M;FD@:F$@:V]P:6]I(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,S,@IM<V=I9"`B
M1&5L:79E<B!I;G1O(&UY($EN8F]X(&%N9"!R961I<F5C="!T;R(*;7-G<W1R
M("),86ET82!V:65S=&D@24Y"3U@@<&]S=&EK86YS:6]O;FD@:F$@=75D96QL
M965N;VAJ86$@;W-O:71T965S965N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Q
M-PIM<V=I9"`B1&5L:79E<B!T;R!F;VQD97(B"FUS9W-T<B`B3&%I=&$@=FEE
M<W1I('3D:.1N(&MA;G-I;V]N(@H*(SH@9FEL=&5R<RYP:'`Z,C0S(&9I;'1E
M<G,N<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$:7-A8FQE("5S(@IM
M<V=S='(@(E!O:7-T82!KY'ET]G-TY"`E<R(*"B,Z('1E;7!L871E<R]W:&ET
M96QI<W0O=VAI=&5L:7-T+FEN8SHQ,"!T96UP;&%T97,O=F%C871I;VXO=F%C
M871I;VXN:6YC.C8*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHR-B!T
M96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHQ,`HC.B!T96UP;&%T97,O
M8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,3`*;7-G:60@(D1I<V%B;&5D(@IM
M<V=S='(@(E!O:7-T971T=2!KY'ET]G-TY"(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W-E='1I;F=S+FEN8SHQ,PIM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!N
M;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/R(*;7-G
M<W1R(").Y'ETY"!I;&UO:71U<R!J;VMA:7-E;&QA('-U;V1A='1I;65N(&OD
M>71T]FME<G)A;&QA+B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO
M;BYI;F,Z,S0*;7-G:60@(D1O(%]N;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L
M:R!O<B!L:7-T(&UE<W-A9V5S(@IM<V=S='(@(L1LY"!LY&AE=.0@=F%S=&%U
M<W9I97-T:>0@:F]U:VMO=FEE<W1E:6AI;B!T86D@<&]S=&EL:7-T879I97-T
M96EH:6XB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C$P"FUS9VED
M(")$;R!T:&ES.B(*;7-G<W1R(")4964@=.1MY#HB"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S@P"FUS9VED(")$;V5S;B=T(&)E9VEN('=I=&@B"FUS9W-T<B`B
M16D@86QA(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W-@IM<V=I9"`B1&]E<VXG
M="!C;VYT86EN(@IM<V=S='(@(D5I('-I<^1L;.0B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S@R"FUS9VED(")$;V5S;B=T(&5N9"!W:71H(@IM<V=S='(@(D5I
M('#DY'1Y(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X-`IM<V=I9"`B1&]E<VXG
M="!E>&ES="(*;7-G<W1R(")%:2!O;&4@;VQE;6%S<V$B"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,S@W"FUS9VED(")$;V5S;B=T(&UA=&-H("AW:71H('!L86-E
M:&]L9&5R<RDB"FUS9W-T<B`B16D@=.1S;>3D("AP;&%C96AO;&1E<FEE;B!K
M86YS<V$I(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR-B!L
M:6(O0FQO8VLO;W9E<G9I97<N<&AP.C8Q"B,Z(&QI8B]";&]C:R]O=F5R=FEE
M=RYP:'`Z-C@@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HX,0HC.B!L:6(O0FQO
M8VLO;W9E<G9I97<N<&AP.C@Y"FUS9VED(")%9&ET(@IM<V=S='(@(DUU;VMK
M86$B"@HC.B!F:6QT97)S+G!H<#HR,#@@9FEL=&5R<RYP:'`Z,C$P(&9I;'1E
M<G,N<&AP.C(Q-"!F:6QT97)S+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="`E<R(*;7-G<W1R(")-=6]K:V%A("5S(@H*(SH@9FEL=&5R<RYP
M:'`Z,C0W(&9I;'1E<G,N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;F%B;&4@)7,B"FUS9W-T<B`B3&%I=&$@<.3D;&QE("5S(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR.`IM<V=I9"`B16YA8FQE9"(*;7-G
M<W1R(")0Y.1L;.0B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@Q"FUS9VED(")%
M;F1S('=I=&@B"FUS9W-T<B`B4.3D='1Y>2(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS.3(*;7-G:60@(D5Q=6%L('1O(@IM<V=S='(@(D]N('EH=.1S=75R:6MU
M:6XB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$S.2!L:6(O1')I=F5R+VQD
M87`N<&AP.C$T.2!L:6(O1')I=F5R+VQD87`N<&AP.C$U.`HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R
M971R:65V:6YG(&-U<G)E;G0@<V-R:7!T.B`H)60I("5S(@IM<V=S='(@(E9I
M<FAE(&AA971T865S<V$@=.1MY&YH971K:7-TY"!S:W)I<'1IY#H@*"5D*2`E
M<R(*"B,Z(&)L86-K;&ES="YP:'`Z-S$*;7-G:60@(D5R<F]R('-A=FEN9R!C
M:&%N9V5S+B(*;7-G<W1R(")6:7)H92!T86QL971E='1A97-S82!M=75T;VMS
M:6$N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR,@IM<V=I
M9"`B17AI<W1I;F<@4G5L97,B"FUS9W-T<B`B3VQE;6%S<V%O;&5V870@<^3D
M;F[V="(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#,*;7-G:60@(D5X:7-T<R(*
M;7-G<W1R(")/;&5M87-S82(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5X<&5C=&5D(#$@;V)J96-T+"!G;W0@
M)60N(@IM<V=S='(@(D]D;W1E='1I:6X@,2!O8FIE:W1I+"!S86%T:6EN("5D
M+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,`IM<V=I
M9"`B1FEL=&5R($%L;"!-97-S86=E<R(*;7-G<W1R(")3=6]D871A(&MA:6MK
M:2!V:65S=&ET(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC
M.C(R"FUS9VED(")&:6QT97(@3VYL>2!3965N($UE<W-A9V5S(@IM<V=S='(@
M(E-U;V1A=&$@=F%I;B!V86YH870@=FEE<W1I="(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W-E='1I;F=S+FEN8SHR,0IM<V=I9"`B1FEL=&5R($]N;'D@56YS
M965N($UE<W-A9V5S(@IM<V=S='(@(E-U;V1A=&$@=F%I;B!U=61E="!V:65S
M=&ET(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C$X"FUS
M9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(")3=6]D871I;B!A<V5T=6MS
M970B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C(U"FUS9VED(")&
M:6QT97(@4G5L92(*;7-G<W1R(")3=6]D871I;G/DY&YT]B(*"B,Z(&9I;'1E
M<G,N<&AP.C$Q,PIM<V=I9"`B1FEL=&5R(%)U;&5S(@IM<V=S='(@(E-U;V1A
M=&EN<^3D;F[V="(*"B,Z('-C<FEP="YP:'`Z-3(*;7-G:60@(D9I;'1E<B!3
M8W)I<'0@1&ES<&QA>2(*;7-G<W1R(")3=6]D871U<W-K<FEP=&D@;N1K>6WD
M(@H*(SH@;&EB+TEN9V\N<&AP.C,R-`IM<V=I9"`B1FEL=&5R(%]2=6QE<R(*
M;7-G<W1R(")3=6]D871I7VYSY.1N;O9T(@H*(SH@;&EB+U-C<FEP="]I;6%P
M+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y
M.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(E-U;V1A=&EN=&]I;6EN=&\Z("5S('9I97-T
M:>0@;VX@<VEI<G)E='1Y(&MA;G-I;V]N(%PB)7-<(BXB"@HC.B!L:6(O4V-R
M:7!T+VEM87`N<&AP.C,P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@
M86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&1E;&5T960N(@IM
M<V=S='(@(E-U;V1A=&EN=&]I;6EN=&\Z("5S('9I97-T:>0@;VX@<&]I<W1E
M='1U+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E
M(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E-U
M;V1A=&EN=&]I;6EN=&\Z("5S('9I97-T:>0@;VX@<VEI<G)E='1Y(&MA;G-I
M;V]N(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C$X,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H
M<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@=V5R92!D96QE=&5D+B(*
M;7-G<W1R(")3=6]D871I;G1O:6UI;G1O.B`E<R!M=7-T86QL82!L:7-T86QL
M82!O;&5V86$@=FEE<W1IY"!O;B!P;VES=&5T='4N(@H*(SH@;&EB+U-C<FEP
M="]I;6%P+G!H<#HS,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB1FEL=&5R
M(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S
M(&)E96X@8V]P:65D('1O('1H92`B"B)F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("(B"B)3=6]D871I;G1O:6UI;G1O.B!6:65S=&D@7"(E<UPB(&]S;VET=&5E
M<W1A(%PB)7-<(B!O;B!K;W!I;VET=2!K86YS:6]O;B!<(B5S(@HB7"(N(@H*
M(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4W5O9&%T:6YT;VEM
M:6YT;SH@5FEE<W1I(%PB)7-<(B!O<V]I='1E97-T82!<(B5S7"(@;VX@<&]I
M<W1E='1U+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<S"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@
M7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&UO=F5D('1O('1H92!F;VQD
M97(@(@HB7"(E<UPB+B(*;7-G<W1R("(B"B)3=6]D871I;G1O:6UI;G1O.B!6
M:65S=&D@7"(E<UPB(&]S;VET=&5E<W1A(%PB)7-<(B!O;B!S:6ER<F5T='D@
M:V%N<VEO;VX@7"(E<R(*(EPB+B(*"B,Z(')U;&4N<&AP.C$V,`IM<V=I9"`B
M1FEL=&5R(&YO="!F;W5N9"XB"FUS9W-T<B`B4W5O9&%T:6YT82!E:2!L]GET
M>6YY="(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#(*;7-G:60@
M(D9O<B!A;B!I;F-O;6EN9R!M97-S86=E('1H870@;6%T8VAE<SHB"FUS9W-T
M<B`B2V%I:VEL;&4@='5L979I;&QE('9I97-T96EL;&4L(&IO=&MA('-O<&EV
M870Z(@H*(SH@9FEL=&5R<RYP:'`Z,38W('1E;7!L871E<R]F;W)W87)D+V9O
M<G=A<F0N:6YC.C@@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV-PHC.B!L:6(O
M0FQO8VLO;W9E<G9I97<N<&AP.C8Y"FUS9VED(")&;W)W87)D(@IM<V=S='(@
M(E5U9&5L;&5E;F]H:F%A(@H*(SH@9F]R=V%R9"YP:'`Z,38*;7-G:60@(D9O
M<G=A<F0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I
M;F<@9')I=F5R+B(*;7-G<W1R(")+Y'ET]G-SY"!O;&5V82!A:G5R:2!E:2!T
M=64@=75D96QL965N;VAJ875S=&$N(@H*(SH@;&EB+U-C<FEP="]M86EL9')O
M<"YP:'`Z,C(U(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(X,@HC.B!L:6(O
M4V-R:7!T+W-I979E+G!H<#HR,30*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@
M(E5U9&5L;&5E;F]H:F%U:W-E="(*"B,Z(&9O<G=A<F0N<&AP.C0U"FUS9VED
M(")&;W)W87)D<R!%9&ET(@IM<V=S='(@(E5U9&5L;&5E;F]H:F%U:W-E;B!M
M=6]K:V%U<R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,SD*;7-G:60@
M(D9R;VTB"FUS9W-T<B`B3.1H971TY&KD(@H*(SH@;&EB+U-C<FEP="]S:65V
M92YP:'`Z,C`V,@IM<V=I9"`B1G)O;3HB"FUS9W-T<B`B3.1H971TY&KD.B(*
M"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$Q,`IM<V=I9"`B1V5N97)A=&5D
M(&)Y($EN9V\@*&AT='`Z+R]W=W<N:&]R9&4N;W)G+VEN9V\O*2(*;7-G<W1R
M("));F=O(&]H:F5L;6%N('1U;W1T86UA("AH='1P.B\O=W=W+FAO<F1E+F]R
M9R]I;F=O+RDB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,SDP"FUS9VED(")'<F5A
M=&5R('1H86XB"FUS9W-T<B`B4W5U<F5M<&D@:W5I;B(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS.3$*;7-G:60@(D=R96%T97(@=&AA;B!O<B!E<75A;"!T;R(*
M;7-G<W1R(")3=75R96UP:2!T86D@>6ATY"!S=75R:2!K=6EN(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,0IM<V=I9"`B26UP;W)T86YT(@IM
M<V=S='(@(E3D<FMEY"(*"B,Z(')U;&4N<&AP.C,V"FUS9VED("));F1I=FED
M=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I
M;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(DOD>73V<W/D(&]L979A(&%J=7)I
M(&5I('1U92!Y:W-I='3D:7-IY"!S=6]D871I;G/DY&YT]FKD+B(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C$X-C`*;7-G:60@(DEN97AI<W1A;G0@;6%I
M;&)O>"!S<&5C:69I960@9F]R(&UE<W-A9V4@9&5L:79E<GDN(@IM<V=S='(@
M(EER:73D="!O:&IA=&$@=FEE<W1E:N0@;VQE;6%T=&]M86%N('!O<W1I:V%N
M<VEO;VXN(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W-PIM<V=I9"`B27,B"FUS
M9W-T<B`B3VXB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S<X"FUS9VED("))<VXG
M="(*;7-G<W1R(")%:2!O;&4B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(S
M"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,
M1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(@IM
M<V=S='(@(B(*(DQ$05`M='5K:2!O;B!P86MO;&QI;F5N+"!M=71T82!,1$%0
M+6UO9'5U;&D@96D@;VQE(&OD>71E='3D=FES<^0@=&%I(&]L92`B"B)L861A
M='1U+B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#@*;7-G:60@(DQE<W,@=&AA
M;B(*;7-G<W1R(")0:65N96UP:2!K=6EN(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,X.0IM<V=I9"`B3&5S<R!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(E!I
M96YE;7!I('1A:2!Y:'3D('-U=7)I(&MU:6XB"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C4Y"FUS9VED("),:7-T+4E$(@IM<V=S='(@(DQI<W0M240B
M"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,C`*;7-G
M:60@(DUA<E]K(&UE<W-A9V4@87,@9&5L971E9"(*;7-G<W1R(")-97)K:71S
M92!V:65S=&D@<&]I<W1E='5K<VDB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T
M97(N:6YC.C(T"FUS9VED(")-87)K(&UE<W-A9V4@87,Z(@IM<V=S='(@(DUE
M<FMI='-E('9I97-T:3HB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@V"FUS9VED
M(")-871C:&5S("AW:71H('!L86-E:&]L9&5R<RDB"FUS9W-T<B`B5.1S;>3D
M("AP;&%C96AO;&1E<FEN(&MA;G-S82DB"@HC.B!L:6(O87!I+G!H<#HU-PIM
M<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4G5L97,B"FUS9W-T<B`B4^3D;G3V
M:F5N(&5N:6UMY&ES;>3D<N0B"@HC.B!L:6(O4W1O<F%G92YP:'`Z-3$S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@;G5M8F5R(&]F(&)L86-K
M;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E
M<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@
M;F5W(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N(@IM<V=S='(@(B(*(DUU<W1A
M;&QA(&QI<W1A;&QA(&]N('-U=7)I;B!S86QL:71T=2!MY.1RY"!O<V]I='1E
M:71A("A/<V]I='1E:71A('EH=&5E;G/D.B`E(@HB<RP@4W5U<FEN('-A;&QI
M='1U(&WDY'+D.B`E<RDN(%5U='1A(&]S;VET971T82!E:2!V;VET=2!L:7/D
M=.0@;75S=&%L;&4@(@HB;&ES=&%L;&4N(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C4V-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O
M9B!W:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E
M<W-E<SH@)7,L("(*(DUA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N
M;W0@861D(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+B(*;7-G<W1R("(B
M"B)686QK;VES96QL82!L:7-T86QL82!O;B!S=75R:6X@<V%L;&ET='4@;>3D
M<N0@;W-O:71T96ET82`H3W-O:71T96ET82`B"B)Y:'1E96YSY#H@)7,L(%-U
M=7)I;B!S86QL:71T=2!MY.1RY#H@)7,I+B!5=71T82!O<V]I=&5T=&$@96D@
M=F]I='4@;&ESY'3D("(*(G9A;&MO:7-E;&QE(&QI<W1A;&QE+B(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C(P-S`*;7-G:60@(DUI<W-I;F<@861D<F5S
M<R!T;R!N;W1I9GDB"FUS9W-T<B`B26QM;VET=7-V:65S=&EN(&MO:&1E;W-O
M:71E('!U=71T=74B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-S(X"FUS
M9VED(")-:7-S:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G92!T;R(*
M;7-G<W1R(")6:65S=&EN('5U9&5L;&5E;F]H:F%U:W-E;B!K;VAD96]S;VET
M92!P=75T='5U(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3<V,`IM<V=I
M9"`B36ES<VEN9R!R96%S;VX@9F]R(')E:F5C="(*;7-G<W1R(")(>6QKY.1M
M:7-V:65S=&D@<'5U='1U=2(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$Y
M,C<*;7-G:60@(DUI<W-I;F<@<F5A<V]N(&EN('9A8V%T:6]N+B(*;7-G<W1R
M(")0;VES<V%O;&]V:65S=&D@<'5U='1U=2XB"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]H96%D97(N:6YC.C(Y"FUS9VED(")-;W9E(@IM<V=S='(@(E-I:7)R
MY"(*"B,Z(&9I;'1E<G,N<&AP.C$S,2!F:6QT97)S+G!H<#HR-#`*;7-G:60@
M(DUO=F4@4G5L92!$;W=N(@IM<V=S='(@(E-I:7)RY"!SY.1N=/;D(&%L87-P
MY&EN(@H*(SH@9FEL=&5R<RYP:'`Z,3,R(&9I;'1E<G,N<&AP.C(S.0IM<V=I
M9"`B36]V92!2=6QE(%5P(@IM<V=S='(@(E-I:7)RY"!SY.1N=/;D('EL]G-P
MY&EN(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHT,@IM
M<V=I9"`B3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C871I;VX@<F5P;&EE
M<SHB"FUS9W-T<B`B35]O;F5N:V\@<.1I=N1N(';D;&5I;B!LY&AE=&5TY.1N
M('!O:7-S86]L;W9I97-T:3HB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F:6QT
M97(M;F]N92YI;F,Z,R!T96UP;&%T97,O9FEL=&5R<R]F;V]T97(N:6YC.C4*
M(SH@;&EB+U-T;W)A9V4N<&AP.C<W,0IM<V=I9"`B3F5W(%)U;&4B"FUS9W-T
M<B`B575S:2!SY.1N=/8B"@HC.B!L:6(O26YG;RYP:'`Z,C,U(&QI8B]);F=O
M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@7"(E<UPB(&5L96UE
M;G0@9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%
M;&5M96YT=&GD(%PB)7-<(B!E:2!L]GET>6YY="!T875S=&%JY')J97-T96QM
MY&X@87-E='5K<VES=&$N(@H*(SH@;&EB+TEN9V\N<&AP.C(S,PIM<V=I9"`B
M3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0B"FUS9W-T<B`B
M5&%U<W1A:N1R:F5S=&5L;>3D(&5I(&]L92!MY.1R:71E;'1Y('3D;&QE('!A
M;'9E;&EM96QL92(*"B,Z(&QI8B]);F=O+G!H<#HR,3`*;7-G:60@(DYO(&)A
M8VME;F1S(&-O;F9I9W5R960@:6X@8F%C:V5N9',N<&AP(@IM<V=S='(@(E1A
M=7-T86KD<FIE<W1E;&UIY"!E:2!O;&4@;>3D<FET96QT>2!B86-K96YD<RYP
M:'`@=&EE9&]S=&]S<V$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F:6QT97(M
M;F]N92YI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!F:6QT97)S+B!#
M;&EC:R!<(B5S7"(@=&\@8W)E871E(&$@;F5W(&9I;'1E<BXB"FUS9W-T<B`B
M16D@<W5O9&%T=&EM:6$N($YA<'-A=71A(%PB)7-<(B!T96ADY&MS97-I('5U
M9&5N('-U;V1A='1I;65N+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$S
M,S(@;&EB+U-C<FEP="]S:65V92YP:'`Z,30R-0HC.B!L:6(O4V-R:7!T+W-I
M979E+G!H<#HQ-3DY"FUS9VED(").;R!H96%D97)S('-P96-I9FEE9"(*;7-G
M<W1R(")/='-A:VME:71A(&5I(&]L92!MY.1R:71E;'1Y(@H*(SH@<V-R:7!T
M+G!H<#HV-PIM<V=I9"`B3F\@<V-R:7!T(&=E;F5R871E9"XB"FUS9W-T<B`B
M4VMR:7!T:>0@96D@;'5O='4N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,38Q-`IM<V=I9"`B3F\@<W1R:6YG<R!S<&5C:69I960B"FUS9W-T<B`B365R
M:VMI:F]N;VIA(&5I(&]L92!MY.1R:71E;'1Y(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,Y,PIM<V=I9"`B3F]T(&5Q=6%L('1O(@IM<V=S='(@(F5R:7-U=7)I
M(&MU:6XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4S"FUS9VED(").;W1I9GD@
M96UA:6P@861D<F5S<R(*;7-G<W1R("));&UO:71U:W-I96X@<^1H:_9P;W-T
M:6]S;VET92(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#<*;7-G:60@(D]N;'D@
M9FQA9R!T:&4@;65S<V%G92(*;7-G<W1R(")-=75T82!V86EN('9I97-T:6X@
M=&EL871I971O82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.0IM<V=I
M9"`B3W!T:6]N<R!A8F]U="!S8W)I<'0@=7!D871I;F<N(@IM<V=S='(@(E9O
M:70@;75U='1A82!S:W)I<'1I;B!PY&EV:71Y:W-E96X@;&EI='1Y=FGD(&%S
M971U:W-I82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@
M(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B375U="!A<V5T=6MS970B"@HC.B!L
M:6(O0FQO8VLO;W9E<G9I97<N<&AP.C,*;7-G:60@(D]V97)V:65W(@IM<V=S
M='(@(EEL96ES:W5V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VYE=U]F
M;VQD97(N:G,Z-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H
M92!N97<@9F]L9&5R.B(*;7-G<W1R(")!;FYA('5U9&5N(&MA;G-I;VX@;FEM
M:3HB"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C8P"FUS
M9VED(")27V5A<V]N(@IM<V=S='(@(E-?>7DB"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C8S"FUS9VED(")296-E:79E9"(*;7-G<W1R(")687-T86%N
M;W1E='1U(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,R.`IM<V=I9"`B4F5D:7)E
M8W0@=&\B"FUS9W-T<B`B575D96QL965N;VAJ86$@;W-O:71T965S965N(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,X-0IM<V=I9"`B4F5G=6QA<B!E>'!R97-S
M:6]N(@IM<V=S='(@(E/DY&YN]FQL:6YE;B!L875S96ME(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C,T,PIM<V=I9"`B4F5J96-T('=I=&@@<F5A<V]N(@IM<V=S
M='(@(DAY;&ODY"!V:65S=&D@=F%S=&%U:W-E;&QA(@H*(SH@8V]N9FEG+V9I
M96QD<RYP:'`N9&ES=#HU-0IM<V=I9"`B4F5S96YT(%1O(@IM<V=S='(@(DSD
M:&5TY"!U=61E;&QE96X@;W-O:71T965S965N(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HU,0IM<V=I9"`B4F5S96YT+69R;VTB"FUS9W-T<B`B575D
M96QL965N;.1H971E='1Y(&]S;VET=&5E<W1A(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O9F]O=&5R+FEN8SHV,`IM<V=I9"`B4F5T=7)N('1O($9I;'1E<G,@3&ES
M="(*;7-G<W1R(")086QA82!S=6]D871I;FQI<W1A86XB"@HC.B!T96UP;&%T
M97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,C0@=&5M<&QA=&5S+W9A8V%T
M:6]N+W9A8V%T:6]N+FEN8SHW,0HC.B!T96UP;&%T97,O9F]R=V%R9"]F;W)W
M87)D+FEN8SHS-"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M-#$*;7-G:60@(E)E='5R;B!T;R!2=6QE<R!,:7-T(@IM<V=S='(@(E!A;&%A
M('/DY&YN]G-T]FQI<W1A86XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D
M97(N:6YC.C(W"FUS9VED(")2=6QE(@IM<V=S='(@(E/DY&YT]B(*"B,Z(&9I
M;'1E<G,N<&AP.C8S"FUS9VED(")2=6QE($-O<&EE9"(*;7-G<W1R(")3Y.1N
M=/8@:V]P:6]I=&EI;B(*"B,Z(&9I;'1E<G,N<&AP.C0R"FUS9VED(")2=6QE
M($1E;&5T960B"FUS9W-T<B`B4^3D;G3V('!O:7-T971T:6EN(@H*(SH@9FEL
M=&5R<RYP:'`Z-SD*;7-G:60@(E)U;&4@1&ES86)L960B"FUS9W-T<B`B4^3D
M;G3V('!O:7,@:^1Y=/9S=.0B"@HC.B!F:6QT97)S+G!H<#HX-`IM<V=I9"`B
M4G5L92!%;F%B;&5D(@IM<V=S='(@(E/DY&YT]B!KY'ET]G-SY"(*"B,Z('1E
M;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,S,*;7-G:60@(E)U;&4@3F%M92(*
M;7-G<W1R(")3Y.1N;O9N(&YI;6DB"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HR,#8T"FUS9VED(")2=6QE.B(*;7-G<W1R(")3Y.1N=/8Z(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")35$%2
M5%1,4R!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4U1!4E143%,@97#D;VYN
M:7-T=6DZ("@E<RD@)7,B"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E
M;&ES="YI;F,Z,C,@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHW
M,`HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C4Y('1E;7!L871E<R]F
M;W)W87)D+V9O<G=A<F0N:6YC.C,S"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O
M8FQA8VML:7-T+FEN8SHT,`IM<V=I9"`B4V%V92(*;7-G<W1R(")486QL971A
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(Y"FUS9VED
M(")3879E(%-E='1I;F=S(@IM<V=S='(@(E1A;&QE=&$@87-E='5K<V5T(@H*
M(SH@=&5M<&QA=&5S+W-C<FEP="]H96%D97(N:6YC.C(*;7-G:60@(E-C<FEP
M="(*;7-G<W1R(")3:W)I<'1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$X"FUS9VED(")38W)I<'0@57!D871I;F<B"FUS9W-T<B`B4VMR:7!T:6X@
M<.1I=FET>7,B"@HC.B!L:6(O26YG;RYP:'`Z,3@V"FUS9VED(")38W)I<'0@
M;F]T('5P9&%T960N(@IM<V=S='(@(E-K<FEP=&GD(&5I('#D:79I=&5T='DN
M(@H*(SH@;&EB+TEN9V\N<&AP.C$T,0IM<V=I9"`B4V-R:7!T('-U8V-E<W-F
M=6QL>2!A8W1I=F%T960N(@IM<V=S='(@(E-K<FEP=&EN(&%K=&EV;VEN=&D@
M;VYN:7-T=6DN(@H*(SH@;&EB+TEN9V\N<&AP.C$T,`IM<V=I9"`B4V-R:7!T
M('-U8V-E<W-F=6QL>2!D96%C=&EV871E9"XB"FUS9W-T<B`B4VMR:7!T:6X@
M86MT:79O:6YT:2!O;FYI<W1U:2XB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T
M97(N:6YC.C(Y"FUS9VED(")3965N(@IM<V=S='(@(E9A;FAA(@H*(SH@<G5L
M92YP:'`Z,3DP"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R(")686QI
M='-E(&ME;G1TY"(*"B,Z(&QI8B]);F=O+G!H<#HU.0IM<V=I9"`B4V5L96-T
M('1A<F=E="!F;VQD97(B"FUS9W-T<B`B5F%L:71S92!K;VAD96MA;G-I;R(*
M"B,Z(')U;&4N<&AP.C(R-PIM<V=I9"`B4V5L9BU$969I;F5D($AE861E<B(*
M;7-G<W1R("))='-E;>3D<FET96QT>2!O='-A:V4B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C,U"FUS9VED(")396YD97(B"FUS9W-T<B`B3.1H971T
MY&KD(@H*(SH@9FEL=&5R<RYP:'`Z.3@*;7-G:60@(E-E='1I;F=S('-U8V-E
M<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")!<V5T=7-T96X@<.1I=FET>7,@
M;VYN:7-T=6DN(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z
M,C0*;7-G:60@(E-H;W<@06-T:79E(%-C<FEP="(*;7-G<W1R(").Y'ETY"!A
M:W1I:79I;F5N('-K<FEP=&DB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV
M871E+FEN8SHS,0IM<V=I9"`B4VAO=R!#=7)R96YT(%-C<FEP="(*;7-G<W1R
M(").Y'ETY"!N>6MY:6YE;B!S:W)I<'1I(@H*(SH@8V]N9FEG+V9I96QD<RYP
M:'`N9&ES=#HX,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")+;VMO(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHT.0IM<V=I9"`B4W1O<"!C:&5C:VEN
M9R!I9B!T:&ES(')U;&4@;6%T8VAE<S\B"FUS9W-T<B`B3&]P971A('1A<FMI
M<W1U<R!J;W,@=.1MY"!SY.1N=/8@<V]P:6DN(@H*(SH@=&5M<&QA=&5S+W9A
M8V%T:6]N+W9A8V%T:6]N+FEN8SHU,0IM<V=I9"`B4W5B:F5?8W0@;V8@=F%C
M871I;VX@;65S<V%G93HB"FUS9W-T<B`B4%]O:7-S86]L;W9I97-T:6X@;W1S
M:6MK;SHB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,Q"FUS9VED(")3
M=6)J96-T(@IM<V=S='(@(D]T<VEK:V\B"@HC.B!L:6(O4V-R:7!T+W-I979E
M+G!H<#HR,#8S"FUS9VED(")3=6)J96-T.B(*;7-G<W1R(")/='-I:VMO.B(*
M"B,Z(&QI8B]A<&DN<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A
M9&1R97-S(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&)L86-K;&ES
M="XB"FUS9W-T<B`B3W-O:71E(%PB)7-<(B!O;B!L:7/D='1Y(&UU<W1A;&QE
M(&QI<W1A;&QE<VDN(@H*(SH@;&EB+V%P:2YP:'`Z,3`T"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!A9&1R97-S(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T
M;R!Y;W5R('=H:71E;&ES="XB"FUS9W-T<B`B3W-O:71E(%PB)7-<(B!O;B!L
M:7/D='1Y('9A;&MO:7-E;&QE(&QI<W1A;&QE<VDN(@H*(SH@;&EB+TEN9V\N
M<&AP.C$S-@IM<V=I9"`B5&AE(&1R:79E<B!S86ED.B`B"FUS9W-T<B`B06IU
M<FEN('9I<FAE:6QM;VET=7,@;VQI.B`B"@HC.B!L:6(O26YG;RYP:'`Z,3,U
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R
M:7!T+B(*;7-G<W1R(")3:W)I<'1I;B!A:W1I=F]I;FYI<W-A('1A<&%H='5I
M('9I<FAE+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S0*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D96%C=&EV871I;F<@=&AE('-C<FEP="XB"FUS9W-T<B`B
M4VMR:7!T:6X@96DM86MT:79O:6YN:7-S82!T87!A:'1U:2!V:7)H92XB"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C(W"FUS9VED(")4;R(*;7-G<W1R
M(")687-T86%N;W1T86IA(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R
M+FAT;6PZ,C$*;7-G:60@(E1O.B(*;7-G<W1R(")687-T86%N;W1T86IA.B(*
M"B,Z(&QI8B]38W)I<'0N<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B
M3>3D<FET>6MS96X@)7,@;'5K96UI;F5N(&5PY&]N;FES='5I+B(*"B,Z(&9I
M;'1E<G,N<&AP.C$V,2!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC
M.C4*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C8R(&QI8B]38W)I<'0O
M<VEE=F4N<&AP.C,U,@HC.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C8P(&QI
M8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C(*;7-G:60@(E9A8V%T:6]N(@IM<V=S
M='(@(E!O:7-S86]L;W9I97-T:2(*"B,Z('9A8V%T:6]N+G!H<#HW,0IM<V=I
M9"`B5F%C871I;VX@161I="(*;7-G<W1R(")0;VES<V%O;&]V:65S=&EN(&UU
M;VMK875S(@H*(SH@=F%C871I;VXN<&AP.C$V"FUS9VED(")686-A=&EO;B!I
M<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV
M97(N(@IM<V=S='(@(DOD>73V<W/D(&]L979A('-U;V1A=&EN86IU<FD@96D@
M='5E('!O:7-S86]L;W9I97-T96KD+B(*"B,Z('1E;7!L871E<R]W:&ET96QI
M<W0O=VAI=&5L:7-T+FEN8SHQ-@IM<V=I9"`B5VA?:71E;&ES="!A9&1R97-S
M97,Z(@IM<V=S='(@(E9A;&MO7VES96X@;&ES=&%N(&]S;VET=&5E=#HB"@HC
M.B!F:6QT97)S+G!H<#HQ-34@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI
M<W0N:6YC.C@*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HW.2!L:6(O0FQO
M8VLO;W9E<G9I97<N<&AP.C@R"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B
M5F%L:V]I;F5N(&QI<W1A(@H*(SH@=VAI=&5L:7-T+G!H<#HU-0IM<V=I9"`B
M5VAI=&5L:7-T($5D:70B"FUS9W-T<B`B5F%L:V]I<V5N(&QI<W1A;B!M=6]K
M:V%U<R(*"B,Z('=H:71E;&ES="YP:'`Z,3@*;7-G:60@(E=H:71E;&ES="!I
M<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV
M97(N(@IM<V=S='(@(DOD>73V<W/D(&]L979A(&%J=7)I(&5I('1U92!V86QK
M;VES=&$@;&ES=&%A+B(*"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(P
M,R!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR,S0*(SH@;&EB+U-C<FEP="]S
M:65V92YP:'`Z,CDX"FUS9VED(")7:&ET96QI<W1E9"!!9&1R97-S97,B"FUS
M9W-T<B`B5F%L:V]I<V5L;&4@;&ES=&%L;&4@;&ESY'1Y="!O<V]I='1E970B
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C<Y"FUS9VED(")8+5!R:6]R
M:71Y(@IM<V=S='(@(E@M4')I;W)I='DB"@HC.B!C;VYF:6<O9FEE;&1S+G!H
M<"YD:7-T.C8W"FUS9VED(")8+5-P86TM3&5V96PB"FUS9W-T<B`B6"U3<&%M
M+4QE=F5L(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B
M6"U3<&%M+5-C;W)E(@IM<V=S='(@(E@M4W!A;2U38V]R92(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z-S4*;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS
M9W-T<B`B6"U3<&%M+5-T871U<R(*"B,Z(&9I;'1E<G,N<&AP.C4V(')U;&4N
M<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@<G5L97,N(@IM<V=S='(@(D5T
M('9O:2!L=6]D82!E;F5M<.3D(&MU:6X@)60@<^3D;G3VY"XB"@HC.B!F:6QT
M97)S+G!H<#HT."!R=6QE+G!H<#HR,0IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;W(@961I="!C=7-T;VT@<G5L97,N(@IM<V=S='(@
M(D5T('9O:2!L=6]D82!T86D@;75O:V%T82!E<FET>6ES:>0@<^3D;G3V:N0N
M(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V,0IM<V=I9"`B66]U(&AA
M=F4@<F5C96EV960@82!N97<@;65S<V%G92(*;7-G<W1R(")3:6YU;&QE(&]N
M('-A87!U;G5T('5U<VD@=FEE<VDB"@HC.B!V86-A=&EO;BYP:'`Z,S`*;7-G
M:60@(B(*(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&5M86EL(&%D
M9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M97-S86=E<R`B"B)S:&]U
M;&0@8F4@86-T:79A=&5D+B(*;7-G<W1R("(B"B)3:6YU;B!P:73DY"!A;G1A
M82!A:6YA:VEN('EK<VD@<^1H:_9P;W-T:6]S;VET92P@:F]L;&4@;&%I=&5T
M86%N('#DY&QL92`B"B)P;VES<V%O;&]V:65S=&ET+B(*"B,Z(&QI8B]38W)I
M<'0O:6UA<"YP:'`Z,C<T(&QI8B]38W)I<'0O:6UA<"YP:'`Z,CDW(&QI8B]3
M8W)I<'0O:6UA<"YP:'`Z,S$Q"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T
M<B`B6T5I(&]T<VEK:V]A72(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O<G=A
M<F0N:6YC.C(T"FUS9VED(")?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SHB
M"FUS9W-T<B`B7U;D;&ETY"!V:65S=&ET(&]S;VET=&5I<VEI;CHB"@HC.B!T
M96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C(S"FUS9VED(")?061D
M<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SHB"FUS9W-T<B`B7\1L
MY"!LY&AE=.0@=F%S=&%U<W9I97-T:>0@;W-O:71T96ES:6EN.B(*"B,Z(&QI
M8B]);F=O+G!H<#HS,CD*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B7TUU
M<W1A(&QI<W1A(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N
M:6YC.C$X"FUS9VED(")?1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L>2(*;7-G
M<W1R(")?4&]I<W1A('9I97-T:2!K;VMO;F%A;B(*"B,Z('1E;7!L871E<R]B
M;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHS,0IM<V=I9"`B7T5N=&5R(&5A8V@@
M861D<F5S<R!O;B!A(&YE=R!L:6YE.B(*;7-G<W1R(")?3&%I=&$@:F]K86EN
M96X@;W-O:71E(&]M86QL92!R:79I;&QE96XZ(@H*(SH@;&EB+TEN9V\N<&AP
M.C,S-0IM<V=I9"`B7T9O<G=A<F0B"FUS9W-T<B`B7U5U9&5L;&5E;F]H:F%A
M(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3<*;7-G:60@
M(E]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_(@IM
M<V=S='(@(E]*Y'3D('9I97-T:7-TY"!K;W!I;R!TY&CD;B!O<V]I='1E97-E
M96XN(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(R
M"FUS9VED(")?36]V92!M97-S86=E('1O(&9O;&1E<CHB"FUS9W-T<B`B7U-I
M:7)RY"!V:65S=&D@:V%N<VEO;VXZ(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N
M+W9A8V%T:6]N+FEN8SHQ,PIM<V=I9"`B7TUY(&5M86EL(&%D9')E<W-E<SHB
M"FUS9W-T<B`B7T]M870@<^1H:_9P;W-T:6]S;VET=&5E=#HB"@HC.B!L:6(O
M26YG;RYP:'`Z,S,X"FUS9VED(")?4V-R:7!T(@IM<V=S='(@(E]3:W)I<'1I
M(@H*(SH@;&EB+TEN9V\N<&AP.C,S,@IM<V=I9"`B7U9A8V%T:6]N(@IM<V=S
M='(@(E]0;VES<V%O;&]V:65S=&DB"@HC.B!L:6(O26YG;RYP:'`Z,S(V"FUS
M9VED(")?5VAI=&5L:7-T(@IM<V=S='(@(E]686QK;VEN96X@;&ES=&$B"@HC
M.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C4T"FUS9VED(")A8W1I=F4B"FUS
M9W-T<B`B86MT:6EV:6YE;B(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI
M;F,Z-`IM<V=I9"`B86YD(@IM<V=S='(@(FIA(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O9FEL=&5R+FAT;6PZ,3,*;7-G:60@(F1I<V%B;&5D("T@8VQI8VL@
M=&\@96YA8FQE(@IM<V=S='(@(G!O:7,@<.3D;'3D("T@;F%P<V%U=&$@;&%I
M='1A86MS97-I('#DY&QL92(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B
M9FEE;&0B"FUS9W-T<B`B:V5N='3D(@H*(SH@;&EB+T)L;V-K+V]V97)V:65W
M+G!H<#HU,@IM<V=I9"`B:6YA8W1I=F4B"FUS9W-T<B`B96D@86MT:6EV:6YE
M;B(*"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C$R,0IM<V=I9"`B;6%I
M;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O(@IM<V=S='(@(DEN9V\@
M;VAJ96QM86X@='5O='1A;6$@<VMR:7!T:2(*"B,Z(&9I;'1E<G,N<&AP.C$X
M-0IM<V=I9"`B;6%T8V@B"FUS9W-T<B`B=.1S;>3D(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")O<B(*;7-G<W1R(")T86DB"@HC
M.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HQ,C@*;7-G:60@(G!R;V-M86EL
M('-C<FEP="!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R("));F=O(&]H:F5L
M;6%N('1U;W1T86UA('!R;V-M86EL+7-K<FEP=&DB"@``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]P;R]214%$344`````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`R-``Q,#0Q
M-S,V,C<T-P`P,38V-3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````<V5E(&AO<F1E+W!O+U)%041-10H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEN9V\O<&\O<F]?4D\N<&\`````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#4R,S$`,3`T,3<S-C(W-#<`,#$W
M,S8S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",@4F]M86YI86X@=')A;G-L871I;VYS(&9O<B!);F=O('!A8VMA9V4N"B,@
M0V]P>7)I9VAT("A#*2`R,#`S($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@
M:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@
M26YG;R!P86-K86=E+@HC($5U9V5N($AO86YC82`\975G96YH0'5R8F%N+6=R
M869X+G)O/BP@,C`P,RX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@26YG;R`P+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R
M,#`U+3`U+3(X(#$S.C`Q*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@175G
M96X@2&]A;F-A(#QE=6=E;FA`=7)B86XM9W)A9G@N<F\^7&XB"B),86YG=6%G
M92U496%M.B!2;VUA;FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:71<;B(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B(&%N
M9"(*;7-G<W1R("(B"@HC.B!F:6QT97)S+G!H<#HQ.#4*;7-G:60@(B!O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI
M;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(D%C=&EO;B!F;W(@8FQA8VML:7-T960@
M861D<F5S<V5S.B(*;7-G<W1R(")!9')E<V4@9&EN(&QI<W1A(&YE86=R82(*
M"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$P"B,L(&9U>GIY
M"FUS9VED(")!8W1I=F%T92!38W)I<'0B"FUS9W-T<B`B06-T:79E87IA(&%C
M97-T('-C<FEP="(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C,R"B,L('!H
M<"UF;W)M870*;7-G:60@(D%C=&EV871I;F<@=&AE('-C<FEP="!F;W(@7"(E
M<UPB(&9A:6QE9#H@*"5D*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]S971T:6YG<RYI;F,Z-@IM<V=I9"`B061D:71I;VYA;"!3971T
M:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC
M.C0T"FUS9VED(")!;&P@;V8@=&AE(&9O;&QO=VEN9R(*;7-G<W1R(")4;V%T
M92!D:6X@8V5L92!U<FUA=&]A<F4B"@HC.B!L:6(O87!I+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B06QL;W<@4G5L97,B"FUS9W-T<B`B4F5G=6QA(&YO=6$B
M"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C,S"FUS9VED(")!;G-W
M97)E9"(*;7-G<W1R(")287-P=6YS92(*"B,Z('1E;7!L871E<R]R=6QE+VAE
M861E<BYI;F,Z-#4*;7-G:60@(D%N>2!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S
M='(@(D]R:6-A<F4@9&EN('5R;6%T;V%R96QE(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O9F]O=&5R+FEN8SHQ,0IM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G
M<W1R("(B"@HC.B!F:6QT97)S+G!H<#HR,30*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,*;7-G:60@(D%U=&]M871I8V%L
M;'D@=7!D871E('1H92!S8W)I<'0@869T97(@96%C:"!C:&%N9V4_(@IM<V=S
M='(@(DEM<')O<W!A=&%R92!A=71O;6%T82!A('-C<FEP='5L=6D@9'5P82!F
M:65C87)E('-C:&EM8F%R93\B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T
M.C0W"FUS9VED(")"8V,B"FUS9W-T<B`B0F-C(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B0F5G:6YS('=I=&@B"FUS9W-T<B`B
M26YC97!E(&-U(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,#8@;&EB+T1R
M:79E<B]L9&%P+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F
M86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z,30T
M('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHW"FUS9VED(")"
M;&%C:VQI<W0B"FUS9W-T<B`B3&ES=&$@;F5A9W)A(@H*(SH@8FQA8VML:7-T
M+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D)L86-K;&ES="!%9&ET(@IM<V=S
M='(@(DQI<W1A(&YE86=R82(*"B,Z(&)L86-K;&ES="YP:'`Z,3<*;7-G:60@
M(D)L86-K;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I
M;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O<')O
M8VUA:6PN<&AP.C(P-R!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HQ-S4*(RP@
M9G5Z>GD*;7-G:60@(D)L86-K;&ES=&5D($%D9')E<W,B"FUS9W-T<B`B061R
M97-E(&1I;B!L:7-T82!N96%G<F$B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HR-#,*;7-G:60@(D)L86-K;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R(")!
M9')E<V4@9&EN(&QI<W1A(&YE86=R82(*"B,Z(&-O;F9I9R]F:65L9',N<&AP
M+F1I<W0Z.#@*;7-G:60@(D)O9'DB"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP
M:'`Z,3@R(')U;&4N<&AP.C(X,0IM<V=I9"`B0V%S92!396YS:71I=F4B"FUS
M9W-T<B`B0V%Z('-E;GII=&EV(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES
M=#HT,PIM<V=I9"`B0V,B"FUS9W-T<B`B0V,B"@HC.B!R=6QE+G!H<#HQ,C(@
M=VAI=&5L:7-T+G!H<#HS-B!F;W)W87)D+G!H<#HS,R!V86-A=&EO;BYP:'`Z
M-#$*(SH@8FQA8VML:7-T+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E
M<R!S879E9"XB"FUS9W-T<B`B36]D:69I8V%R:2!S86QV871E(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HW-0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#`*;7-G:60@(D-O
M;G1A:6YS(@IM<V=S='(@(D-O;G1I;BAE*2(*"B,Z(&9I;'1E<G,N<&AP.C(R
M-2!F:6QT97)S+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2`E
M<R(*;7-G<W1R(")#;W!I97)E("5S(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C<V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&]F("5S(@IM<V=S='(@(D-O
M<&EE(&$@)7,B"@HC.B!L:6(O26YG;RYP:'`Z-3(*;7-G:60@(D-R96%T92!N
M97<@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN
M<&AP.C,S-B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HR-SD*;7-G:60@(D1)
M4T%"3$5$.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I
M=F%T92YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(D1E86-T:79A=&4@4V-R:7!T
M(@IM<V=S='(@(D%C=&EV96%Z82!A8V5S="!S8W)I<'0B"@HC.B!F:6QT97)S
M+G!H<#HR,30@9FEL=&5R<RYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92`E<R(*;7-G<W1R(")3=&5R9V5R92`E<R(*"B,Z('1E;7!L871E
M<R]R=6QE+V9I;'1E<BYI;F,Z,S`*;7-G:60@(D1E;&5T92!#;VYD:71I;VXB
M"FUS9W-T<B`B4W1E<F=E<F4@8V]N9&ET:64B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,CDR"FUS9VED(")$96QE=&4@;65S<V%G92!C;VUP;&5T96QY(@IM<V=S
M='(@(E-T97)G97)E(&-O;7!L971A(&UE<V%J(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O9F]O=&5R+FEN8SHS-0IM<V=I9"`B1&5L971E9"(*;7-G<W1R(")3=&5R
M<RAE*2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.#`*(RP@9G5Z>GD*;7-G:60@
M(D1E;&EV97(@:6YT;R!M>2!)3D)/6"(*;7-G<W1R("),:79R87)E(&$@86-E
M<W1U:2!M97-A:B!I;B!)3D)/6"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,#8*
M(RP@9G5Z>GD*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@8V]P
M>2!T;R(*;7-G<W1R("),:79R87)E(&EN($E.0D]8('-I(')E9&ER96-T87)E
M(&-A=')E(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I
M9"`B1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R961I<F5C="!T;R(*;7-G
M<W1R("),:79R87)E(&EN($E.0D]8('-I(')E9&ER96-T87)E(&-A=')E(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C(X-@HC+"!F=7IZ>0IM<V=I9"`B1&5L:79E
M<B!T;R!F;VQD97(B"FUS9W-T<B`B375T82!M97-A:F4@:6X@9&]S87(Z(@H*
M(SH@9FEL=&5R<RYP:'`Z,C0Q(&9I;'1E<G,N<&AP.C(T,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1&ES86)L92`E<R(*;7-G<W1R(")3=&5R9V5R
M92`E<R(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHQ
M,"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHV('1E;7!L871E<R]F;W)W
M87)D+V9O<G=A<F0N:6YC.C$P"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI
M;F,Z,C8*;7-G:60@(D1I<V%B;&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W-E='1I;F=S+FEN8SHQ,PIM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!N;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN
M:6YC.C,T"B,L(&9U>GIY"FUS9VED(")$;R!?;F]T('-E;F0@<F5S<&]N<V5S
M('1O(&)U;&L@;W(@;&ES="!M97-S86=E<R(*;7-G<W1R(").=2!T<FEM:71E
M(')A<W!U;G-U<FD@8V%T<F4@;65S86IE(&-A<F4@8V]N=&EN(&AE861E<F4@
M3&ES="TJ(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHQ,`HC+"!F
M=7IZ>0IM<V=I9"`B1&\@=&AI<SHB"FUS9W-T<B`B1F$@87-T83HB"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S0U"B,L(&9U>GIY"FUS9VED(")$;V5S;B=T(&)E
M9VEN('=I=&@B"FUS9W-T<B`B3G4@:6YC97!E(&-U(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,T,0HC+"!F=7IZ>0IM<V=I9"`B1&]E<VXG="!C;VYT86EN(@IM
M<V=S='(@(DYU(&-O;G1I;F4B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0W"B,L
M(&9U>GIY"FUS9VED(")$;V5S;B=T(&5N9"!W:71H(@IM<V=S='(@(DYU('-E
M('1E<FUI;F$@8W4B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0Y"B,L(&9U>GIY
M"FUS9VED(")$;V5S;B=T(&5X:7-T(@IM<V=S='(@(DYU(&5X:7-T82(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS-3(*;7-G:60@(D1O97-N)W0@;6%T8V@@*'=I
M=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]H96%D97(N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")%9&ET(@IM<V=S
M='(@(D5D:71A<F4@)7,B"@HC.B!F:6QT97)S+G!H<#HR,#,@9FEL=&5R<RYP
M:'`Z,C`U(&9I;'1E<G,N<&AP.C(P.2!F:6QT97)S+G!H<#HR,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R(")%9&ET87)E("5S(@H*
M(SH@9FEL=&5R<RYP:'`Z,C0U(&9I;'1E<G,N<&AP.C(T-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%;F%B;&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O:&5A9&5R+FEN8SHS-PIM<V=I9"`B16YA8FQE9"(*;7-G<W1R
M("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0V"B,L(&9U>GIY"FUS9VED(")%
M;F1S('=I=&@B"FUS9W-T<B`B4V4@=&5R;6EN82!C=2(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-3<*;7-G:60@(D5Q=6%L('1O(@IM<V=S='(@(B(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,3,Y(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30Y
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,34X"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@
M8W5R<F5N="!S8W)I<'0Z("@E9"D@)7,B"FUS9W-T<B`B(@H*(SH@8FQA8VML
M:7-T+G!H<#HV-PIM<V=I9"`B17)R;W(@<V%V:6YG(&-H86YG97,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C(*;7-G
M:60@(D5X:7-T:6YG(%)U;&5S(@IM<V=S='(@(E)E9W5L:2!E>&ES=&5N=&4B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0X"FUS9VED(")%>&ES=',B"FUS9W-T
M<B`B17AI<W1A(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17AP96-T960@,2!O8FIE8W0L(&=O="`E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(P
M"B,L(&9U>GIY"FUS9VED(")&:6QT97(@06QL($UE<W-A9V5S(@IM<V=S='(@
M(E)E9W5L82!F:6QT<G4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG
M<RYI;F,Z,C(*;7-G:60@(D9I;'1E<B!/;FQY(%-E96X@365S<V%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(Q
M"FUS9VED(")&:6QT97(@3VYL>2!5;G-E96X@365S<V%G97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C$X"B,L(&9U
M>GIY"FUS9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(")!;'1E(&]P=&EU
M;FDB"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C(U"FUS9VED(")&
M:6QT97(@4G5L92(*;7-G<W1R(")296=U;&$@9FEL=')U(@H*(SH@9FEL=&5R
M<RYP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")&:6QT97(@4G5L97,B"FUS9W-T
M<B`B4F5G=6QA(&9I;'1R=2(*"B,Z('-C<FEP="YP:'`Z-3(*;7-G:60@(D9I
M;'1E<B!38W)I<'0@1&ES<&QA>2(*;7-G<W1R("(B"@HC.B!L:6(O26YG;RYP
M:'`Z,S`P"B,L(&9U>GIY"FUS9VED(")&:6QT97(@7U)U;&5S(@IM<V=S='(@
M(E)E9W5L82!F:6QT<G4B"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A
M9V4H<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I
M(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T
M+VEM87`N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+VEM87`N
M<&AP.C$X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ
M("5S(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@=V5R
M92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP
M.C,Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ
M(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I
M960@=&\@=&AE("(*(F9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]38W)I<'0O:6UA<"YP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O
M:6UA<"YP:'`Z,C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D9I;'1E<B!A
M8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B
M965N(&UO=F5D('1O('1H92!F;VQD97(@(@HB7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!R=6QE+G!H<#HQ-C`*;7-G:60@(D9I;'1E<B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#(*(RP@
M9G5Z>GD*;7-G:60@(D9O<B!A;B!I;F-O;6EN9R!M97-S86=E('1H870@;6%T
M8VAE<SHB"FUS9W-T<B`B4&5N=')U(&UE<V%J92!C87)E('9I;B!S:2!S92!P
M;W1R:79E<V,Z(@H*(SH@9FEL=&5R<RYP:'`Z,38R('1E;7!L871E<R]F;W)W
M87)D+V9O<G=A<F0N:6YC.C@*;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B(@H*
M(SH@9F]R=V%R9"YP:'`Z,38*;7-G:60@(D9O<G=A<F0@:7,@;F]T('-U<'!O
M<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R
M("(B"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR.#(@;&EB+U-C<FEP
M="]M86EL9')O<"YP:'`Z,C(T"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("(B
M"@HC.B!F;W)W87)D+G!H<#HT-@IM<V=I9"`B1F]R=V%R9',@161I="(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,Y"FUS9VED(")&
M<F]M(@IM<V=S='(@(D1E(&QA(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-0HC
M+"!F=7IZ>0IM<V=I9"`B1W)E871E<B!T:&%N(@IM<V=S='(@(DUA:2!M87)E
M(&-A(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-@HC+"!F=7IZ>0IM<V=I9"`B
M1W)E871E<B!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(DUA:2!M87)E(&-A
M(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,0IM<V=I9"`B26UP
M;W)T86YT(@IM<V=S='(@(DEM<&]R=&%N="(*"B,Z(')U;&4N<&AP.C,V"FUS
M9VED("));F1I=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H
M92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C$X-34*;7-G:60@(DEN97AI<W1A;G0@;6%I
M;&)O>"!S<&5C:69I960@9F]R(&UE<W-A9V4@9&5L:79E<GDN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#(*;7-G:60@(DES(@IM<V=S='(@
M(D5S=&4B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0S"FUS9VED("))<VXG="(*
M;7-G<W1R(").=2!E<W1E(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,PIM
M<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!
M4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4S"B,L(&9U>GIY"FUS9VED
M("),97-S('1H86XB"FUS9W-T<B`B36%I('!U=&EN(&1E8V%T(@H*(SH@;&EB
M+U-T;W)A9V4N<&AP.C,U-`IM<V=I9"`B3&5S<R!T:&%N(&]R(&5Q=6%L('1O
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-3D*;7-G
M:60@(DQI<W0M240B"FUS9W-T<B`B260M;&ES=&$B"@HC.B!T96UP;&%T97,O
M8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,C`*(RP@9G5Z>GD*;7-G:60@(DUA
M<E]K(&UE<W-A9V4@87,@9&5L971E9"(*;7-G<W1R(")-87)C87)E(&UE<V%J
M(&-A('-T97)S(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHR-`HC
M+"!F=7IZ>0IM<V=I9"`B36%R:R!M97-S86=E(&%S.B(*;7-G<W1R(")-87)C
M87)E(&UE<V%J(&-A.B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3$*;7-G:60@
M(DUA=&-H97,@*'=I=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HU-PIM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4G5L97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C0W.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O9B!B;&%C:VQI<W1E9"!A
M9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L("(*(DUA
M>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A9&1R
M97-S97,@=&\@8FQA8VML:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z-3,Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@;G5M
M8F5R(&]F('=H:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@
M861D<F5S<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O
M=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W,C,*(RP@9G5Z>GD*
M;7-G:60@(DUI<W-I;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O
M(@IM<V=S='(@(DYU(&5X:7-T82!A9')E<V$@<&5N=')U(')E9&ER96-T87)E
M(&UE<V%J(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3<U-0HC+"!F=7IZ
M>0IM<V=I9"`B36ES<VEN9R!R96%S;VX@9F]R(')E:F5C="(*;7-G<W1R(").
M=2!E>&ES=&$@97AP;&EC871I92!P96YT<G4@<F5S<&EN9V5R92(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C$Y,C(*;7-G:60@(DUI<W-I;F<@<F5A<V]N
M(&EN('9A8V%T:6]N+B(*;7-G<W1R(").=2!E>&ES=&$@97AP;&EC871I92!P
M96YT<G4@=F%C86YT82XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N
M:6YC.C0P"FUS9VED(")-;W9E(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP
M.C$R-B!F:6QT97)S+G!H<#HR,S@*;7-G:60@(DUO=F4@4G5L92!$;W=N(@IM
M<V=S='(@(DUU=&$@<F5G=6QA(&EN(&IO<R(*"B,Z(&9I;'1E<G,N<&AP.C$R
M-R!F:6QT97)S+G!H<#HR,S<*;7-G:60@(DUO=F4@4G5L92!5<"(*;7-G<W1R
M(")-=71A(')E9W5L82!I;B!S=7,B"@HC.B!T96UP;&%T97,O=F%C871I;VXO
M=F%C871I;VXN:6YC.C0R"FUS9VED(").7W5M8F5R(&]F(&1A>7,@8F5T=V5E
M;B!V86-A=&EO;B!R97!L:65S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z-"!T96UP;&%T97,O9FEL=&5R<R]F
M;V]T97(N:6YC.C@*(SH@;&EB+U-T;W)A9V4N<&AP.C<Q-`IM<V=I9"`B3F5W
M(%)U;&4B"FUS9W-T<B`B4F5G=6QA(&YO=6$B"@HC.B!L:6(O26YG;RYP:'`Z
M,3DT(&QI8B]);F=O+G!H<#HQ.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M7"(E<UPB(&5L96UE;G0@9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O26YG;RYP:'`Z,3DR"FUS9VED(").;R!B
M86-K96YD(&-O;F9I9W5R960@9F]R('1H:7,@:&]S="(*;7-G<W1R(").=2!E
M>&ES=&$@<W5P;W)T(&-O;F9I9W5R870@<&5N=')U(&%C97-T(&AO<W0B"@HC
M.B!L:6(O26YG;RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!B86-K96YD
M<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S+G!H<"(*;7-G<W1R(").=2!E>&ES
M=&$@<W5P;W)T(&-O;F9I9W5R870@<&5N=')U(&%C97-T(&AO<W0B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@9FEL=&5R<RX@0VQI8VL@7"(E<UPB('1O
M(&-R96%T92!A(&YE=R!F:6QT97(N(@IM<V=S='(@(DYI8VD@=6X@9FEL=')U
M+B!#;&EC('!E("<E<R<@<&5N=')U(&-R96%R92!D92!F:6QT<G4@;F]U(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3,R-R!L:6(O4V-R:7!T+W-I979E
M+G!H<#HQ-#(P"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$U.30*(RP@9G5Z
M>GD*;7-G:60@(DYO(&AE861E<G,@<W!E8VEF:65D(@IM<V=S='(@(DAE861E
M<F4@;F5S<&5C:69I8V%T92(*"B,Z('-C<FEP="YP:'`Z-C<*;7-G:60@(DYO
M('-C<FEP="!G96YE<F%T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O
M<VEE=F4N<&AP.C$V,#D*(RP@9G5Z>GD*;7-G:60@(DYO('-T<FEN9W,@<W!E
M8VEF:65D(@IM<V=S='(@(E-I<G5R:2!N97-P96-I9FEC871E(@H*(SH@;&EB
M+U-T;W)A9V4N<&AP.C,U.`IM<V=I9"`B3F]T(&5Q=6%L('1O(@IM<V=S='(@
M(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,38*;7-G:60@(D]N;'D@9FQA9R!T
M:&4@;65S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3D*;7-G:60@(D]P=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+B(*
M;7-G<W1R(")/<'1I=6YI('!E;G1R=2!I;7!R;W-P871A<F4@<V-R:7!T+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B3W1H97(@3W!T
M:6]N<R(*;7-G<W1R(")!;'1E(&]P=&EU;FDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]N97=?9F]L9&5R+FIS.C8*;7-G:60@(E!L96%S92!E;G1E<B!T
M:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHV,`HC+"!F=7IZ>0IM<V=I
M9"`B4E]E87-O;B(*;7-G<W1R(")%>'!L:6-A=&EE(@H*(SH@8V]N9FEG+V9I
M96QD<RYP:'`N9&ES=#HV,PIM<V=I9"`B4F5C96EV960B"FUS9W-T<B`B(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C(Y-PHC+"!F=7IZ>0IM<V=I9"`B4F5D:7)E
M8W0@=&\B"FUS9W-T<B`B4F5D:7)E8W1A<F4@;65S86H@8V%T<F4B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S4P"FUS9VED(")296=U;&%R(&5X<')E<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Q,@HC+"!F=7IZ>0IM
M<V=I9"`B4F5J96-T('=I=&@@<F5A<V]N(@IM<V=S='(@(E)E<W!I;F=E<F4@
M86-E<W0@;65S86H@8W4@97AP;&EC871I92(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z-34*;7-G:60@(E)E<V5N="!4;R(*;7-G<W1R(")2971R:6UI
M=&5R92!C871R92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-3$*;7-G
M:60@(E)E<V5N="UF<F]M(@IM<V=S='(@(E)E=')I;6ET97)E+61E(&QA(@H*
M(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHV,`IM<V=I9"`B4F5T=7)N
M('1O($9I;'1E<G,@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=VAI
M=&5L:7-T+W=H:71E;&ES="YI;F,Z,C0@=&5M<&QA=&5S+V)L86-K;&ES="]B
M;&%C:VQI<W0N:6YC.C0Q"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO
M;BYI;F,Z-S$@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,S0*;7-G
M:60@(E)E='5R;B!T;R!2=6QE<R!,:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+VAE861E<BYI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(E)U
M;&4B"FUS9W-T<B`B4F5G=6QI(@H*(SH@9FEL=&5R<RYP:'`Z-C`*(RP@9G5Z
M>GD*;7-G:60@(E)U;&4@0V]P:65D(@IM<V=S='(@(E)E9W5L82!S=&5A<G-A
M(@H*(SH@9FEL=&5R<RYP:'`Z,SD*;7-G:60@(E)U;&4@1&5L971E9"(*;7-G
M<W1R(")296=U;&$@<W1E87)S82(*"B,Z(&9I;'1E<G,N<&AP.C<V"B,L(&9U
M>GIY"FUS9VED(")2=6QE($1I<V%B;&5D(@IM<V=S='(@(E)E9W5L82!S=&5A
M<G-A(@H*(SH@9FEL=&5R<RYP:'`Z.#$*(RP@9G5Z>GD*;7-G:60@(E)U;&4@
M16YA8FQE9"(*;7-G<W1R(").=6UE(')E9W5L82(*"B,Z('1E;7!L871E<R]R
M=6QE+VAE861E<BYI;F,Z,S,*;7-G:60@(E)U;&4@3F%M92(*;7-G<W1R(").
M=6UE(')E9W5L82(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z.#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR
M,R!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z-#`*(SH@=&5M
M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHW,"!T96UP;&%T97,O9F]R
M=V%R9"]F;W)W87)D+FEN8SHS,PHC.B!T96UP;&%T97,O<G5L92]F;V]T97(N
M:6YC.C4Y"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9A<F4B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,CD*;7-G:60@(E-A=F4@4V5T
M=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]H96%D97(N
M:6YC.C(*;7-G:60@(E-C<FEP="(*;7-G<W1R(")38W)I<'0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*
M;7-G<W1R("));7!R;W-P871A<F4@<V-R:7!T(@H*(SH@;&EB+TEN9V\N<&AP
M.C(Q-PHC+"!F=7IZ>0IM<V=I9"`B4V-R:7!T(&YO="!U<&1A=&5D+B(*;7-G
M<W1R("));7!R;W-P871A<F4@<V-R:7!T(@H*(SH@;&EB+TEN9V\N<&AP.C$S
M,`IM<V=I9"`B4V-R:7!T('-U8V-E<W-F=6QL>2!A8W1I=F%T960N(@IM<V=S
M='(@(E-C<FEP="!A8W1I=F%T(&-U('-U8V-E<RXB"@HC.B!L:6(O26YG;RYP
M:'`Z,3(Y"B,L(&9U>GIY"FUS9VED(")38W)I<'0@<W5C8V5S<V9U;&QY(&1E
M86-T:79A=&5D+B(*;7-G<W1R(")38W)I<'0@86-T:79A="!C=2!S=6-C97,N
M(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHR.0IM<V=I9"`B4V5E
M;B(*;7-G<W1R(")687IU="AE*2(*"B,Z(')U;&4N<&AP.C$Y,`IM<V=I9"`B
M4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`B4V5L96-T87)E(&-A;7`B"@HC.B!L
M:6(O26YG;RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T87)G970@
M9F]L9&5R(@IM<V=S='(@(E-E;&5C=&%R92!D;W-A<B!T:6YT82(*"B,Z(')U
M;&4N<&AP.C(R-PIM<V=I9"`B4V5L9BU$969I;F5D($AE861E<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,U"FUS9VED(")396YD
M97(B"FUS9W-T<B`B17AP961I=&]R(@H*(SH@9FEL=&5R<RYP:'`Z.34*(RP@
M9G5Z>GD*;7-G:60@(E-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*
M;7-G<W1R(")38W)I<'0@86-T:79A="!C=2!S=6-C97,N(@H*(SH@=&5M<&QA
M=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E-H
M;W<@06-T:79E(%-C<FEP="(*;7-G<W1R(")!9FES87)E('!I8W1O9W)A;6$@
M<V-R:7!T/R(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C,Q
M"B,L(&9U>GIY"FUS9VED(")3:&]W($-U<G)E;G0@4V-R:7!T(@IM<V=S='(@
M(D%F:7-A<F4@<&EC=&]G<F%M82!S8W)I<'0_(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HX,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")-87)I;64B"@HC
M.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C0Y"B,L(&9U>GIY"FUS9VED
M(")3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M871C:&5S/R(*;7-G<W1R
M(").=2!V97)I9FEC82!I;B!C87H@8V$@<F5G=6QA('-E('!O=')I=F5S=&4B
M"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C4Q"B,L(&9U
M>GIY"FUS9VED(")3=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E.B(*;7-G
M<W1R(")3=6)I96-T(&UE<V%J(')A<W!U;G,Z(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HS,0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")3=6)I96-T
M(@H*(SH@;&EB+V%P:2YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&%D9')E<W,@7"(E<UPB(&AA<R!B965N(&%D9&5D('1O('EO=7(@8FQA8VML
M:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@7"(E<UPB(&AA<R!B965N(&%D9&5D
M('1O('EO=7(@=VAI=&5L:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O26YG;RYP
M:'`Z,3(U"FUS9VED(")4:&4@9')I=F5R('-A:60Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O26YG;RYP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*;7-G<W1R("(B"B)3
M+6$@<')O9'5S(&\@97)O87)E(&EN(&%C=&EV87)E82!A8V5S='5I('-C<FEP
M="X@1')I=F5R=6P@<F%P;W)T96%Z83H@)7,B"@HC.B!L:6(O26YG;RYP:'`Z
M,3(S"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5A8W1I
M=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@(B(*(E,M82!P<F]D=7,@;R!E
M<F]A<F4@:6X@86-T:79A<F5A(&%C97-T=6D@<V-R:7!T+B!$<FEV97)U;"!R
M87!O<G1E87IA.B`E<R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,C<*
M;7-G:60@(E1O(@IM<V=S='(@(D-A=')E(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O9FEL=&5R+FAT;6PZ,C@*(RP@9G5Z>GD*;7-G:60@(E1O.B(*;7-G<W1R
M(")#871R92(*"B,Z(&QI8B]38W)I<'0N<&AP.C$R-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z,34V('1E;7!L871E<R]V86-A
M=&EO;B]V86-A=&EO;BYI;F,Z-0HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H
M<#HR-C(*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(E9A8V%N=&$B"@HC.B!V
M86-A=&EO;BYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E9A8V%T:6]N($5D:70B
M"FUS9W-T<B`B5F%C86YT82(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C,U
M,0IM<V=I9"`B5F%C871I;VX@365S<V%G92(*;7-G<W1R(")-97-A:B!V86-A
M;G1A(@H*(SH@=F%C871I;VXN<&AP.C$V"FUS9VED(")686-A=&EO;B!I<R!N
M;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B5VA?:71E;&ES="!A9&1R97-S97,Z
M(@IM<V=S='(@(D%D<F5S92!D:6X@;&ES=&$@;F5A9W)A(@H*(SH@9FEL=&5R
M<RYP:'`Z,34P('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHX
M"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B(@H*(SH@=VAI=&5L:7-T+G!H
M<#HU-0IM<V=I9"`B5VAI=&5L:7-T($5D:70B"FUS9W-T<B`B(@H*(SH@=VAI
M=&5L:7-T+G!H<#HQ.`IM<V=I9"`B5VAI=&5L:7-T(&ES(&YO="!S=7!P;W)T
M960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C,T(&QI8B]38W)I<'0O
M<VEE=F4N<&AP.C(Y-PHC.B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HR,#(*
M(RP@9G5Z>GD*;7-G:60@(E=H:71E;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R
M(")!9')E<V4@9&EN(&QI<W1A(&YE86=R82(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z-SD*;7-G:60@(E@M4')I;W)I='DB"FUS9W-T<B`B6"U0<FEO
M<FET871E(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HV-PIM<V=I9"`B
M6"U3<&%M+4QE=F5L(@IM<V=S='(@(E@M3FEV96PM4W!A;2(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z-S$*(RP@9G5Z>GD*;7-G:60@(E@M4W!A;2U3
M8V]R92(*;7-G<W1R(")8+4YI=F5L+5-P86TB"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C<U"FUS9VED(")8+5-P86TM4W1A='5S(@IM<V=S='(@(E@M
M4W1A<F4M4W!A;2(*"B,Z(&9I;'1E<G,N<&AP.C4S(')U;&4N<&AP.C$T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@<G5L97,N(@IM<V=S='(@(B(*"B,Z(&9I;'1E
M<G,N<&AP.C0U(')U;&4N<&AP.C(Q"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!O<B!E9&ET(&-U<W1O;2!R=6QE<RXB"FUS9W-T<B`B
M(@H*(SH@=F%C871I;VXN<&AP.C,P"FUS9VED("(B"B)9;W4@;75S="!S<&5C
M:69Y(&%T(&QE87-T(&]N92!E;6%I;"!A9&1R97-S(&9O<B!W:&EC:"!T:&4@
M=F%C871I;VX@;65S<V%G97,@(@HB<VAO=6QD(&)E(&%C=&EV871E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR-S@@;&EB+U-C<FEP
M="]I;6%P+G!H<#HS,#$@;&EB+U-C<FEP="]I;6%P+G!H<#HS,34*(RP@9G5Z
M>GD*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(")3=6)I96-T(@H*(SH@
M=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,C0*;7-G:60@(E]!9&1R
M97-S*&5S*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=F%C871I;VXO=F%C871I;VXN:6YC.C(S"B,L(&9U>GIY"FUS9VED(")?
M061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SHB"FUS9W-T<B`B
M061R97-E;&4@;&$@8V%R92!S82!N=2!S92!T<FEM:71A(')A<W!U;G-U<FDB
M"@HC.B!L:6(O26YG;RYP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")?0FQA8VML
M:7-T(@IM<V=S='(@(DQI<W1A(&YE86=R82(*"B,Z('1E;7!L871E<R]B;&%C
M:VQI<W0O8FQA8VML:7-T+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T
M92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`B4W1E<F=E<F4@8V]M<&QE
M=&$@;65S86HB"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI
M;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(E]%;G1E<B!E86-H(&%D9')E<W,@;VX@
M82!N97<@;&EN93HB"FUS9W-T<B`B26YT<F]D=6-E=&D@9FEE8V%R92!A9')E
M<V$@<&4@;&EN:64@;F]U82(*"B,Z(&QI8B]);F=O+G!H<#HS,3$*;7-G:60@
M(E]&;W)W87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O
M<G=A<F0N:6YC.C$W"FUS9VED(")?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@
M:6X@=&AI<R!A8V-O=6YT/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8FQA
M8VML:7-T+V)L86-K;&ES="YI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(E]-;W9E
M(&UE<W-A9V4@=&\@9F]L9&5R.B(*;7-G<W1R(")-=71A(&UE<V%J92!I;B!D
M;W-A<CHB"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")?37D@96UA:6P@861D<F5S<V5S.B(*;7-G<W1R
M(")!9')E<V5L92!M96QE(&1E(&4M;6%I;"(*"B,Z(&QI8B]);F=O+G!H<#HS
M,30*(RP@9G5Z>GD*;7-G:60@(E]38W)I<'0B"FUS9W-T<B`B4V-R:7!T(@H*
M(SH@;&EB+TEN9V\N<&AP.C,P.`HC+"!F=7IZ>0IM<V=I9"`B7U9A8V%T:6]N
M(@IM<V=S='(@(E9A8V%N=&$B"@HC.B!L:6(O26YG;RYP:'`Z,S`R"FUS9VED
M(")?5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R=6QE+V9I
M;'1E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B86YD(@IM<V=S='(@(G-I(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+FAT;6PZ,38*;7-G:60@(F1I
M<V%B;&5D("T@8VQI8VL@=&\@96YA8FQE(@IM<V=S='(@(B(*"B,Z(&9I;'1E
M<G,N<&AP.C$X,`IM<V=I9"`B9FEE;&0B"FUS9W-T<B`B(@H*(SH@;&EB+U-C
M<FEP="]M86EL9')O<"YP:'`Z,3(P"FUS9VED(")M86EL9')O<"!S8W)I<'0@
M9V5N97)A=&5D(&)Y($EN9V\B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z
M,3@P"FUS9VED(")M871C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G5L
M92]F:6QT97(N:6YC.C0*;7-G:60@(F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M8W)I<'0O<')O8VUA:6PN<&AP.C$R.`IM<V=I9"`B<')O8VUA:6P@<V-R:7!T
M(&=E;F5R871E9"!B>2!);F=O(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O
M<VEE=F4N<&AP.C$P.0IM<V=I9"`B<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B
M>2!);F=O(@IM<V=S='(@(B(*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN
M9V\O<&\O;'1?3%0N<&\`````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-3`V,3``,3`T,3<S-C(W-#<`,#$W,S4V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@3&ET:'5A;FEA
M;B!T<F%N<VQA=&EO;G,@9F]R($EN9V\@<&%C:V%G92X*(R!#;W!Y<FEG:'0@
M*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB
M=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!);F=O('!A8VMA
M9V4N"B,@5FEL:75S(%-U;7-K87,@/'9I;&EU<T!L;FLN;'0^+"`R,#`S+"`R
M,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!);F=O(#(N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`T+3$Q
M+3,P(#$U.C4T*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@5FEL:75S(%-U
M;7-K87,@/'9I;&EU<T!L;FLN;'0^7&XB"B),86YG=6%G92U496%M.B!,:71H
M=6%N:6%N(#QV:6QI=7-`;&YK+FQT/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U
M.2TQ,UQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB
M4&QU<F%L+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]/3$@)B8@
M;B4Q,#`A/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@*&XE(@HB,3`P/#$P('Q\(&XE
M,3`P/CTR,"D@/R`Q(#H@,BD[7&XB"@HC.B!F:6QT97)S+G!H<#HQ.#4*;7-G
M:60@(B!A;F0B"FUS9W-T<B`B(&ER(@H*(SH@9FEL=&5R<RYP:'`Z,3@U"FUS
M9VED("(@;W(B"FUS9W-T<B`B(&%R8F$B"@HC.B!T96UP;&%T97,O8FQA8VML
M:7-T+V)L86-K;&ES="YI;F,Z,3<*;7-G:60@(D%C=&EO;B!F;W(@8FQA8VML
M:7-T960@861D<F5S<V5S.B(*;7-G<W1R(")696EK<VUA<R!A9')E<V%M<R!I
M\"!J=6]D;VIO('/@<F'P;SHB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV
M871E+FEN8SHQ,`IM<V=I9"`B06-T:79A=&4@4V-R:7!T(@IM<V=S='(@(L%J
M=6YG=&D@<VMR:7!TX"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C,R"B,L
M('!H<"UF;W)M870*;7-G:60@(D%C=&EV871I;F<@=&AE('-C<FEP="!F;W(@
M7"(E<UPB(&9A:6QE9#H@*"5D*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z-@IM<V=I9"`B061D:71I;VYA;"!3
M971T:6YG<R(*;7-G<W1R(")087!I;&1O;6D@;G5S=&%T>6UA:2(*"B,Z('1E
M;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#0*;7-G:60@(D%L;"!O9B!T:&4@
M9F]L;&]W:6YG(@IM<V=S='(@(E9I<V%S('-E:V%NZ&EA<R!SX&QY9V%S(@H*
M(SH@;&EB+V%P:2YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D%L;&]W(%)U;&5S
M(@IM<V=S='(@(DYA=6IA(&9I;'1R879I;6\@=&%I<WEK;.LB"@HC.B!T96UP
M;&%T97,O<G5L92]F;V]T97(N:6YC.C,S"FUS9VED(")!;G-W97)E9"(*;7-G
M<W1R(")!='-A:WET82(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z
M-#4*;7-G:60@(D%N>2!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@(D)E="!K
M=7)IX"!S96MA;NAIX"!SX&QY9^`B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F
M;V]T97(N:6YC.C$Q"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(E1A
M:6MY=&D@9FEL=')U<R(*"B,Z(&9I;'1E<G,N<&AP.C(Q-`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES(')U;&4_(@IM<V=S
M='(@(D%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\&G@(&9I;'1R879I;6\@
M=&%I<WEK;.8_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S"FUS9VED
M(")!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&5A8V@@
M8VAA;F=E/R(*;7-G<W1R(")!=71O;6%T:?!K86D@871N875J:6YT:2!S:W)I
M<'3@('!O(&MI96MV:65N;R!A=&YA=6II;FEM;S\B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C0W"FUS9VED(")"8V,B"FUS9W-T<B`B0F-C(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,T-`IM<V=I9"`B0F5G:6YS('=I=&@B"FUS9W-T
M<B`B4')A<VED961A(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,#8@;&EB
M+T1R:79E<B]L9&%P+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN
M9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z
M,30T('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHW"FUS9VED
M(")";&%C:VQI<W0B"FUS9W-T<B`B2G5O9&%S:7,@<^!R8?!A<R(*"B,Z(&)L
M86-K;&ES="YP:'`Z,3`P"FUS9VED(")";&%C:VQI<W0@161I="(*;7-G<W1R
M(")*=6]D;VIO('/@<F'P;R!R961A9V%V:6UA<R(*"B,Z(&)L86-K;&ES="YP
M:'`Z,3<*;7-G:60@(D)L86-K;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H
M92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(D1A8F%R=&EN
MZR!F:6QT<F%V:6UO('!O<VES=&5MZR!N97!A;&%I:V\@:G5O9&]J;R!SX')A
M\&\N(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C`W(&QI8B]38W)I
M<'0O;6%I;&1R;W`N<&AP.C$W-0IM<V=I9"`B0FQA8VML:7-T960@061D<F5S
M<R(*;7-G<W1R(")!9')E<V%S(.%T<F%U:W1A<R#A(&IU;V3@:N$@<^!R8?#@
M(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C0S"FUS9VED(")";&%C:VQI
M<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B061R97-A:2#A=')A=6MT:2#A(&IU
M;V3@:N$@<^!R8?#@(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HX.`IM
M<V=I9"`B0F]D>2(*;7-G<W1R("),86GP:V\@='5R:6YY<R(*"B,Z(&9I;'1E
M<G,N<&AP.C$X,B!R=6QE+G!H<#HR.#$*;7-G:60@(D-A<V4@4V5N<VET:79E
M(@IM<V=S='(@(D%T:W)E:7!T:2!DZVUE<^$@X2!D:63^:6%S:6%S+VUA_F%S
M:6%S(')A:61E<R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-#,*;7-G
M:60@(D-C(@IM<V=S='(@(D-C(@H*(SH@<G5L92YP:'`Z,3(R('=H:71E;&ES
M="YP:'`Z,S8@9F]R=V%R9"YP:'`Z,S,@=F%C871I;VXN<&AP.C0Q"B,Z(&)L
M86-K;&ES="YP:'`Z-CD*;7-G:60@(D-H86YG97,@<V%V960N(@IM<V=S='(@
M(E!A:V5I=&EM86D@:?!S875G;W1I+B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z-S4*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R("(B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S0P"FUS9VED(")#;VYT86EN<R(*;7-G<W1R
M(")4=7)I(@H*(SH@9FEL=&5R<RYP:'`Z,C(U(&9I;'1E<G,N<&AP.C(R-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y("5S(@IM<V=S='(@(DMO<&EJ=6]T
M:2`E<R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HW-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]P>2!O9B`E<R(*;7-G<W1R("(E<R!K;W!I:F$B"@HC.B!L:6(O
M26YG;RYP:'`Z-3(*;7-G:60@(D-R96%T92!N97<@9F]L9&5R(@IM<V=S='(@
M(E-U:W5R=&D@;F%U:N`@:V%T86QO9^`B"@HC.B!L:6(O4V-R:7!T+W!R;V-M
M86EL+G!H<#HS,S8@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,C<Y"FUS9VED
M(")$25-!0DQ%1#H@(@IM<V=S='(@(DG02E5.1U1!.B`B"@HC.B!T96UP;&%T
M97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ-PIM<V=I9"`B1&5A8W1I=F%T92!3
M8W)I<'0B"FUS9W-T<B`B2?!J=6YG=&D@<VMR:7!TX"(*"B,Z(&9I;'1E<G,N
M<&AP.C(Q-"!F:6QT97)S+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E("5S(@IM<V=S='(@(DGP=')I;G1I("5S(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O9FEL=&5R+FEN8SHS,`IM<V=I9"`B1&5L971E($-O;F1I=&EO;B(*
M;7-G<W1R("))\'1R:6YT:2!SX&QY9^`B"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,CDR"FUS9VED(")$96QE=&4@;65S<V%G92!C;VUP;&5T96QY(@IM<V=S='(@
M(E9I<VGP:V%I(&GP=')I;G1I(&QA:?!KX"(*"B,Z('1E;7!L871E<R]R=6QE
M+V9O;W1E<BYI;F,Z,S4*;7-G:60@(D1E;&5T960B"FUS9W-T<B`B2?!T<FEN
M=&$B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,C@P"FUS9VED(")$96QI=F5R(&EN
M=&\@;7D@24Y"3U@B"FUS9W-T<B`B4')I<W1A='ET:2#A($E.0D]8(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,P-@IM<V=I9"`B1&5L:79E<B!I;G1O(&UY($E.
M0D]8(&%N9"!C;W!Y('1O(@IM<V=S='(@(E!R:7-T871Y=&D@X2!)3D)/6"!I
M<B!N=6MO<&EJ=6]T:2#A(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,P,0IM<V=I
M9"`B1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R961I<F5C="!T;R(*;7-G
M<W1R(")0<FES=&%T>71I(.$@24Y"3U@@:7(@;G5K<F5I<'1I(.$B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,C@V"FUS9VED(")$96QI=F5R('1O(&9O;&1E<B(*
M;7-G<W1R(")097)K96QT:2#A(&MA=&%L;V?@(@H*(SH@9FEL=&5R<RYP:'`Z
M,C0Q(&9I;'1E<G,N<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$:7-A
M8FQE("5S(@IM<V=S='(@(DGP:G5N9W1I("5S(@H*(SH@=&5M<&QA=&5S+W=H
M:71E;&ES="]W:&ET96QI<W0N:6YC.C$P('1E;7!L871E<R]B;&%C:VQI<W0O
M8FQA8VML:7-T+FEN8SHQ,`HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C8@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHR-@IM<V=I9"`B1&ES86)L960B
M"FUS9W-T<B`B2?!J=6YG=&$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T
M:6YG<RYI;F,Z,3,*;7-G:60@(D1I<W!L87D@9&5T86EL960@;F]T:69I8V%T
M:6]N('=H96X@96%C:"!F:6QT97(@:7,@87!P;&EE9#\B"FUS9W-T<B`B2V%I
M('!A;F%U9&]J86UA<R!F:6QT<F%S(')O9'ET:2!D971A;/@@<')A;F7P:6W@
M/R(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,S0*;7-G
M:60@(D1O(%]N;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L:R!O<B!L:7-T(&UE
M<W-A9V5S(@IM<V=S='(@(DYE<VGX<W1I(&%T<V%K>6WX(.$@871S:71I:W1I
M;FEU<R!A<F)A(%]K;VYF97)E;F-I:O@@;&%I\&MU<R(*"B,Z('1E;7!L871E
M<R]R=6QE+V9O;W1E<BYI;F,Z,3`*;7-G:60@(D1O('1H:7,Z(@IM<V=S='(@
M(E9Y:V1Y=&D@=&%I.B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#4*;7-G:60@
M(D1O97-N)W0@8F5G:6X@=VET:"(*;7-G<W1R(").97!R87-I9&5D82(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS-#$*;7-G:60@(D1O97-N)W0@8V]N=&%I;B(*
M;7-G<W1R(").971U<FDB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0W"FUS9VED
M(")$;V5S;B=T(&5N9"!W:71H(@IM<V=S='(@(DYE<VEB86EG:6$B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S0Y"FUS9VED(")$;V5S;B=T(&5X:7-T(@IM<V=S
M='(@(DYE96=Z:7-T=6]J82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3(*;7-G
M:60@(D1O97-N)W0@;6%T8V@@*'=I=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R
M(").96%T:71I;FMA(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN
M8SHS,0IM<V=I9"`B161I="(*;7-G<W1R(")2961A9V%V:6UA<R(*"B,Z(&9I
M;'1E<G,N<&AP.C(P,R!F:6QT97)S+G!H<#HR,#4@9FEL=&5R<RYP:'`Z,C`Y
M(&9I;'1E<G,N<&AP.C(Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET("5S
M(@IM<V=S='(@(E)E9&%G=6]T:2`E<R(*"B,Z(&9I;'1E<G,N<&AP.C(T-2!F
M:6QT97)S+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YA8FQE("5S
M(@IM<V=S='(@(L%J=6YG=&D@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H
M96%D97(N:6YC.C,W"FUS9VED(")%;F%B;&5D(@IM<V=S='(@(L%J=6YG=&$B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0V"FUS9VED(")%;F1S('=I=&@B"FUS
M9W-T<B`B0F%I9VEA<VDB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4W"FUS9VED
M(")%<75A;"!T;R(*;7-G<W1R("),>6=U<R(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,3,Y(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30Y(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,34X"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,38X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@8W5R<F5N="!S8W)I
M<'0Z("@E9"D@)7,B"FUS9W-T<B`B(@H*(SH@8FQA8VML:7-T+G!H<#HV-PIM
M<V=I9"`B17)R;W(@<V%V:6YG(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C(*;7-G:60@(D5X:7-T:6YG
M(%)U;&5S(@IM<V=S='(@(D5G>FES='5O:F%NZ&EO<R!F:6QT<O@@=&%I<WEK
M;.MS(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T.`IM<V=I9"`B17AI<W1S(@IM
M<V=S='(@(D5G>FES='5O:F$B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%>'!E8W1E9"`Q(&]B:F5C="P@9V]T
M("5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG
M<RYI;F,Z,C`*;7-G:60@(D9I;'1E<B!!;&P@365S<V%G97,B"FUS9W-T<B`B
M1FEL=')U;W1I('9I<W5S(&QA:?!K=7,B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]S971T:6YG<RYI;F,Z,C(*;7-G:60@(D9I;'1E<B!/;FQY(%-E96X@365S
M<V%G97,B"FUS9W-T<B`B1FEL=')U;W1I('1I:R!P97)S:V%I='ET=7,@;&%I
M\&MU<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,0IM
M<V=I9"`B1FEL=&5R($]N;'D@56YS965N($UE<W-A9V5S(@IM<V=S='(@(D9I
M;'1R=6]T:2!T:6L@;F5P97)S:V%I='ET=7,@;&%I\&MU<R(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHQ.`IM<V=I9"`B1FEL=&5R($]P
M=&EO;G,B"FUS9W-T<B`B1FEL='+X('!A<F%M971R86DB"@HC.B!T96UP;&%T
M97,O<G5L92]H96%D97(N:6YC.C(U"FUS9VED(")&:6QT97(@4G5L92(*;7-G
M<W1R(")&:6QT<F%V:6UO('1A:7-Y:VSK(@H*(SH@9FEL=&5R<RYP:'`Z,3`Y
M"FUS9VED(")&:6QT97(@4G5L97,B"FUS9W-T<B`B1FEL=')A=FEM;R!T86ES
M>6MLZW,B"@HC.B!S8W)I<'0N<&AP.C4R"FUS9VED(")&:6QT97(@4V-R:7!T
M($1I<W!L87DB"FUS9W-T<B`B1FEL=')O('-K<FEP=&\@<F]D>6UA<R(*"B,Z
M(&QI8B]);F=O+G!H<#HS,#`*;7-G:60@(D9I;'1E<B!?4G5L97,B"FUS9W-T
M<B`B7T9I;'1R86DB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H
M<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B1FEL=')A=FEM87,Z("5S(&QA:?!K87,H86DL(/@I(&YU:V]P:6IU
M;W1A<RAI+"!A*2#A(&MA=&%L;V?@(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T
M+VEM87`N<&AP.C,P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&1E;&5T960N(@IM<V=S
M='(@(D9I;'1R879I;6%S.B!I\'1R:6YT87,H:2P@82D@)7,@;&%I\&MA<RAA
M:2P@^"DN(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA
M=F4@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
M1FEL=')A=FEM87,Z("5S(&QA:?!K87,H86DL(/@I('!E<FME;'1A<RAI+"!A
M*2#A(&MA=&%L;V?@(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP
M.C$X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S
M(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@=V5R92!D
M96QE=&5D+B(*;7-G<W1R("(B"B)&:6QT<F%V:6UA<SH@)7,@;&%I\&MA<RAA
M:2P@^"D@871I=&EN:V%N=&ES*'ES+"#X*2!J=6]DX&KA('/@<F'PX"!I\'1R
M:6YT87,B"B(H:2P@82DN(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB1FEL=&5R(&%C=&EV:71Y.B!4:&4@
M;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@8V]P:65D('1O
M('1H92`B"B)F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")&:6QT<F%V:6UA<SH@
M;&%I\&MA<R!<(B5S7"(@;G5O(%PB)7-<(B!N=6MO<&EJ=6]T87,@X2!K871A
M;&]GX"!<(B5S7"(N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G
M92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B1FEL=')A=FEM87,Z(&QA:?!K87,@7"(E<UPB(&YU;R!<(B5S7"(@:?!T
M<FEN=&%S+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@
M7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&UO=F5D('1O('1H92!F;VQD
M97(@(@HB7"(E<UPB+B(*;7-G<W1R(")&:6QT<F%V:6UA<SH@;&%I\&MA<R!<
M(B5S7"(@;G5O(%PB)7-<(B!P97)K96QT87,@X2!K871A;&]GX"!<(B5S7"(N
M(@H*(SH@<G5L92YP:'`Z,38P"FUS9VED(")&:6QT97(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")4;VMI;R!F:6QT<F\@;NMR82XB"@HC.B!T96UP;&%T97,O<G5L
M92]H96%D97(N:6YC.C0R"FUS9VED(")&;W(@86X@:6YC;VUI;F<@;65S<V%G
M92!T:&%T(&UA=&-H97,Z(@IM<V=S='(@(E9I<VEE;7,@9V%U;F%M:65M<R!L
M86GP:V%M<R!K=7)I93HB"@HC.B!F:6QT97)S+G!H<#HQ-C(@=&5M<&QA=&5S
M+V9O<G=A<F0O9F]R=V%R9"YI;F,Z.`IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R
M(")097)S:?AS=&DB"@HC.B!F;W)W87)D+G!H<#HQ-@IM<V=I9"`B1F]R=V%R
M9"!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D
M<FEV97(N(@IM<V=S='(@(D1A8F%R=&ENZR!F:6QT<F%V:6UO('!O<VES=&5M
MZR!N97!A;&%I:V\@<&5R<VEU;G1I;?@N(@H*(SH@;&EB+U-C<FEP="]P<F]C
M;6%I;"YP:'`Z,C@R(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(R-`IM<V=I
M9"`B1F]R=V%R9',B"FUS9W-T<B`B4&5R<VEU;G1I;6%I(@H*(SH@9F]R=V%R
M9"YP:'`Z-#8*;7-G:60@(D9O<G=A<F1S($5D:70B"FUS9W-T<B`B4&5R<VEU
M;G1I;?@@<F5D86=A=FEM87,B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T
M.C,Y"FUS9VED(")&<F]M(@IM<V=S='(@(DYU;R(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS-34*;7-G:60@(D=R96%T97(@=&AA;B(*;7-G<W1R(")$875G:6%U
M(&YE:2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-38*;7-G:60@(D=R96%T97(@
M=&AA;B!O<B!E<75A;"!T;R(*;7-G<W1R(")$875G:6%U(&%R8F$@;'EG=2(*
M"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S$*;7-G:60@(DEM<&]R
M=&%N="(*;7-G<W1R(")3=F%R8G4B"@HC.B!R=6QE+G!H<#HS-@IM<V=I9"`B
M26YD:79I9'5A;"!R=6QE<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R
M<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")$86)A<G1I;NL@9FEL
M=')A=FEM;R!P;W-I<W1E;>L@;F5P86QA:6MO(&EN9&EV:61U86QI^"!F:6QT
M<O@N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3@U-0IM<V=I9"`B26YE
M>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G92!D96QI=F5R
M>2XB"FUS9W-T<B`B3&%I\&OX(&=A=FEM=6D@;G5R;V1Y=&$@;F5E9WII<W1U
M;VIA;G1I('!A\'1O(&3K_G5TZRXB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0R
M"FUS9VED("))<R(*;7-G<W1R(")9<F$B"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,S0S"FUS9VED("))<VXG="(*;7-G<W1R(").ZW)A(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HR,PIM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I
M<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N
M;W0@;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4S
M"FUS9VED("),97-S('1H86XB"FUS9W-T<B`B36'^:6%U(&YE:2(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HS-30*;7-G:60@(DQE<W,@=&AA;B!O<B!E<75A;"!T
M;R(*;7-G<W1R(")-8?YI874@87)B82!L>6=U(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HU.0IM<V=I9"`B3&ES="U)1"(*;7-G<W1R(")+;VYF97)E
M;F-I:F]S($E$(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N
M:6YC.C(P"FUS9VED(")-87)?:R!M97-S86=E(&%S(&1E;&5T960B"FUS9W-T
M<B`B4&'^>6WK=&D@;&%I\%]K=7,@:V%I<"!I\'1R:6YT=7,B"@HC.B!T96UP
M;&%T97,O<G5L92]F;V]T97(N:6YC.C(T"FUS9VED(")-87)K(&UE<W-A9V4@
M87,Z(@IM<V=S='(@(E!A_GEMZW1I(&QA:?!KX"!K86EP.B(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS-3$*;7-G:60@(DUA=&-H97,@*'=I=&@@<&QA8V5H;VQD
M97)S*2(*;7-G<W1R(")!=&ET:6YK82(*"B,Z(&QI8B]A<&DN<&AP.C4W"FUS
M9VED(")-87AI;75M($YU;6)E<B!O9B!2=6QE<R(*;7-G<W1R("(B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z-#<X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA
M>&EM=6T@;G5M8F5R(&]F(&)L86-K;&ES=&5D(&%D9')E<W-E<R!E>&-E961E
M9"`H5&]T86P@861D<F5S<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z
M("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!B;&%C:VQI
M<W0N(@IM<V=S='(@(B(*(E!A<VEE:W1A<R!M86MS:6UA;'5S(&%D<F5S^"!S
M:V%IZ&EU<R!J=6]D86IA;64@<^!R8?#K+B`H2?`@=FES;R!A9')E<_@Z("5S
M+"`B"B)M86MS:6UA;'5S(&%D<F5S^"!K:65K:7,Z("5S*2X@3F%U:O@@861R
M97/X('!R:63K=&D@;F5G86QI;6$N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C4S
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O9B!W
M:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E
M<SH@)7,L("(*(DUA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@
M861D(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+B(*;7-G<W1R("(B"B)0
M87-I96MT87,@;6%K<VEM86QU<R!A9')E<_@@<VMA:>AI=7,@8F%L=&%J86UE
M('/@<F'PZRX@*$GP('9I<V\@861R97/X.B`E<RP@(@HB;6%K<VEM86QU<R!A
M9')E<_@@:VEE:VES.B`E<RDN($YA=6KX(&%D<F5S^"!P<FEDZW1I(&YE9V%L
M:6UA+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W,C,*;7-G:60@(DUI
M<W-I;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O(@IM<V=S='(@
M(DQA:?!K^"!P97)S:75N=&EM=6D@;F5N=7)O9'ET87,@96PN('!A\'1O(&%D
M<F5S87,B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-S4U"FUS9VED(")-
M:7-S:6YG(')E87-O;B!F;W(@<F5J96-T(@IM<V=S='(@(D%T;65T:6UU:2!N
M96YU<F]D>71A('!R:67^87-T:7,B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HQ.3(R"FUS9VED(")-:7-S:6YG(')E87-O;B!I;B!V86-A=&EO;BXB"FUS
M9W-T<B`B071O<W1O9_@@;6]D=6QY:F4@;F5N=7)O9'ET82!P<FEE_F%S=&ES
M+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z-#`*;7-G:60@
M(DUO=F4B"FUS9W-T<B`B4&5R:V5L=&DB"@HC.B!F:6QT97)S+G!H<#HQ,C8@
M9FEL=&5R<RYP:'`Z,C,X"FUS9VED(")-;W9E(%)U;&4@1&]W;B(*;7-G<W1R
M(")097)K96QT:2#^96UY;B(*"B,Z(&9I;'1E<G,N<&AP.C$R-R!F:6QT97)S
M+G!H<#HR,S<*;7-G:60@(DUO=F4@4G5L92!5<"(*;7-G<W1R(")097)K96QT
M:2!A=6OP='EN(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN
M8SHT,@IM<V=I9"`B3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C871I;VX@
M<F5P;&EE<SHB"FUS9W-T<B`B1&EE;O@@<VMA:>AI=7,@=&%R<"!A=&]S=&]G
M^"!?871S86MY;?@Z(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+6YO
M;F4N:6YC.C0@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHX"B,Z(&QI
M8B]3=&]R86=E+G!H<#HW,30*;7-G:60@(DYE=R!2=6QE(@IM<V=S='(@(DYA
M=6IA(&9I;'1R879I;6\@=&%I<WEK;.LB"@HC.B!L:6(O26YG;RYP:'`Z,3DT
M(&QI8B]);F=O+G!H<#HQ.38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DYO(%PB)7-<(B!E;&5M96YT(&9O=6YD(&EN(&)A8VME;F0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B4F5I:_!MZR`G)7,G(&YE;G5R;V1Y=&$@<&]S:7-T
M96WK<R!N=7-T871Y;75O<V4N(@H*(SH@;&EB+TEN9V\N<&AP.C$Y,@IM<V=I
M9"`B3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0B"FUS9W-T
M<B`BT&EA;64@<V5R=F5R>6IE(&YE<W5K;VYF:6?[<G5O=&$@<&]S:7-T96WK
M(@H*(SH@;&EB+TEN9V\N<&AP.C$V.0IM<V=I9"`B3F\@8F%C:V5N9',@8V]N
M9FEG=7)E9"!I;B!B86-K96YD<RYP:'`B"FUS9W-T<B`B4&]S:7-T96WK(&YE
M<W5K;VYF:6?[<G5O=&$@8F%C:V5N9',N<&AP(&9A:6QE(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O9FEL=&5R+6YO;F4N:6YC.C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DYO(&9I;'1E<G,N($-L:6-K(%PB)7-<(B!T;R!C<F5A
M=&4@82!N97<@9FEL=&5R+B(*;7-G<W1R(")&:6QT<O@@;NMR82X@3F]RZV1A
M;6D@<W5K=7)T:2!N875JX"!F:6QT<N`L('-P875S:VET92`G)7,G+B(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$S,C<@;&EB+U-C<FEP="]S:65V92YP
M:'`Z,30R,`HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-3DT"FUS9VED(").
M;R!H96%D97)S('-P96-I9FEE9"(*;7-G<W1R(").ZW)A(&%N=')A\.AI^"!S
M<&5C:69I:V%C:6IO<R(*"B,Z('-C<FEP="YP:'`Z-C<*;7-G:60@(DYO('-C
M<FEP="!G96YE<F%T960N(@IM<V=S='(@(E-K<FEP=&%S(&YE<W5G96YE<G5O
M=&%S+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$V,#D*;7-G:60@(DYO
M('-T<FEN9W,@<W!E8VEF:65D(@IM<V=S='(@(DYEX79E<W1O<R!R96EK\&WK
M<R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3@*;7-G:60@(DYO="!E<75A;"!T
M;R(*;7-G<W1R(").96QY9W5S(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Q-@IM
M<V=I9"`B3VYL>2!F;&%G('1H92!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.0IM<V=I9"`B3W!T:6]N<R!A8F]U="!S
M8W)I<'0@=7!D871I;F<N(@IM<V=S='(@(DYU<W1A='EM86D@<W5S:6KF('-U
M('-K<FEP=/@@871N875J:6YI;74N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$W"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(DMI=&D@;G5S
M=&%T>6UA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VYE=U]F;VQD97(N
M:G,Z-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@
M9F]L9&5R.B(*;7-G<W1R("+!=F5S:VET92!N875J;R!K871A;&]G;R!P879A
M9&EN:6W@.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M-C`*;7-G:60@(E)?96%S;VXB"FUS9W-T<B`B4')I95_^87-T:7,B"@HC.B!C
M;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C8S"FUS9VED(")296-E:79E9"(*;7-G
M<W1R(")'875T82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.3<*;7-G:60@(E)E
M9&ER96-T('1O(@IM<V=S='(@(DYU:W)E:7!T:2#A(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,U,`IM<V=I9"`B4F5G=6QA<B!E>'!R97-S:6]N(@IM<V=S='(@
M(E)E9W5L:6%R:2!I\')A:?!K82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,3(*
M;7-G:60@(E)E:F5C="!W:71H(')E87-O;B(*;7-G<W1R(")!=&UE<W1I('-U
M('!R:67^87-T:6UI(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU-0IM
M<V=I9"`B4F5S96YT(%1O(@IM<V=S='(@(E!E<G-I^'-T87,@X2(*"B,Z(&-O
M;F9I9R]F:65L9',N<&AP+F1I<W0Z-3$*;7-G:60@(E)E<V5N="UF<F]M(@IM
M<V=S='(@(E!E<G-I^'-T87,@;G5O(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O
M=&5R+FEN8SHV,`IM<V=I9"`B4F5T=7)N('1O($9I;'1E<G,@3&ES="(*;7-G
M<W1R(")'<N'^=&D@X2!F:6QT<O@@<^!R8?#@(@H*(SH@=&5M<&QA=&5S+W=H
M:71E;&ES="]W:&ET96QI<W0N:6YC.C(T('1E;7!L871E<R]B;&%C:VQI<W0O
M8FQA8VML:7-T+FEN8SHT,0HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C<Q('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,T"FUS
M9VED(")2971U<FX@=&\@4G5L97,@3&ES="(*;7-G<W1R(")'<N'^=&D@X2!F
M:6QT<O@@<^!R8?#@(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN
M8SHS-`IM<V=I9"`B4G5L92(*;7-G<W1R(")486ES>6MLZR(*"B,Z(&9I;'1E
M<G,N<&AP.C8P"FUS9VED(")2=6QE($-O<&EE9"(*;7-G<W1R(")486ES>6ML
MZR!N=6MO<&EJ=6]T82(*"B,Z(&9I;'1E<G,N<&AP.C,Y"FUS9VED(")2=6QE
M($1E;&5T960B"FUS9W-T<B`B5&%I<WEK;.L@:?!T<FEN=&$B"@HC.B!F:6QT
M97)S+G!H<#HW-@IM<V=I9"`B4G5L92!$:7-A8FQE9"(*;7-G<W1R(")486ES
M>6MLZR!I\&IU;F=T82(*"B,Z(&9I;'1E<G,N<&AP.C@Q"FUS9VED(")2=6QE
M($5N86)L960B"FUS9W-T<B`B5&%I<WEK;.L@X6IU;F=T82(*"B,Z('1E;7!L
M871E<R]R=6QE+VAE861E<BYI;F,Z,S,*;7-G:60@(E)U;&4@3F%M92(*;7-G
M<W1R(")486ES>6MLZW,@<&%V861I;FEM87,B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE
M9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T
M+W=H:71E;&ES="YI;F,Z,C,@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C0P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M-S`@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,S,*(SH@=&5M<&QA
M=&5S+W)U;&4O9F]O=&5R+FEN8SHU.0IM<V=I9"`B4V%V92(*;7-G<W1R("))
M\'-A=6=O=&DB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z
M,CD*;7-G:60@(E-A=F4@4V5T=&EN9W,B"FUS9W-T<B`B2?!S875G;W1I(&YU
M<W1A='EM=7,B"@HC.B!T96UP;&%T97,O<V-R:7!T+VAE861E<BYI;F,Z,@IM
M<V=I9"`B4V-R:7!T(@IM<V=S='(@(E-K<FEP=&%S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$X"FUS9VED(")38W)I<'0@57!D871I;F<B"FUS9W-T
M<B`B4VMR:7!T;R!A=&YA=6II;FEM87,B"@HC.B!L:6(O26YG;RYP:'`Z,C$W
M"FUS9VED(")38W)I<'0@;F]T('5P9&%T960N(@IM<V=S='(@(E-K<FEP=&%S
M(&YE871N875J:6YT87,N(@H*(SH@;&EB+TEN9V\N<&AP.C$S,`IM<V=I9"`B
M4V-R:7!T('-U8V-E<W-F=6QL>2!A8W1I=F%T960N(@IM<V=S='(@(E-K<FEP
M=&%S('/K:VUI;F=A:2#A:G5N9W1A<RXB"@HC.B!L:6(O26YG;RYP:'`Z,3(Y
M"FUS9VED(")38W)I<'0@<W5C8V5S<V9U;&QY(&1E86-T:79A=&5D+B(*;7-G
M<W1R(")3:W)I<'1A<R!SZVMM:6YG86D@:?!J=6YG=&%S+B(*"B,Z('1E;7!L
M871E<R]R=6QE+V9O;W1E<BYI;F,Z,CD*;7-G:60@(E-E96XB"FUS9W-T<B`B
M4VMA:71Y=&$B"@HC.B!R=6QE+G!H<#HQ.3`*;7-G:60@(E-E;&5C="!A(&9I
M96QD(@IM<V=S='(@(E!A<VER:6YK:71E(&QA=6O@(@H*(SH@;&EB+TEN9V\N
M<&AP.C0Y"FUS9VED(")396QE8W0@=&%R9V5T(&9O;&1E<B(*;7-G<W1R(")0
M87-I<FEN:VET92!K871A;&]GX"(*"B,Z(')U;&4N<&AP.C(R-PIM<V=I9"`B
M4V5L9BU$969I;F5D($AE861E<B(*;7-G<W1R(")08>AI;R!A<')A\'ET82!A
M;G1R8?!TZR(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S4*;7-G:60@
M(E-E;F1E<B(*;7-G<W1R(")3:75N=.MJ87,B"@HC.B!F:6QT97)S+G!H<#HY
M-0IM<V=I9"`B4V5T=&EN9W,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S
M='(@(DYU<W1A='EM86D@<^MK;6EN9V%I(&%T;F%U:FEN=&DN(@H*(SH@=&5M
M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,C0*;7-G:60@(E-H;W<@06-T
M:79E(%-C<FEP="(*;7-G<W1R(")2;V1Y=&D@86MT>7;X:N$@<VMR:7!TX"(*
M"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C,Q"FUS9VED(")3
M:&]W($-U<G)E;G0@4V-R:7!T(@IM<V=S='(@(E)O9'ET:2!D86)A<G1I;N$@
M<VMR:7!TX"(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z.#,*;7-G:60@
M(E-I>F4B"FUS9W-T<B`B1'ED:7,B"@HC.B!T96UP;&%T97,O<G5L92]F;V]T
M97(N:6YC.C0Y"FUS9VED(")3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M
M871C:&5S/R(*;7-G<W1R(").=7-T;W1I('1I:W)I;G1I(&IE:6=U(&%T:71I
M;FMA(/!IX"!T86ES>6MLYC\B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C
M871I;VXN:6YC.C4Q"FUS9VED(")3=6)J95]C="!O9B!V86-A=&EO;B!M97-S
M86=E.B(*;7-G<W1R(")!=&]S=&]G^"!L86GP:V\@7W1E;6$Z(@H*(SH@8V]N
M9FEG+V9I96QD<RYP:'`N9&ES=#HS,0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R
M(")496UA(@H*(SH@;&EB+V%P:2YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&%D9')E<W,@7"(E<UPB(&AA<R!B965N(&%D9&5D('1O('EO=7(@
M8FQA8VML:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@7"(E<UPB(&AA<R!B965N
M(&%D9&5D('1O('EO=7(@=VAI=&5L:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O
M26YG;RYP:'`Z,3(U"FUS9VED(")4:&4@9')I=F5R('-A:60Z("(*;7-G<W1R
M(")0;W-I<W1E;>MS('!R86YE\&EM87,Z("(*"B,Z(&QI8B]);F=O+G!H<#HQ
M,C0*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8W1I=F%T:6YG('1H92!S
M8W)I<'0N(@IM<V=S='(@(DML86ED82#A:G5N9VEA;G0@<VMR:7!TX"XB"@HC
M.B!L:6(O26YG;RYP:'`Z,3(S"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@(DML86ED82!I\&IU
M;F=I86YT('-K<FEP=.`N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HR
M-PIM<V=I9"`B5&\B"FUS9W-T<B`B2V%M(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O9FEL=&5R+FAT;6PZ,C@*(RP@9G5Z>GD*;7-G:60@(E1O.B(*;7-G<W1R
M(")+86TB"@HC.B!L:6(O4V-R:7!T+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM
M<V=S='(@(DYE9V%L:74@=?YK<F%U=&D@)7,@87!R8?!Y;6\N(@H*(SH@9FEL
M=&5R<RYP:'`Z,34V('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M-0HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR-C(*;7-G:60@(E9A8V%T
M:6]N(@IM<V=S='(@(D%T;W-T;V=O<R(*"B,Z('9A8V%T:6]N+G!H<#HW,@IM
M<V=I9"`B5F%C871I;VX@161I="(*;7-G<W1R(")!=&]S=&]G^"!R961A9V%V
M:6UA<R(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C,U,0IM<V=I9"`B5F%C
M871I;VX@365S<V%G92(*;7-G<W1R(")!=&]S=&]G^"!L86GP:V%S(@H*(SH@
M=F%C871I;VXN<&AP.C$V"FUS9VED(")686-A=&EO;B!I<R!N;W0@<W5P<&]R
M=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@
M(D1A8F%R=&ENZR!F:6QT<F%V:6UO('!O<VES=&5MZR!N97!A;&%I:V\@871O
M<W1O9_@@;6]D=6QI;RXB"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E
M;&ES="YI;F,Z,38*;7-G:60@(E=H7VET96QI<W0@861D<F5S<V5S.B(*;7-G
M<W1R(")"86QT;VIO('/@<F'P;R!?861R97-A:3HB"@HC.B!F:6QT97)S+G!H
M<#HQ-3`@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C@*;7-G
M:60@(E=H:71E;&ES="(*;7-G<W1R(")"86QT87-I<R!SX')A\&%S(@H*(SH@
M=VAI=&5L:7-T+G!H<#HU-0IM<V=I9"`B5VAI=&5L:7-T($5D:70B"FUS9W-T
M<B`B0F%L=&]J;R!SX')A\&\@<F5D86=A=FEM87,B"@HC.B!W:&ET96QI<W0N
M<&AP.C$X"FUS9VED(")7:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")$86)A<G1I
M;NL@9FEL=')A=FEM;R!P;W-I<W1E;>L@;F5P86QA:6MO(&)A;'1O:F\@<^!R
M8?!O+B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(S-"!L:6(O4V-R
M:7!T+W-I979E+G!H<#HR.3<*(SH@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z
M,C`R"FUS9VED(")7:&ET96QI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B061R
M97-A:2#A=')A=6MT:2#A(&)A;'3@:N$@<^!R8?#@(@H*(SH@8V]N9FEG+V9I
M96QD<RYP:'`N9&ES=#HW.0IM<V=I9"`B6"U0<FEO<FET>2(*;7-G<W1R(")3
M=F%R8F$B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C8W"FUS9VED(")8
M+5-P86TM3&5V96PB"FUS9W-T<B`B6"U3<&%M+4QE=F5L(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3<&%M+5-C;W)E(@IM<V=S
M='(@(E@M4W!A;2U38V]R92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z
M-S4*;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T<B`B6"U3<&%M+5-T871U
M<R(*"B,Z(&9I;'1E<G,N<&AP.C4S(')U;&4N<&AP.C$T-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@<G5L97,N(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C0U
M(')U;&4N<&AP.C(Q"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!O<B!E9&ET(&-U<W1O;2!R=6QE<RXB"FUS9W-T<B`B(@H*(SH@=F%C
M871I;VXN<&AP.C,P"FUS9VED("(B"B)9;W4@;75S="!S<&5C:69Y(&%T(&QE
M87-T(&]N92!E;6%I;"!A9&1R97-S(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@
M;65S<V%G97,@(@HB<VAO=6QD(&)E(&%C=&EV871E9"XB"FUS9W-T<B`B(@HB
M071O<W1O9_@@;&%I\&OX(&%K='EV879I;75I('1U<FET92!N=7)O9'ET:2!B
M96YT('9I96[@(&5L+B!P8?!T;R!A9')E<^`N(@H*(SH@;&EB+U-C<FEP="]I
M;6%P+G!H<#HR-S@@;&EB+U-C<FEP="]I;6%P+G!H<#HS,#$@;&EB+U-C<FEP
M="]I;6%P+G!H<#HS,34*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");
M8F4@<&%V861I;FEM;UTB"@HC.B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D
M+FEN8SHR-`IM<V=I9"`B7T%D9')E<W,H97,I('1O(&9O<G=A<F0@=&\Z(@IM
M<V=S='(@(E]!9')E<V%S*&%I*2!P97)S:75NZ&EA;6D@X3HB"@HC.B!T96UP
M;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C(S"FUS9VED(")?061D<F5S
M<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SHB"FUS9W-T<B`B05]D<F5S
M86D@X2!K=7)I=6]S(&YE871S86MY=&DZ(@H*(SH@;&EB+TEN9V\N<&AP.C,P
M-0IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R(")?2G5O9&%S:7,@<^!R8?!A
M<R(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ.`IM
M<V=I9"`B7T1E;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`B7U9I
M<VGP:V%I(&GP=')I;G1I(&QA:?!KX"(*"B,Z('1E;7!L871E<R]B;&%C:VQI
M<W0O8FQA8VML:7-T+FEN8SHS,0IM<V=I9"`B7T5N=&5R(&5A8V@@861D<F5S
M<R!O;B!A(&YE=R!L:6YE.B(*;7-G<W1R(")+:65K=FEE;N`@7V%D<F5SX"!R
M8?!Y:VET92!N875J;VIE(&5I;'5TZVIE.B(*"B,Z(&QI8B]);F=O+G!H<#HS
M,3$*;7-G:60@(E]&;W)W87)D(@IM<V=S='(@(E!?97)S:?AS=&DB"@HC.B!T
M96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHQ-PIM<V=I9"`B7TME97`@
M82!C;W!Y(&]F(&UE<W-A9V5S(&EN('1H:7,@86-C;W5N=#\B"FUS9W-T<B`B
M07(@<&%L:6MT:2!L86GP:V\@:V]P:6K@(/!I;VIE('!A\'1O(&3K_G5TZVIE
M/R(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,@IM
M<V=I9"`B7TUO=F4@;65S<V%G92!T;R!F;VQD97(Z(@IM<V=S='(@(E!E<FME
M;'1I(&QA:?!K=7,@X2!?:V%T86QO9^`Z(@H*(SH@=&5M<&QA=&5S+W9A8V%T
M:6]N+W9A8V%T:6]N+FEN8SHQ,PIM<V=I9"`B7TUY(&5M86EL(&%D9')E<W-E
M<SHB"FUS9W-T<B`B7TUA;F\@16PN('!A\'1O(&%D<F5S86DB"@HC.B!L:6(O
M26YG;RYP:'`Z,S$T"FUS9VED(")?4V-R:7!T(@IM<V=S='(@(E]3:W)I<'1A
M<R(*"B,Z(&QI8B]);F=O+G!H<#HS,#@*;7-G:60@(E]686-A=&EO;B(*;7-G
M<W1R(")!=%]O<W1O9V]S(@H*(SH@;&EB+TEN9V\N<&AP.C,P,@IM<V=I9"`B
M7U=H:71E;&ES="(*;7-G<W1R(")?0F%L=&%S:7,@<^!R8?!A<R(*"B,Z('1E
M;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z-`IM<V=I9"`B86YD(@IM<V=S='(@
M(FER(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+FAT;6PZ,38*;7-G
M:60@(F1I<V%B;&5D("T@8VQI8VL@=&\@96YA8FQE(@IM<V=S='(@(B(*"B,Z
M(&9I;'1E<G,N<&AP.C$X,`IM<V=I9"`B9FEE;&0B"FUS9W-T<B`B;&%U:V%S
M(@H*(SH@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,3(P"B,L(&9U>GIY"FUS
M9VED(")M86EL9')O<"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\B"FUS9W-T
M<B`B<')O8VUA:6P@<VMR:7!T87,@<W5G96YE<G5O=&%S('-U($EN9V\B"@HC
M.B!F:6QT97)S+G!H<#HQ.#`*;7-G:60@(FUA=&-H(@IM<V=S='(@(F%T:71I
M;FMA(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")O
M<B(*;7-G<W1R(")A<F)A(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z
M,3(X"FUS9VED(")P<F]C;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\B
M"FUS9W-T<B`B<')O8VUA:6P@<VMR:7!T87,@<W5G96YE<G5O=&%S('-U($EN
M9V\B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ,#D*;7-G:60@(G-I979E
M(&9I;'1E<B!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R(")S:65V92!F:6QT
M<F%S('-U9V5N97)U;W1A<R!S=2!);F=O(@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O<&\O
M9&5?1$4N<&\`````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-34V-38`,3`T,3<S-C(W-#<`,#$W,S$W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@1V5R;6%N('1R86YS;&%T
M:6]N<R!F;W(@26YG;R!P86-K86=E"B,@1V5R;6%N(&UE<W-A9V5S(&9O<B!)
M;F=O+@HC($-O<'ER:6=H="`H0RD@,C`P,RTR,#`V($AO<F1E(%!R;VIE8W0*
M(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC
M96YS92!A<R!T:&4@26YG;R!P86-K86=E+@HC($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^+"`R,#`S+3(P,#8N"B,*;7-G:60@(B(*;7-G<W1R("(B
M"B)0<F]J96-T+4ED+59E<G-I;VXZ($EN9V\@,2XQ+6-V<UQN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`V+3`S+3`V(#$R.C0W*S`Q,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z-3,K,#$P,%QN(@HB3&%S="U4
M<F%N<VQA=&]R.B!*86X@4V-H;F5I9&5R7&XB"B),86YG=6%G92U496%M.B!I
M,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*
M(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ
M7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)0;'5R
M86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3M<;B(*"B,Z
M(&9I;'1E<G,N<&AP.C$Y,`IM<V=I9"`B(&%N9"(*;7-G<W1R("(@=6YD(@H*
M(SH@9FEL=&5R<RYP:'`Z,3DP"FUS9VED("(@;W(B"FUS9W-T<B`B(&]D97(B
M"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,3<*;7-G
M:60@(D%C=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S<V5S.B(*;7-G<W1R
M(")!:W1I;VX@9OQR(&%U<V=E<V-H;&]S<V5N92!!9')E<W-E;CHB"@HC.B!T
M96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ,`IM<V=I9"`B06-T:79A
M=&4@4V-R:7!T(@IM<V=S='(@(E-K<FEP="!A:W1I=FEE<F5N(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-T
M:79A=&EN9R!T:&4@<V-R:7!T(&9O<B!<(B5S7"(@9F%I;&5D.B`H)60I("5S
M(@IM<V=S='(@(D%K=&EV:65R96X@9&5S(%-K<FEP=',@9OQR(%PB)7-<(B!F
M96AL9V5S8VAL86=E;CH@*"5D*2`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W-E='1I;F=S+FEN8SHV"FUS9VED(")!9&1I=&EO;F%L(%-E='1I;F=S(@IM
M<V=S='(@(EIU<^1T>FQI8VAE($5I;G-T96QL=6YG96XB"@HC.B!T96UP;&%T
M97,O<G5L92]H96%D97(N:6YC.C0T"FUS9VED(")!;&P@;V8@=&AE(&9O;&QO
M=VEN9R(*;7-G<W1R(")!;&QE(&1E<B!F;VQG96YD96XB"@HC.B!L:6(O87!I
M+G!H<#HU-`IM<V=I9"`B06QL;W<@4G5L97,B"FUS9W-T<B`B4F5G96QN(&5R
M;&%U8F5N(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,PIM<V=I
M9"`B06YS=V5R960B"FUS9W-T<B`B0F5A;G1W;W)T970B"@HC.B!T96UP;&%T
M97,O<G5L92]H96%D97(N:6YC.C0U"FUS9VED(")!;GD@;V8@=&AE(&9O;&QO
M=VEN9R(*;7-G<W1R(")%:6YE<B!D97(@9F]L9V5N9&5N(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHW"FUS9VED(")!<'!L>2!&:6QT97)S
M(@IM<V=S='(@(D9I;'1E<G)E9V5L;B!A;G=E;F1E;B(*"B,Z(&9I;'1E<G,N
M<&AP.C(Q.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T
M92!T:&ES(')U;&4_(@IM<V=S='(@(E-I;F0@4VEE('-I8VAE<BP@9&%S<R!3
M:64@9&EE<V4@4F5G96P@;/9S8VAE;B!M]F-H=&5N/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B075T;VUA=&EC86QL>2!U<&1A=&4@
M=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\B"FUS9W-T<B`B1&%S(%-K
M<FEP="!N86-H(&IE9&5R(,1N9&5R=6YG(&%U=&]M871I<V-H(&%K='5A;&ES
M:65R96X_(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HT-PIM<V=I9"`B
M0F-C(@IM<V=S='(@(D)C8R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-SD*;7-G
M:60@(D)E9VEN<R!W:71H(@IM<V=S='(@(D)E9VEN;G0@;6ET(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HQ,#8@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z("@E<RD@)7,B"FUS
M9W-T<B`B5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E;CH@*"5S*2`E<R(*"B,Z
M(&9I;'1E<G,N<&AP.C$T.2!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES
M="YI;F,Z-PHC.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C@W(&QI8B]";&]C
M:R]O=F5R=FEE=RYP:'`Z.3`*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R(")!
M=7-S8VAL=7-S;&ES=&4B"@HC.B!B;&%C:VQI<W0N<&AP.C$P-PIM<V=I9"`B
M0FQA8VML:7-T($5D:70B"FUS9W-T<B`B075S<V-H;'5S<VQI<W1E($)E87)B
M96ET96XB"@HC.B!B;&%C:VQI<W0N<&AP.C$W"FUS9VED(")";&%C:VQI<W0@
M:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I
M=F5R+B(*;7-G<W1R(")!=7-S8VAL=7-S;&ES=&5N('=E<F1E;B!V;VT@86MT
M=65L;&5N($9I;'1E<G1R96EB97(@;FEC:'0@=6YT97)S=/QT>G0N(@H*(SH@
M;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C`W(&QI8B]38W)I<'0O<VEE=F4N
M<&AP.C(T-`HC.B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HQ-S8*;7-G:60@
M(D)L86-K;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R(")!=7-G97-C:&QO<W-E
M;F4@061R97-S96XB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C@X"FUS
M9VED(")";V1Y(@IM<V=S='(@(E1E>'0B"@HC.B!F:6QT97)S+G!H<#HQ.#<@
M<G5L92YP:'`Z,C@Q"FUS9VED(")#87-E(%-E;G-I=&EV92(*;7-G<W1R(")'
M<F_?+2]+;&5I;G-C:')E:6)U;F<@8F5A8VAT96XB"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C0S"FUS9VED(")#8R(*;7-G<W1R(")#8R(*"B,Z('-P
M86TN<&AP.C,X(')U;&4N<&AP.C$R,B!W:&ET96QI<W0N<&AP.C,V(&9O<G=A
M<F0N<&AP.C,S('9A8V%T:6]N+G!H<#HT,0HC.B!B;&%C:VQI<W0N<&AP.C<S
M"FUS9VED(")#:&%N9V5S('-A=F5D+B(*;7-G<W1R("+$;F1E<G5N9V5N(&=E
M<W!E:6-H97)T+B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S4*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R(")697)B:6YD=6YG(&9E:&QG
M97-C:&QA9V5N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W-0IM<V=I9"`B0V]N
M=&%I;G,B"FUS9W-T<B`B16YT:.1L="(*"B,Z(&9I;'1E<G,N<&AP.C(S,"!F
M:6QT97)S+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2`E<R(*
M;7-G<W1R("(E<R!K;W!I97)E;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HX-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!O9B`E<R(*;7-G<W1R(")+;W!I
M92!V;VX@)7,B"@HC.B!L:6(O26YG;RYP:'`Z-C(*;7-G:60@(D-R96%T92!N
M97<@9F]L9&5R(@IM<V=S='(@(DYE=65N($]R9&YE<B!E<G-T96QL96XB"@HC
M.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HS,S8@;&EB+U-C<FEP="]M86EL
M9')O<"YP:'`Z,C@P"FUS9VED(")$25-!0DQ%1#H@(@IM<V=S='(@(D1%04M4
M259)15)4.B`B"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ
M-PIM<V=I9"`B1&5A8W1I=F%T92!38W)I<'0B"FUS9W-T<B`B4VMR:7!T(&1E
M86MT:79I97)E;B(*"B,Z(&9I;'1E<G,N<&AP.C(Q.2!F:6QT97)S+G!H<#HR
M,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(@IM<V=S='(@(B5S
M(&SV<V-H96XB"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C,P"FUS
M9VED(")$96QE=&4@0V]N9&ET:6]N(@IM<V=S='(@(D)E9&EN9W5N9R!L]G-C
M:&5N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,R,PIM<V=I9"`B1&5L971E(&UE
M<W-A9V4@8V]M<&QE=&5L>2(*;7-G<W1R(").86-H<FEC:'0@:V]M<&QE='0@
M;/9S8VAE;B(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S4*;7-G
M:60@(D1E;&5T960B"FUS9W-T<B`B1V5L]G-C:'0B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S$Q"FUS9VED(")$96QI=F5R(&EN=&\@;7D@26YB;W@B"FUS9W-T
M<B`B26X@;65I;F5N(%!O<W1E:6YG86YG(&%U<VQI969E<FXB"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z,S,W"FUS9VED(")$96QI=F5R(&EN=&\@;7D@26YB;W@@
M86YD(&-O<'D@=&\B"FUS9W-T<B`B26X@;65I;F5N(%!O<W1E:6YG86YG(&%U
M<VQI969E<FX@=6YD(&MO<&EE<F5N(&YA8V@B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S,R"FUS9VED(")$96QI=F5R(&EN=&\@;7D@26YB;W@@86YD(')E9&ER
M96-T('1O(@IM<V=S='(@(DEN(&UE:6YE;B!0;W-T96EN9V%N9R!A=7-L:65F
M97)N('5N9"!W96ET97)L96ET96X@;F%C:"(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS,3<*;7-G:60@(D1E;&EV97(@=&\@9F]L9&5R(@IM<V=S='(@(DEN(&1I
M97-E;B!/<F1N97(@875S;&EE9F5R;CHB"@HC.B!F:6QT97)S+G!H<#HR-#,@
M9FEL=&5R<RYP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(D1I<V%B;&4@
M)7,B"FUS9W-T<B`B)7,@9&5A:W1I=FEE<F5N(@H*(SH@=&5M<&QA=&5S+W=H
M:71E;&ES="]W:&ET96QI<W0N:6YC.C$P('1E;7!L871E<R]B;&%C:VQI<W0O
M8FQA8VML:7-T+FEN8SHQ,`HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C8@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHR-@IM<V=I9"`B1&ES86)L960B
M"FUS9W-T<B`B1&5A:W1I=FEE<G0B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S
M971T:6YG<RYI;F,Z,3,*;7-G:60@(D1I<W!L87D@9&5T86EL960@;F]T:69I
M8V%T:6]N('=H96X@96%C:"!F:6QT97(@:7,@87!P;&EE9#\B"FUS9W-T<B`B
M(@HB1&5T86EL:65R=&4@0F5N86-H<FEC:'1I9W5N9R!A;GIE:6=E;B!B96D@
M:F5D96T@1FEL=&5R+"!D97(@86YG97=E;F1E="!W=7)D93\B"@HC.B!T96UP
M;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C,T"FUS9VED(")$;R!?;F]T
M('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES="!M97-S86=E<R(*;7-G
M<W1R("(B"B)?2V5I;F4@06YT=V]R=&5N(&%U9B!.86-H<FEC:'1E;B!V;VX@
M36%I;&EN9VQI<W1E;B!O9&5R($UA<W-E;F5M86EL<R`B"B)V97)S8VAI8VME
M;B(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,3`*;7-G:60@(D1O
M('1H:7,Z(@IM<V=S='(@(D1I97-E<R!T=6XZ(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,X,`IM<V=I9"`B1&]E<VXG="!B96=I;B!W:71H(@IM<V=S='(@(D)E
M9VEN;G0@;FEC:'0@;6ET(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W-@IM<V=I
M9"`B1&]E<VXG="!C;VYT86EN(@IM<V=S='(@(D5N=&CD;'0@;FEC:'0B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S@R"FUS9VED(")$;V5S;B=T(&5N9"!W:71H
M(@IM<V=S='(@(D5N9&5T(&YI8VAT(&UI="(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS.#0*;7-G:60@(D1O97-N)W0@97AI<W0B"FUS9W-T<B`B17AI<W1I97)T
M(&YI8VAT(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X-PIM<V=I9"`B1&]E<VXG
M="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S='(@(D5N='-P<FEC
M:'0@;FEC:'0@*&UI="!0;&%T>FAA;'1E<FXI(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O:&5A9&5R+FEN8SHR-B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C8Q
M"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C@@;&EB+T)L;V-K+V]V97)V
M:65W+G!H<#HX,0HC.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C@Y"FUS9VED
M(")%9&ET(@IM<V=S='(@(D)E87)B96ET96XB"@HC.B!F:6QT97)S+G!H<#HR
M,#@@9FEL=&5R<RYP:'`Z,C$P(&9I;'1E<G,N<&AP.C(Q-"!F:6QT97)S+G!H
M<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R("(E
M<R!"96%R8F5I=&5N(@H*(SH@9FEL=&5R<RYP:'`Z,C0W(&9I;'1E<G,N<&AP
M.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%;F%B;&4@)7,B"FUS9W-T<B`B
M)7,@86MT:79I97)E;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI
M;F,Z,C@*;7-G:60@(D5N86)L960B"FUS9W-T<B`B06MT:79I97)T(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,X,0IM<V=I9"`B16YD<R!W:71H(@IM<V=S='(@
M(D5N9&5T(&UI="(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.3(*;7-G:60@(D5Q
M=6%L('1O(@IM<V=S='(@(D=L96EC:"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,3,Y(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30Y(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,34X"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,38X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@8W5R<F5N="!S8W)I<'0Z
M("@E9"D@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@3&5S96X@9&5S(&%K='5E
M;&QE;B!3:W)I<'1S.B`H)60I("5S(@H*(SH@8FQA8VML:7-T+G!H<#HW,0IM
M<V=I9"`B17)R;W(@<V%V:6YG(&-H86YG97,N(@IM<V=S='(@(D9E:&QE<B!B
M96EM(%-P96EC:&5R;B!D97(@Q&YD97)U;F=E;BXB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]H96%D97(N:6YC.C(R"FUS9VED(")%>&ES=&EN9R!2=6QE<R(*
M;7-G<W1R(")"97-T96AE;F1E(%)E9V5L;B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS.#,*;7-G:60@(D5X:7-T<R(*;7-G<W1R(")%>&ES=&EE<G0B"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M>'!E8W1E9"`Q(&]B:F5C="P@9V]T("5D+B(*;7-G<W1R("(Q($]B:F5K="!E
M<G=A<G1E="P@)60@97)H86QT96XN(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<V5T=&EN9W,N:6YC.C(P"FUS9VED(")&:6QT97(@06QL($UE<W-A9V5S(@IM
M<V=S='(@(D%L;&4@3F%C:')I8VAT96X@9FEL=&5R;B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,@IM<V=I9"`B1FEL=&5R($]N;'D@
M4V5E;B!-97-S86=E<R(*;7-G<W1R(").=7(@9V5L97-E;F4@3F%C:')I8VAT
M96X@9FEL=&5R;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN
M8SHR,0IM<V=I9"`B1FEL=&5R($]N;'D@56YS965N($UE<W-A9V5S(@IM<V=S
M='(@(DYU<B!U;F=E;&5S96YE($YA8VAR:6-H=&5N(&9I;'1E<FXB"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,3@*;7-G:60@(D9I;'1E
M<B!/<'1I;VYS(@IM<V=S='(@(D9I;'1E<F5I;G-T96QL=6YG96XB"@HC.B!T
M96UP;&%T97,O<G5L92]H96%D97(N:6YC.C(U"FUS9VED(")&:6QT97(@4G5L
M92(*;7-G<W1R(")&:6QT97)R96=E;"(*"B,Z(&9I;'1E<G,N<&AP.C$Q,PIM
M<V=I9"`B1FEL=&5R(%)U;&5S(@IM<V=S='(@(D9I;'1E<G)E9V5L;B(*"B,Z
M('-C<FEP="YP:'`Z-3(*;7-G:60@(D9I;'1E<B!38W)I<'0@1&ES<&QA>2(*
M;7-G<W1R(")&:6QT97)S:W)I<'0M06YZ96EG92(*"B,Z(&QI8B]);F=O+G!H
M<#HS,C(*;7-G:60@(D9I;'1E<B!?4G5L97,B"FUS9W-T<B`B7T9I;'1E<G)E
M9V5L;B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E
M(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")&
M:6QT97)A:W1I=FETY'0Z("5S($YA8VAR:6-H="AE;BD@=W5R9&5N('IU;2!/
M<F1N97(@7"(E<UPB(&MO<&EE<G0N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H
M<#HS,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E
M<R!M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")&:6QT
M97)A:W1I=FETY'0Z("5S($YA8VAR:6-H="AE;BD@=W5R9&5N(&=E;/9S8VAT
M+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E
M96X@;6]V960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D9I;'1E
M<F%K=&EV:73D=#H@)7,@3F%C:')I8VAT*&5N*2!W=7)D96X@>G5M($]R9&YE
M<B!<(B5S7"(@=F5R<V-H;V)E;BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP
M.C$X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S
M(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@=V5R92!D
M96QE=&5D+B(*;7-G<W1R("(B"B)&:6QT97)A:W1I=FETY'0Z("5S($YA8VAR
M:6-H="AE;BDL(&1I92!D97(@075S<V-H;'5S<VQI<W1E(&5N='-P<F%C:&5N
M+"`B"B)W=7)D96X@9V5L]G-C:'0N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H
M<#HS,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB1FEL=&5R(&%C=&EV:71Y
M.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@8V]P
M:65D('1O('1H92`B"B)F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"B)&:6QT
M97)A:W1I=FETY'0Z($1I92!.86-H<FEC:'0@7"(E<UPB('9O;B!<(B5S7"(@
M=W5R9&4@>G5M($]R9&YE<B!<(B5S7"(@(@HB:V]P:65R="XB"@HC.B!L:6(O
M4V-R:7!T+VEM87`N<&AP.C(Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT
M97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")&:6QT97)A:W1I=FETY'0Z($1I
M92!.86-H<FEC:'0@7"(E<UPB('9O;B!<(B5S7"(@=W5R9&4@9V5L]G-C:'0N
M(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@
M9G)O;2!<(B5S7"(@:&%S(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B`B"B)<
M(B5S7"(N(@IM<V=S='(@(B(*(D9I;'1E<F%K=&EV:73D=#H@1&EE($YA8VAR
M:6-H="!<(B5S7"(@=F]N(%PB)7-<(B!W=7)D92!Z=6T@3W)D;F5R(%PB)7-<
M(B`B"B)V97)S8VAO8F5N+B(*"B,Z(')U;&4N<&AP.C$V,`IM<V=I9"`B1FEL
M=&5R(&YO="!F;W5N9"XB"FUS9W-T<B`B1FEL=&5R<F5G96P@;FEC:'0@9V5F
M=6YD96XN(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHT,@IM<V=I
M9"`B1F]R(&%N(&EN8V]M:6YG(&UE<W-A9V4@=&AA="!M871C:&5S.B(*;7-G
M<W1R(")&_'(@96EN9V5H96YD92!.86-H<FEC:'1E;BP@875F(&1I92!F;VQG
M96YD92!296=E;&X@>G5T<F5F9F5N.B(*"B,Z(&9I;'1E<G,N<&AP.C$V-R!T
M96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHX(&QI8B]";&]C:R]O=F5R
M=FEE=RYP:'`Z-C<*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV.0IM<V=I
M9"`B1F]R=V%R9"(*;7-G<W1R(")796ET97)L96ET=6YG(@H*(SH@9F]R=V%R
M9"YP:'`Z,38*;7-G:60@(D9O<G=A<F0@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")796ET97)L
M96ET=6YG96X@=V5R9&5N('9O;2!A:W1U96QL96X@1FEL=&5R=')E:6)E<B!N
M:6-H="!U;G1E<G-T_'1Z="XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H
M<#HR.#(@;&EB+U-C<FEP="]S:65V92YP:'`Z,C$T"B,Z(&QI8B]38W)I<'0O
M;6%I;&1R;W`N<&AP.C(R-0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5V5I
M=&5R;&5I='5N9R(*"B,Z(&9O<G=A<F0N<&AP.C0U"FUS9VED(")&;W)W87)D
M<R!%9&ET(@IM<V=S='(@(E=E:71E<FQE:71U;F<@0F5A<F)E:71E;B(*"B,Z
M(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,SD*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B5F]N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V,@IM<V=I9"`B
M1G)O;3HB"FUS9W-T<B`B5F]N.B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP
M.C$Q,`IM<V=I9"`B1V5N97)A=&5D(&)Y($EN9V\@*&AT='`Z+R]W=W<N:&]R
M9&4N;W)G+VEN9V\O*2(*;7-G<W1R(")%<GIE=6=T('9O;B!);F=O("AH='1P
M.B\O=W=W+FAO<F1E+F]R9R]I;F=O+RDB"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,SDP"FUS9VED(")'<F5A=&5R('1H86XB"FUS9W-T<B`B1W+VWV5R(&%L<R(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS.3$*;7-G:60@(D=R96%T97(@=&AA;B!O
M<B!E<75A;"!T;R(*;7-G<W1R(")'<O;?97(@86QS(&]D97(@9VQE:6-H(@H*
M(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,0IM<V=I9"`B26UP;W)T
M86YT(@IM<V=S='(@(E=I8VAT:6<B"@HC.B!R=6QE+G!H<#HS-@IM<V=I9"`B
M26YD:79I9'5A;"!R=6QE<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R
M<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R("(B"B));F1I=FED=65L
M;&4@4F5G96QN('=E<F1E;B!V;VT@86MT=65L;&5N($9I;'1E<G1R96EB97(@
M;FEC:'0@=6YT97)S=/QT>G0N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,3@V,`IM<V=I9"`B26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F;W(@
M;65S<V%G92!D96QI=F5R>2XB"FUS9W-T<B`B3FEC:'0@=F]R:&%N9&5N97(@
M3W)D;F5R(&;\<B!D:64@3F%C:')I8VAT96YA=7-L:65F97)U;F<@86YG96=E
M8F5N+B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-S<*;7-G:60@(DES(@IM<V=S
M='(@(DES="(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-S@*;7-G:60@(DES;B=T
M(@IM<V=S='(@(DES="!N:6-H="(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,C,*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@=&AE
M($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E9"XB
M"FUS9W-T<B`B(@HB3$1!4"U5;G1E<G-T_'1Z=6YG('=I<F0@8F5N]G1I9W0L
M(&%B97(@9&%S($Q$05`M36]D=6P@:7-T(&YI8VAT('9E<F;\9V)A<B`B"B)O
M9&5R('=U<F1E(&YI8VAT(&=E;&%D96XN(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,X.`IM<V=I9"`B3&5S<R!T:&%N(@IM<V=S='(@(DML96EN97(@86QS(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,X.0IM<V=I9"`B3&5S<R!T:&%N(&]R(&5Q
M=6%L('1O(@IM<V=S='(@(DML96EN97(@86QS(&]D97(@9VQE:6-H(@H*(SH@
M8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU.0IM<V=I9"`B3&ES="U)1"(*;7-G
M<W1R("),:7-T+4E$(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C(P"FUS9VED(")-87)?:R!M97-S86=E(&%S(&1E;&5T960B"FUS
M9W-T<B`B3F%C:')I8VAT(&%L<R!?9V5L]G-C:'0@;6%R:VEE<F5N(@H*(SH@
M=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHR-`IM<V=I9"`B36%R:R!M97-S
M86=E(&%S.B(*;7-G<W1R(").86-H<FEC:'0@;6%R:VEE<F5N(&%L<SHB"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S@V"FUS9VED(")-871C:&5S("AW:71H('!L
M86-E:&]L9&5R<RDB"FUS9W-T<B`B16YT<W!R:6-H="`H;6ET(%!L871Z:&%L
M=&5R;BDB"@HC.B!L:6(O87!I+G!H<#HU-PIM<V=I9"`B36%X:6UU;2!.=6UB
M97(@;V8@4G5L97,B"FUS9W-T<B`B36%X:6UA;&4@06YZ86AL(&%N(%)E9V5L
M;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@8FQA8VML:7-T960@861D<F5S<V5S
M(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S97,Z("5S+"`B"B)-87AI;75M(&%D
M9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O
M(&)L86-K;&ES="XB"FUS9W-T<B`B(@HB36%X:6UA;&4@06YZ86AL(&1E<B!A
M=7-G97-C:&QO<W-E;F5N($%D<F5S<V5N(/QB97)S8VAR:71T96X@*$%D<F5S
M<V5N("(*(FEN<V=E<V%M=#H@)7,L($UA>&EM86QE($%N>F%H;#H@)7,I+B!.
M975E($%D<F5S<V5N(&MO;FYT96X@;FEC:'0@>G5R("(*(D%U<W-C:&QU<W-L
M:7-T92!H:6YZ=6=E9OQG="!W97)D96XN(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C4V-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O
M9B!W:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E
M<W-E<SH@)7,L("(*(DUA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N
M;W0@861D(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+B(*;7-G<W1R("(B
M"B)-87AI;6%L92!!;GIA:&P@9&5R('!O<VET:79G96QI<W1E=&5N($%D<F5S
M<V5N(/QB97)S8VAR:71T96X@*$%D<F5S<V5N("(*(FEN<V=E<V%M=#H@)7,L
M($UA>&EM86QE($%N>F%H;#H@)7,I+B!.975E($%D<F5S<V5N(&MO;FYT96X@
M;FEC:'0@>G5R("(*(E!O<VET:79L:7-T92!H:6YZ=6=E9OQG="!W97)D96XN
M(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`W,`IM<V=I9"`B36ES<VEN
M9R!A9&1R97-S('1O(&YO=&EF>2(*;7-G<W1R(")"96YA8VAR:6-H=&EG=6YG
M<V%D<F5S<V4@9F5H;'0B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-S(X
M"FUS9VED(")-:7-S:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G92!T
M;R(*;7-G<W1R(")$:64@061R97-S92P@>G4@9&5R('=E:71E<F=E;&5I=&5T
M('=E<F1E;B!S;VQL+"!W=7)D92!N:6-H="!A;F=E9V5B96XB"@HC.B!L:6(O
M4V-R:7!T+W-I979E+G!H<#HQ-S8P"FUS9VED(")-:7-S:6YG(')E87-O;B!F
M;W(@<F5J96-T(@IM<V=S='(@(D1E<B!'<G5N9"!F_'(@06)L96AN=6YG('=U
M<F1E(&YI8VAT(&%N9V5G96)E;B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP
M.C$Y,C<*;7-G:60@(DUI<W-I;F<@<F5A<V]N(&EN('9A8V%T:6]N+B(*;7-G
M<W1R(")$97(@1W)U;F0@9OQR(&1I92!!8G=E<V5N:&5I='-N86-H<FEC:'0@
M=W5R9&4@;FEC:'0@86YG96=E8F5N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M:&5A9&5R+FEN8SHR.0IM<V=I9"`B36]V92(*;7-G<W1R(")697)S8VAI96)E
M;B(*"B,Z(&9I;'1E<G,N<&AP.C$S,2!F:6QT97)S+G!H<#HR-#`*;7-G:60@
M(DUO=F4@4G5L92!$;W=N(@IM<V=S='(@(E)E9V5L(&YA8V@@=6YT96X@=F5R
M<V-H:65B96XB"@HC.B!F:6QT97)S+G!H<#HQ,S(@9FEL=&5R<RYP:'`Z,C,Y
M"FUS9VED(")-;W9E(%)U;&4@57`B"FUS9W-T<B`B4F5G96P@;F%C:"!O8F5N
M('9E<G-C:&EE8F5N(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N
M+FEN8SHT,@IM<V=I9"`B3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C871I
M;VX@<F5P;&EE<SHB"FUS9W-T<B`B06YZ86AL(&1E<B!?5&%G92!Z=VES8VAE
M;B!D96X@06)W97-E;FAE:71S;F%C:')I8VAT96XZ(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O9FEL=&5R+6YO;F4N:6YC.C,@=&5M<&QA=&5S+V9I;'1E<G,O
M9F]O=&5R+FEN8SHU"B,Z(&QI8B]3=&]R86=E+G!H<#HW-S$*;7-G:60@(DYE
M=R!2=6QE(@IM<V=S='(@(DYE=64@4F5G96PB"@HC.B!L:6(O26YG;RYP:'`Z
M,C,U(&QI8B]);F=O+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M7"(E<UPB(&5L96UE;G0@9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")<(B5S7"(@:6X@9&5R($)A8VME;F1K;VYF:6=U<F%T:6]N
M(&YI8VAT(&%N9V5G96)E;BXB"@HC.B!L:6(O26YG;RYP:'`Z,C,S"FUS9VED
M(").;R!B86-K96YD(&-O;F9I9W5R960@9F]R('1H:7,@:&]S="(*;7-G<W1R
M(")+96EN92!"86-K96YD:V]N9FEG=7)A=&EO;B!F_'(@9&EE<V5N($AO<W0@
M86YG96=E8F5N(@H*(SH@;&EB+TEN9V\N<&AP.C(Q,`IM<V=I9"`B3F\@8F%C
M:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K96YD<RYP:'`B"FUS9W-T<B`B2V5I
M;F4@0F%C:V5N9',@:6X@8F%C:V5N9',N<&AP(&MO;F9I9W5R:65R="(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHS"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO(&9I;'1E<G,N($-L:6-K(%PB)7-<(B!T;R!C<F5A
M=&4@82!N97<@9FEL=&5R+B(*;7-G<W1R(")+96EN92!&:6QT97(N($ML:6-K
M96X@4VEE(&%U9B!<(B5S7"(L('5M(&YE=64@1FEL=&5R(&%N>G5L96=E;BXB
M"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ,S,R(&QI8B]38W)I<'0O<VEE
M=F4N<&AP.C$T,C4*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,34Y.0IM<V=I
M9"`B3F\@:&5A9&5R<R!S<&5C:69I960B"FUS9W-T<B`B2V5I;F4@16UA:6QK
M]G!F92!A;F=E9V5B96XB"@HC.B!S8W)I<'0N<&AP.C8W"FUS9VED(").;R!S
M8W)I<'0@9V5N97)A=&5D+B(*;7-G<W1R(")+96EN(%-K<FEP="!E<GIE=6=T
M+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$V,30*;7-G:60@(DYO('-T
M<FEN9W,@<W!E8VEF:65D(@IM<V=S='(@(DME:6YE(%1E>'1E(&%N9V5G96)E
M;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.3,*;7-G:60@(DYO="!E<75A;"!T
M;R(*;7-G<W1R(")5;F=L96EC:"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3,*
M;7-G:60@(DYO=&EF>2!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D1I97-E($5M
M86EL861D<F5S<V4@8F5N86-H<FEC:'1I9V5N(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,T-PIM<V=I9"`B3VYL>2!F;&%G('1H92!M97-S86=E(@IM<V=S='(@
M(DYA8VAR:6-H="!N=7(@;6%R:VEE<F5N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y"FUS9VED(")/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A=&EN
M9RXB"FUS9W-T<B`B16EN<W1E;&QU;F=E;B!Z=7(@4VMR:7!T+4%K='5A;&ES
M:65R=6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/
M=&AE<B!/<'1I;VYS(@IM<V=S='(@(D%N9&5R92!%:6YS=&5L;'5N9V5N(@H*
M(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HS"FUS9VED(")/=F5R=FEE=R(*
M;7-G<W1R("+<8F5R<VEC:'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]N
M97=?9F]L9&5R+FIS.C8*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O
M9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B0FET=&4@9V5B96X@4VEE(&1E
M;B!.86UE;B!F_'(@9&5N(&YE=65N($]R9&YE<B!A;CHB"@HC.B!T96UP;&%T
M97,O=F%C871I;VXO=F%C871I;VXN:6YC.C8P"FUS9VED(")27V5A<V]N(@IM
M<V=S='(@(E]'<G5N9"(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-C,*
M;7-G:60@(E)E8V5I=F5D(@IM<V=S='(@(D5M<&9A;F=E;B`H4F5C96EV960I
M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,R.`IM<V=I9"`B4F5D:7)E8W0@=&\B
M"FUS9W-T<B`B5V5I=&5R;&5I=&5N(&%N(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,X-0IM<V=I9"`B4F5G=6QA<B!E>'!R97-S:6]N(@IM<V=S='(@(E)E9W5L
MY')E<B!!=7-D<G5C:R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#,*;7-G:60@
M(E)E:F5C="!W:71H(')E87-O;B(*;7-G<W1R(")-:70@9F]L9V5N9&5M($=R
M=6YD(&%B;&5H;F5N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU-0IM
M<V=I9"`B4F5S96YT(%1O(@IM<V=S='(@(DYE=2!V97)S96YD970@86X@*%)E
M<V5N="!T;RDB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4Q"FUS9VED
M(")297-E;G0M9G)O;2(*;7-G<W1R(").974@=F5R<V5N9&5T('9O;B`H4F5S
M96YT+69R;VTI(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHV,`IM
M<V=I9"`B4F5T=7)N('1O($9I;'1E<G,@3&ES="(*;7-G<W1R("):=7+\8VL@
M>G5R($9I;'1E<FQI<W1E(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET
M96QI<W0N:6YC.C(T('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN
M8SHT,0HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C<Q('1E
M;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,T"FUS9VED(")2971U<FX@
M=&\@4G5L97,@3&ES="(*;7-G<W1R("):=7+\8VL@>G5R(%)E9V5L;&ES=&4B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(W"FUS9VED(")2
M=6QE(@IM<V=S='(@(E)E9V5L(@H*(SH@9FEL=&5R<RYP:'`Z-C,*;7-G:60@
M(E)U;&4@0V]P:65D(@IM<V=S='(@(E)E9V5L(&MO<&EE<G0B"@HC.B!F:6QT
M97)S+G!H<#HT,@IM<V=I9"`B4G5L92!$96QE=&5D(@IM<V=S='(@(E)E9V5L
M(&=E;/9S8VAT(@H*(SH@9FEL=&5R<RYP:'`Z-SD*;7-G:60@(E)U;&4@1&ES
M86)L960B"FUS9W-T<B`B4F5G96P@9&5A:W1I=FEE<G0B"@HC.B!F:6QT97)S
M+G!H<#HX-`IM<V=I9"`B4G5L92!%;F%B;&5D(@IM<V=S='(@(E)E9V5L(&%K
M=&EV:65R="(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,S,*;7-G
M:60@(E)U;&4@3F%M92(*;7-G<W1R(")296=E;&YA;64B"@HC.B!L:6(O4V-R
M:7!T+W-I979E+G!H<#HR,#8T"FUS9VED(")2=6QE.B(*;7-G<W1R(")296=E
M;#HB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C@X"B,L('!H<"UF;W)M870*
M;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")35$%2
M5%1,4R!F96AL9V5S8VAL86=E;CH@*"5S*2`E<R(*"B,Z('1E;7!L871E<R]W
M:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR,R!T96UP;&%T97,O8FQA8VML:7-T
M+V)L86-K;&ES="YI;F,Z-#`*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T
M:6]N+FEN8SHW,"!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHS,PHC
M.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C4Y"FUS9VED(")3879E(@IM
M<V=S='(@(E-P96EC:&5R;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I
M;F=S+FEN8SHR.0IM<V=I9"`B4V%V92!3971T:6YG<R(*;7-G<W1R(")%:6YS
M=&5L;'5N9V5N('-P96EC:&5R;B(*"B,Z('1E;7!L871E<R]S8W)I<'0O:&5A
M9&5R+FEN8SHR"FUS9VED(")38W)I<'0B"FUS9W-T<B`B4VMR:7!T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")38W)I<'0@57!D871I
M;F<B"FUS9W-T<B`B4VMR:7!T+4%K='5A;&ES:65R=6YG(@H*(SH@;&EB+TEN
M9V\N<&AP.C$X-@IM<V=I9"`B4V-R:7!T(&YO="!U<&1A=&5D+B(*;7-G<W1R
M(")3:W)I<'0@;FEC:'0@86MT=6%L:7-I97)T+B(*"B,Z(&QI8B]);F=O+G!H
M<#HQ-#$*;7-G:60@(E-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D+B(*
M;7-G<W1R(")3:W)I<'0@97)F;VQG<F5I8V@@86MT:79I97)T+B(*"B,Z(&QI
M8B]);F=O+G!H<#HQ-#`*;7-G:60@(E-C<FEP="!S=6-C97-S9G5L;'D@9&5A
M8W1I=F%T960N(@IM<V=S='(@(E-K<FEP="!E<F9O;&=R96EC:"!A:W1I=FEE
M<G0N(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHR.0IM<V=I9"`B
M4V5E;B(*;7-G<W1R(")'96QE<V5N(@H*(SH@<G5L92YP:'`Z,3DP"FUS9VED
M(")396QE8W0@82!F:65L9"(*;7-G<W1R(")7Y&AL96X@4VEE(&5I;B!&96QD
M(&%U<R(*"B,Z(&QI8B]);F=O+G!H<#HU.0IM<V=I9"`B4V5L96-T('1A<F=E
M="!F;VQD97(B"FUS9W-T<B`B6FEE;&]R9&YE<B!A=7-WY&AL96XB"@HC.B!R
M=6QE+G!H<#HR,C<*;7-G:60@(E-E;&8M1&5F:6YE9"!(96%D97(B"FUS9W-T
M<B`B0F5N=71Z97)D969I;FEE<G1E($MO<&9E:6YT<N1G92(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z,S4*;7-G:60@(E-E;F1E<B(*;7-G<W1R(")!
M8G-E;F1E<B`H4V5N9&5R*2(*"B,Z(&9I;'1E<G,N<&AP.CDX"FUS9VED(")3
M971T:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B1&EE($5I
M;G-T96QL=6YG96X@=W5R9&5N(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+B(*
M"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C(T"FUS9VED(")3
M:&]W($%C=&EV92!38W)I<'0B"FUS9W-T<B`B06MT:79E<R!3:W)I<'0@86YZ
M96EG96XB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHS,0IM
M<V=I9"`B4VAO=R!#=7)R96YT(%-C<FEP="(*;7-G<W1R(")!:W1U96QL97,@
M4VMR:7!T(&%N>F5I9V5N(@H*(SH@<W!A;2YP:'`Z,34*;7-G:60@(E-I;7!L
M92!S<&%M(&9I;'1E<FEN9R!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R
M96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(B(*(E9E<F5I;F9A8VAT
M92!3<&%M9FEL=&5R('=E<F1E;B!V;VT@86MT=65L;&5N($9I;'1E<G1R96EB
M97(@;FEC:'0@=6YT97)S=/QT>G0N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HX,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")'<O;?92(*"B,Z('-P86TN
M<&AP.C4Y"FUS9VED(")3<&%M($9I;'1E<FEN9R(*;7-G<W1R(")3<&%M9FEL
M=&5R(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHT.0IM<V=I9"`B
M4W1O<"!C:&5C:VEN9R!I9B!T:&ES(')U;&4@;6%T8VAE<S\B"FUS9W-T<B`B
M5V5I=&5R92#<8F5R<'+\9G5N9R!A;FAA;'1E;BP@=V5N;B!D:65S92!296=E
M;"!Z=71R:69F=#\B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN
M:6YC.C4Q"FUS9VED(")3=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E.B(*
M;7-G<W1R(")"971R95]F9B!D97(@06)W97-E;FAE:71S;F%C:')I8VAT.B(*
M"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S$*;7-G:60@(E-U8FIE8W0B
M"FUS9W-T<B`B0F5T<F5F9B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(P
M-C,*;7-G:60@(E-U8FIE8W0Z(@IM<V=S='(@(D)E=')E9F8Z(@H*(SH@;&EB
M+V%P:2YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@
M7"(E<UPB(&AA<R!B965N(&%D9&5D('1O('EO=7(@8FQA8VML:7-T+B(*;7-G
M<W1R(")$:64@061R97-S92!<(B5S7"(@=W5R9&4@>G4@26AR97(@075S<V-H
M;'5S<VQI<W1E(&AI;GIU9V5F_&=T+B(*"B,Z(&QI8B]A<&DN<&AP.C$P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!<(B5S7"(@:&%S(&)E
M96X@861D960@=&\@>6]U<B!W:&ET96QI<W0N(@IM<V=S='(@(D1I92!!9')E
M<W-E(%PB)7-<(B!W=7)D92!Z=2!):')E<B!0;W-I=&EV;&ES=&4@:&EN>G5G
M96;\9W0N(@H*(SH@;&EB+TEN9V\N<&AP.C$S-@IM<V=I9"`B5&AE(&1R:79E
M<B!S86ED.B`B"FUS9W-T<B`B06YT=V]R="!D97,@5')E:6)E<G,Z("(*"B,Z
M(&QI8B]);F=O+G!H<#HQ,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A
M8W1I=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@(D)E:6T@06MT:79I97)E
M;B!D97,@4VMR:7!T<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BXB"@HC
M.B!L:6(O26YG;RYP:'`Z,3,T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@(D)E:6T@1&5A:W1I
M=FEE<F5N(&1E<R!3:W)I<'1S(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N
M+B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,C<*;7-G:60@(E1O(@IM
M<V=S='(@(D%N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+FAT;6PZ
M,C$*;7-G:60@(E1O.B(*;7-G<W1R(")!;CHB"@HC.B!L:6(O4V-R:7!T+G!H
M<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(D1E<B`E<RU4<F5I8F5R(&MO
M;FYT92!N:6-H="!G96QA9&5N('=E<F1E;BXB"@HC.B!F:6QT97)S+G!H<#HQ
M-C$@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHU"B,Z(&QI8B]3
M8W)I<'0O<')O8VUA:6PN<&AP.C(V,B!L:6(O4V-R:7!T+W-I979E+G!H<#HS
M-3(*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV,"!L:6(O0FQO8VLO;W9E
M<G9I97<N<&AP.C8R"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")!8G=E<V5N
M:&5I="(*"B,Z('9A8V%T:6]N+G!H<#HW,0IM<V=I9"`B5F%C871I;VX@161I
M="(*;7-G<W1R(")!8G=E<V5N:&5I='-N86-H<FEC:'0@0F5A<F)E:71E;B(*
M"B,Z('9A8V%T:6]N+G!H<#HQ-@IM<V=I9"`B5F%C871I;VX@:7,@;F]T('-U
M<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G
M<W1R("(B"B)!8G=E<V5N:&5I='-N86-H<FEC:'1E;B!W97)D96X@=F]M(&%K
M='5E;&QE;B!&:6QT97)T<F5I8F5R(&YI8VAT('5N=&5R<W3\='IT+B(*"B,Z
M('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHQ-@IM<V=I9"`B
M5VA?:71E;&ES="!A9&1R97-S97,Z(@IM<V=S='(@(E!?;W-I=&EV9V5L:7-T
M971E($%D<F5S<V5N.B(*"B,Z(&9I;'1E<G,N<&AP.C$U-2!T96UP;&%T97,O
M=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z.`HC.B!L:6(O0FQO8VLO;W9E<G9I
M97<N<&AP.C<Y(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z.#(*;7-G:60@(E=H
M:71E;&ES="(*;7-G<W1R(")0;W-I=&EV;&ES=&4B"@HC.B!W:&ET96QI<W0N
M<&AP.C4U"FUS9VED(")7:&ET96QI<W0@161I="(*;7-G<W1R(")0;W-I=&EV
M;&ES=&4@0F5A<F)E:71E;B(*"B,Z('=H:71E;&ES="YP:'`Z,3@*;7-G:60@
M(E=H:71E;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I
M;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(E!O<VET:79L:7-T96X@=V5R9&5N
M('9O;2!A:W1U96QL96X@1FEL=&5R=')E:6)E<B!N:6-H="!U;G1E<G-T_'1Z
M="XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR,S0@;&EB+U-C<FEP
M="]S:65V92YP:'`Z,CDX"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(P
M,PIM<V=I9"`B5VAI=&5L:7-T960@061D<F5S<V5S(@IM<V=S='(@(E!O<VET
M:79G96QI<W1E=&4@061R97-S96XB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD
M:7-T.C<Y"FUS9VED(")8+5!R:6]R:71Y(@IM<V=S='(@(E@M4')I;W)I='DB
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C8W"FUS9VED(")8+5-P86TM
M3&5V96PB"FUS9W-T<B`B6"U3<&%M+4QE=F5L(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3<&%M+5-C;W)E(@IM<V=S='(@(E@M
M4W!A;2U38V]R92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-S4*;7-G
M:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T<B`B6"U3<&%M+5-T871U<R(*"B,Z
M(&9I;'1E<G,N<&AP.C4V(')U;&4N<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@<G5L97,N(@IM<V=S='(@(E-I92!D_')F96X@;FEC:'0@;65H<B!A;',@
M)60@4F5G96QN(&5R<W1E;&QE;BXB"@HC.B!F:6QT97)S+G!H<#HT."!R=6QE
M+G!H<#HR,0IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;W(@961I="!C=7-T;VT@<G5L97,N(@IM<V=S='(@(E-I92!D_')F96X@:V5I
M;F4@96EG96YE;B!296=E;&X@97)S=&5L;&5N(&]D97(@8F5A<F)E:71E;BXB
M"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HR,#8Q"FUS9VED(")9;W4@:&%V
M92!R96-E:79E9"!A(&YE=R!M97-S86=E(@IM<V=S='(@(E-I92!H86)E;B!E
M:6YE(&YE=64@3F%C:')I8VAT(&5R:&%L=&5N(@H*(SH@=F%C871I;VXN<&AP
M.C,P"FUS9VED("(B"B)9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!E
M;6%I;"!A9&1R97-S(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@;65S<V%G97,@
M(@HB<VAO=6QD(&)E(&%C=&EV871E9"XB"FUS9W-T<B`B(@HB4VEE(&W\<W-E
M;B!M:6YD97-T96YS(&5I;F4@16UA:6QA9')E<W-E(&%N9V5B96XL(&;\<B!D
M:64@06)W97-E;FAE:71S;F]T:7IE;B`B"B)A:W1I=FEE<G0@=V5R9&5N('-O
M;&QE;BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C(W-"!L:6(O4V-R:7!T
M+VEM87`N<&AP.C(Y-R!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q,0IM<V=I9"`B
M6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM+96EN($)E=')E9F9=(@H*(SH@=&5M
M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,C0*;7-G:60@(E]!9&1R97-S
M*&5S*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R(")!7V1R97-S92AN*2P@86X@
M9&EE('=E:71E<F=E;&5I=&5T('=E<F1E;B!S;VQL.B(*"B,Z('1E;7!L871E
M<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,C,*;7-G:60@(E]!9&1R97-S97,@
M=&\@;F]T('-E;F0@<F5S<&]N<V5S('1O.B(*;7-G<W1R(")!7V1R97-S92AN
M*2P@86X@9&EE(&ME:6YE($%N='=O<G0@9V5S8VAI8VMT('=E<F1E;B!S;VQL
M.B(*"B,Z(&QI8B]);F=O+G!H<#HS,C<*;7-G:60@(E]";&%C:VQI<W0B"FUS
M9W-T<B`B7T%U<W-C:&QU<W-L:7-T92(*"B,Z('1E;7!L871E<R]B;&%C:VQI
M<W0O8FQA8VML:7-T+FEN8SHQ.`IM<V=I9"`B7T1E;&5T92!M97-S86=E(&-O
M;7!L971E;'DB"FUS9W-T<B`B3F%C:')I8VAT(&MO;7!L971T(%]L]G-C:&5N
M(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C,Q"FUS
M9VED(")?16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z(@IM<V=S
M='(@(E]*961E($%D<F5S<V4@:6X@96EN97(@96EG96YE;B!:96EL92!E:6YT
M<F%G96XZ(@H*(SH@;&EB+TEN9V\N<&AP.C,S,PIM<V=I9"`B7T9O<G=A<F0B
M"FUS9W-T<B`B7U=E:71E<FQE:71U;F<B"@HC.B!T96UP;&%T97,O9F]R=V%R
M9"]F;W)W87)D+FEN8SHQ-PIM<V=I9"`B7TME97`@82!C;W!Y(&]F(&UE<W-A
M9V5S(&EN('1H:7,@86-C;W5N=#\B"FUS9W-T<B`B7TMO<&EE;B!D97(@3F%C
M:')I8VAT96X@:6X@9&EE<V5M($MO;G1O(&)E;&%S<V5N/R(*"B,Z('1E;7!L
M871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,@IM<V=I9"`B7TUO=F4@
M;65S<V%G92!T;R!F;VQD97(Z(@IM<V=S='(@(DYA8VAR:6-H="!I;B!D:65S
M96X@3W)D;F5R(%]V97)S8VAI96)E;CHB"@HC.B!T96UP;&%T97,O=F%C871I
M;VXO=F%C871I;VXN:6YC.C$S"FUS9VED(")?37D@96UA:6P@861D<F5S<V5S
M.B(*;7-G<W1R(")?365I;F4@16UA:6QA9')E<W-E;CHB"@HC.B!L:6(O26YG
M;RYP:'`Z,S,V"FUS9VED(")?4V-R:7!T(@IM<V=S='(@(E]3:W)I<'0B"@HC
M.B!L:6(O26YG;RYP:'`Z,S,P"FUS9VED(")?5F%C871I;VXB"FUS9W-T<B`B
M05]B=V5S96YH96ET(@H*(SH@;&EB+TEN9V\N<&AP.C,R-`IM<V=I9"`B7U=H
M:71E;&ES="(*;7-G<W1R(")?4&]S:71I=FQI<W1E(@H*(SH@;&EB+T)L;V-K
M+V]V97)V:65W+G!H<#HU-`IM<V=I9"`B86-T:79E(@IM<V=S='(@(F%K=&EV
M(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")A;F0B
M"FUS9W-T<B`B=6YD(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+FAT
M;6PZ,3,*;7-G:60@(F1I<V%B;&5D("T@8VQI8VL@=&\@96YA8FQE(@IM<V=S
M='(@(F1E86MT:79I97)T("T@>G5M($%K=&EV:65R96X@86YK;&EC:V5N(@H*
M(SH@9FEL=&5R<RYP:'`Z,3@U"FUS9VED(")F:65L9"(*;7-G<W1R(")&96QD
M(@H*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HU,@IM<V=I9"`B:6YA8W1I
M=F4B"FUS9W-T<B`B:6YA:W1I=B(*"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N
M<&AP.C$R,0IM<V=I9"`B;6%I;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B>2!)
M;F=O(@IM<V=S='(@(E9O;B!);F=O(&5R>F5U9W1E<R!M86EL9')O<"!38W)I
M<'0B"@HC.B!F:6QT97)S+G!H<#HQ.#4*;7-G:60@(FUA=&-H(@IM<V=S='(@
M(F5N='-P<FEC:'0B"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C0*
M;7-G:60@(F]R(@IM<V=S='(@(F]D97(B"@HC.B!L:6(O4V-R:7!T+W!R;V-M
M86EL+G!H<#HQ,C@*;7-G:60@(G!R;V-M86EL('-C<FEP="!G96YE<F%T960@
M8GD@26YG;R(*;7-G<W1R(")6;VX@26YG;R!E<GIE=6=T97,@<')O8VUA:6P@
M4V-R:7!T(@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+W!O+VYL7TY,+G!O````
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4Q-30T
M`#$P-#$W,S8R-S0W`#`Q-S,U,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C($1U=&-H('1R86YS;&%T:6]N<R!F;W(@26YG
M;R!P86-K86=E"B,@0V]P>7)I9VAT("A#*2`R,#`S.B!2=6)E;B!V86X@9&5R
M(%-T965N:&]V96XL(%=E8FUE97-T97)S"B,@4G5B96X@=F%N(&1E<B!3=&5E
M;FAO=F5N(#QI;F=O>&QA=&5`=V5B;65E<W1E<G,N;F5T/BP@,C`P,PHC($IA
M;B!+=6EP97)S(#QJ<FMU:7!E<G-`;&%U=V5R<V-O;&QE9V4N;FP^+"`R,#`T
M"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI
M8V5N<V4@87,@=&AE($EN9V\@<&%C:V%G92X*(PIM<V=I9"`B(@IM<V=S='(@
M(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@26YG;R`Q+C`M8W9S7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,2TR-R`R,3HS-RLP,3`P7&XB"B),87-T
M+51R86YS;&%T;W(Z($IA;B!+=6EP97)S(#QJ<FMU:7!E<G-`;&%U=V5R<V-O
M;&QE9V4N;FP^7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R
M86QS/3([('!L=7)A;#TH;B`A/2`Q*3M<;B(*"B,Z(&9I;'1E<G,N<&AP.C$X
M-0IM<V=I9"`B(&%N9"(*;7-G<W1R("(@96XB"@HC.B!F:6QT97)S+G!H<#HQ
M.#4*;7-G:60@(B!O<B(*;7-G<W1R("(@;V8B"@HC.B!T96UP;&%T97,O8FQA
M8VML:7-T+V)L86-K;&ES="YI;F,Z,3<*;7-G:60@(D%C=&EO;B!F;W(@8FQA
M8VML:7-T960@861D<F5S<V5S.B(*;7-G<W1R(")"97=E<FMI;F<@=F]O<B!Z
M=V%R=&4@;&EJ<W0@861R97-S96XZ(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A
M8W1I=F%T92YI;F,Z,3`*;7-G:60@(D%C=&EV871E(%-C<FEP="(*;7-G<W1R
M(")38W)I<'0@86-T:79E<F5N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-T:79A=&EN9R!T:&4@<V-R:7!T
M(&9O<B!<(B5S7"(@9F%I;&5D.B`H)60I("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHV"FUS9VED(")!9&1I=&EO
M;F%L(%-E='1I;F=S(@IM<V=S='(@(D5X=')A(&EN<W1E;&QI;F=E;B(*"B,Z
M('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#0*;7-G:60@(D%L;"!O9B!T
M:&4@9F]L;&]W:6YG(@IM<V=S='(@(DEE9&5R('9A;B!D92!V;VQG96YD92(*
M"B,Z(&QI8B]A<&DN<&AP.C4T"B,L(&9U>GIY"FUS9VED(")!;&QO=R!2=6QE
M<R(*;7-G<W1R(").:65U=V4@4F5G96PB"@HC.B!T96UP;&%T97,O<G5L92]F
M;V]T97(N:6YC.C,S"FUS9VED(")!;G-W97)E9"(*;7-G<W1R(")"96%N='=O
M;W)D(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHT-0IM<V=I9"`B
M06YY(&]F('1H92!F;VQL;W=I;F<B"FUS9W-T<B`B165N('9A;B!D92!V;VQG
M96YD92(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z,3$*;7-G
M:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B1FEL=&5R<R!T;V5P87-S96XB
M"@HC.B!F:6QT97)S+G!H<#HR,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/R(*;7-G<W1R(")7965T('4@>F5K
M97(@9&%T('4@9&5Z92!R96=E;"!W:6QT('9E<G=I:F1E<F5N/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B075T;VUA=&EC86QL>2!U
M<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\B"FUS9W-T<B`B
M2&5T('-C<FEP="!N82!I961E<F4@=F5R86YD97)I;F<@875T;VUA=&ES8V@@
M8FEJ=V5R:V5N/R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-#<*;7-G
M:60@(D)C8R(*;7-G<W1R(")"8V,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0T
M"FUS9VED(")"96=I;G,@=VET:"(*;7-G<W1R(")"96=I;G0@;65T(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HQ,#8@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z("@E<RD@)7,B
M"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z,30T('1E;7!L871E<R]B;&%C
M:VQI<W0O8FQA8VML:7-T+FEN8SHW"FUS9VED(")";&%C:VQI<W0B"FUS9W-T
M<B`B6G=A<G1E(&QI:G-T(@H*(SH@8FQA8VML:7-T+G!H<#HQ,#`*;7-G:60@
M(D)L86-K;&ES="!%9&ET(@IM<V=S='(@(EIW87)T92!L:6IS="!B97=E<FME
M;B(*"B,Z(&)L86-K;&ES="YP:'`Z,3<*;7-G:60@(D)L86-K;&ES="!I<R!N
M;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N
M(@IM<V=S='(@(B(*(EIW87)T92!L:6IS="!W;W)D="!N:65T(&]N9&5R<W1E
M=6YD(&EN(&AE="!H=6ED:6=E(&9I;'1E<G-T=75R<')O9W)A;6UA+B(*"B,Z
M(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(P-R!L:6(O4V-R:7!T+VUA:6QD
M<F]P+G!H<#HQ-S4*;7-G:60@(D)L86-K;&ES=&5D($%D9')E<W,B"FUS9W-T
M<B`B6G=A<G1E(&QI:G-T(&%D<F5S(@H*(SH@;&EB+U-C<FEP="]S:65V92YP
M:'`Z,C0S"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B
M6G=A<G1E(&QI:G-T(&%D<F5S<V5N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HX.`IM<V=I9"`B0F]D>2(*;7-G<W1R(")";V1Y(@H*(SH@9FEL=&5R
M<RYP:'`Z,3@R(')U;&4N<&AP.C(X,0IM<V=I9"`B0V%S92!396YS:71I=F4B
M"FUS9W-T<B`B2&]O9F1L971T97)G979O96QI9R(*"B,Z(&-O;F9I9R]F:65L
M9',N<&AP+F1I<W0Z-#,*;7-G:60@(D-C(@IM<V=S='(@(D-C(@H*(SH@<G5L
M92YP:'`Z,3(R('=H:71E;&ES="YP:'`Z,S8@9F]R=V%R9"YP:'`Z,S,@=F%C
M871I;VXN<&AP.C0Q"B,Z(&)L86-K;&ES="YP:'`Z-CD*;7-G:60@(D-H86YG
M97,@<V%V960N(@IM<V=S='(@(E9E<F%N9&5R:6YG96X@;W!G97-L86=E;B(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S4*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0P"FUS
M9VED(")#;VYT86EN<R(*;7-G<W1R(")"979A="(*"B,Z(&9I;'1E<G,N<&AP
M.C(R-2!F:6QT97)S+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P
M>2`E<R(*;7-G<W1R("(E<R!K;W!IZW)E;B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HW-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!O9B`E<R(*;7-G<W1R
M(")+;W!I92!V86X@)7,B"@HC.B!L:6(O26YG;RYP:'`Z-3(*;7-G:60@(D-R
M96%T92!N97<@9F]L9&5R(@IM<V=S='(@(DYI975W92!M87`@;6%K96XB"@HC
M.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HS,S8@;&EB+U-C<FEP="]M86EL
M9')O<"YP:'`Z,C<Y"FUS9VED(")$25-!0DQ%1#H@(@IM<V=S='(@(E5I=&=E
M<V-H86ME;&0Z("(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC
M.C$W"FUS9VED(")$96%C=&EV871E(%-C<FEP="(*;7-G<W1R(")38W)I<'0@
M9&5A8W1I=F5R96XB"@HC.B!F:6QT97)S+G!H<#HR,30@9FEL=&5R<RYP:'`Z
M,C$U"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R(")6
M97)W:6ID97(@)7,B"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C,P
M"FUS9VED(")$96QE=&4@0V]N9&ET:6]N(@IM<V=S='(@(E9O;W)W86%R9&4@
M=F]O<B!V97)W:6ID97)E;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.3(*;7-G
M:60@(D1E;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`B0F5R:6-H
M="!V;VQL961I9R!W:7-S96XB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N
M:6YC.C,U"FUS9VED(")$96QE=&5D(@IM<V=S='(@(E9E<G=I:F1E<F0B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,C@P"FUS9VED(")$96QI=F5R(&EN=&\@;7D@
M24Y"3U@B"FUS9W-T<B`B1&ET(&)E<FEC:'0@:6X@;6EJ;B!)3D)/6"!A9FQE
M=F5R96XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S`V"FUS9VED(")$96QI=F5R
M(&EN=&\@;7D@24Y"3U@@86YD(&-O<'D@=&\B"FUS9W-T<B`B069L979E<F5N
M(&EN(&UI:FX@24Y"3U@@96X@:V]P:>MR96X@;F%A<B(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS,#$*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@
M<F5D:7)E8W0@=&\B"FUS9W-T<B`B069L979E<F5N(&EN(&UI:FX@24Y"3U@@
M96X@=F5R9&5R<W1U<F5N(&YA87(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,C@V
M"FUS9VED(")$96QI=F5R('1O(&9O;&1E<B(*;7-G<W1R(")!9FQE=F5R96X@
M:6X@;6%P(@H*(SH@9FEL=&5R<RYP:'`Z,C0Q(&9I;'1E<G,N<&AP.C(T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$:7-A8FQE("5S(@IM<V=S='(@(B5S('5I
M='-C:&%K96QE;B(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T
M+FEN8SHQ,"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHV('1E;7!L871E
M<R]F;W)W87)D+V9O<G=A<F0N:6YC.C$P"B,Z('1E;7!L871E<R]R=6QE+VAE
M861E<BYI;F,Z,C8*;7-G:60@(D1I<V%B;&5D(@IM<V=S='(@(E5I=&=E<V-H
M86ME;&0B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,3,*
M;7-G:60@(D1I<W!L87D@9&5T86EL960@;F]T:69I8V%T:6]N('=H96X@96%C
M:"!F:6QT97(@:7,@87!P;&EE9#\B"FUS9W-T<B`B5V5E<F=E=F5N('9A;B!B
M97)I8VAT('=A;FYE97(@9FEL=&5R<R!Z:6IN('1O96=E<&%S=#\B"@HC.B!T
M96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C,T"FUS9VED(")$;R!?
M;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES="!M97-S86=E<R(*
M;7-G<W1R(")?1V5E;B!A;G1W;V]R9&5N('9E<G-T=7)E;B!O<"!B97)I8VAT
M96X@9&EE(&UA:6QI;F=L:7-T+6AE861E<G,@:&5B8F5N(@H*(SH@=&5M<&QA
M=&5S+W)U;&4O9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@=&AI<SHB"FUS9W-T
M<B`B1&]E(&1I=#HB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0U"FUS9VED(")$
M;V5S;B=T(&)E9VEN('=I=&@B"FUS9W-T<B`B0F5G:6YT(&YI970@;65T(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,T,0IM<V=I9"`B1&]E<VXG="!C;VYT86EN
M(@IM<V=S='(@(D)E=F%T(&YI970B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0W
M"FUS9VED(")$;V5S;B=T(&5N9"!W:71H(@IM<V=S='(@(D5I;F1I9W0@;FEE
M="!M970B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0Y"FUS9VED(")$;V5S;B=T
M(&5X:7-T(@IM<V=S='(@(D)E<W1A870@;FEE="(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS-3(*;7-G:60@(D1O97-N)W0@;6%T8V@@*'=I=&@@<&QA8V5H;VQD
M97)S*2(*;7-G<W1R(")+;VUT(&YI970@;W9E<F5E;B`H;65T('!L86-E:&]L
M9&5R<RDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C,Q"FUS
M9VED(")%9&ET(@IM<V=S='(@(D)E=V5R:V5N(@H*(SH@9FEL=&5R<RYP:'`Z
M,C`S(&9I;'1E<G,N<&AP.C(P-2!F:6QT97)S+G!H<#HR,#D@9FEL=&5R<RYP
M:'`Z,C$P"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@)7,B"FUS9W-T<B`B
M)7,@8F5W97)K96XB"@HC.B!F:6QT97)S+G!H<#HR-#4@9FEL=&5R<RYP:'`Z
M,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D5N86)L92`E<R(*;7-G<W1R(")!
M8W1I=F5E<B`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z
M,S<*;7-G:60@(D5N86)L960B"FUS9W-T<B`B1V5A8W1I=F5E<F0B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S0V"FUS9VED(")%;F1S('=I=&@B"FUS9W-T<B`B
M16EN9&EG="!M970B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4W"FUS9VED(")%
M<75A;"!T;R(*;7-G<W1R(")'96QI:FL@86%N(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HQ,SD@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#D@;&EB+T1R:79E
M<B]L9&%P+G!H<#HQ-3@*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5T<FEE=FEN9R!C=7)R96YT('-C
M<FEP=#H@*"5D*2`E<R(*;7-G<W1R("(B"@HC.B!B;&%C:VQI<W0N<&AP.C8W
M"FUS9VED(")%<G)O<B!S879I;F<@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR,@IM<V=I9"`B17AI<W1I
M;F<@4G5L97,B"FUS9W-T<B`B0F5S=&%A;F1E(')E9V5L<R(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS-#@*;7-G:60@(D5X:7-T<R(*;7-G<W1R(")"97-T86%T
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17AP96-T960@,2!O8FIE8W0L(&=O="`E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(P"FUS9VED(")&
M:6QT97(@06QL($UE<W-A9V5S(@IM<V=S='(@(D9I;'1E<B!A;&QE(&)E<FEC
M:'1E;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,@IM
M<V=I9"`B1FEL=&5R($]N;'D@4V5E;B!-97-S86=E<R(*;7-G<W1R(")&:6QT
M97(@86QL965N(&=E;W!E;F1E(&)E<FEC:'1E;B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W-E='1I;F=S+FEN8SHR,0IM<V=I9"`B1FEL=&5R($]N;'D@56YS
M965N($UE<W-A9V5S(@IM<V=S='(@(D9I;'1E<B!A;&QE96X@;VYG96]P96YD
M92!B97)I8VAT96XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI
M;F,Z,3@*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S='(@(D9I;'1E<F]P
M=&EE<R(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,C4*;7-G:60@
M(D9I;'1E<B!2=6QE(@IM<V=S='(@(D9I;'1E<G)E9V5L(@H*(SH@9FEL=&5R
M<RYP:'`Z,3`Y"FUS9VED(")&:6QT97(@4G5L97,B"FUS9W-T<B`B1FEL=&5R
M<F5G96QS(@H*(SH@<V-R:7!T+G!H<#HU,@IM<V=I9"`B1FEL=&5R(%-C<FEP
M="!$:7-P;&%Y(@IM<V=S='(@(D9I;'1E<G-C<FEP='=E97)G879E(@H*(SH@
M;&EB+TEN9V\N<&AP.C,P,`IM<V=I9"`B1FEL=&5R(%]2=6QE<R(*;7-G<W1R
M(")&:6QT97)?<F5G96QS(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S
M86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(D9I;'1E<F)E=V5R:VEN9SH@)7,@8F5R:6-H="AE;BD@>FEJ
M;B!G96MO<&EE97)D(&YA87(@;6%P(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T
M+VEM87`N<&AP.C,P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&1E;&5T960N(@IM<V=S
M='(@(D9I;'1E<F)E=V5R:VEN9SH@)7,@8F5R:6-H="AE;BD@>FEJ;B!V97)W
M:6ID97)D+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C@S"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H
M879E(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(D9I;'1E<F)E=V5R:VEN9SH@)7,@8F5R:6-H="AE;BD@>FEJ;B!V97)P;&%A
M='-T(&YA87(@;6%P(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP
M.C$X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S
M(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@=V5R92!D
M96QE=&5D+B(*;7-G<W1R("(B"B)&:6QT97)B97=E<FMI;F<Z("5S(&)E<FEC
M:'0H96XI+"!D:64@;W`@9&4@>G=A<G1E(&QI:G-T('-T;VYD96XL('II:FX@
M(@HB=F5R=VEJ9&5R9"XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I960@=&\@
M=&AE("(*(F9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*(D9I;'1E<F)E=V5R
M:VEN9SH@2&5T(&)E<FEC:'0@7"(E<UPB('9A;B!<(B5S7"(@:7,@;F%A<B!D
M92!M87`@7"(E<UPB("(*(F=E:V]P:65E<F0N(@H*(SH@;&EB+U-C<FEP="]I
M;6%P+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV
M:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B1FEL=&5R8F5W97)K:6YG.B!(970@8F5R:6-H
M="!<(B5S7"(@=F%N(%PB)7-<(B!I<R!V97)W:6ID97)D+B(*"B,Z(&QI8B]3
M8W)I<'0O:6UA<"YP:'`Z,C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D9I
M;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB
M(&AA<R!B965N(&UO=F5D('1O('1H92!F;VQD97(@(@HB7"(E<UPB+B(*;7-G
M<W1R("(B"B)&:6QT97)B97=E<FMI;F<Z($AE="!B97)I8VAT(%PB)7-<(B!V
M86X@7"(E<UPB(&ES(&YA87(@9&4@;6%P(%PB)7-<(B`B"B)V97)P;&%A='-T
M+B(*"B,Z(')U;&4N<&AP.C$V,`IM<V=I9"`B1FEL=&5R(&YO="!F;W5N9"XB
M"FUS9W-T<B`B1FEL=&5R(&YI970@9V5V;VYD96XN(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O:&5A9&5R+FEN8SHT,@IM<V=I9"`B1F]R(&%N(&EN8V]M:6YG(&UE
M<W-A9V4@=&AA="!M871C:&5S.B(*;7-G<W1R(")6;V]R(&5E;B!I;FMO;65N
M9"!B97)I8VAT96X@9&%T('9O;&1O970@86%N.B(*"B,Z(&9I;'1E<G,N<&AP
M.C$V,B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHX"FUS9VED(")&
M;W)W87)D(@IM<V=S='(@(D1O;W)S='5R96XB"@HC.B!F;W)W87)D+G!H<#HQ
M-@IM<V=I9"`B1F]R=V%R9"!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R
M96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(D1O;W)S='5R96X@=V]R
M9'0@;FEE="!O;F1E<G-T975N9"!I;B!H970@:'5I9&EG92!F:6QT97)S='5U
M<G!R;V=R86UM82XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR.#(@
M;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,C(T"FUS9VED(")&;W)W87)D<R(*
M;7-G<W1R(")$;V]R<W1U<F5N(@H*(SH@9F]R=V%R9"YP:'`Z-#8*;7-G:60@
M(D9O<G=A<F1S($5D:70B"FUS9W-T<B`B1&]O<G-T=7)E;B!B97=E<FME;B(*
M"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,SD*;7-G:60@(D9R;VTB"FUS
M9W-T<B`B5F%N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-0IM<V=I9"`B1W)E
M871E<B!T:&%N(@IM<V=S='(@(D=R;W1E<B!D86XB"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S4V"FUS9VED(")'<F5A=&5R('1H86X@;W(@97%U86P@=&\B"FUS
M9W-T<B`B1W)O=&5R(&1A;B!O9B!G96QI:FL@86%N(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O9F]O=&5R+FEN8SHS,0IM<V=I9"`B26UP;W)T86YT(@IM<V=S='(@
M(D)E;&%N9W)I:FLB"@HC.B!R=6QE+G!H<#HS-@IM<V=I9"`B26YD:79I9'5A
M;"!R=6QE<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT
M97)I;F<@9')I=F5R+B(*;7-G<W1R("(B"B));F1I=FED=65L92!R96=E;',@
M=V]R9&5N(&YI970@;VYD97)S=&5U;F0@:6X@:&5T(&AU:61I9V4@(@HB9FEL
M=&5R<W1U=7)P<F]G<F%M;6$N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,3@U-0IM<V=I9"`B26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F;W(@
M;65S<V%G92!D96QI=F5R>2XB"FUS9W-T<B`B3FEE="!B97-T86%N9&4@;6%I
M;&)O>"!O<&=E9V5V96X@=F]O<B!B97)I8VAT869L979E<FEN9RXB"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S0R"FUS9VED("))<R(*;7-G<W1R("))<R(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS-#,*;7-G:60@(DES;B=T(@IM<V=S='(@(DES
M(&YI970B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(S"FUS9VED("(B"B),
M1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I
M<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS-3,*;7-G:60@(DQE<W,@=&AA;B(*;7-G<W1R
M(")-:6YD97(@9&%N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-`IM<V=I9"`B
M3&5S<R!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(DUI;F1E<B!D86X@;V8@
M9V5L:6IK(&%A;B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-3D*;7-G
M:60@(DQI<W0M240B"FUS9W-T<B`B3&ES="U)1"(*"B,Z('1E;7!L871E<R]B
M;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,`IM<V=I9"`B36%R7VL@;65S<V%G
M92!A<R!D96QE=&5D(@IM<V=S='(@(D)E<FEC:'0@86QS(&=E=VES="!M87)?
M:V5R96XB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C(T"FUS9VED
M(")-87)K(&UE<W-A9V4@87,Z(@IM<V=S='(@(D)E<FEC:'0@;6%R:V5R96X@
M86QS.B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3$*;7-G:60@(DUA=&-H97,@
M*'=I=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R(")+;VUT(&]V97)E96X@*&UE
M="!P;&%C96AO;&1E<G,I(@H*(SH@;&EB+V%P:2YP:'`Z-3<*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F(%)U;&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X:6UU;2!N
M=6UB97(@;V8@8FQA8VML:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A
M;"!A9&1R97-S97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@
M0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O(&)L86-K;&ES="XB"FUS
M9W-T<B`B(@HB36%X:6UU;2!A86YT86P@>G=A<G1E(&QI:G-T(&%D<F5S<V5N
M(&]V97)S8VAR961E;B`H5&]T86%L(&%A;G1A;"!A9')E<W-E;CH@)2(*(G,L
M(&UA>&EM=6T@86%N=&%L(&%D<F5S<V5N.B`E<RDN($MO;B!G965N(&YI975W
M92!A9')E<W-E;B!A86X@9&4@>G=A<G1E("(*(FQI:G-T('1O979O96=E;BXB
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z-3,Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(DUA>&EM=6T@;G5M8F5R(&]F('=H:71E;&ES=&5D(&%D9')E<W-E<R!E
M>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R
M97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!W
M:&ET96QI<W0N(@IM<V=S='(@(B(*(DUA>&EM=6T@86%N=&%L('=I='1E(&QI
M:G-T(&%D<F5S<V5N(&]V97)S8VAR961E;B`H5&]T86%L(&%A;G1A;"!A9')E
M<W-E;CH@)2(*(G,L(&UA>&EM=6T@86%N=&%L(&%D<F5S<V5N.B`E<RDN($MO
M;B!G965N(&YI975W92!A9')E<W-E;B!A86X@9&4@=VET=&4@;&EJ<W0@(@HB
M=&]E=F]E9V5N+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W,C,*;7-G
M:60@(DUI<W-I;F<@861D<F5S<R!T;R!R961I<F5C="!M97-S86=E('1O(@IM
M<V=S='(@(DAE="!A9')E<RP@=V%A<B!D:70@8F5R:6-H="!H965N(&UO970@
M=V]R9&5N(&1O;W)G97IO;F1E;BP@;VYT8G)E96MT(@H*(SH@;&EB+U-C<FEP
M="]S:65V92YP:'`Z,3<U-0IM<V=I9"`B36ES<VEN9R!R96%S;VX@9F]R(')E
M:F5C="(*;7-G<W1R(")$92!R961E;B!V;V]R(&%F=VEJ>FEN9R!O;G1B<F5E
M:W0B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ.3(R"FUS9VED(")-:7-S
M:6YG(')E87-O;B!I;B!V86-A=&EO;BXB"FUS9W-T<B`B1&4@<F5D96X@=F]O
M<B!H970@869W97II9VAE:61B97)I8VAT('=E<F0@;FEE="!O<&=E9V5V96XB
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C0P"FUS9VED(")-
M;W9E(@IM<V=S='(@(E9E<G!L86%T<V5N(@H*(SH@9FEL=&5R<RYP:'`Z,3(V
M(&9I;'1E<G,N<&AP.C(S.`IM<V=I9"`B36]V92!2=6QE($1O=VXB"FUS9W-T
M<B`B4F5G96P@;F%A<B!B96YE9&5N('9E<G-C:'5I=F5N(@H*(SH@9FEL=&5R
M<RYP:'`Z,3(W(&9I;'1E<G,N<&AP.C(S-PIM<V=I9"`B36]V92!2=6QE(%5P
M(@IM<V=S='(@(E)E9V5L(&YA87(@8F]V96X@=F5R<V-H=6EV96XB"@HC.B!T
M96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C0R"FUS9VED(").7W5M
M8F5R(&]F(&1A>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S.B(*;7-G<W1R
M(")?06%N=&%L(&1A9V5N('1U<W-E;B!A9G=E>FEG:&5I9'-A;G1W;V]R9&5N
M.B(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHT('1E
M;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z.`HC.B!L:6(O4W1O<F%G92YP
M:'`Z-S$T"FUS9VED(").97<@4G5L92(*;7-G<W1R(").:65U=V4@4F5G96PB
M"@HC.B!L:6(O26YG;RYP:'`Z,3DT(&QI8B]);F=O+G!H<#HQ.38*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DYO(%PB)7-<(B!E;&5M96YT(&9O=6YD
M(&EN(&)A8VME;F0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)R5S)R!I;B!D
M92!B86-K96YD8V]N9FEG=7)A=&EE(&YI970@;W!G96=E=F5N+B(*"B,Z(&QI
M8B]);F=O+G!H<#HQ.3(*;7-G:60@(DYO(&)A8VME;F0@8V]N9FEG=7)E9"!F
M;W(@=&AI<R!H;W-T(@IM<V=S='(@(D=E96X@0F%C:V5N9&-O;F9I9W5R871I
M92!V;V]R(&1E>F4@2&]S="!O<&=E9V5V96XB"@HC.B!L:6(O26YG;RYP:'`Z
M,38Y"FUS9VED(").;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S
M+G!H<"(*;7-G<W1R(")'965N(&)A8VME;F1S(&=E8V]N9FEG=7)E97)D(&EN
M(&)A8VME;F1S+G!H<"(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN
M;VYE+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!F:6QT
M97)S+B!#;&EC:R!<(B5S7"(@=&\@8W)E871E(&$@;F5W(&9I;'1E<BXB"FUS
M9W-T<B`B1V5E;B!F:6QT97)S+B!+;&EK(&]P("<E<R<L(&]M(&5E;B!N:65U
M=R!F:6QT97(@=&4@;6%K96XN(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,3,R-R!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-#(P"B,Z(&QI8B]38W)I<'0O
M<VEE=F4N<&AP.C$U.30*;7-G:60@(DYO(&AE861E<G,@<W!E8VEF:65D(@IM
M<V=S='(@(D=E96X@:&5A9&5R<R!O<&=E9V5V96XB"@HC.B!S8W)I<'0N<&AP
M.C8W"FUS9VED(").;R!S8W)I<'0@9V5N97)A=&5D+B(*;7-G<W1R(")38W)I
M<'0@;FEE="!G96UA86MT+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$V
M,#D*;7-G:60@(DYO('-T<FEN9W,@<W!E8VEF:65D(@IM<V=S='(@(D=E96X@
M=&5K<W0@;W!G96=E=F5N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U.`IM<V=I
M9"`B3F]T(&5Q=6%L('1O(@IM<V=S='(@(DYI970@9V5L:6IK(&%A;B(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS,38*;7-G:60@(D]N;'D@9FQA9R!T:&4@;65S
M<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3D*
M;7-G:60@(D]P=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+B(*;7-G<W1R
M(")/<'1I97,@;6)T('-C<FEP=',@8FEJ=V5R:V5N+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R
M(")!;F1E<F4@;W!T:65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;F5W
M7V9O;&1E<BYJ<SHV"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@
M=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(D=E968@9&4@;F%A;2!V86X@9&4@
M;FEE=7=E(&UA<"P@82YU+F(N.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V
M86-A=&EO;BYI;F,Z-C`*;7-G:60@(E)?96%S;VXB"FUS9W-T<B`B<E]E9&5N
M(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HV,PIM<V=I9"`B4F5C96EV
M960B"FUS9W-T<B`B3VYT=F%N9V5N("A296-E:79E9"DB"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,CDW"FUS9VED(")2961I<F5C="!T;R(*;7-G<W1R(")697)D
M97(@<W1U<F5N(&YA87(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4P"FUS9VED
M(")296=U;&%R(&5X<')E<W-I;VXB"FUS9W-T<B`B4F5G=6QI97)E(&5X<')E
M<W-I92(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,3(*;7-G:60@(E)E:F5C="!W
M:71H(')E87-O;B(*;7-G<W1R(")!9G=I:GIE;B!M970@<F5D96XB"@HC.B!C
M;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4U"FUS9VED(")297-E;G0@5&\B"FUS
M9W-T<B`B3W!N:65U=R!V97)Z;VYD96X@86%N("A297-E;G0@=&\I(@H*(SH@
M8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU,0IM<V=I9"`B4F5S96YT+69R;VTB
M"FUS9W-T<B`B3W!N:65U=R!V97)Z;VYD96X@9&]O<B`H4F5S96YT+69R;VTI
M(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHV,`IM<V=I9"`B4F5T
M=7)N('1O($9I;'1E<G,@3&ES="(*;7-G<W1R(")497)U9R!N86%R(&9I;'1E
M<FQI:G-T(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC
M.C(T('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT,0HC.B!T
M96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C<Q('1E;7!L871E<R]F
M;W)W87)D+V9O<G=A<F0N:6YC.C,T"FUS9VED(")2971U<FX@=&\@4G5L97,@
M3&ES="(*;7-G<W1R(")497)U9R!N86%R(')E9V5L;&EJ<W0B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C,T"FUS9VED(")2=6QE(@IM<V=S
M='(@(E)E9V5L(@H*(SH@9FEL=&5R<RYP:'`Z-C`*;7-G:60@(E)U;&4@0V]P
M:65D(@IM<V=S='(@(E)E9V5L(&=E8V]P:65E<F0B"@HC.B!F:6QT97)S+G!H
M<#HS.0IM<V=I9"`B4G5L92!$96QE=&5D(@IM<V=S='(@(E)E9V5L(&=E=VES
M="(*"B,Z(&9I;'1E<G,N<&AP.C<V"FUS9VED(")2=6QE($1I<V%B;&5D(@IM
M<V=S='(@(E)E9V5L('5I=&=E<V-H86ME;&0B"@HC.B!F:6QT97)S+G!H<#HX
M,0IM<V=I9"`B4G5L92!%;F%B;&5D(@IM<V=S='(@(E)E9V5L(&EN9V5S8VAA
M:V5L9"(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,S,*;7-G:60@
M(E)U;&4@3F%M92(*;7-G<W1R(")296=E;&YA86TB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A
M:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=VAI=&5L
M:7-T+W=H:71E;&ES="YI;F,Z,C,@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C
M:VQI<W0N:6YC.C0P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI
M;F,Z-S`@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,S,*(SH@=&5M
M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHU.0IM<V=I9"`B4V%V92(*;7-G<W1R
M(")/<'-L86%N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC
M.C(Y"FUS9VED(")3879E(%-E='1I;F=S(@IM<V=S='(@(DEN<W1E;&QI;F=E
M;B!O<'-L86%N(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]H96%D97(N:6YC.C(*
M;7-G:60@(E-C<FEP="(*;7-G<W1R(")38W)I<'0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*;7-G<W1R
M(")38W)I<'0M8FEJ=V5R:V5N(@H*(SH@;&EB+TEN9V\N<&AP.C(Q-PIM<V=I
M9"`B4V-R:7!T(&YO="!U<&1A=&5D+B(*;7-G<W1R(")38W)I<'0@;FEE="!B
M:6IG97=E<FMT+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S`*;7-G:60@(E-C<FEP
M="!S=6-C97-S9G5L;'D@86-T:79A=&5D+B(*;7-G<W1R(")38W)I<'0@<W5C
M8V5S=F]L(&=E86-T:79E97)D+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,CD*;7-G
M:60@(E-C<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(E-C<FEP="!S=6-C97-V;VP@9V5D96%C=&EV965R9"XB"@HC.B!T96UP;&%T
M97,O<G5L92]F;V]T97(N:6YC.C(Y"FUS9VED(")3965N(@IM<V=S='(@(D=E
M>FEE;B(*"B,Z(')U;&4N<&AP.C$Y,`IM<V=I9"`B4V5L96-T(&$@9FEE;&0B
M"FUS9W-T<B`B4V5L96-T965R(&5E;B!V96QD(@H*(SH@;&EB+TEN9V\N<&AP
M.C0Y"FUS9VED(")396QE8W0@=&%R9V5T(&9O;&1E<B(*;7-G<W1R(")$;V5L
M;6%P('-E;&5C=&5R96XB"@HC.B!R=6QE+G!H<#HR,C<*;7-G:60@(E-E;&8M
M1&5F:6YE9"!(96%D97(B"FUS9W-T<B`B6F5L9B!G961E9FEN:65E<F1E(&AE
M861E<B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S4*;7-G:60@(E-E
M;F1E<B(*;7-G<W1R(")!9GIE;F1E<B`H4V5N9&5R*2(*"B,Z(&9I;'1E<G,N
M<&AP.CDU"FUS9VED(")3971T:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"XB
M"FUS9W-T<B`B26YS=&5L;&EN9V5N(&UE="!S=6-C97,@8FEJ9V5W97)K="XB
M"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHR-`IM<V=I9"`B
M4VAO=R!!8W1I=F4@4V-R:7!T(@IM<V=S='(@(D%C=&EE9B!S8W)I<'0@=V5E
M<F=E=F5N(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,S$*
M;7-G:60@(E-H;W<@0W5R<F5N="!38W)I<'0B"FUS9W-T<B`B2'5I9&EG('-C
M<FEP="!W965R9V5V96XB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C@S
M"FUS9VED(")3:7IE(@IM<V=S='(@(D=R;V]T=&4B"@HC.B!T96UP;&%T97,O
M<G5L92]F;V]T97(N:6YC.C0Y"FUS9VED(")3=&]P(&-H96-K:6YG(&EF('1H
M:7,@<G5L92!M871C:&5S/R(*;7-G<W1R(")'965N('9E<F1E<F4@8V]N=')O
M;&5S('5I='9O97)E;B!A;',@9&5Z92!R96=E;"!V86X@=&]E<&%S<VEN9R!I
M<S\B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C4Q"FUS
M9VED(")3=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E.B(*;7-G<W1R(")/
M;F1E<E]W97)P('9A;B!H970@=F%K86YT:65B97)I8VAT.B(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z,S$*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B
M3VYD97)W97)P(@H*(SH@;&EB+V%P:2YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%D9')E<W,@7"(E<UPB(&AA<R!B965N(&%D9&5D('1O('EO
M=7(@8FQA8VML:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@7"(E<UPB(&AA<R!B
M965N(&%D9&5D('1O('EO=7(@=VAI=&5L:7-T+B(*;7-G<W1R("(B"@HC.B!L
M:6(O26YG;RYP:'`Z,3(U"FUS9VED(")4:&4@9')I=F5R('-A:60Z("(*;7-G
M<W1R(")(970@<W1U=7)P<F]G<F%M;6$@;65L9'0Z("(*"B,Z(&QI8B]);F=O
M+G!H<#HQ,C0*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8W1I=F%T:6YG
M('1H92!S8W)I<'0N(@IM<V=S='(@(D5R('=A<R!E96X@9F]U="!B:6H@:&5T
M(&%C=&EV97)E;B!V86X@:&5T('-C<FEP="XB"@HC.B!L:6(O26YG;RYP:'`Z
M,3(S"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5A8W1I=F%T:6YG('1H
M92!S8W)I<'0N(@IM<V=S='(@(D5R('=A<R!E96X@9F]U="!B:6H@:&5T(&1E
M86-T:79E<F5N('9A;B!H970@<V-R:7!T+B(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z,C<*;7-G:60@(E1O(@IM<V=S='(@(D%A;B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+V9I;'1E<BYH=&UL.C(X"B,L(&9U>GIY"FUS9VED(")4
M;SHB"FUS9W-T<B`B06%N(@H*(SH@;&EB+U-C<FEP="YP:'`Z,3(W"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N
M(&]F("5S+B(*;7-G<W1R(").:65T(&EN('-T86%T(&]M(&1E(&1E9FEN:71I
M92!V86X@)7,@=&4@;&%D96XN(@H*(SH@9FEL=&5R<RYP:'`Z,34V('1E;7!L
M871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-0HC.B!L:6(O4V-R:7!T+W!R
M;V-M86EL+G!H<#HR-C(*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%F=V5Z
M:6=H96ED(@H*(SH@=F%C871I;VXN<&AP.C<R"FUS9VED(")686-A=&EO;B!%
M9&ET(@IM<V=S='(@(D%F=V5Z:6=H96ED(&)E=V5R:V5N(@H*(SH@;&EB+U-C
M<FEP="]S:65V92YP:'`Z,S4Q"FUS9VED(")686-A=&EO;B!-97-S86=E(@IM
M<V=S='(@(D%F=V5Z:6=H96ED<V)E<FEC:'0B"@HC.B!V86-A=&EO;BYP:'`Z
M,38*;7-G:60@(E9A8V%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U
M<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B5F%K86YT:64@=V]R
M9'0@;FEE="!O;F1E<G-T975N9"!I;B!H970@:'5I9&EG92!F:6QT97)S='5U
M<G!R;V=R86UM82XB"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES
M="YI;F,Z,38*;7-G:60@(E=H7VET96QI<W0@861D<F5S<V5S.B(*;7-G<W1R
M(")77VET=&4@;&EJ<W0@861R97-S96XB"@HC.B!F:6QT97)S+G!H<#HQ-3`@
M=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C@*;7-G:60@(E=H
M:71E;&ES="(*;7-G<W1R(")7:71T92!L:6IS="(*"B,Z('=H:71E;&ES="YP
M:'`Z-34*;7-G:60@(E=H:71E;&ES="!%9&ET(@IM<V=S='(@(E=I='1E(&QI
M:G-T(&)E=V5R:V5N(@H*(SH@=VAI=&5L:7-T+G!H<#HQ.`IM<V=I9"`B5VAI
M=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R
M:6YG(&1R:79E<BXB"FUS9W-T<B`B(@HB5VET=&4@;&EJ<W0@=V]R9'0@;FEE
M="!O;F1E<G-T975N9"!I;B!H970@:'5I9&EG92!F:6QT97)S='5U<G!R;V=R
M86UM82XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR,S0@;&EB+U-C
M<FEP="]S:65V92YP:'`Z,CDW"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP
M.C(P,@IM<V=I9"`B5VAI=&5L:7-T960@061D<F5S<V5S(@IM<V=S='(@(E=I
M='1E(&QI:G-T(&%D<F5S<V5N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES
M=#HW.0IM<V=I9"`B6"U0<FEO<FET>2(*;7-G<W1R(")8+5!R:6]R:71Y(@H*
M(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HV-PIM<V=I9"`B6"U3<&%M+4QE
M=F5L(@IM<V=S='(@(E@M4W!A;2U,979E;"(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z-S$*;7-G:60@(E@M4W!A;2U38V]R92(*;7-G<W1R(")8+5-P
M86TM4V-O<F4B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C<U"FUS9VED
M(")8+5-P86TM4W1A='5S(@IM<V=S='(@(E@M4W!A;2U3=&%T=7,B"@HC.B!F
M:6QT97)S+G!H<#HU,R!R=6QE+G!H<#HQ-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(')U;&5S+B(*;7-G<W1R("(B"@HC.B!F:6QT97)S+G!H<#HT-2!R=6QE+G!H
M<#HR,0IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;W(@
M961I="!C=7-T;VT@<G5L97,N(@IM<V=S='(@(B(*"B,Z('9A8V%T:6]N+G!H
M<#HS,`IM<V=I9"`B(@HB66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@
M96UA:6P@861D<F5S<R!F;W(@=VAI8V@@=&AE('9A8V%T:6]N(&UE<W-A9V5S
M("(*(G-H;W5L9"!B92!A8W1I=F%T960N(@IM<V=S='(@(B(*(E4@;6]E="!T
M96YM:6YS=&4@Z>EN($4M36%I;"!A9')E<R!O<&=E=F5N('=A87)V;V]R(&AE
M="!A9G=E>FEG:&5I9',@9FEL=&5R("(*(FUO970@=V]R9&5N(&=E86-T:79E
M97)D+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<X(&QI8B]38W)I<'0O
M:6UA<"YP:'`Z,S`Q(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$U"FUS9VED(");
M3F\@4W5B:F5C=%TB"FUS9W-T<B`B6T=E96X@;VYD97)W97)P72(*"B,Z('1E
M;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C(T"FUS9VED(")?061D<F5S
M<RAE<RD@=&\@9F]R=V%R9"!T;SHB"FUS9W-T<B`B7T%D<F5S<V5N('=A87)N
M86%R(&UO970@=V]R9&5N(&1O;W)G97-T=75R9#HB"@HC.B!T96UP;&%T97,O
M=F%C871I;VXO=F%C871I;VXN:6YC.C(S"FUS9VED(")?061D<F5S<V5S('1O
M(&YO="!S96YD(')E<W!O;G-E<R!T;SHB"FUS9W-T<B`B7T%D<F5S<V5N('=A
M87(@9V5E;B!A;G1W;V]R9"!N86%R(&=E<W1U=7)D(&UO970@=V]R9&5N.B(*
M"B,Z(&QI8B]);F=O+G!H<#HS,#4*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T
M<B`B6E]W87)T92!L:6IS="(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA
M8VML:7-T+FEN8SHQ.`IM<V=I9"`B7T1E;&5T92!M97-S86=E(&-O;7!L971E
M;'DB"FUS9W-T<B`B0F5R:6-H="!V;VQL961I9R!?=VES<V5N(@H*(SH@=&5M
M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C,Q"FUS9VED(")?16YT
M97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z(@IM<V=S='(@(E!L86%T
M<R!?:65D97(@861R97,@;W`@965N(&YI975W92!R96=E;"(*"B,Z(&QI8B])
M;F=O+G!H<#HS,3$*;7-G:60@(E]&;W)W87)D(@IM<V=S='(@(E]$;V]R<W1U
M<F5N(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3<*;7-G
M:60@(E]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_
M(@IM<V=S='(@(E]"97=A87(@965N(&MO<&EE('9A;B!B97)I8VAT96X@:6X@
M9&ET(&%C8V]U;G0_(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C(R"FUS9VED(")?36]V92!M97-S86=E('1O(&9O;&1E<CHB"FUS
M9W-T<B`B0F5R:6-H="!N86%R(&1E>F4@;6%P(%]V97)P;&%A='-E;CHB"@HC
M.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C$S"FUS9VED(")?
M37D@96UA:6P@861D<F5S<V5S.B(*;7-G<W1R(")?36EJ;B!E+6UA:6P@861R
M97-S96XZ(@H*(SH@;&EB+TEN9V\N<&AP.C,Q-`IM<V=I9"`B7U-C<FEP="(*
M;7-G<W1R(")?4V-R:7!T(@H*(SH@;&EB+TEN9V\N<&AP.C,P.`IM<V=I9"`B
M7U9A8V%T:6]N(@IM<V=S='(@(E]686MA;G1I92(*"B,Z(&QI8B]);F=O+G!H
M<#HS,#(*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B5VET=&4@;&E?:G-T
M(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")A;F0B
M"FUS9W-T<B`B96XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F:6QT97(N:'1M
M;#HQ-@IM<V=I9"`B9&ES86)L960@+2!C;&EC:R!T;R!E;F%B;&4B"FUS9W-T
M<B`B(@H*(SH@9FEL=&5R<RYP:'`Z,3@P"FUS9VED(")F:65L9"(*;7-G<W1R
M(")V96QD(@H*(SH@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,3(P"B,L(&9U
M>GIY"FUS9VED(")M86EL9')O<"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\B
M"FUS9W-T<B`B<')O8VUA:6QS8W)I<'0@9V5G96YE<F5E<F0@9&]O<B!);F=O
M(@H*(SH@9FEL=&5R<RYP:'`Z,3@P"FUS9VED(")M871C:"(*;7-G<W1R(")O
M=F5R965N:V]M96YD(&UE="(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI
M;F,Z-`IM<V=I9"`B;W(B"FUS9W-T<B`B;V8B"@HC.B!L:6(O4V-R:7!T+W!R
M;V-M86EL+G!H<#HQ,C@*;7-G:60@(G!R;V-M86EL('-C<FEP="!G96YE<F%T
M960@8GD@26YG;R(*;7-G<W1R(")P<F]C;6%I;'-C<FEP="!G96=E;F5R965R
M9"!D;V]R($EN9V\B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ,#D*;7-G
M:60@(G-I979E(&9I;'1E<B!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R(")3
M:65V92!F:6QT97(@9V5G96YE<F5E<F0@9&]O<B!);F=O(@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O<&\O
M9G)?1E(N<&\`````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-#8Q,S$`,3`T,3<S-C(W-#<`,#$W,S0Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@=')A;G-L871I;VX@;V8@
M9G)?1E(N<&\@=&\@1G)A;F-A:7,*(R!T<F%N<VQA=&EO;B!O9B!F<E]&4BYP
M;R!T;R!&<F%NYV%I<PHC($9R96YC:"!T<F%N<VQA=&EO;B!F;W(@26YG;PHC
M($-O<'ER:6=H="`H0RD@,C`P,R!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE
M(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE
M(&EN9V\@<&%C:V%G92X*(R!!241%($9L;W)E;G0@/&9A:61E0&%L<&AA8V5N
M="YC;VT^+"`R,#`S+@HC(%!I97)R92!,86-H86YC92`\<&Q`<&EE<G)E;&%C
M:&%N8V4N;F5T/B!E="!"96YO:70@4W0M06YD<ND@(#QB96Y`8F5N;VET<W0M
M86YD<F4N;F5T/BP@,C`P,RP@,C`P-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*
M(E!R;VIE8W0M260M5F5R<VEO;CH@9G)?1E)<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-"TQ,BTP-R`Q-3HP,BTP-3`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`T+3`S+3`W(#$U.C`S+3`U,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@0F5N;VET(%-T+4%N9')E(#QB96Y`8F5N;VET<W0M86YD<F4N;F5T/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@1G)A;F-A:7,@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)8+4=E;F5R871O<CH@2T)A8F5L
M(#$N,UQN(@H*(SH@9FEL=&5R<RYP:'`Z,38W"FUS9VED("(@86YD(@IM<V=S
M='(@(B!E="(*"B,Z(&9I;'1E<G,N<&AP.C$V-PIM<V=I9"`B(&]R(@IM<V=S
M='(@(B!O=2(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN
M8SHQ.0IM<V=I9"`B06-T:6]N(&9O<B!B;&%C:VQI<W1E9"!A9&1R97-S97,Z
M(@IM<V=S='(@(D%C=&EO;B!P;W5R(&QE<R!A9')E<W-E<R!E;B!L:7-T92!N
M;VER93HB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ,`IM
M<V=I9"`B06-T:79A=&4@4V-R:7!T(@IM<V=S='(@(D%C=&EV97(@8V4@<V-R
M:7!T("(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHY"FUS
M9VED(")!9&1I=&EO;F%L(%-E='1I;F=S(@IM<V=S='(@(D]P=&EO;G,@<W5P
M<&SI;65N=&%I<F5S(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHU
M,PIM<V=I9"`B06QL(&]F('1H92!F;VQL;W=I;F<B"FUS9W-T<B`B5&]U="!C
M92!Q=6D@<W5I="(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-#0*
M;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(E+I<&]N9'4B"@HC.B!T96UP;&%T
M97,O<G5L92]H96%D97(N:6YC.C4V"FUS9VED(")!;GD@;V8@=&AE(&9O;&QO
M=VEN9R(*;7-G<W1R(")!=2!M;VEN<R!L)W5N(&1E(&-E('%U:2!S=6ET(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHQ-@IM<V=I9"`B07!P
M;'D@1FEL=&5R<R(*;7-G<W1R(")!<'!L:7%U97(@;&5S(&9I;'1R97,B"@HC
M.B!F:6QT97)S+G!H<#HQ.38*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AI<R!R=6QE/R(*;7-G<W1R("+*=&5S+79O=7,@8V5R
M=&%I;B!D92!V;W5L;VER('-U<'!R:6UE<B!C971T92!RZ&=L9:`_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S"FUS9VED(")!=71O;6%T:6-A;&QY
M('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&5A8V@@8VAA;F=E/R(*;7-G<W1R
M(")-971T<F4@X"!J;W5R(&QE('-C<FEP="!A=71O;6%T:7%U96UE;G0@87!R
MZ',@8VAA<75E(&-H86YG96UE;G0_(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HT-PIM<V=I9"`B0F-C(@IM<V=S='(@(D-C:2(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-#8*;7-G:60@(D)E9VEN<R!W:71H(@IM<V=S='(@(D-O;6UE
M;F-E('!A<B(*"B,Z(&9I;'1E<G,N<&AP.C$R-B!T96UP;&%T97,O8FQA8VML
M:7-T+V)L86-K;&ES="YI;F,Z.`IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@
M(DQI<W1E($YO:7)E(@H*(SH@8FQA8VML:7-T+G!H<#HQ,#`*;7-G:60@(D)L
M86-K;&ES="!%9&ET(@IM<V=S='(@(LED:71E<B!L82!,:7-T92!.;VER92(*
M"B,Z(&)L86-K;&ES="YP:'`Z,3<*;7-G:60@(D)L86-K;&ES="!I<R!N;W0@
M<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM
M<V=S='(@(DQA(&QI<W1E(&YO:7)E(&XG97-T('!A<R!S=7!P;W)TZ2!D86YS
M(&QE(&9I;'1R92!A8W1U96PN(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP
M:'`Z,C`Y"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S(@IM<V=S='(@(D%D
M<F5S<V4@96X@;&ES=&4@3F]I<F4B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HR-#4*;7-G:60@(D)L86-K;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R(")!
M9')E<W-E<R!E;B!L:7-T92!.;VER92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP
M+F1I<W0Z.#@*;7-G:60@(D)O9'DB"FUS9W-T<B`B0V]R<',B"@HC.B!F:6QT
M97)S+G!H<#HQ-C0@<G5L92YP:'`Z,C,X"FUS9VED(")#87-E(%-E;G-I=&EV
M92(*;7-G<W1R(")496YI<B!C;VUP=&4@9&4@;&$@8V%S<V4B"@HC.B!C;VYF
M:6<O9FEE;&1S+G!H<"YD:7-T.C0S"FUS9VED(")#8R(*;7-G<W1R(")#8R(*
M"B,Z(&)L86-K;&ES="YP:'`Z-CD@9F]R=V%R9"YP:'`Z,S,@<G5L92YP:'`Z
M,3`U('9A8V%T:6]N+G!H<#HT,0HC.B!W:&ET96QI<W0N<&AP.C,V"FUS9VED
M(")#:&%N9V5S('-A=F5D+B(*;7-G<W1R(")#:&%N9V5M96YT<R!E;G)E9VES
M='+I<RXB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0R"FUS9VED(")#;VYT86EN
M<R(*;7-G<W1R(")#;VYT:65N="(*"B,Z(&9I;'1E<G,N<&AP.C(P-"!F:6QT
M97)S+G!H<#HR,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2`E<R(*;7-G
M<W1R(")#;W!I97(@)7,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z-S<X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O<'D@;V8@)7,B"FUS9W-T<B`B0V]P:64@9&4@
M)7,B"@HC.B!L:6(O26YG;RYP:'`Z-3,*;7-G:60@(D-R96%T92!N97<@9F]L
M9&5R(@IM<V=S='(@(D-RZ65R('5N(&YO=79E874@9&]S<VEE<B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+V9I;'1E<BYH=&UL.C$V"FUS9VED(")$25-!0DQ%
M1"(*;7-G<W1R(")$R5-!0U1)5LDB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL
M+G!H<#HS-30*;7-G:60@(D1)4T%"3$5$.B`B"FUS9W-T<B`B1,E304-425;)
M.B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$W"FUS9VED
M(")$96%C=&EV871E(%-C<FEP="(*;7-G<W1R(")$Z7-A8W1I=F5R(&-E('-C
M<FEP="(*"B,Z(&9I;'1E<G,N<&AP.C$Y-B!F:6QT97)S+G!H<#HQ.3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(@IM<V=S='(@(D5F9F%C97(@
M)7,B"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C(W"FUS9VED(")$
M96QE=&4@0V]N9&ET:6]N(@IM<V=S='(@(D5F9F%C92!L82!C;VYD:71I;VXB
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,CDX"FUS9VED(")$96QE=&4@;65S<V%G
M92!C;VUP;&5T96QY(@IM<V=S='(@(E-U<'!R:6UE<B!L92!M97-S86=E(&-O
M;7!LZ'1E;65N="(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-#<*
M;7-G:60@(D1E;&5T960B"FUS9W-T<B`B169F86/I(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C(X-@IM<V=I9"`B1&5L:79E<B!I;G1O(&UY($E.0D]8(@IM<V=S
M='(@(D3I<&]S97(@8V4@;65S<V%G92!D86YS(&UA(&)O:71E(&1E('+I8V5P
M=&EO;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,3(*;7-G:60@(D1E;&EV97(@
M:6YT;R!M>2!)3D)/6"!A;F0@8V]P>2!T;R(*;7-G<W1R(")$Z7!O<V5R(&1A
M;G,@;6$@0F]I=&4@9&4@<NEC97!T:6]N(&5T(&-O<&EE<B!D86YS(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,P-PIM<V=I9"`B1&5L:79E<B!I;G1O(&UY($E.
M0D]8(&%N9"!R961I<F5C="!T;R(*;7-G<W1R(")$Z7!O<V5R(&1A;G,@;6$@
M0F]I=&4@9&4@<NEC97!T:6]N(&5T(')E9&ER:6=E<B!V97)S(@H*(SH@;&EB
M+U-T;W)A9V4N<&AP.C(Y,@IM<V=I9"`B1&5L:79E<B!T;R!F;VQD97(B"FUS
M9W-T<B`B4&QA8V5R(&1A;G,@;&4@9&]S<VEE<B(*"B,Z(&9I;'1E<G,N<&AP
M.C(Q."!F:6QT97)S+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ES
M86)L92`E<R(*;7-G<W1R(")$Z7-A8W1I=F5R("5S("(*"B,Z('1E;7!L871E
M<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHY('1E;7!L871E<R]V86-A=&EO
M;B]V86-A=&EO;BYI;F,Z.0HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC
M.C,P('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.CD*(SH@=&5M<&QA
M=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C$P"FUS9VED(")$:7-A8FQE
M9"(*;7-G<W1R(")$Z7-A8W1I=NDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S
M971T:6YG<RYI;F,Z,C$*;7-G:60@(D1I<W!L87D@9&5T86EL960@;F]T:69I
M8V%T:6]N('=H96X@96%C:"!F:6QT97(@:7,@87!P;&EE9#\B"FUS9W-T<B`B
M069F:6-H97(@;&4@;65S<V%G92!A<'+H<R!L)V%P<&QI8V%T:6]N(&1E<R!F
M:6QT<F5SH#\@(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN
M8SHS.`IM<V=I9"`B1&\@7VYO="!S96YD(')E<W!O;G-E<R!T;R!B=6QK(&]R
M(&QI<W0@;65S<V%G97,B"FUS9W-T<B`B(@HB3F4@<&%S(&5N=F]Y97(@9&4@
M<NEP;VYS97,@875X(&UE<W-A9V5S('!R;W9E;F%N="!D92!L:7-T97,@;W4@
M9"=E;G9O:7,@(@HB;6%S<VEF<R(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E
M<BYI;F,Z,3`*;7-G:60@(D1O('1H:7,Z(@IM<V=S='(@(D9A:7)E(&-E8VDZ
M("(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#<*;7-G:60@(D1O97-N)W0@8F5G
M:6X@=VET:"(*;7-G<W1R(").92!C;VUM96YC92!P87,@<&%R("(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HS-#,*;7-G:60@(D1O97-N)W0@8V]N=&%I;B(*;7-G
M<W1R(").92!C;VYT:65N="!P87,@(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T
M.0IM<V=I9"`B1&]E<VXG="!E;F0@=VET:"(*;7-G<W1R(").92!F:6YI="!P
M87,@<&%R("(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3$*;7-G:60@(D1O97-N
M)W0@97AI<W0B"FUS9W-T<B`B3B=E>&ES=&4@<&%S("(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-30*;7-G:60@(D1O97-N)W0@;6%T8V@@*'=I=&@@<&QA8V5H
M;VQD97)S*2(*;7-G<W1R(").92!C;W)R97-P;VYD('!A<R(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C`*;7-G:60@(D5D:70B"FUS9W-T
M<B`B36]D:69I97(B"@HC.B!F:6QT97)S+G!H<#HQ.#4@9FEL=&5R<RYP:'`Z
M,3@W(&9I;'1E<G,N<&AP.C$Y,2!F:6QT97)S+G!H<#HQ.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R(")%9&ET97(@)7,B"@HC.B!F
M:6QT97)S+G!H<#HR,C(@9FEL=&5R<RYP:'`Z,C(S"B,L('!H<"UF;W)M870*
M;7-G:60@(D5N86)L92`E<R(*;7-G<W1R(")!8W1I=F5R("5S(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR,@IM<V=I9"`B16YA8FQE9"(*
M;7-G<W1R(")!8W1I=NDB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0X"FUS9VED
M(")%;F1S('=I=&@B"FUS9W-T<B`B($9I;FET('!A<B(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-3D*;7-G:60@(D5Q=6%L('1O(@IM<V=S='(@(LEG86P@X"(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z-PIM<V=I9"`B17AI
M<W1I;F<@4G5L97,B"FUS9W-T<B`B4NAG;&5S(&5X:7-T86YT97,B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S4P"FUS9VED(")%>&ES=',B"FUS9W-T<B`B17AI
M<W1E(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C,P"FUS
M9VED(")&:6QT97(@06QL($UE<W-A9V5S(@IM<V=S='(@(D9I;'1R97(@8VAA
M<75E(&UE<W-A9V4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI
M;F,Z,S(*;7-G:60@(D9I;'1E<B!/;FQY(%-E96X@365S<V%G97,B"FUS9W-T
M<B`B1FEL=')E<B!S975L96UE;G0@;&5S(&UE<W-A9V4@=G5S(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C,Q"FUS9VED(")&:6QT97(@
M3VYL>2!5;G-E96X@365S<V%G97,B"FUS9W-T<B`B1FEL=')E<B!S975L96UE
M;G0@;&5S(&UE<W-A9V5S(&YO;B!V=7,B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]S971T:6YG<RYI;F,Z,C@*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S
M='(@(D]P=&EO;G,@9&4@9FEL=')A9V4B"@HC.B!T96UP;&%T97,O<G5L92]H
M96%D97(N:6YC.C(X"FUS9VED(")&:6QT97(@4G5L92(*;7-G<W1R(")2Z&=L
M92!D92!F:6QT<F%G92(*"B,Z(&9I;'1E<G,N<&AP.CDR"FUS9VED(")&:6QT
M97(@4G5L97,B"FUS9W-T<B`B4NAG;&5S(&1E(&9I;'1R86=E(@H*(SH@<V-R
M:7!T+G!H<#HU,@IM<V=I9"`B1FEL=&5R(%-C<FEP="!$:7-P;&%Y(@IM<V=S
M='(@(D%F9FEC:&%G92!D=2!S8W)I<'0@9&4@9FEL=')E(@H*(SH@;&EB+TEN
M9V\N<&AP.C(V.0IM<V=I9"`B1FEL=&5R(%]2=6QE<R(*;7-G<W1R(")?4NAG
M;&5S(&1E(&9I;'1R86=E(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S
M86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(B(*(D%C=&EV:73I(&1U(&9I;'1R9:`Z("5S(&UE<W-A9V4H
M<RD@;VYT(.ETZ2!DZ7!L86/I<R!V97)S(&QE(&1O<W-I97(@JZ`E<Z"[+B(*
M"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S`X"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B06-T:79I=.D@9'4@9FEL=')EH#H@)7,@;65S
M<V%G92AS*2!O;G0@Z73I(&5F9F%CZ7,N(@H*(SH@;&EB+U-C<FEP="]I;6%P
M+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y
M.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`B(@HB06-T:79I=.D@9'4@9FEL=')EH#H@)7,@
M;65S<V%G92AS*2!O;G0@Z73I(&3I<&QA8^ES('9E<G,@;&4@9&]S<VEE<B"K
MH"5SH+LN(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HQ.#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I('1H
M870@;6%T8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@9&5L971E9"XB"FUS9W-T
M<B`B(@HB06-T:79I=.D@9'4@9FEL=')EH#H@)7,@;65S<V%G92AS*2!C;W)R
M97-P;VYD86YT(.`@;&$@;&ES=&4@;F]I<F4@;VYT(.ETZ2`B"B)E9F9A8^ES
M+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB
M(&9R;VT@7"(E<UPB(&AA<R!B965N(&-O<&EE9"!T;R!T:&4@(@HB9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`B(@HB06-T:79I=.D@9'4@9FEL=')EH#H@;&4@
M;65S<V%G92"KH"5SH+L@9&4@JZ`E<Z"[(&$@Z73I(&-O<&GI('9E<G,@;&4@
M9&]S<VEE<B`B"B*KH"5SH+LN("(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z
M,S`S"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@5&AE
M(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(D%C=&EV:73I(&1U(&9I;'1R9:`Z(&QE(&UE<W-A9V4@JZ`E
M<Z"[(&1E(*N@)7.@NR!A(.ETZ2!E9F9A8^DN("(*"B,Z(&QI8B]38W)I<'0O
M:6UA<"YP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D9I;'1E<B!A
M8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B
M965N(&UO=F5D('1O('1H92!F;VQD97(@(@HB7"(E<UPB+B(*;7-G<W1R("(B
M"B)!8W1I=FETZ2!D=2!F:6QT<F6@.B!L92!M97-S86=E(*N@)7.@NR!D92"K
MH"5SH+L@82#I=.D@9.EP;&%CZ2!V97)S(&QE("(*(F1O<W-I97(@JZ`E<Z"[
M+B`B"@HC.B!R=6QE+G!H<#HQ,S,*;7-G:60@(D9I;'1E<B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D9I;'1R92!N;VX@=')O=7;I(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O:&5A9&5R+FEN8SHT.`IM<V=I9"`B1F]R(&%N(&EN8V]M:6YG(&UE<W-A
M9V4@=&AA="!M871C:&5S.B(*;7-G<W1R(")0;W5R(&QE<R!M97-S86=E<R!E
M;G1R86YT<R!Q=6D@8V]R<F5S<&]N9&5N=#HB"@HC.B!F:6QT97)S+G!H<#HQ
M-#0@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z-PIM<V=I9"`B1F]R
M=V%R9"(*;7-G<W1R(")4<F%N<V9E<G0B"@HC.B!F;W)W87)D+G!H<#HQ-@IM
M<V=I9"`B1F]R=V%R9"!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT
M(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(DQA(')E9&ER96-T:6]N(&XG
M97-T('!A<R!S=7!P;W)TZ64@9&%N<R!L92!P<NES96YT(&9I;'1R92XB"@HC
M.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR.38*;7-G:60@(D9O<G=A<F1S
M(@IM<V=S='(@(E1R86YS;65T=')E(@H*(SH@9F]R=V%R9"YP:'`Z-#8*;7-G
M:60@(D9O<G=A<F1S($5D:70B"FUS9W-T<B`BR61I=&5R(&QA(')E9&ER96-T
M:6]N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HS.0IM<V=I9"`B1G)O
M;2(*;7-G<W1R(")$92(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3<*;7-G:60@
M(D=R96%T97(@=&AA;B(*;7-G<W1R(")0;'5S(&=R86YD('%U92`B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S4X"FUS9VED(")'<F5A=&5R('1H86X@;W(@97%U
M86P@=&\B"FUS9W-T<B`B4&QU<R!G<F%N9"!O=2#I9V%L92#@(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHT,0IM<V=I9"`B26UP;W)T86YT(@IM
M<V=S='(@(DEM<&]R=&%N="(*"B,Z(')U;&4N<&AP.C(V"FUS9VED("));F1I
M=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT
M(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(DQE<R!RZ&=L97,@:6YD:79I
M9'5E;&QE<R!N92!S;VYT('!A<R!S=7!P;W)TZ65S+B(*"B,Z(&QI8B]38W)I
M<'0O<VEE=F4N<&AP.C$W.#,*;7-G:60@(DEN97AI<W1A;G0@;6%I;&)O>"!S
M<&5C:69I960@9F]R(&UE<W-A9V4@9&5L:79E<GDN(@IM<V=S='(@(DQA(&)O
M[G1E('-PZ6-I9FGI92!E<W0@:6YE>&ES=&%N=&4B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S0T"FUS9VED("))<R(*;7-G<W1R(")%<W0B"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,S0U"FUS9VED("))<VXG="(*;7-G<W1R(").)V5S="!P87,B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4U"FUS9VED("),97-S('1H86XB"FUS
M9W-T<B`B4&QU<R!P971I="!Q=64B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4V
M"FUS9VED("),97-S('1H86X@;W(@97%U86P@=&\B"FUS9W-T<B`B4&QU<R!P
M971I="!O=2#I9V%L92#@(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU
M.0IM<V=I9"`B3&ES="U)1"(*;7-G<W1R("),:7-T+4E$(@H*(SH@=&5M<&QA
M=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(R"FUS9VED(")-87)?:R!M
M97-S86=E(&%S(&1E;&5T960B"FUS9W-T<B`B36%R7W%U97(@;&4@;65S<V%G
M92!C;VUM92!S=7!P<FEMZ2(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI
M;F,Z,S,*;7-G:60@(DUA<FL@;65S<V%G92!A<SHB"FUS9W-T<B`B36%R<75E
M<B!L92!M97-S86=E(&-O;6UE.B`@(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U
M,PIM<V=I9"`B36%T8VAE<R`H=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S='(@
M(D-O<G)E<W!O;F0B"@HC.B!L:6(O4W1O<F%G92YP:'`Z-#@V"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(DUA>&EM=6T@;G5M8F5R(&]F(&)L86-K;&ES=&5D
M(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@(@HB
M36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D
M9')E<W-E<R!T;R!B;&%C:VQI<W0N(@IM<V=S='(@(B(*(DYO;6)R92!M87AI
M;75M(&0G861R97-S97,@96X@;&ES=&4@;F]I<F4@9.EP87-SZ2`H3F]M8G)E
M('1O=&%L.B`E<RP@3F]M8G)E("(*(FUA>&EM=6T@9"=A9')E<W-E<SH@)7,I
M+B!);7!O<W-I8FQE(&0G86IO=71E<B!P;'5S(&0G861R97-S97,@96X@;&ES
M=&4@;F]I<F4N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C4T,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O9B!W:&ET96QI<W1E9"!A
M9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L("(*(DUA
M>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A9&1R
M97-S97,@=&\@=VAI=&5L:7-T+B(*;7-G<W1R("(B"B).;VUB<F4@;6%X:6UU
M;2!D)V%D<F5S<V5S(&5N(&QI<W1E(&)L86YC:&4@9.EP87-SZ2`H3F]M8G)E
M('1O=&%L.B`E<RP@3F]M8G)E("(*(FUA>&EM=6T@9"=A9')E<W-E<SH@)7,I
M+B!);7!O<W-I8FQE(&0G86IO=71E<B!P;'5S(&0G861R97-S97,@96X@;&ES
M=&4@(@HB8FQA;F-H92XB"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-C0V
M"FUS9VED(")-:7-S:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G92!T
M;R(*;7-G<W1R(")!9')E<W-E(&UA;G%U86YT92!P;W5R('D@<F5D:7)I9V5R
M(&QE(&UE<W-A9V4@(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,38X,`IM
M<V=I9"`B36ES<VEN9R!R96%S;VX@9F]R(')E:F5C="(*;7-G<W1R(")286ES
M;VX@9&4@<F5J970@;6%N<75A;G1E("(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N
M<&AP.C$X-3`*;7-G:60@(DUI<W-I;F<@<F5A<V]N(&EN('9A8V%T:6]N+B(*
M;7-G<W1R(")286ES;VX@;6%N<75A;G1E(&1A;G,@;&$@<NAG;&4@9"=A8G-E
M;F-E(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR,PIM<V=I
M9"`B36]V92(*;7-G<W1R(")$Z7!L86-E<B(*"B,Z(&9I;'1E<G,N<&AP.C$P
M.2!F:6QT97)S+G!H<#HR,34*;7-G:60@(DUO=F4@4G5L92!$;W=N(@IM<V=S
M='(@(D1E<V-E;F1R92!L82!RZ&=L92(*"B,Z(&9I;'1E<G,N<&AP.C$Q,"!F
M:6QT97)S+G!H<#HR,30*;7-G:60@(DUO=F4@4G5L92!5<"(*;7-G<W1R(")-
M;VYT97(@;&$@<NAG;&4B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C0V"FUS9VED(").7W5M8F5R(&]F(&1A>7,@8F5T=V5E;B!V86-A
M=&EO;B!R97!L:65S.B(*;7-G<W1R(").7V]M8G)E(&1E(&IO=7)S(&5N=')E
M(&QE<R!M97-S86=E<R!D)V%B<V5N8V4Z(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O9FEL=&5R+6YO;F4N:6YC.C0@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R
M+FEN8SHQ,PHC.B!L:6(O4W1O<F%G92YP:'`Z-S(Y"FUS9VED(").97<@4G5L
M92(*;7-G<W1R(").;W5V96QL92!RZ&=L92(*"B,Z(&QI8B]);F=O+G!H<#HR
M,#0@;&EB+TEN9V\N<&AP.C(P-@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`G
M)7,G(&5L96UE;G0@9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B),92!P87)A;>AT<F4@;V)L:6=A=&]I<F4@("5S)R!N)V5S
M="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N+B(*"B,Z(&QI
M8B]);F=O+G!H<#HR,#(*;7-G:60@(DYO(&)A8VME;F0@8V]N9FEG=7)E9"!F
M;W(@=&AI<R!H;W-T(@IM<V=S='(@(E!A<R!D92!"86-K96YD(&-O;F9I9W5R
MZ2!P;W5R(&-E('-E<G9E=7(B"@HC.B!L:6(O26YG;RYP:'`Z,3<Y"FUS9VED
M(").;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S+G!H<"(*;7-G
M<W1R(")087,@9&4@0F%C:V5N9"!C;VYF:6=U<ND@<&]U<B!C92!S97)V975R
M("(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHT"B,L
M('!H<"UF;W)M870*;7-G:60@(DYO(&9I;'1E<G,N($-L:6-K("<E<R<@=&\@
M8W)E871E(&$@;F5W(&9I;'1E<BXB"FUS9W-T<B`B4&%S(&1E(&9I;'1R92X@
M0VQI<75E>B`G)7,G('!O=7(@8W)E97(@=6X@;F]U=F5A=2!F:6QT<F4B"@HC
M.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ,C,S(&QI8B]38W)I<'0O<VEE=F4N
M<&AP.C$S,S,*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,34Q-0IM<V=I9"`B
M3F\@:&5A9&5R<R!S<&5C:69I960B"FUS9W-T<B`B4&%S(&0G96X@=.IT92!S
M<.EC:69IZ2(*"B,Z('-C<FEP="YP:'`Z-C<*;7-G:60@(DYO('-C<FEP="!G
M96YE<F%T960N(@IM<V=S='(@(D%U8W5N('-C<FEP="!GZ6[I<NDN(@H*(SH@
M;&EB+U-C<FEP="]S:65V92YP:'`Z,34S,`IM<V=I9"`B3F\@<W1R:6YG<R!S
M<&5C:69I960B"FUS9W-T<B`B4&%S(&1E(&-H86EN92!S<.EC:69IZ64B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S8P"FUS9VED(").;W0@97%U86P@=&\B"FUS
M9W-T<B`B3F]N(.EG86QE(.`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3D*;7-G:60@(D]P=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+B(*;7-G
M<W1R(")/<'1I;VYS(&1E(&UI<V4@X"!J;W5R(&1E<R!S8W)I<'1S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/=&AE<B!/<'1I;VYS
M(@IM<V=S='(@(D%U=')E<R!/<'1I;VYS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;F5W7V9O;&1E<BYJ<SHV"FUS9VED(")0;&5A<V4@96YT97(@=&AE
M(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(E9E=6EL97H@<V%I
M<VER(&QE(&YO;2!D=2!N;W5V96%U(&1O<W-I97(Z(@H*(SH@=&5M<&QA=&5S
M+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHV-`IM<V=I9"`B4E]E87-O;B(*;7-G
M<W1R(")?4F%I<V]N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HV,PIM
M<V=I9"`B4F5C96EV960B"FUS9W-T<B`B4F7G=2(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS,#,*;7-G:60@(E)E9&ER96-T('1O(@IM<V=S='(@(E)E9&ER:6=E
M<B!V97)S(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,@IM<V=I9"`B4F5G=6QA
M<B!E>'!R97-S:6]N(@IM<V=S='(@(D5X<')E<W-I;VX@<NEG=6QIZ')E(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,Q.`IM<V=I9"`B4F5J96-T('=I=&@@<F5A
M<V]N(@IM<V=S='(@(E)E:F5T97(@879E8R!L82!R86ES;VXB"@HC.B!C;VYF
M:6<O9FEE;&1S+G!H<"YD:7-T.C4U"FUS9VED(")297-E;G0@5&\B"FUS9W-T
M<B`B4F5N=F]YZ2!V97)S(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU
M,0IM<V=I9"`B4F5S96YT+69R;VTB"FUS9W-T<B`B4F5N=F]Y97(@9&5P=6ES
M(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHW,@IM<V=I9"`B4F5T
M=7)N('1O($9I;'1E<G,@3&ES="(*;7-G<W1R(")2971O=7(@=F5R<R!L82!L
M:7-T92!D97,@9FEL=')E<R(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI
M=&5L:7-T+FEN8SHR."!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC
M.C<U"B,Z('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,X('1E;7!L
M871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT,PIM<V=I9"`B4F5T=7)N
M('1O(%)U;&5S($QI<W0B"FUS9W-T<B`B4F5T;W5R('9E<G,@;&$@;&ES=&4@
M9&5S('+H9VQE<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z
M,C$*;7-G:60@(E)U;&4B"FUS9W-T<B`B4NAG;&4B"@HC.B!F:6QT97)S+G!H
M<#HT-0IM<V=I9"`B4G5L92!#;W!I960B"FUS9W-T<B`B4NAG;&4@8V]P:>EE
M(@H*(SH@9FEL=&5R<RYP:'`Z,SD*;7-G:60@(E)U;&4@1&5L971E9"(*;7-G
M<W1R(")2Z&=L92!E9F9A8^EE(@H*(SH@9FEL=&5R<RYP:'`Z-3D*;7-G:60@
M(E)U;&4@1&ES86)L960B"FUS9W-T<B`B4NAG;&4@9.ES86-T:7;I92(*"B,Z
M(&9I;'1E<G,N<&AP.C8T"FUS9VED(")2=6QE($5N86)L960B"FUS9W-T<B`B
M4NAG;&4@9.ES86-T:7;I(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN
M8SHS.0IM<V=I9"`B4G5L92!.86UE(@IM<V=S='(@(DYO;2!D92!L82!RZ&=L
M92(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR-R!T
M96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C<T"B,Z('1E;7!L871E
M<R]R=6QE+V9O;W1E<BYI;F,Z-S$@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R
M9"YI;F,Z,S<*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC
M.C0R"FUS9VED(")3879E(@IM<V=S='(@(D5N<F5G:7-T<F5R(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C0W"FUS9VED(")3879E(%-E
M='1I;F=S(@IM<V=S='(@(D5N<F5G:7-T<F5R(&QE<R!O<'1I;VYS(@H*(SH@
M=&5M<&QA=&5S+W-C<FEP="]H96%D97(N:6YC.C,*;7-G:60@(E-C<FEP="(*
M;7-G<W1R(")38W)I<'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*
M;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*;7-G<W1R(")-:7-E(.`@:F]U<B!D
M=2!S8W)I<'0B"@HC.B!L:6(O26YG;RYP:'`Z,C(Y"FUS9VED(")38W)I<'0@
M;F]T('5P9&%T960N(@IM<V=S='(@(E-C<FEP="!N;VX@;6ES(.`@:F]U<B(*
M"B,Z(&QI8B]);F=O+G!H<#HQ,S8*;7-G:60@(E-C<FEP="!S=6-C97-S9G5L
M;'D@86-T:79A=&5D+B(*;7-G<W1R(")38W)I<'0@86-T:7;I(&%V96,@<W5C
M8^AS+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S4*;7-G:60@(E-C<FEP="!S=6-C
M97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-C<FEP="!DZ7-A8W1I
M=ND@879E8R!S=6-CZ',N(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN
M8SHS.`IM<V=I9"`B4V5E;B(*;7-G<W1R(")6=2(*"B,Z(')U;&4N<&AP.C$V
M,PIM<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`B0VAO:7-I<W-E>B!U
M;B!C:&%M<"(*"B,Z(&QI8B]);F=O+G!H<#HU,`IM<V=I9"`B4V5L96-T('1A
M<F=E="!F;VQD97(B"FUS9W-T<B`B0VAO:7-I<W-E>B!U;B!D;W-S:65R(&-I
M8FQE(@H*(SH@<G5L92YP:'`Z,3@T"FUS9VED(")396QF+41E9FEN960@2&5A
M9&5R(@IM<V=S='(@(D5N+73J=&4@875T;RUDZ69I;FES<V%B;&4B"@HC.B!C
M;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,U"FUS9VED(")396YD97(B"FUS9W-T
M<B`B17APZ61I=&5U<B(*"B,Z(&9I;'1E<G,N<&AP.C<X"FUS9VED(")3971T
M:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B3&5S('!RZ6;I
M<F5N8V5S(&]N="!B:65N(.ETZ2!M:7-E<R#@(&IO=7(N(@H*(SH@=&5M<&QA
M=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,C0*;7-G:60@(E-H;W<@06-T:79E
M(%-C<FEP="(*;7-G<W1R(")!9F9I8VAE<B!L92!S8W)I<'0@86-T:68_(@H*
M(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,S$*;7-G:60@(E-H
M;W<@0W5R<F5N="!38W)I<'0B"FUS9W-T<B`B069F:6-H97(@;&4@<V-R:7!T
M(&-O=7)A;G0B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C@S"FUS9VED
M(")3:7IE(@IM<V=S='(@(E1A:6QL92(*"B,Z('1E;7!L871E<R]R=6QE+V9O
M;W1E<BYI;F,Z-C$*;7-G:60@(E-T;W`@8VAE8VMI;F<@:68@=&AI<R!R=6QE
M(&UA=&-H97,_(@IM<V=S='(@(D%R<F5T97(@;&$@=NER:69I8V%T:6]N(&QO
M<G-Q=64@;&$@<NAG;&4@8V]R<F5S<&]N9#\B"@HC.B!T96UP;&%T97,O=F%C
M871I;VXO=F%C871I;VXN:6YC.C4U"FUS9VED(")3=6)J95]C="!O9B!V86-A
M=&EO;B!M97-S86=E.B(*;7-G<W1R(")3=6IE7W0@9'4@;65S<V%G92!D)V%B
M<V5N8V4Z(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HS,0IM<V=I9"`B
M4W5B:F5C="(*;7-G<W1R(")3=6IE="(*"B,Z(&QI8B]);F=O+G!H<#HQ,S$*
M;7-G:60@(E1H92!D<FEV97(@<V%I9#H@(@IM<V=S='(@(DUE<W-A9V4@9'4@
M<&EL;W1E("AD<FEV97(I.B`B"@HC.B!L:6(O26YG;RYP:'`Z,3,P"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*
M;7-G<W1R(")5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=A
M8W1I=F%T:6]N(&1U('-C<FEP="XB"@HC.B!L:6(O26YG;RYP:'`Z,3(Y"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&5A8W1I=F%T:6YG('1H92!S8W)I
M<'0N(@IM<V=S='(@(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D
M92!L82!DZ7-A8W1I=F%T:6]N(&1U('-C<FEP="XB"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C(W"FUS9VED(")4;R(*;7-G<W1R("+@(@H*(SH@;&EB
M+U-C<FEP="YP:'`Z,3$V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("));7!O<W-I
M8FQE(&1E(&-H87)G97(@;&$@9.EF:6YI=&EO;B!D92`E<RXB"@HC.B!F:6QT
M97)S+G!H<#HQ,S@@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHW
M"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(W,@IM<V=I9"`B5F%C871I
M;VXB"FUS9W-T<B`B06)S96YC92(*"B,Z('9A8V%T:6]N+G!H<#HV-@IM<V=I
M9"`B5F%C871I;VX@161I="(*;7-G<W1R("+)9&ET97(@86)S96YC92(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C,U,@IM<V=I9"`B5F%C871I;VX@365S
M<V%G92(*;7-G<W1R(")-97-S86=E(&0G86)S96YC92(*"B,Z('9A8V%T:6]N
M+G!H<#HQ-@IM<V=I9"`B5F%C871I;VX@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")!8G-E;F-E
M(&XG97-T('!A<R!S=7!P;W)TZ2!P87(@;&4@<&EL;W1E(&%C='5E;"XB"@HC
M.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,3@*;7-G:60@
M(E=H7VET96QI<W0@861D<F5S<V5S.B(*;7-G<W1R(")!9')E<W-E(&5N(&Q?
M:7-T92!B;&%N8VAE(@H*(SH@9FEL=&5R<RYP:'`Z,3,R('1E;7!L871E<R]W
M:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHW"FUS9VED(")7:&ET96QI<W0B"FUS
M9W-T<B`B3&ES=&4@8FQA;F-H92(*"B,Z('=H:71E;&ES="YP:'`Z-34*;7-G
M:60@(E=H:71E;&ES="!%9&ET(@IM<V=S='(@(LED:71E<B!,:7-T92!B;&%N
M8VAE(@H*(SH@=VAI=&5L:7-T+G!H<#HQ.`IM<V=I9"`B5VAI=&5L:7-T(&ES
M(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E
M<BXB"FUS9W-T<B`B3&ES=&4@8FQA;F-H92!N)V5S="!P87,@<W5P<&]R=.EE
M('!A<R!L92!P<NES96YT(&9I;'1R92XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M
M86EL+G!H<#HR-#`@;&EB+U-C<FEP="]S:65V92YP:'`Z,CDY"FUS9VED(")7
M:&ET96QI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B061R97-S92!E;B!L:7-T
M92!B;&%N8VAE(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW.0IM<V=I
M9"`B6"U0<FEO<FET>2(*;7-G<W1R(")8+5!R:6]R:71Y(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HV-PIM<V=I9"`B6"U3<&%M+4QE=F5L(@IM<V=S
M='(@(E@M4W!A;2U,979E;"(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z
M-S$*;7-G:60@(E@M4W!A;2U38V]R92(*;7-G<W1R(")38V]R92!D92!P;W5R
M<FEE;"`H6"U3<&%M+5-C;W)E*2(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I
M<W0Z-S4*;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T<B`B6"U3<&%M+5-T
M871U<R(*"B,Z('9A8V%T:6]N+G!H<#HS,`IM<V=I9"`B(@HB66]U(&UU<W0@
M<W!E8VEF>2!A="!L96%S="!O;F4@96UA:6P@861D<F5S<R!F;W(@=VAI8V@@
M=&AE('9A8V%T:6]N(&UE<W-A9V5S("(*(G-H;W5L9"!B92!A8W1I=F%T960N
M(@IM<V=S='(@(B(*(E9O=7,@9&5V97H@<W#I8VEF:65R(&%U(&UO:6YS('5N
M92!A9')E<W-E(&1E(&-O=7)R:65L('!O=7(@<75E(&QE(&UE<W-A9V4@(@HB
M9"=A8G-E;F-E('-O:70@86-T:7;I+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP
M:'`Z,C@Q(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S`T(&QI8B]38W)I<'0O:6UA
M<"YP:'`Z,S$X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6U!A<R!D
M92!S=6IE=%TB"@HC.B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHR
M-PIM<V=I9"`B7T%D9')E<W,H97,I('1O(&9O<G=A<F0@=&\Z(@IM<V=S='(@
M(D%D<F5S<V4H<RD@=F5R<R!O^2!R961I<FEG97(Z(@H*(SH@=&5M<&QA=&5S
M+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHR.`IM<V=I9"`B7T%D9')E<W-E<R!T
M;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z(@IM<V=S='(@(E]!9')E<W-E<R!A
M=7AQ=65L;&5S(&YE('!A<R!E;G9O>65R(&1E('+I<&]N<V5S.B(*"B,Z(&QI
M8B]);F=O+G!H<#HR-S0*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B3&ES
M=&4@7VYO:7)E(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N
M:6YC.C(P"FUS9VED(")?1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L>2(*;7-G
M<W1R(")?4W5P<')I;65R(&QE(&UE<W-A9V4@8V]M<&SH=&5M96YT(@H*(SH@
M=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C,S"FUS9VED(")?
M16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z(@IM<V=S='(@(E]%
M;G1R97(@8VAA<75E(&%D<F5S<V4@<W5R('5N92!L:6=N92!SZ7!A<NEE.B(*
M"B,Z(&QI8B]);F=O+G!H<#HR.#`*;7-G:60@(E]&;W)W87)D(@IM<V=S='(@
M(E1R86YS7V9E<G0B"@HC.B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN
M8SHQ.0IM<V=I9"`B7TME97`@82!C;W!Y(&]F(&UE<W-A9V5S(&EN('1H:7,@
M86-C;W5N=#\B"FUS9W-T<B`B7T=A<F1E<B!U;F4@8V]P:64@9&5S(&UE<W-A
M9V5S(&1A;G,@8V4@8V]M<'1E/R(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O
M8FQA8VML:7-T+FEN8SHR-`IM<V=I9"`B7TUO=F4@;65S<V%G92!T;R!F;VQD
M97(Z(@IM<V=S='(@(D3I<&QA8V5R(&QE(%]M97-S86=E('9E<G,@;&4@9&]S
M<VEE<B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,3@*
M;7-G:60@(E]->2!E;6%I;"!A9&1R97-S97,Z(@IM<V=S='(@(E]-97,@861R
M97-S97,@8V]U<G)I96PZ(@H*(SH@;&EB+TEN9V\N<&AP.C(X,PIM<V=I9"`B
M7U-C<FEP="(*;7-G<W1R(")?4V-R:7!T(@H*(SH@;&EB+TEN9V\N<&AP.C(W
M-PIM<V=I9"`B7U9A8V%T:6]N(@IM<V=S='(@(E]!8G-E;F-E<R(*"B,Z(&QI
M8B]);F=O+G!H<#HR-S$*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B3&E?
M<W1E(&)L86YC:&4B"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C0*
M;7-G:60@(F%N9"(*;7-G<W1R(")E="(*"B,Z(&9I;'1E<G,N<&AP.C$V,@IM
M<V=I9"`B9FEE;&0B"FUS9W-T<B`B8VAA;7`B"@HC.B!F:6QT97)S+G!H<#HQ
M-C(*;7-G:60@(FUA=&-H(@IM<V=S='(@(F-O<G)E<W!O;F0B"@HC.B!T96UP
M;&%T97,O<G5L92]F:6QT97(N:6YC.C0*;7-G:60@(F]R(@IM<V=S='(@(F]U
M(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,3(V"FUS9VED(")P<F]C
M;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\B"FUS9W-T<B`B4V-R:7!T
M('!R;V-M86EL(&?I;NERZ2!P87(@26YG;R(*"B,Z(&QI8B]38W)I<'0O<VEE
M=F4N<&AP.C$Q,0IM<V=I9"`B<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!)
M;F=O(@IM<V=S='(@(D9I;'1R92!S:65V92!GZ6[I<ND@<&%R($EN9V\B"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG
M;R]P;R]I=%])5"YP;P``````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`T-S<W-@`Q,#0Q-S,V,C<T-P`P,3<S-S,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!)=&%L:6%N('1R
M86YS;&%T:6]N<R!F;W(@26YG;R!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@
M,C`P,R!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D
M('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($EN9V\@<&%C:V%G92X*
M(R!!=71O;6%T:6-A;&QY(&=E;F5R871E9"P@,C`P,RX*(PIM<V=I9"`B(@IM
M<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@26YG;R`R+C`M8W9S7&XB
M"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN
M(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN
M(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP.2TR."`R,SHU,"TP,3`P7&XB
M"B),87-T+51R86YS;&%T;W(Z($UA<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O
M=F%N;T!U;FEB;V-C;VYI+FET/EQN(@HB3&%N9W5A9V4M5&5A;3H@2&]R9&4@
M271A;&EA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I
M;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:71<;B(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B(&%N9"(*;7-G<W1R
M("(@92(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B(&]R(@IM<V=S='(@
M(B!O(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C$W
M"FUS9VED(")!8W1I;VX@9F]R(&)L86-K;&ES=&5D(&%D9')E<W-E<SHB"FUS
M9W-T<B`B07II;VYE('!E<B!I;F1I<FEZ>FD@;F5L;&$@;&ES=&$@;F5R83HB
M"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ,`IM<V=I9"`B
M06-T:79A=&4@4V-R:7!T(@IM<V=S='(@(D%T=&EV82!38W)I<'0B"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M8W1I=F%T:6YG('1H92!S8W)I<'0@9F]R(%PB)7-<(B!F86EL960Z("@E9"D@
M)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N
M:6YC.C8*;7-G:60@(D%D9&ET:6]N86P@4V5T=&EN9W,B"FUS9W-T<B`B56QT
M97)I;W)I($EM<&]S=&%Z:6]N:2(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E
M<BYI;F,Z-#0*;7-G:60@(D%L;"!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@
M(E1U='1E(&QE('-E9W5E;G1I(@H*(SH@;&EB+V%P:2YP:'`Z-30*(RP@9G5Z
M>GD*;7-G:60@(D%L;&]W(%)U;&5S(@IM<V=S='(@(DYU;W9A(%)E9V]L82(*
M"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S,*;7-G:60@(D%N<W=E
M<F5D(@IM<V=S='(@(E)I<W!O<W1O(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A
M9&5R+FEN8SHT-0IM<V=I9"`B06YY(&]F('1H92!F;VQL;W=I;F<B"FUS9W-T
M<B`B56YA('%U86QU;G%U92!D96QL92!S96=U96YT:2(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+V9O;W1E<BYI;F,Z,3$*;7-G:60@(D%P<&QY($9I;'1E<G,B
M"FUS9W-T<B`B07!P;&EC82!I($9I;'1R:2(*"B,Z(&9I;'1E<G,N<&AP.C(Q
M-`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES
M(')U;&4_(@IM<V=S='(@(E-E:2!S:6-U<F\@9&D@=F]L97(@96QI;6EN87)E
M('%U97-T82!R96=O;&$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M"FUS9VED(")!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R
M(&5A8V@@8VAA;F=E/R(*;7-G<W1R(")!9V=I;W)N82!A=71O;6%T:6-A;65N
M=&4@;&\@<V-R:7!T(&1O<'!O(&]G;FD@;6]D:69I8V$_(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HT-PIM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#0*;7-G:60@(D)E9VEN<R!W:71H(@IM
M<V=S='(@(DEN:7II82!C;VXB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$P
M-B!L:6(O1')I=F5R+VQD87`N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!F:6QT97)S
M+G!H<#HQ-#0@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C<*
M;7-G:60@(D)L86-K;&ES="(*;7-G<W1R("),:7-T82!N97)A(@H*(SH@8FQA
M8VML:7-T+G!H<#HQ,#`*;7-G:60@(D)L86-K;&ES="!%9&ET(@IM<V=S='(@
M(DUO9&EF:6-A(&QA($QI<W1A($YE<F$B"@HC.B!B;&%C:VQI<W0N<&AP.C$W
M"FUS9VED(")";&%C:VQI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R
M<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R("),82!L:7-T82!N97)A
M(&YO;B#H('-U<'!O<G1A=&$@;F5L(&1R:79E<B!A='1U86QE(&1I(&9I;'1R
M:2XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR,#<@;&EB+U-C<FEP
M="]M86EL9')O<"YP:'`Z,3<U"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S
M(@IM<V=S='(@(DEN9&ER:7IZ;R!N96QL82!,:7-T82!.97)A(@H*(SH@;&EB
M+U-C<FEP="]S:65V92YP:'`Z,C0S"FUS9VED(")";&%C:VQI<W1E9"!!9&1R
M97-S97,B"FUS9W-T<B`B26YD:7)I>GII(&YE;&QA($QI<W1A($YE<F$Z(@H*
M(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HX.`IM<V=I9"`B0F]D>2(*;7-G
M<W1R(")#;W)P;R(*"B,Z(&9I;'1E<G,N<&AP.C$X,B!R=6QE+G!H<#HR.#$*
M;7-G:60@(D-A<V4@4V5N<VET:79E(@IM<V=S='(@(E)I<W!E='1A($UA:75S
M8V]L92!M:6YU<V-O;&4B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C0S
M"FUS9VED(")#8R(*;7-G<W1R(")#8R(*"B,Z(')U;&4N<&AP.C$R,B!W:&ET
M96QI<W0N<&AP.C,V(&9O<G=A<F0N<&AP.C,S('9A8V%T:6]N+G!H<#HT,0HC
M.B!B;&%C:VQI<W0N<&AP.C8Y"FUS9VED(")#:&%N9V5S('-A=F5D+B(*;7-G
M<W1R(")-;V1I9FEC:&4@<V%L=F%T92XB"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C<U"FUS9VED(")#;VYN96-T:6]N(&9A:6QU<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,T,`IM<V=I9"`B0V]N=&%I;G,B"FUS9W-T
M<B`B0V]N=&EE;F4B"@HC.B!F:6QT97)S+G!H<#HR,C4@9FEL=&5R<RYP:'`Z
M,C(V"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@)7,B"FUS9W-T<B`B0V]P
M:6$@9&D@)7,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z-S8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O<'D@;V8@)7,B"FUS9W-T<B`B0V]P:6$@9&D@)7,B"@HC
M.B!L:6(O26YG;RYP:'`Z-3(*;7-G:60@(D-R96%T92!N97<@9F]L9&5R(@IM
M<V=S='(@(D-R96$@3G5O=F$@0V%R=&5L;&$B"@HC.B!L:6(O4V-R:7!T+W!R
M;V-M86EL+G!H<#HS,S8@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,C<Y"FUS
M9VED(")$25-!0DQ%1#H@(@IM<V=S='(@(D1)4T%"24Q)5$%43SHB"@HC.B!T
M96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ-PIM<V=I9"`B1&5A8W1I
M=F%T92!38W)I<'0B"FUS9W-T<B`B1&ES871T:79A(%-C<FEP="(*"B,Z(&9I
M;'1E<G,N<&AP.C(Q-"!F:6QT97)S+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E("5S(@IM<V=S='(@(D-A;F-E;&QA("5S(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHS,`IM<V=I9"`B1&5L971E($-O;F1I
M=&EO;B(*;7-G<W1R(")%;&EM:6YA(&QA($-O;F1I>FEO;F4B"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z,CDR"FUS9VED(")$96QE=&4@;65S<V%G92!C;VUP;&5T
M96QY(@IM<V=S='(@(D5L:6UI;F$@;65S<V%G9VEO(&-O;7!L971A;65N=&4B
M"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C,U"FUS9VED(")$96QE
M=&5D(@IM<V=S='(@(D5L:6UI;F%T;R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR
M.#`*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!)3D)/6"(*;7-G<W1R(")#;VYS
M96=N82!N96QL82!M:6$@24Y"3U@B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S`V
M"FUS9VED(")$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(&-O<'D@=&\B"FUS
M9W-T<B`B0V]N<V5G;F$@;F5L;&$@;6EA($E.0D]8(&4@<FEM8F%L>F$@82(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS,#$*;7-G:60@(D1E;&EV97(@:6YT;R!M
M>2!)3D)/6"!A;F0@<F5D:7)E8W0@=&\B"FUS9W-T<B`B0V]N<V5G;F$@;F5L
M;&$@;6EA($E.0D]8(&4@<FEM8F%L>F$@82(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HR.#8*;7-G:60@(D1E;&EV97(@=&\@9F]L9&5R(@IM<V=S='(@(E-P;W-T
M82!N96QL82!#87)T96QL82(*"B,Z(&9I;'1E<G,N<&AP.C(T,2!F:6QT97)S
M+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ES86)L92`E<R(*;7-G
M<W1R(")$:7-A='1I=F$@)7,B"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H
M:71E;&ES="YI;F,Z,3`@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N
M:6YC.C$P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-B!T
M96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHQ,`HC.B!T96UP;&%T97,O
M<G5L92]H96%D97(N:6YC.C(V"FUS9VED(")$:7-A8FQE9"(*;7-G<W1R(")$
M:7-A='1I=F%T;R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN
M8SHQ,PIM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE
M;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/R(*;7-G<W1R(")-;W-T82!N;W1I
M9FEC82!D971T86=L:6%T82!D;W!O(&PG87!P;&EC87II;VYE(&1I(&]G;FD@
M9FEL=')O/R(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M,S0*;7-G:60@(D1O(%]N;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L:R!O<B!L
M:7-T(&UE<W-A9V5S(@IM<V=S='(@(DY?;VX@:6YV:6%R92!R:7-P;W-T92!A
M(&=R=7!P:2!O(&UE<W-A9V=I(&1I(&QI<W1E(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@=&AI<SHB"FUS9W-T<B`B1F%I
M('%U97-T;SHB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0U"FUS9VED(")$;V5S
M;B=T(&)E9VEN('=I=&@B"FUS9W-T<B`B3F]N(&EN:7II82!C;VXB"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S0Q"FUS9VED(")$;V5S;B=T(&-O;G1A:6XB"FUS
M9W-T<B`B3F]N(&-O;G1I96YE(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-PIM
M<V=I9"`B1&]E<VXG="!E;F0@=VET:"(*;7-G<W1R(").;VX@9FEN:7-C92!C
M;VXB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0Y"FUS9VED(")$;V5S;B=T(&5X
M:7-T(@IM<V=S='(@(DYO;B!E<VES=&4B"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,S4R"FUS9VED(")$;V5S;B=T(&UA=&-H("AW:71H('!L86-E:&]L9&5R<RDB
M"FUS9W-T<B`B3F]N(&-O<G)I<W!O;F1E(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O:&5A9&5R+FEN8SHS,0IM<V=I9"`B161I="(*;7-G<W1R(")-;V1I9FEC
M82(*"B,Z(&9I;'1E<G,N<&AP.C(P,R!F:6QT97)S+G!H<#HR,#4@9FEL=&5R
M<RYP:'`Z,C`Y(&9I;'1E<G,N<&AP.C(Q,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET("5S(@IM<V=S='(@(DUO9&EF:6-A("5S(@H*(SH@9FEL=&5R<RYP
M:'`Z,C0U(&9I;'1E<G,N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;F%B;&4@)7,B"FUS9W-T<B`B071T:79A("5S(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O:&5A9&5R+FEN8SHS-PIM<V=I9"`B16YA8FQE9"(*;7-G<W1R(")!
M='1I=F%T;R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#8*;7-G:60@(D5N9',@
M=VET:"(*;7-G<W1R(")&:6YI<V-E(&-O;B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS-3<*;7-G:60@(D5Q=6%L('1O(@IM<V=S='(@(E5G=6%L92!A(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HQ,SD@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M-#D@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-3@*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5T<FEE=FEN
M9R!C=7)R96YT('-C<FEP=#H@*"5D*2`E<R(*;7-G<W1R("(B"@HC.B!B;&%C
M:VQI<W0N<&AP.C8W"FUS9VED(")%<G)O<B!S879I;F<@8VAA;F=E<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR,@IM
M<V=I9"`B17AI<W1I;F<@4G5L97,B"FUS9W-T<B`B4F5G;VQE($5S:7-T96YT
M:2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#@*;7-G:60@(D5X:7-T<R(*;7-G
M<W1R(")%<VES=&4B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%>'!E8W1E9"`Q(&]B:F5C="P@9V]T("5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z
M,C`*;7-G:60@(D9I;'1E<B!!;&P@365S<V%G97,B"FUS9W-T<B`B1FEL=')A
M(%1U='1I(&D@365S<V%G9VDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T
M:6YG<RYI;F,Z,C(*;7-G:60@(D9I;'1E<B!/;FQY(%-E96X@365S<V%G97,B
M"FUS9W-T<B`B1FEL=')A(%-O;&\@365S<V%G9VD@3&5T=&DB"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,C$*;7-G:60@(D9I;'1E<B!/
M;FQY(%5N<V5E;B!-97-S86=E<R(*;7-G<W1R(")&:6QT<F$@4V]L;R!-97-S
M86=G:2!.;VX@3&5T=&DB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG
M<RYI;F,Z,3@*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S='(@(D]P>FEO
M;FD@1FEL=')I(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHR-0IM
M<V=I9"`B1FEL=&5R(%)U;&4B"FUS9W-T<B`B4F5G;VQA(&1E;"!&:6QT<F\B
M"@HC.B!F:6QT97)S+G!H<#HQ,#D*;7-G:60@(D9I;'1E<B!2=6QE<R(*;7-G
M<W1R(")296=O;&4@9&5L($9I;'1R;R(*"B,Z('-C<FEP="YP:'`Z-3(*;7-G
M:60@(D9I;'1E<B!38W)I<'0@1&ES<&QA>2(*;7-G<W1R(")6:7-U86QI>GIA
M>FEO;F4@4V-R:7!T(&1I($9I;'1R;R(*"B,Z(&QI8B]);F=O+G!H<#HS,#`*
M;7-G:60@(D9I;'1E<B!?4G5L97,B"FUS9W-T<B`B7U)E9V]L92!D96P@1FEL
M=')O(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@
M8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D%T
M=&EV:73@(&1E;"!F:6QT<F\Z("5S(&UE<W-A9V=I;R]I('-P;W-T871I(&YE
M;&QA(&-A<G1E;&QA(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP
M.C,P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S
M(&UE<W-A9V4H<RD@:&%V92!B965N(&1E;&5T960N(@IM<V=S='(@(D%T=&EV
M:73@(&1E;"!F:6QT<F\Z("5S(&UE<W-A9V=I;R]I('-O;F\@<W1A=&D@96QI
M;6EN871I+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C@S"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H
M879E(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(D%T=&EV:73@(&1E;"!F:6QT<F\Z("5S(&UE<W-A9V=I;R]I('-P;W-T871I
M(&YE;&QA(&-A<G1E;&QA(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N
M<&AP.C$X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ
M("5S(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C:VQI<W0@=V5R
M92!D96QE=&5D+B(*;7-G<W1R("(B"B)!='1I=FETX"!D96P@9FEL=')O.B`E
M<R!M97-S86=G:6\O:2!C:&4@8V]R<FES<&]N9&%N;R!A;&QA(&QI<W1A(&YE
M<F$@<V]N;R`B"B)S=&%T:2!E;&EM:6YA=&DN(@H*(SH@;&EB+U-C<FEP="]I
M;6%P+G!H<#HS,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB1FEL=&5R(&%C
M=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E
M96X@8V]P:65D('1O('1H92`B"B)F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B
M"B)!='1I=FETX"!D96P@9FEL=')O.B!);"!M97-S86=G:6\@7"(E<UPB(&1A
M(%PB)7-<(B#H('-T871O('-P;W-T871O(&YE;&QA("(*(F-A<G1E;&QA(%PB
M)7-<(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB)7-<
M(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!='1I
M=FETX"!D96P@9FEL=')O.B!);"!M97-S86=G:6\@7"(E<UPB(&1A(%PB)7-<
M(B#H('-T871O(&5L:6UI;F%T;RXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP
M.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ
M(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!M;W9E
M9"!T;R!T:&4@9F]L9&5R("(*(EPB)7-<(BXB"FUS9W-T<B`B(@HB071T:79I
M=.`@9&5L(&9I;'1R;SH@26P@;65S<V%G9VEO(%PB)7-<(B!D82!<(B5S7"(@
MZ"!S=&%T;R!S<&]S=&%T;R!N96QL82`B"B)C87)T96QL82!<(B5S7"(N(@H*
M(SH@<G5L92YP:'`Z,38P"FUS9VED(")&:6QT97(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")5=&5N=&4@;F]N('1R;W9A=&\N(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M:&5A9&5R+FEN8SHT,@IM<V=I9"`B1F]R(&%N(&EN8V]M:6YG(&UE<W-A9V4@
M=&AA="!M871C:&5S.B(*;7-G<W1R(")097(@;65S<V%G9VD@:6X@:6YG<F5S
M<V\@8VAE(&-O;6)A8VEA;F\@8V]N.B(*"B,Z(&9I;'1E<G,N<&AP.C$V,B!T
M96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHX"FUS9VED(")&;W)W87)D
M(@IM<V=S='(@(DEN;VQT<F$B"@HC.B!F;W)W87)D+G!H<#HQ-@IM<V=I9"`B
M1F]R=V%R9"!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E
M<FEN9R!D<FEV97(N(@IM<V=S='(@(DPG:6YO;'1R;R!N;VX@Z"!S=7!P;W)T
M871O(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C@R(&QI8B]38W)I
M<'0O;6%I;&1R;W`N<&AP.C(R-`IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B
M26YO;'1R:2(*"B,Z(&9O<G=A<F0N<&AP.C0V"FUS9VED(")&;W)W87)D<R!%
M9&ET(@IM<V=S='(@(DUO9&EF:6-A($EN;VQT<FDB"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C,Y"FUS9VED(")&<F]M(@IM<V=S='(@(D1A(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,U-0IM<V=I9"`B1W)E871E<B!T:&%N(@IM<V=S
M='(@(E!I=2<@9W)A;F1E(&1I(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-@IM
M<V=I9"`B1W)E871E<B!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(DUE;F\@
M9&D@;R!U9W5A;&4@82(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z
M,S$*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R("));7!O<G1A;G1E(@H*(SH@
M<G5L92YP:'`Z,S8*;7-G:60@(DEN9&EV:61U86P@<G5L97,@87)E(&YO="!S
M=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS
M9W-T<B`B4F5G;VQE(&EN9&EV:61U86QI(&YO;B!S;VYO('-U<'!O<G1A=&4B
M"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ.#4U"FUS9VED("));F5X:7-T
M86YT(&UA:6QB;W@@<W!E8VEF:65D(&9O<B!M97-S86=E(&1E;&EV97)Y+B(*
M;7-G<W1R(")#87-E;&QA(&EN97-I<W1E;G1E('-P96-I9FEC871A('!E<B!L
M82!C;VYS96=N82!D96P@;65S<V%G9VEO+B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS-#(*;7-G:60@(DES(@IM<V=S='(@(D4G(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,T,PIM<V=I9"`B27-N)W0B"FUS9W-T<B`B3F]N(.@B"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C(S"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@
M<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE
M(&]R(&YO="!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS-3,*;7-G:60@(DQE<W,@=&AA;B(*;7-G<W1R(")-96YO(&1I(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,U-`IM<V=I9"`B3&5S<R!T:&%N(&]R(&5Q=6%L
M('1O(@IM<V=S='(@(DUE;F\@9&D@;R!U9W5A;&4@82(*"B,Z(&-O;F9I9R]F
M:65L9',N<&AP+F1I<W0Z-3D*;7-G:60@(DQI<W0M240B"FUS9W-T<B`B240@
M3&ES=&$B"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M,C`*;7-G:60@(DUA<E]K(&UE<W-A9V4@87,@9&5L971E9"(*;7-G<W1R(")#
M;VY?=')A<W-E9VYA(&UE<W-A9V=I;R!C;VUE(&5L:6UI;F%T;R(*"B,Z('1E
M;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,C0*;7-G:60@(DUA<FL@;65S<V%G
M92!A<SHB"FUS9W-T<B`B0V]N=')A<W-E9VYA(&UE<W-A9VEO(&-O;64Z(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,U,0HC+"!F=7IZ>0IM<V=I9"`B36%T8VAE
M<R`H=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S='(@(DYO;B!C;W)R:7-P;VYD
M92(*"B,Z(&QI8B]A<&DN<&AP.C4W"FUS9VED(")-87AI;75M($YU;6)E<B!O
M9B!2=6QE<R(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z-#<X"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@;G5M8F5R(&]F(&)L86-K
M;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E
M<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@
M;F5W(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HU,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X
M:6UU;2!N=6UB97(@;V8@=VAI=&5L:7-T960@861D<F5S<V5S(&5X8V5E9&5D
M("A4;W1A;"!A9&1R97-S97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@
M)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O('=H:71E;&ES
M="XB"FUS9W-T<B`B(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3<R,PIM
M<V=I9"`B36ES<VEN9R!A9&1R97-S('1O(')E9&ER96-T(&UE<W-A9V4@=&\B
M"FUS9W-T<B`B36%N8V$@;"=I;F1I<FEZ>F\@86P@<75A;&4@<F5D:7)I9V5R
M92!I;"!M97-S86=G:6\B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-S4U
M"FUS9VED(")-:7-S:6YG(')E87-O;B!F;W(@<F5J96-T(@IM<V=S='(@(DEN
M9F]R;6%Z:6]N:2!M86YC86YT92(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP
M.C$Y,C(*;7-G:60@(DUI<W-I;F<@<F5A<V]N(&EN('9A8V%T:6]N+B(*;7-G
M<W1R("));F9O<FUA>FEO;FD@;6%N8V%N=&4B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]H96%D97(N:6YC.C0P"FUS9VED(")-;W9E(@IM<V=S='(@(E-P;W-T
M82(*"B,Z(&9I;'1E<G,N<&AP.C$R-B!F:6QT97)S+G!H<#HR,S@*;7-G:60@
M(DUO=F4@4G5L92!$;W=N(@IM<V=S='(@(E-P;W-T82!L82!296=O;&$@1VGY
M(@H*(SH@9FEL=&5R<RYP:'`Z,3(W(&9I;'1E<G,N<&AP.C(S-PIM<V=I9"`B
M36]V92!2=6QE(%5P(@IM<V=S='(@(E-P;W-T82!L82!296=O;&$@4_DB"@HC
M.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C0R"FUS9VED(").
M7W5M8F5R(&]F(&1A>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S.B(*;7-G
M<W1R(").7W5M97)O(&1I(&=I;W)N:2!T<F$@9'5E(')I<W!O<W1E(&%L;&\@
M<W1E<W-O(&EN9&ER:7IZ;R(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E
M<BUN;VYE+FEN8SHT('1E;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z.`HC
M.B!L:6(O4W1O<F%G92YP:'`Z-S$T"FUS9VED(").97<@4G5L92(*;7-G<W1R
M(").=6]V82!296=O;&$B"@HC.B!L:6(O26YG;RYP:'`Z,3DT(&QI8B]);F=O
M+G!H<#HQ.38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO(%PB)7-<
M(B!E;&5M96YT(&9O=6YD(&EN(&)A8VME;F0@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B)R5S)R!N;VX@<W!E8VEF:6-A=&$@;F5L;&$@8V]N9FEG=7)A>FEO
M;F4@9&5L;&4@8V%T96=O<FEE+B(*"B,Z(&QI8B]);F=O+G!H<#HQ.3(*;7-G
M:60@(DYO(&)A8VME;F0@8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T(@IM<V=S
M='(@(DYE<W-U;B!B86-K960@8V]N9FEG=7)A=&\@<&5R('%U97-T;R!H;W-T
M(@H*(SH@;&EB+TEN9V\N<&AP.C$V.0IM<V=I9"`B3F\@8F%C:V5N9',@8V]N
M9FEG=7)E9"!I;B!B86-K96YD<RYP:'`B"FUS9W-T<B`B3F5S<W5N(&)A8VME
M9"!C;VYF:6=U<F%T;R!I;B!B86-K96YD<RYP:'`B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B3F\@9FEL=&5R<RX@0VQI8VL@7"(E<UPB('1O(&-R96%T92!A
M(&YE=R!F:6QT97(N(@IM<V=S='(@(DYE<W-U;B!F:6QT<F\N($-L:6-C82`G
M)7,G('!E<B!C<F5A<F4@=6X@;G5O=F\@9FEL=')O+B(*"B,Z(&QI8B]38W)I
M<'0O<VEE=F4N<&AP.C$S,C<@;&EB+U-C<FEP="]S:65V92YP:'`Z,30R,`HC
M.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-3DT"FUS9VED(").;R!H96%D97)S
M('-P96-I9FEE9"(*;7-G<W1R(").97-S=6YA(&EN=&5S=&%Z:6]N92!S<&5C
M:69I8V%T82(*"B,Z('-C<FEP="YP:'`Z-C<*;7-G:60@(DYO('-C<FEP="!G
M96YE<F%T960N(@IM<V=S='(@(DYE<W-U;B!S8W)I<'0@9V5N97)A=&\N(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,38P.0IM<V=I9"`B3F\@<W1R:6YG
M<R!S<&5C:69I960B"FUS9W-T<B`B3F5S<W5N82!S=')I;F=A('-P96-I9FEC
M871A(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U.`IM<V=I9"`B3F]T(&5Q=6%L
M('1O(@IM<V=S='(@(DYO;B!U9W5A;&4@82(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS,38*;7-G:60@(D]N;'D@9FQA9R!T:&4@;65S<V%G92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3D*;7-G:60@(D]P=&EO;G,@
M86)O=70@<V-R:7!T('5P9&%T:6YG+B(*;7-G<W1R(")/<'II;VYI(')I9W5A
M<F1O(&PG86=G:6]R;F%M96YT;R!D96QL;R!S8W)I<'0N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S
M='(@(D%L=')E($]P>FEO;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]N
M97=?9F]L9&5R+FIS.C8*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O
M9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B26YS97)I<V-I(&EL(&YO;64@
M9&5L;&$@;G5O=F$@8V%R=&5L;&$Z(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N
M+W9A8V%T:6]N+FEN8SHV,`IM<V=I9"`B4E]E87-O;B(*;7-G<W1R(")27V%G
M:6]N92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-C,*;7-G:60@(E)E
M8V5I=F5D(@IM<V=S='(@(E)I8V5V=71O(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C(Y-PIM<V=I9"`B4F5D:7)E8W0@=&\B"FUS9W-T<B`B4F5D:7)I9VD@82(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3`*;7-G:60@(E)E9W5L87(@97AP<F5S
M<VEO;B(*;7-G<W1R(")%<W!R97-S:6]N92!R96=O;&%R92(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS,3(*;7-G:60@(E)E:F5C="!W:71H(')E87-O;B(*;7-G
M<W1R(")38V%R=&$@8V]N('5N(')A9VEO;F4B"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C4U"FUS9VED(")297-E;G0@5&\B"FUS9W-T<B`B4FES<&5D
M:7-C:2!!(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU,0IM<V=I9"`B
M4F5S96YT+69R;VTB"FUS9W-T<B`B4FES<&5D:7-C:2!$82(*"B,Z('1E;7!L
M871E<R]R=6QE+V9O;W1E<BYI;F,Z-C`*;7-G:60@(E)E='5R;B!T;R!&:6QT
M97)S($QI<W0B"FUS9W-T<B`B5&]R;F$@86P@16QE;F-O($9I;'1R:2(*"B,Z
M('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR-"!T96UP;&%T
M97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z-#$*(SH@=&5M<&QA=&5S+W9A
M8V%T:6]N+W9A8V%T:6]N+FEN8SHW,2!T96UP;&%T97,O9F]R=V%R9"]F;W)W
M87)D+FEN8SHS-`IM<V=I9"`B4F5T=7)N('1O(%)U;&5S($QI<W0B"FUS9W-T
M<B`B5&]R;F$@86P@16QE;F-O(%)E9V]L92(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+VAE861E<BYI;F,Z,S0*;7-G:60@(E)U;&4B"FUS9W-T<B`B4F5G;VQA
M(@H*(SH@9FEL=&5R<RYP:'`Z-C`*;7-G:60@(E)U;&4@0V]P:65D(@IM<V=S
M='(@(E)E9V]L82!#;W!I871A(@H*(SH@9FEL=&5R<RYP:'`Z,SD*;7-G:60@
M(E)U;&4@1&5L971E9"(*;7-G<W1R(")296=O;&$@16QI;6EN871A(@H*(SH@
M9FEL=&5R<RYP:'`Z-S8*;7-G:60@(E)U;&4@1&ES86)L960B"FUS9W-T<B`B
M4F5G;VQA($1I<V%T=&EV871A(@H*(SH@9FEL=&5R<RYP:'`Z.#$*;7-G:60@
M(E)U;&4@16YA8FQE9"(*;7-G<W1R(")296=O;&$@071T:79A=&$B"@HC.B!T
M96UP;&%T97,O<G5L92]H96%D97(N:6YC.C,S"FUS9VED(")2=6QE($YA;64B
M"FUS9W-T<B`B3F]M92!296=O;&$B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S
M*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E
M;&ES="YI;F,Z,C,@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC
M.C0P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-S`@=&5M
M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,S,*(SH@=&5M<&QA=&5S+W)U
M;&4O9F]O=&5R+FEN8SHU.0IM<V=I9"`B4V%V92(*;7-G<W1R(")386QV82(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR.0IM<V=I9"`B
M4V%V92!3971T:6YG<R(*;7-G<W1R(")386QV82!);7!O<W1A>FEO;FDB"@HC
M.B!T96UP;&%T97,O<V-R:7!T+VAE861E<BYI;F,Z,@HC+"!F=7IZ>0IM<V=I
M9"`B4V-R:7!T(@IM<V=S='(@(E]38W)I<'0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*;7-G<W1R(")!
M9V=I;W)N86UE;G1O(%-C<FEP="(*"B,Z(&QI8B]);F=O+G!H<#HR,3<*;7-G
M:60@(E-C<FEP="!N;W0@=7!D871E9"XB"FUS9W-T<B`B4V-R:7!T(&YO;B!A
M9V=I;W)N871O+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S`*;7-G:60@(E-C<FEP
M="!S=6-C97-S9G5L;'D@86-T:79A=&5D+B(*;7-G<W1R(")38W)I<'0@871T
M:79A=&\@8V]N('-U8V-E<W-O+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,CD*;7-G
M:60@(E-C<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(E-C<FEP="!D:7-A='1I=F%T;R!C;VX@<W5C8V5S<V\N(@H*(SH@=&5M<&QA
M=&5S+W)U;&4O9F]O=&5R+FEN8SHR.0IM<V=I9"`B4V5E;B(*;7-G<W1R(")6
M:7-T;R(*"B,Z(')U;&4N<&AP.C$Y,`IM<V=I9"`B4V5L96-T(&$@9FEE;&0B
M"FUS9W-T<B`B4V5L97II;VYA('5N(&-A;7!O(@H*(SH@;&EB+TEN9V\N<&AP
M.C0Y"FUS9VED(")396QE8W0@=&%R9V5T(&9O;&1E<B(*;7-G<W1R(")396QE
M>FEO;F$@;&$@8V%R=&5L;&$@9&D@9&5S=&EN87II;VYE(@H*(SH@<G5L92YP
M:'`Z,C(W"FUS9VED(")396QF+41E9FEN960@2&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S4*;7-G:60@(E-E;F1E<B(*
M;7-G<W1R(")-:71T96YT92(*"B,Z(&9I;'1E<G,N<&AP.CDU"FUS9VED(")3
M971T:6YG<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B26UP;W-T
M87II;VYI(&%G9VEO<FYA=&4@8V]N('-U8V-E<W-O+B(*"B,Z('1E;7!L871E
M<R]S8W)I<'0O86-T:79A=&4N:6YC.C(T"FUS9VED(")3:&]W($%C=&EV92!3
M8W)I<'0B"FUS9W-T<B`B36]S=')A(%-C<FEP="!!='1I=F\B"@HC.B!T96UP
M;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHS,0IM<V=I9"`B4VAO=R!#=7)R
M96YT(%-C<FEP="(*;7-G<W1R(")-;W-T<F$@4V-R:7!T($%T='5A;&4B"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C@S"FUS9VED(")3:7IE(@IM<V=S
M='(@(D1I;65N<VEO;F4B"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC
M.C0Y"FUS9VED(")3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M871C:&5S
M/R(*;7-G<W1R(")%<V-I(&1A:2!F:6QT<FD@<V4@<75E<W1A(')E9V]L82!C
M;W)R:7-P;VYD93\B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN
M:6YC.C4Q"FUS9VED(")3=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E.B(*
M;7-G<W1R(")/9V=E='1O(&1E;"!M97-S86=G:6\@9&D@=F%C86YZ93HB"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,Q"FUS9VED(")3=6)J96-T(@IM
M<V=S='(@(D]G9V5T=&\B"@HC.B!L:6(O87!I+G!H<#HX-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@861D<F5S<R!<(B5S7"(@:&%S(&)E96X@861D960@
M=&\@>6]U<B!B;&%C:VQI<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!<(B5S7"(@
M:&%S(&)E96X@861D960@=&\@>6]U<B!W:&ET96QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]);F=O+G!H<#HQ,C4*;7-G:60@(E1H92!D<FEV97(@<V%I9#H@
M(@IM<V=S='(@(DEL(&1R:79E<B!H82!R:7-P;W-T;SH@(@H*(SH@;&EB+TEN
M9V\N<&AP.C$R-`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I
M;F<@=&AE('-C<FEP="XB"FUS9W-T<B`B17)R;W)E(&YE;"!A='1I=F%Z:6]N
M92!D96P@<V-R:7!T+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,C,*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D96%C=&EV871I;F<@=&AE('-C<FEP="XB"FUS
M9W-T<B`B17)R;W)E(&YE;"!D:7-A='1I=F%Z:6]N92!D96P@<V-R:7!T+B(*
M"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,C<*;7-G:60@(E1O(@IM<V=S
M='(@(D$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F:6QT97(N:'1M;#HR.`HC
M+"!F=7IZ>0IM<V=I9"`B5&\Z(@IM<V=S='(@(D$B"@HC.B!L:6(O4V-R:7!T
M+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@
M=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A
M<FEC87)E(&QE(&1E9FEN:7II;VYI(&1I("5S+B(*"B,Z(&9I;'1E<G,N<&AP
M.C$U-B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C4*(SH@;&EB
M+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C8R"FUS9VED(")686-A=&EO;B(*;7-G
M<W1R(")686-A;GIE(@H*(SH@=F%C871I;VXN<&AP.C<R"FUS9VED(")686-A
M=&EO;B!%9&ET(@IM<V=S='(@(DUO9&EF:6-A(%9A8V%N>F4B"@HC.B!L:6(O
M4V-R:7!T+W-I979E+G!H<#HS-3$*;7-G:60@(E9A8V%T:6]N($UE<W-A9V4B
M"FUS9W-T<B`B365S<V%G9VEO(%9A8V%N>F4B"@HC.B!V86-A=&EO;BYP:'`Z
M,38*;7-G:60@(E9A8V%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U
M<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B5F%C86YZ92!N;VX@
M<V]N;R!S=7!P;W)T871E(&YE;"!A='1U86QE(&1R:79E<B!D96D@9FEL=')I
M+B(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHQ-@IM
M<V=I9"`B5VA?:71E;&ES="!A9&1R97-S97,Z(@IM<V=S='(@(DEN9&ER:7IZ
M:2!D96QL82!,:7-T82!"7VEA;F-A.B(*"B,Z(&9I;'1E<G,N<&AP.C$U,"!T
M96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z.`IM<V=I9"`B5VAI
M=&5L:7-T(@IM<V=S='(@(DQI<W1A(&)I86YC82(*"B,Z('=H:71E;&ES="YP
M:'`Z-34*;7-G:60@(E=H:71E;&ES="!%9&ET(@IM<V=S='(@(DUO9&EF:6-A
M(&QA($QI<W1A($)I86YC82(*"B,Z('=H:71E;&ES="YP:'`Z,3@*;7-G:60@
M(E=H:71E;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I
M;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(E=H:71E;&ES="!N;VX@Z"!S=7!P
M;W)T871A(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C,T(&QI8B]3
M8W)I<'0O<VEE=F4N<&AP.C(Y-PHC.B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H
M<#HR,#(*;7-G:60@(E=H:71E;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R("))
M;F1I<FEZ>FD@;F5L;&$@3&ES=&$@0FEA;F-A.B(*"B,Z(&-O;F9I9R]F:65L
M9',N<&AP+F1I<W0Z-SD*;7-G:60@(E@M4')I;W)I='DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HV-PIM<V=I9"`B6"U3<&%M+4QE
M=F5L(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-S$*
M;7-G:60@(E@M4W!A;2U38V]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C<U"FUS9VED(")8+5-P86TM4W1A='5S(@IM<V=S='(@
M(B(*"B,Z(&9I;'1E<G,N<&AP.C4S(')U;&4N<&AP.C$T-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@<G5L97,N(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C0U
M(')U;&4N<&AP.C(Q"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!O<B!E9&ET(&-U<W1O;2!R=6QE<RXB"FUS9W-T<B`B(@H*(SH@=F%C
M871I;VXN<&AP.C,P"FUS9VED("(B"B)9;W4@;75S="!S<&5C:69Y(&%T(&QE
M87-T(&]N92!E;6%I;"!A9&1R97-S(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@
M;65S<V%G97,@(@HB<VAO=6QD(&)E(&%C=&EV871E9"XB"FUS9W-T<B`B(@HB
M3V-C;W)R92!S<&5C:69I8V%R92!A;&UE;F\@=6X@:6YD:7)I>GIO(&5M86EL
M('!E<B!I;"!Q=6%L92!A='1I=F%R92!L92`B"B)R96=O;&4@9&D@=F%C86YZ
M82(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<X(&QI8B]38W)I<'0O:6UA
M<"YP:'`Z,S`Q(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$U"FUS9VED(");3F\@
M4W5B:F5C=%TB"FUS9W-T<B`B6TYE<W-U;B!/9V=E='1O72(*"B,Z('1E;7!L
M871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C(T"FUS9VED(")?061D<F5S<RAE
M<RD@=&\@9F]R=V%R9"!T;SHB"FUS9W-T<B`B26YD:7)I>GIO*&DI(&%I('%U
M86QI(&EN;VQT<F%R93HB"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C(S"FUS9VED(")?061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O
M;G-E<R!T;SHB"FUS9W-T<B`B7TEN9&ER:7IZ:2!A:2!Q=6%L:2!N;VX@<FES
M<&]N9&5R93HB"@HC.B!L:6(O26YG;RYP:'`Z,S`U"FUS9VED(")?0FQA8VML
M:7-T(@IM<V=S='(@(E],:7-T82!N97)A(@H*(SH@=&5M<&QA=&5S+V)L86-K
M;&ES="]B;&%C:VQI<W0N:6YC.C$X"FUS9VED(")?1&5L971E(&UE<W-A9V4@
M8V]M<&QE=&5L>2(*;7-G<W1R(")?16QI;6EN82!M97-S86=G:6\@8V]M<&QE
M=&%M96YT92(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN
M8SHS,0IM<V=I9"`B7T5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE
M.B(*;7-G<W1R(")?26YS97)I<V-I(&]G;FD@:6YD:7)I>GIO('-U('5N82!N
M=6]V82!R:6=A.B(*"B,Z(&QI8B]);F=O+G!H<#HS,3$*;7-G:60@(E]&;W)W
M87)D(@IM<V=S='(@(E]);F]L=')A(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O
M9F]R=V%R9"YI;F,Z,3<*;7-G:60@(E]+965P(&$@8V]P>2!O9B!M97-S86=E
M<R!I;B!T:&ES(&%C8V]U;G0_(@IM<V=S='(@(E]-86YT:65N:2!U;F$@8V]P
M:6$@9&5I(&UE<W-A9V=I(&EN('%U97-T;R!A8V-O=6YT/R(*"B,Z('1E;7!L
M871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,@IM<V=I9"`B7TUO=F4@
M;65S<V%G92!T;R!F;VQD97(Z(@IM<V=S='(@(E]3<&]S=&$@;65S<V%G9VD@
M86QL82!C87)T96QL83HB"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C$S"FUS9VED(")?37D@96UA:6P@861D<F5S<V5S.B(*;7-G<W1R
M(")?36EE:2!I;F1I<FEZ>FD@9&D@<&]S=&$Z(@H*(SH@;&EB+TEN9V\N<&AP
M.C,Q-`IM<V=I9"`B7U-C<FEP="(*;7-G<W1R(")?4V-R:7!T(@H*(SH@;&EB
M+TEN9V\N<&AP.C,P.`IM<V=I9"`B7U9A8V%T:6]N(@IM<V=S='(@(E]686-A
M;GIE(@H*(SH@;&EB+TEN9V\N<&AP.C,P,@IM<V=I9"`B7U=H:71E;&ES="(*
M;7-G<W1R(")?3&ES=&$@8FEA;F-A(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL
M=&5R+FEN8SHT"FUS9VED(")A;F0B"FUS9W-T<B`B92(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+V9I;'1E<BYH=&UL.C$V"FUS9VED(")D:7-A8FQE9"`M(&-L
M:6-K('1O(&5N86)L92(*;7-G<W1R("(B"@HC.B!F:6QT97)S+G!H<#HQ.#`*
M;7-G:60@(F9I96QD(@IM<V=S='(@(F-A;7!O(@H*(SH@;&EB+U-C<FEP="]M
M86EL9')O<"YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")M86EL9')O<"!S8W)I
M<'0@9V5N97)A=&5D(&)Y($EN9V\B"FUS9W-T<B`B<V-R:7!T('!R;V-M86EL
M(&=E;F5R871O(&1A($EN9V\B"@HC.B!F:6QT97)S+G!H<#HQ.#`*;7-G:60@
M(FUA=&-H(@IM<V=S='(@(F-O<G)I<W!O;F1E(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O9FEL=&5R+FEN8SHT"FUS9VED(")O<B(*;7-G<W1R(")O(@H*(SH@;&EB
M+U-C<FEP="]P<F]C;6%I;"YP:'`Z,3(X"FUS9VED(")P<F]C;6%I;"!S8W)I
M<'0@9V5N97)A=&5D(&)Y($EN9V\B"FUS9W-T<B`B<V-R:7!T('!R;V-M86EL
M(&=E;F5R871O(&1A($EN9V\B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ
M,#D*;7-G:60@(G-I979E(&9I;'1E<B!G96YE<F%T960@8GD@26YG;R(*;7-G
M<W1R(")F:6QT<F\@<VEE=F4@9V5N97)A=&\@9&$@26YG;R(*```N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O<&\O;'9?3%8N<&\`````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#<W,S(`,3`T,3<S
M-C(W-#<`,#$W,S<U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@3&%T=FEA;B!T<F%N<VQA=&EO;G,@9F]R($EN9V\@<&%C
M:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H
M:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E
M(&%S('1H92!);F=O('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T
M960L(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($EN9V\@2#,@*#$N,"U20S(I7&XB"B)297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-2TP-"TQ-"`Q.#HQ,"LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z
M($%U=&]M871I8V%L;'D@9V5N97)A=&5D7&XB"B),86YG=6%G92U496%M.B!I
M,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*
M(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3=<;B(*
M(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A;"U&
M;W)M<SH@;G!L=7)A;',],SL@<&QU<F%L/2AN)3$P/3TQ("8F(&XE,3`P(3TQ
M,2`_(#`@.B!N("$](#`@/R`Q(#H@(@HB,BD[7&XB"@HC.B!F:6QT97)S+G!H
M<#HQ.#4*;7-G:60@(B!A;F0B"FUS9W-T<B`B('5N(@H*(SH@9FEL=&5R<RYP
M:'`Z,3@U"FUS9VED("(@;W(B"FUS9W-T<B`B('9A:2(*"B,Z('1E;7!L871E
M<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ-PIM<V=I9"`B06-T:6]N(&9O
M<B!B;&%C:VQI<W1E9"!A9&1R97-S97,Z(@IM<V=S='(@(D1A<F+N8F$@365L
M;N(@<V%R86MS=&$@861R97/G;3HB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C
M=&EV871E+FEN8SHQ,`IM<V=I9"`B06-T:79A=&4@4V-R:7!T(@IM<V=S='(@
M(D%K=&EVYW0@<VMR:7!T=2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C,R
M"B,L('!H<"UF;W)M870*;7-G:60@(D%C=&EV871I;F<@=&AE('-C<FEP="!F
M;W(@7"(E<UPB(&9A:6QE9#H@*"5D*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z-@IM<V=I9"`B061D:71I;VYA
M;"!3971T:6YG<R(*;7-G<W1R(")087!I;&1U<R!I97-T873N:G5M:2(*"B,Z
M('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#0*;7-G:60@(D%L;"!O9B!T
M:&4@9F]L;&]W:6YG(@IM<V=S='(@(E9I<VD@<V5K;VIO\&EE(@H*(SH@;&EB
M+V%P:2YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D%L;&]W(%)U;&5S(@IM<V=S
M='(@(DIA=6YS(&QI:W5M<R(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI
M;F,Z,S,*;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(D%T8FEL9.=T82(*"B,Z
M('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#4*;7-G:60@(D%N>2!O9B!T
M:&4@9F]L;&]W:6YG(@IM<V=S='(@(DIE8FMU<O`@;F\@<V5K;VIO\&EE;2(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z,3$*;7-G:60@(D%P
M<&QY($9I;'1E<G,B"FUS9W-T<B`B4&EE;&EE=&]T(&9I;'1R=7,B"@HC.B!F
M:6QT97)S+G!H<#HR,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!D96QE=&4@=&AI<R!R=6QE/R(*;7-G<W1R(")686D@=&EE\.)M(';G;&%T
M:65S(&1ZYW-T(/!O(&QI:W5M=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,*;7-G:60@(D%U=&]M871I8V%L;'D@=7!D871E('1H92!S8W)I<'0@
M869T97(@96%C:"!C:&%N9V4_(@IM<V=S='(@(D%U=&]MXG1I<VMI(&%T<W9A
M:61Z:6[B="!S:W)I<'1U('#G8R!K871R87,@:7IM86GR87,_(@H*(SH@8V]N
M9FEG+V9I96QD<RYP:'`N9&ES=#HT-PIM<V=I9"`B0F-C(@IM<V=S='(@(D)C
M8R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#0*;7-G:60@(D)E9VEN<R!W:71H
M(@IM<V=S='(@(E/B:V%S(&%R(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M,#8@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0FEN9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@9FEL=&5R
M<RYP:'`Z,30T('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHW
M"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`B365L;F%I<R!S87)A:W-T<R(*
M"B,Z(&)L86-K;&ES="YP:'`Z,3`P"FUS9VED(")";&%C:VQI<W0@161I="(*
M;7-G<W1R("),86)O="!-96QN;R!S87)A:W-T<R(*"B,Z(&)L86-K;&ES="YP
M:'`Z,3<*;7-G:60@(D)L86-K;&ES="!I<R!N;W0@<W5P<&]R=&5D(&EN('1H
M92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(E!A\')E:7KG
M:F%I<R!F:6QT<N?P86YA<R!D>FEN:7,@;F5A=&)A;'-T82!-96QN;R!S87)A
M:W-T=2XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR,#<@;&EB+U-C
M<FEP="]M86EL9')O<"YP:'`Z,3<U"FUS9VED(")";&%C:VQI<W1E9"!!9&1R
M97-S(@IM<V=S='(@(D%D<F5S92!N;R!-96QNXB!S87)A:W-T82(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C(T,PIM<V=I9"`B0FQA8VML:7-T960@061D
M<F5S<V5S(@IM<V=S='(@(DUE;&[B('-A<F%K<W1A(&%D<F5S97,B"@HC.B!C
M;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C@X"FUS9VED(")";V1Y(@IM<V=S='(@
M(LUE<FUE;FES(@H*(SH@9FEL=&5R<RYP:'`Z,3@R(')U;&4N<&AP.C(X,0IM
M<V=I9"`B0V%S92!396YS:71I=F4B"FUS9W-T<B`B4F7L:7-T<FIU=.YG<R(*
M"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-#,*;7-G:60@(D-C(@IM<V=S
M='(@(D-C(@H*(SH@<G5L92YP:'`Z,3(R('=H:71E;&ES="YP:'`Z,S8@9F]R
M=V%R9"YP:'`Z,S,@=F%C871I;VXN<&AP.C0Q"B,Z(&)L86-K;&ES="YP:'`Z
M-CD*;7-G:60@(D-H86YG97,@<V%V960N(@IM<V=S='(@(DEZ;6%I\F%S('-A
M9VQA8N)T87,N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-0IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS-#`*;7-G:60@(D-O;G1A:6YS(@IM<V=S='(@(E-A='5R(@H*(SH@
M9FEL=&5R<RYP:'`Z,C(U(&9I;'1E<G,N<&AP.C(R-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W!Y("5S(@IM<V=S='(@(DMO<.=T("5S(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C<V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&]F("5S
M(@IM<V=S='(@(B5S(&MO<&EJ82(*"B,Z(&QI8B]);F=O+G!H<#HU,@IM<V=I
M9"`B0W)E871E(&YE=R!F;VQD97(B"FUS9W-T<B`B27IV96ED;W0@:F%U;G4@
M;6%P:2(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C,S-B!L:6(O4V-R
M:7!T+VUA:6QD<F]P+G!H<#HR-SD*;7-G:60@(D1)4T%"3$5$.B`B"FUS9W-T
M<B`B25I33,='5%,Z("(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N
M:6YC.C$W"FUS9VED(")$96%C=&EV871E(%-C<FEP="(*;7-G<W1R(")$96%K
M=&EVYW0@<VMR:7!T=2(*"B,Z(&9I;'1E<G,N<&AP.C(Q-"!F:6QT97)S+G!H
M<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(@IM<V=S='(@
M(D1ZYW-T("5S(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHS,`IM
M<V=I9"`B1&5L971E($-O;F1I=&EO;B(*;7-G<W1R(")$>N?P86YA<R!N;W-A
M8^YJ=6US(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C(Y,@IM<V=I9"`B1&5L971E
M(&UE<W-A9V4@8V]M<&QE=&5L>2(*;7-G<W1R(")$>N=S="!VYW-T=6QI('!A
M=FES86TB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C,U"FUS9VED
M(")$96QE=&5D(@IM<V=S='(@(DEZ9'KG<W1A(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C(X,`IM<V=I9"`B1&5L:79E<B!I;G1O(&UY($E.0D]8(@IM<V=S='(@
M(DYO9^)DXG0@24Y"3U@B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S`V"FUS9VED
M(")$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(&-O<'D@=&\B"FUS9W-T<B`B
M3F]GXF3B="!)3D)/6"!U;B!K;W#G="!U>B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS,#$*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@<F5D:7)E
M8W0@=&\B"FUS9W-T<B`B3F]GXF3B="!)3D)/6"!U;B!PXG)A9')E<^=T(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C(X-@IM<V=I9"`B1&5L:79E<B!T;R!F;VQD
M97(B"FUS9W-T<B`B3F]GXF3B="!M87#G(@H*(SH@9FEL=&5R<RYP:'`Z,C0Q
M(&9I;'1E<G,N<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$:7-A8FQE
M("5S(@IM<V=S='(@(DEZ<VSG9W0@)7,B"@HC.B!T96UP;&%T97,O=VAI=&5L
M:7-T+W=H:71E;&ES="YI;F,Z,3`@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C
M:VQI<W0N:6YC.C$P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI
M;F,Z-B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHQ,`HC.B!T96UP
M;&%T97,O<G5L92]H96%D97(N:6YC.C(V"FUS9VED(")$:7-A8FQE9"(*;7-G
M<W1R("))>G-LYV=T<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S
M+FEN8SHQ,PIM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@
M=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/R(*;7-G<W1R(")087+B9.YT
M(&1E=&%L:7KG='4@<&%Z:?)O:G5M=2!PYV,@:V%T<F$@9FEL=')A('!I96QI
M971O\&%N87,_("(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI
M;F,Z,S0*;7-G:60@(D1O(%]N;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L:R!O
M<B!L:7-T(&UE<W-A9V5S(@IM<V=S='(@(DYE<_MT[G0@871B:6QD:2!U>B!V
M86ER=6TM('9A:2!VYW-T:V]P=2!VYW-T=6SG;2(*"B,Z('1E;7!L871E<R]R
M=6QE+V9O;W1E<BYI;F,Z,3`*;7-G:60@(D1O('1H:7,Z(@IM<V=S='(@(D1A
M<F+N8F$B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0U"FUS9VED(")$;V5S;B=T
M(&)E9VEN('=I=&@B"FUS9W-T<B`B3F5SXFMA<R!A<B(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-#$*;7-G:60@(D1O97-N)W0@8V]N=&%I;B(*;7-G<W1R(").
M97-A='5R(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-PIM<V=I9"`B1&]E<VXG
M="!E;F0@=VET:"(*;7-G<W1R(").96)E:61Z87,@87(B"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,S0Y"FUS9VED(")$;V5S;B=T(&5X:7-T(@IM<V=S='(@(DYE
M96MS:7-TYR(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3(*;7-G:60@(D1O97-N
M)W0@;6%T8V@@*'=I=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R(").96%T8FEL
M<W0@*&%R('9I971T=7)I96TI(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A
M9&5R+FEN8SHS,0IM<V=I9"`B161I="(*;7-G<W1R("),86)O="(*"B,Z(&9I
M;'1E<G,N<&AP.C(P,R!F:6QT97)S+G!H<#HR,#4@9FEL=&5R<RYP:'`Z,C`Y
M(&9I;'1E<G,N<&AP.C(Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET("5S
M(@IM<V=S='(@(DQA8F]T("5S(@H*(SH@9FEL=&5R<RYP:'`Z,C0U(&9I;'1E
M<G,N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%;F%B;&4@)7,B"FUS
M9W-T<B`B265S;.=G="`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E
M<BYI;F,Z,S<*;7-G:60@(D5N86)L960B"FUS9W-T<B`B265S;.=G=',B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S0V"FUS9VED(")%;F1S('=I=&@B"FUS9W-T
M<B`B0F5I9'IA<R!A<B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3<*;7-G:60@
M(D5Q=6%L('1O(@IM<V=S='(@(E9I96[B9',@87(B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C$S.2!L:6(O1')I=F5R+VQD87`N<&AP.C$T.2!L:6(O1')I
M=F5R+VQD87`N<&AP.C$U.`HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R971R:65V:6YG(&-U<G)E;G0@
M<V-R:7!T.B`H)60I("5S(@IM<V=S='(@(B(*"B,Z(&)L86-K;&ES="YP:'`Z
M-C<*;7-G:60@(D5R<F]R('-A=FEN9R!C:&%N9V5S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(R"FUS9VED(")%>&ES
M=&EN9R!2=6QE<R(*;7-G<W1R(")&:6QT<N?P86YA<R!L:6MU;6DB"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S0X"FUS9VED(")%>&ES=',B"FUS9W-T<B`B16MS
M:7-TYR(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30T"B,L('!H<"UF;W)M
M870*;7-G:60@(D5X<&5C=&5D(#$@;V)J96-T+"!G;W0@)60N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,`IM<V=I
M9"`B1FEL=&5R($%L;"!-97-S86=E<R(*;7-G<W1R(")&:6QT<N=T('9I<V%S
M(';G<W1U;&5S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC
M.C(R"FUS9VED(")&:6QT97(@3VYL>2!3965N($UE<W-A9V5S(@IM<V=S='(@
M(D9I;'1RYW0@=&EK86D@;&%S[G3B<R!VYW-T=6QE<R(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,0IM<V=I9"`B1FEL=&5R($]N;'D@
M56YS965N($UE<W-A9V5S(@IM<V=S='(@(D9I;'1RYW0@=&EK86D@;F5R961Z
MYW1A<R!VYW-T=6QE<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S
M+FEN8SHQ.`IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B1FEL=')U
M(&]P8VEJ87,B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C(U"FUS
M9VED(")&:6QT97(@4G5L92(*;7-G<W1R(")&:6QT<N?P86YA<R!L:6MU;7,B
M"@HC.B!F:6QT97)S+G!H<#HQ,#D*;7-G:60@(D9I;'1E<B!2=6QE<R(*;7-G
M<W1R(")&:6QT<N?P86YA<R!L:6MU;6DB"@HC.B!S8W)I<'0N<&AP.C4R"FUS
M9VED(")&:6QT97(@4V-R:7!T($1I<W!L87DB"FUS9W-T<B`B4&%RXF3N="!F
M:6QT<F$@<VMR:7!T=2(*"B,Z(&QI8B]);F=O+G!H<#HS,#`*;7-G:60@(D9I
M;'1E<B!?4G5L97,B"FUS9W-T<B`B1FEL='+G\&%N87,@;&EK=6UI(@H*(SH@
M;&EB+U-C<FEP="]I;6%P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!C;W!I
M960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D9I;'1RY_!A;F$Z
M("5S(';G<W1U;&4H<RD@;F]K;W#G=&$H<REU>B!M87!I(%PB)7-<(BXB"@HC
M.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,P-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&1E
M;&5T960N(@IM<V=S='(@(D9I;'1RY_!A;F$Z("5S(';G<W1U;&5S(&EZ9'KG
M<W1A*',I+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C@S"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A
M9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R(")&:6QT<N?P86YA.B`E<R!VYW-T=6QE*',I(&YO:V]PYW1A*',I
M=7H@;6%P:2!<(B5S7"(N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HQ.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S
M86=E*',I('1H870@;6%T8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@9&5L971E
M9"XB"FUS9W-T<B`B1FEL='+G\&%N83H@)7,@365L;F%J86T@<V%R86MS=&%M
M(&%T8FEL<W1O\&$H<RD@=N=S='5L92AS*2!I>F1ZYW-T87,N(@H*(SH@;&EB
M+U-C<FEP="]I;6%P+G!H<#HS,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S
M7"(@:&%S(&)E96X@8V]P:65D('1O('1H92`B"B)F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R(")&:6QT<N?P86YA.B!6YW-T=6QE(%PB)7-<(B!N;R!<(B5S7"(@
M;F]K;W#G=&$@=7H@;6%P:2!<(B5S7"(N(@H*(SH@;&EB+U-C<FEP="]I;6%P
M+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y
M.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B1FEL='+G\&%N83H@5N=S='5L92!<(B5S7"(@;F\@
M7"(E<UPB(&EZ9'KG<W1A+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D9I;'1E<B!A8W1I=FET>3H@5&AE
M(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&UO=F5D('1O
M('1H92!F;VQD97(@(@HB7"(E<UPB+B(*;7-G<W1R(")&:6QT<N?P86YA.B!6
MYW-T=6QE(%PB)7-<(B!N;R!<(B5S7"(@<.)R=FEE=&]T82!U>B!M87!I(%PB
M)7-<(BXB"@HC.B!R=6QE+G!H<#HQ-C`*;7-G:60@(D9I;'1E<B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D9I;'1R<R!N878@871R;V1A;7,B"@HC.B!T96UP;&%T
M97,O<G5L92]H96%D97(N:6YC.C0R"FUS9VED(")&;W(@86X@:6YC;VUI;F<@
M;65S<V%G92!T:&%T(&UA=&-H97,Z(@IM<V=S='(@(DEE;N)K;_!A:F%I(';G
M<W1U;&5I+"!K87,@871B:6QS=#HB"@HC.B!F:6QT97)S+G!H<#HQ-C(@=&5M
M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z.`IM<V=I9"`B1F]R=V%R9"(*
M;7-G<W1R(")0XG)S^W3N="(*"B,Z(&9O<G=A<F0N<&AP.C$V"FUS9VED(")&
M;W)W87)D(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R
M:6YG(&1R:79E<BXB"FUS9W-T<B`B4&'P<F5I>N=J86ES(&9I;'1RY_!A;F%S
M(&1Z:6YI<R!N96%T8F%L<W1A('#B<G/[=.[P86YU+B(*"B,Z(&QI8B]38W)I
M<'0O<')O8VUA:6PN<&AP.C(X,B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HR
M,C0*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E#B<G/[=.[P86YA<R(*"B,Z
M(&9O<G=A<F0N<&AP.C0V"FUS9VED(")&;W)W87)D<R!%9&ET(@IM<V=S='(@
M(DQA8F]T(%#B<G/[=.[P86YU(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES
M=#HS.0IM<V=I9"`B1G)O;2(*;7-G<W1R(")3^W3N=.)J<R(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS-34*;7-G:60@(D=R96%T97(@=&AA;B(*;7-G<W1R("),
M:65LXFMS('!A<B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-38*;7-G:60@(D=R
M96%T97(@=&AA;B!O<B!E<75A;"!T;R(*;7-G<W1R("),:65LXFMS('9A:2!V
M:65NXF1S(&%R(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,0IM
M<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(E-V87+N9V$B"@HC.B!R=6QE+G!H
M<#HS-@IM<V=I9"`B26YD:79I9'5A;"!R=6QE<R!A<F4@;F]T('-U<'!O<G1E
M9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")0
M8?!R96EZYVIA:7,@9FEL='+G\&%N87,@9'II;FES(&YE871B86QS=&$@:6YD
M:79I9'7B;'5S(&QI:W5M=7,N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,3@U-0IM<V=I9"`B26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F;W(@
M;65S<V%G92!D96QI=F5R>2XB"FUS9W-T<B`B3F]RXF3N=&$@;F5E:W-I<W3G
M:F_P82!P87-T:V%S=.YT92XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0R"FUS
M9VED("))<R(*;7-G<W1R("))<B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#,*
M;7-G:60@(DES;B=T(@IM<V=S='(@(DYA=B(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,C,*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B
M=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO
M861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,PIM<V=I
M9"`B3&5S<R!T:&%N(@IM<V=S='(@(DUA>N)K<R!P87(B"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,S4T"FUS9VED("),97-S('1H86X@;W(@97%U86P@=&\B"FUS
M9W-T<B`B36%ZXFMS('9A:2!V:65NXF1S(&%R(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HU.0IM<V=I9"`B3&ES="U)1"(*;7-G<W1R("),:7-T+4E$
M(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(P"FUS
M9VED(")-87)?:R!M97-S86=E(&%S(&1E;&5T960B"FUS9W-T<B`B071Z[FWG
M="!VYW-T=6QI(&OB(&EZ9'KG<W1U(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O
M=&5R+FEN8SHR-`IM<V=I9"`B36%R:R!M97-S86=E(&%S.B(*;7-G<W1R(")!
M='KN;>=T(';G<W1U;&D@:^(Z(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,0IM
M<V=I9"`B36%T8VAE<R`H=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S='(@(D%T
M8FEL<W0@*&%R('9I971T=7)I96TI(@H*(SH@;&EB+V%P:2YP:'`Z-3<*;7-G
M:60@(DUA>&EM=6T@3G5M8F5R(&]F(%)U;&5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X
M:6UU;2!N=6UB97(@;V8@8FQA8VML:7-T960@861D<F5S<V5S(&5X8V5E9&5D
M("A4;W1A;"!A9&1R97-S97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@
M)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O(&)L86-K;&ES
M="XB"FUS9W-T<B`B(@HB061R9?!U('-K86ET<R!-96QN86KB('-A<F%K<W3B
M(&EZ<VUE;'1S("A!9')E<V5S(&MO<.(Z("5S+"!M86MS:6WB;&%I<R`B"B)S
M:V%I=',Z("5S*2X@4&EE=FEE;F]T(&%D<F5S97,@365L;F%J86T@<V%R86MS
M=&%M('9A:7)S(&YA=B!I97-PYVIA;7,N(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C4S,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O
M9B!W:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E
M<W-E<SH@)7,L("(*(DUA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N
M;W0@861D(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+B(*;7-G<W1R("(B
M"B)!9')E\'4@<VMA:71S($)A;'1A:N(@<V%R86MS=.(@:7IS;65L=',@*$%D
M<F5S97,@:V]PXCH@)7,L(&UA:W-I;>)L86ES("(*(G-K86ET<SH@)7,I+B!0
M:65V:65N;W0@861R97-E<R!"86QT86IA;2!S87)A:W-T86T@=F%I<G,@;F%V
M(&EE<W#G:F%M<RXB"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-S(S"FUS
M9VED(")-:7-S:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G92!T;R(*
M;7-G<W1R(").878@;F]RXF3N=',L(&MA;2!PXG)A9')E<^=T(@H*(SH@;&EB
M+U-C<FEP="]S:65V92YP:'`Z,3<U-0IM<V=I9"`B36ES<VEN9R!R96%S;VX@
M9F]R(')E:F5C="(*;7-G<W1R(").878@;F]RXF3N=',@871T96EK=6UA(&EE
M;65S;',B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ.3(R"FUS9VED(")-
M:7-S:6YG(')E87-O;B!I;B!V86-A=&EO;BXB"FUS9W-T<B`B3F%V(&YO<N)D
M[G1S('!R;VUB^W1N97,@<&%S:V%I9')O:G5M<R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+VAE861E<BYI;F,Z-#`*;7-G:60@(DUO=F4B"FUS9W-T<B`B4.)R
M=FEE=&]T(@H*(SH@9FEL=&5R<RYP:'`Z,3(V(&9I;'1E<G,N<&AP.C(S.`IM
M<V=I9"`B36]V92!2=6QE($1O=VXB"FUS9W-T<B`B4.)R=FEE=&]T(&QE:G5P
M(@H*(SH@9FEL=&5R<RYP:'`Z,3(W(&9I;'1E<G,N<&AP.C(S-PIM<V=I9"`B
M36]V92!2=6QE(%5P(@IM<V=S='(@(E#B<G9I971O="!A=6?P=7`B"@HC.B!T
M96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C0R"FUS9VED(").7W5M
M8F5R(&]F(&1A>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S.B(*;7-G<W1R
M(")$:65N=2!S:V%I=',@<W1A<G`@8G+N=F1I96YU(&%T8FEL9&5S(&YO<_MT
M[O!A;G4Z(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+6YO;F4N:6YC
M.C0@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHX"B,Z(&QI8B]3=&]R
M86=E+G!H<#HW,30*;7-G:60@(DYE=R!2=6QE(@IM<V=S='(@(DIA=6YS(&QI
M:W5M<R(*"B,Z(&QI8B]);F=O+G!H<#HQ.30@;&EB+TEN9V\N<&AP.C$Y-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@7"(E<UPB(&5L96UE;G0@
M9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0<F]G
M<F%M;6%T^W+B(&YA=B!A=')A<W1S(&YE=FEE;G,@)R5S)R!E;&5M96YT<RXB
M"@HC.B!L:6(O26YG;RYP:'`Z,3DR"FUS9VED(").;R!B86-K96YD(&-O;F9I
M9W5R960@9F]R('1H:7,@:&]S="(*;7-G<W1R(").878@871R;V1A;7,@:V]N
M9FEG=7+G=',@9'II;FES(@H*(SH@;&EB+TEN9V\N<&AP.C$V.0IM<V=I9"`B
M3F\@8F%C:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K96YD<RYP:'`B"FUS9W-T
M<B`B1'II;FEE<R!N878@:V]N9FEG=7+G=',@8F%C:V5N9',N<&AP("(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHT"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!F:6QT97)S+B!#;&EC:R!<(B5S7"(@
M=&\@8W)E871E(&$@;F5W(&9I;'1E<BXB"FUS9W-T<B`B1FEL=')U(&YA=BX@
M3F]S<&EE9&EE="`G)7,G+"!L86D@<F%D[G1U(&IA=6YU(&9I;'1R=2XB"@HC
M.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ,S(W(&QI8B]38W)I<'0O<VEE=F4N
M<&AP.C$T,C`*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,34Y-`IM<V=I9"`B
M3F\@:&5A9&5R<R!S<&5C:69I960B"FUS9W-T<B`B3F%V(&YO<N)D[G1A(&YE
M=FEE;F$@9V%L=F5N92(*"B,Z('-C<FEP="YP:'`Z-C<*;7-G:60@(DYO('-C
M<FEP="!G96YE<F%T960N(@IM<V=S='(@(DYA=B#L96YE<N=T<R!N979I96YS
M('-K<FEP=',N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,38P.0IM<V=I
M9"`B3F\@<W1R:6YG<R!S<&5C:69I960B"FUS9W-T<B`B3F%V(&YO<N)D[G1S
M('1E:W-T<R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3@*;7-G:60@(DYO="!E
M<75A;"!T;R(*;7-G<W1R(").878@=FEE;N)D<R!A<B(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS,38*;7-G:60@(D]N;'D@9FQA9R!T:&4@;65S<V%G92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3D*;7-G:60@(D]P
M=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+B(*;7-G<W1R(")3:W)I<'1U
M(&%T:F%U;FENXO!A;F%S(&]P8VEJ87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3<*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B0VET87,@
M;W!C:6IA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VYE=U]F;VQD97(N
M:G,Z-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@
M9F]L9&5R.B(*;7-G<W1R("),^V1Z=2!I979A9&EE="!J875NXG,@;6%P97,@
M;F]S875K=6UU.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI
M;F,Z-C`*;7-G:60@(E)?96%S;VXB"FUS9W-T<B`B265M97-L<R(*"B,Z(&-O
M;F9I9R]F:65L9',N<&AP+F1I<W0Z-C,*;7-G:60@(E)E8V5I=F5D(@IM<V=S
M='(@(E-A\F5M=&$B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,CDW"FUS9VED(")2
M961I<F5C="!T;R(*;7-G<W1R(")0XG)A9')E<^=T(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,U,`IM<V=I9"`B4F5G=6QA<B!E>'!R97-S:6]N(@IM<V=S='(@
M(DQO[&ES:^)S(&EZ=&5I:W-M97,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S$R
M"FUS9VED(")296IE8W0@=VET:"!R96%S;VXB"FUS9W-T<B`B071T96EK="!A
M<B!I96UE<VQU(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU-0IM<V=I
M9"`B4F5S96YT(%1O(@IM<V=S='(@(E#B<G/[=.YT<R(*"B,Z(&-O;F9I9R]F
M:65L9',N<&AP+F1I<W0Z-3$*;7-G:60@(E)E<V5N="UF<F]M(@IM<V=S='(@
M(E#B<G/[=.YT<R!N;R(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z
M-C`*;7-G:60@(E)E='5R;B!T;R!&:6QT97)S($QI<W0B"FUS9W-T<B`B071G
M<FEE>G1I97,@<&EE(&9I;'1R=2!S87)A:W-T82(*"B,Z('1E;7!L871E<R]W
M:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR-"!T96UP;&%T97,O8FQA8VML:7-T
M+V)L86-K;&ES="YI;F,Z-#$*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T
M:6]N+FEN8SHW,2!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHS-`IM
M<V=I9"`B4F5T=7)N('1O(%)U;&5S($QI<W0B"FUS9W-T<B`B071G<FEE>G1I
M97,@<&EE(&QI:W5M=2!S87)A:W-T82(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+VAE861E<BYI;F,Z,S0*;7-G:60@(E)U;&4B"FUS9W-T<B`B3&EK=6US(@H*
M(SH@9FEL=&5R<RYP:'`Z-C`*;7-G:60@(E)U;&4@0V]P:65D(@IM<V=S='(@
M(DQI:W5M<R!N;VMO<.=T<R(*"B,Z(&9I;'1E<G,N<&AP.C,Y"FUS9VED(")2
M=6QE($1E;&5T960B"FUS9W-T<B`B3&EK=6US(&EZ9'KG<W1S(@H*(SH@9FEL
M=&5R<RYP:'`Z-S8*;7-G:60@(E)U;&4@1&ES86)L960B"FUS9W-T<B`B3&EK
M=6US(&EZ<VSG9W1S(@H*(SH@9FEL=&5R<RYP:'`Z.#$*;7-G:60@(E)U;&4@
M16YA8FQE9"(*;7-G<W1R("),:6MU;7,@:65S;.=G=',B"@HC.B!T96UP;&%T
M97,O<G5L92]H96%D97(N:6YC.C,S"FUS9VED(")2=6QE($YA;64B"FUS9W-T
M<B`B3&EK=6UA(&YO<V%U:W5M<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D.B`H)7,I
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L
M:7-T+FEN8SHR,R!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M-#`*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHW,"!T96UP
M;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHS,PHC.B!T96UP;&%T97,O<G5L
M92]F;V]T97(N:6YC.C4Y"FUS9VED(")3879E(@IM<V=S='(@(E-A9VQA8N)T
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(Y"FUS9VED
M(")3879E(%-E='1I;F=S(@IM<V=S='(@(E-A9VQA8N)T(&]P8VEJ87,B"@HC
M.B!T96UP;&%T97,O<V-R:7!T+VAE861E<BYI;F,Z,@IM<V=I9"`B4V-R:7!T
M(@IM<V=S='(@(E-K<FEP=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*;7-G<W1R(")3:W)I<'1A(&%T
M:F%U;FENXO!A;F$B"@HC.B!L:6(O26YG;RYP:'`Z,C$W"FUS9VED(")38W)I
M<'0@;F]T('5P9&%T960N(@IM<V=S='(@(E-K<FEP=',@;F%V(&%T:F%U;FEN
MXG1S(@H*(SH@;&EB+TEN9V\N<&AP.C$S,`IM<V=I9"`B4V-R:7!T('-U8V-E
M<W-F=6QL>2!A8W1I=F%T960N(@IM<V=S='(@(E-K<FEP=',@=F5I:W-M[F=I
M(&%K=&EVYW1S+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,CD*;7-G:60@(E-C<FEP
M="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-K<FEP=',@
M=F5I:W-M[F=I(&1E86MT:7;G=',N(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O
M=&5R+FEN8SHR.0IM<V=I9"`B4V5E;B(*;7-G<W1R(")2961ZYW1A(@H*(SH@
M<G5L92YP:'`Z,3DP"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R("))
M>G;G;&EE=&EE<R!L875K=2(*"B,Z(&QI8B]);F=O+G!H<#HT.0IM<V=I9"`B
M4V5L96-T('1A<F=E="!F;VQD97(B"FUS9W-T<B`B:7IVYVSG=&EE<R!M87!I
M(@H*(SH@<G5L92YP:'`Z,C(W"FUS9VED(")396QF+41E9FEN960@2&5A9&5R
M(@IM<V=S='(@(E!A\&1E9FENYW1A(&=A;'9E;F4B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C,U"FUS9VED(")396YD97(B"FUS9W-T<B`B4_MT[G3B
M:G,B"@HC.B!F:6QT97)S+G!H<#HY-0IM<V=I9"`B4V5T=&EN9W,@<W5C8V5S
M<V9U;&QY('5P9&%T960N(@IM<V=S='(@(DEE<W1A=.YJ=6UI('9E:6MS;>YG
M:2!A=&IA=6YI;N)T:2XB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E
M+FEN8SHR-`IM<V=I9"`B4VAO=R!!8W1I=F4@4V-R:7!T(@IM<V=S='(@(E+B
M9.YT(&%K=.YV;W,@<VMR:7!T=7,B"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C
M=&EV871E+FEN8SHS,0IM<V=I9"`B4VAO=R!#=7)R96YT(%-C<FEP="(*;7-G
M<W1R(")2XF3N="!P8?!R96EZYVIO('-K<FEP='4B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C@S"FUS9VED(")3:7IE(@IM<V=S='(@(DEZ;>=R<R(*
M"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-#D*;7-G:60@(E-T;W`@
M8VAE8VMI;F<@:68@=&AI<R!R=6QE(&UA=&-H97,_(@IM<V=S='(@(E#B<G1R
M875K="!PXG)B875D:2P@:F$@\&ES(&QI:W5M<R!I>G!I;&3B<S\B"@HC.B!T
M96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C4Q"FUS9VED(")3=6)J
M95]C="!O9B!V86-A=&EO;B!M97-S86=E.B(*;7-G<W1R(")"<NYV9&EE;G4@
M<&%Z:?)O:G5M82!T96UA=',B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T
M.C,Q"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E1E;6%T<R(*"B,Z(&QI8B]A
M<&DN<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(%PB
M)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&)L86-K;&ES="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3`T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!A9&1R97-S(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('=H
M:71E;&ES="XB"FUS9W-T<B`B(@H*(SH@;&EB+TEN9V\N<&AP.C$R-0IM<V=I
M9"`B5&AE(&1R:79E<B!S86ED.B`B"FUS9W-T<B`B1'II;FES('!A>FGR;VIA
M.B(*"B,Z(&QI8B]);F=O+G!H<#HQ,C0*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!A8W1I=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@(DOO^V1A(&%K
M=&EVYVIO="!S:W)I<'1U+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,C,*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D96%C=&EV871I;F<@=&AE('-C<FEP="XB
M"FUS9W-T<B`B2^_[9&$@9&5A:W1I=N=J;W0@<VMR:7!T=2XB"@HC.B!C;VYF
M:6<O9FEE;&1S+G!H<"YD:7-T.C(W"FUS9VED(")4;R(*;7-G<W1R(")38?+G
M;>=J<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BYH=&UL.C(X"B,L
M(&9U>GIY"FUS9VED(")4;SHB"FUS9W-T<B`B4V'RYVWG:G,B"@HC.B!L:6(O
M4V-R:7!T+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DYE=F%R(&EE
M;&%S[G0@)7,@;F]S86/N:G5M=7,N(@H*(SH@9FEL=&5R<RYP:'`Z,34V('1E
M;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-0HC.B!L:6(O4V-R:7!T
M+W!R;V-M86EL+G!H<#HR-C(*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D)R
M[G9D:65N87,B"@HC.B!V86-A=&EO;BYP:'`Z-S(*;7-G:60@(E9A8V%T:6]N
M($5D:70B"FUS9W-T<B`B3&%B;W0@0G+N=F1I96YU('!A>FGR;VIU;74B"@HC
M.B!L:6(O4V-R:7!T+W-I979E+G!H<#HS-3$*;7-G:60@(E9A8V%T:6]N($UE
M<W-A9V4B"FUS9W-T<B`B0G+N=F1I96YU('!A>FGR;VIU;7,B"@HC.B!V86-A
M=&EO;BYP:'`Z,38*;7-G:60@(E9A8V%T:6]N(&ES(&YO="!S=7!P;W)T960@
M:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B4&'P
M<F5I>N=J86ES(&9I;'1RY_!A;F%S(&1Z:6YI<R!N96%T8F%L<W1A(&)R[G9D
M:65N=2!P87II\O1J=6UU<RXB"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H
M:71E;&ES="YI;F,Z,38*;7-G:60@(E=H7VET96QI<W0@861D<F5S<V5S.B(*
M;7-G<W1R(")"86QTXB!S87)A:W-T82!A9')E<V5S(@H*(SH@9FEL=&5R<RYP
M:'`Z,34P('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHX"FUS
M9VED(")7:&ET96QI<W0B"FUS9W-T<B`B0F%L=&%I<R!S87)A:W-T<R(*"B,Z
M('=H:71E;&ES="YP:'`Z-34*;7-G:60@(E=H:71E;&ES="!%9&ET(@IM<V=S
M='(@(DQA8F]T($)A;'1O('-A<F%K<W1U(@H*(SH@=VAI=&5L:7-T+G!H<#HQ
M.`IM<V=I9"`B5VAI=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U
M<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B4&'P<F5I>N=J86ES
M(&9I;'1RY_!A;F%S(&1Z:6YI<R!N96%T8F%L<W1A($)A;'1O('-A<F%K<W1U
M+B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(S-"!L:6(O4V-R:7!T
M+W-I979E+G!H<#HR.3<*(SH@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,C`R
M"FUS9VED(")7:&ET96QI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B0F%L=.(@
M<V%R86MS=&$@861R97-E<R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z
M-SD*;7-G:60@(E@M4')I;W)I='DB"FUS9W-T<B`B6"U0<FEO<FET>2(*"B,Z
M(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-C<*;7-G:60@(E@M4W!A;2U,979E
M;"(*;7-G<W1R(")8+5-P86TM3&5V96PB"@HC.B!C;VYF:6<O9FEE;&1S+G!H
M<"YD:7-T.C<Q"FUS9VED(")8+5-P86TM4V-O<F4B"FUS9W-T<B`B6"U3<&%M
M+5-C;W)E(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW-0IM<V=I9"`B
M6"U3<&%M+5-T871U<R(*;7-G<W1R(")8+5-P86TM4W1A='5S(@H*(SH@9FEL
M=&5R<RYP:'`Z-3,@<G5L92YP:'`Z,30T"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!R
M=6QE<RXB"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z-#4@<G5L92YP:'`Z
M,C$*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&]R(&5D
M:70@8W5S=&]M(')U;&5S+B(*;7-G<W1R("(B"@HC.B!V86-A=&EO;BYP:'`Z
M,S`*;7-G:60@(B(*(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&5M
M86EL(&%D9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M97-S86=E<R`B
M"B)S:&]U;&0@8F4@86-T:79A=&5D+B(*;7-G<W1R("(B"B)*XFYO<N)D82!V
M:7-M87H@=FEE;F$@92UP87-T82!A9')E<V4L(&MU<F%I(&%K=&EVYW0@0G+N
M=F1I96YU('!A>FGR;VIU;75S+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z
M,C<X(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S`Q(&QI8B]38W)I<'0O:6UA<"YP
M:'`Z,S$U"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6T)E>B!T96UA
M=&%=(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,C0*;7-G
M:60@(E]!9&1R97-S*&5S*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R(")!9')E
M<V4H<RD@<.)R<_MT[O!A;F%I.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V
M86-A=&EO;BYI;F,Z,C,*;7-G:60@(E]!9&1R97-S97,@=&\@;F]T('-E;F0@
M<F5S<&]N<V5S('1O.B(*;7-G<W1R(")!9')E<V5S+"!K=7+B;2!N97/[=.YT
M(&%T8FEL9&5S.B(*"B,Z(&QI8B]);F=O+G!H<#HS,#4*;7-G:60@(E]";&%C
M:VQI<W0B"FUS9W-T<B`B365L;F%I<R!S87)A:W-T<R(*"B,Z('1E;7!L871E
M<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ.`IM<V=I9"`B7T1E;&5T92!M
M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`B1'KG<W0@=N=S='5L:2(*"B,Z
M('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHS,0IM<V=I9"`B
M7T5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE.B(*;7-G<W1R(")+
M871R=2!A9')E<VD@:65V861I970@:F%U;N(@<FEN9.(Z(@H*(SH@;&EB+TEN
M9V\N<&AP.C,Q,0IM<V=I9"`B7T9O<G=A<F0B"FUS9W-T<B`B4.)R<_MT[G0B
M"@HC.B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHQ-PIM<V=I9"`B
M7TME97`@82!C;W!Y(&]F(&UE<W-A9V5S(&EN('1H:7,@86-C;W5N=#\B"FUS
M9W-T<B`B4V%G;&%BXG0@=N=S='7O=2!K;W!I:F%S(/!A:N(@:V]N=.(_(@H*
M(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(R"FUS9VED
M(")?36]V92!M97-S86=E('1O(&9O;&1E<CHB"FUS9W-T<B`B4.)R=FEE=&]T
M(';G<W1U;&5S('5Z(&UA<&DZ(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A
M8V%T:6]N+FEN8SHQ,PIM<V=I9"`B7TUY(&5M86EL(&%D9')E<W-E<SHB"FUS
M9W-T<B`B2OMS=2!E+7!A<W1A(&%D<F5S93HB"@HC.B!L:6(O26YG;RYP:'`Z
M,S$T"FUS9VED(")?4V-R:7!T(@IM<V=S='(@(E-K<FEP=',B"@HC.B!L:6(O
M26YG;RYP:'`Z,S`X"FUS9VED(")?5F%C871I;VXB"FUS9W-T<B`B0G+N=F1I
M96YA<R(*"B,Z(&QI8B]);F=O+G!H<#HS,#(*;7-G:60@(E]7:&ET96QI<W0B
M"FUS9W-T<B`B0F%L=&%I<R!S87)K<W1S(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M9FEL=&5R+FEN8SHT"FUS9VED(")A;F0B"FUS9W-T<B`B=6XB"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]F:6QT97(N:'1M;#HQ-@IM<V=I9"`B9&ES86)L960@
M+2!C;&EC:R!T;R!E;F%B;&4B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z
M,3@P"FUS9VED(")F:65L9"(*;7-G<W1R(")L875K<R(*"B,Z(&QI8B]38W)I
M<'0O;6%I;&1R;W`N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B;6%I;&1R;W`@
M<V-R:7!T(&=E;F5R871E9"!B>2!);F=O(@IM<V=S='(@(DYA=B#L96YE<N=T
M<R!N979I96YS('-K<FEP=',N(@H*(SH@9FEL=&5R<RYP:'`Z,3@P"FUS9VED
M(")M871C:"(*;7-G<W1R(")A=&)I;'-T(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M9FEL=&5R+FEN8SHT"B,L(&9U>GIY"FUS9VED(")O<B(*;7-G<W1R("(@=F%I
M(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,3(X"B,L(&9U>GIY"FUS
M9VED(")P<F]C;6%I;"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\B"FUS9W-T
M<B`B3F%V(.QE;F5RYW1S(&YE=FEE;G,@<VMR:7!T<RXB"@HC.B!L:6(O4V-R
M:7!T+W-I979E+G!H<#HQ,#D*;7-G:60@(G-I979E(&9I;'1E<B!G96YE<F%T
M960@8GD@26YG;R(*;7-G<W1R("(B"@``````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O
M+W!O+W!L7U!,+G!O````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#0T-S$W`#$P-#$W,S8R-S0W`#`Q-S,V,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````C($QA;F=U86=E(&YW
M('1R86YS;&%T:6]N<R!F;W(@26YG;R!P86-K86=E+@HC($-O<'ER:6=H="`H
M0RD@,C`P,R!(;W)D92!0<F]J96-T"B,@0V]P>7)I9VAT("A#*2`R,#`U($MR
M>GES>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#X*(R!4:&ES(&9I;&4@
M:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@
M26YG;R!P86-K86=E+@HC($%U=&]M871I8V%L;'D@9V5N97)A=&5D+"`R,#`S
M+@HC($MR>GES>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#XL(#(P,#4N
M"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($EN
M9V\@:#,M,2XP+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,2TR
M-"`R,#HQ.2LP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`U+3$Q+3(T
M(#(P.C,S*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2W)Z>7-Z=&]F($MO
M>FQO=W-K:2`\:V]Z:6LQ0&\R+G!L/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X
M;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,EQN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9FEL
M=&5R<RYP:'`Z,38W"FUS9VED("(@86YD(@IM<V=S='(@(B!I(@H*(SH@9FEL
M=&5R<RYP:'`Z,38W"FUS9VED("(@;W(B"FUS9W-T<B`B(&QU8B(*"B,Z('1E
M;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ.0IM<V=I9"`B06-T
M:6]N(&9O<B!B;&%C:VQI<W1E9"!A9&1R97-S97,Z(@IM<V=S='(@(D%K8VIA
M(&1L82!A9')E\W=Y(&YA(&-Z87)N96H@;&FV8VEE.B(*"B,Z('1E;7!L871E
M<R]S8W)I<'0O86-T:79A=&4N:6YC.C$P"FUS9VED(")!8W1I=F%T92!38W)I
M<'0B"FUS9W-T<B`B06MT>7=U:B!S:W)Y<'0B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]S971T:6YG<RYI;F,Z.0IM<V=I9"`B061D:71I;VYA;"!3971T:6YG
M<R(*;7-G<W1R(")$;V1A=&MO=V4@=7-T87=I96YI82(*"B,Z('1E;7!L871E
M<R]R=6QE+VAE861E<BYI;F,Z-3,*;7-G:60@(D%L;"!O9B!T:&4@9F]L;&]W
M:6YG(@IM<V=S='(@(EIA<W1O<V]W86YI92!W<WIY<W1K:6-H('!O;FF_<WIY
M8V@@<F5G=;,B"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C0T"FUS
M9VED(")!;G-W97)E9"(*;7-G<W1R(")/9'!O=VEE9'II86YE(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHU-@IM<V=I9"`B06YY(&]F('1H92!F
M;VQL;W=I;F<B"FUS9W-T<B`B0WKJMF-I('H@;FEC:"(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+V9O;W1E<BYI;F,Z,38*;7-G:60@(D%P<&QY($9I;'1E<G,B
M"FUS9W-T<B`B6F%S=&]S=6H@9FEL=')Y(@H*(SH@9FEL=&5R<RYP:'`Z,3DV
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@
M<G5L93\B"FUS9W-T<B`B0WIY(&YA('!E=VYO(&-H8V5S>B!U<W5NL>8@=.H@
M<F5G=;/J/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B
M075T;VUA=&EC86QL>2!U<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H
M86YG93\B"FUS9W-T<B`B075T;VUA='EC>FYI92!U86MT=6%L;FEAYB!S:W)Y
M<'0@<&\@:V&_9&5J('IM:6%N:64_(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HT-PIM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS,S<*;7-G:60@(D)E9VEN<R!W:71H(@IM<V=S='(@(EIA8WIY
M;F%JL6-E('-IZB!O9"(*"B,Z(&9I;'1E<G,N<&AP.C$R-B!T96UP;&%T97,O
M8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z.`IM<V=I9"`B0FQA8VML:7-T(@IM
M<V=S='(@(D-Z87)N82!L:7-T82(*"B,Z(&)L86-K;&ES="YP:'`Z,3`P"FUS
M9VED(")";&%C:VQI<W0@161I="(*;7-G<W1R(")%9'EC:F$@8WIA<FYE:B!L
M:7-T>2(*"B,Z(&)L86-K;&ES="YP:'`Z,3<*;7-G:60@(D)L86-K;&ES="!I
M<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV
M97(N(@IM<V=S='(@(D-Z87)N82!L:7-T82!N:64@:F5S="!O8G.S=6=I=V%N
M82!P<GIE>B!O8F5C;GD@<W1E<F]W;FEK(&9I;'1R;W=A;FEA+B(*"B,Z(&QI
M8B]38W)I<'0O<')O8VUA:6PN<&AP.C(P,@IM<V=I9"`B0FQA8VML:7-T960@
M061D<F5S<R(*;7-G<W1R(")!9')E<R!N82!C>F%R;F5J(&QIMF-I92(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(T,@IM<V=I9"`B0FQA8VML:7-T960@
M061D<F5S<V5S(@IM<V=S='(@(D%D<F5S>2!N82!C>F%R;F5J(&QIMF-I92(*
M"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z.#@*;7-G:60@(D)O9'DB"FUS
M9W-T<B`B5')EMN8B"@HC.B!R=6QE+G!H<#HR,S<@9FEL=&5R<RYP:'`Z,38T
M"FUS9VED(")#87-E(%-E;G-I=&EV92(*;7-G<W1R(")3LV%D;FEA(@H*(SH@
M8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HT,PIM<V=I9"`B0V,B"FUS9W-T<B`B
M0V,B"@HC.B!V86-A=&EO;BYP:'`Z-#$@8FQA8VML:7-T+G!H<#HV.2!R=6QE
M+G!H<#HQ,#0@=VAI=&5L:7-T+G!H<#HS-@HC.B!F;W)W87)D+G!H<#HS,PIM
M<V=I9"`B0VAA;F=E<R!S879E9"XB"FUS9W-T<B`B6FUI86YY('IA<&ES86YE
M+B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,S,*;7-G:60@(D-O;G1A:6YS(@IM
M<V=S='(@(EIA=VEE<F$B"@HC.B!F:6QT97)S+G!H<#HR,#0@9FEL=&5R<RYP
M:'`Z,C`U"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@)7,B"FUS9W-T<B`B
M2V]P:75J("5S(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C<U-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W!Y(&]F("5S(@IM<V=S='(@(E-K;W!I;W=A;F\@>B`E
M<R(*"B,Z(&QI8B]);F=O+G!H<#HU,@IM<V=I9"`B0W)E871E(&YE=R!F;VQD
M97(B"FUS9W-T<B`B571W\W)Z(&YO=WD@9F]L9&5R(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O9FEL=&5R+FAT;6PZ,38*;7-G:60@(D1)4T%"3$5$(@IM<V=S
M='(@(E=9HZ%#6D].12(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C,S
M-PIM<V=I9"`B1$E304),140Z("(*;7-G<W1R(")76:-!0UI/3D4Z("(*"B,Z
M('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$W"FUS9VED(")$96%C
M=&EV871E(%-C<FEP="(*;7-G<W1R(")$96%K='EW=6H@<VMR>7!T(@H*(SH@
M9FEL=&5R<RYP:'`Z,3DV(&9I;'1E<G,N<&AP.C$Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@)7,B"FUS9W-T<B`B57-U\2`E<R(*"B,Z('1E;7!L
M871E<R]R=6QE+V9I;'1E<BYI;F,Z,S`*;7-G:60@(D1E;&5T92!#;VYD:71I
M;VXB"FUS9W-T<B`B4F5G=;-A('5S=7=A;FEA(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C(Y,0IM<V=I9"`B1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L>2(*;7-G
M<W1R(")5<W7Q(&-ALVMO=VEC:64@=VEA9&]M;[;F(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O9F]O=&5R+FEN8SHT-PIM<V=I9"`B1&5L971E9"(*;7-G<W1R(")5
M<W5N:>IT;R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR-SD*;7-G:60@(D1E;&EV
M97(@:6YT;R!M>2!)3D)/6"(*;7-G<W1R(")0<GIEMFQI:B!N82!M;VJQ('-K
M<GIY;FOJ(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,P-0IM<V=I9"`B1&5L:79E
M<B!I;G1O(&UY($E.0D]8(&%N9"!C;W!Y('1O(@IM<V=S='(@(E!R>F6V;&EJ
M(&YA(&UO:K$@<VMR>GEN:^H@:2!S:V]P:75J(&1O(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,P,`IM<V=I9"`B1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R
M961I<F5C="!T;R(*;7-G<W1R(")0<GIEMFQI:B!N82!M;VJQ('-K<GIY;FOJ
M(&D@<')Z96MI97)U:B!D;R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.#4*;7-G
M:60@(D1E;&EV97(@=&\@9F]L9&5R(@IM<V=S='(@(E!R>F5N:66V(&1O(&9O
M;&1E<G4B"@HC.B!F:6QT97)S+G!H<#HR,3@@9FEL=&5R<RYP:'`Z,C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D1I<V%B;&4@)7,B"FUS9W-T<B`B5WFSL6-Z
M("5S(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C$P
M('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z.0HC.B!T96UP;&%T
M97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z.2!T96UP;&%T97,O9F]R=V%R
M9"]F;W)W87)D+FEN8SHY"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z
M,S`*;7-G:60@(D1I<V%B;&5D(@IM<V=S='(@(E=YL[%C>F]N92(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHR,0IM<V=I9"`B1&ES<&QA
M>2!D971A:6QE9"!N;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A
M<'!L:65D/R(*;7-G<W1R(")7>;9W:65T;&'F(&1O:[-A9&YE('!O=VEA9&]M
M:65N:64@<')Z>2!UOWEC:74@:V&_9&5G;R!F:6QT<G4_(@H*(SH@=&5M<&QA
M=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHS.`IM<V=I9"`B1&\@7VYO="!S
M96YD(')E<W!O;G-E<R!T;R!B=6QK(&]R(&QI<W0@;65S<V%G97,B"FUS9W-T
M<B`B7TYI92!W>7-YLV%J(&]D<&]W:65D>FD@;F$@;&ES='D@;6%S;W=E(&D@
M9W)U<'D@<W5B<VMR>7!C>6IN92(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E
M<BYI;F,Z,3`*;7-G:60@(D1O('1H:7,Z(@IM<V=S='(@(E=Y:V]N86HZ(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,S.`IM<V=I9"`B1&]E<VXG="!B96=I;B!W
M:71H(@IM<V=S='(@(DYI92!Z86-Z>6YA('-IZB!O9"(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS,S0*;7-G:60@(D1O97-N)W0@8V]N=&%I;B(*;7-G<W1R(").
M:64@>F%W:65R82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#`*;7-G:60@(D1O
M97-N)W0@96YD('=I=&@B"FUS9W-T<B`B3FEE(&MO\6-Z>2!S:>H@;F$B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S0R"FUS9VED(")$;V5S;B=T(&5X:7-T(@IM
M<V=S='(@(DYI92!W>7-TZG!U:F4B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0U
M"FUS9VED(")$;V5S;B=T(&UA=&-H("AW:71H('!L86-E:&]L9&5R<RDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR,`IM
M<V=I9"`B161I="(*;7-G<W1R(")%9'ET=6HB"@HC.B!F:6QT97)S+G!H<#HQ
M.#4@9FEL=&5R<RYP:'`Z,3@W(&9I;'1E<G,N<&AP.C$Y,2!F:6QT97)S+G!H
M<#HQ.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R(")%
M9'ET=6H@)7,B"@HC.B!F:6QT97)S+G!H<#HR,C(@9FEL=&5R<RYP:'`Z,C(S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5N86)L92`E<R(*;7-G<W1R(")7L[%C
M>B`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C(*;7-G
M:60@(D5N86)L960B"FUS9W-T<B`B5[.Q8WIO;F4B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S,Y"FUS9VED(")%;F1S('=I=&@B"FUS9W-T<B`B2V_Q8WJQ8V4@
M<VGJ(&YA(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,`HC+"!F=7IZ>0IM<V=I
M9"`B17%U86P@=&\B"FUS9W-T<B`B4O-W;F4B"@HC.B!B;&%C:VQI<W0N<&AP
M.C8W"FUS9VED(")%<G)O<B!S879I;F<@8VAA;F=E<RXB"FUS9W-T<B`B0K.Q
M9"!P<GIY('IA<&ES>7=A;FEU('IM:6%N+B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+VAE861E<BYI;F,Z-PIM<V=I9"`B17AI<W1I;F<@4G5L97,B"FUS9W-T
M<B`B06MT=6%L;F4@<F5G=;-Y(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T,0IM
M<V=I9"`B17AI<W1S(@IM<V=S='(@(E=S>73J<'5J92(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W-E='1I;F=S+FEN8SHS,`IM<V=I9"`B1FEL=&5R($%L;"!-
M97-S86=E<R(*;7-G<W1R(")&:6QT<G5J('=S>GES=&MI92!W:6%D;VUOMF-I
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C,R"FUS9VED
M(")&:6QT97(@3VYL>2!3965N($UE<W-A9V5S(@IM<V=S='(@(D9I;'1R=6H@
M='EL:V\@=VED>FEA;F4@=VEA9&]M;[9C:2(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W-E='1I;F=S+FEN8SHS,0IM<V=I9"`B1FEL=&5R($]N;'D@56YS965N
M($UE<W-A9V5S(@IM<V=S='(@(D9I;'1R=6H@='EL:V\@;FEE=VED>FEA;F4@
M=VEA9&]M;[9C:2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN
M8SHR.`IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B3W!C:F4@9FEL
M=')O=V%N:6$B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C(X"FUS
M9VED(")&:6QT97(@4G5L92(*;7-G<W1R(")296=ULV$@1FEL=')O=V%N:6$B
M"@HC.B!F:6QT97)S+G!H<#HY,@IM<V=I9"`B1FEL=&5R(%)U;&5S(@IM<V=S
M='(@(E)E9W6S>2!&:6QT<F]W86YI82(*"B,Z('-C<FEP="YP:'`Z-3(*(RP@
M9G5Z>GD*;7-G:60@(D9I;'1E<B!38W)I<'0@1&ES<&QA>2(*;7-G<W1R(")/
M<&-J92!F:6QT<F]W86YI82(*"B,Z(&QI8B]);F=O+G!H<#HR-C<*;7-G:60@
M(D9I;'1E<B!?4G5L97,B"FUS9W-T<B`B7U)E9W6S>2!&:6QT<F]W86YI82(*
M"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@
M8V]P:65D('1O('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")$>FEALV%N
M:64@9FEL=')U.B!S:V]P:6]W86YO("5S('=I861O;6^V8VD@9&\@9F]L9&5R
M=2!<(B5S7"(N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I
M(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")$>FEALV%N:64@9FEL=')U
M.B!U<W5N:>IT;R`E<R!W:6%D;VUOMF-I+B(*"B,Z(&QI8B]38W)I<'0O:6UA
M<"YP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET
M>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@;6]V960@=&\@=&AE(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(D1Z:6&S86YI92!F:6QT<G4Z('!R>F5N:65S
M:6]N;R`E<R!W:6%D;VUOMF-I(&1O(&9O;&1E<G4@7"(E<UPB+B(*"B,Z(&QI
M8B]38W)I<'0O:6UA<"YP:'`Z,3@V"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!T:&%T(&UA=&-H960@=&AE
M(&)L86-K;&ES="!W97)E(&1E;&5T960N(@IM<V=S='(@(D1Z:6&S86YI92!F
M:6QT<G4Z('-K87-O=V%N;R`E<R!W:6%D;VUOMF-I('!A<W5JL6-Y8V@@9&\@
M8WIA<FYE:B!L:7-T>2XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I960@=&\@
M=&AE("(*(F9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*(D1Z:6&S86YI92!F
M:6QT<G4Z(%=I861O;6^VYB!<(B5S7"(@;V0@7"(E<UPB('IO<W1ALV$@<VMO
M<&EO=V%N82!D;R!F;VQD97)U("(*(EPB)7-<(BXB"@HC.B!L:6(O4V-R:7!T
M+VEM87`N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T
M:79I='DZ(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")$>FEALV%N:64@9FEL=')U.B!7:6%D;VUO
MMN8@7"(E<UPB(&]D(%PB)7-<(B!Z;W-T8;-A('-K87-O=V%N82XB"@HC.B!L
M:6(O4V-R:7!T+VEM87`N<&AP.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB
M)7-<(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R("(*(EPB)7-<(BXB
M"FUS9W-T<B`B(@HB1'II8;-A;FEE(&9I;'1R=3H@5VEA9&]M;[;F(%PB)7-<
M(B!O9"!<(B5S7"(@>F]S=&&S82!P<GIE;FEE<VEO;F$@9&\@9F]L9&5R=2`B
M"B)<(B5S7"(N(@H*(SH@<G5L92YP:'`Z,3,R"FUS9VED(")&:6QT97(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")&:6QT<B!N:65Z;F%L97II;VYY+B(*"B,Z('1E
M;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#@*;7-G:60@(D9O<B!A;B!I;F-O
M;6EN9R!M97-S86=E('1H870@;6%T8VAE<SHB"FUS9W-T<B`B1&QA('=I861O
M;6^V8VD@<')Z>6-H;V1ZL6-Y8V@L(&MT\W)E(&]D<&]W:6%D86JQ('5S=&%W
M:65N:6]M.B(*"B,Z(&9I;'1E<G,N<&AP.C$T-"!T96UP;&%T97,O9F]R=V%R
M9"]F;W)W87)D+FEN8SHW"FUS9VED(")&;W)W87)D(@IM<V=S='(@(E!R>F5K
M8;\B"@HC.B!F;W)W87)D+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R
M9"!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D
M<FEV97(N(@IM<V=S='(@(D-Z87)N82!L:7-T82!N:64@:F5S="!O8G.S=6=I
M=V%N82!P<GIE>B!O8F5C;GD@<W1E<F]W;FEK(&9I;'1R;W=A;FEA+B(*"B,Z
M(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(X,PHC+"!F=7IZ>0IM<V=I9"`B
M1F]R=V%R9',B"FUS9W-T<B`B4')Z96MAOR(*"B,Z(&9O<G=A<F0N<&AP.C0V
M"B,L(&9U>GIY"FUS9VED(")&;W)W87)D<R!%9&ET(@IM<V=S='(@(E!R>F5K
M8;\B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,Y"FUS9VED(")&<F]M
M(@IM<V=S='(@(D]D(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T.`IM<V=I9"`B
M1W)E871E<B!T:&%N(@IM<V=S='(@(E=IZFMS>F4@;FF_(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C,T.0IM<V=I9"`B1W)E871E<B!T:&%N(&]R(&5Q=6%L('1O
M(@IM<V=S='(@(E=IZFMS>F4@;FF_(&QU8B!R\W=N92(*"B,Z('1E;7!L871E
M<R]R=6QE+V9O;W1E<BYI;F,Z-#$*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R
M(")78;]N92(*"B,Z(')U;&4N<&AP.C(V"B,L(&9U>GIY"FUS9VED("));F1I
M=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT
M(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(D-Z87)N82!L:7-T82!N:64@
M:F5S="!O8G.S=6=I=V%N82!P<GIE>B!O8F5C;GD@<W1E<F]W;FEK(&9I;'1R
M;W=A;FEA+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$X-#@*;7-G:60@
M(DEN97AI<W1A;G0@;6%I;&)O>"!S<&5C:69I960@9F]R(&UE<W-A9V4@9&5L
M:79E<GDN(@IM<V=S='(@(DIA:V\@;6EE:G-C92!O9&EO<G4@>F]S=&&S82!P
M;V1A;F$@;FEE:7-T;FEE:K%C82!S:W)Z>6YK82XB"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S,U"FUS9VED("))<R(*;7-G<W1R(")*97-T(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C,S-@IM<V=I9"`B27-N)W0B"FUS9W-T<B`B3FEE(&IE<W0B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0V"FUS9VED("),97-S('1H86XB"FUS
M9W-T<B`B36YI96H@;FF_(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-PIM<V=I
M9"`B3&5S<R!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(DUN:65J(&YIOR!L
M=6(@<O-W;F4B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4Y"FUS9VED
M("),:7-T+4E$(@IM<V=S='(@(E=YMG=I971L+4E$(@H*(SH@=&5M<&QA=&5S
M+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(R"FUS9VED(")-87)?:R!M97-S
M86=E(&%S(&1E;&5T960B"FUS9W-T<B`B3WIN86-Z('=I861O;6^VYB!J86MO
M('5S=6YIZG2Q("A?:RDB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC
M.C,S"FUS9VED(")-87)K(&UE<W-A9V4@87,Z(@IM<V=S='(@(D]Z;F%C>B!W
M:6%D;VUOMN8@:F%K;SHB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0T"FUS9VED
M(")-871C:&5S("AW:71H('!L86-E:&]L9&5R<RDB"FUS9W-T<B`B(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C0W,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-
M87AI;75M(&YU;6)E<B!O9B!B;&%C:VQI<W1E9"!A9&1R97-S97,@97AC965D
M960@*%1O=&%L(&%D9')E<W-E<SH@)7,L("(*(DUA>&EM=6T@861D<F5S<V5S
M.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A9&1R97-S97,@=&\@8FQA8VML
M:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z-3(T"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@;G5M8F5R(&]F('=H:71E;&ES
M=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S<V5S.B`E<RP@
M(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO="!A9&0@;F5W
M(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M8W)I<'0O<VEE=F4N<&AP.C$W,38*;7-G:60@(DUI<W-I;F<@861D<F5S<R!T
M;R!R961I<F5C="!M97-S86=E('1O(@IM<V=S='(@(D)R86L@861R97-U+"!N
M82!K=/-R>2!M86JQ(&)YYB!P<GIE:VEE<F]W>7=A;F4@=VEA9&]M;[9C:2(*
M"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W-#@*;7-G:60@(DUI<W-I;F<@
M<F5A<V]N(&9O<B!R96IE8W0B"FUS9W-T<B`B3FEE('ID969I;FEO=V%N>2!P
M;W?S9"!O9')Z=6-E;FEA('=I861O;6^V8VDB"@HC.B!L:6(O4V-R:7!T+W-I
M979E+G!H<#HQ.3$U"FUS9VED(")-:7-S:6YG(')E87-O;B!I;B!V86-A=&EO
M;BXB"FUS9W-T<B`B3FEE('ID969I;FEO=V%N;R!T96MS='4@=R!N;V-I92!W
M86MA8WEJ;F5J+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z
M,C,*;7-G:60@(DUO=F4B"FUS9W-T<B`B4')Z97-U\2(*"B,Z(&9I;'1E<G,N
M<&AP.C$P.2!F:6QT97)S+G!H<#HR,34*;7-G:60@(DUO=F4@4G5L92!$;W=N
M(@IM<V=S='(@(E!R>F5N:66V(')E9W6SZB!N:;]E:B(*"B,Z(&9I;'1E<G,N
M<&AP.C$Q,"!F:6QT97)S+G!H<#HR,30*;7-G:60@(DUO=F4@4G5L92!5<"(*
M;7-G<W1R(")0<GIE;FEEMB!R96=UL^H@=WF_96HB"@HC.B!T96UP;&%T97,O
M=F%C871I;VXO=F%C871I;VXN:6YC.C0V"FUS9VED(").7W5M8F5R(&]F(&1A
M>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S.B(*;7-G<W1R("),:6-Z8F$@
M9&YI('!O;6GJ9'IY(&]D<&]W:65D>FEA;6D@;F]T>2!W86MA8WEJ;F5J.B`H
M7VXI(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+6YO;F4N:6YC.C0@
M=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHQ,PHC.B!L:6(O4W1O<F%G
M92YP:'`Z-S`W"FUS9VED(").97<@4G5L92(*;7-G<W1R(").;W=A(')E9W6S
M82(*"B,Z(&QI8B]);F=O+G!H<#HQ.30@;&EB+TEN9V\N<&AP.C$Y-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@7"(E<UPB(&5L96UE;G0@9F]U
M;F0@:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")"<F%K('=Y
M;6%G86YE:B!O<&-J:2`G=6ED)R!D;&$@:V]N9FEG=7)A8VII('5S=&%W:67Q
M+B(*"B,Z(&QI8B]);F=O+G!H<#HQ.3(*;7-G:60@(DYO(&)A8VME;F0@8V]N
M9FEG=7)E9"!F;W(@=&AI<R!H;W-T(@IM<V=S='(@(D)R86L@:V]N9FEG=7)A
M8VII('=E=V[J=')Z;F5J(&1L82!T96=O(&AO<W1A(@H*(SH@;&EB+TEN9V\N
M<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@8F%C:V5N9',@8V]N9FEG=7)E
M9"!I;B!B86-K96YD<RYP:'`B"FUS9W-T<B`B0G)A:R!K;VYF:6=U<F%C:FD@
M=V5W;NIT<GIN96H@9&QA('1E9V\@:&]S=&$B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]F:6QT97(M;F]N92YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R!F:6QT97)S+B!#;&EC:R!<(B5S7"(@=&\@8W)E871E(&$@;F5W(&9I;'1E
M<BXB"FUS9W-T<B`B0G)A:R!F:6QT<O-W+B!+;&EK;FEJ(%PB)7-<(BP@86)Y
M('5T=V]R>GGF(&YO=WDN(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3,R
M,"!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-#$S"B,Z(&QI8B]38W)I<'0O<VEE
M=F4N<&AP.C$U.#<*;7-G:60@(DYO(&AE861E<G,@<W!E8VEF:65D(@IM<V=S
M='(@(DYI92!Z9&5F:6YI;W=A;F\@;F%GL_-W:_-W(@H*(SH@<V-R:7!T+G!H
M<#HV-PIM<V=I9"`B3F\@<V-R:7!T(&=E;F5R871E9"XB"FUS9W-T<B`B3FEE
M('=Y9V5N97)O=V%N;R"_861N96=O('-K<GEP='4N(@H*(SH@;&EB+U-C<FEP
M="]S:65V92YP:'`Z,38P,@IM<V=I9"`B3F\@<W1R:6YG<R!S<&5C:69I960B
M"FUS9W-T<B`B3FEE('ID9FEN:6]W86YO(&-IL6?S=R(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-3$*;7-G:60@(DYO="!E<75A;"!T;R(*;7-G<W1R(")2\[]N
M92!O9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.0IM<V=I9"`B3W!T
M:6]N<R!A8F]U="!S8W)I<'0@=7!D871I;F<N(@IM<V=S='(@(D]P8VIE(&%K
M='5A;&EZ86-J:2!S:W)Y<'1U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$W"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(DEN;F4@;W!C:F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]N97=?9F]L9&5R+FIS.C8*;7-G
M:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB
M"FUS9W-T<B`B4')O<WKJ('!O9&'F(&YA>G?J(&YO=V5G;R!F;VQD97)U.B(*
M"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-C0*;7-G:60@
M(E)?96%S;VXB"FUS9W-T<B`B4&]W\V0@*%]R*2(*"B,Z(&-O;F9I9R]F:65L
M9',N<&AP+F1I<W0Z-C,*;7-G:60@(E)E8V5I=F5D(@IM<V=S='(@(D]T<GIY
M;6%N92(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.38*;7-G:60@(E)E9&ER96-T
M('1O(@IM<V=S='(@(E!R>F5K:65R=6H@9&\B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S0S"FUS9VED(")296=U;&%R(&5X<')E<W-I;VXB"FUS9W-T<B`B5WER
M8;]E;FEE(')E9W5L87)N92(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,3$*;7-G
M:60@(E)E:F5C="!W:71H(')E87-O;B(*;7-G<W1R(")/9')Z=>8@=VEA9&]M
M;[;F('H@<&]D86YI96T@<&]W;V1U(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HU-0IM<V=I9"`B4F5S96YT(%1O(@IM<V=S='(@(D]D9;9L:6H@9&\B
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4Q"FUS9VED(")297-E;G0M
M9G)O;2(*;7-G<W1R(")/9&6V;&EJ('HB"@HC.B!T96UP;&%T97,O<G5L92]F
M;V]T97(N:6YC.C<R"FUS9VED(")2971U<FX@=&\@1FEL=&5R<R!,:7-T(@IM
M<V=S='(@(E!O=W+S="!D;R!O<&-J:2!L:7-T>2!F:6QT<O-W(@H*(SH@=&5M
M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C0S('1E;7!L871E<R]V
M86-A=&EO;B]V86-A=&EO;BYI;F,Z-S4*(SH@=&5M<&QA=&5S+W=H:71E;&ES
M="]W:&ET96QI<W0N:6YC.C(X('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N
M:6YC.C,X"FUS9VED(")2971U<FX@=&\@4G5L97,@3&ES="(*;7-G<W1R(")0
M;W=R\W0@9&\@;&ES='D@<F5G=;,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H
M96%D97(N:6YC.C(Q"FUS9VED(")2=6QE(@IM<V=S='(@(E)E9W6S82(*"B,Z
M(&9I;'1E<G,N<&AP.C0U"FUS9VED(")2=6QE($-O<&EE9"(*;7-G<W1R(")2
M96=ULV$@<VMO<&EO=V%N82(*"B,Z(&9I;'1E<G,N<&AP.C,Y"FUS9VED(")2
M=6QE($1E;&5T960B"FUS9W-T<B`B4F5G=;-A('5S=6YIZG1A(@H*(SH@9FEL
M=&5R<RYP:'`Z-3D*;7-G:60@(E)U;&4@1&ES86)L960B"FUS9W-T<B`B4F5G
M=;-A('=YL[%C>F]N82(*"B,Z(&9I;'1E<G,N<&AP.C8T"FUS9VED(")2=6QE
M($5N86)L960B"FUS9W-T<B`B4F5G=;-A('>SL6-Z;VYA(@H*(SH@=&5M<&QA
M=&5S+W)U;&4O:&5A9&5R+FEN8SHS.0IM<V=I9"`B4G5L92!.86UE(@IM<V=S
M='(@(DYA>G=A(')E9W6S>2(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA
M8VML:7-T+FEN8SHT,B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC
M.C<T"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR-R!T
M96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHS-PHC.B!T96UP;&%T97,O
M<G5L92]F;V]T97(N:6YC.C<Q"FUS9VED(")3879E(@IM<V=S='(@(EIA<&ES
M>B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHT-PIM<V=I
M9"`B4V%V92!3971T:6YG<R(*;7-G<W1R("):87!I<WH@;W!C:F4B"@HC.B!T
M96UP;&%T97,O<V-R:7!T+VAE861E<BYI;F,Z,PIM<V=I9"`B4V-R:7!T(@IM
M<V=S='(@(E-K<GEP="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.`IM
M<V=I9"`B4V-R:7!T(%5P9&%T:6YG(@IM<V=S='(@(E5A:W1U86QN:65N:64@
M<VMR>7!T=2(*"B,Z(&QI8B]);F=O+G!H<#HR,3<*;7-G:60@(E-C<FEP="!N
M;W0@=7!D871E9"XB"FUS9W-T<B`B4VMR>7!T(&YI975A:W1U86QN:6]N>2XB
M"@HC.B!L:6(O26YG;RYP:'`Z,3,P"FUS9VED(")38W)I<'0@<W5C8V5S<V9U
M;&QY(&%C=&EV871E9"XB"FUS9W-T<B`B4VMR>7!T(&%K='EW;W=A;GD@<&]P
M<F%W;FEE+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,CD*;7-G:60@(E-C<FEP="!S
M=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-K<GEP="!D96%K
M='EW;W=A;GD@<&]P<F%W;FEE+B(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E
M<BYI;F,Z,S@*;7-G:60@(E-E96XB"FUS9W-T<B`B5VED>FEA;F4B"@HC.B!R
M=6QE+G!H<#HQ-C(*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(E=Y
M8FEE<GH@<&]L92(*"B,Z(&QI8B]);F=O+G!H<#HT.0IM<V=I9"`B4V5L96-T
M('1A<F=E="!F;VQD97(B"FUS9W-T<B`B5WEB:65R>B!F;VQD97(@9&]C96QO
M=WDB"@HC.B!R=6QE+G!H<#HQ.#,*;7-G:60@(E-E;&8M1&5F:6YE9"!(96%D
M97(B"FUS9W-T<B`B4V%M;V1Z:65L;FEE('ID969I;FEO=V%N>2!N86>S\W=E
M:R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S4*;7-G:60@(E-E;F1E
M<B(*;7-G<W1R(").861A=V-A(@H*(SH@9FEL=&5R<RYP:'`Z-S@*;7-G:60@
M(E-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")5<W1A
M=VEE;FEA('IO<W1ALWD@>FUI96YI;VYE+B(*"B,Z('1E;7!L871E<R]S8W)I
M<'0O86-T:79A=&4N:6YC.C(T"FUS9VED(")3:&]W($%C=&EV92!38W)I<'0B
M"FUS9W-T<B`B4&]K8;\@86MT>7=N>2!S:W)Y<'0B"@HC.B!T96UP;&%T97,O
M<V-R:7!T+V%C=&EV871E+FEN8SHS,0IM<V=I9"`B4VAO=R!#=7)R96YT(%-C
M<FEP="(*;7-G<W1R(")0;VMAOR!O8F5C;GD@<VMR>7!T(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HX,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")2;WIM
M:6%R(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHV,0IM<V=I9"`B
M4W1O<"!C:&5C:VEN9R!I9B!T:&ES(')U;&4@;6%T8VAE<S\B"FUS9W-T<B`B
M6F%T<GIY;6%J('-P<F%W9'IA;FEE(&=D>2!T82!R96=ULV$@8NID>FEE('!A
M<V]W8>8_(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHU
M-0IM<V=I9"`B4W5B:F5?8W0@;V8@=F%C871I;VX@;65S<V%G93HB"FUS9W-T
M<B`B5&5M870@;F]T>2!W86MA8WEJ;F5J("A?8RDZ(@H*(SH@8V]N9FEG+V9I
M96QD<RYP:'`N9&ES=#HS,0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")496UA
M="(*"B,Z(&QI8B]);F=O+G!H<#HQ,C4*;7-G:60@(E1H92!D<FEV97(@<V%I
M9#H@(@IM<V=S='(@(E-T97)O=VYI:R!W>7!L=;,Z("(*"B,Z(&QI8B]);F=O
M+G!H<#HQ,C0*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8W1I=F%T:6YG
M('1H92!S8W)I<'0N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!A:W1Y=V%C:FD@
M<VMR>7!T=2XB"@HC.B!L:6(O26YG;RYP:'`Z,3(S"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@
M(D*SL60@<&]D8WIA<R!D96%K='EW86-J:2!S:W)Y<'1U+B(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z,C<*;7-G:60@(E1O(@IM<V=S='(@(D1O(@H*
M(SH@;&EB+U-C<FEP="YP:'`Z,3(P"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(").
M:64@;6]GZB!W8WIY=&'F(&1E9FEN:6-J:2`E<RXB"@HC.B!F:6QT97)S+G!H
M<#HQ,S@@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHW"B,Z(&QI
M8B]38W)I<'0O<')O8VUA:6PN<&AP.C(V,0IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`B5V%K86-J92(*"B,Z('9A8V%T:6]N+G!H<#HW,@IM<V=I9"`B5F%C
M871I;VX@161I="(*;7-G<W1R(")%9'EC:F$@;F]T>2!W86MA8WEJ;F5J(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,S4P"FUS9VED(")686-A=&EO;B!-
M97-S86=E(@IM<V=S='(@(DYO=&$@=V%K86-Y:FYA(@H*(SH@=F%C871I;VXN
M<&AP.C$V"FUS9VED(")686-A=&EO;B!I<R!N;W0@<W5P<&]R=&5D(&EN('1H
M92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(B(*(DYO=&$@
M=V%K86-Y:FYA(&YI92!J97-T(&]B<[-U9VEW86YA('!R>F5Z(&]B96-N>2!S
M=&5R;W=N:6L@9FEL=')O=V%N:6$N(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES
M="]W:&ET96QI<W0N:6YC.C$X"FUS9VED(")7:%]I=&5L:7-T(&%D9')E<W-E
M<SHB"FUS9W-T<B`B061R97-Y(&YA(&)I8;-E:B!L:;9C:64@*%]I*3HB"@HC
M.B!F:6QT97)S+G!H<#HQ,S(@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI
M<W0N:6YC.C<*;7-G:60@(E=H:71E;&ES="(*;7-G<W1R(")":6&S82!L:7-T
M82(*"B,Z('=H:71E;&ES="YP:'`Z-34*;7-G:60@(E=H:71E;&ES="!%9&ET
M(@IM<V=S='(@(D5D>6-J82!B:6&S96H@;&ES='DB"@HC.B!W:&ET96QI<W0N
M<&AP.C$X"FUS9VED(")7:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")":6&S82!L
M:7-T82!N:64@:F5S="!O8G.S=6=I=V%N82!P<GIE>B!O8F5C;GD@<W1E<F]W
M;FEK(&9I;'1R;W=A;FEA+B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP
M.C(S,2!L:6(O4V-R:7!T+W-I979E+G!H<#HR.38*;7-G:60@(E=H:71E;&ES
M=&5D($%D9')E<W-E<R(*;7-G<W1R(")!9')E<WD@;F$@8FEALV5J(&QIMF-I
M92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-SD*;7-G:60@(E@M4')I
M;W)I='DB"FUS9W-T<B`B6"U0<FEO<GET970B"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C8W"FUS9VED(")8+5-P86TM3&5V96PB"FUS9W-T<B`B6"U0
M;WII;VTM4W!A;74B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C<Q"FUS
M9VED(")8+5-P86TM4V-O<F4B"FUS9W-T<B`B6"U0=6YK='DM4W!A;74B"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C<U"FUS9VED(")8+5-P86TM4W1A
M='5S(@IM<V=S='(@(E@M4W1A='5S+5-P86UU(@H*(SH@=F%C871I;VXN<&AP
M.C,P"FUS9VED("(B"B)9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!E
M;6%I;"!A9&1R97-S(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@;65S<V%G97,@
M(@HB<VAO=6QD(&)E(&%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+U-C
M<FEP="]I;6%P+G!H<#HR-S@@;&EB+U-C<FEP="]I;6%P+G!H<#HS,#$@;&EB
M+U-C<FEP="]I;6%P+G!H<#HS,34*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G
M<W1R(");8G)A:R!T96UA='5=(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R
M=V%R9"YI;F,Z,C<*;7-G:60@(E]!9&1R97-S*&5S*2!T;R!F;W)W87)D('1O
M.B(*;7-G<W1R(")?061R97-Y+"!N82!K=/-R92!P<GIE:V%Z>7=AYCHB"@HC
M.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C(X"FUS9VED(")?
M061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SHB"FUS9W-T<B`B
M7T%D<F5S>2P@;F$@:W3S<F4@;FEE(&+J9+$@=WES>;-A;F4@;V1P;W=I961Z
M:3HB"@HC.B!L:6(O26YG;RYP:'`Z,C<R"FUS9VED(")?0FQA8VML:7-T(@IM
M<V=S='(@(D-Z87)N82!L:7-T82`H7V(I(@H*(SH@=&5M<&QA=&5S+V)L86-K
M;&ES="]B;&%C:VQI<W0N:6YC.C(P"FUS9VED(")?1&5L971E(&UE<W-A9V4@
M8V]M<&QE=&5L>2(*;7-G<W1R(")5<W7Q(&-ALVMO=VEC:64@=VEA9&]M;[;F
M("A?9"DB"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M,S,*;7-G:60@(E]%;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN93HB
M"FUS9W-T<B`B5W!R;W=A9'IA:B!K8;]D>2!A9')E<R!W(&YO=V5J(&QI;FEI
M("A?92DZ(@H*(SH@;&EB+TEN9V\N<&AP.C(W.`IM<V=I9"`B7T9O<G=A<F0B
M"FUS9W-T<B`B4')Z96MAOR`H7V8I(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O
M9F]R=V%R9"YI;F,Z,3D*;7-G:60@(E]+965P(&$@8V]P>2!O9B!M97-S86=E
M<R!I;B!T:&ES(&%C8V]U;G0_(@IM<V=S='(@(EIA8VAO=V%J(&MO<&GJ('=I
M861O;6^V8VD@;F$@='EM(&MO;F-I93\@*%]K*2(*"B,Z('1E;7!L871E<R]B
M;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR-`IM<V=I9"`B7TUO=F4@;65S<V%G
M92!T;R!F;VQD97(Z(@IM<V=S='(@(E!R>F5N:66V('=I861O;6^VYB!D;R!F
M;VQD97)U("A?;2DZ(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N
M+FEN8SHQ.`IM<V=I9"`B7TUY(&5M86EL(&%D9')E<W-E<SHB"FUS9W-T<B`B
M7TUO:F4@861R97-Y(&5M86EL.B(*"B,Z(&QI8B]);F=O+G!H<#HR.#$*;7-G
M:60@(E]38W)I<'0B"FUS9W-T<B`B7U-K<GEP="(*"B,Z(&QI8B]);F=O+G!H
M<#HR-S4*;7-G:60@(E]686-A=&EO;B(*;7-G<W1R(")786MA8VIE("A?=BDB
M"@HC.B!L:6(O26YG;RYP:'`Z,C8Y"FUS9VED(")?5VAI=&5L:7-T(@IM<V=S
M='(@(D)I8;-A(&QI<W1A("A?=RDB"@HC.B!T96UP;&%T97,O<G5L92]F:6QT
M97(N:6YC.C0*;7-G:60@(F%N9"(*;7-G<W1R(")I(@H*(SH@9FEL=&5R<RYP
M:'`Z,38R"FUS9VED(")F:65L9"(*;7-G<W1R(")P;VQE(@H*(SH@9FEL=&5R
M<RYP:'`Z,38R"FUS9VED(")M871C:"(*;7-G<W1R(")P87-U:F4B"@HC.B!T
M96UP;&%T97,O<G5L92]F:6QT97(N:6YC.C0*;7-G:60@(F]R(@IM<V=S='(@
M(FQU8B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C$R,0IM<V=I9"`B
M<')O8VUA:6P@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O(@IM<V=S='(@(E-K
M<GEP="!P<F]C;6%I;"!W>6=E;F5R;W=A;GD@<')Z97H@26YG;R(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C$P.`IM<V=I9"`B<VEE=F4@9FEL=&5R(&=E
M;F5R871E9"!B>2!);F=O(@IM<V=S='(@(B(*````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6YG;R]P;R]D85]$2RYP;P``````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U,#0Q-``Q,#0Q-S,V,C<T-P`P
M,3<S,#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R!$86YI<V@@=')A;G-L871I;VYS(&9O<B!);F=O($@S('!A8VMA9V4*
M(R!$86YS:V4@;W9E<G/F='1E;'-E<B!F;W(@<&%K:V4@26YG;R!(,RX*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I
M<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!)
M;F=O($@S('!A8VMA9V4N"B,@0G)I86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`
M8G)I86YT<G5E;'-E;BYD:SXL(#(P,#4N"B,*;7-G:60@(B(*;7-G<W1R("(B
M"B)0<F]J96-T+4ED+59E<G-I;VXZ($EN9V\@2#,@*#$N,"XR+6-V<RE<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`U+3$P+3`Y(#$U.C$W*S`R,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@0G)I86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`
M8G)I86YT<G5E;'-E;BYD:SY<;B(*(DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A;"U&;W)M
M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN("$](#$I.UQN(@H*(SH@9FEL=&5R
M<RYP:'`Z,3@U"FUS9VED("(@86YD(@IM<V=S='(@(B!O9R(*"B,Z(&9I;'1E
M<G,N<&AP.C$X-0IM<V=I9"`B(&]R(@IM<V=S='(@(B!E;&QE<B(*"B,Z('1E
M;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ-PIM<V=I9"`B06-T
M:6]N(&9O<B!B;&%C:VQI<W1E9"!A9&1R97-S97,Z(@IM<V=S='(@(DAA;F1L
M:6YG(&9O<B!U^&YS:V5D92!A9')E<W-E<CHB"@HC.B!T96UP;&%T97,O<V-R
M:7!T+V%C=&EV871E+FEN8SHQ,`IM<V=I9"`B06-T:79A=&4@4V-R:7!T(@IM
M<V=S='(@(D%K=&EVZ7(@<V-R:7!T(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-T:79A=&EN9R!T:&4@<V-R
M:7!T(&9O<B!<(B5S7"(@9F%I;&5D.B`H)60I("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHV"FUS9VED(")!9&1I
M=&EO;F%L(%-E='1I;F=S(@IM<V=S='(@(EED97)L:6=E<F4@:6YD<W1I;&QI
M;F=E<B(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#0*;7-G:60@
M(D%L;"!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@(D%L;&4@;F5D96YS=.5E
M;F1E(@H*(SH@;&EB+V%P:2YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D%L;&]W
M(%)U;&5S(@IM<V=S='(@(DYY(')E9V5L(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M9F]O=&5R+FEN8SHS,PIM<V=I9"`B06YS=V5R960B"FUS9W-T<B`B0F5S=F%R
M970B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C0U"FUS9VED(")!
M;GD@;V8@=&AE(&9O;&QO=VEN9R(*;7-G<W1R(")6:6QKY7)L:6=E(&%F(&YE
M9&5N<W3E96YD92(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z
M,3$*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B4.5F^'(@9FEL=')E
M(@H*(SH@9FEL=&5R<RYP:'`Z,C$T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@9&5L971E('1H:7,@<G5L93\B"FUS9W-T<B`B17(@9'4@<VEK
M:V5R('#E+"!A="!D=2!V:6P@<VQE='1E(&1E;FYE(')E9V5L/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B075T;VUA=&EC86QL>2!U
M<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\B"FUS9W-T<B`B
M3W!D873I<B!A=71O;6%T:7-K('-C<FEP=&5T(&5F=&5R(&AV97(@YFYD<FEN
M9S\B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C0W"FUS9VED(")"8V,B
M"FUS9W-T<B`B0F-C(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-`IM<V=I9"`B
M0F5G:6YS('=I=&@B"FUS9W-T<B`B4W1A<G1E<B!M960B"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C$P-B!L:6(O1')I=F5R+VQD87`N<&AP.C$Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R
M("(B"@HC.B!F:6QT97)S+G!H<#HQ-#0@=&5M<&QA=&5S+V)L86-K;&ES="]B
M;&%C:VQI<W0N:6YC.C<*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R(")3;W)T
M;&ES=&YI;F<B"@HC.B!B;&%C:VQI<W0N<&AP.C$P,`IM<V=I9"`B0FQA8VML
M:7-T($5D:70B"FUS9W-T<B`BQFYD<F4@<V]R=&QI<W1N:6YG(@H*(SH@8FQA
M8VML:7-T+G!H<#HQ-PIM<V=I9"`B0FQA8VML:7-T(&ES(&YO="!S=7!P;W)T
M960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B
M4V]R=&QI<W1N:6YG('5N9&5R<W3X='1E<R!I:VME(&%F(&1E;B!N=7;F<F5N
M9&4@9FEL=')E<FEN9W-M96MA;FES;64N(@H*(SH@;&EB+U-C<FEP="]P<F]C
M;6%I;"YP:'`Z,C`W(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C$W-0IM<V=I
M9"`B0FQA8VML:7-T960@061D<F5S<R(*;7-G<W1R(")3;W)T;&ES=&5T(&%D
M<F5S<V4B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HR-#,*;7-G:60@(D)L
M86-K;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R(")3;W)T;&ES=&5D92!A9')E
M<W-E<B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z.#@*;7-G:60@(D)O
M9'DB"FUS9W-T<B`B0F5S:V5D(@H*(SH@9FEL=&5R<RYP:'`Z,3@R(')U;&4N
M<&AP.C(X,0IM<V=I9"`B0V%S92!396YS:71I=F4B"FUS9W-T<B`B1F]R<VME
M;"!PY2!S=&]R92!O9R!S;>4@8F]G<W1A=F5R(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HT,PIM<V=I9"`B0V,B"FUS9W-T<B`B0V,B"@HC.B!R=6QE
M+G!H<#HQ,C(@=VAI=&5L:7-T+G!H<#HS-B!F;W)W87)D+G!H<#HS,R!V86-A
M=&EO;BYP:'`Z-#$*(SH@8FQA8VML:7-T+G!H<#HV.0IM<V=I9"`B0VAA;F=E
M<R!S879E9"XB"FUS9W-T<B`BQFYD<FEN9V5R(&=E;70N(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HW-0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#`*;7-G:60@(D-O;G1A
M:6YS(@IM<V=S='(@(DEN9&5H;VQD97(B"@HC.B!F:6QT97)S+G!H<#HR,C4@
M9FEL=&5R<RYP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@)7,B
M"FUS9W-T<B`B2V]P:>ER("5S(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C<V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&]F("5S(@IM<V=S='(@(DMO<&D@
M868@)7,B"@HC.B!L:6(O26YG;RYP:'`Z-3(*;7-G:60@(D-R96%T92!N97<@
M9F]L9&5R(@IM<V=S='(@(D]P<F5T(&YY(&UA<'!E(@H*(SH@;&EB+U-C<FEP
M="]P<F]C;6%I;"YP:'`Z,S,V(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(W
M.0IM<V=I9"`B1$E304),140Z("(*;7-G<W1R(")3;.5E="!&4D$Z("(*"B,Z
M('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$W"FUS9VED(")$96%C
M=&EV871E(%-C<FEP="(*;7-G<W1R("));F%K=&EVZ7(@<V-R:7!T(@H*(SH@
M9FEL=&5R<RYP:'`Z,C$T(&9I;'1E<G,N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@)7,B"FUS9W-T<B`B4VQE="`E<R(*"B,Z('1E;7!L
M871E<R]R=6QE+V9I;'1E<BYI;F,Z,S`*;7-G:60@(D1E;&5T92!#;VYD:71I
M;VXB"FUS9W-T<B`B4VQE="!B971I;F=E;'-E(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C(Y,@IM<V=I9"`B1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L>2(*;7-G
M<W1R(")3;&5T(&)E<VME9&5R('1O=&%L="(*"B,Z('1E;7!L871E<R]R=6QE
M+V9O;W1E<BYI;F,Z,S4*;7-G:60@(D1E;&5T960B"FUS9W-T<B`B4VQE='1E
M="(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.#`*;7-G:60@(D1E;&EV97(@:6YT
M;R!M>2!)3D)/6"(*;7-G<W1R(")!9FQE=NER(&D@;6EN($EN9&)A:VME(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,P-@IM<V=I9"`B1&5L:79E<B!I;G1O(&UY
M($E.0D]8(&%N9"!C;W!Y('1O(@IM<V=S='(@(D%F;&5VZ7(@:2!M:6X@26YD
M8F%K:V4@;V<@:V]P:>ER('1I;"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,#$*
M;7-G:60@(D1E;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@<F5D:7)E8W0@=&\B
M"FUS9W-T<B`B069L97;I<B!I(&UI;B!);F1B86MK92!O9R!O;6%D<F5S<^ER
M('1I;"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.#8*;7-G:60@(D1E;&EV97(@
M=&\@9F]L9&5R(@IM<V=S='(@(D%F;&5VZ7(@:2!M87!P92(*"B,Z(&9I;'1E
M<G,N<&AP.C(T,2!F:6QT97)S+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&ES86)L92`E<R(*;7-G<W1R(")3;.4@)7,@9G)A(@H*(SH@=&5M<&QA
M=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C$P('1E;7!L871E<R]B;&%C
M:VQI<W0O8FQA8VML:7-T+FEN8SHQ,`HC.B!T96UP;&%T97,O=F%C871I;VXO
M=F%C871I;VXN:6YC.C8@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z
M,3`*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHR-@IM<V=I9"`B1&ES
M86)L960B"FUS9W-T<B`B4VSE970@9G)A(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<V5T=&EN9W,N:6YC.C$S"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&YO
M=&EF:6-A=&EO;B!W:&5N(&5A8V@@9FEL=&5R(&ES(&%P<&QI960_(@IM<V=S
M='(@(E9I<R!D971A;&IE<F5D92!N;W1I9FEK871I;VYE<B!NY7(@:'9E<G0@
M9FEL=&5R('5D9OAR97,_(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T
M:6]N+FEN8SHS-`IM<V=I9"`B1&\@7VYO="!S96YD(')E<W!O;G-E<R!T;R!B
M=6QK(&]R(&QI<W0@;65S<V%G97,B"FUS9W-T<B`B4V5N9"!I:VME(&UE9&1E
M;&5L<V5R('1I;"!M87-S92T@96QL97(@;&ES=&4M8F5S:V5D97(B"@HC.B!T
M96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C$P"FUS9VED(")$;R!T:&ES.B(*
M;7-G<W1R(")'^'(@9&5T=&4Z(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-0IM
M<V=I9"`B1&]E<VXG="!B96=I;B!W:71H(@IM<V=S='(@(E-T87)T97(@:6MK
M92!M960B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0Q"FUS9VED(")$;V5S;B=T
M(&-O;G1A:6XB"FUS9W-T<B`B26YD96AO;&1E<B!I:VME(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C,T-PIM<V=I9"`B1&]E<VXG="!E;F0@=VET:"(*;7-G<W1R
M(")3;'5T=&5R(&EK:V4@;65D(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T.0IM
M<V=I9"`B1&]E<VXG="!E>&ES="(*;7-G<W1R(")&:6YD97,@:6MK92(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS-3(*;7-G:60@(D1O97-N)W0@;6%T8V@@*'=I
M=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R(")087-S97(@:6MK92`H;65D('!L
M861S:&]L9&5R*2(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z
M,S$*;7-G:60@(D5D:70B"FUS9W-T<B`B4F5D:6=E<B(*"B,Z(&9I;'1E<G,N
M<&AP.C(P,R!F:6QT97)S+G!H<#HR,#4@9FEL=&5R<RYP:'`Z,C`Y(&9I;'1E
M<G,N<&AP.C(Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S
M='(@(E)E="`E<R(*"B,Z(&9I;'1E<G,N<&AP.C(T-2!F:6QT97)S+G!H<#HR
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YA8FQE("5S(@IM<V=S='(@(E-L
MY2`E<R!T:6PB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C,W
M"FUS9VED(")%;F%B;&5D(@IM<V=S='(@(E-LY65T('1I;"(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS-#8*;7-G:60@(D5N9',@=VET:"(*;7-G<W1R(")%;F1E
M<B!M960B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4W"FUS9VED(")%<75A;"!T
M;R(*;7-G<W1R("),:6<@;65D(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M,SD@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#D@;&EB+T1R:79E<B]L9&%P+G!H
M<#HQ-3@*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@<F5T<FEE=FEN9R!C=7)R96YT('-C<FEP=#H@*"5D
M*2`E<R(*;7-G<W1R("(B"@HC.B!B;&%C:VQI<W0N<&AP.C8W"FUS9VED(")%
M<G)O<B!S879I;F<@8VAA;F=E<RXB"FUS9W-T<B`B1F5J;"!U;F1E<B!L86=R
M:6YG(&%F(.9N9')I;F=E<BXB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D
M97(N:6YC.C(R"FUS9VED(")%>&ES=&EN9R!2=6QE<R(*;7-G<W1R(")%:W-I
M<W1E<F5N9&4@<F5G;&5R(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T.`IM<V=I
M9"`B17AI<W1S(@IM<V=S='(@(D9I;F1E<R(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,30T"B,L('!H<"UF;W)M870*;7-G:60@(D5X<&5C=&5D(#$@;V)J
M96-T+"!G;W0@)60N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W-E='1I;F=S+FEN8SHR,`IM<V=I9"`B1FEL=&5R($%L;"!-97-S86=E<R(*
M;7-G<W1R(")&:6QT<NER(&%L;&4@8F5S:V5D97(B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]S971T:6YG<RYI;F,Z,C(*;7-G:60@(D9I;'1E<B!/;FQY(%-E
M96X@365S<V%G97,B"FUS9W-T<B`B1FEL='+I<B!K=6X@;.9S=&4@8F5S:V5D
M97(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,C$*;7-G
M:60@(D9I;'1E<B!/;FQY(%5N<V5E;B!-97-S86=E<R(*;7-G<W1R(")&:6QT
M<NER(&MU;B!U;.9S=&4@8F5S:V5D97(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]S971T:6YG<RYI;F,Z,3@*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S
M='(@(D9I;'1E<BUI;F1S=&EL;&EN9V5R(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M:&5A9&5R+FEN8SHR-0IM<V=I9"`B1FEL=&5R(%)U;&4B"FUS9W-T<B`B1FEL
M=&5R<F5G96PB"@HC.B!F:6QT97)S+G!H<#HQ,#D*;7-G:60@(D9I;'1E<B!2
M=6QE<R(*;7-G<W1R(")&:6QT97)R96=L97(B"@HC.B!S8W)I<'0N<&AP.C4R
M"FUS9VED(")&:6QT97(@4V-R:7!T($1I<W!L87DB"FUS9W-T<B`B5FES;FEN
M9R!A9B!F:6QT97(M<V-R:7!T(@H*(SH@;&EB+TEN9V\N<&AP.C,P,`IM<V=I
M9"`B1FEL=&5R(%]2=6QE<R(*;7-G<W1R(")&:6QT97)R96=L97(B"@HC.B!L
M:6(O4V-R:7!T+VEM87`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&-O<&EE
M9"!T;R!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B1FEL=&5R86MT:79I
M=&5T.B`E<R!B97-K960H97(I(&5R(&)L979E="!K;W!I97)E="!T:6P@;6%P
M<&5N(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H
M<RD@:&%V92!B965N(&1E;&5T960N(@IM<V=S='(@(D9I;'1E<F%K=&EV:71E
M=#H@)7,@8F5S:V5D*&5R*2!E<B!B;&5V970@<VQE='1E="XB"@HC.B!L:6(O
M4V-R:7!T+VEM87`N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT
M97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O
M('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")&:6QT97)A:W1I=FET970Z
M("5S(&)E<VME9"AE<BD@97(@9FQY='1E="!T:6P@;6%P<&5N(%PB)7-<(BXB
M"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C$X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@=&AA="!M871C
M:&5D('1H92!B;&%C:VQI<W0@=V5R92!D96QE=&5D+B(*;7-G<W1R(")&:6QT
M97)A:W1I=FET970Z("5S(&)E<VME9"AE<BDL(&1E<B!V87(@<V]R=&QI<W1E
M="P@97(@<VQE='1E="XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I960@=&\@
M=&AE("(*(F9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*(D9I;'1E<F%K=&EV
M:71E=#H@0F5S:V5D96X@7"(E<UPB(&9R82!<(B5S7"(@97(@:V]P:65R970@
M=&EL(&UA<'!E;B!<(B5S7"(N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B!4:&4@
M;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B1FEL=&5R86MT:79I=&5T.B!"97-K961E;B!<(B5S7"(@9G)A
M(%PB)7-<(B!E<B!S;&5T=&5T+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z
M,C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D9I;'1E<B!A8W1I=FET>3H@
M5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&UO=F5D
M('1O('1H92!F;VQD97(@(@HB7"(E<UPB+B(*;7-G<W1R("(B"B)&:6QT97)A
M:W1I=FET970Z($)E<VME9&5N(%PB)7-<(B!F<F$@7"(E<UPB(&5R(&9L>71T
M970@=&EL(&UA<'!E;B!<(B5S7"(N(@H*(SH@<G5L92YP:'`Z,38P"FUS9VED
M(")&:6QT97(@;F]T(&9O=6YD+B(*;7-G<W1R(")&:6QT97(@:6MK92!F=6YD
M970B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C0R"FUS9VED(")&
M;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z(@IM<V=S='(@
M(D9O<B!E;B!I;F1K;VUM96YD92!B97-K960L('-O;2!P87-S97(@=&EL.B(*
M"B,Z(&9I;'1E<G,N<&AP.C$V,B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D
M+FEN8SHX"FUS9VED(")&;W)W87)D(@IM<V=S='(@(E9I9&5R97-E;F0B"@HC
M.B!F;W)W87)D+G!H<#HQ-@IM<V=I9"`B1F]R=V%R9"!I<R!N;W0@<W5P<&]R
M=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@
M(E9I9&5R97-E;F1E;'-E(&5R(&EK:V4@=6YD97)S=/AT=&5T(&%F(&1E;B!N
M=7;F<F5N9&4@9FEL=&5R;65K86YI<VUE+B(*"B,Z(&QI8B]38W)I<'0O<')O
M8VUA:6PN<&AP.C(X,B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HR,C0*;7-G
M:60@(D9O<G=A<F1S(@IM<V=S='(@(E9I9&5R97-E;F1E;'-E(@H*(SH@9F]R
M=V%R9"YP:'`Z-#8*;7-G:60@(D9O<G=A<F1S($5D:70B"FUS9W-T<B`B4F5D
M:6?I<B!V:61E<F5S96YD96QS97(B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD
M:7-T.C,Y"FUS9VED(")&<F]M(@IM<V=S='(@(D9R82(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-34*;7-G:60@(D=R96%T97(@=&AA;B(*;7-G<W1R(")3=/AR
M<F4@96YD(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-@IM<V=I9"`B1W)E871E
M<B!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(E-T^')R92!E;F0@96QL97(@
M;&EG(&UE9"(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S$*;7-G
M:60@(DEM<&]R=&%N="(*;7-G<W1R(")6:6=T:6=T(@H*(SH@<G5L92YP:'`Z
M,S8*;7-G:60@(DEN9&EV:61U86P@<G5L97,@87)E(&YO="!S=7!P;W)T960@
M:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B(@HB
M26YD:79I9'5E;&QE(')E9VQE<B!E<B!I:VME('5N9&5R<W3X='1E="!A9B!D
M96X@;G5VYG)E;F1E(&9I;'1E<FUE:V%N:7-M92XB"@HC.B!L:6(O4V-R:7!T
M+W-I979E+G!H<#HQ.#4U"FUS9VED("));F5X:7-T86YT(&UA:6QB;W@@<W!E
M8VEF:65D(&9O<B!M97-S86=E(&1E;&EV97)Y+B(*;7-G<W1R(")):VME+65K
M<VES=&5R96YD92!B<F5V8F%K:V4@86YG:79E="!T:6P@869L979E<FEN9R!A
M9B!B97-K960N(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T,@IM<V=I9"`B27,B
M"FUS9W-T<B`B17(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0S"FUS9VED("))
M<VXG="(*;7-G<W1R(")%<B!I:VME(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HR,PIM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T
M:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4S"FUS9VED("),
M97-S('1H86XB"FUS9W-T<B`B36EN9')E(&5N9"(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS-30*;7-G:60@(DQE<W,@=&AA;B!O<B!E<75A;"!T;R(*;7-G<W1R
M(")-:6YD<F4@96YD(&5L;&5R(&QI9R!M960B"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C4Y"FUS9VED("),:7-T+4E$(@IM<V=S='(@(DQI<W0M240B
M"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,C`*;7-G
M:60@(DUA<E]K(&UE<W-A9V4@87,@9&5L971E9"(*;7-G<W1R(")-87)KZ7(@
M8F5S:V5D96X@<VQE='1E="(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI
M;F,Z,C0*;7-G:60@(DUA<FL@;65S<V%G92!A<SHB"FUS9W-T<B`B36%R:^ER
M(&)E<VME9&5N.B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3$*;7-G:60@(DUA
M=&-H97,@*'=I=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R(")087-S97(@=&EL
M("AM960@<&QA9'-H;VQD97)E*2(*"B,Z(&QI8B]A<&DN<&AP.C4W"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!2=6QE<R(*;7-G<W1R("(B"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z-#<X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM
M=6T@;G5M8F5R(&]F(&)L86-K;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H
M5&]T86P@861D<F5S<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S
M*2X@($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N
M(@IM<V=S='(@(B(*(DUA:W-I;6%L="!A;G1A;"!S;W)T;&ES=&5D92!A9')E
M<W-E<B!O=F5R<W1E9V5T("A!;G1A;"!A9')E<W-E<CH@)7,L("(*(FUA:W-I
M;6%L="!A;G1A;#H@)7,I+B`@2W5N;F4@:6MK92!T:6QF^&IE(&YY92!A9')E
M<W-E<B!T:6P@<V]R=&QI<W1N:6YG+B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HU
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@
M=VAI=&5L:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S
M97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T
M(&%D9"!N97<@861D<F5S<V5S('1O('=H:71E;&ES="XB"FUS9W-T<B`B(@HB
M36%K<VEM86QT(&%N=&%L(&AV:61L:7-T961E(&%D<F5S<V5R(&]V97)S=&5G
M970@*$%N=&%L(&%D<F5S<V5R.B`E<RP@(@HB;6%K<VEM86QT(&%N=&%L.B`E
M<RDN("!+=6YN92!I:VME('1I;&;X:F4@;GEE(&%D<F5S<V5R('1I;"!H=FED
M;&ES=&YI;F<N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3<R,PIM<V=I
M9"`B36ES<VEN9R!A9&1R97-S('1O(')E9&ER96-T(&UE<W-A9V4@=&\B"FUS
M9W-T<B`B36%N9VQE<B!A9')E<W-E<B!A="!O;6%D<F5S<V5R92!T:6PB"@HC
M.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-S4U"FUS9VED(")-:7-S:6YG(')E
M87-O;B!F;W(@<F5J96-T(@IM<V=S='(@(DUA;F=L97(@Y7)S86<@9F]R(&%F
M=FES;FEN9R(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$Y,C(*;7-G:60@
M(DUI<W-I;F<@<F5A<V]N(&EN('9A8V%T:6]N+B(*;7-G<W1R(")-86YG;&5R
M(.5R<V%G(&D@9F5R:64N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R
M+FEN8SHT,`IM<V=I9"`B36]V92(*;7-G<W1R(")&;'ET(@H*(SH@9FEL=&5R
M<RYP:'`Z,3(V(&9I;'1E<G,N<&AP.C(S.`IM<V=I9"`B36]V92!2=6QE($1O
M=VXB"FUS9W-T<B`B1FQY="!R96=E;"!N960B"@HC.B!F:6QT97)S+G!H<#HQ
M,C<@9FEL=&5R<RYP:'`Z,C,W"FUS9VED(")-;W9E(%)U;&4@57`B"FUS9W-T
M<B`B1FQY="!R96=E;"!O<"(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A
M=&EO;BYI;F,Z-#(*;7-G:60@(DY?=6UB97(@;V8@9&%Y<R!B971W965N('9A
M8V%T:6]N(')E<&QI97,Z(@IM<V=S='(@(D%N=&%L(&1A9V4@;65L;&5M(&9E
M<FEE+7-V87(Z(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+6YO;F4N
M:6YC.C0@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHX"B,Z(&QI8B]3
M=&]R86=E+G!H<#HW,30*;7-G:60@(DYE=R!2=6QE(@IM<V=S='(@(DYY(')E
M9V5L(@H*(SH@;&EB+TEN9V\N<&AP.C$Y-"!L:6(O26YG;RYP:'`Z,3DV"B,L
M('!H<"UF;W)M870*;7-G:60@(DYO(%PB)7-<(B!E;&5M96YT(&9O=6YD(&EN
M(&)A8VME;F0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB(&5L96UE
M;G0@:6MK92!F=6YD970@:2`\96T^8F%C:V5N9#PO96T^+6MO;F9I9W5R871I
M;VXN(@H*(SH@;&EB+TEN9V\N<&AP.C$Y,@IM<V=I9"`B3F\@8F%C:V5N9"!C
M;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0B"FUS9W-T<B`B26YG96X@/&5M/F)A
M8VME;F0\+V5M/B!K;VYF:6=U<F5R970@9F]R(&1E;FYE('-E<G9E<B(*"B,Z
M(&QI8B]);F=O+G!H<#HQ-CD*;7-G:60@(DYO(&)A8VME;F1S(&-O;F9I9W5R
M960@:6X@8F%C:V5N9',N<&AP(@IM<V=S='(@(DEN9V5N(#QE;3YB86-K96YD
M<SPO96T^(&MO;F9I9W5R97)E="!I(#QC;V1E/F)A8VME;F1S+G!H<#PO8V]D
M93XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!F:6QT97)S+B!#;&EC:R!<(B5S7"(@
M=&\@8W)E871E(&$@;F5W(&9I;'1E<BXB"FUS9W-T<B`B26YG96X@9FEL=')E
M+B!#;&EC:R!<(B5S7"(@9F]R(&%T(&]P<F5T=&5T(&5T(&YY="!F:6QT97(N
M(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3,R-R!L:6(O4V-R:7!T+W-I
M979E+G!H<#HQ-#(P"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$U.30*;7-G
M:60@(DYO(&AE861E<G,@<W!E8VEF:65D(@IM<V=S='(@(DEN9V5N(&)R979H
M;W9E9&5R(&%N9VEV970B"@HC.B!S8W)I<'0N<&AP.C8W"FUS9VED(").;R!S
M8W)I<'0@9V5N97)A=&5D+B(*;7-G<W1R(")38W)I<'0@:6MK92!G96YE<F5R
M970N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,38P.0IM<V=I9"`B3F\@
M<W1R:6YG<R!S<&5C:69I960B"FUS9W-T<B`B26YG96X@=&5K<W0M<W1R96YG
M92!A;F=I=F5T(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U.`IM<V=I9"`B3F]T
M(&5Q=6%L('1O(@IM<V=S='(@(DEK:V4@;&EG(&UE9"(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS,38*;7-G:60@(D]N;'D@9FQA9R!T:&4@;65S<V%G92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3D*;7-G:60@(D]P
M=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+B(*;7-G<W1R("));F1S=&EL
M;&EN9V5R('9E9'+X<F5N9&4@<V-R:7!T+6]P9&%T97)I;F<N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM
M<V=S='(@(D%N9')E(&EN9'-T:6QL:6YG97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]N97=?9F]L9&5R+FIS.C8*;7-G:60@(E!L96%S92!E;G1E<B!T
M:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B26YD=&%S="!V
M96YL:6=S="!N879N970@=&EL(&1E;B!N>64@;6%P<&4Z(@H*(SH@=&5M<&QA
M=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHV,`IM<V=I9"`B4E]E87-O;B(*
M;7-G<W1R("+%<G-A9R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-C,*
M;7-G:60@(E)E8V5I=F5D(@IM<V=S='(@(DUO9'1A9V5T(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C(Y-PIM<V=I9"`B4F5D:7)E8W0@=&\B"FUS9W-T<B`B3VUA
M9')E<W-E<B!T:6PB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4P"FUS9VED(")2
M96=U;&%R(&5X<')E<W-I;VXB"FUS9W-T<B`B4F5G=6SF<F4@=61T<GEK(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,Q,@IM<V=I9"`B4F5J96-T('=I=&@@<F5A
M<V]N(@IM<V=S='(@(D%F=FES(&UE9"#E<G-A9R(*"B,Z(&-O;F9I9R]F:65L
M9',N<&AP+F1I<W0Z-34*;7-G:60@(E)E<V5N="!4;R(*;7-G<W1R(")'96YS
M96YD="!T:6PB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4Q"FUS9VED
M(")297-E;G0M9G)O;2(*;7-G<W1R(")'96YS96YD="!F<F$B"@HC.B!T96UP
M;&%T97,O<G5L92]F;V]T97(N:6YC.C8P"FUS9VED(")2971U<FX@=&\@1FEL
M=&5R<R!,:7-T(@IM<V=S='(@(E9E;F0@=&EL8F%G92!T:6P@9FEL=&5R9F]R
M=&5G;F5L<V5N(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N
M:6YC.C(T('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT,0HC
M.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C<Q('1E;7!L871E
M<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,T"FUS9VED(")2971U<FX@=&\@4G5L
M97,@3&ES="(*;7-G<W1R(")696YD('1I;&)A9V4@=&EL(')E9V5L9F]R=&5G
M;F5L<V5N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHS-`IM
M<V=I9"`B4G5L92(*;7-G<W1R(")296=E;"(*"B,Z(&9I;'1E<G,N<&AP.C8P
M"FUS9VED(")2=6QE($-O<&EE9"(*;7-G<W1R(")296=E;"!K;W!I97)E="(*
M"B,Z(&9I;'1E<G,N<&AP.C,Y"FUS9VED(")2=6QE($1E;&5T960B"FUS9W-T
M<B`B4F5G96P@<VQE='1E="(*"B,Z(&9I;'1E<G,N<&AP.C<V"FUS9VED(")2
M=6QE($1I<V%B;&5D(@IM<V=S='(@(E)E9V5L('-LY65T(&9R82(*"B,Z(&9I
M;'1E<G,N<&AP.C@Q"FUS9VED(")2=6QE($5N86)L960B"FUS9W-T<B`B4F5G
M96P@<VSE970@=&EL(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHS
M,PIM<V=I9"`B4G5L92!.86UE(@IM<V=S='(@(E)E9V5L;F%V;B(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!
M4E143%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR,R!T96UP;&%T97,O8FQA8VML
M:7-T+V)L86-K;&ES="YI;F,Z-#`*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A
M8V%T:6]N+FEN8SHW,"!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHS
M,PHC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C4Y"FUS9VED(")3879E
M(@IM<V=S='(@(D=E;2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S
M+FEN8SHR.0IM<V=I9"`B4V%V92!3971T:6YG<R(*;7-G<W1R(")'96T@:6YD
M<W1I;&QI;F=E<B(*"B,Z('1E;7!L871E<R]S8W)I<'0O:&5A9&5R+FEN8SHR
M"FUS9VED(")38W)I<'0B"FUS9W-T<B`B4V-R:7!T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$X"FUS9VED(")38W)I<'0@57!D871I;F<B"FUS9W-T
M<B`B3W!D871E<F5R('-C<FEP="(*"B,Z(&QI8B]);F=O+G!H<#HR,3<*;7-G
M:60@(E-C<FEP="!N;W0@=7!D871E9"XB"FUS9W-T<B`B4V-R:7!T(&EK:V4@
M;W!D871E<F5T+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S`*;7-G:60@(E-C<FEP
M="!S=6-C97-S9G5L;'D@86-T:79A=&5D+B(*;7-G<W1R(")38W)I<'0@<VSE
M970@=&EL+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,CD*;7-G:60@(E-C<FEP="!S
M=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-C<FEP="!S;.5E
M="!F<F$N(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHR.0IM<V=I
M9"`B4V5E;B(*;7-G<W1R(")3970B"@HC.B!R=6QE+G!H<#HQ.3`*;7-G:60@
M(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(E;F;&<@970@9F5L="(*"B,Z(&QI
M8B]);F=O+G!H<#HT.0IM<V=I9"`B4V5L96-T('1A<F=E="!F;VQD97(B"FUS
M9W-T<B`B5N9L9R!E;F1E;&EG(&UA<'!E(@H*(SH@<G5L92YP:'`Z,C(W"FUS
M9VED(")396QF+41E9FEN960@2&5A9&5R(@IM<V=S='(@(D5G96XM9&5F:6YE
M9"!B<F5V:&]V960B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,U"FUS
M9VED(")396YD97(B"FUS9W-T<B`B069S96YD97(B"@HC.B!F:6QT97)S+G!H
M<#HY-0IM<V=I9"`B4V5T=&EN9W,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM
M<V=S='(@(E!RYF9E<F5N8V5R;F4@;W!D871E<F5T+B(*"B,Z('1E;7!L871E
M<R]S8W)I<'0O86-T:79A=&4N:6YC.C(T"FUS9VED(")3:&]W($%C=&EV92!3
M8W)I<'0B"FUS9W-T<B`B5FES(&%K=&EV="!S8W)I<'0B"@HC.B!T96UP;&%T
M97,O<V-R:7!T+V%C=&EV871E+FEN8SHS,0IM<V=I9"`B4VAO=R!#=7)R96YT
M(%-C<FEP="(*;7-G<W1R(")6:7,@;G5VYG)E;F1E('-C<FEP="(*"B,Z(&-O
M;F9I9R]F:65L9',N<&AP+F1I<W0Z.#,*;7-G:60@(E-I>F4B"FUS9W-T<B`B
M4W3X<G)E;'-E(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHT.0IM
M<V=I9"`B4W1O<"!C:&5C:VEN9R!I9B!T:&ES(')U;&4@;6%T8VAE<S\B"FUS
M9W-T<B`B4W1O<"!V:61E<F4@=6YD97)S^&=E;'-E<BP@:'9I<R!D96YN92!R
M96=E;"!P87-S97(_(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N
M+FEN8SHU,0IM<V=I9"`B4W5B:F5?8W0@;V8@=F%C871I;VX@;65S<V%G93HB
M"FUS9W-T<B`B16UN92!T:6P@9F5R:64M8F5S:V5D.B(*"B,Z(&-O;F9I9R]F
M:65L9',N<&AP+F1I<W0Z,S$*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B16UN
M92(*"B,Z(&QI8B]A<&DN<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!A9&1R97-S(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&)L86-K
M;&ES="XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3`T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!A9&1R97-S(%PB)7-<(B!H87,@8F5E;B!A9&1E
M9"!T;R!Y;W5R('=H:71E;&ES="XB"FUS9W-T<B`B(@H*(SH@;&EB+TEN9V\N
M<&AP.C$R-0IM<V=I9"`B5&AE(&1R:79E<B!S86ED.B`B"FUS9W-T<B`B365K
M86YI<VUE;B!S86=D93H@(@H*(SH@;&EB+TEN9V\N<&AP.C$R-`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE('-C<FEP="XB"FUS
M9W-T<B`B1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&%K=&EV97)I;F<@868@
M<V-R:7!T970N(@H*(SH@;&EB+TEN9V\N<&AP.C$R,PIM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*;7-G<W1R
M(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@9&5A:W1I=F5R:6YG(&%F('-C
M<FEP=&5T+B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,C<*;7-G:60@
M(E1O(@IM<V=S='(@(E1I;"(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E
M<BYH=&UL.C(X"B,L(&9U>GIY"FUS9VED(")4;SHB"FUS9W-T<B`B5&EL(@H*
M(SH@;&EB+U-C<FEP="YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")+
M86X@:6MK92!I;F1LYG-E(&1E9FEN:71I;VYE;B!A9B`E<RXB"@HC.B!F:6QT
M97)S+G!H<#HQ-38@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHU
M"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(V,@IM<V=I9"`B5F%C871I
M;VXB"FUS9W-T<B`B1F5R:64B"@HC.B!V86-A=&EO;BYP:'`Z-S(*;7-G:60@
M(E9A8V%T:6]N($5D:70B"FUS9W-T<B`BQFYD<F4@9F5R:64B"@HC.B!L:6(O
M4V-R:7!T+W-I979E+G!H<#HS-3$*;7-G:60@(E9A8V%T:6]N($UE<W-A9V4B
M"FUS9W-T<B`B1F5R:64M8F5S:V5D(@H*(SH@=F%C871I;VXN<&AP.C$V"FUS
M9VED(")686-A=&EO;B!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT
M(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(D9E<FEE(&5R(&EK:V4@=6YD
M97)S=/AT=&5T(&D@9&5N(&YU=N9R96YD92!F:6QT97)M96MA;FES;64N(@H*
M(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C$V"FUS9VED
M(")7:%]I=&5L:7-T(&%D9')E<W-E<SHB"FUS9W-T<B`B2'9I9&QI<W1E9&4@
M861R97-S97(Z(@H*(SH@9FEL=&5R<RYP:'`Z,34P('1E;7!L871E<R]W:&ET
M96QI<W0O=VAI=&5L:7-T+FEN8SHX"FUS9VED(")7:&ET96QI<W0B"FUS9W-T
M<B`B2'9I9&QI<W1N:6YG(@H*(SH@=VAI=&5L:7-T+G!H<#HU-0IM<V=I9"`B
M5VAI=&5L:7-T($5D:70B"FUS9W-T<B`BQFYD<F4@:'9I9&QI<W1E(@H*(SH@
M=VAI=&5L:7-T+G!H<#HQ.`IM<V=I9"`B5VAI=&5L:7-T(&ES(&YO="!S=7!P
M;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T
M<B`B2'9I9&QI<W1N:6YG(&5R(&EK:V4@=6YD97)S=/AT=&5T(&D@9&5N(&YU
M=N9R96YD92!F:6QT97)M96MA;FES;64N(@H*(SH@;&EB+U-C<FEP="]P<F]C
M;6%I;"YP:'`Z,C,T(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(Y-PHC.B!L:6(O
M4V-R:7!T+VUA:6QD<F]P+G!H<#HR,#(*;7-G:60@(E=H:71E;&ES=&5D($%D
M9')E<W-E<R(*;7-G<W1R(")(=FED;&ES=&5D92!A9')E<W-E<B(*"B,Z(&-O
M;F9I9R]F:65L9',N<&AP+F1I<W0Z-SD*;7-G:60@(E@M4')I;W)I='DB"FUS
M9W-T<B`B6"U0<FEO<FET>2(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z
M-C<*;7-G:60@(E@M4W!A;2U,979E;"(*;7-G<W1R(")8+5-P86TM3&5V96PB
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C<Q"FUS9VED(")8+5-P86TM
M4V-O<F4B"FUS9W-T<B`B6"U3<&%M+5-C;W)E(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HW-0IM<V=I9"`B6"U3<&%M+5-T871U<R(*;7-G<W1R(")8
M+5-P86TM4W1A='5S(@H*(SH@9FEL=&5R<RYP:'`Z-3,@<G5L92YP:'`Z,30T
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!R=6QE<RXB"FUS9W-T<B`B(@H*(SH@9FEL
M=&5R<RYP:'`Z-#4@<G5L92YP:'`Z,C$*;7-G:60@(EEO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&]R(&5D:70@8W5S=&]M(')U;&5S+B(*;7-G<W1R
M("(B"@HC.B!V86-A=&EO;BYP:'`Z,S`*;7-G:60@(B(*(EEO=2!M=7-T('-P
M96-I9GD@870@;&5A<W0@;VYE(&5M86EL(&%D9')E<W,@9F]R('=H:6-H('1H
M92!V86-A=&EO;B!M97-S86=E<R`B"B)S:&]U;&0@8F4@86-T:79A=&5D+B(*
M;7-G<W1R("(B"B)$=2!S:V%L(&%N9VEV92!M:6YD<W0@Z6X@92UM86EL+6%D
M<F5S<V4@:'9O<G1I;"!F97)I92UB97-K961E<B!S:V%L(';F<F4@(@HB86MT
M:79E<F5T+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<X(&QI8B]38W)I
M<'0O:6UA<"YP:'`Z,S`Q(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$U"FUS9VED
M(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6TEN=&5T(&5M;F5=(@H*(SH@=&5M
M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,C0*;7-G:60@(E]!9&1R97-S
M*&5S*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R(")!9')E<W-E<B!A="!V:61E
M<F5S96YD92!T:6PZ(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N
M+FEN8SHR,PIM<V=I9"`B7T%D9')E<W-E<R!T;R!N;W0@<V5N9"!R97-P;VYS
M97,@=&\Z(@IM<V=S='(@(D%D<F5S<V5R+"!S;VT@9&5R(&EK:V4@<VMA;"!S
M96YD97,@<F5S<&]N<R!T:6PZ(@H*(SH@;&EB+TEN9V\N<&AP.C,P-0IM<V=I
M9"`B7T)L86-K;&ES="(*;7-G<W1R(")3;W)T;&ES=&YI;F=E<B(*"B,Z('1E
M;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ.`IM<V=I9"`B7T1E
M;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`B4VQE="!B97-K960@
M=&]T86QT(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC
M.C,Q"FUS9VED(")?16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z
M(@IM<V=S='(@(DMU;B#I;B!A9')E<W-E('!R+B!L:6YI93HB"@HC.B!L:6(O
M26YG;RYP:'`Z,S$Q"FUS9VED(")?1F]R=V%R9"(*;7-G<W1R(")6:61E<F5S
M96YD(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3<*;7-G
M:60@(E]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_
M(@IM<V=S='(@(D)E:&]L9"!E;B!K;W!I(&%F(&)E<VME9&5R(&D@9&5N;F4@
M:V]N=&\_(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC
M.C(R"FUS9VED(")?36]V92!M97-S86=E('1O(&9O;&1E<CHB"FUS9W-T<B`B
M1FQY="!B97-K961E<B!T:6P@;6%P<&4Z(@H*(SH@=&5M<&QA=&5S+W9A8V%T
M:6]N+W9A8V%T:6]N+FEN8SHQ,PIM<V=I9"`B7TUY(&5M86EL(&%D9')E<W-E
M<SHB"FUS9W-T<B`B36EN92!E+6UA:6PM861R97-S97(Z(@H*(SH@;&EB+TEN
M9V\N<&AP.C,Q-`IM<V=I9"`B7U-C<FEP="(*;7-G<W1R(")38W)I<'0B"@HC
M.B!L:6(O26YG;RYP:'`Z,S`X"FUS9VED(")?5F%C871I;VXB"FUS9W-T<B`B
M1F5R:64B"@HC.B!L:6(O26YG;RYP:'`Z,S`R"FUS9VED(")?5VAI=&5L:7-T
M(@IM<V=S='(@(DAV:61L:7-T;FEN9V5R(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M9FEL=&5R+FEN8SHT"FUS9VED(")A;F0B"FUS9W-T<B`B;V<B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]F:6QT97(N:'1M;#HQ-@IM<V=I9"`B9&ES86)L960@
M+2!C;&EC:R!T;R!E;F%B;&4B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z
M,3@P"FUS9VED(")F:65L9"(*;7-G<W1R(")B<F5V:&]V961E(@H*(SH@;&EB
M+U-C<FEP="]M86EL9')O<"YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")M86EL
M9')O<"!S8W)I<'0@9V5N97)A=&5D(&)Y($EN9V\B"FUS9W-T<B`B<')O8VUA
M:6P@<V-R:7!T(&=E;F5R97)E="!A9B!);F=O(@H*(SH@9FEL=&5R<RYP:'`Z
M,3@P"FUS9VED(")M871C:"(*;7-G<W1R(")P87-S97(@=&EL(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")O<B(*;7-G<W1R(")E
M;&QE<B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C$R.`IM<V=I9"`B
M<')O8VUA:6P@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O(@IM<V=S='(@(G!R
M;V-M86EL('-C<FEP="!G96YE<F5R970@868@26YG;R(*"B,Z(&QI8B]38W)I
M<'0O<VEE=F4N<&AP.C$P.0IM<V=I9"`B<VEE=F4@9FEL=&5R(&=E;F5R871E
M9"!B>2!);F=O(@IM<V=S='(@(G-I979E(&9I;'1E<B!G96YE<F5R970@868@
M26YG;R(*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6YG;R]P;R]C<U]#6BYP;P``````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`U,#0W,``Q,#0Q-S,V,C<T-P`P,3<S-#4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R!#
M>F5C:"!T<F%N<VQA=&EO;G,@9F]R($EN9V\N"B,@0V]P>7)I9VAT("A#*2`R
M,#`T($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@
M=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*
M(R!0879E;"!#:'ET:6P@/'!A=F5L0&-H>71I;"YO<F<^+"`R,#`T+@HC"FUS
M9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!);F=O(#`N
M,2UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R
M9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ
M,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`T+3$Q+3(Q(#`Y.C`Q
M+3`X,#!<;B(*(DQA<W0M5')A;G-L871O<CH@4&%V96P@0VAY=&EL(#QP879E
M;$!C:'ET:6PN;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH
M;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,EQN(@HB0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N
M<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]/3$@)B8@;B4Q,#`A/3$Q(#\@,"`Z
M(&XE,3`^/3(@)B8@;B4B"B(Q,#P]-"`F)B`H;B4Q,#`\,3`@?'P@;B4Q,#`^
M/3(P*2`_(#$@.B`R*3M<;B(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B
M(&%N9"(*;7-G<W1R("(@82(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B
M(&]R(@IM<V=S='(@(B!N96)O(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B
M;&%C:VQI<W0N:6YC.C$W"FUS9VED(")!8W1I;VX@9F]R(&)L86-K;&ES=&5D
M(&%D9')E<W-E<SHB"FUS9W-T<B`B06MC92!P<F\@861R97-Y(&YA(.AE<F[I
M(&QI<W1I;NPZ(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z
M,3`*;7-G:60@(D%C=&EV871E(%-C<FEP="(*;7-G<W1R(")!:W1I=F]V870@
M4VMR:7!T(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06-T:79A=&EN9R!T:&4@<V-R:7!T(&9O<B!<(B5S7"(@
M9F%I;&5D.B`H)60I("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W-E='1I;F=S+FEN8SHV"FUS9VED(")!9&1I=&EO;F%L(%-E='1I;F=S
M(@IM<V=S='(@(D1O<&SR=6KM8^T@3F%S=&%V96[M(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O:&5A9&5R+FEN8SHT-`IM<V=I9"`B06QL(&]F('1H92!F;VQL;W=I
M;F<B"FUS9W-T<B`B5KEE(&-O(&[A<VQE9'5J92(*"B,Z(&QI8B]A<&DN<&AP
M.C4T"B,L(&9U>GIY"FUS9VED(")!;&QO=R!2=6QE<R(*;7-G<W1R(").;W;I
M(%!R879I9&QO(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,PIM
M<V=I9"`B06YS=V5R960B"FUS9W-T<B`B6F]D<&]V['IE;NDB"@HC.B!T96UP
M;&%T97,O<G5L92]H96%D97(N:6YC.C0U"FUS9VED(")!;GD@;V8@=&AE(&9O
M;&QO=VEN9R(*;7-G<W1R(")#;VMO;&EV(&-O(&[A<VQE9'5J92(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z,3$*;7-G:60@(D%P<&QY($9I
M;'1E<G,B"FUS9W-T<B`B07!L:6MO=F%T($9I;'1R>2(*"B,Z(&9I;'1E<G,N
M<&AP.C(Q-`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T
M92!T:&ES(')U;&4_(@IM<V=S='(@(DIS=&4@<VD@:FES=.TL(+YE(&-H8V5T
M92!V>6UA>F%T('1O=&\@<')A=FED;&\_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S"FUS9VED(")!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R
M:7!T(&%F=&5R(&5A8V@@8VAA;F=E/R(*;7-G<W1R(")/8FYO=G1E('-K<FEP
M="!A=71O;6%T:6-K>2!P;R!K8;YDZ2!Z;>QN[#\B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C0W"FUS9VED(")"8V,B"FUS9W-T<B`B4VMR>73A($MO
M<&EE(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-`IM<V=I9"`B0F5G:6YS('=I
M=&@B"FUS9W-T<B`B6F'H[6[A(',B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C$P-B!L:6(O1')I=F5R+VQD87`N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!F:6QT
M97)S+G!H<#HQ-#0@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC
M.C<*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R("+(97)NX2!,:7-T:6YA(@H*
M(SH@8FQA8VML:7-T+G!H<#HQ,#`*;7-G:60@(D)L86-K;&ES="!%9&ET(@IM
M<V=S='(@(MIP<F%V82#(97)NZ2!,:7-T:6YA(@H*(SH@8FQA8VML:7-T+G!H
M<#HQ-PIM<V=I9"`B0FQA8VML:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE
M(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`BR&5R;N$@3&ES
M=&EN82!N96[M('IA:')N=73A('8@<V]UZ&%S;NEM(&1R:79E<G4@<')O(&9I
M;'1R;W;A;NTN(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C`W(&QI
M8B]38W)I<'0O;6%I;&1R;W`N<&AP.C$W-0IM<V=I9"`B0FQA8VML:7-T960@
M061D<F5S<R(*;7-G<W1R(")!9')E<V$@;F$@R&5R;N$@3&ES=&EN["(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(T,PIM<V=I9"`B0FQA8VML:7-T960@
M061D<F5S<V5S(@IM<V=S='(@(D%D<F5S>2!N82#(97)NX2!,:7-T:6[L(@H*
M(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HX.`IM<V=I9"`B0F]D>2(*;7-G
M<W1R("):<'+A=F$B"@HC.B!F:6QT97)S+G!H<#HQ.#(@<G5L92YP:'`Z,C@Q
M"FUS9VED(")#87-E(%-E;G-I=&EV92(*;7-G<W1R(")2;WIL:;EU:F4@5F5L
M:^$@82!-86SA(%#M<VUE;F$B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T
M.C0S"FUS9VED(")#8R(*;7-G<W1R(")+;W!I92(*"B,Z(')U;&4N<&AP.C$R
M,B!W:&ET96QI<W0N<&AP.C,V(&9O<G=A<F0N<&AP.C,S('9A8V%T:6]N+G!H
M<#HT,0HC.B!B;&%C:VQI<W0N<&AP.C8Y"FUS9VED(")#:&%N9V5S('-A=F5D
M+B(*;7-G<W1R("):;>QN>2!5;&^^96YY+B(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z-S4*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R("(B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0P"FUS9VED(")#;VYT86EN<R(*;7-G
M<W1R(")/8G-A:'5J92(*"B,Z(&9I;'1E<G,N<&AP.C(R-2!F:6QT97)S+G!H
M<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2`E<R(*;7-G<W1R(")+
M;W#M<F]V870@)7,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z-S8S"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O<'D@;V8@)7,B"FUS9W-T<B`B2V]P:64@)7,B"@HC
M.B!L:6(O26YG;RYP:'`Z-3(*;7-G:60@(D-R96%T92!N97<@9F]L9&5R(@IM
M<V=S='(@(E9Y='9O^&ET(&YO=F]U('-L;[YK=2(*"B,Z(&QI8B]38W)I<'0O
M<')O8VUA:6PN<&AP.C,S-B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HR-SD*
M;7-G:60@(D1)4T%"3$5$.B`B"FUS9W-T<B`B1$5!2U1)5D]6P4Y/.B`B"@HC
M.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ-PIM<V=I9"`B1&5A
M8W1I=F%T92!38W)I<'0B"FUS9W-T<B`B1&5A:W1I=F]V870@4VMR:7!T(@H*
M(SH@9FEL=&5R<RYP:'`Z,C$T(&9I;'1E<G,N<&AP.C(Q-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@)7,B"FUS9W-T<B`B4VUA>F%T("5S(@H*(SH@
M=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHS,`IM<V=I9"`B1&5L971E($-O
M;F1I=&EO;B(*;7-G<W1R(")3;6%Z870@4&]D;>UN:W4B"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,CDR"FUS9VED(")$96QE=&4@;65S<V%G92!C;VUP;&5T96QY
M(@IM<V=S='(@(MIP;&[L('-M87IA="!Z<'+A=G4B"@HC.B!T96UP;&%T97,O
M<G5L92]F;V]T97(N:6YC.C,U"FUS9VED(")$96QE=&5D(@IM<V=S='(@(E-M
M87KA;F\B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,C@P"FUS9VED(")$96QI=F5R
M(&EN=&\@;7D@24Y"3U@B"FUS9W-T<B`B1&]R=>AI="!D;R!0V,U#2$]:S2!0
M3ZE462(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,#8*;7-G:60@(D1E;&EV97(@
M:6YT;R!M>2!)3D)/6"!A;F0@8V]P>2!T;R(*;7-G<W1R(")$;W)UZ&ET(&1O
M(%#8S4-(3UK-(%!/J519(&$@:V]P:6D@9&\B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S`Q"FUS9VED(")$96QI=F5R(&EN=&\@;7D@24Y"3U@@86YD(')E9&ER
M96-T('1O(@IM<V=S='(@(D1O<G7H:70@9&\@4-C-0TA/6LT@4$^I5%D@82!P
M^&5S;>QR;W9A="!D;R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR.#8*;7-G:60@
M(D1E;&EV97(@=&\@9F]L9&5R(@IM<V=S='(@(D1O<G7H:70@9&\@<VQOOFMY
M(@H*(SH@9FEL=&5R<RYP:'`Z,C0Q(&9I;'1E<G,N<&AP.C(T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$:7-A8FQE("5S(@IM<V=S='(@(D1E86MT:79O=F%T
M("5S(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C$P
M('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ,`HC.B!T96UP
M;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C8@=&5M<&QA=&5S+V9O<G=A
M<F0O9F]R=V%R9"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN
M8SHR-@IM<V=I9"`B1&ES86)L960B"FUS9W-T<B`B1&5A:W1I=F]VX6YO(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C$S"FUS9VED(")$
M:7-P;&%Y(&1E=&%I;&5D(&YO=&EF:6-A=&EO;B!W:&5N(&5A8V@@9FEL=&5R
M(&ES(&%P<&QI960_(@IM<V=S='(@(EIO8G)A>FET(&ED971A:6QN[2!U<&]Z
M;W)N[&[M('#X:2!K8;YDZ6T@<&]UOFET[2!F:6QT<OD_(@H*(SH@=&5M<&QA
M=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHS-`IM<V=I9"`B1&\@7VYO="!S
M96YD(')E<W!O;G-E<R!T;R!B=6QK(&]R(&QI<W0@;65S<V%G97,B"FUS9W-T
M<B`B7TYE<&]S[6QA="!O9'!O=NQD:2!N82!Z<')A=GD@;WIN8>AE;ND@8G5L
M:R!N96)O(&YA('IP<N%V>2!Z(&QI<W3Y(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@=&AI<SHB"FUS9W-T<B`B4')O=NES
M=#HB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0U"FUS9VED(")$;V5S;B=T(&)E
M9VEN('=I=&@B"FUS9W-T<B`B3F5ZX>CM;N$@;F$Z(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,T,0IM<V=I9"`B1&]E<VXG="!C;VYT86EN(@IM<V=S='(@(DYE
M;V)S86AU:F4B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0W"FUS9VED(")$;V5S
M;B=T(&5N9"!W:71H(@IM<V=S='(@(DYE:V]NZ.T@;F$Z(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C,T.0IM<V=I9"`B1&]E<VXG="!E>&ES="(*;7-G<W1R(").
M965X:7-T=6IE(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,@IM<V=I9"`B1&]E
M<VXG="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S='(@(DYE<VAO
M9'5J92!S92(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,S$*
M;7-G:60@(D5D:70B"FUS9W-T<B`B57!R879I="(*"B,Z(&9I;'1E<G,N<&AP
M.C(P,R!F:6QT97)S+G!H<#HR,#4@9FEL=&5R<RYP:'`Z,C`Y(&9I;'1E<G,N
M<&AP.C(Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@
M(E5P<F%V:70@)7,B"@HC.B!F:6QT97)S+G!H<#HR-#4@9FEL=&5R<RYP:'`Z
M,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D5N86)L92`E<R(*;7-G<W1R(")!
M:W1I=F]V870@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC
M.C,W"FUS9VED(")%;F%B;&5D(@IM<V=S='(@(D%K=&EV;W;A;F\B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S0V"FUS9VED(")%;F1S('=I=&@B"FUS9W-T<B`B
M2V]NZ.T@;F$B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4W"FUS9VED(")%<75A
M;"!T;R(*;7-G<W1R(")2;VYVX2!S92(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,3,Y(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30Y(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,34X"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,38X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@8W5R<F5N="!S8W)I<'0Z
M("@E9"D@)7,B"FUS9W-T<B`B(@H*(SH@8FQA8VML:7-T+G!H<#HV-PIM<V=I
M9"`B17)R;W(@<V%V:6YG(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C(*;7-G:60@(D5X:7-T:6YG(%)U
M;&5S(@IM<V=S='(@(D5X:7-T=6KM8^T@4')A=FED;&$B"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,S0X"FUS9VED(")%>&ES=',B"FUS9W-T<B`B17AI<W1U:F4B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%>'!E8W1E9"`Q(&]B:F5C="P@9V]T("5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,C`*;7-G:60@(D9I
M;'1E<B!!;&P@365S<V%G97,B"FUS9W-T<B`B1FEL=')O=F%T(%:Y96-H;GD@
M6G!RX79Y(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(R
M"FUS9VED(")&:6QT97(@3VYL>2!3965N($UE<W-A9V5S(@IM<V=S='(@(D9I
M;'1R;W9A="!0;W5Z92!0<F]H;.UD;G5TZ2!:<'+A=GDB"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,C$*;7-G:60@(D9I;'1E<B!/;FQY
M(%5N<V5E;B!-97-S86=E<R(*;7-G<W1R(")I;'1R;W9A="!0;W5Z92!.97!R
M;VAL[61N=73I(%IP<N%V>2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I
M;F=S+FEN8SHQ.`IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B36^^
M;F]S=&D@1FEL='+Y(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHR
M-0IM<V=I9"`B1FEL=&5R(%)U;&4B"FUS9W-T<B`B1FEL=')O=F%C[2!0<F%V
M:61L;R(*"B,Z(&9I;'1E<G,N<&AP.C$P.0IM<V=I9"`B1FEL=&5R(%)U;&5S
M(@IM<V=S='(@(D9I;'1R;W9A8^T@4')A=FED;&$B"@HC.B!S8W)I<'0N<&AP
M.C4R"FUS9VED(")&:6QT97(@4V-R:7!T($1I<W!L87DB"FUS9W-T<B`B6F]O
M8G)A>F5N[2!&:6QT<F]V86/M:&\@4VMR:7!T=2(*"B,Z(&QI8B]);F=O+G!H
M<#HS,#`*;7-G:60@(D9I;'1E<B!?4G5L97,B"FUS9W-T<B`B1FEL=')O=F%C
M[2!?4')A=FED;&$B"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H
M<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B1FEL=')A8V4Z("5S('IP<N%V*&$I(&)Y;&\H82D@:V]P[7)O=N%N
M;RAA*2!D;R!S;&^^:WD@7"(E<UPB+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP
M:'`Z,S`U"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@
M)7,@;65S<V%G92AS*2!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B1FEL
M=')A8V4Z("5S('!RX78H82D@8GEL;RAA*2!V>6UA>N%N;RAA*2XB"@HC.B!L
M:6(O4V-R:7!T+VEM87`N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D
M('1O('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")&:6QT<F%C93H@)7,@
M>G!RX78H82D@8GEL;RAA*2!P^&5S=6YU=&\H82D@9&\@<VQOOFMY(%PB)7-<
M(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C$X-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@=&AA="!M
M871C:&5D('1H92!B;&%C:VQI<W0@=V5R92!D96QE=&5D+B(*;7-G<W1R(")&
M:6QT<F%C93H@)7,@>G!RX78H82D@:G-O=2]J92!N82#H97)NZ2!L:7-T:6[L
M(&$@8GEL;RAA*2!V>6UA>N%N>2AA*2XB"@HC.B!L:6(O4V-R:7!T+VEM87`N
M<&AP.C,Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I
M='DZ(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C
M;W!I960@=&\@=&AE("(*(F9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D9I;'1R
M86-E.B!:<'+A=F$@7"(E<UPB(&]D(%PB)7-<(B!B>6QA(&MO<.UR;W;A;F$@
M9&\@<VQOOFMY(%PB)7-<(BXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R(")&:6QT<F%C93H@6G!RX79A(%PB)7-<(B!O9"!<(B5S7"(@8GEL
M82!V>6UA>N%N82XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C(W-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M97-S
M86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@
M9F]L9&5R("(*(EPB)7-<(BXB"FUS9W-T<B`B1FEL=')A8V4Z(%IP<N%V82!<
M(B5S7"(@;V0@7"(E<UPB(&)Y;&$@</AE<W5N=71A(&1O('-L;[YK>2!<(B5S
M7"(N(@H*(SH@<G5L92YP:'`Z,38P"FUS9VED(")&:6QT97(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")&:6QT<F]V86/M('!R879I9&QA(&YE8GEL:2!N86QE>F5N
M>2XB"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C0R"FUS9VED(")&
M;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z(@IM<V=S='(@
M(E!R;R!P^.UC:&]Z[2!Z<'+A=GD@:W1E<ND@;V)S86AU:NTZ(@H*(SH@9FEL
M=&5R<RYP:'`Z,38R('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C@*
M;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B4/AE<&]S;&%T(@H*(SH@9F]R=V%R
M9"YP:'`Z,38*;7-G:60@(D9O<G=A<F0@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")0^&5P;W-L
MX6[M(&YE;NT@>F%H<FYU=&\@=B!S;W7H87-NZ6T@9')I=F5R=2!P<F\@9FEL
M=')O=N%N[2XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR.#(@;&EB
M+U-C<FEP="]M86EL9')O<"YP:'`Z,C(T"FUS9VED(")&;W)W87)D<R(*;7-G
M<W1R(")0^&5P;W-LX6[M(@H*(SH@9F]R=V%R9"YP:'`Z-#8*;7-G:60@(D9O
M<G=A<F1S($5D:70B"FUS9W-T<B`B57!R879I="!0^&5P;W-LX6[M(@H*(SH@
M8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HS.0IM<V=I9"`B1G)O;2(*;7-G<W1R
M(")/9"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-34*;7-G:60@(D=R96%T97(@
M=&AA;B(*;7-G<W1R(")6['2Y[2!N9;XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,S4V"FUS9VED(")'<F5A=&5R('1H86X@;W(@97%U86P@=&\B"FUS9W-T<B`B
M5NQTN>T@;F5B;R!R;W9N;R(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI
M;F,Z,S$*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R(")$^6QEOFETZ2(*"B,Z
M(')U;&4N<&AP.C,V"FUS9VED("));F1I=FED=6%L(')U;&5S(&%R92!N;W0@
M<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM
M<V=S='(@(B(*(DEN9&EV:61UX6QN[2!P<F%V:61L82!N96IS;W4@>F%H<FYU
M='D@=B!S;W7H87-NZ6T@9')I=F5R=2!P<F\@9FEL=')O=N%N[2XB"@HC.B!L
M:6(O4V-R:7!T+W-I979E+G!H<#HQ.#4U"FUS9VED("));F5X:7-T86YT(&UA
M:6QB;W@@<W!E8VEF:65D(&9O<B!M97-S86=E(&1E;&EV97)Y+B(*;7-G<W1R
M(")">6QA('9Y8G+A;F$@;F5E>&ES='5J[6/M('-L;[YK82!P<F\@9&]R=>AE
M;NT@>G!RX79Y+B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#(*;7-G:60@(DES
M(@IM<V=S='(@(DIE(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T,PIM<V=I9"`B
M27-N)W0B"FUS9W-T<B`B3F5N[2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,C,*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@=&AE
M($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,PIM<V=I9"`B3&5S
M<R!T:&%N(@IM<V=S='(@(DUE;KGM(&YEOB(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS-30*;7-G:60@(DQE<W,@=&AA;B!O<B!E<75A;"!T;R(*;7-G<W1R(")-
M96ZY[2!N96)O(')O=FYO(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU
M.0IM<V=I9"`B3&ES="U)1"(*;7-G<W1R(")397IN86TM260B"@HC.B!T96UP
M;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,C`*;7-G:60@(DUA<E]K
M(&UE<W-A9V4@87,@9&5L971E9"(*;7-G<W1R(")/>FYA7^AI="!Z<'+A=G4@
M>F$@=GEM87IA;F]U(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHR
M-`IM<V=I9"`B36%R:R!M97-S86=E(&%S.B(*;7-G<W1R(")/>FYAZ&ET(%IP
M<N%V=2!J86MO.B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3$*;7-G:60@(DUA
M=&-H97,@*'=I=&@@<&QA8V5H;VQD97)S*2(*;7-G<W1R(")3:&]D=6IE('-E
M(@H*(SH@;&EB+V%P:2YP:'`Z-3<*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F
M(%)U;&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HT-S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@8FQA8VML
M:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S97,Z("5S
M+"`B"B)-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T(&%D9"!N
M97<@861D<F5S<V5S('1O(&)L86-K;&ES="XB"FUS9W-T<B`B(@HB0GEL('#X
M96MR;^AE;B!M87AI;>%L;NT@;&EM:70@861R97,@;F$@Z&5R;ND@;&ES=&EN
M["`H0V5L:V]V_2!P;^AE="!A9')E<SH@)2(*(G,L($UA>&EMX6QN[2!P;^AE
M="!A9')E<SH@)7,I+B!.96QZ92!P^&ED870@861R97-U(&YA(.AE<FYO=2!L
M:7-T:6YU+B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HU,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@=VAI=&5L:7-T960@861D
M<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S97,Z("5S+"`B"B)-87AI
M;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@861D<F5S
M<V5S('1O('=H:71E;&ES="XB"FUS9W-T<B`B(@HB0GEL('#X96MR;^AE;B!M
M87AI;>%L;NT@;&EM:70@861R97,@;F$@8NULZ2!L:7-T:6[L("A#96QK;W;]
M('!OZ&5T(&%D<F5S.B`E(@HB<RP@36%X:6WA;&[M('!OZ&5T(&%D<F5S.B`E
M<RDN($YE;'IE('#X:61A="!A9')E<W4@;F$@8NUL;W4@;&ES=&EN=2XB"@HC
M.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-S(S"FUS9VED(")-:7-S:6YG(&%D
M9')E<W,@=&\@<F5D:7)E8W0@;65S<V%G92!T;R(*;7-G<W1R(")#:'EB[2!A
M9')E<V$@<')O('#X97-M[')O=N%N[2!Z<'+A=GDB"@HC.B!L:6(O4V-R:7!T
M+W-I979E+G!H<#HQ-S4U"FUS9VED(")-:7-S:6YG(')E87-O;B!F;W(@<F5J
M96-T(@IM<V=S='(@(D-H>6+M(&3Y=F]D('!R;R!Z86WM=&YU=.T@>G!RX79Y
M(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3DR,@IM<V=I9"`B36ES<VEN
M9R!R96%S;VX@:6X@=F%C871I;VXN(@IM<V=S='(@(D-H>6+M(&3Y=F]D('8@
M9&]V;VQE;NDN(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHT
M,`IM<V=I9"`B36]V92(*;7-G<W1R(")0^&5S=6YO=70B"@HC.B!F:6QT97)S
M+G!H<#HQ,C8@9FEL=&5R<RYP:'`Z,C,X"FUS9VED(")-;W9E(%)U;&4@1&]W
M;B(*;7-G<W1R(")0;W-U;F]U="!0<F%V:61L;R!$;VSY(@H*(SH@9FEL=&5R
M<RYP:'`Z,3(W(&9I;'1E<G,N<&AP.C(S-PIM<V=I9"`B36]V92!2=6QE(%5P
M(@IM<V=S='(@(E!O<W5N;W5T(%!R879I9&QO($YA:&]R=2(*"B,Z('1E;7!L
M871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-#(*;7-G:60@(DY?=6UB97(@
M;V8@9&%Y<R!B971W965N('9A8V%T:6]N(')E<&QI97,Z(@IM<V=S='(@(E!?
M;^AE="!D;OD@;65Z:2!O9'!O=NQD:2!D;W9O;&5NZ3HB"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z-"!T96UP;&%T97,O9FEL=&5R
M<R]F;V]T97(N:6YC.C@*(SH@;&EB+U-T;W)A9V4N<&AP.C<Q-`IM<V=I9"`B
M3F5W(%)U;&4B"FUS9W-T<B`B3F]VZ2!0<F%V:61L;R(*"B,Z(&QI8B]);F=O
M+G!H<#HQ.30@;&EB+TEN9V\N<&AP.C$Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B3F\@7"(E<UPB(&5L96UE;G0@9F]U;F0@:6X@8F%C:V5N9"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*NX61N_2!E;&5M96YT("<E<R<@;F5B
M>6P@;F%L97IE;B!V(&MO;F9I9W5R86-I(&)A8VME;F1U+B(*"B,Z(&QI8B])
M;F=O+G!H<#HQ.3(*;7-G:60@(DYO(&)A8VME;F0@8V]N9FEG=7)E9"!F;W(@
M=&AI<R!H;W-T(@IM<V=S='(@(D)A8VME;F0@;F5B>6P@:V]N9FEG=7)O=N%N
M('!R;R!T96YT;R!H;W-T+B(*"B,Z(&QI8B]);F=O+G!H<#HQ-CD*;7-G:60@
M(DYO(&)A8VME;F1S(&-O;F9I9W5R960@:6X@8F%C:V5N9',N<&AP(@IM<V=S
M='(@(D)A8VME;F0@;F5B>6P@:V]N9FEG=7)O=N%N('8@8F%C:V5N9',N<&AP
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+6YO;F4N:6YC.C0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&9I;'1E<G,N($-L:6-K(%PB
M)7-<(B!T;R!C<F5A=&4@82!N97<@9FEL=&5R+B(*;7-G<W1R("*LX61NZ2!F
M:6QT<GDN($ML:6MN['1E("<E<R<@<')O('9Y='9O^&5N[2!N;W;I:&\@9FEL
M=')U+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$S,C<@;&EB+U-C<FEP
M="]S:65V92YP:'`Z,30R,`HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-3DT
M"FUS9VED(").;R!H96%D97)S('-P96-I9FEE9"(*;7-G<W1R(").96)Y;&$@
M=79E9&5N82"^X61NX2!H;&%V:>AK82XB"@HC.B!S8W)I<'0N<&AP.C8W"FUS
M9VED(").;R!S8W)I<'0@9V5N97)A=&5D+B(*;7-G<W1R(").96)Y;"!G96YE
M<F]VX6X@ON%D;OT@<VMR:7!T+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP
M.C$V,#D*;7-G:60@(DYO('-T<FEN9W,@<W!E8VEF:65D(@IM<V=S='(@(DYE
M8GEL:2!U=F5D96YY(+[A9&[I('IN86MY(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,U.`IM<V=I9"`B3F]T(&5Q=6%L('1O(@IM<V=S='(@(DYE<F]V;N$@<V4B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S$V"FUS9VED(")/;FQY(&9L86<@=&AE
M(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y"FUS9VED(")/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A=&EN9RXB"FUS
M9W-T<B`B36^^;F]S=&D@<')O(&%K='5A;&EZ86-I('-K<FEP='4N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/=&AE<B!/<'1I;VYS
M(@IM<V=S='(@(D1A;+GM($UOOFYO<W1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;F5W7V9O;&1E<BYJ<SHV"FUS9VED(")0;&5A<V4@96YT97(@=&AE
M(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(E!R;W/M;2!Z861E
M:G1E(&[A>F5V(&YO=ND@<VQOOFMY.B(*"B,Z('1E;7!L871E<R]V86-A=&EO
M;B]V86-A=&EO;BYI;F,Z-C`*;7-G:60@(E)?96%S;VXB"FUS9W-T<B`B1%_Y
M=F]D(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HV,PIM<V=I9"`B4F5C
M96EV960B"FUS9W-T<B`B4/AI:F%T;R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR
M.3<*;7-G:60@(E)E9&ER96-T('1O(@IM<V=S='(@(E#X97-M[')O=F%T(&1O
M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,`IM<V=I9"`B4F5G=6QA<B!E>'!R
M97-S:6]N(@IM<V=S='(@(E)E9W5L87(@97AP<F5S<VEO;B(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS,3(*;7-G:60@(E)E:F5C="!W:71H(')E87-O;B(*;7-G
M<W1R("):86WM=&YU=&\@<R!D^79O9&5M(@H*(SH@8V]N9FEG+V9I96QD<RYP
M:'`N9&ES=#HU-0IM<V=I9"`B4F5S96YT(%1O(@IM<V=S='(@(E#X97!O<VSA
M;F\@2V]M=2(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-3$*;7-G:60@
M(E)E<V5N="UF<F]M(@IM<V=S='(@(E#X97!O<VSA;F\M3V1K;VAO(@H*(SH@
M=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHV,`IM<V=I9"`B4F5T=7)N('1O
M($9I;'1E<G,@3&ES="(*;7-G<W1R(").X79R870@:R!397IN86UU($9I;'1R
M^2(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR-"!T
M96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z-#$*(SH@=&5M<&QA
M=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHW,2!T96UP;&%T97,O9F]R=V%R
M9"]F;W)W87)D+FEN8SHS-`IM<V=I9"`B4F5T=7)N('1O(%)U;&5S($QI<W0B
M"FUS9W-T<B`B3N%V<F%T(&L@4V5Z;F%M=2!&:6QT<F]V86/M8V@@4')A=FED
M96PB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C,T"FUS9VED
M(")2=6QE(@IM<V=S='(@(E!R879I9&QO(@H*(SH@9FEL=&5R<RYP:'`Z-C`*
M;7-G:60@(E)U;&4@0V]P:65D(@IM<V=S='(@(E!R879I<VQO(&)Y;&\@:V]P
M[7)O=N%N;R(*"B,Z(&9I;'1E<G,N<&AP.C,Y"FUS9VED(")2=6QE($1E;&5T
M960B"FUS9W-T<B`B4')A=FED;&\@8GEL;R!3;6%ZX6YO(@H*(SH@9FEL=&5R
M<RYP:'`Z-S8*;7-G:60@(E)U;&4@1&ES86)L960B"FUS9W-T<B`B4')A=FED
M;&\@8GEL;R!$96%K=&EV;W;A;F\B"@HC.B!F:6QT97)S+G!H<#HX,0IM<V=I
M9"`B4G5L92!%;F%B;&5D(@IM<V=S='(@(E!R879I9&QO(&)Y;&\@06MT:79O
M=N%N;R(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,S,*;7-G:60@
M(E)U;&4@3F%M92(*;7-G<W1R(").X7IE=B!0<F%V:61L82(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E14
M3%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]W
M:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHR,R!T96UP;&%T97,O8FQA8VML:7-T
M+V)L86-K;&ES="YI;F,Z-#`*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T
M:6]N+FEN8SHW,"!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHS,PHC
M.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C4Y"FUS9VED(")3879E(@IM
M<V=S='(@(E5L;[YI="(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S
M+FEN8SHR.0IM<V=I9"`B4V%V92!3971T:6YG<R(*;7-G<W1R(")-;[YN;W-T
M:2!5;&^^96[M(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]H96%D97(N:6YC.C(*
M;7-G:60@(E-C<FEP="(*;7-G<W1R(")3:W)I<'0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*;7-G<W1R
M(")!:W1U86QI>F%C92!3:W)I<'1U(@H*(SH@;&EB+TEN9V\N<&AP.C(Q-PIM
M<V=I9"`B4V-R:7!T(&YO="!U<&1A=&5D+B(*;7-G<W1R(")3:W)I<'0@;F5B
M>6P@06MT=6%L:7IO=N%N+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S`*;7-G:60@
M(E-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D+B(*;7-G<W1R(")3:W)I
M<'0@8GEL(/IS<.RY;NP@86MT:79O=N%N+B(*"B,Z(&QI8B]);F=O+G!H<#HQ
M,CD*;7-G:60@(E-C<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM
M<V=S='(@(E-K<FEP="!B>6P@^G-P[+EN["!D96%K=&EV;W;A;BXB"@HC.B!T
M96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C(Y"FUS9VED(")3965N(@IM<V=S
M='(@(E!R;VAL[61N=73I(@H*(SH@<G5L92YP:'`Z,3DP"FUS9VED(")396QE
M8W0@82!F:65L9"(*;7-G<W1R(")6>6)R870@<&]L92(*"B,Z(&QI8B]);F=O
M+G!H<#HT.0IM<V=I9"`B4V5L96-T('1A<F=E="!F;VQD97(B"FUS9W-T<B`B
M5GEB<F%T(&/M;&]V;W4@<VQOOFMU(@H*(SH@<G5L92YP:'`Z,C(W"FUS9VED
M(")396QF+41E9FEN960@2&5A9&5R(@IM<V=S='(@(E-A;6$@<V4@1&5F:6YU
M:NUC[2!(;&%V:>AK82(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S4*
M;7-G:60@(E-E;F1E<B(*;7-G<W1R(")/9&5S[6QA=&5L(@H*(SH@9FEL=&5R
M<RYP:'`Z.34*;7-G:60@(E-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A=&5D
M+B(*;7-G<W1R(")68;EE(&YA<W1A=F5N[2!B>6QO(/IS<.RY;NP@86MT=6%L
M:7IO=N%N;RXB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHR
M-`IM<V=I9"`B4VAO=R!!8W1I=F4@4V-R:7!T(@IM<V=S='(@(EIO8G)A>FET
M($%K=&EV;NT@4VMR:7!T(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T
M92YI;F,Z,S$*;7-G:60@(E-H;W<@0W5R<F5N="!38W)I<'0B"FUS9W-T<B`B
M6F]B<F%Z:70@06MT=>%L;NT@4VMR:7!T(@H*(SH@8V]N9FEG+V9I96QD<RYP
M:'`N9&ES=#HX,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")696QI:V]S="(*"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-#D*;7-G:60@(E-T;W`@8VAE
M8VMI;F<@:68@=&AI<R!R=6QE(&UA=&-H97,_(@IM<V=S='(@(EIA='-T879I
M="!K;VYT<F]L=2!P;VMU9"!S92!S:&]D=6IE(',@=.UM=&\@<')A=F]D;&5M
M/R(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-3$*;7-G
M:60@(E-U8FIE7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z(@IM<V=S='(@(E#X
M961?;>QT('!R;R!Z<'+A=G4@;R!D;W9O;&5NZ3HB"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C,Q"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E#X961M
M['0B"@HC.B!L:6(O87!I+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@861D<F5S<R!<(B5S7"(@:&%S(&)E96X@861D960@=&\@>6]U<B!B;&%C
M:VQI<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$P-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!<(B5S7"(@:&%S(&)E96X@861D
M960@=&\@>6]U<B!W:&ET96QI<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]);F=O
M+G!H<#HQ,C4*;7-G:60@(E1H92!D<FEV97(@<V%I9#H@(@IM<V=S='(@(EIP
M<N%V82!O9"!D<FEV97)U.B`B"@HC.B!L:6(O26YG;RYP:'`Z,3(T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*
M;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!A:W1I=F%C:2!S:W)I<'1U+B(*
M"B,Z(&QI8B]);F=O+G!H<#HQ,C,*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D96%C=&EV871I;F<@=&AE('-C<FEP="XB"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P^&D@9&5A:W1I=F%C:2!S:W)I<'1U+B(*"B,Z(&-O;F9I9R]F:65L
M9',N<&AP+F1I<W0Z,C<*;7-G:60@(E1O(@IM<V=S='(@(DMO;74B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]F:6QT97(N:'1M;#HR.`HC+"!F=7IZ>0IM<V=I
M9"`B5&\Z(@IM<V=S='(@(DMO;74B"@HC.B!L:6(O4V-R:7!T+G!H<#HQ,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N(@IM<V=S='(@(DYE;'IE(&1O<^%H;F]U="!D969I;FEC
M:2!P<F\@)7,N(@H*(SH@9FEL=&5R<RYP:'`Z,34V('1E;7!L871E<R]V86-A
M=&EO;B]V86-A=&EO;BYI;F,Z-0HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H
M<#HR-C(*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D1O=F]L96[A(@H*(SH@
M=F%C871I;VXN<&AP.C<R"FUS9VED(")686-A=&EO;B!%9&ET(@IM<V=S='(@
M(E5P<F%V:70@1&]V;VQE;F]U(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,S4Q"FUS9VED(")686-A=&EO;B!-97-S86=E(@IM<V=S='(@(EIP<N%V82!O
M($1O=F]L96[I(@H*(SH@=F%C871I;VXN<&AP.C$V"FUS9VED(")686-A=&EO
M;B!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D
M<FEV97(N(@IM<V=S='(@(DYE;'IE('!O=;[M="!$;W9O;&5N;W4@<V4@<V]U
MZ&%S;OUM(&1R:79E<F5M('!R;R!F:6QT<F%C:2XB"@HC.B!T96UP;&%T97,O
M=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,38*;7-G:60@(E=H7VET96QI<W0@
M861D<F5S<V5S.B(*;7-G<W1R(")"[5]LZ2!A9')E<WDZ(@H*(SH@9FEL=&5R
M<RYP:'`Z,34P('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHX
M"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B0NULX2!L:7-T:6YA(@H*(SH@
M=VAI=&5L:7-T+G!H<#HU-0IM<V=I9"`B5VAI=&5L:7-T($5D:70B"FUS9W-T
M<B`B57!R879I="!"[6QO=2!L:7-T:6YU(@H*(SH@=VAI=&5L:7-T+G!H<#HQ
M.`IM<V=I9"`B5VAI=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U
M<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B3F5L>F4@<&]UONUT
M($+M;&]U(&QI<W1I;G4@<V4@<V]UZ&%S;OUM(&1R:79E<F5M('!R;R!F:6QT
M<F%C:2XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR,S0@;&EB+U-C
M<FEP="]S:65V92YP:'`Z,CDW"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP
M.C(P,@IM<V=I9"`B5VAI=&5L:7-T960@061D<F5S<V5S(@IM<V=S='(@(D%D
M<F5S>2!N82!":6SI(&QI<W1I;NPB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD
M:7-T.C<Y"FUS9VED(")8+5!R:6]R:71Y(@IM<V=S='(@(E@M4')I;W)I='DB
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C8W"FUS9VED(")8+5-P86TM
M3&5V96PB"FUS9W-T<B`B6"U3<&%M+4QE=F5L(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3<&%M+5-C;W)E(@IM<V=S='(@(E@M
M4W!A;2U38V]R92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-S4*;7-G
M:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T<B`B6"U3<&%M+5-T871U<R(*"B,Z
M(&9I;'1E<G,N<&AP.C4S(')U;&4N<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@<G5L97,N(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C0U(')U;&4N
M<&AP.C(Q"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!O
M<B!E9&ET(&-U<W1O;2!R=6QE<RXB"FUS9W-T<B`B(@H*(SH@=F%C871I;VXN
M<&AP.C,P"FUS9VED("(B"B)9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N
M92!E;6%I;"!A9&1R97-S(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@;65S<V%G
M97,@(@HB<VAO=6QD(&)E(&%C=&EV871E9"XB"FUS9W-T<B`B375S[2!B_70@
M=79E9&5N82!N96IMZ6[L(&IE9&YA(&%D<F5S82!P<F\@<&]UOFET[2!$;W9O
M;&5NZ2(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<X(&QI8B]38W)I<'0O
M:6UA<"YP:'`Z,S`Q(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$U"FUS9VED(");
M3F\@4W5B:F5C=%TB"FUS9W-T<B`B6Z[A9&[](%#X961M['1=(@H*(SH@=&5M
M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,C0*;7-G:60@(E]!9&1R97-S
M*&5S*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R(")?061R97-A*'DI('!R;R!P
M^&5P;W-LX6[M.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI
M;F,Z,C,*;7-G:60@(E]!9&1R97-S97,@=&\@;F]T('-E;F0@<F5S<&]N<V5S
M('1O.B(*;7-G<W1R(")?061R97-Y(&MT97+A;2!N96)U9&4@>F%S;.%N82!O
M9'!O=NSO.B(*"B,Z(&QI8B]);F=O+G!H<#HS,#4*;7-G:60@(E]";&%C:VQI
M<W0B"FUS9W-T<B`B7\AE<F[A($QI<W1I;F$B"@HC.B!T96UP;&%T97,O8FQA
M8VML:7-T+V)L86-K;&ES="YI;F,Z,3@*;7-G:60@(E]$96QE=&4@;65S<V%G
M92!C;VUP;&5T96QY(@IM<V=S='(@(E_:<&QNZ2!3;6%ZX6[M(%IP<N%V>2(*
M"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHS,0IM<V=I
M9"`B7T5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE.B(*;7-G<W1R
M(")?5FQOOFET(&MAOF1O=2!A9')E<W4@;F$@;F]V_2#XX61E:SHB"@HC.B!L
M:6(O26YG;RYP:'`Z,S$Q"FUS9VED(")?1F]R=V%R9"(*;7-G<W1R(")?4/AE
M<&]S;&%T(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3<*
M;7-G:60@(E]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U
M;G0_(@IM<V=S='(@(E]0;VYE8VAA="!K;W!I:2!Z<'+A=GD@;F$@=&]M=&\@
M^NAT=3\B"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M,C(*;7-G:60@(E]-;W9E(&UE<W-A9V4@=&\@9F]L9&5R.B(*;7-G<W1R(")?
M4/AE<W5N;W5T('IP<N%V=2!D;R!S;&^^:WDZ(@H*(SH@=&5M<&QA=&5S+W9A
M8V%T:6]N+W9A8V%T:6]N+FEN8SHQ,PIM<V=I9"`B7TUY(&5M86EL(&%D9')E
M<W-E<SHB"FUS9W-T<B`B7TUO:F4@96UA:6QO=ND@861R97-Y.B(*"B,Z(&QI
M8B]);F=O+G!H<#HS,30*;7-G:60@(E]38W)I<'0B"FUS9W-T<B`B7U-K<FEP
M="(*"B,Z(&QI8B]);F=O+G!H<#HS,#@*;7-G:60@(E]686-A=&EO;B(*;7-G
M<W1R(")?1&]V;VQE;N$B"@HC.B!L:6(O26YG;RYP:'`Z,S`R"FUS9VED(")?
M5VAI=&5L:7-T(@IM<V=S='(@(E]"[6SA(&QI<W1I;F$B"@HC.B!T96UP;&%T
M97,O<G5L92]F:6QT97(N:6YC.C0*;7-G:60@(F%N9"(*;7-G<W1R(")A.B(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BYH=&UL.C$V"FUS9VED(")D
M:7-A8FQE9"`M(&-L:6-K('1O(&5N86)L92(*;7-G<W1R("(B"@HC.B!F:6QT
M97)S+G!H<#HQ.#`*;7-G:60@(F9I96QD(@IM<V=S='(@(G!O;&4B"@HC.B!L
M:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(FUA
M:6QD<F]P('-C<FEP="!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R(")P<F]C
M;6%I;"!S:W)I<'0@9V5N97)O=F%N_2!);F=E;2(*"B,Z(&9I;'1E<G,N<&AP
M.C$X,`IM<V=I9"`B;6%T8V@B"FUS9W-T<B`B<VAO9&$B"@HC.B!T96UP;&%T
M97,O<G5L92]F:6QT97(N:6YC.C0*;7-G:60@(F]R(@IM<V=S='(@(FYE8F\B
M"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HQ,C@*;7-G:60@(G!R;V-M
M86EL('-C<FEP="!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R(")P<F]C;6%I
M;"!S:W)I<'0@9V5N97)O=F%N_2!);F=E;2(*"B,Z(&QI8B]38W)I<'0O<VEE
M=F4N<&AP.C$P.0IM<V=I9"`B<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!)
M;F=O(@IM<V=S='(@(G-I979E(&9I;'1E<B!G96YE<F]V86[]($EN9V5M(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6YG;R]P;R]I;F=O+G!O=```````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`T,30V-@`Q,#0Q-S,V,C<T-P`P,3<T-S$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R!33TU%($1%
M4T-225!4259%(%1)5$Q%+@HC($-O<'ER:6=H="`H0RD@645!4B!(;W)D92!0
M<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S
M86UE(&QI8V5N<V4@87,@=&AE(%!!0TM!1T4@<&%C:V%G92X*(R!&25)35"!!
M551(3U(@/$5-04E,0$%$1%)%4U,^+"!914%2+@HC"B,L(&9U>GIY"FUS9VED
M("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!004-+04=%(%9%
M4E-)3TY<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R
M9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT
M-RLP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B!914%2+4U/+41!($A/.DU)
M*UI/3D5<;B(*(DQA<W0M5')A;G-L871O<CH@1E5,3"!.04U%(#Q%34%)3$!!
M1$1215-3/EQN(@HB3&%N9W5A9V4M5&5A;3H@3$%.1U5!1T4@/$Q,0&QI+F]R
M9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]0TA!4E-%5%QN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9FEL=&5R<RYP:'`Z,3DP"FUS9VED
M("(@86YD(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C$Y,`IM<V=I9"`B
M(&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML
M:7-T+FEN8SHQ-PIM<V=I9"`B06-T:6]N(&9O<B!B;&%C:VQI<W1E9"!A9&1R
M97-S97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A
M=&4N:6YC.C$P"FUS9VED(")!8W1I=F%T92!38W)I<'0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B06-T:79A=&EN9R!T:&4@<V-R:7!T(&9O<B!<(B5S7"(@9F%I;&5D.B`H
M)60I("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I
M;F=S+FEN8SHV"FUS9VED(")!9&1I=&EO;F%L(%-E='1I;F=S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-#0*;7-G:60@(D%L
M;"!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C4T"FUS9VED(")!;&QO=R!2=6QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G5L92]F;V]T97(N:6YC.C,S"FUS9VED(")!;G-W97)E9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C0U"FUS9VED(")!
M;GD@;V8@=&AE(&9O;&QO=VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]F;V]T97(N:6YC.C<*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS
M9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z,C$Y"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<G5L93\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S"FUS9VED(")!=71O;6%T:6-A
M;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&5A8V@@8VAA;F=E/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C0W"FUS9VED(")"
M8V,B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W.0IM<V=I9"`B
M0F5G:6YS('=I=&@B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HQ,#8@;&EB+T1R:79E<B]L9&%P+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0FEN9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@9FEL
M=&5R<RYP:'`Z,30Y('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN
M8SHW"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z.#<@;&EB+T)L;V-K+V]V
M97)V:65W+G!H<#HY,`IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(B(*"B,Z
M(&)L86-K;&ES="YP:'`Z,3`W"FUS9VED(")";&%C:VQI<W0@161I="(*;7-G
M<W1R("(B"@HC.B!B;&%C:VQI<W0N<&AP.C$W"FUS9VED(")";&%C:VQI<W0@
M:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I
M=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR
M,#<@;&EB+U-C<FEP="]S:65V92YP:'`Z,C0T"B,Z(&QI8B]38W)I<'0O;6%I
M;&1R;W`N<&AP.C$W-@IM<V=I9"`B0FQA8VML:7-T960@061D<F5S<V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z.#@*;7-G:60@
M(D)O9'DB"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z,3@W(')U;&4N<&AP
M.C(X,0IM<V=I9"`B0V%S92!396YS:71I=F4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+V9I96QD<RYP:'`N9&ES=#HT,PIM<V=I9"`B0V,B"FUS9W-T<B`B(@H*
M(SH@<W!A;2YP:'`Z,S@@<G5L92YP:'`Z,3(R('=H:71E;&ES="YP:'`Z,S8@
M9F]R=V%R9"YP:'`Z,S,@=F%C871I;VXN<&AP.C0Q"B,Z(&)L86-K;&ES="YP
M:'`Z-S,*;7-G:60@(D-H86YG97,@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z-S4*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S<U"FUS9VED(")#
M;VYT86EN<R(*;7-G<W1R("(B"@HC.B!F:6QT97)S+G!H<#HR,S`@9FEL=&5R
M<RYP:'`Z,C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C@W-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W!Y(&]F("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]);F=O+G!H<#HV
M,@IM<V=I9"`B0W)E871E(&YE=R!F;VQD97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+U-C<FEP="]P<F]C;6%I;"YP:'`Z,S,V(&QI8B]38W)I<'0O;6%I;&1R;W`N
M<&AP.C(X,`IM<V=I9"`B1$E304),140Z("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ-PIM<V=I9"`B1&5A8W1I=F%T
M92!38W)I<'0B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z,C$Y(&9I;'1E
M<G,N<&AP.C(R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHS,`IM<V=I
M9"`B1&5L971E($-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S(S"FUS9VED(")$96QE=&4@;65S<V%G92!C;VUP;&5T96QY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S4*;7-G
M:60@(D1E;&5T960B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Q
M,0IM<V=I9"`B1&5L:79E<B!I;G1O(&UY($EN8F]X(@IM<V=S='(@(B(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS,S<*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!)
M;F)O>"!A;F0@8V]P>2!T;R(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S,R"FUS9VED(")$96QI=F5R(&EN=&\@;7D@26YB;W@@86YD(')E9&ER
M96-T('1O(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,3<*;7-G
M:60@(D1E;&EV97(@=&\@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N
M<&AP.C(T,R!F:6QT97)S+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&ES86)L92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T
M+W=H:71E;&ES="YI;F,Z,3`@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C$P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M-B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHQ,`HC.B!T96UP;&%T
M97,O<G5L92]H96%D97(N:6YC.C(V"FUS9VED(")$:7-A8FQE9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,3,*;7-G
M:60@(D1I<W!L87D@9&5T86EL960@;F]T:69I8V%T:6]N('=H96X@96%C:"!F
M:6QT97(@:7,@87!P;&EE9#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9A
M8V%T:6]N+W9A8V%T:6]N+FEN8SHS-`IM<V=I9"`B1&\@7VYO="!S96YD(')E
M<W!O;G-E<R!T;R!B=6QK(&]R(&QI<W0@;65S<V%G97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@=&AI
M<SHB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X,`IM<V=I9"`B
M1&]E<VXG="!B96=I;B!W:71H(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS-S8*;7-G:60@(D1O97-N)W0@8V]N=&%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S@R"FUS9VED(")$;V5S;B=T(&5N9"!W:71H
M(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#0*;7-G:60@(D1O
M97-N)W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X
M-PIM<V=I9"`B1&]E<VXG="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C8@
M;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV,0HC.B!L:6(O0FQO8VLO;W9E<G9I
M97<N<&AP.C8X(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z.#$*(SH@;&EB+T)L
M;V-K+V]V97)V:65W+G!H<#HX.0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC
M.B!F:6QT97)S+G!H<#HR,#@@9FEL=&5R<RYP:'`Z,C$P(&9I;'1E<G,N<&AP
M.C(Q-"!F:6QT97)S+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="`E<R(*;7-G<W1R("(B"@HC.B!F:6QT97)S+G!H<#HR-#<@9FEL=&5R<RYP
M:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(D5N86)L92`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(X"FUS9VED
M(")%;F%B;&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#$*
M;7-G:60@(D5N9',@=VET:"(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,SDR"FUS9VED(")%<75A;"!T;R(*;7-G<W1R("(B"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C$S.2!L:6(O1')I=F5R+VQD87`N<&AP.C$T.2!L:6(O
M1')I=F5R+VQD87`N<&AP.C$U.`HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R971R:65V:6YG(&-U<G)E
M;G0@<V-R:7!T.B`H)60I("5S(@IM<V=S='(@(B(*"B,Z(&)L86-K;&ES="YP
M:'`Z-S$*;7-G:60@(D5R<F]R('-A=FEN9R!C:&%N9V5S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(R"FUS9VED(")%
M>&ES=&EN9R!2=6QE<R(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,S@S"FUS9VED(")%>&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HQ-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B17AP96-T960@,2!O
M8FIE8W0L(&=O="`E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<V5T=&EN9W,N:6YC.C(P"FUS9VED(")&:6QT97(@06QL($UE<W-A9V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN
M8SHR,@IM<V=I9"`B1FEL=&5R($]N;'D@4V5E;B!-97-S86=E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,C$*;7-G
M:60@(D9I;'1E<B!/;FQY(%5N<V5E;B!-97-S86=E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,3@*;7-G:60@(D9I
M;'1E<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R=6QE+VAE
M861E<BYI;F,Z,C4*;7-G:60@(D9I;'1E<B!2=6QE(@IM<V=S='(@(B(*"B,Z
M(&9I;'1E<G,N<&AP.C$Q,PIM<V=I9"`B1FEL=&5R(%)U;&5S(@IM<V=S='(@
M(B(*"B,Z('-C<FEP="YP:'`Z-3(*;7-G:60@(D9I;'1E<B!38W)I<'0@1&ES
M<&QA>2(*;7-G<W1R("(B"@HC.B!L:6(O26YG;RYP:'`Z,S(R"FUS9VED(")&
M:6QT97(@7U)U;&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP
M:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@
M)7,@;65S<V%G92AS*2!H879E(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE
M<W-A9V4H<RD@:&%V92!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]38W)I<'0O:6UA<"YP:'`Z,C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@;6]V960@
M=&\@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I
M<'0O:6UA<"YP:'`Z,3@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A
M8W1I=FET>3H@)7,@;65S<V%G92AS*2!T:&%T(&UA=&-H960@=&AE(&)L86-K
M;&ES="!W97)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O
M:6UA<"YP:'`Z,S$Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D9I;'1E<B!A
M8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B
M965N(&-O<&EE9"!T;R!T:&4@(@HB9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR.38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O
M;2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+U-C<FEP="]I;6%P+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S
M7"(@:&%S(&)E96X@;6]V960@=&\@=&AE(&9O;&1E<B`B"B)<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(')U;&4N<&AP.C$V,`IM<V=I9"`B1FEL=&5R(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN
M8SHT,@IM<V=I9"`B1F]R(&%N(&EN8V]M:6YG(&UE<W-A9V4@=&AA="!M871C
M:&5S.B(*;7-G<W1R("(B"@HC.B!F:6QT97)S+G!H<#HQ-C<@=&5M<&QA=&5S
M+V9O<G=A<F0O9F]R=V%R9"YI;F,Z."!L:6(O0FQO8VLO;W9E<G9I97<N<&AP
M.C8W"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-CD*;7-G:60@(D9O<G=A
M<F0B"FUS9W-T<B`B(@H*(SH@9F]R=V%R9"YP:'`Z,38*;7-G:60@(D9O<G=A
M<F0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@
M9')I=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H
M<#HR.#(@;&EB+U-C<FEP="]S:65V92YP:'`Z,C$T"B,Z(&QI8B]38W)I<'0O
M;6%I;&1R;W`N<&AP.C(R-0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*
M(SH@9F]R=V%R9"YP:'`Z-#4*;7-G:60@(D9O<G=A<F1S($5D:70B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HS.0IM<V=I9"`B1G)O
M;2(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HR,#8R"FUS
M9VED(")&<F]M.B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HQ,3`*;7-G:60@(D=E;F5R871E9"!B>2!);F=O("AH='1P.B\O=W=W+FAO
M<F1E+F]R9R]I;F=O+RDB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,Y,`IM<V=I9"`B1W)E871E<B!T:&%N(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS.3$*;7-G:60@(D=R96%T97(@=&AA;B!O<B!E<75A;"!T
M;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C,Q
M"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`B(@H*(SH@<G5L92YP:'`Z,S8*
M;7-G:60@(DEN9&EV:61U86P@<G5L97,@87)E(&YO="!S=7!P;W)T960@:6X@
M=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+U-C<FEP="]S:65V92YP:'`Z,3@V,`IM<V=I9"`B26YE>&ES=&%N="!M
M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G92!D96QI=F5R>2XB"FUS9W-T
M<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W-PIM<V=I9"`B27,B"FUS9W-T
M<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W.`IM<V=I9"`B27-N)W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,PIM<V=I9"`B(@HB
M3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@
M:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S@X"FUS9VED("),97-S('1H86XB"FUS9W-T
M<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X.0IM<V=I9"`B3&5S<R!T:&%N
M(&]R(&5Q=6%L('1O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP
M+F1I<W0Z-3D*;7-G:60@(DQI<W0M240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(P"FUS9VED(")-87)?:R!M
M97-S86=E(&%S(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O9F]O=&5R+FEN8SHR-`IM<V=I9"`B36%R:R!M97-S86=E(&%S.B(*;7-G
M<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@V"FUS9VED(")-871C:&5S
M("AW:71H('!L86-E:&]L9&5R<RDB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z-3<*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%)U;&5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@8FQA8VML:7-T960@861D<F5S<V5S
M(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S97,Z("5S+"`B"B)-87AI;75M(&%D
M9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O
M(&)L86-K;&ES="XB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C4V
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O9B!W
M:&ET96QI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E
M<SH@)7,L("(*(DUA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@
M861D(&YE=R!A9&1R97-S97,@=&\@=VAI=&5L:7-T+B(*;7-G<W1R("(B"@HC
M.B!L:6(O4V-R:7!T+W-I979E+G!H<#HR,#<P"FUS9VED(")-:7-S:6YG(&%D
M9')E<W,@=&\@;F]T:69Y(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O<VEE
M=F4N<&AP.C$W,C@*;7-G:60@(DUI<W-I;F<@861D<F5S<R!T;R!R961I<F5C
M="!M97-S86=E('1O(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N
M<&AP.C$W-C`*;7-G:60@(DUI<W-I;F<@<F5A<V]N(&9O<B!R96IE8W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3DR-PIM<V=I9"`B
M36ES<VEN9R!R96%S;VX@:6X@=F%C871I;VXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,CD*;7-G:60@(DUO=F4B"FUS
M9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z,3,Q(&9I;'1E<G,N<&AP.C(T,`IM
M<V=I9"`B36]V92!2=6QE($1O=VXB"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP
M:'`Z,3,R(&9I;'1E<G,N<&AP.C(S.0IM<V=I9"`B36]V92!2=6QE(%5P(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M-#(*;7-G:60@(DY?=6UB97(@;V8@9&%Y<R!B971W965N('9A8V%T:6]N(')E
M<&QI97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E
M<BUN;VYE+FEN8SHS('1E;7!L871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z-0HC
M.B!L:6(O4W1O<F%G92YP:'`Z-S<Q"FUS9VED(").97<@4G5L92(*;7-G<W1R
M("(B"@HC.B!L:6(O26YG;RYP:'`Z,C,U(&QI8B]);F=O+G!H<#HR,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@7"(E<UPB(&5L96UE;G0@9F]U;F0@:6X@
M8F%C:V5N9"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O26YG
M;RYP:'`Z,C,S"FUS9VED(").;R!B86-K96YD(&-O;F9I9W5R960@9F]R('1H
M:7,@:&]S="(*;7-G<W1R("(B"@HC.B!L:6(O26YG;RYP:'`Z,C$P"FUS9VED
M(").;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S+G!H<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!F:6QT97)S+B!#;&EC:R!<(B5S
M7"(@=&\@8W)E871E(&$@;F5W(&9I;'1E<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+U-C<FEP="]S:65V92YP:'`Z,3,S,B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ
M-#(U"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$U.3D*;7-G:60@(DYO(&AE
M861E<G,@<W!E8VEF:65D(@IM<V=S='(@(B(*"B,Z('-C<FEP="YP:'`Z-C<*
M;7-G:60@(DYO('-C<FEP="!G96YE<F%T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C$V,30*;7-G:60@(DYO('-T<FEN9W,@<W!E
M8VEF:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.3,*;7-G
M:60@(DYO="!E<75A;"!T;R(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S4S"FUS9VED(").;W1I9GD@96UA:6P@861D<F5S<R(*;7-G<W1R("(B
M"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0W"FUS9VED(")/;FQY(&9L86<@=&AE
M(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y"FUS9VED(")/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/
M=&AE<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]O=F5R=FEE
M=RYP:'`Z,PIM<V=I9"`B3W9E<G9I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;F5W7V9O;&1E<BYJ<SHV"FUS9VED(")0;&5A<V4@
M96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-C`*;7-G:60@
M(E)?96%S;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES
M=#HV,PIM<V=I9"`B4F5C96EV960B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,R.`IM<V=I9"`B4F5D:7)E8W0@=&\B"FUS9W-T<B`B(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,X-0IM<V=I9"`B4F5G=6QA<B!E>'!R97-S:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#,*;7-G:60@(E)E
M:F5C="!W:71H(')E87-O;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C4U"FUS9VED(")297-E;G0@5&\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU,0IM<V=I9"`B4F5S96YT+69R;VTB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHV,`IM
M<V=I9"`B4F5T=7)N('1O($9I;'1E<G,@3&ES="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,C0@=&5M<&QA=&5S
M+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C0Q"B,Z('1E;7!L871E<R]V86-A
M=&EO;B]V86-A=&EO;BYI;F,Z-S$@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R
M9"YI;F,Z,S0*;7-G:60@(E)E='5R;B!T;R!2=6QE<R!,:7-T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C<*;7-G:60@
M(E)U;&4B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z-C,*;7-G:60@(E)U
M;&4@0V]P:65D(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C0R"FUS9VED
M(")2=6QE($1E;&5T960B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z-SD*
M;7-G:60@(E)U;&4@1&ES86)L960B"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP
M:'`Z.#0*;7-G:60@(E)U;&4@16YA8FQE9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G5L92]H96%D97(N:6YC.C,S"FUS9VED(")2=6QE($YA;64B"FUS
M9W-T<B`B(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V-`IM<V=I9"`B
M4G5L93HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HX.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")35$%25%1,4R!F86EL960Z("@E<RD@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N
M:6YC.C(S('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT,`HC
M.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C<P('1E;7!L871E
M<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,S"B,Z('1E;7!L871E<R]R=6QE+V9O
M;W1E<BYI;F,Z-3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(Y"FUS9VED(")3879E(%-E='1I
M;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S8W)I<'0O:&5A9&5R+FEN
M8SHR"FUS9VED(")38W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$X"FUS9VED(")38W)I<'0@57!D871I;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+TEN9V\N<&AP.C$X-@IM<V=I9"`B4V-R:7!T(&YO="!U<&1A
M=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O26YG;RYP:'`Z,30Q"FUS9VED(")3
M8W)I<'0@<W5C8V5S<V9U;&QY(&%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TEN9V\N<&AP.C$T,`IM<V=I9"`B4V-R:7!T('-U8V-E<W-F=6QL>2!D
M96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O
M=&5R+FEN8SHR.0IM<V=I9"`B4V5E;B(*;7-G<W1R("(B"@HC.B!R=6QE+G!H
M<#HQ.3`*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]);F=O+G!H<#HU.0IM<V=I9"`B4V5L96-T('1A<F=E="!F;VQD97(B"FUS
M9W-T<B`B(@H*(SH@<G5L92YP:'`Z,C(W"FUS9VED(")396QF+41E9FEN960@
M2&5A9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z
M,S4*;7-G:60@(E-E;F1E<B(*;7-G<W1R("(B"@HC.B!F:6QT97)S+G!H<#HY
M.`IM<V=I9"`B4V5T=&EN9W,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C(T"FUS
M9VED(")3:&]W($%C=&EV92!38W)I<'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,S$*;7-G:60@(E-H;W<@0W5R<F5N
M="!38W)I<'0B"FUS9W-T<B`B(@H*(SH@<W!A;2YP:'`Z,34*;7-G:60@(E-I
M;7!L92!S<&%M(&9I;'1E<FEN9R!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C
M=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z.#,*;7-G:60@(E-I>F4B"FUS9W-T<B`B(@H*
M(SH@<W!A;2YP:'`Z-3D*;7-G:60@(E-P86T@1FEL=&5R:6YG(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-#D*;7-G:60@(E-T
M;W`@8VAE8VMI;F<@:68@=&AI<R!R=6QE(&UA=&-H97,_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-3$*;7-G:60@
M(E-U8FIE7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S$*;7-G:60@(E-U8FIE8W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V,PIM<V=I9"`B
M4W5B:F5C=#HB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@7"(E<UPB(&AA<R!B965N(&%D
M9&5D('1O('EO=7(@8FQA8VML:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@7"(E
M<UPB(&AA<R!B965N(&%D9&5D('1O('EO=7(@=VAI=&5L:7-T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O26YG;RYP:'`Z,3,V"FUS9VED(")4:&4@9')I=F5R('-A
M:60Z("(*;7-G<W1R("(B"@HC.B!L:6(O26YG;RYP:'`Z,3,U"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*;7-G
M<W1R("(B"@HC.B!L:6(O26YG;RYP:'`Z,3,T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,C<*;7-G:60@(E1O(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BYH=&UL.C(Q"FUS
M9VED(")4;SHB"FUS9W-T<B`B(@H*(SH@;&EB+U-C<FEP="YP:'`Z,3(W"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F:6QT97)S+G!H<#HQ-C$@=&5M
M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHU"B,Z(&QI8B]38W)I<'0O
M<')O8VUA:6PN<&AP.C(V,B!L:6(O4V-R:7!T+W-I979E+G!H<#HS-3(*(SH@
M;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV,"!L:6(O0FQO8VLO;W9E<G9I97<N
M<&AP.C8R"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!V86-A=&EO
M;BYP:'`Z-S$*;7-G:60@(E9A8V%T:6]N($5D:70B"FUS9W-T<B`B(@H*(SH@
M=F%C871I;VXN<&AP.C$V"FUS9VED(")686-A=&EO;B!I<R!N;W0@<W5P<&]R
M=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHQ-@IM
M<V=I9"`B5VA?:71E;&ES="!A9&1R97-S97,Z(@IM<V=S='(@(B(*"B,Z(&9I
M;'1E<G,N<&AP.C$U-2!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI
M;F,Z.`HC.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C<Y(&QI8B]";&]C:R]O
M=F5R=FEE=RYP:'`Z.#(*;7-G:60@(E=H:71E;&ES="(*;7-G<W1R("(B"@HC
M.B!W:&ET96QI<W0N<&AP.C4U"FUS9VED(")7:&ET96QI<W0@161I="(*;7-G
M<W1R("(B"@HC.B!W:&ET96QI<W0N<&AP.C$X"FUS9VED(")7:&ET96QI<W0@
M:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I
M=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR
M,S0@;&EB+U-C<FEP="]S:65V92YP:'`Z,CDX"B,Z(&QI8B]38W)I<'0O;6%I
M;&1R;W`N<&AP.C(P,PIM<V=I9"`B5VAI=&5L:7-T960@061D<F5S<V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-SD*;7-G:60@
M(E@M4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HV-PIM<V=I9"`B6"U3<&%M+4QE=F5L(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]F:65L9',N<&AP+F1I<W0Z-S$*;7-G:60@(E@M4W!A;2U38V]R92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C<U"FUS9VED
M(")8+5-P86TM4W1A='5S(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C4V
M(')U;&4N<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@<G5L97,N(@IM<V=S
M='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C0X(')U;&4N<&AP.C(Q"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!O<B!E9&ET(&-U<W1O;2!R
M=6QE<RXB"FUS9W-T<B`B(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V
M,0IM<V=I9"`B66]U(&AA=F4@<F5C96EV960@82!N97<@;65S<V%G92(*;7-G
M<W1R("(B"@HC.B!V86-A=&EO;BYP:'`Z,S`*;7-G:60@(B(*(EEO=2!M=7-T
M('-P96-I9GD@870@;&5A<W0@;VYE(&5M86EL(&%D9')E<W,@9F]R('=H:6-H
M('1H92!V86-A=&EO;B!M97-S86=E<R`B"B)S:&]U;&0@8F4@86-T:79A=&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C(W-"!L:6(O
M4V-R:7!T+VEM87`N<&AP.C(Y-R!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q,0IM
M<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;W)W87)D+V9O<G=A<F0N:6YC.C(T"FUS9VED(")?061D<F5S<RAE<RD@=&\@
M9F]R=V%R9"!T;SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N
M+W9A8V%T:6]N+FEN8SHR,PIM<V=I9"`B7T%D9')E<W-E<R!T;R!N;W0@<V5N
M9"!R97-P;VYS97,@=&\Z(@IM<V=S='(@(B(*"B,Z(&QI8B]);F=O+G!H<#HS
M,C<*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C$X"FUS9VED(")?1&5L971E(&UE
M<W-A9V4@8V]M<&QE=&5L>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8FQA
M8VML:7-T+V)L86-K;&ES="YI;F,Z,S$*;7-G:60@(E]%;G1E<B!E86-H(&%D
M9')E<W,@;VX@82!N97<@;&EN93HB"FUS9W-T<B`B(@H*(SH@;&EB+TEN9V\N
M<&AP.C,S,PIM<V=I9"`B7T9O<G=A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3<*;7-G:60@(E]+965P(&$@8V]P
M>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,@IM<V=I9"`B
M7TUO=F4@;65S<V%G92!T;R!F;VQD97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,3,*;7-G:60@(E]->2!E;6%I
M;"!A9&1R97-S97,Z(@IM<V=S='(@(B(*"B,Z(&QI8B]);F=O+G!H<#HS,S8*
M;7-G:60@(E]38W)I<'0B"FUS9W-T<B`B(@H*(SH@;&EB+TEN9V\N<&AP.C,S
M,`IM<V=I9"`B7U9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]);F=O+G!H
M<#HS,C0*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V]V97)V:65W+G!H<#HU-`IM<V=I9"`B86-T:79E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z-`IM<V=I9"`B86YD(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BYH=&UL.C$S
M"FUS9VED(")D:7-A8FQE9"`M(&-L:6-K('1O(&5N86)L92(*;7-G<W1R("(B
M"@HC.B!F:6QT97)S+G!H<#HQ.#4*;7-G:60@(F9I96QD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-3(*;7-G:60@(FEN86-T:79E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C$R,0IM
M<V=I9"`B;6%I;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O(@IM<V=S
M='(@(B(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B;6%T8V@B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")O
M<B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HQ,C@*
M;7-G:60@(G!R;V-M86EL('-C<FEP="!G96YE<F%T960@8GD@26YG;R(*;7-G
M<W1R("(B"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEN9V\O<&\O<'1?0E(N<&\`````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-30T,3,`,3`T,3<S-C(W-#<`,#$W
M,S4S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",@=')A;G-L871I;VX@;V8@:6YG;RYP;R!T;R!"<F%Z:6QI86X@4&]R='5G
M=65S90HC($-O<'ER:6=H="`H0RD@645!4B!(;W)D92!0<F]J96-T"B,@5&AI
M<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@
M87,@=&AE($EN9V\@<&%C:V%G92X*(PHC($9A8FEO($=O;65S(#QF;&=O;7-`
M=6]L+F-O;2YB<CXL(#(P,#8N"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C
M="U)9"U697)S:6]N.B!);F=O7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-BTP,BTQ-2`Q.#HP-"TP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($9A8FEO
M($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB<CY<;B(*(DQA;F=U86=E+51E86TZ
M($)R87II;&EA;B!0;W)T=6=U97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@HB6"U'96YE<F%T;W(Z($M"86)E;"`Q+C,N
M,5QN(@HB4&QU<F%L+49O<FUS.B`@;G!L=7)A;',],CL@<&QU<F%L/2AN(#X@
M,2D[7&XB"@HC.B!F:6QT97)S+G!H<#HQ.3`*;7-G:60@(B!A;F0B"FUS9W-T
M<B`B(&4B"@HC.B!F:6QT97)S+G!H<#HQ.3`*;7-G:60@(B!O<B(*;7-G<W1R
M("(@;W4B"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M,3<*;7-G:60@(D%C=&EO;B!F;W(@8FQA8VML:7-T960@861D<F5S<V5S.B(*
M;7-G<W1R(")!Y^-O('!A<F$@96YD97)EYV]S(&YA(&QI<W1A(&YE9W)A.B(*
M"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$P"FUS9VED(")!
M8W1I=F%T92!38W)I<'0B"FUS9W-T<B`B071I=F%R(%)O=&EN82(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G:60@(D%C
M=&EV871I;F<@=&AE('-C<FEP="!F;W(@7"(E<UPB(&9A:6QE9#H@*"5D*2`E
M<R(*;7-G<W1R(")!(&%T:79AY^-O(&1O('-C<FEP="!P87)A(%PB)7-<(B!F
M86QH;W4@*"5D*2`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S
M+FEN8SHV"FUS9VED(")!9&1I=&EO;F%L(%-E='1I;F=S(@IM<V=S='(@(D-O
M;F9I9W5R8>?U97,@061I8VEO;F%I<R(*"B,Z('1E;7!L871E<R]R=6QE+VAE
M861E<BYI;F,Z-#0*;7-G:60@(D%L;"!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S
M='(@(E1O9&]S(&]S('-E9W5I;G1E<R(*"B,Z(&QI8B]A<&DN<&AP.C4T"FUS
M9VED(")!;&QO=R!2=6QE<R(*;7-G<W1R(").;W9A(%)E9W)A(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,PIM<V=I9"`B06YS=V5R960B"FUS
M9W-T<B`B4F5S<&]N9&ED82(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI
M;F,Z-#4*;7-G:60@(D%N>2!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@(E%U
M86QQ=65R('5M(&1O<R!S96=U:6YT97,B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]F;V]T97(N:6YC.C<*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B
M07!L:6-A<B!&:6QT<F]S(@H*(SH@9FEL=&5R<RYP:'`Z,C$Y"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<G5L93\B"FUS
M9W-T<B`B5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!E>&-L=6ER(&5S=&$@
M<F5G<F$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S"FUS9VED(")!
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&5A8V@@8VAA
M;F=E/R(*;7-G<W1R(")!='5A;&EZ87(@875T;VUA=&EC86UE;G1E(&$@<F]T
M:6YA(&1E<&]I<R!D92!C861A(&%L=&5R8>?C;S\B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C0W"FUS9VED(")"8V,B"FUS9W-T<B`B0V-O(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,X,PIM<V=I9"`B0F5G:6YS('=I=&@B"FUS9W-T
M<B`B0V]M9>=A(&-O;2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3`V(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D)I
M;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D9A;&AA(&YA(&%U=&5N=&EC
M8>?C;SH@*"5S*2`E<R(*"B,Z(&9I;'1E<G,N<&AP.C$T.2!T96UP;&%T97,O
M8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z-PHC.B!L:6(O0FQO8VLO;W9E<G9I
M97<N<&AP.C@W(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z.3`*;7-G:60@(D)L
M86-K;&ES="(*;7-G<W1R("),:7-T82!.96=R82(*"B,Z(&)L86-K;&ES="YP
M:'`Z,3`W"FUS9VED(")";&%C:VQI<W0@161I="(*;7-G<W1R(")%9&ET87(@
M3&ES=&$@3F5G<F$B"@HC.B!B;&%C:VQI<W0N<&AP.C$W"FUS9VED(")";&%C
M:VQI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I
M;F<@9')I=F5R+B(*;7-G<W1R("),:7-T82!.96=R82!NXV\@Z2!S=7!O<G1A
M9&$@<&5L;R!C;VYE8W1O<B!D92!F:6QT<F\@871U86PN(@H*(SH@;&EB+U-C
M<FEP="]P<F]C;6%I;"YP:'`Z,C`W(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(T
M-`HC.B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HQ-S8*;7-G:60@(D)L86-K
M;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R(")%;F1E<F7G;W,@;F$@3&ES=&$@
M3F5G<F$B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C@X"FUS9VED(")"
M;V1Y(@IM<V=S='(@(D-O<G!O(@H*(SH@9FEL=&5R<RYP:'`Z,3@W(')U;&4N
M<&AP.C(X,0IM<V=I9"`B0V%S92!396YS:71I=F4B"FUS9W-T<B`B4V5N<^UV
M96P@X"!#86EX82(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-#,*;7-G
M:60@(D-C(@IM<V=S='(@(D-C(@H*(SH@<W!A;2YP:'`Z,S@@<G5L92YP:'`Z
M,3(R('=H:71E;&ES="YP:'`Z,S8@9F]R=V%R9"YP:'`Z,S,@=F%C871I;VXN
M<&AP.C0Q"B,Z(&)L86-K;&ES="YP:'`Z-S,*;7-G:60@(D-H86YG97,@<V%V
M960N(@IM<V=S='(@(D%L=&5R8>?U97,@<V%L=F%S+B(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z-S4*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G
M<W1R(")&86QH82!N82!C;VYE>.-O(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W
M.0IM<V=I9"`B0V]N=&%I;G,B"FUS9W-T<B`B0V]N=.EM(@H*(SH@9FEL=&5R
M<RYP:'`Z,C,P(&9I;'1E<G,N<&AP.C(S,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y("5S(@IM<V=S='(@(D-O<&EA<B`E<R(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HX-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!O9B`E<R(*;7-G
M<W1R(")#;W!I87(@9&4@)7,B"@HC.B!L:6(O26YG;RYP:'`Z-C(*;7-G:60@
M(D-R96%T92!N97<@9F]L9&5R(@IM<V=S='(@(D-R:6%R(&YO=F$@<&%S=&$B
M"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HS,S8@;&EB+U-C<FEP="]M
M86EL9')O<"YP:'`Z,C@P"FUS9VED(")$25-!0DQ%1#H@(@IM<V=S='(@(D1%
M4T%4259!1$$Z("(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC
M.C$W"FUS9VED(")$96%C=&EV871E(%-C<FEP="(*;7-G<W1R(")$97-A=&EV
M87(@4F]T:6YA(@H*(SH@9FEL=&5R<RYP:'`Z,C$Y(&9I;'1E<G,N<&AP.C(R
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,B"FUS9W-T<B`B17AC
M;'5I<B`E<R(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z,S`*;7-G
M:60@(D1E;&5T92!#;VYD:71I;VXB"FUS9W-T<B`B17AC;'5I<B!#;VYD:>?C
M;R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,C<*;7-G:60@(D1E;&5T92!M97-S
M86=E(&-O;7!L971E;'DB"FUS9W-T<B`B17AC;'5I<B!M96YS86=E;2!C;VUP
M;&5T86UE;G1E(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS-0IM
M<V=I9"`B1&5L971E9"(*;7-G<W1R(")%>&-L=>UD82(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS,34*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!);F)O>"(*;7-G
M<W1R(")%;G1R96=A<B!N82!M:6YH82!#86EX82!D92!%;G1R861A(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,T,0IM<V=I9"`B1&5L:79E<B!I;G1O(&UY($EN
M8F]X(&%N9"!C;W!Y('1O(@IM<V=S='(@(D5N=')E9V%R(&YA(&UI;FAA($-A
M:7AA(&1E($5N=')A9&$@92!C;W!I87(@<&%R82(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS,S8*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!);F)O>"!A;F0@<F5D
M:7)E8W0@=&\B"FUS9W-T<B`B16YT<F5G87(@;F$@;6EN:&$@0V%I>&$@9&4@
M16YT<F%D82!E(')E9&ER96-I;VYA<B!P87)A(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,R,0IM<V=I9"`B1&5L:79E<B!T;R!F;VQD97(B"FUS9W-T<B`B16YT
M<F5G87(@;F$@<&%S=&$B"@HC.B!F:6QT97)S+G!H<#HR-#,@9FEL=&5R<RYP
M:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(D1I<V%B;&4@)7,B"FUS9W-T
M<B`B1&5S871I=F%R("5S("(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI
M=&5L:7-T+FEN8SHQ,"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI
M;F,Z,3`*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHV('1E
M;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C$P"B,Z('1E;7!L871E<R]R
M=6QE+VAE861E<BYI;F,Z,C8*;7-G:60@(D1I<V%B;&5D(@IM<V=S='(@(D1E
M<V%T:79A9&\B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z
M,3,*;7-G:60@(D1I<W!L87D@9&5T86EL960@;F]T:69I8V%T:6]N('=H96X@
M96%C:"!F:6QT97(@:7,@87!P;&EE9#\B"FUS9W-T<B`B17AI8FER(&YO=&EF
M:6-AY^-O(&1E=&%L:&%D82!Q=6%N9&\@8V%D82!F:6QT<F\@9F]R(&%P;&EC
M861O/R(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,S0*
M;7-G:60@(D1O(%]N;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L:R!O<B!L:7-T
M(&UE<W-A9V5S(@IM<V=S='(@(E].XV\@96YV:6%R(')E<W!O<W1A<R!P87)A
M(&UE;G-A9V5N<R!E;2!M87-S82!O=2!L:7-T87,@9&4@;65N<V%G96YS(@H*
M(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@=&AI
M<SHB"FUS9W-T<B`B1F'G82!I<W1O.B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS
M.#0*;7-G:60@(D1O97-N)W0@8F5G:6X@=VET:"(*;7-G<W1R(").XV\@8V]M
M9>=A(&-O;2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#`*;7-G:60@(D1O97-N
M)W0@8V]N=&%I;B(*;7-G<W1R(").XV\@8V]N=.EM(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,X-@IM<V=I9"`B1&]E<VXG="!E;F0@=VET:"(*;7-G<W1R(").
MXV\@=&5R;6EN82!C;VTB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@X"FUS9VED
M(")$;V5S;B=T(&5X:7-T(@IM<V=S='(@(D[C;R!E>&ES=&4B"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z,SDQ"FUS9VED(")$;V5S;B=T(&UA=&-H("AW:71H('!L
M86-E:&]L9&5R<RDB"FUS9W-T<B`B3N-O(&-O<G)E<W!O;F1E(&$@*&-O;2!C
M;W)I;F=A<RDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(V
M(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C$*(SH@;&EB+T)L;V-K+V]V97)V
M:65W+G!H<#HV."!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C@Q"B,Z(&QI8B]"
M;&]C:R]O=F5R=FEE=RYP:'`Z.#D*;7-G:60@(D5D:70B"FUS9W-T<B`B161I
M=&%R(@H*(SH@9FEL=&5R<RYP:'`Z,C`X(&9I;'1E<G,N<&AP.C(Q,"!F:6QT
M97)S+G!H<#HR,30@9FEL=&5R<RYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@)7,B"FUS9W-T<B`B161I=&%R("5S(@H*(SH@9FEL=&5R<RYP
M:'`Z,C0W(&9I;'1E<G,N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;F%B;&4@)7,B"FUS9W-T<B`B2&%B:6QI=&%R("5S(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O:&5A9&5R+FEN8SHR.`IM<V=I9"`B16YA8FQE9"(*;7-G<W1R
M(")(86)I;&ET861O(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X-0IM<V=I9"`B
M16YD<R!W:71H(@IM<V=S='(@(E1E<FUI;F$@8V]M(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,Y-@IM<V=I9"`B17%U86P@=&\B"FUS9W-T<B`B26=U86P@82(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3,Y(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,30Y(&QI8B]$<FEV97(O;&1A<"YP:'`Z,34X"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I
M979I;F<@8W5R<F5N="!S8W)I<'0Z("@E9"D@)7,B"FUS9W-T<B`B17)R;R!A
M;R!O8G1E<B!O('-C<FEP="!A='5A;#H@*"5D*2`E<R(*"B,Z(&)L86-K;&ES
M="YP:'`Z-S$*;7-G:60@(D5R<F]R('-A=FEN9R!C:&%N9V5S+B(*;7-G<W1R
M(")%<G)O(&%O('-A;'9A<B!A;'1E<F'G]65S+B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+VAE861E<BYI;F,Z,C(*;7-G:60@(D5X:7-T:6YG(%)U;&5S(@IM
M<V=S='(@(E)E9W)A<R!%>&ES=&5N=&5S(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,X-PIM<V=I9"`B17AI<W1S(@IM<V=S='(@(D5X:7-T92(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,30T"B,L('!H<"UF;W)M870*;7-G:60@(D5X<&5C
M=&5D(#$@;V)J96-T+"!G;W0@)60N(@IM<V=S='(@(C$@;V)J971O(&5S<&5R
M861O+"!O8G1I9&]S("5D+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I
M;F=S+FEN8SHR,`IM<V=I9"`B1FEL=&5R($%L;"!-97-S86=E<R(*;7-G<W1R
M(")&:6QT<F%R(%1O9&%S($UE;G-A9V5N<R(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W-E='1I;F=S+FEN8SHR,@IM<V=I9"`B1FEL=&5R($]N;'D@4V5E;B!-
M97-S86=E<R(*;7-G<W1R(")&:6QT<F%R(%-O;65N=&4@365N<V%G96YS($QI
M9&%S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(Q"FUS
M9VED(")&:6QT97(@3VYL>2!5;G-E96X@365S<V%G97,B"FUS9W-T<B`B1FEL
M=')A<B!3;VUE;G1E($UE;G-A9V5N<R!.XV\@3&ED87,B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,3@*;7-G:60@(D9I;'1E<B!/<'1I
M;VYS(@IM<V=S='(@(D]PY_5E<R!D92!&:6QT<F\B"@HC.B!T96UP;&%T97,O
M<G5L92]H96%D97(N:6YC.C(U"FUS9VED(")&:6QT97(@4G5L92(*;7-G<W1R
M(")296=R82!D;R!&:6QT<F\B"@HC.B!F:6QT97)S+G!H<#HQ,3,*;7-G:60@
M(D9I;'1E<B!2=6QE<R(*;7-G<W1R(")296=R87,@9&4@1FEL=')O(@H*(SH@
M<V-R:7!T+G!H<#HU,@IM<V=I9"`B1FEL=&5R(%-C<FEP="!$:7-P;&%Y(@IM
M<V=S='(@(D5X:6)IY^-O(&1A(%)O=&EN82!D;R!&:6QT<F\B"@HC.B!L:6(O
M26YG;RYP:'`Z,S(R"FUS9VED(")&:6QT97(@7U)U;&5S(@IM<V=S='(@(E]2
M96=R87,@9&4@1FEL=')O(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S
M86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@=&AE(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(D%T:79I9&%D92!D;R!&:6QT<F\Z("5S(&UE;G-A9V5M*&YS
M*2!C;W!I861A*',I('!A<F$@82!P87-T82!<(B5S7"(N(@H*(SH@;&EB+U-C
M<FEP="]I;6%P+G!H<#HS,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R
M(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R(")!=&EV:61A9&4@9&\@1FEL=')O.B`E<R!M96YS86=E;2AN<RD@
M97AC;'7M9&$H<RDN(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E
M*',I(&AA=F4@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B071I=FED861E(&1O($9I;'1R;SH@)7,@;65N<V%G96TH;G,I(&UO
M=FED82AS*2!P87)A(&$@<&%S=&$@7"(E<UPB+B(*"B,Z(&QI8B]38W)I<'0O
M:6UA<"YP:'`Z,3@V"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I
M=FET>3H@)7,@;65S<V%G92AS*2!T:&%T(&UA=&-H960@=&AE(&)L86-K;&ES
M="!W97)E(&1E;&5T960N(@IM<V=S='(@(B(*(D%T:79I9&%D92!D;R!&:6QT
M<F\Z("5S(&UE;G-A9V5M*&YS*2!Q=64@8V]R<F5S<&]N9&5U*')A;2D@82!L
M:7-T82!N96=R82!F;VDB"B(H<F%M*2!E>&-L=>UD82AS*2XB"@HC.B!L:6(O
M4V-R:7!T+VEM87`N<&AP.C,Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&
M:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<
M(B!H87,@8F5E;B!C;W!I960@=&\@=&AE("(*(F9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(B(*(D%T:79I9&%D92!D;R!F:6QT<F\Z($$@;65N<V%G96T@7"(E
M<UPB(&1E(%PB)7-<(B!F;VD@8V]P:6%D82!P87)A(&$@<&%S=&$@7"(E(@HB
M<UPB+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S`P"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB
M(&9R;VT@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D%T:79I
M9&%D92!D;R!&:6QT<F\Z($$@;65N<V%G96T@7"(E<UPB(&1E(%PB)7-<(B!F
M;VD@97AC;'7M9&$N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S
M<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@;6]V960@=&\@=&AE
M(&9O;&1E<B`B"B)<(B5S7"(N(@IM<V=S='(@(B(*(D%T:79I9&%D92!D;R!&
M:6QT<F\Z($$@;65N<V%G96T@7"(E<UPB(&1E(%PB)7-<(F9O:2!M;W9I9&$@
M<&%R82!A('!A<W1A(%PB)7,B"B)<(BXB"@HC.B!R=6QE+G!H<#HQ-C`*;7-G
M:60@(D9I;'1E<B!N;W0@9F]U;F0N(@IM<V=S='(@(D9I;'1R;R!NXV\@96YC
M;VYT<F%D;RXB"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C0R"FUS
M9VED(")&;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z(@IM
M<V=S='(@(E!A<F$@=6UA(&YO=F$@;65N<V%G96T@<75E(&-O<G)E<W!O;F1A
M.B(*"B,Z(&9I;'1E<G,N<&AP.C$V-R!T96UP;&%T97,O9F]R=V%R9"]F;W)W
M87)D+FEN8SHX(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C<*(SH@;&EB+T)L
M;V-K+V]V97)V:65W+G!H<#HV.0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")%
M;F-A;6EN:&%R(@H*(SH@9F]R=V%R9"YP:'`Z,38*;7-G:60@(D9O<G=A<F0@
M:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I
M=F5R+B(*;7-G<W1R(")%;F-A;6EN:&%M96YT;R!NXV\@Z2!S=7!O<G1A9&\@
M<&5L;R!D<FEV97(@9&4@9FEL=')O(&%T=6%L+B(*"B,Z(&QI8B]38W)I<'0O
M<')O8VUA:6PN<&AP.C(X,B!L:6(O4V-R:7!T+W-I979E+G!H<#HR,30*(SH@
M;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,C(U"FUS9VED(")&;W)W87)D<R(*
M;7-G<W1R(")2961I<F5C:6]N86UE;G1O<R(*"B,Z(&9O<G=A<F0N<&AP.C0U
M"FUS9VED(")&;W)W87)D<R!%9&ET(@IM<V=S='(@(D5D:71A<B!2961I<F5C
M:6]N86UE;G1O<R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,SD*;7-G
M:60@(D9R;VTB"FUS9W-T<B`B1&4B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HR,#8R"FUS9VED(")&<F]M.B(*;7-G<W1R(")$93HB"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,SDT"FUS9VED(")'<F5A=&5R('1H86XB"FUS9W-T<B`B36%I
M;W(@<75E(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Y-0IM<V=I9"`B1W)E871E
M<B!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(DUA:6]R(&]U(&EG=6%L(&$B
M"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C,Q"FUS9VED("));7!O
M<G1A;G0B"FUS9W-T<B`B26UP;W)T86YT92(*"B,Z(')U;&4N<&AP.C,V"FUS
M9VED("));F1I=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H
M92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(E)E9W)A<R!I
M;F1I=FED=6%I<R!NXV\@<^-O('-U<&]R=&%D87,@<&5L;R!D<FEV97(@9&4@
M9FEL=')O(&%T=6%L+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$X-C`*
M;7-G:60@(DEN97AI<W1A;G0@;6%I;&)O>"!S<&5C:69I960@9F]R(&UE<W-A
M9V4@9&5L:79E<GDN(@IM<V=S='(@(E!A<W1A(&5S<&5C:69I8V%D82!P87)A
M(&5N=')E9V$@;N-O(&5X:7-T92XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@Q
M"FUS9VED("))<R(*;7-G<W1R("+)(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X
M,@IM<V=I9"`B27-N)W0B"FUS9W-T<B`B3N-O(.DB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C(S"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER
M960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO
M="!L;V%D960N(@IM<V=S='(@(B(*(E-U<&]R=&4@82!,1$%0(.D@;F5C97-S
MX7)I;R!M87,@;R!M\V1U;&\@3$1!4"!NXV\@97-TX2!D:7-P;V[M=F5L(&]U
M(&[C;R!F;VD@(@HB8V%R<F5G861O+B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS
M.3(*;7-G:60@(DQE<W,@=&AA;B(*;7-G<W1R(")-96YO<B!Q=64B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,SDS"FUS9VED("),97-S('1H86X@;W(@97%U86P@
M=&\B"FUS9W-T<B`B365N;W(@;W4@:6=U86P@82(*"B,Z(&-O;F9I9R]F:65L
M9',N<&AP+F1I<W0Z-3D*;7-G:60@(DQI<W0M240B"FUS9W-T<B`B3&ES="U)
M1"(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,`IM
M<V=I9"`B36%R7VL@;65S<V%G92!A<R!D96QE=&5D(@IM<V=S='(@(DUA<E]C
M87(@;65N<V%G96T@8V]M;R!E>&-L=>UD82(*"B,Z('1E;7!L871E<R]R=6QE
M+V9O;W1E<BYI;F,Z,C0*;7-G:60@(DUA<FL@;65S<V%G92!A<SHB"FUS9W-T
M<B`B36%R8V%R(&UE;G-A9V5M(&-O;6\Z(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,Y,`IM<V=I9"`B36%T8VAE<R`H=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S
M='(@(D-O<G)E<W!O;F1E(&$@*&-O;2!C;W)I;F=A<RDB"@HC.B!L:6(O87!I
M+G!H<#HU-PIM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4G5L97,B"FUS9W-T
M<B`B3OIM97)O($WA>&EM;R!D92!296=R87,B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z-3$W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@;G5M8F5R
M(&]F(&)L86-K;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D
M<F5S<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD
M(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!B;&%C:VQI<W0N(@IM<V=S='(@
M(B(*(D5X8V5D974@;R!N^FUE<F\@;>%X:6UO(&1E(&5N9&5R9>=O<R!N82!L
M:7-T82!N96=R82`H5&]T86P@9&4@96YD97)EYV]S.B`E<RP@(@HB3>%X:6UO
M(&1E(&5N9&5R9>=O<SH@)7,I+B`@3N-O(&-O;G-E9W5I(&%D:6-I;VYA<B!N
M;W9O<R!E;F1E<F7G;W,@X"!L:7-T82`B"B)N96=R82XB"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z-3<P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@
M;G5M8F5R(&]F('=H:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T
M86P@861D<F5S<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@
M($-O=6QD(&YO="!A9&0@;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N(@IM
M<V=S='(@(B(*(D5X8V5D974@;R!N^FUE<F\@;>%X:6UO(&1E(&5N9&5R9>=O
M<R!N82!L:7-T82!B<F%N8V$@*%1O=&%L(&1E(&5N9&5R9>=O<SH@)2(*(G,L
M($WA>&EM;R!D92!E;F1E<F7G;W,Z("5S*2X@($[C;R!C;VYS96=U:2!A9&EC
M:6]N87(@;F]V;W,@96YD97)EYV]S(.`@;&ES=&$@(@HB8G)A;F-A+B(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(P-S`*;7-G:60@(DUI<W-I;F<@861D
M<F5S<R!T;R!N;W1I9GDB"FUS9W-T<B`B1F%L=&%N9&\@;W,@96YD97)EYV]S
M('!A<F$@;F]T:69I8V%R(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3<R
M.`IM<V=I9"`B36ES<VEN9R!A9&1R97-S('1O(')E9&ER96-T(&UE<W-A9V4@
M=&\B"FUS9W-T<B`B16YD97)EYV\@<&%R82!R961I<F5C:6]N86UE;G1O(&[C
M;R!I;F9O<FUA9&\B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-S8P"FUS
M9VED(")-:7-S:6YG(')E87-O;B!F;W(@<F5J96-T(@IM<V=S='(@(E)A>N-O
M('!A<F$@<F5J96GGXV\@;N-O(&EN9F]R;6%D82(*"B,Z(&QI8B]38W)I<'0O
M<VEE=F4N<&AP.C$Y,C<*;7-G:60@(DUI<W-I;F<@<F5A<V]N(&EN('9A8V%T
M:6]N+B(*;7-G<W1R(")287KC;R!P87)A(&UE;G-A9V5M(&1E(&;I<FEA<R!N
MXV\@:6YF;W)M861A+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI
M;F,Z,CD*;7-G:60@(DUO=F4B"FUS9W-T<B`B36]V97(B"@HC.B!F:6QT97)S
M+G!H<#HQ,S$@9FEL=&5R<RYP:'`Z,C0P"FUS9VED(")-;W9E(%)U;&4@1&]W
M;B(*;7-G<W1R(")-;W9E<B!296=R82!!8F%I>&\B"@HC.B!F:6QT97)S+G!H
M<#HQ,S(@9FEL=&5R<RYP:'`Z,C,Y"FUS9VED(")-;W9E(%)U;&4@57`B"FUS
M9W-T<B`B36]V97(@4F5G<F$@06-I;6$B"@HC.B!T96UP;&%T97,O=F%C871I
M;VXO=F%C871I;VXN:6YC.C0R"FUS9VED(").7W5M8F5R(&]F(&1A>7,@8F5T
M=V5E;B!V86-A=&EO;B!R97!L:65S.B(*;7-G<W1R(")?3OIM97)O(&1E(&1I
M87,@96YT<F4@87,@<F5S<&]S=&%S(&1E(&;I<FEA<SHB"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z,R!T96UP;&%T97,O9FEL=&5R
M<R]F;V]T97(N:6YC.C4*(SH@;&EB+U-T;W)A9V4N<&AP.C<W-0IM<V=I9"`B
M3F5W(%)U;&4B"FUS9W-T<B`B3F]V82!296=R82(*"B,Z(&QI8B]);F=O+G!H
M<#HR,38@;&EB+TEN9V\N<&AP.C(Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R!<(B5S7"(@96QE;65N="!F;W5N9"!I;B!B86-K96YD(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(D\@<&%RXFUE=')O("<E<R<@;N-O(&9O:2!E;F-O;G1R
M861O(&YA(&-O;F9I9W5R8>?C;R!D;R!D<FEV97(N(@H*(SH@;&EB+TEN9V\N
M<&AP.C(Q-`IM<V=I9"`B3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES
M(&AO<W0B"FUS9W-T<B`B3N-O(&9O:2!C;VYF:6=U<F%D;R!U;2!D<FEV97(@
M<&%R82!E<W1E('-E<G9I9&]R(@H*(SH@;&EB+TEN9V\N<&AP.C$Y,0IM<V=I
M9"`B3F\@8F%C:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K96YD<RYP:'`B"FUS
M9W-T<B`B3F5N:'5M(&1R:79E<B!C;VYF:6=U<F%D;R!E;2!B86-K96YD<RYP
M:'`B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!F:6QT97)S+B!#;&EC:R!<(B5S7"(@
M=&\@8W)E871E(&$@;F5W(&9I;'1E<BXB"FUS9W-T<B`B3F5N:'5M(&9I;'1R
M;RX@0VQI<75E(&5M("<E<R<@<&%R82!C<FEA<B!U;2!N;W9O(&9I;'1R;RXB
M"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ,S,R(&QI8B]38W)I<'0O<VEE
M=F4N<&AP.C$T,C4*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,34Y.0IM<V=I
M9"`B3F\@:&5A9&5R<R!S<&5C:69I960B"FUS9W-T<B`B3F5N:'5M(&-A8F7G
M86QH;R!E<W!E8VEF:6-A9&\B"@HC.B!S8W)I<'0N<&AP.C8W"FUS9VED(").
M;R!S8W)I<'0@9V5N97)A=&5D+B(*;7-G<W1R(").96YH=6UA(')O=&EN82!G
M97)A9&$N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,38Q-`IM<V=I9"`B
M3F\@<W1R:6YG<R!S<&5C:69I960B"FUS9W-T<B`B3F5N:'5M82!C861E:6$@
M9&4@8V%R86-T97)E<R!E<W!E8VEF:6-A9&$B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,SDW"FUS9VED(").;W0@97%U86P@=&\B"FUS9W-T<B`B1&EF97)E;G1E
M(&1E(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-PIM<V=I9"`B3F]T:69Y(&5M
M86EL(&%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@9&4@92UM86EL('!A<F$@
M;F]T:69I8V'GXV\B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4Q"FUS9VED(")/
M;FQY(&9L86<@=&AE(&UE<W-A9V4B"FUS9W-T<B`B07!E;F%S(&UA<G%U92!A
M(&UE;G-A9V5M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y"FUS9VED
M(")/<'1I;VYS(&%B;W5T('-C<FEP="!U<&1A=&EN9RXB"FUS9W-T<B`B3W#G
M]65S('-O8G)E(&%T=6%L:7IAY^-O(&1A(')O=&EN82XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T
M<B`B3W5T<F%S($]PY_5E<R(*"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z
M,PIM<V=I9"`B3W9E<G9I97<B"FUS9W-T<B`B5FESXV\@1V5R86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]N97=?9F]L9&5R+FIS.C8*;7-G:60@(E!L
M96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T
M<B`B4&]R(&9A=F]R(&9O<FYEYV$@;R!N;VUE('!A<F$@82!N;W9A('!A<W1A
M.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-C`*;7-G
M:60@(E)?96%S;VXB"FUS9W-T<B`B4E]A>N-O(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HV,PIM<V=I9"`B4F5C96EV960B"FUS9W-T<B`B4F5C96EV
M960B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S,R"FUS9VED(")2961I<F5C="!T
M;R(*;7-G<W1R(")2961I<F5C:6]N87(@<&%R82(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS.#D*;7-G:60@(E)E9W5L87(@97AP<F5S<VEO;B(*;7-G<W1R(")%
M>'!R97-SXV\@<F5G=6QA<B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#<*;7-G
M:60@(E)E:F5C="!W:71H(')E87-O;B(*;7-G<W1R(")296IE:71A<B!C;VT@
M82!R87KC;R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-34*;7-G:60@
M(E)E<V5N="!4;R(*;7-G<W1R(")297-E;G0@5&\B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C4Q"FUS9VED(")297-E;G0M9G)O;2(*;7-G<W1R(")2
M97-E;G0M9G)O;2(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-C`*
M;7-G:60@(E)E='5R;B!T;R!&:6QT97)S($QI<W0B"FUS9W-T<B`B4F5T;W)N
M87(@<&%R82!A($QI<W1A(&1E($9I;'1R;W,B"@HC.B!T96UP;&%T97,O=VAI
M=&5L:7-T+W=H:71E;&ES="YI;F,Z,C0@=&5M<&QA=&5S+V)L86-K;&ES="]B
M;&%C:VQI<W0N:6YC.C0Q"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO
M;BYI;F,Z-S$@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,S0*;7-G
M:60@(E)E='5R;B!T;R!2=6QE<R!,:7-T(@IM<V=S='(@(E)E=&]R;F%R('!A
M<F$@82!,:7-T82!D92!296=R87,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H
M96%D97(N:6YC.C(W"FUS9VED(")2=6QE(@IM<V=S='(@(E)E9W)A(@H*(SH@
M9FEL=&5R<RYP:'`Z-C,*;7-G:60@(E)U;&4@0V]P:65D(@IM<V=S='(@(E)E
M9W)A($-O<&EA9&$B"@HC.B!F:6QT97)S+G!H<#HT,@IM<V=I9"`B4G5L92!$
M96QE=&5D(@IM<V=S='(@(E)E9W)A($5X8VQU[61A(@H*(SH@9FEL=&5R<RYP
M:'`Z-SD*;7-G:60@(E)U;&4@1&ES86)L960B"FUS9W-T<B`B4F5G<F$@1&5S
M871I=F%D82(*"B,Z(&9I;'1E<G,N<&AP.C@T"FUS9VED(")2=6QE($5N86)L
M960B"FUS9W-T<B`B4F5G<F$@071I=F%D82(*"B,Z('1E;7!L871E<R]R=6QE
M+VAE861E<BYI;F,Z,S,*;7-G:60@(E)U;&4@3F%M92(*;7-G<W1R(").;VUE
M(&1A(%)E9W)A(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V-`IM<V=I
M9"`B4G5L93HB"FUS9W-T<B`B4F5G<F$Z(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")35$%25%1,4R!F86EL960Z
M("@E<RD@)7,B"FUS9W-T<B`B3R!35$%25%1,4R!F86QH;W4Z("@E<RD@)7,B
M"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,C,@=&5M
M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C0P"B,Z('1E;7!L871E
M<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-S`@=&5M<&QA=&5S+V9O<G=A<F0O
M9F]R=V%R9"YI;F,Z,S,*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHU
M.0IM<V=I9"`B4V%V92(*;7-G<W1R(")386QV87(B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]S971T:6YG<RYI;F,Z,CD*;7-G:60@(E-A=F4@4V5T=&EN9W,B
M"FUS9W-T<B`B4V%L=F%R($-O;F9I9W5R8>?U97,B"@HC.B!T96UP;&%T97,O
M<V-R:7!T+VAE861E<BYI;F,Z,@IM<V=I9"`B4V-R:7!T(@IM<V=S='(@(E)O
M=&EN82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.`IM<V=I9"`B4V-R
M:7!T(%5P9&%T:6YG(@IM<V=S='(@(D%T=6%L:7IA;F1O(%)O=&EN82(*"B,Z
M(&QI8B]);F=O+G!H<#HR,SD*;7-G:60@(E-C<FEP="!N;W0@=7!D871E9"XB
M"FUS9W-T<B`B4F]T:6YA(&[C;R!!='5A;&EZ861A+B(*"B,Z(&QI8B]);F=O
M+G!H<#HQ-#$*;7-G:60@(E-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A=&5D
M+B(*;7-G<W1R(")2;W1I;F$@871I=F%D82!C;VT@<W5C97-S;RXB"@HC.B!L
M:6(O26YG;RYP:'`Z,30P"FUS9VED(")38W)I<'0@<W5C8V5S<V9U;&QY(&1E
M86-T:79A=&5D+B(*;7-G<W1R(")2;W1I;F$@9&5S871I=F%D82!C;VT@<W5C
M97-S;RXB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C(Y"FUS9VED
M(")3965N(@IM<V=S='(@(DQI9&$B"@HC.B!R=6QE+G!H<#HQ.3`*;7-G:60@
M(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(E-E;&5C:6]N92!U;2!C86UP;R(*
M"B,Z(&QI8B]);F=O+G!H<#HU.0IM<V=I9"`B4V5L96-T('1A<F=E="!F;VQD
M97(B"FUS9W-T<B`B4V5L96-I;VYE(&$@<&%S=&$@9&5S=&EN;R(*"B,Z(')U
M;&4N<&AP.C(R-PIM<V=I9"`B4V5L9BU$969I;F5D($AE861E<B(*;7-G<W1R
M(")#86)EYV%L:&\@4&5R<V]N86QI>F%D;R(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z,S4*;7-G:60@(E-E;F1E<B(*;7-G<W1R(")296UE=&5N=&4B
M"@HC.B!F:6QT97)S+G!H<#HY.`IM<V=I9"`B4V5T=&EN9W,@<W5C8V5S<V9U
M;&QY('5P9&%T960N(@IM<V=S='(@(D-O;F9I9W5R8>?U97,@871U86QI>F%D
M87,@8V]M('-U8V5S<V\N(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T
M92YI;F,Z,C0*;7-G:60@(E-H;W<@06-T:79E(%-C<FEP="(*;7-G<W1R(")%
M>&EB:7(@4F]T:6YA($%T:79A(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I
M=F%T92YI;F,Z,S$*;7-G:60@(E-H;W<@0W5R<F5N="!38W)I<'0B"FUS9W-T
M<B`B17AI8FER(%)O=&EN82!!='5A;"(*"B,Z('-P86TN<&AP.C$U"FUS9VED
M(")3:6UP;&4@<W!A;2!F:6QT97)I;F<@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R("(B"B)&:6QT
M<F%G96T@<VEM<&QE<R!D92!S<&%M(&[C;R#I('-U<&]R=&%D82!P96QO(&-O
M;F5C=&]R(&1E(&9I;'1R;R!A='5A;"XB"@HC.B!C;VYF:6<O9FEE;&1S+G!H
M<"YD:7-T.C@S"FUS9VED(")3:7IE(@IM<V=S='(@(E1A;6%N:&\B"@HC.B!S
M<&%M+G!H<#HU.0IM<V=I9"`B4W!A;2!&:6QT97)I;F<B"FUS9W-T<B`B1FEL
M=')O(&1E(%-P86TB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C0Y
M"FUS9VED(")3=&]P(&-H96-K:6YG(&EF('1H:7,@<G5L92!M871C:&5S/R(*
M;7-G<W1R(")087)A<B!A(&-H96-A9V5M('-E(&5S=&$@<F5G<F$@8V]R<F5S
M<&]N9&5R/R(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M-3$*;7-G:60@(E-U8FIE7V-T(&]F('9A8V%T:6]N(&UE<W-A9V4Z(@IM<V=S
M='(@(D%?<W-U;G1O(&1A(&UE;G-A9V5M(&1E(&;I<FEA<SHB"@HC.B!C;VYF
M:6<O9FEE;&1S+G!H<"YD:7-T.C,Q"FUS9VED(")3=6)J96-T(@IM<V=S='(@
M(D%S<W5N=&\B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HR,#8S"FUS9VED
M(")3=6)J96-T.B(*;7-G<W1R(")!<W-U;G1O.B(*"B,Z(&QI8B]A<&DN<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(%PB)7-<(B!H
M87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&)L86-K;&ES="XB"FUS9W-T<B`B3R!E
M;F1E<F7G;R!<(B5S7"(@9F]I(&%D:6-I;VYA9&\@82!S=6$@;&ES=&$@;F5G
M<F$N(@H*(SH@;&EB+V%P:2YP:'`Z,3`T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!A9&1R97-S(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('=H
M:71E;&ES="XB"FUS9W-T<B`B3R!E;F1E<F7G;R!<(B5S7"(@9F]I(&%D:6-I
M;VYA9&\@82!S=6$@;&ES=&$@8G)A;F-A+B(*"B,Z(&QI8B]);F=O+G!H<#HQ
M,S8*;7-G:60@(E1H92!D<FEV97(@<V%I9#H@(@IM<V=S='(@(D\@8V]N96-T
M;W(@9&ES<V4Z("(*"B,Z(&QI8B]);F=O+G!H<#HQ,S4*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!A8W1I=F%T:6YG('1H92!S8W)I<'0N(@IM<V=S='(@
M(DAO=79E('5M(&5R<F\@86\@871I=F%R(&$@<F]T:6YA+B(*"B,Z(&QI8B])
M;F=O+G!H<#HQ,S0*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96%C=&EV
M871I;F<@=&AE('-C<FEP="XB"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!D
M97-A=&EV87(@82!R;W1I;F$N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES
M=#HR-PIM<V=I9"`B5&\B"FUS9W-T<B`B4&%R82(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+V9I;'1E<BYH=&UL.C(Q"FUS9VED(")4;SHB"FUS9W-T<B`B4&%R
M83HB"@HC.B!L:6(O4V-R:7!T+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(DEM<&]S<^UV96P@8V%R<F5G87(@82!D969I;FGGXV\@9&4@)7,N(@H*
M(SH@9FEL=&5R<RYP:'`Z,38Q('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO
M;BYI;F,Z-0HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR-C(@;&EB+U-C
M<FEP="]S:65V92YP:'`Z,S4R"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z
M-C`@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV,@IM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`B1NER:6%S(@H*(SH@=F%C871I;VXN<&AP.C<Q"FUS9VED(")6
M86-A=&EO;B!%9&ET(@IM<V=S='(@(D5D:71A<B!/<.?U97,@9&4@1NER:6%S
M(@H*(SH@=F%C871I;VXN<&AP.C$V"FUS9VED(")686-A=&EO;B!I<R!N;W0@
M<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM
M<V=S='(@(D]PY_5E<R!D92!FZ7)I87,@;N-O('/C;R!S=7!O<G1A9&%S(&YO
M(&1R:79E<B!D92!F:6QT<F\@871U86PN(@H*(SH@=&5M<&QA=&5S+W=H:71E
M;&ES="]W:&ET96QI<W0N:6YC.C$V"FUS9VED(")7:%]I=&5L:7-T(&%D9')E
M<W-E<SHB"FUS9W-T<B`B16YD97)EYV]S(&YA(%],:7-T82!"<F%N8V$Z(@H*
M(SH@9FEL=&5R<RYP:'`Z,34U('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L
M:7-T+FEN8SHX"B,Z(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-SD@;&EB+T)L
M;V-K+V]V97)V:65W+G!H<#HX,@IM<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@
M(DQI<W1A($)R86YC82(*"B,Z('=H:71E;&ES="YP:'`Z-34*;7-G:60@(E=H
M:71E;&ES="!%9&ET(@IM<V=S='(@(D5D:71A<B!,:7-T82!"<F%N8V$B"@HC
M.B!W:&ET96QI<W0N<&AP.C$X"FUS9VED(")7:&ET96QI<W0@:7,@;F]T('-U
M<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G
M<W1R("),:7-T82!"<F%N8V$@;N-O(.D@<W5P;W)T861A('!E;&\@9')I=F5R
M(&1E(&9I;'1R;R!A='5A;"XB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H
M<#HR,S0@;&EB+U-C<FEP="]S:65V92YP:'`Z,CDX"B,Z(&QI8B]38W)I<'0O
M;6%I;&1R;W`N<&AP.C(P,PIM<V=I9"`B5VAI=&5L:7-T960@061D<F5S<V5S
M(@IM<V=S='(@(D5N9&5R9>=O<R!N82!,:7-T82!"<F%N8V$B"@HC.B!C;VYF
M:6<O9FEE;&1S+G!H<"YD:7-T.C<Y"FUS9VED(")8+5!R:6]R:71Y(@IM<V=S
M='(@(E@M4')I;W)I='DB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C8W
M"FUS9VED(")8+5-P86TM3&5V96PB"FUS9W-T<B`B6"U3<&%M+4QE=F5L(@H*
M(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3<&%M+5-C
M;W)E(@IM<V=S='(@(E@M4W!A;2U38V]R92(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z-S4*;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T<B`B6"U3
M<&%M+5-T871U<R(*"B,Z(&9I;'1E<G,N<&AP.C4V(')U;&4N<&AP.C$T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@<G5L97,N(@IM<V=S='(@(E9O8^H@;N-O(&5S
M=.$@875T;W)I>F%D;R!A(&-R:6%R(&UA:7,@9&4@)60@<F5G<F%S+B(*"B,Z
M(&9I;'1E<G,N<&AP.C0X(')U;&4N<&AP.C(Q"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!O<B!E9&ET(&-U<W1O;2!R=6QE<RXB"FUS
M9W-T<B`B5F]CZB!NXV\@97-TX2!A=71O<FEZ861O(&$@8W)I87(@;W4@961I
M=&%R(')E9W)A<R!P97)S;VYA;&EZ861A<RXB"@HC.B!L:6(O4V-R:7!T+W-I
M979E+G!H<#HR,#8Q"FUS9VED(")9;W4@:&%V92!R96-E:79E9"!A(&YE=R!M
M97-S86=E(@IM<V=S='(@(E9O8^H@<F5C96)E=2!U;6$@;F]V82!M96YS86=E
M;2(*"B,Z('9A8V%T:6]N+G!H<#HS,`IM<V=I9"`B(@HB66]U(&UU<W0@<W!E
M8VEF>2!A="!L96%S="!O;F4@96UA:6P@861D<F5S<R!F;W(@=VAI8V@@=&AE
M('9A8V%T:6]N(&UE<W-A9V5S("(*(G-H;W5L9"!B92!A8W1I=F%T960N(@IM
M<V=S='(@(B(*(E9O8^H@9&5V92!E<W!E8VEF:6-A<B!P96QO(&UE;F]S('5M
M(&5N9&5R9>=O(&1E(&4M;6%I;"!P87)A('%U92!A(&UE;G-A9V5M("(*(F1E
M(&;I<FEA<R!S96IA(&%T:79A9&$N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H
M<#HR-S@@;&EB+U-C<FEP="]I;6%P+G!H<#HS,#$@;&EB+U-C<FEP="]I;6%P
M+G!H<#HS,34*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");4V5M($%S
M<W5N=&]=(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,C0*
M;7-G:60@(E]!9&1R97-S*&5S*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R(")?
M16YD97)EYV\H<RD@<&%R82!R961I<F5C:6]N87(Z(@H*(SH@=&5M<&QA=&5S
M+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHR,PIM<V=I9"`B7T%D9')E<W-E<R!T
M;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z(@IM<V=S='(@(E]%;F1E<F7G;RAS
M*2!P87)A(&[C;R!E;G9I87(@<F5S<&]S=&%S.B(*"B,Z(&QI8B]);F=O+G!H
M<#HS,C<*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B3&ES=&$@7TYE9W)A
M(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C$X"FUS
M9VED(")?1&5L971E(&UE<W-A9V4@8V]M<&QE=&5L>2(*;7-G<W1R(")%7WAC
M;'5I<B!M96YS86=E;2!C;VUP;&5T86UE;G1E(@H*(SH@=&5M<&QA=&5S+V)L
M86-K;&ES="]B;&%C:VQI<W0N:6YC.C,Q"FUS9VED(")?16YT97(@96%C:"!A
M9&1R97-S(&]N(&$@;F5W(&QI;F4Z(@IM<V=S='(@(E]0<F5E;F-H82!C861A
M(&5N9&5R9>=O(&5M('5M82!N;W9A(&QI;FAA.B(*"B,Z(&QI8B]);F=O+G!H
M<#HS,S,*;7-G:60@(E]&;W)W87)D(@IM<V=S='(@(E]%;F-A;6EN:&%R(@H*
M(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3<*;7-G:60@(E]+
M965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_(@IM<V=S
M='(@(E]-86YT97(@=6UA(&/S<&EA(&1A<R!M96YS86=E;G,@;F5S=&$@8V]N
M=&$_(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(R
M"FUS9VED(")?36]V92!M97-S86=E('1O(&9O;&1E<CHB"FUS9W-T<B`B7TUO
M=F5R(&UE;G-A9V5M('!A<F$@82!P87-T83HB"@HC.B!T96UP;&%T97,O=F%C
M871I;VXO=F%C871I;VXN:6YC.C$S"FUS9VED(")?37D@96UA:6P@861D<F5S
M<V5S.B(*;7-G<W1R(")?365U<R!E;F1E<F7G;W,@9&4@92UM86EL.B(*"B,Z
M(&QI8B]);F=O+G!H<#HS,S8*;7-G:60@(E]38W)I<'0B"FUS9W-T<B`B7U)O
M=&EN82(*"B,Z(&QI8B]);F=O+G!H<#HS,S`*;7-G:60@(E]686-A=&EO;B(*
M;7-G<W1R(")?1NER:6%S(@H*(SH@;&EB+TEN9V\N<&AP.C,R-`IM<V=I9"`B
M7U=H:71E;&ES="(*;7-G<W1R("),:7-T82!?0G)A;F-A(@H*(SH@;&EB+T)L
M;V-K+V]V97)V:65W+G!H<#HU-`IM<V=I9"`B86-T:79E(@IM<V=S='(@(F%T
M:79O(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")A
M;F0B"FUS9W-T<B`B92(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BYH
M=&UL.C$S"FUS9VED(")D:7-A8FQE9"`M(&-L:6-K('1O(&5N86)L92(*;7-G
M<W1R(")D97-A8FEL:71A9&\@+2!C;&EQ=64@<&%R82!H86)I;&ET87(B"@HC
M.B!F:6QT97)S+G!H<#HQ.#4*;7-G:60@(F9I96QD(@IM<V=S='(@(F-A;7!O
M(@H*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HU,@IM<V=I9"`B:6YA8W1I
M=F4B"FUS9W-T<B`B:6YA=&EV;R(*"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N
M<&AP.C$R,0IM<V=I9"`B;6%I;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B>2!)
M;F=O(@IM<V=S='(@(G)O=&EN82!D;R!P<F]C;6%I;"!G97)A9&$@<&5L;R!)
M;F=O(@H*(SH@9FEL=&5R<RYP:'`Z,3@U"FUS9VED(")M871C:"(*;7-G<W1R
M(")C;W)R97-P;VYD92(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z
M-`IM<V=I9"`B;W(B"FUS9W-T<B`B;W4B"@HC.B!L:6(O4V-R:7!T+W!R;V-M
M86EL+G!H<#HQ,C@*;7-G:60@(G!R;V-M86EL('-C<FEP="!G96YE<F%T960@
M8GD@26YG;R(*;7-G<W1R(")R;W1I;F$@9&\@<')O8VUA:6P@9V5R861A('!E
M;&\@26YG;R(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$Q,`IM<V=I9"`B
M<VEE=F4@9FEL=&5R(&=E;F5R871E9"!B>2!);F=O(@IM<V=S='(@(F9I;'1R
M;R!S:65V92!G97)A9&\@<&5L;R!);F=O(@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]P;R]P=%]05"YP;P``
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-S`R
M,P`Q,#0Q-S,V,C<T-P`P,3<S-S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!)3D=/(%!O<G1U9V%L(%!O<G1U9W5E<V4@
M=')A;G-L871I;VXN"B,@36%N=65L($UE;F5Z97,@9&4@4V5Q=65I<F$@/$UA
M;G5E;"Y397%U96ER83XL(#(P,#4N"B,@0F%S960@;VX@82!P<F5V:6]U<PHC
M('1R86YS;&%T:6]N(&]F('!T7T)2+G!O('1O($)R87II;&EA;B!0;W)T=6=U
M97-E"B,@=')A;G-L871I;VX@;V8@:6YG;RYP;R!T;R!"<F%Z:6QI86X@4&]R
M='5G=65S90HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!004-+04=%('!A8VMA9V4N"B,@0V]P>7)I
M9VAT("A#*2!914%2($AO<F1E(%!R;VIE8W0N"B,@1F%B:6\@1V]M97,@/&9L
M9V]M97-`9F%Z96YD82YS<"YG;W8N8G(^+"`R,#`U+@HC"FUS9VED("(B"FUS
M9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!P=%]05%QN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3`X+3,P(#$Q.C(X*S`R,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#4M,#,M,#$@,3(Z,C@M,#,P,%QN(@HB3&%S="U4
M<F%N<VQA=&]R.B!&86)I;R!';VUE<R`\9FQG;VUE<T!F87IE;F1A+G-P+F=O
M=BYB<CY<;B(*(DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T=6=U97-E
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB
M6"U'96YE<F%T;W(Z($M"86)E;"`Q+C,N,5QN(@HB4&QU<F%L+49O<FUS.B`@
M;G!L=7)A;',],CL@<&QU<F%L/2AN(#X@,2D[7&XB"@HC.B!F:6QT97)S+G!H
M<#HQ-C<*;7-G:60@(B!A;F0B"FUS9W-T<B`B(&4B"@HC.B!F:6QT97)S+G!H
M<#HQ-C<*;7-G:60@(B!O<B(*;7-G<W1R("(@;W4B"@HC.B!T96UP;&%T97,O
M8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,3D*;7-G:60@(D%C=&EO;B!F;W(@
M8FQA8VML:7-T960@861D<F5S<V5S.B(*;7-G<W1R(")!8^?C;R!P87)A(&5N
M9&5R9>=O<R!N82!L:7-T82!N96=R83HB"@HC.B!T96UP;&%T97,O<V-R:7!T
M+V%C=&EV871E+FEN8SHQ,`IM<V=I9"`B06-T:79A=&4@4V-R:7!T(@IM<V=S
M='(@(D%C=&EV87(@7")38W)I<'1<(B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W-E='1I;F=S+FEN8SHY"FUS9VED(")!9&1I=&EO;F%L(%-E='1I;F=S(@IM
M<V=S='(@(D-O;F9I9W5R8>?U97,@061I8VEO;F%I<R(*"B,Z('1E;7!L871E
M<R]R=6QE+VAE861E<BYI;F,Z-3,*;7-G:60@(D%L;"!O9B!T:&4@9F]L;&]W
M:6YG(@IM<V=S='(@(E1O9&]S(&]S('-E9W5I;G1E<R(*"B,Z('1E;7!L871E
M<R]R=6QE+V9O;W1E<BYI;F,Z-#0*;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@
M(E)E<W!O;F1I9&\B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C4V
M"FUS9VED(")!;GD@;V8@=&AE(&9O;&QO=VEN9R(*;7-G<W1R(")1=6%L<75E
M<B!D;W,@<V5G=6EN=&5S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R
M+FEN8SHQ-@IM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R(")!<&QI8V%R
M($9I;'1R;W,B"@HC.B!F:6QT97)S+G!H<#HQ.38*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/R(*;7-G<W1R(")4
M96T@82!C97)T97IA('%U92!Q=65R(')E;6]V97(@97-T82!R96=R83\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,*;7-G:60@(D%U=&]M871I8V%L
M;'D@=7!D871E('1H92!S8W)I<'0@869T97(@96%C:"!C:&%N9V4_(@IM<V=S
M='(@(D%C='5A;&EZ87(@875T;VUA=&EC86UE;G1E(&\@7")S8W)I<'1<(B!D
M97!O:7,@9&4@8V%D82!A;'1E<F'GXV\_(@H*(SH@8V]N9FEG+V9I96QD<RYP
M:'`N9&ES=#HT-PIM<V=I9"`B0F-C(@IM<V=S='(@(D-C;R(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS,S<*;7-G:60@(D)E9VEN<R!W:71H(@IM<V=S='(@(D-O
M;67G82!C;VTB"@HC.B!F:6QT97)S+G!H<#HQ,C8@=&5M<&QA=&5S+V)L86-K
M;&ES="]B;&%C:VQI<W0N:6YC.C@*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R
M("),:7-T82!.96=R82(*"B,Z(&)L86-K;&ES="YP:'`Z,3`P"FUS9VED(")"
M;&%C:VQI<W0@161I="(*;7-G<W1R(")%9&ET87(@3&ES=&$@3F5G<F$B"@HC
M.B!B;&%C:VQI<W0N<&AP.C$W"FUS9VED(")";&%C:VQI<W0@:7,@;F]T('-U
M<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G
M<W1R(")!($QI<W1A($YE9W)A(&[C;R#I('-U<&]R=&%D82!P96QO(&UE8V%N
M:7-M;R!D92!F:6QT<F%G96T@8V]R<F5N=&4N(@H*(SH@;&EB+U-C<FEP="]P
M<F]C;6%I;"YP:'`Z,C`R"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S(@IM
M<V=S='(@(D5N9&5R9>=O(&YA($QI<W1A($YE9W)A(@H*(SH@;&EB+U-C<FEP
M="]S:65V92YP:'`Z,C0R"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S97,B
M"FUS9W-T<B`B16YD97)EYV]S(&YA($QI<W1A($YE9W)A(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HX.`IM<V=I9"`B0F]D>2(*;7-G<W1R(")#;W)P
M;R(*"B,Z(&9I;'1E<G,N<&AP.C$V-"!R=6QE+G!H<#HR,S<*;7-G:60@(D-A
M<V4@4V5N<VET:79E(@IM<V=S='(@(D1I<V-R:6UI;F$@36%I^G-C=6QA<R!D
M92!-:6[Z<V-U;&%S(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HT,PIM
M<V=I9"`B0V,B"FUS9W-T<B`B0V,B"@HC.B!R=6QE+G!H<#HQ,#0@=VAI=&5L
M:7-T+G!H<#HS-B!F;W)W87)D+G!H<#HS,R!V86-A=&EO;BYP:'`Z-#$*(SH@
M8FQA8VML:7-T+G!H<#HV.0IM<V=I9"`B0VAA;F=E<R!S879E9"XB"FUS9W-T
M<B`B06QT97)AY_5E<R!G=6%R9&%D87,N(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,S,PIM<V=I9"`B0V]N=&%I;G,B"FUS9W-T<B`B0V]N=.EM(@H*(SH@9FEL
M=&5R<RYP:'`Z,C`T(&9I;'1E<G,N<&AP.C(P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W!Y("5S(@IM<V=S='(@(D-O<&EA<B`E<R(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HW-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!O9B`E<R(*
M;7-G<W1R(")#\W!I82!D92`E<R(*"B,Z(&QI8B]);F=O+G!H<#HU,@IM<V=I
M9"`B0W)E871E(&YE=R!F;VQD97(B"FUS9W-T<B`B0W)I87(@;F]V82!P87-T
M82(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BYH=&UL.C$V"FUS9VED
M(")$25-!0DQ%1"(*;7-G<W1R(")$15-!0U1)5D%$02(*"B,Z(&QI8B]38W)I
M<'0O<')O8VUA:6PN<&AP.C,S-PIM<V=I9"`B1$E304),140Z("(*;7-G<W1R
M(")$15-!0U1)5D%$03H@(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T
M92YI;F,Z,3<*;7-G:60@(D1E86-T:79A=&4@4V-R:7!T(@IM<V=S='(@(D1E
M<V%C=&EV87(@7")38W)I<'1<(B(*"B,Z(&9I;'1E<G,N<&AP.C$Y-B!F:6QT
M97)S+G!H<#HQ.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(@IM
M<V=S='(@(E)E;6]V97(@)7,B"@HC.B!T96UP;&%T97,O<G5L92]F:6QT97(N
M:6YC.C,P"FUS9VED(")$96QE=&4@0V]N9&ET:6]N(@IM<V=S='(@(E)E;6]V
M97(@0V]N9&GGXV\B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,CDQ"FUS9VED(")$
M96QE=&4@;65S<V%G92!C;VUP;&5T96QY(@IM<V=S='(@(E)E;6]V97(@;65N
M<V%G96T@8V]M<&QE=&%M96YT92(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E
M<BYI;F,Z-#<*;7-G:60@(D1E;&5T960B"FUS9W-T<B`B4F5M;W9I9&$B"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,C<Y"FUS9VED(")$96QI=F5R(&EN=&\@;7D@
M24Y"3U@B"FUS9W-T<B`B16YT<F5G87(@;F$@;6EN:&$@0V%I>&$@9&4@16YT
M<F%D82(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,#4*;7-G:60@(D1E;&EV97(@
M:6YT;R!M>2!)3D)/6"!A;F0@8V]P>2!T;R(*;7-G<W1R(")%;G1R96=A<B!N
M82!M:6YH82!#86EX82!D92!%;G1R861A(&4@8V]P:6%R('!A<F$B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S`P"FUS9VED(")$96QI=F5R(&EN=&\@;7D@24Y"
M3U@@86YD(')E9&ER96-T('1O(@IM<V=S='(@(D5N=')E9V%R(&YA(&UI;FAA
M($-A:7AA(&1E($5N=')A9&$@92!R961I<F5C8VEO;F%R('!A<F$B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,C@U"FUS9VED(")$96QI=F5R('1O(&9O;&1E<B(*
M;7-G<W1R(")%;G1R96=A<B!N82!P87-T82(*"B,Z(&9I;'1E<G,N<&AP.C(Q
M."!F:6QT97)S+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ES86)L
M92`E<R(*;7-G<W1R(")$97-A=&EV87(@)7,@(@H*(SH@=&5M<&QA=&5S+W=H
M:71E;&ES="]W:&ET96QI<W0N:6YC.CD@=&5M<&QA=&5S+V)L86-K;&ES="]B
M;&%C:VQI<W0N:6YC.C$P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO
M;BYI;F,Z.2!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHY"B,Z('1E
M;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,S`*;7-G:60@(D1I<V%B;&5D(@IM
M<V=S='(@(D1E<V%T:79A9&\B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T
M:6YG<RYI;F,Z,C$*;7-G:60@(D1I<W!L87D@9&5T86EL960@;F]T:69I8V%T
M:6]N('=H96X@96%C:"!F:6QT97(@:7,@87!P;&EE9#\B"FUS9W-T<B`B36]S
M=')A<B!N;W1I9FEC8>?C;R!P;W)M96YO<FEZ861A('%U86YD;R!C861A(&9I
M;'1R;R!F;W(@87!L:6-A9&\_(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A
M8V%T:6]N+FEN8SHS.`IM<V=I9"`B1&\@7VYO="!S96YD(')E<W!O;G-E<R!T
M;R!B=6QK(&]R(&QI<W0@;65S<V%G97,B"FUS9W-T<B`B(@HB7T[C;R!E;G9I
M87(@<F5S<&]S=&%S('!A<F$@;65N<V%G96YS(&5M(&UA<W-A(&]U(&1E(&QI
M<W1A<R!D92!C;W)R96EO("(*(F5L96-T<O-N:6-O(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@=&AI<SHB"FUS9W-T<B`B
M1F%Z97(@:7-T;SHB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S,X"FUS9VED(")$
M;V5S;B=T(&)E9VEN('=I=&@B"FUS9W-T<B`B3N-O(&-O;67G82!C;VTB"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S,T"FUS9VED(")$;V5S;B=T(&-O;G1A:6XB
M"FUS9W-T<B`B3N-O(&-O;G3I;2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#`*
M;7-G:60@(D1O97-N)W0@96YD('=I=&@B"FUS9W-T<B`B3N-O('1E<FUI;F$@
M8V]M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T,@IM<V=I9"`B1&]E<VXG="!E
M>&ES="(*;7-G<W1R(").XV\@97AI<W1E(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,T-0IM<V=I9"`B1&]E<VXG="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I
M(@IM<V=S='(@(D[C;R!C;W)R97-P;VYD92!A("AC;VT@;6%R8V'G]65S*2(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C`*;7-G:60@(D5D
M:70B"FUS9W-T<B`B161I=&%R(@H*(SH@9FEL=&5R<RYP:'`Z,3@U(&9I;'1E
M<G,N<&AP.C$X-R!F:6QT97)S+G!H<#HQ.3$@9FEL=&5R<RYP:'`Z,3DR"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@)7,B"FUS9W-T<B`B161I=&%R("5S
M(@H*(SH@9FEL=&5R<RYP:'`Z,C(R(&9I;'1E<G,N<&AP.C(R,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%;F%B;&4@)7,B"FUS9W-T<B`B06-T:79A<B`E<R(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,C(*;7-G:60@(D5N
M86)L960B"FUS9W-T<B`B06-T:79A9&\B"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,S,Y"FUS9VED(")%;F1S('=I=&@B"FUS9W-T<B`B5&5R;6EN82!C;VTB"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S4P"FUS9VED(")%<75A;"!T;R(*;7-G<W1R
M("))9W5A;"!A(@H*(SH@8FQA8VML:7-T+G!H<#HV-PIM<V=I9"`B17)R;W(@
M<V%V:6YG(&-H86YG97,N(@IM<V=S='(@(D5R<F\@86\@9W5A<F1A<B!A<R!A
M;'1E<F'G]65S+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z
M-PIM<V=I9"`B17AI<W1I;F<@4G5L97,B"FUS9W-T<B`B4F5G<F%S($5X:7-T
M96YT97,B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0Q"FUS9VED(")%>&ES=',B
M"FUS9W-T<B`B17AI<W1E(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN
M9W,N:6YC.C,P"FUS9VED(")&:6QT97(@06QL($UE<W-A9V5S(@IM<V=S='(@
M(D9I;'1R87(@5&]D87,@87,@365N<V%G96YS(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<V5T=&EN9W,N:6YC.C,R"FUS9VED(")&:6QT97(@3VYL>2!3965N
M($UE<W-A9V5S(@IM<V=S='(@(D9I;'1R87(@07!E;F%S($UE;G-A9V5N<R!,
M:61A<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHS,0IM
M<V=I9"`B1FEL=&5R($]N;'D@56YS965N($UE<W-A9V5S(@IM<V=S='(@(D9I
M;'1R87(@07!E;F%S($UE;G-A9V5N<R!0;W(@3&5R(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(X"FUS9VED(")&:6QT97(@3W!T:6]N
M<R(*;7-G<W1R(")/<.?U97,@9&4@1FEL=')A9V5M(@H*(SH@=&5M<&QA=&5S
M+W)U;&4O:&5A9&5R+FEN8SHR.`IM<V=I9"`B1FEL=&5R(%)U;&4B"FUS9W-T
M<B`B4F5G<F$@9&4@1FEL=')A9V5M(@H*(SH@9FEL=&5R<RYP:'`Z.3(*;7-G
M:60@(D9I;'1E<B!2=6QE<R(*;7-G<W1R(")296=R87,@9&4@1FEL=')A9V5M
M(@H*(SH@<V-R:7!T+G!H<#HU,@IM<V=I9"`B1FEL=&5R(%-C<FEP="!$:7-P
M;&%Y(@IM<V=S='(@(E9I<W5A;&EZ8>?C;R!D;R!<(E-C<FEP=%PB(&1E($9I
M;'1R86=E;2(*"B,Z(&QI8B]);F=O+G!H<#HR-C<*;7-G:60@(D9I;'1E<B!?
M4G5L97,B"FUS9W-T<B`B7U)E9W)A<R!D92!&:6QT<F%G96TB"@HC.B!L:6(O
M4V-R:7!T+VEM87`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT
M97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&-O<&EE9"!T
M;R!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@HB06-T:79I9&%D92!D
M92!F:6QT<F%G96TZ("5S(&UE;G-A9V5M*&YS*2!F;VDH<F%M*2!C;W!I861A
M*',I('!A<F$@82!P87-T82!<(B4B"B)S7"(N(@H*(SH@;&EB+U-C<FEP="]I
M;6%P+G!H<#HS,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV
M:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(")!8W1I=FED861E(&1E(&9I;'1R86=E;3H@)7,@;65N<V%G96TH;G,I(&9O
M:2AR86TI(')E;6]V:61A<RAS*2XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP
M.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S
M(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R("(B"B)!8W1I=FED861E(&1E(&9I;'1R86=E;3H@)7,@
M;65N<V%G96TH;G,I(&9O:2AR86TI(&UO=FED82AS*2!P87)A(&$@<&%S=&$@
M7"(E<R(*(EPB+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,3@V"B,L('!H
M<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS
M*2!T:&%T(&UA=&-H960@=&AE(&)L86-K;&ES="!W97)E(&1E;&5T960N(@IM
M<V=S='(@(B(*(D%C=&EV:61A9&4@9&4@9FEL=')A9V5M.B`E<R!M96YS86=E
M;2AN<RD@8V]M(&-O<G)E<W!O;F1E;G1E(&YA(&QI<W1A(&YE9W)A("(*(F9O
M:2AR86TI(')E;6]V:61A<RAS*2XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP
M.C,Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ
M(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I
M960@=&\@=&AE("(*(F9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*(D%C=&EV
M:61A9&4@9&4@9FEL=')A9V5M.B!!(&UE;G-A9V5M(%PB)7-<(B!D92!<(B5S
M7"(@9F]I(&-O<&EA9&$@<&%R82!A("(*(G!A<W1A(%PB)7-<(BXB"@HC.B!L
M:6(O4V-R:7!T+VEM87`N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!8W1I=FED861E(&1E(&9I
M;'1R86=E;3H@02!M96YS86=E;2!<(B5S7"(@9&4@7"(E<UPB(&9O:2!R96UO
M=FED82XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C(W-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB
M)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R
M("(*(EPB)7-<(BXB"FUS9W-T<B`B(@HB06-T:79I9&%D92!D92!&:6QT<F%G
M96TZ($$@;65N<V%G96T@7"(E<UPB(&1E(%PB)7-<(B!F;VD@;6]V:61A('!A
M<F$@82!P87-T82`B"B)<(B5S7"(N(@H*(SH@<G5L92YP:'`Z,3,R"FUS9VED
M(")&:6QT97(@;F]T(&9O=6YD+B(*;7-G<W1R(")&:6QT<F\@;N-O(&5N8V]N
M=')A9&\N(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHT.`IM<V=I
M9"`B1F]R(&%N(&EN8V]M:6YG(&UE<W-A9V4@=&AA="!M871C:&5S.B(*;7-G
M<W1R(")087)A('5M82!M96YS86=E;2!R96/I;2UC:&5G861A('%U92!C;W)R
M97-P;VYD83HB"@HC.B!F:6QT97)S+G!H<#HQ-#0@=&5M<&QA=&5S+V9O<G=A
M<F0O9F]R=V%R9"YI;F,Z-PIM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")2961I
M<F5C:6]N86UE;G1O(@H*(SH@9F]R=V%R9"YP:'`Z,38*;7-G:60@(D9O<G=A
M<F0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@
M9')I=F5R+B(*;7-G<W1R("(B"B)/(')E9&ER96-C:6]N86UE;G1O(&[C;R#I
M('-U<&]R=&%D;R!P96QO(&UE8V%N:7-M;R!D92!F:6QT<F%G96T@8V]R<F5N
M=&4N(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C@S"FUS9VED(")&
M;W)W87)D<R(*;7-G<W1R(")2961I<F5C8VEO;F%M96YT;W,B"@HC.B!F;W)W
M87)D+G!H<#HT-@IM<V=I9"`B1F]R=V%R9',@161I="(*;7-G<W1R(")%9&ET
M87(@4F5D:7)E8V-I;VYA;65N=&]S(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HS.0IM<V=I9"`B1G)O;2(*;7-G<W1R(")$92(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-#@*;7-G:60@(D=R96%T97(@=&AA;B(*;7-G<W1R(")-86EO
M<B!Q=64B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0Y"FUS9VED(")'<F5A=&5R
M('1H86X@;W(@97%U86P@=&\B"FUS9W-T<B`B36%I;W(@;W4@:6=U86P@82(*
M"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-#$*;7-G:60@(DEM<&]R
M=&%N="(*;7-G<W1R("));7!O<G1A;G1E(@H*(SH@<G5L92YP:'`Z,C8*;7-G
M:60@(DEN9&EV:61U86P@<G5L97,@87)E(&YO="!S=7!P;W)T960@:6X@=&AE
M(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B(@HB4F5G<F%S
M(&EN9&EV:61U86ES(&[C;R!SXV\@<W5P;W)T861A<R!P96QO(&UE8V%N:7-M
M;R!D92!F:6QT<F%G96T@8V]R<F5N=&4N(@H*(SH@;&EB+U-C<FEP="]S:65V
M92YP:'`Z,3@T.`IM<V=I9"`B26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE
M9"!F;W(@;65S<V%G92!D96QI=F5R>2XB"FUS9W-T<B`B0V%I>&$@<&]S=&%L
M(&5S<&5C:69I8V%D82!P87)A(&5N=')E9V$@;N-O(&5X:7-T92XB"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S,U"FUS9VED("))<R(*;7-G<W1R("+)(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C,S-@IM<V=I9"`B27-N)W0B"FUS9W-T<B`B3N-O
M(.DB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0V"FUS9VED("),97-S('1H86XB
M"FUS9W-T<B`B365N;W(@<75E(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-PIM
M<V=I9"`B3&5S<R!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S='(@(DUE;F]R(&]U
M(&EG=6%L(&$B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4Y"FUS9VED
M("),:7-T+4E$(@IM<V=S='(@(DE$(&1A($QI<W1A(@H*(SH@=&5M<&QA=&5S
M+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C(R"FUS9VED(")-87)?:R!M97-S
M86=E(&%S(&1E;&5T960B"FUS9W-T<B`B36%R7V-A<B!M96YS86=E;2!C;VUO
M(')E;6]V:61A(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,PIM
M<V=I9"`B36%R:R!M97-S86=E(&%S.B(*;7-G<W1R(")-87)C87(@;65N<V%G
M96T@8V]M;SHB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0T"FUS9VED(")-871C
M:&5S("AW:71H('!L86-E:&]L9&5R<RDB"FUS9W-T<B`B0V]R<F5S<&]N9&4@
M82`H8V]M(&UA<F-A9&]R97,I(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C0W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-87AI;75M(&YU;6)E<B!O9B!B;&%C
M:VQI<W1E9"!A9&1R97-S97,@97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@
M)7,L("(*(DUA>&EM=6T@861D<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D
M(&YE=R!A9&1R97-S97,@=&\@8FQA8VML:7-T+B(*;7-G<W1R("(B"B)%>&-E
M9&ED;R!O(&[Z;65R;R!MX7AI;6\@9&4@96YD97)EYV]S(&YA(&QI<W1A(&YE
M9W)A("A4;W1A;"!D92!E;F1E<F7G;W,Z("4B"B)S+"!-X7AI;6\@9&4@96YD
M97)EYV]S.B`E<RDN("!);7!O<W/M=F5L(&%D:6-I;VYA<B!N;W9O<R!E;F1E
M<F7G;W,@X"!L:7-T82`B"B)N96=R82XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M-3(T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUA>&EM=6T@;G5M8F5R(&]F
M('=H:71E;&ES=&5D(&%D9')E<W-E<R!E>&-E961E9"`H5&]T86P@861D<F5S
M<V5S.B`E<RP@(@HB36%X:6UU;2!A9&1R97-S97,Z("5S*2X@($-O=6QD(&YO
M="!A9&0@;F5W(&%D9')E<W-E<R!T;R!W:&ET96QI<W0N(@IM<V=S='(@(B(*
M(D5X8V5D:61O(&\@;OIM97)O(&WA>&EM;R!D92!E;F1E<F7G;W,@;F$@;&ES
M=&$@8G)A;F-A("A4;W1A;"!D92!E;F1E<F7G;W,Z("4B"B)S+"!-X7AI;6\@
M9&4@96YD97)EYV]S.B`E<RDN("!);7!O<W/M=F5L(&%D:6-I;VYA<B!N;W9O
M<R!E;F1E<F7G;W,@X"!L:7-T82`B"B)B<F%N8V$N(@H*(SH@;&EB+U-C<FEP
M="]S:65V92YP:'`Z,3<Q-@IM<V=I9"`B36ES<VEN9R!A9&1R97-S('1O(')E
M9&ER96-T(&UE<W-A9V4@=&\B"FUS9W-T<B`B16YD97)EYV\@9&4@<F5D:7)E
M8V-I;VYA;65N=&\@96T@9F%L=&$B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HQ-S0X"FUS9VED(")-:7-S:6YG(')E87-O;B!F;W(@<F5J96-T(@IM<V=S
M='(@(E)A>N-O('!A<F$@<F5J96GGXV\@96T@9F%L=&$B"@HC.B!L:6(O4V-R
M:7!T+W-I979E+G!H<#HQ.3$U"FUS9VED(")-:7-S:6YG(')E87-O;B!I;B!V
M86-A=&EO;BXB"FUS9W-T<B`B4F%ZXV\@<&%R82!M96YS86=E;2!D92!A=7/J
M;F-I82!E;2!F86QT82XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N
M:6YC.C(S"FUS9VED(")-;W9E(@IM<V=S='(@(DUO=F5R(@H*(SH@9FEL=&5R
M<RYP:'`Z,3`Y(&9I;'1E<G,N<&AP.C(Q-0IM<V=I9"`B36]V92!2=6QE($1O
M=VXB"FUS9W-T<B`B36]V97(@4F5G<F$@<&%R82!"86EX;R(*"B,Z(&9I;'1E
M<G,N<&AP.C$Q,"!F:6QT97)S+G!H<#HR,30*;7-G:60@(DUO=F4@4G5L92!5
M<"(*;7-G<W1R(")-;W9E<B!296=R82!P87)A($-I;6$B"@HC.B!T96UP;&%T
M97,O=F%C871I;VXO=F%C871I;VXN:6YC.C0V"FUS9VED(").7W5M8F5R(&]F
M(&1A>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S.B(*;7-G<W1R(")?3OIM
M97)O(&1E(&1I87,@96YT<F4@87,@;65N<V%G96YS(&1E(&%U<^IN8VEA.B(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHT('1E;7!L
M871E<R]F:6QT97)S+V9O;W1E<BYI;F,Z,3,*(SH@;&EB+U-T;W)A9V4N<&AP
M.C<P-PIM<V=I9"`B3F5W(%)U;&4B"FUS9W-T<B`B3F]V82!296=R82(*"B,Z
M(&QI8B]);F=O+G!H<#HQ.30@;&EB+TEN9V\N<&AP.C$Y-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!<(B5S7"(@96QE;65N="!F;W5N9"!I;B!B86-K96YD
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D\@96QE;65N=&\@7"(E<UPB(&[C
M;R!F;VD@96YC;VYT<F%D;R!N82!C;VYF:6=U<F'GXV\@9&4@8F%S92XB"@HC
M.B!L:6(O26YG;RYP:'`Z,3DR"FUS9VED(").;R!B86-K96YD(&-O;F9I9W5R
M960@9F]R('1H:7,@:&]S="(*;7-G<W1R(").XV\@:.$@=6UA(&-O;F9I9W5R
M8>?C;R!D92!B87-E('!A<F$@97-T92!S97)V:61O<B(*"B,Z(&QI8B]);F=O
M+G!H<#HQ-CD*;7-G:60@(DYO(&)A8VME;F1S(&-O;F9I9W5R960@:6X@8F%C
M:V5N9',N<&AP(@IM<V=S='(@(DYE;FAU;6$@8V]N9FEG=7)AY^-O(&1E(&)A
M<V4@96T@8F%C:V5N9',N<&AP(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL
M=&5R+6YO;F4N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@9FEL=&5R
M<RX@0VQI8VL@7"(E<UPB('1O(&-R96%T92!A(&YE=R!F:6QT97(N(@IM<V=S
M='(@(DYE;FAU;2!F:6QT<F\N($-L:7%U92!E;2!<(B5S7"(G('!A<F$@8W)I
M87(@=6T@;F]V;R!F:6QT<F\N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,3,R,"!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-#$S"B,Z(&QI8B]38W)I<'0O
M<VEE=F4N<&AP.C$U.#<*;7-G:60@(DYO(&AE861E<G,@<W!E8VEF:65D(@IM
M<V=S='(@(DYE;FAU;2!C86)EYV%L:&\@97-P96-I9FEC861O(@H*(SH@<V-R
M:7!T+G!H<#HV-PIM<V=I9"`B3F\@<V-R:7!T(&=E;F5R871E9"XB"FUS9W-T
M<B`B3F5N:'5M(%PB<V-R:7!T7"(@9V5R861O+B(*"B,Z(&QI8B]38W)I<'0O
M<VEE=F4N<&AP.C$V,#(*;7-G:60@(DYO('-T<FEN9W,@<W!E8VEF:65D(@IM
M<V=S='(@(DYE;FAU;6$@8V%D96EA(&1E(&-A<F%C=&5R97,@97-P96-I9FEC
M861A(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,0IM<V=I9"`B3F]T(&5Q=6%L
M('1O(@IM<V=S='(@(D1I9F5R96YT92!D92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.0IM<V=I9"`B3W!T:6]N<R!A8F]U="!S8W)I<'0@=7!D871I
M;F<N(@IM<V=S='(@(D]PY_5E<R!S;V)R92!A8W1U86QI>F'GXV\@9&4@7")S
M8W)I<'1S7"(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED
M(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D]U=')A<R!/<.?U97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]N97=?9F]L9&5R+FIS.C8*;7-G:60@(E!L
M96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T
M<B`B4&]R(&9A=F]R(&EN=')O9'5Z82!O(&YO;64@9&$@;F]V82!P87-T83HB
M"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C8T"FUS9VED
M(")27V5A<V]N(@IM<V=S='(@(E)?87KC;R(*"B,Z(&-O;F9I9R]F:65L9',N
M<&AP+F1I<W0Z-C,*;7-G:60@(E)E8V5I=F5D(@IM<V=S='(@(E)E8V5B:61A
M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C(Y-@IM<V=I9"`B4F5D:7)E8W0@=&\B
M"FUS9W-T<B`B4F5D:7)E8VEO;F%R('!A<F$B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S0S"FUS9VED(")296=U;&%R(&5X<')E<W-I;VXB"FUS9W-T<B`B17AP
M<F5S<^-O(')E9W5L87(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S$Q"FUS9VED
M(")296IE8W0@=VET:"!R96%S;VXB"FUS9W-T<B`B4F5J96ET87(@8V]M(')A
M>N-O(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU-0IM<V=I9"`B4F5S
M96YT(%1O(@IM<V=S='(@(E)E96YV:6%D82!087)A(@H*(SH@8V]N9FEG+V9I
M96QD<RYP:'`N9&ES=#HU,0IM<V=I9"`B4F5S96YT+69R;VTB"FUS9W-T<B`B
M4F5E;G9I861A($1E(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHW
M,@IM<V=I9"`B4F5T=7)N('1O($9I;'1E<G,@3&ES="(*;7-G<W1R(")6;VQT
M87(@X"!,:7-T82!D92!&:6QT<F]S(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES
M="]W:&ET96QI<W0N:6YC.C(X('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML
M:7-T+FEN8SHT,PHC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC
M.C<U('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,X"FUS9VED(")2
M971U<FX@=&\@4G5L97,@3&ES="(*;7-G<W1R(")6;VQT87(@X"!,:7-T82!D
M92!296=R87,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(Q
M"FUS9VED(")2=6QE(@IM<V=S='(@(E)E9W)A(@H*(SH@9FEL=&5R<RYP:'`Z
M-#4*;7-G:60@(E)U;&4@0V]P:65D(@IM<V=S='(@(E)E9W)A($-O<&EA9&$B
M"@HC.B!F:6QT97)S+G!H<#HS.0IM<V=I9"`B4G5L92!$96QE=&5D(@IM<V=S
M='(@(E)E9W)A(%)E;6]V:61A(@H*(SH@9FEL=&5R<RYP:'`Z-3D*;7-G:60@
M(E)U;&4@1&ES86)L960B"FUS9W-T<B`B4F5G<F$@1&5S86-T:79A9&$B"@HC
M.B!F:6QT97)S+G!H<#HV-`IM<V=I9"`B4G5L92!%;F%B;&5D(@IM<V=S='(@
M(E)E9W)A($%C=&EV861A(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN
M8SHS.0IM<V=I9"`B4G5L92!.86UE(@IM<V=S='(@(DYO;64@9&$@4F5G<F$B
M"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,C<@=&5M
M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C0R"B,Z('1E;7!L871E
M<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-S0@=&5M<&QA=&5S+V9O<G=A<F0O
M9F]R=V%R9"YI;F,Z,S<*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHW
M,0IM<V=I9"`B4V%V92(*;7-G<W1R(")'=6%R9&%R(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C0W"FUS9VED(")3879E(%-E='1I;F=S
M(@IM<V=S='(@(D=U87)D87(@0V]N9FEG=7)AY_5E<R(*"B,Z('1E;7!L871E
M<R]S8W)I<'0O:&5A9&5R+FEN8SHS"FUS9VED(")38W)I<'0B"FUS9W-T<B`B
M7")38W)I<'1<(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.`IM<V=I
M9"`B4V-R:7!T(%5P9&%T:6YG(@IM<V=S='(@(D%T=6%L:7IAY^-O(&1E(%PB
M4V-R:7!T<UPB(@H*(SH@;&EB+TEN9V\N<&AP.C(Q-PIM<V=I9"`B4V-R:7!T
M(&YO="!U<&1A=&5D+B(*;7-G<W1R(")<(E-C<FEP='-<(B!NXV\@9F]I(&%T
M=6%L:7IA9&\N(@H*(SH@;&EB+TEN9V\N<&AP.C$S,`IM<V=I9"`B4V-R:7!T
M('-U8V-E<W-F=6QL>2!A8W1I=F%T960N(@IM<V=S='(@(EPB4V-R:7!T7"(@
M86-T:79A9&\@8V]M('-U8V5S<V\N(@H*(SH@;&EB+TEN9V\N<&AP.C$R.0IM
M<V=I9"`B4V-R:7!T('-U8V-E<W-F=6QL>2!D96%C=&EV871E9"XB"FUS9W-T
M<B`B7")38W)I<'1<(B!D97-A=&EV861O(&-O;2!S=6-E<W-O+B(*"B,Z('1E
M;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S@*;7-G:60@(E-E96XB"FUS9W-T
M<B`B3&ED;R(*"B,Z(')U;&4N<&AP.C$V,@IM<V=I9"`B4V5L96-T(&$@9FEE
M;&0B"FUS9W-T<B`B4V5L96-C:6]N92!O(&-A;7!O(@H*(SH@;&EB+TEN9V\N
M<&AP.C0Y"FUS9VED(")396QE8W0@=&%R9V5T(&9O;&1E<B(*;7-G<W1R(")3
M96QE8V-I;VYE(&$@<&%S=&$@86QV;R(*"B,Z(')U;&4N<&AP.C$X,PIM<V=I
M9"`B4V5L9BU$969I;F5D($AE861E<B(*;7-G<W1R(")#86)EYV%L:&\@4&5R
M<V]N86QI>F%D;R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S4*;7-G
M:60@(E-E;F1E<B(*;7-G<W1R(")296UE=&5N=&4B"@HC.B!F:6QT97)S+G!H
M<#HW.`IM<V=I9"`B4V5T=&EN9W,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM
M<V=S='(@(D-O;F9I9W5R8>?U97,@86-T=6%L:7IA9&%S(&-O;2!S=6-E<W-O
M+B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C(T"FUS9VED
M(")3:&]W($%C=&EV92!38W)I<'0B"FUS9W-T<B`B36]S=')A<B!<(E-C<FEP
M=%PB($%C=&EV;R(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC
M.C,Q"FUS9VED(")3:&]W($-U<G)E;G0@4V-R:7!T(@IM<V=S='(@(DUO<W1R
M87(@7")38W)I<'1<(B!#;W)R96YT92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP
M+F1I<W0Z.#,*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%M86YH;R(*"B,Z('1E
M;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-C$*;7-G:60@(E-T;W`@8VAE8VMI
M;F<@:68@=&AI<R!R=6QE(&UA=&-H97,_(@IM<V=S='(@(E!A<F%R(&$@=F5R
M:69I8V'GXV\@<75A;F1O(&5S=&$@<F5G<F$@9F]R(&5X96-U=&%D83\B"@HC
M.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C4U"FUS9VED(")3
M=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E.B(*;7-G<W1R(")!7W-S=6YT
M;R!D82!M96YS86=E;2!D92!A=7/J;F-I83HB"@HC.B!C;VYF:6<O9FEE;&1S
M+G!H<"YD:7-T.C,Q"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D%S<W5N=&\B
M"@HC.B!L:6(O26YG;RYP:'`Z,3(U"FUS9VED(")4:&4@9')I=F5R('-A:60Z
M("(*;7-G<W1R(")/(&UE8V%N:7-M;R!D:7-S93H@(@H*(SH@;&EB+TEN9V\N
M<&AP.C$R-`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@
M=&AE('-C<FEP="XB"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O(&%C=&EV
M87(@;R!<(G-C<FEP=%PB+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,C,*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D96%C=&EV871I;F<@=&AE('-C<FEP="XB
M"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O(&1E<V%T:79A<B!O(%PB<V-R
M:7!T7"(N(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HR-PIM<V=I9"`B
M5&\B"FUS9W-T<B`B4&%R82(*"B,Z(&QI8B]38W)I<'0N<&AP.C$R,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO
M;B!O9B`E<RXB"FUS9W-T<B`B26UP;W-S[79E;"!A8W1U86QI>F%R(&$@9&5F
M:6YIY^-O(&1E("5S+B(*"B,Z(&9I;'1E<G,N<&AP.C$S."!T96UP;&%T97,O
M=F%C871I;VXO=F%C871I;VXN:6YC.C<*(SH@;&EB+U-C<FEP="]P<F]C;6%I
M;"YP:'`Z,C8Q"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")-96YS86=E;G,@
M9&4@075SZFYC:6$B"@HC.B!V86-A=&EO;BYP:'`Z-S(*;7-G:60@(E9A8V%T
M:6]N($5D:70B"FUS9W-T<B`B161I=&%R($UE;G-A9V5N<R!D92!!=7/J;F-I
M82(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C,U,`IM<V=I9"`B5F%C871I
M;VX@365S<V%G92(*;7-G<W1R(")-96YS86=E;2!D92!!=7/J;F-I82(*"B,Z
M('9A8V%T:6]N+G!H<#HQ-@IM<V=I9"`B5F%C871I;VX@:7,@;F]T('-U<'!O
M<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R
M("(B"B)-96YS86=E;G,@9&4@875SZFYC:6$@;N-O('/C;R!S=7!O<G1A9&%S
M('!E;&\@;65C86YI<VUO(&1E(&9I;'1R86=E;2`B"B)C;W)R96YT92XB"@HC
M.B!T96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z,3@*;7-G:60@
M(E=H7VET96QI<W0@861D<F5S<V5S.B(*;7-G<W1R(")%;F1E<F7G;W,@;F$@
M3&ES=&$@7T)R86YC83HB"@HC.B!F:6QT97)S+G!H<#HQ,S(@=&5M<&QA=&5S
M+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C<*;7-G:60@(E=H:71E;&ES="(*
M;7-G<W1R("),:7-T82!"<F%N8V$B"@HC.B!W:&ET96QI<W0N<&AP.C4U"FUS
M9VED(")7:&ET96QI<W0@161I="(*;7-G<W1R(")%9&ET87(@3&ES=&$@0G)A
M;F-A(@H*(SH@=VAI=&5L:7-T+G!H<#HQ.`IM<V=I9"`B5VAI=&5L:7-T(&ES
M(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E
M<BXB"FUS9W-T<B`B3&ES=&$@0G)A;F-A(&[C;R#I('-U<'!O<G1A9&$@<&5L
M;R!M96-A;FES;6\@9&4@9FEL=')A9V5M(&-O<G)E;G1E+B(*"B,Z(&QI8B]3
M8W)I<'0O<')O8VUA:6PN<&AP.C(S,2!L:6(O4V-R:7!T+W-I979E+G!H<#HR
M.38*;7-G:60@(E=H:71E;&ES=&5D($%D9')E<W-E<R(*;7-G<W1R(")%;F1E
M<F7G;W,@;F$@3&ES=&$@0G)A;F-A(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N
M9&ES=#HW.0IM<V=I9"`B6"U0<FEO<FET>2(*;7-G<W1R(")8+5!R:6]R:61A
M9&4B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C8W"FUS9VED(")8+5-P
M86TM3&5V96PB"FUS9W-T<B`B6"U.[79E;"UD92U3<&%M(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3<&%M+5-C;W)E(@IM<V=S
M='(@(E@M0VQA<W-I9FEC8>?C;RUD92U3<&%M(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HW-0IM<V=I9"`B6"U3<&%M+5-T871U<R(*;7-G<W1R(")8
M+45S=&%D;RUD92U3<&%M(@H*(SH@=F%C871I;VXN<&AP.C,P"FUS9VED("(B
M"B)9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!E;6%I;"!A9&1R97-S
M(&9O<B!W:&EC:"!T:&4@=F%C871I;VX@;65S<V%G97,@(@HB<VAO=6QD(&)E
M(&%C=&EV871E9"XB"FUS9W-T<B`B(@HB5&5M(&1E(&5S<&5C:69I8V%R('!E
M;&\@;65N;W,@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!P
M87)A('%U92!A("(*(FUE;G-A9V5M(&1E(&%U<^IN8VEA('-E:F$@86-T:79A
M9&$N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR-S@@;&EB+U-C<FEP="]I
M;6%P+G!H<#HS,#$@;&EB+U-C<FEP="]I;6%P+G!H<#HS,34*;7-G:60@(EM.
M;R!3=6)J96-T72(*;7-G<W1R(");4V5M($%S<W5N=&]=(@H*(SH@=&5M<&QA
M=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,C<*;7-G:60@(E]!9&1R97-S*&5S
M*2!T;R!F;W)W87)D('1O.B(*;7-G<W1R(")?16YD97)EYV\H<RD@<&%R82!O
M<R!Q=6%I<R!R961I<F5C:6]N87(Z(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N
M+W9A8V%T:6]N+FEN8SHR.`IM<V=I9"`B7T%D9')E<W-E<R!T;R!N;W0@<V5N
M9"!R97-P;VYS97,@=&\Z(@IM<V=S='(@(E]%;F1E<F7G;RAS*2!A;RAS*2!Q
M=6%L*&ES*2!NXV\@96YV:6%R(')E<W!O<W1A<SHB"@HC.B!L:6(O26YG;RYP
M:'`Z,C<R"FUS9VED(")?0FQA8VML:7-T(@IM<V=S='(@(DQI<W1A(%].96=R
M82(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,`IM
M<V=I9"`B7T1E;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`B4F5M
M;U]V97(@;65N<V%G96T@8V]M<&QE=&%M96YT92(*"B,Z('1E;7!L871E<R]B
M;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHS,PIM<V=I9"`B7T5N=&5R(&5A8V@@
M861D<F5S<R!O;B!A(&YE=R!L:6YE.B(*;7-G<W1R(")?26YT<F]D=7IA(&-A
M9&$@96YD97)EYV\@96T@<W5A(&QI;FAA.B(*"B,Z(&QI8B]);F=O+G!H<#HR
M-S@*;7-G:60@(E]&;W)W87)D(@IM<V=S='(@(E]2961I<F5C:6]N86UE;G1O
M(@H*(SH@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3D*;7-G:60@
M(E]+965P(&$@8V]P>2!O9B!M97-S86=E<R!I;B!T:&ES(&%C8V]U;G0_(@IM
M<V=S='(@(E]-86YT97(@=6UA(&/S<&EA(&1A<R!M96YS86=E;G,@;F5S=&$@
M8V]N=&$_(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC
M.C(T"FUS9VED(")?36]V92!M97-S86=E('1O(&9O;&1E<CHB"FUS9W-T<B`B
M7TUO=F5R(&UE;G-A9V5M('!A<F$@82!P87-T83HB"@HC.B!T96UP;&%T97,O
M=F%C871I;VXO=F%C871I;VXN:6YC.C$X"FUS9VED(")?37D@96UA:6P@861D
M<F5S<V5S.B(*;7-G<W1R(")?365U*',I(&5N9&5R9>=O*',I(&1E(&-O<G)E
M:6\@96QE8W1R\VYI8V\Z(@H*(SH@;&EB+TEN9V\N<&AP.C(X,0IM<V=I9"`B
M7U-C<FEP="(*;7-G<W1R(")<(E]38W)I<'1<(B(*"B,Z(&QI8B]);F=O+G!H
M<#HR-S4*;7-G:60@(E]686-A=&EO;B(*;7-G<W1R(")?075SZFYC:6%S(@H*
M(SH@;&EB+TEN9V\N<&AP.C(V.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R
M("),:7-T82!?0G)A;F-A(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN
M8SHT"FUS9VED(")A;F0B"FUS9W-T<B`B92(*"B,Z(&9I;'1E<G,N<&AP.C$V
M,@IM<V=I9"`B9FEE;&0B"FUS9W-T<B`B8V%M<&\B"@HC.B!F:6QT97)S+G!H
M<#HQ-C(*;7-G:60@(FUA=&-H(@IM<V=S='(@(F-O<G)E<W!O;F1E(@H*(SH@
M=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHT"FUS9VED(")O<B(*;7-G<W1R
M(")O=2(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C$R,0IM<V=I9"`B
M<')O8VUA:6P@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O(@IM<V=S='(@(EPB
M4V-R:7!T7"(@9&\@<')O8VUA:6P@9V5R861O('!E;&\@26YG;R(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C$P.`IM<V=I9"`B<VEE=F4@9FEL=&5R(&=E
M;F5R871E9"!B>2!);F=O(@IM<V=S='(@(D9I;'1R;R!P96YE:7)A("A<(G-I
M979E7"(I(&=E<F%D;R!P96QO($EN9V\B"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEN9V\O<&\O;F)?3D\N<&\`````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-3`R-#,`,3`T,3<S-C(W-#<`,#$W,S,U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",@3F]R
M=V5G:6%N('1R86YS;&%T:6]N<R!F;W(@26YG;R!P86-K86=E+@HC($-O<'ER
M:6=H="`H0RD@,C`P-2!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I
M<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($EN9V\@
M<&%C:V%G92X*(R!!=71O;6%T:6-A;&QY(&=E;F5R871E9"P@,C`P-2X*(PIM
M<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@26YG;R!(
M,R`H,2XP*5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U
M.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#$M,3$@,34Z
M,S@K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!!=71O;6%T:6-A;&QY(&=E
M;F5R871E9%QN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO
M<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L
M<STR.R!P;'5R86P]*&X@(3T@,2D[7&XB"@HC.B!F:6QT97)S+G!H<#HQ.#4*
M;7-G:60@(B!A;F0B"FUS9W-T<B`B;V<B"@HC.B!F:6QT97)S+G!H<#HQ.#4*
M;7-G:60@(B!O<B(*;7-G<W1R(")E;&QE<B(*"B,Z('1E;7!L871E<R]B;&%C
M:VQI<W0O8FQA8VML:7-T+FEN8SHQ-PIM<V=I9"`B06-T:6]N(&9O<B!B;&%C
M:VQI<W1E9"!A9&1R97-S97,Z(@IM<V=S='(@(D%K<VIO;B!F;W(@<W9A<G1E
M;&ES=&5D92!A9')E<W-E<CHB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV
M871E+FEN8SHQ,`IM<V=I9"`B06-T:79A=&4@4V-R:7!T(@IM<V=S='(@(D%K
M=&EV97(@<V-R:7!T(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06-T:79A=&EN9R!T:&4@<V-R:7!T(&9O<B!<
M(B5S7"(@9F%I;&5D.B`H)60I("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W-E='1I;F=S+FEN8SHV"FUS9VED(")!9&1I=&EO;F%L(%-E
M='1I;F=S(@IM<V=S='(@(D%N9')E('9A;&<B"@HC.B!T96UP;&%T97,O<G5L
M92]H96%D97(N:6YC.C0T"FUS9VED(")!;&P@;V8@=&AE(&9O;&QO=VEN9R(*
M;7-G<W1R(")!;&QE(&1E(&;X;&=E;F1E(@H*(SH@;&EB+V%P:2YP:'`Z-30*
M(RP@9G5Z>GD*;7-G:60@(D%L;&]W(%)U;&5S(@IM<V=S='(@(DYY(')E9V5L
M(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,PIM<V=I9"`B06YS
M=V5R960B"FUS9W-T<B`B0F5S=F%R="(*"B,Z('1E;7!L871E<R]R=6QE+VAE
M861E<BYI;F,Z-#4*;7-G:60@(D%N>2!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S
M='(@(DYO96X@878@9&4@9OAL9V5N9&4B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]F;V]T97(N:6YC.C$Q"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@
M(E1A(&9I;'1E<B!I(&)R=6LB"@HC.B!F:6QT97)S+G!H<#HR,30*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!R=6QE/R(*
M;7-G<W1R(")%<B!D=2!324M+15(@<.4@870@9'4@^&YS:V5R(.4@<VQE='1E
M(&1E;FYE(')E9V5L96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M"FUS9VED(")!=71O;6%T:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R
M(&5A8V@@8VAA;F=E/R(*;7-G<W1R(")!=71O;6%T:7-K(&]P<&1A=&5R('-C
M<FEP=&5T(&5T=&5R(&AV97(@9F]R86YD<FEN9S\B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C0W"FUS9VED(")"8V,B"FUS9W-T<B`B0FQI;F0@:V]P
M:2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#0*;7-G:60@(D)E9VEN<R!W:71H
M(@IM<V=S='(@(D)E9WEN;F5R(&UE9"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,3`V(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3$Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&9I
M;'1E<G,N<&AP.C$T-"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI
M;F,Z-PIM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(E-V87)T96QI<W1E(@H*
M(SH@8FQA8VML:7-T+G!H<#HQ,#`*;7-G:60@(D)L86-K;&ES="!%9&ET(@IM
M<V=S='(@(E-V87)T96QI<W1E(@H*(SH@8FQA8VML:7-T+G!H<#HQ-PIM<V=I
M9"`B0FQA8VML:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@
M9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B4W9A<G1E;&ES=&EN9R!E<B!I
M:VME('-T^'1T970@:2!D96YN92!F:6QT97(@9')I=F5R96XB"@HC.B!L:6(O
M4V-R:7!T+W!R;V-M86EL+G!H<#HR,#<@;&EB+U-C<FEP="]M86EL9')O<"YP
M:'`Z,3<U"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S(@IM<V=S='(@(E-V
M87)T96QI<W1E="!A9')E<W-E(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,C0S"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B4W9A
M<G1E;&ES=&5T(&%D<F5S<V5R(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES
M=#HX.`IM<V=I9"`B0F]D>2(*;7-G<W1R(")-96QD:6YG<W1E:W-T(@H*(SH@
M9FEL=&5R<RYP:'`Z,3@R(')U;&4N<&AP.C(X,0IM<V=I9"`B0V%S92!396YS
M:71I=F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HT
M,PIM<V=I9"`B0V,B"FUS9W-T<B`B2V]P:2!T:6PB"@HC.B!R=6QE+G!H<#HQ
M,C(@=VAI=&5L:7-T+G!H<#HS-B!F;W)W87)D+G!H<#HS,R!V86-A=&EO;BYP
M:'`Z-#$*(SH@8FQA8VML:7-T+G!H<#HV.0IM<V=I9"`B0VAA;F=E<R!S879E
M9"XB"FUS9W-T<B`B16YD<FEN9V5R(&QA9W)E="(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z-S4*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R
M("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S0P"FUS9VED(")#;VYT86EN<R(*
M;7-G<W1R("));FYE:&]L9&5R(@H*(SH@9FEL=&5R<RYP:'`Z,C(U(&9I;'1E
M<G,N<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y("5S(@IM<V=S
M='(@(DMO<&EE<B`E<R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HW-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]P>2!O9B`E<R(*;7-G<W1R(")+;W!I(&%V("5S
M(@H*(SH@;&EB+TEN9V\N<&AP.C4R"FUS9VED(")#<F5A=&4@;F5W(&9O;&1E
M<B(*;7-G<W1R(")/<'!R971T(&YY(&UA<'!E(@H*(SH@;&EB+U-C<FEP="]P
M<F]C;6%I;"YP:'`Z,S,V(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(W.0IM
M<V=I9"`B1$E304),140Z("(*;7-G<W1R(")$96%K=&EV97)T.B`B"@HC.B!T
M96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHQ-PIM<V=I9"`B1&5A8W1I
M=F%T92!38W)I<'0B"FUS9W-T<B`B1&5A:W1I=F5R('-C<FEP="(*"B,Z(&9I
M;'1E<G,N<&AP.C(Q-"!F:6QT97)S+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E("5S(@IM<V=S='(@(E-L971T("5S(@H*(SH@=&5M<&QA
M=&5S+W)U;&4O9FEL=&5R+FEN8SHS,`IM<V=I9"`B1&5L971E($-O;F1I=&EO
M;B(*;7-G<W1R(")&:F5R;B!R96=E;"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HR
M.3(*;7-G:60@(D1E;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`B
M4VQE='0@;65L9&EN9R!H96QT(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R
M+FEN8SHS-0IM<V=I9"`B1&5L971E9"(*;7-G<W1R(")3;&5T=&5T(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C(X,`IM<V=I9"`B1&5L:79E<B!I;G1O(&UY($E.
M0D]8(@IM<V=S='(@(DQE=F5R('1I;"!M:6X@26YN8F]K<R(*"B,Z(&QI8B]3
M=&]R86=E+G!H<#HS,#8*;7-G:60@(D1E;&EV97(@:6YT;R!M>2!)3D)/6"!A
M;F0@8V]P>2!T;R(*;7-G<W1R("),979E<B!T:6P@;6EN($EN;F)O:W,@;V<@
M:V]P:65R('1I;"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,#$*;7-G:60@(D1E
M;&EV97(@:6YT;R!M>2!)3D)/6"!A;F0@<F5D:7)E8W0@=&\B"FUS9W-T<B`B
M3&5V97(@=&EL(&UI;B!);FYB;VMS(&]G(')E9&5R:6=E<B!T:6PB"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,C@V"FUS9VED(")$96QI=F5R('1O(&9O;&1E<B(*
M;7-G<W1R("),979E<B!T:6P@;6%P<&4B"@HC.B!F:6QT97)S+G!H<#HR-#$@
M9FEL=&5R<RYP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(D1I<V%B;&4@
M)7,B"FUS9W-T<B`B1&5A:W1I=F5R("5S(@H*(SH@=&5M<&QA=&5S+W=H:71E
M;&ES="]W:&ET96QI<W0N:6YC.C$P('1E;7!L871E<R]B;&%C:VQI<W0O8FQA
M8VML:7-T+FEN8SHQ,`HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN
M:6YC.C8@=&5M<&QA=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHR-@IM<V=I9"`B1&ES86)L960B"FUS
M9W-T<B`B1&5A:W1I=F5R="(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I
M;F=S+FEN8SHQ,PIM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I
M;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/R(*;7-G<W1R(")6:7,@
M9&5T86QJ97)T(&UE;&1I;F<@;N5R(&AV97)T(&9I;'1E<B!B;&ER('1A='0@
M:2!B<G5K/R(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M,S0*;7-G:60@(D1O(%]N;W0@<V5N9"!R97-P;VYS97,@=&\@8G5L:R!O<B!L
M:7-T(&UE<W-A9V5S(@IM<V=S='(@(DEK:V4@<V5N9"!R97-P;VYS('1I;"!B
M=6QK(&5L;&5R(&QI<W1E(&UE;&1I;F=E<B(*"B,Z('1E;7!L871E<R]R=6QE
M+V9O;W1E<BYI;F,Z,3`*;7-G:60@(D1O('1H:7,Z(@IM<V=S='(@(D=J^'(@
M9&5T=&4Z(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-0IM<V=I9"`B1&]E<VXG
M="!B96=I;B!W:71H(@IM<V=S='(@(E-O;2!I:VME(&)E9WEN;F5R(&UE9"(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#$*;7-G:60@(D1O97-N)W0@8V]N=&%I
M;B(*;7-G<W1R(")3;VT@:6MK92!I;FYE:&]L9&5R(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,T-PIM<V=I9"`B1&]E<VXG="!E;F0@=VET:"(*;7-G<W1R(")3
M;VT@:6MK92!S;'5T=&5R(&UE9"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#D*
M;7-G:60@(D1O97-N)W0@97AI<W0B"FUS9W-T<B`B16MS:7-T97)E<B!I:VME
M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U,@IM<V=I9"`B1&]E<VXG="!M871C
M:"`H=VET:"!P;&%C96AO;&1E<G,I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+VAE861E<BYI;F,Z,S$*;7-G:60@(D5D:70B"FUS9W-T<B`B
M4F5D:6=E<B(*"B,Z(&9I;'1E<G,N<&AP.C(P,R!F:6QT97)S+G!H<#HR,#4@
M9FEL=&5R<RYP:'`Z,C`Y(&9I;'1E<G,N<&AP.C(Q,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET("5S(@IM<V=S='(@(E)E9&EG97(@)7,B"@HC.B!F:6QT
M97)S+G!H<#HR-#4@9FEL=&5R<RYP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G
M:60@(D5N86)L92`E<R(*;7-G<W1R(")!:W1I=F5R("5S(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHS-PIM<V=I9"`B16YA8FQE9"(*;7-G
M<W1R(")!:W1I=F5R="(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#8*;7-G:60@
M(D5N9',@=VET:"(*;7-G<W1R(")3;'5T=&5R(&UE9"(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-3<*;7-G:60@(D5Q=6%L('1O(@IM<V=S='(@(DQI:R!S;VTB
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$S.2!L:6(O1')I=F5R+VQD87`N
M<&AP.C$T.2!L:6(O1')I=F5R+VQD87`N<&AP.C$U.`HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R971R
M:65V:6YG(&-U<G)E;G0@<V-R:7!T.B`H)60I("5S(@IM<V=S='(@(B(*"B,Z
M(&)L86-K;&ES="YP:'`Z-C<*;7-G:60@(D5R<F]R('-A=FEN9R!C:&%N9V5S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC
M.C(R"FUS9VED(")%>&ES=&EN9R!2=6QE<R(*;7-G<W1R(")%:W-I<W1E<F5N
M9&4@<F5G;&5R(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T.`IM<V=I9"`B17AI
M<W1S(@IM<V=S='(@(D5K<VES=&5R97(B"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%>'!E8W1E9"`Q(&]B:F5C
M="P@9V]T("5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S
M971T:6YG<RYI;F,Z,C`*;7-G:60@(D9I;'1E<B!!;&P@365S<V%G97,B"FUS
M9W-T<B`B1FEL=')E<B!A;&QE(&UE;&1I;F=E<B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W-E='1I;F=S+FEN8SHR,@IM<V=I9"`B1FEL=&5R($]N;'D@4V5E
M;B!-97-S86=E<R(*;7-G<W1R(")&:6QT<F5R(&)A<F4@;&5S=&4@;65L9&EN
M9V5R(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC.C(Q"FUS
M9VED(")&:6QT97(@3VYL>2!5;G-E96X@365S<V%G97,B"FUS9W-T<B`B1FEL
M=')E<B!B87)E('5L97-T92!M96QD:6YG97(B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]S971T:6YG<RYI;F,Z,3@*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM
M<V=S='(@(D9I;'1E<B!V86QG(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R
M+FEN8SHR-0IM<V=I9"`B1FEL=&5R(%)U;&4B"FUS9W-T<B`B1FEL=&5R<F5G
M;&5R(@H*(SH@9FEL=&5R<RYP:'`Z,3`Y"FUS9VED(")&:6QT97(@4G5L97,B
M"FUS9W-T<B`B1FEL=&5R<F5G;&5R(@H*(SH@<V-R:7!T+G!H<#HU,@IM<V=I
M9"`B1FEL=&5R(%-C<FEP="!$:7-P;&%Y(@IM<V=S='(@(D9I;'1E<B!S8W)I
M<'0@=FES;FEN9R(*"B,Z(&QI8B]);F=O+G!H<#HS,#`*;7-G:60@(D9I;'1E
M<B!?4G5L97,B"FUS9W-T<B`B1FEL=&5R<F5G;&5R(@H*(SH@;&EB+U-C<FEP
M="]I;6%P+G!H<#HS,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9I
M;'1E<B!A8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@8V]P:65D
M('1O('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"B)&:6QT<F5R:6YG
M.B!-96QD:6YG96X@7"(E<UPB(&9R82!<(B5S7"(@:&%R(&)L:71T(&9L>71T
M970@=&EL(&UA<'!E;B!<(B5S7"(N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H
M<#HS,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E
M<R!M97-S86=E*',I(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")&:6QT
M<F5R;VUG.B`E<R!M96QD:6YG*&5N*2!B;&4@<VQE='1E="XB"@HC.B!L:6(O
M4V-R:7!T+VEM87`N<&AP.C(X,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!M
M;W9E9"!T;R!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@HB1FEL=')E
M<FEN9SH@365L9&EN9V5N(%PB)7-<(B!F<F$@7"(E<UPB(&AA<B!B;&ET="!F
M;'ET=&5T('1I;"!M87!P96X@7"(E<UPB+B(*"B,Z(&QI8B]38W)I<'0O:6UA
M<"YP:'`Z,3@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@
M86-T:79I='DZ("5S(&UE<W-A9V4H<RD@=&AA="!M871C:&5D('1H92!B;&%C
M:VQI<W0@=V5R92!D96QE=&5D+B(*;7-G<W1R(")&:6QT<F5R:6YG.B!-96QD
M:6YG96X@7"(E<UPB(&9R82!<(B5S7"(@:&%R(&)L:71T('-L971T970N(@H*
M(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HS,34*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(D9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E
M<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&-O<&EE9"!T;R!T:&4@(@HB9F]L
M9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@HB1FEL=')E<FEN9SH@365L9&EN9V5N
M(%PB)7-<(B!F<F$@7"(E<UPB(&AA<B!B;&ET="!F;'ET=&5T('1I;"!M87!P
M96X@7"(E<UPB+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S`P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ(%1H92!M
M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R(")&:6QT<F5R:6YG.B!-96QD:6YG96X@7"(E<UPB(&9R82!<(B5S
M7"(@:&%R(&)L:71T('-L971T970N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H
M<#HR-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D9I;'1E<B!A
M8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B
M965N(&UO=F5D('1O('1H92!F;VQD97(@(@HB7"(E<UPB+B(*;7-G<W1R("(B
M"B)&:6QT<F5R:6YG.B!-96QD:6YG96X@7"(E<UPB(&9R82!<(B5S7"(@:&%R
M(&)L:71T(&9L>71T970@=&EL(&UA<'!E;B!<(B5S7"(N(@H*(SH@<G5L92YP
M:'`Z,38P"FUS9VED(")&:6QT97(@;F]T(&9O=6YD+B(*;7-G<W1R(")&:6QT
M97(@:6MK92!F=6YN970B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC
M.C0R"FUS9VED(")&;W(@86X@:6YC;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H
M97,Z(@IM<V=S='(@(D9O<B!E;B!I;FYK;VUM96YD92!M96QD:6YG('-O;2!P
M87-S97(Z(@H*(SH@9FEL=&5R<RYP:'`Z,38R('1E;7!L871E<R]F;W)W87)D
M+V9O<G=A<F0N:6YC.C@*;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B5FED97)E
M<V5N9"(*"B,Z(&9O<G=A<F0N<&AP.C$V"FUS9VED(")&;W)W87)D(&ES(&YO
M="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB
M"FUS9W-T<B`B5FED97)E<V5N9"!E<B!I:VME('-T^'1T970@:2!V86QG="!F
M:6QT97(@9')I=F5R(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C@R
M(&QI8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(R-`IM<V=I9"`B1F]R=V%R9',B
M"FUS9W-T<B`B5FED97)E<V5N9&EN9V5R(@H*(SH@9F]R=V%R9"YP:'`Z-#8*
M;7-G:60@(D9O<G=A<F1S($5D:70B"FUS9W-T<B`B5FED97)E<V5N9&EN9W,@
M=F%L9R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,SD*;7-G:60@(D9R
M;VTB"FUS9W-T<B`B1G)A(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U-0IM<V=I
M9"`B1W)E871E<B!T:&%N(@IM<V=S='(@(E-T^')R92!E;FXB"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z,S4V"FUS9VED(")'<F5A=&5R('1H86X@;W(@97%U86P@
M=&\B"FUS9W-T<B`B4W3X<G)E(&5N;B!E;&QE<B!L:6L@<V]M(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHS,0IM<V=I9"`B26UP;W)T86YT(@IM
M<V=S='(@(E9I:W1I9R(*"B,Z(')U;&4N<&AP.C,V"B,L(&9U>GIY"FUS9VED
M("));F1I=FED=6%L(')U;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H92!C
M=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(E-V87)T96QI<W1I
M;F<@97(@:6MK92!S=/AT=&5T(&D@9&5N;F4@9FEL=&5R(&1R:79E<F5N(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3@U-0IM<V=I9"`B26YE>&ES=&%N
M="!M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G92!D96QI=F5R>2XB"FUS
M9W-T<B`B26MK92!E:W-I<W1E<F5N9&4@;6%I;&)O:W,@<W!E<VEF:7-E<G0@
M9F]R(&UE;&1I;F=S(&QE=F5R:6YG(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T
M,@IM<V=I9"`B27,B"FUS9W-T<B`B17(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,S0S"FUS9VED("))<VXG="(*;7-G<W1R(")%<B!I:VME(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HR,PIM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E
M<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O
M<B!N;W0@;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z
M,S4S"FUS9VED("),97-S('1H86XB"FUS9W-T<B`B36EN9')E(&5N;B(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS-30*;7-G:60@(DQE<W,@=&AA;B!O<B!E<75A
M;"!T;R(*;7-G<W1R(")-:6YD<F4@96YN(&5L;&5R(&QI:R!S;VTB"@HC.B!C
M;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4Y"FUS9VED("),:7-T+4E$(@IM<V=S
M='(@(DQI<W1E+4E$(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C(P"FUS9VED(")-87)?:R!M97-S86=E(&%S(&1E;&5T960B"FUS
M9W-T<B`B36%R:V5R(&UE;&1I;F<@<V]M('-L971T970B"@HC.B!T96UP;&%T
M97,O<G5L92]F;V]T97(N:6YC.C(T"FUS9VED(")-87)K(&UE<W-A9V4@87,Z
M(@IM<V=S='(@(DUA<FME<B!M96QD:6YG('-O;3HB"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S4Q"FUS9VED(")-871C:&5S("AW:71H('!L86-E:&]L9&5R<RDB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-3<*;7-G:60@(DUA>&EM=6T@
M3G5M8F5R(&]F(%)U;&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X:6UU;2!N=6UB97(@
M;V8@8FQA8VML:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R
M97-S97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@
M;F]T(&%D9"!N97<@861D<F5S<V5S('1O(&)L86-K;&ES="XB"FUS9W-T<B`B
M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C4S,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)-87AI;75M(&YU;6)E<B!O9B!W:&ET96QI<W1E9"!A9&1R97-S97,@
M97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L("(*(DUA>&EM=6T@861D
M<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A9&1R97-S97,@=&\@
M=VAI=&5L:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H
M<#HQ-S(S"FUS9VED(")-:7-S:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@;65S
M<V%G92!T;R(*;7-G<W1R("(B"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ
M-S4U"FUS9VED(")-:7-S:6YG(')E87-O;B!F;W(@<F5J96-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$Y,C(*;7-G:60@(DUI<W-I
M;F<@<F5A<V]N(&EN('9A8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]H96%D97(N:6YC.C0P"FUS9VED(")-;W9E(@IM<V=S='(@
M(D9L>71T(@H*(SH@9FEL=&5R<RYP:'`Z,3(V(&9I;'1E<G,N<&AP.C(S.`IM
M<V=I9"`B36]V92!2=6QE($1O=VXB"FUS9W-T<B`B1FQY='0@<F5G96P@;F5D
M(@H*(SH@9FEL=&5R<RYP:'`Z,3(W(&9I;'1E<G,N<&AP.C(S-PIM<V=I9"`B
M36]V92!2=6QE(%5P(@IM<V=S='(@(D9L>71T(')E9V5L(&]P<"(*"B,Z('1E
M;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-#(*;7-G:60@(DY?=6UB
M97(@;V8@9&%Y<R!B971W965N('9A8V%T:6]N(')E<&QI97,Z(@IM<V=S='(@
M(D%N=&%L;"!D86=E<B!M96QL;VT@<W9A<B!PY2!F97)I96UE;&1I;F<B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]F:6QT97(M;F]N92YI;F,Z-"!T96UP;&%T
M97,O9FEL=&5R<R]F;V]T97(N:6YC.C@*(SH@;&EB+U-T;W)A9V4N<&AP.C<Q
M-`IM<V=I9"`B3F5W(%)U;&4B"FUS9W-T<B`B3GD@<F5G96PB"@HC.B!L:6(O
M26YG;RYP:'`Z,3DT(&QI8B]);F=O+G!H<#HQ.38*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DYO(%PB)7-<(B!E;&5M96YT(&9O=6YD(&EN(&)A8VME
M;F0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B26YG96X@)R5S)R!E;&5M96YT
M97(@9G5N;F5T(&D@;W!P<V5T=&5T(@H*(SH@;&EB+TEN9V\N<&AP.C$Y,@IM
M<V=I9"`B3F\@8F%C:V5N9"!C;VYF:6=U<F5D(&9O<B!T:&ES(&AO<W0B"FUS
M9W-T<B`B26YG96X@8F%C:V5N9"!K;VYF:6=U<F5R="!F;W(@9&5N;F4@:&]S
M=&5N(@H*(SH@;&EB+TEN9V\N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8F%C:V5N9',@8V]N9FEG=7)E9"!I;B!B86-K96YD<RYP:'`B"FUS9W-T<B`B
M26YG96X@8F%C:V5N9"!K;VYF:6=U<F5R="!F;W(@9&5N;F4@:&]S=&5N(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+6YO;F4N:6YC.C0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&9I;'1E<G,N($-L:6-K(%PB)7-<
M(B!T;R!C<F5A=&4@82!N97<@9FEL=&5R+B(*;7-G<W1R("));F=E;B!F:6QT
M97(N($ML:6MK("<E<R<@9F]R(.4@;&%G92!E='0@;GET="!F:6QT97(N(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3,R-R!L:6(O4V-R:7!T+W-I979E
M+G!H<#HQ-#(P"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$U.30*;7-G:60@
M(DYO(&AE861E<G,@<W!E8VEF:65D(@IM<V=S='(@(DEN9V5N(&AE861E<B!S
M<&5S:69I<V5R="(*"B,Z('-C<FEP="YP:'`Z-C<*;7-G:60@(DYO('-C<FEP
M="!G96YE<F%T960N(@IM<V=S='(@(DEN9V5N('-C<FEP="!G96YE<F5R="(*
M"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$V,#D*;7-G:60@(DYO('-T<FEN
M9W,@<W!E8VEF:65D(@IM<V=S='(@(DEN9V5N('-T<F5N9V5R('-P97-I9FES
M97)T(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,U.`IM<V=I9"`B3F]T(&5Q=6%L
M('1O(@IM<V=S='(@(DEK:V4@;&EK('-O;2(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS,38*;7-G:60@(D]N;'D@9FQA9R!T:&4@;65S<V%G92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3D*;7-G:60@(D]P=&EO;G,@
M86)O=70@<V-R:7!T('5P9&%T:6YG+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T
M<B`B06YD<F4@=F%L9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VYE=U]F
M;VQD97(N:G,Z-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H
M92!N97<@9F]L9&5R.B(*;7-G<W1R(")696YN;&EG<W0@<VMR:78@:6YN(&YA
M=FYE="!P(&1E;B!N>64@;6%P<&5N.B(*"B,Z('1E;7!L871E<R]V86-A=&EO
M;B]V86-A=&EO;BYI;F,Z-C`*;7-G:60@(E)?96%S;VXB"FUS9W-T<B`B1W)U
M;FXB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C8S"B,L(&9U>GIY"FUS
M9VED(")296-E:79E9"(*;7-G<W1R(")-;W1T871T.B(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(E)E9&ER96-T('1O(@IM<V=S
M='(@(D]M861R97-S<B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3`*;7-G:60@
M(E)E9W5L87(@97AP<F5S<VEO;B(*;7-G<W1R(")686YL:6<@=71R>6MK(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,Q,@IM<V=I9"`B4F5J96-T('=I=&@@<F5A
M<V]N(@IM<V=S='(@(DEK:V4@;6]T=&$@;65D(&=R=6YN(@H*(SH@8V]N9FEG
M+V9I96QD<RYP:'`N9&ES=#HU-0HC+"!F=7IZ>0IM<V=I9"`B4F5S96YT(%1O
M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H5'5R8F$@
M,2XR*2`@(RTC+2,M(RTC7&XB"B).=6QL<W1I;&Q<;B(*(B,M(RTC+2,M(R`@
M;F)?3D\N<&\@*$MR;VYO;&ET:"`Q+C$I("`C+2,M(RTC+2-<;B(*(E1M(@H*
M(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B
M4F5S96YT+69R;VTB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A4=7)B82`Q+C(I("`C+2,M(RTC+2-<;B(*(DYU;&QS=&EL;%QN(@HB
M(RTC+2,M(RTC("!N8E].3RYP;R`H2W)O;F]L:71H(#$N,2D@(",M(RTC+2,M
M(UQN(@HB5&TB"@HC.B!T96UP;&%T97,O<G5L92]F;V]T97(N:6YC.C8P"FUS
M9VED(")2971U<FX@=&\@1FEL=&5R<R!,:7-T(@IM<V=S='(@(E1I;&)A:V4@
M=&EL($9I;'1E<B!L:7-T92(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI
M=&5L:7-T+FEN8SHR-"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI
M;F,Z-#$*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHW,2!T
M96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHS-`IM<V=I9"`B4F5T=7)N
M('1O(%)U;&5S($QI<W0B"FUS9W-T<B`B5&EL8F%K92!T:6P@4F5G96P@;&ES
M=&4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C,T"FUS9VED
M(")2=6QE(@IM<V=S='(@(E)E9V5L(@H*(SH@9FEL=&5R<RYP:'`Z-C`*;7-G
M:60@(E)U;&4@0V]P:65D(@IM<V=S='(@(E)E9V5L(&MO<&EE<G0B"@HC.B!F
M:6QT97)S+G!H<#HS.0IM<V=I9"`B4G5L92!$96QE=&5D(@IM<V=S='(@(E)E
M9V5L('-L971T970B"@HC.B!F:6QT97)S+G!H<#HW-@IM<V=I9"`B4G5L92!$
M:7-A8FQE9"(*;7-G<W1R(")296=E;"!D96%K=&EV97)T(@H*(SH@9FEL=&5R
M<RYP:'`Z.#$*;7-G:60@(E)U;&4@16YA8FQE9"(*;7-G<W1R(")296=E;"!A
M:W1I=F5R="(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,S,*;7-G
M:60@(E)U;&4@3F%M92(*;7-G<W1R(")296=E;"!N879N(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")35$%25%1,
M4R!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W=H
M:71E;&ES="]W:&ET96QI<W0N:6YC.C(S('1E;7!L871E<R]B;&%C:VQI<W0O
M8FQA8VML:7-T+FEN8SHT,`HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C<P('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,S"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-3D*;7-G:60@(E-A=F4B"FUS
M9W-T<B`B3&%G<F4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI
M;F,Z,CD*;7-G:60@(E-A=F4@4V5T=&EN9W,B"FUS9W-T<B`B3&%G<F4@:6YS
M=&EL;&EN9V5R(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]H96%D97(N:6YC.C(*
M;7-G:60@(E-C<FEP="(*;7-G<W1R(")38W)I<'0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*;7-G<W1R
M(")38W)I<'0@;W!P9&%T97)I;F<B"@HC.B!L:6(O26YG;RYP:'`Z,C$W"FUS
M9VED(")38W)I<'0@;F]T('5P9&%T960N(@IM<V=S='(@(E-C<FEP="!I:VME
M(&]P<&1A=&5R="(*"B,Z(&QI8B]);F=O+G!H<#HQ,S`*;7-G:60@(E-C<FEP
M="!S=6-C97-S9G5L;'D@86-T:79A=&5D+B(*;7-G<W1R(")38W)I<'0@86MT
M:79E<G0B"@HC.B!L:6(O26YG;RYP:'`Z,3(Y"B,L(&9U>GIY"FUS9VED(")3
M8W)I<'0@<W5C8V5S<V9U;&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")-87!P
M96X@7"(E<UPB(&)L92!S;&5T=&5T+B(*"B,Z('1E;7!L871E<R]R=6QE+V9O
M;W1E<BYI;F,Z,CD*;7-G:60@(E-E96XB"FUS9W-T<B`B3&5S="(*"B,Z(')U
M;&4N<&AP.C$Y,`IM<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`B5F5L
M9R!E='0@9F5L="(*"B,Z(&QI8B]);F=O+G!H<#HT.0IM<V=I9"`B4V5L96-T
M('1A<F=E="!F;VQD97(B"FUS9W-T<B`B=F5L9R!M87!P92(*"B,Z(')U;&4N
M<&AP.C(R-PIM<V=I9"`B4V5L9BU$969I;F5D($AE861E<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,U"FUS9VED(")396YD97(B
M"FUS9W-T<B`B4V5N9&5R(@H*(SH@9FEL=&5R<RYP:'`Z.34*(RP@9G5Z>GD*
M;7-G:60@(E-E='1I;F=S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R
M(")-87!P96X@7"(E<UPB(&)L92!O<'!R971T970N(@H*(SH@=&5M<&QA=&5S
M+W-C<FEP="]A8W1I=F%T92YI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E-H;W<@
M06-T:79E(%-C<FEP="(*;7-G<W1R(")!:W1I=F5R('-C<FEP="(*"B,Z('1E
M;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C,Q"FUS9VED(")3:&]W($-U
M<G)E;G0@4V-R:7!T(@IM<V=S='(@(E9I<R!S8W)I<'0@<V]M(&5R(&D@8G)U
M:R(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z.#,*;7-G:60@(E-I>F4B
M"FUS9W-T<B`B4W3X<G)E;'-E(@H*(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R
M+FEN8SHT.0IM<V=I9"`B4W1O<"!C:&5C:VEN9R!I9B!T:&ES(')U;&4@;6%T
M8VAE<S\B"FUS9W-T<B`B4W1O<'`@<VIE:VL@9&5R<V]M(&1E;FYE(')E9V5L
M96X@<W1E;6UE<C\B"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN
M:6YC.C4Q"B,L(&9U>GIY"FUS9VED(")3=6)J95]C="!O9B!V86-A=&EO;B!M
M97-S86=E.B(*;7-G<W1R(").97-T92!M96QD:6YG(@H*(SH@8V]N9FEG+V9I
M96QD<RYP:'`N9&ES=#HS,0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")%;6YE
M(@H*(SH@;&EB+V%P:2YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&%D9')E<W,@7"(E<UPB(&AA<R!B965N(&%D9&5D('1O('EO=7(@8FQA8VML
M:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@7"(E<UPB(&AA<R!B965N(&%D9&5D
M('1O('EO=7(@=VAI=&5L:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O26YG;RYP
M:'`Z,3(U"FUS9VED(")4:&4@9')I=F5R('-A:60Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O26YG;RYP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*%1U<F)A(#$N,BD@(",M(RTC+2,M
M(UQN(@HB1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T(&%V(&1A=&%E
M;F4N7&XB"B(C+2,M(RTC+2,@(&YB7TY/+G!O("A+<F]N;VQI=&@@,2XQ*2`@
M(RTC+2,M(RTC7&XB"B)$970@<VMJ961D92!E;B!F96EL('9E9"!I;7!O<G0@
M878@9&%T82XB"@HC.B!L:6(O26YG;RYP:'`Z,3(S"B,L(&9U>GIY"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N
M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H5'5R8F$@
M,2XR*2`@(RTC+2,M(RTC7&XB"B)$970@;W!P<W1O9"!E;B!F96EL('9E9"!I
M;7!O<G0@878@9&%T865N92Y<;B(*(B,M(RTC+2,M(R`@;F)?3D\N<&\@*$MR
M;VYO;&ET:"`Q+C$I("`C+2,M(RTC+2-<;B(*(D1E="!S:VIE9&1E(&5N(&9E
M:6P@=F5D(&EM<&]R="!A=B!D871A+B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP
M+F1I<W0Z,C<*;7-G:60@(E1O(@IM<V=S='(@(E1I;"(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+V9I;'1E<BYH=&UL.C(X"B,L(&9U>GIY"FUS9VED(")4;SHB
M"FUS9W-T<B`B5&EL(@H*(SH@;&EB+U-C<FEP="YP:'`Z,3(W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R(")+86X@:6MK92!L87-T92!D971F:6YI<VIO;F5N(&%V
M("5S+B(*"B,Z(&9I;'1E<G,N<&AP.C$U-B!T96UP;&%T97,O=F%C871I;VXO
M=F%C871I;VXN:6YC.C4*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C8R
M"B,L(&9U>GIY"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")0;&%S<V5R:6YG
M(@H*(SH@=F%C871I;VXN<&AP.C<R"B,L(&9U>GIY"FUS9VED(")686-A=&EO
M;B!%9&ET(@IM<V=S='(@(E!L87-S97)I;F<B"@HC.B!L:6(O4V-R:7!T+W-I
M979E+G!H<#HS-3$*(RP@9G5Z>GD*;7-G:60@(E9A8V%T:6]N($UE<W-A9V4B
M"FUS9W-T<B`B3F5S=&4@;65L9&EN9R(*"B,Z('9A8V%T:6]N+G!H<#HQ-@HC
M+"!F=7IZ>0IM<V=I9"`B5F%C871I;VX@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")3=F%R=&5L
M:7-T:6YG(&5R(&EK:V4@<W3X='1E="!I(&1E;FYE(&9I;'1E<B!D<FEV97)E
M;B(*"B,Z('1E;7!L871E<R]W:&ET96QI<W0O=VAI=&5L:7-T+FEN8SHQ-@IM
M<V=I9"`B5VA?:71E;&ES="!A9&1R97-S97,Z(@IM<V=S='(@(DAV:71L:7-T
M971E(&%D<F5S<V5R.B(*"B,Z(&9I;'1E<G,N<&AP.C$U,"!T96UP;&%T97,O
M=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z.`IM<V=I9"`B5VAI=&5L:7-T(@IM
M<V=S='(@(DAV:71L:7-T970B"@HC.B!W:&ET96QI<W0N<&AP.C4U"B,L(&9U
M>GIY"FUS9VED(")7:&ET96QI<W0@161I="(*;7-G<W1R(")(=FET;&ES=&5T
M(@H*(SH@=VAI=&5L:7-T+G!H<#HQ.`HC+"!F=7IZ>0IM<V=I9"`B5VAI=&5L
M:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG
M(&1R:79E<BXB"FUS9W-T<B`B4W9A<G1E;&ES=&EN9R!E<B!I:VME('-T^'1T
M970@:2!D96YN92!F:6QT97(@9')I=F5R96XB"@HC.B!L:6(O4V-R:7!T+W!R
M;V-M86EL+G!H<#HR,S0@;&EB+U-C<FEP="]S:65V92YP:'`Z,CDW"B,Z(&QI
M8B]38W)I<'0O;6%I;&1R;W`N<&AP.C(P,@HC+"!F=7IZ>0IM<V=I9"`B5VAI
M=&5L:7-T960@061D<F5S<V5S(@IM<V=S='(@(E9E;&<@861R97-S96)K97(Z
M(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW.0HC+"!F=7IZ>0IM<V=I
M9"`B6"U0<FEO<FET>2(*;7-G<W1R(")0<FEO<FET970B"@HC.B!C;VYF:6<O
M9FEE;&1S+G!H<"YD:7-T.C8W"FUS9VED(")8+5-P86TM3&5V96PB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3
M<&%M+5-C;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I
M<W0Z-S4*;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9FEL
M=&5R<RYP:'`Z-3,@<G5L92YP:'`Z,30T"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!R
M=6QE<RXB"FUS9W-T<B`B(@H*(SH@9FEL=&5R<RYP:'`Z-#4@<G5L92YP:'`Z
M,C$*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&]R(&5D
M:70@8W5S=&]M(')U;&5S+B(*;7-G<W1R("(B"@HC.B!V86-A=&EO;BYP:'`Z
M,S`*;7-G:60@(B(*(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&5M
M86EL(&%D9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M97-S86=E<R`B
M"B)S:&]U;&0@8F4@86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-R
M:7!T+VEM87`N<&AP.C(W."!L:6(O4V-R:7!T+VEM87`N<&AP.C,P,2!L:6(O
M4V-R:7!T+VEM87`N<&AP.C,Q-0IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S
M='(@(EM);G1E="!E;6YE72(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O<G=A
M<F0N:6YC.C(T"FUS9VED(")?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN
M8SHR,PIM<V=I9"`B7T%D9')E<W-E<R!T;R!N;W0@<V5N9"!R97-P;VYS97,@
M=&\Z(@IM<V=S='(@(B(*"B,Z(&QI8B]);F=O+G!H<#HS,#4*;7-G:60@(E]"
M;&%C:VQI<W0B"FUS9W-T<B`B4W9A<G1E;&ES="!A=G-E;F1E<B(*"B,Z('1E
M;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHQ.`IM<V=I9"`B7T1E
M;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`B4VQE='0@;65L9&EN
M9R!H96QT(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC
M.C,Q"FUS9VED(")?16YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z
M(@IM<V=S='(@(E-K<FEV(&EN;B!H=F5R(&%D<F5S<V4@<.4@96X@;GD@;&EN
M:F4Z(@H*(SH@;&EB+TEN9V\N<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B7T9O
M<G=A<F0B"FUS9W-T<B`B5FED97)E<V5N9"(*"B,Z('1E;7!L871E<R]F;W)W
M87)D+V9O<G=A<F0N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")?2V5E<"!A(&-O
M<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A8V-O=6YT/R(*;7-G<W1R(")$970@
M97(@:6YG96X@;65L9&EN9V5R(&D@9&5N;F4@<&]S=&)O:W-E;BXB"@HC.B!T
M96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z,C(*;7-G:60@(E]-
M;W9E(&UE<W-A9V4@=&\@9F]L9&5R.B(*;7-G<W1R(")&;'ET="!M96QD:6YG
M('1I;"!M87!P93HB"@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN
M:6YC.C$S"B,L(&9U>GIY"FUS9VED(")?37D@96UA:6P@861D<F5S<V5S.B(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*%1U<F)A(#$N
M,BD@(",M(RTC+2,M(UQN(@HB12UP;W-T861R97-S95QN(@HB(RTC+2,M(RTC
M("!N8E].3RYP;R`H2W)O;F]L:71H(#$N,2D@(",M(RTC+2,M(UQN(@HB12UP
M;W-T(&%D<F5S<V4B"@HC.B!L:6(O26YG;RYP:'`Z,S$T"B,L(&9U>GIY"FUS
M9VED(")?4V-R:7!T(@IM<V=S='(@(D5M;F4B"@HC.B!L:6(O26YG;RYP:'`Z
M,S`X"B,L(&9U>GIY"FUS9VED(")?5F%C871I;VXB"FUS9W-T<B`B4&QA<W-E
M<FEN9R(*"B,Z(&QI8B]);F=O+G!H<#HS,#(*;7-G:60@(E]7:&ET96QI<W0B
M"FUS9W-T<B`B2'9I=&QI<W0@879S96YD97(B"@HC.B!T96UP;&%T97,O<G5L
M92]F:6QT97(N:6YC.C0*(RP@9G5Z>GD*;7-G:60@(F%N9"(*;7-G<W1R(")+
M86QE;F1E<B(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BYH=&UL.C$V
M"FUS9VED(")D:7-A8FQE9"`M(&-L:6-K('1O(&5N86)L92(*;7-G<W1R("(B
M"@HC.B!F:6QT97)S+G!H<#HQ.#`*(RP@9G5Z>GD*;7-G:60@(F9I96QD(@IM
M<V=S='(@(D9E;'0B"@HC.B!L:6(O4V-R:7!T+VUA:6QD<F]P+G!H<#HQ,C`*
M(RP@9G5Z>GD*;7-G:60@(FUA:6QD<F]P('-C<FEP="!G96YE<F%T960@8GD@
M26YG;R(*;7-G<W1R("));F=E;B!S8W)I<'0@9V5N97)E<G0B"@HC.B!F:6QT
M97)S+G!H<#HQ.#`*(RP@9G5Z>GD*;7-G:60@(FUA=&-H(@IM<V=S='(@(G1I
M;"(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z-`IM<V=I9"`B;W(B
M"FUS9W-T<B`B96QL97(B"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HQ
M,C@*(RP@9G5Z>GD*;7-G:60@(G!R;V-M86EL('-C<FEP="!G96YE<F%T960@
M8GD@26YG;R(*;7-G<W1R("));F=E;B!S8W)I<'0@9V5N97)E<G0B"@HC.B!L
M:6(O4V-R:7!T+W-I979E+G!H<#HQ,#D*;7-G:60@(G-I979E(&9I;'1E<B!G
M96YE<F%T960@8GD@26YG;R(*;7-G<W1R("(B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN
M9V\O<&\O<W9?4T4N<&\`````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-3,S-C$`,3`T,3<S-C(W-#<`,#$W,S8U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@26YG;R!3=V5D
M:7-H('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`T+3(P,#8@2&]R
M9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T
M:&4@<V%M92!L:6-E;G-E(&%S('1H92!);F=O('!A8VMA9V4N"B,@2F]A<75I
M;2!(;VUR:6=H875S96X@/&IO:&]`=V5B8G!L871S96XN<V4^+"`R,#`V+@HC
M($%N9')E87,@1&%H;.EN(#QA;F1R96%S0&1A:&QE;BYW<SXL(#(P,#4N"B,@
M06YD97)S($YO<G)B<FEN9R`\86YD97)S0&YO<G)B<FEN9RYB:7H^+"`R,#`T
M+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!)
M3D=/(#$N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$T(#$V
M.C(S*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,30@,38Z
M,S`K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!*;V%Q=6EM($AO;7)I9VAA
M=7-E;B`\:F]H;T!W96)B<&QA='-E;BYS93Y<;B(*(DQA;F=U86=E+51E86TZ
M(%-W961I<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A
M/2`Q*3M<;B(*"B,Z(&9I;'1E<G,N<&AP.C$Y,`IM<V=I9"`B(&%N9"(*;7-G
M<W1R("(@;V-H(@H*(SH@9FEL=&5R<RYP:'`Z,3DP"FUS9VED("(@;W(B"FUS
M9W-T<B`B(&5L;&5R(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C$W"FUS9VED(")!8W1I;VX@9F]R(&)L86-K;&ES=&5D(&%D9')E
M<W-E<SHB"FUS9W-T<B`BQ71GY')D(&;V<B!S<.1R<F%D92!A9')E<W-E<B(*
M"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$P"FUS9VED(")!
M8W1I=F%T92!38W)I<'0B"FUS9W-T<B`B06MT:79E<F$@<VMR:7!T(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M06-T:79A=&EN9R!T:&4@<V-R:7!T(&9O<B!<(B5S7"(@9F%I;&5D.B`H)60I
M("5S(@IM<V=S='(@(D1E="!G:6-K(&EN=&4@871T(&%K=&EV97)A('-K<FEP
M=&5T(&;V<B`G)7,G.B`H)60I("5S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<V5T=&EN9W,N:6YC.C8*;7-G:60@(D%D9&ET:6]N86P@4V5T=&EN9W,B"FUS
M9W-T<B`B671T97)L:6=A<F4@:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E
M<R]R=6QE+VAE861E<BYI;F,Z-#0*;7-G:60@(D%L;"!O9B!T:&4@9F]L;&]W
M:6YG(@IM<V=S='(@(D%L;&$@9O9L:F%N9&4B"@HC.B!L:6(O87!I+G!H<#HU
M-`IM<V=I9"`B06QL;W<@4G5L97,B"FUS9W-T<B`B5&EL;.5T(')E9VQE<B(*
M"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S,*;7-G:60@(D%N<W=E
M<F5D(@IM<V=S='(@(D)E<W9A<F%T(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A
M9&5R+FEN8SHT-0IM<V=I9"`B06YY(&]F('1H92!F;VQL;W=I;F<B"FUS9W-T
M<B`B3N5G;VX@878@9O9L:F%N9&4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F
M;V]T97(N:6YC.C<*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B5F5R
M:W-TY&QL(&9I;'1E<B(*"B,Z(&9I;'1E<G,N<&AP.C(Q.0IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES(')U;&4_(@IM<V=S
M='(@(L1R(&1U('/D:V5R(&%T="!D=2!V:6QL(')A9&5R82!A:W1U96QL(')E
M9V5L/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B075T
M;VUA=&EC86QL>2!U<&1A=&4@=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG
M93\B"FUS9W-T<B`B57!P9&%T97)A('-K<FEP=&5T(&5F=&5R('9A<FIE(.1N
M9')I;F<_(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HT-PIM<V=I9"`B
M0F-C(@IM<V=S='(@(D)C8R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-SD*;7-G
M:60@(D)E9VEN<R!W:71H(@IM<V=S='(@(D+V<FIA<B!M960B"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C$P-B!L:6(O1')I=F5R+VQD87`N<&AP.C$Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G
M<W1R(")":6YD(&UI<W-L>6-K861E<SH@*"5S*2`E<R(*"B,Z(&9I;'1E<G,N
M<&AP.C$T.2!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z-PHC
M.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C@W(&QI8B]";&]C:R]O=F5R=FEE
M=RYP:'`Z.3`*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R(")3<.1R<F%D92!A
M9')E<W-E<B(*"B,Z(&)L86-K;&ES="YP:'`Z,3`W"FUS9VED(")";&%C:VQI
M<W0@161I="(*;7-G<W1R("+$;F1R82!S<.1R<F%D92!A9')E<W-E<B(*"B,Z
M(&)L86-K;&ES="YP:'`Z,3<*;7-G:60@(D)L86-K;&ES="!I<R!N;W0@<W5P
M<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S
M='(@(E-PY')R;FEN9R!A=B!A9')E<W-E<B!S=/9D<R!I;G1E(&%V(&%K='5E
M;&P@9FEL=&5R9')I=G)U=&EN+B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN
M<&AP.C(P-R!L:6(O4V-R:7!T+W-I979E+G!H<#HR-#0*(SH@;&EB+U-C<FEP
M="]M86EL9')O<"YP:'`Z,3<V"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S
M97,B"FUS9W-T<B`B4W#D<G)A9&4@861R97-S97(B"@HC.B!C;VYF:6<O9FEE
M;&1S+G!H<"YD:7-T.C@X"FUS9VED(")";V1Y(@IM<V=S='(@(DUE9&1E;&%N
M9&5T97AT(@H*(SH@9FEL=&5R<RYP:'`Z,3@W(')U;&4N<&AP.C(X,0IM<V=I
M9"`B0V%S92!396YS:71I=F4B"FUS9W-T<B`B4VMI9G1LY&=E<VOD;G-L:6<B
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C0S"FUS9VED(")#8R(*;7-G
M<W1R(")#8R(*"B,Z(')U;&4N<&AP.C$R,B!W:&ET96QI<W0N<&AP.C,V(&9O
M<G=A<F0N<&AP.C,S('9A8V%T:6]N+G!H<#HT,0HC.B!B;&%C:VQI<W0N<&AP
M.C<S"FUS9VED(")#:&%N9V5S('-A=F5D+B(*;7-G<W1R("+$;F1R:6YG87(@
M<W!A<F%D92XB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<U"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QU<F4B"FUS9W-T<B`B1O9R8FEN9&5L<V4@=&EL;"!S
M97)V97(@;6ES<VQY8VMA9&5S(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,W-0IM
M<V=I9"`B0V]N=&%I;G,B"FUS9W-T<B`B26YN96CE;&QE<B(*"B,Z(&9I;'1E
M<G,N<&AP.C(S,"!F:6QT97)S+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]P>2`E<R(*;7-G<W1R(")+;W!I97)A("5S(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C@W-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&]F("5S(@IM
M<V=S='(@(DMO<&EA(&%V("5S(@H*(SH@;&EB+TEN9V\N<&AP.C8R"FUS9VED
M(")#<F5A=&4@;F5W(&9O;&1E<B(*;7-G<W1R(")3:V%P82!N>2!M87!P(@H*
M(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,S,V(&QI8B]38W)I<'0O;6%I
M;&1R;W`N<&AP.C(X,`IM<V=I9"`B1$E304),140Z("(*;7-G<W1R(")!5E-4
MQ$Y'1#H@(@H*(SH@=&5M<&QA=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,3<*
M;7-G:60@(D1E86-T:79A=&4@4V-R:7!T(@IM<V=S='(@(D%V86MT:79E<F$@
M<VMR:7!T(@H*(SH@9FEL=&5R<RYP:'`Z,C$Y(&9I;'1E<G,N<&AP.C(R,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,B"FUS9W-T<B`B4F%D97)A
M("5S(@H*(SH@=&5M<&QA=&5S+W)U;&4O9FEL=&5R+FEN8SHS,`IM<V=I9"`B
M1&5L971E($-O;F1I=&EO;B(*;7-G<W1R(")2861E<F$@=FEL;&MO<B(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HS,C,*;7-G:60@(D1E;&5T92!M97-S86=E(&-O
M;7!L971E;'DB"FUS9W-T<B`B4F%D97)A(&UE9&1E;&%N9&4@:&5L="(*"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S4*;7-G:60@(D1E;&5T960B
M"FUS9W-T<B`B4F%D97)A9"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,3$*;7-G
M:60@(D1E;&EV97(@:6YT;R!M>2!);F)O>"(*;7-G<W1R("),979E<F5R82!T
M:6QL(&UI;B!I;FMO<F<B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S,W"FUS9VED
M(")$96QI=F5R(&EN=&\@;7D@26YB;W@@86YD(&-O<'D@=&\B"FUS9W-T<B`B
M3&5V97)E<F$@=&EL;"!M:6X@:6YK;W)G(&]C:"!K;W!I97)A('1I;&PB"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S,R"FUS9VED(")$96QI=F5R(&EN=&\@;7D@
M26YB;W@@86YD(')E9&ER96-T('1O(@IM<V=S='(@(DQE=F5R97)A('1I;&P@
M;6EN(&EN:V]R9R!O8V@@;VUD:7)I9V5R82!T:6QL(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,Q-PIM<V=I9"`B1&5L:79E<B!T;R!F;VQD97(B"FUS9W-T<B`B
M3&5V97)E<F$@=&EL;"!M87!P(@H*(SH@9FEL=&5R<RYP:'`Z,C0S(&9I;'1E
M<G,N<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$:7-A8FQE("5S(@IM
M<V=S='(@(D%V86MT:79E<F$@)7,B"@HC.B!T96UP;&%T97,O=VAI=&5L:7-T
M+W=H:71E;&ES="YI;F,Z,3`@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C$P"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z
M-B!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHQ,`HC.B!T96UP;&%T
M97,O<G5L92]H96%D97(N:6YC.C(V"FUS9VED(")$:7-A8FQE9"(*;7-G<W1R
M(")!=F%K=&EV97)A9"(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S
M+FEN8SHQ,PIM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!N;W1I9FEC871I;VX@
M=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/R(*;7-G<W1R(")6:7-A(&1E
M=&%L:F5R860@;F]T:69I97)I;F<@9O9R('9A<FIE(&9I;'1E<B!NY'(@9&5T
M(&OV<G,_(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHS
M-`IM<V=I9"`B1&\@7VYO="!S96YD(')E<W!O;G-E<R!T;R!B=6QK(&]R(&QI
M<W0@;65S<V%G97,B"FUS9W-T<B`B4VMI8VMA(%]I;F=A('-V87(@<.4@;&ES
M="T@;V-H(&)U;&MM961D96QA;F1E;B(*"B,Z('1E;7!L871E<R]R=6QE+V9O
M;W1E<BYI;F,Z,3`*;7-G:60@(D1O('1H:7,Z(@IM<V=S='(@(D?V<B!D971T
M83HB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@P"FUS9VED(")$;V5S;B=T(&)E
M9VEN('=I=&@B"FUS9W-T<B`B26YT92!B]G)J87(@;65D(@H*(SH@;&EB+U-T
M;W)A9V4N<&AP.C,W-@IM<V=I9"`B1&]E<VXG="!C;VYT86EN(@IM<V=S='(@
M(DEN=&4@:6YN96CE;&QE<B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#(*;7-G
M:60@(D1O97-N)W0@96YD('=I=&@B"FUS9W-T<B`B26YT92!S;'5T87(@;65D
M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X-`IM<V=I9"`B1&]E<VXG="!E>&ES
M="(*;7-G<W1R(")&:6YN<R!I;G1E(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,X
M-PIM<V=I9"`B1&]E<VXG="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I(@IM
M<V=S='(@(DUA=&-H87(@:6YT92(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE
M861E<BYI;F,Z,C8@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HV,0HC.B!L:6(O
M0FQO8VLO;W9E<G9I97<N<&AP.C8X(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z
M.#$*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HX.0IM<V=I9"`B161I="(*
M;7-G<W1R("+$;F1R82(*"B,Z(&9I;'1E<G,N<&AP.C(P."!F:6QT97)S+G!H
M<#HR,3`@9FEL=&5R<RYP:'`Z,C$T(&9I;'1E<G,N<&AP.C(Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@(L1N9')A("5S(@H*(SH@
M9FEL=&5R<RYP:'`Z,C0W(&9I;'1E<G,N<&AP.C(T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%;F%B;&4@)7,B"FUS9W-T<B`B06MT:79E<F$@)7,B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(X"FUS9VED(")%;F%B;&5D
M(@IM<V=S='(@(D%K=&EV97)A9"(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#$*
M;7-G:60@(D5N9',@=VET:"(*;7-G<W1R(")3;'5T87(@;65D(@H*(SH@;&EB
M+U-T;W)A9V4N<&AP.C,Y,@IM<V=I9"`B17%U86P@=&\B"FUS9W-T<B`B3&EK
M82!M960B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$S.2!L:6(O1')I=F5R
M+VQD87`N<&AP.C$T.2!L:6(O1')I=F5R+VQD87`N<&AP.C$U.`HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!R971R:65V:6YG(&-U<G)E;G0@<V-R:7!T.B`H)60I("5S(@IM<V=S='(@
M(DMA;B!I;G1E(&CD;71A(&%K='5E;&QT('-K<FEP=#H@*"5D*2`E<R(*"B,Z
M(&)L86-K;&ES="YP:'`Z-S$*;7-G:60@(D5R<F]R('-A=FEN9R!C:&%N9V5S
M+B(*;7-G<W1R(")$970@9VEC:R!I;G1E(&%T="!S<&%R82#D;F1R:6YG87)N
M82XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N:6YC.C(R"FUS9VED
M(")%>&ES=&EN9R!2=6QE<R(*;7-G<W1R(")"969I;G1L:6=A(')E9VQE<B(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HS.#,*;7-G:60@(D5X:7-T<R(*;7-G<W1R
M(")&:6YN<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5X<&5C=&5D(#$@;V)J96-T+"!G;W0@)60N(@IM<V=S
M='(@(D9I8VL@,2!O8FIE:W0L(&9I8VL@)60N(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<V5T=&EN9W,N:6YC.C(P"FUS9VED(")&:6QT97(@06QL($UE<W-A
M9V5S(@IM<V=S='(@(D9I;'1R97)A(&%L;&$@;65D9&5L86YD96XB"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,C(*;7-G:60@(D9I;'1E
M<B!/;FQY(%-E96X@365S<V%G97,B"FUS9W-T<B`B1FEL=')E<F$@96YB87)T
M(&SD<W1A(&UE9&1E;&%N9&5N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T
M=&EN9W,N:6YC.C(Q"FUS9VED(")&:6QT97(@3VYL>2!5;G-E96X@365S<V%G
M97,B"FUS9W-T<B`B1FEL=')E<F$@96YB87)T(&]LY'-T82!M961D96QA;F1E
M;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHQ.`IM<V=I
M9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B1FEL=&5R:6YS=.1L;&YI;F=A
M<B(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z,C4*;7-G:60@(D9I
M;'1E<B!2=6QE(@IM<V=S='(@(D9I;'1E<G)E9V5L(@H*(SH@9FEL=&5R<RYP
M:'`Z,3$S"FUS9VED(")&:6QT97(@4G5L97,B"FUS9W-T<B`B1FEL=&5R<F5G
M;&5R(@H*(SH@<V-R:7!T+G!H<#HU,@IM<V=I9"`B1FEL=&5R(%-C<FEP="!$
M:7-P;&%Y(@IM<V=S='(@(E-C<FEP=&9I;'1E<FEN<W3D;&QN:6YG87(B"@HC
M.B!L:6(O26YG;RYP:'`Z,S(R"FUS9VED(")&:6QT97(@7U)U;&5S(@IM<V=S
M='(@(D9I;'1E<E]R96=L97(B"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE
M<W-A9V4H<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L9&5R(%PB)7-<
M(BXB"FUS9W-T<B`B1FEL=&5R86MT:79I=&5T.B`E<R!M961D96QA;F1E*&XI
M(&AA<B!F;'ET=&%T<R!T:6QL(&UA<'!E;B`G)7,G+B(*"B,Z(&QI8B]38W)I
M<'0O:6UA<"YP:'`Z,S`Q"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A
M8W1I=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B1FEL=&5R86MT:79I=&5T.B`E<R!M961D96QA;F1E*&XI(&AA<B!R
M861E<F%T<RXB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C(W.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@
M:&%V92!B965N(&UO=F5D('1O('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M(")&:6QT97)A:W1I=FET970Z("5S(&UE9&1E;&%N9&4H;BD@:&%R(&9L>71T
M871S('1I;&P@;6%P<&5N("<E<R<N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H
M<#HQ.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B`E
M<R!M97-S86=E*',I('1H870@;6%T8VAE9"!T:&4@8FQA8VML:7-T('=E<F4@
M9&5L971E9"XB"FUS9W-T<B`B(@HB1FEL=&5R86MT:79I=&5T.B`E<R!M961D
M96QA;F1E*&XI('-O;2!M;W1S=F%R87(@<W#D<G)L:7-T86X@:&%R(')A9&5R
M871S+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S$Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D9I;'1E<B!A8W1I=FET>3H@5&AE(&UE<W-A9V4@7"(E
M<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&-O<&EE9"!T;R!T:&4@(@HB9F]L
M9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@HB1FEL=&5R86MT:79I=&5T.B!-961D
M96QA;F1E="`G)7,G(&9RY6X@)R5S)R!H87(@:V]P:65R871S('1I;&P@;6%P
M<&5N("<E<R<N(@H*(SH@;&EB+U-C<FEP="]I;6%P+G!H<#HR.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<
M(B5S7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M1FEL=&5R86MT:79I=&5T.B!-961D96QA;F1E="`G)7,G("!F<N5N("<E<R<@
M:&%R(')A9&5R871S+B(*"B,Z(&QI8B]38W)I<'0O:6UA<"YP:'`Z,C<S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D9I;'1E<B!A8W1I=FET>3H@5&AE(&UE
M<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&UO=F5D('1O('1H
M92!F;VQD97(@(@HB7"(E<UPB+B(*;7-G<W1R("(B"B)&:6QT97)A:W1I=FET
M970Z($UE9&1E;&%N9&5T("<E<R<@9G+E;B`G)7,G(&AA<B!F;'ET=&%T<R!T
M:6QL(&UA<'!E;B`G)7,G+B(*"B,Z(')U;&4N<&AP.C$V,`IM<V=I9"`B1FEL
M=&5R(&YO="!F;W5N9"XB"FUS9W-T<B`B1FEL=&5R('-A:VYA<RXB"@HC.B!T
M96UP;&%T97,O<G5L92]H96%D97(N:6YC.C0R"FUS9VED(")&;W(@86X@:6YC
M;VUI;F<@;65S<V%G92!T:&%T(&UA=&-H97,Z(@IM<V=S='(@(D;V<B!I;FMO
M;6UA;F1E(&UE9&1E;&%N9&5N('-O;2!M871C:&%R.B(*"B,Z(&9I;'1E<G,N
M<&AP.C$V-R!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHX(&QI8B]"
M;&]C:R]O=F5R=FEE=RYP:'`Z-C<*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H
M<#HV.0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")6:61A<F)E9F]R9')A(@H*
M(SH@9F]R=V%R9"YP:'`Z,38*;7-G:60@(D9O<G=A<F0@:7,@;F]T('-U<'!O
M<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R
M(")6:61A<F)O<F1R86X@<W3V9',@:6YT92!A=B!A:W1U96QL(&9I;'1E<F1R
M:79R=71I;BXB"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HR.#(@;&EB
M+U-C<FEP="]S:65V92YP:'`Z,C$T"B,Z(&QI8B]38W)I<'0O;6%I;&1R;W`N
M<&AP.C(R-0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5FED87)B969O<F1R
M87(B"@HC.B!F;W)W87)D+G!H<#HT-0IM<V=I9"`B1F]R=V%R9',@161I="(*
M;7-G<W1R("+$;F1R82!V:61A<F)E9F]R9')A;B(*"B,Z(&-O;F9I9R]F:65L
M9',N<&AP+F1I<W0Z,SD*;7-G:60@(D9R;VTB"FUS9W-T<B`B1G+E;B(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(P-C(*;7-G:60@(D9R;VTZ(@IM<V=S
M='(@(D9RY6XZ(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Y,`IM<V=I9"`B1W)E
M871E<B!T:&%N(@IM<V=S='(@(E-T]G)R92#D;B(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS.3$*;7-G:60@(D=R96%T97(@=&AA;B!O<B!E<75A;"!T;R(*;7-G
M<W1R(")3=/9R<F4@Y&X@96QL97(@;&EK82!M960B"@HC.B!T96UP;&%T97,O
M<G5L92]F;V]T97(N:6YC.C,Q"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`B
M5FEK=&EG="(*"B,Z(')U;&4N<&AP.C,V"FUS9VED("));F1I=FED=6%L(')U
M;&5S(&%R92!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R96YT(&9I;'1E<FEN
M9R!D<FEV97(N(@IM<V=S='(@(E!E<G-O;FQI9V$@<F5G;&5R('-T]F1S(&EN
M=&4@878@86MT=65L;"!F:6QT<F5R:6YG<W)U=&EN+B(*"B,Z(&QI8B]38W)I
M<'0O<VEE=F4N<&AP.C$X-C`*;7-G:60@(DEN97AI<W1A;G0@;6%I;&)O>"!S
M<&5C:69I960@9F]R(&UE<W-A9V4@9&5L:79E<GDN(@IM<V=S='(@(D%N9VEV
M96X@;6%P<"!F]G(@92U0;W-T(&QE=F5R86YS('-A:VYA<RXB"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z,S<W"FUS9VED("))<R(*;7-G<W1R("+$<B(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HS-S@*;7-G:60@(DES;B=T(@IM<V=S='(@(L1R(&EN
M=&4B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(S"FUS9VED("(B"B),1$%0
M('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N
M;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(@IM<V=S='(@(DQ$05`M<W3V
M9"!K<N1V<RP@;65N($Q$05`M;6]D=6QE;B#D<B!I;G1E('1I;&QGY&YG;&EG
M(&5L;&5R(&QA9&1A9"XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S@X"FUS9VED
M("),97-S('1H86XB"FUS9W-T<B`B36EN9')E(.1N(@H*(SH@;&EB+U-T;W)A
M9V4N<&AP.C,X.0IM<V=I9"`B3&5S<R!T:&%N(&]R(&5Q=6%L('1O(@IM<V=S
M='(@(DUI;F1R92#D;B!E;&QE<B!L:6MA(&UE9"(*"B,Z(&-O;F9I9R]F:65L
M9',N<&AP+F1I<W0Z-3D*;7-G:60@(DQI<W0M240B"FUS9W-T<B`B3&ES="U)
M1"(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,`IM
M<V=I9"`B36%R7VL@;65S<V%G92!A<R!D96QE=&5D(@IM<V=S='(@(DUA<E]K
M97)A(&UE9&1E;&%N9&4@<V]M(')A9&5R870B"@HC.B!T96UP;&%T97,O<G5L
M92]F;V]T97(N:6YC.C(T"FUS9VED(")-87)K(&UE<W-A9V4@87,Z(@IM<V=S
M='(@(DUA<FME<F$@;65D9&5L86YD92!S;VTZ(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,X-@IM<V=I9"`B36%T8VAE<R`H=VET:"!P;&%C96AO;&1E<G,I(@IM
M<V=S='(@(DUA=&-H87(B"@HC.B!L:6(O87!I+G!H<#HU-PIM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@4G5L97,B"FUS9W-T<B`B36%X(&%N=&%L(')E9VQE
M<B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@8FQA8VML:7-T960@861D<F5S<V5S
M(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S97,Z("5S+"`B"B)-87AI;75M(&%D
M9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O
M(&)L86-K;&ES="XB"FUS9W-T<B`B(@HB36%X:6UA;'0@86YT86P@<W#D<G)A
M9&4@861R97-S97(@Y'(@]G9E<G-K<FED96X@*%1O=&%L=#H@)7,L($UA>&EM
M86QT.B`E<RDN("(*(DMA;B!I;G1E(&SD9V=A('1I;&P@861R97-S96X@:2!L
M:7-T86X@;65D('-PY')R861E(&%D<F5S<V5R+B(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HU-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X:6UU;2!N=6UB
M97(@;V8@=VAI=&5L:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A
M9&1R97-S97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U
M;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O('=H:71E;&ES="XB"FUS9W-T
M<B`B(@HB36%X:6UA;'0@86YT86P@8F5T<F]D9&$@861R97-S97(@Y'(@]G9E
M<G-K<FED96X@*%1O=&%L=#H@)7,L($UA>&EM86QT.B`E<RDN("(*(DMA;B!I
M;G1E(&SD9V=A('1I;&P@861R97-S96X@;&ES=&%N(/9V97(@8F5T<F]D9&$@
M861R97-S97(N(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`W,`IM<V=I
M9"`B36ES<VEN9R!A9&1R97-S('1O(&YO=&EF>2(*;7-G<W1R(")!9')E<W,@
M871T('-K:6-K82!N;W1I9FEE<FEN9V%R('1I;&P@<V%K;F%S(@H*(SH@;&EB
M+U-C<FEP="]S:65V92YP:'`Z,3<R.`IM<V=I9"`B36ES<VEN9R!A9&1R97-S
M('1O(')E9&ER96-T(&UE<W-A9V4@=&\B"FUS9W-T<B`B061R97-S(&%T="!S
M:VEC:V$@=FED87)E('1I;&P@<V%K;F%S(@H*(SH@;&EB+U-C<FEP="]S:65V
M92YP:'`Z,3<V,`IM<V=I9"`B36ES<VEN9R!R96%S;VX@9F]R(')E:F5C="(*
M;7-G<W1R(")!;FQE9&YI;F<@=&EL;"!A='0@9O9R:V%S=&$@<V%K;F%S(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3DR-PIM<V=I9"`B36ES<VEN9R!R
M96%S;VX@:6X@=F%C871I;VXN(@IM<V=S='(@(E-E;65S=&5R;F]T97)I;F<@
M<V%K;F%S+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VAE861E<BYI;F,Z,CD*
M;7-G:60@(DUO=F4B"FUS9W-T<B`B1FQY='1A(@H*(SH@9FEL=&5R<RYP:'`Z
M,3,Q(&9I;'1E<G,N<&AP.C(T,`IM<V=I9"`B36]V92!2=6QE($1O=VXB"FUS
M9W-T<B`B1FQY='1A(&YE<B!R96=E;"(*"B,Z(&9I;'1E<G,N<&AP.C$S,B!F
M:6QT97)S+G!H<#HR,SD*;7-G:60@(DUO=F4@4G5L92!5<"(*;7-G<W1R(")&
M;'ET=&$@=7!P(')E9V5L(@H*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T
M:6]N+FEN8SHT,@IM<V=I9"`B3E]U;6)E<B!O9B!D87ES(&)E='=E96X@=F%C
M871I;VX@<F5P;&EE<SHB"FUS9W-T<B`B7T%N=&%L(&1A9V%R(&UE;&QA;B!S
M96UE<W1E<G-V87(Z(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+6YO
M;F4N:6YC.C,@=&5M<&QA=&5S+V9I;'1E<G,O9F]O=&5R+FEN8SHU"B,Z(&QI
M8B]3=&]R86=E+G!H<#HW-S$*;7-G:60@(DYE=R!2=6QE(@IM<V=S='(@(DYY
M(')E9V5L(@H*(SH@;&EB+TEN9V\N<&AP.C(Q-B!L:6(O26YG;RYP:'`Z,C$X
M"B,L('!H<"UF;W)M870*;7-G:60@(DYO(%PB)7-<(B!E;&5M96YT(&9O=6YD
M(&EN(&)A8VME;F0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B26YG970@)R5S
M)RUO8FIE:W0@9FEN;G,@:2`G8F%C:V5N9"<M:V]N9FEG=7)A=&EO;F5N(@H*
M(SH@;&EB+TEN9V\N<&AP.C(Q-`IM<V=I9"`B3F\@8F%C:V5N9"!C;VYF:6=U
M<F5D(&9O<B!T:&ES(&AO<W0B"FUS9W-T<B`B26YG96X@)V)A8VME;F0G(&MO
M;F9I9W5R97)A9&4@9O9R(&1E;FYA(';D<F0B"@HC.B!L:6(O26YG;RYP:'`Z
M,3DQ"FUS9VED(").;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S
M+G!H<"(*;7-G<W1R("));F=A("=B86-K96YD<R<@:V]N9FEG=7)E<F%D92(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHS"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO(&9I;'1E<G,N($-L:6-K(%PB)7-<(B!T;R!C
M<F5A=&4@82!N97<@9FEL=&5R+B(*;7-G<W1R(")&:6QT97(@<V%K;F%S+B!+
M;&EC:V$@<.4@)R5S)R!F]G(@871T('-K87!A(&5T="!N>71T+B(*"B,Z(&QI
M8B]38W)I<'0O<VEE=F4N<&AP.C$S,S(@;&EB+U-C<FEP="]S:65V92YP:'`Z
M,30R-0HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ-3DY"FUS9VED(").;R!H
M96%D97)S('-P96-I9FEE9"(*;7-G<W1R("));G1E(')U8G)I:V5R('-P96-I
M9FEC97)A9&4B"@HC.B!S8W)I<'0N<&AP.C8W"FUS9VED(").;R!S8W)I<'0@
M9V5N97)A=&5D+B(*;7-G<W1R(")3:W)I<'1E="!S:V%P861E<R!I;G1E(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,38Q-`IM<V=I9"`B3F\@<W1R:6YG
M<R!S<&5C:69I960B"FUS9W-T<B`B26YG82!S='+D;F=A<B!S<&5C:69I8V5R
M861E(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Y,PIM<V=I9"`B3F]T(&5Q=6%L
M('1O(@IM<V=S='(@(DEN=&4@;&EK82!M960B"@HC.B!L:6(O4W1O<F%G92YP
M:'`Z,S4S"FUS9VED(").;W1I9GD@96UA:6P@861D<F5S<R(*;7-G<W1R(")%
M+7!O<W1A9')E<W,@9O9R(&YO=&EF:65R:6YG87(B"@HC.B!L:6(O4W1O<F%G
M92YP:'`Z,S0W"FUS9VED(")/;FQY(&9L86<@=&AE(&UE<W-A9V4B"FUS9W-T
M<B`B1FQA9V=A(&5N9&%S="!M961D96QA;F1E="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.0IM<V=I9"`B3W!T:6]N<R!A8F]U="!S8W)I<'0@=7!D
M871I;F<N(@IM<V=S='(@(D%L=&5R;F%T:78@;VT@=7!P9&%T97)I;F<@878@
M<VMR:7!T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")/
M=&AE<B!/<'1I;VYS(@IM<V=S='(@(D%N9')A(&EN<W3D;&QN:6YG87(B"@HC
M.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C,*;7-G:60@(D]V97)V:65W(@IM
M<V=S='(@(M9V97)S:6MT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;F5W
M7V9O;&1E<BYJ<SHV"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@
M=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(D%N9V4@;F%M;B!PY2!N>2!M87!P
M.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z-C`*;7-G
M:60@(E)?96%S;VXB"FUS9W-T<B`B7T]R<V%K(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HV,PIM<V=I9"`B4F5C96EV960B"FUS9W-T<B`B36]T=&%G
M970B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S(X"FUS9VED(")2961I<F5C="!T
M;R(*;7-G<W1R(")%9G1E<G/D;F0@=&EL;"(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS.#4*;7-G:60@(E)E9W5L87(@97AP<F5S<VEO;B(*;7-G<W1R(")296=U
M;&KD<F$@=71T<GEC:R(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-#,*;7-G:60@
M(E)E:F5C="!W:71H(')E87-O;B(*;7-G<W1R(")&]G)K87-T82!M960@;W)S
M86ME;B(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-34*;7-G:60@(E)E
M<V5N="!4;R(*;7-G<W1R("+%=&5R<^1N="!T:6QL(@H*(SH@8V]N9FEG+V9I
M96QD<RYP:'`N9&ES=#HU,0IM<V=I9"`B4F5S96YT+69R;VTB"FUS9W-T<B`B
MQ71E<G/D;G0@9G+E;B(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z
M-C`*;7-G:60@(E)E='5R;B!T;R!&:6QT97)S($QI<W0B"FUS9W-T<B`BQ71E
M<G;D;G0@=&EL;"!F:6QT97)L:7-T82(*"B,Z('1E;7!L871E<R]W:&ET96QI
M<W0O=VAI=&5L:7-T+FEN8SHR-"!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K
M;&ES="YI;F,Z-#$*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN
M8SHW,2!T96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHS-`IM<V=I9"`B
M4F5T=7)N('1O(%)U;&5S($QI<W0B"FUS9W-T<B`BQ71E<G;D;F0@=&EL;"!R
M96=E;&QI<W1A(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHR
M-PIM<V=I9"`B4G5L92(*;7-G<W1R(")296=E;"(*"B,Z(&9I;'1E<G,N<&AP
M.C8S"FUS9VED(")2=6QE($-O<&EE9"(*;7-G<W1R(")296=E;"!K;W!I97)A
M9"(*"B,Z(&9I;'1E<G,N<&AP.C0R"FUS9VED(")2=6QE($1E;&5T960B"FUS
M9W-T<B`B4F5G96P@<F%D97)A9"(*"B,Z(&9I;'1E<G,N<&AP.C<Y"FUS9VED
M(")2=6QE($1I<V%B;&5D(@IM<V=S='(@(E)E9V5L(&%V86MT:79E<F%D(@H*
M(SH@9FEL=&5R<RYP:'`Z.#0*;7-G:60@(E)U;&4@16YA8FQE9"(*;7-G<W1R
M(")296=E;"!A:W1I=F5R860B"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N
M:6YC.C,S"FUS9VED(")2=6QE($YA;64B"FUS9W-T<B`B4F5G96QN86UN(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V-`IM<V=I9"`B4G5L93HB"FUS
M9W-T<B`B4F5G96PZ(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HX.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")35$%25%1,4R!F86EL960Z("@E<RD@)7,B"FUS
M9W-T<B`B4U1!4E143%,@;6ES<VQY8VMA9&5S.B`H)7,I("5S(@H*(SH@=&5M
M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C(S('1E;7!L871E<R]B
M;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT,`HC.B!T96UP;&%T97,O=F%C871I
M;VXO=F%C871I;VXN:6YC.C<P('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N
M:6YC.C,S"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-3D*;7-G:60@
M(E-A=F4B"FUS9W-T<B`B4W!A<F$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S
M971T:6YG<RYI;F,Z,CD*;7-G:60@(E-A=F4@4V5T=&EN9W,B"FUS9W-T<B`B
M4W!A<F$@:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E<R]S8W)I<'0O:&5A
M9&5R+FEN8SHR"FUS9VED(")38W)I<'0B"FUS9W-T<B`B4VMR:7!T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")38W)I<'0@57!D871I
M;F<B"FUS9W-T<B`B57!P9&%T97)A<B!S:W)I<'0B"@HC.B!L:6(O26YG;RYP
M:'`Z,C,Y"FUS9VED(")38W)I<'0@;F]T('5P9&%T960N(@IM<V=S='(@(E-K
M<FEP=&5T('5P<&1A=&5R861E<R!I;G1E(@H*(SH@;&EB+TEN9V\N<&AP.C$T
M,0IM<V=I9"`B4V-R:7!T('-U8V-E<W-F=6QL>2!A8W1I=F%T960N(@IM<V=S
M='(@(E-K<FEP=&5T(&%K=&EV97)A="(*"B,Z(&QI8B]);F=O+G!H<#HQ-#`*
M;7-G:60@(E-C<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S
M='(@(E-K<FEP=&5T(&%V86MT:79E<F%T(@H*(SH@=&5M<&QA=&5S+W)U;&4O
M9F]O=&5R+FEN8SHR.0IM<V=I9"`B4V5E;B(*;7-G<W1R(")3961D(@H*(SH@
M<G5L92YP:'`Z,3DP"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R(")6
MY&QJ(&5T="!FY&QT(@H*(SH@;&EB+TEN9V\N<&AP.C4Y"FUS9VED(")396QE
M8W0@=&%R9V5T(&9O;&1E<B(*;7-G<W1R(")6Y&QJ(&WE;&UA<'`B"@HC.B!R
M=6QE+G!H<#HR,C<*;7-G:60@(E-E;&8M1&5F:6YE9"!(96%D97(B"FUS9W-T
M<B`B16=E;F1E9FEN:65R861E(')U8G)I:V5R(@H*(SH@8V]N9FEG+V9I96QD
M<RYP:'`N9&ES=#HS-0IM<V=I9"`B4V5N9&5R(@IM<V=S='(@(D%V<^1N9&%R
M92(*"B,Z(&9I;'1E<G,N<&AP.CDX"FUS9VED(")3971T:6YG<R!S=6-C97-S
M9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B26YS=.1L;&YI;F=A<B!U<'!D871E
M<F%D92XB"@HC.B!T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8SHR-`IM
M<V=I9"`B4VAO=R!!8W1I=F4@4V-R:7!T(@IM<V=S='(@(E9I<V$@86MT:79A
M('-K<FEP="(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C,Q
M"FUS9VED(")3:&]W($-U<G)E;G0@4V-R:7!T(@IM<V=S='(@(E9I<V$@86MT
M=65L;'0@<VMR:7!T(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HX,PIM
M<V=I9"`B4VEZ92(*;7-G<W1R(")3=&]R;&5K(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O9F]O=&5R+FEN8SHT.0IM<V=I9"`B4W1O<"!C:&5C:VEN9R!I9B!T:&ES
M(')U;&4@;6%T8VAE<S\B"FUS9W-T<B`B4VQU=&$@:V]N=')O;&QE<F$@;VT@
M9&5N;F$@<F5G96P@;6%T8VAA<C\B"@HC.B!T96UP;&%T97,O=F%C871I;VXO
M=F%C871I;VXN:6YC.C4Q"FUS9VED(")3=6)J95]C="!O9B!V86-A=&EO;B!M
M97-S86=E.B(*;7-G<W1R("+$7VUN92!F]G(@<W9A<G-M961D96QA;F1E.B(*
M"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,S$*;7-G:60@(E-U8FIE8W0B
M"FUS9W-T<B`BQ')E;F1E(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,C`V
M,PIM<V=I9"`B4W5B:F5C=#HB"FUS9W-T<B`BQ')E;F1E.B(*"B,Z(&QI8B]A
M<&DN<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(%PB
M)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&)L86-K;&ES="XB"FUS9W-T
M<B`B061R97-S96X@)R5S)R!H87(@;&%G=',@=&EL;"!I(&1I;B!S<.1R<FQI
M<W1A+B(*"B,Z(&QI8B]A<&DN<&AP.C$P-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@861D<F5S<R!<(B5S7"(@:&%S(&)E96X@861D960@=&\@>6]U<B!W
M:&ET96QI<W0N(@IM<V=S='(@(D%D<F5S<V5N("<E<R<@:&%R(&QA9W1S('1I
M;&P@:2!D:6X@;&ES=&$@]G9E<B!B971R;V1D82XB"@HC.B!L:6(O26YG;RYP
M:'`Z,3,V"FUS9VED(")4:&4@9')I=F5R('-A:60Z("(*;7-G<W1R(")$<FEV
M<G5T:6YE;B!S=F%R861E.B`B"@HC.B!L:6(O26YG;RYP:'`Z,3,U"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*
M;7-G<W1R(")&96P@=FED(&%K=&EV97)I;F<@878@<VMR:7!T970N(@H*(SH@
M;&EB+TEN9V\N<&AP.C$S-`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M86-T:79A=&EN9R!T:&4@<V-R:7!T+B(*;7-G<W1R(")&96P@=FED(&%V86MT
M:79E<FEN9R!A=B!S:W)I<'1E="XB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD
M:7-T.C(W"FUS9VED(")4;R(*;7-G<W1R(")4:6QL(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O9FEL=&5R+FAT;6PZ,C$*;7-G:60@(E1O.B(*;7-G<W1R(")4
M:6QL.B(*"B,Z(&QI8B]38W)I<'0N<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS
M9W-T<B`B2V%N(&EN=&4@;&%D9&$@9&5F:6YI=&EO;F5N(&%V("5S+B(*"B,Z
M(&9I;'1E<G,N<&AP.C$V,2!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN
M:6YC.C4*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C8R(&QI8B]38W)I
M<'0O<VEE=F4N<&AP.C,U,@HC.B!L:6(O0FQO8VLO;W9E<G9I97<N<&AP.C8P
M(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z-C(*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(E-E;65S=&5R(@H*(SH@=F%C871I;VXN<&AP.C<Q"FUS9VED(")6
M86-A=&EO;B!%9&ET(@IM<V=S='(@(L1N9')A('-E;65S=&5R(@H*(SH@=F%C
M871I;VXN<&AP.C$V"FUS9VED(")686-A=&EO;B!I<R!N;W0@<W5P<&]R=&5D
M(&EN('1H92!C=7)R96YT(&9I;'1E<FEN9R!D<FEV97(N(@IM<V=S='(@(E-E
M;65S=&5R('-T]F1S(&EN=&4@878@86MT=65L;"!F:6QT97)D<FEV<G5T:6XN
M(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C$V"FUS
M9VED(")7:%]I=&5L:7-T(&%D9')E<W-E<SHB"FUS9W-T<B`B7T)E=')O9&1A
M(&%D<F5S<V5R.B(*"B,Z(&9I;'1E<G,N<&AP.C$U-2!T96UP;&%T97,O=VAI
M=&5L:7-T+W=H:71E;&ES="YI;F,Z.`HC.B!L:6(O0FQO8VLO;W9E<G9I97<N
M<&AP.C<Y(&QI8B]";&]C:R]O=F5R=FEE=RYP:'`Z.#(*;7-G:60@(E=H:71E
M;&ES="(*;7-G<W1R(")"971R;V1D82!A9')E<W-E<B(*"B,Z('=H:71E;&ES
M="YP:'`Z-34*;7-G:60@(E=H:71E;&ES="!%9&ET(@IM<V=S='(@(L1N9')A
M(&)E=')O9&1A(@H*(SH@=VAI=&5L:7-T+G!H<#HQ.`IM<V=I9"`B5VAI=&5L
M:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG
M(&1R:79E<BXB"FUS9W-T<B`B)T)E=')O9&1A(&%D<F5S<V5R)R!S=/9D<R!I
M;G1E(&%V(&%K='5E;&P@9FEL=&5R9')I=G)U=&EN+B(*"B,Z(&QI8B]38W)I
M<'0O<')O8VUA:6PN<&AP.C(S-"!L:6(O4V-R:7!T+W-I979E+G!H<#HR.3@*
M(SH@;&EB+U-C<FEP="]M86EL9')O<"YP:'`Z,C`S"FUS9VED(")7:&ET96QI
M<W1E9"!!9&1R97-S97,B"FUS9W-T<B`B0F5T<F]D9&$@861R97-S97(B"@HC
M.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C<Y"FUS9VED(")8+5!R:6]R:71Y
M(@IM<V=S='(@(E@M4')I;W)I='DB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD
M:7-T.C8W"FUS9VED(")8+5-P86TM3&5V96PB"FUS9W-T<B`B6"U3<&%M+4QE
M=F5L(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3
M<&%M+5-C;W)E(@IM<V=S='(@(E@M4W!A;2U38V]R92(*"B,Z(&-O;F9I9R]F
M:65L9',N<&AP+F1I<W0Z-S4*;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T
M<B`B6"U3<&%M+5-T871U<R(*"B,Z(&9I;'1E<G,N<&AP.C4V(')U;&4N<&AP
M.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@<G5L97,N(@IM<V=S='(@(D1U(&;E
M<B!I;G1E('-K87!A(&UE<B#D;B`E9"!R96=L97(N(@H*(SH@9FEL=&5R<RYP
M:'`Z-#@@<G5L92YP:'`Z,C$*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&]R(&5D:70@8W5S=&]M(')U;&5S+B(*;7-G<W1R(")$=2!F
MY7(@:6YT92!S:V%P82!E;&QE<B!R961I9V5R82!A;G!A<W-A9&4@<F5G;&5R
M+B(*"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C(P-C$*;7-G:60@(EEO=2!H
M879E(')E8V5I=F5D(&$@;F5W(&UE<W-A9V4B"FUS9W-T<B`B1'4@:&%R(&;E
M='0@971T(&YY='0@;65D9&5L86YD92XB"@HC.B!V86-A=&EO;BYP:'`Z,S`*
M;7-G:60@(B(*(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&5M86EL
M(&%D9')E<W,@9F]R('=H:6-H('1H92!V86-A=&EO;B!M97-S86=E<R`B"B)S
M:&]U;&0@8F4@86-T:79A=&5D+B(*;7-G<W1R("(B"B)$=2!MY7-T92!A;F=E
M(&UI;G-T(&5N(&4M<&]S=&%D<F5S<R!F]G(@=FEL:V5N('-E;65S=&5R;65D
M9&5L86YD92!S:V%L;"`B"B)A:W1I=F5R87,N(@H*(SH@;&EB+U-C<FEP="]I
M;6%P+G!H<#HR-S0@;&EB+U-C<FEP="]I;6%P+G!H<#HR.3<@;&EB+U-C<FEP
M="]I;6%P+G!H<#HS,3$*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");
M26YG970@Y')E;F1E72(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N
M:6YC.C(T"FUS9VED(")?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SHB"FUS
M9W-T<B`B7T%D<F5S<RAE<BD@871T('9I9&%R8F5F;V1R82!T:6QL.B(*"B,Z
M('1E;7!L871E<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,C,*;7-G:60@(E]!
M9&1R97-S97,@=&\@;F]T('-E;F0@<F5S<&]N<V5S('1O.B(*;7-G<W1R(")?
M061R97-S97(@871T(&EN=&4@<VMI8VMA('-V87(@=&EL;"(*"B,Z('1E;7!L
M871E<R]M96YU+VUE;G4N:6YC.C$Q(&QI8B]);F=O+G!H<#HS,C<*;7-G:60@
M(E]";&%C:VQI<W0B"FUS9W-T<B`B7U-PY')R861E(@H*(SH@=&5M<&QA=&5S
M+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC.C$X"FUS9VED(")?1&5L971E(&UE
M<W-A9V4@8V]M<&QE=&5L>2(*;7-G<W1R(")?4F%D97)A(&UE9&1E;&%N9&4@
M:&5L="(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHS
M,0IM<V=I9"`B7T5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE.B(*
M;7-G<W1R(")?06YG92!V87)J92!A9')E<W,@<.4@96X@;GD@<F%D(@H*(SH@
M=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z,3<@;&EB+TEN9V\N<&AP.C,S,PIM
M<V=I9"`B7T9O<G=A<F0B"FUS9W-T<B`B7U9I9&%R8F5F;W)D<F$B"@HC.B!T
M96UP;&%T97,O9F]R=V%R9"]F;W)W87)D+FEN8SHQ-PIM<V=I9"`B7TME97`@
M82!C;W!Y(&]F(&UE<W-A9V5S(&EN('1H:7,@86-C;W5N=#\B"FUS9W-T<B`B
M7U-P87)A(&5N(&MO<&EA(&%V(&UE9&1E;&%N9&5T(&;V<B!D970@:.1R(&MO
M;G1O=#\B"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI;F,Z
M,C(*;7-G:60@(E]-;W9E(&UE<W-A9V4@=&\@9F]L9&5R.B(*;7-G<W1R(")?
M1FQY='1A(&UE9&1E;&%N9&4@=&EL;"!M87!P.B(*"B,Z('1E;7!L871E<R]V
M86-A=&EO;B]V86-A=&EO;BYI;F,Z,3,*;7-G:60@(E]->2!E;6%I;"!A9&1R
M97-S97,Z(@IM<V=S='(@(E]-:6YA(&4M<&]S=&%D<F5S<V5R(@H*(SH@=&5M
M<&QA=&5S+VUE;G4O;65N=2YI;F,Z-@IM<V=I9"`B7U)U;&5S(@IM<V=S='(@
M(E]296=L97(B"@HC.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHR,"!L:6(O
M26YG;RYP:'`Z,S,V"FUS9VED(")?4V-R:7!T(@IM<V=S='(@(E]3:W)I<'0B
M"@HC.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHQ-"!L:6(O26YG;RYP:'`Z
M,S,P"FUS9VED(")?5F%C871I;VXB"FUS9W-T<B`B7U-E;65S=&5R(@H*(SH@
M=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z."!L:6(O26YG;RYP:'`Z,S(T"FUS
M9VED(")?5VAI=&5L:7-T(@IM<V=S='(@(E]"971R;V1D82(*"B,Z(&QI8B]"
M;&]C:R]O=F5R=FEE=RYP:'`Z-30*;7-G:60@(F%C=&EV92(*;7-G<W1R(")A
M:W1I=B(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z-`IM<V=I9"`B
M86YD(@IM<V=S='(@(F]C:"(*"B,Z('1E;7!L871E<R]F:6QT97)S+V9I;'1E
M<BYH=&UL.C$S"FUS9VED(")D:7-A8FQE9"`M(&-L:6-K('1O(&5N86)L92(*
M;7-G<W1R(")A=F%K=&EV97)A="`M(&ML:6-K82!F]G(@871T(&%K=&EV97)A
M(@H*(SH@9FEL=&5R<RYP:'`Z,3@U"FUS9VED(")F:65L9"(*;7-G<W1R(")F
MY&QT(@H*(SH@;&EB+T)L;V-K+V]V97)V:65W+G!H<#HU,@IM<V=I9"`B:6YA
M8W1I=F4B"FUS9W-T<B`B:6YA:W1I=B(*"B,Z(&QI8B]38W)I<'0O;6%I;&1R
M;W`N<&AP.C$R,0IM<V=I9"`B;6%I;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B
M>2!);F=O(@IM<V=S='(@(FUA:6QD<F]P+7-K<FEP="!S:V%P870@878@26YG
M;R(*"B,Z(&9I;'1E<G,N<&AP.C$X-0IM<V=I9"`B;6%T8V@B"FUS9W-T<B`B
M;6%T8VAA<B(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z-`IM<V=I
M9"`B;W(B"FUS9W-T<B`B96QL97(B"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL
M+G!H<#HQ,C@*;7-G:60@(G!R;V-M86EL('-C<FEP="!G96YE<F%T960@8GD@
M26YG;R(*;7-G<W1R(")P<F]C;6%I;"!S:W)I<'0@<VMA<&%T(&%V($EN9V\B
M"@HC.B!L:6(O4V-R:7!T+W-I979E+G!H<#HQ,3`*;7-G:60@(G-I979E(&9I
M;'1E<B!G96YE<F%T960@8GD@26YG;R(*;7-G<W1R(")3:65V92!F:6QT97(@
M<VMA<&%T(&%V($EN9V\B"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN
M9V\O<&\O=')?5%(N<&\`````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-#0V-38`,3`T,3<S-C(W-#<`,#$W-#`W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@5'5R:VES:"!T
M<F%N<VQA=&EO;G,@9F]R($EN9V\@<&%C:V%G90HC($EN9V\@<&%K971I(&GG
M:6X@5/QR:^=E(.=E=FER:6QE<BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R
M9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T
M:&4@<V%M92!L:6-E;G-E(&%S('1H92!);F=O('!A8VMA9V4N"B,*(R!'96YE
M<F%T960@8GD*(R!397)V970@1_QN97D@/'-G=6YE>4!M971U+F5D=2YT<CX*
M(R!!:&UE="#6>G3\<FL@/&]A:&UE=$!M971U+F5D=2YT<CX*(PIM<V=I9"`B
M(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@26YG;R`H,2XP+C$I
M7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,#$M,C4@,3@Z-#8K,#$P
M,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP,2TR-2`Q.#HT-BLP,3`P
M7&XB"B),87-T+51R86YS;&%T;W(Z($%U=&]M871I8V%L;'D@9V5N97)A=&5D
M7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U)4T\M.#@U.2TY7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3$[('!L
M=7)A;#TP.UQN(@H*(SH@9FEL=&5R<RYP:'`Z,38W"FUS9VED("(@86YD(@IM
M<V=S='(@(B!V92(*"B,Z(&9I;'1E<G,N<&AP.C$V-PIM<V=I9"`B(&]R(@IM
M<V=S='(@(B!V97EA(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C$Y"FUS9VED(")!8W1I;VX@9F]R(&)L86-K;&ES=&5D(&%D9')E
M<W-E<SHB"FUS9W-T<B`B2V%R86QI<W1E9&5K:2!A9')E<VQE<B!IYVEN(&5Y
M;&5M;&5R.B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C$P
M"FUS9VED(")!8W1I=F%T92!38W)I<'0B"FUS9W-T<B`B0F5T:6ML97)I($5T
M:VEN;&7^=&ER(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N:6YC
M.CD*;7-G:60@(D%D9&ET:6]N86P@4V5T=&EN9W,B"FUS9W-T<B`BW6QA=F4@
M07EA<FQA<B(*"B,Z('1E;7!L871E<R]R=6QE+VAE861E<BYI;F,Z-3,*;7-G
M:60@(D%L;"!O9B!T:&4@9F]L;&]W:6YG(@IM<V=S='(@(E1A:VEP(&5D96YL
M97)I;B!H97!S:2(*"B,Z('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-#0*
M;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(D-E=F%P;&%N;?W^(@H*(SH@=&5M
M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHU-@IM<V=I9"`B06YY(&]F('1H92!F
M;VQL;W=I;F<B"FUS9W-T<B`B5&%K:7`@961E;FQE<FEN(&AE<FAA;F=I(&)I
M<FDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F;V]T97(N:6YC.C$V"FUS9VED
M(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(E/\>F=EYVQE<FD@57EG=6QA(@H*
M(SH@9FEL=&5R<RYP:'`Z,3DV"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@9&5L971E('1H:7,@<G5L93\B"FUS9W-T<B`B0G4@:W5R86S]('-I
M;&UE:R!I<W1E9&GP:6YI>F4@96UI;B!M:7-I;FEZ/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,PIM<V=I9"`B075T;VUA=&EC86QL>2!U<&1A=&4@
M=&AE('-C<FEP="!A9G1E<B!E86-H(&-H86YG93\B"FUS9W-T<B`B0F5T:6L@
M:&5R(&1E\&G^:6UD96X@<V]N<F$@]GID979I;FEM;&D@;VQA<F%K(&?\;F-E
M;&QE;G-I;B!M:3\B"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C0W"FUS
M9VED(")"8V,B"FUS9W-T<B`B1VEZ;&D@2RY++B(*"B,Z(&QI8B]3=&]R86=E
M+G!H<#HS-#D*;7-G:60@(D)E9VEN<R!W:71H(@IM<V=S='(@(D)A_FQA;F?]
M8_TZ(@H*(SH@9FEL=&5R<RYP:'`Z,3(V('1E;7!L871E<R]B;&%C:VQI<W0O
M8FQA8VML:7-T+FEN8SHX"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`B2V%R
M86QI<W1E(@H*(SH@8FQA8VML:7-T+G!H<#HQ,#`*;7-G:60@(D)L86-K;&ES
M="!%9&ET(@IM<V=S='(@(DMA<F%L:7-T97EI($3\>F5N;&4B"@HC.B!B;&%C
M:VQI<W0N<&AP.C$W"FUS9VED(")";&%C:VQI<W0@:7,@;F]T('-U<'!O<G1E
M9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I=F5R+B(*;7-G<W1R(")+
M87)A;&ES=&4@>?QR_')L_&MT92!O;&%N('/\>F=EYR!S_'+\8_QS_"!T87)A
M9OUN9&%N(&1E<W1E:VQE;FUI>6]R+B(*"B,Z(&QI8B]38W)I<'0O<')O8VUA
M:6PN<&AP.C(P.0IM<V=I9"`B0FQA8VML:7-T960@061D<F5S<R(*;7-G<W1R
M(")+87)A;&ES=&5Y92!!;/UN;?W^($%D<F5S(@H*(SH@;&EB+U-C<FEP="]S
M:65V92YP:'`Z,C0U"FUS9VED(")";&%C:VQI<W1E9"!!9&1R97-S97,B"FUS
M9W-T<B`B2V%R86QI<W1E>64@06S];FW]_B!!9')E<VQE<B(*"B,Z(&-O;F9I
M9R]F:65L9',N<&AP+F1I<W0Z.#@*;7-G:60@(D)O9'DB"FUS9W-T<B`BW>=E
M<FEK(@H*(SH@9FEL=&5R<RYP:'`Z,38T(')U;&4N<&AP.C(S.`IM<V=I9"`B
M0V%S92!396YS:71I=F4B"FUS9W-T<B`B0OQY_&LO2_SG_&L@2&%R9B!$=7EA
M<FS](@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HT,PIM<V=I9"`B0V,B
M"FUS9W-T<B`B2RX@2V]P>6$B"@HC.B!R=6QE+G!H<#HQ,#4@=VAI=&5L:7-T
M+G!H<#HS-B!F;W)W87)D+G!H<#HS,R!V86-A=&EO;BYP:'`Z-#$*(SH@8FQA
M8VML:7-T+G!H<#HV.0IM<V=I9"`B0VAA;F=E<R!S879E9"XB"FUS9W-T<B`B
M1&7P:?YI:VQI:VQE<B!K87ED961I;&1I+B(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS-#4*;7-G:60@(D-O;G1A:6YS(@IM<V=S='(@(MWG97)M96MT961I<B(*
M"B,Z(&9I;'1E<G,N<&AP.C(P-"!F:6QT97)S+G!H<#HR,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]P>2`E<R(*;7-G<W1R(")+;W!Y86QA.B5S(@H*(SH@
M;&EB+U-T;W)A9V4N<&AP.C<W-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y
M(&]F("5S(@IM<V=S='(@(DMO<'EA<_TZ("5S(@H*(SH@;&EB+TEN9V\N<&AP
M.C4S"FUS9VED(")#<F5A=&4@;F5W(&9O;&1E<B(*;7-G<W1R(")996YI(&1I
M>FEN('EA<F%T(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O9FEL=&5R+FAT;6PZ
M,38*;7-G:60@(D1)4T%"3$5$(@IM<V=S='(@(E-%Q]U,345:($M)3$E.1$DB
M"@HC.B!L:6(O4V-R:7!T+W!R;V-M86EL+G!H<#HS-30*;7-G:60@(D1)4T%"
M3$5$.B`B"FUS9W-T<B`B4T7'W4Q-15H@2TE,24Y$23H@(@H*(SH@=&5M<&QA
M=&5S+W-C<FEP="]A8W1I=F%T92YI;F,Z,3<*;7-G:60@(D1E86-T:79A=&4@
M4V-R:7!T(@IM<V=S='(@(D)E=&GP:6X@171K:6YL:?!I;FD@2V%L9/UR(@H*
M(SH@9FEL=&5R<RYP:'`Z,3DV(&9I;'1E<G,N<&AP.C$Y-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@)7,B"FUS9W-T<B`B4VEL.B`E<R(*"B,Z('1E
M;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z,S`*;7-G:60@(D1E;&5T92!#;VYD
M:71I;VXB"FUS9W-T<B`B2V_^=6QU(%-I;"(*"B,Z(&QI8B]3=&]R86=E+G!H
M<#HS,#$*;7-G:60@(D1E;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T
M<B`BW6QE=&EY:2!T86UA;65N('-I;"(*"B,Z('1E;7!L871E<R]R=6QE+V9O
M;W1E<BYI;F,Z-#<*;7-G:60@(D1E;&5T960B"FUS9W-T<B`B4VEL:6YD:2(*
M"B,Z(&QI8B]3=&]R86=E+G!H<#HR.#D*;7-G:60@(D1E;&EV97(@:6YT;R!M
M>2!)3D)/6"(*;7-G<W1R(")'14Q%3B!+55154U5.02!G]FYD97(B"@HC.B!L
M:6(O4W1O<F%G92YP:'`Z,S$U"FUS9VED(")$96QI=F5R(&EN=&\@;7D@24Y"
M3U@@86YD(&-O<'D@=&\B"FUS9W-T<B`B1T5,14X@2U5455-53D$@9_9N9&5R
M('9E(&MO<'EA;&%N<_UN(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,Q,`IM<V=I
M9"`B1&5L:79E<B!I;G1O(&UY($E.0D]8(&%N9"!R961I<F5C="!T;R(*;7-G
M<W1R(")'14Q%3B!+55154U5.02!G]FYD97(@=F4@>?9N;&5N9&ER("(*"B,Z
M(&QI8B]3=&]R86=E+G!H<#HR.34*;7-G:60@(D1E;&EV97(@=&\@9F]L9&5R
M(@IM<V=S='(@(D1I>FEN92!G]FYD97(B"@HC.B!F:6QT97)S+G!H<#HR,3@@
M9FEL=&5R<RYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D1I<V%B;&4@
M)7,B"FUS9W-T<B`B4V7G:6QE;65Z($O];#H@)7,B"@HC.B!T96UP;&%T97,O
M=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z.2!T96UP;&%T97,O8FQA8VML:7-T
M+V)L86-K;&ES="YI;F,Z,3`*(SH@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T
M:6]N+FEN8SHY('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.CD*(SH@
M=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHS,`IM<V=I9"`B1&ES86)L960B
M"FUS9W-T<B`B4V7G:6QM97H@2_UL_6YD_2(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W-E='1I;F=S+FEN8SHR,0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!N
M;W1I9FEC871I;VX@=VAE;B!E86-H(&9I;'1E<B!I<R!A<'!L:65D/R(*;7-G
M<W1R(")(97(@<_QZ9V5C:6X@;F4@>F%M86X@=7EG=6QA;F%C8?#];F$@9&%I
M<B!D971A>6S](&)I;&=I('9E<FEL<VEN(&UI/R(*"B,Z('1E;7!L871E<R]V
M86-A=&EO;B]V86-A=&EO;BYI;F,Z,S@*;7-G:60@(D1O(%]N;W0@<V5N9"!R
M97-P;VYS97,@=&\@8G5L:R!O<B!L:7-T(&UE<W-A9V5S(@IM<V=S='(@(EG]
M\/UN('EA9&$@;&ES=&4@:6QE<FEL97)I;F4@7V-E=F%P(&?V;F1E<FUE(@H*
M(SH@=&5M<&QA=&5S+W)U;&4O9F]O=&5R+FEN8SHQ,`IM<V=I9"`B1&\@=&AI
M<SHB"FUS9W-T<B`B66%P.B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3`*;7-G
M:60@(D1O97-N)W0@8F5G:6X@=VET:"(*;7-G<W1R(")"8?YL86UA>6%N(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,T-@IM<V=I9"`B1&]E<VXG="!C;VYT86EN
M(@IM<V=S='(@(MWG97)M97EE;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-3(*
M;7-G:60@(D1O97-N)W0@96YD('=I=&@B"FUS9W-T<B`B0FET;65Y96XB"@HC
M.B!L:6(O4W1O<F%G92YP:'`Z,S4T"FUS9VED(")$;V5S;B=T(&5X:7-T(@IM
M<V=S='(@(D)U;'5N;6%Y86XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4W"FUS
M9VED(")$;V5S;B=T(&UA=&-H("AW:71H('!L86-E:&]L9&5R<RDB"FUS9W-T
M<B`B1?YL9?YM97EE;B`B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]H96%D97(N
M:6YC.C(P"FUS9VED(")%9&ET(@IM<V=S='(@(D3\>F5N;&4B"@HC.B!F:6QT
M97)S+G!H<#HQ.#4@9FEL=&5R<RYP:'`Z,3@W(&9I;'1E<G,N<&AP.C$Y,2!F
M:6QT97)S+G!H<#HQ.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="`E<R(*
M;7-G<W1R(")$_'IE;FQE("5S(@H*(SH@9FEL=&5R<RYP:'`Z,C(R(&9I;'1E
M<G,N<&AP.C(R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;F%B;&4@)7,B"FUS
M9W-T<B`B4V7G:6QI<B!K_6PZ("5S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M:&5A9&5R+FEN8SHR,@IM<V=I9"`B16YA8FQE9"(*;7-G<W1R(")39>=I;&ER
M(&O];/UN9/TB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4Q"FUS9VED(")%;F1S
M('=I=&@B"FUS9W-T<B`B0FET96XB"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S8R
M"FUS9VED(")%<75A;"!T;R(*;7-G<W1R(")%_FET=&ER(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O:&5A9&5R+FEN8SHW"FUS9VED(")%>&ES=&EN9R!2=6QE
M<R(*;7-G<W1R(")687)O;&%N($MU<F%L;&%R(@H*(SH@;&EB+U-T;W)A9V4N
M<&AP.C,U,PIM<V=I9"`B17AI<W1S(@IM<V=S='(@(E9A<B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W-E='1I;F=S+FEN8SHS,`IM<V=I9"`B1FEL=&5R($%L
M;"!-97-S86=E<R(*;7-G<W1R(")"_'3\;B!I;&5T:6QE<FD@4_QZ9V7G;&4B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]S971T:6YG<RYI;F,Z,S(*;7-G:60@
M(D9I;'1E<B!/;FQY(%-E96X@365S<V%G97,B"FUS9W-T<B`B4V%D96-E($?V
M<OQL;?S^(-UL971I;&5R:2!3_'IG9>=L92(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W-E='1I;F=S+FEN8SHS,0IM<V=I9"`B1FEL=&5R($]N;'D@56YS965N
M($UE<W-A9V5S(@IM<V=S='(@(E-A9&5C92!']G+\;&UE;6G^(-UL971I;&5R
M:2!3_'IG9>=L92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W-E='1I;F=S+FEN
M8SHR.`IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B4_QZ9V7G(%-E
MYV5N96ML97)I(@H*(SH@=&5M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8SHR.`IM
M<V=I9"`B1FEL=&5R(%)U;&4B"FUS9W-T<B`B4_QZ9V7G($MU<F%L_2(*"B,Z
M(&9I;'1E<G,N<&AP.CDR"FUS9VED(")&:6QT97(@4G5L97,B"FUS9W-T<B`B
M4_QZ9V7G($MU<F%L;&%R_2(*"B,Z('-C<FEP="YP:'`Z-3(*;7-G:60@(D9I
M;'1E<B!38W)I<'0@1&ES<&QA>2(*;7-G<W1R(")3_'IG9><@0F5T:6L@1_9R
M_&YT_&QE;64B"@HC.B!L:6(O26YG;RYP:'`Z,C8Y"FUS9VED(")&:6QT97(@
M7U)U;&5S(@IM<V=S='(@(E/\>F=EYR!?2W5R86QL87+](@H*(SH@;&EB+U-C
M<FEP="]I;6%P+G!H<#HS,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R
M(&%C=&EV:71Y.B`E<R!M97-S86=E*',I(&AA=F4@8F5E;B!C;W!I960@=&\@
M=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E/\>F=EYR!E=&MI;FQI\&DZ
M("5S(&EL971I(&MO<'EA;&%N9/TZ7"(E<UPB+B(*"B,Z(&QI8B]38W)I<'0O
M:6UA<"YP:'`Z,S`X"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<B!A8W1I
M=FET>3H@)7,@;65S<V%G92AS*2!H879E(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B4_QZ9V7G(&5T:VEN;&GP:3H@)7,@:6QE=&D@<VEL:6YD:2XB"@HC.B!L
M:6(O4V-R:7!T+VEM87`N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&UO=F5D
M('1O('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")3_'IG9><@971K:6YL
M:?!I.B`E<R!I;&5T:2!T8?[];F3].B!<(B5S7"(@9&EZ:6YI;F4N(@H*(SH@
M;&EB+U-C<FEP="]I;6%P+G!H<#HQ.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL=&5R(&%C=&EV:71Y.B`E<R!M97-S86=E*',I('1H870@;6%T8VAE9"!T
M:&4@8FQA8VML:7-T('=E<F4@9&5L971E9"XB"FUS9W-T<B`B4_QZ9V7G(&5T
M:VEN;&GP:3H@:V%R86QI<W1E>6QE(&7^;&7^96X@)7,@:6QE=&D@<VEL:6YD
M:2XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB)7-<
M(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!C;W!I960@=&\@=&AE("(*(F9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!I;&5T:7-I("A<(B5S7"(@9&5N
M(&=E;&UE:W1E*2!<(B5S7"(@9&EZ:6YI;F4@:V]P>6%L86YD_2XB"@HC.B!L
M:6(O4V-R:7!T+VEM87`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")3_'IG9><@971K:6YL:?!I
M.B!<(B5S7"(@:6QE=&ES:2`H7"(E<UPB(&1E;B!G96QM96MT92D@<VEL:6YD
M:2XB"@HC.B!L:6(O4V-R:7!T+VEM87`N<&AP.C(X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)&:6QT97(@86-T:79I='DZ(%1H92!M97-S86=E(%PB)7-<
M(B!F<F]M(%PB)7-<(B!H87,@8F5E;B!M;W9E9"!T;R!T:&4@9F]L9&5R("(*
M(EPB)7-<(BXB"FUS9W-T<B`B(@HB4_QZ9V7G(&5T:VEN;&GP:3H@7"(E<UPB
M(&EL971I<VD@*%PB)7-<(B!D96X@9V5L;65K=&4I(%PB)7-<(B!D:7II;F4@
M=&'^_6YD_2XB"@HC.B!R=6QE+G!H<#HQ,S,*;7-G:60@(D9I;'1E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E/\>F=EYR!B=6QU;F%M863]+B(*"B,Z('1E;7!L
M871E<R]R=6QE+VAE861E<BYI;F,Z-#@*;7-G:60@(D9O<B!A;B!I;F-O;6EN
M9R!M97-S86=E('1H870@;6%T8VAE<SHB"FUS9W-T<B`B1V5L96X@:6QE=&EL
M97(@:>=I;B!E_FQE_FUE.B`B"@HC.B!F:6QT97)S+G!H<#HQ-#0@=&5M<&QA
M=&5S+V9O<G=A<F0O9F]R=V%R9"YI;F,Z-PIM<V=I9"`B1F]R=V%R9"(*;7-G
M<W1R("+=;&5T(@H*(SH@9F]R=V%R9"YP:'`Z,38*;7-G:60@(D9O<G=A<F0@
M:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I;F<@9')I
M=F5R+B(*;7-G<W1R("(B"B+=;&5T:6QE;B!I;&5T:6QE<B!Y_'+\<FS\:W1E
M:VD@<_QZ9V7G('/\<OQC_"!T87)A9OUN9&%N(&1E<W1E:VQE;FUI>6]R+B(*
M"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(Y-@IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`BW6QE="(*"B,Z(&9O<G=A<F0N<&AP.C0V"FUS9VED(")&
M;W)W87)D<R!%9&ET(@IM<V=S='(@(MUL971I;&5C96ML97)I($3\>F5N;&4B
M"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C,Y"FUS9VED(")&<F]M(@IM
M<V=S='(@(DMI;61E;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS-C`*;7-G:60@
M(D=R96%T97(@=&AA;B(*;7-G<W1R(")"_'G\:W3\<B(*"B,Z(&QI8B]3=&]R
M86=E+G!H<#HS-C$*;7-G:60@(D=R96%T97(@=&AA;B!O<B!E<75A;"!T;R(*
M;7-G<W1R(")"_'G\:R!Y861A(&7^:71T:7(B"@HC.B!T96UP;&%T97,O<G5L
M92]F;V]T97(N:6YC.C0Q"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`BUFYE
M;6QI(@H*(SH@<G5L92YP:'`Z,C8*;7-G:60@(DEN9&EV:61U86P@<G5L97,@
M87)E(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R
M:79E<BXB"FUS9W-T<B`B2VG^:7-E;"!K=7)A;&QA<B!Y_'+\<FS\:W1E:VD@
M<_QZ9V7G('/\<OQC_"!T87)A9OUN9&%N(&1E<W1E:VQE;FUI>6]R+B(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$W.#,*;7-G:60@(DEN97AI<W1A;G0@
M;6%I;&)O>"!S<&5C:69I960@9F]R(&UE<W-A9V4@9&5L:79E<GDN(@IM<V=S
M='(@(FEL971I('1E<VQI;6D@:>=I;B!V87(@;VQM87EA;B!B:7(@<&]S=&$@
M:W5T=7-U(&)E;&ER=&EL9&DN(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C,T-PIM
M<V=I9"`B27,B"FUS9W-T<B`B3VQA;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS
M-#@*;7-G:60@(DES;B=T(@IM<V=S='(@(D]L;6%Y86XB"@HC.B!L:6(O4W1O
M<F%G92YP:'`Z,S4X"FUS9VED("),97-S('1H86XB"FUS9W-T<B`B2_SG_&MT
M_'(B"@HC.B!L:6(O4W1O<F%G92YP:'`Z,S4Y"FUS9VED("),97-S('1H86X@
M;W(@97%U86P@=&\B"FUS9W-T<B`B2_SG_&L@>6%D82!E_FET:7(B"@HC.B!C
M;VYF:6<O9FEE;&1S+G!H<"YD:7-T.C4Y"FUS9VED("),:7-T+4E$(@IM<V=S
M='(@(DQI<W1E+4E$(@H*(SH@=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI
M<W0N:6YC.C(R"FUS9VED(")-87)?:R!M97-S86=E(&%S(&1E;&5T960B"FUS
M9W-T<B`BW6QE=&EY:2!S:6QI;F5C95]K(&]L87)A:R!I_F%R971L92(*"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S,*;7-G:60@(DUA<FL@;65S
M<V%G92!A<SHB"FUS9W-T<B`BW6QE=&EY:2!I_F%R971L93HB"@HC.B!L:6(O
M4W1O<F%G92YP:'`Z,S4V"FUS9VED(")-871C:&5S("AW:71H('!L86-E:&]L
M9&5R<RDB"FUS9W-T<B`B1?YL9?YE;B(*"B,Z(&QI8B]3=&]R86=E+G!H<#HT
M.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB36%X:6UU;2!N=6UB97(@;V8@
M8FQA8VML:7-T960@861D<F5S<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S
M97,Z("5S+"`B"B)-87AI;75M(&%D9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T
M(&%D9"!N97<@861D<F5S<V5S('1O(&)L86-K;&ES="XB"FUS9W-T<B`B(@HB
M16X@>?QK<V5K(&MA<F%L:7-T92!A9')E<R!S87G]<_T@8?[];&3]*%1O<&QA
M;2!A9')E<VQE<CH@)7,L($5N('G\:W-E:R!A9')E<R`B"B)S87G]<_TZ("5S
M*2X@2V%R86QI<W1E>64@>65N:2!B:7(@861R97,@96ML97EE;65Z<VEN:7HN
M(@H*(SH@;&EB+U-T;W)A9V4N<&AP.C4T,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)-87AI;75M(&YU;6)E<B!O9B!W:&ET96QI<W1E9"!A9&1R97-S97,@
M97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L("(*(DUA>&EM=6T@861D
M<F5S<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A9&1R97-S97,@=&\@
M=VAI=&5L:7-T+B(*;7-G<W1R("(B"B)%;B!Y_&MS96L@=&5M:7H@861R97,@
M<V%Y_7/](&'^_6QD_2A4;W!L86T@861R97-L97(Z("5S+"!%;B!Y_&MS96L@
M861R97,@(@HB<V%Y_7/].B`E<RDN(%1E;6EZ(&QI<W1E<VEN92!Y96YI(&)I
M<B!A9')E<R!E:VQE>65M97IS:6YI>BXB"@HC.B!L:6(O4V-R:7!T+W-I979E
M+G!H<#HQ-C0V"FUS9VED(")-:7-S:6YG(&%D9')E<W,@=&\@<F5D:7)E8W0@
M;65S<V%G92!T;R(*;7-G<W1R("+=;&5T:6YI;B!Y]FYL96YD:7)I;&5C9?!I
M(&%D<F5S(&5K<VEK(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,38X,`IM
M<V=I9"`B36ES<VEN9R!R96%S;VX@9F]R(')E:F5C="(*;7-G<W1R(")'97)I
M(.=E=FER;64@<V5B96)I(&5K<VEK(@H*(SH@;&EB+U-C<FEP="]S:65V92YP
M:'`Z,3@U,`IM<V=I9"`B36ES<VEN9R!R96%S;VX@:6X@=F%C871I;VXN(@IM
M<V=S='(@(E1A=&EL('-E8F5B:2!E:W-I:RXB"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]H96%D97(N:6YC.C(S"FUS9VED(")-;W9E(@IM<V=S='(@(E1A_OTB
M"@HC.B!F:6QT97)S+G!H<#HQ,#D@9FEL=&5R<RYP:'`Z,C$U"FUS9VED(")-
M;W9E(%)U;&4@1&]W;B(*;7-G<W1R(")+=7)A;/T@0?YA\/T@5&'^_2(*"B,Z
M(&9I;'1E<G,N<&AP.C$Q,"!F:6QT97)S+G!H<#HR,30*;7-G:60@(DUO=F4@
M4G5L92!5<"(*;7-G<W1R(")+=7)A;/T@675K87+](%1A_OTB"@HC.B!T96UP
M;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C0V"FUS9VED(").7W5M8F5R
M(&]F(&1A>7,@8F5T=V5E;B!V86-A=&EO;B!R97!L:65S.B(*;7-G<W1R(")4
M871I;"!C979A<&QA<OT@87)A<_UN9&%K:2!G_%]N('-A>?US_2(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8SHT('1E;7!L871E<R]F
M:6QT97)S+V9O;W1E<BYI;F,Z,3,*(SH@;&EB+U-T;W)A9V4N<&AP.C<R-@IM
M<V=I9"`B3F5W(%)U;&4B"FUS9W-T<B`B665N:2!+=7)A;"(*"B,Z(&QI8B])
M;F=O+G!H<#HR,#0@;&EB+TEN9V\N<&AP.C(P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R`G)7,G(&5L96UE;G0@9F]U;F0@:6X@8F%C:V5N9"!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(G)7,G(/;P97-I('-O;B!Y87#];&%N_?YT82!B
M=6QU;F%M863]+B(*"B,Z(&QI8B]);F=O+G!H<#HR,#(*;7-G:60@(DYO(&)A
M8VME;F0@8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T(@IM<V=S='(@(D)U(&%N
M87-I<W1E;2!IYVEN('-O;B!Y87#];&%N_?X@96MS:6LB"@HC.B!L:6(O26YG
M;RYP:'`Z,3<Y"FUS9VED(").;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A
M8VME;F1S+G!H<"(*;7-G<W1R(")B86-K96YD<RYP:'`@9&]S>6%S_6YD82!S
M;VX@=><@>6%P_6QA;OW^_2!Y;VLB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]F
M:6QT97(M;F]N92YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!F:6QT
M97)S+B!#;&EC:R`G)7,G('1O(&-R96%T92!A(&YE=R!F:6QT97(N(@IM<V=S
M='(@(E/\>F=EYR!Y;VLN66%R871M86L@:>=I;B`G)7,G=/UK;&%Y_6XN(@H*
M(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3(S,R!L:6(O4V-R:7!T+W-I979E
M+G!H<#HQ,S,S"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$U,34*;7-G:60@
M(DYO(&AE861E<G,@<W!E8VEF:65D(@IM<V=S='(@(D)A_FS]:R!B:6QG:7-I
M(&)E;&ER=&EL;65D:2(*"B,Z('-C<FEP="YP:'`Z-C<*;7-G:60@(DYO('-C
M<FEP="!G96YE<F%T960N(@IM<V=S='(@(D)E=&EK('EA<F%T_6QM863]+B(*
M"B,Z(&QI8B]38W)I<'0O<VEE=F4N<&AP.C$U,S`*;7-G:60@(DYO('-T<FEN
M9W,@<W!E8VEF:65D(@IM<V=S='(@(D1I>F=I("!B96QI<G1I;&UE9&DN(@H*
M(SH@;&EB+U-T;W)A9V4N<&AP.C,V,PIM<V=I9"`B3F]T(&5Q=6%L('1O(@IM
M<V=S='(@(D7^:70@9&7P:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3D*;7-G:60@(D]P=&EO;G,@86)O=70@<V-R:7!T('5P9&%T:6YG+B(*;7-G
M<W1R(")"971I:R!G_&YC96QL96UE('-EYV5N96ML97)I+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G
M<W1R(")$:?!E<B!S9>=E;F5K;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VYE=U]F;VQD97(N:G,Z-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N
M86UE(&]F('1H92!N97<@9F]L9&5R.B(*;7-G<W1R("),_'1F96X@>65N:2!D
M:7II;FEN(&%D_6[](&=I<FEN.B(*"B,Z('1E;7!L871E<R]V86-A=&EO;B]V
M86-A=&EO;BYI;F,Z-C0*;7-G:60@(E)?96%S;VXB"FUS9W-T<B`B1V5R96OG
M92(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z-C,*;7-G:60@(E)E8V5I
M=F5D(@IM<V=S='(@(E5L8?YT_2(*"B,Z(&QI8B]3=&]R86=E+G!H<#HS,#8*
M;7-G:60@(E)E9&ER96-T('1O(@IM<V=S='(@(EGV;FQE;F1I<B(*"B,Z(&QI
M8B]3=&]R86=E+G!H<#HS-34*;7-G:60@(E)E9W5L87(@97AP<F5S<VEO;B(*
M;7-G<W1R(")$_'IE;FQI(-UF861E;&5R(@H*(SH@;&EB+U-T;W)A9V4N<&AP
M.C,R,0IM<V=I9"`B4F5J96-T('=I=&@@<F5A<V]N(@IM<V=S='(@(D=E<F5K
MYV5Y;&4@<F5D9&5T(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU-0IM
M<V=I9"`B4F5S96YT(%1O(@IM<V=S='(@(EEE;FED96X@1_9N9&5R(@H*(SH@
M8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HU,0IM<V=I9"`B4F5S96YT+69R;VTB
M"FUS9W-T<B`B665N:61E;B!']FYD97)I;&5N(@H*(SH@=&5M<&QA=&5S+W)U
M;&4O9F]O=&5R+FEN8SHW,@IM<V=I9"`B4F5T=7)N('1O($9I;'1E<G,@3&ES
M="(*;7-G<W1R(")3_'IG9><@3&ES=&5S:6YE($=E<FD@1/9N(@H*(SH@=&5M
M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N:6YC.C(X('1E;7!L871E<R]B
M;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHT,PHC.B!T96UP;&%T97,O=F%C871I
M;VXO=F%C871I;VXN:6YC.C<U('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N
M:6YC.C,X"FUS9VED(")2971U<FX@=&\@4G5L97,@3&ES="(*;7-G<W1R(")+
M=7)A;&QA<B!,:7-T97-I;F4@1V5R:2!$]FXB"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]H96%D97(N:6YC.C(Q"FUS9VED(")2=6QE(@IM<V=S='(@(DMU<F%L
M(@H*(SH@9FEL=&5R<RYP:'`Z-#4*;7-G:60@(E)U;&4@0V]P:65D(@IM<V=S
M='(@(DMU<F%L($MO<'EA;&%N9/TB"@HC.B!F:6QT97)S+G!H<#HS.0IM<V=I
M9"`B4G5L92!$96QE=&5D(@IM<V=S='(@(DMU<F%L(%-I;&EN9&DB"@HC.B!F
M:6QT97)S+G!H<#HU.0IM<V=I9"`B4G5L92!$:7-A8FQE9"(*;7-G<W1R(")+
M=7)A;"!'9>=E<G-I>B!+_6S];F3](@H*(SH@9FEL=&5R<RYP:'`Z-C0*;7-G
M:60@(E)U;&4@16YA8FQE9"(*;7-G<W1R(")+=7)A;"!'9>=E<FQI($O];/UN
M9/TB"@HC.B!T96UP;&%T97,O<G5L92]H96%D97(N:6YC.C,Y"FUS9VED(")2
M=6QE($YA;64B"FUS9W-T<B`B2W5R86P@063](@H*(SH@=&5M<&QA=&5S+W=H
M:71E;&ES="]W:&ET96QI<W0N:6YC.C(W('1E;7!L871E<R]B;&%C:VQI<W0O
M8FQA8VML:7-T+FEN8SHT,@HC.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I
M;VXN:6YC.C<T('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC.C,W"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z-S$*;7-G:60@(E-A=F4B"FUS
M9W-T<B`B2V%Y9&5T(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<V5T=&EN9W,N
M:6YC.C0W"FUS9VED(")3879E(%-E='1I;F=S(@IM<V=S='(@(D%Y87)L87+]
M($MA>61E="(*"B,Z('1E;7!L871E<R]S8W)I<'0O:&5A9&5R+FEN8SHS"FUS
M9VED(")38W)I<'0B"FUS9W-T<B`B0F5T:6LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@*;7-G:60@(E-C<FEP="!5<&1A=&EN9R(*;7-G<W1R(")"
M971I:R!'_&YC96QL96YI>6]R(@H*(SH@;&EB+TEN9V\N<&AP.C(R.0IM<V=I
M9"`B4V-R:7!T(&YO="!U<&1A=&5D+B(*;7-G<W1R(")"971I:R!'_&YC96QL
M96YM961I+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S8*;7-G:60@(E-C<FEP="!S
M=6-C97-S9G5L;'D@86-T:79A=&5D+B(*;7-G<W1R(")"971I:R!B8?YA<OUY
M;&$@971K:6YL9?YT:7)I;&1I+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,S4*;7-G
M:60@(E-C<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(D)E=&GP:6X@971K:6YL:?!I(&)A_F%R_7EL82!K86QD_7+];&3]+B(*"B,Z
M('1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,Z,S@*;7-G:60@(E-E96XB"FUS
M9W-T<B`B1_9R_&QM_/XB"@HC.B!R=6QE+G!H<#HQ-C,*;7-G:60@(E-E;&5C
M="!A(&9I96QD(@IM<V=S='(@(D)I<B!A;&%N('-EYVEN(@H*(SH@;&EB+TEN
M9V\N<&AP.C4P"FUS9VED(")396QE8W0@=&%R9V5T(&9O;&1E<B(*;7-G<W1R
M(")":7(@:&5D968@9&EZ:6X@<V7G:6XB"@HC.B!R=6QE+G!H<#HQ.#0*;7-G
M:60@(E-E;&8M1&5F:6YE9"!(96%D97(B"FUS9W-T<B`B2V5N9&EN9&5N(%1A
M;OUM;/T@0F'^;/UK($)I;&=I<VDB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD
M:7-T.C,U"FUS9VED(")396YD97(B"FUS9W-T<B`B1_9N9&5R96XB"@HC.B!F
M:6QT97)S+G!H<#HW.`IM<V=I9"`B4V5T=&EN9W,@<W5C8V5S<V9U;&QY('5P
M9&%T960N(@IM<V=S='(@(D%Y87)L87(@8F'^87+]>6QA(&?\;F-E;&QE;F1I
M+B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C(T"FUS9VED
M(")3:&]W($%C=&EV92!38W)I<'0B"FUS9W-T<B`B171K:6X@0F5T:?!I($?V
M<W1E<B(*"B,Z('1E;7!L871E<R]S8W)I<'0O86-T:79A=&4N:6YC.C,Q"FUS
M9VED(")3:&]W($-U<G)E;G0@4V-R:7!T(@IM<V=S='(@(EG\<OQR;/QK=&5K
M:2!"971I\&D@1_9S=&5R(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HX
M,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")";WEU="(*"B,Z('1E;7!L871E<R]R
M=6QE+V9O;W1E<BYI;F,Z-C$*;7-G:60@(E-T;W`@8VAE8VMI;F<@:68@=&AI
M<R!R=6QE(&UA=&-H97,_(@IM<V=S='(@(D)U(&MU<F%L(&7^;&7^:7(B"@HC
M.B!T96UP;&%T97,O=F%C871I;VXO=F%C871I;VXN:6YC.C4U"FUS9VED(")3
M=6)J95]C="!O9B!V86-A=&EO;B!M97-S86=E.B(*;7-G<W1R(")4871I;"!M
M97-A:OUN_6X@2V]N7W5S=3HB"@HC.B!C;VYF:6<O9FEE;&1S+G!H<"YD:7-T
M.C,Q"FUS9VED(")3=6)J96-T(@IM<V=S='(@(DMO;G4B"@HC.B!L:6(O26YG
M;RYP:'`Z,3,Q"FUS9VED(")4:&4@9')I=F5R('-A:60Z("(*;7-G<W1R(")3
M_'+\8_P@8F5L:7)T:7EO<CH@(@H*(SH@;&EB+TEN9V\N<&AP.C$S,`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%C=&EV871I;F<@=&AE('-C<FEP="XB
M"FUS9W-T<B`B0F5T:6L@971K:6YL9?YT:7)L:7)K96X@8FER(&AA=&$@;VQU
M_G1U+B(*"B,Z(&QI8B]);F=O+G!H<#HQ,CD*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D96%C=&EV871I;F<@=&AE('-C<FEP="XB"FUS9W-T<B`B0F5T
M:?!I;B!E=&MI;FQI\&D@:V%L9/UR_6S]<FME;B!B:7(@:&%T82!O;'7^='4N
M("(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z,C<*;7-G:60@(E1O(@IM
M<V=S='(@(DMI;64B"@HC.B!L:6(O4V-R:7!T+G!H<#HQ,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N(@IM<V=S='(@(B5S(&EN('1A;OUM_2!Y_&ML96YE;65D:2XB"@HC.B!F
M:6QT97)S+G!H<#HQ,S@@=&5M<&QA=&5S+W9A8V%T:6]N+W9A8V%T:6]N+FEN
M8SHW"B,Z(&QI8B]38W)I<'0O<')O8VUA:6PN<&AP.C(W,@IM<V=I9"`B5F%C
M871I;VXB"FUS9W-T<B`B5&%T:6PB"@HC.B!V86-A=&EO;BYP:'`Z-C8*;7-G
M:60@(E9A8V%T:6]N($5D:70B"FUS9W-T<B`B5&%T:6P@1/QZ96YL92(*"B,Z
M(&QI8B]38W)I<'0O<VEE=F4N<&AP.C,U,@IM<V=I9"`B5F%C871I;VX@365S
M<V%G92(*;7-G<W1R(")4871I;"!-97-A:OTB"@HC.B!V86-A=&EO;BYP:'`Z
M,38*;7-G:60@(E9A8V%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U
M<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB"FUS9W-T<B`B5&%T:6P@>?QR_')L
M_&MT96MI('/\>F=EYR!S_'+\8_QS_"!T87)A9OUN9&%N(&1E<W1E:VQE;FUE
M;65K=&5D:7(N(@H*(SH@=&5M<&QA=&5S+W=H:71E;&ES="]W:&ET96QI<W0N
M:6YC.C$X"FUS9VED(")7:%]I=&5L:7-T(&%D9')E<W-E<SHB"FUS9W-T<B`B
M0F5Y85]Z;&ES=&4@061R97-L97)I.B(*"B,Z(&9I;'1E<G,N<&AP.C$S,B!T
M96UP;&%T97,O=VAI=&5L:7-T+W=H:71E;&ES="YI;F,Z-PIM<V=I9"`B5VAI
M=&5L:7-T(@IM<V=S='(@(D)E>6%Z($QI<W1E(@H*(SH@=VAI=&5L:7-T+G!H
M<#HU-0IM<V=I9"`B5VAI=&5L:7-T($5D:70B"FUS9W-T<B`B0F5Y87H@3&ES
M=&5Y:2!$_'IE;FQE(@H*(SH@=VAI=&5L:7-T+G!H<#HQ.`IM<V=I9"`B5VAI
M=&5L:7-T(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&-U<G)E;G0@9FEL=&5R
M:6YG(&1R:79E<BXB"FUS9W-T<B`B(@HB0F5Y87H@3&ES=&4@>?QR_')L_&MT
M96MI('/\>F=EYR!S_'+\8_QS_"!T87)A9OUN9&%N(&1E<W1E:VQE;FUE;65K
M=&5D:7(N(@H*(SH@;&EB+U-C<FEP="]P<F]C;6%I;"YP:'`Z,C0P(&QI8B]3
M8W)I<'0O<VEE=F4N<&AP.C(Y.0IM<V=I9"`B5VAI=&5L:7-T960@061D<F5S
M<V5S(@IM<V=S='(@(D)E>6%Z($QI<W1E9&5K:2!!9')E<VQE<B(*"B,Z(&-O
M;F9I9R]F:65L9',N<&AP+F1I<W0Z-SD*;7-G:60@(E@M4')I;W)I='DB"FUS
M9W-T<B`B6"W6;F-E;&GP:2(*"B,Z(&-O;F9I9R]F:65L9',N<&AP+F1I<W0Z
M-C<*;7-G:60@(E@M4W!A;2U,979E;"(*;7-G<W1R(")8+5-P86TM1/QZ97EI
M(@H*(SH@8V]N9FEG+V9I96QD<RYP:'`N9&ES=#HW,0IM<V=I9"`B6"U3<&%M
M+5-C;W)E(@IM<V=S='(@(E@M4W!A;2U$97)E8V5S:2(*"B,Z(&-O;F9I9R]F
M:65L9',N<&AP+F1I<W0Z-S4*;7-G:60@(E@M4W!A;2U3=&%T=7,B"FUS9W-T
M<B`B6"U3<&%M+41U<G5M=2(*"B,Z('9A8V%T:6]N+G!H<#HS,`IM<V=I9"`B
M(@HB66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@96UA:6P@861D<F5S
M<R!F;W(@=VAI8V@@=&AE('9A8V%T:6]N(&UE<W-A9V5S("(*(G-H;W5L9"!B
M92!A8W1I=F%T960N(@IM<V=S='(@(B(*(E1A=&EL(&UE<V%J;&%R_6[];OUN
M(&5T:VEN;&7^;65S:2!IYVEN(&5N(&%Z(&)I<B!E;&5K=')O;FEK('!O<W1A
M(&%D<F5S:2`B"B)B96QI<G1M96YI>B!G97)E:VQI9&ER+B(*"B,Z(&QI8B]3
M8W)I<'0O:6UA<"YP:'`Z,C@Q(&QI8B]38W)I<'0O:6UA<"YP:'`Z,S`T(&QI
M8B]38W)I<'0O:6UA<"YP:'`Z,S$X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS
M9W-T<B`B6TMO;G4@66]K72(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O<G=A
M<F0N:6YC.C(W"FUS9VED(")?061D<F5S<RAE<RD@=&\@9F]R=V%R9"!T;SHB
M"FUS9W-T<B`BW6QE=&EL96-E:R!?061R97-L97(Z(@H*(SH@=&5M<&QA=&5S
M+W9A8V%T:6]N+W9A8V%T:6]N+FEN8SHR.`IM<V=I9"`B7T%D9')E<W-E<R!T
M;R!N;W0@<V5N9"!R97-P;VYS97,@=&\Z(@IM<V=S='(@(EEA;OUT(&?V;F1E
M<FEL;65Y96-E:R!?061R97-L97(Z(@H*(SH@;&EB+TEN9V\N<&AP.C(W-`IM
M<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R(")?2V%R82!,:7-T92(*"B,Z('1E
M;7!L871E<R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8SHR,`IM<V=I9"`B7T1E
M;&5T92!M97-S86=E(&-O;7!L971E;'DB"FUS9W-T<B`BW6QE=&ET:2!T86UA
M;65N(%]3:6PB"@HC.B!T96UP;&%T97,O8FQA8VML:7-T+V)L86-K;&ES="YI
M;F,Z,S,*;7-G:60@(E]%;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN
M93HB"FUS9W-T<B`B7TAE<B!A9')E<VD@>65N:2!B:7(@<V%T_7)D82!G:7)I
M;CHB"@HC.B!L:6(O26YG;RYP:'`Z,C@P"FUS9VED(")?1F]R=V%R9"(*;7-G
M<W1R("+=7VQE="(*"B,Z('1E;7!L871E<R]F;W)W87)D+V9O<G=A<F0N:6YC
M.C$Y"FUS9VED(")?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@:6X@=&AI<R!A
M8V-O=6YT/R(*;7-G<W1R(")?W6QE=&EL97)I;B!B:7(@:V]P>6%S_2!H97-A
M<'1A('1U='5L<W5N(&UU/R(*"B,Z('1E;7!L871E<R]B;&%C:VQI<W0O8FQA
M8VML:7-T+FEN8SHR-`IM<V=I9"`B7TUO=F4@;65S<V%G92!T;R!F;VQD97(Z
M(@IM<V=S='(@(MUL971I>6D@9&EZ:6YE(%]48?[].B(*"B,Z('1E;7!L871E
M<R]V86-A=&EO;B]V86-A=&EO;BYI;F,Z,3@*;7-G:60@(E]->2!E;6%I;"!A
M9&1R97-S97,Z(@IM<V=S='(@(D5L96MT<F]N:6L@4&]S=&$@061R97-I7VTZ
M(@H*(SH@;&EB+TEN9V\N<&AP.C(X,PIM<V=I9"`B7U-C<FEP="(*;7-G<W1R
M(")?0F5T:6LB"@HC.B!L:6(O26YG;RYP:'`Z,C<W"FUS9VED(")?5F%C871I
M;VXB"FUS9W-T<B`B7U1A=&EL(@H*(SH@;&EB+TEN9V\N<&AP.C(W,0IM<V=I
M9"`B7U=H:71E;&ES="(*;7-G<W1R(")?0F5Y87H@3&ES=&4B"@HC.B!T96UP
M;&%T97,O<G5L92]F:6QT97(N:6YC.C0*;7-G:60@(F%N9"(*;7-G<W1R(")V
M92(*"B,Z(&9I;'1E<G,N<&AP.C$V,@IM<V=I9"`B9FEE;&0B"FUS9W-T<B`B
M86QA;B(*"B,Z(&9I;'1E<G,N<&AP.C$V,@IM<V=I9"`B;6%T8V@B"FUS9W-T
M<B`B9?YL9?YE;B(*"B,Z('1E;7!L871E<R]R=6QE+V9I;'1E<BYI;F,Z-`IM
M<V=I9"`B;W(B"FUS9W-T<B`B=F5Y82(*"B,Z(&QI8B]38W)I<'0O<')O8VUA
M:6PN<&AP.C$R-@IM<V=I9"`B<')O8VUA:6P@<V-R:7!T(&=E;F5R871E9"!B
M>2!);F=O(@IM<V=S='(@(DEN9V\@=&%R86;];F1A;B!Y87)A=/UL86X@<')O
M8VUA:6P@8F5T:?!I(@H*(SH@;&EB+U-C<FEP="]S:65V92YP:'`Z,3$Q"FUS
M9VED(")S:65V92!F:6QT97(@9V5N97)A=&5D(&)Y($EN9V\B"FUS9W-T<B`B
M26YG;R!T87)A9OUN9&%N('EA<F%T_6QA;B!S:65V92!S_'IG96-I(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;F=O+VQI8B\`````````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4P
M`#`Q-C$R,P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&EB+TE-05`O
M````````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-#<`,#$V-C4W`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6YG;R]L:6(O24U!4"]396%R8V@N<&AP````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-#<W-P`Q,#0Q-S,V,C<T-P`P,C`V,3$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92`G2&]R9&4O24U!4"]396%R8V@N<&AP)SL*"B\J*@H@
M*B!4:&4@26YG;U])34%07U-E87)C:#HZ(&-L87-S(&5X=&5N9',@=&AE($E-
M05!?4V5A<F-H(&-L87-S(&EN(&]R9&5R('1O"B`J('!R;W9I9&4@;F5C97-S
M87)Y(&)U9R!F:7AE<R!T;R!E;G-U<F4@8F%C:W=A<F1S(&-O;7!A=&EB:6QI
M='D@=VET:"!(;W)D90H@*B`S+C`N"B`J"B`J("1(;W)D93H@:6YG;R]L:6(O
M24U!4"]396%R8V@N<&AP+'8@,2XQ+C(N,B`R,#`V+S`R+S$U(#$W.C$W.C0Y
M('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#8@36EC:&%E;"!3
M;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=0
M3"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!);F=O(#$N,0H@*B!`<&%C:V%G92!(;W)D95])34%0"B`J
M+PIC;&%S<R!);F=O7TE-05!?4V5A<F-H(&5X=&5N9',@24U!4%]396%R8V@@
M>PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@
M9VQO8F%L($EN9V]?24U!4%]396%R8V@@;V)J96-T+"!O;FQY(&-R96%T:6YG
M"B`@("`@*B!I="!I9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97(@
M87)R87DN("!)="!M=7-T(&-O;G1A:6X@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@9F]L;&]W:6YG(&5L96UE;G1S.@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("=I;6%P)R`M($%N(&]P96X@24U!4"!S=')E86T@
M<F5S;W5R8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1O8FIE8W0[
M"@H@("`@("`@(&EF("@A:7-S970H)&]B:F5C="DI('L*("`@("`@("`@("`@
M+RH@07)E('=E('5S:6YG(&$@4$]0(&UA:6QB;W@_("HO"B`@("`@("`@("`@
M("1O8B`]($!I;6%P7V-H96-K*"1P87)A;7-;)VEM87`G72D["B`@("`@("`@
M("`@("1P;W`S(#T@*'-T<FES='(H)&]B+3Y$<FEV97(L("=P;W`S)RD@(3T]
M(&9A;'-E*3L*("`@("`@("`@("`@)&]B:F5C="`](&YE=R!);F=O7TE-05!?
M4V5A<F-H*&%R<F%Y*"=P;W`S)R`]/B`D<&]P,RDI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1O8FIE8W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M96%R8VAE<R!M97-S86=E<R!B>2!!3$P@:&5A9&5R<R`H<F%T:&5R('1H86X@
M=&AE(&QI;6ET960@<V5T('!R;W9I9&5D"B`@("`@*B!B>2!I;6%P7W-E87)C
M:"@I*2X*("`@("`J"B`@("`@*B!`<V5E($E-05!?4V5A<F-H.CIS96%R8VA-
M86EL8F]X*"D*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H36%I;&)O>"@D
M<75E<GDL("8D:6UA<"P@)&UB;W@I"B`@("!["B`@("`@("`@+RH@0VQE87(@
M=&AE('-E87)C:"!F;&%G+B`J+PH@("`@("`@("1T:&ES+3Y?<V5A<F-H9FQA
M9R`](#`["@H@("`@("`@(&EF("@A)'1H:7,M/E]P87)A;7-;)W!O<#,G72D@
M>PH@("`@("`@("`@("!`:6UA<%]R96]P96XH)&EM87`L("1M8F]X*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E87)C:$UA:6QB;W@H
M)'%U97)Y+"`D:6UA<"P@)&UB;W@I.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!)
M;F=O7TE-05!?4V5A<F-H7U%U97)Y.CH@8VQA<W,@97AT96YD<R!T:&4@24U!
M4%]396%R8VA?475E<GD@8VQA<W,@:6X*("H@;W)D97(@=&\@<')O=FED92!N
M96-E<W-A<GD@8G5G(&9I>&5S('1O(&5N<W5R92!B86-K=V%R9',@8V]M<&%T
M:6)I;&ET>2!W:71H"B`J($AO<F1E(#,N,"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M26YG;R`Q+C$*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@26YG
M;U])34%07U-E87)C:%]1=65R>2!E>'1E;F1S($E-05!?4V5A<F-H7U%U97)Y
M('L*"B`@("`O*BH*("`@("`J($)U:6QD<R!T:&4@24U!4"!S96%R8V@@<75E
M<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD*"D*("`@('L*("`@("`@
M("`D<V5A<F-H(#T@<&%R96YT.CIB=6EL9"@I.PH@("`@("`@(&EF("AE;7!T
M>2@D<V5A<F-H*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M;W(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-E87)C:#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D<V5A<F-H(#T@)FYE=R!S=&1#;&%S<SL*
M("`@("`@("`@("`@)'-E87)C:"T^9FQA9W,@/2!N=6QL.PH@("`@("`@("`@
M("`D<V5A<F-H+3YN;W0@/2!F86QS93L*("`@("`@("`@("`@)'-E87)C:"T^
M9G5L;'%U97)Y(#T@)'-E87)C:"T^<75E<GD@/2`G04Q,)SL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1S96%R8V@["B`@("!]"GT*`"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6YG;R]L:6(O4V-R:7!T+P``````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<T
M-P`P,3<S-S4`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQI8B]38W)I
M<'0O<')O8VUA:6PN<&AP````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#4Q,#$W`#$P-#$W,S8R-S0W`#`R,3<Q-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($EN9V]?
M4V-R:7!T7W!R;V-M86EL.CH@8VQA<W,@<F5P<F5S96YT<R!A(%!R;V-M86EL
M('-C<FEP="!G96YE<F%T;W(N"B`J"B`J("1(;W)D93H@:6YG;R]L:6(O4V-R
M:7!T+W!R;V-M86EL+G!H<"QV(#$N-#8N,3`N,3,@,C`P-B\P,2\S,2`R,#HP
M,#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!"<F5N
M="!*+B!.;W)D<75I<W0@/&)J;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@0F5N($-H879E="`\8F5N0&-H879E="YN970^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN
M<&AP+@H@*@H@*B!`875T:&]R("!"<F5N="!*+B!.;W)D<75I<W0@/&)J;D!H
M;W)D92YO<F<^"B`J($!A=71H;W(@($)E;B!#:&%V970@/&)E;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($EN9V\@,"XQ"B`J($!P86-K86=E($EN9V\*("HO
M"F-L87-S($EN9V]?4V-R:7!T7W!R;V-M86EL(&5X=&5N9',@26YG;U]38W)I
M<'0@>PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@86-T:6]N<R!A;&QO
M=V5D("AI;7!L96UE;G1E9"D@9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?86-T:6]N<R`](&%R
M<F%Y*`H@("`@("`@($E.1T]?4U1/4D%'15]!0U1)3TY?2T5%4"P*("`@("`@
M("!)3D=/7U-43U)!1T5?04-424].7TU/5D4L"B`@("`@("`@24Y'3U]35$]2
M04=%7T%#5$E/3E]$25-#05)$+`H@("`@("`@($E.1T]?4U1/4D%'15]!0U1)
M3TY?4D5$25)%0U0L"B`@("`@("`@24Y'3U]35$]204=%7T%#5$E/3E]2141)
M4D5#5$M%15`L"B`@("`@("`@24Y'3U]35$]204=%7T%#5$E/3E]214I%0U0*
M("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%T96=O<FEE<R!O9B!F:6QT
M97)I;F<@86QL;W=E9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V-A=&5G;W)I97,@/2!A<G)A>2@*("`@("`@("!)3D=/
M7U-43U)!1T5?04-424].7T),04-+3$E35"P*("`@("`@("!)3D=/7U-43U)!
M1T5?04-424].7U=(251%3$E35"P*("`@("`@("!)3D=/7U-43U)!1T5?04-4
M24].7U9!0T%424].+`H@("`@("`@($E.1T]?4U1/4D%'15]!0U1)3TY?1D]2
M5T%21`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!T>7!E<R!O9B!T97-T
M<R!A;&QO=V5D("AI;7!L96UE;G1E9"D@9F]R('1H:7,@9')I=F5R+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?='EP97,@
M/2!A<G)A>2@*("`@("`@("!)3D=/7U-43U)!1T5?5%E015](14%$15(L"B`@
M("`I.PH*("`@("\J*@H@("`@("H@02!L:7-T(&]F(&%N>2!S<&5C:6%L('1Y
M<&5S('1H870@=&AI<R!D<FEV97(@<W5P<&]R=',N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S<&5C:6%L7W1Y<&5S(#T@
M87)R87DH"B`@("`@("`@)T1E<W1I;F%T:6]N)RP*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!4:&4@;&ES="!O9B!T97-T<R!A;&QO=V5D("AI;7!L96UE;G1E
M9"D@9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?=&5S=',@/2!A<G)A>2@*("`@("`@("`G8V]N
M=&%I;G,G+`H@("`@("`@("=B96=I;G,@=VET:"<L"B`@("`@("`@)V5N9',@
M=VET:"<L"B`@("`@("`@)W)E9V5X)PH@("`@*3L*"B`@("`O*BH*("`@("`J
M($-A;B!T97-T<R!B92!C87-E('-E;G-I=&EV93\*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V%S97-E;G-I=&EV92`]
M('1R=64["@H@("`@+RHJ"B`@("`@*B!$;V5S('1H92!D<FEV97(@<W5P<&]R
M="!T:&4@<W1O<"US8W)I<'0@;W!T:6]N/PH@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S=7!P;W)T4W1O<%-C<FEP="`]
M('1R=64["@H@("`@+RHJ"B`@("`@*B!$;V5S('1H92!D<FEV97(@<F5Q=6ER
M92!A('-C<FEP="!F:6QE('1O(&)E(&=E;F5R871E9#\*("`@("`J"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<V-R:7!T9FEL92`]
M('1R=64["@H@("`@+RHJ"B`@("`@*B!4:&4@<F5C:7!E<R!T:&%T(&UA:V4@
M=7`@=&AE(&-O9&4N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]R96-I<&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!S8W)I<'0@<')E=FEO=7-L>2!G96YE<F%T960@=VET:"!G
M96YE<F%T92@I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M<')O8VUA:6P@<V-R:7!T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T-O9&4H
M*0H@("`@>PH@("`@("`@("1C;V1E(#T@)R<["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]R96-I<&5S(&%S("1I=&5M*2!["B`@("`@("`@("`@("1C;V1E
M("X]("1I=&5M+3YG96YE<F%T92@I("X@(EQN(CL*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N(')T<FEM*"1C;V1E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E<R!T:&4@<')O8VUA:6P@<V-R:7!T('1O(&1O('1H92!F:6QT
M97)I;F<@<W!E8VEF:65D(&EN('1H90H@("`@("H@<G5L97,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P<F]C;6%I;"!S8W)I<'0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E*"D*("`@('L*("`@("`@("`D
M9FEL=&5R<R`]("8D1TQ/0D%,4ULG:6YG;U]S=&]R86=E)UTM/G)E=')I979E
M*$E.1T]?4U1/4D%'15]!0U1)3TY?1DE,5$524RD["@H@("`@("`@("1T:&ES
M+3YA9&1)=&5M*&YE=R!0<F]C;6%I;%]#;VUM96YT*%\H(G!R;V-M86EL('-C
M<FEP="!G96YE<F%T960@8GD@26YG;R(I("X@)R`H)R`N(&1A=&4H)T8@:BP@
M62P@9SII(&$G*2`N("<I)RDI.PH*("`@("`@("`O*B!!9&0@=F%R:6%B;&4@
M:6YF;W)M871I;VXL(&EF('!R97-E;G0N("HO"B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG=F%R:6%B;&5S)UTI("8F"B`@("`@("`@("`@
M(&ES7V%R<F%Y*"1T:&ES+3Y?<&%R86US6R=V87)I86)L97,G72DI('L*("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;)W9A<FEA8FQE<R==
M(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D
M9$ET96TH;F5W(%!R;V-M86EL7U9A<FEA8FQE*&%R<F%Y*"=N86UE)R`]/B`D
M:V5Y+"`G=F%L=64G(#T^("1V86PI*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1F:6QT97)S+3YG971&:6QT97)L:7-T
M*"D@87,@)&9I;'1E<BD@>PH@("`@("`@("`@("!S=VET8V@@*"1F:6QT97);
M)V%C=&EO;B==*2!["B`@("`@("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#
M5$E/3E]"3$%#2TQ)4U0Z"B`@("`@("`@("`@("`@("`D=&AI<RT^9V5N97)A
M=&5";&%C:VQI<W0H(65M<'1Y*"1F:6QT97);)V1I<V%B;&4G72DI.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E($E.1T]?4U1/
M4D%'15]!0U1)3TY?5TA)5$5,25-4.@H@("`@("`@("`@("`@("`@)'1H:7,M
M/F=E;F5R871E5VAI=&5L:7-T*"%E;7!T>2@D9FEL=&5R6R=D:7-A8FQE)UTI
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!)
M3D=/7U-43U)!1T5?04-424].7U9!0T%424]..@H@("`@("`@("`@("`@("`@
M)'1H:7,M/F=E;F5R871E5F%C871I;VXH(65M<'1Y*"1F:6QT97);)V1I<V%B
M;&4G72DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E($E.1T]?4U1/4D%'15]!0U1)3TY?1D]25T%21#H*("`@("`@("`@("`@
M("`@("1T:&ES+3YG96YE<F%T949O<G=A<F0H(65M<'1Y*"1F:6QT97);)V1I
M<V%B;&4G72DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1F:6QT
M97);)V%C=&EO;B==+"`D=&AI<RT^7V%C=&EO;G,I*2!["B`@("`@("`@("`@
M("`@("`@("`@+RH@0W)E871E(&9I;'1E<B!I9B!U<VEN9R!!3D0N("HO"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1F:6QT97);)V-O;6)I;F4G72`]/2!)
M3D=/7U-43U)!1T5?0T]-0DE.15]!3$PI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E8VEP92`](&YE=R!0<F]C;6%I;%]296-I<&4H)&9I;'1E<BP@
M)'1H:7,M/E]P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(21F:6QT97);)W-T;W`G72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E8VEP92T^861D1FQA9R@G8R<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QT
M97);)V-O;F1I=&EO;G,G72!A<R`D8V]N9&ET:6]N*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5C:7!E+3YA9&1#;VYD:71I;VXH)&-O;F1I
M=&EO;BD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9$ET96TH;F5W(%!R;V-M86EL7T-O;6UE
M;G0H)&9I;'1E<ELG;F%M92==+"`A96UP='DH)&9I;'1E<ELG9&ES86)L92==
M*2P@=')U92DI.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D
M271E;2@D<F5C:7!E*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`O*B!#<F5A=&4@9FEL=&5R(&EF('5S
M:6YG($]2("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&1)
M=&5M*&YE=R!0<F]C;6%I;%]#;VUM96YT*"1F:6QT97);)VYA;64G72P@(65M
M<'1Y*"1F:6QT97);)V1I<V%B;&4G72DL('1R=64I*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&QO;W`@/2`P.PH@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9FEL=&5R6R=C;VYD:71I;VYS)UT@87,@)&-O;F1I=&EO
M;BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E8VEP92`]("9N
M97<@4')O8VUA:6Q?4F5C:7!E*"1F:6QT97(L("1T:&ES+3Y?<&%R86US*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;&]O<"LK*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E8VEP92T^861D1FQA
M9R@G12<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"$D9FEL=&5R6R=S=&]P)UTI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5C:7!E+3YA9&1&
M;&%G*"=C)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5C:7!E+3YA9&1#;VYD:71I;VXH
M)&-O;F1I=&EO;BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^861D271E;2@D<F5C:7!E*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YT
M;T-O9&4H*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@
M<')O8VUA:6P@<V-R:7!T('1O(&AA;F1L92!T:&4@8FQA8VML:7-T('-P96-I
M9FEE9"!I;@H@("`@("H@=&AE(')U;&5S+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1D:7-A8FQE("!$:7-A8FQE('1H92!B;&%C:VQI<W0_"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E0FQA8VML:7-T*"1D:7-A8FQE
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&)L86-K;&ES="`]("8D1TQ/0D%,
M4ULG:6YG;U]S=&]R86=E)UTM/G)E=')I979E*$E.1T]?4U1/4D%'15]!0U1)
M3TY?0DQ!0TM,25-4*3L*("`@("`@("`D8FQ?861D<B`]("1B;&%C:VQI<W0M
M/F=E=$)L86-K;&ES="@I.PH@("`@("`@("1B;%]F;VQD97(@/2`D8FQA8VML
M:7-T+3YG971";&%C:VQI<W1&;VQD97(H*3L*"B`@("`@("`@)&)L7W1Y<&4@
M/2`H96UP='DH)&)L7V9O;&1E<BDI(#\@24Y'3U]35$]204=%7T%#5$E/3E]$
M25-#05)$(#H@24Y'3U]35$]204=%7T%#5$E/3E]-3U9%.PH*("`@("`@("!I
M9B`H(65M<'1Y*"1B;%]A9&1R*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D
M271E;2AN97<@4')O8VUA:6Q?0V]M;65N="A?*")";&%C:VQI<W1E9"!!9&1R
M97-S97,B*2P@)&1I<V%B;&4L('1R=64I*3L*("`@("`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"=A8W1I;VXM=F%L=64G(#T^("1B;%]F;VQD97(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G86-T:6]N)R`]/B`D8FQ?='EP92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D:7-A8FQE)R`]/B`D9&ES
M86)L92D["@H@("`@("`@("`@("!F;W)E86-H("@D8FQ?861D<B!A<R`D861D
M<F5S<RD@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<RDI
M('L*("`@("`@("`@("`@("`@("`@("`D<F5C:7!E(#T@;F5W(%!R;V-M86EL
M7U)E8VEP92@D<&%R86US+"`D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@("`@
M("`@("`@("`@)')E8VEP92T^861D0V]N9&ET:6]N*&%R<F%Y*"=F:65L9"<@
M/3X@)T9R;VTG+"`G=F%L=64G(#T^("1A9&1R97-S+"`G;6%T8V@G(#T^("=A
M9&1R97-S)RDI.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&1)=&5M
M*"1R96-I<&4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!P
M<F]C;6%I;"!S8W)I<'0@=&\@:&%N9&QE('1H92!W:&ET96QI<W0@<W!E8VEF
M:65D(&EN"B`@("`@*B!T:&4@<G5L97,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&1I<V%B;&4@($1I<V%B;&4@=&AE('=H:71E;&ES=#\*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&57:&ET96QI<W0H)&1I<V%B;&4@
M/2!F86QS92D*("`@('L*("`@("`@("`D=VAI=&5L:7-T(#T@)B1'3$]"04Q3
M6R=I;F=O7W-T;W)A9V4G72T^<F5T<FEE=F4H24Y'3U]35$]204=%7T%#5$E/
M3E]72$E414Q)4U0I.PH@("`@("`@("1W;%]A9&1R(#T@)'=H:71E;&ES="T^
M9V5T5VAI=&5L:7-T*"D["@H@("`@("`@(&EF("@A96UP='DH)'=L7V%D9'(I
M*2!["B`@("`@("`@("`@("1T:&ES+3YA9&1)=&5M*&YE=R!0<F]C;6%I;%]#
M;VUM96YT*%\H(E=H:71E;&ES=&5D($%D9')E<W-E<R(I+"`D9&ES86)L92P@
M=')U92DI.PH@("`@("`@("`@("!F;W)E86-H("@D=VQ?861D<B!A<R`D861D
M<F5S<RD@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<RDI
M('L*("`@("`@("`@("`@("`@("`@("`D<F5C:7!E(#T@;F5W(%!R;V-M86EL
M7U)E8VEP92AA<G)A>2@G86-T:6]N)R`]/B!)3D=/7U-43U)!1T5?04-424].
M7TM%15`L("=D:7-A8FQE)R`]/B`D9&ES86)L92DL("1T:&ES+3Y?<&%R86US
M*3L*("`@("`@("`@("`@("`@("`@("`D<F5C:7!E+3YA9&1#;VYD:71I;VXH
M87)R87DH)V9I96QD)R`]/B`G1G)O;2<L("=V86QU92<@/3X@)&%D9')E<W,L
M("=M871C:"<@/3X@)V%D9')E<W,G*2D["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F%D9$ET96TH)')E8VEP92D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M96YE<F%T97,@=&AE('!R;V-M86EL('-C<FEP="!T;R!H86YD;&4@=F%C871I
M;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<V%B;&4@($1I
M<V%B;&4@=F%C871I;VX_"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E
M5F%C871I;VXH)&1I<V%B;&4@/2!F86QS92D*("`@('L*("`@("`@("`D=F%C
M871I;VX@/2`F)$=,3T)!3%-;)VEN9V]?<W1O<F%G92==+3YR971R:65V92A)
M3D=/7U-43U)!1T5?04-424].7U9!0T%424].*3L*("`@("`@("`D861D<F5S
M<V5S(#T@)'9A8V%T:6]N+3YG971686-A=&EO;D%D9')E<W-E<R@I.PH@("`@
M("`@("1A8W1I;VYV86P@/2!A<G)A>2@G861D<F5S<V5S)R`]/B`D861D<F5S
M<V5S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W5B:F5C="<@/3X@
M)'9A8V%T:6]N+3YG971686-A=&EO;E-U8FIE8W0H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1A>7,G(#T^("1V86-A=&EO;BT^9V5T5F%C871I
M;VY$87ES*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96%S;VXG
M(#T^("1V86-A=&EO;BT^9V5T5F%C871I;VY296%S;VXH*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VEG;F]R96QI<W0G(#T^("1V86-A=&EO;BT^
M9V5T5F%C871I;VY)9VYO<F5L:7-T*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=E>&-L=61E<R<@/3X@)'9A8V%T:6]N+3YG971686-A=&EO;D5X
M8VQU9&5S*"DI.PH*("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S97,I*2![
M"B`@("`@("`@("`@("1T:&ES+3YA9&1)=&5M*&YE=R!0<F]C;6%I;%]#;VUM
M96YT*%\H(E9A8V%T:6]N(BDL("1D:7-A8FQE+"!T<G5E*2D["B`@("`@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@G86-T:6]N)R`]/B!)3D=/7U-43U)!1T5?
M04-424].7U9!0T%424].+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V%C=&EO;BUV86QU92<@/3X@)&%C=&EO;G9A;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D:7-A8FQE)R`]/B`D9&ES86)L92D["B`@("`@("`@
M("`@("1R96-I<&4@/2!N97<@4')O8VUA:6Q?4F5C:7!E*"1P87)A;7,L("1T
M:&ES+3Y?<&%R86US*3L*("`@("`@("`@("`@)'1H:7,M/F%D9$ET96TH)')E
M8VEP92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A
M=&5S('1H92!P<F]C;6%I;"!S8W)I<'0@=&\@:&%N9&QE(&UA:6P@9F]R=V%R
M9',N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<V%B;&4@($1I
M<V%B;&4@9F]R=V%R9&EN9S\*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A
M=&5&;W)W87)D*"1D:7-A8FQE(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&9O
M<G=A<F0@/2`F)$=,3T)!3%-;)VEN9V]?<W1O<F%G92==+3YR971R:65V92A)
M3D=/7U-43U)!1T5?04-424].7T9/4E=!4D0I.PH@("`@("`@("1A9&1R97-S
M97,@/2`D9F]R=V%R9"T^9V5T1F]R=V%R9$%D9')E<W-E<R@I.PH*("`@("`@
M("!I9B`H(65M<'1Y*"1A9&1R97-S97,I*2!["B`@("`@("`@("`@("1T:&ES
M+3YA9&1)=&5M*&YE=R!0<F]C;6%I;%]#;VUM96YT*%\H(D9O<G=A<F1S(BDL
M("1D:7-A8FQE+"!T<G5E*2D["B`@("`@("`@("`@("1P87)A;7,@/2!A<G)A
M>2@G86-T:6]N)R`]/B!)3D=/7U-43U)!1T5?04-424].7T9/4E=!4D0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G86-T:6]N+79A;'5E)R`]/B`D
M861D<F5S<V5S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1I<V%B
M;&4G(#T^("1D:7-A8FQE*3L*("`@("`@("`@("`@)')E8VEP92`](&YE=R!0
M<F]C;6%I;%]296-I<&4H)'!A<F%M<RP@)'1H:7,M/E]P87)A;7,I.PH@("`@
M("`@("`@("!I9B`H)&9O<G=A<F0M/F=E=$9O<G=A<F1+965P*"DI('L*("`@
M("`@("`@("`@("`@("1R96-I<&4M/F%D9$9L86<H)V,G*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^861D271E;2@D<F5C:7!E*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N(&ET96T@=&\@
M=&AE(')E8VEP92!L:7-T+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@
M)&ET96T@(%1H92!I=&5M('1O(&%D9"!T;R!T:&4@<F5C:7!E(&QI<W0N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!4:&4@;V)J96-T('-H;W5L9"!H
M879E(&$@9V5N97)A=&4H*2!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D271E;2@D:71E;2D*("`@('L*("`@("`@("`D=&AI<RT^7W)E8VEP
M97-;72`]("1I=&5M.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!0<F]C;6%I;%]#
M;VUM96YT.CH@8VQA<W,@<F5P<F5S96YT<R!A(%!R;V-M86EL(&-O;6UE;G0N
M("!4:&ES(&ES"B`J(&$@<')E='1Y('-I;7!L92!C;&%S<RP@8G5T(&ET(&UA
M:V5S('1H92!C;V1E(&EN($EN9V]?4V-R:7!T7W!R;V-M86EL.CH*("H@8VQE
M86YE<B!A<R!I="!P<F]V:61E<R!A(&=E;F5R871E*"D@9G5N8W1I;VX@86YD
M(&-A;B!B92!A9&1E9"!T;R!T:&4*("H@<F5C:7!E(&QI<W0@=&AE('-A;64@
M=V%Y(&%S(&$@<F5C:7!E(&-A;B!B92X*("H*("H@0&%U=&AO<B`@0F5N($-H
M879E="`\8F5N0&-H879E="YN970^"B`J($!S:6YC92`@($EN9V\@,2XP"B`J
M($!P86-K86=E($EN9V\*("HO"F-L87-S(%!R;V-M86EL7T-O;6UE;G0@>PH*
M("`@("\J*@H@("`@("H@5&AE(&-O;6UE;G0@=&5X="X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VUM96YT(#T@)R<[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W('!R;V-M86EL(&-O
M;6UE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]M;65N="`@
M($-O;6UE;G0@=&\@8F4@9V5N97)A=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&1I<V%B;&4@($]U='!U="`G1$E304),140G(&-O;6UE;G0_"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D:&5A9&5R("`@3W5T<'5T(&$@)VAE861E<B<@
M8V]M;65N=#\*("`@("`J+PH@("`@9G5N8W1I;VX@4')O8VUA:6Q?0V]M;65N
M="@D8V]M;65N="P@)&1I<V%B;&4@/2!F86QS92P@)&AE861E<B`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("@D9&ES86)L92D@>PH@("`@("`@("`@("`D
M8V]M;65N="`](%\H(D1)4T%"3$5$.B`B*2`N("1C;VUM96YT.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1H96%D97(I('L*("`@("`@("`@("`@)'1H:7,M
M/E]C;VUM96YT("X]("(C(R,C(R`D8V]M;65N="`C(R,C(R(["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]C;VUM96YT("X]("(C("1C
M;VUM96YT(CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!C;VUM96YT('-T;W)E9"!B>2!T:&ES(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;6UE;G0@<W1O<F5D(&)Y
M('1H:7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]M;65N=#L*("`@('T*
M"GT*"B\J*@H@*B!4:&4@4')O8VUA:6Q?4F5C:7!E.CH@8VQA<W,@<F5P<F5S
M96YT<R!A(%!R;V-M86EL(')E8VEP92X*("H*("H@0&%U=&AO<B`@0F5N($-H
M879E="`\8F5N0&-H879E="YN970^"B`J($!S:6YC92`@($EN9V\@,2XP"B`J
M($!P86-K86=E($EN9V\*("HO"F-L87-S(%!R;V-M86EL7U)E8VEP92!["@H@
M("`@=F%R("1?86-T:6]N(#T@87)R87DH*3L*("`@('9A<B`D7V-O;F1I=&EO
M;G,@/2!A<G)A>2@I.PH@("`@=F%R("1?9&ES86)L92`]("<G.PH@("`@=F%R
M("1?9FQA9W,@/2`G)SL*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["B`@
M("!V87(@)%]V86QI9"`]('1R=64["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1S(&$@;F5W('!R;V-M86EL(')E8VEP92X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@("`@("`@07)R87D@;V8@<&%R86UE=&5R<RX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%)%455)4D5$
M($9)14Q$4SH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G86-T:6]N)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@3U!424].04P@1DE%3$13.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=A8W1I;VXM=F%L=64G("AO;FQY('5S960@:68@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%C=&EO
M;B<@<F5Q=6ER97,@:70I"B`@("`@*B!`<&%R86T@87)R87D@)'-C<FEP='!A
M<F%M<R`@07)R87D@;V8@<&%R86UE=&5R<R!P87-S960@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!);F=O7U-C<FEP=%]P<F]C;6%I
M;#HZ+@H@("`@("HO"B`@("!F=6YC=&EO;B!0<F]C;6%I;%]296-I<&4H)'!A
M<F%M<R`](&%R<F%Y*"DL("1S8W)I<'1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9&ES86)L92`]("%E;7!T>2@D<&%R86US6R=D
M:7-A8FQE)UTI.PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'-C<FEP='!A
M<F%M<SL*"B`@("`@("`@<W=I=&-H("@D<&%R86US6R=A8W1I;VXG72D@>PH@
M("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]+1450.@H@("`@("`@
M("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)R1$149!54Q4)SL*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]-
M3U9%.@H@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)'1H:7,M/G!R
M;V-M86EL4&%T:"@D<&%R86US6R=A8W1I;VXM=F%L=64G72D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?
M1$E30T%21#H*("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<O9&5V
M+VYU;&PG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)3D=/
M7U-43U)!1T5?04-424].7U)%1$E214-4.@H@("`@("`@("`@("`D=&AI<RT^
M7V%C=&EO;EM=(#T@)R$@)R`N("1P87)A;7-;)V%C=&EO;BUV86QU92==.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?
M04-424].7U)%1$E214-42T5%4#H*("`@("`@("`@("`@)'1H:7,M/E]A8W1I
M;VY;72`]("=[)SL*("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@
M(#HP(&,G.PH@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)R`@(2`G
M("X@)'!A<F%M<ULG86-T:6]N+79A;'5E)UT["B`@("`@("`@("`@("1T:&ES
M+3Y?86-T:6]N6UT@/2`G)SL*("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;
M72`]("<@(#HP)SL*("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@
M("1$149!54Q4)SL*("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("=]
M)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24Y'3U]35$]2
M04=%7T%#5$E/3E]214I%0U0Z"B`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N
M6UT@/2`G>R<["B`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N6UT@/2`G("!%
M6$E40T]$13TG("X@)'!A<F%M<ULG86-T:6]N+79A;'5E)UT["B`@("`@("`@
M("`@("1T:&ES+3Y?86-T:6]N6UT@/2`G("!(3U-4/2)N;RYA9&1R97-S+FAE
M<F4B)SL*("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("=])SL*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#
M5$E/3E]604-!5$E/3CH*("`@("`@("`@("`@)&1A>7,@/2`D<&%R86US6R=A
M8W1I;VXM=F%L=64G75LG9&%Y<R==.PH@("`@("`@("`@("`D=&AI<RT^7V%C
M=&EO;EM=(#T@)WLG.PH@("`@("`@("`@("!F;W)E86-H("@D<&%R86US6R=A
M8W1I;VXM=F%L=64G75LG861D<F5S<V5S)UT@87,@)&%D9')E<W,I('L*("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W,I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@($9)3$5$051%/6!L
M<R`M;&-N("TM=&EM92US='EL93TK)7,@7"<N=F%C871I;VXN)R`N("1A9&1R
M97-S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@
M)UPG('P@87=K(%PG>R!P<FEN="`D-B`K("@G"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)&1A>7,@*B`X-C0P,"`N("<I('U<
M)V`G.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N6UT@/2`G
M("!$051%/6!D871E("LE<V`G.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?86-T:6]N6UT@/2`G("!$54U-63U@=&5S="`D1DE,141!5$4@+6QE("1$
M051%)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N
M)R`F)B!R;2!<)RYV86-A=&EO;BXG("X@)&%D9')E<W,@+B=<)V`G.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N6UT@/2`G)SL*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)R`@.C`@5VAC.B!V
M86-A=&EO;BYL;V-K)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%C
M=&EO;EM=(#T@)R`@*B`D7E1O.B@N*EP\*3\G("X@)&%D9')E<W,["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@("H@(5Y8+4QO
M;W`Z("<@+B`D861D<F5S<SL*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U
M;G0H)'!A<F%M<ULG86-T:6]N+79A;'5E)UU;)V5X8VQU9&5S)UTI(#X@,"D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%R86US6R=A
M8W1I;VXM=F%L=64G75LG97AC;'5D97,G70H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<R`D97AC;'5D92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D97AC;'5D92DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)R`@
M*B`A7D9R;VTN*B<@+B`D97AC;'5D93L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<ULG
M86-T:6]N+79A;'5E)UU;)VEG;F]R96QI<W0G72D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)R`@*B`A7D923TU?1$%%
M34].)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)')E87-O;B`]("1P87)A;7-;)V%C=&EO;BUV86QU92==6R=R96%S;VXG
M73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)R`@
M?"!F;W)M86EL("UR1"`X,3DR("YV86-A=&EO;BXG("X@)&%D9')E<W,["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@("`@.C`@
M96AC)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@
M)R`@("!\("AF;W)M86EL("UR22)0<F5C961E;F-E.B!J=6YK(B!<7"<["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@("`@("`@
M+4$B6"U,;V]P.B`G("X@)&%D9')E<W,@+B`G(B!<7"<["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@("`@("`@+6DB4W5B:F5C
M=#H@)R`N("1P87)A;7-;)V%C=&EO;BUV86QU92==6R=S=6)J96-T)UT@+B`G
M(B`[(%Q<)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=
M(#T@)R`@("`@("!E8VAO("(G("X@<W1R7W)E<&QA8V4H(EQR7&XB+"`G(CL@
M96-H;R`B)RP@)')E87-O;BD@+B`G(B!<7"<["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A8W1I;VY;72`]("<@("`@("`I('P@)%-%3D1-04E,("UO
M:2`M="<["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]
M("<G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3Y?86-T:6]N6UT@/2`G?2<["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?1D]25T%21#H*
M("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("=[)SL*("`@("`@("`@
M("`@9F]R96%C:"`H)'!A<F%M<ULG86-T:6]N+79A;'5E)UT@87,@)&%D9')E
M<W,I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W,I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@(#HP
M(&,G.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N6UT@/2`G
M("`A("<@+B`D861D<F5S<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)R`@.C`@)SL*
M("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@("]D978O;G5L;"<[
M"B`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N6UT@/2`G?2<["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED(#T@9F%L<V4["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!F;&%G('1O('1H92!R
M96-I<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FQA9R`@4W1R
M:6YG(&]F(&9L86=S('1O(&%P<&5N9"!T;R!T:&4@8W5R<F5N="!F;&%G<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D1FQA9R@D9FQA9RD*("`@('L*("`@
M("`@("`D=&AI<RT^7V9L86=S("X]("1F;&%G.PH@("`@?0H*("`@("\J*@H@
M("`@("H@061D<R!A(&-O;F1I=&EO;B!T;R!T:&4@<F5C:7!E+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D8V]N9&ET:6]N("!!<G)A>2!O9B!P87)A
M;65T97)S+B!297%U:7)E9"!K97ES(&%R92`G9FEE;&0G"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@86YD("=V86QU92<N("=C87-E)R!I<R!A
M;B!O<'1I;VYA;"!K97DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O;F1I
M=&EO;B@D8V]N9&ET:6]N(#T@87)R87DH*2D*("`@('L*("`@("`@("`D9FQA
M9R`]("@A96UP='DH)&-O;F1I=&EO;ELG8V%S92==*2D@/R`G1"<@.B`G)SL*
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]C;VYD:71I;VYS*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^861D1FQA9R@D9FQA9RD["B`@("`@("`@?0H*("`@
M("`@("`D;6%T8V@@/2`H:7-S970H)&-O;F1I=&EO;ELG;6%T8V@G72DI(#\@
M)&-O;F1I=&EO;ELG;6%T8V@G72`Z(&YU;&P["@H@("`@("`@('-W:71C:"`H
M)&-O;F1I=&EO;ELG9FEE;&0G72D@>PH@("`@("`@(&-A<V4@)T1E<W1I;F%T
M:6]N)SH*("`@("`@("`@("`@)'-T<FEN9R`]("<J(%Y43U\G.PH@("`@("`@
M("`@("`D<')E9FEX(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`D<W1R:6YG(#T@)RH@7B<@+B`D8V]N
M9&ET:6]N6R=F:65L9"==("X@)SHG.PH@("`@("`@("`@("`D<')E9FEX(#T@
M)R`G.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D;6%T8V@I('L*("`@
M("`@("!C87-E("=R96=E>"<Z"B`@("`@("`@("`@("1S=')I;F<@+CT@)'!R
M969I>"`N("1C;VYD:71I;VY;)W9A;'5E)UT["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E("=A9&1R97-S)SH*("`@("`@("`@("`@)'-T<FEN
M9R`N/2`G*"XJ7#PI/R<@+B!Q=6]T96UE=&$H)&-O;F1I=&EO;ELG=F%L=64G
M72D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=B96=I;G,@
M=VET:"<Z"B`@("`@("`@("`@("1S=')I;F<@+CT@)'!R969I>"`N('%U;W1E
M;65T82@D8V]N9&ET:6]N6R=V86QU92==*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)V5N9',@=VET:"<Z"B`@("`@("`@("`@("1S=')I
M;F<@+CT@)RXJ)R`N('%U;W1E;65T82@D8V]N9&ET:6]N6R=V86QU92==*2`N
M("<D)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V-O;G1A
M:6YS)SH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D<W1R:6YG("X]
M("<N*B<@+B!Q=6]T96UE=&$H)&-O;F1I=&EO;ELG=F%L=64G72D["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C;VYD
M:71I;VYS6UT@/2!A<G)A>2@G8V]N9&ET:6]N)R`]/B`D<W1R:6YG+"`G9FQA
M9W,G(#T^("1F;&%G*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E
M<R!P<F]C;6%I;"!C;V1E('1O(')E<')E<V5N="!T:&4@<F5C:7!E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!0<F]C;6%I;"!C;V1E('1O(')E
M<')E<V5N="!T:&4@<F5C:7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE
M<F%T92@I"B`@("!["B`@("`@("`@)&YE<W0@/2`P.PH@("`@("`@("1P<F5F
M:7@@/2`G)SL*("`@("`@("`D=&5X="`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@A)'1H:7,M/E]V86QI9"D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@
M("`@("`@?0H*("`@("`@("`D=&5X=%M=(#T@)SHP("<@+B`D=&AI<RT^7V9L
M86=S.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8V]N9&ET:6]N<R!A<R`D
M8V]N9&ET:6]N*2!["B`@("`@("`@("`@(&EF("@D;F5S="`^(#`I('L*("`@
M("`@("`@("`@("`@("1T97AT6UT@/2!S=')?<F5P96%T*"<@("<L("1N97-T
M("T@,2D@+B`G>R<["B`@("`@("`@("`@("`@("`D=&5X=%M=(#T@<W1R7W)E
M<&5A="@G("`G+"`D;F5S="D@+B`G.C`@)R`N("1C;VYD:71I;VY;)V9L86=S
M)UT["B`@("`@("`@("`@("`@("`D=&5X=%M=(#T@<W1R7W)E<&5A="@G("`G
M+"`D;F5S="D@+B`D8V]N9&ET:6]N6R=C;VYD:71I;VXG73L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T97AT6UT@/2`D8V]N9&ET
M:6]N6R=C;VYD:71I;VXG73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;F5S="LK.PH@("`@("`@('T*"B`@("`@("`@:68@*"TM)&YE<W0@/B`P*2![
M"B`@("`@("`@("`@("1P<F5F:7@@/2!S=')?<F5P96%T*"<@("<L("1N97-T
M*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A8W1I;VX@
M87,@)'9A;"D@>PH@("`@("`@("`@("`D=&5X=%M=(#T@)'!R969I>"`N("1V
M86P["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@)&YE<W0[("1I(#X@
M,#L@)&DM+2D@>PH@("`@("`@("`@("`D=&5X=%M=(#T@<W1R7W)E<&5A="@G
M("`G+"`D:2`M(#$I("X@)WTG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T
M:&ES+3Y?9&ES86)L92D@>PH@("`@("`@("`@("`D8V]D92`]("<G.PH@("`@
M("`@("`@("!F;W)E86-H("@D=&5X="!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("`D8V]M;65N="`](&YE=R!0<F]C;6%I;%]#;VUM96YT*"1V86PI.PH@
M("`@("`@("`@("`@("`@)&-O9&4@+CT@)&-O;6UE;G0M/F=E;F5R871E*"D@
M+B`B7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D8V]D
M92`N(")<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(&EM<&QO9&4H(EQN(BP@)'1E>'0I("X@(EQN(CL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<')O8VUA:6PM<F5A9'D@;6%I
M;&)O>"!P871H+"!C;VYV97)T:6YG($E-05`@9F]L9&5R"B`@("`@*B!P871H
M;F%M92!C;VYV96YT:6]N<R!A<R!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F]L9&5R("!4:&4@24U!4"!F;VQD97(@;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R;V-M86EL(&UA
M:6QB;W@@<&%T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@<')O8VUA:6Q0871H
M*"1F;VQD97(I"B`@("!["B`@("`@("`@+RH@3D]413H@)R1$149!54Q4)R!H
M97)E(&ES(&$@;&ET97)A;"P@;F]T(&$@4$A0('9A<FEA8FQE+B`J+PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<RD@)B8*("`@("`@("`@("`@
M*"1T:&ES+3Y?<&%R86US6R=P871H7W-T>6QE)UT@/3T@)VUA:6QD:7(G*2D@
M>PH@("`@("`@("`@("!I9B`H96UP='DH)&9O;&1E<BD@?'P@*"1F;VQD97(@
M/3T@)TE.0D]8)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`G)$1%1D%5
M3%0G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=6)S='(H)&9O
M;&1E<BP@,"P@-BD@/3T@)TE.0D]8+B<I('L*("`@("`@("`@("`@("`@("1F
M;VQD97(@/2!S=6)S='(H)&9O;&1E<BP@-BD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N("<B)$1%1D%53%0O+B<@+B`D9F]L9&5R("X@)R\B
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H96UP='DH)&9O
M;&1E<BD@?'P@*"1F;VQD97(@/3T@)TE.0D]8)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`G)$1%1D%53%0G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B!S=')?<F5P;&%C92@G("<L("=<("<L("1F;VQD97(I.PH@
M("`@("`@('T*("`@('T*"GT*"B\J*@H@*B!4:&4@4')O8VUA:6Q?5F%R:6%B
M;&4Z.B!C;&%S<R!R97!R97-E;G1S(&$@4')O8VUA:6P@=F%R:6%B;&4N"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@26YG;R`Q+C`*("H@0'!A8VMA
M9V4@26YG;PH@*B\*8VQA<W,@4')O8VUA:6Q?5F%R:6%B;&4@>PH*("`@('9A
M<B`D7VYA;64["B`@("!V87(@)%]V86QU93L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=',@82!N97<@<')O8VUA:6P@=F%R:6%B;&4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%R<F%Y(&]F('!A<F%M971E<G,N
M($5X<&5C=&5D(&9I96QD<R!A<F4@)VYA;64G"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@86YD("=V86QU92<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%!R;V-M86EL7U9A<FEA8FQE*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;F%M92`]("1P87)A;7-;)VYA;64G73L*("`@("`@
M("`D=&AI<RT^7W9A;'5E(#T@)'!A<F%M<ULG=F%L=64G73L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E<R!P<F]C;6%I;"!C;V1E('1O(')E<')E
M<V5N="!T:&4@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%!R;V-M86EL(&-O9&4@=&\@<F5P<F5S96YT('1H92!V87)I86)L92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7VYA;64@+B`G/2<@+B`D=&AI<RT^7W9A;'5E("X@
M(EQN(CL*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN
M9V\O;&EB+U-C<FEP="]I;6%P+G!H<```````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,S4P,3(`,3`T,3<S-C(W-#<`,#(Q,#,R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&4@26YG;U]38W)I<'1?:6UA<#HZ(&-L87-S(')E<')E<V5N=',@86X@
M24U!4"!C;&EE;G0M<VED92!S8W)I<'0*("H@9V5N97)A=&]R+@H@*@H@*B`D
M2&]R9&4Z(&EN9V\O;&EB+U-C<FEP="]I;6%P+G!H<"QV(#$N-#DN,3`N.2`R
M,#`V+S`R+S$R(#(P.C4Y.C,X('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R
M;2YC=7)E8V%N=&DN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*("H*("H@0&%U=&AO<B`@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8W5R96-A;G1I+F]R
M9SX*("H@0'-I;F-E("`@26YG;R`Q+C`*("H@0'!A8VMA9V4@26YG;PH@*B\*
M8VQA<W,@26YG;U]38W)I<'1?:6UA<"!E>'1E;F1S($EN9V]?4V-R:7!T('L*
M"B`@("`O*BH*("`@("`J(%1H92!L:7-T(&]F(&%C=&EO;G,@86QL;W=E9"`H
M:6UP;&5M96YT960I(&9O<B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%C=&EO;G,@/2!A<G)A>2@*
M("`@("`@("!)3D=/7U-43U)!1T5?04-424].7TM%15`L"B`@("`@("`@24Y'
M3U]35$]204=%7T%#5$E/3E]-3U9%+`H@("`@("`@($E.1T]?4U1/4D%'15]!
M0U1)3TY?1$E30T%21"P*("`@("`@("!)3D=/7U-43U)!1T5?04-424].7TU/
M5D5+1450"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(&-A=&5G;W)I97,@
M;V8@9FEL=&5R:6YG(&%L;&]W960N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]C871E9V]R:65S(#T@87)R87DH"B`@("`@
M("`@24Y'3U]35$]204=%7T%#5$E/3E]"3$%#2TQ)4U0L"B`@("`@("`@24Y'
M3U]35$]204=%7T%#5$E/3E]72$E414Q)4U0*("`@("D["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;&ES="!O9B!T97-T<R!A;&QO=V5D("AI;7!L96UE;G1E9"D@
M9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?=&5S=',@/2!A<G)A>2@*("`@("`@("`G8V]N=&%I
M;G,G+"`G;F]T(&-O;G1A:6XG"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE
M('1Y<&5S(&]F('1E<W1S(&%L;&]W960@*&EM<&QE;65N=&5D*2!F;W(@=&AI
M<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]T>7!E<R`](&%R<F%Y*`H@("`@("`@($E.1T]?4U1/4D%'15]4
M65!%7TA%041%4BP*("`@("`@("!)3D=/7U-43U)!1T5?5%E015]325I%+`H@
M("`@("`@($E.1T]?4U1/4D%'15]465!%7T)/1%D*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!$;V5S('1H92!D<FEV97(@<W5P<&]R="!S971T:6YG($E-05`@
M9FQA9W,_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@
M('9A<B`D7W-U<'!O<G1)34%01FQA9W,@/2!T<G5E.PH*("`@("\J*@H@("`@
M("H@1&]E<R!T:&4@9')I=F5R('-U<'!O<G0@=&AE('-T;W`M<V-R:7!T(&]P
M=&EO;C\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?<W5P<&]R=%-T;W!38W)I<'0@/2!T<G5E.PH*("`@("\J*@H@("`@
M("H@5&AI<R!D<FEV97(@8V%N('!E<F9O<FT@;VX@9&5M86YD(&9I;'1E<FEN
M9R`H:6X@9F%C="P@=&AA="!I<R!A;&P*("`@("`J(&ET(&-A;B!D;RDN"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V]N
M9&5M86YD(#T@=')U93L*"B`@("`O*BH*("`@("`J(%!E<F9O<FT@=&AE(&9I
M;'1E<FEN9R!S<&5C:69I960@:6X@=&AE(')U;&5S+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y+B!)
M="!-55-4(&-O;G1A:6XZ"B`@("`@*B`\<')E/@H@("`@("H@)VEM87`G("`@
M("`M+2`@06X@;W!E;B!)34%0('-T<F5A;2X*("`@("`J("=M86EL8F]X)R`@
M+2T@(%1H92!N86UE(&]F('1H92!M86EL8F]X('1O(&9I;'1E<BX*("`@("`J
M(#PO<')E/@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!F:6QT97)I;F<@<&5R9F]R;65D+"!F86QS92!I9B!N;W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!E<F9O<FTH)'!A<F%M<RD*("`@('L*("`@("`@("!G
M;&]B86P@)&EN9V]?<W1O<F%G92P@)&YO=&EF:6-A=&EO;BP@)'!R969S.PH*
M("`@("`@("`D=VAI=&5L:7-T7VED<R`](&%R<F%Y*"D["@H@("`@("`@("\J
M($=E="!T:&4@24U!4%]#86-H92!O8FIE8W0N("HO"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92])34%0+T-A8VAE+G!H<"<["B`@("`@("`@)&EM87!?
M8V%C:&4@/2`F24U!4%]#86-H93HZ<VEN9VQE=&]N*"D["@H@("`@("`@("\J
M($]N;'D@9&\@9FEL=&5R:6YG(&EF.@H@("`@("`@("`@(#$N(%=E(&AA=F4@
M;F]T(&1O;F4@9FEL=&5R:6YG(&)E9F]R92`M;W(M"B`@("`@("`@("`@,BX@
M5&AE(&UA:6QB;W@@:&%S(&-H86YG960@+6]R+0H@("`@("`@("`@(#,N(%1H
M92!R=6QE<R!H879E(&-H86YG960N("HO"B`@("`@("`@)&-A8VAE(#T@)&EM
M87!?8V%C:&4M/F=E=$-A8VAE*"1P87)A;7-;)VEM87`G72P@)'!A<F%M<ULG
M;6%I;&)O>"==+"`G:6YG;V-H86YG92<I.PH@("`@("`@(&EF("@H)&-A8VAE
M("$]/2!F86QS92D@)B8@*"1C86-H92`]/2`D7U-%4U-)3TY;)VEN9V\G75LG
M8VAA;F=E)UTI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["B`@
M("`@("`@<F5Q=6ER95]O;F-E($E.1T]?0D%312`N("<O;&EB+TE-05`O4V5A
M<F-H+G!H<"<["B`@("`@("`@)&EM87!?<V5A<F-H(#T@)DEN9V]?24U!4%]3
M96%R8V@Z.G-I;F=L971O;BAA<G)A>2@G:6UA<"<@/3X@)'!A<F%M<ULG:6UA
M<"==*2D["@H@("`@("`@("\J($=R86(@=&AE(')U;&5S(&QI<W0N("HO"B`@
M("`@("`@)&9I;'1E<G,@/2`F)&EN9V]?<W1O<F%G92T^<F5T<FEE=F4H24Y'
M3U]35$]204=%7T%#5$E/3E]&24Q415)3*3L*"B`@("`@("`@+RH@4VAO=6QD
M('=E(&9I;'1E<B!O;FQY(%MU;EUS965N(&UE<W-A9V5S/R`J+PH@("`@("`@
M("1S965N7V9L86<@/2`D<')E9G,M/F=E=%9A;'5E*"=F:6QT97)?<V5E;B<I
M.PH*("`@("`@("`O*B!3:&]U;&0@=V4@=7-E(&1E=&%I;&5D(&YO=&EF:6-A
M=&EO;B!M97-S86=E<S\@*B\*("`@("`@("`D9&5T86EL;7-G(#T@)'!R969S
M+3YG971686QU92@G<VAO=U]F:6QT97)?;7-G)RD["@H@("`@("`@("\J(%!A
M<G-E('1H<F]U9V@@=&AE(')U;&5S+"!O;F4M8GDM;VYE+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1F:6QT97)S+3YG971&:6QT97)L:7-T*"D@87,@)')U;&4I
M('L*("`@("`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E('1H:7,@:7,@
M82!V86QI9"!R=6QE(&%N9"!T:&%T('1H92!R=6QE(&ES"B`@("`@("`@("`@
M("`@(&YO="!D:7-A8FQE9"X@*B\*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M7W9A;&ED4G5L92@D<G5L95LG86-T:6]N)UTI('Q\"B`@("`@("`@("`@("`@
M("`A96UP='DH)')U;&5;)V1I<V%B;&4G72DI('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<V5A<F-H
M7V%R<F%Y(#T@87)R87DH*3L*("`@("`@("`@("`@)'-T;W!?9FQA9R`](&9A
M;'-E.PH*("`@("`@("`@("`@<W=I=&-H("@D<G5L95LG86-T:6]N)UTI('L*
M("`@("`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-424].7T),04-+3$E3
M5#H*("`@("`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-424].7U=(251%
M3$E35#H*("`@("`@("`@("`@("`@("1B;%]F;VQD97(@/2!N=6QL.PH*("`@
M("`@("`@("`@("`@(&EF("@D<G5L95LG86-T:6]N)UT@/3T@24Y'3U]35$]2
M04=%7T%#5$E/3E]"3$%#2TQ)4U0I('L*("`@("`@("`@("`@("`@("`@("`D
M8FQA8VML:7-T(#T@)B1I;F=O7W-T;W)A9V4M/G)E=')I979E*$E.1T]?4U1/
M4D%'15]!0U1)3TY?0DQ!0TM,25-4*3L*("`@("`@("`@("`@("`@("`@("`D
M861D<B`]("1B;&%C:VQI<W0M/F=E=$)L86-K;&ES="@I.PH@("`@("`@("`@
M("`@("`@("`@("1B;%]F;VQD97(@/2`D8FQA8VML:7-T+3YG971";&%C:VQI
M<W1&;VQD97(H*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'=H:71E;&ES="`]("8D:6YG;U]S=&]R86=E+3YR971R
M:65V92A)3D=/7U-43U)!1T5?04-424].7U=(251%3$E35"D["B`@("`@("`@
M("`@("`@("`@("`@)&%D9'(@/2`D=VAI=&5L:7-T+3YG9717:&ET96QI<W0H
M*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!)9B!L
M:7-T(&ES(&5M<'1Y+"!M;W9E(&]N+B`J+PH@("`@("`@("`@("`@("`@:68@
M*&5M<'1Y*"1A9&1R*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1Q=65R>2`]
M("9N97<@24U!4%]396%R8VA?475E<GDH*3L*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1A9&1R(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D
M;V(@/2`F;F5W($E-05!?4V5A<F-H7U%U97)Y*"D["B`@("`@("`@("`@("`@
M("`@("`@)&]B+3YD96QE=&5D*&9A;'-E*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'-E96Y?9FQA9R`]/2!)3D=/7U-#4DE05%]&24Q415)?54Y3145.
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1O8BT^<V5E;BAF86QS92D[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1S965N7V9L86<@/3T@
M24Y'3U]30U))4%1?1DE,5$527U-%14XI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]B+3YS965N*'1R=64I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D;V(M/FAE861E<B@G9G)O;2<L("1V86PI
M.PH@("`@("`@("`@("`@("`@("`@("1S96%R8VA?87)R87E;72`]("8D;V([
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<75E<GDM/FEM
M87!/<B@D<V5A<F-H7V%R<F%Y*3L*("`@("`@("`@("`@("`@("1I;F1I8V5S
M(#T@)&EM87!?<V5A<F-H+3YS96%R8VA-86EL8F]X*"1Q=65R>2P@)'!A<F%M
M<ULG:6UA<"==+"`D<&%R86US6R=M86EL8F]X)UTI.PH*("`@("`@("`@("`@
M("`@(&EF("@D<G5L95LG86-T:6]N)UT@/3T@24Y'3U]35$]204=%7T%#5$E/
M3E]"3$%#2TQ)4U0I('L*("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<R`]
M(&%R<F%Y7V1I9F8H)&EN9&EC97,L("1W:&ET96QI<W1?:61S*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I;F1I8V5S*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D<V5Q=65N8V4@/2!I;7!L;V1E*"<L)RP@)&EN
M9&EC97,I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1B
M;%]F;VQD97(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:6UA
M<%]M86EL7VUO=F4H)'!A<F%M<ULG:6UA<"==+"`D<V5Q=65N8V4L("1B;%]F
M;VQD97(L($-07U5)1"D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:6UA<%]D96QE=&4H
M)'!A<F%M<ULG:6UA<"==+"`D<V5Q=65N8V4L($947U5)1"D["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@0&EM
M87!?97AP=6YG92@D<&%R86US6R=I;6%P)UTI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B1FEL=&5R
M(&%C=&EV:71Y.B`E<R!M97-S86=E*',I('1H870@;6%T8VAE9"!T:&4@8FQA
M8VML:7-T('=E<F4@9&5L971E9"XB*2P@8V]U;G0H)&EN9&EC97,I*2P@)VAO
M<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1W:&ET96QI
M<W1?:61S(#T@)&EN9&EC97,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@24Y'3U]35$]204=%
M7T%#5$E/3E]+1450.@H@("`@("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!
M0U1)3TY?34]613H*("`@("`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-4
M24].7T1)4T-!4D0Z"B`@("`@("`@("`@("`@("`D<75E<GD@/2`F;F5W($E-
M05!?4V5A<F-H7U%U97)Y*"D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<G5L95LG8V]N9&ET:6]N<R==(&%S("1V86PI('L*("`@("`@("`@("`@("`@
M("`@("`D;V(@/2`F;F5W($E-05!?4V5A<F-H7U%U97)Y*"D["B`@("`@("`@
M("`@("`@("`@("`@)&]B+3YD96QE=&5D*&9A;'-E*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)'-E96Y?9FQA9R`]/2!)3D=/7U-#4DE05%]&24Q415)?
M54Y3145.*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1O8BT^<V5E;BAF
M86QS92D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1S965N7V9L
M86<@/3T@24Y'3U]30U))4%1?1DE,5$527U-%14XI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&]B+3YS965N*'1R=64I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86Q;)W1Y
M<&4G72D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@*"1V86Q;)W1Y<&4G
M72`]/2!)3D=/7U-43U)!1T5?5%E015]325I%*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H)'9A;%LG;6%T8V@G72`]/2`G9W)E871E<B!T:&%N
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]P97)A=&]R(#T@
M)SXG.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'9A;%LG
M;6%T8V@G72`]/2`G;&5S<R!T:&%N)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&]P97)A=&]R(#T@)SPG.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1O8BT^<VEZ92@D=F%L
M6R=V86QU92==+"`D;W!E<F%T;W(I.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("@A96UP='DH)'9A;%LG='EP92==*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`H)'9A;%LG='EP92==(#T]($E.1T]?4U1/4D%'
M15]465!%7T)/1%DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M=F%L6R=M871C:"==(#T]("=C;VYT86EN<R<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1O8BT^8F]D>2@D=F%L6R=V86QU92==+"!F86QS92D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D=F%L6R=M871C
M:"==(#T]("=N;W0@8V]N=&%I;B<I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1O8BT^8F]D>2@D=F%L6R=V86QU92==+"!T<G5E*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L6R=M871C:"==
M(#T]("=C;VYT86EN<R<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1O8BT^:&5A9&5R*"1V86Q;)V9I96QD)UTL("1V86Q;)W9A;'5E)UTL(&9A
M;'-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1V86Q;
M)VUA=&-H)UT@/3T@)VYO="!C;VYT86EN)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&]B+3YH96%D97(H)'9A;%LG9FEE;&0G72P@)'9A;%LG
M=F%L=64G72P@=')U92D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'-E87)C
M:%]A<G)A>5M=(#T@)B1O8CL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("!I9B`H)')U;&5;)V-O;6)I;F4G72`]/2!)3D=/7U-43U)!1T5?
M0T]-0DE.15]!3$PI('L*("`@("`@("`@("`@("`@("`@("`D<75E<GDM/FEM
M87!!;F0H)'-E87)C:%]A<G)A>2D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1Q=65R>2T^:6UA<$]R*"1S96%R8VA?
M87)R87DI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1I
M;F1I8V5S(#T@)&EM87!?<V5A<F-H+3YS96%R8VA-86EL8F]X*"1Q=65R>2P@
M)'!A<F%M<ULG:6UA<"==+"`D<&%R86US6R=M86EL8F]X)UTI.PH*("`@("`@
M("`@("`@("`@(&EF("@H)&EN9&EC97,@/2!A<G)A>5]D:69F*"1I;F1I8V5S
M+"`D=VAI=&5L:7-T7VED<RDI*2!["B`@("`@("`@("`@("`@("`@("`@)'-E
M<75E;F-E(#T@:6UP;&]D92@G+"<L("1I;F1I8V5S*3L*("`@("`@("`@("`@
M("`@("`@("`D<W1O<%]F;&%G(#T@=')U93L*"B`@("`@("`@("`@("`@("`@
M("`@+RH@4V5T('1H92!F;&%G<RX@*B\*("`@("`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1R=6QE6R=F;&%G<R==*2`F)@H@("`@("`@("`@("`@("`@
M("`@("`@("`H)')U;&5;)V%C=&EO;B==("$]($E.1T]?4U1/4D%'15]!0U1)
M3TY?1$E30T%21"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9L86=S
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R=6QE
M6R=F;&%G<R==("8@24Y'3U]35$]204=%7T9,04=?04Y35T52140I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F;&%G<UM=(#T@)UQ<06YS=V5R
M960G.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<G5L95LG9FQA9W,G72`F($E.1T]?4U1/4D%'15]&
M3$%'7T1%3$54140I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;&%G<UM=(#T@)UQ<1&5L971E9"<["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R=6QE6R=F;&%G<R==
M("8@24Y'3U]35$]204=%7T9,04=?1DQ!1T=%1"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9L86=S6UT@/2`G7%Q&;&%G9V5D)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)')U;&5;)V9L86=S)UT@)B!)3D=/7U-43U)!1T5?1DQ!1U]3145.*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FQA9W-;72`]("=<7%-E
M96XG.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@($!I;6%P7W-E=&9L86=?9G5L;"@D<&%R86US6R=I;6%P)UTL
M("1S97%U96YC92P@:6UP;&]D92@G("<L("1F;&%G<RDL(%-47U5)1"D["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H
M)')U;&5;)V%C=&EO;B==(#T]($E.1T]?4U1/4D%'15]!0U1)3TY?2T5%4"D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!!9&0@=&AE<V4@:6YD:6-E
M<R!T;R!T:&4@8W5R<F5N="!W:&ET96QI<W0N("HO"B`@("`@("`@("`@("`@
M("`@("`@("`@("1W:&ET96QI<W1?:61S(#T@87)R87E?=6YI<75E*"1I;F1I
M8V5S("L@)'=H:71E;&ES=%]I9',I.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("@D<G5L95LG86-T:6]N)UT@/3T@24Y'3U]35$]204=%7T%#5$E/
M3E]-3U9%*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J(%=E(&YE960@
M=&\@9W)A8B!T:&4@;W9E<G9I97<@9FER<W0N("HO"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D9&5T86EL;7-G*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;W9E<G9I97<@/2!`:6UA<%]F971C:%]O=F5R=FEE=R@D
M<&%R86US6R=I;6%P)UTL("1S97%U96YC92P@1E1?54E$*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`@("`@+RH@
M36]V92!T:&4@;65S<V%G97,@=&\@=&AE(')E<75E<W1E9"!M86EL8F]X+B`J
M+PH@("`@("`@("`@("`@("`@("`@("`@("!`:6UA<%]M86EL7VUO=F4H)'!A
M<F%M<ULG:6UA<"==+"`D<V5Q=65N8V4L("1R=6QE6R=A8W1I;VXM=F%L=64G
M72P@0U!?54E$*3L*("`@("`@("`@("`@("`@("`@("`@("`@0&EM87!?97AP
M=6YG92@D<&%R86US6R=I;6%P)UTI.PH*("`@("`@("`@("`@("`@("`@("`@
M("`@+RH@1&ES<&QA>2!N;W1I9FEC871I;VX@;65S<V%G92AS*2X@*B\*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1D971A:6QM<V<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O=F5R=FEE=R!A<R`D
M;7-G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D9I;'1E<B!A8W1I=FET>3H@5&AE
M(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB(&AA<R!B965N(&UO=F5D('1O
M('1H92!F;VQD97(@7"(E<UPB+B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D
M;7-G+3YS=6)J96-T*2`_($U)344Z.F1E8V]D92@D;7-G+3YS=6)J96-T+"!.
M3%,Z.F=E=$-H87)S970H*2D@.B!?*");3F\@4W5B:F5C=%TB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@34E-13HZ9&5C;V1E*"1M<V<M/F9R;VTL($Y,4SHZ9V5T0VAA
M<G-E="@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')U;&5;)V%C=&EO;BUV86QU92==
M*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")&:6QT97(@86-T:79I='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B
M965N(&UO=F5D('1O('1H92!F;VQD97(@7"(E<UPB+B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O=6YT*"1I;F1I8V5S*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<G5L95LG86-T:6]N+79A
M;'5E)UTI+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1R=6QE6R=A
M8W1I;VXG72`]/2!)3D=/7U-43U)!1T5?04-424].7T1)4T-!4D0I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@+RH@5V4@;F5E9"!T;R!G<F%B('1H92!O
M=F5R=FEE=R!F:7)S="X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1D971A:6QM<V<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O
M=F5R=FEE=R`]($!I;6%P7V9E=&-H7V]V97)V:65W*"1P87)A;7-;)VEM87`G
M72P@)'-E<75E;F-E+"!&5%]5240I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@("`@("`O*B!$96QE=&4@=&AE(&UE
M<W-A9V5S(&YO=RX@*B\*("`@("`@("`@("`@("`@("`@("`@("`@0&EM87!?
M9&5L971E*"1P87)A;7-;)VEM87`G72P@)'-E<75E;F-E+"!&5%]5240I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!`:6UA<%]E>'!U;F=E*"1P87)A;7-;
M)VEM87`G72D["@H@("`@("`@("`@("`@("`@("`@("`@("`O*B!$:7-P;&%Y
M(&YO=&EF:6-A=&EO;B!M97-S86=E*',I+B`J+PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&1E=&%I;&US9RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&]V97)V:65W(&%S("1M<V<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S
M7"(@9G)O;2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:7-S970H)&US9RT^<W5B:F5C="D@/R!-24U%.CID96-O9&4H)&US
M9RT^<W5B:F5C="P@3DQ3.CIG971#:&%R<V5T*"DI(#H@7R@B6TYO(%-U8FIE
M8W1=(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($U)344Z.F1E8V]D92@D;7-G+3YF<F]M
M+"!.3%,Z.F=E=$-H87)S970H*2DI+"`G:&]R9&4N;65S<V%G92<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D9I;'1E<B!A8W1I=FET>3H@
M)7,@;65S<V%G92AS*2!H879E(&)E96X@9&5L971E9"XB*2P@8V]U;G0H)&EN
M9&EC97,I*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D<G5L95LG
M86-T:6]N)UT@/3T@24Y'3U]35$]204=%7T%#5$E/3E]-3U9%2T5%4"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`O*B!#;W!Y('1H92!M97-S86=E<R!T
M;R!T:&4@<F5Q=65S=&5D(&UA:6QB;W@N("HO"B`@("`@("`@("`@("`@("`@
M("`@("`@($!I;6%P7VUA:6Q?8V]P>2@D<&%R86US6R=I;6%P)UTL("1S97%U
M96YC92P@)')U;&5;)V%C=&EO;BUV86QU92==+"!#4%]5240I.PH*("`@("`@
M("`@("`@("`@("`@("`@("`@+RH@1&ES<&QA>2!N;W1I9FEC871I;VX@;65S
M<V%G92AS*2X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D971A
M:6QM<V<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O=F5R=FEE
M=R`]($!I;6%P7V9E=&-H7V]V97)V:65W*"1P87)A;7-;)VEM87`G72P@)'-E
M<75E;F-E+"!&5%]5240I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&]V97)V:65W(&%S("1M<V<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B1FEL=&5R(&%C=&EV:71Y.B!4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<
M(B5S7"(@:&%S(&)E96X@8V]P:65D('1O('1H92!F;VQD97(@7"(E<UPB+B(I
M+"!I<W-E="@D;7-G+3YS=6)J96-T*2`_($U)344Z.F1E8V]D92@D;7-G+3YS
M=6)J96-T+"!.3%,Z.F=E=$-H87)S970H*2D@.B!?*");3F\@4W5B:F5C=%TB
M*2P@34E-13HZ9&5C;V1E*"1M<V<M/F9R;VTL($Y,4SHZ9V5T0VAA<G-E="@I
M*2P@)')U;&5;)V%C=&EO;BUV86QU92==*2P@)VAO<F1E+FUE<W-A9V4G*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")&:6QT97(@86-T:79I
M='DZ("5S(&UE<W-A9V4H<RD@:&%V92!B965N(&-O<&EE9"!T;R!T:&4@9F]L
M9&5R(%PB)7-<(BXB*2P@8V]U;G0H)&EN9&EC97,I+"`D<G5L95LG86-T:6]N
M+79A;'5E)UTI+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($AA;F1L92!S=&]P(&9L86<N("HO"B`@("`@("`@("`@
M(&EF("@D<W1O<%]F;&%G("8F("1R=6QE6R=S=&]P)UTI('L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!3970@8V%C:&4@9FQA9RX@*B\*("`@("`@("`D:6UA<%]C86-H92T^
M<W1O<F5#86-H92@D<&%R86US6R=I;6%P)UTL("1P87)A;7-;)VUA:6QB;W@G
M72P@87)R87DH)VEN9V]C:&%N9V4G(#T^("1?4T534TE/3ELG:6YG;R==6R=C
M:&%N9V4G72DI.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($ES('1H92!A<'!L>2@I(&9U;F-T:6]N(&%V86EL86)L93\*
M("`@("`J(%1H92`G;6%I;"]G9713=')E86TG($%022!F=6YC=&EO;B!M=7-T
M(&)E(&%V86EL86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@87!P;'DH*2!I<R!A=F%I;&%B;&4L(&9A;'-E(&EF(&YO="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V%N07!P;'DH*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@(')E='5R;B`H)'1H:7,M/G!E
M<F9O<FU!=F%I;&%B;&4H*2`F)B`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G;6%I
M;"]G9713=')E86TG*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<'!L>2!T
M:&4@9FEL=&5R<R!N;W<N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!3964@<&5R9F]R;2@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L>2@I
M"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@:68@
M*"1T:&ES+3YC86Y!<'!L>2@I*2!["B`@("`@("`@("`@("1R97,@/2`D<F5G
M:7-T<GDM/F-A;&PH)VUA:6PO9V5T4W1R96%M)RP@87)R87DH)TE.0D]8)RDI
M.PH@("`@("`@("`@("!I9B`H)')E<R`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("1O8B`]($!I;6%P7V-H96-K*"1R97,I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YP97)F;W)M*&%R<F%Y*"=I;6%P)R`]/B`D<F5S
M+"`G;6%I;&)O>"<@/3X@)&]B+3Y-86EL8F]X*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L:6(O4V-R:7!T
M+W-I979E+G!H<```````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$V
M-S0T,P`Q,#0Q-S,V,C<T-P`P,C$R,S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!);F=O7U-C
M<FEP=%]S:65V93HZ(&-L87-S(')E<')E<V5N=',@82!3:65V92!38W)I<'0N
M"B`J"B`J("1(;W)D93H@:6YG;R]L:6(O4V-R:7!T+W-I979E+G!H<"QV(#$N
M-C,N,3`N,C8@,C`P-B\P,B\R-"`Q.#HU.#HQ-B!J86X@17AP("0*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$%33"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S
M;"YP:'`N"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($EN9V\@,"XQ"B`J($!P86-K
M86=E($EN9V\*("HO"F-L87-S($EN9V]?4V-R:7!T7W-I979E(&5X=&5N9',@
M26YG;U]38W)I<'0@>PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@86-T
M:6]N<R!A;&QO=V5D("AI;7!L96UE;G1E9"D@9F]R('1H:7,@9')I=F5R+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?86-T
M:6]N<R`](&%R<F%Y*`H@("`@("`@($E.1T]?4U1/4D%'15]!0U1)3TY?2T5%
M4"P*("`@("`@("!)3D=/7U-43U)!1T5?04-424].7TU/5D4L"B`@("`@("`@
M24Y'3U]35$]204=%7T%#5$E/3E]$25-#05)$+`H@("`@("`@($E.1T]?4U1/
M4D%'15]!0U1)3TY?4D5$25)%0U0L"B`@("`@("`@24Y'3U]35$]204=%7T%#
M5$E/3E]2141)4D5#5$M%15`L"B`@("`@("`@24Y'3U]35$]204=%7T%#5$E/
M3E]-3U9%2T5%4"P*("`@("`@("!)3D=/7U-43U)!1T5?04-424].7U)%2D5#
M5"P*("`@("`@("!)3D=/7U-43U)!1T5?04-424].7T9,04=/3DQ9+`H@("`@
M("`@($E.1T]?4U1/4D%'15]!0U1)3TY?3D]42499"B`@("`I.PH*("`@("\J
M*@H@("`@("H@5&AE(&-A=&5G;W)I97,@;V8@9FEL=&5R:6YG(&%L;&]W960N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C
M871E9V]R:65S(#T@87)R87DH"B`@("`@("`@24Y'3U]35$]204=%7T%#5$E/
M3E]"3$%#2TQ)4U0L"B`@("`@("`@24Y'3U]35$]204=%7T%#5$E/3E]72$E4
M14Q)4U0L"B`@("`@("`@24Y'3U]35$]204=%7T%#5$E/3E]604-!5$E/3BP*
M("`@("`@("!)3D=/7U-43U)!1T5?04-424].7T9/4E=!4D0*("`@("D["@H@
M("`@+RHJ"B`@("`@*B!4:&4@;&ES="!O9B!T97-T<R!A;&QO=V5D("AI;7!L
M96UE;G1E9"D@9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?=&5S=',@/2!A<G)A>2@*("`@("`@
M("`G8V]N=&%I;G,G+"`G;F]T(&-O;G1A:6XG+"`G:7,G+"`G;F]T(&ES)RP@
M)V)E9VEN<R!W:71H)RP*("`@("`@("`G;F]T(&)E9VEN<R!W:71H)RP@)V5N
M9',@=VET:"<L("=N;W0@96YD<R!W:71H)RP@)V5X:7-T<R<L("=N;W0@97AI
M<W0G+`H@("`@("`@("=L97-S('1H86XG+"`G;&5S<R!T:&%N(&]R(&5Q=6%L
M('1O)RP@)V5Q=6%L)RP@)VYO="!E<75A;"<L"B`@("`@("`@)V=R96%T97(@
M=&AA;B<L("=G<F5A=&5R('1H86X@;W(@97%U86P@=&\G+"`G<F5G97@G+"`G
M;6%T8VAE<R<L"B`@("`@("`@)VYO="!M871C:&5S)PH@("`@*3L*"B`@("`O
M*BH*("`@("`J(%1H92!T>7!E<R!O9B!T97-T<R!A;&QO=V5D("AI;7!L96UE
M;G1E9"D@9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?='EP97,@/2!A<G)A>2@*("`@("`@("!)
M3D=/7U-43U)!1T5?5%E015](14%$15(L"B`@("`@("`@24Y'3U]35$]204=%
M7U194$5?4TE:10H@("`@*3L*"B`@("`O*BH*("`@("`J($-A;B!T97-T<R!B
M92!C87-E('-E;G-I=&EV93\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?8V%S97-E;G-I=&EV92`]('1R=64["@H@("`@
M+RHJ"B`@("`@*B!$;V5S('1H92!D<FEV97(@<W5P<&]R="!S971T:6YG($E-
M05`@9FQA9W,_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7W-U<'!O<G1)34%01FQA9W,@/2!T<G5E.PH*("`@("\J*@H@
M("`@("H@1&]E<R!T:&4@9')I=F5R('-U<'!O<G0@=&AE('-T;W`M<V-R:7!T
M(&]P=&EO;C\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?<W5P<&]R=%-T;W!38W)I<'0@/2!T<G5E.PH*("`@("\J*@H@
M("`@("H@1&]E<R!T:&4@9')I=F5R(')E<75I<F4@82!S8W)I<'0@9FEL92!T
M;R!B92!G96YE<F%T960_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7W-C<FEP=&9I;&4@/2!T<G5E.PH*("`@("\J*@H@
M("`@("H@5&AE(&)L;V-K<R!T:&%T(&UA:V4@=7`@=&AE(&-O9&4N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]B;&]C:W,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-C<FEP="!P
M<F5V:6]U<VQY(&=E;F5R871E9"!W:71H(&=E;F5R871E*"DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!3:65V92!S8W)I<'0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('1O0V]D92@I"B`@("!["B`@("`@("`@)&-O9&4@
M/2`B(R!3:65V92!&:6QT97)<;B,@(B`N(%\H(D=E;F5R871E9"!B>2!);F=O
M("AH='1P.B\O=W=W+FAO<F1E+F]R9R]I;F=O+RDB*2`N("<@*"<@+B!D871E
M*"=&(&HL(%DL(&<Z:2!A)RD@+B`B*5QN7&XB.PH@("`@("`@("1C;V1E(#T@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D8V]D92P@3DQ3.CIG971#:&%R<V5T
M*"DL("=55$8M."<I.PH@("`@("`@("1R97%U:7)E<R`]("1T:&ES+3YR97%U
M:7)E<R@I.PH*("`@("`@("!I9B`H8V]U;G0H)')E<75I<F5S*2`^(#$I('L*
M("`@("`@("`@("`@)'-T<FEN9VQI<W0@/2`G)SL*("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/G)E<75I<F5S*"D@87,@)')E<75I<F4I('L*("`@("`@
M("`@("`@("`@("1S=')I;F=L:7-T("X]("AE;7!T>2@D<W1R:6YG;&ES="DI
M(#\@)R(G(#H@)RP@(B<["B`@("`@("`@("`@("`@("`D<W1R:6YG;&ES="`N
M/2`D<F5Q=6ER92`N("<B)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M8V]D92`N/2`G<F5Q=6ER92!;)R`N("1S=')I;F=L:7-T("X@)UT[)R`N(")<
M;EQN(CL*("`@("`@("!](&5L<V5I9B`H8V]U;G0H)')E<75I<F5S*2`]/2`Q
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YR97%U:7)E<R@I(&%S
M("1R97%U:7)E*2!["B`@("`@("`@("`@("`@("`D8V]D92`N/2`G<F5Q=6ER
M92`B)R`N("1R97%U:7)E("X@)R([)R`N(")<;EQN(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]B;&]C:W,@
M87,@)&)L;V-K*2!["B`@("`@("`@("`@("1C;V1E("X]("1B;&]C:RT^=&]#
M;V1E*"D@+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;V1E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@17-C87!E(&$@<W1R:6YG(&%C8V]R
M9&EN9R!T;R!3:65V92!21D,@,S`R."!;,BXT+C)=+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-T<FEN9R`@("`@(%1H92!S=')I;F<@=&\@97-C
M87!E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E9V5X;6]D92`@27,@=&AE
M(&5S8V%P960@<W1R:6YG(&$@<F5G97@@=F%L=64_"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!N;RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5S8V%P960@<W1R:6YG+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!E<V-A<&53=')I;F<H)'-T<FEN9RP@)')E9V5X
M;6]D92`](&9A;'-E*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!A;GD@8F%C
M:W-L87-H97,@:6X@9G)O;G0@;V8@8V]M;6%S+B`J+PH@("`@("`@("1S=')I
M;F<@/2!S=')?<F5P;&%C92@G7"PG+"`G+"<L("1S=')I;F<I.PH*("`@("`@
M("!I9B`H)')E9V5X;6]D92D@>PH@("`@("`@("`@("!R971U<FX@<W1R7W)E
M<&QA8V4H)R(G+"!A9&1S;&%S:&5S*"<B)RDL("1S=')I;F<I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!S=')?<F5P;&%C92AA<G)A
M>2@G7%PG+"`G(B<I+"!A<G)A>2AA9&1S;&%S:&5S*"=<7"<I+"!A9&1S;&%S
M:&5S*"<B)RDI+"`D<W1R:6YG*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@861D0FQO8VLH)&)L;V-K*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M8FQO8VMS6UT@/2`D8FQO8VL["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VLH
M*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8FQO8VMS(&%S("1B
M;&]C:RD@>PH@("`@("`@("`@("`D<F5S(#T@)&)L;V-K+3YC:&5C:R@I.PH@
M("`@("`@("`@("!I9B`H)')E<R`A/3T@=')U92D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(')E<75I<F5S
M*"D*("`@('L*("`@("`@("`D<F5Q=6ER97,@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?8FQO8VMS(&%S("1B;&]C:RD@>PH@("`@("`@
M("`@("`D<F5Q=6ER97,@/2!A<G)A>5]M97)G92@D<F5Q=6ER97,L("1B;&]C
M:RT^<F5Q=6ER97,H*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R
M87E?=6YI<75E*"1R97%U:7)E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M96YE<F%T97,@=&AE(%-I979E('-C<FEP="!T;R!D;R!T:&4@9FEL=&5R:6YG
M('-P96-I9FEE9"!I;@H@("`@("H@=&AE(')U;&5S+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@4VEE=F4@<V-R:7!T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G96YE<F%T92@I"B`@("!["B`@("`@("`@9VQO8F%L("1I
M;F=O7W-T;W)A9V4["@H@("`@("`@("1?8FQO8VMS(#T@87)R87DH*3L*"B`@
M("`@("`@+RH@1F]R=V%R9"!38W)I<'0@*B\*("`@("`@("!I9B`H)'1H:7,M
M/E]V86QI9%)U;&4H24Y'3U]35$]204=%7T%#5$E/3E]&3U)705)$*2D@>PH@
M("`@("`@("`@("`D9F]R=V%R9$)L;V-K<R`](&%R<F%Y*"D["@H@("`@("`@
M("`@("`D9F]R=V%R9"`]("8D:6YG;U]S=&]R86=E+3YR971R:65V92A)3D=/
M7U-43U)!1T5?04-424].7T9/4E=!4D0I.PH@("`@("`@("`@("`D9G=D7V%D
M9'(@/2`D9F]R=V%R9"T^9V5T1F]R=V%R9$%D9')E<W-E<R@I.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1F=V1?861D<BDI('L*("`@("`@("`@("`@("`@
M("1A8W1I;VX@/2`D861D<G,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1F=V1?861D<B!A<R`D861D<BD@>PH@("`@("`@("`@("`@
M("`@("`@("1A9&1R(#T@=')I;2@D861D<BD["B`@("`@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D861D<BDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&%C=&EO;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?4F5D:7)E8W0H87)R
M87DH)V%D9')E<W,G(#T^("1A9&1R*2D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@D9F]R
M=V%R9"T^9V5T1F]R=V%R9$ME97`H*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1A8W1I;VY;72`]("9N97<@4VEE=F5?06-T:6]N7TME97`H*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D9F]R=V%R9$)L;V-K<UM=
M(#T@)FYE=R!3:65V95]#;VUM96YT*%\H(D9O<G=A<F1S(BDI.PH@("`@("`@
M("`@("`@("`@)'1E<W0@/2`F;F5W(%-I979E7U1E<W1?5')U92@I.PH@("`@
M("`@("`@("`@("`@)&EF(#T@)FYE=R!3:65V95])9B@D=&5S="D["B`@("`@
M("`@("`@("`@("`D:68M/G-E=$%C=&EO;G,H)&%C=&EO;BD["B`@("`@("`@
M("`@("`@("`D9F]R=V%R9$)L;V-K<UM=(#T@)&EF.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!";&%C:VQI<W0@4V-R:7!T("HO"B`@
M("`@("`@:68@*"1T:&ES+3Y?=F%L:612=6QE*$E.1T]?4U1/4D%'15]!0U1)
M3TY?0DQ!0TM,25-4*2D@>PH@("`@("`@("`@("`D8FQA8VML:7-T(#T@)B1I
M;F=O7W-T;W)A9V4M/G)E=')I979E*$E.1T]?4U1/4D%'15]!0U1)3TY?0DQ!
M0TM,25-4*3L*("`@("`@("`@("`@)&)L7V%D9'(@/2`D8FQA8VML:7-T+3YG
M971";&%C:VQI<W0H*3L*("`@("`@("`@("`@)&9O;&1E<B`]("1B;&%C:VQI
M<W0M/F=E=$)L86-K;&ES=$9O;&1E<B@I.PH@("`@("`@("`@("`D8FQA8VML
M:7-T0FQO8VMS(#T@87)R87DH*3L*"B`@("`@("`@("`@(&EF("@A96UP='DH
M)&)L7V%D9'(I*2!["B`@("`@("`@("`@("`@("`D86-T:6]N(#T@87)R87DH
M*3L*"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&9O;&1E<BDI('L*("`@
M("`@("`@("`@("`@("`@("`D86-T:6]N6UT@/2`F;F5W(%-I979E7T%C=&EO
M;E]$:7-C87)D*"D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&9O;&1E
M<B`]/2!)3D=/7T),04-+3$E35%]-05)+15(I('L*("`@("`@("`@("`@("`@
M("`@("`D86-T:6]N6UT@/2`F;F5W(%-I979E7T%C=&EO;E]!9&1F;&%G*&%R
M<F%Y*"=F;&%G<R<@/3X@24Y'3U]35$]204=%7T9,04=?1$5,151%1"DI.PH@
M("`@("`@("`@("`@("`@("`@("1A8W1I;VY;72`]("9N97<@4VEE=F5?06-T
M:6]N7TME97`H*3L*("`@("`@("`@("`@("`@("`@("`D86-T:6]N6UT@/2`F
M;F5W(%-I979E7T%C=&EO;E]296UO=F5F;&%G*&%R<F%Y*"=F;&%G<R<@/3X@
M24Y'3U]35$]204=%7T9,04=?1$5,151%1"DI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D86-T:6]N6UT@/2`F;F5W
M(%-I979E7T%C=&EO;E]&:6QE:6YT;RAA<G)A>2@G9F]L9&5R)R`]/B`D9F]L
M9&5R*2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&%C
M=&EO;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?4W1O<"@I.PH*("`@("`@("`@
M("`@("`@("1C;VUM96YT(#T@)FYE=R!3:65V95]#;VUM96YT*%\H(D)L86-K
M;&ES=&5D($%D9')E<W-E<R(I*3L*("`@("`@("`@("`@("`@("1B;&%C:VQI
M<W1";&]C:W-;72`]("1C;VUM96YT.PH*("`@("`@("`@("`@("`@("\O(%-P
M;&ET('1H92!T97-T('5P('1O(&]N;'D@9&\@-2!A9&1R97-S97,@870@82!T
M:6UE+@H@("`@("`@("`@("`@("`@)'1E;7`@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@)'=I;&1C87)D<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D8FQ?861D<B!A<R`D861D<F5S<RD@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W,I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@H<W1R<W1R*"1A9&1R97-S+"`G*B<I("$]/2!F
M86QS92D@?'P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("AS=')S='(H
M)&%D9')E<W,L("<_)RD@(3T](&9A;'-E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'=I;&1C87)D<UM=(#T@)&%D9')E<W,["B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&5M<%M=(#T@)&%D9')E<W,["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@:68@*&-O=6YT*"1T96UP*2`]/2`U*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T97-T(#T@)FYE=R!3:65V95]497-T7T%D9')E<W,H87)R
M87DH)VAE861E<G,G(#T^(")&<F]M7&Y396YD97)<;E)E<V5N="U&<F]M(BP@
M)V%D9')E<W-E<R<@/3X@:6UP;&]D92@B7&XB+"`D=&5M<"DI*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EF(#T@)FYE=R!3:65V95])9B@D=&5S="D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1I9BT^<V5T06-T:6]N<R@D86-T
M:6]N*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&)L86-K;&ES=$)L;V-K
M<UM=(#T@)&EF.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&5M<"`](&%R
M<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&EF("AC;W5N="@D=VEL9&-A<F1S*2`]/2`U*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T97-T(#T@)FYE=R!3:65V95]497-T7T%D9')E<W,H
M87)R87DH)VAE861E<G,G(#T^(")&<F]M7&Y396YD97)<;E)E<V5N="U&<F]M
M(BP@)VUA=&-H+71Y<&4G(#T^("<Z;6%T8VAE<R<L("=A9&1R97-S97,G(#T^
M(&EM<&QO9&4H(EQN(BP@)'=I;&1C87)D<RDI*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EF(#T@)FYE=R!3:65V95])9B@D=&5S="D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1I9BT^<V5T06-T:6]N<R@D86-T:6]N*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&)L86-K;&ES=$)L;V-K<UM=(#T@)&EF
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=VEL9&-A<F1S(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@:68@*"1T96UP*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1E<W0@/2`F;F5W(%-I979E7U1E<W1?061D<F5S<RAA<G)A>2@G:&5A
M9&5R<R<@/3X@(D9R;VU<;E-E;F1E<EQN4F5S96YT+49R;VTB+"`G861D<F5S
M<V5S)R`]/B!I;7!L;V1E*")<;B(L("1T96UP*2DI.PH@("`@("`@("`@("`@
M("`@("`@("1I9B`]("9N97<@4VEE=F5?268H)'1E<W0I.PH@("`@("`@("`@
M("`@("`@("`@("1I9BT^<V5T06-T:6]N<R@D86-T:6]N*3L*("`@("`@("`@
M("`@("`@("`@("`D8FQA8VML:7-T0FQO8VMS6UT@/2`D:68["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1W:6QD8V%R9',I('L*
M("`@("`@("`@("`@("`@("`@("`D=&5S="`]("9N97<@4VEE=F5?5&5S=%]!
M9&1R97-S*&%R<F%Y*"=H96%D97)S)R`]/B`B1G)O;5QN4V5N9&5R7&Y297-E
M;G0M1G)O;2(L("=M871C:"UT>7!E)R`]/B`G.FUA=&-H97,G+"`G861D<F5S
M<V5S)R`]/B!I;7!L;V1E*")<;B(L("1W:6QD8V%R9',I*2D["B`@("`@("`@
M("`@("`@("`@("`@)&EF(#T@)FYE=R!3:65V95])9B@D=&5S="D["B`@("`@
M("`@("`@("`@("`@("`@)&EF+3YS971!8W1I;VYS*"1A8W1I;VXI.PH@("`@
M("`@("`@("`@("`@("`@("1B;&%C:VQI<W1";&]C:W-;72`]("1I9CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@5VAI=&5L:7-T(%-C<FEP="`J+PH@("`@("`@(&EF("@D=&AI<RT^
M7W9A;&ED4G5L92A)3D=/7U-43U)!1T5?04-424].7U=(251%3$E35"DI('L*
M("`@("`@("`@("`@)'=H:71E;&ES="`]("8D:6YG;U]S=&]R86=E+3YR971R
M:65V92A)3D=/7U-43U)!1T5?04-424].7U=(251%3$E35"D["B`@("`@("`@
M("`@("1W;%]A9&1R(#T@)'=H:71E;&ES="T^9V5T5VAI=&5L:7-T*"D["B`@
M("`@("`@("`@("1W:&ET96QI<W1";&]C:W,@/2!A<G)A>2@I.PH*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=VQ?861D<BDI('L*("`@("`@("`@("`@("`@
M("1W:&ET96QI<W1";&]C:W-;72`]("9N97<@4VEE=F5?0V]M;65N="A?*")7
M:&ET96QI<W1E9"!!9&1R97-S97,B*2D["B`@("`@("`@("`@("`@("`D86-T
M:6]N(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1A8W1I;VY;72`]("9N
M97<@4VEE=F5?06-T:6]N7TME97`H*3L*("`@("`@("`@("`@("`@("1A8W1I
M;VY;72`]("9N97<@4VEE=F5?06-T:6]N7U-T;W`H*3L*("`@("`@("`@("`@
M("`@("1T97-T(#T@)FYE=R!3:65V95]497-T7T%D9')E<W,H87)R87DH)VAE
M861E<G,G(#T^(")&<F]M7&Y396YD97)<;E)E<V5N="U&<F]M(BP@)V%D9')E
M<W-E<R<@/3X@:6UP;&]D92@B7&XB+"`D=VQ?861D<BDI*3L*("`@("`@("`@
M("`@("`@("1I9B`]("9N97<@4VEE=F5?268H)'1E<W0I.PH@("`@("`@("`@
M("`@("`@)&EF+3YS971!8W1I;VYS*"1A8W1I;VXI.PH@("`@("`@("`@("`@
M("`@)'=H:71E;&ES=$)L;V-K<UM=(#T@)&EF.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!686-A=&EO;B!38W)I<'0@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]V86QI9%)U;&4H24Y'3U]35$]204=%7T%#5$E/3E]6
M04-!5$E/3BDI('L*("`@("`@("`@("`@)&%C=&EO;B`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1T97-T<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1V86-A
M=&EO;B`]("8D:6YG;U]S=&]R86=E+3YR971R:65V92A)3D=/7U-43U)!1T5?
M04-424].7U9!0T%424].*3L*("`@("`@("`@("`@)'9A8V%T:6]N7V%D9'(@
M/2`D=F%C871I;VXM/F=E=%9A8V%T:6]N061D<F5S<V5S*"D["B`@("`@("`@
M("`@("1V86-A=&EO;D)L;V-K<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF
M("AC;W5N="@D=F%C871I;VY?861D<BDI('L*("`@("`@("`@("`@("`@("1V
M86QS(#T@87)R87DH)W-U8FIE8W0G(#T^(%-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H)'9A8V%T:6]N+3YG971686-A=&EO;E-U8FIE8W0H*2P@3DQ3.CIG971#
M:&%R<V5T*"DL("=55$8M."<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9&%Y<R<@/3X@)'9A8V%T:6]N+3YG971686-A=&EO;D1A>7,H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%D9')E<W-E<R<@/3X@
M)'9A8V%T:6]N7V%D9'(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R96%S;VXG(#T^(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A8V%T:6]N
M+3YG971686-A=&EO;E)E87-O;B@I+"!.3%,Z.F=E=$-H87)S970H*2P@)U54
M1BTX)RDI.PH*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O
M34E-12](96%D97)S+G!H<"<["B`@("`@("`@("`@("`@("`D;6EM95]H96%D
M97)S(#T@)FYE=R!-24U%7TAE861E<G,H*3L*("`@("`@("`@("`@("`@("1L
M:7-T2&5A9&5R<R`]("1M:6UE7VAE861E<G,M/FQI<W1(96%D97)S*"D["@H@
M("`@("`@("`@("`@("`@)&%C=&EO;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?
M5F%C871I;VXH)'9A;',I.PH*("`@("`@("`@("`@("`@(&EF("@D=F%C871I
M;VXM/F=E=%9A8V%T:6]N26=N;W)E;&ES="@I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S=%]%>&ES=',H87)R87DH)VAE
M861E<G,G(#T^(&EM<&QO9&4H(EQN(BP@87)R87E?:V5Y<R@D;&ES=$AE861E
M<G,I*2DI.PH@("`@("`@("`@("`@("`@("`@("1T97-T<UM=(#T@)FYE=R!3
M:65V95]497-T7TYO="@D=&UP*3L*("`@("`@("`@("`@("`@("`@("`D=F%L
M<R`](&%R<F%Y*"=H96%D97)S)R`]/B`G4')E8V5D96YC92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;6%T8V@M='EP92<@/3X@)SII
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1R:6YG
M<R<@/3X@)VQI<W0L8G5L:R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8V]M<&%R871O<B<@/3X@)VD[87-C:6DM8V%S96UA<"<I.PH@
M("`@("`@("`@("`@("`@("`@("1T;7`@/2`F;F5W(%-I979E7U1E<W1?2&5A
M9&5R*"1V86QS*3L*("`@("`@("`@("`@("`@("`@("`D=&5S='-;72`](&YE
M=R!3:65V95]497-T7TYO="@D=&UP*3L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D861D<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'9A8V%T:6]N+3YG971686-A=&EO;D5X8VQU9&5S*"D@
M87,@)&%D9'(I('L*("`@("`@("`@("`@("`@("`@("`D861D<B`]('1R:6TH
M)&%D9'(I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&%D9'(I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A9&1R<UM=(#T@)&%D9'([
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@(&EF("@D861D<G,I('L*("`@("`@("`@("`@("`@("`@
M("`D=&UP(#T@)FYE=R!3:65V95]497-T7T%D9')E<W,H87)R87DH)VAE861E
M<G,G(#T^(")&<F]M7&Y396YD97)<;E)E<V5N="U&<F]M(BP@)V%D9')E<W-E
M<R<@/3X@:6UP;&]D92@B7&XB+"`D861D<G,I*2D["B`@("`@("`@("`@("`@
M("`@("`@)'1E<W1S6UT@/2`F;F5W(%-I979E7U1E<W1?3F]T*"1T;7`I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1C;VUM96YT(#T@
M)FYE=R!3:65V95]#;VUM96YT*%\H(E9A8V%T:6]N(BDI.PH@("`@("`@("`@
M("`@("`@)'9A8V%T:6]N0FQO8VMS6UT@/2`D8V]M;65N=#L*"B`@("`@("`@
M("`@("`@("!I9B`H)'1E<W1S*2!["B`@("`@("`@("`@("`@("`@("`@)'1E
M<W0@/2`F;F5W(%-I979E7U1E<W1?06QL;V8H)'1E<W1S*3L*("`@("`@("`@
M("`@("`@("`@("`D:68@/2`F;F5W(%-I979E7TEF*"1T97-T*3L*("`@("`@
M("`@("`@("`@("`@("`D:68M/G-E=$%C=&EO;G,H)&%C=&EO;BD["B`@("`@
M("`@("`@("`@("`@("`@)'9A8V%T:6]N0FQO8VMS6UT@/2`D:68["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V86-A
M=&EO;D)L;V-K<UM=(#T@)&%C=&EO;ELP73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&9I;'1E<G,@/2`F
M)&EN9V]?<W1O<F%G92T^<F5T<FEE=F4H24Y'3U]35$]204=%7T%#5$E/3E]&
M24Q415)3*3L*("`@("`@("!F;W)E86-H("@D9FEL=&5R<RT^9V5T1FEL=&5R
M;&ES="@I(&%S("1F:6QT97(I('L*("`@("`@("`@("`@+RH@0VAE8VL@=&\@
M;6%K92!S=7)E('1H:7,@:7,@82!V86QI9"!R=6QE(&%N9"!T:&%T('1H92!R
M=6QE"B`@("`@("`@("`@("`@(&ES(&YO="!D:7-A8FQE9"X@*B\*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7W9A;&ED4G5L92@D9FEL=&5R6R=A8W1I;VXG
M72D@?'P*("`@("`@("`@("`@("`@("%E;7!T>2@D9FEL=&5R6R=D:7-A8FQE
M)UTI*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&%C=&EO;B`](&%R<F%Y*"D["B`@("`@("`@("`@
M('-W:71C:"`H)&9I;'1E<ELG86-T:6]N)UTI('L*("`@("`@("`@("`@8V%S
M92!)3D=/7U-43U)!1T5?04-424].7TM%15`Z"B`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1F:6QT97);)V9L86=S)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&%C=&EO;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?061D9FQA9RAA
M<G)A>2@G9FQA9W,G(#T^("1F:6QT97);)V9L86=S)UTI*3L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`D86-T:6]N6UT@/2`F;F5W(%-I
M979E7T%C=&EO;E]+965P*"D["@H@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D9FEL=&5R6R=F;&%G<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1A
M8W1I;VY;72`]("9N97<@4VEE=F5?06-T:6]N7U)E;6]V949L86<H87)R87DH
M)V9L86=S)R`]/B`D9FEL=&5R6R=F;&%G<R==*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M24Y'3U]35$]204=%7T%#5$E/3E]$25-#05)$.@H@("`@("`@("`@("`@("`@
M)&%C=&EO;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?1&ES8V%R9"@I.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E($E.1T]?4U1/
M4D%'15]!0U1)3TY?34]613H*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)&9I;'1E<ELG9FQA9W,G72DI('L*("`@("`@("`@("`@("`@("`@("`D86-T
M:6]N6UT@/2`F;F5W(%-I979E7T%C=&EO;E]!9&1F;&%G*&%R<F%Y*"=F;&%G
M<R<@/3X@)&9I;'1E<ELG9FQA9W,G72DI.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1A8W1I;VY;72`]("9N97<@4VEE=F5?06-T:6]N
M7T9I;&5I;G1O*&%R<F%Y*"=F;VQD97(G(#T^("1F:6QT97);)V%C=&EO;BUV
M86QU92==*2D["@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9FEL=&5R
M6R=F;&%G<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1A8W1I;VY;72`]
M("9N97<@4VEE=F5?06-T:6]N7U)E;6]V949L86<H87)R87DH)V9L86=S)R`]
M/B`D9FEL=&5R6R=F;&%G<R==*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E($E.1T]?
M4U1/4D%'15]!0U1)3TY?4D5*14-4.@H@("`@("`@("`@("`@("`@)&%C=&EO
M;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?4F5J96-T*&%R<F%Y*"=R96%S;VXG
M(#T^("1F:6QT97);)V%C=&EO;BUV86QU92==*2D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/
M3E]2141)4D5#5#H*("`@("`@("`@("`@("`@("1A8W1I;VY;72`]("9N97<@
M4VEE=F5?06-T:6]N7U)E9&ER96-T*&%R<F%Y*"=A9&1R97-S)R`]/B`D9FEL
M=&5R6R=A8W1I;VXM=F%L=64G72DI.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?4D5$25)%
M0U1+1450.@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9FEL=&5R6R=F
M;&%G<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1A8W1I;VY;72`]("9N
M97<@4VEE=F5?06-T:6]N7T%D9&9L86<H87)R87DH)V9L86=S)R`]/B`D9FEL
M=&5R6R=F;&%G<R==*2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)&%C=&EO;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?4F5D:7)E8W0H
M87)R87DH)V%D9')E<W,G(#T^("1F:6QT97);)V%C=&EO;BUV86QU92==*2D[
M"B`@("`@("`@("`@("`@("`D86-T:6]N6UT@/2`F;F5W(%-I979E7T%C=&EO
M;E]+965P*"D["@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9FEL=&5R
M6R=F;&%G<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1A8W1I;VY;72`]
M("9N97<@4VEE=F5?06-T:6]N7U)E;6]V949L86<H87)R87DH)V9L86=S)R`]
M/B`D9FEL=&5R6R=F;&%G<R==*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@24Y'3U]35$]2
M04=%7T%#5$E/3E]-3U9%2T5%4#H*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&9I;'1E<ELG9FQA9W,G72DI('L*("`@("`@("`@("`@("`@("`@("`D
M86-T:6]N6UT@/2`F;F5W(%-I979E7T%C=&EO;E]!9&1F;&%G*&%R<F%Y*"=F
M;&%G<R<@/3X@)&9I;'1E<ELG9FQA9W,G72DI.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1A8W1I;VY;72`]("9N97<@4VEE=F5?06-T
M:6]N7TME97`H*3L*("`@("`@("`@("`@("`@("1A8W1I;VY;72`]("9N97<@
M4VEE=F5?06-T:6]N7T9I;&5I;G1O*&%R<F%Y*"=F;VQD97(G(#T^("1F:6QT
M97);)V%C=&EO;BUV86QU92==*2D["@H@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D9FEL=&5R6R=F;&%G<R==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1A8W1I;VY;72`]("9N97<@4VEE=F5?06-T:6]N7U)E;6]V949L86<H87)R
M87DH)V9L86=S)R`]/B`D9FEL=&5R6R=F;&%G<R==*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@24Y'3U]35$]204=%7T%#5$E/3E]&3$%'3TY,63H*("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)&9I;'1E<ELG9FQA9W,G72DI('L*("`@("`@("`@
M("`@("`@("`@("`D86-T:6]N6UT@/2`F;F5W(%-I979E7T%C=&EO;E]!9&1F
M;&%G*&%R<F%Y*"=F;&%G<R<@/3X@)&9I;'1E<ELG9FQA9W,G72DI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?3D]42499.@H@("`@("`@
M("`@("`@("`@)&%C=&EO;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?3F]T:69Y
M*&%R<F%Y*"=A9&1R97-S)R`]/B`D9FEL=&5R6R=A8W1I;VXM=F%L=64G72P@
M)VYA;64G(#T^("1F:6QT97);)VYA;64G72DI.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?
M5TA)5$5,25-4.@H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'=H:71E;&ES
M=$)L;V-K<R!A<R`D=VAI=&4I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^861D0FQO8VLH)'=H:71E*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E(#(["@H@("`@("`@("`@("!C87-E($E.1T]?
M4U1/4D%'15]!0U1)3TY?0DQ!0TM,25-4.@H@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&)L86-K;&ES=$)L;V-K<R!A<R`D8FQO8VLI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^861D0FQO8VLH)&)L;V-K*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&-O;G1I;G5E(#(["@H@("`@("`@
M("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?5D%#051)3TXZ"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=F%C871I;VY";&]C:W,@87,@)&)L;V-K
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$)L;V-K*"1B;&]C
M:RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!C;VYT:6YU
M92`R.PH*("`@("`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-424].7T9/
M4E=!4D0Z"B`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9O<G=A<F1";&]C
M:W,@87,@)&)L;V-K*2!["B`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA
M9&1";&]C:R@D8FQO8VLI.PH@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D8V]M;65N="`]("9N97<@4VEE=F5?0V]M;65N="@D9FEL=&5R6R=N86UE
M)UTI.PH@("`@("`@("`@("`D=&AI<RT^861D0FQO8VLH)&-O;6UE;G0I.PH*
M("`@("`@("`@("`@:68@*"1F:6QT97);)W-T;W`G72D@>PH@("`@("`@("`@
M("`@("`@)&%C=&EO;EM=(#T@)FYE=R!3:65V95]!8W1I;VY?4W1O<"@I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&5S="`]("9N97<@4VEE=F5?
M5&5S="@I.PH@("`@("`@("`@("!I9B`H)&9I;'1E<ELG8V]M8FEN92==(#T]
M($E.1T]?4U1/4D%'15]#3TU"24Y%7T%.62D@>PH@("`@("`@("`@("`@("`@
M)'1E<W0@/2`F;F5W(%-I979E7U1E<W1?06YY;V8H*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T97-T(#T@)FYE=R!3:65V95]4
M97-T7T%L;&]F*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1F:6QT97);)V-O;F1I=&EO;G,G72!A<R`D8V]N9&ET:6]N*2!["B`@
M("`@("`@("`@("`@("`D=&UP(#T@)R<["B`@("`@("`@("`@("`@("!S=VET
M8V@@*"1C;VYD:71I;VY;)VUA=&-H)UTI('L*("`@("`@("`@("`@("`@(&-A
M<V4@)V5Q=6%L('1O)SH*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)FYE
M=R!3:65V95]497-T7U)E;&%T:6]N86PH87)R87DH)V-O;7!A<FES;VXG(#T^
M("=E<2<L("=H96%D97)S)R`]/B`D8V]N9&ET:6]N6R=F:65L9"==+"`G=F%L
M=64G(#T^("1C;VYD:71I;VY;)W9A;'5E)UTI*3L*("`@("`@("`@("`@("`@
M("`@("`D=&5S="T^861D5&5S="@D=&UP*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=N;W0@97%U86PG.@H@
M("`@("`@("`@("`@("`@("`@("1T;7`@/2`F;F5W(%-I979E7U1E<W1?4F5L
M871I;VYA;"AA<G)A>2@G8V]M<&%R:7-O;B<@/3X@)VYE)RP@)VAE861E<G,G
M(#T^("1C;VYD:71I;VY;)V9I96QD)UTL("=V86QU92<@/3X@)&-O;F1I=&EO
M;ELG=F%L=64G72DI.PH@("`@("`@("`@("`@("`@("`@("1T97-T+3YA9&14
M97-T*"1T;7`I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&-A<V4@)VQE<W,@=&AA;B<Z"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1C;VYD:71I;VY;)V9I96QD)UT@/3T@)U-I>F4G*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("\J($UE<W-A9V4@4VEZ92!497-T+B`J+PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)FYE=R!3:65V95]497-T
M7U-I>F4H87)R87DH)V-O;7!A<FES;VXG(#T^("<Z=6YD97(G+"`G<VEZ92<@
M/3X@)&-O;F1I=&EO;ELG=F%L=64G72DI.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("\J(%)E;&%T:6]N
M86P@5&5S="X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)'1M<"`]("9N
M97<@4VEE=F5?5&5S=%]296QA=&EO;F%L*&%R<F%Y*"=C;VUP87)I<V]N)R`]
M/B`G;'0G+"`G:&5A9&5R<R<@/3X@)&-O;F1I=&EO;ELG9FEE;&0G72P@)W9A
M;'5E)R`]/B`D8V]N9&ET:6]N6R=V86QU92==*2D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T97-T+3YA9&1497-T*"1T
M;7`I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@(&-A<V4@)VQE<W,@=&AA;B!O<B!E<75A;"!T;R<Z"B`@("`@("`@("`@
M("`@("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S=%]296QA=&EO;F%L*&%R
M<F%Y*"=C;VUP87)I<V]N)R`]/B`G;&4G+"`G:&5A9&5R<R<@/3X@)&-O;F1I
M=&EO;ELG9FEE;&0G72P@)W9A;'5E)R`]/B`D8V]N9&ET:6]N6R=V86QU92==
M*2D["B`@("`@("`@("`@("`@("`@("`@)'1E<W0M/F%D9%1E<W0H)'1M<"D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G9W)E871E<B!T:&%N)SH*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&-O;F1I=&EO;ELG9FEE;&0G72`]/2`G4VEZ92<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@+RH@365S<V%G92!3:7IE(%1E<W0N("HO"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T;7`@/2`F;F5W(%-I979E7U1E<W1?4VEZ92AA
M<G)A>2@G8V]M<&%R:7-O;B<@/3X@)SIO=F5R)RP@)W-I>F4G(#T^("1C;VYD
M:71I;VY;)W9A;'5E)UTI*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!296QA=&EO;F%L(%1E<W0N
M("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1T;7`@/2`F;F5W(%-I979E
M7U1E<W1?4F5L871I;VYA;"AA<G)A>2@G8V]M<&%R:7-O;B<@/3X@)V=T)RP@
M)VAE861E<G,G(#T^("1C;VYD:71I;VY;)V9I96QD)UTL("=V86QU92<@/3X@
M)&-O;F1I=&EO;ELG=F%L=64G72DI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D=&5S="T^861D5&5S="@D=&UP*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E
M("=G<F5A=&5R('1H86X@;W(@97%U86P@=&\G.@H@("`@("`@("`@("`@("`@
M("`@("1T;7`@/2`F;F5W(%-I979E7U1E<W1?4F5L871I;VYA;"AA<G)A>2@G
M8V]M<&%R:7-O;B<@/3X@)V=E)RP@)VAE861E<G,G(#T^("1C;VYD:71I;VY;
M)V9I96QD)UTL("=V86QU92<@/3X@)&-O;F1I=&EO;ELG=F%L=64G72DI.PH@
M("`@("`@("`@("`@("`@("`@("1T97-T+3YA9&1497-T*"1T;7`I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)V5X:7-T<R<Z"B`@("`@("`@("`@("`@("`@("`@)'1M<"`]("9N97<@4VEE
M=F5?5&5S=%]%>&ES=',H87)R87DH)VAE861E<G,G(#T^("1C;VYD:71I;VY;
M)V9I96QD)UTI*3L*("`@("`@("`@("`@("`@("`@("`D=&5S="T^861D5&5S
M="@D=&UP*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=N;W0@97AI<W0G.@H@("`@("`@("`@("`@("`@("`@
M("1T;7`@/2`F;F5W(%-I979E7U1E<W1?17AI<W1S*&%R<F%Y*"=H96%D97)S
M)R`]/B`D8V]N9&ET:6]N6R=F:65L9"==*2D["B`@("`@("`@("`@("`@("`@
M("`@)'1E<W0M/F%D9%1E<W0H;F5W(%-I979E7U1E<W1?3F]T*"1T;7`I*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("=C;VYT86EN<R<Z"B`@("`@("`@("`@("`@("!C87-E("=N;W0@8V]N
M=&%I;B<Z"B`@("`@("`@("`@("`@("!C87-E("=I<R<Z"B`@("`@("`@("`@
M("`@("!C87-E("=N;W0@:7,G.@H@("`@("`@("`@("`@("`@8V%S92`G8F5G
M:6YS('=I=&@G.@H@("`@("`@("`@("`@("`@8V%S92`G;F]T(&)E9VEN<R!W
M:71H)SH*("`@("`@("`@("`@("`@(&-A<V4@)V5N9',@=VET:"<Z"B`@("`@
M("`@("`@("`@("!C87-E("=N;W0@96YD<R!W:71H)SH*("`@("`@("`@("`@
M("`@(&-A<V4@)W)E9V5X)SH*("`@("`@("`@("`@("`@(&-A<V4@)VUA=&-H
M97,G.@H@("`@("`@("`@("`@("`@8V%S92`G;F]T(&UA=&-H97,G.@H@("`@
M("`@("`@("`@("`@("`@("1C;VUP87)A=&]R(#T@*&ES<V5T*"1C;VYD:71I
M;VY;)V-A<V4G72D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]N9&ET:6]N6R=C87-E)UTI"B`@("`@("`@("`@("`@("`@("`@
M("`@(#\@)VD[;V-T970G"B`@("`@("`@("`@("`@("`@("`@("`@(#H@)VD[
M87-C:6DM8V%S96UA<"<["B`@("`@("`@("`@("`@("`@("`@)'9A;',@/2!A
M<G)A>2@G:&5A9&5R<R<@/3X@<')E9U]R97!L86-E*"<O*#\\(5Q<7"E<+"\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B7&XB+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9&ET
M:6]N6R=F:65L9"==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=C;VUP87)A=&]R)R`]/B`D8V]M<&%R871O<BD["B`@("`@("`@("`@
M("`@("`@("`@)'5S95]A9&1R97-S7W1E<W0@/2!F86QS93L*"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1C;VYD:71I;VY;)VUA=&-H)UT@(3T@)W)E9V5X
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9&ET:6]N6R=V86QU
M92==(#T@<')E9U]R97!L86-E*"<O*#\\(5Q<7"E<+"\G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F1I=&EO;ELG=F%L=64G72D[
M"B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O
M*B!$;R`G<VUA<G1E<B<@<V5A<F-H:6YG(&9O<B!F:65L9',@=VAE<F4@=V4@
M:VYO=R!W92!H879E"B`@("`@("`@("`@("`@("`@("`@("H@92UM86EL(&%D
M9')E<W-E<RX@*B\*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@G+UXH1G)O;7Q4;WQ#8WQ"8V,I+R<L("1C;VYD:71I;VY;)V9I96QD)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QS6R=A9&1R97-S97,G
M72`]("1C;VYD:71I;VY;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@
M("`@("1U<V5?861D<F5S<U]T97-T(#T@=')U93L*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L<ULG
M<W1R:6YG<R==(#T@)&-O;F1I=&EO;ELG=F%L=64G73L*("`@("`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)&-O;F1I
M=&EO;ELG;6%T8V@G72D@>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)V-O
M;G1A:6YS)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'-;)VUA=&-H
M+71Y<&4G72`]("<Z8V]N=&%I;G,G.PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'5S95]A9&1R97-S7W1E<W0I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T;7`@/2`F;F5W(%-I979E7U1E<W1?061D<F5S<R@D=F%L
M<RD["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)FYE=R!3:65V95]497-T7TAE
M861E<B@D=F%L<RD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1E<W0M/F%D9%1E<W0H)'1M<"D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@
M("!C87-E("=N;W0@8V]N=&%I;B<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1V86QS6R=M871C:"UT>7!E)UT@/2`G.F-O;G1A:6YS)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1U<V5?861D<F5S<U]T97-T*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)FYE=R!3:65V95]497-T
M7T%D9')E<W,H)'9A;',I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1M<"`]("9N97<@
M4VEE=F5?5&5S=%](96%D97(H)'9A;',I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1T97-T+3YA9&1497-T
M*&YE=R!3:65V95]497-T7TYO="@D=&UP*2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=I<R<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QS6R=M871C:"UT>7!E)UT@
M/2`G.FES)SL*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1U<V5?861D
M<F5S<U]T97-T*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&UP
M(#T@)FYE=R!3:65V95]497-T7T%D9')E<W,H)'9A;',I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S=%](96%D97(H)'9A;',I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T97-T+3YA9&1497-T*"1T;7`I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G;F]T(&ES
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'-;)VUA=&-H+71Y<&4G
M72`]("<Z:7,G.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'5S95]A
M9&1R97-S7W1E<W0I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M;7`@/2`F;F5W(%-I979E7U1E<W1?061D<F5S<R@D=F%L<RD["B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&UP(#T@)FYE=R!3:65V95]497-T7TAE861E<B@D=F%L<RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1E<W0M/F%D9%1E<W0H;F5W(%-I979E7U1E<W1?3F]T*"1T;7`I
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)V)E9VEN<R!W:71H)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A;'-;)VUA=&-H+71Y<&4G72`]("<Z;6%T8VAE<R<["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D=7-E7V%D9')E<W-?=&5S="D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%D9%]A<G(@/2!P<F5G
M7W-P;&ET*"<H7')<;GQ<;GQ<<BDG+"`D=F%L<ULG861D<F5S<V5S)UTI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1A9&1?87)R
M*2`^(#$I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D861D7V%R<B!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D861D7V%R<ELD:UT@/2`D=B`N("<J)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'-;)V%D9')E<W-E<R==(#T@:6UP
M;&]D92@B7')<;B(L("1A9&1?87)R*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'-;)V%D9')E<W-E<R==("X]("<J)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M;7`@/2`F;F5W(%-I979E7U1E<W1?061D<F5S<R@D=F%L<RD["B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D861D7V%R<B`]('!R96=?<W!L:70H)RA<<EQN?%QN?%QR*2<L
M("1V86QS6R=S=')I;F=S)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*"1A9&1?87)R*2`^(#$I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D861D7V%R<B!A<R`D:R`]/B`D
M=BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D861D
M7V%R<ELD:UT@/2`D=B`N("<J)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M;'-;)W-T<FEN9W,G72`](&EM<&QO9&4H(EQR7&XB+"`D861D7V%R<BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V86QS6R=S=')I;F=S)UT@+CT@)RHG
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S=%](96%D97(H
M)'9A;',I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T97-T+3YA9&1497-T*"1T;7`I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G;F]T(&)E9VEN<R!W:71H)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A;'-;)VUA=&-H+71Y<&4G72`]("<Z;6%T8VAE<R<["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D=7-E7V%D9')E<W-?=&5S="D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&%D9%]A<G(@/2!P<F5G7W-P;&ET*"<H
M7')<;GQ<;GQ<<BDG+"`D=F%L<ULG861D<F5S<V5S)UTI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1A9&1?87)R*2`^(#$I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D861D
M7V%R<B!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D861D7V%R<ELD:UT@/2`D=B`N("<J)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'-;)V%D9')E<W-E<R==(#T@:6UP;&]D92@B7')<
M;B(L("1A9&1?87)R*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'-;
M)V%D9')E<W-E<R==("X]("<J)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T;7`@/2`F;F5W
M(%-I979E7U1E<W1?061D<F5S<R@D=F%L<RD["B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M861D7V%R<B`]('!R96=?<W!L:70H)RA<<EQN?%QN?%QR*2<L("1V86QS6R=S
M=')I;F=S)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&-O
M=6YT*"1A9&1?87)R*2`^(#$I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D861D7V%R<B!A<R`D:R`]/B`D=BD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D861D7V%R<ELD:UT@
M/2`D=B`N("<J)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'-;)W-T<FEN
M9W,G72`](&EM<&QO9&4H(EQR7&XB+"`D861D7V%R<BD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1V86QS6R=S=')I;F=S)UT@+CT@)RHG.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S=%](96%D97(H)'9A;',I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T97-T+3YA9&1497-T*&YE=R!3:65V95]497-T7TYO="@D=&UP*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@("`@("!C87-E("=E;F1S('=I=&@G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L<ULG;6%T8V@M='EP92==(#T@)SIM871C:&5S)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1U<V5?861D<F5S<U]T97-T*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D861D7V%R<B`]('!R96=?<W!L
M:70H)RA<<EQN?%QN?%QR*2<L("1V86QS6R=A9&1R97-S97,G72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&%D9%]A<G(I(#X@
M,2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1A9&1?87)R(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1A9&1?87)R6R1K72`]("<J)R`N("1V.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L<ULG861D<F5S<V5S)UT@/2!I;7!L;V1E
M*")<<EQN(BP@)&%D9%]A<G(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L<ULG861D<F5S<V5S)UT@/2`G*B<@+B`@)'9A;'-;)V%D9')E<W-E<R==
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S=%]!9&1R97-S
M*"1V86QS*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A9&1?87)R(#T@<')E9U]S<&QI
M="@G*%QR7&Y\7&Y\7'(I)RP@)'9A;'-;)W-T<FEN9W,G72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&%D9%]A<G(I(#X@,2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A
M9&1?87)R(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1A9&1?87)R6R1K72`]("<J)R`N("1V.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%L<ULG<W1R:6YG<R==(#T@:6UP;&]D92@B7')<
M;B(L("1A9&1?87)R*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'-;
M)W-T<FEN9W,G72`]("<J)R`N("`D=F%L<ULG<W1R:6YG<R==.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S=%](96%D97(H)'9A;',I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T97-T+3YA9&1497-T*"1T;7`I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G;F]T(&5N
M9',@=VET:"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QS6R=M871C
M:"UT>7!E)UT@/2`G.FUA=&-H97,G.PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'5S95]A9&1R97-S7W1E<W0I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A9&1?87)R(#T@<')E9U]S<&QI="@G*%QR7&Y\7&Y\7'(I
M)RP@)'9A;'-;)V%D9')E<W-E<R==*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AC;W5N="@D861D7V%R<BD@/B`Q*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%D9%]A<G(@87,@)&L@
M/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&%D9%]A<G);)&M=(#T@)RHG("X@)'8["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1V86QS6R=A9&1R97-S97,G72`](&EM<&QO9&4H(EQR7&XB+"`D861D7V%R
M<BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86QS6R=A9&1R97-S97,G
M72`]("<J)R`N("`D=F%L<ULG861D<F5S<V5S)UT["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&UP(#T@)FYE=R!3:65V95]497-T7T%D9')E<W,H)'9A;',I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&%D9%]A<G(@/2!P<F5G7W-P;&ET*"<H7')<;GQ<;GQ<<BDG
M+"`D=F%L<ULG<W1R:6YG<R==*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AC;W5N="@D861D7V%R<BD@/B`Q*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%D9%]A<G(@87,@)&L@/3X@
M)'8I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%D
M9%]A<G);)&M=(#T@)RHG("X@)'8["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V
M86QS6R=S=')I;F=S)UT@/2!I;7!L;V1E*")<<EQN(BP@)&%D9%]A<G(I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L<ULG<W1R:6YG<R==(#T@)RHG
M("X@("1V86QS6R=S=')I;F=S)UT["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)FYE
M=R!3:65V95]497-T7TAE861E<B@D=F%L<RD["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'1E<W0M/F%D9%1E
M<W0H;F5W(%-I979E7U1E<W1?3F]T*"1T;7`I*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W)E
M9V5X)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'-;)VUA=&-H+71Y
M<&4G72`]("<Z<F5G97@G.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)'5S95]A9&1R97-S7W1E<W0I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T;7`@/2`F;F5W(%-I979E7U1E<W1?061D<F5S<R@D=F%L<RD["B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&UP(#T@)FYE=R!3:65V95]497-T7TAE861E<B@D
M=F%L<RD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1E<W0M/F%D9%1E<W0H)'1M<"D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E
M("=M871C:&5S)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'-;)VUA
M=&-H+71Y<&4G72`]("<Z;6%T8VAE<R<["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D=7-E7V%D9')E<W-?=&5S="D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S=%]!9&1R97-S*"1V
M86QS*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T;7`@/2`F;F5W(%-I979E7U1E<W1?
M2&5A9&5R*"1V86QS*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&5S="T^861D5&5S="@D=&UP*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)VYO="!M871C:&5S)SH*("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'-;)VUA=&-H+71Y<&4G72`]("<Z;6%T8VAE<R<["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D=7-E7V%D9')E<W-?=&5S="D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1M<"`]("9N97<@4VEE=F5?5&5S
M=%]!9&1R97-S*"1V86QS*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T;7`@/2`F;F5W
M(%-I979E7U1E<W1?2&5A9&5R*"1V86QS*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D=&5S="T^861D5&5S
M="AN97<@4VEE=F5?5&5S=%].;W0H)'1M<"DI.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1I9B`]("9N
M97<@4VEE=F5?268H)'1E<W0I.PH@("`@("`@("`@("`D:68M/G-E=$%C=&EO
M;G,H)&%C=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YA9&1";&]C:R@D:68I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YT;T-O9&4H*3L*
M("`@('T*"GT*"B\J*@H@*B!4:&4@4VEE=F5?268Z.B!4:&ES(&-L87-S(')E
M<')E<V5N=',@82!3:65V92!)9B!3=&%T96UE;G0*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I
M;F-E("`@26YG;R`P+C$*("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@4VEE
M=F5?268@>PH*("`@('9A<B`D7W1E<W0["B`@("!V87(@)%]A8W1I;VYS(#T@
M87)R87DH*3L*("`@('9A<B`D7V5L<VEF<R`](&%R<F%Y*"D["B`@("!V87(@
M)%]E;'-E.PH*("`@(&9U;F-T:6]N(%-I979E7TEF*"1T97-T(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&5S="DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]T97-T(#T@;F5W(%-I979E7U1E<W1?1F%L<V4H*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W1E<W0@/2`D=&5S
M=#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?86-T:6]N<UM=(#T@;F5W
M(%-I979E7T%C=&EO;E]+965P*"D["B`@("`@("`@)'1H:7,M/E]E;'-E(#T@
M;F5W(%-I979E7T5L<V4H*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971497-T
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T97-T.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-E=%1E<W0H)'1E<W0I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]T97-T(#T@)'1E<W0["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T06-T
M:6]N<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?86-T:6]N<SL*
M("`@('T*"B`@("!F=6YC=&EO;B!S971!8W1I;VYS*"1A8W1I;VYS*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?86-T:6]N<R`]("1A8W1I;VYS.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$5L<VEF<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?96QS:69S.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$5L<VEF
M<R@D96QS:69S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?96QS:69S(#T@)&5L
M<VEF<SL*("`@('T*"B`@("!F=6YC=&EO;B!A9&1%;'-I9B@D96QS:68I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]E;'-I9G-;72`]("1E;'-I9CL*("`@('T*
M"B`@("!F=6YC=&EO;B!G971%;'-E*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]E;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$5L<V4H)&5L
M<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]E;'-E(#T@)&5L<V4["B`@("!]
M"@H@("`@9G5N8W1I;VX@=&]#;V1E*"D*("`@('L*("`@("`@("`D8V]D92`]
M("=I9B`G("X@)'1H:7,M/E]T97-T+3YT;T-O9&4H*2`N("(@>R!<;B(["B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]A8W1I;VYS(&%S("1A8W1I;VXI('L*
M("`@("`@("`@("`@)&-O9&4@+CT@)R`@("`G("X@)&%C=&EO;BT^=&]#;V1E
M*"D@+B`B7&XB.PH@("`@("`@('T*("`@("`@("`D8V]D92`N/2`B?2`B.PH*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5L<VEF<R!A<R`D96QS:68I('L*
M("`@("`@("`@("`@)&-O9&4@+CT@)&5L<VEF+3YT;T-O9&4H*3L*("`@("`@
M("!]"@H@("`@("`@("1C;V1E("X]("1T:&ES+3Y?96QS92T^=&]#;V1E*"D[
M"@H@("`@("`@(')E='5R;B`D8V]D92`N(")<;B(["B`@("!]"@H@("`@9G5N
M8W1I;VX@8VAE8VLH*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^7W1E
M<W0M/F-H96-K*"D["B`@("`@("`@:68@*"1R97,@(3T]('1R=64I('L*("`@
M("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V5L<VEF<R!A<R`D96QS:68I('L*("`@("`@("`@("`@
M)')E<R`]("1E;'-I9BT^8VAE8VLH*3L*("`@("`@("`@("`@:68@*"1R97,@
M(3T]('1R=64I('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@)'1H:7,M/E]E
M;'-E+3YC:&5C:R@I.PH@("`@("`@(&EF("@D<F5S("$]/2!T<G5E*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]A8W1I;VYS(&%S("1A8W1I;VXI('L*("`@("`@("`@
M("`@)')E<R`]("1A8W1I;VXM/F-H96-K*"D["B`@("`@("`@("`@(&EF("@D
M<F5S("$]/2!T<G5E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<F5Q=6ER97,H*0H@("`@>PH@("`@("`@
M("1R97%U:7)E<R`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?86-T:6]N<R!A<R`D86-T:6]N*2!["B`@("`@("`@("`@("1R97%U:7)E
M<R`](&%R<F%Y7VUE<F=E*"1R97%U:7)E<RP@)&%C=&EO;BT^<F5Q=6ER97,H
M*2D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5L<VEF
M<R!A<R`D96QS:68I('L*("`@("`@("`@("`@)')E<75I<F5S(#T@87)R87E?
M;65R9V4H)')E<75I<F5S+"`D96QS:68M/G)E<75I<F5S*"DI.PH@("`@("`@
M('T*"B`@("`@("`@)')E<75I<F5S(#T@87)R87E?;65R9V4H)')E<75I<F5S
M+"`D=&AI<RT^7W1E<W0M/G)E<75I<F5S*"DL("1T:&ES+3Y?96QS92T^<F5Q
M=6ER97,H*2D["@H@("`@("`@(')E='5R;B`D<F5Q=6ER97,["B`@("!]"@I]
M"@HO*BH*("H@5&AE(%-I979E7T5L<V4Z.B!4:&ES(&-L87-S(')E<')E<V5N
M=',@82!3:65V92!%;'-E(%-T871E;65N=`H@*@H@*B!`875T:&]R("!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@
M("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S<R!3:65V95]%
M;'-E('L*"B`@("!V87(@)%]A8W1I;VYS(#T@87)R87DH*3L*"B`@("!F=6YC
M=&EO;B!3:65V95]%;'-E*"1A8W1I;VYS(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H:7-?87)R87DH)&%C=&EO;G,I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?86-T:6]N<R`]("1A8VET;VYS.PH@("`@("`@('T@96QS96EF("@A:7-?
M;G5L;"@D86-T:6]N<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VYS
M6UT@/2`D86-T:6]N<SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M=&]#;V1E*"D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]A8W1I
M;VYS*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]
M"@H@("`@("`@("1C;V1E(#T@)V5L<V4G("X@(B![(%QN(CL*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V%C=&EO;G,@87,@)&%C=&EO;BD@>PH@("`@("`@
M("`@("`D8V]D92`N/2`G("`@("<@+B`D86-T:6]N+3YT;T-O9&4H*2`N(")<
M;B(["B`@("`@("`@?0H@("`@("`@("1C;V1E("X](")]("(["@H@("`@("`@
M(')E='5R;B`D8V]D93L*("`@('T*"B`@("!F=6YC=&EO;B!S971!8W1I;VYS
M*"1A8W1I;VYS*0H@("`@>PH@("`@("`@("1T:&ES+3Y?86-T:6]N<R`]("1A
M8W1I;VYS.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$%C=&EO;G,H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%C=&EO;G,["B`@("!]"@H@("`@
M9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?86-T:6]N<R!A<R`D86-T:6]N*2!["B`@("`@("`@("`@("1R97,@/2`D
M86-T:6]N+3YC:&5C:R@I.PH@("`@("`@("`@("!I9B`H)')E<R`A/3T@=')U
M92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(')E<75I<F5S*"D*("`@('L*("`@("`@("`D<F5Q=6ER97,@
M/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%C=&EO;G,@
M87,@)&%C=&EO;BD@>PH@("`@("`@("`@("`D<F5Q=6ER97,@/2!A<G)A>5]M
M97)G92@D<F5Q=6ER97,L("1A8W1I;VXM/G)E<75I<F5S*"DI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R97%U:7)E<SL*("`@('T*"GT*"B\J*@H@
M*B!4:&4@4VEE=F5?16QS:68Z.B!4:&ES(&-L87-S(')E<')E<V5N=',@82!3
M:65V92!%;'-I9B!3=&%T96UE;G0*("H*("H@0&%U=&AO<B`@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@26YG
M;R`P+C$*("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@4VEE=F5?16QS:68@
M>PH*("`@('9A<B`D7W1E<W0["B`@("!V87(@)%]A8W1I;VYS(#T@87)R87DH
M*3L*"B`@("!F=6YC=&EO;B!3:65V95]%;'-I9B@D=&5S="`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1E<W0I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?=&5S="`](&YE=R!3:65V95]497-T7T9A;'-E*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]T97-T(#T@)'1E<W0[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?86-T:6]N<UM=(#T@;F5W(%-I
M979E7T%C=&EO;E]+965P*"D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5&5S
M="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&5S=#L*("`@('T*
M"B`@("!F=6YC=&EO;B!S971497-T*"1T97-T*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?=&5S="`]("1T97-T.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$%C
M=&EO;G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%C=&EO;G,[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T06-T:6]N<R@D86-T:6]N<RD*("`@
M('L*("`@("`@("`D=&AI<RT^7V%C=&EO;G,@/2`D86-T:6]N<SL*("`@('T*
M"B`@("!F=6YC=&EO;B!T;T-O9&4H*0H@("`@>PH@("`@("`@("1C;V1E(#T@
M)V5L<VEF("<@+B`D=&AI<RT^7W1E<W0M/G1O0V]D92@I("X@(B![(%QN(CL*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%C=&EO;G,@87,@)&%C=&EO;BD@
M>PH@("`@("`@("`@("`D8V]D92`N/2`G("`@("<@+B`D86-T:6]N+3YT;T-O
M9&4H*2`N(")<;B(["B`@("`@("`@?0H@("`@("`@("1C;V1E("X](")]("([
M"@H@("`@("`@(')E='5R;B`D8V]D93L*("`@('T*"B`@("!F=6YC=&EO;B!C
M:&5C:R@I"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES+3Y?=&5S="T^8VAE
M8VLH*3L*("`@("`@("!I9B`H)')E<R`A/3T@=')U92D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?86-T:6]N<R!A<R`D86-T:6]N*2!["B`@("`@("`@("`@("1R97,@
M/2`D86-T:6]N+3YC:&5C:R@I.PH@("`@("`@("`@("!I9B`H)')E<R`A/3T@
M=')U92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@(&9U;F-T:6]N(')E<75I<F5S*"D*("`@('L*("`@("`@("`D<F5Q=6ER
M97,@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%C=&EO
M;G,@87,@)&%C=&EO;BD@>PH@("`@("`@("`@("`D<F5Q=6ER97,@/2!A<G)A
M>5]M97)G92@D<F5Q=6ER97,L("1A8W1I;VXM/G)E<75I<F5S*"DI.PH@("`@
M("`@('T*"B`@("`@("`@)')E<75I<F5S(#T@87)R87E?;65R9V4H)')E<75I
M<F5S+"`D=&AI<RT^7W1E<W0M/G)E<75I<F5S*"DI.PH*("`@("`@("!R971U
M<FX@)')E<75I<F5S.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!3:65V95]497-T
M.CH@5&AI<R!C;&%S<R!R97!R97-E;G1S(&$@4VEE=F4@5&5S="X@02!T97-T
M(&ES(&$@<&EE8V4*("H@;V8@8V]D92!T:&%T(&5V86QU871E<R!T;R!T<G5E
M(&]R(&9A;'-E+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`
M<&%C:V%G92!);F=O"B`J+PIC;&%S<R!3:65V95]497-T('L*"B`@("!F=6YC
M=&EO;B!T;T-O9&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&]#;V1E*"D@
M1G5N8W1I;VX@3F]T($EM<&QE;65N=&5D(&EN(&-L87-S("<@+B!G971?8VQA
M<W,H)'1H:7,I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-H96-K*"D*("`@('L*
M("`@("`@("!R971U<FX@)V-H96-K*"D@1G5N8W1I;VX@3F]T($EM<&QE;65N
M=&5D(&EN(&-L87-S("<@+B!G971?8VQA<W,H)'1H:7,I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(')E<75I<F5S*"D*("`@('L*("`@("`@("!R971U<FX@87)R
M87DH*3L*("`@('T*"GT*"B\J*@H@*B!4:&4@4VEE=F5?5&5S=%]4<G5E.CH@
M5&AI<R!C;&%S<R!R97!R97-E;G1S(&$@5')U92!T97-T+@H@*@H@*B!`875T
M:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S
M<R!3:65V95]497-T7U1R=64@97AT96YD<R!3:65V95]497-T('L*"B`@("!F
M=6YC=&EO;B!T;T-O9&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=')U92<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!3:65V95]497-T7T9A
M;'-E.CH@5&AI<R!C;&%S<R!R97!R97-E;G1S(&$@1F%L<V4@=&5S="X*("H*
M("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H@0'-I;F-E("`@26YG;R`P+C$*("H@0'!A8VMA9V4@26YG;PH@
M*B\*8VQA<W,@4VEE=F5?5&5S=%]&86QS92!E>'1E;F1S(%-I979E7U1E<W0@
M>PH*("`@(&9U;F-T:6]N('1O0V]D92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("=F86QS92<["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!3:65V
M95]497-T7T%L;&]F.CH@5&AI<R!C;&%S<R!R97!R97-E;G1S(&$@06QL;V8@
M=&5S="!S=')U8W1U<F4N"B`J($5Q=6EV86QE;G0@=&\@82!L;V=I8V%L($%.
M1"!O9B!A;&P@=&AE('1E<W1S(&ET(&-O;G1A:6YS"B`J"B`J($!A=71H;W(@
M($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S
M:6YC92`@($EN9V\@,"XQ"B`J($!P86-K86=E($EN9V\*("HO"F-L87-S(%-I
M979E7U1E<W1?06QL;V8@97AT96YD<R!3:65V95]497-T('L*"B`@("!V87(@
M)%]T97-T<R`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@4VEE=F5?5&5S=%]!
M;&QO9B@D=&5S="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1T97-T*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1E<W1S(#T@)'1E<W0[
M"B`@("`@("`@?2!E;'-E:68@*"%I<U]N=6QL*"1T97-T*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W1E<W1S6UT@/2`D=&5S=#L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@=&]#;V1E*"D*("`@('L*("`@("`@("`D8V]D92`]
M("<G.PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W1E<W1S*2`^(#$I('L*
M("`@("`@("`@("`@)'1E<W1L:7-T(#T@)R<["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?=&5S=',@87,@)'1E<W0I('L*("`@("`@("`@("`@("`@
M("1T97-T;&ES="`N/2`H96UP='DH)'1E<W1L:7-T*2D@/R`G)R`Z("<L("<[
M"B`@("`@("`@("`@("`@("`D=&5S=&QI<W0@+CT@=')I;2@D=&5S="T^=&]#
M;V1E*"DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8V]D92`](")A
M;&QO9B`H("1T97-T;&ES="`I(CL*("`@("`@("!](&5L<V5I9B`H8V]U;G0H
M)'1H:7,M/E]T97-T<RD@/3T@,2D@>PH@("`@("`@("`@("`D8V]D92`]("1T
M:&ES+3Y?=&5S='-;,%TM/G1O0V]D92@I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`G9F%L<V4G.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&-O9&4["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@
M>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?=&5S=',@87,@)'1E<W0I('L*
M("`@("`@("`@("`@)')E<R`]("1T97-T+3YC:&5C:R@I.PH@("`@("`@("`@
M("!I9B`H)')E<R`A/3T@=')U92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&%D9%1E<W0H)'1E<W0I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]T97-T<UM=(#T@)'1E<W0["B`@("!]"@H@
M("`@9G5N8W1I;VX@9V5T5&5S=',H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W1E<W1S.PH@("`@?0H*("`@(&9U;F-T:6]N(')E<75I<F5S*"D*
M("`@('L*("`@("`@("`D<F5Q=6ER97,@/2!A<G)A>2@I.PH*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7W1E<W1S(&%S("1T97-T*2!["B`@("`@("`@("`@
M("1R97%U:7)E<R`](&%R<F%Y7VUE<F=E*"1R97%U:7)E<RP@)'1E<W0M/G)E
M<75I<F5S*"DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97%U:7)E
M<SL*("`@('T*"GT*"B\J*@H@*B!4:&4@4VEE=F5?5&5S=%]!;GEO9CHZ(%1H
M:7,@8VQA<W,@<F5P<F5S96YT<R!A($%N>6]F('1E<W0@<W1R=6-T=7)E+@H@
M*B!%<75I=F%L96YT('1O(&$@;&]G:6-A;"!/4B!O9B!A;&P@=&AE('1E<W1S
M(&ET(&-O;G1A:6YS"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($EN9V\@,"XQ"B`J
M($!P86-K86=E($EN9V\*("HO"F-L87-S(%-I979E7U1E<W1?06YY;V8@97AT
M96YD<R!3:65V95]497-T('L*"B`@("!V87(@)%]T97-T<R`](&%R<F%Y*"D[
M"@H@("`@9G5N8W1I;VX@4VEE=F5?5&5S=%]!;GEO9B@D=&5S="`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T97-T*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W1E<W1S(#T@)'1E<W0["B`@("`@("`@?2!E;'-E:68@
M*"%I<U]N=6QL*"1T97-T*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1E<W1S
M6UT@/2`D=&5S=#L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=&]#
M;V1E*"D*("`@('L*("`@("`@("`D=&5S=&QI<W0@/2`G)SL*("`@("`@("!I
M9B`H8V]U;G0H)'1H:7,M/E]T97-T<RD@/B`Q*2!["B`@("`@("`@("`@("1T
M97-T;&ES="`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1E
M<W1S(&%S("1T97-T*2!["B`@("`@("`@("`@("`@("`D=&5S=&QI<W0@+CT@
M*&5M<'1Y*"1T97-T;&ES="DI(#\@)R<@.B`G+"`G.PH@("`@("`@("`@("`@
M("`@)'1E<W1L:7-T("X]('1R:6TH)'1E<W0M/G1O0V]D92@I*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&-O9&4@/2`B86YY;V8@*"`D=&5S=&QI
M<W0@*2(["B`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1T:&ES+3Y?=&5S=',I
M(#T](#$I('L*("`@("`@("`@("`@)&-O9&4@/2`D=&AI<RT^7W1E<W1S6S!=
M+3YT;T-O9&4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@)V9A;'-E)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;V1E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&%D9%1E<W0H)'1E<W0I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]T97-T<UM=(#T@)'1E<W0["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T5&5S=',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1E
M<W1S.PH@("`@?0H*("`@(&9U;F-T:6]N(&-H96-K*"D*("`@('L*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7W1E<W1S(&%S("1T97-T*2!["B`@("`@("`@
M("`@("1R97,@/2`D=&5S="T^8VAE8VLH*3L*("`@("`@("`@("`@:68@*"1R
M97,@(3T]('1R=64I('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("!F=6YC=&EO;B!R97%U:7)E<R@I"B`@("!["B`@("`@("`@
M)')E<75I<F5S(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]T97-T<R!A<R`D=&5S="D@>PH@("`@("`@("`@("`D<F5Q=6ER97,@/2!A
M<G)A>5]M97)G92@D<F5Q=6ER97,L("1T97-T+3YR97%U:7)E<R@I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5Q=6ER97,["B`@("!]"@I]"@HO
M*BH*("H@5&AE(%-I979E7U1E<W1?4F5L871I;VYA;#HZ(&-L87-S(')E<')E
M<V5N=',@82!R96QA=&EO;F%L('1E<W0N"B`J"B`J($!A=71H;W(@(%1O9&0@
M365R<FET="`\=&UE<G)I='1`96UA:6PN87)I>F]N82YE9'4^"B`J($!S:6YC
M92`@($EN9V\@,2XP"B`J($!P86-K86=E($EN9V\*("HO"F-L87-S(%-I979E
M7U1E<W1?4F5L871I;VYA;"!E>'1E;F1S(%-I979E7U1E<W0@>PH*("`@('9A
M<B`D7W9A<G,@/2!A<G)A>2@I.PH*("`@(&9U;F-T:6]N(%-I979E7U1E<W1?
M4F5L871I;VYA;"@D=F%R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]V87)S6R=C;VUP87)I<V]N)UT@/2`H:7-S970H)'9A<G-;)V-O;7!A
M<FES;VXG72DI(#\@)'9A<G-;)V-O;7!A<FES;VXG72`Z("<G.PH@("`@("`@
M("1T:&ES+3Y?=F%R<ULG:&5A9&5R<R==(#T@*&ES<V5T*"1V87)S6R=H96%D
M97)S)UTI*2`_("1V87)S6R=H96%D97)S)UT@.B`G)SL*("`@("`@("`D=&AI
M<RT^7W9A<G-;)W9A;'5E)UT@/2`H:7-S970H)'9A<G-;)W9A;'5E)UTI*2`_
M("1V87)S6R=V86QU92==(#H@,#L*("`@('T*"B`@("!F=6YC=&EO;B!T;T-O
M9&4H*0H@("`@>PH@("`@("`@("1C;V1E(#T@)VAE861E<B`Z=F%L=64@(B<@
M+@H@("`@("`@("`@("`D=&AI<RT^7W9A<G-;)V-O;7!A<FES;VXG72`N("<B
M("<@+@H@("`@("`@("`@("`G.F-O;7!A<F%T;W(@(FD[87-C:6DM;G5M97)I
M8R(@)SL*"B`@("`@("`@)&AE861E<G,@/2!P<F5G7W-P;&ET*"<H7')<;GQ<
M;GQ<<BDG+"`D=&AI<RT^7W9A<G-;)VAE861E<G,G72D["B`@("`@("`@)&AE
M861E<E]C;W5N="`](&-O=6YT*"1H96%D97)S*3L*"B`@("`@("`@:68@*"1H
M96%D97)?8V]U;G0@/B`Q*2!["B`@("`@("`@("`@("1C;V1E("X](");(CL*
M("`@("`@("`@("`@)&AE861E<G-T<B`]("<G.PH*("`@("`@("`@("`@9F]R
M96%C:"`H)&AE861E<G,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)&AE
M861E<G-T<B`N/2`H96UP='DH)&AE861E<G-T<BD@/R`G(B<@.B`G+"`B)RD@
M+@H@("`@("`@("`@("`@("`@("`@($EN9V]?4V-R:7!T7W-I979E.CIE<V-A
M<&53=')I;F<H)'9A;"D@+B`G(B<["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1C;V1E("X]("1H96%D97)S='(@+B`B72`B.PH@("`@("`@('T@96QS
M96EF("@D:&5A9&5R7V-O=6YT(#T](#$I('L*("`@("`@("`@("`@)&-O9&4@
M+CT@)R(G("X@26YG;U]38W)I<'1?<VEE=F4Z.F5S8V%P95-T<FEN9R@D:&5A
M9&5R<ULP72D@+B`G(B`G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C
M;V1E("X@)ULB)R`N("1T:&ES+3Y?=F%R<ULG=F%L=64G72`N("<B72<["B`@
M("`@?0H*("`@("!F=6YC=&EO;B!C:&5C:R@I"B`@("`@>PH@("`@("`@("`D
M:&5A9&5R<R`]('!R96=?<W!L:70H)RA<<EQN?%QN?%QR*2<L("1T:&ES+3Y?
M=F%R<ULG:&5A9&5R<R==*3L*("`@("`@("`@<F5T=7)N("1H96%D97)S(#\@
M=')U92`Z(%\H(DYO(&AE861E<G,@<W!E8VEF:65D(BD["B`@("`@?0H*("`@
M("!F=6YC=&EO;B!R97%U:7)E<R@I"B`@("`@>PH@("`@("`@("!R971U<FX@
M87)R87DH)W)E;&%T:6]N86PG+"`G8V]M<&%R871O<BUI.V%S8VEI+6YU;65R
M:6,G*3L*("`@("!]"@I]"@HO*BH*("H@5&AE(%-I979E7U1E<W1?4VEZ93HZ
M(%1H:7,@8VQA<W,@<F5P<F5S96YT<R!A(&UE<W-A9V4@<VEZ92!T97-T+@H@
M*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O
M"B`J+PIC;&%S<R!3:65V95]497-T7U-I>F4@97AT96YD<R!3:65V95]497-T
M('L*"B`@("!V87(@)%]V87)S(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!3
M:65V95]497-T7U-I>F4H)'9A<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?=F%R<ULG8V]M<&%R:7-O;B==(#T@*&ES<V5T*"1V87)S6R=C
M;VUP87)I<V]N)UTI*2`_("1V87)S6R=C;VUP87)I<V]N)UT@.B`G)SL*("`@
M("`@("`D=&AI<RT^7W9A<G-;)W-I>F4G72`]("AI<W-E="@D=F%R<ULG<VEZ
M92==*2D@/R`D=F%R<ULG<VEZ92==(#H@)R<["B`@("!]"@H@("`@9G5N8W1I
M;VX@=&]#;V1E*"D*("`@('L*("`@("`@("!R971U<FX@)W-I>F4@)R`N("1T
M:&ES+3Y?=F%R<ULG8V]M<&%R:7-O;B==("X@)R`G("X@)'1H:7,M/E]V87)S
M6R=S:7IE)UT["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@
M("`@("`@(&EF("@A*&ES<V5T*"1T:&ES+3Y?=F%R<ULG8V]M<&%R:7-O;B==
M*2`F)@H@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?=F%R<ULG<VEZ92==
M*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@HO*BH*("H@5&AE(%-I979E
M7U1E<W1?3F]T.CH@5&AI<R!C;&%S<R!R97!R97-E;G1S('1H92!I;G9E<G-E
M(&]F(&$@9VEV96X@=&5S="X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@26YG;R`P
M+C$*("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@4VEE=F5?5&5S=%].;W0@
M97AT96YD<R!3:65V95]497-T('L*"B`@("!V87(@)%]T97-T(#T@87)R87DH
M*3L*"B`@("!F=6YC=&EO;B!3:65V95]497-T7TYO="@D=&5S="D*("`@('L*
M("`@("`@("`D=&AI<RT^7W1E<W0@/2`D=&5S=#L*("`@('T*"B`@("!F=6YC
M=&EO;B!C:&5C:R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&5S
M="T^8VAE8VLH*3L*("`@('T*"B`@("!F=6YC=&EO;B!T;T-O9&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`G;F]T("<@+B`D=&AI<RT^7W1E<W0M/G1O0V]D
M92@I.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!3:65V95]497-T7T5X:7-T<SHZ
M(%1H:7,@8VQA<W,@<F5P<F5S96YT<R!A('1E<W0@9F]R('1H92!E>&ES='-A
M;F-E(&]F"B`J(&]N92!O<B!M;W)E(&AE861E<G,@:6X@82!M97-S86=E+@H@
M*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O
M"B`J+PIC;&%S<R!3:65V95]497-T7T5X:7-T<R!E>'1E;F1S(%-I979E7U1E
M<W0@>PH*("`@('9A<B`D7W9A<G,@/2!A<G)A>2@I.PH*("`@(&9U;F-T:6]N
M(%-I979E7U1E<W1?17AI<W1S*"1V87)S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D=&AI<RT^7W9A<G-;)VAE861E<G,G72`]("AI<W-E="@D=F%R<ULG
M:&5A9&5R<R==*2D@/R`D=F%R<ULG:&5A9&5R<R==(#H@)R<["B`@("!]"@H@
M("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@("`@("`@("1H96%D97)S(#T@
M<')E9U]S<&QI="@G*%QR7&Y\7&Y\7'(I)RP@)'1H:7,M/E]V87)S6R=H96%D
M97)S)UTI.PH@("`@("`@(&EF("@A)&AE861E<G,I('L*("`@("`@("`@("`@
M<F5T=7)N(%\H(DYO(&AE861E<G,@<W!E8VEF:65D(BD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!T;T-O
M9&4H*0H@("`@>PH@("`@("`@("1C;V1E(#T@)V5X:7-T<R`G.PH@("`@("`@
M("1H96%D97)S(#T@<')E9U]S<&QI="@G*%QR7&Y\7&Y\7'(I)RP@)'1H:7,M
M/E]V87)S6R=H96%D97)S)UTI.PH@("`@("`@(&EF("AC;W5N="@D:&5A9&5R
M<RD@/B`Q*2!["B`@("`@("`@("`@("1C;V1E("X](");(CL*("`@("`@("`@
M("`@)&AE861E<G-T<B`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D:&5A
M9&5R<R!A<R`D:&5A9&5R*2!["B`@("`@("`@("`@("`@("`D:&5A9&5R<W1R
M("X]("AE;7!T>2@D:&5A9&5R<W1R*2`_("<B)R`Z("<L("(G*2`N"B`@("`@
M("`@("`@("`@("`@("`@26YG;U]38W)I<'1?<VEE=F4Z.F5S8V%P95-T<FEN
M9R@D:&5A9&5R*2`N("<B)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M8V]D92`N/2`D:&5A9&5R<W1R("X@(ET@(CL*("`@("`@("!](&5L<V5I9B`H
M8V]U;G0H)&AE861E<G,I(#T](#$I('L*("`@("`@("`@("`@)&-O9&4@+CT@
M)R(G("X@26YG;U]38W)I<'1?<VEE=F4Z.F5S8V%P95-T<FEN9R@D:&5A9&5R
M<ULP72D@+B`G(B`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`B*BIE<G)O<BHJ($YO($AE861E<G,@4W!E8VEF:65D(CL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D8V]D93L*("`@('T*"GT*"B\J*@H@*B!4
M:&4@4VEE=F5?5&5S=%]!9&1R97-S.CH@5&AI<R!C;&%S<R!R97!R97-E;G1S
M(&$@=&5S="!O;B!P87)T<R!O<B!A;&P@;V8*("H@=&AE(&%D9')E<W-E<R!I
M;B!T:&4@9VEV96X@9FEE;&1S+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!);F=O
M(#`N,0H@*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S<R!3:65V95]497-T7T%D
M9')E<W,@97AT96YD<R!3:65V95]497-T('L*"B`@("!V87(@)%]V87)S(#T@
M87)R87DH*3L*"B`@("!F=6YC=&EO;B!3:65V95]497-T7T%D9')E<W,H)'9A
M<G,I"B`@("!["B`@("`@("`@)'1H:7,M/E]V87)S6R=H96%D97)S)UT@/2`H
M:7-S970H)'9A<G-;)VAE861E<G,G72DI(#\@)'9A<G-;)VAE861E<G,G72`Z
M("<G.PH@("`@("`@("1T:&ES+3Y?=F%R<ULG8V]M<&%R871O<B==(#T@*&ES
M<V5T*"1V87)S6R=C;VUP87)A=&]R)UTI*2`_("1V87)S6R=C;VUP87)A=&]R
M)UT@.B`G:3MA<V-I:2UC87-E;6%P)SL*("`@("`@("`D=&AI<RT^7W9A<G-;
M)VUA=&-H+71Y<&4G72`]("AI<W-E="@D=F%R<ULG;6%T8V@M='EP92==*2D@
M/R`D=F%R<ULG;6%T8V@M='EP92==(#H@)SII<R<["B`@("`@("`@)'1H:7,M
M/E]V87)S6R=A9&1R97-S+7!A<G0G72`]("AI<W-E="@D=F%R<ULG861D<F5S
M<RUP87)T)UTI*2`_("1V87)S6R=A9&1R97-S+7!A<G0G72`Z("<Z86QL)SL*
M("`@("`@("`D=&AI<RT^7W9A<G-;)V%D9')E<W-E<R==(#T@*&ES<V5T*"1V
M87)S6R=A9&1R97-S97,G72DI(#\@)'9A<G-;)V%D9')E<W-E<R==(#H@)R<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@("`@("`@("1H
M96%D97)S(#T@<')E9U]S<&QI="@G*%QR7&Y\7&Y\7'(I)RP@)'1H:7,M/E]V
M87)S6R=H96%D97)S)UTI.PH@("`@("`@(&EF("@A)&AE861E<G,I('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&%D
M9')E<W-E<R`]('!R96=?<W!L:70H)RA<<EQN?%QN?%QR*2<L("1T:&ES+3Y?
M=F%R<ULG861D<F5S<V5S)UTI.PH@("`@("`@(&EF("@A)&%D9')E<W-E<RD@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!T;T-O9&4H*0H@
M("`@>PH@("`@("`@("1C;V1E(#T@)V%D9')E<W,@)R`N"B`@("`@("`@("`@
M("1T:&ES+3Y?=F%R<ULG861D<F5S<RUP87)T)UT@+B`G("<@+@H@("`@("`@
M("`@("`G.F-O;7!A<F%T;W(@(B<@+B`D=&AI<RT^7W9A<G-;)V-O;7!A<F%T
M;W(G72`N("<B("<@+@H@("`@("`@("`@("`D=&AI<RT^7W9A<G-;)VUA=&-H
M+71Y<&4G72`N("<@)SL*"B`@("`@("`@)&AE861E<G,@/2!P<F5G7W-P;&ET
M*"<H7')<;GQ<;GQ<<GPL*2<L("1T:&ES+3Y?=F%R<ULG:&5A9&5R<R==*3L*
M("`@("`@("!I9B`H8V]U;G0H)&AE861E<G,I(#X@,2D@>PH@("`@("`@("`@
M("`D8V]D92`N/2`B6R(["B`@("`@("`@("`@("1H96%D97)S='(@/2`G)SL*
M("`@("`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@)&AE861E<BD@>PH@
M("`@("`@("`@("`@("`@)&AE861E<B`]('1R:6TH)&AE861E<BD["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1H96%D97(I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&AE861E<G-T<B`N/2!E;7!T>2@D:&5A9&5R<W1R*2`_("<B
M)R`Z("<L("(G.PH@("`@("`@("`@("`@("`@("`@("1H96%D97)S='(@+CT@
M26YG;U]38W)I<'1?<VEE=F4Z.F5S8V%P95-T<FEN9R@D:&5A9&5R+"`D=&AI
M<RT^7W9A<G-;)VUA=&-H+71Y<&4G72`]/2`G.G)E9V5X)RD@+B`G(B<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-O
M9&4@+CT@)&AE861E<G-T<B`N(")=("(["B`@("`@("`@?2!E;'-E:68@*&-O
M=6YT*"1H96%D97)S*2`]/2`Q*2!["B`@("`@("`@("`@("1C;V1E("X]("<B
M)R`N($EN9V]?4V-R:7!T7W-I979E.CIE<V-A<&53=')I;F<H)&AE861E<G-;
M,%TL("1T:&ES+3Y?=F%R<ULG;6%T8V@M='EP92==(#T]("<Z<F5G97@G*2`N
M("<B("<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(").
M;R!(96%D97)S(%-P96-I9FEE9"(["B`@("`@("`@?0H*("`@("`@("`D861D
M<F5S<V5S(#T@<')E9U]S<&QI="@G*%QR7&Y\7&Y\7'(I)RP@)'1H:7,M/E]V
M87)S6R=A9&1R97-S97,G72D["B`@("`@("`@:68@*&-O=6YT*"1A9&1R97-S
M97,I(#X@,2D@>PH@("`@("`@("`@("`D8V]D92`N/2`B6R(["B`@("`@("`@
M("`@("1A9&1R97-S<W1R(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1A
M9&1R97-S97,@87,@)&%D9'(I('L*("`@("`@("`@("`@("`@("1A9&1R(#T@
M=')I;2@D861D<BD["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1A9&1R97-S<W1R("X](&5M<'1Y
M*"1A9&1R97-S<W1R*2`_("<B)R`Z("<L("(G.PH@("`@("`@("`@("`@("`@
M("`@("1A9&1R97-S<W1R("X]($EN9V]?4V-R:7!T7W-I979E.CIE<V-A<&53
M=')I;F<H)&%D9'(L("1T:&ES+3Y?=F%R<ULG;6%T8V@M='EP92==(#T]("<Z
M<F5G97@G*2`N("<B)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D8V]D92`N/2`D861D<F5S<W-T<B`N(")=("(["B`@
M("`@("`@?2!E;'-E:68@*&-O=6YT*"1A9&1R97-S97,I(#T](#$I('L*("`@
M("`@("`@("`@)&-O9&4@+CT@)R(G("X@26YG;U]38W)I<'1?<VEE=F4Z.F5S
M8V%P95-T<FEN9R@D861D<F5S<V5S6S!=+"`D=&AI<RT^7W9A<G-;)VUA=&-H
M+71Y<&4G72`]/2`G.G)E9V5X)RD@+B`G(B`G.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`B3F\@061D<F5S<V5S(%-P96-I9FEE9"([
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O9&4["B`@("!]"@H@("`@
M9G5N8W1I;VX@<F5Q=6ER97,H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M7W9A<G-;)VUA=&-H+71Y<&4G72`]/2`G.G)E9V5X)RD@>PH@("`@("`@("`@
M("!R971U<FX@87)R87DH)W)E9V5X)RD["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!A<G)A>2@I.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!3:65V95]497-T
M7TAE861E<CHZ(%1H:7,@8VQA<W,@<F5P<F5S96YT<R!A('1E<W0@;VX@=&AE
M(&-O;G1E;G1S(&]F"B`J(&]N92!O<B!M;W)E(&AE861E<G,@:6X@82!M97-S
M86=E+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G
M92!);F=O"B`J+PIC;&%S<R!3:65V95]497-T7TAE861E<B!E>'1E;F1S(%-I
M979E7U1E<W0@>PH*("`@('9A<B`D7W9A<G,@/2!A<G)A>2@I.PH*("`@(&9U
M;F-T:6]N(%-I979E7U1E<W1?2&5A9&5R*"1V87)S(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D=&AI<RT^7W9A<G-;)VAE861E<G,G72`]("AI<W-E="@D
M=F%R<ULG:&5A9&5R<R==*2D@/R`D=F%R<ULG:&5A9&5R<R==(#H@)U-U8FIE
M8W0G.PH@("`@("`@("1T:&ES+3Y?=F%R<ULG8V]M<&%R871O<B==(#T@*&ES
M<V5T*"1V87)S6R=C;VUP87)A=&]R)UTI*2`_("1V87)S6R=C;VUP87)A=&]R
M)UT@.B`G:3MA<V-I:2UC87-E;6%P)SL*("`@("`@("`D=&AI<RT^7W9A<G-;
M)VUA=&-H+71Y<&4G72`]("AI<W-E="@D=F%R<ULG;6%T8V@M='EP92==*2D@
M/R`D=F%R<ULG;6%T8V@M='EP92==(#H@)SII<R<["B`@("`@("`@)'1H:7,M
M/E]V87)S6R=S=')I;F=S)UT@/2`H:7-S970H)'9A<G-;)W-T<FEN9W,G72DI
M(#\@)'9A<G-;)W-T<FEN9W,G72`Z("<G.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&-H96-K*"D*("`@('L*("`@("`@("`D:&5A9&5R<R`]('!R96=?<W!L:70H
M)R@H/SPA7%Q<*5PL?%QR7&Y\7&Y\7'(I)RP@)'1H:7,M/E]V87)S6R=H96%D
M97)S)UTI.PH@("`@("`@(&EF("@A)&AE861E<G,I('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'-T<FEN9W,@/2!P
M<F5G7W-P;&ET*"<H*#\\(5Q<7"E<+'Q<<EQN?%QN?%QR*2<L("1T:&ES+3Y?
M=F%R<ULG<W1R:6YG<R==*3L*("`@("`@("!I9B`H(21S=')I;F=S*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N('1O0V]D92@I"B`@("![
M"B`@("`@("`@)&-O9&4@/2`G:&5A9&5R("<@+@H@("`@("`@("`@("`G.F-O
M;7!A<F%T;W(@(B<@+B`D=&AI<RT^7W9A<G-;)V-O;7!A<F%T;W(G72`N("<B
M("<@+@H@("`@("`@("`@("`D=&AI<RT^7W9A<G-;)VUA=&-H+71Y<&4G72`N
M("<@)SL*"B`@("`@("`@)&AE861E<G,@/2!P<F5G7W-P;&ET*"<H7')<;GQ<
M;GQ<<BDG+"`D=&AI<RT^7W9A<G-;)VAE861E<G,G72D["B`@("`@("`@:68@
M*&-O=6YT*"1H96%D97)S*2`^(#$I('L*("`@("`@("`@("`@)&-O9&4@+CT@
M(ELB.PH@("`@("`@("`@("`D:&5A9&5R<W1R(#T@)R<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1H96%D97)S(&%S("1H96%D97(I('L*("`@("`@("`@("`@
M("`@("1H96%D97)S='(@+CT@96UP='DH)&AE861E<G-T<BD@/R`G(B<@.B`G
M+"`B)SL*("`@("`@("`@("`@("`@("1H96%D97)S='(@+CT@26YG;U]38W)I
M<'1?<VEE=F4Z.F5S8V%P95-T<FEN9R@D:&5A9&5R+"`D=&AI<RT^7W9A<G-;
M)VUA=&-H+71Y<&4G72`]/2`G.G)E9V5X)RD@+B`G(B<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&-O9&4@+CT@)&AE861E<G-T<B`N(")=("(["B`@
M("`@("`@?2!E;'-E:68@*&-O=6YT*"1H96%D97)S*2`]/2`Q*2!["B`@("`@
M("`@("`@("1C;V1E("X]("<B)R`N("1H96%D97)S6S!=("X@)R(@)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@7R@B3F\@:&5A9&5R
M<R!S<&5C:69I960B*3L*("`@("`@("!]"@H@("`@("`@("1S=')I;F=S(#T@
M<')E9U]S<&QI="@G*%QR7&Y\7&Y\7'(I)RP@)'1H:7,M/E]V87)S6R=S=')I
M;F=S)UTI.PH@("`@("`@(&EF("AC;W5N="@D<W1R:6YG<RD@/B`Q*2!["B`@
M("`@("`@("`@("1C;V1E("X](");(CL*("`@("`@("`@("`@)'-T<FEN9VQI
M<W0@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)'-T<FEN9W,@87,@)'-T
M<BD@>PH@("`@("`@("`@("`@("`@)'-T<FEN9VQI<W0@+CT@96UP='DH)'-T
M<FEN9VQI<W0I(#\@)R(G(#H@)RP@(B<["B`@("`@("`@("`@("`@("`D<W1R
M:6YG;&ES="`N/2!);F=O7U-C<FEP=%]S:65V93HZ97-C87!E4W1R:6YG*"1S
M='(L("1T:&ES+3Y?=F%R<ULG;6%T8V@M='EP92==(#T]("<Z<F5G97@G*2`N
M("<B)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8V]D92`N/2`D<W1R
M:6YG;&ES="`N(")=("(["B`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1S=')I
M;F=S*2`]/2`Q*2!["B`@("`@("`@("`@("1C;V1E("X]("<B)R`N($EN9V]?
M4V-R:7!T7W-I979E.CIE<V-A<&53=')I;F<H)'-T<FEN9W-;,%TL("1T:&ES
M+3Y?=F%R<ULG;6%T8V@M='EP92==(#T]("<Z<F5G97@G*2`N("<B("<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%\H(DYO('-T<FEN
M9W,@<W!E8VEF:65D(BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O
M9&4["B`@("!]"@H@("`@9G5N8W1I;VX@<F5Q=6ER97,H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^7W9A<G-;)VUA=&-H+71Y<&4G72`]/2`G.G)E9V5X
M)RD@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)W)E9V5X)RD["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*?0H*+RHJ"B`J
M($$@0V]M;65N="X@5&AI<R!A;F0@4VEE=F5?268@<VAO=6QD(')E86QL>2!E
M>'1E;F1S(&$@4VEE=F5?0FQO8VL@979E;G1U86QL>2X*("H*("H@0&%U=&AO
M<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@
M0'-I;F-E("`@26YG;R`P+C$*("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@
M4VEE=F5?0V]M;65N="!["@H@("`@=F%R("1?8V]M;65N=#L*"B`@("!F=6YC
M=&EO;B!3:65V95]#;VUM96YT*"1C;VUM96YT*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?8V]M;65N="`]("1C;VUM96YT.PH@("`@?0H*("`@(&9U;F-T:6]N
M('1O0V]D92@I"B`@("!["B`@("`@("`@)&-O9&4@/2`G)SL*("`@("`@("`D
M;&EN97,@/2!P<F5G7W-P;&ET*"<H7')<;GQ<;GQ<<BDG+"`D=&AI<RT^7V-O
M;6UE;G0I.PH@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@
M("`@("`@("`@("`D;&EN92`]('1R:6TH)&QI;F4I.PH@("`@("`@("`@("!I
M9B`H<W1R;&5N*"1L:6YE*2D@>PH@("`@("`@("`@("`@("`@)&-O9&4@+CT@
M*&5M<'1Y*"1C;V1E*2`_("<G(#H@(EQN(BD@+B`G(R`G("X@)&QI;F4["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)&-O9&4L($Y,4SHZ9V5T0VAA<G-E="@I+"`G551&
M+3@G*3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&5C:R@I"B`@("!["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@<F5Q=6ER97,H
M*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*?0H*+RHJ
M"B`J(%1H92!3:65V95]!8W1I;VXZ.B!4:&ES(&-L87-S(')E<')E<V5N=',@
M86X@86-T:6]N(&EN(&$@4VEE=F4@<V-R:7!T+@H@*B!!;B!A8W1I;VX@:7,@
M86YY=&AI;F<@=&AA="!H87,@82!S:61E(&5F9F5C="!E9SH@9&ES8V%R9"P@
M<F5D:7)E8W0N"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($EN9V\@,"XQ"B`J($!P
M86-K86=E($EN9V\*("HO"F-L87-S(%-I979E7T%C=&EO;B!["@H@("`@9G5N
M8W1I;VX@=&]#;V1E*"D*("`@('L*("`@("`@("!R971U<FX@)W1O0V]D92@I
M($9U;F-T:6]N($YO="!);7!L96UE;G1E9"!I;B!C;&%S<R`G("X@9V5T7V-L
M87-S*"1T:&ES*2`["B`@("!]"@H@("`@9G5N8W1I;VX@=&]3=')I;F<H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^=&]#;V1E*"D["B`@("!]"@H@
M("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@("`@("`@(')E='5R;B`G8VAE
M8VLH*2!&=6YC=&EO;B!.;W0@26UP;&5M96YT960@:6X@8VQA<W,@)R`N(&=E
M=%]C;&%S<R@D=&AI<RD@.PH@("`@?0H*("`@(&9U;F-T:6]N(')E<75I<F5S
M*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*"GT*"B\J
M*@H@*B!4:&4@4VEE=F5?06-T:6]N7U)E9&ER96-T.CH@5&AI<R!C;&%S<R!R
M97!R97-E;G1S(&$@<F5D:7)E8W0@86-T:6]N+@H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S<R!3:65V
M95]!8W1I;VY?4F5D:7)E8W0@97AT96YD<R!3:65V95]!8W1I;VX@>PH*("`@
M('9A<B`D7W9A<G,@/2!A<G)A>2@I.PH*("`@(&9U;F-T:6]N(%-I979E7T%C
M=&EO;E]2961I<F5C="@D=F%R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]V87)S6R=A9&1R97-S)UT@/2`H:7-S970H)'9A<G-;)V%D9')E
M<W,G72DI(#\@)'9A<G-;)V%D9')E<W,G72`Z("<G.PH@("`@?0H*("`@(&9U
M;F-T:6]N('1O0V]D92@D9&5P=&@@/2`P*0H@("`@>PH@("`@("`@(')E='5R
M;B!S=')?<F5P96%T*"<@)RP@)&1E<'1H("H@-"D@+B`G<F5D:7)E8W0@)R`N
M"B`@("`@("`@("`@("<B)R`N($EN9V]?4V-R:7!T7W-I979E.CIE<V-A<&53
M=')I;F<H)'1H:7,M/E]V87)S6R=A9&1R97-S)UTI("X@)R([)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!C:&5C:R@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?=F%R<ULG861D<F5S<R==*2D@>PH@("`@("`@("`@("!R971U
M<FX@7R@B36ES<VEN9R!A9&1R97-S('1O(')E9&ER96-T(&UE<W-A9V4@=&\B
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H*
M+RHJ"B`J(%1H92!3:65V95]!8W1I;VY?4F5J96-T.CH@8VQA<W,@<F5P<F5S
M96YT<R!A(')E:F5C="!A8W1I;VXN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($EN
M9V\@,"XQ"B`J($!P86-K86=E($EN9V\*("HO"F-L87-S(%-I979E7T%C=&EO
M;E]296IE8W0@97AT96YD<R!3:65V95]!8W1I;VX@>PH*("`@('9A<B`D7W9A
M<G,@/2!A<G)A>2@I.PH*("`@(&9U;F-T:6]N(%-I979E7T%C=&EO;E]296IE
M8W0H)'9A<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R
M<ULG<F5A<V]N)UT@/2`H:7-S970H)'9A<G-;)W)E87-O;B==*2D@/R`D=F%R
M<ULG<F5A<V]N)UT@.B`G)SL*("`@('T*"B`@("!F=6YC=&EO;B!T;T-O9&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`G<F5J96-T("(G("X@26YG;U]38W)I
M<'1?<VEE=F4Z.F5S8V%P95-T<FEN9R@D=&AI<RT^7W9A<G-;)W)E87-O;B==
M*2`N("<B.R<["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W9A<G-;)W)E87-O;B==*2D@>PH@
M("`@("`@("`@("!R971U<FX@7R@B36ES<VEN9R!R96%S;VX@9F]R(')E:F5C
M="(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@9G5N8W1I;VX@<F5Q=6ER97,H*0H@("`@>PH@("`@("`@(')E='5R;B!A
M<G)A>2@G<F5J96-T)RD["B`@("!]"@I]"@HO*BH*("H@5&AE(%-I979E7T%C
M=&EO;E]+965P.CH@8VQA<W,@<F5P<F5S96YT<R!A(&ME97`@86-T:6]N+@H@
M*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O
M"B`J+PIC;&%S<R!3:65V95]!8W1I;VY?2V5E<"!E>'1E;F1S(%-I979E7T%C
M=&EO;B!["@H@("`@9G5N8W1I;VX@=&]#;V1E*"D*("`@('L*("`@("`@("!R
M971U<FX@)VME97`[)SL*("`@('T*"B`@("!F=6YC=&EO;B!C:&5C:R@I"B`@
M("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@HO*BH*("H@5&AE
M(%-I979E7T%C=&EO;E]$:7-C87)D.CH@8VQA<W,@<F5P<F5S96YT<R!A(&1I
M<V-A<F0@86-T:6]N+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@
M*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S<R!3:65V95]!8W1I;VY?1&ES8V%R
M9"!E>'1E;F1S(%-I979E7T%C=&EO;B!["@H@("`@9G5N8W1I;VX@=&]#;V1E
M*"D*("`@('L*("`@("`@("!R971U<FX@)V1I<V-A<F0[)SL*("`@('T*"B`@
M("!F=6YC=&EO;B!C:&5C:R@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@I]"@HO*BH*("H@5&AE(%-I979E7T%C=&EO;E]3=&]P.CH@8VQA
M<W,@<F5P<F5S96YT<R!A('-T;W`@86-T:6]N+@H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S<R!3:65V
M95]!8W1I;VY?4W1O<"!E>'1E;F1S(%-I979E7T%C=&EO;B!["@H@("`@9G5N
M8W1I;VX@=&]#;V1E*"D*("`@('L*("`@("`@("!R971U<FX@)W-T;W`[)SL*
M("`@('T*"B`@("!F=6YC=&EO;B!C:&5C:R@I"B`@("!["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@I]"@HO*BH*("H@5&AE(%-I979E7T%C=&EO;E]&
M:6QE:6YT;SHZ(&-L87-S(')E<')E<V5N=',@82!F:6QE:6YT;R!A8W1I;VXN
M"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($!S:6YC92`@($EN9V\@,"XQ"B`J($!P86-K86=E($EN
M9V\*("HO"F-L87-S(%-I979E7T%C=&EO;E]&:6QE:6YT;R!E>'1E;F1S(%-I
M979E7T%C=&EO;B!["@H@("`@=F%R("1?=F%R<R`](&%R<F%Y*"D["@H@("`@
M9G5N8W1I;VX@4VEE=F5?06-T:6]N7T9I;&5I;G1O*"1V87)S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("`D=&AI<RT^7W9A<G-;)V9O;&1E<B==(#T@*&ES
M<V5T*"1V87)S6R=F;VQD97(G72DI(#\@)'9A<G-;)V9O;&1E<B==(#H@)R<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=&]#;V1E*"D*("`@('L*("`@("`@("!R
M971U<FX@)V9I;&5I;G1O("(G("X@26YG;U]38W)I<'1?<VEE=F4Z.F5S8V%P
M95-T<FEN9R@D=&AI<RT^7W9A<G-;)V9O;&1E<B==*2`N("<B.R<["B`@("!]
M"@H@("`@9G5N8W1I;VX@8VAE8VLH*0H@("`@>PH@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7W9A<G-;)V9O;&1E<B==*2D@>PH@("`@("`@("`@("!R971U
M<FX@7R@B26YE>&ES=&%N="!M86EL8F]X('-P96-I9FEE9"!F;W(@;65S<V%G
M92!D96QI=F5R>2XB*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(')E<75I<F5S*"D*("`@('L*("`@("`@
M("!R971U<FX@87)R87DH)V9I;&5I;G1O)RD["B`@("!]"@I]"@HO*BH*("H@
M5&AE(%-I979E7T%C=&EO;E]686-A=&EO;CHZ(&-L87-S(')E<')E<V5N=',@
M82!V86-A=&EO;B!A8W1I;VXN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($EN9V\@
M,"XQ"B`J($!P86-K86=E($EN9V\*("HO"F-L87-S(%-I979E7T%C=&EO;E]6
M86-A=&EO;B!E>'1E;F1S(%-I979E7T%C=&EO;B!["@H@("`@=F%R("1?=F%R
M<R`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@4VEE=F5?06-T:6]N7U9A8V%T
M:6]N*"1V87)S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W9A
M<G-;)V1A>7,G72`]("AI<W-E="@D=F%R<ULG9&%Y<R==*2D@/R!I;G1V86PH
M)'9A<G-;)V1A>7,G72D@.B`W.PH@("`@("`@("1T:&ES+3Y?=F%R<ULG861D
M<F5S<V5S)UT@/2`H:7-S970H)'9A<G-;)V%D9')E<W-E<R==*2D@/R`D=F%R
M<ULG861D<F5S<V5S)UT@.B`G)SL*("`@("`@("`D=&AI<RT^7W9A<G-;)W-U
M8FIE8W0G72`]("AI<W-E="@D=F%R<ULG<W5B:F5C="==*2D@/R`D=F%R<ULG
M<W5B:F5C="==(#H@)R<["B`@("`@("`@)'1H:7,M/E]V87)S6R=R96%S;VXG
M72`]("AI<W-E="@D=F%R<ULG<F5A<V]N)UTI*2`_("1V87)S6R=R96%S;VXG
M72`Z("<G.PH@("`@?0H*("`@(&9U;F-T:6]N('1O0V]D92@I"B`@("!["B`@
M("`@("`@)&-O9&4@/2`G=F%C871I;VX@.F1A>7,@)R`N("1T:&ES+3Y?=F%R
M<ULG9&%Y<R==("X@)R`G.PH*("`@("`@("`D861D<F5S<V5S(#T@)'1H:7,M
M/E]V87)S6R=A9&1R97-S97,G73L*"B`@("`@("`@)'-T<FEN9VQI<W0@/2`G
M)SL*("`@("`@("!I9B`H8V]U;G0H)&%D9')E<W-E<RD@/B`Q*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1A9&1R97-S97,@87,@)&%D9')E<W,I('L*("`@
M("`@("`@("`@("`@("1A9&1R97-S(#T@=')I;2@D861D<F5S<RD["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1S=')I;F=L:7-T("X](&5M<'1Y*"1S=')I;F=L:7-T*2`_
M("<B)R`Z("<L("(G.PH@("`@("`@("`@("`@("`@("`@("1S=')I;F=L:7-T
M("X]($EN9V]?4V-R:7!T7W-I979E.CIE<V-A<&53=')I;F<H)&%D9')E<W,I
M("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1S=')I;F=L:7-T(#T@(ELB("X@)'-T<FEN9VQI<W0@+B`B72`B
M.PH@("`@("`@('T@96QS96EF("AC;W5N="@D861D<F5S<V5S*2`]/2`Q*2![
M"B`@("`@("`@("`@("1S=')I;F=L:7-T(#T@)R(G("X@26YG;U]38W)I<'1?
M<VEE=F4Z.F5S8V%P95-T<FEN9R@D861D<F5S<V5S6S!=*2`N("<B("<["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1S=')I;F=L:7-T*2D@>PH@
M("`@("`@("`@("`D8V]D92`N/2`G.F%D9')E<W-E<R`G("X@)'-T<FEN9VQI
M<W0["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?=F%R
M<ULG<W5B:F5C="==*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)TAO
M<F1E+TU)344N<&AP)SL*("`@("`@("`@("`@)&-O9&4@+CT@)SIS=6)J96-T
M("(G("X@34E-13HZ96YC;V1E*$EN9V]?4V-R:7!T7W-I979E.CIE<V-A<&53
M=')I;F<H)'1H:7,M/E]V87)S6R=S=6)J96-T)UTI+"`G551&+3@G*2`N("<B
M("<["B`@("`@("`@?0H@("`@("`@("1C;V1E("X]("<B)R`N($EN9V]?4V-R
M:7!T7W-I979E.CIE<V-A<&53=')I;F<H)'1H:7,M/E]V87)S6R=R96%S;VXG
M72D@+B`G(CLG.PH@("`@("`@(')E='5R;B`D8V]D93L*("`@('T*"B`@("!F
M=6YC=&EO;B!C:&5C:R@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES
M+3Y?=F%R<ULG<F5A<V]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B!?*")-
M:7-S:6YG(')E87-O;B!I;B!V86-A=&EO;BXB*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(')E<75I<F5S
M*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)W9A8V%T:6]N)RD["B`@
M("!]"@I]"@HO*BH*("H@5&AE(%-I979E7T%C=&EO;E]&;&%G.CH@8VQA<W,@
M:7,@=&AE(&)A<V4@8VQA<W,@9F]R(&9L86<@86-T:6]N<RX*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O
M"B`J+PIC;&%S<R!3:65V95]!8W1I;VY?1FQA9R!E>'1E;F1S(%-I979E7T%C
M=&EO;B!["@H@("`@=F%R("1?=F%R<R`](&%R<F%Y*"D["@H@("`@9G5N8W1I
M;VX@4VEE=F5?06-T:6]N7T9L86<H)'9A<G,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D=F%R<ULG9FQA9W,G72DI('L*("`@("`@("`@
M("`@:68@*"1V87)S6R=F;&%G<R==("8@24Y'3U]35$]204=%7T9,04=?04Y3
M5T52140I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%R<ULG9FQA9W,G
M75M=(#T@)UQ!;G-W97)E9"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1V87)S6R=F;&%G<R==("8@24Y'3U]35$]204=%7T9,04=?1$5,151%
M1"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)S6R=F;&%G<R==6UT@
M/2`G7$1E;&5T960G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M=F%R<ULG9FQA9W,G72`F($E.1T]?4U1/4D%'15]&3$%'7T9,04='140I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%R<ULG9FQA9W,G75M=(#T@)UQ&
M;&%G9V5D)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'9A<G-;
M)V9L86=S)UT@)B!)3D=/7U-43U)!1T5?1DQ!1U]3145.*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W9A<G-;)V9L86=S)UU;72`]("=<4V5E;B<["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^7W9A<G-;)V9L86=S)UT@/2`G)SL*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@7W1O0V]D92@D;6]D92D*("`@('L*("`@("`@("`D8V]D92`@
M/2`G)SL*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?=F%R<ULG9FQA
M9W,G72D@)B8@(65M<'1Y*"1T:&ES+3Y?=F%R<ULG9FQA9W,G72DI('L*("`@
M("`@("`@("`@)&-O9&4@+CT@)&UO9&4@+B`G("<["B`@("`@("`@("`@(&EF
M("AC;W5N="@D=&AI<RT^7W9A<G-;)V9L86=S)UTI(#X@,2D@>PH@("`@("`@
M("`@("`@("`@)'-T<FEN9VQI<W0@/2`G)SL*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?=F%R<ULG9FQA9W,G72!A<R`D9FQA9RD@>PH@("`@
M("`@("`@("`@("`@("`@("1F;&%G(#T@=')I;2@D9FQA9RD["B`@("`@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D9FQA9RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-T<FEN9VQI<W0@+CT@96UP='DH)'-T<FEN9VQI<W0I
M(#\@)R(G(#H@)RP@(B<["B`@("`@("`@("`@("`@("`@("`@("`@("1S=')I
M;F=L:7-T("X]($EN9V]?4V-R:7!T7W-I979E.CIE<V-A<&53=')I;F<H)&9L
M86<I("X@)R(G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1S=')I;F=L:7-T(#T@)ULG("X@)'-T
M<FEN9VQI<W0@+B`G72<["B`@("`@("`@("`@("`@("`D8V]D92`N/2`D<W1R
M:6YG;&ES="`N("<[)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1C;V1E("X]("<B)R`N($EN9V]?4V-R:7!T7W-I979E.CIE<V-A
M<&53=')I;F<H)'1H:7,M/E]V87)S6R=F;&%G<R==6S!=*2`N("<B.R<["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;V1E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&-H96-K*"D*("`@('L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!R97%U:7)E<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=I;6%P9FQA9W,G*3L*("`@('T*"GT*
M"B\J*@H@*B!4:&4@4VEE=F5?06-T:6]N7T%D9&9L86<Z.B!C;&%S<R!R97!R
M97-E;G1S(&%N(&%D9"!F;&%G(&%C=&EO;BX*("H*("H@0&%U=&AO<B`@36EK
M92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E
M("`@26YG;R`P+C$*("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@4VEE=F5?
M06-T:6]N7T%D9&9L86<@97AT96YD<R!3:65V95]!8W1I;VY?1FQA9R!["@H@
M("`@9G5N8W1I;VX@=&]#;V1E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]T;T-O9&4H)V%D9&9L86<G*3L*("`@('T*"GT*"B\J*@H@*B!4:&4@
M4VEE=F5?06-T:6]N7U)E;6]V969L86<Z.B!C;&%S<R!R97!R97-E;G1S(&$@
M<F5M;W9E(&9L86<*("H@86-T:6]N+@H@*@H@*B!`875T:&]R("!-:6ME($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!)
M;F=O(#`N,0H@*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S<R!3:65V95]!8W1I
M;VY?4F5M;W9E9FQA9R!E>'1E;F1S(%-I979E7T%C=&EO;E]&;&%G('L*"B`@
M("!F=6YC=&EO;B!T;T-O9&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W1O0V]D92@G<F5M;W9E9FQA9R<I.PH@("`@?0H*?0H*+RHJ"B`J(%1H
M92!3:65V95]!8W1I;VY?3F]T:69Y.CH@8VQA<W,@<F5P<F5S96YT<R!A(&YO
M=&EF>2!A8W1I;VXN"B`J"B`J($!A=71H;W(@(%!A=6P@5V]L<W1E;FAO;&UE
M(#QW;VQS=&5N84!S9G4N8V$^"B`J($!S:6YC92`@($EN9V\@,2XQ"B`J($!P
M86-K86=E($EN9V\*("HO"F-L87-S(%-I979E7T%C=&EO;E].;W1I9GD@97AT
M96YD<R!3:65V95]!8W1I;VX@>PH*("`@('9A<B`D7W9A<G,@/2!A<G)A>2@I
M.PH*("`@(&9U;F-T:6]N(%-I979E7T%C=&EO;E].;W1I9GDH)'9A<G,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<ULG861D<F5S<R==
M(#T@:7-S970H)'9A<G-;)V%D9')E<W,G72D@/R`D=F%R<ULG861D<F5S<R==
M(#H@)R<["B`@("`@("`@)'1H:7,M/E]V87)S6R=N86UE)UT@/2!I<W-E="@D
M=F%R<ULG;F%M92==*2`_("1V87)S6R=N86UE)UT@.B`G)SL*("`@('T*"B`@
M("!F=6YC=&EO;B!T;T-O9&4H*2!["B`@("`@("`@<F5T=7)N("=N;W1I9GD@
M.FUE=&AO9"`B;6%I;'1O(B`Z;W!T:6]N<R`B)R`N"B`@("`@("`@("`@($EN
M9V]?4V-R:7!T7W-I979E.CIE<V-A<&53=')I;F<H)'1H:7,M/E]V87)S6R=A
M9&1R97-S)UTI("X*("`@("`@("`@("`@)R(@.FUE<W-A9V4@(B<@+@H@("`@
M("`@("`@("!?*")9;W4@:&%V92!R96-E:79E9"!A(&YE=R!M97-S86=E(BD@
M+B`B7&XB("X*("`@("`@("`@("`@7R@B1G)O;3HB*2`N("(@7"1F<F]M7"0@
M7&XB("X*("`@("`@("`@("`@7R@B4W5B:F5C=#HB*2`N("(@7"1S=6)J96-T
M7"0@7&XB("X*("`@("`@("`@("`@7R@B4G5L93HB*2`N("<@)R`N("1T:&ES
M+3Y?=F%R<ULG;F%M92==("X@)R([)SL*("`@('T*"B`@("!F=6YC=&EO;B!C
M:&5C:R@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=F%R<ULG
M861D<F5S<R==*2D@>PH@("`@("`@("`@("!R971U<FX@7R@B36ES<VEN9R!A
M9&1R97-S('1O(&YO=&EF>2(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@<F5Q=6ER97,H*0H@("`@>PH@
M("`@("`@(')E='5R;B!A<G)A>2@G;F]T:69Y)RD["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;F=O+VQI8B]38W)I<'0O;6%I;&1R;W`N<&AP
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,W,C(T`#$P-#$W,S8R
M-S0W`#`R,3<R,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*+RHJ($%D9&ET:6]N86P@<W1O<F%G92!A8W1I;VX@
M<VEN8V4@;6%I;&1R;W`@9&]E<R!N;W0@<W5P<&]R="!T:&4@(F,M9FQA9R(@
M87,*("H@:6X@<')O8VUA:6PN("HO"F1E9FEN92@G34%)3$123U!?4U1/4D%'
M15]!0U1)3TY?4U1/4D5!3D1&3U)705)$)RP@,3`P*3L*"B\J*@H@*B!4:&4@
M26YG;U]38W)I<'1?;6%I;&1R;W`Z.B!C;&%S<R!R97!R97-E;G1S(&$@;6%I
M;&1R;W`@<V-R:7!T(&=E;F5R871O<BX*("H*("H@)$AO<F1E.B!I;F=O+VQI
M8B]38W)I<'0O;6%I;&1R;W`N<&AP+'8@,2XW+C(N-2`R,#`V+S`Q+S,Q(#(P
M.C`P.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($UA
M='0@5V5Y;&%N9"`\;6%T:&EA<T!W97EL86YD+F-H/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H05-,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*
M("H*("H@0&%U=&AO<B`@36%T="!797EL86YD(#QM871H:6%S0'=E>6QA;F0N
M8V@^"B`J($!S:6YC92`@($EN9V\@,2XQ"B`J($!P86-K86=E($EN9V\*("HO
M"F-L87-S($EN9V]?4V-R:7!T7VUA:6QD<F]P(&5X=&5N9',@26YG;U]38W)I
M<'0@>PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@86-T:6]N<R!A;&QO
M=V5D("AI;7!L96UE;G1E9"D@9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?86-T:6]N<R`](&%R
M<F%Y*`H@("`@("`@($E.1T]?4U1/4D%'15]!0U1)3TY?2T5%4"P*("`@("`@
M("!)3D=/7U-43U)!1T5?04-424].7TU/5D4L"B`@("`@("`@24Y'3U]35$]2
M04=%7T%#5$E/3E]$25-#05)$+`H@("`@("`@($E.1T]?4U1/4D%'15]!0U1)
M3TY?4D5$25)%0U0L"B`@("`@("`@24Y'3U]35$]204=%7T%#5$E/3E]2141)
M4D5#5$M%15`L"B`@("`@("`@24Y'3U]35$]204=%7T%#5$E/3E]214I%0U0*
M("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%T96=O<FEE<R!O9B!F:6QT
M97)I;F<@86QL;W=E9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V-A=&5G;W)I97,@/2!A<G)A>2@*("`@("`@("!)3D=/
M7U-43U)!1T5?04-424].7T),04-+3$E35"P*("`@("`@("!)3D=/7U-43U)!
M1T5?04-424].7U=(251%3$E35"P*("`@("`@("!)3D=/7U-43U)!1T5?04-4
M24].7T9/4E=!4D0*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@='EP97,@
M;V8@=&5S=',@86QL;W=E9"`H:6UP;&5M96YT960I(&9O<B!T:&ES(&1R:79E
M<BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W1Y<&5S(#T@87)R87DH"B`@("`@("`@24Y'3U]35$]204=%7U194$5?2$5!
M1$52"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@=&5S=',@
M86QL;W=E9"`H:6UP;&5M96YT960I(&9O<B!T:&ES(&1R:79E<BX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1E<W1S(#T@
M87)R87DH"B`@("`@("`@)V-O;G1A:6YS)RP*("`@("`@("`G8F5G:6YS('=I
M=&@G+`H@("`@("`@("=E;F1S('=I=&@G+`H@("`@("`@("=R96=E>"<*("`@
M("D["@H@("`@+RHJ"B`@("`@*B!#86X@=&5S=',@8F4@8V%S92!S96YS:71I
M=F4_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7V-A<V5S96YS:71I=F4@/2!T<G5E.PH*("`@("\J*@H@("`@("H@1&]E
M<R!T:&4@9')I=F5R('-U<'!O<G0@=&AE('-T;W`M<V-R:7!T(&]P=&EO;C\*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?
M<W5P<&]R=%-T;W!38W)I<'0@/2!F86QS93L*"B`@("`O*BH*("`@("`J($1O
M97,@=&AE(&1R:79E<B!R97%U:7)E(&$@<V-R:7!T(&9I;&4@=&\@8F4@9V5N
M97)A=&5D/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]S8W)I<'1F:6QE(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1H
M92!R96-I<&5S('1H870@;6%K92!U<"!T:&4@8V]D92X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W)E8VEP97,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-C<FEP="!P<F5V:6]U
M<VQY(&=E;F5R871E9"!W:71H(&=E;F5R871E*"DN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!M86EL9')O<"!S8W)I<'0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1O0V]D92@I"B`@("!["B`@("`@("`@)&-O9&4@/2`G
M)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)E8VEP97,@87,@)&ET96TI
M('L*("`@("`@("`@("`@)&-O9&4@+CT@)&ET96TM/F=E;F5R871E*"D@+B`B
M7&XB.PH@("`@("`@('T*("`@("`@("!R971U<FX@<G1R:6TH)&-O9&4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!M86EL9')O<"!S
M8W)I<'0@=&\@9&\@=&AE(&9I;'1E<FEN9R!S<&5C:69I960@:6X*("`@("`J
M('1H92!R=6QE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&UA:6QD<F]P('-C<FEP="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A
M=&4H*0H@("`@>PH@("`@("`@("1F:6QT97)S(#T@)B1'3$]"04Q36R=I;F=O
M7W-T;W)A9V4G72T^<F5T<FEE=F4H24Y'3U]35$]204=%7T%#5$E/3E]&24Q4
M15)3*3L*"B`@("`@("`@)'1H:7,M/F%D9$ET96TH;F5W($UA:6QD<F]P7T-O
M;6UE;G0H7R@B;6%I;&1R;W`@<V-R:7!T(&=E;F5R871E9"!B>2!);F=O(BD@
M+B`G("@G("X@9&%T92@G1B!J+"!9+"!G.FD@82<I("X@)RDG*2D["@H@("`@
M("`@("\J($%D9"!V87)I86)L92!I;F9O<FUA=&EO;BP@:68@<')E<V5N="X@
M*B\*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=V87)I86)L
M97,G72D@)B8*("`@("`@("`@("`@:7-?87)R87DH)'1H:7,M/E]P87)A;7-;
M)W9A<FEA8FQE<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7W!A<F%M<ULG=F%R:6%B;&5S)UT@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^861D271E;2AN97<@36%I;&1R;W!?5F%R:6%B
M;&4H87)R87DH)VYA;64G(#T^("1K97DL("=V86QU92<@/3X@)'9A;"DI*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&9I
M;'1E<G,M/F=E=$9I;'1E<FQI<W0H*2!A<R`D9FEL=&5R*2!["B`@("`@("`@
M("`@('-W:71C:"`H)&9I;'1E<ELG86-T:6]N)UTI('L*("`@("`@("`@("`@
M8V%S92!)3D=/7U-43U)!1T5?04-424].7T),04-+3$E35#H*("`@("`@("`@
M("`@("`@("1T:&ES+3YG96YE<F%T94)L86-K;&ES="@A96UP='DH)&9I;'1E
M<ELG9&ES86)L92==*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]72$E414Q)4U0Z"B`@
M("`@("`@("`@("`@("`D=&AI<RT^9V5N97)A=&57:&ET96QI<W0H(65M<'1Y
M*"1F:6QT97);)V1I<V%B;&4G72DI.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?1D]25T%2
M1#H*("`@("`@("`@("`@("`@("1T:&ES+3YG96YE<F%T949O<G=A<F0H(65M
M<'1Y*"1F:6QT97);)V1I<V%B;&4G72DI.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@:68@
M*&EN7V%R<F%Y*"1F:6QT97);)V%C=&EO;B==+"`D=&AI<RT^7V%C=&EO;G,I
M*2!["B`@("`@("`@("`@("`@("`@("`@+RH@0W)E871E(&9I;'1E<B!I9B!U
M<VEN9R!!3D0N("HO"B`@("`@("`@("`@("`@("`@("`@)')E8VEP92`]("9N
M97<@36%I;&1R;W!?4F5C:7!E*"1F:6QT97(L("1T:&ES+3Y?<&%R86US*3L*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL=&5R6R=C;VYD:71I
M;VYS)UT@87,@)&-O;F1I=&EO;BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5C:7!E+3YA9&1#;VYD:71I;VXH)&-O;F1I=&EO;BD["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&1)
M=&5M*&YE=R!-86EL9')O<%]#;VUM96YT*"1F:6QT97);)VYA;64G72P@(65M
M<'1Y*"1F:6QT97);)V1I<V%B;&4G72DL('1R=64I*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^861D271E;2@D<F5C:7!E*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YT;T-O9&4H*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R
M871E<R!T:&4@;6%I;&1R;W`@<V-R:7!T('1O(&AA;F1L92!T:&4@8FQA8VML
M:7-T('-P96-I9FEE9"!I;@H@("`@("H@=&AE(')U;&5S+@H@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N("1D:7-A8FQE("!$:7-A8FQE('1H92!B;&%C
M:VQI<W0_"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E0FQA8VML:7-T
M*"1D:7-A8FQE(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&)L86-K;&ES="`]
M("8D1TQ/0D%,4ULG:6YG;U]S=&]R86=E)UTM/G)E=')I979E*$E.1T]?4U1/
M4D%'15]!0U1)3TY?0DQ!0TM,25-4*3L*("`@("`@("`D8FQ?861D<B`]("1B
M;&%C:VQI<W0M/F=E=$)L86-K;&ES="@I.PH@("`@("`@("1B;%]F;VQD97(@
M/2`D8FQA8VML:7-T+3YG971";&%C:VQI<W1&;VQD97(H*3L*"B`@("`@("`@
M)&)L7W1Y<&4@/2`H96UP='DH)&)L7V9O;&1E<BDI(#\@24Y'3U]35$]204=%
M7T%#5$E/3E]$25-#05)$(#H@24Y'3U]35$]204=%7T%#5$E/3E]-3U9%.PH*
M("`@("`@("!I9B`H(65M<'1Y*"1B;%]A9&1R*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^861D271E;2AN97<@36%I;&1R;W!?0V]M;65N="A?*")";&%C:VQI
M<W1E9"!!9&1R97-S97,B*2P@)&1I<V%B;&4L('1R=64I*3L*("`@("`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y*"=A8W1I;VXM=F%L=64G(#T^("1B;%]F;VQD
M97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G86-T:6]N)R`]/B`D
M8FQ?='EP92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D:7-A8FQE
M)R`]/B`D9&ES86)L92D["@H@("`@("`@("`@("!F;W)E86-H("@D8FQ?861D
M<B!A<R`D861D<F5S<RD@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M861D<F5S<RDI('L*("`@("`@("`@("`@("`@("`@("`D<F5C:7!E(#T@)FYE
M=R!-86EL9')O<%]296-I<&4H)'!A<F%M<RP@)'1H:7,M/E]P87)A;7,I.PH@
M("`@("`@("`@("`@("`@("`@("1R96-I<&4M/F%D9$-O;F1I=&EO;BAA<G)A
M>2@G9FEE;&0G(#T^("=&<F]M)RP@)W9A;'5E)R`]/B`D861D<F5S<RDI.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&1)=&5M*"1R96-I<&4I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!M86EL9')O<"!S8W)I
M<'0@=&\@:&%N9&QE('1H92!W:&ET96QI<W0@<W!E8VEF:65D(&EN"B`@("`@
M*B!T:&4@<G5L97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I
M<V%B;&4@($1I<V%B;&4@=&AE('=H:71E;&ES=#\*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5N97)A=&57:&ET96QI<W0H)&1I<V%B;&4@/2!F86QS92D*("`@
M('L*("`@("`@("`D=VAI=&5L:7-T(#T@)B1'3$]"04Q36R=I;F=O7W-T;W)A
M9V4G72T^<F5T<FEE=F4H24Y'3U]35$]204=%7T%#5$E/3E]72$E414Q)4U0I
M.PH@("`@("`@("1W;%]A9&1R(#T@)'=H:71E;&ES="T^9V5T5VAI=&5L:7-T
M*"D["@H@("`@("`@(&EF("@A96UP='DH)'=L7V%D9'(I*2!["B`@("`@("`@
M("`@("1T:&ES+3YA9&1)=&5M*&YE=R!-86EL9')O<%]#;VUM96YT*%\H(E=H
M:71E;&ES=&5D($%D9')E<W-E<R(I+"`D9&ES86)L92P@=')U92DI.PH@("`@
M("`@("`@("!F;W)E86-H("@D=VQ?861D<B!A<R`D861D<F5S<RD@>PH@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<RDI('L*("`@("`@("`@
M("`@("`@("`@("`D<F5C:7!E(#T@)FYE=R!-86EL9')O<%]296-I<&4H87)R
M87DH)V%C=&EO;B<@/3X@24Y'3U]35$]204=%7T%#5$E/3E]+1450+"`G9&ES
M86)L92<@/3X@)&1I<V%B;&4I+"`D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@
M("`@("`@("`@("`@)')E8VEP92T^861D0V]N9&ET:6]N*&%R<F%Y*"=F:65L
M9"<@/3X@)T9R;VTG+"`G=F%L=64G(#T^("1A9&1R97-S*2D["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9$ET96TH)')E8VEP92D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE(&UA:6QD<F]P('-C<FEP="!T;R!H
M86YD;&4@;6%I;"!F;W)W87)D<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D9&ES86)L92`@1&ES86)L92!F;W)W87)D:6YG/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G96YE<F%T949O<G=A<F0H)&1I<V%B;&4@/2!F86QS92D*
M("`@('L*("`@("`@("`D9F]R=V%R9"`]("8D1TQ/0D%,4ULG:6YG;U]S=&]R
M86=E)UTM/G)E=')I979E*$E.1T]?4U1/4D%'15]!0U1)3TY?1D]25T%21"D[
M"B`@("`@("`@)&%D9')E<W-E<R`]("1F;W)W87)D+3YG971&;W)W87)D061D
M<F5S<V5S*"D["@H@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-E<RDI('L*
M("`@("`@("`@("`@)'1H:7,M/F%D9$ET96TH;F5W($UA:6QD<F]P7T-O;6UE
M;G0H7R@B1F]R=V%R9',B*2P@)&1I<V%B;&4L('1R=64I*3L*("`@("`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y*"=A8W1I;VXG(#T^($E.1T]?4U1/4D%'15]!
M0U1)3TY?1D]25T%21"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A
M8W1I;VXM=F%L=64G(#T^("1A9&1R97-S97,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9&ES86)L92<@/3X@)&1I<V%B;&4I.PH@("`@("`@("`@
M("!I9B`H)&9O<G=A<F0M/F=E=$9O<G=A<F1+965P*"DI('L*("`@("`@("`@
M("`@("`@("1P87)A;7-;)V%C=&EO;B==(#T@34%)3$123U!?4U1/4D%'15]!
M0U1)3TY?4U1/4D5!3D1&3U)705)$.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1R96-I<&4@/2`F;F5W($UA:6QD<F]P7U)E8VEP92@D<&%R86US+"`D
M=&AI<RT^7W!A<F%M<RD["B`@("`@("`@("`@("1R96-I<&4M/F%D9$-O;F1I
M=&EO;BAA<G)A>2@G9FEE;&0G(#T^("=&<F]M)RP@)W9A;'5E)R`]/B`G)RDI
M.PH@("`@("`@("`@("`D=&AI<RT^861D271E;2@D<F5C:7!E*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N(&ET96T@=&\@=&AE
M(')E8VEP92!L:7-T+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)&ET
M96T@(%1H92!I=&5M('1O(&%D9"!T;R!T:&4@<F5C:7!E(&QI<W0N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!4:&4@;V)J96-T('-H;W5L9"!H879E
M(&$@9V5N97)A=&4H*2!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D271E;2@D:71E;2D*("`@('L*("`@("`@("`D=&AI<RT^7W)E8VEP97-;
M72`]("1I=&5M.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!-86EL9')O<%]#;VUM
M96YT.CH@8VQA<W,@<F5P<F5S96YT<R!A(&UA:6QD<F]P(&-O;6UE;G0N("!4
M:&ES(&ES"B`J(&$@<')E='1Y('-I;7!L92!C;&%S<RP@8G5T(&ET(&UA:V5S
M('1H92!C;V1E(&EN($EN9V]?4V-R:7!T7VUA:6QD<F]P.CH*("H@8VQE86YE
M<B!A<R!I="!P<F]V:61E<R!A(&=E;F5R871E*"D@9G5N8W1I;VX@86YD(&-A
M;B!B92!A9&1E9"!T;R!T:&4*("H@<F5C:7!E(&QI<W0@=&AE('-A;64@=V%Y
M(&%S(&$@<F5C:7!E(&-A;B!B92X*("H*("H@0&%U=&AO<B`@36%T="!797EL
M86YD(#QM871H:6%S0'=E>6QA;F0N8V@^"B`J($!S:6YC92`@($EN9V\@,2XQ
M"B`J($!P86-K86=E($EN9V\*("HO"F-L87-S($UA:6QD<F]P7T-O;6UE;G0@
M>PH*("`@("\J*@H@("`@("H@5&AE(&-O;6UE;G0@=&5X="X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VUM96YT(#T@
M)R<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(&UA:6QD<F]P
M(&-O;6UE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]M;65N
M="`@($-O;6UE;G0@=&\@8F4@9V5N97)A=&5D+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&1I<V%B;&4@($]U='!U="`G1$E304),140G(&-O;6UE;G0_"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D:&5A9&5R("`@3W5T<'5T(&$@)VAE861E
M<B<@8V]M;65N=#\*("`@("`J+PH@("`@9G5N8W1I;VX@36%I;&1R;W!?0V]M
M;65N="@D8V]M;65N="P@)&1I<V%B;&4@/2!F86QS92P@)&AE861E<B`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@D9&ES86)L92D@>PH@("`@("`@("`@
M("`D8V]M;65N="`](%\H(D1)4T%"3$5$.B`B*2`N("1C;VUM96YT.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1H96%D97(I('L*("`@("`@("`@("`@)'1H
M:7,M/E]C;VUM96YT("X]("(C(R,C(R`D8V]M;65N="`C(R,C(R(["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]C;VUM96YT("X]("(C
M("1C;VUM96YT(CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!C;VUM96YT('-T;W)E9"!B>2!T:&ES(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;6UE;G0@<W1O<F5D
M(&)Y('1H:7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]M;65N=#L*("`@
M('T*"GT*"B\J*@H@*B!4:&4@36%I;&1R;W!?4F5C:7!E.CH@8VQA<W,@<F5P
M<F5S96YT<R!A(&UA:6QD<F]P(')E8VEP92X*("H*("H@0&%U=&AO<B`@36%T
M="!797EL86YD(#QM871H:6%S0'=E>6QA;F0N8V@^"B`J($!S:6YC92`@($EN
M9V\@,2XQ"B`J($!P86-K86=E($EN9V\*("HO"F-L87-S($UA:6QD<F]P7U)E
M8VEP92!["@H@("`@=F%R("1?86-T:6]N(#T@87)R87DH*3L*("`@('9A<B`D
M7V-O;F1I=&EO;G,@/2!A<G)A>2@I.PH@("`@=F%R("1?9&ES86)L92`]("<G
M.PH@("`@=F%R("1?9FQA9W,@/2`G)SL*("`@('9A<B`D7W!A<F%M<R`](&%R
M<F%Y*"D["B`@("!V87(@)%]C;VUB:6YE(#T@)R<["B`@("!V87(@)%]V86QI
M9"`]('1R=64["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(&UA
M:6QD<F]P(')E8VEP92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@("`@("`@07)R87D@;V8@<&%R86UE=&5R<RX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!215%525)%1"!&245,1%,Z"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%C=&EO;B<*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!/4%1)3TY!3"!&245,1%,Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%C=&EO;BUV
M86QU92<@*&]N;'D@=7-E9"!I9B!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G86-T:6]N)R!R97%U:7)E<R!I="D*("`@("`J($!P
M87)A;2!A<G)A>2`D<V-R:7!T<&%R86US("!!<G)A>2!O9B!P87)A;65T97)S
M('!A<W-E9"!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($EN9V]?4V-R:7!T7VUA:6QD<F]P.CHN"B`@("`@*B\*("`@(&9U;F-T:6]N
M($UA:6QD<F]P7U)E8VEP92@D<&%R86US(#T@87)R87DH*2P@)'-C<FEP='!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]D:7-A8FQE
M(#T@(65M<'1Y*"1P87)A;7-;)V1I<V%B;&4G72D["B`@("`@("`@)'1H:7,M
M/E]P87)A;7,@/2`D<V-R:7!T<&%R86US.PH@("`@("`@("1T:&ES+3Y?86-T
M:6]N6UT@/2`G97AC97!T:6]N('LG.PH*("`@("`@("!S=VET8V@@*"1P87)A
M;7-;)V%C=&EO;B==*2!["B`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-4
M24].7TM%15`Z"B`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N6UT@/2`G("`@
M=&\@(B1[1$5&055,5'TB)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]-3U9%.@H@("`@("`@("`@("`D
M=&AI<RT^7V%C=&EO;EM=(#T@)R`@('1O("<@+B`D=&AI<RT^;6%I;&1R;W!0
M871H*"1P87)A;7-;)V%C=&EO;BUV86QU92==*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]$25-#05)$
M.@H@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;EM=(#T@)R`@('1O("(O9&5V
M+VYU;&PB)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24Y'
M3U]35$]204=%7T%#5$E/3E]2141)4D5#5#H*("`@("`@("`@("`@)'1H:7,M
M/E]A8W1I;VY;72`]("<@("!T;R`B(2`G("X@)'!A<F%M<ULG86-T:6]N+79A
M;'5E)UT@+B`G(B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M($E.1T]?4U1/4D%'15]!0U1)3TY?4D5$25)%0U1+1450.@H@("`@("`@("`@
M("`D=&AI<RT^7V%C=&EO;EM=(#T@)R`@(&-C("(A("<@+B`D<&%R86US6R=A
M8W1I;VXM=F%L=64G72`N("<B)SL*("`@("`@("`@("`@)'1H:7,M/E]A8W1I
M;VY;72`]("<@("!T;R`B)'M$149!54Q4?2(G.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-424].7U)%2D5#5#H*
M("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@("!%6$E40T]$13TG
M("X@)'!A<F%M<ULG86-T:6]N+79A;'5E)UT["B`@("`@("`@("`@("1T:&ES
M+3Y?86-T:6]N6UT@/2`G("`@97AI="<["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?1D]25T%21#H*("`@
M("`@("!C87-E($U!24Q$4D]07U-43U)!1T5?04-424].7U-43U)%04Y$1D]2
M5T%21#H*("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<ULG86-T:6]N+79A
M;'5E)UT@87,@)&%D9')E<W,I('L*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&%D9')E<W,I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M8W1I;VY;72`]("<@(&-C("(A("<@+B`D861D<F5S<R`N("<B)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@5&AE
M("=T;R<@;75S="!B92!T:&4@;&%S="!A8W1I;VXL(&)E8V%U<V4@;6%I;&1R
M;W`@<W1O<',*("`@("`@("`@("`@("`@<')O8V5S<VEN9R!A9G1E<B!I="X@
M*B\*("`@("`@("`@("`@:68@*"1P87)A;7-;)V%C=&EO;B==(#T]($U!24Q$
M4D]07U-43U)!1T5?04-424].7U-43U)%04Y$1D]25T%21"D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("<@=&\@(B1[1$5&055,5'TB
M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?86-T:6]N6UT@/2`G(&5X:70G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED(#T@9F%L<V4["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]A8W1I;VY;72`]("=])SL*"B`@("`@("`@
M:68@*&ES<V5T*"1P87)A;7-;)V-O;6)I;F4G72D@)B8*("`@("`@("`@("`@
M*"1P87)A;7-;)V-O;6)I;F4G72`]/2!)3D=/7U-43U)!1T5?0T]-0DE.15]!
M3$PI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]M8FEN92`]("<F)B`G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?8V]M8FEN92`]
M("=\?"`G.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M82!F;&%G('1O('1H92!R96-I<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9FQA9R`@4W1R:6YG(&]F(&9L86=S('1O(&%P<&5N9"!T;R!T:&4@
M8W5R<F5N="!F;&%G<RX*("`@("`J+PH@("`@9G5N8W1I;VX@861D1FQA9R@D
M9FQA9RD*("`@('L*("`@("`@("`D=&AI<RT^7V9L86=S("X]("1F;&%G.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&-O;F1I=&EO;B!T;R!T:&4@
M<F5C:7!E+@H@("`@("H*("`@("`J($!P87)A;2!O<'1O;F%L(&%R<F%Y("1C
M;VYD:71I;VX@($%R<F%Y(&]F('!A<F%M971E<G,N(%)E<75I<F5D(&ME>7,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R92`G
M9FEE;&0G(&%N9"`G=F%L=64G+B`G8V%S92<@:7,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%N(&]P=&EO;F%L(&ME>7,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O;F1I=&EO;B@D8V]N9&ET:6]N(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D9FQA9R`]("@A96UP='DH)&-O;F1I
M=&EO;ELG8V%S92==*2D@/R`G1"<@.B`G)SL*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]C;VYD:71I;VYS*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D
M1FQA9R@D9FQA9RD["B`@("`@("`@?0H*("`@("`@("`D;6%T8V@@/2`H:7-S
M970H)&-O;F1I=&EO;ELG;6%T8V@G72DI(#\@)&-O;F1I=&EO;ELG;6%T8V@G
M72`Z(&YU;&P["B`@("`@("`@)'-T<FEN9R`]("<O7B<@+B`D8V]N9&ET:6]N
M6R=F:65L9"==("X@)SH@)SL*"B`@("`@("`@<W=I=&-H("@D;6%T8V@I('L*
M("`@("`@("!C87-E("=R96=E>"<Z"B`@("`@("`@("`@("1S=')I;F<@+CT@
M)&-O;F1I=&EO;ELG=F%L=64G73L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@)V)E9VEN<R!W:71H)SH*("`@("`@("`@("`@)'-T<FEN9R`N
M/2!Q=6]T96UE=&$H)&-O;F1I=&EO;ELG=F%L=64G72D["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=E;F1S('=I=&@G.@H@("`@("`@("`@
M("`D<W1R:6YG("X]("<N*B<@+B!Q=6]T96UE=&$H)&-O;F1I=&EO;ELG=F%L
M=64G72D@+B`G)"<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=C;VYT86EN<R<Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'-T
M<FEN9R`N/2`G+BHG("X@<75O=&5M971A*"1C;VYD:71I;VY;)W9A;'5E)UTI
M.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("1S=')I
M;F<@+CT@)R\G.PH*("`@("`@("`D=&AI<RT^7V-O;F1I=&EO;G-;72`](&%R
M<F%Y*"=C;VYD:71I;VXG(#T^("1S=')I;F<L("=F;&%G<R<@/3X@)&9L86<I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S(&UA:6QD<F]P(&-O
M9&4@=&\@<F5P<F5S96YT('1H92!R96-I<&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(&UA:6QD<F]P(&-O9&4@=&\@<F5P<F5S96YT('1H92!R
M96-I<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E*"D*("`@('L*
M("`@("`@("`D=&5X="`](&%R<F%Y*"D["@H@("`@("`@(&EF("@A)'1H:7,M
M/E]V86QI9"D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*
M("`@("`@("`D=&5X=%M=(#T@(FEF*"!<7"(["@H@("`@("`@(&EF("AC;W5N
M="@D=&AI<RT^7V-O;F1I=&EO;G,@/B`Q*2D@>PH@("`@("`@("`@("`D;F5S
M="`](&9A;'-E.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-O;F1I
M=&EO;G,@87,@)&-O;F1I=&EO;BD@>PH@("`@("`@("`@("`@("`@)&-O;F0@
M/2`H)&YE<W0I(#\@)'1H:7,M/E]C;VUB:6YE(#H@)R`@("<["B`@("`@("`@
M("`@("`@("`D=&5X=%M=(#T@)&-O;F0@+B`D8V]N9&ET:6]N6R=C;VYD:71I
M;VXG72`N("<Z:"<@+B`D8V]N9&ET:6]N6R=F;&%G<R==("X@(B!<7"(["B`@
M("`@("`@("`@("`@("`D;F5S="`]('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1T97AT6UT@/2`G*2<["@H@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?86-T:6]N(&%S("1V86PI('L*("`@("`@("`@("`@)'1E
M>'1;72`]("1V86P["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]D
M:7-A8FQE*2!["B`@("`@("`@("`@("1C;V1E(#T@)R<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T97AT(&%S("1V86PI('L*("`@("`@("`@("`@("`@("1C
M;VUM96YT(#T@;F5W($UA:6QD<F]P7T-O;6UE;G0H)'9A;"D["B`@("`@("`@
M("`@("`@("`D8V]D92`N/2`D8V]M;65N="T^9V5N97)A=&4H*2`N(")<;B([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1C;V1E("X@(EQN
M(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@:6UP;&]D
M92@B7&XB+"`D=&5X="D@+B`B7&XB.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!M86EL9')O<"UR96%D>2!M86EL8F]X('!A
M=&@L(&-O;G9E<G1I;F<@24U!4"!F;VQD97(*("`@("`J('!A=&AN86UE(&-O
M;G9E;G1I;VYS(&%S(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F;VQD97(@(%1H92!)34%0(&9O;&1E<B!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6%I;&1R;W`@;6%I;&)O>"!P
M871H+@H@("`@("HO"B`@("!F=6YC=&EO;B!M86EL9')O<%!A=&@H)&9O;&1E
M<BD*("`@('L*("`@("`@("`O*B!.3U1%.B`G)$1%1D%53%0G(&AE<F4@:7,@
M82!L:71E<F%L+"!N;W0@82!02%`@=F%R:6%B;&4N("HO"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%R86US*2`F)@H@("`@("`@("`@("`H)'1H:7,M
M/E]P87)A;7-;)W!A=&A?<W1Y;&4G72`]/2`G;6%I;&1I<B<I*2!["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D9F]L9&5R*2!\?"`H)&9O;&1E<B`]/2`G24Y"
M3U@G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("=T;R`B)'M$149!54Q4
M?2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*'-U8G-T<B@D9F]L
M9&5R+"`P+"`V*2`]/2`G24Y"3U@N)RD@>PH@("`@("`@("`@("`@("`@)&9O
M;&1E<B`]('-U8G-T<B@D9F]L9&5R+"`V*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@)R(D>T1%1D%53%1]+RXG("X@)&9O;&1E<B`N("<O
M(B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1F
M;VQD97(I('Q\("@D9F]L9&5R(#T]("=)3D)/6"<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)W1O("1[1$5&055,5'TG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@G("<L("=<("<L("1F;VQD
M97(I.PH@("`@("`@('T*("`@('T*"GT*"B\J*@H@*B!4:&4@36%I;&1R;W!?
M5F%R:6%B;&4Z.B!C;&%S<R!R97!R97-E;G1S(&$@36%I;&1R;W`@=F%R:6%B
M;&4N"B`J"B`J($!A=71H;W(@($UA='0@5V5Y;&%N9"`\;6%T:&EA<T!W97EL
M86YD+F-H/@H@*B!`<VEN8V4@("!);F=O(#$N,0H@*B!`<&%C:V%G92!);F=O
M"B`J+PIC;&%S<R!-86EL9')O<%]687)I86)L92!["@H@("`@=F%R("1?;F%M
M93L*("`@('9A<B`D7W9A;'5E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M<R!A(&YE=R!M86EL9')O<"!V87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@07)R87D@;V8@<&%R86UE=&5R<RX@17AP96-T
M960@9FEE;&1S(&%R92`G;F%M92<*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!A;F0@)W9A;'5E)RX*("`@("`J+PH@("`@9G5N8W1I;VX@36%I;&1R
M;W!?5F%R:6%B;&4H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]N86UE(#T@)'!A<F%M<ULG;F%M92==.PH@("`@("`@("1T:&ES
M+3Y?=F%L=64@/2`D<&%R86US6R=V86QU92==.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5N97)A=&5S(&UA:6QD<F]P(&-O9&4@=&\@<F5P<F5S96YT('1H
M92!V87)I86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@;6%I
M;&1R;W`@8V]D92!T;R!R97!R97-E;G0@=&AE('9A<FEA8FQE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G96YE<F%T92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?;F%M92`N("<])R`N("1T:&ES+3Y?=F%L=64@+B`B7&XB.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQI
M8B]3=&]R86=E+P``````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S0W`#`Q-S4S-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEN9V\O;&EB+U-T;W)A9V4O<')E9G,N<&AP````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(Q,S(`,3`T,3<S-C(W-#<`,#(Q
M,S8Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!);F=O7U-T;W)A9V5?<')E9G,Z.B!I;7!L96UE;G1S
M('1H92!);F=O7U-T;W)A9V4Z.B!!4$D@=&\@<V%V92!);F=O(&1A=&$*("H@
M=FEA('1H92!(;W)D92!P<F5F97)E;F-E<R!S>7-T96TN"B`J"B`J("1(;W)D
M93H@:6YG;R]L:6(O4W1O<F%G92]P<F5F<RYP:'`L=B`Q+C$T+C$R+C$P(#(P
M,#8O,#$O,S$@,C`Z,#`Z,C4@:F%N($5X<"`D"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!
M4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@
M*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC
M;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($EN9V\@,"XQ"B`J($!P86-K86=E
M($EN9V\*("HO"F-L87-S($EN9V]?4W1O<F%G95]P<F5F<R!E>'1E;F1S($EN
M9V]?4W1O<F%G92!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@061D:71I;VYA;"!P
M87)A;65T97)S(&9O<B!T:&4@<W5B8VQA<W,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($EN9V]?4W1O<F%G95]P<F5F<R@D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE('-P96-I9FEE9"!D871A(&9R
M;VT@=&AE('-T;W)A9V4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9FEE;&0@
M(%1H92!F:65L9"!N86UE(&]F('1H92!D97-I<F5D(&1A=&$N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(%-E92!L:6(O4W1O<F%G92YP:'`@9F]R
M('1H92!A=F%I;&%B;&4@9FEE;&1S+@H@("`@("H*("`@("`J($!R971U<FX@
M26YG;U]3=&]R86=E7W)U;&5\26YG;U]3=&]R86=E7V9I;'1E<G,@(%1H92!S
M<&5C:69I960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]R971R:65V
M92@D9FEE;&0I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@
M("`@<W=I=&-H("@D9FEE;&0I('L*("`@("`@("!C87-E($E.1T]?4U1/4D%'
M15]!0U1)3TY?0DQ!0TM,25-4.@H@("`@("`@("`@("`D9&%T82`]('5N<V5R
M:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H)V)L86-K;&ES="<I*3L*("`@("`@
M("`@("`@)&]B(#T@)FYE=R!);F=O7U-T;W)A9V5?8FQA8VML:7-T*"D["B`@
M("`@("`@("`@("1O8BT^<V5T0FQA8VML:7-T*"1D871A6R=A)UTL(&9A;'-E
M*3L*("`@("`@("`@("`@)&]B+3YS971";&%C:VQI<W1&;VQD97(H)&1A=&%;
M)V8G72D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($E.1T]?
M4U1/4D%'15]!0U1)3TY?1DE,5$524SH*("`@("`@("`@("`@)&1A=&$@/2!`
M=6YS97)I86QI>F4H)'!R969S+3YG971686QU92@G<G5L97,G+"!F86QS92DI
M.PH@("`@("`@("`@("!I9B`H)&1A=&$@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`O*B!#;VYV97)T(')U;&5S(&9R;VT@=&AE(&]L9"!F;W)M870N
M("HO"B`@("`@("`@("`@("`@("`D9&%T82`]('5N<V5R:6%L:7IE*"1P<F5F
M<RT^9V5T5F%L=64H)W)U;&5S)RDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&1A=&$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T
M*"1D871A+"`D<')E9G,M/F=E=$-H87)S970H*2P@3DQ3.CIG971#:&%R<V5T
M*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1O8B`]("9N97<@26YG
M;U]3=&]R86=E7V9I;'1E<G,H*3L*("`@("`@("`@("`@)&]B+3YS971&:6QT
M97)L:7-T*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@24Y'3U]35$]204=%7T%#5$E/3E]&3U)705)$.@H@("`@("`@("`@("`D
M9&%T82`]('5N<V5R:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H)V9O<G=A<F0G
M*2D["B`@("`@("`@("`@("1O8B`]("9N97<@26YG;U]3=&]R86=E7V9O<G=A
M<F0H*3L*("`@("`@("`@("`@)&]B+3YS971&;W)W87)D061D<F5S<V5S*"1D
M871A6R=A)UTL(&9A;'-E*3L*("`@("`@("`@("`@)&]B+3YS971&;W)W87)D
M2V5E<"@D9&%T85LG:R==*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]604-!5$E/3CH*("`@("`@("`@
M("`@)&1A=&$@/2!`=6YS97)I86QI>F4H)'!R969S+3YG971686QU92@G=F%C
M871I;VXG+"!F86QS92DI.PH@("`@("`@("`@("!I9B`H)&1A=&$@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`O*B!#;VYV97)T('9A8V%T:6]N(&9R
M;VT@=&AE(&]L9"!F;W)M870N("HO"B`@("`@("`@("`@("`@("`D9&%T82`]
M('5N<V5R:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H)W9A8V%T:6]N)RDI.PH@
M("`@("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&1A=&$I*2!["B`@("`@
M("`@("`@("`@("`D9&%T82`]("1P<F5F<RT^8V]N=F5R=$9R;VU$<FEV97(H
M)&1A=&$L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&]B(#T@)FYE=R!);F=O7U-T;W)A9V5?=F%C871I;VXH*3L*
M("`@("`@("`@("`@)&]B+3YS971686-A=&EO;D%D9')E<W-E<R@D9&%T85LG
M861D<F5S<V5S)UTL(&9A;'-E*3L*("`@("`@("`@("`@)&]B+3YS971686-A
M=&EO;D1A>7,H)&1A=&%;)V1A>7,G72D["B`@("`@("`@("`@("1O8BT^<V5T
M5F%C871I;VY%>&-L=61E<R@D9&%T85LG97AC;'5D97,G72P@9F%L<V4I.PH@
M("`@("`@("`@("`D;V(M/G-E=%9A8V%T:6]N26=N;W)E;&ES="@D9&%T85LG
M:6=N;W)E;&ES="==*3L*("`@("`@("`@("`@)&]B+3YS971686-A=&EO;E)E
M87-O;B@D9&%T85LG<F5A<V]N)UTI.PH@("`@("`@("`@("`D;V(M/G-E=%9A
M8V%T:6]N4W5B:F5C="@D9&%T85LG<W5B:F5C="==*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]72$E4
M14Q)4U0Z"B`@("`@("`@("`@("1O8B`]("9N97<@26YG;U]3=&]R86=E7W=H
M:71E;&ES="@I.PH@("`@("`@("`@("`D;V(M/G-E=%=H:71E;&ES="AU;G-E
M<FEA;&EZ92@D<')E9G,M/F=E=%9A;'5E*"=W:&ET96QI<W0G*2DL(&9A;'-E
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("1O8B`](&9A;'-E.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;V(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3=&]R97,@=&AE('-P96-I9FEE9"!D871A(&EN('1H92!S=&]R86=E(&)A
M8VME;F0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M($EN9V]?4W1O<F%G95]R=6QE?$EN9V]?4W1O<F%G95]F
M:6QT97)S("1O8B`@5&AE(&]B:F5C="!T;R!S=&]R92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-T;W)E*"8D;V(I"B`@("!["B`@("`@("`@9VQO8F%L
M("1P<F5F<SL*"B`@("`@("`@<W=I=&-H("@D;V(M/F]B5'EP92@I*2!["B`@
M("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-424].7T),04-+3$E35#H*("`@
M("`@("`@("`@)&1A=&$@/2!A<G)A>2@I.PH@("`@("`@("`@("`D9&%T85LG
M82==(#T@)&]B+3YG971";&%C:VQI<W0H*3L*("`@("`@("`@("`@)&1A=&%;
M)V8G72`]("1O8BT^9V5T0FQA8VML:7-T1F]L9&5R*"D["B`@("`@("`@("`@
M("1R970@/2`D<')E9G,M/G-E=%9A;'5E*"=B;&%C:VQI<W0G+"!S97)I86QI
M>F4H)&1A=&$I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M24Y'3U]35$]204=%7T%#5$E/3E]&24Q415)3.@H@("`@("`@("`@("`D<F5T
M(#T@)'!R969S+3YS971686QU92@G<G5L97,G+"!S97)I86QI>F4H4W1R:6YG
M.CIC;VYV97)T0VAA<G-E="@D;V(M/F=E=$9I;'1E<FQI<W0H*2P@3DQ3.CIG
M971#:&%R<V5T*"DL("1P<F5F<RT^9V5T0VAA<G-E="@I*2DL(&9A;'-E*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24Y'3U]35$]204=%
M7T%#5$E/3E]&3U)705)$.@H@("`@("`@("`@("`D9&%T82`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1D871A6R=A)UT@/2`D;V(M/F=E=$9O<G=A<F1!9&1R
M97-S97,H*3L*("`@("`@("`@("`@)&1A=&%;)VLG72`]("1O8BT^9V5T1F]R
M=V%R9$ME97`H*3L*("`@("`@("`@("`@)')E="`]("1P<F5F<RT^<V5T5F%L
M=64H)V9O<G=A<F0G+"!S97)I86QI>F4H)&1A=&$I*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]604-!
M5$E/3CH*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`D9&%T85LG861D<F5S<V5S)UT@/2`D;V(M/F=E=%9A8V%T:6]N061D<F5S
M<V5S*"D["B`@("`@("`@("`@("1D871A6R=D87ES)UT@/2`D;V(M/F=E=%9A
M8V%T:6]N1&%Y<R@I.PH@("`@("`@("`@("`D9&%T85LG97AC;'5D97,G72`]
M("1O8BT^9V5T5F%C871I;VY%>&-L=61E<R@I.PH@("`@("`@("`@("`D9&%T
M85LG:6=N;W)E;&ES="==(#T@)&]B+3YG971686-A=&EO;DEG;F]R96QI<W0H
M*3L*("`@("`@("`@("`@)&1A=&%;)W)E87-O;B==(#T@)&]B+3YG971686-A
M=&EO;E)E87-O;B@I.PH@("`@("`@("`@("`D9&%T85LG<W5B:F5C="==(#T@
M)&]B+3YG971686-A=&EO;E-U8FIE8W0H*3L*("`@("`@("`@("`@)&1A=&$@
M/2`D<')E9G,M/F-O;G9E<G14;T1R:79E<B@D9&%T82P@3DQ3.CIG971#:&%R
M<V5T*"DI.PH@("`@("`@("`@("`D<F5T(#T@)'!R969S+3YS971686QU92@G
M=F%C871I;VXG+"!S97)I86QI>F4H)&1A=&$I+"!F86QS92D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?
M5TA)5$5,25-4.@H@("`@("`@("`@("`D<F5T(#T@)'!R969S+3YS971686QU
M92@G=VAI=&5L:7-T)RP@<V5R:6%L:7IE*"1O8BT^9V5T5VAI=&5L:7-T*"DI
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("1R970@/2!F86QS93L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&EB+T1R
M:79E<B\`````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-3``,#$W,S4V`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6YG;R]L:6(O1')I=F5R+VQD87`N<&AP````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C,V,``Q,#0Q-S,V,C<U,``P,C$P,#<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J($EN9V]?1')I=F5R7VQD87`Z.B!);7!L96UE;G1S('1H92!3
M:65V95]$<FEV97(@87!I('1O(&%L;&]W('-C<FEP=',@=&\@8F4*("H@:6YS
M=&%L;&5D(&%N9"!S970@86-T:79E('9I82!A;B!,1$%0('-E<G9E<BX*("H*
M("H@)$AO<F1E.B!I;F=O+VQI8B]$<FEV97(O;&1A<"YP:'`L=B`Q+C@N,BXR
M(#(P,#8O,#$O,S$@,C`Z,#`Z,C0@:F%N($5X<"`D"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@
M*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S
M>7,N8V]M/@H@*B!`<VEN8V4@("!);F=O(#$N,0H@*B!`<&%C:V%G92!);F=O
M"B`J+PIC;&%S<R!);F=O7T1R:79E<E]L9&%P(&5X=&5N9',@26YG;U]$<FEV
M97(@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($EN9V]?1')I=F5R7VQD87`H)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VQD
M87`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%
M<G)O<BA?*"),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0
M(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(BDI+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)&1E9F%U
M;'1?<&%R86US(#T@87)R87DH)VAO<W1S<&5C)R`]/B`G;&]C86QH;W-T)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&]R="<@/3X@,S@Y
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S8W)I<'1?871T
M<FEB=71E)R`]/B`G;6%I;%-I979E4G5L95-O=7)C92<I.PH@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H)&1E9F%U;'1?<&%R86US+"`D
M<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A($1.(&9R
M;VT@82!$3B!T96UP;&%T92X*("`@("`J"B`@("`@*B!4:&ES(&ES(&1O;F4@
M8GD@<W5B<W1I='5T:6YG('1H92!U<V5R;F%M92!F;W(@)74@86YD('1H92`G
M9&,])PH@("`@("H@8V]M<&]N96YT<R!F;W(@)60N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5M<&P@("`@(%1H92!$3B!T96UP;&%T92`H9G)O;2!T:&4@8V]N9FEG*2X*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("!4:&4@=7-E<FYA;64@
M=&\@<W5B<W1I='5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(')E<W5L=&EN9R!$3BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-U8G-T
M57-E<B@D=&5M<&PL("1U<V5R;F%M92D*("`@('L*("`@("`@("`D9&]M86EN
M(#T@)R<["B`@("`@("`@:68@*'-T<G!O<R@D=7-E<FYA;64L("=`)RD@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@(&QI<W0H)'5S97)N86UE+"`D9&]M86EN
M*2`](&5X<&QO9&4H)T`G+"`D=7-E<FYA;64I.PH@("`@("`@('T*("`@("`@
M("`D9&]M86EN(#T@:6UP;&]D92@G+"!D8STG+"!E>'!L;V1E*"<N)RP@)&1O
M;6%I;BDI.PH@("`@("`@(&EF("@A96UP='DH)&1O;6%I;BDI('L*("`@("`@
M("`@("`@)&1O;6%I;B`]("=D8STG("X@)&1O;6%I;CL*("`@("`@("!]"@H@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EQS?%QS)'Q<<UQS?%LL*STB7')<
M;CP^(SM=+R<L("1U<V5R;F%M92DI('L*("`@("`@("`@("`@)'5S97)N86UE
M(#T@)R(G("X@<W1R7W)E<&QA8V4H)R(G+"`G7%PB)RP@)'5S97)N86UE*2`N
M("<B)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!S=')?<F5P;&%C92AA
M<G)A>2@G)74G+"`G)60G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)'5S97)N86UE+"`D9&]M86EN*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1E;7!L*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;FYE
M8W0@86YD(&)I;F0@=&\@;&1A<"!S97)V97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<FYA;64@(%1H92!U<V5R('1O(&)I;F0@87,N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5&AE(&)I;F0@<&%S<W=O
M<F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"1U<V5R;F%M92P@
M)'!A<W-W;W)D*0H@("`@>PH@("`@("`@(&EF("@A*"1L9&%P8VX@/2!`;&1A
M<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=P;W)T)UTI*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")#;VYN96-T:6]N(&9A:6QU<F4B*2D["B`@("`@("`@?0H*("`@
M("`@("`O*B!3970@=&AE($Q$05`@<')O=&]C;VP@=F5R<VEO;BX@*B\*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI*2![
M"B`@("`@("`@("`@($!L9&%P7W-E=%]O<'1I;VXH)&QD87!C;BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!,1$%07T]05%]04D]43T-/3%]615)3
M24].+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=V97)S:6]N)UTI.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1A<G0@
M5$Q3(&EF('=E)W)E('5S:6YG(&ET+B`J+PH@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]P87)A;7-;)W1L<R==*2D@>PH@("`@("`@("`@("!I9B`H(4!L
M9&%P7W-T87)T7W1L<R@D;&1A<&-N*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")35$%25%1,4R!F86EL
M960Z("@E<RD@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D;&1A<&-N*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&1A
M<%]E<G)O<B@D;&1A<&-N*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O*B!":6YD('1O('1H92!S97)V97(N("HO"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=B:6YD7V1N)UTI*2!["B`@("`@("`@
M("`@("1B:6YD7V1N(#T@)'1H:7,M/E]S=6)S=%5S97(H)'1H:7,M/E]P87)A
M;7-;)V)I;F1?9&XG72P@)'5S97)N86UE*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)&)I;F1?9&XL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D8FEN9%]D;CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=B:6YD7W!A<W-W;W)D)UTI*2![
M"B`@("`@("`@("`@("`@("`D<&%S<W=O<F0@/2`D=&AI<RT^7W!A<F%M<ULG
M8FEN9%]P87-S=V]R9"==.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H(4!L9&%P7V)I;F0H)&QD87!C;BP@)&)I;F1?9&XL("1P87-S=V]R9"DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B0FEN9"!F86EL960Z("@E<RD@)7,B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N
M;R@D;&1A<&-N*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D;&1A<&-N*2DI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E:68@*"$H0&QD87!?8FEN9"@D;&1A<&-N
M*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")":6YD(&9A:6QE9#H@*"5S*2`E<R(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)&QD
M87!C;BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;&1A<%]E<G)O<B@D;&1A<&-N*2DI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1L9&%P8VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R
M:65V92!C=7)R96YT('5S97(G<R!S8W)I<'1S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M;&1A<&-N("!4:&4@8V]N;F5C=&EO;B!T;R!T:&4@3$1!4"!S97)V97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92`@5&AE('5S97(G<R!L;V=I
M;BX*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)$3B`@("!3970@=&\@=&AE
M('5S97(@;V)J96-T)W,@<F5A;"!$3BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!!<G)A>2!O9B!S8W)I<'0@<V]U<F-E<RP@;W(@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T4V-R:7!T
M<R@D;&1A<&-N+"`D=7-E<FYA;64L("8D=7-E<D1.*0H@("`@>PH@("`@("`@
M("1A='1R<R`](&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=S8W)I<'1?871T<FEB
M=71E)UTL("=D;B<I.PH@("`@("`@("1F:6QT97(@/2`D=&AI<RT^7W-U8G-T
M57-E<B@D=&AI<RT^7W!A<F%M<ULG<V-R:7!T7V9I;'1E<B==+"`D=7-E<FYA
M;64I.PH*("`@("`@("`O*B!&:6YD('1H92!U<V5R(&]B:F5C="X@*B\*("`@
M("`@("`D<W(@/2!`;&1A<%]S96%R8V@H)&QD87!C;BP@)'1H:7,M/E]P87)A
M;7-;)W-C<FEP=%]B87-E)UTL("1F:6QT97(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A='1R<RD["B`@("`@("`@:68@*"1S<B`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")%<G)O<B!R971R:65V:6YG(&-U<G)E;G0@<V-R:7!T.B`H)60I("5S
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;&1A<%]E<G)N;R@D;&1A<&-N*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1L9&%P8VXI*2D[
M"B`@("`@("`@?0H@("`@("`@(&EF("A`;&1A<%]C;W5N=%]E;G1R:65S*"1L
M9&%P8VXL("1S<BD@(3T@,2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(D5X<&5C=&5D(#$@;V)J96-T+"!G;W0@
M)60N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;&1A<%]C;W5N=%]E;G1R:65S*"1L9&%P8VXL("1S<BDI*3L*("`@
M("`@("!]"B`@("`@("`@)&5N="`]($!L9&%P7V9I<G-T7V5N=')Y*"1L9&%P
M8VXL("1S<BD["B`@("`@("`@:68@*"1E;G0@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B17)R
M;W(@<F5T<FEE=FEN9R!C=7)R96YT('-C<FEP=#H@*"5D*2`E<R(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?
M97)R;F\H)&QD87!C;BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D;&1A<&-N*2DI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4F5T<FEE=F4@=&AE('5S97(G<R!$3BX@*B\*("`@
M("`@("`D=B`]($!L9&%P7V=E=%]D;B@D;&1A<&-N+"`D96YT*3L*("`@("`@
M("!I9B`H)'8@/3T](&9A;'-E*2!["B`@("`@("`@("`@($!L9&%P7V9R965?
M<F5S=6QT*"1S<BD["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B17)R;W(@<F5T<FEE=FEN9R!C=7)R96YT('-C<FEP
M=#H@*"5D*2`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&QD87!?97)R;F\H)&QD87!C;BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D
M;&1A<&-N*2DI.PH@("`@("`@('T*("`@("`@("`D=7-E<D1.(#T@)'8["@H@
M("`@("`@("\J(%)E=')I979E('1H92!U<V5R)W,@<V-R:7!T<RX@*B\*("`@
M("`@("`D871T<G,@/2!`;&1A<%]G971?871T<FEB=71E<R@D;&1A<&-N+"`D
M96YT*3L*("`@("`@("!`;&1A<%]F<F5E7W)E<W5L="@D<W(I.PH@("`@("`@
M(&EF("@D871T<G,@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B17)R;W(@<F5T<FEE=FEN9R!C
M=7)R96YT('-C<FEP=#H@*"5D*2`E<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)&QD87!C;BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;&1A<%]E<G)O<B@D;&1A<&-N*2DI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M071T<FEB=71E(&-A;B!B92!I;B!A;GD@8V%S92P@86YD(&-A;B!H879E(&$@
M(CMB:6YA<GDB"B`@("`@("`@("H@<W!E8VEF:65R+B`J+PH@("`@("`@("1R
M96=E>'`@/2`G+UXG("X@<')E9U]Q=6]T92@D=&AI<RT^7W!A<F%M<ULG<V-R
M:7!T7V%T=')I8G5T92==+"`G+R<I("X*("`@("`@("`@("`@("`@("`@)R@_
M.CLN*BD_)"]I)SL*("`@("`@("!U;G-E="@D871T<G-;)V-O=6YT)UTI.PH@
M("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D;F%M92`]/B`D=F%L=65S*2![
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"1R96=E>'`L("1N86UE*2D@
M>PH@("`@("`@("`@("`@("`@=6YS970H)'9A;'5E<ULG8V]U;G0G72D["B`@
M("`@("`@("`@("`@("!R971U<FX@87)R87E?=F%L=65S*"1V86QU97,I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@82!S8W)I<'0@<G5N;FEN
M9R!O;B!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S8W)I<'0@("`@5&AE('-I979E('-C<FEP="X*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97)N86UE("!4:&4@8F%C:V5N9"!U<V5R;F%M92X*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("!4:&4@8F%C:V5N9"!P87-S=V]R
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E
M<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=%-C<FEP=$%C=&EV92@D<V-R:7!T+"`D=7-E<FYA;64L("1P87-S=V]R
M9"D*("`@('L*("`@("`@("`D;&1A<&-N(#T@)'1H:7,M/E]C;VYN96-T*"1U
M<V5R;F%M92P@)'!A<W-W;W)D*3L*("`@("`@("!I9B`H:7-?82@D;&1A<&-N
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;&1A<&-N
M.PH@("`@("`@('T*"B`@("`@("`@)'9A;'5E<R`]("1T:&ES+3Y?9V5T4V-R
M:7!T<R@D;&1A<&-N+"`D=7-E<FYA;64L("1U<V5R1$XI.PH@("`@("`@(&EF
M("AI<U]A*"1V86QU97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1V86QU97,["B`@("`@("`@?0H*("`@("`@("`D9F]U;F0@/2!F
M86QS93L*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1I(#T^("1V86QU
M92D@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1V86QU92P@(B,C24Y'3UQN
M(BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)'-C
M<FEP="DI('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D=F%L=65S6R1I
M72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1V86QU97-;)&E=(#T@)'-C<FEP=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M(21F;W5N9"`F)B`A96UP='DH)'-C<FEP="DI('L*("`@("`@("`@("`@)'9A
M;'5E<UM=(#T@)'-C<FEP=#L*("`@("`@("!]"@H@("`@("`@("1R97!L86-E
M(#T@87)R87DH4W1R:6YG.CIL;W=E<B@D=&AI<RT^7W!A<F%M<ULG<V-R:7!T
M7V%T=')I8G5T92==*2`]/B`D=F%L=65S*3L*("`@("`@("!I9B`H96UP='DH
M)'9A;'5E<RDI('L*("`@("`@("`@("`@)'(@/2!`;&1A<%]M;V1?9&5L*"1L
M9&%P8VXL("1U<V5R1$XL("1R97!L86-E*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<B`]($!L9&%P7VUO9%]R97!L86-E*"1L9&%P8VXL("1U
M<V5R1$XL("1R97!L86-E*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D<BD@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(D%C=&EV871I;F<@=&AE('-C<FEP="!F;W(@7"(E<UPB(&9A:6QE9#H@
M*"5D*2`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1U<V5R1$XL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D;&1A<&-N*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R
M<F]R*"1L9&%P8VXI*2D["B`@("`@("`@?0H*("`@("`@("!`;&1A<%]C;&]S
M92@D;&1A<&-N*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G0@;V8@=&AE(&-U<G)E;G1L
M>2!A8W1I=F4@<V-R:7!T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97)N86UE("!4:&4@8F%C:V5N9"!U<V5R;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A<W-W;W)D("!4:&4@8F%C:V5N9"!P87-S=V]R9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;7!L971E(')U;&5S
M970@;V8@=&AE('-P96-I9FEE9"!U<V5R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G97138W)I<'0H)'5S97)N86UE+"`D<&%S<W=O<F0I"B`@("!["B`@("`@
M("`@)&QD87!C;B`]("1T:&ES+3Y?8V]N;F5C="@D=7-E<FYA;64L("1P87-S
M=V]R9"D["B`@("`@("`@:68@*&ES7V$H)&QD87!C;BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&QD87!C;CL*("`@("`@("!]"@H@
M("`@("`@("1V86QU97,@/2`D=&AI<RT^7V=E=%-C<FEP=',H)&QD87!C;BP@
M)'5S97)N86UE+"`D=7-E<D1.*3L*("`@("`@("!I9B`H:7-?82@D=F%L=65S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=F%L=65S
M.PH@("`@("`@('T*"B`@("`@("`@)'-C<FEP="`]("<G.PH@("`@("`@(&9O
M<F5A8V@@*"1V86QU97,@87,@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("AS
M=')P;W,H)'9A;'5E+"`B(R-)3D=/7&XB*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1S8W)I<'0@/2`D=F%L=64["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@;&1A<%]C
M;&]S92@D;&1A<&-N*3L*("`@("`@("!R971U<FX@)'-C<FEP=#L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&EB+T1R:79E
M<B]T:6US:65V960N<&AP````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#4W,#4`,3`T,3<S-C(W-3``,#(R,#8T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4H)TYE
M="]3:65V92YP:'`G*3L*"B\J*@H@*B!);F=O7T1R:79E<E]T:6US:65V960Z
M.B!);7!L96UE;G1S('1H92!3:65V95]$<FEV97(@87!I('1O(&%L;&]W('-C
M<FEP=',@=&\*("H@8F4@:6YS=&%L;&5D(&%N9"!S970@86-T:79E('9I82!A
M($-Y<G5S('1I;7-I979E9"!S97)V97(N"B`J"B`J("1(;W)D93H@:6YG;R]L
M:6(O1')I=F5R+W1I;7-I979E9"YP:'`L=B`Q+C$U+C$P+C8@,C`P-B\P,2\S
M,2`R,#HP,#HR-"!J86X@17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN("!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H
M;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J
M($!S:6YC92`@($EN9V\@,"XQ"B`J($!P86-K86=E($EN9V\*("HO"F-L87-S
M($EN9V]?1')I=F5R7W1I;7-I979E9"!E>'1E;F1S($EN9V]?1')I=F5R('L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!);F=O7T1R:79E<E]T:6US:65V960H)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@)&1E9F%U;'1?<&%R86US(#T@87)R87DH"B`@("`@
M("`@("`@("=H;W-T<W!E8R<@("`]/B`G;&]C86QH;W-T)RP*("`@("`@("`@
M("`@)VQO9VEN='EP92<@(#T^("=03$%)3B<L"B`@("`@("`@("`@("=P;W)T
M)R`@("`@("`]/B`R,#`P+`H@("`@("`@("`@("`G<V-R:7!T;F%M92<@/3X@
M)VEN9V\G+`H@("`@("`@("`@("`G861M:6XG("`@("`@/3X@)R<*("`@("`@
M("`I.PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H)&1E
M9F%U;'1?<&%R86US+"`D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@82!S8W)I<'0@<G5N;FEN9R!O;B!T:&4@8F%C:V5N9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8W)I<'0@("`@5&AE('-I979E('-C
M<FEP="X*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("!4:&4@8F%C
M:V5N9"!U<V5R;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D
M("!4:&4@8F%C:V5N9"!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,N"B`@("`@*B`@("`@("`@("`@("`@
M("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%-C<FEP=$%C=&EV92@D<V-R:7!T+"`D=7-E<FYA;64L("1P
M87-S=V]R9"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A
M;7-;)V%D;6EN)UTI*2!["B`@("`@("`@("`@("1A=71H(#T@)'5S97)N86UE
M.PH@("`@("`@("`@("`D=7-E<B`]("<G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1A=71H(#T@)'1H:7,M/E]P87)A;7-;)V%D;6EN)UT["B`@
M("`@("`@("`@("1U<V5R(#T@)'5S97)N86UE.PH@("`@("`@('T*("`@("`@
M("`D<VEE=F4@/2`F;F5W($YE=%]3:65V92@D875T:"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG;&]G:6YT>7!E)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'5S97(I.PH*("`@("`@("!I9B`H:7-?82@D<F5S
M(#T@)'-I979E+3YG971%<G)O<B@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1S:65V92T^:6YS=&%L;%-C<FEP="@D=&AI<RT^7W!A<F%M<ULG<V-R:7!T
M;F%M92==+"`D<V-R:7!T+"!T<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&-O;G1E;G0@;V8@=&AE(&-U<G)E;G1L>2!A8W1I=F4@
M<V-R:7!T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE
M("!4:&4@8F%C:V5N9"!U<V5R;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<W-W;W)D("!4:&4@8F%C:V5N9"!P87-S=V]R9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;7!L971E(')U;&5S970@;V8@=&AE
M('-P96-I9FEE9"!U<V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G97138W)I
M<'0H)'5S97)N86UE+"`D<&%S<W=O<F0I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;B==*2D@>PH@("`@("`@("`@("`D
M875T:"`]("1U<V5R;F%M93L*("`@("`@("`@("`@)'5S97(@/2`G)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D875T:"`]("1T:&ES+3Y?<&%R
M86US6R=A9&UI;B==.PH@("`@("`@("`@("`D=7-E<B`]("1U<V5R;F%M93L*
M("`@("`@("!]"B`@("`@("`@)'-I979E(#T@)FYE=R!.971?4VEE=F4H)&%U
M=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<W-W;W)D
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VQO9VEN='EP92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R*3L*"B`@("`@
M("`@:68@*&ES7V$H)')E<R`]("1S:65V92T^9V5T17)R;W(H*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<VEE=F4M/F=E=%-C<FEP="@D<VEE=F4M/F=E
M=$%C=&EV92@I*3L*("`@('T*?0H`````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6YG;R]L:6(O1')I=F5R+W9F<RYP:'``````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S,P,@`Q,#0Q-S,V,C<U
M,``P,C`V-C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($EN9V]?1')I=F5R7W9F<SHZ($EM<&QE;65N
M=',@86X@26YG;R!S=&]R86=E(&1R:79E<B!U<VEN9R!(;W)D92!61E,N"B`J
M"B`J("1(;W)D93H@:6YG;R]L:6(O1')I=F5R+W9F<RYP:'`L=B`Q+C$R+C$P
M+C@@,C`P-B\P,B\P,B`R,CHU-SHT,B!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!"<F5N="!*+B!.;W)D<75I<W0@/&)J;D!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L
M:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!"<F5N="!*+B!.;W)D
M<75I<W0@/&)J;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($EN9V\@,"XQ"B`J
M($!P86-K86=E($EN9V\*("HO"F-L87-S($EN9V]?1')I=F5R7W9F<R!E>'1E
M;F1S($EN9V]?1')I=F5R('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@
M82!N97<@5D93+6)A<V5D('-T;W)A9V4@9')I=F5R+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!D<FEV
M97(@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@26YG;U]$<FEV
M97)?=F9S*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D969A
M=6QT7W!A<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`G:&]S='-P96,G("`@
M(#T^("`G;&]C86QH;W-T)RP*("`@("`@("`@("`@)W!O<G0G("`@("`@("`]
M/B`@,C$L"B`@("`@("`@("`@("=F:6QE;F%M92<@("`@/3X@("<N:6YG;U]F
M:6QT97(G+`H@("`@("`@("`@("`G=F9S='EP92<@("`@(#T^("`G9G1P)RP*
M("`@("`@("`@("`@)W5S97)N86UE)R`@("`]/B`@9F%L<V4L"B`@("`@("`@
M("`@("=P87-S=V]R9"<@("`@/3X@(&9A;'-E+`H@("`@("`@("`@("`G=F9S
M7W!A=&@G("`@(#T^("`G)RP*("`@("`@("`I.PH@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@87)R87E?;65R9V4H)&1E9F%U;'1?<&%R86US+"`D<&%R86US
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-U8G-T:71U=&5S(%]P87)A;2!V
M87)I86)L97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA
M;64@(%1H92!U<V5R)W,@;&]G:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M87-S=V]R9"`@5&AE('5S97(G<R!P87-S=V]R9"X*("`@("`J"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]S=6)S=%9A<G,H)'5S97)N86UE+"`D<&%S<W=O<F0I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=U<V5R
M;F%M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA
M;64G72`]("1U<V5R;F%M93L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72`]("1P87-S=V]R9#L*("`@("`@
M("!]"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG=F9S7W!A
M=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9F<U]P871H
M)UT@/2!S=')?<F5P;&%C92AA<G)A>2@G)74G+"`G)54G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@D=7-E<FYA;64L("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=F9S7W!A=&@G72D["B`@("`@("`@
M("`@(&EF("AS=6)S='(H)'1H:7,M/E]P87)A;7-;)W9F<U]P871H)UTL("TQ
M*2`A/2`G+R<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V
M9G-?<&%T:"==("X]("<O)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)V9I;&5N86UE)UTI("8F
M"B`@("`@("`@("`@("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<')O8VUA:6QR
M8R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9FEL96YA;64G
M72`]("1T:&ES+3Y?<&%R86US6R=P<F]C;6%I;')C)UT["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A('-C<FEP="!R=6YN:6YG(&]N
M('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-C
M<FEP="`@5&AE(&9I;'1E<B!S8W)I<'0*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(&]R(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4V-R:7!T06-T:79E*"1S
M8W)I<'0L("1U<V5R;F%M92P@)'!A<W-W;W)D*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7W!A<F%M<ULG=F9S='EP92==("$]("=F='`G*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H<W!R:6YT9B@B5D93
M('1Y<&4@7"(E<UPB(&YO="!Y970@:6UP;&5M96YT960N(BP@)'1H:7,M/E]P
M87)A;7-;)W9F<W1Y<&4G72DI*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?<W5B<W1687)S*"1U<V5R;F%M92P@)'!A<W-W;W)D*3L*"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=61E,N<&AP)SL*("`@("`@("`D=F9S(#T@)E9&4SHZ
M<VEN9VQE=&]N*"1T:&ES+3Y?<&%R86US6R=V9G-T>7!E)UTL("1T:&ES+3Y?
M<&%R86US*3L*("`@("`@("`D<F5S(#T@)'9F<RT^=W)I=&5$871A*"<G+"`D
M=&AI<RT^7W!A<F%M<ULG=F9S7W!A=&@G72`N("1T:&ES+3Y?<&%R86US6R=F
M:6QE;F%M92==+"`D<V-R:7!T*3L*("`@("`@("`D=F9S+3Y?9&ES8V]N;F5C
M="@I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M8V]N=&5N="!O9B!T:&4@8W5R<F5N=&QY(&%C=&EV92!S8W)I<'0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@(%1H92!B86-K96YD
M('5S97)N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<W=O<F0@(%1H
M92!B86-K96YD('!A<W-W;W)D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8V]M<&QE=&4@<G5L97-E="!O9B!T:&4@<W!E8VEF:65D('5S
M97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-C<FEP="@D=7-E<FYA;64L
M("1P87-S=V]R9"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;
M)W9F<W1Y<&4G72`A/2`G9G1P)RD@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*'-P<FEN=&8H(E9&4R!T>7!E(%PB)7-<(B!N;W0@
M>65T(&EM<&QE;65N=&5D+B(L("1T:&ES+3Y?<&%R86US6R=V9G-T>7!E)UTI
M*2D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-U8G-T5F%R<R@D=7-E
M<FYA;64L("1P87-S=V]R9"D["@H@("`@("`@(')E<75I<F5?;VYC92`G5D93
M+G!H<"<["B`@("`@("`@)'9F<R`]("961E,Z.G-I;F=L971O;B@D=&AI<RT^
M7W!A<F%M<ULG=F9S='EP92==+"`D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@
M)')E<R`]("1V9G,M/G)E860H)R<L("1T:&ES+3Y?<&%R86US6R=V9G-?<&%T
M:"==("X@)'1H:7,M/E]P87)A;7-;)V9I;&5N86UE)UTI.PH@("`@("`@("1V
M9G,M/E]D:7-C;VYN96-T*"D["B`@("`@("`@<F5T=7)N("1R97,["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L:6(O1')I
M=F5R+VYU;&PN<&AP````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#<S,@`Q,#0Q-S,V,C<U,``P,C$P-#``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@
M:6YG;R]L:6(O1')I=F5R+VYU;&PN<&AP+'8@,2XQ,"XQ,"XR(#(P,#8O,#$O
M,S$@,C`Z,#`Z,C0@:F%N($5X<"`D"B`J"B`J($EN9V]?1')I=F5R7VYU;&PZ
M.B!);7!L96UE;G1S(&$@;G5L;"!A<&D@+2T@=7-E9G5L(&9O<B!J=7-T('1E
M<W1I;F<*("H@=&AE(%5)(&%N9"!S=&]R86=E+@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M05-,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*("H*
M("H@0&%U=&AO<B`@0G)E;G0@2BX@3F]R9'%U:7-T(#QB:FY`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`<&%C:V%G92!);F=O"B`J+PH*
M8VQA<W,@26YG;U]$<FEV97)?;G5L;"!E>'1E;F1S($EN9V]?1')I=F5R('L*
M"GT*```````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&EB+T)L;V-K+P``````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-3``,#$W,34U`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L
M:6(O0FQO8VLO;W9E<G9I97<N<&AP````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C(P,``Q,#0Q-S,V,C<U,``P,C$U,C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B1B;&]C:U]N
M86UE(#T@7R@B3W9E<G9I97<B*3L*"B\J*@H@*B!);F=O7T9I;'1E<G-?0FQO
M8VLZ.B!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&5?0FQO8VL@05!)('1O
M('-H;W<@9FEL=&5R"B`J(&EN9F]R;6%T:6]N(&]N('1H92!P;W)T86PN"B`J
M"B`J("1(;W)D93H@:6YG;R]L:6(O0FQO8VLO;W9E<G9I97<N<&AP+'8@,2XQ
M+C(N-"`R,#`V+S`Q+S,Q(#(P.C`P.C(T(&IA;B!%>'`@)`H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H05-,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H
M<"X*("H*("H@0&%U=&AO<B`@3VQI=F5R($MU:&P@/&]K=6AL0&YE=&-O;&]G
M;F4N9&4^"B`J($!S:6YC92`@($EN9V\@,2XQ"B`J($!P86-K86=E($AO<F1E
M7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U]I;F=O7V]V97)V:65W(&5X
M=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=I;F=O)SL*
M"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I;B!T:&ES(&)L;V-K
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE('1I=&QE('1E
M>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@
M("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@<F5T=7)N($AO<F1E.CIL
M:6YK*$AO<F1E.CIU<FPH)')E9VES=')Y+3YG971);FET:6%L4&%G92@I+"!T
M<G5E*2D@+B`D<F5G:7-T<GDM/F=E="@G;F%M92<I("X@)SPO83XG.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@=&AI<R!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!C;VYT
M96YT"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@('L*("`@
M("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("!R97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN+V)A<V4N<&AP)SL*"B`@("`@("`@+RH@
M1V5T(&QI<W0@;V8@9FEL=&5R<R`J+PH@("`@("`@("1F:6QT97)S(#T@)B1'
M3$]"04Q36R=I;F=O7W-T;W)A9V4G72T^<F5T<FEE=F4H24Y'3U]35$]204=%
M7T%#5$E/3E]&24Q415)3*3L*("`@("`@("`D:'1M;"`]("<\=&%B;&4@=VED
M=&@](C$P,"4B(&AE:6=H=#TB,3`P)2(^)SL*("`@("`@("`D:'1M;%]P<F4@
M/2`G/'1R/CQT9"!V86QI9VX](G1O<"(^)SL*("`@("`@("`D:'1M;%]P;W-T
M(#T@)SPO=&0^/"]T<CXG.PH@("`@("`@(&9O<F5A8V@@*"1F:6QT97)S+3Y?
M9FEL=&5R<R!A<R`D9FEL=&5R*2!["B`@("`@("`@("`@(&EF("@A96UP='DH
M)&9I;'1E<ELG9&ES86)L92==*2D@>PH@("`@("`@("`@("`@("`@)&%C=&EV
M92`](%\H(FEN86-T:79E(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D86-T:79E(#T@7R@B86-T:79E(BD["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@('-W:71C:"@D9FEL=&5R6R=N86UE)UTI('L*("`@
M("`@("`@("`@8V%S92`G5F%C871I;VXG.@H@("`@("`@("`@("`@("`@("1H
M=&UL("X]("1H=&UL7W!R92`N"B`@("`@("`@("`@("`@("`@("`@($AO<F1E
M.CII;6<H)W9A8V%T:6]N+G!N9R<L(%\H(E9A8V%T:6]N(BDI("X@)SPO=&0^
M/'1D/B<@+@H@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ;&EN:RA(;W)D
M93HZ87!P;&EC871I;VY5<FPH)W9A8V%T:6]N+G!H<"<I+"!?*")%9&ET(BDI
M("X*("`@("`@("`@("`@("`@("`@("`@7R@B5F%C871I;VXB*2`N("<\+V$^
M("<@+B`D86-T:79E("X@)&AT;6Q?<&]S=#L*("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T9O<G=A<F0G.@H@("`@("`@("`@
M("`@("`@("1H=&UL("X]("1H=&UL7W!R92`N"B`@("`@("`@("`@("`@("`@
M("`@($AO<F1E.CII;6<H)V9O<G=A<F0N<&YG)RP@7R@B1F]R=V%R9"(I*2`N
M("<\+W1D/CQT9#XG("X*("`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.FQI
M;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=F;W)W87)D+G!H<"<I+"!?*")%
M9&ET(BDI("X*("`@("`@("`@("`@("`@("`@("`@7R@B1F]R=V%R9"(I("X@
M)SPO83X@)R`N("1A8W1I=F4["B`@("`@("`@("`@("`@("`@)&1A=&$@/2!U
M;G-E<FEA;&EZ92@D<')E9G,M/F=E=%9A;'5E*"=F;W)W87)D)RDI.PH@("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&1A=&%;)V$G72DI('L*("`@("`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G.CQB<B`O/B<@+B!I;7!L;V1E*"<\
M8G(@+SXG+"`D9&%T85LG82==*3L*("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@)&AT;6Q?<&]S=#L*("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U=H:71E;&ES="<Z"B`@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@)&AT;6Q?<')E("X*("`@("`@("`@
M("`@("`@("`@("`@2&]R9&4Z.FEM9R@G=VAI=&5L:7-T+G!N9R<L(%\H(E=H
M:71E;&ES="(I*2`N"B`@("`@("`@("`@("`@("`@("`@("<\+W1D/CQT9#XG
M("X*("`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=W:&ET96QI<W0N<&AP)RDL(%\H(D5D:70B*2D@+@H@
M("`@("`@("`@("`@("`@("`@("!?*")7:&ET96QI<W0B*2`N("<\+V$^("<@
M+B`D86-T:79E("X@)&AT;6Q?<&]S=#L*("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)T)L86-K;&ES="<Z"B`@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@)&AT;6Q?<')E("X*("`@("`@("`@("`@("`@("`@
M("`@2&]R9&4Z.FEM9R@G8FQA8VML:7-T+G!N9R<L(%\H(D)L86-K;&ES="(I
M*2`N"B`@("`@("`@("`@("`@("`@("`@("<\+W1D/CQT9#XG("X*("`@("`@
M("`@("`@("`@("`@("`@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=B;&%C:VQI<W0N<&AP)RDL(%\H(D5D:70B*2D@+@H@("`@("`@("`@
M("`@("`@("`@("!?*")";&%C:VQI<W0B*2`N("<\+V$^("<@+B`D86-T:79E
M("X@)&AT;6Q?<&]S=#L*("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?0H*("`@("`@("!]"B`@("`@("`@)&AT;6P@+CT@)SPO=&%B;&4^
M)SL*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O
M;&EB+W9E<G-I;VXN<&AP````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P-30`,3`T,3<S-C(W-3``,#(P,S$U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP(&1E9FEN92@G
M24Y'3U]615)324].)RP@)T@S("@Q+C$I)RD@/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+VQI8B]397-S:6]N
M+G!H<```````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V
M,#4V`#$P-#$W,S8R-S4P`#`R,#(V,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@1G5N8W1I;VYS(')E
M<75I<F5D('1O('-T87)T(&$@26YG;R!S97-S:6]N+@H@*@H@*B`D2&]R9&4Z
M(&EN9V\O;&EB+U-E<W-I;VXN<&AP+'8@,2XR+C$P+C<@,C`P-B\P,2\S,2`R
M,#HP,#HR-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H05-,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H
M<"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@26YG;R`Q+C`*("H@0'!A8VMA9V4@26YG
M;PH@*B\*8VQA<W,@26YG;U]397-S:6]N('L*"B`@("`O*BH*("`@("`J($-R
M96%T92!A;B!I;F=O('-E<W-I;VXN"B`@("`@*B!4:&ES(&9U;F-T:6]N('-H
M;W5L9"!O;FQY(&)E(&-A;&QE9"!O;F-E+"!W:&5N('1H92!U<V5R(&9I<G-T
M('5S97,*("`@("`J($EN9V\@:6X@82!S97-S:6]N+@H@("`@("H*("`@("`J
M($-R96%T97,@=&AE("1I;F=O('-E<W-I;VX@=F%R:6%B;&4@=VET:"!T:&4@
M9F]L;&]W:6YG(&5N=')I97,Z"B`@("`@*B`G8F%C:V5N9"<@*&%R<F%Y*2`M
M(%1H92!B86-K96YD(&-O;F9I9W5R871I;VX@=&\@=7-E+@H@("`@("H@)V-H
M86YG92<@*&EN=&5G97(I("T@5&AE('1I;65S=&%M<"!O9B!T:&4@;&%S="!T
M:6UE('1H92!R=6QE<R!W97)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!A;'1E<F5D+@H@("`@("H@)W-T;W)A9V4G("AA<G)A>2D@+2!5<V5D(&)Y
M($EN9V]?4W1O<F%G93HZ(&9O<B!C86-H:6YG(&1A=&$N"B`@("`@*B`G<V-R
M:7!T7V-A=&5G;W)I97,G("AA<G)A>2D@+2!4:&4@;&ES="!O9B!A=F%I;&%B
M;&4@8V%T96=O<FEE<R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!);F=O7U-C<FEP="!D<FEV97(@:6X@=7-E+@H@("`@
M("H@)W-C<FEP=%]G96YE<F%T92<@*&)O;VQE86XI("T@27,@=&AE($EN9V]?
M4V-R:7!T.CIG96YE<F%T92@I(&-A;&P*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%V86EL86)L93\*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5S<VEO;B@I"B`@("![
M"B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)%]315-324].6R=I
M;F=O)UT@/2!A<G)A>2@I.PH@("`@("`@("1?4T534TE/3ELG:6YG;R==6R=C
M:&%N9V4G72`](#`["B`@("`@("`@)%]315-324].6R=I;F=O)UU;)W-T;W)A
M9V4G72`](&%R<F%Y*"D["@H@("`@("`@("\J($=E="!T:&4@8F%C:V5N9"X@
M*B\*("`@("`@("`D7U-%4U-)3TY;)VEN9V\G75LG8F%C:V5N9"==(#T@26YG
M;SHZ9V5T0F%C:V5N9"@I.PH*("`@("`@("`O*B!$971E<FUI;F4@:68@=&AE
M($EN9V]?4V-R:7!T.CH@9V5N97)A=&4H*2!M971H;V0@:7,@879A:6QA8FQE
M+B`J+PH@("`@("`@("1I;F=O7W-C<FEP="`]("9);F=O.CIL;V%D26YG;U-C
M<FEP="@I.PH@("`@("`@("1?4T534TE/3ELG:6YG;R==6R=S8W)I<'1?9V5N
M97)A=&4G72`]("1I;F=O7W-C<FEP="T^9V5N97)A=&5!=F%I;&%B;&4H*3L*
M"B`@("`@("`@+RH@1V5T('1H92!L:7-T(&]F(&-A=&5G;W)I97,@=&AI<R!D
M<FEV97(@<W5P<&]R=',N("HO"B`@("`@("`@)%]315-324].6R=I;F=O)UU;
M)W-C<FEP=%]C871E9V]R:65S)UT@/2!A<G)A>5]M97)G92@D:6YG;U]S8W)I
M<'0M/F%V86EL86)L94%C=&EO;G,H*2P@)&EN9V]?<V-R:7!T+3YA=F%I;&%B
M;&5#871E9V]R:65S*"DI.PH*("`@("`@("`O*B!$:7-A8FQE(&-A=&5G;W)I
M97,@87,@<W!E8VEF:65D(&EN('!R969E<F5N8V5S("HO"B`@("`@("`@:68@
M*"1P<F5F<RT^:7-,;V-K960H)V)L86-K;&ES="<I("8F(&EN7V%R<F%Y*$E.
M1T]?4U1/4D%'15]!0U1)3TY?0DQ!0TM,25-4+"`D7U-%4U-)3TY;)VEN9V\G
M75LG<V-R:7!T7V-A=&5G;W)I97,G72DI('L*("`@("`@("`@("`@)%]315-3
M24].6R=I;F=O)UU;)W-C<FEP=%]C871E9V]R:65S)UT@/2!A<G)A>5]D:69F
M*"1?4T534TE/3ELG:6YG;R==6R=S8W)I<'1?8V%T96=O<FEE<R==+"!A<G)A
M>2A)3D=/7U-43U)!1T5?04-424].7T),04-+3$E35"DI.PH@("`@("`@('T*
M("`@("`@("!I9B`H)'!R969S+3YI<TQO8VME9"@G=VAI=&5L:7-T)RD@)B8@
M:6Y?87)R87DH24Y'3U]35$]204=%7T%#5$E/3E]72$E414Q)4U0L("1?4T53
M4TE/3ELG:6YG;R==6R=S8W)I<'1?8V%T96=O<FEE<R==*2D@>PH@("`@("`@
M("`@("`D7U-%4U-)3TY;)VEN9V\G75LG<V-R:7!T7V-A=&5G;W)I97,G72`]
M(&%R<F%Y7V1I9F8H)%]315-324].6R=I;F=O)UU;)W-C<FEP=%]C871E9V]R
M:65S)UTL(&%R<F%Y*$E.1T]?4U1/4D%'15]!0U1)3TY?5TA)5$5,25-4*2D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D<')E9G,M/FES3&]C:V5D*"=V86-A
M=&EO;B<I("8F(&EN7V%R<F%Y*$E.1T]?4U1/4D%'15]!0U1)3TY?5D%#051)
M3TXL("1?4T534TE/3ELG:6YG;R==6R=S8W)I<'1?8V%T96=O<FEE<R==*2D@
M>PH@("`@("`@("`@("`D7U-%4U-)3TY;)VEN9V\G75LG<V-R:7!T7V-A=&5G
M;W)I97,G72`](&%R<F%Y7V1I9F8H)%]315-324].6R=I;F=O)UU;)W-C<FEP
M=%]C871E9V]R:65S)UTL(&%R<F%Y*$E.1T]?4U1/4D%'15]!0U1)3TY?5D%#
M051)3TXI*3L*("`@("`@("!]"B`@("`@("`@:68@*"1P<F5F<RT^:7-,;V-K
M960H)V9O<G=A<F0G*2`F)B!I;E]A<G)A>2A)3D=/7U-43U)!1T5?04-424].
M7T9/4E=!4D0L("1?4T534TE/3ELG:6YG;R==6R=S8W)I<'1?8V%T96=O<FEE
M<R==*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)VEN9V\G75LG<V-R:7!T
M7V-A=&5G;W)I97,G72`](&%R<F%Y7V1I9F8H)%]315-324].6R=I;F=O)UU;
M)W-C<FEP=%]C871E9V]R:65S)UTL(&%R<F%Y*$E.1T]?4U1/4D%'15]!0U1)
M3TY?1D]25T%21"DI.PH@("`@("`@('T*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L:6(O26YG;RYP
M:'``````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S
M,3(U,``Q,#0Q-S,V,C<U,``P,3<U,C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%-T<FEN9R!T:&%T
M(&-A;B=T(&)E(&$@=F%L:60@9F]L9&5R(&YA;64@=7-E9"!T;R!M87)K(&)L
M86-K;&ES=&5D(&5M86EL(&%S"B`J(&1E;&5T960N"B`J+PID969I;F4H)TE.
M1T]?0DQ!0TM,25-47TU!4DM%4B<L("<K*T1%3$5412LK)RD["@HO*BH*("H@
M26YG;R!B87-E(&-L87-S+@H@*@H@*B`D2&]R9&4Z(&EN9V\O;&EB+TEN9V\N
M<&AP+'8@,2XV.2XV+C$U(#(P,#8O,#(O,C`@,C$Z,#,Z,3D@:F%N($5X<"`D
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E
M;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!);F=O(#$N,`H@
M*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S<R!);F=O('L*"B`@("`O*BH*("`@
M("`J($=E;F5R871E<R!A(&9O;&1E<B!W:61G970N"B`@("`@*B!)9B!A;B!A
M<'!L:6-A=&EO;B!I<R!A=F%I;&%B;&4@=&AA="!P<F]V:61E<R!A(&9O;&1E
M<FQI<W0@;65T:&]D"B`@("`@*B!T:&5N(&$@)FQT.W-E;&5C="9G=#L@:6YP
M=70@:7,@8W)E871E9"!E;'-E(&$@<VEM<&QE('1E>'0@9FEE;&0*("`@("`J
M(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'9A
M;'5E("`@(%1H92!C=7)R96YT('9A;'5E(&9O<B!T:&4@9FEE;&0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F;W)M("`@("!4:&4@9F]R;2!N86UE(&9O<B!T
M:&4@;F5W1F]L9&5R3F%M92@I(&-A;&PN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T86=N86UE("!4:&4@;&%B96P@9F]R('1H92!S96QE8W0@=&%G+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;VYC:&%N9V4@2F%V87-C<FEP="!C;V1E('1O
M(&5X96-U=&4@;VYC:&%N9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!(5$U,('1O(')E;F1E<B!T:&4@9FEE;&0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9L:7-T4V5L96-T*"1V86QU92`](&YU;&PL("1F;W)M(#T@
M;G5L;"P@)'1A9VYA;64@/2`G86-T:6]N=F%L=64G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)&]N8VAA;F=E(#T@;G5L;"D*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8L("1R96=I<W1R>3L*"B`@("`@("`@:68@*"%E;7!T>2@D
M8V]N9ELG<G5L97,G75LG=7-E9F]L9&5R87!I)UTI("8F"B`@("`@("`@("`@
M("1R96=I<W1R>2T^:&%S365T:&]D*"=M86EL+V9O;&1E<FQI<W0G*2D@>PH@
M("`@("`@("`@("`D;6%I;&)O>&5S(#T@)')E9VES=')Y+3YC86QL*"=M86EL
M+V9O;&1E<FQI<W0G*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1M86EL8F]X
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1C<F5A=&5F
M;VQD97(@/2`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G;6%I;"]C<F5A=&5&;VQD
M97(G*3L*"B`@("`@("`@("`@("`@("`D=&5X="`]("<\<V5L96-T(&YA;64]
M(B<@+B`D=&%G;F%M92`N("<B)SL*("`@("`@("`@("`@("`@(&EF("@D8W)E
M871E9F]L9&5R('Q\("1O;F-H86YG92D@>PH@("`@("`@("`@("`@("`@("`@
M("1T97AT("X]("<@;VYC:&%N9V4](B<["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1O;F-H86YG92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&5X
M="`N/2`D;VYC:&%N9V4@+B`G.R<["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&EF("@D8W)E871E9F]L9&5R*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T97AT("X]("=N97=&;VQD97).86UE*%PG
M)R`N("1F;W)M("X@)UPG+"!<)R<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1A9VYA;64@+B`G7"<I.R<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1T97AT("X]("<B)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1T97AT("X]("(^7&XB.PH@("`@
M("`@("`@("`@("`@)'1E>'0@+CT@)SQO<'1I;VX@=F%L=64](B(^)R`N(%\H
M(E-E;&5C="!T87)G970@9F]L9&5R(BD@+B`B/"]O<'1I;VX^7&XB.PH*("`@
M("`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G;6%I;"]C
M<F5A=&5&;VQD97(G*2D@>PH@("`@("`@("`@("`@("`@("`@("1T97AT("X]
M("<\;W!T:6]N('9A;'5E/2(B/B<@+B!?*")#<F5A=&4@;F5W(&9O;&1E<B(I
M("X@(CPO;W!T:6]N/EQN(CL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D;6%I;&)O>&5S(&%S("1M8F]X*2!["B`@
M("`@("`@("`@("`@("`@("`@)'-E;"`]("@D;6)O>%LG=F%L)UT@)B8@*"1M
M8F]X6R=V86PG72`]/3T@)'9A;'5E*2D@/R`G('-E;&5C=&5D/2)S96QE8W1E
M9"(G(#H@)R<["B`@("`@("`@("`@("`@("`@("`@)'9A;"`](&AT;6QS<&5C
M:6%L8VAA<G,H)&UB;WA;)W9A;"==*3L*("`@("`@("`@("`@("`@("`@("`D
M;&%B96P@/2`D;6)O>%LG86)B<F5V)UT["B`@("`@("`@("`@("`@("`@("`@
M)'1E>'0@+CT@<W!R:6YT9B@G/&]P=&EO;B!V86QU93TB)7,B)7,^)7,\+V]P
M=&EO;CXE<R<L("1V86PL("1S96PL(%1E>'0Z.FAT;6Q3<&%C97,H)&QA8F5L
M*2P@(EQN(BD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M)'1E>'0@+CT@)SPO<V5L96-T/B<["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1E>'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`G/&EN<'5T(&YA;64](B<@+B`D=&%G;F%M92`N("<B('-I>F4](C0P(B!V
M86QU93TB)R`N("1V86QU92`N("<B("\^)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@82!N97<@24U!4"!F;VQD97(@=FEA(&%N(&%P:2!C86QL
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&YA
M;64@;V8@=&AE(&9O;&1E<B!T;R!C<F5A=&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&EF(&YO="!C
M<F5A=&5D+"!014%27T5R<F]R(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D
M9F]L9&5R*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@
M("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G;6%I;"]C<F5A=&5&;VQD
M97(G*2D@>PH@("`@("`@("`@("`@<F5T=7)N("1R96=I<W1R>2T^8V%L;"@G
M;6%I;"]C<F5A=&5&;VQD97(G+"!A<G)A>2@G9F]L9&5R)R`]/B!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1F;VQD97(L($Y,4SHZ9V5T0VAA<G-E="@I+"`G
M551&-RU)34%0)RDI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($-O;FYE8W1S('1O('1H92!B86-K
M96YD(&%N9"!U<&QO861S('1H92!S8W)I<'0@86YD('-E=',@:70@86-T:79E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-C<FEP="`@("`@("!4
M:&4@<V-R:7!T('1O('-E="!A8W1I=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D9&5A8W1I=F%T92`@268@=')U92P@;F]T:69I8V%T:6]N('=I;&P@:61E
M;G1I9GD@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<V-R:7!T(&%S(&1E86-T:79A=&5D(&EN<W1E860@;V8@86-T:79A=&5D+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S
M+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8W1I
M=F%T95-C<FEP="@D<V-R:7!T+"`D9&5A8W1I=F%T92`](&9A;'-E*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D;F]T:69I8V%T:6]N.PH*("`@("`@("!R97%U
M:7)E7V]N8V4@24Y'3U]"05-%("X@)R]L:6(O1')I=F5R+G!H<"<["@H@("`@
M("`@("\O(%-E="!A=71H96YT:6-A=&EO;B!P87)A;65T97)S+@H@("`@("`@
M(&EF("@A96UP='DH)%]315-324].6R=I;F=O)UU;)V)A8VME;F0G75LG:&]R
M9&5A=71H)UTI*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("@D7U-%4U-)
M3TY;)VEN9V\G75LG8F%C:V5N9"==6R=H;W)D96%U=&@G72`]/3T@)V9U;&PG
M*0H@("`@("`@("`@("`@("`@("`@("`@("`_($%U=&@Z.F=E=$%U=&@H*2`Z
M($%U=&@Z.F=E=$)A<F5!=71H*"D["B`@("`@("`@("`@("1P87-S=V]R9"`]
M($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RD["B`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1?4T534TE/3ELG:6YG;R==6R=B86-K96YD)UU;)W!A
M<F%M<R==6R=U<V5R;F%M92==*2`F)@H@("`@("`@("`@("`@("`@("!I<W-E
M="@D7U-%4U-)3TY;)VEN9V\G75LG8F%C:V5N9"==6R=P87)A;7,G75LG<&%S
M<W=O<F0G72DI('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)%]315-324].
M6R=I;F=O)UU;)V)A8VME;F0G75LG<&%R86US)UU;)W5S97)N86UE)UT["B`@
M("`@("`@("`@("1P87-S=V]R9"`]("1?4T534TE/3ELG:6YG;R==6R=B86-K
M96YD)UU;)W!A<F%M<R==6R=P87-S=V]R9"==.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]($%U=&@Z.F=E=$)A<F5!=71H*"D[
M"B`@("`@("`@("`@("1P87-S=V]R9"`]($%U=&@Z.F=E=$-R961E;G1I86PH
M)W!A<W-W;W)D)RD["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@)DEN
M9V]?1')I=F5R.CIS:6YG;&5T;VXH)%]315-324].6R=I;F=O)UU;)V)A8VME
M;F0G75LG9')I=F5R)UTL("1?4T534TE/3ELG:6YG;R==6R=B86-K96YD)UU;
M)W!A<F%M<R==*3L*("`@("`@("`D<F5S(#T@)&1R:79E<BT^<V5T4V-R:7!T
M06-T:79E*"1S8W)I<'0L("1U<V5R;F%M92P@)'!A<W-W;W)D*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1M<V<@/2`H)&1E86-T:79A=&4I"B`@("`@("`@("`@("`@/R!?*")4:&5R
M92!W87,@86X@97)R;W(@9&5A8W1I=F%T:6YG('1H92!S8W)I<'0N(BD*("`@
M("`@("`@("`@("`Z(%\H(E1H97)E('=A<R!A;B!E<G)O<B!A8W1I=F%T:6YG
M('1H92!S8W)I<'0N(BD["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H)&US9R`N("<@)R`N(%\H(E1H92!D<FEV97(@<V%I9#H@(BD@+B`D<F5S
M+3YG971-97-S86=E*"DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"1R97,@/3T]('1R=64I
M('L*("`@("`@("`@("`@)&US9R`]("@D9&5A8W1I=F%T92D*("`@("`@("`@
M("`@("`_(%\H(E-C<FEP="!S=6-C97-S9G5L;'D@9&5A8W1I=F%T960N(BD*
M("`@("`@("`@("`@("`Z(%\H(E-C<FEP="!S=6-C97-S9G5L;'D@86-T:79A
M=&5D+B(I.PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1M<V<L
M("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0V]N;F5C=',@=&\@=&AE(&)A8VME;F0@86YD(')E='5R;G,@
M=&AE(&-U<G)E;G1L>2!A8W1I=F4@<V-R:7!T+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@8W5R<F5N=&QY(&%C=&EV92!S8W)I<'0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%-C<FEP="@I"B`@("!["B`@("`@("`@
M<F5Q=6ER95]O;F-E($E.1T]?0D%312`N("<O;&EB+T1R:79E<BYP:'`G.PH*
M("`@("`@("`O+R!3970@875T:&5N=&EC871I;VX@<&%R86UE=&5R<RX*("`@
M("`@("!I9B`H(65M<'1Y*"1?4T534TE/3ELG:6YG;R==6R=B86-K96YD)UU;
M)VAO<F1E875T:"==*2D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`H)%]3
M15-324].6R=I;F=O)UU;)V)A8VME;F0G75LG:&]R9&5A=71H)UT@/3T]("=F
M=6QL)RD*("`@("`@("`@("`@("`@("`@("`@("`@/R!!=71H.CIG971!=71H
M*"D@.B!!=71H.CIG971"87)E075T:"@I.PH@("`@("`@("`@("`D<&%S<W=O
M<F0@/2!!=71H.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I.PH@("`@("`@
M('T@96QS96EF("AI<W-E="@D7U-%4U-)3TY;)VEN9V\G75LG8F%C:V5N9"==
M6R=P87)A;7,G75LG=7-E<FYA;64G72D@)B8*("`@("`@("`@("`@("`@("`@
M:7-S970H)%]315-324].6R=I;F=O)UU;)V)A8VME;F0G75LG<&%R86US)UU;
M)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1?4T53
M4TE/3ELG:6YG;R==6R=B86-K96YD)UU;)W!A<F%M<R==6R=U<V5R;F%M92==
M.PH@("`@("`@("`@("`D<&%S<W=O<F0@/2`D7U-%4U-)3TY;)VEN9V\G75LG
M8F%C:V5N9"==6R=P87)A;7,G75LG<&%S<W=O<F0G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2!!=71H.CIG971"87)E075T
M:"@I.PH@("`@("`@("`@("`D<&%S<W=O<F0@/2!!=71H.CIG971#<F5D96YT
M:6%L*"=P87-S=V]R9"<I.PH@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`]
M("9);F=O7T1R:79E<CHZ<VEN9VQE=&]N*"1?4T534TE/3ELG:6YG;R==6R=B
M86-K96YD)UU;)V1R:79E<B==+"`D7U-%4U-)3TY;)VEN9V\G75LG8F%C:V5N
M9"==6R=P87)A;7,G72D["B`@("`@("`@<F5T=7)N("1D<FEV97(M/F=E=%-C
M<FEP="@D=7-E<FYA;64L("1P87-S=V]R9"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$;V5S(&%L;"!T:&4@=V]R:R!I;B!U<&1A=&EN9R!T:&4@<V-R:7!T
M(&]N('1H92!S97)V97(N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T95-C
M<FEP="@I"B`@("!["B`@("`@("`@9VQO8F%L("1N;W1I9FEC871I;VX["@H@
M("`@("`@(&EF("@D7U-%4U-)3TY;)VEN9V\G75LG<V-R:7!T7V=E;F5R871E
M)UTI('L*("`@("`@("`@("`@)&EN9V]?<V-R:7!T(#T@)DEN9V\Z.FQO861)
M;F=O4V-R:7!T*"D["B`@("`@("`@("`@(&EF("@A)&EN9V]?<V-R:7!T*2![
M"B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E-C<FEP
M="!N;W0@=7!D871E9"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!'96YE<F%T92!A;F0@86-T
M:79A=&4@=&AE('-C<FEP="X@*B\*("`@("`@("`@("`@("`@("1S8W)I<'0@
M/2`D:6YG;U]S8W)I<'0M/F=E;F5R871E*"D["B`@("`@("`@("`@("`@("!)
M;F=O.CIA8W1I=F%T95-C<FEP="@D<V-R:7!T*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!T:&4@
M8F%C:V5N9"!T;R!U<V4N"B`@("`@*@H@("`@("H@5&AI<R!D96-I<VEO;B!I
M<R!B87-E9"!O;B!T:&4@9VQO8F%L("=315)615)?3D%-12<@86YD("=(5%10
M7TA/4U0G"B`@("`@*B!S97)V97(@=F%R:6%B;&5S(&%N9"!T:&4@8V]N=&5N
M=',@;V8@=&AE("=P<F5F97)R960G(&5I=&AE<B!F:65L9`H@("`@("H@:6X@
M=&AE(&)A8VME;F0G<R!D969I;FET:6]N+B`@5&AE("=P<F5F97)R960G(&9I
M96QD(&UA>2!T86ME(&$*("`@("`J('-I;F=L92!V86QU92!O<B!A;B!A<G)A
M>2!O9B!M=6QT:7!L92!V86QU97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE(&)A8VME;F0@96YT<GDN"B`@("`@*B`@("`@("`@("`@("`@
M("!#86QL<R!(;W)D93HZ9F%T86PH*2!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T0F%C:V5N9"@I"B`@("!["B`@("`@("`@:6YC;'5D92!)
M3D=/7T)!4T4@+B`G+V-O;F9I9R]B86-K96YD<RYP:'`G.PH@("`@("`@(&EF
M("@A:7-S970H)&)A8VME;F1S*2!\?"`A:7-?87)R87DH)&)A8VME;F1S*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BA?
M*").;R!B86-K96YD<R!C;VYF:6=U<F5D(&EN(&)A8VME;F1S+G!H<"(I*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1B86-K96YD<R!A<R`D=&5M<"D@>PH@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1B86-K96YD*2D@>PH@("`@("`@("`@("`@("`@)&)A8VME;F0@/2`D
M=&5M<#L*("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=&5M<%LG<')E
M9F5R<F5D)UTI*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1E
M;7!;)W!R969E<G)E9"==*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1T96UP6R=P<F5F97)R960G72!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@H)'9A;"`]/2`D7U-%4E9%4ELG4T525D527TY!
M344G72D@?'P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D=F%L(#T]
M("1?4T525D526R=(5%107TA/4U0G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1B86-K96YD(#T@)'1E;7`["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H*"1T96UP6R=P<F5F97)R960G72`]/2`D7U-%4E9%4ELG
M4T525D527TY!344G72D@?'P*("`@("`@("`@("`@("`@("`@("`@("`@("`H
M)'1E;7!;)W!R969E<G)E9"==(#T]("1?4T525D526R=(5%107TA/4U0G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D8F%C:V5N9"`]("1T96UP.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!#:&5C:R!F;W(@=F%L:60@8F%C:V5N9"!C;VYF:6=U<F%T:6]N+B`J
M+PH@("`@("`@(&EF("@A:7-S970H)&)A8VME;F0I*2!["B`@("`@("`@("`@
M($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*%\H(DYO(&)A8VME;F0@
M8V]N9FEG=7)E9"!F;W(@=&AI<R!H;W-T(BDI+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D8F%C:V5N9%LG<V-R:7!T
M)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B3F\@7"(E<UPB(&5L96UE;G0@9F]U;F0@:6X@8F%C
M:V5N9"!C;VYF:6=U<F%T:6]N+B(I+"`G<V-R:7!T)RDI+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D8F%C:V5N9%LG
M9')I=F5R)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B3F\@7"(E<UPB(&5L96UE;G0@9F]U;F0@
M:6X@8F%C:V5N9"!C;VYF:6=U<F%T:6]N+B(I+"`G9')I=F5R)RDI+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S
M=7)E('1H92`G<&%R86US)R!E;G1R>2!E>&ES=',N("HO"B`@("`@("`@:68@
M*"%I<W-E="@D8F%C:V5N9%LG<&%R86US)UTI*2!["B`@("`@("`@("`@("1B
M86-K96YD6R=P87)A;7,G72`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&)A8VME;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D
M<R!A($EN9V]?4V-R:7!T.CH@8F%C:V5N9"!A;F0@8VAE8VMS(&9O<B!E<G)O
M<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@26YG;U]38W)I<'0Z
M.B!O8FIE8W0@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)FQO861);F=O4V-R:7!T*"D*("`@('L*("`@("`@
M("!G;&]B86P@)&YO=&EF:6-A=&EO;CL*"B`@("`@("`@<F5Q=6ER95]O;F-E
M($E.1T]?0D%312`N("<O;&EB+U-C<FEP="YP:'`G.PH@("`@("`@("1I;F=O
M7W-C<FEP="`]("9);F=O7U-C<FEP=#HZ<VEN9VQE=&]N*"1?4T534TE/3ELG
M:6YG;R==6R=B86-K96YD)UU;)W-C<FEP="==+"!I<W-E="@D7U-%4U-)3TY;
M)VEN9V\G75LG8F%C:V5N9"==6R=S8W)I<'1P87)A;7,G72D@/R`D7U-%4U-)
M3TY;)VEN9V\G75LG8F%C:V5N9"==6R=S8W)I<'1P87)A;7,G72`Z(&%R<F%Y
M*"DI.PH@("`@("`@(&EF("AI<U]A*"1I;F=O7W-C<FEP="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1I;F=O
M7W-C<FEP="T^9V5T365S<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;F=O7W-C<FEP=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE('-P96-I9FEE9"!P97)M:7-S:6]N(&9O<B!T:&4@8W5R<F5N="!U<V5R
M+@H@("`@("H*("`@("`J($!S:6YC92!);F=O(#$N,0H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@($$@<&5R;6ES<VEO;BP@96ET
M:&5R("=A;&QO=U]R=6QE<R<@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=M87A?<G5L97,G+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!V86QU92!O9B!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)'!E<FUI<W-I
M;VXI"B`@("!["B`@("`@("`@9VQO8F%L("1P97)M<SL*"B`@("`@("`@:68@
M*"$D<&5R;7,M/F5X:7-T<R@G:6YG;SHG("X@)'!E<FUI<W-I;VXI*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&%L
M;&]W960@/2`D<&5R;7,M/F=E=%!E<FUI<W-I;VYS*"=I;F=O.B<@+B`D<&5R
M;6ES<VEO;BD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1A;&QO=V5D*2D@>PH@
M("`@("`@("`@("!S=VET8V@@*"1P97)M:7-S:6]N*2!["B`@("`@("`@("`@
M(&-A<V4@)V%L;&]W7W)U;&5S)SH*("`@("`@("`@("`@("`@("1A;&QO=V5D
M(#T@87)R87E?<F5D=6-E*"1A;&QO=V5D+"!C<F5A=&5?9G5N8W1I;VXH)R1A
M+"`D8B<L("=R971U<FX@)&$@?"`D8CLG*2P@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VUA>%]R=6QE<R<Z"B`@
M("`@("`@("`@("`@("`D86QL;W=E9"`](&%R<F%Y7W)E9'5C92@D86QL;W=E
M9"P@8W)E871E7V9U;F-T:6]N*"<D82P@)&(G+"`G<F5T=7)N(&UA>"@D82P@
M)&(I.R<I+"`P*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%L;&]W960["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@86X@861D<F5S<R!I
M<R!E;7!T>2!O<B!O;FQY(&-O;G1A:6YS(&$@(D`B+@H@("`@("H@2&5L<&5R
M(&9U;F-T:6]N(&9O<B!A<G)A>5]F:6QT97(H*2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A9&1R97-S("!!;B!E;6%I;"!A9&1R97-S('1O('1E
M<W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H
M92!A9&1R97-S(&ES(&YO="!E;7!T>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V9I;'1E<D5M<'1Y061D<F5S<R@D861D<F5S<RD*("`@('L*("`@("`@("`D
M861D<F5S<R`]('1R:6TH)&%D9')E<W,I.PH@("`@("`@(')E='5R;B`A96UP
M='DH)&%D9')E<W,I("8F("1A9&1R97-S("$]("=`)SL*("`@('T*"B`@("`O
M*BH*("`@("`J($)U:6QD($EN9V\G<R!L:7-T(&]F(&UE;G4@:71E;7,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE;G4H)')E='5R;E1Y<&4@/2`G;V)J
M96-T)RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N
M<&AP)SL*"B`@("`@("`@)&UE;G4@/2`F;F5W($UE;G4H*3L*("`@("`@("`D
M;65N=2T^861D*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9FEL=&5R<RYP:'`G
M*2P@7R@B1FEL=&5R(%]2=6QE<R(I+"`G:6YG;RYP;F<G+"!N=6QL+"!N=6QL
M+"!N=6QL+"!B87-E;F%M92@D7U-%4E9%4ELG4$A07U-%3$8G72D@/3T@)VEN
M9&5X+G!H<"<@/R`G8W5R<F5N="<@.B!N=6QL*3L*("`@("`@("!I9B`H(6ES
M7V$H)'=H:71E;&ES=%]U<FP@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^;&EN
M:R@G;6%I;"]S:&]W5VAI=&5L:7-T)RDL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@)&UE;G4M/F%D9"A(;W)D93HZ=7)L*"1W:&ET96QI<W1?=7)L
M*2P@7R@B7U=H:71E;&ES="(I+"`G=VAI=&5L:7-T+G!N9R<I.PH@("`@("`@
M('T*("`@("`@("!I9B`H(6ES7V$H)&)L86-K;&ES=%]U<FP@/2`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^;&EN:R@G;6%I;"]S:&]W0FQA8VML:7-T)RDL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&UE;G4M/F%D9"A(;W)D93HZ
M=7)L*"1B;&%C:VQI<W1?=7)L*2P@7R@B7T)L86-K;&ES="(I+"`G8FQA8VML
M:7-T+G!N9R<I.PH@("`@("`@('T*("`@("`@("!I9B`H:6Y?87)R87DH24Y'
M3U]35$]204=%7T%#5$E/3E]604-!5$E/3BP@)%]315-324].6R=I;F=O)UU;
M)W-C<FEP=%]C871E9V]R:65S)UTI*2!["B`@("`@("`@("`@("1M96YU+3YA
M9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=V86-A=&EO;BYP:'`G*2P@7R@B
M7U9A8V%T:6]N(BDL("=V86-A=&EO;BYP;F<G*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&EN7V%R<F%Y*$E.1T]?4U1/4D%'15]!0U1)3TY?1D]25T%21"P@
M)%]315-324].6R=I;F=O)UU;)W-C<FEP=%]C871E9V]R:65S)UTI*2!["B`@
M("`@("`@("`@("1M96YU+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=F
M;W)W87)D+G!H<"<I+"!?*")?1F]R=V%R9"(I+"`G9F]R=V%R9"YP;F<G*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1?4T534TE/3ELG:6YG;R==6R=S8W)I
M<'1?9V5N97)A=&4G72D@>PH@("`@("`@("`@("`D;65N=2T^861D*$AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G<V-R:7!T+G!H<"<I+"!?*")?4V-R:7!T(BDL
M("=S8W)I<'0N<&YG)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)')E='5R
M;E1Y<&4@/3T@)V]B:F5C="<I('L*("`@("`@("`@("`@<F5T=7)N("1M96YU
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D;65N=2T^
M<F5N9&5R*"D["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]L
M:6(O4V-R:7!T+G!H<```````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R,3$S,P`Q,#0Q-S,V,C<U,``P,C`P-S4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B\J*@H@*B!/
M;FQY(&9I;'1E<B!U;G-E96X@;65S<V%G97,N"B`J+PID969I;F4H)TE.1T]?
M4T-225!47T9)3%1%4E]53E-%14XG+"`Q*3L*"B\J*@H@*B!/;FQY(&9I;'1E
M<B!S965N(&UE<W-A9V5S+@H@*B\*9&5F:6YE*"=)3D=/7U-#4DE05%]&24Q4
M15)?4T5%3B<L(#(I.PH*+RHJ"B`J(%1H92!);F=O7U-C<FEP=#HZ(&-L87-S
M('!R;W9I9&5S(&$@8V]M;6]N(&%B<W1R86-T960@:6YT97)F86-E('1O('1H
M90H@*B!S8W)I<'0M9V5N97)A=&EO;B!S=6)C;&%S<V5S+@H@*@H@*B`D2&]R
M9&4Z(&EN9V\O;&EB+U-C<FEP="YP:'`L=B`Q+C,P+C$P+C@@,C`P-B\P,2\S
M,2`R,#HP,#HR-"!J86X@17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN("!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H
M;W(@($)R96YT($HN($YO<F1Q=6ES="`\8FIN0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@26YG;R`P+C$*("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@26YG
M;U]38W)I<'0@>PH*("`@("\J*@H@("`@("H@5&AE('-C<FEP="!C;&%S<R<@
M861D:71I;VYA;"!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J(%1H92!L:7-T(&]F(&%C=&EO;G,@86QL;W=E9"`H:6UP;&5M
M96YT960I(&9O<B!T:&ES(&1R:79E<BX*("`@("`J(%1H:7,@4TA/54Q$(&)E
M(&1E9FEN960@:6X@96%C:"!S=6)C;&%S<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%C=&EO;G,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@5&AE(&-A=&5G;W)I97,@;V8@9FEL=&5R:6YG(&%L
M;&]W960N"B`@("`@*B!4:&ES(%-(3U5,1"!B92!D969I;F5D(&EN(&5A8V@@
M<W5B8VQA<W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]C871E9V]R:65S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%1H92!L:7-T(&]F('1E<W1S(&%L;&]W960@*&EM<&QE;65N=&5D*2!F;W(@
M=&AI<R!D<FEV97(N"B`@("`@*B!4:&ES(%-(3U5,1"!B92!D969I;F5D(&EN
M(&5A8V@@<W5B8VQA<W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]T97-T<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!4:&4@='EP97,@;V8@=&5S=',@86QL;W=E9"`H:6UP;&5M96YT960I(&9O
M<B!T:&ES(&1R:79E<BX*("`@("`J(%1H:7,@4TA/54Q$(&)E(&1E9FEN960@
M:6X@96%C:"!S=6)C;&%S<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W1Y<&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($$@;&ES="!O9B!A;GD@<W!E8VEA;"!T>7!E<R!T:&%T('1H:7,@9')I
M=F5R('-U<'!O<G1S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<W!E8VEA;%]T>7!E<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!#86X@=&5S=',@8F4@8V%S92!S96YS:71I=F4_"B`@("`@*@H@
M("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-A<V5S96YS
M:71I=F4@/2!F86QS93L*"B`@("`O*BH*("`@("`J($1O97,@=&AE(&1R:79E
M<B!S=7!P;W)T('-E='1I;F<@24U!4"!F;&%G<S\*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<W5P<&]R=$E-05!&;&%G
M<R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@1&]E<R!T:&4@9')I=F5R('-U
M<'!O<G0@=&AE('-T;W`M<V-R:7!T(&]P=&EO;C\*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<W5P<&]R=%-T;W!38W)I
M<'0@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-A;B!T:&ES(&1R:79E<B!P
M97)F;W)M(&]N(&1E;6%N9"!F:6QT97)I;F<_"B`@("`@*@H@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V]N9&5M86YD(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!$;V5S('1H92!D<FEV97(@<F5Q=6ER92!A('-C
M<FEP="!F:6QE('1O(&)E(&=E;F5R871E9#\*("`@("`J"B`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<V-R:7!T9FEL92`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E
M=&4@26YG;U]38W)I<'0@:6YS=&%N8V4@8F%S960@;VX@)'-C<FEP="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8W)I<'0@(%1H92!T>7!E(&]F
M($EN9V]?4V-R:7!T('-U8F-L87-S('1O(')E='5R;BX*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@2&%S:"!C;VYT86EN:6YG(&%D9&ET:6]N86P@
M<&%R86UT97)S('1O(&)E('!A<W-E9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!T;R!T:&4@<W5B8VQA<W,G(&-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!R971U<FX@26YG;U]38W)I<'0@(%1H92!N97=L>2!C<F5A=&5D
M(&-O;F-R971E($EN9V]?4V-R:7!T(&EN<W1A;F-E+"!O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9F86-T;W)Y*"1S8W)I<'0L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1S8W)I<'0@/2!B87-E;F%M92@D<V-R:7!T*3L*
M("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U-C
M<FEP="\G("X@)'-C<FEP="`N("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G
M26YG;U]38W)I<'1?)R`N("1S8W)I<'0["B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1I;F=O(#T@)FYE=R`D8VQA
M<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&EN
M9V\@/2!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(BDL("1C;&%S<RDI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;F=O.PH@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E
M=&4@26YG;U]38W)I<'0@:6YS=&%N8V4*("`@("`J(&)A<V5D(&]N("1S8W)I
M<'0N"B`@("`@*@H@("`@("H@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I
M;G-T86YC92!I9B!N;R!);F=O7U-C<FEP="!I;G-T86YC92!W:71H('1H90H@
M("`@("H@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R
M(#T@)DEN9V]?4V-R:7!T.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'-C<FEP="`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@26YG
M;U]38W)I<'0@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!
M(&AA<V@@8V]N=&%I;FEN9R!A9&1I=&EO;F%L('!A<F%M971E<G,@9F]R('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N($EN9V]?4V-R:7!T("!4:&4@8V]N8W)E=&4@
M26YG;U]38W)I<'0@<F5F97)E;F-E+"!O<B!F86QS92!O;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9S:6YG;&5T;VXH)'-C<FEP="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@(&EF("@A:7-S
M970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R
M<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L
M:7IE*&%R<F%Y*"1S8W)I<'0L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES
M<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I
M;G-T86YC97-;)'-I9VYA='5R95T@/2`F26YG;U]38W)I<'0Z.F9A8W1O<GDH
M)'-C<FEP="P@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T97)S(&YE961E9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@26YG;U]38W)I<'0H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH*("`@("`@("`O*B!$971E<FUI
M;F4@:68@:6YG;R!S:&]U;&0@:&%N9&QE('1H92!B;&%C:VQI<W0N("HO"B`@
M("`@("`@)&ME>2`](&%R<F%Y7W-E87)C:"A)3D=/7U-43U)!1T5?04-424].
M7T),04-+3$E35"P@)'1H:7,M/E]C871E9V]R:65S*3L*("`@("`@("!I9B`H
M)&ME>2`A/3T@9F%L<V4@)B8@*"1R96=I<W1R>2T^:&%S365T:&]D*"=M86EL
M+V)L86-K;&ES=$9R;VTG*2`A/2`G:6YG;R<I*2!["B`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?8V%T96=O<FEE<ULD:V5Y72D["B`@("`@("`@?0H*("`@
M("`@("`O*B!$971E<FUI;F4@:68@:6YG;R!S:&]U;&0@:&%N9&QE('1H92!W
M:&ET96QI<W0N("HO"B`@("`@("`@)&ME>2`](&%R<F%Y7W-E87)C:"A)3D=/
M7U-43U)!1T5?04-424].7U=(251%3$E35"P@)'1H:7,M/E]C871E9V]R:65S
M*3L*("`@("`@("!I9B`H)&ME>2`A/3T@9F%L<V4@)B8@*"1R96=I<W1R>2T^
M:&%S365T:&]D*"=M86EL+W=H:71E;&ES=$9R;VTG*2`A/2`G:6YG;R<I*2![
M"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8V%T96=O<FEE<ULD:V5Y72D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M879A:6QA8FQE(&%C=&EO;G,@9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F(&%V86EL86)L92!A8W1I
M;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=F%I;&%B;&5!8W1I;VYS*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]A8W1I;VYS.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@879A:6QA8FQE(&-A=&5G;W)I
M97,@9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!L:7-T(&]F(&-A=&5G;W)I97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%V86EL86)L94-A=&5G;W)I97,H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V-A=&5G;W)I97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!A=F%I;&%B;&4@=&5S=',@9F]R('1H:7,@9')I=F5R+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F('1E<W1S
M(&%C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%V86EL86)L951E<W1S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T97-T<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%V86EL86)L92!T97-T('1Y
M<&5S(&9O<B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@;&ES="!O9B!T97-T('1Y<&5S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A=F%I;&%B;&54>7!E<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?='EP97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N
M>2!T97-T('1Y<&5S('1H870@87)E('-P96-I86P@9F]R('1H:7,@9')I=F5R
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F('-P
M96-I86P@='EP97,*("`@("`J+PH@("`@9G5N8W1I;VX@<W!E8VEA;%1Y<&5S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S<&5C:6%L7W1Y<&5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I9B!T:&ES(&1R:79E
M<B!A;&QO=W,@8V%S92!S96YS:71I=F4@<V5A<F-H97,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!$;V5S('1H:7,@9')I=F5R(&%L;&]W(&-A
M<V4@<V5N<VET:79E('-E87)C:&5S/PH@("`@("HO"B`@("!F=6YC=&EO;B!C
M87-E4V5N<VET:79E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C
M87-E<V5N<VET:79E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I
M9B!T:&ES(&1R:79E<B!A;&QO=W,@24U!4"!F;&%G<R!T;R!B92!S970N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!$;V5S('1H:7,@9')I=F5R
M(&%L;&]W($E-05`@9FQA9W,@=&\@8F4@<V5T/PH@("`@("HO"B`@("!F=6YC
M=&EO;B!I;6%P1FQA9W,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W-U<'!O<G1)34%01FQA9W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&EF('1H:7,@9')I=F5R('-U<'!O<G1S('1H92!S=&]P+7-C<FEP="!O
M<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!$;V5S('1H
M:7,@9')I=F5R('-U<'!O<G0@=&AE('-T;W`M<V-R:7!T(&]P=&EO;C\*("`@
M("`J+PH@("`@9G5N8W1I;VX@<W1O<%-C<FEP="@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<W5P<&]R=%-T;W!38W)I<'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<V-R:7!T('!R979I;W5S;'D@9V5N97)A
M=&5D('=I=&@@9V5N97)A=&4H*2X*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-C<FEP="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=&]#;V1E*"D*("`@('L*("`@("`@("!R971U
M<FX@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86X@=&AI<R!D<FEV97(@
M9V5N97)A=&4@82!S8W)I<'0@9FEL93\*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@9V5N97)A=&4H*2!I<R!A=F%I;&%B;&4L(&9A
M;'-E(&EF(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5!=F%I
M;&%B;&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-C<FEP=&9I
M;&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE('-C<FEP
M="!T;R!D;R!T:&4@9FEL=&5R:6YG('-P96-I9FEE9"!I;@H@("`@("H@=&AE
M(')U;&5S+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<V-R:7!T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G96YE<F%T92@I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0V%N('1H:7,@9')I=F5R('!E<F9O<FT@;VX@
M9&5M86YD(&9I;'1E<FEN9S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@<&5R9F]R;2@I(&ES(&%V86EL86)L92P@9F%L<V4@:68@
M;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!P97)F;W)M079A:6QA8FQE*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]O;F1E;6%N9#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%!E<F9O<FT@=&AE(&9I;'1E<FEN9R!S<&5C:69I
M960@:6X@=&AE(')U;&5S+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R
M(&%R<F%Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!F:6QT97)I;F<@<&5R9F]R;65D+"!F86QS92!I9B!N;W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!E<F9O<FTH)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M27,@=&AE(&%P<&QY*"D@9G5N8W1I;VX@879A:6QA8FQE/PH@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!A<'!L>2@I(&ES(&%V86EL
M86)L92P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!C86Y!
M<'!L>2@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YP97)F;W)M079A
M:6QA8FQE*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<'!L>2!T:&4@9FEL
M=&5R<R!N;W<N"B`@("`@*B!4:&ES(&ES(&5S<V5N=&EA;&QY(&$@=W)A<'!E
M<B!A<F]U;F0@<&5R9F]R;2@I('1H870@86QL;W=S('1H870*("`@("`J(&9U
M;F-T:6]N('1O(&)E(&-A;&QE9"!F<F]M('=I=&AI;B!);F=O(&5N<W5R:6YG
M('1H870@86QL(&YE8V5S<V%R>0H@("`@("H@<&%R86UE=&5R<R!A<F4@<V5T
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@4V5E('!E<F9O<FTH*2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@87!P;'DH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<&5R9F]R
M;2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AI<R!A('9A;&ED(')U
M;&4_"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'1Y<&4@(%1H92!R=6QE('1Y<&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R('1H92!R=6QE(&ES
M('9A;&ED(&]R(&YO="!F;W(@=&AI<R!D<FEV97(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]V86QI9%)U;&4H)'1Y<&4I"B`@("!["B`@("`@("`@<F5T=7)N
M("@A96UP='DH)'1Y<&4I("8F(&EN7V%R<F%Y*"1T>7!E+"!A<G)A>5]M97)G
M92@D=&AI<RT^7V-A=&5G;W)I97,L("1T:&ES+3Y?86-T:6]N<RDI*3L*("`@
M('T*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;F=O+VQI8B]$<FEV97(N<&AP````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`U-S`T`#$P-#$W,S8R-S4P`#`R,#`W,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@26YG;U]$<FEV97(Z.B!D969I;F5S(&%N($%022!T;R!A8W1I=F%T
M92!F:6QT97(@<V-R:7!T<R!O;B!A('-E<G9E<BX*("H*("H@)$AO<F1E.B!I
M;F=O+VQI8B]$<FEV97(N<&AP+'8@,2XQ,"XQ,"XW(#(P,#8O,#$O,S$@,C`Z
M,#`Z,C0@:F%N($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,
M24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!);F=O(#$N,`H@*B!`<&%C:V%G92!);F=O"B`J+PIC;&%S<R!);F=O
M7T1R:79E<B!["@H@("`@+RHJ"B`@("`@*B!$<FEV97(@<W!E8VEF:6,@<&%R
M86UE=&5R<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?<&%R86US.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@8V]N8W)E=&4@26YG;U]$<FEV97(@:6YS=&%N8V4@8F%S960@;VX@
M)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@
M(%1H92!T>7!E(&]F(&-O;F-R971E($EN9V]?1')I=F5R('-U8F-L87-S('1O
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S
M<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!N97=L>2!C<F5A=&5D(&-O;F-R971E($EN9V]?1')I=F5R(&EN<W1A;F-E
M+"!O<@H@("`@("H@("`@("`@("`@("`@("`@9F%L<V4@;VX@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D
M9')I=F5R*3L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+T1R:79E<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D
M8VQA<W,@/2`G26YG;U]$<FEV97)?)R`N("1D<FEV97(["B`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1I;F=O(#T@
M)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&EN9V\@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:6YG;SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E
M='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($EN9V]?1')I=F5R(&EN
M<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J
M($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@26YG
M;U]$<FEV97(@:6YS=&%N8V4@=VET:"!T:&4*("`@("`J('-A;64@<&%R86UE
M=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO
M=6QD(&)E('5S960@:68@;75L=&EP;&4@<W1O<F%G92!S;W5R8V5S(&%R92!R
M97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN
M=F]K960@87,Z("1V87(@/2`F26YG;U]$<FEV97(Z.G-I;F=L971O;B@I.PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@
M;V8@8V]N8W)E=&4@26YG;U]$<FEV97(@<W5B8VQA<W,@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA
M;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-R96%T960@
M8V]N8W)E=&4@26YG;U]$<FEV97(@:6YS=&%N8V4L(&]R(&9A;'-E"B`@("`@
M*B`@("`@("`@("`@("`@("!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*"B`@("`@("`@:68@*"%I
M<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@
M87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I
M86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A
M:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9);F=O7T1R:79E<CHZ9F%C=&]R
M>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($EN9V]?1')I
M=F5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M82!S8W)I<'0@<G5N;FEN9R!O;B!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S8W)I<'0@(%1H92!F:6QT97(@<V-R:7!T+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@:68@<V-R:7!T(&-A;B=T(&)E(&%C=&EV871E9"X*("`@("`J("`@
M("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T4V-R:7!T06-T:79E*"1S8W)I<'0I"B`@
M("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&EB+V%P:2YP
M:'``````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#<R-34`,3`T,3<S-C(W-3``,#$W-#$S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!);F=O(&5X=&5R
M;F%L($%022!I;G1E<F9A8V4N"B`J"B`J(%1H:7,@9FEL92!D969I;F5S($EN
M9V\G<R!E>'1E<FYA;"!!4$D@:6YT97)F86-E+B!/=&AE<B!A<'!L:6-A=&EO
M;G,*("H@8V%N(&EN=&5R86-T('=I=&@@26YG;R!T:')O=6=H('1H:7,@05!)
M+@H@*@H@*B`D2&]R9&4Z(&EN9V\O;&EB+V%P:2YP:'`L=B`Q+C$V+C$R+C0@
M,C`P-B\P,2\S,2`R,#HP,#HR-"!J86X@17AP("0*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$%33"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J
M+PH*)%]S97)V:6-E<ULG<&5R;7,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^
M(&%R<F%Y*"DL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R
M87DG*3L*"B1?<V5R=FEC97-;)V)L86-K;&ES=$9R;VTG72`](&%R<F%Y*`H@
M("`@)V%R9W,G(#T^(&%R<F%Y*"=A9&1R97-S97,G(#T^("=[=7)N.FAO<F1E
M?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD
M7W-E<G9I8V5S6R=S:&]W0FQA8VML:7-T)UT@/2!A<G)A>2@*("`@("=L:6YK
M)R`]/B`G)6%P<&QI8V%T:6]N)2]B;&%C:VQI<W0N<&AP)PHI.PH*)%]S97)V
M:6-E<ULG=VAI=&5L:7-T1G)O;2==(#T@87)R87DH"B`@("`G87)G<R<@/3X@
M87)R87DH)V%D9')E<W-E<R<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG
M*2P*("`@("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)W-H
M;W=7:&ET96QI<W0G72`](&%R<F%Y*`H@("`@)VQI;FLG(#T^("<E87!P;&EC
M871I;VXE+W=H:71E;&ES="YP:'`G"BD["@HD7W-E<G9I8V5S6R=C86Y!<'!L
M>49I;'1E<G,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@
M("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S6R=A<'!L>49I
M;'1E<G,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=P87)A;7,G
M(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP92<@/3X@
M)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S6R=S:&]W1FEL=&5R<R==(#T@87)R
M87DH"B`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O9FEL=&5R<RYP:'`G
M"BD["@IF=6YC=&EO;B!?:6YG;U]P97)M<R@I"GL*("`@("1P97)M<R`](&%R
M<F%Y*"D["B`@("`D<&5R;7-;)W1R964G75LG:6YG;R==6R=A;&QO=U]R=6QE
M<R==(#T@9F%L<V4["B`@("`D<&5R;7-;)W1I=&QE)UU;)VEN9V\Z86QL;W=?
M<G5L97,G72`](%\H(D%L;&]W(%)U;&5S(BD["B`@("`D<&5R;7-;)W1Y<&4G
M75LG:6YG;SIA;&QO=U]R=6QE<R==(#T@)V)O;VQE86XG.PH@("`@)'!E<FUS
M6R=T<F5E)UU;)VEN9V\G75LG;6%X7W)U;&5S)UT@/2!F86QS93L*("`@("1P
M97)M<ULG=&ET;&4G75LG:6YG;SIM87A?<G5L97,G72`](%\H(DUA>&EM=6T@
M3G5M8F5R(&]F(%)U;&5S(BD["B`@("`D<&5R;7-;)W1Y<&4G75LG:6YG;SIM
M87A?<G5L97,G72`]("=I;G0G.PH*("`@(')E='5R;B`D<&5R;7,["GT*"F9U
M;F-T:6]N(%]I;F=O7V)L86-K;&ES=$9R;VTH)&%D9')E<W-E<RD*>PH@("`@
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]L:6(O8F%S
M92YP:'`G.PH@("`@9VQO8F%L("1I;F=O7W-T;W)A9V4["@H@("`@+RH@0VAE
M8VL@9F]R("=`)R!E;G1R:65S(&EN("1A9&1R97-S97,@+2!T:&ES('=O=6QD
M(&-A;&P@86QL(&UA:6P@=&\*("`@("`J(&)E(&)L86-K;&ES=&5D('=H:6-H
M(&ES(&UO<W0@;&EK96QY(&YO="!W:&%T(&ES(&1E<VER960N("HO"B`@("`D
M861D<F5S<V5S(#T@87)R87E?=6YI<75E*"1A9&1R97-S97,I.PH@("`@)&ME
M>2`](&%R<F%Y7W-E87)C:"@G0"<L("1A9&1R97-S97,I.PH@("`@:68@*"1K
M97D@(3T](&9A;'-E*2!["B`@("`@("`@=6YS970H)&%D9')E<W-E<ULD:V5Y
M72D["B`@("!]"@H@("`@:68@*"%E;7!T>2@D861D<F5S<V5S*2D@>PH@("`@
M("`@("1B;&%C:VQI<W0@/2`F)&EN9V]?<W1O<F%G92T^<F5T<FEE=F4H24Y'
M3U]35$]204=%7T%#5$E/3E]"3$%#2TQ)4U0I.PH@("`@("`@("1R970@/2`D
M8FQA8VML:7-T+3YS971";&%C:VQI<W0H87)R87E?;65R9V4H)&)L86-K;&ES
M="T^9V5T0FQA8VML:7-T*"DL("1A9&1R97-S97,I*3L*("`@("`@("!I9B`H
M:7-?82@D<F5T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1'3$]"
M04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"@D<F5T+"`D<F5T+3YG971#;V1E
M*"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I;F=O7W-T;W)A
M9V4M/G-T;W)E*"1B;&%C:VQI<W0I.PH@("`@("`@("`@("!);F=O.CIU<&1A
M=&538W)I<'0H*3L*("`@("`@("`@("`@9F]R96%C:"`H)&%D9')E<W-E<R!A
M<R`D9G)O;2D@>PH@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A
M=&EO;B==+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&%D9')E<W,@7"(E<UPB(&AA
M<R!B965N(&%D9&5D('1O('EO=7(@8FQA8VML:7-T+B(I+"`D9G)O;2DI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO;B!?:6YG
M;U]W:&ET96QI<W1&<F]M*"1A9&1R97-S97,I"GL*("`@(')E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO;&EB+V)A<V4N<&AP)SL*("`@
M(&=L;V)A;"`D:6YG;U]S=&]R86=E.PH*("`@("1W:&ET96QI<W0@/2`F)&EN
M9V]?<W1O<F%G92T^<F5T<FEE=F4H24Y'3U]35$]204=%7T%#5$E/3E]72$E4
M14Q)4U0I.PH@("`@)')E="`]("1W:&ET96QI<W0M/G-E=%=H:71E;&ES="AA
M<G)A>5]M97)G92@D=VAI=&5L:7-T+3YG9717:&ET96QI<W0H*2P@)&%D9')E
M<W-E<RDI.PH@("`@:68@*&ES7V$H)')E="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"@D<F5T+"`D
M<F5T+3YG971#;V1E*"DI.PH@("`@?2!E;'-E('L*("`@("`@("`D:6YG;U]S
M=&]R86=E+3YS=&]R92@D=VAI=&5L:7-T*3L*("`@("`@("!);F=O.CIU<&1A
M=&538W)I<'0H*3L*("`@("`@("!F;W)E86-H("@D861D<F5S<V5S(&%S("1F
M<F]M*2!["B`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^
M<'5S:"AS<')I;G1F*%\H(E1H92!A9&1R97-S(%PB)7-<(B!H87,@8F5E;B!A
M9&1E9"!T;R!Y;W5R('=H:71E;&ES="XB*2P@)&9R;VTI*3L*("`@("`@("!]
M"B`@("!]"GT*"F9U;F-T:6]N(%]I;F=O7V-A;D%P<&QY1FEL=&5R<R@I"GL*
M("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO;&EB
M+V)A<V4N<&AP)SL*"B`@("`D:6YG;U]S8W)I<'0@/2`F26YG;SHZ;&]A9$EN
M9V]38W)I<'0H*3L*("`@(&EF("@D:6YG;U]S8W)I<'0I('L*("`@("`@("!R
M971U<FX@)&EN9V]?<V-R:7!T+3YP97)F;W)M079A:6QA8FQE*"D["B`@("!]
M(&5L<V4@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*?0H*9G5N8W1I
M;VX@7VEN9V]?87!P;'E&:6QT97)S*"1P87)A;7,@/2!A<G)A>2@I*0I["B`@
M("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+VQI8B]B
M87-E+G!H<"<["@H@("`@)&EN9V]?<V-R:7!T(#T@)DEN9V\Z.FQO861);F=O
M4V-R:7!T*"D["B`@("!I9B`H)&EN9V]?<V-R:7!T*2!["B`@("`@("`@<F5T
M=7)N("1I;F=O7W-C<FEP="T^<&5R9F]R;2@D<&%R86US*3L*("`@('T*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEN9V\O;&EB+V)A<V4N<&AP````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#0Q-C$`,3`T,3<S-C(W-3``,#$W-30U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!);F=O(&)A<V4@:6YC;'5S:6]N(&9I;&4N"B`J(%1H:7,@9FEL
M92!B<FEN9W,@:6X@86QL(&]F('1H92!D97!E;F1E;F-I97,@=&AA="!E=F5R
M>2!);F=O"B`J('-C<FEP="!W:6QL(&YE960@86YD('-E=',@=7`@;V)J96-T
M<R!T:&%T(&%L;"!S8W)I<'1S('5S92X*("H*("H@5&AE(&9O;&QO=VEN9R!G
M;&]B86P@=F%R:6%B;&5S(&%R92!D96-L87)E9"!B>2!T:&ES('-C<FEP=#H*
M("H@("`D:6YG;U]S=&]R86=E("T@5&AE($EN9V]?4W1O<F%G93HZ(&]B:F5C
M="!T;R!U<V4@9F]R('-T;W)I;F<@<G5L97,N"B`J"B`J("1(;W)D93H@:6YG
M;R]L:6(O8F%S92YP:'`L=B`Q+C4V+C$P+C(@,C`P-B\P,2\S,2`R,#HP,#HR
M-"!J86X@17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.
M4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN("!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R
M9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J+PH*+R\@0VAE8VL@9F]R(&$@
M<')I;W(@9&5F:6YI=&EO;B!O9B!(3U)$15]"05-%("AP97)H87!S(&)Y(&%N
M"B\O(&%U=&]?<')E<&5N9%]F:6QE(&1E9FEN:71I;VX@9F]R('-I=&4@8W5S
M=&]M:7IA=&EO;BDN"FEF("@A9&5F:6YE9"@G2$]21$5?0D%312<I*2!["B`@
M("!`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN+RXN)RD["GT*"B\O($QO860@=&AE($AO<F1E($9R86UE=V]R:R!C;W)E
M+"!A;F0@<V5T('5P(&EN8VQU<VEO;B!P871H<RX*<F5Q=6ER95]O;F-E($A/
M4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["@HO+R!296=I<W1R>2X*)')E
M9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH*3L*:68@*&ES7V$H*"1P
M=7-H960@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)VEN9V\G+"`A9&5F:6YE9"@G
M05542%](04Y$3$52)RDI*2P@)U!%05)?17)R;W(G*2D@>PH@("`@:68@*"1P
M=7-H960M/F=E=$-O9&4H*2`]/2`G<&5R;6ES<VEO;E]D96YI960G*2!["B`@
M("`@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D[
M"B`@("!]"B`@("!(;W)D93HZ9F%T86PH)'!U<VAE9"P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!F86QS92D["GT*)&-O;F8@/2`F)$=,3T)!3%-;)V-O;F8G73L*
M0&1E9FEN92@G24Y'3U]414U03$%415,G+"`D<F5G:7-T<GDM/F=E="@G=&5M
M<&QA=&5S)RDI.PH*+R\@3F]T:69I8V%T:6]N('-Y<W1E;2X*)&YO=&EF:6-A
M=&EO;B`]("9.;W1I9FEC871I;VXZ.G-I;F=L971O;B@I.PHD;F]T:69I8V%T
M:6]N+3YA='1A8V@H)W-T871U<R<I.PH*+R\@4F5D:7)E8W0@=&AE('5S97(@
M=&\@=&AE($AO<F1E(&QO9VEN('!A9V4@:68@=&AE>2!H879E;B=T"B\O(&%U
M=&AE;G1I8V%T960N"FEF("@A075T:#HZ:7-!=71H96YT:6-A=&5D*"D@)B8@
M(61E9FEN960H)T%55$A?2$%.1$Q%4B<I*2!["B`@("!(;W)D93HZ875T:&5N
M=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*+R\@1FEN9"!T:&4@8F%S
M92!F:6QE('!A=&@@;V8@26YG;RX*0&1E9FEN92@G24Y'3U]"05-%)RP@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["@HO+R!);F=O(&)A<V4@;&EB<F%R
M>2X*<F5Q=6ER95]O;F-E($E.1T]?0D%312`N("<O;&EB+TEN9V\N<&AP)SL*
M"B\O($]T:&5R($AO<F1E(&QI8G)A<FEE<R!N965D960N"G)E<75I<F5?;VYC
M92`G2&]R9&4O2&5L<"YP:'`G.PH*+R\@4W1A<G0@8V]M<')E<W-I;VXN"DAO
M<F1E.CIC;VUP<F5S<T]U='!U="@I.PH*+R\@3&]A9"!T:&4@26YG;U]3=&]R
M86=E(&1R:79E<BX@270@87!P96%R<R!I;B!T:&4@9VQO8F%L('9A<FEA8FQE
M"B\O("1I;F=O7W-T;W)A9V4N"G)E<75I<F5?;VYC92!)3D=/7T)!4T4@+B`G
M+VQI8B]3=&]R86=E+G!H<"<["B1'3$]"04Q36R=I;F=O7W-T;W)A9V4G72`]
M("9);F=O7U-T;W)A9V4Z.G-I;F=L971O;B@I.PH*+R\@0W)E871E('1H92!I
M;F=O('-E<W-I;VX@*&EF(&YE961E9"DN"FEF("@A:7-S970H)%]315-324].
M6R=I;F=O)UTI('Q\("%I<U]A<G)A>2@D7U-%4U-)3TY;)VEN9V\G72DI('L*
M("`@(')E<75I<F5?;VYC92!)3D=/7T)!4T4@+B`G+VQI8B]397-S:6]N+G!H
M<"<["B`@("!);F=O7U-E<W-I;VXZ.F-R96%T95-E<W-I;VXH*3L*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEN9V\O;&EB+U-T;W)A9V4N<&AP````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C,P-S``,3`T,3<S-C(W
M-3``,#(P,C0S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@HO*BH*("H@26YG;U]3=&]R86=E.CH@)V-O;6)I;F4G
M(&-O;G-T86YT<PH@*B\*9&5F:6YE*"=)3D=/7U-43U)!1T5?0T]-0DE.15]!
M3$PG+"`Q*3L*9&5F:6YE*"=)3D=/7U-43U)!1T5?0T]-0DE.15]!3EDG+"`R
M*3L*"B\J*@H@*B!);F=O7U-T;W)A9V4Z.B`G86-T:6]N)R!C;VYS=&%N=',*
M("HO"F1E9FEN92@G24Y'3U]35$]204=%7T%#5$E/3E]&24Q415)3)RP@,"D[
M"F1E9FEN92@G24Y'3U]35$]204=%7T%#5$E/3E]+1450)RP@,2D["F1E9FEN
M92@G24Y'3U]35$]204=%7T%#5$E/3E]-3U9%)RP@,BD["F1E9FEN92@G24Y'
M3U]35$]204=%7T%#5$E/3E]$25-#05)$)RP@,RD["F1E9FEN92@G24Y'3U]3
M5$]204=%7T%#5$E/3E]2141)4D5#5"<L(#0I.PID969I;F4H)TE.1T]?4U1/
M4D%'15]!0U1)3TY?4D5$25)%0U1+1450)RP@-2D["F1E9FEN92@G24Y'3U]3
M5$]204=%7T%#5$E/3E]214I%0U0G+"`V*3L*9&5F:6YE*"=)3D=/7U-43U)!
M1T5?04-424].7T),04-+3$E35"<L(#<I.PID969I;F4H)TE.1T]?4U1/4D%'
M15]!0U1)3TY?5D%#051)3TXG+"`X*3L*9&5F:6YE*"=)3D=/7U-43U)!1T5?
M04-424].7U=(251%3$E35"<L(#DI.PID969I;F4H)TE.1T]?4U1/4D%'15]!
M0U1)3TY?1D]25T%21"<L(#$P*3L*9&5F:6YE*"=)3D=/7U-43U)!1T5?04-4
M24].7TU/5D5+1450)RP@,3$I.PID969I;F4H)TE.1T]?4U1/4D%'15]!0U1)
M3TY?1DQ!1T].3%DG+"`Q,BD["F1E9FEN92@G24Y'3U]35$]204=%7T%#5$E/
M3E].3U1)1EDG+"`Q,RD["@HO*BH*("H@26YG;U]3=&]R86=E.CH@)V9L86=S
M)R!C;VYS=&%N=',*("HO"F1E9FEN92@G24Y'3U]35$]204=%7T9,04=?04Y3
M5T52140G+"`Q*3L*9&5F:6YE*"=)3D=/7U-43U)!1T5?1DQ!1U]$14Q%5$5$
M)RP@,BD["F1E9FEN92@G24Y'3U]35$]204=%7T9,04=?1DQ!1T=%1"<L(#0I
M.PID969I;F4H)TE.1T]?4U1/4D%'15]&3$%'7U-%14XG+"`X*3L*"B\J*@H@
M*B!);F=O7U-T;W)A9V4Z.B`G='EP92<@8V]N<W1A;G1S+@H@*B\*9&5F:6YE
M*"=)3D=/7U-43U)!1T5?5%E015](14%$15(G+"`Q*3L*9&5F:6YE*"=)3D=/
M7U-43U)!1T5?5%E015]325I%)RP@,BD["F1E9FEN92@G24Y'3U]35$]204=%
M7U194$5?0D]$62<L(#,I.PH*+RHJ"B`J($EN9V]?4W1O<F%G93HZ(&1E9FEN
M97,@86X@05!)('1O('-T;W)E('1H92!V87)I;W5S(&9I;'1E<B!R=6QE<RX*
M("H*("H@)$AO<F1E.B!I;F=O+VQI8B]3=&]R86=E+G!H<"QV(#$N-#,N."XQ
M-2`R,#`V+S`R+S`Q(#$X.C0V.C0R(&IA;B!%>'`@)`H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H05-,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*
M("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O
M<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!);F=O(#`N,0H@*B!`<&%C
M:V%G92!);F=O"B`J+PIC;&%S<R!);F=O7U-T;W)A9V4@>PH*("`@("\J*@H@
M("`@("H@1')I=F5R('-P96-I9FEC('!A<F%M971E<G,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@0V%C:&5D(')U;&4@;V)J96-T<RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-A8VAE
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($AA<R!?861D4VAU=&1O=VY#
M86-H92@I(&)E96X@8V%L;&5D('EE=#\*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1?<VAU=&1O=VY#86-H92`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E
M=&4@26YG;U]3=&]R86=E(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP92!O
M9B!C;VYC<F5T92!);F=O7U-T;W)A9V4@<W5B8VQA<W,@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B`@5&AI<R!I<R!B87-E9"!O
M;B!T:&4@<W1O<F%G92!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@*"1D<FEV97(I+B`@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC
M;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T
M97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!);F=O7U-T
M;W)A9V4@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("!F86QS
M92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH
M)&1R:79E<B`](&YU;&PL("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<U]N=6QL*"1D<FEV97(I*2!["B`@("`@("`@("`@("1D<FEV97(@
M/2`D1TQ/0D%,4ULG8V]N9B==6R=S=&]R86=E)UU;)V1R:79E<B==.PH@("`@
M("`@('T*"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH*
M("`@("`@("!I9B`H:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D
M<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G<W1O<F%G92<L("1D
M<FEV97(I.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]3=&]R86=E+R<@+B`D9')I=F5R("X@)RYP:'`G
M.PH@("`@("`@("1C;&%S<R`]("=);F=O7U-T;W)A9V5?)R`N("1D<FEV97([
M"B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@
M("`@("1I;F=O(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&EN9V\@/2!F86QS93L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D:6YG;SL*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($EN
M9V]?4W1O<F%G92!I;G-T86YC90H@("`@("H@8F%S960@;VX@)&1R:79E<BX@
M($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\*("`@
M("`J($EN9V]?4W1O<F%G92!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M
M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H
M;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE('-T;W)A9V4@<V]U<F-E<R!A<F4@
M<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I
M;G9O:V5D(&%S.B`D=F%R(#T@)DEN9V]?4W1O<F%G93HZ<VEN9VQE=&]N*"D[
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP
M92!O9B!C;VYC<F5T92!);F=O7U-T;W)A9V4@<W5B8VQA<W,@=&\*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B`@5&AI<R!I<R!B87-E
M9"!O;B!T:&4@<W1O<F%G92!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@*"1D<FEV97(I+B`@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@
M:6YC;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE
M=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&-R96%T960@8V]N8W)E=&4@26YG;U]3=&]R86=E
M(&EN<W1A;F-E+"!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@;VX@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E
M<B`](&YU;&PL("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I
M8R`D:6YS=&%N8V5S.PH*("`@("`@("!I9B`H:7-?;G5L;"@D9')I=F5R*2D@
M>PH@("`@("`@("`@("`D9')I=F5R(#T@)$=,3T)!3%-;)V-O;F8G75LG<W1O
M<F%G92==6R=D<FEV97(G73L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N
M=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@/2!(;W)D93HZ
M9V5T1')I=F5R0V]N9FEG*"=S=&]R86=E)RP@)&1R:79E<BD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@
M("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@
M)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US
M*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=
M*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DEN
M9V]?4W1O<F%G93HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!S<&5C:69I960@
M9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9FEE;&0@(%1H
M92!F:65L9"!N86UE(&]F('1H92!D97-I<F5D(&1A=&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@*$E.1T]?4U1/4D%'15]!0U1)3TY?*B!C;VYS
M=&%N=',I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAE("!5<V4@=&AE
M(&-A8VAE9"!O8FIE8W0_"B`@("`@*@H@("`@("H@0')E='5R;B!);F=O7U-T
M;W)A9V5?<G5L97Q);F=O7U-T;W)A9V5?9FEL=&5R<R`@5&AE('-P96-I9FEE
M9"!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9R971R:65V92@D9FEE
M;&0L("1C86-H92`]('1R=64I"B`@("!["B`@("`@("`@:68@*"1C86-H92D@
M>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8V%C:&5;)&9I96QD
M72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5;)&9I96QD72`]
M(&%R<F%Y*"=M;V0G(#T^(&9A;'-E*3L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D7U-%4U-)3TY;)VEN9V\G75LG<W1O<F%G92==6R1F:65L9%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397-S
M:6]N3V)J96-T<RYP:'`G.PH@("`@("`@("`@("`@("`@("`@("1C86-H95-E
M<W,@/2`F2&]R9&5?4V5S<VEO;D]B:F5C=',Z.G-I;F=L971O;B@I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5;)&9I96QD75LG;V(G72`]
M("1C86-H95-E<W,M/G%U97)Y*"1?4T534TE/3ELG:6YG;R==6R=S=&]R86=E
M)UU;)&9I96QD72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5;)&9I96QD75LG;V(G72`]("8D
M=&AI<RT^7W)E=')I979E*"1F:65L9"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<VAU=&1O=VY#86-H92D@>PH@
M("`@("`@("`@("`@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N
M*&%R<F%Y*"8D=&AI<RP@)U]A9&1#86-H95-H=71D;W=N)RDI.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<VAU=&1O=VY#86-H92`]('1R=64["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]B
M(#T@)B1T:&ES+3Y?8V%C:&5;)&9I96QD75LG;V(G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D;V(@/2`F)'1H:7,M/E]R971R:65V92@D9FEE
M;&0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@<W!E8VEF:65D(&1A=&$@9G)O
M;2!T:&4@<W1O<F%G92!B86-K96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&9I96QD("!4:&4@9FEE;&0@;F%M92!O9B!T:&4@9&5S:7)E
M9"!D871A+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!3964@;&EB
M+U-T;W)A9V4N<&AP(&9O<B!T:&4@879A:6QA8FQE(&9I96QD<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N($EN9V]?4W1O<F%G95]R=6QE?$EN9V]?4W1O<F%G
M95]F:6QT97)S("!4:&4@<W!E8VEF:65D(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]R971R:65V92@D9FEE;&0I"B`@("!["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S('1H92!S<&5C
M:69I960@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@26YG;U]3=&]R86=E
M7W)U;&5\26YG;U]3=&]R86=E7V9I;'1E<G,@)&]B("!4:&4@;V)J96-T('1O
M('-T;W)E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAE("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@0V%C:&4@=&AE(&]B:F5C=#\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<W1O<F4H)B1O8BP@)&-A8VAE(#T@=')U92D*
M("`@('L*("`@("`@("`D='EP92`]("1O8BT^;V)4>7!E*"D["B`@("`@("`@
M:68@*&EN7V%R<F%Y*"1T>7!E+"!A<G)A>2A)3D=/7U-43U)!1T5?04-424].
M7T),04-+3$E35"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($E.1T]?4U1/4D%'15]!0U1)3TY?5D%#051)3TXL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!)3D=/7U-43U)!1T5?04-424].7U=(251%
M3$E35"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($E.1T]?
M4U1/4D%'15]!0U1)3TY?1D]25T%21"DI*2!["B`@("`@("`@("`@("1F:6QT
M97)S(#T@)'1H:7,M/G)E=')I979E*$E.1T]?4U1/4D%'15]!0U1)3TY?1DE,
M5$524RD["B`@("`@("`@("`@(&EF("@D9FEL=&5R<RT^9FEN9%)U;&5)9"@D
M='EP92D@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@('-W:71C:"`H)'1Y
M<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/
M3E]"3$%#2TQ)4U0Z"B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G0FQA
M8VML:7-T)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@24Y'3U]35$]204=%7T%#5$E/3E]604-!5$E/3CH*("`@
M("`@("`@("`@("`@("`@("`D;F%M92`]("=686-A=&EO;B<["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E($E.1T]?
M4U1/4D%'15]!0U1)3TY?5TA)5$5,25-4.@H@("`@("`@("`@("`@("`@("`@
M("1N86UE(#T@)U=H:71E;&ES="<["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?
M1D]25T%21#H*("`@("`@("`@("`@("`@("`@("`D;F%M92`]("=&;W)W87)D
M)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1F:6QT97)S+3YA9&12=6QE*&%R<F%Y*"=A
M8W1I;VXG(#T^("1T>7!E+"`G;F%M92<@/3X@)&YA;64I*3L*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^<W1O<F4H)&9I;'1E<G,L("1C86-H
M92D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("@D8V%C:&4I('L*("`@("`@("`@("`@)'1H:7,M/E]C86-H
M95LD;V(M/F]B5'EP92@I72`](&%R<F%Y*"=O8B<@/3X@)&]B+"`G;6]D)R`]
M/B!T<G5E*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W-H=71D;W=N0V%C
M:&4I('L*("`@("`@("`@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T
M:6]N*&%R<F%Y*"8D=&AI<RP@)U]A9&1#86-H95-H=71D;W=N)RDI.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S:'5T9&]W;D-A8VAE(#T@=')U93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<W1O<F4H)&]B*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!T:&4@
M<W!E8VEF:65D(&1A=&$@:6X@=&AE('-T;W)A9V4@8F%C:V5N9"X*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!);F=O7U-T;W)A9V5?<G5L97Q);F=O7U-T;W)A
M9V5?9FEL=&5R<R`D;V(@(%1H92!O8FIE8W0@=&\@<W1O<F4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]S=&]R92@F)&]B*0H@("`@>PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%-A=F5S(&$@8V]P
M>2!O9B!O8FIE8W1S(&%T('1H92!E;F0@;V8@82!R97%U97-T+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M861D0V%C:&53:'5T9&]W;B@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]397-S:6]N3V)J96-T<RYP:'`G.PH@("`@("`@("1C86-H92`]
M("9(;W)D95]397-S:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D["@H@("`@("`@
M("\J(%-T;W)E('1H92!C=7)R96YT(&]B:F5C=',N("HO"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]C86-H92!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@:68@*"$D=F%L6R=M;V0G72`F)B!I<W-E="@D7U-%4U-)3TY;)VEN
M9V\G75LG<W1O<F%G92==6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1?
M4T534TE/3ELG:6YG;R==6R=S=&]R86=E)UU;)&ME>5TI*2!["B`@("`@("`@
M("`@("`@("`D8V%C:&4M/G-E=%!R=6YE1FQA9R@D7U-%4U-)3TY;)VEN9V\G
M75LG<W1O<F%G92==6R1K97E=+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEN9V\G75LG<W1O<F%G92==6R1K97E=(#T@
M)&-A8VAE+3YS=&]R94]I9"@D=F%L6R=O8B==+"!F86QS92D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!O
M;B!A(&=I=F5N(&%C=&EO;B!C;VYS=&%N="X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D86-T:6]N("!4:&4@24Y'3U]35$]204=%7T%#5$E/3E\J
M('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@<W1D0VQA<W,@($]B:F5C
M="!W:71H('1H92!F;VQL;W=I;F<@=F%L=65S.@H@("`@("H@/'!R93X*("`@
M("`J("=F;&%G<R<@/3X@*&)O;VQE86XI($1O97,@=&AI<R!A8W1I;VX@86QL
M;W<@9FQA9W,@=&\@8F4@<V5T/PH@("`@("H@)VQA8F5L)R`]/B`H<W1R:6YG
M*2!4:&4@;&%B96P@9F]R('1H:7,@86-T:6]N+@H@("`@("H@)W1Y<&4G("`]
M/B`H<W1R:6YG*2!%:71H97(@)V9O;&1E<B<L("=T97AT)RP@;W(@96UP='DN
M"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06-T:6]N
M26YF;R@D86-T:6]N*0H@("`@>PH@("`@("`@("1O8B`]("9N97<@<W1D0VQA
M<W,["B`@("`@("`@)&]B+3YF;&%G<R`](&9A;'-E.PH@("`@("`@("1O8BT^
M='EP92`]("=T97AT)SL*"B`@("`@("`@<W=I=&-H("@D86-T:6]N*2!["B`@
M("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-424].7TM%15`Z"B`@("`@("`@
M("`@("1O8BT^;&%B96P@/2!?*")$96QI=F5R(&EN=&\@;7D@26YB;W@B*3L*
M("`@("`@("`@("`@)&]B+3YT>7!E(#T@9F%L<V4["B`@("`@("`@("`@("1O
M8BT^9FQA9W,@/2!T<G5E.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!)3D=/7U-43U)!1T5?04-424].7TU/5D4Z"B`@("`@("`@("`@("1O
M8BT^;&%B96P@/2!?*")$96QI=F5R('1O(&9O;&1E<B(I.PH@("`@("`@("`@
M("`D;V(M/G1Y<&4@/2`G9F]L9&5R)SL*("`@("`@("`@("`@)&]B+3YF;&%G
M<R`]('1R=64["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($E.
M1T]?4U1/4D%'15]!0U1)3TY?1$E30T%21#H*("`@("`@("`@("`@)&]B+3YL
M86)E;"`](%\H(D1E;&5T92!M97-S86=E(&-O;7!L971E;'DB*3L*("`@("`@
M("`@("`@)&]B+3YT>7!E(#T@9F%L<V4["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?4D5$25)%0U0Z"B`@
M("`@("`@("`@("1O8BT^;&%B96P@/2!?*")2961I<F5C="!T;R(I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-4
M24].7U)%1$E214-42T5%4#H*("`@("`@("`@("`@)&]B+3YL86)E;"`](%\H
M(D1E;&EV97(@:6YT;R!M>2!);F)O>"!A;F0@<F5D:7)E8W0@=&\B*3L*("`@
M("`@("`@("`@)&]B+3YF;&%G<R`]('1R=64["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E($E.1T]?4U1/4D%'15]!0U1)3TY?34]614M%15`Z
M"B`@("`@("`@("`@("1O8BT^;&%B96P@/2!?*")$96QI=F5R(&EN=&\@;7D@
M26YB;W@@86YD(&-O<'D@=&\B*3L*("`@("`@("`@("`@)&]B+3YT>7!E(#T@
M)V9O;&1E<B<["B`@("`@("`@("`@("1O8BT^9FQA9W,@/2!T<G5E.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)3D=/7U-43U)!1T5?04-4
M24].7U)%2D5#5#H*("`@("`@("`@("`@)&]B+3YL86)E;"`](%\H(E)E:F5C
M="!W:71H(')E87-O;B(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!)3D=/7U-43U)!1T5?04-424].7T9,04=/3DQ9.@H@("`@("`@("`@
M("`D;V(M/FQA8F5L(#T@7R@B3VYL>2!F;&%G('1H92!M97-S86=E(BD["B`@
M("`@("`@("`@("1O8BT^='EP92`](&9A;'-E.PH@("`@("`@("`@("`D;V(M
M/F9L86=S(#T@=')U93L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@24Y'3U]35$]204=%7T%#5$E/3E].3U1)1EDZ"B`@("`@("`@("`@("1O
M8BT^;&%B96P@/2!?*").;W1I9GD@96UA:6P@861D<F5S<R(I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&]N(&$@
M9VEV96X@=&5S="!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D86-T:6]N("!4:&4@=&5S="!S=')I;F<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=&1#;&%S<R`@3V)J96-T('=I=&@@=&AE(&9O;&QO=VEN9R!V86QU
M97,Z"B`@("`@*B`\<')E/@H@("`@("H@)VQA8F5L)R`]/B`H<W1R:6YG*2!4
M:&4@;&%B96P@9F]R('1H:7,@86-T:6]N+@H@("`@("H@)W1Y<&4G("`]/B`H
M<W1R:6YG*2!%:71H97(@)VEN="<L("=N;VYE)RP@;W(@)W1E>'0G+@H@("`@
M("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1E<W1);F9O*"1T
M97-T*0H@("`@>PH@("`@("`@("\J($UA<'!I;F<@;V8@9V5T=&5X="!S=')I
M;F=S("T^(&QA8F5L<RX@*B\*("`@("`@("`D;&%B96QS(#T@87)R87DH"B`@
M("`@("`@("`@("=C;VYT86EN<R<@/3X@7R@B0V]N=&%I;G,B*2P*("`@("`@
M("`@("`@)VYO="!C;VYT86EN)R`]/B`@7R@B1&]E<VXG="!C;VYT86EN(BDL
M"B`@("`@("`@("`@("=I<R<@/3X@7R@B27,B*2P*("`@("`@("`@("`@)VYO
M="!I<R<@/3X@7R@B27-N)W0B*2P*("`@("`@("`@("`@)V)E9VEN<R!W:71H
M)R`]/B!?*")"96=I;G,@=VET:"(I+`H@("`@("`@("`@("`G;F]T(&)E9VEN
M<R!W:71H)R`]/B!?*")$;V5S;B=T(&)E9VEN('=I=&@B*2P*("`@("`@("`@
M("`@)V5N9',@=VET:"<@/3X@7R@B16YD<R!W:71H(BDL"B`@("`@("`@("`@
M("=N;W0@96YD<R!W:71H)R`]/B!?*")$;V5S;B=T(&5N9"!W:71H(BDL"B`@
M("`@("`@("`@("=E>&ES=',G(#T^("!?*")%>&ES=',B*2P*("`@("`@("`@
M("`@)VYO="!E>&ES="<@/3X@7R@B1&]E<VXG="!E>&ES="(I+`H@("`@("`@
M("`@("`G<F5G97@G(#T^(%\H(E)E9W5L87(@97AP<F5S<VEO;B(I+`H@("`@
M("`@("`@("`G;6%T8VAE<R<@/3X@7R@B36%T8VAE<R`H=VET:"!P;&%C96AO
M;&1E<G,I(BDL"B`@("`@("`@("`@("=N;W0@;6%T8VAE<R<@/3X@7R@B1&]E
M<VXG="!M871C:"`H=VET:"!P;&%C96AO;&1E<G,I(BDL"B`@("`@("`@("`@
M("=L97-S('1H86XG(#T^(%\H(DQE<W,@=&AA;B(I+`H@("`@("`@("`@("`G
M;&5S<R!T:&%N(&]R(&5Q=6%L('1O)R`]/B!?*"),97-S('1H86X@;W(@97%U
M86P@=&\B*2P*("`@("`@("`@("`@)V=R96%T97(@=&AA;B<@/3X@7R@B1W)E
M871E<B!T:&%N(BDL"B`@("`@("`@("`@("=G<F5A=&5R('1H86X@;W(@97%U
M86P@=&\G(#T^(%\H(D=R96%T97(@=&AA;B!O<B!E<75A;"!T;R(I+`H@("`@
M("`@("`@("`G97%U86PG(#T^(%\H(D5Q=6%L('1O(BDL"B`@("`@("`@("`@
M("=N;W0@97%U86PG(#T^(%\H(DYO="!E<75A;"!T;R(I"B`@("`@("`@*3L*
M"B`@("`@("`@+RH@5&AE('1Y<&4@;V8@=&5S=',@879A:6QA8FQE+B`J+PH@
M("`@("`@("1T>7!E<R`](&%R<F%Y*`H@("`@("`@("`@("`G:6YT)R`@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`G;&5S<R!T:&%N)RP@)VQE<W,@=&AA
M;B!O<B!E<75A;"!T;R<L("=G<F5A=&5R('1H86XG+`H@("`@("`@("`@("`@
M("`@)V=R96%T97(@=&AA;B!O<B!E<75A;"!T;R<L("=E<75A;"<L("=N;W0@
M97%U86PG"B`@("`@("`@("`@("DL"B`@("`@("`@("`@("=N;VYE)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("=E>&ES=',G+"`G;F]T(&5X:7-T)PH@
M("`@("`@("`@("`I+`H@("`@("`@("`@("`G=&5X="<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`G8V]N=&%I;G,G+"`G;F]T(&-O;G1A:6XG+"`G:7,G
M+"`G;F]T(&ES)RP@)V)E9VEN<R!W:71H)RP*("`@("`@("`@("`@("`@("=N
M;W0@8F5G:6YS('=I=&@G+"`G96YD<R!W:71H)RP@)VYO="!E;F1S('=I=&@G
M+"`G<F5G97@G+`H@("`@("`@("`@("`@("`@)VUA=&-H97,G+"`G;F]T(&UA
M=&-H97,G"B`@("`@("`@("`@("D*("`@("`@("`I.PH*("`@("`@("`O*B!#
M<F5A=&4@=&AE(&EN9F]R;6%T:6]N(&]B:F5C="X@*B\*("`@("`@("`D;V(@
M/2`F;F5W('-T9$-L87-S.PH@("`@("`@("1O8BT^;&%B96P@/2`D;&%B96QS
M6R1T97-T73L*("`@("`@("!F;W)E86-H("@D='EP97,@87,@)&ME>2`]/B`D
M=F%L*2!["B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D=&5S="P@)'9A;"DI
M('L*("`@("`@("`@("`@("`@("1O8BT^='EP92`]("1K97D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1O8CL*("`@('T*"GT*"B\J*@H@*B!);F=O7U-T;W)A9V5?
M<G5L93HZ(&ES('1H92!B87-E(&-L87-S(&9O<B!T:&4@=F%R:6]U<R!A8W1I
M;VX@;V)J96-T<PH@*B!U<V5D(&)Y($EN9V]?4W1O<F%G92X*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!);F=O(#$N,`H@*B!`<&%C:V%G92!);F=O
M"B`J+PIC;&%S<R!);F=O7U-T;W)A9V5?<G5L92!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;V)J96-T('1Y<&4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D7V]B='EP93L*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&]B:F5C="!R=6QE('1Y<&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!4:&4@;V)J96-T(')U;&4@='EP92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;V)4>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]O8G1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T
M;R!M86YA9V4@86X@:6YT97)N86P@861D<F5S<R!L:7-T+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`D9&%T82`@("!4:&4@:6YC;VUI;F<@9&%T82`H87)R87D@;W(@<W1R:6YG
M*2X*("`@("`J($!P87)A;2!B;V]L96%N("1S;W)T("!3;W)T('1H92!L:7-T
M/PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!A9&1R97-S(&QI
M<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?861D<F5S<TQI<W0H)&1A=&$L
M("1S;W)T*0H@("`@>PH@("`@("`@("1O=71P=70@/2!A<G)A>2@I.PH*("`@
M("`@("!I9B`H:7-?87)R87DH)&1A=&$I*2!["B`@("`@("`@("`@("1O=71P
M=70@/2`D9&%T83L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%T
M82`]('1R:6TH)&1A=&$I.PH@("`@("`@("`@("`D;W5T<'5T(#T@*&5M<'1Y
M*"1D871A*2D@/R!A<G)A>2@I(#H@<')E9U]S<&QI="@B+UQS*R\B+"`D9&%T
M82D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-O<G0I('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("`@
M("`D;W5T<'5T(#T@2&]R9&5?07)R87DZ.G!R97!A<F5!9&1R97-S3&ES="@D
M;W5T<'5T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@
M("`@?0H*?0H*+RHJ"B`J($EN9V]?4W1O<F%G95]B;&%C:VQI<W0@:7,@=&AE
M(&]B:F5C="!U<V5D('1O(&AO;&0@8FQA8VML:7-T(')U;&4*("H@:6YF;W)M
M871I;VXN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@26YG;R`Q+C`*
M("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@26YG;U]3=&]R86=E7V)L86-K
M;&ES="!E>'1E;F1S($EN9V]?4W1O<F%G95]R=6QE('L*"B`@("!V87(@)%]A
M9&1R(#T@87)R87DH*3L*("`@('9A<B`D7V9O;&1E<B`]("<G.PH@("`@=F%R
M("1?;V)T>7!E(#T@24Y'3U]35$]204=%7T%#5$E/3E]"3$%#2TQ)4U0["@H@
M("`@+RHJ"B`@("`@*B!3971S('1H92!L:7-T(&]F(&)L86-K;&ES=&5D(&%D
M9')E<W-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1A=&$@("`@
M5&AE(&QI<W0@;V8@861D<F5S<V5S("AA<G)A>2!O<B!S=')I;F<I+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)'-O<G0@(%-O<G0@=&AE(&QI<W0_"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@4$5!4E]%<G)O<B!O;B!E<G)O<BP@
M=')U92!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971";&%C
M:VQI<W0H)&1A=&$L("1S;W)T(#T@=')U92D*("`@('L*("`@("`@("`D861D
M<B`]("8D=&AI<RT^7V%D9')E<W-,:7-T*"1D871A+"`D<V]R="D["B`@("`@
M("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=S=&]R86=E)UU;)VUA
M>&)L86-K;&ES="==*2D@>PH@("`@("`@("`@("`D861D<E]C;W5N="`](&-O
M=6YT*"1A9&1R*3L*("`@("`@("`@("`@:68@*"1A9&1R7V-O=6YT(#X@)$=,
M3T)!3%-;)V-O;F8G75LG<W1O<F%G92==6R=M87AB;&%C:VQI<W0G72D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")-87AI;75M(&YU;6)E<B!O9B!B;&%C:VQI<W1E9"!A9&1R97-S97,@
M97AC965D960@*%1O=&%L(&%D9')E<W-E<SH@)7,L($UA>&EM=6T@861D<F5S
M<V5S.B`E<RDN("!#;W5L9"!N;W0@861D(&YE=R!A9&1R97-S97,@=&\@8FQA
M8VML:7-T+B(I+"`D861D<E]C;W5N="P@)$=,3T)!3%-;)V-O;F8G75LG<W1O
M<F%G92==6R=M87AB;&%C:VQI<W0G72DL("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V%D9'(@/2`D
M861D<CL*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO
M;B!S971";&%C:VQI<W1&;VQD97(H)&1A=&$I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]F;VQD97(@/2`D9&%T83L*("`@('T*"B`@("!F=6YC=&EO;B!G971"
M;&%C:VQI<W0H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>5]F:6QT97(H
M)'1H:7,M/E]A9&1R+"!A<G)A>2@G26YG;R<L("=?9FEL=&5R16UP='E!9&1R
M97-S)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$)L86-K;&ES=$9O;&1E
M<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9F]L9&5R.PH@("`@
M?0H*?0H*+RHJ"B`J($EN9V]?4W1O<F%G95]W:&ET96QI<W0@:7,@=&AE(&]B
M:F5C="!U<V5D('1O(&AO;&0@=VAI=&5L:7-T(')U;&4*("H@:6YF;W)M871I
M;VXN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@26YG;R`Q+C`*("H@
M0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@26YG;U]3=&]R86=E7W=H:71E;&ES
M="!E>'1E;F1S($EN9V]?4W1O<F%G95]R=6QE('L*"B`@("!V87(@)%]A9&1R
M(#T@87)R87DH*3L*("`@('9A<B`D7V]B='EP92`]($E.1T]?4U1/4D%'15]!
M0U1)3TY?5TA)5$5,25-4.PH*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;&ES
M="!O9B!W:&ET96QI<W1E9"!A9&1R97-S97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1D871A("`@(%1H92!L:7-T(&]F(&%D9')E<W-E<R`H87)R
M87D@;W(@<W1R:6YG*2X*("`@("`J($!P87)A;2!B;V]L96%N("1S;W)T("!3
M;W)T('1H92!L:7-T/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%!%
M05)?17)R;W(@;VX@97)R;W(L('1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T5VAI=&5L:7-T*"1D871A+"`D<V]R="`]('1R=64I
M"B`@("!["B`@("`@("`@)&%D9'(@/2`F)'1H:7,M/E]A9&1R97-S3&ES="@D
M9&%T82P@)'-O<G0I.PH@("`@("`@("1A9&1R(#T@87)R87E?9FEL=&5R*"1A
M9&1R+"!A<G)A>2@G26YG;R<L("=?9FEL=&5R16UP='E!9&1R97-S)RDI.PH@
M("`@("`@(&EF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG<W1O<F%G92==
M6R=M87AW:&ET96QI<W0G72DI('L*("`@("`@("`@("`@)&%D9')?8V]U;G0@
M/2!C;W5N="@D861D<BD["B`@("`@("`@("`@(&EF("@D861D<E]C;W5N="`^
M("1'3$]"04Q36R=C;VYF)UU;)W-T;W)A9V4G75LG;6%X=VAI=&5L:7-T)UTI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B36%X:6UU;2!N=6UB97(@;V8@=VAI=&5L:7-T960@861D<F5S
M<V5S(&5X8V5E9&5D("A4;W1A;"!A9&1R97-S97,Z("5S+"!-87AI;75M(&%D
M9')E<W-E<SH@)7,I+B`@0V]U;&0@;F]T(&%D9"!N97<@861D<F5S<V5S('1O
M('=H:71E;&ES="XB*2P@)&%D9')?8V]U;G0L("1'3$]"04Q36R=C;VYF)UU;
M)W-T;W)A9V4G75LG;6%X=VAI=&5L:7-T)UTI+"`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]A9&1R
M(#T@)&%D9'(["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T5VAI=&5L:7-T*"D*("`@('L*("`@("`@("!R971U<FX@87)R
M87E?9FEL=&5R*"1T:&ES+3Y?861D<BP@87)R87DH)TEN9V\G+"`G7V9I;'1E
M<D5M<'1Y061D<F5S<R<I*3L*("`@('T*"GT*"B\J*@H@*B!);F=O7U-T;W)A
M9V5?9F]R=V%R9"!I<R!T:&4@;V)J96-T('5S960@=&\@:&]L9"!M86EL(&9O
M<G=A<F1I;F<@<G5L90H@*B!I;F9O<FUA=&EO;BX*("H*("H@0&%U=&AO<B`@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/@H@*B!`<VEN8V4@("!);F=O(#$N,`H@*B!`<&%C:V%G92!);F=O"B`J+PIC
M;&%S<R!);F=O7U-T;W)A9V5?9F]R=V%R9"!E>'1E;F1S($EN9V]?4W1O<F%G
M95]R=6QE('L*"B`@("!V87(@)%]A9&1R(#T@87)R87DH*3L*("`@('9A<B`D
M7VME97`@/2!T<G5E.PH@("`@=F%R("1?;V)T>7!E(#T@24Y'3U]35$]204=%
M7T%#5$E/3E]&3U)705)$.PH*("`@(&9U;F-T:6]N('-E=$9O<G=A<F1!9&1R
M97-S97,H)&1A=&$L("1S;W)T(#T@=')U92D*("`@('L*("`@("`@("`D=&AI
M<RT^7V%D9'(@/2`F)'1H:7,M/E]A9&1R97-S3&ES="@D9&%T82P@)'-O<G0I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$9O<G=A<F1+965P*"1D871A*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?:V5E<"`]("1D871A.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$9O<G=A<F1!9&1R97-S97,H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V%D9'(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M1F]R=V%R9$ME97`H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VME
M97`["B`@("!]"@I]"@HO*BH*("H@26YG;U]3=&]R86=E7W9A8V%T:6]N(&ES
M('1H92!O8FIE8W0@=7-E9"!T;R!H;VQD('9A8V%T:6]N(')U;&4*("H@:6YF
M;W)M871I;VXN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@26YG;R`Q
M+C`*("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@26YG;U]3=&]R86=E7W9A
M8V%T:6]N(&5X=&5N9',@26YG;U]3=&]R86=E7W)U;&4@>PH*("`@('9A<B`D
M7V%D9'(@/2!A<G)A>2@I.PH@("`@=F%R("1?9&%Y<R`](#<["B`@("!V87(@
M)%]E>&-L=61E<R`](&%R<F%Y*"D["B`@("!V87(@)%]I9VYO<F5L:7-T(#T@
M=')U93L*("`@('9A<B`D7V]B='EP92`]($E.1T]?4U1/4D%'15]!0U1)3TY?
M5D%#051)3TX["B`@("!V87(@)%]R96%S;VX@/2`G)SL*("`@('9A<B`D7W-U
M8FIE8W0@/2`G)SL*"B`@("!F=6YC=&EO;B!S971686-A=&EO;D%D9')E<W-E
M<R@D9&%T82P@)'-O<G0@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M861D<B`]("8D=&AI<RT^7V%D9')E<W-,:7-T*"1D871A+"`D<V]R="D["B`@
M("!]"@H@("`@9G5N8W1I;VX@<V5T5F%C871I;VY$87ES*"1D871A*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9&%Y<R`]("1D871A.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-E=%9A8V%T:6]N17AC;'5D97,H)&1A=&$L("1S;W)T(#T@=')U
M92D*("`@('L*("`@("`@("`D=&AI<RT^7V5X8VQU9&5S(#T@)B1T:&ES+3Y?
M861D<F5S<TQI<W0H)&1A=&$L("1S;W)T*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!S971686-A=&EO;DEG;F]R96QI<W0H)&1A=&$I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]I9VYO<F5L:7-T(#T@)&1A=&$["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5T5F%C871I;VY296%S;VXH)&1A=&$I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]R96%S;VX@/2`D9&%T83L*("`@('T*"B`@("!F=6YC=&EO;B!S9716
M86-A=&EO;E-U8FIE8W0H)&1A=&$I"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M=6)J96-T(#T@)&1A=&$["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F%C871I
M;VY!9&1R97-S97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%D
M9'(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F%C871I;VY$87ES*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D87ES.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=%9A8V%T:6]N17AC;'5D97,H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V5X8VQU9&5S.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%9A8V%T:6]N26=N;W)E;&ES="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:6=N;W)E;&ES=#L*("`@('T*"B`@("!F=6YC=&EO;B!G971686-A
M=&EO;E)E87-O;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5A
M<V]N.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9A8V%T:6]N4W5B:F5C="@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W5B:F5C=#L*("`@('T*
M"GT*"B\J*@H@*B!);F=O7U-T;W)A9V5?9FEL=&5R<R!I<R!T:&4@;V)J96-T
M('5S960@=&\@:&]L9"!U<V5R+61E9FEN960@9FEL=&5R:6YG(')U;&4*("H@
M:6YF;W)M871I;VXN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@26YG
M;R`Q+C`*("H@0'!A8VMA9V4@26YG;PH@*B\*8VQA<W,@26YG;U]3=&]R86=E
M7V9I;'1E<G,@>PH*("`@("\J*@H@("`@("H@5&AE(&9I;'1E<B!L:7-T+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9FEL
M=&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@;V)J96-T('1Y
M<&4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D7V]B='EP92`]($E.1T]?4U1/4D%'15]!0U1)3TY?1DE,5$524SL*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&]B:F5C="!R=6QE('1Y<&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;V)J96-T(')U;&4@
M='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@;V)4>7!E*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]O8G1Y<&4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!0<F]P86=A=&5S('1H92!F:6QT97(@;&ES="!W:71H(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D871A("!!(&QI<W0@;V8@<G5L
M92!H87-H97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9I;'1E<FQI<W0H
M)&1A=&$I"B`@("!["B`@("`@("`@)'1H:7,M/E]F:6QT97)S(#T@)&1A=&$[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!F:6QT97(@;&ES
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!R
M=6QE(&AA<VAE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1FEL=&5R;&ES
M="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9FEL=&5R<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S:6YG;&4@<G5L92!H87-H
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9"`@02!R=6QE(&YU
M;6)E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5Q=65S
M=&5D(')U;&4@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4G5L92@D
M:60I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9FEL=&5R<ULD:61=
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')U;&4@:&%S:"!W
M:71H(&1E9F%U;'0@=F%L=64@=7-E9"!W:&5N(&-R96%T:6YG(&YE=R!R=6QE
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(')U;&4@:&%S:"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%)U;&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@)VYA;64G(#T^(%\H
M(DYE=R!2=6QE(BDL"B`@("`@("`@("`@("=C;VUB:6YE)R`]/B!)3D=/7U-4
M3U)!1T5?0T]-0DE.15]!3$PL"B`@("`@("`@("`@("=C;VYD:71I;VYS)R`]
M/B!A<G)A>2@I+`H@("`@("`@("`@("`G86-T:6]N)R`]/B!)3D=/7U-43U)!
M1T5?04-424].7TM%15`L"B`@("`@("`@("`@("=A8W1I;VXM=F%L=64G(#T^
M("<G+`H@("`@("`@("`@("`G<W1O<"<@/3X@9F%L<V4L"B`@("`@("`@("`@
M("=F;&%G<R<@/3X@,"P*("`@("`@("`@("`@)V1I<V%B;&4G(#T^(&9A;'-E
M"B`@("`@("`@*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E87)C:&5S(&9O
M<B!T:&4@9FER<W0@<G5L92!O9B!A(&-E<G1A:6X@86-T:6]N('1Y<&4@86YD
M(')E='5R;G,@:71S"B`@("`@*B!N=6UB97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&%C=&EO;B`@5&AE(&9I96QD('1Y<&4@;V8@=&AE('-E
M87)C:&5D(')U;&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("A)
M3D=/7U-43U)!1T5?04-424].7RH@8V]N<W1A;G1S*2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@=&AE(&9I<G-T(&UA
M=&-H:6YG(')U;&4@;W(@;G5L;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEN
M9%)U;&5)9"@D86-T:6]N*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?9FEL=&5R<R!A<R`D:60@/3X@)')U;&4I('L*("`@("`@("`@("`@:68@
M*"1R=6QE6R=A8W1I;VXG72`]/2`D86-T:6]N*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)&ED.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5A<F-H97,@9F]R(&%N9"!R971U<FYS('1H92!F
M:7)S="!R=6QE(&]F(&$@8V5R=&%I;B!A8W1I;VX@='EP92X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D86-T:6]N("!4:&4@9FEE;&0@='EP92!O
M9B!T:&4@<V5A<F-H960@<G5L90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@*$E.1T]?4U1/4D%'15]!0U1)3TY?*B!C;VYS=&%N=',I+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!F:7)S="!M871C:&EN9R!R
M=6QE(&AA<V@@;W(@;G5L;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEN9%)U
M;&4H)&%C=&EO;BD*("`@('L*("`@("`@("`D:60@/2`D=&AI<RT^9FEN9%)U
M;&5)9"@D86-T:6]N*3L*("`@("`@("!I9B`H)&ED("$]/2!N=6QL*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T4G5L92@D:60I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!R=6QE(&AA<V@@=&\@
M=&AE(&9I;'1E<G,@;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)')U;&4@("`@("`@02!R=6QE(&AA<V@N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D9&5F875L="`@268@=')U92!M97)G92!T:&4@<G5L92!H87-H('=I=&@@
M9&5F875L="!R=6QE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&12=6QE*"1R=6QE+"`D
M9&5F875L="`]('1R=64I"B`@("!["B`@("`@("`@:68@*"1D969A=6QT*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?9FEL=&5R<UM=(#T@87)R87E?;65R9V4H
M)'1H:7,M/F=E=$1E9F%U;'12=6QE*"DL("1R=6QE*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V9I;'1E<G-;72`]("1R=6QE.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T97,@86X@97AI
M<W1I;F<@<G5L92!W:71H(&$@<G5L92!H87-H+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<G5L92`@02!R=6QE(&AA<V@*("`@("`J($!P87)A;2!I
M;G1E9V5R("1I9"`@02!R=6QE(&YU;6)E<@H@("`@("HO"B`@("!F=6YC=&EO
M;B!U<&1A=&52=6QE*"1R=6QE+"`D:60I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]F:6QT97)S6R1I9%T@/2`D<G5L93L*("`@('T*"B`@("`O*BH*("`@("`J
M($1E;&5T97,@82!R=6QE(&9R;VT@=&AE(&9I;'1E<G,@;&ES="X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@($YU;6)E<B!O9B!T:&4@<G5L
M92!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!R=6QE(&AA<R!B965N(&9O=6YD(&%N9"!D96QE=&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&52=6QE*"1I9"D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]F:6QT97)S6R1I9%TI*2!["B`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?9FEL=&5R<ULD:61=*3L*("`@("`@("`@
M("`@)'1H:7,M/E]F:6QT97)S(#T@87)R87E?=F%L=65S*"1T:&ES+3Y?9FEL
M=&5R<RD["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E
M871E<R!A(&-O<'D@;V8@86X@97AI<W1I;F<@<G5L92X*("`@("`J"B`@("`@
M*B!4:&4@8W)E871E9"!C;W!Y(&ES(&%D9&5D('1O('1H92!F:6QT97)S(&QI
M<W0@<FEG:'0@869T97(@=&AE(&]R:6=I;F%L"B`@("`@*B!R=6QE+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9"`@3G5M8F5R(&]F('1H92!R
M=6QE('1O(&-O<'DN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!R=6QE(&AA<R!B965N(&9O=6YD(&%N9"!C;W!I960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O<'E2=6QE*"1I9"D*("`@('L*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]F:6QT97)S6R1I9%TI*2!["B`@("`@("`@
M("`@("1N97=R=6QE(#T@)'1H:7,M/E]F:6QT97)S6R1I9%T["B`@("`@("`@
M("`@("1N97=R=6QE6R=N86UE)UT@/2!S<')I;G1F*%\H(D-O<'D@;V8@)7,B
M*2P@)'1H:7,M/E]F:6QT97)S6R1I9%U;)VYA;64G72D["B`@("`@("`@("`@
M("1T:&ES+3Y?9FEL=&5R<R`](&%R<F%Y7VUE<F=E*&%R<F%Y7W-L:6-E*"1T
M:&ES+3Y?9FEL=&5R<RP@,"P@)&ED("L@,2DL(&%R<F%Y*"1N97=R=6QE*2P@
M87)R87E?<VQI8V4H)'1H:7,M/E]F:6QT97)S+"`D:60@*R`Q*2D["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V97,@82!R=6QE('5P
M(&EN('1H92!F:6QT97)S(&QI<W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&ED("`@("!.=6UB97(@;V8@=&AE(')U;&4@=&\@;6]V92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1S=&5P<R`@3G5M8F5R(&]F('!O<VET:6]N
M<R!T;R!M;W9E('1H92!R=6QE('5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M=6QE57`H)&ED+"`D<W1E<',@/2`Q*0H@("`@>PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1S=&5P<R`F)B`D:60@/B`P.RD@>PH@("`@("`@("`@("`D
M=&5M<"`]("1T:&ES+3Y?9FEL=&5R<ULD:60@+2`Q73L*("`@("`@("`@("`@
M)'1H:7,M/E]F:6QT97)S6R1I9"`M(#%=(#T@)'1H:7,M/E]F:6QT97)S6R1I
M9%T["B`@("`@("`@("`@("1T:&ES+3Y?9FEL=&5R<ULD:61=(#T@)'1E;7`[
M"B`@("`@("`@("`@("\J($-O;G1I;G5E('1O(&UO=F4@=7`@=6YT:6P@=V4@
M<W=A<"!W:71H(&$@=FEE=V%B;&4@8V%T96=O<GDN("HO"B`@("`@("`@("`@
M(&EF("AI;E]A<G)A>2@D=&5M<%LG86-T:6]N)UTL("1?4T534TE/3ELG:6YG
M;R==6R=S8W)I<'1?8V%T96=O<FEE<R==*2D@>PH@("`@("`@("`@("`@("`@
M)&DK*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:60M+3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(')U;&4@9&]W;B!I
M;B!T:&4@9FEL=&5R<R!L:7-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1I9"`@("`@3G5M8F5R(&]F('1H92!R=6QE('1O(&UO=F4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<W1E<',@($YU;6)E<B!O9B!P;W-I=&EO;G,@
M=&\@;6]V92!T:&4@<G5L92!D;W=N+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M=6QE1&]W;B@D:60L("1S=&5P<R`](#$I"B`@("!["B`@("`@("`@)')U;&5C
M;W5N="`](&-O=6YT*"1T:&ES+3Y?9FEL=&5R<RD@+2`Q.PH@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1S=&5P<R`F)B`D:60@/"`D<G5L96-O=6YT.RD@
M>PH@("`@("`@("`@("`D=&5M<"`]("1T:&ES+3Y?9FEL=&5R<ULD:60@*R`Q
M73L*("`@("`@("`@("`@)'1H:7,M/E]F:6QT97)S6R1I9"`K(#%=(#T@)'1H
M:7,M/E]F:6QT97)S6R1I9%T["B`@("`@("`@("`@("1T:&ES+3Y?9FEL=&5R
M<ULD:61=(#T@)'1E;7`["B`@("`@("`@("`@("\J($-O;G1I;G5E('1O(&UO
M=F4@9&]W;B!U;G1I;"!W92!S=V%P('=I=&@@82!V:65W86)L90H@("`@("`@
M("`@("`@("!C871E9V]R>2X@*B\*("`@("`@("`@("`@:68@*&EN7V%R<F%Y
M*"1T96UP6R=A8W1I;VXG72P@)%]315-324].6R=I;F=O)UU;)W-C<FEP=%]C
M871E9V]R:65S)UTI*2!["B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1I9"LK.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($1I<V%B;&5S(&$@<G5L92X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D:60@($YU;6)E<B!O9B!T:&4@<G5L92!T;R!D:7-A
M8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R=6QE1&ES86)L92@D:60I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]F:6QT97)S6R1I9%U;)V1I<V%B;&4G72`]
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&$@<G5L92X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@($YU;6)E<B!O9B!T
M:&4@<G5L92!T;R!E;F%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;&5%
M;F%B;&4H)&ED*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9FEL=&5R<ULD:61=
M6R=D:7-A8FQE)UT@/2!F86QS93L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;F=O+W1E;7!L871E<R\`````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S4P`#`Q-S,U,P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&5M<&QA
M=&5S+W-C<FEP="\`````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-3``,#(P-C4W`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6YG;R]T96UP;&%T97,O<V-R:7!T+V%C=&EV871E+FEN8P``````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(U-0`Q,#0Q-S,V,C<U,``P,C,Q-30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````("`\
M='(^"B`@("`\=&0@86QI9VX](F-E;G1E<B(^"B`@("`@(#QT86)L93X*("`@
M("`@("`\='(^"CP_<&AP(&EF("@D86-T:6]N240@(3T@)W-H;W=?86-T:79E
M)RDZ(#\^"B`@("`@("`@("`\=&0^"B`@("`@("`@("`@(#QF;W)M(&UE=&AO
M9#TB<&]S="(@;F%M93TB86-T:79A=&5?<V-R:7!T(B!A8W1I;VX](CP_<&AP
M(&5C:&\@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S8W)I<'0N<&AP)RD@/SXB
M/@H@("`@("`@("`@("`@(#P_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H@
M("`@("`@("`@("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO
M;DE$(B!V86QU93TB86-T:6]N7V%C=&EV871E(B`O/@H@("`@("`@("`@("`@
M(#QI;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)S=6)M:70B(&YA;64](G-U
M8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B06-T:79A=&4@4V-R:7!T(BD@
M/SXB("\^"B`@("`@("`@("`@(#PO9F]R;3X*("`@("`@("`@(#PO=&0^"B`@
M("`@("`@("`\=&0^"B`@("`@("`@("`@(#QF;W)M(&UE=&AO9#TB<&]S="(@
M;F%M93TB9&5A8W1I=F%T95]S8W)I<'0B(&%C=&EO;CTB/#]P:'`@96-H;R!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)W-C<FEP="YP:'`G*2`_/B(^"B`@("`@
M("`@("`@("`@/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"B`@("`@("`@
M("`@("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A
M;'5E/2)A8W1I;VY?9&5A8W1I=F%T92(@+SX*("`@("`@("`@("`@("`\:6YP
M=70@8VQA<W,](F)U='1O;B(@='EP93TB<W5B;6ET(B!N86UE/2)S=6)M:70B
M('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1E86-T:79A=&4@4V-R:7!T(BD@/SXB
M("\^"B`@("`@("`@("`@(#PO9F]R;3X*("`@("`@("`@(#PO=&0^"B`@("`@
M("`@("`\=&0^"B`@("`@("`@("`@(#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M
M93TB<VAO=U]A8W1I=F5?<V-R:7!T(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"=S8W)I<'0N<&AP)RD@/SXB/@H@("`@("`@
M("`@("`@(#P_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H@("`@("`@("`@
M("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU
M93TB<VAO=U]A8W1I=F4B("\^"B`@("`@("`@("`@("`@/&EN<'5T(&-L87-S
M/2)B=71T;VXB('1Y<&4](G-U8FUI="(@;F%M93TB<W5B;6ET(B!V86QU93TB
M/#]P:'`@96-H;R!?*")3:&]W($%C=&EV92!38W)I<'0B*2`_/B(@+SX*("`@
M("`@("`@("`@/"]F;W)M/@H@("`@("`@("`@/"]T9#X*/#]P:'`@96QS93H@
M/SX*("`@("`@("`@(#QT9#X*("`@("`@("`@("`@/&9O<FT@;65T:&]D/2)P
M;W-T(B!N86UE/2)S:&]W7V-U<G)E;G1?<V-R:7!T(B!A8W1I;VX](CP_<&AP
M(&5C:&\@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S8W)I<'0N<&AP)RD@/SXB
M/@H@("`@("`@("`@("`@(#P_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H@
M("`@("`@("`@("`@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)S=6)M
M:70B(&YA;64](G-U8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B4VAO=R!#
M=7)R96YT(%-C<FEP="(I(#\^(B`O/@H@("`@("`@("`@("`\+V9O<FT^"B`@
M("`@("`@("`\+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`@("`@("`\+W1R/@H@
M("`@("`\+W1A8FQE/@H@("`@/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEN9V\O=&5M<&QA=&5S+W-C<FEP="]S8W)I<'0N:6YC````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`Q,38`,3`T,3<S-C(W-3``,#(R-C4Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#QT86)L92!W
M:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/@H@(#QT<CX*("`@(#QT9"!C
M;&%S<STB:71E;2(^"B`@("`@(#QP<F4^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+W1E;7!L
M871E<R]S8W)I<'0O9F]O=&5R+FEN8P``````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#4P`#$P-#$W,S8R-S4P`#`R,C8T,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````@("`@("`\+W!R93X*("`@(#PO
M=&0^"B`@/"]T<CX*/"]T86)L93X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T96UP;&%T97,O<V-R:7!T
M+VAE861E<BYI;F,`````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$S,P`Q
M,#0Q-S,V,C<U,``P,C(U-S0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/&@Q(&-L87-S/2)H96%D97(B/@H@(#P_<&AP(&5C
M:&\@7R@B4V-R:7!T(BD@/SX*/"]H,3X*/'1A8FQE('=I9'1H/2(Q,#`E(B!C
M96QL<W!A8VEN9STB,"(^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEN9V\O=&5M<&QA=&5S+W)U;&4O````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``
M,#(P,S(R`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T96UP;&%T97,O
M<G5L92]F:6QT97(N:6YC````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C(T-P`Q,#0Q-S,V,C<U,``P,C(S,#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(#QT<B!S='EL93TB=F5R=&EC86PM86QI
M9VXZ=&]P(CX*/#]P:'`@:68@*"1C;VYD7VYU;2`^(#`I.B`_/@H@(#QT9#X*
M("`@/'-T<F]N9SX\/W!H<"!E8VAO("@D<G5L95LG8V]M8FEN92==(#T]($E.
M1T]?4U1/4D%'15]#3TU"24Y%7T%,3"D@/R!?*")A;F0B*2`Z(%\H(F]R(BD@
M/SX\+W-T<F]N9SX*("`\+W1D/@H\/W!H<"!E;'-E:68@*"@D8V]N9%]N=6T@
M/3T@,"D@)B8@(21L87-T9FEE;&0I.B`_/@H@(#QT9#XF;F)S<#L\+W1D/@H\
M/W!H<"!E;F1I9CL@/SX*("`\=&0^"B`@(#QS96QE8W0@;VYC:&%N9V4](F1O
M8W5M96YT+G)U;&4N<W5B;6ET*"D[(')E='5R;B!T<G5E.R(@;F%M93TB9FEE
M;&1;/#]P:'`@96-H;R`H:6YT*21C;VYD7VYU;2`_/ETB/@H@("`@/#]P:'`@
M96-H;R`D9FEE;&1?<V5L96-T(#\^"B`@(#PO<V5L96-T/@H\/W!H<"!I9B`H
M)&AE861E<E]E;G1R>2DZ(#\^"B`@(#QI;G!U="!N86UE/2)U<V5R:&5A9&5R
M6SP_<&AP(&5C:&\@*&EN="DD8V]N9%]N=6T@/SY=(B!V86QU93TB/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R:&5A9&5R*2`_/B(@+SX*/#]P
M:'`@96YD:68[(#\^"B`@/"]T9#X*/#]P:'`@:68@*"1L87-T9FEE;&0I.B`_
M/@H@(#QT9"!C;VQS<&%N/2(R(CXF;F)S<#L\+W1D/@H\/W!H<"!E;'-E.B`_
M/@H@(#QT9#X*("`@/'-E;&5C="!O;F-H86YG93TB9&]C=6UE;G0N<G5L92YS
M=6)M:70H*3L@<F5T=7)N('1R=64[(B!N86UE/2)M871C:%L\/W!H<"!E8VAO
M("AI;G0I)&-O;F1?;G5M(#\^72(^"B`@("`\/W!H<"!E8VAO("1M871C:%]S
M96QE8W0@/SX*("`@/"]S96QE8W0^"B`@/"]T9#X*("`\=&0^"B`@(#P_<&AP
M(&5C:&\@)&UA=&-H7W9A;'5E(#\^"B`@/"]T9#X*/#]P:'`@96YD:68[(#\^
M"CP_<&AP(&EF("@A)&QA<W1F:65L9"DZ(#\^"B`@/'1D/CP_<&AP(&5C:&\@
M2&]R9&4Z.FQI;FLH)VIA=F%S8W)I<'0Z9&5L971E7V-O;F1I=&EO;B@G("X@
M*&EN="DD8V]N9%]N=6T@+B`G*3LG+"!?*")$96QE=&4@0V]N9&ET:6]N(BDI
M("X@2&]R9&4Z.FEM9R@G9&5L971E+G!N9R<L(%\H(D1E;&5T92!#;VYD:71I
M;VXB*2P@;G5L;"P@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@
M/SX\+V$^/"]T9#X*/#]P:'`@96QS96EF("@D8V]N9%]N=6T@(3T@,"DZ(#\^
M"B`@/'1D/B9N8G-P.SPO=&0^"CP_<&AP(&5N9&EF.R`_/@H@/"]T<CX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;F=O+W1E;7!L871E<R]R=6QE+V9O;W1E<BYI;F,`````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-#`U`#$P-#$W,S8R-S4P`#`R,C,Q
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````@
M("`@("`\+W1A8FQE/@H@("`@/"]T9#X*("`@(#QT9"!W:61T:#TB-#`B(&%L
M:6=N/2)R:6=H="(^"B`@("`@(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6YG
M;R<L("=R=6QE+6UA=&-H97,G*2`_/B9N8G-P.PH@("`@/"]T9#X*("`\+W1R
M/@H*("`\='(@8VQA<W,](FET96TP(CX*("`@(#QT9#X*("`@("`@/&5M/CP_
M<&AP(&5C:&\@7R@B1&\@=&AI<SHB*2`_/CPO96T^"B`@("`@(#QB<B`O/@H@
M("`@("`\<V5L96-T(&]N8VAA;F=E/2)D;V-U;65N="YR=6QE+G-U8FUI="@I
M.R!R971U<FX@=')U93LB(&YA;64])V%C=&EO;B<^"B`@("`@("`@/#]P:'`@
M96-H;R`D86-T:6]N<V5L96-T(#\^"B`@("`@(#PO<V5L96-T/@H@("`@("`\
M/W!H<"!E8VAO("1A8W1I;VYV86QU92`_/@H@("`@/"]T9#X\=&0@=VED=&@]
M(C0P(B!A;&EG;CTB<FEG:'0B/@H@("`@("`\/W!H<"!E8VAO($AE;'`Z.FQI
M;FLH)VEN9V\G+"`G<G5L92UA8W1I;VXG*2`_/B9N8G-P.PH@("`@/"]T9#X*
M("`\+W1R/@H*/#]P:'`@:68@*"1C=7)R96YT7V%C=&EO;BT^9FQA9W,@)B8@
M)&EN9V]?<V-R:7!T+3YI;6%P1FQA9W,H*2DZ(#\^"B`@/'1R(&-L87-S/2)I
M=&5M,"(^"B`@("`\=&0^"B`@("`@(#QE;3X\/W!H<"!E8VAO(%\H(DUA<FL@
M;65S<V%G92!A<SHB*2`_/CPO96T^"B`@("`@(#QB<B`O/@H@("`@("`\=&%B
M;&4@8V5L;'-P86-I;F<](C`B/@H@("`@("`@(#QT<CX*("`@("`@("`@(#QT
M9#X*("`@("`@("`@("`@/&EN<'5T('1Y<&4](F-H96-K8F]X(B!I9#TB<V5E
M;B(@;F%M93TB9FQA9W-;72(@=F%L=64](CP_<&AP(&5C:&\@24Y'3U]35$]2
M04=%7T9,04=?4T5%3B`_/B(\/W!H<"!E8VAO("A)3D=/7U-43U)!1T5?1DQ!
M1U]3145.("8@)')U;&5;)V9L86=S)UTI(#\@)R!C:&5C:V5D/2)C:&5C:V5D
M(B`G(#H@)R<@/SXO/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=S965N)RP@
M7R@B4V5E;B(I*2`_/B9N8G-P.PH@("`@("`@("`@/"]T9#X\=&0^"B`@("`@
M("`@("`@(#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@:60](FEM<&]R=&%N="(@
M;F%M93TB9FQA9W-;72(@=F%L=64](CP_<&AP(&5C:&\@24Y'3U]35$]204=%
M7T9,04=?1DQ!1T=%1"`_/B(\/W!H<"!E8VAO("A)3D=/7U-43U)!1T5?1DQ!
M1U]&3$%'1T5$("8@)')U;&5;)V9L86=S)UTI(#\@)R!C:&5C:V5D/2)C:&5C
M:V5D(B`G(#H@)R<@/SXO/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=I;7!O
M<G1A;G0G+"!?*"));7!O<G1A;G0B*2D@/SXF;F)S<#L*("`@("`@("`@(#PO
M=&0^/'1D/@H@("`@("`@("`@("`\:6YP=70@='EP93TB8VAE8VMB;W@B(&ED
M/2)A;G-W97)E9"(@;F%M93TB9FQA9W-;72(@=F%L=64](CP_<&AP(&5C:&\@
M24Y'3U]35$]204=%7T9,04=?04Y35T52140@/SXB/#]P:'`@96-H;R`H24Y'
M3U]35$]204=%7T9,04=?04Y35T52140@)B`D<G5L95LG9FQA9W,G72D@/R`G
M(&-H96-K960](F-H96-K960B("<@.B`G)R`_/B\^/#]P:'`@96-H;R!(;W)D
M93HZ;&%B96PH)V%N<W=E<F5D)RP@7R@B06YS=V5R960B*2D@/SXF;F)S<#L*
M("`@("`@("`@(#PO=&0^/'1D/@H@("`@("`@("`@("`\:6YP=70@='EP93TB
M8VAE8VMB;W@B(&ED/2)D96QE=&5D(B!N86UE/2)F;&%G<UM=(B!V86QU93TB
M/#]P:'`@96-H;R!)3D=/7U-43U)!1T5?1DQ!1U]$14Q%5$5$(#\^(CP_<&AP
M(&5C:&\@*$E.1T]?4U1/4D%'15]&3$%'7T1%3$54140@)B`D<G5L95LG9FQA
M9W,G72D@/R`G(&-H96-K960](F-H96-K960B("<@.B`G)R`_/B\^/#]P:'`@
M96-H;R!(;W)D93HZ;&%B96PH)V1E;&5T960G+"!?*")$96QE=&5D(BDI(#\^
M)FYB<W`["B`@("`@("`@("`\+W1D/@H@("`@("`@(#PO='(^"B`@("`@(#PO
M=&%B;&4^"B`@("`\+W1D/@H@("`@/'1D('=I9'1H/2(T,"(@86QI9VX](G)I
M9VAT(CX*("`@("`@/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;F=O)RP@)W)U
M;&4M;6%R:R<I(#\^)FYB<W`["B`@("`\+W1D/@H@(#PO='(^"CP_<&AP(&5N
M9&EF.R`_/@H*/#]P:'`@:68@*"1I;F=O7W-C<FEP="T^<W1O<%-C<FEP="@I
M*3H@/SX*("`\='(@8VQA<W,](FET96TQ(CX*("`@(#QT9"!A;&EG;CTB;&5F
M="(^"B`@("`@(#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB<W1O<"(@
M=F%L=64](C$B/#]P:'`@96-H;R`H)')U;&5;)W-T;W`G72D@/R`G(&-H96-K
M960](F-H96-K960B)R`Z("<G(#\^("\^(#P_<&AP(&5C:&\@7R@B4W1O<"!C
M:&5C:VEN9R!I9B!T:&ES(')U;&4@;6%T8VAE<S\B*2`_/@H@("`@/"]T9#X*
M("`@(#QT9"!W:61T:#TB-#`B(&%L:6=N/2)R:6=H="(^"B`@("`@(#P_<&AP
M(&5C:&\@2&5L<#HZ;&EN:R@G:6YG;R<L("=R=6QE+7-T;W`G*2`_/B9N8G-P
M.PH@("`@/"]T9#X*("`\+W1R/@H\/W!H<"!E;F1I9CL@/SX*"B`@/'1R/@H@
M("`@/'1D(&-L87-S/2)C;VYT<F]L(B!C;VQS<&%N/2(R(CX*("`@("`@/&EN
M<'5T(&-L87-S/2)B=71T;VXB('1Y<&4](F)U='1O;B(@;VYC;&EC:STB9&]C
M=6UE;G0N<G5L92YA8W1I;VY)1"YV86QU93TG<G5L95]S879E)SMD;V-U;65N
M="YR=6QE+G-U8FUI="@I.R!R971U<FX@=')U93LB('9A;'5E/2(F;F)S<#L\
M/W!H<"!E8VAO(%\H(E-A=F4B*2`_/B9N8G-P.R(@+SX*("`@("`@/&EN<'5T
M(&-L87-S/2)B=71T;VXB('1Y<&4](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE
M;G0N;&]C871I;VXN:')E9CTG/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)V9I;'1E<G,N<&AP)RP@=')U92D@/SXG(B!V86QU93TB/#]P:'`@
M96-H;R!?*")2971U<FX@=&\@1FEL=&5R<R!,:7-T(BD@/SXB("\^"B`@("`\
M+W1D/@H@(#PO='(^"CPO=&%B;&4^"CPO9F]R;3X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&5M
M<&QA=&5S+W)U;&4O:&5A9&5R+FEN8P``````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#0Q-#(`,3`T,3<S-C(W-3``,#(R,C0S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP("1R=6QE7W5R;"`]
M($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<G5L92YP:'`G*3L*("`@(&EF("@A
M:7-?;G5L;"@D961I=%]N=6UB97(I*2!["B`@("`@("`@)')U;&5?=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1R=6QE7W5R;"P@)V5D:70G+"`D961I=%]N
M=6UB97(I.PH@("`@?0H_/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP
M="(^"CPA+2T*9G5N8W1I;VX@9&5L971E7V-O;F1I=&EO;BAN=6TI"GL*("`@
M(&1O8W5M96YT+G)U;&4N86-T:6]N240N=F%L=64@/2`G<G5L95]D96QE=&4G
M.PH@("`@9&]C=6UE;G0N<G5L92YC;VYD:71I;VYN=6UB97(N=F%L=64@/2!N
M=6T["B`@("!D;V-U;65N="YR=6QE+G-U8FUI="@I.PH@("`@<F5T=7)N('1R
M=64["GT*+R\M+3X*/"]S8W)I<'0^"@H\9F]R;2!M971H;V0](G!O<W0B(&YA
M;64](G)U;&4B(&%C=&EO;CTB/#]P:'`@96-H;R`D<G5L95]U<FP@/SXB/@H\
M/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)R=6QE7W5P9&%T92(@+SX*/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB8V]N9&ET:6]N;G5M8F5R(B!V86QU
M93TB+3$B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FYE=U]F;VQD
M97)?;F%M92(@=F%L=64](B(@+SX*"CQD:78@8VQA<W,](FAE861E<B(^"B`\
M/W!H<"!E8VAO(%\H(D9I;'1E<B!2=6QE(BD@/SX*(#P_<&AP(&EF("@A96UP
M='DH)')U;&5;)V1I<V%B;&4G72DI.B`_/EL\<W!A;B!S='EL93TB9F]R;2UE
M<G)O<B(^/#]P:'`@96-H;R!?*")$:7-A8FQE9"(I(#\^/"]S<&%N/ET\/W!H
M<"!E;F1I9CL@/SX*(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6YG;R<L("=R
M=6QE)RD@/SX*/"]D:78^"@H\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C
M:6YG/2(P(CX*("`\='(@8VQA<W,](F-O;G1R;VPB/@H@("`@/'1D/@H@("`@
M("`\/W!H<"!E8VAO(%\H(E)U;&4@3F%M92(I(#\^(#H@/&EN<'5T(&-L87-S
M/2)I;G!U="(@;F%M93TB;F%M92(@<VEZ93TB-3`B('9A;'5E/2(\/W!H<"!E
M8VAO("AI<W-E="@D<G5L95LG;F%M92==*2D@/R`D<G5L95LG;F%M92==(#H@
M)R<@/SXB("\^"B`@("`\+W1D/@H@("`@/'1D('=I9'1H/2(T,"(@8VQA<W,]
M(G)I9VAT06QI9VXB/@H@("`@("`\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEN
M9V\G+"`G<G5L92UN86UE)RD@/SXF;F)S<#L*("`@(#PO=&0^"B`@/"]T<CX*
M"B`@/'1R(&-L87-S/2)I=&5M,"(^"B`@("`\=&0^"B`@("`@(#QE;3X\/W!H
M<"!E8VAO(%\H(D9O<B!A;B!I;F-O;6EN9R!M97-S86=E('1H870@;6%T8VAE
M<SHB*2`_/CPO96T^"B`@("`@(#QB<B`O/@H@("`@("`\:6YP=70@:60](F%L
M;"(@;VYC;&EC:STB9&]C=6UE;G0N<G5L92YS=6)M:70H*3L@<F5T=7)N('1R
M=64[(B!T>7!E/2)R861I;R(@;F%M93TB8V]M8FEN92(@=F%L=64](CP_<&AP
M(&5C:&\@24Y'3U]35$]204=%7T-/34))3D5?04Q,(#\^(CP_<&AP(&5C:&\@
M*"1R=6QE6R=C;VUB:6YE)UT@/3T@24Y'3U]35$]204=%7T-/34))3D5?04Q,
M*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\/W!H<"!E8VAO
M($AO<F1E.CIL86)E;"@G86QL)RP@7R@B06QL(&]F('1H92!F;VQL;W=I;F<B
M*2D@/SXF;F)S<#L*("`@("`@/&EN<'5T(&ED/2)A;GDB(&]N8VQI8VL](F1O
M8W5M96YT+G)U;&4N<W5B;6ET*"D[(')E='5R;B!T<G5E.R(@='EP93TB<F%D
M:6\B(&YA;64](F-O;6)I;F4B('9A;'5E/2(\/W!H<"!E8VAO($E.1T]?4U1/
M4D%'15]#3TU"24Y%7T%.62`_/B(\/W!H<"!E8VAO("@D<G5L95LG8V]M8FEN
M92==(#T]($E.1T]?4U1/4D%'15]#3TU"24Y%7T%.62D@/R`G(&-H96-K960]
M(F-H96-K960B)R`Z("<G(#\^("\^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH
M)V%N>2<L(%\H(D%N>2!O9B!T:&4@9F]L;&]W:6YG(BDI(#\^"B`@("`\+W1D
M/@H@("`@/'1D('=I9'1H/2(T,"(@8VQA<W,](G)I9VAT06QI9VXB/@H@("`@
M("`\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEN9V\G+"`G<G5L92UC;VUB:6YE
M)RD@/SXF;F)S<#L*("`@(#PO=&0^"B`@/"]T<CX*"B`@/'1R(&-L87-S/2)I
M=&5M,"(^"B`@("`\=&0^"B`@("`@(#QT86)L92!W:61T:#TB,3`P)2(@8V5L
M;'-P86-I;F<](C`B/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEN9V\O=&5M<&QA=&5S+V9I;'1E<G,O````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``,#(Q,#(S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T96UP;&%T97,O9FEL=&5R<R]F
M:6QT97(N:'1M;```````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,S,P`Q,#0Q
M-S,V,C<U,``P,C,Q-S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/&QO;W`Z9FEL=&5R/@H\='(^"B`\=&0^"B`@/'1A9SIF
M:6QT97(N961I=&QI;FL@+SX\=&%G.F9I;'1E<BYE9&ET:6UG("\^/"]A/@H\
M:68Z9FEL=&5R+F1E;&QI;FL^"B`@/'1A9SIF:6QT97(N9&5L;&EN:R`O/CQT
M86<Z9FEL=&5R+F1E;&EM9R`O/CPO83X*/"]I9CIF:6QT97(N9&5L;&EN:SX*
M/&EF.F9I;'1E<BYC;W!Y;&EN:SX*("`\=&%G.F9I;'1E<BYC;W!Y;&EN:R`O
M/CQT86<Z9FEL=&5R+F-O<'EI;6<@+SX\+V$^"CPO:68Z9FEL=&5R+F-O<'EL
M:6YK/@H@/"]T9#X*(#QT9#X*("`\<W1R;VYG/CQT86<Z9FEL=&5R+FYU;6)E
M<B`O/BXF;F)S<#L\:68Z9FEL=&5R+F9I;'1E<FEM9SX\=&%G.F9I;'1E<BYF
M:6QT97)I;6<@+SXF;F)S<#LF;F)S<#L\+VEF.F9I;'1E<BYF:6QT97)I;6<^
M/'1A9SIF:6QT97(N9&5S8W)I<&QI;FL@+SX\+V$^/"]S=')O;F<^)FYB<W`[
M/&EF.F9I;'1E<BYE;F%B;&5L:6YK/CQS=')O;F<^6SQT86<Z9FEL=&5R+F5N
M86)L96QI;FL@+SX\<W!A;B!S='EL93TB8V]L;W(Z<F5D(CX\9V5T=&5X=#YD
M:7-A8FQE9"`M(&-L:6-K('1O(&5N86)L93PO9V5T=&5X=#X\+W-P86X^/"]A
M/ET\+W-T<F]N9SX\+VEF.F9I;'1E<BYE;F%B;&5L:6YK/@H@/"]T9#X*(#QT
M9"!A;&EG;CTB8V5N=&5R(CX*("`\:68Z9FEL=&5R+F1I<V%B;&5L:6YK/CQT
M86<Z9FEL=&5R+F1I<V%B;&5L:6YK("\^/'1A9SIF:6QT97(N9&ES86)L96EM
M9R`O/CPO83X\+VEF.F9I;'1E<BYD:7-A8FQE;&EN:SX\:68Z9FEL=&5R+F5N
M86)L96QI;FL^/'1A9SIF:6QT97(N96YA8FQE;&EN:R`O/CQT86<Z9FEL=&5R
M+F5N86)L96EM9R`O/CPO83X\+VEF.F9I;'1E<BYE;F%B;&5L:6YK/@H@/"]T
M9#X*(#QT9"!A;&EG;CTB<FEG:'0B(&-L87-S/2)N;W=R87`B/@H@(#QI9CIF
M:6QT97(N=7!L:6YK/CQT86<Z9FEL=&5R+G5P;&EN:R`O/CQT86<Z=7!?:6UG
M("\^/"]A/CPO:68Z9FEL=&5R+G5P;&EN:SX*("`\:68Z9FEL=&5R+F1O=VYL
M:6YK/CQT86<Z9FEL=&5R+F1O=VYL:6YK("\^/'1A9SID;W=N7VEM9R`O/CPO
M83X\+VEF.F9I;'1E<BYD;W=N;&EN:SX*("`\9V5T=&5X=#Y4;SH\+V=E='1E
M>'0^)FYB<W`[/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C(B(&]N8VAA;F=E
M/2)M;W9E1G)O;51O*#QT86<Z9FEL=&5R+FYU;6)E<B`O/BP@=&AI<RYV86QU
M92P@)SQT86<Z9FEL=&5R+G5P=7)L("\^)RP@)SQT86<Z9FEL=&5R+F1O=VYU
M<FP@+SXG*3LB+SX*(#PO=&0^"CPO='(^"CPO;&]O<#IF:6QT97(^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;F=O+W1E;7!L871E<R]F:6QT97)S+V9I;'1E<BUN;VYE+FEN8P``````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,C(R`#$P-#$W,S8R-S4P`#`R,S<S,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\='(^"B`\=&0@
M8V]L<W!A;CTB-"(@8VQA<W,](G1E>'0B/@H@(#QE;3X\/W!H<"!P<FEN=&8H
M7R@B3F\@9FEL=&5R<RX@0VQI8VL@7"(E<UPB('1O(&-R96%T92!A(&YE=R!F
M:6QT97(N(BDL(%\H(DYE=R!2=6QE(BDI(#\^/"]E;3X*(#PO=&0^"CPO='(^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T96UP;&%T
M97,O9FEL=&5R<R]S971T:6YG<RYI;F,`````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S,R-0`Q,#0Q-S,V,C<U,``P,C,S-38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`@)&9L86=S7W9A;"`]("1P
M<F5F<RT^9V5T5F%L=64H)V9I;'1E<E]S965N)RD@/SX*/&9O<FT@;65T:&]D
M/2)P;W-T(B!N86UE/2)F:6QT97)S971T:6YG<R(@86-T:6]N/2)F:6QT97)S
M+G!H<"(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](G-E='1I;F=S7W-A
M=F4B/@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(%\H(D%D9&ET
M:6]N86P@4V5T=&EN9W,B*2`_/@H\+V@Q/@H*/'1A8FQE('=I9'1H/2(Q,#`E
M(B!C96QL<W!A8VEN9STB,"(^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)I=&5M
M(B!A;&EG;CTB;&5F="(^"B`@("`@(#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@
M;F%M93TB<VAO=U]F:6QT97)?;7-G(CP_<&AP(&EF("@D<')E9G,M/F=E=%9A
M;'5E*"=S:&]W7V9I;'1E<E]M<V<G*2D@96-H;R`G(&-H96-K960](F-H96-K
M960B)R`_/B`O/B9N8G-P.PH@("`@("`\/W!H<"!E8VAO(%\H(D1I<W!L87D@
M9&5T86EL960@;F]T:69I8V%T:6]N('=H96X@96%C:"!F:6QT97(@:7,@87!P
M;&EE9#\B*2`_/@H@("`@/"]T9#X\=&0@8VQA<W,](FET96TB(&%L:6=N/2)R
M:6=H="(@=VED=&@](C$E(CX*("`@("`@/#]P:'`@96-H;R!(96QP.CIL:6YK
M*"=I;F=O)RP@)W!R968M<VAO=U]F:6QT97)?;7-G)RD@/SX*("`@(#PO=&0^
M"B`@/"]T<CX\='(^"B`@("`\=&0@8VQA<W,](FET96TB(&%L:6=N/2)L969T
M(B!W:61T:#TB.3DE(CX\/W!H<"!E8VAO(%\H(D9I;'1E<B!/<'1I;VYS(BD@
M/SXF;F)S<#L*("`@("`@/'-E;&5C="!I9#TB9FEL=&5R7W-E96XB(&YA;64]
M(F9I;'1E<E]S965N(CX*("`@("`@("`\;W!T:6]N('9A;'5E/2(P(CP_<&AP
M(&EF("AE;7!T>2@D9FQA9W-?=F%L*2D@96-H;R`G('-E;&5C=&5D/2)S96QE
M8W1E9"(G(#\^/CP_<&AP(&5C:&\@7R@B1FEL=&5R($%L;"!-97-S86=E<R(I
M(#\^/"]O<'1I;VX^"B`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H
M;R!)3D=/7U-#4DE05%]&24Q415)?54Y3145.(#\^(CP_<&AP(&EF("@D9FQA
M9W-?=F%L(#T]($E.1T]?4T-225!47T9)3%1%4E]53E-%14XI(&5C:&\@)R!S
M96QE8W1E9#TB<V5L96-T960B)R`_/CX\/W!H<"!E8VAO(%\H(D9I;'1E<B!/
M;FQY(%5N<V5E;B!-97-S86=E<R(I(#\^/"]O<'1I;VX^"B`@("`@("`@/&]P
M=&EO;B!V86QU93TB/#]P:'`@96-H;R!)3D=/7U-#4DE05%]&24Q415)?4T5%
M3B`_/B(\/W!H<"!I9B`H)&9L86=S7W9A;"`]/2!)3D=/7U-#4DE05%]&24Q4
M15)?4T5%3BD@96-H;R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^/CP_<&AP
M(&5C:&\@7R@B1FEL=&5R($]N;'D@4V5E;B!-97-S86=E<R(I(#\^/"]O<'1I
M;VX^"B`@("`@(#PO<V5L96-T/@H@("`@/"]T9#X\=&0@8VQA<W,](FET96TB
M(&%L:6=N/2)R:6=H="(@=VED=&@](C$E(CX*("`@("`@/#]P:'`@96-H;R!(
M96QP.CIL:6YK*"=I;F=O)RP@)W!R968M9FEL=&5R7W-E96XG*2`_/@H@("`@
M/"]T9#X*("`\+W1R/CQT<CX*("`@(#QT9"!C;VQS<&%N/2(R(B!C;&%S<STB
M8V]N=')O;"(^"B`@("`@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)B
M=71T;VXB(&]N8VQI8VL](F1O8W5M96YT+F9I;'1E<G-E='1I;F=S+G-U8FUI
M="@I.R!R971U<FX@=')U93LB('9A;'5E/2(F;F)S<#L\/W!H<"!E8VAO(%\H
M(E-A=F4@4V5T=&EN9W,B*2`_/B9N8G-P.R(^"B`@("`\+W1D/@H@(#PO='(^
M"CPO=&%B;&4^"CPO9F]R;3X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&5M<&QA=&5S+V9I
M;'1E<G,O9F]O=&5R+FEN8P``````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P
M,C$`,3`T,3<S-C(W-3``,#(S,#`S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#PO=&%B;&4^"CP_<&AP(&EF("@D8W)E871E
M<G5L92!\?"`D8V%N87!P;'DI.B`_/@H\9&EV(&-L87-S/2)C;VYT<F]L(B!S
M='EL93TB<&%D9&EN9SHR<'@B/@H\/W!H<"!I9B`H)&-R96%T97)U;&4I.B`_
M/@H@/&EN<'5T(&-L87-S/2)B=71T;VXB('1Y<&4](F)U='1O;B(@;VYC;&EC
M:STB=VEN9&]W+FQO8V%T:6]N/2<\/W!H<"!E8VAO(&%D9'-L87-H97,H)')U
M;&5?=7)L*2`_/B<B('9A;'5E/2(F;F)S<#L\/W!H<"!E8VAO(%\H(DYE=R!2
M=6QE(BD@/SXF;F)S<#LB("\^"CP_<&AP(&5N9&EF.R!I9B`H)&-A;F%P<&QY
M*3H@/SX*(#QI;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)B=71T;VXB(&]N
M8VQI8VL](F1O8W5M96YT+F9I;'1E<G,N86-T:6]N240N=F%L=64])V%P<&QY
M7V9I;'1E<G,G.V1O8W5M96YT+F9I;'1E<G,N<W5B;6ET*"D[(')E='5R;B!T
M<G5E.R(@=F%L=64](B9N8G-P.SP_<&AP(&5C:&\@7R@B07!P;'D@1FEL=&5R
M<R(I(#\^)FYB<W`[(CX*/#]P:'`@96YD:68[(&5N9&EF.R`_/@H\+V1I=CX*
M/"]F;W)M/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&5M<&QA
M=&5S+V9I;'1E<G,O:F%V87-C<FEP="YI;F,`````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$S-38`,3`T,3<S-C(W-3``,#(S-C8V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO;B!T;V=G;&52;W<H*0I["B`@("!I
M9B`H(61O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*2!["B`@("`@("`@
M<F5T=7)N.PH@("`@?0H*("`@('1A8FQE<R`](&1O8W5M96YT+F=E=$5L96UE
M;G1S0GE486=.86UE*"=T86)L92<I.PH@("`@9F]R("AI(#T@,#L@:2`\('1A
M8FQE<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AT86)L97-;:5TN8VQA
M<W-.86UE+FEN9&5X3V8H)W-T<FEP960G*2`A/2`M,2D@>PH@("`@("`@("`@
M("!V87(@=')S(#T@=&%B;&5S6VE=+F=E=$5L96UE;G1S0GE486=.86UE*"=T
M<B<I.PH@("`@("`@("`@("!F;W(@*'9A<B!J(#T@,#L@:B`\('1R<RYL96YG
M=&@[(&HK*RD@>PH@("`@("`@("`@("`@("`@=')S6VI=+F]N;6]U<V5O=F5R
M/69U;F-T:6]N*"E["B`@("`@("`@("`@("`@("`@("`@=&AI<RYC;&%S<TYA
M;64@*ST@)R!S96QE8W1E9"<[(')E='5R;B!F86QS90H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@=')S6VI=+F]N;6]U<V5O=70]9G5N8W1I
M;VXH*7L*("`@("`@("`@("`@("`@("`@("!T:&ES+F-L87-S3F%M92`]('1H
M:7,N8VQA<W-.86UE+G)E<&QA8V4H)W-E;&5C=&5D)RP@)R<I.R!R971U<FX@
M9F%L<V4*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*?0IW:6YD;W<N;VYL;V%D(#T@=&]G9VQE4F]W.PHO+R`M+3X*
M/"]S8W)I<'0^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O
M=&5M<&QA=&5S+V9I;'1E<G,O:&5A9&5R+FEN8P``````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$U-S<`,3`T,3<S-C(W-3``,#(R-S4U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO;B!M;W9E1G)O;51O*&9R
M;VTL('1O+"!U<'5R;"P@9&]W;G5R;"D*>PH@("`@=F%R('-T97!S(#T@=&\@
M+2!F<F]M.PH@("`@:68@*'-T97!S(#P@,"D@>PH@("`@("`@('=I;F1O=RYL
M;V-A=&EO;B`]('5P=7)L("L@)R9S=&5P<STG("L@+7-T97!S.PH@("`@?2!E
M;'-E(&EF("AS=&5P<R`^(#`I('L*("`@("`@("!W:6YD;W<N;&]C871I;VX@
M/2!D;W=N=7)L("L@)R9S=&5P<STG("L@<W1E<',["B`@("!]"B`@("!R971U
M<FX@=')U93L*?0HO+RTM/@H\+W-C<FEP=#X*/&9O<FT@;65T:&]D/2)P;W-T
M(B!N86UE/2)F:6QT97)S(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=F:6QT97)S+G!H<"<I(#\^(CX*/#]P:'`@571I;#HZ
M<&9O<FU);G!U="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C
M=&EO;DE$(B!V86QU93TB(B`O/@H\9&EV(&-L87-S/2)H96%D97(B/@H@(#QU
M;#X*("`@(#QL:3X\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEN9V\G+"`G9FEL
M=&5R<U]R=6QE<R<I(#\^/"]L:3X*("`\+W5L/@H@(#P_<&AP(&5C:&\@7R@B
M17AI<W1I;F<@4G5L97,B*2`_/@H\+V1I=CX*/'1A8FQE('=I9'1H/2(Q,#`E
M(B!C96QL<W!A8VEN9STB,"(@8VQA<W,](G-T<FEP960B/@H@(#QT<B!C;&%S
M<STB8V]N=')O;"(^"B`@("`\=&@@=VED=&@](C@P(CX\/W!H<"!E8VAO(%\H
M(D5D:70B*2`_/CPO=&@^"B`@("`\=&@^/#]P:'`@96-H;R!?*")2=6QE(BD@
M/SX\+W1H/@H@("`@/'1H('=I9'1H/2(U,"(^/#]P:'`@96-H;R!?*")%;F%B
M;&5D(BD@/SX\+W1H/@H@("`@/'1H('=I9'1H/2(Q,C`B/CP_<&AP(&5C:&\@
M7R@B36]V92(I(#\^/"]T:#X*("`\+W1R/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEN9V\O=&5M<&QA=&5S+V9O<G=A<F0O````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``,#(Q,#$W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T96UP;&%T97,O9F]R=V%R9"]F;W)W
M87)D+FEN8P``````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(V-``Q,#0Q-S,V
M,C<U,``P,C,Q-C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)I;F=O7V9O<G=A
M<F0B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)V9O<G=A<F0N<&AP)RD@/SXB/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@
M/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E
M/2)U<&1A=&4B("\^"CQD:78@8VQA<W,](FAE861E<B(^"B`@/'5L/@H@("`@
M/&QI/CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6YG;R<L("=F;W)W87)D)RD@
M/SX\+VQI/@H@(#PO=6P^"B`@/#]P:'`@96-H;R!?*")&;W)W87)D(BD@/SX*
M/#]P:'`@:68@*"%E;7!T>2@D9G=D7W)U;&5;)V1I<V%B;&4G72DI.B`_/@H@
M("9N8G-P.UL\9F]N="!C;VQO<CTB<F5D(CX\/W!H<"!E8VAO(%\H(D1I<V%B
M;&5D(BD@/SX\+V9O;G0^70H\/W!H<"!E;F1I9CL@/SX*/"]D:78^"CQT86)L
M92!C96QL<W!A8VEN9STB,"(@8V5L;'!A9&1I;F<](C`B/@H@(#QT<B!C;&%S
M<STB:71E;3`B/@H@("`@/'1D('-T>6QE/2)P861D:6YG.C5P>"(@86QI9VX]
M(FQE9G0B/@H@("`@("`\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](FME
M97!?8V]P>2(@:60](FME97!?8V]P>2(@=F%L=64](C$B/#]P:'`@:68@*"1F
M;W)W87)D+3YG971&;W)W87)D2V5E<"@I*2!E8VAO("<@8VAE8VME9#TB8VAE
M8VME9"(G(#\^("\^"B`@("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=K
M965P7V-O<'DG+"!?*")?2V5E<"!A(&-O<'D@;V8@;65S<V%G97,@:6X@=&AI
M<R!A8V-O=6YT/R(I*2`_/@H@("`@/"]T9#X*("`@(#QT9"!W:61T:#TB-#`B
M(&%L:6=N/2)R:6=H="(^"B`@("`@(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G
M:6YG;R<L("=F;W)W87)D+6ME97!C;W!Y)RD@/SXF;F)S<#L*("`@(#PO=&0^
M"B`@/"]T<CX\='(@8VQA<W,](FET96TQ(CX*("`@(#QT9"!S='EL93TB<&%D
M9&EN9SHU<'@B(&%L:6=N/2)L969T(CX*("`@("`@/#]P:'`@96-H;R!(;W)D
M93HZ;&%B96PH)V%D9')E<W-E<R<L(%\H(E]!9&1R97-S*&5S*2!T;R!F;W)W
M87)D('1O.B(I*2`_/@H@("`@("`\8G(@+SX*("`@("`@/'1E>'1A<F5A(&YA
M;64](F%D9')E<W-E<R(@:60](F%D9')E<W-E<R(@<F]W<STB-2(@8V]L<STB
M-#`B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RAI;7!L;V1E*")<;B(L
M("1F;W)W87)D+3YG971&;W)W87)D061D<F5S<V5S*"DI*2`_/CPO=&5X=&%R
M96$^"B`@("`\+W1D/@H@("`@/'1D('=I9'1H/2(T,"(@86QI9VX](G)I9VAT
M(CX*("`@("`@/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;F=O)RP@)V9O<G=A
M<F0M861D<F5S<V5S)RD@/SXF;F)S<#L*("`@(#PO=&0^"B`@/"]T<CX\='(@
M8VQA<W,](F-O;G1R;VPB/@H@("`@/'1D(&-O;'-P86X](C(B(&-L87-S/2)C
M;VYT<F]L(CX*("`@("`@/&EN<'5T(&-L87-S/2)B=71T;VXB('1Y<&4](G-U
M8FUI="(@=F%L=64](B9N8G-P.SP_<&AP(&5C:&\@7R@B4V%V92(I(#\^)FYB
M<W`[(B`O/@H@("`@("`\:6YP=70@8VQA<W,](F)U='1O;B(@='EP93TB8G5T
M=&]N(B!O;F-L:6-K/2)D;V-U;65N="YL;V-A=&EO;BYH<F5F/2<\/W!H<"!E
M8VAO(&%D9'-L87-H97,H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=F:6QT97)S
M+G!H<"<L('1R=64I*2`_/B<B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E='5R
M;B!T;R!2=6QE<R!,:7-T(BD@/SXB("\^"B`@("`\+W1D/@H@(#PO='(^"CPO
M=&%B;&4^"CPO9F]R;3X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEN9V\O=&5M<&QA=&5S+W=H:71E;&ES="\`````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``
M,#(Q,S8W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T96UP;&%T97,O
M=VAI=&5L:7-T+W=H:71E;&ES="YI;F,`````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C,P-0`Q,#0Q-S,V,C<U,``P,C0P-S,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE
M/2)F:6QT97)S(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=W:&ET96QI<W0N<&AP)RD@/SXB/@H\/W!H<"!5=&EL.CIP9F]R
M;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N
M240B('9A;'5E/2)R=6QE7W5P9&%T92(@+SX*/&1I=B!C;&%S<STB:&5A9&5R
M(CX*("`\=6P^"B`@("`\;&D^/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;F=O
M)RP@)W=H:71E;&ES="<I(#\^/"]L:3X*("`\+W5L/@H@(#P_<&AP(&5C:&\@
M7R@B5VAI=&5L:7-T(BD@/SX*/#]P:'`@:68@*"%E;7!T>2@D=VQ?<G5L95LG
M9&ES86)L92==*2DZ(#\^"B`@)FYB<W`[6SQF;VYT(&-O;&]R/2)R960B/CP_
M<&AP(&5C:&\@7R@B1&ES86)L960B*2`_/CPO9F]N=#Y="CP_<&AP(&5N9&EF
M.R`_/@H\+V1I=CX*/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!C96QL<&%D9&EN
M9STB,"(^"B`@/'1R(&-L87-S/2)I=&5M,"(^"B`@("`\=&0@86QI9VX](FQE
M9G0B/@H@("`@("`\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G=VAI=&5L:7-T
M)RP@7R@B5VA?:71E;&ES="!A9&1R97-S97,Z(BDI(#\^/&)R("\^"B`@("`@
M(#QT97AT87)E82!N86UE/2)W:&ET96QI<W0B(&ED/2)W:&ET96QI<W0B(')O
M=W,](C$U(B!C;VQS/2(X,"(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*&EM<&QO9&4H(EQN(BP@)'=H:71E;&ES="T^9V5T5VAI=&5L:7-T*"DI*2`_
M/CPO=&5X=&%R96$^"B`@("`\+W1D/CQT9"!A;&EG;CTB<FEG:'0B/@H@("`@
M("`\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEN9V\G+"`G=VAI=&5L:7-T+6%D
M9')E<W-E<R<I(#\^)FYB<W`["B`@("`\+W1D/@H@(#PO='(^/'1R/@H@("`@
M/'1D(&-O;'-P86X](C(B(&-L87-S/2)C;VYT<F]L(CX*("`@("`@/&EN<'5T
M(&-L87-S/2)B=71T;VXB('1Y<&4](G-U8FUI="(@=F%L=64](B9N8G-P.SP_
M<&AP(&5C:&\@7R@B4V%V92(I(#\^)FYB<W`[(B`O/@H@("`@("`\:6YP=70@
M8VQA<W,](F)U='1O;B(@='EP93TB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N
M="YL;V-A=&EO;BYH<F5F/2<\/W!H<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G9FEL=&5R<RYP:'`G+"!T<G5E*2`_/B<B('9A;'5E/2(\/W!H<"!E
M8VAO(%\H(E)E='5R;B!T;R!2=6QE<R!,:7-T(BD@/SXB("\^"B`@("`\+W1D
M/@H@(#PO='(^"CPO=&%B;&4^"CPO9F]R;3X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;F=O+W1E;7!L871E<R]J879A<V-R:7!T+P``````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4P`#`R,34R
M,0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;F5W7V9O;&1E<BYJ<P``````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W,C8`
M,3`T,3<S-C(W-3``,#(T,C`U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````&9U;F-T:6]N(&YE=T9O;&1E<DYA;64H;F%M92D*
M>PH@("`@=F%R(&9O<FT@/2!D;V-U;65N="YG971%;&5M96YT<T)Y3F%M92AN
M86UE*3L*"B`@("!I9B`H9F]R;5LP72YA8W1I;VYV86QU92YS96QE8W1E9$EN
M9&5X(#T](#$I>PH@("`@("`@('9A<B!F;VQD97(@/2!W:6YD;W<N<')O;7!T
M*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE87-E(&5N=&5R('1H92!N
M86UE(&]F('1H92!N97<@9F]L9&5R.B(I*2`_/EQN)RP@)R<I.PH*("`@("`@
M("!I9B`H*&9O;&1E<B`A/2!N=6QL*2`F)B`H9F]L9&5R("$]("<G*2D@>PH@
M("`@("`@("`@("!F;W)M6S!=+F%C=&EO;DE$+G9A;'5E(#T@)V-R96%T95]F
M;VQD97(G.PH@("`@("`@("`@("!F;W)M6S!=+FYE=U]F;VQD97)?;F%M92YV
M86QU92`](&9O;&1E<CL*("`@("`@("`@("`@9F]R;5LP72YS=6)M:70H*3L*
M("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N('1R=64["GT*````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;F=O+W1E;7!L871E<R]V86-A=&EO;B\`````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4P
M`#`R,3$U-P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&5M<&QA=&5S
M+W9A8V%T:6]N+W9A8V%T:6]N+FEN8P``````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#8Q-#0`,3`T,3<S-C(W-3``,#(S-#8P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M
M93TB=F%C871I;VXB(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)W9A8V%T:6]N+G!H<"<I(#\^(CX*/#]P:'`@571I;#HZ<&9O
M<FU);G!U="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO
M;DE$(B!V86QU93TB<G5L95]U<&1A=&4B("\^"CQH,2!C;&%S<STB:&5A9&5R
M(CX*(#P_<&AP(&5C:&\@7R@B5F%C871I;VXB*2`_/@H@/#]P:'`@:68@*"%E
M;7!T>2@D=F%C7W)U;&5;)V1I<V%B;&4G72DI.B`_/EL\<W!A;B!C;&%S<STB
M9F]R;2UE<G)O<B(^/#]P:'`@96-H;R!?*")$:7-A8FQE9"(I(#\^/"]S<&%N
M/ET\/W!H<"!E;F1I9CL@/SX*(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6YG
M;R<L("=V86-A=&EO;B<I(#\^"CPO:#$^"@H\=&%B;&4@=VED=&@](C$P,"4B
M(&-E;&QS<&%C:6YG/2(P(CX*("`\='(@8VQA<W,](FET96TP(CX*("`@(#QT
M9#X*("`@("`@/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)V%D9')E<W-E<R<L
M(%\H(E]->2!E;6%I;"!A9&1R97-S97,Z(BDI(#\^"B`@("`@(#QB<B`O/@H@
M("`@("`\=&5X=&%R96$@;F%M93TB861D<F5S<V5S(B!I9#TB861D<F5S<V5S
M(B!R;W=S/2(U(B!C;VQS/2(T,"(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*&EM<&QO9&4H(EQN(BP@)'9A8V%T:6]N+3YG971686-A=&EO;D%D9')E
M<W-E<R@I*2D@/SX\+W1E>'1A<F5A/@H@("`@/"]T9#X*("`@(#QT9"!W:61T
M:#TB-#`B(&-L87-S/2)R:6=H=$%L:6=N(CX*("`@("`@/#]P:'`@96-H;R!(
M96QP.CIL:6YK*"=I;F=O)RP@)W9A8V%T:6]N+6UY96UA:6PG*2`_/B9N8G-P
M.PH@("`@/"]T9#X*("`\+W1R/@H@(#QT<B!C;&%S<STB:71E;3$B/@H@("`@
M/'1D/@H@("`@("`\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G97AC;'5D97,G
M+"!?*")?061D<F5S<V5S('1O(&YO="!S96YD(')E<W!O;G-E<R!T;SHB*2D@
M/SX*("`@("`@/&)R("\^"B`@("`@(#QT97AT87)E82!N86UE/2)E>&-L=61E
M<R(@:60](F5X8VQU9&5S(B!R;W=S/2(Q,"(@8V]L<STB-#`B/CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<RAI;7!L;V1E*")<;B(L("1V86-A=&EO;BT^
M9V5T5F%C871I;VY%>&-L=61E<R@I*2D@/SX\+W1E>'1A<F5A/@H@("`@/"]T
M9#X*("`@(#QT9"!W:61T:#TB-#`B(&-L87-S/2)R:6=H=$%L:6=N(CX*("`@
M("`@/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;F=O)RP@)W9A8V%T:6]N+6YO
M<F5S<&]N<V4G*2`_/B9N8G-P.PH@("`@/"]T9#X*("`\+W1R/@H@(#QT<B!C
M;&%S<STB:71E;3`B/@H@("`@/'1D/@H@("`@("`\:6YP=70@='EP93TB8VAE
M8VMB;W@B(&YA;64](FEG;F]R96QI<W0B(&ED/2)I9VYO<F5L:7-T(B!V86QU
M93TB,2(\/W!H<"!I9B`H)'9A8V%T:6]N+3YG971686-A=&EO;DEG;F]R96QI
M<W0H*2D@96-H;R`G(&-H96-K960](F-H96-K960B)SL@/SX@+SX*("`@("`@
M/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)VEG;F]R96QI<W0G+"!?*")$;R!?
M;F]T('-E;F0@<F5S<&]N<V5S('1O(&)U;&L@;W(@;&ES="!M97-S86=E<R(I
M*2`_/@H@("`@/"]T9#X*("`@(#QT9"!W:61T:#TB-#`B(&-L87-S/2)R:6=H
M=$%L:6=N(CX*("`@("`@/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;F=O)RP@
M)W9A8V%T:6]N+6)U;&LG*2`_/B9N8G-P.PH@("`@/"]T9#X*("`\+W1R/@H@
M(#QT<B!C;&%S<STB:71E;3`B/@H@("`@/'1D/@H@("`@("`\/W!H<"!E8VAO
M($AO<F1E.CIL86)E;"@G9&%Y<R<L(%\H(DY?=6UB97(@;V8@9&%Y<R!B971W
M965N('9A8V%T:6]N(')E<&QI97,Z(BDI(#\^"B`@("`@(#QI;G!U="!T>7!E
M/2)T97AT(B!N86UE/2)D87ES(B!I9#TB9&%Y<R(@<VEZ93TB,B(@;6%X;&5N
M9W1H/2(R(B!V86QU93TB/#]P:'`@96-H;R`H:6YT*21V86-A=&EO;BT^9V5T
M5F%C871I;VY$87ES*"D@/SXB("\^"B`@("`\+W1D/@H@("`@/'1D('=I9'1H
M/2(T,"(@8VQA<W,](G)I9VAT06QI9VXB/@H@("`@("`\/W!H<"!E8VAO($AE
M;'`Z.FQI;FLH)VEN9V\G+"`G=F%C871I;VXM9&%Y<R<I(#\^)FYB<W`["B`@
M("`\+W1D/@H@(#PO='(^"B`@/'1R(&-L87-S/2)I=&5M,2(^"B`@("`\=&0^
M"B`@("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=S=6)J96-T)RP@7R@B
M4W5B:F5?8W0@;V8@=F%C871I;VX@;65S<V%G93HB*2D@/SX@)FYB<W`["B`@
M("`@(#QI;G!U="!T>7!E/2)T97AT(B!N86UE/2)S=6)J96-T(B!I9#TB<W5B
M:F5C="(@<VEZ93TB-#`B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'9A8V%T:6]N+3YG971686-A=&EO;E-U8FIE8W0H*2D@/SXB("\^
M"B`@("`\+W1D/@H@("`@/'1D('=I9'1H/2(T,"(@8VQA<W,](G)I9VAT06QI
M9VXB/@H@("`@("`\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEN9V\G+"`G=F%C
M871I;VXM<W5B:F5C="<I(#\^)FYB<W`["B`@("`\+W1D/@H@(#PO='(^"B`@
M/'1R(&-L87-S/2)I=&5M,"(^"B`@("`\=&0^"B`@("`@(#P_<&AP(&5C:&\@
M2&]R9&4Z.FQA8F5L*"=R96%S;VXG+"!?*")27V5A<V]N(BDI(#\^.@H@("`@
M("`\8G(@+SX*("`@("`@/'1E>'1A<F5A(&YA;64](G)E87-O;B(@:60](G)E
M87-O;B(@<F]W<STB,3`B(&-O;',](C0P(CX\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'9A8V%T:6]N+3YG971686-A=&EO;E)E87-O;B@I*2`_/CPO
M=&5X=&%R96$^"B`@("`\+W1D/@H@("`@/'1D('=I9'1H/2(T,"(@8VQA<W,]
M(G)I9VAT06QI9VXB/@H@("`@("`\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEN
M9V\G+"`G=F%C871I;VXM<F5A<V]N)RD@/SXF;F)S<#L*("`@(#PO=&0^"B`@
M/"]T<CX*("`\='(^"B`@("`\=&0@8V]L<W!A;CTB,B(@8VQA<W,](F-O;G1R
M;VPB/@H@("`@("`\:6YP=70@8VQA<W,](F)U='1O;B(@='EP93TB<W5B;6ET
M(B!V86QU93TB)FYB<W`[/#]P:'`@96-H;R!?*")3879E(BD@/SXF;F)S<#LB
M("\^"B`@("`@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)B=71T;VXB
M(&]N8VQI8VL](F1O8W5M96YT+FQO8V%T:6]N+FAR968])SP_<&AP(&5C:&\@
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=F:6QT97)S+G!H<"<L('1R=64I(#\^
M)R(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5T=7)N('1O(%)U;&5S($QI<W0B
M*2`_/B(@+SX*("`@(#PO=&0^"B`@/"]T<CX*/"]T86)L93X*/"]F;W)M/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+W1E;7!L871E
M<R]B;&%C:VQI<W0O````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S4P`#`R,3,R,P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEN9V\O=&5M<&QA=&5S+V)L86-K;&ES="]B;&%C:VQI<W0N:6YC````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#0T,#``,3`T,3<S-C(W-3``,#(S-S8Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QF;W)M
M(&UE=&AO9#TB<&]S="(@;F%M93TB9FEL=&5R<R(@86-T:6]N/2(\/W!H<"!E
M8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G8FQA8VML:7-T+G!H<"<I(#\^
M(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB<G5L95]U<&1A=&4B("\^
M"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FYE=U]F;VQD97)?;F%M92(@
M=F%L=64](B(@+SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@
M7R@B0FQA8VML:7-T(BD@/SX*(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6YG
M;R<L("=B;&%C:VQI<W0G*2`_/@H\/W!H<"!I9B`H(65M<'1Y*"1B;%]R=6QE
M6R=D:7-A8FQE)UTI*3H@/SX*("`F;F)S<#M;/'-P86X@<W1Y;&4](F-O;&]R
M.G)E9"(^/#]P:'`@96-H;R!?*")$:7-A8FQE9"(I(#\^/"]S<&%N/ET*/#]P
M:'`@96YD:68[(#\^"CPO:#$^"@H\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS
M<&%C:6YG/2(P(CX*("`\='(@8VQA<W,](FET96TP(CX*("`@(#QT9#X*("`@
M("`@/#]P:'`@96-H;R!?*")!8W1I;VX@9F]R(&)L86-K;&ES=&5D(&%D9')E
M<W-E<SHB*2`_/CQB<B`O/@H@("`@("`\:6YP=70@='EP93TB<F%D:6\B(&YA
M;64](F%C=&EO;B(@:60](F%C=&EO;E]D96QE=&4B('9A;'5E/2)D96QE=&4B
M(#P_<&AP(&EF("AE;7!T>2@D8FQA8VML:7-T7V9O;&1E<BDI(&5C:&\@)V-H
M96-K960](F-H96-K960B("<@/SXO/B`\/W!H<"!E8VAO($AO<F1E.CIL86)E
M;"@G86-T:6]N7V1E;&5T92<L(%\H(E]$96QE=&4@;65S<V%G92!C;VUP;&5T
M96QY(BDI(#\^/&)R("\^"CP_<&AP(&EF("@D:&%V95]M87)K*3H@/SX*("`@
M("`@/&EN<'5T('1Y<&4](G)A9&EO(B!N86UE/2)A8W1I;VXB(&ED/2)A8W1I
M;VY?;6%R:R(@=F%L=64](FUA<FLB(#P_<&AP(&EF("@D8FQA8VML:7-T7V9O
M;&1E<B`]/2!)3D=/7T),04-+3$E35%]-05)+15(I(&5C:&\@)V-H96-K960]
M(F-H96-K960B("<@/SXO/B`\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G86-T
M:6]N7VUA<FLG+"!?*")-87)?:R!M97-S86=E(&%S(&1E;&5T960B*2D@/SX\
M8G(@+SX*/#]P:'`@96YD:68[(#\^"B`@("`@(#QI;G!U="!T>7!E/2)R861I
M;R(@;F%M93TB86-T:6]N(B!I9#TB86-T:6]N7V9O;&1E<B(@=F%L=64](F9O
M;&1E<B(@/#]P:'`@:68@*"%E;7!T>2@D8FQA8VML:7-T7V9O;&1E<BD@)B8@
M*"1B;&%C:VQI<W1?9F]L9&5R("$]($E.1T]?0DQ!0TM,25-47TU!4DM%4BDI
M(&5C:&\@)V-H96-K960](F-H96-K960B("<@/SXO/B`\/W!H<"!E8VAO($AO
M<F1E.CIL86)E;"@G86-T:6]N7V9O;&1E<B<L(%\H(E]-;W9E(&UE<W-A9V4@
M=&\@9F]L9&5R.B(I*2`_/@H@("`@("`\/W!H<"!E8VAO("1F;VQD97)?;&ES
M="`_/@H@("`@/"]T9#X*("`@(#QT9"!W:61T:#TB-#`B(&%L:6=N/2)R:6=H
M="(^"B`@("`@(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6YG;R<L("=B;&%C
M:VQI<W0M86-T:6]N)RD@/SXF;F)S<#L*("`@(#PO=&0^"B`@/"]T<CX*("`\
M='(@8VQA<W,](FET96TQ(CX*("`@(#QT9"!A;&EG;CTB;&5F="(^"B`@("`@
M(#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=B;&%C:VQI<W0G+"!?*")?16YT
M97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4Z(BDI(#\^/&)R("\^"B`@
M("`@(#QT97AT87)E82!N86UE/2)B;&%C:VQI<W0B(&ED/2)B;&%C:VQI<W0B
M(')O=W,](C$U(B!C;VQS/2(X,"(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*&EM<&QO9&4H(EQN(BP@)&)L86-K;&ES="T^9V5T0FQA8VML:7-T*"DI
M*2`_/CPO=&5X=&%R96$^"B`@("`\+W1D/@H@("`@/'1D('=I9'1H/2(T,"(@
M86QI9VX](G)I9VAT(CX*("`@("`@/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I
M;F=O)RP@)V)L86-K;&ES="UA9&1R97-S97,G*2`_/B9N8G-P.PH@("`@/"]T
M9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB8V]N=')O;"(@8V]L
M<W!A;CTB,B(^"B`@("`@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)S
M=6)M:70B('9A;'5E/2(F;F)S<#L\/W!H<"!E8VAO(%\H(E-A=F4B*2`_/B9N
M8G-P.R(@+SX*("`@("`@/&EN<'5T(&-L87-S/2)B=71T;VXB('1Y<&4](F)U
M='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N;&]C871I;VXN:')E9CTG/#]P:'`@
M96-H;R!(;W)D93HZ87!P;&EC871I;VY5<FPH)V9I;'1E<G,N<&AP)RP@=')U
M92D@/SXG(B!V86QU93TB/#]P:'`@96-H;R!?*")2971U<FX@=&\@4G5L97,@
M3&ES="(I(#\^(B`O/@H@("`@/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H\+V9O
M<FT^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&5M<&QA=&5S+V-O;6UO;BUH96%D97(N
M:6YC````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R-S0`,3`T,3<S-C(W
M-3``,#(R-38V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"FEF("AI<W-E="@D;&%N9W5A9V4I*2!["B`@("!H96%D
M97(H)T-O;G1E;G0M='EP93H@=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z
M.F=E=$-H87)S970H*2D["B`@("!H96%D97(H)U9A<GDZ($%C8V5P="U,86YG
M=6%G92<I.PI]"B1P86=E7W1I=&QE(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G;F%M92<I.PII9B`H(65M<'1Y*"1T:71L92DI('L*("`@("1P86=E
M7W1I=&QE("X]("<@.CH@)R`N("1T:71L93L*?0H_/@H\(41/0U194$4@:'1M
M;"!054),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,"!4<F%N<VET:6]N86PO
M+T5.(B`B1%1$+WAH=&UL,2UT<F%N<VET:6]N86PN9'1D(CX*/"$M+2!);F=O
M.B!#;W!Y<FEG:'0@,C`P,BTR,#`V+"!4:&4@2&]R9&4@4')O:F5C="X@26YG
M;R!I<R!U;F1E<B!A($AO<F1E(&QI8V5N<V4N("TM/@H\(2TM($AO<F1E(%!R
M;VIE8W0Z(&AT='`Z+R]W=W<N:&]R9&4N;W)G+R!\(%-K96QE=&]N.B!H='1P
M.B\O=W=W+FAO<F1E+F]R9R]I;F=O+R`@+2T^"CPA+2T@("`@("`@("`@("`@
M2&]R9&4@3&EC96YS97,Z(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S
M+R`@("`@("`@("`@("`@("`@("`M+3X*/#]P:'`@96-H;R`A96UP='DH)&QA
M;F=U86=E*2`_("<\:'1M;"!L86YG/2(G("X@<W1R='(H)&QA;F=U86=E+"`G
M7R<L("<M)RD@+B`G(CXG(#H@)SQH=&UL/B<@/SX*/&AE860^"CP_<&AP(&EF
M("@A96UP='DH)')E9G)E<VA?=&EM92D@)B8@(65M<'1Y*"1R969R97-H7W5R
M;"DI.B`_/@H\;65T82!H='1P+65Q=6EV/2)R969R97-H(B!C;VYT96YT/2(\
M/W!H<"!E8VAO("1R969R97-H7W1I;64@/SX[=7)L/3P_<&AP(&5C:&\@)')E
M9G)E<VA?=7)L(#\^(CX*/#]P:'`@96YD:68[(#\^"CP_<&AP($AO<F1E.CII
M;F-L=61E4V-R:7!T1FEL97,H*3L@/SX*/'1I=&QE/CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D<&%G95]T:71L92D@/SX\+W1I=&QE/@H\;&EN:R!H
M<F5F/2(\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G
M941I<B@I/SXO9F%V:6-O;BYI8V\B(')E;#TB4TA/4E1#550@24-/3B(@+SX*
M/#]P:'`@96-H;R!(;W)D93HZ<W1Y;&5S:&5E=$QI;FLH)VEN9V\G*2`_/@H\
M+VAE860^"@H\8F]D>3P_<&AP(&EF("A5=&EL.CIN;VY);G!U=%9A<B@G8F]D
M>4-L87-S)RDI(&5C:&\@)R!C;&%S<STB)R`N("1B;V1Y0VQA<W,@+B`G(B<@
M/SX^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T
M96UP;&%T97,O;65N=2YI;F,`````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#(Q,``Q,#0Q-S,V,C<U,``P,C$P,#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/&1I=B!I9#TB;65N=2(^
M"B`\/W!H<"!E8VAO($EN9V\Z.F=E=$UE;G4H)W-T<FEN9R<I(#\^"CPO9&EV
M/@H\/W!H<"`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/FYO=&EF>2AA<G)A
M>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI(#\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&AE;65S+P``````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-3``,#$V-C0R`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6YG;R]T:&5M97,O9W)A<&AI8W,O````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,``P,C`T-#(`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;F=O+W1H96UE<R]G<F%P:&EC<R]E;F%B;&4N
M<&YG````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S,T`#$P-#$W,S8R
M-S4P`#`R,C,W,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````8
M4$Q410`````A``"$`'/O<X3WA*W_K<[_SM;_UI*"4W8````!=%).4P!`YMAF
M`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0*
M$0X?"5EV1_(````]241!5`C78V#``92@-%.J`H2A%BP`%3"$2(,%F)(5F$I!
M`DPN3E`5JJ&AAF"5C&')$"T,HH90TQ@%&/`#``1;!M7ZSPT"`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6YG;R]T:&5M97,O9W)A<&AI8W,O9F%V:6-O;BYI8V\`````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4W-@`Q,#0Q-S,V,C<U,``P,C(U-S(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````!
M``$`$!````$`"`!H!0``%@```"@````0````(`````$`"```````````````
M``````````$`````````````A(0``,;&Q@#___\`____`/___P#___\`____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0`````
M!`0$!`0$!`0$!`0$``$!``0$!`0$!`0$!`0$!``!`0`$!`0$!`0$!`0$!`0`
M`P(`!`0$!`0$!`0$!`0$``,"``0$!`0$!`0$!`0$``("`@$`!`0$!`0$!`0$
M``$"`@(!`0`$!`0$!`0$``$"`P("`@$!``0$!`0$``$"`P("`@("`0$`!`0$
M``$"`P,#`@("`@$!`0`$!```````````````````!`0$!`0$!`0$!`0$!`0$
M!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+W1H96UE<R]G<F%P
M:&EC<R]W:&ET96QI<W0N<&YG````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,S,T`#$P-#$W,S8R-S4P`#`R,S$V,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`$
M`P```.W=XE(````84$Q410`````A``"$`'/O<X3WA*W_K<[_SM;_UI*"4W8`
M```!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<
M&`````=T24U%!]0*$0X@%_NG4*T````]241!5`C78V#``92@-%.J`H2A%BP`
M%3"$2(,%F)(5F$I!`DPN3E`5JJ&AAF"5C&')$"T,HH90TQ@%&/`#``1;!M7Z
MSPT"`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T:&5M97,O9W)A<&AI8W,O9F]R=V%R
M9"YP;F<`````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,T,``Q,#0Q-S,V
M,C<U,``P,C(V,#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````
M+5!,5$7___]Z:EB&=F2.?FR:AFRFDGBRGH3!J8P"`@3_________________
M______^/SCOP`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q,```L3`0":G!@````'=$E-10?5#`H0)B(N\DOI````+$E$050(UV-@(!)P
M-,`8&2"R`PC20$*-0B:NZ1401FA:!50JO0%9,;)V`@``5-<+X]9.:@@`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEN9V\O=&AE;65S+V=R87!H:6-S+V-O<'DN<&YG````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,S,`,3`T,3<S-C(W-3``,#(R,3(P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````$0@#````YX0,RP```%I03%1%`/\`(20A
M0D$Y8V%2<W%S````E)*$G)Z,I:*4I::4K:Z<K:ZMM;:EM;*MO;JEUM.]UM>]
MUM?&WMO&WM_&WM_.WM_>Y^/.Y^?.[^O6[^_6]_/6]_/>]_?>[^OG@VFNP0``
M``%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8
M````!W1)344'U`H1#ATQ0T*=[@```'I)1$%4*)%=SM$60S`01=%!+X(6H42U
M__^;G4DF5N(^6'&R'T+$`R@?,-990]$/DT6*\7L\9]LAP7B7QBY;@@F5E/W"
MDEY<."GVJ;;KMCO%0VA\<H=BUTI#Q^6C^#@#DSL$?'Z-9XV\,6"CS]6OQW0-
M$<=_6<19NBTM?^,("*]>-3N$`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O
M+W1H96UE<R]G<F%P:&EC<R]S8W)I<'0N<&YG````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,C8T`#$P-#$W,S8R-S4P`#`R,C0U-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```#M4$Q410```!<6%$`_.T!`0$)!/%)0
M2E-23E1335]=5F=E7VAF86IH8W-S<WAU;'9U<W=W=WIY='MY<WEY>7QZ<GIZ
M>GU[=7Q\?'U]?7Y^?H.`>(:$?86%A8:&AHF'@8J(@XZ,A9>5CYJ9DIN9DYJ9
MEIN;FZ&AH:2DI*:FIJ>GIZVMK+.SL[6TM+>VL\?'Q\K*RL_.RM#0T-'1T=+2
MTM33U-34U-75U=;6UMC7V-S<W-W<V^#@X.'AX.CGY^GIZ>KKZ^SL[.WL[.[N
M[O'Q\?'Q\O+Q\?/T]/3T]/GY^OGZ^OKZ^?O[^_S\_/W]_?___P```)FXTX@`
M```!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<
M&`````=T24U%!]0,%!,B%A+V-P@```",=$58=$-O;6UE;G0`365N=2US:7IE
M9"!I8V]N"CT]/3T]/3T]/3T*"BAC*2`R,#`S($IA:W5B("=J:6UM86,G(%-T
M96EN97(L(`IH='1P.B\O:FEM;6%C+FUU<VEC:&%L;"YC>@H*8W)E871E9"!W
M:71H('1H92!'24U0+`IH='1P.B\O=W=W+F=I;7`N;W)G9XK'1P```*A)1$%4
M>-IEC]<.@E`01*^]]P**O?>"#1$L*,7"_/_GB-Z`))YD'W8RN[-+""$`B`NK
MG</F*QP:U7H)G"PK?,?W,60BWF@.,$TY-5J#8-\,>I*M``2!YSY#0+K<GA0`
M4>3I;M1BB7`(8TE:P4[Q6W4Z'W?X!?>5V_6R<82'IJJ:IFU_PEW7#4-?4"&>
MS1=9EF7,YY(>^J)T&7-&'0/AR[32&SJQ[M?^>`,7GB?PJ!0IQ`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;F=O+W1H96UE<R]G<F%P:&EC<R]I;F=O+G!N9P``````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,S(V`#$P-#$W,S8R-S4P`#`R,C$P,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`$`P```.W=XE(````/4$Q411$``,;&QO___P``
M``"$A'F['.0````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]4,%0T=-/H09FH```!`241!5`C78V#``,S&
M8&#`P.RHI"@HXF+`P&`B)"@HX@R2<U04!`D`A2`"0"%!$0.(1B-A!C2&B3,Z
MP]B8`2\``'#^!P&$GY^4`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]T:&5M
M97,O9W)A<&AI8W,O=F%C871I;VXN<&YG````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#,U-P`Q,#0Q-S,V,C<U,``P,C(W-38`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0!`,```#MW>)2````)U!,5$49``#_[:/_Y7__S`#_F0#,S``SS/\S
MF?\S,P``S#,`9@``,P#___X>V@.W`````7123E,`0.;89@````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]0*$P@3""Q`C%$```!.241!5`C78V#`#;A6
M<^]:"6+LW+5[]6RPT,I57!`IA@Z&!1!5'3PB+HX'0(Q#SL8F.B"&B+&QL2-#
M>7E'>5I:6CE#:&A':!F$`0%X[`0`12`7*-XBOXP`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&AE;65S+V=R87!H:6-S
M+V1I<V%B;&4N<&YG````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,C(`
M,3`T,3<S-C(W-3``,#(R-30S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```.%03%1%`/\`$!00&!@0&!@8&!P8(0@`(0P(*0@`*0P`*0P((1`(
M*10((1@0*100*1@0*1@8,1`(,100,1@0,1P0.100.1@0.1P8,2`8(2`A(20A
M,2PI.30Q2A0(0A002A@02AP00B`84B`86B080BPI2C`I8R08&`@`A"00A"08
ME"P8G"P8E#`8G#`8I30AI3@AK30AM30AM3@AM3PAO3@AO3PAO3PIK44QM5E*
MM6%2QC@AQD$IQD4IQDTQSDTQSE$YSE5"UEU*QFU:SF52SFU:UF%*UFU:WG%:
MSG%CSGEKUGUSWHY[^X[H3`````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`H1#AXD!;(JQ@```*I)1$%4
M*!4%P8DB`F$8`,`1<M2&5*Z4,U:N]:TC_LA9O/\#F>&@`\#V#L=_DSY`]OY0
M<?+UEGK`YL]S7K>71I%.H?X=>1=9BDA'5#[+LR502Q%%:^[IY;P*R%)$\?AZ
ML0B@G2+&Q3(`NA]E1-$&L/Y;WA411088S.[S^5:*N*V!SBR&55HIHFC@<!IY
M%?93C*X7;$W+RQ6@ET8W#;OY<`#0'U^MT5P%H+GA'S"N%G7H4IJ7`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&AE;65S+V=R
M87!H:6-S+V)L86-K;&ES="YP;F<`````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$P,C(`,3`T,3<S-C(W-3``,#(S,3$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P```.%03%1%`/\`$!00&!@0&!@8&!P8(0@`(0P(*0@`*0P`
M*0P((1`(*10((1@0*100*1@0*1@8,1`(,100,1@0,1P0.100.1@0.1P8,2`8
M(2`A(20A,2PI.30Q2A0(0A002A@02AP00B`84B`86B080BPI2C`I8R08&`@`
MA"00A"08E"P8G"P8E#`8G#`8I30AI3@AK30AM30AM3@AM3PAO3@AO3PAO3PI
MK44QM5E*M6%2QC@AQD$IQD4IQDTQSDTQSE$YSE5"UEU*QFU:SF52SFU:UF%*
MUFU:WG%:SG%CSGEKUGUSWHY[^X[H3`````%T4DY3`$#FV&8````!8DM'1`"(
M!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`H1#AP;@>)E>0``
M`*I)1$%4*!4%P8DB`F$8`,`1<M2&5*Z4,U:N]:TC_LA9O/\#F>&@`\#V#L=_
MDSY`]OY0<?+UEGK`YL]S7K>71I%.H?X=>1=9BDA'5#[+LR502Q%%:^[IY;P*
MR%)$\?AZL0B@G2+&Q3(`NA]E1-$&L/Y;WA411088S.[S^5:*N*V!SBR&55HI
MHFC@<!IY%?93C*X7;$W+RQ6@ET8W#;OY<`#0'U^MT5P%H+GA'S"N%G7H4IJ7
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O=&AE
M;65S+W-C<F5E;BYC<W,`````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`R,S4`,3`T,3<S-C(W-3``,#(P-C,P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&EN
M9V\O=&AE;65S+W-C<F5E;BYC<W,L=B`Q+C$N,BXQ(#(P,#4O,3`O,3<@,C,Z
M,SDZ,#D@:F%N($5X<"`D"B`J+PH*+RH@365N=2!B;W1T;VT@;6%R9VEN+"!A
M9&1E9"!F;W(@0D,N("HO"B-M96YU('L*("`@(&UA<F=I;BUB;W1T;VTZ(#AP
M>#L*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+V1O8W,O````````````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4P`#`Q-C,P-0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN
M9V\O9&]C<R]#4D5$2513````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#0W-S,`,3`T,3<S-C(W-3``,#$W,S,U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"B!);F=O($1E=F5L;W!M96YT(%1E86T*/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-B\P
M,B\R,"`Q,CHR,#HU,"`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N
M,C,N-"XQ,2`D"CI#;VYT86-T.B`@("`@("!I;F=O0&QI<W1S+FAO<F1E+F]R
M9PH*"D-O<F4@1&5V96QO<&5R<PH]/3T]/3T]/3T]/3T]/3T*"BT@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*+2!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H*"DQO8V%L:7IA=&EO;@H]/3T]/3T]/3T]/3T*
M"CT]/3T]/3T]/3T]/3T]/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I"<F%Z:6QI86X@
M4&]R='5G=65S92`@("!&86)I;R!';VUE<R`\9FQG;VUS0'5O;"YC;VTN8G(^
M"D-H:6YE<V4@*%1R861I=&EO;F%L*2`@($1A=FED($-H86YG(#QD879I9$!T
M;78N9V]V+G1W/@I#>F5C:"`@("`@("`@("`@("`@("`@("!0879E;"!#:'ET
M:6P@/'!A=F5L0&-H>71I;"YT:SX*1&%N:7-H("`@("`@("`@("`@("`@("`@
M0G)I86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`8G)I86YT<G5E;'-E;BYD:SX*
M1'5T8V@@("`@("`@("`@("`@("`@("`@4G5B96X@=F%N(&1E<B!3=&5E;FAO
M=F5N"B`@("`@("`@("`@("`@("`@("`@("`@(#QR=6)E;E]D;VYO='-P86UM
M94!W96)M965S=&5R<RYN970^"D9I;FYI<V@@("`@("`@("`@("`@("`@($QE
M96YA($AE:6YO(#Q,965N82Y(96EN;T!U=&$N9FD^"D9R96YC:"`@("`@("`@
M("`@("`@("`@($9L;W)E;G0@06ED92`\9F%I9&5`86QP:&%C96YT+F-O;3X*
M("`@("`@("`@("`@("`@("`@("`@("`@0F5N;VET(%-T+4%N9'+I(#QB96Y`
M8F5N;VET<W0M86YD<F4N;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!0
M:65R<F4@3&%C:&%N8V4@/'!L0'!I97)R96QA8VAA;F-E+FYE=#X*1V5R;6%N
M("`@("`@("`@("`@("`@("`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*2'5N9V%R:6%N("`@("`@("`@("`@("`@071T:6QA($YA9WD@/&)R84!F
M<VXN:'4^"B`@("`@("`@("`@("`@("`@("`@("`@($QA<WIL;R!,+B!4;W)N
M;V-I(#QT;W)L87-Z0'AE;FEA+G-O=&4N:'4^"DET86QI86X@("`@("`@("`@
M("`@("`@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`@("`@("`@
M("`@("`@("`@("`@("`@($UA<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O=F%N
M;T!U;FEB;V-C;VYI+FET/@H@("`@("`@("`@("`@("`@("`@("`@("!#<FES
M=&EA;B!-86YO;FD@/&-R:7-T:6%N+FUA;F]N:4!N971H97-I<RYI=#X*2V]R
M96%N("`@("`@("`@("`@("`@("`@2FEN:'EO:R!(96\@/&YO=F5M8G)E0&]U
M<FYA='5R92YO<F<^"DQA='9I86X@("`@("`@("`@("`@("`@($IA;FES($5I
M<V%K<R`\:F%N8W-`9'8N;'8^"DQI=&AU86YI86X@("`@("`@("`@("`@(%9I
M;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT/@I.;W)W96=I86X@0F]K;6%A
M;"`@("`@("!4<F]N9"!":OAR<W1A9"`\=')B0&YD;BYN;SX*("`@("`@("`@
M("`@("`@("`@("`@("`@5&AO;6%S($-H<BX@1&%H;"`\=&-D0&YD;BYN;SX*
M4&]L:7-H("`@("`@("`@("`@("`@("`@4')Z96UY<VQA=R`B4')I;6\B(%=I
M=&5K(#QP<FEM;T!N<&PN<&P^"B`@("`@("`@("`@("`@("`@("`@("`@($MR
M>GES>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#X*4&]R='5G=65S92`@
M("`@("`@("`@("`@36%N=65L($UE;F5Z97,@9&4@4V5Q=65I<F$@/$UA;G5E
M;"Y397%U96ER83X*4F]M86YI86X@("`@("`@("`@("`@("`@175G96X@2&]A
M;F-A(#QE=6=E;FA`=7)B86XM9W)A9G@N<F\^"E-P86YI<V@@("`@("`@("`@
M("`@("`@($UA;G5E;"!097)E>B!!>6%L82`\;7!E<F%Y84!A;&-A>F%B82YU
M;F5X+F5S/@I3=V5D:7-H("`@("`@("`@("`@("`@("!!;F1E<G,@3F]R<F)R
M:6YG(#QA;F1E<G-`;F]R<F)R:6YG+F)I>CX*5'5R:VES:"`@("`@("`@("`@
M("`@("`@4V5R=F5T($?\;F5Y(#QS9W5N97E`;65T=2YE9'4N='(^"B`@("`@
M("`@("`@("`@("`@("`@("`@($%H;65T(-9Z=/QR:R`\;V%H;65T0&UE='4N
M961U+G1R/@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T@("`]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"@I)
M;F%C=&EV92!$979E;&]P97)S"CT]/3T]/3T]/3T]/3T]/3T]/3T*"BT@36EK
M92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*+2!"<F5N="!*
M+B!.;W)D<75I<W0@/&)J;D!H;W)D92YO<F<^"@H*3W1H97(@5&AA;FMS"CT]
M/3T]/3T]/3T]/0H*4GEA;B!'86QL86=H97(@/')Y86Y`<W1U9&EE<V%B<F]A
M9"YC;VT^"@HM(%1H92!N86UE(#HM*2`B36%I;"!C;VUE<R`G:6XG+BXN5VAE
M<F4@9&]E<R!I="`G9V\G/R(*"E1U9G1S(%5N:79E<G-I='D*"BT@1G5N9&EN
M9R!S=7!P;W)T(&9O<B!,1$%0+U-I979E("A3=6X@2D53+T].12`F(&E0;&%N
M970@;65S<V%G:6YG('-E<G9E<G,I+@H*```````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEN9V\O9&]C<R]214%$344`````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R,30`,3`T,3<S-C(W-3``,#$W
M,38S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%=H870@:7,@26YG;S\*/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@
M("`D1&%T93H@,C`P-2\Q,"\Q-R`R,SHS.3HP,B`D"CI2979I<VEO;CH@("`@
M("`D4F5V:7-I;VXZ(#$N."XQ,"XQ("0*.D-O;G1A8W0Z("`@("`@(&EN9V]`
M;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"BXN('-E
M8W1I;VXM;G5M8F5R:6YG.CH*"DEN9V\@:7,@86X@96UA:6P@9FEL=&5R(')U
M;&5S(&UA;F%G97(N("!)="!C86X@9V5N97)A=&4@4VEE=F4@86YD('!R;V-M
M86EL"G-C<FEP=',@86YD('5P;&]A9"!T:&5M('1O('1H92!S97)V97(@*'5S
M:6YG(&$@=&EM<VEE=F5D(&]R(%9&4R!&5%`@9')I=F5R+`IR97-P96-T:79E
M;'DI+B`@270@8V%N(&%L<V\@8W)E871E(&%N9"!E>&5C=71E($E-05`@8V]M
M;6%N9',@=&\@<G5N(&9I;'1E<@IR=6QE<RX*"E1H:7,@<V]F='=A<F4@:7,@
M3U-)($-E<G1I9FEE9"!/<&5N(%-O=7)C92!3;V9T=V%R92X@($]322!#97)T
M:69I960@:7,@80IC97)T:69I8V%T:6]N(&UA<FL@;V8@=&AE(&!/<&5N(%-O
M=7)C92!);FET:6%T:79E8%\N"@HN+B!?8$]P96X@4V]U<F-E($EN:71I871I
M=F5@.B!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+PH*"D]B=&%I;FEN9R!)
M;F=O"BTM+2TM+2TM+2TM+2TM"@I&=7)T:&5R(&EN9F]R;6%T:6]N(&]N($EN
M9V\@86YD('1H92!L871E<W0@=F5R<VEO;B!C86X@8F4@;V)T86EN960@870*
M"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O:6YG;R\*"@I$;V-U;65N=&%T:6]N
M"BTM+2TM+2TM+2TM+2T*"E1H92!F;VQL;W=I;F<@9&]C=6UE;G1A=&EO;B!I
M<R!A=F%I;&%B;&4@:6X@=&AE($EN9V\@9&ES=')I8G5T:6]N.@H*.E)%041-
M15\Z("`@("`@("`@(%1H:7,@9FEL90HZ3$E#14Y315\Z("`@("`@("`@0V]P
M>7)I9VAT(&%N9"!L:6-E;G-E(&EN9F]R;6%T:6]N"CI@9&]C<R]#2$%.1T53
M8%\Z("!#:&%N9V5S(&)Y(')E;&5A<V4*.F!D;V-S+T-2141)5%-@7SH@(%!R
M;VIE8W0@9&5V96QO<&5R<PHZ8&1O8W,O24Y35$%,3&!?.B`@26YS=&%L;&%T
M:6]N(&EN<W1R=6-T:6]N<R!A;F0@;F]T97,*.F!D;V-S+U1/1$]@7SH@("`@
M($1E=F5L;W!M96YT(%1/1$\@;&ES=`H*"DEN<W1A;&QA=&EO;@HM+2TM+2TM
M+2TM+2T*"DEN<W1R=6-T:6]N<R!F;W(@:6YS=&%L;&EN9R!);F=O(&-A;B!B
M92!F;W5N9"!I;B!T:&4@9FEL92!)3E-404Q,7R!I;B!T:&4*8&!D;V-S+V!@
M(&1I<F5C=&]R>2!O9B!T:&4@26YG;R!D:7-T<FEB=71I;VXN"@H*07-S:7-T
M86YC90HM+2TM+2TM+2TM"@I)9B!Y;W4@96YC;W5N=&5R('!R;V)L96US('=I
M=&@@26YG;RP@:&5L<"!I<R!A=F%I;&%B;&4A"@I4:&4@2&]R9&4@1G)E<75E
M;G1L>2!!<VME9"!1=65S=&EO;G,@3&ES="`H1D%1*2P@879A:6QA8FQE(&]N
M('1H92!796(@870*(`H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+V9A<2\*"E1H
M92!(;W)D92!0<F]J96-T(')U;G,@82!N=6UB97(@;V8@;6%I;&EN9R!L:7-T
M<RP@9F]R(&EN9&EV:61U86P@87!P;&EC871I;VYS"F%N9"!F;W(@:7-S=65S
M(')E;&%T:6YG('1O('1H92!P<F]J96-T(&%S(&$@=VAO;&4N("!);F9O<FUA
M=&EO;BP@87)C:&EV97,L(&%N9`IS=6)S8W)I<'1I;VX@:6YF;W)M871I;VX@
M8V%N(&)E(&9O=6YD(&%T"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VUA:6PO
M"@I,87-T;'DL($AO<F1E(&1E=F5L;W!E<G,L(&-O;G1R:6)U=&]R<R!A;F0@
M=7-E<G,@86QS;R!M86ME(&]C8V%S:6]N86P*87!P96%R86YC97,@;VX@25)#
M+"!O;B!T:&4@8VAA;FYE;"`C:&]R9&4@;VX@=&AE($9R965N;V1E($YE='=O
M<FL**&ER8RYF<F5E;F]D92YN970I+@H*"DQI8V5N<VEN9PHM+2TM+2TM+2T*
M"D9O<B!L:6-E;G-I;F<@86YD(&-O<'ER:6=H="!I;F9O<FUA=&EO;BP@<&QE
M87-E('-E92!T:&4@9FEL92!,24-%3E-%7PII;B!T:&4@26YG;R!D:7-T<FEB
M=71I;VXN"@I4:&%N:W,L"@I4:&4@26YG;R!T96%M"@H*+BX@7U)%041-13H@
M/V8]4D5!1$U%+FAT;6P*+BX@7TQ)0T5.4T4Z(&AT='`Z+R]W=W<N:&]R9&4N
M;W)G+VQI8V5N<V5S+V%S;"YP:'`*+BX@7V1O8W,O0TA!3D=%4SH@/V8]0TA!
M3D=%4RYH=&UL"BXN(%]D;V-S+T-2141)5%,Z(#]F/4-2141)5%,N:'1M;`HN
M+B!?24Y35$%,3#H*+BX@7V1O8W,O24Y35$%,3#H@/V8]24Y35$%,3"YH=&UL
M"BXN(%]D;V-S+U1/1$\Z(#]F/51/1$\N:'1M;`H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9V\O9&]C<R]#2$%.1T53````````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30V-3$`,3`T
M,3<S-C(W-3``,#$W,S`T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"TM+2T*=C$N,0HM+2TM"@I;:F%N72!!=71O;6%T:6-A
M;&QY(&%D9"!M:7-S:6YG('-P96-I86P@<G5L97,@=VAE;B!E9&ET:6YG('1H
M96T@*$)U9R`C,S,R-2DN"@H*+2TM+2TM+2T*=C$N,2U20S$*+2TM+2TM+2T*
M"EMJ86Y=($%D9"!P;W)T86P@8FQO8VL@9F]R('-P96-I86P@<G5L97,@*$]L
M:79E<B!+=6AL(#QO:W5H;$!N971C;VQO9VYE+F1E/BP*("`@("`@4F5Q=65S
M="`C,S$P-BDN"EMJ86Y=($%D9"!0;W)T=6=U97-E('1R86YS;&%T:6]N("A-
M86YU96P@365N97IE<R!D92!397%U96ER80H@("`@("`\36%N=65L+E-E<75E
M:7)A/BDN"EMC:FA=($9I>"!E<V-A<&EN9R!O9B!O=71P=70@:6X@<V5V97)A
M;"!C87-E<RX*6VUA<UT@061D(&YO=&EF>2!R=6QE+B`H4&%U;"!7;VQS=&5N
M:&]L;64@/'=O;'-T96YA0'-F=2YC83XL($)U9R`C,3$S.2D*6VIA;ET@061D
M(%1U<FMI<V@@=')A;G-L871I;VX@*&AO<F1E+71R0&UE='4N961U+G1R*2X*
M6VIA;ET@1&]N)W0@86-T:79A=&4@<V-R:7!T(&EF(&5X8V5E9&5D(&)L86-K
M;&ES="]W:&ET96QI<W0@;&EM:71S("A"=6<@(S$Q-C8I+@I;:F%N72!!9&0@
M1&%N:7-H('1R86YS;&%T:6]N("A"<FEA;B!4<G5E;'-E;B`\:&]R9&4K:3$X
M;D!B<FEA;G1R=65L<V5N+F1K/BDN"EMJ86Y=($%L;&]W('1O('5S92!A('-I
M;F=L92!U<V5R(&9O<B!61E,@9')I=F5R<R`H;6%D9&]G,FM`;6%D9&]G,FLN
M;F5T+`H@("`@("!297%U97-T(",R,S(T*2X*6VIA;ET@06QL;W<@=&\@;6]V
M92!R=6QE<R!B>2!S<&5C:69Y:6YG('1H96ER('!O<VET:6]N<R`H1V5R9V5L
M>2!2:7-K;PH@("`@("`\9V5R9V5L>4!R:7-K;RYH=3XL(%)E<75E<W0@(S$P
M-C`I+@I;;6%S72!!9&0@9FQA9RUO;FQY(')U;&4N("A297%U97-T(",Q,3$T
M*0I;8F5N72!(:61E('!R;V-M86EL('9A8V%T:6]N(&1B(&9I;&5S"EMM;7-=
M($%D9"!M86EL9')O<"!S8W)I<'0@9')I=F5R("A-871T(%=E>6QA;F0@/&UA
M=&AI87-`=V5Y;&%N9"YC:#XI+@I;8F5N72!!9&0@<W5P<&]R="!F;W(@)UY4
M3U\G('!R;V-M86EL(')U;&4@;6%T8VAI;F<N"EMB96Y=($%D9"!S=7!P;W)T
M(&9O<B!S<&5C:6%L(&AE861E<G,@;VX@82!P97(M9')I=F5R(&)A<VES+@I;
M:FUF72!!9&0@<W5P<&]R="!F;W(@<W1O<FEN9R!3:65V92!R=6QE<R!I;B!,
M1$%0("A3=7!P;W)T<R!3=6X@2D53+T].12!A;F0*("`@("`@:5!L86YE="!M
M97-S86=I;F<@<V5R=F5R<RDN"EMJ86Y=($%D9"!P97)M:7-S:6]N<R!T;R!R
M97-T<FEC="!F:6QT97(@<G5L92!C<F5A=&EO;BX*"@HM+2TM+2T*=C$N,"XR
M"BTM+2TM+0H*6VIA;ET@061D($MO<F5A;B!T<F%N<VQA=&EO;B`H2FEN:'EO
M:R!(96\@/&YO=F5M8G)E0&]U<FYA='5R92YO<F<^*2X*"@HM+2TM+2TM+2TM
M"G8Q+C`N,BU20S$*+2TM+2TM+2TM+0H*6VIA;ET@0V]N=F5R="!R=6QE<R!F
M<F]M($EN9V\@,2XP('=I=&@@;75L=&EB>71E(&-H87)A8W1E<G,@*$)U9R`C
M,3(X,BDN"EMJ86Y=($%L=V%Y<R!E;F-O9&4@4VEE=F4@<V-R:7!T<R!I;B!5
M5$8M."!A;F0@34E-12!E;F-O9&4@<W5B:F5C="!O9B!V86-A=&EO;@H@("`@
M("!M97-S86=E<R`H1V5R9V5L>2!2:7-K;R`\9V5R9V5L>4!R:7-K;RYH=3XL
M($)U9R`C,C$R,2DN"EMC:FA=($1O;B=T(&5S8V%P92`B7"(@:6X@4VEE=F4@
M<F5G97@@;6]D92`H0G5G(",R,3,T*2X*6VIA;ET@1&]N)W0@86QL;W<@96UP
M='D@861D<F5S<V5S(&EN(&)L86-K;&ES=',@86YD('=H:71E;&ES=',@*$)U
M9R`C,C$V-2DN"EMJ86Y=(%)E86QL>2!S:&]W('1H92!A8W1I=F4@<V-R:7!T
M(&EF(&-L:6-K:6YG('1H870@8G5T=&]N("A"=6<@(S(Q,S4I+@I;:F%N72!&
M:7@@;6EG<F%T:6]N('-C<FEP="!F;W(@24U0(&9I;'1E<G,@=&\@;F]T(&EN
M8VQU9&4@9F]L9&5R(')U;&5S(&9R;VT*("`@("`@86QR96%D>2!M:6=R871E
M9"!U<V5R<R`H0G5G(",R,3$T*2X*6VIA;ET@1FEX(&-R96%T:6YG(&]F(&YO
M;BUA<V-I:2!)34%0(&9O;&1E<B!N86UE<R`H0G5G(",R,#4T*2X*6VIA;ET@
M1FEX(')E9W5L87(@97AP<F5S<VEO;B!R=6QE<R!T:&%T(&-O;G1A:6X@8V]M
M;6%S("A"=6<@(S$Y,#0I+@I;;6%S72!!;&QO=R!T:&4@9&ES86)L:6YG(&]F
M(&)L86-K;&ES="P@=VAI=&5L:7-T+"!V86-A=&EO;BP@86YD(&9O<G=A<F0*
M("`@("`@*%)E<75E<W0@(S$Q-C0I+@I;:F%N72!!;&QO=R!M97-S86=E(&9L
M86=S('=I=&@@86QL('-I979E(')U;&5S('1H870@:V5E<"!T:&4@;65S<V%G
M90H@("`@("`H0G5G(",Q,CDR*2X*6VIA;ET@061D($YO<G=E9VEA;B!";VMM
M86%L('1R86YS;&%T:6]N("A4<F]N9"!":OAR<W1A9"`\=')B0&YD;BYN;SXL
M(%1H;VUA<PH@("`@("!#:'(N($1A:&P@/'1C9$!N9&XN;F\^*2X*6VIA;ET@
M0VAA;F=E('=H:71E;&ES="!R=6QE(&9O<B!3:65V92!T;R!N;W0@87!P;'D@
M86YY(&9U<G1H97(@<G5L97,*("`@("`@*$)U9R`C,3,W."DN"EMJ86Y=($%D
M9"!S:&]R=&-U="!I8V]N("AF879I8V]N+FEC;RDN"EMB96Y=($9I>"!P<F]C
M;6%I;"!F;W)W87)D:6YG+B`H:&%G97(@*&%T*2!F:"UR;W-E;FAE:6T@*&1O
M="D@9&4L($)U9R`C,3$R-2D*6VIA;ET@06QL;W<@=&\@<W!E8VEF>2!M=6QT
M:7!L92!V86QU97,@=VET:"`B0F5G:6YS+T5N9',@5VET:"(@=&5S=',@*%1O
M9&0*("`@("`@365R<FET="`\=&UE<G)I='1`96UA:6PN87)I>F]N82YE9'4^
M+"!"=6<@(S$Q,#4I+@H*"BTM+2TM+0IV,2XP+C$*+2TM+2TM"@I;:F%N72!&
M:7@@8FQA8VML:7-T(&-O;G9E<G-I;VX@:6X@24U0+71O+4EN9V\@8V]N=F5R
M<VEO;B!S8W)I<'0@*%-T979E($QI9&EE"B`@("`@(#QS;VPP0$QE:&EG:"Y%
M1%4^*2X*6VIA;ET@1FEX(&9I;'1E<B!R=6QE<R!W:71H(&UU;'1I8GET92!C
M:&%R86-T97)S+@H*"BTM+2T*=C$N,`HM+2TM"@I;:F%N72!!9&0@0G)A>FEL
M:6%N(%!O<G1U9W5E<V4@=')A;G-L871I;VX@*$9A8FEO($=O;65S"B`@("`@
M(#QF;&=O;65S0&9A>F5N9&$N<W`N9V]V+F)R/BDN"@H*+2TM+2TM+2T*=C$N
M,"U20S(*+2TM+2TM+2T*"EMJ86Y=($%D9"!#>F5C:"!T<F%N<VQA=&EO;B`H
M4&%V96P@0VAY=&EL(#QP879E;$!C:'ET:6PN=&L^*2X*6V-J:%T@4VAO=R!M
M96YU(&EN(%-C<FEP="!V:65W("A"=6<@(S@T,RDN"@H*+2TM+2TM+2T*=C$N
M,"U20S$*+2TM+2TM+2T*"EMC:FA=(%5P9&%T92!I8V]N<RX*6VIA;ET@1&ES
M86)L92!+;VQA8B!B86-K96YD<R!I9B!D:7-A8FQE9"!G;&]B86QL>2X*"@HM
M+2TM+2TM+2T*=C$N,"U"151!"BTM+2TM+2TM+0H*6VIA;ET@061D(%-P86YI
M<V@@=')A;G-L871I;VX@*$UA;G5E;"!097)E>B!!>6%L82`\;7!E<F%Y84!A
M;&-A>F%B82YU;F5X+F5S/BDN"EMJ86Y=($%D9"!V86-A=&EO;B!S=7!P;W)T
M('1O('!R;V-M86EL(&1R:79E<B`H36EC:&$@2V5R<VQO;W0*("`@("`@/&UI
M8VAA0&MO=F]K<RYN;#XI+@H*"BTM+2TM+2TM+2T*=C$N,"U!3%!(00HM+2TM
M+2TM+2TM"@I;;6US72!!9&0@8V]N9FEG=7)A=&EO;B!O<'1I;VX@=&\@;&EM
M:70@=&]T86P@;G5M8F5R(&]F(&)L86-K;&ES="]W:&ET96QI<W0*("`@("`@
M96YT<FEE<R!A('5S97(@8V%N(&AA=F4N"EMJ86Y=($%L;&]W('-E='1I;F<@
M=7`@82!G;&]B86P@=7-E<B!I;B!T:&4@8F%C:V5N9',@8V]N9FEG=7)A=&EO
M;B`H36%R=&EN"B`@("`@($QU971H:2`\:&]R9&5`:'5M8F%P82YC:#XI+@I;
M;6US72!!;&QO=R!U<V5R('1O(&1E86-T:79A=&4@<V-R:7!T+@I;;6US72!!
M9&0@<W5P<&]R="!T;R!F:6QT97(@8GD@8F]D>2!C;VYT96YT<R!F;W(@24U!
M4"!D<FEV97(N"EMM;7-=($%L;&]W('5S97(M9&5F:6YE9"!F:6QT97)S(&9O
M<B!T:&4@<')O8VUA:6P@9')I=F5R("A"96X@0VAA=F5T"B`@("`@(#QB96Y`
M8VAA=F5T+FYE=#XI+@I;;6US72!!;&QO=R!U<V5R+7-P96-I9FEE9"!(96%D
M97)S('1O(&)E('5S960@9F]R(&9I;'1E<FEN9RX*6VUM<UT@5&AE('-T;W)A
M9V4@<WES=&5M(&AA<R!B965N(&%B<W1R86-T960@;W5T('1O(&%L;&]W(&9O
M<B!M=6QT:7!L90H@("`@("!B86-K96YD('-T;W)A9V4@9')I=F5R<RX*6VUM
M<UT@4F5M;W9E9"!A;&P@)W-H;W=?*B<@<')E9F5R96YC97,@+2!A;&P@879A
M:6QA8FQE(&%C=&EO;G,@=VEL;"!B90H@("`@("!S:&]W;B!O;B!T:&4@;65N
M=2!B>2!D969A=6QT+@I;;6US72!!9&1E9"!T:&4@9F]R=V%R9"!A8W1I;VX@
M*%1O9&0@365R<FET="`\=&UE<G)I='1`96UA:6PN87)I>F]N82YE9'4^*2X*
M6VUM<UT@3VX@9&5M86YD(&9I;'1E<G,@8V%N(&YO=R!A<'!L>2!T;R!E>&-L
M=7-I=F5L>2!S965N(&]R('5N<V5E;B!M97-S86=E<RX*6VUM<UT@4G5L97,@
M8V%N(&YO=R!B92!D:7-A8FQE9"`H5&]D9"!-97)R:71T(#QT;65R<FET=$!E
M;6%I;"YA<FEZ;VYA+F5D=3XI+@I;;6US72!!9&1E9"!R96QA=&EO;F%L+"!R
M96=E>"P@86YD(&UA=&-H97,@=&5S=',@=&\@4VEE=F4@<V-R:7!T"B`@("`@
M("A4;V1D($UE<G)I='0@/'1M97)R:71T0&5M86EL+F%R:7IO;F$N961U/BDN
M"EMM;7-=($AO;F]R(&]T:&5R(&UO9'5L92=S(&AA;F1L:6YG(&]F(&)L86-K
M;&ES="]W:&ET96QI<W0N"EMM;7-=($1O;B=T('-H;W<@<V-R:7!T(&]P=&EO
M;G,@:68@=&AE('5N9&5R;'EI;F<@26YG;U]38W)I<'0Z.B!D<FEV97(*("`@
M("`@9&]E<VXG="!U<V4@=&AE;2X*6VUM<UT@0V%S92!S96YS:71I=F4@<V5A
M<F-H97,@;VYL>2!A;&QO=V5D(&9O<B!);F=O7U-C<FEP=#HZ(&1R:79E<G,@
M=&AA=`H@("`@("!C86X@:&%N9&QE('1H96TN"EMM;7-=("=B;&%C:VQI<W1?
M9F]L9&5R)R!P<F5F97)E;F-E(&YO=R!H86YD;&5D(&EN<VED92!T:&4@)V)L
M86-K;&ES="<*("`@("`@<')E9F5R96YC92X*6VUM<UT@061D960@)W-H;W=?
M9FEL=&5R7VUS9R<@<')E9F5R96YC92`M(&9O<B!U<V4@=VET:"!(;W)D95]3
M8W)I<'0Z.@H@("`@("!B86-K96YD<R!T:&%T('-U<'!O<G0@;VX@9&5M86YD
M(&9I;'1E<FEN9RX*6VUM<UT@061D960@=&AE("=M86EL+V-A;D%P<&QY1FEL
M=&5R<R<@05!)(&-A;&PN"EMM;7-=($EN9V]?4W1O<F%G93HZ(&YO=R!H86YD
M;&5S(&%L;"!S97-S:6]N(&-A8VAI;F<N"EMM;7-=($%D9&5D($E-05`@8VQI
M96YT('-I9&4@26YG;U]38W)I<'0Z.B!D<FEV97(N"@H*+2TM+0IV,"XQ"BTM
M+2T*"EMJ86Y=($%D9"!3=V5D:7-H('1R86YS;&%T:6]N("A!;F1E<G,@3F]R
M<F)R:6YG(#QA;F1E<G-`;F]R<F)R:6YG+F)I>CXI+@I;:F%N72!!9&0@3&ET
M:'5A;FEA;B!T<F%N<VQA=&EO;B`H5FEL:75S(%-U;7-K87,@/'9I;&EU<T!L
M;FLN;'0^*2X*6VIA;ET@061D($ET86QI86X@=')A;G-L871I;VX@*$UA<FMO
M($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^*2X*6VIA;ET@061D($AU;F=A<FEA
M;B!T<F%N<VQA=&EO;B`H071T:6QA($YA9WD@/&)R84!F<VXN:'4^*2X*6VUM
M<UT@061D($1U=&-H('1R86YS;&%T:6]N("A2=6)E;B!V86X@9&5R(%-T965N
M:&]V96X*("`@("`@/')U8F5N7V1O;F]T<W!A;6UE0'=E8FUE97-T97)S+FYE
M=#XI+@I;:F%N72!!9&0@1FEN;FES:"!T<F%N<VQA=&EO;B`H3&5E;F$@2&5I
M;F\@/$QE96YA+DAE:6YO0'5T82YF:3XI+@I;;6US72!!9&1E9"!T:&4@)VUA
M:6PO87!P;'E&:6QT97)S)R!!4$D@8V%L;"X*6V)J;ET@061D('=H:71E;&ES
M="!F=6YC=&EO;G,N"EMJ86Y=($%D9"!'97)M86X@=')A;G-L871I;VXN"EMM
M;7-=($)L86-K;&ES=&5D(&%D9')E<W-E<R!N;W<@<W1O<F5D(&EN('1H92!S
M=&]R86=E(&)A8VME;F0@:6X@87)R87D@9F]R;6%T+@I;;6US72!!9&1E9"!)
M;F=O7U-T;W)A9V4Z.B!D<FEV97(@=&\@86QL;W<@9F]R('-T;W)A9V4@;V8@
M<G5L97,@:6X*("`@("`@=F%R:6]U<R!B86-K96YD<RX*6V)J;ET@06)S=')A
M8W0@4V-R:7!T(&-L87-S+"!A;F0@<')O8VUA:6P@<V-R:7!T('-U<'!O<G0N
M"EMJ86Y=($%D9"!0;VQI<V@@=')A;G-L871I;VX@*%!R>F5M>7-L87<@(E!R
M:6UO(B!7:71E:R`\<')I;6]`;G!L+G!L/BDN"EMJ86Y=($%D9"!2;VUA;FEA
M;B!T<F%N<VQA=&EO;B`H175G96X@2&]A;F-A(#QE=6=E;FA`=7)B86XM9W)A
M9G@N<F\^*2X*6VIA;ET@3&5T('1H92!U<V5R<R!S96QE8W0@=VAA="!S:&]U
M;&0@:&%P<&5N('1O(&5M86EL<R!F<F]M(&)L86-K;&ES=&5D"B`@("`@(&%D
M9')E<W-E<RX*6VIA;ET@061D(%1R861I=&EO;F%L($-H:6YE<V4@=')A;G-L
M871I;VX@*$1A=FED($-H86YG"B`@("`@(#QD879I9$!T:&)U;RYG;W8N='<^
M*2X*6VIA;ET@061D($9R96YC:"!T<F%N<VQA=&EO;B`H1FQO<F5N="!!:61E
M(#QF86ED94!A;'!H86-E;G0N8V]M/BDN"EMJ86Y=($%D9"!A;B!!4$D@9F]R
M($EN9V\N"EMM86-=($%D9"!A('5S97(@<')E9F5R96YC92!T;R!A=71O;6%T
M:6-A;&QY('5P9&%T92!T:&4@<V-R:7!T(&%F=&5R(&$@8VAA;F=E+@I;;6%C
M72!!9&0@82!U<V5R('!R969E<F5N8V4@=&\@:&ED92!T:&4@<V-R:7!T(&EC
M;VXN"EMM86-=($9I>"!S;VUE(')E9V5X(&EN('1H92!S8W)I<'0@9V5N97)A
M=&EO;@I;:F%N72!$969A=6QT('1O(&9I<G-T(&)A8VME;F0@:68@;F\@<')E
M9F5R<F5D(&)A8VME;F0@:7,@<W!E8VEF:65D+V9O=6YD+@I;;6%C72!);FET
M:6%L($-O;6UI="X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+V1O8W,O
M3$E#14Y310``````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`T,C4U`#$P-#$W,S8R-S4P`#`Q-S,Q-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!697)S:6]N(#$N,`H*0V]P>7)I
M9VAT("AC*2`R,#`R+"!4:&4@2&]R9&4@4')O:F5C="`\8V]R94!H;W)D92YO
M<F<^"D%L;"!R:6=H=',@<F5S97)V960N"@I2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70*;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@
M=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS(&%R90IM970Z"@HQ+B!2961I<W1R
M:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E
M(&-O<'ER:6=H=`IN;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"@HR+B!2961I<W1R:6)U=&EO
M;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O
M<'ER:6=H=`IN;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE"F1O8W5M96YT871I;VX@
M86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T
M<FEB=71I;VXN"@HS+B!4:&4@96YD+75S97(@9&]C=6UE;G1A=&EO;B!I;F-L
M=61E9"!W:71H('1H92!R961I<W1R:6)U=&EO;BP@:68*86YY+"!M=7-T(&EN
M8VQU9&4@=&AE(&9O;&QO=VEN9R!A8VMN;W=L961G;65N=#H*"B`@(")4:&ES
M('!R;V1U8W0@:6YC;'5D97,@<V]F='=A<F4@9&5V96QO<&5D(&)Y('1H92!(
M;W)D92!0<F]J96-T"B`@("`H:'1T<#HO+W=W=RYH;W)D92YO<F<O*2XB"@I!
M;'1E<FYA=&5L>2P@=&AI<R!A8VMN;W=L961G;65N="!M87D@87!P96%R(&EN
M('1H92!S;V9T=V%R92!I='-E;&8L(&EF"F%N9"!W:&5R979E<B!S=6-H('1H
M:7)D+7!A<G1Y(&%C:VYO=VQE9&=M96YT<R!N;W)M86QL>2!A<'!E87(N"@HT
M+B!4:&4@;F%M97,@(DAO<F1E(BP@(E1H92!(;W)D92!0<F]J96-T(BP@86YD
M("));F=O(B!M=7-T(&YO="!B92!U<V5D"G1O(&5N9&]R<V4@;W(@<')O;6]T
M92!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T
M"G!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX@1F]R('=R:71T96X@<&5R;6ES
M<VEO;BP@<&QE87-E(&-O;G1A8W0*8V]R94!H;W)D92YO<F<N"@HU+B!0<F]D
M=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!M87D@;F]T(&)E(&-A
M;&QE9"`B2&]R9&4B(&]R"B));F=O(BP@;F]R(&UA>2`B2&]R9&4B(&]R("))
M;F=O(B!A<'!E87(@:6X@=&AE:7(@;F%M92P@=VET:&]U="!P<FEO<@IW<FET
M=&5N('!E<FUI<W-I;VX@;V8@=&AE($AO<F1E(%!R;VIE8W0N"@I42$E3(%-/
M1E1705)%($E3(%!23U9)1$5$(")!4R!)4R(@04Y$($%.62!%6%!215-3140@
M3U(@24U03$E%1`I705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-
M251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1@I-15)#2$%.5$%"
M24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%2
M12!$25-#3$%)345$+@I)3B!.3R!%5D5.5"!32$%,3"!42$4@2$]21$4@4%)/
M2D5#5"!/4B!)5%,@0T].5%))0E543U)3($)%($Q)04),12!&3U(*04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%2
M62P@3U(@0T].4T51545.5$E!3`I$04U!1T53("A)3D-,541)3D<L($)55"!.
M3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5410I'3T]$
M4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[
M($]2($)54TE.15-3"DE.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$
M($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52"DE.($-/3E12
M04-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'
M3$E'14Y#12!/4@I/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@
M3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&"D%$5DE3140@
M3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H*5&AI<R!S;V9T
M=V%R92!C;VYS:7-T<R!O9B!V;VQU;G1A<GD@8V]N=')I8G5T:6]N<R!M861E
M(&)Y(&UA;GD*:6YD:79I9'5A;',@;VX@8F5H86QF(&]F('1H92!(;W)D92!0
M<F]J96-T+B!&;W(@;6]R92!I;F9O<FUA=&EO;B!O;@IT:&4@2&]R9&4@4')O
M:F5C="P@<&QE87-E('-E92`\:'1T<#HO+W=W=RYH;W)D92YO<F<O/BX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;F=O+V1O8W,O24Y35$%,3```````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$W,S,Q`#$P-#$W,S8R-S4P`#`Q-S,T,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*($EN<W1A;&QI;F<@26YG;R`Q+C$*/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#4O,3`O
M,3<@,C,Z-#(Z,3@@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C$T
M+C@N-B`D"CI#;VYT86-T.B`@("`@("!I;F=O0&QI<W1S+FAO<F1E+F]R9PH*
M+BX@8V]N=&5N=',Z.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ
M"@I4:&ES(&1O8W5M96YT(&-O;G1A:6YS(&EN<W1R=6-T:6]N<R!F;W(@:6YS
M=&%L;&EN9R!T:&4@26YG;R!%;6%I;"!&:6QT97(@4G5L97,*36%N86=E<BX*
M"@I/8G1A:6YI;F<@26YG;PH]/3T]/3T]/3T]/3T]/0H*26YG;R!C86X@8F4@
M;V)T86EN960@9G)O;2!T:&4@2&]R9&4@=V5B<VET92!A;F0@1E10('-E<G9E
M<BP@870*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VEN9V\O"B`@(&9T<#HO
M+V9T<"YH;W)D92YO<F<O<'5B+VEN9V\O"@I/<B!U<V4@=&AE(&UI<G)O<B!C
M;&]S97-T('1O('EO=3H*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VUI<G)O
M<G,N<&AP"@I";&5E9&EN9RUE9&=E(&1E=F5L;W!M96YT('9E<G-I;VYS(&]F
M($EN9V\@87)E(&%V86EL86)L92!V:6$@0U93.R!S964@=&AE(&9I;&4*8&AO
M<F1E+V1O8W,O2$%#2TE.1V!?+"!O<B!T:&4@=V5B<VET92!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]S;W5R8V4O+"!F;W(*:6YF;W)M871I;VX@;VX@86-C97-S
M:6YG('1H92!(;W)D92!#5E,@<F5P;W-I=&]R>2X*"@I0<F5R97%U:7-I=&5S
M"CT]/3T]/3T]/3T]/3T*"E1O(&9U;F-T:6]N('!R;W!E<FQY+"!);F=O("HJ
M<F5Q=6ER97,J*B!T:&4@9F]L;&]W:6YG.@H*,2X@02!W;W)K:6YG($AO<F1E
M(&EN<W1A;&QA=&EO;@H*("`@26YG;R!R=6YS('=I=&AI;B!T:&4@8$AO<F1E
M($%P<&QI8V%T:6]N($9R86UE=V]R:V!?+"!A('-E="!O9B!C;VUM;VX@=&]O
M;',*("`@9F]R(%=E8B!A<'!L:6-A=&EO;G,@=W)I='1E;B!I;B!02%`N("!9
M;W4@;75S="!I;G-T86QL($AO<F1E(&)E9F]R90H@("!I;G-T86QL:6YG($EN
M9V\N"@H@("`N+B!);7!O<G1A;G0Z.B!);F=O(#$N,"!R97%U:7)E<R!V97)S
M:6]N(#,N,"L@;V8@=&AE($AO<F1E($9R86UE=V]R:R`M"B`@("`@("`@("`@
M("`@("`@(&5A<FQI97(@=F5R<VEO;G,@;V8@2&]R9&4@=VEL;"`J*FYO="HJ
M('=O<FLN"@H@("`N+B!?8$AO<F1E($%P<&QI8V%T:6]N($9R86UE=V]R:V`Z
M(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VAO<F1E+PH*("`@5&AE($AO<F1E($9R
M86UE=V]R:R!C86X@8F4@;V)T86EN960@9G)O;2!T:&4@2&]R9&4@=V5B<VET
M92!A;F0@1E10('-E<G9E<BP*("`@870*"B`@("`@(&AT='`Z+R]W=W<N:&]R
M9&4N;W)G+VAO<F1E+PH*("`@("`@9G1P.B\O9G1P+FAO<F1E+F]R9R]P=6(O
M:&]R9&4O"@H@("!-86YY(&]F($EN9V\G<R!P<F5R97%U:7-I=&5S(&%R92!A
M;'-O($AO<F1E('!R97)E<75I<VET97,N"@H@("`N+B!);7!O<G1A;G0Z.B!"
M92!S=7)E('1O(&AA=F4@8V]M<&QE=&5D(&%L;"!O9B!T:&4@<W1E<',@:6X@
M=&AE"B`@("`@("`@("`@("`@("`@(&!H;W)D92]D;V-S+TE.4U1!3$Q@7R!F
M:6QE(&9O<B!T:&4@2&]R9&4@1G)A;65W;W)K(&)E9F]R90H@("`@("`@("`@
M("`@("`@("!I;G-T86QL:6YG($EN9V\N"@HR+B!4:&4@9F]L;&]W:6YG(%!(
M4"!C87!A8FEL:71I97,Z"@H@("!A+B!)34%0(&%N9"!03U`S('-U<'!O<G0@
M8&`M+7=I=&@M:6UA<&!@(%M/4%1)3TY!3%T*"B`@("`@(%!(4"!U<V5S('1H
M92!55RU)34%0(&,M8VQI96YT(&QI8G)A<GD@=&\@<')O=FED92!)34%0(&%N
M9"!03U`S"B`@("`@('-U<'!O<G0N("!)34%0('-U<'!O<G0@:7,@;VYL>2!N
M96-E<W-A<GD@:68@>6]U('=I;&P@8F4@=7-I;F<@=&AE"B`@("`@(&-L:65N
M="US:61E(&EM87`@9')I=F5R("AS964@8&!I;F=O+V-O;F9I9R]B86-K96YD
M<RYP:'!@8"DN"@H@("`@("!#+6-L:65N="!I<R!A=F%I;&%B;&4@9G)O;0H*
M("`@("`@("`@9G1P.B\O9G1P+F-A8RYW87-H:6YG=&]N+F5D=2]I;6%P+PH*
M,RX@5&AE(&9O;&QO=VEN9R!014%2(&UO9'5L97,Z"B`@("A3964@8&AO<F1E
M+V1O8W,O24Y35$%,3&!?(&9O<B!I;G-T<G5C=&EO;G,@;VX@:6YS=&%L;&EN
M9R!014%2(&UO9'5L97,I"@H@("!A+B!.971?4VEE=F4@,2XP+C$@6T]05$E/
M3D%,70H@(`H@("`@("!);F=O('5S97,@=&AE($YE=%]3:65V92!C;&%S<R!F
M;W(@8V]M;75N:6-A=&EN9R!W:71H('1I;7-I979E9"!R=6YN:6YG"B`@("`@
M(&]N($-Y<G5S(&UA:6P@<V5R=F5R<RX@(%EO=2!W:6QL(&]N;'D@;F5E9"!T
M;R!I;G-T86QL('1H:7,@8VQA<W,@:68@>6]U"B`@("`@(&%R92!U<VEN9R!3
M:65V92!F;W(@9FEL=&5R:6YG+@H*("`@8BX@3F5T7U-O8VME="!;3U!424].
M04Q="@H@("`@("!.971?4V]C:V5T(&ES('5S960@8GD@3F5T7U-I979E(&%N
M9"P@=&AU<RP@:7,@;VYL>2!R97%U:7)E<R!I9B!Y;W4@=VEL;`H@("`@("!B
M92!U<VEN9R!3:65V92!F:6QT97)I;F<N("!014%2("IS:&]U;&0J(&EN<W1A
M;&P@3F5T7U-O8VME="!W:&5N(&ET"B`@("`@(&EN<W1A;&QS($YE=%]3:65V
M92X*"@I);G-T86QL:6YG($EN9V\*/3T]/3T]/3T]/3T]/3T]"@I);F=O(&ES
M('=R:71T96X@:6X@4$A0+"!A;F0@;75S="!B92!I;G-T86QL960@:6X@82!W
M96(M86-C97-S:6)L92!D:7)E8W1O<GDN"E1H92!P<F5C:7-E(&QO8V%T:6]N
M(&]F('1H:7,@9&ER96-T;W)Y('=I;&P@9&EF9F5R(&9R;VT@<WES=&5M('1O
M('-Y<W1E;2X*0V]N=F5N=&EO;F%L;'DL($EN9V\@:7,@:6YS=&%L;&5D(&1I
M<F5C=&QY('5N9&5R;F5A=&@@2&]R9&4@:6X@=&AE('=E8G-E<G9E<B=S"F1O
M8W5M96YT('1R964N"@I3:6YC92!);F=O(&ES('=R:71T96X@:6X@4$A0+"!T
M:&5R92!I<R!N;R!C;VUP:6QA=&EO;B!N96-E<W-A<GD[('-I;7!L>2!E>'!A
M;F0*=&AE(&1I<W1R:6)U=&EO;B!W:&5R92!Y;W4@=V%N="!I="!T;R!R97-I
M9&4@86YD(')E;F%M92!T:&4@<F]O="!D:7)E8W1O<GD@;V8*=&AE(&1I<W1R
M:6)U=&EO;B!T;R!W:&%T979E<B!Y;W4@=VES:"!T;R!A<'!E87(@:6X@=&AE
M(%523"X@($9O<B!E>&%M<&QE+"!W:71H"G1H92!!<&%C:&4@=V5B<V5R=F5R
M)W,@9&5F875L="!D;V-U;65N="!R;V]T(&]F(&!@+W5S<B]L;V-A;"]A<&%C
M:&4O:'1D;V-S8&`L"GEO=2!W;W5L9"!T>7!E.CH*"B`@(&-D("]U<W(O;&]C
M86PO87!A8VAE+VAT9&]C<R]H;W)D90H@("!T87(@>GAV9B`O<&%T:"]T;R]I
M;F=O+7@N>2YZ+G1A<BYG>@H@("!M=B!I;F=O+7@N>2YZ(&EN9V\*"F%N9"!W
M;W5L9"!T:&5N(&9I;F0@26YG;R!A="!T:&4@55),.CH*"B`@(&AT='`Z+R]Y
M;W5R+7-E<G9E<B]H;W)D92]I;F=O+PH*"D-O;F9I9W5R:6YG($EN9V\*/3T]
M/3T]/3T]/3T]/3T]/0H*,2X@0V]N9FEG=7)I;F<@2&]R9&4@9F]R($EN9V\*
M"B`@(&$N(%)E9VES=&5R('1H92!A<'!L:6-A=&EO;@H*("`@("`@26X@8&!H
M;W)D92]C;VYF:6<O<F5G:7-T<GDN<&AP8&`L(&9I;F0@=&AE(&%P<&QI8V%T
M:6]N<ULG:6YG;R==('-T86YZ82X*("`@("`@5&AE(&1E9F%U;'0@<V5T=&EN
M9W,@:&5R92!S:&]U;&0@8F4@;VMA>2P@8G5T('EO=2!C86X@8VAA;F=E('1H
M96T@:68*("`@("`@9&5S:7)E9"X@($EF('EO=2!H879E(&-H86YG960@=&AE
M(&QO8V%T:6]N(&]F($EN9V\@<F5L871I=F4@=&\@2&]R9&4L"B`@("`@(&5I
M=&AE<B!I;B!T:&4@55),+"!I;B!T:&4@9FEL97-Y<W1E;2!O<B!B;W1H+"!Y
M;W4@;75S="!U<&1A=&4@=&AE"B`@("`@(&!@9FEL97)O;W1@8"!A;F0@8&!W
M96)R;V]T8&`@<V5T=&EN9W,@=&\@=&AE:7(@8V]R<F5C="!V86QU97,N"@HR
M+B!#;VYF:6=U<FEN9R!);F=O"@H@("!4;R!C;VYF:6=U<F4@26YG;RP@8VAA
M;F=E('1O('1H92!@8&-O;F9I9R]@8"!D:7)E8W1O<GD@;V8@=&AE(&EN<W1A
M;&QE9`H@("!D:7-T<FEB=71I;VXL(&%N9"!M86ME(&-O<&EE<R!O9B!A;&P@
M;V8@=&AE(&-O;F9I9W5R871I;VX@8&!D:7-T8&`@9FEL97,*("`@=VET:&]U
M="!T:&4@8&!D:7-T8&`@<W5F9FEX.CH*"B`@("`@(&-D(&-O;F9I9R\*("`@
M("`@9F]R(&9O;R!I;B`J+F1I<W0[(&1O(&-P("1F;V\@8&)A<V5N86UE("1F
M;V\@+F1I<W1@.R!D;VYE"@H@("!/<B!O;B!7:6YD;W=S.CH*"B`@("`@(&-O
M<'D@*BYD:7-T("HN"@H@("!$;V-U;65N=&%T:6]N(&]N('1H92!F;W)M870@
M;V8@=&AO<V4@9FEL97,@8V%N(&)E(&9O=6YD(&EN(&5A8V@@9FEL92X@(%=I
M=&@*("`@=&AE(&5X8V5P=&EO;B!O9B!T:&4@8&!C;VYF+BI@8"!F:6QE<R`H
M<V5E(&)E;&]W*2!A;F0@8&!B86-K96YD<RYP:'!@8"P@=&AE"B`@(&]T:&5R
M(&9I;&5S(&EN(&!@8V]N9FEG+V!@(&YE960@;VYL>2!B92!M;V1I9FEE9"!I
M9B!Y;W4@=VES:"!T;R!C=7-T;VUI>F4*("`@26YG;R=S(&%P<&5A<F%N8V4@
M;W(@8F5H879I;W(L(&%S('1H92!D969A=6QT<R!W:6QL(&)E(&-O<G)E8W0@
M9F]R(&UO<W0*("`@<VET97,N"@H@("!9;W4@;75S="!L;V=I;B!T;R!(;W)D
M92!A<R!A($AO<F1E($%D;6EN:7-T<F%T;W(@=&\@9FEN:7-H('1H90H@("!C
M;VYF:6=U<F%T:6]N(&]F($EN9V\N("!5<V4@=&AE($AO<F1E(&!@061M:6YI
M<W1R871I;VY@8"!M96YU(&ET96T@=&\@9V5T"B`@('1O('1H92!A9&UI;FES
M=')A=&EO;B!P86=E+"!A;F0@=&AE;B!C;&EC:R!O;B!T:&4@8&!#;VYF:6=U
M<F%T:6]N8&`@:6-O;B!T;PH@("!G970@=&AE(&-O;F9I9W5R871I;VX@<&%G
M92X@(%-E;&5C="!@8$9I;'1E<G-@8"!F<F]M('1H92!S96QE8W1I;VX@;&ES
M="!O9@H@("!A<'!L:6-A=&EO;G,N("!&:6QL(&EN(&]R(&-H86YG92!A;GD@
M8V]N9FEG=7)A=&EO;B!V86QU97,@87,@;F5E9&5D+B`@5VAE;@H@("!D;VYE
M(&-L:6-K(&]N(&!@1V5N97)A=&4@1FEL=&5R<R!#;VYF:6=U<F%T:6]N8&`@
M=&\@9V5N97)A=&4@=&AE"B`@(&!@8V]N9BYP:'!@8"!F:6QE+B`@268@>6]U
M<B!W96(@<V5R=F5R(&1O97-N)W0@:&%V92!W<FET92!P97)M:7-S:6]N<R!T
M;PH@("!T:&4@26YG;R!C;VYF:6=U<F%T:6]N(&1I<F5C=&]R>2!O<B!F:6QE
M+"!I="!W:6QL(&YO="!B92!A8FQE('1O('=R:71E('1H90H@("!F:6QE+B`@
M26X@=&AI<R!C87-E+"!G;R!B86-K('1O(&!@0V]N9FEG=7)A=&EO;F!@(&%N
M9"!C:&]O<V4@;VYE(&]F('1H90H@("!O=&AE<B!M971H;V1S('1O(&-R96%T
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE(&!@:6YG;R]C;VYF:6<O8V]N9BYP
M:'!@8"X*"B`@($YO=&4@9F]R(&EN=&5R;F%T:6]N86P@=7-E<G,Z($EN9V\@
M=7-E<R!'3E4@9V5T=&5X="!T;R!P<F]V:61E(&QO8V%L"B`@('1R86YS;&%T
M:6]N<R!O9B!T97AT(&1I<W!L87EE9"!B>2!A<'!L:6-A=&EO;G,[('1H92!T
M<F%N<VQA=&EO;G,@87)E(&9O=6YD"B`@(&EN('1H92!P;R\@9&ER96-T;W)Y
M+B`@268@82!T<F%N<VQA=&EO;B!I<R!N;W0@>65T(&%V86EL86)L92!F;W(@
M>6]U<@H@("!L;V-A;&4@*&%N9"!Y;W4@=VES:"!T;R!C<F5A=&4@;VYE*2P@
M<V5E('1H92!@8&AO<F1E+W!O+U)%041-16!@(&9I;&4L(&]R"B`@(&EF('EO
M=2=R92!H879I;F<@=')O=6)L92!U<VEN9R!A('!R;W9I9&5D('1R86YS;&%T
M:6]N+"!P;&5A<V4@<V5E('1H90H@("!@:&]R9&4O9&]C<R]44D%.4TQ!5$E/
M3E-@7R!F:6QE(&9O<B!I;G-T<G5C=&EO;G,N"@HS+B!-:6=R871I;F<@97AI
M<W1I;F<@9FEL=&5R(')U;&5S(&9R;VT@24U0(#,N>"!T;R!);F=O(#$N>`H*
M("`@26YG;R!R97!L86-E<R!T:&4@9FEL=&5R('-Y<W1E;2!O9B!)35`@,RYX
M+B`@268@>6]U(&%R92!U<VEN9R!);F=O('1O9V5T:&5R"B`@('=I=&@@24U0
M(&%N9"!Y;W4@87)E('5P9W)A9&EN9R!)35`@9G)O;2!V97)S:6]N(#,N>"!T
M;R`T+G@L('EO=2!N965D('1O"B`@(&UI9W)A=&4@=&AE(&5X:7-T:6YG($E-
M4"!F:6QT97(@<G5L97,@=&\@26YG;R!F:6QT97(@<G5L97,N"@H@("!4;R!C
M;VYV97)T('1H92!F:6QT97)S+"!Y;W4@=VEL;"!N965D(&$@;&ES="!O9B!A
M;&P@=7-E<G,@=VAO<V4@9FEL=&5R<R!Y;W4*("`@=V%N="!T;R!C;VYV97)T
M+B`@4V%V92!T:&ES('5S97(@;&ES="!I;B!A('1E>'0@9FEL92!W:71H(&5A
M8V@@=7-E<B!N86UE(&]N"B`@(&$@<V5P87)A=&4@;&EN92X@(%1H92!U<V5R
M(&YA;65S(&UU<W0@8F4@=&AE('-A;64@=&AA="!A<F4@=7-E9"!T;R!S=&]R
M90H@("!U<V5R('!R969E<F5N8V5S(&EN('1H92!P<F5F97)E;F-E(&)A8VME
M;F0N"@H@("!.;W<@8V%L;"!T:&4@8V]N=F5R<VEO;B!S8W)I<'0@8&!S8W)I
M<'1S+V-O;G9E<G1?:6UP7V9I;'1E<G,N<&AP8&`@86YD(&9E960*("`@:70@
M=VET:"!Y;W5R('5S97(@;&ES=#HZ"@H@("`@('!H<"!C;VYV97)T7V9I;'1E
M<G,N<&AP(#P@=7-E<FQI<W0N='AT"@H@("`N+B!(:6YT.CH@66]U(&-A;B!A
M;'-O(&5N=&5R('1H92!U<V5R<R!M86YU86QL>2!B>2!C86QL:6YG('1H92!S
M8W)I<'0L"B`@("`@("`@("`@("!E;G1E<FEN9R!T:&4@=7-E<B!N86UE<R!E
M86-H(&-O;F9I<FUE9"!W:71H('1H92!@8$5N=&5R8&`@:V5Y+`H@("`@("`@
M("`@("`@86YD(&9I;F%L;'D@<')E<W-I;F<@8&!#=')L*T1@8"!W:&5N('EO
M=2=R92!D;VYE+@H*2VYO=VX@4')O8FQE;7,*/3T]/3T]/3T]/3T]/3T*"E-O
M;64@<&5O<&QE(&5X<&5R:65N8V5D('!R;V)L96US('=I=&@@26YG;R=S(%-I
M979E(&1R:79E<B!A;F0@0WER=7,@,BXQ+C$R+@I4:&4@(F%D9&9L86<O<F5M
M;W9E9FQA9R(@4VEE=F4@8V]M;6%N9',@8V%N(&-A=7-E(&UE<W-A9V4@8V]P
M:65S('-T:6-K:6YG(&EN"D-Y<G5S)R!M97-S86=E('%U975E<R!P<F]D=6-I
M;F<@(G9I<G1U86P@;65M;W)Y(&5X:&%U<W1E9"(@97)R;W)S+B`@270@=V%S
M"G)E<&]R=&5D('1H870@=7!G<F%D:6YG('1O('9E<G-I;VX@,BXQ+C$U(&AA
M<R!F:7AE9"!T:&ES('!R;V)L96TN"@H*3V)T86EN:6YG(%-U<'!O<G0*/3T]
M/3T]/3T]/3T]/3T]/3T*"DEF('EO=2!E;F-O=6YT97(@<')O8FQE;7,@=VET
M:"!);F=O+"!H96QP(&ES(&%V86EL86)L92$*"E1H92!(;W)D92!&<F5Q=65N
M=&QY($%S:V5D(%%U97-T:6]N<R!,:7-T("A&05$I+"!A=F%I;&%B;&4@;VX@
M=&AE(%=E8B!A=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]F87$O"@I4:&4@
M2&]R9&4@4')O:F5C="!R=6YS(&$@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',L
M(&9O<B!I;F1I=FED=6%L(&%P<&QI8V%T:6]N<PIA;F0@9F]R(&ES<W5E<R!R
M96QA=&EN9R!T;R!T:&4@<')O:F5C="!A<R!A('=H;VQE+B`@26YF;W)M871I
M;VXL(&%R8VAI=F5S+"!A;F0*<W5B<V-R:7!T:6]N(&EN9F]R;6%T:6]N(&-A
M;B!B92!F;W5N9"!A=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]M86EL+PH*
M3&%S=&QY+"!(;W)D92!D979E;&]P97)S+"!C;VYT<FEB=71O<G,@86YD('5S
M97)S(&%L<V\@;6%K92!O8V-A<VEO;F%L"F%P<&5A<F%N8V5S(&]N($E20RP@
M;VX@=&AE(&-H86YN96P@(VAO<F1E(&]N('1H92!&<F5E;F]D92!.971W;W)K
M"BAI<F,N9G)E96YO9&4N;F5T*2X*"E!L96%S92!K965P(&EN(&UI;F0@=&AA
M="!);F=O(&ES(&9R964@<V]F='=A<F4@=W)I='1E;B!B>2!V;VQU;G1E97)S
M+@I&;W(@:6YF;W)M871I;VX@;VX@<F5A<V]N86)L92!S=7!P;W)T(&5X<&5C
M=&%T:6]N<RP@<&QE87-E(')E860*"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M<W5P<&]R="YP:'`*"E1H86YK<R!F;W(@=7-I;F<@26YG;R$*"E1H92!);F=O
M('1E86T*"@HN+B!?8&AO<F1E+V1O8W,O2$%#2TE.1V`Z("XN+RXN+VAO<F1E
M+V1O8W,O/V8]2$%#2TE.1RYH=&UL"BXN(%]@:&]R9&4O9&]C<R])3E-404Q,
M8#H@+BXO+BXO:&]R9&4O9&]C<R\_9CU)3E-404Q,+FAT;6P*+BX@7V!H;W)D
M92]D;V-S+U1204Y33$%424].4V`Z("XN+RXN+VAO<F1E+V1O8W,O/V8]5%)!
M3E-,051)3TY3+FAT;6P*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6YG;R]D;V-S+U)%3$5!4T5?3D]415,`
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S4T-0`Q,#0Q
M-S,V,C<U,``P,C`R-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%)E;&5A<V4@9F]C=7,N(%!O<W-I
M8FQE('9A;'5E<SH*("H@,"`M($XO00H@*B`Q("T@26YI=&EA;"!F<F5S:&UE
M870@86YN;W5N8V5M96YT"B`J(#(@+2!$;V-U;65N=&%T:6]N"B`J(#,@+2!#
M;V1E(&-L96%N=7`*("H@-"`M($UI;F]R(&9E871U<F4@96YH86YC96UE;G1S
M"B`J(#4@+2!-86IO<B!F96%T=7)E(&5N:&%N8V5M96YT<PH@*B`V("T@36EN
M;W(@8G5G9FEX97,*("H@-R`M($UA:F]R(&)U9V9I>&5S"B`J(#@@+2!-:6YO
M<B!S96-U<FET>2!F:7AE<PH@*B`Y("T@36%J;W(@<V5C=7)I='D@9FEX97,*
M("HO"B1T:&ES+3YN;W1E<ULG9FTG75LG9F]C=7,G72`](#4["@HO*B!-86EL
M:6YG(&QI<W0@<F5L96%S92!N;W1E<RX@*B\*)'1H:7,M/FYO=&5S6R=M;"==
M6R=C:&%N9V5S)UT@/2`\/#Q-3`I4:&4@2&]R9&4@5&5A;2!I<R!P;&5A<V5D
M('1O(&%N;F]U;F-E('1H92!F:6YA;"!R96QE87-E(&]F('1H92!);F=O($5M
M86EL"D9I;'1E<B!2=6QE<R!-86YA9V5R('9E<G-I;VX@2#,@*#$N,2DN"@I)
M;F=O(&ES(&%N(&5M86EL+69I;'1E<B!M86YA9V5M96YT(&%P<&QI8V%T:6]N
M+B!)="!I<R!F=6QL>2!I;G1E<FYA=&EO;F%L:7IE9"P*:6YT96=R871E9"!W
M:71H($AO<F1E(&%N9"!T:&4@24U0(%=E8FUA:6P@8VQI96YT+"!A;F0@<W5P
M<&]R=',@8F]T:`IS97)V97(M<VED92`H4VEE=F4L('!R;V-M86EL+"!M86EL
M9')O<"D@86YD(&-L:65N="US:61E("A)34%0*2!R=6QE(&-R96%T:6]N+@H*
M36%J;W(@8VAA;F=E<R!C;VUP87)E9"!T;R!T:&4@26YG;R!(,R`H,2XP*2!V
M97)S:6]N<R!A<F4Z"B`@("`J($UA:6QD<F]P('-C<FEP="!D<FEV97(N"B`@
M("`J($9L86<M;VYL>2!A;F0@;F]T:69Y(')U;&5S+@H@("`@*B!-;W9I;F<@
M<G5L97,@8GD@<W!E8VEF>6EN9R!T:&5I<B!P;W-I=&EO;G,N"B`@("`J(%!O
M<G1A;"!B;&]C:RX*("`@("H@0V]M<&%T:6)L92!W:71H(%!(4"`U+C$N"B`@
M("`J(%-U<'!O<G0@9F]R('-T;W)I;F<@4VEE=F4@<G5L97,@:6X@3$1!4"`H
M4W5N($I%4R]/3D4@86YD(&E0;&%N970*("`@("`@;65S<V%G:6YG('-E<G9E
M<G,I+@H@("`@*B!097)M:7-S:6]N<R!T;R!R97-T<FEC="!F:6QT97(@<G5L
M92!C<F5A=&EO;BX*("`@("H@4W5P<&]R="!F;W(@)UY43U\G('!R;V-M86EL
M(')U;&4@;6%T8VAI;F<N"B`@("`J($YE=R!T<F%N<VQA=&EO;G,Z($1A;FES
M:"P@4&]R='5G=65S92P@5'5R:VES:"X*34P["@HO*B!&<F5S:&UE870@<F5L
M96%S92!N;W1E<RP@;F]T(&UO<F4@=&AA;B`V,#`@8VAA<F%C=&5R<RX@*B\*
M)'1H:7,M/FYO=&5S6R=F;2==6R=C:&%N9V5S)UT@/2`\/#Q&30I3=7!P;W)T
M(&9O<B!-86EL9')O<"!H87,@8F5E;B!A9&1E9"X*1FQA9RUO;FQY(&%N9"!N
M;W1I9GD@<G5L97,@:&%V92!B965N(&%D9&5D+@I2=6QE<R!C86X@8F4@;6]V
M960@8GD@<W!E8VEF>6EN9R!T:&5I<B!P;W-I=&EO;G,N"D$@<&]R=&%L(&)L
M;V-K(&AA<R!B965N(&%D9&5D+@I3=7!P;W)T(&9O<B!S=&]R:6YG(%-I979E
M(')U;&5S(&EN($Q$05`@*%-U;B!*15,O3TY%(&%N9"!I4&QA;F5T"FUE<W-A
M9VEN9R!S97)V97)S*2!H87,@8F5E;B!A9&1E9"X*4&5R;6ES<VEO;G,@=&\@
M<F5S=')I8W0@9FEL=&5R(')U;&4@8W)E871I;VX@:&%V92!B965N(&%D9&5D
M+@I3=7!P;W)T(&9O<B`G7E1/7R<@<')O8VUA:6P@<G5L92!M871C:&EN9R!H
M87,@8F5E;B!A9&1E9"X*1&%N:7-H+"!0;W)T=6=U97-E+"!A;F0@5'5R:VES
M:"!T<F%N<VQA=&EO;G,@:&%V92!B965N(&%D9&5D+@I&33L*"B1T:&ES+3YN
M;W1E<ULG;F%M92==(#T@)TEN9V\G.PHD=&AI<RT^;F]T97-;)V9M)UU;)W!R
M;VIE8W0G72`]("=I;F=O)SL*)'1H:7,M/FYO=&5S6R=F;2==6R=B<F%N8V@G
M72`]("=$969A=6QT)SL*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEN9V\O9&]C<R]43T1/````````````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-S(`,3`T,3<S-C(W
M-3``,#$W,#`P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*($EN9V\@1&5V
M96QO<&UE;G0@5$]$3R!,:7-T"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-2\Q,"\Q-R`R,SHS.3HP
M,R`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N,3`N,3`N,2`D"CI#
M;VYT86-T.B`@("`@("!I;F=O0&QI<W1S+FAO<F1E+F]R9PH*+2!"971T97(@
M8VAE8VMS(&9O<B!B=6QK(&%N9"!M86EL:6YG(&QI<W1S(&EN('9A8V%T:6]N
M+@H*+2!!('-M87)T(&-O;7!O<VET92!D<FEV97(@=&AA="!W;W5L9"!L970@
M>6]U(&1E9FEN92!S97!E<F%T92!D<FEV97)S(&9O<@H@(&9O<G=A<F1S+"!V
M86-A=&EO;BP@86YD(&9I;'1E<G,N("!3:&]U;&0@86QS;R!D969I;F4@=&AE
M(&]R9&5R(&]F('1H;W-E"B`@8F%C:V5N9',@<V\@=&AA="!);F=O(&]N;'D@
M86QL;W=S(')E+6%R<F%N9VEN9R!O9B!R=6QE(&]R9&5R('=I=&AI;B!T:&4*
M("!C;W)R96-T(&)O=6YD<RX*````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;F=O+V9O<G=A<F0N<&AP````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(Q`#$P-#$W,S8R-S4P`#`Q-S4R-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!I;F=O+V9O<G=A<F0N<&AP+'8@,2XQ,2XX+C4@
M,C`P-B\P,2\S,2`R,#HP,#HR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!4;V1D($UE<G)I='0@/'1M97)R:71T0&5M86EL+F%R:7IO
M;F$N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO
M<F<O;&EC96YS97,O87-L+G!H<"X*("HO"@I`9&5F:6YE*"=)3D=/7T)!4T4G
M+"`@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@24Y'3U]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@4F5D:7)E8W0@:68@9F]R=V%R9"!I
M<R!N;W0@879A:6QA8FQE+B`J+PII9B`H(6EN7V%R<F%Y*$E.1T]?4U1/4D%'
M15]!0U1)3TY?1D]25T%21"P@)%]315-324].6R=I;F=O)UU;)W-C<FEP=%]C
M871E9V]R:65S)UTI*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D9O
M<G=A<F0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT97)I
M;F<@9')I=F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C
M871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)V9I;'1E<G,N<&AP
M)RP@=')U92DI.PH@("`@97AI=#L*?0H*+RH@1V5T('1H92!F;W)W87)D(&]B
M:F5C="X@*B\*)&9O<G=A<F0@/2`F)&EN9V]?<W1O<F%G92T^<F5T<FEE=F4H
M24Y'3U]35$]204=%7T%#5$E/3E]&3U)705)$*3L*"B\J(%!E<F9O<FT@<F5Q
M=65S=&5D(&%C=&EO;G,N("HO"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$
M871A*"=A8W1I;VY)1"<I.PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=U
M<&1A=&4G.@H@("`@)&9O<G=A<F0M/G-E=$9O<G=A<F1!9&1R97-S97,H571I
M;#HZ9V5T1F]R;41A=&$H)V%D9')E<W-E<R<I*3L*("`@("1F;W)W87)D+3YS
M971&;W)W87)D2V5E<"@H:6YT=F%L*%5T:6PZ.F=E=$9O<FU$871A*"=K965P
M7V-O<'DG*2D@/3T@,2DI.PH@("`@:68@*&ES7V$H)')E<W5L="`]("1I;F=O
M7W-T;W)A9V4M/G-T;W)E*"1F;W)W87)D*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="D["B`@("!](&5L
M<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B0VAA;F=E<R!S
M879E9"XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!I9B`H)'!R969S
M+3YG971686QU92@G875T;U]U<&1A=&4G*2D@>PH@("`@("`@("`@("!);F=O
M.CIU<&1A=&538W)I<'0H*3L*("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*
M?0H*+RH@1V5T('1H92!F;W)W87)D(')U;&4N("HO"B1F:6QT97)S(#T@)B1I
M;F=O7W-T;W)A9V4M/G)E=')I979E*$E.1T]?4U1/4D%'15]!0U1)3TY?1DE,
M5$524RD["B1F=V1?<G5L92`]("1F:6QT97)S+3YF:6YD4G5L92A)3D=/7U-4
M3U)!1T5?04-424].7T9/4E=!4D0I.PH*)'1I=&QE(#T@7R@B1F]R=V%R9',@
M161I="(I.PIR97%U:7)E($E.1T]?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["G)E<75I<F4@24Y'3U]414U03$%415,@+B`G+VUE;G4N:6YC
M)SL*<F5Q=6ER92!)3D=/7U1%35!,051%4R`N("<O9F]R=V%R9"]F;W)W87)D
M+FEN8R<["G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6YG;R]F:6QT97)S+G!H<```````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`R-#<S,P`Q,#0Q-S,V,C<U,``P,3<U-#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:6YG;R]F:6QT97)S+G!H<"QV(#$N-3DN,BXW(#(P,#8O
M,#$O,S$@,C`Z,#`Z,C,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$%33"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N
M<V5S+V%S;"YP:'`N"B`J+PH*0&1E9FEN92@G24Y'3U]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@24Y'3U]"05-%("X@)R]L:6(O
M8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L871E+G!H<"<[
M"@HO*B!'970@=&AE(&QI<W0@;V8@9FEL=&5R(')U;&5S+B`J+PHD9FEL=&5R
M<R`]("8D:6YG;U]S=&]R86=E+3YR971R:65V92A)3D=/7U-43U)!1T5?04-4
M24].7T9)3%1%4E,I.PII9B`H:7-?82@D9FEL=&5R<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"1F:6QT97)S+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PI]"@HO*B!,;V%D('1H92!);F=O7U-C<FEP=#HZ(&1R:79E<BX@
M*B\*)&EN9V]?<V-R:7!T(#T@)DEN9V\Z.FQO861);F=O4V-R:7!T*"D["@HO
M*B!$971E<FUI;F4@:68@=V4@;F5E9"!T;R!S:&]W('1H92!O;BUD96UA;F0@
M<V5T=&EN9W,N("HO"B1O;E]D96UA;F0@/2`D:6YG;U]S8W)I<'0M/G!E<F9O
M<FU!=F%I;&%B;&4H*3L*"B\J($=E="!W96(@<&%R86UE=&5R(&1A=&$N("HO
M"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PHD
M:60@/2!5=&EL.CIG971&;W)M1&%T82@G<G5L96YU;6)E<B<I.PH*+RH@4&5R
M9F]R;2!R97%U97-T960@86-T:6]N<RX@*B\*<W=I=&-H("@D86-T:6]N240I
M('L*8V%S92`G<G5L95]D;W=N)SH*8V%S92`G<G5L95]U<"<Z"F-A<V4@)W)U
M;&5?8V]P>2<Z"F-A<V4@)W)U;&5?9&5L971E)SH*8V%S92`G<G5L95]D:7-A
M8FQE)SH*8V%S92`G<G5L95]E;F%B;&4G.@H@("`@<W=I=&-H("@D86-T:6]N
M240I('L*("`@(&-A<V4@)W)U;&5?9&5L971E)SH*("`@("`@("!I9B`H)&9I
M;'1E<G,M/F1E;&5T95)U;&4H)&ED*2D@>PH@("`@("`@("`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*%\H(E)U;&4@1&5L971E9"(I+"`G:&]R9&4N<W5C8V5S
M<R<I.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=R=6QE
M7V-O<'DG.@H@("`@("`@(&EF("@A26YG;SHZ:&%S4&5R;6ES<VEO;B@G86QL
M;W=?<G5L97,G*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]($!H=&UL<W!E
M8VEA;&-H87)S*%\H(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&]R
M(&5D:70@8W5S=&]M(')U;&5S+B(I+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H
M87)S970H*2D["B`@("`@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS
M)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@("`@("`@("`@("`D;65S<V%G
M92`]($AO<F1E.CIC86QL2&]O:R@G7W!E<FUS7VAO;VM?9&5N:65D)RP@87)R
M87DH)VEN9V\Z86QL;W=?<G5L97,G*2P@)VAO<F1E)RP@)&UE<W-A9V4I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M)&UE<W-A9V4L("=H;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I
M*3L*("`@("`@("`@("`@8G)E86L@,CL*("`@("`@("!](&5L<V5I9B`H26YG
M;SHZ:&%S4&5R;6ES<VEO;B@G;6%X7W)U;&5S)RD@(3T]('1R=64@)B8*("`@
M("`@("`@("`@("`@("`@26YG;SHZ:&%S4&5R;6ES<VEO;B@G;6%X7W)U;&5S
M)RD@/#T@8V]U;G0H)&9I;'1E<G,M/F=E=$9I;'1E<DQI<W0H*2DI('L*("`@
M("`@("`@("`@)&UE<W-A9V4@/2!`:'1M;'-P96-I86QC:&%R<RAS<')I;G1F
M*%\H(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!R=6QE<RXB*2P@26YG;SHZ:&%S4&5R;6ES<VEO;B@G;6%X7W)U;&5S)RDI
M+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@
M(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W!E<FUS9&5N:65D)UTI*2![
M"B`@("`@("`@("`@("`@("`D;65S<V%G92`]($AO<F1E.CIC86QL2&]O:R@G
M7W!E<FUS7VAO;VM?9&5N:65D)RP@87)R87DH)VEN9V\Z;6%X7W)U;&5S)RDL
M("=H;W)D92<L("1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*"1M97-S86=E+"`G:&]R9&4N97)R;W(G
M+"!A<G)A>2@G8V]N=&5N="YR87<G*2D["B`@("`@("`@("`@(&)R96%K(#([
M"B`@("`@("`@?2!E;'-E:68@*"1F:6QT97)S+3YC;W!Y4G5L92@D:60I*2![
M"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B4G5L92!#;W!I
M960B*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!]"B`@("`@("`@8G)E
M86L["@H@("`@8V%S92`G<G5L95]U<"<Z"B`@("`@("`@)'-T97!S(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W-T97!S)RP@,2D["B`@("`@("`@)&9I;'1E<G,M
M/G)U;&55<"@D:60L("1S=&5P<RD["B`@("`@("`@8G)E86L["@H@("`@8V%S
M92`G<G5L95]D;W=N)SH*("`@("`@("`D<W1E<',@/2!5=&EL.CIG971&;W)M
M1&%T82@G<W1E<',G+"`Q*3L*("`@("`@("`D9FEL=&5R<RT^<G5L941O=VXH
M)&ED+"`D<W1E<',I.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)W)U;&5?
M9&ES86)L92<Z"B`@("`@("`@)&9I;'1E<G,M/G)U;&5$:7-A8FQE*"1I9"D[
M"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")2=6QE($1I<V%B;&5D
M(BDL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@8G)E86L["@H@("`@8V%S
M92`G<G5L95]E;F%B;&4G.@H@("`@("`@("1F:6QT97)S+3YR=6QE16YA8FQE
M*"1I9"D["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")2=6QE($5N
M86)L960B*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!B<F5A:SL*("`@
M('T*"B`@("`O*B!3879E(&-H86YG97,@*B\*("`@("1I;F=O7W-T;W)A9V4M
M/G-T;W)E*"1F:6QT97)S*3L*("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=A
M=71O7W5P9&%T92<I*2!["B`@("`@("`@26YG;SHZ=7!D871E4V-R:7!T*"D[
M"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)W-E='1I;F=S7W-A=F4G.@H@("`@
M)'!R969S+3YS971686QU92@G<VAO=U]F:6QT97)?;7-G)RP@571I;#HZ9V5T
M1F]R;41A=&$H)W-H;W=?9FEL=&5R7VUS9R<I*3L*("`@("1P<F5F<RT^<V5T
M5F%L=64H)V9I;'1E<E]S965N)RP@571I;#HZ9V5T1F]R;41A=&$H)V9I;'1E
M<E]S965N)RDI.PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")3971T:6YG
M<R!S=6-C97-S9G5L;'D@=7!D871E9"XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@(&)R96%K.PH*8V%S92`G87!P;'E?9FEL=&5R<R<Z"B`@("!I9B`H)&EN
M9V]?<V-R:7!T+3YC86Y!<'!L>2@I*2!["B`@("`@("`@)&EN9V]?<V-R:7!T
M+3YA<'!L>2@I.PH@("`@?0H@("`@8G)E86L["GT*"B\J($=E="!T:&4@;&ES
M="!O9B!R=6QE<R!N;W<N("HO"B1F:6QT97)?;&ES="`]("1F:6QT97)S+3YG
M971&:6QT97),:7-T*"D["@I(;W)D93HZ861D4V-R:7!T1FEL92@G=&]O;'1I
M<"YJ<R<L("=H;W)D92<L('1R=64I.PI(;W)D93HZ861D4V-R:7!T1FEL92@G
M<W1R:7!E+FIS)RP@)VEN9V\G+"!T<G5E*3L*)'1I=&QE(#T@7R@B1FEL=&5R
M(%)U;&5S(BD["G)E<75I<F4@24Y'3U]414U03$%415,@+B`G+V-O;6UO;BUH
M96%D97(N:6YC)SL*<F5Q=6ER92!)3D=/7U1%35!,051%4R`N("<O;65N=2YI
M;F,G.PIR97%U:7)E7V]N8V4@24Y'3U]414U03$%415,@+B`G+V9I;'1E<G,O
M:F%V87-C<FEP="YI;F,G.PIR97%U:7)E($E.1T]?5$5-4$Q!5$53("X@)R]F
M:6QT97)S+VAE861E<BYI;F,G.PH*+RH@0V]M;6]N(%523',N("HO"B1F:6QT
M97)S7W5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9FEL=&5R<RYP:'`G
M*3L*)')U;&5?=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=R=6QE+G!H
M<"<I.PH*:68@*&-O=6YT*"1F:6QT97)?;&ES="D@/3T@,"D@>PH@("`@<F5Q
M=6ER92!)3D=/7U1%35!,051%4R`N("<O9FEL=&5R<R]F:6QT97(M;F]N92YI
M;F,G.PI](&5L<V4@>PH@("`@)&1I<W!L87D@/2!A<G)A>2@I.PH@("`@)&D@
M/2`P.PH@("`@)')U;&5?8V]U;G0@/2!A<G)A>5]S=6TH87)R87E?;6%P*&-R
M96%T95]F=6YC=&EO;B@G)&$G+"`B<F5T=7)N("AI;E]A<G)A>2A<)&%;)V%C
M=&EO;B==+"!<)%]315-324].6R=I;F=O)UU;)W-C<FEP=%]C871E9V]R:65S
M)UTI*2`_(#$@.B`P.R(I+"`D9FEL=&5R7VQI<W0I*3L*"B`@("`O*B!#;VUM
M;VX@9W)A<&AI8W,N("HO"B`@("`D9&]W;E]I;6<@/2!(;W)D93HZ:6UG*"=N
M878O9&]W;BYP;F<G+"!?*")-;W9E(%)U;&4@1&]W;B(I+"`G)RP@)')E9VES
M=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D["B`@("`D=7!?:6UG(#T@2&]R
M9&4Z.FEM9R@G;F%V+W5P+G!N9R<L(%\H(DUO=F4@4G5L92!5<"(I+"`G)RP@
M)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D["@H@("`@9F]R96%C
M:"`H)&9I;'1E<E]L:7-T(&%S("1R=6QE7VYU;6)E<B`]/B`D9FEL=&5R*2![
M"B`@("`@("`@+RH@4VMI<"!N;VXM9&ES<&QA>2!C871E9V]R:65S+B`J+PH@
M("`@("`@(&EF("@A:6Y?87)R87DH)&9I;'1E<ELG86-T:6]N)UTL("1?4T53
M4TE/3ELG:6YG;R==6R=S8W)I<'1?8V%T96=O<FEE<R==*2D@>PH@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@("1E;G1R>2`](&%R
M<F%Y*"D["B`@("`@("`@)&5N=')Y6R=N=6UB97(G72`]("LK)&D["B`@("`@
M("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D9FEL=&5R<U]U<FPL("=R
M=6QE;G5M8F5R)RP@)')U;&5?;G5M8F5R*3L*("`@("`@("`D8V]P>75R;"`]
M("1D96QU<FP@/2`D961I='5R;"`]("1N86UE(#T@;G5L;#L*"B`@("`@("`@
M<W=I=&-H("@D9FEL=&5R6R=A8W1I;VXG72D@>PH@("`@("`@(&-A<V4@24Y'
M3U]35$]204=%7T%#5$E/3E]"3$%#2TQ)4U0Z"B`@("`@("`@("`@("1E9&ET
M=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=B;&%C:VQI<W0N<&AP)RD[
M"B`@("`@("`@("`@("1E;G1R>5LG9FEL=&5R:6UG)UT@/2!(;W)D93HZ:6UG
M*"=B;&%C:VQI<W0N<&YG)RD["B`@("`@("`@("`@("1N86UE(#T@7R@B0FQA
M8VML:7-T(BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($E.
M1T]?4U1/4D%'15]!0U1)3TY?5TA)5$5,25-4.@H@("`@("`@("`@("`D961I
M='5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G=VAI=&5L:7-T+G!H<"<I
M.PH@("`@("`@("`@("`D96YT<GE;)V9I;'1E<FEM9R==(#T@2&]R9&4Z.FEM
M9R@G=VAI=&5L:7-T+G!N9R<I.PH@("`@("`@("`@("`D;F%M92`](%\H(E=H
M:71E;&ES="(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)
M3D=/7U-43U)!1T5?04-424].7U9!0T%424]..@H@("`@("`@("`@("`D961I
M='5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G=F%C871I;VXN<&AP)RD[
M"B`@("`@("`@("`@("1E;G1R>5LG9FEL=&5R:6UG)UT@/2!(;W)D93HZ:6UG
M*"=V86-A=&EO;BYP;F<G*3L*("`@("`@("`@("`@)&YA;64@/2!?*")686-A
M=&EO;B(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)3D=/
M7U-43U)!1T5?04-424].7T9/4E=!4D0Z"B`@("`@("`@("`@("1E9&ET=7)L
M(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=F;W)W87)D+G!H<"<I.PH@("`@
M("`@("`@("`D96YT<GE;)V9I;'1E<FEM9R==(#T@2&]R9&4Z.FEM9R@G9F]R
M=V%R9"YP;F<G*3L*("`@("`@("`@("`@)&YA;64@/2!?*")&;W)W87)D(BD[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`D961I='5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D<G5L95]U<FPL
M(&%R<F%Y*"=E9&ET)R`]/B`D<G5L95]N=6UB97(L("=A8W1I;VY)1"<@/3X@
M)W)U;&5?961I="<I*3L*("`@("`@("`@("`@)&1E;'5R;"`@/2!5=&EL.CIA
M9&1087)A;65T97(H)'5R;"P@)V%C=&EO;DE$)RP@)W)U;&5?9&5L971E)RD[
M"B`@("`@("`@("`@("1C;W!Y=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U
M<FPL("=A8W1I;VY)1"<L("=R=6QE7V-O<'DG*3L*("`@("`@("`@("`@)&5N
M=')Y6R=F:6QT97)I;6<G72`](&9A;'-E.PH@("`@("`@("`@("`D;F%M92`]
M("1F:6QT97);)VYA;64G73L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H*("`@("`@("`O*B!#<F5A=&4@9&5S8W)I<'1I;VXN("HO"B`@("`@("`@
M:68@*"%E;7!T>2@D9FEL=&5R6R=C;VYD:71I;VYS)UTI*2!["B`@("`@("`@
M("`@("1D97-C<FEP(#T@)R<["B`@("`@("`@("`@("1C;VYD:71I;VY?<VEZ
M92`](&-O=6YT*"1F:6QT97);)V-O;F1I=&EO;G,G72D@+2`Q.PH@("`@("`@
M("`@("!F;W)E86-H("@D9FEL=&5R6R=C;VYD:71I;VYS)UT@87,@)&-O;F1I
M9"`]/B`D8V]N9"D@>PH*("`@("`@("`@("`@("`@("1D97-C<FEP("X]('-P
M<FEN=&8H(B5S("5S(%PB)7-<(B(L(%\H)&-O;F1;)V9I96QD)UTI+"!?*"1C
M;VYD6R=M871C:"==*2P@)&-O;F1;)W9A;'5E)UTI.PH@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9%LG8V%S92==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1D97-C<FEP("X]("<@6R<@+B!?*")#87-E(%-E;G-I=&EV92(I
M("X@)UTG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*"1C;VYD:60@/"`D8V]N9&ET:6]N7W-I>F4I('L*("`@("`@("`@("`@("`@
M("`@("`D9&5S8W)I<"`N/2`H)&9I;'1E<ELG8V]M8FEN92==(#T]($E.1T]?
M4U1/4D%'15]#3TU"24Y%7T%,3"D@/R!?*"(@86YD(BD@.B!?*"(@;W(B*3L*
M("`@("`@("`@("`@("`@("`@("`D9&5S8W)I<"`N/2`B7&X@("(["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1D97-C
M<FEP("X](")<;B(["@H@("`@("`@("`@("`D;V(@/2`D:6YG;U]S=&]R86=E
M+3YG971!8W1I;VY);F9O*"1F:6QT97);)V%C=&EO;B==*3L*("`@("`@("`@
M("`@)&1E<V-R:7`@+CT@)&]B+3YL86)E;#L*"B`@("`@("`@("`@(&EF("@D
M9FEL=&5R6R=A8W1I;VXM=F%L=64G72D@>PH@("`@("`@("`@("`@("`@)&1E
M<V-R:7`@+CT@)SH@)R`N("1F:6QT97);)V%C=&EO;BUV86QU92==.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&9I;'1E<ELG<W1O<"==*2![
M"B`@("`@("`@("`@("`@("`D9&5S8W)I<"`N/2`B7&Y;<W1O<%TB.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D96YT<GE;)V1E<V-R:7!L:6YK)UT@
M/2!(;W)D93HZ;&EN:U1O;VQT:7`H)&5D:71U<FPL('-P<FEN=&8H7R@B161I
M="`E<R(I+"`D;F%M92DL(&YU;&PL(&YU;&PL(&YU;&PL("1D97-C<FEP*2`N
M("1N86UE.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E;G1R>5LG
M9&5S8W)I<&QI;FLG72`]($AO<F1E.CIL:6YK*"1E9&ET=7)L+"!S<')I;G1F
M*%\H(D5D:70@)7,B*2P@)&YA;64I*2`N("1N86UE.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0W)E871E(&5D:70@;&EN:RX@*B\*("`@("`@("`D96YT<GE;
M)V5D:71L:6YK)UT@/2!(;W)D93HZ;&EN:R@D961I='5R;"P@<W!R:6YT9BA?
M*")%9&ET("5S(BDL("1N86UE*2D["B`@("`@("`@)&5N=')Y6R=E9&ET:6UG
M)UT@/2!(;W)D93HZ:6UG*"=E9&ET+G!N9R<L('-P<FEN=&8H7R@B161I="`E
M<R(I+"`D;F%M92DL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D
M92<I*3L*"B`@("`@("`@+RH@0W)E871E(&1E;&5T92!L:6YK+B`J+PH@("`@
M("`@(&EF("@A:7-?;G5L;"@D9&5L=7)L*2D@>PH@("`@("`@("`@("`D96YT
M<GE;)V1E;&QI;FLG72`]($AO<F1E.CIL:6YK*"1D96QU<FPL('-P<FEN=&8H
M7R@B1&5L971E("5S(BDL("1N86UE*2P@;G5L;"P@;G5L;"P@(G)E='5R;B!W
M:6YD;W<N8V]N9FER;2@G(B`N(&%D9'-L87-H97,H7R@B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1E;&5T92!T:&ES(')U;&4_(BDI("X@(B<I.R(I.PH@
M("`@("`@("`@("`D96YT<GE;)V1E;&EM9R==(#T@2&]R9&4Z.FEM9R@G9&5L
M971E+G!N9R<L('-P<FEN=&8H7R@B1&5L971E("5S(BDL("1N86UE*2P@)R<L
M("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1E;G1R>5LG9&5L;&EN:R==(#T@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@8V]P>2!L:6YK+B`J+PH@
M("`@("`@(&EF("@A:7-?;G5L;"@D8V]P>75R;"D@)B8*("`@("`@("`@("`@
M*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG<&5R;7-D96YI960G72D@?'P*("`@
M("`@("`@("`@($EN9V\Z.FAA<U!E<FUI<W-I;VXH)VUA>%]R=6QE<R<I(#T]
M/2!T<G5E('Q\"B`@("`@("`@("`@("!);F=O.CIH87-097)M:7-S:6]N*"=M
M87A?<G5L97,G*2`^(&-O=6YT*"1F:6QT97)?;&ES="DI*2!["B`@("`@("`@
M("`@("1E;G1R>5LG8V]P>6QI;FLG72`]($AO<F1E.CIL:6YK*"1C;W!Y=7)L
M+"!S<')I;G1F*%\H(D-O<'D@)7,B*2P@)&YA;64I*3L*("`@("`@("`@("`@
M)&5N=')Y6R=C;W!Y:6UG)UT@/2!(;W)D93HZ:6UG*"=C;W!Y+G!N9R<L('-P
M<FEN=&8H7R@B0V]P>2`E<R(I+"`D;F%M92DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1E;G1R>5LG8V]P>6QI;FLG72`](&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0W)E871E('5P+V1O=VX@87)R;W<@;&EN:W,N
M("HO"B`@("`@("`@)&5N=')Y6R=U<'5R;"==(#T@571I;#HZ861D4&%R86UE
M=&5R*"1U<FPL("=A8W1I;VY)1"<L("=R=6QE7W5P)RD["B`@("`@("`@)&5N
M=')Y6R=D;W=N=7)L)UT@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)V%C
M=&EO;DE$)RP@)W)U;&5?9&]W;B<I.PH@("`@("`@("1E;G1R>5LG=7!L:6YK
M)UT@/2`H)&D@/B`Q*2`_($AO<F1E.CIL:6YK*"1E;G1R>5LG=7!U<FPG72P@
M7R@B36]V92!2=6QE(%5P(BDI(#H@9F%L<V4["B`@("`@("`@)&5N=')Y6R=D
M;W=N;&EN:R==(#T@*"1I(#P@)')U;&5?8V]U;G0I(#\@2&]R9&4Z.FQI;FLH
M)&5N=')Y6R=D;W=N=7)L)UTL(%\H(DUO=F4@4G5L92!$;W=N(BDI(#H@9F%L
M<V4["@H@("`@("`@(&EF("AE;7!T>2@D9FEL=&5R6R=D:7-A8FQE)UTI*2![
M"B`@("`@("`@("`@("1E;G1R>5LG9&ES86)L96QI;FLG72`]($AO<F1E.CIL
M:6YK*%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G86-T:6]N240G+"`G<G5L
M95]D:7-A8FQE)RDL('-P<FEN=&8H7R@B1&ES86)L92`E<R(I+"`D;F%M92DI
M.PH@("`@("`@("`@("`D96YT<GE;)V1I<V%B;&5I;6<G72`]($AO<F1E.CII
M;6<H)V5N86)L92YP;F<G+"!S<')I;G1F*%\H(D1I<V%B;&4@)7,B*2P@)&YA
M;64I*3L*("`@("`@("`@("`@)&5N=')Y6R=E;F%B;&5L:6YK)UT@/2!F86QS
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D96YT<GE;)V5N86)L
M96QI;FLG72`]($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G86-T:6]N240G+"`G<G5L95]E;F%B;&4G*2P@<W!R:6YT9BA?*")%;F%B
M;&4@)7,B*2P@)&YA;64I*3L*("`@("`@("`@("`@)&5N=')Y6R=E;F%B;&5I
M;6<G72`]($AO<F1E.CII;6<H)V1I<V%B;&4N<&YG)RP@<W!R:6YT9BA?*")%
M;F%B;&4@)7,B*2P@)&YA;64I*3L*("`@("`@("`@("`@)&5N=')Y6R=D:7-A
M8FQE;&EN:R==(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D9&ES<&QA
M>5M=(#T@)&5N=')Y.PH@("`@?0H*("`@("\J($]U='!U="!T:&4@=&5M<&QA
M=&4N("HO"B`@("`D=&5M<&QA=&4@/2`F;F5W($AO<F1E7U1E;7!L871E*"D[
M"B`@("`D=&5M<&QA=&4M/G-E="@G9&]W;E]I;6<G+"`D9&]W;E]I;6<I.PH@
M("`@)'1E;7!L871E+3YS970H)W5P7VEM9R<L("1U<%]I;6<I.PH@("`@)'1E
M;7!L871E+3YS970H)V9I;'1E<B<L("1D:7-P;&%Y+"!T<G5E*3L*("`@("1T
M96UP;&%T92T^<V5T3W!T:6]N*"=G971T97AT)RP@=')U92D["B`@("!E8VAO
M("1T96UP;&%T92T^9F5T8V@H24Y'3U]414U03$%415,@+B`G+V9I;'1E<G,O
M9FEL=&5R+FAT;6PG*3L*?0H*)&%C=&EO;G,@/2`D:6YG;U]S8W)I<'0M/F%V
M86EL86)L94%C=&EO;G,H*3L*)&-R96%T97)U;&4@/2`H(65M<'1Y*"1A8W1I
M;VYS*2`F)@H@("`@("`@("`@("`@("`H(65M<'1Y*"1C;VYF6R=H;V]K<R==
M6R=P97)M<V1E;FEE9"==*2!\?`H@("`@("`@("`@("`@("`@*$EN9V\Z.FAA
M<U!E<FUI<W-I;VXH)V%L;&]W7W)U;&5S)RD@)B8*("`@("`@("`@("`@("`@
M("`H26YG;SHZ:&%S4&5R;6ES<VEO;B@G;6%X7W)U;&5S)RD@/3T]('1R=64@
M?'P*("`@("`@("`@("`@("`@("`@26YG;SHZ:&%S4&5R;6ES<VEO;B@G;6%X
M7W)U;&5S)RD@/B!C;W5N="@D9FEL=&5R7VQI<W0I*2DI*3L*)&-A;F%P<&QY
M(#T@)&EN9V]?<V-R:7!T+3YC86Y!<'!L>2@I.PIR97%U:7)E($E.1T]?5$5-
M4$Q!5$53("X@)R]F:6QT97)S+V9O;W1E<BYI;F,G.PII9B`H)&]N7V1E;6%N
M9"D@>PH@("`@<F5Q=6ER92!)3D=/7U1%35!,051%4R`N("<O9FEL=&5R<R]S
M971T:6YG<RYI;F,G.PI]"@IR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP
M;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;F=O+W=H:71E;&ES="YP:'``````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,#8T`#$P-#$W,S8R-S4P
M`#`R,#$P,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!I;F=O+W=H:71E;&ES="YP:'`L
M=B`Q+C$X+C@N-B`R,#`V+S`Q+S,Q(#(P.C`P.C(S(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0G)E;G0@
M2BX@3F]R9'%U:7-T(#QB:FY`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N
M;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J+PH*0&1E9FEN92@G24Y'3U]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@24Y'3U]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@4F5D:7)E8W0@:68@=VAI=&5L:7-T
M(&YO="!A=F%I;&%B;&4N("HO"FEF("@A:6Y?87)R87DH24Y'3U]35$]204=%
M7T%#5$E/3E]72$E414Q)4U0L("1?4T534TE/3ELG:6YG;R==6R=S8W)I<'1?
M8V%T96=O<FEE<R==*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")7
M:&ET96QI<W0@:7,@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT
M97)I;F<@9')I=F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G
M3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)V9I;'1E<G,N
M<&AP)RP@=')U92DI.PH@("`@97AI=#L*?0H*)'=H:71E;&ES="`]("8D:6YG
M;U]S=&]R86=E+3YR971R:65V92A)3D=/7U-43U)!1T5?04-424].7U=(251%
M3$E35"D["@HO*B!097)F;W)M(')E<75E<W1E9"!A8W1I;VYS+B`J+PHD86-T
M:6]N240@/2!5=&EL.CIG971&;W)M1&%T82@G86-T:6]N240G*3L*<W=I=&-H
M("@D86-T:6]N240I('L*8V%S92`G<G5L95]U<&1A=&4G.@H@("`@)')E="`]
M("1W:&ET96QI<W0M/G-E=%=H:71E;&ES="A5=&EL.CIG971&;W)M1&%T82@G
M=VAI=&5L:7-T)RDI.PH@("`@:68@*&ES7V$H)')E="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E="P@)')E="T^
M9V5T0V]D92@I*3L*("`@('T@96QS92!["B`@("`@("`@:68@*"$D:6YG;U]S
M=&]R86=E+3YS=&]R92@D=VAI=&5L:7-T*2D@>PH@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*")%<G)O<B!S879I;F<@8VAA;F=E<RXB+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*%\H(D-H86YG97,@<V%V960N(BDL("=H;W)D92YS
M=6-C97-S)RD["@H@("`@("`@("`@("!I9B`H)'!R969S+3YG971686QU92@G
M875T;U]U<&1A=&4G*2D@>PH@("`@("`@("`@("`@("`@+RH@5&AI<R!D;V5S
M(&ET<R!O=VX@)&YO=&EF:6-A=&EO;BT^<'5S:"@I(&]N(&5R<F]R.B`J+PH@
M("`@("`@("`@("`@("`@26YG;SHZ=7!D871E4V-R:7!T*"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T92!T:&4@=&EM97-T
M86UP(&9O<B!T:&4@<G5L97,N("HO"B`@("`@("`@)%]315-324].6R=I;F=O
M)UU;)V-H86YG92==(#T@=&EM92@I.PH@("`@?0H*("`@(&)R96%K.PI]"@HO
M*B!'970@=&AE('=H:71E;&ES="!R=6QE+B`J+PHD9FEL=&5R<R`]("8D:6YG
M;U]S=&]R86=E+3YR971R:65V92A)3D=/7U-43U)!1T5?04-424].7T9)3%1%
M4E,I.PHD=VQ?<G5L92`]("1F:6QT97)S+3YF:6YD4G5L92A)3D=/7U-43U)!
M1T5?04-424].7U=(251%3$E35"D["@HD=&ET;&4@/2!?*")7:&ET96QI<W0@
M161I="(I.PIR97%U:7)E($E.1T]?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["G)E<75I<F4@24Y'3U]414U03$%415,@+B`G+VUE;G4N:6YC
M)SL*<F5Q=6ER92!)3D=/7U1%35!,051%4R`N("<O=VAI=&5L:7-T+W=H:71E
M;&ES="YI;F,G.PIR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G
M+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O+V-O;F9I9P``````````
M````````````````````````````````````````````````````````````
M`````````````#`Q,C`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4P`#`R-#8Q-@`@,B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M
M:&]R9&4O:6YG;P``````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN
M9V\O8FQA8VML:7-T+G!H<```````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#<Q,3<`,3`T,3<S-C(W-3``,#(P,#0Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&EN9V\O8FQA8VML:7-T+G!H<"QV(#$N,S0N."XX(#(P,#8O
M,#$O,S$@,C`Z,#`Z,C,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*B\*"D!D
M969I;F4H)TE.1T]?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER
M95]O;F-E($E.1T]?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B\J(%)E9&ER
M96-T(&EF(&)L86-K;&ES="!I<R!N;W0@879A:6QA8FQE+B`J+PII9B`H(6EN
M7V%R<F%Y*$E.1T]?4U1/4D%'15]!0U1)3TY?0DQ!0TM,25-4+"`D7U-%4U-)
M3TY;)VEN9V\G75LG<V-R:7!T7V-A=&5G;W)I97,G72DI('L*("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B0FQA8VML:7-T(&ES(&YO="!S=7!P;W)T960@
M:6X@=&AE(&-U<G)E;G0@9FEL=&5R:6YG(&1R:79E<BXB*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=F:6QT97)S+G!H<"<L('1R=64I*3L*("`@(&5X:70["GT*
M"B\J($=E="!T:&4@8F%C:V5N9"X@*B\*)&AA=F5?;6%R:R`](&9A;'-E.PHD
M<V-R:7!T;W(@/2`F26YG;SHZ;&]A9$EN9V]38W)I<'0H*3L*:68@*"1S8W)I
M<'1O<BD@>PH@("`@+RH@1&5T97)M:6YE(&EF('1H:7,@<V-R:7!T;W(@<W5P
M<&]R=',@;6%R:RUA<RUD96QE=&5D+B`J+PH@("`@)&%V86EL7V%C=&EO;G,@
M/2`D<V-R:7!T;W(M/F%V86EL86)L94%C=&EO;G,H*3L*("`@(&EF("AI;E]A
M<G)A>2A)3D=/7U-43U)!1T5?04-424].7T9,04=/3DQ9+"`D879A:6Q?86-T
M:6]N<RDI('L*("`@("`@("`D:&%V95]M87)K(#T@=')U93L*("`@('T*?0H*
M+RH@1V5T('1H92!B;&%C:VQI<W0@;V)J96-T+B`J+PHD8FQA8VML:7-T(#T@
M)B1I;F=O7W-T;W)A9V4M/G)E=')I979E*$E.1T]?4U1/4D%'15]!0U1)3TY?
M0DQ!0TM,25-4*3L*:68@*&ES7V$H)&)L86-K;&ES="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D8FQA8VML:7-T*3L*("`@
M("1B;&%C:VQI<W0@/2!N97<@26YG;U]3=&]R86=E7T)L86-K;&ES="@I.PI]
M"@HO*B!097)F;W)M(')E<75E<W1E9"!A8W1I;VYS+B`J+PHD86-T:6]N240@
M/2!5=&EL.CIG971&;W)M1&%T82@G86-T:6]N240G*3L*<W=I=&-H("@D86-T
M:6]N240I('L*8V%S92`G8W)E871E7V9O;&1E<B<Z"B`@("`D8FQA8VML:7-T
M7V9O;&1E<B`]($EN9V\Z.F-R96%T949O;&1E<BA5=&EL.CIG971&;W)M1&%T
M82@G;F5W7V9O;&1E<E]N86UE)RDI.PH@("`@8G)E86L["@IC87-E("=R=6QE
M7W5P9&%T92<Z"B`@("!S=VET8V@@*%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I
M;VXG*2D@>PH@("`@8V%S92`G9&5L971E)SH*("`@("`@("`D9F]L9&5R(#T@
M)R<["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G;6%R:R<Z"B`@("`@("`@
M)&9O;&1E<B`]($E.1T]?0DQ!0TM,25-47TU!4DM%4CL*("`@("`@("!B<F5A
M:SL*"B`@("!C87-E("=F;VQD97(G.@H@("`@("`@("1F;VQD97(@/2!5=&EL
M.CIG971&;W)M1&%T82@G86-T:6]N=F%L=64G*3L*("`@("`@("!B<F5A:SL*
M("`@('T*"B`@("!I9B`H*"1F;VQD97(@/3T@24Y'3U]"3$%#2TQ)4U1?34%2
M2T52*2`F)B`A)&AA=F5?;6%R:RD@>PH@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H(DYO="!S=7!P;W)T960@8GD@=&AI<R!S8W)I<'0@9V5N97)A=&]R
M+B(L("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@("`D<F5T
M(#T@)&)L86-K;&ES="T^<V5T0FQA8VML:7-T*%5T:6PZ.F=E=$9O<FU$871A
M*"=B;&%C:VQI<W0G*2D["B`@("`@("`@:68@*&ES7V$H)')E="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1R
M970L("1R970M/F=E=$-O9&4H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&)L86-K;&ES="T^<V5T0FQA8VML:7-T1F]L9&5R*"1F;VQD97(I
M.PH@("`@("`@("`@("!I9B`H(21I;F=O7W-T;W)A9V4M/G-T;W)E*"1B;&%C
M:VQI<W0I*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*%\H(D5R<F]R('-A=FEN9R!C:&%N9V5S+B(I+"`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H7R@B0VAA;F=E<R!S879E9"XB*2P@)VAO<F1E+G-U8V-E
M<W,G*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1P<F5F<RT^
M9V5T5F%L=64H)V%U=&]?=7!D871E)RDI('L*("`@("`@("`@("`@("`@("\J
M(%1H:7,@9&]E<R!I=',@;W=N("1N;W1I9FEC871I;VXM/G!U<V@H*2!O;B!E
M<G)O<CH@*B\*("`@("`@("`@("`@("`@($EN9V\Z.G5P9&%T95-C<FEP="@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!5<&1A=&4@
M=&AE('1I;65S=&%M<"!F;W(@=&AE(')U;&5S+B`J+PH@("`@("`@("1?4T53
M4TE/3ELG:6YG;R==6R=C:&%N9V4G72`]('1I;64H*3L*("`@('T*"B`@("!B
M<F5A:SL*?0H*+RH@0W)E871E('1H92!F;VQD97(@;&ES=&EN9RX@*B\*:68@
M*"%I<W-E="@D8FQA8VML:7-T7V9O;&1E<BDI('L*("`@("1B;&%C:VQI<W1?
M9F]L9&5R(#T@)&)L86-K;&ES="T^9V5T0FQA8VML:7-T1F]L9&5R*"D["GT*
M)&9I96QD7VYU;2`]("1H879E7VUA<FL@/R`R(#H@,3L*)&9O;&1E<E]L:7-T
M(#T@26YG;SHZ9FQI<W1396QE8W0H)&)L86-K;&ES=%]F;VQD97(L("=F:6QT
M97)S)RP@)V%C=&EO;G9A;'5E)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1O8W5M96YT+F9I;'1E<G,N86-T:6]N6R<@+B`D9FEE;&1?
M;G5M("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)UTN8VAE
M8VME9#UT<G5E)RD["@HO*B!'970@=&AE(&)L86-K;&ES="!R=6QE+B`J+PHD
M9FEL=&5R<R`]("8D:6YG;U]S=&]R86=E+3YR971R:65V92A)3D=/7U-43U)!
M1T5?04-424].7T9)3%1%4E,I.PHD8FQ?<G5L92`]("1F:6QT97)S+3YF:6YD
M4G5L92A)3D=/7U-43U)!1T5?04-424].7T),04-+3$E35"D["@HO*B!);F-L
M=61E(&YE=R!F;VQD97(@2E,@:68@;F5C97-S87)Y+B`J+PII9B`H)')E9VES
M=')Y+3YH87--971H;V0H)VUA:6PO8W)E871E1F]L9&5R)RDI('L*("`@($AO
M<F1E.CIA9&138W)I<'1&:6QE*"=N97=?9F]L9&5R+FIS)RD["GT*"B1T:71L
M92`](%\H(D)L86-K;&ES="!%9&ET(BD["G)E<75I<F4@24Y'3U]414U03$%4
M15,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!)3D=/7U1%35!,
M051%4R`N("<O;65N=2YI;F,G.PIR97%U:7)E($E.1T]?5$5-4$Q!5$53("X@
M)R]B;&%C:VQI<W0O8FQA8VML:7-T+FEN8R<["G)E<75I<F4@)')E9VES=')Y
M+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R
M+FEN8R<["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEN9V\O=F%C871I;VXN<&AP````````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4T,S,`,3`T,3<S-C(W
M-3``,#$W-C<T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EN9V\O=F%C871I;VXN<&AP
M+'8@,2XR."XX+C<@,C`P-B\P,2\S,2`R,#HP,#HR,R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYH;W)D92YO<F<O;&EC96YS97,O87-L+G!H<"X*("HO"@I`9&5F:6YE*"=)
M3D=/7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!)
M3D=/7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HO*B!2961I<F5C="!I9B!V
M86-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B`J+PII9B`H(6EN7V%R<F%Y*$E.
M1T]?4U1/4D%'15]!0U1)3TY?5D%#051)3TXL("1?4T534TE/3ELG:6YG;R==
M6R=S8W)I<'1?8V%T96=O<FEE<R==*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"A?*")686-A=&EO;B!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!C=7)R
M96YT(&9I;'1E<FEN9R!D<FEV97(N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G
M9FEL=&5R<RYP:'`G+"!T<G5E*2D["B`@("!E>&ET.PI]"@HO*B!'970@=F%C
M871I;VX@;V)J96-T+B`J+PHD=F%C871I;VX@/2`F)&EN9V]?<W1O<F%G92T^
M<F5T<FEE=F4H24Y'3U]35$]204=%7T%#5$E/3E]604-!5$E/3BD["@HO*B!0
M97)F;W)M(')E<75E<W1E9"!A8W1I;VYS+B`J+PHD86-T:6]N240@/2!5=&EL
M.CIG971&;W)M1&%T82@G86-T:6]N240G*3L*<W=I=&-H("@D86-T:6]N240I
M('L*8V%S92`G<G5L95]U<&1A=&4G.@H@("`@)&%D9'(@/2!5=&EL.CIG971&
M;W)M1&%T82@G861D<F5S<V5S)RD["B`@("!I9B`H96UP='DH)&%D9'(I*2![
M"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W4@;75S="!S<&5C
M:69Y(&%T(&QE87-T(&]N92!E;6%I;"!A9&1R97-S(&9O<B!W:&EC:"!T:&4@
M=F%C871I;VX@;65S<V%G97,@<VAO=6QD(&)E(&%C=&EV871E9"XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@("1V86-A=&EO;BT^
M<V5T5F%C871I;VY!9&1R97-S97,H571I;#HZ9V5T1F]R;41A=&$H)V%D9')E
M<W-E<R<I*3L*("`@("`@("`D=F%C871I;VXM/G-E=%9A8V%T:6]N1&%Y<RA5
M=&EL.CIG971&;W)M1&%T82@G9&%Y<R<I*3L*("`@("`@("`D=F%C871I;VXM
M/G-E=%9A8V%T:6]N17AC;'5D97,H571I;#HZ9V5T1F]R;41A=&$H)V5X8VQU
M9&5S)RDI.PH@("`@("`@("1V86-A=&EO;BT^<V5T5F%C871I;VY)9VYO<F5L
M:7-T*"A5=&EL.CIG971&;W)M1&%T82@G:6=N;W)E;&ES="<I(#T]("<Q)RDI
M.PH@("`@("`@("1V86-A=&EO;BT^<V5T5F%C871I;VY296%S;VXH571I;#HZ
M9V5T1F]R;41A=&$H)W)E87-O;B<I*3L*("`@("`@("`D=F%C871I;VXM/G-E
M=%9A8V%T:6]N4W5B:F5C="A5=&EL.CIG971&;W)M1&%T82@G<W5B:F5C="<I
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)&EN9V]?<W1O<F%G92T^
M<W1O<F4H)'9A8V%T:6]N*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*"1R97-U;'0I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B0VAA;F=E
M<R!S879E9"XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@:68@
M*"1P<F5F<RT^9V5T5F%L=64H)V%U=&]?=7!D871E)RDI('L*("`@("`@("`@
M("`@("`@($EN9V\Z.G5P9&%T95-C<FEP="@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J(%5P9&%T92!T:&4@=&EM97-T86UP(&9O
M<B!T:&4@<G5L97,N("HO"B`@("`D7U-%4U-)3TY;)VEN9V\G75LG8VAA;F=E
M)UT@/2!T:6UE*"D["@H@("`@8G)E86L["GT*"B\J($UA:V4@<W5R92!W92!H
M879E(&%T(&QE87-T(&]N92!A9&1R97-S+B`J+PII9B`H(21V86-A=&EO;BT^
M9V5T5F%C871I;VY!9&1R97-S97,H*2D@>PH@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92])9&5N=&ET>2YP:'`G.PH@("`@)&ED96YT:71Y(#T@)DED96YT:71Y
M.CIS:6YG;&5T;VXH)VYO;F4G*3L*("`@("1A9&1R97-S97,@/2!I;7!L;V1E
M*")<;B(L("1I9&5N=&ET>2T^9V5T06QL*"=F<F]M7V%D9'(G*2D["B`@("`O
M*B!296UO=F4@96UP='D@;&EN97,N("HO"B`@("`D861D<F5S<V5S(#T@<')E
M9U]R97!L86-E*"<O7&XK+R<L(")<;B(L("1A9&1R97-S97,I.PH@("`@:68@
M*&5M<'1Y*"1A9&1R97-S97,I*2!["B`@("`@("`@)&%D9')E<W-E<R`]($%U
M=&@Z.F=E=$%U=&@H*3L*("`@('T*("`@("1V86-A=&EO;BT^<V5T5F%C871I
M;VY!9&1R97-S97,H)&%D9')E<W-E<RD["GT*"B\J($=E="!T:&4@=F%C871I
M;VX@<G5L92X@*B\*)&9I;'1E<G,@/2`F)&EN9V]?<W1O<F%G92T^<F5T<FEE
M=F4H24Y'3U]35$]204=%7T%#5$E/3E]&24Q415)3*3L*)'9A8U]R=6QE(#T@
M)&9I;'1E<G,M/F9I;F12=6QE*$E.1T]?4U1/4D%'15]!0U1)3TY?5D%#051)
M3TXI.PH*)'1I=&QE(#T@7R@B5F%C871I;VX@161I="(I.PIR97%U:7)E($E.
M1T]?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@
M24Y'3U]414U03$%415,@+B`G+VUE;G4N:6YC)SL*<F5Q=6ER92!)3D=/7U1%
M35!,051%4R`N("<O=F%C871I;VXO=F%C871I;VXN:6YC)SL*<F5Q=6ER92`D
M<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO
M;BUF;V]T97(N:6YC)SL*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6YG;R]T97-T+G!H<```````````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-C8U,0`Q,#0Q-S,V,C<U,``P,3<P-3(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:6YG;R]T97-T+G!H<"QV(#$N,38N,3(N,R`R,#`V+S`Q
M+S,Q(#(P.C`P.C(S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($)R96YT($HN($YO<F1Q=6ES="`\8FIN0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@
M/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,
M24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*B\*"B\J($EN8VQU9&4@
M2&]R9&4G<R!C;W)E+G!H<"!F:6QE+B`J+PII;F-L=61E7V]N8V4@)RXN+VQI
M8B]C;W)E+G!H<"<["@HO*B!792!S:&]U;&0@:&%V92!L;V%D960@=&AE(%-T
M<FEN9R!C;&%S<RP@9G)O;2!T:&4@2&]R9&5?571I;`H@*B!P86-K86=E+"!I
M;B!C;W)E+G!H<"X@268@4W1R:6YG.CH@:7-N)W0@9&5F:6YE9"P@=&AE;B!W
M92=R92!N;W0*("H@9FEN9&EN9R!S;VUE(&-R:71I8V%L(&QI8G)A<FEE<RX@
M*B\*:68@*"%C;&%S<U]E>&ES=',H)U-T<FEN9R<I*2!["B`@("!E8VAO("<\
M8G(@+SX\<W!A;B!S='EL93TB8V]L;W(Z(')E9#L@9F]N="US:7IE.B`Q.'!X
M.R!F;VYT+7=E:6=H=#H@8F]L9#LB/E1H92!(;W)D95]5=&EL('!A8VMA9V4@
M=V%S(&YO="!F;W5N9"X@268@4$A07"=S(&5R<F]R7W)E<&]R=&EN9R!S971T
M:6YG(&ES(&AI9V@@96YO=6=H+"!T:&5R92!S:&]U;&0@8F4@97)R;W(@;65S
M<V%G97,@<')I;G1E9"!A8F]V92!T:&%T(&UA>2!H96QP('EO=2!I;B!D96)U
M9V=I;F<@=&AE('!R;V)L96TN($EF('EO=2!A<F4@<VEM<&QY(&UI<W-I;F<@
M=&AE<V4@9FEL97,L('1H96X@>6]U(&YE960@=&\@9V5T('1H92`\82!H<F5F
M/2)H='1P.B\O8W9S+FAO<F1E+F]R9R]C=G,N<&AP+V9R86UE=V]R:R(^9G)A
M;65W;W)K/"]A/B!M;V1U;&4@9G)O;2`\82!H<F5F/2)H='1P.B\O:&]R9&4N
M;W)G+W-O=7)C92\B/DAO<F1E($-64SPO83XL(&%N9"!I;G-T86QL('1H92!P
M86-K86=E<R!I;B!I="!W:71H('1H92!I;G-T86QL+7!A8VMA9V5S+G!H<"!S
M8W)I<'0N/"]S<&%N/B<["B`@("!E>&ET.PI]"@HO*B!);FET:6%L:7IE('1H
M92!(;W)D95]497-T.CH@8VQA<W,N("HO"FEF("@A*$!I<U]R96%D86)L92@G
M+BXO;&EB+U1E<W0N<&AP)RDI*2!["B`@("!E8VAO("=%4E)/4CH@66]U(&UU
M<W0@:6YS=&%L;"!(;W)D92!B969O<F4@<G5N;FEN9R!T:&ES('-C<FEP="XG
M.PH@("`@97AI=#L*?0IR97%U:7)E7V]N8V4@)RXN+VQI8B]497-T+G!H<"<[
M"B1H;W)D95]T97-T(#T@)FYE=R!(;W)D95]497-T.PH*+RH@26YG;R!V97)S
M:6]N+B`J+PHD;6]D=6QE(#T@)TEN9V\G.PIR97%U:7)E7V]N8V4@)RXO;&EB
M+W9E<G-I;VXN<&AP)SL*)&UO9'5L95]V97)S:6]N(#T@24Y'3U]615)324].
M.PH*<F5Q=6ER92!415-47U1%35!,051%4R`N("=H96%D97(N:6YC)SL*<F5Q
M=6ER92!415-47U1%35!,051%4R`N("=V97)S:6]N+FEN8R<["@HO*B!$:7-P
M;&%Y('9E<G-I;VYS(&]F(&]T:&5R($AO<F1E(&%P<&QI8V%T:6]N<RX@*B\*
M)&%P<%]L:7-T(#T@87)R87DH"B`@("`G:6UP)R`@/3X@(&%R<F%Y*`H@("`@
M("`@("=E<G)O<B<@/3X@)TE-4"!C86X@8F4@=7-E9"!T;R!I;G1E<F9A8V4@
M:6YG;R!W:71H(&$@;6%I;'-E<G9E<BXG+`H@("`@("`@("=V97)S:6]N)R`]
M/B`G-"XP)PH@("`@*0HI.PHD87!P7V]U='!U="`]("1H;W)D95]T97-T+3YR
M97%U:7)E9$%P<$-H96-K*"1A<'!?;&ES="D["@H_/@H\:#$^3W1H97(@2&]R
M9&4@07!P;&EC871I;VYS/"]H,3X*/'5L/@H@("`@/#]P:'`@96-H;R`D87!P
M7V]U='!U="`_/@H\+W5L/@H\/W!H<`H*+RH@4$A0(&UO9'5L92!C87!A8FEL
M:71I97,N("HO"B1M;V1U;&5?;&ES="`](&%R<F%Y*`H@("`@)V9T<"<@/3X@
M87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=&5%`@4W5P<&]R="<L"B`@
M("`@("`@)V5R<F]R)R`]/B`G268@>6]U('=I;&P@8F4@=7-I;F<@=&AE(%9&
M4R!&5%`@9')I=F5R(&9O<B!P<F]C;6%I;"!S8W)I<'1S+"!02%`@;75S="!H
M879E($944"!S=7!P;W)T+B!#;VUP:6QE(%!(4"`\8V]D93XM+7=I=&@M9G1P
M/"]C;V1E/B!B969O<F4@8V]N=&EN=6EN9RXG"B`@("`I+`H@("`@)VEM87`G
M(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G24U!4"!3=7!P;W)T
M)RP*("`@("`@("`G97)R;W(G(#T^("=)9B!Y;W4@=VEL;"!B92!U<VEN9R!T
M:&4@24U!4"!C;&EE;G0M<VED92!D<FEV97(L(%!(4"!M=7-T(&AA=F4@24U!
M4"!S=7!P;W)T(&)U:6QT(&EN+B!#;VUP:6QE(%!(4"`\8V]D93XM+7=I=&@M
M:6UA<#PO8V]D93X@8F5F;W)E(&-O;G1I;G5I;F<N)PH@("`@*0HI.PH*+RH@
M1&ES<&QA>2!02%`@5F5R<VEO;B!I;F9O<FUA=&EO;BX@*B\*)'!H<%]I;F9O
M(#T@)&AO<F1E7W1E<W0M/F=E=%!H<%9E<G-I;VY);F9O<FUA=&EO;B@I.PIR
M97%U:7)E(%1%4U1?5$5-4$Q!5$53("X@)W!H<%]V97)S:6]N+FEN8R<["@HO
M*B!014%2("HO"B1P96%R7VQI<W0@/2!A<G)A>2@*("`@("=.971?4V]C:V5T
M)R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)TYE="]3;V-K970N<&AP
M)RP*("`@("`@("`G97)R;W(G(#T^("=)9B!Y;W4@=VEL;"!B92!U<VEN9R!3
M:65V92!S8W)I<'1S+"!M86ME('-U<F4@>6]U(&%R92!U<VEN9R!A('9E<G-I
M;VX@;V8@4$5!4B!W:&EC:"!I;F-L=61E<R!T:&4@3F5T7U-O8VME="!C;&%S
M<RP@;W(@=&AA="!Y;W4@:&%V92!I;G-T86QL960@=&AE($YE=%]3;V-K970@
M<&%C:V%G92!S97!E<F%T96QY+B<*("`@("DL"B`@("`G3F5T7U-I979E)R`]
M/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)TYE="]3:65V92YP:'`G+`H@
M("`@("`@("=E<G)O<B<@/3X@)TEF('EO=2!W:6QL(&)E('5S:6YG(%-I979E
M('-C<FEP=',L(&UA:V4@<W5R92!Y;W4@87)E('5S:6YG(&$@=F5R<VEO;B!O
M9B!014%2('=H:6-H(&EN8VQU9&5S('1H92!.971?4VEE=F4@8VQA<W,L(&]R
M('1H870@>6]U(&AA=F4@:6YS=&%L;&5D('1H92!.971?4VEE=F4@<&%C:V%G
M92!S97!E<F%T96QY+B<*("`@("D**3L*"B\J($=E="!T:&4@<W1A='5S(&]U
M='!U="!N;W<N("HO"B1M;V1U;&5?;W5T<'5T(#T@)&AO<F1E7W1E<W0M/G!H
M<$UO9'5L94-H96-K*"1M;V1U;&5?;&ES="D["@H_/@H\:#$^4$A0($UO9'5L
M92!#87!A8FEL:71I97,\+V@Q/@H\=6P^"B`@("`\/W!H<"!E8VAO("1M;V1U
M;&5?;W5T<'5T(#\^"CPO=6P^"@H\:#$^4$5!4B!-;V1U;&5S/"]H,3X*/'5L
M/@H@("`@/#]P:'`@96-H;R`D:&]R9&5?=&5S="T^4$5!4DUO9'5L94-H96-K
M*"1P96%R7VQI<W0I(#\^"CPO=6P^"@H\/W!H<`IR97%U:7)E(%1%4U1?5$5-
M4$Q!5$53("X@)V9O;W1E<BYI;F,G.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEN9V\O<V-R:7!T+G!H<```````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,V,C$`,3`T,3<S-C(W-3``,#$W,S<Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&EN9V\O<V-R:7!T+G!H<"QV(#$N,S,N-BXS(#(P,#8O
M,#$O,S$@,C`Z,#`Z,C,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$%33"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N
M<V5S+V%S;"YP:'`N"B`J+PH*0&1E9FEN92@G24Y'3U]"05-%)RP@(&1I<FYA
M;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E($E.1T]?0D%312`N("<O;&EB
M+V)A<V4N<&AP)SL*"B\J(%)E9&ER96-T(&EF('-C<FEP="!U<&1A=&EN9R!I
M<R!N;W0@879A:6QA8FQE+B`J+PII9B`H(21?4T534TE/3ELG:6YG;R==6R=S
M8W)I<'1?9V5N97)A=&4G72D@>PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9FEL=&5R<RYP:'`G+"!T<G5E*2D[
M"B`@("!E>&ET.PI]"@HD<V-R:7!T(#T@)R<["@HO*B!'970@=&AE($EN9V]?
M4V-R:7!T.CH@8F%C:V5N9"X@*B\*)'-C<FEP=&]R(#T@)DEN9V\Z.FQO861)
M;F=O4V-R:7!T*"D["FEF("@D<V-R:7!T;W(I('L*("`@("\J($=E;F5R871E
M('1H92!S8W)I<'0N("HO"B`@("`D<V-R:7!T(#T@)'-C<FEP=&]R+3YG96YE
M<F%T92@I.PI]"@HO*B!!8W1I=F%T92]D96%C=&EV871E('-C<FEP="!I9B!R
M97%U97-T960N"B`@(&%C=&EV871E4V-R:7!T*"D@9&]E<R!I=',@;W=N("1N
M;W1I9FEC871I;VXM/G!U<V@H*2!O;B!E<G)O<BX@*B\*)&%C=&EO;DE$(#T@
M571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD["G-W:71C:"`H)&%C=&EO
M;DE$*2!["F-A<V4@)V%C=&EO;E]A8W1I=F%T92<Z"B`@("!I9B`H(65M<'1Y
M*"1S8W)I<'0I*2!["B`@("`@("`@26YG;SHZ86-T:79A=&538W)I<'0H)'-C
M<FEP="D["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V%C=&EO;E]D96%C=&EV
M871E)SH*("`@($EN9V\Z.F%C=&EV871E4V-R:7!T*"<G+"!T<G5E*3L*("`@
M(&)R96%K.PH*8V%S92`G<VAO=U]A8W1I=F4G.@H@("`@)'-C<FEP="`]($EN
M9V\Z.F=E=%-C<FEP="@I.PH@("`@:68@*&ES7V$H)'-C<FEP="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'-C<FEP
M="P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@)'-C<FEP="`]("<G.PH@("`@
M?0H@("`@8G)E86L["GT*"B1T:71L92`](%\H(D9I;'1E<B!38W)I<'0@1&ES
M<&QA>2(I.PIR97%U:7)E($E.1T]?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["G)E<75I<F4@24Y'3U]414U03$%415,@+B`G+VUE;G4N:6YC
M)SL*<F5Q=6ER92!)3D=/7U1%35!,051%4R`N("<O<V-R:7!T+VAE861E<BYI
M;F,G.PII9B`H(65M<'1Y*"1S8W)I<'0I*2!["B`@("!R97%U:7)E($E.1T]?
M5$5-4$Q!5$53("X@)R]S8W)I<'0O86-T:79A=&4N:6YC)SL*?0IR97%U:7)E
M($E.1T]?5$5-4$Q!5$53("X@)R]S8W)I<'0O<V-R:7!T+FEN8R<["FEF("@A
M96UP='DH)'-C<FEP="DI('L*("`@("1L:6YE<R`]('!R96=?<W!L:70H)RA<
M<EQN?%QN?%QR*2<L("1S8W)I<'0I.PH@("`@)&D@/2`P.PH@("`@9F]R96%C
M:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@<')I;G1F*"(E,V0Z("5S
M7&XB+"`K*R1I+"!H=&UL<W!E8VEA;&-H87)S*"1L:6YE*2D["B`@("!]"GT@
M96QS92!["B`@("!E8VAO("=;)R`N(%\H(DYO('-C<FEP="!G96YE<F%T960N
M(BD@+B`G72<["GT*"G)E<75I<F4@24Y'3U]414U03$%415,@+B`G+W-C<FEP
M="]F;V]T97(N:6YC)SL*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA
M=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F=O
M+W)U;&4N<&AP````````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(V,S8Q`#$P-#$W,S8R-S4P`#`Q-S`T,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!I;F=O+W)U;&4N<&AP+'8@,2XV,RXX+C<@,C`P-B\P,2\S,2`R
M,#HP,#HR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y
M<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W
M;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J+PH*+RH@1&5F:6YE
M('1H92!K97D@=&\@=7-E('1O(&EN9&EC871E(&$@=7-E<BUD969I;F5D(&AE
M861E<B!I<R!R97%U97-T960N("HO"D!D969I;F4H)TE.1T]?55-%4E](14%$
M15(G+"`G*RM54T527TA%041%4BLK)RD["@I`9&5F:6YE*"=)3D=/7T)!4T4G
M+"`@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@24Y'3U]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@24Y'3U]"05-%("X@
M)R]L:6(O1')I=F5R+G!H<"<["@HO*B!#:&5C:R!R=6QE('!E<FUI<W-I;VYS
M+B`J+PII9B`H(4EN9V\Z.FAA<U!E<FUI<W-I;VXH)V%L;&]W7W)U;&5S)RDI
M('L*("`@("1M97-S86=E(#T@0&AT;6QS<&5C:6%L8VAA<G,H7R@B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;W(@961I="!C=7-T;VT@<G5L97,N
M(BDL($5.5%]#3TU0050L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@(&EF("@A
M96UP='DH)&-O;F9;)VAO;VMS)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@
M("`@)&UE<W-A9V4@/2!(;W)D93HZ8V%L;$AO;VLH)U]P97)M<U]H;V]K7V1E
M;FEE9"<L(&%R<F%Y*"=I;F=O.F%L;&]W7W)U;&5S)RDL("=H;W)D92<L("1M
M97-S86=E*3L*("`@('T*("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&UE<W-A
M9V4L("=H;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@
M(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)V9I;'1E<G,N<&AP)RP@=')U92DI.PH@("`@97AI=#L*?0H*+RH@3&]A9"!T
M:&4@26YG;U]38W)I<'0Z.B!D<FEV97(N("HO"B1I;F=O7W-C<FEP="`]("9)
M;F=O.CIL;V%D26YG;U-C<FEP="@I.PH*+RH@4F5D:7)E8W0@:68@;F\@<G5L
M97,@87)E(&%V86EL86)L92X@*B\*)&%V86EL06-T:6]N<R`]("1I;F=O7W-C
M<FEP="T^879A:6QA8FQE06-T:6]N<R@I.PII9B`H96UP='DH)&%V86EL06-T
M:6]N<RDI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B26YD:79I9'5A
M;"!R=6QE<R!A<F4@;F]T('-U<'!O<G1E9"!I;B!T:&4@8W5R<F5N="!F:6QT
M97)I;F<@9')I=F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G
M3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)V9I;'1E<G,N
M<&AP)RP@=')U92DI.PH@("`@97AI=#L*?0H*+RH@5&AI<R!P<F]V:61E<R!T
M:&4@)&EN9V]?9FEE;&1S(&%R<F%Y+B`J+PIR97%U:7)E($E.1T]?0D%312`N
M("<O8V]N9FEG+V9I96QD<RYP:'`G.PH*+RH@1V5T('1H92!C=7)R96YT(')U
M;&5S+B`J+PHD9FEL=&5R<R`]("8D:6YG;U]S=&]R86=E+3YR971R:65V92A)
M3D=/7U-43U)!1T5?04-424].7T9)3%1%4E,I.PH*+RH@4G5N('1H<F]U9V@@
M86-T:6]N(&AA;F1L97)S+B`J+PHD86-T:6]N240@/2!5=&EL.CIG971&;W)M
M1&%T82@G86-T:6]N240G*3L*)&5D:71?;G5M8F5R(#T@571I;#HZ9V5T1F]R
M;41A=&$H)V5D:70G*3L*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G8W)E
M871E7V9O;&1E<B<Z"F-A<V4@)W)U;&5?<V%V92<Z"F-A<V4@)W)U;&5?=7!D
M871E)SH*8V%S92`G<G5L95]D96QE=&4G.@H@("`@)')U;&4@/2!A<G)A>2@I
M.PH@("`@)')U;&5;)VYA;64G72`](%5T:6PZ.F=E=$9O<FU$871A*"=N86UE
M)RD["B`@("`D<G5L95LG8V]M8FEN92==(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V-O;6)I;F4G*3L*("`@("1R=6QE6R=C;VYD:71I;VYS)UT@/2!A<G)A>2@I
M.PH*("`@("1F:65L9"`](%5T:6PZ.F=E=$9O<FU$871A*"=F:65L9"<I.PH@
M("`@)&UA=&-H(#T@571I;#HZ9V5T1F]R;41A=&$H)VUA=&-H)RD["B`@("`D
M=7-E<FAE861E<B`](%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R:&5A9&5R)RD[
M"B`@("`D=F%L=64@/2!5=&EL.CIG971&;W)M1&%T82@G=F%L=64G*3L*("`@
M(&EF("@D:6YG;U]S8W)I<'0M/F-A<V5396YS:71I=F4H*2D@>PH@("`@("`@
M("1C87-E<V5N<VET:79E(#T@571I;#HZ9V5T1F]R;41A=&$H)V-A<V4G*3L*
M("`@('T*("`@(&9O<F5A8V@@*"1F:65L9"!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("!I9B`H(65M<'1Y*"1V86PI*2!["B`@("`@("`@("`@("1C;VYD
M:71I;VX@/2!A<G)A>2@I.PH@("`@("`@("`@("!I9B`H)'9A;"`]/2!)3D=/
M7U5315)?2$5!1$52*2!["B`@("`@("`@("`@("`@("`D8V]N9&ET:6]N6R=F
M:65L9"==(#T@*&5M<'1Y*"1U<V5R:&5A9&5R6R1K97E=*2D@/R`G)R`Z("1U
M<V5R:&5A9&5R6R1K97E=.PH@("`@("`@("`@("`@("`@)&-O;F1I=&EO;ELG
M='EP92==(#T@24Y'3U]35$]204=%7U194$5?2$5!1$52.PH@("`@("`@("`@
M("!](&5L<V5I9B`H(6ES<V5T*"1I;F=O7V9I96QD<ULD=F%L72DI('L*("`@
M("`@("`@("`@("`@("1C;VYD:71I;VY;)V9I96QD)UT@/2`D=F%L.PH@("`@
M("`@("`@("`@("`@)&-O;F1I=&EO;ELG='EP92==(#T@24Y'3U]35$]204=%
M7U194$5?2$5!1$52.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&-O;F1I=&EO;ELG9FEE;&0G72`]("1V86P["B`@("`@("`@("`@
M("`@("`D8V]N9&ET:6]N6R=T>7!E)UT@/2`D:6YG;U]F:65L9'-;)'9A;%U;
M)W1Y<&4G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8V]N9&ET:6]N
M6R=M871C:"==(#T@:7-S970H)&UA=&-H6R1K97E=*2`_("1M871C:%LD:V5Y
M72`Z("<G.PH@("`@("`@("`@("`D8V]N9&ET:6]N6R=V86QU92==(#T@:7-S
M970H)'9A;'5E6R1K97E=*2`_("1V86QU95LD:V5Y72`Z("<G.PH@("`@("`@
M("`@("!I9B`H:7-S970H)&-A<V5S96YS:71I=F4I*2!["B`@("`@("`@("`@
M("`@("`D8V]N9&ET:6]N6R=C87-E)UT@/2!I<W-E="@D8V%S97-E;G-I=&EV
M95LD:V5Y72D@/R`D8V%S97-E;G-I=&EV95LD:V5Y72`Z("<G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1R=6QE6R=C;VYD:71I;VYS)UU;72`]("1C
M;VYD:71I;VX["B`@("`@("`@?0H@("`@?0H*("`@(&EF("@D86-T:6]N240@
M/3T@)V-R96%T95]F;VQD97(G*2!["B`@("`@("`@)')U;&5;)V%C=&EO;BUV
M86QU92==(#T@26YG;SHZ8W)E871E1F]L9&5R*%5T:6PZ.F=E=$9O<FU$871A
M*"=N97=?9F]L9&5R7VYA;64G*2D["B`@("!](&5L<V4@>PH@("`@("`@("1R
M=6QE6R=A8W1I;VXM=F%L=64G72`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I
M;VYV86QU92<I.PH@("`@?0H*("`@("1R=6QE6R=A8W1I;VXG72`](%5T:6PZ
M.F=E=$9O<FU$871A*"=A8W1I;VXG*3L*("`@("1R=6QE6R=S=&]P)UT@/2!5
M=&EL.CIG971&;W)M1&%T82@G<W1O<"<I.PH*("`@("1R=6QE6R=F;&%G<R==
M(#T@,#L*("`@("1F;&%G<R`](%5T:6PZ.F=E=$9O<FU$871A*"=F;&%G<R<L
M(&%R<F%Y*"DI.PH@("`@:68@*"%E;7!T>2@D9FQA9W,I*2!["B`@("`@("`@
M9F]R96%C:"`H)&9L86=S(&%S("1V86PI('L*("`@("`@("`@("`@)')U;&5;
M)V9L86=S)UT@?#T@)'9A;#L*("`@("`@("!]"B`@("!]"@H@("`@+RH@57!D
M871E('1H92!T:6UE<W1A;7`@9F]R('1H92!R=6QE<RX@*B\*("`@("1?4T53
M4TE/3ELG:6YG;R==6R=C:&%N9V4G72`]('1I;64H*3L*"B`@("`O*B!3879E
M('1H92!R=6QE+B`J+PH@("`@:68@*"1A8W1I;VY)1"`]/2`G<G5L95]S879E
M)RD@>PH@("`@("`@(&EF("AI<U]N=6QL*"1E9&ET7VYU;6)E<BDI('L*("`@
M("`@("`@("`@:68@*$EN9V\Z.FAA<U!E<FUI<W-I;VXH)VUA>%]R=6QE<R<I
M("$]/2!T<G5E("8F"B`@("`@("`@("`@("`@("!);F=O.CIH87-097)M:7-S
M:6]N*"=M87A?<G5L97,G*2`\/2!C;W5N="@D9FEL=&5R<RT^9V5T1FEL=&5R
M3&ES="@I*2D@>PH@("`@("`@("`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@
M)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9FEL=&5R<RYP:'`G+"!T<G5E
M*2D["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1F:6QT97)S+3YA9&12=6QE*"1R=6QE*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D9FEL=&5R<RT^=7!D871E4G5L92@D<G5L92P@
M)&5D:71?;G5M8F5R*3L*("`@("`@("!]"B`@("`@("`@)&EN9V]?<W1O<F%G
M92T^<W1O<F4H)&9I;'1E<G,I.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H7R@B0VAA;F=E<R!S879E9"XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*"B`@
M("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)V%U=&]?=7!D871E)RDI('L*
M("`@("`@("`@("`@26YG;SHZ=7!D871E4V-R:7!T*"D["B`@("`@("`@?0H*
M("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=F:6QT97)S+G!H<"<I*3L*("`@("`@("!E>&ET.PH@("`@?2!E
M;'-E:68@*"1A8W1I;VY)1"`]/2`G<G5L95]D96QE=&4G*2!["B`@("`@("`@
M)&-O;F1?;G5M(#T@571I;#HZ9V5T1F]R;41A=&$H)V-O;F1I=&EO;FYU;6)E
M<B<I.PH@("`@("`@(&EF("@A:7-?;G5L;"@D8V]N9%]N=6TI*2!["B`@("`@
M("`@("`@('5N<V5T*"1R=6QE6R=C;VYD:71I;VYS)UU;)&-O;F1?;G5M72D[
M"B`@("`@("`@("`@("1R=6QE6R=C;VYD:71I;VYS)UT@/2!A<G)A>5]V86QU
M97,H)')U;&5;)V-O;F1I=&EO;G,G72D["B`@("`@("`@?0H@("`@?0H*("`@
M(&)R96%K.PH*9&5F875L=#H*("`@(&EF("AI<U]N=6QL*"1E9&ET7VYU;6)E
M<BDI('L*("`@("`@("!I9B`H26YG;SHZ:&%S4&5R;6ES<VEO;B@G;6%X7W)U
M;&5S)RD@(3T]('1R=64@)B8*("`@("`@("`@("`@26YG;SHZ:&%S4&5R;6ES
M<VEO;B@G;6%X7W)U;&5S)RD@/#T@8V]U;G0H)&9I;'1E<G,M/F=E=$9I;'1E
M<DQI<W0H*2DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!`:'1M;'-P96-I
M86QC:&%R<RAS<')I;G1F*%\H(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!R=6QE<RXB*2P@26YG;SHZ:&%S4&5R;6ES<VEO
M;B@G;6%X7W)U;&5S)RDI+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H
M*2D["B`@("`@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W!E
M<FUS9&5N:65D)UTI*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]($AO
M<F1E.CIC86QL2&]O:R@G7W!E<FUS7VAO;VM?9&5N:65D)RP@87)R87DH)VEN
M9V\Z;6%X7W)U;&5S)RDL("=H;W)D92<L("1M97-S86=E*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1M97-S86=E
M+"`G:&]R9&4N97)R;W(G+"!A<G)A>2@G8V]N=&5N="YR87<G*2D["B`@("`@
M("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)V9I;'1E<G,N<&AP)RP@=')U92DI.PH@("`@("`@("`@("!E>&ET
M.PH@("`@("`@('T*("`@("`@("`D<G5L92`]("1F:6QT97)S+3YG971$969A
M=6QT4G5L92@I.PH@("`@?2!E;'-E('L*("`@("`@("`D<G5L92`]("1F:6QT
M97)S+3YG9712=6QE*"1E9&ET7VYU;6)E<BD["B`@("!]"B`@("!B<F5A:SL*
M?0H*:68@*"$D<G5L92D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")&
M:6QT97(@;F]T(&9O=6YD+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E
M<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)V9I;'1E
M<G,N<&AP)RP@=')U92DI.PH@("`@97AI=#L*?0H*:68@*"1R96=I<W1R>2T^
M:&%S365T:&]D*"=M86EL+V-R96%T949O;&1E<B<I*2!["B`@("!(;W)D93HZ
M861D4V-R:7!T1FEL92@G;F5W7V9O;&1E<BYJ<R<I.PI]"@HD=&ET;&4@/2`D
M<G5L95LG;F%M92==.PIR97%U:7)E($E.1T]?5$5-4$Q!5$53("X@)R]C;VUM
M;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@24Y'3U]414U03$%415,@+B`G+VUE
M;G4N:6YC)SL*<F5Q=6ER92!)3D=/7U1%35!,051%4R`N("<O<G5L92]H96%D
M97(N:6YC)SL*"B\J($%D9"!N97<L(&)L86YK(&-O;F1I=&EO;BX@*B\*)')U
M;&5;)V-O;F1I=&EO;G,G75M=(#T@87)R87DH*3L*"B\J($%V86EL86)L92!C
M;VYD:71I;VYS+B`J+PHD879A:6Q?='EP97,@/2`D:6YG;U]S8W)I<'0M/F%V
M86EL86)L951Y<&5S*"D["B1L87-T8V]N9"`](&-O=6YT*"1R=6QE6R=C;VYD
M:71I;VYS)UTI("T@,3L*"B\J($1I<W!L87D@=&AE(&-O;F1I=&EO;G,N("HO
M"F9O<F5A8V@@*"1R=6QE6R=C;VYD:71I;VYS)UT@87,@)&-O;F1?;G5M(#T^
M("1C;VYD:71I;VXI('L*("`@("1L87-T9FEE;&0@/2`H)&QA<W1C;VYD(#T]
M("1C;VYD7VYU;2D@/R!T<G5E(#H@9F%L<V4["@H@("`@+RH@0W)E871E('1H
M92!F:65L9"!L:7-T:6YG+B`J+PH@("`@)&9I96QD7W-E;&5C="`]("<G.PH@
M("`@)&]P=&EO;E]S96QE8W1E9"`]("%I<W-E="@D8V]N9&ET:6]N6R=F:65L
M9"==*3L*"B`@("!I9B`H)&QA<W1F:65L9"D@>PH@("`@("`@("1F:65L9%]S
M96QE8W0@+CT@)SQO<'1I;VX@=F%L=64](B(^)R`N(%\H(E-E;&5C="!A(&9I
M96QD(BD@+B`B/"]O<'1I;VX^7&XB.PH@("`@("`@("1F:65L9%]S96QE8W0@
M+CT@(CQO<'1I;VX@=F%L=64]7")<(CX@+2TM+2TM+2TM(#PO;W!T:6]N/EQN
M(CL*("`@('T*"B`@("!F;W)E86-H("@D:6YG;U]F:65L9',@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@:68@*&EN7V%R<F%Y*"1V86Q;)W1Y<&4G72P@
M)&%V86EL7W1Y<&5S*2D@>PH@("`@("`@("`@("`D9FEE;&1?<V5L96-T("X]
M("<\;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`N
M("<B)SL*("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYD:71I;VY;)V9I96QD
M)UTI*2!["B`@("`@("`@("`@("`@("!I9B`H)&ME>2`]/2`D8V]N9&ET:6]N
M6R=F:65L9"==*2!["B`@("`@("`@("`@("`@("`@("`@)&9I96QD7W-E;&5C
M="`N/2`G('-E;&5C=&5D/2)S96QE8W1E9"(G.PH@("`@("`@("`@("`@("`@
M("`@("1O<'1I;VY?<V5L96-T960@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1F:65L9%]S96QE8W0@+CT@
M)SXG("X@:'1M;'-P96-I86QC:&%R<R@D=F%L6R=L86)E;"==*2`N("(\+V]P
M=&EO;CY<;B(["B`@("`@("`@?0H@("`@?0H*("`@("\J($%D9"!A;GD@<W!E
M8VEA;"!T>7!E<RX@*B\*("`@("1S<&5C:6%L(#T@)&EN9V]?<V-R:7!T+3YS
M<&5C:6%L5'EP97,H*3L*("`@(&EF("AC;W5N="@D<W!E8VEA;"DI('L*("`@
M("`@("`D9FEE;&1?<V5L96-T("X]("(\;W!T:6]N('9A;'5E/5PB7"(^("TM
M+2TM+2TM+2`\+V]P=&EO;CY<;B(["B`@("`@("`@9F]R96%C:"`H)'-P96-I
M86P@87,@)'1Y<&4I('L*("`@("`@("`@("`@)'-E;&5C=&5D(#T@)R<["B`@
M("`@("`@("`@(&EF("AI<W-E="@D8V]N9&ET:6]N6R=F:65L9"==*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("1C;VYD:71I;VY;)V9I96QD
M)UTI('L*("`@("`@("`@("`@("`@("`@("`D<V5L96-T960@/2`G('-E;&5C
M=&5D/2)S96QE8W1E9"(G.PH@("`@("`@("`@("`@("`@("`@("1O<'1I;VY?
M<V5L96-T960@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1F:65L9%]S96QE8W0@+CT@)SQO<'1I;VX@=F%L
M=64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1T>7!E*2`N("<B)R`N("1S96QE
M8W1E9"`N("<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1Y<&4I("X@)SPO;W!T
M:6]N/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J($%D9"!U<V5R(&1E9FEN
M960@:&5A9&5R(&]P=&EO;BX@*B\*("`@("1H96%D97)?96YT<GD@/2!F86QS
M93L*("`@(&EF("@D8V]N9ELG<G5L97,G75LG=7-E<FAE861E<B==*2!["B`@
M("`@("`@)&9I96QD7W-E;&5C="`N/2`B/&]P=&EO;B!V86QU93U<(EPB/B`M
M+2TM+2TM+2T@/"]O<'1I;VX^7&XB.PH@("`@("`@("1F:65L9%]S96QE8W0@
M+CT@)SQO<'1I;VX@=F%L=64](B<@+B!)3D=/7U5315)?2$5!1$52("X@)R(G
M("X@*"@A)&]P=&EO;E]S96QE8W1E9"D@/R`G('-E;&5C=&5D/2)S96QE8W1E
M9"(G(#H@)R<I("X@)SXG("X@7R@B4V5L9BU$969I;F5D($AE861E<B(I("X@
M*"@D;&%S=&9I96QD*2`_("<G(#H@)SHG*2`N("(\+V]P=&EO;CY<;B(["B`@
M("`@("`@:68@*"$D;W!T:6]N7W-E;&5C=&5D*2!["B`@("`@("`@("`@("1H
M96%D97)?96YT<GD@/2!T<G5E.PH@("`@("`@("`@("`D=7-E<FAE861E<B`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R:&5A9&5R)RD["B`@("`@("`@("`@
M(&EF("AE;7!T>2@D=7-E<FAE861E<BDI('L*("`@("`@("`@("`@("`@("1U
M<V5R:&5A9&5R(#T@:7-S970H)&-O;F1I=&EO;ELG9FEE;&0G72D@/R`D8V]N
M9&ET:6]N6R=F:65L9"==(#H@)R<["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=7-E<FAE861E<B`]("1U<V5R:&5A9&5R6R1C;VYD
M7VYU;5T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@:68@
M*"1L87-T9FEE;&0I('L*("`@("`@("!R97%U:7)E($E.1T]?5$5-4$Q!5$53
M("X@)R]R=6QE+V9I;'1E<BYI;F,G.PH@("`@("`@(&-O;G1I;G5E.PH@("`@
M?0H*("`@("\J($-R96%T92!T:&4@;6%T8V@@;&ES=&EN9RX@*B\*("`@(&EF
M("@A:7-S970H)&-O;F1I=&EO;ELG9FEE;&0G72D@?'P*("`@("`@("`H)&-O
M;F1I=&EO;ELG9FEE;&0G72`]/2!)3D=/7U5315)?2$5!1$52*2!\?`H@("`@
M("`@("%I<W-E="@D:6YG;U]F:65L9'-;)&-O;F1I=&EO;ELG9FEE;&0G75U;
M)W1E<W1S)UTI*2!["B`@("`@("`@)&%V86EL7W1E<W1S(#T@)&EN9V]?<V-R
M:7!T+3YA=F%I;&%B;&5497-T<R@I.PH@("`@?2!E;'-E('L*("`@("`@("`D
M879A:6Q?=&5S=',@/2`D:6YG;U]F:65L9'-;)&-O;F1I=&EO;ELG9FEE;&0G
M75U;)W1E<W1S)UT["B`@("!]"@H@("`@)&UA=&-H7W-E;&5C="`]("<G.PH*
M("`@(&EF("AE;7!T>2@D879A:6Q?=&5S=',I*2!["B`@("`@("`@)&UA=&-H
M7W-E;&5C="`]("(\;W!T:6]N('9A;'5E/5PB7"(^("TM+2TM+2TM+2`\+V]P
M=&EO;CY<;B(["B`@("!](&5L<V4@>PH@("`@("`@(&9O<F5A8V@@*"1A=F%I
M;%]T97-T<R!A<R`D=&5S="D@>PH@("`@("`@("`@("`D=&5S=$]B(#T@)&EN
M9V]?<W1O<F%G92T^9V5T5&5S=$EN9F\H)'1E<W0I.PH@("`@("`@("`@("`D
M;6%T8VA?<V5L96-T("X]("<\;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P96-I
M86QC:&%R<R@D=&5S="D@+B`G(B<["B`@("`@("`@("`@(&EF("@A96UP='DH
M)&-O;F1I=&EO;ELG;6%T8V@G72DI('L*("`@("`@("`@("`@("`@(&EF("@D
M=&5S="`]/2`D8V]N9&ET:6]N6R=M871C:"==*2!["B`@("`@("`@("`@("`@
M("`@("`@)&UA=&-H7W-E;&5C="`N/2`G('-E;&5C=&5D/2)S96QE8W1E9"(G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1M871C:%]S96QE8W0@+CT@)SXG("X@:'1M;'-P96-I86QC:&%R<R@D=&5S
M=$]B+3YL86)E;"D@+B`B/"]O<'1I;VX^7&XB.PH@("`@("`@('T*("`@('T*
M"B`@("`O*B!#<F5A=&4@=&AE(&UA=&-H:6YG(&EN<'5T(&5L96UE;G1S+B`J
M+PH@("`@)'1E<W1/8B`]("1I;F=O7W-T;W)A9V4M/F=E=%1E<W1);F9O*"%E
M;7!T>2@D8V]N9&ET:6]N6R=M871C:"==*2`_("1C;VYD:71I;VY;)VUA=&-H
M)UT@.B`G8V]N=&%I;G,G*3L*("`@("1V86QU92`](&ES<V5T*"1C;VYD:71I
M;VY;)W9A;'5E)UTI(#\@:'1M;'-P96-I86QC:&%R<R@D8V]N9&ET:6]N6R=V
M86QU92==*3H@)R<["@H@("`@)&UA=&-H7W9A;'5E(#T@)SQI;G!U="!N86UE
M/2)V86QU95LG("X@*&EN="DD8V]N9%]N=6T@+B`G72(@<VEZ93TB-#`B('9A
M;'5E/2(G("X@)'9A;'5E("X@)R(@+SXG.PH*("`@('-W:71C:"`H)'1E<W1/
M8BT^='EP92D@>PH@("`@8V%S92`G=&5X="<Z"B`@("`@("`@:68@*"1I;F=O
M7W-C<FEP="T^8V%S95-E;G-I=&EV92@I*2!["B`@("`@("`@("`@("1M871C
M:%]V86QU92`N/2`G/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)C87-E
M6R<@+B`H:6YT*21C;VYD7VYU;2`N("==(B!V86QU93TB,2(@)SL*("`@("`@
M("`@("`@)&UA=&-H7W9A;'5E("X]("AI<W-E="@D8V]N9&ET:6]N6R=C87-E
M)UTI("8F("1C;VYD:71I;VY;)V-A<V4G72D@/R`G8VAE8VME9#TB8VAE8VME
M9"(@)R`Z("<G.PH@("`@("`@("`@("`D;6%T8VA?=F%L=64@+CT@)R\^("<@
M+B!?*")#87-E(%-E;G-I=&EV92(I.PH@("`@("`@('T*("`@("`@("!B<F5A
M:SL*("`@('T*("`@(')E<75I<F4@24Y'3U]414U03$%415,@+B`G+W)U;&4O
M9FEL=&5R+FEN8R<["GT*"B\J($=E="!T:&4@86-T:6]N('-E;&5C="!O=71P
M=70N("HO"B1A8W1I;VYS96QE8W0@/2`G)SL*)&%C=&EO;FQI<W0@/2`D:6YG
M;U]S8W)I<'0M/F%V86EL86)L94%C=&EO;G,H*3L*9F]R96%C:"`H)&%C=&EO
M;FQI<W0@87,@)'9A;"D@>PH@("`@)&%C=&EO;G-E;&5C="`N/2`G/&]P=&EO
M;B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'9A;"D@+B`G(B<["B`@
M("`D86-T:6]N(#T@)&EN9V]?<W1O<F%G92T^9V5T06-T:6]N26YF;R@D=F%L
M*3L*("`@(&EF("@D=F%L(#T]("1R=6QE6R=A8W1I;VXG72D@>PH@("`@("`@
M("1A8W1I;VYS96QE8W0@+CT@)R!S96QE8W1E9#TB<V5L96-T960B)SL*("`@
M("`@("`D8W5R<F5N=%]A8W1I;VX@/2`D86-T:6]N.PH@("`@("`@("1A8W1I
M;VXM/FQA8F5L("X]("<Z)SL*("`@('T*("`@("1A8W1I;VYS96QE8W0@+CT@
M)SXG("X@:'1M;'-P96-I86QC:&%R<R@D86-T:6]N+3YL86)E;"D@+B`B/"]O
M<'1I;VX^7&XB.PI]"@HO*B!'970@=&AE(&%C=&EO;B!V86QU92!O=71P=70N
M("HO"B1A8W1I;VYV86QU92`]("<G.PIS=VET8V@@*"1C=7)R96YT7V%C=&EO
M;BT^='EP92D@>PIC87-E("=F;VQD97(G.@H@("`@)&%C=&EO;G9A;'5E(#T@
M26YG;SHZ9FQI<W1396QE8W0H)')U;&5;)V%C=&EO;BUV86QU92==+"`G<G5L
M92<I.PH@("`@8G)E86L["@IC87-E("=T97AT)SH*8V%S92`G:6YT)SH*("`@
M("1A8W1I;VYV86QU92`]("<\:6YP=70@;F%M93TB86-T:6]N=F%L=64B('-I
M>F4](C0P(B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)')U;&5;)V%C
M=&EO;BUV86QU92==*2`N("<B("\^)SL*("`@(&)R96%K.PI]"@IR97%U:7)E
M($E.1T]?5$5-4$Q!5$53("X@)R]R=6QE+V9O;W1E<BYI;F,G.PIR97%U:7)E
M("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M
M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;F=O+VEN9&5X+G!H<```````````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q-C4R`#$P-#$W,S8R-S4P`#`Q-S$W-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!I;F=O+VEN9&5X+G!H<"QV(#$N,30N,3`N,R`R,#`V+S`Q
M+S,Q(#(P.C`P.C(S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E
M<R]A<VPN<&AP+@H@*B\*"D!D969I;F4H)TE.1T]?0D%312<L(&1I<FYA;64H
M7U]&24Q%7U\I*3L*)&EN9V]?8V]N9FEG=7)E9"`]("A`:7-?<F5A9&%B;&4H
M24Y'3U]"05-%("X@)R]C;VYF:6<O8V]N9BYP:'`G*2`F)@H@("`@("`@("`@
M("`@("`@("`@($!I<U]R96%D86)L92A)3D=/7T)!4T4@+B`G+V-O;F9I9R]P
M<F5F<RYP:'`G*2`F)@H@("`@("`@("`@("`@("`@("`@($!I<U]R96%D86)L
M92A)3D=/7T)!4T4@+B`G+V-O;F9I9R]B86-K96YD<RYP:'`G*2`F)@H@("`@
M("`@("`@("`@("`@("`@($!I<U]R96%D86)L92A)3D=/7T)!4T4@+B`G+V-O
M;F9I9R]F:65L9',N<&AP)RDI.PH*:68@*"$D:6YG;U]C;VYF:6=U<F5D*2![
M"B`@("!R97%U:7)E($E.1T]?0D%312`N("<O+BXO;&EB+U1E<W0N<&AP)SL*
M("`@($AO<F1E7U1E<W0Z.F-O;F9I9T9I;&5S36ES<VEN9R@G26YG;R<L($E.
M1T]?0D%312P*("`@("`@("!A<G)A>2@G8V]N9BYP:'`G+"`G<')E9G,N<&AP
M)RP@)V)A8VME;F1S+G!H<"<I+`H@("`@("`@(&%R<F%Y*"=F:65L9',N<&AP
M)R`]/B`G5&AI<R!F:6QE(&1E9FEN97,@='EP97,@;V8@8W)E9&5N=&EA;',@
M=&AA="!A(&)A8VME;F0@;6EG:'0@<F5Q=65S="XG*2D["GT*"G)E<75I<F4@
M24Y'3U]"05-%("X@)R]F:6QT97)S+G!H<"<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]K<F]N;VQI=&@O````````````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`Q-C0S-0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]S8W)I<'1S+P``````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-3``,#(P,3(Q`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L
M:71H+W-C<FEP=',O<W%L+P``````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,``P,C`W,C``(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]K<F]N;VQI=&@O<V-R:7!T<R]S<6PO:W)O;F]L:71H+G!G
M<W%L+G-Q;````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-34P`#$P-#$W,S8R-S4P`#`R
M-#4W-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+2`D2&]R9&4Z(&MR;VYO;&ET:"]S8W)I<'1S+W-Q;"]K<F]N;VQI=&@N
M<&=S<6PN<W%L+'8@,2XS(#(P,#0O,3(O,C$@,34Z-3(Z,S(@8VAU8VL@17AP
M("0*"D-214%412!404),12!K<F]N;VQI=&A?979E;G1S("@*("`@(&5V96YT
M7VED(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@979E;G1?=6ED(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@(&-A;&5N9&%R7VED(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@(&5V96YT7V-R96%T;W)?:60@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@979E;G1?9&5S8W)I<'1I;VX@5$585"P*("`@(&5V
M96YT7VQO8V%T:6]N(%1%6%0L"B`@("!E=F5N=%]S=&%T=7,@24Y4($1%1D%5
M3%0@,"P*("`@(&5V96YT7V%T=&5N9&5E<R!415A4+`H@("`@979E;G1?:V5Y
M=V]R9',@5$585"P*("`@(&5V96YT7V5X8V5P=&EO;G,@5$585"P*("`@(&5V
M96YT7W1I=&QE(%9!4D-(05(H,C4U*2P*("`@(&5V96YT7V-A=&5G;W)Y(%9!
M4D-(05(H.#`I+`H@("`@979E;G1?<F5C=7)T>7!E(%9!4D-(05(H,3$I($1%
M1D%53%0@,"P*("`@(&5V96YT7W)E8W5R:6YT97)V86P@5D%20TA!4B@Q,2DL
M"B`@("!E=F5N=%]R96-U<F1A>7,@5D%20TA!4B@Q,2DL"B`@("!E=F5N=%]R
M96-U<F5N9&1A=&4@5$E-15-404U0+`H@("`@979E;G1?<W1A<G0@5$E-15-4
M04U0+`H@("`@979E;G1?96YD(%1)34535$%-4"P*("`@(&5V96YT7V%L87)M
M($E.5"!$149!54Q4(#`L"B`@("!E=F5N=%]M;V1I9FEE9"!)3E0@3D]4($Y5
M3$PL"@H@("`@4%))34%262!+15D@*&5V96YT7VED*0HI.PH*0U)%051%($E.
M1$58(&MR;VYO;&ET:%]C86QE;F1A<E]I9'@@3TX@:W)O;F]L:71H7V5V96YT
M<R`H8V%L96YD87)?:60I.PI#4D5!5$4@24Y$15@@:W)O;F]L:71H7W5I9%]I
M9'@@3TX@:W)O;F]L:71H7V5V96YT<R`H979E;G1?=6ED*3L*"D=204Y4(%-%
M3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!K<F]N;VQI=&A?979E
M;G1S(%1/(&AO<F1E.PH*"D-214%412!404),12!K<F]N;VQI=&A?<W1O<F%G
M92`H"B`@("!V9F)?;W=N97(@("`@("!605)#2$%2*#(U-2D@1$5&055,5"!.
M54Q,+`H@("`@=F9B7V5M86EL("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,
M($1%1D%53%0@)R<L"B`@("!V9F)?<V5R:6%L:7IE9"!415A4($Y/5"!.54Q,
M"BD["@I#4D5!5$4@24Y$15@@:W)O;F]L:71H7W9F8E]O=VYE<E]I9'@@3TX@
M:W)O;F]L:71H7W-T;W)A9V4@*'9F8E]O=VYE<BD["D-214%412!)3D1%6"!K
M<F]N;VQI=&A?=F9B7V5M86EL7VED>"!/3B!K<F]N;VQI=&A?<W1O<F%G92`H
M=F9B7V5M86EL*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%
M3$5412!/3B!K<F]N;VQI=&A?<W1O<F%G92!43R!H;W)D93L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]S
M8W)I<'1S+W-Q;"]K<F]N;VQI=&@N;7ES<6PN<W%L````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(V,#4`,3`T,3<S-C(W-3``,#(T-C$V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM("1(;W)D93H@:W)O;F]L:71H
M+W-C<FEP=',O<W%L+VMR;VYO;&ET:"YM>7-Q;"YS<6PL=B`Q+C,@,C`P-"\Q
M,B\R,2`Q-3HU,CHS,B!C:'5C:R!%>'`@)`H*55-%(&AO<F1E.PH*0U)%051%
M(%1!0DQ%(&MR;VYO;&ET:%]E=F5N=',@*`H@("`@979E;G1?:60@5D%20TA!
M4B@S,BD@3D]4($Y53$PL"B`@("!E=F5N=%]U:60@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@8V%L96YD87)?:60@5D%20TA!4B@R-34I($Y/5"!.54Q,
M+`H@("`@979E;G1?8W)E871O<E]I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL
M"B`@("!E=F5N=%]D97-C<FEP=&EO;B!415A4+`H@("`@979E;G1?;&]C871I
M;VX@5$585"P*("`@(&5V96YT7W-T871U<R!)3E0@1$5&055,5"`P+`H@("`@
M979E;G1?871T96YD965S(%1%6%0L"B`@("!E=F5N=%]K97EW;W)D<R!415A4
M+`H@("`@979E;G1?97AC97!T:6]N<R!415A4+`H@("`@979E;G1?=&ET;&4@
M5D%20TA!4B@R-34I+`H@("`@979E;G1?8V%T96=O<GD@5D%20TA!4B@X,"DL
M"B`@("!E=F5N=%]R96-U<G1Y<&4@5D%20TA!4B@Q,2D@1$5&055,5"`P+`H@
M("`@979E;G1?<F5C=7)I;G1E<G9A;"!605)#2$%2*#$Q*2P*("`@(&5V96YT
M7W)E8W5R9&%Y<R!605)#2$%2*#$Q*2P*("`@(&5V96YT7W)E8W5R96YD9&%T
M92!$051%5$E-12P*("`@(&5V96YT7W-T87)T($1!5$5424U%+`H@("`@979E
M;G1?96YD($1!5$5424U%+`H@("`@979E;G1?86QA<FT@24Y4($1%1D%53%0@
M,"P*("`@(&5V96YT7VUO9&EF:65D($E.5"!.3U0@3E5,3"P*"B`@("!04DE-
M05)9($M%62`H979E;G1?:60I"BD["@I#4D5!5$4@24Y$15@@:W)O;F]L:71H
M7V-A;&5N9&%R7VED>"!/3B!K<F]N;VQI=&A?979E;G1S("AC86QE;F1A<E]I
M9"D["D-214%412!)3D1%6"!K<F]N;VQI=&A?=6ED7VED>"!/3B!K<F]N;VQI
M=&A?979E;G1S("AE=F5N=%]U:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L
M(%501$%412P@1$5,151%($].(&MR;VYO;&ET:%]E=F5N=',@5$\@:&]R9&5`
M;&]C86QH;W-T.PH*"D-214%412!404),12!K<F]N;VQI=&A?<W1O<F%G92`H
M"B`@("!V9F)?;W=N97(@("`@("!605)#2$%2*#(U-2D@1$5&055,5"!.54Q,
M+`H@("`@=F9B7V5M86EL("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%
M1D%53%0@)R<L"B`@("!V9F)?<V5R:6%L:7IE9"!415A4($Y/5"!.54Q,"BD[
M"@I#4D5!5$4@24Y$15@@:W)O;F]L:71H7W9F8E]O=VYE<E]I9'@@3TX@:W)O
M;F]L:71H7W-T;W)A9V4@*'9F8E]O=VYE<BD["D-214%412!)3D1%6"!K<F]N
M;VQI=&A?=F9B7V5M86EL7VED>"!/3B!K<F]N;VQI=&A?<W1O<F%G92`H=F9B
M7V5M86EL*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$54
M12!/3B!K<F]N;VQI=&A?<W1O<F%G92!43R!H;W)D94!L;V-A;&AO<W0["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+W-C<FEP=',O<W%L+VMR;VYO;&ET:"YS
M<6P````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4S-P`Q,#0Q-S,V,C<U,``P
M,C,T-38`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+2T@)$AO<F1E.B!K<F]N;VQI=&@O<V-R:7!T<R]S<6PO:W)O;F]L:71H
M+G-Q;"QV(#$N,R`R,#`T+S$R+S(Q(#$U.C4R.C,R(&-H=6-K($5X<"`D"@I#
M4D5!5$4@5$%"3$4@:W)O;F]L:71H7V5V96YT<R`H"B`@("!E=F5N=%]I9"!6
M05)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&5V96YT7W5I9"!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!C86QE;F1A<E]I9"!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!E=F5N=%]C<F5A=&]R7VED(%9!4D-(05(H,C4U*2!.3U0@
M3E5,3"P*("`@(&5V96YT7V1E<V-R:7!T:6]N(%1%6%0L"B`@("!E=F5N=%]L
M;V-A=&EO;B!415A4+`H@("`@979E;G1?<W1A='5S($E.5"!$149!54Q4(#`L
M"B`@("!E=F5N=%]A='1E;F1E97,@5$585"P*("`@(&5V96YT7VME>7=O<F1S
M(%1%6%0L"B`@("!E=F5N=%]E>&-E<'1I;VYS(%1%6%0L"B`@("!E=F5N=%]T
M:71L92!605)#2$%2*#(U-2DL"B`@("!E=F5N=%]C871E9V]R>2!605)#2$%2
M*#@P*2P*("`@(&5V96YT7W)E8W5R='EP92!605)#2$%2*#$Q*2!$149!54Q4
M(#`L"B`@("!E=F5N=%]R96-U<FEN=&5R=F%L(%9!4D-(05(H,3$I+`H@("`@
M979E;G1?<F5C=7)D87ES(%9!4D-(05(H,3$I+`H@("`@979E;G1?<F5C=7)E
M;F1D871E($1!5$5424U%+`H@("`@979E;G1?<W1A<G0@1$%4151)344L"B`@
M("!E=F5N=%]E;F0@1$%4151)344L"B`@("!E=F5N=%]A;&%R;2!)3E0@1$5&
M055,5"`P+`H@("`@979E;G1?;6]D:69I960@24Y4($Y/5"!.54Q,+`H*("`@
M(%!224U!4ED@2T59("AE=F5N=%]I9"D**3L*"D-214%412!)3D1%6"!K<F]N
M;VQI=&A?8V%L96YD87)?:61X($].(&MR;VYO;&ET:%]E=F5N=',@*&-A;&5N
M9&%R7VED*3L*0U)%051%($E.1$58(&MR;VYO;&ET:%]U:61?:61X($].(&MR
M;VYO;&ET:%]E=F5N=',@*&5V96YT7W5I9"D["@I'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:W)O;F]L:71H7V5V96YT<R!43R!H
M;W)D93L*"@I#4D5!5$4@5$%"3$4@:W)O;F]L:71H7W-T;W)A9V4@*`H@("`@
M=F9B7V]W;F5R("`@("`@5D%20TA!4B@R-34I($1%1D%53%0@3E5,3"P*("`@
M('9F8E]E;6%I;"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4
M("<G+`H@("`@=F9B7W-E<FEA;&EZ960@5$585"!.3U0@3E5,3`HI.PH*0U)%
M051%($E.1$58(&MR;VYO;&ET:%]V9F)?;W=N97)?:61X($].(&MR;VYO;&ET
M:%]S=&]R86=E("AV9F)?;W=N97(I.PI#4D5!5$4@24Y$15@@:W)O;F]L:71H
M7W9F8E]E;6%I;%]I9'@@3TX@:W)O;F]L:71H7W-T;W)A9V4@*'9F8E]E;6%I
M;"D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@
M:W)O;F]L:71H7W-T;W)A9V4@5$\@:&]R9&4["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O
M<V-R:7!T<R]S<6PO:W)O;F]L:71H+FUS<W%L+G-Q;```````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-C(W`#$P-#$W,S8R-S4P`#`R-#8Q-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+2`D2&]R9&4Z(&MR;VYO;&ET
M:"]S8W)I<'1S+W-Q;"]K<F]N;VQI=&@N;7-S<6PN<W%L+'8@,2XQ+C(N,2`R
M,#`V+S`Q+S$X(#$Y.C4Y.C(R(&)E;B!%>'`@)`H*0U)%051%(%1!0DQ%(&MR
M;VYO;&ET:%]E=F5N=',@*`H@("`@979E;G1?:60@5D%20TA!4B@S,BD@3D]4
M($Y53$PL"B`@("!E=F5N=%]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@
M("`@8V%L96YD87)?:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@979E
M;G1?8W)E871O<E]I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!E=F5N
M=%]D97-C<FEP=&EO;B!605)#2$%2*$U!6"DL"B`@("!E=F5N=%]L;V-A=&EO
M;B!605)#2$%2*$U!6"DL"B`@("!E=F5N=%]S=&%T=7,@24Y4($1%1D%53%0@
M,"P*("`@(&5V96YT7V%T=&5N9&5E<R!605)#2$%2*$U!6"DL"B`@("!E=F5N
M=%]K97EW;W)D<R!605)#2$%2*$U!6"DL"B`@("!E=F5N=%]E>&-E<'1I;VYS
M(%9!4D-(05(H34%8*2P*("`@(&5V96YT7W1I=&QE(%9!4D-(05(H,C4U*2P*
M("`@(&5V96YT7V-A=&5G;W)Y(%9!4D-(05(H.#`I+`H@("`@979E;G1?<F5C
M=7)T>7!E(%9!4D-(05(H,3$I($1%1D%53%0@,"P*("`@(&5V96YT7W)E8W5R
M:6YT97)V86P@5D%20TA!4B@Q,2DL"B`@("!E=F5N=%]R96-U<F1A>7,@5D%2
M0TA!4B@Q,2DL"B`@("!E=F5N=%]R96-U<F5N9&1A=&4@1$%4151)344L"B`@
M("!E=F5N=%]S=&%R="!$051%5$E-12P*("`@(&5V96YT7V5N9"!$051%5$E-
M12P*("`@(&5V96YT7V%L87)M($E.5"!$149!54Q4(#`L"B`@("!E=F5N=%]M
M;V1I9FEE9"!)3E0@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*&5V96YT
M7VED*0HI.PH*0U)%051%($E.1$58(&MR;VYO;&ET:%]C86QE;F1A<E]I9'@@
M3TX@:W)O;F]L:71H7V5V96YT<R`H8V%L96YD87)?:60I.PI#4D5!5$4@24Y$
M15@@:W)O;F]L:71H7W5I9%]I9'@@3TX@:W)O;F]L:71H7V5V96YT<R`H979E
M;G1?=6ED*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$54
M12!/3B!K<F]N;VQI=&A?979E;G1S(%1/(&AO<F1E.PH*"D-214%412!404),
M12!K<F]N;VQI=&A?<W1O<F%G92`H"B`@("!V9F)?;W=N97(@("`@("!605)#
M2$%2*#(U-2D@1$5&055,5"!.54Q,+`H@("`@=F9B7V5M86EL("`@("`@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`@("!V9F)?<V5R:6%L
M:7IE9"!605)#2$%2*$U!6"D@3D]4($Y53$P**3L*"D-214%412!)3D1%6"!K
M<F]N;VQI=&A?=F9B7V]W;F5R7VED>"!/3B!K<F]N;VQI=&A?<W1O<F%G92`H
M=F9B7V]W;F5R*3L*0U)%051%($E.1$58(&MR;VYO;&ET:%]V9F)?96UA:6Q?
M:61X($].(&MR;VYO;&ET:%]S=&]R86=E("AV9F)?96UA:6PI.PH*1U)!3E0@
M4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&MR;VYO;&ET:%]S
M=&]R86=E(%1/(&AO<F1E.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]S8W)I<'1S+W-Q;"]K<F]N;VQI=&@N
M;V-I."YS<6P`````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V-#4`,3`T,3<S-C(W-3``
M,#(T,S$W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM("1(;W)D93H@:W)O;F]L:71H+W-C<FEP=',O<W%L+VMR;VYO;&ET
M:"YO8VDX+G-Q;"QV(#$N-"XR+C(@,C`P-2\Q,"\Q."`Q,CHR-SHT,"!J86X@
M17AP("0*"D-214%412!404),12!K<F]N;VQI=&A?979E;G1S("@*("`@(&5V
M96YT7VED(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*("`@(&5V96YT7W5I9"!6
M05)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@8V%L96YD87)?:60@5D%20TA!
M4C(H,C4U*2!.3U0@3E5,3"P*("`@(&5V96YT7V-R96%T;W)?:60@5D%20TA!
M4C(H,C4U*2!.3U0@3E5,3"P*("`@(&5V96YT7V1E<V-R:7!T:6]N(%9!4D-(
M05(R*#0P,#`I+`H@("`@979E;G1?;&]C871I;VX@5D%20TA!4C(H-#`P,"DL
M"B`@("!E=F5N=%]S=&%T=7,@24Y4($1%1D%53%0@,"P*("`@(&5V96YT7V%T
M=&5N9&5E<R!605)#2$%2,B@T,#`P*2P*("`@(&5V96YT7VME>7=O<F1S(%9!
M4D-(05(R*#0P,#`I+`H@("`@979E;G1?97AC97!T:6]N<R!605)#2$%2,B@T
M,#`P*2P*("`@(&5V96YT7W1I=&QE(%9!4D-(05(R*#(U-2DL"B`@("!E=F5N
M=%]C871E9V]R>2!605)#2$%2,B@X,"DL"B`@("!E=F5N=%]R96-U<G1Y<&4@
M5D%20TA!4C(H,3$I($1%1D%53%0@)S`G+`H@("`@979E;G1?<F5C=7)I;G1E
M<G9A;"!605)#2$%2,B@Q,2DL"B`@("!E=F5N=%]R96-U<F1A>7,@5D%20TA!
M4C(H,3$I+`H@("`@979E;G1?<F5C=7)E;F1D871E($1!5$4L"B`@("!E=F5N
M=%]S=&%R="!$051%+`H@("`@979E;G1?96YD($1!5$4L"B`@("!E=F5N=%]A
M;&%R;2!)3E0@1$5&055,5"`P+`H@("`@979E;G1?;6]D:69I960@24Y4($Y/
M5"!.54Q,+`HM+0H@("`@4%))34%262!+15D@*&5V96YT7VED*0HI.PH*0U)%
M051%($E.1$58(&MR;VYO;&ET:%]C86QE;F1A<E]I9'@@3TX@:W)O;F]L:71H
M7V5V96YT<R`H8V%L96YD87)?:60I.PI#4D5!5$4@24Y$15@@:W)O;F]L:71H
M7W5I9%]I9'@@3TX@:W)O;F]L:71H7V5V96YT<R`H979E;G1?=6ED*3L*"D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!K<F]N;VQI
M=&A?979E;G1S(%1/(&AO<F1E.PH*"D-214%412!404),12!K<F]N;VQI=&A?
M<W1O<F%G92`H"B`@("!V9F)?;W=N97(@("`@("!605)#2$%2,B@R-34I($1%
M1D%53%0@3E5,3"P*("`@('9F8E]E;6%I;"`@("`@(%9!4D-(05(R*#(U-2D@
M1$5&055,5"`G)R!.3U0@3E5,3"P*("`@('9F8E]S97)I86QI>F5D(%9!4D-(
M05(R*#0P,#`I($Y/5"!.54Q,"BD["@I#4D5!5$4@24Y$15@@:W)O;F]L:71H
M7W9F8E]O=VYE<E]I9'@@3TX@:W)O;F]L:71H7W-T;W)A9V4@*'9F8E]O=VYE
M<BD["D-214%412!)3D1%6"!K<F]N;VQI=&A?=F9B7V5M86EL7VED>"!/3B!K
M<F]N;VQI=&A?<W1O<F%G92`H=F9B7V5M86EL*3L*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!K<F]N;VQI=&A?<W1O<F%G92!4
M3R!H;W)D93L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+W-C<FEP=',O=7!G<F%D97,O````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,``P,C$W,S,`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]K<F]N;VQI=&@O<V-R:7!T<R]U<&=R861E<R\Q+C%?=&]?,BXP
M+G!G<W%L+G-Q;````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C`U`#$P-#$W,S8R-S4P`#`R-3$V
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+2!5<&1A=&4@<V-R:7!T('1O('5P9&%T92!+<F]N;VQI=&@@,2XQ(&1A=&$@
M=&\@,BYX(&1A=&$@9F]R('!G<W%L"BTM($-O;G9E<G1E9"!F<F]M(&UY<W%L
M('9E<G-I;VX@8GD@1&%N:65L($4N($UA<FML92`\;&5X:6-O;D!S975L+F]R
M9SX*+2T*+2T@66]U(&-A;B!S:6UP;'D@97AE8W5T92!T:&ES(&9I;&4@:6X@
M>6]U<B!D871A8F%S92X*+2T*+2T@4G5N(&%S.@HM+0HM+2`D('!S<6P@/&1B
M(&YA;64^("UF(#P@,2XQ7W1O7S(N,"YP9W-Q;"YS<6P*"D)%1TE..PI!3%1%
M4B!404),12!K<F]N;VQI=&A?979E;G1S($%$1"!#3TQ534X@979E;G1?:61?
M;F5W(%9!4D-(05(H,S(I.PI54$1!5$4@:W)O;F]L:71H7V5V96YT<R!3150@
M979E;G1?:61?;F5W(#T@979E;G1?:60["D%,5$52(%1!0DQ%(&MR;VYO;&ET
M:%]E=F5N=',@1%)/4"!E=F5N=%]I9#L*04Q415(@5$%"3$4@:W)O;F]L:71H
M7V5V96YT<R!214Y!344@979E;G1?:61?;F5W(%1/(&5V96YT7VED.PI!3%1%
M4B!404),12!K<F]N;VQI=&A?979E;G1S($%,5$52($-/3%5-3B!E=F5N=%]I
M9"!3150@3D]4($Y53$P["D-/34U)5#L*"D)%1TE..PI!3%1%4B!404),12!K
M<F]N;VQI=&A?979E;G1S($%$1"!#3TQ534X@979E;G1?=&ET;&5?;F5W(%9!
M4D-(05(H,C4U*3L*55!$051%(&MR;VYO;&ET:%]E=F5N=',@4T54(&5V96YT
M7W1I=&QE7VYE=R`](&5V96YT7W1I=&QE.PI!3%1%4B!404),12!K<F]N;VQI
M=&A?979E;G1S($123U`@979E;G1?=&ET;&4["D%,5$52(%1!0DQ%(&MR;VYO
M;&ET:%]E=F5N=',@4D5.04U%(&5V96YT7W1I=&QE7VYE=R!43R!E=F5N=%]T
M:71L93L*0T]-34E4.PH*0D5'24X["D%,5$52(%1!0DQ%(&MR;VYO;&ET:%]E
M=F5N=',@041$($-/3%5-3B!E=F5N=%]U:60@5D%20TA!4B@R-34I.PI54$1!
M5$4@:W)O;F]L:71H7V5V96YT<R!3150@979E;G1?=6ED(#T@)R<["D%,5$52
M(%1!0DQ%(&MR;VYO;&ET:%]E=F5N=',@04Q415(@0T],54U.(&5V96YT7W5I
M9"!3150@3D]4($Y53$P["D-/34U)5#L*"D)%1TE..PI!3%1%4B!404),12!K
M<F]N;VQI=&A?979E;G1S($%$1"!#3TQ534X@979E;G1?8W)E871O<E]I9"!6
M05)#2$%2*#(U-2D["E501$%412!K<F]N;VQI=&A?979E;G1S(%-%5"!E=F5N
M=%]C<F5A=&]R7VED(#T@)R<["D%,5$52(%1!0DQ%(&MR;VYO;&ET:%]E=F5N
M=',@04Q415(@0T],54U.(&5V96YT7V-R96%T;W)?:60@4T54($Y/5"!.54Q,
M.PI#3TU-250["@I"14=)3CL*04Q415(@5$%"3$4@:W)O;F]L:71H7V5V96YT
M<R!!1$0@0T],54U.(&5V96YT7W-T871U<R!)3E0["E501$%412!K<F]N;VQI
M=&A?979E;G1S(%-%5"!E=F5N=%]S=&%T=7,@/2`P.PI!3%1%4B!404),12!K
M<F]N;VQI=&A?979E;G1S($%,5$52($-/3%5-3B!E=F5N=%]S=&%T=7,@4T54
M($1%1D%53%0@,#L*0T]-34E4.PH*04Q415(@5$%"3$4@:W)O;F]L:71H7V5V
M96YT<R!!1$0@0T],54U.(&5V96YT7V%T=&5N9&5E<R!415A4.PH*0U)%051%
M($E.1$58(&MR;VYO;&ET:%]U:61?:61X($].(&MR;VYO;&ET:%]E=F5N=',@
M*&5V96YT7W5I9"D["@I#4D5!5$4@5$%"3$4@:W)O;F]L:71H7W-T;W)A9V4@
M*`H@("`@=F9B7V]W;F5R("`@("`@5D%20TA!4B@R-34I($1%1D%53%0@3E5,
M3"P*("`@('9F8E]E;6%I;"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$
M149!54Q4("<G+`H@("`@=F9B7W-E<FEA;&EZ960@5$585"!.3U0@3E5,3`HI
M.PH*0U)%051%($E.1$58(&MR;VYO;&ET:%]V9F)?;W=N97)?:61X($].(&MR
M;VYO;&ET:%]S=&]R86=E("AV9F)?;W=N97(I.PI#4D5!5$4@24Y$15@@:W)O
M;F]L:71H7W9F8E]E;6%I;%]I9'@@3TX@:W)O;F]L:71H7W-T;W)A9V4@*'9F
M8E]E;6%I;"D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%
M5$4@3TX@:W)O;F]L:71H7W-T;W)A9V4@5$\@:&]R9&4["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:W)O;F]L:71H+W-C<FEP=',O=7!G<F%D97,O,2XQ7W1O7S(N,"YM>7-Q
M;"YS<6P````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C(S,@`Q,#0Q-S,V,C<U,``P,C4Q-S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2T@)$AO
M<F1E.B!K<F]N;VQI=&@O<V-R:7!T<R]U<&=R861E<R\Q+C%?=&]?,BXP+FUY
M<W%L+G-Q;"QV(#$N-"`R,#`T+S$R+S(Q(#$U.C4R.C,R(&-H=6-K($5X<"`D
M"BTM"BTM(%EO=2!C86X@<VEM<&QY(&5X96-U=&4@=&AI<R!F:6QE(&EN('EO
M=7(@9&%T86)A<V4N"BTM"BTM(%)U;B!A<SH*+2T*+2T@)"!M>7-Q;"`M+75S
M97(]<F]O="`M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@
M;F%M93X@/"`Q+C%?=&]?,BXP+FUY<W%L+G-Q;`H*55-%(&AO<F1E.PH*04Q4
M15(@5$%"3$4@:W)O;F]L:71H7V5V96YT<R!#2$%.1T4@0T],54U.(&5V96YT
M7VED(&5V96YT7VED(%9!4D-(05(H,S(I($Y/5"!.54Q,.PI!3%1%4B!404),
M12!K<F]N;VQI=&A?979E;G1S($-(04Y'12!#3TQ534X@979E;G1?=&ET;&4@
M979E;G1?=&ET;&4@5D%20TA!4B@R-34I.PH*04Q415(@5$%"3$4@:W)O;F]L
M:71H7V5V96YT<R!!1$0@0T],54U.(&5V96YT7W5I9"!605)#2$%2*#(U-2D@
M3D]4($Y53$P["D%,5$52(%1!0DQ%(&MR;VYO;&ET:%]E=F5N=',@041$($-/
M3%5-3B!E=F5N=%]C<F5A=&]R7VED(%9!4D-(05(H,C4U*2!.3U0@3E5,3#L*
M04Q415(@5$%"3$4@:W)O;F]L:71H7V5V96YT<R!!1$0@0T],54U.(&5V96YT
M7W-T871U<R!)3E0@1$5&055,5"`P.PI!3%1%4B!404),12!K<F]N;VQI=&A?
M979E;G1S($%$1"!#3TQ534X@979E;G1?871T96YD965S(%1%6%0["@I#4D5!
M5$4@24Y$15@@:W)O;F]L:71H7W5I9%]I9'@@3TX@:W)O;F]L:71H7V5V96YT
M<R`H979E;G1?=6ED*3L*"@I#4D5!5$4@5$%"3$4@:W)O;F]L:71H7W-T;W)A
M9V4@*`H@("`@=F9B7V]W;F5R("`@("`@5D%20TA!4B@R-34I($1%1D%53%0@
M3E5,3"P*("`@('9F8E]E;6%I;"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,
M3"!$149!54Q4("<G+`H@("`@=F9B7W-E<FEA;&EZ960@5$585"!.3U0@3E5,
M3`HI.PH*0U)%051%($E.1$58(&MR;VYO;&ET:%]V9F)?;W=N97)?:61X($].
M(&MR;VYO;&ET:%]S=&]R86=E("AV9F)?;W=N97(I.PI#4D5!5$4@24Y$15@@
M:W)O;F]L:71H7W9F8E]E;6%I;%]I9'@@3TX@:W)O;F]L:71H7W-T;W)A9V4@
M*'9F8E]E;6%I;"D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$
M14Q%5$4@3TX@:W)O;F]L:71H7W-T;W)A9V4@5$\@:&]R9&5`;&]C86QH;W-T
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O<V-R:7!T<R]U
M<&=R861E<R\R,#`T+3$R+3(Q7V%D9%]E=F5N=%]U:60N<W%L````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S8S
M`#$P-#$W,S8R-S4P`#`R-C,U,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+2`D2&]R9&4Z(&MR;VYO;&ET:"]S8W)I<'1S
M+W5P9W)A9&5S+S(P,#0M,3(M,C%?861D7V5V96YT7W5I9"YS<6PL=B`Q+C$@
M,C`P-"\Q,B\R,2`Q-3HU,CHS,B!C:'5C:R!%>'`@)`H*04Q415(@5$%"3$4@
M:W)O;F]L:71H7V5V96YT<R!!1$0@0T],54U.(&5V96YT7W5I9"!605)#2$%2
M*#(U-2D@3D]4($Y53$P["D-214%412!)3D1%6"!K<F]N;VQI=&A?=6ED7VED
M>"!/3B!K<F]N;VQI=&A?979E;G1S("AE=F5N=%]U:60I.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W-C<FEP=',O=7!G<F%D97,O,C`P
M-"TQ,BTR,5]A9&1?979E;G1?=6ED+G!G<W%L+G-Q;``````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4W,``Q,#0Q-S,V,C<U
M,``P,C<T-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@)$AO<F1E.B!K<F]N;VQI=&@O<V-R:7!T<R]U<&=R861E<R\R
M,#`T+3$R+3(Q7V%D9%]E=F5N=%]U:60N<&=S<6PN<W%L+'8@,2XQ+C(N,B`R
M,#`U+S$P+S$X(#$R.C(W.C0Q(&IA;B!%>'`@)`H*04Q415(@5$%"3$4@:W)O
M;F]L:71H7V5V96YT<R!!1$0@0T],54U.(&5V96YT7W5I9"!605)#2$%2*#(U
M-2D["E501$%412!K<F]N;VQI=&A?979E;G1S(%-%5"!E=F5N=%]U:60@/2`G
M)R!72$5212!E=F5N=%]U:60@25,@3E5,3#L*06Q415(@5$%"3$4@:W)O;F]L
M:71H7V5V96YT<R!!3%1%4B!#3TQ534X@979E;G1?=6ED(%-%5"!.3U0@3E5,
M3#L*0U)%051%($E.1$58(&MR;VYO;&ET:%]U:61?:61X($].(&MR;VYO;&ET
M:%]E=F5N=',@*&5V96YT7W5I9"D["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]S8W)I<'1S+W5P9W)A9&5S+S(P,#0M,#4M,3E?8V]N
M=F5R=%]C871E9V]R:65S7W1O7W-T<FEN9W,N<&AP````,#$P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#0V-C``,3`T,3<S-C(W-3``,#,Q-S,P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",A+W5S
M<B]L;V-A;"]B:6XO<&AP"CP_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR;VYO;&ET
M:"]S8W)I<'1S+W5P9W)A9&5S+S(P,#0M,#4M,3E?8V]N=F5R=%]C871E9V]R
M:65S7W1O7W-T<FEN9W,N<&AP+'8@,2XR+C$P+C,@,C`P-B\P,2\P,2`R,3HR
M.3HP-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL
M+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE
M*"=+4D].3TQ)5$A?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N
M+B<I.PIR97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]B87-E
M+G!H<"<["@HO+R!2=6X@=&AR;W5G:"!E=F5R>2!C86QE;F1A<BX*)&-A;',@
M/2`D:W)O;F]L:71H7W-H87)E<RT^;&ES=$%L;%-H87)E<R@I.PIF;W)E86-H
M("@D8V%L<R!A<R`D8V%L:60@/3X@)&-A;'-H87)E*2!["B`@("!E8VAO(")#
M;VYV97)T:6YG(&-A=&5G;W)I97,@9F]R("1C86QI9"`N+BY<;B(["@H@("`@
M:68@*"1K<F]N;VQI=&@M/F=E=$-A;&5N9&%R*"D@(3T@)&-A;&ED*2!["B`@
M("`@("`@)&MR;VYO;&ET:"T^8VQO<V4H*3L*("`@("`@("`D:W)O;F]L:71H
M+3YO<&5N*"1C86QI9"D["B`@("!]"@H@("`@)&-A=&5G;W)I97,@/2!L:7-T
M0V%T96=O<FEE<R@D8V%L:60I.PH*("`@("\O($QI<W0@86QL(&5V96YT<RX*
M("`@("1E=F5N=',@/2`D:W)O;F]L:71H+3YL:7-T179E;G1S*"D["B`@("!F
M;W)E86-H("@D979E;G1S(&%S("1E=F5N=$ED*2!["B`@("`@("`@)&5V96YT
M(#T@)B1K<F]N;VQI=&@M/F=E=$5V96YT*"1E=F5N=$ED*3L*("`@("`@("!I
M9B`H:7-S970H)&-A=&5G;W)I97-;)&5V96YT+3YG971#871E9V]R>2@I72DI
M('L*("`@("`@("`@("`@)&5V96YT+3YS971#871E9V]R>2@D8V%T96=O<FEE
M<ULD979E;G0M/F=E=$-A=&5G;W)Y*"E=*3L*("`@("`@("`@("`@)')E<W5L
M="`]("1E=F5N="T^<V%V92@I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH)')E<W5L="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"GT*"F5C:&\@(EQN*BH@0V%T96=O<FEE<R!S=6-C97-S9G5L;'D@8V]N=F5R
M=&5D("HJ*EQN(CL*97AI=#L*"F9U;F-T:6]N(&QI<W1#871E9V]R:65S*"1C
M86QE;F1A<B`](&YU;&PI"GL*("`@(&=L;V)A;"`D<')E9G,["@H@("`@<W1A
M=&EC("1C8713=')I;F<L("1C871E9V]R:65S.PH*("`@("1C=7(@/2!G9710
M<F5F0GE3:&%R92@G979E;G1?8V%T96=O<FEE<R<L("1C86QE;F1A<BD["B`@
M("!I9B`H:7-?;G5L;"@D8V%T4W1R:6YG*2!\?"`D8V%T4W1R:6YG("$]("1C
M=7(I('L*("`@("`@("`D8V%T96=O<FEE<R`](&%R<F%Y*#`@/3X@7R@B56YF
M:6QE9"(I*3L*"B`@("`@("`@)&-A=%-T<FEN9R`]("1C=7(["B`@("`@("`@
M:68@*&5M<'1Y*"1C8713=')I;F<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M8V%T96=O<FEE<SL*("`@("`@("!]"@H@("`@("`@("1C871S(#T@97AP;&]D
M92@G?"<L("1C8713=')I;F<I.PH@("`@("`@(&9O<F5A8V@@*"1C871S(&%S
M("1C870I('L*("`@("`@("`@("`@;&ES="@D:V5Y+"`D=F%L*2`](&5X<&QO
M9&4H)SHG+"`D8V%T*3L*("`@("`@("`@("`@)&-A=&5G;W)I97-;)&ME>5T@
M/2!?*"1V86PI.PH@("`@("`@('T*("`@('T*"B`@("!A<V]R="@D8V%T96=O
M<FEE<RD["B`@("!R971U<FX@)&-A=&5G;W)I97,["GT*"F9U;F-T:6]N(&=E
M=%!R969">5-H87)E*"1P<F5F+"`D<VAA<F4@/2!N=6QL*0I["B`@("!I9B`H
M(6ES7V$H)'-H87)E+"`G1&%T851R965/8FIE8W1?4VAA<F4G*2D@>PH@("`@
M("`@("1S:&%R92`]("1'3$]"04Q36R=K<F]N;VQI=&A?<VAA<F5S)UTM/F=E
M=%-H87)E*"1S:&%R92D["B`@("`@("`@:68@*&ES7V$H)'-H87)E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@
M('T*("`@('T*"B`@("`D;W=N97(@/2`D<VAA<F4M/F=E="@G;W=N97(G*3L*
M("`@("1U<V5R<')E9G,@/2`F4')E9G,Z.G-I;F=L971O;B@D1TQ/0D%,4ULG
M8V]N9B==6R=P<F5F<R==6R=D<FEV97(G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T07!P
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]W;F5R
M+"`G)RP@;G5L;"P@9F%L<V4I.PH@("`@)'5S97)P<F5F<RT^<F5T<FEE=F4H
M*3L*("`@(')E='5R;B`D=7-E<G!R969S+3YG971686QU92@D<')E9BD["GT*
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]S8W)I<'1S+RYH=&%C8V5S<P``
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S-C(W
M-3``,#(Q-S$Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$1E;GD@9G)O;2!A;&P*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]K<F]N;VQI=&@O<V-R:7!T<R]I;7!O<G1?:6-A;',N<&AP````````
M`````````````````````````````````````````````#`Q,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#0T`#$P-#$W,S8R-S4P`#`R,S,R-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C(2]U
M<W(O8FEN+W!H<`H\/W!H<`HO*BH*("H@5&AI<R!S8W)I<'0@:6UP;W)T<R!I
M0V%L96YD87(O=D-A;&5N9&%R(&1A=&$@:6YT;R!+<F]N;VQI=&@@8V%L96YD
M87)S+@H@*B!4:&4@9&%T82!I<R!R96%D(&9R;VT@<W1A;F1A<F0@:6YP=70L
M('1H92!C86QE;F1A<B!A;F0@=7-E<B!N86UE('!A<W-E9"!A<PH@*B!P87)A
M;65T97)S+@H@*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]S8W)I<'1S+VEM<&]R
M=%]I8V%L<RYP:'`L=B`Q+C,N,BXR(#(P,#8O,#$O,#$@,C$Z,CDZ,#0@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!
M551(7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PH*+R\@1&\@0TQ)(&-H96-K
M<R!A;F0@96YV:7)O;FUE;G0@<V5T=7`@9FER<W0N"G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+T-,22YP:'`G.PH*+R\@36%K92!S=7)E(&YO(&]N92!R=6YS('1H:7,@
M9G)O;2!T:&4@=V5B+@II9B`H(4AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH
M*2D@>PH@("`@97AI="@B375S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L
M:6YE7&XB*3L*?0H*+R\@3&]A9"!T:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K
M92!S=7)E('1H97)E)W,@;F\@=&EM92!L:6UI="P@:6YI="!S;VUE"B\O('9A
M<FEA8FQE<RP@971C+@HD8VQI(#T@)DAO<F1E7T-,23HZ<VEN9VQE=&]N*"D[
M"B1C;&DM/FEN:70H*3L*"B\O(%)E860@8V]M;6%N9"!L:6YE('!A<F%M971E
M<G,N"FEF("AC;W5N="@D87)G=BD@(3T@,RD@>PH@("`@)&-L:2T^;65S<V%G
M92@G5&]O(&UA;GD@;W(@=&]O(&9E=R!P87)A;65T97)S+B<L("=C;&DN97)R
M;W(G*3L*("`@('5S86=E*"D["GT*)&-A;"`]("1A<F=V6S%=.PHD=7-E<B`]
M("1A<F=V6S)=.PH*+R\@4F5A9"!S=&%N9&%R9"!I;G!U="X*)&EC86P@/2`D
M8VQI+3YR96%D4W1D:6XH*3L*:68@*&5M<'1Y*"1I8V%L*2D@>PH@("`@)&-L
M:2T^;65S<V%G92@G3F\@:6UP;W)T(&1A=&$@<')O=FED960N)RP@)V-L:2YE
M<G)O<B<I.PH@("`@=7-A9V4H*3L*?0H*+R\@4F5G:7-T<GDN"B1R96=I<W1R
M>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*"D["@HO+R!3970@=7-E<BX*)&%U
M=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==
M*3L*)&%U=&@M/G-E=$%U=&@H)'5S97(L(&%R<F%Y*"DI.PH*+R\@26UP;W)T
M(&1A=&$N"B1R97-U;'0@/2`D<F5G:7-T<GDM/F-A;&PH)V-A;&5N9&%R+VEM
M<&]R="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&EC86PL
M("=T97AT+W@M:6-A;&5N9&%R)RP@)&-A;"DI.PII9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D8VQI+3YF871A;"@D<F5S=6QT+3YT
M;U-T<FEN9R@I*3L*?0H*)&-L:2T^;65S<V%G92@G26UP;W)T960@<W5C8V5S
M<V9U;&QY("<@+B!C;W5N="@D<F5S=6QT*2`N("<@979E;G1S)RP@)V-L:2YS
M=6-C97-S)RD["@IF=6YC=&EO;B!U<V%G92@I"GL*("`@("1'3$]"04Q36R=C
M;&DG72T^=W)I=&5L;B@G57-A9V4Z(&EM<&]R=%]I8V%L<RYP:'`@8V%L96YD
M87(@=7-E<B<I.PH@("`@97AI=#L*?0H*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:W)O;F]L:71H+W-C<FEP=',O;6EG<F%T95]T;U]S<6Q?9')I=F5R+G!H<```
M```````````````````````````````````````P,3`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,S`T,@`Q,#0Q-S,V,C<U,``P,C4R,34`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R$O=7-R+VQO
M8V%L+V)I;B]P:'`*/#]P:'`*+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+W-C
M<FEP=',O;6EG<F%T95]T;U]S<6Q?9')I=F5R+G!H<"QV(#$N,2XQ,"XR(#(P
M,#8O,#$O,#$@,C$Z,CDZ,#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]G<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T
M<G5E*3L*0&1E9FEN92@G2U)/3D],251(7T)!4T4G+"!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($M23TY/3$E42%]"05-%("X@
M)R]L:6(O8F%S92YP:'`G.PH*+R\@4V5T('1H97-E(&%S(')E<75I<F5D+@HD
M<W%L<&%R86US(#T@)&-O;F9;)W-Q;"==.PH*+R\@0W)E871E(&$@8V%L96YD
M87(@8F%C:V5N9"!O8FIE8W0N"B1S<6QC86P@/2`F2W)O;F]L:71H7T1R:79E
M<CHZ9F%C=&]R>2@G<W%L)RP@)'-Q;'!A<F%M<RD["B1M8V%L(#T@)&MR;VYO
M;&ET:#L*"B\O(%)U;B!T:')O=6=H(&5V97)Y(&-A;&5N9&%R+@HD8V%L<R`]
M("1K<F]N;VQI=&A?<VAA<F5S+3YL:7-T06QL4VAA<F5S*"D["F9O<F5A8V@@
M*"1C86QS(&%S("1C86QI9"`]/B`D8V%L<VAA<F4I('L*("`@(&5C:&\@(D-O
M;G9E<G1I;F<@)&-A;&ED("XN+EQN(CL*"B`@("!I9B`H)&UC86PM/F=E=$-A
M;&5N9&%R*"D@(3T@)&-A;&ED*2!["B`@("`@("`@)&UC86PM/F-L;W-E*"D[
M"B`@("`@("`@)&UC86PM/F]P96XH)&-A;&ED*3L*("`@('T*("`@(&EF("@D
M<W%L8V%L+3YG971#86QE;F1A<B@I("$]("1C86QI9"D@>PH@("`@("`@("1S
M<6QC86PM/F-L;W-E*"D["B`@("`@("`@)'-Q;&-A;"T^;W!E;B@D8V%L:60I
M.PH@("`@?0H*("`@("\O($QI<W0@86QL(&5V96YT<RX*("`@("1E=F5N=',@
M/2`D;6-A;"T^;&ES=$5V96YT<R@I.PH@("`@96-H;R!C;W5N="@D979E;G1S
M*2`N(")<;EQN(CL*"B`@("!F;W)E86-H("@D979E;G1S(&%S("1E=F5N=$ED
M*2!["B`@("`@("`@)&5V96YT(#T@)&UC86PM/F=E=$5V96YT*"1E=F5N=$ED
M*3L*("`@("`@("`D;F5W979E;G0@/2`D<W%L8V%L+3YG971%=F5N="@I.PH*
M("`@("`@("!F;W)E86-H("@H87)R87DI)&5V96YT(&%S("1K97D@/3X@)'9A
M;'5E*2!["B`@("`@("`@("`@(&EF("@D:V5Y("$]("=E=F5N=$E$)RD@>PH@
M("`@("`@("`@("`@("`@)&YE=V5V96YT+3XD:V5Y(#T@)'9A;'5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:W)O;F]L:71H(#T@)'-Q
M;&-A;#L*("`@("`@("`D<W5C8V5S<R`]("1N97=E=F5N="T^<V%V92@I.PH@
M("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@('9A<E]D=6UP*"1S=6-C97-S*3L*("`@("`@("!]"B`@("`@
M("`@)&MR;VYO;&ET:"`]("1M8V%L.PH@("`@?0I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]S8W)I<'1S+W)E;6EN9&5R<RYP:'``````````````````````````
M````````````````````````````````,#$P,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#,T,C$`,3`T,3<S-C(W-3``,#(R-C(R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````",A+W5S<B]L;V-A;"]B
M:6XO<&AP("UQ"CP_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]S8W)I
M<'1S+W)E;6EN9&5R<RYP:'`L=B`Q+C$W+C$P+C0@,C`P-B\P,2\P,2`R,3HR
M.3HP-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*+R\@1FEN9"!T:&4@8F%S92!F:6QE('!A=&@@;V8@2&]R9&4N
M"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXO+BXG*3L*"B\O($9I;F0@=&AE(&)A<V4@9FEL92!P871H(&]F($MR;VYO
M;&ET:"X*0&1E9FEN92@G2U)/3D],251(7T)!4T4G+"!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXG*3L*"B\O($1O($-,22!C:&5C:W,@86YD(&5N=FER;VYM
M96YT('-E='5P(&9I<G-T+@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O
M;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#3$DN<&AP)SL*
M"B\O($UA:V4@<W5R92!N;R!O;F4@<G5N<R!T:&ES(&9R;VT@=&AE('=E8BX*
M:68@*"%(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@(&5X:70H
M(DUU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN95QN(BD["GT*"B\O
M($QO860@=&AE($-,22!E;G9I<F]N;65N="`M(&UA:V4@<W5R92!T:&5R92=S
M(&YO('1I;64@;&EM:70L(&EN:70*+R\@<V]M92!V87)I86)L97,L(&5T8RX*
M2&]R9&5?0TQ).CII;FET*"D["@HO+R!.;W<@;&]A9"!T:&4@4F5G:7-T<GD@
M86YD('-E='5P(&-O;F8L(&5T8RX*)')E9VES=')Y(#T@)E)E9VES=')Y.CIS
M:6YG;&5T;VXH2$]21$5?4T534TE/3E].3TY%*3L*)')E9VES=')Y+3YP=7-H
M07!P*"=K<F]N;VQI=&@G+"!F86QS92D["@HO+R!);F-L=61E(&YE961E9"!L
M:6)R87)I97,N"G)E<75I<F5?;VYC92`G1&%T92]#86QC+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O1&%T92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+U-C:&5D=6QE<BYP:'`G.PIR97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@
M+B`G+VQI8B]+<F]N;VQI=&@N<&AP)SL*<F5Q=6ER95]O;F-E($M23TY/3$E4
M2%]"05-%("X@)R]L:6(O4V-H961U;&5R+VMR;VYO;&ET:"YP:'`G.PH*+R\@
M0W)E871E(&$@<VAA<F4@:6YS=&%N8V4N(%1H:7,@;75S="!E>&ES="!I;B!T
M:&4@9VQO8F%L('-C;W!E(&9O<@HO+R!+<F]N;VQI=&@G<R!!4$D@8V%L;',@
M=&\@9G5N8W1I;VX@<')O<&5R;'DN"G)E<75I<F5?;VYC92`G2&]R9&4O4VAA
M<F4N<&AP)SL*)'-H87)E<R`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1R
M96=I<W1R>2T^9V5T07!P*"DI.PH*+R\@0W)E871E(&$@8V%L96YD87(@8F%C
M:V5N9"!O8FIE8W0N(%1H:7,@;75S="!E>&ES="!I;B!T:&4@9VQO8F%L"B\O
M('-C;W!E(&9O<B!+<F]N;VQI=&@G<R!!4$D@8V%L;',@=&\@9G5N8W1I;VX@
M<')O<&5R;'DN"B1K<F]N;VQI=&@@/2`F2W)O;F]L:71H7T1R:79E<CHZ9F%C
M=&]R>2@I.PH*+R\@1V5T(&%N(&EN<W1A;F-E(&]F('1H92!+<F]N;VQI=&@@
M<V-H961U;&5R<BX*)')E;6EN9&5R(#T@)DAO<F1E7U-C:&5D=6QE<CHZ=6YS
M97)I86QI>F4H)TAO<F1E7U-C:&5D=6QE<E]K<F]N;VQI=&@G*3L*"B\O(%-T
M87)T('1H92!D865M;VX@9V]I;F<N"B1R96UI;F1E<BT^<G5N*"D["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O
M;&]C86QE+P``````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S4R`#`Q-S8W,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O8F=?0D<O````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``,#(P-C,Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]B9U]"
M1R],0U]-15-304=%4R\`````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<U,``P,C(T,38`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N
M;VQI=&@O;&]C86QE+V)G7T)'+TQ#7TU%4U-!1T53+VMR;VYO;&ET:"YM;P``
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#8Q,C`Q`#$P-#$W,S8R-S4P`#`R-#<V,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#>$@25`````'<!```<
M````U`L``/<!``",%P```````&@?```.````:1\```@```!X'P``#````($?
M```+````CA\``"@```":'P``%0```,,?```=````V1\```X```#W'P``'0``
M``8@```(````)"```#(````M(```.````&`@``!4````F2```%$```#N(```
M-````$`A```%````=2$```D```![(0``#0```(4A```2````DR$```\```"F
M(0``#P```+8A```9````QB$```<```#@(0``#@```.@A```#````]R$```4`
M``#[(0``"@````$B```4````#"(```H````A(@``!0```"PB```*````,B(`
M``\````](@``!P```$TB```-````52(```H```!C(@``'P```&XB```1````
MCB(```P```"@(@``.0```*TB```"````YR(``"<```#J(@``+````!(C```J
M````/R,```H```!J(P``%0```'4C```I````BR,``!$```"U(P``%@```,<C
M```6````WB,```@```#U(P``!````/XC```)`````R0```,````-)````P``
M`!$D```(````%20```D````>)```(````"@D```(````220```H```!2)```
M#````%TD```&````:B0```<```!Q)```$````'DD```;````BB0``"L```"F
M)```!````-(D```>````UR0``!L```#V)```&P```!(E```S````+B4``"\`
M``!B)0``*0```)(E```2````O"4```,```#/)0```@```-,E```%````UB4`
M`!,```#<)0```P```/`E```&````]"4``!````#[)0``!@````PF```)````
M$R8```P````=)@``7````"HF```+````AR8``"\```"3)@``!P```,,F```/
M````RR8```<```#;)@``"````.,F```$````["8```<```#Q)@``%0```/DF
M```%````#R<```T````5)P``&P```",G```-````/R<```@```!-)P``!@``
M`%8G```(````72<```4```!F)P``$P```&PG```0````@"<``!````"1)P``
M#P```*(G```+````LB<```\```"^)P``#````,XG```/````VR<```\```#K
M)P``'@```/LG```A````&B@``"`````\*````P```%TH```3````82@``!0`
M``!U*```#````(HH```)````ER@``!L```"A*```!P```+TH```$````Q2@`
M``8```#**````@```-$H```&````U"@```D```#;*```!````.4H```4````
MZB@```8```#_*```$0````8I```>````&"D```0````W*0``!````#PI```,
M````02D```H```!.*0``!0```%DI```'````7RD``"````!G*0``(````(@I
M```F````J2D``"D```#0*0``"@```/HI```/````!2H``!8````5*@``$@``
M`"PJ```0````/RH``!<```!0*@``!@```&@J```,````;RH```P```!\*@``
M#0```(DJ```H````ERH``"L```#`*@``"````.PJ```(````]2H```H```#^
M*@``"0````DK```>````$RL``!`````R*P``&@```$,K```(````7BL```8`
M``!G*P``!P```&XK```"````=BL``"4```!Y*P``!````)\K```8````I"L`
M``\```"]*P``!P```,TK```'````U2L```H```#=*P``!P```.@K```&````
M\"L```D```#W*P``"0````$L```"````"RP```T````.+```!@```!PL```%
M````(RP```<````I+```%0```#$L```*````1RP```0```!2+```!P```%<L
M```%````7RP```D```!E+```%P```&\L```*````ARP```@```"2+```"0``
M`)LL```E````I2P``#,```#++```,P```/\L```X````,RT```L```!L+0``
M+0```'@M```Q````IBT``"P```#8+0``&@````4N```)````("X```0````J
M+@``!0```"\N```"````-2X```<````X+@``#````$`N```1````32X``!$`
M``!?+@``"0```'$N```(````>RX```D```"$+@``"@```(XN```5````F2X`
M``4```"O+@``!P```+4N```H````O2X``!X```#F+@``&@````4O```%````
M("\``"`````F+P``#````$<O```R````5"\```4```"'+P``!````(TO```R
M````DB\```L```#%+P``#P```-$O```3````X2\``!,```#U+P``#P````DP
M```,````&3````X````F,```#0```#4P```-````0S```!````!1,```*@``
M`&(P```&````C3````\```"4,```!````*0P```)````J3````,```"S,```
M`@```+<P```(````NC````L```##,```"@```,\P```5````VC```!(```#P
M,```#P````,Q```4````$S$``%@````H,0``(0```($Q```:````HS$``!<`
M``"^,0``&@```-8Q```9````\3$``!<````+,@``'0```",R```;````03(`
M`!D```!=,@``'P```'<R``!7````ES(```0```#O,@``.P```/0R```?````
M,#,``"@```!0,P``!````'DS```7````?C,```H```"6,P``"````*$S```*
M````JC,```(```"U,P``!@```+@S```'````OS,```8```#',P``!0```,XS
M```)````U#,```(```#>,P``)````.$S```C````!C0``"$````J-```2@``
M`$PT```X````ES0``$@```#0-```20```!DU```P````8S4``&D```"4-0``
M/0```/XU``!E````/#8``$T```"B-@``+@```/`V```P````'S<``!\```!0
M-P``+P```'`W```L````H#<``!<```#--P``)0```.4W```R````"S@``#X`
M```^.```)0```'TX```A````HS@``#````#%.```'````/8X```(````$SD`
M``T````<.0``!0```"HY```%````,#D```@````V.0```@```#\Y```'````
M0CD```0```!*.0```P```$\Y```9````4SD``!0```!M.0``)````((Y```B
M````ISD``"4```#*.0``)@```/`Y```)````%SH```<````A.@``!@```"DZ
M```)````,#H``!,````Z.@``#@```$XZ```(````73H```D```!F.@``"@``
M`'`Z```4````>SH```@```"0.@``/P```)DZ```'````V3H```(```#A.@``
M"0```.0Z```$````[CH```<```#S.@``!P```/LZ```&`````SL``!0````*
M.P``#0```!\[```+````+3L``"\````Y.P``2````&D[``!,````LCL```P`
M``#_.P``"@````P\```)````%SP```(````A/```!@```"0\```4````*SP`
M``,```!`/```*````$0\``!"````;3P``#````"P/```)P```.$\```I````
M"3T``"8````S/0``)0```%H]```H````@#T``!````"I/0``<P```+H]```?
M````+CX``!0```!./@``#P```&,^```#````<SX```8```!W/@``!````'X^
M```$````@SX```0```"(/@``"````(T^```0````ECX``!,```"G/@``!P``
M`+L^```%````PSX```0```#)/@``"P```,X^```%````VCX```<```#@/@``
M60$``.@^```/````0D````<```!20```"````%I````.````8T```"4```!R
M0```'````)A````?````M4````P```#50```&@```.)````'````_4```#4`
M```%00``-0```#M!``!2````<4$``$\```#$00``-P```!1"```%````3$(`
M``X```!20@``%@```&%"```6````>$(``!,```"/0@``%@```*-"```F````
MND(```4```#A0@``#@```.="```'````]D(```8```#^0@``#@````5#```D
M````%$,```T````Y0P``"0```$=#```,````44,```P```!>0P``"@```&M#
M```4````=D,```X```"+0P``(P```)I#```7````OD,```T```#60P``-P``
M`.1#```!````'$0``"T````>1```+0```$Q$```O````>D0```@```"J1```
M&````+-$```R````S$0```\```#_1```&P````]%```E````*T4```H```!1
M10``"0```%Q%```'````9D4```,```!N10```P```')%```(````=D4```D`
M``!_10``)@```(E%```)````L$4```\```"Z10``$````,I%```'````VT4`
M``@```#C10``$P```.Q%```Y`````$8``"D````Z1@``!P```&1&```E````
M;$8``"4```"21@``)P```+A&```E````X$8``#H````&1P``-0```$%'```3
M````=T<```8```"+1P```@```))'```)````E4<``!@```"?1P```P```+A'
M```(````O$<``!L```#%1P``!@```.%'```)````Z$<```X```#R1P``50``
M``%(```(````5T@``"X```!@2```!@```(](```-````ED@```X```"D2```
M#P```+-(```(````PT@```X```#,2```+0```-M(```%````"4D```L````/
M20``(@```!M)```0````/DD```L```!/20``!P```%M)```)````8TD```8`
M``!M20``$P```'1)```/````B$D``!````"820``#@```*E)```-````N$D`
M`!0```#&20``#````-M)```3````Z$D``!,```#\20``*0```!!*```R````
M.DH``"0```!M2@``!````))*```5````ETH``!8```"M2@``#````,1*```+
M````T4H``"8```#=2@``!@````1+```%````"TL```8````12P```@```!A+
M```%````&TL```L````A2P``!````"U+```7````,DL```4```!*2P``#@``
M`%!+```A````7TL```4```"!2P``!@```(=+```-````CDL```\```"<2P``
M!0```*Q+```&````LDL``"\```"Y2P``+P```.E+```\````&4P``"8```!6
M3```"@```'U,```-````B$P``!<```"63```%````*Y,```3````PTP``!\`
M``#73```"0```/=,```2`````4T``!$````430``$@```"9-```J````.4T`
M`"T```!D30``#````))-```$````GTT```X```"D30``$````+--```F````
MQ$T```H```#K30``(0```/9-```%````&$X```0````>3@``!0```"-.```"
M````*4X``"T````L3@``!````%I.```E````7TX``!````"%3@``!0```)9.
M```'````G$X```X```"D3@``!0```+-.```%````N4X```@```"_3@``"0``
M`,A.```"````TDX``!$```#53@``"@```.=.```%````\DX```<```#X3@``
M&0````!/```*````&D\```,````E3P``!0```"E/```&````+T\```P````V
M3P``(P```$-/```-````9T\```L```!U3P``$````(%/```A````DD\``"8`
M``"T3P``)@```-M/```K`````E```!`````N4```*P```#]0```O````:U``
M`#4```";4```&0```-%0```.````ZU````0```#Z4```!P```/]0```"````
M!U$```4````*40``#P```!!1```0````(%$``!0````Q40``"0```$91```&
M````4%$```<```!740``"````%]1```2````:%$```8```![40``#````()1
M```R````CU$``!T```#"40``&0```.!1```'````^E$``!X````"4@``#```
M`"%2```W````+E(```H```!F4@``!@```'%2``!"````>%(```\```"[4@``
M$````,M2```=````W%(``!4```#Z4@``%0```!!3```2````)E,``!`````Y
M4P``$0```$I3```0````7%,``!,```!M4P``*0```(%3```(````JU,``!<`
M``"T4P``!````,Q3```)````T5,```,```#;4P```@```-]3```&````XE,`
M`!````#I4P``#@```/I3```:````"50``"`````D5```#P```$54```=````
M550``&(```!S5```'````-94```9````\U0``!H````-50``&````"A5```K
M````054``!@```!M50``,````(95```>````MU4``",```#650``)````/I5
M``!H````'U8```D```"(5@``1@```))6```E````V58``#X```#_5@``!@``
M`#Y7```>````15<```P```!D5P``"@```'%7```+````?%<```(```"(5P``
M!P```(M7```%````DU<```8```"95P``!@```*!7```*````IU<```(```"R
M5P``)P```+57```<````W5<``!T```#Z5P``1P```!A8```K````8%@``$D`
M``",6```5P```-98```O````+ED``%\```!>60``-0```+Y9``!A````]%D`
M`#\```!66@``)P```)9:```J````OEH``!@```#I6@``'`````);```;````
M'UL``!<````[6P``*@```%-;```Q````?EL``$4```"P6P``(````/9;```D
M````%UP``#<````\7```(````'1<```)````E5P``!4```"?7```"````+5<
M```$````OEP```0```##7````@```,A<```'````RUP```,```#37````P``
M`-=<```>````VUP``!L```#Z7```*@```!9=```K````05T``"4```!M70``
M*````)-=```*````O%T```H```#'70``!P```-)=```*````VET``!\```#E
M70``%P````5>```#````'5X```0````A7@``!0```"9>```8````+%X```@`
M``!%7@``/0```$Y>```(````C%X```(```"57@``!0```)A>```'````GEX`
M``H```"F7@``"@```+%>```(````O%X``!H```#%7@``$````.!>```/````
M\5X``#0````!7P``+P```#9?```N````9E\```P```"57P``#@```*)?```/
M````L5\```(```#!7P``!P```,1?```9````S%\```(```#F7P``(0```.E?
M```Z````"V```"8```!&8```'@```&U@```R````C&```"L```"_8```*@``
M`.M@```M````%F$``!$```!$80``90```%9A```K````O&$```\```#H80``
M$````/AA```#````"6(```@````-8@```P```!9B```$````&F(```(````?
M8@``"````")B```.````*V(``!4````Z8@``!P```%!B```%````6&(```<`
M``!>8@``"P```&9B```'````<F(```8```!Z8@```0````L!````````CP``
M`,H``````````````.L````B`0``)0$``#8!`````````````/``````````
MJP```%8```#)````50```%\!``!5`0``[0```#T`````````*@```($```!+
M````.0`````````L`0``&0$``-D`````````20```#\```!0`0``\P```%D!
M``!$`0````````8`````````OP```&8```#W````S`````````!(````8@``
M`(P```!B`0``HP````````#B````2@```!8!``````````````````!R`0``
MLP```#H!```[````B@``````````````)@```"@!``#\````YP````X`````
M````$@``````````````(@```````````````````$(```"J````.````-8`
M````````?@```)L```!&````'@``````````````K0```.X````!`0``W```
M`*`````D````/0$``#P!```M````B0```'\```"W````````````````````
M#`$````````Y`0``I````/H`````````(0```%L```"+````:0$``)8````K
M`0````````````!+`0```````-0`````````%0$``)X`````````]```````
M``!1````*@$```````"F`````@``````````````$P$``%X!````````"```
M`!0```"&````P````$P!``#>````_P```'<!````````&P$```````!N`0``
M*0````0```!@`0``^````!<!`````````````'@```!Q````````````````
M````0`$``/8````0`0``^P```*X```"8```````````````O````V````%P`
M`````````@$``,8```"P````````````````````KP```&\```"3````9P$`
M`&8!``"$````(0$``&<```!0`````````$X```"H````:P```+$`````````
M`````!$!```,````20$`````````````6`$```D!``"7````@P```"0!``"E
M````_0``````````````&@$```````#Y````'P$``-\```".````?0```"<`
M````````"@$``"``````````40$``"<!``!Q`0`````````````H````?```
M`#4!``!7`0````````````#C````6P$``(4`````````5P```%(!``!T````
M:@```%8!```8````#P$``'8`````````D@```!H```""````/@$``%0```"'
M````]0```+P`````````$0```'4```!(`0``O@````<````L`````````#H`
M```\````U0```,T`````````,0$``#0````@`0``&P````````"Z````S@``
M`.8``````0``M@````````!?````SP```,0```!D`0``'``````````Q````
M90```$$!`````````````!T`````````!0$````````O`0``.`$```\````9
M````70```+D```!J`0``!P$``,@`````````7@```&P```!,````T````)D`
M````````!`$``&T```#2`````````'8!``!&`0```````%D`````````8P$`
M``````!$````:````+@```!4`0``T0```%,!````````UP````````!O`0``
M`````#\!``!!````RP````H```"L````7`$``)4```"```````````T```"?
M````B````$<```"4`````````'`!``!8`````````&$`````````````````
M````````'P```&0`````````#0$````````V``````````D````7````-P$`
M``````````````````````!W`````````'4!``!-````:0```!X!```#`0``
M-`$``.@```!'`0``4P`````````.`0``+@```&P!``"B````D0```!@!```4
M`0``W0```!8`````````$P```!4```#3`````````+(```#!````+0$`````
M````````80$``#X``````````````)T```!S`0``X0```*D```!Y````````
M`&4!``"T````>@```",```#E``````````````#D````6@```-H```#Q````
M30$``+4```"]````-P```)H````I`0``\@`````````<`0``_@```$,!````
M````10$```````!T`0``-0```)P```![````4@```$````!:`0``<@```#,`
M``#L````;@````````!#````Z@```-L`````````.P$``&T!``"A````````
M`.D````S`0``!0`````````(`0```````$4```!.`0```````&@!```R````
M`````"L```##`````````,4```!/````"P```"X!``!P````)@$``&,````2
M`0``0@$``',````0`````P```!T!``#@````D````$\!```P`0``:P$``$H!
M``"G````70$``,(```#O````(P$```8!```P````NP```,<`````````)0``
M`&``````````,@$``(T`````("@E<R!D87ES(&%G;RD`("AT;V1A>2D`("AY
M97-T97)D87DI`"5S("T@3F]T:6-E`"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&9I
M;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E<75I<F5D`"H@4&QE
M87-E('-E;&5C="!A9&1R97-S*&5S*2`J`#(T(&AO=7)S`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!32]030!!9&0@179E;G0`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI
M<W-I;VX`061D(&$@;F5W(&5V96YT`$%D9"!A(&YE=R!U<V5R.@!!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061M:6YI<W1R871I;VX`061S
M`$%L87)M`$%L87)M($1A=&4`06QA<FT@4W!A;B`H;6EN=71E<RD`06QA<FT@
M5&EM90!!;&EA<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9&%Y
M`$%L;"!D87D@979E;G0`06QL(&5V96YT<P!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!
M<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<S\`070`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1R:6)U=&5S`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=F%I;&%B
M;&4@9FEE;&1S.@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O
M<R!U<V5R;F%M92X`0FER=&AD87D`0F]L9`!";V]K;6%R:W,`0TU3`$-20P!#
M86QE;F1A<@!#86QE;F1A<G,`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%T96=O<GD`0V5L;"!0:&]N90!#;VQO<B!0:6-K97(`0V]M:6-S
M`$-O;7!A;GD`0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&1E;&5T:6]N(&]F
M(&5V96YT<S\`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!#;W!Y`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@
M9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#<F5A=&4@82!.97<@179E;G0`0W5T`$1$`$1A
M:6QY`$1A:6QY.B!296-U<G,@979E<GD`1&%Y`$1A>2AS*0!$969A=6QT($ED
M96YT:71Y`$1E;&5T90!$96QE=&4@)7,`1&5L971E($5V96YT`$1E;&5T92!T
M:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L
M;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@86QL(&]C8W5R96YC97,_`$1E<V-R
M:7!T:6]N`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1I<W!L87D`1&ES<&QA>2!/<'1I;VYS`$1U93H@)7,`1'5R
M871I;VX`161I=`!%9&ET("5S`$5D:70@4F5M;W1E($-A;&5N9&%R<P!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;7!T>2!R97-U;'0N`$5N9"!$871E`$5N9"!/;@!%;F0@5&EM90!%<G)O<@!%
M=F5N="!F<F]M("5S('1O("5S`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@
M<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L
M9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AP;W)T($-A
M;&5N9&%R`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@4TU"('-E<G9E<BX`1F%X`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#
M;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YD`$9O<G5M<P!&<@!&
M<FED87D`1G5L;"!.86UE`$=A;64`1W)O=7`@061M:6YI<W1R871I;VX`1W)O
M=7!S`$=U97-T(%!E<FUI<W-I;VYS`$A45%`@075T:&5N=&EC871I;VX@;F]T
M(&9O=6YD+@!(96QP`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R
M9&4`2&]U<BAS*0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S(&YO="!W:71H
M:6X@86QL;W=E9"!#2412(&)L;V-K+@!)8V]N<R!/;FQY`$EC;VYS('=I=&@@
M=&5X=`!);7!O<G0O17AP;W)T($-A;&5N9&%R`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN=F%L:60@9&%T82!S=6)M:71T960N`$ET
M86QI8P!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$ME>7=O
M<F1S`$QA;F=U86=E`$QA<W0@36]N=&@`3&%S="!W965K`$QI;6ET('1H92!T
M:6UE('-P86X@=&\@97AP;W)T.@!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$U-
M`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`36%I;`!-
M86YA9V4@<F5M;W1E(&-A;&5N9&%R<RX`36%T8VAI;F<@9FEE;&1S`$UE971I
M;F<`365M8F5R<P!-96YU(&UO9&4Z`$UE<W-A9V4`365T:&]D`$UI;64@5'EP
M90!-:6YU=&4H<RD`36\`36]D:69I960@1&%T90!-;VYD87D`36]N=&@`36]N
M=&AL>0!-;VYT:&QY.B!296-U<G,@979E<GD`37D@06-C;W5N=`!.86UE`$YE
M='=O<FL`3F5V97(`3F5W($5V96YT`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI
M`$YE>'0@36]N=&@`3F5X="!D87D`3F5X="!W965K`$YO(&-A;&5N9&%R<R!A
M<F4@879A:6QA8FQE('1O(&=U97-T<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+@!.;R!E;F0@9&%T90!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME
M<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F]N90!.;W1E<P!/2P!/<'1I;VYS`$]R9&5R960@
M3&ES=`!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!02%`@
M4VAE;&P`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A='1E<FX`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M86YE;G1L>2!D96QE=&4@=&AI
M<R!E=F5N=#\`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&AO;F4`4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4')E=FEO=7,@9&%Y`%!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN`%)A=&EO`%)E860`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C=7(@56YT:6P`4F5C=7)R96YC92!$
M871A`%)E8W5R<F5N8V4@16YD($1A=&4`4F5C=7)R96YC92!);G1E<G9A;`!2
M96-U<G)E;F-E(%1Y<&4`4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E
M8W5R<R!W965K;'D`4F5C=7)S('EE87)L>0!296UO=&4@0V%L96YD87)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E('5S97(Z("5S`%)O;&4`4U%,(%-H96QL`%-32`!380!3871U
M<F1A>0!3879E($%S($YE=P!3879E($5V96YT`%-E;&5C="!A(&=R;W5P('1O
M(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C
M="!A('5S97(@=&\@861D`%-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@
M:&]W('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E
M(&1E9F%U;'0@=FEE=RX`4V5L96-T('1H92!C86QE;F1A<B!T;R!I;7!O<G0@
M=&\Z`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T
M92!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T
M:&4@9FER<W0@=V5E:V1A>3H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1H92!T:6UE('-P86X@=&\@<VAO=SH`4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R(&1I<W!L87D@;W!T:6]N<RX`4VAO=P!3:&]W(&1E;&5T92P@86QA<FTL
M(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/P!3:&]W
M(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_`%-H;W<@;VYL>2!E=F5N=',@
M=&AA="!H879E(&%N(&%L87)M('-E=#\`4VEZ90!3<&5C:6%L($-H87)A8W1E
M<B!);G!U=`!3=&%R="!$871E`%-T87)T($]N`%-T87)T(%1I;64`4W4`4W5B
M;6ET`%-U8V-E<W,`4W5N9&%Y`%1A<VMS`%1E>'0@3VYL>0!4:`!4:&4@8V%L
M96YD87(@(B5S(B!C86YN;W0@8F4@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES
M(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!E
M;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA
M<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H
M87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L
M;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY
M('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+@!4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O
M<G0N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N
M)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AU<G-D87D`5&EM92!4<F%C:VEN9P!4:71L
M90!4;V1A>0!4;VUO<G)O=P!4=0!4=65S9&%Y`%1Y<&4`55),`%5N86)L92!T
M;R!D96QE=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`E<RX`56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N=`!5;F1E<FQI;F4`56YF:6QE9`!5<&1A=&4`57!D871E("5S`%5S
M97(@061M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`57-E<FYA;64`57-E
M<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`5F%C871I
M;VX`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N`%=A<FYI;F<`5V4`5V5D;F5S9&%Y`%=E
M96L`5V5E:R`E9`!7965K*',I`%=E96ML>0!7965K;'DZ(%)E8W5R<R!E=F5R
M>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@=&EM92!S:&]U
M;&0@9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@
M;&%T97(@979E;G1S/P!7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V
M:65W<R!S=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_
M`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=O<FL@5V5E:P!960!996%R;'D`
M665A<FQY.B!296-U<G,@979E<GD`665S`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I
M;VX@=&\@861D(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L96YD87(N`%EO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T92!T:&ES(&5V96YT
M+@!9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BX`66]U
M(&UU<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=7(@26YF;W)M871I;VX`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%ML:6YE("5S(&]F("5S70!D
M87D`9&%Y*',I`&1A>7,`9FEL90!F<F]M`&UO;G1H*',I`&]N('1H92!S86UE
M(&1A=&4`;VX@=&AE('-A;64@=V5E:V1A>0!U;FYA;65D`'9#87)D`'=E96L`
M=V5E:RAS*2!O;CH`=V5E:W,`>65A<BAS*0!0<F]J96-T+4ED+59E<G-I;VXZ
M($MR;VYO;&ET:"`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTQ,2TQ.2`R,#HT
M-"TP-3`P"DQA<W0M5')A;G-L871O<CH@36ER;W-L878@4&5N9&5V(#QM:7)O
M0&-Y8F5R<VAA9&4N=7,^"DQA;F=U86=E+51E86TZ($)'(&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=`H`("@E<R#D[>@@[>#GX.0I`"`HY.WE\2D`("CB]^7PX"D`
M)7,@+2#'X.'EZ^7FZN``)7,@SN'QZ_/FXN#YZ"#N[^7PX/;HZ"`M(,_N\N+Z
M\.;DY>WHY0`E<R#3\>ONXNC_(._N(-'O[O#@Y_/LY>WHY?+N`"5S(/3@Z>L@
MX>7XY2#H[._N\/+H\.#M(//Q[^7X[>X`)7,@[>7NX?7NY.CL`"H@S.[K_R#H
MY^'E\.7RY2#@Y/#E\2CH*2`J`#(T(/?@\>``Q^`@Y.`@ZO#H[_+H\.#RY2#O
MZ/'L[B#E(.WE[N'U[N3H["#O\^'KZ/?E[2!01U`@ZNO^]RX`Q^`@Y.`@[_#N
MXN7PZ/+E(._NY._H\>#M[B#OZ/'L[B#E(.WE[N'U[N3H["!01U`@ZNO^]RX`
MQ^`@Y.`@Y.7J\.CO\NCPX/+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH
M]^7M(.KK_O<L(.OH]^7M(.KK_O<@Z"#JZ_[W[N+@(/3PX.?@+@#'X"#DX"#O
M[N3OZ/CE\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@ZNO^]RP@
MZ^CWY>T@ZNO^]R#H(.KK_O?NXN`@]/#@Y^`N`,?@(.3@(.KPZ._RZ/#@\N4@
M[^CQ[.X@Y2#MY>[A]>[DZ.P@[_/AZ^CWY>T@4TU)344@ZNO^]RX`04TO4$T`
MQ.[AX.+H(/'ZX>CRZ.4`Q.[AX.+_[>4@[>`@[>[BX"#C\//OX`#$[N'@XO_M
MY2#MX"#M[N+H(._PX.+@`,3NX>#BZ"#M[N+N(/'ZX>CRZ.4`Q.[AX.+H(.WN
MXB#O[O+PY>'H\N7K.@#$[N'@XO_MY?+N(.W@(._N\O#EX>CRY>OH(.4@Y^#A
M\.#MY>WN+@#`Y/#E\0#`Y.SH[>CQ\O#H\.#MY0#$[N'@XNKH`,#KX/#LX`#$
MX/+@(.?@(.#KX/#LX`#/\.[D^NOFZ/+EZ^WN\?(@[>`@X.O@\.S@\N`@*.SH
M[?/RZ"D`U^#Q(.?@(.#KX/#LX`#/\>7BY.[MZ.P`PO'H]^KH(./P\^_H`,+Q
MZ/?JZ"#O\.#BX`#6Y>OH__(@Y.7M`-'ZX>CRZ/\@Y^`@]N7KZ/\@Y.7M`,+Q
MZ/?JZ"#Q^N'H\NC_`,+ZXN7DY>W@\N`@\?+NZ>WN\?(@[>4@Y2#D[N_S\?+H
M[.`N`-#@Y^SE\"#MX"#@\/7HXNWH_R#TX.GK`,CLY2#MX"#@\/7HXN``Q.`@
M\>4@Z/'JX"#KZ"#O[O+B^O#FY.7MZ.4@[_#EY.@@[N'QZ_/FXN#YZ/+E(.[O
MY?#@]NCH/P#B`,/PY?CJX"#O\.@@Z.?R\.CBX.WE(.W@(.WE\?KYY?'RXO/B
MX/G@(./P\^_@+@##\.7XZN`@[_#H(.CG\O#HXN#MY2#MY2#MY?'Z^>7Q\N+S
MXN#YZ"#O\.#BX"X`P_#E^.K@(._PZ"#PY>3@ZO+H\.#MY2#MX"#MY?'Z^>7Q
M\N+SXN#YZ"#O\.#BX"X`P/+PZ.'S\N@`P_#E^.K@(._PZ"#HY.7M\NCTZ.K@
M]NC_`,CDY>WRZ/3HZN#VZ/_RX"#AY?CE(.[R]>+Z\.OE[>`@[O(@4D%$2553
M(/'Z\.+Z\.`N`,W@Z^CW[>@@[^[KY?+@.@#-Y>+@Z^CD[>`@:V5R8F5R;W,@
M(._@\.[KX"X`S>7BX.OHY.WN(&ME<F)E<F]S(._N\O#EX>CRY>OQZNX@Z.SE
M+@#0[N;DY>T@Y.7M`-/DY>'EZ^7MZ`#.\NSE\NKH`$--4P!#4D,`RN#KY>WD
MX/``RN#KY>WDX/#H`,/PY?CJX"#O\.@@\>+Z\.?BX.WE(/$@[.7IZR#Q^O#B
M^O`Z("5S`,K@\N7C[O#H_P#,[N'HZ^7M(/+EZ^7T[NT`R.?AZ/#@[>4@[>`@
M]N+_\@#*[NSHZO'H`,KN[._@[>C_`,_N\N+Z\.3E\N4@[^#P[NO@\N``Q.`@
M\>4@Z.?H\>KBX"#KZ"#O[O+B^O#FY.7MZ.4@[_#H(.CG\O#HXN#MY?+N(.W@
M(/'ZX>CRZ/\_`,3N\?+Z[^`@Y.X@[_/AZ^CW[>C_(/'Z\.+Z\"#AY?CE(.[R
MZN#GX.TN`,KN[^CPX.D`P_#E^.K@(._PZ"!01U`@ZO#H[_+H\.#MY?+N(.W@
M(._H\>SN+@##\.7XZN`@[_#H(%!'4"#O[N3OZ/'BX.WE\NX@[>`@[^CQ[.XN
M`,/PY?CJX"#O\.@@Y.7J\.CO\NCPX.WE\NX@[>`@4$=0(.3@[>WH+@#-Y>KN
M\.7J\N7M(&5M86EL(.#D\.7Q(.W@(._NZ_/WX/+EZ_\N`,/PY?CJX"#O\.@@
M[^[K\_?@XN#MY?+N(.W@(._SX>OH]^WH_R#JZ_[W(.[R(.KK_O<M\?KPXOKP
MX"X`S>7B^N?L[N;M[O'R(.3@(/'E(.[RXN[PZ"#.X?'K\^;BX/GH7^?@Y.#W
MZ"#L[N3SZR`E<R``T?KGY.#I(.WNXNX@\?KAZ/+HY0#HY_#EYN@`Q,0`Q>;E
MY.WEXNWN`,3MY>+M[CH@[^[B\N#P_R#QY2#B\>7JZ`#$Y>T`Q.7M*.3MZ"D`
MR.3E[?+H]^WN\?(@[^X@[^[D\.#GX>CPX.WE`,CG\O#HZ0#(Y_+PZ.D@)7,`
MR.?R\.CI(/'ZX>CRZ.4`R.?R\.CI(/'@[.X@\N7J\_GN\NX@\?KAZ/+HY2P@
M\N[BX"#H(.+QZ/?JZ"#A^N3E^>@@[^[_XO_BX.WH_RP@Z.OH(.+QZ/?JZ"#O
M[O_B_^+@[>C_/P#.[^CQX.WHY0#$Y?+@Z>OH\N4@X?_UX"#PY>/H\?+PZ/#@
M[>@@Y^`@X.3LZ.WH\?+PX/+N\.`N`,_NZN#FZ`#$Z/'OZ^7I(,[O]NCH`,?@
MY/KKYN7MZ.4Z("5S`,_P[N3ZZ^;H\N7K[>[Q\@#0Y>3@ZO;H_P#0Y>3@ZO;H
M_R#MX"`E<P#0Y>3@ZO;H_R#MX"#N\N3@Z^7WY>WH("CMY>ONZN#K[>@I(.K@
MZ^7MY.#PZ"X`S^CQ[.X`Q6UA:6P@X.3PY?$`16UA:6P@X.3PY?'H\N4@\O#_
MX>+@(.3@(/'ZXN_@Y.#R+@#/\.#GY>T@\.7G\^ORX/(N`,KPX.GMX"#DX/+@
M`,KPX.D@[>``RO#@Y>T@]^#Q`,/PY?CJX`#1^N'H\NCE(.[R("5S(.3N("5S
M`,+QY>KH(#$U(.SH[?/RZ`#"\>7JZ"`S,"#QY>KS[>3H`,+QY>KH(#4@[.CM
M\_+H`,+Q_^KN(.ONX^+@[>4`S>`@XO'EZN@@[^[K[N+H[2#WX/$`PO'_ZN`@
M[.CM\_+@`,_PZ.SE\.WH(/'R[NGM[O'RZ#H`Q>KQ[^[P\B#MX"#*X.OE[>3@
M\`#-Y>+ZY^SNYNWN\?(@Y.`@\>4@Y^#PY>3_\B#O\.7TY?#E[?;HZ/+E+@#-
MY>+ZY^SNYNWN\?(@Y.`@\>4@[O'Z^>7Q\N+H(.+P^N?JX"#Q($Q$05`@\?KP
MXOKP+@##\.7XZN`@[_#H(/'B^O#GXN#MY2#Q^O$@4TU"(/'Z\.+Z\"X`U.#J
M\0#!\.[I(/3@Z>ONXN4Z("5S(/3@Z>L`P?#NZ2#TX.GK[N+E.B`E<R#TX.GK
MX`#4X.GK(.SE[>#FY?``R.SE(.W@(/3@Z>L`R.?O\.#YX.WE\NX@[>`@].#I
MZ^[BY2#MY2#QY2#O[N3D^O#FX"X`U.CK\OKP`-+Z\/'H`-3N\//LZ`#/Z@#/
MY?+ZZ@#([.4@[>`@].#IZP#(X_#@`,#D[.CMZ/'R\.CPX.WE(.W@(./P\^_H
M`,/P\^_H`,_PX.+@(.?@(./N\?+H`$A45%`@Z.3E[?+H].CJX/;H_R#MY2#E
M(.W@[.7PY>W@+@#/[NSN^0#-X/?@Z^X`Q.[LX/CE[2#@Y/#E\0#$[NS@^.7M
M(/+EZ^7T[NT`2&]R9&4`U^#Q*.`I`,/PY?CJX"#O\.@@\?KGY.#BX.WE(.W@
M($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S`,/PY?CJX"#O\.@@Z.?R\.CBX.WE
M(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S`,/PY?CJX"#O[O#@Y.@@ZN+N
M\N`@[_#H(/'ZY^3@XN#MY2#MX"!)34%0(._N^>7M\>K@(.KS\NC_.B`E<P!)
M4"#@Y/#E\>`@[>4@Y2#B(._NY^+NZ^7MZ/\@0TE$4B#AZ^[J+@#1X.SN(.CJ
M[NWH`,CJ[NWH(/$@\N7J\?(`R.SO[O#R+\7J\>_N\/(@RN#KY>WDX/``R.SO
M[O#RZ/#@[>X@[^[KY3H@)7,`R.SO[O#RZ/#@[>@@[^[KY?+@.@#(Y^_PX/+E
M[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N`,W@ZNON[>7MZ`#O^NOM[B#O[N3P
MX.+M_^+@[>4`Z__B[B#O[N3PX.+M_^+@[>4`Y/_Q[>X@[^[D\.#B[?_BX.WE
M`$ME<F)E<F]S(/'Z\.+Z\.`@[O+UXOKPZ^@@Z.3E[?+H].CJX/;H__+@+@#*
MZ_[WX"#BY??E(/'Z^>7Q\N+SXN`@XB#O\^'KZ/?MZ/\@ZNO^]_'Z\.+Z\"X`
MRNO^]^[BZ"#D\^SH`,7GZ.H`S_#EY.CXY>T@[.7QY?8`S_#EY.CX[>`@\>7D
M[.CVX`#.X_#@[>CWZ"#O\.[D^NOFZ/+EZ^WN\?+RX"#GX"#EZO'O[O#R.@#/
M[NSN^2#RY>SH`-'OZ/'ZZN`@\2#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M+@#,
M__'R[@#"]>[D`,CG]>[D`,S,`$U3+51.148@[_#HZO#E[^7MZ/_R(/3@Z>L@
M[>4@\?KD^O#FX/CE(.3@[>WH+@#/[OG@`-/O\.#BZ__BX.WE(.W@(.WEZ^[J
MX.OMZ/+E(.K@Z^7MY.#PZ"X`T?KB[^#DX/GH(._NZ^7RX`#1\.7YX`#7Z^7M
M[N+E`,+HY"#MX"#LY>W^\NXZ`,_H\>SN`,SE\N[D`$UI;64@\NCO`,SH[?/R
MX"CH*0#/[0#$X/+@(.W@(._P[NSE[?_MY0#/[NWEY.7K[>CJ`,SE\>7V`,SE
M\>7W[>X`S.7QY??M[CH@[^[B\N#P_R#QY2#B\>7JZ`#,[O_RX"#/[OG@`,CL
MY0#,\.7FX`#-Z.KNX^``S>[B[B#Q^N'H\NCE`,WNXNX@[^[R\.7AZ/+EZ_'J
M[B#H[.4@*.[O]NCN[>#K[>XI`-'KY>3BX/D@[.7QY?8`T>OEY.+@^2#DY>T`
MT>OEY.+@^>`@\>7D[.CVX`#-_^S@(.K@Z^7MY.#PZ"#D[O'R^N_MZ"#GX"#C
M[O'RZ"X`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@1E10(%9&4RX`
MS?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,(%9&4RX`S?_LX"#G
MX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,+49I;&4@5D93+@#-_^S@(.KP
MX.GMX"#DX/+@`,W_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($E-05`@Z.3E[?+H
M].CJX/;H_RX`S?_LX"#GX.3@Y.7MX"#OX/#NZ^`@Y^`@2V5R8F5R;W,@Z.3E
M[?+H].CJX/;H_RX`S?_LX"#J[NWTZ./S\.#VZ.[M[>`@Z.WT[O#LX/;H_R#G
MX"!334(@Z.3E[?+H].CJX/;H_RX`POKP[>#RZ/+E(.3@[>WH(.WE(/'@(%A-
M3`#-_^S@(/'R[NGM[O'RZ`#-_^S@`,'EZ^7FZN@`SLH`SN_VZ.@`S^[D\.7D
MY>T@\>_H\?KJ`,3P\^/@(.CM].[P[.#VZ/\`S_#@XN`@[>`@[_#H\N7FX/+E
MZ_\`4$=0(%-H96QL`,_@\.[KX`#/X/#NZ^`Z`,_@\.[KX#H@`,WEZN[PY>KR
M[>`@[^#P[NO@+@#"[/KJ[>@`S^[B\N[P_^7L[O'R`,3@(/'E(.CGXOKP^.+@
M\B#KZ"#NX?'K\^;BX/GH\N4@[N_E\.#VZ.@@[_#H(,+U[N0_`,3@(/'E(.?@
MZ^CWZ"#KZ"#R[N+@(/'ZX>CRZ.4_`,#D[.CMZ/'R\.CPX.WE(.W@(._PX.+@
M\N``TN7KY?3N[0#,[NO_+"#B^N+EY.7RY2#LY?'E]B#H(./NY.CMX"X`S_#E
MY.CXY>T@Y.7M`,KK_O?NXN`@Y.+NZ>K@(._SX>OH]^7M+_?@\?+E[2#JZ_[W
M(.WE(.'E^.4@X^7MY?#H\.#MX"X`RN[E].CVZ.7M\@#7Y?+E[>4`R/'JX/+E
M(.3@(.CG\O#HY?+E("5S(.OH/R#2X.?H(.[OY?#@]NC_(.WE(.SNYN4@Y.`@
M\>4@XOKP[>4@[>#GX.0N`,_NXO+@\/_I(.3NZN#R[@#/[N+R[O#_Y>SH(.3@
M[>WH`,KPX.GMX"#DX/+@(.?@(._NXO+N\/_E[.[Q\O+@`,_NXO+N\/_E[.[Q
M\B#H[?+E\.+@ZP#2Z.\@[>`@[^[B\N[P_^7L[O'R\N``S^[B\N#P_^D@XO'E
MZN@@Y.7M`,_NXO+@\/_I(.SE\>7W[>X`S^[B\N#P_^D@\>7D[.CW[>X`S^[B
M\N#P_^D@X^[DZ/CM[@#-Y>ONZN#K[>@@RN#KY>WDX/#H`,#D\.7Q(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`,_PY>S@]>WH`,_PY>S@
M]>WH(._N\O#EX>CRY>LZ("5S`-#NZ_\`4U%,(%-H96QL`%-32`#1X0#1^N'N
M\N``Q^#OZ/CH(.K@\NX@[>[B[@#'X._H^.@@\?KAZ/+HY0#(Y^'E\.7RY2#C
M\//OX"#GX"#D[N'@XO_MY0#(Y^'E\.7RY2#M[N(@[_#H\N7FX/+EZR#MX"#C
M\//OX`#(Y^'E\.7RY2#Q^O#B^O``R.?AY?#H(._N\O#EX>CRY>L@Y^`@Y.[A
MX.+_[>4`R.?AY?#E\N4@[N_VZ.CRY2#GX"#O[O+B^O#FY.7MZ.4L(.K@ZB#D
MX"#QY2#O[NK@Y^+@\B#PX.?KZ/?MZ/+E(.CGX^OEY.@@Z"#HY^/KY>3@(._N
M(._NY/#@Y^'H\.#MY2X`R.?AY?#E\N4@ZN#KY>WDX/`@Y^`@Z.SO[O#R.@#(
MY^'E\.7RY2#$X/+@(/#@Y^3EZ^CRY>LZ`,CGX>7PY?+E(/3N\.S@\B#GX"#$
MX/+@\N`Z`,CGX>7PY?+E(/3@Z>L@Y^`@Z.SO[O#R.@#(Y^'E\.7RY2#J[ND@
MY.`@Y2#O^O#BZ/_R(.3E[2#MX"#QY>3LZ/;@\N`Z`,CGX>7PY?+E(/3N\.S@
M\B#GX"#7X/'@.@#(Y^'E\.7RY2#O\.[D^NOFZ/+EZ^WN\?+RX"P@ZN[_\NX@
MY.`@\>4@[^[JX.?BX#H`R.?AY?#E\N4@Y.+E(/'ZXN_@Y.#YZ"#O[NOE\N`Z
M`,CGX>7PY?+E(.+@^.#RX"#Q]>7LX"#GX"#VXN7R[N+E\N4N`,CGX>7PY?+E
M(._PY>3O[O?H\N#MZ/_R(.[R(,+@\2#EY^CJ.@#'X.3@Z?+E(,+@^.7R[B#M
MX/?@Z^WN(._PZ.ONYN7MZ.4L(/'UY>S@(.?@(/;BY?+NXN4L(.[O\.7Q[?_B
MX.WE(.W@(/'R\.#MZ/;@\N`@Z"#D\//CZ"#N[_;HZ"#GX"#DZ/'OZ^7_+@#/
M[NK@Y^+@[>4`S^[JX.;H(.CG\O#HZ2P@X.O@\.S@(.@@[^[B\N[P_^7L[O'R
M(.CJ[NWH(.(@Z.?CZ^7DZ/+E(.W@(.K@Z^7MY.#PZ/+E/P#$X"#QY2#O[NK@
MY^+@\B#KZ"#GX.3@]^@@XB#JX.OE[>3@\.`_`,3@(/'E(._NZN#GXN#R(.OH
M(/'@[.X@\?KAZ/+H__+@+"#J[NCR[B#H[.#R(.W@\?+P[N7MX"#@Z^#P[.`_
M`-#@Y^SE\`#"^N+EYN3@[>4@[>`@\>_E]NC@Z^WH(/'H[.+NZ^@`S>#WX.OM
MX"#DX/+@`,?@[^[WXN`@[>``S>#WX.OE[2#WX/$`S>0`R.?O\.#RZ`#3\>_E
M]0#-Y>3EZ_\`Q^#DX/?H`-'@[.X@\N7J\?(`U_(`RN#KY>WDX/#Z\B`B)7,B
M(.WE(.SNYN4@Y.`@X?KDY2#HY_+PZ/(N`,K@Z^7MY.#P^O(@(B5S(B#AY?CE
M(.CG\O#H\BX`RN#KY>WDX/#Z\B`B)7,B(.'E^.4@Y^#OZ/'@[2X`S_#HZO#E
M[^7MZ/_R(%!'4"#O[N3OZ/$@Y2#MY>[A]>[DZ.P@Y^`@Y.`@\>4@[_#NXN7P
MZ"#O[N3OZ/'@[>[R[B#OZ/'L[BX`RO#H[_+H\.#MY?+N(.CGZ/'JXN`@ZO#H
M[_+H\.#MX"!W96(@XO#ZY^K@+@#,Y?'R[N_NZ^[FY>WHY?+N(.W@($=N=5!'
M(/3@Z>O@(/+P_^'BX"#DX"#A^N3E(.3@Y.7M;R#MX"!#<GEP=%]P9W`Z.B!C
M;&%S`,_P[N/PX.S@\N`L(.KN__+N(/'K\^;H(.?@(._NZN#GXN#MY2#MX"#R
M[N?H(/+H[R#DX.WMZ"`H)7,I(.WE(.'E^.4@[O+J\.CRX"#B(/'H\?+E[.#R
MX`#-_^S@(.3B[NGJZ"P@ZN[H\NX@Y.`@X?KDX/(@[^[JX.?@[>@@XB#KZ.WH
M__+@+@#([.`@\N+Z\.3E(.SM[N/N(/'H[.+NZ^@@XB#R[N+@(._NZ^4N(,+Z
MXN7KZ"#Q\N4@)7,@\>CLXN[KX#L@\O#_X>+@(.3@(.+ZXN7DY?+E(._N+>S@
MZ^KN(.[R("5S+@##\.7XZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@Z>O@.B`E
M<R#MY2#AY?CE(.CG[_#@\N7M+@#([.#XY2#O\.[AZ^7L(._PZ"#HY^_PX/G@
M[>7R[B#MX"#TX.GKX"X@)7,@Y2#O[BWC[NO_["#N\B#LX.KQZ.S@Z^WN(.3N
M[_/Q\NCLZ/\@\.#G[.7P("@E9"#AX.GRX"DN`,/PY?CJX"#O\.@@Z.?O\.#Y
MX.WE\NX@[>`@].#IZ^`N("5S(.'E^.4@\>#L[B#N\O?@\?+H(.CG[_#@\N7M
M+@##\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J[NWRX.KRZ"X`P_#E
M^.K@(._PZ"#H[._N\/+H\.#MY2#MX"!I0V%L96YD870@Y.#M[>@N`,W_[.`@
M\?KAZ/+H_R#GX"#EZO'O[O#R+@#2[N+@(.WE(.4@XN#KZ.3E[2!R87(@X/#U
MZ.(N`-+NXN`@[>4@Y2#BX.OHY.7M('II<"#TX.GK+@#2[N+@(._NZ^4@Y2#M
MY>[A]>[DZ.SN+@#2[N+@(._NZ^4@[.[FY2#DX"#Q^N3Z\.;@(/'@[.X@]N7K
MZ"#WZ/'KX"X`TN[BX"#O[NOE(.SNYN4@Y.`@\?KD^O#FX"#QX.SN(/?H\>O@
M(.@@Y.+NY?+N]^CE+@#2[N+@(._NZ^4@\O#_X>+@(.3@(.4@Y^#OY?+@_R#H
MZ^@@Z.WRY?#BX.L@\.#GY.7KY>T@\>_H\?KJ(._P[NSE[>OHXN@`TN#GZ"#T
M[O#LX"#BY??E(.'E^.4@[N'PX.'N\N7MX"X`TN[BX"#WZ/'K[B#R\/_AXN`@
MY.`@Y2#O[NWE(.7DZ.WH]N`N`-+NY^@@\?KPXOKP(.WE(.SNYN4@Y.`@Y.7J
M[NSO\.7QZ/#@('II<"#H(&=Z:7`@].#IZ^[BY2X`TN#GZ"#Q\N[I[>[Q\B#R
M\/_AXN`@Y.`@Y2#WZ/'K[BX`U^7RXOKP\OKJ`,_P[O'KY>3_XN#MY2#MY2#B
M\.7LY0#$Z_KF[>[Q\@#$[>7Q`-/R\.4`PO(`PO+N\.WHZ@#2Z.\`55),`,/P
MY?CJX"#O\.@@Z.?R\.CBX.WE("(E<R(Z("5S+@##\.7XZN`@[_#H(.CG\O#H
MXN#MY2#MX"`E<RX`P_#E^.K@(._PZ"#GX/#EYN3@[>4@[>`@Y.7TZ.WH]NC_
M\N`@[>`@)7,N`,/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO\.7QZ/#@
M[2#@\/7HXBX`P_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@
M+@##\.7XZN`@[_#H(._PY>+NY.`@[>`@\N[GZ"!7;W)D(.3NZO/LY>WR`,_N
MY/?E\/+@[>@`S>7O[N_ZZ^WE[0#.[_#E\>WH`,[O\.7Q[>@@)7,`P.3LZ.WH
M\?+PZ/#@[>4@[>`@[^[R\.7AZ/+EZ^CRY0#/[O+PY>'H\N7K\>KH(.CM\N7P
M].7I\0#([.4`R.SE.@#([.4Z(`#/[O+PY>'H\N7KZ"#B(/'H\?+E[.#RX#H`
MPN#JX.WVZ/\`P_#E^.K@(._PZ"#O\.[BY?#JX/+@("T@\N[BX"#OZ/'L[B#L
M[N;E(.3@(.4@X>CK[B#O[N3O\.#BY>WN+@#"[>CLX.WHY0#1\`#1\/_DX`#1
MY>3LZ/;@`-'EY.SH]N`@)60`T>7D[.CVX"CH*0#1Y>3LZ/?M[@#1Y>3LZ/?M
M[CH@[^[B\N#P_R#QY2#B\?_JX`#$[N'PY2#$[OCKZ"#B("5S`,3NX?#E(.3N
M^.OH+"`E<P#(Y^'E\.7RY2#O\.CK[N;E[>CE\NXL(.KNY?+N("5S(.3@(._N
MZN#FY2#QZ^7D(.+U[N0N`,KNX^`@Y.`@Y^#B^O#XXN#R(.3MY>+MZ/_R(.@@
M\>7D[.CW[>C_\B#HY^/KY>0_`,KNX^`@Y.`@Y^#O[O?BX/(@Y.WEXNWH__(@
MZ"#QY>3LZ/?MZ/_R(.CGX^OEY#\`P>CG[>7Q(.#D\.7Q`,'HY^WE\2#RY>OE
M].[M`-#@X>[R[>`@\>7D[.CVX`##PP##[N3H^.WN`,/NY.CX[>XZ(._NXO+@
M\/\@\>4@XO'_ZN``Q.``S>4@XOKBY>3N]?+E(.+@Z^CDY>T@96UA:6P@X.3P
MY?$N`,W_[.#RY2#O\.#BX"#GX"#D[N'@XO_MY2#MX"#Q^N'H\NC_(.KZ["#H
MY^'PX.WH_R#JX.OE[>3@\"X`S?_LX/+E(._PX.+@(.3@(.CG\O#HY?+E(/+N
MXN`@\?KAZ/+HY2X`Q^#DX.OH(/'RY2#MY>+@Z^CDY>T@ZN#KY>WDX/`N`-+P
M_^'BX"#DX"#HY^'E\.7RY2#JX.OE[>3@\"P@ZN[I\NX@Y.`@X?KDY2#HY_+P
MZ/(N`-+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#M
MY2X`TO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4N
M`-+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.[O\.7Q[?_BX.WE
M+@#([?3N\.S@]NC_(.?@(,+@\0#"X/CH__(@Z.3E[?+H].CJX/;H[NWE[2#D
M\.#IXN7P(.WE(._NY.3Z\.;@(/'OZ/'ZZB#MX"#O[O+PY>'H\N7KZ/+E+"#H
MZ^@@\N#GZ"#B^N?L[N;M[O'R(.4@Y^#A\.#MY>W@+@#"X/CH\N4@ZN[M].CC
M\_#@]NCN[>WH(.[O]NCH(.'_]>`@[N'M[N+E[>@N`,+@^.CRY2#Q^O#B^O#H
M.@!;Z^CMZ/\@)7,@[O(@)7-=`.3E[0#DY>THY.WH*0#D[>@`].#IZP#N\@#L
MY?'E]BC@*0#MX"#Q^OG@\N`@Y.#RX`#MX"#Q^OGH__(@\.#A[O+E[2#DY>T`
MX>7G(.CLY0!V0V%R9`#QY>3LZ/;@`/'EY.SH]N`HZ"DZ`/'EY.SH]N@`X^[D
MZ.W@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+V%R7U-9+P``````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4P`#`R,#<P
M-@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O87)?
M4UDO3$-?34534T%'15,O````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-3``,#(R-#<S`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O
M;F]L:71H+VQO8V%L92]A<E]362],0U]-15-304=%4R]K<F]N;VQI=&@N;6\`
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`S,C8R-``Q,#0Q-S,V,C<U,``P,C4P-#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````WA($E0````#U````
M'````,0'``!+`0``;`\```````"8%```'0```)D4```(````MQ0```4```#`
M%```"0```,84```/````T!0```@```#@%```!P```.D4```%````\10```H`
M``#W%```%`````(5```*````%Q4```,````B%0``!P```"85```-````+A4`
M``H````\%0``'P```$<5```%````9Q4``#D```!M%0```@```*<5```&````
MJA4``"D```"Q%0``$0```-L5```6````[14``!8````$%@``"````!L6```&
M````)!8``!4````K%@``"````$$6```*````2A8```P```!5%@``!@```&(6
M```'````:18``!L```!Q%@``*0```(T6```2````MQ8```<```#*%@```@``
M`-(6```%````U18``!,```#;%@```P```.\6```&````\Q8```@```#Z%@``
M$`````,7```&````%!<```D````;%P``#````"47``!<````,A<``!0```"/
M%P``"P```*07```O````L!<```\```#@%P``)@```/`7```'````%Q@```@`
M```?&```!````"@8```'````+1@```4````U&```#0```#L8```(````21@`
M``8```!2&```"````%D8```%````8A@``!````!H&```$````'D8```/````
MBA@```L```":&```#P```*88```,````MA@```\```##&```!@```-,8```/
M````VA@``!X```#J&```(0````D9```@````*QD```,```!,&0``"````%`9
M```"````61D```8```!<&0``!@```&,9```$````:AD```0```!O&0``!```
M`'09```,````>1D```H```"&&0``!0```)$9```'````EQD```H```"?&0``
M#P```*H9```6````NAD``!(```#1&0``$````.09```'````]1D```0```#]
M&0``!`````(:```H````!QH```@````P&@``"````#D:```)````0AH``!X`
M``!,&@``$````&L:```(````?!H```8```"%&@``!P```(P:```"````E!H`
M``0```"7&@``!0```)P:```/````HAH```,```"R&@``!P```+8:```*````
MOAH```<```#)&@``"0```-$:```"````VQH```8```#>&@``!0```.4:```'
M````ZQH``!4```#S&@``!0````D;```*````#QL```@````:&P``"0```",;
M```S````+1L``#,```!A&P``.````)4;```+````SAL``#$```#:&P``+```
M``P<```$````.1P```4````^'```"````$0<```"````31P```<```!0'```
M!P```%@<```1````8!P```@```!R'```!P```'L<```>````@QP``!X```"B
M'```!0```,$<```H````QQP``"D```#P'```#````!H=```3````)QT```L`
M```['0``#P```$<=```3````5QT``!,```!K'0``#P```'\=```,````CQT`
M``X```"<'0``#0```*L=```-````N1T```L```#''0``$0```-,=```1````
MY1T```0```#W'0```@```/P=```(````_QT```L````('@``"@```!0>```,
M````'QX``%@````L'@``&@```(4>```7````H!X``!H```"X'@``&0```-,>
M```7````[1X``!T````%'P``&P```",?```?````/Q\``!,```!?'P``"0``
M`',?```[````?1\``!\```"Y'P``*````-D?```0`````B```!<````3(```
M"@```"L@```(````-B````H````_(````@```$H@```'````32````8```!5
M(```!0```%P@```)````8B````(```!L(```+P```&\@```?````GR```"$`
M``"_(```'````.$@```(````_B````4````'(0``!0````TA```(````$R$`
M``(````<(0``!````!\A```O````)"$``!0```!4(0``)````&DA```E````
MCB$``"````"T(0``)@```-4A```,````_"$```<````)(@``#@```!$B```,
M````("(```@````M(@``!P```#8B```"````/B(```D```!!(@``!````$LB
M```'````4"(```<```!8(@``!@```&`B```4````9R(```T```!\(@``"P``
M`(HB``!(````EB(``$P```#?(@``#````"PC```*````.2,```D```!$(P``
M`@```$XC```&````42,``!0```!8(P```P```&TC``!%````<2,``#````"W
M(P``$````.@C```?````^2,``!`````9)```#P```"HD```#````.B0```8`
M```^)```!````$4D```(````2B0```0```!3)```$````%@D```3````:20`
M``4```!])```!````(,D```+````B"0```4```"4)```!P```)HD``"5`0``
MHB0``!D````X)@``!P```%(F```,````6B8```D```!G)@``#@```'$F```)
M````@"8```<```"*)@``!0```)(F```-````F"8``!8```"F)@``"P```+TF
M```&````R28```@```#0)@``$````-DF```,````ZB8``!@```#W)@``!0``
M`!`G```F````%B<```(````])P```@```$`G```M````0R<``!````!Q)P``
M'P```((G```A````HB<```D```#$)P``!0```,XG```5````U"<```4```#J
M)P``#0```/`G```-````_B<```8````,*```!@```!,H```2````&B@``"H`
M```M*```#@```%@H```&````9R@```L```!N*```!````'HH```0````?R@`
M``,```"0*```"@```)0H```+````GR@``!````"K*````P```+PH```&````
MP"@```D```#'*```2P```-$H```+````'2D```4````I*0``'````"\I```.
M````3"D``"D```!;*0``"P```(4I```&````D2D```8```"8*0``"````)\I
M```1````J"D```T```"Z*0``#@```,@I```,````URD```X```#D*0```P``
M`/,I```+````]RD```L````#*@``"@````\J```'````&BH```L````B*@``
M"````"XJ```0````-RH```4```!(*@``#0```$XJ```?````7"H``!\```!\
M*@``'@```)PJ```$````NRH```0```#`*@``!@```,4J```&````S"H```@`
M``#3*@``!````-PJ```(````X2H```<```#J*@``#````/(J```+````_RH`
M``4````+*P``"0```!$K```+````&RL```\````G*P``'````#<K```4````
M5"L``!$```!I*P``#````'LK```&````B"L```0```"/*P``)0```)0K```1
M````NBL```4```#,*P``#@```-(K```=````X2L``!4```#_*P``!@```!4L
M```$````'"P```0````A+```"P```"8L```&````,BP```0````Y+```#0``
M`#XL```$````3"P```8```!1+```#0```%@L```%````9BP```T```!L+```
M!P```'HL```'````@BP```4```"*+```!@```)`L```0````ERP```4```"H
M+```#````*XL```,````NRP```X```#(+```)P```-<L```G````_RP``"D`
M```G+0``$P```%$M```@````92T``!P```"&+0``!@```*,M```'````JBT`
M``P```"R+0``!0```+\M```+````Q2T```8```#1+0``#````-@M```+````
MY2T```4```#Q+0``%````/<M```9````#"X```0````F+@``'````"LN```H
M````2"X```P```!Q+@``"P```'XN```)````BBX```X```"4+@``%````*,N
M```-````N"X```L```#&+@``"@```-(N```*````W2X```P```#H+@``"@``
M`/4N```,`````"\``!0````-+P``$0```"(O```%````-"\```4````Z+P``
M!0```$`O```)````1B\```D```!0+P``#````%HO```^````9R\``!4```"F
M+P``$P```+PO```7````T"\``!8```#H+P``$0```/\O```=````$3```!0`
M```O,```$@```$0P```8````5S````4```!P,```,@```'8P```B````J3``
M`"8```#,,```#````/,P```/`````#$```T````0,0``!P```!XQ```+````
M)C$```4````R,0``"````#@Q```%````03$```<```!',0``!@```$\Q```&
M````5C$``#(```!=,0``%@```)`Q```C````IS$``!L```#+,0``!@```.<Q
M```'````[C$```P```#V,0``!`````,R```(````"#(```,````1,@``*P``
M`!4R```.````03(``!P```!0,@``'P```&TR```N````C3(``"(```"\,@``
M$@```-\R```(````\C(```X```#[,@``#P````HS```,````&C,```4````G
M,P``"````"TS```(````-C,```<````_,P``"@```$<S```0````4C,```@`
M``!C,P``$@```&PS```/````?S,```T```"/,P``2P```)TS``!*````Z3,`
M``L````T-```"@```$`T```+````2S0```@```!7-```!@```&`T```0````
M9S0```,```!X-```)@```'PT```M````HS0```@```#1-```$0```-HT```/
M````[#0``!````#\-```!0````TU```.````$S4```8````B-0``"@```"DU
M```%````-#4```X````Z-0``%````$DU```%````7C4```4```!D-0``%```
M`&HU```(````?S4```L```"(-0```0```!,````4````L`````````"N````
M``````````#S````(````!P```##`````````)8````R````8P````4`````
M````I@```'(```#O````XP```#L```#!`````````*<```#J````Y@``````
M````````OP```'P```"C``````````@```"#`````````#D```!T````8```
M`-D```#2````V@```(T```#A````$@```$0```!K````>@````````!*````
MTP```-<```"M````GP```-4````_`````````"\``````````````+,```!%
M````3````%$``````````````$\```#T````O@````````"1````&@```+T`
M``````````````````#M````20```%T```#K````9@```/``````````````
M``````#6````A````+0```!J````1P```!$```!"````&````,@```!0````
MF@````P```#$`````````"T```">`````````#8```#H`````````%<```"L
M````<````%H```"O``````````````"8`````````.(`````````T0```)T`
M``!2````-P```)(`````````L0```+L`````````J`````````#-````E0``
M``````!3`````````,8```"\````>0```!T```!N````5`````````"A````
MVP```),```!+`````````"$```!&````!@``````````````W@```%8`````
M````Q0```#4`````````P@`````````+```````````````#````<P````(`
M```9````H````*D`````````M@```*4`````````S````"8```#)````2```
M`'8```!H`````````#0````\````00```````````````````$````";````
M8@```!8```#=````<0````````")````J@```&\````B````YP`````````'
M````)````&$`````````*````!\```!M````.````/(```!<````A@``````
M``"4`````````'L```#I`````````"D```"X````+@```"4```!_````D```
M`(````#'````V````!``````````P````&P```"U````7@```($```"9````
M``````\```"*`````````#```````````````-\````G````9P```$X```!-
M````A0```!<```#U````*P````````"R````S@```-0````L`````````.P`
M``!8````"@``````````````T`````````""````*@```(\```#/````,0``
M`+<```#N````,P```)<```````````````T```"B````AP```'X```"Y````
M7P```&4````Z````W```````````````B````'<`````````Y0```(X```!U
M`````````%4`````````RP`````````>````````````````````R@```(L`
M```$````N@```)P```!#````6P```%D````;``````````D`````````/0``
M``X```"D``````````````",`````````&D```#D`````````.`````C````
M/@```'T``````````````&0```"K`````````'@````5````\0`````E<R!F
M:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``R-"!H;W5R<P!!32]030!!9&0@
M179E;G0`061D(&$@;F5W(&5V96YT`$%D9"!P86ER`$%D9')E<W,`06QA<FT`
M06QA<FT@1&%T90!!;&%R;2!3<&%N("AM:6YU=&5S*0!!;&%R;2!4:6UE`$%L
M;`!!;&P@9&%Y`$%L;"!D87D@979E;G0`06QL(&5V96YT<P!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%P<FEL`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!=`!!
M=6=U<W0`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BX`079A:6QA8FQE(&9I96QD<SH`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"
M860@:V5R8F5R;W,@=7-E<FYA;64N`$)I<G1H9&%Y`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%T96=O<GD`0V5L;"!0:&]N90!#;&]S92!7:6YD
M;W<`0V]M:6-S`$-O;7!A;GD`0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-R
M96%T92!A($YE=R!%=F5N=`!#=7)R96YT`$1$`$1A:6QY`$1A:6QY.B!296-U
M<G,@979E<GD`1&%Y`$1A>2AS*0!$96-E;6)E<@!$969A=6QT($ED96YT:71Y
M`$1E;&5T90!$96QE=&4@)7,`1&5L971E($5V96YT`$1E;&5T92!T:&4@8W5R
M<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U
M<F4@;V-C=7)E;F-E<RP@;W(@86QL(&]C8W5R96YC97,_`$1E<V-R:6)E('1H
M92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$=64Z("5S`$1U
M<F%T:6]N`$5D:70`161I="`E<P!%;6%I;`!%;7!T>2!R97-U;'0N`$5N9"!$
M871E`$5N9"!/;@!%;F0@5&EM90!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M<&]R=`!%>'!O<G0@0V%L96YD87(`1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&87@`1F5B<G5A<GD`1G(`
M1G)I9&%Y`$9U='5R90!'86UE`$AE;'``2&]M90!(;VUE($%D9')E<W,`2&]M
M92!0:&]N90!(;W)D90!(;W5R*',I`$EC;VYS($]N;'D`26-O;G,@=VET:"!T
M97AT`$EM<&]R="]%>'!O<G0@0V%L96YD87(`26UP;W)T960@9FEE;&0Z("5S
M`$EM<&]R=&5D(&9I96QD<SH`2F%N=6%R>0!*=6QY`$IU;F4`2V5R8F5R;W,@
M<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97EW;W)D<P!,86YG
M=6%G90!,87-T('=E96L`3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z
M`$QI<W0@2&5L<"!4;W!I8W,`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`34T`
M36%I;`!-87)C:`!-871C:&EN9R!F:65L9',`36%Y`$UE971I;F<`365N=2!M
M;V1E.@!-97-S86=E`$UI;G5T92AS*0!-;P!-;VYD87D`36]N=&@`36]N=&AL
M>0!-;VYT:&QY.B!296-U<G,@979E<GD`3F5V97(`3F5X="!-;VYT:`!.97AT
M(&1A>0!.97AT('=E96L`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!E
M;F0@9&%T90!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO;F4`3F]T97,`3F]V96UB97(`3TL`3V-T;V)E<@!/
M<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!A='1E<FX`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<FUA;F5N=&QY(&1E;&5T
M92!T:&ES(&5V96YT/P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!R979I;W5S(&1A>0!0<F]B;&5M($1E<V-R:7!T:6]N
M`%)E8W5R(%5N=&EL`%)E8W5R<F5N8V4@1&%T80!296-U<G)E;F-E($5N9"!$
M871E`%)E8W5R<F5N8V4@26YT97)V86P`4F5C=7)R96YC92!4>7!E`%)E8W5R
M<R!D86EL>0!296-U<G,@;6]N=&AL>0!296-U<G,@=V5E:VQY`%)E8W5R<R!Y
M96%R;'D`4F5M;W9E('!A:7(`4F5S970@=&\@1&5F875L=',`4F5T=7)N('1O
M($]P=&EO;G,`4F]L90!380!3871U<F1A>0!3879E($%S($YE=P!3879E($5V
M96YT`%-A=F4@3W!T:6]N<P!396QE8W0@8V]N9FER;6%T:6]N(&]P=&EO;G,L
M(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE=W,@86YD(&-H;V]S
M92!D969A=6QT('9I97<N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O
M<G0Z`%-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3H`4V5L96-T('1H92!T:6UE
M(&9O<FUA=#H`4V5L96-T('1H92!T:6UE('-P86X@=&\@<VAO=SH`4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!397!T96UB97(`4VAO=R!D
M96QE=&4L(&%L87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I;B!C86QE;F1A
M<B!V:65W<S\`4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R/P!3:&]W
M(&]N;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S970_`%-K:7`@36%I
M;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W1A<G0@1&%T90!3
M=&%R="!/;@!3=&%R="!4:6UE`%-U`%-U8V-E<W,`4W5N9&%Y`%1A<VMS`%1E
M>'0@3VYL>0!4:`!4:&4@96YD(&1A=&4@;75S="!B92!L871E<B!T:&%N('1H
M92!S=&%R="!D871E+@!4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N`%1H=7)S9&%Y`%1I=&QE`%1O9&%Y`%1O;6]R
M<F]W`%1U`%1Y<&4`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&1E;&5T92`E<RX`56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!R96%D('1H
M92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`E<R\E<RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YD;R!#:&%N9V5S`%5N9FEL960`57-E<B!);G1E<F9A8V4`57-E<B!/
M<'1I;VYS`%5S97)N86UE`%=A<FYI;F<`5V4`5V5D;F5S9&%Y`%=E96L`5V5E
M:R`E9`!7965K*',I`%=E96ML>0!7965K;'DZ(%)E8W5R<R!E=F5R>0!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@=&EM92!S:&]U;&0@9&%Y(&%N
M9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E
M;G1S/P!7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R
M="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_`%=O<FL@061D
M<F5S<P!7;W)K(%!H;VYE`%=O<FL@5V5E:P!960!996%R;'D`665A<FQY.B!2
M96-U<G,@979E<GD`665S`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`
M66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`&1A>0!D87DH
M<RD`9&%Y<P!M;VYT:"AS*0!N86UE`&]N('1H92!S86UE(&1A=&4`;VX@=&AE
M('-A;64@=V5E:V1A>0!V0V%R9`!W965K`'=E96LH<RD@;VXZ`'=E96MS`'EE
M87(H<RD`4')O:F5C="U)9"U697)S:6]N.B!+<F]N;VQI=&@@,2XQ"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P,RTP-"TS,"`Q,CHP,"LP,C`P"DQA<W0M5')A;G-L871O<CH@
M(%!L871I;G5M($1E=F5L;W!M96YT(%1E86T@/&1E=G1E86U`<&QA=&EN=6TM
M<WDN8V]M/@I,86YG=6%G92U496%M.B!!<F%B:6,@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]0U`Q,C4V"D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@
M/B`Q*3L*`"5S(,KC(,?3RNW1Q\\@Q^'CX=T@R.3,Q\T`,C0@T\?:R0#DY<?1
MQ_`OX>WAQ_``Q=;'W<D@S<_+`,76Q]W)(,W/RR#,S^W/`,/6W2#+Y,?&[0#'
MX=KDYL?D`,KDR.WE`,K'T>W.(,?ARN3([>4`X\_)(,?ARN3([>4@*,C'X<_>
MQ\;>*0#2X^0@Q^'*Y,CMY0#'X<SC[=H`W^$@Q^'MYN,`S./MVB##S<_'RR#'
MX>WFXP#,X^W:(,?AP\W/Q\L`RN,@RLW/[<\@WNWCR2#;[=$@X][(YN')`.3M
MT\?D`,K#W^W/(,?AV.'((-[(X2#'X<C/P2#(VN/A[<?*(,?AU>W'Y,F_`-WM
M`,+(`,KC(-'=UB#'X<K-WMX@X^0@Q^'EYNW)(./D(-[(X2#'X>/.S^,@T<?/
M[>;3+@#'X<W>YN$@Q^'CRN;=T<DZ`-_AX\D@X]'FT2#;R-$@X][(YN')("C?
M[='([='FTRD`Q]/C(,?AX]/*SL_C(-O(T2#CWLCFX2`HW^W1R.W1YM,I`-KM
MSR#C[>''SP#%X=O'P0#%X=O'P2#'X<CAQ]L@VN0@X]3?X<D`RM7D[=T`Q^'E
MQ\K=(,?AS.;'X0#%V^''WB#'X>3'W=#)`-'3YN/'R@#'X=31W\D`RL/?[<\@
MS=#=(,?AP\W/Q\N_`.''Q>/?Q^3MR2#AW<K-($UA:6YT96YA;F-E7U1A<VL@
MX>'(T>WCS"`E<P#%Y-3'P2#-S\L@S,_MSP#'X<W'X>T`[>;C("T@T=[C[>0`
M[>;C[0#MYN/MQ_`Z(,K?T<?1(-_A`.WFXP#MYN,@*,/MQ^,I`-_'Y.;D(,?A
MP^;A`,?ARLW>WB#'X<?=RM''UNT`S=#=`,W0W2`E<P#-T-T@Q^'-S\L`S=#=
M(,?AS<_+(,?AS<?A[2`@W=[8(*$@Y=#E(,?AX]')(.;'X>/1Q\H@Q^'>Q\_C
MR2##YL/F(,SC[=H@Q^'CT<?*(,?ARL?A[<F_`-31S2#'X>/4W^')`,?AU-'-
M`,KC(,W=V2#'X<K=Q]7MX2#AX\_MT2#'X>39Q^,`Q=GEQ]$@Q^'.[<?1Q\H`
MX<<@RL_.X2#CR,?4T<GP(,7A["#'X>/AW2!M86EN=&5N86YC92YP:'``Q]/*
MS=['WCH@)7,`Q^'=RM')`,ED:71E<@#*S='MT2`E<P#'X<C1[<\@Q^'%X=_*
MT>;D[0#AQ\KFS,\@Y,K'QLPN`,K'T>W.(,?AQ>3*Y<?!`,KDRN7M(,C*Q]'M
MS0#*YM[MRB#'X<7DRN7'P0#.V,,`W^$@,34@S][MWLD`W^$@,S`@S][MWLD`
MW^$@-2#/WNW>R0#?X2#/SN;A`-_A(.35W2#3Q]K)`-_A(,_>[=[)`,/CR^')
M(-KA["#'X=[MXSH`RM7/[=$`RM7/[=$@Q^'#S.3/R0#AQ\7CW\?D[<D@X>':
MR^;1(-KA["#'X<K=UNWAQ\HN`.''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@
M3$1!4"X`X<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!334(N`-W'W],`U,C'
MV`#'X<SCVLD`Q^',X]K)`./3RM[(X<?P`.':R,D`Q^'CT\?:S\D`Q^'(S\?M
MR0#:Y.;'Y"#'X>/DTN$`Y<?*W2#'X>/DTN$`Y>;1S^T`T\?:R2`HT\?:`,/M
MWN;DQ\H@W=[8`,/MWN;DQ\H@X]H@Y-7FU0#'T\KMT<?/+\K5S^W1(,CMQ^3'
MRB#'X</,Y,_)`,?AS=[FX2#'X>/3RN;1S\DZ("5S`,?AS=[FX2#'X>/3RN;1
MS\DZ`-_'Y.;D(,?AR\?D[0#-TNW1Q^0`RN/FT@#'X>/.S^,@W^W1R.W1YM,@
MT=W6(,?ARLW>WB#CY"#'X>7F[<DN`,?AW^'CQ\H@Q^'CW<K'S>W)`,?AX=O)
M`,?AP]/(YMH@Q^'#SNW1`,K-S^W/(,?AW<K1R2#'X=+CY.W)(.'*U<_MT>7'
M`-['QN/)(-KDQ^;MY"#'X>/3Q]K/R0#'X>/?Q^0`S\[FX0#.T>;,`-3ET2`M
M(-'>X^WD`,?AR-'MSP#"T,?1`./8Q\C>R2#'X<W>YN$`P^W'T0#'S,KCQ]H`
MYM;:(,?AX]#?T<?*.@#1T\?AR0#/WNW>R2`HS]['QMXI`,?AQ<OD[>0`Q^'%
MR^3MY`#'X=3ET0#4Y='MQ_``U.71[<?P.B#*W]''T2#?X0##R,_'\`#'X=3E
MT2#'X<K'X>T`Q^'MYN,@Q^'*Q^'M`,?AP]/(YMH@Q^'>Q\;C`.''RN;,SR#C
MVN'FX\?*(,WFX2#%VL_'S\?*(,?AW"!&5%`@5D93+@#AQ\KFS,\@X]KAYN/'
MRB#-YN$@Q=K/Q\_'RB#'X=P@4U%,(%9&4RX`X<?*YLS/(./:X>;CQ\H@S>;A
M(,7:S\?/Q\H@X^'=Q\H@4U%,(%9&4RX`X<?MYLS/(,K'T>W.(,?DRN7'P0#A
MQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB#?[='([='FTP#AQ\KFS,\@W^'CR2#C
MT>;1(.'ARLW>WB!334(^`.''[>;,SP#CX<?-V<?*`,K4T>WD(,?AR\?D[0#C
MYL?=W@#*U-'MY"#'X</FX0#.[<?1Q\H`X]KAYN/'RB#"SM'L`-_AX\D@Q^'C
MT>;1`.3CYM#,`,KDW>W0(-KCX>W'RB#'X=7MQ^3)`,W0W2#ET,<@Q^'-S\L@
MR-3?X2#DY<?&[;\`Y<?*W0#'X=',Q\$@RM+F[<_DQR#CX<[5(,?AX]3?X<DN
M`,?AT<S'P2#*TN;MS^3'(,C'T^,@Q^'CT\K.S^,@YM_AX\D@Q^'3T2X`Q^'M
MYN,@Q^'3Q\C>`-31S2#'X>/4W^')`,K?T<?1(,W*[`#([<?DQ\H@Q^'*W]''
MT0#*Q]'MSB#'Y,KEQ\$@Q^'*W]''T0#'X=W'U>$@Q^'2X^3M`.3FVB#'X<K?
MT<?1`,K?T<?1(.WFX^T`RM_1Q]$@U.71[0#*W]''T2#'T\CFVNT`RM_1Q]$@
MT^3F[0#%TN')(,?AR^3'QNT`Q^'%VL_'S\?*(,?AQ]W*T<?6[<D`VN;/R2#%
MX>P@Q^'.[<?1Q\H`Q^'/YM$`Q^'#S<\`Q^'#S<\`S=W9(-_,S^W/`,W=V2#'
MX<W/RP#-W=D@Q^'.[<?1Q\H`Q\[*T2#%VL_'S\?*(,?ARL/?[<\@H2#?[=T@
M[<KC(,?AQ=GEQ]$@YL?.RM$@Q^'%V>7'T2#'X<?=RM''UNT`Q\[*T2#'X=WF
MQ]7A(.'ARL?1[<XZ`,?.RM$@RN33[=X@Q^'*Q]'MSCH`Q\[*T2#CX=T@X>W*
MXR#'T\KMT<?/Y3H`Q\[*T2#MYN,@R,_'[<D@Q^'#T\CFV@#'SLK1(,KDT^W>
M(,?AYM[*.@#'SLK1(,?AW<K1R2#'X=+CY.W)(.'%V>7'T>7'.@#%SLK1(,W>
MX>WD(./*X\?+X>WD+@#%SLK1(.';RM\@Q^'CW=;AR3H`P]'3X2#*WM'MT<?P
M(,CCU-_AR2#-U>'*`,7MX>;A`,79Y<?1(,/MWN;DQ\H@Q^'-T-T@H2#'X<KD
MR.WE(.;'X<K?T<?1(-WM(,?AQ<SDS\F_`,79Y<?1(,?AP\W/Q\L@Q^'CT\K-
MWLD@W>T@Q^'#S.3/R;\`Q=GEQ]$@Q^'#S<_'RR#'X<KM(,KC(,7:S\?/Y<<@
MX]H@RN3([>4`Q>7CX2#'X=7MQ^3)`,7/SL?1(,W1YMT@SL?5R0#*Q]'MSB#'
MX<C/Q^W)`.W(S\,@W>T`TN/D(,?AR,_'[<D`Q^'#S<\`RN,@R.3,Q\T`Q^'#
MS<\`Q^'CY>/'R@#DU2#=WM@`Q^'.X^W3`.W,R"##Y"#MW^;D(,K'T>W.(,?A
MY.7'[<D@X\K#SM''\"#:Y"#*Q]'MSB#'X<C/Q^W)`.''RN;,SR#CY>/'RB#A
MRM7/[='EQRX`[<S((,/D(.W?YN0@Y=#'(,?AT=[C(,/?R-$@X^0@Q^'5W=$`
M[<S((,/D(,K?YN0@Y=#E(,?AWNWCR2#1WN,N`,?ASN/MTP#'X=KDYL?D`,?A
M[>;C(,?AS<?A[0#;S\?P`,?AR^''R\?!`.3FV@#AQR#%X]_'Y.W)(.'*V^WM
MT2#'X=/CQ\WMQ\H@X>/AW2!61E,@)7,O)7,N`.''[>/?Y"#-T-T@)7,N`.''
M[>/?Y"#*S>/MX2#'X<K:T>W=(.'<("`E<RX`X<<@Q>/?Q^3MR2#AWM''P<D@
MX\SASR!V9G-R;V]T+@#AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=
M(,?AW"!61E,@)7,O)7,N`-OMT2#>Q\_1(-KA["#*T<SCR2#CT\KDSR#'X>;1
MSR#ET,<`RM''S-H@VN0@Q^'*V^WMT<?*`-OMT2#CVM'=`.;'S.7)(,?AX]/*
MSL_C`,[MQ]''RB#'X>/3RL[/XP#'T^,@Q^'CT\K.S^,`RN3([>4`Q^'#T<C:
MQ\$`Q^'#T<C:Q\$`Q^''T\CFV@#'X<?3R.;:("5D`,?AP]/(YMH@*,/3Q\CM
MVBD`P]/(YMKMQ_``P]/(YMKMQ_`Z(,K?T<?1(-_A`,/EX<<@R-_C(,7A["`E
M<P##Y>''(.;3Y>''("5S`./'Y>8@PL[1(.;>RB#MRN,@Q=GEQ]'E(,WMY"#A
MQR#*YLS/(,/-S\?+(,C:S^4@W>T@YM;:(,79Y<?1(,?A[>;C(.;'X</3R.;:
MOP#CQ^7F(,/FX2#FWLH@[<KC(,79Y<?1Y2#-[>0@X<<@RN;,SR##S<_'RR#>
MR.'EW>T@YM;:(,79Y<?1(,?A[>;C(.;'X</3R.;:OP#:Y.;'Y"#'X=KCX0#E
MQ\K=(,?AVN/A`,?3R.;:(,?AVN/A`-/DR2`M(-?7`-/DYNW'\`#3Y.;MQ_`Z
M(,K?T<?1(-_A`.3:XP#MS,@@U-'-(,?AX]3?X<D@WLCA(,?1T\?A(,K>T>W1
MQ_`@R.7'+@#'Y,KERB#5X<?-[<D@Q^''RM7'X2`E<RX@Q^'1S,?!(,7:Q\_)
M(,?AS\[FX2X`R.W'Y,?*WSH`RN,@RLW/[<L@Q^'.[<?1Q\H`6\K>T>W1(,?A
MX]3?X<E=`%O'X=/8T2`E<R#CY"`E<UT`Q^'MYN,`Q^'MYN,@*,?AP^W'XRD`
MQ^'#[<?C`-3ET2`HP]3ET2D`Q^''T^,`X"!L82!MZFUE(&1A=&4`Y-W3(,?A
M[>;C(-WM(,?AQ]/(YMH`=D-A<F0`Q]/(YMH`Q^'#T\CFVB`HP]/'R.W:*2#=
M[3H`Q^'#T\?([=H`T^3)("C3Y.;'RBD`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+V1A7T1+
M+P``````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S4P`#`R,#8S,P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]L;V-A;&4O9&%?1$LO3$-?34534T%'15,O````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``,#(R-#(P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]D85]$2R],0U]-15-304=%
M4R]K<F]N;VQI=&@N;6\````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-S$Q,``Q,#0Q-S,V,C<U,``P
M,C0W-C0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````#6````'````,P&```E`0``?`T````````0$@``*````!$2
M```=````.A(```@```!8$@``!0```&$2```)````9Q(```\```!Q$@``#P``
M`($2```(````D1(```@```":$@``&0```*,2```'````O1(```X```#%$@``
M!0```-02```*````VA(``!0```#E$@``"@```/H2```%````!1,```,````+
M$P``!P````\3```-````%Q,```H````E$P``!0```#`3```"````-A,```8`
M```Y$P``$0```$`3```(````4A,```8```!;$P``%0```&(3```(````>!,`
M``H```"!$P``#````(P3```'````F1,``!````"A$P``&P```+(3```I````
MSA,``!(```#X$P``!P````L4```"````$Q0```4````6%```$P```!P4```#
M````,!0```8````T%```"````#L4```0````1!0```8```!5%```"0```%P4
M```,````9A0``%P```!S%```%````-`4```+````Y10```\```#Q%```)@``
M``$5```'````*!4```@````P%0``!````#D5```'````/A4```4```!&%0``
M#0```$P5```(````6A4```8```!C%0``"````&H5```%````<Q4```L```!Y
M%0``#P```(45```&````E14```\```"<%0``(0```*P5```#````SA4```@`
M``#2%0``#````-L5```"````Z!4```8```#K%0``!@```/(5```$````^14`
M``0```#^%0``#`````,6```*````$!8```4````;%@``!P```"$6```6````
M*18``!(```!`%@``$````%,6```'````9!8```0```!L%@``!````'$6```(
M````=A8```D```!_%@``'@```(D6```0````J!8``!H```"Y%@``"````-06
M```&````W18```<```#D%@```@```.P6```$````[Q8```4```#T%@``#P``
M`/H6```#````"A<```<````.%P``!P```!87```)````'A<```(````H%P``
M!@```"L7```%````,A<```<````X%P``%0```$`7```'````5A<```D```!>
M%P``!````&@7```*````;1<```@```!X%P``"0```($7```+````BQ<```0`
M``"7%P``!0```)P7```(````HA<```<```"K%P``"````+,7```5````O!<`
M``<```#2%P``'@```-H7```>````^1<```4````8&```*````!X8```I````
M1Q@```P```!Q&```$P```'X8```+````DA@```\```">&```$P```*X8```3
M````PA@```\```#6&```#````.88```.````\Q@```T````"&0``#0```!`9
M```+````'AD```4````J&0``$0```#`9```1````0AD```0```!4&0```@``
M`%D9```(````7!D```L```!E&0``"@```'$9```,````?!D``%@```")&0``
M&@```.(9```7````_1D``!H````5&@``&0```#`:```7````2AH``!T```!B
M&@``&P```(`:```3````G!H```D```"P&@``'P```+H:```H````VAH``!``
M```#&P``%P```!0;```*````+!L```@````W&P``"@```$`;```"````2QL`
M``<```!.&P``!@```%8;```%````71L```(```!C&P``+P```&8;```?````
MEAL```@```"V&P``!0```+\;```%````Q1L```(```#+&P``!P```,X;```$
M````UAL``"8```#;&P``#`````(<```.````#QP```@````>'```%````"<<
M```'````/!P```(```!$'```"0```$<<```$````41P```<```!6'```!P``
M`%X<```&````9AP``!0```!M'```"P```((<``!(````CAP``$P```#7'```
M#````"0=```*````,1T```D````\'0```@```$8=```&````21T``!0```!0
M'0``10```&4=```F````JQT``"4```#2'0``<P```/@=```0````;!X```,`
M``!]'@``!@```($>```$````B!X```@```"-'@``$````)8>```3````IQX`
M``0```"['@``"P```,`>```%````S!X```<```#2'@``<@$``-H>```@````
M32```!T```!N(```"````(P@```%````E2````T```";(```$````*D@```5
M````NB````D```#0(```#````-H@```B````YR````<````*(0``#@```!(A
M```%````(2$```H````G(0``&0```#(A```)````3"$```D```!6(0``!```
M`&`A```*````92$```X```!P(0``#````'\A```%````C"$```,```"2(0``
M!@```)8A```4````G2$```H```"R(0``"````+TA```=````QB$```@```#D
M(0``!0```.TA```*````\R$```4```#^(0``#P````0B```?````%"(``"P`
M```T(@``#P```&$B```&````<2(```(```!X(@``!@```'LB```5````@B(`
M``,```"8(@``!@```)PB```(````HR(``!(```"L(@``!````+\B```'````
MQ"(```L```#,(@``8@```-@B```1````.R,```L```!-(P``&P```%DC```H
M````=2,```T```">(P``"````*PC```#````M2,```8```"Y(P``!0```,`C
M```/````QB,```L```#6(P``"P```.(C```+````[B,```0```#Z(P``#P``
M`/\C```0````#R0```D````@)```$@```"HD```L````/20```,```!J)```
M!P```&XD```-````=B0```,```"$)```!@```(@D```)````CR0```0```"9
M)```!0```)XD```.````I"0```X```"S)```!0```,(D```'````R"0``!L`
M``#0)```%@```.PD```3`````R4```8````7)0``!````!XE```$````(R4`
M``H````H)0``"@```#,E```C````/B4``!D```!B)0``(````'PE```$````
MG24```<```"B)0``!@```*HE```"````L24```0```"T)0``!0```+DE```6
M````OR4```,```#6)0``!````-HE```*````WR4```H```#J)0```P```/4E
M```&````^24```4`````)@``"`````8F```7````#R8```<````G)@``"0``
M`"\F```'````.28```L```!!)@``"0```$TF```)````5R8```\```!A)@``
M!0```'$F```%````=R8```@```!])@``!P```(8F```'````CB8``!D```"6
M)@``"````+`F```5````N28``"$```#/)@``!P```/$F```Z````^28``"8`
M```T)P``#@```%LG```2````:B<```P```!])P``#P```(HG```4````FB<`
M`!,```"O)P``#P```,,G```0````TR<``!(```#D)P``$0```/<G```/````
M"2@```@````9*```!P```"(H```A````*B@``!L```!,*```!0```&@H```#
M````;B@```8```!R*```"@```'DH```*````A"@``!,```"/*```6````*,H
M```6````_"@``!`````3*0``&0```"0I```3````/BD``!````!2*0``(0``
M`&,I```H````A2D``!<```"N*0``"0```,8I```D````T"D``"$```#U*0``
M&P```!<J```?````,RH```H```!3*@``"0```%XJ```)````:"H```,```!R
M*@``"````'8J```&````?RH```<```"&*@```P```(XJ```H````DBH``"0`
M``"[*@``!P```.`J```%````Z"H```4```#N*@```P```/0J```'````^"H`
M``0`````*P``*`````4K```1````+BL``!$```!`*P``"@```%(K```3````
M72L```@```!Q*P```P```'HK```&````?BL```,```"%*P``!@```(DK```&
M````D"L```@```"7*P``%@```*`K```-````MRL``$T```#%*P``4@```!,L
M```1````9BP``!$```!X+```"@```(HL```"````E2P```4```"8+```%```
M`)XL``!*````LRP``"\```#^+```,````"XM``"#````7RT``!0```#C+0``
M`P```/@M```&````_"T```0````#+@``"@````@N```-````$RX```\````A
M+@```P```#$N```*````-2X```0```!`+@```@```$4N```!````N0```#<`
M``"'````-@````0```!5````-`````````""````KP```+(````U````````
M`*P```!,`````````!,```!6```````````````C````4@`````````M````
MA@```#@```"`````N````"@```#5`````````,<````<````%P```)H````J
M````1P```,`````-````40```'X````N````Q````&$````"````````````
M``#%``````````\```!=````D0```(T`````````M````)(`````````.@``
M``H```"H`````````!0```#&``````````````#1````C@```%,`````````
M``````D`````````F0``````````````0````)T```"\````E@```$(```!@
M`````````)X```!]````T`````````!I`````````&8``````````````(,`
M````````IP````````#!````*0```,\```"+`````````+H```"8````/```
M`&\`````````:```````````````OP```+X`````````6`````````"B````
MB@```%D``````````````(D```",````D````"$`````````6P```&<```!T
M`````````````````````````!X```"<````2````'$```"Q````'0```%\`
M````````FP```,D````0```````````````:``````````````"D````"P``
M`+4````P````/@```"0```#-````%@```-,```#,`````````&X```!P````
M3P```$0```"M````O0``````````````0P```&4````;````E````%P````[
M````A0```&L```!+````M@```$T```!:````````````````````20```'D`
M``!D`````````"L`````````S@```'(``````````````(\`````````:@``
M``<```!W`````````&T```!S`````````&P```"W````>````'4`````````
M(````#\````9````````````````````U@````````"N````JP`````````S
M````4````*8```"P````/0`````````Y````)@```#(```#2````'P```)\`
M````````?P````@```#*````%0```,(````E````5P```#$```!B````7@``
M`)<```!!````!0`````````1````HP`````````.````PP```$X```!&````
M@0``````````````!@```$4```"3````5````*```````````````*D`````
M`````````'H```#4`````````,L`````````)P```'L````2````J@````P`
M``"E````NP```,@````O````&````+,```"A````A````(@`````````2@``
M`"(```!V`````P````````"5````8P````````!\````+``````E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(&9I;&4@<W5C
M8V5S<V9U;&QY(&EM<&]R=&5D`#(T(&AO=7)S`$%-+U!-`$%D9"!%=F5N=`!!
M9&0@82!N97<@979E;G0`061D(&$@;F5W('5S97(Z`$%D9"!P86ER`$%D9"!U
M<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&UI;FES
M=')A=&EO;@!!;&%R;0!!;&%R;2!$871E`$%L87)M(%-P86X@*&UI;G5T97,I
M`$%L87)M(%1I;64`06QI87,`06QL`$%L;"!D87D`06QL(&1A>2!E=F5N=`!!
M;&P@979E;G1S`$%P<FEL`$%T`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!"
M:7)T:&1A>0!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A=&5G;W)Y
M`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]N9FER;2!087-S
M=V]R9`!#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0W)E871E(&$@3F5W($5V
M96YT`$-U<G)E;G0`1$0`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E=F5R>0!$87D`
M1&%Y*',I`$1E8V5M8F5R`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T
M92`E<P!$96QE=&4@179E;G0`1&5L971E('1H92!C=7)R96YT(&5V96YT(&]N
M;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL(&9U='5R92!O8V-U<F5N8V5S
M+"!O<B!A;&P@;V-C=7)E;F-E<S\`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S
M8W)I<'1I;VX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP`$1U93H@)7,`1'5R871I;VX`161I=`!%9&ET
M("5S`$5M86EL`$5M<'1Y(')E<W5L="X`16YD($1A=&4`16YD($]N`$5N9"!4
M:6UE`$5R<F]R`$5V97)Y($QO9VEN`$5X86UP;&4@=F%L=65S.@!%>'!O<G0`
M17AP;W)T($-A;&5N9&%R`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+@!&87@`1F5B<G5A<GD`1FEL92!-86YA9V5R`$9R`$9R:61A>0!&=71U
M<F4`1V%M90!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO
M=7(H<RD`26UP;W)T+T5X<&]R="!#86QE;F1A<@!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!*86YU87)Y`$IU;'D`2G5N90!+97EW;W)D
M<P!,87-T('=E96L`3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z`$QI
M<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]C
M871I;VX`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-87)C:`!-871C:&EN9R!F
M:65L9',`36%Y`$UE971I;F<`365S<V%G90!-:6YU=&4H<RD`36\`36]N9&%Y
M`$UO;G1H`$UO;G1H;'D`36]N=&AL>3H@4F5C=7)S(&5V97)Y`$YE='=O<FL`
M3F5W($5V96YT`$YE=W,`3F5X="!-;VYT:`!.97AT(&1A>0!.97AT('=E96L`
M3F\@96YD(&1A=&4`3F]N90!.;W1E<P!.;W9E;6)E<@!/8W1O8F5R`%!A<W-W
M;W)D`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!0871T97)N`%!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<P!097)M86YE;G1L>2!D96QE=&4@=&AI<R!E
M=F5N=#\`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9`!0<F5V:6]U<R!D87D`4')O8FQE;2!$97-C<FEP=&EO;@!296-U<B!5
M;G1I;`!296-U<G)E;F-E($1A=&$`4F5C=7)R96YC92!%;F0@1&%T90!296-U
M<G)E;F-E($EN=&5R=F%L`%)E8W5R<F5N8V4@5'EP90!296-U<G,@9&%I;'D`
M4F5C=7)S(&UO;G1H;'D`4F5C=7)S('=E96ML>0!296-U<G,@>65A<FQY`%)E
M;6]V92!P86ER`%)E<V5T`%)E<V5T('1O($1E9F%U;'1S`%)E='5R;B!T;R!/
M<'1I;VYS`%)O;&4`4V$`4V%T=7)D87D`4V%V92!!<R!.97<`4V%V92!%=F5N
M=`!3879E($]P=&EO;G,`4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H
M;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@
M9&5F875L="!V:65W+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T
M.@!396QE8W0@=&AE(&9I<G-T('=E96MD87DZ`%-E;&5C="!T:&4@=&EM92!F
M;W)M870Z`%-E;&5C="!T:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+@!396YD(%!R;V)L96T@4F5P;W)T`%-E<'1E
M;6)E<@!3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_`%-H;W<@;VYL
M>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\`4VMI<"!-86EN=&5N
M86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=&%R="!$871E`%-T87)T
M($]N`%-T87)T(%1I;64`4W4`4W5C8V5S<P!3=6YD87D`5&%S:W,`5&@`5&AE
M(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A<G0@9&%T92X`
M5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@97AP;W)T+@!4:'5R<V1A>0!4:71L
M90!4;V1A>0!4=0!4=65S9&%Y`%1Y<&4`56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S97(@26YT97)F86-E
M`%5S97)N86UE`%5S97)S(&EN('1H92!S>7-T96TZ`%=A<FYI;F<`5V4`5V5D
M;F5S9&%Y`%=E96L`5V5E:R`E9`!7965K*',I`%=E96ML>0!7965K;'DZ(%)E
M8W5R<R!E=F5R>0!796QC;VUE+"`E<P!7:&%T('1I;64@<VAO=6QD(&1A>2!A
M;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V
M96YT<S\`5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@<W1A
M<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/P!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!7;W)K(%=E96L`65D`665A<FQY`%EE87)L>3H@
M4F5C=7)S(&5V97)Y`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`6U!R;V)L96T@4F5P;W)T70!D87D`9&%Y*',I`&1A>7,`;6]N=&@H
M<RD`;VX@=&AE('-A;64@9&%T90!O;B!T:&4@<V%M92!W965K9&%Y`'=E96L`
M=V5E:RAS*2!O;CH`=V5E:W,`>65A<BAS*0!0<F]J96-T+4ED+59E<G-I;VXZ
M($MR;VYO;&ET:"`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP-2TR,B`Q-#HQ
M,BLP,C`P"DQA<W0M5')A;G-L871O<CH@36%R=&EN($QI<W0M4&5T97)S96X@
M/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K/@I,86YG=6%G92U496%M.B!$86YI
M<V@@/&1K+6AO<F1E0&AU;'!S>7-T96US+FYE=#X*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y
M+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"5S(%9E9&QI
M9V5H;VQD96QS92`M($)E:W+F9G1E;'-E`"5S(&9I;"!S=6-C97-F=6QD="!I
M;7!O<G1E<F5T`#(T('1I;65R`$%-+U!-`%1I;&;X:B!!9G1A;&4`5&EL9OAJ
M(&YY(&%F=&%L90!/<')E='1E(&5N(&YY(&)R=6=E<CH`3W!R970@<&%R`$]P
M<F5T(&)R=6=E<@!/<')E='1E;'-E(&%F(&)R=6=E<F4@97(@<VSE970@9G)A
M`$%D<F5S<V4`061M:6YI<W1R871I;VX`06QA<FT`06QA<FT@1&%T;P!!;&%R
M;2!687)I9VAE9"`H;6EN=71T97(I`$%L87)M(%1I9`!+86QD96YA=FX`06QL
M90!(96QE(&1A9V5N`$AE;&5D86=S869T86QE`$%L;&4@869T86QE<@!!<')I
M;`!+;"X`075G=7-T`$9E;'1E<B!T:6P@<N5D:6=H960Z`$;X9'-E;'-D86<`
M06YN=6QL97(`069B<GED(')E<&]R=&5R:6YG(&%F('!R;V)L96T`2V%T96=O
M<FD`36]B:6P`3'5K('9I;F1U90!&:7)M80!"96MRYF9T(&MO9&5O<F0`0F5K
M<N9F="!A;FYU;&QE<FEN9R!A9B!A9G1A;&5R/P!+=6YN92!I:VME(.5B;F4@
M;6]D=6P@=&EL('9E9&QI9V5H;VQD96QS92`E<P!/<')E="!.>2!!9G1A;&4`
M06MT=65L`$1$`$1A9VQI9P!$86=L:6<Z($=E;G1A9V5S(&AV97(`1&%G`$1A
M9RAE*0!$96-E;6)E<@!3=&%N9&%R9"UI9&5N=&ET970`4VQE=`!3;&5T("5S
M`%-L970@069T86QE`%-L970@:W5N(&1E;FYE(&%F=&%L92P@9&5N;F4@;V<@
M86QL92!T:6QH^')E;F1E(&9R96UT:61I9V4@869T86QE<BP@96QL97(@86QL
M92!T:6QH^')E;F1E(&%F=&%L97(_`$)E<VMR:78@<')O8FQE;65T`$)E<VMR
M:79E;'-E`$EN9'-T:6QL:6YG97)N92!F;W(@=FES;FEN9P!$=2!MY2!I:VME
M(&MA;&1E(&UA:6YT96YA;F-E+G!H<"!D:7)E:W1E`$9O<F9A;&1E;CH@)7,`
M5F%R:6=H960`4F5T`%)E="`E<P!E36%I;`!);G1E="!R97-U;'1A="X`4VQU
M='1E<B!D96X`4VQU='1E<B!D96X`4VQU='1E<B!+;"X`1F5J;`!!;'1I9"!V
M960@;&]G:6X`16MS96UP96QVYG)D:65R.@!%:W-P;W)TZ7(`16MS<&]R=.ER
M($MA;&5N9&5R`$MU;FYE(&EK:V4@9N4@9F]R8FEN9&5L<V4@=&EL($Q$05`@
M<V5R=F5R96XN`$9A>`!&96)R=6%R`$9I;&CE;F1T97)I;F<`1G)E`$9R961A
M9P!&<F5M=&ED:6<`4W!I;`!(:N9L<`!!9')E<W-E("AH:F5M*0!496QE9F]N
M("AH:F5M*0!(;W)D90!4:6UE*'(I`$EM<&]R=.ER+T5K<W!O<G3I<B!+86QE
M;F1E<@!);7!O<G1E<F5D92!F96QT97(Z("5S`$EM<&]R=&5R961E(&9E;'1E
M<CH`2F%N=6%R`$IU;&D`2G5N:0!.^&=L96]R9&5R`%-I9'-T92!U9V4`0F5G
M<N9N<R!T:61S<G5M;65T(&9O<B!D:6X@96MS<&]R=#H`3W!L:7-T;FEN9R!A
M9B!H:N9L<&5E;6YE<@!6:7-N:6YG(&%F(&)R=6=E<F4@97(@<VSE970@9G)A
M+@!3=&5D`$QO9R!I;F0`3&]G('5D`$U-`$UA:6P`36%R=',`3W9E<F5N<W!A
M<W-E;F1E(&9E;'1E<@!-86H`3?AD90!-961D96QE;'-E`$UI;G5T*'1E<BD`
M36%N`$UA;F1A9P!-Y6YE9`!-Y6YE9&QI9P!-Y6YE9&QI9SH@1V5N=&%G97,@
M:'9E<@!.971VYG)K`$YY($%F=&%L90!.>6AE9&5R`$[F<W1E($WE;F5D`$[F
M<W1E(&1A9P!.YG-T92!U9V4`26YG96X@<VQU="!D871O`$EN9V5N`$YO=&5R
M`$YO=F5M8F5R`$]K=&]B97(`2V]D96]R9`!+;V1E;W)D96YE('-K86P@=N9R
M92!E;G,N`$9R96MV96YS`%5D9OAR('9E9&QI9V5H;VQD96QS90!3;&5T(&1E
M;FYE(&%F=&%L92!U:6=E;FMA;&1E;&EG=#\`5&5L969O;@!3:W)I=B!V96YL
M:6=S="P@:'9A9"!P<F]B;&5M970@9^5R('5D('#E(&]G(&AV860@9&5R('-K
M97(N`$EN9'1A<W0@=F5N;&EG<W0@8G)U9V5R;F%V;B!O9R!K;V1E;W)D`$9O
M<F5GY65N9&4@9&%G`%!R;V)L96UB97-K<FEV96QS90!'96YT86=E<R!T:6P`
M1V5N=&%G96QS92!$871A`$=E;G1A9V5L<V4@4VQU="!$871O`$=E;G1A9V5L
M<V4@26YT97)V86P`1V5N=&%G96QS92!4>7!E`$=E;G1A9V5S(&1A9VQI9W0`
M1V5N=&%G97,@;>5N961L:6=T`$=E;G1A9V5S('5G96YT;&EG`$=E;G1A9V5S
M(.5R;&EG=`!3;&5T('!A<@!.=6QS=&EL`%1I;&)A9V4@=&EL('-T86YD87)D
M:6YD<W1I;&QI;F=E<@!4:6QB86=E('1I;"!I;F1S=&EL;&EN9V5R;F4`4F5G
M96P`3/AR`$SX<F1A9P!'96T@<V]M(&YY`$=E;2!A9G1A;&4`1V5M;64@26YD
M<W1I;&QI;F=E<@!6YFQG(&)E:W+F9G1E;'-E<BP@:'9O<F1A;B!M86X@=FES
M97(@9F]R<VME;&QI9V4@;W9E<G-I9W1E<BP@;V<@=N9L9R!S=&%N9&%R9&]V
M97)S:6=T96XN`%;F;&<@9&%T;RUA9'-K:6QL97)E;CH`5N9L9R!D871O9F]R
M;6%T.@!6YFQG(&9I;"!T:6P@:6UP;W)T97)I;F<Z`%;F;&<@9OAR<W1E('5G
M961A9SH`5N9L9R!T:61S9F]R;6%T.@!6YFQG('1I9'-V87)I9VAE9"!D97(@
M<VMA;"!V:7-E<SH`5N9L9R!T;R!F96QT97(L(&1E<B!S=F%R97(@=&EL(&AI
M;F%N9&5N+@!396YD('!R;V)L96UB97-K<FEV96QS90!397!T96UB97(`5FES
M(&9O<F5F86QD96YD92!O<&=A=F5R(&D@:V%L96YD97(_`%9I<R!K=6X@869T
M86QE<B!S;VT@97(@;65D(&%L87)M/P!3<')I;F<@=F5D;&EG96AO;&1E;'-E
M(&]V97(`26YD=&%S=&YI;F<@9F]R('-P96-I86QK87)A:W1E<@!3=&%R="!D
M871O`%-T87)T(&1E;@!3=&%R="!T:60`4_AN`$QY:VME9&5S`%/X;F1A9P!/
M<&=A=F5R`%1O<@!3;'5T9&%T;R!S:V%L(';F<F4@<V5N97)E(&5N9"!S=&%R
M=&1A=&\N`$1E<B!V87(@:6YG96X@869T86QE<B!A="!E:W-P;W)T97)E+@!4
M;W)S9&%G`%1I=&5L`$D@1&%G`%1I<@!4:7)S9&%G`%1Y<&4`2W5N;F4@:6MK
M92!O=F5R<^9T=&4@9&5T=&4@5V]R9"!D;VMU;65N=`!&;W)T<GED(.9N9')I
M;F=E<@!"<G5G97)G<N9N<V5F;&%D90!"<G5G97)N879N`$)R=6=E<F4@:2!S
M>7-T96UE=#H`061V87)S96P`3VYS`$]N<V1A9P!59V4`56=E("5D`%5G92AR
M*0!59V5N=&QI9P!59V5N;&EG.B!'96YT86=E<R!H=F5R`%9E;&MO;6UE;BP@
M)7,`2'9A9"!T:60@<VMA;"!D86<@;V<@=6=E(&]V97)S:6=T97(@96YD92!M
M960L(&[E<B!D97(@:6MK92!E<B!S96YE<F4@869T86QE<C\`2'9A9"!T:60@
M<VMA;"!D86<@;V<@=6=E(&]V97)S:6=T97(@<W1A<G1E(&UE9"P@;N5R(&1E
M<B!I:VME(&5R('1I9&QI9V5R92!A9G1A;&5R/P!!9')E<W-E("AA<F)E:F1E
M*0!496QE9F]N("AA<F)E:F1E*0!!<F)E:F1S=6=E`,7%`,5R;&EG`,5R;&EG
M.B!'96YT86=E<R!H=F5R`$1U(&)L:79E<B!N^&0@=&EL(&%T(&QA=F4@96X@
M<')O8FQE;6)E<VMR:79E;'-E+"!F^'(@9'4@:V%N('-E;F1E(&1E;B!I;F0N
M`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!F:F5R
M;F4N`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!T
M:6QF^&IE+@!$:6X@875T;W)I<V%T:6]N<RUB86-K96YD('5N9&5R<W3X='1E
M<B!I:VME(&]P;&ES=&YI;F=E;B!A9B!B<G5G97)E(&5L;&5R(&5R(&1E;B!F
M=6YK=&EO;B!A9B!E;B!E;&QE<B!A;F1E;B!G<G5N9"!B;&5V970@<VSE970@
M9G)A+@!;4')O8FQE;6)E<VMR:79E;'-E70!D86<`9&%G*&4I`&1A9V4`;>5N
M960H97(I(`!PY2!S86UM92!D871O`'#E('-A;6UE('5G961A9P!U9V4`=6=E
M*'(I('#E.@!U9V5R`.5R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C
M86QE+V1E7T1%+P``````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S4P`#`R,#8S,0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]L;V-A;&4O9&5?1$4O3$-?34534T%'15,O````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``,#(R-#$V`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]D95]$12],
M0U]-15-304=%4R]K<F]N;VQI=&@N;6\`````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#4Q,C,U,0`Q,#0Q
M-S,V,C<U,``P,C0W-S``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````WA($E0````#N"```'````(Q'``#I"P``_(X```````"@
MO@``#@```*&^```/````L+X```T```#`O@``"````,Z^```+````U[X```P`
M``#CO@``!````/"^```8````];X``!L````.OP``+0```"J_```=````6+\`
M`"0```!VOP``*0```)N_```9````Q;\``"8```#?OP``#`````;````2````
M$\```"0````FP```"0```$O````/````5<````L```!EP```'P```''````.
M````D<````4```"@P```*````*;````(````S\````H```#8P```%0```./`
M```2````^<````L````,P0``#````!C!```=````)<$``(4```!#P0``#@``
M`,G!```*````V,$```T```#CP0``#@```/'!```1`````,(```T````2P@``
M#````"#"```-````+<(```8````[P@``E````$+"``!/````U\(``!T````G
MPP``'0```$7#```*````8\,```\```!NPP``&````'[#```,````E\,```H`
M``"DPP``!P```*_#```&````M\,```X```"^PP``"@```,W#```*````V,,`
M``X```#CPP``"````/+#```*````^\,```D````&Q```)0```!#$```H````
M-L0``"0```!?Q```)@```(3$```N````J\0``!H```#:Q```,@```/7$```X
M````*,4``%0```!AQ0``40```+;%``!:````",8``%<```!CQ@``-````+O&
M```"````\,8```D```#SQ@``#0```/W&```'````"\<```H````3QP``#P``
M`!['```%````+L<```8````TQP``$0```#O'```(````3<<```D```!6QP``
M"0```&#'```(````:L<``"4```!SQP``(````)G'```3````NL<``!````#.
MQP``#P```-_'```*````[\<``!````#ZQP```P````O(```/````#\@``!0`
M```?R```"0```#3(```)````/L@```T```!(R```$@```%;(```9````:<@`
M`!X```"#R```&0```*+(```/````O,@```\```#,R```#0```-S(```*````
MZL@```\```#UR```"`````7)```D````#LD``!0````SR0``$````$C)```6
M````6<D```@```!PR0``3@```'G)```M````R,D``!D```#VR0``!P```!#*
M```,````&,H``"P````ER@``#@```%+*```#````8<H```\```!ER@``"P``
M`'7*```%````@<H``!0```"'R@``%0```)S*```7````LLH``!4```#*R@``
M$@```.#*```3````\\H``!4````'RP``$P```!W+```*````,<L``!0````\
MRP``"@```%'+```'````7,L```<```!DRP``!0```&S+```%````<LL```H`
M``!XRP```P```(/+```-````A\L``!<```"5RP``"@```*W+```*````N,L`
M``@```##RP``#P```,S+```+````W,L```<```#HRP``#0```/#+```*````
M_LL```X````)S```&````!C,```C````,<P```X```!5S```%````&3,```7
M````><P``!<```"1S```%P```*G,```3````P<P```\```#5S```#@```.7,
M```?````],P``!T````4S0``!P```#+-```&````.LT```@```!!S0``#P``
M`$K-```&````6LT```H```!AS0``$P```&S-```#````@,T```L```"$S0``
M$````)#-```5````H<T``!4```"WS0``!P```,W-```0````U<T```4```#F
MS0``%0```.S-```1`````LX```P````4S@``.P```"'.```X````7<X```D`
M``"6S@``!P```*#.```4````J,X```,```"]S@``!0```,'.```0````Q\X`
M``D```#8S@``$P```.+.```Y````]LX``!(````PSP```@```$//``"T````
M1L\``"<```#[SP``+````"/0```J````4-```"4```![T```"@```*'0```)
M````K-````H```"VT```!@```,'0```)````R-````<```#2T```+P```-K0
M```W````"M$``"X```!"T0``50```''1```M````Q]$``"T```#UT0``/0``
M`"/2```_````8=(``"T```"AT@``0````,_2```C````$-,``",````TTP``
M0````%C3```M````F=,``#,```#'TP``)0```/O3```5````(=0``!D````W
MU```*0```%'4```D````>]0``"@```"@U```$0```,G4```*````V]0```P`
M``#FU```"@```//4```0````_M0``!8````/U0``%@```";5```'````/=4`
M``<```!%U0``%````$W5```*````8M4```@```!MU0``)P```';5```(````
MGM4```P```"GU0``!P```+35```'````O-4```8```#$U0``!0```,O5```'
M````T=4```8```#9U0``"````.#5```I````Z=4```X````3U@``"@```"+6
M```$````+=8```<````RU@``"0```#K6```&````1-8``!$```!+U@``!P``
M`%W6```6````9=8```0```!\U@``"````('6```&````BM8```T```"1U@``
M!@```)_6```>````IM8``!$```#%U@``"````-?6```-````X-8```P```#N
MU@``!P```/O6```$`````]<```,````(UP```P````S7```7````$-<```D`
M```HUP``$P```#+7```=````1M<```D```!DUP``"````&[7```0````=]<`
M`!T```"(UP``"0```*;7```;````L-<```0```#,UP``"````-'7```(````
MVM<``$$```#CUP``&@```"78```K````0-@``"````!LV```&0```(W8```5
M````I]@```8```"]V```!@```,38```5````R]@```D```#AV```#0```.O8
M```8````^=@``"(````2V0``+@```#79```=````9-D``"$```""V0``5```
M`*39```I````^=D```H````CV@``!P```"[:```'````-MH```D````^V@``
M%0```$C:```(````7MH```X```!GV@``"@```';:```/````@=H```T```"1
MV@``#P```)_:```-````K]H```D```"]V@``%````,?:```&````W-H``!@`
M``#CV@``'0```/S:```3````&ML``!$````NVP``%````$#;```$````5=L`
M``8```!:VP``%````&';``!4````=ML``&0```#+VP``!````##<```.````
M-=P```4```!$W```!0```$K<```;````4-P``!H```!LW```$P```(?<```1
M````F]P``!$```"MW```'````+_<``!.````W-P``$4````KW0``10```''=
M```J````M]T``#8```#BW0``/@```!G>```_````6-X``!T```"8W@``$```
M`+;>```A````Q]X```4```#IW@``$P```._>```+`````]\``!,````/WP``
M$@```"/?```*````-M\```\```!!WP``#0```%'?```1````7]\``!,```!Q
MWP``#````(7?```,````DM\```8```"?WP``#````*;?```&````L]\``!<`
M``"ZWP``$````-+?```1````X]\```@```#UWP``!0```/[?```,````!.``
M`!`````1X```!0```"+@```-````*.````8````VX```%@```#W@```'````
M5.````T```!<X```!P```&K@```+````<N````<```!^X```!P```(;@```)
M````CN````D```"8X```"@```*+@```9````K>```#T```#'X```'0````7A
M```,````(^$``!`````PX0``&P```$'A```)````7>$```4```!GX0``)0``
M`&WA```2````D^$``!,```"FX0``*P```+KA```[````YN$``"`````BX@``
M"````$/B```V````3.(``"$```"#X@``$````*7B```(````MN(```P```"_
MX@``!@```,SB```$````T^(```\```#8X@``#@```.CB``!`````]^(```<`
M```XXP``"@```$#C```-````2^,``!\```!9XP``'````'GC```A````EN,`
M`!X```"XXP``&0```-?C```>````\>,``!L````0Y```(0```"SD```N````
M3N0``"8```!]Y```'````*3D```>````P>0``!P```#@Y```)@```/WD```K
M````).4``#,```!0Y0``)@```(3E```K````J^4``#@```#7Y0``'0```!#F
M```5````+N8``"\```!$Y@``(````'3F```2````E>8``"D```"HY@``'@``
M`-+F```@````\>8``!(````2YP``H@```"7G```6````R.<``",```#?YP``
M*`````/H```I````+.@``"@```!6Z```'P```'_H```5````G^@``"````"U
MZ```)0```-;H```H````_.@``"T````EZ0``,````%/I``"2````A.D``"$`
M```7Z@``%@```#GJ```<````4.H``"8```!MZ@``*@```)3J``!!````O^H`
M`$0````!ZP``#````$;K```'````4^L```<```!;ZP``!@```&/K```/````
M:NL``!(```!ZZP``#0```(WK```0````F^L``!(```"LZP``!P```+_K```3
M````Q^L``!(```#;ZP``!P```.[K```$````]NL```<```#[ZP``$`````/L
M```0````%.P```P````E[```#@```#+L```-````0>P```\```!/[```$P``
M`%_L```-````<^P``"@```"![````P```*KL```-````KNP```8```"\[```
M$0```,/L```7````U>P``!L```#M[```#@````GM```"````&.T``$D````;
M[0``!0```&7M```3````:^T``!````!_[0``#P```)#M```$````H.T```T`
M``"E[0``#@```+/M```#````PNT```8```#&[0``!P```,WM```.````U>T`
M``@```#D[0``#P```.WM```(````_>T```\````&[@``!P```!;N```0````
M'NX```T````O[@``$````#WN```-````3NX```L```!<[@``!@```&CN```)
M````;^X```L```!Y[@``#````(7N```,````DNX```H```"?[@``$0```*KN
M```9````O.X```L```#6[@``#0```.+N```B````\.X```\````3[P``&P``
M`"/O```T````/^\```H```!T[P``&````'_O```2````F.\``!D```"K[P``
M7````,7O```6````(O```"(````Y\```#0```%SP```'````:O````P```!R
M\```%````'_P```+````E/```"(```"@\```+P```,/P```+````\_````D`
M``#_\```&0````GQ```+````(_$``!<````O\0``%P```$?Q```)````7_$`
M``<```!I\0``%@```''Q```1````B/$```\```":\0``&0```*KQ```6````
MQ/$```X```#;\0``&````.KQ```(`````_(```T````,\@``)@```!KR```Y
M````0?(```X```![\@``0P```(KR```(````SO(``!(```#7\@``'P```.KR
M```(````"O,```L````3\P``+P```!_S```.````3_,```4```!>\P``!P``
M`&3S```(````;/,```8```!U\P``10```'SS```#````PO,```<```#&\P``
M!````,[S```'````T_,```X```#;\P``"@```.KS```.````]?,```H````$
M]```#P````_T```0````'_0``!<````P]```%0```$CT```.````7O0``!H`
M``!M]```$0```(CT```9````FO0``!<```"T]```"0```,ST```%````UO0`
M``L```#<]```"@```.CT```"````\_0```4```#V]```#0```/ST```;````
M"O4``!<````F]0``%````#[U```)````4_4```X```!=]0``#0```&SU```2
M````>O4```0```"-]0``.````)+U```@````R_4```@```#L]0``!@```/7U
M```(````_/4```@````%]@``#@````[V``![````'?8``!@```"9]@``&```
M`++V```1````R_8```<```#=]@``!0```.7V```8````Z_8``!X````$]P``
M&P```"/W```9````/_<``#$```!9]P``&P```(OW```9````I_<``!,```#!
M]P``!P```-7W```(````W?<```8```#F]P``!@```.WW```,````]/<```X`
M```!^```#0```!#X```3````'O@```\````R^```'@```$+X```9````8?@`
M`!````![^```#P```(SX```0````G/@```\```"M^```"P```+WX```/````
MR?@```P```#9^```#P```.;X```'````]O@```8```#^^```#`````7Y```.
M````$OD```P````A^0``*````"[Y```/````5_D```@```!G^0``!@```'#Y
M```/````=_D```@```"'^0``$P```)#Y```>````I/D``"$```##^0``(```
M`.7Y```9````!OH``!<````@^@``)0```#CZ```7````7OH``!8```!V^@``
M!````(WZ```;````DOH```T```"N^@``#````+SZ```#````R?H```4```#-
M^@``"````-/Z```*````W/H```P```#G^@``"P```/3Z```0`````/L```P`
M```1^P``#@```![[```+````+?L```0````Y^P``!````#[[```3````0_L`
M`!0```!7^P``#````&S[```)````>?L```X```"#^P``"P```)+[```;````
MGOL```<```"Z^P``!````,+[```'````Q_L```H```#/^P``#0```-K[```)
M````Z/L```0```#R^P``!0```/?[```#````_?L``!@````!_```"@```!K\
M```$````)?P``"8````J_```#@```%'\``!\````8/P``!4```#=_```!0``
M`//\```'````^?P```P````!_0``"`````[]```*````%_T```8````B_0``
M"````"G]```"````,OT```8````U_0``!@```#S]```4````0_T```0```!8
M_0``%0```%W]```-````<_T``!````"!_0``&P```)+]```&````KOT```0`
M``"U_0``"0```+K]```0````Q/T```D```#5_0``"0```-_]```&````Z?T`
M``4```#P_0``&@```/;]```(````$?X```8````:_@``!````"'^```'````
M)OX``!D````N_@``#@```$C^```'````5_X```<```!?_@``!0```&?^```)
M````;?X```H```!W_@``#@```(+^```"````D?X```8```"4_@``"P```)O^
M```-````I_X```<```"U_@``"0```+W^```&````Q_X``!(```#._@``"0``
M`.'^```'````Z_X``!0```#S_@``'0````C_``!"````)O\``"4```!I_P``
M)0```(__```&````M?\```H```"\_P``!````,?_```)````S/\```@```#6
M_P``$0```-__```)````\?\```8```#[_P``#0````(``0`&````$``!``0`
M```7``$`.0```!P``0`]````5@`!`#H```"4``$`'@```,\``0`%````[@`!
M``X```#T``$`!`````,!`0`&````"`$!``<````/`0$`(0```!<!`0`-````
M.0$!`!4```!'`0$`!@```%T!`0`$````9`$!`!$```!I`0$`!@```'L!`0`*
M````@@$!`"(```"-`0$`!````+`!`0`'````M0$!``0```"]`0$`!0```,(!
M`0`=````R`$!``0```#F`0$`#````.L!`0`.````^`$!``H````'`@$`"```
M`!("`0`)````&P(!``4````E`@$`.@```"L"`0`P````9@(!`#4```"7`@$`
M*0```,T"`0!'````]P(!`#@````_`P$`*0```'@#`0`_````H@,!`"X```#B
M`P$`+0```!$$`0`?````/P0!``\```!?!`$`$@```&\$`0`+````@@0!``<`
M``".!`$`)@```)8$`0`\````O00!`"D```#Z!`$`.@```"0%`0`D````7P4!
M`"8```"$!0$`"````*L%`0`*````M`4!``D```"_!0$`!P```,D%`0`@````
MT04!`"````#R!0$`)@```!,&`0`*````.@8!`!D```!%!@$`*0```%\&`0`6
M````B08!`!(```"@!@$`!P```+,&`0`*````NP8!``P```#&!@$`#P```-,&
M`0`0````XP8!`$````#T!@$`<````#4'`0!F````I@<!`-$````-"`$`#@``
M`-\(`0`)````[@@!``H```#X"`$`$@````,)`0`3````%@D!``P````J"0$`
M!@```#<)`0`8````/@D!``\```!7"0$`%@```&<)`0`2````?@D!`!````"1
M"0$`$0```*()`0`<````M`D!`",```#1"0$`:@```/4)`0`/````8`H!``4`
M``!P"@$`$````'8*`0`)````APH!``0```"1"@$`"P```)8*`0`@````H@H!
M`!0```##"@$`#````-@*`0`,````Y0H!``\```#R"@$`%0````(+`0`I````
M&`L!`"H```!""P$`)@```&T+`0`G````E`L!`"D```"\"P$`*@```.8+`0`9
M````$0P!`$(````K#`$`$0```&X,`0`2````@`P!`!,```"3#`$`%````*<,
M`0`/````O`P!`!8```#,#`$`%P```.,,`0`0````^PP!`!$````,#0$`-```
M`!X-`0`3````4PT!`!(```!G#0$`-0```'H-`0`4````L`T!``<```#%#0$`
M#````,T-`0`@````V@T!`!````#[#0$`%`````P.`0`1````(0X!`!<````S
M#@$`'````$L.`0`3````:`X!`!0```!\#@$`&@```)$.`0`1````K`X!`!H`
M``"^#@$`'@```-D.`0`:````^`X!`!,````3#P$`%0```"</`0`1````/0\!
M`!<```!/#P$`%````&</`0`7````?`\!`!4```"4#P$`"0```*H/`0`0````
MM`\!`!D```#%#P$`!````-\/`0`'````Y`\!``L```#L#P$`$0```/@/`0`&
M````"A`!``8````1$`$`!@```!@0`0`%````'Q`!``<````E$`$`!P```"T0
M`0`%````-1`!`!8````[$`$`!@```%(0`0`&````61`!``0```!@$`$`!```
M`&40`0`'````:A`!``X```!R$`$`#````($0`0`,````CA`!``T```";$`$`
M"@```*D0`0`.````M!`!``4```##$`$`*````,D0`0`.````\A`!``P````!
M$0$`#P````X1`0`*````'A$!``@````I$0$`"0```#(1`0`K````/!$!``@`
M``!H$0$`!````'$1`0`(````=A$!`"8```!_$0$`$@```*81`0`/````N1$!
M``8```#)$0$`"@```-`1`0`'````VQ$!``@```#C$0$`(````.P1`0`-````
M#1(!``D````;$@$`#0```"42`0`*````,Q(!`!0````^$@$`#````%,2`0`-
M````8!(!``D```!N$@$`#@```'@2`0`6````AQ(!`!$```">$@$`"0```+`2
M`0`&````NA(!``,```#!$@$`!@```,42`0`9````S!(!``<```#F$@$`!```
M`.X2`0`+````\Q(!``L```#_$@$`!P````L3`0`%````$Q,!``<````9$P$`
M%@```"$3`0`-````.!,!``T```!&$P$`"@```%03`0`0````7Q,!``\```!P
M$P$`$0```(`3`0`7````DA,!``H```"J$P$`$0```+43`0`(````QQ,!`!X`
M``#0$P$`!````.\3`0`/````]!,!`#H````$%`$`!0```#\4`0`,````110!
M`!X```!2%`$`#@```'$4`0`0````@!0!``L```"1%`$`#````)T4`0`)````
MJA0!``<```"T%`$`"@```+P4`0`)````QQ0!``X```#1%`$`$````.`4`0`;
M````\10!`!@````-%0$`&@```"85`0`*````014!``D```!,%0$`"0```%85
M`0`*````8!4!``P```!K%0$`#P```'@5`0`(````B!4!``8```"1%0$`'```
M`)@5`0`'````M14!``4```"]%0$`"P```,,5`0!'````SQ4!``T````7%@$`
M"0```"46`0`$````+Q8!``,````T%@$`$P```#@6`0`3````3!8!`!,```!@
M%@$`"@```'06`0`"````?Q8!``0```""%@$`)0```(<6`0`#````K18!``4`
M``"Q%@$`*@```+<6`0`*````XA8!``4```#M%@$`!````/,6`0`*````^!8!
M``T````#%P$`!@```!$7`0`(````&!<!``@````A%P$`!````"H7`0`%````
M+Q<!`!@````U%P$`:````$X7`0`)````MQ<!``P```#!%P$`$````,X7`0`%
M````WQ<!``8```#E%P$`&P```.P7`0`O````"!@!`!`````X&`$`"@```$D8
M`0`/````5!@!``H```!D&`$`"0```&\8`0`3````>1@!`!L```"-&`$`&```
M`*D8`0`7````PA@!`!@```#:&`$`'P```/,8`0`.````$QD!``,````B&0$`
M!P```"89`0`"````+AD!``@````Q&0$`!P```#H9`0`'````0AD!``L```!*
M&0$`"0```%89`0`*````8!D!``L```!K&0$`!P```'<9`0!1````?QD!`!``
M``#1&0$`#````.(9`0`-````[QD!`!H```#]&0$`2@```!@:`0`9````8QH!
M``8```!]&@$`&@```(0:`0`E````GQH!``8```#%&@$`!@```,P:`0`?````
MTQH!``8```#S&@$`"0```/H:`0`8````!!L!`!<````=&P$`*````#4;`0`)
M````7AL!``8```!H&P$`#0```&\;`0`B````?1L!`%<```"@&P$`$P```/@;
M`0`C````#!P!`!,````P'`$``@```$0<`0`+````1QP!``@```!3'`$`#0``
M`%P<`0`*````:AP!``<```!U'`$`%````'T<`0`&````DAP!``8```"9'`$`
M"````*`<`0`%````J1P!``H```"O'`$`#@```+H<`0`'````R1P!`!,```#1
M'`$`%0```.4<`0`,````^QP!``T````('0$`"@```!8=`0`+````(1T!`#(`
M```M'0$`!P```&`=`0`,````:!T!``T```!U'0$`%P```(,=`0`,````FQT!
M``D```"H'0$`"0```+(=`0`*````O!T!``<```#''0$`"0```,\=`0`'````
MV1T!``H```#A'0$`&P```.P=`0`/````"!X!`$(````8'@$`$@```%L>`0`*
M````;AX!`!8```!Y'@$`#````)`>`0`-````G1X!`!````"K'@$`"0```+P>
M`0`0````QAX!``<```#7'@$`$@```-\>`0`$````\AX!``<```#W'@$`!0``
M`/\>`0`%````!1\!``L````+'P$`%````!<?`0`1````+!\!`!H````^'P$`
M%@```%D?`0`4````<!\!`!<```"%'P$`&````)T?`0`<````MA\!`!D```#3
M'P$`!P```.T?`0`%````]1\!``T```#['P$`#`````D@`0`)````%B`!``@`
M```@(`$`%P```"D@`0`+````02`!`$X```!-(`$`#````)P@`0`?````J2`!
M`!H```#)(`$`$P```.0@`0`$````^"`!``H```#](`$`!`````@A`0`-````
M#2$!``T````;(0$`"````"DA`0`*````,B$!``D````](0$`"0```$<A`0`(
M````42$!``P```!:(0$`"0```&<A`0`%````<2$!``D```!W(0$`!0```($A
M`0`'````AR$!``4```"/(0$`!````)4A`0`"````FB$!``@```"=(0$`#```
M`*8A`0`X````LR$!`"P```#L(0$`$@```!DB`0`I````+"(!`#(```!6(@$`
M)0```(DB`0`*````KR(!`"P```"Z(@$`+@```.<B`0`S````%B,!`#,```!*
M(P$`.````'XC`0`/````MR,!`!@```#'(P$`"P```.`C`0`4````[",!`!``
M```!)`$`+````!(D`0`<````/R0!``\```!<)`$`$P```&PD`0`5````@"0!
M`!0```"6)`$`$@```*LD`0`4````OB0!`!4```#3)`$`+0```.DD`0`M````
M%R4!`#$```!%)0$`+@```'<E`0`O````IB4!`"P```#6)0$`8@````,F`0`3
M````9B8!``T```!Z)@$`#0```(@F`0`(````EB8!`!<```"?)@$`"````+<F
M`0`,````P"8!`"L```#-)@$`(0```/DF`0`:````&R<!`!P````V)P$`"0``
M`%,G`0!%````72<!`$$```"C)P$`!````.4G`0`3````ZB<!`!0```#^)P$`
M#@```!,H`0`3````(B@!`!@````V*`$`!@```$\H`0`)````5B@!``H```!@
M*`$`#P```&LH`0`)````>R@!`!````"%*`$`!P```)8H`0`.````GB@!``4`
M``"M*`$`&P```+,H`0`-````SR@!``@```#=*`$``P```.8H`0`&````ZB@!
M`!0```#Q*`$`$0````8I`0`.````&"D!`#@````G*0$``@```&`I`0`&````
M8RD!``X```!J*0$`!0```'DI`0`'````?RD!``X```"'*0$`!@```)8I`0`H
M````G2D!``P```#&*0$`'````-,I`0`$````\"D!``(```#U*0$`)@```/@I
M`0`6````'RH!`!0````V*@$`*0```$LJ`0`7````=2H!`!\```"-*@$`7```
M`*TJ`0`4````"BL!`#X````?*P$`'P```%XK`0`0````?BL!``@```"/*P$`
M$@```)@K`0`'````JRL!``X```"S*P$`#````,(K`0`,````SRL!`!,```#<
M*P$`"@```/`K`0`=````^RL!`!D````9+`$`!0```#,L`0`1````.2P!``@`
M``!++`$`!0```%0L`0`1````6BP!``D```!L+`$`)````'8L`0`2````FRP!
M`!4```"N+`$`$@```,0L`0`.````URP!`!D```#F+`$`"``````M`0`)````
M"2T!``(````3+0$`#0```!8M`0`'````)"T!``H````L+0$`!P```#<M`0`/
M````/RT!``8```!/+0$`"P```%8M`0`:````8BT!``H```!]+0$`!P```(@M
M`0`(````D"T!``4```"9+0$`'P```)\M`0`&````ORT!`!````#&+0$`"```
M`-<M`0`-````X"T!``@```#N+0$`'@```/<M`0`2````%BX!`"P````I+@$`
M&@```%8N`0`)````<2X!``H```![+@$`%0```(8N`0`0````G"X!``4```"M
M+@$`%````+,N`0`$````R"X!``<```#-+@$`$````-4N`0`&````YBX!``<`
M``#M+@$`'@```/4N`0`H````%"\!`!X````]+P$`"@```%PO`0`<````9R\!
M`!$```"$+P$`"P```)8O`0`:````HB\!`!0```"]+P$`!````-(O`0`$````
MUR\!``L```#<+P$`!0```.@O`0`&````[B\!``@```#U+P$`!@```/XO`0`*
M````!3`!`!L````0,`$`-````"PP`0`T````83`!`"````"6,`$`*0```+<P
M`0`@````X3`!`$$````",0$`&@```$0Q`0`H````7S$!`"D```"(,0$`4```
M`+(Q`0`B`````S(!``8````F,@$`"````"TR`0`%````-C(!``X````\,@$`
M"````$LR`0`9````5#(!`!D```!N,@$`*@```(@R`0`C````LS(!`!D```#7
M,@$`+@```/$R`0`T````(#,!``@```!5,P$`%P```%XS`0`*````=C,!``<`
M``"!,P$`(0```(DS`0`,````JS,!``T```"X,P$`#````,8S`0`0````TS,!
M``X```#D,P$`"P```/,S`0`'````_S,!`!,````'-`$`"````!LT`0`+````
M)#0!``H````P-`$`%````#LT`0`/````4#0!`#(```!@-`$`"P```),T`0`.
M````GS0!``4```"N-`$`!0```+0T`0`%````NC0!`!<```#`-`$`#P```-@T
M`0`$````Z#0!``H```#M-`$`"0```/@T`0`+`````C4!``T````.-0$`#```
M`!PU`0`.````*34!``4````X-0$`!````#XU`0`-````0S4!`#(```!1-0$`
M10```(0U`0`+````RC4!``H```#6-0$`#P```.$U`0`3````\34!`!,````%
M-@$`#P```!DV`0`,````*38!``X````V-@$`#0```$4V`0`-````4S8!`!<`
M``!A-@$`!P```'DV`0`>````@38!`!0```"@-@$`!0```+4V`0`4````NS8!
M``8```#0-@$`!P```-<V`0`,````WS8!`!````#L-@$`$0```/TV`0`.````
M#S<!`!<````>-P$`*@```#8W`0`&````83<!``D```!H-P$`#P```'(W`0`,
M````@C<!``T```"/-P$`$0```)TW`0`+````KS<!`#8```"[-P$`"@```/(W
M`0`B````_3<!``L````@.`$`#P```"PX`0!]````/#@!`#(```"Z.`$`)0``
M`.TX`0`(````$SD!`#`````<.0$`,0```$TY`0`M````?SD!`!(```"M.0$`
M#@```,`Y`0`%````SSD!``X```#5.0$`$P```.0Y`0`1````^#D!``@````*
M.@$`$@```!,Z`0`'````)CH!`!$````N.@$`$P```$`Z`0`'````5#H!`!0`
M``!<.@$`&````'$Z`0`'````BCH!``4```"2.@$`#````)@Z`0`,````I3H!
M`!(```"R.@$`!````,4Z`0`'````RCH!``H```#2.@$`"P```-TZ`0`,````
MZ3H!``X```#V.@$`#@````4[`0`%````%#L!``4````:.P$`+@```"`[`0`F
M````3SL!`",```!V.P$``P```)H[`0`2````GCL!``8```"Q.P$`'@```+@[
M`0`8````USL!`"4```#P.P$`#0```!8\`0`)````)#P!`!\````N/`$``P``
M`$X\`0`'````4CP!``H```!:/`$``@```&4\`0`,````:#P!`!4```!U/`$`
M"P```(L\`0`9````ESP!`"````"Q/`$`$@```-(\`0`%````Y3P!``H```#K
M/`$`%0```/8\`0`2````##T!``@````?/0$`#````"@]`0`$````-3T!``D`
M```Z/0$`!P```$0]`0`+````3#T!``X```!8/0$`"@```&<]`0`,````<CT!
M`%(```!_/0$`%P```-(]`0`D````ZCT!`!(````//@$`!P```"(^`0`&````
M*CX!`!`````Q/@$`#@```$(^`0`.````43X!`"````!@/@$`#````($^`0`9
M````CCX!``T```"H/@$`%0```+8^`0`2````S#X!``\```#?/@$`%````.\^
M`0`*````!#\!`!L````//P$`$````"L_`0`<````/#\!`%@```!9/P$`"P``
M`+(_`0`A````OC\!`"4```#@/P$`:0````9``0`:````<$`!`!<```"+0`$`
M&0```*-``0`:````O4`!`!D```#80`$`)0```/)``0`G````&$$!`!H```!`
M00$`%P```%M!`0`=````<T$!`"8```"100$`&P```+A!`0`J````U$$!`!D`
M``#_00$`'P```!E"`0`3````.4(!``@```!-0@$`1````%9"`0`3````FT(!
M`$````"O0@$`!P```/!"`0`(````^$(!``D````!0P$`%0````M#`0`-````
M(4,!`",````O0P$`#0```%-#`0`3````84,!``@```!U0P$``P```'Y#`0`,
M````@D,!`$8```"/0P$`%P```-9#`0`.````[D,!`#\```#]0P$`30```#U$
M`0`W````BT0!`%<```##1`$`!0```!M%`0`?````(44!`"\```!!10$`"@``
M`'%%`0`3````?$4!`!````"010$`$0```*%%`0`(````LT4!``T```"\10$`
M+0```,I%`0`$````^$4!``T```#]10$`%0````M&`0`[````(48!`$\```!=
M1@$`'P```*U&`0`6````S48!`"4```#D1@$`*`````I'`0`<````,T<!``L`
M``!01P$`(P```%Q'`0`?````@$<!`"$```"@1P$`'0```,)'`0`E````X$<!
M`"`````&2`$`)````"=(`0`@````3$@!`#````!M2`$`"P```)Y(`0`'````
MJD@!``T```"R2`$`#````,!(`0`7````S4@!``8```#E2`$`.0```.Q(`0`,
M````)DD!``<````S20$`"0```#M)`0`3````14D!``D```!920$`!````&-)
M`0`0````:$D!``@```!Y20$`"````())`0`$````BTD!``L```"020$`#```
M`)Q)`0`2````J4D!`!$```"\20$`#````,Y)`0`:````VTD!``\```#V20$`
M!P````9*`0`-````#DH!`!0````<2@$`#@```#%*`0`,````0$H!`!L```!-
M2@$`+````&E*`0`3````EDH!`!P```"J2@$`*````,=*`0`&````\$H!``<`
M``#W2@$`$P```/]*`0`%````$TL!``0````92P$`%P```!Y+`0`*````-DL!
M``P```!!2P$`"0```$Y+`0`&````6$L!``D```!?2P$`!@```&E+`0`(````
M<$L!``D```!Y2P$`"@```(-+`0`(````CDL!``H```"72P$`"@```*)+`0`'
M````K4L!`!$```"U2P$`!@```,=+`0`.````SDL!``X```#=2P$`#0```.Q+
M`0`+````^DL!`!T````&3`$`"P```"1,`0`"````,$P!`!P````S3`$`!P``
M`%!,`0`&````6$P!`&0```!?3`$`"0```,1,`0`'````SDP!`"8```#63`$`
M.````/U,`0`:````-DT!`"H```!130$`.P```'Q-`0`H````N$T!`#0```#A
M30$`&0```!9.`0`5````,$X!``4```!&3@$`!P```$Q.`0`(````5$X!``<`
M``!=3@$`!@```&5.`0`%````;$X!``<```!R3@$`#@```'I.`0`)````B4X!
M``8```"33@$`"````)I.`0`+````HTX!``<```"O3@$`"````+=.`0`'````
MP$X!`!8```#(3@$`"0```-].`0`&````Z4X!``L```#P3@$`$````/Q.`0`&
M````#4\!`!P````43P$`%````#%/`0`'````1D\!`!$```!.3P$`"````&!/
M`0`.````:4\!``@```!X3P$`$````(%/`0`)````DD\!`!````"<3P$`!@``
M`*U/`0`9````M$\!``H```#.3P$`'````-E/`0`'````]D\!``4```#^3P$`
M$`````10`0`4````%5`!``L````J4`$`#0```#90`0`H````1%`!`!@```!M
M4`$`%P```(90`0`)````GE`!``0```"H4`$`"0```*U0`0`*````MU`!``<`
M``#"4`$``@```,I0`0`.````S5`!``@```#<4`$`.````.50`0`C````'E$!
M`!\```!"40$`.````&)1`0`F````FU$!`#$```#"40$`)P```/11`0!D````
M'%(!`!0```"!4@$`)````)92`0`C````NU(!`",```#?4@$`*P````-3`0`A
M````+U,!`"0```!14P$`50```'93`0`X````S%,!`$H````%5`$`6P```%!4
M`0`H````K%0!`#@```#55`$`+P````Y5`0!%````/E4!`$H```"$50$`1@``
M`,]5`0`S````%E8!`"@```!*5@$`+````'-6`0`F````H%8!`!L```#'5@$`
M/@```.-6`0`Z````(E<!`*D!``!=5P$`(P````=9`0`7````*UD!`$@```!#
M60$`A0```(Q9`0`P````$EH!`"4```!#6@$`00```&E:`0!;````JUH!`$D`
M```'6P$`,0```%%;`0!I````@UL!`!T```#M6P$`&`````M<`0`K````)%P!
M`"$```!07`$`'P```')<`0`K````DEP!`"8```"^7`$`)P```.5<`0`Z````
M#5T!`!T```!(70$`$0```&9=`0`S````>%T!`"4```"L70$`)P```-)=`0`@
M````^ET!`#(````;7@$`'P```$Y>`0`P````;EX!`&D```"?7@$`,0````E?
M`0!!````.U\!`#,```!]7P$`)0```+%?`0`]````UU\!`&4````58`$`30``
M`'M@`0`M````R6`!`"<```#W8`$`+P```!]A`0`H````3V$!`"X```!X80$`
M,````*=A`0!4````V&$!`"<````M8@$`6@```%5B`0`Z````L&(!`$@```#K
M8@$`2@```#1C`0`?````?V,!`#(```"?8P$`+P```-)C`0`L`````F0!`"T`
M```O9`$`<0```%UD`0!F````SV0!`&\````V90$`LP```*9E`0`7````6F8!
M`"4```!R9@$`,@```)AF`0`I````RV8!`#X```#U9@$`(@```#1G`0!2````
M5V<!`"(```"J9P$`)0```,UG`0`+````\V<!`+$```#_9P$`(````+%H`0!%
M````TF@!`"$````8:0$`,````#II`0`E````:VD!`!P```"1:0$`,0```*YI
M`0`'````X&D!``@```#H:0$`!P```/%I`0`$````^6D!``H```#^:0$`#0``
M``EJ`0`+````%VH!``X````C:@$`"0```#)J`0`+````/&H!``8```!(:@$`
M!0```$]J`0`0````56H!``(```!F:@$`60```&EJ`0`%````PVH!`!(```#)
M:@$`!````-QJ`0`'````X6H!``@```#I:@$`!0```/)J`0`P````^&H!``,`
M```I:P$`$````"UK`0`,````/FL!`!,```!+:P$`#0```%]K`0`"````;6L!
M``<```!P:P$`!P```'AK`0`&````@&L!`!0```"':P$`#````)QK`0`8````
MJ6L!``8```#":P$`!````,EK`0`2````SFL!``P```#A:P$``P```.YK`0`J
M````\FL!``0````=;`$`!@```")L`0`'````*6P!`!\````Q;`$`-0```%%L
M`0`N````AVP!`"\```"V;`$`%P```.9L`0`B````_FP!`"4````A;0$`(```
M`$=M`0`;````:&T!`!@```"$;0$`)````)UM`0`?````PFT!`!H```#B;0$`
M(0```/UM`0`@````'VX!`!H```!`;@$`,@```%MN`0`9````CFX!`!H```"H
M;@$`+P```,-N`0`K````\VX!`!\````?;P$`(P```#]O`0`?````8V\!`!H`
M``"#;P$`(0```)YO`0`E````P&\!`"8```#F;P$`)0````UP`0`D````,W`!
M`!@```!8<`$`'0```'%P`0`D````CW`!`!@```"T<`$`(@```,UP`0`L````
M\'`!`"\````=<0$`%0```$UQ`0`E````8W$!`!D```")<0$`/````*-Q`0`?
M````X'$!`",`````<@$`'P```"1R`0`@````1'(!`!H```!E<@$`+P```(!R
M`0`8````L'(!`"8```#)<@$`'@```/!R`0`I````#W,!`!X````Y<P$`,0``
M`%AS`0`)````BG,!``P```"4<P$`%P```*%S`0`O````N7,!`"0```#I<P$`
M!P````YT`0`/````%G0!`!0````F=`$`#@```#MT`0`-````2G0!`"0```!8
M=`$`!0```'UT`0`'````@W0!`"(```"+=`$`)0```*YT`0`:````U'0!`!T`
M``#O=`$`&@````UU`0`'````*'4!`,<````P=0$`"P```/AU`0`<````!'8!
M`!4````A=@$`!@```#=V`0`)````/G8!``L```!(=@$`#0```%1V`0`,````
M8G8!`!<```!O=@$`!@```(=V`0`S````CG8!`!,```#"=@$`$P```-9V`0`'
M````ZG8!``\```#R=@$`!P````)W`0`R````"G<!``0````]=P$`(0```$)W
M`0`3````9'<!``X```!X=P$`#````(=W`0`1````E'<!`#(```"F=P$`%@``
M`-EW`0`(````\'<!`!T```#Y=P$`"0```!=X`0`*````(7@!`!0````L>`$`
M"@```$%X`0`=````3'@!``@```!J>`$`'P```'-X`0`(````DW@!`!H```"<
M>`$`)P```+=X`0`&````WW@!`!4```#F>`$`!P```/QX`0`(````!'D!``D`
M```->0$`/P```!=Y`0`'````5WD!``\```!?>0$`#@```&]Y`0`0````?GD!
M``D```"/>0$`"0```)EY`0`(````HWD!`!,```"L>0$`!P```,!Y`0`(````
MR'D!`!D```#1>0$`"@```.MY`0`7````]GD!`!0````.>@$`"@```"-Z`0`,
M````+GH!`!<````[>@$`!````%-Z`0`J````6'H!``P```"#>@$`$0```)!Z
M`0`'````HGH!``(```"J>@$`$````*UZ`0`8````OGH!``L```#7>@$``P``
M`.-Z`0`(````YWH!``D```#P>@$`!````/IZ`0`'````_WH!``<````'>P$`
M!@````][`0`4````%GL!``<````K>P$`#0```#-[`0`+````07L!`!0```!-
M>P$`%0```&)[`0`.````>'L!`"\```"'>P$`(````+=[`0`<````V'L!`$@`
M``#U>P$`3````#Y\`0`5````BWP!``P```"A?`$`,0```*Y\`0`%````X'P!
M`!(```#F?`$`/P```/E\`0`2````.7T!``H```!,?0$`!@```%=]`0`$````
M7GT!``0```!C?0$`"@```&A]`0`3````<WT!``4```"'?0$`!@```(U]`0`&
M````E'T!``@```";?0$`!````*1]`0`,````J7T!``H```"V?0$`"0```,%]
M`0`Y````RWT!`"X````%?@$`*0```#1^`0`%````7GX!`!@```!D?@$`&0``
M`'U^`0`?````EWX!`!T```"W?@$`$0```-5^`0`"````YWX!``0```#J?@$`
M"@```.]^`0`$````^GX!``8```#_?@$`%`````9_`0`%````&W\!``,````A
M?P$`#````"5_`0!%````,G\!`#(```!X?P$`,@```*M_`0`O````WG\!`!H`
M```.@`$`.@```"F``0`T````9(`!`"@```"9@`$`4P```,*``0"3````%H$!
M`"\```"J@0$`0@```-J!`0`P````'8(!`"X```!.@@$`&0```'V"`0`G````
MEX(!`#@```"_@@$`.````/B"`0`W````,8,!`'(```!I@P$`(````-R#`0`U
M````_8,!`"$````SA`$`10```%6$`0`P````FX0!`"D```#,A`$`(0```/:$
M`0`H````&(4!`"D```!!A0$`)@```&N%`0`E````DH4!`"@```"XA0$`*```
M`.&%`0`B````"H8!`"L````MA@$`(P```%F&`0!%````?88!`$D```##A@$`
M1@````V'`0`\````5(<!`#````"1AP$`$@```,*'`0`3````U8<!`!````#I
MAP$`>0```/J'`0`)````=(@!`*$```!^B`$`<P```"")`0!\````E(D!`"L`
M```1B@$`5````#V*`0`7````DHH!`!4```"JB@$`)P```,"*`0`6````Z(H!
M``\```#_B@$`%P````^+`0`?````)XL!`$````!'BP$`'P```(B+`0`<````
MJ(L!`%$```#%BP$`&@```!>,`0`4````,HP!``H```!'C`$`!0```%*,`0`&
M````6(P!``@```!?C`$`!0```&B,`0`2````;HP!`!````"!C`$`$P```)*,
M`0`=````IHP!``\```#$C`$`#P```-2,`0`/````Y(P!``8```#TC`$`#0``
M`/N,`0`$````"8T!``D````.C0$`"P```!B-`0`%````)(T!``4````JC0$`
M!P```#"-`0`%````.(T!`!0````^C0$`#@```%.-`0`'````8HT!``@```!J
MC0$`#P```'.-`0`-````@XT!``H```"1C0$`"````)R-`0`,````I8T!``8`
M``"RC0$`#P```+F-`0`'````R8T!``8```#1C0$`%````-B-`0`&````[8T!
M``8```#TC0$`#````/N-`0`1````"(X!`!<````:C@$`"````#*.`0`$````
M.XX!`!D```!`C@$`$0```%J.`0`*````;(X!`!@```!WC@$`$P```)".`0`<
M````I(X!`!$```#!C@$``P```-..`0`&````UXX!``0```#>C@$`!````...
M`0`/````Z(X!``H```#XC@$`"@````./`0`'````#H\!``0````6CP$`&0``
M`!N/`0`'````-8\!``(````]CP$``@```$"/`0`1````0X\!``D```!5CP$`
M`@```%^/`0`&````8H\!`!(```!ICP$`%P```'R/`0`&````E(\!`"<```";
MCP$``@```,./`0`(````QH\!``0```#/CP$`#P```-2/`0`3````Y(\!``<`
M``#XCP$`"P````"0`0`0````#)`!`!,````=D`$`!P```#&0`0`1````.9`!
M``8```!+D`$`&````%*0`0`&````:Y`!`!,```!RD`$`$````(:0`0`2````
MEY`!``(```"JD`$`!@```*V0`0`,````M)`!``D```#!D`$`$0```,N0`0`B
M````W9`!``<`````D0$`!P````B1`0`+````$)$!`!,````<D0$`!0```#"1
M`0`1````-I$!``(```!(D0$`"P```$N1`0`$````5Y$!``L```!<D0$`!0``
M`&B1`0`'````;I$!`%T!``!VD0$`#P```-22`0`3````Y)(!``X```#XD@$`
M"`````>3`0`)````$),!``H````:DP$`!0```"63`0`:````*Y,!`!\```!&
MDP$`,@```&:3`0`P````F9,!`"D```#*DP$`*````/23`0`>````'90!`#,`
M```\E`$`#````'"4`0`4````?90!`"<```"2E`$`"@```+J4`0`2````Q90!
M``P```#8E`$`(0```.64`0`0````!Y4!``4````8E0$`(0```!Z5`0`0````
M0)4!`!````!1E0$`%@```&*5`0`5````>94!``P```"/E0$`#0```)R5`0`I
M````JI4!`(4```#4E0$`$````%J6`0`*````:Y8!`!(```!VE@$`$````(F6
M`0`.````FI8!``P```"IE@$`#@```+:6`0`1````Q98!``8```#7E@$`P0``
M`-Z6`0!;````H)<!`"\```#\EP$`'@```"R8`0`'````2Y@!``L```!3F`$`
M&@```%^8`0`/````>I@!``P```"*F`$`"````)>8`0`(````H)@!`!$```"I
MF`$`"@```+N8`0`*````QI@!`!$```#1F`$`"@```..8`0`*````[I@!``<`
M``#YF`$`)@````&9`0`F````*)D!`"<```!/F0$`*````'>9`0`L````H)D!
M`"0```#-F0$`50```/*9`0!A````2)H!`'D```"JF@$`>````"2;`0!\````
MG9L!`'L````:G`$`6````):<`0`"````[YP!`!$```#RG`$`&0````2=`0`0
M````'IT!`!(````OG0$`&````$*=`0`%````6YT!``8```!AG0$`$@```&B=
M`0`'````>YT!``T```"#G0$`#0```)&=`0`*````GYT!`#<```"JG0$`+@``
M`.*=`0`2````$9X!``T````DG@$`$@```#*>`0`+````19X!`!$```!1G@$`
M"@```&.>`0`;````;IX!`!L```"*G@$`$0```*:>`0`0````N)X!`!8```#)
MG@$`%@```.">`0`>````]YX!`!X````6GP$`*````#6?`0`=````7I\!`"4`
M``!\GP$`%0```**?`0`1````N)\!`!H```#*GP$`#P```.6?`0`J````]9\!
M`!H````@H`$`&0```#N@`0`?````5:`!`!,```!UH`$`>@```(F@`0!"````
M!*$!`"\```!'H0$`!P```'>A`0`*````?Z$!`#````"*H0$`#@```+NA`0`'
M````RJ$!`!````#2H0$`"P```..A`0`%````[Z$!`!0```#UH0$`%P````JB
M`0`7````(J(!`!8````ZH@$`$@```%&B`0`5````9*(!`!4```!ZH@$`%```
M`)"B`0`*````I:(!``\```"PH@$`"0```,"B`0`(````RJ(!``@```#3H@$`
M"0```-RB`0`+````YJ(!``P```#RH@$`!````/^B`0`/````!*,!`!0````4
MHP$`$````"FC`0`,````.J,!`!````!'HP$`"P```%BC`0`/````9*,!``D`
M``!THP$`$@```'ZC`0`,````D:,!`!````">HP$`&0```*^C`0`F````R:,!
M`!$```#PHP$`&@````*D`0`:````':0!`!X````XI`$`&````%>D`0`4````
M<*0!`!(```"%I`$`$@```)BD`0`G````JZ0!`"<```#3I`$`!P```/ND`0`&
M`````Z4!``@````*I0$`#@```!.E`0`'````(J4!``D````JI0$`$P```#2E
M`0`$````2*4!``D```!-I0$`#P```%>E`0`5````9Z4!`!@```!]I0$`"@``
M`):E`0`/````H:4!``4```"QI0$`%P```+>E`0`+````SZ4!``H```#;I0$`
M2P```.:E`0!%````,J8!``L```!XI@$`"````(2F`0`5````C:8!``4```"C
MI@$`!0```*FF`0`0````KZ8!``L```#`I@$`%P```,RF`0`N````Y*8!`!``
M```3IP$``@```"2G`0#?````)Z<!`#T````'J`$`/````$6H`0`_````@J@!
M`#\```#"J`$`"P````*I`0`*````#JD!``D````9J0$`!@```".I`0`*````
M*JD!``H````UJ0$`00```$"I`0`]````@JD!`$````#`J0$`<0````&J`0`_
M````<ZH!`$,```"SJ@$`4P```/>J`0!0````2ZL!`#\```"<JP$`40```-RK
M`0`S````+JP!`#<```!BK`$`5P```)JL`0`_````\JP!`$,````RK0$`*@``
M`':M`0`@````H:T!`!P```#"K0$`/0```-^M`0`I````':X!`"D```!'K@$`
M$@```'&N`0`-````A*X!``T```"2K@$`"P```*"N`0`0````K*X!`!L```"]
MK@$`'P```-FN`0`'````^:X!``<````!KP$`%@````FO`0`+````(*\!``@`
M```LKP$`+0```#6O`0`*````8Z\!``X```!NKP$`"@```'VO`0`'````B*\!
M``8```"0KP$`!0```)>O`0`(````G:\!``8```"FKP$`"@```*VO`0`M````
MN*\!`!(```#FKP$`"````/FO`0`$`````K`!``@````'L`$`"P```!"P`0`$
M````'+`!``P````AL`$`!@```"ZP`0`3````-;`!``8```!)L`$`"````%"P
M`0`%````6;`!``L```!?L`$`"0```&NP`0`I````=;`!`!$```"?L`$`"0``
M`+&P`0`3````N[`!``P```#/L`$`!P```-RP`0`+````Y+`!``,```#PL`$`
M`P```/2P`0`7````^+`!``D````0L0$`%P```!JQ`0`W````,K$!``D```!J
ML0$`"````'2Q`0`2````?;$!`!T```"0L0$`"````*ZQ`0`B````M[$!``D`
M``#:L0$`"@```.2Q`0`'````[[$!`&,```#WL0$`+````%NR`0`Z````B+(!
M`#P```##L@$`+@````"S`0`J````+[,!``8```!:LP$`"0```&&S`0`8````
M:[,!``@```"$LP$`#````(VS`0`L````FK,!`"4```#'LP$`-@```.VS`0`R
M````)+0!`#,```!7M`$`D0```(NT`0!(````';4!``D```!FM0$`"P```'"U
M`0`(````?+4!``H```"%M0$`'0```)"U`0`)````KK4!``T```"XM0$`#```
M`,:U`0`3````T[4!``T```#GM0$`$P```/6U`0`.````";8!``P````8M@$`
M%@```"6V`0`)````/+8!`!P```!&M@$`'0```&.V`0`1````@;8!`!(```"3
MM@$`%0```*:V`0`&````O+8!``8```##M@$`%P```,JV`0"$````XK8!`'L`
M``!GMP$`!P```..W`0`3````Z[<!``4```#_MP$`!0````6X`0`?````"[@!
M`!X````KN`$`%````$JX`0`7````7[@!`!X```!WN`$`-````):X`0!K````
MR[@!`&$````WN0$`2P```)FY`0`O````Y;D!`%4````5N@$`70```&NZ`0!F
M````R;H!`"<````PNP$`#P```%B[`0`H````:+L!``8```"1NP$`&````)B[
M`0`4````L;L!`!D```#&NP$`&0```."[`0`5````^KL!`!4````0O`$`$0``
M`":\`0`*````.+P!`!,```!#O`$`$0```%>\`0`1````:;P!``8```![O`$`
M"P```(*\`0`'````CKP!``L```"6O`$`#@```**\`0`7````L;P!``D```#)
MO`$`!0```-.\`0`+````V;P!``@```#EO`$`"````.Z\`0`4````][P!``8`
M```,O0$`%````!.]`0`&````*+T!``P````OO0$`"0```#R]`0`0````1KT!
M``<```!7O0$`!0```%^]`0`(````9;T!``L```!NO0$`"P```'J]`0`:````
MAKT!`$0```"AO0$`*P```.:]`0`0````$KX!`!,````CO@$`(````#>^`0`)
M````6+X!``4```!BO@$`'````&B^`0`:````A;X!`!L```"@O@$`/0```+R^
M`0!,````^KX!`"@```!'OP$`"````'"_`0`]````>;\!`"0```"WOP$`#P``
M`-R_`0`&````[+\!``L```#SOP$`!@```/^_`0`(````!L`!`!L````/P`$`
M$````"O``0!4````/,`!``D```"1P`$`"@```)O``0`.````IL`!`#D```"U
MP`$`.0```._``0`[````*<$!`#L```!EP0$`*P```*'!`0`J````S<$!`"P`
M``#XP0$`*@```"7"`0!"````4,(!`"\```"3P@$`+@```,/"`0`P````\L(!
M`"@````CPP$`+P```$S#`0`\````?,,!`#X```"YPP$`-````/C#`0`Q````
M+<0!`#D```!?Q`$`+P```)G$`0`R````R<0!`$8```#\Q`$`,````$/%`0`?
M````=,4!`#H```"4Q0$`+@```,_%`0`[````_L4!`!\````ZQ@$`W````%K&
M`0`?````-\<!`"X```!7QP$`,0```(;'`0`R````N,<!`#4```#KQP$`,```
M`"'(`0`N````4L@!`#$```"!R`$`.0```+/(`0`\````[<@!`$0````JR0$`
M/````&_)`0#%````K,D!`"\```!RR@$`(@```*+*`0`O````Q<H!`#,```#U
MR@$`/@```"G+`0!D````:,L!`%T```#-RP$`#@```"O,`0`$````.LP!``4`
M```_S`$`"0```$7,`0`2````3\P!`!8```!BS`$`#@```'G,`0`6````B,P!
M`!4```"?S`$`"````+7,`0`/````OLP!`!(```#.S`$`"````.',`0`$````
MZLP!``8```#OS`$`$0```/;,`0`1````",T!``T````:S0$`$````"C-`0`1
M````.<T!`!````!+S0$`&````%S-`0`.````=<T!`%$```"$S0$`#````-;-
M`0`4````X\T!``8```#XS0$`$P```/_-`0`9````$\X!`!X````MS@$`%0``
M`$S.`0`"````8LX!`$L```!ES@$`!P```+'.`0`:````N<X!`!````#4S@$`
M$````.7.`0`%````]LX!``T```#\S@$`#0````K/`0`#````&,\!``8````<
MSP$`"````"//`0`/````+,\!``@````\SP$`!@```$7/`0`)````3,\!`!$`
M``!6SP$`"````&C/`0`1````<<\!``T```"#SP$`$0```)'/`0`-````H\\!
M``P```"QSP$`!P```+[/`0`*````QL\!``T```#1SP$`#@```-_/`0`.````
M[L\!``L```#]SP$`#@````G0`0`A````&-`!``T````ZT`$`#@```$C0`0`F
M````5]`!`!,```!^T`$`%P```)+0`0`M````JM`!``T```#8T`$`'0```.;0
M`0`3````!-$!`!L````8T0$`80```#31`0`:````EM$!`"X```"QT0$`$0``
M`.#1`0`(````\M$!``T```#[T0$`&P````G2`0`,````)=(!`"(````RT@$`
M,````%72`0`+````AM(!``@```"2T@$`'0```)O2`0`*````N=(!`!4```#$
MT@$`%0```-K2`0`+````\-(!``<```#\T@$`(P````33`0`1````*-,!`!4`
M```ZTP$`'P```%#3`0`9````<-,!``T```"*TP$`$P```)C3`0`)````K-,!
M``T```"VTP$`+P```,33`0`_````]-,!`!(````TU`$`40```$?4`0`(````
MF=0!`!<```"BU`$`(@```+K4`0`-````W=0!`!````#KU`$`-````/S4`0`,
M````,=4!``8````^U0$`"@```$75`0`&````4-4!``4```!7U0$`2P```%W5
M`0`&````J=4!``<```"PU0$`"@```+C5`0`-````P]4!`!4```#1U0$`$```
M`.?5`0`3````^-4!`!$````,U@$`$0```![6`0`1````,-8!`!H```!"U@$`
M&P```%W6`0`5````>=8!`"````"/U@$`'0```+#6`0`:````SM8!`!@```#I
MU@$`!P````+7`0`'````"M<!``L````2UP$`"@```![7`0`"````*=<!``4`
M```LUP$`#````#+7`0`E````/]<!`!4```!EUP$`%@```'O7`0`'````DM<!
M`!````":UP$`$````*O7`0`4````O-<!``4```#1UP$`.P```-?7`0`G````
M$]@!``@````[V`$`"````$38`0`'````3=@!``<```!5V`$`$0```%W8`0"7
M````;]@!`!D````'V0$`(P```"'9`0`1````1=D!``<```!7V0$`!@```%_9
M`0`F````9MD!`#(```"-V0$`,````,#9`0`D````\=D!`#X````6V@$`)```
M`%7:`0`=````>MH!`!\```"8V@$`!P```+C:`0`)````P-H!``D```#*V@$`
M!@```-3:`0`3````V]H!`!````#OV@$`$@````#;`0`4````$]L!`!4````H
MVP$`)````#[;`0`A````8]L!``\```"%VP$`#@```)7;`0`0````I-L!``X`
M``"UVP$`$P```,3;`0`1````V-L!`!````#JVP$`#@```/O;`0`)````"MP!
M``H````4W`$`#````!_<`0`.````+-P!``P````[W`$`/0```$C<`0`-````
MAMP!``@```"4W`$`"P```)W<`0`4````J=P!`!````"^W`$`(P```,_<`0`S
M````\]P!`"<````GW0$`)@```$_=`0`O````=MT!`"D```"FW0$`-@```-#=
M`0`L````!]X!`!4````TW@$`!@```$K>`0`.````4=X!``8```!@W@$`$```
M`&?>`0`#````>-X!``0```!\W@$`!P```('>`0`3````B=X!`!4```"=W@$`
M$P```+/>`0`9````Q]X!``H```#AW@$`#@```.S>`0`+````^]X!``<````'
MWP$`!0````_?`0`0````%=\!`!(````FWP$`#````#G?`0`)````1M\!``P`
M``!0WP$`#P```%W?`0`Q````;=\!``8```"?WP$`!0```*;?`0`(````K-\!
M``P```"UWP$`#@```,+?`0`7````T=\!``@```#IWP$`"````/+?`0`%````
M^]\!`"(````!X`$`#````"3@`0`%````,>`!`"H````WX`$`$````&+@`0!Q
M````<^`!`!,```#EX`$`"0```/G@`0`*`````^$!``T````.X0$`"P```!SA
M`0`-````*.$!``4````VX0$`#0```#SA`0`"````2N$!``8```!-X0$`"@``
M`%3A`0`7````7^$!``0```!WX0$`&@```'SA`0`3````E^$!`!8```"KX0$`
M,0```,+A`0`'````].$!``,```#\X0$`!`````#B`0`9````!>(!``@````?
MX@$`$@```"CB`0`*````.^(!``4```!&X@$`&0```$SB`0`(````9N(!``8`
M``!OX@$`!0```';B`0`+````?.(!`!D```"(X@$`#@```*+B`0`(````L>(!
M``L```"ZX@$`!0```,;B`0`)````S.(!``<```#6X@$`&````-[B`0`#````
M]^(!``8```#[X@$`"P````+C`0`,````#N,!``P````;XP$`"@```"CC`0`,
M````,^,!`!<```!`XP$`"````%CC`0`'````8>,!`!$```!IXP$`(P```'OC
M`0!0````G^,!`#8```#PXP$`.@```"?D`0`'````8N0!``H```!JY`$`!```
M`'7D`0`)````>N0!``@```"$Y`$`"@```(WD`0`)````F.0!``8```"BY`$`
M#0```*GD`0`&````M^0!``0```"^Y`$`.P```,/D`0`^````_^0!`#T````^
MY0$`)@```'SE`0`%````H^4!`!````"IY0$`!@```+KE`0`+````P>4!``P`
M``#-Y0$`&0```-KE`0`0````].4!`!@````%Y@$`!````![F`0`%````(^8!
M``L````IY@$`!0```#7F`0`*````.^8!`!X```!&Y@$`"@```&7F`0`-````
M<.8!``0```!^Y@$`"P```(/F`0`,````C^8!``H```"<Y@$`#@```*?F`0`/
M````MN8!``X```#&Y@$`"````-7F`0`)````WN8!``4```#HY@$`,P```.[F
M`0`S````(N<!`#P```!6YP$`+P```)/G`0!.````P^<!`$@````2Z`$`-0``
M`%OH`0!6````D>@!`#L```#HZ`$`3````"3I`0`P````<>D!`!$```"BZ0$`
M&0```+3I`0`+````SND!``D```#:Z0$`0P```.3I`0!(````*.H!`"\```!Q
MZ@$`5````*'J`0`B````]NH!`"X````9ZP$`$````$CK`0`2````6>L!``<`
M``!LZP$`!@```'3K`0`Q````>^L!`#$```"MZP$`.````-_K`0`*````&.P!
M`!L````C[`$`*0```#_L`0`?````:>P!`!,```")[`$`!@```)WL`0`*````
MI.P!``P```"O[`$`#P```+SL`0`9````S.P!`%\```#F[`$`?0```$;M`0!Z
M````Q.T!``4!```_[@$`#0```$7O`0`(````4^\!``D```!<[P$`$````&;O
M`0`1````=^\!``X```")[P$`!@```)CO`0`@````G^\!`!<```#`[P$`%P``
M`-CO`0`5````\.\!`!,````&\`$`%````!KP`0`;````+_`!`"H```!+\`$`
ME0```';P`0`1````#/$!``8````>\0$`$0```"7Q`0`*````-_$!``L```!"
M\0$`#0```$[Q`0`C````7/$!`!8```"`\0$`#P```)?Q`0`0````I_$!``T`
M``"X\0$`%P```,;Q`0`L````WO$!`"L````+\@$`*P```#?R`0`J````8_(!
M`#8```".\@$`-0```,7R`0`<````^_(!`$\````8\P$`%0```&CS`0`4````
M?O,!`!8```"3\P$`%0```*KS`0`6````P/,!`!8```#7\P$`%0```.[S`0`5
M````!/0!`!0````:]`$`,P```"_T`0`8````8_0!`!@```!\]`$`.P```)7T
M`0`2````T?0!``@```#D]`$`%````.WT`0`C`````O4!`!0````F]0$`%```
M`#OU`0`3````4/4!`!D```!D]0$`%@```'[U`0`6````E?4!`!L```"L]0$`
M&0```,CU`0`4````XO4!`!\```#W]0$`(@```!?V`0`5````.O8!`!4```!0
M]@$`%P```&;V`0`5````?O8!`!H```"4]@$`'0```*_V`0`;````S?8!`!@`
M``#I]@$`"`````+W`0`0````"_<!`!@````<]P$`!````#7W`0`&````.O<!
M``L```!!]P$`%````$WW`0`&````8O<!``H```!I]P$`!@```'3W`0`'````
M>_<!``<```"#]P$`!@```(OW`0`%````DO<!`!<```"8]P$`!@```+#W`0`)
M````M_<!``0```#!]P$`!````,;W`0`)````R_<!``H```#5]P$`"0```.#W
M`0`0````ZO<!`!$```#[]P$`"@````WX`0`5````&/@!``4````N^`$`-0``
M`#3X`0`/````:O@!`!(```!Z^`$`'````(WX`0`.````JO@!``P```"Y^`$`
M#@```,;X`0!)````U?@!``L````?^0$`!@```"OY`0`(````,OD!`"$````[
M^0$`#@```%WY`0`3````;/D!``8```"`^0$`"P```(?Y`0`)````D_D!``<`
M``"=^0$`!````*7Y`0`1````JOD!``T```"\^0$`#P```,KY`0`-````VOD!
M`!<```#H^0$`#P````#Z`0`6````$/H!``P````G^@$`%````#3Z`0`;````
M2?H!`!H```!E^@$`#````(#Z`0`(````C?H!``8```"6^@$`!@```)WZ`0`=
M````I/H!``<```#"^@$`!0```,KZ`0`1````T/H!``L```#B^@$`!P```.[Z
M`0`%````]OH!``<```#\^@$`!@````3[`0`-````"_L!``H````9^P$`#@``
M`"3[`0`3````,_L!`!4```!'^P$`%````%W[`0`;````<OL!`!,```".^P$`
M%0```*+[`0`(````N/L!`#8```#!^P$`!````/C[`0`2````_?L!`!<````0
M_`$`!0```"C\`0`1````+OP!`"4```!`_`$`%````&;\`0`6````>_P!`!$`
M``"2_`$`#0```*3\`0`,````LOP!``D```"__`$`#P```,G\`0`.````V?P!
M`!````#H_`$`$````/G\`0`P````"OT!`#`````[_0$`+````&S]`0`)````
MF?T!``<```"C_0$`!````*O]`0`'````L/T!`!````"X_0$`$````,G]`0`#
M````VOT!``@```#>_0$`(````.?]`0`(````"/X!``@````1_@$`#P```!K^
M`0!I````*OX!`!D```"4_@$`"P```*[^`0`%````NOX!``<```#`_@$`&@``
M`,C^`0`:````X_X!`!,```#^_@$`"0```!+_`0`"````'/\!``0````?_P$`
M)````"3_`0`'````2?\!``4```!1_P$`+P```%?_`0`*````A_\!``4```"2
M_P$`!P```)C_`0`4````H/\!`!````"U_P$`!@```,;_`0`(````S?\!``D`
M``#6_P$`!````.#_`0`%````Y?\!`!\```#K_P$`=`````L``@`+````@``"
M``X```",``(`&````)L``@`$````M``"``P```"Y``(`)@```,8``@`U````
M[0`"``X````C`0(`"@```#(!`@`2````/0$"``L```!0`0(`"0```%P!`@`9
M````9@$"`"@```"``0(`*0```*D!`@`H````TP$"`!L```#\`0(`(````!@"
M`@`.````.0("``,```!(`@(`#@```$P"`@`#````6P("``<```!?`@(`"P``
M`&<"`@`*````<P("``D```!^`@(`"0```(@"`@`*````D@("`!0```"=`@(`
M"0```+("`@!:````O`("`!P````7`P(`#@```#0#`@`,````0P,"`!L```!0
M`P(`3````&P#`@`=````N0,"``<```#7`P(`)````-\#`@`P````!`0"``@`
M```U!`(`!@```#X$`@`B````100"``4```!H!`(`!P```&X$`@`I````=@0"
M`"@```"@!`(`-````,D$`@`)````_@0"``@````(!0(`#0```!$%`@`>````
M'P4"`&(````^!0(`&````*$%`@`6````N@4"`!4```#1!0(``@```.<%`@`+
M````Z@4"``4```#V!0(`#@```/P%`@`.````"P8"``<````:!@(`#P```"(&
M`@`&````,@8"``8````Y!@(`"````$`&`@`%````208"``T```!/!@(`#@``
M`%T&`@`)````;`8"`!8```!V!@(`'````(T&`@`0````J@8"``P```"[!@(`
M"@```,@&`@`*````TP8"`#<```#>!@(`!P```!8'`@`2````'@<"`!,````Q
M!P(`'@```$4'`@`2````9`<"``H```!W!P(`"@```(('`@`+````C0<"``D`
M``"9!P(`"@```*,'`@`)````K@<"``@```"X!P(`'P```,$'`@`1````X0<"
M`$@```#S!P(`#P```#P(`@`*````3`@"``H```!7"`(`#@```&((`@`/````
M<0@"`!8```"!"`(`"P```)@(`@`1````I`@"``4```"V"`(`&0```+P(`@`$
M````U@@"``<```#;"`(`!0```.,(`@`%````Z0@"``L```#O"`(`&````/L(
M`@`2````%`D"`!D````G"0(`&P```$$)`@`B````70D"`!8```"`"0(`%P``
M`)<)`@`2````KPD"`!8```#""0(`"````-D)`@`#````X@D"``T```#F"0(`
M#@```/0)`@`,`````PH"``<````0"@(`'0```!@*`@`*````-@H"`$X```!!
M"@(`#@```)`*`@`F````GPH"`"L```#&"@(`%@```/(*`@`+````"0L"``L`
M```5"P(`!@```"$+`@`2````*`L"`!`````["P(`#````$P+`@`.````60L"
M``T```!H"P(`#0```'8+`@`,````A`L"`!4```"1"P(`#0```*<+`@`'````
MM0L"``D```"]"P(`!0```,<+`@`'````S0L"``8```#5"P(`!````-P+`@`$
M````X0L"``H```#F"P(`$````/$+`@!``````@P"`#H```!##`(`%````'X,
M`@`S````DPP"`#L```#'#`(`*P````,-`@`1````+PT"`$P```!!#0(`.@``
M`(X-`@!+````R0T"`$L````5#@(`40```&$.`@`7````LPX"`!D```#+#@(`
M"0```.4.`@`-````[PX"`!<```#]#@(`,0```!4/`@`I````1P\"`!4```!Q
M#P(`'0```(</`@`3````I0\"`!H```"Y#P(`%````-0/`@`7````Z0\"`!P`
M```!$`(`-P```!X0`@`W````5A`"`#L```".$`(`.````,H0`@`Y`````Q$"
M`#8````]$0(`=0```'01`@`C````ZA$"`"D````.$@(`$@```#@2`@`,````
M2Q("`!P```!8$@(`#````'42`@`4````@A("`#0```"7$@(`+````,P2`@`P
M````^1("`",````J$P(`"P```$X3`@!<````6A,"`%8```"W$P(`!0````X4
M`@`9````%!0"`!8````N%`(`#````$44`@`4````4A0"`!(```!G%`(`"```
M`'H4`@`*````@Q0"``D```".%`(`$````)@4`@`.````J10"`!0```"X%`(`
M$````,T4`@`2````WA0"``<```#Q%`(`)0```/D4`@`2````'Q4"``@````R
M%0(`!0```#L5`@`$````014"`!(```!&%0(`$@```%D5`@`1````;!4"`"\`
M``!^%0(``@```*X5`@`&````L14"``\```"X%0(`"0```,@5`@`'````TA4"
M`!P```#:%0(`!````/<5`@`[````_!4"``X````X%@(`&````$<6`@`$````
M8!8"``(```!E%@(`,````&@6`@`?````F18"`!@```"Y%@(`+P```-(6`@`9
M`````A<"`!\````<%P(`7@```#P7`@`7````FQ<"`$<```"S%P(`*0```/L7
M`@`-````)1@"``H````S&`(`%@```#X8`@`-````51@"`!0```!C&`(`$0``
M`'@8`@`,````BA@"`!8```"7&`(`#````*X8`@`=````NQ@"`!8```#9&`(`
M"````/`8`@`4````^1@"``D````.&0(`"````!@9`@`.````(1D"``P````P
M&0(`*@```#T9`@`2````:!D"`!D```![&0(`&````)49`@`:````KAD"`"L`
M``#)&0(`"````/49`@`)````_AD"``(````(&@(`&0````L:`@`1````)1H"
M`!,````W&@(`$@```$L:`@`9````7AH"`!$```!X&@(`%````(H:`@`;````
MGQH"``H```"[&@(`#````,8:`@`(````TQH"``4```#<&@(`(0```.(:`@`&
M````!!L"``\````+&P(`"````!L;`@`1````)!L"``@````V&P(`'@```#\;
M`@`1````7AL"`#D```!P&P(`&````*H;`@`)````PQL"``H```#-&P(`(@``
M`-@;`@`9````^QL"``@````5'`(`'P```!X<`@`$````/AP"``@```!#'`(`
M'````$P<`@`(````:1P"``<```!R'`(`'````'H<`@`P````EQP"`"@```#(
M'`(`!@```/$<`@`@````^!P"`!(````9'0(`!@```"P=`@`0````,QT"`!,`
M``!$'0(`!````%@=`@`)````71T"``L```!G'0(`!P```',=`@`%````>QT"
M``@```"!'0(`!0```(H=`@`+````D!T"`!\```"<'0(`/@```+P=`@!,````
M^QT"`"<```!('@(`-@```'`>`@`G````IQX"`%4```#/'@(`)P```"4?`@`W
M````31\"`#<```"%'P(`BP```+T?`@`H````22`"``4```!R(`(`!P```'@@
M`@`(````@"`"`!,```")(`(`"````)T@`@`;````IB`"`!T```#"(`(`*@``
M`.`@`@`J````"R$"`"8````V(0(`0````%TA`@!&````GB$"``D```#E(0(`
M%P```.\A`@`+````!R("``@````3(@(`.````!PB`@`+````52("``P```!A
M(@(`#0```&XB`@`6````?"("`!````"3(@(`$@```*0B`@`(````MR("`!,`
M``#`(@(`"````-0B`@`-````W2("`!8```#K(@(`)P````(C`@`H````*B,"
M`$,```!3(P(`"P```)<C`@`=````HR,"``4```#!(P(`!P```,<C`@`8````
MSR,"`",```#H(P(`#`````PD`@`%````&20"``H````?)`(`#````"HD`@`,
M````-R0"``L```!$)`(`&@```%`D`@`*````:R0"``H```!V)`(`!0```($D
M`@`1````AR0"`$D```"9)`(`70```.,D`@`/````024"``P```!1)0(`$P``
M`%XE`@`1````<B4"`!8```"$)0(`$````)LE`@`'````K"4"``D```"T)0(`
M"P```+XE`@`(````RB4"`!X```#3)0(`#````/(E`@`F````_R4"`!P````F
M)@(`$@```$,F`@`3````5B8"``T```!J)@(`"P```'@F`@`.````A"8"`!``
M``"3)@(`$0```*0F`@`0````MB8"``X```#')@(`+0```-8F`@`)````!"<"
M``P````.)P(`%````!LG`@`-````,"<"``X````^)P(`%@```$TG`@`,````
M9"<"`#X```!Q)P(`"````+`G`@`I````N2<"`!````#C)P(`%````/0G`@".
M````"2@"`$4```"8*`(`,P```-XH`@`)````$BD"`#<````<*0(`-````%0I
M`@`P````B2D"`!4```"Z*0(`$````-`I`@`,````X2D"`!4```#N*0(`'@``
M``0J`@`,````(RH"``8````P*@(`%P```#<J`@`*````3RH"`!<```!:*@(`
M'@```'(J`@`'````D2H"`!H```"9*@(`'````+0J`@`&````T2H"``8```#8
M*@(`$@```-\J`@`,````\BH"`!<```#_*@(`!0```!<K`@`(````'2L"``X`
M```F*P(`$0```#4K`@`2````1RL"`!,```!:*P(`$P```&XK`@`'````@BL"
M``8```"**P(`*````)$K`@`;````NBL"`!H```#6*P(`!P```/$K`@`5````
M^2L"``8````/+`(`(P```!8L`@`C````.BP"`"L```!>+`(`"P```(HL`@`)
M````EBP"`",```"@+`(``P```,0L`@`&````R"P"``H```#/+`(``@```-HL
M`@`,````W2P"`!4```#J+`(`"P`````M`@`9````#"T"`"`````F+0(`%P``
M`$<M`@`%````7RT"``H```!E+0(`%0```'`M`@`2````ABT"``<```"9+0(`
M#0```*$M`@`)````KRT"``X```"Y+0(`#````,@M`@`3````U2T"`!0```#I
M+0(`$````/XM`@`7````#RX"`%@````G+@(`'0```(`N`@`T````GBX"`!0`
M``#3+@(`#````.@N`@`%````]2X"``\```#[+@(`#0````LO`@`.````&2\"
M`!8````H+P(`$0```#\O`@`L````42\"``\```!^+P(`(````(XO`@`8````
MKR\"`!````#(+P(`(@```-DO`@`.````_"\"`"8````+,`(`$````#(P`@`8
M````0S`"`(X```!<,`(`$````.LP`@`W````_#`"`#\````T,0(`D0```'0Q
M`@`B````!C("`!P````I,@(`'````$8R`@`Q````8S("`!\```"5,@(`+0``
M`+4R`@`Q````XS("`"`````5,P(`&@```#8S`@`U````43,"`$$```"',P(`
M+````,DS`@!+````]C,"`!H```!"-`(`(P```%TT`@`9````@30"``\```";
M-`(`3P```*LT`@`5````^S0"`&0````1-0(`!P```'8U`@`(````?C4"``D`
M``"'-0(`%@```)$U`@`,````J#4"`"H```"U-0(`$@```.`U`@`6````\S4"
M``D````*-@(`#````!0V`@`2````(38"`'L````T-@(`&P```+`V`@`4````
MS#8"`%0```#A-@(`5@```#8W`@!%````C3<"`'````#3-P(`#0```$0X`@`E
M````4C@"`"P```!X.`(`"@```*4X`@`G````L#@"`!,```#8.`(`%````.PX
M`@`'`````3D"`!4````).0(`0@```!\Y`@`&````8CD"`!$```!I.0(`&P``
M`'LY`@!*````ESD"`%0```#B.0(`)@```#<Z`@`>````7CH"`#````!].@(`
M'P```*XZ`@`B````SCH"`!(```#Q.@(`*P````0[`@`E````,#L"`"D```!6
M.P(`*@```(`[`@`O````JSL"`"D```#;.P(`+P````4\`@`E````-3P"`#\`
M``!;/`(`%0```)L\`@`'````L3P"``P```"Y/`(`#@```,8\`@`7````U3P"
M``L```#M/`(`/0```/D\`@`,````-ST"``P```!$/0(`"````%$]`@`3````
M6CT"``@```!N/0(`!0```'<]`@`=````?3T"``@```";/0(`"0```*0]`@`&
M````KCT"``T```"U/0(`#0```,,]`@`2````T3T"`!0```#D/0(`#````/D]
M`@`8````!CX"``T````?/@(`"````"T^`@`1````-CX"`!X```!(/@(`$```
M`&<^`@`)````>#X"`!H```""/@(`+````)T^`@`3````RCX"`"T```#>/@(`
M+0````P_`@`-````.C\"``<```!(/P(`"````%`_`@`'````63\"``0```!A
M/P(`%0```&8_`@`,````?#\"``T```")/P(`#````)<_`@`%````I#\"``D`
M``"J/P(`!P```+0_`@`(````O#\"``D```#%/P(`"@```,\_`@`&````VC\"
M``D```#A/P(`"0```.L_`@`'````]3\"`!@```#]/P(`!@```!9``@`.````
M'4`"``8````L0`(`#P```#-``@`,````0T`"`"````!00`(`"@```'%``@`"
M````?$`"`"4```!_0`(`!P```*5``@`*````K4`"`(H```"X0`(`#````$-!
M`@`&````4$$"`",```!700(`-````'M!`@`@````L$$"`"````#100(`5P``
M`/)!`@`Q````2D("`#0```!\0@(`(P```+%"`@`@````U4("``4```#V0@(`
M#P```/Q"`@`-````#$,"``\````:0P(`!P```"I#`@`&````,D,"``T````Y
M0P(`$P```$=#`@`/````6T,"``\```!K0P(`$0```'M#`@`,````C4,"``<`
M``":0P(`!P```*)#`@`(````JD,"`!8```"S0P(`"0```,I#`@`(````U$,"
M``<```#=0P(`'````.5#`@`&`````D0"`!T````)1`(`&0```"=$`@`(````
M040"`!,```!*1`(`"````%Y$`@`-````9T0"``D```!U1`(`%0```']$`@`'
M````E40"`!4```"=1`(`!@```+-$`@`;````ND0"``T```#61`(`'````.1$
M`@`%`````44"``@````'10(`#0```!!%`@`?````'D4"``H````^10(`#```
M`$E%`@`I````5D4"`!P```"`10(`$@```)U%`@`/````L$4"``0```#`10(`
M"````,5%`@`+````SD4"``D```#:10(``@```.1%`@`6````YT4"``@```#^
M10(`-@````=&`@`F````/D8"`"8```!E1@(`/@```(Q&`@`O````RT8"`#0`
M``#[1@(`.@```#!'`@!O````:T<"``D```#;1P(`+P```.5'`@`@````%4@"
M`"$````V2`(`+````%A(`@`D````A4@"`"P```"J2`(`;````-=(`@`[````
M1$D"`%,```"`20(`<@```-1)`@`I````1TH"`$<```!Q2@(`+P```+E*`@!<
M````Z4H"`&0```!&2P(`6````*M+`@`^````!$P"`"\```!#3`(`,0```'-,
M`@`T````I4P"`!\```#:3`(`/@```/I,`@`V````.4T"`.@!``!P30(`(@``
M`%E/`@`)````?$\"`$D```"&3P(`J````-!/`@`K````>5`"`#4```"E4`(`
M0P```-M0`@!V````'U$"`$@```"640(`0@```-]1`@!^````(E("`!0```"A
M4@(`"@```+92`@`]````P5("`!\```#_4@(`(@```!]3`@`P````0E,"`"H`
M``!S4P(`*0```)Y3`@!0````R%,"`!(````95`(`"````"Q4`@!(````-50"
M`#<```!^5`(`*@```+94`@`G````X50"`"L````)50(`)@```#55`@`K````
M7%4"`&@```"(50(`0P```/%5`@!&````-58"`$(```!\5@(`.P```+]6`@!0
M````^U8"`&T```!,5P(`6````+I7`@`]````$U@"`#L```!16`(`00```(U8
M`@`[````SU@"`#T````+60(`0````$E9`@!F````BED"`#P```#Q60(`>```
M`"Y:`@!2````IUH"`'````#Z6@(`<````&M;`@`Y````W%L"`#@````67`(`
M+@```$]<`@`N````?EP"`#````"M7`(`@P```-Y<`@!X````8ET"`'\```#;
M70(`TP```%M>`@`:````+U\"`"P```!*7P(`-@```'=?`@`K````KE\"`%@`
M``#:7P(`+0```#-@`@!7````86`"`"H```"Y8`(`*@```.1@`@`,````#V$"
M`+X````<80(`%P```-MA`@!=````\V$"`",```!18@(`.````'5B`@`G````
MKF("`"````#68@(`0P```/=B`@`&````.V,"``H```!"8P(`!P```$UC`@`$
M````56,"``L```!:8P(`#0```&9C`@`*````=&,"``L```!_8P(`"@```(MC
M`@`+````EF,"``8```"B8P(`!0```*EC`@`0````KV,"``(```#`8P(`7P``
M`,-C`@`%````(V0"`!P````I9`(`!````$9D`@`'````2V0"``8```!39`(`
M!0```%ID`@`Z````8&0"``0```";9`(`%P```*!D`@`-````N&0"`!,```#&
M9`(`$````-ID`@`"````ZV0"``@```#N9`(`"````/=D`@`&`````&4"`!4`
M```'90(`#````!UE`@`7````*F4"``8```!"90(``P```$EE`@`.````364"
M``H```!<90(`"````&=E`@`N````<&4"``@```"?90(`!@```*AE`@`'````
MKV4"`#@```"W90(`7````/!E`@!(````368"`$D```"69@(`,@```.!F`@`P
M````$V<"`#,```!$9P(`.````'AG`@`O````L6<"`"H```#A9P(`-@````QH
M`@`Q````0V@"`"L```!U:`(`-@```*%H`@`M````V&@"`"T````&:0(`0@``
M`#1I`@`C````=VD"`"0```";:0(`/P```,!I`@`Z`````&H"`#$````[:@(`
M-0```&UJ`@`P````HVH"`"L```#4:@(`-@````!K`@`R````-VL"`#8```!J
M:P(`-0```*%K`@`K````UVL"`"T````#;`(`,````#%L`@`[````8FP"`"L`
M``">;`(`*````,IL`@!&````\VP"`$D````Z;0(`)P```(1M`@`T````K&T"
M`"0```#A;0(`3P````9N`@`R````5FX"`#8```");@(`,0```,!N`@`R````
M\FX"`"P````E;P(`.@```%)O`@`I````C6\"`"X```"W;P(`,P```.9O`@!&
M````&G`"`"\```!A<`(`8````)%P`@`-````\G`"`!P`````<0(`(@```!UQ
M`@!!````0'$"`"4```""<0(`$````*AQ`@`/````N7$"`!P```#)<0(`%@``
M`.9Q`@`2````_7$"`"0````0<@(`"0```#5R`@`)````/W("`"4```!)<@(`
M*````&]R`@`G````F'("`"<```#`<@(`)````.AR`@`)````#7,"``,!```7
M<P(`$@```!MT`@`B````+G0"`!T```!1=`(`#@```&]T`@`0````?G0"`!8`
M``"/=`(`&````*9T`@`1````OW0"`!\```#1=`(`"0```/%T`@!.````^W0"
M`!H```!*=0(`$P```&5U`@`'````>74"`!4```"!=0(`#````)=U`@!9````
MI'4"``@```#^=0(`*0````=V`@`2````,78"`!(```!$=@(`%0```%=V`@`5
M````;78"`#X```"#=@(`'````,)V`@`,````WW8"`"@```#L=@(`#0```!5W
M`@`.````(W<"`!4````R=P(`"@```$AW`@`D````4W<"``L```!X=P(`&0``
M`(1W`@`*````GG<"`!T```"I=P(`+0```,=W`@`%````]7<"`"<```#[=P(`
M!P```"-X`@`'````*W@"``D````S>`(`3````#UX`@`'````BG@"`!$```"2
M>`(`"P```*1X`@`7````L'@"``D```#(>`(`"0```-)X`@`'````W'@"`!8`
M``#D>`(`"P```/MX`@`,````!WD"`!X````4>0(`#P```#-Y`@`8````0WD"
M`!P```!<>0(`!0```'EY`@`'````?WD"`!D```"'>0(`!P```*%Y`@`Q````
MJ7D"``T```#;>0(`$0```.EY`@`'````^WD"``(````#>@(`$`````9Z`@`/
M````%WH"``L````G>@(``P```#-Z`@`'````-WH"``@````_>@(`!0```$AZ
M`@`)````3GH"``@```!8>@(`"P```&%Z`@`>````;7H"``H```",>@(`$0``
M`)=Z`@`.````J7H"`!L```"X>@(`'````-1Z`@`*````\7H"`#8```#\>@(`
M)````#-[`@`J````6'L"`%@```"#>P(`6````-Q[`@`7````-7P"``T```!-
M?`(`/@```%M\`@`&````FGP"`!<```"A?`(`0````+E\`@`.````^GP"``<`
M```)?0(`!P```!%]`@`$````&7T"``0````>?0(`"0```"-]`@`>````+7T"
M``4```!,?0(`!@```%)]`@`(````67T"``P```!B?0(`!@```&]]`@`4````
M=GT"`!0```"+?0(`#````*!]`@!`````K7T"`#0```#N?0(`+@```"-^`@`,
M````4GX"`!X```!??@(`(0```'Y^`@`O````H'X"`"D```#0?@(`%````/I^
M`@`"````#W\"``0````2?P(`#````!=_`@`$````)'\"``@````I?P(`&P``
M`#)_`@`%````3G\"``(```!4?P(`$0```%=_`@!A````:7\"`"X```#+?P(`
M+P```/I_`@`H````*H`"`!H```!3@`(`1@```&Z``@`Z````M8`"`"\```#P
M@`(`7@```""!`@##````?X$"`#\```!#@@(`5@```(."`@`]````VH("`$``
M```8@P(`%@```%F#`@`N````<(,"`#T```"?@P(`/0```-V#`@!!````&X0"
M`'T```!=A`(`*0```-N$`@!6````!84"`"D```!<A0(`0````(:%`@`^````
MQX4"`#4````&A@(`)P```#R&`@`U````9(8"`$P```":A@(`-0```.>&`@`W
M````'8<"`#D```!5AP(`'P```(^'`@`N````KX<"`#(```#>AP(`*````!&(
M`@!6````.H@"`%0```"1B`(`4P```.:(`@!'````.HD"`$````""B0(`$@``
M`,.)`@`2````UHD"``P```#IB0(`B0```/:)`@`(````@(H"`,8```")B@(`
M<0```%"+`@"+````PHL"`"T```!.C`(`90```'R,`@`7````XHP"`!4```#Z
MC`(`)@```!"-`@`7````-XT"`!<```!/C0(`&@```&>-`@`D````@HT"`$,`
M``"GC0(`)@```.N-`@`@````$HX"`&L````SC@(`'````)^.`@`,````O(X"
M``L```#)C@(`!0```-6.`@`&````VXX"``@```#BC@(`!0```.N.`@`6````
M\8X"`!`````(CP(`%0```!F/`@`@````+X\"`!0```!0CP(`$0```&6/`@`/
M````=X\"``8```"'CP(`#P```(Z/`@`-````GH\"``D```"LCP(`#@```+:/
M`@`+````Q8\"``@```#1CP(`"````-J/`@`&````XX\"`!4```#JCP(`#@``
M``"0`@`)````#Y`"``D````9D`(`$P```".0`@`/````-Y`"``T```!'D`(`
M#@```%60`@`'````9)`"``@```!LD`(`$@```'60`@`&````B)`"``X```"/
MD`(`&0```)Z0`@`&````N)`"``D```"_D`(`"@```,F0`@`2````U)`"`!0`
M``#GD`(`"````/R0`@`)````!9$"`"D````/D0(`(@```#F1`@`0````7)$"
M`"4```!MD0(`%````).1`@`;````J)$"`!$```#$D0(``P```-:1`@`&````
MVI$"``0```#AD0(`"@```.:1`@`6````\9$"``L````(D@(`"P```!22`@`'
M````()("``4````HD@(`%0```"Z2`@`$````1)("``(```!)D@(``@```$R2
M`@`2````3Y("``8```!BD@(``@```&F2`@`&````;)("`!(```!SD@(`%P``
M`(:2`@`'````GI("`#H```"FD@(``@```.&2`@`(````Y)("``0```#MD@(`
M$P```/*2`@`8````!I,"``H````?DP(`"P```"J3`@`1````-I,"`!4```!(
MDP(`!P```%Z3`@`2````9I,"``4```!YDP(`&0```'^3`@`(````F9,"`!<`
M``"BDP(`%0```+J3`@`3````T),"``(```#DDP(`#@```.>3`@`,````]I,"
M``T````#E`(`%@```!&4`@`Z````*)0"``<```!CE`(`"0```&N4`@`1````
M=90"`!,```"'E`(`!0```)N4`@`6````H90"``(```"XE`(`"P```+N4`@`%
M````QY0"``P```#-E`(`!@```-J4`@`'````X90"``$````V`````````#,"
M````````+@0``.`'``#?`0``"00``-X````7````2`@``(@!````````````
M`/0$````````_@(``-8(``#[`@``````````````````UP8`````````````
M0@<`````````````$04``-\(``"8"````````"T#``!'````U08``/P!````
M````C0@`````````````50<``#,$````````RP(``,\"``!?`````````"H`
M``!G!@``*P(``(8'``"=`P``3@,```````#@`0``+0(```````!3!```````
M`!X'``![``````(``/\"``!4````7`0``(X%````````]@```,8```"0`@``
M`P(``+@#````````40(``)D```!J`P``X04``!P'``#&`P````````````#(
M!P``KP````````#2`0``\@`````````"`@``^@0``$,&``!%!```!04`````
M`````````````/H!````````$`@``$T$``"E"```Y`8``"$'``"V!0``HP,`
M`%<!````````@0@```$&``"+`@``G`0``%D&``!\`P```````#L#``#\!P``
M@`8``.T#``!W`@``>`,```````!#!P``GP<``-4%````````00,``+H!``!E
M`P``Q`$``/8"``#:````<@@``-\%```Y!P```````,T```"*`0```````+$%
M``#H`P``D`0``(`$```V!@``3P0``+H"````````C00``)("```[!0``?@,`
M`"X#``!P!0``.@@``!('``"3!````````.8$``"R`P``$0@``"X(```+!0``
M`````&($``!0`P```````/T%`````````````,T$``"$!@``Y@4``,D'````
M````$@$``'H````U`@``E`$``+@$```F`````````-4#``"P!```CP```'H$
M```T!P``[`$``.\```!Q!@``_`,```````!W````C08``)4"``!9"```6@8`
M`*,%``!*!```DP@```````#K````NP,``-`&``#B!P``%P(`````````````
MK`8```````#$`P``[@,``-8```!>`0``;@(```@$``!!!P``;@4``"L'````
M````QP``````````````_P<``$X"```]`0```````'(#````````K@```-X$
M``!\!0``'00``$$(``!)`0``[P<``)0'``!!`@```````!,!````````X0,`
M`$4(``#J`P``20(``.,'````````HP$``$L%``!7`@```````)P`````````
M`````"("````````;@0```````!*`0``?P8``#L!``#2!P``TP```"T%``!V
M"```H`$```4!``"M"`````````````!%`0``,`4``"`(`````````````-L`
M``#:`0````````````"I`0````````````#X`@```````$,(``!K````````
M`$P'``"^````9`````\"``#``0```````(,!```B"````````"0#``"B!0``
MV@4``-D```#``P``%P,``$8"``#Z!0```````%L!````````````````````
M````M````(4#``"%"```,P@``-0'``!M`@``4@<`````````````PP<``#0"
M```F"````````-@%``"G!0``R0$`````````````0`(``/L`````````````
M`!`#``"E````\P```&T```"H`P``9@```-\'```J`@```````/`$``!>!P``
MA`0````````&````/P(``%@#``".`0``)0$``(T'````````&0,````````I
M`0``E@```+@%``#0"`````````````!6!@``W````)T```";!P``-04``(<#
M````````$P8``````````````````-("``#9!```D@``````````````````
M``````"K`0````````````!<````-P(``"8!``#F`P``L`4```````!0!0``
M^````#P$````````L0```"X%```."```[0$``&`%````````M@```$H#``#A
M`@``$0$```````"_"```EP(```````!$"```G0@``(X#```U````1`$``!@`
M````````)P0``!4#``#Q`P``304``(8"```F!@```````/4!``","```4P``
M`(8&``!W`0````````````#?!@```````,(#```[!@````````````!8`0``
M`````+(&````````]P(```````"<`0````````````!O!```3@```+L'``"B
M!````````-T%``#5"````````'$#```/!```3@0``$D```#C`@```````,X(
M``#.!P``%@4``!<'```$````)P@``-@$````````U`,``&,'``!7!```FP(`
M`+@'```+`P``K@$```````"T!@```````#T$``!/`P``I0,````````>!```
M-`,``&(&``"*`````````.T&``#(`P``/@(`````````````20@``((!````
M````T@8``*H!```I````U````$L$``"0`````0,``#8$``"B!P```````-L$
M```_!````````%$$``"!``````````H$``"2!0``M@8``"D'``"M`P``OP<`
M`#L$``!@`P```````&H$``#*!```Z`4``.0$``!-!@``>@4```````#W!```
M\P(``!@&```&"```%@0``-$"``#U!P``F@````````!Y`@```````&<'``!\
M````P04`````````````````````````````TP,``&,%````````(`$``/D'
M``!0!```CP0``-\"```>!0```````)D%``!&!0``CP@``/X%````````*@,`
M`"$$``!&"```]@0```L!````````6@4````````C"```V````*H(``"8`P``
M\@<``.@&````````'`0``)H%``#H"```YP,```@'``#<`@```P```(P"```;
M`0``3P(``'\%``#V!@````````````!Y````60$``+T"``!A!P```````/4$
M`````````````$4&``"G````/P$````````$!@``B@8``-`!````````````
M``````"H"```MP```)\!```-!P``N@0```````#'!0``N@8`````````````
M9`$```````#S`0``C@<``)H'````````\0```%H#``#!`0``=`8``!((```Z
M!P``?`<``````````````````'D&``"E`0``?08`````````````````````
M```P!@``8`@``'\"``!\!@``;0@``!4(``!0"```H0<``,X&````````````
M`.4(````````IP0``*<"``!I`P``*@4```````#S!@``'08``"4'```'!```
MP````/`&``"_!@``J0<``"4```!J"```2@8``/H&````````(P```*$(```N
M`@```````,0'``!P`0``[0(``)4&````````"`,``,,(````````,`(``.@`
M`````````````+D'```0!```)P```/D!```2!```````````````````*```
M``````!O"```10```-<"``#A!```PP(``&`!```6`````````"\!````````
M#P,`````````````&0<``````````````````+T!`````````````*8(``#(
M`0```````!P(``#;!0``-`0``````````````````.`#``#^!@```````(0`
M````````RP,``,H!``"3!@``-@$``'`````""```504``#\%``#;`0``````
M`+((``"3!P```00``*P(````````S0@```````!^!0```````$X!```-!@``
MKP8`````````````AP@``+L$``#("```&08```````!O!0``L@0``-`$``#=
M`@``KP@``*`(``!D!0``1@$``*\"```G!P``0P(``-L"``!L!0``H0,``)X"
M``!'!0``/````)$!``!/`0``!00``'T#``"0!P``;`@```````#"!```U@$`
M`)`%```8!````````````````````````!@'``#X`0``(P$``&(#``"I!0``
MY@<``.(%``!P!```0P````````!\`@````````````````````````````#`
M`@``K@<```````"$`0``)P$``(<!``!?!```N04``"X!``!6!P``J@<``.0'
M````````K0<``"P!``"5!0``_P8``#8%```)````S`<``)P&````````5`(`
M`&@&``!X"````````*T!``#I!P``F@$```````".!@``I0(`````````````
MU@4```````!^`@````````````#Q!````````-H(```G!@```````"L````Q
M"```QP<``&4```#,````3P@``$X%````````NP$``#\(``"6!0``1P$``&X(
M``!N!@``.P<```````#="```(P,```````")``````````````!T`0``U@<`
M``````!,`0``L0(`````````````T@4``$H"``#/`P``0`8``#0!```/!@``
M`````)L&``!?`0``SP0``,,!`````````````"T$``!]`0``0P0``*4$``!P
M"```?0(``-@"``"3````30,````````G!0``%@@``#``````````>P8`````
M```@!P``@P0``"X&``!I````-P0````&``#D`P``A@```&$"````````,04`
M``````#)`P```````*0'``!'!````````-X#`````````````+@&``#3"```
M`````.(````O!@``X@@``!\#```)!0``(@8```````#<!```!`4``)8'````
M````<`8``,$'``#3!```50```,\(```/!0``*P0```````!4!@``````````
M``"*!P``%`$``,(&````````<@$```````!]````%0$```````"A````````
M`.<'```O!P````````0"``!8!@``@``````````*`P```````.8!```?!0``
M'@,``#(%````````]08``!,"``"B"```.08```('``"T`@``B`0```8'``!^
M!@``70@``'8`````````;P,``'@'``````````````````"-`@```````(0%
M``````````4``)0`````````E`8```$(``"*"```F08``,4(``#:`@``-@,`
M`&T%``"-!0``.04``+H`````````@P(```````!J!0``>P$``%P'``!>`@``
M<00``!T#```;!```'@```.X"``#+!```U00``/(&``#J`0``&P,````````'
M"```7P8``(L```!B!0``#@```&L'``!I`@``4@,```````";!0``Q0,```0'
M``!X`@``\0$``'4"``"J!````````!\!```F!0``\@(``&H!```,!0``````
M`!,'``#]`0``U@(``-D(``#_!0``````````````````30$``/@'``"^!P``
M`````````````````````,4!```^`0``-08``````````````````$0`````
M````GP4``-$`````````,0,``$$```!4`P```````-,'```=`0``"0,`````
M``!H`0``&04```````!'`P``:P4``!H(``"?"```-P<``!H&````````=08`
M`,`%````````E@0```````!?!0``S@$``!8&``#T`P``````````````````
MB@,``$`%``#(!```=0@```````!."```+P,``$$$```>"```%`,``-@&```/
M`````````$@%``"(!@```````!P#````````2`$``'4#``"/`0``[`0``*8!
M``"%!P``_````%L&``"*!```PP```($"``"G"````````*L"````````=00`
M`)X'``#U`@```````#(#````````_0,``/X`````````80@``-T!``#`!P``
M!P,```````"\!```?@0```H%``#%````6@<``*X(````````,P4```$"````
M````U0$```L"``!E`0``@`@``%\"``#@!0```````,H"``!U!P``(0(``%@(
M```8"```Q`(``#('``#"`@``VP@``.L$``!U!0``;0$``-4```#I!0``@P``
M`*,'````````2P$```T#````````P@@``),"```S````LP(```H````M"```
M7@@``%`"``"^!0``5@4``.T'````````<@8``)<!``"V!P``@`4````````G
M`P``#0$``!`%``#C`P``V`<``/<!``!8`@``0@8``-$!``!F!```XP$`````
M````````"0$``$H%``````````````8%`````````````-@(``!T!```````
M`.4%``"$`@``>P(``'H#``!K`0``%0```$T'````````!@0``(<```!!!0``
M`````&@```!R!P``M0,``/X!``"I````ZP(`````````````NP(``,P$```'
M!P``D`@``*$!`````````````%,%``!B"````````&4&``#N````\04``-X!
M```L!P````<``"````"#!0```````+P``````````````,H#```I`@``````
M`+P'`````````````*8````@`P``)P(``.X$``"O!P```````/\$``";"```
MV@8``````````````````&4$```*`0``E`,``'H'``!$`P``I04``#\&````
M````)0(````````*!P``*0,``,0(``#Q!@```````$D$``"4"```````````
M``".`@``6`<``!,$``#+!P``.P```%P&````````P@4``'D(````````````
M`#@(```V`@```````!`&`````````````/<`````````R@4``'H!````````
MC@```%@```#X`P```````(`#``!N!P``#04```````"D!`````````````!<
M`@``6`0``-8&```H`0``-P@``$\%``!O`@``)0,``$L&`````````````*D(
M``"!`0``'`(````````L!0``L0<``+,$``!$!```MP$``%,&``!B!P``````
M`"0(``!I!0``JP````````"!!@``UP<``'8'``!/````)`4```@%````````
M:P0``$H(`````````````*X$``#%!P``K@(`````````````G00```````#I
M`P``*`,``.$```""`@``&P<``+<%``!9````-0<``$$&``!3"````````/,'
M```V!P``L@<``.<```"5`0```````#$'````````8@(```````")!P``````
M``````#F"```?@@``&@"````````=@(``/4#``"9`@``.`4``'<%````````
M`````'8#``"K!P``>0$``/,%```%"```5P,```````!G!0```````,8!```-
M"```RP4```X!```?!```,0(```````#T!@``(`0``,P(```P"```?P$``"@"
M````````H@8````````<````XP8```D&```D!```'0@``&P&```#!0``L08`
M`)<%`````````@,``#D#````````<P<``&$%````````SP```)D$```'````
MJ`4``#@&````````N00```P(``"T"```0`0``-D#````````%04``($'````
M`````````+@"`````````````',```#=`````````#L"``!6`````````(($
M````````L`@``!\&``#[`0``"`@``"$!```=!0```````'L'```X!P``K0``
M`*8#```C!```E0<``-X&``!3`0``O@(``$,#````````^@<``+P#``"Q`0``
M(`8````````]"```I`,````````N````+`8```````"2`0``'0<``)8"``"Y
M!@``\P,```````!=`0```````-(#```2!@``:@(`````````````)00``#H&
M````````8P$``(\&``#\!@``Y00``$<'````````9P@``-,&``!C"```<@``
M``````!K`@``R@@``%0%``!,`@``'0```&8"``"O`0``BP8``&`$```,`0``
MO@@``+\#````````@`<``(`"``"U````=`,```````!X`0``.0@``&P"``#3
M!0``R0@``!$```#P!P``%`8``-H$```.!0``H04`````````````N0(``*H%
M```O!0``TP(``/L#```;````?`0``+,'```.!P``Q00``#\#``!\"```700`
M````````````'P@``/H"````````)`(``-0$``!_!P``5P``````````````
MQP,````````0````O0,`````````!`````````````#>!0``,@```$L"``#E
M````2````,D%``!Z`@``9P```+@````^"```R`4```````!J!P``*`<``.D!
M``#R`P``FP$``!L%``"=`@``A@0``%\#````````YP4```````"H`@``````
M````````````/@8```($``!T"```O@,```4"```6`@``-0$``,D&``"B`0``
M`````#T&````````\0(```````!W!```'P````````">!````````!0$```-
M````JP0``+<'``#!"```G@8```````#%!@``\@$``*P"``!;"```C`8```L'
M``"P`P``&0$``#H"``#I!````````/T"``#9!0```````$<&``"D`@``````
M``````!Q`@````````````"D````>P@```````!<`P``P@$```````!P`P``
M_@0``'$(``"I`@```````````````````````'\$``"5"```Z@<``.,%``">
M`0``YP(```````!0````9`8``)`&``!^`0``;00``/P$``#/!P``F0,``/\#
M``")!```IP<``+H#```%`P``B`(```````#?`P```````&<"``"#!@``'P(`
M```````&`P```````)8#``!:`@```````#,'``#1!P``5`@`````````````
MV0(``/L&``#,`@``U0(``/4%``!7"```3````"H!``!S!0``+P0``*@!```J
M!@``W`@```````!/!@``(P8```````!]"```604``%8"``",````-`8``'D'
M``!T`@``M0@``-$&``!Q!0```````#H!``"+`P``S0$``+$(``!G`P``````
M`,,$```,`P```````*@&``!X!```\`(``,<"``!.!P``_P````````#(`@``
M`````(((```(`@``[0```%4(``#B`@``-P,``&0(````````Q@@``&,$````
M````/0(``%4"``"T!P```````$D'``"T`0``'@(``+(%``">`P```````.L'
M````````BP4``*D#``"6`0``T````$D%```````````````````L!```````
M`*D$```$!```]P,``-P!``"P`@``C0,``.(#````````6`4````````5!```
M``````````"E!@``8P,``+,(``#N`0``,@(``$(!````````Z@4``$0%````
M````T@@```````"G!@``*08``%D"``#]!P``!P(``"($````````C0```-4'
M``!`"````````-P'``#L!@``N@4````````!!0``7@4``!@#``#G"```````
M`-$#``"N!@``"0<```````##!0``1@<```,#``"1!P``P08``.\%````````
M`````)`!``#4"```O`4``/<'``#I!@``E00``,,#``#^!P``404``,<&``">
M!0````````````"K`P``G`(``*,&``#V!P``^04``-$$`````````````!8'
M``"U!0``N0```$T````,!P``J08``(<'`````````````*8%```C!P``````
M`/8!```Q!```%P$`````````````!@$``$,%```^`P``=P,``',#``!^!P``
MB0@``.X'````````V`$```````",!0```````#\```!`!P``````````````
M`````````,0```#0`@``C`,``)(&``!H!P``Z@8``)$(``!E!P``&@0`````
M``#=!P``O@8``'(%``#K!0``<`<``&P'````````````````````````C@0`
M````````````[04``$(%``!T````6P````````"P!P``N0$```````!6`0``
MOP```#@#``#R!```Z0````\!``!K`P``"P@```````#$!@``````````````
M````=@4```T"````````;P```#$&```2!0``;@```,(```!(!P```````+<$
M````````U`4``-$%``"]"```,0$``+P!``"8!0```````%H$``"%!@``L0,`
M``````"O`P``I@0``!`!````````3`,``)X(``">````_`4```,(``!)`P``
M`````.4!``!;!```Y0(``.$!``!<"```F@(``.H(``!5!```]`(```````#3
M`0``[`(``*`%```P`P``@@```%(%``!D!```4@$````````8`@```````)\#
M````````[@8``#((``!B`````````"`"``!+"```J@8``#X'``#'!```RP$`
M`,D```"B`@``5`<``-T#``"5````T0@```D(``"+!P``S04``&D'```C`@``
M50,``,0%``")!@``T@`````````#!@````````````#,!@``V0$``#,&```*
M!@```0<```````"\!@``]0```!D(````````+0````````!%`@``````````
M````````@P,``'T$````````_0```.P(````````4@8``%$!``!R!```````
M`)P(````````>P,``+4'```I"````````!@%``!2"```Y0<``&,"``"H````
M:@8``#0%````````ZP$``!H#``#R!0``GP8```0!``#X!@``600`````````
M````RP```!0```#)!````````%L'``"\`@``Q0(``,X```!/!P``1`(``.P#
M``"D"```4P,``((%```7!0``6P4``$@&````````0@@``,8&````````;0,`
M`*`'``"%!0``V@<``(\%``"X`0``LP```,$$``"."```V0<``$P&``#F`@``
M`````&8(``!K"```/@```.<!``!=````9`(``/0'``!:`0``#`(``&0#``!B
M`0``O0```"@&``#P`P``E@@``!H'```5!P``.0(```````")`@``````````
M``"@`@```````(T!``!T!P``T`<``!`"`````````````(L$``"M!0``'`4`
M`"$%```U"```+````(\#``#?!````````*L(```/!P``=P<```````"(`P``
MW`,``,8'```,!@``4P<``%$'```\`P``X@8``-@#````````E@8``,$```"P
M`0``MP8``.P```"8!P```````-8#``#%!0``$P``````````````VP8``,('
M````````1`8``!$'```'!0``M08`````````````"P````X"``#=!@``M@$`
M``````!H`P```````.P%```@!0``;`$``.H$````````W@@```````!2````
M;@$``,\%``!`````D0,``$L````:`0``]P8```````")!0``=`4`````````
M````6P,``(P!````````>0,``'$!```_!P``S@,``'L%``#V`P``>@8``-L'
M```)`@``Q@4```````!5!@``;`0``"L%````````9`<````````X`0``X`8`
M`+\%``#G!@``,@0``.$&```Z!```Y0,```4```#^`P``B@4``(<%``!A````
M*P@``#P&``"M!@```````/D&``"@````I`8``(4"``#\`@``1@8```````"1
M!```@@,``'\```"F!P``$0(``(4!```(`````@8```````#*!P``*`0``),#
M```>`0``10,````````$`P``&P(``"('```4"```#````&,```!I!@``M0(`
M`!0'``#4`0```````.\!````````CP<``&\'````````B````'\#````````
MJ@(``!D$````````@04``)H(```-!````````!`'```V"```(0,``)\````W
M!0``>````#H%``"W`P``:P8``%($```H"````````/L$``"1````````````
M```O`````````+8$``!&!```GP(``&````"B`P``FP0``!8#````````+@<`
M`#@"```\"``````````!``#G!```A`@``.H```!U````1P@```````!M!P``
MQP@``+0#```]`P``?`$``!,(`````````````((&``!?!P``'0(``+T%````
M````EP<``-T$``"T!0``4`8``&`&``#V!0``A0````````#/!@``````````
M``"C"```CP(```````"T!```90@``$("````````&`$``%H(```3!0``````
M`$@#````````^@,``)<&``";````M00``.4&`````````````+8(````````
M```````````X!```JP4`````````````$P,``+,%`````````0$``%T"``!G
M`0``2P,``"L#``!O`0```````#0```#D`0```````%T#``!;`@``P`8`````
M````````F@8```````"7"```````````````````UP0``+X!``"5`P``F`(`
M`(`!``#,`0`````````````]!P``^@````X#``!+!P``H`,``/D"``"N!0``
MK@,``````````````````!L&````````@P@``!(#``"(!P```````,0$````
M````$@```,T"````````NP```.$(``"R`0````````````#&!```G04``+L(
M``"9`0````@``+L%`````````````'$'````````D@0``.L&````````/`$`
M`.T$``"=!P``T@0``!X&````````D0(``(P'``#(!@``10<```````"_`0``
M`````#,#``#0!0``UP```&@$``#P````F`0```,'``!9!P``P0,``#<```"O
M!```RP@``+H'```7!```*P8``.`"``"J`````````&P```"4!0``208`````
M``!W!@``HP````H(``"9"```I@8```````")`0``B0,``"4&``"R`@``Y```
M``````"$!P``&@4``,L&```B`P``7@,``&8#``#;`P``'`$``"(%````````
M`````.\&``#Y!````````"P(``!"````:00```````!(!```XP@``&$&````
M````,`<``)T&```4`@``0`,``'$```"4!```Z`$```P$```]````(@$``%T%
M``#B`0```````%0$``#<!0``U`(``/L%````````IP,````````U`P``Y`@`
M````````````O0<``$T"``!!`0``=@8``)<#``#@!```B`4```````!Z"```
M``````````#7`0``=@0``#H#``";`P````````````!L`P``G`<```````!1
M"```+0$``*(`````````7`$``%$&``!5`0``HP(``/$'``#K`P``+0<``(<$
M`````````````!0%``!S"```+`(```X$``!@`@```````+,!```D!@``````
M`/`%````````U`8``$($``#T`0``Z0@``!D"``#-!P``F````#`$``!6!```
MUP,```X&`````````@````````"*`@``F0<``"T&```<!@```````$0'``"3
M`0``K`$``!<&````````[P(```8&````````;P8``!<(```["```/`4``.($
M```+!```-P8``&8!````````.0$``',&``#I`@```````#4$``!A`P``4`$`
M`%8#``!=!@``1P(``"@%``"K!@```````.X(`````````````/T$``"+"```
MI0<``!D```"Q!```XP0````````\`@``800``%T'``"R``````````````"&
M"```!`@````````&`@``:`@```L&``"+`0``O00```````!,"```(08``*`&
M````````DP4``.8```"%!```)@<``,,&``#`!````````)$%````````.@``
M`-<%``#X!```D08`````````````M@(``'T'````````D`,``*@'``"G`0``
MGP0``+\"````````]`4````````O"```Q@(``+L&````````!08``"\"``"&
M`0```````!H"````````R@````@&``!F!@```````.,````D````P`@``$4%
M```?!P```````$@"``",!`````````````#7"```%08``&8'``"D!0``````
M``````"!`P``````````````````N0@``#D$````````H`0``)H#``!3`@``
MZP@``#D``````````````*P'``````````````````"2`P``(@````(!``":
M!````````#(!``!]!0``90(`````````````AP(``#0(```#!```K`0`````
M``#<!@```````%<%``"!!```D@@```````#T````<P0``(@(``#'`0``<P$`
M```````/"````````)('``#)`@``)@0```(%``!V`0``R````)@&``!.!@``
MAP8``!$$``"F`@``*00``*H#``!W"```>`8``$H'``"&!0``@@<``*$$``"H
M!`````````````````````````````#0`P```````",%``#L!P``*@0``%`'
M```E"```[P0``&X#``"P!@``HP0``*$&```Q`````````+,#````````0@,`
M`.$'```;"```Z`(```````````````````````#9!@``:0@``,H&```'!@``
M1@``````````````K00``!4"``"$`P``3`0``+8#`````P``<@(`````````
M``````````````#[!P``"@(``.@'````````S0,```````"W"```````````
M``#.`@````````````#@"```EP```#X%``!&`P```````)0"``!``0``L```
M`+,&``#@`````````$,!`````````````'@%```A"```4@(``%P%``!1`P``
M;08```````"]!@``N0,``)@!``!@!P``80$``+H(``#-!@``K0(```````"A
M`@```````"$``````````````%X$``#,`P``S@0``%$```!7!@``/`<``%0!
M``"7!```*@@``+4!````````>P0``%H```#Y`````````/<%``!-"```>00`
M`*0!``"&`P``)@(``*P#``#?````<`(```````#J`@``8P8``&<$``!_"```
M`````%8(````````S`4``!$#```#`0``60,```````!7!P``7P@``"0'```R
M!@``)`$``/@%``#!`@``K````/\!``#]!@``/04```````!E!0```````.X%
M````````3`4``/,$``#:`P``S@4``-X'````````=0$``!("``!F!0``````
M`&D!``#F!@``O@0``````````````````$H````F`P``%@$``.@$```W`0``
M\`$``+@(```^!```&@```)T!```L`P``U@0```<!````````.````*P%``"<
M!0``,`$``%X```"\"```>04``"4%``````````````4'``!H!0``^0,`````
M``#D!0``[0@``.\#```S`0``?@````````#/`0``G`,``%X&```(`0``<P(`
M`!$&````````:@```+<"````````*04``"L!```J!P```````(,'````````
MY`(``````````````````+\$``"O!0``W@(`````````("@E<R!D87ES(&%G
M;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E
M8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D
M(&-A;&5N9&%R<R!F;W5N9``E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@
M97AP:7)E<RX`)60@979E;G1S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC
M90`E<R!$87DH<RD@)7,@2&]U<BAS*2`E<R!-:6YU=&5S`"5S($9I;F=E<G!R
M:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE
M;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&%T=&5N9&5E
M<P`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D
M`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S
M($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S
M(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@
M=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"A#;&EC:R!O;B!C86QE
M;F1A<B!N86UE('1O('-W:71C:"!T:&4@8V%L96YD87(G<R!V:7-I8FEL:71Y
M(&EN('1H92!M86EN('=I;F1O=RD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@
M061D("H`*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("H`+"!G=7-T:6YG
M(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM
M('-E;&5C="`M+0`Q(&%T=&5N9&5E`#$@979E;G0`,2!H;W5R`#$R($AO=7(@
M1F]R;6%T`#$U(&UI;G5T97,`,C`@;6EN=71E<P`R-"!(;W5R($9O<FUA=``R
M-"!H;W5R<P`S,"!M:6YU=&5S`#Q0<F5V:6]U<P`\<W1R;VYG/D%T=&5N9&5E
M<SPO<W1R;VYG/B`H;W!T:6]N86PI`#QS=')O;F<^1&5S8W)I7W!T:6]N/"]S
M=')O;F<^("AO<'1I;VYA;"D`/'-T<F]N9SY+97EW;W)D<SPO<W1R;VYG/B`H
M;W!T:6]N86PI`#QS=')O;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H;W!T:6]N
M86PI`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M04T`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S
M`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET
M;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'1E9`!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C
M;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9%]V
M86YC960@4V5A<F-H`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E
M<FUI<W-I;VX`061D($5V96YT`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D
M9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D
M9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@4F5M;W1E
M($-A;&5N9&%R`$%D9"!A(&YE=R!E=F5N=`!!9&0@82!N97<@=7-E<CH`061D
M(&%T=&5N9&5E<P!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O
M(&%D9')E<W,@8F]O:SH`061D('1O(&%T=&5N9&5E<P!!9&0@=&\@;7D@861D
M<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`061V86YC960@4V5A<F-H
M`$%F9VAA;FES=&%N`$%L87)M`$%L87)M("5D(&1A>7,@8F5F;W)E`$%L87)M
M("5D(&AO=7)S(&)E9F]R90!!;&%R;2`E9"!M:6YU=&5S(&)E9F]R90!!;&%R
M;2`E9"!W965K<R!B969O<F4`06QA<FT@,2!D87D@8F5F;W)E`$%L87)M(#$@
M:&]U<B!B969O<F4`06QA<FT@,2!M:6YU=&4@8F5F;W)E`$%L87)M(#$@=V5E
M:R!B969O<F4`06QA<FT@1&%T90!!;&%R;2!3<&%N("AM:6YU=&5S*0!!;&%R
M;2!4:6UE`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z
M`$%L;`!!;&P@071T96YD965S`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!&=71U<F4`06QL($=R;W5P<P!!;&P@4&%S=`!!;&P@4&5R;6ES<VEO;G,`
M06QL(%9I<VEB;&4`06QL(&1A>0!!;&P@9&%Y(&5V96YT`$%L;"!E=F5N=',`
M06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S
M`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I
M8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG
M=6$@86YD($)A<F)U9&$`06YY`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI
M<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E
M<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD
M;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E
M<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE
M;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!
M<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S
M:6=N;65N="!C;VQU;6YS`$%T`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F
M:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@979E;G0N($EF
M('EO=7(@;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I<"!R97%U97-T<R!Y;W4@
M8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P9&%T92!Y;W5R(&QO8V%L
M(&-O<'D@;V8@=&AE(&5V96YT+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S
M:&%R92X`071T96YD86YC90!!='1E;F1E97,`071T<FEB=71E<P!!=6=U<W0`
M075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN
M`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@
M9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A
M8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R
M8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX
M.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER
M96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"87-I8R!396%R8V@`
M0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!"
M:7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O
M=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!"
M;V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S
M;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V
M970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"
M=7)K:6YA($9A<V\`0G5R=6YD:0!"=7-Y`$--4P!#4D,`0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',`0U]A;&5N9&%R`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C
M:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L7V5N9&%R`$-A;&5N9&%R
M`$-A;&5N9&%R(%-U;6UA<GD`0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E
M9"X`0V%L96YD87)S`$-A;&5N9&%R<R!M=7-T(&AA=F4@82!N86UE+@!#86QM
M`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T
M;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N
M;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N
M86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,`0V%N)W0@8W)E871E(&$@;F5W(&5V96YT+@!#86XG="!O<&5N
M(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O
M<G0`0V%N8V5L;&5D`$-A;F-E;&QE9#H@)7,`0V%N;F]T(&1E;&5T92!F:6QE
M("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#
M86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E
M9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)?
M>0!#871E9V]R:65S(&%N9"!,86)E;',`0V%T96=O<GD`0V%Y;6%N($ES;&%N
M9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#
M96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC
M("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI
M8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$
M971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S
M`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`
M0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D
M("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!
M<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA
M;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@:68@>6]U
M('=A;G0@=&\@8F4@;F]T:69I960@;V8@;F5W+"!E9&ET960L(&%N9"!D96QE
M=&5D(&5V96YT<R!B>2!E;6%I;#H`0VAO;W-E(&EF('EO=2!W86YT('1O(&)E
M(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',N
M`$-H;V]S92!I9B!Y;W4@=V%N="!T;R!R96-E:79E(&5M86EL(')E;6EN9&5R
M<R!F;W(@979E;G1S('=I=&@@86QA<FUS.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O
M;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z`$-H;V]S92!T:&4@
M8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXZ`$-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@=VAE;B!G
M96YE<F%T:6YG(&9R964O8G5S>2!54DQS.@!#:&]O<V4@>6]U<B!D969A=6QT
M(&-A;&5N9&%R+@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L
M96%R(%%U97)Y`$-L96%R(&%L;"!A='1E;F1E97,`0VQE87(@;W5T('5S97(Z
M("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`
M0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7
M:6YD;W<`0VQO<V4@=VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y
M`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L
M;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O
M;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M
M;6$@<V5P87)A=&5D('9A;'5E<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M
M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O
M;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`
M0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO
M;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&1E;&5T
M:6]N(&]F(&5V96YT<S\`0V]N9FER;65D`$-O;F=O`$-O;F=O+"!4:&4@1&5M
M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O
M;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N
M="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`
M0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D
M.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W!Y('1H92!54DP@8F5L;W<@9F]R('5S
M92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ`$-O<W0@
M240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK
M9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S
M(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N
M;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`
M0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@0V%L96YD87(`0W)E871E
M(&$@3F5W($5V96YT`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#
M<F5A=&4@<W5B(&9O;&1E<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS
M`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N=`!#=7)R
M96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U
M<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N
M`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L
M:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$86EL
M>3H@4F5C=7)S(&5V97)Y`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O
M:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&%Y
M*',I`$1E7VQE=&4`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N
M=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U
M;'0@0V%L96YD87(`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E
M9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92`E<P!$96QE
M=&4@0V5L;`!$96QE=&4@179E;G0`1&5L971E($=R;W5P`$1E;&5T92!,;V<`
M1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$
M96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T
M:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@
M86QL(&]C8W5R96YC97,_`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E
M9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E
M;FUA<FL`1&5S8W)I7W!T:6]N`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R
M:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D`1&ES<&QA>2`R
M-"UH;W5R('1I;65S/P!$:7-P;&%Y($-A;&5N9&%R<P!$:7-P;&%Y($]P=&EO
M;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T
M("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@
M=VAI8V@@87)E(&1U92!O;B!Y;W5R(&-A;&5N9&%R/P!$;V5S(&YO="!R96-U
M<@!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!2
M97!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL
M;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$1U93H@
M)7,`1'5R871I;VX`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E
M<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%
M4E(`16-U861O<@!%9&ET`$5D:70@)7,`161I="!!='1E;F1E97,`161I="!"
M;&]C:P!%9&ET($-A;&5N9&%R<P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO
M;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D
M:70@4F5M;W1E($-A;&5N9&%R<P!%9&ET(&%T=&5N9&5E<P!%9&ET(&-A=&5G
M;W)I97,@86YD(&-O;&]R<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI
M<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A
M=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I
M8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C
M:"!T97)M<P!%;E]D`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@
M4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C
M;VYT97AT(&UE;G4_`$5N9"!$871E`$5N9"!/;@!%;F0@5&EM90!%;F0@>65A
M<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T
M97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@<F5T<FEE=FEN9R!F<F5E+V)U<WD@
M:6YF;W)M871I;VX@9F]R("5S.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG
M("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5N="!A
M9&1E9#H`179E;G0@9&5L971E9#H`179E;G0@961I=&5D.@!%=F5N="!F<F]M
M("5S('1O("5S`$5V96YT(&YO="!F;W5N9`!%=F5N=',@;75S="!H879E(&$@
M<W1A<G0@9&%T92X`179E;G1S(&UU<W0@:&%V92!A('1I=&QE+@!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A
M;F0@3F%M97,`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$
M871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@0V%L96YD87(`1D<@0V]L;W(`
M1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R
M;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R
M96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B
M)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A
M>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@
M4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@
M0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.
M86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;F0`1FEN;&%N9`!&:7)S="!(86QF
M`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U
M<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N
M97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC
M90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E`$9R964O0G5S>2!);F9O<FUA
M=&EO;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S`$9R:61A>0!&<F]M`$9R;VT@=&AE(`!&=6QL
M($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1G5T=7)E`$=A8F]N
M`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'
M86UE`$=E;F5R86P`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T
M960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N
M($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O
M;V=L92!396%R8V@`1V]T;R`E<P!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)
M4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A
M=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U
M<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R
M;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T
M(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'
M=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET
M:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E
M=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O
M<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z`$AI9&4`2&ED92`E<P!(:6=H`$AO7VUE`$AO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER
M96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N
M9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R
M871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS
M:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E
M92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N
M=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]U<BAS*0!(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;&]N9R!S:&]U;&0@=&AE
M('1I;64@<VQO=',@;VX@=&AE(&1A>2!A;F0@=V5E:R!V:65W<R!B93\`2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA
M;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M871I;VX@<VAO=6QD('=E(&=E
M;F5R871E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I
M='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N
M<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG
M<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@
M86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE
M960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N`$EF('EO=7(@96UA:6P@8VQI96YT(&1O97-N
M)W0@<W5P<&]R="!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T
M:&4@9F]L;&]W:6YG(&QI;FMS('1O(&%C8V5P="!O<B!D96-L:6YE('1H92!E
M=F5N="X*"E1O(&%C8V5P="!T:&4@979E;G0Z"B5S"@I4;R!A8V-E<'0@=&AE
M(&5V96YT('1E;G1A=&EV96QY.@HE<PH*5&\@9&5C;&EN92!T:&4@979E;G0Z
M"B5S`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E
M(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A
M9`!);6%G97,`26UP;W)T($-A;&5N9&%R+"!3=&5P("5D`$EM<&]R="P@4W1E
M<"`E9`!);7!O<G0O17AP;W)T($-A;&5N9&%R`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`
M26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA
M=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@
M0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R
M="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@
M8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O
M<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@
M<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T
M+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN
M=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`
M26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV
M86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T
M`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED
M960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@
M<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP
M:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C
M92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN
M=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q
M`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L
M`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA
M<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`
M2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,
M969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+
M96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`
M2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97EW;W)D<P!+:61S`$MI
M<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY
M<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8P!,87-T(#(T(&AO=7)S`$QA<W0@2&%L9@!,87-T($UO
M9&EF:65D`$QA<W0@36]N=&@`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1
M=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!996%R`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%S
M="!W965K`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE
M<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI
M96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A
M:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3
M:&]W97(`3&EM97)I8VL`3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z
M`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN
M=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T
M($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M
M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S
M=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S
M<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`
M3&]?8V%T:6]N`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@
M5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S
M<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B
M96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@
M:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W
M`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E
M<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N
M:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A
M<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`
M36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@<F5M;W1E(&-A
M;&5N9&%R<RX`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA
M<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E
M`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL
M;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!.=6UB97(@;V8@179E;G1S`$UA>&EM=6T@3G5M8F5R(&]F(%!O
M<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`364`365D
M:6-I;F4`365E=&EN9P!-96UB97)S`$UE;G4@06QA<FUS`$UE;G4@3&ES=`!-
M96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G
M92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN
M960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R
M:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED
M9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E
M;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO
M="!Y970@97AP:7)E9`!-:6YU=&4H<RD`36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-
M:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B
M;&EC(&]F`$UO;F%C;P!-;VYD87D`36]N9V]L:6$`36]N=&@`36]N=&@@5FEE
M=P!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1H;'D@179E;G1S($QI<W0`
M36]N=&AL>3H@4F5C=7)S(&5V97)Y`$UO;G1H<R!!:&5A9`!-;VYT:',@0F5F
M;W)E`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@
M:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T
M;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD
M>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE
M(&E#86QE;F1A<B!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!V179E;G0@
M:7,@<W5P<&]R=&5D+@!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY($-A;&5N9&%R<P!->2!#86QE;F1A
M<G,Z`$UY($9R964O0G5S>2!54DP`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO
M=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA
M=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE
M='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE
M='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T
M<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE
M`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A
M=&5G;W)Y`$YE=R!%=F5N=`!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO
M;F%L*0!.97<@6F5A;&%N9`!.97<@8V%L96YD87(@8W)E871E9"!A;F0@875T
M;VUA=&EC86QL>2!S:&%R960@=VET:"!T:&4@9F]L;&]W:6YG(&=R;W5P*',I
M.B`E<RX`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O
M;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H
M7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#(T(&AO=7)S`$YE
M>'0@-"!0:&%S97,`3F5X="!$87D`3F5X="!-;VYT:`!.97AT(%=E96L`3F5X
M="!996%R`$YE>'0@9&%Y`$YE>'0@;W!T:6]N<P!.97AT('=E96L`3F5X=#X`
M3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A;&%R
M;0!.;R!A='1E;F1E97,`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T
M82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T
M96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N
M`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO
M(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I
M;VXN`$YO(&-A;&5N9&%R<R!A<F4@879A:6QA8FQE('1O(&=U97-T<RX`3F\@
M8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M
M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET
M(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!E;F0@9&%T90!.
M;R!E=F5N=',@=&\@9&ES<&QA>0!.;R!F:6QE('5P;&]A9&5D`$YO(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S`$YO(&E#86QE
M;F1A<B!D871A('=A<R!F;W5N9"X`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T
M:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@
M<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF
M:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T
M82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')E8W5R
M<F5N8V4`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED
M97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;&ED(&5M86EL
M(&%D9')E<W,@9F]U;F0`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L
M:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R
M=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R
M=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@
M9F]U;F0`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N
M`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I9FEC871I
M;VYS`$YO=F5M8F5R`$YO=P!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`
M3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`
M3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS
M92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E
M(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="X`3VUA;@!/;@!/;B!A;&P@8V%L96YD87)S($D@:&%V92!R96%D
M(&%C8V5S<R!T;P!/;B!A;&P@<VAO=VX@8V%L96YD87)S`$]N(&UY(&-A;&5N
M9&%R<R!O;FQY`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL
M(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R
M;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E
M;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE
M9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;F%L`$]P=&EO;F%L($%T=&5N9&5E
M<P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES
M871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W9E<G9I97<`3W=N97(`3W=N
M97(@4&5R;6ES<VEO;G,`3W=N97(Z("5S`%!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET
M86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME
M>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L
M;`!030!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W
M`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT
M96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N
M`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA
M`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S
M=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@
M:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N
M=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D
M.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T($5V96YT
M<R!,:7-T`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&%T=&5R
M;@!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_`%!E<FUA;F5N=&QY(&1E;&5T92!T:&ES(&5V96YT
M/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R
M;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI
M<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E
M<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N
M`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A
M('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L
M(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S
M92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R
M>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT
M+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y
M<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA
M;F0`4&]L:71I8W,`4&]L;',`4&]R=&%L($]P=&EO;G,`4&]R='5G86P`4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I
M=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R
M92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S($1A>0!0<F5V:6]U
M<R!7965K`%!R979I;W5S(&1A>0!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O
M8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO
M;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@
M06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP
M86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0
M=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME
M>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A
M:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO
M=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A
M;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8W5R(%5N=&EL`%)E8W5R
M<F5N8V4`4F5C=7)R96YC92!$871A`%)E8W5R<F5N8V4@16YD($1A=&4`4F5C
M=7)R96YC92!);G1E<G9A;`!296-U<G)E;F-E(%1Y<&4`4F5C=7)S(&1A:6QY
M`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`4F5C=7)S('EE87)L>0!2
M961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!2
M96QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!296UI;F1E<CH@
M)7,`4F5M;W1E($-A;&5N9&%R<P!296UO=&4@0V%L96YD87)S.@!296UO=&4@
M4V5R=F5R<P!296UO=&4@4W5B<V-R:7!T:6]N(%523`!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92`E
M<P!296UO=F4@071T96YD964`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`
M4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V
M92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO
M=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5P;&%C92!E>&ES=&EN9R!C86QE
M;F1A<B!W:71H('1H92!I;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@
M5&AI<R!D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE
M;F1A<BX\+W-T<F]N9SX`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@
M;F]T(&)E(&9O=6YD+@!297%U:7)E9`!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@
M<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@071T
M96YD965S`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E
M<V5T(%EO=7(@4&%S<W=O<F0`4F5S970@=&\@1&5F875L=',`4F5S<&]N<V4`
M4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`
M4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T
M:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I
M9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O
M;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H
M=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E
M9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R
M90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!3
M44P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?
M44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I
M<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF
M*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E
M;&QI=&4@4')O=FED97(`4V%T=7)D87D`4V%U9&D@07)A8FEA`%-A=F4`4V%V
M92`B)7,B`%-A=F4@)7,`4V%V92!!<R!.97<`4V%V92!!='1E;F1E97,`4V%V
M92!%=F5N=`!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O
M<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!#86QE;F1A<G,`4V5A<F-H($5N
M9VEN97,`4V5A<F-H(%)E<W5L=',`4V5A<F-H(&9O<B!C86QE;F1A<G,@8V]N
M=&%I;FEN9SH`4V5L96-T($9I;&5S`%-E;&5C="!A(&-A;&5N9&%R('1O(&5D
M:70`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T
M(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O
M(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!3
M96QE8W0@86X@;V)J96-T`%-E;&5C="!C86QE;F1A<G,@=&\@9&ES<&QA>3H`
M4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T
M:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@9&5F875L="!V:65W+@!3
M96QE8W0@;F]N90!396QE8W0@=&AE(&-A;&5N9&%R('1O(&EM<&]R="!T;SH`
M4V5L96-T('1H92!C86QE;F1A<BAS*2!T;R!E>'!O<G0@9G)O;0!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE
M8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE(&9I<G-T('=E96MD
M87DZ`%-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E
M;&5C="!T:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C="!T:&4@=FEE=R!T
M;R!D:7-P;&%Y(&]N('-T87)T=7`Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@:6X@=&AE('!O<G1A
M;"X`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`
M4V5N9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL(&%T=&5N9&5E<R!W
M:&5N(&1E;&5T:6YG('1H:7,@979E;G0`4V5N9"!A;B!E;6%I;"!T;R`E<P!3
M96YD('5P9&%T97,O:6YV:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N
M('-A=FEN9R!T:&ES(&5V96YT`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R
M`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S
M<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&5N9"!D871E`%-E
M="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D
M(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T(')E8W5R<F5N8V4@96YD(&1A
M=&4`4V5T('-T87)T(&1A=&4`4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R
M(&9R964O8G5S>2!C86QE;F1A<G,@86YD('EO=7(@;W=N(&%N9"!O=&AE<B!U
M<V5R<R<@9G)E92]B=7-Y(&]P=&EO;G,N`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&%R
M92!N;W0@9F]U;F0Z("5S`%-H87)E9"!#86QE;F1A<G,`4VAA<F5D($-A;&5N
M9&%R<SH`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W($-A;&5N
M9&%R`%-H;W<@8V%T96=O<GD@;&5G96YD/P!3:&]W(&1E;&5T92P@86QA<FTL
M(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/P!3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@9'5E('1A<VMS
M(&EN('1H92!C86QE;F1A<C\`4VAO=R!F<F5E+V)U<WD@;&5G96YD/P!3:&]W
M(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;VYL>2!E
M=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\`4VAO=R!O<'1I;VX@=&\@
M:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('-H87)E9"!C86QE;F1A
M<G,@<VED92UB>2US:61E/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B
M87(_`%-H;W<@=&%S:W,@=7-I;F<@8V%T96=O<GD@8V]L;W)S/P!3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('1I;64@;V8@9&%Y
M(&)E='=E96X@96%C:"!D87D@:6X@=V5E:R!V:65W<S\`4VAO=R!U<&QO860`
M4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN
M('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N
M90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A
M<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`
M4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A
M<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG
M<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S
M`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U
M=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A
M8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN
M`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T85]R=`!3=&%N9&%R9`!3
M=&%R(%1R96L`4W1A<G0@1&%T90!3=&%R="!/;@!3=&%R="!4:6UE`%-T87)T
M('EE87(`4W1A=%]U<P!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G
M92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@
M;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-3
M70!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B
M;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@
M8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY
M(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R
M960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S
M(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A
M=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S
M9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A
M;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N9&%Y`%-U;FYY`%-U;G)I
M<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3
M=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y
M;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N
M9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L
M92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A
M;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N
M92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M
M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI
M;FES=')A=&EO;@!496YT871I=F4`5&5X=`!497AT($]N;'D`5&5X="!A;&EG
M;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!%9&ET
M($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N($5X:71I
M;F<N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(
M:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-
M4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4
M:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V%L96YD87(@(B5S(B!C86YN;W0@
M8F4@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@8W)E871E
M9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&-A
M;&5N9&%R("(E<R(@:&%S(&)E96X@<F5N86UE9"!T;R`B)7,B+@!4:&4@8V%L
M96YD87(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&-A;&5N9&%R(&-O=6QD
M(&YO="!B92!P=7)G960Z("5S`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN
M('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S
M:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N
M960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H
M97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@
M=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S
M<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E;F0@9&%T92!M=7-T(&)E(&QA
M=&5R('1H86X@=&AE('-T87)T(&1A=&4N`%1H92!E=F5N="`B)7,B(&AA<R!B
M965N(&%D9&5D('1O("(E<R(@8V%L96YD87(L('=H:6-H(&ES(&]N("5S(&%T
M("5S+@!4:&4@979E;G0@(B5S(B!H87,@8F5E;B!D96QE=&5D(&9R;VT@(B5S
M(B!C86QE;F1A<BP@=VAI8V@@=V%S(&]N("5S(&%T("5S+@!4:&4@979E;G0@
M(B5S(B!H87,@8F5E;B!E9&ET960@;VX@(B5S(B!C86QE;F1A<BP@=VAI8V@@
M:7,@;VX@)7,@870@)7,N`%1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@
M=V%S('-U8V-E<W-F=6QL>2!S96YT+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I960@
M;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+@!4:&4@9F]L;&]W:6YG(&ES(&$@;6]R92!D971A:6QE
M9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z`%1H92!F=6QL('-C<F5E;B!M
M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@
M17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T
M(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A
M<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O
M<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L
M969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@
M8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S
M+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B
M)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@
M;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA
M>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W
M('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N`%1H92!R97%U97-T('=A<R!I;F-O;7!L971E+B!3;VUE('!A
M<F%M971E<G,@=&AA="!A<F4@;F5C97-S87)Y('1O(&%C8V5P="!O<B!D96-L
M:6YE(&%N(&5V96YT(&%R92!M:7-S:6YG+@!4:&4@<FEG:'0@86YD(&QE9G0@
M<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R
M871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N
M(')E;6]V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI
M<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N
M('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H
M92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I
M;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@
M879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4
M:&5R92!A<F4@;F\@979E;G1S(&UA=&-H:6YG('1H92!C=7)R96YT(&-R:71E
M<FEA+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T
M;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG
M(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@
M=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL
M;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A
M;&5N9&%R.B`E<P!4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N
M=#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I;F<@=&AE(&5V96YT
M.B`E<P!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R
M871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F
M:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S
M`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC
M871I;VX@=&\@)7,Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W97)E(&YO(&5V
M96YT<R!T;R!E>'!O<G0N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D
M869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W
M:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O
M<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4
M:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@
M5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L
M:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R
M;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@
M=FES:70@)7,`5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A
M;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU
M;F1E<@!4:'5R<V1A>0!4:6-K971S`%1I;64`5&EM92!3<%]A;@!4:6UE(%1R
M86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;64@<W!A;@!4
M:6UO<BU,97-T90!4:71?;&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4
M;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4
M;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W
M`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S
M="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`
M5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U97-D87D`
M5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP90!4>7!E
M('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E
M<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S
M(CH@)7,`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E
M;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B
M;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F
M86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@
M=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("(E<R(Z
M("5S`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O
M;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`
M56YA8FQE('1O(')E=')I979E(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@
M)7,`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL
M960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E
M<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D
M`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@
M2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E
M<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`
M56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<P!5;G-U<'!O<G1E9"!%>'1E
M;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E
M<R(N`%5P9&%T960Z("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO
M860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M
M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S
M97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M
M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`57-E<B!/<'1I;VYS`%5S97(@
M4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E
M<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z
M`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI
M;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N
M9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A
M='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T
M:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S
M:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P
M861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S
M92`H5DE30TE)*0!6:65W("5S`%9I97<@1&%Y`%9I97<@86X@97AT97)N86P@
M=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6
M:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6
M;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%
M(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES
M(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H
M97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`
M5V5D;F5S9&%Y`%=E96L`5V5E:R`E9`!7965K*',I`%=E96ML>0!7965K;'DZ
M(%)E8W5R<R!E=F5R>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I
M`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAA="!T:6UE
M('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD+"!W:&5N('1H97)E(&%R
M92!N;R!L871E<B!E=F5N=',_`%=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W
M965K('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V
M96YT<S\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE
M`%=O<FL@5V5E:P!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI
M;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N
M<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N
M=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!9
M96%R`%EE87)L>0!996%R;'DZ(%)E8W5R<R!E=F5R>0!996UE;@!997,`665S
M+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@979E;G1S
M+@!9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF:65D(&5V
M96YT+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&]N;'D@
M=7-E('1H:7,@9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN
M`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9
M;W4@9&\@;F]T(&AA=F4@86X@96UA:6P@861D<F5S<R!C;VYF:6=U<F5D(&EN
M('EO=7(@4&5R<V]N86P@26YF;W)M871I;VX@3W!T:6]N<RX@66]U(&UU<W0@
M<V5T(&]N92`E<VAE<F4E<R!B969O<F4@979E;G0@;F]T:69I8V%T:6]N<R!C
M86X@8F4@<V5N="X`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D
M(&5V96YT<R!T;R`E<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M861D(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L96YD87(N`%EO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T92!T:&ES(&5V96YT+@!9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N`%EO
M=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@<W!E8VEF:65D(&%N
M(&EN=F%L:60@8V%L96YD87(N`%EO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E
M<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N`%EO=2!H879E('-U8V-E
M<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N`%EO
M=2!H879E('1E;G1A=&EV96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI
M<R!E=F5N="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@
M=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I
M9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O
M8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O`%EO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N
M`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@
M;F5E9"!T;R!S96QE8W0@82!C86QE;F1A<B!F:7)S=`!9;W4@<F5Q=65S=&5D
M('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T;R!Y;W5R
M(&-A;&5N9&%R<RX`66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N
M(&5V96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+@!9;W4@
M<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET
M960@:6X@>6]U<B!C86QE;F1A<G,N`%EO=2!R97%U97-T960@=&\@8F4@<F5M
M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+@!9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U
M<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O
M<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@
M3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T
M;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I
M9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S
M+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U
M<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-A;&5N9&%R`%EO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R
M;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=`%M5;FYA;65D(&5V96YT70!;;&EN92`E<R!O
M9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]!;&%R;0!?0F%S:6,@4V5A<F-H`%]#
M3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]%9&ET`%]';W1O`%]'<F]U<',`
M7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQO
M9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7TUY($-A;&5N9&%R<P!?
M3F5W($5V96YT`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V
M92!,:6YK+BXN`%]396%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN
M`%]4;V1A>0!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N
M`&)E9F]R92!T:&4@979E;G0@<W1A<G1S`&-A;&5N9&%R`&-A;&T`8V%N;F]T
M(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H
M97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R
M<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@
M97)R;W(`9&%Y`&1A>2AS*0!D87ES`&5D:70`96YT<GD@;F]T(&9O=6YD`&5V
M96YT<RYC<W8`979E;G1S+FEC<P!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N
M`&EM;65D:6%T90!I;@!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R
M;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@
M)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;6]N=&@H<RD`;F%M90!N;W0@:6UP
M;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`&]N("5S(&%T
M("5S`&]N('1H92!S86UE(&1A=&4`;VX@=&AE('-A;64@=V5E:V1A>0!P97)C
M96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@
M<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F
M97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E
M<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S
M<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S
M96QE8W0`=D-A;&5N9&%R+VE#86QE;F1A<@!V0V%R9`!V179E;G0@;F]T(&9O
M=6YD+@!W.@!W96%T:&5R+F-O;0!W965K`'=E96LH<RD@;VXZ`'=E96MS`'EE
M87(H<RD`4')O:F5C="U)9"U697)S:6]N.B!+<F]N;VQI=&@@,BXQ+6-V<PI2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT-RLP,3`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z-38K,#$P,`I,87-T+51R86YS;&%T
M;W(Z($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"DQA;F=U86=E+51E
M86TZ($=E<FUA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO
M;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M
M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`@*'9O
M<B`E<R!486=E;BD`("A:=6=R:69F<W1A<W1E("5S*0`@*&EN("5S(%1A9V5N
M*0`@*&AE=71E*0`@*&UO<F=E;BD`("AG97-T97)N*0`@;6ET(``B)7,B(&ES
M="!K96EN(%9E<GIE:6-H;FES+@`B)7,B(&ES="!K96EN92!G_&QT:6=E($%U
M<W=A:&PN`"(E<R(@:7-T(&EN(&1E<B!(;W)D92!296=I<W1R>2!N:6-H="!K
M;VYF:6=U<FEE<G0N`$1E<B!"875M+5)E;F1E<F5R(&;\<B`B)7,B('=U<F1E
M(&YI8VAT(&=E9G5N9&5N+@`B)7,B('=U<F1E('IU;2!'<G5P<&5N<WES=&5M
M(&AI;GIU9V5F_&=T+@`B)7,B('=U<F1E('IU;2!296-H=&5S>7-T96T@:&EN
M>G5G96;\9W0N`"(E<R(@=W5R9&4@;FEC:'0@97)S=&5L;'0Z("5S+@`E+C)F
M34(@*"4S)"XR9B4E*2!V;VX@)3(D+C)F34(@97)L875B=&5N('9E<F)R875C
M:'0`)60@)7,@=6YD("5S`"5D($MA;&5N9&5R(&=E9G5N9&5N`$EN("5D(%1A
M9V5N('=I<F0@26AR(%!A<W-W;W)T('5N9_QL=&EG+@`E9"!497)M:6YE`"5D
M+51A9V4M5F]R:&5R<V%G90`E<R`M($AI;G=E:7,`)7,@5&%G*&4I("5S(%-T
M=6YD92AN*2`E<R!-:6YU=&5N`"5S($9I;F=E<F%B9')U8VL`)7,@2T(`)7,@
M5V%R='5N9W-A<F)E:71E;B`M($)E<W3D=&EG=6YG`"5S+4MO;F9I9W5R871I
M;VX`)7,@4F5G:7-T<FEE<G5N9P`E<R!.=71Z=6YG<V)E9&EN9W5N9V5N`"5S
M(&5X:7-T:65R="!B97)E:71S+@`E<R!M:70@)7,@)7,`)7,@5&5I;&YE:&UE
M<@!$:64@)7,M1&%T96D@=W5R9&4@97)F;VQG<F5I8V@@:6UP;W)T:65R=``E
M<R!W:7)D(&1I92!787)T=6YG<V%R8F5I=&5N(&1U<F-H9OQH<F5N+"!D:64@
M=6YT96X@;6%R:VEE<G0@<VEN9"X@36%R:VEE<F5N(%-I92!A;&QE($%U9F=A
M8F5N+"!D:64@:F5T>G0@9'5R8VAG96;\:')T('=E<F1E;B!S;VQL96XN`"5S
M(&ES="!N;W1W96YD:6<`)7,@36EN=71E;@`E<R!N:6-H="!G969U;F1E;BX`
M)7,@8FES("5S('9O;B`E<P`E<W,@061R97-S8G5C:``E<W,@2V%L96YD97(`
M)7-S($YO=&EZ8FQO8VL`)7-S($%U9F=A8F5N;&ES=&4`)7,Z("5S`"5S.B!$
M:65S92!.86-H<FEC:'0@<W1A;6UT('5N=&5R(%5M<W3D;F1E;B!N:6-H="!V
M;VX@9&5M(&%N9V5G96)E;F5N($%B<V5N9&5R+B!&;VQG96X@4VEE(&ME:6YE
M;B!,:6YK<R!I;B!D:65S97(@3F%C:')I8VAT('5N9"!H_'1E;B!3:64@<VEC
M:"!D879O<BP@9&5M($%B<V5N9&5R('!E<G/V;FQI8VAE($1A=&5N('!R96ES
M>G5G96)E;BX`*$ML:6-K96X@4VEE(&%U9B!D96X@2V%L96YD97)N86UE;BP@
M=6T@9&5N($MA;&5N9&5R(&EM($AA=7!T9F5N<W1E<B!E:6XM(&]D97(@875S
M>G5B;&5N9&5N*0`J($1I97-E(&AI;GIU9OQG96X@9'5R8V@@2VQI8VL@875F
M($AI;GIU9OQG96X@*@`J($)I='1E($%D<F5S<V4H;BD@875S=^1H;&5N("H`
M+"!B]FEG(``L(&)I9R`E<R`E<P`L('-C:'=A;FME;F0@=F]N("5S(&)I<R`E
M<P`M+2!!=7-WY&AL96X@+2T`,2!496EL;F5H;65R`#$@5&5R;6EN`#$@4W1U
M;F1E`#$R+5-T=6YD96XM1F]R;6%T`#$U($UI;G5T96X`,C`@36EN=71E;@`R
M-"U3='5N9&5N+49O<FUA=``R-"!3='5N9&5N`#,P($UI;G5T96X`/%IU<OQC
M:P`\<W1R;VYG/E1E:6QN96AM97(\+W-T<F]N9SX@*&]P=&EO;F%L*0`\<W1R
M;VYG/E]+;VUM96YT87(\+W-T<F]N9SX@*&]P=&EO;F%L*0`\<W1R;VYG/E-T
M:6-H=_9R=&5R/"]S=')O;F<^("AO<'1I;VYA;"D`/'-T<F]N9SY7:65D97)H
M;VQU;F<\+W-T<F]N9SX@*&]P=&EO;F%L*0!&<B!D:65S96X@0FQO8VL@=VER
M9"!E:6YE($1A=&5N8F%N:R!B96YT:6=T+@!%:6X@<V-H=V5R97(@1F5H;&5R
M(&ES="!A=69G971R971E;CH`16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS
M<V5L('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU;F<@96EN97(@3F%C:')I
M8VAT(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P@
M=VER9"!F_'(@9&EE(-QB97)P<OQF=6YG(&5I;F5R('5N=&5R>F5I8VAN971E
M;B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I
M;B!P<FEV871E<B!01U`M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R="!W
M:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B
M96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%!'
M4"U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5
M;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V
M9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L
M('-O=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L
M=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE
M<B!U;F0@96EN('!R:79A=&5R(%,O34E-12U38VAL_'-S96P@<V]W:64@96EN
M(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.
M86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@4R]-24U%+5-C
M:&S\<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R($YA
M8VAR:6-H="!B96[V=&EG="X`04T`5F]R;6ET=&%G<R!7;VQK96X`5F]R;6ET
M=&%G<R!L96EC:'1E<B!296=E;@!6;W)M:71T86=S(%)E9V5N`%9O<FUI='1A
M9W,@4V-H875E<@!6;W)M:71T86=S(%-C:&YE97-C:&%U97(`04TO4$T`05!)
M($E$`-QB97(@9&EE<V5N($5D:71O<@!);F9O+BXN`$%B<V]L=70@56YT96X`
M06)S;VQU="!-:71T90!!;F=E;F]M;65N`%IU9W)I9F8@=F5R=V5I9V5R="!B
M96EM($%N;&5G96X@9&5S(%9&4RU697)Z96EC:&YI<W-E<RX`6G5G<FEF9B!V
M97)W96EG97)T(&)E:6T@06YL96=E;B!D97(@5D93+41A=&5I+@!+;VYT;VEN
M9F]R;6%T:6]N96X`2V]N=&]P87-S=V]R=`!+;VYT;R!E:6YG969R;W)E;BX`
M0G5C:&AA;'1U;F<`15]R=V5I=&5R=&4@4W5C:&4`2&EN>G5F_&=E;@!.975E
M(%5N=&5R9W)U<'!E(&AI;GIU9OQG96X`3F5U92!5;G1E<G)E8VAT92!H:6YZ
M=6;\9V5N`%1E<FUI;B!H:6YZ=6;\9V5N`$AI97(@:&EN>G5F_&=E;CH`3F5U
M92!'<G5P<&4@:&EN>G5F_&=E;@!.975E(%)E8VAT92!H:6YZ=6;\9V5N`%5N
M=&5R9W)U<'!E('IU("(E<R(@:&EN>G5F_&=E;@!5;G1E<G)E8VAT92!Z=2`B
M)7,B(&AI;GIU9OQG96X`16EN96X@;F5U96X@97AT97)N96X@2V%L96YD97(@
M:&EN>G5F_&=E;@!%:6YE;B!N975E;B!497)M:6X@:&EN>G5F_&=E;@!&_&=E
M;B!3:64@96EN96X@;F5U96X@0F5N=71Z97(@:&EN>G4Z`%1E:6QN96AM97(@
M:&EN>G5F_&=E;@!3<&%L=&4@:&EN>G5F_&=E;@!.975E($UI=&=L:65D97(@
M:&EN>G5F_&=E;@!086%R(&AI;GIU9OQG96X`1&%S("5S+4UE;OP@>G5R($UO
M>FEL;&$@4VED96)A<B!H:6YZ=6;\9V5N`%IU;2!!9')E<W-B=6-H(&AI;GIU
M9OQG96XZ`%IU(%1E:6QN96AM97)N(&AI;GIU9OQG96X`6G4@;65I;F5M($%D
M<F5S<V)U8V@@:&EN>G5F_&=E;@!"96YU='IE<B!H:6YZ=6;\9V5N`"(E<R(@
M=W5R9&4@>G5M(%-Y<W1E;2!H:6YZ=6=E9OQG="P@86)E<B!D:64@>G5SY'1Z
M;&EC:&5N(%)E9VES=')I97)U;F=S:6YF;W)M871I;VYE;B!K;VYN=&5N(&YI
M8VAT(&=E<W!E:6-H97)T('=E<F1E;CH@)7,N`"(E<R(@=W5R9&4@>G5M(%-Y
M<W1E;2!H:6YZ=6=E9OQG="X@4VEE(&OV;FYE;B!S:6-H(&IE='IT(&%N;65L
M9&5N+@!$87,@2&EN>G5F_&=E;B!V;VX@0F5N=71Z97)N(&ES="!N:6-H="!M
M]F=L:6-H+@!!9')E<W-E`$%D<F5S<V)U8V@`5F5R=V%L=&5N("T@4F5C:'1E
M(&;\<B!A;F1E<F4@0F5N=71Z97(@9F5S=&QE9V5N`$%D;6EN:7-T<F%T:6]N
M`%=E<F)U;F<`17)W96ET97)T92!3=6-H90!!9F=H86YI<W1A;@!!;&%R;0!!
M;&%R;2`E9"!486=E('9O<FAE<@!!;&%R;2`E9"!3='5N9&5N('9O<FAE<@!!
M;&%R;2`E9"!-:6YU=&5N('9O<FAE<@!!;&%R;2`E9"!7;V-H96X@=F]R:&5R
M`$%L87)M(#$@5&%G('9O<FAE<@!!;&%R;2`Q(%-T=6YD92!V;W)H97(`06QA
M<FT@,2!-:6YU=&4@=F]R:&5R`$%L87)M(#$@5V]C:&4@=F]R:&5R`$%L87)M
M9&%T=6T`06QA<FT@*$UI;G5T96XI`$%L87)M>F5I=`!!;&)A;FEE;@!!;&=E
M<FEE;@!3<&ET>FYA;64`075S<FEC:'1U;F<`075S<FEC:'1U;F<Z`$%L;&4`
M06QL92!496EL;F5H;65R`$%N9V5M96QD971E($)E;G5T>F5R`$%L;&4@>G5K
M_&YF=&EG96X`06QL92!'<G5P<&5N`$%L;&4@=F5R9V%N9V5N96X`06QL92!2
M96-H=&4`06QL92!S:6-H=&)A<F5N`$=A;GITY&=I9P!'86YZ=.1G:6=E<B!4
M97)M:6X`06QL92!497)M:6YE`$%L;&4@=FEE<B!396ET96X`365H<F5R92!!
M9')E<W-E;B!E<FQA=6)E;@!&;W)M870@=F]N(&YU;6UE<FEE<G1E;B!,:7-T
M96X@Y&YD97)N/P!%>&ES=&EE<G0@8F5R96ET<P!!;'1E<FYA=&EV92!)35-0
M+4%N;65L9'5N9P!!;'1E<FYA=&EV97,@24U34"U087-S=V]R=`!!;'1E<FYA
M=&EV97(@24U34"U"96YU='IE<FYA;64`06QT97)N871I=F4@16UA:6QA9')E
M<W-E`$%L=&5R;F%T:79E(%9O<FQA9V5N`$%L=&5R;F%T:79E<B!497AT.@!!
M;65R:6MA;FES8V@M4V%M;V$`17,@=W5R9&4@96EN('5N9_QL=&EG97(@5V5R
M="!A;F=E9V5B96XN`$5I;B!U;F)E:V%N;G1E<B!&96AL97(@:7-T(&%U9F=E
M=')E=&5N+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UE<B!0<F]X
M>0!!;G1W;W)T`$%N=&%R:W1I<P!!;G1I9W5A('5N9"!"87)B=61A`$%L;&4`
M06YW96YD=6YG`$%N=V5N9'5N9W-L:7-T90!!;G=E;F1U;F<@:7-T(&)E<F5I
M="X`075F(%5N=&5R<F5C:'1E(&%N=V5N9&5N`$)E<W3D=&EG96X`56YG96;D
M:')E($=R]M]E`$%P<FEL`$%R86)I<V-H("A7:6YD;W=S+3$R-38I`$%R8VAI
M=F=R]M]E`$%R8VAI=FYA;64`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D
M:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!L]G-C:&5N(&WV8VAT
M96X_`%-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@(B5S(B!U;F0@86QL92!5
M;G1E<F=R=7!P96X@;/9S8VAE;B!M]F-H=&5N/P!!<F=E;G1I;FEE;@!!<FUE
M;FEE;@!!<FUE;FES8V@@*$%235-#24DM."D`2W5N<W0`07)U8F$`07-C96YS
M:6]N+4EN<V5L;@!!4T-)22U+=6YS=`!!<VEE;B]087II9FES8VAE(%)E9VEO
M;@!!;G-T96AE;F1E(%=A<G1U;F=S87)B96ET96X@8F5S=.1T:6=E;B!L87-S
M96X_`%IU;W)D;G5N9W-F96QD97(`=6T`26T@06YH86YG(&)E9FEN9&5T('-I
M8V@@96EN92!I0V%L96YD87(M1&%T96D@;6ET(&UE:'(@26YF;W)M871I;VYE
M;B!Z=2!D:65S96T@5&5R;6EN+B!796YN($EH<B!%;6%I;"U0<F]G<F%M;2!I
M5&EP+4%N9G)A9V5N(&)E:&5R<G-C:'0L(&OV;FYE;B!3:64@9&EE<V4@1&%T
M96D@9&%Z=2!B96YU='IE;BP@26AR92!L;VMA;&4@5F5R<VEO;B!D97,@5&5R
M;6EN<R!Z=2!A:W1U86QI<VEE<F5N+@!%<R!W=7)D92!V97)S=6-H="P@96EN
M92!N:6-H="!E>&ES=&EE<F5N9&4@1W)U<'!E('IU(&SV<V-H96XN`$5S('=U
M<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI<W1I97)E;F1E<R!296-H="!Z
M=2!L]G-C:&5N+@!%<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T
M:65R96YD97,@4F5C:'0@>G4@8F5A<F)E:71E;BX`17,@=W5R9&4@=F5R<W5C
M:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E87)B96ET
M96XN`$%N=V5S96YH96ET`%1E:6QN96AM97(`071T<FEB=71E`$%U9W5S=`!!
M=7-T<F%L:65N`-9S=&5R<F5I8V@`075T:%]C>7)S<6PZ($1I92!B96[V=&EG
M=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T
M:%]C>7)U<SH@1&%S($)A8VME;F0@:&%T(&YI8VAT(&1I92!B96[V=&EG=&5N
M($;D:&EG:V5I=&5N+@!!=71H7V-Y<G5S.B!$:64@8F5N]G1I9W1E($E-05`M
M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?9G1P.B!$
M:64@8F5N]G1I9W1E($944"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U
M;F1E;BX@2V]M<&EL:65R96X@4VEE(%!(4"!M:70@9&5M("TM96YA8FQE+69T
M<"!087)A;65T97(N`$%U=&A?:6UA<#H@1&EE(&)E;O9T:6=T92!)34%0+45R
M=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7VMR8C4Z($1I
M92!B96[V=&EG=&4@2V5R8F5R;W,M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@
M9V5F=6YD96XN`$%U=&A?;&1A<#H@1&%S($AI;GIU9OQG96X@=F]N($)E;G5T
M>F5R;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT('5N=&5R<W3\
M='IT`$%U=&A?;&1A<#H@1&%S($SV<V-H96X@=F]N($)E;G5T>F5R;B!W:7)D
M(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT('5N=&5R<W3\='IT`$%U=&A?
M;&1A<#H@1&EE(&)E;O9T:6=T92!,1$%0+45R=V5I=&5R=6YG('=U<F1E(&YI
M8VAT(&=E9G5N9&5N+@!!=71H7VQD87`Z($1E<B!"96YU='IE<B`E<R!K;VYN
M=&4@;FEC:'0@:&EN>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG(&1E<R!397)V
M97)S.B``075T:%]L9&%P.B!"96YU='IE<B`E<R!K;VYN=&4@;FEC:'0@9V5L
M]G-C:'0@=V5R9&5N`$%U=&A?;&1A<#H@0F5N=71Z97(@)7,@:V]N;G1E(&YI
M8VAT(&%K='5A;&ES:65R="!W97)D96X`075T:%]L9&%P.B!$87,@06MT=6%L
M:7-I97)E;B!V;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV92!$:7)E8W1O
M<GD@;FEC:'0@=6YT97)S=/QT>G0N`$%U=&A?;6-A;#H@1&EE(&)E;O9T:6=T
M92!-0T%,+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H
M7W-M8F%U=&@Z($1I92!B96[V=&EG=&4@4V%M8F$M17)W96ET97)U;F<@=W5R
M9&4@;FEC:'0@9V5F=6YD96XN`$%N;65L9'5N9R!B96EM($E-05`M4V5R=F5R
M(&9E:&QG97-C:&QA9V5N+@!!=71H96YT:69I>FEE<G5N9R!F96AL9V5S8VAL
M86=E;@!!;FUE;&1U;F<@9F5H;&=E<V-H;&%G96XN("5S`$1I92!!=71H96YT
M:69I>FEE<G5N9R!W=7)D92!V;VT@4D%$2553+5-E<G9E<B!Z=7+\8VMG97=I
M97-E;BX`06YM96QD=6YG(&)E:6T@1E10+5-E<G9E<B!F96AL9V5S8VAL86=E
M;BX`06YM96QD=6YG(&)E:6T@4TU"+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`
M5F5R9OQG8F%R92!&96QD97(Z`$%S97)B86ED<V-H86X`0D]&2"U!=7-R961E
M;@!(:6YT97)G<G5N9`!(:6YT97)G<G5N9&9A<F)E`$9A;'-C:&5S($ME<F)E
M<F]S+5!A<W-W;W)T+@!&86QS8VAE<B!+97)B97)O<RU"96YU='IE<FYA;64N
M`$)A:&%M87,`0F%H<F5I;@!"86QT:7-C:"`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<V-H`$)A<F)A9&]S`$)A<VES+4)I;&1E<BU697)Z96EC:&YI<R`B)7,B
M(&YI8VAT(&=E9G5N9&5N+@!'<G5N9&QI;FEE`$5I;F9A8VAE(%-U8VAE`%=E
M:=]R=6QA;F0`0F5L9VEE;@!"96QI>F4`0F5N:6X`0F5R;75D87,`0FAU=&%N
M`$=E8G5R='-T86<`0FQO8VL@(B5S(B!D97(@06YW96YD=6YG("(E<R(@;FEC
M:'0@9V5F=6YD96XN`$)L;V-K96EN<W1E;&QU;F=E;@!";&]C:W1Y<`!&971T
M`$)O;&EV:65N`$QE<V5Z96EC:&5N`%)A;F0`4F%H;65N9&EC:V4Z`%+D;F1E
M<@!";W-N:65N+4AE<GIE9V]W:6YA`$)E:61E<P!";W1S=V%N80!5;G1E;@!"
M;W5V971I;G-E;`!"<F%S:6QI96X`0G)I=&ES8VAE<R!497)R:71O<FEU;2!I
M;2!);F1I<V-H96X@3WIE86X`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:65N
M`%5N;G5M;65R:65R=&4@3&ES=&4`0G5R:VEN82!&87-O`$)U<G5N9&D`0F5S
M8VCD9G1I9W0`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N<W-T96QL90!?2V%L
M96YD97(`7UIE;&QE;F5I9V5N<V-H869T96XN+BX`1&5R(%IW:7-C:&5N<W!E
M:6-H97(@:V]N;G1E(&YI8VAT(&EN:71I86QI<VEE<G0@=V5R9&5N+@!?2V%L
M96YD97(`2V%L96YD97(`2V%L96YD97(MW&)E<G-I8VAT`$MA;&5N9&5R(&5R
M9F]L9W)E:6-H(&=E;&5E<G0N`$MA;&5N9&5R`$MA;&5N9&5R(&W\<W-E;B!E
M:6YE;B!.86UE;B!H86)E;BX`5VEN9'-T:6QL`$MA;6)O9'-C:&$`2V%M97)U
M;@!087-S=V]R="!K86YN(&YI8VAT(&%U=&]M871I<V-H('IU<OQC:V=E<V5T
M>G0@=V5R9&5N+"!B:71T92!W96YD96X@4VEE('-I8V@@86X@26AR96X@061M
M:6YI<W1R871O<BX`1&EE($1A=&5I("(E<R(@:V%N;B!N:6-H="!G97-P96EC
M:&5R="!W97)D96X`17AT97)N92!397-S:6]N+4AA;F1L97(@:_9N;F5N(&YI
M8VAT(&%D;6EN:7-T<FEE<G0@=V5R9&5N+@!697)B:6YD=6YG('IU;2!)34%0
M+5-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;CH@)7,`16EN
M(&YE=65R(%1E<FUI;B!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N+@!$
M:64@1&%T96D@(B5S(B!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX`2V%N
M861A`$%B8G)E8VAE;@!0<F]B;&5M8F5R:6-H="!A8F)R96-H96X`06)G97-A
M9W0`06)G97-A9W0Z("5S`$1I92!$871E:2`B)7,B(&MO;FYT92!N:6-H="!G
M96SV<V-H="!W97)D96XN`$ME:6X@=&5M<&]RY')E<R!697)Z96EC:&YI<R!G
M969U;F1E;BX`1F]R='-E='IU;F<@;VAN92`B=&%R9V5T1FEL92(M4&%R86UE
M=&5R(&YI8VAT(&WV9VQI8V@N`$1A<R!697)Z96EC:&YI<R`B)7,B(&MO;FYT
M92!N:6-H="!E;G1F97)N="!W97)D96XN`$MO;FYT92!N:6-H="!E;G1F97)N
M="!W97)D96XL("5D($MI;F1E<B!E>&ES=&EE<F5N+@!5;7-O<G1I97)E;B!N
M:6-H="!M]F=L:6-H+B!$:64@06YZ86AL(&1E<B!%:6YT<N1G92P@9&EE('5M
M<V]R=&EE<G0@=V5R9&5N('-O;&QE;BP@<W1I;6UT(&YI8VAT(&UI="!D97(@
M06YZ86AL(&1E<B!G97-P96EC:&5R=&5N($5I;G1RY&=E(/QB97)E:6XN`$1I
M92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&%N(&1I92!A;F=E9V5B92!.=6UM
M97(@=V5I=&5R9V5L96ET970@=V5R9&5N+@!+87`@5F5R9&4`W&)E<G-C:')I
M9G0`4')O=FED97(`2V%T96=O7W)I90!+871E9V]R:65N('5N9"!"97-C:')I
M9G1U;F=E;@!+871E9V]R:64`0V%Y;6%N+4EN<V5L;@!-;V)I;'1E;&5F;VX`
M6F5L;&5N96EG96YS8VAA9G1E;@!);FYE;F%B<W1A;F0Z`%IE;&QE;F5I9V5N
M<V-H869T96X`6F5L;&5N86)S=&%N9#H`36]B:6QT96QE9F]N`$ME;'1I<V-H
M("A)4T\M.#@U.2TQ-"D`6F5N=')I97)T`%IE;G1R86QA9G)I:V%N:7-C:&4@
M4F5P=6)L:6L`36ET=&5L975R;W#D:7-C:"`H25-/+3@X-3DM,BD`6F5R=&EF
M:6MA=&1E=&%I;',`6F5R=&EF:6MA=&)E<VET>F5R`%IE<G1I9FEK871R:6-H
M=&QI;FEE;@!4<V-H860`Q&YD97)N`,1N9&5R;B!3:64@26AR(%!A<W-W;W)T
M`,1N9&5R;B!3:64@9&5N($YA;65N(&]D97(@9&EE($5M86EL861R97-S92P@
M9&EE(&1I92!%;7!FY&YG97(@26AR97(@16UA:6QS('-E:&5N+"!W96YN(&1I
M97-E($EH<F4@16UA:6QS(&QE<V5N(&]D97(@9&%R875F(&%N=V]R=&5N+@!$
M87,@Q&YD97)N($EH<F5S(%!A<W-W;W)T<R!W:7)D('9O;B!D:65S96T@4WES
M=&5M('IU<B!:96ET(&YI8VAT('5N=&5R<W3\='IT+B!":71T92!W96YD96X@
M4VEE('-I8V@@86X@26AR96X@061M:6YI<W1R871O<BX`6F5I8VAE;@!,:6YK
M(/QB97)?<'+\9F5N+BXN`$-H:6QE`$-H:6YA`$-H:6YE<VES8V@@=F5R96EN
M9F%C:'0@*$=",C,Q,BD`0VAI;F5S:7-C:"!T<F%D:71I;VYE;&P@*$)I9S4I
M`$%N=V5N9'5N9R!A=7-WY&AL96XZ`%?D:&QE;B!3:64@96EN(%!A<W-W;W)T
M`%?D:&QE;B!3:64@96EN96X@0F5N=71Z97)N86UE;@!,96=E;B!3:64@9F5S
M="P@=VEE(&1A<R!$871U;2!A;F=E>F5I9W0@=V5R9&5N('-O;&PZ`$QE9V5N
M(%-I92!F97-T+"!O8B!3:64@<&5R($5M86EL(/QB97(@;F5U92P@9V7D;F1E
M<G1E(&]D97(@9V5L]G-C:'1E(%1E<FUI;F4@8F5N86-H<FEC:'1I9W0@=V5R
M9&5N(&WV8VAT96XZ`$QE9V5N(%-I92!F97-T+"!O8B!3:64@_&)E<B!N975E
M+"!G9>1N9&5R=&4@;V1E<B!G96SV<V-H=&4@5&5R;6EN92!B96YA8VAR:6-H
M=&EG="!W97)D96X@;?9C:'1E;BX`3&5G96X@4VEE(&9E<W0L(&]B(%-I92!P
M97(@16UA:6P@_&)E<B!!;&%R;64@8F5N86-H<FEC:'1I9W0@=V5R9&5N(&WV
M8VAT96XZ`$QI<W1E;F9O<FUA="!A=7-WY&AL96X@*&;\<B!N=6UM97)I97)T
M92!,:7-T96XI`%?D:&QE;B!3:64@9&EE($%D<F5S<V+\8VAE<B!A=7,L(&EN
M(&1E;F5N(&YA8V@@1G)E:2]'96)U8VAT+5523',@9V5S=6-H="!W97)D96X@
M<V]L;#H`5^1H;&5N(%-I92!D:64@2V%L96YD97(@875S+"!D:64@:6X@26AR
M92!&<F5I+T=E8G5C:'0M26YF;W)M871I;VYE;B!E:6YB97IO9V5N('=E<F1E
M;B!S;VQL96XZ`%?D:&QE;B!3:64@9&EE($MA;&5N9&5R(&%U<RP@9&EE(&5I
M;F)E>F]G96X@=V5R9&5N('-O;&QE;BP@=V5N;B!):')E($9R96DO1V5B=6-H
M="U54DQS(&5R>F5U9W0@=V5R9&5N.@!7Y&AL96X@4VEE($EH<F5N(%-T86YD
M87)D+4MA;&5N9&5R(&%U<RX`5V5I:&YA8VAT<VEN<V5L`$ML87-S96YD969I
M;FET:6]N(&;\<B`E<R!N:6-H="!G969U;F1E;BX`2&5I=&5R`$U3+4]F9FEC
M92U486=S(&5N=&9E<FYE;@!!8F9R86=E('IU<OQC:W-E='IE;@!!;&QE(%1E
M:6QN96AM97(@96YT9F5R;F5N`$)E;G5T>F5R9&%T96X@;/9S8VAE;CH@)7,`
M0F5N=71Z97)D871E;B!L]G-C:&5N`$)E;G5T>F5R9&%T96X@;/9S8VAE;@!3
M<.1T97(@075F:VQA<F5N9`!&;W)T9F%H<F5N`$-L:6-K871E;&P@<&5R($A4
M5%``1F5N<W1E<B!S8VAL:67?96X`1F5N<W1E<B!S8VAL:67?96X`5V]L:V5N
M`$9R_&@@5V]L:V5N`$)E=_9L:W0`2V]K;W-I;G-E;&X`365N_"!E:6YF86AR
M96X`6G5S86UM96YHY&YG96YD92!286AM96X`2V]L=6UB:65N`$9A<F)E`$9A
M<F)A=7-W86AL`$9A<F)W86AL`%-P86QT96XZ`%-P86QT96[\8F5R<V-H<FEF
M=&5N`$-O;6EC<P!+;VUM86=E=')E;FYT92!797)T90!"969E:&P`0F5F96AL
M<WIE:6QE`$MO;6UE;G1A<@!%:6YD975T:6=E<B!.86UE`$MO;6]R96X`1FER
M;6$`0V]M<'5T97(`0F5D:6YG=6YG96X`0F5D:6YG=6YG96X`2V]N9FEG=7)A
M=&EO;G-U;G1E<G-C:&EE9&4`2V]N9FEG=7)A=&EO;B!D97(@4WEN8VAR;VYI
M>F%T:6]N(&UI="!01$%S+"!3;6%R='!H;VYE<R!U;F0@3W5T;&]O:RX`1&EE
M($MO;F9I9W5R871I;VX@;75S<R!A:W1U86QI<VEE<G0@=V5R9&5N+@`E<R!K
M;VYF:6=U<FEE<F5N`%!A<W-W;W)T(&)E<W3D=&EG96X`3/9S8VAE;B!V;VX@
M5&5R;6EN96X@8F5S=.1T:6=E;C\`0F5S=.1T:6=T`$MO;F=O`$1E;6]K<F%T
M:7-C:&4@4F5P=6)L:6,@2V]N9V\`5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E
M;BX`5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E;CH@`%9E<F)I;F1U;F<@>G5M
M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(@=W5R9&4@86)G97=I97-E
M;BX`5F5R8FEN9'5N9R!Z=6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E;'-E<G9E
M<B!W=7)D92!A8F=E=VEE<V5N+B!'<G5N9#H@)7,@*"5S*0!697)B:6YD=6YG
M('IU;2!&5%`M4V5R=F5R(&9E:&QG97-C:&QA9V5N`$MO;G1A:W1E`$1I92!+
M;VYT86MT92!W=7)D96X@97)F;VQG<F5I8V@@26AR96T@061R97-S8G5C:"!H
M:6YZ=6=E9OQG="X`26YH86QT<W1Y<"!D97(@:V]M<')I;6EE<G1E;B!$871E
M:3H@`$EN:&%L="!V;VX@(B5S(@!796ET97(`0V]O:RU);G-E;&X`0V]O:VEE
M`$MO<&EE<F5N`$MO<&EE<F5N(&9E:&QG97-C:&QA9V5N.B`E<P!!=7-W86AL
M(&MO<&EE<F5N`$)E;G5T>F5N(%-I92!D96X@3&EN:R!A=7,@9&EE<V5M($9E
M;&0L('=O(&EM;65R(%-I92!):')E($9R96DO1V5B=6-H="U54DP@8F5N]G1I
M9V5N.@!+;W-T96XM240`0V]S=&$@4FEC80!%;&9E;F)E:6YK_'-T90!$:64@
M3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@4$=0('9E<G-C:&S\<W-E;'0@
M=V5R9&5N.B``1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!U
M;G1E<GIE:6-H;F5T('=E<F1E;CH@`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI
M8VAT(&UI="!3+TU)344@=F5R<V-H;/QS<V5L="!W97)D96XN`$1I92!.86-H
M<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!3+TU)344@=6YT97)Z96EC:&YE="!W
M97)D96XN`$MO;G1A:W0@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E
M;BX@)7,`5F5R8FEN9'5N9R!Z=6T@3$1!4"U397)V97(@9F5H;&=E<V-H;&%G
M96XN`$MO;G1O<W1A;F0@:V]N;G1E(&YI8VAT(/QB97)P<OQF="!W97)D96XN
M("5S`%9E<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N
M+@!&5%`M5F5R8FEN9'5N9R!Z=6T@4V5R=F5R("(E<R(@:V]N;G1E(&YI8VAT
M(&AE<F=E<W1E;&QT('=E<F1E;CH@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E
M(&YI8VAT(&5R<W1E;&QT('=E<F1E;BX@)7,`4$=0+41A=&5N(&MO;FYT96X@
M;FEC:'0@96YT<V-H;/QS<V5L="!W97)D96XZ(`!3+TU)344M1&%T96X@:V]N
M;G1E;B!N:6-H="!E;G1S8VAL_'-S96QT('=E<F1E;BX`2V]N=&%K="!K;VYN
M=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B`E<P!697)T96EL97)L:7-T92!K
M;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B`E<P!$87,@06MT=6%L:7-I
M97)U;F=S<VMR:7!T("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E
M;BX`1&EE($5M86EL861R97-S92!D97,@16UP9N1N9V5R<R!K;VYN=&4@;FEC
M:'0@97)M:71T96QT('=E<F1E;BX`1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI
M8VAT(&MO;7!L971T(&=E;&5S96X@=V5R9&5N+@!697)T96EL97)L:7-T92!K
M;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN("5S`$QI<W1E(&1E<B!6
M97)T96EL97)L:7-T96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N
M+@!$:64@4W1R871E9VEE("(E<R(@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R
M9&5N+@!$87,@5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@86YG96QE
M9W0@=V5R9&5N+@#69F9E;G1L:6-H97(@4V-H;/QS<V5L(&MO;FYT92!N:6-H
M="!V;VT@4V-H;/QS<V5L<V5R=F5R(&=E:&]L="!W97)D96XN`"(E<R(@:V]N
M;G1E(&YI8VAT('IU;2!38VAR96EB96X@9V7V9F9N970@=V5R9&5N+@`E<R!K
M;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN`$1A<R!-86EN=&5N86YC95]4
M87-K($UO9'5L("5S(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96X`5F5R
M>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!6
M97)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!K;VYN=&4@;FEC:'0@:&5R9V5S
M=&5L;'0@=V5R9&5N+@`E<R!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN
M`$1A<R!087-S=V]R="!F_'(@9&5N(&%N9V5G96)E;F5N($)E;G5T>F5R(&MO
M;FYT92!N:6-H="!Z=7+\8VMG97-E='IT('=E<F1E;BP@=V5I;"!E:6YI9V4@
M06YG86)E;B!N:6-H="!R:6-H=&EG('=A<F5N+B!697)S=6-H96X@4VEE(&5S
M(&5R;F5U="!O9&5R('=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!!9&UI;FES
M=')A=&]R+"!W96YN(%-I92!W96ET97)E($AI;&9E(&)E;O9T:6=E;BX`04-,
M(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;@!$87,@061R97-S8G5C:"!K
M;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN("5S`%9E<G1E:6QE<FQI<W1E
M(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`5F5R=&5I;&5R
M;&ES=&5N(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`1&EE
M(%-E<G9E<F;D:&EG:V5I=&5N(&MO;FYT96X@;FEC:'0@875S9V5L97-E;B!W
M97)D96X`2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S971Z
M="!W97)D96XN`%9E<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S
M8VAT('=E<F1E;BX`)7,M2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S
M<&5I8VAE<G0@=V5R9&5N+@!"86-K=7`@9&5R($MO;F9I9W5R871I;VX@:V]N
M;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`0F%C:W5P(&1E<B!+;VYF
M:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S
M`$1A<R!!:W1U86QI<VEE<G5N9W-S:W)I<'0@:V]N;G1E(&YI8VAT(&YA8V@@
M(B5S(B!G97-P96EC:&5R="!W97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A
M=&EO;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$:64@
M2V]N9FEG=7)A=&EO;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N+B!3:64@:_9N;F5N(&5N='=E9&5R(&5I;F4@9&5R($WV9VQI8VAK96ET
M96X@=6YT97(@)7,@=F5R=V5N9&5N+"!U;2!D96X@0V]D92!Z=2!S<&5I8VAE
M<FXL(&]D97(@9&5N('5N=&5N<W1E:&5N9&5N($-O9&4@;6%N=65L;"!N86-H
M("5S(&MO<&EE<F5N+@!$97(@3$1!4"U397)V97(@:V]N;G1E(&YI8VAT(&1U
M<F-H<W5C:'0@=V5R9&5N+@`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W
M97)D96XN`$1E<B!+;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W
M97)D96XN("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A:W1U86QI
M<VEE<G0@=V5R9&5N+B`E<P!$:64@2V]N9FEG=7)A=&EO;B!F_'(@(B5S(B!K
M;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N.B`E<P!$:64@36]Z:6QL
M82!3:61E8F%R(&MO;FYT92!N:6-H="!G969U;F1E;B!W97)D96XN(%-T96QL
M96X@4VEE('-I8VAE<BP@9&%S<R!D:64@4VED96)A<B!G9?9F9FYE="!I<W0N
M`$1E;2!"96YU='IE<B`B)7,B(&MO;FYT96X@9&EE(&9O;&=E;F1E(%)E8VAT
M92!F_'(@9&5N($]R9&YE<B`B)7,B(&YI8VAT('IU9V5W:65S96X@=V5R9&5N
M.B`E<P!'97KD:&QT97(@5&5X=`!,86YD`$MU<G-E`$5R<W1E;&QE;@!+86QE
M;F1E<B!E<G-T96QL96X`3F5U96X@5&5R;6EN(&5R<W1E;&QE;@!,:6YK(&5R
M<W1E;&QE;@!.975E($ED96YT:73D="!A;FQE9V5N`%5N=&5R;W)D;F5R(&5R
M<W1E;&QE;@!%<G-T96QL=`!%<G-T96QL97)R96-H=&4`2W)E9&ET:V%R=&5N
M;G5M;65R`$MR;V%T:65N`$MU8F$`1&EE<V5N`$%K='5E;&QE(#0@4&AA<V5N
M`$%K='5E;&QE(%-E<W-I;VYS`$%K='5E;&QE(%IE:70`06MT=65L;&4@55),
M(&ES=`!!:W1U96QL92!"96YU='IE<@!!:W1U96QL97,@5V5T=&5R`$1E<GIE
M:71I9V4@0F5D:6YG=6YG96XZ(`!!:W1U96QL97(@4W1I;`!,96=E;B!3:64@
M9F5S="P@=V5L8VAE($%U9F=A8F5N(&YA8V@@9&5R($%N;65L9'5N9R!B96D@
M)7,@97)L961I9W0@=V5R9&5N('-O;&QE;BX`075S<V-H;F5I9&5N`$%U<W=A
M:&P@875S<V-H;F5I9&5N`%IY<&5R;@!+>7)I;&QI<V-H("A+3TDX+5(I`$MY
M<FEL;&ES8V@@*%=I;F1O=W,M,3(U,2D`2WER:6QL:7-C:"]5:W)A:6YI<V-H
M("A+3TDX+54I`%1S8VAE8VAI<V-H92!297!U8FQI:P!45`!$4TX@*'-I96AE
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"D`5.1G;&EC:`!4Y&=L:6-H.B!7:65D97)H
M;VQU;F<@86QL90!$871A5')E92!"<F]W<V5R`$1A=&5N8F%N:V%B9G)A9V4`
M1&%T=6T`16UP9F%N9W-D871U;0!$871U;7-A=7-W86AL`%1A9P!486<H92D`
M7TSV<V-H96X`4W!A;'1E(%]L]G-C:&5N`$1E>F5M8F5R`%IA:&QE;@!!8F=E
M;&5H;G0`16EN>G5G('9E<G)I;F=E<FX`4W1A;F1A<F0`4W1A;F1A<F0M2V%L
M96YD97(`4W1A;F1A<F1F87)B90!3=&%N9&%R9&ED96YT:73D=`!3=&%N9&%R
M9'-H96QL`$1E9FEN:71I;VYE;@!,]G-C:&5N`"5S(&SV<V-H96X`6F5L;&4@
M;/9S8VAE;@!497)M:6X@;/9S8VAE;@!'<G5P<&4@;/9S8VAE;@!,;V<@;/9S
M8VAE;@!296-H=&4@;/9S8VAE;@!.86-H<FEC:'1E;B!L]G-C:&5N('5N9"!E
M;G1F97)N96X`6F5L;&4@;/9S8VAE;@!3<&%L=&4@;/9S8VAE;@!"97-T96AE
M;F1E(&%L=&5R;F%T:79E(%9O<FQA9V4@;/9S8VAE;@!.86-H<FEC:'1E;B!L
M]G-C:&5N`%)E8VAT92!F_'(@(B5S(B!L]G-C:&5N`%)E8VAT92!F_'(@(B5S
M(B!U;F0@86QL92!5;G1E<G)E8VAT92!L]G-C:&5N/P!:96EL92!L]G-C:&5N
M`$%U<V=E=^1H;'1E($ED96YT:73D="!L]G-C:&5N`%5N=&5R;W)D;F5R(&SV
M<V-H96X`1&EE(&%K='5E;&QE(%-P86QT92!L]G-C:&5N`$YU<B!D96X@86MT
M=65L;&5N(%1E<FUI;B!L]G-C:&5N+"!A;&QE('IU:_QN9G1I9V5N(%1E<FUI
M;F4@:6YK;'5S:79E(&1I97-E;2!O9&5R(&1I92!G86YZ92!397)I93\`1&EE
M(&%K='5E;&QE(%IE:6QE(&SV<V-H96X`1&%S($%K='5A;&ES:65R=6YG<W-K
M<FEP="`B)7,B('=U<F1E(&=E;/9S8VAT+@!!=7-L:65F97)U;F=S>F5I=`!$
MY&YE;6%R:P!?0F5S8VAR96EB=6YG`$)E<V-H<F5I8F5N(%-I92!D87,@4')O
M8FQE;0!"97-C:')E:6)U;F<`1&5T86EL<R`H875C:"!I;B!(;W)D97,@3&]G
M9&%T96DI.@!$971A:6QS('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@
M;6ET9V5L;V=G="X`16YT=VEC:VQU;F<`5&%U<'5N:W0`5&%U<'5N:W0@9&5R
M(&QE='IT96X@4W1U;F1E.B``5&%U<'5N:W0Z(`!6;VX@;&EN:W,@;F%C:"!R
M96-H=',`5F]N(')E8VAT<R!N86-H(&QI;FMS`%9E<GIE:6-H;FES`$%N>F5I
M9V4`6F5I="!I;2`R-"U3='5N9&5N+49O<FUA="!A;GIE:6=E;C\`2V%L96YD
M97(@86YZ96EG96X`06YZ96EG92U%:6YS=&5L;'5N9V5N`$1E=&%I;&EE<G1E
M(%9O<FAE<G-A9V4@86YZ96EG96X`5F]R:&5R<V%G92`H5$%&*2!A;GIE:6=E
M;@!!;GIE:6=E9F]R;6%T`$5M<&9A;F=S8F5S=.1T:6=U;F<`1'-C:&EB=71I
M`$YI8VAT(&SV<V-H96X`1W)E:69E;B!3:64@;FEC:'0@9&ER96MT(&%U9B!M
M86EN=&5N86YC92YP:'`@>G4`4V]L;&5N(/QB97)FY&QL:6=E($%U9F=A8F5N
M(&EN($EH<F5M($MA;&5N9&5R(&%N9V5Z96EG="!W97)D96X_`$ME:6YE(%=I
M961E<FAO;'5N9P!%;G1HY&QT(&1I92!E<G-T92!:96EL92!D:64@1F5L9&YA
M;65N/R!796YN(&IA+"!D:65S97,@075S=V%H;&OD<W1C:&5N(&UA<FMI97)E
M;CH`1&]M:6YI8V$`1&]M:6YI:V%N:7-C:&4@4F5P=6)L:6L`3F]C:"!K96EN
M96X@6G5G86YG/R!(:65R(&%N;65L9&5N+@!(97)U;G1E<FQA9&5N`"5S($AE
M<G5N=&5R;&%D96X`17)Z975G=&4@2V]N9FEG=7)A=&EO;B!A;',@4$A0+5-K
M<FEP="!H97)U;G1E<FQA9&5N+@!!=7-W86AL;&ES=&4`1')O9V5N`$;D;&QI
M9SH@)7,`7T1A=65R`$5M86EL`$5M86EL+6YA8V@M4TU3+6=A=&5W87D@9OQR
M(%!R;W9I9&5R+"!D:64@96EN96X@<V]L8VAE;B!$:65N<W0@=6YT97)S=/QT
M>F5N+@!&14A,15(`16-U861O<@!"96%R8F5I=&5N`"5S(&)E87)B96ET96X`
M5&5I;&YE:&UE<B!B96%R8F5I=&5N`$)L;V-K(&)E87)B96ET96X`2V%L96YD
M97(@8F5A<F)E:71E;@!'<G5P<&4@8F5A<F)E:71E;@!296-H=&4@8F5A<F)E
M:71E;@!296-H=&4@8F5A<F)E:71E;@!296-H=&4@9OQR("<E<R<@8F5A<F)E
M:71E;@!%>'1E<FYE($MA;&5N9&5R(&)E87)B96ET96X`5&5I;&YE:&UE<B!B
M96%R8F5I=&5N`$MA=&5G;W)I96X@=6YD($9A<F)E;B!B96%R8F5I=&5N`$5I
M;G-T96QL=6YG96X@8F5A<F)E:71E;B!F_'(Z`%)E8VAT92!F_'(@(B5S(B!B
M96%R8F5I=&5N`%)E8VAT92!F_'(@)7,@8F5A<F)E:71E;@!":6QD=6YG`,1G
M>7!T96X`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;&%D
M<F5S<V4`1&EE($5M86EL861R97-S96X@;?QS<V5N(&=L96EC:"!S96EN+@!%
M;6%I;"!M:70@0F5S=.1T:6=U;F<`16UA:6PM;F%C:"U335,M1V%T97=A>0!3
M;6EL97ES`$QE97)E($YA8VAR:6-H="X`3&5E<F5S($5R9V5B;FES+@!3=6-H
M8F5G<FEF9F4@;/9S8VAE;@!%;E]D90!%:6YF_&=E;B!V;VX@0FEL9&5R;B!A
M=7,@1F]T;V=A;&5R:65N(&EN(&1E;B!497AT(&5R;&%U8F5N/P!+;VYT97AT
M;65N_"!B96D@4F5C:'1S:VQI8VL@86MT:79I97)E;C\`16YD9&%T=6T`96YD
M970@86T`16YD>F5I=`!%;F1J86AR`$5D:71O<B!V97)G<O;?97)N`$=E8F5N
M(%-I92!E:6YE(%-I8VAE<FAE:71S9G)A9V4@96EN+"!D:64@26AN96X@9V5S
M=&5L;'0@=VER9"P@=V5N;B!3:64@26AR(%!A<W-W;W)T('IU<OQC:W-E='IE
M;B!M]F-H=&5N+"!Z+B!"+B`B5VEE(&QA=71E="!D97(@3F%M92!):')E<R!(
M875S=&EE<G,_(CH`2&EE<B!D:64@0FEL9"U54DP@86YG96)E;@!'96)E;B!S
M:64@9&EE($)U8VAS=&%B96X@=6YT96X@96EN.@#$<75A=&]R:6%L+4=U:6YE
M80!%<FET<F5A`$9E:&QE<@!&96AL97(@8F5I;2!%<G-T96QL96X@96EN97,@
M0FQO8VMS.B`E<P!&96AL97(@8F5I;2!,]G-C:&5N(&1E<R!3>6YC:')O;FES
M871I;VYS86YK97)S.B`E<P!&96AL97(@8F5I;2!,]G-C:&5N(&1E<R!3>6YC
M:')O;FES871I;VYS;&]G<SH@)7,`1F5H;&5R(&)E:6T@17)Z975G96X@9&5S
M($EN:&%L=',Z("5S`$9E:&QE<B!B96EM($%U<VQE<V5N(&1E<B!&<F5I+T=E
M8G5C:'0M26YF;W)M871I;VYE;B!F_'(@)7,Z("5S`$9E:&QE<B!B96EM(,1N
M9&5R;B!D97,@4&%S<W=O<G1S.B`E<P!&96AL97(@:6X@9&5R($5M86EL;F%C
M:')I8VAT+@!&96AL97(@8F5I;2!38VAR96EB96X@=F]N("(E<R(N`$5S=&QA
M;F0`Q'1H:6]P:65N`$5T;FES8VAE<P!%=7)O<&$`5&5R;6EN(&AI;GIU9V5F
M_&=T.@!497)M:6X@9V5L]G-C:'0Z`%1E<FUI;B!B96%R8F5I=&5T.@!497)M
M:6X@=F]N("5S(&)I<R`E<P!497)M:6X@;FEC:'0@9V5F=6YD96X`5&5R;6EN
M92!M_'-S96X@96EN(%-T87)T9&%T=6T@:&%B96XN`%1E<FUI;F4@;?QS<V5N
M(&5I;F5N(%1I=&5L(&AA8F5N+@!!;&QE(#$U($UI;G5T96X`06QL92`R($UI
M;G5T96X`06QL92`S,"!396MU;F1E;@!!;&QE(#4@36EN=71E;@!"96D@:F5D
M97(@06YM96QD=6YG`$%L;&4@:&%L8F4@4W1U;F1E`$%L;&4@-C`@4V5K=6YD
M96X`0F5I<W!I96QW97)T93H`075S9OQH<F5N`%9E<F=R]M]E<FX`3F%M96X@
M<W5C:&5N`$UE;OP@875S9F%H<F5N`"<I)R!E<G=A<G1E=`!%:6YZ96QN97,@
M5V]R="!O9&5R(%-U8VAB96=R:69F(&EN($%N9OQH<G5N9W-Z96EC:&5N(&5R
M=V%R=&5T`%9E<F9A;&QS9&%T=6T`17AP;VYE;G0`17AP;W)T:65R96X`2V%L
M96YD97(@97AP;W)T:65R96X`5F]R9&5R9W)U;F1F87)B90!(;V-H;&%D96X@
M9&5R($MO;F9I9W5R871I;VX@<&5R($944`!"96YU='IE<F5I;G-T96QL=6YG
M96X@:V]N;G1E;B!N:6-H="!G96QA9&5N('=E<F1E;BX`5F5R8FEN9'5N9R!Z
M=6T@3$1!4"!397)V97(@9V5S8VAE:71E<G0N`%9E<F)I;F1U;F<@>G5M(%--
M0BU397)V97(@9V5S8VAE:71E<G0N`$5S(&MO;FYT92!K96EN92!+;W!I92!V
M;VX@(B5S(B!E<G-T96QL="!W97)D96XN`$5S(&MO;FYT92!N:6-H="!N86-H
M("(E<R(@:V]P:65R="!W97)D96XN`$%U9F)A=2!E:6YE;B!N975E;B!305-,
M+59E<F)I;F1U;F<@:7-T(&9E:&QG97-C:&QA9V5N+@!%<R!K;VYN=&4@;FEC
M:'0@;F%C:"`B)7,B('9E<G-C:&]B96X@=V5R9&5N+@!&96AL97(@8F5I;2!,
M97-E;CH@)7,`2&5I=&5R`$9A;&ML86YD:6YS96QN`$9A<O9E<@!38VAW97)E
M<B!&96AL97(Z`$9A>`!&87AE`$9E8G)U87(`1V5F_&AL=&4@5&5M<&5R871U
M<@!'96;\:&QT92!496UP97)A='5R.B``5F5R96EN>F5L=&4@4V-H875E<@!6
M97)E:6YZ96QT92!38VAN965S8VAA=65R`$9E;&1M871R:7@`1FEG;&5T($-!
M4%1#2$$`1FEG;&5T+49O;G0`1FED<V-H:0!$871E:0!!;GIA:&PZ("5S($1A
M=&5I`$%N>F%H;#H@)7,@1&%T96EE;@!$871E:6UA;F%G97(`1&%T96EN86UE
M`$1A=&5I875S=V%H;`!$871E:2U(;V-H;&%D96X`1&%S($AO8VAL861E;B!V
M;VX@1&%T96EE;B!W:7)D(&YI8VAT('5N=&5R<W3\='IT+@!&:6QT97(`4W5C
M:&4`1FEN;FQA;F0`17)S=&4@2.1L9G1E`$5R<W1E<R!6:65R=&5L`%9E<FCD
M;'1N:7,@>G5R_&-K<V5T>F5N`%5M9')E:&5N`%1E>'1F;'7?`$YE8F5L`$1A
M<R!697)Z96EC:&YI<R`E<R!E>&ES=&EE<G0@;FEC:'0`4V-H<FEF=&9A<F)E
M`$5S<V5N`$;\<B!"<F]W<V5R+"!D:64@:V5I;F4@0FEL9&5R('5N=&5R<W3\
M='IE;@!6;W)H97)S86=E("A4048I`%9O<FAE<F=E<V%G=&4@5&%G92`H5F]R
M:&5R<V%G96X@96YT:&%L=&5N(%1A9V4@=6YD($[D8VAT92P@96EN(&AO:&5R
M(%=E<G0@:V%N;B!Z=2!E:6YE;2!S96AR(&=R;]]E;B!";&]C:R!F_&AR96XI
M`%!A<W-W;W)T('9E<F=E<W-E;C\`1F]R;75L87)E`$=L_&-K<VME:W,`1VS\
M8VMS:V5K<W1Y<`!';/QC:W-K96MS90!';/QC:W-K96MS92`R`$9O<F5N`%=E
M:71E<FQE:71U;F<`1G(`4F%H;65N`$9R86YK<F5I8V@`175R;W#D:7-C:&5S
M($9R86YK<F5I8V@`1G)E:0!&<F5I+T=E8G5C:'0M26YF;W)M871I;VYE;@!&
M<F%N>O9S:7-C:"U'=6%Y86YA`$9R86YZ]G-I<V-H+5!O;'EN97-I96X`1G)A
M;GKV<VES8VAE($=E8FEE=&4@:6T@<_QD;&EC:&5N($EN9&ES8VAE;B!/>F5A
M;@!&<F5I=&%G`%9O;@!!=7,@`%9O;&QS=.1N9&EG92!"97-C:')E:6)U;F<`
M5F]L;&UO;F0`5F]L;'-TY&YD:6=E<B!.86UE`%IU:_QN9G1I9V4`1V%B=6X`
M0FEL9&5R(&%U<R!D:65S97(@1V%L97)I90!'86QE<FEE.@!'86UB:6$`4W!I
M96P`06QL9V5M96EN97,`)7,M2V]N9FEG=7)A=&EO;B!E<GIE=6=E;@!%<GIE
M=6=T97(@0V]D90!'96]R9VEE;@!$975T<V-H;&%N9`!':&%N80!':6)R86QT
M87(`5F]R;F%M90!!;&QG96UE:6YE($5I;G-T96QL=6YG96X`3&]S`$=O961E
M;`!';V]G;&4@36%P<P!';V]G;&4@4W5C:&4`1V5H92!N86-H("5S`$=R875S
M='5F96X`1W)I96-H96YL86YD`$=R:65C:&ES8V@@*$E33RTX.#4Y+3<I`$=R
M]FYL86YD`$=R96YA9&$`1W)U<'!E;G9E<G=A;'1U;F<`1W)U<'!E;FYA;65N
M(&3\<F9E;B!N:6-H="!L965R('-E:6X`1W)O=7!?;&1A<#H@1&EE($=R=7!P
M92`E<R!K;VYN=&4@;FEC:'0@:&EN>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG
M(&1E<R!397)V97)S.B``1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN
M=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N`$=R;W5P7VQD87`Z($1I92!'<G5P
M<&4@)7,@:V]N;G1E(&YI8VAT(&%K='5A;&ES:65R="!W97)D96X`1W)U<'!E
M;@!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=A<W1R96-H
M=&4`1^1S=&5B=6-H`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,
M`$1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%IE;&QE(&5I;F5R(%IE:6QE
M(&YI8VAT(&SV<V-H96XN`$1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%-P
M86QT92!E:6YE<B!486)E;&QE(&YI8VAT(&SV<V-H96XN`$1E<B!%9&ET;W(@
M:V%N;B!D:64@;&5T>G1E(%IE:6QE(&5I;F5R(%1A8F5L;&4@;FEC:'0@;/9S
M8VAE;BX`2%144"U!=71H96YT:69I>FEE<G5N9R!N:6-H="!G969U;F1E;BX`
M2&%I=&D`2&%S:"U!;&=O<FET:&UU<P!$:65S:6<`W&)E<G-C:')I9G0`2V]P
M9F5I;G1RY&=E`$AE87)D+2!U;F0@36-$;VYA;&1I;G-E;&X`4V-H=V5R92!'
M97=I='1E<@!(96)RY&ES8V@@*$E33RTX.#4Y+3@M22D`2/9H90!(:6QF90!%
M9&ET;W)H:6QF90!(:6QF90!(96UI<W!H97)E`$1I97,@:7-T(&1E<B!"96=I
M;FX@9&5R($1A=&5I.@!!=7-B;&5N9&5N`"5S(&%U<V)L96YD96X`2&]C:`!?
M4W1A<G1S96ET90!6871I:V%N<W1A9'0`4W1A<G1S96ET90!!9')E<W-E('!R
M:79A=`!(96EM=F5R>F5I8VAN:7,`5&5L969O;B!P<FEV870`2&]N9'5R87,`
M2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!5;F?\;'1I9V4@)7,M6$U,
M+41A=&5N(&EN($YA8VAR:6-H="`E<P!(;W)D92]+;VQA8CH@17,@<&%S<W0@
M:V5I;F4@3F%C:')I8VAT('IU;2!/8FIE:W0@)7,`2&]R9&4O2V]L86(Z($ME
M:6X@3V)J96MT('9O;2!4>7`@)7,@:6X@3F%C:')I8VAT("5S(&=E9G5N9&5N
M`$AO<F1E+TMO;&%B.B`E<R`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&5N=&9E
M<FYT`$AO<F1E+TMO;&%B.B!$:64@26YT96=R871I;VYS9G5N:W1I;VYE;B!B
M96[V=&EG96X@9&EE(")D;VUX;6PB(%!(4"U%<G=E:71E<G5N9P!(;W)D92]+
M;VQA8CH@1OQR(&1A<R!/8FIE:W0@)7,@:V]N;G1E(&ME:6X@;F5U97(@6$U,
M+4)A=6T@97)Z975G="!W97)D96X`2&]R9&4O2V]L86(Z("5S("(E<R(@:V]N
M;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z($1I
M92!-24U%+4E$(&1E<R!!8G-C:&YI='1S('9O;2!4>7`@)7,@:V]N;G1E(&YI
M8VAT(&AE<F%U<V=E9G5N9&5N('=E<F1E;BX`2&]R9&4O2V]L86(Z("5S("(E
M<R(@:V]N;G1E(&YI8VAT('-Y;F-H<F]N:7-I97)T('=E<F1E;CH@)7,`2&]R
M9&4O2V]L86(Z($1I92!G96UE:6YS86UE;B!/8FIE:W1E(&MO;FYT96X@;FEC
M:'0@<WEN8VAR;VYI<VEE<G0@=V5R9&5N.B`E<P!(;W)D92]+;VQA8CH@56YB
M96MA;FYT97,@9V5M96EN<V%M97,@3V)J96MT("(E<R(`2&]R:7IO;G1A;&4@
M3&EN:64`2&]R:7IO;G1A;&5R($EN;F5N86)S=&%N9`!(;W)I>F]N=&%L.@!3
M='5N9&4H;BD`5VEE('-I;F0@4VEE(&AI97)H97)G96QA;F=T/R!":71T92!A
M;B!D:64@16YT=VEC:VQE<B!Z=7+\8VMM96QD96XA*0!7:64@;&%N9R!S;VQL
M96X@9&EE(%IE:71A8G-C:&YI='1E(&EN(&1E<B!486=E<RT@=6YD(%=O8VAE
M;F%N<VEC:'0@<V5I;C\`5VEE('9I96QE(%-P86QT96X@<V]L;&5N('IU<V%M
M;65N9V5F_&=T('=E<F1E;C\`1OQR('=I979I96QE(%1A9V4@:6X@9&5R(%IU
M:W5N9G0@<V]L;&5N($9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N(&%N9V5Z
M96EG="!W97)D96X_`%=I979I96QE($9E;&1E<B`H4W!A;'1E;BD@9VEB="!E
M<S\`5VEE('9I96QE(%IE:6QE;B!S;VQL96X@>G5S86UM96YG96;\9W0@=V5R
M9&5N/P!,=69T9F5U8VAT:6=K96ET`$QU9G1F975C:'1I9VME:70Z(`!+;VUI
M:V5R`%5N9V%R;@!!;FQE9V5N(&1E<R!)34%0+5!O<W1F86-H<R!I<W0@9F5H
M;&=E<V-H;&%G96XZ("5S`$SV<V-H96X@9&5S($E-05`M4&]S=&9A8VAS(&ES
M="!F96AL9V5S8VAL86=E;CH@)7,`1F5S=&QE9V5N(&1E<B!)34%0+5!O<W1F
M86-H+5%U;W1A(&ES="!F96AL9V5S8VAL86=E;CH@)7,`25`M061R97-S90!)
M4"U!9')E<W-E(&YI8VAT('9E<F;\9V)A<BX`25`M061R97-S92!N:6-H="!I
M;2!E<FQA=6)T96X@0TE$4BU";&]C:RX`5F5R;&5T>G5N9R!D97(@9F5S=&=E
M;&5G=&5N($E0+@!:96EL92!E:6YF_&=E;B!?=F]R`$ES;&%N9`!.=7(@0FEL
M9&5R`$EC;VYS(&;\<B`E<P!":6QD97(@=6YD(%1E>'0`0F5Z96EC:&YU;F<@
M9&5R($ED96YT:73D=`!796YN('-I92!N:6-H="!K;W)R96MT(&%N9V5Z96EG
M="!W:7)D+"`E<RP@=6T@<VEE(&EN(&5I;F5M(&YE=65N($9E;G-T97(@86YG
M97IE:6=T('IU(&)E:V]M;65N+@!796YN(%-I92!M:70@9&5M($EN=&5R;F5T
M($5X<&QO<F5R(&ME:6YE(%-Y;6)O;&4@<V5H96XL(&W\<W-E;B!3:64@9&EE
M<V5S($OD<W1C:&5N(&UA<FMI97)E;BP@=6T@4$Y'+51R86YP87)E;GH@875S
M>G5S=&5L;&5N+@!796YN(%-I92!D:65S92!.86-H<FEC:'0@86X@4W1E;&QE
M(&5I;F4@0FEL9&5S('-E:&5N+"!K86YN($EH<B!"<F]W<V5R(&1A<R!":6QD
M+"!D87,@4VEE(&AO8VAL861E;B!M]F-H=&5N(&YI8VAT(&%N>F5I9V5N+@!&
M86QL<R!):'(@16UA:6QP<F]G<F%M;2!K96EN92!I5&EP+4%N9G)A9V5N('5N
M=&5R<W3\='IT+"!K]FYN96X@4VEE(&5I;F5N(&1E<B!F;VQG96YD96X@3&EN
M:W,@=F5R=V5N9&5N+"!U;2!D96X@5&5R;6EN('IU(&)E<W3D=&EG96X@;V1E
M<B!A8GIU;&5H;F5N+@H*56T@9&5N(%1E<FUI;B!Z=2!B97-TY'1I9V5N.@HE
M<PH*56T@9&5N(%1E<FUI;B!U;G1E<B!6;W)B96AA;'0@>G4@8F5S=.1T:6=E
M;CH*)7,*"E5M(&1E;B!497)M:6X@86)Z=6QE:&YE;CH*)7,`0FEL9'9O<G-C
M:&%U.@!":6QD+5523`!":6QD+5523#H`0FEL9"!V;VX@1V%L97)I90!":6QD
M('9O;B!'86QE<FEE.@!":6QD+4AO8VAL861E;@!":6QD97(`2V%L96YD97(@
M:6UP;W)T:65R96XL(%-C:')I='0@)60`26UP;W)T:65R96XL(%-C:')I='0@
M)60`2V%L96YD97(M26UP;W)T+RU%>'!O<G0`26UP;W)T:65R=&5S($9E;&0Z
M("5S`$EM<&]R=&EE<G1E($9E;&1E<CH`6F5I;&4@96EN9OQG96X@7VYA8V@`
M56YG_&QT:6=E($%K=&EO;B!A;F=E9V5B96XN`%5N9_QL=&EG97(@0F5N=71Z
M97)N86UE('5N9"]O9&5R(%!A<W-W;W)T+@!&86QS8VAE<B!"96YU='IE<FYA
M;64@;V1E<B!%;6%I;&%D<F5S<V4N(%9E<G-U8VAE;B!3:64@97,@97)N975T
M(&]D97(@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N(%-Y<W1E;6%D;6EN:7-T
M<F%T;W(L('=E;FX@4VEE('=E:71E<F4@2&EL9F4@8F5N]G1I9V5N+@!%:6YZ
M=6<@=F5R9W+VWV5R;@!);F1I96X`16EN>F5L;F4@0F5N=71Z97(`26YD;VYE
M<VEE;@!);F9O<FUA=&EO;@!);F9O<FUA=&EO;F5N`$EN9F]R;6%T:6]N96X@
M;FEC:'0@;65H<B!V97)F_&=B87(N`%]3<&%L=&4@9&%V;W(@96EN9OQG96X`
M0FEL9"!H:6YZ=6;\9V5N`%1A8F5L;&4@96EN9OQG96X`3&EN:R!E:6YF_&=E
M;@!37W!A;'1E(&1A;F%C:"!E:6YF_&=E;@!%:6YE(&YE=64@4W!A;'1E(&YA
M8V@@9&5R(&%K='5E;&QE;B!E:6YF_&=E;@!%:6YE(&YE=64@4W!A;'1E('9O
M<B!D97(@86MT=65L;&5N(&5I;F;\9V5N`$5I;F4@;F5U92!:96EL92!N86-H
M(&1E<B!A:W1U96QL96X@96EN9OQG96X`16EN92!N975E(%IE:6QE('9O<B!D
M97(@86MT=65L;&5N(&5I;F;\9V5N`$5I;F5N(&YE=65N($%B<V%T>B!N86-H
M(&1E;2!A:W1U96QL96X@16QE;65N="!E:6YF_&=E;@!%:6YE;B!N975E;B!!
M8G-A='H@=F]R(&1E;2!A:W1U96QL96X@16QE;65N="!E:6YF_&=E;@!!;'1E
M<FYA=&EV92!6;W)L86=E(&5I;F;\9V5N`$=E8F5N(%-I92!E:6YE($5M86EL
M861R97-S92!A;BP@86X@9&EE(&1A<R!N975E(%!A<W-W;W)T(&=E<V-H:6-K
M="!W97)D96X@<V]L;#H`6F5L;&4@9&%N86-H(&5I;F;\9V5N`%IE;&QE(&1A
M=F]R(&5I;F;\9V5N`%-P86QT92!D86YA8V@@96EN9OQG96X`4W!A;'1E(&1A
M=F]R(&5I;F;\9V5N`$YA8VAR:6-H=&5N(&AI;GIU9OQG96X`06)S871Z(&1A
M;F%C:"!E:6YF_&=E;@!!8G-A='H@9&%V;W(@96EN9OQG96X`6F5I;&4@9&%N
M86-H(&5I;F;\9V5N`%IE:6QE(&1A=F]R(&5I;F;\9V5N`$=E8F5N(%-I92!D
M:64@06YT=V]R="!A=68@9&EE(%-I8VAE<FAE:71S9G)A9V4@96EN.@!":6QD
M(&5I;F;\9V5N+V)E87)B96ET96X`3&EN:R!E:6YF_&=E;B]B96%R8F5I=&5N
M`%IU('=E;FEG($=U=&AA8F5N+"!U;2!A;B!D:64@5F5R=&5I;&5R;&ES=&4@
M>G4@=F5R<V-H:6-K96XN`%IU('=E;FEG($=U=&AA8F5N+@!'86YZ>F%H;`!,
M:7-T92!V;VX@1V%N>GIA:&QE;@!5;F?\;'1I9V5R(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+@!5;F?\;'1I9V4@6DE0+41A=&5N+@!5;F?\;'1I9V4@06YW
M96YD=6YG+@!5;F?\;'1I9V4@0F%T8V@M240N`%5N9_QL=&EG92!$871E;B!E
M:6YG96)E;BX`56YG_&QT:6=E(%II96QA9')E<W-E+@!5;F?\;'1I9V5S($1A
M=&5I9F]R;6%T`%5N9_QL=&EG97(@3&EZ96YZ<V-H;/QS<V5L+@!5;F?\;'1I
M9V5R($]R="!A;F=E9V5B96XN`%5N9_QL=&EG97(@;7-G7W1Y<&4N`%5N9_QL
M=&EG92!O9&5R(&9E:&QE;F1E(&%P:5]I9"X`56YG_&QT:6=E(&]D97(@9F5H
M;&5N9&4@4&%R86UE=&5R+@!5;F?\;'1I9V5S(-QB97)R96-H="X`56YG_&QT
M:6=E(%!A<G1N97(M240N`%5N9_QL=&EG97(@4')O9'5K=&-O9&4N`%5N9_QL
M=&EG97,@4')O=&]K;VQL+@!5;F?\;'1I9V5R($5M<&;D;F=E<CH@(B5S(@!5
M;F?\;'1I9V5S(&=E;65I;G-A;65S($]B:F5K=`!5;F?\;'1I9V4@57)S<')U
M;F=S861R97-S92X`56YG_&QT:6=E(%5N:6-O9&4M1&%T96XN`$EN=F5N=&%R
M`$%U<W=A:&P@=6UK96AR96X`27-L86UI<V-H92!297!U8FQI:R!)<F%N`$ER
M86L`27)L86YD`$ES;&4@;V8@36%N`%9E<F5I;GIE;'1E($=E=VET=&5R`$ES
M<F%E;`!!=7-S=&5L;&5R`$MU<G-I=@!)=&%L:65N`$IA;6%I:V$`2F%N=6%R
M`$IA<&%N`$IA<&%N:7-C:"`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YI
M96X`2G5L:0!*=6YI`$)L;V-K<V%T>@!:96YT<FEE<F5N`$)L;V-K<V%T>@!,
M:6YK<R!A=7-R:6-H=&5N`%)E8VAT<R!A=7-R:6-H=&5N`$MA<V%C:'-T86X`
M3W)I9VEN86P@8F5I8F5H86QT96X_`$ME;FEA`$ME<F)E<F]S+5-E<G9E<B!H
M870@075T:&5N=&EF:7II97)U;F<@>G5R_&-K9V5W:65S96XN`$ME<FYE;"U.
M975L:6YG90!38VAL_'-S96QE<GIE=6=U;F<`1FEN9V5R86)D<G5C:R!D97,@
M4V-H;/QS<V5L<P!38VAL_'-S96QLY&YG90!38VAL_'-S96QT>7``4V-H;/QS
M<V5L>G=E8VL`1&5R(%-C:&S\<W-E;"!B969I;F1E="!S:6-H(&)E<F5I=',@
M875F(&1E;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R+@!3=&EC:'?V
M<G1E<@!+:6YD97(`2VER:6)A=&D`1&5M;VMR871I<V-H92!6;VQK<W)E<'5B
M;&EC($MO<F5A`%)E<'5B;&EK($MO<F5A`$MO<F5A;FES8V@@*$550RU+4BD`
M2W5W86ET`$MI<F=I<VES=&%N`$%N7W!A<W-E;@!3<')A8VAE`$QA;W,`3&5T
M>G1E(#(T(%-T=6YD96X`3&5T>G1E($CD;&9T90!,971Z=&4@Q&YD97)U;F<`
M3&5T>G1E<B!-;VYA=`!,971Z=&4@4&%S<W=O<G3D;F1E<G5N9P!,971Z=&5S
M(%9I97)T96P`3&5T>G1E($%K='5A;&ES:65R=6YG.@!,971Z=&5S($IA:'(`
M3&5T>G1E($%N;65L9'5N9SH@)7,`3&5T>G1E($%N;65L9'5N9SH@)7,@=F]N
M("5S`$QE='IT92!!;FUE;&1U;F<Z($YO8V@@;FEE`$QE='IT92!7;V-H90!,
M971T;&%N9`!'97-E='H`1F]R;6%T`$QE97(@;&%S<V5N(&;\<B!K96EN96X@
M4F%H;65N`$QI8F%N;VX`3&EN:W,`3&EN:V4@W&)E<G-C:')I9G0`3&EN:V4@
M5V5R=&4`3&5S;W1H;P!%8F5N90!,:6)E<FEA`$QI8GEE;@!,:65C:'1E;G-T
M96EN`%-P<OQH<F5G96X`3&5I8VAT97(@4F5G96X`1G+\:"!L96EC:'1E<B!2
M96=E;@!3<.1T97(@3&5I8VAT97(@4F5G96X`3&5I8VAT92!296=E;G-C:&%U
M97(`3&5I8VAT97(@4F5G96X@;6ET($=E=VET=&5R`$QE:6-H=&5R(%-C:&YE
M969A;&P`3&5I8VAT92!38VAN965S8VAA=65R`$QI;65R:6-K`%?D:&QE;B!3
M:64@9&EE(%IE:71S<&%N;F4L(&1I92!E>'!O<G1I97)T('=E<F1E;B!S;VQL
M.@!,:6YK`$QI;FL@=F5R=V5I<W0@875F.@!%;6%I;&%D<F5S<V4@=F5R;&EN
M:V5N/P!,:6YK<P!,:6YU>"U';/QC:W-K96MS90!,:7-T("T@0F5N=71Z97(@
M:V%N;B!D96X@3W)D;F5R('-E:&5N`$1A=&5N8F%N:V5N(&%N>F5I9V5N`$AI
M;&9E96EN='+D9V4@86YZ96EG96X`5&%B96QL96X@86YZ96EG96X`3&ES=&5N
M+4%R8VAI=@!,:7-T96XM2&EL9F4`3&ES=&5N+4ED`$QI<W1E;BU"97-I='IE
M<@!,:7-T96XM061R97-S90!,:7-T96XM06YM96QD=6YG`$QI<W1E;BU!8FUE
M;&1U;F<`1&%S($%N>F5I9V5N(&1E<B!397-S:6]N<R!I<W0@9F5H;&=E<V-H
M;&%G96XZ("5S`$1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@:7-T(&9E:&QG
M97-C:&QA9V5N.B`E<P!$87,@06YZ96EG96X@9&5R($)E;G5T>F5R(&ES="!N
M:6-H="!M]F=L:6-H+@!,:71E<F%T=7(`3&ET875E;@!?3W)T`$QA9&4N+BX`
M3&]K86QE(%5H<GIE:70Z(`!3<')A8VAE('5N9"!:96ET`$]R=`!!;FUE;&1E
M;@!,;V<@9&5R(&QE='IT96X@4WEN8VAR;VYI<V%T:6]N+@!!8FUE;&1E;@!!
M;FUE;&1E;@!!;FUE;&1E875F9V%B96X`1&EE($%N;65L9'5N9R!I<W0@9F5H
M;&=E<V-H;&%G96XL('=E:6P@4VEE($EH<F5N($)E;G5T>F5R;F%M96X@;V1E
M<B!):'(@4&%S<W=O<G0@9F%L<V-H(&5I;F=E9V5B96X@:&%B96XN`$%N;65L
M9'5N9R!F96AL9V5S8VAL86=E;BX`3&%N9V5R(%1E>'0`3&EE8F4`3FEE9')I
M9P!+;"X@9W)I96-H:7-C:&4@0G5C:'-T86)E;@!+;"X@;&%T96EN:7-C:&4@
M0G5C:'-T86)E;@!+;"X@<O9M:7-C:&4@6F%H;&5N`$QU>&5M8G5R9P!-30!-
M3U1$`$U3+51.148M06YH86YG(&5N=&AI96QT(&ME:6YE($1A=&5N+@!(24Y7
M14E3`$UA8V%O`$1I92!E:&5M86QI9V4@2G5G;W-L87=I<V-H92!297!U8FQI
M:R!-87IE9&]N:65N`$UA9&%G87-K87(`36%G:64`5V5B;6%I;`!%;6%I;"!!
M9&UI;FES=')A=&EO;@!,:6YK(%]A;FQE9V5N+BXN`$UA;&%W:0!-86QA>7-I
M80!-86QI9&EV96X`36%L:0!-86QT80!697)W86QT96X@4VEE(&5X=&5R;F4@
M2V%L96YD97(N`%9E<G=A;'1E;B!3:64@9&EE($MA=&5G;W)I96XL(&UI="!D
M96YE;B!3:64@16QE;65N=&4@=6YD($5I;G1RY&=E(&ME;FYZ96EC:&YE;B!K
M]FYN96XL('-O=VEE(&1I92!Z=6=E:/9R:6=E;B!&87)B96XN`$UA<#(T+4MA
M<G1E`$UA<%%U97-T+4MA<G1E`%IU;W)D;G5N9V5N(&=E<W!E:6-H97)T+@!-
MY')Z`$%UWV5N86)S=&%N9`!-:70@1V5L97-E;BTO56YG96QE<V5N+5-T871U
M<R!V97)S96AE;@!-:70@86YD97)E;2!3=&%T=7,@=F5R<V5H96X@*'HN0BX@
M5VEC:'1I9R]"96%N=V]R=&5T*0!-87)S:&%L;&EN<V5L;@!-87)T:6YI<75E
M`%IU9V5O<F1N971E($9E;&1E<@!-875R971A;FEE;@!-875R:71I=7,`36%X
M:6UA;"!E<FQA=6)T97(@2W)E9&ET+@!-87AI;6%L92!.86-H=&EC:'1E;G1E
M:6QE(/QB97)S8VAR:71T96XN`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT
M96X@,C0@4W1U;F1E;CH@`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT96X@
M-B!3='5N9&5N.B``36%X:6UA;&4@06YZ86AL(&%N(%1E<FUI;F5N`$UA>&EM
M86QE($%N>F%H;"!A;B!0;W)T86QB;/9C:V5N`$UA>&EM86QE($SD;F=E`$UA
M:0!-87EO='1E($ES;&%N9`!)8V@`365D:7II;@!"97-P<F5C:'5N9P!-:71G
M;&EE9&5R`$UE;OQA;&%R;0!-96[\;&ES=&4`365N_&UO9'5S.@!:96QL96X@
M>G5S86UM96YF_&=E;@!.86-H<FEC:'0`1&EE($YA8VAR:6-H="!K;VYN=&4@
M97)F;VQG<F5I8V@@_&)E<G!R_&9T('=E<F1E;B!A8F5R(&YI8VAT(&1A<R!:
M97)T:69I:V%T(&1E<R!!8G-E;F1E<G,N`$YA8VAR:6-H="!N:6-H="!M96AR
M(&?\;'1I9RX`3F%C:')I8VAT96YT>7``365T87(@5V5T=&5R`$UE=&%R8FQO
M8VL@;FEC:'0@=F5R9OQG8F%R+@!-971A<F)L;V-K(&YI8VAT('9E<F;\9V)A
M<BX@1&5T86EL<R!W=7)D96X@9OQR(&1E;B!!9&UI;FES=')A=&]R(&UI=&=E
M;&]G9W0N`$ME:6YE(%9E<F)I;F1U;F<@>G5R($UE=&%R1$(N`$UE=&AO9&4`
M1&EE($UE=&AO9&4@(B5S(B!I<W0@;FEC:'0@9&5F:6YI97)T`$UE=&AO9&4@
M;FEC:'0@9&5F:6YI97)T+B!!=69G97)U9F5N92!-971H;V1E.B`E<P!-971R
M:7-C:`!-97AI:V\`1O9D97)I97)T92!3=&%A=&5N('9O;B!-:6MR;VYE<VEE
M;@!-:71T90!-:6UE='EP`%1I969S='1E;7!E<F%T=7(@9&5R(&QE='IT96X@
M,C0@4W1U;F1E;CH@`%1I969S='1E;7!E<F%T=7(@9&5R(&QE='IT96X@-B!3
M='5N9&5N.B``1&%S(&UI;FEM86QE(%!A<W-W;W)T86QT97(@:7-T(&YO8V@@
M;FEC:'0@86)G96QA=69E;@!-:6YU=&4H;BD`4W!I96=E;&X`5F5R<V-H:65D
M96YE<P!014%2+5!A:V5T($A45%!?4F5Q=65S="!F96AL="X`1F5H;&5N9&4@
M2V]N9FEG=7)A=&EO;BX@4VEE(&W\<W-E;B!D:65S92!J971Z="!E<GIE=6=E
M;BP@=V5N;B!3:64@9&EE($%N=V5N9'5N9R!V97)W96YD96X@;?9C:'1E;BX`
M1F5H;&5N9&4@3F%C:')I8VAT96XM240N`%!%05(M4&%K970@36%I;"!F96AL
M="X`1F5H;&5N9&4@4VET>G5N9W,M240N`$UO`$5M86EL($UO8FEL`$WDWVEG
M`,1N9&5R=6YG<V1A='5M`%523"!B96%R8F5I=&5N`$UO9'5L=7,`4F5P=6)L
M:6L@36]L9&%U`$UO;F%C;P!-;VYT86<`36]N9V]L96D`36]N870`36]N871S
M86YS:6-H=`!-;VYA="!U;F0@2F%H<@!-;VYA=&QI8V@`36]N871L:6-H92!4
M97)M:6YL:7-T90!-;VYA=&QI8V@Z(%=I961E<FAO;'5N9R!A;&QE`$UO;F%T
M92!I;2!V;W)A=7,`36]N871E('IU=F]R`$UO;G1S97)R870`36]N9'!H87-E
M;@!-96AR($9E;&1E<B!I;B!:96EL92`E9"!A;',@9&EE(&5R=V%R=&5T96X@
M)60@9V5F=6YD96XN`$UA<F]K:V\`W&)E<G=I96=E;F0@:&5I=&5R`-QB97)W
M:65G96YD($)E=_9L:W0`W&)E<G=I96=E;F0@0F5W]FQK="!U;F0@5VEN9&EG
M`-QB97)W:65G96YD(%-O;FYI9P!.86-H('5N=&5N`$YA8V@@;&EN:W,`3F%C
M:"!R96-H=',`3F%C:"!O8F5N`$YA8V@@=6YT96X`3F%C:"!O8F5N`$UO<V%M
M8FEK`$%U<W=A:&QL:7-T92!I;B!M96AR97)E;B!%8F5N96X`375L=&EM87`M
M54LM2V%R=&4`365H<F5R92!I0V%L96YD87(M2V]M<&]N96YT96X@9V5F=6YD
M96X[(&YU<B!E:6X@=D5V96YT('=I<F0@=6YT97)S=/QT>G0N`$UE:')F86-H
M875S=V%H;`!-96EN($MO;G1O`$UE:6X@2V]N=&\`365I;F4@2V%L96YD97(`
M365I;F4@2V%L96YD97(Z`$UE:6YE($9R96DO1V5B=6-H="U54DP`365I;B!0
M;W)T86P`365I;B!0;W)T86QL87EO=70`0G5R;6$`3D5)3BP@:6-H('-T:6UM
M92!.24-(5"!Z=0!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3FEE9&5R;&%N
M9&4`3FEE9&5R;.1N9&ES8VAE($%N=&EL;&5N`$YE='-C87!E+4)A<VES+552
M3`!.971S8V%P92U#02U3<&5R<G5N9W,M55),`$YE='-C87!E+4-!+5)I8VAT
M;&EN:65N+5523`!.971S8V%P92U:971I9FEK871S97)N975E<G5N9W,M55),
M`$YE='-C87!E+5-P97)R=6YG<RU54DP`3F5T<V-A<&4M4U-,+5-E<G9E<FYA
M;64`3F5T<V-A<&4M2V]M;65N=&%R`$YE='-C87!E+5IE<G1I9FEK871T>7``
M3F5T>G=E<FL`3FEE`$YE=6MA;&5D;VYI96X`3F5U92!+871E9V]R:64`3F5U
M97(@5&5R;6EN`$YE=6UO;F0`3F5U97(@0F5N=71Z97)N86UE("AO<'1I;VYA
M;"D`3F5U<V5E;&%N9`!.975E<B!+86QE;F1E<B!E<G-T96QL="!U;F0@875T
M;VUA=&ES8V@@9F]L9V5N9&5N($=R=7!P96X@6G5G<FEF9B!G97?D:')T.B`E
M<RX`3F5U97,@4&%S<W=O<G0`1&%S(&YE=64@4&%S<W=O<F0@=VER9"!A;2`E
M>"!A8FQA=69E;BX`1&EE(&YE=65N(%!A<W-W]G)T97(@<W1I;6UE;B!N:6-H
M="#\8F5R96EN+@!.975E<R!&96YS=&5R("A?8FQA;FLI`$YA8VAR:6-H=&5N
M`$YE=W-G<G5P<&5N`%=E:71E<@!.Y&-H<W1E(#(T(%-T=6YD96X`3N1C:'-T
M92`T(%!H87-E;@!.Y&-H<W1E<B!486<`3N1C:'-T97(@36]N870`3N1C:'-T
M92!7;V-H90!.Y&-H<W1E<R!*86AR`$[D8VAS=&5R(%1A9P!.Y&-H<W1E($5I
M;G-T96QL=6YG96X`3N1C:'-T92!7;V-H90!796ET97(^`$YI8V%R86=U80!.
M:6=E<@!.:6=E<FEA`$YA8VAT<P!.:75E`$YE:6X`2V5I;B!!;&%R;0!+96EN
M92!496EL;F5H;65R`$ME:6YE($MO;F9I9W5R871I;VYS9&%T96X@=F5R9OQG
M8F%R+"!U;2!5;G1E<G-C:&EE9&4@86YZ=7IE:6=E;BX`2V5I;F4@4W1R871E
M9VEE('IU;2!%<G-T96QL96X@=F]N($E33RU!8F)I;&1E<FX@=F5R9OQG8F%R
M+@!+96EN92!"871C:"U6;W)L86=E+@!%<R!E>&ES=&EE<G0@:V5I;B!";&]C
M:R!A;B!D97(@86YG96=E8F5N96X@4&]S:71I;VX`2V5I;B!+86QE;F1E<FYA
M;64@9OQR(&1I92!-0T%,+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`
M17,@<VEN9"!K96EN92!+86QE;F1E<B!F_'(@1^1S=&4@=F5R9OQG8F%R+@!+
M96EN92#$;F1E<G5N9V5N+@!5;G1E<FAA;&(@9&EE<V5R($5B96YE(&OV;FYE
M;B!K96EN92!W96ET97)E;B!5;G1E<G)E8VAT92!H:6YZ=6=E9OQG="!W97)D
M96XN`$;\<B`E<R!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA
M=&EO;F5N(&%N9V5G96)E;BX`1OQR(&1E;B!&5%`M5D93+51R96EB97(@=W5R
M9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B
M96XN`$;\<B!D96X@4U%,+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF
M:6=U<F%T:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+@!&_'(@9&5N(%-1
M3"U$871E:2U61E,M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO
M;G-I;F9O<FUA=&EO;F5N(&%N9V5G96)E;BX`2V5I;B!+<F5D:70@;65H<B#\
M8G)I9RX`2V5I;B!%;7!FY&YG97(@86YG96=E8F5N+@!+96EN($5N9&4`2V5I
M;F4@5&5R;6EN90!+96EN92!$871E:2!H;V-H9V5L861E;@!+96EN92!&<F5I
M+T=E8G5C:'0M26YF;W)M871I;VYE;B!F_'(@)7,@=F5R9OQG8F%R`$5S('=U
M<F1E;B!K96EN92!I0V%L96YD87(M1&%T96X@9V5F=6YD96XN`$ME:6YE($EC
M;VYS(&=E9G5N9&5N+@!%<R!W=7)D92!K96EN($]R="!F97-T9V5L96=T+@!+
M96EN($]R="!A;F=E9V5B96XN`$ME:6YE($YA8VAR:6-H="!A;F=E9V5B96XN
M`$ME:6X@3F%M92!A;F=E9V5B96XN`$ME:6YE($YU;6UE<B!A;F=E9V5B96XN
M`$ME:6YE(&%N<W3VWVEG96X@1VS\8VMS:V5K<V4`2V5I;B!087-S=V]R="!F
M_'(@9&EE($A45%`M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+96EN
M(%!A<W-W;W)T(&;\<B!D:64@24U!4"U!=71H96YT:69I>FEE<G5N9R!A;F=E
M9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!+97)B97)O<RU!=71H96YT
M:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!,
M;V=I;BU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O
M<G0@9OQR(&1I92!005-35T0M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N
M+@!+96EN(%!A<W-W;W)T(&;\<B!D:64@4TU"+4%U=&AE;G1I9FEZ:65R=6YG
M(&%N9V5G96)E;BX`2V5I;B!09F%D('IU;2!/<&5N4U-,+5!R;V=R86UM(&%N
M9V5G96)E;BX@1&%S($]P96Y34TPM4')O9W)A;6T@=VER9"!B96[V=&EG="P@
M=6T@4$M#4RTQ,BU$871E;B!V97)A<F)E:71E;B!Z=2!K]FYN96XN`$ME:6YE
M(&%U<W-T96AE;F1E;B!296=I<W1R:65R=6YG96XN`$ME:6X@4W!E:6-H97)P
M;&%T>BU+;VYT:6YG96YT(&9E<W1G96QE9W0N`$ME:6YE(%=I961E<FAO;'5N
M9P!+96EN92!286AM96X`2V5I;B!4<F5N;GIE:6-H96X@86YG96=E8F5N+@!+
M96EN92!396ET96X`1&%T96D@;FEC:'0@9V5F=6YD96X`2V5I;F4@=&5M<&]R
MY')E<R!697)Z96EC:&YI<R!F_'(@9&5N($-A8VAE(&=E9G5N9&5N+@!+96EN
M($)E;G5T>F5R;F%M92!U;F0O;V1E<B!087-S=V]R="!A;F=E8F5N+@!%<R!W
M=7)D96X@:V5I;F4@9_QL=&EG96X@6$U,+41A=&5N('IU<OQC:V=E9V5B96X`
M2V5I;F4@9_QL=&EG92!%;6%I;&%D<F5S<V4@9V5F=6YD96X`2V5I;F4@5V5R
M=&4`2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@9&5R($]R:6=I;F%L:V]N9FEG
M=7)A=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE($EH<F4@2V]N9FEG=7)A
M=&EO;BX`2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@26AR97(@2V]N9FEG=7)A
M=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE($EH<F4@2V]N9FEG=7)A=&EO
M;BX`2V5I;F4`2V5I;G,@*%-T86YD87)D(&)E;G5T>F5N*0!.;W)D:7-C:"`H
M25-/+3@X-3DM,3`I`$YO<F9O;&MI;G-E;`!.]G)D;&EC:&4@2&5M:7-P:&5R
M90!.]G)D;&EC:&4@36%R:6%N96X`3F]R=V5G96X`1_QL=&EG(&)I<P!'_&QT
M:6<@86(`2V5I;B!697)Z96EC:&YI<P!.:6-H="!G969U;F1E;@!.:6-H="!I
M;7!L96UE;G1I97)T+@!.:6-H="!F97-T9V5L96=T`$YI8VAT('5N=&5R<W3\
M='IT+@!.;W1I>F5N`$YI8VAT<R!A;GIU>F5I9V5N+"!B:71T92!Z=7+\8VMG
M96AE;BX`0F5N86-H<FEC:'1I9W5N9V5N`$YO=F5M8F5R`$IE='IT`%IA:&P`
M06YZ86AL(&1E<B!:96EC:&5N`$%N>F%H;"!D97(@4W!A;'1E;@!!;GIA:&P@
M9&5R(%IE:6QE;@!+96EN92!.=6UM97)N(&;\<B!D:64@5F5R=&5I;&5R;&ES
M=&4@86YG96=E8F5N+@!/2P!/8FIE:W0`3V)J96MT97)S=&5L;&5R`$]K=&%L
M>F%H;`!/:W1O8F5R`$9I;'1E<B!F_'(@86YS=/;?:6=E($EN:&%L=&4`0OQR
M;P!):'(@;F5U97,@4&%S<W=O<G0@;75S<R!S:6-H('9O;B!):')E;2!A;'1E
M;B!U;G1E<G-C:&5I9&5N+@!!;'1E<R!087-S=V]R=`!&86QS8VAE<R!A;'1E
M<R!087-S=V]R="X`3VUA;@!!;0!"96D@86QL96X@2V%L96YD97)N+"!F_'(@
M9&EE(&EC:"!,97-E<F5C:'1E(&AA8F4`0F5I(&%L;&5N(&%N9V5Z96EG=&5N
M($MA;&5N9&5R;@!.=7(@8F5I(&UE:6YE;B!+86QE;F1E<FX`3G5R($E-05`M
M4V5R=F5R('5N=&5R<W3\='IE;B!G96UE:6YS86UE($]R9&YE<BX`3G5R(&%N
M<W3VWVEG92!';/QC:W-K96MS90!.=7(@96EN92!%;6%I;"U!9')E<W-E(&5R
M;&%U8G0N`$YU<B!D97(@0F5S:71Z97(@;V1E<B!D97(@4WES=&5M861M:6YI
M<W1R871O<B!K86YN(&1E;B!"97-I='IE<B!O9&5R(&1I92!"97-I='IE<G)E
M8VAT92#D;F1E<FX`26X@;F5U96T@1F5N<W1E<B#V9F9N96X`3W!E;E-33"U&
M96AL97(Z(%-I9VYI97)T92!3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E
M>'1R86AI97)T('=E<F1E;BX`1&EE<V5N($QI;FL@:6X@96EN96T@;F5U96T@
M1F5N<W1E<B#V9F9N96X`0F5T<FEE8G-Y<W1E;0!&<F5I=VEL;&EG`$9R96EW
M:6QL:6=E(%1E:6QN96AM97(`16EN<W1E;&QU;F=E;@!%:6YS=&5L;'5N9V5N
M(&;\<B`E<P!.=6UM97)I97)T92!,:7-T90!/<F=A;FES871I;VX`3W)G86YI
M<V%T:6]N<V%B=&5I;'5N9P!/<F=A;FES:65R96X`3W)I9VEN86QV;W)L86=E
M(&1E<B!!;G=E;F1U;F<`3W)I9VEN86QV;W)L86=E(&EN("5S.@!3;VYS=&EG
M90!!;F1E<F4@26YF;W)M871I;VYE;@#<8F5R<VEC:'0`0F5S:71Z97(`0F5S
M:71Z97)R96-H=&4`0F5S:71Z97(Z("5S`%!!32U!=71H96YT:69I>FEE<G5N
M9R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!014%2.CI-86EL+4)A8VME;F0`1&EG
M:71A;&4@4$=0+55N=&5R<V-H<FEF=`!01U`M=F5R<V-H;/QS<V5L=&4@1&%T
M96X`UF9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P`36ET(%!'4"!U;G1E<GIE
M:6-H;F5T92]V97)S8VAL_'-S96QT92!$871E;@!02%`@0V]D90!02%`@4VAE
M;&P`4$T`5F]R;6ET=&%G<R!L96EC:'1E<B!296=E;@!.86-H;6ET=&%G<R!2
M96=E;@!.86-H;6ET=&%G<R!38VAA=65R`$YA8VAM:71T86=S(%-C:&YE90!.
M86-H;6ET=&%G<R!38VAN965S8VAA=65R`$YA8VAM:71T86=S(%-O;FYE`$YA
M8VAM:71T86=S($=E=VET=&5R`$1I92!03U-)6"U%<G=E:71E<G5N9R!F96AL
M=`!?4$A0(%-H96QL`$EN;F5N86)S=&%N9`!086MI<W1A;@!086QA=0!"97-E
M='IT92!086SD<W1I;F5N<VES8VAE($=E8FEE=&4`4&%N86UA`%!A<'5A+4YE
M=6=U:6YE80!087)A9W5A>0!496EL=V5I<V4@0F5W]FQK=`!087-S=V]R=`!0
M87-S=V]R="!E<F9O;&=R96EC:"!G9>1N9&5R="X`1F%L<V-H97,@4&%S<W=O
M<G0`2V5I;B!087-S=V]R="!F_'(@9&EE(%)!1$E54RU!=71H96YT:69I>FEE
M<G5N9R!A;F=E9V5B96XN`%!A<W-W;W)T(&UI="!"97-TY'1I9W5N9P!087-S
M=V]R=#H`4&%S<W=O<G0Z(`!$:64@4&%S<W?V<G1E<B!M_'-S96X@9VQE:6-H
M('-E:6XN`$QI<W1E('9E<F=A;F=E;F5R(%1E<FUI;F4`16EN9OQG96X`5F]N
M(&1E<B!:=VES8VAE;F%B;&%G92!E:6YF_&=E;@!09F%D`%)H>71H;75S`$%U
M<W-T96AE;F1E(%)E9VES=')I97)U;F=E;CH`4&5R<V]N96X`4')O>F5N=`!7
M87)T=6YG<V%R8F5I=&5N(&1U<F-H9OQH<F5N`%=A<G1U;F=S87)B96ET96X@
M;F%C:"!D97(@06YM96QD=6YG(&1U<F-H9OQH<F5N/P!$:65S96X@5&5R;6EN
M('5N=VEE9&5R8G)I;F=L:6-H(&SV<V-H96X_`%)E8VAT90!296-H="`B)7,B
M('=U<F1E(&YI8VAT(&=E;/9S8VAT+@!:=6=R:69F('9E<G=E:6=E<G0`4F5C
M:'1E`%)E8VAT979E<G=A;'1U;F<`4&5R<_9N;&EC:&4@06YG86)E;@!097)U
M`$AA=7-T:65R90!0:&EL:7!P:6YE;@!496QE9F]N`$9O=&]S`%!I=&-A:7)N
M`%!I>&5L`%!L871T:&5I=&5N`$)I='1E(&ML:6-K96X@4VEE(&EN(&5I;F4@
M6F5L;&4`0FET=&4@8F5S=.1T:6=E;B!3:64L(&1A<W,@4VEE(&1I97-E<R!%
M;&5M96YT(&SV<V-H96X@;?9C:'1E;CH`0FET=&4@8F5TY'1I9V5N(%-I92P@
M9&%S<R!3:64@9&5N($QI;FL@=F]N(&1I97-E;2!%;&5M96YT(&5N=&9E<FYE
M;B!M]F-H=&5N+@!":71T92!E:6YE;B!-;VYA="!U;F0@96EN($IA:'(@86YG
M96)E;BX`0FET=&4@9V5B96X@4VEE(&5I;F5N($YA;65N(&;\<B!D:64@;F5U
M92!+871E9V]R:64@86XZ`$)I='1E(&5I;F4@9_QL=&EG92!)4"U!9')E<W-E
M(&5I;F=E8F5N+@!":71T92!G96)E;B!3:64@96EN(&?\;'1I9V5S($1A='5M
M(&%N.R#\8F5R<'+\9F5N(%-I92!D:64@6F%H;"!D97(@5&%G92!I;B!D96T@
M36]N870N`$)I='1E(&5I;F5N(&?\;'1I9V5N(%IE:71W97)T(&5I;F=E8F5N
M+@!":71T92!G96)E;B!3:64@96EN92!:=7-A;6UE;F9A<W-U;F<@26AR97,@
M4')O8FQE;7,@86XN`$)I='1E(&=E8F5N(%-I92!):')E;B!"96YU='IE<FYA
M;65N('5N9"!):'(@4&%S<W=O<G0@86X`0FET=&4@;&5S96X@4VEE('-I8V@@
M9&5N(&9O;&=E;F1E;B!497AT('-O<F=FY&QT:6<@9'5R8V@N(%-I92!-W%-3
M14X@9&EE<V5N($)E9&EN9W5N9V5N('IU<W1I;6UE;BP@=V5N;B!3:64@9&EE
M<V5S(%-Y<W1E;2!B96YU='IE;B!M]F-H=&5N+@!":71T92!D96X@;F5U96X@
M2V%T96=O<FEE;F%M96X@96EN9V5B96XZ`%!O;&5N`%!O;&ET:6L`56UF<F%G
M96X`4&]R=&%L96EN<W1E;&QU;F=E;@!0;W)T=6=A;`!0;W-I=&EO;FEE<G5N
M9R!D:65S92!":6QD97,`4&]S:71I;VYI97)U;F<@9&EE<V5R(%1A8F5L;&4`
M4V5N9&5N(&%N(&1I97-E;B!/<F1N97(@*&YI8VAT(&1U<F-H($E-05`I`$YI
M961E<G-C:&QA9R!I;B!D96X@;&5T>G1E;B`E<R!3='5N9&4H;BDZ(`!.:65D
M97)S8VAL86=S+3QB<B`O/G=A:')S8VAE:6YL:6-H:V5I=`!0<F5F<U]L9&%P
M.B!$:64@8F5N]G1I9W1E($Q$05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@
M9V5F=6YD96XN`%!R969S7W-E<W-I;VXZ($1I92!B96[V=&EG=&4@4V5S<VEO
M;BU%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`3'5F=&1R=6-K
M`$QU9G1D<G5C:R!A=68@4V5E:/9H93H@`$QU9G1D<G5C:SH@`%9O<G-C:&%U
M`$5I;F4@5F]R<V-H874@9&5S($)I;&1E<R!I;B!E:6YE;2!N975E;2!&96YS
M=&5R(&%N>F5I9V5N`%9O<FEG97(@5&%G`%9O<FEG92!7;V-H90!6;VAE<FEG
M97(@5&%G`%9O:&5R:6=E($5I;G-T96QL=6YG96X`1&]K=6UE;G0@9')U8VME
M;@!0<FEV871E<B!38VAL_'-S96P`4')O8FQE;64`4')O8FQE;6)E<V-H<F5I
M8G5N9P!0<F]J96MT90!.86-H9G)A9V5T97AT`-9F9F5N=&QI8VAE<B!38VAL
M_'-S96P`06QG;W)I=&AM=7,@9&5S(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS
M`$EN9F]R;6%T:6]N96X@>G5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96P`1&%S
M(/9F9F5N=&QI8VAE+W!R:79A=&4@4V-H;/QS<V5L<&%A<B!K;VYN=&4@;FEC
M:'0@97)S=&5L;'0@=V5R9&5N+@!0=65R=&\@4FEC;P!.86-H<FEC:'1E;B!E
M;F1G_&QT:6<@;/9S8VAE;@!+871A<@!!8F9R86=E`%-P96EC:&5R<&QA='HM
M2V]N=&EN9V5N=`#69F9E;G1L:6-H97(@4E-!(%-C:&S\<W-E;"`H)60@0FET
M*0!!=7-W86AL:VYO<&8`4F5G96X`1G+\:"!296=E;@!3<.1T97(@4F5G96X`
M4F5G96YS8VAA=65R`%-C:&YE97)E9V5N`%)E9V5N(&EN(%-C:&YE92#\8F5R
M9V5H96YD`$=L_&-K<VME:W,`5F5R:.1L=&YI<P!,97-E;@!.86-H<FEC:'1E
M;B!L97-E;@`E<R!W:7)K;&EC:"!L]G-C:&5N/R!$:65S97(@5F]R9V%N9R!K
M86YN(&YI8VAT('+\8VMGY&YG:6<@9V5M86-H="!W97)D96XN`$1A=&5N(&1E
M<R!"96YU='IE<G,@)7,@=VER:VQI8V@@;/9S8VAE;C\@1&EE<V5R(%9O<F=A
M;F<@:V%N;B!N:6-H="!R_&-K9^1N9VEG(&=E;6%C:'0@=V5R9&5N+@!7:65D
M97)H;VQE;B!B:7,`5VEE9&5R:&]L=6YG`%=I961E<FAO;'5N9W-M=7-T97(`
M5VEE9&5R:&]L=6YG<V5N9&4`5VEE9&5R:&]L=6YG<VEN=&5R=F%L;`!7:65D
M97)H;VQU;F=S='EP`%3D9VQI8V@`36]N871L:6-H`%?V8VAE;G1L:6-H`$KD
M:')L:6-H`$;\:')T(&QE='IT92!!:W1I;VX@97)N975T(&%U<P!!:W1U86QI
M<VEE<F4`1'EN86UI<V-H92!-96[\96QE;65N=&4@86MT=6%L:7-I97)E;CH`
M4&]R=&%L86YS:6-H="!A:W1U86QI<VEE<F5N.@!296=U;.1R97(@075S9')U
M8VL`5F5R8FEN9'5N9W,M0G)O=W-E<@!!:W1U86QI<VEE<F5N`$)E;65R:W5N
M9V5N`$5R:6YN97)U;F<Z("5S`$5X=&5R;F4@2V%L96YD97(`17AT97)N92!+
M86QE;F1E<CH`16YT9F5R;G1E(%-E<G9E<@!!8F]N;F5M96YT+5523`!397)V
M97)A9')E<W-E("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`16YT
M9F5R;F5N`"5S(&5N=&9E<FYE;@!496EL;F5H;65R(&5N=&9E<FYE;@!";&]C
M:R!L]G-C:&5N`%-P86QT92!L]G-C:&5N`$9O<FUA=&EE<G5N9R!E;G1F97)N
M96X`4&%A<B!L]G-C:&5N`$=E<W!E:6-H97)T97,@4VMR:7!T(&%U<R!D96T@
M=&5M<&]RY')E;B!697)Z96EC:&YI<R!E;G1F97)N96XN`$5N=&9E<FYE`$1I
M97-E<R!%;&5M96YT(&%U<R!D96T@1&]K=6UE;G0@96YT9F5R;F5N`$)E;G5T
M>F5R(&SV<V-H96X`0F5N=71Z97(@;/9S8VAE;CH@)7,`17AI<W1I97)E;F1E
M;B!+86QE;F1E<B!M:70@9&5M(&EM<&]R=&EE<G1E;B!E<G-E='IE;C\@/'-T
M<F]N9SY787)N=6YG.B!$86UI="!W97)D96X@86QL92!A:W1U96QL96X@16EN
M='+D9V4@:6X@9&5M($MA;&5N9&5R(&=E;/9S8VAT+CPO<W1R;VYG/@!!;F9R
M86=E(&MO;FYT92!N:6-H="!B96%N='=O<G1E="!W97)D96XN(%IU<OQC:V=E
M9V5B96YE<B!&96AL97)C;V1E.B``1&5R(&=E=_QN<V-H=&4@1&EE;G-T(&MO
M;FYT92!N:6-H="!G969U;F1E;B!W97)D96XN`$YO='=E;F1I9P`B)7,B('=U
M<F1E(&EN(&1E<B!+;VYF:6=U<F%T:6]N(&;\<B`E<R!N:6-H="!A;F=E9V5B
M96XN`"(E<R(@=W5R9&4@:6X@9&5R(%9&4RU+;VYF:6=U<F%T:6]N(&YI8VAT
M(&%N9V5G96)E;BX`(B5S(B!W=7)D92!I;B!D97(@2V]N9FEG=7)A=&EO;B!N
M:6-H="!A;F=E9V5B96XN`$YO='=E;F1I9V4@5&5I;&YE:&UE<@!.;W1W96YD
M:6=E<R!&96QD`%IU<OQC:W-E='IE;@!087-S=V]R="!Z=7+\8VMS971Z96X`
M4V5T>F5N(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K`%IU<OQC:W-E='IE;@!!
M;G=O<G0`3&5T>G1E($%B9G)A9V4@96EN9OQG96X`17)G96)N:7-S90!:=7+\
M8VL@>G4@16EN<W1E;&QU;F=E;@!.975E<R!087-S=V]R="!E<FYE=70@96EN
M9V5B96X`4NEU;FEO;@!+;VYF:6=U<F%T:6]N('IU<OQC:W-E='IE;@!765-)
M5UE'+45D:71O<B!%:6YS=&5L;'5N9V5N`%+D='-E;`!296-H=',`4F5C:'1E
M(-QB97)S8VAR:69T`%)E8VAT92!797)T90!?6F5I;&5N96EG96YS8VAA9G1E
M;BXN+@!2;VQL90!2=6WD;FEE;@!5;2`Q.#"P(&1R96AE;@!.86-H(&QI;FMS
M(&1R96AE;@!.86-H(')E8VAT<R!D<F5H96X`6F5I;&5N96EG96YS8VAA9G1E
M;@!:96EL96YE:6=E;G-C:&%F=&5N`%IE:6QE;CH`4F5G96QN`%)A:&UE;B!Z
M=VES8VAE;B!A;&QE;B!:96EL96X@=6YD(%-P86QT96X`4F%H;65N(&YU<B!Z
M=VES8VAE;B!3<&%L=&5N`%)A:&UE;B!N=7(@>G=I<V-H96X@6F5I;&5N`%-T
M87)T96X`4G5S<VES8VAE($;V<F1E<F%T:6]N`%)U86YD80!3+TU)344@:W)Y
M=&]G<F%P:&ES8VAE(%5N=&5R<V-H<FEF=`!-:70@4R]-24U%('9E<G-C:&S\
M<W-E;'1E($YA8VAR:6-H=`!305-,+4%U=&AE;G1I9FEZ:65R=6YG(&ES="!N
M:6-H="!V97)F_&=B87(N`%--4RU697)S86YD`%-13"!3:&5L;`!344PM06YW
M96ES=6YG('IU<B!!8F9R86=E(&1E<B!797)T90!34T@`15)&3TQ'`%-?44P@
M4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S('5N9"!.979I<P!3
M86EN="!,=6-I80!386EN="!0:65R<F4@=6YD($UI<75E;&]N`%-A:6YT(%9I
M;F-E;G0@=6YD(&1I92!'<F5N861I;F5N`$=L96EC:&5R(%)A:&UE;B`H7W-E
M;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@=6YD(%!R:6YC:7!E`%-A
M=&5L;&ET96YP<F]V:61E<@!386US=&%G`%-A=61I+4%R86)I96X`4W!E:6-H
M97)N`"(E<R(@<W!E:6-H97)N`"5S('-P96EC:&5R;@!!;',@2V]P:64@<W!E
M:6-H97)N`%1E:6QN96AM97(@<W!E:6-H97)N`%1E<FUI;B!S<&5I8VAE<FX`
M16EN<W1E;&QU;F=E;B!S<&5I8VAE<FX`17)Z975G=&4@2V]N9FEG=7)A=&EO
M;B!A;',@4$A0+5-K<FEP="!I;2!T96UP;W+D<F5N(%9E<GIE:6-H;FES($EH
M<F5S(%-E<G9E<G,@<W!E:6-H97)N+@`E<RU+;VYF:6=U<F%T:6]N(&=E<W!E
M:6-H97)T+@!$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T('=U<F1E(&EN("(E
M<R(@9V5S<&5I8VAE<G0N`%9E<F5I;GIE;'1E($=E=VET=&5R`%=I<W-E;G-C
M:&%F=`!3=6-H90!+86QE;F1E<B!3=6-H96X`4W5C:&UA<V-H:6YE;@!3=6-H
M97)G96)N:7-S90!.86-H($MA;&5N9&5R;B!S=6-H96XZ`$1A=&5I96X@875S
M=^1H;&5N`%?D:&QE;B!3:64@96EN96X@2V%L96YD97(@>G5M($)E87)B96ET
M96X@875S`$1A='5M(&%U<W?D:&QE;@!(:6YZ=7IU9OQG96YD92!'<G5P<&5N
M(&%U<W?D:&QE;@!.975E;B!"97-I='IE<B!A=7-WY&AL96X`4V5R=F5R(&%U
M<W?D:&QE;@!(:6YZ=7IU9OQG96YD96X@0F5N=71Z97(@875S=^1H;&5N`$%L
M;&4@875S=^1H;&5N`$QE9V5N(%-I92!A;&QE($1A='5M<VMO;7!O;F5N=&5N
M(&9E<W0N`$]B:F5K="!A=7-WY&AL96X`5^1H;&5N(%-I92!+86QE;F1E<B!A
M=7,Z`$QE9V5N(%-I92!"97-TY'1I9W5N9W,M16EN<W1E;&QU;F=E;B!F97-T
M+"!W:64@9&EE('5N=&5R<V-H:65D;&EC:&5N($%N<VEC:'1E;B!D87)G97-T
M96QL="!W97)D96X@<V]L;&5N+"!U;F0@=^1H;&5N(%-I92!E:6YE(%-T86YD
M87)D86YS:6-H="X`2V5I;F5N(&%U<W?D:&QE;@!7Y&AL96X@4VEE(&1E;B!+
M86QE;F1E<BP@:6X@9&5N(&EM<&]R=&EE<G0@=V5R9&5N('-O;&PZ`%?D:&QE
M;B!3:64@9&5N+V1I92!+86QE;F1E<BP@9&5R+V1I92!E>'!O<G1I97)T('=E
M<F1E;B!S;VQL*&5N*0!7Y&AL96X@4VEE(&1I92!B96[V=&EG=&5N(%IE:6-H
M96X@875S(&1E;B!J97=E:6QI9V5N($9E;&1E<FX@875S+B!$86YN(&OV;FYE
M;B!3:64@9&EE<V4@875S(&1E;2!497AT9F5L9"!K;W!I97)E;B!U;F0@:6X@
M26AR92!.86-H<FEC:'0@96EN9OQG96XN`%?D:&QE;B!3:64@9&%S($1A='5M
M<W1R96YN>F5I8VAE;CH`5^1H;&5N(%-I92!D87,@1&%T=6US9F]R;6%T.@!7
MY&AL96X@4VEE(&1A<R!%>'!O<G1F;W)M870Z`%?D:&QE;B!3:64@9&EE($1A
M=&5I+"!D:64@:6UP;W)T:65R="!W97)D96X@<V]L;#H`5^1H;&5N(%-I92!D
M96X@97)S=&5N(%=O8VAE;G1A9P!7Y&AL96X@4VEE(&1A<R!&;W)M870@9&5R
M(&EM<&]R=&EE<G1E;B!$871E:3H`5^1H;&5N(%-I92!D:64@261E;G1I=.1T
M+"!D:64@4VEE(.1N9&5R;B!M]F-H=&5N.@!7Y&AL96X@4VEE(&1A<R!:96ET
M=')E;FYZ96EC:&5N.@!7Y&AL96X@4VEE(&1A<R!:96ET9F]R;6%T.@!7Y&AL
M96X@4VEE(&1I92!:96ET<W!A;FYE+"!D:64@86YG97IE:6=T('=E<F1E;B!S
M;VQL.@!7Y&AL96X@4VEE(&1I92!!;G-I8VAT(&%U<RP@9&EE(&)E:6T@4W1A
M<G0@86YG97IE:6=T('=E<F1E;B!S;VQL.@!7Y&AL96X@4VEE('IW96D@>G5S
M86UM96YG96CV<FEG92!&96QD97(@875S+@!,96=E;B!3:64@9F5S="P@=V5L
M8VAE(%1E<FUI;F4@875F(&1E<B!0;W)T86QS96ET92!A;F=E>F5I9W0@=V5R
M9&5N('-O;&QE;BX`5^1H;&5N(%-I92!E:6X@1F%R8G-C:&5M82X`5^1H;&5N
M(%-I92!):')E(&)E=F]R>G5G=&4@4W!R86-H93H`4')O8FQE;6)E<FEC:'0@
M86)S8VAI8VME;@!335,@=F5R<V-H:6-K96X`16EN92!497)M:6YA8G-A9V4@
M86X@86QL92!496EL;F5H;65R('-C:&EC:V5N+"!W96YN(&1I97-E<B!497)M
M:6X@9V5L]G-C:'0@=VER9`!%;6%I;"!A;B`E<R!S8VAR96EB96X`06MT=6%L
M:7-I97)U;F=E;B]%:6YL861U;F=E;B!A;B!A;&QE(%1E:6QN96AM97(\8G(@
M+SX*<V-H:6-K96XL('=E;FX@9&EE<V5R(%1E<FUI;B!G97-P96EC:&5R="!W
M:7)D+@!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:65N('5N9"!-
M;VYT96YE9W)O`%-E<FEE;FYU;6UE<@!397)V97)D871E;B!U;F?\;'1I9R!O
M9&5R(&YI8VAT('9E<F;\9V)A<BX`4V5S<W-I;VYV97)W86QT=6YG`%-E<W-I
M;VXM240@86)G96QA=69E;BX`4VET>G5N9V5N`$%U<W=A:&PM4V%T>@!%;F1D
M871U;2!F97-T;&5G96X`3&5G96X@4VEE(&1I92!%:6YS=&5L;'5N9V5N(&9E
M<W0L(&1I92!E<R!):&YE;B!E<FQA=6)E;B!):'(@4&%S<W=O<G0@>G5R_&-K
M>G5S971Z96XL(&9A;&QS('-I92!E<R!E:6YM86P@=F5R9V5S<V5N('-O;&QT
M96XN`%=I961E<FAO;'5N9W-E;F1E(&9E<W1L96=E;@!3=&%R=&1A='5M(&9E
M<W1L96=E;@!,96=E;B!3:64@96YT9F5R;G1E(%-E<G9E<B!F97-T+"!A=68@
M9&EE(%-I92!V;VX@26AR96T@4&]R=&%L(&%U<R!Z=6=R96EF96X@;?9C:'1E
M;BX`3&5G96X@4VEE($EH<F4@1G)E:2]'96)U8VAT+4MA;&5N9&5R('5N9"`M
M16EN<W1E;&QU;F=E;B!U;F0@9&EE(&%N9&5R97(@0F5N=71Z97(@9F5S="X`
M5^1H;&5N(%-I92!):')E(&)E=F]R>G5G=&4@4W!R86-H92P@6F5I='IO;F4@
M=6YD($1A='5M<V5I;G-T96QL=6YG96XN`$QE9V5N(%-I92!D87,@9&EE(%-T
M87)T86YW96YD=6YG+"!D87,@1F%R8G-C:&5M82P@9&EE(%-E:71E;F%K='5A
M;&ES:65R=6YG('5N9"!A;F1E<F4@06YZ96EG965I;G-T96QL=6YG96X@9F5S
M="X`2V]N9FEG=7)A=&EO;@!!:W1U86QI<VEE<G5N9W-S:W)I<'1E('-I;F0@
M=F5R9OQG8F%R`$UE:')E<F4@<&%S<V5N9&4@3W)T92!M:70@9&EE<V5M(%!A
M<F%M971E<CH@`%-E>6-H96QL96X`1V5M96EN<V%M97(@2V%L96YD97(@;FEC
M:'0@9V5F=6YD96XZ("5S`$=E;65I;G-A;64@2V%L96YD97(`1V5M96EN<V%M
M92!+86QE;F1E<CH`16EN:V%U9@!+=7)Z92!:=7-A;6UE;F9A<W-U;F<`4V]L
M;&5N(%1A<W1E;FMO;6)I;F%T:6]N96X@9OQR(&1I92!M96ES=&5N($QI;FMS
M(&%K=&EV:65R="!W97)D96X_`%IE:6=E;@!+86QE;F1E<B!!;GIE:6=E;@!+
M871E9V]R:65N;&5G96YD92!A;GIE:6=E;C\`3/9S8VAE;BTL($%L87)M+2!U
M;F0@5VEE9&5R:&]L=6YG<W-Y;6)O;&4@:6X@9&5R($MA;&5N9&5R86YS:6-H
M="!A;GIE:6=E;C\`56YT97)S8VAI961E('IW:7-C:&5N(&1E<B!A:W1U96QL
M96X@=6YD(&1E<B!G97)A9&4@97)Z975G=&5N($MO;F9I9W5R871I;VX@86YZ
M96EG96XN`$;D;&QI9V4@075F9V%B96X@:6T@2V%L96YD97(@86YZ96EG96X_
M`$9R96DO1V5B=6-H="U,96=E;F1E(&%N>F5I9V5N/P!!;GIE:6=E;BP@=V%N
M;B!D:64@;&5T>G1E($%N;65L9'5N9R!E<F9O;&=T(&ES=#\`3G5R(%1E<FUI
M;F4@;6ET($%L87)M(&%N>F5I9V5N/P!%<FAA;'1E;B!D97,@3W)I9VEN86QS
M(&5R;?9G;&EC:&5N`$%U<W?D:&QE<B!A;GIE:6=E;@!'96UE:6YS86UE($MA
M;&5N9&5R(&YE8F5N96EN86YD97(@86YZ96EG96X_`%=E<FMZ975G;&5I<W1E
M(&;\<B!486)E;&QE;B!A;GIE:6=E;C\`075F9V%B96X@:6X@9&5N($MA=&5G
M;W)I969A<F)E;B!A;GIE:6=E;C\`1&%S("5S+4UE;OP@875F(&1E<B!L:6YK
M96X@4V5I=&4@86YZ96EG96X_`$1I86QO9R!F_'(@5&%B96QL96YZ96QL96YE
M:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YE:6=E
M;G-C:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YZ96EL96YE
M:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@0FEL9&5I9V5N<V-H
M869T96X@86YZ96EG96X`56AR>F5I=&5N('IW:7-C:&5N(&%L;&5N(%1A9V5N
M(&EN(&1E;B!7;V-H96YA;G-I8VAT96X@86YZ96EG96X_`$AO8VAL861E;B!E
M<FWV9VQI8VAE;@!38VAA=65R`$9R_&@@4V-H875E<@!3<.1T97(@4V-H875E
M<@!38VAA=65R(&EN(&1E<B!5;6=E8G5N9P!697)K;&5I;F5R;@!697)K;&5I
M;F5R;B!O9&5R('9E<G-C:&EE8F5N(%-I92!E<G-T(&1I92!B96YA8VAB87)T
M96X@0FSV8VME`%-I97)R82!,96]N90!296=I<W1R:65R96X`4VEG;F%T=7(`
M4VEG;F%T=7)A;&=O<FET:&UU<P!3:6YG87!U<@!'<O;?90!787)T=6YG<V%R
M8F5I=&5N(/QB97)S<')I;F=E;@!3;&]W86ME:0!3;&]W96YI96X`4V-H;F5E
M`%-C:&YE97-C:&%U97(`4V-H;F5E<V-H875E<@!&<OQH(%-C:&YE97-C:&%U
M97(`4W#D=&5R(%-C:&YE97-C:&%U97(`4V-H;F5E:/9H93H@`%-C:&YE96UE
M;F=E(&%L<R!787-S97(Z(`!3;VQO;6]N:6YS96QN`%-O;6%L:65N`$QI961E
M<B`F($=E9&EC:'1E`$%U<W=A:&P@9&5R(%-O<G1I97)R96EH96YF;VQG90!5
M<G-P<G5N9W-A9')E<W-E`%/\9&%F<FEK80!3_&1E=7)O<.1I<V-H("A)4T\M
M.#@U.2TS*0!3_&1G96]R9VEE;B!U;F0@9&EE(%/\9&QI8VAE;B!386YD=VEC
M:&EN<V5L;@!3_&1L:6-H92!(96UI<W!H97)E`$%B<W1A;F0@>G=I<V-H96X@
M875F96EN86YD97(@9F]L9V5N9&5N(%IE;&QE;@!!8G-T86YD('IW:7-C:&5N
M($EN:&%L="!U;F0@4F%H;65N('9O;B!:96QL96X`06)S=&%N9&AA;'1E<@!!
M8G-T86YD`$%B<W3D;F1E`%-P86YI96X`4W!A;0!3;VYD97)Z96EC:&5N+45I
M;F=A8F4`6F5L;&4@=&5I;&5N`%-P86QT92!T96EL96X`6F5I;&4@=&5I;&5N
M`%-P;W)T`%-R:2!,86YK80!?0F5G:6YN`%-T86YD87)D`%-T87(@5')E:P!3
M=&%R=&1A='5M`$)E9VEN;@!3=&%R='IE:70`4W1A<G1J86AR`%]3=&%T=7,`
M0G5N9&5S<W1A870@;V1E<B!0<F]V:6YZ`%-T871U<P!3<&5I8VAE<F9O<FUA
M=`!3=')AWV4`1'5R8VAG97-T<FEC:&5N`%IE:6-H96YL:7-T90!$;VUA:6X@
M875S(&1E<B!!9')E<W-E(&5N=&9E<FYE;@!3=&EL(%M#4U-=`%-O`%5N=&5R
M=F5R>F5I8VAN:7,@(B5S(B!N:6-H="!G969U;F1E;BX`0F5T<F5F9@!!8G-C
M:&EC:V5N`$1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@9OQR("(E<R(@=W5R
M9&4@86)G97-C:&EC:W0N(%-I92!K]FYN96X@<VEC:"!N;V-H(&YI8VAT(&%N
M;65L9&5N+"!S;VQA;F=E(&1I92!!;F9R86=E(&YO8V@@;FEC:'0@8F5S=.1T
M:6=T('=U<F1E+@!4:65F9V5S=&5L;'0`17)F;VQG`"(E<R(@=W5R9&4@97)F
M;VQG<F5I8V@@:&EN>G5G96;\9W0N`$1A=&5N(&1E<R!"96YU='IE<G,@(B5S
M(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="X`(B5S(B!W=7)D92!E<F9O
M;&=R96EC:"!G96SV<V-H="X`(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G96SV
M<V-H="X`2V]N9FEG=7)A=&EO;B!E<F9O;&=R96EC:"!Z=7+\8VMG97-E='IT
M+B!396ET92!N974@;&%D96XL('5M(&1I92#$;F1E<G5N9V5N(&%N>G5Z96EG
M96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B!E<F9O;&=R96EC:"!G97-P
M96EC:&5R="X`0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N("5S(&5R9F]L9W)E
M:6-H(&=E<W!E:6-H97)T+@`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&%K='5A
M;&ES:65R=``E<R!W=7)D92!E<F9O;&=R96EC:"!G97-P96EC:&5R=`!3=61A
M;@!:=7-A;6UE;F9A<W-U;F<`4V]N;F5N875F9V%N9P!3;VYN96YU;G1E<F=A
M;F<`4V]N;G1A9P!3;VYN:6<`4V]N;F5N875F9V%N9P!3;VYN96YA=68O=6YT
M97)G86YG`%-O;FYE;F%U9F=A;F<Z(`!3;VYN96YU;G1E<F=A;F<`4V]N;F5N
M=6YT97)G86YG.B``2&]C:&=E<W1E;&QT`%-U<'!O<G0`4W5R:6YA;0!.86-H
M;F%M90!3=F%L8F%R9"!U;F0@2F%N($UA>65N`%-W87-I;&%N9`!38VAW961E
M;@!38VAW96EZ`%-Y;F-H<F]N:7IA=&EO;G-L;V<@9V5L]G-C:'0`4WEN8TU,
M`$9O<FUA=&9E:&QE<B!I;B!3=6-H8F5G<FEF9F5N`$%R86)I<V-H92!297!U
M8FQI:R!3>7)I96X`1V5W:71T97(`1V5W:71T97(@=6YD(%=I;F1I9P!'97=I
M='1E<@!&<OQH($=E=VET=&5R`%135BU$871E:0!486)E;&QE;F5I9V5N<V-H
M869T96X`5&%B96QL90!486)E;&QE;F5I9V5N<V-H869T96X`5&%I=V%N`%1A
M:7=A;BP@8VAI;F5S:7-C:&4@4')O=FEN>@!4861S8VAI:VES=&%N`%9E<F5I
M;FEG=&4@4F5P=6)L:6L@5&%N<V%N:6$`6FEE;#H`075F9V%B96X`5&5L969O
M;FYU;6UE<@!496UP97)A='5R(&1E<B!L971Z=&5N(%-T=6YD93H@`%1E;7!E
M<F%T=7(`5&5M<&5R871U<CH@`%1E;7!E<F%T=7(\8G(@+SXH)7--87@E<R\E
M<TUI;B5S*2`F9&5G.R5S`%9O<FQA9V4@(B5S(B!N:6-H="!G969U;F1E;BX`
M5F]R;&%G96YV97)W86QT=6YG`%5N=&5R(%9O<F)E:&%L=`!497AT`$YU<B!4
M97AT`$%U<W)I8VAT=6YG`%1E>'0@3V)E;@!$;P!4:&%I;.1N9&ES8V@@*%1)
M4RTV,C`I`%1H86EL86YD`$1I92!496EL;F5H;65R86YS:6-H="!I<W0@;FEC
M:'0@;65H<B!G96QA9&5N+B!!8F)R=6-H+@!$:64@1E10+45X=&5N<VEO;B!I
M<W0@;FEC:'0@=F5R9OQG8F%R+@!$:64@0VAR;VYI:R!S=&5H="!N:6-H="!Z
M=7(@5F5R9OQG=6YG+@!$:64@2&]R9&4O2V]L86(@26YT96=R871I;VYS9G5N
M:W1I;VYE;B!U;G1E<G-T_'1Z96X@(B5S(B!N:6-H=`!$:64@24U34"U,;V=D
M871E:2!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N+@!$:64@36%I;G1E
M;F%N8V4Z.B!+;&%S<V4@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R9&5N`$1A
M<R!%:6YS=&5L;'5N9V5N+49E;G-T97(@:7-T(&=E<V-H;&]S<V5N('=O<F1E
M;BX@06)B<G5C:"X`1&5R($%D;6EN:7-T<F%T;W(@;75S<R!E:6X@<&5R;6%N
M96YT97,@4F5C:'1E+4)A8VME;F0@96EN<FEC:'1E;BP@=V5N;B!3:64@9&EE
M(%)E8VAT979E<G=A;'1U;F<@;G5T>F5N(&WV8VAT96XN`$YU<B!U;G1E;@!$
M97(@2V%L96YD97(@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M+@!$97(@2V%L96YD97(@(B5S(B!W=7)D92!E<GIE=6=T+@!$97(@2V%L96YD
M97(@(B5S(B!W=7)D92!G96SV<V-H="X`1&5R($MA;&5N9&5R("(E<R(@=W5R
M9&4@;F%C:"`B)7,B('5M8F5N86YN="X`1&5R($MA;&5N9&5R("(E<R(@=W5R
M9&4@9V5S<&5I8VAE<G0N`$1E<B!+86QE;F1E<B!K;VYN=&4@;FEC:'0@9V5L
M965R="!W97)D96XZ("5S`$1I92!)1"U.=6UM97(@9&5S($MO;G1A:W1S('=U
M<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D97(@:V]N;G1E(&EN(&1E
M<B!$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@=V5R9&5N+@!$97(@2V]N=&%K
M="!W=7)D92!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B=6-H(&AI;GIU9V5F
M_&=T+@!$97(@4$=0+5-I9VYA='5R8FQO8VL@=VER9"!B96[V=&EG="P@=6T@
M9&EE('5N=&5R>F5I8VAN971E($YA8VAR:6-H="!Z=2#\8F5R<'+\9F5N+@!$
M:64@240M3G5M;65R(&1E<B!697)T96EL97)L:7-T92!W=7)D92!N:6-H="!A
M;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92!I;B!D97(@1&%T96YB86YK
M(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`1&EE(%9E<G1E:6QE<FQI<W1E('=U
M<F1E(&YI8VAT(&%N9V5G96)E;BX`1&EE(%9E<G-C:&S\<W-E;'5N9W-F=6YK
M=&EO;F5N(&)E;O9T:6=E;B!E:6YE('-I8VAE<F4@4V5R=F5R=F5R8FEN9'5N
M9RX`1&%S($5N9&1A='5M(&UU<W,@:&EN=&5R(&1E;2!3=&%R=&1A='5M(&QI
M96=E;BX`1&5R(%1E<FUI;B`B)7,B+"!D97(@86T@)3,D<R!U;2`E-"1S(%5H
M<B!S=&%T=&9I;F1E="P@=W5R9&4@>G5M($MA;&5N9&5R("(E,B1S(B!H:6YZ
M=6=E9OQG="X`1&5R(%1E<FUI;B`B)7,B+"!D97(@86T@)3,D<R!U;2`E-"1S
M(%5H<B!S=&%T=&9I;F1E;B!S;VQL=&4L('=U<F1E(&%U<R!D96T@2V%L96YD
M97(@(B4R)',B(&=E;/9S8VAT+@!$97(@5&5R;6EN("(E<R(L(&1E<B!A;2`E
M,R1S('5M("4T)',@56AR('-T871T9FEN9&5T+"!W=7)D92!I;2!+86QE;F1E
M<B`B)3(D<R(@9V7D;F1E<G0N`$EH<F4@5&5R;6EN8F5N86-H<FEC:'1I9W5N
M9R!A;B`E<R!W=7)D92!E<F9O;&=R96EC:"!V97)S96YD970N`$1I92!$871E
M:2`E<R!S;VQL=&4@96EN96X@)7,@16EN=')A9R!E;G1H86QT96XN`$1I92!$
M871E:2`E<R!S;VQL=&4@96EN:6=E("5S($5I;G1RY&=E(&5N=&AA;'1E;BX`
M1&EE($1A=&5I(&MA;FX@;FEC:'0@875F('-I8V@@<V5L8G-T(&MO<&EE<G0@
M=V5R9&5N+@!$:64@1&%T96D@96YT:&EE;'0@:V5I;F4@1&%T96XN`$AI97(@
M<VEN9"!D:64@2V]P9F5I;G1RY&=E(&;\<B!D:65S92!M97-S86=E+W)F8S@R
M,B!.86-H<FEC:'0N`$AI97(@:7-T(&5I;F4@9&5T86EL;&EE<G1E<F4@0F5S
M8VAR96EB=6YG(&1E<R!497)M:6YS.@!$97(@5F]L;&)I;&1M;V1U<R!V97)U
M<G-A8VAT(&%U9B!'<G5N9"!V;VX@1F5H;&5R;B!I;2!);G1E<FYE="!%>'!L
M;W)E<B!B96MA;FYT97)M8=]E;B!0<F]B;&5M92!M:70@9&EE<V5M($)R;W=S
M97(L(&1I92!W:7(@;FEC:'0@=6UG96AE;B!K]FYN96XN(%5N=&5R(%5M<W3D
M;F1E;B!E<FAA;'1E;B!3:64@96EN92!F96AL97)H869T92!!;GIE:6=E+"!F
M96AL96X@161I=&]R9G5N:W1I;VYE;BP@;V1E<B!D97(@0G)O=W-E<B!S=/QR
M>G0@86(N($%U9B!E:6YE;2!7:6YD;W<@.7@@4WES=&5M('=E<F1E;B!3:64@
M=F5R;75T;&EC:"!E:6YE("=!;&QG96UE:6YE(%-C:'5T>G9E<FQE='IU;F<G
M(&5R:&%L=&5N('5N9"!M_'-S96X@9&5N(%)E8VAN97(@;F5U('-T87)T96XN
M7&Y<;E-I92!W=7)D96X@9V5W87)N="X@0FET=&4@9'+\8VME;B!3:64@875F
M($]++"!W96YN(%-I92!N;V-H(&EM;65R(&1E;B!6;VQL8FEL9&UO9'5S('9E
M<G=E;F1E;B!M]F-H=&5N+@!$:64@261E;G1I=.1T("(E<R(@=W5R9&4@9V5L
M]G-C:'0N`$YU<B!L:6YK<P!$97(@3W)T(&1E<R!';G501RU0<F]G<F%M;7,@
M;75S<R!D97(@0W)Y<'1?<&=P.CH@2VQA<W-E(/QB97)G96)E;B!W97)D96XN
M`$1I92!.86-H<FEC:'0@;6ET(&1E;2!"971R969F("(E,R1S(BP@9&EE(&%M
M("4Q)',@86X@)3(D<R!G97-C:&EC:W0@=W5R9&4L(&ES="!A;F=E>F5I9W0@
M=V]R9&5N+@I$87,@:&5IWW0@;FEC:'0L(&1A<W,@9&EE($YA8VAR:6-H="!A
M=6-H(&=E;&5S96X@;V1E<B!V97)S=&%N9&5N('=U<F1E+@!.86UE(&;\<B!D
M96X@3&EN:R!Z=7(@3F%C:')I8VAT96YE<G-T96QL=6YG`$1I92!!;GIA:&P@
M9&5R($9E;&1E<B!M=7-S(&%L<R!:86AL(&%N9V5G96)E;B!W97)D96XN`$1A
M<R!/<&5N4U-,+4UO9'5L('=I<F0@9OQR(&1I92!(;W)D95]#<GEP=%]S;6EM
M93HZ($ML87-S92!B96[V=&EG="X`1&EE($)E;G5T>F5R96EN<W1E;&QU;F<@
M(B5S(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+"!W96EL(&EH
M<F4@1&%T96X@9&EE(&UA>&EM86P@97)L875B=&4@1W+VWV4@_&)E<G-C:')E
M:71E;@!$87,@4')O9W)A;6T@9OQR(&1I92!!;GIE:6=E(&1I97-E<R!$871E
M:71Y<',@*"5S*2!W=7)D92!N:6-H="!G969U;F1E;BX`1&%S($%N9OQH<G5N
M9W-Z96EC:&5N(&UU<W,@86QS(&5I;GIE;&YE<R!:96EC:&5N(&%N9V5G96)E
M;B!W97)D96XN`$1I92!!;F9R86=E('=A<B!U;G9O;&QS=.1N9&EG+B!%:6YI
M9V4@9&5R(%!A<F%M971E<BP@9&EE(&YO='=E;F1I9R!S:6YD+"!U;2!E:6YE
M;B!497)M:6X@>G4@8F5S=.1T:6=E;B!O9&5R(&%B>G5S86=E;BP@9F5H;&5N
M+@!.=7(@;&EN:W,@=6YD(')E8VAT<P!.=7(@<F5C:'1S`$1A<R!4<F5N;GIE
M:6-H96X@;75S<R!A;',@96EN>F5L;F5S(%IE:6-H96X@86YG96=E8F5N('=E
M<F1E;BX`1&5R(%-E<G9E<B`B)7,B('=U<F1E(&5N=&9E<FYT+@!$97(@4V5R
M=F5R("(E<R(@=W5R9&4@9V5S<&5I8VAE<G0N`$1I92!296=I<W1R:65R=6YG
M<V%N9G)A9V4@=F]N("5S('=U<F1E(&5N=&9E<FYT+@!$:64@86YG96=E8F5N
M92!:96EL92`H)60I(&5X:7-T:65R="!N:6-H="X`1&EE('1E;7!O<N1R92!$
M871E:2`B)7,B(&5X:7-T:65R="!N:6-H="X`1&5R(%1E>'0L(&1E;B!3:64@
M86YG96=E8F5N(&AA8F5N+"!E;G1S<')I8VAT(&YI8VAT(&1E;2!497AT(&%U
M9B!D96T@0FEL9'-C:&ER;2X`3G5R(&]B96X@=6YD('5N=&5N`$YU<B!O8F5N
M`$1I92!H;V-H9V5L861E;F5N($1A=&5N('-I;F0@;F%C:"!D96T@;&5T>G1E
M;B!38VAR:71T('9E<FQO<F5N(&=E9V%N9V5N+@!$:64@:&]C:&=E;&%D96YE
M($1A=&5I(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN`$1E<B!W
M96%T:&5R+F-O;2!";&]C:R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!4:&5M96XM
M5F5R>F5I8VAN:7,@(B5S(B!N:6-H="!G969U;F1E;BX`17,@=W5R9&5N(&ME
M:6YE('!A<W-E;F1E;B!497)M:6YE(&=E9G5N9&5N+@!%<R!S:6YD(&ME:6YE
M($5I;G-T96QL=6YG96X@=F5R9OQG8F%R+@!%<R!G:6)T(&ME:6YE(&%N>F5I
M9V)A<F5N($YA8VAR:6-H=&5N=&5I;&4N`$1I97-E<R!&96QD(&5N=&CD;'0@
M>G4@=FEE;&4@6F5I8VAE;BX@4VEE(&AA8F5N("5S(%IE:6-H96X@86YG96=E
M8F5N.R!3:64@;?QS<V5N('=E;FEG97(@86QS("5S(&%N9V5B96XN`$)E:6T@
M2&EN>G5F_&=E;B!V;VX@(B5S(B!Z=6T@4WES=&5M(&ES="!E:6X@4')O8FQE
M;2!A=69G971R971E;CH@)7,`0F5I;2!,]G-C:&5N(&1E<B!$871E;B!V;VX@
M0F5N=71Z97(@(B5S(B!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ(`!"
M96EM($SV<V-H96X@=F]N("(E<R(@875S(&1E;2!3>7-T96T@:7-T(&5I;B!0
M<F]B;&5M(&%U9F=E=')E=&5N.B``0F5I;2!!:W1U86QI<VEE<F5N('9O;B`B
M)7,B(&ES="!E:6X@4')O8FQE;2!A=69G971R971E;CH@)7,`0F5I;2!(;V-H
M;&%D96X@9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E
M<R!W=7)D92!N:6-H="!H;V-H9V5L861E;BX`0F5I;2!(;V-H;&%D96X@9&5R
M($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W87(@9W+V
MWV5R(&%L<R!D:64@;6%X:6UA;"!E<FQA=6)T92!'<O;?92`H)60@0GET97,I
M+@!"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&96AL97(@875F
M9V5T<F5T96XN("5S('=U<F1E(&YU<B!T96EL=V5I<V4@:&]C:&=E;&%D96XN
M`$)E:6T@6G5G<FEF9B!A=68@9&5N($MA;&5N9&5R(&ES="!E:6X@1F5H;&5R
M(&%U9F=E=')E=&5N.B`E<RX`0F5I;2!(:6YZ=6;\9V5N(&1E<R!497)M:6YS
M(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N.B`E<RX`0F5I;2!!;GIE:6=E
M;B!D:65S97,@3F%C:')I8VAT96YT96EL<R!I<W0@96EN($9E:&QE<B!A=69G
M971R971E;BX`0F5I;2!"96%R8F5I=&5N(&1E<R!497)M:6YS(&ES="!E:6X@
M1F5H;&5R(&%U9F=E=')E=&5N.B`E<RX`0F5I;2!);7!O<G1I97)E;B!D97(@
M2V]N=&%K=&1A=&5N(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+@!"96EM
M($EM<&]R=&EE<F5N(&1E<B!I0V%L96YD87(@1&%T96X@:7-T(&5I;B!&96AL
M97(@875F9V5T<F5T96XN`$1A<R!+;VYF:6=U<F%T:6]N<RU&;W)M=6QA<B!E
M;G1H:65L="!E:6YE;B!&96AL97(N(%9I96QL96EC:'0@:&%B96X@4VEE(&5I
M;B!09FQI8VAT9F5L9"!L965R(&=E;&%S<V5N+@!"96EM(%9E<G-C:&EE8F5N
M(&1E<R!497)M:6YS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N.B`E<RX`
M0F5I;2!!=7-F_&AR96X@9&5R(&%N9V5G96)E;F5N($%D<F5S<V)U8VAF=6YK
M=&EO;B!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET=&4@=F5R<W5C
M:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`$)E:6T@5F5R<V-H:6-K
M96X@96EN97(@5&5R;6EN8F5N86-H<FEC:'1I9W5N9R!A;B`E<R!I<W0@96EN
M($9E:&QE<B!A=69G971R971E;CH@)7,`0F5I(&1E<B!!:W1U86QI<VEE<G5N
M9R!D97(@2V]N=&%K=&1E=&%I;',@:7-T(&5I;B!&96AL97(@875F9V5T<F5T
M96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L
M+@!"96D@9&5R($%K='5A;&ES:65R=6YG(&1E<B!697)T96EL97)L:7-T92!I
M<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET=&4@=F5R<W5C:&5N(%-I
M92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`$5S(&MO;FYT96X@:V5I;F4@5&5R
M;6EN92!Z=6T@17AP;W)T:65R96X@9V5F=6YD96X@=V5R9&5N+@!$:65S97(@
M24U!4"U397)V97(@=6YT97)S=/QT>G0@:V5I;F4@9V5M96EN<V%M96X@3W)D
M;F5R+@!$:65S('-C:&5I;G0@:V5I;B!G_&QT:6=E<R!205(M07)C:&EV('IU
M('-E:6XN`$1I97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%I)4"U!<F-H:78@
M>G4@<V5I;BX`1&EE<R!S8VAE:6YT(&ME:6YE(&?\;'1I9V4@2V%R=&5N;G5M
M;65R('IU('-E:6XN`$1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C
M:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D96X@0VQI8VMA=&5L;"U'
M871E=V%Y("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&UI="!(:6QF92!D97(@
M2%144"U!4$DN`$1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC
M:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D96X@5TE.+4=A=&5W87D@*&AT
M='`Z+R]W:6YP;&,N8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)+@!$:65S
M97(@5')E:6)E<B!E<FQA=6)T(&1A<R!697)S8VAI8VME;B!V;VX@3F%C:')I
M8VAT96X@9'5R8V@@9&5N('-M<S)M86EL+4=A=&5W87D@*&AT='`Z+R]S;7,R
M;6%I;"YC;VTI(&UI="!(:6QF92!D97(@2%144"U!4$DN`$1I97-E<B!4<F5I
M8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!P
M97(@4TU44"!D=7)C:"!D96X@5F]D869O;F4M271A;&EE;BU'871E=V%Y(&%U
M<W-C:&QI9=]L:6-H(&%N(%9O9&%F;VYE+4YU;6UE<FXN($1A9OQR('=I<F0@
M96EN($5M86EL:V]N=&\@8F5I(%9O9&%F;VYE($ET86QI96X@*&AT='`Z+R]W
M=W<N,3DP+FET*2!B96[V=&EG="X`1&EE<V5S($9E;&0@:7-T(&YO='=E;F1I
M9RX`1&EE<V5S($9E;&0@9&%R9B!N=7(@9V%N>F4@6F%H;&5N(&5N=&AA;'1E
M;BX`1&EE<V5S($9E;&0@9&%R9B!N=7(@6F%H;&5N('5N9"!E:6YE;B!0=6YK
M="!E;G1H86QT96XN`$1I97-E<R!&96QD(&1A<F8@;G5R($]K=&%L>F%H;&5N
M(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@;75S<R!E:6YE(&MO;6UA+2!O9&5R
M(&QE97)Z96EC:&5N9V5T<F5N;G1E($QI<W1E('9O;B!G86YZ96X@6F%H;&5N
M(&5N=&AA;'1E;@!$:65S97,@1F5L9"!M=7-S(&5I;F4@9_QL=&EG92!:86AL
M(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@;75S<R!E:6YE;B!&87)B=V5R="!I
M;2!H97AA9&5Z:6UA;&5N(%)'0BU&;W)M870@96YT:&%L=&5N+"!Z+B!"+B`G
M(S$R,S1A9B<N`$1I97-E<R!$871E:69O<FUA="!W:7)D(&YI8VAT('5N=&5R
M<W3\='IT+@!$:65S97,@1F]R;75L87(@=W5R9&4@8F5R96ET<R!V97)A<F)E
M:71E="X`1&EE<R!I<W0@)7,N`$1I92!I<W0@96EN($MO;&%B+4=R;W5P=V%R
M92U/8FIE:W0N(%5M(&1I97-E<R!/8FIE:W0@86YZ=7IE:6=E;BP@8F5N]G1I
M9V5N(%-I92!E:6X@16UA:6QP<F]G<F%M;2P@9&%S(&1A<R!+;VQA8BU'<F]U
M<'=A<F4M1F]R;6%T('5N=&5R<W3\='IT+B!%:6YE($QI<W1E('-O;&-H97(@
M4')O9W)A;6UE(&9I;F1E;B!3:64@=6YT97(@)7,`365L9'5N9R!D97,@4V5R
M=F5R<SH@)7,`1&EE<V4@3F%C:')I8VAT('=U<F1E(&EN(&5I;F5M(%IE:6-H
M96YS871Z("@E<RD@97)S=&5L;'0L(&1E<B!N:6-H="!):')E;2!E:6=E;F5N
M(&5N='-P<FEC:'0N`$1I97-E(%IA:&P@;75S<R`Q(&]D97(@9W+VWV5R('-E
M:6XN`$1I97-E<B!397)V97(@:V%N;B!:25`M('5N9"!'6DE0+41A=&5I;B!N
M:6-H="!E;G1P86-K96XN`$1I97-E<R!3>7-T96T@:7-T('IU<B!:96ET(&1E
M86MT:79I97)T+@!$:65S97(@5V5R="!M=7-S(&5I;F4@6F%H;"!S96EN+@!$
M:65S97,@1F5N<W1E<B!M=7-S('9O;B!E:6YE;2!%:6YS=&5L;'5N9V5N+49E
M;G-T97(@9V7V9F9N970@=V5R9&5N`$1O;FYE<@!$;VYN97)S=&%G`%1I8VME
M=',`6F5I=`!:96ET<U]P86YN90!:96ET97)F87-S=6YG`%IE:71F;W)M870`
M6F5I=&%U<W=A:&P`6F5I='-P86YN90!4:6UO<BU,97-T90!4:71E7VP`5&ET
M96P`5&ET96P@*%1O;VQT:7`I.@!!;@!(86QT96X@4VEE(&)E:6T@2VQI8VME
M;B!3=')G(&)Z=RX@*%!#*2!#;VUM86YD("A-86,I(&=E9'+\8VMT+"!U;2!M
M96AR97)E($5I;G1RY&=E(&%U<WIU=^1H;&5N+@!(975T90!:=2!(5$U,+5%U
M96QL8V]D92!U;7-C:&%L=&5N`%1O9V\`5&]K96QA=0!-;W)G96X`5&]N9V$`
M6G4@=FEE;&4@=6YG_&QT:6=E($%N;65L9&5V97)S=6-H92!I;B!D96X@;&5T
M>G1E;B!-:6YU=&5N+@!/8F5N`,1UWV5R<W1E<B!286AM96X@*%]T;W`I`-QB
M97)S971Z=6YG96X`5')I;FED860@=6YD(%1O8F%G;P!786AR(&]D97(@9F%L
M<V-H`$1I`$1I96YS=&%G`%1U;F5S:65N`%3\<FME:0!4_')K:7-C:"`H25-/
M+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS+2!U;F0@0V%I8V]S:6YS96QN
M`%1U=F%L=0!4>7``26AR92!!=7-W86AL.B``558M26YD97@Z(`!(;VUE<&%G
M90!54DP@26AR97,@4VMR:7!T<R!F_'(@9&5N(%9E<G-A;F1S=&%T=7-B97)I
M8VAT`$%D<F5S<V4Z`%5G86YD80!5:W)A:6YE`$%U9B!D87,@5D93+59E<GIE
M:6-H;FES(&MO;FYT92!N:6-H="!Z=6=E9W)I9F9E;B!W97)D96XN`$1I92!Z
M=7/D='IL:6-H96X@0F5N=71Z97)I;F9O<FUA=&EO;F5N(&MO;FYT96X@8F5I
M(&1E<B!296=I<W1R:65R=6YG(&YI8VAT(&AI;GIU9OQG="!W97)D96XN`$1I
M92!:=6=R:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`B)7,B(&MO;FYT
M96X@;FEC:'0@9V7D;F1E<G0@=V5R9&5N+@!$:64@6G5G<FEF9G-R96-H=&4@
M9OQR(&1I92!61E,M1&%T96D@)7,O)7,@:V]N;G1E;B!N:6-H="!G9>1N9&5R
M="!W97)D96XN`$5S(&MA;FX@;FEC:'0@:6X@5F5R>F5I8VAN:7,@)7,@9V5W
M96-H<V5L="!W97)D96XN`$1I92!'<O;?92!V;VX@(B5S(B!K;VYN=&4@;FEC
M:'0@8F5S=&EM;70@=V5R9&5N+@!$:64@1W+VWV4@=F]N("(E<R\E<R(@:V]N
M;G1E(&YI8VAT(&)E<W1I;6UT('=E<F1E;BX`5F5R8FEN9'5N9R!Z=6T@4U%,
M(%-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;BX`4U-,+59E
M<F)I;F1U;F<@:V]N;G1E(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;BX`1&EE
M(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@:V]P:65R="!W97)D96XN`$1A<R!6
M1E,M5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R
M9&5N+@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!A;F=E;&5G
M="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&%N9V5L96=T
M('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H
M="!A;F=E;&5G="!W97)D96XN`$QE97)E(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@86YG96QE9W0@=V5R9&5N+@!$:64@1&%T96X@:V]N;G1E;B!N:6-H="!D
M96MO;7!R:6UI97)T('=E<F1E;BX`(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C
M:'0@=V5R9&5N+"!D87,@5F5R>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(N`"(E
M<R(@:V%N;B!N:6-H="!G96SV<V-H="!W97)D96XZ("5S`"(E<R(@:V%N;B!N
M:6-H="!G96SV<V-H="!W97)D96XZ("5S+@`E<R!K;VYN=&4@;FEC:'0@9V5L
M]G-C:'0@=V5R9&5N+"!D87,@5F5R>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(`
M1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@<F5K=7)S:78@9V5L
M]G-C:'0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H
M="!G96SV<V-H="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E
M(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N`$1I92!61E,M1&%T96D@(B5S
M(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!$:64@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1A<R!61E,M5F5R>F5I
M8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!$87,@
M5D93(&MO;FYT92!N:6-H="!R96MU<G-I=B!G96SV<V-H="!W97)D96XZ("5S
M+@!$87,@86MT=65L;&4@5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&)E<W1I
M;6UT('=E<F1E;BX`1&EE(%IE<G1I9FEK871D971A:6QS(&MO;FYT96X@;FEC
M:'0@875S9V5L97-E;B!W97)D96X`1&5R("5S+51R96EB97(@:V]N;G1E(&YI
M8VAT(&=E;&%D96X@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H
M="!V97)S8VAO8F5N('=E<F1E;BX`1&EE(%9&4RU$871E:2`B)7,B(&MO;FYT
M92!N:6-H="!G9?9F9FYE="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E
M(&YI8VAT('IU;2!"97-C:')E:6)E;B!G9?9F9FYE="!W97)D96XN`$1I92!6
M1E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX`1&%S($%R
M8VAI=B!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!$:64@5D93+41A
M=&5I(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;B`H9FEL97-I>F4H*2!F
M96AL9V5S8VAL86=E;BDN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E
M;&5S96X@=V5R9&5N("AG971&:6QE4VEZ92@I(&9E:&QG97-C:&QA9V5N*2X`
M1&EE($1A=&5I(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;CH@`$1A<R!V
M9G-R;V]T+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E
M;BX`(B5S(B!K86YN(&YI8VAT('5M8F5N86YN="!W97)D96XZ("5S`"5S(&MO
M;FYT92!N:6-H="!N86-H("5S('5M8F5N86YN="!W97)D96XZ($1A<R!::65L
M=F5R>F5I8VAN:7,@97AI<W1I97)T(&)E<F5I=',`1&%S(%9&4RU697)Z96EC
M:&YI<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&%S(%9&4RU6
M97)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;CH@)7,N
M`$1I92!61E,M1&%T96D@(B5S(B!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E
M<F1E;BX`1&EE(%9&4RU$871E:2`E<R\E<R!K;VYN=&4@;FEC:'0@=6UB96YA
M;FYT('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@=6UB96YA
M;FYT('=E<F1E;BX`1F5H;&5R(&)E:6T@075S;&5S96X@9&5R($9R96DO1V5B
M=6-H="U);F9O<FUA=&EO;F5N(&;\<B`E<P`B;6MI<V]F<R(@:V]N;G1E(&YI
M8VAT(&%U<V=E9OQH<G0@=V5R9&5N+@!$:65S97,@5V]R9"U$;VMU;65N="!L
MY'-S="!S:6-H(&YI8VAT(&%N>F5I9V5N`$1I92!61E,M1&%T96D@(B5S(B!K
M;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$:64@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!G97-C:')I96)E;B!W97)D96X@*&-O<'DH*2!F96AL
M9V5S8VAL86=E;BDN`$1I92!61E,M1&%T96X@:V]N;G1E;B!N:6-H="!G97-C
M:')I96)E;B!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E
M<V-H<FEE8F5N('=E<F1E;BP@9&%S(%-P96EC:&5R<&QA='HM2V]N=&EN9V5N
M="!W_')D92#\8F5R<V-H<FET=&5N+@!5;G1E<G-T<FEC:&5N`,1N9&5R=6YG
M96X@<OQC:V?D;F=I9R!M86-H96X`36%C:'0@9&EE(&QE='IT92!!:W1I;VX@
M<OQC:V?D;F=I9P!5;F?\;'1I9V4@4OQC:VUE;&1U;F<@=F]M(%-E<G9E<B!B
M96EM($AE<G-T96QL96X@9&5R(%9E<F)I;F1U;F<Z(`!5;F5R=V%R=&5T92!!
M;G1W;W)T(&1E<R!397)V97)S(&%U9CH@`$YI8VAT('IU9V5O<F1N970`56YI
M8V]D92`H551&+3@I`%9E<F5I;FEG=&4@07)A8FES8VAE($5M:7)A=&4`5F5R
M96EN:6=T97,@2_9N:6=R96EC:`!697)E:6YI9W1E(%-T86%T96X`2VQE:6YE
M<F4@06UE<FEK86YI<V-H92#<8F5R<V5E:6YS96QN`$5I;FAE:71E;@!5;F)E
M:V%N;G0`56YB96MA;FYT92!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;F)E:V%N;G1E(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$5S('=U
M<F1E(&5I;B!U;F)E:V%N;G1E<B!/<G0@86YG96=E8F5N+@!5;F)E:V%N;G1E
M<B!"96YU='IE<FYA;64@;V1E<B!087-S=V]R="X`3&EN:R!V;VT@86MT=65L
M;&5N($5L96UE;G0@96YT9F5R;F5N`%5N8F5N86YN=`!!=7,@4VEC:&5R:&5I
M='-G<OQN9&5N(&3\<F9E;B!U;F%U=&]R:7-I97)T92!3:W)I<'1E(&YI8VAT
M(&%U<V-H;F5I9&5N+"!K;W!I97)E;B!U;F0@96EN9OQG96XN($ML:6-K96X@
M4VEE(&%U9B!/2RP@=6T@96EN96X@2&EN=V5I<R!A=68@;6]Z:6QL82YO<F<@
M86YG97IE:6=T('IU(&)E:V]M;65N+"!D97(@8F5S8VAR96EB="P@=VEE(%-I
M92!E:6YE;2!3:W)I<'0@9&5N(%IU9W)I9F8@875F(&1I92!:=VES8VAE;F%B
M;&%G92!E<FQA=6)E;B!K]FYN96XN`$9A<F)E('IU<OQC:W-E='IE;@!.:6-H
M="!U;G1E<G-T_'1Z=&5R($EN:&%L='-T>7`Z("5S`$5R=V5I=&5R=6YG(&YI
M8VAT('5N=&5R<W3\='IT`$%K='5A;&ES:65R=6YG`"5S(&%K='5A;&ES:65R
M96X`0F5N=71Z97(@86MT=6%L:7-I97)E;@`B)7,B('=U<F1E(&%K='5A;&ES
M:65R="X`06MT=6%L:7-I97)T.B`E<RX`06MT=6%L:7-I97)U;F=S<VMR:7!T
M(&=E;/9S8VAT+@!(;V-H;&%D96X`1&EE($MO;F9I9W5R871I;VYS9&%T96EE
M;B!A;&QE<B!!;G=E;F1U;F=E;B!W=7)D96X@875F(&1E;B!397)V97(@:&]C
M:&=E;&%D96XN`$=R+B!L871E:6YI<V-H92!"=6-H<W1A8F5N`$=R+B!R]FUI
M<V-H92!:86AL96X`57)U9W5A>0!!:W1U96QL92!B96YU='IE;CH@)7,`4U-,
M(&)E;G5T>F5N`$)I='1E(&%U<V;\;&QE;BP@=V5N;B!3:64@96EN96X@86YD
M97)E;B!"96YU='IE<FYA;65N+U!A<W-W;W)T(&;\<B!D96X@24U34"U397)V
M97(@:&%B96XN`$)E;G5T>F5R`$)E;G5T>F5R("5S(&ES="!F_'(@)7,@;FEC
M:'0@875T;W)I<VEE<G0N`$)E;G5T>F5R=F5R=V%L='5N9P!"96YU='IE<F]B
M97)F;.1C:&4`0F5N=71Z97)E:6YS=&5L;'5N9V5N`$)E;G5T>F5R<F5G:7-T
M<FEE<G5N9P!$:64@0F5N=71Z97)R96=I<W1R:65R=6YG('=U<F1E(&%U9B!D
M:65S96T@4WES=&5M(&1E86MT:79I97)T+@!"96YU='IE<FMO;G1O(&YI8VAT
M(&=E9G5N9&5N`$)E;G5T>F5R;F%M90!$97(@0F5N=71Z97)N86UE("(E<R(@
M97AI<W1I97)T(&)E<F5I=',N`$)E;G5T>F5R;F%M93H`0F5N=71Z97)N86UE
M.B``0F5N=71Z97(@9&5S(%-Y<W1E;7,Z`%5S8F5K:7-T86X`1&%S(%9&4RU6
M97)Z96EC:&YI<R!E>&ES=&EE<G0@;FEC:'0N`$%B=V5S96YH96ET`%!A<W-E
M;F1E(&=E9G5N9&5N92!/<G1E.B``1_QL=&EG:V5I=`!797)T(&EN($UI;G5T
M96X@=F]N(&IE='IT(&%N+@!$97(@5V5R="!I<W0@_&)E<B!D97(@;6%X:6UA
M;&5N($SD;F=E('9O;B`E<RX`5V5R=&4`5V5R=&4L(&%U<R!D96YE;B!A=7-G
M97?D:&QT('=E<F1E;B!K86YN`%9A;G5A='4`1')E:&5N9`!696YE>G5E;&$`
MW&)E<G!R_&9U;F<@9F5H;&=E<V-H;&%G96X@+2!D:65S92!.86-H<FEC:'0@
M:_9N;G1E(&UA;FEP=6QI97)T('=O<F1E;B!S96EN+@!697)S:6]N`%9E<G-I
M;VYS:V]N=')O;&QE`$%U<W)I8VAT=6YG`%9E<G1I:V%L97(@26YN96YA8G-T
M86YD`%9E<G1I:V%L.@!396AR($AO8V@`5FEE=&YA;0!6:65T;F%M97-I<V-H
M("A625-#24DI`"5S(&%N>F5I9V5N`%1A9R!A;GIE:6=E;@!%:6YE(&5X=&5R
M;F4@5V5B<V5I=&4@86YZ96EG96X`06YZ96EG96X@86QS("5S`$)R:71I<V-H
M92!*=6YG9F5R;FEN<V5L;@!!;65R:6MA;FES8VAE($IU;F=F97)N:6YS96QN
M`%-I8VAT`%-I8VAT.B``5F]D869O;F4@271A;&EE;B!P97(@4TU44`!705).
M54Y'`%=!4DY53D<A(2$@3-930TA%3B!3244@1$%3(%-+4DE05"!-04Y514Q,
M($%54R`E<RX`5TE.(/QB97(@2%144`!786QL:7,@=6YD($9U='5N80!787)N
M=6YG`$UI`%=E='1E<G9O<FAE<G-A9V4`5V5T=&5R9&%T96X@=F]N`%=E871H
M97(N8V]M`%=E8@!796)S:71E`$UI='1W;V-H`%=O8VAE`"5D+B!7;V-H90!7
M;V-H92AN*0!7]F-H96YT;&EC:`!7]F-H96YT;&EC:#H@5VEE9&5R:&]L=6YG
M(&%L;&4`5VEL;&MO;6UE;@!7:6QL:V]M;65N(&)E:2`E<P!7:6QL:V]M;65N
M+"`E<P!797-T975R;W#D:7-C:"`H25-/+3@X-3DM,2D`5V5S=&5U<F]PY&ES
M8V@@*$E33RTX.#4Y+3$U*0!797-T<V%H87)A`%=E;&-H92!!;G=E;F1U;F<@
M<V]L;"`E<R!N86-H(&1E;2!!;FUE;&1E;B!A;F=E>F5I9V5N/P!796QC:&5S
M(%1R96YN>F5I8VAE;B!W:7)D('9E<G=E;F1E=#\`5V5L8VAE($%N9OQH<G5N
M9W-Z96EC:&5N('=E<F1E;B!V97)W96YD970_`%=A;FX@<V]L;&5N(&1I92!4
M86=E<RT@=6YD(%=O8VAE;F%N<VEC:'1E;B!E;F1E;BP@=V5N;B!K96EN92!S
M<.1T97)E;B!497)M:6YE('9O<FQI96=E;C\`5V%N;B!S;VQL96X@9&EE(%1A
M9V5S+2!U;F0@5V]C:&5N86YS:6-H=&5N(&5N9&5N+"!W96YN(&ME:6YE(&9R
M_&AE<F5N(%1E<FUI;F4@=F]R;&EE9V5N/P!7:&5R96ES+4%U<W1R86QI82U+
M87)T90!796QC:&4@4&AA<V5N`%=E;&-H92!0;'5G:6YS(&;\<B!D96X@5UE3
M25=91RU%9&ET;W(@<V]L;&5N(&%K=&EV:65R="!W97)D96X_`$)R96ET90!"
M<F5I=&4@:6X@0U-3+45I;FAE:71E;@!"<F5I=&4@9&5S("5S+4UE;OQS(&QI
M;FMS("AW:7)K<V%M(&YA8V@@9&5R(&[D8VAS=&5N($%N;65L9'5N9RDZ`%1A
M8F5L;&5N8G)E:71E`$5I;FAE:70`0G)E:71E.@!7:6MI`%=I;F0`1G+\:"!7
M:6YD`%=I;F1G97-C:'=I;F1I9W1K96ET(&EN($MN;W1E;@!7:6YD.@!7:6YD
M.B``5V5I<VAE:70`5W5N<V-H>F5T=&5L`$%R8F5I=`!!9')E<W-E(&=E<V-H
MY&9T;&EC:`!496QE9F]N(&=E<V-HY&9T;&EC:`!!<F)E:71S=V]C:&4`1F%L
M<V-H92!!;GIA:&P@86X@1F5L9&5R;B!I;B!:96EL92`E9"X@)60@97)W87)T
M970L("5D(&=E9G5N9&5N+@!&86QS8VAE($%N>F%H;"!A;B!&96QD97)N+B`E
M9"!E<G=A<G1E="P@)60@9V5F=6YD96XN`%5N9_QL=&EG97(@3V9F<V5T("5D
M(&)E:6T@3&5S96X@9&5R(%9&4RU$871E:2X`475E<G9E<G=E:7-E`%@U,#EV
M,R!'96YE<F5L;&4@16EN<V-H<N1N:W5N9P!8-3`Y=C,@17)W96ET97)T97(@
M4V-H;/QS<V5L>G=E8VL`6#4P.78S($%L=&5R;F%T:79E<B!.86UE(&1E<R!:
M97)T:69I:V%T:6YH86)E<G,`6#4P.78S($ED96YT:73D="!D97,@6F5R=&EF
M:6MA='-C:&S\<W-E;',`6#4P.78S($5R=V5I=&5R=6YG96X`2DH`2DI*2@!9
M86AO;R$@2V%R=&4`2F%H<@!*Y&AR;&EC:`!*Y&AR;&EC:#H@5VEE9&5R:&]L
M=6YG(&%L;&4`2F5M96X`2F$`2F$L(&EC:"!S=&EM;64@>G4`4VEE(&)E9FEN
M9&5N('-I8V@@:6T@5&5X=&UO9'5S+B!"96YU='IE;B!3:64@9&5N(%L\/ET@
M2VYO<&8L('5M(&EN(&1E;B!765-)5TE'+4UO9'5S('IU('=E8VAS96QN+@!3
M:64@9/QR9F5N(&YI8VAT(&UE:'(@86QS("5D($)L]F-K92!E<G-T96QL96XN
M`%-I92!D_')F96X@;FEC:'0@;65H<B!A;',@)60@5&5R;6EN92!E<G-T96QL
M96XN`%-I92!S:6YD(&ME:6X@5&5I;&YE:&UE<B!D:65S97,@5&5R;6EN<RX`
M4VEE('-I;F0@;FEC:'0@86YG96UE;&1E="X`4VEE(&OV;FYE;B!D:65S97,@
M1F]R;75L87(@;G5R('9O;B!D97(@5&5I;&YE:&UE<F%N<VEC:'0@875S(&)E
M;G5T>F5N+@!3:64@9/QR9F5N(&1A<R!:96EC:&5N("=<)R!N:6-H="!I;B!)
M:')E;2!.86UE;B!V97)W96YD96XN`%-I92!H86)E;B!K96EN92!G_&QT:6=E
M($5M86EL861R97-S92!A;F=E9V5B96XN`%-I92!H86)E;B!K96EN92!&96QD
M97(@875S(&1E;B!I;7!O<G1I97)T96X@1&%T96X@9&5N(&5N='-P<F5C:&5N
M9&5N($9E;&1E<FX@:6X@)7,@>G5G96]R9&YE="X`4VEE(&AA8F5N(&EN($EH
M<F5N($5I;G-T96QL=6YG96X@=6YT97(@4&5R<_9N;&EC:&4@26YF;W)M871I
M;VYE;B!K96EN92!%;6%I;&%D<F5S<V4@86YG96=E8F5N+B!3:64@;?QS<V5N
M("5S:&EE<B5S(&5I;F4@061R97-S92!E:6YT<F%G96XL(&)E=F]R(%1E<FUI
M;F)E;F%C:')I8VAT:6=U;F=E;B!V97)S8VAI8VMT('=E<F1E;B!K]FYN96XN
M`%-I92!H86)E;B!N:6-H="!G96[\9V5N9"!296-H=&4L('5M(%1E<FUI;F4@
M>G4@)7,@:&EN>G5Z=6;\9V5N+@!3:64@:&%B96X@;FEC:'0@9V5N_&=E;F0@
M4F5C:'1E+"!U;2!497)M:6YE('IU(&1E;2!A=7-G97?D:&QT96X@2V%L96YD
M97(@:&EN>G5Z=6;\9V5N+@!3:64@:&%B96X@;FEC:'0@9V5N_&=E;F0@4F5C
M:'1E+"!U;2!D:65S96X@5&5R;6EN('IU(&SV<V-H96XN`%-I92!H86)E;B!N
M:6-H="!G96[\9V5N9"!296-H=&4L('5M(&1I97-E;B!497)M:6X@>G4@8F5A
M<F)E:71E;BX`4VEE('=U<F1E;B!A8F=E;65L9&5T+@!3:64@:&%B96X@96EN
M96X@=6YG_&QT:6=E;B!+86QE;F1E<B!A;F=E9V5B96XN`%-I92!H86)E;B!E
M<F9O;&=R96EC:"!D:64@5&5I;&YA:&UE(&%N(&1I97-E;2!%=F5N="!Z=6=E
M<V%G="X`4VEE(&AA8F5N(&5R9F]L9W)E:6-H(&1I92!496EL;F%H;64@86X@
M9&EE<V5M($5V96YT(&%B9V5S86=T+@!3:64@:&%B96X@=6YT97(@5F]R8F5H
M86QT(&1I92!496EL;F%H;64@86X@9&EE<V5M($5V96YT('IU9V5S86=T+@!3
M:64@;?QS<V5N(&5I;F4@9_QL=&EG92!-;V)I;'1E;&5F;VYN=6UM97(@86YG
M96)E;BP@;G5R(&%U<R!:86AL96X@=6YD(&=G9BX@96EN96T@(BLB(&;\<B!I
M;G1E<FYA=&EO;F%L92!6;W)W86AL96X@8F5S=&5H96YD+@!3:64@;?QS<V5N
M(&5I;F5N(&?\;'1I9V5N(%=E<G0@86YG96=E8F5N+@!3:64@;?QS<V5N(&5I
M;B!$871A5')E92U"86-K96YD(&MO;F9I9W5R:65R96XL('5M(%)E9VES=')I
M97)U;F=E;B!V97)W96YD96X@>G4@:_9N;F5N+@!3:64@;?QS<V5N(&5I;B!6
M1E,M0F%C:V5N9"!K;VYF:6=U<FEE<F5N+@!3:64@;?QS<V5N(&1A<R!0<F]B
M;&5M(&)E<V-H<F5I8F5N+"!U;2!D96X@0F5R:6-H="!A8GIU<V-H:6-K96XN
M`%-I92!M_'-S96X@9&EE(%523"!A;F=E8F5N+"!A=68@9&EE(&1I97-E<B!,
M:6YK('9E<G=E:7-E;B!S;VQL`%-I92!M_'-S96X@97)S="!D96X@>G4@;/9S
M8VAE;F1E;B!+86QE;F1E<B!A=7-WY&AL96XN`%-I92!M_'-S96X@97)S="!E
M:6YE($%D<F5S<V4@875S=^1H;&5N+@!3:64@;?QS<V5N(&5R<W0@9&5N('IU
M(&5N=&9E<FYE;F1E;B!397)V97(@875S=^1H;&5N+@!3:64@;?QS<V5N(&5I
M;F5N($)E;G5T>F5R;F%M96X@86YG96)E;BP@9&5S<V5N($1A=&5N(&=E;/9S
M8VAT('=E<F1E;B!S;VQL96XN`%-I92!M_'-S96X@96EN96X@>G4@;/9S8VAE
M;F1E;B!"96YU='IE<FYA;65N(&%N9V5B96XN`%-I92!M_'-S96X@96EN96X@
M:&EN>G5Z=6;\9V5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BX`4VEE(&W\
M<W-E;B!D96X@>G4@86MT=6%L:7-I97)E;F1E;B!"96YU='IE<FYA;65N(&%N
M9V5B96XN`%-I92!M_'-S96X@96EN92!!:W1I;VX@86YG96)E;BX`4VEE(&W\
M<W-E;B!E:6YE;B!N975E;B!+871E9V]R:65N86UE;B!A;F=E8F5N+@!3:64@
M;?QS<V5N(&5I;F4@271A;&EE;FES8VAE(%1E;&5F;VYN=6UM97(@86YG96)E
M;@!3:64@;?QS<V5N(&5R<W0@96EN96X@2V%L96YD97(@875S=^1H;&5N`%-I
M92!W;VQL=&5N(&)E;F%C:')I8VAT:6=T('=E<F1E;BP@=V5N;B!497)M:6YE
M('IU($EH<F5N($MA;&5N9&5R;B!H:6YZ=6=E9OQG="!W97)D96XN`%-I92!W
M;VQL=&5N(&)E;F%C:')I8VAT:6=T('=E<F1E;BP@=V5N;B!497)M:6YE(&%U
M<R!):')E;B!+86QE;F1E<FX@9V5L]G-C:'0@=V5R9&5N+@!3:64@=V]L;'1E
M;B!B96YA8VAR:6-H=&EG="!W97)D96XL('=E;FX@5&5R;6EN92!I;B!):')E
M;B!+86QE;F1E<FX@9V7D;F1E<G0@=V5R9&5N+@!3:64@=V]L;'1E;B#\8F5R
M("5S(&)E;F%C:')I8VAT:6=T('=E<F1E;BP@9&%S(&%M("5S('5M("5S('-T
M871T9FEN9&5T+@!):')E("5S+5-E<W-I;VX@:7-T(&%B9V5L875F96XN($)I
M='1E(&UE;&1E;B!3:64@<VEC:"!E<FYE=70@86XN`$EH<F4@16UA:6PM061R
M97-S90!):')E(%9O;CH@061R97-S93H`26AR92!!;F=A8F5N`$EH<F4@26YT
M97)N971A9')E<W-E(&AA="!S:6-H(&=EY&YD97)T+"!S96ET(%-I92!D:64@
M)7,M4VET>G5N9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C:'5T>B!):')E<B!3
M:6-H97)H96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN`$EH<B!.
M86UE`$EH<B!!=71H96YT:69I>FEE<G5N9W-S>7-T96T@97)L875B="!K96EN
M($AI;GIU9OQG96X@=F]N(&YE=65N($)E;G5T>F5R;BX@5V5N;B!3:64@2&]R
M9&4@8F5N=71Z96X@;?9C:'1E;BP@=6T@26AR92!"96YU='IE<B!Z=2!V97)W
M86QT96XL(&W\<W-E;B!3:64@96EN96X@86YD97)E;B!!=71H96YT:69I>FEE
M<G5N9W-T<F5I8F5R(&)E;G5T>F5N+@!):'(@075T:&5N=&EF:7II97)U;F=S
M<WES=&5M(&5R;&%U8G0@9&%S($%N>F5I9V5N(&1E<B!"96YU='IE<B!N:6-H
M="P@;V1E<B!D:65S92!-]F=L:6-H:V5I="!W=7)D92!A=7-G97-C:&%L=&5T
M+@!):'(@0G)O=W-E<B!H870@<VEC:"!A;G-C:&5I;F5N9"!G9>1N9&5R="!S
M96ET(%-I92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C
M:'5T>B!):')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM
M96QD96XN`$EH<B!"<F]W<V5R('5N=&5R<W3\='IT(&1I97-E($9U;FMT:6]N
M(&YI8VAT+@!):'(@0G)O=W-E<B!U;G1E<G-T_'1Z="!D:65S92!$<G5C:V9U
M;FMT:6]N(&YI8VAT+B!":71T92!D<OQC:V5N(%-I92!3=')G+TMO;6UA;F1O
M("L@4"!U;2!Z=2!D<G5C:V5N+@!):')E(&%K='5E;&QE(%IE:71Z;VYE.@!)
M:'(@4W1A;F1A<F0M2V%L96YD97(`26AR92!3=&%N9&%R9&ED96YT:73D="!W
M=7)D92!G9>1N9&5R="X`26AR92!3=&%N9&%R9&ED96YT:73D=#H`26AR('9O
M;&QS=.1N9&EG97(@3F%M93H`26AR(%IU9V%N9R!I<W0@86)G96QA=69E;BX`
M26AR(&YE=65S(%!A<W-W;W)T(&;\<B`E<R!L875T970Z("5S`$EH<F4@16EN
M<W1E;&QU;F=E;B!W=7)D96X@9OQR(&1I92!$875E<B!D:65S97(@4VET>G5N
M9R!G97-P96EC:&5R="X`26AR92!%:6YS=&5L;'5N9V5N('=U<F1E;B!G97-P
M96EC:&5R="X`26AR(%!A<W-W;W)T('=U<F1E('IU<OQC:V=E<V5T>G0`26AR
M(%!A<W-W;W)T('=U<F1E('IU<OQC:V=E<V5T>G0N(%)U9F5N(%-I92!):')E
M($5M86EL<R!A8B!U;F0@;65L9&5N(%-I92!S:6-H(&UI="!):')E;2!N975E
M;B!087-S=V]R="!A;BX`26AR(%!A<W-W;W)T(&ES="!A8F=E;&%U9F5N+@!)
M:')E(%-E<G9E<CH`2G5G;W-L87=I96X`6F%I<F4`4V%M8FEA`%-I;6)A8G=E
M`%II<'!Y`%M::71A='1E>'0@=F5R<W1E8VME;ET`6U!R;V)L96UB97)I8VAT
M70!;6FET871T97AT(&%N>F5I9V5N("T`6UII=&%T=&5X="!A;GIE:6=E;B`M
M("5S(%IE:6QE;ET`6U5N8F5N86YN=&5R(%1E<FUI;ET`6UIE:6QE("5S('9O
M;B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]!;&%R;0!%:6Y?9F%C:&4@4W5C:&4`
M0F5?9F5H;'-Z96EL90!?1&%T851R964`6F5I;&4@7VSV<V-H96X`7T)E87)B
M96ET96X`7T=E:&4@>G4`7T=R=7!P96X`7TAI;&9E`%]":6QD96EG96YS8VAA
M9G1E;BXN+@!?26UP;W)T+T5X<&]R=`!!;E]M96QD96X`06)?;65L9&5N`$QI
M;FL@7V)E87)B96ET96XN+BX`7TUE:6YE($MA;&5N9&5R`%].975E<B!497)M
M:6X`7T5I;G-T96QL=6YG96X`7U)E8VAT90!?1')U8VME;@!,:6YK(%]E;G1F
M97)N96XN+BX`7U-U8VAE`%]+;VYF:6=U<F%T:6]N`%]486)E;&QE;F5I9V5N
M<V-H869T96XN+BX`2&5?=71E`%]"96YU='IE<@!!9')E<W-B=6-H`$%D<F5S
M<V%T('5N8F5K86YN=`!V;W(@9&5M(%1E<FUI;F)E9VEN;@!+86QE;F1E<@!W
M:6YD<W1I;&P`075S9V%B961A=&5I(&MO;FYT92!N:6-H="!E<G-T96QL="!W
M97)D96X`16EN9V%B92!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E;@!K;&EC
M:V5N(%-I92!H:65R`%5N9_QL=&EG92!"96YU='IU;F<@9&5R($MO;6UA;F1O
M>F5I;&4`2V]N9FEG=7)A=&EO;G-F96AL97(`2W)I=&ES8VAE(%-Y<W1E;61A
M=&5I(&9E:&QT`$1A=&5N9F]R;6%T9F5H;&5R`%1A9P!486<H92D`5&%G90!B
M96%R8F5I=&5N`$5I;G1R86<@;FEC:'0@9V5F=6YD96X`=&5R;6EN92YC<W8`
M=&5R;6EN92YI8W,`9F%L;&5N9`!$871E:0!A=7,@)7,@*"5S*2!M:70@)7,@
M)7,`8O9I9P!H.@!H:`!(;W-T;F%M92!U;F)E:V%N;G0`<V]F;W)T`&EN`$EN
M;&EN90!%:6XM+T%U<V=A8F5F96AL97(`26YT97)N97(@4V]F='=A<F5F96AL
M97(`6F5I;&5N70!M:VES;V9S+49E:&QE<F-O9&4@)60@8F5I(&1E<B!%<G-T
M96QL=6YG(&1E<R!)4T\M06)B:6QD97,N`&UM`$UO;F%T*&4I`$YA;64`;FEC
M:'0@:6UP;&5M96YT:65R=`!.;V-H(&YI8VAT(&EM<&QE;65N=&EE<G0`3F]T
M:7IB;&]C:P!A;2`E<R!U;2`E<P!A;2!G;&5I8VAE;B!$871U;0!A;2!G;&5I
M8VAE;B!7;V-H96YT86<`4')O>F5N=`!:=6=R:69F('9E<G=E:6=E<G0`4&EX
M96P`4F5M;W1E9F5H;&5R(&EM(%!R;W1O:V]L;`!S=&5I9V5N9`!397)V:6-E
M(&YI8VAT('9E<F;\9V)A<@!5;G1E<G-C:&EE9&4@86YZ96EG96X`<VUS,F5M
M86EL(/QB97(@2%144`!S<P!G;&5I8VAB;&5I8F5N9`!3>7-T96UF96AL97(`
M075F9V%B96YL:7-T90!6;W+\8F5R9V5H96YD97(@1F5H;&5R`&=E8F5N(%-I
M92!D87,@4&%S<W=O<G0@96EN('IW96ET97,@36%L('IU<B!"97-TY'1I9W5N
M9R!E:6X`=6YI9FEE9`!U;F)E;F%N;G0`8F5N=71Z97)D969I;FEE<G0`=D-A
M;&5N9&%R+VE#86QE;F1A<@!V0V%R9`!V179E;G0@;FEC:'0@9V5F=6YD96XN
M`&(Z`'=E871H97(N8V]M`%=O8VAE`%=O8VAE*&XI(&%M.@!7;V-H96X`2F%H
M<BAE*0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]L;V-A;&4O9&5?1$4O:&5L<"YX;6P`````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3(V-C``,3`T,3<S-C(W-3``,#(R,S`U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_>&UL('9E<G-I;VX]
M(C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3$B/SX*/"$M+2`D2&]R9&4Z(&MR
M;VYO;&ET:"]L;V-A;&4O9&5?1$4O:&5L<"YX;6PL=B`Q+C$N,BXR(#(P,#4O
M,3`O,3@@,3(Z,C<Z,S(@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@
M:60](D]V97)V:65W(B!M9#4](C$U.#4Y,C=D-#AE-#8R-V,W.3)F93`S,S)C
M-#%F9#,Y(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DMR;VYO;&ET
M:#H@W&)E<F)L:6-K/"]T:71L93X*("`@(#QP87)A/@H@("`@("!"96D@2W)O
M;F]L:71H(&AA;F1E;'0@97,@<VEC:"!U;2!E:6YE;B!W96)B87-I97)T96X@
M2V%L96YD97(N($YE8F5N(&1E;@H@("`@("#\8FQI8VAE;B!&=6YK=&EO;F5N
M('=I92!%:6YT<F%G96XL($)E87)B96ET96X@=6YD($SV<V-H96X@=F]N(%1E
M<FUI;F5N"B`@("`@('=E<F1E;B!A==]E<F1E;2!S:6-H('=I961E<FAO;&5N
M9&4@5&5R;6EN92`H;6ET($%U<VYA:&UE;B!U;F0*("`@("`@=F5R<V-H:65D
M96YE;B!,]G-C:&WV9VQI8VAK96ET96XI+"!!;&%R;64L($EM+2!U;F0@17AP
M;W)T("AI0V%L96YD87(L"B`@("`@(%1E>'1D871E:65N('5N9"!086QM*2P@
M:4-A;&5N9&%R+45I;FQA9'5N9V5N+"!V97)S8VAI961E;F4*("`@("`@2V%L
M96YD97)A;G-I8VAT96XL(&=E;65I;G-A;64@2V%L96YD97(L($%N>F5I9V4@
M=F]N($%U9F=A8F5N("AW96YN"B`@("`@(&1I92!!=69G86)E;FQI<W1E;F%N
M=V5N9'5N9R!.86<@:6YS=&%L;&EE<G0@:7-T*2!U;F0@9&EE($%N>F5I9V4@
M=F]N"B`@("`@(%1E<FUI;F5N(&EM($AO<F1E+5!O<G1A;"!U;G1E<G-T_'1Z
M="X*("`@(#PO<&%R83X*("`\+V5N=')Y/@H*("`\96YT<GD@:60](FUE;G4M
M=&]D87DB(&UD-3TB8S9D,&,P9C,V-C$W-6$S.&0P-C4U960Y.38Y960T838B
M('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^365N_#H@2&5U=&4\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("`@($5I;B!+;&EC:R!A=68@9&5N(#QI/DAE
M=71E/"]I/BU-96[\96EN=')A9R!Z96EG="!):')E(%-T86YD87)D86YS:6-H
M=`H@("`@("`H36]N870L(%=O8VAE+"!486<@=7-W+B!W:64@:6X@9&5N($5I
M;G-T96QL=6YG96X@9F5S=&=E;&5G="D@9OQR(&1A<PH@("`@("!A:W1U96QL
M92!$871U;2!A;BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H*("`\96YT<GD@
M:60](FUE;G4M1V]T;R(@;60U/2(U-C8Q.3$W-S5B83DP8C<V.68R93-F-V-D
M9C(T8V)F82(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y-96[\.B!'
M96AE('IU/"]T:71L93X*("`@(#QP87)A/@H@("`@("!%:6X@2VQI8VL@875F
M(&1E;B`\:3Y'96AE('IU/"]I/BU-96[\96EN=')A9R!Z96EG="!E:6X@:VQE
M:6YE<PH@("`@("!0;W!U<&9E;G-T97(@86XL(/QB97(@9&%S(%-I92!S8VAN
M96QL('IU(&5I;F5N(&)E<W1I;6UT96X@36]N870L(%=O8VAE"B`@("`@(&]D
M97(@5&%G(&=E;&%N9V5N(&OV;FYE;BX@1&EE<R!I<W0@9OQR(&=E=_9H;FQI
M8V@@9&EE('-C:&YE;&QS=&4@07)T+"!I;0H@("`@("!+86QE;F1E<B!Z=2!N
M879I9VEE<F5N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"@H@(#QE;G1R>2!I
M9#TB;65N=2U$87DB(&UD-3TB,V-D-C)E,3`Q,38P-3AD8C4R83$U9F5C9#=D
M9&)C8C`B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^365N_#H@5&%G
M/"]T:71L93X*("`@(#QP87)A/@H@("`@("!%:6X@2VQI8VL@875F(&1E;B`\
M:3Y486<\+VD^+51A8G)E:71E<B!Z96EG="!D:64@5&%G97-A;G-I8VAT(&1E
M<PH@("`@("!A=7-G97?D:&QT96X@5&%G97,@86XN"B`@("`\+W!A<F$^"B`@
M/"]E;G1R>3X*"B`@/&5N=')Y(&ED/2)M96YU+7=O<FLM=V5E:R(@;60U/2)F
M.6$V,S4X-6,X,61C838S.#@W93$S,&1B8F5A.3%D92(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y-96[\.B!!<F)E:71S=V]C:&4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("`@($5I;B!+;&EC:R!A=68@9&5N(#QI/D%R8F5I='-W
M;V-H93PO:3XM5&%B<F5I=&5R('IE:6=T(&1I90H@("`@("!!<F)E:71S=V]C
M:&5N86YS:6-H="`H36]N=&%G(&)I<R!&<F5I=&%G*2!D97,@875S9V5WY&AL
M=&5N(%1A9V5S(&%N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"@H@(#QE;G1R
M>2!I9#TB;65N=2UW965K(B!M9#4](C-D.&$S8F9D838R.6)B-F4P.3@Q.6(R
M938V,#4T-F4U(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE;OPZ
M(%=O8VAE/"]T:71L93X*("`@(#QP87)A/@H@("`@("!%:6X@2VQI8VL@875F
M(&1E;B`\:3Y7;V-H93PO:3XM5&%B<F5I=&5R('IE:6=T(&1I92!7;V-H96YA
M;G-I8VAT"B`@("`@("@W+51A9V4M5V]C:&4I(&1E<R!A=7-G97?D:&QT96X@
M5&%G97,@86XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*"B`@/&5N=')Y(&ED
M/2)M96YU+6UO;G1H(B!M9#4](C1B93(P-38X-S4W-S5E8S%F-6(P9CDR,&$Q
M9&%B-C`X(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE;OPZ($UO
M;F%T/"]T:71L93X*("`@(#QP87)A/@H@("`@("!%:6X@2VQI8VL@875F(&1E
M;B`\:3Y-;VYA=#PO:3XM5&%B<F5I=&5R('IE:6=T(&1I92!-;VYA='-A;G-I
M8VAT(&1E<PH@("`@("!A=7-G97?D:&QT96X@5&%G97,@86XN"B`@("`\+W!A
M<F$^"B`@/"]E;G1R>3X*"B`@/&5N=')Y(&ED/2)M96YU+6YE=RUE=F5N="(@
M;60U/2(S-S0P-F-C,F5E-3$P-#`X-C)D9C%E86$R9C8T-60T92(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93Y-96[\.B!.975E<B!497)M:6X\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("`@($1E<B`\:3Y'96AE('IU/"]I/BU-96[\
M96EN=')A9R!E<FQA=6)T(&1A<R!(:6YZ=6;\9V5N(&YE=65R(%1E<FUI;F4@
M>G5M"B`@("`@($MA;&5N9&5R+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"@H@
M(#QE;G1R>2!I9#TB;65N=2UO<'1I;VYS(B!M9#4](F0W9&8R8S!C9&$X-&,X
M.6,V,SAD.60V934Y,S`W.3<V(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/DUE;OPZ($5I;G-T96QL=6YG96X\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("`@(-QB97(@9&5N(#QI/D5I;G-T96QL=6YG96X\+VD^+4UE;OQE:6YT<F%G
M(&OV;FYE;B!3:64@9&EE($5I;G-T96QL=6YG96X*("`@("`@8F5A<F)E:71E
M;BP@9&EE(&1A<R!!=7-S96AE;B!+<F]N;VQI=&AS('5N9"!D87,@6G5S86UM
M96YS<&EE;"!+<F]N;VQI=&AS"B`@("`@(&UI="!(;W)D92!U;F0@=6YD(&%N
M9&5R96X@2&]R9&4M06YW96YD=6YG96X@8F5E:6YF;'5S<V5N('5N9"!M96AR
M97)E+`H@("`@("!A=6-H(&=E;65I;G-A;64L($MA;&5N9&5R('9E<G=A;'1E
M;BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H*("`\96YT<GD@:60](FUE;G4M
M:6UP;W)T+65X<&]R="(@;60U/2(S-&)C.61F8S1D-C,P,F9C,3`Q,38Y-F$Q
M8CAD,6-A."(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y-96[\.B!)
M;7!O<G0O17AP;W)T/"]T:71L93X*("`@(#QP87)A/@H@("`@("!-:70@9&5M
M(#QI/DEM<&]R="]%>'!O<G0\+VD^+4UE;OQE:6YT<F%G(&OV;FYE;B!3:64@
M5&5R;6EN92!I;2T@=6YD"B`@("`@(&5X<&]R=&EE<F5N+B!:=7(@6F5I="!K
M]FYN96X@4VEE(&MO;6UA9V5T<F5N;G1E(%1E>'1D871E:65N+"!Z+D(N('9O
M;@H@("`@("!-:6-R;W-O9G0@3W5T;&]O:R!U;F0@1&%T96EE;B!I;2!V0V%L
M96YD97(O:4-A;&5N9&%R+49O<FUA="!I;2T@=6YD"B`@("`@(&5X<&]R=&EE
M<F5N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"@H@(#QE;G1R>2!I9#TB86QA
M<FUS(B!M9#4](C1C,6,V9C-E8C$S830Q-C`S,69F8F5E-&9C93DY96$Q(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%L87)M93PO=&ET;&4^"B`@
M("`\<&%R83X*("`@("`@2W)O;F]L:71H(&MA;FX@06QA<FUE(&;\<B!497)M
M:6YE(&5R>F5U9V5N+B!!;',@4W1A;F1A<F0@=VER9"!D97(@06QA<FT*("`@
M("`@,34@36EN=71E;B!V;W(@9&5M(%1E<FUI;F)E9VEN;B!A=7-G96SV<W0L
M(%-I92!K]FYN96X@9&EE($%L87)M>F5I="!A8F5R"B`@("`@(&;\<B!J961E
M;B!497)M:6X@9G)E:2!F97-T;&5G96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R
M>3X*"B`@/&5N=')Y(&ED/2)R96-U<G)I;F<M979E;G1S(B!M9#4](C@S83!C
M,V$X83)D,F8U8V4X8C4U,3!B9&$R-34V-#-D(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/E=I961E<FME:')E;F1E(%1E<FUI;F4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("`@(%1E<FUI;F4@:_9N;F5N(&%U9B!V97)S8VAI961E
M;F4@5V5I<V4@=VEE9&5R:&]L="!W97)D96XL('HN0BX@;6]N871L:6-H"B`@
M("`@(&]D97(@=_9C:&5N=&QI8V@N($%B97(@875C:"!K;VUP;&5X97)E(%=I
M961E<FAO;')H>71H;65N('-I;F0@;?9G;&EC:"P*("`@("`@>BY"+B!J961E
M;B!D<FET=&5N($9R96ET86<@96EN97,@36]N871S(&]D97(@:F5D92!7;V-H
M92!-;VYT86=S+`H@("`@("!-:71T=V]C:',@=6YD($9R96ET86=S+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%-I92!K]FYN96X@96)E;F9A;&QS
M(&9E<W1L96=E;BP@=VEE(&QA;F=E(&5I;B!497)M:6X@=VEE9&5R:&]L="!W
M:7)D+`H@("`@("!I;F1E;2!3:64@96EN(#QI/D5N9&1A='5M/"]I/B!F_'(@
M9&EE(%=I961E<FAO;'5N9V5N(&5I;G-T96QL96XN"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@("`@3F]R;6%L97)W96ES92!W:7)K96X@<VEC:"#$;F1E
M<G5N9V5N(&%N(&5I;F5M('=I961E<FME:')E;F1E;B!497)M:6X@875F"B`@
M("`@(&%L;&4@5VEE9&5R:&]L=6YG96X@9&EE<V5S(%1E<FUI;G,@875S+B!3
M:64@:_9N;F5N(&%B97(@96EN92!E:6YZ96QN90H@("`@("!7:65D97)H;VQU
M;F<@8F5A<F)E:71E;BP@:6YD96T@4VEE(&)E:6T@0F5A<F)E:71E;B!D96X@
M5VEE9&5R:&]L<FAY=&AM=7,*("`@("`@>G5R_&-K<V5T>F5N('5N9"!D:64@
M0F5A<F)E:71U;F<@;6ET(")!;',@2V]P:64@<W!E:6-H97)N(@H@("`@("!B
M965N9&5N+B!$86YA8V@@:&%B96X@4VEE(&5I;F5N(&5I;GIE;&YE;B!497)M
M:6XL(&1E;B!3:64@9V5T<F5N;G0@=F]N"B`@("`@(&1E;B!A;F1E<F5N(&)E
M87)B96ET96X@:_9N;F5N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"@H@(#QE
M;G1R>2!I9#TB4')I;G1I;F<B(&UD-3TB,F8Y,&0Q-&4S-&(W,35A,#4T9F(U
M,F)B.3$Y86,U9C@B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^1')U
M8VME;CPO=&ET;&4^"B`@("`\:&5A9&EN9SY$<G5C:V5N('9O;B!+86QE;F1E
M<FX@=6YD(%1E<FUI;F5N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%9E
M<G-C:&EE9&5N92!!;G-I8VAT96X@:_9N;F5N(&%U<V=E9')U8VMT('=E<F1E
M;BX@5V5N;B!3:64@<VEC:"!I;B!E:6YE<@H@("`@("!D:65S97(@06YS:6-H
M=&5N(&)E9FEN9&5N+"!W:7)D(&5I;B`\:3Y$<G5C:V5N/"]I/BU3>6UB;VP@
M:6T@365N_`H@("`@("!A;F=E>F5I9W0N(%=E;FX@4VEE(&%U9B!D:65S96X@
M16EN=')A9R!K;&EC:V5N+"!W:7)D(&1I92!A:W1U96QL90H@("`@("!!;G-I
M8VAT(&%U<V=E9')U8VMT+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O8W-?0UHO````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-3``,#(P-C<R`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+VQO8V%L92]C<U]#6B],0U]-15-304=%4R\`````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,``P,C(T-3<`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+V-S7T-:+TQ#7TU%4U-!1T53+VMR
M;VYO;&ET:"YM;P```````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S<W-S4U`#$P-#$W,S8R-S4P`#`R-3`U
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````*4'```<````1#T``#$*``!L>@```````#"C```.````,:,```\`
M``!`HP``#0```%"C```(````7J,```L```!GHP``#````'.C```$````@*,`
M``P```"%HP``"0```)*C```/````G*,```L```"LHP``'P```+BC```.````
MV*,```4```#GHP``*````.VC```(````%J0```H````?I```%0```"JD```2
M````0*0```L```!3I```#````%^D```=````;*0```X```"*I```"@```)FD
M```-````I*0```X```"RI```$0```,&D```-````TZ0```P```#AI```#0``
M`.ZD```&````_*0``!T````#I0``'0```"&E```/````/Z4``!@```!/I0``
M#````&BE```*````=:4```<```"`I0``#@```(BE```.````EZ4```@```"F
MI0``+@```*^E```:````WJ4``#(```#YI0``.````"RF``!4````9:8``%$`
M``"ZI@``6@````RG``!7````9Z<``#0```"_IP```@```/2G```'````]Z<`
M``H```#_IP``#P````JH```%````&J@```8````@J```$0```">H```(````
M.:@```D```!"J```"0```$RH```(````5J@``"4```!?J```(````(6H```0
M````IJ@```\```"WJ```"@```,>H```0````TJ@```,```#CJ```#P```.>H
M```4````]Z@```D````,J0``"0```!:I```-````(*D``!(````NJ0``&0``
M`$&I```/````6ZD```\```!KJ0``#0```'NI```*````B:D```\```"4J0``
M"````*2I```D````K:D``!0```#2J0``%@```.>I```(````_JD``!D````'
MJ@``!P```"&J```,````*:H``"P````VJ@``#@```&.J```#````<JH```\`
M``!VJ@``"P```(:J```%````DJH``!0```"8J@``%0```*VJ```7````PZH`
M`!4```#;J@``$@```/&J```3````!*L``!4````8JP``$P```"ZK```*````
M0JL``!0```!-JP``"@```&*K```'````;:L```<```!UJP``!0```'VK```%
M````@ZL```H```")JP```P```)2K```-````F*L``!<```"FJP``"@```+ZK
M```*````R:L```@```#4JP``#P```-VK```+````[:L```<```#YJP``#0``
M``&L```*````#ZP```X````:K```&````"FL```C````0JP```X```!FK```
M%````'6L```7````BJP``!<```"BK```%P```+JL```3````TJP```\```#F
MK```#@```/:L```?````!:T```<````EK0``!@```"VM```(````-*T```\`
M```]K0``!@```$VM```*````5*T``!,```!?K0```P```'.M```+````=ZT`
M`!````"#K0``%0```)2M```5````JJT```<```#`K0``$````,BM```%````
MV:T``!4```#?K0``$0```/6M```,````!ZX``#L````4K@``"0```%"N```'
M````6JX``!0```!BK@```P```'>N```%````>ZX``!````"!K@``"0```)*N
M```3````G*X``#D```"PK@``$@```.JN```"````_:X``+0`````KP``)P``
M`+6O```L````W:\``"H````*L```)0```#6P```*````6[````D```!FL```
M"@```'"P```&````>[````D```""L```!P```(RP```O````E+```#<```#$
ML```+@```/RP``!5````*[$``"T```"!L0``+0```*^Q```M````W;$``$``
M```+L@``(P```$RR```C````<+(``"T```"4L@``,P```,*R```5````]K(`
M`!D````,LP``*0```":S```D````4+,``!$```!ULP``"@```(>S```,````
MDK,```H```"?LP``$````*JS```6````N[,``!8```#2LP``!P```.FS```'
M````\;,``!0```#YLP``"@````ZT```(````&;0```@````BM```#````"NT
M```'````.+0```<```!`M```!@```$BT```%````3[0```<```!5M```!@``
M`%VT```(````9+0``"D```!MM```#@```)>T```*````IK0```0```"QM```
M!P```+:T```)````OK0```8```#(M```$0```,^T```'````X;0``!8```#I
MM```!`````"U```(````!;4```8````.M0``#0```!6U```&````([4``!X`
M```JM0``$0```$FU```(````6[4```T```!DM0``#````'*U```'````?[4`
M``0```"'M0```P```(RU```#````D+4``!<```"4M0``"0```*RU```3````
MMK4```D```#*M0``"````-2U```0````W;4```D```#NM0``&P```/BU```$
M````%+8```@````9M@``"````"*V``!!````*[8``"````!MM@``&0```(ZV
M```&````J+8```8```"OM@``%0```+:V```)````S+8```T```#6M@``&```
M`.2V```B````_;8``"X````@MP``'0```$^W```A````;;<``%0```"/MP``
M*0```.2W```*````#K@```<````9N```"0```"&X```5````*[@```@```!!
MN```#@```$JX```*````6;@```\```!DN```#0```'2X```/````@K@```T`
M``"2N```"0```*"X```4````JK@```8```"_N```&````,:X```=````W[@`
M`!,```#]N```%````!&Y```$````)KD```8````KN0``5````#*Y```$````
MA[D```X```",N0``!0```)NY```%````H;D``!L```"GN0``&@```,.Y```1
M````WKD``!$```#PN0``'`````*Z```J````'[H``#8```!*N@``'0```(&Z
M```0````G[H``"$```"PN@``!0```-*Z```3````V+H``!(```#LN@``"@``
M`/^Z```/````"KL``!$````:NP``$P```"R[```,````0+L```8```!-NP``
M!@```%2[```7````6[L``!````!SNP``$0```(2[```(````EKL```4```"?
MNP``#````*6[```0````LKL```4```##NP``#0```,F[```&````U[L``!8`
M``#>NP``!P```/6[```-````_;L```<````+O```"P```!.\```'````'[P`
M``<````GO```"0```"^\```*````.;P``!D```!$O```#````%Z\```0````
M:[P``!L```!\O```"0```)B\```%````HKP``"4```"HO```$@```,Z\```3
M````X;P``"L```#UO```.P```"&]```@````7;T``#8```!^O0``"````+6]
M```,````OKT```8```#+O0``!````-*]```.````U[T``$````#FO0``"@``
M`">^```-````,KX``!X```!`O@``&P```%^^```A````>[X``!X```"=O@``
M&0```+R^```>````UKX``!L```#UO@``)@```!&_```;````.+\``!X```!4
MOP``'````'._```F````D+\``#,```"WOP``)@```.N_```K````$L```#@`
M```^P```+P```'?````2````I\```"D```"ZP```$@```.3```"B````]\``
M`!8```":P0``(P```+'!```H````U<$``"D```#^P0``*````"C"```?````
M4<(``"````!QP@``)0```)+"```P````N,(``"$```#IP@``'`````O#```F
M````*,,``$$```!/PP``#````)'#```'````GL,```<```"FPP``!@```*[#
M```2````M<,```T```#(PP``$````-;#```2````Y\,```<```#ZPP``$P``
M``+$```2````%L0```<````IQ```!````#'$```'````-L0```P````^Q```
M#@```$O$```/````6L0``!,```!JQ```#0```'[$```H````C,0```,```"U
MQ```#0```+G$```&````Q\0``!$```#.Q```%P```.#$```;````^,0```X`
M```4Q0```@```"/%```%````)L4``!,````LQ0``$````$#%```$````4<4`
M``T```!6Q0``#@```&3%```#````<\4```8```!WQ0``!P```'[%```.````
MAL4```@```"5Q0``#P```)[%```(````KL4```\```"WQ0``!P```,?%```0
M````S\4```T```#@Q0``$````.[%```+````_\4```8````+Q@``"0```!+&
M```,````',8```P````IQ@``$0```#;&```9````2,8```L```!BQ@``#0``
M`&[&```B````?,8```H```"?Q@``&````*K&```9````P\8``%P```#=Q@``
M%@```#K'```-````4<<```<```!?QP``#````&?'```4````=,<```L```")
MQP``(@```)7'```O````N,<```L```#HQP``"0```/3'```9````_L<```L`
M```8R```%P```"3(```7````/,@```D```!4R```!P```%[(```6````9L@`
M``\```!]R```%@```(W(```.````I,@``!@```"SR```"````,S(```-````
MU<@``"8```#CR```.0````K)```.````1,D``$,```!3R0``"````)?)```2
M````H,D```@```"SR0``"P```+S)```O````R,D```X```#XR0``!0````?*
M```'````#<H```@````5R@``!@```![*```#````)<H```<````IR@``!```
M`#'*```'````-LH```X````^R@``"@```$W*```*````6,H```\```!CR@``
M$````'/*```7````A,H``!4```"<R@``#@```++*```:````P<H``!$```#<
MR@``%P```.[*```)````!LL```4````0RP``"P```!;+```*````(LL```(`
M```MRP``!0```##+```-````-LL``!L```!$RP``%P```&#+```)````>,L`
M``X```""RP``#0```)'+```2````G\L``#@```"RRP``(````.O+```(````
M#,P```8````5S```"````!S,```(````)<P```X````NS```>P```#W,```8
M````N<P``!$```#2S```!P```.3,```%````[,P``#$```#RS```&0```"3-
M```'````/LT```@```!&S0``!@```$_-```&````5LT``!,```!=S0``$```
M`''-```/````@LT``!````"2S0``#P```*/-```+````L\T```\```"_S0``
M#````,_-```/````W,T```<```#LS0``!@```/3-```.````^\T```P````*
MS@``*````!?.```/````0,X```@```!0S@``!@```%G.```/````8,X```@`
M``!PS@``$P```'G.```>````C<X``"$```"LS@``(````,[.```9````[\X`
M`!<````)SP``)0```"'/```7````1\\```0```!?SP``&P```&3/```-````
M@,\```P```".SP```P```)O/```(````G\\```H```"HSP``#````+//```+
M````P,\``!````#,SP``#````-W/```$````ZL\``!,```#OSP``%`````/0
M```,````&-````D````ET```#@```"_0```+````/M```!L```!*T```!P``
M`&;0```$````;M````<```!ST```"@```'O0```-````AM````D```"4T```
M!````)[0```%````H]````,```"IT```&````*W0```*````QM````0```#1
MT```)@```-;0```.````_=```'P````,T0``%0```(G1```%````G]$```<`
M``"ET0``#````*W1```(````NM$```H```##T0``!@```,[1```(````U=$`
M``(```#>T0``!@```.'1```&````Z-$``!0```#OT0``#0````32```0````
M$M(``!L````CT@``!@```#_2```$````1M(```D```!+T@``$````%72```)
M````9M(```D```!PT@``!@```'K2```%````@=(``!H```"'T@``"````*+2
M```&````J](```0```"RT@``!P```+?2```9````O](```X```#9T@``!P``
M`.C2```'````\-(```4```#XT@``"0```/[2```*````"-,```(````3TP``
M!@```!;3```-````'=,```<````KTP``"0```#/3```&````/=,``!(```!$
MTP``"0```%?3```'````8=,``!0```!ITP``'0```'[3```&````G-,```H`
M``"CTP``!````*[3```)````L],```@```"]TP``$0```,;3```)````V-,`
M``8```#BTP``#0```.G3```&````]],```0```#^TP``.0````/4```]````
M/=0``#H```![U```'@```+;4```%````U=0```X```#;U```!````.K4```&
M````[]0``"$```#VU```%0```!C5```&````+M4```0````UU0``$0```#K5
M```&````3-4```H```!3U0``(@```%[5```$````@=4```4```"&U0``'0``
M`(S5```$````JM4```P```"OU0``"@```+S5```(````Q]4```D```#0U0``
M!0```-K5```Z````X-4``#`````;U@``-0```$S6```I````@M8``$<```"L
MU@``.````/36```I````+=<``#\```!7UP``+@```)?7```M````QM<``!\`
M``#TUP``#P```!38```2````)-@```L````WV```!P```$/8```F````2]@`
M`"D```!RV```)````)S8```F````P=@```@```#HV```"@```/'8```)````
M_-@```<````&V0``(`````[9```@````+]D``"8```!0V0``"@```'?9```9
M````@MD``"D```"<V0``%@```,;9```2````W=D```<```#PV0``"@```/C9
M```,`````]H```\````0V@``$````"#:``!`````,=H``'````!RV@``9@``
M`./:```.````2ML```D```!9VP``"@```&/;```2````;ML``!,```"!VP``
M#````)7;```&````HML``!@```"IVP``#P```,+;```6````TML``!(```#I
MVP``$````/S;```1````#=P``!P````?W```(P```#S<``!J````8-P```\`
M``#+W```!0```-O<```0````X=P```D```#RW```!````/S<```+`````=T`
M`!0````-W0``#````"+=```,````+]T```\````\W0``%0```$S=```I````
M8MT``"H```",W0``)@```+?=```G````WMT``"D````&W@``*@```##>```9
M````6]X``$(```!UW@``$0```+C>```2````RMX``!,```#=W@``%````/'>
M```/````!M\``!8````6WP``%P```"W?```0````1=\``!$```!6WP``-```
M`&C?```3````G=\``!(```"QWP``-0```,3?```4````^M\```<````/X```
M#````!?@```@````).```!0```!%X```$0```%K@```7````;.```!P```"$
MX```$P```*'@```1````M>```!H```#'X```'@```.+@```:`````>$``!$`
M```<X0``%````"[A```7````0^$``!4```!;X0``"0```''A```9````>^$`
M``0```"5X0``!P```)KA```+````HN$``!$```"NX0``!@```,#A```&````
MQ^$```8```#.X0``!0```-7A```'````V^$```<```#CX0``!0```.OA```6
M````\>$```8````(X@``!@````_B```$````%N(```0````;X@``!P```"#B
M```.````*.(```P````WX@``#````$3B```-````4>(```H```!?X@``#@``
M`&KB```%````>>(``"@```!_X@``#@```*CB```,````M^(```\```#$X@``
M"@```-3B```(````W^(```D```#HX@``*P```/+B```(````'N,```0````G
MXP``"````"SC```F````->,``!(```!<XP``#P```&_C```&````?^,```H`
M``"&XP``!P```)'C```(````F>,``"````"BXP``#0```,/C```)````T>,`
M``T```#;XP``"@```.GC```,````].,```T````!Y```#@````_D```6````
M'N0``!$````UY```"0```$?D```&````4>0```,```!8Y```!@```%SD```9
M````8^0```<```!]Y```!````(7D```+````BN0```L```"6Y```!P```*+D
M```'````JN0``!8```"RY```#0```,GD```-````U^0```H```#EY```$```
M`/#D```/`````>4``!$````1Y0``%P```"/E```*````.^4``!$```!&Y0``
M"````%CE```>````8>4```0```"`Y0``#P```(7E```Z````E>4```4```#0
MY0``#````-;E```>````X^4```X````"Y@``$````!'F```+````(N8```P`
M```NY@``"0```#OF```'````1>8```H```!-Y@``"0```%CF```.````8N8`
M`!````!QY@``&@```(+F```*````G>8```D```"HY@``"0```++F```*````
MO.8```P```#'Y@``#P```-3F```(````Y.8```8```#MY@``!P```/3F```+
M````_.8``$<````(YP``#0```%#G```)````7N<```0```!HYP```P```&WG
M```3````<><``!,```"%YP``$P```)GG```*````K><```(```"XYP``!```
M`+OG```E````P.<```,```#FYP``!0```.KG```J````\.<```H````;Z```
M!0```";H```$````+.@```H````QZ```#0```#SH```&````2N@```@```!1
MZ```"````%KH```$````8^@```4```!HZ```&````&[H``!H````A^@```D`
M``#PZ```#````/KH```%````!^D```8````-Z0``&P```!3I```O````,.D`
M`!````!@Z0``"@```''I```/````?.D```H```",Z0``"0```)?I```3````
MH>D``!L```"UZ0``&````-'I```7````ZND```X````"Z@```P```!'J```'
M````%>H```@````=Z@``!P```";J```'````+NH```D````VZ@``"@```$#J
M```+````2^H```<```!7Z@``40```%_J```0````L>H```P```#"Z@``#0``
M`,_J```:````W>H``$H```#XZ@``!@```$/K```&````2NL```8```!1ZP``
M'P```%CK```&````>.L```D```!_ZP``&````(GK```7````HNL```D```"Z
MZP``!@```,3K```-````R^L``!(```#9ZP``(@```.SK``!7````#^P``!,`
M``!G[```(P```'OL```3````G^P```(```"S[```"P```+;L```(````PNP`
M``T```#+[```"@```-GL```'````Y.P``!0```#L[```!@````'M```&````
M".T```@````/[0``!0```!CM```*````'NT```X````I[0``!P```#CM```3
M````0.T``!4```!4[0``#````&KM```-````=^T```H```"%[0``"P```)#M
M```'````G.T```P```"D[0``#0```+'M```,````O^T```D```#,[0``"0``
M`-;M```*````X.T```<```#K[0``"0```//M```'````_>T```H````%[@``
M&P```!#N``!"````+.X``!(```!O[@``"@```(+N```,````C>X```T```":
M[@``$````*CN```)````N>X``!````##[@``!P```-3N```2````W.X```0`
M``#O[@``!P```/3N```%````_.X```4````"[P``"P````CO```4````%.\`
M`!$````I[P``&@```#OO```6````5N\``!0```!M[P``%P```(+O```8````
MFN\``!P```"S[P``&0```-#O```'````ZN\```4```#R[P``#0```/CO```,
M````!O````D````3\```"````!WP```7````)O````L````^\```$P```$KP
M```$````7O````H```!C\```!````&[P```-````<_````@```"!\```"@``
M`(KP```)````E?````@```"?\```#````*CP```)````M?````D```"_\```
M!0```,GP```'````S_````4```#7\```!````-WP```,````XO```#@```#O
M\```+````"CQ```2````5?$``"D```!H\0``,@```)+Q```E````Q?$```H`
M``#K\0``+````/;Q```N````(_(``#,```!2\@``,P```(;R```X````NO(`
M``\```#S\@``&`````/S```+````'/,``!0````H\P``$````#WS```L````
M3O,``!P```![\P``#P```)CS```3````J/,``!0```"\\P``$@```-'S```4
M````Y/,``!4```#Y\P``+0````_T```M````/?0``#$```!K]```+@```)WT
M```O````S/0``"P```#\]```8@```"GU```3````C/4```@```"@]0``"```
M`*GU```K````LO4``"$```#>]0``&@````#V```<````&_8```D````X]@``
M10```$+V``!!````B/8```0```#*]@``$P```,_V```4````X_8```X```#X
M]@``$P````?W```8````&_<```8````T]P``"0```#OW```*````1?<```\`
M``!0]P``"0```&#W```0````:O<```<```![]P``#@```(/W```%````DO<`
M`!L```"8]P``"````+3W```#````O?<```8```#!]P``%````,CW```1````
MW?<```X```#O]P``.````/[W```"````-_@```8````Z^```#@```$'X```%
M````4/@```<```!6^```#@```%[X```&````;?@```0```!T^```*0```'GX
M```7````H_@``!\```"[^```7````-OX```4````./D``#X```!-^0``'P``
M`(SY```0````K/D```@```"]^0``!P```,;Y```.````SOD```P```#=^0``
M#````.KY```3````]_D```H````+^@``'0```!;Z```9````-/H```4```!.
M^@``$0```%3Z```%````9OH``!$```!L^@``)````'[Z```5````H_H``!(`
M``"Y^@``#@```,SZ```9````V_H```@```#U^@``"0```/[Z```"````"/L`
M``T````+^P``"@```!G[```'````)/L```\````L^P``"P```#S[```*````
M2/L```<```!3^P``"````%O[```%````9/L``!\```!J^P``#0```(K[```&
M````F/L``!````"?^P``"````+#[```-````N?L```@```#'^P``$@```-#[
M```L````X_L``!H````0_```"0```"O\```*````-?P``!4```!`_```$```
M`%;\```%````9_P``!0```!M_```!````(+\```'````A_P``!````"/_```
M!@```*#\```'````I_P``!X```"O_```*````,[\```>````]_P```H````6
M_0``$0```"']```+````,_T``!H````__0``%````%K]```$````;_T```0`
M``!T_0``"P```'G]```%````A?T```8```"+_0``"````)+]```&````F_T`
M``H```"B_0``&P```*W]```T````R?T``#0```#^_0``(````#/^```I````
M5/X``"````!^_@``00```)_^```:````X?X``"@```#\_@``*0```"7_```B
M````3_\```8```!R_P``"````'G_```%````@O\```X```"(_P``"````)?_
M```9````H/\``!D```"Z_P``*@```-3_```C````__\``"X````C``$`-```
M`%(``0`(````AP`!`!<```"0``$`"@```*@``0`'````LP`!`"$```"[``$`
M#````-T``0`-````Z@`!``P```#X``$`$`````4!`0`.````%@$!``L````E
M`0$`!P```#$!`0`3````.0$!``@```!-`0$`"P```%8!`0`*````8@$!`!0`
M``!M`0$`,@```((!`0`+````M0$!``4```#!`0$`!0```,<!`0`7````S0$!
M``\```#E`0$`!````/4!`0`*````^@$!``D````%`@$`"P````\"`0`-````
M&P(!``P````I`@$`#@```#8"`0`%````10(!``0```!+`@$`#0```%`"`0`R
M````7@(!`$4```"1`@$`"P```-<"`0`*````XP(!``\```#N`@$`$P```/X"
M`0`3````$@,!``\````F`P$`#````#8#`0`.````0P,!``T```!2`P$`#0``
M`&`#`0`7````;@,!`!X```"&`P$`%````*4#`0`%````N@,!`!0```#``P$`
M!P```-4#`0`,````W0,!`!````#J`P$`$0```/L#`0`.````#00!`"H````<
M!`$`!@```$<$`0`)````3@0!``\```!8!`$`#````&@$`0`-````=00!`!$`
M``"#!`$`"P```)4$`0`V````H00!``H```#8!`$`(@```.,$`0`+````!@4!
M``\````2!0$`,@```"(%`0`(````504!`!(```!>!0$`#@```'$%`0`%````
M@`4!``X```"&!0$`$P```)4%`0`1````J04!``@```"[!0$`!P```,0%`0`1
M````S`4!``<```#>!0$`%````.8%`0`8````^P4!``<````4!@$`!0```!P&
M`0`,````(@8!``P````O!@$`$@```#P&`0`$````3P8!``<```!4!@$`"@``
M`%P&`0`+````9P8!``P```!S!@$`#@```(`&`0`.````CP8!``4```">!@$`
M!0```*0&`0`N````J@8!`"8```#9!@$`(P`````'`0`#````)`<!`!(````H
M!P$`!@```#L'`0`>````0@<!`!@```!A!P$`)0```'H'`0`-````H`<!``D`
M``"N!P$``P```+@'`0`'````O`<!``H```#$!P$``@```,\'`0`,````T@<!
M`!4```#?!P$`"P```/4'`0`9`````0@!`"`````;"`$`$@```#P(`0`%````
M3P@!``H```!5"`$`%0```&`(`0`2````=@@!``@```")"`$`#````)((`0`'
M````GP@!``L```"G"`$`"@```+,(`0`,````O@@!`%(```#+"`$`%P```!X)
M`0`'````-@D!``8````^"0$`#@```$4)`0`,````5`D!``T```!A"0$`%0``
M`&\)`0`2````A0D!``\```"8"0$`%````*@)`0`;````O0D!`!````#9"0$`
M6````.H)`0`A````0PH!`&D```!E"@$`&@```,\*`0`7````Z@H!`!D````"
M"P$`&@```!P+`0`9````-PL!`"4```!1"P$`)P```'<+`0`:````GPL!`!<`
M``"Z"P$`'0```-(+`0`F````\`L!`!L````7#`$`*@```#,,`0`9````7@P!
M`!\```!X#`$`$P```)@,`0`(````K`P!`$0```"U#`$`$P```/H,`0!`````
M#@T!``<```!/#0$`"````%<-`0`)````8`T!`!4```!J#0$`#0```(`-`0`3
M````C@T!``,```"B#0$`#````*8-`0!&````LPT!`!<```#Z#0$`#@```!(.
M`0`_````(0X!`#<```!A#@$`5P```)D.`0`%````\0X!`!\```#W#@$`+P``
M`!</`0`*````1P\!`!$```!2#P$`"````&0/`0`-````;0\!`"T```![#P$`
M!````*D/`0`5````K@\!`#L```#$#P$`3P`````0`0`?````4!`!`!8```!P
M$`$`)0```(<0`0`H````K1`!`!P```#6$`$`"P```/,0`0`?````_Q`!`!T`
M```?$0$`)0```#T1`0`@````8Q$!`"0```"$$0$`(````*D1`0`P````RA$!
M``L```#[$0$`!P````<2`0`-````#Q(!``P````=$@$`%P```"H2`0`&````
M0A(!`#D```!)$@$`#````(,2`0`'````D!(!``D```"8$@$`$P```*(2`0`)
M````MA(!``0```#`$@$`$````,42`0`(````UA(!``@```#?$@$`!````.@2
M`0`+````[1(!``P```#Y$@$`$@````83`0`1````&1,!``P````K$P$`&@``
M`#@3`0`/````4Q,!``<```!C$P$`#0```&L3`0`4````>1,!``X```".$P$`
M#````)T3`0`;````JA,!`"P```#&$P$`$P```/,3`0`<````!Q0!`"@````D
M%`$`!@```$T4`0`'````5!0!`!,```!<%`$`!0```'`4`0`$````=A0!`!<`
M``![%`$`"@```),4`0`,````GA0!``D```"K%`$`!@```+44`0`)````O!0!
M``@```#&%`$`"0```,\4`0`*````V10!``@```#D%`$`"@```.T4`0`*````
M^!0!``<````#%0$`$0````L5`0`&````'14!``X````D%0$`#@```#,5`0`-
M````0A4!``L```!0%0$`'0```%P5`0`+````>A4!``(```"&%0$`!P```(D5
M`0`&````D14!``D```"8%0$`!P```*(5`0`[````JA4!`"@```#F%0$`-```
M``\6`0`5````1!8!``4```!:%@$`!P```&`6`0`(````:!8!``<```!Q%@$`
M!@```'D6`0`%````@!8!``<```"&%@$`#@```(X6`0`)````G18!``8```"G
M%@$`"````*X6`0`+````MQ8!``<```##%@$`"````,L6`0`'````U!8!`!8`
M``#<%@$`"0```/,6`0`&````_18!``L````$%P$`'````!`7`0`4````+1<!
M``<```!"%P$`"````$H7`0`(````4Q<!``4```!<%P$`$````&(7`0`0````
M<Q<!``8```"$%P$`&0```(L7`0`*````I1<!`!P```"P%P$`!P```,T7`0`%
M````U1<!`!````#;%P$`%````.P7`0`+`````1@!``T````-&`$`%P```!L8
M`0`)````,Q@!``0````]&`$`"0```$(8`0`*````3!@!``<```!7&`$``@``
M`%\8`0`.````8A@!``@```!Q&`$`'P```'H8`0`X````FA@!`",```#3&`$`
M.````/<8`0`Q````,!D!`"<```!B&0$`9````(H9`0`4````[QD!`"0````$
M&@$`(P```"D:`0`K````31H!`"$```!Y&@$`50```)L:`0`X````\1H!`$H`
M```J&P$`6P```'4;`0`H````T1L!`#@```#Z&P$`+P```#,<`0`S````8QP!
M`"@```"7'`$`+````,`<`0`G````[1P!`!L````5'0$`/@```#$=`0`Z````
M<!T!`*D!``"K'0$`(P```%4?`0`7````>1\!`$@```"1'P$`A0```-H?`0`P
M````8"`!`$$```"1(`$`6P```-,@`0!)````+R$!`!T```!Y(0$`&````)<A
M`0`A````L"$!`!\```#2(0$`*P```/(A`0`A````'B(!`"<```!`(@$`'0``
M`&@B`0`1````AB(!`#,```"8(@$`)0```,PB`0`G````\B(!`#(````:(P$`
M'P```$TC`0`P````;2,!`&D```">(P$`/0````@D`0!E````1B0!`$T```"L
M)`$`+0```/HD`0`G````*"4!`"\```!0)0$`*````(`E`0`N````J24!`#``
M``#8)0$`5`````DF`0`G````7B8!`%H```"&)@$`.@```.$F`0!(````'"<!
M`$H```!E)P$`'P```+`G`0`R````T"<!`"\````#*`$`+````#,H`0`M````
M8"@!`'$```".*`$`;P`````I`0"S````<"D!`!<````D*@$`)0```#PJ`0`R
M````8BH!`"D```"5*@$`/@```+\J`0`B````_BH!`%(````A*P$`(@```'0K
M`0`E````ERL!``L```"]*P$`L0```,DK`0`@````>RP!`$4```"<+`$`(0``
M`.(L`0`P````!"T!`"4````U+0$`'````%LM`0`Q````>"T!``<```"J+0$`
M"````+(M`0`'````NRT!``0```##+0$`"@```,@M`0`-````TRT!``L```#A
M+0$`#@```.TM`0`)````_"T!``L````&+@$`!@```!(N`0`%````&2X!`!``
M```?+@$``@```#`N`0!9````,RX!``4```"-+@$`$@```),N`0`$````IBX!
M``<```"K+@$`"````+,N`0`%````O"X!``,```#"+@$`$````,8N`0`,````
MURX!`!,```#D+@$`#0```/@N`0`"````!B\!``<````)+P$`!P```!$O`0`&
M````&2\!`!0````@+P$`#````#4O`0`8````0B\!``8```!;+P$`!````&(O
M`0`2````9R\!``P```!Z+P$`*@```(<O`0`$````LB\!``8```"W+P$`!P``
M`+XO`0`?````QB\!`#4```#F+P$`+@```!PP`0`O````2S`!`!<```![,`$`
M(````),P`0`;````M#`!`!@```#0,`$`)````.DP`0`?````#C$!`!H````N
M,0$`(````$DQ`0`:````:C$!`#(```"%,0$`&0```+@Q`0`O````TC$!`!0`
M```",@$`*P```!<R`0`?````0S(!`",```!C,@$`'P```(<R`0`:````IS(!
M`"4```#",@$`)@```.@R`0`E````#S,!`"0````U,P$`&````%HS`0`=````
M<S,!`"0```"1,P$`&````+8S`0`B````SS,!`"4```#R,P$`&0```!@T`0`\
M````,C0!`!\```!O-`$`(P```(\T`0`?````LS0!`"````#3-`$`&@```/0T
M`0`O````#S4!`!@````_-0$`)@```%@U`0`>````?S4!`"D```">-0$`'@``
M`,@U`0`)````YS4!``P```#Q-0$`%P```/XU`0`O````%C8!`"0```!&-@$`
M!P```&LV`0`/````<S8!`!0```"#-@$`#@```)@V`0`-````IS8!`"0```"U
M-@$`!0```-HV`0`'````X#8!`"(```#H-@$`)0````LW`0`=````,3<!`!H`
M``!/-P$`!P```&HW`0#'````<C<!``L````Z.`$`%0```$8X`0`&````7#@!
M``D```!C.`$`"P```&TX`0`,````>3@!`!<```"&.`$`!@```)XX`0`S````
MI3@!`!,```#9.`$`$P```.TX`0`'`````3D!``\````).0$`!P```!DY`0`R
M````(3D!`"$```!4.0$`$P```'8Y`0`.````BCD!``P```"9.0$`$0```*8Y
M`0`R````N#D!``@```#K.0$`"0```/0Y`0`*````_CD!`!0````).@$`"@``
M`!XZ`0`=````*3H!``@```!'.@$`'P```%`Z`0`(````<#H!`!H```!Y.@$`
M!@```)0Z`0`5````FSH!``<```"Q.@$`"````+DZ`0`)````PCH!`#\```#,
M.@$`!P````P[`0`/````%#L!``X````D.P$`$````#,[`0`)````1#L!``D`
M``!..P$`"````%@[`0`3````83L!``<```!U.P$`"````'T[`0`9````ACL!
M``H```"@.P$`%P```*L[`0`4````PSL!``H```#8.P$`#````.,[`0`7````
M\#L!``0````(/`$`*@````T\`0`1````.#P!``<```!*/`$``@```%(\`0`0
M````53P!`!@```!F/`$`"P```'\\`0`#````BSP!``@```"//`$`"0```)@\
M`0`$````HCP!``<```"G/`$`!P```*\\`0`&````MSP!`!0```"^/`$`!P``
M`-,\`0`-````VSP!``L```#I/`$`%````/4\`0`5````"CT!``X````@/0$`
M+P```"\]`0`@````7ST!`!P```"`/0$`2````)T]`0!,````YCT!``P````S
M/@$`,0```$`^`0`%````<CX!`!(```!X/@$`/P```(L^`0`2````RSX!``H`
M``#>/@$`!@```.D^`0`$````\#X!``0```#U/@$`"@```/H^`0`3````!3\!
M``4````9/P$`!@```!\_`0`&````)C\!``0````M/P$`#````#(_`0`*````
M/S\!``D```!*/P$`!0```%0_`0`8````6C\!`!D```!S/P$`'P```(T_`0`=
M````K3\!`!$```#+/P$``@```-T_`0`$````X#\!``H```#E/P$`!@```/`_
M`0`4````]S\!``4````,0`$``P```!)``0`,````%D`!`$4````C0`$`&@``
M`&E``0`U````A$`!`#H```"Z0`$`*````/5``0!3````'D$!`"\```!R00$`
M0@```*)!`0`P````Y4$!`"X````60@$`&0```$5"`0`G````7T(!`'(```"'
M0@$`(````/I"`0`U````&T,!`"$```!10P$`10```'-#`0`P````N4,!`"D`
M``#J0P$`(0```!1$`0`H````-D0!`"D```!?1`$`)@```(E$`0`E````L$0!
M`"@```#61`$`*````/]$`0`B````*$4!`#````!+10$`$@```'Q%`0`3````
MCT4!`!````"C10$`>0```+1%`0`)````+D8!`',````X1@$`?````*Q&`0`K
M````*4<!`!<```!51P$`%0```&U'`0`6````@T<!``\```":1P$`'P```*I'
M`0!`````RD<!`!\````+2`$`'````"M(`0!1````2$@!`!0```":2`$`"@``
M`*](`0`%````ND@!``8```#`2`$`"````,=(`0`%````T$@!`!(```#62`$`
M$````.E(`0`3````^D@!`!T````.20$`#P```"Q)`0`/````/$D!``\```!,
M20$`#0```%Q)`0`$````:DD!``D```!O20$`"P```'E)`0`%````A4D!``4`
M``"+20$`!P```)%)`0`%````F4D!`!0```"?20$`#@```+1)`0`'````PTD!
M``@```#+20$`#P```-1)`0`-````Y$D!``H```#R20$`"````/U)`0`,````
M!DH!``8````32@$`#P```!I*`0`'````*DH!``8````R2@$`%````#E*`0`&
M````3DH!``8```!52@$`#````%Q*`0`7````:4H!``@```"!2@$`!````(I*
M`0`*````CTH!``,```":2@$`!@```)Y*`0`$````I4H!``H```"J2@$`"@``
M`+5*`0`'````P$H!``0```#(2@$`!````,U*`0`9````TDH!``(```#L2@$`
M"0```.]*`0`&````^4H!``8`````2P$`)P````=+`0`(````+TL!``0````X
M2P$`#P```#U+`0`3````34L!``<```!A2P$`$````&E+`0`3````>DL!``<`
M``".2P$`!@```)9+`0`&````G4L!`!````"D2P$`$@```+5+`0`&````R$L!
M``D```#/2P$`(@```-E+`0`'````_$L!``<````$3`$`"P````Q,`0`3````
M&$P!``4````L3`$`$0```#),`0`"````1$P!``L```!'3`$`!````%-,`0`+
M````6$P!``4```!D3`$`!P```&I,`0#2`0``<DP!``X```!%3@$`%0```%1.
M`0`-````:DX!``<```!X3@$`"````(!.`0`(````B4X!``H```"23@$`"@``
M`)U.`0`+````J$X!`!(```"T3@$`#0```,=.`0`@````U4X!``@```#V3@$`
M!0```/].`0`=````!4\!``P````C3P$`#0```#!/`0`5````/D\!`!````!4
M3P$`"P```&5/`0`,````<4\!`!P```!^3P$`$````)M/`0`(````K$\!`!,`
M``"U3P$`#0```,E/`0`*````UT\!``T```#B3P$`"P```/!/`0`/````_$\!
M``8````,4`$`(P```!-0`0`I````-U`!`!````!A4`$`%@```')0`0`+````
MB5`!``H```"54`$`"0```*!0`0`2````JE`!`!(```"]4`$`"````-!0`0`M
M````V5`!`!D````'40$`.````"%1`0!!````6E$!`%,```"<40$`40```/!1
M`0!9````0E(!`%<```"<4@$`.P```/12`0`"````,%,!``H````S4P$`#@``
M`#Y3`0`6````35,!``4```!D4P$`!@```&I3`0`9````<5,!``P```"+4P$`
M%````)A3`0`7````K5,!``<```#%4P$`)P```,U3`0`F````]5,!`!$````<
M5`$`'P```"Y4`0`/````3E0!`!(```!>5`$`!@```'%4`0`1````>%0!`!``
M``"*5`$`#@```)M4`0`'````JE0!`!0```"R5`$`$0```,=4`0`=````V50!
M`!0```#W5`$`&`````Q5`0`0````)54!``X````V50$`$0```$55`0`*````
M5U4!`"D```!B50$`$P```(Q5`0`7````H%4!`!````"X50$`(P```,E5`0`&
M````[54!``@```#T50$`2@```/U5`0`,````2%8!``@```!55@$`$0```%Y6
M`0`+````<%8!``4```!\5@$`$0```()6`0`3````E%8!`!,```"H5@$`$P``
M`+Q6`0`0````T%8!`!,```#A5@$`$P```/56`0`2````"5<!``P````<5P$`
M'````"E7`0`*````1E<!``<```!15P$`"````%E7`0`/````8E<!``@```!R
M5P$`"@```'M7`0`#````AE<!`!$```"*5P$`&0```)Q7`0`5````ME<!``\`
M``#,5P$`#@```-Q7`0`9````ZU<!`!$````%6`$`"````!=8`0`3````(%@!
M`!`````T6`$`%````$58`0`2````6E@!`"@```!M6`$`#````)98`0`G````
MHU@!`!<```#+6`$`(P```.-8`0`=````!UD!`!(````E60$`$@```#A9`0`.
M````2UD!`!\```!:60$`!@```'I9`0`&````@5D!``@```"(60$`#@```)%9
M`0`'````H%D!``H```"H60$`$0```+-9`0`)````Q5D!``@```#/60$`#P``
M`-A9`0`6````Z%D!`!H```#_60$`"````!I:`0`2````(UH!``4````V6@$`
M%@```#Q:`0`>````4UH!``T```!R6@$`,````(!:`0`)````L5H!``<```"[
M6@$`%````,-:`0`%````V%H!``4```#>6@$`$````.1:`0`+````]5H!`!H`
M```!6P$`,P```!Q;`0`/````4%L!``$```!@6P$`L@```&);`0`F````%5P!
M`#,````\7`$`,0```'!<`0`P````HEP!``4```#37`$`"0```-E<`0`(````
MXUP!``4```#L7`$`"0```/)<`0`(````_%P!`#D````%70$`+0```#]=`0`X
M````;5T!`%,```"F70$`-P```/I=`0`W````,EX!`#8```!J7@$`-P```*%>
M`0`E````V5X!`"H```#_7@$`-P```"I?`0`]````8E\!``\```"@7P$`$P``
M`+!?`0`G````Q%\!`!P```#L7P$`#@````E@`0`+````&&`!``P````D8`$`
M!@```#%@`0`,````.&`!`!H```!%8`$`)@```&!@`0`&````AV`!``<```".
M8`$`%@```)9@`0`)````K6`!``@```"W8`$`!@```,!@`0`(````QV`!``D`
M``#08`$`!@```-I@`0`%````X6`!``4```#G8`$`!P```.U@`0`&````]6`!
M``H```#\8`$`)0````=A`0`/````+6$!``D````]80$`!0```$=A`0`'````
M36$!``<```!580$`!0```%UA`0`-````8V$!``8```!Q80$`$P```'AA`0`#
M````C&$!``@```"080$`"@```)EA`0`-````I&$!``@```"R80$`(P```+MA
M`0`1````WV$!``D```#Q80$`$@```/MA`0`,````#F(!``<````;8@$`#```
M`"-B`0`#````,&(!``,````T8@$`%````#AB`0`)````36(!`!0```!78@$`
M"0```&QB`0`(````=F(!`!$```!_8@$`"0```)%B`0`9````FV(!``@```"U
M8@$`"````+YB`0`'````QV(!`%<```#/8@$`)````"=C`0`=````3&,!``8`
M``!J8P$`!@```'%C`0`7````>&,!``H```"08P$`#@```)MC`0`:````JF,!
M`!P```#%8P$`+````.)C`0`;````#V0!`"X````K9`$`<@```%ID`0`E````
MS60!``H```#S9`$`!P```/YD`0`*````!F4!`!(````190$`"0```"1E`0`1
M````+F4!``\```!`90$`#@```%!E`0`4````7V4!`!````!T90$`%````(5E
M`0`/````FF4!`!4```"J90$`!0```,!E`0`7````QF4!`!L```#>90$`%P``
M`/IE`0`4````$F8!``,````G9@$`!@```"MF`0!H````,F8!``0```";9@$`
M%@```*!F`0`%````MV8!``0```"]9@$`'@```,)F`0`8````X68!``P```#Z
M9@$`&`````=G`0`8````(&<!`"T````Y9P$`*@```&=G`0`:````DF<!``X`
M``"M9P$`(@```+QG`0`(````WV<!`!H```#H9P$`&`````-H`0`3````'&@!
M`!P````P:`$`&````$UH`0`4````9F@!``L```![:`$`"````(=H`0`'````
MD&@!`!````"8:`$`%0```*EH`0`0````OV@!``@```#0:`$`!0```-EH`0`+
M````WV@!``P```#K:`$`"````/AH`0`-`````6D!``<````/:0$`%P```!=I
M`0`&````+VD!`!$````V:0$`"````$AI`0`,````46D!``<```!>:0$`!0``
M`&9I`0`(````;&D!``@```!U:0$`$P```'YI`0`+````DFD!``X```">:0$`
M&@```*UI`0`)````R&D!``4```#2:0$`'0```-AI`0`0````]FD!`!$````'
M:@$`-````!EJ`0!$````3FH!`!\```"3:@$`,0```+-J`0`*````Y6H!``\`
M``#P:@$`!P````!K`0`)````"&L!``\````2:P$`/@```")K`0`)````86L!
M`!$```!K:P$`(0```'UK`0`A````GVL!`"0```#!:P$`)````.9K`0`8````
M"VP!`"$````D;`$`&P```$9L`0`E````8FP!`!H```"(;`$`'0```*-L`0`8
M````P6P!`",```#:;`$`*0```/YL`0`;````*&T!`"8```!$;0$`,````&MM
M`0`N````G&T!`!$```#+;0$`*0```-UM`0`.````!VX!`+`````6;@$`$```
M`,=N`0`8````V&X!`",```#Q;@$`)````!5O`0`?````.F\!`!L```!:;P$`
M(````'9O`0`A````EV\!`"X```"Y;P$`'````.AO`0`>````!7`!`"D````D
M<`$`2P```$YP`0`/````FG`!``0```"J<`$`$@```*]P`0`(````PG`!`!8`
M``#+<`$`#@```.)P`0`.````\7`!`!(`````<0$`"0```!-Q`0`+````'7$!
M`!0````I<0$`"@```#YQ`0`$````27$!``@```!.<0$`#````%=Q`0`/````
M9'$!``\```!T<0$`$P```(1Q`0`,````F'$!`#$```"E<0$`"P```-=Q`0`1
M````XW$!``0```#U<0$`#P```/IQ`0`5````"G(!`!@````@<@$`#P```#ER
M`0`"````27(!``4```!,<@$`%P```%)R`0`2````:G(!``4```!]<@$`"P``
M`(-R`0`,````CW(!``,```"<<@$`"````*!R`0`&````J7(!``\```"P<@$`
M"````,!R`0`8````R7(!``@```#B<@$`$````.MR`0`*````_'(!`!,````'
M<P$`$````!MS`0`3````+',!``@```!`<P$`!@```$ES`0`)````4',!``X`
M``!:<P$`#@```&ES`0`,````>',!`!@```"%<P$`#````)YS`0`.````JW,!
M`",```"Z<P$`#````-YS`0`>````ZW,!`!<````*=`$`8````")T`0`5````
M@W0!``P```"9=`$`!@```*9T`0`&````K70!``X```"T=`$`!0```,-T`0`G
M````R70!`#\```#Q=`$`!0```#%U`0`)````-W4!`!X```!!=0$`"P```&!U
M`0`3````;'4!`!,```"`=0$`!P```)1U`0`(````G'4!`!D```"E=0$`$@``
M`+]U`0`8````TG4!`!````#K=0$`%0```/QU`0`(````$G8!``@````;=@$`
M)@```"1V`0!%````2W8!``T```"1=@$`2````)]V`0`(````Z'8!`!8```#Q
M=@$`!P````AW`0`*````$'<!`#$````;=P$`#P```$UW`0`%````77<!``X`
M``!C=P$`#````')W`0`&````?W<!``,```"&=P$`!P```(IW`0`'````DG<!
M``H```":=P$`$0```*5W`0`,````MW<!``\```#$=P$`#0```-1W`0`-````
MXG<!`!0```#P=P$`&@````5X`0`1````('@!`!D````R>`$`%0```$QX`0`4
M````8G@!``4```!W>`$`!0```'UX`0`+````@W@!``@```"/>`$``@```)AX
M`0`%````FW@!``\```"A>`$`(0```+%X`0`2````TW@!`!````#F>`$`#P``
M`/=X`0`1````!WD!`!X````9>0$`,0```#AY`0`M````:GD!``X```"8>0$`
M!P```*=Y`0`,````KWD!``H```"\>0$`#@```,=Y`0"+````UGD!`!8```!B
M>@$`$````'EZ`0`'````BGH!``4```"2>@$`-0```)AZ`0`A````SGH!``@`
M``#P>@$`!P```/EZ`0`'`````7L!``8````)>P$`$P```!![`0`0````)'L!
M``X````U>P$`$0```$1[`0`/````5GL!`!L```!F>P$`$0```()[`0`-````
ME'L!`!<```"B>P$`!P```+I[`0`)````PGL!`!0```#,>P$`#0```.%[`0`[
M````[WL!`!D````K?`$`"````$5\`0`*````3GP!`!,```!9?`$`#0```&U\
M`0`=````>WP!`!D```"9?`$`(0```+-\`0`@````U7P!`!H```#V?`$`&P``
M`!%]`0`E````+7T!`!H```!3?0$`!0```&Y]`0`=````='T!`!````"2?0$`
M#@```*-]`0`#````LGT!``0```"V?0$`#0```+M]`0`.````R7T!``\```#8
M?0$`%P```.A]`0`+`````'X!``0````,?@$`&````!%^`0`9````*GX!``\`
M``!$?@$`#0```%1^`0`-````8GX!``X```!P?@$`'P```']^`0`&````GWX!
M``@```"F?@$`!@```*]^`0`.````MGX!``X```#%?@$`#0```-1^`0`(````
MXGX!``@```#K?@$`!````/1^`0`4````^7X!``L````.?P$`!0```!I_`0`D
M````('\!``\```!%?P$`:P```%5_`0`:````P7\!``D```#<?P$`!@```.9_
M`0`*````[7\!``8```#X?P$`"````/]_`0`$````"(`!``H````-@`$``@``
M`!B``0`$````&X`!``<````@@`$`%0```"B``0`2````/H`!`!0```!1@`$`
M&@```&:``0`%````@8`!``(```"'@`$``@```(J``0`.````C8`!``8```"<
M@`$`"@```*.``0`*````KH`!``4```"Y@`$`&0```+^``0`(````V8`!``8`
M``#B@`$``P```.F``0`)````[8`!`!<```#W@`$`$`````^!`0`)````(($!
M``<````J@0$`!0```#*!`0`)````.($!``T```!"@0$`!@```%"!`0`&````
M5X$!`!D```!>@0$`"0```'B!`0`+````@H$!``4```".@0$`$@```)2!`0`'
M````IX$!``<```"O@0$`&````+>!`0`=````T($!``<```#N@0$`"@```/:!
M`0`$`````8(!``D````&@@$`"````!""`0`+````&8(!``L````E@@$`!@``
M`#&"`0`-````.((!``8```!&@@$`!````$V"`0`W````4H(!`$$```"*@@$`
M.````,R"`0`F````!8,!``4````L@P$`#P```#*#`0`&````0H,!``@```!)
M@P$`'P```%*#`0`:````<H,!``4```"-@P$`"````).#`0`3````G(,!``@`
M``"P@P$`"0```+F#`0`7````PX,!``8```#;@P$`!@```.*#`0`5````Z8,!
M``4```#_@P$`"P````6$`0`,````$80!``@````>A`$`"0```">$`0`%````
M,80!`"X````WA`$`-````&:$`0`\````FX0!`"<```#8A`$`/@````"%`0`X
M````/X4!`"@```!XA0$`,@```*&%`0`M````U(4!`#4````"A@$`*````#B&
M`0`2````888!`!,```!TA@$`#0```(B&`0`(````EH8!`#$```"?A@$`'```
M`-&&`0`<````[H8!`!H````+AP$`!P```":'`0`(````+H<!``<````WAP$`
M"````#^'`0`F````2(<!`"0```!OAP$`,0```)2'`0`)````QH<!`!@```#0
MAP$`*````.F'`0`6````$H@!`!(````IB`$`!@```#R(`0`+````0X@!``P`
M``!/B`$`#@```%R(`0`/````:X@!`#@```![B`$`@````+2(`0!F````-8D!
M``\```"<B0$`"P```*R)`0`,````N(D!`!$```#%B0$`$@```->)`0`.````
MZHD!``<```#YB0$`'`````&*`0`/````'HH!`!X````NB@$`%````$V*`0`1
M````8HH!``\```!TB@$`'@```(2*`0`P````HXH!`'T```#4B@$`$````%*+
M`0`%````8XL!`!0```!IBP$`"0```'Z+`0`)````B(L!``D```"2BP$`$@``
M`)R+`0`.````KXL!``X```"^BP$`$P```,V+`0`5````X8L!`!\```#WBP$`
M(0```!>,`0`=````.8P!`!\```!7C`$`(````'>,`0`B````F(P!`!@```"[
MC`$`-P```-2,`0`/````#(T!`!$````<C0$`$0```"Z-`0`3````0(T!``T`
M``!4C0$`$@```&*-`0`4````=8T!``\```"*C0$`$0```)J-`0`R````K(T!
M`!8```#?C0$`%````/:-`0`\````"XX!`!0```!(C@$`"@```%V.`0`3````
M:(X!`"(```!\C@$`$@```)^.`0`H````LHX!`!D```#;C@$`&0```/6.`0`7
M````#X\!`!(````GCP$`'P```#J/`0`B````6H\!`!H```!]CP$`$@```)B/
M`0`7````JX\!`!P```##CP$`%@```."/`0`(````]X\!`!@`````D`$`!```
M`!F0`0`%````'I`!``L````DD`$`$````#"0`0`&````09`!``P```!(D`$`
M!P```%60`0`&````79`!``<```!DD`$`!0```&R0`0`(````<I`!`!@```![
MD`$`!@```)20`0`)````FY`!``@```"ED`$`!@```*Z0`0`(````M9`!`!$`
M``"^D`$`$@```-"0`0`/````XY`!`!````#SD`$`"@````21`0`1````#Y$!
M``0````AD0$`(0```":1`0`/````2)$!``\```!8D0$`%@```&B1`0`+````
M?Y$!``D```"+D0$`"P```)61`0`O````H9$!``T```#1D0$`!````-^1`0`(
M````Y)$!``0```#MD0$`!0```/*1`0`1````^)$!``8````*D@$`"@```!&2
M`0`*````')(!``4````GD@$`(P```"V2`0`3````49(!``X```!ED@$`$0``
M`'22`0`,````AI(!`!$```"3D@$`%0```*62`0`7````NY(!`!P```#3D@$`
M&@```/"2`0`,````"Y,!``4````8DP$`!0```!Z3`0`)````)),!`!D````N
MDP$`!P```$B3`0`&````4),!``T```!7DP$`#@```&63`0`'````=),!``<`
M``!\DP$`!0```(23`0`/````BI,!``X```":DP$`"@```*F3`0`0````M),!
M`!(```#%DP$`%````-B3`0`4````[9,!``T````"E`$`%@```!"4`0`(````
M)Y0!`"D````PE`$`!0```%J4`0`2````8)0!`$@```!SE`$`!@```+R4`0`/
M````PY0!`",```#3E`$`#P```/>4`0`5````!Y4!``X````=E0$`#0```"R5
M`0`/````.I4!``D```!*E0$`#P```%25`0`/````9)4!`!$```!TE0$`$```
M`(:5`0`>````EY4!``H```"VE0$`"````,&5`0`&````RI4!``P```#1E0$`
M#````-Z5`0`,````ZY4!``4```#XE0$`#````/Z5`0`)````"Y8!`!X````5
ME@$`9P```#26`0`3````G)8!``L```"PE@$`!0```+R6`0`%````PI8!`!(`
M``#(E@$`%````-N6`0`3````\)8!``L````$EP$``@```!"7`0`*````$Y<!
M`"\````>EP$``P```$Z7`0`%````4I<!`"8```!8EP$`"@```'^7`0`%````
MBI<!``4```"0EP$`$P```):7`0`2````JI<!``8```"]EP$`"````,27`0`'
M````S9<!``0```#5EP$`!0```-J7`0`?````X)<!`&X`````F`$`"@```&^8
M`0`-````>I@!``8```"(F`$`!0```(^8`0`I````E9@!`#(```"_F`$`$0``
M`/*8`0`*````!)D!`!$````/F0$`"@```"&9`0`)````+)D!`!D````VF0$`
M)P```%"9`0`I````>)D!`"@```"BF0$`#P```,N9`0`&````VYD!``<```#B
MF0$`"````.J9`0`&````\YD!``<```#ZF0$`"P````*:`0`.````#IH!``P`
M```=F@$`!@```"J:`0!%````,9H!`!````!WF@$`"@```(B:`0`&````DYH!
M`!P```":F@$`80```+>:`0`&````&9L!``@````@FP$`!@```"F;`0`4````
M,)L!``D```!%FP$`"````$^;`0`I````6)L!`"@```""FP$`"````*N;`0`)
M````M)L!``4```"^FP$`&0```,2;`0`K````WIL!`&<````*G`$`*0```'*<
M`0`N````G)P!`!@```#+G`$``@```.2<`0`-````YYP!``4```#UG`$`%```
M`/N<`0`*````$)T!``4````;G0$`"````"&=`0`&````*IT!``<````QG0$`
M"0```#F=`0`%````0YT!``X```!)G0$`"P```%B=`0`'````9)T!`!8```!L
MG0$`&0```(.=`0`.````G9T!``L```"LG0$`"````+B=`0`+````P9T!``8`
M``#-G0$`#@```-2=`0`0````XYT!`!$```#TG0$`#0````:>`0`/````%)X!
M`!`````DG@$`#P```#6>`0`-````19X!``\```!3G@$`"````&.>`0`>````
M;)X!`$@```"+G@$`$P```-2>`0`(````Z)X!``D```#QG@$`"@```/N>`0`-
M````!I\!``H````4GP$`%@```!^?`0`'````-I\!``\````^GP$`!0```$Z?
M`0`'````5)\!``4```!<GP$`!0```&*?`0`(````:)\!`!$```!QGP$`$0``
M`(.?`0`:````E9\!`!8```"PGP$`%````,>?`0`7````W)\!`!H```#TGP$`
M'P````^@`0`8````+Z`!``,```!(H`$`!0```$R@`0`.````4J`!``X```!A
MH`$`#````'"@`0`6````?:`!`"(```"4H`$`"P```+>@`0`4````PZ`!``<`
M``#8H`$`"@```."@`0`%````ZZ`!`!````#QH`$`"0````*A`0`+````#*$!
M``L````8H0$`"0```"2A`0`.````+J$!``L````]H0$`"0```$FA`0`%````
M4Z$!``<```!9H0$``P```&&A`0`$````9:$!``T```!JH0$`/@```'BA`0`T
M````MZ$!`!0```#LH0$`*@````&B`0!%````+*(!`"H```!RH@$`"@```)VB
M`0`L````J*(!`#,```#5H@$`.`````FC`0`X````0J,!`#T```![HP$`%```
M`+FC`0`:````SJ,!`!````#IHP$`&@```/JC`0`;````%:0!`"X````QI`$`
M*0```&"D`0`<````BJ0!`!L```"GI`$`'P```,.D`0`;````XZ0!`!L```#_
MI`$`#@```!NE`0`P````*J4!`#````!;I0$`-````(RE`0`]````P:4!`#(`
M``#_I0$`+P```#*F`0!R````8J8!`"8```#5I@$`#````/RF`0`*````":<!
M`#,````4IP$`-0```$BG`0`G````?J<!`"T```"FIP$`#0```-2G`0!$````
MXJ<!`#\````GJ`$`!0```&>H`0`;````;:@!`!8```")J`$`$@```*"H`0`1
M````LZ@!`!D```#%J`$`!@```-^H`0`'````YJ@!``D```#NJ`$`#@```/BH
M`0`*````!ZD!`!0````2J0$`#@```">I`0`1````-JD!``@```!(J0$`'@``
M`%&I`0`(````<*D!``0```!YJ0$`!0```'ZI`0`+````A*D!``T```"0J0$`
M"P```)ZI`0`Z````JJD!``(```#EJ0$`!@```.BI`0`.````[ZD!``D```#^
MJ0$`!0````BJ`0`2````#JH!``@````AJ@$`!````"JJ`0`S````+ZH!``X`
M``!CJ@$`*0```'*J`0!0````G*H!`!4```#MJ@$`.@````.K`0`@````/JL!
M``\```!?JP$`"0```&^K`0`(````>:L!``\```""JP$`#P```)*K`0`*````
MHJL!`!0```"MJP$`#````,*K`0`:````SZL!`!4```#JJP$`!P````"L`0`1
M````"*P!``@````:K`$`$0```".L`0`A````-:P!`!0```!7K`$`$@```&RL
M`0`0````?ZP!`",```"0K`$`!P```+2L`0`+````O*P!``(```#(K`$`%```
M`,NL`0`2````X*P!`!$```#SK`$`&@````6M`0`0````(*T!``P````QK0$`
M!P```#ZM`0`(````1JT!``4```!/K0$`(0```%6M`0`-````=ZT!``8```"%
MK0$`$0```(RM`0`(````GJT!``X```"GK0$`!0```+:M`0`/````O*T!`"\`
M``#,K0$`$@```/RM`0`&````#ZX!``<````6K@$`%P```!ZN`0`7````-JX!
M``8```!.K@$`$@```%6N`0`%````:*X!``0```!NK@$`%0```'.N`0`$````
MB:X!``<```".K@$`%@```):N`0`Q````K:X!`"````#?K@$`!0````"O`0`2
M````!J\!``4````9KP$`$P```!^O`0`0````,Z\!``0```!$KP$`#@```$FO
M`0`(````6*\!``<```!AKP$`"@```&FO`0`(````=*\!``8```!]KP$`!0``
M`(2O`0`@````BJ\!`#4```"KKP$`-0```.&O`0`;````%[`!`"0````SL`$`
M(P```%BP`0`_````?+`!`!L```"\L`$`)@```-BP`0`M````_[`!`"0````M
ML0$`!@```%*Q`0`(````6;$!``D```!BL0$`$````&RQ`0`+````?;$!`!<`
M``")L0$`$````*&Q`0`N````LK$!`"0```#AL0$`-`````:R`0`X````.[(!
M`!$```!TL@$`(@```(:R`0`2````J;(!``8```"\L@$`&P```,.R`0`-````
MW[(!``\```#ML@$`#0```/VR`0`2````"[,!`!$````>LP$`#0```#"S`0`'
M````/K,!``X```!&LP$`"````%6S`0`+````7K,!``P```!JLP$`&P```'>S
M`0`T````D[,!``D```#(LP$`!0```-*S`0`)````V+,!`!H```#BLP$`$0``
M`/VS`0`$````#[0!``H````4M`$`"P```!^T`0`0````*[0!``X````\M`$`
M#````$NT`0`6````6+0!``4```!OM`$`!0```'6T`0`/````>[0!`"P```"+
MM`$`2P```+BT`0`0````!+4!``D````5M0$`#0```!^U`0`2````+;4!`!(`
M``!`M0$`#0```%.U`0`.````8;4!`!````!PM0$`#@```(&U`0`.````D+4!
M`!8```"?M0$`'0```+:U`0`:````U+4!``4```#OM0$`$````/6U`0`'````
M!K8!``P````.M@$`$@```!NV`0`3````+K8!`!$```!"M@$`+````%2V`0`)
M````@;8!``P```"+M@$`$P```)BV`0`.````K+8!`!$```"[M@$`%0```,VV
M`0`-````X[8!`#D```#QM@$`"0```"NW`0`=````-;<!`!,```!3MP$`%P``
M`&>W`0`O````?[<!``<```"OMP$`$0```+>W`0`/````R;<!`!$```#9MP$`
M%P```.NW`0`>`````[@!`"$````BN`$`!P```$2X`0`(````3+@!`!(```!5
MN`$`!P```&BX`0`4````<+@!`!H```"%N`$`!P```*"X`0`'````J+@!`!``
M``"PN`$`#P```,&X`0`1````T;@!``4```#CN`$`"````.FX`0`-````\K@!
M``T`````N0$`#@````ZY`0`0````';D!`!`````NN0$`!@```#^Y`0`(````
M1KD!`"X```!/N0$`)@```'ZY`0`D````I;D!``<```#*N0$`#@```-*Y`0`&
M````X;D!`!<```#HN0$`%P````"Z`0`B````&+H!``H````[N@$`"P```$:Z
M`0`#````4KH!``8```!6N@$`#````%VZ`0`"````:KH!``P```!MN@$`$P``
M`'JZ`0`+````CKH!`!D```":N@$`(````+2Z`0`2````U;H!``4```#HN@$`
M"@```.ZZ`0`5````^;H!`!$````/NP$`!@```"&[`0`.````*+L!``D````W
MNP$`$0```$&[`0`.````4[L!`!````!BNP$`2@```'.[`0`7````OKL!``0`
M``#6NP$`"````-N[`0`4````Y+L!``X```#YNP$`#`````B\`0`B````%;P!
M`!<````XO`$`#0```%"\`0`C````7KP!`!P```""O`$`#0```)^\`0!*````
MK;P!`"````#XO`$`8@```!F]`0`B````?+T!`!8```"?O0$`%@```+:]`0`<
M````S;T!`!<```#JO0$`(0````*^`0`K````)+X!`"````!0O@$`%````'&^
M`0`B````AKX!`",```"IO@$`'@```,V^`0`P````[+X!`!8````=OP$`'P``
M`#2_`0`8````5+\!``H```!MOP$`20```'B_`0`/````PK\!`$,```#2OP$`
M!P```!;``0`'````'L`!``0````FP`$`$P```"O``0`-````/\`!`!$```!-
MP`$`"````%_``0`6````:,`!`$$```!_P`$`%P```,'``0`6````V<`!`#P`
M``#PP`$`0@```"W!`0!@````<,$!``D```#1P0$`/@```-O!`0`O````&L(!
M``H```!*P@$`$@```%7"`0`*````:,(!``X```!SP@$`.P```(+"`0`(````
MOL(!`!L```#'P@$`20```./"`0`X````+<,!`"@```!FPP$`'P```(_#`0`N
M````K\,!`"@```#>PP$`(@````?$`0`/````*L0!`"D````ZQ`$`&````&3$
M`0`P````?<0!`"(```"NQ`$`*````-'$`0`B````^L0!`#,````=Q0$`#P``
M`%'%`0`(````8<4!``X```!JQ0$`#P```'G%`0`0````B<4!``<```":Q0$`
M/0```*+%`0`,````X,4!``X```#MQ0$`!@```/S%`0`5`````\8!``@````9
MQ@$`"````"+&`0`/````*\8!``D````[Q@$`"0```$7&`0`'````3\8!`!``
M``!7Q@$`$````&C&`0`6````><8!`!<```"0Q@$`$0```*C&`0`;````NL8!
M`!,```#6Q@$`"````.K&`0`-````\\8!``P````!QP$`#P````['`0`,````
M'L<!`!D````KQP$`+````$7'`0`/````<L<!`!\```""QP$`*````*+'`0`(
M````R\<!``8```#4QP$`$````-O'`0`)````[,<!``0```#VQP$`&````/O'
M`0`.````%,@!`!`````CR`$`#@```#3(`0`%````0\@!``D```!)R`$`"```
M`%/(`0`)````7,@!``T```!FR`$`"````'3(`0`+````?<@!``L```")R`$`
M!0```)7(`0`1````F\@!``0```"MR`$`#@```++(`0`%````P<@!``L```#'
MR`$`#@```-/(`0`A````XL@!``H````$R0$``@````_)`0`'````$LD!``4`
M```:R0$`"P```"#)`0`'````+,D!`#(````TR0$`)````&?)`0`Q````C,D!
M`!<```"^R0$`!0```-;)`0`'````W,D!``<```#DR0$`#````.S)`0`&````
M^<D!``@`````R@$`#0````G*`0`3````%\H!``\````KR@$`#````#O*`0`.
M````2,H!``L```!7R@$`!P```&/*`0`(````:\H!``@```!TR@$`%@```'W*
M`0`)````E,H!``<```">R@$`"0```*;*`0`@````L,H!``4```#1R@$`!@``
M`-?*`0`&````WLH!``H```#ER@$`!P```/#*`0`2````^,H!`!(````+RP$`
M!@```![+`0`6````)<L!``L````\RP$`&P```$C+`0`$````9,L!``@```!I
MRP$`#P```'++`0`<````@LL!``<```"?RP$`"0```*?+`0`5````L<L!``D`
M``#'RP$`!````-'+`0`*````ULL!``\```#ARP$`"@```/'+`0`"````_,L!
M`!$```#_RP$`!P```!',`0`>````&<P!`"T````XS`$`'@```&;,`0`S````
MA<P!`"4```"YS`$`*0```-_,`0!=````"<T!`!,```!GS0$`&P```'O-`0`9
M````E\T!`"8```"QS0$`&0```-C-`0!4````\LT!`"X```!'S@$`00```';.
M`0!>````N,X!`"`````7SP$`2@```#C/`0`E````@\\!`#(```"ISP$`*```
M`-S/`0`R````!=`!`",````XT`$`'0```%S0`0`L````>M`!`"4```"GT`$`
M[@$``,W0`0`;````O-(!`!0```#8T@$`1@```.W2`0"%````--,!`#\```"Z
MTP$`,0```/K3`0!+````+-0!`#@```!XU`$`'````+'4`0`5````SM0!`!@`
M``#DU`$`%P```/W4`0`K````%=4!`!P```!!U0$`'P```%[5`0`3````?M4!
M``P```"2U0$`+P```)_5`0`>````S]4!`!\```#NU0$`,P````[6`0`A````
M0M8!`$(```!DU@$`4````*?6`0`U````^-8!`&$````NUP$`1@```)#7`0`K
M````U]<!`"@````#V`$`+P```"S8`0`E````7-@!`"<```""V`$`+````*K8
M`0!'````U]@!`"4````?V0$`4````$79`0`Y````EMD!`$$```#0V0$`3@``
M`!+:`0`=````8=H!`"T```!_V@$`)0```*W:`0`E````T]H!`"8```#YV@$`
M:@```"#;`0!H````B]L!`*X```#TVP$`&P```*/<`0`J````O]P!`#8```#J
MW`$`+P```"'=`0!%````4=T!`"````"7W0$`40```+C=`0`B````"MX!`"$`
M```MW@$`"P```$_>`0"U````6]X!`!T````1WP$`/````"_?`0`B````;-\!
M`"H```"/WP$`*P```+K?`0`<````YM\!`"\````#X`$`!@```#/@`0`'````
M.N`!``8```!"X`$``P```$G@`0`/````3>`!``X```!=X`$`"P```&S@`0`*
M````>.`!``\```"#X`$`"P```)/@`0`&````G^`!``4```"FX`$`#````*S@
M`0`$````N>`!`&X```"^X`$`!````"WA`0`6````,N$!``0```!)X0$`!P``
M`$[A`0`%````5N$!``4```!<X0$`!````&+A`0`0````9^$!``@```!XX0$`
M$0```('A`0`3````D^$!``(```"GX0$`!0```*KA`0`'````L.$!``<```"X
MX0$`%````,#A`0`,````U>$!`!8```#BX0$`!@```/GA`0`#`````.(!`!,`
M```$X@$`#````!CB`0`H````)>(!``0```!.X@$`!@```%/B`0`(````6N(!
M`!L```!CX@$`-````'_B`0`G````M.(!`"@```#<X@$`$P````7C`0`@````
M&>,!`!T````ZXP$`&P```%CC`0`@````=.,!`!L```"5XP$`&@```+'C`0`B
M````S.,!`!0```#OXP$`,0````3D`0`6````-N0!`"\```!-Y`$`$````'WD
M`0`F````CN0!`!H```"UY`$`'@```-#D`0`>````[^0!`!D````.Y0$`(P``
M`"CE`0`=````3.4!`"@```!JY0$`&@```)/E`0`;````KN4!`"````#*Y0$`
M(P```.OE`0`9````#^8!`"$````IY@$`'@```$OF`0`:````:N8!`#8```"%
MY@$`'@```+SF`0`B````V^8!`"(```#^Y@$`(P```"'G`0`=````1><!`"<`
M``!CYP$`&````(OG`0`B````I.<!`"$```#'YP$`,@```.GG`0`@````'.@!
M``H````]Z`$`"P```$CH`0`6````5.@!`"@```!KZ`$`'0```)3H`0`*````
MLN@!``\```"]Z`$`%P```,WH`0`.````Y>@!`!8```#TZ`$`(0````OI`0`(
M````+>D!``<````VZ0$`(@```#[I`0`E````8>D!`"4```"'Z0$`%@```*WI
M`0`*````Q.D!`-P```#/Z0$`$0```*SJ`0`5````ONH!``P```#4Z@$`#P``
M`.'J`0`6````\>H!`!,````(ZP$`(P```!SK`0`&````0.L!`$````!'ZP$`
M%0```(CK`0`4````GNL!``<```"SZP$`$P```+OK`0`*````S^L!`#<```#:
MZP$`*0```!+L`0`6````/.P!`!0```!3[`$`%````&CL`0`4````?>P!`#$`
M``"2[`$`$0```,3L`0`2````UNP!`!,```#I[`$`$0```/WL`0`*````#^T!
M`!<````:[0$`"````#+M`0`@````.^T!``@```!<[0$`$P```&7M`0`'````
M>>T!`!$```"![0$`!P```)/M`0`(````F^T!``D```"D[0$`-@```*[M`0`%
M````Y>T!``\```#K[0$`%````/OM`0`1````$.X!``L````B[@$`#````"[N
M`0`'````.^X!`!,```!#[@$`"P```%?N`0`,````8^X!`!L```!P[@$`$```
M`(SN`0`:````G>X!`!<```"X[@$`"P```-#N`0`,````W.X!`!@```#I[@$`
M"0````+O`0`J````#.\!`!$````W[P$`"@```$GO`0`"````5.\!`!````!7
M[P$`%P```&CO`0`+````@.\!``,```",[P$`"@```)#O`0`&````F^\!``4`
M``"B[P$`"````*CO`0`(````L>\!``4```"Z[P$`%P```,#O`0`'````V.\!
M``P```#@[P$`"P```.WO`0`4````^>\!`!4````.\`$`#@```"3P`0`X````
M,_`!`!@```!L\`$`&````(7P`0!-````GO`!`$L```#L\`$`"@```#CQ`0`E
M````0_$!``4```!I\0$`%@```&_Q`0`\````AO$!``T```##\0$`#@```-'Q
M`0`&````X/$!``0```#G\0$`!````.SQ`0`*````\?$!`!<```#\\0$`!0``
M`!3R`0`&````&O(!``@````A\@$`!0```"KR`0`4````,/(!`!4```!%\@$`
M#@```%OR`0`%````:O(!`!<```!P\@$`'@```(CR`0`?````I_(!`!H```#'
M\@$`$````.+R`0`"````\_(!``0```#V\@$`"P```/OR`0`%````!_,!`!<`
M```-\P$`!0```"7S`0`#````*_,!``X````O\P$`3````#[S`0`<````B_,!
M`"H```"H\P$`/````-/S`0`F````$/0!`$X````W]`$`+@```(;T`0`_````
MM?0!`"T```#U]`$`+````"/U`0`?````4/4!`!T```!P]0$`70```([U`0`=
M````[/4!`$<````*]@$`(````%+V`0`Q````<_8!`#,```"E]@$`*@```-GV
M`0`H````!/<!`"@````M]P$`-````%;W`0`V````B_<!`#0```#"]P$`,```
M`/?W`0`H````*/@!`"(```!1^`$`.````'3X`0`4````K?@!`!4```#"^`$`
M#@```-CX`0!A````Y_@!``H```!)^0$`8P```%3Y`0!I````N/D!`"<````B
M^@$`&P```$KZ`0`7````9OH!`!@```!^^@$`$0```)?Z`0`=````J?H!`#D`
M``#'^@$`(@````'[`0`;````)/L!`&H```!`^P$`%@```*O[`0`*````POL!
M``0```#-^P$`!@```-+[`0`(````V?L!``4```#B^P$`%0```.C[`0`2````
M_OL!`!D````1_`$`(P```"O\`0`3````3_P!``\```!C_`$`#0```'/\`0`)
M````@?P!``0```"+_`$`"0```)#\`0`-````FOP!``@```"H_`$`!P```+'\
M`0`(````N?P!``D```#"_`$`%@```,S\`0`6````X_P!``L```#Z_`$`"@``
M``;]`0`5````$?T!``H````G_0$`#0```#+]`0`)````0/T!``8```!*_0$`
M!0```%']`0`3````5_T!``D```!K_0$`"@```'7]`0`6````@/T!``4```"7
M_0$`"@```)W]`0`'````J/T!`!8```"P_0$`"````,?]`0`(````T/T!``P`
M``#9_0$``P```.;]`0`(````ZOT!``,```#S_0$`#````/?]`0`,````!/X!
M``8````1_@$`!@```!C^`0`"````'_X!`!D````B_@$``@```#S^`0`(````
M/_X!``8```!(_@$`!@```$_^`0`I````5OX!``@```"`_@$`!0```(G^`0`3
M````C_X!`!D```"C_@$`"````+W^`0`.````QOX!`!````#5_@$`!P```.;^
M`0`&````[OX!``H```#U_@$`$`````#_`0`9````$?\!``@````K_P$`#```
M`#3_`0`C````0?\!``H```!E_P$`"0```'#_`0`0````>O\!`!,```"+_P$`
M!0```)__`0`5````I?\!``(```"[_P$`"P```+[_`0`%````RO\!``\```#0
M_P$`!0```.#_`0`&````YO\!``$```"O!@```@0``#(#```9!````````/4"
M``#3`0``E@,````````T`0``\`0````````B!@``N0,``#D#````````$P$`
M``````"C`P``)@````H#`````````````*`'``#M`P``R@```+P"```F`@``
M`````/P%``#&`P``OP,````````Z`@``Y08```````#+`0```````$H%```H
M````_`8````````(`0``*@0``(H#```0`P``:08``#<#``#K`P```0,`````
M``"#`@``+`,``","`````````````!D&```[`@``]P4``!H'``#2!@``>P``
M```````9`0``/P0``%X&``"_`0````````<!``!)!```UP,```````":````
M`````$\!``#A`P``10```!P!````````Y`8````````D!@```````/H"``#Q
M`````````(T!````````,0<```````!:!P``7`````````!>````&`(``"D!
M```Z!```S`4``,<&``"I``````````4'``!U`0``*`8``"4&``!&````;P,`
M`'L#``!:`0``JP$```T#``",`P``A`<``&@!``!-`@```````'P%``!_`0``
M.P```"L&``#_````;0,``)P```````````````````"(`0``5`$```````!;
M!@``20$``,@%```K!P``K@0``!8%``#1!```#`4``%<$```I````!0```,@$
M`````````````)H$```Z!P```````,0&``!4!0````````````#)````=@0`
M``X%```X!@``^0(``%8#``!Y!````````#($```R`0````````````#N!```
M,`4``"$"```S`0``QP(``(P!```#!P```````.,$``#1`P```````/T%````
M`````````-<"````````,@````````"7`@``I@0```````````````````$"
M````````D0``````````````1`<``'$#``#_`0``0`8```````#Z`0``QP``
M`"4"``"7`0```````*`%``"P````2@```.L````M`0``,0```)P%``!V`0``
M``````````"-!```^08``'```````````````,("``"@`P``2````(L$```W
M!```]0$``-8`````````'P4``*$```#"!@``Z08``$`"````````1@<``'@`
M``!5`P``?0,``$(!```J`0``H08``*,````]````>`,``!T&``!8!```(`4`
M`+4```";!P``JP0``%<#``#"!0```00``#T!``"``0``U0$``'<!```F`0``
M`````#P#```"`@``H@,``(X```#.`0``,@(``*H`````````(`,``+P#``!O
M!0``*`(``*X"``#L````;@$``#4`````````\`,``/`!```X!P``I04``$D#
M````````@P,```\!``#9!````````&\$``"#!@``$@,``,,````&`@``````
M`*,$`````````````.($````````&0<``*8!````````YP(``!H```#-````
MA`(``&$$``!$!```S```````````````DP(`````````````L@8``%D&````
M````V`$``%D$````````[P0```````!P`0``G0```%`!```Z!0``400`````
M``#O`@```P```*0$``!R`@``%0<```````#;!0``$P```)8&```X`P``G04`
M`/L"``#%`P``T`0``/,#``#E````P@```(<!````````/0,``!D"````````
M`````'X"```&!```B@<``"8#````````L0$```L&``!Y`@```````&8```"D
M`P```````%`'``!F!0````````P"``"3!P``=@8``)T!```Z``````````@#
M``#@`0``;@,``'(```"(`@``9`8```````#2!0``)00``*(&````````'@,`
M`.X&``"?!0``M04`````````````^@,``(`%``"G!@``#P8``((```!X!P``
MX`````````#5!@`````````````.`P``9`<``(<'````````0P0```````!B
M!0``&@(````````B`0``_`$``*T#````````?@4``$4%``"R`P``;P<`````
M````````]@0``%`%``"F`@``B`,``+@!``!_!@``.`0``*4!``##!0``````
M`````````````````$8!``#]!`````````````!>!P```````!(&``#0!@``
M$P<``%H%``"Y`0``&P4```<%```6`@```````#P'````````$0(``"\%``"Q
M!```:0(``/L&``#<!@```````/$$```:!0``:0````````""!@``L`8``.\`
M````````@0```(P$````````HP$``-P#```+`@```````(<&``"Z`@``=@,`
M`$4"``#*!```DP0``$$"`````````````'$$```N!```]@````````#(`P``
M;````'('````````!`8``-4`````````&`0``!0```!L!P``X00``'X#````
M````XP(```````")!0``TP0``*$#`````````````.(&```<!@``Q0``````
M``#W`P```````"("``#R!@``C````/@"```H`0``5P8``*0!``"F````#@``
M`/$!``!K!P``!@$``.D#``"G````80```#,&`````````````&L&``#R!```
M"04``.L%```R!0``^@8````````+!```E@$``$<%``!'!```/@8````````>
M`@````````````````````````````"!`0`````````````3!@``V````"H'
M```D`P``!0,``&4%``#[````Z`,```````!H`@``8@(```````!!`0``80<`
M```````5!```70$``"D'```>!@``$`<``$H&`````````````!0'``"^`@``
M`````%X!``#+!@``4P4``!T`````````%`,``($'``#L!0````````````"S
M`P``1````(,!``"Y`@```````#$%``"H!0``5`8``%\#````````W@0```T"
M``"3`P````````````!;!```F0,``%T'``##`0``QP$``$@#````````````
M``````!+`0``$0,``#H&``"S`0``"@4``/L$````````?`<``#8$```8!0``
M```````'``#;`0```````&L%```B`P``H00``(T#``"Z`````````&0```#L
M`P```````)H!``!?!@``V`4``$\'``#8!@``Z@$``+\"````````)04``*@#
M```O`0``;0```$T!```````````````````N`0``2@(``)0#````````]P0`
M`"$%````````V`0```````"2!@``E`0```````">`P``N0````````!\`P``
M``````(#```D!```F0(````````G!P```````````````````````,0"``"]
M`0``@P4``,,#``#0`0``YP,``*\#``"B`0``WP``````````````NP(``-\%
M```4`@``E00``/D!``"!`@``@`,``)8%````````9@$``,H"```V!@``'@$`
M`-`%``#&`0``'`<``)8'``#/`P``T0(```\"````````-08``)X"``";!@``
M>`$``'\#``#:!0``R08`````````````P0(``!0&`````````````*X%````
M````K00```````#7!```4P,``!\!``"<!P```````,D"``!(!```0@```.T`
M```W`@``9@8``&X`````````1`,```L```!``0```````*`"````````X04`
M`+T"````````L08``#P$``""!0```````"`!````````<P(``$,`````````
M:@0``/H$`````````````)$!``!@`0```````)H"````````X08```0'```/
M!0``6`<``/(#```D!0``4@```"H```#P````90```.$```#F`P``2`8```@&
M``!.!0```````(D#```9`P``4@,`````````````EP4``'\'````````P`(`
M`#4$``#%`@``5@4```````#<``````````````#"`0``R@,``.\%``#J`P``
M-`,``/0```"*`0```````,\"````````XP4``&(``````````````!<%``!*
M!P``%08```````")!P``4P$``,X#``#T!@``MP4```````"@!@``+`8`````
M``#T!0``H`$``.T%``">!0``Q`,``+X$``!,!@``#@<``"@%``#`!0``-@$`
M`'\%``"+!P``<P4``'@$`````````````(<%```3!```A@<``.(!``"P!```
MNP,``"T&``!B!@``R`8``#L$```9!0``OP4``,D!``!+!0```````&`#````
M````+P0``-0"``#^!@````````````!Z````KP```,\```#F`````````*8%
M``!@!P``+0,``)P&````````F04``.D$`````````````%($``!-!0``````
M`%$#``!L`P```````-,%``"2`0``B@8``,$!``!#!@``V`(``-4%``#*`0``
MM`$```$!``":!@``"P4```````",!P``B0(``"P!``"T!@``D`0```D'``"C
M!P``_`,``#(&```?!P```````-4#``!U!```]P(```````#J`@``>@8``%H$
M````````KP$``.<!``!P!@``W@$```<&``!5!````````*@!``#=`@``E0$`
M`.4#``!.`0``^P$``*L"``"1!@```````)<'````````[@$``&8$```.`@``
M``````````"=!@``S0$```````"G!0``4`0``#L&``!+```````````````T
M!P``I`<``-\&```5`@```````,8&``"&`0``LP(````````P!P``T`(``)4#
M````````!``````````#`@``A0``````````````>0```)\!``!H!```Y`(`
M``````#F!```%0,```````#=`0```````(4"````````K@````````"\````
MN@,``/X!``!W`P``2`$``/@%````````9@<``+<$`````````````.`$``!:
M`P``G@<```````"%!```B`````````"R`@````````````#X!````````!\$
M``#C`0``>0<``/@#```J`@````````````"P!0``'0,``/\"``#&````K@,`
M`)$"``"L!0```````*@&``"I`0``?0$``'0!```O`@```````)<```!G!```
MKP(``",$``";!0``SP4``,L#`````P``3P8```````"0!P``00```%D"``"B
M!P``F`$``$,!``!0`P``DP4``(D$``#:!```900``%0#``"8!P``8P(``&($
M``!S!P``EP,````````1!@``)`$``````````````````'(!``!-`P``O00`
M`(@%````````6`4``/,"`````````````(,$``"<`@``Y`$```````#T`@``
M^0,```0"``#C````:P0``"@$``#?!```(@<``$\%```)`@``VP(```$'``#1
M`0``\0,`````````````?04``/T````D!P``-0<``#\!````````EP0``*L%
M``#&`@``-`8``/P```!O`@``^0```$X"```V````-@,``'$'```@!@``E`8`
M`$X#````````D`(``/@```#8`P```````"($```8`P``O08`````````````
M`````-0&``#U!@``10,``.(#``#_!```^`$````````T````9P```,H&``!Z
M!```0@(``%$````&`P```````$('``#<!0````````````"E!@``LP8``-0$
M````````5@0``+8```!N!0``0@8``,P&``!E!P``4@4`````````````````
M`&H````9````<P$``*4'```$!```D@0```````!)````N@0``%P&````````
M_0(``.<&``"D````0@0``+D&``"'````Z`0``(0```"E`````````%@#``">
M`0``-@4``+0%``!<`@``#P<````````X!0``*P0``/\%```$!0``*@,``#<!
M````````&P8```````"V`0````````````!]!P``E0```'X````2````7P4`
M``````!,!0``(`0``+X%``"[!0``?08````````I`P``1@,```0#``#F`0``
M`````#T'````````:0<```X$```Y!@``7P$```,$``"``@```@$````````_
M`P````````````#R`0``+00``"4'```Q`@``7P<``)H%````````/P8``#@"
M``````````````````!*!`````````````!T`P``````````````````_0$`
M``````!2`@```08``.0%``!5`````````*L#``!D!0```````"X&```0!```
M)P```)`#``#]!@``;0(````````=`0``>`(``'`$```(````\P``````````
M````A04``#D!```3`@`````````````7`P``+`4``&<"````````````````
M``!@````N00``*X&``"Z!0``/`$``$$$``!#!0``3P(``.0#````````````
M`"(`````````W`0```````!C!@```````!$!```:!@``#`$``$`'``!I!```
MGP,``"H%````````X`,``*4"``!;!P``Z`$``"4#``````````````````#9
M`0``M00``(H````7````<04````````%!````````"8$```$`0``G0<``%X"
M```%`@``+@<``.D%````````1`8``!T$``!\!```2P(``$4!``!P!P``$`8`
M`$8"````````!08``#T&```)`0```````"P"``"8!```=0,`````````````
MHP(``````````````````````````@``%0```(H"``!<!```MP,``'T"``#-
M!```X0(``#4%``";`0```````)$%````````3`<``&H%``#T`0``:`,``&$&
M``!M!````````!<&```^`@```````"D$``!!!@``_0,``#L%```M````M```
M`",`````````/````/X$``!V!0``604``',&`````````````(L#``#M`0``
M9`,``(D!````````KP4``$8&``#^`@``(P<``(('```%!0``(0,``-(````^
M!P``>P$```````#O`0``^`8``+P&```7`0``K`0``$8$``#1!@``NP$`````
M``#'`P``<P0``*H%```M!P````````````!=!0``@08```````#V`0``'`4`
M``````"-!@```````-4$`````````````````````````````+8#``#E`0``
M"08``!P$``"@!```;`4````````B!0``>0$``#T%``"U`@``%@8``'L"````
M`````````+$"````````VP8```````#$!```N````/,%````````N`4`````
M``!G`0``,```````````````-P8``````````````P8``+$%```O!@``````
M`(8#``#;````?`8``&4&``"P`P``U@4```````!?````T````*@```"\`0``
MK`,```````!P`P``4P<``*````"9!P``5`<``&`$``!^!@``Z`4```H```!'
M!P``P`,``&,#``#7`0``504``-4"``#/!@``D0<``.4$``">!@``?P0``$8%
M``#9`P``3`,``#@!````````7`4``"T%``"*!```\P$``&L"```Y!0``.P$`
M`/8&``#B````#0$``/4%````````P04``"L%``!_`````````),&```/````
M`````!(!``#7````7@,``.D"```(!`````8``(4&``!Z`@``'0(``(T'````
M````0P,``,@```"A`@``$@4``)\"``")!@``S`(`````````````B@4``$,"
M````````<0```!0$````````#P0``-,"````````<`4``"<%``#T`P``````
M``````#9`@``A0,``&T!````````>08```````!W````IP0``+4!``"[!@``
MS0(``&@%``"8````8@<```````"$!@``RP0```````!G!@```````&,%``#!
M`P``BP8```4!`````````````*(```";`P``M0,``(````!Q!@``]`0``%,&
M````````K@$``,($````````-`(``%T```!)!@``M08````````0!0``!@8`
M`)T#`````````````+P%``#B`@```````&\```````````````(&``#N!0``
M!P(``-\!``!\````;P$``,8%`````0``O04```````"4!P``M@(``&,$````
M````<@,``(<#``!6````#`,```<#````````6P````````!;!0``P`$`````
M````````Y04``-8&```+`P``(0$``````````````````(@$``#7!0``3@``
M`#4!``"G`0``9`$``,<$````````=08``,P$````````A`$``+,```!'!@``
M``````````!7!0``,`$``"@#``!T`@``;`8``#('``"6`@``GP```'H!``!6
M!P``G@0```````".`P``2@$``!@'``#C!@``+0(``'<$````````$@(``(\"
M``!`````7P0```````"&`@````````````#V`P``>P8``&T&```1!P``CP<`
M`!\"````````R@4``#\"``"P`@``>P<``#<%``"8!@```````,`$``#>!0``
M`````.@&``"[````;@<``)`!````````^@```(X"```Y!```L@```!H#```W
M````M`(```````"I!0```````-X"``!_`@``M@0``,```````````````.`"
M``#1!0``)P8``````````````````#X#`````````````-0!``!G!0``>P0`
M``````"$!0``>0,```````"V!0``60,``,T%``````````````H$``!9`0``
M``````````"`!```8`(``-`#``!U!P``>@,``-0#``"]`P``E0<``*("````
M````KP0``%L!``!,`@``:`8``-X&``#^!0``RP4``%`&``"D!@``)```````
M``!)!P``U@(``%,```#=!@``=P<``#X```#6!``````````````-!P``8P``
M``````!0`@``J00``!T%``!+`P``[`0````````6`````````)\$``"-````
M;@(``/<`````````FP(``.L"``#<`@```````)`%``#(`0``"@$`````````
M`````````+H!``!W!0``V0````L!```]`@``(0```($%``!D`@``9@,`````
M```A!@```````&`%```L!```W`$```````!R!```J`0`````````````6@8`
M``('``!!!P``9`0``#D"``"5!@````````````#P!0```````(\#``!E`P``
MD@<``(\!`````````````$(#``"M!@``8P<``'$!```P`P``,P<````````8
M!@``\0(``(($```G`P``H@0```H&``"L````YP4```````"I`P``)P$`````
M`````````````)P!```<`@```````````````````````&D#````````=@``
M`"<"```````````````````P!````````'`"``#>`P``Q08``!H$``!E`@``
M`````$P!```N!0``$04``-0````&!0``G00``!L"``#=`P``-P<```````#L
M`0``GP<``&$%````````=````*,%``"`!@``508`````````````R04``-L$
M```Y````K04``*D&``````````````````"V!@``(00```````!%!@``3@0`
M`%@"````````P@,```````#F`@``Y0(``````````````````"P```#9!@``
MGP8```````!!`P``N`8```````"%!P```````)(%``"S!```Q````-\"``!'
M`0``4P(``!X'````````.0<```````!!!0``'@4``````````````````#P&
M```@````S`$``%('``#.```````````````D`@``[@```$0%``!1!0``_@``
M`!0%````````204``&(#``!L!```C`(``&L#``"^`0``#@$``*H&``#[!0``
M?00`````````````@@,``$P````N`@``100``#$$``!\`0``=`4``),!``#2
M`0``#00``,P#````````3P,```````".`0``C`4````````G!```*P``````
M``"A!P``1P(``#L'``!=`P``0P<``!<$```=!P```````&4!````````````
M`-T$```X````S@8``````````````````)P#````````"`<``-(#``!R!@``
M"@(``/4$``````````````````#:`P``"`(``(L"```Z`0```````%$'````
M````3@<``+`!````````?`(``.T"``!]`````````,D#```S`P``_P,``,4%
M``#Y!0```````-H&``""`@``A@4```````#`!@``7`,``'(%``"/!0``LP4`
M`-,#````````'@0````````<`P``I0,``-X```"3````7P(``#,$```#`P``
M`````/<&``````````````````"!`P``=`<``%@&``"0!@```````!,#``!K
M`0``:@,```D#`````````````.H$``!:````308```````!N!@``D0,``"@'
M``!9````=`0```@%``"D!0```````+@$``````````````````!N!```6P,`
M``````!Z!0``E0(``````````````````+\```!$`@``G`0`````````````
MQ0$``%H"``#!````%04```D```!1`@``PP0``.,#``",!@``$@0`````````
M````OP8``(0#````````HP8``(@&````````5P$``.D!````````$P4`````
M````````ZP0````````!!0``5P<``#4#````````ZP$``/8"``"\!```S0,`
M``````!A`@``M`,``!8#``!8````)@<``-($``#'!0``5`(``'@&```,!```
M6`$``#X!`````````````.X"``````````````````#U`P``I`(```(%````
M````1P,``#0%``#A`0``UP8``",#`````````````!\````V!P``*@8`````
M``!V!P```````.<``````````````%T"````````F08``*H"``"'!```L0``
M````````````Q`4```````!Z!P``[`(``(0$`````````````)$$```;`P``
M`````'<&``!"!0``R`(``*L```">````C@0``#,```#!!@``F0``````````
M`````````.T$``#:`@``\08``/,$``"M`@``/@4`````````````MP```%P!
M````````<P,``.H````-````50$``($$``!9!P``:0$``(X'``"^!@``S08`
M``````"M````(`<``+L$``"T!````````#\'``!$`0```````+@#````````
MY@4``/X#``!5`@```````%L"````````Y`0``,\$````````708```,!``!,
M!`````````````"G`@``0`0``)("```1!```Q`$``(L!````````2@,`````
M``"A`0``5@$``",!````````N@8``````````````````&H!``#\!```K`(`
M`"D%```2!P``E@0```````#[`P``:````#,"``"5!0``CP0``!@!``!(`@``
MCP```$4'```````````````````4`0``E`(```L'``##`@``[P8```````#S
M!@````````P&````````IP,`````````````8@$``%4'```K`P``````````
M``"J`P``L@0``(T%``!G`P``&P```!<'``#F!@``K`8``'X!``!.!@``"00`
M`)D!```[`P``RP``````````````;`(``+X````Q`P``$`(```````"%`0``
M)@8``)0%``#G!```Y````-("````````````````````````^@4``&$#````
M`````````,\!``#M!@``0`,``'X'```*!P``)0```$T$``"K!@```````#$&
M``!A`0``]@4```````!Y!0``&````-,&``#R````.@,``+\$``"J`0``S@(`
M`#,%``"=`@``\@4``.P&```"````]0````````"Q`P````````````!F`@``
MF@,``"X#``"W!@`````````````F!0``Z@4````````1````\`(``-$````\
M`@``(`(``$\`````````[P,``(\&``!/!```!P```&L`````````0`4``&P!
M``#@!0```````'X$``#H````4````%X%```A!P``C@4``!X`````````````
M`!P`````````Z@8``(<"````````O@,````%``#W`0``Z0``````````````
M`````#`&```_!0``_P8``",%```C!@```````"D"``#H`@``<0(```,%``"E
M!```;0<```````#+`@``:04``!H!```6`0``H04``'<"```]!```D````',`
M``!+!@``!@```!8$``"F`P``P00``)(```#6`0``@@$``&H'``"W`@``A@0`
M`&`&``!O!@``U`4``(X&``#)!```=0```%$&``!6!@``>`4``#P%``!2!@``
M40$``/`&``!>!```B`<``(D```#R`@``5`0```P'``#6`P```````-H`````
M````K0$``$@'``!(!0``*P$``*H$``!J!@``@P<``)L````P`@``30<``+D%
M``!'````+P,```````!M!0``MP$```````#.!0``ZP8``/P"```V`@``\04`
M`&@'``"&!@``&P0``+@"````````,0$``-\#```O!P``!P<``)8```!)`@``
M2P<```T%````!```@`<``,4$``"#````BP4```````!<!P``F`(``#0$``!U
M`@````````````#B!0``#08``*@"``#;`P``PP8``(L```"4````:@(``%T$
M``"]`````````!<"``!2`0``5@(``$L$````````F`,``)D$``#Y!```A@``
M`"\```"L`0``H@4``-D%```;`0``=`8``````````````````&<'```^!```
M!P0``!L'``#=!0```````-,```!-````[@,``)@%```?!@```````!4!``![
M!0``#@8```````!7````-0(``#\````I!@````````8'``!V`@``V@$```\#
M```,````L@4`````````````=04``!\#```6!P```````)(#```L!P``I@8`
M`!`!```E`0``E`$`````````````J0(`````````````+@```,X$``";!```
MF@<``(T"``#@!@``Q@0``%,$``!7`@``$````+(!``!4`````````-T````K
M`@``EP8``&,!`````````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S
M*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R
M9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E9"!E=F5N=',`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($1A>2AS*2`E<R!(;W5R*',I("5S($UI;G5T
M97,`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@871T96YD965S`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D
M`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T
M;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S
M)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`J($%D9"!T:&5S92!B
M>2!C;&EC:VEN9R!!9&0@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@
M*@`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM
M('-E;&5C="`M+0`Q(&%T=&5N9&5E`#$@979E;G0`,3(@2&]U<B!&;W)M870`
M,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!30!!32!286EN`$%-(%-H;W=E<G,`04T@
M4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!
M8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P=&5D`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R
M;WIE;BX`06-C;W5N=&EN9P!!9%]V86YC960@4V5A<F-H`$%D9`!!9&0@0VAI
M;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($5V96YT`$%D9"!(
M97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N
M97<@4F5M;W1E($-A;&5N9&%R`$%D9"!A(&YE=R!E=F5N=`!!9&0@82!N97<@
M=7-E<CH`061D(&%T=&5N9&5E<P!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O
M:P!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`
M061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9'9A;F-E9"!396%R
M8V@`069G:&%N:7-T86X`06QA<FT`06QA<FT@)60@9&%Y<R!B969O<F4`06QA
M<FT@)60@:&]U<G,@8F5F;W)E`$%L87)M("5D(&UI;G5T97,@8F5F;W)E`$%L
M87)M("5D('=E96MS(&)E9F]R90!!;&%R;2`Q(&1A>2!B969O<F4`06QA<FT@
M,2!H;W5R(&)E9F]R90!!;&%R;2`Q(&UI;G5T92!B969O<F4`06QA<FT@,2!W
M965K(&)E9F]R90!!;&%R;2!$871E`$%L87)M(%-P86X@*&UI;G5T97,I`$%L
M87)M(%1I;64`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N
M=#H`06QL`$%L;"!!='1E;F1E97,`06QL($%U=&AE;G1I8V%T960@57-E<G,`
M06QL($9U='5R90!!;&P@1W)O=7!S`$%L;"!087-T`$%L;"!097)M:7-S:6]N
M<P!!;&P@5FES:6)L90!!;&P@9&%Y`$%L;"!D87D@979E;G0`06QL(&5V96YT
M<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES
M=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O
M<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D
M9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE
M<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R
M`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!;GD`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!
M<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`
M07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA
M`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L
M86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/P!!<W-I9VYM96YT(&-O;'5M;G,`070`071T86-H960@:7,@86X@:4-A;&5N
M9&%R(&9I;&4@=VET:"!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('1H92!E=F5N
M="X@268@>6]U<B!M86EL(&-L:65N="!S=7!P;W)T<R!I5&EP(')E<75E<W1S
M('EO=2!C86X@=7-E('1H:7,@9FEL92!T;R!E87-I;'D@=7!D871E('EO=7(@
M;&]C86P@8V]P>2!O9B!T:&4@979E;G0N`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+@!!='1E;F1A;F-E`$%T=&5N9&5E<P!!='1R:6)U=&5S`$%U
M9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F
M='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE
M(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD
M87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL
M86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U
M;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A
M9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F%S
M:6,@4V5A<F-H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D
M80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B
M)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD
M`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!"
M;W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!"
M;W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE
M=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0G5S>0!#35,`0U)#`$-2
M3"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?86QE;F1A<@!#7V5L;"!0<F]P97)T
M:65S+BXN`$-A;%]E;F1A<@!#86QE;F1A<@!#86QE;F1A<B!3=6UM87)Y`$-A
M;&5N9&%R<P!#86QE;F1A<G,@;75S="!H879E(&$@;F%M92X`0V%L;0!#86UB
M;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!C<F5A=&4@82!N97<@979E
M;G0N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;F-E
M;&QE9`!#86YC96QL960Z("5S`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C
M965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E
M;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R
M96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O
M<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<E]Y`$-A=&5G;W)I97,@86YD
M($QA8F5L<P!#871E9V]R>0!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E
M;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#
M96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#
M96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A
M=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`
M0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI
M<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@
M861D<F5S<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.@!#
M:&]O<V4@>6]U<B!D969A=6QT(&-A;&5N9&%R+@!#:')I<W1M87,@27-L86YD
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A
M<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R
M`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL
M('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE
M8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6$@<V5P87)A
M=&5D('9A;'5E<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM
M;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`
M0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER
M;2!087-S=V]R9`!#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\`0V]N9FER
M;65D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T
M:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O
M<'D@<V5L96-T:6]N`$-O<'D@=&AE(%523"!B96QO=R!F;W(@=7-E('=H97)E
M=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y(%523#H`0V]S=&$@4FEC80!#
M;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E
M;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E
M+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U
M;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D
M871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D
M96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD
M(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O
M=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E
M<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE
M(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@
M;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R
M=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T
M('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U
M<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`
M0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@3F5W($5V96YT`$-R96%T92!A(&QI
M;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871E
M9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A
M=&EA`$-U8F$`0W5R<F5N=`!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`
M0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S
M='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N
M`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E
M=F5R>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E
M('-E;&5C=&EO;@!$87D`1&%Y*',I`$1E7VQE=&4`1&5?;&5T92!#;VQU;6X`
M1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN
M9&5N=`!$969A=6QT`$1E9F%U;'0@0V%L96YD87(`1&5F875L="!#;VQO<@!$
M969A=6QT($ED96YT:71Y`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@)7,`
M1&5L971E($5V96YT`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T
M:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@
M86QL(&]C8W5R96YC97,_`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E
M<GD@=&EM90!$96YM87)K`$1E<V-R:5]P=&EO;@!$97-C<FEB92!T:&4@4')O
M8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R
M(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I
M9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y
M`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@=&\@
M<VAO=R!T87-K<R!W:&EC:"!A<F4@9'5E(&]N('EO=7(@8V%L96YD87(_`$1O
M97,@;F]T(')E8W5R`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`
M1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R
M;W`@9&]W;B!L:7-T`$1R=6=S`$1U93H@)7,`1'5R871I;VX`12U-86EL`$52
M4@!%8W5A9&]R`$5D:70`161I="`E<P!%9&ET($%T=&5N9&5E<P!%9&ET($)L
M;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO
M;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!296UO=&4@0V%L96YD
M87)S`$5D:70@871T96YD965S`$5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S
M`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D
M=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL
M`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M
M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E
M+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS
M97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT
M/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@1&%T90!%
M;F0@3VX`16YD(%1I;64`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!5
M4DP@:&5R90!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R
M(')E=')I979I;F<@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<SH@)7,`
M17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T
M:&YI8P!%=7)O<&4`179E;G0@9G)O;2`E<R!T;R`E<P!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED
M96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T
M`$5X<&]R="!#86QE;F1A<@!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P
M`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@
M8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE
M8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z
M`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO
M=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@
M0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA
M9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YD`$9I;FQA;F0`
M1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T
M`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N
M80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE
M<P!&<FED87D`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL
M($UO;VX`1G5L;"!.86UE`$9U='5R90!'86)O;@!'86QL97)Y('1O('1A:V4@
M:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V%M90!'96YE<F%L`$=E;F5R
M871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'
M97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!'
M;V]G;&4@4V5A<F-H`$=O=&\@)7,`1W)A>7-C86QE`$=R965C90!'<F5E:R`H
M25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R
M871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!S`$=U
M861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES
M<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(
M5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L
M92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M
M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<P!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``
M2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E
M("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@
M4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!)
M;G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE
M(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@
M=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S
M:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`
M2&]R:7IO;G1A;#H`2&]U<BAS*0!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M
M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)
M8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I
M='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S
M964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y
M(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS
M<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%52
M3`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A
M;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T($-A;&5N9&%R+"!3
M=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($-A;&5N9&%R
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@
M4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O
M;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);G-E<G0@0U]O;'5M;B!!9G1E<@!)
M;G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E
M<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S
M<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`
M26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C
M;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A
M9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B
M969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L
M:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@
M87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S
M=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI
M9"!F:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`
M26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`
M26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`
M26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E
M9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A
M`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`
M2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I
M9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N
M`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N
M`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G
M90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M`$ME>7=O<F1S`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H
M155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@,C0@:&]U<G,`
M3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S="!-;VYT:`!,87-T(%%U87)T
M97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E
M<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA<W0@=V5E:P!,871V:6$`
M3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`
M3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`
M3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R
M:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@
M3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E
M<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;6ET
M('1H92!T:6UE('-P86X@=&\@97AP;W)T.@!,:6YK`$QI;FL@<&]I;G1S('1O
M.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@
M=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP
M(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI
M<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES
M="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;U]C871I;VX`3&]A9&EN9RXN+@!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T
M`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN
M(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E
M<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU
M>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D
M(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@
M061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`
M36%L:0!-86QT80!-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RX`36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R
M:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`
M36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I
M=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE
M`$UE971I;F<`365M8F5R<P!-96YU($QI<W0`365N=2!M;V1E.@!-97)G92!C
M96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF
M:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T
M:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`365X:6-O`$UI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``
M36EN=71E*',I`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-E9"!%=F5N=',@
M3&ES=`!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I
M;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W
M(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG
M(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A
M=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@
M4F5P=6)L:6,@;V8`36]N86-O`$UO;F1A>0!-;VYG;VQI80!-;VYT:`!-;VYT
M:"!6:65W`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N=&AL>2!%=F5N=',@
M3&ES=`!-;VYT:&QY.B!296-U<G,@979E<GD`36]N=&AS($%H96%D`$UO;G1H
M<R!"969O<F4`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L
M>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`
M36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U
M<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT
M:7!L92!I0V%L96YD87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V
M96YT(&ES('-U<'!O<G1E9"X`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U
M;G0`37D@0V%L96YD87)S`$UY($-A;&5N9&%R<SH`37D@1G)E92]"=7-Y(%52
M3`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O
M($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N
M9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%52
M3`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%52
M3`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`
M3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($5V96YT`$YE
M=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE
M=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`R
M-"!H;W5R<P!.97AT($1A>0!.97AT($UO;G1H`$YE>'0@5V5E:P!.97AT(&1A
M>0!.97AT(&]P=&EO;G,`3F5X="!W965K`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`$YI9VAT`$YI=64`3F\@871T96YD965S`$YO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A
M=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C86QE;F1A<G,@87)E(&%V86EL86)L92!T
M;R!G=65S=',N`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!6
M1E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`
M3F\@96YD(&1A=&4`3F\@979E;G1S('1O(&1I<W!L87D`3F\@9FEL92!U<&QO
M861E9`!.;R!F<F5E+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE(&9O
M<B`E<P!.;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N`$YO(&EC;VYS(&9O
M=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N
M`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O
M9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A4
M5%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)
M34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@
M3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I
M<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N
M9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE
M9`!.;R!V86QI9"!E;6%I;"!A9&1R97-S(&9O=6YD`$YO('9A;'5E<P!.;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N
M90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO
M<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@
M82!D:7)E8W1O<GD`3F]T(&9O=6YD`$YO="!I;7!L96UE;G1E9"X`3F]T('-E
M=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RX`3F]V96UB97(`3F]W`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R
M<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E
M;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P
M;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA;`!/<'1I
M;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`
M3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H
M97(`3W1H97(@26YF;W)M871I;VX`3W=N97(`3W=N97(@4&5R;6ES<VEO;G,`
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I
M=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+
M97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE
M;&P`4$T`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO
M=R!3:&]W97)S`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI
M<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A
M;&T@1&%T94)O;VL`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`
M4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W0@179E;G1S($QI<W0`4&%S=&4`
M4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0871T97)N`%!E;F1I;F<@4VEG
M;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_`%!E<FUI<W-I;VX`
M4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H
M:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET
M=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A
M=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R=&%L($]P=&EO;G,`
M4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<R!$87D`4')E=FEO=7,@5V5E:P!0<F5V:6]U
M<R!D87D`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E
M($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O
M;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@
M8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T
M90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD
M;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A
M;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8W5R(%5N=&EL`%)E8W5R<F5N8V4`
M4F5C=7)R96YC92!$871A`%)E8W5R<F5N8V4@16YD($1A=&4`4F5C=7)R96YC
M92!);G1E<G9A;`!296-U<G)E;F-E(%1Y<&4`4F5C=7)S(&1A:6QY`%)E8W5R
M<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`4F5C=7)S('EE87)L>0!2961O97,@
M>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R
M;W=S97(`4F5M87)K<P!296UI;F1E<CH@)7,`4F5M;W1E($-A;&5N9&%R<P!2
M96UO=&4@0V%L96YD87)S.@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92`E
M<P!296UO=F4@071T96YD964`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`
M4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V
M92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO
M=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A
M;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=6ER960`4F5Q=6ER
M960@071T96YD965S`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W
M;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S970@=&\@1&5F875L=',`4F5S
M<&]N<V4`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R
M="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D
M;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P
M97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T
M`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2
M;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U
M;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG
M`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE
M;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A='5R
M9&%Y`%-A=61I($%R86)I80!3879E("5S`%-A=F4@07,@3F5W`%-A=F4@179E
M;G0`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V-I96YC90!396%R
M8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&-O;F9I
M<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT
M('9I97=S(&%N9"!C:&]O<V4@9&5F875L="!V:65W+@!396QE8W0@=&AE(&-A
M;&5N9&%R('1O(&EM<&]R="!T;SH`4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM
M<&]R=#H`4V5L96-T('1H92!F:7)S="!W965K9&%Y.@!396QE8W0@=&AE(&9O
M<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@=&AE('1I;64@<W!A
M;B!T;R!S:&]W.@!396QE8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O;B!S=&%R
M='5P.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('=H:6-H
M(&5V96YT<R!T;R!S:&]W(&EN('1H92!P;W)T86PN`%-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3
M96YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F0@82!C86YC96P@;F]T
M:69I8V%T:6]N('1O(&%L;"!A='1E;F1E97,@=VAE;B!D96QE=&EN9R!T:&ES
M(&5V96YT`%-E;F0@86X@96UA:6P@=&\@)7,`4V5N9"!U<&1A=&5S+VEN=FET
M871I;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N
M=`!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E
M;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3
M970@96YD(&1A=&4`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@<F5C
M=7)R96YC92!E;F0@9&%T90!3970@<W1A<G0@9&%T90!3970@=7`@<F5M;W1E
M('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O
M<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N
M+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I
M<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V
M86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P
M87)A;65T97(Z(`!397EC:&5L;&5S`%-H87)E9"!#86QE;F1A<G,Z`%-H;W!P
M:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!C871E9V]R>2!L96=E;F0_
M`%-H;W<@9&5L971E+"!A;&%R;2P@86YD(')E8W5R<F5N8V4@:6-O;G,@:6X@
M8V%L96YD87(@=FEE=W,_`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;BX`4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R/P!3:&]W(&9R
M964O8G5S>2!L96=E;F0_`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G
M9VEN9R!I;C\`4VAO=R!O;FQY(&5V96YT<R!T:&%T(&AA=F4@86X@86QA<FT@
M<V5T/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R
M`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:6UE(&]F(&1A>2!B971W
M965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_`%-H;W<@=7!L;V%D`%-H;W=E
M<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@
M5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG
M;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`
M4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`
M4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3
M;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0
M;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T
M:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N
M($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C
M92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3
M<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI
M="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A
M<G0@1&%T90!3=&%R="!/;@!3=&%R="!4:6UE`%-T87)T('EE87(`4W1A=%]U
M<P!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R
M965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)J96-T
M`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C
M97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`
M4W5N(%-E=`!3=6YD87D`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3
M=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`
M4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II
M;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C
M:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FUS
M`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R
M=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES
M=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K
M<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E
M<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R871I;VX`
M5&5N=&%T:79E`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4
M:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG
M('1H92!S>7-T96TN`%1H92!%9&ET($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@
M;&]N9V5R('!R97-E;G0N($5X:71I;F<N`%1H92!&5%`@97AT96YS:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E
M;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O
M='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R("(E<R(@8V%N;F]T(&)E(&1E
M;&5T960N`%1H92!C86QE;F1A<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!C86QE;F1A<B`B)7,B(&AA<R!B965N(')E;F%M960@=&\@(B5S(BX`5&AE
M(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!C;VYT86-T($E$
M(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@
M;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E
M=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N
M;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S
M(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E;F0@9&%T
M92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N`%1H92!E=F5N
M="!N;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F
M:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C
M;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9O;&QO
M=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V
M96YT.@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E
M<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9
M;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@
M961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE
M<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI
M:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R
M;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N
M"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E
M96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE
M(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S
M<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C
M875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@
M<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@
M*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4
M:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES
M="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E
M(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R
M979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M`%1H97)E(&%R92!N;R!E=F5N=',@;6%T8VAI;F<@=&AE(&-U<G)E;G0@8W)I
M=&5R:6$N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@
M;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R
M('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E
M<G)O<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<P!4:&5R92!W87,@86X@
M97)R;W(@861D:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R
M<F]R(&5D:71I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&UO=FEN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@<V5N
M9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N`%1H:7,@24U!
M4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N
M`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R
M+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F:6QE(&9O<FUA="!I<R!N
M;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C
M97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@
M96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S
M('!L96%S92!V:7-I="`E<P!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=P!4:'5N9&5R`%1H=7)S9&%Y`%1I8VME=',`5&EM90!4:6UE(%-P7V%N
M`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM
M92!S<&%N`%1I;6]R+4QE<W1E`%1I=%]L90!4:71L90!4:71L92`H=&]O;'1I
M<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI
M8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`
M5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I
M;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=65S
M9&%Y`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM
M96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4`
M5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S`%5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T
M;R!D96QE=&4@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@
M=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@(B5S(CH@)7,`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N(&9O<B`E<P!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P
M>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5
M;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I
M;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET
M960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@
M3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5
M;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E
M9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A
M;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@
M<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO
M=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L
M:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P
M9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9#H@)7,N`%5P9W)A
M9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@
M;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E
M;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E
M9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`
M57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T
M:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97)N86UE
M`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z
M8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I
M;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S('1O('-E
M;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A
M;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE
M="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@1&%Y`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y
M`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET
M90!7961N97-D87D`5V5E:P!7965K("5D`%=E96LH<RD`5V5E:VQY`%=E96ML
M>3H@4F5C=7)S(&5V97)Y`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ
M-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&%T('1I
M;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE<F4@
M87)E(&YO(&QA=&5R(&5V96YT<S\`5VAA="!T:6UE('-H;W5L9"!D87D@86YD
M('=E96L@=FEE=W,@<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@
M979E;G1S/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@
M=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7
M:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P
M965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!7;W)K(%=E96L`6"U2968`6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S
M(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M
M87``665A<FQY`%EE87)L>3H@4F5C=7)S(&5V97)Y`%EE;65N`%EE<P!997,L
M($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!C86X@;VYL>2!U<V4@=&AI
M<R!F;W)M(&9R;VT@=&AE($5D:70@071T96YD965S('-C<F5E;BX`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O("5S+@!9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE8W1E9"!C
M86QE;F1A<BX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@9&5L971E
M('1H:7,@979E;G0N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&5D
M:70@=&AI<R!E=F5N="X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@
M:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BX`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C
M="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A
M;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C
M;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO
M=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S
M<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-A
M;&5N9&%R`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z
M`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V
M:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!4
M97AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6U5N;F%M960@979E;G1=`%ML
M:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T)A<VEC(%-E87)C:`!?
M0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?161I=`!?1V]T;P!?1W)O=7!S
M`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%]);7!O<G0O17AP;W)T`%],
M;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]->2!#86QE;F1A<G,`
M7TYE=R!%=F5N=`!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U!R:6YT`%]296UO
M=F4@3&EN:RXN+@!?4V5A<F-H`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN
M+@!?5&]D87D`7U5S97)S`&%D9')E<W,@8F]O:P!B969O<F4@=&AE(&5V96YT
M('-T87)T<P!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`9&%Y`&1A>2AS*0!D
M87ES`&5V96YT<RYC<W8`979E;G1S+FEC<P!F86QL:6YG`&9I;&4`9G)O;0!F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z`&EM;65D:6%T90!I;FQI;F4`
M;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+@!M;VYT:"AS*0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE
M;65N=&5D`&YO=&5P860`;VX@=&AE('-A;64@9&%T90!O;B!T:&4@<V%M92!W
M965K9&%Y`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S
M`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@=&AE
M('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S
M97(@<V5L96-T`'9#86QE;F1A<B]I0V%L96YD87(`=D-A<F0`=D5V96YT(&YO
M="!F;W5N9"X`=SH`=V5A=&AE<BYC;VT`=V5E:P!W965K*',I(&]N.@!W965K
M<P!Y96%R*',I`%!R;VIE8W0M260M5F5R<VEO;CH@2W)O;F]L:71H(#(N,"UC
M=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2
M979I<VEO;BU$871E.B`@,C`P,2TP-RTR-B`Q-#HU-BTP.3`P"DQA<W0M5')A
M;G-L871O<CH@4&%V96P@0VAY=&EL(#QP879E;$!C:'ET:6PN=&L^"DQA;F=U
M86=E+51E86TZ($-Z96-H(#QD979`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E
M<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M25-/+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`I0
M;'5R86PM1F]R;7,Z(&YP;'5R86QS/3,[('!L=7)A;#TH;B4Q,#T],2`F)B!N
M)3$P,"$],3$@/R`P(#H@;B4Q,#X],B`F)B!N)3$P/#TT("8F("AN)3$P,#PQ
M,"!\?"!N)3$P,#X],C`I(#\@,2`Z(#(I.PH`("AP^&5D("5S(&1N>2D`("A0
M^.US='5P;W;](&ML[>@@)7,I`"`H=B`E<R!D;F5C:"D`("AD;F5S*0`@*'KM
M=')A*0`@*';H97)A*0`@<GEC:&QO<W0@`"5D("5S(&$@)7,`)60@=63A;&]S
M=.T`)60M9&5N;NT@</AE9'!O=NSO`"5S("T@;WINX6UE;NT`)7,@1&[Y*$1E
M;BD@)7,@2&]D:6XH82D@)7,@36EN=70`)7,@;W1I<VL`)7,@2T(`)7,@;W!E
M<F%C92#Z9'*^8GD@+2!P;W1V<GIE;NT`)7,@;F%S=&%V96[M`"5S(')E9VES
M=')A8V4`)7,@<&]D;>UN:WD@<&]UONUVX6[M`"5S(&IIOB!E>&ES='5J92X`
M)7,@;F$@)7,@)7,`)7,@^NAA<W1N[6OY`"5S('-O=6)O<B#Z<W#LN6[L(&EM
M<&]R=&]VX6X`)7,@:F4@<&^^861O=N%N;P`E<R!M:6YU=``E<R!N96)Y;&\@
M;F%L97IE;F\N`"5S(&&^("5S('H@)7,`)7,@861R97/A^``E<R`M($MA;&5N
M9.'X`"5S('KA<&ES;NUK`"5S('-E>FYA;2#Z:V]L^0`E<SH@)7,`*B!0^&ED
M870@='ET;R!K;&EK;G5T[6T@;F$@4/AI9&%T("H`*B!0<F]S[6T@=GEB97)T
M92!E;6%I;&]V;W4HZ2D@861R97-U*'DI("H`+"!NX7)A>F]V_2`E<R`E<P`L
M('!R;VWL;F[A(&]D("5S(&1O("5S`"TM(';]8NQR("TM`#$@^NAA<W1N[6L`
M,2!U9.%L;W-T`#$R(&AO9&EN;W;](&9O<FWA=``R-"!H;V1I;F]V_2!F;W)M
MX70`,C0@:&]D:6X`4')O('1E;G1O(&)L;VL@:F4@=GF^861O=N%N(&1A=&%B
MX7IO=OT@>F1R;VHN`%9Y<VMY=&QA('-E('KA=F&^;N$@8VAY8F$`4')O('IA
MN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@
M:VSMZ"X`4')O('9E<FEF:6MA8VD@<&]D97!S86[I('IP<N%V>2!J92!N=71N
M;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"X`4')O(&1EN6EF<F]VX6[M('IP
M<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"P@<')I=N%T
M;NT@4$=0(&ML[>@@82!H97-L;RX`4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@
M;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'4"!K
M;.WH(&$@:&5S;&\N`%!R;R!D9;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@
M<&]UONUT('9E^&5J;OT@4R]-24U%(&ML[>@L('!R:7;A=&[M(%,O34E-12!K
M;.WH(&$@:&5S;&\N`%!R;R!P;V1E<'/A;NT@>G!RX79Y(&IE(&YU=&YO('!O
M=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEVX71N[2!3+TU)344@:VSM
MZ"!A(&AE<VQO+@!0<F\@>F&Y:69R;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O
M=;[M="!V9?AE:F[](%,O34E-12!K;.WH+@!!30!286YN[2!DZ;F[`%)A;F[M
M('#X96CA\FMY`%)A;F[M('-N[&AO=ND@</AE:.'R:WD`04TO4$T`05!)($E$
M`$EN9F]R;6%C92!O('1O;71O(&5D:71O<G4`26YF;W)M86-E+BXN`%1E>'0@
M9&]L^2!D;R!O8G+A>FMU`%1E>'0@9&]P<F]S=/AE9"!O8G+A>FMU`%#X:6IA
M=&\`5GET=F_X96[M(%9&4R!A9')A<^'X92!N96)Y;&\@<&]V;VQE;F\N`%9Y
M='9O^&5N[2!61E,@<V]U8F]R=2!N96)Y;&\@<&]V;VQE;F\N`%6^:79A=&5L
M<VOI(&AE<VQO`%6^:79A=&5L:_T@^NAE="!B>6P@>F%B;&]K;W;A;BX`5;YI
M=F%T96QKZ2#ZZ'1Y`$AL7V5D870@1/EK;&%D;NQJ:0!0^&ED870`4/AI9&%T
M('!O9'-K=7!I;G4`4/AI9&%T('!O9"UP<N%V80!0^&ED870@563A;&]S=`!0
M^&ED870Z`%#X:61A="!N;W9O=2!S:W5P:6YU`%#X:61A="!N;W;A('!RX79A
M`%#X:61A="!N;W;](%9Z9.%L96[]($MA;&5N9.'X`%#X:61A="!N;W9O=2!U
M9.%L;W-T`%#X:61A="!N;W;I:&\@=;YI=F%T96QE.@!0^&ED870@^NAA<W1N
M[6MY`%#X:61A="!S;&]U<&5C`%#X:61A="!N;W;I(.AL96YY`%#X:61A="!P
MX7(`4/AI9&%T("5S(&UE;G4@:F%K;R!B;^AN[2!S;&]U<&5C($UO>FEL;'D`
M4/AI9&%T(&1O(&%D<F5SX?AE.@!0^&ED870@9&\@;>EH;R!A9')E<^'X90!0
M^&ED870@=;YI=F%T96QE`%#X:63A=N%N[2!UOFEV871E;/D@:F4@>F%B;&]K
M;W;A;F\N`$%D<F5S80!+;VYT86MT>0!6>6MO;N%V870@861M:6YI<W1R86-I
M("T@;F%S=&%V96[M('#X[7-T=7!O=OUC:"!P<N%V('!R;R!O<W1A=&[M('6^
M:79A=&5L90!!9&UI;FES=')A8V4`26YZ97+A='D`2&QE9&%T($3Y:VQA9&[L
M:FD`069G:.%N:7-TX6X`06QA<FT`06QA<FT@)60@9&[Y('#X960`06QA<FT@
M)60@:&]D:6X@</AE9`!!;&%R;2`E9"!M:6YU="!P^&5D`$%L87)N("5D('3]
M9&[Y('#X960`06QA<FT@,2!D96X@</AE9`!!;&%R;2`Q(&AO9&EN=2!P^&5D
M`$%L87)M(#$@;6EN=71U('#X960`06QA<FT@,2!T_61E;B!P^&5D`$1A='5M
M($%L87)M=0!6>6WL^&5N[2!!;&%R;74@*'8@;6EN=73A8V@I`,AA<R!!;&%R
M;74`06QBX6YI90!!;+[M<G-K;P!0^&5Z9.UV:V$O06QI87,`6F%R;W9N870`
M6F%R;W9NX6[M.@!6N64`5KEI8VAN:2#:Z&%S=&[M8VD`5KEI8VAN:2!O=NSX
M96[M('6^:79A=&5LZ0!6N65C:&YY('8@0G5D;W5C;F]S=&D`5KEE8VAN>2!S
M:W5P:6YY`%:Y96-H;GD@36EN=6SI`%:Y96-H;F$@=;YI=F%T96QS:^$@<'+A
M=F$`5KEE8VAN>2!6:61I=&5L;ND`0V5L_2!D96X`563A;&]S="!N82!C96S]
M(&1E;@!6N65C:&YY(%5DX6QO<W1I`%:Y96-H;GD@Z'1Y^&D@<W1R86YY`%!O
M=F]L:70@=NUC92!A9')E<P!0;W9O;&ET(&YA<W1A=F5N[2!T>7!U('-E=/CM
M9.QN_2!S97IN86T_`$IIOB!E>&ES='5J90!!;'1E<FYA=&EV;NT@24U34"!P
M^&EH;.&Y96[M(&1O('-Y<W3I;74`06QT97)N871I=F[M($E-4U`@:&5S;&\`
M06QT97)N871I=F[M($E-4U`@=;YI=F%T96QS:^D@:FWI;F\`06QT97)N871I
M=F[M(&4M;6%I;&]VX2!A9')E<V$`06QT97)N871I=F[M('9Z;W)Y`$%L=&5R
M;F%T:79N[2!T97AT.@!!;65R:6-KX2!386UO80!">6QA('IA9.%N82!N97!O
M=F]L96[A(&AO9&YO=&$N`$%N9&]R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM
M;NT@<')O>'D`3V1P;W;L[P!!;G1A<FMT:6MA`$%N=&EG=6$@82!"87)B=61A
M`$IA:^%K;VQI=@!!<&QI:V%C90!397IN86T@87!L:6MA8^T`07!L:6MA8V4@
M:F4@</AI<')A=F5N80!0;W6^[70@<')O(&3L9&GH;ND@<V3M;&5N[0!38VAV
MX6QI=`!0^&EB;&F^;N$@=F5L:6MO<W0`1'5B96X`07)A8G-K>2`H5VEN9&]W
M<RTQ,C4V*0!696QI:V]S="!A<F-H:79O=F%NZ6AO('-O=6)O<G4`2FWI;F\@
M87)C:&EV=0!5<NAI=.P@8VAC971E('9Y;6%Z870@ON%D;W-T(&\@</AI:&SA
MN65N[2!D;R`E<S\`07)G96YT:6YA`$%R;>EN:64`07)MZ6YS:_T@*$%235-#
M24DM."D`56WL;NT`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!U;>QN
M[0!!<VEE+W)E9VEO;B!4:6-HZ6AO(&]C9>%N=0!0;[[A9&%T(&\@<&]T=G)Z
M96[M('#X960@<')O=F5D96[M;2!O<&5R86/M(/ID<KYB>3\`4VQO=7!C92!S
M(/IK;VQY`%8`4V]U8F]R(&E#86QE;F1A<B!J92!P^&EL;[YE;B!S(&EN9F]R
M;6%C96UI(&\@=63A;&]S=&DN(%!O:W5D(%;AN2!E;6%I;&]V_2!K;&EE;G0@
M<&]D<&]R=6IE(&E4:7`@ON%D;W-T:2P@;?F^971E('!O=;[M="!T96YT;R!S
M;W5B;W(@<')O(&IE9&YO9'6Y[2!A:W1U86QI>F%C:2!L;VOA;&[M:&\@:V%L
M96YDX?AE+@!0;VMU<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC[2!S:W5P:6YY
M+@!0;VMU<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC[6-H('6^:79A=&5L<VO]
M8V@@<'+A=BX`4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J[6/M8V@@=;YI=F%T
M96QS:_UC:"!P<N%V+@!0;VMU<R!O(/IP<F%V=2!N965X:7-T=6KM8^UH;R!S
M9.UL96[I:&\@;V)J96MT=2X`VNAA<W0`VNAA<W1N[6-I`$%T<FEB=71Y`%-R
M<&5N`$%U<W1RX6QI90!286MO=7-K;P!!=71H7V-Y<G-Q;#H@3F5B>6QA(&YA
M;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:6UA<"X`075T:%]C>7)U
M<SH@6F1R;VH@;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN`$%U=&A?8WER
M=7,Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&EM
M87`N`$%U=&A?9G1P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP
M;VYA('!R;R!F='`N($MO;7!I;'5J=&4@4$A0(',@+2UE;F%B;&4M9G1P`$%U
M=&A?:6UA<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P
M<F\@24U!4"X`075T:%]K<F(U.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%N
MX2!P^.UP;VYA('!R;R!K<F(U+@!!=71H7VQD87`Z($YE8GEL82!N86QE>F5N
M82!P;[YA9&]V86[A('#X[7!O;F$@<')O($Q$05``075T:%]L9&%P.B!.96QZ
M92!P^&ED870@=;YI=F%T96QE("5S+B!(;.&Y96[M('-E<G9E<G4Z(`!!=71H
M7VQD87`Z($YE;'IE('9Y;6%Z870@=;YI=F%T96QE("5S`$%U=&A?;&1A<#H@
M3F5L>F4@86MT=6%L:7IO=F%T('6^:79A=&5L92`E<P!!=71H7VUC86PZ($YE
M8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O($U#04PN`$%U
M=&A?<VUB875T:#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N
M82!P<F\@<VUB875T:"X`3W;L^&5N[2!S96QH86QO`$]V[/AE;NT@<V5L:&%L
M;RX@)7,`3W;L^&5N[2!B>6QO('IA;>UT;G5T;R!2041)55,@<V5R=F5R96TN
M`%-E;&AA;&\@;W;L^&5N[2!&5%`@<V5V97)E;2X`1&]S='5P;N$@<&]L93H`
M07IE<F)A:F2^X6X`0D]&2"!V_6UL=79Y`%!O>F%D[0!"87)V82!P;WIA9.T`
MJ7!A=&[I(&AE<VQO('!R;R!K97)B97)O<RX`J7!A=&[I('6^:79A=&5L<VOI
M(&IMZ6YO('!R;R!K97)B97)O<RX`0F%H86UY`$)A:')A:6X`0F%L=&EC:^D@
M*$E33RTX.#4Y+3$S*0!"86YG;&%DZ;D`0F%R8F%D;W,`6N%K;&%D`%9Y:&QE
M9&%T`$+L;&]R=7-K;P!"96QG:64`0F5L:7H`0F5N:6X`0F5R;75D>0!":/IT
MX6X`3F%R;WIE;FEN>0!.96QZ92!N86SI>G0@Z.%S="`B)7,B(&%P;&EK86-E
M("(E<R(N`$YA<W1A=F5N[2!B;&]K=0!4>7`@8FQO:W4`5'7H;NP`0F]L[79I
M90!:X6QOOFMY`$]K<F%J`*GM^&MA(&]K<F%J93H`3VMR86IE`$)O<VYA(&$@
M2&5R8V5G;W9I;F$`3V)A`$)O='-W86YA`$1O;&[M(.CA<W0`0F]U=F5T($ES
M;&%N9`!"<F%Z[6QI90!"<FET<VOA('1E<FET;W)I82!V($EN9&EC:^EM(&]C
M9>%N[`!"<G5N96D@1&%R=7-S86QA;0!"=6QH87)S:V\`4V5Z;F%M(',@;V1R
MX;YK86UI`$)U<FMI;F$@1F%S;P!"=7)U;F1A`%IA;F5P<N%Z;NQN_0!#35,`
M0U)#`$-23"!D:7-T<FEB=>AN[2!B;V1Y`$M?86QE;F3A^`!6;&%S=&YO<W1I
M(&)?=?)K>2XN+@!+86Q?96YDX?@`2V%L96YDX?@`4VAR;G5T[2!+86QE;F3A
M^&4`2V%L96YDX?AE`$MA;&5N9.'X92!M=7/M(&WM="!J;>EN;RX`0F5Z=NQT
M^.T`2V%M8F]DOF$`2V%M97)U;@!(97-L;R!N96QZ92!N87-T879I="!A=71O
M;6%T:6-K>2P@<')O<^UM(&MO;G1A:W1U:G1E(%9AN65H;R!S>7-TZ6UO=NEH
M;R!A9&UI;FES='+A=&]R82X`3F5L>F4@<V4@</AI<&]J:70@:R!)34%0('-E
M<G9E<G4Z("5S`$YE;'IE('9Y='9O^&ET(&YO=F]U('5DX6QO<W0N`$MA;F%D
M80!3=&]R;F\`4W1O<FYO(&ALX;EE;NT@<')O8FSI;74`4W1O<FYO=N%N;P!3
M=&]R;F]VX6YO.B`E<P!.96QZ92!V>6UA>F%T('-O=6)O<B`B)7,B+@!.96QZ
M92!N86KM="!D;^AA<V[](&%D<F5SX?@N`$YE;'IE('!O:W)AZ&]V870@8F5Z
M('!A<F%M971R=2`G=&%R9V5T1FEL92<N`$YE;'IE('9Y;6%Z870@861R97/A
M^"`B)7,B+@!.96QZ92!V>6UA>F%T+"!P<F]T;[YE(&5X:7-T=6KM('!O9'-K
M=7!I;GD@)60N`$YE;'IE('!R;W;I<W0@>FWL;G4@=7-P;_CA9.%N[2P@<&_H
M970@<&]S:WET;G5T_6-H('!O;&^^96L@<')O(&YO=ND@=7-P;_CA9.%N[2!N
M96]D<&]V[63A('!OZ'1U('5L;[YE;OUC:"!P;VQOOF5K+@!.96QZ92!Z87-L
M870@>G!RX79U(&YA('IA9&%NZ2#H[7-L;RX@`$-A<&4@5F5R9&4`5&ET=6QK
M>0!+871E9V]R7VEE`$MA=&5G;W)I92!A('IN8>AK>0!+871E9V]R:64`2V%J
M;6%N<VOI(&]S=')O=GD`36]B:6QN[2!T96QE9F]N`$UOOFYO<W1I(&)U\FMY
M`$]D<W1U<"!M97II(&)U\FMA;6DZ`%9L87-T;F]S=&D@8G7R:WD`365Z97)Y
M(&UE>FD@8G7R:V%M:3H`36]B:6QN[2!T96QE9F]N`$ME;'1S:_T@*$E33RTX
M.#4Y+3$T*0!3=/AE9`!3=/AE9&]A9G)I8VOA(')E<'5B;&EK80!3=/AE9&]E
M=G)O<'-K_2`H25-/+3@X-3DM,BD`4&]D<F]B;F]S=&D@8V5R=&EF:6OA='4`
M4&]D;>UN:WD@8V5R=&EF:6OA='4`R&%D`%IM[&YI=`!.87-T879E;NT@:FWI
M;F$@82!E;6%I;&]VZ2!A9')E<WDN(%1Y=&\@<&]L;[YK>2!L:63I('5V:63M
M+"!K9'F^('-I(.AT;W4@;F5B;R!O9'!O=NUD86KM(&YA(%9AN64@>G!RX79Y
M+@!:;F%K`%IK;VYT7W)O;&]V870@;V1K87HN+BX`0VAI;&4`R.UN80#([6ZY
M=&EN82!Z:F5D;F]D=;EE;N$@*$=",C,Q,BD`5')A9&GH;NT@Z.UNN71I;F$@
M*$)I9S4I`%IV;VQT92!H97-L;P!:=F]L=&4@=;YI=F%T96QS:^D@:FWI;F\`
M5GEB<F%T('IO8G)A>F5N[2!D871U;74Z`%9Y8G)A="!T>7`@<W1Y;'4@<V5Z
M;F%M=2`H<')O(/AA>F5NZ2!S97IN86UY*0!6>6)R870@2V]N=&%K='D@<')O
M(&AL963A;NT@9G)E92]B=7-Y(%523#H`6G9O;&ET(&EM<&QI8VET;NT@:V%L
M96YDX?@`5N%N;^AN[2!O<W1R;W8`3F5B>6QA(&YA;&5Z96YA(&1E9FEN:6-E
M('3X[61Y("5S+@!6>>AI<W1I=`!6>>AI<W1I="!Z;F'H:WD@>B!-4T]F9FEC
M90!/9'-T<F%N[&[M('6^:79A=&5L93H@)7,`3V1S=')A;FET('6^:79A=&5L
M90!/9'-T<F%N[&[M(/ID86KY(&\@=;YI=F%T96QI`$ML:6MN['1E('!R;R!P
M;VMR8>AO=N%N[0!#;&EC:V%T96QL('#X97,@2%144`!:87;X[70@;VMN;P!:
M871AOF5N;P!/8FQAZ&YO`$MO:V]S;W;I(&]S=')O=GD`4VML87!N;W5T(&)O
MZ&[M(&QIN71U`%-K;&%P;F]U="!O:W)A:F4`2V]L=6UB:64`0F%R=F$`5OUB
M['(@8F%R978`4&%L971A(&)A<F5V`%-L;W5P8V4Z`$[A>G9Y('-L;W5P8V4`
M2V]M:6MS>0#(X7)K;W4@;V1D[&QE;ND@:&]D;F]T>0!0^.UK87H`4/CM:V%Z
M;W;A(&MO;GIO;&$`4&]Z;N%M:V$`3V)E8V[I(&IMZ6YO`$MO;6]R;W,`1FER
M;6$`4&_H[71AZ&4`4&]D;>UN:WD`4F]Z9.UL>2!V(&YA<W1A=F5N[0!.87-T
M879I="`E<P!0;W1V<F1I="!H97-L;P!0;W1V<F1I="!S;6%ZX6[M('5DX6QO
M<W3M/P!0;W1V<GIE;F\`2V]N9V\`2V]N9V\L($1E;6]K<F%T:6-KX2!R97!U
M8FQI:V$`4W!O:F5N[2!S96QH86QO+@!3<&]J96[M('-E;&AA;&\Z(`!">6QO
M('IA;>UT;G5T;R!S<&]J96[M(',@=F7X96IN_6T@:VSMZ&]V_6T@<V5R=F5R
M96TN`$)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE:F[];2!K;.WH;W;]
M;2!S97)V97)E;2X@1/EV;V0@.B`E<R`H)7,I`%-E;&AA;&\@<W!O:F5N[2!S
M($944"!S97)V97)E;2X`2V]N=&%K='D@8GEL>2#Z<W#LN6[L('#X:63A;GD@
M9&\@5F&Y96AO(&%D<F5SX?AE+@!0;VMR8>AO=F%T`$-O;VMO=GD@;W-T<F]V
M>0!+;VSAZ&5K`$MO<.UR;W9A=`!+;W#M<F]V870@=OUB['(`6FMO<.UR;W9A
M="!N[;YE('5V961E;F]U(%523"!P<F\@<&]UOFET[2!S(%9AN>T@1G)E92]"
M=7-Y(%523#H`2V]S=&%R:6MA`%!O8OAEONT@<VQO;F]V:6YY`%IP<N%V=2!N
M96QZ92"Y:69R;W9A="!P;VUO8^T@4$=0+@!:<'+A=G4@;F5L>F4@<&]D97!S
M870@<&]M;V/M(%!'4"X`6G!RX79U(&YE;'IE(+EI9G)O=F%T('!O;6]C[2!3
M+TU)344N`%IP<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@4R]-24U%+@!.
M96QZ92!P^&ED870@:V]N=&%K="X@)7,`3F5L>F4@<V4@</AI<&]J:70@:R!,
M1$%0('-E<G9E<G4N`$YE;'IE('IK;VYT<F]L;W9A="#ZZ&5T+B`E<P!.96QZ
M92!V>71V;_AI="!D:7-T<FEB=>AN[2!S97IN86TN("5S`$YE;'IE(&1EN6EF
M<F]V870@4$=0(&1A=&$N`$YE;'IE(&1EN6EF<F]V870@4R]-24U%(&1A=&$N
M`$YE;'IE('-M87IA="!K;VYT86MT+B`E<P!.96QZ92!S;6%Z870@9&ES=')I
M8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!Z:FES=&ET(&4M;6%I;&]V;W4@861R
M97-U('#X[6IE;6-E+@!.96QZ92!Z[7-K870@^G!L;OT@861R97/A^"X`3F5L
M>F4@>NUS:V%T(/IP;&[](&1I<W1R:6)UZ&[M('-E>FYA;2X`3F5L>F4@>NUS
M:V%T(/IP;&[]('-E>FYA;2!D:7-T<FEB=>AN[6-H('-E>FYA;?DN`$YE;'IE
M('KM<VMA="!V9?AE:F[](&ML[>@@>B!K;.WH;W;I:&\@<V5R=F5R=2X`3F5L
M>F4@;W1E=OCM="`E<RX`3F5L>F4@<')O=NES="!O<&5R86-E(/ID<KYB>2!P
M<F\@;6]D=6P@)7,`3F5L>F4@Z.US="`E<RX`3F5L>F4@<F5S971O=F%T(&AE
M<VQO('!R;R!D86[I:&\@=;YI=F%T96QE+B!6N65C:&YY(&YE8F\@;NQK=&5R
MZ2!Z('!O9')O8FYO<W3M(&YE8GEL>2!S<'+A=F[L('IA9.%N>2X@6FMU<W1E
M('1O('IN;W9U(&YE8F\@<&]K=60@<&]T^&5B=6IE=&4@<&]M;V,L(&MO;G1A
M:W1U:G1E('-P<N%V8V4@<WES=.EM=2X`3F5L>F4@>NUS:V%T($%#3`!.96QZ
M92!Z[7-K870@861R97/A^"X@)7,`3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M
M('-E>FYA;2X@)7,`3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA;7DN
M("5S`$YE;'IE('KM<VMA="!S8VAO<&YO<W1I('-E<G9E<G4`3F5L>F4@</AE
M<&YO=70@:V]N9FEG=7)A8VDN`$YE;'IE('5L;[YI="!K;VYF:6=U<F%C:2!P
M<F\@)7,N`$YE;'IE('5L;[YI="!ZX6QOOF[M(&MO;F9I9W5R86-I+@!.96QZ
M92!U;&^^:70@>N%L;VAU(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N`$YE
M;'IE(&AL961A="!V($Q$05`@<V5R=F5R=2X`3F5L>F4@86MT=6%L:7IO=F%T
M(&MO;G1A:W0N("5S`$YE;'IE(&%K='5A;&EZ;W9A="!D:7-T<FEB=>AN[2!S
M97IN86TN("5S`$YE;'IE(&YA;.EZ="!B;^AN[2!L:;ET=2!P<F\@36]Z:6QL
M=2X@4')O<^UM('#X97-V[&3H=&4@<V4L(+YE(&IE(&]T97;X96[A+@!/9'!O
MZ.UT86[]('1E>'0`6F5M[`!6>77H;W9A8^T@</AE9&WL='D`5GET=F_X:70`
M5GET=F_X:70@3F]V;W4@563A;&]S=`!6>71V;_AI="!O9&MA>@!6>71V;_AI
M="!N;W9O=0!6>71V;_AI="!P;V1S;&^^:WD`5GET=F_X96YO`%1V^7)C92!P
M<N%V`,CM<VQO(&MR961I=&[M(&MA<G1Y`$-H;W)V871S:V\`2W5B80!3;W7H
M87-N_0!!:W1UX6QN[2#H87,`06MT=>%L;NT@55),(&IE`$%K='7A;&[M('!O
MZ&%S[0!!:W1UX6QN[2!P;V1M[6YK>3H@`$YY;NQJN>T@<W1Y;`!.87-T879E
M;NT@^FMO;/D@<')O=N%D[&[]8V@@</AI('#X:6ALX;EE;NT@9&\@)7,N`%9Y
M<W3X:6AN;W5T`%9Y<W3X:6AN;W5T(';]8NQR`$MY<'(`07IB=6MA("A+3TDX
M+5(I`$%Z8G5K82`H5VEN9&]W<RTQ,C4Q*0!!>F)U:V$O56MR86II;F$@*$M/
M23@M52D`R&5S:^$@<F5P=6)L:6MA`$1$`$1E;F[L`$1E;F[L.B!296MU<GKM
M=F[L(&MAOF3]`$1A=&%4<F5E('!R;VAL[;YEZ`!$871U;0!0^&EJ871O(&1N
M90!6_6+L<B!D871U;74`1&5N`$1E;BA$;GDI`%-M7WIA=`!3;6%?>F%T('-L
M;W5P96,`4')O<VEN96,`R.US;&$@9&5S[71K;W;I('-O=7-T879Y`%IA;>UT
M;G5T`%IM96ZY:70@;V1S87IE;NT`26UP;&EC:71N[0!);7!L:6-I=&[M($MA
M;&5N9.'X`$EM<&QI8VET;NT@8F%R=F$`26UP;&EC:71N[2!I9&5N=&ET80!$
M969I;FEC90!3;6%Z870`4VUA>F%T("5S`%-M87IA="!59.%L;W-T`%-M87IA
M="!S:W5P:6YU`%-M87IA="!P<N%V80!3;6%Z870@82!V>>AI<W1I="!Z<'+A
M=GD`4VUA>F%T(&)U\FMU`%-M87IA="!S;&]U<&5C`%-M87IA="!E>&ES='5J
M[6/M(&%L=&5R;F%T:79N[2!V>F]R`%-M87IA="#XX61E:P!3;6%Z870@=GEB
M<F%N;W4HZ2D@:61E;G1I='4H>2D`4VUA>F%T('-O=>AA<V[]('-L;W5P96,`
M4VUA>F%T('!O=7IE('-O=>AA<VYO=2!U9.%L;W-T+"!T96YT;R!V_7-K>70@
M82!VN65C:&YY(';]<VMY='D@=B!B=61O=6-N=2P@;F5B;R!VN65C:&YY(';]
M<VMY='D_`%-M87IA="!S;W7H87-N_2#XX61E:P#(87,@9&]R=>AE;NT`1.%N
M<VMO`%!O<&E?<P!0;W!S870@<')O8FSI;0!0;W!I<P!0;V1R;V)N;W-T:2`H
M=&%KZ2!V(&QO9R!S;W5B;W)U($AO<F1E*3H`4&]D<F]B;F]S=&D@8GEL>2!Z
M87IN86UE;N%N>2!D;R!L;V<@<V]U8F]R=2!P<F\@861M:6YI<W1RX71O<F$N
M`%;]=F]J`%)O<V[](&)O9`!2;W-N_2!B;V0@>F$@<&]S;&5D;NT@:&]D:6YU
M.B``4F]S;OT@8F]D.B``4VWL<B!Z(&QE=F$@9&]P<F%V80!3;>QR('H@<')A
M=F$@9&]L979A`$%D<F5SX?@`6F]B<F%Z:70`6F]B<F%Z:70@,C0M:&]D:6YO
M=OT@Z&%S/P!-;[YN;W-T:2!:;V)R87IE;NT`6F]B<F%Z:70@</AE9'!O=NSO
M("A4048I`$9O<FWA="!Z;V)R87IE;NT`1&ES<&]Z:>AN[2!U<&]Z;W)N[&[M
M`$1J:6)O=71I`$YE<VUA>F%T`$YE</AI<W1U<&]V870@</CM;6\@9&\@;6%I
M;G1E;F%N8V4N<&AP`%#X96IE=&4@<VD@>F]B<F%Z:70@^FMO;'DL(&MT97+I
M(&IS;W4@<&^^861O=N%N>2P@;F$@5F&Y96T@:V%L96YDX?AI/P!"97H@;W!A
M:V]VX6[M`$]B<V%H=6IE('!R=F[M(/CA9&5K(&[A>F5V('-L;W5P8_D_(%!O
M:W5D(&%N;RP@>F&Y:W)T;NQT92!T96YT;R!RX6UEZ&5K.@!$;VUI;FEK80!$
M;VUI;FEKX6YS:^$@<F5P=6)L:6MA`%-T8;YE;NT`4W1AOF5N[2`E<P!3=&%H
M;F]U="!G96YE<F]V86YO=2!K;VYF:6=U<F%C:2!J86MO(%!(4"!S:W)I<'0N
M`%)O;&5T;W;]('-E>FYA;0!$<F]G>0!0;[YA9&]V86[].B`E<P!$Z6QK82!4
M<G;A;NT`12UM86EL`$524@!%:W;A9&]R`%5P<F%V:70`57!R879I="`E<P!5
M<')A=FET(-KH87-T;NUK>0!5<')A=FET(&)L;VL`57!R879I="!S:W5P:6YU
M`%5P<F%V:70@<'+A=F$`57!R879I="!P<N%V80!5<')A=FET('!RX79A('!R
M;R`E<P!5<')A=FET(%9Z9.%L96[I($MA;&5N9.'X90!5<')A=FET(/GH87-T
M;NUK>0!5<')A=FET(&MA=&5G;W)I92!A(&)A<G9Y`%5P<F%V:70@;6^^;F]S
M=&D@<')O.@!5<')A=FET('!RX79A('!R;R`E<P!6_75K80!%9WEP=`!%;"!3
M86QV861O<@!0<G9E:RXN+@!%;0!%;6%I;`!%;6%I;&]VX2!!9')E<V$`16UA
M:6QO=ND@861R97-Y('-E(&UU<^T@<VAO9&]V870N`$5M86EL(',@<&]T=G)Z
M96[M;0!):V]N:WD@<R!E;6]C96UI`%!RX7ID;N$@>G!RX79A+@!0<N%Z9&[]
M(';]<VQE9&5K+@!0<N%Z9&[]('1E<FWM;B!P<F\@=GEH;&5DX7;A;NT`4&]V
M;VQI="!V:VSA9.%N[2!O8G)A>FOY('H@9F]T;R!G86QE<FGM(&1O('1E>'1U
M/P!!:W1I=F]V870@<')A=ND@:VQI:VYU=.T@<')O(&MO;G1E>'1O=ND@;65N
M=3\`1&%T=6T@56MO;NAE;NT`2V]N96,@=@#(87,@56MO;NAE;NT`2V]N96,@
M<F]K=0!:=NQTN6ET(&5D:71O<@!:861E:G1E(&)E>G!EZ&YO<W1N[2!O=.%Z
M:W4L(&YA(&MT97)O=2!B=61E=&4@;75S970@;V1P;W;L9.QT('!O:W5D('-I
M(&)U9&5T92!C:'3M="!R97-E=&]V870@<W;I(&AE<VQO+"!N87#X+B`G2F%K
MZ2!J92!J;>EN;R!68;EE:&\@<'-A/R<Z`%ID92!V;&^^:70@55),(&]B<N%Z
M:W4`4F]V;NUK;W;A($=U:6YE80!%<FET<F5A`$-H>6)A`$YA<W1A;&$@8VAY
M8F$@</AI(';]8NQR=2`E<R!I;F9O<FUA8V4@;R!F<F5E+V)U<WDZ("5S`$YA
M<W1A;&$@8VAY8F$@<R!P;[ET;W9N[2!Z<'+A=F]U+@!%<W1O;G-K;P!%=&EO
M<&EE`$5T;FEC:^D`179R;W!A`%5DX6QO<W0@;V0@)7,@9&\@)7,`2V&^9/UC
M:"`Q-2!M:6YU=`!+8;YDZ2`R(&UI;G5T>0!+8;YD_6-H(#,P('-E:W5N9`!+
M8;YD_6-H(#4@;6EN=70`2V&^9.D@</AI:&SAN65N[2!D;R!S>7-TZ6UU`$MA
MOF1O=2!P^6P@:&]D:6YU`$MAOF1O=2!M:6YU='4`5GIO<F]V_2!P^.UK;&%D
M(&AO9&YO=#H`4')O=NES=`!2;WIV:6YO=70`4F]Z8F%L:70@8F_H;NT@;&FY
M='4`3^AE:^%VX6YA("<I)P!/Z&5KX7;A;F\@<V%M;W-T871NZ2!S;&]V;R!N
M96)O(&AL961A;OT@=&5R;>UN('8@=79O>F]V:^%C:`!$871U;2!P<F\@:V]N
M96,@<&QA=&YO<W1I`$5X<&]N96YT`$5X<&]R=&]V870`17AP;W)T;W9A="!+
M86QE;F3A^`!"87)V82!P;W#X963M`%#X96YO<R!K;VYF:6=U<F%C92!P;VUO
M8^T@1E10`%-E;&AA;&\@>NUS:^%N[2!M;[YN;W-T[2X`3F5L>F4@<V4@</AI
M<&]J:70@:R!,1$%0('-E<G9E<G4N`$YE;'IE('-E('#X:7!O:FET(&L@4TU"
M('-E<G9E<G4N`%-E;&AA;&\@:V]P[7)O=N%N[2!Z("(E<R(N`%-E;&AA;&\@
M:V]P[7)O=N%N[2!D;R`B)7,B+@!396QH86QO('IA;&^^96[M(&YO=NEH;R!3
M05-,('-P;VIE;NTN`%-E;&AA;&\@</AE<W5N=73M(&1O("(E<R(N`$1O8G+I
M`$9A;&ML86YD<VOI(&]S=')O=GD@*$UA;'9I;GDI`$9A<FEJ<VOI(&]S=')O
M=GD`6N%V8;YNX2!C:'EB83H`1F%X`-IN;W(`0^UT:70@<V4@:F%K;P!#[71I
M="!S92!J86MO.@!$<F]B;ND@</AE:.'R:WD`1')O8F[I('-N[&AO=ND@</AE
M:.'R:WD`36%T:6-E('!O;&4`1FEJ:0!0;^AE="!S;W5B;W+Y.B`E<R!S;W5B
M;W(`4&_H970@<V]U8F]R^3H@)7,@<V]U8F]R^0!3<'+A=F-E('-O=6)O<OD`
M3N%Z978@<V]U8F]R=0!6_6+L<B!S;W5B;W)U`%#X96[I<W0@<V]U8F]R`%#X
M96YO<R!S;W5B;W+Y(&YE;NT@<&]D<&]R;W;A;BX`1FEL=')Y`%9Y:&QE9&%T
M`$9I;G-K;P!0<G9N[2!P;VQO=FEN80!0<G9N[2#H='9R=&EN80!0979NZ2!M
M[/CM=&MO`%#X96AO9&ET`%!L;W9O=6/M`$UL:&$`4VQOOFMA("5S(&YE97AI
M<W1U:F4`0F%R=F$@<.US;6$`2NUD;&\`4')O('!R;VAL[;YEZ&4@;F5P;V1P
M;W)U:NUC[2!O8G+A>FMY`%#X961P;W;L[R`H5$%&*0!0^&5D<&]V[.\@<&_H
M87/M('!R;R!D;GD@*'!O>F[A;6MA.B!P^&5D<&]V[.\@:F4@<')O(&1N>2!I
M(&YO8VD[('1O=&\@;?F^92!V>71V;_AI="!P;VWL<F[L(&]B<^%H;/T@<V5Z
M;F%M+@!:87!O;6[L;&D@:G-T92!68;EE(&AE<VQO/P!&;W)M=6SA^&4`J73L
M<W3M`%1Y<""Y=.QS=.T`J73L<W3M`*ET['-T[2`R`$;S<F$`4/AE<&]S;.%N
M[0!0X0!2X6UY`$9R86YC:64`1G)A;F-I92P@;65T<F]P;VQI=&[M`$9R86YC
M;W5S:^$@1W5A:>%N80!&<F%N8V]U<VOA(%!O;'ENZ7-I90!&<F%N8V]U<VOA
M(&IIOF[M('1E<FET;W)I80!0X71E:P!/9`!/9`!0;V1R;V)N_2!P;W!I<P#:
M<&QN[&L`0V5LZ2!J;>EN;P!"=61O=6-N;W-T`$=A8F]N`$=A;&5R:64@<')O
M(';]8NQR(&]B<N%Z:_D`1V%L97)I93H`1V%M8FEE`$AR80!6N65O8F5C;NP`
M5GET=F_X:70@)7,@:V]N9FEG=7)A8VD`5GEG96YE<F]V86[](&OS9`!'<G5Z
M[6YS:V\`3NQM96-K;P!':&%N80!':6)R86QT87(`2_AE<W1N[2!J;>EN;P!*
M9&D@;F$`1V]E9&5L`%9Y:&QE9.%VX6[M('!O;6]C[2!';V]G;'4`2NUT(&YA
M("5S`%-T=7!N[""Y961I`-AE8VMO`-AE8VOI("A)4T\M.#@U.2TW*0!'<O-N
M<VMO`$=R96YA9&$`061M:6YI<W1R86-E('!R;R!S:W5P:6YY`$UU<^T@8OUT
M('IA9.%N;R!J;>EN;R!S:W5P:6YY`%-K=7!I;GD`1W5A9&5L;W5P90!'=6%M
M`$=U871E;6%L80!'=65R;G-E>0!0<N%V82!H;W-T^0!+;FEH82!H;W-T^0!'
M=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!Z8F%B
M[&QE(&]D;>UTX2!S;6%Z870@<&]S;&5D;NT@8G7R:W4@;F$@^.%D:W4N`$A4
M34Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P;W-L961N[2!B=?)K=2!V
M92!S;&]U<&-I('1A8G5L:WDN`$A434Q!<F5A('IB86+L;&4@;V1M[73A('-M
M87IA="!P;W-L961N[2#XX61E:R!V('1A8G5L8V4N`$]V[/AO=N%N[2!P;VUO
M8^T@2%144"!N96)Y;&\@;F%L97IE;F\N`$AA:71I`$AA<V@M86QG;W)I=&UU
M<P!-;&AA=F\`2&QA=FGH:V$`2&5A<F0@27-L86YD(&$@36-$;VYA;&0@27-L
M86YD<P!(96)R96JY=&EN82`H25-/+3@X-3DM."U)*0!6_;EK80!.X7!O=NQD
M80!.X7!O=NQD82!P<F\@961I=&]R`%!O;6]C;NUK`$AE;6ES9NER80!:9&4@
M:F4@>F'HX71E:R!S;W5B;W)U.@!6>7-O:^$`7TAO<F1E`%-V873I($WL<W1O
M("A6871I:^%N*0!(;W)D90!!9')E<V$@9&]M^0!496QE9F]N(&1O;?D`2&]N
M9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!.97!L871NZ2`E
M<R!834P@9&%T82!V92!Z<'+A=NP@)7,`2&]R9&4O2V]L86(Z(*[A9&[A('IP
M<N%V82!S92!N97-H;V1U:F4@<R!O8FIE:W1E;2`E<P!(;W)D92]+;VQA8CH@
M3F5B>6P@;F%L97IE;B"^X61N_2!O8FIE:W0@='EP=2`E<R!V92!Z<'+A=NP@
M)7,`2&]R9&4O2V]L86(Z(-IS<.RY;ND@;V1S=')A;NQN[2`E<R`B)7,B`$AO
M<F1E+TMO;&%B.B!);G1E9W)AZ&[M(&[A<W1R;VH@<&]T^&5B=6IE(%!(4"!P
M^.UP;VYU("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!.96QZ92!V>71V;_AI="!N
M;W;]('-T<F]M(%A-3"!P<F\@;V)J96MT("5S`$AO<F1E+TMO;&%B.B!.96QZ
M92!O9'-T<F%N:70@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YE;'IE('KM
M<VMA="!-24U%($E$('!R;R#HX7-T('1Y<'4@)7,`2&]R9&4O2V]L86(Z($YE
M;'IE('-Y;F-H<F]N:7IO=F%T("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.
M96QZ92!S>6YC:')O;FEZ;W9A="!S9.UL96[I(&]B:F5K='DZ("5S`$AO<F1E
M+TMO;&%B.B!.97INX6W]('-D[6QE;OT@;V)J96MT("(E<R(`5F]D;W)O=F[I
M('!R87;M=&MO`$AO<FEZ;VYTX6QN[2!O9'-T=7``2&]R:7IO;G3A;&[M.@!(
M;V1I;BAA*0!*86L@:G-T92!S92!S96T@9&]S=&%L:3\@*%IAN6QE=&4@<')O
M<^UM('IP<N%V=2$I`$MO;&EK('-L;W5P8_D@8VAC971E('-P;VII=#\`2V]L
M:6L@:F4@=&%M('!O;.T@*'-L;W5P8_DI/P!+;VQI:R#XX61K^2!C:&-E=&4@
M<W!O:FET/P!6;&AK;W-T`%9L:&MO<W0Z`$AU;6]R;ND`36'O87)S:V\`4V5L
M:&%L;R!V>71V;_AE;NT@24U!4&]VZ2!S8VARX6YK>3H@)7,`4V5L:&%L;R!S
M;6%ZX6[M($E-05!O=ND@<V-H<N%N:WDZ("5S`%-E;&AA;&\@;F%S=&%V96[M
M(&MV\W1Y('!R;R!)34%0;W9O=2!S8VARX6YK=3H@)7,`25`@861R97-A`$E0
M(&%D<F5S82!N96[M(&1O<W1U<&[A+@!)4"!A9')E<V$@;F5N[2!V('!O=F]L
M96[I;2!#2412(')O>G-A:'4N`%!O<G6Y96[M(&EN=&5G<FET>2!)4"X`5E]L
M;[YT92#XX61E:R!P^&5D`$ES;&%N9`!0;W5Z92!I:V]N>0!):V]N>2!P<F\@
M)7,`26MO;GD@<R!T97AT96T`3N%Z978@:61E;G1I='DZ`%!O:W5D('IO8G)A
M>F5N[2!N96[M('8@<&_XX61K=2P@)7,@;W1E=OCM="!V(&YO=NEM(&]K;NPN
M`%!O:W5D('!O=;[M=N%T92!);G1E<FYE="!%>'!L;W)E<B!A(&YE=FED[71E
M(+[A9&[I(&EK;VYY+"!Z^&5J;>P@<&]T^&5B=6IE=&4@;WIN8>AI="!T96YT
M;R!RX6UEZ&5K('!R;R!V>7!N=73M(%!.1R!T<F%N<W!A<F5N8V4N`%!O:W5D
M('9I9.UT92!T=71O('IP<N%V=2!M[7-T;R!O8G+A>FMU+"!O8G+A>F5K(&MT
M97+](&-H8V5T92!P^&5NZ7-T(&YE;'IE(%9AN>UM('!R;VAL[;YEZ&5M('IO
M8G)A>FET+@!.X6AL960@;V)RX7IK=3H`55),(&]B<N%Z:W4`55),(&]B<N%Z
M:W4Z`$]B<N%Z96L@>B!G86QE<FEE`$]B<N%Z96L@>B!G86QE<FEE.@!0^&5N
M;W,@;V)RX7IK=0!/8G+A>FMY`$EM<&]R=&]V870@2V%L96YDX?@L($MR;VL@
M)60`26UP;W)T+"!K<F]K("5D`$EM<&]R=&]V870O17AP;W)T;W9A="!+86QE
M;F3A^`!);7!O<G1O=F%NZ2!P;VQE.B`E<P!);7!O<G1O=F%NX2!P;VQE.@!6
M;&^^:70@^.%D:W4@>F$`0GEL('IA9.%N(&YE<W!RX79N_2!A:^AN[2!K\V0N
M`$YE<W!RX79N["!Z861A;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE
M<VQO+@!.97-P<N%V;ND@=;YI=F%T96QS:^D@:FWI;F\@;F5B;R!A;'1E<FYA
M=&EV;NT@861R97-A+B!::W5S=&4@:F6Y=.P@:F5D;F]U(&YE8F\@:V]N=&%K
M='5J=&4@5F&Y96AO('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T;W)A+@!:=NQT
MN6ET(&]D<V%Z96[M`$EN9&EE`$IE9&YO=&QI=NT@=;YI=F%T96SI`$EN9&]N
MZ7-I90!);F9O<FUA8V4`26YF;W)M86-E`%9L;[YI="!S7VQO=7!E8R!Z80!6
M;&^^:70@;V)RX7IE:P!6;&^^:70@=&%B=6QK=0!6;&^^:70@=V5B;W;](&]D
M:V%Z`%9L;[YI="!?<VQO=7!E8R!P^&5D(`!6;&^^:70@;F]V_2!S;&]U<&5C
M('IA('-O=>AA<V[]`%9L;[YI="!N;W;]('-L;W5P96,@</AE9"!S;W7H87-N
M_0!6;&^^:70@;F]V_2#XX61E:R!Z82!S;W7H87-N_0!6;&^^:70@;F]V_2#X
MX61E:R!P^&5D('-O=>AA<V[]`%9L;[YI="!O9'-T879E8R!Z82!S;W7H87-N
M_2!U>F5L`%9L;[YI="!O9'-T879E8R!P^&5D('-O=>AA<V[]('5Z96P`5FQO
MOFET(&%L=&5R;F%T:79N[2!V>F]R`%9L;[YT92!E;6%I;&]V;W4@861R97-U
M+"!N82!K=&5R;W4@;V)D<K[M=&4@;F]VZ2!H97-L;SH`5FQOOFET(&)U\FMU
M('IA`%9L;[YI="!B=?)K=2!P^&5D`%9L;[YI="!S;&]U<&5C('IA`%9L;[YI
M="!S;&]U<&5C('#X960`5FQOOFET('IP<N%V>0!6;&^^:70@;V1S=&%V96,@
M>F$`5FQOOFET(&]D<W1A=F5C('#X960`5FQOOFET(/CA9&5K('IA`%9L;[YI
M="#XX61E:R!P^&5D`%9L;[YT92!P;[YA9&]V86YO=2!O9'!O=NSO(&YA(&)E
M>G!EZ&YO<W1N[2!O=.%Z:W4Z`%9L;[YI="]U<')A=FET(&]B<N%Z96L`5FQO
MOFET+W5P<F%V:70@;V1K87H`3F5D;W-T871EZ&[](&MR961I="!K(&]D97-L
MX6[M('IP<N%V>2!N82!D:7-T<FEB=>AN[2!S97IN86TN`$YE9&]S=&%T9>AN
M_2!K<F5D:70N`$-E;.D@Z.US;&\`4V5Z;F%M(&-E;/UC:"#H[7-E;`!.97-P
M<N%V;ND@541(+B`H57-E<B!$871A($AE861E<BDN`$YE<&QA=&[A(&%P;&EK
M86-E+@!.97!L871NZ2!I9&5N=&EF:6MAZ&[M(.CM<VQO("A)1"D@9.%V:WDN
M`$)Y;&$@>F%DX6YA(&YE<&QA=&[A(&1A=&$`3F5P;&%T;N$@861R97-A('#X
M[6IE;6-E+@!.97!L871N_2!F;W)MX70@<V]U8F]R=0!.97!L871N_2!M<V=?
M='EP92X`3F5P;&%T;ND@;F5B;R!C:'EB[&KM8^T@87!I7VED+@!.97!L871N
MZ2!N96)O(&-H>6+L:NUC[2!P87)A;65T<GDN`$YE<&QA=&[A('9L87-T;FEC
M:^$@<'+A=F$N`$YE<&QA=&[]('!R;W1O:V]L+@!.97!L871N_2!S9.UL96[]
M(&]B:F5K=`!.97!L871NX2!A9')E<V$@;V1E<^UL871E;&4N`$YE<&QA=&[A
M(&1A=&$@=6YI8V]D92X`26YV96YTX?@`S7+A;BP@27-LX6US:^$@<F5P=6)L
M:6MA`$ERX6L`27)S:V\`3W-T<F]V(&UUOF4`3VIE9&EN[&SI(&)O=?AK>0!)
M<W)A96P`4&]S:WET;W9A=&5L`$MU<GKM=F$`273A;&EE`$IA;6%J:V$`3&5D
M96X`2F%P;VYS:V\`2F%P;VZY=&EN82`H25-/+3(P,C(M2E`I`%1R:6MO=`!*
M;W)DX6YS:V\`R&5R=F5N96,`R&5R=F5N`%IA<F]V;F%T`%IA<F]V;F%T(&YA
M('-T^&5D`%IA<F]V;F%T('9Y<&QN[&[M;0!:87)O=FYA="!D;VQE=F$`6F%R
M;W9N870@9&]P<F%V80!+87IA8VAS=.%N`%5C:&]V870@;W)I9VENX6P_`$ME
M\F$`2V5R8F5R;W,@<V5R=F5R('IA;>UT;G5L(&]V[/AE;NTN`$YO=N'H8VD@
M:V5R;F5L=0!6>71V;_AE;NT@:VSMZ&4`5GET=F_X96[M(&]T:7-K=2!K;.WH
M90!$Z6QK82!K;.WH90!4>7`@:VSMZ&4`5;YI=.T@:VSMZ&4`2VSMZ"!J:;X@
M97AI<W1U:F4@;F$@=F7X96INZ6T@:VSMZ&]VZ6T@<V5R=F5R=2X`2VSMZ&]V
MX2!S;&]V80!$['1I`$MI<FEB871I`$M,1%(`2V]R96$`2V]R96IS:WD@*$55
M0RU+4BD`2W5V86IT`$MY<F=I>G-TX6X`7U)O>FQOOF5N[0!*87IY:P!,86]S
M+"!,:61O=NP@1&5M;VMR871I8VMA(%)E<'5B;&EK80!0;W-L961N[6-H(#(T
M(&AO9&EN`$1R=6CA('!O;&]V:6YA`$YA<&]S;&5D>2!:;>QN[&YO`$UI;G5L
M_2!-['/M8P!0;W-L961N[2#H='9R=&EN80!0;W-L961N[2!A:W1U86QI>F%C
M93H`4&]S;&5D;NT@</AI:&SAN65N[3H@)7,`4&]S;&5D;NT@</AI:&SAN65N
M[3H@)7,@>B`E<P!0;W-L961N[2!P^&EH;.&Y96[M.B!.:6MD>0!-:6YU;/T@
M=/UD96X`3&ET=F$`4'+A=F\`4F]Z;&^^96[M`$YE8VAA="!P<N%Z9&[I(&)E
M>B!O:W)A:F4`3&EB86YO;@!$;VQE=F$`3&5VX2!H;&%V:>AK80!(;V1N;W1Y
M(&YA;&5V;P!,97-O=&AO`$QI8NER:64`3&EB:64`3&EC:'1E;KET96IN<VMO
M`$QE:&OI(&UR:&]L96[M`$QE:&O](&3IN;L`0G)Z:_T@;&5H:_T@9.FYNP!0
M;WID[&II(&QE:&O](&3IN;L`3&5H:^D@9&6YNV]VZ2!S<N&^:WD`3&5H:_T@
M9.FYNR!S(&CX;>QN[6T`3&5H:^D@<V[LOF5N[0!,96AKZ2!S;NQH;W;I('#X
M96CA\FMY`$QI;65R:6-K`$QI;6ET;W9A="#H87-O=ND@<F]Z<.QT[2!P<F\@
M97AP;W)T;W;A;NTZ`$]D:V%Z`$]D:V%Z>2!U:V%Z=6KM(&YA.@!0;W6^[70@
M;V1K87IY(&YA(&5M86EL;W;I(&%D<F5S>2!P^&D@>F]B<F%Z;W;A;NT@<W1R
MX6YK>2!P<F\@<'-A;NT@>G!RX78`3V1K87IY`$QI;G5X;W;I(&-O;VMI90!3
M97IN86T@+2!UOFEV871E;"!M^;YE('9I9.QT('-L;[YK=0!397IN86T@9&%T
M86+A>NT`4V5Z;F%M('3I;6%T(&[A<&]V[&1Y`%-E>FYA;2!T86)U;&5K`%-E
M>FYA;2U!<F-H:78`4V5Z;F%M+4[A<&]V[&1A`%-E>FYA;2U)9`!397IN86TM
M5FQA<W1N[6L`4V5Z;F%M+4]D97-LX6[M`%-E>FYA;2U0^&EH;.&Y96[M`%-E
M>FYA;2U/9&ALX;EE;NT`5OUP:7,@=;YI=F%T96SY(&YE;NT@9&]S='5P;OTN
M`$QI=&5R871U<F$`3&]T>;ES:V\`3>U?<W1O`$YA:'+A=N%N[2XN+@!-[7-T
M;NT@Z&%S.B``3&]C86QE(&$@Z&%S`$WM<W1O`%#X:6ALX7-I="!S90!/9&AL
MX;EE;NT`VFMO;'D@<')O=N%D[&[I('#X:2!P^&EH;.&Y96[M`%-E;&AA;&\@
M</AI:&SAN65N[2!D;R!S>7-TZ6UU+B!0<F%V9.QP;V1O8F[L(%9AN64@=;YI
M=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO(&YE8GEL;R!S<'+A=F[L('IA
M9.%N;RX`4/AI:&SAN65N[2!S96QH86QO+@!$;&]U:/T@=&5X=`!,X7-K80!.
M[7IKX0!-86SA(/AE8VOA('#M<VUE;F$`36%LX2!T:7-K86/M('#M<VUE;F$`
M36%LZ2#X[6US:^D@Z.US;&EC90!,=6-E;6)U<G-K;P!-30!:<'+A=F$@9&YE
M`%#X:7!O:F5N_2!S;W5B;W(@35,M3E1%1B!N96]B<V%H=6IE(+[A9&[A(&1A
M=&$N`$U31P!-86MA;P!-86ME9&]N:64L(&+]=F%LX2!297!U8FQI:V$@2G5G
M;W-LX79I90!-861A9V%S:V%R`$UA9VEE`%!ON71A`$%D;6EN:7-T<N%T;W(@
M<&^Y='D`5GET=F_X:70@;V1?:V%Z+BXN`$UA;&%W:0!-86QA:G-I90!-86QD
M:79Y`$UA;&D`36%L=&$`3W9LX63A;NT@<')O('9Z9.%L96[I(&MA;&5N9.'X
M90!0<F\@=6UOOF[L;NT@;W9LX63A;NT@:V%T96=O<FGM(&IE('IA<&]T^&5B
M[2!O>FYAZ&ET('!O;&^^:WD@8F%R=F%M:2P@:W1E<ND@:G-O=2!P^&GX87IE
M;GD@:R!T[&UT;R!K871E9V]R:>UM+@!-87!A($UA<#(T`$UA<&$@36%P475E
M<W0`0OAE>F5N`$]K<F%J`$]Z;F'H:70@>FYAZ&MO=2!0<F]H;.ED;G5T;R].
M97!R;VALZ61N=71O`$]Z;F'H:70@:FEN_6UI('IN8>AK86UI("AJ86MO($3Y
M;&6^:73I+T]D<&]V['IE;NDI`$UA<KEA;'-KZ2!/<W1R;W9Y`$UA<G1I;FEQ
M=64`4VAO9'5J[6/M('-E('!O;&4`36%U<F5TX6YI90!-875R:6-I=7,`36%X
M:6UA;&[M('!O=F]L96[](&MR961I=`!">6QA('#X96MR;^AE;F$@;6%X:6UA
M;&[M(&3I;&MA('IP<N%V>2X`3F5J=GFYN>T@=&5P;&]T82!Z82!P;W-L961N
M[6-H(#(T(&AO9&EN.B``3F5J=GFYN>T@=&5P;&]T82!Z82!P;W-L961N[6-H
M(#8@:&]D:6XZ(`!-87AI;>%L;NT@9.EL:V$`2W;L=&5N`$UA>6]T=&4`365D
M:6/M;F$`4V-H^7IE`,AL96YO=ND`365N=2!397IN86T`3?-D>2!P<F\@;65N
M=3H`4W!O:FET(&)U\FMY`%IP<N%V80!:<'+A=F$@8GEL82!O=NSX96YA('8@
M<&_XX61K=2P@86QE(&YE;'IE(&]V[/AI="!P;V1P:7-O=OT@8V5R=&EF:6OA
M="X`6G!RX79A('!R;W!A9&QA+@!4>7`@>G!RX79Y`%!OZ&%S[0!";&]K(&\@
M<&_H87/M(&YE;NT@9&]S='5P;OTN`$)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T
M=7!N_2X@4&]D<F]B;F]S=&D@8GEL>2!Z87IN86UE;N%N>2!P<F\@<WES=.EM
M;W;I:&\@861M:6YI<W1RX71O<F$@9&\@;&]G=2X`365T;V1A`$UE=')I8VO]
M`$UE>&EK;P!-:6MR;V[I<VEE+"!&961E<F%C90!5<')O<W3X960`5'EP($UI
M;64`3F5J;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``
M3F5J;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!-:6YU
M="AA*0!:<F-A9&QO=NP`4OEZ;ND`5OUP:7,@6FUEN6MA;OUC:"!59.%L;W-T
M[0!0<F]G<F%M;W;](&)A;.UK($A45%!?4F5Q=65S="!C:'EB[2!V(%!%05(N
M`$-H>6+L:NUC[2!K;VYF:6=U<F%C92X@4&]K=60@<VD@</AE:F5T92!P;W6^
M[79A="!T=71O(&%P;&EK86-I+"!M=7/M=&4@=GEG96YE<F]V870@:V]N9FEG
M=7)AZ&[M('-O=6)O<BX`0VAY8NQJ[6/M($E$('IP<N%V>2`H:61E;G1I9FEK
M8>AN[2#H[7-L;RD`4&^^861O=F%N_2!P<F]G<F%M;W;](&)A;.UK($UA:6P@
M8VAY8NT@=B!014%2+@!#:'EB[&KM8^T@240@<')O(')E;&%C:2X`4&\`36]B
M:6QN[2!P;[ET80!-[7)N_0!$871U;2!P;W-L961N[2!Z;>QN>0!:;>SR:70@
M55),`$UO9'5L`$UO;&3A=FEE`$UO;F%K;P!0;VYD[&SM`$UO;F=O;'-K;P!-
M['/M8P!:;V)R87II="!-['/M8P!-['/M8R!A(')O:P!-['/MZ&[L`$WL<^WH
M;NT@5OUP:7,@563A;&]S=.T`3>QS[>AN[#H@4F5K=7)Z[79N["!K8;YD_0!-
M['/M8V4@1&]P^&5D=0!0^&5D($WL<^UC:0!-;VYS97)A=`!&X7IE($WL<^UC
M90!-87)O:V\`4/AE=N&^;NP@:F%S;F\`4/AE=N&^;NP@;V)L8>AN;P!0^&5V
MX;YN["!S;'5N9>AN;P!0;W-U;F]U="!D;VSY`%!O<W5N;W5T(&1O;&5V80!0
M;W-U;F]U="!D;W!R879A`%!O<W5N;W5T(&YA:&]R=0!0;W-U;F]U="!D;VSY
M`%!O<W5N;W5T(&YA:&]R=0!-;W-A;6)I:P!6[6-E+?IR;W;R;W;I(')O;&5T
M;W;I('-E>FYA;7D`0GEL;R!N86QE>F5N;R!N[&MO;&EK(.CA<W3M(&E#86QE
M;F1A<BX@2F4@;6^^;F\@<&]UONUT(&IE;B!J961E;B!V179E;G0N`%;M8V5N
MX7-O8F[A('-E;&5K8V4`3?EJ(/KH970`2V%L96YDX?AE`$MA;&5N9.'X93H`
M1G)E92]"=7-Y(%523`!-^6H@<&]R=.%L`$UO:F4@<F]Z;&^^96[M('!O<G3A
M;'4`37EA;FUA<@!.12P@3D533U5(3$%3S4T`3N%Z978`3F%M:6)I90!.875R
M=0!.97#A;`!.:7IO>F5M[0!.:7IO>F5M<VOI($%N=&EL>0!.971S8V%P92!"
M87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#
M02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E
M=F]C871I;VX@55),`$IMZ6YO($YE='-C87!E(%-33"!S97)V97)U`%!O>F[A
M;6MA(&L@8V5R=&EF:6OA='4@3F5T<V-A<'4`5'EP(&-E<G1I9FEKX71U($YE
M='-C87!U`%/MNP!.:6MD>0!.;W;A($MA;&5D;VYI90!.;W;A(&MA=&5G;W)I
M90!.;W;A(%5DX6QO<W0`3>QS[6,@=B!P<G9N[2#H='9R=&EN[`!.;W;I('6^
M:79A=&5L<VOI(&IMZ6YO("AN97!O=FEN;NDI`$YO=OT@6NEL86YD`$YO=ND@
M;VMN;R`H7W!RX7ID;NDI`$YO=FEN:WD`3F5W<V=R;W5P<P!$86RY[0!$86RY
M[6-H(#(T(&AO9&EN`$1A;+GM($1E;@!$86RY[2!-['/M8P!$86RY[2!4_61E
M;@!$86RY[2!D96X`1&%LN>T@;6^^;F]S=&D`1&%LN>T@=/UD96X`3FEK87)A
M9W5A`$YI9V5R`$YI9^ER:64`3F]C`$YI=64`0F5Z(/KH87-T;NUK^0"N861N
MX2!K;VYF:6=U<F'H;NT@9&%T82!N96IS;W4@9&]S='5P;N$@<')O('IO8G)A
M>F5N[2!R;WID[6SY+@!.96[M(&1O<W1U<&[A(+[A9&[A('-T<F%T96=I92!P
M<F\@='9O<F)U($E33R!O8G)A>ODN`$)E>B!DX79K;W;I:&\@=GIO<G4N`$YA
M('!OOF%D;W9A;ND@<&]Z:6-I(&YE97AI<W1U:F4@ON%D;OT@8FQO:P!.96)Y
M;&\@<&]S:WET;G5T;R"^X61NZ2!J;>EN;R!P<F\@:V%L96YDX?@@</AI(&]V
M[/AO=N%N[2!P;VUO8^T@34-!3"X`KN%D;OT@>B!+86QE;F3A^/D@;F5N[2!D
M;W-T=7!N_2!P<F\@:&]S='DN`$)E>B!Z;>QN>2X`3F5L>F4@</AI9&%T(+[A
M9&[A('!O9"UP<N%V82!K('3L;71O('!RX7;Y;2X`3F5B>6QY('5V961E;GD@
MON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@)7,N`$YE8GEL>2!U
M=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O($944"!6
M1E,N`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA
M8V4@<')O(%-13"!61E,N`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R
M8>AN[2!I;F9O<FUA8V4@<')O(%-13"U&:6QE(%9&4RX`3F5MX71E(+[A9&[]
M(&MR961I="X`3F5B>6P@<&]S:WET;G5T(+[A9&[](&/M;"X`0F5Z(&1N92!U
M:V]NZ&5N[0"NX61NZ2!U9.%L;W-T:2!K('IO8G)A>F5N[0"NX61N_2!S;W5B
M;W(@;F5B>6P@</AE;F5S96X`KN%D;N$@9G)E92]B=7-Y(&EN9F]R;6%C92!N
M96[M(&1O<W1U<&[A('!R;R`E<P!.96)Y;&$@;F%L97IE;F$@ON%D;N$@9&%T
M82!P<F\@:4-A;&5N9&%R+@!.96)Y;'D@;F%L97IE;GD@ON%D;ND@:6MO;GDN
M`$YE8GEL;R!V>6)RX6YO(+[A9&[I(&WM<W1O+@!.96)Y;'D@<&]S:WET;G5T
M>2"^X61NZ2!Z<'+A=GDN`$YE8GEL;R!U=F5D96YO(+[A9&[I(&IMZ6YO+@!.
M96)Y;&\@=79E9&5N;R"^X61NZ2#H[7-L;RX`0F5Z(&YE<VQUN6[]8V@`3F5B
M>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M($A45%`N
M`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!)
M34%0+@!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO
M8^T@2V5R8F5R;W,N`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX
M96[M('#X:6ALX;EE;NT@<V4@9&\@<WES=.EM=2X`3F5B>6QO('!O<VMY=&YU
M=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M(%!!4U-71"X`3F5B>6QO('!O
M<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M(%--0BX`3F5B>6QA
M('!O<VMY=&YU=&$@8V5S=&$@:R!B:6[A<F[M;74@<V]U8F]R=2!/<&5N4U-,
M+B!":6[A<F[M('-O=6)O<B!/<&5N4U-,(&IE('IA<&]T^&5B[2!P<F\@<'+A
M8VD@<R!02T-3(#$R(&1A='DN`*[A9&[I(&YE=GGX[7IE;ND@ON%D;W-T:2!O
M('#X:6ALX;EE;NTN`$)E>B!P<F%V:61E;`!"97H@;VMR86KY`*[A9&[]('H@
M9&_H87-N_6-H(&%D<F5SX?CY(&YE;NT@9&]S='5P;OT@<')O(&-A8VAE+@!.
M96)Y;&\@;V1E<VSA;F\@ON%D;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O
M(&AE<VQO+@!.96)Y;&$@;F%V<N%C96YA(+[A9&[A('!L871NX2!834P@9&%T
M82X`3F5B>6QA(&YA;&5Z96YA(+[A9&[A('!L871NX2!E+6UA:6QO=N$@861R
M97-A`*[A9&[I(&AO9&YO='D`5B!O<FEG:6[A;&[M(&MO;F9I9W5R86-I(&YE
M8GEL82!N86QE>F5N82!V97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C:2X`5F4@
M5F&Y[2!K;VYF:6=U<F%C:2!N96)Y;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V
M=&4@:V]N9FEG=7)A8VDN`*[A9&[A`*[A9&[]("AP;W6^:6IT92!I;7!L:6-I
M=&[M*0!3979E<G-K_2`H25-/+3@X-3DM,3`I`$YO<F9O;&MS:^D@;W-T<F]V
M>0!3979E<F[M('!O;&]K;W5L90!3979E<F[M($UA<FGA;G-KZ2!O<W1R;W9Y
M`$YO<G-K;P!.96[M('!O`$YE;NT@</AE9`!.96[M(&%D<F5SX?AE;0!.96YA
M;&5Z96YO`$YE;NT@:6UP;&5M96YT;W;A;F\N`$YE;NT@;F%S=&%V96YO`$YE
M;NT@<&]D<&]R;W;A;F\N`%!O>F[A;6MA`$YI8R!K('!R;VALZ61N=73M+"!B
M[+YT92!Z<.QT+@!,:7-T;W!A9`!.>6[M`,CM<VQO`%!OZ&5T('IN86OY`%!O
MZ&5T('-L;W5P8_D`4&_H970@^.%D:_D`3F5B>6QA('IA9.%N82#H[7-L82!P
M<F\@86MT=6%L:7IA8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+@!/2P!/8FIE
M:W0`5';Y<F-E(&]B:F5K=/D`3W-M:>AK;W;]`-CM:F5N`$9I;'1R;W9A="!N
M97-L=;ENZ0!+86YC96SA^`!/;>%N`%-D[6QE;ND@<VQOOFMY(&IS;W4@<&]S
M:WET;W;A;GD@<&]U>F4@24U!4"!S97)V97)Y+@!0;W5Z92!N97-L=;ENZ0!*
M92!P;W9O;&5N82!P;W5Z92!J961N82!E+6UA:6QO=N$@861R97-A+@!0;W5Z
M92!V;&%S=&[M:R!N96)O('-Y<W3I;6]V_2!A9&UI;FES='+A=&]R(&WYOF4@
M;>QN:70@<'+A=F$@<')O('-D[6QE;OT@;V)J96MT+@!/=&5V^.UT('8@;F]V
MZ6T@;VMN["X`0VAY8F$@3W!E;E-33#H@3F5L>F4@>NUS:V%T(&1A=&$@>B!P
M;V1E<'-A;ND@Z.%S=&D@4R]-24U%+@!/=&5V^.UT('1E;G1O(&]D:V%Z('8@
M;F]VZ6T@;VMN[`!/<&5R8>AN[2!S>7-TZ6T`3F5P;W9I;F[]`$UOOFYO<W1I
M`$UOOFYO<W1I('!R;R`E<P!39?AA>F5N_2!S97IN86T`3W)G86YI>F%C90!/
M<F=A;FEZ8>AN[2!J961N;W1K80!/<F=A;FEZ;W;A;NT`3W)I9VENX6QN[2!V
M>F]R('!R;R"^X61O<W0`3W)I9VENX6QN[2!V>F]R('8@)7,Z`$]S=&%T;NT`
M3W-T871N[2!I;F9O<FUA8V4`5FQA<W1N[6L`5;YI=F%T96QS:^$@<'+A=F$`
M3W;L^&5N[2!P;VUO8^T@4$%-(&YE;NT@9&]S='5P;NDN`%!'4"!D:6=I=.%L
M;NT@<&]D<&ES`%!'4""Y:69R;W9A;N$@9&%T80!69?AE:F[](%!'4"!K;.WH
M`$1A=&$@<&]D97!S86[A+[EI9G)O=F%NX2!P;VUO8^T@4$=0`%!(4"!K\V0`
M4$A0(&MO;GIO;&$`4$T`3V1P;VQE9&[M(&QE:&O](&3IN;L`3V1P;VQE9&[M
M('#X96CA\FMY`$]D<&]L961N[2!S;NR^96[M`$]D<&]L961N[2!S;NQH;W;I
M('#X96CA\FMY`$]D<&]L961N[2!B;W7X:WD`4%](4"!K;VYZ;VQA`$]D<W1U
M<'D`4.%K:7-TX6X`4&%L874`4&%L97-T:6YS:^D@=&5R:71O<FEU;2P@;VMU
M<&]V86[I`%!A;&T@1&%T94)O;VL`4&%N86UA`%!A<'5A($YO=N$@1W5I;F5A
M`%!A<F%G=6%Y`$WM<W1Y('IA=&&^96YO`$AE<VQO`$YE<W!RX79NZ2!H97-L
M;P!0<F\@;W;L^&5N[2!P;VUO8^T@4D%$54E3(&IE(&YU=&YO('IA9&%T(&AE
M<VQO+@!(97-L;R!S('!O='9R>F5N[6T`2&5S;&\Z`$AE<VQO.B``2&5S;&$@
M<V4@;75S[2!S:&]D;W9A="X`5OUP:7,@<')ON6SM8V@@=63A;&]S=.T`5FQO
MOFET`%9L;[YI="!Z92!S8VARX6YK>0!#97-T80!6>F]R`*[A9&]S=&D@;R!P
M^&EH;.&Y96[M.@!,:63I`%!R;V-E;G0`4')O=NES="!O<&5R86-E(/ID<KYB
M>0!0<F]VZ7-T(&]P97)A8V4@^F1ROF)Y('#X:2!P^&EH;.&Y96[M(&1O('-Y
M<W3I;74_`%!E<FUA;F5N=&[L('-M87IA="!T=71O('5DX6QO<W0_`%!RX79A
M`$YE<&]V;VQE;OT@</CM<W1U<`!0<N%V80!!9&UI;FES=')AZ&[M('!RX79A
M`$]S;V)N[2!I;F9O<FUA8V4`4&5R=0!$;VWA8^T@>G;M^&%T80!&:6QI<.UN
M>0!496QE9F]N`$9O=&]G<F%F:64`4&ET8V%I<FX`4&EX96SY`$9RX7IE`%!R
M;W/M;2!K;&EK;NQT92!N82!N[&IA:V]U(&)U\FMU`%!R;W/M;2!P;W1V<N]T
M92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N=&\@<')V96LZ`%!R;W/M
M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N=&\@<')V
M96LN`%!R;W/M;2!Z861E:G1E(&WL<^UC(&$@<F]K+@!0<F]S[6T@>F%D96IT
M92!NX7IE=B!N;W;I(&MA=&5G;W)I93H`4')O<^UM('IA9&5J=&4@<W!RX79N
M;W4@25`@861R97-U+BX`4')O<^UM('IA9&5J=&4@<W!RX79N_2!D871U;2!A
M('IK;VYT<F]L=6IT92!P;^AE="!D;NT@=B!M['/M8VDN`%!R;W/M;2!Z861E
M:G1E('-P<N%V;OT@Z&%S+@!0<F]S[6T@=79E[W1E('-H<FYU=.T@5F&Y96AO
M('!R;V)LZ6UU+@!0<F]S[6T@>F%D96IT92!68;EE('6^:79A=&5L<VOI(&IM
MZ6YO(&$@:&5S;&\`4')O<^UM('IA9&5J=&4@;F]V_2!NX7IE=B!K871E9V]R
M:64Z`%!O;'-K;P!0;VQI=&EK80!(;&%S;W;A;NT`36^^;F]S=&D@4&]R=.%L
M=0!0;W)T=6=A;'-K;P!5;>US=.QN[2!T;VAO=&\@;V)RX7IK=0!5;>US=.QN
M[2!T86)U;&MY`%IA<VQA="!D;R!TZ71O('-L;[YK>2`H;F5N[2!P;W-K>71N
M=71O($E-05!E;2D`4W+AOFMY('IA('!O<VQE9&[M*&-H*2`E<R!H;V1I;BAU
M*3H@`%!R969S7VQD87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X
M[7!O;F$@3$1!4"X`4')E9G-?<V5S<VEO;CH@3F5B>6QA(&YA;&5Z96YA('!O
MOF%D;W9A;N$@</CM<&]N82!S96MC92X`0F%R;VUE=')I8VO]('1L86L`0F%R
M;VUE=')I8VO]('1L86L@;F$@^G)O=FYI(&UO^&4Z(`!"87)O;65T<FEC:_T@
M=&QA:SH`3N%H;&5D`$[A:&QE9"!O8G+A>FMU('8@;F]VZ6T@;VMN[`!0^&5D
M8VAO>NT@1&5N`%#X961C:&]Z[2!4_61E;@!0^&5D8VAO>NT@9&5N`%#X961C
M:&]Z[2!M;[YN;W-T:0!4:7-K;F]U="!D;VMU;65N=`!0<FEVX71N[2!K;.WH
M`%!R;V)LZ6T`4&]P:7,@<')O8FSI;74`4')O:F5K='D`4')O;7!T('1E>'0`
M5F7X96IN_2!K;.WH`$%L9V]R:71M=7,@<')O('9E^&5J;OT@:VSMZ`!69?AE
M:F[]+W!R:7;A=&[M(&ML[>AO=OT@<.%R(&YE8GEL(/IS<.RY;NP@=GET=F_X
M96XN`%!O<G1O<FEK;P!+871A<@!6>6AL963A;NT`4E-!('9E^&5J;OT@:VSM
MZ"`H)60@8FET^2D`4W#X8;YE;ND@=&QAZ.UT:V\`1.FYNP!"<GIK_2!DZ;F[
M`%!O>F1N[2!DZ;F[`$1EN;MO=ND@</AE:.'R:WD`1.FYNR!S92!S;NQH96T`
M1.FYNR!AOB!S;NUH`$[A:&]D;NP@=GEB<F%NZ2"Y=.QS=.T`4&]M['(`R'1E
M8^T`4/AEZ'1E;ND@>G!RX79Y`$]P<F%V9'4@<VUA>F%T("5S/R!4871O(&]P
M97)A8V4@:F4@;F5V<F%T;N$N`$]P<F%V9'4@<VUA>F%T('6^:79A=&5L<VOA
M(&1A=&$@<')O('6^:79A=&5L92`E<S\@5&%T;R!O<&5R86-E(&IE(&YE=G)A
M=&[A+@!296MU<GKM=F[L(&&^(&1O`$]P86MO=N%N[0!/<&%K;W;A;NT@1&%T
M`$1A='5M($]P86MO=F%N[2!D;P!/<&%K;W9A8^T@26YT97)V86P`3W!A:V]V
M86/M(%1Y<`!/<&%K;W9A="!D96YN[`!/<&%K;W9A="!M97/MZ&[L`$]P86MO
M=F%T('3]9&[L`$]P86MO=F%T(')OZ&[L`$]P86MO=F%T('!O<VQE9&[M(&%K
M8VD`3V)N;W9I="!D>6YA;6EC:^D@<')V:WD@;65N=3H`3V)N;W9A('IO8G)A
M>F5N[2!P;W)TX6QU.B``4F5G97@`4')O:&SMOF7H('9Z=&%H^0!(;V1N;W1Y
M`%5P;VWM;FMA.B`E<P!6>F3A;&5NZ2!+86QE;F3A^&4`5GIDX6QE;ND@2V%L
M96YDX?AE.@!6>F3A;&5NZ2!S97)V97)Y+@!6>F3A;&5NX2!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!/9'-T<F%N:70`3V1S=')A;FET
M("5S`$]D<W1R86YI="#:Z&%S=&[M:V$`3V1S=')A;FET(&)L;VL`3V1S=')A
M;FET('-L;W5P96,`3V1S=')A;FET(&9O<FWA=&]VX6[M`$]D<W1R86YI="!P
MX7(`3V1S=')A=&ET('5L;[YE;OT@<VMR:7!T('H@9&_H87-NZ6AO(&%D<F5S
MX?AE(&YA('-E<G9E<G4N`$]D<W1R86YI=`!/9'-T<F%N:70@='5T;R#HX7-T
M(&1O:W5M96YT=0!/9'-T<F%N:70@=;YI=F%T96QE`$]D<W1R86YI="!UOFEV
M871E;&4Z("5S`$YE;'IE(&]D<&]V[&3L="!N82!P;[YA9&%V96LN($-H>6)O
M=ND@:&SAN65N[3H@`%!O=FEN;ND`4&]V:6YN[2#:Z&%S=&[M8VD`4&^^861O
M=F%NZ2!P;VQE`%;]8VAO>NT@;F%S=&%V96[M`%;]8VAO>NT@;F%S=&%V96[M
M(&AE<VQA`%;]8VAO>NT@;F%S=&%V96[M(%9AN65H;R!H97-L80!297-E=&]V
M870@;F$@26UP;&EC:71N[2!.87-T879E;NT`3V1P;W;L[P!6_7-L961K>0!.
MX79R870@9&\@;6^^;F]S=.T`4F5U;FEO;@!0^&5P;F]U="!K;VYF:6=U<F%C
M:0!-;[YN;W-T:2!2:6-H(%1E>'0@961I=&]R=0!(X61A;FMY`$1O<')A=F$`
M2&QA=FGH:V$@;F%P<F%V;P!(;V1N;W1Y(&YA<')A=F\`5FQA<W1N;W-T:2#X
MX5]D:W4`VFQO:&$`4G5M=6YS:V\`3W1OZ&ET(&\@,3@PL`!/=&_H:70@9&]L
M979A`$]T;^AI="!D;W!R879A`%9L87-T;F]S=&D@^.%D:W4`5FQA<W1N;W-T
M:2#XX61K=0#8X61K>3H`4')A=FED;&$`4')A=FED;&$@<V4@=7!L871N[2!M
M97II(':Y96UI(/CA9&MY(&$@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M
M('!O=7IE(&UE>FD@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M('!O=7IE
M(&UE>FD@^.%D:WD`4')O=NES=`!2=7-KX2!F961E<F%C90!2=V%N9&$`4R]-
M24U%(+EI9G)O=F%N_2!P;V1P:7,`4R]-24U%(+EI9G)O=F%NX2!Z<'+A=F$`
M3W;L^&5N[2!P;VUO8^T@4T%33"!N96[M(&1O<W1U<&[I+@!335,@>G!RX79Y
M`%-13"!K;VYZ;VQA`%-32`#:4U#,0T@`4U]13"!K;VYZ;VQA`%-O`%-V873A
M($AE;&5N80!3=F%T_2!+:71T<R!A($YE=FES`%-A:6YT($QU8VEA`%-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,`4W1E:F[]('+A;2`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@86YD(%!R:6YC:7!E`%9L87-T;NUK('-A=&5L:71U`%-O8F]T
M80!3875D<VOA($%RX6)I90!5;&^^:70@)7,`56QOOFET($IA:V\@3F]V;W4`
M56QOOFET(%5DX6QO<W0`56QOOF5N[2!M;[YN;W-T[0!5;&^^:70@=GET=F_X
M96[](&MO;F9I9W5R8>AN[2!02%`@<VMR:7!T(&1O(&1OZ&%S;NEH;R!A9')E
M<^'X92!N82!S97)V97)U+@!+;VYF:6=U<F%C92`E<R!U;&^^96YA+@!6[&1A
M`%9Y:&QE9&%T`%9Y:&QE9.%V86/M(&[A<W1R;VIE`%9Y8G)A="!S;W5B;W)Y
M`%9Y8G)A="!D871U;0!6>6)R870@<VMU<&EN=2P@:W1E<N$@8G5D92!P^&ED
MX6YA`%9Y8G)A="!N;W;I:&\@=FQA<W1N[6MA`%9Y8G)A="!S97)V97(`5GEB
M<F%T('6^:79A=&5L92P@:W1E<OT@8G5D92!P^&EDX6X`5GEB<F%T(':Y96-H
M;GD@Z.%S=&D@9&%T=6UU+@!6>6)R870@;V)J96MT`%9Y8G)A="!M;[YN;W-T
M:2!P;W1V<GIE;NTL('+Y>F[I('IO8G)A>F5N[2!A('9Y8F5R870@:6UP;&EC
M:71N[2!Z;V)R87IE;NTN`%9Y8G)A="!K86QE;F3A^"!P<F\@:6UP;W)T;W;A
M;NTZ`%9Y8F5R=&4@<&]T^&5B;ND@>FYA:WD@>B!N[;YE('5V961E;OUC:"!B
M;WCY+B!0;W3I(&IE(&WYOF5T92!K;W#M<F]V870@82!V;&^^:70@>B!T97AT
M;W;I(&]B;&%S=&DN`%9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R!D871U
M;3H`5GEB97)T92!F;W)MX70@9&%T=6UU.@!6>6)R870@9F]R;>%T(&5X<&]R
M='4Z`%9Y8G)A="!S;W5B;W(@:R!I;7!O<G1O=N%N[3H`5GEB<F%T('!R=F[M
M(&1E;B!T_61N93H`5GEB<F%T(&9O<FWA="!Z9')O:F]VZ6AO('-O=6)O<G4Z
M`%9Y8F5R=&4@:61E;G1I='4L(&MT97)O=2!S:2!P^&5J971E('IM[&YI=#H`
M5GEB97)T92!O9&3L;&]V86/M('IN86L@<')O(.AA<SH`5GEB97)T92!F;W)M
MX70@Z&%S=3H`5GEB<F%T(.AA<V]VZ2!R;WIP['3M(&L@>F]B<F%Z96[M.@!6
M>6)R870@>F]B<F%Z96[M('!O('#X:6AL8;EE;NT@<V4Z(`!6>6)E<G1E(&1V
M["!O9'!O=NUD86KM8^T@<&]L92X`5GEB<F%T(&IA:^D@=63A;&]S=&D@<V4@
M;6%J[2!Z;V)R87II="!V('!O<G3A;'4N`%9Y8F5R=&4@8F%R979N_2!M;W1I
M=BX`5GEB97)T92!6X6UI('!R969E<F]V86[](&IA>GEK.@!0;W-L870@>G!R
MX79U(&\@<')O8FSI;74`4&]S;&%T(%--4P!:87-L870@>G!RX79U(&\@>G)U
MN65N[2!U9.%L;W-T:2!VN65M(/KH87-T;NUK^6TL(&MD>;X@<V4@=63A;&]S
M="!S;6%ZX7;A`%IA<VQA="!E;6%I;"`E<P!:87-L870@86MT=6%L:7IA8VDO
M<&]Z=N%N:W4@=KEE;2#ZZ&%S=&[M:_EM+"!K9'F^('-E('5DX6QO<W0@=6ML
MX63A`%-E;F5G86P`4V5N<V]R.@!:X?CM`%-R8G-K;R!A(,AE<F[A($AO<F$`
M4^ER:6]VZ2#H[7-L;P!)1"!S96MC92!Z86YI:VQO+@!.87-T879I=`!.87-T
M879I="!K;VYEZ&[](&1A='5M`$YA<W1A=FET(&UOOFYO<W1I('!R;R!P;W9O
M;&5N[2!R97-E='4@:&5S;&$L('!O:W5D(&AO('IA<&]M96YE=&4N`$MO;F7H
M;OT@9&%T=6T@;W!A:V]V86[M`$YA<W1A=FET(&1A='5M('IAZ.%T:W4`3F%S
M=&%V:70@=GIDX6QE;ND@<V5R=F5R>2!T86LL(+YE(&)U9&]U('#X[7-T=7!N
MZ2!Z('!O<G3A;'4N`$YA<W1A=F5N[2!6X6UI('!R969E<F]V86[I:&\@:F%Z
M>6MA+"#H87-O=NEH;R!PX7-M82!A('1Y<'4@9&%T=6UU+@!.87-T879E;NT@
M<&_HX71EZ&[M(&%P;&EK86-E+"!B87)E=F[I:&\@;6]T:79U+"!O8FYO=F]V
MX6[M('-T<N%N96L@82!D86RY[6-H(&UOOFYO<W3M('IO8G)A>F5N[2X`3F%S
M=&%V96[M`$YA<W1A=F]V86/M(&MO;F9I9W5R8>AN[2!S:W)I<'1Y('!R;R!A
M:W1U86QI>F%C:2!J<V]U(&1O<W1U<&[I`$[L:W1E<N$@;>US=&$@;'IE(&YA
M<W1A=FET(',@=.UM=&\@<&%R86UE=')E;3H@`%-E>6-H96QL97,`4V3M;&5N
MZ2!+86QE;F3A^&4Z`$YA:W5P;W;A;NT`2W+A=&OI('-H<FYU=.T`3>QL>2!B
M>2!B_70@</CM<W1U<&]VZ2!K;.WH92!D969I;F]VX6YY('!R;R!V['2Y:6YU
M(&]D:V%Z^3\`6F]B<F%Z:70`6F]B<F%Z:70@;&5G96YD=2!K871E9V]R:>T_
M`%IO8G)A>FET(&EK;VYK>2!P<F\@<VUA>N%N[2P@86QA<FT@82!O<&%K;W;A
M;NT@</AI('IO8G)A>F]VX6[M(&MA;&5N9.'X93\`6F]B<F%Z:70@<F]Z9.UL
M>2!M97II('-O=>AA<VYO=2!A('#X961C:&]Z[2!K;VYF:6=U<F%C[2X`6F]B
M<F%Z:70@;^AE:^%V86[I('5D86QO<W1I('8@:V%L96YDX?AI/P!:;V)R87II
M="!L96=E;F1U('!R;R!F<F5E+V)U<WD_`%IO8G)A>FET(.AA<R!P;W-L961N
M[6AO('#X:6ALX;EE;NT@9&\@<WES=.EM=3\`36%J[2!S92!U:^%Z870@<&]U
M>F4@=63A;&]S=&D@<R!A;&%R;65M/P!:;V)R87II="!M;[YN;W-T('5D<KYE
M;NT@;W)I9VENX6QU`%IO8G)A>FET('-B[')AZ`!:;V)R87II="!M96YU(&]P
M97)AZ&[M(&QIN71U('!R;R!T86)U;&MY/P!:;V)R87II="`E<R!M96YU(&YA
M;&5V;S\`6F]B<F%Z:70@9&EA;&]G('!R;R!V;&%S=&YO<W1I(&)U;NQK('8@
M=&%B=6QKX6-H`%IO8G)A>FET(&1I86QO9R!V;&%S=&YO<W3M('1A8G5L96L`
M6F]B<F%Z:70@9&EA;&]G('9L87-T;F]S=.T@^.%D96L@=&%B=6QE:P!:;V)R
M87II="!D:6%L;V<@=FQA<W1N;W-T[2!O8G+A>FOY`%IO8G)A>FET(.AA<R!M
M97II(&MAOF3];2!D;F5M('8@=/UD96YN[6T@>F]B<F%Z96[M/P!:;V)R87II
M="!P^&5N;W,`4/AE:.'R:WD`0G)Z:^D@</AE:.'R:WD`4&]Z9&[M('#X96CA
M\FMY`%#X96CA\FMY('8@;VMO;.T`6FUE;KEI=`!:;65NN6ET(&YE8F\@<&]S
M=6YO=70@9&\@<V]U<V5D;NUH;R!B;&]K=2CY*2P@>B!C97-T>2!P<G9N[6UU
M`%-I97)R82!,96]N90!296=I<W1R;W9A="!S90!0;V1P:7,`06QG;W)I=&UU
M<R!P<F\@<&]D<&ES`%-I;F=A<'5R`%9E;&EK;W-T`%9Y;F5C:&%T(/ID<KYB
M=0!3;&]V96YS:V\`4VQO=FEN<VMO`%-N[+YE;NT`4V[L:&]VX2!P^&5HX?)K
M80!3;NQH;W;I('#X96CA\FMY`%)A;F[M('-N[&AO=ND@</AE:.'R:WD`4&]Z
M9&[M('-N[&AO=ND@</AE:.'R:WD`4V[L:&]VX2!P;VMR_79K83H`5F]D;NT@
M96MV:79A;&5N="!P<F\@<V[M:#H@`*EA;&%M;W5N;W9Y(&]S=')O=GD`4V]M
MX6QS:V\`4.US;NP@82!BX7-N[`!3;>QR('3X[63L;NT`6F1R;VIO=N$@861R
M97-A`$IIOF[M($%F<FEK80!*:6AO979R;W!S:_T@*$E33RTX.#4Y+3,I`%-O
M=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$II
MOF[M('!O;&]K;W5L90!0<F]S=&]R(&UE>FD@<V]U<V5D;NUM:2!B=?)K86UI
M`%!R;W-T;W(@;65Z:2!O8G-A:&5M(&$@:')A;FEC96UI('8@8G7R8V4`365Z
M97)N[6L`365Z97)Y`$]D<W1U<'D@82!M97IE<GD`J7!A;NQL<VMO`%-P86T`
M5G-T=7`@<')O('IV;.&Y=&[M('IN86MY`%)O>F3L;&ET(&)U\FMU`%)O>F3L
M;&ET('-L;W5P96,`4F]Z9.QL:70@^.%D96L`4W!O<G0`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!$871U;2!:8>CA=&MU`%IAZ.UNX2!6`,AA<R!:
M8>CA=&MU`%)O:R!Z8>CA=&MU`%-T85]V`%-TX70@Z&D@<')O=FEN8VEE`%-T
M878`1F]R;>%T('5L;[YE;NT`56QI8V4`4/AEN6MR=&YU=/T`4V5Z;F%M(/AE
M=.QZ8V4`3V1S=')A;FET(&1O;>EN;W;I(&IMZ6YO('H@861R97-Y`%-T>6P@
M6T-34UT`3F4`4/AE9&WL=`!0;V1A=`!$;VQN[2!I;F1E>`#:<W#LN6[L`$MO
M;F9I9W5R86-E(&)Y;&$@^G-P[+EN["!Z;>QN[&YA+B!/8FYO=G1E('-T<N%N
M:W4N`-IS<.RY;ND@=6QOOF5N[2!ZX6QOOF[M(&MO;F9I9W5R86-E+@#:<W#L
MN6[I('5L;[YE;NT@>N%L;VAY(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N
M`"5S(&)Y;&\@^G-P[+EN["!Z87!SX6YO`%-U9.%N`%-H<FYU=.T`4W;M=.%N
M[0!:X7!A9"!3;'5N8V4`3F5D[&QE`%-L=6YEZ&YO`%;]8VAO9"!3;'5N8V4`
M5OUC:&]D+WKA<&%D(%-L=6YC90!6_6-H;V0@4VQU;F-E.B``6N%P860@4VQU
M;F-E`%KA<&%D(%-L=6YC93H@`$AO<F[M(&EN9&5X`%!O9'!O<F$`4W5R:6YA
M;64`4/CM:FUE;NT`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QS:V\`
MJ7;I9'-K;P"I=OUC87)S:V\`4WEN=&%X;W;A(&-H>6)A('8@:&QE9&%NZ6T@
M=&5X='4`4_UR:64`0F]U^&MA`$)O=?AK>0!44U8@<V]U8F]R`%1A8G5L:V$`
M5FQA<W1N;W-T:2!T86)U;&MY`%9L87-T;F]S=&D@=&%B=6QK>0!486EW86X`
M5&%I=V%N+"!P<F]V:6YC:64@R.UN>0!4862^:6MI<W3A;@!486YZX6YI92P@
M4W!O:F5NX2!R97!U8FQI:V$`0^UL.@!59.%L;W-T:0!496QE9F]N;NT@Z.US
M;&\`5&5P;&]T82!Z82!P;W-L961N[2!H;V1I;G4Z(`!497!L;W1A`%1E<&QO
M=&$Z(`!6>F]R('!R;R!A9&UI;FES=')A8VD`4/AE9&+LOF[]`%1E>'0`4&]U
M>F4@=&5X=`!:87)O=F[A;NT@=&5X='4`5G)C:"!T97AT=0#(=`!4:&%J<VMY
M("A425,M-C(P*0!4:&%J<VMO`$3L:W5J96UE('IA('!O=;[M=N%N[2!S>7-T
MZ6UU+@!3='+A;FMA(',@57!R879O=2#:Z&%S=&[M:_D@:FF^(&YE;NTN($MO
M;NCM;2X`4/CM<&]N82!P<F\@1E10(&YE;NT@9&]S='5P;N$N`$EN=&5G<F'H
M;NT@86QG;W)I=&UY('8@2&]R9&4O2V]L86(@;F5P;V1P;W)U:NT@(B5S(@!.
M9?IS<.RY;ND@;F'H=&5N[2!T^.UD>2!-86EN=&5N86YC93HZ`$)Y;&\@=7IA
M=OAE;F\@;VMN;R!S(&UOOFYO<W1M:2X@56MO;NAE;F\N`$%D;6EN:7-T<NUT
M;W(@<&]T^&5B=6IE(&YA:V]N9FEG=7)O=F%T('1R=F%LX2!P<N%V82!V('-Y
M<W3I;74L('!O:W5D('-I('#X96IE=&4@<&]UONUT('!RX79A+@!0;W5Z92!S
M<&]D;NT@<W1R86YA`$YE;'IE('-M87IA="!K86QE;F3A^"`B)7,B+@!+86QE
M;F3A^"`B)7,B(&)Y;"!S;6%ZX6XN`$MA;&5N9.'X("(E<R(@8GEL('#X96IM
M96YO=N%N(&YA("(E<R(N`$MA;&5N9.'X("(E<R(@8GEL('5L;[YE;BX`3F5B
M>6QO('5V961E;F\@240@<')O(&MO;G1A:W0L(&YE8GEL;R!N86QE>F5N;R!V
M(&1A=&%BX7II(&YE8F\@8GEL;R#Z<&QN["!V>6YE8VCA;F\N`$MO;G1A:W0@
M8GEL(/IS<.RY;NP@</AI9.%N(&1O(%9AN65H;R!A9')E<^'X92X`2R!O=NSX
M96[M('!O9&5P<V%NZ2!Z<'+A=GD@:F4@=/AE8F$@;V1D[&QE;OT@8FQO:R!S
M(%!'4"!P;V1P:7-E;2X`3F5B>6QO('5V961E;F\@240@9&ES=')I8G7H;NUH
M;R!S97IN86UU+"!N96)Y;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O(&)Y
M;&\@^G!L;NP@=GEN96-HX6YO+@!.96)Y;"!U=F5D96X@9&ES=')I8G7H;NT@
M<V5Z;F%M+@"I:69R;W9A8^T@;6^^;F]S=&D@;'IE('9Y=;[M="!P;W5Z92!P
M^&D@8F5Z<&7H;NEM('-P;VIE;NT@<R!W96)E;2`H:'1T<',I+@!$871U;2!K
M;VYC92!M=7/M(&+]="!P;R!D871U('IAZ.%T:W4N`%5P;WIO<F[L;NT@;R!U
M9.%L;W-T:2!B>6QO(/IS<.RY;NP@>F%S;.%N;R!P<F\@)7,N`%-O=6)O<B`E
M<R!B>2!M[&P@;V)S86AO=F%T(&YA<W1A=F5N[2`E<RX`4V]U8F]R("5S(&)Y
M(&WL;"!O8G-A:&]V870@;NQK=&5RX2!Z(&YA<W1A=F5N[2`E<RX`4V]U8F]R
M(&YE;'IE(&MO<.UR;W9A="!SX6T@9&\@<V5B92X`4V]U8F]R(&YE;V)S86AU
M:F4@ON%D;N$@9&%T82X`3N%S;&5D=6KM(&AL879IZ&MY('!R;R!M97-S86=E
M+W)F8S@R,B!Z<'+A=G4`3N%S;&5D=6IE('!O9')O8F[L:KGM('!O<&ES('5D
MX6QO<W1I.@!*92!Z;N%MZ2P@OF4@;?-D('#X97,@8V5L;W4@;V)R87IO=FMU
M('8@26YT97)N970@17AP;&]R97)U('#Y<V]B[2!P<F]B;.EM>2P@<')O=&^^
M92!S92!V(&[L;2!V>7-K>71U:F4@8VAY8F$L(&MT97+I('-E(&YE;'IE('9Y
M:&YO=70N($IA:V\@;N%S;&5D96L@;?F^92!B_70@;N%H;V1NZ2!Z:')O=6-E
M;NT@=&]H;W1O('!R;V=R86UU+"!C:'EB[&KM8^T@9G5N:V-E(&5D:71O<G4@
M;F5B;R!N97-P<N%V;ND@>F]B<F%Z;W;A;NTN(%!O:W5D(&IE(%;AN2!S>7-T
M96WI;2!7:6YO9'=S(#EX+"!J92!V96QM:2!P<F%V9.QP;V1O8F[I+""^92!S
M92!O8FIE=NT@8VAY8F]VZ2!H;.&Y96[M("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G(&$@8G5D971E(&UU<V5T(')E<W1A<G1O=F%T('!OZ.UT8>@N7&Y<
M;D)Y;&D@:G-T92!V87)O=N%N:2X@4')O<^UM('-T:7-K;NQT92!/2R!P;VMU
M9"!S:2!P^&5J971E('!O:W)AZ&]V870@=B!M\V1U('#X97,@8V5L;W4@;V)R
M87IO=FMU+@!)9&5N=&ET82`B)7,B(&)Y;&$@<VUA>N%N82X`4&]U>F4@;F$@
M;&5VZ2!S=')A;NP`56WM<W3L;NT@8FENX7)N[6AO('-O=6)O<G4@1VYU4$<@
M;75S[2!B_70@>F%DX6YO(&1O('3X[61Y($-R>7!T7W!G<#HZ+@!:<'+A=F$@
M>F%S;&%NX2!V("5S(&L@)7,@<R!P^&5D;>QT96T@(B5S(B!B>6QA('IO8G)A
M>F5N82X*5&]T;R!N97IA<G7H=6IE+""^92!Z<'+A=F$@8GEL82!P^&7H=&5N
M82!N96)O(+YE(&KM(&%D<F5SX70H:V$I(')O>G5M[&PH82DN`$[A>F5V+"!K
M=&5R_2!B=61E('!O=;YI="!P^&D@;V1K87IO=N%N[2!N82!S='+A;F-E('1V
M;W)B>2!Z<'+A=@!4^.UD82!(;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE
M(&UO9'5L(&]P96YS<VPN`$YE;'IE('5L;[YI="!N87-T879E;NT@(B5S(BP@
M<')O=&^^92!J96AO('9E;&EK;W-T('#X97/A:&QA('!O=F]L96[](&QI;6ET
M+@!.96)Y;&$@;F%L97IE;F$@87!L:6MA8V4@<')O(.AT96[M('1O:&]T;R!T
M>7!U(&1A="`H)7,I+@!0;W5Z92!N82!P<F%VZ2!A(&QE=ND@<W1R86[L`%!O
M=7IE(&YA('!R87;I('-T<F%N[`!397)V97(@(B5S(B!B>6P@=GEM87KA;BX`
M4V5R=F5R("(E<R(@8GEL('5L;[YE;BX`0GEL82!O9'-T<F%N[&YA(+[A9&]S
M="!O('#X:6ALX;EE;NT@<')O("5S+@!0;[YA9&]V86[](/CA9&5K(&YE97AI
M<W1U:F4N`$1OZ&%S;OT@<V]U8F]R("(E<R(@;F5E>&ES='5J92X`4&]U>F4@
M;F%H;_AE(&$@9&]L90!0;W5Z92!N86AO^&4`6G1R871I;&$@<V4@</AE;F5S
M96[A(&1A=&$@>B!P^&5D8VAO>NUH;R!K<F]K=2X`4/AE;F5S96[]('-O=6)O
M<B!N96QZ92!U;&^^:70N`$)L;VL@=V5A=&AE<BYC;VT@;F5N[2!D;W-T=7!N
M_2X`KN%D;ND@=63A;&]S=&D@<V4@;F5S:&]D=6KM('-E('-O=>AA<V[];2!K
M<FETZ7)I96TN`*[A9&[I('H@;6^^;F]S=.T@;F5J<V]U(&1O<W1U<&[I+@!.
M96)Y;'D@;F%L97IE;GD@ON%D;ND@Z.%S=&DL(&MT97+I(&)Y(&)Y;&\@;6^^
M;F\@>F]B<F%Z:70@=B#XX61K=2X`4/CM;&FY(&UN;VAO('IN86OY('8@<&]L
M:2X@6F%D86QI(&IS=&4@)7,@>FYA:_D[(&UU<^UT92!Z861A="!MZ6[L(&YE
MOB`E<R!Z;F%K^2X`3F%S=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U
M.B`E<R!N96)Y;"!P^&5N97-E;BX`3F%S=&%L82!C:'EB82!P^&D@</AE;F]S
M=2!S;W5B;W)U+B`E<R!N96WYOF4@8OUT(';L=+GM(&YEOB!M87AI;>%L;NT@
M<&]V;VQE;N$@=F5L:6MO<W0@*"5D(&)Y=/DI+@!.87-T86QA(&-H>6)A('#X
M:2!P^&5N;W-U('-O=6)O<G4Z(&)Y;&$@</AE;F5S96YA(&IE;B#HX7-T('-O
M=6)O<G4@)7,N`$YA<W1A;&$@8VAY8F$@</AI('#X[7-T=7!U(&ME(&MA;&5N
M9.'X:3H@)7,`3F%S=&%L82!C:'EB82!P^&D@</AI9.%VX6[M('5DX6QO<W1I
M.B`E<P!$;[EL;R!K(&-H>6+L('#X:2!Z;V)R87IO=N%N[2!TZ71O(.CA<W1I
M('IP<N%V>0!.87-T86QA(&-H>6)A('#X:2#Z<')A=NP@=63A;&]S=&DZ("5S
M`$YA<W1A;&$@8VAY8F$@</AI(&EM<&]R=&]VX6[M(&MO;G1A:W1U+@!0^&D@
M:6UP;W)T;W;A;NT@:4-A;&5N9&%R(&1A="!D;[EL;R!K(&-H>6+L+@!#:'EB
M82!V(&MO;F9I9W5R8>AN[6T@9F]R;75LX?AI+B!:^&5J;>P@:G-T92!V>6YE
M8VAA;&D@<&^^861O=F%NZ2!P;VQE+@!.87-T86QA(&-H>6)A('#X:2!P;W-U
M;G4@=63A;&]S=&DZ("5S`$YA<W1A;&$@8VAY8F$@</AI('!R;W;A9.QN[2!Z
M861A;ND@;W!E<F%C92!V(&%D<F5SX?AI+B!0<F]S[6T@>FMU<W1E('1O('!O
M>F3L:FDN`$YA<W1A;&$@8VAY8F$@</AI('IA<^UL[6[M(&]Z;N%M96[M(&\@
M=63A;&]S=&D@<')O("5S.B`E<P!.87-T86QA(&-H>6)A('#X:2!A:W1U86QI
M>F%C:2!K;VYT86MT=2X@4')O<^UM('IK=7-T92!T;R!P;WID[&II+@!.87-T
M86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA
M;74N(%!R;W/M;2!Z:W5S=&4@=&\@<&]Z9.QJ:2X`KN%D;ND@=63A;&]S=&D@
M:R!E>'!O<G1O=N%N[2X`5&5N=&\@24U!4"!S97)V97(@;F5P;V1P;W)U:F4@
M<V3M;&5N[2!S;&^^96LN`%1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T;OT@<F%R
M(&%R8VAI=BX`5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!Z:7`@<V]U8F]R
M+@!4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[I(.CM<VQO(&MA<G1Y+@!496YT
M;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP<N%V('!O;6]C[2!#;&EC
M:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&)RX6YY('#X:2!P;W6^
M:73M($A45%`@05!)`%1E;G1O(&]V;&%D8>@@=6UOOO)U:F4@<&]S[6SA;NT@
M>G!RX78@<&]M;V/M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M(&)RX6YY('#X:2!P;W6^:73M($A45%`@05!)`%1E;G1O(&]V;&%D8>@@=6UO
MOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M(%--5%`@9&\@5F]D869O;F4@
M271A;'D@8G+A;GD@<&]U>F4@<')O(.CM<VQA('!O<VMY=&YU=.D@5F]D869O
M;F5M+B!-=7/M=&4@;>UT(&5M86EL;W;](/KH970@=2!6;V1A9F]N92!)=&%L
M>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4;W1O('!O;&4@:F4@;G5T;ND@=GEP
M;&YI="X`5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&-E;.$@Z.US
M;&$N`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!C96SA(.CM<VQA
M(&$@9'9O:G1EZ&MU+@!4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@
M;W-M:>AK;W;I(.CM<VQA+@!4;W1O('!O;&4@;75S[2!B_70@<V5Z;F%M(&-E
M;/UC:"#H[7-E;"!O9&3L;&5N_6-H(.CA<FMO=2!N96)O(&UE>F5R;W4`5&]T
M;R!P;VQE(&UU<^T@8OUT('!L871NZ2#H[7-L;RX`5&]T;R!P;VQE(&UU<^T@
M<&)S86AO=F%T(&)A<F5V;OT@:_-D('8@N65S=&[A8VMO=NEM(%)'0B!F;W)M
MX71U+"!N87#X+B`G(S$R,S1A9B<N`%1E;G1O(&9O<FWA="!S;W5B;W)U(&YE
M;'IE('!O=;[M="X`5&5N=&\@9F]R;75LX?@@:FF^(&)Y;"!Z<')A8V]VX6XN
M`%1O=&\@:F4@)7,N`%1O=&\@:F4@;V)J96MT($MO;&%B($=R;W5P=V%R=2X@
M2R!Z:&SI9&YU=.T@=&]H;W1O(&]B:F5K='4@:F4@>F%P;W3X96+M(&WM="!P
M;[ET;W9N[6AO(&ML:65N=&$L(&MT97+](')O>G5M[2!F;W)MX71U($MO;&%B
M($=R;W5P=V%R=2X@4')O('-E>FYA;2!T86MO=OUC:"!K;&EE;G3Y('!R;W/M
M;2!N87:Y=&EV=&4@)7,`5&]T;R!J92!Z<'+A=F$@>F4@<V5R=F5R=3H@)7,`
M5&%T;R!Z<'+A=F$@8GEL82!N87!SX6YA('8@:FENZ2!Z;F%K;W;I('-A9.P@
M*"5S*2!N9;X@5F&Y[2X@`%1O=&\@Z.US;&\@;75S[2!B_70@;F5J;>EN["!J
M961N82X`4V5R=F5R(&YE;?F^92!R;WIB86QI="!Z:7`@82!G>FEP('-O=6)O
M<GDN`%1E;G1O('-Y<W3I;2!J92!V('-O=>AA<VYO<W1I(&1E86MT:79O=F%N
M_2X`5&%T;R!H;V1N;W1A(&UU<^T@8OUT(.CM<VQO+@!4;W1O(&]K;F\@;76^
M92!B_70@=F]LX6YO('!O=7IE('H@;VMN82!M;[YN;W-T[0!(^&WL;NT`R'1V
M<G1E:P!,[7-T:WD`R&%S`,AA<V]VZ2!2;WI?<.QT[0!3;&5D;W;A;NT@Z&%S
M=0!&;W)MX70@Z&%S=0!6_6+L<B#H87-U`,AA<V]VZ2!2;WIP['3M(`!4:6UO
M<BU,97-T90!4:71?=6P`5&ET=6P`5&ET=6P@*'1I<"DZ`$MO;74`4&]K=60@
M<VD@</AE:F5T92!V>6)R870@=NUC92!P;VQOOF5K+"!Z;>'H:V[L=&4@:VSA
M=F5S=2!#;VYT<F]L("A00RD@;F5B;R!#;VUM86YD("A-86,I(&$@:VQI:V[L
M=&4@;F$@<&]L;[YK=2X`1&YE<P!0^&5P;F]U="!N82!(5$U,('ID<F]J`%1O
M9V\`5&]K96QA=0!:[71R80!4;VYG80!6<F-H`$AO<F[M('+A;2`H7W1O<"D`
M4/AE:VQA9'D`5')I;FED860@82!4;V)A9V\`4W!RX79N["!N96)O(+EP871N
M[`#:=`#:=&5R_0!4=6YI<VMO`%1U<F5C:V\`5'5R96-K>2`H25-/+3@X-3DM
M.2D`5'5R:VUE;FES=.%N`%1U<FMS(&$@0V%I8V]S(&]S=')O=GD`5'5V86QU
M`%1Y<`!.87!IN71E(%9AN6D@=F]L8G4Z`%4N5BX@:6YD97@Z(`!54DP@<')O
M('IP<N%V=2!O('-T879U('IA<VQA;NEH;R!S:W)I<'1U`%523#H`56=A;F1A
M`%5K<F%J:6YA`%9&4R!A9')E<^'X(&IE(&YE</CM<W1U<&[]+@!0^&D@<F5G
M:7-T<F%C:2!N96QZ92!P^&ED870@97AT<F$@=;YI=F%T96QS:^D@^F1A:F4N
M`$YE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O<B`B)7,B+@!.96QZ
M92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@)7,O)7,N`$YE;'IE('IM
M[&YI="!N82`E<RX`3F5L>F4@<V4@</AI<&]J:70@;F$@4U%,('-E<G9E<BX`
M3F5L>F4@<V4@</AI<&]J:70@<&]M;V/M(%-33"X`3F5L>F4@:V]P[7)O=F%T
M(%9&4R!S;W5B;W(N`$YE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X("(E<R(N
M`$YE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X+@!.96QZ92!V>71V;_AI="!6
M1E,@<V]U8F]R+@!.96QZ92!V>71V;_AI="!P<N%Z9&[](%9&4R!S;W5B;W(N
M`$YE;'IE(')O>F)A;&ET(&1A=&$N`$YE;'IE('9Y;6%Z870@(B5S(BP@<')O
M=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2X`3F5L>F4@<VUA>F%T("(E<R(Z
M("5S+@!.96QZ92!V>6UA>F%T("5S+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P
M<N%Z9&[]+@!.96QZ92!S;6%Z870@)7,N`$YE;'IE(')E:W5R>FEV["!O9'-T
M<F%N:70@5D93(&%D<F5SX?@N`$YE;'IE('9Y;6%Z870@5D93(&%D<F5SX?@N
M`$YE;'IE('9Y;6%Z870@5D93(&%D<F5SX?@Z("5S+@!.96QZ92!V>6UA>F%T
M(%9&4R!S;W5B;W(@(B5S(BX`3F5L>F4@=GEM87IA="!61E,@<V]U8F]R+@!.
M96QZ92!R96MU<GII=F[L(&]D<W1R86YI="!61E,Z("5S+@!.96QZ92!U<NAI
M="!A:W1UX6QN[2!A9')E<^'X+@!.96QZ92!Z:FES=&ET('!O9')O8FYO<W1I
M(&\@8V5R=&EF:6OA='4N`$1E9FEN:6-E("5S(&YE;NT@9&]S='5P;N$N`$YE
M;'IE('#X97-U;F]U="!61E,@<V]U8F]R+@!.96QZ92!P^&5S=6YO=70@5D93
M('-O=6)O<B`B)7,B+@!61E,@<V]U8F]R(&YE;'IE(&]T97;X[70@<')O('KA
M<&ES+@!.96QZ92!O=&5V^.UT(%9&4R!S;W5B;W(N`$YE;'IE(&]T97;X[70@
M87)C:&EV;W9A;OT@<V]U8F]R+@!.96QZ92#H[7-T('H@=F9S<F]O="!A9')E
M<^'X92X`3F5L>F4@</AE:FWL;F]V870@(B5S(CH@)7,`3F5L>F4@</AE:FUE
M;F]V870@)7,@;F$@)7,Z(&/M;&]VX2!S;&^^:V$@:FF^(&5X:7-T=6IE`%9&
M4R!A9')E<^'X(&YE;'IE('#X96IM96YO=F%T+@!61E,@861R97/A^"!N96QZ
M92!P^&5J;65N;W9A=#H@)7,N`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B
M;W(@(B5S(BX`3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<B`E<R\E<RX`
M3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<BX`3F5L>F4@>FII<W1I="!I
M;F9O<FUA8^T@9G)E92]B=7-Y('!R("5S`$YE;'IE('!R;W;I<W0@)VUK:7-O
M9G,G+@!496YT;R!D;VMU;65N="!7;W)D(&YE;'IE('#X96QOOFET`$YE;'IE
M('IA<'-A="!D;R!61E,@<V]U8F]R=2`B)7,B+@!.96QZ92!Z87!S870@9&%T
M82!D;R!61E,@<V]U8F]R=2`H<V5L:&%L;R!C;W!Y*"DI+@!.96QZ92!Z87!S
M870@9&%T82!D;R!61E,@<V]U8F]R=0!0;V1T<FAN=73I`%-T;W)N;R!Z;>QN
M`%-T;W)N;W9A="!P;W-L96[M(&%K8VD`3F5OZ&5KX79A;N$@;V1P;W;L[R!S
M97)V97)U(&YA('-P;VIE;NTZ(`!.96_H96OA=F%NX2!O9'!O=NSO('-E<G9E
M<G4Z(`!.979Y<&QN[&YO`%5N:6-O9&4@*%541BTX*0!3<&]J96[I($%R86)S
M:^D@16UI<N%T>0!696QKX2!"<FETX6YI90!3<&]J96[I(%-TX71Y($%M97)I
M8VOI`%-P;VIE;ND@4W3A='D@365NN6EN;W;]8V@@;W-T<F]V^0!*961N;W1K
M>0!.97INX6WI`$YE>F[A;>D@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`
M3F5Z;N%MZ2!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!.97INX6WI
M('6^:79A=&5L<VOI(&IMZ6YO(&YE8F\@:&5S;&\N`$]D<&]J:70@<V]UZ&%S
M;OT@<')V96L`0F5Z92!J;>EN80!.97!R:79I;&5G;W9A;ND@<VMR:7!T>2!N
M96UO:&]U('9Y=;[M=F%T(&9U;FMC82!6>6IM;W5T+TMO<.UR;W9A="]6;&^^
M('H@8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y+B!+;&EK;NQT92!N82!/2R!A8GES
M=&4@=FED[&QI('1E8VAN:6-K;W4@>G!RX79U('H@;6]Z:6QL82YO<F<L(&MT
M97+A('9Y<W;L=&QU:F4L(&IA:R!N87-T879I="!S:W)I<'0@<')O('#X[7-T
M=7`@:V4@<V-H<N%N8V4N`$YE;F%S=&%V96[A(&)A<G9A`$YE<&]D<&]R;W9A
M;N$@</CM<&]N80!!:W1U86QI>F]V870`06MT=6%L:7IO=F%T("5S`$%K='5A
M;&EZ;W9A="!UOFEV871E;&4`06MT=6%L:7IO=N%N:6\Z("5S+@!3:W)I<'0@
M<')O(&%K='5A;&EZ86-I(&)Y;"!V>6UA>N%N+@!0^&5N;W,`5KEE8VAN>2!S
M;W5B;W)Y('!R;R!N87-T879E;NT@87!L:6MA8^T@8GEL>2!P^&5N97-E;GD@
M;F$@<V5R=F5R+@!696QKX2!T:7-K86/M('#M<VUE;F$`5F5L:^D@^.UM<VOI
M(.CM<VQI8V4`57)U9W5A>0!0;W6^[70@86MT=>%L;NTZ("5S`%!O=;[M="!3
M4TP`4&]UONUT('!O:W5D(&IMZ6YO+VAE<VQO(&IS;W4@:FENZ2!N9;X@<')O
M($E-4U`@<V5R=F5R+@!5OFEV871E;"`E<R!N96[M(&]P<N%V;NQN(&L@<&]U
MONUVX6[M("5S+@!!9&UI;FES=')A8V4@=;YI=F%T96SY`%6^:79A=&5L<VOI
M(%)O>FAR86[M`%6^:79A=&5L<VOI(&UOOFYO<W1I`%)E9VES=')A8V4@=;YI
M=F%T96SY`$YA('1O;71O('-E<G9E<G4@;F5N[2!M;[YNX2!R96=I<W1R86-E
M('6^:79A=&5L^2X`5;YI=F%T96QS:^D@:FWI;F\`5;YI=F%T96QS:^D@:FWI
M;F\Z`%6^:79A=&5L<VOI(&IMZ6YO.B``4V5Z;F%M('6^:79A=&5L^3H`57IB
M96MI<W3A;@!61E,@861R97/A^"!N965X:7-T=6IE+@!$;W9O;&5NX0!.86QE
M>F5NX2!P;&%T;N$@;>US=&$@>F%H<FYU:NTZ(`!0;&%T;F]S=`!(;V1N;W1A
M('8@;6EN=73A8V@N`$AO9&YO='D`5GEB<F%NZ2!H;V1N;W1Y('H`5F%N=6%T
M=0!0<F]M[&YNZ0!696YE>G5E;&$`4V5L:&%L82!V97)I9FEK86-E("T@=&%T
M;R!Z<'+A=F$@;6]H;&$@8OUT('IF86RY;W;A;F$N`%9E<GIE`%9E<G-I;VX@
M0V]N=')O;`!697)T:6OA;&[M('IA<F]V;N%N[0!697)T:6OA;&[M(&]D<W1U
M<`!697)T:6OA;&[M.@!696QM:2!V>7-O:^$`5FEE=&YA;0!6:65T;F%M<VMY
M("A625-#24DI`%IO8G)A>FET("5S`%IO8G)A>FET($1E;@!:;V)R87II="!E
M>'1E<F[M('=E8G-T<N%N:W4`6F]B<F%Z:70@:F%K;R`E<P!086YN96YS:^D@
M3W-T<F]V>2P@0G)I='-KZ0!086YN96YS:^D@3W-T<F]V>2P@52Y3+@!6:61I
M=&5L;F]S=`!6:61I=&5L;F]S=#H`5F]D869O;F4@271A;'D@</AE<R!33510
M`%503UI/4DY)5`!54$]:3U).S$[-(2$A($]$4U120=)412!32U))4%0@4E7(
M3LP@6B`E<RX`5V%L;&ES(&%N9"!&=71U;F$`57!O>F]R;NQN[0!3=`!0^&5D
M<&]V[.\@<&_H87/M`$1A=&$@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H97(N
M8V]M`%=E8@!796(@<V5R=F5R`%-T^&5D80!4_61E;@!4_61E;B`E9`!4_61E
M;BAY*0!4_61N[`!4_61N[#H@4F5K=7)Z[79N["!K8;YD_0!6[71E:G1E`%;M
M=&5J=&4@=B`E<P!6[71E:G1E+"`E<P!:X7!A9&[M("A)4T\M.#@U.2TQ*0!:
MX7!A9&[M("A)4T\M.#@U.2TQ-2D`6N%P861N[2!386AA<F$`2W1E<F]U(&%P
M;&EK86-I(&WA("5S('IO8G)A>FET('!O('#X:6ALX;EE;NT@9&\@<WES=.EM
M=3\`2F%K_2!J92!O9&3L;&]V86/M('IN86L_`$IA:_T@:F4@>FYA:R!P<F\@
M8VET86-I/P!+9'D@;>$@Z&%S;W;I('IO8G)A>F5N:2!D;F4@82!T_61N92!K
M;V[H:70L('!O:W5D(&YE;V)S86AU:NT@<&]Z9&YI('5DX6QO<W1I/P!+9'D@
M;>$@Z&%S;W;I('IO8G)A>F5N:2!D;F4@82!T_61N92!Z8>CM="P@<&]K=60@
M;F5O8G-A:'5J[2#H87-NZ2!U9.%L;W-T:3\`2W1E<ND@9N%Z90!6;VQB82!R
M;WJY[?AE;NT@<')O(%)I8V@@5&5X="!E9&ET;W(N`*GM^&MA`*GM^&MA('8@
M0U-3(&IE9&YO=&OA8V@`J>WX:V$@)7,@;65N=2!V;&5V;R`H>FWL;F$@<V4@
M;V)J97;M('#X:2!D86RY[6T@</AI:&SAN65N[2DZ`*GM^&MA('1A8G5L:WD`
M2F5D;F]T:V$@N>WX:WD`J>WX:V$Z`%=I:VD`5NUT<@!286YN[2!V[71R`%)Y
M8VAL;W-T(';L=')U('8@=7IL96-H`%;M='(Z`%;M='(Z(`!-;W5D<F]S=`!0
M<N%C90!!9')E<V$@9&\@>F%M['-T;N%N[0!496QE9F]N(&1O('IA;>QS=&[A
M;NT`4')A8V]V;NT@5/UD96X`6"U2968`6#4P.78S('KA:VQA9&[M(&]M97IE
M;NT`6#4P.78S(')O>KGM^&5NZ2!P;W6^:73M(&ML[>AE`%@U,#EV,R!A;'1E
M<FYA=&EV;NT@:FWI;F\@;W-O8GD`6#4P.78S(&ED96YT:69I:^%T;W(@:VSM
MZ&4`6#4P.78S(')O>KGM^&5N[0!24@!24E)2`$UA<&$@66%H;V\A`%)OZ&[L
M`%)OZ&[L.B!296MU<GKM=F[L(&MAOF3]`$IE;65N`$%N;P!!;F\L('-O=6AL
M87/M;0!*<W1E('8@5$585$]6R4T@3=-$52X@4&]UOFEJ=&4@6SP^72!T;&'H
M[71K82!K('IP['1NZ6UU('#X97!N=73M(&1O(%=94TE764<N`$YE8GEL:2!J
M<W1E('-P<N%V;NP@;W;L^&5N:2X`6FYA:R`G7"<@;F5M^;YE(&+]="!S;W7H
MX7-T[2!68;EE:&\@:FWI;F$N`%1E;G1O(&9O<FUU;.'X(&QZ92!P;W5Z92!P
M;W6^[70@>F4@<W1RX6YK>2#:<')A=GD@VNAA<W1N[6OY+@!">6QA('IA9.%N
M82!N97!L871NX2!E+6UA:6QO=N$@861R97-A+@!.96UA<&]V86QI(&IS=&4@
MON%D;N$@<&]L92!Z(&EM<&]R=&]V86[I:&\@<V]U8F]R=2!K(&]D<&]V[61A
M:NUC[6T@<&]L[6T@=B`E<RX`3F5D;W-T871EZ&[A('!RX79A('!R;R!P^&ED
MX6[M('5DX6QO<W3M(&1O("5S+@!.961O<W1A=&7H;N$@<'+A=F$@<')O('#X
M:63A;NT@=63A;&]S=.T@9&\@=GEB<F%NZ6AO(&MA;&5N9.'X92X`3F5D;W-T
M871EZ&[A('!RX79A('!R;R!S;6%ZX6[M('3I=&\@=63A;&]S=&DN`$YE9&]S
M=&%T9>ANX2!P<N%V82!P<F\@^G!R879U('3I=&\@=63A;&]S=&DN`$)Y;&D@
M:G-T92!O9&ALX;EE;FD@>F4@<WES=.EM=2X`0GEL('IA9.%N(&YE:7!L871N
M_2!K86QE;F3A^"X`5FQOOG1E(.CM<VQO(&UO8FEL;NUH;R!T96QE9F]N=2P@
M<&]UOFEJ=&4@:F5N(.CM<VQI8R!N96)O('#X[7!A9&[L("<K)R!P<F\@;65Z
M:6[A<F]D;NT@Z&ES;&$N`$UU<^UT92!Z861A="!P;&%T;F]U(&AO9&YO='4N
M`$UU<^UT92!K;VYF:6=U<F]V870@9&%T86+A>FD@9&%T+"!P;VMU9"!S:2!P
M^&5J971E('!O=;[M=F%T(%)E9VES=')A8V4N`$UU<^UT92!K;VYF:6=U<F]V
M870@5D93(&)A8VME;F0N`$UU<^UT92!N96ID^.UV92!P;W!S870@<')O8FSI
M;2!A('!O=.D@:&\@;V1E<VQA="X`375S[71E('IA9&%T(%523"!N82!K=&5R
MZ2!B=61E('1E;G1O(&]D:V%Z('5K87IO=F%T`$UU<^UT92!V>6)R870@:V%L
M96YDX?@L(&MT97+](&)U9&4@<VUA>N%N+@!-=7/M=&4@;F5J9/CM=F4@=GEB
M<F%T(&5M86EL;W9O=2!A9')E<W4N`$UU<^UT92!V>6)R870@<V5R=F5R+"!K
M=&5R_2!B=61E('-M87KA;BX`375S[71E('9Y8G)A="!UOFEV871E;'-KZ2!J
M;>EN;RP@:W1E<ND@8G5D92!S;6%ZX6YO+@!-=7/M=&4@>F%D870@=;YI=F%T
M96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@;V1S=')A;NQN;RX`3F5U=F5D;&D@
M:G-T92!UOFEV871E;'-KZ2!J;>EN;RP@:W1E<ND@8G5D92!P^&EDX6YO+@!.
M975V961L:2!J<W1E('6^:79A=&5L<VOI(&IMZ6YO('!R;R!A:W1U86QI>F%C
M:2X`375S[71E('IA9&%T(&%K8VDL(&MT97+A(&)U9&4@<')O=F5D96YA+@!-
M=7/M=&4@>F%D870@:FWI;F\@;F]VZ2!K871E9V]R:64N`%9AN64@)7,@<F5L
M86-E(&)Y;&$@=6MO;NAE;F$N($]P['0@<V4@</AI:&QAN71E+"!P<F]S[6TN
M`%9AN64@96UA:6QO=N$@861R97-A`%9AN64@3V0M:V]H;SH@861R97-A.@!6
M8;EE(&EN9F]R;6%C90!6(')E;&%C:2`E<R!S92!Z;>QN:6QA(%9AN64@:6YT
M97)N971O=N$@861R97-A+B!:(&)E>G!EZ&YO<W1N[6-H(&3Y=F]D^2!S92!M
M=7/M=&4@;W#L="!P^&EH;.%S:70N`%9AN64@:FWI;F\`5N&Y(&]V[/AO=F%C
M[2!S>7-TZ6T@;F5P;V1P;W)U:F4@=OUP:7,@=;YI=F%T96SY(&%N96)O('1A
M=&\@;6^^;F]S="!N96[M('#X[7-T=7!NX2!Z(&II;OUC:"!D^79O9/DN`%ID
MX2!S92P@OF4@=B!P<OEB[&AU(')E;&%C92`E<R!S92!Z;>QN:6P@5N&Y('!R
M;VAL[;YEZ"X@6B!B97IP9>AN;W-T;NUC:"!D^79O9/D@<V4@;75S[71E(&]P
M['0@</AI:&SA<VET+@!6X;D@<')O:&SMOF7H(&YE<&]D<&]R=6IE('1U=&\@
M;6^^;F]S="X`5F&Y92!S;W7H87-NZ2#H87-O=ND@<.%S;6\Z`%;AN2!I;7!L
M:6-I=&[M(&MA;&5N9.'X`%9AN64@:6UP;&EC:71N[2!I9&5N=&ET80!68;EE
M(/IP;&[I(&IMZ6YO.@!68;EE(&YO=ND@:&5S;&\@<')O("5S(&IE.B`E<P!6
M8;EE(&YA<W1A=F5N[2!B>6QO(&%K='5A;&EZ;W;A;F\@<')O('1R=N%N[2!T
MZ71O(')E;&%C92X`5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI>F]VX6YO
M+@!68;EE(&AE<VQO(&)Y;&\@<F5S971O=N%N;RX`5F&Y92!H97-L;R!B>6QO
M(')E<V5T;W;A;F\L('IK;VYT<F]L=6IT92!S:2!Z<'+A=GD@96QE:W1R;VYI
M8VOI('!ON71Y(&$@</AI:&QAN71E('-E(',@5F&Y[6T@;F]V_6T@:&5S;&5M
M+@!68;EE('9Z9.%L96[I('-E<G9E<GDZ`$IU9V]S;.%V:64`6F%I<@!:86UB
M:64`6FEM8F%B=F4`6FEP<'D`6U5K<OUT(&-I=&]V86[]('1E>'1=`%M(;.&Y
M96[M('!R;V)LZ6UU70!;6F]B<F%Z:70@8VET;W9A;OT@=&5X="`M`%M:;V)R
M87II="!C:71O=F%N_2!T97AT("T@)7,@^.%D:_E=`%M59.%L;W-T(&)E>B!N
MX7IV=5T`6_CA9&5K("5S('H@)7-=`%]!9&UI;FES=')A8V4`7U9Y:&QE9&%T
M`%]#3$D`7T1A=&%4<F5E`%]3;6%Z870@^.%D96L`7U5P<F%V:70`7TKM="!N
M80!?4VMU<&EN>0!?3N%P;W;L9&$`7U9L87-T;F]S=&D@;V)RX7IK=2XN+@!?
M26UP;W)T;W9A="]%>'!O<G1O=F%T`%]0^&EH;.&Y96[M`%]/9&ALX;EE;NT`
M7TUO9&EF:6MO=F%T(&]D:V%Z+BXN`%]+86QE;F3A^&4`7TYO=N$@563A;&]S
M=`!?36^^;F]S=&D`7U!RX79A`%]4:7-K`%]/9'-T<F%N:70@;V1K87HN+BX`
M7U9Y:&QE9&%T`%].87-T879E;NT`7U9L87-T;F]S=&D@=&%B=6QK>2XN+@!?
M1&YE<P!?5;YI=F%T96SI`&%D<F5SX?@`</AE9"!Z8>CA=&ME;2!U9.%L;W-T
M:0!K86QE;F3A^`!B97IV['3X[0!K;&EK;F]U="!Z9&4`9&5N`&1E;BAD;GDI
M`&1N>0!U9.%L;W-T:2YC=G,`=63M;&]S=&DN:6-S`'-RX;YK>0!S;W5B;W(`
M;V0`>B`E<R`H)7,I(')Y8VAL;W-T[2`E<R`E<P!H.@!O:V%MOFET[`!V(/AA
M9.P`^.%D:_E=`&-H>6)O=OT@:_-D(&UK:7-O9G,@)60@</AI('9Y=';A^&5N
M[2!)4T\N`&WL<^UC*&4I`&IMZ6YO`&YE;NT@:6UP;&5M96YT;W;A;F\`;F5N
M[2!D;W-U9"!I;7!L96UE;G1O=N%N;P!ZX7!I<V[M:P!V92!S=&5J;NEM(&1N
M=0!V92!S=&5J;NEM('3]9&YU`'!R;V-E;G0`<&EX96SY`'-T;W5P86KM8^T`
M>F]B<F%Z:70@<F]Z9.UL>0!S;7,R96UA:6P@>F$@<&]UOFET[2!(5%10`'9Y
M=')V86SI`'-E>FYA;2#Z:V]L^0!P<F\@<&]T=G)Z96[M(&YA<&FY=&4@:&5S
M;&\@9'9A:W+A=`!S:F5D;F]C96[]`&)E>B!NX7IV=0!V>6)R870@=;YI=F%T
M96QE`'9#86QE;F1A<B]I0V%L96YD87(`=D-A<F0`=D5V96YT(&YE8GEL(&YA
M;&5Z96XN`'<Z`'=E871H97(N8V]M`'3]9&5N`'3]9&5N*'3]9&YY*2!V.@!T
M_61N>0!R;VLH>2D``````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]E;%]'4B\`````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,``P
M,C`V-C$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE
M+V5L7T=2+TQ#7TU%4U-!1T53+P``````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S4P`#`R,C0T-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]L;V-A;&4O96Q?1U(O3$-?34534T%'15,O:W)O;F]L:71H
M+FUO````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,S$U-3``,3`T,3<S-C(W-3``,#(U,#$U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
MX0```!P````D!P``,P$``"P.````````^!(``"@```#Y$@``'0```"(3```(
M````0!,```4```!)$P``"0```$\3```/````61,```@```!I$P``!P```'(3
M```%````>A,```H```"`$P``%````(L3```*````H!,```4```"K$P```P``
M`+$3```'````M1,```T```"]$P``"@```,L3```?````UA,```4```#V$P``
M`@```/P3```&````_Q,``!$````&%```"````!@4```&````(10``!4````H
M%```"````#X4```*````1Q0```P```!2%```!P```%\4```;````9Q0``!(`
M``"#%```!P```)84```"````GA0```4```"A%```$P```*<4```#````NQ0`
M``8```"_%```"````,84```0````SQ0```8```#@%```"0```.<4```,````
M\10``%P```#^%```%````%L5```+````<!4``"\```!\%0``#P```*P5```F
M````O!4```<```#C%0``"````.L5```$````]!4```<```#Y%0``!0````$6
M```-````!Q8```@````5%@``!@```!X6```(````)18```4````N%@``$```
M`#06```0````118```\```!6%@``"P```&86```/````<A8```P```""%@``
M#P```(\6```&````GQ8```\```"F%@``'@```+86```A````U18```,```#W
M%@``"````/L6```"````!!<```8````'%P``!@````X7```$````%1<```0`
M```:%P``#````!\7```*````+!<```4````W%P``!P```#T7```*````11<`
M``\```!0%P``%@```&`7```2````=Q<``!````"*%P``!P```)L7```$````
MHQ<```0```"H%P``"````*T7```(````MA<```D```"_%P``'@```,D7```0
M````Z!<```@```#Y%P``!@````(8```'````"1@```(````1&```!````!08
M```%````&1@```\````?&````P```"\8```'````,Q@```H````[&```!P``
M`$88```)````3A@```(```!8&```!@```%L8```%````8A@```<```!H&```
M%0```'`8```%````AA@```D```",&```"@```)88```(````H1@```D```"J
M&```"P```+08```$````P!@```4```#%&```"````,L8```'````U!@```<`
M``#<&```$0```.08```(````]A@```<```#_&```'@````<9```>````)AD`
M``4```!%&0``*````$L9```I````=!D```P```">&0``$P```*L9```+````
MOQD```\```#+&0``$P```-L9```3````[QD```\````#&@``#````!,:```.
M````(!H```T````O&@``#0```#T:```+````2QH``!$```!7&@``$0```&D:
M```$````>QH```(```"`&@``"````(,:```+````C!H```H```"8&@``#```
M`*,:``!8````L!H``!H````)&P``%P```"0;```:````/!L``!D```!7&P``
M%P```'$;```=````B1L``!L```"G&P``'P```,,;```3````XQL```D```#W
M&P``'P````$<```H````(1P``!````!*'```%P```%L<```*````<QP```@`
M``!^'```"@```(<<```"````DAP```<```"5'```!@```)T<```%````I!P`
M``D```"J'````@```+0<```O````MQP``!\```#G'```(0````<=```<````
M*1T```@```!&'0``!0```$\=```%````51T```(```!;'0``!P```%X=```$
M````9AT``"0```!K'0``)@```)`=```,````MQT```X```#$'0``#````-,=
M```(````X!T```<```#I'0```@```/$=```)````]!T```0```#^'0``!P``
M``,>```'````"QX```8````3'@``%````!H>```-````+QX```L````]'@``
M2````$D>``!,````DAX```P```#?'@``"@```.P>```)````]QX```(````!
M'P``!@````0?```4````"Q\``$4````@'P``,````&8?```0````EQ\``!\`
M``"H'P``$````,@?```/````V1\```,```#I'P``!@```.T?```$````]!\`
M``@```#Y'P``$`````(@```3````$R````4````G(```!````"T@```+````
M,B````4````^(```!P```$0@``!P`0``3"```"<```"](0``*0```.4A```+
M````#R(```4````;(@``$@```"$B```7````-"(``!````!,(@``"0```%TB
M```-````9R(``!D```!U(@``'P```(\B```9````KR(```D```#)(@```P``
M`-,B```.````UR(``"````#F(@``#P````<C```B````%R,```@````Z(P``
M`@```$,C```)````1B,``!````!0(P``"````&$C```%````:B,``!P```!P
M(P``"0```(TC```/````ER,``!(```"G(P``!P```+HC```X````PB,``!D`
M``#[(P``!@```!4D```"````'"0```@````?)```$````"@D```%````.20`
M``D````_)```"@```$DD```7````5"0```@```!L)```"P```'4D```2````
M@20``'@```"4)```&0````TE```)````)R4``#4````Q)0``$@```&<E``!`
M````>B4```P```"[)0``"````,@E```+````T24```X```#=)0``#````.PE
M```>````^24``!`````8)@``"0```"DF```)````,R8```4````])@``#0``
M`$,F```4````428```P```!F)@``)````',F```-````F"8```H```"F)@``
M%@```+$F```'````R"8``!,```#0)@``-P```.0F```L````'"<```,```!)
M)P``"P```$TG```"````62<```D```!<)P``"@```&8G```(````<2<```<`
M``!Z)P``$0```((G```0````E"<```T```"E)P``!P```+,G```.````NR<`
M`!4```#*)P``'````.`G```5````_2<``!4````3*```"@```"DH```'````
M-"@```<````\*```"P```$0H```&````4"@``!(```!7*```+````&HH```6
M````ER@```D```"N*```!P```+@H```&````P"@```(```#'*```#````,HH
M```'````UR@``!0```#?*```!0```/0H```)````^B@``!`````$*0``!@``
M`!4I```(````'"D```(````E*0``!P```"@I```%````,"D```<````V*0``
M#0```#XI```$````3"D```L```!1*0``#@```%TI```,````;"D``!````!Y
M*0``'````(HI```&````IRD```H```"N*0``"0```+DI```)````PRD```@`
M``#-*0``$0```-8I```'````Z"D```8```#P*0``'P```/<I```D````%RH`
M``@````\*@``+````$4J```Q````<BH``!$```"D*@``%0```+8J```-````
MS"H``!,```#:*@``$@```.XJ```.`````2L``!@````0*P``"P```"DK```2
M````-2L``!8```!(*P``$P```%\K```0````<RL``"8```"$*P``%P```*LK
M```%````PRL```(```#)*P``!P```,PK```1````U"L``!0```#F*P``$P``
M`/LK``!'````#RP``",```!7+```+````'LL```C````J"P``"<```#,+```
M)0```/0L```P````&BT``"(```!++0``%P```&XM```=````ABT```L```"D
M+0``*@```+`M``!"````VRT``!(````>+@``&P```#$N```4````32X```T`
M``!B+@``#0```'`N```"````?BX```@```"!+@``!P```(HN```(````DBX`
M``P```";+@```@```*@N``!(````JRX``",```#T+@``,````!@O```D````
M22\```8```!N+P``!@```'4O```&````?"\```,```"#+P``!0```(<O```%
M````C2\``#,```"3+P``+P```,<O```/````]R\``!$````',```#P```!DP
M```,````*3````T````V,````@```$0P```'````1S````@```!/,```"P``
M`%@P```,````9#````L```!Q,```$0```'TP```1````CS````\```"A,```
MA0```+$P``"&````-S$``!(```"^,0``$0```-$Q```)````XS$```(```#M
M,0``!@```/`Q```-````]S$``$$````%,@``00```$<R```2````B3(``"(`
M``"<,@``%0```+\R```2````U3(```4```#H,@``"0```.XR```&````^#(`
M``@```#_,@``#@````@S```1````%S,```T````I,P``"````#<S```5````
M0#,```D```!6,P``!P```&`S```!`````````'$```#4````1`````````!)
M```````````````P`````````,,```!R````W0```!T`````````V0```*4`
M`````````````"<````0````#0```%,```#1````7P``````````````````
M``0```#8`````````!\```"J`````````"D`````````%P````,```"C````
M+P```,0````R`````````&0```#?`````````"4````>`````````#X```!X
M````L0```'<`````````3`````\`````````5P``````````````S````%P`
M``"S````U0```%$```"=````C@```!,``````````````-,`````````````
M`+H```!E`````````)\```!`````UP```%H```!B`````````)0```!]````
MR0```!@```"8````?``````````N````00```'8```!0````-0``````````
M````A0````P```!H````B@```(0```"@````3@```*0```!_`````````',`
M````````2````)8```!=````6P```&<`````````:P```%(````S````H0``
M`-````"5`````````&,```"0````FP```)<````2`````````'````!#````
MG@```#P`````````````````````````;0``````````````````````````
M``````````````"Y`````````+4````1````7@```)H```!Z````:0``````
M````````8`````````!"````NP```$\```#-````(````(<````(````@@``
M`$8```"^````L@```,@````;`````````"(````F````BP```#<`````````
M!P```"@````Z````-@```$H`````````P@````````#*`````````$4```"/
M````VP```),```"(`````````&X````.````%@````D````X````G````)(`
M````````!0```&$```"M````9@``````````````A@```-X`````````+0``
M``````"P````Q@```%0```!5````K````)D`````````@P``````````````
MK@````(```"B````@0````````"\````P0````8```#'````B0```!H````L
M````P````$L```#<````%0```,\```#@````;````````````````````"L`
M````````"P```#L```"W````5@````````"F`````````$<````*````````
M`+\```"G````.0```#0```!-````JP```,L```!U````KP```+@```"-````
M(0````````#:````(P```````````````````*@```#2````%````%@`````
M````'````#T`````````M@```*D```#6````C````!D```#.````)````%D`
M```J`````````#\```"1````>P```,4```"]````;P``````````````X0``
M`'0```"``````````'D````Q````M````&H```!^`````"5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@9FEL92!S=6-C97-S
M9G5L;'D@:6UP;W)T960`,C0@:&]U<G,`04TO4$T`061D($5V96YT`$%D9"!A
M(&YE=R!E=F5N=`!!9&0@<&%I<@!!9&1R97-S`$%L87)M`$%L87)M($1A=&4`
M06QA<FT@4W!A;B`H;6EN=71E<RD`06QA<FT@5&EM90!!;&EA<P!!;&P`06QL
M(&1A>0!!;&P@9&%Y(&5V96YT`$%L;"!E=F5N=',`06X@:6QL96=A;"!V86QU
M92!W87,@<W!E8VEF:65D+@!!<')I;`!!=`!!=6=U<W0`079A:6QA8FQE(&9I
M96QD<SH`0FER=&AD87D`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M871E9V]R>0!#96QL(%!H;VYE`$-L;W-E(%=I;F1O=P!#;VUP86YY`$-O;F9I
M<FT@9&5L971I;VX@;V8@979E;G1S/P!#<F5A=&4@82!.97<@179E;G0`0W5R
M<F5N=`!$1`!$86EL>0!$86EL>3H@4F5C=7)S(&5V97)Y`$1A>0!$87DH<RD`
M1&5C96UB97(`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5L971E("5S`$1E
M;&5T92!%=F5N=`!$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI
M<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R(&%L
M;"!O8V-U<F5N8V5S/P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO
M;@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$:7-P;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'``1'5E.B`E<P!$=7)A=&EO;@!%9&ET`$5D:70@)7,`
M16UA:6P`16UP='D@<F5S=6QT+@!%;F0@1&%T90!%;F0@3VX`16YD(%1I;64`
M17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>'!O<G0`17AP;W)T($-A;&5N9&%R
M`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$9E8G)U87)Y`$9R`$9R:61A>0!&
M=71U<F4`1V%M90!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E
M`$AO=7(H<RD`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`26UP;W)T+T5X
M<&]R="!#86QE;F1A<@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE
M;&1S.@!*86YU87)Y`$IU;'D`2G5N90!+97EW;W)D<P!,86YG=6%G90!,87-T
M('=E96L`3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z`$QI<W0@2&5L
M<"!4;W!I8W,`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-87)C
M:`!-871C:&EN9R!F:65L9',`36%Y`$UE971I;F<`365N=2!M;V1E.@!-97-S
M86=E`$UI;G5T92AS*0!-;P!-;VYD87D`36]N=&@`36]N=&AL>0!-;VYT:&QY
M.B!296-U<G,@979E<GD`3F5V97(`3F5W($5V96YT`$YE>'0@36]N=&@`3F5X
M="!D87D`3F5X="!W965K`$YO(&5N9"!D871E`$YO;F4`3F]T97,`3F]V96UB
M97(`3V-T;V)E<@!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D
M`%!A='1E<FX`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<FUA
M;F5N=&QY(&1E;&5T92!T:&ES(&5V96YT/P!0:&]N90!0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R979I;W5S(&1A>0!0<F]B;&5M
M($1E<V-R:7!T:6]N`%)E8W5R(%5N=&EL`%)E8W5R<F5N8V4@1&%T80!296-U
M<G)E;F-E($5N9"!$871E`%)E8W5R<F5N8V4@26YT97)V86P`4F5C=7)R96YC
M92!4>7!E`%)E8W5R<R!D86EL>0!296-U<G,@;6]N=&AL>0!296-U<G,@=V5E
M:VQY`%)E8W5R<R!Y96%R;'D`4F5M;W9E('!A:7(`4F5S970@=&\@1&5F875L
M=',`4F5T=7)N('1O($]P=&EO;G,`4F]L90!380!3871U<F1A>0!3879E($%S
M($YE=P!3879E($5V96YT`%-A=F4@3W!T:6]N<P!396QE8W0@8V]N9FER;6%T
M:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE
M=W,@86YD(&-H;V]S92!D969A=6QT('9I97<N`%-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@
M9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3H`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1H92!T:6UE('-P86X@=&\@
M<VAO=SH`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!397!T
M96UB97(`4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R/P!3:&]W(&]N
M;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S970_`%-K:7`@36%I;G1E
M;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W1A<G0@1&%T90!3=&%R
M="!/;@!3=&%R="!4:6UE`%-U`%-U8V-E<W,`4W5N9&%Y`%1A<VMS`%1E>'0@
M3VYL>0!4:`!4:&4@96YD(&1A=&4@;75S="!B92!L871E<B!T:&%N('1H92!S
M=&%R="!D871E+@!4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N`%1H=7)S9&%Y`%1I=&QE`%1O9&%Y`%1U`%1U97-D
M87D`5'EP90!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#
M:&%N9V5S`%5S97(@26YT97)F86-E`%5S97(@3W!T:6]N<P!5<V5R;F%M90!7
M87)N:6YG`%=E`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E:RAS*0!7965K
M;'D`5V5E:VQY.B!296-U<G,@979E<GD`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L
M('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\`5VAA="!T:6UE('-H
M;W5L9"!D87D@86YD('=E96L@=FEE=W,@<W1A<G0L('=H96X@=&AE<F4@87)E
M(&YO(&5A<FQI97(@979E;G1S/P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7
M;W)K(%=E96L`65D`665A<FQY`%EE87)L>3H@4F5C=7)S(&5V97)Y`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`
M6VQI;F4@)7,@;V8@)7-=`&1A>0!D87DH<RD`9&%Y<P!M;VYT:"AS*0!O;B!T
M:&4@<V%M92!D871E`&]N('1H92!S86UE('=E96MD87D`=D-A<F0`=V5E:P!W
M965K*',I(&]N.@!W965K<P!Y96%R*',I`%!R;VIE8W0M260M5F5R<VEO;CH@
M2W)O;F]L:71H.B`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,2TP-RTR-B`Q,3HS
M-BLP,C`P"DQA<W0M5')A;G-L871O<CH@4W1E9F%N;W,@22X@1&EM:71R:6]U
M(#QS=7!P;W)T7W=E8FUA:6Q`=&5I871H+F=R/@I,86YG=6%G92U496%M.B!'
M<F5E:R`\9&5V0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3<*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"5S(,OEZ?3O]?'C
MW^7R(-/U[?3>\>?SY_(@+2#%\.GBY>+AW_GSYP`E<RP@W>/I[>4@Y?#I]/7W
M_O(@YR#EZ?/AX_GCWB#T[_4@X?'WY=_O]0`R-/[QYR#L[_'VW@#0S"_,S`#0
M\>_SZ-[JYR##Y>/O[?ST[_(`T/'O\^C>ZN<@[=WO]2##Y>/O[?ST[_(`T/'O
M\^C>ZN<@YN7]X^_U\@#$Z>7]Z/7M\^<`T/'OY>GD[_#OW^?SYP#'[.7Q[^SG
M[=_A(-#Q[^7IY._P[]_G\^?R`,3IW/'JY>GA(-#Q[^7IY._P[]_G\^?R("CK
MY?#TW"D`Q^SE\>_LY^W?X2#0\>_EZ>3O\._?Y_/G\@#8Y?7D_NWU[.\`O.OA
M`+SKY?(@].GR(.S=\>7R`,/EX^_M_/(@\._U(.3IX?'JY=\@_.OG(/3G[2#L
MW?'A`+SKX2#TX2#CY>/O[?STX0#/\=_S].?JY2#LW^$@[.<@Y?#I]/'E\/SL
MY>WG(/3I[-XN`,'P\=_KZ>_R`-/E`,']X^_U\_3O\@#$Z>'HW?/I[.$@T.7D
MW^$Z`,/E[=WHZ^GA`,'J]?'O`,'J_?'Y\^<@P>WA]N_QW/(@T/'OXNO>[.'T
M[_(`RN'TY^/O\=_A`,KI[>?T_"#4Y^O=]OGM[P#*Z^7?\^GL[R#0X?'<Z/7Q
M[_4`Q?3AZ?'?X0`JS>$@YN?TY=_TX>D@Y?#IXN7BX=_Y\^<@ZN'TW"#TYR#D
MZ>'C\>'VWB#T^>T@X^7C[^W\]/GM.P#$Y^SI[_7QX]_A(.W=[_4@X^7C[^W\
M]._R`-3QW??Y[0!$1`#'[.7QWO/IX0#*X>CG[.7QZ>W<.B#*W.CE`,?LW?'A
M`,?LW?'A*.7R*0#$Y>K=[.+QZ>_R`-#Q[^7PZ>OEX^S=[><@U.'U]/STY_3A
M`,3IX>/QX?;>`,3IX>/QX?;>("5S`,3IX>/QX?;>(,/EX^_M_/3O\@#$Z>'C
M\=SX].4@].\@]/'=]_GM(./EX^_M_/(@[/SM[RP@X?7T_"#T[R#PY?'I\_3A
M].GJ_"#JX>D@_.OE\B#TZ?(@[.7KZ^_M].GJW?(@Y>SVX>W?\^7I\B#T[_4L
M(-[\Z^7R(/3I\B#E[/;A[=_SY>GR(/3O]3L`T.7QZ>/QX?;>(/3O]2#0\>_B
MZ][LX?3O\@#0Y?'IX_'A]MX`S^D@Z^7P]._LW?'EZ>7R(-WW[_7M(.KA].'C
M\>'VY=\@X^GA(/3O[2#DZ>'WY>GQZ?/TWBX`Q>SVW.WI\^<@T?7H[-_SY?GM
M`,SG[2#E\.GWY>GQWO/E].4@[>$@X>WOW^[E].4@X?#E]>CEW^'R(/3O(.'Q
M]^7?[R!M86EN=&5N86YC92YP:'``Q.G<\>KEZ>$Z("5S`,3IW/'JY>GA`,7P
MY>[E\>/A\]_A`,7PY>[E\>/A\]_A("5S`,'KZ^?K[^/QX?;?X0#$Y>T@Y?#I
M\_3QW/;GZN'M(,'P[_3EZ]WS[.'TX2X`Q^SE\>_LY^W?X2#+WN[G\@#+WN[G
M(-/TZ?(`O_'A(,O>[N?R`,O<Z._R`,K<Z.4@,34@Z^7P]-P`RMSHY2`S,"#D
MY?7TY?'\Z^7P].$`RMSHY2`U(.OE\/3<`,K<Z.4@]N_QW"#P[_4@[/#AW^WE
M].4@\_3G[2#U\.?QY?/?X0#*W.CE(.SI\]X@_O'A`,K<Z.4@Z^7P]/P`T.'Q
MX>3EZ>/LX?3IZMWR(/3I[-WR.@#%[N'C^>/>`,7NX>/YX]X@Q^SE\>_K[^/?
M[_4`P?#O]/7WW^$@ZN'TW"#TY^T@\/'O\_#<Z.7IX2#A[=SJ].?SY_(@]/GM
M(/#Q[_3I[-[SY?GM+@#!\._T]???X2#S_>WDY?/G\B#S]._M(.3IX>KO[.GS
M]-X@RN'TX>O\X^_U+@#6P<X`UN7B\>_UW/'I[_(`T.$`T.'QX?/JY?7>`,SE
MZ^OO[?3IZMP`T.'I]^W?Y.D`PN_>Z.7IX0#$Z>7]Z/7M\^<@T_#I].GO_0#4
MY^O=]OGM[R#3\.GTZ>_]`,'Q]^GJWB#3Y>O?Y.$`O_'A*.7R*0#,_.WO(,7I
MZN_MW^3IX0#%Z>KO[=_DZ>$@ZN'I(,KEW^SE[>\`Q>GSX>/YX]XOQ>[AX_GC
MWB#'[.7Q[^OOX]_O]0#0Y>3?[R#P[_4@Y>GSWO?HYSH@)7,`T.7DW^$@\._U
M(.7I\][WZ.?SX>TZ`,GA[>_UW/'I[_(`R>_]Z^GO\@#)[_WMZ>_R`,O=[N<@
MZNOEZ>3?`,/K_O/SX0#4Y>OE]?3AW^$@Q>+D[^S<Y.$`Q?#IZ]WN].4@].\@
MY?WQ[_(@]._U(/?Q_.WO]2#P[_4@Z.$@Y>[<X^7TY3H`R]_S].$@Z.7LW/3Y
M[2#"[][HY>GA\@#4[_#OZ.7SW^$`Q=_S[^3O\@"X[N_D[_(`S,P`P>OKY^OO
MX_'A]M_A`,S<\?3I[_(`T.7DW^$@\._U(/3AZ?'IW.;O]>T`S-SI[_(`T_7M
MW.WTY_/G`,KA]-SS].'SYR#,Y>WO_3H`S-[M]>SA`,OE\/3\*-PI`,3E`,3E
M]?3=\>$`S-[MX?(`S.?MZ>'?X0#,Y^WIX=_A.B#*W.CE`-#O]-T`S=WO(,/E
MX^_M_/(`Q?#\[.7M[_(@S-[MX?(`Q?#\[.7MYR#,W?'A`,7P_.SE[><@Q>+D
M[^S<Y.$`Q.7M(/7PW/'WY>D@Y^SE\>_LY^W?X2#KWN[G\@#*X>W=[>$`T^?L
MY>G^\^7I\@#-[]WLXO'I[_(`S^KT_N+QZ>_R`,7PZ>OOX]WR`,'KZ^7R(-#K
MY_'O]N_QW^7R`,KYY.GJ_/(`S._TW^+O`,7J]-WKY?/G(,OEZ?3O]?'CZ?[M
M(-/U[?3>\>?SY_(`S>$@Y.GAX_'A]N7?(,S/S<G,P2#A]?3\(/3O(./EX^_M
M_/([`-3GZ]WV^>WO`-#A\>'JX>O^(.3^\_3E(.S?X2#PY?'?Z^?XYR#T[_4@
M\/'OXNO>[.'T[_(N`-#A\>'JX>O^(.3^\_3E(/3O(+SM[^SA(-?QWO/TYR#J
MX>D@]._M(.KYY.GJ_"#SX?(`T/'OY^/O_>SE[><@Y^S=\>$`T.7QZ>/QX?;>
M(-#Q[^+KWNSA]._R`,7PX>W<Z^?XYR#=^?(`Q?#A[=SKY_CG(.3EY._LW>WY
M[0`JQ^SE\>_LY^W?X2#4W>OO]?(`*L7PX>W<Z^?XYR#=^?(`*L7PX>WAZ^'L
MXN'M_.SE[>_R(-3]\._R`,KAZ.?LY?'I[?[R`,7PX>W<Z^?XYR#A[=P@[-[M
MX0#%\.'MW.OG^.<@X>W<(.7BY._LW.3A`,7PX>W<Z^?XYR#A[=P@]_'\[>\`
MP?;AW_'E\^<@YN7]X^_U\@#%\.'MX?;O\=P@]/GM(/#Q[^7PZ>OEX^S=[?GM
M(/'UZ.S?\^7Y[0#%\.GS]/'O]MX@\_3I\B#%\.GK[^/=\@#1_.OO\@#3X0#3
MW.+BX?3O`,'P[^C>ZN7U\^<@^?(@[=WO`,'P[^C>ZN7U\^<@P^7C[^W\]._R
M`,'P[^C>ZN7U\^<@Q?#IZ^_C_NT`Q?#IZ]WN].4@]._M(/3Q_/#O(.7L]MSM
MZ?/G\BP@ZN'I(/3O[2#T\?SP[R#E\.GBY>+AW_GSY_(@]/GM(.7MY?'CY>G^
M[2X`Q?#IZ^_CWB#T[_4@Y.GA]_GQZ?/TWB#G[.7Q[^SG[=_A\CH`Q?#IZ^_C
MWB#TY_(@[._Q]M[R(/#O]2#HX2#=]^7I(.<@Y^SE\>_LY^W?X3H`Q?#IZ]WN
M].4@].\@X?'WY=_O(/#O]2#HX2#EZ?/<X^7TY3H`Q?#IZ]WN].4@].?M(/#Q
M_O3G(.?LW?'A(/3G\B#EXN3O[-SD[_(Z`,7PZ>OOX]X@].?R(.SO\?;>\B#P
M[_4@Z.$@W??EZ2#G(/[QX3H`Q?#IZ]WN].4@].\@Y?WQ[_(@]._U(/?Q_.WO
M]2#P[_4@Z.$@Y>SVX>W?YN7TX>DZ`,7PZ>O=[O3E(.3][R#PY>3?X2#P[_4@
M].'I\>G<YN_U[2X`Q?#IZ]WN].4@].<@X^O^\_/A(//A\CH`P?#O\_3OZ]X@
MP>WA]N_QW/(@T/'OXNO>[.'T[_(`T^7P]-WLXO'I[_(`S>$@Y>SVX>W?YN_M
M].'I(/3A(./EX^_M_/3A(//T[R#'[.7Q[^O\X^GO`,WA(.7L]N'MZ?/T[_WM
M(.S\[>\@].$@X^7C[^W\].$@\_3A(._P[]_A(-WWY>D@[_'I\_3EWR#U\.7M
MZ/WLZ?/G.P#!ZOWQ^?/G(-/U[?3>\>?SY_(`Q>GSX>/YX]X@Q>GDZ>K^[2#7
MX?'AZO3>\?GM`,?LY?'O[.?MW^$@Q>KJW^WG\^?R`,7JZM_MY_/G(//TZ?(`
MO_'A(,7JZM_MY_/G\@#*]0#%\.GT]???X0#*]?'IX>K>`,/EX^_M_/3A`,S\
M[>\@RN7?[.7M[P#0W0#'(.?LY?'O[.?MW^$@]-WK[_7R(/#QW?#EZ2#MX2#E
MW^WAZ2#LY?3AX^7MW?/TY?'G(/3G\B#G[.7Q[^SG[=_A\B#A\??>\BX`Q.7M
M(/7PW/'W[_7M(./EX^_M_/3A(/#Q[_(@Y>[AX_GCWBX`P?7T_/(@[R#A\>GH
M[/SR(/#QW?#EZ2#MX2#EW^WAZ2#T[_7KW/?I\_3O[2#=[>$N`,'U]-X@YR#T
MZ>S>(/#QW?#EZ2#MX2#EW^WAZ2#A\>GH[/SR+@#0W>SP].<`U-_TZ^_R`-/>
M[.7QX0#4\=\`U/'?].<`U/WP[_(`Q.7M(.7?[>'I(.3U[>'T_.T@[>$@]N_Q
M]/GH[_WM(._I(/'UZ.S?\^7I\B#T[_4@)7,N`,3E[2#L\/SQY?/E(.WA(.SE
M].'V\>'S].7?(.'U]/P@].\@W>/C\>'V[R!7;W)D`,'J_?'Y\^<@P>OKX>/^
M[0#0Y?'IXMSKZ^_M(-?QWO/TYP#%\.GK[^/=\B#7\=[S].<`O.WO[.$@U_'>
M\_3G`-#Q[^7IY._P[]_G\^<`U.4`U.7TW/'TYP#%XN3O[-SDX0#%XN3O[-SD
MX2`E9`#%XN3O[-SDX2CE\BD`Q>+D[^SAY.GAW^$`Q>+D[^SAY.GAW^$Z(,K<
MZ.4`RN'K^?/>\>CE\B#S].\@)7,`RN'K_O(@WNOHY?(L("5S`-#OZ>$@Z.$@
MY=_MX>D@YR#TY>OIZMX@_O'A(//TY^T@Y>SVW.WI\^<@X>W<(.?LW?'A(.KA
MZ2#A[=P@Y>+D[^S<Y.$L(/STX>T@Y.7M]?#<\??O]>T@W.OKX2#CY>/O[?ST
MX2#P\>_SY.GO\>GS[-WMX2#A\>/\].7QX2#A\/P@X?7TWCL`T._IX2#HX2#E
MW^WAZ2#G(/[QX2#=[>'Q[N?R(//TY^T@Y>SVW.WI\^<@X>W<(.?LW?'A(.KA
MZ2#A[=P@Y>+D[^S<Y.$L(/STX>T@Y.7M]?#<\??O]>T@W.OKX2#CY>/O[?ST
MX2#P\>_SY.GO\>GS[-WMX2#M^?'?].7QX2#A\/P@X?7TWCL`Q.GE_>CU[?/G
M(,7QX^'SW^'R`-3GZ]WV^>WO(,7QX^'SW^'R`-#E[>C>[.7Q[P!960#%]-[S
MZ>$`Q?3G\]_Y\CH@RMSHY0#0\=WPY>D@[>$@\.7QZ>/QW/CE].4@].\@\/'\
MXNOG[.$@\/'I[2#S].7?Z^7TY2#A[>'V[_'<(./IX2#A]?3\+@#'(//][>3E
M\^<@\^'R("5S(.3IX>K\\.?JY2X@T.'QX>KAZ_X@Y._JZ>S<\_3E(.WA(.[A
M[>'S]>WDY>CEW_3E+@#/Z2#0Z^?Q[_;O\=_E\B#SX?(`S^D@Y?#IZ^_CW?(@
M\^'R(-WW[_7M(.'P[^CGZN7U].7?+@!;P>WA]N_QW"#0\>_BZ][LX?3O\ET`
M6^/QX>SLWB`E<R#A\/P@)7-=`.?LW?'A`.?LW?'A*.7R*0#G[-WQY?(`[-[M
MX2CE\BD`].?M(-_DZ>$@Y^S=\>$`].?M(-_DZ>$@Y>+D[^S<Y.$`V.?VZ>'J
MWB#*W/'TX0#EXN3O[-SDX0#EXN3O[-SDX2CE\BD@].?M*/3O*3H`Y>+D[^S<
MY.7R`-WT[_(HYRD`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O96Y?55,O````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``,#(P
M-S`R`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]E
M;E]54R]H96QP+GAM;```````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3(W
M,``Q,#0Q-S,V,C<U,``P,C(S-3(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]X;6P@=F5R<VEO;CTG,2XP)S\^"CPA+2T@
M)$AO<F1E.B!K<F]N;VQI=&@O;&]C86QE+V5N7U53+VAE;'`N>&UL+'8@,2XT
M(#(P,#0O,3(O,#<@,38Z,#`Z,S<@:F%N($5X<"`D("TM/@H\:&5L<#X*"CQE
M;G1R>2!I9#TB3W9E<G9I97<B/@H@("`@/'1I=&QE/DMR;VYO;&ET:#H@3W9E
M<G9I97<\+W1I=&QE/@H@("`@/&AE861I;F<^5VAA="!I<R!+<F]N;VQI=&@_
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!+<F]N;VQI=&@@:7,@82!W96(M
M8F%S960@8V%L96YD87(@87!P;&EC871I;VXN("!);B!A9&1I=&EO;B!T;R!T
M:&4*("`@(')E<75I<F5D(&9U;F-T:6]N<R!O9B!C<F5A=&EN9RP@;6]D:69Y
M:6YG+"!A;F0@9&5L971I;F<@979E;G1S+"!I=`H@("`@8W5R<F5N=&QY('-U
M<'!O<G1S(')E8W5R<FEN9R!E=F5N=',@*'=I=&@@97AC97!T:6]N<R!A;F0@
M=F%R:6]U<R!D96QE=&EO;@H@("`@;W!T:6]N<RDL(&%L87)M<RP@:6UP;W)T
M(&%N9"!E>'!O<G0@9G5N8W1I;VYS("AI0V%L96YD87(@86YD($-35B!F;W)M
M871S*2P*("`@(&E#86QE;F1A<B!I;G9I=&%T:6]N<RP@;75L=&EP;&4@8V%L
M96YD87(@=FEE=W,L('-H87)E9"!C86QE;F1A<G,L(&1I<W!L87D*("`@(&]F
M(%1A<VL@3&ES="`H3F%G*2!T87-K<R`H:68@5&%S:W,@3&ES="!I<R!I;G-T
M86QL960I+"!A;F0@86)I;&ET>2!T;R!S:&]W"B`@("!E=F5N=',@:6X@=&AE
M($AO<F1E('-U;6UA<GD@<V-R965N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*
M/&5N=')Y(&ED/2)M96YU+71O9&%Y(CX*("`@(#QT:71L93Y-96YU.B!4;V1A
M>3PO=&ET;&4^"B`@("`\<&%R83X*("`@(%1H92`\:3Y4;V1A>3PO:3X@;65N
M=2!I=&5M('=I;&P@9&ES<&QA>2!Y;W5R(&1E9F%U;'0@=FEE=R`H;6]N=&@L
M('=E96LL"B`@("!D87DL(&5T8RX@87,@<V5T(&EN($]P=&EO;G,I(&9O<B!T
M:&4@8W5R<F5N="!D871E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y
M(&ED/2)M96YU+4=O=&\B/@H@("`@/'1I=&QE/DUE;G4Z($=O=&\\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!4:&4@/&D^1V]T;SPO:3X@;65N=2!I=&5M('=I
M;&P@9&ES<&QA>2!A('-M86QL('!O<"UU<"!W:6YD;W<@:6X@=VAI8V@@>6]U
M"B`@("!C86X@<75I8VML>2!S96QE8W0@82!M;VYT:"P@=V5E:R!O9B!T:&4@
M>65A<BP@;W(@9&%Y(&]F('1H92!M;VYT:"!T;R`\:3YG;PH@("`@=&\\+VD^
M+B`@5&AI<R!I<R!U<W5A;&QY('1H92!Q=6EC:V5S="!W87D@=&\@;6]V92!W
M:71H:6X@=&AE(&-A;&5N9&%R+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N
M=')Y(&ED/2)M96YU+41A>2(^"B`@("`\=&ET;&4^365N=3H@1&%Y/"]T:71L
M93X*("`@(#QP87)A/@H@("`@5&AE(#QI/D1A>3PO:3X@=&%B('=I;&P@9&ES
M<&QA>2!T:&4@9&%Y('9I97<@;V8@=&AE(&-U<G)E;G1L>2!S96QE8W1E9`H@
M("`@9&%Y+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)M96YU
M+7=O<FLM=V5E:R(^"B`@("`\=&ET;&4^365N=3H@5V]R:R!7965K/"]T:71L
M93X*("`@(#QP87)A/@H@("`@5&AE(#QI/E=O<FL@5V5E:SPO:3X@=&%B('=I
M;&P@9&ES<&QA>2!T:&4@=V]R:R!W965K('9I97<@*$UO;F1A>2!T:')O=6=H
M"B`@("!&<FED87DI(&-L;W-E<W0@=&\@=&AE(&-U<G)E;G1L>2!S96QE8W1E
M9"!D87DN"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](FUE;G4M
M=V5E:R(^"B`@("`\=&ET;&4^365N=3H@5V5E:SPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(%1H92`\:3Y7965K/"]I/B!T86(@=VEL;"!D:7-P;&%Y('1H92!W
M965K('9I97<@*#<@9&%Y('9I97<I(&9O<B!T:&4@=V5E:PH@("`@8V]N=&%I
M;FEN9R!T:&4@8W5R<F5N=&QY('-E;&5C=&5D(&1A>2X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*"CQE;G1R>2!I9#TB;65N=2UM;VYT:"(^"B`@("`\=&ET;&4^
M365N=3H@36]N=&@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4:&4@/&D^36]N
M=&@\+VD^('1A8B!W:6QL(&1I<W!L87D@=&AE(&UO;G1H('9I97<@9F]R('1H
M92!M;VYT:"!C;VYT86EN:6YG"B`@("!T:&4@8W5R<F5N;'D@<V5L96-T960@
M9&%Y+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)M96YU+6YE
M=RUE=F5N="(^"B`@("`\=&ET;&4^365N=3H@3F5W($5V96YT/"]T:71L93X*
M("`@(#QP87)A/@H@("`@5&AE(#QI/DYE=R!%=F5N=#PO:3X@;65N=2!I=&5M
M('=I;&P@86QL;W<@>6]U('1O(&-R96%T92!A(&YE=R!E=F5N="!T;R!B90H@
M("`@861D960@=&\@82!C86QE;F1A<BX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M"CQE;G1R>2!I9#TB;65N=2UO<'1I;VYS(CX*("`@(#QT:71L93Y-96YU.B!/
M<'1I;VYS/"]T:71L93X*("`@(#QP87)A/@H@("`@5&AE(#QI/D]P=&EO;G,\
M+VD^(&UE;G4@:71E;2!A;&QO=W,@>6]U('1O('-E="`\:3Y/<'1I;VYS/"]I
M/B`H;W(*("`@('!R969E<F5N8V5S*2!T:&%T(&-O;G1R;VP@=&AE(&QO;VL@
M86YD(&9E96P@;V8@2W)O;F]L:71H+"!+<F]N;VQI=&@G<PH@("`@:6YT97)A
M8W1I;VX@=VET:"!(;W)D92!A;F0@;W1H97(@2&]R9&4@87!P;&EC871I;VYS
M+"!A;F0@;6%N86=E(&UU;'1I<&QE"B`@("!A;F0@<VAA<F5D(&-A;&5N9&%R
M<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB;65N=2UI;7!O
M<G0M97AP;W)T(CX*("`@(#QT:71L93Y-96YU.B!);7!O<G0O17AP;W)T/"]T
M:71L93X*("`@(#QP87)A/@H@("`@5&AE(#QI/DEM<&]R="]%>'!O<G0\+VD^
M(&UE;G4@:71E;2!A;&QO=W,@>6]U('1O(&EM<&]R="!O<B!E>'!O<G0@8V%L
M96YD87(*("`@(&5V96YT<RX@($-U<G)E;G1L>2!Y;W4@8V%N(&EM<&]R="!F
M:6QE<R!I;B!#4U8L($UI8W)O<V]F="!/=71L;V]K+"!A;F0*("`@('9#86QE
M;F1A<B]I0V%L96YD87(@9F]R;6%T<RX@(%EO=2!C86X@97AP;W)T('1O(&]N
M;'D@0U-6(&%N9"!I0V%L96YD87(*("`@(&9O<FUA=',N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"@H\96YT<GD@:60](F%L87)M<R(^"B`@("`\=&ET;&4^06QA
M<FUS/"]T:71L93X*("`@(#QP87)A/@H@("`@2W)O;F]L:71H(&-A;B!G96YE
M<F%T92!A;&%R;7,@9F]R(&5V96YT<R!I;B!A(&-A;&5N9&%R+B`@0GD@9&5F
M875L="P@=&AE"B`@("!F:7)S="!A;&%R;2!I<R!G96YE<F%T960@9FEF=&5E
M;B!M:6YU=&5S(&)E9F]R92!T:&4@87!P;VEN=&UE;G0@:7,*("`@('-U<'!O
M<V5D('1O('-T87)T+"!B=70@=&AE(&%L87)M(&-A;B!B92!S970@*'!E<B!E
M=F5N="D@=&\@;V-C=7(@870@86QM;W-T"B`@("!A;GD@:6YT97)V86P@8F5F
M;W)E('1H92!E=F5N="!S=&%R="!T:6UE+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H*/&5N=')Y(&ED/2)R96-U<G)I;F<M979E;G1S(CX*("`@(#QT:71L93Y2
M96-U<G)I;F<@179E;G1S/"]T:71L93X*("`@(#QP87)A/@H@("`@179E;G1S
M(&-A;B!B92!M861E('1O(')E<&5A="!I;B!V87)I;W5S('=A>7,N($UA;GD@
M979E;G1S(')E<&5A="!I;@H@("`@8V5R=&%I;B!F<F5Q=65N=&QY('5S960@
M=V%Y<RX@1F]R(&5X86UP;&4L('1H92`\:3Y-;VYT:&QY/"]I/B!R96-U<G)E
M;F-E"B`@("!T>7!E<R!M86ME('1H92!S96QE8W1E9"!I=&5M(')E<&5A="!E
M86-H(&UO;G1H(&%N9"!T:&4@/&D^5V5E:VQY/"]I/@H@("`@<F5C=7)R96YC
M92!T>7!E(&UA:V5S('1H92!S96QE8W1E9"!I=&5M(')E<&5A="!E86-H('!E
M<B!W965K+B!4:&5S92!C86X@8F4*("`@(&UA9&4@=&\@<F5P<F5S96YT(&5V
M96YT<R!T:&%T(')E<&5A="!I;B!C;VUP;&5X('=A>7,Z(&9O<B!E>&%M<&QE
M+"!A;B!I=&5M"B`@("!T:&%T(&]C8W5R<R!O;B!T:&4@=&AI<F0@1G)I9&%Y
M(&]F(&5A8V@@;6]N=&@L(&]R(&%N(&ET96T@=&AA="!O8V-U<G,@;VX*("`@
M($UO;F1A>2P@5V5D;F5S9&%Y+"!A;F0@1G)I9&%Y(&5V97)Y('=E96LN(`H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!9;W4@8V%N(&%L<V\@<F5S=')I
M8W0@:&]W(&QO;F<@86X@979E;G0@<F5P96%T<R!B>2!S96QE8W1I;F<@=&AE
M(#QI/F5N9`H@("`@9&%T93PO:3X@9F]R('1H92!E=F5N="=S(')E8W5R<F5N
M8V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($YO<FUA;&QY+"!A(&UO
M9&EF:6-A=&EO;B!T;R!A(')E<&5A=&EN9R!E=F5N="!A<'!L:65S('1O(&%L
M;"!O8V-U<G)E;F-E<PH@("`@;V8@=&AA="!E=F5N="X@02!S:6YG;&4@;V-C
M=7)R96YC92!O9B!A(')E<&5A=&EN9R!E=F5N="!C86X@8F4@;6]D:69I960@
M8GD*("`@(&5D:71I;F<@=&AE(&]C8W5R<F5N8V4L(')E;6]V:6YG(&ET<R!R
M96-U<G)E;F-E(&EN9F]R;6%T:6]N+"!A;F0@=&AE;@H@("`@8VAO;W-I;F<@
M=&AE(#QI/E-A=F4@87,@3F5W/"]I/B!O<'1I;VX@9G)O;2!T:&4@4F5P96%T
M(&UE;G4N(%1H92!S96QE8W1E9`H@("`@;V-C=7)R96YC92!C86X@;F]W(&)E
M(&UO9&EF:65D(&EN9&5P96YD96YT;'D@;V8@=&AE(&]T:&5R(&]C8W5R96YC
M97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](E!R:6YT:6YG
M(CX*("`@(#QT:71L93Y0<FEN=&EN9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY0
M<FEN=&EN9R!#86QE;F1A<G,@86YD($5V96YT<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@0V5R=&%I;B!V:65W<R!A<F4@9&5S:6=N960@=&\@8F4@<')I
M;G1A8FQE+B`@5VAE;B!I;B!O;F4@;V8@=&AE<V4@=FEE=W,L(&$*("`@(#QI
M/E!R:6YT/"]I/B!I8V]N('=I;&P@87!P96%R(&EN('1H92!T;W`@;65N=2!B
M87(N("!5<V4@=&AI<R!M96YU(&EC;VX@=&\*("`@('!R:6YT('1H92!C=7)R
M96YT('9I97<N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\+VAE;'`^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L
M;V-A;&4O97-?15,O````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-3``,#(P-C8W`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]E<U]%4R],0U]-15-304=%4R\`````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,``P,C(T-30`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+V5S7T53
M+TQ#7TU%4U-!1T53+VMR;VYO;&ET:"YM;P``````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-3`V,3$V`#$P
M-#$W,S8R-S4P`#`R-3`S,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#>$@25`````.T(```<````A$<``.D+``#LC@``````
M`)"^```.````D;X```\```"@O@``#0```+"^```(````OKX```L```#'O@``
M#````-.^```$````X+X``!@```#EO@``&P```/Z^```M````&K\``!T```!(
MOP``)````&:_```I````B[\``!D```"UOP``)@```,^_```,````]K\``!(`
M```#P```)````!;````)````.\````\```!%P```"P```%7````?````8<``
M``X```"!P```!0```)#````H````EL````@```"_P```"@```,C````5````
MT\```!(```#IP```"P```/S````,````",$``!T````5P0``A0```#/!```.
M````N<$```H```#(P0``#0```-/!```.````X<$``!$```#PP0``#0````+"
M```,````$,(```T````=P@``!@```"O"``"4````,L(``$\```#'P@``'0``
M`!?#```=````-<,```H```!3PP``#P```%[#```8````;L,```P```"'PP``
M"@```)3#```'````G\,```8```"GPP``#@```*[#```*````O<,```H```#(
MPP``#@```-/#```(````XL,```H```#KPP``"0```/;#```E`````,0``"@`
M```FQ```)````$_$```F````=,0``"X```";Q```&@```,K$```R````Y<0`
M`#@````8Q0``5````%'%``!1````IL4``%H```#XQ0``5P```%/&```T````
MJ\8```(```#@Q@``"0```./&```-````[<8```<```#[Q@``"@````/'```/
M````#L<```4````>QP``!@```"3'```1````*\<```@````]QP``"0```$;'
M```)````4,<```@```!:QP``)0```&/'```@````B<<``!,```"JQP``$```
M`+['```/````S\<```H```#?QP``$````.K'```#````^\<```\```#_QP``
M%`````_(```)````),@```D````NR```#0```#C(```2````1L@``!D```!9
MR```'@```'/(```9````DL@```\```"LR```#P```+S(```-````S,@```H`
M``#:R```#P```.7(```(````]<@``"0```#^R```%````"/)```0````.,D`
M`!8```!)R0``"````&#)``!.````:<D``"T```"XR0``&0```.;)```'````
M`,H```P````(R@``+````!7*```.````0LH```,```!1R@``#P```%7*```+
M````9<H```4```!QR@``%````'?*```5````C,H``!<```"BR@``%0```+K*
M```2````T,H``!,```#CR@``%0```/?*```3````#<L```H````ARP``%```
M`"S+```*````0<L```<```!,RP``!P```%3+```%````7,L```4```!BRP``
M"@```&C+```#````<\L```T```!WRP``%P```(7+```*````G<L```H```"H
MRP``"````+/+```/````O,L```L```#,RP``!P```-C+```-````X,L```H`
M``#NRP``#@```/G+```8````",P``",````AS```#@```$7,```4````5,P`
M`!<```!IS```%P```(',```7````F<P``!,```"QS```#P```,7,```.````
MU<P``!\```#DS```'0````3-```'````(LT```8````JS0``"````#'-```/
M````.LT```8```!*S0``"@```%'-```3````7,T```,```!PS0``"P```'3-
M```0````@,T``!4```"1S0``%0```*?-```'````O<T``!````#%S0``!0``
M`-;-```5````W,T``!$```#RS0``#`````3.```[````$<X``#@```!-S@``
M"0```(;.```'````D,X``!0```"8S@```P```*W.```%````L<X``!````"W
MS@``"0```,C.```3````TLX``#D```#FS@``$@```"#/```"````,\\``+0`
M```VSP``)P```.O/```L````$]```"H```!`T```)0```&O0```*````D=``
M``D```"<T```"@```*;0```&````L=````D```"XT```!P```,+0```O````
MRM```#<```#ZT```+@```#+1``!5````8=$``"T```"WT0``+0```.71```]
M````$](``#\```!1T@``+0```)'2``!`````O](``",`````TP``(P```"33
M``!`````2-,``"T```")TP``,P```+?3```E````Z],``!4````1U```&0``
M`"?4```I````0=0``"0```!KU```*````)#4```1````N=0```H```#+U```
M#````-;4```*````X]0``!````#NU```%@```/_4```6````%M4```<````M
MU0``!P```#75```4````/=4```H```!2U0``"````%W5```G````9M4```@`
M``".U0``#````)?5```'````I-4```<```"LU0``!@```+35```%````N]4`
M``<```#!U0``!@```,G5```(````T-4``"D```#9U0``#@````/6```*````
M$M8```0````=U@``!P```"+6```)````*M8```8````TU@``$0```#O6```'
M````3=8``!8```!5U@``!````&S6```(````<=8```8```!ZU@``#0```('6
M```&````C]8``!X```"6U@``$0```+76```(````Q]8```T```#0U@``#```
M`-[6```'````Z]8```0```#SU@```P```/C6```#````_-8``!<`````UP``
M"0```!C7```3````(M<``!T````VUP``"0```%37```(````7M<``!````!G
MUP``'0```'C7```)````EM<``!L```"@UP``!````+S7```(````P=<```@`
M``#*UP``00```-/7```:````%=@``"L````PV```(````%S8```9````?=@`
M`!4```"7V```!@```*W8```&````M-@``!4```"[V```"0```-'8```-````
MV]@``!@```#IV```(@````+9```N````)=D``!T```!4V0``(0```'+9``!4
M````E-D``"D```#IV0``"@```!/:```'````'MH```<````FV@``"0```"[:
M```5````.-H```@```!.V@``#@```%?:```*````9MH```\```!QV@``#0``
M`(':```/````C]H```T```"?V@``"0```*W:```4````M]H```8```#,V@``
M&````-/:```=````[-H``!,````*VP``$0```![;```4````,-L```0```!%
MVP``!@```$K;```4````4=L``%0```!FVP``9````+O;```$````(-P```X`
M```EW```!0```#3<```%````.MP``!L```!`W```&@```%S<```3````=]P`
M`!$```"+W```$0```)W<```<````K]P``$X```#,W```10```!O=``!%````
M8=T``"H```"GW0``-@```-+=```^````"=X``#\```!(W@``'0```(C>```0
M````IMX``"$```"WW@``!0```-G>```3````W]X```L```#SW@``$P```/_>
M```2````$]\```H````FWP``#P```#'?```-````0=\``!$```!/WP``$P``
M`&'?```,````==\```P```""WP``!@```(_?```,````EM\```8```"CWP``
M%P```*K?```0````PM\``!$```#3WP``"````.7?```%````[M\```P```#T
MWP``$`````'@```%````$N````T````8X```!@```";@```6````+>````<`
M``!$X```#0```$S@```'````6N````L```!BX```!P```&[@```'````=N``
M``D```!^X```"0```(C@```*````DN```!D```"=X```/0```+?@```=````
M]>````P````3X0``$````"#A```;````,>$```D```!-X0``!0```%?A```E
M````7>$``!(```"#X0``$P```);A```K````JN$``#L```#6X0``(````!+B
M```(````,^(``#8````\X@``(0```'/B```0````E>(```@```"FX@``#```
M`*_B```&````O.(```0```##X@``#P```,CB```.````V.(``$````#GX@``
M!P```"CC```*````,.,```T````[XP``'P```$GC```<````:>,``"$```"&
MXP``'@```*CC```9````Q^,``!X```#AXP``&P````#D```A````'.0``"X`
M```^Y```)@```&WD```<````E.0``!X```"QY```'````-#D```F````[>0`
M`"L````4Y0``,P```$#E```F````=.4``"L```";Y0``.````,?E```=````
M`.8``!4````>Y@``+P```#3F```@````9.8``!(```"%Y@``*0```)CF```>
M````PN8``"````#AY@``$@````+G``"B````%><``!8```"XYP``(P```,_G
M```H````\^<``"D````<Z```*````$;H```?````;^@``!4```"/Z```(```
M`*7H```E````QN@``"@```#LZ```+0```!7I```P````0^D``)(```!TZ0``
M(0````?J```6````*>H``!P```!`Z@``)@```%WJ```J````A.H``$$```"O
MZ@``1````/'J```,````-NL```<```!#ZP``!P```$OK```&````4^L```\`
M``!:ZP``$@```&KK```-````?>L``!````"+ZP``$@```)SK```'````K^L`
M`!,```"WZP``$@```,OK```'````WNL```0```#FZP``!P```.OK```0````
M\^L``!`````$[```#````!7L```.````(NP```T````Q[```#P```#_L```3
M````3^P```T```!C[```*````''L```#````FNP```T```">[```!@```*SL
M```1````L^P``!<```#%[```&P```-WL```.````^>P```(````([0``20``
M``OM```%````5>T``!,```!;[0``$````&_M```/````@.T```0```"0[0``
M#0```)7M```.````H^T```,```"R[0``!@```+;M```'````O>T```X```#%
M[0``"````-3M```/````W>T```@```#M[0``#P```/;M```'````!NX``!``
M```.[@``#0```!_N```0````+>X```T````^[@``"P```$SN```&````6.X`
M``D```!?[@``"P```&GN```,````=>X```P```""[@``"@```(_N```1````
MFNX``!D```"L[@``"P```,;N```-````TNX``"(```#@[@``#P````/O```;
M````$^\``#0````O[P``"@```&3O```8````;^\``!(```"([P``&0```)OO
M``!<````M>\``!8````2\```(@```"GP```-````3/````<```!:\```#```
M`&+P```4````;_````L```"$\```(@```)#P```O````L_````L```#C\```
M"0```._P```9````^?````L````3\0``%P```!_Q```7````-_$```D```!/
M\0``!P```%GQ```6````8?$``!$```!X\0``#P```(KQ```9````FO$``!8`
M``"T\0``#@```,OQ```8````VO$```@```#S\0``#0```/SQ```F````"O(`
M`#D````Q\@``#@```&OR``!#````>O(```@```"^\@``$@```,?R```?````
MVO(```@```#Z\@``"P````/S```O````#_,```X````_\P``!0```$[S```'
M````5/,```@```!<\P``!@```&7S``!%````;/,```,```"R\P``!P```+;S
M```$````OO,```<```##\P``#@```,OS```*````VO,```X```#E\P``"@``
M`/3S```/````__,``!`````/]```%P```"#T```5````./0```X```!.]```
M&@```%WT```1````>/0``!D```"*]```%P```*3T```)````O/0```4```#&
M]```"P```,ST```*````V/0```(```#C]```!0```.;T```-````[/0``!L`
M``#Z]```%P```!;U```4````+O4```D```!#]0``#@```$WU```-````7/4`
M`!(```!J]0``!````'WU```X````@O4``"````"[]0``"````-SU```&````
MY?4```@```#L]0``"````/7U```.````_O4``'L````-]@``&````(GV```8
M````HO8``!$```"[]@``!P```,WV```%````U?8``!@```#;]@``'@```/3V
M```;````$_<``!D````O]P``,0```$GW```;````>_<``!D```"7]P``$P``
M`+'W```'````Q?<```@```#-]P``!@```-;W```&````W?<```P```#D]P``
M#@```/'W```-`````/@``!,````.^```#P```"+X```>````,O@``!D```!1
M^```$````&OX```/````?/@``!````",^```#P```)WX```+````K?@```\`
M``"Y^```#````,GX```/````UO@```<```#F^```!@```.[X```,````]?@`
M``X````"^0``#````!'Y```H````'OD```\```!'^0``"````%?Y```&````
M8/D```\```!G^0``"````'?Y```3````@/D``!X```"4^0``(0```+/Y```@
M````U?D``!D```#V^0``%P```!#Z```E````*/H``!<```!.^@``%@```&;Z
M```$````??H``!L```""^@``#0```)[Z```,````K/H```,```"Y^@``!0``
M`+WZ```(````P_H```H```#,^@``#````-?Z```+````Y/H``!````#P^@``
M#`````'[```.````#OL```L````=^P``!````"G[```$````+OL``!,````S
M^P``%````$?[```,````7/L```D```!I^P``#@```'/[```+````@OL``!L`
M``".^P``!P```*K[```$````LOL```<```"W^P``"@```+_[```-````ROL`
M``D```#8^P``!````.+[```%````Y_L```,```#M^P``&````/'[```*````
M"OP```0````5_```)@```!K\```.````0?P``'P```!0_```%0```,W\```%
M````X_P```<```#I_```#````/'\```(````_OP```H````'_0``!@```!+]
M```(````&?T```(````B_0``!@```"7]```&````+/T``!0````S_0``!```
M`$C]```5````3?T```T```!C_0``$````'']```;````@OT```8```">_0``
M!````*7]```)````JOT``!````"T_0``"0```,7]```)````S_T```8```#9
M_0``!0```.#]```:````YOT```@````!_@``!@````K^```$````$?X```<`
M```6_@``&0```![^```.````./X```<```!'_@``!P```$_^```%````5_X`
M``D```!=_@``"@```&?^```.````<OX```(```"!_@``!@```(3^```+````
MB_X```T```"7_@``!P```*7^```)````K?X```8```"W_@``$@```+[^```)
M````T?X```<```#;_@``%````./^```=````^/X``$(````6_P``)0```%G_
M```E````?_\```8```"E_P``"@```*S_```$````M_\```D```"\_P``"```
M`,;_```1````S_\```D```#A_P``!@```.O_```-````\O\```8```````$`
M!`````<``0`Y````#``!`#T```!&``$`.@```(0``0`>````OP`!``4```#>
M``$`#@```.0``0`$````\P`!``8```#X``$`!P```/\``0`A````!P$!``T`
M```I`0$`%0```#<!`0`&````30$!``0```!4`0$`$0```%D!`0`&````:P$!
M``H```!R`0$`(@```'T!`0`$````H`$!``<```"E`0$`!````*T!`0`%````
ML@$!`!T```"X`0$`!````-8!`0`,````VP$!``X```#H`0$`"@```/<!`0`(
M`````@(!``D````+`@$`!0```!4"`0`Z````&P(!`#````!6`@$`-0```(<"
M`0`I````O0(!`$<```#G`@$`.````"\#`0`I````:`,!`#\```"2`P$`+@``
M`-(#`0`M`````00!`!\````O!`$`#P```$\$`0`2````7P0!``L```!R!`$`
M!P```'X$`0`F````A@0!`#P```"M!`$`*0```.H$`0`Z````%`4!`"0```!/
M!0$`)@```'0%`0`(````FP4!``H```"D!0$`"0```*\%`0`'````N04!`"``
M``#!!0$`(````.(%`0`F`````P8!``H````J!@$`&0```#4&`0`I````3P8!
M`!8```!Y!@$`$@```)`&`0`'````HP8!``H```"K!@$`#````+8&`0`/````
MPP8!`!````#3!@$`0````.0&`0!P````)0<!`&8```"6!P$`T0```/T'`0`.
M````SP@!``D```#>"`$`"@```.@(`0`2````\P@!`!,````&"0$`#````!H)
M`0`&````)PD!`!@````N"0$`#P```$<)`0`6````5PD!`!(```!N"0$`$```
M`($)`0`1````D@D!`!P```"D"0$`(P```,$)`0!J````Y0D!``\```!0"@$`
M!0```&`*`0`0````9@H!``D```!W"@$`!````($*`0`+````A@H!`"````"2
M"@$`%````+,*`0`,````R`H!``P```#5"@$`#P```.(*`0`5````\@H!`"D`
M```("P$`*@```#(+`0`F````70L!`"<```"$"P$`*0```*P+`0`J````U@L!
M`!D````!#`$`0@```!L,`0`1````7@P!`!(```!P#`$`$P```(,,`0`4````
MEPP!``\```"L#`$`%@```+P,`0`7````TPP!`!````#K#`$`$0```/P,`0`T
M````#@T!`!,```!##0$`$@```%<-`0`U````:@T!`!0```"@#0$`!P```+4-
M`0`,````O0T!`"````#*#0$`$````.L-`0`4````_`T!`!$````1#@$`%P``
M`",.`0`<````.PX!`!,```!8#@$`%````&P.`0`:````@0X!`!$```"<#@$`
M&@```*X.`0`>````R0X!`!H```#H#@$`$P````,/`0`5````%P\!`!$````M
M#P$`%P```#\/`0`4````5P\!`!<```!L#P$`%0```(0/`0`)````F@\!`!``
M``"D#P$`&0```+4/`0`$````SP\!``<```#4#P$`"P```-P/`0`1````Z`\!
M``8```#Z#P$`!@````$0`0`&````"!`!``4````/$`$`!P```!40`0`'````
M'1`!``4````E$`$`%@```"L0`0`&````0A`!``8```!)$`$`!````%`0`0`$
M````51`!``<```!:$`$`#@```&(0`0`,````<1`!``P```!^$`$`#0```(L0
M`0`*````F1`!``X```"D$`$`!0```+,0`0`H````N1`!``X```#B$`$`#```
M`/$0`0`/````_A`!``H````.$0$`"````!D1`0`)````(A$!`"L````L$0$`
M"````%@1`0`$````81$!``@```!F$0$`)@```&\1`0`2````EA$!``\```"I
M$0$`!@```+D1`0`*````P!$!``<```#+$0$`"````-,1`0`@````W!$!``T`
M``#]$0$`"0````L2`0`-````%1(!``H````C$@$`%````"X2`0`,````0Q(!
M``T```!0$@$`"0```%X2`0`.````:!(!`!8```!W$@$`$0```(X2`0`)````
MH!(!``8```"J$@$``P```+$2`0`&````M1(!`!D```"\$@$`!P```-82`0`$
M````WA(!``L```#C$@$`"P```.\2`0`'````^Q(!``4````#$P$`!P````D3
M`0`6````$1,!``T````H$P$`#0```#83`0`*````1!,!`!````!/$P$`#P``
M`&`3`0`1````<!,!`!<```""$P$`"@```)H3`0`1````I1,!``@```"W$P$`
M'@```,`3`0`$````WQ,!``\```#D$P$`.@```/03`0`%````+Q0!``P````U
M%`$`'@```$(4`0`.````810!`!````!P%`$`"P```($4`0`,````C10!``D`
M``":%`$`!P```*04`0`*````K!0!``D```"W%`$`#@```,$4`0`0````T!0!
M`!L```#A%`$`&````/T4`0`:````%A4!``H````Q%0$`"0```#P5`0`)````
M1A4!``H```!0%0$`#````%L5`0`/````:!4!``@```!X%0$`!@```($5`0`<
M````B!4!``<```"E%0$`!0```*T5`0`+````LQ4!`$<```"_%0$`#0````<6
M`0`)````%18!``0````?%@$``P```"06`0`3````*!8!`!,````\%@$`$P``
M`%`6`0`*````9!8!``(```!O%@$`!````'(6`0`E````=Q8!``,```"=%@$`
M!0```*$6`0`J````IQ8!``H```#2%@$`!0```-T6`0`$````XQ8!``H```#H
M%@$`#0```/,6`0`&`````1<!``@````(%P$`"````!$7`0`$````&A<!``4`
M```?%P$`&````"47`0!H````/A<!``D```"G%P$`#````+$7`0`0````OA<!
M``4```#/%P$`!@```-47`0`;````W!<!`"\```#X%P$`$````"@8`0`*````
M.1@!``\```!$&`$`"@```%08`0`)````7Q@!`!,```!I&`$`&P```'T8`0`8
M````F1@!`!<```"R&`$`&````,H8`0`?````XQ@!``X````#&0$``P```!(9
M`0`'````%AD!``(````>&0$`"````"$9`0`'````*AD!``<````R&0$`"P``
M`#H9`0`)````1AD!``H```!0&0$`"P```%L9`0`'````9QD!`%$```!O&0$`
M$````,$9`0`,````TAD!``T```#?&0$`&@```.T9`0!*````"!H!`!D```!3
M&@$`!@```&T:`0`:````=!H!`"4```"/&@$`!@```+4:`0`&````O!H!`!\`
M``##&@$`!@```.,:`0`)````ZAH!`!@```#T&@$`%P````T;`0`H````)1L!
M``D```!.&P$`!@```%@;`0`-````7QL!`"(```!M&P$`5P```)`;`0`3````
MZ!L!`",```#\&P$`$P```"`<`0`"````-!P!``L````W'`$`"````$,<`0`-
M````3!P!``H```!:'`$`!P```&4<`0`4````;1P!``8```""'`$`!@```(D<
M`0`(````D!P!``4```"9'`$`"@```)\<`0`.````JAP!``<```"Y'`$`$P``
M`,$<`0`5````U1P!``P```#K'`$`#0```/@<`0`*````!AT!``L````1'0$`
M,@```!T=`0`'````4!T!``P```!8'0$`#0```&4=`0`,````<QT!``D```"`
M'0$`"0```(H=`0`*````E!T!``<```"?'0$`"0```*<=`0`'````L1T!``H`
M``"Y'0$`&P```,0=`0`/````X!T!`$(```#P'0$`$@```#,>`0`*````1AX!
M`!8```!1'@$`#````&@>`0`-````=1X!`!````"#'@$`"0```)0>`0`0````
MGAX!``<```"O'@$`$@```+<>`0`$````RAX!``<```#/'@$`!0```-<>`0`%
M````W1X!``L```#C'@$`%````.\>`0`1````!!\!`!H````6'P$`%@```#$?
M`0`4````2!\!`!<```!='P$`&````'4?`0`<````CA\!`!D```"K'P$`!P``
M`,4?`0`%````S1\!``T```#3'P$`#````.$?`0`)````[A\!`!$```#X'P$`
M"`````H@`0`7````$R`!``L````K(`$`2@```#<@`0`,````@B`!`!\```"/
M(`$`&@```*\@`0`3````RB`!``0```#>(`$`"@```.,@`0`$````[B`!``T`
M``#S(`$`#0````$A`0`(````#R$!``H````8(0$`"0```",A`0`)````+2$!
M``@````W(0$`#````$`A`0`)````32$!``4```!7(0$`"0```%TA`0`%````
M9R$!``<```!M(0$`!0```'4A`0`$````>R$!``(```"`(0$`"````(,A`0`,
M````C"$!`#@```"9(0$`+````-(A`0`2````_R$!`"D````2(@$`,@```#PB
M`0`E````;R(!``H```"5(@$`+````*`B`0`N````S2(!`#,```#\(@$`,P``
M`#`C`0`X````9",!``\```"=(P$`&````*TC`0`+````QB,!`!0```#2(P$`
M$````.<C`0`L````^",!`!P````E)`$`#P```$(D`0`3````4B0!`!4```!F
M)`$`%````'PD`0`2````D20!`!0```"D)`$`%0```+DD`0`M````SR0!`"T`
M``#])`$`,0```"LE`0`N````724!`"\```",)0$`+````+PE`0!B````Z24!
M`!,```!,)@$`#0```&`F`0`-````;B8!``@```!\)@$`%P```(4F`0`(````
MG28!``P```"F)@$`*P```+,F`0`A````WR8!`!H````!)P$`'````!PG`0`)
M````.2<!`$4```!#)P$`00```(DG`0`$````RR<!`!,```#0)P$`%````.0G
M`0`.````^2<!`!,````(*`$`&````!PH`0`&````-2@!``D````\*`$`"@``
M`$8H`0`/````42@!``D```!A*`$`$````&LH`0`'````?"@!``X```"$*`$`
M!0```),H`0`;````F2@!``T```"U*`$`"````,,H`0`#````S"@!``8```#0
M*`$`%````-<H`0`1````["@!``X```#^*`$`.`````TI`0`"````1BD!``8`
M``!)*0$`#@```%`I`0`%````7RD!``<```!E*0$`#@```&TI`0`&````?"D!
M`"@```"#*0$`#````*PI`0`<````N2D!``0```#6*0$``@```-LI`0`F````
MWBD!`!8````%*@$`%````!PJ`0`I````,2H!`!<```!;*@$`'P```',J`0!<
M````DRH!`!0```#P*@$`/@````4K`0`?````1"L!`!````!D*P$`"````'4K
M`0`2````?BL!``<```"1*P$`#@```)DK`0`,````J"L!``P```"U*P$`$P``
M`,(K`0`*````UBL!`!T```#A*P$`&0```/\K`0`%````&2P!`!$````?+`$`
M"````#$L`0`%````.BP!`!$```!`+`$`"0```%(L`0`D````7"P!`!(```"!
M+`$`%0```)0L`0`2````JBP!``X```"]+`$`&0```,PL`0`(````YBP!``D`
M``#O+`$``@```/DL`0`-````_"P!``<````*+0$`"@```!(M`0`'````'2T!
M``\````E+0$`!@```#4M`0`+````/"T!`!H```!(+0$`"@```&,M`0`'````
M;BT!``@```!V+0$`!0```'\M`0`?````A2T!``8```"E+0$`$````*PM`0`(
M````O2T!``T```#&+0$`"````-0M`0`>````W2T!`!(```#\+0$`+`````\N
M`0`:````/"X!``D```!7+@$`"@```&$N`0`5````;"X!`!````""+@$`!0``
M`),N`0`4````F2X!``0```"N+@$`!P```+,N`0`0````NRX!``8```#,+@$`
M!P```-,N`0`>````VRX!`"@```#Z+@$`'@```",O`0`*````0B\!`!P```!-
M+P$`$0```&HO`0`+````?"\!`!H```"(+P$`%````*,O`0`$````N"\!``0`
M``"]+P$`"P```,(O`0`%````SB\!``8```#4+P$`"````-LO`0`&````Y"\!
M``H```#K+P$`&P```/8O`0`T````$C`!`#0```!',`$`(````'PP`0`I````
MG3`!`"````#',`$`00```.@P`0`:````*C$!`"@```!%,0$`*0```&XQ`0!0
M````F#$!`"(```#I,0$`!@````PR`0`(````$S(!``4````<,@$`#@```"(R
M`0`(````,3(!`!D````Z,@$`&0```%0R`0`J````;C(!`",```"9,@$`&0``
M`+TR`0`N````US(!`#0````&,P$`"````#LS`0`7````1#,!``H```!<,P$`
M!P```&<S`0`A````;S,!``P```"1,P$`#0```)XS`0`,````K#,!`!````"Y
M,P$`#@```,HS`0`+````V3,!``<```#E,P$`$P```.TS`0`(`````30!``L`
M```*-`$`"@```!8T`0`4````(30!``\````V-`$`,@```$8T`0`+````>30!
M``X```"%-`$`!0```)0T`0`%````FC0!``4```"@-`$`%P```*8T`0`/````
MOC0!``0```#.-`$`"@```-,T`0`)````WC0!``L```#H-`$`#0```/0T`0`,
M`````C4!``X````/-0$`!0```!XU`0`$````)#4!``T````I-0$`,@```#<U
M`0!%````:C4!``L```"P-0$`"@```+PU`0`/````QS4!`!,```#7-0$`$P``
M`.LU`0`/````_S4!``P````/-@$`#@```!PV`0`-````*S8!``T````Y-@$`
M%P```$<V`0`'````7S8!`!X```!G-@$`%````(8V`0`%````FS8!`!0```"A
M-@$`!@```+8V`0`'````O38!``P```#%-@$`$````-(V`0`1````XS8!``X`
M``#U-@$`%P````0W`0`J````'#<!``8```!'-P$`"0```$XW`0`/````6#<!
M``P```!H-P$`#0```'4W`0`1````@S<!``L```"5-P$`-@```*$W`0`*````
MV#<!`"(```#C-P$`"P````8X`0`/````$C@!`'T````B.`$`,@```*`X`0`E
M````TS@!``@```#Y.`$`,`````(Y`0`Q````,SD!`"T```!E.0$`$@```),Y
M`0`.````ICD!``4```"U.0$`#@```+LY`0`3````RCD!`!$```#>.0$`"```
M`/`Y`0`2````^3D!``<````,.@$`$0```!0Z`0`3````)CH!``<````Z.@$`
M%````$(Z`0`8````5SH!``<```!P.@$`!0```'@Z`0`,````?CH!``P```"+
M.@$`$@```)@Z`0`$````JSH!``<```"P.@$`"@```+@Z`0`+````PSH!``P`
M``#/.@$`#@```-PZ`0`.````ZSH!``4```#Z.@$`!0`````[`0`N````!CL!
M`"8````U.P$`(P```%P[`0`#````@#L!`!(```"$.P$`!@```)<[`0`>````
MGCL!`!@```"].P$`)0```-8[`0`-````_#L!``D````*/`$`'P```!0\`0`#
M````-#P!``<````X/`$`"@```$`\`0`"````2SP!``P```!./`$`%0```%L\
M`0`+````<3P!`!D```!]/`$`(````)<\`0`2````N#P!``4```#+/`$`"@``
M`-$\`0`5````W#P!`!(```#R/`$`"`````4]`0`,````#CT!``0````;/0$`
M"0```"`]`0`'````*CT!``L````R/0$`#@```#X]`0`*````33T!``P```!8
M/0$`4@```&4]`0`7````N#T!`"0```#0/0$`$@```/4]`0`'````"#X!``8`
M```0/@$`$````!<^`0`.````*#X!``X````W/@$`(````$8^`0`,````9SX!
M`!D```!T/@$`#0```(X^`0`5````G#X!`!(```"R/@$`#P```,4^`0`4````
MU3X!``H```#J/@$`&P```/4^`0`0````$3\!`!P````B/P$`6````#\_`0`+
M````F#\!`"$```"D/P$`)0```,8_`0!I````[#\!`!H```!60`$`%P```'%`
M`0`9````B4`!`!H```"C0`$`&0```+Y``0`E````V$`!`"<```#^0`$`&@``
M`"9!`0`7````04$!`!T```!900$`)@```'=!`0`;````GD$!`"H```"Z00$`
M&0```.5!`0`?````_T$!`!,````?0@$`"````#-"`0!$````/$(!`!,```"!
M0@$`0````)5"`0`'````UD(!``@```#>0@$`"0```.="`0`5````\4(!``T`
M```'0P$`(P```!5#`0`-````.4,!`!,```!'0P$`"````%M#`0`#````9$,!
M``P```!H0P$`1@```'5#`0`7````O$,!``X```#40P$`/P```.-#`0!-````
M(T0!`#<```!Q1`$`5P```*E$`0`%`````44!`!\````'10$`+P```"=%`0`*
M````5T4!`!,```!B10$`$````'9%`0`1````AT4!``@```"910$`#0```*)%
M`0`M````L$4!``0```#>10$`#0```.-%`0`5````\44!`#L````'1@$`3P``
M`$-&`0`?````DT8!`!8```"S1@$`)0```,I&`0`H````\$8!`!P````91P$`
M"P```#9'`0`C````0D<!`!\```!F1P$`(0```(9'`0`=````J$<!`"4```#&
M1P$`(````.Q'`0`D````#4@!`"`````R2`$`,````%-(`0`+````A$@!``<`
M``"02`$`#0```)A(`0`,````ID@!`!<```"S2`$`!@```,M(`0`Y````TD@!
M``P````,20$`!P```!E)`0`)````(4D!`!,````K20$`"0```#])`0`$````
M24D!`!````!.20$`"````%])`0`(````:$D!``0```!Q20$`"P```'9)`0`,
M````@DD!`!(```"/20$`$0```*))`0`,````M$D!`!H```#!20$`#P```-Q)
M`0`'````[$D!``T```#T20$`%`````)*`0`.````%TH!``P````F2@$`&P``
M`#-*`0`L````3TH!`!,```!\2@$`'````)!*`0`H````K4H!``8```#62@$`
M!P```-U*`0`3````Y4H!``4```#Y2@$`!````/]*`0`7````!$L!``H````<
M2P$`#````"=+`0`)````-$L!``8````^2P$`"0```$5+`0`&````3TL!``@`
M``!62P$`"0```%]+`0`*````:4L!``@```!T2P$`"@```'U+`0`*````B$L!
M``<```"32P$`$0```)M+`0`&````K4L!``X```"T2P$`#@```,-+`0`-````
MTDL!``L```#@2P$`'0```.Q+`0`+````"DP!``(````63`$`'````!E,`0`'
M````-DP!``8````^3`$`9````$5,`0`)````JDP!``<```"T3`$`)@```+Q,
M`0`X````XTP!`!H````<30$`*@```#=-`0`[````8DT!`"@```">30$`-```
M`,=-`0`9````_$T!`!4````63@$`!0```"Q.`0`'````,DX!``@````Z3@$`
M!P```$-.`0`&````2TX!``4```!23@$`!P```%A.`0`.````8$X!``D```!O
M3@$`!@```'E.`0`(````@$X!``L```")3@$`!P```)5.`0`(````G4X!``<`
M``"F3@$`%@```*Y.`0`)````Q4X!``8```#/3@$`"P```-9.`0`0````XDX!
M``8```#S3@$`'````/I.`0`4````%T\!``<````L3P$`$0```#1/`0`(````
M1D\!``X```!/3P$`"````%Y/`0`%````9T\!`!````!M3P$`"0```'Y/`0`0
M````B$\!``8```"93P$`&0```*!/`0`*````ND\!`!P```#%3P$`!P```.)/
M`0`%````ZD\!`!````#P3P$`%`````%0`0`+````%E`!``T````B4`$`*```
M`#!0`0`8````65`!`!<```!R4`$`"0```(I0`0`$````E%`!``D```"94`$`
M"@```*-0`0`'````KE`!``(```"V4`$`#@```+E0`0`(````R%`!`#@```#1
M4`$`(P````I1`0`?````+E$!`#@```!.40$`)@```(=1`0`Q````KE$!`"<`
M``#@40$`9`````A2`0`4````;5(!`"0```""4@$`(P```*=2`0`C````RU(!
M`"L```#O4@$`(0```!M3`0`D````/5,!`%4```!B4P$`.````+A3`0!*````
M\5,!`%L````\5`$`*````)A4`0`X````P50!`"\```#Z5`$`10```"I5`0!*
M````<%4!`$8```"[50$`,P````)6`0`H````-E8!`"P```!?5@$`)@```(Q6
M`0`;````LU8!`#X```#/5@$`.@````Y7`0"I`0``25<!`",```#S6`$`%P``
M`!=9`0!(````+UD!`(4```!X60$`,````/Y9`0`E````+UH!`$$```!56@$`
M6P```)=:`0!)````\UH!`#$````]6P$`:0```&];`0`=````V5L!`!@```#W
M6P$`*P```!!<`0`A````/%P!`!\```!>7`$`*P```'Y<`0`F````JEP!`"<`
M``#17`$`.@```/E<`0`=````-%T!`!$```!270$`,P```&1=`0`E````F%T!
M`"<```"^70$`(````.9=`0`R````!UX!`!\````Z7@$`,````%I>`0!I````
MBUX!`#$```#U7@$`00```"=?`0`S````:5\!`"4```"=7P$`/0```,-?`0!E
M`````6`!`$T```!G8`$`+0```+5@`0`G````XV`!`"\````+80$`*````#MA
M`0`N````9&$!`#````"380$`5````,1A`0`G````&6(!`%H```!!8@$`.@``
M`)QB`0!(````UV(!`$H````@8P$`'P```&MC`0`R````BV,!`"\```"^8P$`
M+````.YC`0`M````&V0!`'$```!)9`$`9@```+MD`0!O````(F4!`+,```"2
M90$`%P```$9F`0`E````7F8!`#(```"$9@$`*0```+=F`0`^````X68!`"(`
M```@9P$`4@```$-G`0`B````EF<!`"4```"Y9P$`"P```-]G`0"Q````ZV<!
M`"````"=:`$`10```+YH`0`A````!&D!`#`````F:0$`)0```%=I`0`<````
M?6D!`#$```"::0$`!P```,QI`0`(````U&D!``<```#=:0$`!````.5I`0`*
M````ZFD!``T```#U:0$`"P````-J`0`.````#VH!``D````>:@$`"P```"AJ
M`0`&````-&H!``4````[:@$`$````$%J`0`"````4FH!`%D```!5:@$`!0``
M`*]J`0`2````M6H!``0```#(:@$`!P```,UJ`0`(````U6H!``4```#>:@$`
M`P```.1J`0`0````Z&H!``P```#Y:@$`$P````9K`0`-````&FL!``(````H
M:P$`!P```"MK`0`'````,VL!``8````[:P$`%````$)K`0`,````5VL!`!@`
M``!D:P$`!@```'UK`0`$````A&L!`!(```"):P$`#````)QK`0`#````J6L!
M`"H```"M:P$`!````-AK`0`&````W6L!``<```#D:P$`'P```.QK`0`U````
M#&P!`"X```!";`$`+P```'%L`0`7````H6P!`"(```"Y;`$`)0```-QL`0`@
M`````FT!`!L````C;0$`&````#]M`0`D````6&T!`!\```!];0$`&@```)UM
M`0`A````N&T!`"````#:;0$`&@```/MM`0`R````%FX!`!D```!);@$`&@``
M`&-N`0`O````?FX!`"L```"N;@$`'P```-IN`0`C````^FX!`!\````>;P$`
M&@```#YO`0`A````66\!`"4```![;P$`)@```*%O`0`E````R&\!`"0```#N
M;P$`&````!-P`0`=````+'`!`"0```!*<`$`&````&]P`0`B````B'`!`"P`
M``"K<`$`+P```-AP`0`5````"'$!`"4````><0$`&0```$1Q`0`\````7G$!
M`!\```";<0$`(P```+MQ`0`?````WW$!`"````#_<0$`&@```"!R`0`O````
M.W(!`!@```!K<@$`)@```(1R`0`>````JW(!`"D```#*<@$`'@```/1R`0`Q
M````$W,!``D```!%<P$`#````$]S`0`7````7',!`"\```!T<P$`)````*1S
M`0`'````R7,!``\```#1<P$`%````.%S`0`.````]G,!``T````%=`$`)```
M`!-T`0`%````.'0!``<````^=`$`(@```$9T`0`E````:70!`!H```"/=`$`
M'0```*IT`0`:````R'0!``<```#C=`$`QP```.MT`0`+````LW4!`!P```"_
M=0$`%0```-QU`0`&````\G4!``D```#Y=0$`"P````-V`0`-````#W8!``P`
M```==@$`%P```"IV`0`&````0G8!`#,```!)=@$`$P```'UV`0`3````D78!
M``<```"E=@$`#P```*UV`0`'````O78!`#(```#%=@$`!````/AV`0`A````
M_78!`!,````?=P$`#@```#-W`0`,````0G<!`!$```!/=P$`,@```&%W`0`6
M````E'<!``@```"K=P$`'0```+1W`0`)````TG<!``H```#<=P$`%````.=W
M`0`*````_'<!`!T````'>`$`"````"5X`0`?````+G@!``@```!.>`$`&@``
M`%=X`0`G````<G@!``8```":>`$`%0```*%X`0`'````MW@!``@```"_>`$`
M"0```,AX`0`_````TG@!``<````2>0$`#P```!IY`0`.````*GD!`!`````Y
M>0$`"0```$IY`0`)````5'D!``@```!>>0$`$P```&=Y`0`'````>WD!``@`
M``"#>0$`&0```(QY`0`*````IGD!`!<```"Q>0$`%````,EY`0`*````WGD!
M``P```#I>0$`%P```/9Y`0`$````#GH!`"H````3>@$`#````#YZ`0`1````
M2WH!``<```!=>@$``@```&5Z`0`0````:'H!`!@```!Y>@$`"P```))Z`0`#
M````GGH!``@```"B>@$`"0```*MZ`0`$````M7H!``<```"Z>@$`!P```,)Z
M`0`&````RGH!`!0```#1>@$`!P```.9Z`0`-````[GH!``L```#\>@$`%```
M``A[`0`5````'7L!``X````S>P$`+P```$)[`0`@````<GL!`!P```"3>P$`
M2````+![`0!,````^7L!`!4```!&?`$`#````%Q\`0`Q````:7P!``4```";
M?`$`$@```*%\`0`_````M'P!`!(```#T?`$`"@````=]`0`&````$GT!``0`
M```9?0$`!````!Y]`0`*````(WT!`!,````N?0$`!0```$)]`0`&````2'T!
M``8```!/?0$`"````%9]`0`$````7WT!``P```!D?0$`"@```'%]`0`)````
M?'T!`#D```"&?0$`+@```,!]`0`I````[WT!``4````9?@$`&````!]^`0`9
M````.'X!`!\```!2?@$`'0```')^`0`1````D'X!``(```"B?@$`!````*5^
M`0`*````JGX!``0```"U?@$`!@```+I^`0`4````P7X!``4```#6?@$``P``
M`-Q^`0`,````X'X!`$4```#M?@$`,@```#-_`0`R````9G\!`"\```"9?P$`
M&@```,E_`0`Z````Y'\!`#0````?@`$`*````%2``0!3````?8`!`),```#1
M@`$`+P```&6!`0!"````E8$!`#````#8@0$`+@````F"`0`9````.((!`"<`
M``!2@@$`.````'J"`0`X````LX(!`#<```#L@@$`<@```"2#`0`@````EX,!
M`#4```"X@P$`(0```.Z#`0!%````$(0!`#````!6A`$`*0```(>$`0`A````
ML80!`"@```#3A`$`*0```/R$`0`F````)H4!`"4```!-A0$`*````'.%`0`H
M````G(4!`"(```#%A0$`*P```.B%`0!%````%(8!`$D```!:A@$`1@```*2&
M`0`\````ZX8!`#`````HAP$`$@```%F'`0`3````;(<!`!````"`AP$`>0``
M`)&'`0`)````"X@!`*$````5B`$`<P```+>(`0!\````*XD!`"L```"HB0$`
M5````-2)`0`7````*8H!`!4```!!B@$`)P```%>*`0`6````?XH!``\```"6
MB@$`%P```*:*`0`?````OHH!`$````#>B@$`'P```!^+`0`<````/XL!`%$`
M``!<BP$`&@```*Z+`0`4````R8L!``H```#>BP$`!0```.F+`0`&````[XL!
M``@```#VBP$`!0```/^+`0`2````!8P!`!`````8C`$`$P```"F,`0`=````
M/8P!``\```!;C`$`#P```&N,`0`/````>XP!``8```"+C`$`#0```)*,`0`$
M````H(P!``D```"EC`$`"P```*^,`0`%````NXP!``4```#!C`$`!P```,>,
M`0`%````SXP!`!0```#5C`$`#@```.J,`0`'````^8P!``@````!C0$`#P``
M``J-`0`-````&HT!``H````HC0$`"````#.-`0`,````/(T!``8```!)C0$`
M#P```%"-`0`'````8(T!``8```!HC0$`%````&^-`0`&````A(T!``8```"+
MC0$`#````)*-`0`1````GXT!`!<```"QC0$`"````,F-`0`$````THT!`!D`
M``#7C0$`$0```/&-`0`*`````XX!`!@````.C@$`$P```">.`0`<````.XX!
M`!$```!8C@$``P```&J.`0`&````;HX!``0```!UC@$`!````'J.`0`/````
M?XX!``H```"/C@$`"@```)J.`0`'````I8X!``0```"MC@$`&0```+*.`0`'
M````S(X!``(```#4C@$``@```->.`0`1````VHX!``D```#LC@$``@```/:.
M`0`&````^8X!`!(`````CP$`%P```!./`0`&````*X\!`"<````RCP$``@``
M`%J/`0`(````78\!``0```!FCP$`#P```&N/`0`3````>X\!``<```"/CP$`
M"P```)>/`0`0````HX\!`!,```"TCP$`!P```,B/`0`1````T(\!``8```#B
MCP$`&````.F/`0`&`````I`!`!,````)D`$`$````!V0`0`2````+I`!``(`
M``!!D`$`!@```$20`0`,````2Y`!``D```!8D`$`$0```&*0`0`B````=)`!
M``<```"7D`$`!P```)^0`0`+````IY`!`!,```"SD`$`!0```,>0`0`1````
MS9`!``(```#?D`$`"P```.*0`0`$````[I`!``L```#SD`$`!0```/^0`0`'
M````!9$!`($!```-D0$`#P```(^2`0`2````GY(!``T```"RD@$`!@```,"2
M`0`)````QY(!``<```#1D@$``P```-F2`0`9````W9(!`!\```#WD@$`,@``
M`!>3`0`O````2I,!`"@```!ZDP$`+0```*.3`0`9````T9,!`"L```#KDP$`
M"@```!>4`0`6````(I0!`"X````YE`$`$@```&B4`0`6````>Y0!``H```"2
ME`$`'P```)V4`0`4````O90!``4```#2E`$`+@```-B4`0`3````!Y4!``L`
M```;E0$`&@```">5`0`-````0I4!``X```!0E0$`#0```%^5`0`P````;94!
M`)D```">E0$`#0```#B6`0`*````1I8!`!<```!1E@$`#@```&F6`0`1````
M>)8!``P```"*E@$`%@```)>6`0`,````KI8!``8```"[E@$`G0```,*6`0!4
M````8)<!`"D```"UEP$`+0```-^7`0`*````#9@!``\````8F`$`%0```"B8
M`0`1````/I@!``L```!0F`$`$````%R8`0`&````;9@!`!,```!TF`$`"@``
M`(B8`0`*````DY@!`!,```">F`$`"````+*8`0`*````NY@!``D```#&F`$`
M)@```-"8`0`H````]Y@!`"H````@F0$`)@```$N9`0`V````<ID!`"0```"I
MF0$`.````,Z9`0!#````!YH!`&4```!+F@$`8@```+&:`0!K````%)L!`&@`
M``"`FP$`.@```.F;`0`"````))P!``\````GG`$`%0```#><`0`.````39P!
M`!,```!<G`$`&0```'"<`0`%````BIP!``D```"0G`$`$0```)J<`0`,````
MK)P!``T```"YG`$`#0```,><`0`(````U9P!`#0```#>G`$`,0```!.=`0`)
M````19T!`!0```!/G0$`%````&2=`0`,````>9T!`!(```"&G0$`!@```)F=
M`0`9````H)T!`!X```"ZG0$`%0```-F=`0`,````[YT!``P```#\G0$`$0``
M``F>`0`C````&YX!`"@````_G@$`&````&B>`0`8````@9X!`!(```":G@$`
M$0```*V>`0`.````OYX!``\```#.G@$`"@```-Z>`0`O````Z9X!`!D````9
MGP$`$P```#.?`0`9````1Y\!``X```!AGP$`7````'"?`0`Z````S9\!`"H`
M```(H`$`"0```#.@`0`6````/:`!`#0```!4H`$`#@```(F@`0`(````F*`!
M`!$```"AH`$`"@```+.@`0`&````OJ`!`!0```#%H`$`%0```-J@`0`7````
M\*`!`!<````(H0$`$@```""A`0`3````,Z$!`!8```!'H0$`%0```%ZA`0`/
M````=*$!`"````"$H0$`$0```*6A`0`'````MZ$!``<```"_H0$`!0```,>A
M`0`'````S:$!``L```#5H0$`!0```.&A`0`4````YZ$!`"$```#\H0$`%P``
M`!ZB`0`0````-J(!`!<```!'H@$`%0```%^B`0`2````=:(!``L```"(H@$`
M'@```)2B`0`9````LZ(!``\```#-H@$`&P```-VB`0`T````^:(!``D````N
MHP$`%P```#BC`0`6````4*,!`!@```!GHP$`(0```("C`0`7````HJ,!`!$`
M``"ZHP$`#P```,RC`0`?````W*,!`"4```#\HP$`!P```"*D`0`&````*J0!
M``<````QI`$`#0```#FD`0`)````1Z0!``D```!1I`$`$@```%ND`0`*````
M;J0!``H```!YI`$`%0```(2D`0`9````FJ0!`"P```"TI`$`!P```.&D`0`1
M````Z:0!``4```#[I`$`%@````&E`0`2````&*4!`!(````KI0$`/@```#ZE
M`0`^````?:4!``D```"\I0$`!P```,:E`0`3````SJ4!``0```#BI0$`!0``
M`.>E`0`.````[:4!``X```#\I0$`%P````NF`0!'````(Z8!`!8```!KI@$`
M!0```(*F`0#6````B*8!`"8```!?IP$`*P```(:G`0`L````LJ<!`#0```#?
MIP$`"@```!2H`0`*````'Z@!``D````JJ`$`!@```#2H`0`)````.Z@!``<`
M``!%J`$`.````$VH`0`Z````AJ@!`#<```#!J`$`7````/FH`0`V````5JD!
M`#8```"-J0$`1P```,2I`0!+````#*H!`#8```!8J@$`3@```(^J`0`L````
MWJH!`"X````+JP$`30```#JK`0`V````B*L!`#P```"_JP$`+@```/RK`0`8
M````*ZP!`!P```!$K`$`,P```&&L`0`M````E:P!`"T```##K`$`$P```/&L
M`0`*````!:T!``P````0K0$`!0```!VM`0`.````(ZT!`!\````RK0$`)@``
M`%*M`0`'````>:T!``<```"!K0$`%0```(FM`0`*````GZT!``@```"JK0$`
M,P```+.M`0`*````YZT!``\```#RK0$`!P````*N`0`'````"JX!``8````2
MK@$`!0```!FN`0`(````'ZX!``8````HK@$`"@```"^N`0`T````.JX!`!(`
M``!OK@$`#@```(*N`0`'````D:X!``<```"9K@$`"@```*&N`0`%````K*X!
M`!$```"RK@$`!@```,2N`0`2````RZX!``4```#>K@$`"````.2N`0`(````
M[:X!``X```#VK@$`!@````6O`0`I````#*\!`!$````VKP$`"````$BO`0`1
M````4:\!``P```!CKP$`!P```'"O`0`'````>*\!``,```"`KP$``P```(2O
M`0`:````B*\!``<```"CKP$`&````*NO`0`J````Q*\!``<```#OKP$`!@``
M`/>O`0`4````_J\!`"T````3L`$`!P```$&P`0`G````2;`!``4```!QL`$`
M!P```'>P`0`'````?[`!`&4```"'L`$`)P```.VP`0`X````%;$!`"D```!.
ML0$`(P```'BQ`0`B````G+$!``8```"_L0$`"````,:Q`0`=````S[$!``D`
M``#ML0$`#0```/>Q`0`E````!;(!`"<````KL@$`-````%.R`0`H````B+(!
M`"T```"QL@$`8@```-^R`0`V````0K,!``H```!YLP$`"0```(2S`0`)````
MCK,!``H```"8LP$`%@```*.S`0`)````NK,!``P```#$LP$`#@```-&S`0`4
M````X+,!`!````#ULP$`%`````:T`0`3````&[0!``X````OM`$`%0```#ZT
M`0`'````5+0!`!@```!<M`$`&P```'6T`0`8````D;0!`!L```"JM`$`&0``
M`,:T`0`$````X+0!``<```#EM`$`%````.VT`0!8`````K4!`'(```!;M0$`
M!P```,ZU`0`5````UK4!``4```#LM0$`!0```/*U`0`;````^+4!`!@````4
MM@$`"P```"VV`0`4````.;8!`!H```!.M@$`'@```&FV`0!P````B+8!`%D`
M``#YM@$`5````%.W`0`[````J+<!`%T```#DMP$`5````$*X`0!0````E[@!
M`!P```#HN`$`#@````6Y`0`L````%+D!``<```!!N0$`&P```$FY`0`/````
M9;D!`!L```!UN0$`$@```)&Y`0`.````I+D!`!@```"SN0$`$````,RY`0`6
M````W;D!`!,```#TN0$`#@````BZ`0`.````%[H!``4````FN@$`#P```"RZ
M`0`&````/+H!`!@```!#N@$`%0```%RZ`0`/````<KH!``@```""N@$`!0``
M`(NZ`0`1````D;H!`!(```"CN@$`"0```+:Z`0`7````P+H!``8```#8N@$`
M&P```-^Z`0`'````^[H!`!$````#NP$`"@```!6[`0`,````(+L!``<````M
MNP$`"````#6[`0`+````/KL!``D```!*NP$`"P```%2[`0`?````8+L!`$D`
M``"`NP$`)0```,J[`0`-````\+L!`!0```#^NP$`*@```!.\`0`*````/KP!
M``4```!)O`$`(````$^\`0`2````<+P!`!,```"#O`$`.@```)>\`0!*````
MTKP!`"<````=O0$`"0```$6]`0`\````3[T!`"H```",O0$`$0```+>]`0`)
M````R;T!``H```#3O0$`!@```-Z]`0`&````Y;T!`!(```#LO0$`$````/^]
M`0!4````$+X!``L```!EO@$`"@```'&^`0`/````?+X!`"P```",O@$`+```
M`+F^`0`M````YKX!`"X````4OP$`(@```$._`0`E````9K\!`"(```",OP$`
M)@```*^_`0`V````UK\!`"X````-P`$`)@```#S``0`H````8\`!`"0```",
MP`$`,0```+'``0!%````X\`!`$`````IP0$`-0```&K!`0`T````H,$!`#X`
M``#5P0$`)@```!3"`0`E````.\(!`#P```!AP@$`)0```)["`0`5````Q,(!
M`#D```#:P@$`)0```!3#`0`G````.L,!`!0```!BPP$`R@```'?#`0`;````
M0L0!`#$```!>Q`$`,````)#$`0`S````P<0!`#$```#UQ`$`)P```"?%`0`H
M````3\4!`"L```!XQ0$`,@```*3%`0`U````U\4!`$L````-Q@$`-````%G&
M`0"D````CL8!`"<````SQP$`'0```%O'`0`F````><<!`#,```"@QP$`,0``
M`-3'`0!.````!L@!`%4```!5R`$`#0```*O(`0`$````N<@!``8```"^R`$`
M!0```,7(`0`,````R\@!``8```#8R`$`#P```-_(`0`%````[\@!`!$```#U
MR`$`!@````?)`0`6````#LD!`!P````ER0$`!P```$+)`0`$````2LD!``8`
M``!/R0$`$````%;)`0`1````9\D!``L```!YR0$`"@```(7)`0`1````D,D!
M``T```"BR0$`$@```+#)`0`-````P\D!`#H```#1R0$`!@````S*`0`0````
M$\H!``8````DR@$`$0```"O*`0`7````/<H!`!L```!5R@$`#P```''*`0`"
M````@<H!`$D```"$R@$`"P```,[*`0`;````VLH!``P```#VR@$`'`````/+
M`0`%````(,L!`!<````FRP$`$@```#[+`0`#````4<L!``8```!5RP$`"0``
M`%S+`0`1````9LL!``D```!XRP$`$0```(++`0`)````E,L!`!````">RP$`
M"P```*_+`0`2````N\L!`!$```#.RP$`%0```.#+`0`1````]LL!``P````(
MS`$`"````!7,`0`+````'LP!``X````JS`$`"````#G,`0`.````0LP!`!$`
M``!1S`$`$P```&/,`0`:````=\P!``X```"2S`$`$````*',`0`K````LLP!
M`!$```#>S`$`'````/#,`0!$````#<T!``T```!2S0$`'P```&#-`0`4````
M@,T!`!D```"5S0$`7P```*_-`0`6````#\X!`$,````FS@$`$````&K.`0`)
M````>\X!``P```"%S@$`%````)+.`0`+````I\X!`#8```"SS@$`-0```.K.
M`0`*````(,\!`!4````KSP$`*0```$'/`0`7````:\\!`!8```"#SP$`%@``
M`)K/`0`*````L<\!``<```"\SP$`(````,3/`0`/````Y<\!`!D```#USP$`
M'`````_0`0`8````+-`!`!D```!%T`$`&````%_0`0`(````>-`!``L```"!
MT`$`*0```(W0`0`X````M]`!``P```#PT`$`6````/W0`0`(````5M$!`!0`
M``!?T0$`(@```'31`0`)````E]$!``P```"AT0$`-@```*[1`0`1````Y=$!
M``8```#WT0$`#````/[1`0`(````"](!``8````4T@$`50```!O2`0`#````
M<=(!``<```!UT@$`"0```'W2`0`,````A](!`!0```"4T@$`$````*G2`0`1
M````NM(!``\```#,T@$`%````-S2`0`5````\=(!`!L````'TP$`&0```"/3
M`0`4````/=,!`!X```!2TP$`%@```''3`0`=````B-,!`!L```"FTP$`"0``
M`,+3`0`&````S-,!``L```#3TP$`"P```-_3`0`"````Z],!``8```#NTP$`
M$P```/73`0`O````"=0!`!<````YU`$`%0```%'4`0`*````9]0!`!$```!R
MU`$`%````(34`0`<````F=0!``8```"VU`$`.0```+W4`0`W````]]0!``L`
M```OU0$`"@```#O5`0`*````1M4!`!(```!1U0$`#P```&35`0"&````=-4!
M`",```#[U0$`(````!_6`0`1````0-8!``<```!2U@$`!0```%K6`0`<````
M8-8!`"T```!]U@$`,P```*O6`0`?````W]8!`$````#_U@$`)0```$#7`0`?
M````9M<!`!<```"&UP$`!P```)[7`0`'````IM<!``8```"NUP$`!@```+77
M`0`7````O-<!`!D```#4UP$`&@```.[7`0`<````"=@!`"`````FV`$`-P``
M`$?8`0`O````?]@!``\```"OV`$`#@```+_8`0`0````SM@!``X```#?V`$`
M%0```.[8`0`/````!-D!``L````4V0$`$P```"#9`0`(````--D!``@````]
MV0$`$````$;9`0`5````5]D!``\```!MV0$`10```'W9`0`4````P]D!``D`
M``#8V0$`"````.+9`0`/````Z]D!``X```#[V0$`'P````K:`0`@````*MH!
M`"<```!+V@$`)@```'/:`0`8````FMH!`!<```"SV@$`(````,O:`0`8````
M[-H!`!8````%VP$`"0```!S;`0`9````)ML!``L```!`VP$`%````$S;`0`#
M````8=L!``4```!EVP$`!P```&O;`0`.````<]L!`!````""VP$`#0```)/;
M`0`8````H=L!`!````"ZVP$`$0```,O;`0`/````W=L!``0```#MVP$`!P``
M`/+;`0`:````^ML!`!L````5W`$`"````#'<`0`1````.MP!`!0```!,W`$`
M#@```&'<`0`G````<-P!``<```"8W`$`"0```*#<`0`)````JMP!`!````"T
MW`$`$````,7<`0`*````UMP!``<```#AW`$`"P```.G<`0`&````]=P!`!@`
M``#\W`$`#@```!7=`0`&````)-T!`"@````KW0$`$````%3=`0";````9=T!
M`!L````!W@$`"P```!W>`0`'````*=X!``\````QW@$`"````$'>`0`*````
M2MX!``4```!5W@$`"````%O>`0`#````9-X!``8```!HW@$`!P```&_>`0`6
M````=]X!``4```".W@$`(````)3>`0`0````M=X!`!(```#&W@$`'0```-G>
M`0`'````]]X!``(```#_W@$`!`````+?`0`4````!]\!``H````<WP$`#P``
M`"??`0`&````-]\!``4````^WP$`(P```$3?`0`(````:-\!``8```!QWP$`
M!0```'C?`0`'````?M\!`!L```"&WP$`#P```*+?`0`'````LM\!``@```"Z
MWP$`!0```,/?`0`)````R=\!``\```#3WP$`$0```./?`0`"````]=\!``8`
M``#XWP$`#P```/_?`0`2````#^`!``<````BX`$`$````"K@`0`&````.^`!
M`!,```!"X`$`"P```%;@`0`'````8N`!`!@```!JX`$`,````(/@`0!-````
MM.`!`"L````"X0$`+0```"[A`0`&````7.$!``D```!CX0$`!````&WA`0`)
M````<N$!``D```!\X0$`%P```(;A`0`,````GN$!``8```"KX0$`#0```++A
M`0`'````P.$!``0```#(X0$`00```,WA`0!(````#^(!`$$```!8X@$`)P``
M`)KB`0`%````PN(!``T```#(X@$`!P```-;B`0`(````WN(!``D```#GX@$`
M&P```/'B`0`9````#>,!`!4````GXP$`!@```#WC`0`%````1.,!`!````!*
MXP$`"````%OC`0`*````9.,!`",```!OXP$`!P```)/C`0`*````F^,!``0`
M``"FXP$`!P```*OC`0`G````L^,!``8```#;XP$`"0```.+C`0`3````[.,!
M`!,`````Y`$`"````!3D`0`)````'>0!``4````GY`$`1P```"WD`0`T````
M=>0!`$$```"JY`$`,@```.SD`0!)````'^4!`#L```!IY0$`+````*7E`0`^
M````TN4!`"\````1Y@$`/0```$'F`0`Q````?^8!`!````"QY@$`$0```,+F
M`0`+````U.8!``<```#@Y@$`,@```.CF`0!!````&^<!`"$```!=YP$`00``
M`'_G`0`?````P><!`!X```#AYP$`!P````#H`0`)````".@!``H````2Z`$`
M!P```!WH`0`I````)>@!`"P```!/Z`$`/0```'SH`0`,````NN@!`",```#'
MZ`$`-@```.OH`0`6````(ND!`!4````YZ0$`"````$_I`0`+````6.D!``P`
M``!DZ0$`$````''I`0`7````@ND!`$4```":Z0$`?````.#I`0!G````7>H!
M`-8```#%Z@$`#0```)SK`0`0````JNL!`!$```"[ZP$`%````,WK`0`5````
MXNL!`!<```#XZP$`"````!#L`0`8````&>P!`!$````R[`$`&0```$3L`0`3
M````7NP!`!(```!R[`$`%0```(7L`0`N````F^P!`"T```#*[`$`EP```/CL
M`0`1````D.T!``4```"B[0$`%0```*CM`0`)````ONT!``L```#([0$`"P``
M`-3M`0`E````X.T!`!@````&[@$`#P```!_N`0`.````+^X!`!0````^[@$`
M&0```%/N`0`M````;>X!`"X```";[@$`*@```,KN`0`J````]>X!`"8````@
M[P$`*````$?O`0`>````<.\!`$$```"/[P$`%0```-'O`0`4````Y^\!`!<`
M``#\[P$`%@```!3P`0`1````*_`!`!<````]\`$`%@```%7P`0`4````;/`!
M`!0```"!\`$`.P```);P`0`9````TO`!`!H```#L\`$`.@````?Q`0`3````
M0O$!``8```!6\0$`$````%WQ`0`M````;O$!`!0```"<\0$`%0```+'Q`0`5
M````Q_$!`"````#=\0$`'@```/[Q`0`<````'?(!`!P````Z\@$`)P```%?R
M`0`3````?_(!`"````"3\@$`)@```+3R`0`@````V_(!`!D```#\\@$`'0``
M`!;S`0`4````-/,!`!P```!)\P$`'````&;S`0`A````@_,!`!D```"E\P$`
M"@```+_S`0`2````RO,!`!L```#=\P$`!````/GS`0`'````_O,!``L````&
M]`$`$@```!+T`0`&````)?0!``8````L]`$`!P```#/T`0`&````._0!``<`
M``!"]`$`!0```$KT`0`%````4/0!`!4```!6]`$`!@```&ST`0`&````<_0!
M``4```!Z]`$`!0```(#T`0`*````AO0!`!$```"1]`$`"@```*/T`0`6````
MKO0!`!0```#%]`$`"@```-KT`0`7````Y?0!``4```#]]`$`-0````/U`0`2
M````.?4!`!$```!,]0$`&@```%[U`0`/````>?4!``T```")]0$`$````)?U
M`0`T````J/4!``X```#=]0$`!0```.SU`0`(````\O4!`"<```#[]0$`$P``
M`"/V`0`0````-_8!``8```!(]@$`"@```$_V`0`-````6O8!``8```!H]@$`
M(@```&_V`0`0````DO8!`!````"C]@$`$P```+3V`0`,````R/8!`!L```#5
M]@$`$````/'V`0`5`````O<!``P````8]P$`$0```"7W`0`:````-_<!`!0`
M``!2]P$`#P```&?W`0`&````=_<!``4```!^]P$`#````(3W`0`F````D?<!
M``<```"X]P$`"0```,#W`0`2````RO<!`!<```#=]P$`!P```/7W`0`%````
M_?<!``<````#^`$`%@````OX`0`-````(O@!``\````P^`$`#0```$#X`0`6
M````3O@!`!@```!E^`$`#P```'[X`0`1````CO@!``P```"@^`$`&````*WX
M`0`,````QO@!`!T```#3^`$`!P```/'X`0`4````^?@!`$(````.^0$`"```
M`%'Y`0`,````6OD!`"T```!G^0$`%0```)7Y`0`5````J_D!``T```#!^0$`
M#````,_Y`0`)````W/D!``<```#F^0$`"@```.[Y`0`)````^?D!``X````#
M^@$`$````!+Z`0`I````(_H!`"4```!-^@$`*@```'/Z`0`*````GOH!``@`
M``"I^@$`"@```++Z`0`*````O?H!``P```#(^@$`#0```-7Z`0`)````X_H!
M``X```#M^@$`-0```/SZ`0`%````,OL!``X````X^P$`&@```$?[`0!=````
M8OL!`!H```#`^P$`#@```-O[`0`$````ZOL!``0```#O^P$`&@```/3[`0`:
M````#_P!`!H````J_`$`"@```$7\`0`"````4/P!``0```!3_`$`)0```%C\
M`0`#````?OP!``4```""_`$`*0```(C\`0`*````LOP!``4```"]_`$`!@``
M`,/\`0`+````ROP!`!$```#6_`$`!@```.C\`0`'````[_P!``@```#W_`$`
M!`````#]`0`%````!?T!`!T````+_0$`:P```"G]`0`*````E?T!``T```"@
M_0$`'0```*[]`0`%````S/T!``8```#2_0$`*0```-G]`0`V`````_X!``X`
M```Z_@$`"0```$G^`0`3````4_X!``H```!G_@$`"````'+^`0`7````>_X!
M`#@```"3_@$`'P```,S^`0`>````[/X!`"`````+_P$`(P```"S_`0`/````
M4/\!``0```!@_P$`!P```&7_`0`"````;?\!``@```!P_P$`!P```'G_`0`(
M````@?\!``<```"*_P$`#P```)+_`0`1````HO\!``\```"T_P$`!P```,3_
M`0!A````S/\!`!$````N``(`#P```$```@`/````4``"`!L```!@``(`40``
M`'P``@`<````S@`"``8```#K``(`'P```/(``@`F````$@$"``<````Y`0(`
M!@```$$!`@`@````2`$"``@```!I`0(`"0```'(!`@`A````?`$"`"````">
M`0(`/````+\!`@`)````_`$"``@````&`@(`"@````\"`@`G````&@("`%0`
M``!"`@(`&P```)<"`@`?````LP("`!H```#3`@(``P```.X"`@`,````\@("
M``@```#_`@(`&0````@#`@`-````(@,"``8````P`P(`%@```#<#`@`&````
M3@,"``4```!5`P(`"````%L#`@`#````9`,"``T```!H`P(`"0```'8#`@`,
M````@`,"`"0```"-`P(`'````+(#`@`.````SP,"``T```#>`P(`"@```.P#
M`@`0````]P,"`$$````(!`(`"0```$H$`@`:````5`0"`!<```!O!`(`&```
M`(<$`@`5````H`0"`!@```"V!`(`%@```,\$`@`6````Y@0"`!4```#]!`(`
M%@```!,%`@`*````*@4"`!\````U!0(`$````%4%`@!3````9@4"`!(```"Z
M!0(`"0```,T%`@`,````UP4"``L```#D!0(`#````/`%`@`;````_04"``D`
M```9!@(`&0```",&`@`'````/08"`!<```!%!@(`!@```%T&`@`'````9`8"
M``4```!L!@(`!0```'(&`@`'````>`8"`!,```"`!@(`%````)0&`@`B````
MJ08"`"(```#,!@(`'0```.\&`@`<````#0<"`"(````J!P(`)@```$T'`@`?
M````=`<"``,```"4!P(`!0```)@'`@`/````G@<"``\```"N!P(`!@```+X'
M`@`3````Q0<"``H```#9!P(`(@```.0'`@`-````!P@"`%0````5"`(`$```
M`&H(`@`C````>P@"`!T```"?"`(`%@```+T(`@`(````U`@"``X```#="`(`
M"0```.P(`@`1````]@@"`!`````("0(`"P```!D)`@`+````)0D"``X````Q
M"0(`"P```$`)`@`+````3`D"`!,```!8"0(`#@```&P)`@`*````>PD"``D`
M``"&"0(`!0```)`)`@`'````E@D"``4```">"0(`!````*0)`@`"````J0D"
M``H```"L"0(`#@```+<)`@`W````Q@D"`#L```#^"0(`&0```#H*`@`F````
M5`H"`$8```!["@(`+````,(*`@`,````[PH"`#0```#\"@(`.P```#$+`@!$
M````;0L"`$0```"R"P(`3````/<+`@`/````1`P"`"````!4#`(`#P```'4,
M`@`<````A0P"`!\```"B#`(`-P```,(,`@`B````^@P"`!P````=#0(`'P``
M`#H-`@`?````6@T"`"````!Z#0(`(````)L-`@`@````O`T"``P```#=#0(`
M00```.H-`@!!````+`X"`$4```!N#@(`1@```+0.`@!#````^PX"`$`````_
M#P(`>0```(`/`@`5````^@\"`!`````0$`(`#@```"$0`@`)````,!`"`",`
M```Z$`(`!P```%X0`@`4````9A`"`#H```![$`(`.````+80`@`D````[Q`"
M`"\````4$0(`"P```$01`@!3````4!$"`$H```"D$0(`!P```.\1`@`7````
M]Q$"`!4````/$@(`#P```"42`@`0````-1("`!@```!&$@(`!P```%\2`@`*
M````9Q("``@```!R$@(`$P```'L2`@`3````CQ("`!````"C$@(`#@```+02
M`@`2````PQ("``4```#6$@(`)````-P2`@`&`````1,"``D````($P(`!0``
M`!(3`@`&````&!,"`!0````?$P(`$@```#03`@`/````1Q,"`$@```!7$P(`
M!P```*`3`@`&````J!,"`!(```"O$P(`!0```,(3`@`'````R!,"``\```#0
M$P(`!P```.`3`@`U````Z!,"`!(````>%`(`)0```#$4`@`$````5Q0"``(`
M``!<%`(`+P```%\4`@`=````CQ0"`!,```"M%`(`.P```,$4`@`.````_10"
M`"@````,%0(`AP```#45`@`:````O14"`$4```#8%0(`)P```!X6`@`1````
M1A8"``@```!8%@(`&````&$6`@`(````>A8"``X```"#%@(`#@```)(6`@`,
M````H18"`!,```"N%@(`#````,(6`@`@````SQ8"`!P```#P%@(`!`````T7
M`@`0````$A<"``P````C%P(`"P```#`7`@`;````/!<"``\```!8%P(`*@``
M`&@7`@`5````DQ<"`!$```"I%P(`%@```+L7`@`1````TA<"`!\```#D%P(`
M"@````08`@`,````#Q@"``(````<&`(`$P```!\8`@`1````,Q@"`!<```!%
M&`(`$````%T8`@`<````;A@"``X```"+&`(`%0```)H8`@`B````L!@"``T`
M``#3&`(`!@```.$8`@`(````Z!@"``4```#Q&`(`(````/<8`@`&````&!D"
M`!(````?&0(`"````#(9`@`3````.QD"``H```!/&0(`*````%H9`@`5````
M@QD"`$$```"9&0(`&P```-L9`@`+````]QD"``P````#&@(`)0```!`:`@`B
M````-AH"``4```!9&@(`%@```%\:`@`#````=AH"``8```!Z&@(`$0```($:
M`@`%````DQH"``H```"9&@(`)0```*0:`@`Y````RAH"`"X````$&P(`"@``
M`#,;`@`F````/AL"`!````!E&P(`"P```'8;`@`=````@AL"`!0```"@&P(`
M!````+4;`@`(````NAL"``D```##&P(`"````,T;`@`+````UAL"``@```#B
M&P(`!P```.L;`@`'````\QL"`!(```#[&P(`*@````X<`@`W````.1P"`!L`
M``!Q'`(`*P```(T<`@`C````N1P"`$$```#='`(`&P```!\=`@`D````.QT"
M`"T```!@'0(`3````(X=`@`H````VQT"``<````$'@(`"`````P>`@`)````
M%1X"`!(````?'@(`"````#(>`@`5````.QX"`!0```!1'@(`+````&8>`@`O
M````DQX"`"(```##'@(`-P```.8>`@`_````'A\"``<```!>'P(`&@```&8?
M`@`)````@1\"``P```"+'P(`+@```)@?`@`,````QQ\"``\```#4'P(`#```
M`.0?`@`3````\1\"`!(````%(`(`#0```!@@`@`+````)B`"`!@````R(`(`
M"0```$L@`@`2````52`"`!$```!H(`(`&@```'H@`@`<````E2`"`#D```"R
M(`(`"P```.P@`@`0````^"`"``4````)(0(`"`````\A`@`%````&"$"`!H`
M```>(0(`#P```#DA`@`&````22$"``\```!0(0(`$0```&`A`@`(````<B$"
M``X```![(0(`#@```(HA`@`3````F2$"``4```"M(0(`$````+,A`@`-````
MQ"$"`#P```#2(0(`4@````\B`@`-````8B("``H```!P(@(`#P```'LB`@`:
M````BR("`!<```"F(@(`$@```+XB`@`3````T2("`!0```#E(@(`%````/HB
M`@`2````#R,"`"(````B(P(`"@```$4C`@`G````4","`!L```!X(P(`!0``
M`)0C`@`7````FB,"``D```"R(P(`#0```+PC`@`0````RB,"``\```#;(P(`
M$````.LC`@`2````_","`!D````/)`(`*@```"DD`@`&````5"0"``D```!;
M)`(`$````&4D`@`-````=B0"``X```"$)`(`$````),D`@`*````I"0"`#T`
M``"O)`(`"0```.TD`@`@````]R0"`!`````8)0(`%````"DE`@!_````/B4"
M`$````"^)0(`)@```/\E`@`)````)B8"`$(````P)@(`0P```',F`@`\````
MMR8"`!4```#T)@(`#P````HG`@`'````&B<"`!(````B)P(`$@```#4G`@`=
M````2"<"``D```!F)P(`&0```'`G`@`*````BB<"`!,```"5)P(`&P```*DG
M`@`'````Q2<"`!<```#-)P(`*````.4G`@`&````#B@"``<````5*`(`$```
M`!TH`@`5````+B@"`!<```!$*`(`!P```%PH`@`'````9"@"``D```!L*`(`
M%````'8H`@`2````BR@"`!,```">*`(`$P```+(H`@`&````QB@"``4```#-
M*`(`,0```-,H`@`H````!2D"`"4````N*0(`"````%0I`@`/````72D"``8`
M``!M*0(`&@```'0I`@`9````CRD"`"L```"I*0(`"0```-4I`@`,````WRD"
M`"<```#L*0(``P```!0J`@`%````&"H"``T````>*@(``P```"PJ`@`,````
M,"H"`!,````]*@(`"P```%$J`@`7````72H"`!@```!U*@(`$P```(XJ`@`%
M````HBH"``H```"H*@(`%@```+,J`@`5````RBH"``8```#@*@(`#@```.<J
M`@`'````]BH"``P```#^*@(`"@````LK`@`2````%BL"`!(````I*P(`!P``
M`#PK`@`0````1"L"`%T```!5*P(`)@```+,K`@`\````VBL"`!(````7+`(`
M!P```"HL`@`&````,BP"`!$````Y+`(`"P```$LL`@`9````5RP"`"````!Q
M+`(`%````)(L`@`A````IRP"`!0```#)+`(`'````-XL`@`?````^RP"`!8`
M```;+0(`'@```#(M`@`0````42T"`"T```!B+0(`%0```)`M`@`A````IBT"
M`&<```#(+0(`#0```#`N`@`G````/BX"`#,```!F+@(`;@```)HN`@`D````
M"2\"`"`````N+P(`)0```$\O`@`A````=2\"`",```"7+P(`*0```+LO`@`K
M````Y2\"`",````1,`(`'P```#4P`@`A````53`"`"<```!W,`(`(P```)\P
M`@`V````PS`"`"4```#Z,`(`'P```"`Q`@`;````0#$"``H```!<,0(`4@``
M`&<Q`@`5````NC$"`%H```#0,0(`!P```"LR`@`(````,S("``H````\,@(`
M$P```$<R`@`/````6S("`"T```!K,@(`&````)DR`@`<````LC("``@```#/
M,@(`"@```-@R`@`6````XS("`%(```#Z,@(`)0```$TS`@`:````<S,"`$4`
M``".,P(`;P```-0S`@!`````1#0"`'@```"%-`(`#0```/XT`@`P````##4"
M`#$````]-0(`"@```&\U`@`I````>C4"`!,```"D-0(`%````+@U`@`'````
MS34"``T```#5-0(`.@```.,U`@`3````'C8"``X````R-@(`)P```$$V`@!*
M````:38"`$0```"T-@(`*@```/DV`@`J````)#<"`"T```!/-P(`+0```'TW
M`@`G````JS<"`!````#3-P(`)0```.0W`@`R````"C@"`#8````].`(`(P``
M`'0X`@`S````F#@"`"H```#,.`(`,@```/<X`@`K````*CD"`#H```!6.0(`
M#0```)$Y`@`)````GSD"`!$```"I.0(`$P```+LY`@`8````SSD"``<```#H
M.0(`-P```/`Y`@`,````*#H"``0````U.@(`!0```#HZ`@`2````0#H"``@`
M``!3.@(`!@```%PZ`@`4````8SH"``H```!X.@(`"0```(,Z`@`%````C3H"
M`!$```"3.@(`$0```*4Z`@`:````MSH"`!P```#2.@(`%0```.\Z`@`A````
M!3L"``T````G.P(`!P```#4[`@`2````/3L"`"D```!0.P(`"0```'H[`@`)
M````A#L"`!L```"..P(`*````*H[`@`.````TSL"`"$```#B.P(`-`````0\
M`@`)````.3P"``D```!#/`(`$@```$T\`@`&````8#P"``0```!G/`(`(@``
M`&P\`@`-````CSP"``\```"=/`(`#````*T\`@`(````NCP"``D```##/`(`
M"P```,T\`@`(````V3P"``D```#B/`(`#P```.P\`@`*````_#P"``X````'
M/0(`#0```!8]`@`'````)#T"`!(````L/0(`!@```#\]`@`9````1CT"`!4`
M``!@/0(`!P```'8]`@`0````?CT"`"````"//0(`#````+`]`@`#````O3T"
M`"4```#!/0(`!@```.<]`@`&````[CT"`'L```#U/0(`"0```'$^`@`%````
M>SX"`"P```"!/@(`1@```*X^`@`C````]3X"`"\````9/P(`4````$D_`@`Z
M````FC\"`#T```#5/P(`)````!-``@`@````.$`"``4```!90`(`!P```%]`
M`@`(````9T`"``D```!P0`(`!P```'I``@`'````@D`"``@```"*0`(`$@``
M`)-``@`*````ID`"``D```"Q0`(`"P```+M``@`+````QT`"``<```#30`(`
M!P```-M``@`(````XT`"`!0```#L0`(`"P````%!`@`&````#4$"``4````4
M00(`)````!I!`@`&````/T$"`"T```!&00(`&````'1!`@`(````C4$"`!0`
M``"600(`"0```*M!`@`3````M4$"``L```#)00(`!0```-5!`@`4````VT$"
M``4```#P00(`%````/9!`@`&````"T("`!H````20@(`"@```"U"`@`<````
M.$("``@```!50@(`!@```%Y"`@`2````94("`"0```!X0@(`"P```)U"`@`-
M````J4("`"H```"W0@(`(0```.)"`@`<````!$,"``L````A0P(`!0```"U#
M`@`*````,T,"`!,````^0P(`&````%)#`@`#````:T,"`!,```!O0P(`"0``
M`(-#`@!*````C4,"`"0```#80P(`*````/U#`@`S````)D0"`"@```!:1`(`
M-0```(-$`@`O````N40"`&0```#I1`(`%@```$Y%`@`D````944"`!P```"*
M10(`'P```*=%`@`J````QT4"`!X```#R10(`(@```!%&`@!<````-$8"`#H`
M``"11@(`20```,Q&`@!K````%D<"`"H```""1P(`00```*U'`@`U````[T<"
M`$8````E2`(`2@```&Q(`@!*````MT@"`#T````"20(`,0```$!)`@`W````
M<DD"`"T```"J20(`'0```-A)`@!"````]DD"`$$````Y2@(`TP$``'M*`@`B
M````3TP"`!<```!R3`(`3````(I,`@"`````UTP"`#<```!830(`+````)!-
M`@`_````O4T"`%X```#]30(`2@```%Q.`@`J````ITX"`'<```#23@(`(@``
M`$I/`@`4````;4\"`!\```""3P(`(0```*)/`@`@````Q$\"`"L```#E3P(`
M)````!%0`@`C````-E`"`#X```!:4`(`(@```)E0`@`5````O%`"`#<```#2
M4`(`)@````I1`@`L````,5$"`"L```!>40(`/P```(I1`@`:````RE$"`"T`
M``#E40(`:0```!-2`@`V````?5("`$D```"T4@(`-P```/Y2`@`M````-E,"
M`$````!D4P(`<````*53`@!2````%E0"`"X```!I5`(`,P```)A4`@`U````
MS%0"`#8````"50(`-P```#E5`@`T````<54"`&L```"F50(`-@```!)6`@!S
M````258"`$$```"]5@(`6@```/]6`@!9````6E<"`",```"T5P(`-P```-A7
M`@`I````$%@"`"D````Z6`(`+P```&18`@!Y````E%@"`&X````.60(`=P``
M`'U9`@#$````]5D"`!8```"Z6@(`)P```-%:`@`X````^5H"`"\````R6P(`
M30```&);`@`J````L%L"`&,```#;6P(`*@```#]<`@`C````:EP"``L```".
M7`(`J````)I<`@`C````0UT"`$H```!G70(`*0```+)=`@`X````W%T"`"H`
M```57@(`(P```$!>`@`]````9%X"``8```"B7@(`!@```*E>`@`+````L%X"
M``0```"\7@(`"@```,%>`@`*````S%X"``\```#77@(`$0```.=>`@`)````
M^5X"``L````#7P(`!P````]?`@`&````%U\"`!$````>7P(`!````#!?`@!F
M````-5\"``,```"<7P(`%````*!?`@`$````M5\"``<```"Z7P(`!@```,)?
M`@`%````R5\"``@```#/7P(`%0```-A?`@`,````[E\"`!$```#[7P(`$0``
M``U@`@`#````'V`"``8````C8`(`!0```"I@`@`'````,&`"`!(````X8`(`
M#````$M@`@`4````6&`"``8```!M8`(`!````'1@`@`5````>6`"``T```"/
M8`(``P```)U@`@`N````H6`"``0```#08`(`!@```-5@`@`'````W&`"`"4`
M``#D8`(`1P````IA`@`X````4F$"`#D```"+80(`&````,5A`@`G````WF$"
M`"H````&8@(`)@```#%B`@`<````6&("`"$```!U8@(`*````)=B`@`C````
MP&("`"````#D8@(`)`````5C`@`F````*F,"`"(```!18P(`-@```'1C`@`<
M````JV,"`!T```#(8P(`,P```.9C`@`Y````&F0"`"8```!49`(`*@```'MD
M`@`H````IF0"`",```#/9`(`*````/-D`@`R````'&4"`"L```!/90(`,```
M`'ME`@`F````K&4"`"0```#390(`)0```/AE`@`N````'F8"`"````!-9@(`
M)P```&YF`@`W````EF8"`#H```#.9@(`'`````EG`@`F````)F<"`!T```!-
M9P(`/0```&MG`@`G````J6<"`"L```#19P(`*````/UG`@`J````)F@"`"0`
M``!1:`(`/@```'9H`@`>````M6@"`"L```#4:`(`*`````!I`@`W````*6D"
M`"X```!A:0(`.0```)!I`@`)````RFD"`!````#4:0(`&````.5I`@`R````
M_FD"`"4````Q:@(`#0```%=J`@`/````96H"`!8```!U:@(`"@```(QJ`@`.
M````EVH"`"H```"F:@(`"````-%J`@`+````VFH"`"\```#F:@(`,0```!9K
M`@`I````2&L"`"(```!R:P(`)````)5K`@`*````NFL"`.P```#%:P(`#```
M`+)L`@`B````OVP"`!8```#B;`(`"@```/EL`@`-````!&T"`!(````2;0(`
M%P```"5M`@`0````/6T"`"H```!.;0(`!@```'EM`@!2````@&T"`!H```#3
M;0(`&@```.YM`@`'````"6X"``\````1;@(`"````"%N`@!"````*FX"``<`
M``!M;@(`+0```'5N`@`:````HVX"`!,```"^;@(`$P```-)N`@`4````YFX"
M`#0```#[;@(`(````#!O`@`'````46\"`"0```!9;P(`"````'YO`@`)````
MAV\"`!<```"1;P(`"@```*EO`@`<````M&\"``@```#1;P(`+@```-IO`@`'
M````"7`"`",````1<`(`)P```#5P`@`'````77`"`!4```!E<`(`!P```'MP
M`@`(````@W`"``D```",<`(`0````)9P`@`'````UW`"``P```#?<`(`$P``
M`.QP`@`/`````'$"``D````0<0(`"````!IQ`@`'````(W$"`!,````K<0(`
M!@```#]Q`@`'````1G$"`!H```!.<0(`"P```&EQ`@`:````=7$"`!0```"0
M<0(`"P```*5Q`@`-````L7$"`"````"_<0(`!0```.!Q`@`U````YG$"``P`
M```<<@(`#P```"ER`@`+````.7("``,```!%<@(`%````$ER`@`B````7G("
M``L```"!<@(``P```(UR`@`(````D7("``D```":<@(`!@```*1R`@`)````
MJW("``D```"U<@(`#````+]R`@`<````S'("``H```#I<@(`$````/1R`@`.
M````!7,"`!(````4<P(`$P```"=S`@`1````.W,"`#@```!-<P(`(0```(9S
M`@`?````J',"`%H```#(<P(`6````"-T`@`A````?'0"``D```">=`(`-```
M`*AT`@`'````W70"`!<```#E=`(`0````/UT`@`3````/G4"`!,```!2=0(`
M"````&9U`@`$````;W4"``8```!T=0(`#P```'MU`@`=````BW4"``<```"I
M=0(`"````+%U`@`)````NG4"``8```#$=0(`!@```,MU`@`5````TG4"`!0`
M``#H=0(`"@```/UU`@!"````"'8"`#,```!+=@(`*0```']V`@`%````J78"
M`!L```"O=@(`'0```,MV`@`C````Z78"`"<````-=P(`$@```#5W`@`"````
M2'<"``0```!+=P(`#P```%!W`@`#````8'<"``H```!D=P(`&@```&]W`@`%
M````BG<"``(```"0=P(`#0```)-W`@!(````H7<"`#<```#J=P(`/P```")X
M`@`O````8G@"`!8```"2>`(`4@```*EX`@`W````_'@"`"P````T>0(`6@``
M`&%Y`@":````O'D"`#L```!7>@(`3P```)-Z`@`\````XWH"`#T````@>P(`
M%P```%Y[`@`E````=GL"`$,```"<>P(`1````.![`@!!````)7P"`(,```!G
M?`(`)0```.M\`@`Z````$7T"`"(```!,?0(`-@```&]]`@`X````IGT"`"P`
M``#??0(`+`````Q^`@`M````.7X"`"P```!G?@(`+````)1^`@`J````P7X"
M`"X```#L?@(`+@```!M_`@`R````2G\"`#,```!]?P(`5````+%_`@!9````
M!H`"`%H```!@@`(`2P```+N``@`R````!X$"`!8````Z@0(`#0```%&!`@`.
M````7X$"`(8```!N@0(`"0```/6!`@"M````_X$"`'$```"M@@(`A0```!^#
M`@`K````I8,"`%P```#1@P(`%````"Z$`@`5````0X0"`"@```!9A`(`%@``
M`(*$`@`0````F80"`"0```"JA`(`(@```,^$`@!"````\H0"`"`````UA0(`
M'@```%:%`@!<````=84"`!H```#2A0(`$P```.V%`@`*`````88"``4````,
MA@(`!@```!*&`@`(````&88"``4````BA@(`%@```"B&`@`5````/X8"`!<`
M``!5A@(`(@```&V&`@`;````D(8"`!````"LA@(`#P```+V&`@`'````S88"
M`!````#5A@(`!````.:&`@`,````ZX8"``X```#XA@(`"@````>'`@`%````
M$H<"``<````8AP(`!@```""'`@`9````)X<"`!(```!!AP(`#P```%2'`@`&
M````9(<"`!4```!KAP(`#````(&'`@`'````CH<"``D```"6AP(`#````*"'
M`@`)````K8<"`!0```"WAP(`!P```,R'`@`,````U(<"`!@```#AAP(`!```
M`/J'`@`)````_X<"``L````)B`(`&````!6(`@`F````+H@"``8```!5B`(`
M!0```%R(`@`G````8H@"`!L```"*B`(`"@```*:(`@`9````L8@"`!8```#+
MB`(`)````.*(`@`9````!XD"``,````AB0(`!@```"6)`@`$````+(D"``D`
M```QB0(`%0```#N)`@`3````48D"`!,```!EB0(`"````'F)`@`'````@HD"
M`!<```"*B0(`!P```**)`@`"````JHD"``(```"MB0(`'P```+")`@`.````
MT(D"``(```#?B0(`"````.*)`@`7````ZXD"`!D````#B@(`!P```!V*`@`K
M````)8H"``(```!1B@(`!P```%2*`@`&````7(H"``\```!CB@(`&0```'.*
M`@`%````C8H"``X```"3B@(`$0```***`@`9````M(H"``H```#.B@(`$P``
M`-F*`@`'````[8H"`!D```#UB@(`"@````^+`@`7````&HL"`!,````RBP(`
M$@```$:+`@`"````68L"``<```!<BP(`$0```&2+`@`&````=HL"``X```!]
MBP(`,````(R+`@`)````O8L"``H```#'BP(`%````-*+`@`3````YXL"``4`
M``#[BP(`&0````&,`@`"````&XP"``L````>C`(`!@```"J,`@`-````,8P"
M``<````_C`(`!@```$>,`@`!````-@`````````S`@```````"X$``#@!P``
MWP$```D$``#>````%P```$@(``"(`0````````````#T!````````/X"``#5
M"```^P(``````````````````-@&`````````````$,'`````````````!$%
M``#>"```EP@````````M`P``1P```-8&``#\`0```````(P(````````````
M`%8'```S!````````,L"``#/`@``7P`````````J````9P8``"L"``"&!P``
MG0,``$X#````````X`$``"T"```'"```4P0````````?!P``>P`````"``#_
M`@``5````%P$``".!0```````/8```#&````D`(```,"``"X`P```````%$"
M``"9````:@,``.$%```=!P``Q@,`````````````R`<``*\`````````T@$`
M`/(``````````@(``/H$``!#!@``100```4%``````````````````#Z`0``
M`````!`(``!-!```I`@``.4&```B!P``M@4``*,#``!7`0```````(`(```!
M!@``BP(```````!9!@``?`,````````[`P``_`<``(`&``#M`P``=P(``'@#
M````````1`<``)\'``#5!0```````$$#``"Z`0``90,``,0!``#V`@``V@``
M`'$(``#?!0``.@<```````#-````B@$```````"Q!0``Z`,``(\$``!_!```
M-@8``$\$``"Z`@```````(P$``"2`@``.P4``'X#```N`P``<`4``#H(```3
M!P``D@0```````#F!```L@,``!$(```N"```"P4```````!B!```4`,`````
M``#]!0````````````#-!```A`8``.8%``#)!P```````!(!``!Z````-0(`
M`)0!``"X!```)@````````#5`P``L`0``(\```!Y!```-0<``.P!``#O````
M<08``/P#````````=P```(T&``"5`@``60@``%H&``"C!0``2@0``)((````
M````ZP```+L#``#1!@``X@<``!<"`````````````*P&````````Q`,``.X#
M``#6````7@$``&X"```(!```0@<``&X%```L!P```````,<`````````````
M`/\'``!.`@``/0$```````!R`P```````*X```#>!```?`4``!T$``!!"```
M20$``.\'``"4!P``00(````````3`0```````.$#``!%"```Z@,``$D"``#C
M!P```````*,!``!+!0``5P(```````"<```````````````B`@```````&X$
M````````2@$``'\&```[`0``T@<``-,````M!0``=0@``*`!```%`0``K`@`
M````````````10$``#`%```@"`````````````#;````V@$`````````````
MJ0$`````````````^`(```````!#"```:P````````!-!P``O@```&0````/
M`@``P`$```````"#`0``(@@````````D`P``H@4``-H%``#9````P`,``!<#
M``!&`@``^@4```````!;`0```````````````````````+0```"%`P``A`@`
M`#,(``#4!P``;0(``%,'`````````````,,'```T`@``)@@``)@$``#8!0``
MIP4``,D!`````````````$`"``#[```````````````0`P``I0```/,```!M
M````J`,``&8```#?!P``*@(```````#P!```7P<``(,$````````!@```#\"
M``!8`P``C@$``"4!``"-!P```````!D#````````*0$``)8```"X!0``SP@`
M````````````5@8``-P```"=````FP<``#4%``"'`P```````!,&````````
M``````````#2`@``V00``)(`````````````````````````JP$`````````
M````7````#<"```F`0``Y@,``+`%````````4`4``/@````\!````````+$`
M```N!0``#@@``.T!``!@!0```````+8```!*`P``X0(``!$!````````O@@`
M`)<"````````1`@``)P(``".`P``-0```$0!```8`````````"<$```5`P``
M\0,``$T%``"&`@``)@8```````#U`0``BP@``%,```"&!@``=P$`````````
M````X`8```````#"`P``.P8`````````````6`$```````"R!@```````/<"
M````````G`$`````````````;P0``$X```"[!P``H@0```````#=!0``U`@`
M``````!Q`P``#P0``$X$``!)````XP(```````#-"```S@<``!8%```8!P``
M!````"<(``#8!````````-0#``!D!P``5P0``)L"``"X!P``"P,``*X!````
M````M`8````````]!```3P,``*4#````````'@0``#0#``!B!@``B@``````
M``#N!@``R`,``#X"`````````````$D(``""`0```````-,&``"J`0``*0``
M`-0```!+!```D`````$#```V!```H@<```````#;!```/P0```````!1!```
M@0`````````*!```D@4``+8&```J!P``K0,``+\'```[!```8`,```````!J
M!```R@0``.@%``#D!```308``'H%````````]P0``/,"```8!@``!@@``!8$
M``#1`@``]0<``)H`````````>0(```````!H!P``?````,$%````````````
M`````````````````-,#``!C!0```````"`!``#Y!P``4`0``(X$``#?`@``
M'@4```````"9!0``1@4``(X(``#^!0``6P<``"H#```A!```1@@``/8$```+
M`0```````%H%````````(P@``-@```"I"```F`,``/('``#I!@```````!P$
M``":!0``YP@``.<#```)!P``W`(```,```",`@``&P$``$\"``!_!0``]P8`
M````````````>0```%D!``"]`@``8@<```````#U!`````````````!%!@``
MIP```#\!````````!`8``(H&``#0`0``````````````````IP@``+<```"?
M`0``#@<``+H$````````QP4``+H&`````````````&0!````````\P$``(X'
M``":!P```````/$```!:`P``P0$``'0&```2"```.P<``'P'````````````
M``````!Y!@``I0$``'T&````````````````````````,`8``&`(``!_`@``
M?`8``&P(```5"```4`@``*$'``#/!@````````````#D"````````*<$``"G
M`@``:0,``"H%````````]`8``!T&```F!P``!P0``,````#Q!@``OP8``*D'
M```E````:0@``$H&``#[!@```````",```"@"```+@(```````#$!P``<`$`
M`.T"``"5!@````````@#``#""````````#`"``#H``````````````"Y!P``
M$`0``"<```#Y`0``$@0``````````````````"@`````````;@@``$4```#7
M`@``X00``,,"``!@`0``%@`````````O`0````````\#`````````````!H'
M``````````````````"]`0````````````"E"```R`$````````<"```VP4`
M`#0$``````````````````#@`P``_P8```````"$`````````,L#``#*`0``
MDP8``#8!``!P`````@@``%4%```_!0``VP$```````"Q"```DP<```$$``"K
M"````````,P(````````?@4```````!.`0``#08``*\&`````````````(8(
M``"[!```QP@``!D&````````;P4``+($``#0!```W0(``*X(``"?"```9`4`
M`$8!``"O`@``*`<``$,"``#;`@``;`4``*$#``">`@``1P4``#P```"1`0``
M3P$```4$``!]`P``D`<``&L(````````P@0``-8!``"0!0``&`0`````````
M```````````````9!P``^`$``",!``!B`P``J04``.8'``#B!0``P0@``$,`
M````````?`(`````````````````````````````P`(``*X'````````A`$`
M`"<!``"'`0``7P0``+D%```N`0``5P<``*H'``#D!P```````*T'```L`0``
ME04````'```V!0``"0```,P'``"<!@```````%0"``!H!@``=P@```````"M
M`0``Z0<``)H!````````C@8``*4"`````````````-8%````````?@(`````
M````````\00```````#9"```)P8````````K````,0@``,<'``!E````S```
M`$\(``!.!0```````+L!```_"```E@4``$<!``!M"```;@8``#P'````````
MW`@``",#````````B0``````````````=`$``-8'````````3`$``+$"````
M`````````-(%``!*`@``SP,``$`&```T`0``#P8```````";!@``7P$``,\$
M``##`0`````````````M!```?0$``$,$``"E!```;P@``'T"``#8`@``DP``
M`$T#````````)P4``!8(```P`````````'L&````````(0<``(($```N!@``
M:0```#<$````!@``Y`,``(8```!A`@```````#$%````````R0,```````"D
M!P``1P0```````#>`P````````````"X!@``T@@```````#B````+P8``.$(
M```?`P``"04``"(&````````W`0```0%``"6!P```````'`&``#!!P``TP0`
M`%4```#."```#P4``"L$````````5`8`````````````B@<``!0!``#"!@``
M`````'(!````````?0```!4!````````H0````````#G!P``,`<````````$
M`@``6`8``(``````````"@,```````#F`0``'P4``!X#```R!0```````/8&
M```3`@``H0@``#D&```#!P``M`(``(<$```'!P``?@8``%T(``!V````````
M`&\#``!X!P``````````````````C0(```````"$!0`````````%``"4````
M`````)0&```!"```B0@``)D&``#$"```V@(``#8#``!M!0``C04``#D%``"Z
M`````````(,"````````:@4``'L!``!=!P``7@(``'`$```=`P``&P0``!X`
M``#N`@``RP0``-4$``#S!@``Z@$``!L#````````G`0``%\&``"+````8@4`
M``X```!K!P``:0(``%(#````````FP4``,4#```%!P``>`(``/$!``!U`@``
MJ@0````````?`0``)@4``/("``!J`0``#`4````````4!P``_0$``-8"``#8
M"```_P4``````````````````$T!``#X!P``O@<`````````````````````
M``#%`0``/@$``#4&``````````````````!$`````````)\%``#1````````
M`#$#``!!````5`,```````#3!P``'0$```D#````````:`$``!D%````````
M1P,``&L%```:"```G@@``#@'```:!@```````'4&``#`!0```````)4$````
M````7P4``,X!```6!@``]`,``````````````````(H#``!`!0``R`0``'0(
M````````3@@``"\#``!!!```'@@``!0#``#9!@``#P````````!(!0``B`8`
M```````<`P```````$@!``!U`P``CP$``.P$``"F`0``A0<``/P```!;!@``
MB00``,,```"!`@``I@@```````"K`@```````'0$``">!P``]0(````````R
M`P```````/T#``#^`````````&$(``#=`0``P`<```<#````````O`0``'T$
M```*!0``Q0```,X&``"M"````````#,%```!`@```````-4!```+`@``90$`
M`'\(``!?`@``X`4```````#*`@``=0<``"$"``!8"```&`@``,0"```S!P``
MP@(``-H(``#K!```=04``&T!``#5````Z04``(,```"C!P```````$L!```-
M`P````````````"3`@``,P```+,"```*````+0@``%X(``!0`@``O@4``%8%
M``#M!P```````'(&``"7`0``M@<``(`%````````)P,```T!```0!0``XP,`
M`-@'``#W`0``6`(``$(&``#1`0``9@0``.,!``````````````D!``!*!0``
M```````````&!0````````````#7"```<P0```````#E!0``A`(``'L"``!Z
M`P``:P$``!4```!.!P````````8$``"'````004```````!H````<@<``+4#
M``#^`0``J0```.L"`````````````+L"``#,!```"`<``(\(``"A`0``````
M``````!3!0``8@@```````!E!@``[@```/$%``#>`0``+0<```$'```@````
M@P4```````"\``````````````#*`P``*0(```````"\!P````````````"F
M````(`,``"<"``#N!```KP<```````#_!```F@@``-L&````````````````
M``!E!```"@$``)0#``!Z!P``1`,``*4%```_!@```````"4"````````"P<`
M`"D#``##"```\@8```````!)!```DP@`````````````C@(``%D'```3!```
MRP<``#L```!<!@```````,(%``!X"``````````````X"```-@(````````0
M!@````````````#W`````````,H%``!Z`0```````(X```!8````^`,`````
M``"``P``;@<```T%````````I`0`````````````7`(``%@$``#7!@``*`$`
M`#<(``!/!0``;P(``"4#``!+!@````````````"H"```@0$``!P"````````
M+`4``+$'``"S!```1`0``+<!``!3!@``8P<````````D"```:04``*L`````
M````@08``-<'``!V!P``3P```"0%```(!0```````&L$``!*"```````````
M``"N!```Q0<``*X"`````````````)T$````````Z0,``"@#``#A````@@(`
M`!P'``"W!0``60```#8'``!!!@``4P@```````#S!P``-P<``+('``#G````
ME0$````````R!P```````&("````````B0<`````````````Y0@``'T(``!H
M`@```````'8"``#U`P``F0(``#@%``!W!0````````````!V`P``JP<``'D!
M``#S!0``!0@``%<#````````9P4```````#&`0``#0@``,L%```.`0``'P0`
M`#$"````````]08``"`$``#+"```,`@``'\!```H`@```````*(&````````
M'````.0&```)!@``)`0``!T(``!L!@```P4``+$&``"7!0````````(#```Y
M`P```````','``!A!0```````,\```"9!```!P```*@%```X!@```````+D$
M```,"```LP@``$`$``#9`P```````!4%``"!!P````````````"X`@``````
M``````!S````W0`````````[`@``5@````````"!!````````*\(```?!@``
M^P$```@(```A`0``'04```````![!P``.0<``*T```"F`P``(P0``)4'``#?
M!@``4P$``+X"``!#`P```````/H'``"\`P``L0$``"`&````````/0@``*0#
M````````+@```"P&````````D@$``!X'``"6`@``N08``/,#````````70$`
M``````#2`P``$@8``&H"`````````````"4$```Z!@```````&,!``"/!@``
M_08``.4$``!(!P```````&<(``#4!@``8P@``'(`````````:P(``,D(``!4
M!0``3`(``!T```!F`@``KP$``(L&``!@!```#`$``+T(``"_`P```````(`'
M``"``@``M0```'0#````````>`$``#D(``!L`@``TP4``,@(```1````\`<`
M`!0&``#:!```#@4``*$%`````````````+D"``"J!0``+P4``-,"``#[`P``
M&P```'L$``"S!P``#P<``,4$```_`P``>P@``%T$`````````````!\(``#Z
M`@```````"0"``#4!```?P<``%<``````````````,<#````````$````+T#
M``````````0`````````````W@4``#(```!+`@``Y0```$@```#)!0``>@(`
M`&<```"X````/@@``,@%````````:@<``"D'``#I`0``\@,``)L!```;!0``
MG0(``(4$``!?`P```````.<%````````J`(``````````````````#X&```"
M!```<P@``+X#```%`@``%@(``#4!``#)!@``H@$````````]!@```````/$"
M````````=@0``!\`````````G@0````````4!```#0```*L$``"W!P``P`@`
M`)X&````````Q08``/(!``"L`@``6P@``(P&```,!P``L`,``!D!```Z`@``
MZ00```````#]`@``V04```````!'!@``I`(`````````````<0(`````````
M````I````'H(````````7`,``,(!````````<`,``/X$``!P"```J0(`````
M``````````````````!^!```E`@``.H'``#C!0``G@$``.<"````````4```
M`&0&``"0!@``?@$``&T$``#\!```SP<``)D#``#_`P``B`0``*<'``"Z`P``
M!0,``(@"````````WP,```````!G`@``@P8``!\"````````!@,```````"6
M`P``6@(````````T!P``T0<``%0(`````````````-D"``#\!@``S`(``-4"
M``#U!0``5P@``$P````J`0``<P4``"\$``"H`0``*@8``-L(````````3P8`
M`",&````````?`@``%D%``!6`@``C````#0&``!Y!P``=`(``+0(``#2!@``
M<04````````Z`0``BP,``,T!``"P"```9P,```````##!```#`,```````"H
M!@``=P0``/`"``#'`@``3P<``/\`````````R`(```````"!"```"`(``.T`
M``!5"```X@(``#<#``!D"````````,4(``!C!````````#T"``!5`@``M`<`
M``````!*!P``M`$``!X"``"R!0``G@,```````#K!P```````(L%``"I`P``
ME@$``-````!)!0``````````````````+`0```````"I!```!`0``/<#``#<
M`0``L`(``(T#``#B`P```````%@%````````%00`````````````I08``&,#
M``"R"```[@$``#("``!"`0```````.H%``!$!0```````-$(````````IP8`
M`"D&``!9`@``_0<```<"```B!````````(T```#5!P``0`@```````#<!P``
M[08``+H%`````````04``%X%```8`P``Y@@```````#1`P``K@8```H'````
M````PP4``$<'```#`P``D0<``,$&``#O!0````````````"0`0``TP@``+P%
M``#W!P``Z@8``)0$``##`P``_@<``%$%``#'!@``G@4`````````````JP,`
M`)P"``"C!@``]@<``/D%``#1!``````````````7!P``M04``+D```!-````
M#0<``*D&``"'!P````````````"F!0``)`<```````#V`0``,00``!<!````
M``````````8!``!#!0``/@,``'<#``!S`P``?@<``(@(``#N!P```````-@!
M````````C`4````````_````00<```````````````````````#$````T`(`
M`(P#``"2!@``E@@``.L&``"0"```9@<``!H$````````W0<``+X&``!R!0``
MZP4``'`'``!L!P```````````````````````(T$`````````````.T%``!"
M!0``=````%L`````````L`<``+D!````````5@$``+\````X`P``\@0``.D`
M```/`0``:P,```L(````````Q`8``````````````````'8%```-`@``````
M`&\````Q!@``$@4``&X```#"````20<```````"W!````````-0%``#1!0``
MO`@``#$!``"\`0``F`4```````!:!```A08``+$#````````KP,``*8$```0
M`0```````$P#``"="```G@```/P%```#"```20,```````#E`0``6P0``.4"
M``#A`0``7`@``)H"``#I"```500``/0"````````TP$``.P"``"@!0``,`,`
M`((```!2!0``9`0``%(!````````&`(```````"?`P```````.\&```R"```
M8@`````````@`@``2P@``*H&```_!P``QP0``,L!``#)````H@(``%4'``#=
M`P``E0```-`(```)"```BP<``,T%``!I!P``(P(``%4#``#$!0``B08``-(`
M`````````P8`````````````S`8``-D!```S!@``"@8```('````````O`8`
M`/4````9"````````"T`````````10(``````````````````(,#``!\!```
M`````/T```#K"````````%(&``!1`0``<00```````";"````````'L#``"U
M!P``*0@````````8!0``4@@``.4'``!C`@``J````&H&```T!0```````.L!
M```:`P``\@4``)\&```$`0``^08``%D$`````````````,L````4````R00`
M``````!<!P``O`(``,4"``#.````4`<``$0"``#L`P``HP@``%,#``""!0``
M%P4``%L%``!(!@```````$((``#&!@```````&T#``"@!P``A04``-H'``"/
M!0``N`$``+,```#!!```C0@``-D'``!,!@``Y@(```````!F"```:@@``#X`
M``#G`0``70```&0"``#T!P``6@$```P"``!D`P``8@$``+T````H!@``\`,`
M`)4(```;!P``%@<``#D"````````B0(`````````````H`(```````"-`0``
M=`<``-`'```0`@````````````"*!```K04``!P%```A!0``-0@``"P```"/
M`P``WP0```````"J"```$`<``'<'````````B`,``-P#``#&!P``#`8``%0'
M``!2!P``/`,``.,&``#8`P```````)8&``#!````L`$``+<&``#L````F`<`
M``````#6`P``Q04``!,``````````````-P&``#"!P```````$0&```2!P``
M!P4``+4&``````````````L````.`@``W@8``+8!````````:`,```````#L
M!0``(`4``&P!``#J!````````-T(````````4@```&X!``#/!0``0````)$#
M``!+````&@$``/@&````````B04``'0%`````````````%L#``",`0``````
M`'D#``!Q`0``0`<``,X#``![!0``]@,``'H&``#;!P``"0(``,8%````````
M508``&P$```K!0```````&4'````````.`$``.$&``"_!0``Z`8``#($``#B
M!@``.@0``.4#```%````_@,``(H%``"'!0``80```"L(```\!@``K08`````
M``#Z!@``H````*0&``"%`@``_`(``$8&````````D`0``((#``!_````I@<`
M`!$"``"%`0``"`````(&````````R@<``"@$``"3`P``'@$``$4#````````
M!`,``!L"```C!P``%`@```P```!C````:08``+4"```5!P``U`$```````#O
M`0```````(\'``!O!P```````(@```!_`P```````*H"```9!````````($%
M``"9"```#00````````1!P``-@@``"$#``"?````-P4``'@````Z!0``MP,`
M`&L&``!2!```*`@```````#[!```D0``````````````+P````````"V!```
M1@0``)\"``!@````H@,``)L$```6`P```````"\'```X`@``/`@`````````
M`0``YP0``(,(``#J````=0```$<(````````;0<``,8(``"T`P``/0,``'P!
M```3"`````````````""!@``8`<``!T"``"]!0```````)<'``#=!```M`4`
M`%`&``!@!@``]@4``(4`````````T`8`````````````H@@``(\"````````
MM`0``&4(``!"`@```````!@!``!:"```$P4```````!(`P```````/H#``"7
M!@``FP```+4$``#F!@````````````"U"```````````````````.`0``*L%
M`````````````!,#``"S!0````````$!``!=`@``9P$``$L#```K`P``;P$`
M```````T````Y`$```````!=`P``6P(``,`&`````````````)H&````````
M`````````````````````-<$``"^`0``E0,``)@"``"``0``S`$`````````
M````/@<``/H````.`P``3`<``*`#``#Y`@``K@4``*X#````````````````
M```;!@```````(((```2`P``B`<```````#$!````````!(```#-`@``````
M`+L```#@"```L@$`````````````Q@0``)T%``"Z"```F0$````(``"[!0``
M``````````!Q!P```````)$$``#L!@```````#P!``#M!```G0<``-($```>
M!@```````)$"``",!P``R`8``$8'````````OP$````````S`P``T`4``-<`
M``!H!```\````)<$```$!P``6@<``,$#```W````KP0``,H(``"Z!P``%P0`
M`"L&``#@`@``J@````````!L````E`4``$D&````````=P8``*,````*"```
MF`@``*8&````````B0$``(D#```E!@``L@(``.0`````````A`<``!H%``#+
M!@``(@,``%X#``!F`P``VP,``!P!```B!0````````````#P!@``^00`````
M```L"```0@```&D$````````2`0``.((``!A!@```````#$'``"=!@``%`(`
M`$`#``!Q````DP0``.@!```,!```/0```"(!``!=!0``X@$```````!4!```
MW`4``-0"``#[!0```````*<#````````-0,``.,(`````````````+T'``!-
M`@``00$``'8&``"7`P``X`0``(@%````````>0@`````````````UP$``'4$
M```Z`P``FP,`````````````;`,``)P'````````40@``"T!``"B````````
M`%P!``!1!@``50$``*,"``#Q!P``ZP,``"X'``"&!``````````````4!0``
M<@@``"P"```.!```8`(```````"S`0``)`8```````#P!0```````-4&``!"
M!```]`$``.@(```9`@``S0<``)@````P!```5@0``-<#```.!@````````(`
M````````B@(``)D'```M!@``'`8```````!%!P``DP$``*P!```7!@``````
M`.\"```&!@```````&\&```7"```.P@``#P%``#B!```"P0``#<&``!F`0``
M`````#D!``!S!@``Z0(````````U!```80,``%`!``!6`P``708``$<"```H
M!0``JP8```````#M"`````````````#]!```B@@``*4'```9````L00``.,$
M````````/`(``&$$``!>!P``L@``````````````A0@```0(````````!@(`
M`&@(```+!@``BP$``+T$````````3`@``"$&``"@!@```````),%``#F````
MA`0``"<'``##!@``P`0```````"1!0```````#H```#7!0``^`0``)$&````
M`````````+8"``!]!P```````)`#``"H!P``IP$``)\$``"_`@```````/0%
M````````+P@``,8"``"[!@````````4&```O`@``A@$````````:`@``````
M`,H````(!@``9@8```````#C````)````+\(``!%!0``(`<```````!(`@``
MBP0`````````````U@@``!4&``!G!P``I`4`````````````@0,`````````
M`````````+@(```Y!````````*`$``":`P``4P(``.H(```Y````````````
M``"L!P``````````````````D@,``"(````"`0``F@0````````R`0``?04`
M`&4"`````````````(<"```T"````P0``*P$````````W08```````!7!0``
M@`0``)$(````````]````'($``"'"```QP$``',!````````#P@```````"2
M!P``R0(``"8$```"!0``=@$``,@```"8!@``3@8``(<&```1!```I@(``"D$
M``"J`P``=@@``'@&``!+!P``A@4``(('``"A!```J`0`````````````````
M````````````T`,````````C!0``[`<``"H$``!1!P``)0@``.\$``!N`P``
ML`8``*,$``"A!@``,0````````"S`P```````$(#``#A!P``&P@``.@"````
M````````````````````V@8```````#*!@``!P8``$8``````````````*T$
M```5`@``A`,``$P$``"V`P````,``'("````````````````````````^P<`
M``H"``#H!P```````,T#````````M@@`````````````S@(`````````````
MWP@``)<````^!0``1@,```````"4`@``0`$``+````"S!@``X`````````!#
M`0````````````!X!0``(0@``%("``!<!0``40,``&T&````````O08``+D#
M``"8`0``80<``&$!``"Y"```S08``*T"````````H0(````````A````````
M``````!>!```S`,``,X$``!1````5P8``#T'``!4`0``E@0``"H(``"U`0``
M`````'H$``!:````^0````````#W!0``30@``'@$``"D`0``A@,``"8"``"L
M`P``WP```'`"````````Z@(``&,&``!G!```?@@```````!6"````````,P%
M```1`P```P$``%D#````````6`<``%\(```E!P``,@8``"0!``#X!0``P0(`
M`*P```#_`0``_@8``#T%````````904```````#N!0```````$P%``#S!```
MV@,``,X%``#>!P```````'4!```2`@``9@4```````!I`0``YP8``+X$````
M``````````````!*````)@,``!8!``#H!```-P$``/`!``"W"```/@0``!H`
M``"=`0``+`,``-8$```'`0```````#@```"L!0``G`4``#`!``!>````NP@`
M`'D%```E!0`````````````&!P``:`4``/D#````````Y`4``.P(``#O`P``
M,P$``'X`````````SP$``)P#``!>!@``"`$``',"```1!@```````&H```"W
M`@```````"D%```K`0``*P<```````"#!P```````.0"````````````````
M``"_!```KP4``-X"`````````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES
M(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B
M)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B
M('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!C86QE;F1A<G,@9F]U
M;F0`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D(&5V
M96YT<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1&%Y*',I("5S
M($AO=7(H<RD@)7,@36EN=71E<P`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P
M`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@
M97AI<W1S+@`E<R!A="`E<R`E<P`E<R!A='1E;F1E97,`)7,@9FEL92!S=6-C
M97-S9G5L;'D@:6UP;W)T960`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S
M(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`
M)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@
M)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+@`H0VQI8VL@;VX@8V%L96YD87(@;F%M92!T;R!S
M=VET8V@@=&AE(&-A;&5N9&%R)W,@=FES:6)I;&ET>2!I;B!T:&4@;6%I;B!W
M:6YD;W<I`"H@061D('1H97-E(&)Y(&-L:6-K:6YG($%D9"`J`"H@4&QE87-E
M('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S
M("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,2!A
M='1E;F1E90`Q(&5V96YT`#$@:&]U<@`Q,B!(;W5R($9O<FUA=``Q-2!M:6YU
M=&5S`#(P(&UI;G5T97,`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`,S`@;6EN
M=71E<P`\4')E=FEO=7,`/'-T<F]N9SY!='1E;F1E97,\+W-T<F]N9SX@*&]P
M=&EO;F%L*0`\<W1R;VYG/D1E<V-R:5]P=&EO;CPO<W1R;VYG/B`H;W!T:6]N
M86PI`#QS=')O;F<^2V5Y=V]R9',\+W-T<F]N9SX@*&]P=&EO;F%L*0`\<W1R
M;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@*&]P=&EO;F%L*0!!(&1A=&%B87-E
M(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@
M97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-`$%-($-L;W5D<P!!
M32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E
M<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B
M<V)O='1O;0!!8G-M:61D;&4`06-C97!T960`06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`
M06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061?=F%N8V5D(%-E87)C:`!!
M9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!%
M=F5N=`!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I
M;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M
M:7-S:6]N('1O("(E<R(`061D(&$@;F5W(%)E;6]T92!#86QE;F1A<@!!9&0@
M82!N97<@979E;G0`061D(&$@;F5W('5S97(Z`$%D9"!A='1E;F1E97,`061D
M(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ
M`$%D9"!T;R!A='1E;F1E97,`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@
M=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M
M:6YI<W1R871I;VX`061S`$%D=F%N8V5D(%-E87)C:`!!9F=H86YI<W1A;@!!
M;&%R;0!!;&%R;2`E9"!D87ES(&)E9F]R90!!;&%R;2`E9"!H;W5R<R!B969O
M<F4`06QA<FT@)60@;6EN=71E<R!B969O<F4`06QA<FT@)60@=V5E:W,@8F5F
M;W)E`$%L87)M(#$@9&%Y(&)E9F]R90!!;&%R;2`Q(&AO=7(@8F5F;W)E`$%L
M87)M(#$@;6EN=71E(&)E9F]R90!!;&%R;2`Q('=E96L@8F5F;W)E`$%L87)M
M($1A=&4`06QA<FT@4W!A;B`H;6EN=71E<RD`06QA<FT@5&EM90!!;&)A;FEA
M`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%T=&5N
M9&5E<P!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1G5T=7)E`$%L;"!'
M<F]U<',`06QL(%!A<W0`06QL(%!E<FUI<W-I;VYS`$%L;"!6:7-I8FQE`$%L
M;"!D87D`06QL(&1A>2!E=F5N=`!!;&P@979E;G1S`$%L;"!F;W5R('-I9&5S
M`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R
M9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U3
M4"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@
M=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@
M:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U
M<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A
M`$%N>0!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N
M(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R
M;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H
M:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B
M+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM
M."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O
M4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O
M:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN
M<P!!=`!!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!W:71H(&UO<F4@
M:6YF;W)M871I;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y;W5R(&UA:6P@8VQI
M96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@=&AI<R!F
M:6QE('1O(&5A<VEL>2!U<&1A=&4@>6]U<B!L;V-A;"!C;W!Y(&]F('1H92!E
M=F5N="X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&%N
M8V4`071T96YD965S`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T
M<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E
M<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H
M.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE
M;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I
M;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H
M92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A
M:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO
M="!F;W5N9"X`0F%S96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R=7,`0F5L9VEU
M;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@
M(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T
M=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E
M<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z
M:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U
M<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U
M<G5N9&D`0G5S>0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?
M86QE;F1A<@!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N`$-A;%]E;F1A<@!#86QE;F1A<@!#86QE;F1A<B!3=6UM
M87)Y`$-A;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G960N`$-A;&5N9&%R<P!#
M86QE;F1A<G,@;75S="!H879E(&$@;F%M92X`0V%L;0!#86UB;V1I80!#86UE
M<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I
M;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N
M9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T
M(&-R96%T92!A(&YE=R!E=F5N="X`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A
M;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;F-E;&QE9`!#
M86YC96QL960Z("5S`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E
M(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R7WD`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#
M:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN
M`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H
M;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO
M=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',@8GD@
M96UA:6PZ`$-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N
M97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S+@!#:&]O<V4@:68@>6]U
M('=A;G0@=&\@<F5C96EV92!E;6%I;"!R96UI;F1E<G,@9F]R(&5V96YT<R!W
M:71H(&%L87)M<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R
M960@;&ES=',I`$-H;V]S92!T:&4@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@
M9F]R(&9R964O8G5S>2!54DQS.@!#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I
M;F-L=61E(&EN('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.@!#:&]O<V4@
M=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E('=H96X@9V5N97)A=&EN9R!F<F5E
M+V)U<WD@55),<SH`0VAO;W-E('EO=7(@9&5F875L="!C86QE;F1A<BX`0VAR
M:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N
M9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A
M<B!A;&P@871T96YD965S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R
M`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I
M;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W-E('=I
M;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N
M`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA('-E<&%R871E9"!V
M86QU97,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA
M;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET
M:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S
M`$-O;F9I<FT@4&%S<W=O<F0`0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_
M`$-O;F9I<FUE9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE
M9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP
M<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@
M27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE
M8W1I;VX`0V]P>2!T:&4@55),(&)E;&]W(&9O<B!U<V4@=VAE<F5V97(@>6]U
M(&YE960@>6]U<B!&<F5E+T)U<WD@55),.@!#;W-T($E$`$-O<W1A(%)I8V$`
M0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@
M`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD
M('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C
M;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T
M(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P
M('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L
M;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L
M9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#
M;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E
M;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R
M96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C
M="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#
M3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C
M:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A
M=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3
M:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N
M)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E
M<P!#<F5A=&4`0W)E871E($-A;&5N9&%R`$-R96%T92!A($YE=R!%=F5N=`!#
M<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD
M97)S`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N
M=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0`0W5R<F5N="`T(%!H87-E<P!#
M=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#
M=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO
M;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL
M:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E=F5R
M>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@
M4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1A>2AS*0!$95]L971E`$1E
M7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L:6YE
M9`!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-A;&5N9&%R`$1E
M9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E
M9FEN:71I;VYS`$1E;&5T90!$96QE=&4@)7,`1&5L971E($-E;&P`1&5L971E
M($5V96YT`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S
M:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L
M971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M`$1E;&5T92!M97-S86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`
M1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI
M<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$
M96QE=&4@<W5B(&9O;&1E<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$
M96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E
M(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R(&%L;"!O8V-U<F5N8V5S
M/P!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:5]P
M=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E
M=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@
M`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L
M969T`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`
M1&ES<&QA>2!#86QE;F1A<G,`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y
M(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@
M;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!$;R!Y;W4@=V%N="!T;R!S:&]W('1A<VMS('=H:6-H(&%R92!D=64@
M;VX@>6]U<B!C86QE;F1A<C\`1&]E<R!N;W0@<F5C=7(`1&]E<R!T:&4@9FER
M<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K
M('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@
M:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E
M<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R
M:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!$=64Z("5S`$1U<F%T:6]N`$4M
M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R
M<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I
M=`!%9&ET("5S`$5D:70@071T96YD965S`$5D:70@0FQO8VL`161I="!#86QE
M;F1A<G,`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S
M:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(%)E;6]T92!#86QE
M;F1A<G,`161I="!A='1E;F1E97,`161I="!C871E9V]R:65S(&%N9"!C;VQO
M<G,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S
M(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@
M4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M
M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S
M<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16Y?9`!%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%
M;F0@1&%T90!%;F0@3VX`16YD(%1I;64`16YD('EE87(`16YL87)G92!%9&ET
M;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H
M92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U
M871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S`$5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O
M<B`E<SH@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA
M`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E;G0@861D960Z`$5V96YT(&1E
M;&5T960Z`$5V96YT(&5D:71E9#H`179E;G0@9G)O;2`E<R!T;R`E<P!%=F5N
M="!N;W0@9F]U;F0`179E;G1S(&UU<W0@:&%V92!A('-T87)T(&1A=&4N`$5V
M96YT<R!M=7-T(&AA=F4@82!T:71L92X`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`
M179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M
M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD($YA;65S`$5X<&%N
M9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!%
M>'!O<G0`17AP;W)T($-A;&5N9&%R`$9'($-O;&]R`$944"!U<&QO860@;V8@
M<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE
M9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O
M(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S
M*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A
M<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N
M;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T
M(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R
M`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O
M<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`
M1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R
M;W!O;&ET86X`1G)E90!&<F5E+T)U<WD@26YF;W)M871I;VX`1G)E;F-H($=U
M:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<P!&<FED87D`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$9U='5R90!'86)O;@!'86QL97)Y('1O('1A
M:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V%M90!'96YE<F%L`$=E
M;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I
M80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/
M<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=O
M=&\@)7,`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E
M96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M
M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D
M9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R
M;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P
M90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'
M=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET
M:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M
M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES
M<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:61E
M`$AI9&4@)7,`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H
M;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV
M86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO
M<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E
M<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA
M<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO
M<FEZ;VYT86PZ`$AO=7(H<RD`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A
M<V4@<F5P;W)T(2D`2&]W(&QO;F<@<VAO=6QD('1H92!T:6UE('-L;W1S(&]N
M('1H92!D87D@86YD('=E96L@=FEE=W,@8F4_`$AO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&1A>7,@;V8@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N('-H;W5L9"!W92!G96YE<F%T93\`2&]W(&UA
M;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``
M2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`
M25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F
M;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN
M9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S
M964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W
M86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W
M<V5R+@!)9B!Y;W5R(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O<G0@:51I
M<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@;V8@=&AE(&9O;&QO=VEN9R!L
M:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N"@I4;R!A8V-E
M<'0@=&AE(&5V96YT.@HE<PH*5&\@86-C97!T('1H92!E=F5N="!T96YT871I
M=F5L>3H*)7,*"E1O(&1E8VQI;F4@=&AE(&5V96YT.@HE<P!);6%G92!0<F5V
M:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`
M26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R
M="!#86QE;F1A<BP@4W1E<"`E9`!);7!O<G0L(%-T97`@)60`26UP;W)T+T5X
M<&]R="!#86QE;F1A<@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE
M;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@
M9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U
M86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I
M;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T97(`
M26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS
M97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E
M<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z
M`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@
M8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S
M86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@
M8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS
M97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T
M:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!)
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@
M;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED
M(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@
M240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I
M;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N
M<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US
M9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R
M(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO
M;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`
M26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV
M86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV
M86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N
M`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@
M;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC
M`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P
M,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF
M>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I
M9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@
M<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE
M<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y
M(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`2V5Y=V]R9',`2VED<P!+:7)I8F%T:0!+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L
M:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO
M=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`
M3&%S="`R-"!H;W5R<P!,87-T($AA;&8`3&%S="!-;V1I9FEE9`!,87-T($UO
M;G1H`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P
M9&%T960Z`$QA<W0@665A<@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E
M<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA<W0@=V5E:P!,871V:6$`
M3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`
M3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI
M8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI
M9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT
M(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@
M5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K
M`$QI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.@!,:6YK`$QI;FL@<&]I
M;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES
M="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(
M96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I
M8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO7V-A=&EO;@!,;V%D
M:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`
M3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,
M;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,
M;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L
M971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R
M<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-
M86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I
M=F5S`$UA;&D`36%L=&$`36%N86=E(')E;6]T92!C86QE;F1A<G,N`$UA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O
M<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L
M9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R
M(&]F($5V96YT<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA
M>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE`$UE9&EC:6YE`$UE971I;F<`
M365M8F5R<P!-96YU($%L87)M<P!-96YU($QI<W0`365N=2!M;V1E.@!-97)G
M92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E
M<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!7
M96%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`
M365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@
M9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R
M;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`
M36EN=71E*',I`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN
M9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N
M($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO
M9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`
M36]N9&%Y`$UO;F=O;&EA`$UO;G1H`$UO;G1H(%9I97<`36]N=&@@86YD('EE
M87(`36]N=&AL>0!-;VYT:&QY($5V96YT<R!,:7-T`$UO;G1H;'DZ(%)E8W5R
M<R!E=F5R>0!-;VYT:',@06AE860`36]N=&AS($)E9F]R90!-;VYT<V5R<F%T
M`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA
M;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L
M>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V
M92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`
M375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-
M=6QT:7!L92!I0V%L96YD87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@
M=D5V96YT(&ES('-U<'!O<G1E9"X`375L=&EP;&4@<V5L96-T:6]N`$UY($%C
M8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!#86QE;F1A<G,`37D@
M0V%L96YD87)S.@!->2!&<F5E+T)U<WD@55),`$UY(%!O<G1A;`!->2!0;W)T
M86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M
M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I
M;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N
M(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@
M55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V
M97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E
M(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA
M`$YE=R!#871E9V]R>0!.97<@179E;G0`3F5W($UE<W-A9V4@=&\@)7,`3F5W
M($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W
M(&-A;&5N9&%R(&-R96%T960@86YD(&%U=&]M871I8V%L;'D@<VAA<F5D('=I
M=&@@9F]L;&]W:6YG(&=R;W5P*',I.B`E<RX`3F5W('!A<W-W;W)D`$YE=R!P
M87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG
M="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`
M3F5X=`!.97AT(#(T(&AO=7)S`$YE>'0@-"!0:&%S97,`3F5X="!$87D`3F5X
M="!-;VYT:`!.97AT(%=E96L`3F5X="!996%R`$YE>'0@9&%Y`$YE>'0@;W!T
M:6]N<P!.97AT('=E96L`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`
M3FEG:'0`3FEU90!.;P!.;R!A;&%R;0!.;R!A='1E;F1E97,`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-A;&5N9&%R<R!A<F4@879A
M:6QA8FQE('1O(&=U97-T<RX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U
M<'!L:65D+@!.;R!E;F0@9&%T90!.;R!E=F5N=',@=&\@9&ES<&QA>0!.;R!F
M:6QE('5P;&]A9&5D`$YO(&9R964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I
M;&%B;&4@9F]R("5S`$YO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"X`3F\@
M:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@
M<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF
M:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N
M97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.
M;R!Q=6]T82!S970N`$YO(')E8W5R<F5N8V4`3F\@<G5L97,`3F\@<V5P87)A
M=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D`$YO('9A;&ED(&5M86EL(&%D9')E<W,@9F]U;F0`3F\@=F%L=65S
M`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R
M;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E
M`$YO="!A(&1I<F5C=&]R>0!.;W0@9F]U;F0`3F]T(&EM<&QE;65N=&5D+@!.
M;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+@!.;W1I9FEC871I;VYS`$YO=F5M8F5R`$YO=P!.=6UB97(`
M3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R
M(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R
M`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D
M`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;@!/;B!A;&P@
M8V%L96YD87)S($D@:&%V92!R96%D(&%C8V5S<R!T;P!/;B!A;&P@<VAO=VX@
M8V%L96YD87)S`$]N(&UY(&-A;&5N9&%R<R!O;FQY`$]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E
M;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X
M=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;F%L`$]P=&EO;F%L($%T=&5N9&5E<P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S
M`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI
M=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R
M:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I
M;VX`3W9E<G9I97<`3W=N97(`3W=N97(@4&5R;6ES<VEO;G,`3W=N97(Z("5S
M`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-
M86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T
M960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$
M871A`%!(4"!#;V1E`%!(4"!3:&5L;`!030!032!,:6=H="!286EN`%!-(%)A
M:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`
M4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3
M:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I
M=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U
M87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U
M8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I
M<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M
M=7-T(&UA=&-H+@!087-T($5V96YT<R!,:7-T`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&%T=&5R;@!096YD:6YG(%-I9VYU<',Z`%!E;W!L
M90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUA;F5N
M=&QY(&1E;&5T92!T:&ES(&5V96YT/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@
M(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO
M;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M
M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C
M86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE
M(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T
M96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E
M860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H
M92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R=&%L
M($]P=&EO;G,`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R
M93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M`%!R979I;W5S($1A>0!0<F5V:6]U<R!7965K`%!R979I;W5S(&1A>0!0<F5V
M:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L
M96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0
M=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF
M;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R
M>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I
M;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN
M(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E8W5R(%5N=&EL`%)E8W5R<F5N8V4`4F5C=7)R96YC92!$871A`%)E
M8W5R<F5N8V4@16YD($1A=&4`4F5C=7)R96YC92!);G1E<G9A;`!296-U<G)E
M;F-E(%1Y<&4`4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W
M965K;'D`4F5C=7)S('EE87)L>0!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2
M969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H
M(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO
M860`4F5M87)K<P!296UI;F1E<CH@)7,`4F5M;W1E($-A;&5N9&%R<P!296UO
M=&4@0V%L96YD87)S.@!296UO=&4@4V5R=F5R<P!296UO=&4@4W5B<V-R:7!T
M:6]N(%523`!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3H`4F5M;W9E`%)E;6]V92`E<P!296UO=F4@071T96YD964`4F5M;W9E
M($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E
M('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F
M<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`
M4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O<G1E9"!O
M;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R!D96QE=&5S(&%L;"!E;G1R:65S
M(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SX`4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9`!2
M97%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@071T96YD965S`%)E<75I<F5D($9I96QD`%)E
M<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S970@
M=&\@1&5F875L=',`4F5S<&]N<V4`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L
M=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N
M:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`
M4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@
M365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L
M;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA
M`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R
M<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4
M;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%T=7)D87D`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!!<R!.
M97<`4V%V92!!='1E;F1E97,`4V%V92!%=F5N=`!3879E($]P=&EO;G,`4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C
M:"!#86QE;F1A<G,`4V5A<F-H($5N9VEN97,`4V5A<F-H(%)E<W5L=',`4V5A
M<F-H(&9O<B!C86QE;F1A<G,@8V]N=&%I;FEN9SH`4V5L96-T($9I;&5S`%-E
M;&5C="!A(&-A;&5N9&%R('1O(&5D:70`4V5L96-T(&$@9&%T90!396QE8W0@
M82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E
M<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!C
M86QE;F1A<G,@=&\@9&ES<&QA>3H`4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I
M;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C
M:&]O<V4@9&5F875L="!V:65W+@!396QE8W0@;F]N90!396QE8W0@=&AE(&-A
M;&5N9&%R('1O(&EM<&]R="!T;SH`4V5L96-T('1H92!C86QE;F1A<BAS*2!T
M;R!E>'!O<G0@9G)O;0!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!3
M96QE8W0@=&AE(&9I<G-T('=E96MD87DZ`%-E;&5C="!T:&4@9F]R;6%T(&]F
M('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!S<&%N('1O('-H
M;W<Z`%-E;&5C="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N('-T87)T=7`Z`%-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=VAI8V@@979E;G1S
M('1O('-H;W<@:6X@=&AE('!O<G1A;"X`4V5L96-T('EO=7(@8V]L;W(@<V-H
M96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O
M8FQE;2!297!O<G0`4V5N9"!335,`4V5N9"!A(&-A;F-E;"!N;W1I9FEC871I
M;VX@=&\@86QL(&%T=&5N9&5E<R!W:&5N(&1E;&5T:6YG('1H:7,@979E;G0`
M4V5N9"!A;B!E;6%I;"!T;R`E<P!396YD('5P9&%T97,O:6YV:71A=&EO;G,@
M=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V96YT`%-E;F5G
M86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!3
M97)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B
M;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N
M<P!3970`4V5T(&5N9"!D871E`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`
M4V5T(')E8W5R<F5N8V4@96YD(&1A=&4`4V5T('-T87)T(&1A=&4`4V5T('5P
M(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@
M>6]U<B!P;W)T86PN`%-E="!Y;W5R(&9R964O8G5S>2!C86QE;F1A<G,@86YD
M('EO=7(@;W=N(&%N9"!O=&AE<B!U<V5R<R<@9G)E92]B=7-Y(&]P=&EO;G,N
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B``4V5Y8VAE;&QE<P!3:&%R92!N;W0@9F]U;F0Z("5S`%-H87)E9"!#
M86QE;F1A<G,`4VAA<F5D($-A;&5N9&%R<SH`4VAO<'!I;F<`4VAO<G0@4W5M
M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\`4VAO=P!3:&]W($-A;&5N9&%R`%-H;W<@8V%T96=O<GD@;&5G96YD
M/P!3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN
M(&-A;&5N9&%R('9I97=S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VXN`%-H;W<@9'5E('1A<VMS(&EN('1H92!C86QE;F1A<C\`4VAO=R!F
M<F5E+V)U<WD@;&5G96YD/P!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO
M9V=I;F<@:6X_`%-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M
M('-E=#\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME
M<@!3:&]W('-H87)E9"!C86QE;F1A<G,@<VED92UB>2US:61E/P!3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&%S:W,@=7-I;F<@8V%T
M96=O<GD@8V]L;W)S/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9P!3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C:"!D87D@:6X@=V5E
M:R!V:65W<S\`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H
M;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR
M:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@
M=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N
M871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N
M8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H
M;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N
M;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N
M($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L
M96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@
M<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P
M;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA
M;FMA`%-T85]R=`!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@1&%T90!3=&%R
M="!/;@!3=&%R="!4:6UE`%-T87)T('EE87(`4W1A=%]U<P!3=&%T92!O<B!0
M<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`
M4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N
M=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C
M8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E
M(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E
M<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N9&%Y`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES
M93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN
M86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`
M4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y
M;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L
M:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M
M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE
M(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@
M;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E
M<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!496YT871I
M=F4`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@
M*%1)4RTV,C`I`%1H86EL86YD`%1H92!%9&ET($%T=&5N9&5E<R!S8W)E96X@
M:7,@;F\@;&]N9V5R('!R97-E;G0N($5X:71I;F<N`%1H92!&5%`@97AT96YS
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D
M:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B
M92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L
M;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N
M9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U
M('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL
M>0!4:&4@8V%L96YD87(@(B5S(B!C86YN;W0@8F4@9&5L971E9"X`5&AE(&-A
M;&5N9&%R("(E<R(@:&%S(&)E96X@8W)E871E9"X`5&AE(&-A;&5N9&%R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E
M96X@<F5N86UE9"!T;R`B)7,B+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E
M;B!S879E9"X`5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S
M`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R
M>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I
M;VXN`%1H92!E;F0@9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T
M(&1A=&4N`%1H92!E=F5N="`B)7,B(&AA<R!B965N(&%D9&5D('1O("(E<R(@
M8V%L96YD87(L('=H:6-H(&ES(&]N("5S(&%T("5S+@!4:&4@979E;G0@(B5S
M(B!H87,@8F5E;B!D96QE=&5D(&9R;VT@(B5S(B!C86QE;F1A<BP@=VAI8V@@
M=V%S(&]N("5S(&%T("5S+@!4:&4@979E;G0@(B5S(B!H87,@8F5E;B!E9&ET
M960@;VX@(B5S(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%1H
M92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S
M96YT+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N
M`%1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@
M9F]L;&]W:6YG(&ES(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T
M:&4@979E;G0Z`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C
M:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C
M<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E
M<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I
M;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E
M;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@
M=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY
M`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV
M96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L
M87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H
M87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F
M(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I
M>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA
M<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R97%U
M97-T('=A<R!I;F-O;7!L971E+B!3;VUE('!A<F%M971E<G,@=&AA="!A<F4@
M;F5C97-S87)Y('1O(&%C8V5P="!O<B!D96-L:6YE(&%N(&5V96YT(&%R92!M
M:7-S:6YG+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C
M:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@
M9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E
M9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H
M92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S
M=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H
M92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@
M9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@979E;G1S
M(&UA=&-H:6YG('1H92!C=7)R96YT(&-R:71E<FEA+@!4:&5R92!A<F4@;F\@
M;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA
M<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H
M87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S
M(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V
M:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A
M<R!A;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@861D:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S
M(&%N(&5R<F]R(&5D:71I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N`%1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H
M:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES
M(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C
M="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A
M;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F
M('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AI<R!M97-S86=E('=A<R!W<FET
M=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O
M=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E
M<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI
M<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:'5R<V1A>0!4:6-K
M971S`%1I;64`5&EM92!3<%]A;@!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T
M`%1I;64@<V5L96-T:6]N`%1I;64@<W!A;@!4:6UO<BU,97-T90!4:71?;&4`
M5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@
M:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@
M*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3
M;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A
M;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R
M=64@;W(@9F%L<V4`5'4`5'5E<V1A>0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S`%1U=F%L=0!4>7!E`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN
M9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R
M;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET
M:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<P!5;F%B;&4@=&\@9&5L971E
M("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE
M('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D
M(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN
M`%5N86)L92!T;R!R96YA;64@(B5S(CH@)7,`56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<F5T<FEE=F4@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<P!5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD
M;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N
M:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!#;VYT96YT+51Y
M<&4Z("5S`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S
M`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!D871E9#H@)7,N`%5P9W)A
M9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@
M;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E
M;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($EN=&5R
M9F%C90!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E
M<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L
M<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T
M:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU
M97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E
M<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@
M2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE
M=R!$87D`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I
M<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I
M<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510
M`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E
M`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E
M871H97(N8V]M`%=E8@!796(@4VET90!7961N97-D87D`5V5E:P!7965K("5D
M`%=E96LH<RD`5V5E:VQY`%=E96ML>3H@4F5C=7)S(&5V97)Y`%=E;&-O;64`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ
M*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/P!7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V
M:65W<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\`5VAA
M="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@<W1A<G0L('=H96X@
M=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/P!7:&5R96ES($%U<W1R86QI
M82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N
M:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED
M=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E
M9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5V]R:R!7965K`%=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N
M`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`
M6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO
M;G,`65D`65E960!986AO;R$@;6%P`%EE87(`665A<FQY`%EE87)L>3H@4F5C
M=7)S(&5V97)Y`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!E=F5N=',N`%EO=2!A<F4@;F]T(&%N(&%T=&5N
M9&5E(&]F('1H92!S<&5C:69I960@979E;G0N`%EO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N`%EO=2!C86X@;VYL>2!U<V4@=&AI<R!F;W)M(&9R;VT@=&AE
M($5D:70@071T96YD965S('-C<F5E;BX`66]U(&-A;FYO="!H879E('1H92`G
M7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N
M>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S
M<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@:&%V92!A;B!E;6%I
M;"!A9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S;VYA;"!);F9O<FUA
M=&EO;B!/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S:&5R925S(&)E9F]R
M92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT+@!9;W4@9&\@;F]T
M(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O("5S+@!9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE
M8W1E9"!C86QE;F1A<BX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M9&5L971E('1H:7,@979E;G0N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N
M('1O(&5D:70@=&AI<R!E=F5N="X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+@!9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BX`66]U
M(&AA=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI
M<R!E=F5N="X`66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E8VQI;F5D(&%T=&5N
M9&5N8V4@=&\@=&AI<R!E=F5N="X`66]U(&AA=F4@=&5N=&%T:79E;'D@86-C
M97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT+@!9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I
M=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),
M('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@
M8V%L96YD87(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%N(&%D
M9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@
M9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R
M(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P
M96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A
M(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET
M86QI86X@<&AO;F4@;G5M8F5R`%EO=2!R97%U97-T960@=&\@8F4@;F]T:69I
M960@=VAE;B!E=F5N=',@87)E(&%D9&5D('1O('EO=7(@8V%L96YD87)S+@!9
M;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!D
M96QE=&5D(&9R;VT@>6]U<B!C86QE;F1A<G,N`%EO=2!R97%U97-T960@=&\@
M8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R(&-A
M;&5N9&%R<RX`66]U(')E<75E<W1E9"!T;R!B92!R96UI;F1E9"!A8F]U="`E
M<RP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%EO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E
M<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@
M26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U
M<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@
M=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`
M66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.@!9;W5R(&1E9F%U;'0@8V%L96YD87(`66]U<B!D969A=6QT(&ED
M96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET
M>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S
M:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@
M<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A
M8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=
M`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L
M:6YE<UT`6U5N;F%M960@979E;G1=`%ML:6YE("5S(&]F("5S70!?061M:6YI
M<W1R871I;VX`7T%L87)M`%]"87-I8R!396%R8V@`7T-,20!?1&%T851R964`
M7T1E;&5T92!2;W<`7T5D:70`7T=O=&\`7T=R;W5P<P!?2&5L<`!?26UA9V4@
M4')O<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&]G(&EN`%],;V<@;W5T
M`%]-;V1I9GD@3&EN:RXN+@!?37D@0V%L96YD87)S`%].97<@179E;G0`7T]P
M=&EO;G,`7U!E<FUI<W-I;VYS`%]0<FEN=`!?4F5M;W9E($QI;FLN+BX`7U-E
M87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U1O9&%Y`%]5<V5R
M<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8F5F;W)E('1H92!E
M=F5N="!S=&%R=',`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L
M:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@
M<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!D87D`9&%Y
M*',I`&1A>7,`961I=`!E;G1R>2!N;W0@9F]U;F0`979E;G1S+F-S=@!E=F5N
M=',N:6-S`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN
M`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@
M97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI
M;F<@25-/+@!M;0!M;VYT:"AS*0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@
M>65T(&EM<&QE;65N=&5D`&YO=&5P860`;VX@)7,@870@)7,`;VX@=&AE('-A
M;64@9&%T90!O;B!T:&4@<V%M92!W965K9&%Y`'!E<F-E;G0`<&5R;6ES<VEO
M;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I
M;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E
M;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES
M=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%L96YD
M87(O:4-A;&5N9&%R`'9#87)D`'9%=F5N="!N;W0@9F]U;F0N`'<Z`'=E871H
M97(N8V]M`'=E96L`=V5E:RAS*2!O;CH`=V5E:W,`>65A<BAS*0!0<F]J96-T
M+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`R+C`M8W9S"E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`V+3`R+3$T(#$S.C,R*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-BTP,BTQ-"`Q,3HS-RLP,3`P"DQA<W0M5')A;G-L871O<CH@36%N=65L(%`N
M($%Y86QA(#QM87EA;&%`=6YE>"YE<SX*3&%N9W5A9V4M5&5A;3H@:3$X;D!L
M:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([
M('!L=7)A;#TH;B`A/2`Q*3L*`"`H:&%C92`E<R!D[6%S*0`@*$%C8V5D:65N
M9&\@82`E<RD`("AE;B`E<R!D[6%S*0`@*&AO>2D`("AM8?%A;F$I`"`H87EE
M<BD`96X@`"(E<R(@;F\@97,@=6X@9&ER96-T;W)I;RX`(B5S(B!N;R!E<R!U
M;F$@96QE8V-I\VX@=N%L:61A+@!.;R!S92!H82!C;VYF:6=U<F%D;R`B)7,B
M(&5N(&5L(')E9VES=')O(&1E($AO<F1E+@!.;R!S92!E;F-O;G1R\R!E;"!G
M96YE<F%D;W(@9&4@X7)B;VQE<R!D92`B)7,B+@!392!H82!A\6%D:61O("(E
M<R(@86P@<VES=&5M82!D92!G<G5P;W,N`%-E(&AA(&'Q861I9&\@(B5S(B!A
M;"!S:7-T96UA(&1E('!R:79I;&5G:6]S+@!.;R!S92!H82!C<F5A9&\@(B5S
M(CH@)7,N`%5S861O<R`E+C)F34(@9&4@)2XR9DU"('!E<FUI=&ED;W,@*"4N
M,F8E)2D`)60@)7,@>2`E<P!%;F-O;G1R861A<R`E9"!A9V5N9&%S`%%U961A
M;B`E9"!D[6%S(&AA<W1A('%U92!E>'!I<F4@;&$@8V]N=')A<V7Q82X`)60@
M86-O;G1E8VEM:65N=&]S`"5D('!R;V[S<W1I8V]S(&1I87)I;W,`)7,@+2!!
M=FES;P`E<R!D[6$H<RD@)7,@:&]R82AS*2`E<R!M:6YU=&]S`$AU96QL82!D
M:6=I=&%L(&1E("5S`"5S($M"`"5S(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM
M:65N=&\@+2!#;VYF:7)M86-I\VX`0V]N9FEG=7)A8VGS;B!D92`E<P!&:7)M
M82!D92`E<P!!8W5E<F1O<R!D92!L:6-E;F-I82!D92`E<P!982!E>&ES=&4@
M)7,N`"5S(&$@;&%S("5S("5S`"5S(&%S:7-T96YT97,`16P@87)C:&EV;R`E
M<R!S92!H82!I;7!O<G1A9&\@<V%T:7-F86-T;W)I86UE;G1E`"5S(&5S=.$@
M<')E<&%R861O('!A<F$@<F5A;&EZ87(@;&%S(&]P97)A8VEO;F5S(&1E(&UA
M;G1E;FEM:65N=&\@<V5L96-C:6]N861A<RY!8W1I=F4@;&%S(&-A<VEL;&%S
M(&1E(&QA<R!O<&5R86-I;VYE<R!Q=64@9&5S96$@96IE8W5T87(@96X@97-T
M82!O8V%S:?-N+@!(86-E(&9A;'1A("5S`"5S(&UI;G5T;W,`3F\@<V4@:&$@
M96YC;VYT<F%D;R`E<RX`)7,@86P@)7,@9&4@)7,`1&ER96-C:6]N97,@9&4@
M)7,`06=E;F1A(&1E("5S`$QI8G)E=&$@9&4@;F]T87,@9&4@)7,`5&%R96%S
M(&1E("5S`"5S.B`E<P`E<SH@17-T92!M96YS86IE('!U961E('%U92!N;R!P
M<F]C961A(&1E('%U:65N('!A<F5C92!S97(N($5V:71E('-E9W5I<B!C=6%L
M<75I97(@=NUN8W5L;R!I;F-L=>UD;R!O('-U;6EN:7-T<F%R(&-U86QQ=6EE
M<B!I;F9O<FUA8VGS;B!P97)S;VYA;"!A;"!R96UI=&5N=&4N`"A0=6QS92!E
M;"!N;VUB<F4@9&5L(&-A;&5N9&%R:6\@<&%R82!C;VYM=71A<B!S=2!V:7-I
M8FEL:61A9"!E;B!L82!V96YT86X@<')I;F-I<&%L*0`J($%G<F5G87(@Z7-T
M;W,@:&%C:65N9&\@8VQI8R!E;B!!\6%D:7(@*@`J(%!O<B!F879O<BP@<V5L
M96-C:6]N92!L82AS*2!D:7)E8V-I\VXH97,I("H`+"!V96YT;W-O(``L('9E
M;G1O<V\@)7,@)7,`+"!V87)I86)L92!D92`E<R!A("5S`"TM('-E;&5C8VEO
M;F%R("TM`#$@87-I<W1E;G1E`#$@86-O;G1E8VEM:65N=&\`,2!H;W)A`$9O
M<FUA=&\@9&4@,3(@:&]R87,`,34@;6EN=71O<P`R,"!M:6YU=&]S`$9O<FUA
M=&\@9&4@,C0@:&]R87,`,C0@:&]R87,`,S`@;6EN=71O<P`\06YT97)I;W(`
M/'-T<F]N9SY!<VES=&5N=&5S/"]S=')O;F<^("AO<&-I;VYA;"D`/'-T<F]N
M9SY$97-C<FE?<&-I\VX\+W-T<F]N9SX@*&]P8VEO;F%L*0`\<W1R;VYG/E!A
M;&%B<F%S(&-L879E/"]S=')O;F<^("AO<&-I;VYA;"D`/'-T<F]N9SY297!E
M=&EC:?-N/"]S=')O;F<^("AO<&-I;VYA;"D`4&%R82!E<W1E(&)L;W%U92!H
M86-E(&9A;'1A('5N(&UO=&]R(&1E(&)A<V4@9&4@9&%T;W,N`%-E(&AA('!R
M;V1U8VED;R!U;B!E<G)O<B!I<G)E<&%R86)L90!(86-E(&9A;'1A('5N82!C
M;&%V92!01U`@</IB;&EC82!P87)A(&-I9G)A<B!U;B!M96YS86IE+@!(86-E
M(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82!P87)A(&-O;7!R;V)A<B!U
M;B!M96YS86IE(&9I<FUA9&\N`$AA8V5N(&9A;'1A('5N82!C;&%V92!01U`@
M</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R87-E(&-L
M879E('!A<F$@9&5S8VEF<F%R('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N
M82!C;&%V92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@
M=6YA(&9R87-E(&-L879E('!A<F$@9FER;6%R('5N(&UE;G-A:F4N`$AA8V5N
M(&9A;'1A('5N82!C;&%V92!3+TU)344@</IB;&EC82P@=6YA(&-L879E(%,O
M34E-12!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9&5S8VEF<F%R
M('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V92!3+TU)344@</IB
M;&EC82P@=6YA(&-L879E(%,O34E-12!P<FEV861A('D@=6YA(&9R87-E(&-L
M879E('!A<F$@9FER;6%R('5N(&UE;G-A:F4N`$AA8V4@9F%L=&$@=6YA(&-L
M879E(%--24U%('#Z8FQI8V$@<&%R82!C:69R87(@=6X@;65N<V%J92X`04T`
M3G5B97,@;6%T:6YA;&5S`$QI9V5R82!L;'5V:6$@;6%T:6YA;`!,;'5V:6$@
M;6%T:6YA;`!!9W5A8V5R;W,@;6%T:6YA;&5S`$%G=6%C97)O(&UA=&EN86P@
M9&4@;FEE=F4`04TO4$T`240@9&4@05!)`$%C97)C82!D96P@961I=&]R`$%C
M97)C82!D92XN+@!);F9E<FEO<B!!8G,N`$5N(&UE9&EO($%B<RX`06-E<'1A
M9&$`4V4@:&$@9&5N96=A9&\@96P@86-C97-O(&%L(&-R96%R(&5L(&1I<F5C
M=&]R:6\@5D93+@!392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@
M96P@87)C:&EV;R!61E,N`$ED96YT:61A9`!#;VYT<F%S9?%A(&1E(&%C8V5S
M;P!)9&5N=&ED860@8FQO<75E861A+@!#;VYT86)I;&ED860`0OIS7W%U961A
M(&%V86YZ861A`$'Q861I<@!!\6%D:7(@9W)U<&\@9&5S8V5N9&EE;G1E`$'Q
M861I<B!P<FEV:6QE9VEO(&1E<V-E;F1I96YT90!!\6%D:7(@06-O;G1E8VEM
M:65N=&\`0?%A9&ER(&%Q=>TZ`$'Q861I<B!G<G5P;P!!\6%D:7(@<')I=FEL
M96=I;P!!\6%D:7(@82`B)7,B('5N(&=R=7!O(&1E<V-E;F1I96YT90!!\6%D
M:7(@82`B)7,B('5N('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E`$'Q861I<B!U
M;F$@86=E;F1A(')E;6]T80!!\6%D:7(@=6X@86-O;G1E8VEM:65N=&\`0?%A
M9&ER('5N('5S=6%R:6\Z`$'Q861I<B!A<VES=&5N=&5S`$'Q861I<B!C;VQU
M;6YA`$'Q861I<B!M:65M8G)O<P!!\6%D:7(@<&%R`$'Q861I<B!E;"!M96[Z
M("5S(&-O;6\@<&%N96P@;&%T97)A;"!D92!-;WII;&QA`$'Q861I<B!A(&QA
M<R!D:7)E8V-I;VYE<SH`0?%A9&ER(&$@87-I<W1E;G1E<P!!\6%D:7(@82!L
M87,@9&ER96-C:6]N97,Z`$'Q861I<B!U<W5A<FEO`%-E(&AA(&'Q861I9&\@
M(B5S(B!A;"!S:7-T96UA+"!P97)O(&YO('-E('!U961E(&'Q861I<B!L82!I
M;F9O<FUA8VGS;B!A9&EC:6]N86P@9&4@86QT83H@)7,N`%-E(&AA(&'Q861I
M9&\@(B5S(B!A;"!S:7-T96UA+B!982!P=65D92!I;FEC:6%R(&QA('-E<VGS
M;BX`3&$@861I8VGS;B!D92!U<W5A<FEO<R!E<W3A(&1E<VAA8FEL:71A9&$N
M`$1I<F5C8VGS;@!,:6)R971A(&1E(&1I<F5C8VEO;F5S`$%D;6EN:7-T<F%D
M;W(@+2!D969I;F4@<')I=FEL96=I;W,@9&4@;W1R;W,@=7-U87)I;W,`061M
M:6YI<W1R86-I\VX`06YU;F-I;W,`0OIS<75E9&$@879A;GIA9&$`069G86YI
M<W3A;@!!;&%R;6$`06QA<FUA("5D(&3M87,@86YT97,`06QA<FUA("5D(&AO
M<F%S(&%N=&5S`$%L87)M82`E9"!M:6YU=&]S(&%N=&5S`$%L87)M82`E9"!S
M96UA;F%S(&%N=&5S`$%L87)M82`Q(&3M82!A;G1E<P!!;&%R;6$@,2!H;W)A
M(&%N=&5S`$%L87)M82`Q(&UI;G5T;R!A;G1E<RD`06QA<FUA(#$@<V5M86YA
M(&%N=&5S`$9E8VAA(&1E(&%L87)M80!);G1E<G9A;&\@9&4@;&$@86QA<FUA
M("AM:6YU=&]S*0!(;W)A(&1E(&QA(&%L87)M80!!;&)A;FEA`$%R9V5L:6$`
M06QI87,`06QI;F5A<@!!;&EN96%C:?-N.@!4;V1A<P!4;V1O<R!L;W,@87-I
M<W1E;G1E<P!4;V1O<R!L;W,@=7-U87)I;W,@875T96YT:69I8V%D;W,`06-O
M;G1E8VEM:65N=&]S(&9U='5R;W,`5&]D;W,@;&]S(&=R=7!O<P!!8V]N=&5C
M:6UI96YT;W,@<&%S861O<P!4;V1O<R!L;W,@<')I=FEL96=I;W,`5&]D87,@
M;&%S('9I<VEB;&5S`%1O9&\@96P@9.UA`$%C;VYT96-I;6EE;G1O('!O<B!T
M;V1O(&5L(&3M80!4;V1O<R!L;W,@86-O;G1E8VEM:65N=&]S`%1O9&]S(&QO
M<R!L861O<P!097)M:71I<B!V87)I87,@9&ER96-C:6]N97,`OU!E<FUI=&ER
M(&-O;F9I9W5R86-I\VX@9&4@=&EP;R!D92!L:7-T87,@;W)D96YA9&%S/P!9
M82!E>&ES=&4`06-C97-O($E-4U`@86QT97)N871I=F\`0VQA=F4@24U34"!A
M;'1E<FYA=&EV80!5<W5A<FEO($E-4%,@86QT97)N871I=F\`1&ER96-C:?-N
M(&5L96-T<O-N:6-A(&%L=&5R;F%T:79A`%!L86YT:6QL87,@86QT97)N871I
M=F%S`%1E>'1O(&%L=&5R;F%T:79O`%-A;6]A($%M97)I8V%N80!392!H82!I
M;F1I8V%D;R!U;B!V86QO<B!I;&5G86PN`%-E(&AA('!R;V1U8VED;R!U;B!E
M<G)O<B!D97-C;VYO8VED;RX`06YD;W)R80!!;F=O;&$`06YG=6EL80!0<F]X
M>2!A;O-N:6UO`%)E<W!U97-T80!!;G3A<G1I9&$`06YT:6=U82!Y($)A<F)A
M9&]S`$-U86QQ=6EE<F$`07!L:6-A8VGS;@!,:7-T82!D92!A<&QI8V%C:6]N
M97,`3&$@87!L:6-A8VGS;B!E<W3A(&QI<W1A+@!!<&QI8V%R(&$@<F5C=7)S
M;W,@8V]M<&%R=&ED;W,@9&5S8V5N9&EE;G1E<P!!<')O8F%R`%1A;6'Q;R!A
M<')O>&EM861O`$%B<FEL`$%RX6)I9V\@*%=I;F1O=W,M,3(U-BD`5&%M8?%O
M(&1E;"!A<F-H:79O`$YO;6)R92!D96P@87)C:&EV;P"_17-T82!S96=U<F\@
M9&4@<75E(&1E<V5A(&5L:6UI;F%R(&QA('-O;&EC:71U9"!D92!A;'1A(&1E
M("5S/P"_17-TX2!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R("(E<R(@
M>2!T;V1O<R!S=7,@<W5B9W)U<&]S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE
M;FEO("A!4DU30TE)+3@I`$%R=&4`07)U8F$`27-L82!!<V-E;G-I\VX`1W+A
M9FEC;W,@07-C:6D`4F5G:?-N(&1E($%S:6$O4&%C[69I8V\`OU-O;&EC:71A
M<B!C;VYF:7)M86-I\VX@86YT97,@9&4@<F5A;&EZ87(@;W!E<F%C:6]N97,@
M9&4@;6%N=&5N:6UI96YT;S\`0V]L=6UN87,@9&4@87-I9VYA8VGS;@!!(&QA
M<P!392!A9&IU;G1A('5N(&%R8VAI=F\@:4-A;&5N9&%R(&-O;B!MX7,@:6YF
M;W)M86-I\VX@<V]B<F4@96P@86-O;G1E8VEM:65N=&\N(%-I('-U(&-L:65N
M=&4@9&4@8V]R<F5O('-O<&]R=&$@<V]L:6-I='5D97,@:51I<"P@<'5E9&4@
M=71I;&EZ87(@96P@87)C:&EV;R!P87)A(&%C='5A;&EZ87(@9N%C:6QM96YT
M92!S=2!C;W!I82!L;V-A;"!D96P@86-O;G1E8VEM:65N=&\N`$EN=&5N=&$@
M96QI;6EN87(@=6X@9W)U<&\@:6YE>&ES=&5N=&4N`$EN=&5N=&$@96QI;6EN
M87(@=6X@<')I=FEL96=I;R!I;F5X:7-T96YT92X`26YT96YT82!M;V1I9FEC
M87(@=6X@<')I=FEL96=I;R!I;F5X:7-T96YT92X`26YT96YT82!M;V1I9FEC
M87(@=6X@<F5C=7)S;R!C;VUP87)T:61O(&EN97AI<W1E;G1E+@!!<VES=&5N
M8VEA`$%S:7-T96YT97,`071R:6)U=&]S`$%G;W-T;P!!=7-T<F%L:6$`075S
M=')I80!!=71H7V-Y<G-Q;#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N
M(&EM87`@;F5C97-A<FEA+@!!=71H7V-Y<G5S.B!%;"!M;W1O<B!C87)E8V4@
M9&4@;&%S(&-A<&%C:61A9&5S(&YE8V5S87)I87,N`$%U=&A?8WER=7,Z($YO
M('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!I;6%P(&YE8V5S87)I82X`075T
M:%]F='`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!&5%`@;F5C97-A
M<FEA+B!#;VUP:6QE(%!(4"!C;VX@;&$@;W!C:?-N("TM96YA8FQE+69T<"X`
M075T:%]I;6%P.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@24U!4"!N
M96-E<V%R:6$N`$%U=&A?:W)B-3H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS
M:?-N(&MR8C4@;F5C97-A<FEA+@!!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T
M861A(&QA(&%D:6-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R
M>0!!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&5L:6UI;F%C:?-N
M(&1E('5S=6%R:6]S(&1E($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!.
M;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@3$1!4"!N96-E<V%R:6$N`$%U
M=&A?;&1A<#H@3F\@<V4@<'5E9&4@8?%A9&ER(&5L('5S=6%R:6\@)7,N(,ES
M=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(Z(`!!=71H7VQD87`Z($EN
M8V%P87H@9&4@96QI;6EN87(@96P@=7-U87)I;R`E<P!!=71H7VQD87`Z($EN
M8V%P87H@9&4@86-T=6%L:7IA<B!E;"!U<W5A<FEO("5S`$%U=&A?;&1A<#H@
M3F\@97-TX2!S;W!O<G1A9&$@;&$@86-T=6%L:7IA8VGS;B!D92!U<W5A<FEO
M<R!D92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;6-A;#H@3F\@<V4@96YC;VYT
M<O,@;&$@97AT96YS:?-N($U#04P@;F5C97-A<FEA+@!!=71H7W-M8F%U=&@Z
M($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!S;6)A=71H(&YE8V5S87)I
M82X`1F%L;/,@;&$@875T96YT:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!)
M34%0+@!&86QL\R!L82!A=71E;G1I9FEC86-I\VX`1F%L;/,@;&$@875T96YT
M:69I8V%C:?-N+B`E<P!%;"!S97)V:61O<B!2041)55,@:&$@<F5C:&%Z861O
M(&QA(&%U=&5N=&EF:6-A8VGS;BX`1F%L;/,@;&$@875T96YT:69I8V%C:?-N
M(&-O;B!E;"!S97)V:61O<B!&5%`N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS
M;B!C;VX@96P@<V5R=FED;W(@4TU"+@!#86UP;W,@9&ES<&]N:6)L97,Z`$%Z
M97)B86EJ86X`17AC=7-A<R!"3T9(`$9O;F1O`$-O;&]R(&1E(&9O;F1O`$-O
M;G1R87-E\6$@:V5R8F5R;W,@:6YC;W)R96-T82X`3F]M8G)E(&1E('5S=6%R
M:6\@:V5R8F5R;W,@:6YC;W)R96-T;RX`0F%H86UA<P!"86AR86EN`$+A;'1I
M8V\@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$YO('-E(&5N
M8V]N='+S(&5L(&1I<F5C=&]R:6\@8F%S92!D92!I;>%G96YE<R`B)7,B+@!,
M[6YE82!B87-E`$+Z<W%U961A('-I;7!L90!"96QA<G5S`$+I;&=I8V$`0F5L
M:7IE`$)E;FEN`$)E<FUU9&%S`$)H=71A;@!#=6UP;&5A\6]S`$YO('-E(&5N
M8V]N='+S(&5L(&)L;W%U92`B)7,B(&1E(&QA(&%P;&EC86-I\VX@(B5S(BX`
M3W!C:6]N97,@9&4@8FQO<75E`%1I<&\@9&4@8FQO<75E`$YE9W)I=&$`0F]L
M:79I80!-87)C861O<F5S`$)O<F1E`$=R;W-O<B!D96P@8F]R9&4Z`$)O<F1E
M<P!";W-N:6$@2&5R>F5G;W9I;F$`06UB;W,`0F]T<W=A;F$`26YF97)I;W(`
M27-L82!D92!";W5V970`0G)A<VEL`%1E<G)I=&]R:6\@;V-EX6YI8V\@9&4@
M;&$@26YD:6$@8G)I=.%N:6-A`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA
M`$QI<W1A(&1E<V]R9&5N861A`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$]C=7!A
M9&\`0TU3`$-20P!0=6YT;W,@9&4@9&ES=')I8G5C:?-N($-20P!!7V=E;F1A
M`%!R;W!I961A9&5S(&1E(%]C96QD82XN+@!.;R!S92!H82!F:6YA;&EZ861O
M(&5L(&EN:6-I;R!D92!L82!C86-HZ2X`05]G96YD80!!9V5N9&$`4F5S=6UE
M;B!D92!L82!A9V5N9&$`3&$@86=E;F1A('-E(&AA('-U<')I;6ED;R!S871I
M<V9A8W1O<FEA;65N=&4N`$%G96YD87,`3&%S(&%G96YD87,@=&EE;F5N('%U
M92!T96YE<B!U;B!N;VUB<F4N`$-A;&UA`$-A;6)O>6$`0V%M97+Z;@!.;R!S
M92!P=65D92!R96%J=7-T87(@;&$@8VQA=F4@875T;VWA=&EC86UE;G1E+"!P
M\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S
M:7-T96UA+@!.;R!S92!P=65D92!E<V-R:6)I<B!E;B!E;"!A<F-H:79O("(E
M<R(`3F\@<V4@<'5E9&5N(&%D;6EN:7-T<F%R(&UA;F5J861O<F5S(&1E('-E
M<VGS;B!E>'1E<FYO<RX`3F\@<V4@<'5E9&4@8V]N96-T87(@86P@<V5R=FED
M;W(@24U!4#H@)7,`3F\@<V4@<'5E9&4@8W)E87(@=6X@86-O;G1E8VEM:65N
M=&\`3F\@<V4@<'5E9&4@86)R:7(@96P@87)C:&EV;R`B)7,B+@!#86YA9.$`
M0V%N8V5L87(`0V%N8V5L87(@:6YF;W)M92!D92!P<F]B;&5M87,`0V%N8V5L
M861O`$-A;F-E;&%D;SH@)7,`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@87)C
M:&EV;R`B)7,B+@!.;R!S92!E;F-U96YT<F$@=6X@9&ER96-T;W)I;R!T96UP
M;W)A;"X`3F\@<V4@<'5E9&4@8V]N=&EN=6%R('-I;B!E;"!P87+A;65T<F\@
M)W1A<F=E=$9I;&4G+@!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!D:7)E8W1O
M<FEO("(E<R(N`$YO('-E('!U961E(&5L:6UI;F%R+"!T:65N92`E9"!D97-C
M96YD:65N=&5S+@!.;R!S92!P=65D92!R96]R9&5N87(L(&5L(&[Z;65R;R!D
M92!E;G1R861A<R!Q=64@<V4@9&5S96$@;W)D96YA<B!N;R!C;VEN8VED92!C
M;VX@;&%S(&%L;6%C96YA9&%S+@!.;R!S92!P=65D92!D:7)I9VER(&5L(&UE
M;G-A:F4@86P@;OIM97)O(&5S<&5C:69I8V%D;RX`0V%B;R!697)D90!3=6)T
M[71U;&\`4')O=F5E9&]R`%]#871E9V]R[6$`0V%T96=O<NUA<R!Y(&5T:7%U
M971A<P!#871E9V]R[6$`27-L87,@0V%I;>%N`%1E;.EF;VYO(&WS=FEL`%!R
M;W!I961A9&5S(&1E(&-E;&1A`$UA<F=E;B!D92!C96QD83H`4')O<&EE9&%D
M97,@9&4@8V5L9&$`17-P86-I861O(&1E(&-E;&1A.@!496SI9F]N;R!M\W9I
M;`!#Z6QT:6-O("A)4T\M.#@U.2TQ-"D`0V5N=')A<@!297#Z8FQI8V$@0V5N
M=')O869R:6-A;F$`175R;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I`$1E=&%L
M;&5S(&1E;"!C97)T:69I8V%D;P!0<F]P:65T87)I;R!D96P@8V5R=&EF:6-A
M9&\`4&]L[71I8V%S(&1E;"!C97)T:69I8V%D;P!#:&%D`$-A;6)I87(`0V%M
M8FEE(&QA(&-O;G1R87-E\6$`0V%M8FEA(&5L(&YO;6)R92!Y(&QA(&1I<F5C
M8VGS;B!E;&5C='+S;FEC82!V:7-I8FQE<R!A;"!L965R(&\@<F5S<&]N9&5R
M(&$@<W5S(&UE;G-A:F5S+@!,82!C;VYF:6=U<F%C:?-N(&%C='5A;"!N;R!S
M;W!O<G1A(&5L(&-A;6)I;R!D92!C;VYT<F%S9?%A<RX@4/-N9V%S92!E;B!C
M;VYT86-T;R!C;VX@96P@861M:6YI<W1R861O<B!D96P@<VES=&5M82X`1W+A
M9FEC;P!697)I9FEC87(@7W;M;F-U;&\N+BX`0VAI;&4`0VAI;F$`0VAI;F\@
M<VEM<&QI9FEC861O("A'0C(S,3(I`$-H:6YO('1R861I8VEO;F%L("A":6<U
M*0!!<&QI8V%C:?-N.@!%;&EJ82!U;F$@8V]N=')A<V7Q80!%;&EJ82!U;B!N
M;VUB<F4@9&4@=7-U87)I;P!%;&EJ82!C\VUO(&UO<W1R87(@;&%S(&9E8VAA
M<SH`16QI:F$@<VD@9&5S96$@<75E('-E(&QE(&YO=&EF:7%U96X@<&]R(&-O
M<G)E;R!E;&5C='+S;FEC;R!L;W,@86-O;G1E8VEM:65N=&]S(&YU979O<RP@
M;6]D:69I8V%D;W,@;R!E;&EM:6YA9&]S.@!%;&EJ82!S:2!D97-E82!Q=64@
M<V4@;&4@;F]T:69I<75E;B!L;W,@86-O;G1E8VEM:65N=&]S(&YU979O<RP@
M;6]D:69I8V%D;W,@;R!E;&EM:6YA9&]S+@!%;&EJ82!S:2!Q=6EE<F4@<F5C
M:6)I<B!R96-O<F1A=&]R:6]S('!O<B!C;W)R96\@9&4@;&]S(&%C;VYT96-I
M;6EE;G1O<R!C;VX@86QA<FUA<SH`4V5L96-C:6]N87(@=&EP;R!D92!E<W1I
M;&\@9&4@;&ES=&$@*'!A<F$@;&ES=&%S(&]R9&5N861A<RD`16QI:F$@;&%S
M(&QI8G)E=&%S(&1E(&1I<F5C8VEO;F5S(&5N(&QA<R!Q=64@8G5S8V%R(%52
M3',@9&4@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4N`$5L:6IA
M(&QA<R!A9V5N9&%S('%U92!Q=6EE<F4@<75E('-E(&EN8VQU>6%N(&5N(&QA
M(&EN9F]R;6%C:?-N(&1E(%1I96UP;R!$:7-P;VYI8FQE.@!%;&EJ82!L87,@
M86=E;F1A<R!A(&EN8VQU:7(@86P@9V5N97)A<B!54DQS(&1E(&EN9F]R;6%C
M:?-N(&1E('1I96UP;R!D:7-P;VYI8FQE.@!%;&EJ82!L82!A9V5N9&$@<&]R
M(&]M:7-I\VXN`$ES;&$@9&4@4&%S8W5A`$YO('-E(&5N8V]N='+S(&QA(&1E
M9FEN:6-I\VX@9&4@8VQA<V4@9&4@)7,N`$QI;7!I87(`16QI;6EN87(@971I
M<75E=&%S($U33V9F:6-E`$)O<G)A<B!C;VYS=6QT80!";W)R87(@=&]D;W,@
M;&]S(&%S:7-T96YT97,`0F]R<F%R('5S=6%R:6\Z("5S`$)O<G)A<B!U<W5A
M<FEO`$)O<G)A<B!D871O<R!D96P@=7-U87)I;P!$97-P96IA9&\@=&%R9.UO
M`$AA9V$@8VQI8VL@<&%R82!S96=U:7(`0VQI8VMA=&5L;"!P;W(@2%144`!#
M97)R87(@=F5N=&%N80!#97)R87(@=F5N=&%N80!.=6)E<P!.=6)E<R!T96UP
M<F%N87,`;G5B;W-O`$ES;&%S(&1E(&-O8V]S("A+965L:6YG*0!/8W5L=&%R
M(&)A<G)A(&QA=&5R86P`0V]L87!S87(@8F]R9&5S`$-O;&]M8FEA`$-O;&]R
M`%-E;&5C=&]R(&1E(&-O;&]R`%-E;&5C8VGS;B!D92!C;VQO<@!#;VQU;6YA
M<SH`5.UT=6QO<R!D92!L87,@8V]L=6UN87,`0_-M:6-S`%9A;&]R97,@<V5P
M87)A9&]S('!O<B!C;VUA<P!#;VUA;F1O`$EN=.ER<'(N(&-O;6%N9&]S`$-O
M;65N=&%R:6\`3F]M8G)E(&-O;?IN`$-O;6]R;W,`0V]M<&'Q[6$`3W)D96YA
M9&]R97,`0V]N9&EC:?-N`$-O;F1I8VEO;F5S`$1I9F5R96YC:6%S(&1E(&QA
M(&-O;F9I9W5R86-I\VX`0V]N9FEG=7)A8VGS;B!P87)A('-I;F-R;VYI>F%C
M:?-N(&-O;B!01$%S+"!-\W9I;&5S(&-O;B!A9V5N9&$@>2!/=71L;V]K+@!,
M82!C;VYF:6=U<F%C:?-N(&5S=.$@9&5S86-T=6%L:7IA9&$N`$-O;F9I9W5R
M87(@)7,`0V]N9FER;6%R(&-O;G1R87-E\6$`OT-O;F9I<FUA<B!E;&EM:6YA
M8VGS;B!D92!A8V]N=&5C:6UI96YT;W,_`$-O;F9I<FUA9&\`0V]N9V\`0V]N
M9V\L(%)E</IB;&EC82!$96UO8W+A=&EC82!D96P`1F%L;/,@;&$@8V]N97AI
M\VXN`$9A;&SS(&QA(&-O;F5X:?-N.B``4V4@:&$@<F5C:&%Z861O(&QA(&-O
M;F5X:?-N(&%L('-E<G9I9&]R(&1E(&-L879E<R!P^F)L:6-O+@!392!H82!R
M96-H87IA9&\@;&$@8V]N97AI\VX@86P@<V5R=FED;W(@9&4@8VQA=F5S('#Z
M8FQI8V\N($UO=&EV;SH@)7,@*"5S*0!(82!F86QL861O(&QA(&-O;F5X:?-N
M(&%L('-E<G9I9&]R($944"X`0V]N=&%C=&]S`%-E(&AA;B!A\6%D:61O(&-O
M<G)E8W1A;65N=&4@;&]S(&-O;G1A8W1O<R!A('-U<R!D:7)E8V-I;VYE<P!4
M:7!O(&1E(&-O;G1E;FED;R!D96P@87)C:&EV;R!C;VUP<FEM:61O.B``0V]N
M=&5N:61O(&1E("(E<R(`0V]N=&EN=6%R`$ES;&%S($-O;VL`0V]O:VEE`$-O
M<&EA<@!&86QL\R!L82!C;W!I83H@)7,`0V]P:6%R('-E;&5C8VGS;@!#;W!I
M92!L82!S:6=U:65N=&4@55),('!A<F$@=7-A<FQA('-I96UP<F4@<75E(&YE
M8V5S:71E('-U(%523"!D92!T:65M<&\@9&ES<&]N:6)L93H`240@9&4@8V]S
M=&4`0V]S=&$@4FEC80!#;W-T82!D92!-87)F:6P`3F\@<V4@<'5E9&4@8VEF
M<F%R(&5L(&UE;G-A:F4@;65D:6%N=&4@4$=0.B``3F\@<V4@<'5E9&4@9FER
M;6%R(&5L(&UE;G-A:F4@;65D:6%N=&4@4$=0.B``3F\@<V4@<'5E9&4@8VEF
M<F%R(&5L(&UE;G-A:F4@;65D:6%N=&4@4R]-24U%`$YO('-E('!U961E(&9I
M<FUA<B!E;"!M96YS86IE(&UE9&EA;G1E("!3+TU)344`3F\@<V4@<'5E9&4@
M8?%A9&ER(&5L(&-O;G1A8W1O+B`E<P!.;R!S92!P=65D92!E;FQA>F%R(&%L
M('-E<G9I9&]R($Q$05`N`$YO('-E('!U961E(&-O;7!R;V)A<B!E;"!S86QD
M;RX@)7,`3F\@<V4@<'5E9&4@8V]N96-T87(@86P@<V5R=FED;W(@3$1!4"X`
M3F\@<V4@<'5E9&4@8V]N96-T87(@86P@<V5R=FED;W(@(B5S(B!M961I86YT
M92!&5%`Z("5S`$YO('-E('!U961E(&-R96%R(&QA(&QI<W1A(&1E(&1I<W1R
M:6)U8VGS;BX@)7,`3F\@<V4@<'5E9&5N(&1E<V-I9G)A<B!L;W,@9&%T;W,@
M4$=0.B``3F\@<V4@<'5E9&5N(&1E<V-I9G)A<B!L;W,@9&%T;W,@4R]-24U%
M+@!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@
M<'5E9&4@96QI;6EN87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<P!.
M;R!S92!P=65D92!E;&EM:6YA<B!E;"!G=6GS;B!D92!A8W1U86QI>F%C:?-N
M(&1E(&-O;F9I9W5R86-I\VX@(B5S(BX`3F\@<V4@<'5E9&4@9&5T97)M:6YA
M<F$@;&$@9&ER96-C:?-N(&1E(&-O<G)E;R!D96P@9&5S=&EN871A<FEO+@!.
M;R!S92!P=65D92!T<F%E<B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&-O
M;7!L971A+@!.;R!S92!P=65D92!T<F%E<B!L82!L:7-T82!D92!D:7-T<FEB
M=6-I\VX@8V]M<&QE=&$N`$YO('-E('!U961E('1R865R(&QA(&QI<W1A(&-O
M;7!L971A(&1E(&QI<W1A<R!D92!D:7-T<FEB=6-I\VXN`$YO('-E('!U961E
M(&-A<F=A<B!L82!E<W1R871E9VEA("(E<R(N`$YO('-E('!U961E(&-R96%R
M(&5L(&1I<F5C=&]R:6\@(B5S(BX`3F\@<V4@<'5E9&4@;V)T96YE<B!L82!C
M;&%V92!P^F)L:6-A(&1E;"!S97)V:61O<B!D92!C;&%V97,N`$YO('-E('!U
M961E(&%B<FER("(E<R(@<&%R82!E<V-R:6)I<BX`3F\@<V4@<'5E9&4@86)R
M:7(@)7,N`$YO('-E('!U961E(&%B<FER(&5L(&WS9'5L;R!D92!T87)E87,@
M9&4@;6%N=&5N:6UI96YT;R`E<P!.;R!S92!P=65D92!A8G)I<B!E;"!D:7)E
M8W1O<FEO("(E<R(N`$YO('-E('!U961E(&QO8V%L:7IA<B!E;"!S97)V:61O
M<B!,1$%0+@!.;R!S92!P=65D92!L965R("5S+@!.;R!S92!P=65D92!R97-T
M86)L96-E<B!L82!C;VYT<F%S9?%A(&1E;"!U<W5A<FEO('-O;&EC:71A9&\N
M(%!A<G1E(&1E(&QO<R!D971A;&QE<R!O('1O9&]S+"!S;VX@:6YC;W)R96-T
M;W,N(%!R=65B92!O=')A('9E>B!O('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N
M(&5L(&%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$@<&%R82!MX7,@:6YF;W)M
M86-I\VXN`$YO('-E('!U961E(&]B=&5N97(@;&$@04-,+@!.;R!S92!P=65D
M92!O8G1E;F5R(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,N("5S`$YO('-E
M('!U961E(&]B=&5N97(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<P!.
M;R!S92!P=65D96X@;V)T96YE<B!L87,@;&ES=&%S(&1E(&1I<W1R:6)U8VGS
M;BX@)7,`3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S(&-A<&%C:61A9&5S(&1E
M;"!S97)V:61O<@!.;R!S92!P=65D92!R97-T875R87(@;&$@8V]N9FEG=7)A
M8VGS;BX`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R`B)7,B
M+@!.;R!S92!P=65D92!G=6%R9&%R(&QA(&-O;F9I9W5R86-I\VX@9&4@)7,N
M`$YO('-E('!U961E(&=U87)D87(@=6YA(&-O<&EA(&1E(&QA(&-O;F9I9W5R
M86-I\VXN`$YO('-E('!U961E(&=U87)D87(@=6YA(&-O<&EA(&1E(&QA(&-O
M;F9I9W5R86-I\VXZ("5S`$YO('-E('!U961E(&=U87)D87(@96P@9W5I\VX@
M9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N(&5N.B`B)7,B
M+@!.;R!S92!P=65D92!G=6%R9&%R(&QA(&-O<&EA("5S(&1E(&QA(&-O;F9I
M9W5R86-I\VXN`$YO('-E('!U961E(&=U87)D87(@96P@87)C:&EV;R`E<R!D
M92!C;VYF:6=U<F%C:?-N+B!0=65D92!U=&EL:7IA<B!U;F$@9&4@;&%S(&]P
M8VEO;F5S('!A<F$@<F5S=&%U<F%R(&5L(&/S9&EG;R!D92`E<R!O(&-O<&EA
M<B!M86YU86QM96YT92!A("5S(&5L(&/S9&EG;R!S:6=U:65N=&4N`$YO('-E
M('!U961E(&)U<V-A<B!E;B!E;"!S97)V:61O<B!,1$%0+@!.;R!S92!P=65D
M92!D97-V:6YC=6QA<B`B)7,B+@!.;R!S92!P=65D92!A8W1U86QI>F%R(&5L
M(&-O;G1A8W1O+B`E<P!.;R!S92!P=65D92!A8W1U86QI>F%R(&QA(&QI<W1A
M(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@<V4@<'5E9&4@97-C<FEB:7(@;&$@
M8V]N9FEG=7)A8VGS;B!D92`B)7,B.B`E<P!.;R!S92!P=65D92!L;V-A;&EZ
M87(@96P@<&%N96P@;&%T97)A;"!D92!-;WII;&QA+B!#;VUP<G5E8F4@<75E
M(&5S=.D@86)I97)T;RX`3F\@<V4@<'5E9&5N(&]T;W)G87(@86P@=7-U87)I
M;R`B)7,B(&QO<R!S:6=U:65N=&5S(&1E<F5C:&]S('!A<F$@;&$@8V%R<&5T
M82`B)7,B.B`E<P!497AT;R!C;VYT861O`%!A[7,`0W5R<V]S`$-R96%R`$-R
M96%R(&%G96YD80!!\6%D:7(`0W)E82!U;B!V[6YC=6QO`$-R96%R`$-R96%R
M('-U8F-A<G!E=&%S`$-R96%D;P!0<FEV:6QE9VEO<R!D92!C<F5A9&]R`$[Z
M;65R;R!D92!T87)J971A(&1E(&-RZ61I=&\`0W)O86-I80!#=6)A`$%C='5A
M;``T($9A<V5S(&%C='5A;&5S`%-E<VEO;F5S(&%C='5A;&5S`$AO<F$@86-T
M=6%L`%523"!A8W1U86P`57-U87)I;W,@86-T=6%L97,`5&EE;7!O(&%C='5A
M;`!#;VYD:6-I\VX@86-T=6%L.B``17-T:6QO(&%C='5A;`!097)S;VYA;&EZ
M82!L87,@=&%R96%S(&$@96IE8W5T87(@86P@:6YI8VEA<B!S97-I\VX@96X@
M)7,N`$-O<G1A<@!#;W)T87(@<V5L96-C:?-N`$-H:7!R90!#:7+M;&EC;R`H
M2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W<RTQ,C4Q*0!#:7+M;&EC;R]58W)A
M;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A($-H96-A`$1$`$133B`H=F5A(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5S+W!A8VMA9V4N9&%T86)A<V4N
M9&(N:6YT<F\M9'-N+G!H<"D`1&EA<FEA;65N=&4`1&EA<FEA;65N=&4Z(%-E
M(')E<&ET92!C861A`,%R7V)O;"!D871O<P!#;VYS=6QT82!D92!L82!B87-E
M(&1E(&1A=&]S`$9E8VAA`%-E(&AA(')E8VEB:61O(&QA(&9E8VAA`%-E;&5C
M8VGS;B!D92!F96-H80!$[6$`1.UA*',I`%]%;&EM:6YA<@!%7VQI;6EN87(@
M8V]L=6UN80!$:6-I96UB<F4`3OIM97)O<R!D96-I;6%L97,`4F5C:&%Z861A
M`%)E9'5C:7(@<V%N9W)A9&\`4&]R(&]M:7-I\VX`06=E;F1A('!O<B!O;6ES
M:?-N`$-O;&]R('!O<B!O;6ES:?-N`$ED96YT:61A9"!P;W(@;VUI<VGS;@!3
M:&5L;"!P;W(@;VUI<VGS;@!$969I;FEC:6]N97,`16QI;6EN87(`16QI;6EN
M87(@)7,`16QI;6EN87(@8V5L9&$`16QI;6EN87(`16QI;6EN87(@9W)U<&\`
M16QI;6EN87(@<F5G:7-T<F\`16QI;6EN87(@<')I=FEL96=I;P!%;&EM:6YA
M<B!Y('9A8VEA<B!M96YS86IE<P!%;&EM:6YA<B!C96QD80!%;&EM:6YA<B!C
M;VQU;6YA`$5L:6UI;F%R('!L86YT:6QL87,@86QT97)N871I=F%S(&5X:7-T
M96YT97,`16QI;6EN87(@;65N<V%J97,`16QI;6EN87(@<')I=FEL96=I;W,@
M9&4@(B5S(@"_16QI;6EN87(@<')I=FEL96=I;W,@<&%R82`B)7,B('D@8W5A
M;'%U:65R('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E/P!%;&EM:6YA<B!F:6QA
M`$5L:6UI;F%R(&ED96YT:61A9"!S96QE8V-I;VYA9&$`16QI;6EN87(@<W5B
M8V%R<&5T87,`16QI;6EN82!L82!C;VQU;6YA(&%C='5A;`"_16QI;6EN87(@
M<_-L;R!E;"!A8V]N=&5C:6UI96YT;R!A8W1U86PL(.ES=&$@87!A<FEC:?-N
M('D@;&%S(&9U='5R87,L(&\@=&]D87,@;&%S(&%P87)I8VEO;F5S/P!%;&EM
M:6YA(&QA(&9I;&$@86-T=6%L`%-E(&AA(&5L:6UI;F%D;R!E;"!G=6GS;B!D
M92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX@(B5S(BX`2&]R
M82!D92!E;G1R96=A.@!$:6YA;6%R8V$`7T1E<V-R:7!C:?-N`$1E<V-R:6)A
M(&5L('!R;V)L96UA`$1E<V-R:7!C:?-N`$1E=&%L;&5S("AT86UB:>EN(&5N
M(&5L(&%R8VAI=F\@9&4@<F5G:7-T<F\@9&4@2&]R9&4I.@!392!H86X@<F5G
M:7-T<F%D;R!L;W,@9&5T86QL97,@<&%R82!E;"!A9&UI;FES=')A9&]R+@!$
M97-A<G)O;&QO`%!U;G1O(&1E(&-O;F1E;G-A8VGS;@!0=6YT;R!D92!C;VYD
M96YS86-I\VX@9&4@;&$@^FQT:6UA(&AO<F$Z(`!0=6YT;R!D92!C;VYD96YS
M86-I\VXZ(`!$92!I>G%U:65R9&$@82!D97)E8VAA`$1E(&1E<F5C:&$@82!I
M>G%U:65R9&$`1&ER96-T;W)I;P!-;W-T<F%R`+]-;W-T<F%R(&5N(&9O<FUA
M=&\@9&4@,C0M:&]R87,_`$UO<W1R87(@86=E;F1A<P!/<&-I;VYE<R!D92!6
M:7-U86QI>F%C:?-N`$UO<W1R87(@<')O;O-S=&EC;R!D971A;&QA9&\`36]S
M=')A<B!P<F]N\W-T:6-O("A4048I`$9O<FUA=&\@9&4@=FES=7IA;&EZ86-I
M\VX`3F]T:69I8V%C:?-N(&1E(&-O;G-U;'1A`$1J:6)O=71I`$YO(&5L:6UI
M;F%R`$YO(&%C8V5D97(@9&ER96-T86UE;G1E(&$@;6%I;G1E;F%N8V4N<&AP
M`%-E;&5C8VEO;F4@8_-M;R!M;W-T<F%R(&5N(&QA(&%G96YD82!L87,@=&%R
M96%S('9E;F-I9&%S`$YO('-E(')E<&ET90"_0V]N=&EE;F4@;&$@<')I;65R
M82!F:6QA(&QO<R!N;VUB<F5S(&1E(&QO<R!C86UP;W,_(%-I(&5S(&%S[2P@
M<V5L96-C:6]N92!E<W1A(&-A<VEL;&$Z`$1O;6EN:6-A`%)E</IB;&EC82!$
M;VUI;FEC86YA`+].;R!D:7-P;VYE(&1E(&-U96YT83\@4V]L:6/M=&5L82X`
M1&5S8V%R9V%R`$1E<V-A<F=A<B`E<P!$97-C87)G87(@;&$@8V]N9FEG=7)A
M8VGS;B!G96YE<F%D82!C;VUO('5N(&=U:?-N(%!(4"X`3&ES=&$@9&5S<&QE
M9V%B;&4`1')O9V%S`%9E;F-I9&\Z("5S.@!$=7)A8VGS;@!#;W)R96\`0V]N
M=')O;&%D;W(@9&4@<&%S87)E;&$@0V]R<F5O+6$M4TU3('!A<F$@<')O=F5E
M9&]R97,@<75E('!R;W!O<F-I;VYE;B!E<W1E('-E<G9I8VEO+@!%4E(`16-U
M861O<@!-;V1I9FEC87(`36]D:69I8V%R("5S`$UO9&EF:6-A<B!A<VES=&5N
M=&5S`$UO9&EF:6-A<B!B;&]Q=64`36]D:69I8V%R(&%G96YD87,`36]D:69I
M8V%R(&=R=7!O`$UO9&EF:6-A<B!P<FEV:6QE9VEO`$UO9&EF:6-A<B!P<FEV
M:6QE9VEO<P!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,`36]D:69I8V%R
M(&%G96YD87,@<F5M;W1A<P!-;V1I9FEC87(@87-I<W1E;G1E<P!-;V1I9FEC
M87(@8V%T96=O<NUA<R!Y(&-O;&]R97,`36]D:69I8V%R(&]P8VEO;F5S(&1E
M.@!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@(B5S(@!-;V1I9FEC87(@<')I
M=FEL96=I;W,@9&4@)7,`161U8V%C:?-N`$5G:7!T;P!%;"!386QV861O<@!%
M;&5M96YT;RXN+@!%;0!#;W)R96\`1&ER96-C:?-N(&1E(&-O<G)E;P!,87,@
M9&ER96-C:6]N97,@9&4@8V]R<F5O('1I96YE;B!Q=64@8V]I;F-I9&ER+@!#
M;W)R96\@8V]N(&-O;F9I<FUA8VGS;@!087-A<F5L82!#;W)R96\M82U335,`
M16UO=&EC;VYE<P!-96YS86IE(&5N(&)L86YC;P!297-U;'1A9&\@96X@8FQA
M;F-O+@!,:6UP:6%R('3I<FUI;F]S(&1E(&+Z<W%U961A`%]&:6YA;`"_4&5R
M;6ET:7(@:6YS97)C:?-N(&1E(&EMX6=E;F5S(&1E(&QA<R!'86QE<NUA<R!D
M92!F;W1O<S\`OU!E<FUI=&ER(&UE;OH@9&4@8V]N=&5X=&\@9&5L(&)O=/-N
M(&1E<F5C:&\@9&5L(')A=/-N/P!&96-H82!F:6YA;`!497)M:6YA(&5L`$AO
M<F$@9FEN86P`0?%O(&1E('1E<FUI;F%C:?-N`$%G<F%N9&%R(&5D:71O<@!)
M;G1R;V1U>F-A('5N82!P<F5G=6YT82!D92!S96=U<FED860@<75E('-E(&QE
M(&9O<FUU;&%RX2!S:2!P<F5C:7-A(')E86IU<W1A<B!L82!C;VYT<F%S9?%A
M+"!P+F4N(">_0W7A;"!E<R!E;"!N;VUB<F4@9&4@<W4@;6%S8V]T83\G.@!)
M;G1R;V1U>F-A(&%Q=>T@;&$@55),(&1E(&QA(&EM86=E;@!);G1R;V1U>F-A
M(&QA<R!L971R87,@9&4@9&5B86IO.@!'=6EN96$@16-U871O<FEA;`!%<FET
M<F5A`$5R<F]R`$5R<F]R(&%L(&-R96%R(&5L(&)L;W%U93H@)7,`17)R;W(@
M86P@96QI;6EN87(@86YC;&$@9&4@<VEN8W)O;FEZ86-I\VXZ("5S`$5R<F]R
M(&%L(&5L:6UI;F%R(&5L(')E9VES=')O(&1E('-I;F-R;VYI>F%C:?-N.B`E
M<P!%<G)O<B!A;"!O8G1E;F5R(&-O;G1E;FED;W,Z("5S`$5R<F]R(&%L(')E
M8W5P97)A<B!L82!I;F9O<FUA8VGS;B!D92!T:65M<&\@9&ES<&]N:6)L92!D
M92`E<SH@)7,`17)R;W(@86P@86-T=6%L:7IA<B!L82!C;VYT<F%S9?%A.B`E
M<P!%<G)O<B!C;VX@96P@;65N<V%J92!D92!C;W)R96\N`$5R<F]R(&%L(&5S
M8W)I8FER("(E<R(N`$5S=&]N:6$`171I;W#M80#)=&YI8V\`175R;W!A`$%C
M;VYT96-I;6EE;G1O(&'Q861I9&\Z`$%C;VYT96-I;6EE;G1O(&5L:6UI;F%D
M;SH`06-O;G1E8VEM:65N=&\@;6]D:69I8V%D;SH`06-O;G1E8VEM:65N=&\@
M9&4@)7,@<&%R82`E<P!.;R!S92!E;F-O;G1R\R!E;"!A8V]N=&5C:6UI96YT
M;P!,;W,@86-O;G1E8VEM:65N=&]S('1I96YE;B!Q=64@=&5N97(@=6YA(&9E
M8VAA(&EN:6-I86PN`$QO<R!A8V]N=&5C:6UI96YT;W,@=&EE;F5N('%U92!T
M96YE<B!U;B!T[71U;&\N`$-A9&$@,34@;6EN=71O<P!#861A(#(@;6EN=71O
M<P!#861A(#,P('-E9W5N9&]S`$-A9&$@-2!M:6YU=&]S`$-A9&$@:6YI8VEO
M(&1E('-E<VGS;@!#861A(&UE9&EA(&AO<F$`0V%D82!M:6YU=&\`5F%L;W)E
M<R!D92!E:F5M<&QO.@!%:F5C=71A<@!%>'!A;F1I<@!%>'!A;F1I<B!N;VUB
M<F5S`$UO<W1R87(@8F%R<F$@;&%T97)A;`!S92!E<W!E<F%B82`G*2<`4V4@
M97-P97)A8F$@=6YA(/IN:6-A('!A;&%B<F$@;R!U;B!TZ7)M:6YO(&1E(&+Z
M<W%U961A(&5N=')E8V]M:6QL861O`$9E8VAA(&1E('9E;F-I;6EE;G1O`$5X
M<&]N96YT90!%>'!O<G1A<@!%>'!O<G1A<B!A9V5N9&$`0V]L;W(@9&4@;&5T
M<F$`0V%R9V%R(&QA(&-O;F9I9W5R86-I\VX@<&]R($944`!&86QL;R!A;"!T
M<F%E<B!L87,@<')E9F5R96YC:6%S+@!);F-A<&%Z(&1E(&-O;F5C=&%R<V4@
M86P@<V5R=FED;W(@3$1!4"X`26YC87!A>B!D92!C;VYE8W1A<G-E(&%L('-E
M<G9I9&]R(%--0BX`1F%L;&\@86P@8V]P:6%R(&1E("(E<R(N`$9A;&QO(&%L
M(&-O<&EA<B!A("(E<R(N`$9A;&QO(&%L(&-R96%R('5N82!C;VYE>&GS;B!3
M05-,`$9A;&QO(&%L('1R87-L861A<B`B)7,B+@!&86QL;R!A;"!R96-U<&5R
M87(Z("5S`$1E<W!E:F%D;P!)<VQA<R!-86QV:6YA<R`H1F%L:VQA;F0I`$ES
M;&%S($9A<F]E`$5R<F]R(&ER<F5C=7!E<F%B;&4Z`$9A>`!&87AE<P!&96)R
M97)O`%-E('-I96YT92!C;VUO`%-E('-I96YT92!C;VUO.B``4&]C87,@;&QU
M=FEA<P!%<V-A<V\@86=U86-E<F\@9&4@;FEE=F4`36%T<FEZ(&1E(&-A;7!O
M<P!#05!40TA!(&1E($9I9VQE=`!,971R82!D92!&:6=L970`1FEJ:0!!<F-H
M:79O`$ZZ(&1E(&%R8VAI=F]S.B`E<R!A<F-H:79O`$ZZ(&1E(&%R8VAI=F]S
M.B`E<R!A<F-H:79O<P!!<F-H:79O<P!.;VUB<F4@9&4@87)C:&EV;P!396QE
M8V-I\VX@9&4@87)C:&EV;P!#87)G87(@87)C:&EV;P!,82!C87)G82!D92!A
M<F-H:79O<R!N;R!E<W3A('-O<&]R=&%D82X`1FEL=')O<P!%;F-O;G1R87(`
M1FEN;&%N9&EA`$-U87)T;R!C<F5C:65N=&4`0W5A<G1O(&-R96-I96YT90!2
M87KS;B!F:6IA`%9O;'1E87(`1&ES<&]S:6-I\VX`3FEE8FQA`$QA(&-A<G!E
M=&$@)7,@;F\@97AI<W1E+@!#;VQO<B!D92!L971R80!#;VUI9&$`4&%R82!N
M879E9V%D;W)E<R!Q=64@;F\@861M:71A;B!I;>%G96YE<P!0<F]N\W-T:6-O
M("A4048I`$3M87,@9&5L('!R;V[S<W1I8V\@*'1E;F=A(&5N(&-U96YT82!Q
M=64@96P@<')O;O-S=&EC;R!F86-I;&ET861O(&EN8VQU>64@=&%N=&\@96P@
M9.UA(&-O;6\@;&$@;F]C:&4[('5N(&[Z;65R;R!G<F%N9&4@<V4@=')A9'5C
M:7+A(&5N('5N(&)L;W%U92!M=7D@86YC:&\I`+](82!O;'9I9&%D;R!L82!C
M;VYT<F%S9?%A/P!&;W)M=6QA<FEO<P!&;W)T=6YA`%1I<&\@9&4@9F]R='5N
M80!&;W)T=6YA<P!&;W)T=6YA<R`R`$9O<F]S`%)E96YV[6]S`%9I90!&<F%M
M97,`1G)A;F-I80!&<F%N8VEA+"!-971R;W!O;&ET86YA`$QI8G)E`$EN9F]R
M;6%C:?-N(&1E('1I96UP;R!D:7-P;VYI8FQE`$=U87EA;F$@9G)A;F-E<V$`
M4&]L:6YE<VEA(&9R86YC97-A`%1E<G)I=&]R:6]S(&9R86YC97-E<R!D96P@
M<W5R`%9I97)N97,`1&4`1&5L(`!$97-C<FEP8VGS;B!C;VUP;&5T80!,=6YA
M(&QL96YA`$YO;6)R92!C;VUP;&5T;P!&=71U<F\`1V%B\VX`1V%L97+M82!D
M92!L82!Q=64@;V)T96YE<B!L82!I;6%G96X`1V%L97+M83H`1V%M8FEA`$IU
M96=O`$=E;F5R86P`1V5N97)A<B!C;VYF:6=U<F%C:?-N(&1E("5S`$/S9&EG
M;R!G96YE<F%D;P!'96]R9VEA`$%L96UA;FEA`$=H86YA`$=I8G)A;'1A<@!.
M;VUB<F4@:6YD:6-A9&\`3W!C:6]N97,@9VQO8F%L97,`27(`1V]E9&5L`$UA
M<&%S(&1E($=O;V=L90!"^G-Q=65D82!E;B!';V]G;&4`27(@82`E<P!%<V-A
M;&$@9&4@9W)I<V5S`$=R96-I80!'<FEE9V\@*$E33RTX.#4Y+3<I`$=R;V5N
M;&%N9&EA`$=R86YA9&$`061M:6YI<W1R86-I\VX@9&4@9W)U<&]S`$QO<R!N
M;VUB<F5S(&1E(&=R=7!O(&YO('!U961E;B!D96IA<G-E(&5N(&)L86YC;P!'
M<F]U<%]L9&%P.B!.;R!S92!P=65D92!A\6%D:7(@96P@9W)U<&\@)7,N(,ES
M=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(Z(`!'<F]U<%]L9&%P.B!)
M;F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&=R=7!O("5S`$=R;W5P7VQD87`Z($EN
M8V%P87H@9&4@86-T=6%L:7IA<B!E;"!G<G5P;R`E<P!'<G5P;W,`1W5A9&%L
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N97-E>0!0<FEV:6QE9VEO<R!D92!I
M;G9I=&%D;P!,+B!I;G9I=&%D;W,`1W5I;F5A`$=U:6YE82U":7-S874`1W5A
M>6%N80!(5$U,`$A434P@<V4@;FEE9V$@8V]B87)D96UE;G1E(&$@96QI;6EN
M87(@;&$@^FQT:6UA(&-E;&1A(&1E(&QA(&9I;&$N`$A434Q!<F5A('-E(&YI
M96=A(&-O8F%R9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM82!C;VQU;6YA
M(&1E(&QA('1A8FQA+@!(5$U,('-E(&YI96=A(&-O8F%R9&5M96YT92!A(&5L
M:6UI;F%R(&QA(/IL=&EM82!F:6QA(&1E(&QA('1A8FQA+@!.;R!S92!E;F-O
M;G1R\R!L82!A=71E;G1I9FEC86-I\VX@2%144"X`2&%I=.T`06QG;W)I;6\@
M2&%S:`!.96)L:6YA`$-A8F5C97)A`$-A8F5C97)A<P!)<VQA($AE87)D(&4@
M27-L87,@36-$;VYA;&0`5&]R;65N=&$@=')O<&EC86P@:6YT96YS80!(96)R
M96\@*$E33RTX.#4Y+3@M22D`06QT=7)A`$%Y=61A`$%Y=61A(&1E;"!E9&ET
M;W(`07EU9&%N=&4`2&5M:7-F97)I;P!!<77M('1I96YE(&5L(&-O;6EE;GIO
M(&1E;"!A<F-H:79O.@!/8W5L=&%R`$]C=6QT87(@)7,`06QT80!?26YI8VEO
M`%-A;G1A(%-E9&4@*$-I=61A9"U%<W1A9&\@9&5L(%9A=&EC86YO*0!);FEC
M:6\`1&]M:6-I;&EO`$1I<F5C=&]R:6\@<&5R<V]N86P`5&5LZ69O;F\@<&%R
M=&EC=6QA<@!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M(%-E(&AA;B!E;F-O;G1R861O(&1A=&]S(%A-3"`E<R!N;R!VX6QI9&]S(&5N
M(&5L(&UE;G-A:F4@)7,`2&]R9&4O2V]L86(Z($YI;F?Z;B!M96YS86IE(&-O
M<G)E<W!O;F1E(&%L(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@3F\@<V4@96YC
M;VYT<O,@=6X@;V)J971O(&1E('1I<&\@)7,@96X@96P@;65N<V%J92`E<P!(
M;W)D92]+;VQA8CH@4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@)7,@
M(B5S(@!(;W)D92]+;VQA8CH@16P@;6]T;W(@9&4@:6YT96=R86-I\VX@<')E
M8VES82!D92!L82!E>'1E;G-I\VX@4$A0("=D;VUX;6PG`$AO<F1E+TMO;&%B
M.B!);F-A<&%Z(&1E(&-R96%R(&YU979O(.%R8F]L(%A-3"!D96P@;V)J971O
M("5S`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E(&5L:6UI;F%R("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E(&]B=&5N97(@240@34E-12!D
M92!L82!P87)T92!D92!T:7!O("5S`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E
M('-I;F-R;VYI>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!);F-A<&%Z
M(&1E('-I;F-R;VYI>F%R(&5L96UE;G1O<R!C;VUP87)T:61O<SH@)7,`2&]R
M9&4O2V]L86(Z($5L96UE;G1O(&-O;7!A<G1I9&\@9&5S8V]N;V-I9&\@(B5S
M(@!,[6YE82!H;W)I>F]N=&%L`$UA<F=E;B!H;W)I>F]N=&%L`$AO<FEZ;VYT
M86PZ`$AO<F$H<RD`OT/S;6\@;&QE9_,@:&%S=&$@87%U[3\@**%#;VUU;NUQ
M=65L;RP@<&]R(&9A=F]R(2D`OU1A;6'Q;R!D92!L87,@9&EV:7-I;VYE<R!H
M;W)A<FEA<R!E;B!L87,@=FES=&%S(&1E(&3M82!Y('-E;6%N83\`OT-U86YT
M87,@8V]L=6UN87,@9&5S96$@8V]M8FEN87(_`+]$92!C=6%N=&]S(&3M87,@
M<V4@9V5N97)A<N$@;&$@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB
M;&4_`+]#=>%N=&]S(&-A;7!O<R`H8V]L=6UN87,I(&AA>3\`OT-U86YT87,@
M9FEL87,@9&5S96$@8V]M8FEN87(_`$AU;65D860`2'5M961A9#H@`$AU;6]R
M:7-T87,`2'5N9W+M80!(82!F86QL861O(&QA(&-R96%C:?-N(&1E;"!B=7KS
M;B!)34%0.B`E<P!(82!F86QL861O(&QA(&5L:6UI;F%C:?-N(&1E;"!B=7KS
M;B!)34%0.B`E<P!(82!F86QL861O(&QA(&-R96%C:?-N(&1E(&5S<&%C:6\@
M87-I9VYA9&\@9&5L(&)U>O-N($E-05`Z("5S`$1I<F5C8VGS;B!)4`!,82!D
M:7)E8V-I\VX@25`@;F\@97-TX2!D:7-P;VYI8FQE+@!,82!D:7)E8V-I\VX@
M25`@;F\@97-TX2!E;G1R92!B;&]Q=65S($-)1%(@<&5R;6ET:61O<RX`5FEO
M;&%C:?-N(&QO8VMD;W=N($E0+@!)7VYS97)T87(@9FEL82!E;F-I;6$`27-L
M86YD:6$`4_-L;R!I8V]N;W,`26-O;F]S(&1E("5S`$EC;VYO<R!C;VX@=&5X
M=&\`3F]M8G)E(&1E(&QA(&ED96YT:61A9#H`4VD@;F\@<V4@;75E<W1R82!C
M;W)R96-T86UE;G1E+"`E<R!P87)A(&%B<FER;&\@96X@=6YA('9E;G1A;F$@
M;G5E=F$N`%-I(&YO('9E(&YI;F?Z;B!I8V]N;R!M961I86YT92!);G1E<FYE
M="!%>'!L;W)E<BP@<'5E9&4@=&5N97(@<75E(&%C=&EV87(@97-T82!C87-I
M;&QA('!A<F$@9&5S86-T:79A<B!L82!T<F%N<W!A<F5N8VEA(%!.1RX`4VD@
M=F4@97-T92!M96YS86IE('-I;B!N:6YG=6YA(&EM86=E;BP@;&$@:6UA9V5N
M('%U92!Q=6EE<F4@8V%R9V%R(&YO('-E('!U961E(&UO<W1R87(@96X@<W4@
M;F%V96=A9&]R+@!3:2!S=2!C;&EE;G1E(&1E(&-O<G)E;R!N;R!S;W!O<G1A
M('!E=&EC:6]N97,@:51I<"P@<'5E9&4@=7-A<B!U;F\@9&4@;&]S(';M;F-U
M;&]S('-I9W5I96YT97,@<&%R82!A8V5P=&%R(&\@<F5C:&%Z87(@96P@86-O
M;G1E8VEM:65N=&\N"@I087)A(&%C97!T87)L;SH*)7,*"E!A<F$@86-E<'1A
M<FQO(&-O;F1I8VEO;F%L;65N=&4Z"B5S"@I087)A(')E8VAA>F%R;&\Z"B5S
M`%9I<W1A('!R979I83H`55),(&1E(&QA(&EM86=E;@!54DP@9&4@;&$@:6UA
M9V5N.@!);6%G96X@9&4@;&$@9V%L97+M80!);6%G96X@9&4@;&$@9V%L97+M
M83H`4V4@:&$@8V%R9V%D;R!L82!I;6%G96X`26WA9V5N97,`26UP;W)T87(@
M86=E;F1A+B!087-O("5D`$EM<&]R=&%R+"!P87-O("5D`$EM<&]R=&%R+T5X
M<&]R=&%R(&%G96YD87,`0V%M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@:6UP
M;W)T861O<SH`26Y?<V5R=&%R(&9I;&$@9&5B86IO`%-E(&AA(&EN9&EC861O
M('5N(&/S9&EG;R!D92!A8V-I\VX@:6YC;W)R96-T;RX`3F]M8G)E(&1E('5S
M=6%R:6\@>2]O(&-O;G1R87-E\6$@:6YC;W)R96-T;W,N`$YO;6)R92!D92!U
M<W5A<FEO(&\@9&ER96-C:?-N(&%L=&5R;F%T:79A(&EN8V]R<F5C=&]S+B!6
M=65L=F$@82!I;G1E;G1A<FQO(&\@</-N9V%S92!E;B!C;VYT86-T;R!C;VX@
M96P@861M:6YI<W1R861O<B!D92!S:7-T96UA<R!P87)A(&WA<R!I;F9O<FUA
M8VGS;BX`075M96YT87(@<V%N9W)A9&\`26YD:6$`57-U87)I;W,@:6YD:79I
M9'5A;&5S`$EN9&]N97-I80!);F9O<FUA8VGS;@!);F9O<FUA8VGS;@!,82!I
M;F9O<FUA8VGS;B!Y82!N;R!E<W3A(&1I<W!O;FEB;&4N`$EN<V5R=&%R(&-?
M;VQU;6YA(&1E='+A<P!);G-E<G1A<B!I;6%G96X`26YS97)T87(@=&%B;&$`
M26YS97)T87(@=NUN8W5L;R!796(`26YS97)T87(@7V-O;'5M;F$@9&5L86YT
M90!);G-E<G1A('5N82!N=65V82!C;VQU;6YA(&1E='+A<R!D92!L82!A8W1U
M86P`26YS97)T82!U;F$@;G5E=F$@8V]L=6UN82!D96QA;G1E(&1E(&QA(&%C
M='5A;`!);G-E<G1A('5N82!F:6QA(&YU979A(&1E8F%J;R!D92!L82!A8W1U
M86P`26YS97)T82!U;F$@9FEL82!N=65V82!E;F-I;6$@9&4@;&$@86-T=6%L
M`$EN<V5R=&$@=6X@<.%R<F%F;R!T<F%S(&5L(&YO9&\@86-T=6%L`$EN<V5R
M=&$@=6X@<.%R<F%F;R!A;G1E<R!D96P@;F]D;R!A8W1U86P`26YS97)T87(@
M<&QA;G1I;&QA(&%L=&5R;F%T:79A`$EN<V5R=&%R('5N82!D:7)E8V-I\VX@
M9&4@8V]R<F5O(&5N(&QA('%U92!R96-I8FER(&QA(&-O;G1R87-E\6$Z`$EN
M<V5R=&%R(&-E;&1A(&1E='+A<P!);G-E<G1A<B!C96QD82!A;G1E<P!);G-E
M<G1A<B!C;VQU;6YA(&1E='+A<P!);G-E<G1A<B!C;VQU;6YA(&%N=&5S`$EN
M<V5R=&%R(&UE;G-A:F5S`$EN<V5R=&%R('#A<G)A9F\@9&5T<N%S`$EN<V5R
M=&%R('#A<G)A9F\@86YT97,`26YS97)T87(@9FEL82!D96)A:F\`26YS97)T
M87(@9FEL82!E;F-I;6$`26YS97)T87(@;&$@<F5S<'5E<W1A(&YE8V5S87)I
M82!A(&QA('!R96=U;G1A(&1E('-E9W5R:61A9#H`26YS97)T87(O36]D:69I
M8V%R(&EM86=E;@!);G-E<G1A<B]-;V1I9FEC87(@=NUN8W5L;P!386QD;R!I
M;G-U9FEC:65N=&4@<&%R82!E;G9I87(@82!L82!L:7-T82!D92!D:7-T<FEB
M=6-I\VXN`%-A;&1O(&EN<W5F:6-I96YT92X`16YT97)O`$QI<W1A(&1E(&5N
M=&5R;W,`541(("A#86)E8V5R82!D92!$871O<R!D92!5<W5A<FEO*2!N;R!V
MX6QI9&$N`$1A=&]S(%I)4"!N;R!VX6QI9&]S`$%P;&EC86-I\VX@;F\@=N%L
M:61A+@!)1"!D92!L;W1E(&YO(';A;&ED;RX`4V4@:&%N(&5N=FEA9&\@9&%T
M;W,@;F\@=N%L:61O<RX`1&ER96-C:?-N(&1E(&-O<G)E;R!N;R!VX6QI9&$N
M`$9O<FUA=&\@9&4@87)C:&EV;R!N;R!VX6QI9&\`0VQA=F4@9&4@;&EC96YC
M:6$@;F\@=N%L:61A+@!392!H82!I;F1I8V%D;R!U;F$@=6)I8V%C:?-N(&YO
M(';A;&ED82X`;7-G7W1Y<&4@;F\@=N%L:61O+@!A<&E?:60@;F\@=N%L:61O
M(&\@9&5S87!A<F5C:61O+@!087+A;65T<F]S(&YO(';A;&ED;W,@;R!D97-A
M<&%R96-I9&]S+@!0<FEV:6QE9VEO(&1E;"!P861R92!N;R!VX6QI9&]S+@!)
M1"!D92!A<V]C:6%D;R!N;R!VX6QI9&\N`$/S9&EG;R!D92!P<F]D=6-T;R!N
M;R!VX6QI9&\N`%!R;W1O8V]L;R!N;R!VX6QI9&\N`$1E<W1I;F%T87)I;R!N
M;R!VX6QI9&\Z("(E<R(`3V)J971O(&-O;7!A<G1I9&\@;F\@=N%L:61O+@!$
M:7)E8V-I\VX@9&5L(')E;6ET96YT92!N;R!VX6QI9&$`1&%T;W,@=6YI8V]D
M92!N;R!VX6QI9&]S+@!);G9E;G1A<FEO`$EN=F5R=&ER('-E;&5C8VGS;@!)
M<N%N+"!297#Z8FQI8V$@27-LX6UI8V$@9&4`27)A<0!)<FQA;F1A`$ES;&$@
M9&4@36%N`$)O<G)A<V-A<R!A:7-L861A<P!)<W)A96P`16UI<V]R`$-U<G-I
M=F$`271A;&EA`$IA;6%I8V$`16YE<F\`2F%P\VX`2F%P;V[I<R`H25-/+3(P
M,C(M2E`I`$IE<G-E>0!*;W)DX6X`2G5L:6\`2G5N:6\`2G5S=&EF:6-A<@!!
M;&EN96%R(&%L(&-E;G1R;P!*=7-T:69I8V%R`$%L:6YE87(@82!L82!I>G%U
M:65R9&$`06QI;F5A<B!A(&QA(&1E<F5C:&$`2V%Z86MH<W1A;@"_0V]N<V5R
M=F%R(&5L(&]R:6=I;F%L/P!+96YY80!%;"!S97)V:61O<B!+97)B97)O<R!H
M82!R96-H87IA9&\@;&$@875T96YT:69I8V%C:?-N+@!.;W9A=&]S(&1E;"!+
M97)N96P`0W)E86-I\VX@9&4@8VQA=F4`2'5E;&QA(&1I9VET86P@9&4@;&$@
M8VQA=F4`5&%M8?%O(&1E(&-L879E`%1I<&\@9&4@8VQA=F4`57-O(&1E(&QA
M(&-L879E.@!,82!C;&%V92!Y82!E>&ES=&4@96X@96P@<V5R=FED;W(@9&4@
M8VQA=F5S('#Z8FQI8V\N`%!A;&%B<F%S(&-L879E`$YI\6]S`$MI<FEB871I
M`$-O<F5A+"!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D90!#;W)E
M82P@4F5P^F)L:6-A(&1E`$-O<F5A;F\@*$550RU+4BD`2W5W86ET`$MY<F=Y
M>G-T86X`7T1I<W1R:6)U8VGS;@!)9&EO;6$`3&%O+"!297#Z8FQI8V$@1&5M
M;V-RX71I8V$@4&]P=6QA<@#:;'1I;6%S(#(T(&AO<F%S`$-U87)T;R!M96YG
M=6%N=&4`VFQT:6UA(&UO9&EF:6-A8VGS;@!-97,@86YT97)I;W(`VFQT:6UO
M(&-A;6)I;R!D92!C;VYT<F%S9?%A`$-U87)T;R!M96YG=6%N=&4`VFQT:6UA
M(&%C='5A;&EZ86-I\VXZ`$'Q;R!A;G1E<FEO<@#:;'1I;6$@<V5S:?-N.B`E
M<P#:;'1I;6$@<V5S:?-N.B`E<R!D97-D92`E<P#:;'1I;6$@<V5S:?-N.B!.
M=6YC80!396UA;F$@86YT97)I;W(`3&%T=FEA`$QE>65S`$1I<W1R:6)U8VGS
M;@!$96IA<B!E;B!B;&%N8V\@<&%R82!E;&EM:6YA<B!E;"!B;W)D90!,96)A
M;F]N`$EZ<75I97)D80!#86)E8V5R82!I>G%U:65R9&$`5F%L;W)E<R!D92!L
M82!I>G%U:65R9&$`3&5S;W1H;P!.:79E;`!,:6)E<FEA`$QI8GEA;B!!<F%B
M($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=E<F$@;&QO=FEZ;F$`3&QU
M=FEA(&QI9V5R80!,;'5V:6$@;&EG97)A(&UA='5T:6YA`$QL=79I82!L:6=E
M<F$@=F5S<&5R=&EN80!!9W5A8V5R;R!L:6=E<F\`3&QU=FEA<R!Y('1R=65N
M;W,`3F5V861A('-U879E`$QI9V5R;R!A9W5A8V5R;R!D92!N:65V90!#:&%S
M8V%R<FEL;&\`3&EM:71A<B!I;G1E<G9A;&\@82!E>'!O<G1A<CH`5NUN8W5L
M;P!%;"!V[6YC=6QO(&%P=6YT82!A.@!6:6YC=6QA<B!D:7)E8V-I\VX@9&4@
M8V]R<F5O(&$@;&$@<.%G:6YA(&1E(&-O;7!O<VEC:?-N(&%L(&UO<W1R87(`
M5NUN8W5L;W,`0V]O:VEE($QI;G5X`$QI<W1A<B`M(&5L('5S=6%R:6\@<'5E
M9&4@97AA;6EN87(@;&$@8V%R<&5T80!,:7-T87(@8F%S97,@9&4@9&%T;W,`
M3&ES=&%R('1E;6%S(&1E(&%Y=61A`$QI<W1A<B!T86)L87,`3&ES="U!<F-H
M:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI
M<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`2&$@9F%L;&%D;R!E;"!L
M:7-T861O(&1E(&QA<R!S97-I;VYE<SH@)7,`2&$@9F%L;&%D;R!E;"!L:7-T
M861O(&1E('5S=6%R:6]S.B`E<P!%;"!L:7-T861O(&1E('5S=6%R:6]S(&5S
M=.$@9&5S:&%B:6QI=&%D;RX`3&ET97)A='5R80!,:71U86YI80!?56)I8V%C
M:?-N`$QE>65N9&\N+BX`2&]R82!L;V-A;#H@`$ED:6]M82!Y(&AO<F$`56)I
M8V%C:?-N`$EN:6-I87(@<V5S:?-N`%)E9VES=')O(&1E(&QA<R!S97-I;VYE
M<R!D92!S:6YC<F]N:7IA8VGS;B!A;G1E<FEO<F5S`%-A;&ER`$EN:6-I87(@
M<V5S:?-N`%1A<F5A<R!D92!I;FEC:6\@9&4@<V5S:?-N`$9A;&SS(&5L(&EN
M:6-I;R!D92!S97-I\VX@<&]R<75E(&EN=')O9'5J;R!I;F-O<G)E8W1A;65N
M=&4@<W4@;F]M8G)E(&1E('5S=6%R:6\@;R!C;VYT<F%S9?%A+@!&86QL\R!E
M;"!I;FEC:6\@9&4@<V5S:?-N+@!497AT;R!C;VUP;&5T;P!!;6]R`$)A:F$`
M06QF86)E=&\@9W)I96=O(&5N(&UI;OIS8RX`06QF86)E=&\@;&%T:6YO(&5N
M(&UI;OIS8RX`3OIM97)O<R!R;VUA;F]S(&5N(&UI;OIS8RX`3'5X96UB=7)G
M;P!-30!-3U1$`$5L(&%D:G5N=&\@35,M5$Y%1B!N;R!C;VYT96[M82!D871O
M<RX`35-'`$UA8V%O`$UA8V5D;VYI82P@06YT:6=U82!297#Z8FQI8V$@675G
M;W-L879A(&1E`$UA9&%G87-C87(`36%G:6$`0V]R<F5O`$%D;2X@8V]R<F5O
M`$-R96%R(%]V[6YC=6QO+BXN`$UA;&%W:0!-86QA<VEA`$UA;&1I=F%S`$UA
M;&D`36%L=&$`1V5S=&EO;F4@;&%S(&%G96YD87,@<F5M;W1A<RX`1V5S=&EO
M;F$@;&$@;&ES=&$@9&4@8V%T96=O<NUA<R!C;VX@;&$@<75E(&5T:7%U971A
M<B!E;&5M96YT;W,@>2!L;W,@8V]L;W)E<R!A<V]C:6%D;W,@82!D:6-H87,@
M8V%T96=O<NUA<RX`36%P82!M87`R-`!-87!A(&UA<'%U97-T`$-O<G)E<W!O
M;F1E;F-I87,@86QM86-E;F%D87,N`$UA<GIO`$UA<F=E;@!-87)C87(@8V]N
M(&QA<R!B86YD97)A<R!D92!,9>UD;R]3:6X@;&5E<@!-87)C87(@8V]N(&]T
M<F%R(&)A;F1E<F%S("AP+F4N($EM<&]R=&%N=&4O4F5S<&]N9&ED;RD`27-L
M87,@36%R<VAA;&P`36%R=&EN:6-A`$-A;7!O<R!C;VEN8VED96YT97,`36%U
M<FET86YI80!-875R:6-I;P!386QD;R!MX7AI;6\@<&5R;6ET:61O+@!392!H
M82!S;V)R97!A<V%D;R!E;"!N^FUE<F\@;>%X:6UO(&1E('!A<G1E<R!D92!M
M96YS86IE+@!496UP+B!MX7AI;6$@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7`N
M(&WA>&EM82#Z;'1I;6%S(#8@:&]R87,Z(`!.^FUE<F\@;>%X:6UO(&1E(&%C
M;VYT96-I;6EE;G1O<P!.^FUE<F\@;>%X:6UO(&1E(&)L;W%U97,@9&5L('!O
M<G1A;`!,;VYG:71U9"!MX7AI;6$`36%Y;P!-87EO='1E`%EO`$UE9&EC:6YA
M`%)E=6YI\VX`36EE;6)R;W,`06QA<FUA<P!,:7-T861O(&1E(&UE;OH`1F]R
M;6%T;R!D96P@;65N^CH`0V]M8FEN87(@8V5L9&%S`$UE;G-A:F4`4V4@:&$@
M8V]M<')O8F%D;R!C;W)R96-T86UE;G1E(&5L(&UE;G-A:F4@<&5R;R!N;R!S
M92!P=65D92!V97)I9FEC87(@96P@8V5R=&EF:6-A9&\@9&5L(&9I<FUA;G1E
M+@!-96YS86IE(&-A9'5C861O+@!4:7!O(&1E(&UE;G-A:F4`5&EE;7!O(&1E
M($UE=&%R`$)L;W%U92!-971A<B!N;R!D:7-P;VYI8FQE+@!";&]Q=64@365T
M87(@;F\@9&ES<&]N:6)L92X@4V4@:&%N(')E9VES=')A9&\@;&]S(&1E=&%L
M;&5S('!A<F$@96P@861M:6YI<W1R861O<BX`3F\@97-TX2!C;VYE8W1A9&$@
M;&$@365T87)$0@!-Z71O9&\`16P@;>ET;V1O("(E<R(@;F\@97-TX2!D969I
M;FED;P!-Z71O9&\@;F\@9&5F:6YI9&\N($WI=&]D;R!L;&%M861O.B`E<P!-
MZ71R:6-O`$WI:FEC;P!-:6-R;VYE<VEA+"!%<W1A9&]S($9E9&5R861O<R!D
M90!%;B!M961I;P!4:7!O($UI;64`5&5M<"X@;>UN+B!L87,@^FQT:6UA<R`R
M-"!H;W)A<SH@`%1E;7`N(&WM;BX@;&%S(/IL=&EM87,@-B!H;W)A<SH@`%1O
M9&%V[6$@;F\@:&$@97AP:7)A9&\@;&$@86YT:6?\961A9"!M[6YI;6$@9&4@
M;&$@8V]N=')A<V7Q80!-:6YU=&\H<RD`4F5F;&5J87(`36ES8V5LX6YE80!0
M87%U971E(%!%05(@2%144%]297%U97-T(&1E<V%P87)E8VED;RX`1F%L=&$@
M;&$@8V]N9FEG=7)A8VGS;BX@5&EE;F4@<75E(&=E;F5R87)L82!A:&]R82!S
M:2!D97-E82!U=&EL:7IA<B!E<W1A(&%P;&EC86-I\VXN`$E$(&1E(&UE;G-A
M:F4@9&5S87!A<F5C:61O+@!087%U971E(%!%05(@36%I;"!D97-A<&%R96-I
M9&\N`$E$(&1E('-E<VGS;B!D97-A<&%R96-I9&\N`$QU;@!#;W)R96\@;?-V
M:6P`36]D97)A9&\`4V4@:&$@;6]D:69I8V%D;R!L82!F96-H80!-;V1I9FEC
M87(@55),`$WS9'5L;P!-;VQD879I82P@4F5P^F)L:6-A(&1E`$WS;F%C;P!,
M=6YE<P!-;VYG;VQI80!-97,`5FES=&$@;65N<W5A;`!-97,@>2!A\6\`365N
M<W5A;&UE;G1E`$QI<W1A9&\@9&4@86-O;G1E8VEM:65N=&]S(&UE;G-U86QE
M<P!-96YS=6%L;65N=&4Z(%-E(')E<&ET92!C861A`%!R\WAI;6]S(&UE<V5S
M`$UI;G5T;W,@86YT97,`36]N='-E<G)A=`!&87-E<R!D92!L82!L=6YA`%-E
M(&AA;B!E;F-O;G1R861O(&WA<R!C86UP;W,@96X@;&$@;.UN96$@)60@<75E
M(&QO<R`E9"!E<W!E<F%D;W,N`$UA<G)U96-O<P!&=6YD86UE;G1A;&UE;G1E
M(&1E<W!E:F%D;P!&=6YD86UE;G1A;&UE;G1E(&YU8F]S;P!&=6YD86UE;G1A
M;&UE;G1E('-O;&5A9&\`1&5S<&QA>F%R(&AA8VEA(&%B86IO`$1E<W!L87IA
M<B!A(&QA(&EZ<75I97)D80!$97-P;&%Z87(@82!L82!D97)E8VAA`$1E<W!L
M87IA<B!H86-I82!A<G)I8F$`1&5S<&QA>F%R(&AA8VEA(&%B86IO`$1E<W!L
M87IA<B!H86-I82!A<G)I8F$`36]Z86UB:7%U90!,:7-T87,@9&5S<&QE9V%B
M;&5S(&UU;'1I+6YI=F5L`$UA<&$@54L@;?IL=&EP;&4`4V4@:&%N(&5N8V]N
M=')A9&\@=F%R:6]S(&-O;7!O;F5N=&5S(&E#86QE;F1A<CL@<_-L;R!S92!S
M;W!O<G1A('5N('9%=F5N="!C861A('9E>BX`4V5L96-C:?-N(&WZ;'1I<&QE
M`$ED96YT:61A9`!-:2!I9&5N=&ED860`36ES(&%G96YD87,`36ES(&%G96YD
M87,Z`$UI(%523"!D92!T:65M<&\@9&ES<&]N:6)L90!-:2!P;W)T86P`1&ES
M=')I8G5C:?-N(&1E(&UI('!O<G1A;`!->6%N;6%R`$Y/+"!.3R!E<W1O>2!D
M92!A8W5E<F1O`$YO;6)R90!.86UI8FEA`$YA=7)U`$YE<&%L`$AO;&%N9&$`
M06YT:6QL87,@2&]L86YD97-A<P!54DP@8F%S92!D92!.971S8V%P90!54DP@
M9&4@86YU;&%C:?-N(&1E($-!(&1E($YE='-C87!E`%523"!D92!P;VSM=&EC
M87,@9&4@0T$@9&4@3F5T<V-A<&4`55),(&1E(')E;F]V86-I\VX@9&4@3F5T
M<V-A<&4`55),(&1E(&%N=6QA8VGS;B!D92!.971S8V%P90!.;VUB<F4@9&4@
M<V5R=FED;W(@4U-,(&1E($YE='-C87!E`$-O;65N=&%R:6\@9&5L(&-E<G1I
M9FEC861O(&1E($YE='-C87!E`%1I<&\@9&4@8V5R=&EF:6-A9&\@9&4@3F5T
M<V-A<&4`4F5D`$YU;F-A`$YU979A($-A;&5D;VYI80!.=65V82!C871E9V]R
M[6$`0?%A9&ER`$5N=FEA<B!M96YS86IE(&$@)7,`3'5N82!N=65V80!.=65V
M;R!N;VUB<F4@9&4@=7-U87)I;R`H;W!C:6]N86PI`$YU979A(%IE;&%N9&$`
M06=E;F1A(&-R96%D82!Y(&-O;7!A<G1I9&$@9&4@9F]R;6$@875T;VWA=&EC
M82!C;VX@96PO;&]S('-I9W5I96YT92AS*2!G<G5P;RAS*3H@)7,N`$-O;G1R
M87-E\6$@;G5E=F$`3&$@;G5E=F$@8V]N=')A<V7Q82!E>'!I<F%RX2!E;"`E
M>"X`3&%S(&-O;G1R87-E\6%S(&YO(&-O:6YC:61E;BX`3G5E=F$@=F5N=&%N
M82`H7V)L86YK*0!.;W1I8VEA<P!'+B!D92!N;W1I8VEA<P!3:6=U:65N=&4`
M4'+S>&EM87,@,C0@:&]R87,`4'+S>&EM87,@-"!F87-E<P!0<O-X:6UO(&3M
M80!0<O-X:6UO(&UE<P!0<O-X:6UA('-E;6%N80!0<O-X:6UO(&'Q;P!0<O-X
M:6UO(&3M80!/<&-I;VYE<R!S:6=U:65N=&5S`%!R\WAI;6$@<V5M86YA`%-I
M9W5I96YT93X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3F]C:&4`3FEU90!.
M;P!3:6X@86QA<FUA`%-I;B!A<VES=&5N=&5S`$YO(&AA>2!D871O<R!D92!C
M;VYF:6=U<F%C:?-N('!A<F$@;6]S=')A<B!D:69E<F5N8VEA<RX`3F\@<V4@
M9&ES<&]N92!D92!E<W1R871E9VEA(&1E(&5L86)O<F%C:?-N(&1E(&EMX6=E
M;F5S($E33RX`3F\@:&%Y('!L86YT:6QL82!D92!L;W1E<P!.;R!H87D@8FQO
M<75E<R!E;B!L82!P;W-I8VGS;B!I;F1I8V%D80!.;R!S92!H82!I;G1R;V1U
M8VED;R!U;B!N;VUB<F4@9&4@86=E;F1A('!A<F$@;&$@875T96YT:69I8V%C
M:?-N($U#04PN`$YO('-E(&1I<W!O;F4@9&4@86=E;F1A<R!P87)A(&QO<R!I
M;G9I=&%D;W,N`%-I;B!C86UB:6]S+@!.;R!S92!P=65D96X@8?%A9&ER(&1E
M<V-E;F1I96YT97,@82!E<W1E('!R:79I;&5G:6\N`$YO('-E(&AA(&5S<&5C
M:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@)7,N
M`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U
M<F%C:?-N('!A<F$@5D93('!O<B!&5%`N`$YO('-E(&AA(&5S<&5C:69I8V%D
M;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!3
M44PN`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF
M:6=U<F%C:?-N('!A<F$@5D93('!O<B!A<F-H:79O(%-13"X`3F\@<75E9&$@
M<V%L9&\N`$YO('-E(&AA(&EN=')O9'5C:61O(&5L(&1E<W1I;F\N`%-I;B!F
M96-H82!F:6YA;`!3:6X@86-O;G1E8VEM:65N=&]S('9I<VEB;&5S`$YO('-E
M(&AA(&-A<F=A9&\@;FEN9_IN(&%R8VAI=F\`3F\@<V4@9&ES<&]N92!D92!I
M;F9O<FUA8VGS;B!D92!T:65M<&\@9&ES<&]N:6)L92!D92`E<P!.;R!S92!E
M;F-O;G1R87)O;B!D871O<R!I0V%L96YD87(N`$YO('-E(&AA;B!E;F-O;G1R
M861O(&EC;VYO<RX`3F\@<V4@:&$@9&5F:6YI9&\@;&$@=6)I8V%C:?-N+@!.
M;R!S92!H82!D969I;FED;R!L82!U8FEC86-I\VXN`$YO('-E(&AA(&EN=')O
M9'5C:61O('5N(&UE;G-A:F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N
M;VUB<F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N^FUE<F\N`$YO(&]F
M96YS:79A<P!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P
M87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!(5%10+@!.;R!S92!H82!I;G1R;V1U
M8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!)
M34%0+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A
M(&QA(&%U=&5N=&EF:6-A8VGS;B!+97)B97)O<RX`3F\@<V4@:&$@:6YT<F]D
M=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@
M9&4@:6YI8VEO+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q
M82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!005-35T0N`$YO('-E(&AA(&EN
M=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C
M:?-N(%--0BX`3F\@<V4@:&$@:6YD:6-A9&\@=NUA(&1E(&%C8V5S;R!A(&QO
M<R!B:6YA<FEO<R!/<&5N4U-,+B!087)A('1R86)A:F%R(&-O;B!D871O<R!0
M2T-3(#$R(&AA8V5N(&9A;'1A(&QO<R!B:6YA<FEO<R!/<&5N4U-,+@!3:6X@
M86QT87,@<&5N9&EE;G1E<RX`0V%R96-E(&1E('%U;W1A+@!3:6X@<F5P971I
M8VGS;@!3:6X@<F%Y87,`3F\@<V4@:&$@97-P96-I9FEC861O('5N('-E<&%R
M861O<BX`3FEN9W5N;P!.;R!E>&ES=&4@96P@87)C:&EV;P!.;R!S92!D:7-P
M;VYE(&1E('5N(&1I<F5C=&]R:6\@9&4@86QM86-E;F%M:65N=&\@=&5M<&]R
M86PN`$YO('-E(&AA(&5N=FEA9&\@96P@;F]M8G)E(&1E('5S=6%R:6\@>2]O
M(&QA(&-O;G1R87-E\6$N`$YO('-E(&AA;B!D979U96QT;R!D871O<R!834P@
M=N%L:61O<P!.;R!S92!E;F-O;G1R87)O;B!D:7)E8V-I;VYE<R!D92!C;W)R
M96\@=N%L:61A<P!3:6X@=F%L;W)E<P!.;R!S92!E;F-O;G1R\R!L82!V97)S
M:?-N(&5N(&QA(&-O;F9I9W5R86-I\VX@;W)I9VEN86PN(%)E9V5N97)A<B!L
M82!C;VYF:6=U<F%C:?-N+@!.;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N
M(&QA(&-O;F9I9W5R86-I\VXN(%)E9V5N97)A<B!L82!C;VYF:6=U<F%C:?-N
M+@!.:6YG=6YA`$YI;F=U;F\@*'5S;R!I;7!L[6-I=&\I`$[S<F1I8V\@*$E3
M3RTX.#4Y+3$P*0!)<VQA(&1E($YO<F9O;&L`2&5M:7-F97)I;R!N;W)T90!)
M<VQA<R!-87)I86YA<R!D96P@3F]R=&4`3F]R=65G80!.;R!D97-P=>ES`$YO
M(&%N=&5S`$YO(&5S('5N(&1I<F5C=&]R:6\`3F\@<V4@:&$@96YC;VYT<F%D
M;P!3:6X@9&5S87)R;VQL87(N`%-I;B!E<W1A8FQE8V5R`$YO(&5S=.$@<V]P
M;W)T861O+@!.;W1A<P!.;R!H87D@;F%D82!V:7-U86QI>F%B;&4L(')E=')O
M8V5D82X`079I<V]S`$YO=FEE;6)R90!!:&]R80!.^FUE<F\`3OIM97)O(&1E
M(&-A<F%C=&5R97,`3OIM97)O(&1E(&-O;'5M;F%S`$[Z;65R;R!D92!F:6QA
M<P!.;R!S92!H86X@97-P96-I9FEC861O(&[Z;65R;W,@82!A8W1U86QI>F%R
M(&5N(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX`06-E<'1A<@!/8FIE=&\`
M0W)E861O<B!D92!O8FIE=&]S`$]C=&%L`$]C='5B<F4`1FEL=')A<B!O9F5N
M<V%S`$]F:6-I;F$`3&$@8V]N=')A<V7Q82!A;G1I9W5A('D@;&$@;G5E=F$@
M9&5B96X@<V5R(&1I<W1I;G1A<RX`0V]N=')A<V7Q82!A;G1I9W5A`$QA(&-O
M;G1R87-E\6$@86YT:6=U82!N;R!E<R!C;W)R96-T82X`3VWA;@!%;`!$92!T
M;V1O<R!L;W,@8V%L96YD87)I;W,@82!L;W,@<75E('1E;F=O(&%C8V5S;P!$
M92!T;V1A<R!L87,@86=E;F1A<R!V:7-I8FQE<P!3\VQO(&1E(&UI<R!A9V5N
M9&%S`%/S;&\@;&]S('-E<G9I9&]R97,@24U!4"!S;W!O<G1A;B!L87,@8V%R
M<&5T87,@8V]M<&%R=&ED87,N`%/S;&\@;V9E;G-I=F%S`%/S;&\@<V4@<&5R
M;6ET92!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;RX`4_-L;R!E;"!P<F]P:65T
M87)I;R!O('5N(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<'5E9&4@8V%M
M8FEA<B!L82!P<F]P:65D860@;R!L;W,@<')I=FEL96=I;W,@9&4@<')O<&EE
M=&%R:6\@9&4@=6X@<F5C=7)S;R!C;VUP87)T:61O`$%B<FER(&5N('5N82!N
M=65V82!V96YT86YA`$5R<F]R($]P96Y34TPZ($YO('-E('!U961E;B!E>'1R
M865R(&1A=&]S(&1E(&QA('!A<G1E(%,O34E-12!F:7)M861A+@!!8G)I<B!E
M<W1E(';M;F-U;&\@96X@=6YA('9E;G1A;F$@;G5E=F$`4VES=&5M82!O<&5R
M871I=F\`3W!C:6]N86P`07-I<W1E;G1E<R!S:6X@8V]N9FER;6%R`$]P8VEO
M;F5S`$]P8VEO;F5S(&1E("5S`$QI<W1A(&]R9&5N861A`$]R9V%N:7IA8VGS
M;@!5;FED860@;W)G86YI>F%T:79A`$]R9V%N:7IA8VGS;@!0;&%N=&EL;&$@
M9&4@87!L:6-A8VGS;B!O<FEG:6YA;`!0;&%N=&EL;&%S(&]R:6=I;F%L97,@
M96X@)7,Z`$]T<F\`3W1R82!I;F9O<FUA8VGS;@!);G1R;V1U8V-I\VX`4')O
M<&EE=&%R:6\`4')I=FEL96=I;W,@9&5L('!R;W!I971A<FEO`%!R;W!I971A
M<FEO.B`E<P!,82!A=71E;G1I9FEC86-I\VX@4$%-(&YO(&5S=.$@9&ES<&]N
M:6)L92X`4$5!4CHZ36]T;W(@9&4@8V]R<F5O`$9I<FUA(&1I9VET86P@4$=0
M`$1A=&]S(&-I9G)A9&]S(&-O;B!01U``0VQA=F4@4$=0('#Z8FQI8V$`1&%T
M;W,@9FER;6%D;W,O8VEF<F%D;W,@8V]N(%!'4`!#\V1I9V\@4$A0`$EN=.ER
M<'(N(%!(4`!030!,;&]V:7IN82!V97-P97)T:6YA`$QL=79I82!V97-P97)T
M:6YA`$-H87!A<G)O;F5S('9E<W!E<G1I;F]S`$YI979E('9E<W!E<G1I;F$`
M06=U86-E<F\@9&4@;FEE=F4@=F5S<&5R=&EN;P!3;VP@=F5S<&5R=&EN;P!"
M;W)R87-C87,@=F5S<&5R=&EN87,`3F\@<V4@96YC=65N=')A(&QA(&5X=&5N
M<VGS;B!03U-)6`!);G3I<G!R+B!07TA0`$UA<F=E;@!086MI<W3A;@!086QA
M=0!086QE<W1I;F]S+"!497)R:71O<FEO<R!/8W5P861O<P!086YA;>$`4&%P
M^F$@3G5E=F$@1W5I;F5A`%!A<F%G=6%Y`%!A<F-I86QM96YT92!N=6)O<V\`
M0V]N=')A<V7Q80!,82!C;VYT<F%S9?%A('-E(&-A;6)I861O(&-O<G)E8W1A
M;65N=&4N`$-O;G1R87-E\6$@:6YC;W)R96-T80!(87D@<75E(&EN=')O9'5C
M:7(@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@4D%$
M2553+@!#;VYT<F%S9?%A(&-O;B!C;VYF:7)M86-I\VX`0V]N=')A<V7Q83H`
M0V]N=')A<V7Q83H@`$QA<R!C;VYT<F%S9?%A<R!T:65N96X@<75E(&-O:6YC
M:61I<BX`3&ES=&%D;R!D92!A8V]N=&5C:6UI96YT;W,@<&%S861O<P!096=A
M<@!096=A<B!D96P@<&]R=&%P87!E;&5S`%;M80!0871R\VX`06QT87,@<&5N
M9&EE;G1E<SH`1V5N=&4`4&]R8V5N=&%J90!296%L:7IA<B!O<&5R86-I;VYE
M<R!D92!M86YT96YI;6EE;G1O`+]296%L:7IA<B!O<&5R86-I;VYE<R!D92!M
M86YT96YI;6EE;G1O(&%L(&EN:6-I87(@<V5S:?-N/P"_16QI;6EN87(@<&5R
M;6%N96YT96UE;G1E(&5S=&4@86-O;G1E8VEM:65N=&\_`%!R:79I;&5G:6\`
M3F\@<V4@:&$@96QI;6EN861O(&5L('!R:79I;&5G:6\@(B5S(BX`4&5R;6ES
M;R!D96YE9V%D;P!0<FEV:6QE9VEO<P!!9&UI;FES=')A8VGS;B!D92!P<FEV
M:6QE9VEO<P!);F9O<FUA8VGS;B!P97)S;VYA;`!097+Z`$UA<V-O=&%S`$9I
M;&EP:6YA<P!496SI9F]N;P!&;W1O9W)A9NUA<P!0:71C86ER;@!0[7AE;&5S
M`%3S<&EC;W,`4'5L<V4@96X@=6YA(&-E;&1A`$-O;F9I<FUE('%U92!D97-E
M82!E;&EM:6YA<B!E<W1E(&5L96UE;G1O.@!#;VYF:7)M92!Q=64@9&5S96$@
M96QI;6EN87(@96P@=NUN8W5L;R!A(&5S=&4@96QE;65N=&\N`$EN=')O9'5Z
M8V$@=6X@;65S('D@=6X@8?%O+@!);G1R;V1U>F-A(&5L(&YO;6)R92!D92!L
M82!N=65V82!C871E9V]R[6$Z`$EN=')O9'5Z8V$@=6YA(&1I<F5C8VGS;B!)
M4"!VX6QI9&$N`$EN=')O9'5Z8V$@=6YA(&9E8VAA(';A;&ED82P@8V]M<')U
M96)E(&5L(&[Z;65R;R!D92!D[6%S(&1E;"!M97,N`$EN=')O9'5Z8V$@=6YA
M(&AO<F$@=N%L:61A+@!0<F]P;W)C:6]N92!U;B!R97-U;65N(&1E;"!P<F]B
M;&5M82X`26YT<F]D=7IC82!S=2!N;VUB<F4@9&4@=7-U87)I;R!Y(&-O;G1R
M87-E\6$N`$QE82!E;"!T97AT;R!S:6=U:65N=&4N($1%0D4@86-E<'1A<B!L
M;W,@=.ER;6EN;W,@<VD@<75I97)E('5S87(@96P@<VES=&5M82X`26YT<F]D
M=7IC82!E;"!N=65V;R!N;VUB<F4@9&4@8V%T96=O<NUA.@!0;VQO;FEA`%!O
M;.UT:6-A`$5N8W5E<W1A<P!/<&-I;VYE<R!D92!P;W)T86P`4&]R='5G86P`
M4&]S:6-I\VX@9&4@;&$@:6UA9V5N`%!O<VEC:?-N(&1E(&QA('1A8FQA`$5N
M=FEA<B!A(&5S=&$@8V%R<&5T82`H;F\@;V)L:6=A9&\@<&]R($E-05`I`%!R
M96-I<&ET86-I;VYE<R!D92!L82AS*2#Z;'1I;6$H<RD@)7,@:&]R82AS*3H@
M`%!R;V)A8FEL:61A9#QB<B`O/F1E('!R96-I<&ET86-I\VX`4')E9G-?;&1A
M<#H@;F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N($Q$05`@<F5Q=65R:61A
M+@!0<F5F<U]S97-S:6]N.B!N;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@
M9&4@<V5S:?-N(')E<75E<FED82X`4')E<VGS;@!0<F5S:?-N(&%L(&YI=F5L
M(&1E;"!M87(Z(`!0<F5S:?-N.B``5FES=&$@<')E=FEA`%9I<W1A('!R979I
M82!D92!L82!I;6%G96X@96X@=6YA(&YU979A('9E;G1A;F$`1.UA(&%N=&5R
M:6]R`%-E;6%N82!A;G1E<FEO<@!$[6$@86YT97)I;W(`3W!C:6]N97,@86YT
M97)I;W)E<P!);7!R:6UI<B!D;V-U;65N=&\`0VQA=F4@<')I=F%D80"_4')O
M8FQE;6%S/P!$97-C<FEP8VGS;B!D96P@<')O8FQE;6$`4')O>65C=&]S`%1E
M>'1O(&1E;"!I;F1U8W1O<@!#;&%V92!01U`@</IB;&EC80!!;&=O<FET;6\@
M9&4@8VQA=F4@</IB;&EC80!);F9O<FUA8VGS;B!D92!C;&%V92!P^F)L:6-A
M`$YO('-E(&=E;F5R87)O;B!C;W)R96-T86UE;G1E(&QA<R!C;&%V97,@4/IB
M;&EC82]0<FEV861A+@!0=65R=&\@4FEC;P!,:6UP:6%R(&UE;G-A:F5S`%%A
M=&%R`$-O;G-U;'1A`%%U;W1A`$-L879E(%)302!P^F)L:6-A("@E9"!B:70I
M`$)O=/-N(&1E(&]P8VGS;@!,;'5V:6$`3&QU=FEA(&UA='5T:6YA`$QL=79I
M82!V97-P97)T:6YA`$%G=6%C97)O`$QL=79I82!Y($YI979E`$QL=79I82!A
M($YI979E`%)U961A(&1E(&QA(&9O<G1U;F$`4F%Z\VX`)FYB<W`[3&5E<B9N
M8G-P.P!,965R(&UE;G-A:F5S`+]%;&EM:6YA<B!R96%L;65N=&4@)7,_($5S
M=&$@;W!E<F%C:?-N(&YO('-E('!U961E(&1E<VAA8V5R+@"_16QI;6EN87(@
M<F5A;&UE;G1E(&QO<R!D871O<R!D96P@=7-U87)I;R`E<S\@17-T82!O<&5R
M86-I\VX@;F\@<V4@<'5E9&4@9&5S:&%C97(N`%)E<&5T:7(@:&%S=&$`4F5P
M971I8VGS;@!$871O<R!A(')E<&5T:7(`1F5C:&$@9&4@9FEN(&1E(')E<&5T
M:6-I\VX`26YT97)V86QO(&1E(')E<&5T:6-I\VX`5&EP;R!D92!R97!E=&EC
M:?-N`%)E<&5T:7(@9&EA<FEA;65N=&4`4F5P971I<B!M96YS=6%L;65N=&4`
M4F5P971I<B!S96UA;F%L;65N=&4`4F5P971I<B!A;G5A;&UE;G1E`%9U96QV
M92!A(')E86QI>F%R(&QA(/IL=&EM82!A8V-I\VX`06-T=6%L:7IA<@!!8W1U
M86QI>F%R(&5L96UE;G1O<R!D92!M96[Z(&1I;N%M:6-O<SH`06-T=6%L:7IA
M<B!V:7-T82!D96P@<&]R=&%L`%)E9V5X`$YA=F5G861O<B!D92!R96QA8VEO
M;F5S`%)E9G)E<V-A<@!/8G-E<G9A8VEO;F5S`%)E8V]R9&%T;W)I;SH@)7,`
M06=E;F1A<R!R96UO=&%S`$%G96YD87,@<F5M;W1A<SH`4V5R=FED;W)E<R!R
M96UO=&]S`%523"!D92!S=7-C<FEP8VGS;B!R96UO=&$`55),(')E;6]T82`H
M:'1T<#HO+W=W=RYE:F5M<&QO+F-O;2]H;W)D92DZ`%%U:71A<@!1=6ET87(@
M)7,`475I=&%R(&%S:7-T96YT90!1=6ET87(@8FQO<75E`%%U:71A<B!C;VQU
M;6YA`$5L:6UI;F%R(&9O<FUA=&\`475I=&%R('!A<@!%;&EM:6YA<B!G=6GS
M;B!G=6%R9&%D;R!D96P@9&ER96-T;W)I;R!T96UP;W)A;"!D96P@<V5R=FED
M;W(N`$5L:6UI;F%R(`!%;&EM:6YA<B!E<W1E(&YO9&\@9&5L(&1O8W5M96YT
M;P!%;&EM:6YA<B!U<W5A<FEO`$5L:6UI;F%R('5S=6%R:6\Z("5S`+]3=7-T
M:71U:7(@;&$@86=E;F1A(&5X:7-T96YT92!C;VX@;&$@:6UP;W)T861A/R`\
M<W1R;VYG/D%V:7-O.B#)<W1O(&5L:6UI;F%RX2!T;V1A<R!L87,@96YT<F%D
M87,@9&4@;&$@86=E;F1A(&%C='5A;"X\+W-T<F]N9SX`3F\@<V4@<'5E9&4@
M<F5S<&]N9&5R(&$@;&$@<V]L:6-I='5D+B!#\V1I9V\@9&4@97)R;W(@9&5V
M=65L=&\Z(`!.;R!S92!E;F-O;G1R\R!E;"!S97)V:6-I;R!S;VQI8VET861O
M+@!297%U97)I9&\`3F\@<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@<F5Q
M=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@)7,N`$YO('-E(&AA(&5S
M<&5C:69I8V%D;R!E;"`B)7,B(')E<75E<FED;R!E;B!L82!C;VYF:6=U<F%C
M:?-N(&1E(%9&4RX`3F\@<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@<F5Q
M=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VXN`$%S:7-T96YT97,@<F5Q=65R
M:61O<P!#86UP;R!N96-E<V%R:6\`3&EM<&EA<@!,:6UP:6%R(&-O;G1R87-E
M\6$`3&EM<&EA<B!C;VYT<F%S9?%A`%)E<W1A=7)A<B!V86QO<F5S('!O<B!O
M;6ES:?-N`%)E<W!U97-T80!297-T875R87(@^FQT:6UA(&-O;G-U;'1A`%)E
M<W5L=&%D;W,`4F5G<F5S87(@82!O<&-I;VYE<P!2965S8W)I8FER(&-O;G1R
M87-E\6$@;G5E=F$`4F5U;FGS;@!297-T875R87(@8V]N9FEG=7)A8VGS;@!/
M<&-I;VYE<R!D92!E9&EC:?-N(&1E('1E>'1O(&5N<FEQ=65C:61O`$-R:6)A
M<P!$97)E8VAA`$-A8F5C97)A(&1E<F5C:&$`5F%L;W)E<R!D92!L82!D97)E
M8VAA`%!R;W!I961A9&5S(&1E(%]F:6QA+BXN`$9U;F-I\VX`4G5M86[M80!'
M:7)A<B`Q.#``1VER87(@82!L82!I>G%U:65R9&$`1VER87(@82!L82!D97)E
M8VAA`%!R;W!I961A9&5S(&1E(&9I;&$`4')O<&EE9&%D97,@9&4@9FEL80!&
M:6QA<SH`4F%Y87,`07!A<F5C97+A;B!R87EA<R!E;G1R92!T;V1A<R!L87,@
M9FEL87,@>2!C;VQU;6YA<P!!<&%R96-E<N%N(')A>6%S('/S;&\@96YT<F4@
M;&%S(&-O;'5M;F%S`$%P87)E8V5RX6X@<F%Y87,@<_-L;R!E;G1R92!L87,@
M9FEL87,`16IE8W5T87(`1F5D97)A8VGS;B!2=7-A`%)U86YD80!&:7)M82!C
M<FEP=&]G<N%F:6-A(%,O34E-10!-96YS86IE(&-I9G)A9&\@96X@4R]-24U%
M`$YO(&5S=.$@9&ES<&]N:6)L92!L82!A=71E;G1I9FEC86-I\VX@4T%33"X`
M365N<RX@4TU3`$EN=.ER<'(N(%-13`!396YT96YC:6$@4U%,('!A<F$@8V]N
M<W5L=&%S(&1E('9A;&]R97,`4U-(`,E8251/`$EN=.ER<'(N(%-?44P`4V%B
M`%-A;G1A($AE;&5N80!386EN="!+:71T<R!Y($YE=FES`%-A;G1A($QU8^UA
M`%-A:6YT(%!I97)R92!Y($UI<75E;&]N`%-A;B!6:6-E;G1E('D@1W)A;F%D
M:6YA<P!-:7-M;R!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%N
M=&\@5&]MX7,@>2!0<NUN8VEP90!0<F]V965D;W(@9&4@<V%TZ6QI=&4`4^%B
M861O`$%R86)I82!3875D:71A`$=U87)D87(`1W5A<F1A<B`B)7,B`$=U87)D
M87(@)7,`1W5A<F1A<B!C;VUO(&YU979O`$=U87)D87(@87-I<W1E;G1E<P!'
M=6%R9&%R`$=U87)D87(@;W!C:6]N97,`1W5A<F1A<B!L82!C;VYF:6=U<F%C
M:?-N(&=E;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0(&5N(&5L(&1I<F5C=&]R
M:6\@=&5M<&]R86P@9&4@<W4@<V5R=FED;W(N`%-E(&AA(&=U87)D861O(&QA
M(&-O;F9I9W5R86-I\VX@9&4@)7,N`$=U87)D87(@9W5I\VX@9&4@86-T=6%L
M:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N(&5N.B`B)7,B+@!";W)R87-C
M87,@86ES;&%D87,`0VEE;F-I80!"=7-C87(`0G5S8V%R(&5N(&%G96YD87,`
M32X@8OIS<75E9&$`4F5S=6QT861O<R!D92!L82!B^G-Q=65D80!"=7-C87(@
M96X@86=E;F1A<R!Q=64@8V]N=&5N9V%N.@!396QE8V-I;VYA<B!A<F-H:79O
M<P!396QE8V-I;VYE('5N82!A9V5N9&$@82!M;V1I9FEC87(`4V5L96-C:6]N
M92!U;F$@9F5C:&$`4V5L96-C:6]N92!E;"!G<G5P;R!A(&'Q861I<@!396QE
M8V-I;VYE('5N(&YU979O('!R;W!I971A<FEO`%-E;&5C8VEO;F4@=6X@<V5R
M=FED;W(`4V5L96-C:6]N92!E;"!U<W5A<FEO(&$@8?%A9&ER`%-E;&5C8VEO
M;F%R('1O9&\`4V5L96-C:6]N92!T;V1O<R!L;W,@8V]M<&]N96YT97,@9&4@
M;&$@9F5C:&$N`%-E;&5C8VEO;F%R('5N(&]B:F5T;P!396QE8V-I;VYE(&QA
M<R!A9V5N9&%S(&UO<W1R861A<SH`4V5L96-C:6]N92!O<&-I;VYE<R!D92!C
M;VYF:7)M86-I\VXL(&/S;6\@;6]S=')A<B!L87,@9&EF97)E;G1E<R!V:7-T
M87,@>2!E<V-O:F5R(&QA('9I<W1A('!O<B!O;6ES:?-N+@!3:6X@<V5L96-C
M:?-N`%-E;&5C8VEO;F4@;&$@86=E;F1A(&$@;&$@<75E(&EM<&]R=&%R.@!3
M96QE8V-I;VYE(&QA*',I(&%G96YD82AS*2!D97-D92!L82AS*2!Q=64@97AP
M;W)T87(`4V5L96-C:6]N92!L;W,@8V%RX6-T97)E<R!Q=64@;F5C97-I=&4@
M9&4@;&%S(&-A<VEL;&%S(&1E(&%B86IO+B!0=65D92!C;W!I87)L;W,@>2!P
M96=A<FQO<R!D96P@X7)E82!D92!T97AT;RX`4V5L96-C:6]N92!E;"!D96QI
M;6ET861O<B!D92!F96-H87,Z`%-E;&5C8VEO;F4@96P@9F]R;6%T;R!D92!F
M96-H87,Z`%-E;&5C8VEO;F4@96P@9F]R;6%T;R!D92!E>'!O<G1A8VGS;CH`
M4V5L96-C:6]N92!E;"!A<F-H:79O(&$@:6UP;W)T87(Z`%-E;&5C8VEO;F4@
M96P@<')I;65R(&3M82!L86)O<F%B;&4Z`%-E;&5C8VEO;F4@96P@9F]R;6%T
M;R!D96P@87)C:&EV;R!O<FEG96XZ`%-E;&5C8VEO;F4@;&$@:61E;G1I9&%D
M('%U92!Q=6EE<F$@8V%M8FEA<CH`4V5L96-C:6]N92!E;"!D96QI;6ET861O
M<B!D92!H;W)A<SH`4V5L96-C:6]N92!E;"!F;W)M871O(&1E(&AO<F%S.@!3
M96QE8V-I;VYE(&5L(&EN=&5R=F%L;R!M;W-T<F%D;SH`4V5L96-C:6]N92!L
M82!V:7-T82!M;W-T<F%D82!A;"!I;FEC:6\Z`%-E;&5C8VEO;F4@9&]S(&-A
M;7!O<R!C;VEN8VED96YT97,N`%-E;&5C8VEO;F4@;&]S(&%C;VYT96-I;6EE
M;G1O<R!M;W-T<F%D;W,@96X@96P@<&]R=&%L+@!396QE8V-I;VYE('-U(&-O
M;6)I;F%C:?-N(&1E(&-O;&]R97,N`%-E;&5C8VEO;F4@<W4@:61I;VUA('!R
M969E<FED;SH`16YV:6%R(&EN9F]R;64@9&4@<')O8FQE;6%S`$5N=FEA<B!3
M35,`06P@8F]R<F%R(&5S=&4@86-O;G1E8VEM:65N=&\L(&5N=FEA<B!U;B!A
M=FES;R!D92!A;G5L86-I\VX@82!T;V1O<R!L;W,@87-I<W1E;G1E<P!%;G9I
M87(@=6X@8V]R<F5O(&$@)7,`06P@9W5A<F1A<B!E<W1E(&%C;VYT96-I;6EE
M;G1O+"!E;G9I87(@86-T=6%L:7IA8VEO;F5S+VEN=FET86-I;VYE<R!A('1O
M9&]S(&QO<R!A<VES=&5N=&5S`%-E;F5G86P`4V5N<V]R.B``4V5P=&EE;6)R
M90!397)B:6$@>2!-;VYT96YE9W)O`$[Z;65R;R!D92!S97)I90!$871O<R!D
M96P@<V5R=FED;W(@97)R\VYE;W,@;R!N;R!D:7-P;VYI8FQE<RX`061M:6YI
M<W1R86-I\VX@9&4@<V5S:?-N`$AA(&-A9'5C861O(&5L($E$(&1E('-E<VGS
M;BX`4V5S:6]N97,`17-T86)L96-E<@!%<W1A8FQE8V5R(&9E8VAA(&9I;F%L
M`$5S=&%B;&5C92!O<&-I;VYE<R!Q=64@;&4@<&5R;6ET96X@<F5A:G5S=&%R
M('-U(&-O;G1R87-E\6$@<VD@;&QE9V%R82!A(&]L=FED87)L82X`17-T86)L
M96-E<B!F96-H82!D92!F:6X@9&4@<F5P971I8VGS;@!%<W1A8FQE8V5R(&9E
M8VAA(&1E(&EN:6-I;P!#;VYF:6=U<F$@<V5R=FED;W)E<R!R96UO=&]S(&$@
M;&]S('%U92!D97-E92!A8V-E9&5R(&1E<V1E(&5L('!O<G1A;"X`1&5F:6YA
M('-U<R!A9V5N9&%S(&1E('1I96UP;R!D:7-P;VYI8FQE('D@<W4@<')O<&EE
M9&%D('D@;&%S(&]P8VEO;F5S(&1E('1I96UP;R!D:7-P;VYI8FQE('!A<F$@
M;W1R;W,@=7-U87)I;W,N`$1E9FEN92!L87,@;W!C:6]N97,@<')E9F5R:61A
M<R!D92!I9&EO;6$L('IO;F$@:&]R87)I82!Y(&9E8VAA<RX`1&5F:6YE(&QA
M(&%P;&EC86-I\VX@9&4@:6YI8VEO+"!L82!C;VUB:6YA8VGS;B!D92!C;VQO
M<F5S+"!L82!A8W1U86QI>F%C:?-N(&1E('#A9VEN82!Y(&]T<F%S(&]P8VEO
M;F5S(&1E('9I<W5A;&EZ86-I\VXN`$-O;F9I9W5R86-I\VX`2&%Y(&=U:6]N
M97,@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N`%9A<FEA
M<R!U8FEC86-I;VYE<R!D:7-P;VYI8FQE<R!C;VX@96P@<&%RX6UE=')O.B``
M4V5Y8VAE;&QE<P!.;R!S92!E;F-O;G1R\R!E;"!R96-U<G-O(&-O;7!A<G1I
M9&\Z("5S+@!!9V5N9&%S(&-O;7!A<G1I9&%S`$%G96YD87,@8V]M<&%R=&ED
M87,Z`$-O;7!R87,`4F5S=6UE;B!C;W)T;P"_1&5F:6YI<B!C;&%V97,@9&4@
M86-C97-O('!A<F$@;&$@;6%Y;W+M82!D92!L;W,@=NUN8W5L;W,_`"9N8G-P
M.TUO<W1R87(F;F)S<#L`36]S=')A<B!A9V5N9&$`OTUO<W1R87(@8V]M96YT
M87)I;W,@9&4@;&%S(&-A=&5G;W+M87,_`$5N(&QA<R!V:7-T87,@9&4@86=E
M;F1A(+]M;W-T<F%R(&QO<R!I8V]N;W,@96QI;6EN87(L(&%L87)M82!Y(')E
M<&5T:6-I\VX_`$UU97-T<F$@;&%S(&1I9F5R96YC:6%S(&5N=')E(&QA(&YU
M979A(&-O;F9I9W5R86-I\VX@>2!L82!A;&UA8V5N861A`+]-;W-T<F%R(&QA
M<R!T87)E87,@=F5N8VED87,@96X@;&$@86=E;F1A/P"_36]S=')A<B!C;VUE
M;G1A<FEO<R!D92!T:65M<&\@9&ES<&]N:6)L93\`OTUO<W1R87(@:&]R82!D
M92!L82#Z;'1I;6$@<V5S:?-N(&%L(&EN:6-I87(_`+]-;W-T<F%R('/S;&\@
M;&]S(&%C;VYT96-I;6EE;G1O<R!C;VX@86QA<FUA/P!-;W-T<F%R(&]P8VGS
M;B!D92!C;VYS97)V87(@96P@;W)I9VEN86P`36]S=')A<B!S96QE8W1O<@"_
M36]S=')A<B!A9V5N9&%S(&-O;7!A<G1I9&%S(&%L(&QA9&\_`+]-;W-T<F%R
M(&QA(&)A<G)A(&1E(&UE;OH@9&4@;W!E<F%C:6]N97,@9&4@=&%B;&$_`+]-
M;W-T<F%R(&QA<R!T87)E87,@8V]N(&QO<R!C;VQO<F5S(&1E(&QA<R!C871E
M9V]R[6%S/P"_36]S=')A<B!E;"!M96[Z("5S(&$@;&$@:7IQ=6EE<F1A/P!-
M=65S=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@8V5L9&$@9&4@
M=&%B;&$`375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E('1A
M8FQA`$UU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!F:6QA
M(&1E('1A8FQA`$UU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E<R!D
M92!I;6%G96X`OTUO<W1R87(@;&%S(&AO<F%S(&5N=')E(&-A9&$@9.UA(&5N
M(&QA<R!V:7-T87,@<V5M86YA;&5S/P!-;W-T<F%R(&-A<F=A`$%G=6%C97)O
M<P!,;'5V:6%S(&UA='5T:6YA<P!,;'5V:6%S('9E<W!E<G1I;F%S`$%G=6%C
M97)O<R!E;B!L82!V96-I;F1A9`!2961U8VER`%!R:6UE<F\@<F5D=7IC82!O
M('%U:71E(&1E(&5N;65D:6\@;&]S(&)L;W%U97,@8V5R8V%N;W,`4VEE<G)A
M($QE;VYA`$%L=&$`1FER;6$`06QG;W)I=&UO(&1E(&9I<FUA`%-I;F=A<'5R
M`%1A;6'Q;P!/;6ET:7(@;6%N=&5N:6UI96YT;P!%<VQO=F%Q=6EA`$5S;&]V
M96YI80!.:65V90!!9W5A8V5R;R!D92!N:65V90!!9W5A8V5R;R!D92!N:65V
M90!!9W5A8V5R;R!D92!N:65V92!M871U=&EN;P!!9W5A8V5R;R!D92!N:65V
M92!V97-P97)T:6YO`$5S<&5S;W(@9&4@;&$@;FEE=F4Z(`!%<75I=F%L96YT
M92!D92!L82!N:65V92!E;B!A9W5A.B``27-L87,@4V%L;VWS;@!3;VUA;&EA
M`$-A;F-I;VYE<R`F(%!O96UA<P!396QE8V-I\VX@9&5L('-E;G1I9&\@9&4@
M;&$@8VQA<VEF:6-A8VGS;@!296UI=&5N=&4`4W5DX69R:6-A`$5U<F]P82!D
M96P@<W5R("A)4T\M.#@U.2TS*0!'96]R9VEA(&1E;"!3=7(@92!)<VQA<R!3
M86YD=VEC:"!D96P@4W5R`$AE;6ES9F5R:6\@<W5R`$5S<&%C:6%D;R!E;G1R
M92!C96QD87,@861Y86-E;G1E<P!%<W!A8VEA9&\@96YT<F4@96P@8V]N=&5N
M:61O('D@96P@8F]R9&4@9&4@=6YA(&-E;&1A`%-E<&%R861O<@!%<W!A8VEA
M9&\`17-P86-I861O('D@;6%R9V5N`$5S<&'Q80!3<&%M`$5S8W)I='5R82!D
M92!C87)A8W1E<F5S(&5S<&5C:6%L97,`1&EV:61I<B!C96QD80!$:79I9&ER
M(&-O;'5M;F$`1&EV:61I<B!F:6QA`$1E<&]R=&5S`%-R:2!,86YK80!%;5]P
M:65Z82!E;`!%<W3A;F1A<@!3=&%R(%1R96L`1F5C:&$@9&4@:6YI8VEO`$5M
M<&EE>F$@96P`2&]R82!D92!I;FEC:6\`0?%O(&1E(&EN:6-I;P!?17-T861O
M`$5S=&%D;R!O('!R;W9I;F-I80!%<W1A9&\`1F]R;6%T;R!D92!A;&UA8V5N
M86UI96YT;P!$:7)E8V-I\VX@9&4@;&$@8V%L;&4`5&%C:&%D80!,:7-T82!D
M92!C861E;F%S`$5L:6UI;F%R(&1O;6EN:6\@9&4@;&$@9&ER96-C:?-N`$5S
M=&EL;R!;0U-370!$;VT`3F\@<V4@96YC;VYT<O,@96P@<W5B9&ER96-T;W)I
M;R`B)7,B+@!!<W5N=&\`16YV:6%R`%-E(&AA(&5N=FEA9&\@=6YA('-O;&EC
M:71U9"!D92!A;'1A(&1E("(E<R(@96X@96P@<VES=&5M82X@3F\@<&]D<N$@
M:6YI8VEA<B!S97-I\VX@:&%S=&$@<75E('-E(&AA>6$@87!R;V)A9&\@;&$@
M<V]L:6-I='5D+@!3=6+M;F1I8V4`R7AI=&\`4V4@:&$@8?%A9&ED;R!C;W)R
M96-T86UE;G1E("(E<R(@86P@<VES=&5M82X`4V4@:&%N(&5L:6UI;F%D;R!C
M;W)R96-T86UE;G1E(&QO<R!D871O<R!D96P@=7-U87)I;R`B)7,B(&1E;"!S
M:7-T96UA+@!392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`B)7,B+@!3
M92!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`B)7,B(&1E;"!S:7-T96UA
M+@!392!H82!R97-T875R861O(&-O<G)E8W1A;65N=&4@;&$@8V]N9FEG=7)A
M8VGS;BX@4F5F<F5S<75E('!A<F$@=F5R(&QO<R!C86UB:6]S+@!392!H82!G
M=6%R9&%D;R!C;W)R96-T86UE;G1A(&QA(&-O<&EA(&1E(&QA(&-O;F9I9W5R
M86-I\VXN`%-E(&AA(&=U87)D861O(&-O<G)E8W1A;65N=&4@;&$@8V]P:6$@
M)7,@9&4@;&$@8V]N9FEG=7)A8VGS;BX`4V4@:&$@86-T=6%L:7IA9&\@8V]R
M<F5C=&%M96YT92`B)7,B`%-E(&AA(&5S8W)I=&\@8V]R<F5C=&%M96YT92`G
M)7,G`%-U9.%N`%)E<W5M96X`06UA;F5C97(`071A<F1E8V5R`$1O;6EN9V\`
M4V]L96%D;P!!;6%N96-E<@!!;6%N96-E<B]!=&%R9&5C97(`06UA;F5C97(Z
M(`!!=&%R9&5C97(`071A<F1E8V5R.B``4W5P97+M;F1I8V4`4V]P;W)T90!3
M=7)I;F%M`$%P96QL:61O`%-V86QB87)D('D@2F%N($UA>65N`%-W87II;&%N
M9&EA`%-U96-I80!3=6EZ80!296=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;B!E
M;&EM:6YA9&\`4WEN8TU,`$5R<F]R(&1E('-I;G1A>&ES(&5N(&QO<R!TZ7)M
M:6YO<R!D92!B^G-Q=65D80!297#Z8FQI8V$@P7)A8F4@9&4@4VER:6$`0VAU
M8F%S8V\`0F]R<F%S8V]S;R!Y('9E;G1O<V\`0F]R<F%S8V%S`$)O<G)A<V-A
M<R!M871U=&EN87,`07)C:&EV;R!44U8`5&%B;&$`4')O<&EE9&%D97,@9&4@
M=&%B;&$`5&%B;&$`4')O<&EE9&%D97,@9&4@=&%B;&$`5&%I=^%N`%1A:7?A
M;BP@4')O=FEN8VEA(&1E($-H:6YA`%1A>6EK:7-TX6X`5&%N>F%N:6$L(%)E
M</IB;&EC82!5;FED82!D90!$97-T:6YO.@!487)E87,`3OIM97)O(&1E('1E
M;.EF;VYO`%1E;7!E<F%T=7)A(&1U<F%N=&4@;&$@^FQT:6UA(&AO<F$Z(`!4
M96UP97)A='5R80!496UP97)A='5R83H@`%1E;7!E<F%T=7)A/&)R("\^*"5S
M3>%X)7,O)7--[6XE<RD@)F1E9SLE<P!.;R!S92!E;F-O;G1R\R!L82!P;&%N
M=&EL;&$@(B5S(BX`061M:6YI<W1R86-I\VX@9&4@<&QA;G1I;&QA<P!0<F]V
M:7-I;VYA;`!497AT;P!3\VQO('1E>'1O`$%L:6YE86-I\VX@9&4@=&5X=&\`
M0F]R9&4@<W5P97)I;W(@9&5L('1E>'1O`$IU90!486EL86YDZ7,@*%1)4RTV
M,C`I`%1A:6QA;F1I80!982!N;R!E<W3A(&1I<W!O;FEB;&4@;&$@<&%N=&%L
M;&$@9&4@;6]D:69I8V%C:?-N(&1E(&%S:7-T96YT97,N(%-A;&EE;F1O+@!.
M;R!E<W3A(&1I<W!O;FEB;&4@;&$@97AT96YS:?-N($944"X`16P@<VES=&5M
M82!H:7-T\W)I8V\@97-TX2!D97-H86)I;&ET861O+@!%;"!M;W1O<B!D92!I
M;G1E9W)A8VGS;B!(;W)D92]+;VQA8B!N;R!S;W!O<G1A("(E<R(`3F\@<V4@
M<'5E9&4@:6YI8VEA<B!E;"!R96=I<W1R;R!D92!)35-0+@!.;R!S92!H82!C
M87)G861O(&-O<G)E8W1A;65N=&4@;&$@8VQA<V4@36%I;G1E;F%N8V4Z.@!3
M92!H82!C97)R861O(&QA('9E;G1A;F$@9&4@;W!C:6]N97,N(%-A;&EE;F1O
M+@!3:2!D97-E82!U=&EL:7IA<B!P97)M:7-O<RP@96P@861M:6YI<W1R861O
M<B!T:65N92!Q=64@8V]N9FEG=7)A<B!U;B!S;W!O<G1E(&1E('!E<FUI<V]S
M('!E<FUA;F5N=&4N`%/S;&\@96P@8F]R9&4@:6YF97)I;W(`3F\@<V4@<'5E
M9&4@96QI;6EN87(@;&$@86=E;F1A("(E<R(N`%-E(&AA(&-R96%D;R!L82!A
M9V5N9&$@(B5S(BX`4V4@:&$@96QI;6EN861O(&QA(&%G96YD82`B)7,B+@!3
M92!H82!R96YO;6)R861O(&QA(&%G96YD82`B)7,B(&-O;6\@(B5S(BX`4V4@
M:&$@9W5A<F1A9&\@;&$@86=E;F1A("(E<R(N`$YO('-E('!U961E(&5L:6UI
M;F%R(&QA(&%G96YD83H@)7,`16P@240@9&5L(&-O;G1A8W1O(&YO('-E(&5S
M<&5C:69I8_,L('-E(&1E:O,@96X@8FQA;F-O(&\@;F\@<V4@96YC;VYT<O,@
M96X@;&$@8F%S92!D92!D871O<RX`4V4@:&$@8?%A9&ED;R!C;W)R96-T86UE
M;G1E(&5L(&-O;G1A8W1O(&$@<W5S(&1I<F5C8VEO;F5S+@!087)A(&-O;7!R
M;V)A<B!E;"!M96YS86IE(&9I<FUA9&\@:&%C92!F86QT82!E;"!B;&]Q=64@
M9&4@9FER;6$@<V5P87)A9&\N`$5L($E$(&1E(&QA(&QI<W1A(&1E(&1I<W1R
M:6)U8VGS;B!N;R!S92!E<W!E8VEF:6/S+"!S92!D96KS(&5N(&)L86YC;R!O
M(&YO('-E(&5N8V]N='+S(&5N(&QA(&)A<V4@9&4@9&%T;W,N`$YO('-E(&5S
M<&5C:69I8_,@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+@!,87,@8V%R86-T
M97+M<W1I8V%S(&1E(&-I9G)A9&\@;F5C97-I=&%N('5N82!C;VYE>&GS;B!W
M96(@<V5G=7)A+@!,82!F96-H82!F:6YA;"!D96)E('-E<B!P;W-T97)I;W(@
M82!L82!F96-H82!I;FEC:6%L+@!392!H82!A\6%D:61O(&5L(&%C;VYT96-I
M;6EE;G1O("(E<R(@82!L82!A9V5N9&$@(B5S(BP@96P@)7,@82!L87,@)7,N
M`%-E(&AA(&5L:6UI;F%D;R!E;"!A8V]N=&5C:6UI96YT;R`B)7,B(&1E(&QA
M(&%G96YD82`B)7,B+"!D96P@)7,@82!L87,@)7,N`%-E(&AA(&UO9&EF:6-A
M9&\@96P@86-O;G1E8VEM:65N=&\@(B5S(B!D92!L82!A9V5N9&$@(B5S(BP@
M96P@)7,@82!L87,@)7,N`%-E(&AA(&5N=FEA9&\@8V]R<F5C=&%M96YT92!A
M("5S(&5L(&%V:7-O(&1E;"!A8V]N=&5C:6UI96YT;RX`16P@87)C:&EV;R`E
M<R!T96YD<NUA('%U92!C;VYT96YE<B!U;F$@;W!C:?-N("5S+@!%;"!A<F-H
M:79O("5S('1E;F1R[6$@<75E(&-O;G1E;F5R(&%L9W5N87,@;W!C:6]N97,@
M)7,N`$YO('-E('!U961E(&-O<&EA<B!E;"!A<F-H:79O('-O8G)E('/M(&UI
M<VUO+@!%;"!A<F-H:79O(&YO(&-O;G1I96YE(&1A=&]S+@!!(&-O;G1I;G5A
M8VGS;B!T:65N92!L87,@8V%B96-E<F%S(&1E(&5S=&4@;65N<V%J92!M97-S
M86=E+W)F8S@R,BX`3&\@<75E('-I9W5E(&5S('5N82!D97-C<FEP8VGS;B!M
MX7,@9&5T86QL861A(&1E;"!A8V]N=&5C:6UI96YT;SH`4V4@<V%B92!Q=64@
M96P@;6]D;R!D92!P86YT86QL82!C;VUP;&5T82!D82!P<F]B;&5M87,@8V]N
M($EN=&5R;F5T($5X<&QO<F5R(&1E8FED;R!A(&9A;&QO<R!D96P@;F%V96=A
M9&]R('%U92!N;R!H96UO<R!P;V1I9&\@<V]S;&%Y87(N(%!U961E('-U9G)I
M<B!V:7-U86QI>F%C:?-N(&1E(&)A<W5R82P@<.ER9&ED82!D92!F=6YC:6]N
M97,@9&5L(&5D:71O<B!Y+V\@8W5E;&=U97,@86QE871O<FEO<R!D96P@;F%V
M96=A9&]R+B!3:2!S=2!S:7-T96UA(&]P97)A=&EV;R!E<R!7:6YD;W=S(#EX
M+"!E<R!M=7D@<')O8F%B;&4@<75E('-U9G)A('5N(&9A;&QO(&1E('!R;W1E
M8V-I\VX@9V5N97)A;"!Y('1E;F=A('%U92!R96EN:6-I87(@96P@97%U:7!O
M+EQN7&Y982!E<W3A(&%V:7-A9&\N(%!U;'-E($%C97!T87(@<VD@8?IN(&1E
M<V5A('!R;V)A<B!E;"!E9&ET;W(@96X@;6]D;R!D92!P86YT86QL82!C;VUP
M;&5T82X`4V4@:&$@96QI;6EN861O(&QA(&ED96YT:61A9"`B)7,B+@!3\VQO
M(&5L(&)O<F1E(&EZ<75I97)D;P!(87D@<75E(&EN9&EC87)L92!A(&QA(&-L
M87-E($-R>7!T7W!G<#HZ(&QA('5B:6-A8VGS;B!D92!L;W,@8FEN87)I;W,@
M1VYU4$<N`%-E(&AA(&UO<W1R861O(&5L(&UE;G-A:F4@96YV:6%D;R!E;"`E
M<R!A("5S(&-O;B!E;"!A<W5N=&\@(B5S(BX*R7-T;R!N;R!G87)A;G1I>F$@
M<75E(&5L(&UE;G-A:F4@:&%Y82!S:61O(&QE:61O(&\@8V]M<')E;F1I9&\N
M`$YO;6)R92!U=&EL:7IA9&\@86P@=FEN8W5L87(@82!L82!PX6=I;F$@9&4@
M8V]M<&]S:6-I\VX`16P@;OIM97)O(&1E(&-A;7!O<R!T:65N92!Q=64@<V5R
M('5N(&[Z;65R;RX`2&%C92!F86QT82!E;"!M\V1U;&\@;W!E;G-S;"!P87)A
M(&QA(&-L87-E($AO<F1E7T-R>7!T7W-M:6UE.CHN`$YO('-E('!U961E(&=U
M87)D87(@;&$@<')E9F5R96YC:6$@(B5S(B!P;W)Q=64@<W5S(&1A=&]S('-O
M8G)E<&%S86X@96P@=&%M8?%O(&WA>&EM;R!P97)M:71I9&\`3F\@<V4@96YC
M;VYT<O,@96X@96P@<VES=&5M82!E;"!P<F]G<F%M82!P87)A('9E<B!E<W1E
M('1I<&\@9&4@9&%T;W,@*"5S*2X`16P@8V%RX6-T97(@9&4@8VET82!D96)E
M('-E<B!S97(@<_-L;R!U;F\N`$QA('!E=&EC:?-N(&5S=&%B82!I;F-O;7!L
M971A+B!#87)E8V4@9&4@=F%R:6]S(&1E(&QO<R!P87+A;65T<F]S(&YE8V5S
M87)I;W,@<&%R82!A8V5P=&%R(&\@<F5C:&%Z87(@=6X@86-O;G1E8VEM:65N
M=&\N`%/S;&\@;&]S(&QA9&]S(&EZ<75I97)D;R!Y(&1E<F5C:&\`4_-L;R!E
M;"!L861O(&1E<F5C:&\`16P@<V5P87)A9&]R(&1E8F4@<V5R('/S;&\@=6YO
M+@!392!H82!E;&EM:6YA9&\@96P@<V5R=FED;W(@(B5S(BX`4V4@:&$@9W5A
M<F1A9&\@96P@<V5R=FED;W(@(B5S(BX`4V4@:&$@96QI;6EN861O(&QA('-O
M;&EC:71U9"!D92!A;'1A(&1E("5S+@!,82!F:6QA(&5S<&5C:69I8V%D82`H
M)60I(&YO(&5X:7-T92X`16P@87)C:&EV;R!T96UP;W)A;"`B)7,B(&YO(&5X
M:7-T92X`16P@=&5X=&\@<75E(&AA(&EN=')O9'5C:61O(&YO(&-O:6YC:61E
M(&-O;B!E;"!D92!L82!P86YT86QL82X`4_-L;R!L;W,@;&%D;W,@<W5P97)I
M;W(@92!I;F9E<FEO<@!3\VQO(&5L(&QA9&\@<W5P97)I;W(`4V4@<&5R9&EE
M<F]N(&QO<R!D871O<R!C87)G861O<R!D97-D92!E;"!P87-O(&%N=&5R:6]R
M+@!.;R!S92!P=61O(&=U87)D87(@96P@87)C:&EV;R!C87)G861O+@!.;R!E
M<W3A(&1I<W!O;FEB;&4@96P@8FQO<75E(&1E('=E871H97(N8V]M+@!.;R!S
M92!E;F-O;G1R\R!E;"!D:7)E8W1O<FEO(&1E(%1E;6%S("(E<R(N`$YO(&AA
M>2!A8V]N=&5C:6UI96YT;W,@8V]I;F-I9&5N=&5S(&-O;B!L;W,@8W)I=&5R
M:6]S(&%C='5A;&5S+@!.;R!S92!D:7-P;VYE(&1E(&]P8VEO;F5S+@!.;R!H
M87D@<&%R=&5S('%U92!S92!P=65D86X@;6]S=')A<B!E;B!L[6YE82X`16X@
M97-T92!C86UP;R!H87D@9&5M87-I861O<R!C87)A8W1E<F5S+B!(82!I;G1R
M;V1U8VED;R`E<R!C87)A8W1E<F5S('D@=&EE;F4@<75E(&EN=')O9'5C:7(@
M;65N;W,@9&4@)7,N`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A9&ER
M(&$@(B5S(B!A;"!S:7-T96UA.B`E<P!392!P<F]D=6IO('5N('!R;V)L96UA
M(&%L(&)O<G)A<B!L;W,@9&%T;W,@9&5L('5S=6%R:6\@(B5S(B!D96P@<VES
M=&5M83H@`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@96QI;6EN87(@82`B
M)7,B(&1E;"!S:7-T96UA.B``4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A
M8W1U86QI>F%R("(E<R(Z("5S`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@8V]N
M(&QA(&-A<F=A(&1E;"!A<F-H:79O.B!.;R!S92!C87)G\R`E<RX`4V4@<')O
M9'5J;R!U;B!P<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N($5L
M("5S(&5R82!MX7,@9W)A;F1E('%U92!E;"!T86UA\6\@;>%X:6UO('!E<FUI
M=&ED;R`H)60@8GET97,I+@!392!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L
M82!C87)G82!D96P@87)C:&EV;RX@4_-L;R!S92!C87)G\R!P87)C:6%L;65N
M=&4@96P@)7,N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@86-C961E<B!A(&QA
M(&%G96YD83H@)7,`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A\6%D:7(@96P@
M86-O;G1E8VEM:65N=&\Z("5S`%-E('!R;V1U:F\@=6X@97)R;W(@86P@;6]S
M=')A<B!E<W1A('!A<G1E(&1E;"!M96YS86IE`%-E('!R;V1U:F\@=6X@97)R
M;W(@86P@;6]D:69I8V%R(&5L(&%C;VYT96-I;6EE;G1O.B`E<P!392!P<F]D
M=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QO<R!D871O<R!D96P@8V]N=&%C
M=&\N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S
M(&E#86QE;F1A<BX`4V4@<')O9'5J;R!U;B!E<G)O<B!E;B!E;"!F;W)M=6QA
M<FEO(&1E(&-O;F9I9W5R86-I\VXN(%!U961E('%U92!H87EA(&]L=FED861O
M(')E;&QE;F%R('5N(&-A;7!O(&YE8V5S87)I;RX`4V4@<')O9'5J;R!U;B!E
M<G)O<B!A;"!T<F%S;&%D87(@96P@86-O;G1E8VEM:65N=&\Z("5S`%-E('!R
M;V1U:F\@=6X@97)R;W(@86P@96IE8W5T87(@;&$@9G5N8VGS;B!E<W!E8VEF
M:6-A9&$@9&4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RX@5G5E;'9A(&$@
M<')O8F%R(&WA<R!A9&5L86YT92X`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!E
M;G9I87(@=6X@879I<V\@9&4@86-O;G1E8VEM:65N=&\@82`E<SH@)7,`4V4@
M<')O9'5J;R!U;B!E<G)O<B!A;"!A8W1U86QI>F%R(&QO<R!D971A;&QE<R!D
M96P@8V]N=&%C=&\N(%9U96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N`%-E
M('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L:7IA<B!L82!L:7-T82!D92!D
M:7-T<FEB=6-I\VXN(%9U96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N`$YO
M(&AU8F\@86-O;G1E8VEM:65N=&]S(&$@97AP;W)T87(N`$5S=&4@<V5R=FED
M;W(@24U!4"!N;R!S;W!O<G1A(&QA<R!C87)P971A<R!C;VUP87)T:61A<RX`
MR7-T92!N;R!P87)E8V4@<V5R('5N(&%R8VAI=F\@<F%R(';A;&ED;RX`R7-T
M92!N;R!P87)E8V4@<V5R('5N(&%R8VAI=F\@>FEP(';A;&ED;RX`R7-T92!N
M;R!P87)E8V4@<V5R('5N(&[Z;65R;R!D92!T87)J971A(';A;&ED;RX`17-T
M92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!A('1R87;I
M<R!D92!L82!P87-A<F5L82!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L
M;"YC;VTI+"!M961I86YT92!L82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R
M('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R
M96QA(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI+"!M961I86YT92!L82!!4$D@
M2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S
M(&$@=')A=NES(&1E(&QA('!A<V%R96QA('-M<S)E;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"YC;VTI+"!M961I86YT92!L82!!4$D@2%144`!%<W1E(&-O;G1R
M;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S('9I82!33510(&$@=')A
M=NES(&1E(&QA('!A<V%R96QA(&1E(%9O9&%F;VYE(&1E($ET86QI82P@<_-L
M;R!A(&[Z;65R;W,@5F]D869O;F4N($AA8V4@9F%L=&$@=6YA(&-U96YT82!D
M92!C;W)R96\@9&4@5F]D869O;F4@9&4@271A;&EA("AH='1P.B\O=W=W+C$Y
M,"YI="DN`$AA8V4@9F%L=&$@97-T92!C86UP;RX`17-T92!C86UP;R!S\VQO
M('!U961E(&-O;G1E;F5R(&5N=&5R;W,N`$5S=&4@8V%M<&\@<_-L;R!P=65D
M92!C;VYT96YE<B!N^FUE<F]S('D@;&]S(&1O<R!P=6YT;W,N`$5S=&4@8V%M
M<&\@<_-L;R!P=65D92!C;VYT96YE<B!V86QO<F5S(&]C=&%L97,N`$5S=&4@
M8V%M<&\@=&EE;F4@<75E('-E<B!U;F$@;&ES=&$@9&4@96YT97)O<R!S97!A
M<F%D;W,@<&]R(&-O;6%S(&\@97-P86-I;W,N`$5S=&4@8V%M<&\@=&EE;F4@
M<75E('-E<B!U;B!N^FUE<F\@=N%L:61O+@!%<W1E(&-A;7!O('1I96YE('%U
M92!C;VYT96YE<B!U;B!C\V1I9F\@9&4@8V]L;W(@96X@9F]R;6%T;R!21T(@
M2&5X861E8VEM86PL('!O<B!E:F5M<&QO("<C,3(S-&%F)RX`17-T92!F;W)M
M871O(&1E(&%R8VAI=F\@;F\@97-TX2!S;W!O<G1A9&\N`%EA('-E(&AA('!R
M;V-E<V%D;R!E<W1E(&9O<FUU;&%R:6\N`$5S=&\@97,@)7,N`,ES=&\@97,@
M=6X@;V)J971O(&1E($MO;&%B($=R;W5P=V%R92X@4&%R82!V97)L;R!N96-E
M<VET82!U;B!C;&EE;G1E(&1E(&-O<G)E;R`@<75E(&5N=&EE;F1A(&5L(&9O
M<FUA=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!U;F$@;&ES=&$@9&4@
M9&EC:&]S(&-L:65N=&5S('9I<VET92`E<P#)<W1O(&5S(&QO('%U92!D:6IO
M(&5L('-E<G9I9&]R.B`E<P!%<W1E(&UE;G-A:F4@<V4@97-C<FEB:?,@8V]N
M('5N(&IU96=O(&1E(&-A<F%C=&5R97,@*"5S*2!D:7-T:6YT;R!A;"!S=7EO
M+@!%<W1E(&[Z;65R;R!D96)E('-E<B!P;W(@;&\@;65N;W,@=6X@=6YO+@!%
M<W1E('-E<G9I9&]R(&YO('!U961E(&1E<V-O;7!R:6UI<B!A<F-H:79O<R!Z
M:7`@>2!G>FEP+@!%<W1E('-I<W1E;6$@86-T=6%L;65N=&4@97-TX2!D97-A
M8W1I=F%D;RX`17-T92!V86QO<B!T:65N92!Q=64@<V5R('5N(&[Z;65R;RX`
M17-T82!V96YT86YA('/S;&\@<'5E9&4@86)R:7)S92!D97-D92!U;F$@=F5N
M=&%N82!D92!O<&-I;VYE<P!4<G5E;F\`2G5E=F5S`$EN8VED96YC:6%S`$AO
M<F$`26YT95]R=F%L;P!#+B!T:65M<&]S`$9O<FUA=&\@:&]R87)I;P!396QE
M8V-I\VX@9&4@:&]R80!);G1E<G9A;&\`5&EM;W(M3&5S=&4`7U3M='5L;P!4
M[71U;&\`5.UT=6QO("AC;VYS96IO*3H`4&%R80!087)A('-E;&5C8VEO;F%R
M('9A<FEO<R!C86UP;W,L(&UA;G1E;F=A('!U;'-A9&$@;&$@=&5C;&$@0V]N
M=')O;"`H4$,I(&\@0V]M86YD;R`H36%C*2!A;"!H86-E<B!C;&EC:RX`2&]Y
M`$-O;FUU=&%R(&]R:6=E;B!(5$U,`%1O9V\`5&]K96QA=0!-8?%A;F$`5&]N
M9V$`4W5P97)I;W(`1G)A;64@<W5P97)I;W(@*%]T;W`I`%1R861U8V-I;VYE
M<P!4<FEN:61A9"!Y(%1O8F%G;P!697)D861E<F\@;R!F86QS;P!-87(`36%R
M=&5S`%3Z;F5Z`%1U<G%U[6$`5'5R8V\@*$E33RTX.#4Y+3DI`%1U<FMM96YI
M<W3A;@!)<VQA<R!4=7)K<R!Y($-A:6-O<P!4=79A;'4`5&EP;P!%<V-R:6)A
M('-U(&5L96-C:?-N.B``S6YD:6-E(%4N5BXZ(`!54DP`55),(&1E('-U(&EN
M9F]R;64@9&4@97-T861O(&1E(&5N=NUO(&1E;"!G=6GS;@!54DPZ`%5G86YD
M80!58W)A;FEA`$EN8V%P87H@9&4@86-C961E<B!A;"!D:7)E8W1O<FEO(%9&
M4RX`26YC87!A>B!D92!A\6%D:7(@:6YF;W)M86-I\VX@9&4@=7-U87)I;R!A
M9&EC:6]N86P@86P@<F5A;&EZ87(@96P@86QT82X`26YC87!A>B!D92!C86UB
M:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C:&EV;R!61E,@(B5S(BX`26YC
M87!A>B!D92!C86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C:&EV;R!6
M1E,@)7,O)7,N`$EN8V%P87H@9&4@8V%M8FEA<B!A("5S+@!);F-A<&%Z(&1E
M(&-O;7!R;V)A<B!E;"!T86UA\6\@9&4@(B5S(BX`26YC87!A>B!D92!C;VUP
M<F]B87(@96P@=&%M8?%O(&1E("(E<R\E<R(N`$EN8V%P87H@9&4@8V]N96-T
M87)S92!A;"!S97)V:61O<B!344PN`$EN8V%P87H@9&4@8V]N96-T87(@8V]N
M(%-33"X`26YC87!A>B!D92!C;W!I87(@96P@87)C:&EV;R!61E,N`$EN8V%P
M87H@9&4@8W)E87(@96P@9&ER96-T;W)I;R!61E,@(B5S(BX`26YC87!A>B!D
M92!C<F5A<B!E;"!D:7)E8W1O<FEO(%9&4RX`26YC87!A>B!D92!C<F5A<B!E
M;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!C<F5A<B!L82!C87)P971A(%9&
M4R`B)7,B`$EN8V%P87H@9&4@8W)E87(@=6X@87)C:&EV;R!61E,@=F%C[6\N
M`$EN8V%P87H@9&4@9&5S8V]M<')I;6ER(&QO<R!D871O<RX`26YC87!A>B!D
M92!E;&EM:6YA<B`B)7,B+"!E;"!D:7)E8W1O<FEO(&YO(&5S=.$@=F%C[6\N
M`$EN8V%P87H@9&4@96QI;6EN87(@(B5S(CH@)7,`26YC87!A>B!D92!E;&EM
M:6YA<B`B)7,B.B`E<RX`26YC87!A>B!D92!E;&EM:6YA<B`E<RP@96P@9&ER
M96-T;W)I;R!N;R!E<W3A('9A8^UO`$EN8V%P87H@9&4@96QI;6EN87(@96P@
M9&ER96-T;W)I;R!61E,@9&4@9F]R;6$@<F5C=7)S:79A+@!);F-A<&%Z(&1E
M(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(&5L:6UI
M;F%R(&5L(&1I<F5C=&]R:6\@5D93.B`E<RX`26YC87!A>B!D92!E;&EM:6YA
M<B!E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L
M(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&QA(&-A<G!E=&$@
M5D93("(E<R(N`$EN8V%P87H@9&4@96QI;6EN87(@96P@5D93(&1E(&9O<FUA
M(')E8W5R<VEV83H@)7,N`$EN8V%P87H@9&4@9&5T97)M:6YA<B!E;"!D:7)E
M8W1O<FEO(&%C='5A;"X`26YC87!A>B!D92!E>'1R865R(&QO<R!D971A;&QE
M<R!D96P@8V5R=&EF:6-A9&\N`$EN8V%P87H@9&4@8V%R9V%R(&QA(&1E9FEN
M:6-I\VX@9&4@)7,N`$EN8V%P87H@9&4@=')A<VQA9&%R(&5L(&%R8VAI=F\@
M5D93+@!);F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI=F\@5D93("(E<R(N`$EN
M8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!61E,@<&%R82!E<V-R:6)I<BX`
M26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!A
M8G)I<B!E;"!A<F-H:79O(&-O;7!R:6UI9&\N`$EN8V%P87H@9&4@;&5E<B!U
M;B!A<F-H:79O(%9&4R`H:&$@9F%L;&%D;R!F:6QE<VEZ92@I*2X`26YC87!A
M>B!D92!L965R('5N(&%R8VAI=F\@5D93("AH82!F86QL861O(&=E=$9I;&53
M:7IE*"DI+@!);F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV;SH@`$EN8V%P87H@
M9&4@;&5E<B!E;"!D:7)E8W1O<FEO('9F<W)O;W0N`$EN8V%P87H@9&4@<F5N
M;VUB<F%R("(E<R(Z("5S`$EN8V%P87H@9&4@<F5N;VUB<F%R("5S(&-O;6\@
M)7,Z(&QA(&-A<G!E=&$@9&5S=&EN;R!Y82!E>&ES=&4`26YC87!A>B!D92!R
M96YO;6)R87(@96P@9&ER96-T;W)I;R!61E,N`$EN8V%P87H@9&4@<F5N;VUB
M<F%R(&5L(&1I<F5C=&]R:6\@5D93.B`E<RX`26YC87!A>B!D92!R96YO;6)R
M87(@96P@87)C:&EV;R!61E,@(B5S(@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E
M;"!A<F-H:79O(%9&4R`E<R\E<RX`26YC87!A>B!D92!R96YO;6)R87(@96P@
M87)C:&EV;R!61E,N`$EN8V%P87H@9&4@<F5C=7!E<F%R(&QA(&EN9F]R;6%C
M:?-N(&1E('1I96UP;R!D:7-P;VYI8FQE(&1E("5S`$EN8V%P87H@9&4@96IE
M8W5T87(@)VUK:7-O9G,G+@!.;R!S92!P=65D92!T<F%D=6-I<B!E<W1E(&1O
M8W5M96YT;R!D92!7;W)D`$EN8V%P87H@9&4@97-C<FEB:7(@96P@87)C:&EV
M;R!61E,@(B5S(BX`26YC87!A>B!D92!E<V-R:6)I<B!U;B!A<F-H:79O(%9&
M4R`H:&$@9F%L;&%D;R!C;W!Y*"DI+@!);F-A<&%Z(&1E(&5S8W)I8FER(&QO
M<R!D871O<R!D96P@87)C:&EV;R!61E,N`$EN8V%P87H@9&4@97-C<FEB:7(@
M=6X@87)C:&EV;R!61E,L('-E('-U<&5R87+A(&QA('%U;W1A+@!3=6)R87EA
M9&$`1&5S:&%C97(@8V%M8FEO<P!$97-H86-E(&QA(/IL=&EM82!A8V-I\VX`
M4F5S<'5E<W1A(&EN97-P97)A9&$@9&5L('-E<G9I9&]R(&5N(&QA(&-O;F5X
M:?-N.B``4F5S<'5E<W1A(&EN97-P97)A9&$@9&5L('-E<G9I9&]R(&$Z(`!3
M:6X@8V%T96=O<NUA`%5N:6-O9&4@*%541BTX*0!%;6ER871O<R#!<F%B97,@
M56YI9&]S`$EN9VQA=&5R<F$`17-T861O<R!5;FED;W,`17-T861O<R!5;FED
M;W,@;65N;W,@;&%S(&ES;&%S('!E<FEFZ7)I8V%S`%5N:61A9&5S`$1E<V-O
M;F]C:61O`$%P:6US9VED(&1E<V-O;F]C:61O("A)1"!D92!M96YS86IE(&1E
M(&QA($%022DN`$-L:6US9VED(&1E<V-O;F]C:61O("A)1"!D92!M96YS86IE
M(&1E;"!C;&EE;G1E*2X`4V4@:&$@9&5F:6YI9&\@=6YA('5B:6-A8VGS;B!D
M97-C;VYO8VED82X`57-U87)I;R!O(&-O;G1R87-E\6$@9&5S8V]N;V-I9&]S
M+@!%;&EM:6YA<B!V[6YC=6QO(&1E;"!E;&5M96YT;R!A8W1U86P`4VEN(&YO
M;6)R90!,;W,@9W5I;VYE<R!S:6X@<')I=FEL96=I;W,@;F\@<'5E9&5N(&%C
M8V5D97(@9&4@9F]R;6$@<')O9W)A;>%T:6-A(&$@0V]R=&%R+T-O<&EA<B]0
M96=A<B!P;W(@<F%Z;VYE<R!D92!S96=U<FED860N(%!U;'-E($%C97!T87(@
M<&%R82!V97(@96X@;6]Z:6QL82YO<F<@=6YA(&YO=&$@=.EC;FEC82!Q=64@
M;&4@;75E<W1R92!C\VUO('!E<FUI=&ER('%U92!U;B!G=6GS;B!A8V-E9&$@
M86P@<&]R=&%P87!E;&5S+@!!;G5L87(@8V]L;W(`5&EP;R!D92!C;VYT96YI
M9&\@;F\@<V]P;W)T861O.B`E<P!%>'1E;G-I\VX@;F\@<V]P;W)T861A`$%C
M='5A;&EZ87(`06-T=6%L:7IA<B`E<P!!8W1U86QI>F%R('5S=6%R:6\`4V4@
M:&$@86-T=6%L:7IA9&\@(B5S(BX`06-T=6%L:7IA9&\Z("5S+@!392!H82!E
M;&EM:6YA9&\@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;BX`0V%R9V%R`%-E
M(&AA;B!C87)G861O(&5N(&5L('-E<G9I9&]R('1O9&]S(&QO<R!A<F-H:79O
M<R!D92!C;VYF:6=U<F%C:?-N(&1E(&%P;&EC86-I;VYE<RX`06QF86)E=&\@
M;&%T:6YO(&5N(&UA>?IS8RX`3OIM97)O<R!R;VUA;F]S(&5N(&UA>?IS8RX`
M57)U9W5A>0!5<V%R(&%C='5A;#H@)7,`57-A<B!34TP`4V4@=7-A('-I(&5L
M('5S=6%R:6\O8V]N=')A<V7Q82!S;VX@9&ES=&EN=&]S(&5N(&5L('-E<G9I
M9&]R($E-4U`N`%5S=6%R:6\`16P@=7-U87)I;R`E<R!C87)E8V4@9&4@875T
M;W)I>F%C:?-N('!A<F$@)7,N`$%D;6EN:7-T<F%C:?-N(&1E('5S=6%R:6]S
M`$EN=&5R9F%Z(&1E('5S=6%R:6\`3W!C:6]N97,@9&4@=7-U87)I;P!296=I
M<W1R;R!D92!U<W5A<FEO<P!%<W1A('-E9&4@=&EE;F4@9&5S86-T:79A9&\@
M96P@<F5G:7-T<F\@9&4@=7-U87)I;W,N`$YO('-E(&AA(&5N8V]N=')A9&\@
M;&$@:61E;G1I9&%D`%5S=6%R:6\`66$@97AI<W1E(&5L(&YO;6)R92!D92!U
M<W5A<FEO("(E<R(N`%5S=6%R:6\Z`%5S=6%R:6\Z(`!5<W5A<FEO<R!E;B!E
M;"!S:7-T96UA.@!5>F)E:VES=.%N`$YO(&5X:7-T92!E;"!D:7)E8W1O<FEO
M(%9&4RX`075S96YC:6$`3&%S('5B:6-A8VEO;F5S(';A;&ED87,@96YC;VYT
M<F%D87,@:6YC;'5Y96XZ(`!686QI9&5Z`%9A;&]R(&5N(&UI;G5T;W,@82!P
M87)T:7(@9&4@86AO<F$N`$5L('9A;&]R(&5X8V5D92!E;"!T86UA\6\@;>%X
M:6UO(&1E("5S+@!686QO<F5S`%9A;&]R97,@82!S96QE8V-I;VYA<@!686YU
M871U`%9A<FEA8FQE`%9E;F5Z=65L80!(82!F86QL861O(&QA(&-O;7!R;V)A
M8VGS;B`M(&5S=&4@;65N<V%J92!P=65D92!H86)E<G-E(&9O<GIA9&\N`%9E
M<G-I\VX`0RX@=F5R<VEO;F5S`$%L:6YE86-I\VX@=F5R=&EC86P`36%R9V5N
M('9E<G1I8V%L`%9E<G1I8V%L.@!-=7D@86QT80!6:65T;F%M`%9I971N86UI
M=&$@*%9)4T-)22D`5F5R("5S`%9E<B!D[6$`5F5R('5N82!PX6=I;F$@=V5B
M(&5X=&5R;F$`5F5R(&-O;6\@)7,`27-L87,@5NUR9V5N97,L($)R:73A;FEC
M87,`27-L87,@5NUR9V5N97,L(%4N4RX`5FES:6)I;&ED860`5FES:6)I;&ED
M860Z(`!6;V1A9F]N92!D92!)=&%L:6$@;65D:6%N=&4@4TU44`!!5DE33P"A
MH:%!1%9%4E1%3D-)02$A(2!%3$E-24Y%($U!3E5!3$U%3E1%($5,($=52=-.
M($1%("5S+@!724X@<&]R($A45%``5V%L;&ES('D@1G5T=6YA`$%D=F5R=&5N
M8VEA`$UI90!0<F5V:7-I\VX@9&5L('1I96UP;P!$871O<R!D96P@=&EE;7!O
M('-U;6EN:7-T<F%D;W,@<&]R`%=E871H97(N8V]M`%=E8@!3961E(%=E8@!-
M:>ER8V]L97,`4V5M86YA`%-E;6%N82`E9`!396UA;F$H<RD`4V5M86YA;&UE
M;G1E`%-E;6%N86QM96YT93H@4V4@<F5P:71E(&-A9&$`0FEE;G9E;FED;P!"
M:65N=F5N:61O<R!A("5S`$)I96YV96YI9&\L("5S`$]E<W1E("A)4T\M.#@U
M.2TQ*0!/97-T92`H25-/+3@X-3DM,34I`%/A:&%R82!/8V-I9&5N=&%L`+]1
M=>D@87!L:6-A8VGS;B!D96)E<NUA(&UO<W1R87(@)7,@86P@:6YI8VEA<B!L
M82!S97-I\VX_`+]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E;&EM:71A9&]R/P"_
M0W7A;"!E<R!E;"!C87+A8W1E<B!D92!C:71A9&\_`+]%;B!Q=>D@:&]R82!T
M97)M:6YA<N%N(&QA<R!V:7-T87,@9&4@9.UA('D@<V5M86YA+"!S:2!N;R!H
M87D@86-O;G1E8VEM:65N=&]S('!O<W1E<FEO<F5S/P"_16X@<77I(&AO<F$@
M96UP97IA<N%N(&QA<R!V:7-T87,@9&4@9.UA('D@<V5M86YA+"!S:2!N;R!H
M87D@86-O;G1E8VEM:65N=&]S(&%N=&5R:6]R97,_`$UA<&$@9&4@;&]C86QI
M>F%C:?-N(&1E($%U<W1R86QI80!1=>D@9F%S97,`4&QU9VEN<R!H86)I;&ET
M861O<R!D96P@961I=&]R(&1E('1E>'1O(&5N<FEQ=65C:61O+@!!;F-H=7)A
M`$%N8VAU<F$@96X@=6YI9&%D97,@0U-3`$%N8VAU<F$@9&5L(&UE;OH@)7,@
M:7IQ=6EE<F1O("AD:7-P;VYI8FQE(&5N(&QA('!R\WAI;6$@<V5S:?-N*3H`
M06YC:'5R82!D92!L82!T86)L80!5;FED861E<R!D92!A;F-H=7)A`$%N8VAU
M<F$Z`%=I:VD`5FEE;G1O`%9I96YT;R!M871U=&EN80!696QO8VED860@9&5L
M('9I96YT;R!E;B!N=61O<P!6:65N=&\Z`%9I96YT;SH@`%-A8FED=7+M80!$
M97-E;W,`16UP;&5O`$1I<F5C8VGS;B!D96P@=')A8F%J;P!496SI9F]N;R!D
M96P@=')A8F%J;P!3+B!L86)O<F%L`$[Z;65R;R!E<G+S;F5O(&1E(&-A;7!O
M<R!E;B!L82!L[6YE82`E9"X@4V4@97-P97)A8F%N("5D('D@:&%Y("5D+@!.
M^FUE<F\@97)R\VYE;R!D92!C86UP;W,N(%-E(&5S<&5R86)A;B`E9"!Y(&AA
M>2`E9"X`3V9F<V5T("5D(&5R<O-N96\@86P@;&5E<B!U;B!A<F-H:79O(%9&
M4RX`6"U2968`3&EM:71A8VEO;F5S(&+A<VEC87,@6#4P.78S`%5S;R!D92!C
M;&%V92!E>'1E;F1I9&$@6#4P.78S`$YO;6)R92!A;'1E<FYA=&EV;R!D92!A
M<W5N=&\@6#4P.78S`$ED96YT:69I8V%D;W(@9&4@8VQA=F4@9&4@87-U;G1O
M(%@U,#EV,P!%>'1E;G-I;VYE<R!8-3`Y=C,`04$`04%!00"A36%P82!D92!9
M86AO;R$`0?%O`$%N=6%L;65N=&4`06YU86QM96YT93H@4V4@<F5P:71E(&-A
M9&$`665M96X`4^T`4^TL(&QO(&%C97!T;P!%<W3A(&5N($U/1$\@5$585$\N
M(%5T:6QI8V4@96P@8F]T\VX@6SP^72!P87)A(')E9W)E<V%R(&%L(&UO9&\@
M5UE325=91RX`3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A(&-R96%R
M(&WA<R!D92`E9"!B;&]Q=65S+@!.;R!D:7-P;VYE(&1E('!R:79I;&5G:6]S
M('!A<F$@8W)E87(@;>%S(&1E("5D(&%C;VYT96-I;6EE;G1O<RX`3F\@97,@
M=6X@87-I<W1E;G1E(&1E;"!A8V]N=&5C:6UI96YT;R!I;F1I8V%D;RX`3F\@
M97-TX2!A=71E;G1I9FEC861O+@!%<W1E(&9O<FUU;&%R:6\@<_-L;R!P=65D
M92!U<V%R;&\@9&5S9&4@;&$@<&%N=&%L;&$@9&4@;6]D:69I8V%C:?-N(&1E
M(&%S:7-T96YT97,N`$YO('!U961E(&EN8VQU:7(@96P@8V%RX6-T97(@(EPB
M(&5N(&5L(&YO;6)R92!C;VUP;&5T;RX`3F\@:6YT<F]D=6IO('5N82!D:7)E
M8V-I\VX@9&4@8V]R<F5O(';A;&ED82X`3F\@87-O8VGS(&YI;F=U;F\@9&4@
M;&]S(&-A;7!O<R!D96P@87)C:&EV;R!I;7!O<G1A9&\@82!L;W,@8V%M<&]S
M(&-O<G)E<W!O;F1I96YT97,@9&4@)7,N`$YO(&AA(&-O;F9I9W5R861O('5N
M82!D:7)E8V-I\VX@9&4@8V]R<F5O(&5N(&QA<R!P<F5F97)E;F-I87,@9&4@
M<W4@:61E;G1I9&%D+B!4:65N92!Q=64@:6YD:6-A<B!U;F$@)7-A<77M)7,@
M<&%R82!P;V1E<B!E;G9I87(@879I<V]S(&1E(&%C;VYT96-I;6EE;G1O<RX`
M3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A(&'Q861I<B!A8V]N=&5C
M:6UI96YT;W,@82`E<RX`3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A
M(&'Q861I<B!A8V]N=&5C:6UI96YT;W,@82!L82!A9V5N9&$@<V5L96-C:6]N
M861A+@!.;R!D:7-P;VYE(&1E('!R:79I;&5G:6]S('!A<F$@96QI;6EN87(@
M97-T92!A8V]N=&5C:6UI96YT;RX`3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO
M<R!P87)A(&UO9&EF:6-A<B!E<W1E(&%C;VYT96-I;6EE;G1O+@!(82!S86QI
M9&\@9&4@;&$@<V5S:?-N+@!(82!E<W!E8VEF:6-A9&\@=6YA(&%G96YD82!N
M;R!VX6QI9&$N`$AA(&%C97!T861O('-A=&ES9F%C=&]R:6%M96YT92!L82!A
M<VES=&5N8VEA(&$@97-T92!A8V]N=&5C:6UI96YT;RX`2&$@<F5C:&%Z861O
M('-A=&ES9F%C=&]R:6%M96YT92!L82!A<VES=&5N8VEA(&$@97-T92!A8V]N
M=&5C:6UI96YT;RX`2&$@86-E<'1A9&\@8V]N9&EC:6]N86QM96YT92!L82!A
M<VES=&5N8VEA(&$@97-T92!A8V]N=&5C:6UI96YT;RX`5&EE;F4@<75E(&EN
M=')O9'5C:7(@=6X@;OIM97)O(&1E('1E;.EF;VYO(&WS=FEL(';A;&ED;RP@
M<_-L;R!D[6=I=&]S(&-O;B!U;B`G*R<@;W!C:6]N86P@<&%R82!E;"!P<F5F
M:6IO(&1E(&QL86UA9&$@:6YT97)N86-I;VYA;"X`5&EE;F4@<75E(&EN=')O
M9'5C:7(@=6X@=F%L;W(@=N%L:61O+@!087)A('5S87(@06QT87,@=&EE;F4@
M<75E(&-O;F9I9W5R87(@=6X@;6]T;W(@9&4@1&%T851R964N`%1I96YE('%U
M92!C;VYF:6=U<F%R('5N(&UO=&]R(%9&4RX`1&5B92!D97-C<FEB:7(@96P@
M<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&5L(&EN9F]R;64N`%1I96YE('%U
M92!I;G1R;V1U8VER(&QA(%523"!A(&QA('%U92!A<'5N=&$@97-T92!V[6YC
M=6QO`%1I96YE('%U92!S96QE8V-I;VYA<B!U;F$@86=E;F1A(&$@96QI;6EN
M87(N`%!R:6UE<F\@=&EE;F4@<75E('-E;&5C8VEO;F%R('5N82!D:7)E8V-I
M\VXN`%1I96YE('%U92!S96QE8V-I;VYA<B!U;B!S97)V:61O<B!A(&5L:6UI
M;F%R+@!4:65N92!Q=64@97-P96-I9FEC87(@=6X@=7-U87)I;R!A(&5L:6UI
M;F%R+@!4:65N92!Q=64@97-P96-I9FEC87(@=6X@=7-U87)I;R!A(&5L:6UI
M;F%R+@!4:65N92!Q=64@97-P96-I9FEC87(@96P@=7-U87)I;R!A(&'Q861I
M<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S=6%R:6\@82!A8W1U86QI
M>F%R+@!4:65N92!Q=64@97-P96-I9FEC87(@<77I(&%C8VGS;B!S92!E:F5C
M=71A<N$N`%1I96YE('%U92!I;G1R;V1U8VER('5N(&YU979O(&YO;6)R92!D
M92!C871E9V]R[6$N`%1I96YE('%U92!I;G1R;V1U8VER('5N(&[Z;65R;R!D
M92!T96SI9F]N;R!I=&%L:6%N;P!(86+M82!S;VQI8VET861O(&QA(&YO=&EF
M:6-A8VGS;B!D92!L82!A9&EC:?-N(&1E(&%C;VYT96-I;6EE;G1O<R!A('-U
M<R!C86QE;F1A<FEO<RX`2&%B[6$@<V]L:6-I=&%D;R!L82!N;W1I9FEC86-I
M\VX@9&4@;&$@96QI;6EN86-I\VX@9&4@86-O;G1E8VEM:65N=&]S(&1E('-U
M<R!C86QE;F1A<FEO<RX`2&%B[6$@<V]L:6-I=&%D;R!L82!N;W1I9FEC86-I
M\VX@9&4@;&$@;6]D:69I8V%C:?-N(&1E(&%C;VYT96-I;6EE;G1O<R!D92!S
M=7,@8V%L96YD87)I;W,N`%-O;&EC:73S('%U92!S92!L92!E;G9I87)A;B!R
M96-O<F1A=&]R:6]S(&1E("5S+"!Q=64@97-T87+A(&5N("5S(&$@;&%S("5S
M+@!(82!E>'!I<F%D;R!S=2!S97-I\VX@)7,N(%9U96QV82!A(&EN:6-I87(@
M<V5S:?-N+@!3=2!D:7)E8V-I\VX@9&4@8V]R<F5O`$1I<F5C8VGS;B!$93H`
M4W4@:6YF;W)M86-I\VX`2&$@8V%M8FEA9&\@<W4@9&ER96-C:?-N(&1E($EN
M=&5R;F5T(&1E<V1E(&5L(&-O;6EE;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R
M(')A>F]N97,@9&4@<V5G=7)I9&%D('1I96YE('%U92!V;VQV97(@82!I;FEC
M:6%R(&QA('-E<VGS;BX`4W4@;F]M8G)E`%-U(&UO=&]R(&1E(&%U=&5N=&EF
M:6-A8VGS;B!N;R!P97)M:71E(&'Q861I<B!U<W5A<FEO<RX@4VD@<75I<VEE
M<F$@=7-A<B!(;W)D92!P87)A(&%D;6EN:7-T<F%R(&-U96YT87,@9&4@=7-U
M87)I;RP@=&5N9'+A('%U92!U=&EL:7IA<B!U;B!M;W1O<B!D92!A=71E;G1I
M9FEC86-I\VX@9&ES=&EN=&\N`%-U(&UO=&]R(&1E(&%U=&5N=&EF:6-A8VGS
M;B!N;R!P97)M:71E(&QI<W1A<B!U<W5A<FEO<RP@;R!S92!H82!D97-H86)I
M;&ET861O(&QA(&-A<F%C=&5R[7-T:6-A('!O<B!A;&?Z;B!M;W1I=F\N`%!A
M<F5C92!Q=64@:&$@8V%M8FEA9&\@<W4@;F%V96=A9&]R(&1E<V1E(&5L(&-O
M;6EE;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R(')A>F]N97,@9&4@<V5G=7)I
M9&%D('1I96YE('%U92!V;VQV97(@82!I;FEC:6%R(&QA('-E<VGS;BX`4W4@
M;F%V96=A9&]R(&YO(&%D;6ET92!E<W1A(&-A<F%C=&5R[7-T:6-A+@!%;"!N
M879E9V%D;W(@;F\@861M:71E(&5S=&$@;W!C:?-N(&1E(&EM<')E<VGS;BX@
M4')E<VEO;F4@0V]N=')O;"]#;VUA;F1O("L@4"!P87)A(&EM<')I;6ER+@!:
M;VYA(&AO<F%R:6$@86-T=6%L.@!3=2!A9V5N9&$@<&]R(&]M:7-I\VX`4V4@
M:&$@8V%M8FEA9&\@<W4@:61E;G1I9&%D('!O<B!O;6ES:?-N+@!)9&5N=&ED
M860@<&]R(&]M:7-I\VXZ`$YO;6)R92!C;VUP;&5T;SH`4V4@:&$@86=O=&%D
M;R!S=2!T:65M<&\@9&4@8V]N97AI\VXN`$QA(&YU979A(&-O;G1R87-E\6$@
M<&%R82`E<R!E<SH@)7,`4V4@:&%N(&%C='5A;&EZ861O('-U<R!O<&-I;VYE
M<R!S\VQO('!O<B!L82!D=7)A8VGS;B!D92!L82!S97-I\VXN`%-E(&AA;B!A
M8W1U86QI>F%D;R!S=7,@;W!C:6]N97,N`%-E(&AA(')E86IU<W1A9&\@<W4@
M8V]N=')A<V7Q80!392!H82!R96%J=7-T861O('-U(&-O;G1R87-E\6$L(&-O
M;7!R=65B92!E;"!C;W)R96\@92!I;FEC:64@<V5S:?-N(&-O;B!S=2!N=65V
M82!C;VYT<F%S9?%A+@!,82!C;VYT<F%S9?%A(&AA(&5X<&ER861O+@!397)V
M:61O<F5S(')E;6]T;W,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A
M8G=E`%II<'!Y`%M/8W5L=&%R('1E>'1O(&-I=&%D;UT`6TEN9F]R;64@9&4@
M<')O8FQE;6%=`%M-;W-T<F%R('1E>'1O(&-I=&%D;R`M`%M-;W-T<F%R('1E
M>'1O(&-I=&%D;R`M("5S(&SM;F5A<UT`6T%C;VYT96-I;6EE;G1O('-I;B!N
M;VUB<F5=`%ML[6YE82`E<R!D92`E<UT`7T%D;6EN:7-T<F%C:?-N`%]!;&%R
M;6$`0OIS7W%U961A('-I;7!L90!?0TQ)`,%R7V)O;"!D871O<P!%7VQI;6EN
M87(@9FEL80!-;U]D:69I8V%R`$E?<B!A`%]'<G5P;W,`05]Y=61A`%!R;W!I
M961A9&5S(&1E(%]I;6%G96XN+BX`7TEM<&]R=&%R+T5X<&]R=&%R`%]);FEC
M:6%R('-E<VGS;@!?4V%L:7(`36]D:69I8V%R(%]V[6YC=6QO+BXN`%]-:7,@
M86=E;F1A<P!?0?%A9&ER`%]/<&-I;VYE<P!?4')I=FEL96=I;W,`26U?<')I
M;6ER`%]%;&EM:6YA<B!V[6YC=6QO+BXN`%]"=7-C87(`0V]N7V9I9W5R86,N
M`%!R;W!I961A9&5S(&1E(%]T86)L82XN+@!?2&]Y`%]5<W5A<FEO<P!D:7)E
M8V-I;VYE<P!D97-T:6YA=&%R:6\@9&5S8V]N;V-I9&\`86YT97,@9&4@<75E
M(&5M<&EE8V4@96P@86-O;G1E8VEM:65N=&\`86=E;F1A`&-A;&UA`&YO('-E
M('!U961E(&-R96%R(&5L(&%R8VAI=F\@9&4@9&5S=&EN;P!N;R!S92!P=65D
M92!A8G)I<B!E;"!O<FEG96X`<'5L<V4@87%U[0!E<G)O<B!D92!L[6YE82!D
M92!C;VUA;F1O`&5R<F]R(&1E(&-O;F9I9W5R86-I\VX`9F%L=&$@=6X@87)C
M:&EV;R!C<NUT:6-O(&1E;"!S:7-T96UA`&5R<F]R(&1E(&9O<FUA=&\@9&4@
M9&%T;W,`9.UA`&3M82AS*0!D[6%S`&UO9&EF:6-A<@!E;G1R861A(&YO(&5N
M8V]N=')A9&$`86-O;G1E8VEM:65N=&]S+F-S=@!A8V]N=&5C:6UI96YT;W,N
M:6-S`&1E<V-E;G-O`&%R8VAI=F\`9&5L("5S("@E<RD@82!L87,@)7,@)7,`
M=F5N=&]S;P!H.@!H:`!N;VUB<F4@9&4@86YF:71R:?-N(&1E<V-O;F]C:61O
M`&EN;65D:6%T86UE;G1E`&5N`&5N(&SM;F5A`&5R<F]R(&1E(&5N=')A9&$O
M<V%L:61A`&5R<F]R(&1E('-O9G1W87)E(&EN=&5R;F\`;.UN96%S70!C\V1I
M9V\@9&4@97)R;W(@;6MI<V]F<R`E9"!A;"!R96%L:7IA<B!)4T\N`&UM`&UE
M<RAE<RD`;F]M8G)E`'-I;B!D97-A<G)O;&QA<@!A^FX@;F\@<V4@:&$@9&5S
M87)R;VQL861O`&YO=&%S`&5L("5S(&$@;&%S("5S`&5N(&QA(&UI<VUA(&9E
M8VAA`&5N(&5L(&UI<VUO(&3M82!L86)O<F%B;&4`<&]R8V5N=&%J90!P<FEV
M:6QE9VEO(&1E;F5G861O`'#M>&5L97,`97)R;W(@<F5M;W1O(&1E('!R;W1O
M8V]L;P!E;B!A=6UE;G1O`'-E<G9I8VEO(&YO(&1I<W!O;FEB;&4N`&UO<W1R
M87(@9&EF97)E;F-I87,`<VUS,F5M86EL('!O<B!(5%10`'-S`&5S=&%B;&4`
M97)R;W(@9&5L('-I<W1E;6$`=&%R96%S`&9A;&QO('1E;7!O<F%L`&5S8W)I
M8F$@9&]S('9E8V5S(&QA(&-O;G1R87-E\6$@<&%R82!C;VYF:7)M87)L80!U
M;FEF:6-A9&\`<VEN(&YO;6)R90!U<W5A<FEO('-E;&5C8VEO;F%D;P!V0V%L
M96YD87(O:4-A;&5N9&%R`'9#87)D`$YO('-E(&5N8V]N='+S(&5L('9%=F5N
M="X`=SH`=V5A=&AE<BYC;VT`<V5M86YA`'-E;6%N82AS*2!E;CH`<V5M86YA
M<P!A\6\H<RD`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O97-?15,O:&5L
M<"YX;6P`````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34R,3$`,3`T,3<S
M-C(W-3``,#(R,S,V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@
M:W)O;F]L:71H+VQO8V%L92]E<U]%4R]H96QP+GAM;"QV(#$N,2`R,#`T+S$R
M+S$Q(#$Q.C4T.C`W(&IA;B!%>'`@)"`M+3X*/&AE;'`^"@H\96YT<GD@:60]
M(D]V97)V:65W(B!M9#4](C$U.#4Y,C=D-#AE-#8R-V,W.3)F93`S,S)C-#%F
M9#,Y(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DMR;VYO;&ET:#H@
M26YT<F]D=6-C:28C>$8S.VX\+W1I=&QE/@H@("`@/&AE861I;F<^)B-X0D8[
M474F(WA%.3L@97,@:W)O;F]L:71H/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@2W)O;F]L:71H(&5S('5N82!A<&QI8V%C:28C>$8S.VX@9&4@86=E;F1A
M(&)A<V%D82!E;B!W96(N($%D96TF(WA%,3MS(&1E(&QA<R!F=6YC:6]N97,@
M:&%B:71U86QE<R!D92!C<F5A8VDF(WA&,SMN+"!M;V1I9FEC86-I)B-X1C,[
M;B!Y(&5L:6UI;F%C:28C>$8S.VX@9&4@86-O;G1E8VEM:65N=&]S+"!S;W!O
M<G1A(&%C;VYT96-I;6EE;G1O<R!R96-U<G)E;G1E<R`H8V]N(&5X8V5P8VEO
M;F5S('D@9&EV97)S87,@;W!C:6]N97,@9&4@96QI;6EN86-I)B-X1C,[;BDL
M(&%L87)M87,L(&9U;F-I;VYE<R!D92!I;7!O<G1A8VDF(WA&,SMN('D@97AP
M;W)T86-I)B-X1C,[;B`H96X@9F]R;6%T;W,@:4-A;&5N9&%R('D@4&%L;2!$
M871A0F]O:R`H4$1"*2DL(&EN=FET86-I;VYE<R!I0V%L96YD87(L(&TF(WA&
M03ML=&EP;&5S('9I<W1A<RP@86=E;F1A<R!C;VUP87)T:61A<RP@=FES=6%L
M:7IA8VDF(WA&,SMN(&1E('1A<F5A<R!D92!.86<@*'-I(&QA<R!487)E87,@
M97-T)B-X13$[;B!I;G-T86QA9&%S*2!Y(&QA(&-A<&%C:61A9"!D92!M;W-T
M<F%R(&%C;VYT96-I;6EE;G1O<R!E;B!L82!P86YT86QL82!D92!R97-U;65N
M(&1E($AO<F1E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)M
M96YU+71O9&%Y(B!M9#4](F,V9#!C,&8S-C8Q-S5A,SAD,#8U-65D.3DV.65D
M-&$V(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE;B8C>$9!.SH@
M2&]Y/"]T:71L93X*("`@(#QH96%D:6YG/DAO>3PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@16P@96QE;65N=&\@/&D^2&]Y/"]I/B!D96P@;65N)B-X1D$[
M(&UO<W1R87(F(WA%,3L@;&$@=FES=&$@<&]R(&]M:7-I)B-X1C,[;B`H;65N
M<W5A;"P@<V5M86YA;"P@9&EA<FEA+"!E=&,N('-E9R8C>$9!.VX@<V4@:&%Y
M82!C;VYF:6=U<F%D;R!E;B!L87,@3W!C:6]N97,I(&1E(&QA(&9E8VAA(&%C
M='5A;"X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB;65N=2U'
M;W1O(B!M9#4](C4V-C$Y,3<W-6)A.3!B-S8Y9C)E,V8W8V1F,C1C8F9A(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE;B8C>$9!.SH@27(@83PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY)<B!A/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%;"!E;&5M96YT;R`\:3Y)<B!A/"]I/B!D96P@;65N)B-X1D$[(&UO
M<W1R87(F(WA%,3L@=6YA('!E<75E)B-X1C$[82!V96YT86YA(&1E<W!L96=A
M8FQE(&5N(&QA('%U92!P;V1R)B-X13$[('-E;&5C8VEO;F%R('(F(WA%,3MP
M:61A;65N=&4@=6X@828C>$8Q.V\L(&UE<RP@<V5M86YA(&\@9"8C>$5$.V$@
M86P@<75E(#QI/DER(&$\+VD^+B!3=65L92!S97(@;&$@9F]R;6$@;28C>$4Q
M.W,@<B8C>$4Q.W!I9&$@9&4@9&5S<&QA>F%R<V4@9&5N=')O(&1E(&QA(&%G
M96YD82X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB;65N=2U$
M87DB(&UD-3TB,V-D-C)E,3`Q,38P-3AD8C4R83$U9F5C9#=D9&)C8C`B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^365N)B-X1D$[.B!$)B-X140[
M83PO=&ET;&4^"B`@("`\:&5A9&EN9SY6:7-T82!D:6%R:6$\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($5L(&5L96UE;G1O(#QI/D0F(WA%1#MA/"]I/B!D
M96P@;65N)B-X1D$[(&UO<W1R87(F(WA%,3L@=6YA('9I<W1A(&1I87)I82!D
M96P@9"8C>$5$.V$@<V5L96-C:6]N861O(&%C='5A;&UE;G1E+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)M96YU+7=O<FLM=V5E:R(@;60U
M/2)F.6$V,S4X-6,X,61C838S.#@W93$S,&1B8F5A.3%D92(@<W1A=&4](G5P
M=&]D871E(CX*("`@(#QT:71L93Y-96XF(WA&03LZ(%-E;6%N82!L86)O<F%L
M/"]T:71L93X*("`@(#QH96%D:6YG/E9I<W1A(&1E('-E;6%N82!L86)O<F%L
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;"!E;&5M96YT;R`\:3Y3+B!L
M86)O<F%L/"]I/B!D96P@;65N)B-X1D$[(&UO<W1R87(F(WA%,3L@;&$@=FES
M=&$@9&4@<V5M86YA(&QA8F]R86P@*&1E(&QU;F5S(&$@=FEE<FYE<RD@;28C
M>$4Q.W,@861E8W5A9&$@9&5L(&0F(WA%1#MA('-E;&5C8VEO;F%D;R!A8W1U
M86QM96YT92X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB;65N
M=2UW965K(B!M9#4](C-D.&$S8F9D838R.6)B-F4P.3@Q.6(R938V,#4T-F4U
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE;B8C>$9!.SH@4V5M
M86YA/"]T:71L93X*("`@(#QH96%D:6YG/E9I<W1A('-E;6%N86P\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5L(&5L96UE;G1O(#QI/E-E;6%N83PO:3X@
M9&5L(&UE;B8C>$9!.R!M;W-T<F%R)B-X13$[('5N82!V:7-T82!S96UA;F%L
M("AD92`W(&0F(WA%1#MA<RD@9&4@;&$@<V5M86YA('%U92!C;VYT96YG82!E
M;"!D)B-X140[82!S96QE8V-I;VYA9&\@86-T=6%L;65N=&4N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"@H\96YT<GD@:60](FUE;G4M;6]N=&@B(&UD-3TB-&)E
M,C`U-C@W-3<W-65C,68U8C!F.3(P83%D86(V,#@B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^365N)B-X1D$[.B!-97,\+W1I=&QE/@H@("`@/&AE
M861I;F<^5FES=&$@;65N<W5A;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M16P@96QE;65N=&\@/&D^365S/"]I/B!D96P@;65N)B-X1D$[(&UO<W1R87(F
M(WA%,3L@;&$@=FES=&$@;65N<W5A;"!D96P@;65S('%U92!C;VYT96YG82!E
M;"!D)B-X140[82!S96QE8V-I;VYA9&\@86-T=6%L;65N=&4N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"@H\96YT<GD@:60](FUE;G4M;F5W+65V96YT(B!M9#4]
M(C,W-#`V8V,R964U,3`T,#@V,F1F,65A83)F-C0U9#1E(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/DUE;B8C>$9!.SH@028C>$8Q.V%D:7(\+W1I
M=&QE/@H@("`@/&AE861I;F<^028C>$8Q.V%D:7(@=6X@86-O;G1E8VEM:65N
M=&\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5L(&5L96UE;G1O(#QI/D$F
M(WA&,3MA9&ER/"]I/B!D96P@;65N)B-X1D$[(&QE('!E<FUI=&ER)B-X13$[
M(&$F(WA&,3MA9&ER('5N(&%C;VYT96-I;6EE;G1O(&$@;&$@86=E;F1A+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)M96YU+6]P=&EO;G,B
M(&UD-3TB9#=D9C)C,&-D83@T8S@Y8S8S.&0Y9#9E-3DS,#<Y-S8B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^365N)B-X1D$[.B!/<&-I;VYE<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY/<&-I;VYE<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@16P@96QE;65N=&\@/&D^3W!C:6]N97,\+VD^(&1E;"!M96XF
M(WA&03L@;&4@<&5R;6ET92!C;VYF:6=U<F%R(#QI/D]P8VEO;F5S/"]I/B`H
M;R!P<F5F97)E;F-I87,I('%U92!C;VYT<F]L86X@96P@87-P96-T;R!Y(&-O
M;7!O<G1A;6EE;G1O(&1E(&MR;VYO;&ET:"P@<W4@:6YT97)A8V-I)B-X1C,[
M;B!C;VX@2&]R9&4@>2!C;VX@96P@<F5S=&\@9&4@;&%S(&%P;&EC86-I;VYE
M<RP@9V5S=&EO;F%R('9A<FEA<R!A9V5N9&%S('D@8V]M<&%R=&ER;&%S(&%S
M)B-X140[(&-O;6\@9V5S=&EO;F%R(&,F(WA&,SMD:6=O<R!D92!C871E9V]R
M)B-X140[87,@<&%R82!L;W,@86-O;G1E8VEM:65N=&]S+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)M96YU+6EM<&]R="UE>'!O<G0B(&UD
M-3TB,S1B8SED9F,T9#8S,#)F8S$P,3$V.39A,6(X9#%C83@B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^365N)B-X1D$[.B!);7!O<G1A<B]%>'!O
M<G1A<CPO=&ET;&4^"B`@("`\:&5A9&EN9SY);7!O<G1A<B]%>'!O<G1A<CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16P@96QE;65N=&\@/&D^26UP;W)T
M87(O17AP;W)T87(\+VD^(&1E;"!M96XF(WA&03L@;&4@<&5R;6ET92!I;7!O
M<G1A<B!O(&5X<&]R=&%R(&%C;VYT96-I;6EE;G1O<R!D92!L82!A9V5N9&$N
M($%C='5A;&UE;G1E('-E('!U961E;B!I;7!O<G1A<B!A<F-H:79O<R!E;B!F
M;W)M871O($-35BP@3W5T;&]O:R!D92!-:6-R;W-O9G0L(%!A;&T@1&%T94)O
M;VL@>2!V0V%L96YD87(O:4-A;&5N9&%R+B!3)B-X1C,[;&\@<V4@<'5E9&4@
M97AP;W)T87(@82!F;W)M871O<R!#4U8@92!I0V%L96YD87(N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"@H\96YT<GD@:60](F%L87)M<R(@;60U/2(T8S%C-F8S
M96(Q,V$T,38P,S%F9F)E931F8V4Y.65A,2(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93Y!;&%R;6%S/"]T:71L93X*("`@(#QH96%D:6YG/D%L87)M
M87,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($MR;VYO;&ET:"!P=65D92!G
M96YE<F%R(&%L87)M87,@<&%R82!L;W,@86-O;G1E8VEM:65N=&]S(&1E('5N
M82!A9V5N9&$N(%!O<B!O;6ES:28C>$8S.VX@;&$@<')I;65R82!A;&%R;6$@
M<V4@<')O9'5C:7(F(WA%,3L@,34@;6EN=71O<R!A;G1E<R!D92!L82!H;W)A
M('!R979I<W1A(&1E(&EN:6-I;R!D96P@86-O;G1E8VEM:65N=&\L('!E<F\@
M<V4@<'5E9&4@8V]N9FEG=7)A<B`H<&%R82!C861A(&%C;VYT96-I;6EE;G1O
M*2!P87)A('%U92!S92!P<F]D=7IC82!P<B8C>$4Q.V-T:6-A;65N=&4@82!C
M=6%L<75I97(@:6YT97)V86QO(&%N=&5S(&1E(&QA(&AO<F$@>2!F96-H82!P
M<F5V:7-T87,N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](G)E
M8W5R<FEN9RUE=F5N=',B(&UD-3TB.#-A,&,S83AA,F0R9C5C93AB-34Q,&)D
M83(U-38T,V0B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^06-O;G1E
M8VEM:65N=&]S(')E8W5R<F5N=&5S/"]T:71L93X*("`@(#QH96%D:6YG/D%C
M;VYT96-I;6EE;G1O<R!R96-U<G)E;G1E<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@3&]S(&%C;VYT96-I;6EE;G1O<R!S92!P=65D96X@:&%C97(@<F5C
M=7)R96YT97,@9&4@=F%R:6%S(&9O<FUA<RX@3&$@;6%Y;W(F(WA%1#MA(&1E
M(&QO<R!A8V]N=&5C:6UI96YT;W,@<V4@<F5P:71E;B!D92!C:65R=&%S(&9O
M<FUA<R!H86)I='5A;&5S+B!0;W(@96IE;7!L;RP@96P@=&EP;R!D92!R96-U
M<G)E;F-I82`\:3Y-96YS=6%L/"]I/B!P<F]V;V-A('%U92!E;"!E;&5M96YT
M;R!S96QE8V-I;VYA9&\@<V4@<F5P:71A(&-A9&$@;65S('D@96P@=&EP;R`\
M:3Y396UA;F%L/"]I/B!Q=64@;&\@:&%G82!C861A('-E;6%N82X@4V4@<'5E
M9&5N('5T:6QI>F%R('!A<F$@<F5F;&5J87(@86-O;G1E8VEM:65N=&]S('%U
M92!S92!R97!I=&%N(&1E(&9O<FUA<R!C;VUP;&5J87,Z('!O<B!E:F5M<&QO
M+"!U;B!E;&5M96YT;R!Q=64@<W5C961A(&-A9&$@)B-X1D$[;'1I;6\@=FEE
M<FYE<R!D92!C861A(&UE<R!O(&QO<R!L=6YE<RP@;6DF(WA%.3MR8V]L97,@
M>2!V:65R;F5S(&1E(&-A9&$@<V5M86YA+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("!486UB:28C>$4Y.VX@<V4@<'5E9&4@;&EM:71A<B!L82!D=7)A
M8VDF(WA&,SMN(&1E(&QA<R!R97!E=&EC:6]N97,@9&4@=6X@86-O;G1E8VEM
M:65N=&\@<V5L96-C:6]N86YD;R!U;F$@/&D^9F5C:&$@9FEN86P\+VD^+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!.;W)M86QM96YT92P@;&$@;6]D
M:69I8V%C:28C>$8S.VX@9&4@=6X@86-O;G1E8VEM:65N=&\@<F5C=7)R96YT
M92!S92!A<&QI8V%R)B-X13$[(&$@=&]D87,@;&%S(')E<&5T:6-I;VYE<R!D
M96P@;6ES;6\N(%-E('!U961E(&UO9&EF:6-A<B!U;F$@<F5P971I8VDF(WA&
M,SMN(&EN9&EV:61U86P@9&4@=6X@86-O;G1E8VEM:65N=&\@<F5C=7)R96YT
M92!M;V1I9FEC86YD;R!L82!R97!E=&EC:28C>$8S.VXL(&5L:6UI;F%N9&\@
M;&$@:6YF;W)M86-I)B-X1C,[;B!D92!R96-U<G)E;F-I82!Y('-E;&5C8VEO
M;F%N9&\@;&$@;W!C:28C>$8S.VX@/&D^1W5A<F1A<B!C;VUO(&YU979O/"]I
M/B!D96P@;65N)B-X1D$[(&1E(')E8W5R<F5N8VEA+B!%;"!A8V]N=&5C:6UI
M96YT;R!S96QE8V-I;VYA9&\@<V4@<&]D<B8C>$4Q.R!M;V1I9FEC87(@96YT
M;VYC97,@9&4@9F]R;6$@:6YD97!E;F1I96YT92!A(&QA<R!O=')A<R!R97!E
M=&EC:6]N97,@9&5L(&UI<VUO+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N
M=')Y(&ED/2)0<FEN=&EN9R(@;60U/2(R9CDP9#$T93,T8C<Q-6$P-31F8C4R
M8F(Y,3EA8S5F."(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y);7!R
M97-I)B-X1C,[;CPO=&ET;&4^"B`@("`\:&5A9&EN9SY);7!R97-I)B-X1C,[
M;B!D92!A9V5N9&%S('D@86-O;G1E8VEM:65N=&]S/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!$971E<FUI;F%D87,@=FES=&%S('-E(&AA;B!D:7-E)B-X
M1C$[861O(&-O;B!E;"!O8FIE=&EV;R!D92!P;V1E<B!I;7!R:6UI<G-E+B!3
M:2!S92!E<W0F(WA%,3L@96X@=6YA(&1E(&5L;&%S+"!A<&%R96-E<B8C>$4Q
M.R!E;"!I8V]N;R`\:3Y);7!R:6UI<CPO:3X@96X@;&$@8F%R<F$@9&4@;65N
M)B-X1D$[('-U<&5R:6]R+B!5=&EL:6-E(&1I8VAO(&EC;VYO('!A<F$@:6UP
M<FEM:7(@;&$@=FES=&$@86-T=6%L+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*
M/"]H96QP/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]L;V-A;&4O9FE?1DDO````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``,#(P-C0U`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]F:5]&22],
M0U]-15-304=%4R\`````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<U,``P,C(T,S(`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI
M=&@O;&]C86QE+V9I7T9)+TQ#7TU%4U-!1T53+VMR;VYO;&ET:"YM;P``````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P-#<V,34S`#$P-#$W,S8R-S4P`#`R-3`Q-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#>$@25`````.\(```<````
ME$<``.D+```,CP```````+"^```.````L;X```\```#`O@``#0```-"^```(
M````WKX```L```#GO@``#````/.^```$`````+\``!@````%OP``&P```!Z_
M```M````.K\``!T```!HOP``)````(:_```I````J[\``!D```#5OP``)@``
M`.^_```,````%L```!(````CP```)````#;````)````6\````\```!EP```
M"P```'7````?````@<````X```"AP```!0```+#````H````ML````@```#?
MP```"@```.C````5````\\```!(````)P0``"P```!S!```,````*,$``!T`
M```UP0``A0```%/!```.````V<$```H```#HP0``#0```//!```.`````<(`
M`!$````0P@``#0```"+"```,````,,(```T````]P@``!@```$O"``"4````
M4L(``$\```#GP@``'0```#?#```=````5<,```H```!SPP``#P```'[#```8
M````CL,```P```"GPP``"@```+3#```'````O\,```8```#'PP``#@```,[#
M```*````W<,```H```#HPP``#@```//#```(`````L0```H````+Q```"0``
M`!;$```E````(,0``"@```!&Q```)````&_$```F````E,0``"X```"[Q```
M&@```.K$```R````!<4``#@````XQ0``5````''%``!1````QL4``%H````8
MQ@``5P```'/&```T````R\8```(`````QP``"0````/'```-````#<<```<`
M```;QP``"@```"/'```/````+L<```4````^QP``!@```$3'```1````2\<`
M``@```!=QP``"0```&;'```)````<,<```@```!ZQP``)0```(/'```@````
MJ<<``!,```#*QP``$````-['```/````[\<```H```#_QP``$`````K(```#
M````&\@```\````?R```%````"_(```)````1,@```D```!.R```#0```%C(
M```2````9L@``!D```!YR```'@```)/(```9````LL@```\```#,R```#P``
M`-S(```-````[,@```H```#ZR```#P````7)```(````%<D``"0````>R0``
M%````$/)```0````6,D``!8```!IR0``"````(#)``!.````B<D``"T```#8
MR0``&0````;*```'````(,H```P````HR@``+````#7*```.````8LH```,`
M``!QR@``#P```'7*```+````A<H```4```"1R@``%````)?*```5````K,H`
M`!<```#"R@``%0```-K*```2````\,H``!,````#RP``%0```!?+```3````
M+<L```H```!!RP``%````$S+```*````8<L```<```!LRP``!P```'3+```%
M````?,L```4```""RP``"@```(C+```#````D\L```T```"7RP``%P```*7+
M```*````O<L```H```#(RP``"````-/+```/````W,L```L```#LRP``!P``
M`/C+```-`````,P```H````.S```#@```!G,```8````*,P``",```!!S```
M#@```&7,```4````=,P``!<```")S```%P```*',```7````N<P``!,```#1
MS```#P```.7,```.````]<P``!\````$S0``'0```"3-```'````0LT```8`
M``!*S0``"````%'-```/````6LT```8```!JS0``"@```''-```3````?,T`
M``,```"0S0``"P```)3-```0````H,T``!4```"QS0``%0```,?-```'````
MW<T``!````#ES0``!0```/;-```5````_,T``!$````2S@``#````"3.```[
M````,<X``#@```!MS@``"0```*;.```'````L,X``!0```"XS@```P```,W.
M```%````T<X``!````#7S@``"0```.C.```3````\LX``#D````&SP``$@``
M`$#/```"````4\\``+0```!6SP``)P````O0```L````,]```"H```!@T```
M)0```(O0```*````L=````D```"\T```"@```,;0```&````T=````D```#8
MT```!P```.+0```O````ZM```#<````:T0``+@```%+1``!5````@=$``"T`
M``#7T0``+0````72```]````,](``#\```!QT@``+0```+'2``!`````W](`
M`",````@TP``(P```$33``!`````:-,``"T```"ITP``,P```-?3```E````
M"]0``!4````QU```&0```$?4```I````8=0``"0```"+U```*````+#4```1
M````V=0```H```#KU```#````/;4```*`````]4``!`````.U0``%@```!_5
M```6````-M4```<```!-U0``!P```%75```4````7=4```H```!RU0``"```
M`'W5```G````AM4```@```"NU0``#````+?5```'````Q-4```<```#,U0``
M!@```-35```%````V]4```<```#AU0``!@```.G5```(````\-4``"D```#Y
MU0``#@```"/6```*````,M8```0````]U@``!P```$+6```)````2M8```8`
M``!4U@``$0```%O6```'````;=8``!8```!UU@``!````(S6```(````D=8`
M``8```":U@``#0```*'6```&````K]8``!X```"VU@``$0```-76```(````
MY]8```T```#PU@``#````/[6```'````"]<```0````3UP```P```!C7```#
M````'-<``!<````@UP``"0```#C7```3````0M<``!T```!6UP``"0```'37
M```(````?M<``!````"'UP``'0```)C7```)````MM<``!L```#`UP``!```
M`-S7```(````X=<```@```#JUP``00```//7```:````-=@``"L```!0V```
M(````'S8```9````G=@``!4```"WV```!@```,W8```&````U-@``!4```#;
MV```"0```/'8```-````^]@``!@````)V0``(@```"+9```N````1=D``!T`
M``!TV0``(0```)+9``!4````M-D``"D````)V@``"@```#/:```'````/MH`
M``<```!&V@``"0```$[:```5````6-H```@```!NV@``#@```'?:```*````
MAMH```\```"1V@``#0```*':```/````K]H```T```"_V@``"0```,W:```4
M````U]H```8```#LV@``&````//:```=````#-L``!,````JVP``$0```#[;
M```4````4-L```0```!EVP``!@```&K;```4````<=L``%0```"&VP``9```
M`-O;```$````0-P```X```!%W```!0```%3<```%````6MP``!L```!@W```
M&@```'S<```3````E]P``!$```"KW```$0```+W<```<````S]P``$X```#L
MW```10```#O=``!%````@=T``"H```#'W0``-@```/+=```^````*=X``#\`
M``!HW@``'0```*C>```0````QMX``"$```#7W@``!0```/G>```3````_]X`
M``L````3WP``$P```!_?```2````,]\```H```!&WP``#P```%'?```-````
M8=\``!$```!OWP``$P```('?```,````E=\```P```"BWP``!@```*_?```,
M````MM\```8```##WP``%P```,K?```0````XM\``!$```#SWP``"`````7@
M```%````#N````P````4X```$````"'@```%````,N````T````XX```!@``
M`$;@```6````3>````<```!DX```#0```&S@```'````>N````L```""X```
M!P```([@```'````EN````D```">X```"0```*C@```*````LN```!D```"]
MX```/0```-?@```=````%>$```P````SX0``$````$#A```;````4>$```D`
M``!MX0``!0```'?A```E````?>$``!(```"CX0``$P```+;A```K````RN$`
M`#L```#VX0``(````#+B```(````4^(``#8```!<X@``(0```)/B```0````
MM>(```@```#&X@``#````,_B```&````W.(```0```#CX@``#P```.CB```.
M````^.(``$`````'XP``!P```$CC```*````4.,```T```!;XP``'P```&GC
M```<````B>,``"$```"FXP``'@```,CC```9````Y^,``!X````!Y```&P``
M`"#D```A````/.0``"X```!>Y```)@```(WD```<````M.0``!X```#1Y```
M'````/#D```F````#>4``"L````TY0``,P```&#E```F````E.4``"L```"[
MY0``.````.?E```=````(.8``!4````^Y@``+P```%3F```@````A.8``!(`
M``"EY@``*0```+CF```>````XN8``"`````!YP``$@```"+G``"B````-><`
M`!8```#8YP``(P```._G```H````$^@``"D````\Z```*````&;H```?````
MC^@``!4```"OZ```(````,7H```E````YN@``"@````,Z0``+0```#7I```P
M````8^D``)(```"4Z0``(0```"?J```6````2>H``!P```!@Z@``)@```'WJ
M```J````I.H``$$```#/Z@``1````!'K```,````5NL```<```!CZP``!P``
M`&OK```&````<^L```\```!ZZP``$@```(KK```-````G>L``!````"KZP``
M$@```+SK```'````S^L``!,```#7ZP``$@```.OK```'````_NL```0````&
M[```!P````OL```0````$^P``!`````D[```#````#7L```.````0NP```T`
M``!1[```#P```%_L```3````;^P```T```"#[```*````)'L```#````NNP`
M``T```"^[```!@```,SL```1````T^P``!<```#E[```&P```/WL```.````
M&>T```(````H[0``20```"OM```%````=>T``!,```![[0``$````(_M```/
M````H.T```0```"P[0``#0```+7M```.````P^T```,```#2[0``!@```-;M
M```'````W>T```X```#E[0``"````/3M```/````_>T```@````-[@``#P``
M`!;N```'````)NX``!`````N[@``#0```#_N```0````3>X```T```!>[@``
M"P```&SN```&````>.X```D```!_[@``"P```(GN```,````E>X```P```"B
M[@``"@```*_N```1````NNX``!D```#,[@``"P```.;N```-````\NX``"(`
M````[P``#P```"/O```;````,^\``#0```!/[P``"@```(3O```8````C^\`
M`!(```"H[P``&0```+OO``!<````U>\``!8````R\```(@```$GP```-````
M;/````<```!Z\```#````(+P```4````C_````L```"D\```(@```+#P```O
M````T_````L````#\0``"0````_Q```9````&?$```L````S\0``%P```#_Q
M```7````5_$```D```!O\0``!P```'GQ```6````@?$``!$```"8\0``#P``
M`*KQ```9````NO$``!8```#4\0``#@```.OQ```8````^O$```@````3\@``
M#0```!SR```F````*O(``#D```!1\@``#@```(OR``!#````FO(```@```#>
M\@``$@```.?R```?````^O(```@````:\P``"P```"/S```O````+_,```X`
M``!?\P``!0```&[S```'````=/,```@```!\\P``!@```(7S``!%````C/,`
M``,```#2\P``!P```-;S```$````WO,```<```#C\P``#@```.OS```*````
M^O,```X````%]```"@```!3T```/````'_0``!`````O]```%P```$#T```5
M````6/0```X```!N]```&@```'WT```1````F/0``!D```"J]```%P```,3T
M```)````W/0```4```#F]```"P```.ST```*````^/0```(````#]0``!0``
M``;U```-````#/4``!L````:]0``%P```#;U```4````3O4```D```!C]0``
M#@```&WU```-````?/4``!(```"*]0``!````)WU```X````HO4``"````#;
M]0``"````/SU```&````!?8```@````,]@``"````!7V```.````'O8``'L`
M```M]@``&````*GV```8````PO8``!$```#;]@``!P```.WV```%````]?8`
M`!@```#[]@``'@```!3W```;````,_<``!D```!/]P``,0```&GW```;````
MF_<``!D```"W]P``$P```-'W```'````Y?<```@```#M]P``!@```/;W```&
M````_?<```P````$^```#@```!'X```-````(/@``!,````N^```#P```$+X
M```>````4O@``!D```!Q^```$````(OX```/````G/@``!````"L^```#P``
M`+WX```+````S?@```\```#9^```#````.GX```/````]O@```<````&^0``
M!@````[Y```,````%?D```X````B^0``#````#'Y```H````/OD```\```!G
M^0``"````'?Y```&````@/D```\```"'^0``"````)?Y```3````H/D``!X`
M``"T^0``(0```-/Y```@````]?D``!D````6^@``%P```##Z```E````2/H`
M`!<```!N^@``%@```(;Z```$````G?H``!L```"B^@``#0```+[Z```,````
MS/H```,```#9^@``!0```-WZ```(````X_H```H```#L^@``#````/?Z```+
M````!/L``!`````0^P``#````"'[```.````+OL```L````]^P``!````$G[
M```$````3OL``!,```!3^P``%````&?[```,````?/L```D```")^P``#@``
M`)/[```+````HOL``!L```"N^P``!P```,K[```$````TOL```<```#7^P``
M"@```-_[```-````ZOL```D```#X^P``!`````+\```%````!_P```,````-
M_```&````!'\```*````*OP```0````U_```)@```#K\```.````8?P``'P`
M``!P_```%0```.W\```%`````_T```<````)_0``#````!']```(````'OT`
M``H````G_0``!@```#+]```(````.?T```(```!"_0``!@```$7]```&````
M3/T``!0```!3_0``!````&C]```5````;?T```T```"#_0``$````)']```;
M````HOT```8```"^_0``!````,7]```)````ROT``!````#4_0``"0```.7]
M```)````[_T```8```#Y_0``!0````#^```:````!OX```@````A_@``!@``
M`"K^```$````,?X```<````V_@``&0```#[^```.````6/X```<```!G_@``
M!P```&_^```%````=_X```D```!]_@``"@```(?^```.````DOX```(```"A
M_@``!@```*3^```+````J_X```T```"W_@``!P```,7^```)````S?X```8`
M``#7_@``$@```-[^```)````\?X```<```#[_@``%`````/_```=````&/\`
M`$(````V_P``)0```'G_```E````G_\```8```#%_P``"@```,S_```$````
MU_\```D```#<_P``"````.;_```1````[_\```D````!``$`!@````L``0`-
M````$@`!``8````@``$`!````"<``0`Y````+``!`#T```!F``$`.@```*0`
M`0`>````WP`!``4```#^``$`#@````0!`0`$````$P$!``8````8`0$`!P``
M`!\!`0`A````)P$!``T```!)`0$`%0```%<!`0`&````;0$!``0```!T`0$`
M$0```'D!`0`&````BP$!``H```"2`0$`(@```)T!`0`$````P`$!``<```#%
M`0$`!````,T!`0`%````T@$!`!T```#8`0$`!````/8!`0`,````^P$!``X`
M```(`@$`"@```!<"`0`(````(@(!``D````K`@$`!0```#4"`0`Z````.P(!
M`#````!V`@$`-0```*<"`0`I````W0(!`$<````'`P$`.````$\#`0`I````
MB`,!`#\```"R`P$`+@```/(#`0`M````(00!`!\```!/!`$`#P```&\$`0`2
M````?P0!``L```"2!`$`!P```)X$`0`F````I@0!`#P```#-!`$`*0````H%
M`0`Z````-`4!`"0```!O!0$`)@```)0%`0`(````NP4!``H```#$!0$`"0``
M`,\%`0`'````V04!`"````#A!0$`(`````(&`0`F````(P8!``H```!*!@$`
M&0```%4&`0`I````;P8!`!8```"9!@$`$@```+`&`0`'````PP8!``H```#+
M!@$`#````-8&`0`/````XP8!`!````#S!@$`0`````0'`0!P````10<!`&8`
M``"V!P$`T0```!T(`0`.````[P@!``D```#^"`$`"@````@)`0`2````$PD!
M`!,````F"0$`#````#H)`0`&````1PD!`!@```!."0$`#P```&<)`0`6````
M=PD!`!(```"."0$`$````*$)`0`1````L@D!`!P```#$"0$`(P```.$)`0!J
M````!0H!``\```!P"@$`!0```(`*`0`0````A@H!``D```"7"@$`!````*$*
M`0`+````I@H!`"````"R"@$`%````-,*`0`,````Z`H!``P```#U"@$`#P``
M``(+`0`5````$@L!`"D````H"P$`*@```%(+`0`F````?0L!`"<```"D"P$`
M*0```,P+`0`J````]@L!`!D````A#`$`0@```#L,`0`1````?@P!`!(```"0
M#`$`$P```*,,`0`4````MPP!``\```#,#`$`%@```-P,`0`7````\PP!`!``
M```+#0$`$0```!P-`0`T````+@T!`!,```!C#0$`$@```'<-`0`U````B@T!
M`!0```#`#0$`!P```-4-`0`,````W0T!`"````#J#0$`$`````L.`0`4````
M'`X!`!$````Q#@$`%P```$,.`0`<````6PX!`!,```!X#@$`%````(P.`0`:
M````H0X!`!$```"\#@$`&@```,X.`0`>````Z0X!`!H````(#P$`$P```",/
M`0`5````-P\!`!$```!-#P$`%P```%\/`0`4````=P\!`!<```",#P$`%0``
M`*0/`0`)````N@\!`!````#$#P$`&0```-4/`0`$````[P\!``<```#T#P$`
M"P```/P/`0`1````"!`!``8````:$`$`!@```"$0`0`&````*!`!``4````O
M$`$`!P```#40`0`'````/1`!``4```!%$`$`%@```$L0`0`&````8A`!``8`
M``!I$`$`!````'`0`0`$````=1`!``<```!Z$`$`#@```((0`0`,````D1`!
M``P```">$`$`#0```*L0`0`*````N1`!``X```#$$`$`!0```-,0`0`H````
MV1`!``X````"$0$`#````!$1`0`/````'A$!``H````N$0$`"````#D1`0`)
M````0A$!`"L```!,$0$`"````'@1`0`$````@1$!``@```"&$0$`)@```(\1
M`0`2````MA$!``\```#)$0$`!@```-D1`0`*````X!$!``<```#K$0$`"```
M`/,1`0`@````_!$!``T````=$@$`"0```"L2`0`-````-1(!``H```!#$@$`
M%````$X2`0`,````8Q(!``T```!P$@$`"0```'X2`0`.````B!(!`!8```"7
M$@$`$0```*X2`0`)````P!(!``8```#*$@$``P```-$2`0`&````U1(!`!D`
M``#<$@$`!P```/82`0`$````_A(!``L````#$P$`"P````\3`0`'````&Q,!
M``4````C$P$`!P```"D3`0`6````,1,!``T```!($P$`#0```%83`0`*````
M9!,!`!````!O$P$`#P```(`3`0`1````D!,!`!<```"B$P$`"@```+H3`0`1
M````Q1,!``@```#7$P$`'@```.`3`0`$````_Q,!``\````$%`$`.@```!04
M`0`%````3Q0!``P```!5%`$`'@```&(4`0`.````@10!`!````"0%`$`"P``
M`*$4`0`,````K10!``D```"Z%`$`!P```,04`0`*````S!0!``D```#7%`$`
M#@```.$4`0`0````\!0!`!L````!%0$`&````!T5`0`:````-A4!``H```!1
M%0$`"0```%P5`0`)````9A4!``H```!P%0$`#````'L5`0`/````B!4!``@`
M``"8%0$`!@```*$5`0`<````J!4!``<```#%%0$`!0```,T5`0`+````TQ4!
M`$<```#?%0$`#0```"<6`0`)````-18!``0````_%@$``P```$06`0`3````
M2!8!`!,```!<%@$`$P```'`6`0`*````A!8!``(```"/%@$`!````)(6`0`E
M````EQ8!``,```"]%@$`!0```,$6`0`J````QQ8!``H```#R%@$`!0```/T6
M`0`$`````Q<!``H````(%P$`#0```!,7`0`&````(1<!``@````H%P$`"```
M`#$7`0`$````.A<!``4````_%P$`&````$47`0!H````7A<!``D```#'%P$`
M#````-$7`0`0````WA<!``4```#O%P$`!@```/47`0`;````_!<!`"\````8
M&`$`$````$@8`0`*````61@!``\```!D&`$`"@```'08`0`)````?Q@!`!,`
M``")&`$`&P```)T8`0`8````N1@!`!<```#2&`$`&````.H8`0`?`````QD!
M``X````C&0$``P```#(9`0`'````-AD!``(````^&0$`"````$$9`0`'````
M2AD!``<```!2&0$`"P```%H9`0`)````9AD!``H```!P&0$`"P```'L9`0`'
M````AQD!`%$```"/&0$`$````.$9`0`,````\AD!``T```#_&0$`&@````T:
M`0!*````*!H!`!D```!S&@$`!@```(T:`0`:````E!H!`"4```"O&@$`!@``
M`-4:`0`&````W!H!`!\```#C&@$`!@````,;`0`)````"AL!`!@````4&P$`
M%P```"T;`0`H````11L!``D```!N&P$`!@```'@;`0`-````?QL!`"(```"-
M&P$`5P```+`;`0`3````"!P!`",````<'`$`$P```$`<`0`"````5!P!``L`
M``!7'`$`"````&,<`0`-````;!P!``H```!Z'`$`!P```(4<`0`4````C1P!
M``8```"B'`$`!@```*D<`0`(````L!P!``4```"Y'`$`"@```+\<`0`.````
MRAP!``<```#9'`$`$P```.$<`0`5````]1P!``P````+'0$`#0```!@=`0`*
M````)AT!``L````Q'0$`,@```#T=`0`'````<!T!``P```!X'0$`#0```(4=
M`0`7````DQT!``P```"K'0$`"0```+@=`0`)````PAT!``H```#,'0$`!P``
M`-<=`0`)````WQT!``<```#I'0$`"@```/$=`0`;````_!T!``\````8'@$`
M0@```"@>`0`2````:QX!``H```!^'@$`%@```(D>`0`,````H!X!``T```"M
M'@$`$````+L>`0`)````S!X!`!````#6'@$`!P```.<>`0`2````[QX!``0`
M```"'P$`!P````<?`0`%````#Q\!``4````5'P$`"P```!L?`0`4````)Q\!
M`!$````\'P$`&@```$X?`0`6````:1\!`!0```"`'P$`%P```)4?`0`8````
MK1\!`!P```#&'P$`&0```.,?`0`'````_1\!``4````%(`$`#0````L@`0`,
M````&2`!``D````F(`$`"````#`@`0`7````.2`!``L```!1(`$`2@```%T@
M`0`,````J"`!`!\```"U(`$`&@```-4@`0`3````\"`!``0````$(0$`"@``
M``DA`0`$````%"$!``T````9(0$`#0```"<A`0`(````-2$!``H````^(0$`
M"0```$DA`0`)````4R$!``@```!=(0$`#````&8A`0`)````<R$!``4```!]
M(0$`"0```(,A`0`%````C2$!``<```"3(0$`!0```)LA`0`$````H2$!``(`
M``"F(0$`"````*DA`0`,````LB$!`#@```"_(0$`+````/@A`0`2````)2(!
M`"D````X(@$`,@```&(B`0`E````E2(!``H```"[(@$`+````,8B`0`N````
M\R(!`#,````B(P$`,P```%8C`0`X````BB,!``\```##(P$`&````-,C`0`+
M````[",!`!0```#X(P$`$`````TD`0`L````'B0!`!P```!+)`$`#P```&@D
M`0`3````>"0!`!4```",)`$`%````*(D`0`2````MR0!`!0```#*)`$`%0``
M`-\D`0`M````]20!`"T````C)0$`,0```%$E`0`N````@R4!`"\```"R)0$`
M+````.(E`0!B````#R8!`!,```!R)@$`#0```(8F`0`-````E"8!``@```"B
M)@$`%P```*LF`0`(````PR8!``P```#,)@$`*P```-DF`0`A````!2<!`!H`
M```G)P$`'````$(G`0`)````7R<!`$4```!I)P$`00```*\G`0`$````\2<!
M`!,```#V)P$`%`````HH`0`.````'R@!`!,````N*`$`&````$(H`0`&````
M6R@!``D```!B*`$`"@```&PH`0`/````=R@!``D```"'*`$`$````)$H`0`'
M````HB@!``X```"J*`$`!0```+DH`0`;````OR@!``T```#;*`$`"````.DH
M`0`#````\B@!``8```#V*`$`%````/TH`0`1````$BD!``X````D*0$`.```
M`#,I`0`"````;"D!``8```!O*0$`#@```'8I`0`%````A2D!``<```"+*0$`
M#@```),I`0`&````HBD!`"@```"I*0$`#````-(I`0`<````WRD!``0```#\
M*0$``@````$J`0`F````!"H!`!8````K*@$`%````$(J`0`I````5RH!`!<`
M``"!*@$`'P```)DJ`0!<````N2H!`!0````6*P$`/@```"LK`0`?````:BL!
M`!````"**P$`"````)LK`0`2````I"L!``<```"W*P$`#@```+\K`0`,````
MSBL!``P```#;*P$`$P```.@K`0`*````_"L!`!T````'+`$`&0```"4L`0`%
M````/RP!`!$```!%+`$`"````%<L`0`%````8"P!`!$```!F+`$`"0```'@L
M`0`D````@BP!`!(```"G+`$`%0```+HL`0`2````T"P!``X```#C+`$`&0``
M`/(L`0`(````#"T!``D````5+0$``@```!\M`0`-````(BT!``<````P+0$`
M"@```#@M`0`'````0RT!``\```!++0$`!@```%LM`0`+````8BT!`!H```!N
M+0$`"@```(DM`0`'````E"T!``@```"<+0$`!0```*4M`0`?````JRT!``8`
M``#++0$`$````-(M`0`(````XRT!``T```#L+0$`"````/HM`0`>`````RX!
M`!(````B+@$`+````#4N`0`:````8BX!``D```!]+@$`"@```(<N`0`5````
MDBX!`!````"H+@$`!0```+DN`0`4````ORX!``0```#4+@$`!P```-DN`0`0
M````X2X!``8```#R+@$`!P```/DN`0`>`````2\!`"@````@+P$`'@```$DO
M`0`*````:"\!`!P```!S+P$`$0```)`O`0`+````HB\!`!H```"N+P$`%```
M`,DO`0`$````WB\!``0```#C+P$`"P```.@O`0`%````]"\!``8```#Z+P$`
M"`````$P`0`&````"C`!``H````1,`$`&P```!PP`0`T````.#`!`#0```!M
M,`$`(````*(P`0`I````PS`!`"````#M,`$`00````XQ`0`:````4#$!`"@`
M``!K,0$`*0```)0Q`0!0````OC$!`"(````/,@$`!@```#(R`0`(````.3(!
M``4```!",@$`#@```$@R`0`(````5S(!`!D```!@,@$`&0```'HR`0`J````
ME#(!`",```"_,@$`&0```.,R`0`N````_3(!`#0````L,P$`"````&$S`0`7
M````:C,!``H```"",P$`!P```(TS`0`A````E3,!``P```"W,P$`#0```,0S
M`0`,````TC,!`!````#?,P$`#@```/`S`0`+````_S,!``<````+-`$`$P``
M`!,T`0`(````)S0!``L````P-`$`"@```#PT`0`4````1S0!``\```!<-`$`
M,@```&PT`0`+````GS0!``X```"K-`$`!0```+HT`0`%````P#0!``4```#&
M-`$`%P```,PT`0`/````Y#0!``0```#T-`$`"@```/DT`0`)````!#4!``L`
M```.-0$`#0```!HU`0`,````*#4!``X````U-0$`!0```$0U`0`$````2C4!
M``T```!/-0$`,@```%TU`0!%````D#4!``L```#6-0$`"@```.(U`0`/````
M[34!`!,```#]-0$`$P```!$V`0`/````)38!``P````U-@$`#@```$(V`0`-
M````438!``T```!?-@$`%P```&TV`0`'````A38!`!X```"--@$`%````*PV
M`0`%````P38!`!0```#'-@$`!@```-PV`0`'````XS8!``P```#K-@$`$```
M`/@V`0`1````"3<!``X````;-P$`%P```"HW`0`J````0C<!``8```!M-P$`
M"0```'0W`0`/````?C<!``P```".-P$`#0```)LW`0`1````J3<!``L```"[
M-P$`-@```,<W`0`*````_C<!`"(````).`$`"P```"PX`0`/````.#@!`'T`
M``!(.`$`,@```,8X`0`E````^3@!``@````?.0$`,````"@Y`0`Q````63D!
M`"T```"+.0$`$@```+DY`0`.````S#D!``4```#;.0$`#@```.$Y`0`3````
M\#D!`!$````$.@$`"````!8Z`0`2````'SH!``<````R.@$`$0```#HZ`0`3
M````3#H!``<```!@.@$`%````&@Z`0`8````?3H!``<```"6.@$`!0```)XZ
M`0`,````I#H!``P```"Q.@$`$@```+XZ`0`$````T3H!``<```#6.@$`"@``
M`-XZ`0`+````Z3H!``P```#U.@$`#@````([`0`.````$3L!``4````@.P$`
M!0```"8[`0`N````+#L!`"8```!;.P$`(P```(([`0`#````ICL!`!(```"J
M.P$`!@```+T[`0`>````Q#L!`!@```#C.P$`)0```/P[`0`-````(CP!``D`
M```P/`$`'P```#H\`0`#````6CP!``<```!>/`$`"@```&8\`0`"````<3P!
M``P```!T/`$`%0```($\`0`+````ESP!`!D```"C/`$`(````+T\`0`2````
MWCP!``4```#Q/`$`"@```/<\`0`5`````CT!`!(````8/0$`"````"L]`0`,
M````-#T!``0```!!/0$`"0```$8]`0`'````4#T!``L```!8/0$`#@```&0]
M`0`*````<ST!``P```!^/0$`4@```(L]`0`7````WCT!`"0```#V/0$`$@``
M`!L^`0`'````+CX!``8````V/@$`$````#T^`0`.````3CX!``X```!=/@$`
M(````&P^`0`,````C3X!`!D```":/@$`#0```+0^`0`5````PCX!`!(```#8
M/@$`#P```.L^`0`4````^SX!``H````0/P$`&P```!L_`0`0````-S\!`!P`
M``!(/P$`6````&4_`0`+````OC\!`"$```#*/P$`)0```.P_`0!I````$D`!
M`!H```!\0`$`%P```)=``0`9````KT`!`!H```#)0`$`&0```.1``0`E````
M_D`!`"<````D00$`&@```$Q!`0`7````9T$!`!T```!_00$`)@```)U!`0`;
M````Q$$!`"H```#@00$`&0````M"`0`?````)4(!`!,```!%0@$`"````%E"
M`0!$````8D(!`!,```"G0@$`0````+M"`0`'````_$(!``@````$0P$`"0``
M``U#`0`5````%T,!``T````M0P$`(P```#M#`0`-````7T,!`!,```!M0P$`
M"````(%#`0`#````BD,!``P```".0P$`1@```)M#`0`7````XD,!``X```#Z
M0P$`/P````E$`0!-````240!`#<```"71`$`5P```,]$`0`%````)T4!`!\`
M```M10$`+P```$U%`0`*````?44!`!,```"(10$`$````)Q%`0`1````K44!
M``@```"_10$`#0```,A%`0`M````UD4!``0````$1@$`#0````E&`0`5````
M%T8!`#L````M1@$`3P```&E&`0`?````N48!`!8```#91@$`)0```/!&`0`H
M````%D<!`!P````_1P$`"P```%Q'`0`C````:$<!`!\```",1P$`(0```*Q'
M`0`=````SD<!`"4```#L1P$`(````!)(`0`D````,T@!`"````!82`$`,```
M`'E(`0`+````JD@!``<```"V2`$`#0```+Y(`0`,````S$@!`!<```#92`$`
M!@```/%(`0`Y````^$@!``P````R20$`!P```#])`0`)````1TD!`!,```!1
M20$`"0```&5)`0`$````;TD!`!````!T20$`"````(5)`0`(````CDD!``0`
M``"720$`"P```)Q)`0`,````J$D!`!(```"U20$`$0```,A)`0`,````VDD!
M`!H```#G20$`#P````)*`0`'````$DH!``T````:2@$`%````"A*`0`.````
M/4H!``P```!,2@$`&P```%E*`0`L````=4H!`!,```"B2@$`'````+9*`0`H
M````TTH!``8```#\2@$`!P````-+`0`3````"TL!``4````?2P$`!````"5+
M`0`7````*DL!``H```!"2P$`#````$U+`0`)````6DL!``8```!D2P$`"0``
M`&M+`0`&````=4L!``@```!\2P$`"0```(5+`0`*````CTL!``@```":2P$`
M"@```*-+`0`*````KDL!``<```"Y2P$`$0```,%+`0`&````TTL!``X```#:
M2P$`#@```.E+`0`-````^$L!``L````&3`$`'0```!),`0`+````,$P!``(`
M```\3`$`'````#],`0`'````7$P!``8```!D3`$`9````&M,`0`)````T$P!
M``<```#:3`$`)@```.),`0`X````"4T!`!H```!"30$`*@```%U-`0`[````
MB$T!`"@```#$30$`-````.U-`0`9````(DX!`!4````\3@$`!0```%).`0`'
M````6$X!``@```!@3@$`!P```&E.`0`&````<4X!``4```!X3@$`!P```'Y.
M`0`.````ADX!``D```"53@$`!@```)].`0`(````IDX!``L```"O3@$`!P``
M`+M.`0`(````PTX!``<```#,3@$`%@```-1.`0`)````ZTX!``8```#U3@$`
M"P```/Q.`0`0````"$\!``8````93P$`'````"!/`0`4````/4\!``<```!2
M3P$`$0```%I/`0`(````;$\!``X```!U3P$`"````(1/`0`%````C4\!`!``
M``"33P$`"0```*1/`0`0````KD\!``8```"_3P$`&0```,9/`0`*````X$\!
M`!P```#K3P$`!P````A0`0`%````$%`!`!`````64`$`%````"=0`0`+````
M/%`!``T```!(4`$`*````%90`0`8````?U`!`!<```"84`$`"0```+!0`0`$
M````NE`!``D```"_4`$`"@```,E0`0`'````U%`!``(```#<4`$`#@```-]0
M`0`(````[E`!`#@```#W4`$`(P```#!1`0`?````5%$!`#@```!T40$`)@``
M`*U1`0`Q````U%$!`"<````&4@$`9````"Y2`0`4````DU(!`"0```"H4@$`
M(P```,U2`0`C````\5(!`"L````54P$`(0```$%3`0`D````8U,!`%4```"(
M4P$`.````-Y3`0!*````%U0!`%L```!B5`$`*````+Y4`0`X````YU0!`"\`
M```@50$`10```%!5`0!*````EE4!`$8```#A50$`,P```"A6`0`H````7%8!
M`"P```"%5@$`)@```+)6`0`;````V58!`#X```#U5@$`.@```#17`0"I`0``
M;U<!`",````960$`%P```#U9`0!(````55D!`(4```">60$`,````"1:`0`E
M````55H!`$$```![6@$`6P```+U:`0!)````&5L!`#$```!C6P$`:0```)5;
M`0`=````_UL!`!@````=7`$`*P```#9<`0`A````8EP!`!\```"$7`$`*P``
M`*1<`0`F````T%P!`"<```#W7`$`.@```!]=`0`=````6ET!`!$```!X70$`
M,P```(I=`0`E````OET!`"<```#D70$`(`````Q>`0`R````+5X!`!\```!@
M7@$`,````(!>`0!I````L5X!`#$````;7P$`00```$U?`0`S````CU\!`"4`
M``##7P$`/0```.E?`0!E````)V`!`$T```"-8`$`+0```-M@`0`G````"6$!
M`"\````Q80$`*````&%A`0`N````BF$!`#````"Y80$`5````.IA`0`G````
M/V(!`%H```!G8@$`.@```,)B`0!(````_6(!`$H```!&8P$`'P```)%C`0`R
M````L6,!`"\```#D8P$`+````!1D`0`M````060!`'$```!O9`$`9@```.%D
M`0!O````2&4!`+,```"X90$`%P```&QF`0`E````A&8!`#(```"J9@$`*0``
M`-UF`0`^````!V<!`"(```!&9P$`4@```&EG`0`B````O&<!`"4```#?9P$`
M"P````5H`0"Q````$6@!`"````##:`$`10```.1H`0`A````*FD!`#````!,
M:0$`)0```'UI`0`<````HVD!`#$```#`:0$`!P```/)I`0`(````^FD!``<`
M```#:@$`!`````MJ`0`*````$&H!``T````;:@$`"P```"EJ`0`.````-6H!
M``D```!$:@$`"P```$YJ`0`&````6FH!``4```!A:@$`$````&=J`0`"````
M>&H!`%D```![:@$`!0```-5J`0`2````VVH!``0```#N:@$`!P```/-J`0`(
M````^VH!``4````$:P$`,`````IK`0`#````.VL!`!`````_:P$`#````%!K
M`0`3````76L!``T```!Q:P$``@```']K`0`'````@FL!``<```"*:P$`!@``
M`))K`0`4````F6L!``P```"N:P$`&````+MK`0`&````U&L!``0```#;:P$`
M$@```.!K`0`,````\VL!``,`````;`$`*@````1L`0`$````+VP!``8````T
M;`$`!P```#ML`0`?````0VP!`#4```!C;`$`+@```)EL`0`O````R&P!`!<`
M``#X;`$`(@```!!M`0`E````,VT!`"````!9;0$`&P```'IM`0`8````EFT!
M`"0```"O;0$`'P```-1M`0`:````]&T!`"$````/;@$`(````#%N`0`:````
M4FX!`#(```!M;@$`&0```*!N`0`:````NFX!`"\```#5;@$`*P````5O`0`?
M````,6\!`",```!1;P$`'P```'5O`0`:````E6\!`"$```"P;P$`)0```-)O
M`0`F````^&\!`"4````?<`$`)````$5P`0`8````:G`!`!T```"#<`$`)```
M`*%P`0`8````QG`!`"(```#?<`$`+`````)Q`0`O````+W$!`!4```!?<0$`
M)0```'5Q`0`9````FW$!`#P```"U<0$`'P```/)Q`0`C````$G(!`!\````V
M<@$`(````%9R`0`:````=W(!`"\```"2<@$`&````,)R`0`F````VW(!`!X`
M```"<P$`*0```"%S`0`>````2W,!`#$```!J<P$`"0```)QS`0`,````IG,!
M`!<```"S<P$`+P```,MS`0`D````^W,!``<````@=`$`#P```"AT`0`4````
M.'0!``X```!-=`$`#0```%QT`0`D````:G0!``4```"/=`$`!P```)5T`0`B
M````G70!`"4```#`=`$`&@```.9T`0`=`````74!`!H````?=0$`!P```#IU
M`0#'````0G4!``L````*=@$`'````!9V`0`5````,W8!``8```!)=@$`"0``
M`%!V`0`+````6G8!``T```!F=@$`#````'1V`0`7````@78!``8```"9=@$`
M,P```*!V`0`3````U'8!`!,```#H=@$`!P```/QV`0`/````!'<!``<````4
M=P$`,@```!QW`0`$````3W<!`"$```!4=P$`$P```'9W`0`.````BG<!``P`
M``"9=P$`$0```*9W`0`R````N'<!`!8```#K=P$`"`````)X`0`=````"W@!
M``D````I>`$`"@```#-X`0`4````/G@!``H```!3>`$`'0```%YX`0`(````
M?'@!`!\```"%>`$`"````*5X`0`:````KG@!`"<```#)>`$`!@```/%X`0`5
M````^'@!``<````.>0$`"````!9Y`0`)````'WD!`#\````I>0$`!P```&EY
M`0`/````<7D!``X```"!>0$`$````)!Y`0`)````H7D!``D```"K>0$`"```
M`+5Y`0`3````OGD!``<```#2>0$`"````-IY`0`9````XWD!``H```#]>0$`
M%P````AZ`0`4````('H!``H````U>@$`#````$!Z`0`7````37H!``0```!E
M>@$`*@```&IZ`0`,````E7H!`!$```"B>@$`!P```+1Z`0`"````O'H!`!``
M``"_>@$`&````-!Z`0`+````Z7H!``,```#U>@$`"````/EZ`0`)`````GL!
M``0````,>P$`!P```!%[`0`'````&7L!``8````A>P$`%````"A[`0`'````
M/7L!``T```!%>P$`"P```%-[`0`4````7WL!`!4```!T>P$`#@```(I[`0`O
M````F7L!`"````#)>P$`'````.I[`0!(````!WP!`$P```!0?`$`%0```)U\
M`0`,````LWP!`#$```#`?`$`!0```/)\`0`2````^'P!`#\````+?0$`$@``
M`$M]`0`*````7GT!``8```!I?0$`!````'!]`0`$````=7T!``H```!Z?0$`
M$P```(5]`0`%````F7T!``8```"??0$`!@```*9]`0`(````K7T!``0```"V
M?0$`#````+M]`0`*````R'T!``D```#3?0$`.0```-U]`0`N````%WX!`"D`
M``!&?@$`!0```'!^`0`8````=GX!`!D```"/?@$`'P```*E^`0`=````R7X!
M`!$```#G?@$``@```/E^`0`$````_'X!``H````!?P$`!`````Q_`0`&````
M$7\!`!0````8?P$`!0```"U_`0`#````,W\!``P````W?P$`10```$1_`0`R
M````BG\!`#(```"]?P$`+P```/!_`0`:````((`!`#H````[@`$`-````':`
M`0`H````JX`!`%,```#4@`$`DP```"B!`0`O````O($!`$(```#L@0$`,```
M`"^"`0`N````8((!`!D```"/@@$`)P```*F"`0`X````T8(!`#@````*@P$`
M-P```$.#`0!R````>X,!`"````#N@P$`-0````^$`0`A````180!`$4```!G
MA`$`,````*V$`0`I````WH0!`"$````(A0$`*````"J%`0`I````4X4!`"8`
M``!]A0$`)0```*2%`0`H````RH4!`"@```#SA0$`(@```!R&`0`K````/X8!
M`",```!KA@$`10```(^&`0!)````U88!`$8````?AP$`/````&:'`0`P````
MHX<!`!(```#4AP$`$P```.>'`0`0````^X<!`'D````,B`$`"0```(:(`0"A
M````D(@!`',````RB0$`?````*:)`0`K````(XH!`%0```!/B@$`%P```*2*
M`0`5````O(H!`"<```#2B@$`%@```/J*`0`/````$8L!`!<````ABP$`'P``
M`#F+`0!`````68L!`!\```":BP$`'````+J+`0!1````UXL!`!H````IC`$`
M%````$2,`0`*````68P!``4```!DC`$`!@```&J,`0`(````<8P!``4```!Z
MC`$`$@```(",`0`0````DXP!`!,```"DC`$`'0```+B,`0`/````UHP!``\`
M``#FC`$`#P```/:,`0`&````!HT!``T````-C0$`!````!N-`0`)````((T!
M``L````JC0$`!0```#:-`0`%````/(T!``<```!"C0$`!0```$J-`0`4````
M4(T!``X```!EC0$`!P```'2-`0`(````?(T!``\```"%C0$`#0```)6-`0`*
M````HXT!``@```"NC0$`#````+>-`0`&````Q(T!``\```#+C0$`!P```-N-
M`0`&````XXT!`!0```#JC0$`!@```/^-`0`&````!HX!``P````-C@$`$0``
M`!J.`0`7````+(X!``@```!$C@$`!````$V.`0`9````4HX!`!$```!LC@$`
M"@```'Z.`0`8````B8X!`!,```"BC@$`'````+:.`0`1````TXX!``,```#E
MC@$`!@```.F.`0`$````\(X!``0```#UC@$`#P```/J.`0`*````"H\!``H`
M```5CP$`!P```""/`0`$````*(\!`!D````MCP$`!P```$>/`0`"````3X\!
M``(```!2CP$`$0```%6/`0`)````9X\!``(```!QCP$`!@```'2/`0`2````
M>X\!`!<```".CP$`!@```*:/`0`G````K8\!``(```#5CP$`"````-B/`0`$
M````X8\!``\```#FCP$`$P```/:/`0`'````"I`!``L````2D`$`$````!Z0
M`0`3````+Y`!``<```!#D`$`$0```$N0`0`&````79`!`!@```!DD`$`!@``
M`'V0`0`3````A)`!`!````"8D`$`$@```*F0`0`"````O)`!``8```"_D`$`
M#````,:0`0`)````TY`!`!$```#=D`$`(@```.^0`0`'````$I$!``<````:
MD0$`"P```"*1`0`3````+I$!``4```!"D0$`$0```$B1`0`"````6I$!``L`
M``!=D0$`!````&F1`0`+````;I$!``4```!ZD0$`!P```("1`0!;`0``B)$!
M`!,```#DD@$`$0```/B2`0`.````"I,!``D````9DP$`"P```".3`0`(````
M+Y,!``$````XDP$`%0```#J3`0`:````4),!`"H```!KDP$`(0```):3`0`B
M````N),!`!H```#;DP$`$@```/:3`0`J````"90!``L````TE`$`%````$"4
M`0`F````590!``T```!\E`$`$@```(J4`0`-````G90!`"````"KE`$`#@``
M`,R4`0`%````VY0!`",```#AE`$`"@````65`0`0````$)4!``X````AE0$`
M$@```#"5`0`/````0Y4!``\```!3E0$`'````&.5`0!E````@)4!`!````#F
ME0$`#````/>5`0`/````!)8!``P````4E@$`$````"&6`0`.````,I8!`!``
M``!!E@$`$0```%*6`0`&````9)8!`,(```!KE@$`2P```"Z7`0`M````>I<!
M`!4```"HEP$`#P```+Z7`0`5````SI<!`!4```#DEP$`#0```/J7`0`-````
M")@!``L````6F`$`!P```"*8`0`5````*I@!``P```!`F`$`#````$V8`0`5
M````6I@!``D```!PF`$`#````'J8`0`*````AY@!`"T```"2F`$`*````,"8
M`0`K````Z9@!`"L````5F0$`/````$&9`0`5````?ID!`#````"4F0$`0P``
M`,69`0!>````"9H!`&````!HF@$`7````,F:`0!F````)IL!`#(```"-FP$`
M`@```,";`0`)````PYL!`!(```#-FP$`!P```.";`0`*````Z)L!``X```#S
MFP$`!0````*<`0`&````")P!`!(````/G`$`"@```"*<`0`)````+9P!``T`
M```WG`$`"@```$6<`0`N````4)P!`"T```!_G`$`&````*V<`0`:````QIP!
M`!8```#AG`$`"@```/B<`0`.`````YT!``4````2G0$`#@```!B=`0`/````
M)YT!``\````WG0$`#````$>=`0`0````5)T!`!$```!EG0$`&P```'>=`0`6
M````DYT!`!<```"JG0$`%````,*=`0`4````UYT!`!(```#LG0$`#````/^=
M`0`3````#)X!``H````@G@$`*````"N>`0`4````5)X!`!,```!IG@$`%0``
M`'V>`0`.````DYX!`%L```"BG@$`.````/Z>`0`A````-Y\!``8```!9GP$`
M"P```&"?`0`Y````;)\!``@```"FGP$`"0```*^?`0`-````N9\!``H```#'
MGP$`!P```-*?`0`<````VI\!`!P```#WGP$`'@```!2@`0`=````,Z`!`!H`
M``!1H`$`&@```&R@`0`>````AZ`!`!L```"FH`$`$0```,*@`0`?````U*`!
M``L```#TH`$`!P````"A`0`'````"*$!``4````0H0$`!0```!:A`0`'````
M'*$!``8````DH0$`$P```"NA`0`>````/Z$!``X```!>H0$`#0```&VA`0`.
M````>Z$!``\```"*H0$`#@```)JA`0`+````J:$!`!4```"UH0$`$0```,NA
M`0`9````W:$!`!4```#WH0$`)P````VB`0`.````-:(!`"<```!$H@$`'```
M`&RB`0`B````B:(!`"(```"LH@$`%0```,^B`0`6````Y:(!`!(```#\H@$`
M%P````^C`0`:````)Z,!``<```!"HP$`!@```$JC`0`(````4:,!``X```!:
MHP$`!P```&FC`0`)````<:,!`!(```![HP$`#````(ZC`0`'````FZ,!``P`
M``"CHP$`$@```+"C`0`A````PZ,!``<```#EHP$`#0```.VC`0`(````^Z,!
M`!4````$I`$`#````!JD`0`,````)Z0!`#\````TI`$`/P```'2D`0`)````
MM*0!``<```"^I`$`$P```,:D`0`%````VJ0!``4```#@I`$`$````.:D`0`+
M````]Z0!`!8````#I0$`-P```!JE`0`0````4J4!``4```!CI0$`N@```&FE
M`0`E````)*8!`"<```!*I@$`)P```'*F`0`D````FJ8!``X```"_I@$`#```
M`,ZF`0`/````VZ8!``8```#KI@$`"0```/*F`0`(````_*8!`#8````%IP$`
M/P```#RG`0`U````?*<!`%T```"RIP$`-````!"H`0`T````1:@!`$$```!Z
MJ`$`0P```+RH`0`T`````*D!`$<````UJ0$`*````'VI`0`J````IJD!`$4`
M``#1J0$`-````!>J`0`Z````3*H!`"P```"'J@$`&0```+2J`0`=````SJH!
M`"X```#LJ@$`*P```!NK`0`K````1ZL!`!L```!SJP$`"P```(^K`0`/````
MFZL!``8```"KJP$`"@```+*K`0`8````O:L!`!X```#6JP$`!@```/6K`0`'
M````_*L!`!0````$K`$`"@```!FL`0`(````)*P!`"X````MK`$`"@```%RL
M`0`3````9ZP!``P```![K`$`!@```(BL`0`&````CZP!``4```"6K`$`!P``
M`)RL`0`&````I*P!``P```"KK`$`*````+BL`0`/````X:P!``P```#QK`$`
M"0```/ZL`0`'````"*T!``P````0K0$`!0```!VM`0`/````(ZT!``8````S
MK0$`$@```#JM`0`(````3:T!``@```!6K0$`!````%^M`0`-````9*T!``@`
M``!RK0$`)P```'NM`0`0````HZT!``@```"TK0$`#0```+VM`0`,````RZT!
M``<```#8K0$`!P```."M`0`#````Z*T!``,```#LK0$`$P```/"M`0`*````
M!*X!`!`````/K@$`(P```""N`0`*````1*X!``D```!/K@$`%0```%FN`0`;
M````;ZX!``H```"+K@$`'0```):N`0`%````M*X!``D```"ZK@$`!P```,2N
M`0!&````S*X!`"$````3KP$`.@```#6O`0`F````<*\!`"$```"7KP$`'```
M`+FO`0`&````UJ\!``0```#=KP$`$@```.*O`0`'````]:\!``L```#]KP$`
M(`````FP`0`A````*K`!`"\```!,L`$`(0```'RP`0`H````GK`!`&$```#'
ML`$`*0```"FQ`0`)````4[$!``H```!=L0$`$````&BQ`0`*````>;$!`!4`
M``"$L0$`"0```)JQ`0`-````I+$!``P```"RL0$`#````+^Q`0`,````S+$!
M``P```#9L0$`#````.:Q`0`,````\[$!`!0`````L@$`"@```!6R`0`7````
M(+(!`!L````XL@$`$0```%2R`0`3````9K(!`!4```!ZL@$`!````)"R`0`%
M````E;(!`!$```";L@$`2P```*VR`0!3````^;(!``8```!-LP$`$P```%2S
M`0`%````:+,!``4```!NLP$`(````'2S`0`8````E;,!``\```"NLP$`$```
M`+ZS`0`6````S[,!`!\```#FLP$`9`````:T`0!6````:[0!`%L```#"M`$`
M,````!ZU`0`[````3[4!`$8```"+M0$`.````-*U`0`>````"[8!``L````J
MM@$`(````#:V`0`&````5[8!`!4```!>M@$`#0```'2V`0`:````@K8!`!,`
M``"=M@$`#P```+&V`0`7````P;8!`!(```#9M@$`%````.RV`0`7`````;<!
M``P````9MP$`#````":W`0`&````,[<!`!$````ZMP$`"````$RW`0`7````
M5;<!`!0```!MMP$`$@```(*W`0`(````E;<!``0```">MP$`#````*.W`0`+
M````L+<!``8```"\MP$`$P```,.W`0`*````U[<!`!@```#BMP$`!P```/NW
M`0`-`````[@!``D````1N`$`#````!NX`0`'````*+@!``8````PN`$`"P``
M`#>X`0`(````0[@!``H```!,N`$`#P```%>X`0!#````9[@!`!H```"KN`$`
M$@```,:X`0`J````V;@!`!P````$N0$`"P```"&Y`0`%````+;D!`!\````S
MN0$`$P```%.Y`0`4````9[D!`#,```!\N0$`0@```+"Y`0`D````\[D!``P`
M```8N@$`)@```"6Z`0`=````3+H!``X```!JN@$`!0```'FZ`0`+````?[H!
M``8```"+N@$`!@```)*Z`0`9````F;H!``X```"SN@$`00```,*Z`0`'````
M!+L!``H````,NP$`$0```!>[`0`E````*;L!`#$```!/NP$`)P```(&[`0`S
M````J;L!`!L```#=NP$`,````/F[`0`=````*KP!`",```!(O`$`.0```&R\
M`0`?````IKP!`"<```#&O`$`*0```.Z\`0`A````&+T!`"$````ZO0$`)P``
M`%R]`0!"````A+T!`"$```#'O0$`(0```.F]`0`K````"[X!`!\````WO@$`
M'P```%>^`0`Z````=[X!`"(```"RO@$`%0```-6^`0`G````Z[X!`"`````3
MOP$`*P```#2_`0`5````8+\!`)(```!VOP$`&@````G``0`?````),`!`!\`
M``!$P`$`(````&3``0`N````A<`!`!T```"TP`$`'P```-+``0`@````\L`!
M`"P````3P0$`+@```$#!`0`P````;\$!`"\```"@P0$`H0```-#!`0`K````
M<L(!`"````">P@$`)````+_"`0`C````Y,(!`"P````(PP$`0````#7#`0!$
M````=L,!``\```"[PP$``P```,O#`0`'````S\,!``,```#7PP$`#0```-O#
M`0`2````Z<,!``\```#\PP$`"`````S$`0`9````%<0!``4````OQ`$`$@``
M`#7$`0`2````2,0!``<```!;Q`$`!0```&/$`0`(````:<0!`!@```!RQ`$`
M%@```(O$`0`9````HL0!`!0```"\Q`$`%P```-'$`0`1````Z<0!`!0```#[
MQ`$`$P```!#%`0!.````),4!``<```!SQ0$`#P```'O%`0`&````B\4!`!,`
M``"2Q0$`&0```*;%`0`;````P,4!`!````#<Q0$``@```.W%`0!0````\,4!
M``H```!!Q@$`'0```$S&`0`/````:L8!``X```!ZQ@$`!P```(G&`0`8````
MD<8!`!,```"JQ@$`!0```+[&`0`&````Q,8!``<```#+Q@$`#@```-/&`0`(
M````XL8!`!````#KQ@$`"@```/S&`0`3````!\<!``8````;QP$`#P```"+'
M`0`*````,L<!``X````]QP$`%````$S'`0`+````8<<!``8```!MQP$`"0``
M`'3'`0`+````?L<!`!````"*QP$`#````)O'`0`+````J,<!``T```"TQP$`
M*@```,+'`0`+````[<<!``T```#YQP$`*P````?(`0`4````,\@!`!<```!(
MR`$`00```&#(`0`+````HL@!`!<```"NR`$`&0```,;(`0`5````X,@!`&H`
M``#VR`$`$P```&')`0`?````=<D!``P```"5R0$`!@```*+)`0`'````J<D!
M``\```"QR0$`!@```,')`0`Y````R,D!`#@````"R@$`!P```#O*`0`,````
M0\H!`!\```!0R@$`#@```'#*`0`:````?\H!`!H```":R@$`"0```+7*`0`%
M````O\H!`!T```#%R@$`$````./*`0`1````],H!`"0````&RP$`'````"O+
M`0`*````2,L!`!,```!3RP$`"````&?+`0`.````<,L!`"0```!_RP$`/```
M`*3+`0`)````X<L!`$````#KRP$`#@```"S,`0`8````.\P!`#````!4S`$`
M"````(7,`0`+````CLP!`"0```":S`$`#P```+_,`0`'````S\P!``T```#7
MS`$`!0```.7,`0`0````Z\P!`%8```#\S`$`!0```%/-`0`'````6<T!``<`
M``!AS0$`"@```&G-`0`4````=,T!``X```")S0$`%````)C-`0`.````K<T!
M`!````"\S0$`$0```,W-`0`8````W\T!`!<```#XS0$`%````!#.`0`>````
M)<X!`!(```!$S@$`&````%?.`0`6````<,X!``@```"'S@$`!@```)#.`0`+
M````E\X!``P```"CS@$``@```+#.`0`*````L\X!`!````"^S@$`)P```,_.
M`0`9````]\X!`!0````1SP$`!@```";/`0`-````+<\!``X````[SP$`#P``
M`$K/`0`(````6L\!`#H```!CSP$`+0```)[/`0`3````S,\!``<```#@SP$`
M#0```.C/`0`.````]L\!`!$````%T`$`9P```!?0`0`4````?]`!`!0```"4
MT`$`%@```*G0`0`'````P-`!``4```#(T`$`'P```,[0`0`L````[M`!`"(`
M```;T0$`'@```#[1`0`Y````7=$!`"(```"7T0$`&@```+K1`0`;````U=$!
M``4```#QT0$`!P```/?1`0`'````_]$!``@````'T@$`%````!#2`0`6````
M)=(!`!8````\T@$`'@```%/2`0`6````<M(!`"D```")T@$`'P```+/2`0`2
M````T](!`!$```#FT@$`$@```/C2`0`1````"],!`"`````=TP$`%````#[3
M`0`/````4],!``\```!CTP$`!P```'/3`0`(````>],!``X```"$TP$`%```
M`)/3`0`6````J-,!`#````"_TP$`#P```/#3`0`+`````-0!``,````,U`$`
M#0```!#4`0`'````'M0!`"`````FU`$`&P```$?4`0`D````8]0!`",```"(
MU`$`'P```*S4`0`?````S-0!`"D```#LU`$`'````!;5`0`6````,]4!``8`
M``!*U0$`'````%'5`0`*````;M4!``T```!YU0$`!0```(?5`0`&````C=4!
M``@```"4U0$`"P```)W5`0`-````J=4!`!````"WU0$`%````,C5`0`.````
MW=4!``X```#LU0$`#P```/O5`0`%````"]8!``@````1U@$`(@```!K6`0`C
M````/=8!`!4```!AU@$`#@```'?6`0`1````AM8!`!````"8U@$`*````*G6
M`0`+````TM8!``0```#>U@$`!0```./6`0`4````Z=8!`!4```#^U@$`#```
M`!37`0`-````(=<!``<````OUP$`!````#?7`0`<````/-<!``\```!9UP$`
M!0```&G7`0`A````;]<!``T```"1UP$`DP```)_7`0`5````,]@!``D```!)
MV`$`"@```%/8`0`3````7M@!``P```!RV`$`#@```'_8`0`(````CM@!`!(`
M``"7V`$``@```*K8`0`(````K=@!``8```"VV`$`$0```+W8`0`%````S]@!
M`!4```#5V`$`#@```.O8`0`1````^M@!`!T````,V0$`"0```"K9`0`)````
M--D!``H````^V0$`#P```$G9`0`(````6=D!``D```!BV0$`!P```&S9`0`%
M````=-D!`!P```!ZV0$`"0```)?9`0`&````H=D!``0```"HV0$`!P```*W9
M`0`0````M=D!``\```#&V0$`!P```-;9`0`%````WMD!``4```#DV0$`"0``
M`.K9`0`'````]-D!`!$```#\V0$`!`````[:`0`%````$]H!``T````9V@$`
M"P```"?:`0`'````,]H!``H````[V@$`!P```$;:`0`4````3MH!``D```!C
MV@$`!P```&W:`0`/````==H!`",```"%V@$`2````*G:`0`K````\MH!`"L`
M```>VP$`!@```$K;`0`*````4=L!``0```!<VP$`"0```&';`0`(````:]L!
M`!0```!TVP$`"P```(G;`0`&````E=L!``T```"<VP$`!@```*K;`0`$````
ML=L!`$8```"VVP$`3P```/W;`0!+````3=P!`"````"9W`$`!0```+K<`0`.
M````P-P!``0```#/W`$`!@```-3<`0`&````V]P!`!@```#BW`$`%````/O<
M`0`5````$-T!``<````FW0$`!````"[=`0`6````,]T!``0```!*W0$`#P``
M`$_=`0`;````7]T!``<```![W0$`"@```(/=`0`&````CMT!``4```"5W0$`
M)P```)O=`0`$````P]T!``H```#(W0$`#0```-/=`0`.````X=T!``@```#P
MW0$`"0```/G=`0`%`````]X!`#`````)W@$`,@```#K>`0`Z````;=X!`"``
M``"HW@$`20```,G>`0`Y````$]\!`"D```!-WP$`.````'??`0`J````L-\!
M`"P```#;WP$`(0````C@`0`1````*N`!`!`````\X`$`"P```$W@`0`&````
M6>`!`"4```!@X`$`-0```(;@`0`G````O.`!`#P```#DX`$`(0```"'A`0`C
M````0^$!``<```!GX0$`"0```&_A`0`*````>>$!``8```"$X0$`*0```(OA
M`0`I````M>$!`#(```#?X0$`"0```!+B`0`?````'.(!`"T````\X@$`%@``
M`&KB`0`1````@>(!``<```"3X@$`"P```)OB`0`-````I^(!`!````"UX@$`
M#P```,;B`0!`````UN(!`(T````7XP$`9````*7C`0#N````"N0!`!$```#Y
MY`$`"`````OE`0`)````%.4!`!`````>Y0$`$0```"_E`0`,````0>4!``4`
M``!.Y0$`&P```%3E`0`0````<.4!`!$```"!Y0$`$````)/E`0`.````I.4!
M`!,```"SY0$`'````,?E`0`F````Y.4!`'0````+Y@$`$````(#F`0`%````
MD>8!`!4```"7Y@$`"0```*WF`0`$````M^8!``L```"\Y@$`'@```,CF`0`5
M````Y^8!``H```#]Y@$`#@````CG`0`0````%^<!`!,````HYP$`(@```#SG
M`0`@````7^<!`"````"`YP$`'@```*'G`0`D````P.<!`"(```#EYP$`&@``
M``CH`0`U````(^@!`!(```!9Z`$`$````&SH`0`2````?>@!`!(```"0Z`$`
M%````*/H`0`5````N.@!`!,```#.Z`$`$````.+H`0`2````\^@!`"D````&
MZ0$`$P```##I`0`5````1.D!`$H```!:Z0$`'````*7I`0`,````PND!`!$`
M``#/Z0$`(0```.'I`0`5`````^H!`!$````9Z@$`$@```"OJ`0`=````/NH!
M`!\```!<Z@$`%@```'SJ`0`7````D^H!`!4```"KZ@$`$P```,'J`0`=````
MU>H!`"````#SZ@$`)0```!3K`0`3````.NL!`!0```!.ZP$`%````&/K`0`<
M````>.L!`!4```"5ZP$`%0```*OK`0`9````P>L!``L```#;ZP$`&P```.?K
M`0`<`````^P!``0````@[`$`!P```"7L`0`)````+>P!`!<````W[`$`!@``
M`$_L`0`1````5NP!``H```!H[`$`!@```'/L`0`'````>NP!``@```""[`$`
M!@```(OL`0`4````DNP!``8```"G[`$`"````*[L`0`(````M^P!``<```#`
M[`$`!P```,CL`0`0````T.P!``X```#A[`$`$@```/#L`0`0`````^T!``D`
M```4[0$`%0```![M`0`%````-.T!`#`````Z[0$`$P```&OM`0`.````?^T!
M`!````".[0$`#@```)_M`0`.````KNT!``X```"][0$`*P```,SM`0`*````
M^.T!``8````#[@$`"`````KN`0`U````$^X!`!X```!)[@$`#@```&CN`0`&
M````=^X!``D```!^[@$`"0```(CN`0`%````DNX!`"0```"8[@$`$P```+WN
M`0`5````T>X!`!$```#G[@$`$@```/GN`0`9````#.\!`!8````F[P$`%```
M`#WO`0`/````4N\!`"$```!B[P$`)0```(3O`0`M````JN\!`!````#8[P$`
M!@```.GO`0`$````\.\!``@```#U[P$`'````/[O`0`'````&_`!``4````C
M\`$`#````"GP`0`+````-O`!``8```!"\`$`!````$GP`0`'````3O`!`!4`
M``!6\`$`#````&SP`0`.````>?`!``\```"(\`$`&````)CP`0`9````L?`!
M`!,```#+\`$`'0```-_P`0`3````_?`!`!,````1\0$`"0```"7Q`0`<````
M+_$!``8```!,\0$`$````%/Q`0`_````9/$!``8```"D\0$`#P```*OQ`0`>
M````N_$!`!$```#:\0$`%0```.SQ`0`,`````O(!``X````/\@$`"P```![R
M`0`)````*O(!``\````T\@$`#````$3R`0`-````4?(!`!T```!?\@$`(@``
M`'WR`0`B````H/(!`"@```##\@$`#````.SR`0`'````^?(!``<````!\P$`
M"P````GS`0`3````%?,!`!0````I\P$`!@```#[S`0`/````1?,!`"(```!5
M\P$`#0```'CS`0`/````AO,!`!X```"6\P$`90```+7S`0`@````&_0!``P`
M```\]`$`!P```$GT`0`&````4?0!`!X```!8]`$`'0```'?T`0`:````E?0!
M``D```"P]`$``@```+KT`0`$````O?0!`"````#"]`$`!@```./T`0`%````
MZO0!`"H```#P]`$`"@```!OU`0`'````)O4!``H````N]0$`#P```#GU`0`.
M````2?4!``8```!8]0$`!P```%_U`0`*````9_4!``4```!R]0$`!0```'CU
M`0`<````?O4!`(,```";]0$`#````!_V`0`/````+/8!`!@````\]@$`"0``
M`%7V`0`*````7_8!`!X```!J]@$`+````(GV`0`/````MO8!``H```#&]@$`
M$````-'V`0`*````XO8!``D```#M]@$`&@```/?V`0`I````$O<!`"<````\
M]P$`)@```&3W`0`8````B_<!`!X```"D]P$`%@```,/W`0`(````VO<!``D`
M``#C]P$``@```.WW`0`*````\/<!``H```#[]P$`!P````;X`0`2````#O@!
M``T````A^`$`#````"_X`0`-````//@!``8```!*^`$`4@```%'X`0`/````
MI/@!``X```"T^`$`"0```,/X`0`@````S?@!`%D```#N^`$`&@```$CY`0`&
M````8_D!`!X```!J^0$`+0```(GY`0`(````M_D!``<```#`^0$`'P```,CY
M`0`(````Z/D!``L```#Q^0$`)P```/WY`0`F````)?H!`"4```!,^@$`"0``
M`'+Z`0`)````?/H!``H```"&^@$`(@```)'Z`0!<````M/H!`!0````1^P$`
M)@```";[`0`4````3?L!``(```!B^P$`$0```&7[`0`+````=_L!`!8```"#
M^P$`#@```)K[`0`'````J?L!`!(```"Q^P$`!@```,3[`0`)````R_L!``@`
M``#5^P$`"````-[[`0`.````Y_L!`!$```#V^P$`#0````C\`0`>````%OP!
M`"`````U_`$`$0```%;\`0`2````:/P!``H```![_`$`#````(;\`0`S````
MD_P!``<```#'_`$`$0```,_\`0`2````X?P!`"````#T_`$`%P```!7]`0`/
M````+?T!`!$````]_0$`#P```$_]`0`/````7_T!``\```!O_0$`#P```'_]
M`0`(````C_T!`!P```"8_0$`'@```+7]`0!"````U/T!``L````7_@$`$@``
M`"/^`0`=````-OX!``L```!4_@$`#````&#^`0`5````;?X!``P```"#_@$`
M%P```)#^`0`/````J/X!``T```"X_@$`!````,;^`0`'````R_X!``4```#3
M_@$`!0```-G^`0`*````W_X!`!4```#J_@$`$0````#_`0`:````$O\!`!8`
M```M_P$`%````$3_`0`7````6?\!`!X```!Q_P$`'0```)#_`0`:````KO\!
M``8```#)_P$`"@```-#_`0`.````V_\!``T```#J_P$`#@```/C_`0`'````
M!P`"`",````/``(`#0```#,``@!0````00`"``T```"2``(`&@```*```@`F
M````NP`"`!0```#B``(`!P```/<``@`0````_P`"``@````0`0(`$P```!D!
M`@`4````+0$"``X```!"`0(`$0```%$!`@`/````8P$"``X```!S`0(`#@``
M`((!`@`3````D0$"``\```"E`0(`"0```+4!`@`)````OP$"``4```#)`0(`
M!P```,\!`@`"````UP$"``0```#:`0(``@```-\!`@`*````X@$"``\```#M
M`0(`1````/T!`@!#````0@("``T```"&`@(`(@```)0"`@`V````MP("`#$`
M``#N`@(`#````"`#`@`I````+0,"`!T```!7`P(`(@```'4#`@`B````F`,"
M`"<```"[`P(`$````.,#`@`4````]`,"`!(````)!`(`&P```!P$`@`>````
M.`0"`"P```!7!`(`'@```(0$`@`5````HP0"`!@```"Y!`(`%P```-($`@`3
M````Z@0"`!<```#^!`(`'````!8%`@`:````,P4"`"\```!.!0(`+P```'X%
M`@`S````K@4"`#````#B!0(`,0```!,&`@`N````108"`&L```!T!@(`)0``
M`.`&`@`9````!@<"``T````@!P(`"P```"X'`@`;````.@<"``H```!6!P(`
M%0```&$'`@`J````=P<"`"P```"B!P(`*````,\'`@`I````^`<"``D````B
M"`(`6P```"P(`@!-````B`@"``D```#6"`(`(````.`(`@`F`````0D"``X`
M```H"0(`&````#<)`@`;````4`D"``4```!L"0(`"@```'()`@`(````?0D"
M`!````"&"0(`"P```)<)`@`2````HPD"``L```"V"0(`"@```,()`@`-````
MS0D"`"4```#;"0(`"P````$*`@`)````#0H"``,````7"@(`"0```!L*`@`2
M````)0H"`!4````X"@(`$````$X*`@`Y````7PH"``(```"9"@(`!P```)P*
M`@`.````I`H"``<```"S"@(`!P```+L*`@`3````PPH"``@```#7"@(`.```
M`.`*`@`.````&0L"`!D````H"P(`!````$(+`@`#````1PL"`#0```!+"P(`
M*````(`+`@`:````J0L"`#````#$"P(`'````/4+`@`L````$@P"`%4````_
M#`(`%@```)4,`@!'````K`P"`",```#T#`(`$0```!@-`@`-````*@T"`!<`
M```X#0(`"0```%`-`@`0````6@T"`!$```!K#0(`#````'T-`@`3````B@T"
M``P```">#0(`&P```*L-`@`;````QPT"``,```#C#0(`"P```.<-`@`)````
M\PT"``@```#]#0(`$@````8.`@`,````&0X"`"@````F#@(`'````$\.`@`>
M````;`X"`!,```"+#@(`$@```)\.`@`G````L@X"``D```#:#@(`$0```.0.
M`@`"````]@X"`!(```#Y#@(`!P````P/`@`*````%`\"``<````?#P(`#@``
M`"</`@`'````-@\"`!`````^#P(`'````$\/`@`2````;`\"``4```!_#P(`
M"````(4/`@`%````C@\"`!P```"4#P(`!@```+$/`@`1````N`\"``@```#*
M#P(`$0```-,/`@`(````Y0\"`!H```#N#P(`#@````D0`@`K````&!`"`!<`
M``!$$`(`"0```%P0`@`*````9A`"`!T```!Q$`(`&P```(\0`@`%````JQ`"
M`!,```"Q$`(`!0```,40`@`*````RQ`"`"@```#6$`(`!P```/\0`@`)````
M!Q$"`!P````1$0(`/````"X1`@`F````:Q$"``8```"2$0(`&P```)D1`@`0
M````M1$"``@```#&$0(`$P```,\1`@`+````XQ$"``0```#O$0(`"````/01
M`@`+````_1$"``<````)$@(`"0```!$2`@`(````&Q("``<````D$@(`!P``
M`"P2`@`5````-!("`"T```!*$@(`.P```'@2`@`7````M!("`"````#,$@(`
M%0```.T2`@`^`````Q,"`!P```!"$P(`'0```%\3`@`E````?1,"`%@```"C
M$P(`(````/P3`@`%````'10"``H````C%`(`!P```"X4`@`3````-A0"``D`
M``!*%`(`$@```%04`@`5````9Q0"`#@```!]%`(`(P```+84`@`?````VA0"
M`#4```#Z%`(`.@```#`5`@`*````:Q4"`!H```!V%0(`#````)$5`@`*````
MGA4"`"$```"I%0(`#P```,L5`@`0````VQ4"``\```#L%0(`$P```/P5`@`2
M````$!8"``X````C%@(`!P```#(6`@`/````.A8"``D```!*%@(`$````%06
M`@`.````918"`!H```!T%@(`%P```(\6`@`P````IQ8"``L```#8%@(`'P``
M`.06`@`%````!!<"``8````*%P(`!P```!$7`@`>````&1<"``P````X%P(`
M!````$47`@`0````2A<"``\```!;%P(`"0```&L7`@`,````=1<"``X```""
M%P(`%@```)$7`@`%````J!<"``0```"N%P(`$@```+,7`@`Q````QA<"`$0`
M``#X%P(`$@```#T8`@`*````4!@"`!,```!;&`(`(````&\8`@`1````D!@"
M`!,```"B&`(`$@```+88`@`5````R1@"`!,```#?&`(`$@```/,8`@`7````
M!AD"``<````>&0(`(P```"89`@`8````2AD"`!0```!C&0(`#@```'@9`@`/
M````AQD"``T```"7&0(`#0```*49`@`-````LQD"``X```#!&0(`#0```-`9
M`@`0````WAD"`"\```#O&0(`!@```!\:`@`)````)AH"`!(````P&@(`"P``
M`$,:`@`-````3QH"``\```!=&@(`"P```&T:`@`\````>1H"``8```"V&@(`
M'@```+T:`@`/````W!H"`!,```#L&@(`CP`````;`@`G````D!L"`!\```"X
M&P(`"@```-@;`@`[````XQL"`#P````?'`(`.````%P<`@`6````E1P"`!$`
M``"L'`(`"````+X<`@`1````QQP"`!,```#9'`(`$0```.T<`@`'````_QP"
M`!@````''0(`"````"`=`@`0````*1T"`!8````Z'0(`!P```%$=`@`1````
M61T"`!P```!K'0(`"P```(@=`@`%````E!T"``P```":'0(`"P```*<=`@`0
M````LQT"``4```#$'0(`!P```,H=`@`*````TAT"`!,```#='0(`$P```/$=
M`@`,````!1X"``P````2'@(`!@```!\>`@`)````)AX"`#8````P'@(`*```
M`&<>`@`C````D!X"``<```"T'@(`(````+P>`@`&````W1X"`"0```#D'@(`
M%0````D?`@`H````'Q\"`!$```!('P(`$0```%H?`@`<````;!\"``,```")
M'P(`"````(T?`@`2````EA\"``(```"I'P(`#````*P?`@`4````N1\"``L`
M``#.'P(`&````-H?`@`<````\Q\"`!@````0(`(`!0```"D@`@`*````+R`"
M`!0````Z(`(`'````$\@`@`(````;"`"``T```!U(`(`!P```(,@`@`,````
MBR`"``H```"8(`(`#@```*,@`@`4````LB`"`!$```#'(`(`$0```-D@`@!*
M````ZR`"`!P````V(0(`-P```%,A`@`8````BR$"``4```"D(0(`!````*HA
M`@`2````KR$"``H```#"(0(`#0```,TA`@`B````VR$"`!$```#^(0(`'P``
M`!`B`@`2````,"("`!<```!#(@(`%0```%LB`@`0````<2("`!H```""(@(`
M#@```)TB`@`D````K"("``\```#1(@(`(````.$B`@!S`````B,"`!````!V
M(P(`*0```(<C`@`J````L2,"`&L```#<(P(`(````$@D`@`>````:20"`",`
M``"()`(`*````*PD`@`@````U20"`!T```#V)`(`'````!0E`@`@````,24"
M`!@```!2)0(`'0```&LE`@`V````B24"`"0```#`)0(`,@```.4E`@`2````
M&"8"`!D````K)@(`%````$4F`@`*````6B8"`$8```!E)@(`'0```*PF`@!6
M````RB8"``<````A)P(`"P```"DG`@`'````-2<"`!0````])P(`"P```%(G
M`@`Z````7B<"`!,```"9)P(`&@```*TG`@`(````R"<"``4```#1)P(`%```
M`-<G`@!*````["<"`"8````W*`(`%P```%XH`@!/````=B@"`%@```#&*`(`
M30```!\I`@!D````;2D"``<```#2*0(`*````-HI`@`L`````RH"``H````P
M*@(`%0```#LJ`@`1````42H"`!(```!C*@(`"````'8J`@`-````?RH"`#(`
M``"-*@(`!0```,`J`@`/````QBH"`!T```#6*@(`.@```/0J`@!2````+RL"
M`"@```""*P(`&P```*LK`@`L````QRL"`#$```#T*P(`)````"8L`@`.````
M2RP"`",```!:+`(`(````'XL`@`M````GRP"`!P```#-+`(`(P```.HL`@`=
M````#BT"`",````L+0(`&@```%`M`@`Y````:RT"``P```"E+0(`!P```+(M
M`@`0````NBT"`!$```#++0(`%````-TM`@`(````\BT"`$````#[+0(`#```
M`#PN`@`(````22X"``T```!2+@(`&@```&`N`@`)````>RX"``0```"%+@(`
M%@```(HN`@`(````H2X"``@```"J+@(`!````+,N`@`+````N"X"``L```#$
M+@(`%````-`N`@`3````Y2X"``X```#Y+@(`%`````@O`@`.````'2\"``<`
M```L+P(`$````#0O`@`<````12\"``L```!B+P(`#0```&XO`@`;````?"\"
M`"H```"8+P(`&````,,O`@`>````W"\"`"H```#[+P(`!````"8P`@`$````
M*S`"``T````P,`(`!P```#XP`@`*````1C`"`!8```!1,`(`"````&@P`@`*
M````<3`"``@```!\,`(`!P```(4P`@`)````C3`"``8```"7,`(`"0```)XP
M`@`)````J#`"`!$```"R,`(`!0```,0P`@`+````RC`"``P```#6,`(`!0``
M`.,P`@`.````Z3`"``0```#X,`(`#@```/TP`@`*````##$"``H````7,0(`
M#P```"(Q`@`<````,C$"``L```!/,0(``@```%LQ`@`?````7C$"``<```!^
M,0(`!@```(8Q`@!H````C3$"``P```#V,0(`"`````,R`@`H````##("`$0`
M```U,@(`'P```'HR`@`M````FC("`%@```#(,@(`)@```"$S`@`I````2#,"
M`!@```!R,P(`'0```(LS`@`%````J3,"``H```"O,P(`#0```+HS`@`-````
MR#,"``D```#6,P(`"P```.`S`@`-````[#,"`!4```#Z,P(`#P```!`T`@`-
M````(#0"``\````N-`(`#P```#XT`@`$````3C0"``<```!3-`(`"````%LT
M`@`9````9#0"``@```!^-`(`!@```(<T`@`'````CC0"`!,```"6-`(`!@``
M`*HT`@`;````L30"`!8```#--`(`"P```.0T`@`9````\#0"``P````*-0(`
M%@```!<U`@`,````+C4"``@````[-0(`#P```$0U`@`2````5#4"``\```!G
M-0(`!@```'<U`@`7````?C4"``L```"6-0(`'@```*(U`@`&````P34"``@`
M``#(-0(`#0```-$U`@`@````WS4"``D`````-@(`"P````HV`@`F````%C8"
M`!@````]-@(`$````%8V`@`)````9S8"``8```!Q-@(`"P```'@V`@`.````
MA#8"``D```"3-@(``@```)TV`@`.````H#8"``<```"O-@(`/@```+<V`@`F
M````]C8"`"D````=-P(`*P```$<W`@`<````<S<"`"P```"0-P(`*0```+TW
M`@!:````YS<"``T```!".`(`'P```%`X`@`8````<#@"`!L```").`(`+0``
M`*4X`@`=````TS@"`!\```#Q.`(`30```!$Y`@`T````7SD"`%,```"4.0(`
M3````.@Y`@`A````-3H"`#,```!7.@(`/P```(LZ`@`Z````RSH"`#T````&
M.P(`/0```$0[`@`N````@CL"`"8```"Q.P(`,@```-@[`@`K````"SP"`!,`
M```W/`(`/0```$L\`@`I````B3P"`)@"``"S/`(`&@```$P_`@`0````9S\"
M`#\```!X/P(`A0```+@_`@`N````/D`"`"4```!M0`(`1````)-``@!/````
MV$`"`$H````H00(`+````'-!`@!I````H$$"`!D````*0@(`$````"1"`@`E
M````-4("`!L```!;0@(`'````'="`@`H````E$("`"<```"]0@(`*@```.5"
M`@`P````$$,"`!D```!!0P(`#0```%M#`@`K````:4,"`"0```"50P(`*```
M`+I#`@`A````XT,"`#H````%1`(`'````$!$`@`Z````740"`&4```"81`(`
M-0```/Y$`@!+````-$4"`#4```"`10(`*````+9%`@`V````WT4"`%P````6
M1@(`.@```'-&`@`J````KD8"`"D```#91@(`+P````-'`@`J````,T<"`"@`
M``!>1P(`+````(='`@!7````M$<"`"D````,2`(`5@```#9(`@`[````C4@"
M`$<```#)2`(`10```!%)`@`K````5TD"`"\```"#20(`*0```+-)`@`I````
MW4D"`"D````'2@(`:````#%*`@!B````FDH"`&L```#]2@(`NP```&E+`@`:
M````)4P"`"X```!`3`(`-P```&],`@`H````ITP"`&0```#03`(`&````#5-
M`@!8````3DT"`"$```"G30(`'````,E-`@`+````YDT"`,P```#R30(`(```
M`+].`@!/````X$X"`"(````P3P(`/````%-/`@`@````D$\"`!@```"Q3P(`
M,P```,I/`@`&````_D\"``<````%4`(`!P````U0`@`$````%5`"``L````:
M4`(`#````"90`@`0````,U`"``P```!$4`(`"@```%%0`@`+````7%`"``@`
M``!H4`(`!P```'%0`@`2````>5`"``T```",4`(`@@```)I0`@`&````'5$"
M`!4````D40(`!````#I1`@`'````/U$"``@```!'40(`!0```%!1`@!2````
M5E$"``0```"I40(`&0```*Y1`@`*````R%$"`!(```#340(`$````.91`@`"
M````]U$"``<```#Z40(`!P````)2`@`&````"E("`!,````14@(`#````"52
M`@`6````,E("``8```!)4@(`!@```%!2`@`4````5U("``\```!L4@(``P``
M`'Q2`@`N````@%("``0```"O4@(`!@```+12`@`'````NU("`!X```##4@(`
M/````.)2`@`N````'U,"`"\```!.4P(`%@```'Y3`@`H````E5,"`#````"^
M4P(`(@```.]3`@`J````$E0"`"`````]5`(`(P```%Y4`@`>````@E0"`!P`
M``"A5`(`+````+Y4`@`D````ZU0"`!H````050(`+@```"M5`@`9````6E4"
M`!H```!T50(`+````(]5`@`P````O%4"`"````#M50(`)`````Y6`@`D````
M,U8"`!\```!85@(`(P```'A6`@`L````G%8"`"<```#)5@(`)P```/%6`@`E
M````&5<"`!\````_5P(`)````%]7`@`P````A%<"`!T```"U5P(`*@```--7
M`@`V````_E<"`#D````U6`(`&@```&]8`@`G````BE@"`"(```"R6`(`30``
M`-58`@`I````(UD"`"T```!-60(`+0```'M9`@`N````J5D"`"@```#860(`
M*0````%:`@`F````*UH"`"$```!26@(`)P```'1:`@`X````G%H"`"H```#5
M6@(`-0````!;`@`,````-EL"``X```!#6P(`(````%);`@`J````<UL"`"$`
M``">6P(`#P```,!;`@`/````T%L"`!H```#@6P(`&@```/M;`@`+````%EP"
M`"<````B7`(`#````$I<`@`*````5UP"`"4```!B7`(`*````(A<`@`B````
ML5P"`"<```#47`(`(@```/Q<`@`'````'UT"`-P````G70(`"P````1>`@`:
M````$%X"`!,````K7@(`!P```#]>`@`*````1UX"`!````!27@(`$@```&->
M`@`3````=EX"`!P```"*7@(``P```*=>`@`S````JUX"`!L```#?7@(`&```
M`/M>`@`'````%%\"`!(````<7P(`$@```"]?`@`S````0E\"``@```!V7P(`
M*0```']?`@`3````J5\"``X```"]7P(`$P```,Q?`@`9````X%\"`#,```#Z
M7P(`'0```"Y@`@`.````3&`"`",```!;8`(`#P```']@`@`0````CV`"`!<`
M``"@8`(`"@```+A@`@`?````PV`"``\```#C8`(`'0```/-@`@`/````$6$"
M`!X````A80(`)@```$!A`@`%````9V$"`!````!M80(`!P```'YA`@`+````
MAF$"``D```"280(`.````)QA`@`&````U6$"``\```#<80(`$0```.QA`@`0
M````_F$"``L````/8@(`#P```!MB`@`'````*V("`!`````S8@(`"````$1B
M`@`+````36("`!L```!98@(`"````'5B`@`;````?F("`!L```":8@(`"P``
M`+9B`@`-````PF("`!P```#08@(`"````.UB`@`Q````]F("`!$````H8P(`
M$````#IC`@`(````2V,"``(```!48P(`"@```%=C`@`8````8F,"``L```![
M8P(``P```(=C`@`+````BV,"``L```"78P(`!@```*-C`@`)````JF,"``<`
M``"T8P(`"P```+QC`@`>````R&,"``H```#G8P(`%P```/)C`@`.````"F0"
M`!@````99`(`'@```#)D`@`,````460"`#D```!>9`(`(@```)AD`@`C````
MNV0"`%@```#?9`(`50```#AE`@`9````CF4"``T```"H90(`10```+9E`@`&
M````_&4"`!H````#9@(`5@```!YF`@`/````=68"`!````"%9@(`!P```)9F
M`@`$````GF8"``4```"C9@(`$0```*EF`@`6````NV8"``8```#29@(`!P``
M`-EF`@`'````X68"``L```#I9@(``P```/5F`@`,````^68"``T````&9P(`
M"0```!1G`@`Y````'F<"`"X```!89P(`+````(=G`@`%````M&<"`!8```"Z
M9P(`)0```-%G`@`B````]V<"`!\````::`(`$P```#IH`@`"````3F@"``0`
M``!1:`(`#0```%9H`@`%````9&@"``H```!J:`(`'0```'5H`@`%````DV@"
M``4```"9:`(`#P```)]H`@!-````KV@"`"0```#]:`(`*````")I`@`U````
M2VD"`!<```"!:0(`/P```)EI`@`B````V6D"`#````#\:0(`3@```"UJ`@"B
M````?&H"`#(````?:P(`00```%)K`@`Q````E&L"`#$```#&:P(`%@```/AK
M`@`F````#VP"`$`````V;`(`00```'=L`@!)````N6P"`'X````#;0(`'@``
M`()M`@!9````H6T"`"H```#[;0(`3P```"9N`@`P````=FX"`"D```"G;@(`
M(````-%N`@`H````\FX"`"T````;;P(`+0```$EO`@`K````=V\"`"X```"C
M;P(`*0```-)O`@`H````_&\"`"P````E<`(`(@```%)P`@!,````=7`"`$X`
M``#"<`(`30```!%Q`@`Z````7W$"`#<```":<0(`%````-)Q`@`:````YW$"
M``P````"<@(`J`````]R`@`&````N'("`+D```"_<@(`A0```'ES`@"@````
M_W,"`"````"@=`(`5P```,%T`@`0````&74"`!(````J=0(`'0```#UU`@`1
M````6W4"``<```!M=0(`&0```'5U`@`>````CW4"`$$```"N=0(`&0```/!U
M`@`6````"G8"`%<````A=@(`&@```'EV`@`/````E'8"``H```"D=@(`!0``
M`*]V`@`&````M78"``@```"\=@(`!0```,5V`@`9````RW8"``D```#E=@(`
M&````.]V`@`B````"'<"`!8````K=P(`#P```$)W`@`)````4G<"``@```!<
M=P(`%````&5W`@`.````>G<"``D```")=P(`#````)-W`@`(````H'<"``4`
M``"I=P(`!P```*]W`@`%````MW<"`!````"]=P(`"````,YW`@`0````UW<"
M``X```#H=P(`$````/=W`@`,````"'@"``\````5>`(`"@```"5X`@`)````
M,'@"``@````Z>`(`$````$-X`@`%````5'@"``@```!:>`(`$P```&-X`@`'
M````=W@"``H```!_>`(`"P```(IX`@`8````EG@"`!8```"O>`(`"0```,9X
M`@`&````T'@"`!L```#7>`(`&````/-X`@`.````#'D"`!0````;>0(`"P``
M`#!Y`@`F````/'D"`!0```!C>0(`!0```'AY`@`&````?GD"``8```"%>0(`
M!P```(QY`@`5````E'D"``H```"J>0(`"@```+5Y`@`'````P'D"``@```#(
M>0(`(@```-%Y`@`+````]'D"``(`````>@(``@````-Z`@`:````!GH"``P`
M```A>@(``0```"YZ`@`&````,'H"``@````W>@(`&@```$!Z`@`&````6WH"
M`"4```!B>@(``@```(AZ`@`)````BWH"``0```"5>@(`$0```)IZ`@`7````
MK'H"``L```#$>@(`#````-!Z`@`.````W7H"`!0```#L>@(`"0````%[`@`0
M````"WL"``H````<>P(`%@```"=[`@`'````/GL"`!P```!&>P(`"@```&-[
M`@`7````;GL"``(```"&>P(`!0```(E[`@`0````CWL"``P```"@>P(`$@``
M`*U[`@`I````P'L"``<```#J>P(`!P```/)[`@`1````^GL"`!,````,?`(`
M!0```"!\`@`4````)GP"``(````[?`(`"P```#Y\`@`&````2GP"``H```!1
M?`(`!P```%Q\`@`&````9'P"``$````V`````````#,"````````+@0``.$'
M``#?`0``"00``-X````7````20@``(@!`````````````/0$````````_@(`
M`-<(``#[`@``````````````````V`8`````````````0P<`````````````
M$04``.`(``"9"````````"T#``!'````U@8``/P!````````C@@`````````
M````5@<``#,$````````RP(``,\"``!?`````````"H```!G!@``*P(``(<'
M``"=`P``3@,```````#@`0``+0(```@(``!3!````````!\'``![``````(`
M`/\"``!4````7`0``(X%````````]@```,8```"0`@```P(``+@#````````
M40(``)D```!J`P``X04``!T'``#&`P````````````#)!P``KP````````#2
M`0``\@`````````"`@``^@0``$,&``!%!```!04``````````````````/H!
M````````$0@``$T$``"F"```Y08``"('``"V!0``HP,``%<!````````@@@`
M``$&``"+`@```````%D&``!\`P```````#L#``#]!P``@`8``.T#``!W`@``
M>`,```````!$!P``H`<``-4%````````00,``+H!``!E`P``Q`$``/8"``#:
M````<P@``-\%```Z!P```````,T```"*`0```````+$%``#H`P``D`0``(`$
M```V!@``3P0``+H"````````C00``)("```[!0``?@,``"X#``!P!0``.P@`
M`!,'``"3!````````.8$``"R`P``$@@``"\(```+!0```````&($``!0`P``
M`````/T%`````````````,T$``"$!@``Y@4``,H'````````$@$``'H````U
M`@``E`$``+@$```F`````````-4#``"P!```CP```'H$```U!P``[`$``.\`
M``!Q!@``_`,```````!W````C08``)4"``!:"```6@8``*,%``!*!```E`@`
M``````#K````NP,``-$&``#C!P``%P(`````````````K`8```````#$`P``
M[@,``-8```!>`0``;@(```@$``!"!P``;@4``"P'````````QP``````````
M``````@``$X"```]`0```````'(#````````K@```-X$``!\!0``'00``$((
M``!)`0``\`<``)4'``!!`@```````!,!````````X0,``$8(``#J`P``20(`
M`.0'````````HP$``$L%``!7`@```````)P``````````````"("````````
M;@0```````!*`0``?P8``#L!``#3!P``TP```"T%``!W"```H`$```4!``"N
M"`````````````!%`0``,`4``"$(`````````````-L```#:`0``````````
M``"I`0````````````#X`@```````$0(``!K`````````$T'``"^````9```
M``\"``#``0```````(,!```C"````````"0#``"B!0``V@4``-D```#``P``
M%P,``$8"``#Z!0```````%L!````````````````````````M````(4#``"&
M"```-`@``-4'``!M`@``4P<`````````````Q`<``#0"```G"````````-@%
M``"G!0``R0$`````````````0`(``/L``````````````!`#``"E````\P``
M`&T```"H`P``9@```.`'```J`@```````/`$``!?!P``A`0````````&````
M/P(``%@#``".`0``)0$``(X'````````&0,````````I`0``E@```+@%``#1
M"`````````````!6!@``W````)T```"<!P``-04``(<#````````$P8`````
M`````````````-("``#9!```D@````````````````````````"K`0``````
M``````!<````-P(``"8!``#F`P``L`4```````!0!0``^````#P$````````
ML0```"X%```/"```[0$``&`%````````M@```$H#``#A`@``$0$```````#`
M"```EP(```````!%"```G@@``(X#```U````1`$``!@`````````)P0``!4#
M``#Q`P``304``(8"```F!@```````/4!``"-"```4P```(8&``!W`0``````
M``````#@!@```````,(#```[!@````````````!8`0```````+(&````````
M]P(```````"<`0````````````!O!```3@```+P'``"B!````````-T%``#6
M"````````'$#```/!```3@0``$D```#C`@```````,\(``#/!P``%@4``!@'
M```$````*`@``-@$````````U`,``&0'``!7!```FP(``+D'```+`P``K@$`
M``````"T!@```````#T$``!/`P``I0,````````>!```-`,``&(&``"*````
M`````.X&``#(`P``/@(`````````````2@@``((!````````TP8``*H!```I
M````U````$L$``"0`````0,``#8$``"C!P```````-L$```_!````````%$$
M``"!``````````H$``"2!0``M@8``"H'``"M`P``P`<``#L$``!@`P``````
M`&H$``#*!```Z`4``.0$``!-!@``>@4```````#W!```\P(``!@&```'"```
M%@0``-$"``#V!P``F@````````!Y`@```````&@'``!\````P04`````````
M````````````````````TP,``&,%````````(`$``/H'``!0!```CP0``-\"
M```>!0```````)D%``!&!0``D`@``/X%``!;!P``*@,``"$$``!'"```]@0`
M``L!````````6@4````````D"```V````*L(``"8`P``\P<``.D&````````
M'`0``)H%``#I"```YP,```D'``#<`@```P```(P"```;`0``3P(``'\%``#W
M!@````````````!Y````60$``+T"``!B!P```````/4$`````````````$4&
M``"G````/P$````````$!@``B@8``-`!``````````````````"I"```MP``
M`)\!```.!P``N@0```````#'!0``N@8`````````````9`$```````#S`0``
MCP<``)L'````````\0```%H#``#!`0``=`8``!,(```[!P``?0<`````````
M`````````'D&``"E`0``?08````````````````````````P!@``80@``'\"
M``!\!@``;@@``!8(``!1"```H@<``,\&`````````````.8(````````IP0`
M`*<"``!I`P``*@4```````#T!@``'08``"8'```'!```P````/$&``"_!@``
MJ@<``"4```!K"```2@8``/L&````````(P```*((```N`@```````,4'``!P
M`0``[0(``)4&````````"`,``,0(````````,`(``.@``````````````+H'
M```0!```)P```/D!```2!```````````````````*`````````!P"```10``
M`-<"``#A!```PP(``&`!```6`````````"\!````````#P,`````````````
M&@<``````````````````+T!`````````````*<(``#(`0```````!T(``#;
M!0``-`0``````````````````.`#``#_!@```````(0`````````RP,``,H!
M``"3!@``-@$``'`````#"```504``#\%``#;`0```````+,(``"4!P```00`
M`*T(````````S@@```````!^!0```````$X!```-!@``KP8`````````````
MB`@``+L$``#)"```&08```````!O!0``L@0``-`$``#=`@``L`@``*$(``!D
M!0``1@$``*\"```H!P``0P(``-L"``!L!0``H0,``)X"``!'!0``/````)$!
M``!/`0``!00``'T#``"1!P``;0@```````#"!```U@$``)`%```8!```````
M`````````````````!D'``#X`0``(P$``&(#``"I!0``YP<``.(%``!P!```
M0P````````!\`@````````````````````````````#``@``KP<```````"$
M`0``)P$``(<!``!?!```N04``"X!``!7!P``JP<``.4'````````K@<``"P!
M``"5!0````<``#8%```)````S0<``)P&````````5`(``&@&``!Y"```````
M`*T!``#J!P``F@$```````".!@``I0(`````````````U@4```````!^`@``
M``````````#Q!````````-L(```G!@```````"L````R"```R`<``&4```#,
M````4`@``$X%````````NP$``$`(``"6!0``1P$``&\(``!N!@``/`<`````
M``#>"```(P,```````")``````````````!T`0``UP<```````!,`0``L0(`
M````````````T@4``$H"``#/`P``0`8``#0!```/!@```````)L&``!?`0``
MSP0``,,!`````````````"T$``!]`0``0P0``*4$``!Q"```?0(``-@"``"3
M````30,````````G!0``%P@``#``````````>P8````````A!P``@P0``"X&
M``!I````-P0````&``#D`P``A@```&$"````````,04```````#)`P``````
M`*4'``!'!````````-X#`````````````+@&``#4"````````.(````O!@``
MXP@``!\#```)!0``(@8```````#<!```!`4``)<'````````<`8``,('``#3
M!```50```-`(```/!0``*P0```````!4!@````````````"+!P``%`$``,(&
M````````<@$```````!]````%0$```````"A`````````.@'```P!P``````
M``0"``!8!@``@``````````*`P```````.8!```?!0``'@,``#(%````````
M]@8``!,"``"C"```.08```,'``"T`@``B`0```<'``!^!@``7@@``'8`````
M````;P,``'D'``````````````````"-`@```````(0%``````````4``)0`
M````````E`8```((``"+"```F08``,8(``#:`@``-@,``&T%``"-!0``.04`
M`+H`````````@P(```````!J!0``>P$``%T'``!>`@``<00``!T#```;!```
M'@```.X"``#+!```U00``/,&``#J`0``&P,```````"<!```7P8``(L```!B
M!0``#@```&P'``!I`@``4@,```````";!0``Q0,```4'``!X`@``\0$``'4"
M``"J!````````!\!```F!0``\@(``&H!```,!0```````!0'``#]`0``U@(`
M`-H(``#_!0``````````````````30$``/D'``"_!P``````````````````
M`````,4!```^`0``-08``````````````````$0`````````GP4``-$`````
M````,0,``$$```!4`P```````-0'```=`0``"0,```````!H`0``&04`````
M``!'`P``:P4``!L(``"@"```.`<``!H&````````=08``,`%````````E@0`
M``````!?!0``S@$``!8&``#T`P``````````````````B@,``$`%``#(!```
M=@@```````!/"```+P,``$$$```?"```%`,``-D&```/`````````$@%``"(
M!@```````!P#````````2`$``'4#``"/`0``[`0``*8!``"&!P``_````%L&
M``"*!```PP```($"``"H"````````*L"````````=00``)\'``#U`@``````
M`#(#````````_0,``/X`````````8@@``-T!``#!!P``!P,```````"\!```
M?@0```H%``#%````S@8``*\(````````,P4```$"````````U0$```L"``!E
M`0``@0@``%\"``#@!0```````,H"``!V!P``(0(``%D(```9"```Q`(``#,'
M``#"`@``W`@``.L$``!U!0``;0$``-4```#I!0``@P```*0'````````2P$`
M``T#````````PP@``),"```S````LP(```H````N"```7P@``%`"``"^!0``
M5@4``.X'````````<@8``)<!``"W!P``@`4````````G`P``#0$``!`%``#C
M`P``V0<``/<!``!8`@``0@8``-$!``!F!```XP$`````````````"0$``$H%
M``````````````8%`````````````-D(``!T!````````.4%``"$`@``>P(`
M`'H#``!K`0``%0```$X'````````!@0``(<```!!!0```````&@```!S!P``
MM0,``/X!``"I````ZP(`````````````NP(``,P$```(!P``D0@``*$!````
M`````````%,%``!C"````````&4&``#N````\04``-X!```M!P```0<``"``
M``"#!0```````+P``````````````,H#```I`@```````+T'````````````
M`*8````@`P``)P(``.X$``"P!P```````/\$``"<"```VP8`````````````
M`````&4$```*`0``E`,``'L'``!$`P``I04``#\&````````)0(````````+
M!P``*0,``,4(``#R!@```````$D$``"5"`````````````".`@``60<``!,$
M``#,!P``.P```%P&````````P@4``'H(`````````````#D(```V`@``````
M`!`&`````````````/<`````````R@4``'H!````````C@```%@```#X`P``
M`````(`#``!O!P``#04```````"D!`````````````!<`@``6`0``-<&```H
M`0``.`@``$\%``!O`@``)0,``$L&`````````````*H(``"!`0``'`(`````
M```L!0``L@<``+,$``!$!```MP$``%,&``!C!P```````"4(``!I!0``JP``
M``````"!!@``V`<``'<'``!/````)`4```@%````````:P0``$L(````````
M`````*X$``#&!P``K@(`````````````G00```````#I`P``*`,``.$```""
M`@``'`<``+<%``!9````-@<``$$&``!4"````````/0'```W!P``LP<``.<`
M``"5`0```````#('````````8@(```````"*!P````````````#G"```?P@`
M`&@"````````=@(``/4#``"9`@``.`4``'<%`````````````'8#``"L!P``
M>0$``/,%```&"```5P,```````!G!0```````,8!```."```RP4```X!```?
M!```,0(```````#U!@``(`0``,T(```Q"```?P$``"@"````````H@8`````
M```<````Y`8```D&```D!```'@@``&P&```#!0``L08``)<%`````````@,`
M`#D#````````=`<``&$%````````SP```)D$```'````J`4``#@&````````
MN00```T(``"U"```0`0``-D#````````%04``(('`````````````+@"````
M`````````',```#=`````````#L"``!6`````````(($````````L0@``!\&
M``#[`0``"0@``"$!```=!0```````'P'```Y!P``K0```*8#```C!```E@<`
M`-\&``!3`0``O@(``$,#````````^P<``+P#``"Q`0``(`8````````^"```
MI`,````````N````+`8```````"2`0``'@<``)8"``"Y!@``\P,```````!=
M`0```````-(#```2!@``:@(`````````````)00``#H&````````8P$``(\&
M``#]!@``Y00``$@'````````:`@``-0&``!D"```<@````````!K`@``RP@`
M`%0%``!,`@``'0```&8"``"O`0``BP8``&`$```,`0``OP@``+\#````````
M@0<``(`"``"U````=`,```````!X`0``.@@``&P"``#3!0``R@@``!$```#Q
M!P``%`8``-H$```.!0``H04`````````````N0(``*H%```O!0``TP(``/L#
M```;````?`0``+0'```/!P``Q00``#\#``!]"```700`````````````(`@`
M`/H"````````)`(``-0$``"`!P``5P``````````````QP,````````0````
MO0,`````````!`````````````#>!0``,@```$L"``#E````2````,D%``!Z
M`@``9P```+@````_"```R`4```````!K!P``*0<``.D!``#R`P``FP$``!L%
M``"=`@``A@0``%\#````````YP4```````"H`@``````````````````/@8`
M``($``!U"```O@,```4"```6`@``-0$``,D&``"B`0```````#T&````````
M\0(```````!W!```'P````````">!````````!0$```-````JP0``+@'``#"
M"```G@8```````#%!@``\@$``*P"``!<"```C`8```P'``"P`P``&0$``#H"
M``#I!````````/T"``#9!0```````$<&``"D`@````````````!Q`@``````
M``````"D````?`@```````!<`P``P@$```````!P`P``_@0``'((``"I`@``
M`````````````````````'\$``"6"```ZP<``.,%``">`0``YP(```````!0
M````9`8``)`&``!^`0``;00``/P$``#0!P``F0,``/\#``")!```J`<``+H#
M```%`P``B`(```````#?`P```````&<"``"#!@``'P(````````&`P``````
M`)8#``!:`@```````#0'``#2!P``50@`````````````V0(``/P&``#,`@``
MU0(``/4%``!8"```3````"H!``!S!0``+P0``*@!```J!@``W0@```````!/
M!@``(P8```````!^"```604``%8"``",````-`8``'H'``!T`@``M@@``-(&
M``!Q!0```````#H!``"+`P``S0$``+((``!G`P```````,,$```,`P``````
M`*@&``!X!```\`(``,<"``!/!P``_P````````#(`@```````(,(```(`@``
M[0```%8(``#B`@``-P,``&4(````````QP@``&,$````````/0(``%4"``"U
M!P```````$H'``"T`0``'@(``+(%``">`P```````.P'````````BP4``*D#
M``"6`0``T````$D%```````````````````L!````````*D$```$!```]P,`
M`-P!``"P`@``C0,``.(#````````6`4````````5!`````````````"E!@``
M8P,``+0(``#N`0``,@(``$(!````````Z@4``$0%````````TP@```````"G
M!@``*08``%D"``#^!P``!P(``"($````````C0```-8'``!!"````````-T'
M``#M!@``N@4````````!!0``7@4``!@#``#H"````````-$#``"N!@``"@<`
M``````##!0``1P<```,#``"2!P``P08``.\%`````````````)`!``#5"```
MO`4``/@'``#J!@``E00``,,#``#_!P``404``,<&``">!0````````````"K
M`P``G`(``*,&``#W!P``^04``-$$`````````````!<'``"U!0``N0```$T`
M```-!P``J08``(@'`````````````*8%```D!P```````/8!```Q!```%P$`
M````````````!@$``$,%```^`P``=P,``',#``!_!P``B@@``.\'````````
MV`$```````",!0```````#\```!!!P```````````````````````,0```#0
M`@``C`,``)(&``!I!P``ZP8``)((``!F!P``&@0```````#>!P``O@8``'(%
M``#K!0``<0<``&T'````````````````````````C@0`````````````[04`
M`$(%``!T````6P````````"Q!P``N0$```````!6`0``OP```#@#``#R!```
MZ0````\!``!K`P``#`@```````#$!@``````````````````=@4```T"````
M````;P```#$&```2!0``;@```,(```!)!P```````+<$````````U`4``-$%
M``"^"```,0$``+P!``"8!0```````%H$``"%!@``L0,```````"O`P``I@0`
M`!`!````````3`,``)\(``">````_`4```0(``!)`P```````.4!``!;!```
MY0(``.$!``!="```F@(``.L(``!5!```]`(```````#3`0``[`(``*`%```P
M`P``@@```%(%``!D!```4@$````````8`@```````)\#````````[P8``#,(
M``!B`````````"`"``!,"```J@8``#\'``#'!```RP$``,D```"B`@``50<`
M`-T#``"5````T@@```H(``",!P``S04``&H'```C`@``50,``,0%``")!@``
MT@`````````#!@````````````#,!@``V0$``#,&```*!@```@<```````"\
M!@``]0```!H(````````+0````````!%`@``````````````````@P,``'T$
M````````_0```.T(````````4@8``%$!``!R!````````)T(````````>P,`
M`+8'```J"````````!@%``!3"```Y@<``&,"``"H````:@8``#0%````````
MZP$``!H#``#R!0``GP8```0!``#Y!@``600`````````````RP```!0```#)
M!````````%P'``"\`@``Q0(``,X```!0!P``1`(``.P#``"E"```4P,``((%
M```7!0``6P4``$@&````````0P@``,8&````````;0,``*$'``"%!0``VP<`
M`(\%``"X`0``LP```,$$``"/"```V@<``$P&``#F`@```````&<(``!L"```
M/@```.<!``!=````9`(``/4'``!:`0``#`(``&0#``!B`0``O0```"@&``#P
M`P``EP@``!L'```6!P``.0(```````")`@````````````"@`@```````(T!
M``!U!P``T0<``!`"`````````````(L$``"M!0``'`4``"$%```V"```+```
M`(\#``#?!````````*P(```0!P``>`<```````"(`P``W`,``,<'```,!@``
M5`<``%('```\`P``XP8``-@#````````E@8``,$```"P`0``MP8``.P```"9
M!P```````-8#``#%!0``$P``````````````W`8``,,'````````1`8``!('
M```'!0``M08`````````````"P````X"``#>!@``M@$```````!H`P``````
M`.P%```@!0``;`$``.H$````````WP@```````!2````;@$``,\%``!`````
MD0,``$L````:`0``^`8```````")!0``=`4`````````````6P,``(P!````
M````>0,``'$!``!`!P``S@,``'L%``#V`P``>@8``-P'```)`@``Q@4`````
M``!5!@``;`0``"L%````````90<````````X`0``X08``+\%``#H!@``,@0`
M`.(&```Z!```Y0,```4```#^`P``B@4``(<%``!A````+`@``#P&``"M!@``
M`````/H&``"@````I`8``(4"``#\`@``1@8```````"1!```@@,``'\```"G
M!P``$0(``(4!```(`````@8```````#+!P``*`0``),#```>`0``10,`````
M```$`P``&P(``",'```5"```#````&,```!I!@``M0(``!4'``#4`0``````
M`.\!````````D`<``'`'````````B````'\#````````J@(``!D$````````
M@04``)L(```-!````````!$'```W"```(0,``)\````W!0``>````#H%``"W
M`P``:P8``%($```I"````````/L$``"1```````````````O`````````+8$
M``!&!```GP(``&````"B`P``FP0``!8#````````+P<``#@"```]"```````
M```!``#G!```A0@``.H```!U````2`@```````!N!P``R`@``+0#```]`P``
M?`$``!0(`````````````((&``!@!P``'0(``+T%````````F`<``-T$``"T
M!0``4`8``&`&``#V!0``A0````````#0!@````````````"D"```CP(`````
M``"T!```9@@``$("````````&`$``%L(```3!0```````$@#````````^@,`
M`)<&``";````M00``.8&`````````````+<(```````````````````X!```
MJP4`````````````$P,``+,%`````````0$``%T"``!G`0``2P,``"L#``!O
M`0```````#0```#D`0```````%T#``!;`@``P`8`````````````F@8`````
M``"8"```````````````````UP0``+X!``"5`P``F`(``(`!``#,`0``````
M```````^!P``^@````X#``!,!P``H`,``/D"``"N!0``K@,`````````````
M`````!L&````````A`@``!(#``")!P```````,0$````````$@```,T"````
M````NP```.((``"R`0````````````#&!```G04``+P(``"9`0```0@``+L%
M`````````````'('````````D@0``.P&````````/`$``.T$``">!P``T@0`
M`!X&````````D0(``(T'``#(!@``1@<```````"_`0```````#,#``#0!0``
MUP```&@$``#P````F`0```0'``!:!P``P0,``#<```"O!```S`@``+L'```7
M!```*P8``.`"``"J`````````&P```"4!0``208```````!W!@``HP````L(
M``":"```I@8```````")`0``B0,``"4&``"R`@``Y`````````"%!P``&@4`
M`,L&```B`P``7@,``&8#``#;`P``'`$``"(%`````````````/`&``#Y!```
M`````"T(``!"````:00```````!(!```Y`@``&$&````````,0<``)T&```4
M`@``0`,``'$```"4!```Z`$```P$```]````(@$``%T%``#B`0```````%0$
M``#<!0``U`(``/L%````````IP,````````U`P``Y0@`````````````O@<`
M`$T"``!!`0``=@8``)<#``#@!```B`4```````!["`````````````#7`0``
M=@0``#H#``";`P````````````!L`P``G0<```````!2"```+0$``*(`````
M````7`$``%$&``!5`0``HP(``/('``#K`P``+@<``(<$`````````````!0%
M``!T"```+`(```X$``!@`@```````+,!```D!@```````/`%````````U08`
M`$($``#T`0``Z@@``!D"``#.!P``F````#`$``!6!```UP,```X&````````
M`@````````"*`@``F@<``"T&```<!@```````$4'``"3`0``K`$``!<&````
M````[P(```8&````````;P8``!@(```\"```/`4``.($```+!```-P8``&8!
M````````.0$``',&``#I`@```````#4$``!A`P``4`$``%8#``!=!@``1P(`
M`"@%``"K!@```````.\(`````````````/T$``","```I@<``!D```"Q!```
MXP0````````\`@``800``%X'``"R``````````````"'"```!0@````````&
M`@``:0@```L&``"+`0``O00```````!-"```(08``*`&````````DP4``.8`
M``"%!```)P<``,,&``#`!````````)$%````````.@```-<%``#X!```D08`
M````````````M@(``'X'````````D`,``*D'``"G`0``GP0``+\"````````
M]`4````````P"```Q@(``+L&````````!08``"\"``"&`0```````!H"````
M````R@````@&``!F!@```````.,````D````P0@``$4%```@!P```````$@"
M``",!`````````````#8"```%08``&<'``"D!0````````````"!`P``````
M````````````N@@``#D$````````H`0``)H#``!3`@``[`@``#D`````````
M`````*T'``````````````````"2`P``(@````(!``":!````````#(!``!]
M!0``90(`````````````AP(``#4(```#!```K`0```````#=!@```````%<%
M``"!!```DP@```````#T````<P0``(D(``#'`0``<P$````````0"```````
M`),'``#)`@``)@0```(%``!V`0``R````)@&``!.!@``AP8``!$$``"F`@``
M*00``*H#``!X"```>`8``$L'``"&!0``@P<``*$$``"H!```````````````
M``````````````#0`P```````",%``#M!P``*@0``%$'```F"```[P0``&X#
M``"P!@``HP0``*$&```Q`````````+,#````````0@,``.('```<"```Z`(`
M``````````````````````#:!@``:@@``,H&```'!@``1@``````````````
MK00``!4"``"$`P``3`0``+8#`````P``<@(```````````````````````#\
M!P``"@(``.D'````````S0,```````"X"`````````````#.`@``````````
M``#A"```EP```#X%``!&`P```````)0"``!``0``L````+,&``#@````````
M`$,!`````````````'@%```B"```4@(``%P%``!1`P``;08```````"]!@``
MN0,``)@!``!A!P``80$``+L(``#-!@``K0(```````"A`@```````"$`````
M`````````%X$``#,`P``S@0``%$```!7!@``/0<``%0!``"7!```*P@``+4!
M````````>P0``%H```#Y`````````/<%``!."```>00``*0!``"&`P``)@(`
M`*P#``#?````<`(```````#J`@``8P8``&<$``"`"````````%<(````````
MS`4``!$#```#`0``60,```````!8!P``8`@``"4'```R!@``)`$``/@%``#!
M`@``K````/\!``#^!@``/04```````!E!0```````.X%````````3`4``/,$
M``#:`P``S@4``-\'````````=0$``!("``!F!0```````&D!``#G!@``O@0`
M`````````````````$H````F`P``%@$``.@$```W`0``\`$``+D(```^!```
M&@```)T!```L`P``U@0```<!````````.````*P%``"<!0``,`$``%X```"]
M"```>04``"4%``````````````8'``!H!0``^0,```````#D!0``[@@``.\#
M```S`0``?@````````#/`0``G`,``%X&```(`0``<P(``!$&````````:@``
M`+<"````````*04``"L!```K!P```````(0'````````Y`(`````````````
M`````+\$``"O!0``W@(`````````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E
M<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&-A;&5N9&%R<R!F
M;W5N9``E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60@
M979E;G1S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!$87DH<RD@
M)7,@2&]U<BAS*2`E<R!-:6YU=&5S`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T
M=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D
M>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&%T=&5N9&5E<P`E<R!F:6QE('-U
M8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K
M('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`
M)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O
M:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S
M.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET
M(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@
M:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R
M<V]N86P@:6YF;W)M871I;VXN`"A#;&EC:R!O;B!C86QE;F1A<B!N86UE('1O
M('-W:71C:"!T:&4@8V%L96YD87(G<R!V:7-I8FEL:71Y(&EN('1H92!M86EN
M('=I;F1O=RD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@061D("H`*B!0;&5A
M<V4@<V5L96-T(&%D9')E<W,H97,I("H`+"!G=7-T:6YG(``L(&=U<W1I;F<@
M)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q
M(&%T=&5N9&5E`#$@979E;G0`,2!H;W5R`#$R($AO=7(@1F]R;6%T`#$U(&UI
M;G5T97,`,C`@;6EN=71E<P`R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`S,"!M
M:6YU=&5S`#Q0<F5V:6]U<P`\<W1R;VYG/D%T=&5N9&5E<SPO<W1R;VYG/B`H
M;W!T:6]N86PI`#QS=')O;F<^1&5S8W)I7W!T:6]N/"]S=')O;F<^("AO<'1I
M;VYA;"D`/'-T<F]N9SY+97EW;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI`#QS
M=')O;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H;W!T:6]N86PI`$$@9&%T86)A
M<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A
M;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T`04T@0VQO=61S
M`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO
M=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`
M06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R
M9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9%]V86YC960@4V5A<F-H
M`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D
M($5V96YT`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES
M<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@4F5M;W1E($-A;&5N9&%R`$%D
M9"!A(&YE=R!E=F5N=`!!9&0@82!N97<@=7-E<CH`061D(&%T=&5N9&5E<P!!
M9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S
M($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O
M:SH`061D('1O(&%T=&5N9&5E<P!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D
M9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E
M9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!
M9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!
M9&UI;FES=')A=&EO;@!!9',`061V86YC960@4V5A<F-H`$%F9VAA;FES=&%N
M`$%L87)M`$%L87)M("5D(&1A>7,@8F5F;W)E`$%L87)M("5D(&AO=7)S(&)E
M9F]R90!!;&%R;2`E9"!M:6YU=&5S(&)E9F]R90!!;&%R;2`E9"!W965K<R!B
M969O<F4`06QA<FT@,2!D87D@8F5F;W)E`$%L87)M(#$@:&]U<B!B969O<F4`
M06QA<FT@,2!M:6YU=&4@8F5F;W)E`$%L87)M(#$@=V5E:R!B969O<F4`06QA
M<FT@1&%T90!!;&%R;2!3<&%N("AM:6YU=&5S*0!!;&%R;2!4:6UE`$%L8F%N
M:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@071T
M96YD965S`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!&=71U<F4`06QL
M($=R;W5P<P!!;&P@4&%S=`!!;&P@4&5R;6ES<VEO;G,`06QL(%9I<VEB;&4`
M06QL(&1A>0!!;&P@9&%Y(&5V96YT`$%L;"!E=F5N=',`06QL(&9O=7(@<VED
M97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)
M35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)
M35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T
M92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM
M;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U
M9&$`06YY`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I
M;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P
M<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R
M8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S
M=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)
M22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I
M82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@
M9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU
M;6YS`$%T`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R
M92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@979E;G0N($EF('EO=7(@;6%I;"!C
M;&EE;G0@<W5P<&]R=',@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES
M(&9I;&4@=&\@96%S:6QY('5P9&%T92!Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE
M(&5V96YT+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD
M86YC90!!='1E;F1E97,`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U
M<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E
M<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N
M86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@
M4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A
M=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@
M=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R
M8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L
M;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA
M;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@
M;F]T(&9O=6YD+@!"87-E;&EN90!"87-I8R!396%R8V@`0F5L87)U<P!"96QG
M:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C
M:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3
M971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R
M9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z
M96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R
M87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A
M<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`
M0G5R=6YD:0!"=7-Y`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`
M0U]A;&5N9&%R`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@
M;F]T(&-O;7!L971E9"X`0V%L7V5N9&%R`$-A;&5N9&%R`$-A;&5N9&%R(%-U
M;6UA<GD`0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"X`0V%L96YD87)S
M`$-A;&5N9&%R<R!M=7-T(&AA=F4@82!N86UE+@!#86QM`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@
M9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H
M86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N
M)W0@8W)E871E(&$@;F5W(&5V96YT+@!#86XG="!O<&5N(&9I;&4@(B5S(BX`
M0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N8V5L;&5D
M`$-A;F-E;&QE9#H@)7,`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L
M:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N
M`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A
M<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)?>0!#871E9V]R:65S
M(&%N9"!,86)E;',`0V%T96=O<GD`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N
M90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I
M97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ
M-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I
M9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E
M`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO
M="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@
M0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN
M+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H
M:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`
M0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@:68@>6]U('=A;G0@=&\@8F4@
M;F]T:69I960@;V8@;F5W+"!E9&ET960L(&%N9"!D96QE=&5D(&5V96YT<R!B
M>2!E;6%I;#H`0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO=&EF:65D(&]F
M(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',N`$-H;V]S92!I9B!Y
M;W4@=V%N="!T;R!R96-E:79E(&5M86EL(')E;6EN9&5R<R!F;W(@979E;G1S
M('=I=&@@86QA<FUS.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C
M:"!F;W(@9G)E92]B=7-Y(%523',Z`$-H;V]S92!T:&4@8V%L96YD87)S('1O
M(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXZ`$-H;V]S
M92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R
M964O8G5S>2!54DQS.@!#:&]O<V4@>6]U<B!D969A=6QT(&-A;&5N9&%R+@!#
M:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O
M=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L
M96%R(&%L;"!A='1E;F1E97,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S
M97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N
M=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO<V4@
M=VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L
M:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E
M<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I
M;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6$@<V5P87)A=&5D
M('9A;'5E<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@
M3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD
M:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO
M;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L
M;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@
M)7,`0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT
M<S\`0V]N9FER;65D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I
M;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O
M;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O
M:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E
M;&5C=&EO;@!#;W!Y('1H92!54DP@8F5L;W<@9F]R('5S92!W:&5R979E<B!Y
M;W4@;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ`$-O<W0@240`0V]S=&$@4FEC
M80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E
M.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-
M24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE
M<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E
M<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N
M;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A
M+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C
M;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O
M<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T
M(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O
M=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@
M=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@
M04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E
M=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T
M(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H
M92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y
M(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A
M<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#
M;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L
M9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R
M<V5S`$-R96%T90!#<F5A=&4@0V%L96YD87(`0W)E871E(&$@3F5W($5V96YT
M`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O
M;&1E<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D
M(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N=`!#=7)R96YT(#0@4&AA<V5S
M`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES
M`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET
M:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I
M;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI
M8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS
M964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$86EL>3H@4F5C=7)S(&5V
M97)Y`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T
M92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&%Y*',I`$1E7VQE=&4`
M1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI
M;F5D`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V%L96YD87(`
M1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`
M1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92`E<P!$96QE=&4@0V5L;`!$96QE
M=&4@179E;G0`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI
M<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$
M96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S
M(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y
M`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M`$1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R<F5N
M8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@86QL(&]C8W5R96YC
M97,_`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I
M7W!T:6]N`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`
M1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT
M.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O
M(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D`1&ES<&QA>2`R-"UH;W5R('1I;65S
M/P!$:7-P;&%Y($-A;&5N9&%R<P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D
M971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L
M87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U
M92!O;B!Y;W5R(&-A;&5N9&%R/P!$;V5S(&YO="!R96-U<@!$;V5S('1H92!F
M:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE
M8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG
M="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D
M("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$1U93H@)7,`1'5R871I;VX`
M12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I
M97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%
M9&ET`$5D:70@)7,`161I="!!='1E;F1E97,`161I="!";&]C:P!%9&ET($-A
M;&5N9&%R<P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI
M<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@4F5M;W1E($-A
M;&5N9&%R<P!%9&ET(&%T=&5N9&5E<P!%9&ET(&-A=&5G;W)I97,@86YD(&-O
M;&]R<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%
M;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER
M;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;E]D
M`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R
M:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_
M`$5N9"!$871E`$5N9"!/;@!%;F0@5&EM90!%;F0@>65A<@!%;FQA<F=E($5D
M:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@
M=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%
M<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N
M=#H@)7,`17)R;W(@<F5T<FEE=FEN9R!F<F5E+V)U<WD@:6YF;W)M871I;VX@
M9F]R("5S.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5N="!A9&1E9#H`179E;G0@
M9&5L971E9#H`179E;G0@961I=&5D.@!%=F5N="!F<F]M("5S('1O("5S`$5V
M96YT(&YO="!F;W5N9`!%=F5N=',@;75S="!H879E(&$@<W1A<G0@9&%T92X`
M179E;G1S(&UU<W0@:&%V92!A('1I=&QE+@!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@3F%M97,`17AP
M86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT
M`$5X<&]R=`!%>'!O<G0@0V%L96YD87(`1D<@0V]L;W(`1E10('5P;&]A9"!O
M9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I
M;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%3
M3"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@
M=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R
M=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@
M4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L
M970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O
M=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L
M96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D
M+@!&:6QT97)S`$9I;F0`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T
M97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO
M="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N
M)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y
M<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O
M=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R
M97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`
M1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@
M,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE
M=')O<&]L:71A;@!&<F5E`$9R964O0G5S>2!);F9O<FUA=&EO;@!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R:61A>0!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N
M`$9U;&P@36]O;@!&=6QL($YA;64`1G5T=7)E`$=A8F]N`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'86UE`$=E;F5R86P`
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R
M9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L
M($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`
M1V]T;R`E<P!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'
M<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R
M:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M
M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI
M9&4`2&ED92`E<P!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@
M4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@
M4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!)
M;G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE
M(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@
M=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S
M:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`
M2&]R:7IO;G1A;#H`2&]U<BAS*0!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*0!(;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@
M;VX@=&AE(&1A>2!A;F0@=V5E:R!V:65W<R!B93\`2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9&%Y<R!O9B!F
M<F5E+V)U<WD@:6YF;W)M871I;VX@<VAO=6QD('=E(&=E;F5R871E/P!(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ
M(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S
M`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N
M+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS
M(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N`$EF('EO=7(@96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I
M5&EP(')E<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T:&4@9F]L;&]W:6YG
M(&QI;FMS('1O(&%C8V5P="!O<B!D96-L:6YE('1H92!E=F5N="X*"E1O(&%C
M8V5P="!T:&4@979E;G0Z"B5S"@I4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A
M=&EV96QY.@HE<PH*5&\@9&5C;&EN92!T:&4@979E;G0Z"B5S`$EM86=E(%!R
M979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R
M>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP
M;W)T($-A;&5N9&%R+"!3=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O
M17AP;W)T($-A;&5N9&%R`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I
M9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA
M=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E
M<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!)
M;G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R
M="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE
M<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P
M:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!)
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK
M`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E
M<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L
M:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C
M:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC
M96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@
M;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E
M+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!)
M;G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!)
M;G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I
M;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L
M92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L
M:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M
M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T
M:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@
M4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B
M:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+
M97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!+97EW;W)D<P!+:61S`$MI<FEB871I`$MO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U
M8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?
M>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8P!,87-T(#(T(&AO=7)S`$QA<W0@2&%L9@!,87-T($UO9&EF:65D`$QA<W0@
M36]N=&@`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!996%R`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%S="!W965K`$QA='9I
M80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO
M;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`
M3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`
M3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG
M:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET
M:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I
M8VL`3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z`$QI;FL`3&EN:R!P
M;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,
M:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T
M+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C
M<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D
M.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]?8V%T:6]N`$QO
M861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO
M;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T
M`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L
M9&EV97,`36%L:0!-86QT80!-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RX`36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S
M=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA
M9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I
M96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N
M`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T
M(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB
M97(@;V8@179E;G1S`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`
M36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`364`365D:6-I;F4`365E=&EN
M9P!-96UB97)S`$UE;G4@06QA<FUS`$UE;G4@3&ES=`!-96YU(&UO9&4Z`$UE
M<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R
M(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D
M+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO
M="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP
M90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO
M=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E
M9`!-:6YU=&4H<RD`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I
M;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`
M36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C
M;P!-;VYD87D`36]N9V]L:6$`36]N=&@`36]N=&@@5FEE=P!-;VYT:"!A;F0@
M>65A<@!-;VYT:&QY`$UO;G1H;'D@179E;G1S($QI<W0`36]N=&AL>3H@4F5C
M=7)S(&5V97)Y`$UO;G1H<R!!:&5A9`!-;VYT:',@0F5F;W)E`$UO;G1S97)R
M870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T
M:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S
M=&QY($-L;W5D>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T;'D@4W5N
M;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V
M92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE(&E#86QE;F1A<B!C
M;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!V179E;G0@:7,@<W5P<&]R=&5D
M+@!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN
M9F]R;6%T:6]N`$UY($-A;&5N9&%R<P!->2!#86QE;F1A<G,Z`$UY($9R964O
M0G5S>2!54DP`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.
M3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE
M=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@
M55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O
M;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.
M971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!%
M=F5N=`!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A
M;&%N9`!.97<@8V%L96YD87(@8W)E871E9"!A;F0@875T;VUA=&EC86QL>2!S
M:&%R960@=VET:"!F;VQL;W=I;F<@9W)O=7`H<RDZ("5S+@!.97<@<&%S<W=O
M<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O
M<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W
M<V=R;W5P<P!.97AT`$YE>'0@,C0@:&]U<G,`3F5X="`T(%!H87-E<P!.97AT
M($1A>0!.97AT($UO;G1H`$YE>'0@5V5E:P!.97AT(%EE87(`3F5X="!D87D`
M3F5X="!O<'1I;VYS`$YE>'0@=V5E:P!.97AT/@!.:6-A<F%G=6$`3FEG97(`
M3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%L87)M`$YO(&%T=&5N9&5E<P!.
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8V%L96YD87)S
M(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+@!.;R!C:&%N9V4N`$YO(&-H:6QD
M<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N`$YO(&5N9"!D871E`$YO(&5V96YT<R!T;R!D:7-P
M;&%Y`$YO(&9I;&4@=7!L;V%D960`3F\@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M(&ES(&%V86EL86)L92!F;W(@)7,`3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O
M=6YD+@!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L
M;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M
M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV
M92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO
M9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,
M(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S
M<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I
M9VYU<',N`$YO('%U;W1A('-E="X`3F\@<F5C=7)R96YC90!.;R!R=6QE<P!.
M;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960`3F\@=F%L:60@96UA:6P@861D<F5S<R!F;W5N9`!.
M;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO
M="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!F;W5N9`!.;W0@:6UP;&5M
M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EF:6-A=&EO;G,`3F]V96UB97(`3F]W
M`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN
M<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T
M($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`
M3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@
M<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N
M`$]N(&%L;"!C86QE;F1A<G,@22!H879E(')E860@86-C97-S('1O`$]N(&%L
M;"!S:&]W;B!C86QE;F1A<G,`3VX@;7D@8V%L96YD87)S(&]N;'D`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S
M:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N86P`3W!T:6]N86P@071T96YD965S`$]P=&EO;G,`3W!T:6]N
M<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I
M;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!)
M;F9O<FUA=&EO;@!/=F5R=FEE=P!/=VYE<@!/=VYE<B!097)M:7-S:6]N<P!/
M=VYE<CH@)7,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0
M($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-`%!-($QI9VAT(%)A
M:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S
M`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE
M80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W0@179E;G1S($QI<W0`4&%S=&4`4&%S
M=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0871T97)N`%!E;F1I;F<@4VEG;G5P
M<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_`%!E<FUI<W-I;VX`4&5R
M;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!0
M97)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA
M;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO
M=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I
M;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@
M;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S
M<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E
M<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@
M=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL
M<P!0;W)T86P@3W!T:6]N<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@
M9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N
M8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@
M`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<`4')E=FEO=7,@1&%Y`%!R979I;W5S(%=E96L`4')E=FEO=7,@
M9&%Y`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+
M97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP
M="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC
M($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A
M=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO
M('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO
M=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE
M`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5C=7(@56YT:6P`4F5C=7)R96YC90!296-U<G)E;F-E
M($1A=&$`4F5C=7)R96YC92!%;F0@1&%T90!296-U<G)E;F-E($EN=&5R=F%L
M`%)E8W5R<F5N8V4@5'EP90!296-U<G,@9&%I;'D`4F5C=7)S(&UO;G1H;'D`
M4F5C=7)S('=E96ML>0!296-U<G,@>65A<FQY`%)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W
M<V5R`%)E;&]A9`!296UA<FMS`%)E;6EN9&5R.B`E<P!296UO=&4@0V%L96YD
M87)S`%)E;6]T92!#86QE;F1A<G,Z`%)E;6]T92!397)V97)S`%)E;6]T92!3
M=6)S8W)I<'1I;VX@55),`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E("5S`%)E;6]V92!!='1E;F1E
M90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN
M9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U
M<V5R.B`E<P!297!L86-E(&5X:7-T:6YG(&-A;&5N9&%R('=I=&@@=&AE(&EM
M<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES(&1E;&5T97,@86QL
M(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&-A;&5N9&%R+CPO<W1R;VYG/@!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E
M<75I<F5D`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I
M;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!!='1E;F1E97,`4F5Q=6ER960@
M1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R
M9`!297-E="!T;R!$969A=6QT<P!297-P;VYS90!297-T;W)E($QA<W0@475E
M<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W
M;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT
M('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T
M92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S
M`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R
M('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN
M="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I
M;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3
M871U<F1A>0!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3
M879E($%S($YE=P!3879E($%T=&5N9&5E<P!3879E($5V96YT`%-A=F4@3W!T
M:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C
M<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A
M=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R
M8V@`4V5A<F-H($-A;&5N9&%R<P!396%R8V@@16YG:6YE<P!396%R8V@@4F5S
M=6QT<P!396%R8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN:6YG.@!396QE8W0@
M1FEL97,`4V5L96-T(&$@8V%L96YD87(@=&\@961I=`!396QE8W0@82!D871E
M`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L
M96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`
M4V5L96-T(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.@!396QE8W0@8V]N9FER;6%T
M:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE
M=W,@86YD(&-H;V]S92!D969A=6QT('9I97<N`%-E;&5C="!N;VYE`%-E;&5C
M="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.@!396QE8W0@=&AE(&-A;&5N
M9&%R*',I('1O(&5X<&]R="!F<F]M`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y
M;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O
M<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@
M=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!3
M96QE8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I
M;7!O<G0Z`%-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3H`4V5L96-T('1H92!F
M;W)M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@=&AE(&ED96YT:71Y
M('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E
M<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1H92!T:6UE('-P
M86X@=&\@<VAO=SH`4V5L96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A
M<G1U<#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!W:&EC
M:"!E=F5N=',@=&\@<VAO=R!I;B!T:&4@<&]R=&%L+@!396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`
M4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YD(&$@8V%N8V5L(&YO
M=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@=&AI
M<R!E=F5N=`!396YD(&%N(&5M86EL('1O("5S`%-E;F0@=7!D871E<R]I;G9I
M=&%T:6]N<R!T;R!A;&P@871T96YD965S('=H96X@<V%V:6YG('1H:7,@979E
M;G0`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT
M96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N
M`%-E<W-I;VYS`%-E=`!3970@96YD(&1A=&4`4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+@!3970@<F5C=7)R96YC92!E;F0@9&%T90!3970@<W1A<G0@9&%T
M90!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@9G)E92]B=7-Y(&-A;&5N
M9&%R<R!A;F0@>6]U<B!O=VX@86YD(&]T:&5R('5S97)S)R!F<F5E+V)U<WD@
M;W!T:6]N<RX`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S
M(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H87)E(&YO="!F;W5N9#H@)7,`
M4VAA<F5D($-A;&5N9&%R<P!3:&%R960@0V%L96YD87)S.@!3:&]P<&EN9P!3
M:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@0V%L96YD87(`4VAO=R!C871E9V]R
M>2!L96=E;F0_`%-H;W<@9&5L971E+"!A;&%R;2P@86YD(')E8W5R<F5N8V4@
M:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_`%-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;BX`4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R
M/P!3:&]W(&9R964O8G5S>2!L96=E;F0_`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O;FQY(&5V96YT<R!T:&%T(&AA=F4@
M86X@86QA<FT@<V5T/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H
M;W<@<&EC:V5R`%-H;W<@<VAA<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_
M`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T87-K<R!U
M<VEN9R!C871E9V]R>2!C;VQO<G,_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&EM92!O9B!D87D@8F5T=V5E;B!E86-H(&1A
M>2!I;B!W965K('9I97=S/P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@
M16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H
M<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T
M=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-
M86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R
M`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S
M($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O
M<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E
M`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C
M:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T
M<P!3<FD@3&%N:V$`4W1A7W)T`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!$
M871E`%-T87)T($]N`%-T87)T(%1I;64`4W1A<G0@>65A<@!3=&%T7W5S`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E
M<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L
M;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3
M=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B
M)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E
M<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I
M<V4`4W5N(%-E=`!3=6YD87D`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E
M=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O
M<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W
M87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3
M>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A
M8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS
M`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I
M97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!4
M96UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@
M`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M
M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N
M`%1E;G1A=&EV90!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($5D:70@071T96YD965S
M('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N="X@17AI=&EN9RX`5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES
M=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C86QE;F1A<B`B)7,B(&-A;FYO="!B92!D96QE=&5D
M+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!C<F5A=&5D+@!4:&4@8V%L
M96YD87(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@8V%L96YD87(@(B5S
M(B!H87,@8F5E;B!R96YA;65D('1O("(E<R(N`%1H92!C86QE;F1A<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@8V%L96YD87(@8V]U;&0@;F]T(&)E('!U
M<F=E9#H@)7,`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A
M<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BX`5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T
M:&4@<W1A<G0@9&%T92X`5&AE(&5V96YT("(E<R(@:&%S(&)E96X@861D960@
M=&\@(B5S(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%1H92!E
M=F5N="`B)7,B(&AA<R!B965N(&1E;&5T960@9G)O;2`B)7,B(&-A;&5N9&%R
M+"!W:&EC:"!W87,@;VX@)7,@870@)7,N`%1H92!E=F5N="`B)7,B(&AA<R!B
M965N(&5D:71E9"!O;B`B)7,B(&-A;&5N9&%R+"!W:&EC:"!I<R!O;B`E<R!A
M="`E<RX`5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@<W5C8V5S
M<V9U;&QY('-E;G0N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N`%1H92!F;VQL;W=I;F<@:7,@82!M;W)E(&1E=&%I;&5D(&1E<V-R:7!T
M:6]N(&]F('1H92!E=F5N=#H`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO
M=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@
M9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P
M;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B
M<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX
M(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@
M:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I
M;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED
M96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S
M="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E
M96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N
M=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@
M;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q
M=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`
M5&AE(')E<75E<W0@=V%S(&EN8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T
M:&%T(&%R92!N96-E<W-A<GD@=&\@86-C97!T(&]R(&1E8VQI;F4@86X@979E
M;G0@87)E(&UI<W-I;F<N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY
M`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N
M`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`
M5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E
M;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO
M=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E
M;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E
M(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R
M979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N
M;R!E=F5N=',@;6%T8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N`%1H97)E
M(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T
M96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@
M=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S
M`%1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<P!4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4
M:&5R92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M
M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R
M92!W87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S
M(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O
M;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E
M<SH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=E<F4@;F\@979E;G1S('1O(&5X
M<&]R="X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I
M;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L
M:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC
M:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@
M5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R
M97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE
M(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L
M=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A
M<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V
M86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S
M-&%F)RX`5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N
M`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<P!4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1H=7)S
M9&%Y`%1I8VME=',`5&EM90!4:6UE(%-P7V%N`%1I;64@5')A8VMI;F<`5&EM
M92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM92!S<&%N`%1I;6]R+4QE<W1E
M`%1I=%]L90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L
M92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O
M(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N
M`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A
M;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5E<V1A>0!4=6YI<VEA`%1U
M<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E`%1Y<&4@>6]U<B!C:&]I
M8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L
M:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L
M92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R
M82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S
M(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE
M('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E
M<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<P!5;F%B
M;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5
M;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N
M86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@(B5S(CH@)7,`56YA8FQE
M('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A
M9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<P!5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O
M($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H
M551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N
M:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M
M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E
M9"!#;VYT96YT+51Y<&4Z("5S`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A
M=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!D871E
M9#H@)7,N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`
M57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U
M87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R($EN=&5R9F%C90!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I
M;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R
M;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L
M90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO
M;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R
M=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI
M`%9I97<@)7,`5FEE=R!$87D`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N
M80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7961N97-D87D`
M5V5E:P!7965K("5D`%=E96LH<RD`5V5E:VQY`%=E96ML>3H@4F5C=7)S(&5V
M97)Y`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!3
M86AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E
M<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&%T('1I;64@<VAO=6QD(&1A
M>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R
M(&5V96YT<S\`5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@
M<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/P!7:&5R
M96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED
M=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T
M:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R
M;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I
M<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5V]R:R!7965K
M`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG
M(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P
M.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87(`665A<FQY
M`%EE87)L>3H@4F5C=7)S(&5V97)Y`%EE;65N`%EE<P!997,L($D@06=R964`
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!E=F5N=',N`%EO=2!A<F4@
M;F]T(&%N(&%T=&5N9&5E(&]F('1H92!S<&5C:69I960@979E;G0N`%EO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;VYL>2!U<V4@=&AI<R!F
M;W)M(&9R;VT@=&AE($5D:70@071T96YD965S('-C<F5E;BX`66]U(&-A;FYO
M="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@
M:&%V92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S
M;VYA;"!);F9O<FUA=&EO;B!/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S
M:&5R925S(&)E9F]R92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT
M+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O
M("5S+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S
M('1O('1H92!S96QE8W1E9"!C86QE;F1A<BX`66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N`%EO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="X`66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+@!9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C
M86QE;F1A<BX`66]U(&AA=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N
M9&5N8V4@=&\@=&AI<R!E=F5N="X`66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E
M8VQI;F5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="X`66]U(&AA=F4@=&5N
M=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU
M<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<V5L96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P
M<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=2!N965D('1O('-E
M;&5C="!A(&-A;&5N9&%R(&9I<G-T`%EO=2!R97%U97-T960@=&\@8F4@;F]T
M:69I960@=VAE;B!E=F5N=',@87)E(&%D9&5D('1O('EO=7(@8V%L96YD87)S
M+@!9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R
M92!D96QE=&5D(&9R;VT@>6]U<B!C86QE;F1A<G,N`%EO=2!R97%U97-T960@
M=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R
M(&-A;&5N9&%R<RX`66]U(')E<75E<W1E9"!T;R!B92!R96UI;F1E9"!A8F]U
M="`E<RP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%EO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D
M9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO
M=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN
M9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T
M97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S
M<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8V%L96YD87(`66]U<B!D969A=6QT
M(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N
M=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N
M`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6U5N;F%M960@979E;G1=`%ML:6YE("5S(&]F("5S70!?061M
M:6YI<W1R871I;VX`7T%L87)M`%]"87-I8R!396%R8V@`7T-,20!?1&%T851R
M964`7T1E;&5T92!2;W<`7T5D:70`7T=O=&\`7T=R;W5P<P!?2&5L<`!?26UA
M9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&]G(&EN`%],;V<@
M;W5T`%]-;V1I9GD@3&EN:RXN+@!?37D@0V%L96YD87)S`%].97<@179E;G0`
M7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]0<FEN=`!?4F5M;W9E($QI;FLN+BX`
M7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U1O9&%Y`%]5
M<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8F5F;W)E('1H
M92!E=F5N="!S=&%R=',`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U
M='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N
M9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!D87D`
M9&%Y*',I`&1A>7,`961I=`!E;G1R>2!N;W0@9F]U;F0`979E;G1S+F-S=@!E
M=F5N=',N:6-S`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E
M`&EN`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A
M<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!M;0!M;VYT:"AS*0!N86UE`&YO="!I;7!L96UE;G1E9`!N
M;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;VX@)7,@870@)7,`;VX@=&AE
M('-A;64@9&%T90!O;B!T:&4@<V%M92!W965K9&%Y`'!E<F-E;G0`<&5R;6ES
M<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R
M:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M
M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@
M;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%L
M96YD87(O:4-A;&5N9&%R`'9#87)D`'9%=F5N="!N;W0@9F]U;F0N`'<Z`'=E
M871H97(N8V]M`'=E96L`=V5E:RAS*2!O;CH`=V5E:W,`>65A<BAS*0!0<F]J
M96-T+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`R+C$M8W9S"E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`R+3(P(#$S.C`S*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-BTP,BTQ."`Q,CHU.2LP,C`P"DQA<W0M5')A;G-L871O<CH@3&5E;F$@
M2&5I;F\@/&QI:6YU0'5T82YF:3X*3&%N9W5A9V4M5&5A;3H@1FEN;FES:"`\
M:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`@*"5S('#D:7;DY"!S:71T
M96XI`"`H4&EK86[D<'#D:6X@)7,I`"`H)7,@<.1I=N1S<^0I`"`H=.1NY.1N
M*0`@*&AU;VUE;FYA*0`@*&5I;&5N*0`@`"(E<R(@96D@;VQE(&AA:V5M:7-T
M;P`B)7,B(&5I(&ME;'!A82!V86QI;FYA:W-I+@`B)7,B(&5I(&]L92!A<V5N
M;F5T='4@2&]R9&5N(')E:VES=&5R:7-SY"X`(B5S(B!P=6ED96X@:W5V86%J
M86$@96D@;/9Y='EN>70N`"(E<R(@;&ESY'1T:6EN(')Y:&WD:N1R:F5S=&5L
M;>3D;BX`(B5S(B!L:7/D='1I:6X@;VEK975K<VEI;BX`(B5S(B!E:2!L=6]T
M=3H@)7,N`"4N,F9-0B!KY'ET971T>2`E+C)F34(@<V%L;&ET=7-T82`H)2XR
M9B4E*0`E9"`E<R!J82`E<P!L]GET>6D@)60@:V%L96YT97)I80!386QA<V%N
M87-I('9A;FAE;G1U=2`E9"!PY&EVY&X@<.3D<W3D+@`E9"!T87!A:'1U;6%A
M`"5D('#D:7;D;B!E;FYU<W1U<P`E<R`M($EL;6]I='5S`"5S(%#D:7;DY"`E
M<R!4=6YT:6$@)7,@36EN=75T=&EA`"5S(%-O<FUE;FKD;&MI`"5S($M"`"5S
M(%EL;.1P:71O=&]I;65N<&ET965T("T@5F%R;6ES='5S`"5S(&%S96YN=7,`
M)7,@:VER:F%U='5M:6YE;@`E<R!KY'ET=/9E:&1O=``E<R!O;B!J;R!O;&5M
M87-S82X`)7,@<W5U;G1A("5S("5S`"5S(&]S86QL:7-T=6IA80`E<R!T:65D
M;W-T;VX@='5O;G1I(&]N;FES='5I`"5S(&]N('9A;&UI<R!S=6]R:71T86UA
M86X@>6QLY'!I=&]T;VEM96YP:71E:73D+B!686QI='-E('9A;&EN=&%R=75D
M=6ES=&$@<W5O<FET971T879A="!T;VEM96YP:71E970N`"5S(&]N('!A:V]L
M;&EN96X`)7,@;6EN=75T=&EA`"5S(&5I(&SV>71Y;GET+@`E<R`M("5S("\@
M)7,`)7,Z;B!O<V]I=&5K:7)J80`E<SIN(&MA;&5N=&5R:0`E<SIN(&UU:7-T
M:6QI<W1A`"5S.FX@=&5H=.1VY&QI<W1A`"5S.B`E<P`E<R`Z(%3D;>0@=FEE
M<W1I(&5I(&]L92!VY&QT=.1MY'1TY"!S:6QTY"!LY&AE='3D:N1L=.0L(&IO
M:V$@;VX@;65R:VET='D@;.1H971TY&KD:W-I+B!3=6AT875D=2!V87)A=6MS
M96QL82!V:65S=&ES<^0@;VQE=FEI;B!L:6YK:V5I:&EN(&IA('9A<F\@86YT
M86UA<W1A(&SD:&5T=.1JY&QL92!M:73DY&X@>6MS:6SV:79IY"!T:65T;VIA
M+@`H3F%P<V%U=&$@:V%L96YT97)I;B!N:6UEY"!V86EH=&%A:W-E<VD@:V%L
M96YT97)I;B!NY&MY=GEY='3D('#DY&EK:W5N87-S82D`*B!,:7/DY"!NY&WD
M(&YA<&%U='1A;6%L;&$@3&ESY.0M<&%I;FEK971T82`J`"H@5F%L:71S92!O
M<V]I='1E970@*@`L('!U=7-K:71T86ES=&$`+"!P=75S:VET=&%I<W1A("5S
M("5S`"P@=F%I:'1E;&5V86$@)7,@+2`E<P`M+2!V86QI='-E("TM`#$@;W-A
M;&QI<W1U:F$`,2!T87!A:'1U;6$`,2!T=6YT:0`Q,BUT=6YN:6X@:N1R:F5S
M=&5L;>0`,34@;6EN=75T=&EA`#(P(&UI;G5U='1I80`R-"UT=6YN:6X@:N1R
M:F5S=&5L;>0`,C0@='5N=&EA`#,P(&UI;G5U='1I80`\161E;&QI;F5N`#QS
M=')O;F<^3W-A;&QI<W1U:F%T/"]S=')O;F<^("AV87!A865H=&]I;F5N*0`\
M<W1R;VYG/DMU=F%?=7,\+W-T<F]N9SX@*'9A<&%A96AT;VEN96XI`#QS=')O
M;F<^079A:6YS86YA=#PO<W1R;VYG/B`H=F%P86%E:'1O:6YE;BD`/'-T<F]N
M9SY4;VES='5V=75S/"]S=')O;F<^("AV87!A865H=&]I;F5N*0!4:65T;VMA
M;G1A=&%U<W1A:N1R:F5S=&5L;>3D(&5I(&]L92!MY.1R:71E;'1Y('3D;&QE
M(&]S:6]L;&4`5&%P86AT=6D@=F%K879A('9I<FAE`%9I97-T:6X@<V%L875K
M<V5E;B!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+@!!;&QE:VER:F]I
M=&5T=6X@=FEE<W1I;B!T87)K:7-T=6MS965N('1A<G9I=&%A;B!J=6QK:6YE
M;B!01U`M879A:6XN`%-A;&%T=6X@=FEE<W1I;B!A=F%A;6ES965N('1A<G9I
M=&%A;B!J=6QK:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'4"UA=F%I;B!J
M82!S86QA<V%N871E:W-T:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A;6ES96MS
M:2!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+"!S86QA:6YE;B!01U`M
M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@879A86UI<V5E;B!T
M87)V:71A86X@:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA:6YE;B!3+TU)
M344M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@86QL96MI<FIO
M:71T86UI<V5K<VD@=&%R=FET86%N(&IU;&MI;F5N(%,O34E-12UA=F%I;BP@
M<V%L86EN96X@4R]-24U%+6%V86EN(&IA('-A;&%S86YA=&5K<W1I+@!6:65S
M=&EN('-A;&%U:W-E96X@=&%R=FET86%N(&IU;&MI;F5N(%--24U%+6%V86EN
M+@!!30!!32!0:6QV:>0`04T@:V5V>71TY"!S861E='1A`$%-('-A9&4`04T@
M<V%T96ET80!!32!L=6UI<V%T96ET80!!32]030!!4$D@240`5&EE=&]J82!E
M9&ET;W)I<W1A`%1I971O:F$N+BX`06)S+B!A;&EN`$%B<RX@:V5S:V5L;.0`
M2'EVY&MS>71T>0!3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@;'5O9&$@5D93
M+6AA:V5M:7-T;V$N`%-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!L=6]D82!6
M1E,M=&EE9&]S=&]A+@!+Y'ET=.1JY'1U;FYU:W-E;B!T:65D;W0`2^1Y='3D
M:N1T=6YN=6MS96X@<V%L87-A;F$`2^1Y='3D:N1T:6QI('-U;&IE='1U+@!+
M:7)J86YP:71O`%1A7W)K96UP:2!H86MU`$QI<^3D`$QI<^3D(&%L:7)Y:&WD
M`$QI<^3D(&%L:6]I:V5U<P!,:7/DY"!T87!A:'1U;6$`3&ESY.0@=.1HY&XZ
M`$QI<^3D('5U<VD@<GEH;>0`3&ESY.0@=75S:2!O:6ME=7,`3&ESY.0@86QI
M<GEH;>0@<GEH;>3D;B`B)7,B`$QI<^3D(&%L:6]I:V5U9&5T("(E<R(`3&ES
MY.0@=75S:2!E=.1K86QE;G1E<FD`3&ESY.0@=75S:2!T87!A:'1U;6$`3&ES
MY.0@=75S:2!KY'ET=.1JY#H`3&ESY.0@;W-A;&QI<W1U:F%T`$QI<^3D('-A
M<F%K90!,:7/DY"!U=7-I82!JY'-E;FGD`$QI<^3D('!A<FD`3&ESY.0@)7,@
M=F%L:6MK;R!-;WII;&QA;B!3:61E8F%R(&]S:6]O;@!,:7/DY"!O<V]I=&5K
M:7)J86%N.@!,:7/DY"!O<V%L;&ES='5J:6EN`$QI<^3D(&]S;VET96MI<FIA
M86YI.@!,:7/DY"!KY'ET=.1JY`!,:7/D='1I:6X@(B5S(B!JY')J97-T96QM
MY.1N+"!M=71T82!E:2!V;VD@;&ESY'3D('-I<^3D;FMI<FIA=71U;6ES<'EY
M;F[V;B!L:7/D=&EE=&]J83H@)7,N`$QI<^1T=&EI;B`B)7,B(&KD<FIE<W1E
M;&WDY&XN(%9O:70@;GET(&MI<FIA=71U82!S:7/DY&XN`$OD>71TY&II96X@
M;&ESY.1M:6YE;B!O;B!E<W1E='1Y+@!/<V]I=&4`3W-O:71E:VER:F$`5F]I
M(&%S971T86$@=&%I(&WDY')I=&5L;.0@;VEK975K<VEA('1O:7-I;&QE(&OD
M>71TY&II;&QE`%EL;.1P:71O`$UA:6YO:W-E=`!487)K96UP:2!H86MU`$%F
M9V%N:7-T86X`2.1L>71Y<P!(Y&QY=.0@)60@<.1I=N3D(&%I:V%I<V5M;6EN
M`$CD;'ETY"`E9"!T=6YT:6$@86EK86ES96UM:6X`2.1L>73D("5D(&UI;G5U
M='1A(&%I:V%I<V5M;6EN`$CD;'ETY"`E9"!V:6EK:V]A(&%I:V%I<V5M;6EN
M`$CD;'ETY"`Q('#D:7;D(&%I:V%I<V5M;6EN`$CD;'ETY"`Q('1U;G1I(&%I
M:V%I<V5M;6EN`$CD;'ETY"`Q(&UI;G5U='1I82!A:6MA:7-E;6UI;@!(Y&QY
M=.0@,2!V:6EK:V\@86EK86ES96UM:6X`2.1L>71Y<W#D:7;D;>3D<N0`2.1L
M>71Y:W-E;B!P:71U=7,@*&UI;G5U='1E:6YA*0!(Y&QY='ES86EK80!!;&)A
M;FEA`$%L9V5R:6$`06QI87,`5&%S86$`5&%S875S.@!+86EK:VD`2V%I:VMI
M(&]S86QL:7-T=6IA=`!+86EK:VD@875T96YT:6MO:61U="!KY'ET=.1JY'0`
M2V%I:VMI('1U;&5V870`2V%I:VMI(')Y:&WD=`!+86EK:VD@;65N;F5E=`!+
M86EK:VD@;VEK975D970`2V%I:VMI(&[D:WEVY'0`2V]K;R!PY&EVY&X`2V]K
M;R!PY&EVY&X@=&%P86AT=6UA`$MA:6MK:2!T87!A:'1U;6%T`$MA:6MI;'1A
M(&YE;&KD;'3D('-I=G5L=&$`4V%L;&D@;6]N970@;W-O:71T965T`%-A;&QI
M(&KD<FIE<W1E='EN(&QI<W1A;B!T>7EP:6X@87-E='5S+@!/;B!J;R!O;&5M
M87-S80!686EH=&]E:'1O:6YE;B!)35-0+7-I<^3D;FMI<FIA=71U;6EN96X`
M5F%I:'1O96AT;VEN96X@24U34"US86QA<V%N80!686EH=&]E:'1O:6YE;B!)
M35-0+6OD>71TY&KD='5N;G5S`%9A:6AT;V5H=&]I<V5T('/D:&OV<&]S=&EO
M<V]I='1E970`5F%I:'1O96AT;VES970@;6%L;&ET`%9A:6AT;V5H=&]I;F5N
M('1E:W-T:3H`66AD>7-V86QT86EN(%-A;6]A`$%N;F5T='4@87)V;R!E:2!K
M96QP86$N`'1A<&%H='5I('1U;G1E;6%T;VX@=FER:&4N`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY>6UI('!R;WAY`%9A<W1A=7,`06YT87)K=&ES
M`$%N=&EG=6$@:F$@0F%R8G5D80!-:6OD('1A:&%N<V$`3VAJ96QM80!/:&IE
M;&UA;&ES=&$`3VAJ96QM82!O;B!V86QM:7,N`$QA:71A(&OD>71T]O9N(&MA
M:6MK:2!A;&EJ86MO:6AI;@!(>7;D:W-Y`$%R=FEO:71U(&MO:V\`:'5H=&EK
M=74`07)A8FEA("A7:6YD;W=S+3$R-38I`%!A:V5T:6X@:V]K;P!086ME=&EN
M(&YI;6D`3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!P;VES=&%A('-I<^3D
M;FMI<FIA=71U;6ES<'EY;F[V;B`E<R`_`$]L971K;R!V87)M82P@971TY"!H
M86QU870@<&]I<W1A82`B)7,B(&IA(&MA:6MK:2!S96X@86QI<GEH;>1T/P!!
M9V5N=&EI;F$`07)M96YI80!!<FUE;FEA("A!4DU30TE)+3@I`%1A:61E`$%R
M=6)A`$%S8V5N<VEO;B!S86%R970`07-C:6DM=&%I9&4`07-I86XO5'EY;F5N
M;65R96X@86QU90!+>7-Y('9A<FUI<W1U<R!E;FYE;B!K=6EN('1E:&3DY&X@
M>6QLY'!I=&]T;VEM96YP:71E970N`%1E:'3D=N1S87)A:VME970`2V5L;&\`
M3&EI='1E96YA(&]N(&E#86QE;F1A<B!T:65D;W-T;RP@:F]S<V$@;VX@;&ES
MY'1I971O:F$@=&%P86AT=6UA<W1A+B!*;W,@<^1H:_9P;W-T:6]H:F5L;6%S
M=&D@='5K964@:51I<"!P>7EN=/9JY"P@;FEI;B!V;VET('3D;>1N('1I961O
M<W1O;B!A=G5L;&$@<.1I=FET=.3D('1I961O=&\@<&%I:V%L;&ES965N(&MO
M<&EO;VXN`%ER:71E='1I:6X@<&]I<W1A82!O;&5M871O;G1A(')Y:&WDY"X`
M67)I=&5T=&EI;B!P;VES=&%A(&]L96UA=&]N=&$@;VEK975T=&$N`%ER:71E
M='1I:6X@;75O:V%T82!O;&5M871O;G1A(&]I:V5U='1A+@!9<FET971T:6EN
M(&UU;VMA=&$@;VQE;6%T;VYT82!J86MO82X`3W-A;&QI<W1U;6EN96X`3W-A
M;&QI<W1U:F%T`$QI<^1MY.1R:71Y:W-E=`!E;&]K=74`075S=')A;&EA`$ET
MY'9A;'1A`$%U=&A?8WER<W%L.B!487)V:71T879A82!)34%0+6QA86IE;FYU
M<W1A(&5I(&SV>71Y;GET+@!!=71H7V-Y<G5S.B!4875S=&%JY')J97-T96QM
MY"!E:2!T=64@=&%R=FET=&%V:6$@;VUI;F%I<W5U:W-I82X`075T:%]C>7)U
M<SH@5&%R=FET=&%V86$@24U!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`
M075T:%]F='`Z('1A<G9I='1A=F%A($944"UL86%J96YN=7-T82!E:2!L]GET
M>6YY="X@2^3D;F[D(%!(4"!KY'ET=.1E;B`M+65N86)L92UF='`@87-E='5S
M=&$N`$%U=&A?:6UA<#H@5&%R=FET=&%V86$@24U!4"UL86%J96YN=7-T82!E
M:2!L]GET>6YY="X`075T:%]K<F(U.B!487)V:71T879A82!K<F(U+6QA86IE
M;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7VQD87`Z(&OD>71TY&II96X@;&ES
MY.1M:6YE;B!!8W1I=F4@1&ER96-T;W)Y>6X@96D@;VQE('1U971T=0!!=71H
M7VQD87`Z($OD>71TY&II96X@<&]I<W1A;6EE;FX@06-T:79E($1I<F5C=&]R
M>7-TY"!E:2!O;&4@='5E='1U`$%U=&A?;&1A<#H@5&%R=FET=&%V86$@3$1!
M4"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T:%]L9&%P.B!%:2!V;VED
M82!L:7/D=.0@:^1Y='3D:N3D("5S+B!086QV96QI;65N('9I<FAE:6QM;VET
M=7,@;VQI.B``075T:%]L9&%P.B!%:2!V;VED82!P;VES=&%A(&OD>71TY&KD
MY"`E<P!!=71H7VQD87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET=.1JY.0@
M)7,`075T:%]L9&%P.B!+Y'ET=.1J:65N('#D:79I='3D;6EN96X@06-T:79E
M($1I<F5C=&]R>7EN(&5I(&]L92!T=65T='4N`$%U=&A?;6-A;#H@5&%R=FET
M=&%V86$@34-!3"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T:%]S;6)A
M=71H.B!487)V:71T879A82!S;6)A=71H+6QA86IE;FYU<W1A(&5I(&SV>71Y
M;GET+@!!=71E;G1I:V]I;G1I($E-05`M<&%L=F5L:6UE;&QE(&5PY&]N;FES
M='5I+@!!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I`$%U=&5N=&EK;VEN=&D@
M97#D;VYN:7-T=6DN("5S`$%U=&5N=&EK;VEN=&D@4D%$2553+7!A;'9E;&EM
M96QT82!E<.1O;FYI<W1U:2X`075T96YT:6MO:6YT:2!&5%`M<&%L=F5L:6UE
M;&QE(&5PY&]N;FES='5I+@!!=71E;G1I:V]I;G1I(%--0BUP86QV96QI;65L
M;&4@97#D;VYN:7-T=6DN`$OD>71E='3D=FES<^1O;&5V870@:V5N=.1T.@!!
M>F5R8F%I>F1A;@!"3T9(('-E;&ET>6MS970`5&%U<W1A`%1A=7-T87;D<FD`
M5N3D<N0@:V5R8F5R;W,@<V%L87-A;F$N`%;DY'+D(&ME<F)E<F]S(&OD>71T
MY&KD='5N;G5S+@!"86AA;6$`0F%H<F%I;@!"86QT:6$@*$E33RTX.#4Y+3$S
M*0!"86YG;&%D97-H`$)A<F)A9&]S`$=R869I:6MO:61E;B!P97)U<VAA:V5M
M:7-T;V$@(B5S(B!E:2!L]GET>6YY="X`4&5R=7-V:6EV80!9:W-I;FME<G1A
M:6YE;B!H86MU`%9A;&MO+59E;N1JY`!"96QG:6$`0F5L:7IE`$)E;FEN`$)E
M<FUU9&$`0FAU=&%N`%-Y;G1Y;>1PY&EVY`!/<VEO=&$@(B5S(B!O:&IE;&UA
M;&QE("(E<R(@96D@;/9Y='EN>70N`$]S:6]N(&%S971U:W-E=`!/<VEO;B!T
M>7EP<&D`3&EH879O:71U`$)O;&EV:6$`2VER:F%N;65R:VET`%)E=6YA`%)E
M=6YA;B!V86AV=75S.@!2975N870`0F]S;FEA($AE<GIE9V]V:6YA`$UO;&5M
M;6%T`$)O='-W86YA`$%L:6X`0F]U=F5T('-A87)E=`!"<F%S:6QI80!"<FET
M86YN:6%N($EN=&EA;B!V86QT86UE<F5N('1E<G)I=&]R:6\`0G)U;F5I($1A
M<G5S86QA;0!"=6QG87)I80!086QL=6MK86QI<W1A`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`%9A<F%T='4`0TU3`$-20P!#4DPM:F%K96QU;W-O:71T965T`%]+
M86QE;G1E<FD`4U]O;'5N('1I961O="XN+@!6Y&QI;75I<W1I;B!A;'5S='5S
M(&5I('9A;&UI<W1U;G5T+@!+7V%L96YT97)I`$MA;&5N=&5R:0!+86QE;G1E
M<FEN('EH=&5E;G9E=&\`2V%L96YT97)I;B!P;VES=&\@;VYN:7-T=6DN`$MA
M;&5N=&5R:70`2V%L96YT97)I;&QA('!I=.3D(&]L;&$@;FEM:2X`5'EY;FD`
M2V%M<'5T<V5A`$MA;65R=6X`4V%L87-A;F%A(&5I('9O:2!T>6AJ96YTY.0@
M875T;VUA871T:7-E<W1I+"!O=&$@>6AT97ET=.0@>6QLY'!I=.1JY.1N+@!%
M:2!V;VD@:VER:F]I='1A82!T:65D;W-T;V]N("(E<R(`56QK;VES:6$@:7-T
M=6YT;VOD<VET=&5L:6KV:73D(&5I(&]L92!M86AD;VQL:7-T82!H86QL:71A
M+@!)34%0+7!A;'9E;&EM965N(&5I('-A871U('EH=&5Y='3D.B`E<P!%:2!V
M;VED82!L=6]D82!U=71T82!T87!A:'1U;6%A;BX`16D@=F]I(&%V871A('1I
M961O<W1O82`B)7,B+@!+86YA9&$`4&5R=0!097)U(&]N9V5L;6%V:65S=&D`
M4&5R=71T=0!097)U='1U.B`E<P!%:2!V;VED82!P;VES=&%A('1I961O<W1O
M82`B)7,B+@!6Y&QI86EK86ES:&%K96UI<W1O82!E:2!L]GET>6YY="X`16D@
M=F]I9&$@:F%T:V%A(&EL;6%N("=T87)G971&:6QE)R`M<&%R86UE=')I82X`
M16D@=F]I9&$@<&]I<W1A82!H86ME;6ES=&]A("(E<R(N`$5I('9O:61A('!O
M:7-T86$L("5D(&%L:71A<V]J82!O;&5M87-S82X`16D@=F]I('5U9&5L;&5E
M;FKD<FIE<W3DY"P@86YN971T=6IE;B!T:65T=65I9&5N(&WDY'+D(&5I('9A
M<W1A82!T86QL971E='1U:F5N('1I971U96ED96X@;>3D<N3D+@!%:2!V;VD@
M;VAJ871A('9I97-T:>0@86YN971T=75N(&YU;65R;V]N+@!+87`@5F5R9&4`
M2W5V871E:W-T:0!086QV96QU;G1A<FIO86IA`$MA=&5G;W)I7V$`2V%T96=O
M<FEA="!J82!O='-I:V]T`$MA=&5G;W)I80!#87EM86X@<V%A<F5T`%!U:&5L
M:6XH1U--*0!3;VQU;B!T:65D;W0`4V]L=6X@=.1Y=&4Z`%-O;'5N('1I961O
M=`!3;VQU;B!VY&QY<SH`36%T:V%P=6AE;&EN`$ME;'1T:2`H25-/+3@X-3DM
M,30I`$ME<VMI=&5T='D`2V5S:VDM069R:6MA;B!T87-A=F%L=&$`2V5S:VDM
M175R;V]P<&$@*$E33RTX.#4Y+3(I`%9A<FUE;G1E96X@=&EE9&]T`%9A<FUE
M;G1E96X@;VUI<W1A:F$`5F%R;65N=&5E;B!P;VQI=&EI:V%T`%1S860`375U
M=&$`5F%I:&1A('-A;&%S86YA<VD`5F]I="!M=75T=&%A(&SD:&5T=.1M:7-S
MY'-I('/D:&OV<&]S=&5I<W-A(&[D:WEV:>0@;FEM:2T@=&%I(&]S;VET971I
M971O:F$N`%-A;&%S86YA;B!V86EH=&\@96D@;VQE(&OD>73V<W/D(&YY:WEI
M<VEL;.0@87-E='5K<VEL;&$N($]T82!Y:'1E>71TY"!Y;&SD<&ETY&II:6XN
M`$UE<FMK:0!487)K:7-T7V$@;&EN:VMI+BXN`$-H:6QE`$MI:6YA`$MI:6YA
M('EK<VEN:V5R=&%I<W1E='1U("A'0C(S,3(I`$MI:6YA('!E<FEN=&5I;F5N
M("A":6<U*0!686QI='-E(&]H:F5L;6$`5F%L:71S92!S86QA<V%N80!686QI
M='-E(&OD>71TY&KD='5N;G5S`%9A;&ET<V4@<.1I=N1MY.1R:65N(&5S:71Y
M<V%S=3H`5F%L:71S92!H86QU871K;R!S86%D82!I;&UO:71U:W-I82!U=7-I
M<W1A+"!M=6]K871U:7-T82!T86D@<&]I<W1E='5I<W1A('1A<&%H='5M:7-T
M82!SY&AK]G!O<W1I='-E.@!686QI='-E(&AA;'5A=&MO('-A861A(&EL;6]I
M='5K<VEA('5U<VES=&$L(&UU;VMA='5I<W1A('1A:2!P;VES=&5T=6ES=&$@
M=&%P86AT=6UI<W1A+@!686QI='-E(&AA;'5A=&MO('-A861A(&UU:7-T=71U
M:W-I82!SY&AK]G!O<W1I='-E('1A<&%H='5M:7-T82P@:F]I:&EN(&]N(&QI
M:71E='1Y(&CD;'ET>7,Z`%9A;&ET<V4@;&ES=&%N('1Y>7!P:2`H:N1R:F5S
M=&5T>6EL;&4@;&ES=&]I;&QE*0!686QI='-E(&]S;VET96MI<FIA="P@:F]I
M<W1A(&5T<VETY.1N('9A<&%A+W9A<F%T='4@55),96IA.@!686QI='-E(&MA
M;&5N=&5R:70L(&IO=&MA(&AA;'5A="!L:6ET971TY';D('9A<&%A+W9A<F%T
M='4@;&ES=&%U:W-I:6XZ`%9A;&ET<V4@:V%L96YT97)I="P@:F]I<W1A('1E
M:&3DY&X@=F%P86$O=F%R871T=2!54DQE:F$Z`%9O:70@=F%L:71A(&]L971U
M<VMA;&5N=&5R:7-I+@!*;W5L=7-A87)E=`!,=6]K:V%MY.1R:71Y<W3D("5S
M(&5I(&SV>71Y;GET+@!396QK9>0`4&]I<W1A($U33V9F:6-E('1A9VET`%!O
M:7-T82!K>7-E;'D`4&]I<W1A(&MA:6MK:2!O<V%L;&ES='5J870`4&]I<W1A
M(&OD>71TY&KD.B`E<P!0;VES=&$@:^1Y='3D:N0`4&]I<W1A(&OD>71TY&KD
M;B!T:65D;W0`4V5L:V5N97;DY"!M>?9HY.1N`$YA<'-A=71A(&IA=&MA86MS
M97-I`$-L:6MA=&5L;"!(5%10.FX@:V%U='1A`%-U;&IE(&EK:W5N80!3=6QJ
M92!I:VMU;F$`4&EL=FGD`%!I;'9I;F5N(&%I:V%I<VEN`%!I;'9I;F5N`$MO
M;VMO<R`H2V5E;&EN9RD@<V%A<F5T`%!I96YE;F[D('-I=G5V86QI:VMO`%!I
M96YE;FYE='ET(')E=6YA=`!+;VQU;6)I80!6Y')I`%;D<FEV86QI='-I;@!6
MY')I=F%L:6YT80!387)A:SH`4V%R86MK96ED96X@;W1S:6MO=`!387)J86MU
M=F%T`%!I;&MU:6QL82!E<F]T971U="!A<G9O=`!+;VUE;G1O`$MO;65N=&]T
M=6QK:VD`2V]M;65N='1I`%EL96EN96X@;FEM:0!+;VUO<FET`%ER:71Y<P!4
M:65T;VMO;F5E=`!/;&]S=6AD90!/;&]S=6AT965T`$%S971U:W-I96X@97)O
M=`!!<V5T=6MS970@4$1!+6QA:71T96ED96XL(.1L>7!U:&5L:6UI96X@:F$@
M3W5T;&]O:VEN('-Y;FMR;VYO:71I:6XN`$%S971U:W-I82!P:73DY"!PY&EV
M:71TY.0N`$%S971A(&%S971U:W-E="`E<P!686AV:7-T82!K:7)J;VET=&%M
M86QL82!S86QA<V%N82!U=61E<W1A86X`5F%R;6ES=&$@=&%P86AT=6UI96X@
M<&]I<W1O+@!687)M:7-T971T=0!+;VYG;P!+;VYG;VX@9&5M;VMR86%T=&EN
M96X@=&%S879A;'1A`%EH=&5Y<R!E<.1O;FYI<W1U:2X`66AT97ES(&5PY&]N
M;FES='5I.B``66AT97ES(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L
M;&4@97#D;VYN:7-T=6DN`%EH=&5Y<R!J=6QK:7-T96X@879A:6YT96X@<&%L
M=F5L:6UE;&QE(&5PY&]N;FES='5I+B!6:7)H93H@)7,@*"5S*0!9:'1E>7,@
M9G1P+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`66AT97ES=&EE9&]T`%EH
M=&5Y<W1I961O="!L:7/D='1I:6X@;W-O:71E:VER:F%A<VDN`%1I:79I<W1E
M='EN('1I961O<W1O;B!T>7EP<&DZ`"(E<R(Z;B!S:7/D;'3V`$IA=&MA`$-O
M;VL@<V%A<F5T`$5VY'-T90!+;W!I;VD`2V]P:6]I;G1I(&5PY&]N;FES='5I
M.B`E<P!+;W!I;VD@=F%L:6YT80!+;W!I;VD@86QL82!O;&5V82!54DP@<VEN
M;F4@;6EN;F4@=&%R=FET<V5T('9A<&%A+W9A<F%T='4@55),.N3D.@!#;W-T
M($E$`$-O<W1A(%)I8V$`3F]R<W5N;'5U<F%N;FEK:V\`5FEE<W1I;B!01U`M
M<V%L875S=&$@96D@=F]I='4@=&5H9.0Z(`!6:65S=&EI;B!E:2!V;VET=2!M
M=6]D;W-T86$@4$=0+6%L;&5K:7)J;VET=7-T83H@`%9I97-T:6X@4R]-24U%
M+7-A;&%U<W1A(&5I('9O:71U('1E:&3D+@!6:65S=&EI;B!E:2!V;VET=2!M
M=6]D;W-T86$@4R]-24U%+6%L;&5K:7)J;VET=7-T82X`16D@=F]I='4@;W1T
M86$@>6AT97ET=.0N("5S`$QD87`M<&%L=F5L:6UE96X@96D@<V%A='4@875T
M;W)I<V]I='5A('EH=&5Y='3D+@!%:2!V;VET=2!T87)K:7-T86$@<V%L9&]A
M+B`E<P!,1$%0+7!A;'9E;&EM965N(&5I('-A871U('EH=&5Y='3D+@!%:2!V
M;VET=2!O='1A82!Y:'1E>71TY"!P86QV96QI;65E;B`B)7,B(&OD>71TY&5N
M($944#H@)7,`16D@=F]I='4@;'5O9&$@:F%K96QU;&ES=&%A+B`E<P!01U`M
M<V%L871T=6$@=&EE=&]A(&5I('9O:71U(&%U:V%I<W1A.B``4R]-24U%+7-A
M;&%T='5A('1I971O82!E:2!V;VET=2!A=6MA:7-T82X`16D@=F]I='4@<&]I
M<W1A82!Y:'1E>7-T:65T;V$N("5S`$5I('9O:71U('!O:7-T86$@:F%K96QU
M;&ES=&%A+B`E<P!%:2!V;VET=2!P;VES=&%A('#D:79I='ES<VMR:7!T:>0@
M(B5S(BX`5FEE<W1I;B!LY&AE='3D:N1N('/D:&OV<&]S=&EO<V]I=&5T=&$@
M96D@<'ES='ET='D@;>3D<FET=&5L96WDY&XN`$5I('9O:71U(&AA:V5A(&MO
M:V\@;W-O:71E:VER:F%A+@!%:2!V;VET=2!H86ME82!K;VMO(&IA:V5L=6QI
M<W1A82X`16D@=F]I='4@:&%K96$@:V]K;R!L:7-T86$@:F%K96QU;&ES=&]I
M<W1A+@!%:2!V;VET=2!L=6ME82!S=')A=&5G:6%A("(E<R(N`$MO;65N=&\@
M;6MD:7(@(B5S(B!E<.1O;FYI<W1U:2X`2G5L:VES=&5N(&%V86EN=&5N('!A
M;'9E;&EM96QT82!E:2!S86%T=2!J=6QK:7-T82!A=F%I;G1A+@!4:65D;W-T
M;V]N("(E<R(@96D@=F]I(&MI<FIO:71T86$N`$5I('9O:71U(&%U:V%I<W1A
M("5S+@!9;&SD<&ET;VUO9'5U;&EN("5S(&%U:V%I<W4@97#D;VYN:7-T=6D`
M16D@=F]I(&%U:V%I<W1A(&AA:V5M:7-T;V$@(B5S(BX`3$1!4"UP86QV96QI
M;65L=&$@96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD+@`E<SKDY"!E:2!V;VET
M=2!L=6ME82X`2^1Y='3D:N1N('-A;&%S86YA82!E:2!V;VET=2!N;VQL871A
M+B!*;W1K=70@=&%R=FET=&%V870@=&EE9&]T(&]V870@=N3D<FEN+B!9<FET
MY"!U=61E<W1A86X@=&%I(&]T82!Y:'1E>71TY"!Y;&SD<&ET;V]N(&IO<R!T
M87)V:71S970@;&ESY.0@87!U82X`16D@=F]I='4@:&%K96$@04-,+71I971O
M:F$`16D@=F]I='4@:&%K96$@;W-O:71E:VER:F%A+B`E<P!%:2!V;VET=2!H
M86ME82!J86ME;'5L:7-T86$N("5S`$5I('9O:71U(&AA:V5A(&IA:V5L=6QI
M<W1O:F$N("5S`$5I('9O:71U(&AA:V5A('1I971O:F$@<&%L=F5L:6UE;B!T
M;VEM:6YN;VES=&$`16D@=F]I='4@<&%L875T=&%A(&%S971U:W-I82X`2V]M
M96YT;R!R;61I<B`B)7,B(&5PY&]N;FES='5I+@!%:2!V;VET=2!T86QL971T
M86$@)7,@87-E='5K<VEA+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N
M('9A<FUU=7-K;W!I;W1A+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N
M('9A<FUU=7-K;W!I;W1A("5S`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-P
MY&EV:71Y<W-K<FEP=&GD.B`B)7,B+@!%:2!V;VET=2!T86QL971T86$@87-E
M='5S=&5N('9A<FUU=7-K;W!I;W1A("5S+@!!<V5T=7-T:65D;W-T;VX@)7,@
M=&%L;&5T=7,@97#D;VYN:7-T=6DN(%9O:70@:^1Y='3DY"!J;W1A:VEN(&%S
M971U<W1A('1A;&QE='1A86MS97-I(&MO;V1I;B!T86MA:7-I;B`E<R!T86D@
M=&%I(&MO<&EO:61A(&OD<VEN(&%L;&$@;VQE=F%N(&MO;V1I;B!T:65D;W-T
M;V]N("5S+@!,1$%0+7!A;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L;&ES=&$@
M971S:>0N`$MO;65N=&\@=6YL:6YK("(E<R(@97#D;VYN:7-T=6DN`$5I('9O
M:71U('#D:79I='3DY"!Y:'1E>7-T:65T;VIA+B`E<P!%:2!V;VET=2!PY&EV
M:71TY.0@:F%K96QU;&ES=&%A+B`E<P!6:65S=&5JY"!E:2!V;VET=2!P;VES
M=&%A(&MA;G-I;W-T82`B)7,B.B`E<P!-;WII;&QA(%-I9&5B87(@96D@;/9Y
M='EN>70N(%9A<FUI<W1A(&5T=.0@4VED96)A<B!O<VEO(&]N(&%U:VDN`$OD
M>71TY&KD;&QE("(E<R(@96D@=F]I='4@86YT86$@<V5U<F%A=FEA(&]I:V5U
M<VEA(&MA;G-I;V]N("(E<R(Z("5S`$QA<VME='1U('1E:W-T:0!-86$`2W5R
M<W-I=`!,=6\`3'5O(&MA;&5N=&5R:0!,=6\@=75S:2!T87!A:'1U;6$`3'5O
M('5U<VD@;&EN:VMI`$QU;R!U=7-I`%9O:2!L=6]D82!U=7-I82!K86YS:6]I
M=&$`3'5O='4`3VEK975D970@=&5K:6KD;&SD`$QU;W1T;VMO<G1I;FYU;65R
M;P!+<F]A=&EA`$MU=6)A`$YY:WEI;F5N`%3D;>1N:&5T:VEN96X@-"!V86EH
M971T80!4Y&WD;FAE=&MI<V5T(&ES='5N;F]T`$ME;&QO;F%I:V$@=.1L;.0@
M:&5T:V5L;.0`5.1MY&YH971K:6YE;B!54DP@;VX`5.1MY&YH971K:7-E="!K
MY'ET=.1JY'0`5.1MY&YH971K:6YE;B!SY.0`5.1MY&YH971K:6YE;B!T:6QA
M.B``5.1MY&YH971K:6YE;B!T>7EL:0!6;VET(&UU;VMA=&$@=&5H=.1V:>0L
M(&IO=&MA('-U;W)I=&5T86%N(&MU;B!K:7)J875D=71A86X@<VESY.1N(&]H
M:F5L;6%A;B`E<RX`3&5I:VMA80!,96EK:V%A('9A;&ET='4`2WEP<F]S`$MY
M<FEL;&EN96X@*$M/23@M4BD`2WER:6QL:6YE;B`H5VEN9&]W<RTQ,C4Q*0!+
M>7)I;&QI;F5N+U5K<F%I;F$@*$M/23@M52D`5'-E:VEN('1A<V%V86QT80!0
M4`!$4TX@*&QI<^1T:65T;V$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO
M96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!0Y&EV:71T
MY&EN`%#D:79I='3D:6XZ(%1O:7-T=79U=61E;B!VY&QI`$1A=&%4<F5E+7-E
M;&%I;@!4:65T;VMA;G1A:&%K=0!0Y&EVY'ES`%#D:7;D;>3D<N0@=F%S=&%A
M;F]T971T=0!0Y&EVY&WDY'+D;B!V86QI;G1A`%#D:7;D`%#D:7;DY`!0;U]I
M<W1A`%!O7VES=&$@<V%R86ME`&IO=6QU:W5U`$1E<VEM86%L:6YU;65R;W0`
M2VEE;'3D>71Y:0!0:65N96YNY"!S:7-E;FYY<W3D`$]L971U<P!/;&5T=7-K
M86QE;G1E<FD`3VQE='5S=N1R:0!/;&5T=7-P<F]F:6EL:0!/;&5T=7,@:V]M
M96YT;W1U;&MK:0!-Y.1R:71E;&WD=`!0;VES=&$`4&]I<W1A("5S`%!O:7-T
M82!S;VQU`%!O:7-T82!T87!A:'1U;6$`4&]I<W1A(')Y:&WD`%!O:7-T82!L
M;VMI`%!O:7-T82!O:6ME=7,`5F]I('!O:7-T86$@:F$@='5H;W1A('!O:7-T
M971T=6IA('9I97-T96KD`%!O:7-T82!S;VQU`%!O:7-T82!S87)A:V4`4&]I
M<W1A(&]L96UA<W-A(&]L979A="!V86EH=&]E:'1O:6YE;B!M86QL:0!6;VD@
M<&]I<W1A82!V:65S=&5JY`!0;VES=&$@(B5S(CIN(&]I:V5U:W-I80!/;&5T
M:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@(B5S(B!J82!K86EK:VD@
M<V5N(&%L:6]I:V5U9&5T/P!0;VES=&$@<FEV:0!0;VES=&$@=F%L:71T=2!P
M<F]F:6EL:0!6;VD@;'5O9&$@=75S:6$@:V%N<VEO:71A`%!O:7-T82!V86QI
M='1U('-A<F%K90!0;VES=&$@=F%I;B!TY&WD('1A<&%H='5M82P@=.1MY"!T
M87!A:'1U;6$@:F$@:V%I:VMI('-E;B!T;VES:6YN;W0@=F%I(&MA:6MK:2!T
MY&CD;B!T87!A:'1U;6%A;B!L:6ET='EVY'0N`%!O:7-T82!V86QI='1U(')I
M=FD`4&]I<W1E='1U('#D:79I='ES<VMR:7!T:2`B)7,B+@!4;VEM:71U<V%I
M:V$`5&%N<VMA`$MU7W9A=7,`3VYG96QM86X@:W5V875S`$MU=F%U<P!487)K
M96UM870@=&EE9&]T("AL]GET>7;D="!M>?9S($AO<F1E.FX@;&]K:71I961O
M<W1O<W1A*3H`5&%R:V5M;6%T('1I961O="!O;B!T86QL971E='1U('EL;.1P
M:61O;B!KY'-I=&5L=.1VY&MS:2X`2V5H:71Y<P!+;W-T975S<&ES=&4`161E
M;&QI<V5N('1U;FYI;B!K;W-T975S<&ES=&4Z(`!+;W-T975S<&ES=&4Z(`!3
M=75N=&$@=F%S96UM86QT82!O:6ME86QL90!3=75N=&$@;VEK96%L=&$@=F%S
M96UM86QL90!(86ME;6ES=&\`3N1Y=.0`2^1Y=.0@,C0M='5N;FEN(&%I:V%E
M<VET>7-TY"X`3N1Y=.0@:V%L96YT97)I=`!.Y&MY;>1N(&%S971U:W-E=`!%
M<VET>7-T87!A('EK<VET>6ES:V]H=&%I;F5N(&5N;G5S=&4`17-I='ES=&%P
M82!E;FYU<W1E96QL92`H5$%&*0!%<VET>7-T87!A`%!E<FEL;&5M96YO:6QM
M;VET=7,`1&II8F]U=&D`16D@<V%A('!O:7-T86$`Q&SD(&OD>73D('-U;W)A
M86X@;6%I;G1E;F%N8V4N<&AP.G3D`$[D>73D(&MA;&5N=&5R:7-S82!N92!T
M96ATY';D="P@:F]T:V$@<&ETY&ES:2!O;&QA('9A;&UI:6YA+@!%:2!T;VES
M='4`2F]S(&5N<VEM;>1I;F5N(')I=FD@<VESY&QTY.0@<V%R86MK96ED96X@
M;W1S:6MO="P@;FEI;B!V86QI='-E.@!$;VUI;FEK86%N:6YE;@!$;VUI;FEK
M86%N:6YE;B!T87-A=F%L=&$`16EK]B!O;&4@:^1Y='3D:N1T=6YN=7-T83\@
M2VER:F%U9'4@:^1Y='3D:N1K<VDN`%1A;&QE;FYA`%1A;&QE;FYA("5S`%1A
M;&QE;FYA(&QU;W1U(&%S971U<R!02%`M<VMR:7!T:6[D+@!!;&%S=F5T;W9A
M;&EK:V\`2'5U;65E=`!686QM:7-T=74Z("5S`$ME<W1O`%/D:&OV<&]S=&EO
M<V]I=&4`14UA:6PM=&\M4TU3(&=A=&5W87D@86IU<FDL(&YI:6QL92!P86QV
M96QU;G1A<FIO86II;&QE+"!J;W1K82!T87)J;V%V870@=.1TY"!P86QV96QU
M82X`5DE22$4`16-U861O<@!-=6]K:V%A`$UU;VMK86$@)7,`375O:VMA82!O
M<V%L;&ES='5J:6$`375O:VMA82!O<VEO=&$`375O:VMA82!K86QE;G1E<F5I
M=&$`375O:VMA82!R>6AMY.0`375O:VMA82!O:6ME=71T80!-=6]K:V%A(&]I
M:V5U:W-I80!-=6]K:V%A("<E<R<Z;B!O:6ME=6MS:6$`375O:VMA82!E=.1K
M86QE;G1E<F5I=&$`375O:VMA82!O<V%L;&ES='5J:6$`375O:VMA82!K871E
M9V]R:6]I=&$@:F$@=N1R96KD`$UU;VMK86$@87-E='5K<VEA.@!-=6]K:V%A
M("(E<R(Z;B!O:6ME=6MS:6$`375O:VMA82`E<SIN(&]I:V5U:W-I80!+;W5L
M=71U<P!%9WEP=&D`16P@4V%L=F%D;W(`16QE;65N='1I+BXN`$5M`%/D:&OV
M<&]S=&D`4^1H:_9P;W-T:6]S;VET90!3Y&AK]G!O<W1I;W-O:71T96ED96X@
M<&ETY.0@;VQL82!S86UA="X`4^1H:_9P;W-T:2!V87)M:7-T=6MS96QL80!%
M;6%I;"UT;RU335,@1V%T97=A>0!(>6UI]G0`5'EH:N0@=FEE<W1I+@!4>6AJ
MY"!V87-T875S+@!4>6AJY"!H86MU=&5R;6D`4.3D='1Y7WD`4V%L;&D@:W5V
M:65N(&QA:71T86UI;F5N(&MU=F%G86QL97)I87-T82!T96MS=&EN(&IO=6MK
M;V]N+@!,86ET82!PY.1L;&4@;VEK96%N('!A:6YI:VME96X@:V]N=&5K<W1I
M;65N=2X`4.3D='1Y;6ES<.1I=N1MY.1RY`!0Y.1T='EY`%#DY'1T>6UI<V%I
M:V$`4.3D='1Y;6ES=G5O<VD`4W5U<F5N;F$@961I=&]R:6$`06YN82!K>7-Y
M;7ES(&IO:V$@:WES>73DY&XL(&IO<R!S86QA<V%N87-I(&IO=61U=&%A;B!N
M;VQL86%M86%N(&5S:6UE<FMI:W-I("=M:6OD(&]N(&QE;6UI:VMI<VD@;FEM
M:3\G.@!,86ET82!K=79A(%523"!TY&CD;@!!;FYA(&MI<FIA:6UE="!A;&QE
M.@!%:W9A=&]R:6%A;&EN96X@1W5I;F5A`$5R:71R96$`5FER:&4`5FER:&4@
M<.1I=FET971TY&5S<^0@;W-I;W1A.B`E<P!6:7)H92!PY&EV:71E='3D97-S
MY"!S>6YC(&%N8VAO<B`M=&EE=&]A.B`E<P!6:7)H92!P;VES=&5T=&%E<W-A
M('-Y;F,@;&]K:6$Z("5S`%9I<FAE(&AA971T865S<V$@<VESY&QT]N0Z("5S
M+@!487!A:'1U:2!V:7)H92!T=6]T865S<V$@=F%P86$O=F%R871T=2!T:65T
M;VIA("5S.FQL93H@)7,`5FER:&4@<.1I=FET971TY&5S<^0@<V%L87-A;F%A
M.B`E<P!6:7)H92!SY&AK]G!O<W1I=FEE<W1I<W/D+@!6:7)H92!K:7)J;VET
M971T865S<V$@(B5S(BX`165S=&D`171I;W!I80!%=&YI;F5N`$5U<F]O<'!A
M`%1A<&%H='5M82!L:7/D='1I:6XZ`%1A<&%H='5M82!P;VES=&5T=&EI;CH`
M5&%P86AT=6UA82!M=6]K871T:6EN.@!487!A:'1U;6$@86QK865N("5S(&QO
M<'!U96X@)7,`5&%P86AT=6UA82!E:2!L]GET>6YY=`!487!A:'1U;6EL;&$@
M<&ETY.0@;VQL82!A;&MA;6ES86IA;FMO:'1A+@!487!A:'1U;6EL;&$@<&ET
MY.0@;VQL82!O='-I:VMO`#$U(&UI;G5U=&EN(';D;&5I;@`R(&UI;G5U=&EN
M(';D;&5I;@`S,"!S96MU;FYI;B!VY&QE:6X`-2!M:6YU=71I;B!VY&QE:6X`
M2F]K86ES96QL82!S:7/DY&YK:7)J875T=6UI<V5L;&$`4'5O;&5N('1U;FYI
M;B!VY&QE:6X`36EN=75T:6X@=N1L96EN`$5S:6UE<FMK:6%R=F]T.@!3=6]R
M:71A`$QA86IE;FYA`$QA86IE;FYA(&YI;65T`$QA86IE;FYA('-I=G5V86QI
M:VMO`$]D;W1E='1I:6X@;65R:VMIY"`G*2<`4V%N82!S96QL86ES96YA86X@
M=&%I(&AA:W5T97)M:2!L86EN875S;65R:V5I<W/D`$QO<'!U<.1I=N1MY.1R
MY`!%:W-P;VYE;G1T:0!6:64`5FEE(&MA;&5N=&5R:0!&1R!VY')I`$%S971U
M<W1I961O<W1O:F5N('1U;VYT:2!&5%`Z;&SD`$%S971U<W1E;B!H86MU(&5P
MY&]N;FES='5I+@!9:'1E>7,@3$1!4"UP86QV96QI;65E;B!E<.1O;FYI<W1U
M:2X`66AT97ES(%--0BUP86QV96QI;65E;B!E<.1O;FYI<W1U:2X`2V]P:6]I
M;G1I("(E<R(Z;'3D(&5PY&]N;FES='5I+@!+;W!I;VEN=&D@(B5S(CIL;&4@
M97#D;VYN:7-T=6DN`%5U9&5N(%-!4TPM>6AT97ED96X@;'5O;6EN96X@97#D
M;VYN:7-T=6DN`%-I:7)T;R`B)7,B.N3D;B!E<.1O;FYI<W1U:2X`4VEI<G1O
M(&5PY&]N;FES='5I.B`E<P!+875N:7,`1F%L:VQA;F1I;B!S86%R970@*$UA
M;'9I;F%S*0!&Y'(@<V%A<F5T`%9A:V%V82!V:7)H93H`1F%K<VD`1F%K<VET
M`&AE;&UI:W5U`%1U;G1U=2!K=6EN`%1U;G1U=2!K=6EN.B``375U=&%M:6$@
M<V%T96ET80!-=75T86UI82!L=6UI<V%T96ET80!+96YT=.1M871R:6ES:0!&
M:6=L970@0T%05$-(00!&:6=L970@:VER:F%S:6X`1FED>FD`5&EE9&]S=&\`
M5&EE9&]S=&]J96X@;'5K=6WDY'+D.B`E<R!T:65D;W-T;P!4:65D;W-T;VIE
M;B!L=6MU;>3D<N0Z("5S('1I961O<W1O80!4:65D;W-T;VIE;B!KY'-I='1E
M;'D`5&EE9&]S=&]N(&YI;6D`5&EE9&]S=&]N('9A;&EN=&$`5&EE9&]S=&]N
M('1U;VYT:0!4:65D;W-T;VIE;B!T=6]N=&D@96D@;VQE(&OD>71E='3D=FES
M<^0N`%-U;V1A='1I;65T`$AA:W4`4W5O;6D`16YS:6UMY&EN96X@<'5O;&ES
M:V\`16YS:6UMY&EN96X@;F5L:N1N;F5S`$MO<FIA82!S=6AD90!+Y.1N;N0@
M>6UPY')I`$ME;&QU=F$`4W5M=0!+86YS:6]T82`E<R!E:2!O;&4@;VQE;6%S
M<V$N`$MI<FIA<VEM96X@=N1R:0!2=6]K80!396QA:6UI;&QE+"!J;W1K82!E
M:7;D="!T=64@:W5V:6$`16YN=7-T92`H5$%&*0!%;FYU<W1E='1A=F%T('9U
M;W)O:V%U9&5T("A(=6]M86%T:&%N(&5T=.0@96YN=7-T=6MS97-S82!O;B!T
M:65D;W0@<V5KY"!PY&EV:7-TY"!E='3D(/9I<W3D+"!J;W1E;B!S=75R:2!M
MY.1RY"!PY&EV:>0@86EH975T=&%A(&QI:6%N(&QE=F7D;B!O<VEO;BD`56YO
M:&1I=&MO('-A;&%S86YA<VD_`$QO;6%K:V5E=`!-:65T96QA=7-E`$UI971E
M;&%U<V5E;B!T>7EP<&D`36EE=&5L875S965T`$UI971E;&%U<V5E="`R`$9O
M;W)U;6ET`%5U9&5L;&5E;F]H:F%U:W-E=`!P90!+96AY:W-E=`!286YS:V$`
M4F%N<VMA+"!-971R;W!O;&D`5F%P86$`5F%P86$O=F%R871T=2!T:65T;VIA
M`%)A;G-K86X@1W5Y86YA`%)A;G-K86X@4&]L>6YE<VEA`%)A;G-K86X@971E
M;.1I<V5T('1E<G)I=&]R:6]T`'!E<FIA;G1A:0!,Y&AE='3D:N0`4W5U;FYA
M<W1A(`!0:61E;7!I(&MU=F%U<SH`5.1Y<VEK=74`2V]K;R!N:6UI`%1U;&5V
M870`1V%B;VX`1V%L;&5R:6$L(&IO<W1A(&MU=F$@;W1E=&%A;@!'86QL97)I
M83H`1V%M8FEA`%!E;&D`66QE:6YE;@!4964@)7,@87-E='5K<V5T`$=E;F5R
M;VET=2!K;V]D:0!'96]R9VEA`%-A:W-A`$=H86YA`$=I8G)A;'1A<@!%='5N
M:6UI`%EL96ES970@87-E='5K<V5T`$UE;F4`1_9D96P`1V]O9VQE($MA<G1A
M=`!';V]G;&4@:&%K=0!-96YE("5S`$AA<FUA87/D=GD`2W)E:6MK80!+<F5I
M:VMA("A)4T\M.#@U.2TW*0!'<O9N;&%N=&D`1W)E;F%D80!2>6AMY&X@>6QL
MY'!I=&\`4GEH;6EE;B!N:6UE="!E:7;D="!S86$@;VQL82!T>6AJ:>0`1W)O
M=7!?;&1A<#H@16D@=F]I9&$@;&ESY'3D(&OD>71TY&KDY"`E<RX@4&%L=F5L
M:6UE;B!V:7)H96EL;6]I='5S(&]L:3H@`$=R;W5P7VQD87`Z($5I('9O:61A
M('#D:7;D='3DY"!KY'ET=.1JY.0@)7,`1W)O=7!?;&1A<#H@16D@=F]I9&$@
M<.1I=N1T=.3D(&OD>71TY&KDY"`E<P!2>6AMY'0`1W5A9&5L;W5P90!'=6%M
M`$=U871E;6%L80!'=65R;G-E>0!6:65R86EL:6IA;B!O:6ME=61E=`!6:65R
M87-K:7)J80!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,
M07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!R
M:79I;B!V:6EM96ES=.0@<V]L=6$N`$A434Q!<F5A('!E;&MU<FEM86ES97-T
M:2!K:65L=.1Y='EY('!O:7-T86UA<W1A('9I:6UE:7-TY"!S87)A:V5T=&$@
M=&%U;'5K;W-T82X`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET
M>7D@<&]I<W1A;6%S=&$@=FEI;65I<W3D(')I=FGD('1A=6QU:V]S=&$N`$A4
M5%`M875T96YT:6MO:6YT:6$@96D@;/9Y='EN>70N`$AA:71I`$AA<V@M86QG
M;W)I=&UI`%5S=F$`3W1S86ME`$]T<V%K90!(96%R9"!J82!-8T1O;F%L9"!S
M86%R970`5F]I;6%K87,@=6MK;W-M>7)S:WD`2&5P<F5A("A)4T\M.#@U.2TX
M+4DI`$MO<FME=7,`3VAJ90!!<'5A(&5D:71O<FEN(&OD>71T]O9N`$]H:F4`
M4&%L;&]N<'5O;&ES:V\Z`%3D<W/D(&]N('1I961O<W1O;B!A;&MU;W-A.@!0
M:6EL;W1A`%!I:6QO=&$@)7,`2V]R:V5A`$MO7W1I`%!Y:.0@:7-T=6EN("A6
M871I:V%A;FEN(&MA=7!U;FMI=F%L=&EO*0!+;W1I`$MO=&EO<V]I=&4`2V]T
M:6AA:V5M:7-T;P!0=6AE;&EN("AK;W1I*0!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z($5PY&ME;'!O82`E<R!834PM9&%T86$@=FEE
M<W1I<W/D("5S`$AO<F1E+TMO;&%B.B!9:W-I:^3D;B!V:65S=&D@96D@=F%S
M=&%A(&]B:F5K=&EA("5S`$AO<F1E+TMO;&%B.B!9:'3D:^3D;B!O8FIE:W1I
M82`E<R!E:2!L]GET>6YY="!V:65S=&ES=.0@)7,`2&]R9&4O2V]L86(Z(%!O
M:7-T971T:6EN("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F%A=&EO:V]N
M92!V86%T:6D@=&]I;6EA:W-E96X@)V1O;7AM;"<@4$A0+6QA86IE;FYU:W-E
M;@!(;W)D92]+;VQA8CH@16D@=F]I9&$@;'5O9&$@=75T=&$@6$U,+7!U=71A
M(&]B:F5K=&EL;&4@)7,`2&]R9&4O2V]L86(Z($5I('9O:71U('!O:7-T86$@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($5I('9O:61A(&AA:V5A($U)344@
M240ZY"!O<VEO;&QE('1Y>7!P:>0@)7,`2&]R9&4O2V]L86(Z($5I('9O:2!S
M>6MR;VYO:61A("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2!V;VED82!S
M>6YK<F]N;VED82!J86MO:F$Z("5S`$AO<F1E+TMO;&%B.B!4=6YT96UA=&]N
M(&IA:V\@(B5S(@!686%K87-U;W)A('/DY&YT]@!686%K87-U;W)A('3D>71E
M`%9A86MA<W5O<F$Z`%1U;G1I80!-:71E;B!T=6QI="!TY&YN93\@*%)A<&]R
M=&]I(&MI:71O<R$I`$MU:6YK82!P:71KY"!O;B!A:6MA;&]K97)O('#D:7;D
M+2!J82!V:6EK:V]NY&MY;6ES<^0_`$MU:6YK82!M;VYT82!S87)A:V5T=&$@
M:&%L=6%T('EH9&ES=.3D/P!-;VYE;&QE:V\@='5L979A;&QE('#D:7;D;&QE
M(&QU;V1A86X@=F%P86$O=F%R871T=2`M=&EE=&]J83\`2V5N='1I96X@*'-A
M<F%K:V5I9&5N*2!L=6MU;>3D<N0N`$MU:6YK82!M;VYT82!R:79IY"!H86QU
M870@>6AD:7-TY.0_`$MO<W1E=7,`2V]S=&5U<SH@`$AU;6]R:7-T:70`56YK
M87)I`$E-05`M<&]S=&EL86%T:6MO;B!L=6]N=&D@97#D;VYN:7-T=6DZ("5S
M`$E-05`M<&]S=&EL86%T:6MO;B!P;VES=&\@97#D;VYN:7-T=6DZ("5S`$E-
M05`M<&]S=&EL86%T:6MO;B!K:6EN=&GV;B!L=6]N=&D@97#D;VYN:7-T=6DZ
M("5S`$E0+6]S;VET90!)4"UO<V]I=&4@96D@;VQE(&OD>71E='3D=FES<^0N
M`$E0+6]S;VET92!E:2!O;&4@<V%L;&ET=6X@0TE$4BUB;&]K:6X@<VESY&QL
MY`!)4"USY.1N;O9S=/9N(')I:VMO;75S`$Q?86ET82!R:79I(&5N;F5N`$ES
M;&%N=&D`5F%I;B!I:V]N:70`26MO;FET("5S.FQL90!):V]N:70@:F$@=&5K
M<W1I`%!R;V9I:6QI;B!N:6UI.@!*;W,@<VEV=2!E:2!NY'D@:W5N;F]L;&$L
M(&YI:6X@875K86ES92`E<R!E<FEL;&ES97-SY"!I:VMU;F%S<V$N`$IO<R!E
M="!NY&4@:6MO;F5I=&$@:^1Y='3D97-SY'-I($EN=&5R;F5T($5X<&QO<F5R
M('-E;&%I;G1A+"!N:6EN('-I;G5N('!I=.3D(&]T=&%A('!O:7,@<.3D;'3D
M(%!.1R!LY'!I;N1K>79Y>7,@<F%S=&ET=&%M86QL82!TY&WD(&QA871I:VMO
M+@!*;W,@;N1E="!TY&WD;B!V:65S=&EN+"!M=71T82!E="!K=79A82P@;FEI
M;B!T=6]M86%S:2!K=79A82!E:2!V;VD@;N1Y='3DY"!KY'ET=.1MY'-SY'-I
M('-E;&%I;65S<V$N`$IO<R!SY&AK]G!O<W1I;VAJ96QM87-I(&5I('1U92!I
M5&EP('!Y>6YT]FKD+"!N:6EN('9O:2!KY'ET=.3D(&%L;&$@;VQE=FEA(&QI
M;FMK96KD(&]S86QL:7-T=6%K<V5S:2!T86D@:VEE;'3D>71YY"!O<V%L;&ES
M='5M87-T82!T87!A:'1U;6%A;BX*"DAY=N1K<WGD('1A<&%H='5M86XZ"B5S
M"@I!;'5S=&%V87-T:2!H>7;D:W-YY"!T87!A:'1U;6%N.@HE<PH*2VEE;'3D
M>71YY&MS97-I('1A<&%H='5M87-T83H*)7,`2W5V:65N(&5S:6MA='-E;'4`
M2W5V82!54DP`2W5V82!54DPZ`$MU=F$@9V%L;&5R:6%S=&$`2W5V82!G86QL
M97)I87-T83H`2W5V86X@=FEE;G1I`$MU=F%T`$MA;&5N=&5R:6X@='5O;G1I
M+"!A<VME;"`E9`!4=6]N=&DL(&%S:V5L("5D`%1U;R]6:64@:V%L96YT97)I
M`%1U;W1U(&ME;G1TY#H@)7,`5'5O9'5T(&ME;G3D=#H`3&%?:71A(')I=FD@
M:N1L:V5E;@!6Y.1RY"!T;VEM:6YT;VMO;V1I(&%N;F5T='4N`$OD>71TY&KD
M='5N;G5S('1A:2!S86QA<V%N82!O;B!VY.1R:6XN`%;DY'+D(&OD>71TY&KD
M='5N;G5S('1A:2!V86EH=&]E:'1O:6YE;B!O<V]I=&4N(%ER:73D('5U9&5S
M=&%A;B!J82!O=&$@>6AT97ET=.0@>6QLY'!I=&]O;B!J;W,@=&%R=FET<V5T
M(&QI<^3D(&%P=6$N`$QI<^3D('-I<V5N;GES=.0`26YT:6$`66MS:71TY&ES
M970@:^1Y='3D:N1T`$EN9&]N97-I80!);F9O`$EN9F]R;6%A=&EO`%1I971O
M82!E:2!O;&4@96[DY"!S86%T879I;&QA+@!,86ET82!S7V%R86ME(&KD;&ME
M96X`3&%I=&$@:W5V80!,86ET82!T875L=6MK;P!,86ET82!W=W<M;&EN:VMI
M`$QA:71A(%]S87)A:V4@96YN96X`3&%I=&$@=75S:2!S87)A:V4@;GEK>6ES
M96X@:N1L:V5E;@!,86ET82!U=7-I('-A<F%K92!E;FYE;B!N>6MY:7-TY`!,
M86ET82!U=7-I(')I=FD@;GEK>6ES96X@:N1L:V5E;@!,86ET82!U=7-I(')I
M=FD@96YN96X@;GEK>6ES=.0`3&%I=&$@:V%P<&%L92!N>6MY:7-E;B!N;V1E
M;B!JY&QK965N`$QA:71A(&MA<'!A;&4@96YN96X@;GEK>6ES=.0@;F]D96$`
M3&%I=&$@=F%I:'1O96AT;VEN96X@;6%L;&D`06YN82!SY&AK]G!O<W1I;W-O
M:71E(&IO:&]N('5U<VD@<V%L87-A;F$@;.1H971E=.3D;CH`3&%I=&$@<V]L
M=2!JY&QK965N`$QA:71A('-O;'4@96YN96X`3&%I=&$@<V]L=2!JY&QK965N
M`$QA:71A('-A<F%K92!E;FYE;@!6;VD@;&%I='1A82!V:65S=&5JY`!,86ET
M82!K87!P86QE(&KD;&ME96X`3&%I=&$@:V%P<&%L92!E;FYE;@!,86ET82!R
M:79I(&5N;F5N`$QA:71A(')I=FD@:N1L:V5E;@!!;FYA('9A861I='1A=F$@
M=F%S=&%U<R!T=7)V86MY<WEM>6MS965N.@!,:6ETY"]-=6]K:V%A(&MU=FEA
M`$QI:73D+TUU;VMK86$@;&EN:VMIY`!3:6YU;&QA(&5I(&]L92!T87)P965K
M<VD@:W)E9&EI='1E:N0@;.1H971TY.1K<V5S:2!V:65S=&EN(&IA:V5L=6QI
M<W1A;&QE+@!2:6ET=.1MY'1T]FWD<W1I(&MR961I:71T96KD`$MO:V]N86ES
M;'5K=0!+;VMO;F%I<VQU:W5L:7-T80!%<.1K96QP;R`@541(("A5<V5R($1A
M=&$@2&5A9&5R*2X`17#D:V5L<&]A(%I)4"UT:65T;V$N`$5PY&ME;'!O(&]H
M:F5L;6$N`$5PY&ME;'!O(&)A=&-H($E$+@!,Y&AE=&5T=&EI;B!E<.1K96QP
M;V$@=&EE=&]A+@!%<.1K96QP;R!V87-T86%N;W1T86IA;B!O<V]I=&4N`$5P
MY&ME;'!O('1I961O<W1O;75O=&\`17#D:V5L<&\@;&ES96YS<VEA=F%I;BX`
M17#D:V5L<&\@<&%I:VMA=&EE=&\N`$5PY&ME;'!O(&US9U]T>7!E("X`17#D
M:V5L<&\@=&%I('!U=71T=79A(&%P:5]I9"X`17#D:V5L<&\@=&%I('!U=71T
M=79A('!A<F%M971R:2X`17#D:V5L=F]T(&]I:V5U9&5T('EL96UMY&QLY"!T
M87-O;&QA+@!%<.1K96QP;R!P87)N97(@:60N`$5PY&ME;'!O('1U;W1E:V]O
M9&DN`$5PY&ME;'!O('!R;W1O:V]L;&$N`$5PY&ME;'!O('9A<W1A86YO='1A
M:F$Z("(E<R(`17#D:V5L<&\@:F%K;RUO8FIE:W1I`$5PY&ME;'!O(&SD:&1E
M;W-O:71E+@!%<.1K96QP;V$@=6YI8V]D92UT:65T;V$N`$EN=F5N=&%A<FEO
M`$ODY&YNY"!V86QI;G1A(&ODY&YT96ES96MS:0!)<F%N+"!)<VQA;6EL86EN
M96X@=&%S879A;'1A`$ER86L`27)L86YT:0!-86XM<V%A<FD`17)I;&QI<VGD
M(%5K:V]S;7ER<VMY:N0`27-R865L`$QI:6MK965L;&5L87-K:6IA`$MU<G-I
M=F]I='4`271A;&EA`$IA;6%I:V$`=&%M;6EK=74`2F%P86YI`$IA<&%N:2`H
M25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YI80!H96ENY&MU=0!K97/D:W5U
M`$ME<VMI=.0`2V5S:VETY"!K97-K96QL90!+97-K:73D('3D>7-I;@!+97-K
M:73D('9A<V5M;6%L;&4`2V5S:VETY"!O:6ME86QL90!+87IA:W-T86X`4^1I
M;'ETY"!A;&MU<&5RY&EN96X_`$ME;FEA`$%U=&5N=&EK;VEN=&D@97#D;VYN
M:7-T=6D@2V5R8F5R;W,M<&%L=F5L:6UE;&QE+@!+97)N96P@86QO:71T96QI
M:F%T`$%V86EM96X@;'5O;G1I`$%V86EM96X@='5N;FES=&4`079A:6UE;B!P
M:71U=7,`079A:6UE;B!T>7EP<&D`079A:6UE;B!KY'ET=/8`079A:6X@;VX@
M:F\@:G5L:VES=&5N(&%V86EN=&5N('!A;'9E;&EM96QL80!!=F%I;G-A;F%T
M`$QA<'-E=`!+:7)I8F%T:0!+;W)E82P@9&5M;VMR86%T=&EN96X@:V%N<V%N
M=&%S879A;'1A("A0;VAJ;VES+4MO<F5A*0!+;W)E82P@=&%S879A;'1A("A%
M=&5LY"U+;W)E82D`2V]R96$@*$550RU+4BD`2W5W86ET`$MI<F=I<W1A;@!!
M<U]E='1E;'4`2VEE;&D`3&%O<RP@9&5M;VMR86%T=&EN96X@:V%N<V%N=&%S
M879A;'1A`$5D96QL:7-E="`R-"!T=6YT:6$`2N1L:VEM;>1I;F5N('!U;VQI
M<VMO`$UU;VMA='1U('9I:6UE:W-I`$5D96QL:6YE;B!K=75K875S:0!%9&5L
M;&EN96X@<V%L87-A;F%N=F%I:'1O`$KD;&MI;6WD:6YE;B!N96QJY&YN97,`
M4.1I=FET971T>2!V:6EM96MS:3H`161E;&QI;F5N('9U;W-I`$5D96QL:6YE
M;B!S:7/DY&YK:7)J875T=6UI;F5N.B`E<P!%9&5L;&EN96X@<VESY.1N:VER
M:F%U='5M:6YE;CH@)7,L("5S`$5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI
M;F5N.B!%:2!M:6QL;VEN:V%A;@!%9&5L;&EN96X@=FEI:VMO`$QA='9I80!,
M86MI`$%S971T96QU`$KD=.0@='EH:N1K<VD@:F]S(&5I(')E=6YO:F$`3&EB
M86YO;@!687-E;@!687-E;B!O='-A:V4`5F%S96X@87)V;W0`3&5S;W1O`%1A
M<V\`3&EB97)I80!,:6)Y82!!<F%B($IA;6%H:7)I>6$`3&EC:'1E;G-T86EN
M`$ME=GET=.0@<N1N=.3D`$MI<FIA=61U('-I<^3D;@!+979Y='3D('-A9&5T
M=&$@86EK86ES:6X`2V5V>71TY"!S861E='1A(&UY]FAE;6UI;@!+979Y:73D
M('-A9&5K=75R;VIA`$ME=GET=.0@<V%D971T82!J82!M>7)S:WEI<W3D`$ME
M=GET=.0@;'5M:7-A9&5T=&$`2V5V>6ETY"!L=6UI:W5U<F]J80!,:6UE<FEK
M:70`4F%J;VET82!V:65N;FEN(&%I:V%I:VMU;F%A.@!,:6YK:VD`3&EN:VMI
M(&]S;VET=&%A.@!,:6YK:73D('/D:&OV<&]S=&EO<V]I=&4@:VER:F]I=&$@
M=75S:2!V:65S=&D@<VEV=6QL92!NY&MY;>1S<^0`3&EN:VET`$QI;G5X('!I
M<&%R96ET80!6;VD@;&ES=&%U:W-E<W-A(&[D:&3D(&MA;G-I;VX`3N1Y=.0@
M=&EE=&]K86YN870`3N1Y=.0@;VAJ96ED96X@86EH965T`$[D>73D('1A=6QU
M=`!,:7-T86XM07)K:7-T;P!,:7-T86XM3VAJ90!,:7-T86XM260`3&ES=&%N
M+4]M:7-T86IA`$QI<W1A+79I97-T:0!,:7-T86XM5&EL875S`$QI<W1A;BU4
M:6QA=6MS96XM;&]P971T86UI;F5N`$ES='5N=&]J96X@;&ES=&%U<R!E<.1O
M;FYI<W1U:3H@)7,`2^1Y='3D:FEE;B!L:7-T875S(&5PY&]N;FES='5I.B`E
M<P!+Y'ET=.1JY'1I971O:F5N(&[D>71TY&UI;F5N(&]N(&5S=&5T='DN`$MI
M<FIA;&QI<W5U<P!,:65T='5A`%!A:5]K:V$`3&%D871A86XN+BX`4&%I:V%L
M;&ES=&$@86EK86$Z(`!,;VMA;&ES86%T:6\@:F$@86EK80!086EK:V$`2VER
M:F%U9'4@<VESY.1N`$5D96QL:7-E;B!S>6YK<F]N;VEN=&ES97-S:6]N(&QO
M:VD`2VER:F%U9'4@=6QO<P!+:7)J875D=2!S:7/DY&X`5&5H=.1VY'0@<VES
MY.1N:VER:F%U='5M:7-E<W-A`%-I<^3D;FMI<FIA=71U;6ES97-I(&5PY&]N
M;FES='5I+B!4;V1E;F[D:_9I<V5S=&D@:VER:F]I=&ET(';DY')I;B!KY'ET
M=.1JY'1U;FYU:W-E<VD@=&%I('-A;&%S86YA<VDN`%-I<^3D;FMI<FIA=71U
M;6EN96X@97#D;VYN:7-T=6DN`%!I=&OD('1E:W-T:0!286MK875S`$UA=&%L
M80!0:65N970@:W)E:6MK86QA:7-E="!K:7)J86EM970`4&EE;F5T(&QA=&EN
M86QA:7-E="!K:7)J86EM970`4&EE;F5T(')O;VUA;&%I<V5T(&YU;65R;W0`
M3'5X96UB=7)G`$M+`$U/5$0`35,M5$Y%1B!L:6ET971I961O<W1O(&]L:2!T
M>6AJY"X`5DE%4U1)`$UA8V%O`$UA:V5D;VYI82P@16YT:6YE;B!*=6=O<VQA
M=FEA;B!T87-A=F%L;&%N+@!-861A9V%S:V%R`%1A:6MU=7,`4^1H:_9P;W-T
M:0!0;W-T:6X@>6QLY'!I=&\`5&5E(&QI;FM?:VDN+BX`36%L87=I`$UA;&5S
M:6$`36%L961I:79I=`!0;W-T:0!-86QT80!6;VET(&AA;&QI=&$@973D:V%L
M96YT97)E:F$N`%9O:70@:&%L;&EN;F]I9&$@;&ES=&%A(&MA=&5G;W)I;VES
M=&$L(&IO:61E;B!A=G5L;&$@=F]I="!L:6ET=.3D(&%S:6]I=&$@>6AT965N
M('-A;6]J96X@;W1S86MK96ED96X@86QL92!J82!L:6ET=.3D(&YI:6AI;B!V
MY')E:N0N`$UA<#(T(&MA<G1T80!-87!1=65S="!K87)T=&$`5F%S=&%A=G5U
M9&5T('1A;&QE=&5T='4N`&UA86QI<VMU=0!-87)G:6YA86QI`%9O:2!M97)K
M:73D(%9A;FAA+U5U<VD@=&EE=&]J80!6;VD@;65R:VETY"!V:65S=&5JY"`H
M97-I;2X@5.1R:V7D+U9A<W1A='1U*0!-87)S:&%L;"!S86%R970`36%R=&EN
M:7%U90!4Y'-MY.1VY'0@:V5N=.1T`$UA=7)I=&%N:6$`36%U<FET:75S`%-U
M=7)I;B!S86QL:71T>2!K<F5D:6ET=&DN`%-U=7)I;B!S86QL:71T=2!V:65S
M=&EO<VEO;>3D<N0@>6QI=&5T='DN`$5D96QL:7-E;B`R-"!T=6YN:6X@:V]R
M:V5I;B!LY&UP]G1I;&$Z(`!%9&5L;&ES96X@-B!T=6YN:6X@:V]R:V5I;B!L
MY&UP]G1I;&$Z(`!487!A:'1U;6EE;B!M86MS:6UI;>3D<N0`4&]R=&%A;&EO
M<VEO:61E;B!E;FEM;>1I<VWDY'+D`%-U=7)I;B!S86QL:71T=2!P:71U=7,`
M=&]U:V]K=74`36%Y;VYE='1E`%1A`$SDY&ME=&EE9&4`5&%P86%M:6YE;@!*
MY'-E;F5T`%9A;&EK:V\@:.1L>71Y:W-E=`!686QI:VMO(&QI<W1A`$UE;G5N
M(&UU;W1O.@!9:&1I<W3D('-O;'5T`%9I97-T:0!6:65S=&EN('1A<FMI<W1U
M<R!O;FYI<W1U:2P@;75T=&$@86QL96MI<FIO:71T86IA;B!V87)M96YN971T
M82!E:2!V;VET=2!T87)K:7-T86$N`%9I97-T:2!V86YH96YI+@!6:65S=&EN
M('1Y>7!P:0!-971A<B!SY.0`365T87(M;W-I;R!E:2!O;&4@:^1Y=&5T=.1V
M:7-SY"X`365T87(M;W-I;R!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X@5&%R:V5M
M;6%T('1I961O="!O;B!T86QL971E='1U('EL;.1P:61O;B!KY'-I=&5L=.1V
MY&MS:2X`365T87)$0B!E:2!O;&4@>6AD:7-T971T>2X`365T;V1I`$UE=&]D
M:6$@(B5S(B!E:2!O;&4@;>3D<FET96QT>0!-971O9&EA(&5I(&]L92!MY.1R
M:71E;'1Y+B!+=71S=79A(&UE=&]D:3H@)7,`365T<FEN96X`365K<VEK;P!-
M:6MR;VYE<VEA+"!9:&1I<W1Y;F5E="!V86QT:6]T`$ME<VME;&SD`$UI;64M
M='EY<'!I`$5D96QL:7-E;B`R-"!T=6YN:6X@;6%T86QI;B!LY&UP]G1I;&$Z
M(`!%9&5L;&ES96X@-B!T=6YN:6X@;6%T86QI;B!LY&UP]G1I;&$Z(`!386QA
M<V%N82!E:2!O;&4@=FEE;.0@=&%R<&5E:W-I('9A;FAA`$UI;G5U='1I80!0
M96EL:6MU=F$`4V5K86QA:7-E=`!014%2+7!A:V5T=&D@2%144%]297%U97-T
M('!U=71T=74N`%!U=71T=79A="!A<V5T=7-T:65D;W-T;RX@4VEN=6X@<&ET
MY.0@=&5H9.0@87-E='5S=&EE9&]S=&\@:F]S(&AA;'5A="!KY'ET=.3D('3D
M=.0@;VAJ96QM86$N`%!U=71T=79A(&UE<W-A9V4@240N`%;D;'1TY&WD=/9N
M(%!%05(M<&%K971T:2!-86EL('!U=71T=74N`%!U=71T=79A('-E<W-I;VX@
M240N`&UA`$UO8FEI;&ESY&AK]G!O<W1I`$MO:'1A;&%I;F5N`$UU;VMK875K
M<V5N('#D:7;D;>3D<N0`375O:VMA82!54DPZ:6$`2V5R<F]I;@!-;VQD;W9A
M+"!T87-A=F%L=&$`36]N86-O`&UA86YA;G1A:0!-;VYG;VQI80!+=75K875S
M:0!+=75K875S:6[D:WEMY`!K=75K875S:2!J82!V=6]S:0!+=75K875S:71T
M86EN`$MU=6MA=7-I='1A:6YE;B!T87!A:'1U;6%L:7-T80!+=75K875S:71T
M86EN.B!4;VES='5V=75D96X@=N1L:0!4=6QE=F%A(&MU=6MA=71T80!-96YN
M>71TY"!K=75K875T=&$`36]N='-E<G)A=`!+=75N('9A:6AE970`4FEV:6QT
MY"`E9"!L]GET>6D@96YE;6WD;B!K96YT=&GD(&MU:6X@;V1O=&5T='4@)60N
M`$UA<F]K:V\`16YI;6WD:W-I('-E;&MEY.0`16YI;6WD:W-I('!I;'9I<W3D
M`$5N:6UMY&MS965N('!I;'9I<W3D(&IA('1U=6QI<W1A`$5N:6UMY&MS965N
M(&%U<FEN:V]I<W1A`%-I:7)RY"!A;&%S<.1I;@!3:6ER<N0@=F%S96UM86QL
M90!3:6ER<N0@;VEK96%L;&4`4VEI<G+D('EL]G-PY&EN`%-I:7)RY"!A;&%S
M<.1I;@!3:6ER<N0@>6SV<W#D:6X`36]S86UB:6L`36]N:71A<V]I;F5N(&%L
M87-V971O=F%L:6MK;P!-=6QT:6UA<"!)<V\M0G)I=&%N;FEA;B!K87)T=&$`
M3/9Y='EI('5S96ET82!I0V%L96YD87(@:V]M<&]N96YT=&5J83L@5F%I;B!Y
M:W-I('9%=F5N="!O;B!T=65T='4N`$UO;FEV86QI;G1A`$OD>71TY&KD='5N
M;G5K<V5N:0!/;6%N(&OD>71TY&KD='5N;G5K<V5N('1I961O=`!+86QE;G1E
M<FEN:0!+86QE;G1E<FEN:3H`5F%P86$O=F%R871T=2!54DPZ:6YI`$]M82!P
M;W)T86%L:0!/;6%N('!O<G1A86QI;B!A<V5T=&5L=0!->6%N;6%R("A"=7)M
M82D`14DL($5.('-U;W-T=0!.:6UI`$YA;6EB:6$`3F%U<G4`3F5P86P`06QA
M;FMO;6%A=`!!;&%N:V]M86ED96X@06YT:6QL:70`3F5T<V-A<&4@0F%S92!5
M4DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L
M:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T
M:6]N(%523`!.971S8V%P92!34TPM<&%L=F5L:6UE;B!O<V]I=&4`3F5T<V-A
M<&4@=F%R;65N=&5E;B!K;VUM96YT=&D`3F5T<V-A<&4@=F%R;65N=&5E;B!T
M>7EP<&D`5F5R:VMO`$5I(&MO<VMA86X`575S:2U+86QE9&]N:6$`575S:2!L
M=6]K:71U<P!5=7-I('1A<&%H='5M80!5=7-I:W5U`%5U<VD@:^1Y='3D:N1T
M=6YN=7,@*'9A<&%A96AT;VEN96XI`%5U<VDM4V5E;&%N=&D`575S:2!K86QE
M;G1E<FD@;VX@;'5O='4@:F$@875T;VUA871T:7-E<W1I(&IA971T=2!S975R
M86%V:65N(')Y:&UI96X@:V%N<W-A.B`E<RX`575S:2!S86QA<V%N80!5=7-I
M('-A;&%S86YA('9A;FAE;F5E("5X+@!!;G1A;6%S:2!U=61E="!S86QA<V%N
M870@96EVY'0@=.1S;>3D+@!5=7-I(&EK:W5N82`H7V)L86YK*0!5=71I<V5T
M`$ME<VMU<W1E;'5R>6AMY'0`4V5U<F%A=F$`4V5U<F%A=F%T(#(T('1U;G1I
M80!3975R86%V870@-"!V86EH971T80!3975R86%V82!PY&EVY`!3975R86%V
M82!K=75K875S:0!3975R86%V82!V:6EK:V\`4V5U<F%A=F$@=G5O<VD`4V5U
M<F%A=F$@<.1I=N0`4V5U<F%A=F%T(&%S971U:W-E=`!3975R86%V82!V:6EK
M:V\`4V5U<F%A=F$^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`%GV`$YI=64`
M16D`16D@:.1L>71Y<P!%:2!O<V%L;&ES='5J870`07-E='5S=&EE=&]J82!E
M:2!O;&4@<V%A=&%V:6QL82P@:F]S=&$@=F]I<VD@;N1Y='3DY"!E<F]A=F%I
M<W5U:W-I82X`16D@;VQE('-A871A=FEL;&$@<W5U;FYI=&5L;6%A($E33R!L
M979Y:W5V871I961O<W1O:F5N('1E:V5M:7-E:W-I+@!%:2!E<N1M86QL:6$N
M`$]S:6]T82!E:2!O;&4@<'EY9&5T>7-SY"!P86EK87-S82X`2V%L96YT97)I
M;B!N:6UEY"!E:2!O;&4@86YN971T=2!-0T%,+6%U=&5N=&EK;VEN;FEL;&4N
M`%9I97)A:6QI:F]I;&QE(&5I(&]L92!T87)J;VQL82!Y:'3DY&X@:V%L96YT
M97)I82X`16D@;75U=&]S=&$N`$%L:71A<V]J82!E:2!V;VD@;&ESY'3D('3D
M;&QE(&]I:V5U9&5L;&4N`$%S971U:W-I82!E:2!L]GET>6YY="`E<SIL;&4N
M`$%S971U:W-I82!E:2!L]GET>6YY="!&5%`@5D93.FQL92X`07-E='5K<VEA
M(&5I(&SV>71Y;GET(%-13"!61E,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN
M>70@4U%,+49I;&4@5D93.FQL92X`2W)E9&EI=&ET(&QO<'!U+@!+;VAD971T
M82!E:2!A;FYE='1U+@!%:2!PY.1T='EM:7-PY&EVY.0`16D@=&%P86AT=6UI
M82!NY'ET971TY';D:W-I`$5I('1U;W1U(&%I;G5T=&%K86%N('1I961O<W1O
M80!687!A82]V87)A='1U('1I971O:F$@)7,Z;&QE(&5I(&]L92!O;&5M87-S
M80!%:2!L]GET>6YY="!I0V%L96YD87(@=&EE=&]J82X`26MO;F5I=&$@96D@
M;/9Y='EN>70N`%!A:6MK86$@96D@;VQE(&%S971E='1U+@!086EK:V%A(&5I
M(&]L92!A;FYE='1U+@!%:2!A;FYE='1U('9I97-T:>0N`$YI;67D(&5I(&]L
M;'5T(&%N;F5T='4N`$QU:W5MY.1RY.0@96D@;VQL=70@86YN971T=2X`16D@
M;&]U:VMA879A="!M:65T96QA=7-E970`4V%L87-A;F%A(&5I(&]L92!A;FYE
M='1U($A45%`M875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L92!A
M;FYE='1U($E-05`M875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L
M92!A;FYE='1U($ME<F)E<F]S+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA
M82!E:2!O;&4@86YN971T=2!,;V=I;B!A=71E;G1I:V]I;FYI<W-A+@!386QA
M<V%N86$@96D@;VQE(&%N;F5T='4@4$%34U=$+6%U=&5N=&EK;VEN;FES<V$N
M`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!334(M875T96YT:6MO:6YN:7-S
M82X`4&]L:W5A($]P96Y34TP@:V]M96YT;V]N(&5I(&]L92!MY.1R:71E;'1Y
M+B!/<&5N4U-,('!I=.3D(&]L;&$@:^1Y=&5T=.1V:7-SY"!J;W,@:^1S:71E
M;&SDY&X@4$M#4R`Q,B!D871A82X`16D@<VESY.1N:VER:F%U='5M:7-P>7EN
M=/9JY"!J;VYO<W-A+@!+:6EN=&GV=.0@96D@;VQE(&%S971E='1U`$5I('1O
M:7-T=79U=7,`16D@<^3D;G3V:N0`17)O=&EN=&$@96D@;VQE(&WDY')I=&5L
M='DN`$5I(')E=6YO:F$`16D@;/9Y='EN>70@=&EE9&]S=&]A`%;D;&EM=6ES
M=&EL;&4@96D@;VQE(';D;&EA:6MA:7-H86ME;6ES=&]A+@!+Y'ET=.1JY'1U
M;FYU<W1A('1A:2!S86QA<V%N86$@96D@;.1H971E='1Y+@!+86EK:VD@<&%L
M875T=6YU="!834PM9&%T82!O;&D@97#D:V5L<&]A`$5I(&SV>71Y;GET('1O
M:6UI=F%A('/D:&OV<&]S=&EO<V]I=&5T=&$N`$5I(&%R=F]J80!697)S:6]T
M:65T;VIA(&5I(&SV>71Y;GET(&%L:W5P97+D:7-I=.0@87-E='5K<VES=&$N
M(%-I;G5N('!I=.3D('1E:&3D(&%S971U:W-E="!U=61E<W1A86XN`%9E<G-I
M;W1I971O:F$@96D@;/9Y='EN>70@87-E='5K<VES=&$N(%-I;G5N('!I=.3D
M('1E:&3D(&%S971U:W-E="!U=61E<W1A86XN`$5I(&UI=.3D;@!%:2!M:73D
MY&X@*$OD>73D(&EM<&QI<VEI='1I<W3D*0!,87!P:2]0;VAJ;VES;6%A="]%
M<VMI;6\@*$E33RTX.#4Y+3$P*0!.;W)F;VQK('-A87)E=`!0;VAJ;VEN96X@
M<&%L;&]N<'5O;&ES:V\`4&]H:F]I<V5T($UA<FEA86YI96X@<V%A<F5T`$YO
M<FIA`$5I(&KD;&ME96X`16D@96YN96X`16D@;VQE(&AA:V5M:7-T;P!%:2!L
M]GET>6YY=`!%:2!O;&4@=&]T975T971T=2X`16D@87-E=&5T='4`16D@='5E
M='1U+@!-=6ES=&EI;G!A;F]T`$5I(&UI=.3D;B!S96QA='1A=F%A+"!P86QA
M82!T86MA:7-I;BX`26QM;VET=6MS970`;6%R<F%S:W5U`$YY=`!,=6MU;>3D
M<N0`365R:VMI96X@;'5K=6WDY'+D`%-A<F%K:V5I9&5N(&QU:W5MY.1RY`!2
M:79I96X@;'5K=6WDY'+D`$IA:V5L=6QI<W1A;B!N=6UE<F]I=&$@96D@;VQE
M(&WDY')I=&5L='D@<.1I=FET971TY';D:W-I+@!/2P!/8FIE:W1I`$]B:F5K
M=&EN(&QU;VIA`$]K=&%A;&D`;&]K86MU=0!,;W5K:V%A=G5U<W-U;V1A=&EN
M`%1O:6UI<W1O`%5U<VD@<V%L87-A;F$@96D@<V%A(&]L;&$@<V%M82!K=6EN
M(&YY:WEI;F5N('-A;&%S86YA<VDN`%9A;FAA('-A;&%S86YA`%9A;FAA('-A
M;&%S86YA(&]N(';DY')I;BX`3VUA;@`@+2``2V%I:VMI:6X@:V%L96YT97)E
M:6AI;BP@:F]I:&EN(&UI;G5L;&$@;VX@;'5K=6]I:V5U<P!+86EK:6QL82!N
MY&MY=FEL;.0@;VQE=FEI;B!K86QE;G1E<F5I:&EN`%9A:6X@;VUA;&QA(&MA
M;&5N=&5R:6QL86YI`%9A:6X@24U!4"UP86QV96QI;65T('1U:V5V870@:F%E
M='1U:F$@:V%N<VEO:71A+@!686EN(&QO=6MK86%V870@;6EE=&5L875S965T
M`%9O:70@;&%I='1A82!V86EN('EH9&5N('/D:&OV<&]S=&EO<V]I='1E96XN
M`%9A:6X@;VUI<W1A:F$@=&%I(&KD<FIE<W1E;&WD;B!Y;&SD<&ETY&KD('9O
M:2!M=75T=&%A(&IA:V]J96X@;VUI<W1A:FEA('1A:2!O:6ME=6MS:6$`079A
M82!U=61E<W-A(&EK:W5N87-S80!/<&5N4U-,('9I<FAE.B!4:65T;VIA(&5I
M('-A871U(&5S:6QL92!A;&QE:VER:F]I=&5T=7-T82!3+TU)344M;W-A<W1A
M+@!!=F%A('3D;>1N(&QI;FMI;B!U=61E<W-A(&EK:W5N87-S80!+Y'ET=/9J
MY')J97-T96QMY`!687!A865H=&]I;F5N`$UA:&1O;&QI;F5N(&]S86QL:7-T
M=6IA`$%S971U:W-E=`!!<V5T=6MS970@)7,Z;&QE`$KD<FIE<W1E='1Y(&QI
M<W1A`$]R9V%N:7-A871I;P!/<F=A;FES86%T:6]Y:W-I:VOV`$]R9V%N:7-O
M:6YT:0!!;&MU<&5RY&EN96X@;VAJ96QM86X@;6%L;&D`06QK=7!E<N1I<V5T
M(&UA;&QI="`E<SIS<^0Z`$UU=0!-=75T('1I961O=`!9;&5I<VMU=F$`3VUI
M<W1A:F$`3VUI<W1A:F%N(&]I:V5U9&5T`$]M:7-T86IA.B`E<P!004TM875T
M96YT:6MO:6YT:6$@96D@;VQE(&OD>71E='3D=FES<^0N`%!%05(Z.DUA:6P@
M=&%U<W1A:N1R:F5S=&5L;>0`1&EG:71A86QI;F5N(%!'4"UA;&QE:VER:F]I
M='5S`%!'4"US86QA='1U82!T:65T;V$`2G5L:VEN96X@4$=0+6%V86EN`%!'
M4"UA;&QE:VER:F]I=&5T='5A(&IA('-A;&%T='5A('1I971O80!02%`M:V]O
M9&D`4$A0+6MO;65N=&]T=6QK:VD`4$T`4$T@:V5V>71TY"!S861E='1A`%!-
M('-A9&4`4$T@:W5U<F]J80!032!L=6UI`%!-(&QU;6ES871E:71A`%!-(&QU
M;6D`4$T@=6MK;W-M>7)S:WEJY`!03U-)6"UL86%J96YN=6MS970@<'5U='1U
M=F%T`%!?2%`M:V]M96YT;W1U;&MK:0!4Y'ET90!086MI<W1A;@!086QA=0!0
M86QE<W1I:6YA("AM:65H:71E='1Y(&%L=64I`%!A;F%M80!087!U82!5=7-I
M+4=U:6YE80!087)A9W5A>0!/<VET=&%I;B!P:6QV:7-TY`!386QA<V%N80!3
M86QA<V%N86X@=F%I:'1O(&]N;FES='5I+@!6Y.1RY"!S86QA<V%N80!386QA
M<V%N86$@=&%R=FET86%N(%)!1$E54RUA=71E;G1I:V]I;G1I:6XN`%-A;&%S
M86YA('9A<FUI<W1U:W-E;&QA`%-A;&%S86YA.@!386QA<V%N83H@`%-A;&%S
M86YO:F5N('!I=.3D(&]L;&$@<V%M870N`$UE;FYE:61E;B!T87!A:'1U;6EE
M;B!L:7-T80!,:6ETY`!,:6ETY"!L96EK97#V>63D;'3D`%!O;&MU`%1O:7-T
M=79U=7,`2F]N;W-S82!O;&5V870@<VESY.1N:VER:F%U='5M:7-P>7EN;O9T
M.@!):&UI<V5T`%!R;W-E;G1T:0!3=6]R:71A('EL;.1P:71O=&]I;65N<&ET
M965T`%-U;W)I=&$@>6QLY'!I=&]T;VEM96YP:71E970@<VESY.1N:VER:F%U
M='5M:7-E;B!Y:'1E>61E<W/D+@!0;VES=&5T86%N:V\@=.1MY"!T87!A:'1U
M;6$@<'ES>7;D<W1I/P!/:6ME=7,`3VEK975T=&$@(B5S(B!E:2!P;VES=&5T
M='4N`$OD>71T]B!K:65L;&5T='D`3VEK975D970`3VEK975K<VEE;B!Y;&SD
M<&ET;P!/;6%T('1I961O=`!097)U`$QE;6UI:VET`$9I;&EP<&EI;FET`%!U
M:&5L:6X`5F%L;VMU=F%T`%!I=&-A:7)N`%!I:W-E;&D`2VQI<V5E=`!.87!S
M875T82!J;W1A:6X@<V]L=6$`5F%R;6ES=&$@971TY"!H86QU870@<&]I<W1A
M82!TY&WD;B!E;&5M96YT:6XZ`%9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T
M86$@;&EN:VET>6MS96X@=.1HY&X@96QE;65N='1I:6XN`$%N;F$@:W5U:V%U
M<VD@:F$@=G5O<VDN`$%N;F$@;FEM:2!U=61E;&QE(&QU;VMI='5K<V5L;&4Z
M`$%N;F$@;VEK96$@25`M;W-O:71E+@!!;FYA(&]I:V5A('#D:7;D;>3D<N0[
M(%1A<FMI<W1A('#D:79I96X@;'5K=6WDY'+D(&MU=6MA=61E<W-A+@!!;FYA
M(&%I:V$@;VEK96%S<V$@;75O9&]S<V$N`$%N;F$@;'EH>70@:W5V875S(&]N
M9V5L;6%S=&$N`$%N;F$@:^1Y='3D:N1T=6YN=6MS97-I(&IA('-A;&%S86YA
M<VD`3'5E('-E=7)A879A('1E:W-T:2X@4VEN=6X@4$E4Q,0@<W5O<W1U82!K
MY'ET=/9E:'1O:6AI;B!V;VED86MS97-I(&OD>71TY.0@:N1R:F5S=&5L;>3D
M+@!!;FYA(&YI;6D@=75D96QL92!L=6]K:71U:W-E;&QE.@!0=6]L80!0;VQI
M=&EI:VMA`$MY<V5L>70`4&]R=&%A;&EN(&%S971U:W-E=`!0;W)T=6=A;&D`
M5.1MY&X@:W5V86X@<&%I:VMA`%3D;>1N('1A=6QU:V]N('!A:6MK80!6;VD@
M;.1H971TY.0@=FEE<W1E:N0@:V%N<VEO;VX@*&5I(&MO<VME($E-05`@>6AT
M97EK<VGD*0!3861E;>3D<N0@961E;&QI<VEL;&4@)7,@='5N;FEL;&4Z(`!(
M86EH='5V=75S(#QB<B`O/G1O9&5N;N1K]FES>7ES`%!R969S7VQD87`Z(%1A
M<G9I='1A=F%A($Q$05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`%!R969S
M7W-E<W-I;VXZ(%1A<G9I='1A=F%A('-E<W-I;VXM;&%A:F5N;G5S=&$@96D@
M;/9Y='EN>70`26QM86YP86EN90!);&UA;G!A:6YE(&UE<F5N<&EN;F%S<V$Z
M(`!);&UA;G!A:6YE.B``17-I:V%T<V5L=0!%<VEK871S96QE(&MU=F$@=75D
M97-S82!I:VMU;F%S<V$`161E;&QI;F5N('#D:7;D`$5D96QL:6YE;B!V:6EK
M:V\`161E;&QI;F5N('#D:7;D`$5D96QL:7-E="!A<V5T=6MS970`5'5L;W-T
M82!D;VMU;65N='1I`%-A;&%I;F5N(&%V86EN`$]N9V5L;6$`3VYG96QM86X@
M:W5V875S`%!R;VIE:W1I=`!+96AO='1E96X@=&5K<W1I`$IU;&MI;F5N(&%V
M86EN`$IU;&MI<V5N(&%V86EM96X@86QG;W)I=&UI`$IU;&MI<V5N(&%V86EM
M96X@=&EE9&]T`$IU;&MI<V5N+W-A;&%I<V5N(&%V86EN<&%R:6X@;'5O;G1I
M(&5PY&]N;FES='5I+@!0=65R=&\@4FEC;P!6;VD@='5H;W1A('!O:7-T971T
M=6IA('9I97-T96KD`%%A=&%R`$MY<V5L90!+:6EN=&GV`%)302!*=6QK:6YE
M;B!A=F%I;B`H)60@8FET=&GD*0!2861I;W!A:6YI:V4`4V%D90!3861E='1A
M(&%I:V%I<VEN`%-A9&5T=&$@;7GV:.3D;@!3861E:W5U<F\`5F5S:2!J82!L
M=6UI`%9E9&5S=.0@;'5M965N`%-A='5N;F%I;F5N(&UI971E;&%U<V4`4W5H
M9&4`3'5K=0!6;VD@;'5K96$@=FEE<W1E:N0`4&]I<W1E=&%A;FMO("5S/R!4
MY'3D('1O:6UI;G1O82!E:2!V;VD@<&5R=75T=&%A+@!0;VES=&5T86%N:V\@
M=&EE9&]T(&OD>71TY&KD<W3D("5S/R!4Y'3D('1O:6UI;G1O82!E:2!V;VD@
M<&5R=75T=&%A+@!4;VES='5V=75S('#DY'1T>7D`5&]I<W1U=G5U<P!4;VES
M='5V=75D96X@=&EE9&]T`%1O:7-T=79U=61E;B!PY.1T='EM:7-PY&EVY&WD
MY'+D`%1O:7-T=79U=61E;B!VY&QI`%1O:7-T=79U=61E;B!T>7EP<&D`5&]I
M<W1U=2!PY&EV:71TY&EN`%1O:7-T=74@:W5U:V%U<VET=&%I;@!4;VES='5U
M('9I:6MO:71T86EN`%1O:7-T=74@=G5O<VET=&%I;@!4964@;75U=&]K<V5T
M('5U9&5S=&%A;@!0Y&EV:73D`%#D:7;D="!D>6YA86UI<V5T('9A;&EK:V]E
M;&5M96YT:70Z`%#D:79I=.0@<&]R=&%A;&ENY&MY;>3D.@!3Y.1N;O9L;&EN
M96X@;&%U<V5K90!296QA871I;W-E;&%I;@!,871A82!U=61E;&QE96X`375I
M<W1I:6YP86YO=`!-=6ES='5T=7,Z("5S`$5TY&MA;&5N=&5R:70`173D:V%L
M96YT97)I=#H`173D<&%L=F5L:6UE=`!%=.1T:6QA=6MS96X@55),`$5TY'!A
M;'9E;'5N(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%!O
M:7-T80!0;VES=&$@)7,`4&]I<W1A(&]S86QL:7-T=6IA`%!O:7-T82!O<VEO
M`%!O:7-T82!S87)A:V4`4&]I<W1A(&UU;W1O:6QU`%!O:7-T82!P87)I`%!O
M:7-T82!T86QL971E='1U('-K<FEP=&D@<&%L=F5L:6UE;B!VY&QI86EK86ES
M:&%K96UI<W1O<W1A+@!0;VES=&$`4&]I<W1A('3D;>0@;F]O9&D@9&]K=6UE
M;G1I<W1A`%!O:7-T82!KY'ET=.1JY`!0;VES=&$@:^1Y='3D:N0Z("5S`$MO
M<G9A82!O;&5M87-S86]L979A="!K86QE;G1E<FET('1U;V1U;&QA(&MA;&5N
M=&5R:6QL83\@/'-T<F]N9SY687)O:71U<SH@5.1MY"!P;VES=&%A(&MA:6MK
M:2!T:65T=65E="!TY&WD;FAE=&MI<V5S=.0@:V%L96YT97)I<W1A<VDN/"]S
M=')O;F<^`%!Y>6YT]O9N(&5I('9O:71U('9A<W1A=&$N(%9I<FAE:V]O9&DZ
M(`!0>7ED971T>>0@<&%L=F5L=6$@96D@;/9Y='EN>70N`%!A:V]L;&EN96X`
M5&%R=FET=&%V86$@(B5S(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2`E
M<R!A<V5T=6MS:7-S82X`5&%R=FET=&%V86$@(B5S(BUT:65T;V$@96D@;VQL
M=70@;>3D<FET96QT>2!61E,@87-E='5K<VES<V$N`%1A<G9I='1A=F%A("(E
M<R(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@87-E='5K<VES<V$N`%!A
M:V]L;&EN96X@;W-A;&QI<W1U:F$`4&%K;VQL:6YE;B!K96YT=.0`5'EH:F5N
M;N0`5'EH:F5N;N0@<V%L87-A;F$`5'EH:F5N;N0@<V%L87-A;F%S:0!086QA
M=71A(&]L971U:W-E=`!687-T875S`%!A;&%U=&$@961E;&QI;F5N(&MY<V5L
M>0!4=6QO:W-E=`!086QA82!A<V5T=6MS:6EN`%9A:'9I<W1A('5U<VD@<V%L
M87-A;F$`4F5U;FEO;@!086QA=71A(&%S971U:W-E=`!2:6-H(%1E>'0@161I
M=&]R:6X@87-E='5K<V5T`$%R=F]I='5K<V5T`$]I:V5A`$]I:V5A(&]T<V%K
M90!/:6ME82!A<G9O=`!2:79I7VX@=&EE9&]T+BXN`%)O;VQI`%)O;6%N:6$`
M2^3D;F[D(#$X,`!+Y.1N;N0@=F%S=&%PY&EVY.1N`$ODY&YNY"!M>?9TY'#D
M:7;DY&X`4FEV:6X@=&EE9&]T`%)I=FEN('1I961O=`!2:79I=#H`5FEI=F]I
M=&EN`%9I:79O:71I;B!NY&MY>2!K86EK:VEE;B!R:79I96X@:F$@<V%R86MK
M96ED96X@=N1L:6QLY`!6:6EV;VET:6X@;N1K>7D@=F%I;B!S87)A:VME:61E
M;B!VY&QI;&SD`%9I:79O:71I;B!NY&MY>2!V86EN(')I=FEE;B!VY&QI;&SD
M`%-U;W)I=&$`5F5NY&KD;B!&961E<F%T:6EV:6YE;B!T87-A=F%L=&$`4G5A
M;F1A`%,O34E-12!K<GEP=&]G<F%A9FEN96X@86QL96MI<FIO:71U<P!3+TU)
M344@<V%L871T=2!V:65S=&D`4T%33"UA=71E;G1I:V]I;G1I(&5I(&]L92!K
MY'ET971TY'9I<W/D+@!335,@5&5K<W1I=FEE<W1I=`!344PM:V]M96YT;W1U
M;&MK:0!344PM;&%U<V4@87)V;VIE;B!H86ME;6ES965N`%-32`!/3DY)4U15
M20!37U%,+6MO;65N=&]T=6QK:VD`;&$`4V%I;G0@2&5L96YA`%-A:6YT($MI
M='1S(&IA($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!J82!-:7%U
M96QO;@!386EN="!6:6YC96YT(&IA($=R96YA9&EI;FET`%-A;6%A;B!K96AY
M:W-E96X@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&IA(%!R
M:6YC:7!E`%-A=&5L;&EI='1I('!A;'9E;'5N=&%R:F]A:F$`;&%U86YT86D`
M4V%U9&EA($%R86)I80!486QL971A`%1A;&QE=&$@(B5S(@!486QL971A("5S
M`%1A;&QE=&$@=75T96YA`%1A;&QE=&$@;W-A;&QI<W1U:F%T`%1A;&QE=&$@
M=&%P86AT=6UA`%1A;&QE=&$@87-E='5K<V5T`%1A;&QE=&$@;'5O9'5T(&%S
M971U:W-E="!02%`M<VMR:7!T:6[D('!A;'9E;&EM97-I(';D;&EA:6MA:7-H
M86ME;6ES=&]O;BX@`%1A;&QE=&5T=&EI;B`E<SIN(&%S971U:W-E="X`07-E
M='5S=&5N('#D:79I='ES<VMR:7!T:2!O;B!T86QL971E='1U('!A:6MK86%N
M.B`B)7,B+@!(86IA;F%I<VEA('5K:V]S;7ER<VMY:N0`5&EE9&4`2&%K=0!(
M86MU(&MA;&5N=&5R96ES=&$`2&%K=6MO;F5E=`!(875N('1U;&]K<V5T`$AA
M92!K86QE;G1E<F5I<W1A+"!J;W1K82!S:7/D;'3DY#H`5F%L:71S92!T:65D
M;W-T;W0`5F%L:71S92!K86QE;G1E<FD@;75O:V%T=&%V86MS:0!686QI='-E
M('#D:7;D;>3D<N0`5F%L:71S92!L:7/D='3D=N0@<GEH;>0`5F%L:71S92!U
M=7-I(&]M:7-T86IA`%9A;&ET<V4@<&%L=F5L:6X`5F%L:71S92!L:7/D='3D
M=N0@:^1Y='3D:N0`5F%L:71S92!K86EK:VD`5F%L:71S92!K86EK:VD@<.1I
M=N1MY.1RY&MO;7!O;F5N=&ET`%9A;&ET<V4@;V)J96MT:0!686QI='-E(&MA
M;&5N=&5R:2!NY'ET971TY';D:W-I.@!6;VET(&UU=71T86$@=F%R;6ES='5K
M<V5E;B!L:6ET='EV:>0@87-E='5K<VEA+"!M:71E;B!E<FEL86ES:6$@;N1K
M>6UIY"!NY'ET973DY&X@:F$@;6ETY"!KY'ET973DY&X@;VQE='5S;N1K>6WD
M;N0N`%1Y:&IE;F[D('9A;&EN=&$`5F%L:71S92!K86QE;G1E<FDL(&IO:&]N
M('1U;V1A86X@=&EE=&]J83H`5F%L:71S92!K86QE;G1E<FET+"!J;VES=&$@
M=FEE9.3D;B!T:65T;VIA`%9A;&ET<V4@=&%R=FET=&%V870@;65R:VET(&%L
M;&$@;VQE=FES=&$@=F%L:6MO:7-T82X@5F]I="!S96X@:N1L:V5E;B!K;W!I
M;VED82!J82!L:6ET=.3D(&UE<FMI="!T96MS=&EI<VDN`%9A;&ET<V4@<.1I
M=N1Y:W-E;B!E<F]T:6YM97)K:VDZ`%9A;&ET<V4@<.1I=N1Y:W-E;B!E<VET
M>7-T87!A.@!686QI='-E('9I96YN:7-SY"!KY'ET971TY';D(&UU;W1O.@!6
M86QI='-E('1I961O<W1O+"!J;W-T82!T=6]D86%N('1I971O:F$Z`%9A;&ET
M<V4@96YS:6UMY&EN96X@=FEI:V]N<.1I=N0Z`%9A;&ET<V4@;.1H9&5T:65D
M;W-T;VX@;75O=&\Z`%9A;&ET<V4@;75U=&5T=&%V82!P<F]F:6EL:3H`5F%L
M:71S92!K96QL;VYA:F%N(&5R;W1I;FUE<FMK:3H`5F%L:71S92!A:F%N(&5S
M:71Y<W1A<&$Z`%9A;&ET<V4@;N1Y=&5T=.1VY"!A:6MA:F%K<V\Z`%9A;&ET
M<V4@<VESY.1N:VER:F%U='5M:7-E;B!JY&QK965N(&[D>71E='3D=N0@;N1K
M>6WD.@!686QI='-E(&MA:W-I('EH=&5E;G-O<&EV86$@:V5N='3DY"X`5F]I
M="!V86QI=&$@;6ETY"!T87!A:'1U;6EA(&[D>71E=.3D;B!P;W)T86%L:7-S
M82X`5F%L:71S92!VY')I=&5E;6$N`%9A;&ET<V4@:^1Y=&5T=.1VY"!K:65L
M:3H`3.1H973D(&]N9V5L;6%V:65S=&D`3.1H973D(%--4P!,Y&AE=.0@<&5R
M=75T=7-V:65S=&D@:V%I:VEL;&4@;W-A;&QI<W1U:FEL;&4@:W5N('1A<&%H
M='5M82!P;VES=&5T86%N`$SD:&5TY"!V:65S=&D@;W-O:71T965S965N("5S
M`$SD:&5TY"!PY&EV:71Y:W-E="]K=71S=70@:V%I:VEL;&4@;W-A;&QI<W1U
M:FEL;&4@:W5N('1A<&%H='5M86X@;75U=&]K<VEA('1A;&QE=&5T86%N`%-E
M;F5G86P`5'5N;FES=&EN.B``<WEY<VMU=0!397)B:6$@:F$@36]N=&5N96=R
M;P!387)J86YU;65R;P!086QV96QI;65N('1I961O="!O=F%T(';DY')IY"!T
M86D@96EVY'0@;VQE(&OD>71E='3D=FES<^0N`$ES='5N=&]J96X@:&%L;&EN
M=&$`4V5S<VEO;B!)1"!O;B!V86YH96YT=6YU="X`27-T=6YN;W0`07-E=&$`
M07-E=&$@<.3D='1Y;6ES<.1I=N0`4V%L87-A;F%N(')E<V5T;VEN=&EI;B!L
M:6ET='EV:>0@87-E='5K<VEA+"!J;W,@:F]S:W5S('5N;VAD870@<V%L87-A
M;F%S:2X`07-E=&$@=&]I<W1U=G5U9&5N('#DY'1T>6UI<W#D:7;D;>3D<N0`
M07-E=&$@86QK86UI<W#D:7;D;>3D<N0`5F]I="!A<V5T=&%A('5L:V]I<W1E
M;B!P86QV96QI;6EE;B!A<V5T=6MS970L(&IO:71A(&AA;'5A="!KY'ET=.3D
M('!O<G1A86QI<W-A+@!!<V5T82!V87!A82]V87)A='1U(&MA;&5N=&5R:7-I
M('-E:^0@<VEN=75N(&IA(&UU:6AI;B!L:6ET='EV:>0@=F%P86$O=F%R871T
M=2!A<V5T=6MS:6$N`%9O:70@87-E='1A82!KY'ET971TY';D;B!K:65L96XL
M(&%I:V%V>?9H>6MK965N(&IA(&UU:71A('#D:7;D;>3D<N1A<V5T=6MS:6$N
M`%9O:70@87-E='1A82!A;&]I='5S;VAJ96QM86XL(';D<FET965M86XL(&[D
M:WEMY&X@<.1I=FET>6MS96X@:F$@;75I=&$@;N1K>6WDY&X@;&EI='1Y=FGD
M(&%S971U:W-I82X`07-E;FYU<P!!<V5N;G5K<V5N('#D:79I='ES<VMR:7!T
M:2!O;B!S86%T879I;&QA`%5S96%T('!A:6MA="!S;W!I=F%T(&%N;F5T='5U
M;B!P87)A;65T<FEI;CH@`%-E>6-H96QL:70`2F%K;V$@96D@;/9Y='EN>70Z
M("5S`$IA971U="!K86QE;G1E<FET`$IA971U="!K86QE;G1E<FET.@!/<W1O
M:W-E=`!,>6AY="!K=79A=7,Z`$%S971E=&$@<&EK879A;&EN=&%NY'!PY&EM
M970@=7-E:6UM:6QL92!L:6YK96EL;&4N`$[D>73D`$[D>73D(&MA;&5N=&5R
M:0!.Y'ETY"!L=6]K:71U<W1E;B!S96QI='EK<V5T+@!.Y'ETY"!P;VES=&$L
M(&CD;'ET>7,@:F$@=&]I<W1O(&EK;VYI="!K86QE;G1E<FENY&MY;>1S<^0N
M`$[D>73D(&5R;V%V86ES=75D970@87-E='5K<VEE;B!T86QL971E='5S<V$@
M:F$@=75D97-S82!J=75R:2!M=6]K871U<W-A('9E<G-I;W-S82X`3N1Y=.0@
M=F%L;6ES='5V870@=&5H=.1VY'0@:V%L96YT97)I<W-A+@!.Y'ETY"!V87!A
M82]V87)A='1U('-E;&ET92X`3N1Y=.0@961E;&QI<V5N('-I<^3D;FMI<FIA
M=71U;6ES96X@<.1I=N1Y<RX`3N1Y=.0@=F%I;B!N92!T87!A:'1U;6%T+"!J
M;VEH:6X@;&EI='1Y>2!HY&QY='ES+@!.Y'ETY"!A<V5T=7,@<&ETY.1K<V5S
M:2!A;&MU<&5RY&ES96X`3N1Y=.0@=F%L:71S:6X`3N1Y=.0@:F%E='5T(&MA
M;&5N=&5R:70@=FEE<F5K:^1I;BX`3N1Y=.0@=&%U;'5K:V]T;VEM:6YN;W0@
M=F%L:6MK;RX`3N1Y=.0@=&5H=.1VY'0@:^1Y='3D96X@:V%T96=O<FEO:61E
M;B!VY')E:N0N`$[D>73D('9A<V5M;6%L;&$@)7,@=F%L:6MK;RX`3N1Y=.0@
M=&%U;'5K;VX@<V]L=6X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@=&%U;'5K;VX@
M=&EE9&]T(&1I86QO9VD`3N1Y=.0@=&%U;'5K;VX@<FEV:6X@=&EE9&]T(&1I
M86QO9VD`3N1Y=.0@:W5V86X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@:V5L;&]N
M86EK82!J;VMA:7-E;B!PY&EVY&X@=N1L:7-SY"!V:6EK:V]NY&MY;>1S<^0N
M`$[D>73D('1U;VYT:0!3871E:71A`%-A=&5I=&$@86EK86ES:6X`4V%T96ET
M82!M>?9H96UM:6X`4V%T96ET82!LY&AE='1Y=FEL;&$`4&EE;F5N;N0`4&EE
M;F5N;N0@=&%I('-I:7)RY"!V:65R96ES:>0@;W-I;VET82P@:F]T=&$@;F4@
M96EVY'0@;VQE('1I96QLY`!3:65R<F$@3&5O;F4`2VER:F%U9'4`06QL96MI
M<FIO:71U<P!!;&QE:VER:F]I='5K<V5N(&%L9V]R:71M:0!3:6YG87!O<F4`
M2V]K;P!/:&ET82!Y;&SD<&ET;W1E:'3D=N1T`%-L;W9A:VEA`%-L;W9E;FEA
M`$QU;6D`3'5M:7-A9&5T=&$`3'5M:7-A=&5I=&$`3'5M:7-A=&5I=&$@86EK
M86ES:6X`3'5M:7-A=&5I=&$@;7GV:.3D;@!,=6UE;B!S>79Y>7,Z(`!,=6UE
M;B!MY.1RY"!V971E;N0Z(`!386QO;6]N('-A87)E=`!3;VUA;&EA`$QA=6QU
M="!J82!2=6YO=7,`2N1R:F5S='EK<V5N('-U=6YN86X@=F%L:6YT80!,Y&AD
M96]S;VET90!%=&5LY"U!9G)I:VMA`$5T96SD+45U<F]O<'!A("A)4T\M.#@U
M.2TS*0!%=&5LY"U'96]R9VEA(&IA(&5T96SD:7-E="!386YD=VEC:"!S86%R
M970`171E;.1I;F5N('!A;&QO;G!U;VQI<VMO`%;D;&D@=FEE<F5I<V5T('-O
M;'5J96X@=N1L:7-SY`!6Y&QI('-O;'5N(&QE:7#D=&5K<W1I;B!J82!R975N
M86X@=N1L:7-SY"``5N1L:0!6Y&QI`%;D;&D@:F$@=.1Y=&4`17-P86YJ80!2
M;W-K87!O<W1I`$5R:6MO:7-M97)K:VEE;B!S>?9T=/8`2F%A('-O;'4`2F%A
M('-A<F%K90!*86$@<FEV:0!5<FAE:6QU`%-R:2!,86YK80!?06QK86$`4W1A
M;F1A<F1I`%-T87(@5')E:P!!;&MA;6ES<.1I=N1MY.1RY`!!;&MA80!!;&MA
M;6ES86EK80!!;&MA;6ES=G5O<VD`5%]I;&$`3.3D;FD@=&%I(&%L=64`5&EL
M80!486QL96YN=7-M=6]T;P!+871U;W-O:71E`$SD<&EL>?9N=&D`365R:VMI
M:F]N;VQI<W1A`%!O:7-T82!T;VEM:6%L=64@;W-O:71T965S=&$`5'EY;&D@
M6T-34UT`<W4`06QI:&%K96UI<W1O82`B)7,B(&5I(&SV>71Y;GET+@!/='-I
M:VMO`$SD:&5TY`!,Y&AE=&5T=&EI;B`B)7,B.FX@;&ESY'ES<'EY;G3V+B!%
M="!V;VD@:VER:F%U='5A('-I<^3D;B!E;FYE;B!K=6EN('!Y>6YT]G-I(&]N
M(&OD<VET96QT>2!J82!H>7;D:W-Y='1Y+@!!;&EK:7)J;VET=7,`3VYN:7-T
M=6D`(B5S(CH@;&ESY.1M:6YE;B!JY')J97-T96QMY.1N(&]N;FES='5I+@!+
MY'ET=.1JY&X@(B5S(B!KY'ET=.1JY'1I971O:F5N('!O:7-T86UI;F5N(&KD
M<FIE<W1E;&WD<W3D(&]N;FES='5I+@`B)7,B('!O:7-T971T:6EN(&]N;FES
M='5N965S=&DN`"(E<R(Z(&]N;FES='5T=&EI;B!P;VES=&%M86%N(&KD<FIE
M<W1E;&WD<W3D+@!086QA='1I:6X@;VYN:7-T=6YE97-T:2!V86YH;VEH:6X@
M87-E='5K<VEI;BX@3&%T86$@<VEV=2!U=61E<W1A86X@;N1H9.1K<V5S:2!M
M=75T;VMS970N`%1A;&QE;FYE='1I:6X@87-E='5K<VEE;B!V87)M=75S:V]P
M:6\N`%1A;&QE;FYE='1I:6X@87-E='5K<VEE;B!V87)M=75S:V]P:6\@)7,N
M`"<E<R<Z('#D:79I='ES(&]N;FES='5I+@`E<SIN(&MI<FIO:71T86UI;F5N
M(&]N;FES='5I+@!3=61A;@!9:'1E96YV971O`$%U<FEN9V]N;F]U<W4`075R
M:6YG;VYL87-K=0!S=6YN=6YT86D`075R:6YK;VEN96X`075R:6YG;VYN;W5S
M=0!!=7)I;FMO(&YO=7-E92]L87-K964`075R:6YG;VYN;W5S=3H@`$%U<FEN
M9V]N;&%S:W4`075R:6YG;VYL87-K=3H@`%#DY&QL96MI<FIO:71U<P!4=6MI
M`%-U<FEN86T`4W5K=6YI;6D`2'5I<'!U=G5O<F5T(&IA($IA;B!-87EE;@!3
M=V%Z:6UA80!2=6]T<VD`4W9E:71S:0!3>6YC(&QO:VD@<&]I<W1E='1U`%-Y
M;F--3`!3>6YT86MS:79I<FAE(&AA:W5T97)M96ES<^0`4WEY<FEA+"!A<F%B
M:71A<V%V86QT80!5:VMO<VUY<G-K>0!5:VMO<VUY<G-K>6KD(&IA('1U=6QI
M<W1A`%5K:V]S;7ER<VMY=`!5:VMO<VUY<G-K>6KD(&%I:V%I<VEN`%135BUT
M:65D;W-T;P!4875L=6MK;P!4875L=6MO;B!T:65D;W0`5&%U;'5K;VX@87-E
M='5K<V5T`%1A=6QU:V]N('1I961O=`!486EW86X`5&%I=V%N+"!+:6EN86X@
M;6%A:W5N=&$`5&%D>FEK:7-T86X`5&%N>F%N:6$L(%EH9&ES='EN>70@=&%S
M879A;'1A`$MO:&1E.@!496ATY';D=`!0=6AE;&EN;G5M97)O`$SD;7#V=&EL
M82!E9&5L;&ES96QL92!T=6YN:6QL93H@`$SD;7#V=&EL80!,Y&UP]G1I;&$Z
M(`!,Y&UP]G1I;&$\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!-86QL
M:6$@(B5S(B!E:2!L]GET>6YY="X`36%L;&EE;B!H86QL:6YT80!%:&1O=&5T
M='4`5&5K<W1I`%9A:6X@=&5K<W1I`%1E:W-T:6X@=&%S875S`%1E:W-T:71O
M<`!T;P!4:&%I("A425,M-C(P*0!4:&%I;6%A`$UU;VMK86$@;W-A;&QI<W1U
M:F$@+6[D:WEMY"!E:2!O;&4@96[DY"!NY&MY=FES<^0N(%!O:7-T=71A86XN
M`$944"UL:7/D=&]I;6EN=&\@96D@;VQE(&OD>71E='3D=FES<^0N`$AI<W1O
M<GD@:N1R:F5S=&5L;>0@96D@;VQE(&OD>71E='3D=FES<^0N`$AO<F1E+TMO
M;&%B(&EN=&5G<F]I;G1I;6]O='1O<FD@96D@='5E("(E<R(`24U34"!L;VMI
M82!E:2!V;VET=2!A;'5S=&%A+@!-86EN=&5N86YC93HZ("UL=6]K86X@;&%T
M86%M:6YE;B!E<.1O;FYI<W1U:0!!<V5T=6MS970@:6MK=6YA(&]N('-U;&IE
M='1U+B!0;VES='5T86%N+@!9;&SD<&ED;VX@<&ETY.0@;W1T86$@:^1Y='3V
M]FX@<'ES>7;D('1A;&QE='5S='EY<'!I(%!E<FUI<W-I;VXL(&IO<R!H86QU
M870@:^1Y='3DY"!N:6ETY"X`5F%I;B!A;&%P=6]L:0!+86QE;G1E<FEA("(E
M<R(@96D@=F]I('!O:7-T86$N`$MA;&5N=&5R:2`B)7,B(&]N(&QU;W1U+@!+
M86QE;G1E<FD@(B5S(B!O;B!P;VES=&5T='4`2V%L96YT97)I("(E<R(@;VX@
M;FEM971T>2!U=61E;&QE96X@(B5S(CIK<VDN`$MA;&5N=&5R:2`B)7,B(&]N
M('1A;&QE=&5T='4N`$MA;&5N=&5R:6$@96D@=F]I='4@<&]I<W1A83H@)7,`
M0V]N=&%C="!I9"!N=6UE<F]A(&5I(&]L92!MY.1R:71E;'1Y+"!O;B!T>6AJ
MY"!T86D@96D@;/9Y='EN>70@=&EE=&]K86YN87-T82X`66AT97ES=&EE9&]T
M(&QI<^1T=&EI;B!O;FYI<W1U;F5E<W1I(&]S;VET96MI<FIA87-I+@!6:65S
M=&EN(&%L;&5K:7)J;VET=6MS96X@=&%R:VES=&%M:7-E96X@=&%R=FET86%N
M(&5R:6QL:6YE;B!01U`M86QL96MI<FIO:71U<VQO:&MO+@!*86ME;'5L:7-T
M86X@240@96D@;VQL=70@;>3D<FET96QT>2P@;VX@='EH:N0@=&%I(&5I(&SV
M>71Y;GET('1I971O:V%N;F%S=&$N`$IA:V5L=6QI<W1A82!E:2!O;&QU="!M
MY.1R:71E;'1Y+@!386QA=7-T;VEM:6YN;VX@:^1Y='3V('9A871I('-A;&%T
M='5A(%=75RUY:'1E>71TY"X`4.3D='1Y;6ES<.1I=N1MY.1RY"!P:73DY"!O
M;&QA(&UY]FAE;7!I(&MU:6X@86QK86UI<W#D:7;D;>3D<N0N`%1A<&%H='5M
M82`B)7,B(&]N(&QI<^1T='D@:V%L96YT97)I:6X@(B5S(BP@:F]K82!O;B`E
M<R`E<RX`5&%P86AT=6UA("(E<R(@;VX@<&]I<W1E='1U(&MA;&5N=&5R:7-T
M82`B)7,B+"!J;VMA(&]N("5S("5S+@!487!A:'1U;6%A("(E<R(@;VX@;75O
M:V%T='4@:V%L96YT97)I<W-A("(E<R(L(&IO:V$@;VX@)7,@)7,N`%1A<&%H
M='5M86EL;6]I='5K<V5N(&SD:&5T=.1M:6YE;B`E<R!O;FYI<W1U:2X`5&EE
M9&]S=&]S<V$@)7,@<&ETY&ES:2!O;&QA("5S(&%S971U<RX`5&EE9&]S=&]S
M<V$@)7,@<&ETY&ES:2!O;&QA(&IO:71A:VEN("5S(&%S971U:W-I82X`5&EE
M9&]S=&]A(&5I('9O:61A(&MO<&EO:61A(&ET<V5N<^0@<.3D;&QE+@!4:65D
M;W-T;R!O;&D@='EH:N0N`%-E=7)A879A<W-A(&]N(&]T<VEK:V]T:65D;W0@
M=.1S=.0@;65S<V%G92]R9F,X,C(@+79I97-T:7-TY"X`5.1S<^0@;W9A="!T
M87)K96UM870@=&EE9&]T('1A<&%H='5M87-T83H`2V]K;W)U=61U;B!NY'ET
M=/9T:6QA(&%I:&5U='1A82!O;F=E;&UI82!J;VEL;&%K:6X@26YT97)N970@
M17AP;&]R97(@<V5L86EM96X@:^1Y='3D:FEL;.0N(%9A;&ET971T879A<W1I
M(&MY<V5I;F5N('-E;&%I;B!S:7/D;'3DY"!P:6ER=&5I=.0@:F$@=FER:&5I
M=.0@:F]I:&EN(&5I(&]L92!L]GET>6YY="!K;W)J875S=&$@=&%I(&ME:6YO
M82!K:65R=.3D(&]N9V5L;6$N($AU;VUA871H86X@971TY"!J;W,@:^1Y=.1T
M('3D=.0@;N1Y='3V=&EL86$@:F$@26YT97)N970@17AP;&]R97(@<V5L86EN
M=&$L(&YI:6X@;N1Y='3V('-A871T86$@;65N;N0@<V5K86ES:6XL(&IO=&MU
M="!T;VEM:6YN;W0@96EVY'0@=&]I;6D@=&%I('-E;&%I;B!S86%T=&%A(&MA
M871U82X@2F]S(&OD>73D="!7:6YD;W=S(#EX('1A:2!-12!V97)S:6]T82P@
M;FEI;B!O;B!M86AD;VQL:7-T82!E='3D(&OD>71T]FKD<FIE<W1E;&WD(&MA
M871U=2!N<RX@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@+79I<FAE97-E
M96X@:F$@<VEN=6X@<&ETY.0@:^1Y;FYI<W3DY"!K;VYE('5U9&5S=&%A;BY<
M;EQN($UU:7-T82!E='3D('-I;G5A(&]N('9A<F]I=&5T='4N($YA<'-A=71A
M($]++6YA<'!U;&%A(&IO<R!H86QU870@:V]K96EL;&4@961I=&]R:6X@:V]K
M;W)U=71U(&[D>71T]G1I;&%A+@!0;VES=&5T=&EI;B!P<F]F:6EL:2`B)7,B
M+@!686EN('9A<V5N('!U;VQI`$=N=5!'(&]H:F5L;6%N('-I:F%I;G1I('!I
M=.3D(&WDY')I=&5L;.0@0W)Y<'1?<&=P.CH@+6QU;VMA<W-A+@!6:65S=&D@
M;.1H971E='1Y("5S('9A<W1A86YO='1A:F%L;&4@)7,@;W1S:6MK;VYA("(E
M<R(@;VX@;N1Y=&5T='DN"D5I(&]L92!M:73DY&X@=&%K96ET82!S:6ETY"!E
M='3D('9I97-T:2!O;B!L=65T='4@=&%I('EM;>1R<F5T='DN`$YI;6D@:F]T
M82!KY'ET973DY&X@;&EN:VET971TY&5S<V$@;'5O('-I=G5L;&4`2V5N='1I
M96X@;>3D<N0@<&ETY.0@86YT86$@;G5M97)O:6YA+@!-;V1U=6QI(&]P96YS
M<VP@=&%R=FET86%N($AO<F1E7T-R>7!T7W-M:6UE.CH@+6QU;VMA;B!KY'ET
M=.1M:7-E:W-I+@!!<V5T=7-T82`B)7,B(&MO<VMA('-E;B!T:65D;W0@>6QI
M='1I=N1T('1A;&QE='5S=&%V86X@<W5U<FEM;6%N('-A;&QI='5N(')A:F%N
M`$]H:F5L;6%A+"!J;VQL82!V;VD@:V%T<V]A('9I97-T:71Y>7!P:>0@*"5S
M*2P@96D@;/9Y='EN>70@:N1R:F5S=&5L;>1S=.0N`$QA:6YA=7-M97)K:VD@
M<&ETY.0@;VQL82!Y:W-I='3D:6YE;B!M97)K:VDN`%!Y>6YT]B!O;&D@97#D
M=.1Y9&5L;&EN96XN($IO:71A:VEN('!A<F%M971R96IA('!U=71T=74L(&IO
M='1A('1A<&%H='5M82!O;&ES:2!V;VET=2!H>7;D:W-YY"!T86D@:'ELY'3D
M+@!686EN(&]I:V5A(&IA('9A<V5N('!U;VQI`%9A:6X@;VEK96$@<'5O;&D`
M17)O=&EN('!I=.3D(&]L;&$@>6MS:71TY&EN96X@;65R:VMI+@!086QV96QI
M;B`B)7,B(&]N('!O:7-T971T=2X`4&%L=F5L:6X@(B5S(B!O;B!T86QL971E
M='1U+@!3:7/DY&YK:7)J875T=6UI<W!Y>6YT]B`E<R!O;B!P;VES=&5T='4N
M`$WDY')I=&5L='GD(')I=FGD("@E9"D@96D@;VQE(&]L96UA<W-A+@!686QI
MY&%I:V%I<W1I961O<W1O82`B)7,B(&5I(&]L92!O;&5M87-S82X`2VER:F]I
M='1A;6%S:2!T96MS=&D@96D@=F%S=&%A('1E:W-T:>0@<G5U9'5L;&$N`%9A
M:6X@>6SD<'5O;&D@:F$@86QA<'5O;&D`5F%I;B!Y;.1P=6]L:0!4=6]T=2!T
M:65T;R!HY'9I<VD@961E;&QI<V5N(&MO:&1A;B!A:6MA;F$N`%1U;W1U82!T
M:65D;W-T;V$@96D@=F]I='4@=&%L;&5T=&%A+@!/<VEO=&$@=V5A=&AE<BYC
M;VT@96D@;VQE(&OD>71E='3D=FES<^0N`%1E96UA:&%K96UI<W1O82`B)7,B
M(&5I(&SV>71Y;GET+@!%:2!O;&4@=&%P86AT=6UI82P@:F]T:V$@=F%S=&%I
M<VEV870@;GEK>6ES:>0@=F%A=&EM=6MS:6$N`$%S971U:W-I82!E:2!O;&4@
M<V%A=&%V:6QL82X`16D@;VQE(&]S:6]I=&$L(&IO=&MA('9O:61A86X@;N1Y
M='3DY"!V:65S=&EE;B!Y:'1E>61E<W/D+@!4Y'-SY"!K96YTY'-SY"!O;B!L
M:6EA;B!M;VYT82!M97)K:VGD+B!!;FYO:70@)7,@;65R:VMIY#L@<VEN=6X@
M<&ETY.0@86YT86$@=N1H96UMY&X@:W5I;B`E<R!M97)K:VGD+@!*;VET86MI
M;B!O;F=E;&UI82`B)7,B(&QI<^3D;6ES97-SY"!JY')J97-T96QMY.1N.B`E
M<P!+Y'ET=.1JY&X@(B5S(B!KY'ET=.1JY'1I971O:F5N('!O:7-T86UI<V5S
M<V$@:N1R:F5S=&5L;>1S<^0@;VQI(&]N9V5L;6EA.B``2F]I=&%K:6X@;VYG
M96QM:6$@(B5S(B!P;VES=&%M:7-E<W-A(&KD<FIE<W1E;&WD<W3D.B``2F]I
M=&%K:6X@;VYG96QM:6$@(B5S(B!PY&EV:71Y:W-E<W/D.B`E<P!4:65D;W-T
M;VX@='5O;FYI<W-A(&]L:2!O;F=E;&UI82X@66ATY.1N("5S.F$@96D@='5O
M='4`5&EE9&]S=&]N('1U;VYN:7-S82!O;&D@;VYG96QM:6$N("5S(&MO:V\@
M;VQI('-U=7)E;7!I(&MU:6X@<W5U<FEN('-A;&QI='1U(&MO:V\@*"5D('1A
M=G5A*2X`5&EE9&]S=&]N('1U;VYN:7-S82!O;&D@;VYG96QM:6$N("5S(&QA
M=&%U='5I('9A:6X@;W-A:W-I+@!487!A:'1U:2!V:7)H92!KY'ET971TY&5S
M<^0@:V%L96YT97)I83H@)7,`5&%P86AT=6D@=FER:&4@;&ESY'1TY&5S<^0@
M=&%P86AT=6UA83H@)7,`5&%P86AT=6D@=FER:&4@;N1Y=&5T=.1E<W/D('9I
M97-T:6X@=.1TY"!O<VEO=&$`5&%P86AT=6D@=FER:&4@;75O:V%T=&%E<W-A
M('1A<&%H='5M86$Z("5S`%EH=&5Y<W1I971O:F5N('1U;VYN:7-S82!T87!A
M:'1U:2!V:7)H92X`:4-A;&5N9&%R+71I971O:F5N('1U;VYN:7-S82!T87!A
M:'1U:2!V:7)H92X`07-E='5S=&EE=&]L;VUA:VME97-S82!O;B!J;VMI;B!V
M:7)H92X@16AKY"!JY'1I="!J;VYK=6X@<&%K;VQL:7-E;B!K;VAD86X@=.1Y
M='3D;>1T=.0N`%1A<&%H='5M:65N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H
M93H@)7,N`%1A<&%H='5I('9I<FAE('ER:71E='3D97-SY"!S=6]R:71T86$@
M;W-O:71E:VER:F%T;VEM:6YT;V$N(%ER:73D(&UY]FAE;6UI;B!U=61E<W1A
M86XN`%1A<&%H='5I('9I<FAE(&SD:&5T971TY&5S<^0@=&%P86AT=6UA:6QM
M;VET=7-T82`E<SIL;&4Z("5S`%EH=&5Y<W1I971O:F5N('#D:79I='EK<V5S
M<^0@=&%P86AT=6D@=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U=61E<W1A86XN
M`$IA:V5L=6QI<W1A;B!PY&EV:71Y:W-E<W/D('1A<&%H='5I('9I<FAE+B!9
M<FETY"!M>?9H96UM:6X@=75D97-T86%N+@!%:2!O;&4@=&%P86AT=6UI82X@
M5&%P86AT=6UI82!E:2!V;VD@=FEE9.0N`%3D;>0@24U!4"!P86QV96QI;B!E
M:2!T=64@:V%N<VEO:61E;B!J86MA;6ES=&$N`%3D;>0@=&EE9&]S=&\@96D@
M=F%I:W5T82!R87(M=&EE9&]S=&]L=&$N`%3D;>0@=&EE9&]S=&\@96D@=F%I
M:W5T82!Z:7`M=&EE9&]S=&]L=&$N`%3D;>0@96D@=F%I:W5T82!O:6ME86QT
M82!K;W)T=&EN=6UE<F]L=&$N`%3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3D
MY"!V:65S=&5JY"!#;&EC:V%T96QL:6X@*&AT='`Z+R]C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2!P86QV96QU82!(5%10($%023IL;&$N`%3D;&SD(&%J=7)I
M;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!724X@*&AT='`Z+R]W:6YP;&,N
M8V]M*2!G871E=V%Y('!A;'9E;'5N(&MA=71T82!(5%10($%023IL;&$N`%3D
M;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!S;7,R96UA:6P@
M*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y('!A;'9E;'5N(&MA=71T
M82!(5%10($%023IL;&$N`%3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V
M:65S=&5JY"!6;V1A9F]N96X@;G5M97)O:6AI;B!33510.FQLY"!KY'ET=.1E
M;B!6;V1A9F]N92!)=&%L>2!G871E=V%Y('!A;'9E;'5A+B!4Y'3D('!A;'9E
M;'5A('9O:2!KY'ET=.3D('9A:6X@5F]D869O;F4@271A;'D@*&AT='`Z+R]W
M=W<N,3DP+FET*2!T=6YN=6MS:6QL82X`5.1MY"!K96YT=.0@;VX@<&%K;VQL
M:6YE;BX`5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!V86EN(&MO:V]N86ES
M;'5K=6IA+@!4Y'-SY"!K96YTY'-SY"!P:73DY"!O;&QA(&YU;65R;VET82!J
M82!P:6QK:W4M;65R:VME:N0N`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@
M;VMT86%L:6QU:W5J82X`5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!L:7-T
M82!K;VMO;F%I<VQU:W5J82P@:F]T:V$@<&ETY.0@;VQL82!E<F]T971T=2!P
M:6QK=6QL82!T86D@=N1L:6QY]FYN:6QLY`!!<G9O;B!P:73DY"!O;&QA(&YU
M;65R;RX`5.1S<^0@:V5N=.1S<^0@;VX@=N1R:6WDY')I='ES+"!J;VYK82!P
M:73DY"!O;&QA(%)'0B!(97@@;75O9&]S<RP@97-I;65R:VEK<VD@)R,Q,C,T
M868G+@!4Y&WD('1I961O<W1O;75O=&\@96D@;VQE('1U971T=2X`5.1MY"!L
M;VUA:V4@;VX@:F\@:^1S:71E;'1Y+@!4Y&WD(&]N("5S+@!4Y&WD(&]N($MO
M;&%B($=R;W5P=V%R92!O8FIE:W1I+B!+871S;V%K<V5S:2!TY&WD;B!O8FIE
M:W1I;B!S:6YU;&QA('!I=.3D(&]L;&$@<^1H:_9P;W-T:6]H:F5L;6$L(&IO
M:V$@>6UMY')TY.0@2V]L86(@1W)O=7!W87)E(&9O<FUA871T:6$N($QI<W1A
M('EH=&5E;G-O<&EV:7-T82!SY&AK]G!O<W1I;VAJ96QM:7-T82!L]GET>7D@
M;W-O:71T965S=&$@)7,`4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L:3H@
M)7,`5.1MY"!V:65S=&D@;VX@:VER:F]I=&5T='4@97)I(&UE<FMI<W3V;&SD
M("@E<RD@:W5I;B!M:6OD('-I;G5L;&$@;VX@:^1Y=/9S<^0N(`!.=6UE<F]N
M('!I=.3D(&]L;&$@=N1H:6YTY.1N('EK<VDN`%3D;&SD('!A;'9E;&EM96QL
M82!E:2!V;VD@875K86ES=&$@>FEP+2!T86D@9WII<"UT:65D;W-T;VIA+@!4
MY&WD(&KD<FIE<W1E;&WD(&]N('!O:7,@<.3D;'3D+@!!<G9O;B!P:73DY"!O
M;&QA(&YU;65R;RX`5.1MY&X@:6MK=6YA;B!V;VD@875K86ES=&$@=F%I;B!!
M<V5T=6MS970@:6MK=6YA<W1A`$UY<G-K>0!T;W)S=&%I`%1I:V5T:70`06EK
M80!!:6MA:6MK7W5N80!!:F%N<V5U<F%N=&$`06IA;B!E<VET>7-M=6]T;P!!
M:F%N('9A;&EN=&$`06EK86EK:W5N80!4:6UO<BU,97-T90!/='-I7VMK;P!/
M='-I:VMO`$]T<VEK:V\@*'1O;VQT:7`I.@!687-T86%N;W1T86IA`%9O:61A
M:W-E<VD@=F%L:71A('5S96%M<&EA('9A:6AT;V5H=&]J82P@<&EDY"!#;VYT
M<F]L+2`H4$,I('1A:2!#;VUM86YD+2`H36%C*2!NY'!PY&EN=.0@<&]H:F%S
M<V$@:W5N(&YA<'-A=71A="!H:6ER96X@<&%I;FEK971T82X`5.1NY.1N`$[D
M>73D($A434PM;.1H9&5K;V]D:0!4;V=O`%1O:V5L874`2'5O;65N;F$`5&]N
M9V$`3&EI86X@;6]N=&$@97#D;VYN:7-T=6YU='1A(&MI<FIA=71U;6ES>7)I
M='ES=.0@=FEI;65I<VEM<&EE;B!M:6YU=71T:65N(&MU;'5E<W-A+@!9;/9S
M`%EL:6UPY.1N(&ME:'EK<V5E;B`H7W1O<"D`2^3D;F[V:W-E=`!4<FEN:61A
M9"!J82!4;V)A9V\`5&]S:2!V86D@97#D=&]S:0!T:0!T:6ES=&%I`%1U;FES
M:6$`5'5R:VMI`%1U<FMK:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U
M<FMS(&IA($-A:6-O<R!S86%R970`5'5V86QU`%1Y>7!P:0!+:7)J;VET82!V
M86QI;G1A<VDZ(`!5+E8N("UI;F1E:W-I.B``55),`%523"!J;VAO;B!P86QA
M=71E=&%A;B!S:W)I<'1I;B!S=&%T=7,@<F%P;W)T=&D`55),.@!59V%N9&$`
M56MR86EN80!61E,M:&%K96UI<W1O82!E:2!V;VET=2!L=6ME82X`2^1Y='3D
M:N1N(&QI<^1T:65T;VIE;B!L:7/D>7,@96D@;VYN:7-T=6YU="!K:7)J875T
M=6UI<V5S<V$N`$5I('9O:2!V86EH=&%A(&]I:V5U:W-I82!61E,M=&EE9&]S
M=&]L;&4@(B5S(BX`16D@=F]I('9A:6AT86$@;VEK975K<VEA(%9&4RUT:65D
M;W-T;VQL92`E<R\E<RX`16D@=F]I9&$@=F%I:'1A82`E<SIN+@!4:65D;W-T
M;VX@(B5S(B!K;VMO82!E:2!V;VET=2!T87)K:7-T86$N`$5I('9O:61A(&YI
M;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82`B)7,O)7,B+@!344PM<&%L
M=F5L:6UE96X@96D@<V%A9&$@>6AT97ET=.0N`%EH=&5Y='3D(&5I('9O:61A
M(&UU;V1O<W1A82!34TPM<V%L871T=6YA+@!61E,M=&EE9&]S=&]A(&5I('9O
M:61A(&MO<&EO:61A+@!%:2!V;VED82!L=6]D82!61E,M:&%K96UI<W1O82`B
M)7,B+@!%:2!V;VED82!L=6]D82!61E,M:&%K96UI<W1O82X`16D@=F]I='4@
M;'5O9&$@5D93+71I961O<W1O80!%:2!V;VED82!N:6UE=.0@=75D96QL965N
M(%9&4RUK86YS:6]T82`B)7,B+@!%:2!V;VET=2!L=6]D82!T>6AJY.0@5D93
M+71I961O<W1O82X`5&EE=&]A(&5I('9O:61A(&QA86IE;G1A82X`16D@=F]I
M9&$@<&]I<W1A82`B)7,B+"!H86ME;6ES=&\@96D@;VQE('1Y:&KD+@!%:2!V
M;VED82!P;VES=&%A("(E<R(Z("5S`$5I('9O:61A('!O:7-T86$@(B5S(CH@
M)7,N`$5I('9O:61A('!O:7-T86$@)7,L(&AA:V5M:7-T;R!E:2!O;&4@='EH
M:N0N`$5I('9O:61A('!O:7-T86$@5D93+6AA:V5M:7-T;V$@<F5K=7)S:6EV
M:7-E<W1I+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A+@!%:2!V
M;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A.B`E<RX`16D@=F]I9&$@<&]I
M<W1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A('!O:7-T86$@5D93
M+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M:V%N<VEO=&$@(B5S
M(BX`16D@=F]I9&$@<&]I<W1A82!61E,ZY.0@<F5K=7)S:6EV:7-E<W1I.B`E
M<RX`3GEK>6ES=.0@:&%K96UI<W1O82!E:2!V;VET=2!S96QV:71TY.0N`%9A
M<FUE;G1E96X@=&EE=&]J82!E:2!V;VED82!E>'1R86MT;VED80!-Y.1R:71Y
M:W-E;B`E<R!L=6ME;6EN96X@97#D;VYN:7-T=6DN`$5I('9O:61A('-I:7)T
MY.0@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S
M=&]A("(E<R(N`$5I('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$@:VER:F]I
M='5S=&$@=F%R=&5N+@!%:2!V;VED82!A=F%T82!61E,M=&EE9&]S=&]A+@!4
M:6EV:7-T971Y;B!T:65D;W-T;VX@875K86ES=2!E<.1O;FYI<W1U:2X`16D@
M=F]I='4@;'5K96$@5D93+71I961O<W1O82`H9FEL97-I>F4H*2!E<.1O;FYI
M<W1U:2DN`$5I('9O:61A(&QU:V5A(%9&4RUT:65D;W-T;V$@*&=E=$9I;&53
M:7IE*"D@97#D;VYN:7-T=6DI+@!%:2!V;VET=2!L=6ME82!T:65D;W-T;V$Z
M(`!V9G-R;V]T(&IU=7)I:&%K96UI<W1O82!E:2!V;VET=2!L=6ME82X`16D@
M=F]I9&$@;FEM973D('5U9&5L;&5E;B`B)7,B.B`E<P!5=61E;&QE96YN:6UE
MY&UI;F5N("5S("5S.FMS:2!E<.1O;FYI<W1U:2!K;W-K82!K;VAD96AA:V5M
M:7-T;R!O;B!J;R!O;&5M87-S80!%:2!V;VED82!N:6UE=.0@=75D96QL965N
M(%9&4RUH86ME;6ES=&]A+@!%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&
M4RUH86ME;6ES=&]A.B`E<RX`16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!6
M1E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@
M5D93+71I961O<W1O82`E<R\E<RX`16D@=F]I='4@;FEM973D('5U9&5L;&5E
M;B!61E,M=&EE9&]S=&]A+@!%:2!V;VD@:&%K96$@=F%P86$O=F%R871T=2!T
M:65T;VIA("5S.FQL90!%:2!V;VED82!S=6]R:71T86$@:V]M96YT;V$@)VUK
M:7-O9G,G+@!7;W)D+61O:W5M96YT=&EA(&5I('9O:71U(&ODY&YTY.0`16D@
M=F]I9&$@:VER:F]I='1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A
M(&MI<FIO:71T86$@5D93+71I961O<W1O;VX@*&-O<'DH*2!E<.1O;FYI<W1U
M:2DN`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O<W1O;B!T:65T;VIA
M+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T;V$L(&MI:6YT:?8@
M;VX@=.1Y;F[D+@!!;&QE=FEI=F%T='4`4&5R=2!M=75T;VMS970`4&5R=75T
M=&%A(&5D96QL:7-E;B!T;VEM96YP:71E96X`5'5N=&5M871O;B!V87-T875S
M('!A;'9E;&EM96QT82!Y:'1E>71E96XZ`%1U;G1E;6%T;VX@=F%S=&%U<R!P
M86QV96QI;65L=&$Z(`!,=6]K:71T96QE;6%T;VX`56YI8V]D92`H551&+3@I
M`%EH9&ES='EN965T(&%R86)I96UI<F%A=&ET`%EH9&ES='EN965T(&MU;FEN
M9V%S:W5N;F%T`%EH9'ES=F%L;&%T`%EH9'ES=F%L=&]J96X@5'EY;F5N;65R
M96X@97)I;&QI<W-A87)E=`!-:71T87EK<VEK]G0`5'5N=&5M871O;@!4=6YT
M96UA=&]N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%1U;G1E;6%T;VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`06YN971T=2!P86EK:V%T
M:65T;R!O;B!T=6YT96UA=&]N+@!4=6YT96UA=&]N(&OD>71TY&KD='5N;G5S
M('1A:2!S86QA<V%N82X`4&]I<W1A(&YY:WEI<V5N(&5L96UE;G1I;B!L:6YK
M:71Y<P!.:6UE=/9N`%1I971O='5R=F%S>6ES=.0@96DM<')I=FEL965G:7-E
M="!S:W)I<'1I="!E:7;D="!V;VD@:W5T<W5A($QE:6MK86$O2V]P:6]I+TQI
M:73D('1O:6UI;G1O:F$N($YA<'-A=71A($]++6YA<'!U;&%A(&[D:&3D:W-E
M<VD@;6]Z:6QL82YO<F<@<VEV=6EL;&$@;VQE=F%N(&]H:F5E;BP@:F]S<V$@
M;F5U=F]T86%N(&UI=&5N('-K<FEP=&ES:2!V;VEV870@:^1Y='3DY"!L96EK
M97#V>73DY"X`4&]I<W1A(';D<FD`16D@='5E='1U($-O;G1E;G0M5'EP93H@
M)7,`16DM='5E='1U(&QA86IE;FYU<P!0Y&EV:73D`%#D:79I=.0@)7,`4.1I
M=FETY"!KY'ET=.1JY`!0Y&EV:71E='1I:6X@(B5S(BX`4.1I=FET971T:6EN
M.B`G)7,G+@!0Y&EV:71Y<W-K<FEP=&D@<&]I<W1E='1I:6XN`%1U;P!T=6\@
M:V%I:VMI(&]H:F5L;6EE;B!A<V5N;G5S=&EE9&]S=&]T('!A;'9E;&EM96QL
M92X`27-O="!L871I;F%L86ES970@:VER:F%I;65T`$ES;W0@<F]O;6%L86ES
M970@;G5M97)O=`!5<G5G=6%Y`$OD>73D(&YY:WEI<W3D.B`E<P!+Y'ETY"!3
M4TPM<V%L875S=&$`2^1Y=.0@:F]S('1U;FYU<R]S86QA<V%N82!O;B!E<FD@
M24U34"UP86QV96QI;65L;&4N`$OD>71TY&KD`$OD>71TY&KD;&SD("5S(&5I
M(&]L92!O:6ME=6MS:6$@=&5H9.0@)7,N`$OD>71TY&II96X@>6QLY'!I=&\`
M2^1Y='3V;&EI='1Y;>0`2^1Y='3D:N1N(&%S971U:W-E=`!+Y'ET=.1JY&X@
M<F5K:7-T97+V:6UI;F5N`%3D<W/D(&KD<FIE<W1E;&WD<W/D(&5I('9O:2!R
M96MI<W1E<O9I9.0@:^1Y='3D:FGD+@!+Y'ET=.1JY'1U;FYU<W1A(&5I(&SV
M>71Y;GET+@!+Y'ET=.1JY'1U;FYU<P!+Y'ET=.1JY'1U;FYU<R`B)7,B(&]N
M(&IO(&]L96UA<W-A+@!+Y'ET=.1JY'1U;FYU<SH`2^1Y='3D:N1T=6YN=7,Z
M(`!*Y')J97-T96QMY&X@:^1Y='3D:N1T.@!5>F)E:VES=&%N`%9&4RUH86ME
M;6ES=&]A(&5I(&]L92!O;&5M87-S82X`4&]I<W-A;VQO=FEE<W1I`%!A:6MK
M;VIA(&SV>71Y:2!E<VEM97)K:6MS:3H@`%9O:6UA<W-A;VQO86EK80!!<G9O
M(&UI;G5U=&5I<W-A(&YY:WEH971K97-TY"X`07)V;R!O;B!Y;&D@<&ET=75D
M96X@;6%K<VEM:6%R=F]N("5S+CP`07)V;W0`5F%L:71T879A="!A<G9O=`!6
M86YU871U`%9A:6AT96QE=F%A`%9E;F5Z=65L80!487)K:7-T=7,@97#D;VYN
M:7-T=6D@+2!4Y'3D('9I97-T:>0@;VX@=F]I='4@:^1S:71E;&SD+@!697)S
M:6\`5F5R<VEO;FAA;&QI;G1A`%!Y<W1Y<W5O<F$@=&%S875S`%!Y<W1Y<W5O
M<F$@=.1Y=&4`4'ES='ES=6]R83H`17)I='3D:6X@:V]R:V5A`%9I971N86T`
M5FEE=&YA;2`H5DE30TE)*0!.Y'ETY"`E<P!.Y'ETY"!PY&EVY`!.Y'ETY"!E
M<FEL;&ES96[D('=W=RUS:79U;F$`3N1Y=.0@)7,`3F5I='-Y='-A87)E="P@
M0G)I='1I;.1I;F5N`$YE:71S>71S86%R970L(%EH9'ES=F%L=&%I;@!.Y&MY
M=N1I<WEY<P!.Y&MY=N1I<WEY<SH@`%9O9&%F;VYE($ET86QY(%--5%`Z;B!A
M=G5L;&$`5D%23TE455,`5D%23TE455,A(2$@4$])4U1!(%-+4DE05$D@2^13
M24X@4$%,5D5,24U%3%1!("5S+@!724X@2%144#IN(&%V=6QL80!786QL:7,@
M:F$@1G5T=6YA`%9A<F]I='5S`&ME`%/DY&5N;G5S=&4`4^3D=&EE9&]T(&]N
M('1O:6UI='1A;G5T`%=E871H97(N8V]M`%=75P!75U<M<VEV=7-T;P!K97-K
M:79I:6MK;P!6:6EK:V\`5FEI:VMO("5D`%9I:6MK;V$`5FEI:V]I='1A:6X`
M5FEI:V]I='1A:6XZ(%1O:7-T=79U=61E;B!VY&QI`%1E<G9E='5L;V$`5&5R
M=F5T=6QO82!O:&IE;&UA86X@)7,`5&5R=F5T=6QO82P@)7,`3.1N<VEM86EN
M96X@*$E33RTX.#4Y+3$I`$SD;G-I;6%I;F5N+T5U<F\@*$E33RTX.#4Y+3$U
M*0!,Y&YS:2U386AA<F$`36EN:^0@;VAJ96QM86X@)7,@:^1Y;FYI<W3DY"!S
M:7/DY&YK:7)J875T=6UI<V5N(&KD;&ME96XN`$UI=.0@;65R:VMIY"!KY'ET
M973DY&X@97)O='1I;65N83\`36ETY"!M97)K:VGD(&OD>71E=.3D;B!L86EN
M875K<V5E;C\`36EH:6X@86EK86%N('#D:7;D(&IA('9I:6MK;V[D:WEMY'0@
M<&ETY&ES:2!PY.1T='GD+"!J;W,@96D@;VQE(&UY]FCD:7-E;7!IY"!T87!A
M:'1U;6EA/P!-:6AI;B!A:6MA86X@<.1I=N0@:F$@=FEI:VMO;N1K>6WD="!P
M:73D:7-I(&%L:V%A+"!J;W,@96D@;VQE(&%I:V%I<V5M<&EA('1A<&%H='5M
M:6$_`%=H97)E:7,@075S=')A;&EA;B!K87)T=&$`36ET:^0@=F%I:&5E=`!6
M;VET(&WDY')I=&5L;.0@;&ESY'1O:6UI;G1O:F$@;&%I=&5T86%N('#DY&QL
M92!2:6-H(%1E>'0@961I=&]R:7-S82X`3&5V97ES`$QE=F5Y<R!#4U,@;6ET
M=&%Y:W-I:VOV:6[D`%9A<V5M;6%L;&$@;VQE=F%N("5S('9A;&EK;VX@;&5V
M97ES("AT=6QE92!V;VEM86%N('-E=7)A879A;&QA('-I<^3D;FMI<FIA=71U
M;6ES96QL82DZ`%1A=6QU:V]N(&QE=F5Y<P!,979E>61E;B!Y:W-I:VOV`$QE
M=F5Y<SH`5VEK:0!4=75L:0!4=75L:7-T82!A:6MA:7-I;@!4=75L96YN;W!E
M=7,@<V]L;75I<W-A`%1U=6QI.@!4=75L:3H@`%9I:7-A=7,`5&]I=F5L:7-T
M870`5'GV`$]S;VET92`H='GV*0!0=6AE;&EN("AT>?8I`%1Y]G9I:6MK;P!6
MY.1RY"!MY.1RY"!K96YT=&GD(')I=FEL;.0@)60N($]D;W1E='1I:6X@)60L
M(&SV>71Y:2`E9"X`5N3D<N0@;>3D<N0@:V5N='1IY"X@3V1O=&5T=&EI;B`E
M9"P@;/9Y='EI("5D+@!6Y.1RY"!P;VEK:V5A;6$@)60@;'5E='1A97-S82!6
M1E,M=&EE9&]S=&]A+@!8+5)E9@!8-3`Y=C,@<&5R=7-R86IO:71T965T`%@U
M,#EV,R!L:7/D=&]I;6EN;F]T(&%V86EM96X@:^1Y=/9L;&4`6#4P.78S($MO
M:'1E96X@=F%I:'1O96AT;VEN96X@;FEM:0!8-3`Y=C,@2V]H=&5E;B!A=F%I
M;65N('1U;FYI<W1E`%@U,#EV,RUL86%J96YN=6MS970`5E8`5E965@!986AO
M;R$@:V%R='1A`%9U;W-I`%9U;W-I='1A:6X`5G5O<VET=&%I;CH@5&]I<W1U
M=G5U9&5N(';D;&D`2F5M96X`2WEL;.0`2WEL;.0L('-U;W-T=6XN`$OD>73D
M="!414M35$E424Q!02X@2^1Y=.0@6SP^72!N87!P=6QA82!V86EH=&%A:W-E
M<VD@=&%K86ES:6X@5UE325=91RUT:6QA86XN`$5T('9O:2!T96ADY"!E;F5M
M<.3D(&MU:6X@)60@;W-I;W1A+@!%="!V;VD@=&5H9.0@96YE;7#DY"!K=6EN
M("5D('1A<&%H='5M86$N`$5T(&]L92!M97)K:71T>2!O<V%L;&ES='5J86MS
M:2!A;FYE='1U=6X@=&%P86AT=6UA86XN`$5T(&]L92!A=71E;G1I:V]I='5N
M=70N`%3D=.0@;&]M86ME='1A('9O:2!KY'ET=.3D('9A:6X@375O:VMA82!O
M<V%L;&ES='5J82`M;N1K>6WD<W3D+@!.:6UE<W/D<VD@96D@<V%A(&]L;&$@
M)UPG+6UE<FMK:>0N`$5T(&%N=&%N=70@;VEK96%N(&UU;W1O:7-T82!SY&AK
M]G!O<W1I;W-O:71E='1A+@!%="!MY.1R:71E;&QY="!M:71KY"!T=6]D=6X@
M=&EE9&]S=&]N(&ME;G3D="!V87-T86%V870@;6ETY&MI;B!K96YT=&GD("5S
M.G-SY"X`170@;VQE(&WDY')I=&5L;'ET('/D:&OV<&]S=&EO<V]I=&5T=&%S
M:2!P<F]F:6EL:7-I(&%S971U:W-I<W-A+B!3:6YU;B!P:73DY"!MY.1R:71E
M;&SD('/D:&OV<&]S=&EO<V]I=&4@)7-TY.1L;.0E<RP@96YN96YK=6EN('1A
M<&%H='5M82!T:65T;VIA('9O:61A86X@;.1H971TY.0N`%-I;G5L;&$@96D@
M;VQE(&]I:V5U:W-I82!L:7/D=.0@=&%P86AT=6UI82`E<SKDY&XN`%-I;G5L
M;&$@96D@;VQE(&]I:V5U:W-I82!L:7/D=.0@=&%P86AT=6UI82!V86QI='1U
M=6X@:V%L96YT97)I:6XN`%-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!P;VES
M=&%A('3D=.0@=&%P86AT=6UA82X`4VEN=6QL82!E:2!O;&4@;VEK975K<VEA
M(&UU;VMA=&$@=.1TY"!T87!A:'1U;6%A+@!/;&5T(&MI<FIA=71U;G5T('5L
M;W,N`$]L970@;>3D<FET96QL>70@97#D:V5L=F]N(&MA;&5N=&5R:6XN`$]L
M970@;VYN:7-T=6YE97-T:2!H>7;D:W-Y;GET(&]S86QL:7-T=6UI<V5S:2!T
MY&CD;B!T87!A:'1U;6%A;BX`3VQE="!O;FYI<W1U;F5E<W1I(&MI96QTY'ET
M>6YY="!O<V%L;&ES='5M87-T82!TY&CD;B!T87!A:'1U;6%A;BX`3VQE="!O
M;FYI<W1U;F5E<W1I(&%L=7-T879A<W1I(&UY]FYT>6YY="!O<V%L;&ES='5M
M86%N('3D:.1N('1A<&%H='5M86%N+@!3:6YU;B!P:73DY"!A;G1A82!O:6ME
M82!M871K87!U:&5L:6YN=6UE<F\L('9A:6X@;G5M97)O:71A(&IA(&UA:&1O
M;&QI<V5S=&D@)RLG(&IO<R!KY'ETY'0@:V%N<V%I;G;D;&ES=.0@<'5H96QI
M;FYU;65R;VUU;W1O82X`4VEN=6X@=.1Y='EY(&%N=&%A(&]I:V5A(&%R=F\N
M`%-I;G5N('!I=.3D(&%S96YT86$@1&%T851R964M=&%U<W1A:N1R:F5S=&5L
M;>0@96YN96X@:W5I;B!V;VET(&OD>71TY.0@4VEG;G5P+71O:6UI;G1O:F$N
M`%-I;G5N('!I=.3D(&%S96YT86$@5D93+71A=7-T86KD<FIE<W1E;&WD+@!3
M:6YU;B!T=6QE92!K=79A:6QL82!O;F=E;&UA=&EL86YN971T82!E;FYE;B!K
M=6EN('9O:70@;.1H971TY.0@;VYG96QM879I97-T:6XN`%-I;G5N('!I=.3D
M(&%N=&%A(%523"!M:6AI;B!TY&WD(&QI;FMK:2!O<V]I='1A80!3:6YU;B!P
M:73DY"!V86QI=&$@<&]I<W1E='1A=F$@:V%L96YT97)I+@!3:6YU;B!P:73D
MY"!E;G-I;B!V86QI=&$@;W-O:71E+@!3:6YU;B!P:73DY"!V86QI=&$@<&]I
M<W1E='1A=F$@<&%L=F5L:6XN`%-I;G5N('!I=.3D(&%N=&%A('!O:7-T971T
M879A(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!A;G1A82!P;VES=&5T
M=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@;&ESY'1T
MY';D(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!A;G1A82!PY&EV:71E
M='3D=N0@:^1Y='3D:N1T=6YN=7,N`%-I;G5N('!I=.3D('9A;&ET82!S=6]R
M:71E='1A=F$@=&]I;6EN=&\N`%-I;G5N('!I=.3D(&%N=&%A('5U9&5N(&MA
M=&5G;W)I86X@;FEM:2X`4VEN=6X@<&ETY.0@86YT86$@:71A;&EA;&%I;F5N
M('!U:&5L:6YN=6UE<F\`4VEN=6X@<&ETY.0@96YS:6X@=F%L:71A(&MA;&5N
M=&5R:0!/;&5T('9A;&EN;G5T(&AA;'5A=F%S:2!I;&UO:71U:W-I82!K=6X@
M=&%P86AT=6UI82!L:6ET973DY&X@:V%L96YT97)E:6AI<VDN`$]L970@=F%L
M:6YN=70@:&%L=6%V87-I(&EL;6]I='5K<VEA(&MU;B!T87!A:'1U;6EA('!O
M:7-T971A86X@:V%L96YT97)E:7-T87-I+@!/;&5T('9A;&EN;G5T(&AA;'5A
M=F%S:2!I;&UO:71U:W-I82!K=6X@=&%P86AT=6UI82!M=6]K871A86X@:V%L
M96YT97)E:7-S87-I+@!0>7ES:70@;75I<W1U='1A;6%A;B!T87!A:'1U;6%S
M=&$@)7,L(&IO:V$@;VX@:V5L;&\@)7,@)7,N`$ES='5N=&]S:2`E<R!O;B!V
M86YH96YT=6YU="X@2VER:F%U9'4@=75D96QL965N('-I<^3D;BX`4^1H:_9P
M;W-T:6]S;VET=&5E<VD`4VEN=6X@;.1H971TY&KD;W-O:71T965S:3H`3VUA
M="!T:65T;W-I`%-I;G5N('1I971O:V]N965S:2!KY'ET=.1MY"!T:65T;W9E
M<FMK;RUO<V]I=&4@;VX@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T
M(&%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN
M=6X@<&ETY.0@:VER:F%U='5A('5U9&5S=&%A;B!JY')J97-T96QMY.1N+@!.
M:6UE<VD`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J97-T
M96QMY"!E:2!T=64@:^1Y='3D:FEE;B!L:7/DY&UI<W3D+B!*;W,@:&%L=6%T
M(&AA;&QI;FYO:61A(&OD>71TY&KD='5N;G5K<VEA+"!S:6YU;B!P:73DY"!K
MY'ET=.3D(&IO=&%K:6X@=&]I<W1A(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD
M<FIE<W1E;&WDY"X`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%J
MY')J97-T96QMY"!E:2!T=64@:^1Y='3D:N1T:65T;VIE;B!NY'ET=.1M:7-T
MY"!T86D@=.1MY"!P:6ER<F4@96D@;VQE(&IO<W1A:VEN('-Y>7-TY"!KY'ET
M971TY'9I<W/D+@!3:6YU;B!KY'ET=.1MY'-I('=W=RUS96QA:6X@;N1Y='3D
MY"!O;&5V86X@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T(&%L;VET
M=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN=6X@<&ET
MY.0@:VER:F%U='5A('5U9&5S=&%A;FKD<FIE<W1E;&WDY&XN`%-E;&%I;65S
M:2!E:2!T=64@=.1TY"!T;VEM:6YT;V$N`%-E;&%I;65S:2!E:2!T=64@=&%R
M=FET=&%V86$@='5L;W-T=7-T;VEM:6YT;V$N(%!A:6YA($-O;G1R;VPO3W!T
M:6]N("L@4"!T=6QO<W1A86MS97-I+@!!:6MA=GGV:'EK:V5E<VDZ`$]L971U
M<VMA;&5N=&5R:7-I.@!/;&5T=7-P<F]F:6EL:7-I(&]N(&UU=71E='1U+@!/
M;&5T=7-P<F]F:6EL:7-I.@!.:6UE<VDZ`$ES='5N=&]S:2!O;B!V86YH96YT
M=6YU="X`4VEN=6X@<V%L87-A;F%S:2`E<SIL;&4@;VXZ("5S`$%S971U:W-E
M<VD@;VX@<.1I=FET971T>2!J82!N92!O=F%T('9O:6UA<W-A('3D;>1N(&ES
M='5N;F]N(&%J86XN`$%S971U:W-E<VD@;VX@<.1I=FET971T>2X`4V%L87-A
M;F%S:2!O;B!N;VQL871T=0!386QA<V%N87-I(&]N(&YO;&QA='1U+"!T87)K
M:7-T82!SY&AK]G!O<W1I<VD@:F$@:VER:F%U9'4@<VESY.1N('5U9&5L;&$@
M<V%L87-A;F%L;&%S:2X`4V%L87-A;F%S:2!O;B!V86YH96YT=6YU="X`173D
M<&%L=F5L:6UE<VDZ`$IU9V]S;&%V:6$`6F%I<F4`4V%M8FEA`%II;6)A8G=E
M`%II<'!Y`%M0:6EL;W1A(&QA:6YA='1U('1E:W-T:5T`6T]N9V5L;6%=`%M.
MY'ETY"!L86EN871T=2!T96MS=&D@+0!;3N1Y=.0@;&%I;F%T='4@=&5K<W1I
M("T@)7,@<FEV:>1=`%MN:6UEY&WD=/9N('1A<&%H='5M85T`6W)I=FEL;.0@
M)7,O)7-=`%]9;&SD<&ET;P!?2.1L>71Y<P!?66MS:6YK97)T86EN96X@2&%K
M=0!?2V]M96YT;W1U;&MK:0!?1&%T851R964`7U!O:7-T82!R:79I`%]-=6]K
M:V%A`%]-96YE`%]2>6AMY'0`7T]H:F4`7TMU=F%N('1I961O="XN+@!?5'5O
M+U9I90!?2VER:F%U9'4@<VESY.1N`%]+:7)J875D=2!U;&]S`%]-=6]K:V%A
M(&QI;FMK:>0`7TMA;&5N=&5R:6YI`%]5=7-I('1A<&%H='5M80!?07-E='5K
M<V5T`%]/:6ME=61E=`!?5'5L;W-T80!0;VES=&$@;&EN:VMI+BXN`%](86MU
M`%]!<V5N;G5S`%]4875L=6MO;B!T:65D;W0N+BX`7U3D;N3D;@!?2^1Y='3D
M:N1T`&]S;VET96MI<FIA`'9A<W1A86YO='1A:F$@='5N=&5M871O;@!E;FYE
M;B!T87!A:'1U;6%N(&%L:W5A`&MA;&5N=&5R:0!T>7EN=.0`96D@=F]I(&QU
M;V1A('1U;&]S=&EE9&]S=&]A`&5I('9O:2!A=6MA:7-T82!LY&AD971TY`!N
M87!S875T82!TY'-TY`!V:7)H92!K;VUE;G1O<FEV:6QLY`!A<V5T=7-V:7)H
M90!K<FEI='1I;F5N(&KD<FIE<W1E;&WD=&EE9&]S=&\@<'5U='1U=0!M=6]T
M;W9I<FAE('1I961O:7-S80!PY&EVY`!PY&EVY.0`<.1I=N3D`&UU;VMK86$`
M=&EE='5E='1A(&5I(&SV>71Y;GET`&5V96YT<RYC<W8`979E;G1S+FEC<P!L
M87-K979A`'1I961O<W1O`'-U=6YN87-T82`E<R`H)7,I(&YO<&5U9&5L;&$@
M)7,@)7,`<'5U<VMI='1A:6X`:#H`:&@`='5N=&5M871O;B!P86QV96QI;65N
M(&YI;6D`=N1L:71T]FWD<W1I`"``:6YL:6YE`&EO+79I<FAE`&]H:F5L;6ES
M=&]N('-I<^1I;F5N('9I<FAE`')I=FET70!M:VES;V9S('9I<FAE:V]O9&D@
M)60@25-/.F$@=&5H9&5S<^0N`&UM`&MU=6MA=71T80!N:6UI`&5I(&]L92!T
M;W1E=71E='1U`&5I(&]L92!V:65LY"!T;W1E=71E='1U`&UU:7-T:6QI<W1A
M`&%L:V%E;B`E<R`E<P!S86UA;F$@<.1I=N1NY`!S86UA;F$@=FEI:V]N<.1I
M=N1NY`!P<F]S96YT=&D`:^1Y='3V(&MI96QL971T>0!P:6MS96QE:73D`&5T
MY'9I<FAE('!R;W1O:V]L;&%S<V$`;F]U<V5V80!P86QV96QU(&5I(&]L92!K
MY'ET971TY'9I<W/D`&[D>73D(&5R;W0`<VUS,F5M86EL($A45%`Z;B!A=G5L
M;&$`<W,`=F%K86$`:N1R:F5S=&5L;>1V:7)H90!T96ATY';D;&ES=&$`=N1L
M:6%I:V%I;F5N('9I<FAE`'9A<FUI<W1A86MS97-I(&MI<FIO:71A('-A;&%S
M86YA(&MA:&1E<W1I`'5N:69I960`;FEM973V;@!KY'ET=.1JY&X@=F%L:6YT
M80!V0V%L96YD87(O:4-A;&5N9&%R`'9#87)D`&5I(&SV>71Y;GET('9%=F5N
M=#KD`'<Z`'=E871H97(N8V]M`'9I:6MK;P!V:6EK;VEL;&$Z`'9I:6MK;V$`
M=G5O='1A````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO
M8V%L92]F:5]&22]H96QP+GAM;```````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q-#(R-@`Q,#0Q-S,V,C<U,``P,C(S,C$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^
M"CPA+2T@)$AO<F1E.B!K<F]N;VQI=&@O;&]C86QE+V9I7T9)+VAE;'`N>&UL
M+'8@,2XR+C$R+C,@,C`P-B\P,B\R,"`Q,3HR,#HU-R!J86X@17AP("0@+2T^
M"CQH96QP/@H@(#QE;G1R>2!I9#TB3W9E<G9I97<B(&UD-3TB,34X-3DR-V0T
M.&4T-C(W8S<Y,F9E,#,S,F,T,69D,SDB('-T871E/2)U<'1O9&%T92(^"B`@
M("`\=&ET;&4^2W)O;F]L:71H.B!9;&5I<VMU=F$\+W1I=&QE/@H@("`@/&AE
M861I;F<^36EK)B-X130[(&]N($MR;VYO;&ET:#\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($MR;VYO;&ET:"!W=W<M<&]H:F%I;F5N(&MA;&5N=&5R:7-O
M=F5L;'5S+B!/:&IE;&UI<W1O('1U:V5E"B`@("!P97)U<W1O:6UI;G1O:F5N
M(&MU=&5N('1A<&%H='5M86X@;&ES)B-X130[>7,L(&UU;VMK875S(&IA('!O
M:7-T;PH@("`@;&ES)B-X130[:W-I(&UY)B-X1C8[<R!T;VES='5V:6$@=&%P
M86AT=6UI82`H:F]T:V$@=F]I=F%T('-I<R8C>$4T.VQT)B-X130[)B-X130[
M"B`@("!P;VEK:V5U:W-I82DL(&@F(WA%-#ML>71Y:W-I)B-X130[+"!T=6]N
M=&D@:F$@=FEE;G1I('1O:6UI;G1O:F$@*&E#86QE;F1A<@H@("`@=&%I($-3
M5BUM=6]D;W-S82DL(&E#86QE;F1A<B!P;VAJ86ES:6$@:W5T<W5J82P@;6]N
M:6$*("`@(&MA;&5N=&5R:6XF(WA%-#MK>6UI)B-X130[+"!J865T='5J82!K
M86QE;G1E<F5I=&$L('1E:'0F(WA%-#MV)B-X130[;&ES=&%N("A.86<I"B`@
M("!T96AT)B-X130[=FEE;B!N)B-X130[>71T)B-X130[;6ES96X@*$IO<R!4
M96AT)B-X130[=B8C>$4T.W0@;VAJ96QM82!O;B!A<V5N;F5T='4I(&IA"B`@
M("!Y:'1E96YV961O;B!T87!A:'1U;6ES=&$@=F]I(&UY)B-X1C8[<R!L:7,F
M(WA%-#MT)B-X130[($AO<F1E('EH=&5E;G9E=&]N)B-X130[:WEM)B-X130[
M)B-X130[;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FUE
M;G4M=&]D87DB(&UD-3TB8S9D,&,P9C,V-C$W-6$S.&0P-C4U960Y.38Y960T
M838B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^5F%L:6MK;SH@5"8C
M>$4T.VXF(WA%-#LF(WA%-#MN/"]T:71L93X*("`@(#QP87)A/@H@("`@/&D^
M5"8C>$4T.VXF(WA%-#LF(WA%-#MN/"]I/B!V86QI:VMO=&]I;6EN=&\@;B8C
M>$4T.WET="8C>$4T.R8C>$4T.R!A<V5T=6MS:7-S82!V86QI='-E;6%S:0H@
M("`@;VQE='5S;B8C>$4T.VMY;28C>$4T.VX@*&MU=6MA=7-I+"!V:6EK:V\L
M('`F(WA%-#MI=B8C>$4T.RD@:W5L=79A;&QE('`F(WA%-#MI=B8C>$4T.VQL
M92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FUE;G4M1V]T
M;R(@;60U/2(U-C8Q.3$W-S5B83DP8C<V.68R93-F-V-D9C(T8V)F82(@<W1A
M=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y686QI:VMO.B!-96YE/"]T:71L
M93X*("`@(#QP87)A/@H@("`@/&D^365N93PO:3X@=F%L:6MK;W1O:6UI;G1O
M(&%V86$@<&EE;F5N('!O;FYA:&1U<VEK:W5N86XL(&IO<W-A('9O:70*("`@
M(&YO<&5A<W1I('9A;&ET82!K=75K875D96XL('9I:6MO;B!T86D@<"8C>$4T
M.VEV)B-X130[;BP@:F]N:V$@:V]H9&%L;&4*("`@(&AA;'5A="`\:3YM96YN
M)B-X130[/"]I/BX@5"8C>$4T.VTF(WA%-#L@;VX@=7-E:6X@;F]P96EN('1A
M<&$@<VEI<G1Y)B-X130["B`@("!K86QE;G1E<FES<V$N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)M96YU+41A>2(@;60U/2(S8V0V,F4Q
M,#$Q-C`U.&1B-3)A,35F96-D-V1D8F-B,"(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93Y686QI:VMO.B!0)B-X130[:78F(WA%-#L\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("`\:3Y0)B-X130[:78F(WA%-#L\+VD^('9A;&EK:V]L
M96AT:2!N)B-X130[>71T)B-X130[)B-X130[)B-X130[('9A;&ET=6X@<"8C
M>$4T.VEV)B-X130[;B!T:65D;W0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)M96YU+7=O<FLM=V5E:R(@;60U/2)F.6$V,S4X-6,X,61C
M838S.#@W93$S,&1B8F5A.3%D92(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT
M:71L93Y686QI:VMO.B!4>28C>$8V.W9I:6MK;SPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(#QI/E1Y)B-X1C8[=FEI:VMO/"]I/B!V86QI:VMO;&5H=&D@879A
M82!T>28C>$8V.W9I:6MK;VXF(WA%-#MK>6TF(WA%-#MN("AM86%N86YT86ES
M=&$*("`@('!E<FIA;G1A:6AI;BDL(&IO:V$@;VX@;"8C>$4T.VAI;FXF(WA%
M-#L@=F%L:71T=6$@<"8C>$4T.VEV)B-X130[)B-X130[+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UW965K(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB,V0X83-B9F1A-C(Y8F(V93`Y.#$Y8C)E-C8P-30V934B
M/@H@("`@/'1I=&QE/E9A;&EK:V\Z(%9I:6MK;SPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(#QI/E9I:6MK;SPO:3X@=F%L:6MK;VQE:'1I(&XF(WA%-#MY='0F
M(WA%-#LF(WA%-#L@=FEI:VMO;B8C>$4T.VMY;28C>$4T.VX@*&XF(WA%-#MK
M>79I<W,F(WA%-#L*("`@('-E:71S96TF(WA%-#MN('`F(WA%-#MI=B8C>$4T
M.R8C>$4T.RD@<VET96X@971T)B-X130[('-E('-I<R8C>$4T.VQT)B-X130[
M)B-X130[('9A;&ET=6X@<"8C>$4T.VEV)B-X130[;BX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](FUE;G4M;6]N=&@B(&UD-3TB-&)E,C`U
M-C@W-3<W-65C,68U8C!F.3(P83%D86(V,#@B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^5F%L:6MK;SH@2W5U:V%U<VD\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("`\:3Y+=75K875S:3PO:3X@=F%L:6MK;VQE:'1I(&XF(WA%-#MY
M='0F(WA%-#LF(WA%-#L@:W5U:V%U<VEN)B-X130[:WEM)B-X130[;B!S:71E
M;B!E='0F(WA%-#L@<V4@<VES)B-X130[;'0F(WA%-#ME;B!V86QI='5N('`F
M(WA%-#MI=B8C>$4T.VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)M96YU+6YE=RUE=F5N="(@;60U/2(S-S0P-F-C,F5E-3$P-#`X-C)D
M9C%E86$R9C8T-60T92(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y6
M86QI:VMO.B!5=7-I('1A<&%H='5M83PO=&ET;&4^"B`@("`\<&%R83X*("`@
M(#QI/E5U<VD@=&%P86AT=6UA/"]I/B!V86QI:VMO=&]I;6EN;F]L;&$@=F]I
M="!L:7,F(WA%-#MT)B-X130[(&MA;&5N=&5R:6EN"B`@("!U=61E;B!T87!A
M:'1U;6%N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N
M=2UO<'1I;VYS(B!M9#4](F0W9&8R8S!C9&$X-&,X.6,V,SAD.60V934Y,S`W
M.3<V(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E9A;&EK:V\Z($%S
M971U:W-E=#PO=&ET;&4^"B`@("`\<&%R83X*("`@(#QI/D%S971U:W-E=#PO
M:3X@=F%L:6MK;W1O:6UI;FYO;&QA('9O:70@;75O:V%T82!O:&IE;&UA;@H@
M("`@/&D^87-E='5K<VEA/"]I/B`H=&%I('9A:6AT;V5H=&]J82DN($XF(WA%
M-#MI;&PF(WA%-#L@87-E='5K<VEL;&$@=F]I=`H@("`@=F%I:W5T=&%A($MR
M;VYO;&ET:"!O:&IE;&UA;B!U;&MO;B8C>$4T.VLF(WA&-CLF(WA&-CMN(&IA
M('1O:6UI;G1A86%N+"!O:&IE;&UA;@H@("`@=&%P86%N('1O:6UI82!(;W)D
M96X@=&%I(&UU:61E;B!(;W)D92!O:&IE;&UI96X@:V%N<W-A(&IA"B`@("!H
M86QL:6YN;VED82!J865T='5J82!K86QE;G1E<F5I=&$N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)M96YU+6EM<&]R="UE>'!O<G0B(&UD
M-3TB,S1B8SED9F,T9#8S,#)F8S$P,3$V.39A,6(X9#%C83@B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^5F%L:6MK;SH@5'5O+U9I93PO=&ET;&4^
M"B`@("`\<&%R83X*("`@(#QI/E1U;R]6:64\+VD^('9A;&EK:V]T;VEM:6YN
M;VQL82!V;VET('1U;V1A(&IA('9I960F(WA%-#L*("`@(&MA;&5N=&5R:71A
M<&%H='5M:6$N(%0F(WA%-#ML;"8C>$4T.R!H971K96QL)B-X130[('9O:70@
M='5O9&$@=&%P86AT=6UI82!#4U8L"B`@("!-:6-R;W-O9G0@3W5T;&]O:R!T
M86D@=D-A;&5N9&%R+VE#86QE;F1A<B!M=6]D;VES<V$N(%1A<&%H='5M:6$*
M("`@('9O:2!V:65D)B-X130[('9A:6X@0U-6('1A:2!I0V%L96YD87(@;75O
M9&]I<W-A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB86QA
M<FUS(B!M9#4](C1C,6,V9C-E8C$S830Q-C`S,69F8F5E-&9C93DY96$Q(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D@F(WA%-#ML>71Y:W-E=#PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($MR;VYO;&ET:"!O:&IE;&UA<W-A('9O
M:2!A<V5T=&%A(&@F(WA%-#ML>71Y:W-I)B-X130["B`@("!K86QE;G1E<FET
M87!A:'1U;6EL;&4N($]L971U:W-E;F$@96YS:6UM)B-X130[:6YE;B!H)B-X
M130[;'ET>7,@='5L964@,34*("`@(&UI;G5U='1I82!E;FYE;B!K=6EN('1A
M<&%H='5M82!O;B!M97)K:71T>2!A;&MA=F%K<VDL(&UU='1A('9O:70*("`@
M(&UY)B-X1C8[<R!I='-E(&TF(WA%-#LF(WA%-#MR:71E;&PF(WA%-#L@:"8C
M>$4T.VQY='EK<V5N"B`@("!T87!A:'1U;6%K;VAT86ES97-T:2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G)E8W5R<FEN9RUE=F5N=',B
M(&UD-3TB.#-A,&,S83AA,F0R9C5C93AB-34Q,&)D83(U-38T,V0B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^5&]I<W1U=F%T('1A<&%H='5M870\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!487!A:'1U;6EA('9O:2!T;VES=&%A
M(&UO;F5L;&$@97)I('1A=F%L;&$N(%5S96EM;6%T('1O:7-T=79A=`H@("`@
M=&%P86AT=6UA="!T;VES='5V870@97-I;65R:VEK<VD@/&D^:W5U:V%U<VET
M=&%I;CPO:3X@*'1A<&%H='5U"B`@("!K97)R86X@:W5U:V%U9&5S<V$I('1A
M:2`\:3YV:6EK;VET=&%I;CPO:3X@*'1A<&%H='5U(&ME<G)A;@H@("`@=FEI
M:V]S<V$I+B!4;VES=&]N('9O:2!M>28C>$8V.W,@;28C>$4T.R8C>$4T.W)I
M=&5L;"8C>$4T.R!M;VYI;75T:V%I<V5M;6%K<VD*("`@(&5S:6UE<FMI:W-I
M('1A<&%H='5M82!V;VD@=&]I<W1U82!K=75K875S:71T86EN('9A:6X@:F]K
M82!K;VQM87,*("`@('!E<FIA;G1A:2!T86D@=FEI:V]I='1A:6XL(&UU='1A
M('9A:6X@;6%A;F%N=&%I<VEN+`H@("`@:V5S:VEV:6EK:V]I<VEN(&IA('!E
M<FIA;G1A:7-I;BX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@5F]I="!M
M)B-X130[)B-X130[<FET96QL)B-X130[(&UI=&5N(&MA=6%N('1A<&%H='5M
M86%N('1O:7-T971A86X@;28C>$4T.R8C>$4T.W)I=&5L96TF(WA%-#ML;"8C
M>$4T.R!S:6QL92!T;VES=&]N(#QI/FQO<'!U<"8C>$4T.VEV)B-X130[;28C
M>$4T.R8C>$4T.W(F(WA%-#MN/"]I/BX*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@2F]S(&UU;VMK86%T('1O:7-T=79A;B!T87!A:'1U;6%N('1O:7-T
M=79U=71T82P@;FEI;B!M=75T;W,@='5L964*("`@('9O:6UA86X@=&%P86AT
M=6UA;B!K86EK:7-S82!T;VES=&]I<W-A+B!6;VET(&MU:71E;FMI;B!M=75T
M=&%A"B`@("!T;VES='5V86X@=&%P86AT=6UA;B!Y:'0F(WA%-#L@;65R:VEN
M="8C>$4T.R8C>$4T.R!S:71E;B!E='0F(WA%-#L@;75O:VMA870*("`@('1A
M<&%H='5M86$@:F$@=F%L:71S970@/&D^5&%L;&5N;F$@=75T96YA/"]I/B!T
M;VES='5V=75S"B`@("!V86QI:V]S=&$N(%0F(WA%-#MM)B-X130[;B!J)B-X
M130[;&ME96X@=F]I="!M=75T=&%A('1A<&%H='5M86$@:71S96XF(WA%-#MI
M<V5S=&DL"B`@("!I;&UA;B!E='0F(WA%-#L@;75U=&]K<V5T(&MO<VMI<VEV
M870@;7DF(WA&-CMS(&UU:71A('1A<&%H='5M86X@=&]I<W1O:F$N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)0<FEN=&EN9R(@;60U/2(R
M9CDP9#$T93,T8C<Q-6$P-31F8C4R8F(Y,3EA8S5F."(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y4=6QO<W1A/"]T:71L93X*("`@(#QH96%D:6YG
M/DMA;&5N=&5R96ED96X@:F$@=&%P86AT=6UI96X@='5L;W-T=7,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($IO=&MU="!N)B-X130[:WEM)B-X130[="!O
M;B!S=75N;FET96QT=2!T=6QO<W1E='1A=FEK<VDN($MU;B!O;&5T(&IO<W-A
M:VEN('0F(WA%-#ML;"8C>$4T.VES97-S)B-X130[(&XF(WA%-#MK>6TF(WA%
M-#MS<R8C>$4T.RP@;FEI;B`\:3Y4=6QO<W1A/"]I/B`M:6MO;FD@='5L964@
M;B8C>$4T.VMY=FEI;B!R=75D=6X@>6PF(WA%-#MO<V%N('1O:6UI;G1O=F%L
M:6MK;V]N+B!6;VET(#QI/E1U;&]S=&$\+VD^("UI:V]N:6$@;F%P<V%U='1A
M;6%L;&$@='5L;W-T86$@;B8C>$4T.VMY;28C>$4T.VXN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]L;V-A;&4O9G)?1E(O````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3``,#(P-C8W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]F<E]&4B],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<U,``P,C(T-30`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O
M;&]C86QE+V9R7T92+TQ#7TU%4U-!1T53+VMR;VYO;&ET:"YM;P``````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P-3$R,30Q`#$P-#$W,S8R-S4P`#`R-3`R,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25`````.<(```<````5$<`
M`.$+``",C@```````!"^```.````$;X```\````@O@``#0```#"^```(````
M/KX```L```!'O@``#````%.^```$````8+X``!@```!EO@``&P```'Z^```M
M````FKX``!T```#(O@``)````.:^```I````"[\``!D````UOP``)@```$^_
M```,````=K\``!(```"#OP``)````):_```)````N[\```\```#%OP``"P``
M`-6_```?````X;\```X````!P```!0```!#````H````%L````@````_P```
M"@```$C````5````4\```!(```!IP```"P```'S````,````B,```!T```"5
MP```A0```+/````.````.<$```H```!(P0``#0```%/!```.````8<$``!$`
M``!PP0``#0```(+!```,````D,$```T```"=P0``!@```*O!``"4````LL$`
M`$\```!'P@``'0```)?"```=````M<(```H```#3P@``#P```-["```8````
M[L(```P````'PP``"@```!3#```'````'\,```8````GPP``#@```"[#```*
M````/<,```H```!(PP``#@```%/#```(````8L,```H```!KPP``"0```';#
M```E````@,,``"@```"FPP``)````,_#```F````],,``"X````;Q```&@``
M`$K$```R````9<0``#@```"8Q```5````-'$``!1````)L4``%H```!XQ0``
M5P```-/%```T````*\8```(```!@Q@``"0```&/&```-````;<8```<```![
MQ@``"@```(/&```/````CL8```4```">Q@``!@```*3&```1````J\8```@`
M``"]Q@``"0```,;&```)````T,8```@```#:Q@``)0```./&```@````"<<`
M`!,````JQP``$````#['```/````3\<```H```!?QP``$````&K'```#````
M>\<```\```!_QP``%````(_'```)````I,<```D```"NQP``#0```+C'```2
M````QL<``!D```#9QP``'@```//'```9````$L@```\````LR```#P```#S(
M```-````3,@```H```!:R```#P```&7(```(````=<@``"0```!^R```%```
M`*/(```0````N,@``!8```#)R```"````.#(``!.````Z<@``"T````XR0``
M&0```&;)```'````@,D```P```"(R0``+````)7)```.````PLD```,```#1
MR0``#P```-7)```+````Y<D```4```#QR0``%````/?)```5````#,H``!<`
M```BR@``%0```#K*```2````4,H``!,```!CR@``%0```'?*```3````C<H`
M``H```"AR@``%````*S*```*````P<H```<```#,R@``!P```-3*```%````
MW,H```4```#BR@``"@```.C*```#````\\H```T```#WR@``%P````7+```*
M````'<L```H````HRP``"````#/+```/````/,L```L```!,RP``!P```%C+
M```-````8,L```H```!NRP``#@```'G+```8````B,L``",```"ARP``#@``
M`,7+```4````U,L``!<```#IRP``%P````',```7````&<P``!,````QS```
M#P```$7,```.````5<P``!\```!DS```'0```(3,```'````HLP```8```"J
MS```"````+',```/````NLP```8```#*S```"@```-',```3````W,P```,`
M``#PS```"P```/3,```0`````,T``!4````1S0``%0```"?-```'````/<T`
M`!````!%S0``!0```%;-```5````7,T``!$```!RS0``#````(3-```[````
MD<T``#@```#-S0``"0````;.```'````$,X``!0````8S@```P```"W.```%
M````,<X``!`````WS@``"0```$C.```3````4LX``#D```!FS@``$@```*#.
M```"````L\X``+0```"VS@``)P```&O/```L````D\\``"H```#`SP``)0``
M`.O/```*````$=````D````<T```"@```";0```&````,=````D````XT```
M!P```$+0```O````2M```#<```!ZT```+@```++0``!5````X=```"T````W
MT0``+0```&71```]````D]$``#\```#1T0``+0```!'2``!`````/](``",`
M``"`T@``(P```*32``!`````R-(``"T````)TP``,P```#?3```E````:],`
M`!4```"1TP``&0```*?3```I````P=,``"0```#KTP``*````!#4```1````
M.=0```H```!+U```#````%;4```*````8]0``!````!NU```%@```'_4```6
M````EM0```<```"MU```!P```+74```4````O=0```H```#2U```"````-W4
M```G````YM0```@````.U0``#````!?5```'````)-4```<````LU0``!@``
M`#35```%````.]4```<```!!U0``!@```$G5```(````4-4``"D```!9U0``
M#@```(/5```*````DM4```0```"=U0``!P```*+5```)````JM4```8```"T
MU0``$0```+O5```'````S=4``!8```#5U0``!````.S5```(````\=4```8`
M``#ZU0``#0````'6```&````#]8``!X````6U@``$0```#76```(````1]8`
M``T```!0U@``#````%[6```'````:]8```0```!SU@```P```'C6```#````
M?-8``!<```"`U@``"0```)C6```3````HM8``!T```"VU@``"0```-36```(
M````WM8``!````#GU@``'0```/C6```)````%M<``!L````@UP``!````#S7
M```(````0=<```@```!*UP``00```%/7```:````E=<``"L```"PUP``(```
M`-S7```9````_=<``!4````7V```!@```"W8```&````--@``!4````[V```
M"0```%'8```-````6]@``!@```!IV```(@```(+8```N````I=@``!T```#4
MV```(0```/+8``!4````%-D``"D```!IV0``"@```)/9```'````GMD```<`
M``"FV0``"0```*[9```5````N-D```@```#.V0``#@```-?9```*````YMD`
M``\```#QV0``#0````':```/````#]H```T````?V@``"0```"W:```4````
M-]H```8```!,V@``&````%/:```=````;-H``!,```"*V@``$0```)[:```4
M````L-H```0```#%V@``!@```,K:```4````T=H``%0```#FV@``9````#O;
M```$````H-L```X```"EVP``!0```+3;```%````NML``!L```#`VP``&@``
M`-S;```3````]]L``!$````+W```$0```!W<```<````+]P``$X```!,W```
M10```)O<``!%````X=P``"H````GW0``-@```%+=```^````B=T``#\```#(
MW0``'0````C>```0````)MX``"$````WW@``!0```%G>```3````7]X```L`
M``!SW@``$P```'_>```2````D]X```H```"FW@``#P```+'>```-````P=X`
M`!$```#/W@``$P```.'>```,````]=X```P````"WP``!@````_?```,````
M%M\```8````CWP``%P```"K?```0````0M\``!$```!3WP``"````&7?```%
M````;M\```P```!TWP``$````('?```%````DM\```T```"8WP``!@```*;?
M```6````K=\```<```#$WP``#0```,S?```'````VM\```L```#BWP``!P``
M`.[?```'````]M\```D```#^WP``"0````C@```*````$N```!D````=X```
M/0```#?@```=````=>````P```"3X```$````*#@```;````L>````D```#-
MX```!0```-?@```E````W>```!(````#X0``$P```!;A```K````*N$``#L`
M``!6X0``(````)+A```(````L^$``#8```"\X0``(0```//A```0````%>(`
M``@````FX@``#````"_B```&````/.(```0```!#X@``#P```$CB```.````
M6.(``$````!GX@``!P```*CB```*````L.(```T```"[X@``'P```,GB```<
M````Z>(``"$````&XP``'@```"CC```9````1^,``!X```!AXP``'0```(#C
M```;````GN,``"````"ZXP``+@```-OC```F````"N0``!P````QY```'@``
M`$[D```<````;>0``"8```"*Y```*P```+'D```S````W>0``"8````1Y0``
M*P```#CE```X````9.4``!T```"=Y0``%0```+OE```O````T>4``"`````!
MY@``$@```"+F```I````->8``!X```!?Y@``(````'[F```2````G^8``*(`
M``"RY@``%@```%7G```C````;.<``"@```"0YP``*0```+GG```H````X^<`
M`!\````,Z```%0```"SH```@````0N@``"4```!CZ```*````(GH```M````
MLN@``#````#@Z```D@```!'I```A````I.D``!8```#&Z0``'````-WI```F
M````^ND``"H````AZ@``00```$SJ``!$````CNH```P```#3Z@``!P```.#J
M```'````Z.H```8```#PZ@``#P```/?J```2````!^L```T````:ZP``$```
M`"CK```2````.>L```<```!,ZP``$P```%3K```2````:.L```<```![ZP``
M!````(/K```'````B.L``!````"0ZP``$````*'K```,````LNL```X```"_
MZP``#0```,[K```/````W.L``!,```#LZP``#0````#L```H````#NP```,`
M```W[```#0```#OL```&````2>P``!$```!0[```%P```&+L```;````>NP`
M``X```"6[````@```*7L``!)````J.P```4```#R[```$P```/CL```0````
M#.T```\````=[0``!````"WM```-````,NT```X```!`[0```P```$_M```&
M````4^T```<```!:[0``#@```&+M```(````<>T```\```!Z[0``"````(KM
M```/````D^T```<```"C[0``$````*OM```-````O.T``!````#*[0``#0``
M`-OM```+````Z>T```8```#U[0``"0```/SM```+````!NX```P````2[@``
M#````!_N```*````+.X``!$````W[@``&0```$GN```+````8^X```T```!O
M[@``(@```'WN```;````H.X``#0```"\[@``"@```/'N```8````_.X``!D`
M```5[P``7````"_O```6````C.\``"(```"C[P``#0```,;O```'````U.\`
M``P```#<[P``%````.GO```+````_N\``"(````*\```+P```"WP```+````
M7?````D```!I\```&0```'/P```+````C?```!<```"9\```%P```+'P```)
M````R?````<```#3\```%@```-OP```1````\O````\````$\0``&0```!3Q
M```6````+O$```X```!%\0``&````%3Q```(````;?$```T```!V\0``)@``
M`(3Q```Y````J_$```X```#E\0``0P```/3Q```(````./(``!(```!!\@``
M'P```%3R```(````=/(```L```!]\@``+P```(GR```.````N?(```4```#(
M\@``!P```,[R```(````UO(```8```#?\@``10```.;R```#````+/,```<`
M```P\P``!````#CS```'````/?,```X```!%\P``"@```%3S```.````7_,`
M``H```!N\P``#P```'GS```0````B?,``!<```":\P``%0```++S```.````
MR/,``!H```#7\P``$0```/+S```9````!/0``!<````>]```"0```#;T```%
M````0/0```L```!&]```"@```%+T```"````7?0```4```!@]```#0```&;T
M```;````=/0``!<```"0]```%````*CT```)````O?0```X```#']```#0``
M`-;T```2````Y/0```0```#W]```.````/ST```@````-?4```@```!6]0``
M!@```%_U```(````9O4```@```!O]0``#@```'CU``![````A_4``!@````#
M]@``&````!SV```1````-?8```<```!']@``!0```$_V```8````5?8``!X`
M``!N]@``&P```(WV```9````J?8``#$```##]@``&P```/7V```9````$?<`
M`!,````K]P``!P```#_W```(````1_<```8```!0]P``!@```%?W```,````
M7O<```X```!K]P``#0```'KW```3````B/<```\```"<]P``'@```*SW```9
M````R_<``!````#E]P``#P```/;W```0````!O@```\````7^```"P```"?X
M```/````,_@```P```!#^```#P```%#X```'````8/@```8```!H^```#```
M`&_X```.````?/@```P```"+^```*````)CX```/````P?@```@```#1^```
M!@```-KX```/````X?@```@```#Q^```$P```/KX```>````#OD``"$````M
M^0``(````$_Y```9````</D``!<```"*^0``)0```*+Y```7````R/D``!8`
M``#@^0``!````/?Y```;````_/D```T````8^@``#````";Z```#````,_H`
M``4````W^@``"````#WZ```*````1OH```P```!1^@``"P```%[Z```0````
M:OH```P```![^@``#@```(CZ```+````E_H```0```"C^@``!````*CZ```3
M````K?H``!0```#!^@``#````-;Z```)````X_H```X```#M^@``"P```/SZ
M```;````"/L```<````D^P``!````"S[```'````,?L```H````Y^P``#0``
M`$3[```)````4OL```0```!<^P``!0```&'[```#````9_L``!@```!K^P``
M"@```(3[```$````C_L``"8```"4^P``#@```+O[``!\````ROL``!4```!'
M_```!0```%W\```'````8_P```P```!K_```"````'C\```*````@?P```8`
M``",_```"````)/\```"````G/P```8```"?_```!@```*;\```4````K?P`
M``0```#"_```%0```,?\```-````W?P``!````#K_```&P```/S\```&````
M&/T```0````?_0``"0```"3]```0````+OT```D````__0``"0```$G]```&
M````4_T```4```!:_0``&@```&#]```(````>_T```8```"$_0``!````(O]
M```'````D/T``!D```"8_0``#@```++]```'````P?T```<```#)_0``!0``
M`-']```)````U_T```H```#A_0```@```.S]```&````[_T```L```#V_0``
M#0````+^```'````$/X```D````8_@``!@```"+^```2````*?X```D````\
M_@``!P```$;^```4````3OX``!T```!C_@``0@```('^```E````Q/X``"4`
M``#J_@``!@```!#_```*````%_\```0````B_P``"0```"?_```(````,?\`
M`!$````Z_P``"0```$S_```&````5O\```T```!=_P``!@```&O_```$````
M<O\``#D```!W_P``/0```+'_```Z````[_\``!X````J``$`!0```$D``0`.
M````3P`!``0```!>``$`!@```&,``0`'````:@`!`"$```!R``$`#0```)0`
M`0`5````H@`!``8```"X``$`!````+\``0`1````Q``!``8```#6``$`"@``
M`-T``0`B````Z``!``0````+`0$`!P```!`!`0`$````&`$!``4````=`0$`
M'0```",!`0`$````00$!``P```!&`0$`#@```%,!`0`*````8@$!``@```!M
M`0$`"0```'8!`0`%````@`$!`#H```"&`0$`,````,$!`0`U````\@$!`"D`
M```H`@$`1P```%("`0`X````F@(!`"D```#3`@$`/P```/T"`0`N````/0,!
M`"T```!L`P$`'P```)H#`0`/````N@,!`!(```#*`P$`"P```-T#`0`'````
MZ0,!`"8```#Q`P$`/````!@$`0`I````500!`#H```!_!`$`)````+H$`0`F
M````WP0!``@````&!0$`"@````\%`0`)````&@4!``<````D!0$`(````"P%
M`0`@````304!`"8```!N!0$`"@```)4%`0`9````H`4!`"D```"Z!0$`%@``
M`.0%`0`2````^P4!``<````.!@$`"@```!8&`0`,````(08!``\````N!@$`
M$````#X&`0!`````3P8!`'````"0!@$`9@````$'`0#1````:`<!``X````Z
M"`$`"0```$D(`0`*````4P@!`!(```!>"`$`$P```'$(`0`,````A0@!``8`
M``"2"`$`&````)D(`0`/````L@@!`!8```#""`$`$@```-D(`0`0````[`@!
M`!$```#]"`$`'`````\)`0`C````+`D!`&H```!0"0$`#P```+L)`0`%````
MRPD!`!````#1"0$`"0```.()`0`$````[`D!``L```#Q"0$`(````/T)`0`4
M````'@H!``P````S"@$`#````$`*`0`/````30H!`!4```!="@$`*0```',*
M`0`J````G0H!`"8```#("@$`)P```.\*`0`I````%PL!`"H```!!"P$`&0``
M`&P+`0!"````A@L!`!$```#)"P$`$@```-L+`0`3````[@L!`!0````"#`$`
M#P```!<,`0`6````)PP!`!<````^#`$`$````%8,`0`1````9PP!`#0```!Y
M#`$`$P```*X,`0`2````P@P!`#4```#5#`$`%`````L-`0`'````(`T!``P`
M```H#0$`(````#4-`0`0````5@T!`!0```!G#0$`$0```'P-`0`7````C@T!
M`!P```"F#0$`$P```,,-`0`4````UPT!`!H```#L#0$`$0````<.`0`:````
M&0X!`!X````T#@$`&@```%,.`0`3````;@X!`!4```""#@$`$0```)@.`0`7
M````J@X!`!0```#"#@$`%P```-<.`0`5````[PX!``D````%#P$`$`````\/
M`0`9````(`\!``0````Z#P$`!P```#\/`0`+````1P\!`!$```!3#P$`!@``
M`&4/`0`&````;`\!``8```!S#P$`!0```'H/`0`'````@`\!``<```"(#P$`
M!0```)`/`0`6````E@\!``8```"M#P$`!@```+0/`0`$````NP\!``0```#`
M#P$`!P```,4/`0`.````S0\!``P```#<#P$`#````.D/`0`-````]@\!``H`
M```$$`$`#@````\0`0`%````'A`!`"@````D$`$`#@```$T0`0`,````7!`!
M``\```!I$`$`"@```'D0`0`(````A!`!``D```"-$`$`*P```)<0`0`(````
MPQ`!``0```#,$`$`"````-$0`0`F````VA`!`!(````!$0$`#P```!01`0`&
M````)!$!``H````K$0$`!P```#81`0`(````/A$!`"````!'$0$`#0```&@1
M`0`)````=A$!``T```"`$0$`"@```(X1`0`4````F1$!``P```"N$0$`#0``
M`+L1`0`)````R1$!``X```#3$0$`%@```.(1`0`1````^1$!``D````+$@$`
M!@```!42`0`#````'!(!``8````@$@$`&0```"<2`0`'````01(!``0```!)
M$@$`"P```$X2`0`+````6A(!``<```!F$@$`!0```&X2`0`'````=!(!`!8`
M``!\$@$`#0```),2`0`-````H1(!``H```"O$@$`$````+H2`0`/````RQ(!
M`!$```#;$@$`%P```.T2`0`*````!1,!`!$````0$P$`"````"(3`0`>````
M*Q,!``0```!*$P$`#P```$\3`0`Z````7Q,!``4```":$P$`#````*`3`0`>
M````K1,!``X```#,$P$`$````-L3`0`+````[!,!``P```#X$P$`"0````44
M`0`'````#Q0!``H````7%`$`"0```"(4`0`.````+!0!`!`````[%`$`&P``
M`$P4`0`8````:!0!`!H```"!%`$`"@```)P4`0`)````IQ0!``D```"Q%`$`
M"@```+L4`0`,````QA0!``\```#3%`$`"````.,4`0`&````[!0!`!P```#S
M%`$`!P```!`5`0`%````&!4!``L````>%0$`1P```"H5`0`-````<A4!``D`
M``"`%0$`!````(H5`0`#````CQ4!`!,```"3%0$`$P```*<5`0`3````NQ4!
M``H```#/%0$``@```-H5`0`$````W14!`"4```#B%0$``P````@6`0`%````
M#!8!`"H````2%@$`"@```#T6`0`%````2!8!``0```!.%@$`"@```%,6`0`-
M````7A8!``8```!L%@$`"````',6`0`(````?!8!``0```"%%@$`!0```(H6
M`0`8````D!8!`&@```"I%@$`"0```!(7`0`,````'!<!`!`````I%P$`!0``
M`#H7`0`&````0!<!`!L```!'%P$`+P```&,7`0`0````DQ<!``H```"D%P$`
M#P```*\7`0`*````OQ<!``D```#*%P$`$P```-07`0`;````Z!<!`!@````$
M&`$`%P```!T8`0`8````-1@!`!\```!.&`$`#@```&X8`0`#````?1@!``<`
M``"!&`$``@```(D8`0`(````C!@!``<```"5&`$`!P```)T8`0`+````I1@!
M``D```"Q&`$`"@```+L8`0`+````QA@!``<```#2&`$`40```-H8`0`0````
M+!D!``P````]&0$`#0```$H9`0`:````6!D!`$H```!S&0$`&0```+X9`0`&
M````V!D!`!H```#?&0$`)0```/H9`0`&````(!H!``8````G&@$`'P```"X:
M`0`&````3AH!``D```!5&@$`&````%\:`0`7````>!H!`"@```"0&@$`"0``
M`+D:`0`&````PQH!``T```#*&@$`(@```-@:`0!7````^QH!`!,```!3&P$`
M(P```&<;`0`3````BQL!``(```"?&P$`"P```*(;`0`(````KAL!``T```"W
M&P$`"@```,4;`0`'````T!L!`!0```#8&P$`!@```.T;`0`&````]!L!``@`
M``#[&P$`!0````0<`0`*````"AP!``X````5'`$`!P```"0<`0`3````+!P!
M`!4```!`'`$`#````%8<`0`-````8QP!``H```!Q'`$`"P```'P<`0`R````
MB!P!``<```"['`$`#````,,<`0`-````T!P!``P```#>'`$`"0```.L<`0`)
M````]1P!``H```#_'`$`!P````H=`0`)````$AT!``<````<'0$`"@```"0=
M`0`;````+QT!``\```!+'0$`0@```%L=`0`2````GAT!``H```"Q'0$`%@``
M`+P=`0`,````TQT!``T```#@'0$`$````.X=`0`)````_QT!`!`````)'@$`
M!P```!H>`0`2````(AX!``0````U'@$`!P```#H>`0`%````0AX!``4```!(
M'@$`"P```$X>`0`4````6AX!`!$```!O'@$`&@```($>`0`6````G!X!`!0`
M``"S'@$`%P```,@>`0`8````X!X!`!P```#Y'@$`&0```!8?`0`'````,!\!
M``4````X'P$`#0```#X?`0`,````3!\!``D```!9'P$`$0```&,?`0`(````
M=1\!`!<```!^'P$`"P```)8?`0!*````HA\!``P```#M'P$`'P```/H?`0`:
M````&B`!`!,````U(`$`!````$D@`0`*````3B`!``0```!9(`$`#0```%X@
M`0`-````;"`!``@```!Z(`$`"@```(,@`0`)````CB`!``D```"8(`$`"```
M`*(@`0`,````JR`!``D```"X(`$`!0```,(@`0`)````R"`!``4```#2(`$`
M!P```-@@`0`%````X"`!``0```#F(`$``@```.L@`0`(````[B`!``P```#W
M(`$`.`````0A`0`L````/2$!`!(```!J(0$`*0```'TA`0`R````IR$!`"4`
M``#:(0$`"@`````B`0`L````"R(!`"X````X(@$`,P```&<B`0`S````FR(!
M`#@```#/(@$`#P````@C`0`8````&",!``L````Q(P$`%````#TC`0`0````
M4B,!`"P```!C(P$`'````)`C`0`/````K2,!`!,```"](P$`%0```-$C`0`4
M````YR,!`!(```#\(P$`%`````\D`0`5````)"0!`"T````Z)`$`+0```&@D
M`0`Q````EB0!`"X```#()`$`+P```/<D`0`L````)R4!`&(```!4)0$`$P``
M`+<E`0`-````RR4!``T```#9)0$`"````.<E`0`7````\"4!``@````()@$`
M#````!$F`0`K````'B8!`"$```!*)@$`&@```&PF`0`<````AR8!``D```"D
M)@$`10```*XF`0!!````]"8!``0````V)P$`$P```#LG`0`4````3R<!``X`
M``!D)P$`$P```',G`0`8````AR<!``8```"@)P$`"0```*<G`0`*````L2<!
M``\```"\)P$`"0```,PG`0`0````UB<!``<```#G)P$`#@```.\G`0`%````
M_B<!`!L````$*`$`#0```"`H`0`(````+B@!``,````W*`$`!@```#LH`0`4
M````0B@!`!$```!7*`$`#@```&DH`0`X````>"@!``(```"Q*`$`!@```+0H
M`0`.````NR@!``4```#**`$`!P```-`H`0`.````V"@!``8```#G*`$`*```
M`.XH`0`,````%RD!`!P````D*0$`!````$$I`0`"````1BD!`"8```!)*0$`
M%@```'`I`0`4````ARD!`"D```"<*0$`%P```,8I`0`?````WBD!`%P```#^
M*0$`%````%LJ`0`^````<"H!`!\```"O*@$`$````,\J`0`(````X"H!`!(`
M``#I*@$`!P```/PJ`0`.````!"L!``P````3*P$`#````"`K`0`3````+2L!
M``H```!!*P$`'0```$PK`0`9````:BL!``4```"$*P$`$0```(HK`0`(````
MG"L!``4```"E*P$`$0```*LK`0`)````O2L!`"0```#'*P$`$@```.PK`0`5
M````_RL!`!(````5+`$`#@```"@L`0`9````-RP!``@```!1+`$`"0```%HL
M`0`"````9"P!``T```!G+`$`"@```'4L`0`'````@"P!``\```"(+`$`!@``
M`)@L`0`+````GRP!`!H```"K+`$`"@```,8L`0`'````T2P!``@```#9+`$`
M!0```.(L`0`?````Z"P!``8````(+0$`$`````\M`0`(````("T!``T````I
M+0$`"````#<M`0`>````0"T!`!(```!?+0$`+````'(M`0`:````GRT!``D`
M``"Z+0$`"@```,0M`0`5````SRT!`!````#E+0$`!0```/8M`0`4````_"T!
M``0````1+@$`!P```!8N`0`0````'BX!``8````O+@$`!P```#8N`0`>````
M/BX!`"@```!=+@$`'@```(8N`0`*````I2X!`!P```"P+@$`$0```,TN`0`+
M````WRX!`!H```#K+@$`%`````8O`0`$````&R\!``0````@+P$`"P```"4O
M`0`%````,2\!``8````W+P$`"````#XO`0`&````1R\!``H```!.+P$`&P``
M`%DO`0`T````=2\!`#0```"J+P$`(````-\O`0`I`````#`!`"`````J,`$`
M00```$LP`0`:````C3`!`"@```"H,`$`*0```-$P`0!0````^S`!`"(```!,
M,0$`!@```&\Q`0`(````=C$!``4```!_,0$`#@```(4Q`0`(````E#$!`!D`
M``"=,0$`&0```+<Q`0`J````T3$!`",```#\,0$`&0```"`R`0`N````.C(!
M`#0```!I,@$`"````)XR`0`7````IS(!``H```"_,@$`!P```,HR`0`A````
MTC(!``P```#T,@$`#0````$S`0`,````#S,!`!`````<,P$`#@```"TS`0`+
M````/#,!``<```!(,P$`$P```%`S`0`(````9#,!``L```!M,P$`"@```'DS
M`0`4````A#,!``\```"9,P$`,@```*DS`0`+````W#,!``4```#H,P$`!0``
M`.XS`0`%````]#,!`!<```#Z,P$`#P```!(T`0`$````(C0!``H````G-`$`
M"0```#(T`0`+````/#0!``T```!(-`$`#````%8T`0`.````8S0!``4```!R
M-`$`!````'@T`0`-````?30!`#(```"+-`$`10```+XT`0`+````!#4!``H`
M```0-0$`#P```!LU`0`3````*S4!`!,````_-0$`#P```%,U`0`,````8S4!
M``X```!P-0$`#0```'\U`0`-````C34!`!<```";-0$`!P```+,U`0`>````
MNS4!`!0```#:-0$`!0```.\U`0`4````]34!``8````*-@$`!P```!$V`0`,
M````&38!`!`````F-@$`$0```#<V`0`.````238!`!<```!8-@$`*@```'`V
M`0`&````FS8!``D```"B-@$`#P```*PV`0`,````O#8!``T```#)-@$`$0``
M`-<V`0`+````Z38!`#8```#U-@$`"@```"PW`0`B````-S<!``L```!:-P$`
M#P```&8W`0!]````=C<!`#(```#T-P$`)0```"<X`0`(````33@!`#````!6
M.`$`,0```(<X`0`M````N3@!`!(```#G.`$`#@```/HX`0`%````"3D!``X`
M```/.0$`$P```!XY`0`1````,CD!``@```!$.0$`$@```$TY`0`'````8#D!
M`!$```!H.0$`$P```'HY`0`'````CCD!`!0```"6.0$`&````*LY`0`'````
MQ#D!``4```#,.0$`#````-(Y`0`,````WSD!`!(```#L.0$`!````/\Y`0`'
M````!#H!``H````,.@$`"P```!<Z`0`,````(SH!``X````P.@$`#@```#\Z
M`0`%````3CH!``4```!4.@$`+@```%HZ`0`F````B3H!`",```"P.@$``P``
M`-0Z`0`2````V#H!``8```#K.@$`'@```/(Z`0`8````$3L!`"4````J.P$`
M#0```%`[`0`)````7CL!`!\```!H.P$``P```(@[`0`'````C#L!``H```"4
M.P$``@```)\[`0`,````HCL!`!4```"O.P$`"P```,4[`0`9````T3L!`"``
M``#K.P$`$@````P\`0`%````'SP!``H````E/`$`%0```#`\`0`2````1CP!
M``@```!9/`$`#````&(\`0`$````;SP!``D```!T/`$`!P```'X\`0`+````
MACP!``X```"2/`$`"@```*$\`0`,````K#P!`%(```"Y/`$`%P````P]`0`D
M````)#T!`!(```!)/0$`!P```%P]`0`&````9#T!`!````!K/0$`#@```'P]
M`0`.````BST!`"````":/0$`#````+L]`0`9````R#T!``T```#B/0$`%0``
M`/`]`0`2````!CX!``\````9/@$`%````"D^`0`*````/CX!`!L```!)/@$`
M$````&4^`0`<````=CX!`%@```"3/@$`"P```.P^`0`A````^#X!`"4````:
M/P$`:0```$`_`0`:````JC\!`!<```#%/P$`&0```-T_`0`:````]S\!`!D`
M```20`$`)0```"Q``0`G````4D`!`!H```!Z0`$`%P```)5``0`=````K4`!
M`"8```#+0`$`&P```/)``0`J````#D$!`!D````Y00$`'P```%-!`0`3````
M<T$!``@```"'00$`1````)!!`0`3````U4$!`$````#I00$`!P```"I"`0`(
M````,D(!``D````[0@$`%0```$5"`0`-````6T(!`",```!I0@$`#0```(U"
M`0`3````FT(!``@```"O0@$``P```+A"`0`,````O$(!`$8```#)0@$`%P``
M`!!#`0`.````*$,!`#\````W0P$`30```'=#`0`W````Q4,!`%<```#]0P$`
M!0```%5$`0`?````6T0!`"\```![1`$`"@```*M$`0`3````MD0!`!````#*
M1`$`$0```-M$`0`(````[40!``T```#V1`$`+0````1%`0`$````,D4!``T`
M```W10$`%0```$5%`0`[````6T4!`$\```"710$`'P```.=%`0`6````!T8!
M`"4````>1@$`*````$1&`0`<````;48!``L```"*1@$`(P```)9&`0`?````
MND8!`"$```#:1@$`'0```/Q&`0`E````&D<!`"````!`1P$`)````&%'`0`@
M````AD<!`#````"G1P$`"P```-A'`0`'````Y$<!``T```#L1P$`#````/I'
M`0`7````!T@!``8````?2`$`.0```"9(`0`,````8$@!``<```!M2`$`"0``
M`'5(`0`3````?T@!``D```"32`$`!````)U(`0`0````HD@!``@```"S2`$`
M"````+Q(`0`$````Q4@!``L```#*2`$`#````-9(`0`2````XT@!`!$```#V
M2`$`#`````A)`0`:````%4D!``\````P20$`!P```$!)`0`-````2$D!`!0`
M``!620$`#@```&M)`0`,````>DD!`!L```"'20$`+````*-)`0`3````T$D!
M`!P```#D20$`*`````%*`0`&````*DH!``<````Q2@$`$P```#E*`0`%````
M34H!``0```!32@$`%P```%A*`0`*````<$H!``P```![2@$`"0```(A*`0`&
M````DDH!``D```"92@$`!@```*-*`0`(````JDH!``D```"S2@$`"@```+U*
M`0`(````R$H!``H```#12@$`"@```-Q*`0`'````YTH!`!$```#O2@$`!@``
M``%+`0`.````"$L!``X````72P$`#0```"9+`0`+````-$L!`!T```!`2P$`
M"P```%Y+`0`"````:DL!`!P```!M2P$`!P```(I+`0`&````DDL!`&0```"9
M2P$`"0```/Y+`0`'````"$P!`"8````03`$`.````#=,`0`:````<$P!`"H`
M``"+3`$`.P```+9,`0`H````\DP!`#0````;30$`&0```%!-`0`5````:DT!
M``4```"`30$`!P```(9-`0`(````CDT!``<```"730$`!@```)]-`0`%````
MIDT!``<```"L30$`#@```+1-`0`)````PTT!``8```#-30$`"````-1-`0`+
M````W4T!``<```#I30$`"````/%-`0`'````^DT!`!8````"3@$`"0```!E.
M`0`&````(TX!``L````J3@$`$````#9.`0`&````1TX!`!P```!.3@$`%```
M`&M.`0`'````@$X!`!$```"(3@$`"````)I.`0`.````HTX!``@```"R3@$`
M!0```+M.`0`0````P4X!``D```#23@$`$````-Q.`0`&````[4X!`!D```#T
M3@$`"@````Y/`0`<````&4\!``<````V3P$`!0```#Y/`0`0````1$\!`!0`
M``!53P$`"P```&I/`0`-````=D\!`"@```"$3P$`&````*U/`0`7````QD\!
M``D```#>3P$`!````.A/`0`)````[4\!``H```#W3P$`!P````)0`0`"````
M"E`!``X````-4`$`"````!Q0`0`X````)5`!`",```!>4`$`.````()0`0`F
M````NU`!`#$```#B4`$`)P```!11`0!D````/%$!`!0```"A40$`)````+91
M`0`C````VU$!`",```#_40$`*P```"-2`0`A````3U(!`"0```!Q4@$`50``
M`)92`0`X````[%(!`$H````E4P$`6P```'!3`0`H````S%,!`#@```#U4P$`
M+P```"Y4`0!%````7E0!`$H```"D5`$`1@```.]4`0`S````-E4!`"@```!J
M50$`+````)-5`0`F````P%4!`!L```#G50$`/@````-6`0`Z````0E8!`*D!
M``!]5@$`(P```"=8`0`7````2U@!`$@```!C6`$`A0```*Q8`0`P````,ED!
M`"4```!C60$`00```(E9`0!;````RUD!`$D````G6@$`,0```'%:`0!I````
MHUH!`!T````-6P$`&````"M;`0`K````1%L!`"$```!P6P$`'P```));`0`K
M````LEL!`"$```#>6P$`)P````!<`0`Z````*%P!`!T```!C7`$`$0```(%<
M`0`S````DUP!`"4```#'7`$`)P```.U<`0`@````%5T!`#(````V70$`'P``
M`&E=`0`P````B5T!`&D```"Z70$`,0```"1>`0!!````5EX!`#,```"87@$`
M)0```,Q>`0`]````\EX!`&4````P7P$`30```)9?`0`M````Y%\!`"<````2
M8`$`+P```#I@`0`H````:F`!`"X```"38`$`,````,)@`0!4````\V`!`"<`
M``!(80$`6@```'!A`0`Z````RV$!`$@````&8@$`2@```$]B`0`?````FF(!
M`#(```"Z8@$`+P```.UB`0`L````'6,!`"T```!*8P$`<0```'AC`0!F````
MZF,!`&\```!19`$`LP```,%D`0`7````=64!`"4```"-90$`,@```+-E`0`I
M````YF4!`#X````09@$`(@```$]F`0!2````<F8!`"(```#%9@$`)0```.AF
M`0`+````#F<!`+$````:9P$`(````,QG`0!%````[6<!`"$````S:`$`,```
M`%5H`0`E````AF@!`!P```"L:`$`,0```,EH`0`'````^V@!``@````#:0$`
M!P````QI`0`$````%&D!``H````9:0$`#0```"1I`0`+````,FD!``X````^
M:0$`"0```$UI`0`+````5VD!``8```!C:0$`!0```&II`0`0````<&D!``(`
M``"!:0$`60```(1I`0`%````WFD!`!(```#D:0$`!````/=I`0`'````_&D!
M``@````$:@$`!0````UJ`0`#````$VH!`!`````7:@$`#````"AJ`0`3````
M-6H!``T```!):@$``@```%=J`0`'````6FH!``<```!B:@$`!@```&IJ`0`4
M````<6H!``P```"&:@$`&````)-J`0`&````K&H!``0```"S:@$`$@```+AJ
M`0`,````RVH!``,```#8:@$`*@```-QJ`0`$````!VL!``8````,:P$`!P``
M`!-K`0`?````&VL!`#4````[:P$`+@```'%K`0`O````H&L!`!<```#0:P$`
M(@```.AK`0`E````"VP!`"`````Q;`$`&P```%)L`0`8````;FP!`"0```"'
M;`$`'P```*QL`0`:````S&P!`"$```#G;`$`(`````EM`0`:````*FT!`#(`
M``!%;0$`&0```'AM`0`:````DFT!`"\```"M;0$`*P```-UM`0`?````"6X!
M`",````I;@$`'P```$UN`0`:````;6X!`"$```"(;@$`)0```*IN`0`F````
MT&X!`"4```#W;@$`)````!UO`0`8````0F\!`!T```!;;P$`)````'EO`0`8
M````GF\!`"(```"W;P$`+````-IO`0`O````!W`!`!4````W<`$`)0```$UP
M`0`9````<W`!`#P```"-<`$`'P```,IP`0`C````ZG`!`!\````.<0$`(```
M`"YQ`0`:````3W$!`"\```!J<0$`&````)IQ`0`F````LW$!`!X```#:<0$`
M*0```/EQ`0`>````(W(!`#$```!"<@$`"0```'1R`0`,````?G(!`!<```"+
M<@$`+P```*-R`0`D````TW(!``<```#X<@$`#P````!S`0`4````$',!``X`
M```E<P$`#0```#1S`0`D````0G,!``4```!G<P$`!P```&US`0`B````=7,!
M`"4```"8<P$`&@```+YS`0`=````V7,!`!H```#W<P$`!P```!)T`0#'````
M&G0!``L```#B=`$`'````.YT`0`5````"W4!``8````A=0$`"0```"AU`0`+
M````,G4!``T````^=0$`#````$QU`0`7````674!``8```!Q=0$`,P```'AU
M`0`3````K'4!`!,```#`=0$`!P```-1U`0`/````W'4!``<```#L=0$`,@``
M`/1U`0`$````)W8!`"$````L=@$`$P```$YV`0`.````8G8!``P```!Q=@$`
M$0```'YV`0`R````D'8!`!8```##=@$`"````-IV`0`=````XW8!``D````!
M=P$`"@````MW`0`4````%G<!``H````K=P$`'0```#9W`0`(````5'<!`!\`
M``!==P$`"````'UW`0`:````AG<!`"<```"A=P$`!@```,EW`0`5````T'<!
M``<```#F=P$`"````.YW`0`)````]W<!`#\````!>`$`!P```$%X`0`/````
M27@!``X```!9>`$`$````&AX`0`)````>7@!``D```"#>`$`"````(UX`0`3
M````EG@!``<```"J>`$`"````+)X`0`9````NW@!``H```#5>`$`%P```.!X
M`0`4````^'@!``H````->0$`#````!AY`0`7````)7D!``0````]>0$`*@``
M`$)Y`0`,````;7D!`!$```!Z>0$`!P```(QY`0`"````E'D!`!````"7>0$`
M&````*AY`0`+````P7D!``,```#->0$`"````-%Y`0`)````VGD!``0```#D
M>0$`!P```.EY`0`'````\7D!``8```#Y>0$`%`````!Z`0`'````%7H!``T`
M```=>@$`"P```"MZ`0`4````-WH!`!4```!,>@$`#@```&)Z`0`O````<7H!
M`"````"A>@$`'````,)Z`0!(````WWH!`$P````H>P$`%0```'5[`0`,````
MBWL!`#$```"8>P$`!0```,I[`0`2````T'L!`#\```#C>P$`$@```"-\`0`*
M````-GP!``8```!!?`$`!````$A\`0`$````37P!``H```!2?`$`$P```%U\
M`0`%````<7P!``8```!W?`$`!@```'Y\`0`(````A7P!``0```".?`$`#```
M`)-\`0`*````H'P!``D```"K?`$`.0```+5\`0`N````[WP!`"D````>?0$`
M!0```$A]`0`8````3GT!`!D```!G?0$`'P```(%]`0`=````H7T!`!$```"_
M?0$``@```-%]`0`$````U'T!``H```#9?0$`!````.1]`0`&````Z7T!`!0`
M``#P?0$`!0````5^`0`#````"WX!``P````/?@$`10```!Q^`0`R````8GX!
M`#(```"5?@$`+P```,A^`0`:````^'X!`#H````3?P$`-````$Y_`0`H````
M@W\!`%,```"L?P$`DP````"``0`O````E(`!`$(```#$@`$`,`````>!`0`N
M````.($!`!D```!G@0$`)P```(&!`0`X````J8$!`#@```#B@0$`-P```!N"
M`0!R````4X(!`"````#&@@$`-0```.>"`0`A````'8,!`$4````_@P$`,```
M`(6#`0`I````MH,!`"$```#@@P$`*`````*$`0`I````*X0!`"8```!5A`$`
M)0```'R$`0`H````HH0!`"@```#+A`$`(@```/2$`0`K````%X4!`$4```!#
MA0$`20```(F%`0!&````TX4!`#P````:A@$`,````%>&`0`2````B(8!`!,`
M``";A@$`$````*^&`0!Y````P(8!``D````ZAP$`H0```$2'`0!S````YH<!
M`'P```!:B`$`*P```->(`0!4`````XD!`!<```!8B0$`%0```'")`0`G````
MAHD!`!8```"NB0$`#P```,6)`0`7````U8D!`!\```#MB0$`0`````V*`0`?
M````3HH!`!P```!NB@$`40```(N*`0`:````W8H!`!0```#XB@$`"@````V+
M`0`%````&(L!``8````>BP$`"````"6+`0`%````+HL!`!(````TBP$`$```
M`$>+`0`3````6(L!`!T```!LBP$`#P```(J+`0`/````FHL!``\```"JBP$`
M!@```+J+`0`-````P8L!``0```#/BP$`"0```-2+`0`+````WHL!``4```#J
MBP$`!0```/"+`0`'````]HL!``4```#^BP$`%`````2,`0`.````&8P!``<`
M```HC`$`"````#",`0`/````.8P!``T```!)C`$`"@```%>,`0`(````8HP!
M``P```!KC`$`!@```'B,`0`/````?XP!``<```"/C`$`!@```)>,`0`4````
MGHP!``8```"SC`$`!@```+J,`0`,````P8P!`!$```#.C`$`%P```.",`0`(
M````^(P!``0````!C0$`&0````:-`0`1````((T!``H````RC0$`&````#V-
M`0`3````5HT!`!P```!JC0$`$0```(>-`0`#````F8T!``8```"=C0$`!```
M`*2-`0`/````J8T!``H```"YC0$`"@```,2-`0`'````SXT!``0```#7C0$`
M&0```-R-`0`'````]HT!``(```#^C0$``@````&.`0`1````!(X!``D````6
MC@$``@```"".`0`&````(XX!`!(````JC@$`%P```#V.`0`&````58X!`"<`
M``!<C@$``@```(2.`0`(````AXX!``0```"0C@$`#P```)6.`0`3````I8X!
M``<```"YC@$`"P```,&.`0`0````S8X!`!,```#>C@$`!P```/*.`0`1````
M^HX!``8````,CP$`&````!./`0`&````+(\!`!,````SCP$`$````$>/`0`2
M````6(\!``(```!KCP$`!@```&Z/`0`,````=8\!``D```""CP$`$0```(R/
M`0`B````GH\!``<```#!CP$`!P```,F/`0`+````T8\!`!,```#=CP$`!0``
M`/&/`0`1````]X\!``(````)D`$`"P````R0`0`$````&)`!``L````=D`$`
M!0```"F0`0`'````+Y`!`'\!```WD`$`$@```+>1`0`;````RI$!`!````#F
MD0$`#@```/>1`0`)````!I(!``<````0D@$``P```!B2`0`;````')(!`"$`
M```XD@$`-0```%J2`0`Q````D)(!`"L```#"D@$`+P```.Z2`0`=````'I,!
M`"T````\DP$`"P```&J3`0`6````=I,!`#(```"-DP$`#0```,"3`0`4````
MSI,!``L```#CDP$`(@```.^3`0`3````$I0!``4````FE`$`,0```"R4`0`0
M````7I0!`!$```!OE`$`'@```(&4`0`/````H)0!``L```"PE`$`#P```+R4
M`0`@````S)0!`)8```#ME`$`$@```(25`0`*````EY4!``T```"BE0$`#0``
M`+"5`0`7````OI4!``P```#6E0$`$````..5`0`5````])4!``<````*E@$`
MG0```!*6`0!-````L)8!`"<```#^E@$`+0```":7`0`,````5)<!``P```!A
MEP$`%````&Z7`0`2````@Y<!``T```"6EP$`"P```*27`0`'````L)<!`!``
M``"XEP$`"@```,F7`0`*````U)<!`!````#?EP$`"0```/"7`0`*````^I<!
M``H````%F`$`*@```!"8`0`J````.Y@!`"<```!FF`$`*````(Z8`0!$````
MMY@!`"````#\F`$`/@```!V9`0!-````7)D!`&X```"JF0$`:@```!F:`0!T
M````A)H!`'````#YF@$`00```&J;`0`"````K)L!``\```"OFP$`%0```+^;
M`0`.````U9L!`!````#DFP$`&````/6;`0`%````#IP!``8````4G`$`%P``
M`!N<`0`+````,YP!``H````_G`$`#0```$J<`0`'````6)P!`#0```!@G`$`
M,````)6<`0`4````QIP!`!8```#;G`$`#@```/*<`0`'`````9T!`!(````)
MG0$`!P```!R=`0`6````))T!`"0````[G0$`$0```&"=`0`-````<IT!`!D`
M``"`G0$`'P```)J=`0`?````NIT!`"4```#:G0$`(`````">`0`;````(9X!
M`!\````]G@$`&````%V>`0`3````=IX!`!L```"*G@$`$0```*:>`0`H````
MN)X!`!X```#AG@$`&`````"?`0`?````&9\!`!8````YGP$`80```%"?`0`P
M````LI\!`#(```#CGP$`!P```!:@`0`1````'J`!`$,````PH`$`#@```'2@
M`0`$````@Z`!`!$```"(H`$`"P```)J@`0`&````IJ`!`!4```"MH`$`%0``
M`,.@`0`7````V:`!`!<```#QH`$`%@````FA`0`4````(*$!`!4````UH0$`
M%@```$NA`0`0````8J$!`!L```!SH0$`$0```(^A`0`'````H:$!``<```"I
MH0$`!0```+&A`0`'````MZ$!``P```"_H0$`!````,RA`0`5````T:$!`"(`
M``#GH0$`&@````JB`0`0````):(!`!H````VH@$`%@```%&B`0`,````:*(!
M`!````!UH@$`%0```(:B`0`3````G*(!`!````"PH@$`+````,&B`0`Q````
M[J(!``L````@HP$`(0```"RC`0`<````3J,!`"$```!KHP$`'P```(VC`0`.
M````K:,!`!(```"\HP$`#P```,^C`0`D````WZ,!`",````$I`$`!P```"BD
M`0`&````,*0!``@````WI`$`#0```$"D`0`'````3J0!``L```!6I`$`$@``
M`&*D`0`.````=:0!``L```"$I`$`%````)"D`0`7````I:0!`!L```"]I`$`
M"````-FD`0`4````XJ0!``4```#WI`$`%````/VD`0`9````$J4!`!`````L
MI0$`30```#VE`0!!````BZ4!``D```#-I0$`!P```->E`0`4````WZ4!``,`
M``#TI0$`!0```/BE`0`/````_J4!``D````.I@$`%0```!BF`0!)````+J8!
M`!,```!XI@$``0```(RF`0#K````CJ8!`"X```!ZIP$`-0```*FG`0`W````
MWZ<!`#(````7J`$`"````$JH`0`(````4Z@!``H```!<J`$`!````&>H`0`)
M````;*@!``@```!VJ`$`,````'^H`0`W````L*@!`"\```#HJ`$`7@```!BI
M`0`O````=ZD!`"\```"GJ0$`2P```->I`0!.````(ZH!`"\```!RJ@$`5```
M`**J`0`T````]ZH!`#<````LJP$`5P```&2K`0`O````O*L!`#4```#LJP$`
M+````"*L`0`;````3ZP!`!X```!KK`$`+@```(JL`0`K````N:P!`"L```#E
MK`$`%````!&M`0`+````)JT!``P````RK0$`#P```#^M`0`/````3ZT!`!T`
M``!?K0$`(0```'VM`0`'````GZT!``<```"GK0$`$P```*^M`0`*````PZT!
M``<```#.K0$`+````-:M`0`-`````ZX!`!`````1K@$`!P```"*N`0`(````
M*JX!``8````SK@$`!0```#JN`0`(````0*X!``<```!)K@$`#````%&N`0`J
M````7JX!`!,```")K@$`#````)VN`0`$````JJX!``<```"OK@$`!P```+>N
M`0`'````OZX!`!D```#'K@$`!0```.&N`0`2````YZX!``@```#ZK@$`"```
M``.O`0`#````#*\!``8````0KP$`!@```!>O`0`J````'J\!`!(```!)KP$`
M"````%RO`0`-````9:\!``P```!SKP$`!P```("O`0`&````B*\!`!(```"/
MKP$``P```**O`0!!````IJ\!``<```#HKP$`&0```/"O`0`P````"K`!``<`
M```[L`$`!@```$.P`0`4````2K`!`!H```!?L`$`!P```'JP`0`A````@K`!
M``4```"DL`$`"````*JP`0`(````L[`!`&0```"\L`$`*@```"&Q`0`_````
M3+$!`"H```",L0$`*@```+>Q`0`F````XK$!``8````)L@$`!P```!"R`0`>
M````&+(!``<````WL@$`#0```#^R`0`J````3;(!`"X```!XL@$`-P```*>R
M`0`M````W[(!`#<````-LP$`;P```$6S`0`S````M;,!``@```#ILP$`!P``
M`/*S`0`,````^K,!``H````'M`$`&````!*T`0`)````*[0!``L````UM`$`
M%````$&T`0`8````5K0!`"(```!OM`$`&````)*T`0`:````J[0!`!4```#&
MM`$`$P```-RT`0`'````\+0!`!D```#XM`$`'0```!*U`0`5````,+4!`!H`
M``!&M0$`&@```&&U`0`%````?+4!``@```""M0$`&P```(NU`0!R````I[4!
M`'D````:M@$`!````)2V`0`1````F;8!``4```"KM@$`!0```+&V`0`:````
MM[8!`!L```#2M@$`%P```.ZV`0`7````!K<!`!L````>MP$`)P```#JW`0!H
M````8K<!`%H```#+MP$`80```":X`0`V````B+@!`$<```"_N`$`10````>Y
M`0!)````3;D!`",```"7N0$`#@```+NY`0`J````RKD!``<```#UN0$`'@``
M`/VY`0`2````'+H!`!T````ON@$`&0```$VZ`0`5````9[H!`"0```!]N@$`
M'P```**Z`0`7````PKH!`!,```#:N@$`$0```.ZZ`0`1`````+L!``8````2
MNP$`#P```!F[`0`'````*;L!``H````QNP$`&````#R[`0`1````5;L!``@`
M``!GNP$`!P```'"[`0`3````>+L!`!<```",NP$`!@```*2[`0`1````J[L!
M``0```"]NP$`(0```,*[`0`(````Y+L!``X```#MNP$`"P```/R[`0`)````
M"+P!``<````2O`$`!P```!J\`0`+````(KP!``D````NO`$`"@```#B\`0`<
M````0[P!`$D```!@O`$`(@```*J\`0`-````S;P!`!D```#;O`$`*0```/6\
M`0`)````'[T!``4````IO0$`(````"^]`0`5````4+T!`!@```!FO0$`+0``
M`'^]`0`_````K;T!`"0```#MO0$`"````!*^`0`\````&[X!`"<```!8O@$`
M$0```("^`0`*````DKX!``D```"=O@$`#P```*>^`0`&````M[X!`!8```"^
MO@$`%0```-6^`0!?````Z[X!``@```!+OP$`"@```%2_`0`-````7[\!`"0`
M``!MOP$`)@```)*_`0`N````N;\!`"<```#HOP$`(````!#``0`E````,<`!
M`"0```!7P`$`*@```'S``0`E````I\`!`#0```#-P`$`,`````+!`0`K````
M,\$!`"P```!?P0$`(P```(S!`0`Q````L,$!`#8```#BP0$`-@```!G"`0`K
M````4,(!`#$```!\P@$`00```*["`0`J````\,(!`"D````;PP$`0P```$7#
M`0`K````B<,!`!L```"UPP$`,0```-'#`0`G`````\0!`"<````KQ`$`&@``
M`%/$`0"S````;L0!`!\````BQ0$`*@```$+%`0`N````;<4!`#````"<Q0$`
M+0```,W%`0`R````^\4!`"D````NQ@$`*P```%C&`0`[````A,8!`#L```#`
MQ@$`0````/S&`0!"````/<<!`+(```"`QP$`)P```#/(`0`A````6\@!`"4`
M``!]R`$`,@```*/(`0`Y````UL@!`$8````0R0$`3P```%?)`0`,````I\D!
M``0```"TR0$`!0```+G)`0`%````O\D!``\```#%R0$`&0```-7)`0`-````
M[\D!`!````#]R0$`%0````[*`0`$````),H!`!<````IR@$`&0```$'*`0`'
M````6\H!``0```!CR@$`!P```&C*`0`2````<,H!`!$```"#R@$`#@```)7*
M`0`:````I,H!`!0```"_R@$`%@```-3*`0`5````Z\H!``T````!RP$`.0``
M``_+`0`&````2<L!`!,```!0RP$`!@```&3+`0`3````:\L!`!D```!_RP$`
M'0```)G+`0`2````M\L!``(```#*RP$`20```,W+`0`+````%\P!`!T````C
MS`$`%@```$',`0`0````6,P!``0```!IS`$`$0```&[,`0`4````@,P!``0`
M``"5S`$`!P```)K,`0`*````HLP!`!4```"MS`$`"````,/,`0`0````S,P!
M``<```#=S`$`%@```.7,`0`&````_,P!`!$````#S0$`$@```!7-`0`3````
M*,T!`",````\S0$`"P```&#-`0`)````;,T!``P```!VS0$`$@```(/-`0`5
M````ELT!`!,```"LS0$`$````,#-`0`8````T<T!`"````#JS0$`$@````O.
M`0`2````'LX!`"(````QS@$`)0```%3.`0!%````>LX!`!$```#`S@$`(0``
M`-+.`0`;````],X!`&X````0SP$`&@```'_/`0`W````FL\!`!(```#2SP$`
M"````.7/`0`,````[L\!`!,```#[SP$`"P````_0`0`T````&]`!`#0```!0
MT`$`#0```(70`0`.````D]`!`"@```"BT`$`$0```,O0`0`2````W=`!`!(`
M``#PT`$`"@````/1`0`(````#M$!`!@````7T0$`%````##1`0`3````1=$!
M`!\```!9T0$`&P```'G1`0`2````E=$!`!$```"HT0$`"````+K1`0`0````
MP]$!`"P```#4T0$`2P````'2`0`-````3=(!`&(```!;T@$`"0```+[2`0`6
M````R-(!`"T```#?T@$`"P````W3`0`.````&=,!`#@````HTP$`$````&'3
M`0`'````<M,!``T```!ZTP$`!0```(C3`0`5````CM,!`$D```"DTP$``P``
M`.[3`0`(````\M,!``@```#[TP$`"0````34`0`7````#M0!``X````FU`$`
M$@```#74`0`0````2-0!`!4```!9U`$`%@```&_4`0`B````AM0!`!L```"I
MU`$`%P```,74`0`A````W=0!`!D```#_U`$`(@```!G5`0`>````/-4!``D`
M``!;U0$`!@```&75`0`(````;-4!``H```!UU0$``@```(#5`0`4````@]4!
M``@```"8U0$`,````*'5`0`:````TM4!`!D```#MU0$`"@````?6`0`-````
M$M8!``X````@U@$`&````"_6`0`$````2-8!`$4```!-U@$`+P```)/6`0`+
M````P]8!``8```#/U@$`!0```-;6`0`.````W-8!`!(```#KU@$`H````/[6
M`0`F````G]<!`!\```#&UP$`$@```.;7`0`(````^=<!``8````"V`$`)P``
M``G8`0!`````,=@!`$````!RV`$`+@```+/8`0!/````XM@!`#(````RV0$`
M%P```&79`0`J````?=D!``<```"HV0$`"````+#9`0`(````N=D!``8```#"
MV0$`$@```,G9`0`4````W-D!`!$```#QV0$`%0````/:`0`4````&=H!`"\`
M```NV@$`)@```%[:`0`9````A=H!`!0```"?V@$`%@```+3:`0`4````R]H!
M`!(```#@V@$`&@```//:`0`2````#ML!`!0````AVP$`"````#;;`0`*````
M/]L!`!,```!*VP$`&````%[;`0`.````=]L!`#,```"&VP$`$0```+K;`0`,
M````S-L!``@```#9VP$`$0```.+;`0`4````]-L!`#H````)W`$`(P```$3<
M`0`F````:-P!`"4```"/W`$`(````+7<`0`?````UMP!`"\```#VW`$`(0``
M`";=`0`B````2-T!``0```!KW0$`&0```'#=`0`*````BMT!``\```"5W0$`
M`P```*7=`0`*````J=T!``<```"TW0$`%0```+S=`0`8````TMT!`!````#K
MW0$`&````/S=`0`2````%=X!``X````HW@$`&@```#?>`0`%````4MX!``<`
M``!8W@$`%P```&#>`0`7````>-X!`!@```"0W@$`#@```*G>`0`0````N-X!
M`!D```#)W@$`+0```./>`0`'````$=\!``<````9WP$`"````"'?`0`.````
M*M\!`!`````YWP$`#@```$K?`0`)````6=\!``@```!CWP$`"@```&S?`0`6
M````=]\!`!$```".WP$`"@```*#?`0`Q````J]\!``\```#=WP$`A````.W?
M`0`E````<N`!``L```"8X`$`"````*3@`0`0````K>`!``D```"^X`$`"P``
M`,C@`0`&````U.`!``L```#;X`$``P```.?@`0`&````Z^`!``8```#RX`$`
M%0```/G@`0`%````#^$!``X````5X0$`$````"3A`0`3````->$!`"L```!)
MX0$`"````'7A`0`"````?N$!``,```"!X0$`%````(7A`0`+````FN$!``L`
M``"FX0$`!P```++A`0`%````NN$!`!H```#`X0$`!P```-OA`0`&````X^$!
M``,```#JX0$`"````.[A`0`>````]^$!``L````6X@$`!P```"+B`0`)````
M*N(!``4````TX@$`"0```#KB`0`&````1.(!``4```!+X@$`!@```%'B`0`-
M````6.(!`!````!FX@$`"@```'?B`0`.````@N(!``4```"1X@$`$0```)?B
M`0`)````J>(!``<```"SX@$`&@```+OB`0`L````UN(!`%`````#XP$`,```
M`%3C`0`Q````A>,!``<```"WXP$`"@```+_C`0`$````RN,!``D```#/XP$`
M"0```-GC`0`7````X^,!``H```#[XP$`!@````;D`0`-````#>0!``8````;
MY`$`!````"+D`0!&````)^0!`$0```!NY`$`0P```+/D`0`B````]^0!``4`
M```:Y0$`%0```"#E`0`+````-N4!``<```!"Y0$`"````$KE`0`6````4^4!
M``\```!JY0$`%0```'KE`0`'````D.4!``0```"8Y0$`$P```)WE`0`$````
ML>4!``H```"VY0$`&P```,'E`0`&````W>4!``D```#DY0$`!0```.[E`0`(
M````].4!``\```#]Y0$`!P````WF`0`3````%>8!`!0````IY@$`$P```#[F
M`0`(````4N8!``D```!;Y@$`!0```&7F`0!$````:^8!`#4```"PY@$`/@``
M`.;F`0`L````)><!`$L```!2YP$`10```)[G`0`Q````Y.<!`%(````6Z`$`
M-P```&GH`0`Z````H>@!`"0```#<Z`$`$0````'I`0`6````$^D!``P````J
MZ0$`"````#?I`0`S````0.D!`$@```!TZ0$`*P```+WI`0!7````Z>D!`"<`
M``!!Z@$`*@```&GJ`0`(````E.H!``L```"=Z@$`"@```*GJ`0`'````M.H!
M`"\```"\Z@$`,@```.SJ`0`Y````'^L!``H```!9ZP$`&@```&3K`0`D````
M?^L!`!@```"DZP$`%0```+WK`0`'````T^L!`!````#;ZP$`#@```.SK`0`1
M````^^L!``\````-[`$`30```!WL`0"+````:^P!`'<```#W[`$`_@```&_M
M`0`3````;NX!`!8```""[@$`&````)GN`0`0````LNX!`!(```##[@$`%P``
M`-;N`0`&````[NX!`!P```#U[@$`%0```!+O`0`;````*.\!`!(```!$[P$`
M$0```%?O`0`5````:>\!`!@```!_[P$`-0```)CO`0!X````SN\!`!<```!'
M\`$`!````%_P`0`8````9/`!``D```!]\`$`!````(?P`0`,````C/`!`"0`
M``"9\`$`%@```+[P`0`-````U?`!`!(```#C\`$`$P```/;P`0`6````"O$!
M`#8````A\0$`-@```%CQ`0`T````C_$!`#0```#$\0$`,````/GQ`0`P````
M*O(!`!<```!;\@$`5````'/R`0`5````R/(!`!4```#>\@$`%0```/3R`0`5
M````"O,!`!0````@\P$`&````#7S`0`8````3O,!`!0```!G\P$`%````'SS
M`0`P````D?,!`!H```#"\P$`'````-WS`0`[````^O,!`!,````V]`$`!@``
M`$KT`0`.````4?0!`!\```!@]`$`%````(#T`0`5````E?0!`!,```"K]`$`
M&P```+_T`0`@````V_0!`!L```#\]`$`&0```!CU`0`=````,O4!`!0```!0
M]0$`'@```&7U`0`B````A/4!`!0```"G]0$`&P```+SU`0`9````V/4!`!,`
M``#R]0$`'@````;V`0`9````)?8!`!@````_]@$`&````%CV`0`*````<?8!
M`!4```!\]@$`!````)+V`0`$````E_8!``<```"<]@$`"@```*3V`0`0````
MK_8!``8```#`]@$`"````,?V`0`(````T/8!``8```#9]@$`"````.#V`0`'
M````Z?8!``4```#Q]@$`%@```/?V`0`&````#O<!``@````5]P$`!P```![W
M`0`$````)O<!``D````K]P$`!P```#7W`0`)````/?<!`!````!']P$`$```
M`%CW`0`*````:?<!`!,```!T]P$`!0```(CW`0`P````CO<!`!(```"_]P$`
M$````-+W`0`4````X_<!`!,```#X]P$`#`````SX`0`6````&?@!`#8````P
M^`$`"0```&?X`0`'````<?@!``@```!Y^`$`#0```(+X`0`,````D/@!``\`
M``"=^`$`!@```*WX`0`,````M/@!``T```#!^`$`!@```,_X`0`$````UO@!
M`!,```#;^`$`#@```._X`0`5````_O@!``X````4^0$`)0```"/Y`0`0````
M2?D!`!8```!:^0$`$````''Y`0`7````@OD!`"8```":^0$`&P```,'Y`0`2
M````W?D!``@```#P^0$``P```/GY`0`,````_?D!`"D````*^@$`!0```#3Z
M`0`&````.OH!``T```!!^@$`$0```$_Z`0`'````8?H!``8```!I^@$`!P``
M`'#Z`0`%````>/H!``T```!^^@$`#0```(SZ`0`,````FOH!`"````"G^@$`
M$0```,CZ`0`/````VOH!`!H```#J^@$`$P````7[`0`6````&?L!``4````P
M^P$`'P```#;[`0`$````5OL!`!4```!;^P$`3````''[`0`%````OOL!``T`
M``#$^P$`*````-+[`0`:````^_L!``\````6_`$`$P```";\`0`4````.OP!
M`!````!/_`$`#P```&#\`0`8````</P!`!````")_`$`%0```)K\`0`9````
ML/P!`",```#*_`$`)P```.[\`0`W````%OT!``L```!._0$`"````%K]`0`%
M````8_T!``T```!I_0$`#P```'?]`0`/````A_T!``0```"7_0$`"0```)S]
M`0`O````IOT!``L```#6_0$`"0```.+]`0`3````[/T!`&L`````_@$`$P``
M`&S^`0`*````@/X!``4```"+_@$`!@```)'^`0`:````F/X!`!D```"S_@$`
M&0```,W^`0`*````Y_X!``(```#R_@$`%@```/7^`0`S````#/\!``,```!`
M_P$`!0```$3_`0`7````2O\!``H```!B_P$`!0```&W_`0`(````<_\!`!H`
M``!\_P$`#@```)?_`0`&````IO\!``@```"M_P$`"````+;_`0`$````O_\!
M``4```#$_P$`'0```,K_`0!*````Z/\!``\````S``(`$@```$,``@`=````
M5@`"``0```!T``(`!0```'D``@`E````?P`"`#D```"E``(`#0```-\``@`*
M````[0`"`!$```#X``(`"@````H!`@`+````%0$"`!8````A`0(`&P```#@!
M`@`O````5`$"`"X```"$`0(`&P```+,!`@`B````SP$"`!````#R`0(``P``
M``,"`@`'````!P("``,````/`@(`"@```!,"`@`'````'@("``<````F`@(`
M$````"X"`@`$````/P("``X```!$`@(`%@```%,"`@`'````:@("`%H```!R
M`@(`#P```,T"`@`/````W0("``L```#M`@(`)P```/D"`@!=````(0,"`!L`
M``!_`P(`!P```)L#`@`C````HP,"`"D```#'`P(`"````/$#`@`'````^@,"
M`!L````"!`(`!@```!X$`@`)````)00"`"X````O!`(`+0```%X$`@`W````
MC`0"``D```#$!`(`!@```,X$`@`&````U00"`"P```#<!`(`9@````D%`@`7
M````<`4"`"0```"(!0(`%P```*T%`@`#````Q04"`!$```#)!0(`!@```-L%
M`@`4````X@4"``X```#W!0(`!@````8&`@`(````#08"``8````6!@(`!0``
M`!T&`@`(````(P8"``0````L!@(`#````#$&`@`-````/@8"``T```!,!@(`
M'0```%H&`@`=````>`8"``P```"6!@(`#@```*,&`@`*````L@8"`!$```"]
M!@(`.P```,\&`@`%````"P<"`!<````1!P(`%````"D'`@`7````/@<"``L`
M``!6!P(`$0```&('`@`1````=`<"``P```"&!P(`"P```),'`@`,````GP<"
M``H```"L!P(`(````+<'`@`5````V`<"`$P```#N!P(`$@```#L(`@`5````
M3@@"`!@```!D"`(`"P```'T(`@`-````B0@"`!D```"7"`(`"P```+$(`@`;
M````O0@"``@```#9"`(`%0```.((`@`#````^`@"``<```#\"`(`!0````0)
M`@`%````"@D"``@````0"0(`%@```!D)`@`7````,`D"`"0```!("0(`(P``
M`&T)`@`>````D0D"`!H```"P"0(`&P```,L)`@`B````YPD"`!L````*"@(`
M!@```"8*`@`&````+0H"`!(````T"@(`$@```$<*`@`0````6@H"`!0```!K
M"@(`#0```(`*`@`E````C@H"`!````"T"@(`4P```,4*`@`4````&0L"`"<`
M```N"P(`)0```%8+`@`9````?`L"``D```"6"P(`!@```*`+`@`'````IPL"
M`!0```"O"P(`$@```,0+`@`-````UPL"``P```#E"P(`$0```/(+`@`.````
M!`P"``P````3#`(`$0```"`,`@`0````,@P"``@```!##`(`"0```$P,`@`%
M````5@P"``<```!<#`(`!````&0,`@`$````:0P"``,```!N#`(`#0```'(,
M`@`1````@`P"`$@```"2#`(`-@```-L,`@`E````$@T"`"H````X#0(`00``
M`&,-`@`I````I0T"``P```#/#0(`0````-P-`@`V````'0X"`#D```!4#@(`
M.0```(X.`@`^````R`X"`!@````'#P(`&P```"`/`@`2````/`\"`!H```!/
M#P(`%````&H/`@!`````?P\"`"````#`#P(`$P```.$/`@`<````]0\"`"``
M```2$`(`%````#,0`@`3````2!`"`!8```!<$`(`&@```',0`@`[````CA`"
M`#L```#*$`(`/P````81`@`T````1A$"`#L```![$0(`.````+<1`@![````
M\!$"`!X```!L$@(`&````(L2`@`/````I!("``T```"T$@(`&@```,(2`@`,
M````W1("`!(```#J$@(`.````/T2`@`S````-A,"`"H```!J$P(`(@```)43
M`@`-````N!,"`%,```#&$P(`3````!H4`@`&````9Q0"`!X```!N%`(`%@``
M`(T4`@`+````I!0"``\```"P%`(`%@```,`4`@`'````UQ0"``D```#?%`(`
M"0```.D4`@`.````\Q0"``H````"%0(`#P````T5`@`'````'14"`!,````E
M%0(`!0```#D5`@`F````/Q4"``T```!F%0(`"````'05`@`*````?14"``8`
M``"(%0(`%````(\5`@`2````I!4"`!$```"W%0(`1````,D5`@`"````#A8"
M``4````1%@(`$````!<6`@`%````*!8"``<````N%@(`%0```#86`@`&````
M3!8"`#T```!3%@(`$P```)$6`@`C````I18"``0```#)%@(``@```,X6`@`S
M````T18"`!T````%%P(`&0```",7`@`X````/1<"`"8```!V%P(`)@```)T7
M`@!=````Q!<"`"`````B&`(`30```$,8`@`J````D1@"`!8```"\&`(`"0``
M`-,8`@`7````W1@"``<```#U&`(`#P```/T8`@`/````#1D"``P````=&0(`
M%P```"H9`@`,````0AD"`!T```!/&0(`&P```&T9`@`%````B1D"`!,```"/
M&0(`"````*,9`@`,````K!D"`!L```"Y&0(`$0```-49`@`L````YQD"`!$`
M```4&@(`%P```"8:`@`5````/AH"`!$```!4&@(`'0```&8:`@`(````A!H"
M`!````"-&@(``@```)X:`@`9````H1H"`!0```"[&@(`$@```-`:`@`<````
MXQH"`!,`````&P(`$P```!0;`@`7````*!L"`!$```!`&P(`"P```%(;`@`(
M````7AL"``4```!G&P(`'0```&T;`@`&````BQL"`!D```"2&P(`"````*P;
M`@`5````M1L"``P```#+&P(`)````-@;`@`6````_1L"`#,````4'`(`'@``
M`$@<`@`.````9QP"``\```!V'`(`*@```(8<`@`;````L1P"``8```#-'`(`
M'P```-0<`@`&````]!P"``4```#['`(`&@````$=`@`)````'!T"``L````F
M'0(`)P```#(=`@`X````6AT"`"8```"3'0(`"@```+H=`@`I````Q1T"`!0`
M``#O'0(`#@````0>`@`>````$QX"`!0````R'@(`!0```$<>`@`'````31X"
M``L```!5'@(`"0```&$>`@`&````:QX"``@```!R'@(`!@```'L>`@`*````
M@AX"`!P```"-'@(`+0```*H>`@`Q````V!X"`"4````*'P(`,P```#`?`@`F
M````9!\"`$<```"+'P(`(0```-,?`@`G````]1\"`#X````=(`(`7````%P@
M`@`P````N2`"``<```#J(`(`"0```/(@`@`(````_"`"`!(````%(0(`"```
M`!@A`@`7````(2$"`!8````Y(0(`+````%`A`@`N````?2$"`!D```"L(0(`
M,````,8A`@`Z````]R$"``@````R(@(`'P```#LB`@`+````6R("``8```!G
M(@(`*P```&XB`@`.````FB("`!(```"I(@(`#@```+PB`@`3````RR("`!0`
M``#?(@(`"P```/0B`@`(`````","`!<````)(P(`!P```"$C`@`+````*2,"
M``T````U(P(`&P```$,C`@`A````7R,"`#P```"!(P(`"@```+XC`@`%````
MR2,"``<```#/(P(`!0```-<C`@`;````W2,"``\```#Y(P(`!0````DD`@`2
M````#R0"`!H````B)`(`!P```#TD`@`.````120"`!````!4)`(`$P```&4D
M`@`$````>20"``0```!^)`(`#````(,D`@`>````D"0"`%H```"O)`(`#P``
M``HE`@`*````&B4"`!4````E)0(`&0```#LE`@`8````524"`!(```!N)0(`
M%@```($E`@`4````F"4"`!<```"M)0(`$P```,4E`@`?````V24"``H```#Y
M)0(`*P````0F`@`@````,"8"`!8```!1)@(`%@```&@F`@`)````?R8"``D`
M``"))@(`"P```),F`@`0````GR8"`!(```"P)@(`$0```,,F`@`<````U28"
M`"X```#R)@(`!P```"$G`@`*````*2<"`!8````T)P(`#P```$LG`@`2````
M6R<"`!0```!N)P(`$````(,G`@!!````E"<"``H```#6)P(`'````.$G`@`5
M````_B<"`!H````4*`(`C0```"\H`@`Y````O2@"`",```#W*`(`!@```!LI
M`@!,````(BD"`%````!O*0(`20```,`I`@`3````"BH"`!$````>*@(``P``
M`#`J`@`=````-"H"`"(```!2*@(`)````'4J`@`'````FBH"`!T```"B*@(`
M"0```,`J`@`3````RBH"`"$```#>*@(`!P`````K`@`E````""L"`!X````N
M*P(`"@```$TK`@`&````6"L"`!````!?*P(`$0```'`K`@`<````@BL"``0`
M``"?*P(`"````*0K`@`+````K2L"`!````"Y*P(`$````,HK`@`7````VRL"
M`!<```#S*P(`"0````LL`@`&````%2P"`$`````<+`(`-````%TL`@`S````
MDBP"``8```#&+`(`!@```,TL`@`&````U"P"`!T```#;+`(`%@```/DL`@`L
M````$"T"``X````]+0(`$````$PM`@`D````72T"``,```""+0(`!@```(8M
M`@`1````C2T"``,```"?+0(`#0```*,M`@`:````L2T"``P```#,+0(`&```
M`-DM`@`?````\BT"`!(````2+@(`$@```"4N`@`+````."X"`!0```!$+@(`
M%0```%DN`@`&````;RX"``\```!V+@(`"P```(8N`@`2````DBX"``X```"E
M+@(`'P```+0N`@`<````U"X"`!<```#Q+@(`%P````DO`@!H````(2\"`"(`
M``"*+P(`/P```*TO`@`-````[2\"``<```#[+P(`"@````,P`@`;````#C`"
M`!0````J,`(`&0```#\P`@`B````63`"`!<```!\,`(`'P```)0P`@`5````
MM#`"`"````#*,`(`)````.LP`@`7````$#$"`"4````H,0(`$0```$XQ`@`O
M````8#$"`!,```"0,0(`)0```*0Q`@!R````RC$"`!4````],@(`+````%,R
M`@`S````@#("`)````"T,@(`)````$4S`@`@````:C,"`"D```"+,P(`)```
M`+4S`@`8````VC,"`"H```#S,P(`,0```!XT`@`D````4#0"`",```!U-`(`
M)````)DT`@!$````OC0"`"0````#-0(`-P```"@U`@`E````8#4"`"0```"&
M-0(`'0```*LU`@`+````R34"`%T```#5-0(`&````#,V`@!B````3#8"``<`
M``"O-@(`"````+<V`@`)````P#8"`!0```#*-@(`#P```-\V`@`W````[S8"
M`!L````G-P(`%@```$,W`@`(````6C<"``P```!C-P(`&P```'`W`@!J````
MC#<"`"\```#W-P(`'0```"<X`@!"````13@"`&T```"(.`(`2@```/8X`@"`
M````03D"``T```#".0(`,0```-`Y`@`Q`````CH"``H````T.@(`%P```#\Z
M`@`0````5SH"`!(```!H.@(`!0```'LZ`@`&````@3H"`$4```"(.@(`"```
M`,XZ`@`1````USH"`"0```#I.@(`6`````X[`@!F````9SL"`"X```#..P(`
M)P```/T[`@`U````)3P"`#@```!;/`(`*````)0\`@`4````O3P"`"L```#2
M/`(`)P```/X\`@`V````)CT"`!X```!=/0(`+0```'P]`@`W````JCT"`$0`
M``#B/0(`-P```"<^`@!$````7SX"`!L```"D/@(`!P```,`^`@`;````R#X"
M`!<```#D/@(`%0```/P^`@`)````$C\"`#0````</P(`#````%$_`@`*````
M7C\"``D```!I/P(`%P```',_`@`)````BS\"``8```"5/P(`%@```)P_`@`)
M````LS\"``@```"]/P(`!0```,8_`@`/````S#\"`!````#</P(`)````.T_
M`@`@````$D`"`!,````S0`(`-````$=``@`,````?$`"``<```")0`(`$@``
M`)%``@`;````I$`"``X```#`0`(`#@```,]``@`9````WD`"`"8```#X0`(`
M#@```!]!`@`@````+D$"`#8```!/00(`"````(9!`@`*````CT$"`!D```":
M00(`!P```+1!`@`(````O$$"`!,```#%00(`$@```-E!`@`2````[$$"`!$`
M``#_00(`!@```!%"`@`)````&$("``8````B0@(`"````"E"`@`)````,D("
M``T````\0@(`"````$I"`@`.````4T("``X```!B0@(`!P```'%"`@`0````
M>4("``8```"*0@(`%````)%"`@`#````ID("``4```"J0@(`$````+!"`@`?
M````P4("``L```#A0@(``P```.U"`@`A````\4("``4````30P(`!0```!E#
M`@!R````'T,"``8```"20P(`!@```)E#`@`<````H$,"`$8```"]0P(`'@``
M``1$`@`<````(T0"`%L```!`1`(`.P```)Q$`@!/````V$0"`"`````H10(`
M%0```$E%`@`&````7T4"``@```!F10(`#P```&]%`@`1````?T4"``@```"1
M10(`"@```)I%`@`/````I44"`!<```"U10(`$0```,U%`@`1````WT4"`!0`
M``#Q10(`"`````9&`@`*````#T8"`!T````:1@(`#@```#A&`@`:````1T8"
M``D```!B1@(`!0```&Q&`@`&````<D8"`",```!Y1@(`!@```)U&`@`N````
MI$8"``4```#31@(`!@```-E&`@`-````X$8"``8```#N1@(`#P```/5&`@`+
M````!4<"``<````11P(`%0```!E'`@`2````+T<"`!4```!"1P(`!@```%A'
M`@`9````7T<"``H```!Y1P(`"````(1'`@`'````C4<"``8```"51P(`$P``
M`)Q'`@`E````L$<"``L```#61P(`#@```.)'`@`H````\4<"`!@````:2`(`
M&@```#-(`@`)````3D@"``4```!82`(`"@```%Y(`@`3````:4@"``T```!]
M2`(``P```(M(`@`.````CT@"``D```">2`(`1P```*A(`@`E````\$@"`#H`
M```620(`*P```%%)`@`X````?4D"`"P```"V20(`9P```.-)`@`;````2TH"
M`"H```!G2@(`&P```))*`@`?````KDH"`"4```#.2@(`(0```/1*`@`E````
M%DL"`&`````\2P(`.````)U+`@!*````UDL"`%D````A3`(`+P```'M,`@`Q
M````JTP"`#@```#=3`(`/@```!9-`@!)````54T"`$(```"?30(`-P```.)-
M`@`K````&DX"`#$```!&3@(`+P```'A.`@`F````J$X"`#T```#/3@(`-0``
M``U/`@`B`@``0T\"`",```!F40(`&````(I1`@!*````HU$"`($```#N40(`
M,P```'!2`@`O````I%("`$````#44@(`6@```!53`@!0````<%,"`#D```#!
M4P(`=0```/M3`@`C````<50"`!<```"55`(`+````*U4`@`A````VE0"`",`
M``#\5`(`,P```"!5`@`?````5%4"`"H```!T50(`-@```)]5`@`;````UE4"
M`!$```#R50(`5`````16`@`K````658"`"T```"%5@(`)P```+-6`@`Q````
MVU8"`"(````-5P(`+0```#!7`@!9````7E<"`#4```"X5P(`5````.Y7`@`Z
M````0U@"`#P```!^6`(`3@```+M8`@!O````"ED"`%@```!Z60(`.0```--9
M`@`]````#5H"`$<```!+6@(`/P```)-:`@!*````TUH"`$0````>6P(`:P``
M`&-;`@`^````SUL"`'4````.7`(`10```(1<`@!I````REP"`&8````T70(`
M*@```)M=`@`_````QET"`"T````&7@(`+````#1>`@`P````85X"`'<```"2
M7@(`9@````I?`@!U````<5\"`,````#G7P(`&0```*A@`@`J````PF`"`#T`
M``#M8`(`,@```"MA`@!2````7F$"`"0```"Q80(`6P```-9A`@`N````,F("
M`"````!A8@(`"0```()B`@"]````C&("`!<```!*8P(`2@```&)C`@`C````
MK6,"`#T```#18P(`)@````]D`@`A````-F0"`#X```!89`(`"````)=D`@`%
M````H&0"``<```"F9`(`!0```*YD`@`'````M&0"``T```"\9`(`#@```,ID
M`@`4````V60"``4```#N9`(`#@```/1D`@`&`````V4"``4````*90(`$P``
M`!!E`@`!````)&4"`'D````F90(`"P```*!E`@`3````K&4"``0```#`90(`
M!P```,5E`@`&````S64"``4```#490(`!````-IE`@`4````WV4"``L```#T
M90(`$0````!F`@`,````$F8"``,````?9@(`!0```"-F`@`'````*68"``<`
M```Q9@(`$0```#EF`@`,````2V8"`!<```!89@(`!@```'!F`@`$````=V8"
M`!4```!\9@(`#````))F`@`#````GV8"`"T```"C9@(`!````-%F`@`'````
MUF8"``<```#>9@(`*0```.9F`@!&````$&<"`$(```!79P(`00```)IG`@`>
M````W&<"`#8```#[9P(`.0```#)H`@`D````;&@"`!L```"1:`(`)````*UH
M`@`M````TF@"`"8`````:0(`(P```"=I`@`M````2VD"`"D```!Y:0(`+@``
M`*-I`@`\````TFD"`"4````/:@(`)@```#5J`@`W````7&H"`#````"4:@(`
M*0```,5J`@`O````[VH"`"T````?:P(`)@```$UK`@`P````=&L"`"H```"E
M:P(`+````-!K`@`O````_6L"`"T````M;`(`)@```%ML`@`J````@FP"`"\`
M``"M;`(`(P```-UL`@`M`````6T"`#@````O;0(`.P```&AM`@`@````I&T"
M`"P```#%;0(`(@```/)M`@`^````%6X"`"D```!4;@(`+@```'YN`@`M````
MK6X"`"P```#;;@(`)@````AO`@!`````+V\"`"````!P;P(`*````)%O`@`J
M````NF\"`$,```#E;P(`+P```"EP`@`\````67`"``D```"6<`(`%P```*!P
M`@`<````N'`"`#4```#5<`(`(@````MQ`@`.````+G$"``\````]<0(`$P``
M`$UQ`@`+````87$"``H```!M<0(`'P```'AQ`@`&````F'$"``<```"?<0(`
M(@```*=Q`@`E````RG$"`"````#P<0(`*@```!%R`@`8````/'("``@```!5
M<@(`^````%YR`@`:````5W,"`"$```!R<P(`'0```)1S`@`(````LG,"``L`
M``"[<P(`%@```,=S`@`6````WG,"`!````#U<P(`)0````9T`@`'````+'0"
M`%,````T=`(`&@```(AT`@`:````HW0"``<```"^=`(`&0```,9T`@`,````
MX'0"`$P```#M=`(`"P```#IU`@`P````1G4"`!\```!W=0(`%0```)=U`@`8
M````K74"`!\```#&=0(`/````.9U`@`=````(W8"`!$```!!=@(`)P```%-V
M`@`3````>W8"`!0```"/=@(`%@```*1V`@`+````NW8"`!H```#'=@(`"```
M`.)V`@`L````ZW8"``@````8=P(`*0```"%W`@`O````2W<"``<```![=P(`
M&0```(-W`@`'````G7<"``@```"E=P(`"0```*YW`@!%````N'<"``<```#^
M=P(`$P````9X`@`3````&G@"`!0````N>`(`"@```$-X`@`*````3G@"``<`
M``!9>`(`%````&%X`@`'````=G@"``P```!^>`(`&0```(MX`@`-````I7@"
M`!D```"S>`(`&P```,UX`@`*````Z7@"``T```#T>`(`%P````)Y`@`&````
M&GD"`#0````A>0(`#````%9Y`@`0````8WD"``D```!T>0(``P```'YY`@`0
M````@GD"`!H```"3>0(`"P```*YY`@`#````NGD"``@```"^>0(`"````,=Y
M`@`'````T'D"``H```#8>0(`"@```.-Y`@`.````[GD"`"````#]>0(`"0``
M`!YZ`@`.````*'H"``T````W>@(`%P```$5Z`@`8````77H"`!$```!V>@(`
M/````(AZ`@`E````Q7H"`",```#K>@(`8P````][`@!C````<WL"`!<```#7
M>P(`#@```.][`@`T````_GL"``<````S?`(`%0```#M\`@!9````47P"`!(`
M``"K?`(`$````+Y\`@`)````SWP"``0```#9?`(`!````-Y\`@`1````XWP"
M`!X```#U?`(`!@```!1]`@`'````&WT"``<````C?0(`$P```"M]`@`'````
M/WT"`!<```!'?0(`%P```%]]`@`0````=WT"`$(```"(?0(`-````,M]`@`X
M`````'X"``4````Y?@(`&P```#]^`@`A````6WX"`!D```!]?@(`(@```)=^
M`@`1````NGX"``(```#,?@(`!````,]^`@`1````U'X"``4```#F?@(`#```
M`.Q^`@`@````^7X"``4````:?P(``P```"!_`@`.````)'\"`%8````S?P(`
M,@```(I_`@`W````O7\"`#L```#U?P(`'````#&``@!2````3H`"`$$```"A
M@`(`-@```..``@!8````&H$"`*$```!S@0(`/0```!6"`@!/````4X("`#H`
M``"C@@(`.0```-Z"`@`9````&(,"`"4````R@P(`,````%B#`@`O````B8,"
M`$(```"Y@P(`>0```/R#`@`H````=H0"`$@```"?A`(`)````.B$`@!'````
M#84"`"P```!5A0(`,@```(*%`@`I````M84"`"P```#?A0(`+P````R&`@`N
M````/(8"`"X```!KA@(`.````)J&`@`L````TX8"`#0`````AP(`+0```#6'
M`@!$````8X<"`%````"HAP(`30```/F'`@`N````1X@"`#4```!VB`(`&0``
M`*R(`@`C````QH@"`!@```#JB`(`>@````.)`@`)````?HD"`,L```"(B0(`
MD````%2*`@!\````Y8H"`"T```!BBP(`;@```)"+`@`=````_XL"`!<````=
MC`(`)@```#6,`@`3````7(P"`!,```!PC`(`%@```(2,`@`J````FXP"`$``
M``#&C`(`(0````>-`@`E````*8T"`'$```!/C0(`'````,&-`@`7````WHT"
M``L```#VC0(`!0````*.`@`&````"(X"``@````/C@(`!0```!B.`@`6````
M'HX"`!4````UC@(`&0```$N.`@`D````98X"`!0```"*C@(`$````)^.`@`/
M````L(X"``<```#`C@(`$0```,B.`@`2````VHX"``D```#MC@(`%````/>.
M`@`'````#(\"``@````4CP(`"````!V/`@`%````)H\"`!D````LCP(`$@``
M`$:/`@`*````68\"``P```!DCP(`&````'&/`@`,````BH\"`!$```"7CP(`
M"````*F/`@`,````LH\"``D```"_CP(`$````,F/`@`*````VH\"``X```#E
MCP(`%@```/2/`@`,````"Y`"``T````8D`(`$0```":0`@`4````.)`"`!T`
M``!-D`(`!@```&N0`@`%````<I`"`"@```!XD`(`'````*&0`@`+````OI`"
M`"P```#*D`(`%P```/>0`@`E````#Y$"`!H````UD0(`!````%"1`@`'````
M59$"``4```!=D0(`$0```&.1`@`*````=9$"``H```"`D0(`!P```(N1`@`'
M````DY$"`!D```";D0(`"0```+61`@`#````OY$"``(```##D0(`$@```,:1
M`@`-````V9$"``0```#GD0(`"@```.R1`@`6````]Y$"`!D````.D@(`!P``
M`"B2`@`F````,)("``(```!7D@(`!````%J2`@`#````7Y("`!(```!CD@(`
M&0```':2`@`*````D)("``H```";D@(`#@```*:2`@`:````M9("``L```#0
MD@(`$@```-R2`@`&````[Y("`"$```#VD@(`"0```!B3`@`7````(I,"`!<`
M```ZDP(`$@```%*3`@`"````99,"``0```!HDP(`#@```&V3`@`/````?),"
M`!````",DP(`+P```)V3`@`&````S9,"``@```#4DP(`%P```-V3`@`3````
M]9,"``4````)E`(`%@````^4`@`#````)I0"``L````JE`(`!P```#:4`@`0
M````/I0"``@```!/E`(`"````%B4`@`!````NP(```````"4`0``3P@``(D&
M``!^"```A@4``(`'```("````````*0%``"U!```(04```X&````````````
M`"`%``!1!```4P<``"$"``#-!0``=@(``*D#``!Q`P``````````````````
M\P8``)@%```*`@``0@8``)<%```""```E@,```````#0`0```````%````#U
M!@```````%0!```>`0```````+0!``#A`P```````,X(``!X!0```````.,$
M``!#`0``Q`0``'T%```G!@``W0````````!R!@```````+\"```9!@``!0<`
M`/P#``#V!0``)P```)8````C`0``M@,``),'````!```F`0`````````````
MD@(`````````````<0```&<$````````F@`````````N!```&P8``$H!``"4
M!0``<00``)@#```!!@```@,``,0!````````C@```.\"````````7P```,<!
M``"V!0``;0$``%4"``!?"```(P(``)$````S`P```````!D#````````````
M``````!:`0``>P```)`(```P!P``.P0``-L```!3!@``3P8`````````````
M(`<``#T&``#1!@``+P(``/<```">`@``1`4``+\&````````>````$T(```1
M`@``U`4``',"```@!@```````+$"``#Y`@``*0$``"L#```P`P``[@8``*8#
M```R`P``A@@```<$``#J`P```````&,'``#7"```L@4``+H!``!:!```````
M`'H"``",`@```````(4`````````-@8``,H"``!C````6P$```````"Q````
M@`0``-P$```:!0``#P8``/$%``"3`@``?@<`````````````^0,```````!K
M`0``AP<``,((``"8`````````&T#````````,P4``&@#````````&P,`````
M````````D@,``&H&``"'`0``O@(```````"6!`````````````#G`0``8`<`
M`&0(```^`0``3`<```P#````````)`@``````````````````-@"```4!@``
M`````.0"``"*`@``,00````````U!@``Y`@```````"'`@``208``'X`````
M````VP(``!(!``#-!```<0(``!`$````````]@<``/(&````````Z@8``(\`
M`````````````"8"`````````````/T!``"_`P``1````*X%``#<"```*`0`
M`*0(```R"```NP8``(L!```[`P``V@,````````5"````````/($``!.!@``
M?@0``#0!````````8P8`````````````*08`````````````$`,``+H```"6
M"```;08``%X#``#_!@``2`,``/L!````````:@@```````#5`@``S`8``*X`
M````````S0(``(8```!W````0P4``,,(``"B````<P8``.\#```3`0``C0,`
M``````!``P``_00``"L$```S"```C@0````````O"```^`8``$`!```1`P``
M[@$```````!A``````````8'``!Z!````````&@$````````5P4``"8#``!"
M````Y@(``(4$``"9!P``H0```,\#``!F!@```````*@`````````F04``!0#
M``!8"```YP@``(4'``"@`@``V@8``,@(``!>`@```````"4"``#[!@``70@`
M```````\!@``O@```/,#```O!0``$````'8$``!S````[P```+X#``#A!P``
M`````````````````````*`!````````+P<````````?`P``E@8```````#M
M`0``;P<```````"/!```N@<````````8!0``]04``!0```#@!````````%@'
M````````!08``)(%````````1@@```````"_"````````&,"````````````
M``````#9`P``^@(``-0!``#C"```A0(``',!``#R`P``E0(``%4```#F!@``
M'`8```4(``"N`@``=@$``-L#``"'!```)0```*0#````````?`$```````"O
M`P``_08``"L!```<!```C@@``+L(````````70(``*4#````````F@$``(<#
M`````````````!8!```Y!P````````````#>!P``,0@``+@%``"V"```````
M`&(&```:"```FP$``+D&```#!P``R@```/$```"W"```&`8``(P%``##`0``
M``````````!/!P``N0$``)\"``!!`P``NP0``!<```"D`0```````(0'``#)
M!0``)P<``,<$```<!P``4P(``'H%``".`@``"0`````````U"```$@(``/D`
M``#^!@``.`,``#("```%````FP@```````!'!0```@0``+\%``"G!0``````
M`-H"`````````````"`$``!7"```U@0```````!H`@``````````````````
M`````+T#``!6`0```````#\%``!?`P``A@(``"$'``"S"```S@(``,P!``"[
M`P``-0(``-,"``!I!```20$``)T$````````````````````````#P$``!,%
M``"%"````````,('``!2`P```````'0!```W`0````````````#,````$`@`
M`#T(```+````Z`8```X"```)`0``Q0$``/X$``!`!0``QP,``,8%``"`"```
MR00```````!U!@``308```````"B`0``DP$``&L&```H`P```````#L!``"9
M!@``^@8``&T$``!R!P```````%L'```Z!0``]0(``*,`````````9@<``!D"
M``"E"```:`8``&````!3"```L0<``&X&```W`@```````,$'``#-!@``O`4`
M`/<!``!'`@``NP`````````Y````TP4``!,```"I````Y`0``)(!``"C!0``
M?@(````(``#;`0``7@@```````#\`0````<``(8'``#U!```708````````+
M`@```````"0!``!6!P``<P,``(H%``#<`P```````$8&``"&`P``UP<``"D"
M```A"```CP4``$\$``#V`P``D@8``&H!``#*`P``S`<``$D#``"]`0``I`(`
M``````".!P``2@<``%\!``!Z!@``J`8``-,'`````````P$``*P%``!)!0``
MTP0``!4'```D````6P(``)D`````````>P<``+<"```\!```@@$``)@(``!$
M`P``````````````````9@$``*D(````````6@```$@&````````J`(`````
M``#\!@```````-4'``!B`@``=0,``%@%````````1P<``'$%``"2!```2`(`
M`/L%``"D````DP0``!$&`````````````%H&`````````````"$$```T`@``
M9@(``#\```#K`0``K0```&X$``!:`P``Y0,`````````````!`````H```#[
M!P```````&('``";!@```````'\'````````J`4``!X"``#>!@``D0$``'@#
M```9!0``V00``$4!```G`P```````#T```"=`P``?````)\$``"H!```````
M````````````6P8``)$#``!I`@``Y08``.<$```````````````````^!@``
M'@<`````````````H00``)T'````````)`<``%8%```E!P```````$@!``#J
M!P``F@,``$P"````````Z@0```````!M!P``-P0``+\$```B`P``C@4``!(%
M``"J`@```````-4````H`@`````````````>!@``:P```/@`````````````
M`)0(``#R`````````'D$`````````````&`"````````?P,````````M!```
MP`(``&<"``!!!0``4@8```````"N!P``4@(``+8```!:"```#P4`````````
M`````````'8#``"4`````````&X```"2````E0$``&<!``"*````Y`4`````
M``!E`P``0P0```````#.`0``^0<``!P(````````4@<``%`&``!&!P``````
M`.,&````````Y@$``&<&```X````+@4```````!\!````````*<#``"Q`0``
M[0<``"4!``#5`P```````/@%```T!@``K`<``*<```#7`@```````%,$``#?
M````908``)D!``"J"```*P<``#@!``"R`0``L@(``+,```#&!P```````%\&
M``"N!```#P,```````")`P``<`0```````#0!0``40,``&H%````````````
M`*X&``"$!@``LP$``!P```#%`@``````````````````^0$``-D&````````
M-@0```````">!```+@<``(T'``#L`P``G`0``'<!``"U!P``5P$``!T#```5
M!```;@,``'D!```I!0``F@4```````!D!@``T@$``$`$````````M0(``-8%
M``!\!0``'08``,\&``#@`P``Y@,```````#<!0``80@``*<(``#&!@``````
M`-\$```&`````````*`'``#@!@``XP```.\!``"T````JP4``#H"``#W`@``
M`````.((````````8P@``$8!``"9"````````!0%``````````````````#I
M`0``2P8``)X(````````$P,```````#_!P``C`@``,8`````````R@<``(L'
M``!Z!P``40<``#,```!B!```P`4```````""!```F@8``-X#```B"```:P,`
M``````!4"````````#(%``#J!0```````$4"````````SP<```````"?`0``
M,`0```````":"```H0$``#D#```,!P``50$``+<`````````B`0````````1
M````]`4``/X"``#!````R`0```````"0!P``60,``,@```!Y````````````
M``!6"``````````````Q````,P$``(L(``"<!0``%P0```````#T!P``````
M``````!9!```?`(``.T%````````20`````````3!@``100```D%```3!```
M``````````""`P``7`4``$H(```]!```P`$``"H!```-!@``(`,``)D"``!P
M`0``]0<```````")!P`````````````G!0``GP````````"W!@```@$`````
M`````````````%(``````````````"P$````````/P@``-4(``")!```````
M`!<%``#*!0``U@<``,L"``!*!0``]0,``&P$``!V"`````````````!I````
M8P$``(8$``"V!@``!04``$D$````````30<````````'!P``=0@``*<"``!5
M`P``"P8``!4"``#7!0``P````/P'`````````````"P%```'!@``````````
M``!-`0``0`(``/H$``#S!P````````````!P`@``$`$``)`&````````G@$`
M`%`!`````@``>@@``+$%```I!P``P@0``,P#```*!```1`0``'L$``"!`0``
MWP,``.`"``"$`0````````````#W!P``0P`````````8`@``=@4``)8!```[
M!@``!`(`````````````$0<``-$(````````7P0``'P&```U!```+@@``#4%
M```M`@``A`@``)L"``"Q!@``*`8```````!8`````````%0&``!S!P``````
M`"(&````````.0(``%`(```,`@``\0,``.P&```\`0`````````````W!P``
MH@<``&8#````````GP<```<```!9!0``W@@``*4!``!4`P``2P````````"J
M`````````$4%``!%`P``@0<``%D````X`@``N00``(@&````````(P4`````
M``````````````H%``!&`@``7`,``(P!````````[0,``!X`````````*P(`
M``````#^`0``YP4``)<````X!P``%0,``&P#`````````````#8#``#T!@``
M`````&X'````````Q0`````````&!@``T04```````#@`0``+0,``*P&``!&
M````@08``,L'``#H!0```````)X%``"*!@``<0$``-P!```"!@``2`@``!D`
M``#=!0```````.L"``"8!@``0@,``,L%``!<`@``(0```-$````O`0``1`<`
M`+\'``!T`@``'P$``!$!````````7@4``!8%````````*0```+,#``!_`@``
M%P,``.(&``"]!@``(P<``&@`````````Z@$``!\`````````X`4``'(````W
M!@``6P````````!#"```5P(`````````````5P<``/8!```R`0``+@(``'``
M```P`0```````.<&````````!P$``.P$``"D!@``+0```.8```!P"````P,`
M````````````3@```(,(```2`````````($$```K"``````````````3!P``
M<@0```````#B!0```````.D"``"R!```I@8``"D#``!T"```L`<``&$&````
M````?00``!\$```F!0```````,<'``!:!P``CP(``#`&```;"```=@8``&@%
M``#L````)@0```,&```A`P``-`4``+0#``!E!```"`$``.0```#6`0``[@(`
M`&L$``#]!P````````````"J`P``;@4``'H```!@`0``MP,``#($````````
M``````````""!0``Q00``$X!``"/`P``Q`@``````````````````-0"``">
M!P````````````!+`0``L`8``!8#``#R!0``[@````D(``"I!0``#`0``!($
M````````6P,``#P'```E!0`````````````R````/0(```L#``!4````````
M``````!_!```E00``!T%``#8!P``JP<``'`'``"M"```4@@```$"``"E!```
M,P0``"H'````````U`8```````##!@``^P0``&P&```*!P``?0```%8$``#Y
M!0```````*("``#.!```3P```-(#``#'````ZP0``````````````````,`'
M``#_!0``T`(``'H!``"Q!```60(``,\%``#W!```[P0```````!]!@``````
M`.$$``"`!@````````X$```F`0```````,,```"/`0``````````````````
MQ`4``+L!`````````````-@$```H!0```````($%``"W!P``N@0``*D"```@
M`0``0@4``*D$````````NP4``$X'````````JP(``,4#``!C`P``````````
M``!6`@```````)<&``"H`0```````"(%```3"````````/`'```T`P``````
M``````"C!```=P0`````````````````````````````Q@$``/`````K````
M`````/("``#5!0``#0(```,"``#'!0``8`,```````#!`P``H@4``%4$```M
M"```!`0```````#3`0```````-L&``#T`````````$T```#?"```:08``)X&
M````````;0@``,D"```5!@``3`@``"\#``":`@````````````!<!P``/P0`
M``````#J`````````)T```"A!@``@P```*L#``#-!P``&@0```````#U````
M_`0``(T%``#V!````````)T%``"U!0``W0<```````#^````'P4``/T%````
M````G0(``/`"````````Y@<``-\%``#H!```Q@0``-L'``!G`P``H@8``$`(
M```/````"@8```,(````````KP(```````#X`@``.P<````````X"```E04`
M``4$``#;!```9@0``#<%``!?!0``IP$```````#&`P```````/X'``"("```
M,0(``"('``"3!@``+P8``,,%`````````````(,!``!"`0``U`0``)@!```<
M`@``U@(``-<#```X!0``1`8``#8!``#3`````````#P#```Q`P``+`$``$4`
M``#7!```/`@```0#``#2!@``9@@``(T"``````````````````#.````````
M``$(``!@"```,`````P````J!@``&0@``+T"```_!P``K@$``"<$``"8`@``
MK`$``-`'``#B`0```````'<#``"^`0```````$L$```^`````````.4"````
M````90(``$$'```"!P``\08``(,"``!O`@``70```",#``"M`@``>0<``)T!
M````````)`(````````Y!0``V`8``$<$```'`@``-`0``(`"``"L!```VP@`
M`$D"````````Y00```````!:`@```````"0&``"M!@``@`,``+0%````````
M`````"X```![`@``S`4``(,#`````````````%4'``#4```````````````W
M````?0,``#P```!?!P``5P0``"H"```Q!P``E@4``!$%``"*`P``J0$``/4!
M``"+!@``-@```'L!````````C00``/<#```)!@````````8#```J!```!`<`
M`$("````````;`<``+8"``!5!@``Z@(``$X%````````S`0``,\"``!_!0``
M.08``$<!````````2P4``'P'``#M````+`,``%X&`````````````'@$``#I
M!@``>`@``-,(```-`P``3`$``,4'````````PP,``+`$```Z````%`0``)P"
M``!@!0```````.D#``"4`@`````````````T"```<@,``%,!``!4`@``D@<`
M`%P(``"E!@``\@$``+8!````````XP4``)`$``#Q!P``FP```%8&``"F"```
M.@8``-`#```@````B@$``,,"``!K"```+@,``!X#``!-`@``_````.(```!3
M!0``G@```!8```"]!```T0,``-D(`````````````)P#``")"```,@<``(P#
M``!&!0```P4``((```#Q`@``O0```,X%```Y"```WP$``!H&```Z`P``/0<`
M`'4"````````00(``"L%``!F!0```````(<(```6!```)@<```````#$````
MQ08``&X(``!P`P``U@@`````````````Z0````````!8`@``N0<```````"[
M!P``!`8``&\```#F"```O````'0&``!Y`P```````.X%````````60<``,`#
M```O````D`,``)0'``"(!0``L`@``%D!```F"```O`@``,@"``#M`@``````
M`*L!``!'"```+`@``*\&``"8!P``T`8``&0!``#T!```.P````````"-!@``
MRP$``$L"``"B`P```````"T!``!,!@``Z`$``!$(``!Y!@```````-@(````
M````E`,``-@%``!!`0``RP8``'8'```0!P```````-<&```_`@``Z`,``-@!
M``"-"`````````````!J`P```````*````#"`@``T0<`````````````]`,`
M`#4!``!B`P``ZP,`````````````P`0``*((``#1!```T0(`````````````
M:0,``#X'````````!0$``-D'````````.0$``*0'``"%`0``````````````
M!@``Y`,``%H%``!0!```>P@````````>"```%0$```````":!```#`$``/D&
M`````````````,4(``"1!P``!P4``'<&```G"```-````#T!````````*```
M`%L$`````````````'`%```J````5@,```````#\!0``[@0````````7!@``
MN@4```H(``"$!```700```````"5`P``@0,``&0"```6"```AP8``",(``#$
M!P``#@<``'T!``"5!@``O0<``(0%``!#!@```````$,"```/!P```````/P"
M``#.!P``J@8``.("```D!```$@,```````#W!@````````````"T!@``EP0`
M`',%``!.`P`````````````?!P``H0@``-P"```!!```K00``%D&````````
M9`0``#@&``!K!P``1`$``'<%``"A!P``R@0``&X"``!D!0```````+('``"^
M!0``P@$``````````````````&D(````````I@(``-\'````````XP$``,L(
M````````6P4``%@!```0!@``I0<``$P$````````%`<``-X!````````````
M`!T!``!Y!0``I`0``.L```!)!P``HP8``+D"````````(08``&T````T!P``
M@@<``&$#``"O!```O@@```````"#!```GP8``$($``!]!P``D0@``-<```!&
M!```M`@``),`````````C@8``",$```2"```^`0``,L$````````7````,$"
M``"Y`P``5P```'T(``````````$``.<"````````)0@``(0"``!F````SP``
M`)`%``!_````00```(P```#G!P````````````"S!@``8@$``+<!``#:"```
MFP0``*L&````````B0(``-L%``"E!0``U@````````#]`````````.,#````
M``````````````"1!@``P@4`````````````&P4``/D$```>!```T@<`````
M``"@!@``K`@``/H!`````````0$``"H#``#-`P```````"4&``"Z!@``-0,`
M`'T"````````KP<``/0!``#E!0``````````````````W0(`````````````
M_P0``*4```"M!P``2`<``(H(``#W!0``3@@``"T&``"5"```<08``.4!```-
M`0``3@(```(%```6!P``N`,``'4````^!```I@$`````````````70,``$P%
M``!D`P``C`8```````"!```````````````K!@```````#,"``!7`P``<P@`
M`,0#``#3!@``X@0```````"-````QP(```````!'`P``N````*@(``#]`P``
M#0<`````````````_P(``%P$````````)@```+X$````````C0$``+P#````
M````]@(``,D#```;`0``&P<``'(%``"*!P```````$4(``#G````@0(`````
M`````````````#P"``#:!```(@$```````"G!@``B@0``!(&``#H````3```
M``@%````````'`4``'0%``#.!@``*@@```````!(!```MP0````````,!0``
M`````)<!```W`P``^P(``)<"````````&`0``$T#```O!````````-P&```)
M`P````````````!'!@````````````!1`@``JP@``````````````0,``#4`
M``"(`P``!@4``$4&````````A04``+@"``"9`P``KP@``%@$``"9!```8@4`
M`.\'``"L`@``/P$``*T#``#0!```1P````````"J!P```````.$(``"+`P``
MHP<```````"'!0```````&\&``#V!@```````.(#```#`````````(4&``"?
M"```!`@``+0"``#S!````````(L$````````X````%P&``")````````````
M```6!@``:`<``#H(``!2`0```````#8(``#N!P``^P,``-T&``!0!P``LP<`
M`&$"``"+````Q`8```````#9`@```````*T!``#(!P``M@<``(,%````````
M)00```````"K!```:`$``!`"``".`0```````,`&``"A`@``T0$``$H#````
M````@@(``$H&``#=`P``=P(``'0```!?`@``ZP4```X```#"!@``_P,`````
M```1!```D`$```````#7`0```````-T$``#&`@``+`(``/,```!>!P``M08`
M````````````D04````````^`P``'`,```P(``"7!P``2@(``%L(``"_````
M2P<``!H'``#$`@``;P0``%D(``!""```704``"P&``"]"````````+4#``!A
M!0```````$@```#Z!0``Y`$``-4!``!#`P``O04``#(&````````7`$``!4%
M````````'P8``````````````````(@```````````````````"O!0``````
M`!<'``#P`0``Q@@``'@"````````@0@``+@&``#)`0``XP(``!4`````````
M`````$4'````````#P(``-(```"<"````````)L'```Z!```@`$``'<(````
M````G`8``"T%```C````@P<``),(```]`P``)0,``.$%```I"```&`,`````
M```8````:P4```````````````````````"C`0```````&$$``#"`P``;P,`
M`#8%````````D`````````#:`````````)4````G`0``&@(``(L%````````
M``````````!G"```<`8``,\(`````````````$0(````````````````````
M````'0```*($````````_@,``+8$``#2!0``,04``'\(``!G!P``,`4`````
M```.`P``6`8``.T&````````SP$``+,"```(!P``R`8``+@'````````;P4`
M`),#````````.@<``*H!``"'````/@(````````W"```WP(`````````````
M9P4```<#`````````````*@'``#"````2P,``/('``!4!````````!@'```S
M!P``Z00``!L$``#@"```"@,```````!Z`P``:0$``)<(``````````````L%
M``"F````&00``.('``!)"```!@(```````#G`P``!@0``'4!``!M!0``````
M`#X(````````Y0<``*\!``#Q!```3P,```````!/`@``V0$``*,#``#=`0``
MB`$``.`'``!1"```L@```!L"````````T@@``!0"``"F!0``8P0```("``#,
M`@``Y@0```````"?`P``L`(``/@#````````_@4``,L#```L`````````"$!
M``!X`0``K````/T"````````7@```.8%``#'!@``X0$``"@'``!8`P``BP(`
M`'8`````````N`0````````[`@``C`<````````+`0```````#$!````````
M````````````````````````````````R@8``&`$`````````````#X%````
M````N`@``&\(``"3!0``#00``%`#``"P!0``000``#8'```B!```L@,``%0'
M```!!0``#`8``$$(``#4!P``5P8```,$``"`````)`4``-X$``"?!0``N@@`
M``````#*`0````````L(``#4"`````````````#Z`````````-\&``!^!0``
M>P4```D$```D`P``\`8``-D```#(!0``^`$``.T$``#*"```````````````
M````;P$``-T(``#_````M0```$H$``!`!P``L0,``%$&```-"````````+P$
M``!^`P``=`<``$T%``#V````'@4``'P#``"(!P``MP4````````G`@``8@``
M`.@"``"N`P``%@(```````````````````\(```_`P``<P0``&D%``#D!@``
M300``"8&```=!```R0@``+`#``!T!```E`8``&P```#>````0@<```````#>
M`@``0```````````````&0$```````!6````<@$``%,``````````````-@`
M``!C!0``T`````````#`"```=P<``*<$```:`0```````)T(````````````
M``````"Y!0````````````````````````````!4!0``"0(```````#P!0``
MU00``/L```!Q"```4@0``,L`````````S0@`````````````S0$`````````
M````.P4``,,'``"1`@``K@@``&P!````````J08``-8&``!Y"```H`4``&X!
M``!=!P``J@4``%X$``!U!P`````````````B`@``````````````````CP8`
M`"(`````````HP(``*T%`````````````&L"```4"```PP0`````````````
M````````````````'0<`````````````:0<``,$&````````Y0@````````&
M`0`````````````N`0``A@$```<(``#0"```"``````````$`0``2`4``'@'
M````````H`0```````!1`0``P00```````````````````T````J!0``[@,`
M`#@$````````"`0``/,%``#P`P``Y0```.$"```="`````````````"6!P``
M80$``!('``#C!P```````&$'````````V@4``'P(````````[`4```````"\
M!@```````"D$``#>!0`````````````-!0``"0<```````"P````.@$``-,#
M``!5!0``"`8``*H$``#L`0``;`4``'\!`````````````$X$``!=`0``````
M`'D"````````A`,``.\&``"K````=00``)X#````````/04``*$%``#P!```
M@@8`````````````4`4```````#-````,`(```````"\!P``G`$```````".
M`P``G08``*$#``!/!0``3P$``+P"```U!P``'`$```````!1````7@$``)L%
M```?"```:@```!,"````````9````-("``#(`P``I@0``+,%``"5!P``\P(`
M`!D'``#9!0``J0<``#8"``"U"````````!@(``!J!P``P0@``)H'````````
M``4```0%```.`0``E`0``.$&``!0`@````````````"F!P``&@,``(D!``"@
M"```ZP8``-H!```+!P```````#`(``![!@```````(((``"P`0``>P,``-4&
M``#T`@``M0$``$H```!T`P``R08``(8&```C!@``#@4``+,$````````[P4`
M`(`%``"%`P```@```&H$```Q!@``SP0``!@!``#%!0``M`<`````````````
M`````#P%```/!```^`<``,D'``#A`````````%$%````````J`,``/,!``"#
M!@```````(\(````````:@(``$0"````````S@,``$P#``"0`@``OP$``#,&
M```."```D@@`````````````<0<```8(```7"`````````````#L`@``````
M``H!````````G`<``(D%````````P04``"@!``!#!P``8@@`````````````
MHP@``````````````````&4(```H"````````"X&`````````````!<"``!M
M`@``D00``&<```"^!@``EP,``!<!``!5"```.00```````"<````K`,``)8"
M``"\`0``_P$``&4'``#D!P``$`4``(@"``#Q`0``N0@``&0'``"$````````
M`+X'``!E`````````+$(````````'0(``'\&``!R`@``L@8``*\`````````
M0`8```````"@`P``QP@``````````````````-P'```;````.P@```@#```@
M`@``;`(```````"R"```Z`<``!\"``#6`P````````````!U!0``````````
M``!^!@``T@0````#```@"```>`8``-H'```L!P```````+D`````````I0(`
M`/H#``!2!0``&@```&4%``"Z`P``008``,@!``!+"```M`0```````"G!P``
M``````````"/!P``+0<``.D'````````W`````````!@!@````````````!H
M"```!0,``.P'```(`@``V`,``&P(``#,"```/P8``+@!``!&`P``%`$`````
M```+!```?@$`````````````!0(``/H'``"Z`@``C`0``.L'``#I!0``````
M``$'````````4P,``,$!``";`P``U`,``&4!``!R"```R0`````@*"5S(&1A
M>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y
M*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A
M(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@
M:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B
M('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F
M34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@
M)7,`)60@8V%L96YD87)S(&9O=6YD`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S
M=V]R9"!E>'!I<F5S+@`E9"!E=F5N=',`)60M9&%Y(&9O<F5C87-T`"5S("T@
M3F]T:6-E`"5S($1A>2AS*2`E<R!(;W5R*',I("5S($UI;G5T97,`)7,@1FEN
M9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G
M<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@871T
M96YD965S`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS
M*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q
M=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S
M`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D
M`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E
M;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`*$-L:6-K(&]N
M(&-A;&5N9&%R(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB
M:6QI='D@:6X@=&AE(&UA:6X@=VEN9&]W*0`J($%D9"!T:&5S92!B>2!C;&EC
M:VEN9R!!9&0@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`L(&=U
M<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,`+2T@<V5L96-T("TM`#$@871T96YD964`,2!E=F5N=``Q(&AO=7(`,3(@
M2&]U<B!&;W)M870`,34@;6EN=71E<P`R,"!M:6YU=&5S`#(T($AO=7(@1F]R
M;6%T`#(T(&AO=7)S`#,P(&UI;G5T97,`/%!R979I;W5S`#QS=')O;F<^071T
M96YD965S/"]S=')O;F<^("AO<'1I;VYA;"D`/'-T<F]N9SY$97-C<FE?<'1I
M;VX\+W-T<F]N9SX@*&]P=&EO;F%L*0`\<W1R;VYG/DME>7=O<F1S/"]S=')O
M;F<^("AO<'1I;VYA;"D`/'-T<F]N9SY296-U<G)E;F-E/"]S=')O;F<^("AO
M<'1I;VYA;"D`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T
M:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+@!!30!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H
M;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES
M(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P=&5D
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO
M;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG
M`$%D7W9A;F-E9"!396%R8V@`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI
M;&0@4&5R;6ES<VEO;@!!9&0@179E;G0`061D($AE<F4Z`$%D9"!.97<@1W)O
M=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E
M<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!2
M96UO=&4@0V%L96YD87(`061D(&$@;F5W(&5V96YT`$%D9"!A(&YE=R!U<V5R
M.@!!9&0@871T96YD965S`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D
M9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!
M9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@871T96YD965S`$%D9"!T;R!M
M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES
M=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O
M<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E
M<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9'9A;F-E9"!3
M96%R8V@`069G:&%N:7-T86X`06QA<FT`06QA<FT@)60@9&%Y<R!B969O<F4`
M06QA<FT@)60@:&]U<G,@8F5F;W)E`$%L87)M("5D(&UI;G5T97,@8F5F;W)E
M`$%L87)M("5D('=E96MS(&)E9F]R90!!;&%R;2`Q(&1A>2!B969O<F4`06QA
M<FT@,2!H;W5R(&)E9F]R90!!;&%R;2`Q(&UI;G5T92!B969O<F4`06QA<FT@
M,2!W965K(&)E9F]R90!!;&%R;2!$871E`$%L87)M(%-P86X@*&UI;G5T97,I
M`$%L87)M(%1I;64`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N
M;65N=#H`06QL`$%L;"!!='1E;F1E97,`06QL($%U=&AE;G1I8V%T960@57-E
M<G,`06QL($9U='5R90!!;&P@1W)O=7!S`$%L;"!087-T`$%L;"!097)M:7-S
M:6]N<P!!;&P@5FES:6)L90!!;&P@9&%Y`$%L;"!D87D@979E;G0`06QL(&5V
M96YT<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`
M06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E
M>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S
M<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL
M(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`
M06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D
M+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L
M80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`
M06YT:6=U82!A;F0@0F%R8G5D80!!;GD`07!P;&EC871I;VX`07!P;&EC871I
M;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@
M4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@
M*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE
M`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE
M=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA
M`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L
M86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/P!!<W-I9VYM96YT(&-O;'5M;G,`070`071T86-H960@:7,@86X@:4-A;&5N
M9&%R(&9I;&4@=VET:"!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('1H92!E=F5N
M="X@268@>6]U<B!M86EL(&-L:65N="!S=7!P;W)T<R!I5&EP(')E<75E<W1S
M('EO=2!C86X@=7-E('1H:7,@9FEL92!T;R!E87-I;'D@=7!D871E('EO=7(@
M;&]C86P@8V]P>2!O9B!T:&4@979E;G0N`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+@!!='1E;F1A;F-E`$%T=&5N9&5E<P!!='1R:6)U=&5S`$%U
M9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F
M='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE
M(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L
M92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D
M871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F
M86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL
M86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U
M;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A
M9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC
M<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)A<VEC(%-E
M87)C:`!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU
M=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N
M;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI
M=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M
M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,
M:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$)U<WD`0TU3`$-20P!#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<P!#7V%L96YD87(`0U]E;&P@4')O<&5R=&EE<RXN
M+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86Q?96YD87(`0V%L
M96YD87(`0V%L96YD87(@4W5M;6%R>0!#86QE;F1A<B!S=6-C97-S9G5L;'D@
M<'5R9V5D+@!#86QE;F1A<G,`0V%L96YD87)S(&UU<W0@:&%V92!A(&YA;64N
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E
M>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<P!#86XG="!C<F5A=&4@82!N97<@979E;G0N`$-A;B=T
M(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M
M(%)E<&]R=`!#86YC96QL960`0V%N8V5L;&5D.B`E<P!#86YN;W0@9&5L971E
M(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T
M96=O<E]Y`$-A=&5G;W)I97,@86YD($QA8F5L<P!#871E9V]R>0!#87EM86X@
M27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I
M;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#
M96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E
M<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC
M871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L
M:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO
M=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT
M(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO
M;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U
M<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!I
M9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD
M(&1E;&5T960@979E;G1S(&)Y(&5M86EL.@!#:&]O<V4@:68@>6]U('=A;G0@
M=&\@8F4@;F]T:69I960@;V8@;F5W+"!E9&ET960L(&%N9"!D96QE=&5D(&5V
M96YT<RX`0VAO;W-E(&EF('EO=2!W86YT('1O(')E8V5I=F4@96UA:6P@<F5M
M:6YD97)S(&9O<B!E=F5N=',@=VET:"!A;&%R;7,Z`$-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=&AE(&%D9')E
M<W,@8F]O:W,@=&\@<V5A<F-H(&9O<B!F<F5E+V)U<WD@55),<SH`0VAO;W-E
M('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!I;B!Y;W5R(&9R964O8G5S>2!I
M;F9O<FUA=&EO;CH`0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!W
M:&5N(&=E;F5R871I;F<@9G)E92]B=7-Y(%523',Z`$-H;V]S92!Y;W5R(&1E
M9F%U;'0@8V%L96YD87(N`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A
M9W,`0VQE87(@475E<GD`0VQE87(@86QL(&%T=&5N9&5E<P!#;&5A<B!O=70@
M=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@
M3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L
M;W-E(%=I;F1O=P!#;&]S92!W:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#
M;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A
M<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K
M97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC
M<P!#;VUM82!S97!A<F%T960@=F%L=65S`$-O;6UA;F0`0V]M;6%N9"!3:&5L
M;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E
M<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA
M<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F
M(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F9I<FT@
M9&5L971I;VX@;V8@979E;G1S/P!#;VYF:7)M960`0V]N9V\`0V]N9V\L(%1H
M92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE
M9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E
M<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#
M;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@
M(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F
M86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<'D@=&AE(%523"!B96QO=R!F
M;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y(%523#H`
M0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N
M("5S`$-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E
M='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@
M8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@
M;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO
M="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R
M<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E
M($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R
M971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R
M="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@
M;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`
M0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG
M=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U
M;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U
M<G-E<P!#<F5A=&4`0W)E871E($-A;&5N9&%R`$-R96%T92!A($YE=R!%=F5N
M=`!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F
M;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R
M9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0`0W5R<F5N="`T(%!H87-E
M<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I
M<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I
M=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER
M:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H
M<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E
M=F5R>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A
M=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1A>2AS*0!$95]L971E
M`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L
M:6YE9`!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-A;&5N9&%R
M`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL
M`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@)7,`1&5L971E($-E;&P`1&5L
M971E($5V96YT`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M
M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`
M1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T
M92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(&5V96YT(&]N;'DL('1H
M:7,@;V-C=7)R96YC92!A;F0@86QL(&9U='5R92!O8V-U<F5N8V5S+"!O<B!A
M;&P@;V-C=7)E;F-E<S\`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D
M('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N
M;6%R:P!$97-C<FE?<'1I;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I
M<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_`$1I<W!L87D@0V%L96YD87)S`$1I<W!L87D@3W!T:6]N
M<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@
M*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@=&\@<VAO=R!T87-K<R!W
M:&EC:"!A<F4@9'5E(&]N('EO=7(@8V%L96YD87(_`$1O97,@;F]T(')E8W5R
M`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E
M<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO
M860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`1'5E.B`E
M<P!$=7)A=&EO;@!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R
M+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$52
M4@!%8W5A9&]R`$5D:70`161I="`E<P!%9&ET($%T=&5N9&5E<P!%9&ET($)L
M;V-K`$5D:70@0V%L96YD87)S`$5D:70@1W)O=7``161I="!097)M:7-S:6]N
M`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I
M="!296UO=&4@0V%L96YD87)S`$5D:70@871T96YD965S`$5D:70@8V%T96=O
M<FEE<R!A;F0@8V]L;W)S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T
M:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA
M:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@
M=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC
M;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N7V0`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O
M;G1E>'0@;65N=3\`16YD($1A=&4`16YD($]N`$5N9"!4:6UE`$5N9"!Y96%R
M`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E
M<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R
M;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC
M:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T
M=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!F;W(@)7,Z("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D
M.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@
M(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V96YT(&%D
M9&5D.@!%=F5N="!D96QE=&5D.@!%=F5N="!E9&ET960Z`$5V96YT(&9R;VT@
M)7,@=&\@)7,`179E;G0@;F]T(&9O=6YD`$5V96YT<R!M=7-T(&AA=F4@82!S
M=&%R="!D871E+@!%=F5N=',@;75S="!H879E(&$@=&ET;&4N`$5V97)Y(#$U
M(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E
M<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R
M>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N
M9"!.86UE<P!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@
M8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A
M=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R="!#86QE;F1A<@!&1R!#;VQO<@!&
M5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O
M;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E
M<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA
M;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X
M`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3
M:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#
M05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA
M;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N`$9I;'1E<G,`1FEN9`!&:6YL86YD`$9I<G-T($AA;&8`
M1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E
M<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&
M;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T
M(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H
M97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R
M('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE
M<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E
M`$9R86YC92P@365T<F]P;VQI=&%N`$9R964`1G)E92]"=7-Y($EN9F]R;6%T
M:6]N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`1G)I9&%Y`$9R;VT`1G)O;2!T:&4@`$9U;&P@
M1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=71U<F4`1V%B;VX`
M1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=A
M;64`1V5N97)A;`!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E
M9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@
M3F%M90!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!';W1O
M("5S`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N
M;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`
M1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM
M`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI
M`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H
M97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&ED90!(
M:61E("5S`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N
M90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L
M:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D
M92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S
M("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E
M("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I
M>F]N=&%L.@!(;W5R*',I`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I`$AO=R!L;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T
M:&4@9&%Y(&%N9"!W965K('9I97=S(&)E/P!(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!D87ES(&]F(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B!S:&]U;&0@=V4@9V5N97)A=&4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU
M;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?
M;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BX`268@>6]U<B!E;6%I;"!C;&EE;G0@9&]E<VXG="!S=7!P;W)T(&E4:7`@
M<F5Q=65S=',@>6]U(&-A;B!U<V4@;VYE(&]F('1H92!F;VQL;W=I;F<@;&EN
M:W,@=&\@86-C97!T(&]R(&1E8VQI;F4@=&AE(&5V96YT+@H*5&\@86-C97!T
M('1H92!E=F5N=#H*)7,*"E1O(&%C8V5P="!T:&4@979E;G0@=&5N=&%T:79E
M;'DZ"B5S"@I4;R!D96-L:6YE('1H92!E=F5N=#H*)7,`26UA9V4@4')E=FEE
M=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM
M86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@
M0V%L96YD87(L(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O
M<G0@0V%L96YD87(`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD
M<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L
M(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN
M<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R
M="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!)
M;G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O
M;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G
M97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E
M9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI
M<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:
M25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$
M+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E
M(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?
M='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M
M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN
M=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L
M:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L
M:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F
M($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)
M=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R
M+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@
M0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H
M=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E
M<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`
M2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4
M>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N`$ME>7=O<F1S`$MI9',`2VER:6)A=&D`2V]R96$L($1E
M;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC
M(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T
M`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA
M<W0@,C0@:&]U<G,`3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S="!-;VYT
M:`!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A
M=&5D.@!,87-T(%EE87(`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87-T('=E96L`3&%T=FEA`$QA
M=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE
M9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E
M<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H
M="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!2
M86EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,
M:6UI="!T:&4@=&EM92!S<&%N('1O(&5X<&]R=#H`3&EN:P!,:6YK('!O:6YT
M<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M
M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@
M2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L
M<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E
M`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S
M`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;U]C871I;VX`3&]A9&EN
M9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO
M9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G
M:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R
M;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G
M:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T
M=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`
M3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9
M=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I
M;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E
M<P!-86QI`$UA;'1A`$UA;F%G92!R96UO=&4@8V%L96YD87)S+@!-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E
M9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-
M87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D
M*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S
M`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O
M9B!%=F5N=',`36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI
M;75M(&QE;F=T:`!-87D`36%Y;W1T90!-90!-961I8VEN90!-965T:6YG`$UE
M;6)E<G,`365N=2!!;&%R;7,`365N=2!,:7-T`$UE;G4@;6]D93H`365R9V4@
M8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B
M=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I
M9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A
M=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE
M=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E
M9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI
M;G5T92AS*0!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C
M:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)
M1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I
M9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO
M;F1A>0!-;VYG;VQI80!-;VYT:`!-;VYT:"!6:65W`$UO;G1H(&%N9"!Y96%R
M`$UO;G1H;'D`36]N=&AL>2!%=F5N=',@3&ES=`!-;VYT:&QY.B!296-U<G,@
M979E<GD`36]N=&AS($%H96%D`$UO;G1H<R!"969O<F4`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@
M4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU
M;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L
M=&EP;&4@:4-A;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE('9%
M=F5N="!I<R!S=7!P;W)T960N`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O
M=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@0V%L96YD87)S`$UY($-A
M;&5N9&%R<SH`37D@1G)E92]"=7-Y(%523`!->2!0;W)T86P`37D@4&]R=&%L
M($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB
M:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL
M97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!5
M4DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%52
M3`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R
M(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C
M97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.
M97<@0V%T96=O<GD`3F5W($5V96YT`$YE=R!-97-S86=E('1O("5S`$YE=R!-
M;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!C
M86QE;F1A<B!C<F5A=&5D(&%N9"!A=71O;6%T:6-A;&QY('-H87)E9"!W:71H
M(&9O;&QO=VEN9R!G<F]U<"AS*3H@)7,N`$YE=R!P87-S=V]R9`!.97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE
M>'0`3F5X="`R-"!H;W5R<P!.97AT(#0@4&AA<V5S`$YE>'0@1&%Y`$YE>'0@
M36]N=&@`3F5X="!7965K`$YE>'0@665A<@!.97AT(&1A>0!.97AT(&]P=&EO
M;G,`3F5X="!W965K`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI
M9VAT`$YI=64`3F\`3F\@86QA<FT`3F\@871T96YD965S`$YO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N
M`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C86QE;F1A<G,@87)E(&%V86EL
M86)L92!T;R!G=65S=',N`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E
M(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM
M1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P
M;&EE9"X`3F\@96YD(&1A=&4`3F\@979E;G1S('1O(&1I<W!L87D`3F\@9FEL
M92!U<&QO861E9`!.;R!F<F5E+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA
M8FQE(&9O<B`E<P!.;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N`$YO(&EC
M;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R
M;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE
M9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@
M<75O=&$@<V5T+@!.;R!R96-U<G)E;F-E`$YO(')U;&5S`$YO('-E<&%R871O
M<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QI9"!E;6%I;"!A9&1R97-S(&9O=6YD`$YO('9A;'5E<P!.
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`
M3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I
M`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.
M;W0@82!D:7)E8W1O<GD`3F]T(&9O=6YD`$YO="!I;7!L96UE;G1E9"X`3F]T
M('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@
M9V\@8F%C:RX`3F]T:69I8V%T:6]N<P!.;W9E;6)E<@!.;W<`3G5M8F5R`$YU
M;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/
M8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VX`3VX@86QL(&-A
M;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\`3VX@86QL('-H;W=N(&-A
M;&5N9&%R<P!/;B!M>2!C86QE;F1A<G,@;VYL>0!/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T
M=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@
M:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA
M;`!/<'1I;VYA;"!!='1E;F1E97,`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]V97)V:65W`$]W;F5R`$]W;F5R(%!E<FUI<W-I;VYS`$]W;F5R.B`E<P!0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I
M;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D
M($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M80!02%`@0V]D90!02%`@4VAE;&P`4$T`4$T@3&EG:'0@4F%I;@!032!3:&]W
M97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M
M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I
M;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@
M0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M`%!A<W0@179E;G1S($QI<W0`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`
M4&%T:`!0871T97)N`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6%N96YT;'D@9&5L971E
M('1H:7,@979E;G0_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D
M96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U
M`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L
M<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE
M;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H
M:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE
M87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L
M;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O
M('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T86P@3W!T:6]N<P!0
M;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS
M*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S
M=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE
M=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@
M1&%Y`%!R979I;W5S(%=E96L`4')E=FEO=7,@9&%Y`%!R979I;W5S(&]P=&EO
M;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M
M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`
M4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U
M97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E
M9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,
M871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A
M;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C=7(@56YT:6P`4F5C=7)R96YC
M90!296-U<G)E;F-E($1A=&$`4F5C=7)R96YC92!%;F0@1&%T90!296-U<G)E
M;F-E($EN=&5R=F%L`%)E8W5R<F5N8V4@5'EP90!296-U<G,@9&%I;'D`4F5C
M=7)S(&UO;G1H;'D`4F5C=7)S('=E96ML>0!296-U<G,@>65A<FQY`%)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T
M:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6EN9&5R.B`E<P!2
M96UO=&4@0V%L96YD87)S`%)E;6]T92!#86QE;F1A<G,Z`%)E;6]T92!397)V
M97)S`%)E;6]T92!3=6)S8W)I<'1I;VX@55),`%)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E("5S`%)E
M;6]V92!!='1E;F1E90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO
M=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H
M90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U
M<V5R`%)E;6]V92!U<V5R.B`E<P!297!L86-E(&5X:7-T:6YG(&-A;&5N9&%R
M('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES
M(&1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&-A;&5N9&%R
M+CPO<W1R;VYG/@!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N`%)E<75I<F5D`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!!='1E;F1E
M97,`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@
M66]U<B!087-S=V]R9`!297-E="!T;R!$969A=6QT<P!297-P;VYS90!297-T
M;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y
M<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@
M:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2
M;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A
M=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S
M=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3
M:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A
M:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A
M;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET
M92!0<F]V:61E<@!3871U<F1A>0!3875D:2!!<F%B:6$`4V%V90!3879E("(E
M<R(`4V%V92`E<P!3879E($%S($YE=P!3879E($%T=&5N9&5E<P!3879E($5V
M96YT`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`
M4V-I96YC90!396%R8V@`4V5A<F-H($-A;&5N9&%R<P!396%R8V@@16YG:6YE
M<P!396%R8V@@4F5S=6QT<P!396%R8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN
M:6YG.@!396QE8W0@1FEL97,`4V5L96-T(&$@8V%L96YD87(@=&\@961I=`!3
M96QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N
M97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D
M`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C
M="!A;B!O8FIE8W0`4V5L96-T(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.@!396QE
M8W0@8V]N9FER;6%T:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D
M:69F97)E;G0@=FEE=W,@86YD(&-H;V]S92!D969A=6QT('9I97<N`%-E;&5C
M="!N;VYE`%-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.@!396QE
M8W0@=&AE(&-A;&5N9&%R*',I('1O(&5X<&]R="!F<F]M`%-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A
M<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E;&5C="!T
M:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3H`
M4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T
M('1H92!T:6UE('-P86X@=&\@<VAO=SH`4V5L96-T('1H92!V:65W('1O(&1I
M<W!L87D@;VX@<W1A<G1U<#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;&5C="!W:&EC:"!E=F5N=',@=&\@<VAO=R!I;B!T:&4@<&]R=&%L+@!3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YD
M(&$@8V%N8V5L(&YO=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@
M9&5L971I;F<@=&AI<R!E=F5N=`!396YD(&%N(&5M86EL('1O("5S`%-E;F0@
M=7!D871E<R]I;G9I=&%T:6]N<R!T;R!A;&P@871T96YD965S('=H96X@<V%V
M:6YG('1H:7,@979E;G0`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R
M8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@
M=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N
M($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@96YD(&1A=&4`4V5T(&]P
M=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@
M>6]U(&5V97(@9F]R9V5T(&ET+@!3970@<F5C=7)R96YC92!E;F0@9&%T90!3
M970@<W1A<G0@9&%T90!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@9G)E
M92]B=7-Y(&-A;&5N9&%R<R!A;F0@>6]U<B!O=VX@86YD(&]T:&5R('5S97)S
M)R!F<F5E+V)U<WD@;W!T:6]N<RX`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S
M:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H87)E(&YO
M="!F;W5N9#H@)7,`4VAA<F5D($-A;&5N9&%R<P!3:&%R960@0V%L96YD87)S
M.@!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@0V%L96YD87(`
M4VAO=R!C871E9V]R>2!L96=E;F0_`%-H;W<@9&5L971E+"!A;&%R;2P@86YD
M(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_`%-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!D=64@=&%S:W,@:6X@
M=&AE(&-A;&5N9&%R/P!3:&]W(&9R964O8G5S>2!L96=E;F0_`%-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O;FQY(&5V96YT
M<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/P!3:&]W(&]P=&EO;B!T;R!K965P
M(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@<VAA<F5D(&-A;&5N9&%R<R!S
M:61E+6)Y+7-I9&4_`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`
M4VAO=R!T87-K<R!U<VEN9R!C871E9V]R>2!C;VQO<G,_`%-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&EM92!O9B!D87D@8F5T
M=V5E;B!E86-H(&1A>2!I;B!W965K('9I97=S/P!3:&]W('5P;&]A9`!3:&]W
M97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@
M8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I
M9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E
M`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W
M`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`
M4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N
M="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@
M4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U
M=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R
M;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`
M4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA
M;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L
M:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A7W)T`%-T86YD87)D`%-T87(@
M5')E:P!3=&%R="!$871E`%-T87)T($]N`%-T87)T(%1I;64`4W1A<G0@>65A
M<@!3=&%T7W5S`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O
M<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T
M`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U
M`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`
M4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D
M960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D
M871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L
M;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A
M=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL
M>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U
M;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YD87D`4W5N;GD`4W5N<FES90!3
M=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R
M<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@
M2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L
M;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I
M;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A
M8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I
M=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H
M;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!4
M96UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D
M;6EN:7-T<F%T:6]N`%1E;G1A=&EV90!497AT`%1E>'0@3VYL>0!497AT(&%L
M:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($5D
M:70@071T96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N="X@17AI
M=&EN9RX`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE
M($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P
M;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN
M9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V%L96YD
M87(@(B5S(B!C86YN;W0@8F4@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@
M:&%S(&)E96X@8W)E871E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@<F5N86UE9"!T
M;R`B)7,B+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S`%1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E;F0@
M9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N`%1H92!E
M=F5N="`B)7,B(&AA<R!B965N(&%D9&5D('1O("(E<R(@8V%L96YD87(L('=H
M:6-H(&ES(&]N("5S(&%T("5S+@!4:&4@979E;G0@(B5S(B!H87,@8F5E;B!D
M96QE=&5D(&9R;VT@(B5S(B!C86QE;F1A<BP@=VAI8V@@=V%S(&]N("5S(&%T
M("5S+@!4:&4@979E;G0@(B5S(B!H87,@8F5E;B!E9&ET960@;VX@(B5S(B!C
M86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%1H92!E=F5N="!N;W1I
M9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A
M;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9F]L;&]W:6YG(&ES
M(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z`%1H
M92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US
M('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@
M=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H
M="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@
M9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N
M9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F
M=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T
M(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F
M;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E
M;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@
M97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R
M86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F
M;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R97%U97-T('=A<R!I;F-O
M;7!L971E+B!3;VUE('!A<F%M971E<G,@=&AA="!A<F4@;F5C97-S87)Y('1O
M(&%C8V5P="!O<B!D96-L:6YE(&%N(&5V96YT(&%R92!M:7-S:6YG+@!4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E
M(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O
M97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO
M="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T
M:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO
M="!F;W5N9"X`5&AE<F4@87)E(&YO(&5V96YT<R!M871C:&EN9R!T:&4@8W5R
M<F5N="!C<FET97)I82X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M
M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@
M)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@86-C97-S
M:6YG('1H92!C86QE;F1A<CH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN
M9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!E9&ET:6YG
M('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@=&AE
M(&5V96YT.B`E<P!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@
M<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@86X@979E
M;G0@;F]T:69I8V%T:6]N('1O("5S.B`E<P!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V5R92!N;R!E=F5N=',@=&\@97AP;W)T+@!4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@
M;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9I;&4@9F]R;6%T(&ES
M(&YO="!S=7!P;W)T960N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N
M=',@<&QE87-E('9I<VET("5S`%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W`%1H=6YD97(`5&AU<G-D87D`5&EC:V5T<P!4:6UE`%1I;64@4W!?
M86X`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4
M:6UE('-P86X`5&EM;W(M3&5S=&4`5&ET7VQE`%1I=&QE`%1I=&QE("AT;V]L
M=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C
M;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA
M=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA
M=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U
M97-D87D`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R
M:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP
M90!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N
M9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L
M9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M("(E<R(Z("5S`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92X`56YA8FQE('1O(')E=')I979E(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B!F;W(@)7,`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH
M*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5
M;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5
M;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@
M8V]L;W(`56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<P!5;G-U<'!O<G1E
M9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A
M=&5D("(E<R(N`%5P9&%T960Z("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D
M+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M
M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S
M97(@061M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`57-E<B!/<'1I;VYS
M`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U
M;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E
M<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI
M<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!6
M86QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E
M(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M
M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T
M:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE
M=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@1&%Y`%9I97<@86X@97AT
M97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI
M='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``
M5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T
M`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B
M(%-I=&4`5V5D;F5S9&%Y`%=E96L`5V5E:R`E9`!7965K*',I`%=E96ML>0!7
M965K;'DZ(%)E8W5R<R!E=F5R>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X
M-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAA
M="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD+"!W:&5N('1H
M97)E(&%R92!N;R!L871E<B!E=F5N=',_`%=H870@=&EM92!S:&]U;&0@9&%Y
M(&%N9"!W965K('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L
M:65R(&5V96YT<S\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E
M<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I
M:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`
M5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K
M(%!H;VYE`%=O<FL@5V5E:P!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI
M;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@
M)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S
M:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME
M>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A
M(&UA<`!996%R`%EE87)L>0!996%R;'DZ(%)E8W5R<R!E=F5R>0!996UE;@!9
M97,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS
M+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M979E;G1S+@!9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF
M:65D(&5V96YT+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N
M(&]N;'D@=7-E('1H:7,@9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S
M8W)E96XN`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN
M("5S+@!9;W4@9&\@;F]T(&AA=F4@86X@96UA:6P@861D<F5S<R!C;VYF:6=U
M<F5D(&EN('EO=7(@4&5R<V]N86P@26YF;W)M871I;VX@3W!T:6]N<RX@66]U
M(&UU<W0@<V5T(&]N92`E<VAE<F4E<R!B969O<F4@979E;G0@;F]T:69I8V%T
M:6]N<R!C86X@8F4@<V5N="X`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@
M=&\@861D(&5V96YT<R!T;R`E<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I
M;VX@=&\@861D(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L96YD87(N`%EO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T92!T:&ES(&5V96YT
M+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E
M;G0N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@<W!E8VEF
M:65D(&%N(&EN=F%L:60@8V%L96YD87(N`%EO=2!H879E('-U8V-E<W-F=6QL
M>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N`%EO=2!H879E
M('-U8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E
M;G0N`%EO=2!H879E('1E;G1A=&EV96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@
M=&\@=&AI<R!E=F5N="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E
M;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N
M('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M
M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<@!9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R
M92!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R<RX`66]U(')E<75E<W1E9"!T;R!B
M92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@
M8V%L96YD87)S+@!9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@
M979E;G1S(&%R92!E9&ET960@:6X@>6]U<B!C86QE;F1A<G,N`%EO=2!R97%U
M97-T960@=&\@8F4@<F5M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S
M(&%T("5S+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L
M;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D
M<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H
M('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD
M+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@
M4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A
M=6QT(&-A;&5N9&%R`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE
M.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F
M;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F
M;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R
M('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9
M=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1
M=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X
M="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%M5;FYA;65D(&5V
M96YT70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]!;&%R;0!?
M0F%S:6,@4V5A<F-H`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]%9&ET
M`%]';W1O`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM
M<&]R="]%>'!O<G0`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`
M7TUY($-A;&5N9&%R<P!?3F5W($5V96YT`%]/<'1I;VYS`%]097)M:7-S:6]N
M<P!?4')I;G0`7U)E;6]V92!,:6YK+BXN`%]396%R8V@`7U-E='5P`%]486)L
M92!0<F]P97)T:65S+BXN`%]4;V1A>0!?57-E<G,`861D<F5S<R!B;V]K`&%D
M9')E<W-E92!U;FMN;W=N`&)E9F]R92!T:&4@979E;G0@<W1A<G1S`&-A;&5N
M9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E
M;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C
M;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<`9&%T82!F;W)M870@97)R;W(`9&%Y`&1A>2AS*0!D87ES`&5N=')Y(&YO
M="!F;W5N9`!E=F5N=',N8W-V`&5V96YT<RYI8W,`9F%L;&EN9P!F:6QE`&9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA
M;64@=6YK;F]W;@!I;6UE9&EA=&4`:6X`:6YL:6YE`&EN<'5T+V]U='!U="!E
M<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&UO;G1H*',I`&YA
M;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A
M9`!O;B`E<R!A="`E<P!O;B!T:&4@<V%M92!D871E`&]N('1H92!S86UE('=E
M96MD87D`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE
M`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D
M>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA
M;65D`'5S97(@<V5L96-T`'9#86QE;F1A<B]I0V%L96YD87(`=D-A<F0`=D5V
M96YT(&YO="!F;W5N9"X`=SH`=V5A=&AE<BYC;VT`=V5E:P!W965K*',I(&]N
M.@!W965K<P!Y96%R*',I`%!R;VIE8W0M260M5F5R<VEO;CH@9G)?1E(*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#(M,C(@,#<Z,C4K,#$P,`I03RU2979I<VEO
M;BU$871E.B`R,#`V+3`R+3(R(#(R.C`U*S`Q,#`*3&%S="U4<F%N<VQA=&]R
M.B!4:&EE<G)Y(%1H;VUA<R`\=&AI97)R>4!P;VUP;RYN970^"DQA;F=U86=E
M+51E86TZ($9R96YC:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R
M<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)
M4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU
M<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@/B`Q*3L*`"`H:6P@
M>2!A("5S(&IO=7)S*0`@*%1O=6-H92!D)V%C8^AS(')A<&ED92`E<RD`("AD
M86YS("5S(&IO=7)S*0`@*&%U:F]U<F0G:'5I*0`@*&1E;6%I;BD`("AH:65R
M*0`@X"``JZ`E<Z"[(&XG97-T('!A<R!U;B!D;W-S:65R`*N@)7.@NR!N)V5S
M="!P87,@=6X@8VAO:7@@=F%L:61E+@"KH"5SH+L@;B=E<W0@<&%S(&-O;F9I
M9W5RZ2!D86YS(&QE(')E9VES=')E(&1E($AO<F1E+@!,)VEN=&5R<'+I=&5U
M<B!D)V%R8G)E(*N@)7.@NR!N)V$@<&%S(.ETZ2!T<F]U=NDN`*N@)7.@NR!A
M(.ETZ2!A:F]U=.D@874@<WES=.AM92!D97,@9W)O=7!E<RX`JZ`E<Z"[(&$@
MZ73I(&%J;W5TZ2!A=2!S>7-TZ&UE(&1E<R!P97)M:7-S:6]N<RX`JZ`E<Z"[
M(&XG82!P87,@Z73I(&-RZ>F@.B`E<RX`)2XR9J!-;R!U=&EL:7/I<R!S=7(@
M)2XR9J!-;R!P97)M:7,@*"4N,F:@)24I`"5D("5S(&5T("5S`"5D(&-A;&5N
M9')I97)S('1R;W5VZ7,`)60@:F]U<G,@879A;G0@;"=E>'!I<F%T:6]N(&1E
M('9O=')E(&UO="!D92!P87-S92X`)60@Z7;I;F5M96YT<P`E9"UP<NEV:7-I
M;VX@9'4@:F]U<@`E<R`M($YO=&EC90`E<R!*;W5R<RAS*2`E<R!(975R92AS
M*2`E<R!-:6YU=&5S`$5M<')E:6YT92!01U`@9&4@)7,`)7.@2V\`)7,@;W#I
M<F%T:6]N<R!D92!M86EN=&5N86YC92`F;F1A<V@[($-O;F9I<FUA=&EO;@!#
M;VYF:6=U<F%T:6]N("5S`$EN<V-R:7!T:6]N(&1E("5S`$-O;F1I=&EO;G,@
M9"=U=&EL:7-A=&EO;B!D92`E<P`E<R!E>&ES=&4@9.EJX"X`("5SH.`@)7,@
M)7,`)7,@<&%R=&EC:7!A;G1S`$QE(&9I8VAI97(@)7,@82!B:65N(.ETZ2!I
M;7!O<G3I`"5S(&5S="!P<NIT(.`@969F96-T=65R(&QE<R!O<.ER871I;VYS
M(&1E(&UA:6YT96YA;F-E(&-O8VCI97,@8VDM9&5S<V]U<RX@4^EL96-T:6]N
M;F5Z(&QA(&]U(&QE<R!O<.ER871I;VXH<RD@<75E('9O=7,@=F]U;&5Z(&5F
M9F5C='5E<B!C971T92!F;VES+6-I+@`E<R!E<W0@;V)L:6=A=&]I<F4`)7,@
M;6EN=71E<P`E<R!N;VX@=')O=7;I`"5SH.`@)7,@9&4@)7,`0V%R;F5T(&0G
M861R97-S97,@9&4@)7,`06=E;F1A(&1E("5S`$)L;V,M;F]T97,@9&4@)7,`
M3&ES=&4@9&4@=.)C:&5S(&1E("5S`"5SH#H@)7,`)7.@.B!L)^EM971T975R
M(&1E(&-E(&UE<W-A9V4@82!P=2#J=')E(&9A;'-I9FGI+B!!='1E;G1I;VX@
M96X@<W5I=F%N="!L97,@;&EE;G,@<74G:6P@8V]N=&EE;G0@;W4@96X@9F]U
M<FYI<W-A;G0@9&5S(&EN9F]R;6%T:6]N<R!P97)S;VYN96QL97,@X"!L)^EM
M971T975R+@`H0VQI<75E<B!S=7(@;&4@;F]M(&1U(&-A;&5N9')I97(@<&]U
M<B!L)V%F9FEC:&5R(&1A;G,@;&$@9F5NZG1R92!P<FEN8VEP86QE*0`J($QE
M<R!A:F]U=&5R(&5N(&-L:7%U86YT('-U<B!!:F]U=&5R("H`*B!6975I;&QE
M>B!SZ6QE8W1I;VYN97(@=6YE*&1E<RD@861R97-S92AS*2`J`"P@96X@<F%F
M86QE(`!R869A;&4@)7,@)7,`=F%R:6%B;&4@9'4@)7,@874@)7,`+2T@4^EL
M96-T:6]N;F5R("TM`#$@<&%R=&EC:7!A;G0`,2#I=NEN96UE;G0`,2!H975R
M90!&;W)M870@,3(@:&5U<F5S`#$U(&UI;G5T97,`,C`@;6EN=71E<P!&;W)M
M870@,C0@:&5U<F5S`#(T(&AE=7)E<P`S,"!M:6YU=&5S`#Q0<NECZ61E;G0`
M/'-T<F]N9SY087)T:6-I<&%N=',\+W-T<F]N9SX@*&9A8W5L=&%T:68I`#QS
M=')O;F<^1&5S8W)I7W!T:6]N/"]S=')O;F<^("AF86-U;'1A=&EF*0`\<W1R
M;VYG/DUO=',M8VSI<SPO<W1R;VYG/B`H9F%C=6QT871I9BD`/'-T<F]N9SY2
MZ7#I=&ET:6]N/"]S=')O;F<^("AF86-U;'1A=&EF*0!5;F4@8F%S92!D92!D
M;VYNZ65S('!R:6YC:7!A;&4@*&)A8VME;F0I(&5S="!NZ6-E<W-A:7)E('!O
M=7(@8V4@8FQO8P!5;F4@97)R975R(&9A=&%L92!S)V5S="!P<F]D=6ET90!5
M;F4@8VQE9B!P=6)L:7%U92!01U`@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF
M9G)E<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!01U`@97-T(&[I
M8V5S<V%I<F4@<&]U<B!VZ7)I9FEE<B!L82!S:6=N871U<F4@9"=U;B!M97-S
M86=E+@!5;F4@8VQE9B!P=6)L:7%U92!01U`L('5N92!C;&5F('!R:7;I92!0
M1U`L(&5T('5N92!P:')A<V4@<V5C<NAT92!S;VYT(&[I8V5S<V%I<F5S('!O
M=7(@9.EC:&EF9G)E<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!0
M1U`L('5N92!C;&5F('!R:7;I92!01U`L(&5T('5N92!P:')A<V4@<V5C<NAT
M92!S;VYT(&[I8V5S<V%I<F5S('!O=7(@<VEG;F5R('5N(&UE<W-A9V4N`%5N
M92!C;&5F('!U8FQI<75E(%,O34E-12P@=6YE(&-L968@<')I=NEE(%,O34E-
M12P@970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U
M<B!DZ6-H:69F<F5R('5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%,O
M34E-12P@=6YE(&-L968@<')I=NEE(%,O34E-12P@970@=6YE('!H<F%S92!S
M96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U<B!S:6=N97(@=6X@;65S<V%G
M92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%(&5S="!NZ6-E<W-A:7)E('!O
M=7(@8VAI9F9R97(@=6X@;65S<V%G92X`04T`3G5A9V5S(&QE(&UA=&EN`%!L
M=6EE(&SI9^AR92!L92!M871I;@!0;'5I92!L92!M871I;@!!=F5R<V5S(&QE
M(&UA=&EN`$-H=71E<R!D92!N96EG92!L92!M871I;@!!32]030!!4$D@240`
MP"!P<F]P;W,@9&4@8V5T(.ED:71E=7(`P"!P<F]P;W,N+BX`0F%S(&%B<V]L
M=0!-:6QI974@86)S;VQU`$%C8V5P=.D`06-CZ',@<F5F=7/I(&QO<G,@9&4@
M;&$@8W+I871I;VX@9&4@<NEP97)T;VER92!61E,@+@!!8V/H<R!R969U<^D@
M;&]R<R!D92!L82!C<NEA=&EO;B!D92!F:6-H:65R(%9&4RX`1&]N;NEE<R!P
M97)S;VYN96QL97,`36]T(&1E('!A<W-E(&1U(&-O;7!T90!#;VUP=&4@:6YA
M8W1I9@!#;VUP=&5S`%]296-H97)C:&4@879A;F/I90!!:F]U=&5R`$%J;W5T
M97(@=6X@<V]U<RUG<F]U<&4`06IO=71E<B!U;F4@;F]U=F5L;&4@<V]U<RUP
M97)M:7-S:6]N`$%J;W5T(&0GZ7;I;F5M96YT`$%J;W5T97(@:6-IH#H`06IO
M=71E<B!U;B!N;W5V96%U(&=R;W5P90!!:F]U=&5R('5N92!N;W5V96QL92!P
M97)M:7-S:6]N`$%J;W5T97(@=6X@9W)O=7!E(&9I;',@X""KH"5SH+L`06IO
M=71E<B!U;F4@<&5R;6ES<VEO;B!F:6QL92#@(*N@)7.@NP!!:F]U=&5R('5N
M(&YO=79E;"!A9V5N9&$@9&ES=&%N=`!!:F]U=&5R('5N(&YO=79E;"#I=NEN
M96UE;G0`06IO=71E<B!U;B!N;W5V96P@=71I;&ES871E=7*@.@!!:F]U=&5R
M(&1E<R!P87)T:6-I<&%N=',`06IO=71E<B!U;F4@8V]L;VYN90!!:F]U=&5R
M(&1E(&YO=79E875X(&UE;6)R97,`06IO=71E<B!U;F4@<&%I<F4`06IO=71E
M<B!L92!M96YU("5S(.`@;&$@8F%R<F4@9&4@36]Z:6QL80!!:F]U=&5R(&%U
M(&-A<FYE="!D)V%D<F5S<V5SH#H`06IO=71E<B!A=7@@<&%R=&EC:7!A;G1S
M`$%J;W5T97(@X"!M;VX@8V%R;F5T(&0G861R97-S97,`06IO=71E<B!U;B!U
M=&EL:7-A=&5U<@"KH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64L(&UA
M:7,@;"=A:F]U="!D)VEN9F]R;6%T:6]N('-U<'!LZ6UE;G1A:7)E<R`E<R!N
M)V5S="!P87,@<&]S<VEB;&4N`*N@)7.@NR!A(.ETZ2!A:F]U=.DN(%9O=7,@
M<&]U=F5Z('9O=7,@8V]N;F5C=&5R+@!,82!F;VYC=&EO;B!D)V%J;W5T(&0G
M=71I;&ES871E=7)S(&5S="!DZ7-A8W1I=NEE+@!!9')E<W-E`$-A<FYE="!D
M)V%D<F5S<V5S`$%D;6EN:7-T<F%T975R("T@86IU<W1E<B!L97,@<&5R;6ES
M<VEO;G,@<&]U<B!D)V%U=')E<R!U=&EL:7-A=&5U<G,`061M:6YI<W1R871I
M;VX`4'5B<P!296-H97)C:&4@879A;F/I90!!9F=H86YI<W1A;@!!;&5R=&4`
M06QE<G1E("5D(&IO=7)S(&%V86YT`$%L97)T925D(&AE=7)E<R!A=F%N=`!!
M;&5R=&4@)60@;6EN=71E<R!A=F%N=`!!;&5R=&4@)60@<V5M86EN92!A=F%N
M=`!!;&5R=&4@,2!J;W5R;NEE(&%V86YT`$%L97)T92`Q(&AE=7)E(&%V86YT
M`$%L97)T92`Q(&UI;G5T92!A=F%N=`!!;&5R=&4@,2!S96UA:6YE(&%V86YT
M`$1A=&4@9&4@;"=A;&5R=&4`1'5RZ64@9&4@;"=A;&5R=&4@*&UI;G5T97,I
M`$AE=7)E(&1E(&PG86QE<G1E`$%L8F%N:64`06QGZ7)I90!!;&EA<P!!;&EG
M;F5R`$%L:6=N96UE;G2@.@!4;W5T`%1O=7,@;&5S('!A<G1I8VEP86YT<P!4
M;W5S(&QE<R!P87)T:6-I<&%N=',@875T:&5N=&EF:>ES`%1O=7,@Z7;I;F5M
M96YT<R!U;'3I<FEE=7)S`%1O=7,@;&5S(&=R;W5P97,`5&]U<R#I=NEN96UE
M;G1S(&%N=.ER:65U<G,`5&]U=&5S(&QE<R!P97)M:7-S:6]N<P!4;W5T('9I
M<VEB;&4`5&]U=&4@;&$@:F]U<F[I90!$=7)E('1O=71E(&QA(&IO=7)NZ64`
M5&]U<R!L97,@Z7;I;F5M96YT<P!,97,@<75A=')E(&/T=.ES`%!E<FUE='1R
M92!D97,@861R97-S97,@9&4@8V]U<G)I96P@;75L=&EP;&5S`$%U=&]R:7-E
M<B!L82!M:7-E(&5N('!L86-E(&1E(&QI<W1E<R!N=6WI<F]TZ65SH#\`17AI
M<W1E(&3I:N``3F]M(&0G=71I;&ES871E=7(@24U34"!A;'1E<FYA=&EF`$UO
M="!D92!P87-S92!)35-0(&%L=&5R;F%T:68`3F]M(&0G=71I;&ES871E=7(@
M24U34"!A;'1E<FYA=&EF`$%D<F5S<V4@9&4@8V]U<G)I96P@86QT97)N871I
M=F4`075T<F5S(&UO9.AL97,`5&5X=&4@86QT97)N871I9J`Z`%-A;6]A($%M
MZ7)I8V%I;@!5;F4@=F%L975R(&EL;.EG86QE(&$@Z73I('-PZ6-I9FGI92X`
M56YE(&5R<F5U<B!I;F-O;FYU92!S)V5S="!P<F]D=6ET92X`06YD;W)R90!!
M;F=O;&$`06YG=6EL;&$`4')O>'D@86YO;GEM90!2Z7!O;G-E`$%N=&%R8W1I
M<75E`$%N=&EG=6$M970M0F%R8G5D80!.)VEM<&]R=&4@<75E;`!!<'!L:6-A
M=&EO;@!,:7-T92!D)V%P<&QI8V%T:6]N<P!,)V%P<&QI8V%T:6]N(&5S="!P
M<NIT90!!<'!L:7%U97(@875X('!A<G1A9V5S(&9I;',`07!P<F]U=ND`5&%I
M;&QE(&%P<')O>&EM871I=F4`079R:6P`07)A8F4@*%=I;F1O=W,M,3(U-BD`
M5&%I;&QE(&1U(&9I8VAI97(@87)C:&EV90!.;VT@9&4@;"=A<F-H:79E`,IT
M97,M=F]U<R!C97)T86EN(&1E('9O=6QO:7(@<W5P<')I;65R(&-E='1E(')E
M<77J=&4@9"=I;G-C<FEP=&EO;B`@<&]U<B`E<Z`_`,IT97,M=F]U<R!C97)T
M86EN(&1E('9O=6QO:7(@969F86-E<B"KH"5SH+L@970@<V5S('-O=7,M9W)O
M=7!E<Z`_`$%R9V5N=&EN90!!<FWI;FEE`$%R;>EN:65N("A!4DU30TE)+3@I
M`$%R=`!!<G5B80!!<V-E;G-I;VX@*,YL92D`07)T($%30TE)`%+I9VEO;B!!
M<VEE+U!A8VEF:7%U90!$96UA;F1E<B!U;F4@8V]N9FER;6%T:6]N(&%V86YT
M(&1E(&QA;F-E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC9:`_`$-O
M;&]N;F5S(&1E<R!TXF-H97,`P`!,82!P:>AC92!J;VEN=&4@97-T('5N(&9I
M8VAI97(@:4-A;&5N9&%R(&-O;G1E;F%N="!P;'5S(&0G:6YF;W)M871I;VYS
M(&-O;F-E<FYA;G0@;"?I=NEN96UE;G0N(%-I('9O=')E(&-L:65N="!D92!C
M;W5R<FEE<B!S=7!P;W)T92!L97,@<F5Q=>IT97,@:51I<"!V;W5S('!O=79E
M>B!U=&EL:7-E<B!C92!F:6-H:65R('!O=7(@;65T=')E(.`@:F]U<B!V;W1R
M92!C;W!I92!L;V-A;&4@9&4@;"?I=NEN96UE;G0N`%1E;G1A=&EV92!D)V5F
M9F%C96UE;G0@9"=U;B!G<F]U<&4@:6YE>&ES=&%N="X`5&5N=&%T:79E("!D
M)V5F9F%C96UE;G0@9"=U;F4@<&5R;6ES<VEO;B!I;F5X:7-T86YT92X`5&5N
M=&%T:79E(&1E(&UO9&EF:6-A=&EO;B!D)W5N92!P97)M:7-S:6]N(&EN97AI
M<W1A;G1E+@!496YT871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6X@<&%R=&%G
M92!I;F5X:7-T86YT+@!0<NES96YC90!0<NES96YT<P!0<F]P<FGI=.ES`$%O
M^W0`075S=')A;&EE`$%U=')I8VAE`$%U=&A?8WER=7.@.B!%>'1E;G-I;VX@
M<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE+@!!=71H7V-Y<G5SH#H@;&4@8F%C
M:V5N9"!N)V$@<&%S(&QE<R!C87!A8VETZ7,@<F5Q=6ES97,N`$%U=&A?8WER
M=7.@.B!E>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE`$%U=&A?
M9G1PH#H@97AT96YS:6]N(')E<75I<V4@1E10(&YO;B!T<F]U=NEE+B!);"!F
M875T(&-O;7!I;&5R(%!(4"!A=F5C(&PG;W!T:6]N("TM96YA8FQE+69T<"X`
M075T:%]I;6%PH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I
M92X`075T:%]K<F(UH#H@97AT96YS:6]N(')E<75I<V4@:W)B-2!N;VX@=')O
M=7;I92X`075T:%]L9&%PH#H@;"=A:F]U="!D)W5T:6QI<V%T975R<R!N)V5S
M="!P87,@<W5P<&]R=.D@879E8R!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<*`Z(&QE(')E=')A:70@9"=U=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U<'!O
M<G3I(&%V96,@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87"@.B!E>'1E;G-I
M;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE+@!!=71H7VQD87"@.B!I;7!O
M<W-I8FQE(&0G86IO=71E<B!L)W5T:6QI<V%T975R("5S+B!#96-I(&5S="!L
M82!RZ7!O;G-E(&1U('-E<G9E=7*@.B``075T:%]L9&%PH#H@:6UP;W-S:6)L
M92!D92!S=7!P<FEM97(@;"=U=&EL:7-A=&5U<B`E<P!!=71H7VQD87"@.B!M
M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D92!L)W5T:6QI<V%T975R("5S`$%U
M=&A?;&1A<*`Z(&QA(&UO9&EF:6-A=&EO;B!D97,@=71I;&ES871E=7)S(&XG
M97-T('!A<R!S=7!P;W)TZ64@879E8R!!8W1I=F4@1&ER96-T;W)Y+@!!=71H
M7VUC86R@.B!E>'1E;G-I;VX@<F5Q=6ES92!-0T%,(&YO;B!T<F]U=NEE+@!!
M=71H7W-M8F%U=&B@.B!E>'1E;G-I;VX@<F5Q=6ES92!S;6)A=71H(&YO;B!T
M<F]U=NEE+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX@874@<V5R=F5U
M<B!)34%0+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX`R6-H96,@9&4@
M;"=A=71H96YT:69I8V%T:6]N("5S`$QE('-E<G9E=7(@4D%$2553(&$@<F5J
M973I(&PG875T:&5N=&EF:6-A=&EO;BX`R6-H96,@9&4@;"=A=71H96YT:69I
M8V%T:6]N(&%U('-E<G9E=7(@1E10+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC
M871I;VX@874@<V5R=F5U<B!334(N`$-H86UP<R!D:7-P;VYI8FQE<Z`Z`$%Z
M97)B8>]D:F%N`$5X8W5S97,@0D]&2`!#;W5L975R(&1E(&9O;F0`0V]U;&5U
M<B!D92!F;VYD`$UO="!D92!P87-S92!+97)B97)O<R!E<G)O;NDN`$YO;2!D
M92!C;VYN97AI;VX@2V5R8F5R;W,@97)R;V[I+@!"86AA;6%S`$)A:')E[VX`
M0F%L=&4@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&4`4NEP97)T
M;VER92!D97,@9W)A<&AI<75E<R"KH"5SH+L@;F]N('1R;W5VZ2X`3&EG;F4@
M9&4@8F%S90!296-H97)C:&4@<VEM<&QE`$+I;&%R=7,`0F5L9VEQ=64`0F5L
M:7IE`$+I;FEN`$)E<FUU9&5S`$)H;W5T86X`06YN:79E<G-A:7)E`$)L;V,@
MJR5S(+L@9&4@;"=A<'!L:6-A=&EO;B"KH"5SH+L@:6YC;VYN=0!0<NEFZ7)E
M;F-E<R!D92!B;&]C`%1Y<&4@9&4@8FQO8P!'<F%S`$)O;&EV:64`4VEG;F5T
M<P!";W)D=7)E`,EP86ES<V5U<B!D92!L82!B;W)D=7)EH#H`0F]R9',`0F]S
M;FEE+4AE<GKI9V]V:6YE`$QE<R!D975X`$)O='-W86YA`$)A<P!";W5V970`
M0G+I<VEL`%1E<G)I=&]I<F5S(&)R:71A;FYI<75E<R!D92!L)T]CZ6%N($EN
M9&EE;@!3=6QT86YA="!D=2!"<G5NZ6D`0G5L9V%R:64`3&ES=&4@X"!P=6-E
M<P!"=7)K:6YA($9A<V\`0G5R=6YD:0!/8V-U<.D`1V5S=&EO;B!D92!C;VYT
M96YU`$-20P!$:7-T<FEB=71I;VX@9&5S('!O:6YT<R!,4D,@*$QI<W1E(&1E
M('+I=F]C871I;VX@9&5S(&-E<G1I9FEC871S*0!?06=E;F1A`%!R;W!R:>ET
MZ7,@9&4@;&$@0U]E;&QU;&4`3"=I;FET:6%L:7-A=&EO;B!D=2!C86-H92!N
M92!S)V5S="!P87,@=&5R;6ENZ64N`$%?9V5N9&$`06=E;F1A`%-O;6UA:7)E
M(&1E(&PG86=E;F1A`$QE(&-A;&5N9')I97(@82#I=.D@<'5R9^DN`$%G96YD
M87,`3&5S(&%G96YD87,@9&]I=F5N="!A=F]I<B!U;B!N;VTN`$-A;&UE`$-A
M;6)O9&=E`$-A;65R;W5N`$EM<&]S<VEB;&4@9&4@<NEI;FET:6%L:7-E<B!L
M92!M;W0@9&4@<&%S<V4@875T;VUA=&EQ=65M96YT+"!C;VYT86-T97H@=F]T
M<F4@861M:6YI<W1R871E=7(@<WES=.AM92X`26UP;W-S:6)L92!D92!S=7!P
M<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN`$EM<&]S<VEB;&4@9"=A9&UI;FES
M=')E<B!D97,@9V5S=&EO;FYA:7)E<R!D92!S97-S:6]N(&5X=&5R;F5S+@#)
M8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!)34%0H#H@)7,`0W+I
M871I;VX@:6UP;W-S:6)L92!D)W5N(&YO=79E;"#I=NEN96UE;G0N`$EM<&]S
M<VEB;&4@9"=O=79R:7(@;&4@9FEC:&EE<B"KH"5SH+LN`$-A;F%D80!!;FYU
M;&5R`$%N;G5L97(@;&4@<F%P<&]R="!D=2!P<F]B;.AM90!!;FYU;.EE`$%N
M;G5LZ66@.B`E<RX`26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@9FEC:&EE
M<B"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@=')O=79E<B!U;B!RZ7!E<G1O:7)E
M('1E;7!O<F%I<F4`26UP;W-S:6)L92!D92!P<F]CZ61E<B!S86YS(&QE('!A
M<F%MZ'1R92"K('1A<F=E=$9I;&4@NP!);7!O<W-I8FQE(&1E('-U<'!R:6UE
M<B!L92!RZ7!E<G1O:7)E(*N@)7.@NRX`4W5P<')E<W-I;VX@:6UP;W-S:6)L
M92P@:6P@>2!A("5D(&5N<F5G:7-T<F5M96YT<R!F:6QS+@!);7!O<W-I8FQE
M(&1E('+I;W)D;VYN97(L(&QE(&YO;6)R92!D)^ELZ6UE;G1S(.`@<NEO<F1O
M;FYE<B!N92!C;W)R97-P;VYD('!A<R!A=2!N;VUB<F4@9"?I;.EM96YT<R!E
M;G)E9VES='+I<RX`3F4@<&5U="!D:7)I9V5R(&QE(&UE<W-A9V4@=F5R<R!L
M92!N;VUB<F4@<W#I8VEF:>DN`$-A<"U697)T`$SI9V5N9&4`5')A;G-P;W)T
M975R`$-A=.EG;W)?:64`0V%TZ6=O<FEE<R!E="#)=&EQ=65T=&5S`$-A=.EG
M;W)I90#.;&5S($-A[VUA;@!4Z6SI<&AO;F4@8V5L;'5L86ER90!0<F]P<FGI
M=.ES(&1E(&QA(&-E;&QU;&4`4F5M<&QI<W-A9V4@875T;W5R(&1E(&QA(&-E
M;&QU;&6@.@!0<F]P<FGI=.ES(&1E(&QA(&-E;&QU;&4`17-P86-E;65N="!D
M92!L82!C96QL=6QEH#H`5.ELZ7!H;VYE(&-E;&QU;&%I<F4@`$-E;'1E("A)
M4T\M.#@U.2TQ-"D`0V5N=')E<@!2Z7!U8FQI<75E(&-E;G1R869R:6-A:6YE
M`$5U<F]PZ65N(&-E;G1R86P@*$E33RTX.#4Y+3(I`$3I=&%I;',@9'4@8V5R
M=&EF:6-A=`!0<F]P<FGI=&%I<F4@9'4@8V5R=&EF:6-A=`!0;VQI=&EQ=64@
M9&4@8V5R=&EF:6-A=&EO;@!48VAA9`!-;V1I9FEE<@!-;V1I9FEE<B!V;W1R
M92!M;W0@9&4@<&%S<V4`0VAA;F=E<B!L92!N;VTL(&PG861R97-S92!E="!L
M82!S:6=N871U<F4@<75E(&QE<R!P97)S;VYN97,@=F]I96YT('%U86YD(&5L
M;&5S(&QI<V5N="!E="!RZ7!O;F1E;G0@X"!V;W,@;65S<V%G97,N`$QA(&UO
M9&EF:6-A=&EO;B!D92!V;W1R92!M;W0@9&4@<&%S<V4@;B=E<W0@<&%S('-U
M<'!O<G3I92!A=F5C(&QA(&-O;F9I9W5R871I;VX@86-T=65L;&4N($-O;G1A
M8W1E>B!V;W1R92!A9&UI;FES=')A=&5U<BX`0VAA<@!6Z5]R:69I97(@;&4@
M;&EE;@!#:&EL:0!#:&EN90!#:&EN;VES('-I;7!L:69IZ2`H1T(R,S$R*0!#
M:&EN;VES('1R861I=&EO;FYE;"`H0FEG-2D`0VAO:7-I<B!L)V%P<&QI8V%T
M:6]NH#H`0VAO:7-I<B!U;B!M;W0@9&4@<&%S<V4`0VAO:7-I<B!U;B!N;VT@
M9&4@8V]N;F5X:6]N`$-H;VES:7(@;&4@;6]D92!D)V%F9FEC:&%G92!D97,@
M9&%T97.@.@!#:&]I<VES<V5Z('-I('9O=7,@=F]U;&5Z(.IT<F4@879E<G1I
M(&1E<R!C<NEA=&EO;G,L(&TN(.`@:BX@;W4@<W5P<')E<W-I;VYS(&0GZ7;I
M;F5M96YT<R!P87(@8V]U<G)I97*@.@!#:&]I<VES<V5Z('-I('9O=7,@=F]U
M;&5Z(.IT<F4@879E<G1I(&1E<R!C<NEA=&EO;G,L(&TN(.`@:BX@;W4@<W5P
M<')E<W-I;VYS(&0GZ7;I;F5M96YT<RX`0VAO:7-I<W-E>B!S:2!V;W5S('9O
M=6QE>B!R96-E=F]I<B!D97,@8V]U<G)I97)S(&1E(')A<'!E;"!P;W5R(&QE
M<R#I=NEN96UE;G1S(&%V96,@9&5S(&%L87)M97.@.@!#:&]I<VER(&QE('-T
M>6QE(&1E(&QI<W1E("AP;W5R(&QE<R!L:7-T97,@;G5MZ7)I<75E<RD`0VAO
M:7-I<W-E>B!L92!C87)N970@9"=A9')E<W-E<R!O^2!C:&5R8VAE<B!L97,@
M55),(&1E(&1I<W!O;FEB:6QI=.ESH#H`0VAO:7-I<W-E>B!L97,@86=E;F1A
M<R#@(&EN8VQU<F4@9&%N<R!V;W1R92!L:7-T92!D92!D:7-P;VYI8FEL:73I
M<Z`Z`$-H;VES:7-S97H@;&5S(&%G96YD87,@X"!I;F-L=7)E('!O=7(@9^EN
MZ7)E<B!L97,@55),(&1E(&1I<W!O;FEB:6QI=.ESH#H`0VAO:7-I<W-E>B!V
M;W1R92!A9V5N9&$@<&%R(&3I9F%U="X`SFQE<R!#:')I<W1M87,`1.EF:6YI
M=&EO;B!D92!L82!C;&%S<V4@9&4@)7,@;F]N('1R;W5VZ64N`$5F9F%C97(`
M3F5T=&]Y97(@;&5S(&)A;&ES97,@35,M3V9F:6-E`$5F9F%C97(@;&$@<F5Q
M=>IT90!,:6+I<F5R('1O=7,@;&5S('!A<G1I8VEP86YT<P!2971I<F5R(&PG
M=71I;&ES871E=7(Z("5S`$5F9F%C97(@;"=U=&EL:7-A=&5U<@!%9F9A8V5R
M(&QE<R!D;VYNZ65S(&1E(&PG=71I;&ES871E=7(`R6-L86ER8VEE<R!T87)D
M(&1A;G,@;&$@:F]U<F[I90!#;&EQ=65R('!O=7(@<&]U<G-U:79R90!#;&EC
M:V%T96QL('9I82!(5%10`$9E<FUE<B!L82!F96[J=')E`$9E<FUE<B!L82!F
M96[J=')E`$YU86=E<P!.=6%G97,@;6%T:6YA=7@`3G5A9V5U>`#.;&5S($-O
M8V]S`%)E<&QI97(@;&$@8F%R<F4@9&4@8_1TZ0!2Z61U:7)E(&QE<R!B;W)D
M<P!#;VQO;6)I90!#;W5L975R`%!A;&5T=&4@9&4@8V]U;&5U<G,`4^EL96-T
M:6]N(&0G=6YE(&-O=6QE=7(`0V]L<Z`Z`%1I=')E<R!D92!C;VQO;FYE`$(N
M1"X`5F%L975R<R!SZ7!A<NEE<R!P87(@9&5S('9I<F=U;&5S`$-O;6UA;F1E
M`$-O;6UA;F1E('-H96QL`$-O;6UE;G1A:7)E`$YO;2!U<W5E;`!#;VUO<F5S
M`%-O8VGI=.D`3W)D:6YA=&5U<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`1&EF
M9NER96YC97,@9&4@8V]N9FEG=7)A=&EO;@!3>6YC:')O;FES871I;VX@9&5S
M(&%S<VES=&%N=',@<&5R<V]N;F5L<RP@/$D^<VUA<G1P:&]N97,\+TD^(&5T
M($]U=&QO;VLN`$QA(&-O;F9I9W5R871I;VX@;B=E<W0@<&%S(.`@:F]U<BX`
M0V]N9FEG=7)E<B`E<P!#;VYF:7)M97(@;&4@;6]T(&1E('!A<W-E`$-O;F9I
M<FUE<B!L82!S=7!P<F5S<VEO;B!D97,@Z7;I;F5M96YT<Z`_`$-O;F9I<FWI
M90!#;VYG;P!2Z7!U8FQI<75E(&3I;6]C<F%T:7%U92!D=2!#;VYG;P#)8VAE
M8R!D92!L82!C;VYN97AI;VX`R6-H96,@9&4@;&$@8V]N;F5X:6]NH#H@`$-O
M;FYE>&EO;B!A=2!S97)V975R(&1E(&-L969S('!U8FQI8R!R969U<^EE+@!#
M;VYN97AI;VX@874@<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@<F5F=7/I92X@
M4F%I<V]NH#H@("5S("@E<RD`R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E
M<G9E=7(@1E10`$-O;G1A8W1S`$-E<R!C;VYT86-T<R!O;G0@8FEE;B#I=.D@
M86IO=73I<R#@('9O=')E(&-A<FYE="!D)V%D<F5S<V5S+@!4>7!E(&1E(&-O
M;G1E;G4@9'4@9FEC:&EE<B!C;VUP<F5S<^F@.B``0V]N=&5N=2!D92"KH"5S
MH+L`4&]U<G-U:79R90#.;&5S($-O;VL`5.EM;VEN("AC;V]K:64I`$-O<&EE
M<@#)8VAE8R!D92!L82!C;W!I9:`Z("5S`%/I;&5C=&EO;B!D)W5N92!C;W!I
M90!#;W!I97(@;"=54DP@8VDM9&5S<V]U<R!P;W5R('5T:6QI<V5R(&QO<G-Q
M=64@=F]U<R!A=F5Z(&)E<V]I;B!D92!V;W1R92!54DP@9&4@9&ES<&]N:6)I
M;&ETZ7.@.@!)9"X@8V_[=`!#;W-T82!2:6-A`$/T=&4@9"=)=F]I<F4`26UP
M;W-S:6)L92!D92!C:&EF9G)E<B!L92!M97-S86=EH#H@`%-I9VYA='5R92!0
M1U`@9'4@;65S<V%G92!I;7!O<W-I8FQEH#H@`$EM<&]S<VEB;&4@9&4@8VAI
M9F9R97(@;&4@;65S<V%G92!A=F5C(%,O34E-12X`4VEG;F%T=7)E(%,O34E-
M12!D=2!M97-S86=E(&EM<&]S<VEB;&4N`$%J;W5T(&1U(&-O;G1A8W0@)7,@
M:6UP;W-S:6)L92X@`$YE('!E=70@<V4@8V]N;F5C=&5R(&%U('-E<G9E=7(@
M3$1!4"X`3F4@<&5U="!S92!C;VYN96-T97(@874@<V5R=F5U<B!,1$%0`%;I
M<FEF:6-A=&EO;B!D92!L82!B86QA;F-E("5S(&EM<&]S<VEB;&4N(`#)8VAE
M8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!,1$%0`,EC:&5C(&1E(&QA
M(&-O;FYE>&EO;B!A=2!S97)V975R(*N@)7.@NR!V:6$@1E10H#H@)7,`0W+I
M871I;VX@9&4@;&ES=&4@9&4@9&ES=')I8G5T:6]N(&EM<&]S<VEB;&4N("5S
M`$EM<&]S<VEB;&4@9&4@9.EC:&EF9G)E<B!L97,@9&]N;NEE<R!01U"@.B``
M26UP;W-S:6)L92!D92!DZ6-H:69F<F5R(&QE<R!D;VYNZ65S(%,O34E-12X`
M3F4@<&5U="!P87,@<W5P<')I;65R(&QE(&-O;G1A8W0@)7,`3F4@<&5U="!P
M87,@<W5P<')I;65R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B`E<P!.92!P
M975T('!A<R!S=7!P<FEM97(@;&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(*N@
M)7.@NRX`1.ET97)M:6YA=&EO;B!D92!L)V%D<F5S<V4@9'4@9&5S=&EN871A
M:7)E(&EM<&]S<VEB;&4N`$YE('!E=70@<NEC=7#I<F5R('1O=70@;&4@8V%R
M;F5T(&0G861R97-S92X`3F4@<&5U="!RZ6-U<.ER97(@=&]U=&4@;&$@;&ES
M=&4@9&4@9&ES=')I8G5T:6]N+@!.)V$@<&%S('!U('+I8W5PZ7)E<B!L82!L
M:7-T92!C;VUP;.AT92!D92!L:7-T97,@9&4@9&ES=')I8G5T:6]N+@!);7!O
M<W-I8FQE(&1E(&-H87)G97(@;&$@<W1R873I9VEE(*N@)7.@NRX`26UP;W-S
M:6)L92!D92!C<NEE<B!L92!RZ7!E<G1O:7)E(*N@)7.@NRX`26UP;W-S:6)L
M92!D)V]B=&5N:7(@;&$@8VQE9B!P=6)L:7%U92#@('!A<G1I<B!D=2!S97)V
M975R(&1E(&-L969S+@!/=79E<G1U<F4@9&4@JZ`E<Z"[(&EM<&]S<VEB;&4@
M96X@Z6-R:71U<F4N`$]U=F5R='5R92!D92`E<R!I;7!O<W-I8FQE+@!);7!O
M<W-I8FQE(&0G;W5V<FER(&QE(&UO9'5L92!-86EN=&5N86YC95]487-K("5S
M`$]U=F5R='5R92!D=2!D;W-S:65R(*N@)7.@NR!I;7!O<W-I8FQE+@!);7!O
M<W-I8FQE(&0G871T96EN9')E(&QE('-E<G9E=7(@3$1!4"X`3&5C='5R92!D
M92`E<R!I;7!O<W-I8FQE+B``3B=A('!U(')E;65T=')E(.`@>NER;R!L92!M
M;W0@9&4@<&%S<V4@<&]U<B!L)W5T:6QI<V%T975R(&1E;6%N9.DN($-E<G1A
M:6YS("AO=2!T;W5S*2!L97,@9.ET86EL<R!N92!S;VYT('!A<R!C;W)R96-T
M<RX@4NEE<W-A>65Z(&]U(&-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U
M<B!P;W5R(&1E(&PG86ED92X`4NEC=7#I<F%T:6]N(&1E<R!!0TP@:6UP;W-S
M:6)L90!.92!P975T('+I8W5PZ7)E<B!L92!C87)N970@9"=A9')E<W-E<RX@
M)7,`3F4@<&5U="!RZ6-U<.ER97(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N
M+B`E<P!.92!P975T('+I8W5PZ7)E<B!L97,@;&ES=&5S(&1E(&1I<W1R:6)U
M=&EO;BX@)7,`3F4@<&5U="!RZ6-U<.ER97(@;&5S('!O<W-I8FEL:73I<R!D
M=2!S97)V975R`$YE('!E=70@<&%S(')E=F5N:7(@X"!L82!C;VYF:6=U<F%T
M:6]N('!RZ6/I9&5N=&4N`$5F9F%C96UE;G0@9'4@9&]S<VEE<B"KH"5SH+L@
M:6UP;W-S:6)L92X@`$YE('!E=70@<&%S(&5N<F5G:7-T<F5R(&QA(&-O;F9I
M9W5R871I;VX@)7,`3F4@<&5U="!P87,@96YR96=I<W1R97(@=6YE('-A=79E
M9V%R9&4@9&4@;&$@8V]N9FEG=7)A=&EO;BX`26UP;W-S:6)L92!D)V5N<F5G
M:7-T<F5R('5N92!C;W!I92!D92!L82!C;VYF:6=U<F%T:6]NH#H@)7,`26UP
M;W-S:6)L92!D)V5N<F5G:7-T<F5R(&QE('-C<FEP="!D92!M:7-E(.`@:F]U
M<B!D86YSH#H@JZ`E<Z"[+@!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@=6YE
M(&-O<&EE(&1U(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RX`26UP;W-S
M:6)L92!D)V5N<F5G:7-T<F5R(&QE(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO
M;B`E<RX@5F]U<R!P;W5V97H@<V]I="!U=&EL:7-E<B!U;F4@9&5S(&]P=&EO
M;G,@<&]U<B!S875V97(@;&4@8V]D92!S=7(@)7,@<V]I="!C;W!I97(@;6%N
M=65L;&5M96YT(&QE(&-O9&4@8VDM9&5S<V]U<R!D86YS("5S+@!.92!P975T
M('!A<R!R96-H97)C:&5R(&QE('-E<G9E=7(@3$1!4"X`4W5P<')E<W-I;VX@
M9&4@JZ`E<Z"[(&EM<&]S<VEB;&4N`$UI<V4@X"!J;W5R(&1U(&-O;G1A8W0@
M:6UP;W-S:6)L92X@)7,`3F4@<&5U="!M971T<F4@X"!J;W5R(&QA(&QI<W1E
M(&1E(&1I<W1R:6)U=&EO;BX@)7,`3F4@<&5U="!P87,@96YR96=I<W1R97(@
M;&$@8V]N9FEG=7)A=&EO;B!P;W5R(*N@)7.@NZ`Z("5S`$YE('!E=70@=')O
M=79E<B!L82!B87)R92!D92!-;WII;&QA+B`@07-S=7)E>BUV;W5S('%U)V5L
M;&4@97-T(&%C=&EV92X`3F4@<&5U="!A='1R:6)U97(@8V5S(&1R;VET<R#@
M(&PG=71I;&ES871E=7(@JZ`E<Z"[("!S=7(@;&4@9&]S<VEE<B"KH"5SH+N@
M.B`E<P!497AT92!C;VUP=.D`4&%Y<P!#;W5R<P!#<NEE<@!#<NEE<B!U;B!A
M9V5N9&$`0W+I97(@=6X@;F]U=F5L(.EVZ6YE;65N=`!#<NEE<B!U;B!L:65N
M`$-RZ65R('5N(&YO=79E874`0W+I97(@=6X@<V]U<RUD;W-S:65R`$-RZ>D`
M4&5R;6ES<VEO;G,@1&4@0W+I871E=7(`3G5MZ7)O(&1E(&-A<G1E(&1E(&-R
MZ61I=`!#<F]A=&EE`$-U8F$`0V]U<F%N=``T('!H87-E<R!C;W5R86YT97,`
M4V5S<VEO;G,@96X@8V]U<G,`2&5U<F4@86-T=65L;&4`3"=A9')E<W-E(%52
M3"!A8W1U96QL92!E<W0`571I;&ES871E=7)S(&%C='5E;',`3V)S97)V871I
M;VYS(&%C='5E;&QE<P!#;VYD:71I;VX@86-T=65L;&6@.B``4W1Y;&4@8V]U
M<F%N=`!$Z69I;FER(&QE<R!TXF-H97,@X"!E9F9E8W1U97(@;&]R<R!D92!L
M82!C;VYN97AI;VX@X"`E<RX`0V]U<&5R`$-O=7!E<B!L82!SZ6QE8W1I;VX`
M0VAY<')E`$-Y<FEL;&EQ=64@*$M/23@M4BD`0WER:6QL:7%U92`H5VEN9&]W
M<RTQ,C4Q*0!#>7)I;&QI<75E+U5K<F%I;FEE;B`H2T])."U5*0!2Z7!U8FQI
M<75E(%1C:.AQ=64`2DH`1%-.("A#9BX@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!#
M:&%Q=64@:F]U<@!1=6]T:61I96Z@.B!RZ7#I=&ET:6]N(&-H87%U90!.879I
M9V%T975R(&1E($1A=&%4<F5E`$%L:6%S(&1E(&QA(&)A<V4`1&%T90!$871E
M(&1E('+I8V5P=&EO;@!3Z6QE8W1I;VX@9"=U;F4@9&%T90!*;W5R`$IO=7(H
M<RD`7U-U<'!R:6UE<@!3=7!P<FEM97(@7VQA(&-O;&]N;F4`1.EC96UB<F4`
M3F]M8G)E<R!DZ6-I;6%U>`!$Z6-L:6[I`$1I;6EN=65R(&PG:6YD96YT871I
M;VX`1.EF875T`$%G96YD82!P87(@9.EF875T`$-O=6QE=7(@<&%R(&3I9F%U
M=`!)9&5N=&ETZ2!P87(@9.EF875T`$EN=&5R<'+I=&5U<B!D92!C;VUM86YD
M92!P87(@9.EF875T`$3I9FEN:71I;VYS`%-U<'!R:6UE<@!3=7!P<FEM97(@
M)7,`169F86-E<B!L82!C96QL=6QE`%-U<'!R:6UE<B!L)^EVZ6YE;65N=`!3
M=7!P<FEM97(@=6X@9W)O=7!E`$5F9F%C97(@;&$@=')A8V4`4W5P<')I;65R
M('5N92!P97)M:7-S:6]N`%-U<'!R:6UE<B!E="!P=7)G97(@;&5S(&UE<W-A
M9V5S`$5F9F%C97(@;&$@8V5L;'5L90!%9F9A8V5R(&QA(&-O;&]N;F4`4W5P
M<')I;65R('5N(&%U=')E(&UO9.AL92!E>&ES=&%N=`!3=7!P<FEM97(@;&5S
M('!E<FUI<W-I;VYS('!O=7(@JZ`E<Z"[`,IT97,M=F]U<R!C97)T86EN(&1E
M('9O=6QO:7(@969F86-E<B"KH"5SH+L@970@<V5S('-O=7,M<&5R;6ES<VEO
M;G.@/P!%9F9A8V5R(&QA(')A;F?I90!3=7!P<FEM97(@;"=I9&5N=&ETZ2!S
MZ6QE8W1I;VYNZ64`169F86-E<B!L82!C;VQO;FYE(&%C='5E;&QE`%-U<'!R
M:6UE<B!L)^EVZ6YE;65N="!C;W5R86YT('-E=6QE;65N="P@8V5T=&4@;V-C
M=7)R96YC92!E="!T;W5T97,@;&5S('-U:79A;G1E<RP@;W4@=&]U=&5S(&QE
M<R!O8V-U<G)E;F-E<Z`_`$5F9F%C97(@;&$@<F%N9^EE(&%C='5E;&QE`%-C
M<FEP="!D92!C;VYF:6=U<F%T:6]N(&1E(&UI<V4@X"!J;W5R('-U<'!R:6WI
M(*N@)7.@NRX`2&5U<F4@9&4@;&EV<F%I<V]N`$1A;F5M87)K`$1E<V-R:5]P
M=&EO;@!$Z6-R:7)E(&QE('!R;V)LZ&UE`$1E<V-R:7!T:6]N`$3I=&%I;',@
M*&%U<W-I(&1A;G,@;&4@9FEC:&EE<B!D92!T<F%C97,@9&4@2&]R9&4IH#H`
M3&5S(&3I=&%I;',@;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L)V%D;6EN:7-T
M<F%T975R+@!$Z79E;&]P<&5M96YT`%!O:6YT(&1E(')O<^EE`%!O:6YT(&1E
M(')O<^EE('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``4&]I;G0@9&4@<F]S
MZ66@.B``1&4@9V%U8VAE(.`@9')O:71E`$1E(&1R;VET92#@(&=A=6-H90!2
MZ7!E<G1O:7)E`$%F9FEC:&5R`$%F9FEC:&5R('-U<B`R-"!H975R97.@/P!!
M9F9I8VAE<B!L97,@86=E;F1A<P!/<'1I;VYS(&0G869F:6-H86=E`$%F9FEC
M:&5R(&QA('!RZ79I<VEO;B!DZ71A:6QLZ64`069F:6-H97(@;&$@<'+I=FES
M:6]N("A4048I`$9O<FUA="!D)V%F9FEC:&%G90!!=FES(&1E(&QI=G)A:7-O
M;@!$:FEB;W5T:0!.92!P87,@<W5P<')I;65R`$YE('!A<R!A8V/I9&5R(&1I
M<F5C=&5M96YT(.`@;6%I;G1E;F%N8V4N<&AP`%9O=6QE>BUV;W5S(&%F9FEC
M:&5R(&QE<R!TXF-H97,@<75I('9I96YN96YT(.`@Z6-HZ6%N8V4@9&%N<R!V
M;W1R92!A9V5N9&&@/P!.;VX@<NEPZ71I=&EF`$QE('!R96UI97(@96YR96=I
M<W1R96UE;G0@8V]N=&EE;G0M:6P@;&4@;F]M(&1E<R!C:&%M<'.@/R!$86YS
M(&PG869F:7)M871I=F4L(&-O8VAE>B!C971T92!B;^YT9:`Z`$1O;6EN:7%U
M90!2Z7!U8FQI<75E(&1O;6EN:6-A:6YE`%9O=7,@;B=A=F5Z('!A<R!D92!C
M;VUP=&6@/R!%;G)E9VES=')E>BUV;W5S+@!4Z6SI8VAA<F=E<@!4Z6SI8VAA
M<F=E<B`E<P!4Z6SI8VAA<F=E<B!L82!C;VYF:6=U<F%T:6]N(&?I;NERZ64@
M8V]M;64@=6X@<V-R:7!T(%!(4`!,:7-T92!DZ7)O=6QA;G1E`$1R;V=U97,`
MR6-HZ6%N8V6@.B`E<P!$=7+I90!#;W5R<FEE<B#I;&5C=')O;FEQ=64`4&EL
M;W1E(&1E('!A<W-E<F5L;&4@8V]U<G)I97(@+R!335,L('!O=7(@;&5S(&9O
M=7)N:7-S975R<R!D92!C92!S97)V:6-E+@!%4E(`R7%U871E=7(`36]D:69I
M97(`R61I=&5R("5S`,ED:71E<B!L97,@<&%R=&EC:7!A;G1S`,ED:71E<B!L
M92!B;&]C`,ED:71E<B!L97,@86=E;F1A<P#)9&ET97(@=6X@9W)O=7!E`,ED
M:71E<B!U;F4@<&5R;6ES<VEO;@#)9&ET97(@;&5S('!E<FUI<W-I;VYS`,ED
M:71E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`R61I=&5R(&1E<R!A
M9V5N9&%S(&1I<W1A;G1S`,ED:71E>B!L97,@<&%R=&EC:7!A;G1S`$UO9&EF
M:65R(&-A=.EG;W)I97,@970@Z71I<75E='1E<P#)9&ET97(@;&5S(&]P=&EO
M;G,@<&]U<J`Z`,ED:71E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`
MR61I=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R("5S`,ED=6-A=&EO;@#)9WEP
M=&4`4V%L=F%D;W(`R6SI;65N="XN+@!%;0!!9')E<W-E(.EL96-T<F]N:7%U
M90!#;W5R<FEE;`!,97,@861R97-S97,@Z6QE8W1R;VYI<75E<R!D;VEV96YT
M(&-O<G)E<W!O;F1R92X`0V]U<G)I97(@879E8R!C;VYF:7)M871I;VX`4&%S
M<V5R96QL92!C;W5R<FEE<B`O(%--4P#);6]T:6/T;F5S`$UE<W-A9V4@=FED
M92X`4NES=6QT870@=FED92X`5&5R;65S(&1E(')E8VAE<F-H92!V:61E`$9I
M7VX`06-T:79E<B!L)VEN<V5R=&EO;B!D)VEM86=E<R!V96YA;G0@9&5S(&%L
M8G5M<R!P:&]T;W,@9&%N<R!L92!T97AT9:`_`$%C=&EV97(@;&4@;65N=2!C
M;VYT97AT=65L(&%V96,@=6X@8VQI8R!D<F]I=*`_`$1A=&4@9&4@9FEN`$9I
M;B!L90!&:6X@X`!&:6X@9&4@;"=A;F[I90!!9W)A;F1I<B!L)^ED:71E=7(`
MR6-R:79E>B!U;F4@<75E<W1I;VX@9&4@<^EC=7)I=.D@<74G;VX@=F]U<R!P
M;W-E<F$@<VD@=F]U<R!D979E>B!R96UE='1R92#@('KI<F\@=F]T<F4@;6]T
M(&1E('!A<W-E+"!P87(@97AE;7!L92"K(%%U96P@97-T(&QE(&YO;2!D92!V
M;W1R92!A;FEM86P@<'+I9NERZ:`_H+N@.@!);G-C<FEV97H@;"=A9')E<W-E
M(%523"!D92!L)VEM86=E(&EC:0!%;G1R97H@;&5S(&QE='1R97,@8VDM9&5S
M<V]U<Z`Z`$=U:6[I92#I<75A=&]R:6%L90#)<GET:'+I90!%<G)E=7(`17)R
M975R(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@8FQO8Z`Z("5S`$5R<F5U<B!L
M;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E(&PG86YC<F4@9&4@<WEN8VAR;VYI
M<V%T:6]NH#H@)7,`17)R975R(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9'4@
M:F]U<FYA;"!D92!S>6YC:')O;FES871I;VZ@.B`E<P!%<G)E=7(@;&]R<R!D
M92!L82!RZ6-U<.ER871I;VX@9'4@8V]N=&5N=:`Z("5S`%5N92!E<G)E=7(@
M97-T('-U<G9E;G5E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE
M<R!I0V%L96YD87*@9&4@("5SH#H@)7,`17)R975R(&QO<G,@9&4@;&$@;6ES
M92#@(&IO=7(@9'4@;6]T(&1E('!A<W-EH#H@)7,`17)R975R(&%V96,@;&4@
M;65S<V%G92X`17)R975R(&QO<G,@9&4@;"=E;G)E9VES=')E;65N="!D92"K
MH"5SH+LN`$5S=&]N:64`R71H:6]P:64`171H;FEQ=64`175R;W!E`,EVZ6YE
M;65N="!A:F]U=.F@.@#)=NEN96UE;G0@<W5P<')I;>F@.@#)=NEN96UE;G0@
MZ61I=.F@.@#)=NEN96UE;G0@9'4@)7,@874@)7,`R7;I;F5M96YT(&YO;B!T
M<F]U=ND`3&5S(.EVZ6YE;65N=',@9&]I=F5N="!A=F]I<B!U;F4@9&%T92!D
M92!DZ6)U="X`3&5S(.EVZ6YE;65N=',@9&]I=F5N="!A=F]I<B!U;B!T:71R
M92X`5&]U<R!L97,@)F9R86,Q-#L@9"=H975R90!4;W5T97,@;&5S(#(@;6EN
M=71E<P!4;W5T97,@;&5S(#,P('-E8V]N9&5S`%1O=71E<R!L97,@-2!M:6YU
M=&5S`,`@8VAA<75E(&-O;FYE>&EO;@!4;W5T97,@;&5S("9F<F%C,3([(&AE
M=7)E<P!4;W5T97,@;&5S(&UI;G5T97,`17AE;7!L92!D92!V86QE=7)SH#H`
M17CI8W5T97(`1.EV96QO<'!E<@!$Z79E;&]P<&5R(&QE<R!N;VUS`$3I<&QI
M97(@;&$@8F%R<F4@9&4@8_1TZ0"K("D@NR!A='1E;F1U90!5;B!S975L(&UO
M="!O=2!E>'!R97-S:6]N(&5N=')E(&=U:6QL96UE=',@871T96YD=7,`1&%T
M92!D)V5X<&ER871I;VX`4F5P<NES96YT86YT`$5X<&]R=&5R`$5X<&]R=&5R
M(&PG86=E;F1A`$-O=6QE=7(@9"=A=F%N="UP;&%N`%3I;.EC:&%R9V5M96YT
M('9E<G,@;&4@<V5R=F5U<B!D92!L82!C;VYF:6=U<F%T:6]N('!A<B!&5%``
M3&5C='5R92!D97,@<'+I9NER96YC97,@:6UP;W-S:6)L92X`R6-H96,@9&4@
M;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@3$1!4"X`R6-H96,@9&4@;&$@8V]N
M;F5X:6]N(&%U('-E<G9E=7(@4TU"+@#)8VAE8R!D92!L82!C;W!I92!D97!U
M:7,@JZ`E<Z"[+@#)8VAE8R!D92!L82!C;W!I92!V97)S(""KH"5SH+LN`$EM
M<&]S<VEB;&4@9&4@8W+I97(@=6YE(&YO=79E;&QE(&-O;FYE>&EO;B!305-,
M`,EC:&5C(&1U(&3I<&QA8V5M96YT('9E<G,@JZ`E<Z"[+@#)8VAE8R!L;W)S
M(&1E(&QA('+I8W5PZ7)A=&EO;J`Z("5S`$)E874`SFQE<R!&86QK;&%N9"`H
M36%L;W5I;F5S*0#.;&5S($;I<F_I`$5R<F5U<B!F871A;&6@.@!&87@`5.EL
MZ6-O<&EE<P!&Z79R:65R`%1E;7#I<F%T=7)E(')E<W-E;G1I90!496UPZ7)A
M='5R92!R97-S96YT:66@.B``475E;'%U97,@879E<G-E<P!1=65L<75E<R!C
M:'5T97,@9&4@;F5I9V4`36%T<FEC92!D97,@8VAA;7!S`$9I9VQE="!#05!4
M0TA!`%!O;&EC92!D92!L82`\23YF:6=L970\+TD^`$9I9&II`$9I8VAI97(`
M3F]M8G)E(&1E(&9I8VAI97)SH#H@)7,`3F]M8G)E(&1E(&9I8VAI97)SH#H@
M)7,`1V5S=&EO;FYA:7)E(&1E(&9I8VAI97)S`$YO;2!D=2!F:6-H:65R`$-H
M;VEX(&1E(&9I8VAI97(`5.ELZ6-H87)G96UE;G0@9&4@9FEC:&EE<@!,)V5N
M=F]I(&1E(&9I8VAI97)S(&XG97-T('!A<R!P<FES(&5N(&-O;7!T92X`1FEL
M=')E<P!4<F]U=F5R`$9I;FQA;F1E`%!R96UIZ')E(&1E;6EE`%!R96UI97(@
M<75A<G1I97(`1FEX97(@;&4@<F%T:6\`4F5T;W5R;F5R`$9L;W1T86YT`$)R
M;W5I;&QA<F0`1&]S<VEE<B`E<R!I;F5X:7-T86YT+@!#;W5L975R(&1E('!O
M;&EC90!.;W5R<FET=7)E`%!O=7(@;&5S(&YA=FEG871E=7)S(&YE('-U<'!O
M<G1A;G0@<&%S(&QE<R!I;6%G97,`4'+I=FES:6]N("A4048I`$IO=7)S(&1E
M('!RZ79I<VEO;B`H;F]T97H@<75E(&QE<R!P<NEV:7-I;VYS(&9O=7)N:65S
M(&1O;FYE;G0@;&4@:F]U<B!E="!L82!N=6ETH#L@=6X@9W)A;F0@;F]M8G)E
M(&EC:2!P975T(&9A:7)E('5N(&)L;V,@='+H<R!L87)G90!6;W5S(&%V97H@
M;W5B;&GI('9O=')E(&UO="!D92!P87-S9:`_`$9O<FUU;&%I<F5S`$-I=&%T
M:6]N`%1Y<&4@9&4@8VET871I;VX`0VET871I;VYS`$-I=&%T:6]N<R`R`$9O
M<G5M<P!2961I<F5C=&EO;@!696X`0V%D<F5S`$9R86YC90!&<F%N8V4@;>ET
M<F]P;VQI=&%I;F4`3&EB<F4`1&ES<&]N:6)I;&ETZ7,`1W5Y86YE(&9R86[G
M86ES90!0;VQY;NES:64@9G)A;N=A:7-E`%1E<G)E<R!A=7-T<F%L97,@970@
M86YT87)C=&EQ=65S(&9R86[G86ES97,`5F5N9')E9&D`1&4`1'4@`$1E<V-R
M:7!T:6]N(&-O;7!LZ'1E`%!L96EN92!L=6YE`$YO;2!C;VUP;&5T`,`@=F5N
M:7(`1V%B;VX`06QB=6T@9"=O<FEG:6YE(&1E(&PG:6UA9V4`06QB=6V@.@!'
M86UB:64`2F5U`$?I;NER86QE`$?I;NER97(@;&$@8V]N9FEG=7)A=&EO;B!D
M92`E<P!#;V1E(&?I;NERZ0!'Z6]R9VEE`$%L;&5M86=N90!':&%N80!':6)R
M86QT87(`4'+I;F]M`$%L;&5R`$=O961E;`!#87)T97,@1V]O9VQE`%)E8VAE
M<F-H92!';V]G;&4`06QL97(@X"`E<P!.:79E874@9&4@9W)I<P!'<NAC90!'
M<F5C("A)4T\M.#@U.2TW*0!'<F_K;FQA;F0`1W)E;F%D90!!9&UI;FES=')A
M=&EO;B!D97,@9W)O=7!E<P!,97,@;F]M<R!D92!G<F]U<&4@;F4@<&5U=F5N
M="!P87,@ZG1R92!V:61E<P!'<F]U<%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J
M;W5T97(@;&4@9W)O=7!E("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U('-E
M<G9E=7*@.@!'<F]U<%]L9&%PH#H@<W5P<')E<W-I;VX@:6UP;W-S:6)L92!D
M=2!G<F]U<&4@)7,`1W)O=7!?;&1A<*`Z(&UO9&EF:6-A=&EO;B!I;7!O<W-I
M8FQE(&1U(&=R;W5P92`E<P!'<F]U<&5S`$=U861E;&]U<&4`1W5A;0!'=6%T
M96UA;&$`1W5E<FYE<V5Y`%!E<FUI<W-I;VYS(&1E<R!I;G9I=.ES`$QI=G)E
M(&0G;W(`1W5I;NEE`$=U:6[I92U":7-S874`1W5Y86YA`$A434P`2%1-3$%R
M96$@<F5F=7-E(&+J=&5M96YT(&1E('-U<'!R:6UE<B!L82!D97)N:>AR92!C
M96QL=6QE(&1E(&QA(')A;F?I90!(5$U,07)E82!R969U<V4@8NIT96UE;G0@
M9&4@<W5P<')I;65R(&QA(&1E<FYIZ')E(&-O;&]N;F4@9'4@=&%B;&5A=0!(
M5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I;65R(&QA(&1E<FYI
MZ')E(')A;F?I92!D=2!T86)L96%U`$%U=&AE;G1I9FEC871I;VX@2%144"!N
M;VX@=')O=7;I92X`2&'O=&D`06QG;W)I=&AM92!D92!H86-H86=E`$)R=6UE
M('/H8VAE`$5N+73J=&4`16XM=.IT97,`SFQE<R!(96%R9"!E="!-8T1O;F%L
M9`!/<F%G97,@=FEO;&5N=',`2.EB<F5U("A)4T\M.#@U.2TX+4DI`$AA=71E
M=7(`06ED90!!:61E('!O=7(@;"?I9&ET975R`$%I9&4`2.EM:7-P:.AR90!6
M;VEC:2!L92!DZ6)U="!D=2!F:6-H:65RH#H`0V%C:&5R`$-A8VAE<B`E<P!(
M875T90!!7V-C=65I;`!#:73I(&1U(%9A=&EC86X`06-C=65I;`!!9')E<W-E
M('!E<G-O;FYE;&QE`%+I<&5R=&]I<F4@<&5R<V]N;F5L`%3I;.EP:&]N92!P
M97)S;VYN96P`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
MH#H@9&]N;NEE<R!834P@)7,@:6YV86QI9&5S(')E=')O=7;I97,@9&%N<R!L
M92!M97-S86=E("5S`$AO<F1E+TMO;&%BH#H@875C=6X@;65S<V%G92!N92!C
M;W)R97-P;VYD(&%U('-U:F5T("5S`$AO<F1E+TMO;&%BH#H@<&%S(&0G;V)J
M970@9&4@='EP92`E<R!T<F]U=ND@9&%N<R!L92!M97-S86=E("5S`$AO<F1E
M+TMO;&%BH#H@)7,@<W5P<')I;>D@JZ`E<Z"[(&%V96,@<W5C8^AS`$AO<F1E
M+TMO;&%BH#H@;&4@;6]T975R(&0G:6YTZ6=R871I;VX@;NEC97-S:71E(&PG
M97AT96YS:6]N("=D;VUX;6PG(&1E(%!(4`!(;W)D92]+;VQA8J`Z(&EM<&]S
M<VEB;&4@9&4@8W+I97(@=6X@;F]U=F5L(&%R8G)E(%A-3"!P;W5R(&PG;V)J
M970@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&0G96YL979E<B`E<R"K
MH"5SH+N@.B`E<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<NEC=7#I
M<F5R(&PG:61E;G1I9FEA;G0@34E-12!P;W5R(&QA('!A<G1I92!D92!T>7!E
M("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D92!S>6YC:')O;FES97(@
M)7,@JZ`E<Z"[H#H@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E('-Y
M;F-H<F]N:7-E<B!L97,@<&%R=&%G97.@.B`E<P!(;W)D92]+;VQA8J`Z('!A
M<G1A9V4@:6YC;VYN=2"KH"5SH+L`3&EG;F4@:&]R:7IO;G1A;&4`4F5M<&QI
M<W-A9V4@:&]R:7IO;G1A;`!(;W)I>F]N=&%LH#H`2&5U<F4H<RD`0V]M;65N
M="#J=&5S+79O=7,@87)R:7;I(&EC::`_("A35E`@<F%P<&]R=&5Z+6QEH"$I
M`$1U<NEE(&1E<R!T<F%N8VAE<R!H;W)A:7)E<R!D86YS(&QE<R!V=65S(.`@
M;&$@:F]U<F[I92!E="#@(&QA('-E;6%I;F6@/P!#;VUB:65N(&1E(&-O;&]N
M;F5S('9O=6QE>BUV;W5S(&9U<VEO;FYE<J`_`%!O=7(@8V]M8FEE;B!D92!J
M;W5R<R#@(&QA(&9O:7,@9&]I="UO;B!GZ6[I<F5R(&QE<R!I;F9O<FUA=&EO
M;G,@<W5R(&QA(&1I<W!O;FEB:6QI=.F@/P!#;VUB:65N(&1E(&-H86UP<R`H
M8V]L;VYN97,I('D@82UT+6ELH#\`0V]M8FEE;B!D92!R86YGZ65S('9O=6QE
M>BUV;W5S(&9U<VEO;FYE<J`_`$AU;6ED:73I`$AU;6ED:73IH#H@`$AU;6]R
M:7-T97,`2&]N9W)I90#)8VAE8R!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1E(&QA
M(&)O[G1E($E-05"@.B`E<P#)8VAE8R!L;W)S(&1E(&QA('-U<'!R97-S:6]N
M(&1E(&QA(&)O[G1E($E-05"@.B`E<P#)8VAE8R!L;W)S(&1E(&QA(&-RZ6%T
M:6]N(&1U('%U;W1A('-U<B!L82!B;^YT92!)34%0H#H@)7,`061R97-S92!)
M4`!!9')E<W-E($E0(&YO;B!D:7-P;VYI8FQE+@!!9')E<W-E($E0(&AO<G,@
M9'4@8FQO8R!#2412(&%L;&]UZ2X`5FEO;&%T:6]N(&1E(&)L;V-A9V4@25`N
M`$E?;G/I<F5R(')A;F?I92!A=F%N=`!)<VQA;F1E`$EC]&YE<R!S975L96UE
M;G0`26/T;F5S('!O=7(@)7,`26/T;F5S('!L=7,@=&5X=&4`3F]M(&1U(&-O
M;7!T9:`Z`%-I(&PG869F:6-H86=E(&XG97-T('!A<R!C;W)R96-T+"`E<R!P
M;W5R(&PG;W5V<FER(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4N`%-I('9O
M=7,@;F4@=F]Y97H@875C=6X@:6/T;F4@96X@=71I;&ES86YT($EN=&5R;F5T
M($5X<&QO<F5R+"!V;W5S('!O=79E>B!A=F]I<B#@(&-O8VAE<B!C971T92!C
M87-E('!O=7(@9.ES86-T:79E<B!L82!T<F%N<W!A<F5N8V4@9&5S(%!.1RX`
M4VD@=F]U<R!V;WEE>B!C92!M97-S86=E(&UA:7,@875C=6YE(&EM86=E+"!L
M)VEM86=E('%U92!V;W5S('9O=6QE>B!E;G9O>65R(&YE('!E=70@ZG1R92!A
M9F9I8VCI92!P87(@=F]T<F4@;F%V:6=A=&5U<BX`4VD@=F]T<F4@;&]G:6-I
M96P@9&4@8V]U<G)I97(@;F4@<W5P<&]R=&4@<&%S(&QE<R!R97%UZG1E<R!I
M5&EP('9O=7,@<&]U=F5Z('5T:6QI<V5R('5N(&1E<R!L:65N<R!S=6EV86YT
M<R!P;W5R(&%C8V5P=&5R(&]U(')E9G5S97(@;"?I=NEN96UE;G0N"@I0;W5R
M(&%C8V5P=&5R(&PGZ7;I;F5M96YTH#H*)7,*"E!O=7(@86-C97!T97(@;"?I
M=NEN96UE;G0@<')O=FES;VER96UE;G2@.@HE<PH*4&]U<B!R969U<V5R(&PG
MZ7;I;F5M96YTH#H*)7,`07!E<N=U(&1E(&PG:6UA9V6@.@!!9')E<W-E(%52
M3"!D92!L)VEM86=E`$%D<F5S<V4@55),(&1E(&PG:6UA9V6@.@!);6%G92!D
M92!L)V%L8G5M`$EM86=E(&1E(&PG86QB=6V@.@!4Z6SI8VAA<F=E;65N="!D
M)VEM86=E<P!);6%G97,`26UP;W)T97(@=6X@86=E;F1A+"#I=&%P92`E9`!)
M;7!O<G1A=&EO;BP@Z71A<&4@)60`26UP;W)T97(O17AP;W)T97(@=6X@86=E
M;F1A`$-H86UP(&EM<&]R=.F@.B`E<P!#:&%M<',@:6UP;W)TZ7.@.@!);E]S
MZ7)E<B!R86YGZ64@87!RZ',`0V]D92!D)V%C=&EO;B!I;F-O<G)E8W0N`$YO
M;2!D)W5T:6QI<V%T975R(&5T+V]U('9O=')E(&UO="!D92!P87-S92!I;F-O
M<G)E8W0N`$YO;2!D)W5T:6QI<V%T975R(&]U(&%D<F5S<V4@86QT97)N871I
M=F4@:6YC;W)R96-T+B`@4NEE<W-A>65Z(&]U(&-O;G1A8W1E>B!V;W1R92!A
M9&UI;FES=')A=&5U<B!S>7-TZ&UE('!O=7(@9&4@;"=A:61E+@!!=6=M96YT
M97(@;"=I;F1E;G1A=&EO;@!);F1E`%5T:6QI<V%T975R<R!I;F1I=FED=65L
M<P!);F1O;NES:64`26YF;P!);F9O<FUA=&EO;G,`3"=I;F9O<FUA=&EO;B!N
M)V5S="!P;'5S(&1I<W!O;FEB;&4N`$EN<^ER97(@8U]O;&]N;F4@87!RZ',`
M26YSZ7)E<B!I;6%G90!);G/I<F5R('5N('1A8FQE874`26YSZ7)E<B!U;B!L
M:65N('=E8@!);G/I<F5R(%]C;VQO;FYE(&%V86YT`$EN<^ER97(@=6YE(&YO
M=79E;&QE(&-O;&]N;F4@87!RZ',@;&$@8V]L;VYN92!A8W1U96QL90!);G/I
M<F5R('5N92!N;W5V96QL92!C;VQO;FYE(&%V86YT(&QA(&-O;&]N;F4@86-T
M=65L;&4`26YSZ7)E<B!U;F4@;F]U=F5L;&4@<F%N9^EE(&%P<NAS(&QA(')A
M;F?I92!A8W1U96QL90!);G/I<F5R('5N92!N;W5V96QL92!R86YGZ64@879A
M;G0@;&$@<F%N9^EE(&%C='5E;&QE`$EN<^ER97(@=6X@<&%R86=R87!H92!A
M<'+H<R!L92!N)F]E;&EG.W5D(&%C='5E;`!);G/I<F5R('5N('!A<F%G<F%P
M:&4@879A;G0@;&4@;B9O96QI9SMU9"!A8W1U96P`26YSZ7)E<B!U;B!A=71R
M92!M;V3H;&4`26YS8W)I=F5Z('5N92!A9')E<W-E(&1E(&-O=7)R:65R(.`@
M;&%Q=65L;&4@=F]U<R!R96-E=G)E>B!L92!N;W5V96%U(&UO="!D92!P87-S
M9:`Z`$EN<^ER97(@8V5L;'5L92!A<'+H<P!);G/I<F5R(&-E;&QU;&4@879A
M;G0`26YSZ7)E<B!C;VQO;FYE(&%P<NAS`$EN<^ER97(@8V]L;VYN92!A=F%N
M=`!);G/I<F5R(&QE<R!M97-S86=E<P!);G/I<F5R('!A<F%G<F%P:&4@87!R
MZ',`26YSZ7)E<B!P87)A9W)A<&AE(&%V86YT`$EN<^ER97(@<F%N9^EE(&%P
M<NAS`$EN<^ER97(@<F%N9^EE(&%V86YT`$EN<V-R:79E>B!L82!RZ7!O;G-E
M(.`@;&$@<75E<W1I;VX@9&4@<^EC=7)I=.F@.@!);G/I<F5R+TUO9&EF:65R
M('5N92!I;6%G90!);G/I<F5R+TUO9&EF:65R('5N(&QI96X@=V5B`$-RZ61I
M="!I;G-U9F9I<V%N="!P;W5R(&5N=F]Y97(@X"!L82!L:7-T92!D92!D:7-T
M<FEB=71I;VXN`$-RZ61I="!I;G-U9F9I<V%N="X`16YT:65R`$QI<W1E(&-O
M;7!LZ'1E`%5$2"`H57-E<B!$871A($AE861E<BD@:6YV86QI9&4`1&]N;NEE
M(%I)4"!I;G9A;&ED92X`07!P;&EC871I;VX@:6YV86QI9&4N`$=R;W5P92!)
M1"!I;G9A;&ED92X`16YV;VD@9&4@9&]N;NEE<R!I;G9A;&ED97,N`$%D<F5S
M<V4@9&4@9&5S=&EN871I;VX@:6YV86QI9&4N`$9O<FUA="!D92!F:6-H:65R
M(&EN=F%L:61E+@!#;&5F(&1E(&QI8V5N8V4@:6YV86QI9&4N`$5M<&QA8V5M
M96YT(&EN9&EQ=>D@:6YV86QI9&4N`*MM<V=?='EP9;L@:6YV86QI9&4N`*MA
M<&E?:62[(&EN=F%L:61E(&]U(&UA;G%U86YT+@!087)A;>AT<F5S(&EN=F%L
M:61E<R!O=2!M86YQ=6%N=',N`%!E<FUI<W-I;VX@:6YV86QI9&4N`$ED+B!D
M92!P87)T96YA:7)E(&EN=F%L:61E+@!#;V1E(&1E('!R;V1U:70@:6YV86QI
M9&4N`%!R;W1O8V]L92!I;G9A;&ED92X`1&5S=&EN871A:7)E(&EN=F%L:61E
MH#H@JZ`E<Z"[`$]B:F5T(&1E('!A<G1A9V4@:6YV86QI9&4`061R97-S92!S
M;W5R8V4@:6YV86QI9&4N`$1O;F[I92!5;FEC;V1E(&EN=F%L:61E+@!);G9E
M;G1A:7)E`$EN=F5R<V5R(&QA('/I;&5C=&EO;@!)<F%N`$ER86L`27)L86YD
M90#.;&4@9&4@36%N`%1E;7#J=&5S(&ES;VSI97,`27-R8>ML`,EM971T975R
M`$ET86QI<75E`$ET86QI90!*86UA[W%U90!*86YV:65R`$IA<&]N`$IA<&]N
M86ES("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE`$IU:6QL970`2G5I
M;@!*=7-T:69I97(`0V5N=')E<@!*=7-T:69I97(`06QI9VYE<B#@(&=A=6-H
M90!!;&EG;F5R(.`@9')O:71E`$MA>F%K:'-T86X`1V%R9&5R(&PG;W)I9VEN
M86R@/P!+96YY80!,92!S97)V975R($ME<F)E<F]S(&$@<F5J973I(&PG875T
M:&5N=&EF:6-A=&EO;BX`1.EB=71A;G1S(&1U(&YO>6%U`$-RZ6%T:6]N(&1E
M(&-L968`16UP<F5I;G1E(&1E(&QA(&-L968`3&]N9W5E=7(@9&4@;&$@8VQE
M9@!4>7!E(&1E(&-L968`571I;&ES871I;VX@9&4@;&$@8VQE9@!,82!C;&5F
M('-E('1R;W5V92!DZ6K@('-U<B!L92!S97)V975R(&1E(&-L969S('!U8FQI
M8RX`36]T<RUC;.ES`$5N9F%N=',`2VER:6)A=&D`0V]RZ64@9'4@3F]R9`!#
M;W+I92!D=2!3=60`0V]RZ65N("A%54,M2U(I`$MO=V7O=`!+:7)G:&EZ:7-T
M86X`4'+I7W-E;G1A=&EO;@!,86YG=64`3&%O<P!$97)N:>AR97,@,C0@:&5U
M<F5S`$1E<FYIZ')E(&1E;6EE`$1E<FYIZ')E(&UO9&EF:6-A=&EO;@!-;VES
M('!RZ6/I9&5N=`!$97)N:>AR92!M;V1I9FEC871I;VX@9'4@;6]T(&1E('!A
M<W-E`$1E<FYI97(@<75A<G1I97(`1&5R;FGH<F4@;6ES92#@(&IO=7*@.@!!
M;F[I92!P<NECZ61E;G1E`$1E<FYIZ')E(&-O;FYE>&EO;J`Z("5S`$1E<FYI
MZ')E(&-O;FYE>&EO;J`Z("5S(.`@<&%R=&ER(&1E("5S`$1E<FYIZ')E(&-O
M;FYE>&EO;J`Z(&IA;6%I<P!396UA:6YE('!RZ6/I9&5N=&4`3&5T=&]N:64`
M3&]I`%!RZ7-E;G1A=&EO;@!,86ES<V5R('9I9&4@<&]U<B!N92!P87,@879O
M:7(@9&4@8F]R9'5R90!,:6)A;@!'875C:&4`16YTZG1E(&=A=6-H90!686QE
M=7)S(&1E(&=A=6-H90!,97-O=&AO`$YI=F5A=0!,:6+I<FEA`$QI8GEE`$QI
M96-H=&5N<W1E:6X`0G)U:6YE(&SI9^AR90!0;'5I92!LZ6?H<F4`4&QU:64@
M;.EGZ')E('3T="!D86YS(&QA(&IO=7)NZ64`4&QU:64@;.EGZ')E('1A<F0`
M079E<G-E<R!LZ6?H<F5S`%!L=6EE(&SI9^AR92!A=F5C('1O;FYE<G)E`$YE
M:6=E(&EN=&5R;6ET=&5N=&4`079E<G-E(&1E(&YE:6=E(&SI9^AR90!2:6UE
M<P!,:6UI=&5R(&QA('#I<FEO9&4@X"!E>'!O<G1E<J`Z`$QI96X`3&4@;&EE
M;B!P;VEN=&4@=F5R<Z`Z`$QI92!L)V%D<F5S<V4@9&4@8V]U<G)I96P@X"!L
M82!P86=E(&1E(&-O;7!O<VET:6]N(&1U(&UE<W-A9V4@96X@;"=A9F9I8VAA
M;G0`3&EE;G,`0FES8W5I="!,:6YU>`!,:7-T92`M('5T:6QI<V%T975R('!E
M=70@=F]I<B!L92!D;W-S:65R`$QI<W1E(&1E<R!B87-E<R!D92!D;VYNZ65S
M`$EN9&5X(&1E(&PG86ED90!!9F9I8VAE<B!L97,@=&%B;&5S`$%R8VAI=F5S
M(&1E(&QA(&QI<W1E`$%I9&4@9&4@;&$@;&ES=&4`260N(&1E(&QA(&QI<W1E
M`%!R;W!R:>ET86ER92!D92!L82!L:7-T90!%;G9O:2#@(&QA(&QI<W1E`$%B
M;VYN96UE;G0@X"!L82!L:7-T90!$Z7-A8F]N;F5M96YT(&1E(&QA(&QI<W1E
M`,EC:&5C(&1E(&QA(&QI<W1E(&1E<R!S97-S:6]N<Z`Z("5S`,EC:&5C(&1E
M(&QA(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G.@.B`E<P!,)V%F9FEC:&%G92!D
M92!L82!L:7-T92!D97,@=71I;&ES871E=7)S(&5S="!DZ7-A8W1I=NDN`$QI
M='3I<F%T=7)E`$QI='5A;FEE`$Q?:65U`$-H87)G96UE;G0N+BX`2&5U<F4@
M;&]C86QEH#H@`$AE=7)E(&5T(&QO8V%L90!,:65U`$-O;FYE>&EO;@!4<F%C
M92!D92!L82!D97)N:>AR92!S97-S:6]N(&1E('-Y;F-H<F]N:7-A=&EO;@!$
MZ6-O;FYE>&EO;@!#;VYN97AI;VX`5.)C:&5S(&1E(&-O;FYE>&EO;@!,82!C
M;VYN97AI;VX@97-T(')E9G5SZ64N($EL(&5S="!P<F]B86)L92!Q=64@=F]T
M<F4@;F]M(&0G=71I;&ES871E=7(@;W4@=F]T<F4@;6]T(&1E('!A<W-E(&$@
MZ73I(&UA;"!S86ES:0#)8VAE8R!D92!C;VYN97AI;VXN`%1E>'1E(&QO;F<`
M06UO=7(`1F%I8FQE`$QE='1R92!G<F5C<75E<R!M:6YU<V-U;&5S`$QE='1R
M92!L871I;F5S(&UI;G5S8W5L97,`3F]M8G)E(')O;6%I;G,@;6EN=7-C=6QE
M<P!,=7AE;6)O=7)G`$U-`$UE<W-A9V4@9'4@:F]U<B`H34]41"D`3&$@<&GH
M8V4@:F]I;G1E($U3+51.148@;F4@8V]N=&5N86ET(&%U8W5N92!D;VYNZ64N
M`$U31P!-86-A;P!2Z7!U8FQI<75E(&1E($UA8^ED;VEN90!-861A9V%S8V%R
M`$UA9VEE`$-O=7)R:65R`$%D;6EN:7-T<F%T:6]N(&1U(&-O=7)R:65L`$9A
M:7)E('5N(&QI95]N`$UA;&%W:0!-86QA:7-I90!-86QD:79E<P!-86QI`$UA
M;'1E`$=E<W1I;VX@9&5S(&%G96YD87,@9&ES=&%N=',N`$%D;6EN:7-T<F5Z
M(&QA(&QI<W1E(&1E(&-A=.EG;W)I97,@970@;&5S(&-O=6QE=7)S(&QIZ65S
M(.`@8V5S(&-A=.EG;W)I97,N`$-A<G1E(*L@36%P,C0@NP!#87)T92"K($UA
M<'%U97-T(+L`0V]R<F5S<&]N9&%N8V5S(&5N<F5G:7-T<NEE<RX`36%R<P!-
M87)G90!-87)Q=65R(&%V96,@9&5S(.ET:7%U971T97,@5G4O3F]N('9U`$UA
M<G%U97(@879E8R!D)V%U=')E<R#I=&EQ=65T=&5S("AE>"XZ($EM<&]R=&%N
M="]2Z7!O;F1U*0#.;&5S($UA<G-H86QL`$UA<G1I;FEQ=64`0VAA;7!S(&%P
M<&%R96YTZ7,`36%U<FET86YI90#.;&4@36%U<FEC90!#<NED:70@;6%X:6UU
M;2!A;&QO=>DN`$QI;6ET92!D=2!M97-S86=E(&3I<&%S<^EE+@!496UPZ7)A
M='5R92!M87AI;6%L92!D97,@,C0@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!496UP
MZ7)A='5R92!M87AI;6%L92!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@`$YO
M;6)R92!M87AI;6%L(&0GZ7;I;F5M96YT<P!.;VUB<F4@;6%X:6UU;2!D92!B
M;&]C<R!D=2!P;W)T86EL`$QO;F=U975R(&UA>&EM=6T`36%I`$UA>6]T=&4`
M36]I`$WI9&EC86UE;G0`4NEU;FEO;@!-96UB<F5S`$UE;G4@9&5S(&%L97)T
M97,`365N=0!4>7!E(&1E(&UE;G6@.@!&=7-I;VYN97(@;&5S(&-E;&QU;&5S
M`$UE<W-A9V4`5NER:69I8V%T:6]N(&1U(&UE<W-A9V4@<NEU<W-I92P@;6%I
M<R!L92!C97)T:69I8V%T(&1U('-I9VYA=&%I<F4@;B=A('!A<R!P=2#J=')E
M(';I<FEF:>DN`$UE<W-A9V4@97AP:7+I+@!4>7!E(&1E(&UE<W-A9V4`3>ET
MZ6\@365T87(`3&4@8FQO8R"K($UE=&%R(+L@;B=E<W0@<&%S(&1I<W!O;FEB
M;&4N`$QE(&)L;V,@JR!-971A<B"[(&XG97-T('!A<R!D:7-P;VYI8FQE+B`@
M3&5S(&3I=&%I;',@;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L)V%D;6EN:7-T
M<F%T975R+@!-971A<D1"(&XG97-T('!A<R!C;VYN96-TZ2X`3>ET:&]D90!,
M82!MZ71H;V1E(*N@)7.@NR!N)V5S="!P87,@9.EF:6YI90!-Z71H;V1E(&YO
M;B!DZ69I;FEE+B!-Z71H;V1E(&%P<&5LZ66@.B`E<P!-Z71R:7%U90!-97AI
M<75E`,ET871S(&;I9.ERZ7,@9&4@36EC<F]NZ7-I90!-:6QI974`5'EP92!-
M24U%`%1E;7#I<F%T=7)E(&UI;FEM=6T@9&5S(#(T(&1E<FYIZ')E<R!H975R
M97.@.B``5&5M<.ER871U<F4@;6EN:6UU;2!D97,@-B!D97)N:>AR97,@:&5U
M<F5SH#H@`$QA(&1U<NEE(&UI;FEM86QE(&1U(&UO="!D92!P87-S92!N)V$@
M<&%S(&5N8V]R92!E>'!I<ND`36EN=71E*',I`$UI<F]I<@!687)IZ7,`3&4@
M<&%Q=65T86=E($A45%!?<F5Q=65S="!014%2(&5S="!M86YQ=6%N="X`0V]N
M9FEG=7)A=&EO;B!I;F5X:7-T86YT92X@5F]U<R!D979E>B!L82!GZ6[I<F5R
M(&UA:6YT96YA;G0@<VD@=F]U<R!V;W5L97H@=71I;&ES97(@8V5T=&4@87!P
M;&EC871I;VXN`$E$(&1U(&UE<W-A9V4@;6%N<75A;G0N`$QE('!A<75E=&%G
M92!014%2($UA:6P@97-T(&UA;G%U86YT+@!)1"!D92!S97-S:6]N(&UA;G%U
M86YT+@!,=6X`0V]U<G)I96P@<V%N<R!F:6P`36]DZ7+I`$1A=&4@9&4@;6]D
M:69I8V%T:6]N`$UO9&EF:65R(&PG55),`$UO9'5L;P!-;VQD879I90!-;VYA
M8V\`3'5N9&D`36]N9V]L:64`36]I<P!6=64@<&%R(&UO:7,`36]I<R!E="!A
M;F[I90!-96YS=65L;&5M96YT`$QI<W1E(&1E<R#I=NEN96UE;G1S(&UE;G-U
M96QS`$UE;G-U96R@.B!RZ7#I=&ET:6]N('1O=7,@;&5S`$UO:7,@X"!V96YI
M<@!-;VES('!RZ6/I9&5N=`!-;VYT<V5R<F%T`%!H87-E<R!D92!L82!L=6YE
M`$-H86UP<R!S=7!P;.EM96YT86ER97,@=')O=7;I<R#@(&QA(&QI9VYE("5D
M("AA='1E;F1U<R`E9"DN`$UA<F]C`$?I;NER86QE;65N="!E;G-O;&5I;&SI
M`$?I;NER86QE;65N="!N=6%G975X`$?I;NER86QE;65N="!E;G-O;&5I;&SI
M`%9E<G,@;&4@8F%S`$3I<&QA8V5R(.`@9V%U8VAE`$3I<&QA8V5R(.`@9')O
M:71E`%9E<G,@;&4@:&%U=`!697)S(&QE(&)A<P!697)S(&QE(&AA=70`36]Z
M86UB:7%U90!,:7-T97,@9.ER;W5L86YT97,@;75L=&DM;FEV96%U>`!#87)T
M92"KH$UU;'1I;6%P(%5+H+L`4&QU<VEE=7)S(&-O;7!O<V%N=',@:4-A;&5N
M9&%R('1R;W5VZ7,[('-E=6QE;65N="!U;B#I=NEN96UE;G0@97-T('-U<'!O
M<G3I+@!3Z6QE8W1I;VX@;75L=&EP;&4`4&%R86WI=')A9V4@9'4@8V]M<'1E
M`$UE<R!D;VYNZ65S('!E<G-O;FYE;&QE<P!-97,@86=E;F1A<P!-97,@86=E
M;F1A<Z`Z`$UO;B!54DP@9&4@9&ES<&]N:6)I;&ETZ7,`36]N('!O<G1A:6P`
M4'+I<V5N=&%T:6]N(&1E(&UO;B!P;W)T86EL`$)I<FUA;FEE`$Y/3BP@:F4@
M;B=A8V-E<'1E('!A<P!.;VT`3F%M:6)I90!.875R=0!.Z7!A;`!087ES+4)A
M<P!!;G1I;&QE<R!NZ65R;&%N9&%I<V5S`%523"!D92!B87-E(&1E($YE='-C
M87!E`%523"!D92!RZ79O8V%T:6]N(&1E(&PG02Y#+B!.971S8V%P90!54DP@
M9&4@;&$@<&]L:71I<75E(&0G02Y#+B!.971S8V%P90!54DP@9&4@<F5N;W5V
M96QL96UE;G0@3F5T<V-A<&4`55),(&1E('+I=F]C871I;VX@3F5T<V-A<&4`
M3F]M(&1U('-E<G9E=7(@4U-,($YE='-C87!E`$-O;6UE;G1A:7)E(&1U(&-E
M<G1I9FEC870@3F5T<V-A<&4`5'EP92!D=2!C97)T:69I8V%T($YE='-C87!E
M`%+I<V5A=0!*86UA:7,`3F]U=F5L;&4M0V%LZ61O;FEE`$YO=79E;&QE(&-A
M=.EG;W)I90!.;W5V96P@Z7;I;F5M96YT`$YO=79E874@;65S<V%G92#@("5S
M`$YO=79E;&QE(&QU;F4`3F]U=F5A=2!N;VT@9&4@8V]N;F5X:6]N("AF86-U
M;'1A=&EF*0!.;W5V96QL92U:Z6QA;F1E`$YO=79E;"!A9V5N9&$@8W+IZ2!E
M="!P87)T86?I(&%U=&]M871I<75E;65N="!A=F5C(&QE*',I(&=R;W5P92AS
M*2!S=6EV86YT*',IH#H@)7,N`$YO=79E874@;6]T(&1E('!A<W-E`$QE(&YO
M=79E874@;6]T(&1E('!A<W-E(&5X<&ER97)A(&QE("5X+@!,97,@;F]U=F5A
M=7@@;6]T<R!D92!P87-S92!D:69FZ')E;G0N`$YO=79E;&QE(&9E;NIT<F4@
M*%]B;&%N:RD`3F]U=F5L;&5S`$9O<G5M<P!3=6EV86YT`%!R;V-H86EN97,@
M,C0@:&5U<F5S`#0@<&AA<V5S('-U:79A;G1E<P!*;W5R('-U:79A;G0@`$UO
M:7,@<W5I=F%N=`!396UA:6YE('-U:79A;G1E(`!!;F[I92!S=6EV86YT90!*
M;W5R('-U:79A;G0`3W!T:6]N<R!S=6EV86YT97,`4V5M86EN92!S=6EV86YT
M90!3=6EV86YT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.=6ET`$YI=64`
M3F]N`$%U8W5N92!A;&5R=&4`075C=6X@<&%R=&EC:7!A;G0`4&%S(&1E(&1O
M;F[I97,@9&4@8V]N9FEG=7)A=&EO;B!P;W5R(&QE<W%U96QL97,@;6]N=')E
M<B!L97,@9&EF9NER96YC97,N`%!A<R!D92!S=')A=.EG:64@9&ES<&]N:6)L
M92!P;W5R(&9A:7)E(&1E<R!I;6%G97,@25-/+@!087,@9&4@9V%B87)I="!E
M;B!T<F%I=&5M96YT('!A<B!L;W0N`$%U8W5N(&)L;V,@;B=E>&ES=&4@X"!L
M82!P;W-I=&EO;B!D96UA;F3I90!087,@9&4@;F]M(&1E(&-A;&5N9')I97(@
M9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!-0T%,+@!087,@
M9"=A9V5N9&$@9&ES<&]N:6)L92!P;W5R(&QE<R!I;G9I=.ES+@!.;VX@;6]D
M:69IZ2X`075C=6YE('-O=7,M<&5R;6ES<VEO;B!N)V$@8F5S;VEN(&0GZG1R
M92!A:F]U=.EE('-O=7,@8V4@;FEV96%U+@!!=6-U;F4@:6YF;W)M871I;VX@
M9&4@8V]N9FEG=7)A=&EO;B!S<.EC:69IZ64@<&]U<B`E<RX`075C=6YE(&EN
M9F]R;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R($944"!6
M1E,N`$%U8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N
M:64@<&]U<B!344P@5D93+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG
M=7)A=&EO;B!F;W5R;FEE('!O=7(@4U%,+49I;&4@5D93+@!!=6-U;B!C<NED
M:70@9&ES<&]N:6)L92X`075C=6YE(&1E<W1I;F%T:6]N('1R;W5VZ64N`%!A
M<R!D92!D871E(&1E(&9I;@!!=6-U;B#I=NEN96UE;G0@X"!A9F9I8VAE<@!!
M=6-U;B!F:6-H:65R(&5N=F]YZ0!!=6-U;F4@:6YF;W)M871I;VX@<W5R(&QE
M<R!D:7-P;VYI8FEL:73I<R!D92`E<R!N)V5S="!A8V-E<W-I8FQE`$%U8W5N
M92!D;VYNZ64@:4-A;&5N9&%R('1R;W5VZ64N`$%U8W5N(&EC]&YE('1R;W5V
MZ2X`075C=6X@;&EE=2!N)V5S="!SZ6QE8W1I;VYNZ0!!=6-U;B!E;7!L86-E
M;65N="!N)V5S="!I;F1I<77I+@!!=6-U;B!M97-S86=E(&9O=7)N:0!!=6-U
M;B!N;VT@<W#I8VEF:>DN`$%U8W5N(&YO;6)R92!S<.EC:69IZ2X`4&%S(&0G
M87!H;W)I<VUE<R!C:&]Q=6%N=',`075C=6X@;6]T(&1E('!A<W-E(&9O=7)N
M:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@2%144"X`075C=6X@;6]T
M(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@
M24U!4"X`075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N
M=&EF:6-A=&EO;B!P87(@2V5R8F5R;W,N`$%U8W5N(&UO="!D92!P87-S92!S
M<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;BX`075C=6X@;6]T(&1E
M('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%!!4U-7
M1"X`075C=6X@;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT
M:69I8V%T:6]N(%--0BX`075C=6X@8VAE;6EN('9E<G,@;&4@8FEN86ER92!/
M<&5N4U-,(&9O=7)N:2X@3&4@8FEN86ER92!D)T]P96Y34TP@97-T(&[I8V5S
M<V%I<F4@<&]U<B!F;VYC=&EO;FYE<B!A=F5C(&1E<R!D;VYNZ65S(%!+0U,@
M,3(N`$%U8W5N92!C;VYF:7)M871I;VX@96X@871T96YT90!087,@9&4@<75O
M=&$@<&]S:71I;VYNZ2X`4V%N<R!RZ7#I=&ET:6]N`%!A<R!D92!RZ&=L97,`
M075C=6X@<^EP87)A=&5U<B!S<.EC:69IZ2X`4&%S(&1E(&/T=.ES`$9I8VAI
M97(@:6YE>&ES=&%N=`!!=6-U;B!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@97-T
M(&1I<W!O;FEB;&4@<&]U<B!L82!C86-H90!!=6-U;B!N;VT@9"=U=&EL:7-A
M=&5U<B!E="`O;W4@;6]T(&1E('!A<W-E(&5N=F]YZ2X`075C=6YE(&1O;F[I
M92!834P@=F%L:61E(&XG82#I=.D@<F5T;W5R;NEE`$%U8W5N92!A9')E<W-E
M(&1E(&-O=7)R:65R('1R;W5VZ64`4&%S(&1E('9A;&5U<@!087,@9&4@=F5R
M<VEO;B!T<F]U=NEE(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B!O<FEG:6YA;&4N
M(%+I9^ENZ7)E>B!L82!C;VYF:6=U<F%T:6]N+@!087,@9&4@=F5R<VEO;B!T
M<F]U=NEE(&1A;G,@=F]T<F4@8V]N9FEG=7)A=&EO;BX@4NEGZ6[I<F5Z(&QA
M(&-O;F9I9W5R871I;VXN`$%U8W5N90!!=6-U;B`H=71I;&ES97(@:6UP;&EC
M:71E;65N="D`3F]R9&EQ=64@*$E33RTX.#4Y+3$P*0#.;&4@3F]R9F]L:P!(
MZ6UI<W!HZ')E($YO<F0`SFQE<R!-87)I86YN97,@9'4@;F]R9`!.;W)VZ&=E
M`%!A<R!A<'+H<P!087,@879A;G0`4&%S('5N(&1O<W-I97(`3F]N('1R;W5V
MZ0!.;VX@:6UP;.EM96YTZ2X`26YA8W1I9@!.;VX@<')I<R!E;B!C;VUP=&4N
M`$YO=&5S`%)I96X@X"!N879I9W5E<BP@<F5T;W5R;F5Z(&5N(&%R<FGH<F4N
M`$YO=&EF:6-A=&EO;G,`3F]V96UB<F4`36%I;G1E;F%N=`!.;VUB<F4`3F]M
M8G)E(&1E(&-A<F%C=.AR97,`3F]M8G)E(&1E(&-O;&]N;F5S`$YO;6)R92!D
M92!R86YGZ65S`$YO;6)R92!N;VX@<W#I8VEF:>D@<&]U<B!L82!M:7-E(.`@
M:F]U<B!D92!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN`$]+`$]B:F5T`$-R
MZ6%T975R(&0G;V)J970`3V-T86P`3V-T;V)R90!&:6QT<F4@86YT:2UO9F9E
M;G-A;G0`0G5R96%U`$PG86YC:65N(&5T(&QE(&YO=79E874@;6]T<R!D92!P
M87-S92!D;VEV96YT(.IT<F4@9&EF9NER96YT<RX`06YC:65N(&UO="!D92!P
M87-S90!,)V%N8VEE;B!M;W0@9&4@<&%S<V4@97-T(&EN8V]R<F5C=`!/;6%N
M`$QE`%-U<B!T;W5S(&QE<R!A9V5N9&%S(&%U>'%U96QS(&HG86D@86-CZ',@
M96X@;&5C='5R90!3=7(@=&]U<R!L97,@86=E;F1A<R!A9F9I8VCI<P!3975L
M96UE;G0@<W5R(&UE<R!A9V5N9&%S`%-E=6P@;&5S('-E<G9E=7)S($E-05`@
M<W5P<&]R=&5N="!L97,@9&]S<VEE<G,@<&%R=&%GZ7,N`%-E=6QE;65N="!L
M97,@JZ!F;W)T=6YE<Z"[(&]F9F5N<V%N=&5S`%5N92!S975L92!A9')E<W-E
M(&1E(&-O=7)R:65L('!E<FUI<V4N`%-E=6QS(&QE('!R;W!R:>ET86ER92!O
M=2!L)V%D;6EN:7-T<F%T975R('-Y<W3H;64@<&5U="!M;V1I9FEE<B!L97,@
M<&5R;6ES<VEO;G,@9"=U;B!P87)T86=E+@!/=79R:7(@9&%N<R!U;F4@;F]U
M=F5L;&4@9F5NZG1R90!%<G)E=7(@3W!E;E-33*`Z(&EM<&]S<VEB;&4@9"=E
M>'1R86ER92!L97,@9&]N;NEE<R!D92!L82!P87)T:64@<VEG;NEE(%,O34E-
M10!/=79R:7(@;&5S(&QI96YS(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`
M4WES=.AM92!D)V5X<&QO:71A=&EO;@!/<'1I;VYN96P`4&%R=&EC:7!A;G1S
M(&]P=&EO;FYE;',`3W!T:6]N<P!/<'1I;VYS('!O=7(@)7,`3&ES=&4@;G5M
MZ7)O=.EE`$]R9V%N:7-A=&EO;@!5;FETZ2!O<F=A;FES871I;VYN96QL90!/
M<F=A;FES871I;VX`36]DZ&QE(&]R:6=I;F%L(&0G87!P;&EC871I;VX`36]D
MZ&QE<R!O<FEG:6YA=7@@9&%N<R`E<Z`Z`$%U=')E`$%U=')E<R!I;F9O<FUA
M=&EO;G,`4WEN=&CH<V4`4')O<')IZ71A:7)E`%!E<FUI<W-I;VYS(&1U('!R
M;W!R:>ET86ER90!0<F]P<FGI=&%I<F6@.B`E<P!,)V%U=&AE;G1I9FEC871I
M;VX@4$%-(&XG97-T('!A<R!D:7-P;VYI8FQE+@!-;V1U;&4@4$5!4CHZ36%I
M;`!3:6=N871U<F4@;G5MZ7)I<75E(%!'4`!$;VYNZ65S(%!'4"!C:&EF9G+I
M97,`0VQE9B!P=6)L:7%U92!01U``1&]N;NEE<R!01U`@<VEG;NEE<R]C:&EF
M9G+I97,`0V]D92!02%``26YT97)P<NET975R(%!(4`!030!0;'5I92!LZ6?H
M<F4@;"=A<'+H<RUM:61I`$%V97)S97,@;"=A<'+H<RUM:61I`$YE:6=E(&PG
M87!RZ',M;6ED:0!#:'5T97,@9&4@;F5I9V4@;"=A<'+H<RUM:61I`%-O;&5I
M;"!L)V%P<NAS+6UI9&D`3W)A9V5S(&PG87!RZ',M;6ED:0!%>'1E;G-I;VX@
M4$]325@@86)S96YT90!);G1E<G!RZ71E=7(@4%](4`!296UP;&ES<V%G90!0
M86MI<W1A;@!"96QA=0!086QE<W1I;F4@*'1E<G)I=&]I<F4@;V-C=7#I*0!0
M86YA;6$`4&%P;W5A<VEE+4YO=79E;&QE+4=U:6[I90!087)A9W5A>0!087)T
M:65L;&5M96YT(&YU86=E=7@`36]T(&1E('!A<W-E`$-H86YG96UE;G0@9'4@
M;6]T(&1E('!A<W-E(&5F9F5C='7I+@!-;W0@9&4@<&%S<V4@:6YC;W)R96-T
M`$UO="!D92!P87-S92!R97%U:7,@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@
M4D%$2553+@!-;W0@9&4@<&%S<V4@879E8R!C;VYF:7)M871I;VX`36]T(&1E
M('!A<W-EH#H`36]T(&1E('!A<W-EH#H@`$QE<R!M;W1S(&1E('!A<W-E(&1O
M:79E;G0@ZG1R92!I9&5N=&EQ=65S+@!,:7-T92!D97,@Z7;I;F5M96YT<R!P
M87-SZ7,`0V]L;&5R`$-O;&QE<B!D97!U:7,@;&4@<')E<W-E+7!A<&EE<G,`
M0VAE;6EN`$UO=&EF`$-O;F9I<FUA=&EO;G,@96X@871T96YT9:`Z`%!E<G-O
M;FYE<P!0;W5R8V5N=&%G90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@
M;6%I;G1E;F%N8V4`169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT
M96YA;F-E(.`@;&$@8V]N;F5X:6]NH#\`169F86-E<B!C970@Z7;I;F5M96YT
M(&3I9FEN:71I=F5M96YTH#\`4&5R;6ES<VEO;@!,82!P97)M:7-S:6]N(*N@
M)7.@NR!N)V5S="!P87,@<W5P<')I;>EE+@!!=71O<FES871I;VX@<F5J973I
M90!$<F]I=',@9"=A8V/H<P!!9&UI;FES=')A=&EO;B!D97,@<&5R;6ES<VEO
M;G,`1&]N;NEE<R!P97)S;VYN96QL97,`4.ER;W4`06YI;6%U>`!0:&EL:7!P
M:6YE<P!4Z6SI<&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U
M9&5S`%-64"!C;&EQ=65Z(&1A;G,@=6YE(&-E;&QU;&4`4U90(&-O;F9I<FUE
M>B!L82!S=7!P<F5S<VEO;B!D92!C970@Z6SI;65N=*`Z`%-64"!C;VYF:7)M
M97H@<75E('9O=7,@=F]U;&5Z(&3I;&EE<B!C970@Z6SI;65N="X`5F5U:6QL
M97H@<V%I<VER('5N(&UO:7,@970@=6YE(&%N;NEE+@!6975I;&QE>B!S86ES
M:7(@=6X@;F]M('!O=7(@;&$@;F]U=F5L;&4@8V%TZ6=O<FEEH#H`5F5U:6QL
M97H@96YT<F5R('5N92!A9')E<W-E($E0('9A;&ED92X`5F5U:6QL97H@96YT
M<F5R('5N92!D871E('9A;&ED9:`[(';I<FEF:65Z(&QE(&YO;6)R92!D92!J
M;W5R<R!D=2!M;VES+B``5F5U:6QL97H@96YT<F5R('5N92!H975R92!V86QI
M9&4N`%9E=6EL;&5Z(&9O=7)N:7(@=6X@<NES=6WI(&1U('!R;V)LZ&UE+@!6
M975I;&QE>B!F;W5R;FER('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&5T('9O
M=')E(&UO="!D92!P87-S90!6975I;&QE>B!L:7)E(&QE('1E>'1E('-U:79A
M;G0N(%9O=7,@9&5V97H@86-C97!T97(@;&5S(&-O;F1I=&EO;G,@<&]U<B!U
M=&EL:7-E<B!L92!S>7-TZ&UE+@!6975I;&QE>B!E;G1R97(@;&4@;F]U=F5A
M=2!N;VV@9&4@;&$@8V%TZ6=O<FEEH#H`4&]L;V=N90!0;VQI=&EQ=64`4V-R
M=71I;G,`3W!T:6]N<R!D=2!S>7-TZ&UE`%!O<G1U9V%L`%!O<VET:6]N(&1E
M(&-E='1E(&EM86=E`%!O<VET:6]N(&1E(&-E('1A8FQE874`16YV;WEE<B#@
M(&-E(&1O<W-I97(@*&YO;B!A<'!L:7%UZ2!P87(@24U!4"D`4'+I8VEP:71A
M=&EO;G,@<&]U<B!L97,@)7,@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!0<F]B86)I
M;&ETZ3QB<B`O/F1E('!L=6EE`%!R969S7VQD87"@.B!E>'1E;G-I;VX@<F5Q
M=6ES92!,1$%0(&YO;B!T<F]U=NEE+@!0<F5F<U]S97-S:6]NH#H@97AT96YS
M:6]N(')E<75I<V4@JZ!S97-S:6]NH+L@;F]N('1R;W5VZ64N`%!R97-S:6]N
M`%!R97-S:6]N(&%U(&YI=F5A=2!D92!L82!M97*@.B``4')E<W-I;VZ@.B``
M07!E<N=U`$%P97+G=2!D92!L)VEM86=E(&1A;G,@=6YE(&YO=79E;&QE(&9E
M;NIT<F4`2F]U<B!P<NECZ61E;G0`4V5M86EN92!P<NECZ61E;G1E`$IO=7(@
M<'+I8^ED96YT`$]P=&EO;G,@<'+I8^ED96YT97,`26UP<FEM97(@;&4@9&]C
M=6UE;G0`0VQE9B!P<FEVZ64`4')O8FSH;64`1&5S8W)I<'1I;VX@9'4@<')O
M8FSH;64`4')O:F5T<P!497AT92!C;W5R=`!#;&5F('!U8FQI<75E`$%L9V]R
M:71H;64@9&4@8VQE9B!P=6)L:7%U90!);F9O<FUA=&EO;G,@<W5R(&QA(&-L
M968@<'5B;&EQ=64`R6-H96,@9&4@;&$@9^ENZ7)A=&EO;B!D92!L82!P86ER
M92!D92!C;&5F<R!P=6)L:7%U92]P<FEVZ64N`%!O<G1O(%)I8V\`46%T87(`
M4F5Q=>IT90!1=6]T80!#;&5F('!U8FQI<75E(%)302`H)60@8FET<RD`4^EL
M96-T:6]N(')A9&EO`%!L=6EE`%!L=6EE('3T="!L92!M871I;@!0;'5I92!T
M87)D(&1A;G,@;&$@:F]U<F[I90!!=F5R<V5S`%!L=6EE(&5T(&YE:6=E`%!L
M=6EE('!U:7,@;F5I9V4`07!H;W)I<VUE(&%U(&AA<V%R9`!4875X`$QI<F4`
M365S<V%G97,@;'5S`%-U<'!R97-S:6]N(&3I9FEN:71I=F4@9&4@)7.@/P!3
M=7!P<F5S<VEO;B!DZ69I;FET:79E(&1E<R!D;VYNZ65S('!O=7(@;"=U=&EL
M:7-A=&5U<B`E<Z`_($-E='1E(&]PZ7)A=&EO;B!E<W0@9.EF:6YI=&EV92X`
M4NEPZ71E<B!J=7-Q=2?@`%+I<.ET:71I;VX`1&]N;NEE<R!D92!RZ7#I=&ET
M:6]N`$1A=&4@9&4@9FEN(&1E('+I<.ET:71I;VX`26YT97)V86QL92!D92!R
MZ7#I=&ET:6]N`%1Y<&4@9&4@<NEPZ71I=&EO;@!2Z7#I=&ET:6]N('%U;W1I
M9&EE;FYE`%+I<.ET:71I;VX@;65N<W5E;&QE`%+I<.ET:71I;VX@:&5B9&]M
M861A:7)E`%+I<.ET:71I;VX@86YN=65L;&4`4F5P<F5N9')E('9O=')E(&1E
M<FYIZ')E(&%C=&EO;@!2869R8>YC:&ER`%)A9G)A[F-H:7(@;&5S(.ELZ6UE
M;G1S(&1U(&UE;G4@9'EN86UI<75EH#H`4F%F<F'N8VAI<B!L)^EC<F%N(&1U
M('-O;6UA:7)EH#H`17AP<F5S<VEO;B!R871I;VYN96QL90!.879I9V%T975R
M(')E;&%T:6]N;F5L`%)E8VAA<F=E<@!296UA<G%U97,`4F%P<&5LH#H@)7,`
M06=E;F1A<R!D:7-T86YT<P!!9V5N9&%S(&1I<W1A;G1SH#H`4V5R=F5U<G,@
M9&ES=&%N=',`55),(&1E('-O=7-C<FEP=&EO;B!D:7-T86YT90!54DP@9&ES
M=&%N=&4@*&AT='`Z+R]W=W<N97AE;7!L92YC;VTO:&]R9&4O*:`Z`%)E=&ER
M97(`4F5T:7)E<B`E<P!2971I<F5R(&QE('!A<G1I8VEP86YT`%)E=&ER97(@
M;&4@8FQO8P!2971I<F5R(&QA(&-O;&]N;F4`4F5T:7)E<B!L92!F;W)M871A
M9V4`4F5T:7)E<B!L82!P86ER90!%;FQE=F5R(&QE('-C<FEP="!E;G)E9VES
M='+I(&1U('+I<&5R=&]I<F4@=&5M<&]R86ER92!D=2!S97)V975R+@!2971I
M<F5R(&QE`%)E=&ER97(@8V4@;F]E=60@9'4@9&]C=6UE;G0`4F5T:7)E<B!L
M)W5T:6QI<V%T975R`%)E=&ER97(@;"=U=&EL:7-A=&5U<J`Z("5S`%)E;7!L
M86-E<B!L92!C86QE;F1R:65R(&5X:7-T86YT('!A<B!L)VEM<&]R=.F@/R`\
M<W1R;VYG/D%V97)T:7-S96UE;G2@.B!C96QA('-U<'!R:6UE<F$@=&]U=&5S
M(&QE<R!E;G1RZ65S(&1E('9O=')E(&%G96YD82!C;W5R86YT+CPO<W1R;VYG
M/@!!=6-U;F4@<NEP;VYS92#@('9O=')E(')E<77J=&4N($-O9&4@9"=E<G)E
M=7(@<F5T;W5R;NF@.B``3&4@<V5R=FEC92!D96UA;F3I(&5S="!I;G1R;W5V
M86)L92X`4F5Q=6ES`$QE('!A<F%MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@
M;B=E<W0@<&%S('-PZ6-I9FGI(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B`E<RX`
M3&4@<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I
M8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N(&1U(%9&4RX`3&4@<&%R86WH
M=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@9&%N
M<R!L82!C;VYF:6=U<F%T:6]N+@!087)T:6-I<&%N=',@<F5Q=6ES`$-H86UP
M(&]B;&EG871O:7)E`%+`6@!296UI<V4@X"!ZZ7)O(&1U(&UO="!D92!P87-S
M90!296UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E`%+I:6YI=&EA
M;&ES97(@875X('9A;&5U<G,@<&%R(&3I9F%U=`!2Z7!O;G-E`%)E=F5N:7(@
MX"!L82!D97)N:>AR92!R97%UZG1E`%+I<W5L=&%T<P!2979E;FER(&%U>"!O
M<'1I;VYS`%+I+65N=')E<B!L92!N;W5V96%U(&UO="!D92!P87-S90!2Z75N
M:6]N`%)E=F5N:7(@X"!L82!C;VYF:6=U<F%T:6]N('!RZ6/I9&5N=&4`3W!T
M:6]N<R!D92!L)^ED:71E=7(@4FEC:"!497AT`$1E=FEN971T97,`1')O:71E
M`$5N=.IT92!D92!D<F]I=&4`5F%L975R<R!C;W)R96-T97,`4')O<')IZ73I
M<R!D92!L82!R86Y?9^EE("XN+@!2]&QE`%)O=6UA;FEE`%!I=F]T97(@,3@P
M`%!I=F]T97(@X"!G875C:&4`4&EV;W1E<B#@(&1R;VET90!0<F]P<FGI=.ES
M(&1E(&QA(')A;F?I90!0<F]P<FGI=.ES(&1E(&QA(')A;F?I90!286YGZ65S
MH#H`4NAG;&5S`$1E<R!F:6QE=',@87!P87)A[G1R;VYT(&5N=')E('1O=71E
M<R!L97,@<F%N9^EE<R!E="!L97,@8V]L;VYN97,`1&5S(&9I;&5T<R!A<'!A
M<F'N=')O;G0@96YT<F4@;&5S(&-O;&]N;F5S('-E=6QE;65N=`!$97,@9FEL
M971S(&%P<&%R8>YT<F]N="!E;G1R92!L97,@<F%N9^EE<R!S975L96UE;G0`
M3&%N8V5R`%)U<W-I90!2=V%N9&$`4VEG;F%T=7)E(.EL96-T<F]N:7%U92!3
M+TU)344`365S<V%G92!C:&EF9G+I(%,O34E-10!,)V%U=&AE;G1I9FEC871I
M;VX@4T%33"!N)V5S="!P87,@9&ES<&]N:6)L90!-97-S86=E<FEE(%--4P!)
M;G1E<G!RZ71E=7(@4U%,`$]R9')E(%-13"!P;W5R(')E=&]U<FYE<B!L97,@
M=F%L975R<P!34T@`4U5#0\A3`$EN=&5R<'+I=&5U<B!37U%,`%-A;0!386EN
M=&4M2.ELZ&YE`%-A:6YT+4-H<FES=&]P:&4M970M3FGI=NAS`%-A:6YT92U,
M=6-I90!386EN="U0:65R<F4@970@36EQ=65L;VX`4V%I;G0M5FEN8V5N="UE
M="UL97,@1W)E;F%D:6YE<P!-ZFUE(&-A9')E("A?<V5L9BD`4V%M;V$@;V-C
M:61E;G1A;&5S`%-A:6YT+4UA<FEN`%-A;RU4;VWI+65T+5!R:6YC:7!E`$9O
M=7)N:7-S975R('-A=&5L;&ET90!386UE9&D`07)A8FEE(%-A;W5D:71E`$5N
M<F5G:7-T<F5R`$5N<F5G:7-T<F5R(*N@)7.@NP!%;G)E9VES=')E<B`E<P!%
M;G)E9VES=')E<B!E;B!T86YT('%U92!N;W5V96%U`$5N<F5G:7-T<F5R(&QE
M<R!P87)T:6-I<&%N=',`16YR96=I<W1R97(@;"?I=NEN96UE;G0`16YR96=I
M<W1R97(@;&5S(&]P=&EO;G,`16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO
M;B!GZ6[I<NEE(&-O;6UE('5N('-C<FEP="!02%`@9&%N<R!L92!RZ7!E<G1O
M:7)E('1E;7!O<F%I<F4@9&4@=F]T<F4@<V5R=F5U<BX`16YR96=I<W1R97(@
M;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!38W)I<'0@9&4@;6ES92#@(&IO=7(@
M9&4@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I('-O=7.@.B"K("5SH+L`3W)A
M9V5S(&ES;VSI<P!38VEE;F-E`%)E8VAE<F-H97(`4F5C:&5R8VAE<B!D86YS
M(&QE<R!A9V5N9&%S`$UO=&5U<G,@9&4@<F5C:&5R8VAE`%+I<W5L=&%T<R!D
M92!L82!R96-H97)C:&4`4F5C:&5R8VAE<B!L97,@86=E;F1A<R!C;VYT96YA
M;G2@.@!#:&]I<VES<V5Z(&QE<R!F:6-H:65R<P!3Z6QE8W1I;VYN97H@=6X@
M86=E;F1A(.`@Z61I=&5R`%/I;&5C=&EO;FYE>B!U;F4@9&%T90!3Z6QE8W1I
M;VYN97H@=6X@9W)O=7!E(.`@86IO=71E<@!3Z6QE8W1I;VYN97H@=6X@;F]U
M=F5A=2!P<F]P<FGI=&%I<F4`4^EL96-T:6]N;F5Z('5N('-E<G9E=7(`4^EL
M96-T:6]N;F5Z('5N('5T:6QI<V%T975R(.`@86IO=71E<@!4;W5T('/I;&5C
M=&EO;FYE<@!3Z6QE8W1I;VYN97H@=&]U=&5S(&QE<R!C;VUP;W-A;G1E<R!D
M92!L82!D871E+@!#:&]I<VES<V5Z('5N(&]B:F5T`%/I;&5C=&EO;FYE>B!L
M97,@86=E;F1A<R#@(&%F9FEC:&5RH#H`4^EL96-T:6]N(&1E<R!O<'1I;VYS
M(&1E(&-O;F9I<FUA=&EO;BP@9&4@;&$@9F'G;VX@9"=A9F9I8VAE<B!L97,@
M9&EF9NER96YT<R#I8W)A;G,@970@8VAO:7@@9&4@;&$@=G5E('!A<B!DZ69A
M=70N`$YE('/I;&5C=&EO;FYE<B!A=6-U;@!3Z6QE8W1I;VYN97H@;"=A9V5N
M9&$@9&%N<R!L97%U96P@:6UP;W)T97*@.@!3Z6QE8W1I;VYN97H@;&5S(&%G
M96YD87,@X"!P87)T:7(@9&5S<75E;',@97AP;W)T97(`4^EL96-T:6]N;F5Z
M(&QE<R!C87)A8W3H<F5S(&1O;G0@=F]U<R!A=F5Z(&)E<V]I;B#@(&PG86ED
M92!D92!L)V]U=&EL(&-I+61E<W-O=7,N(%9O=7,@<&]U=F5Z(&5N<W5I=&4@
M;&5S(&-O<&EE<B!E="!L97,@8V]L;&5R(&1A;G,@=F]T<F4@=&5X=&4N`%/I
M;&5C=&EO;FYE>B!L92!DZ6QI;6ET975R(&1E(&1A=&6@.@!3Z6QE8W1I;VYN
M97H@;&4@9F]R;6%T(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97H@;&4@9F]R;6%T
M(&1E(&PG97AP;W)T871I;VZ@.@!3Z6QE8W1I;VYN97H@;&4@9FEC:&EE<B#@
M(&EM<&]R=&5RH#H`3&$@<V5M86EN92!C;VUM96YC92!L9:`Z`%/I;&5C=&EO
M;FYE>B!L92!F;W)M870@9'4@9FEC:&EE<B!S;W5R8V6@.@!3Z6QE8W1I;VYN
M97(@;&4@<')O9FEL('%U92!V;W5S(&3I<VER97H@;6]D:69I97(Z`%/I;&5C
M=&EO;FYE>B!L92!DZ6QI;6ET975R(&0G:&5U<F6@.@!3Z6QE8W1I;VYN97H@
M;&4@9F]R;6%T(&1E(&PG:&5U<F6@.@!3Z6QE8W1I;VYN97H@;&$@<.ER:6]D
M92#@(&%F9FEC:&5RH#H`4^EL96-T:6]N;F5Z(&QA('9U92#@(&%F9FEC:&5R
M(&QO<G,@9&4@;"=E;G1RZ64@9&%N<R!L)V%P<&QI8V%T:6]NH#H`4^EL96-T
M:6]N;F5Z(&1E=7@@8VAA;7!S(&%P<&%R96YTZ7,N`%/I;&5C=&EO;FYE>B!Q
M=65L<R#I=NEN96UE;G1S(&%F9FEC:&5R(&1A;G,@;&4@<&]R=&%I;"X`4^EL
M96-T:6]N;F5Z('9O=')E('1HZ&UE(&1E(&-O=6QE=7)S+@!3Z6QE8W1I;VYN
M97H@=F]T<F4@;&%N9W5E('!RZ6;I<NEEH#H`16YV;WEE<B!L92!R87!P;W)T
M(&0G86YO;6%L:64`16YV;WEE<B!335,`16YV;WEE<B!U;B!M97-S86=E(&0G
M86YN=6QA=&EO;B#@('1O=7,@;&5S('!A<G1I8VEP86YT<R!L;W)S(&1E(&QA
M('-U<'!R97-S:6]N(&1E(&PGZ7;I;F5M96YT`$5N=F]Y97(@=6X@8V]U<G)I
M97(@X"`E<P!%;G9O>65R('5N92!M:7-E(.`@:F]U<B]I;G9I=&%T:6]N(.`@
M=&]U<R!L97,@<&%R=&EC:7!A;G1S(&QO<G,@9&4@;"=E;G)E9VES=')E;65N
M="!D92!L)^EVZ6YE;65N=`!3Z6[I9V%L`%-O;F1EH#H@`%-E<'1E;6)R90!3
M97)B:64@970@36]N=&5N96=R;P!.=6WI<F\@9&4@<^ER:64`3&5S(&1O;F[I
M97,@9'4@<V5R=F5U<B!S;VYT(&9A=7-S97,@;W4@;F]N(&1I<W!O;FEB;&5S
M+@!!9&UI;FES=')A=&EO;B!D97,@<V5S<VEO;G,`260N(&1E('-E<W-I;VX@
M97AP:7+I+@!397-S:6]N<P!3Z6QE8W1I;VYN97(`4^EL96-T:6]N;F5Z(&QA
M(&1A=&4@9&4@9FEN`$-O;F9I9W5R97(@;&5S(&]P=&EO;G,@<&]U<B!V;W5S
M('!E<FUE='1R92!D92!R96UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A
M<W-E('-I(&IA;6%I<R!V;W5S(&PG;W5B;&EE>BX`4^EL96-T:6]N;F5Z(&QA
M(&1A=&4@9&4@;&$@9FEN(&1E(&QA('+I8W5R<F5N8V4`4^EL96-T:6]N;F5Z
M(&QA(&1A=&4@9&4@9.EB=70`0V]N9FEG=7)E<B!L97,@<V5R=F5U<G,@9&ES
M=&%N=',@86-C97-S:6)L97,@9&5P=6ES('9O=')E('!O<G1A:6PN`$%F9F5C
M=&5R('9O<R!A9V5N9&%S(&1E(&1I<W!O;FEB:6QI=.ES(&5T(&QE<R!O<'1I
M;VYS(&1E(&1I<W!O;FEB:6QI=.ES('!O=7(@=F]U<R!E="!L97,@875T<F5S
M('5T:6QI<V%T975R<RX`4^EL96-T:6]N;F5Z('9O=')E(&QA;F=U92!P<NEF
MZ7+I92P@9G5S96%U(&AO<F%I<F4@970@;&5S(&]P=&EO;G,@9&4@9&%T92X`
M1.EF:6YI<W-E>B!L82!P<F5M:>AR92!A<'!L:6-A=&EO;B!L86YCZ64L(&QE
M('1HZ&UE(&1E(&-O=6QE=7)S+"!L92!R869R8>YC:&ES<V5M96YT(&1E<R!P
M86=E<RP@970@9"=A=71R97,@;W!T:6]N<R!D)V%F9FEC:&%G92X`0V]N9FEG
M=7)A=&EO;@!38W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E(.`@:F]U
M<B!D:7-P;VYI8FQE`%!L=7-I975R<R!E;F1R;VET<R!P;W-S:6)L97,@879E
M8R!L92!P87)A;>AT<F6@.B``4V5Y8VAE;&QE<P!087)T86=E(&YO;B!T<F]U
M=NF@.B`E<P!!9V5N9&%S('!A<G1A9^ES`$%G96YD87,@<&%R=&%GZ7.@.@!!
M8VAA=`!2Z7-U;>D`1&]I="UO;B!DZ69I;FER(&1E<R!T;W5C:&5S(&1E(')A
M8V-O=7)C:7,@<&]U<B!L82!P;'5P87)T(&1E<R!L:65N<Z`_`$%F9FEC:&5R
M`$%F9FEC:&5R(&PG86=E;F1A`$UO;G1R97(@;&$@;.EG96YD92!D92!L82!C
M873I9V]R:66@/P!-;VYT<F5R(&QE<R!I8_1N97,@9&4@<W5P<')E<W-I;VXL
M(&0G86QA<FUE(&5T(&1E('+I<.ET:71I;VX@9&%N<R!L97,@=G5E<R!D92!L
M)V%G96YD8:`_`$UO;G1R97(@;&5S(&1I9F;I<F5N8V5S(&5N=')E(&QA(&-O
M;F9I9W5R871I;VX@96YR96=I<W1RZ64@86-T=65L;&5M96YT(&5T(&-E;&QE
M(&YO=79E;&QE;65N="!GZ6[I<NEE+@!!9F9I8VAE<B!L97,@=.)C:&5S(.`@
M<NEA;&ES97(@9&%N<R!L)V%G96YD8:`_`$UO;G1R97(@;&$@;.EG96YD92!D
M97,@9&ES<&]N:6)I;&ETZ7.@/P!-;VYT<F5R(&PG:&5U<F4@9&4@;&$@9&5R
M;FGH<F4@8V]N;F5X:6]N(.`@;"=E;G1RZ66@/P!.)V%F9FEC:&5R('%U92!L
M97,@Z7;I;F5M96YT<R!A8V-O;7!A9V[I<R!D)W5N92!A;&5R=&6@/P!-;VYT
M<F5R(&PG;W!T:6]N(&1E(&-O;G-E<G9E<B!L)V]R:6=I;F%L`$UO;G1R97(@
M;&4@<^EL96-T975R`$%F9FEC:&5R(&QE<R!A9V5N9&%S('!A<G1A9^ES(&/T
M=&4@X"!C]'1EH#\`069F:6-H97(@;&$@8F%R<F4@9&4@;65N=2!D92!T86)L
M96%U>*`_`%5T:6QI<V5R(&QE<R!C;W5L975R<R!D97,@8V%TZ6=O<FEE<R!P
M;W5R(&QE<R!TXF-H97.@/P!!9F9I8VAE<B!L92!M96YU("5S(.`@9V%U8VAE
MH#\`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@=&%B;&5A=2!C96QL
M=6QE`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P<F]P<FGI
M=.ES(&1U('1A8FQE874`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@
M9&5S('!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE(&1U('1A8FQE874`069F:6-H
M97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ETZ7,@9&4@;"=I
M;6%G90!-;VYT<F5R(&PG:&5U<F4@96YT<F4@8VAA8W5N92!D97,@:F]U<F[I
M97,@9&%N<R!L82!V=64@<&%R('-E;6%I;F6@/P!!9F9I8VAE<B!L)V5N=F]I
M(&1E(&9I8VAI97(`079E<G-E<P!!=F5R<V5S('3T="!D86YS(&QA(&IO=7)N
MZ64`079E<G-E<R!T87)D(&5N(&IO=7)NZ64`079E<G-E<R!A=7@@86QE;G1O
M=7)S`%)E<W-E<G)E<@!297-S97)R97(@;W4@9.EG86=E<B!D)V%B;W)D(&QE
M*',I(&)L;V,H<RD@=F]I<VEN*',I`%-I97)R82!,96]N90!3)VEN<V-R:7)E
M`%-I9VYA='5R90!!;&=O<FET:&UE(&1E('-I9VYA='5R90!3:6YG87!O=7(`
M5&%I;&QE`$%N;G5L97(@;&$@;6%I;G1E;F%N8V4`4VQO=F%Q=6EE`%-L;W;I
M;FEE`$YE:6=E`$%V97)S92!D92!N96EG90!!=F5R<V5S(&1E(&YE:6=E`$%V
M97)S97,@9&4@;F5I9V4@=/1T(&1A;G,@;&$@:F]U<F[I90!!=F5R<V5S(&1E
M(&YE:6=E('1A<F0@96X@:F]U<F[I90!(875T975R(&1E(&YE:6=EH#H@`%%U
M86YT:73I(&0G96%U(.EQ=6EV86QE;G1E(.`@;&$@<75A;G1I=.D@9&4@;F5I
M9V6@.B``SFQE<R!386QO;6]N`%-O;6%L:64`0VAA;G-O;G,@970@<&_H;65S
M`%/I;&5C=&EO;B!D92!L)V]R9')E(&1E('1R:0!!9')E<W-E('-O=7)C90!!
M9G)I<75E(&1U('-U9`!3=60M975R;W#I96X@*$E33RTX.#4Y+3,I`$?I;W)G
M:64M9'4M<W5D(&5T(.YL97,@4V%N9'=I8V@M9'4M<W5D`$CI;6ES<&CH<F4@
M4W5D`$5S<&%C92!E;G1R92!C96QL=6QE<R!A9&IA8V5N=&5S`$5S<&%C92!E
M;G1R92!L92!C;VYT96YU(&5T(&QA(&)O<F1U<F4@9&%N<R!U;F4@8V5L;'5L
M90!%<W!A8V5U<@!%<W!A8V5M96YT`$5S<&%C96UE;G0@970@<F5M<&QI<W-A
M9V4`17-P86=N90!0;W5R<FEE;`!#87)A8W3H<F5S('-PZ6-I875X`%-C:6YD
M97(@;&$@8V5L;'5L90!38VEN9&5R(&QA(&-O;&]N;F4`4V-I;F1E<B!L82!R
M86YGZ64`4W!O<G1S`%-R:2!,86YK80!$Z6)?=70`4W1A;F1A<F0`4W1A<B!4
M<F5K`$1A=&4@9&4@9.EB=70`1.EB=70@;&4`2&5U<F4@9&4@9.EB=70`06YN
MZ64@9&4@9.EB=70`4W1A=%]U=`#)=&%T(&]U('!R;W9I;F-E`%-T871U=`!&
M;W)M870@9&4@<V%U=F5G87)D90!2=64`0F%R<ND`3&ES=&4@9&4@8VAA[FYE
M<P!2971I<F5R(&QE(&1O;6%I;F4@9&4@;"=A9')E<W-E`%-T>6QE(%M#4U-=
M`$1I;0!3;W5S+7+I<&5R=&]I<F4@JZ`E<Z"[(&YO;B!T<F]U=ND`4W5J970`
M16YV;VD`3&$@9&5M86YD92!D)V%J;W5T(&1E(*N@)7.@NR!A=2!S>7-TZ&UE
M(&$@Z73I('-O=6UI<V4N(%9O=7,@;F4@<&]U<G)E>B!P87,@=F]U<R!C;VYN
M96-T97(@:G5S<74GX"!S;VX@87!P<F]B871I;VXN`$EN9&EC90!3=6-CZ',`
MJZ`E<Z"[(&$@8FEE;B#I=.D@86IO=73I*&4I+@!,97,@9&]N;NEE<R!D92!L
M)W5T:6QI<V%T975R(*N@)7.@NR!O;G0@8FEE;B#I=.D@<F5T:7+I97,@9'4@
M<WES=.AM92XN`*N@)7.@NR!A(&)I96X@Z73I('-U<'!R:6WI*&4I+@"KH"5S
MH+L@82!B:65N(.ETZ2!R971I<NDH92DN`%)E=&]U<B#@(&QA(&-O;F9I9W5R
M871I;VX@:6YI=&EA;&4@<NEU<W-I+B`@4F%F<F'N8VAI<B!L82!P86=E('!O
M=7(@=F]I<B!L97,@;6]D:69I8V%T:6]N<RX`16YR96=I<W1R96UE;G0@9&4@
M;&$@8V]N9FEG=7)A=&EO;B!D92!L82!S875V96=A<F1E('+I=7-S:2X`16YR
M96=I<W1R96UE;G0@<NEU<W-I(&1E(&QA(&-O<&EE(&1E('-A=79E9V%R9&4@
M9'4@9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+@"KH"5SH+L@82!B:65N
M(.ETZ2!M:7,H92D@X"!J;W5R+@#)8W)I='5R92!D92`E<R!RZ75S<VD`4V]U
M9&%N`%-O;6UA:7)E`$QE=F5R(&1U(%-O;&5I;`!#;W5C:&5R(&1U(%-O;&5I
M;`!$:6UA;F-H90!%;G-O;&5I;&SI`$QE=F5R(&1U(%-O;&5I;`!,979E<B]#
M;W5C:&5R(&1U(%-O;&5I;`!,979E<B!D=2!3;VQE:6PZ(`!#;W5C:&5R(&1U
M(%-O;&5I;`!#;W5C:&5R(&1U(%-O;&5I;*`Z(`!%>'!O<V%N=`!!<W-I<W1A
M;F-E`%-U<FEN86T@;W4@1W5Y86YE(&AO;&QA;F1A:7-E`$YO;2!D92!F86UI
M;&QE`,YL97,@4W9A;&)A<F0@970@2F%N($UA>65N`%-W87II;&%N9`!3=>AD
M90!3=6ES<V4`2F]U<FYA;"!D92!S>6YC:')O;FES871I;VX@<W5P<')I;>D`
M4WEN8TU,`$5R<F5U<B!D92!S>6YT87AE(&1A;G,@;&5S('1E<FUE<R!D92!R
M96-H97)C:&4`4WER:64`3W)A9V5S`$]R86=E(&5T('9E;G0`3W)A9V5S`$]R
M86=E<R!M871I;F%U>`!&:6-H:65R(%135@!486)L96%U`%!R;W!R:>ETZ7,@
M9'4@=&%B;&5A=0!486)L96%U(&1E('9A;&5U<G,`4')O<')IZ73I<R!D=2!T
M86)L96%U`%1A[W=A;@!48>]W86XL('!R;W9I;F-E(&1E($-H:6YE`%1A:FEK
M:7-T86X`5&%N>F%N:64`0VEB;&6@.@!4XF-H97,`3G5MZ7)O(&1E('3I;.EP
M:&]N90!496UPZ7)A='5R92!P;W5R(&QA(&1E<FYIZ')E(&AE=7)EH#H@`%1E
M;7#I<F%T=7)E`%1E;7#I<F%T=7)EH#H@`%1E;7#I<F%T=7)E/&)R("\^*"5S
M2&$E<R\E<T)A)7,I("9D96<[)7,`4')O9FEL(*N@)7.@NR!N;VX@=')O=7;I
M`$%D;6EN:7-T<F%T:6]N(&1E<R!M;V3H;&5S`%1E;G1A=&EV90!497AT90!4
M97AT92!S975L`$%L:6=N96UE;G0@9'4@=&5X=&4`5&5X=&4@96X@:&%U=`!*
M974`5&AA[R`H5$E3+38R,"D`5&AA[VQA;F1E`$PGZ6-R86X@9"?I9&ET:6]N
M(&1E<R!P87)T:6-I<&%N=',@;B=E<W0@<&QU<R!P<NES96YT+B!3;W)T:64@
M96X@8V]U<G,N`$PG97AT96YS:6]N($944"!N)V5S="!P87,@9&ES<&]N:6)L
M92X`3&4@;6]T975R(&0G:6YTZ6=R871I;VX@2&]R9&4O2V]L86(@;F4@<W5P
M<&]R=&4@<&%S(*N@)7.@NP!,92!J;W5R;F%L($E-4U`@;B=A('!A<R!P=2#J
M=')E(&EN:71I86QI<^DN`$QA(&-L87-S92!-86EN=&5N86YC93HZ(&XG82!P
M87,@Z73I(&-H87)GZ64@8V]R<F5C=&5M96YT`$QA(&9E;NIT<F4@9&5S(&]P
M=&EO;G,@<R=E<W0@9F5R;>EE+B!3;W)T:64N`$PG861M:6YI<W1R871E=7(@
M9&]I="!C;VYF:6=U<F5R('5N(&)A8VME;F0@<&5R;6%N96YT('!O=7(@;&5S
M('!E<FUI<W-I;VYS('-I('9O=7,@=F]U;&5Z(&QE<R!E;7!L;WEE<BX`3&$@
M8F]R9'5R92!D=2!B87,@<V5U;&5M96YT`%-U<'!R97-S:6]N(&EM<&]S<VEB
M;&4@9&4@;"=A9V5N9&$@JZ`E<Z"[+@!,)V%G96YD82"KH"5SH+L@82#I=.D@
M8W+IZ2X`3"=A9V5N9&$@JZ`E<Z"[(&$@Z73I('-U<'!R:6WI+@!,)V%G96YD
M82"KH"5SH+L@82#I=.D@<F5N;VUMZ2"K("5S(+LN`$PG86=E;F1A(*N@)7.@
MNR!A(.ETZ2!E;G)E9VES='+I+@!0=7)G92!I;7!O<W-I8FQE(&1E(&PG86=E
M;F1AH#H@JZ`E<Z"[`$PG240@9'4@8V]N=&%C="!N)V$@<&%S(.ETZ2!S<.EC
M:69IZ2P@;&%I<W/I('9I9&4@;W4@;B=A('!A<R#I=.D@=')O=7;I(&1A;G,@
M;&$@8F%S92!D92!D;VYNZ65S+@!#92!C;VYT86-T(&$@8FEE;B#I=.D@86IO
M=73I(.`@=F]T<F4@8V%R;F5T(&0G861R97-S97,N(`!,92!B;&]C(&1E('-I
M9VYA='5R92!01U`@<^EP87+I(&5S="!NZ6-E<W-A:7)E('!O=7(@=NER:69I
M97(@;&$@<VEG;F%T=7)E+@!,)TE$(&1E(&QA(&QI<W1E(&XG82!P87,@Z73I
M('-PZ6-I9FGI+"!L86ES<^D@=FED92!O=2!N;VX@=')O=7;I(&1A;G,@;&$@
M8F%S92!D92!D;VYNZ65S+@!,82!L:7-T92!D92!D:7-T<FEB=71I;VX@;B=A
M('!A<R#I=.D@<W#I8VEF:>EE+@!,92!C:&EF9G)E;65N="!NZ6-E<W-I=&4@
M=6YE(&-O;FYE>&EO;B!SZ6-U<FESZ64N`$QA(&1A=&4@9&4@9FEN(&1O:70@
MZG1R92!P;W-TZ7)I975R92#@(&QA(&1A=&4@9&4@9.EB=70N`$PGZ7;I;F5M
M96YT(*N@)7.@NR!A(.ETZ2!A:F]U=.D@X"!L)V%G96YD82"K("5S(+LL(&QE
M("5S(.`@)7,N`$PGZ7;I;F5M96YT(*N@)7.@NR!A(.ETZ2!R971I<ND@9&4@
M;"=A9V5N9&$@JR`E<R"[H#L@:6P@Z71A:70@;&4@)7,@X"`E<RX`3"?I=NEN
M96UE;G0@JZ`E<Z"[(&$@Z73I(&TN(.`@:BX@9&%N<R!L)V%G96YD82"K("5S
M(+LL(&QE("5S(.`@)7,N`$QA(&YO=&EF:6-A=&EO;B!D92!L)^EVZ6YE;65N
M="#@("5S(&$@8FEE;B#I=.D@96YV;WGI92X`3&4@9FEC:&EE<B`E<R!D;VET
M(&-O;G1E;FER(&QE<R!O<'1I;VYS("5S+@!,92!F:6-H:65R("5S(&1O:70@
M8V]N=&5N:7(@8V5R=&%I;F5S(&]P=&EO;G,@)7,N`$QE(&9I8VAI97(@;F4@
M<&5U="!P87,@ZG1R92!C;W!IZ2!S=7(@;'5I+6WJ;64N`$QE(&9I8VAI97(@
M;F4@8V]N=&5N86ET(&%U8W5N92!D;VYNZ64N`$-E('%U:2!S=6ET('-O;G0@
M;&5S(&5N+73J=&5S('!O=7(@8V4@;65S<V%G92!M97-S86=E+U)&0S@R,BX`
M5F]I8VD@=6YE(&1E<V-R:7!T:6]N('!L=7,@9.ET86EL;.EE(&1E(&PGZ7;I
M;F5M96YTH#H`3&4@;6]D92!P;&5I;B#I8W)A;B!C875S92!D97,@<')O8FSH
M;65S(&%V96,@26YT97)N970@17AP;&]R97(@9/L@X"!D97,@8F]G=65S(&1U
M(&YA=FEG871E=7(@<75I(&XG;VYT('!U(.IT<F4@8V]N=&]U<F[I<RX@5F]U
M<R!P;W5V97H@ZG1R92!C;VYF<F]N=.ES(.`@9&4@;"=A9F9I8VAA9V4@9&4@
M8V%R86-TZ')E<R#I=')A;F=E<RP@874@;F]N+69O;F-T:6]N;F5M96YT(&1E
M<R!C97)T86EN97,@9F]N8W1I;VYS(&5T+V]U(&%U('!L86YT86=E(&%LZ6%T
M;VER92!D=2!N879I9V%T975R+B!3:2!V;W1R92!S>7-TZ&UE(&5S="!U;B!7
M:6YD;W=S(#EX+"!I;"!E<W0@='+H<R!P;W-S:6)L92!Q=64@=F]U<R!A=7)E
M>B!U;F4@)T9A=71E(&?I;NER86QE(&1E('!R;W1E8W1I;VXG(&5T('%U92!V
M;W5S(&1E=G)E>B!R963I;6%R<F5R('9O=')E(&]R9&EN871E=7(N7&Y<;E9O
M=7,@879E>B#I=.D@<'+I=F5N=7,N(%-64"!A<'!U>65Z('-U<B!/2R!S:2!V
M;W5S('9O=6QE>B!T;W5J;W5R<R!E<W-A>65R(&QE(&UO9&4@<&QE:6X@Z6-R
M86X@9&4@;"?I9&ET975R`$PG:61E;G1I=.D@JZ`E<Z"[("!A(.ETZ2!S=7!P
M<FEMZ64N`$QE(&/T=.D@9V%U8VAE('-E=6QE;65N=`!,)V5M<&QA8V5M96YT
M(&1U('!R;V=R86UM92!';G501R!D;VET(.IT<F4@9F]U<FYI(.`@;&$@8VQA
M<W-E($-R>7!T7W!G<#HZ+@!,92!M97-S86=E(&5N=F]YZ2!L92`E<R#@("5S
M(&%V96,@8V]M;64@<W5J970@JZ`E<Z"[(&$@Z73I(&%F9FEC:.DN(`I);"!N
M)WD@82!A=6-U;F4@9V%R86YT:64@<75E(&-E(&UE<W-A9V4@82#I=.D@;'4@
M;W4@8V]M<')I<RX`3&4@;F]M(.`@=71I;&ES97(@96X@;&EA;G0@X"!L82!P
M86=E(&1E(&-O;7!O<VET:6]N`$QE(&YO;6)R92!D92!C:&%M<',@9&]I="#J
M=')E('5N(&YO;6)R92!V86QI9&4N`$QE(&UO9'5L92!/<&5N4U-,(&5S="!R
M97%U:7,@<&]U<B!L82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BX`3&$@
M<'+I9NER96YC92"KH"5SH+L@;B=A('!A<R!P=2#J=')E(&5N<F5G:7-T<NEE
M(&-A<B!S82!T86EL;&4@9.EP87-S92!L92!M87AI;75M(&%U=&]R:7/I`$QE
M('!R;V=R86UM92!U=&EL:7/I('!O=7(@=FES=6%L:7-E<B!C92!T>7!E(&1E
M(&1O;F[I97,@*"5S*2!N)V$@<&%S(.ETZ2!T<F]U=NDN`$QE(&-A<F%C=.AR
M92!D92!P<F]T96-T:6]N(&1O:70@ZG1R92!U;B!C87)A8W3H<F4@=6YI<75E
M+@!,82!R97%UZG1E(.ET86ET(&EN8V]M<&SH=&4N($EL(&UA;G%U92!C97)T
M86EN<R!P87)A;>AT<F5S(&[I8V5S<V%I<F5S('!O=7(@;"=A8V-E<'1A=&EO
M;B!O=2!L92!R969U<R!D)W5N(.EVZ6YE;65N="X`3&5S(&/T=.ES(&=A=6-H
M92!E="!D<F]I="!S975L96UE;G0`3&4@8_1TZ2!D<F]I="!S975L96UE;G0`
M3&4@<^EP87)A=&5U<B!D;VET(.IT<F4@=6X@8V%R86-TZ')E('5N:7%U92X`
M3&4@<V5R=F5U<B"KH"5SH+L@82#I=.D@<W5P<')I;>DN`$QE('-E<G9E=7(@
MJZ`E<Z"[(&$@Z73I(&5N<F5G:7-T<NDN`$QA(')E<77J=&4@9"=E;G)E9VES
M=')E;65N="!P;W5R("5S(&$@Z73I(&3I<&QA8^EE+@!,82!L:6=N92!D96UA
M;F3I92!N)V5X:7-T92!P87,N`$QE(&9I8VAI97(@=&5M<&]R86ER92"K("5S
MH+L@;B=E>&ES=&4@<&%S+@!,92!T97AT92!E;G1RZ2!N92!C;W)R97-P;VYD
M('!A<R!A=2!T97AT92!S=7(@;"?I8W)A;BX`3&4@:&%U="!E="!L92!B87,@
M<V5U;&5M96YT`$QE(&AA=70@<V5U;&5M96YT`$QE<R!D;VYNZ65S('3I;.EC
M:&%R9^EE<R!V97)S(&QE('-E<G9E=7(@;VYT(.ETZ2!P97)D=65S(&1E<'5I
M<R!L)^ET87!E('!RZ6/I9&5N=&4N(`!,92!F:6-H:65R(.EM:7,@;B=A('!A
M<R!P=2#J=')E(&5N<F5G:7-T<NDN`$QE(&)L;V,@JZ!W96%T:&5R+F-O;:"[
M(&XG97-T('!A<R!D:7-P;VYI8FQE+@!2Z7!E<G1O:7)E(&1E<R!T:.AM97,@
MJZ`E<Z"[(&YO;B!T<F]U=ND`075C=6X@Z7;I;F5M96YT(&YE(&-O<G)E<W!O
M;F0@874@<'+I<V5N="!C<FETZ')E+@!);"!N)WD@82!P87,@9"=O<'1I;VYS
M(&1I<W!O;FEB;&5S`$%U8W5N92!P87)T:64@;F4@<&5U="#J=')E(&%F9FEC
M:.EE(&5N(&QI9VYE+@!);"!Y("!A('1R;W`@9&4@8V%R86-TZ')E<R!D86YS
M(&-E(&-H86UP+B!6;W5S(&5N(&%V97H@96YT<ND@)7.@.R!I;"!E;B!F875T
M(&UO:6YS(&1E("5S+@!5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@
M;"=A:F]U="!D92"KH"5SH+N@.B`E<P!5;B!P<F]B;.AM92!E<W0@87!P87)U
M(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&5S(&1O;F[I97,@9&4@;"=U=&EL
M:7-A=&5U<B"KH"5SH+N@.B``56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S
M(&1E(&QA('-U<'!R97-S:6]N(&1E(*N@)7.@NZ`Z(`!5;B!P<F]B;.AM92!E
M<W0@87!P87)U(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@9&4@JZ`E<Z"[H#H@
M)7,`56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&PG96YV;VD@9'4@
M9FEC:&EE<J`Z(&%U8W5N("5S(&XG82#I=.D@=')A;G-M:7,N`%5N92!E<G)E
M=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65RH#H@
M;&4@)7,@Z71A:70@<&QU<R!G<F]S('%U92!L92!M87AI;75M(&%U=&]R:7/I
M("@E9"!O8W1E=',I+@!5;F4@97)R975R(&5S="!S=7)V96YU92!L;W)S(&1E
M(&PG96YV;VD@9'4@9FEC:&EE<J`Z(&QE("5S(&$@Z73I('1R86YS;6ES('!A
M<G1I96QL96UE;G0N`%5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D
M92!L)V%C8^AS(.`@;"=A9V5N9&&@.B`E<P!5;F4@97)R975R(',G97-T('!R
M;V1U:71E(&QO<G,@9&4@;"=A:F]U="!D92!L)^EVZ6YE;65N=*`Z("5S`%5N
M92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L)V%F9FEC:&%G92!D
M92!C971T92!P87)T92!D=2!M97-S86=E`%5N92!E<G)E=7(@<R=E<W0@<')O
M9'5I=&4@;&]R<R!D92!L)^ED:71I;VX@9&4@;"?I=NEN96UE;G2@.B`E<P!5
M;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A=&EO
M;B!D97,@9&]N;NEE<R!D92!C92!C;VYT86-T+@!5;F4@97)R975R(&5S="!S
M=7)V96YU92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I97,@:4-A
M;&5N9&%R+@!);"!Y(&%V86ET('5N92!E<G)E=7(@9&%N<R!L92!F;W)M=6QA
M:7)E(&1E(&-O;F9I9W5R871I;VXN(%!E=70MZG1R92!A=F5Z+79O=7,@;&%I
M<W/I('5N(&-H86UP(')E<75I<R!V:61E+@!5;F4@97)R975R(&5S="!A<'!A
M<G5E(&QO<G,@9'4@9.EP;&%C96UE;G0@9&4@;"?I=NEN96UE;G2@.B`E<P!5
M;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=E>.EC=71I;VX@
M9&4@8V5T=&4@9F]N8W1I;VX@9'4@8V%R;F5T(&0G861R97-S92X@4U90(&5S
M<V%Y97(@X"!N;W5V96%U('!L=7,@=&%R9"X`56YE(&5R<F5U<B!E<W0@<W5R
M=F5N=64@;&]R<R!D92!L)V5N=F]I(&1E('9O=')E(&EN=FET871I;VX@X"`E
M<Z`Z("5S`$EL('D@82!E=2!U;F4@97)R975R(&QO<G,@9&4@;&$@;6ES92#@
M(&IO=7(@9&5S(&EN9F]R;6%T:6]N<R!S=7(@;&4@8V]N=&%C="X@(%9E=6EL
M;&5Z(&5S<V%Y97(@X"!N;W5V96%U+@!);"!Y(&$@974@=6YE(&5R<F5U<B!L
M;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1E(&QA(&QI<W1E(&1E(&1I<W1R:6)U
M=&EO;BX@(%9E=6EL;&5Z(&5S<V%Y97(@9&4@;F]U=F5A=2X`075C=6X@Z7;I
M;F5M96YT(.`@97AP;W)T97(@;B=A(.ETZ2!T<F]U=NDN`$QE('!RZ7-E;G0@
M<V5R=F5U<B!)34%0(&YE('-U<'!O<G1E('!A<R!L92!P87)T86=E(&1E(&1O
M<W-I97)S+@#'82!N92!S96UB;&4@<&%S(.IT<F4@=6YE(&%R8VAI=F4@4D%2
M('9A;&ED92X`QV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&9I8VAI97(@6DE0
M('9A;&ED92X`QV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&YU;>ER;R!D92!C
M87)T92!V86QI9&4N`$-E('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S
M86=E<R#@('1R879E<G,@;&$@<&%S<V5R96QL92!#;&EC:V%T96QL("AH='1P
M.B\O8VQI8VMA=&5L;"YC;VTI(&5N('5T:6QI<V%N="!L)T%022!(5%10`$-E
M('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R!V:6$@;&$@<&%S
M<V5R96QL92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!E;B!U=&EL:7-A;G0@
M;"=!4$D@2%144`!#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G
M97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@<VUS,F5M86EL("AH='1P.B\O
M<VUS,F5M86EL+F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%``0V4@<&EL
M;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('!A<B!33510(.`@=')A
M=F5R<R!L82!P87-S97)E;&QE(%9O9&%F;VYE($ET86QI92P@<V5U;&5M96YT
M(&%U>"!N=6WI<F]S(%9O9&%F;VYE+B!#96QA(&[I8V5S<VET92!U;B!C;VUP
M=&4@9&4@8V]U<G)I96P@5F]D869O;F4@271A;&EE("AH='1P.B\O=W=W+C$Y
M,"YI="DN`$-E(&-H86UP(&5S="!O8FQI9V%T;VER92X`0V4@8VAA;7`@;F4@
M9&]I="!C;VYT96YI<B!Q=64@9&5S(&5N=&EE<G,N`$-E(&-H86UP(&YE(&1O
M:70@8V]N=&5N:7(@<75E(&1E<R!N;VUB<F5S(&5T(&QE<R!D975X+7!O:6YT
M<RX`0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S('9A;&5U<G,@
M;V-T86QE<RX`0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U;F4@;&ES=&4@9"=E
M;G1I97)S('/I<&%RZ7,@<&%R(&1E<R!V:7)G=6QE<R!O=2!D97,@97-P86-E
M<P!#92!C:&%M<"!D;VET(.IT<F4@=6X@;F]M8G)E('9A;&ED92X`0V4@8VAA
M;7`@9&]I="!C;VYT96YI<B!U;B!C;V1E(&1E(&-O=6QE=7(@874@9F]R;6%T
M(%)'0B!H97AA9.EC:6UA;"P@<&%R(&5X96UP;&4@)R,Q,C,T868G+@!#92!F
M;W)M870@9&4@9FEC:&EE<B!N)V5S="!P87,@<')I<R!E;B!C;VUP=&4N`$-E
M(&9O<FUU;&%I<F4@82!DZ6K@(.ETZ2!T<F%I=.DN`$,G97-T("5S+@!#96-I
M(&5S="!U;B!O8FIE="!+;VQA8B!'<F]U<'=A<F4N(%!O=7(@=F]I<B!C970@
M;V)J970L('9O=7,@9&5V<F5Z(&%V;VER('5N(&-L:65N="!D92!C;W5R<FEE
M;"!Q=6D@8V]M<')E;F0@;&4@9F]R;6%T($MO;&%B($=R;W5P=V%R92X@4&]U
M<B!U;F4@;&ES=&4@9&4@8V5S(&-L:65N=',@9&4@8V]U<G)I96PL('9I<VET
M97H@)7,`3&4@<V5R=F5U<B!I;F1I<75EH#H@)7,`0V4@;65S<V%G92!A(.ET
MZ2#I8W)I="!D86YS('5N(&-O9&4@9&4@8V%R86-TZ')E<R`H)7,I(&%U=')E
M('%U92!L92!V]'1R92X`0V4@;F]M8G)E(&1O:70@ZG1R92!S=7#I<FEE=7(@
MX"!U;BX`0V4@<V5R=F5U<B!N92!P975T('!A<R!DZ6-O;7!R97-S97(@;&5S
M(&9I8VAI97)S(%I)4"!E="!G>FEP+@!#92!S>7-TZ&UE(&5S="!P<NES96YT
M96UE;G0@9.ES86-T:7;I+@!#971T92!V86QE=7(@9&]I="#J=')E('5N(&YO
M;6)R92X`0V5T=&4@9F5NZG1R92!D;VET(.IT<F4@87!P96SI92!D97!U:7,@
M=6YE(&9E;NIT<F4@9&5S(&]P=&EO;G,`5&]N;F5R<F4`2F5U9&D`5&EC:V5T
M<P!(975R90!0Z7)I;V1E`%-U:79I(&AO<F%I<F4`1F]R;6%T(&0G:&5U<F4`
M4^EL96-T:6]N(&1E(&PG:&5U<F4`1'5RZ64`5&EM;W(@;W)I96YT86P`5&ET
M7W)E`%1I=')E`%1I=')E("AI;F9O8G5L;&4IH#H`P`!0;W5R('/I;&5C=&EO
M;FYE<B!P;'5S:65U<G,@:71E;7,@X"!L82!F;VES+"!M86EN=&5N97H@96YF
M;VYCZ2!L92!B;W5T;VX@JZ!#=')LH+L@*%!#*2!O=2"KH$-O;6UA;F1EH+L@
M*$UA8RD@96X@8VQI<75A;G0N`$%U:F]U<F0G:'5I`%9O:7(@;&$@<V]U<F-E
M($A434P`5&]G;P!4;VME;&%U`$1E;6%I;@!4;VYG80!(875T`$-A9')E(&1U
M(&AA=70@*%]T;W`I`%1R861U8W1I;VYS`%1R:6YI=.DM970M5&]B86=O`%9R
M86D@;W4@9F%U>`!-87(`36%R9&D`5'5N:7-I90!4=7)Q=6EE`%1U<F,@*$E3
M3RTX.#4Y+3DI`%1U<FMMZ6YI<W1A;@#.;&5S(%1U<G%U97,@970@0V'O<75E
M<P!4=79A;'4`5'EP90!%;G1R97H@=F]T<F4@8VAO:7B@.B``26YD:6-E(%56
MH#H@`%523`!54DP@<&]U<B!V;W1R92!R87!P;W)T(&1E(&QI=G)A:7-O;B!D
M=2!S8W)I<'0`55),.@!/=6=A;F1A`%5K<F%I;F4`26UP;W-S:6)L92!D)V%T
M=&5I;F1R92!L92!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S:6)L92!D)V%J;W5T
M97(@9&5S(&EN9F]R;6%T:6]N<R!C;VUP;.EM96YT86ER97,@X"!L)VEN<V-R
M:7!T:6]N+@!);7!O<W-I8FQE(&1E(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N
M<R!P;W5R(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D92!M
M;V1I9FEE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!L92!F:6-H:65R(%9&4R`E
M<R\E<RX`26UP;W-S:6)L92!D92!C:&%N9V5R('!O=7(@)7,N`$EM<&]S<VEB
M;&4@9&4@=NER:69I97(@;&$@=&%I;&QE(&1U(&9I8VAI97(@9&4@JZ`E<Z"[
M+@!);7!O<W-I8FQE(&1E(';I<FEF:65R(&QA('1A:6QL92!D=2!F:6-H:65R
M(&1E(*L@)7,O)7,@NRX`0V]N;F5X:6]N(&%U('-E<G9E=7(@4U%,(&EM<&]S
M<VEB;&4N`$-O;FYE>&EO;B!I;7!O<W-I8FQE(&5N(%-33`!);7!O<W-I8FQE
M(&1E(&-O<&EE<B!U;B!F:6-H:65R(%9&4RX`26UP;W-S:6)L92!D92!C<NEE
M<B!U;B!RZ7!E<G1O:7)E(%9&4R"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@8W+I
M97(@=6X@<NEP97)T;VER92!61E,N`$EM<&]S<VEB;&4@9&4@8W+I97(@;&4@
M9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@9&4@8W+I97(@;&4@<NEP97)T;VER
M92!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(&-RZ65R('5N(&9I8VAI97(@
M5D93('9I9&4N(`!/=79E<G1U<F4@:6UP;W-S:6)L92!D92!L)V%R8VAI=F4@
M8V]M<')E<W/I92X@`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@JZ`E<Z"[
M+"!L92!D;W-S:65R(&XG97-T('!A<R!V:61E+@!3=7!P<F5S<VEO;B!I;7!O
M<W-I8FQE(&1E(*N@)7.@NZ`Z("5S`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@
M9&4@JZ`E<Z"[H#H@)7,N`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@)7,L
M(&QE(&1O<W-I97(@;B=E<W0@<&%S('9I9&4`4W5P<')E<W-I;VX@<NEC=7)S
M:79E(&1U(&1O<W-I97(@5D93(&EM<&]S<VEB;&4N`%-U<'!R97-S:6]N(&1U
M('+I<&5R=&]I<F4@5D93(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9&4@<W5P
M<')I;65R(&QE('+I<&5R=&]I<F4@5D93H#H@)7,N`%-U<'!R97-S:6]N(&EM
M<&]S<VEB;&4@9'4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!3=7!P<F5S<VEO;B!I
M;7!O<W-I8FQE(&1U(&9I8VAI97(@5D93+@!3=7!P<F5S<VEO;B!I;7!O<W-I
M8FQE(&1U('+I<&5R=&]I<F4@5D93(*N@)7.@NRX`4W5P<')E<W-I;VX@5D93
M('+I8W5R<VEV92!I;7!O<W-I8FQEH#H@)7,N`$EM<&]S<VEB;&4@9&4@9.ET
M97)M:6YE<B!L92!D;W-S:65R(&-O=7)A;G0N`$EM<&]S<VEB;&4@9"=E>'1R
M86ER92!L97,@9.ET86EL<R!D=2!C97)T:69I8V%T`$-H87)G96UE;G0@:6UP
M;W-S:6)L92!D92!L82!DZ69I;FET:6]N(&1E("5S+@!);7!O<W-I8FQE(&1E
M(&3I<&QA8V5R(&QE(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&0G;W5V<FER
M(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D)V]U=G)I<B!U
M;B!F:6-H:65R(%9&4R!E;B#I8W)I='5R92X`26UP;W-S:6)L92!D)V]U=G)I
M<B!U;B!F:6-H:65R(%9&4RX`3W5V97)T=7)E(&EM<&]S<VEB;&4@9&4@;"=A
M<F-H:79E(&-O;7!R97-SZ64N`$EM<&]S<VEB;&4@9&4@;&ER92!L92!F:6-H
M:65R(%9&4R`HZ6-H96,@9&4@9FEL97-I>F4H*2DN`$EM<&]S<VEB;&4@9&4@
M;&ER92!L92!F:6-H:65R(%9&4R`HZ6-H96,@9&4@9V5T1FEL95-I>F4H*2DN
M`$EM<&]S<VEB;&4@9&4@;&ER92!L92!F:6-H:65RH#H@`$QE8W1U<F4@9'4@
M<NEP97)T;VER92!R86-I;F4@5D93(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@
M9&4@<F5N;VUM97(@JZ`E<Z"[H#H@)7,`26UP;W-S:6)L92!D92!R96YO;6UE
M<B`E<R!E;B`E<Z`Z(&QE(&1O<W-I97(@8VEB;&4@97AI<W1E(&3I:N``26UP
M;W-S:6)L92!D92!R96YO;6UE<B!L92!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S
M:6)L92!D92!R96YO;6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z("5S+@!);7!O
M<W-I8FQE(&1E(')E;F]M;65R(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP
M;W-S:6)L92!D92!R96YO;6UE<B!L92!F:6-H:65R(%9&4R`E<R\E<RX`26UP
M;W-S:6)L92!D92!R96YO;6UE<B!L92!F:6-H:65R(%9&4RX`26UP;W-S:6)L
M92!D92!RZ6-U<.ER97(@;&5S(&EN9F]R;6%T:6]N<R!D92!D:7-P;VYI8FEL
M:73I<R!D92`E<P!);7!O<W-I8FQE(&0G97CI8W5T97(@)VUK:7-O9G,G+@!)
M;7!O<W-I8FQE(&1E('1R861U:7)E(&-E(&1O8W5M96YT(%=O<F0N`$EM<&]S
M<VEB;&4@9"?I8W)I<F4@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!);7!O<W-I
M8FQE(&0GZ6-R:7)E(&QE<R!D;VYNZ65S(&1U(&9I8VAI97(@5D93("AC;W!Y
M*"D@:6UP;W-S:6)L92DN`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&5S(&1O;F[I
M97,@9'4@9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&4@9FEC
M:&EE<B!61E,L(&QE('%U;W1A('-E<F%I="!DZ7!A<W/I+@!3;W5L:6=N97(`
M06YN=6QE<B!L97,@8VAA;F=E;65N=',`06YN=6QE('9O=')E(&1E<FYIZ')E
M(&%C=&EO;@!2Z7!O;G-E(&EN871T96YD=64@9'4@<V5R=F5U<B!L;W)S(&1E
M(&QA(&-O;FYE>&EO;J`Z(`!2Z7!O;G-E(&EN871T96YD=64@9'4@<V5R=F5U
M<B#@H#H@`$AO<G,@8V%TZ6=O<FEE`%5N:6-O9&4@*%541BTX*0#);6ER871S
M($%R86)E<R!5;FES`%)O>6%U;64M56YI`,ET871S+55N:7,`SFQE<R!E>'3I
M<FEE=7)E<R!D97,@R71A=',M56YI<P!5;FETZ7,`26YC;VYN=0!A<&EM<V=I
M9"!I;F-O;FYU("A!4$D@365S<V%G92!)1"DN`&-L:6US9VED(&EN8V]N;G4@
M*$-L:65N="!-97-S86=E($E$*2X`16UP;&%C96UE;G0@<^EL96-T:6]N;ND@
M:6YC;VYN=2X`3F]M(&0G=71I;&ES871E=7(@;W4@;6]T(&1E('!A<W-E(&EN
M8V]N;G4N`$3I;&EE<B!L)^ELZ6UE;G0@8V]U<F%N=`!386YS(&YO;0!,97,@
M<V-R:7!T<R!N;VXM<')I=FELZ6=IZ7,@;F4@<&5U=F5N="!A8V/I9&5R(&%U
M>"!F;VYC=&EO;G,@8V]U<&5R+V-O<&EE<B]C;VQL97(@<&]U<B!D97,@<F%I
M<V]N<R!D92!SZ6-U<FETZ2X@07!P=7EE>B!S=7(@3TL@<&]U<B!V;VER('5N
M92!N;W1E('1E8VAN:7%U92!S=7(@;6]Z:6QL82YO<F<@<75I('9O=7,@97AP
M;&EQ=65R82!C;VUM96YT(&%U=&]R:7-E<B!U;B!S8W)I<'0@X"!U=&EL:7-E
M<B!L92!P<F5S<V4M<&%P:65R<P!296UE='1R92!L82!C;W5L975R(.`@>NER
M;P!4>7!E(&1E(&-O;G1E;G4@;F]N+7-U<'!O<G3IH#H@)7,`17AT96YS:6]N
M(&YO;B!P<FES92!E;B!C;VUP=&4`36]D:69I97(`36]D:69I97(@)7,`36]D
M:69I97(@;"=U=&EL:7-A=&5U<@!-:7-E(.`@:F]U<B!D92"KH"5SH+LN`$UI
M<V4@X"!J;W5RH#H@)7,`3&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&5S="!S
M=7!P<FEMZ0!#:&%R9V5R`%1O=7,@;&5S(&9I8VAI97)S(&1E(&-O;F9I9W5R
M871I;VX@9&5S(&%P<&QI8V%T:6]N<R!O;G0@Z73I(&5N=F]YZ7,@<W5R(&QE
M('-E<G9E=7(N`$QE='1R97,@;&%T:6YE<R!M86IU<V-U;&5S`$YO;6)R97,@
M<F]M86EN<R!M86IU<V-U;&5S`%5R=6=U87D`16UP;&]YZ2!A8W1U96QL96UE
M;G2@.B`E<P!5=&EL:7-E<B!34TP`571I;&ES97(@<VD@;&4@;F]M(&0G=71I
M;&ES871E=7(O;6]T(&1E('!A<W-E(&5S="!D:69FZ7)E;G0@9'4@<V5R=F5U
M<B!)35-0+@!5=&EL:7-A=&5U<@!,)W5T:6QI<V%T975R("5S(&XG82!P87,@
M;"=A=71O<FES871I;VX@<&]U<B`E<RX`061M:6YI<W1R871I;VX@9&5S('5T
M:6QI<V%T975R<P!);G1E<F9A8V4@=71I;&ES871E=7(`4'+I9NER96YC97,@
M<&5R<V]N;F5L;&5S`$5N<F5G:7-T<F5M96YT(&1E<R!U=&EL:7-A=&5U<G,`
M3"=E;G)E9VES=')E;65N="!D)W5T:6QI<V%T975R(&5S="!DZ7-A8W1I=ND@
M<W5R(&-E('-Y<W3H;64N`$-O;7!T92!U=&EL:7-A=&5U<B!N;VX@=')O=7;I
M`$YO;2!D)W5T:6QI<V%T975R`$QE(&YO;2!D92!C;VYN97AI;VX@JZ`E<Z"[
M(&5X:7-T92!DZ6K@+@!.;VT@9"=U=&EL:7-A=&5U<J`Z`$YO;2!D)W5T:6QI
M<V%T975RH#H@`%5T:6QI<V%T975R<R!DZ69I;FESH#H`3W5Z8NEK:7-T86X`
M4NEP97)T;VER92!61E,@:6YE>&ES=&%N="X`06)S96YC97,`3&5S(&5M<&QA
M8V5M96YT<R!V86QI9&5S('1R;W5VZ7,@:6YC;'5E;G2@.B``5F%L:61I=.D`
M5F%L975R(&5N(&UI;G5T97,@X"!P87)T:7(@9&4@;6%I;G1E;F%N="X`5F%L
M975R('-U<.ER:65U<F4@X"!L82!L;VYG=65U<B!M87AI;6%L92!D92`E<RX`
M5F%L975R<P!686QE=7)S(.`@<^EL96-T:6]N;F5R(&1E`%9A;G5A='4`5F%R
M:6%B;&4`5NENZ7IU96QA`,EC:&5C(&1E(&QA(';I<FEF:6-A=&EO;B`F;61A
M<V@[(&-E(&UE<W-A9V4@82!P975T+>IT<F4@Z73I(&9A;'-I9FGI+@!697)S
M:6]N`$-O;G1R]&QE(&1E('9E<G-I;VX`06QI9VYE;65N="!V97)T:6-A;`!2
M96UP;&ES<V%G92!V97)T:6-A;`!697)T:6-A;*`Z`%1RZ',@:&%U=&4`5FEE
M=&YA;0!6:>IT+6YA;6EE;B`H5DE30TE)*0!6;VER("5S`%9O:7(@;&4@:F]U
M<@!6;VER('5N92!P86=E('=E8B!E>'1E<FYE`%9O:7(@8V]M;64@)7,`SFQE
M<R!6:65R9V5S(&)R:71A;FYI<75E<P#.;&5S(%9I97)G97,@9&5S(,ET871S
M+55N:7,`5FES:6)I;&ETZ0!6:7-I8FEL:73IH#H@`%9O9&%F;VYE($ET86QY
M('9I82!33510`$Y/5$E#10!!5%1%3E1)3TXA(2$@(%-54%!224U%4B!,12!3
M0U))4%0@34%.545,3$5-14Y4($1%("5S`%=)3B!V:6$@2%144`!786QL:7,@
M970@1G5T=6YA`$%T=&5N=&EO;@!-97(`4'+I=FES:6]N<R!MZ73I;P!$;VYN
MZ65S(&WI=.EO(&9O=7)N:65S('!A<@!796%T:&5R+F-O;0!796(`4VET92!W
M96(`365R8W)E9&D`4V5M86EN90!396UA:6YE("5D`%-E;6%I;F4H<RD`0VAA
M<75E('-E;6%I;F4`2&5B9&]M861A:7)EH#H@<NEPZ71I=&EO;B!C:&%Q=64`
M0FEE;G9E;G5E`$)I96YV96YU92#@("5S`$)I96YV96YU92P@)7,`3V-C:61E
M;G1A;"`H25-/+3@X-3DM,2D`3V-C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A
M:&%R82!/8V-I9&5N=&%L`%%U96QL92!A<'!L:6-A=&EO;B`E<R!D;VET+6EL
M('!RZ7-E;G1E<B!A<'+H<R!L82!C;VYN97AI;VZ@/P!1=65L(&5S="!L92!C
M87)A8W3H<F4@9&4@<^EP87)A=&EO;J`_`%%U96P@97-T(&QE(&-A<F%C=.AR
M92!D92!C:71A=&EO;J`_`$1E<FYIZ')E(&AE=7)E('-U<B!L97,@Z6-R86YS
M(&1E<R!J;W5R<R!E="!D97,@<V5M86EN97,L('%U86YD(&EL(&XG>2!A('!A
M<R!D)^EVZ6YE;65N="!U;'3I<FEE=7*@/P!0<F5M:>AR92!H975R92!S=7(@
M;&5S(.EC<F%N<R!D97,@:F]U<G,@970@9&5S('-E;6%I;F5S+"!Q=6%N9"!I
M;"!N)WD@82!P87,@9"?I=NEN96UE;G0@86YTZ7)I975RH#\`0V%R=&4@5VAE
M<F5I<R!!=7-T<F%L:64`475E;&QE<R!P:&%S97,`475E;&QE<R!E>'1E;G-I
M;VYS(&%C=&EV97(@<&]U<B!L)^ED:71E=7(@4FEC:"!497AT+@!,87)G975R
M`$QA<F=E=7(@96X@=6YI=.ES($-34P!,87)G975R(&1U(&UE;G4@9&4@9V%U
M8VAE("5S("`H;&$@8V]N9FEG=7)A=&EO;B!P<F5N9')A(&5F9F5T(.`@;&$@
M<')O8VAA:6YE(&-O;FYE>&EO;BF@.@!,87)G975R(&1U('1A8FQE874`56YI
M=.D@9&4@;&%R9V5U<@!,87)G975RH#H`5VEK:0!696YT`%9E;G0@=/1T(&QE
M(&UA=&EN`%9I=&5S<V4@9'4@=F5N="!E;B!N)F]E;&EG.W5D<P!696YTH#H`
M5F5N=*`Z(`!386=E<W-E`$QI<W1E(&1E('8F;V5L:6<[=7@`5')A=F%I;`!!
M9')E<W-E('!R;V9E<W-I;VYN96QL90!4Z6SI<&AO;F4@<')O9F5S<VEO;FYE
M;`!396UA:6YE(&]U=G)A8FQE`$YO;6)R92!D92!C:&%M<',@:6YC;W)R96-T
M(.`@;&$@;&EG;F4@)60N("5D(&%T=&5N9'5S+"`E9"!T<F]U=NES+@!.;VUB
M<F4@9&4@8VAA;7!S(&EN8V]R<F5C="X@)60@871T96YD=7,L("5D('1R;W5V
MZ7,N`$3I8V%L86=E("5D(&EN8V]R<F5C="!L;W)S(&1E(&QA(&QE8W1U<F4@
M9&4@9FEC:&EE<B!61E,N`%@M4F5F`$-O;G1R86EN=&5S(&)A<VEQ=65S(%@U
M,#EV,P!5=&EL:7-A=&EO;B!D92!C;.D@Z71E;F1U92!8-3`Y=C,`075T<F4@
M;F]M(&1U('-U:F5T(%@U,#EV,P!)9&5N=&EF:6%N="!D92!C;.D@9'4@<W5J
M970@6#4P.78S`$5X=&5N<VEO;G,@6#4P.78S`$%!`$%!04$`0V%R=&4@JZ!9
M86AO;Z`AH+L`06YNZ64`06YN=65L;&5M96YT`$%N;G5E;&QE;65N=*`Z('+I
M<.ET:71I;VX@8VAA<75E`%GI;65N`$]U:0!/=6DL(&HG86-C97!T90!6;W5S
M(.IT97,@96X@;6]D92"KH%1E>'1EH+LN(%5T:6QI<V5Z(&QE(&)O=71O;B!;
M/#Y=('!O=7(@<F5V96YI<B!A=2!M;V1E(*N@5UE325=91Z"[+@!6;W5S(&XG
MZG1E<R!P87,@875T;W)I<^D@X"!C<NEE<B!P;'5S(&1E("5D(&)L;V-S+@!6
M;W5S(&XGZG1E<R!P87,@875T;W)I<^D@X"!C<NEE<B!P;'5S(&1E("5D(.EV
MZ6YE;65N=',N`%9O=7,@;B?J=&5S('!A<R!U;B!D97,@<&%R=&EC:7!A;G1S
M(.`@;"?I=NEN96UE;G0@<W#I8VEF:>DN`%9O=7,@;B?J=&5S('!A<R!A=71H
M96YT:69IZ2X`0V4@9F]R;75L86ER92!N92!P975T(.IT<F4@=71I;&ESZ2!Q
M=64@9&5P=6ES(&PGZ6-R86X@9"?I9&ET:6]N(&1E<R!P87)T:6-I<&%N=',N
M(`!6;W5S(&YE('!O=79E>B!P87,@879O:7(@;&4@8V%R86-TZ')E(*M<NR!D
M86YS('9O=')E(&YO;2!C;VUP;&5T+@!6;W5S(&XG879E>B!P87,@<V%I<VD@
M=6YE(&%D<F5S<V4@Z6QE8W1R;VYI<75E('9A;&ED92X`5F]U<R!N)V%V97H@
M<&%S(&%S<V]C:>D@;&5S(&-H86UP<R!D=2!F:6-H:65R(&EM<&]R=.D@875X
M(&-H86UP<R!C;W)R97-P;VYD86YT<R!D86YS("5S+@!!=6-U;F4@861R97-S
M92!D92!C;W5R<FEE;"!N)V5S="!C;VYF:6=U<NEE(&1A;G,@=F]T<F4@<')O
M9FEL+B!6;W5S(&1E=F5Z(&5N(&3I9FEN:7(@=6YE("5S:6-I)7,@879A;G0@
M<75E(&1E<R!N;W1I9FEC871I;VYS(&0GZ7;I;F5M96YT<R!P=6ES<V5N="#J
M=')E(&5N=F]YZ65S+@!6;W5S(&XG879E>B!P87,@;"=A=71O<FES871I;VX@
M9"=A:F]U=&5R(&1E<R#I=NEN96UE;G1S(.`@)7,N`%9O=7,@;B=A=F5Z('!A
M<R!L)V%U=&]R:7-A=&EO;B!D)V%J;W5T97(@9&5S(.EVZ6YE;65N=',@X"!L
M)V%G96YD82!SZ6QE8W1I;VYNZ2X`5F]U<R!N)V%V97H@<&%S(&PG875T;W)I
M<V%T:6]N(&1E('-U<'!R:6UE<B!C970@Z7;I;F5M96YT+@!6;W5S(&XG879E
M>B!P87,@;"=A=71O<FES871I;VX@9&4@;6]D:69I97(@8V5T(.EVZ6YE;65N
M="X`5F]U<R!A=F5Z(.ETZ2!DZ6-O;FYE8W3I+@!6;W5S(&%V97H@:6YD:7%U
MZ2!U;B!A9V5N9&$@:6YV86QI9&4N`%9O=7,@879E>B!A8V-E<'3I(&1E('!A
M<G1I8VEP97(@X"!C970@Z7;I;F5M96YT+@!6;W5S(&%V97H@<F5F=7/I(&1E
M('!A<G1I8VEP97(@X"!C970@Z7;I;F5M96YT+@!6;W5S(&%V97H@86-C97!T
MZ2!D92!P87)T:6-I<&5R(.`@8V5T(.EVZ6YE;65N="!A=F5C(&1E<R!RZ7-E
M<G9E<RX`5F]U<R!D979E>B!I;G-C<FER92!U;B!N=6WI<F\@9&4@8V5L;'5L
M86ER92!V86QI9&4L('-E=6QS(&1E<R!N;VUB<F5S(&5T('5N(*LKNR!O<'1I
M;VYN96P@<&]U<B!L97,@87!P96QS(&EN=&5R;F%T:6]N875X+@!6;W5S(&XG
M879E>B!P87,@<V%I<VD@=6YE(&5N='+I92!V86QI9&4N`%9O=7,@9&5V97H@
M8V]N9FEG=7)E<B!U;B!B86-K96YD($1A=&%4<F5E('!O=7(@=71I;&ES97(@
M;&5S(&EN<V-R:7!T:6]N<P!6;W5S(&1E=F5Z(&-O;F9I9W5R97(@=6X@;6]D
M=6QE(%9&4RX`5F]U<R!D979E>B!DZ6-R:7)E(&QE('!R;V)LZ&UE(&%V86YT
M(&1E(&YO=7,@9F%I<F4@<&%R=F5N:7(@;&4@<F%P<&]R="X`5F]U<R!D979E
M>B!E;G1R97(@=6YE(%523"!O^2!P;VEN=&4@9&4@;&EE;BX`26P@9F%U="!D
M)V%B;W)D('/I;&5C=&EO;FYE<B!L)V%G96YD82#@('-U<'!R:6UE<BX`26P@
M9F%U="!D)V%B;W)D('/I;&5C=&EO;FYE<B!U;F4@861R97-S92X`26P@9F%U
M="!SZ6QE8W1I;VYN97(@=6X@<V5R=F5U<B#@('-U<'!R:6UE<BX`5F]U<R!D
M979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+B``5F]U
M<R!D979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+@!6
M;W5S(&1E=F5Z('-PZ6-I9FEE<B!U;B!U=&EL:7-A=&5U<B#@(&%J;W5T97(N
M`%9O=7,@9&5V97H@<W#I8VEF:65R(&QE(&YO;2!D92!L)W5T:6QI<V%T975R
M(.`@;6]D:69I97(N`%9O=7,@9&5V97H@:6YD:7%U97(@<75E;&QE(&%C=&EO
M;B!A8V-O;7!L:7(N`%9O=7,@9&5V97H@Z6-R:7)E('5N(&YO;2!P;W5R(&QA
M(&YO=79E;&QE(&-A=.EG;W)I92X`5F]U<R!D979E>B!F;W5R;FER('5N(&ZP
M(&1E('3I;.EP:&]N92!I=&%L:65N`%9O=7,@879E>B!D96UA;F3I(.`@ZG1R
M92!A=F5R=&D@9&5S(.EVZ6YE;65N=',@86IO=73I<R#@('9O<R!A9V5N9&$N
M`%9O=7,@879E>B!D96UA;F3I(.`@ZG1R92!A=F5R=&D@9&4@;&$@<W5P<')E
M<W-I;VX@9"?I=NEN96UE;G1S(&1A;G,@=F]S(&%G96YD87,N`%9O=7,@879E
M>B!D96UA;F3I(.`@ZG1R92!N;W1I9FGI(&1E(&QA(&TN(.`@:BX@9"?I=NEN
M96UE;G1S(&1A;G,@=F]S(&%G96YD87,N`%9O=7,@879E>B!D96UA;F3I(&QE
M(')A<'!E;"!D92`E<RP@;&4@)7,@X"`E<RX`5F]T<F4@<V5S<VEO;B`E<R!A
M(&5X<&ERZ2X@5F5U:6QL97H@=F]U<R!R96-O;FYE8W1E<BX`5F]T<F4@861R
M97-S92!D92!C;W5R<FEE;`!6;W1R92!A9')E<W-E(&1E(&-O=7)R:65L(*L@
M1&4Z(+N@.@!6;W,@9&]N;NEE<R!P97)S;VYN96QL97,`5F]T<F4@861R97-S
M92!);G1E<FYE="!A(&-H86YGZ2!D97!U:7,@;"=O=79E<G1U<F4@9&4@=F]T
M<F4@<V5S<VEO;B`E<RX@(%!O=7(@=F]T<F4@<^EC=7)I=.DL('9O=7,@9&5V
M97H@=F]U<R!R96-O;FYE8W1E<BX`5F]T<F4@;F]M`%9O=')E(&UO9'5L92!D
M)V%U=&AE;G1I9FEC871I;VX@;F4@<W5P<&]R=&4@<&%S(&PG86IO=70@9"=U
M=&EL:7-A=&5U<G,L(%-I('9O=7,@<V]U:&%I=&5Z('5T:6QI<V5Z($AO<F1E
M('!O=7(@861M:6YI<W1R97(@;&5S(&-O;7!T97,@=71I;&ES871E=7)S+"!V
M;W5S(&1E=F5Z('5T:6QI<V5R('5N(&%U=')E(&UO9'5L92!D)V%U=&AE;G1I
M9FEC871I;VXN`%9O=')E(&UO9'5L92!D)V%U=&AE;G1I9FEC871I;VX@;B=E
M<W0@<&%S(&5N(&UE<W5R92!D)^ET86)L:7(@=6YE(&QI<W1E(&1E<R!U=&EL
M:7-A=&5U<G,L(&]U(&-E='1E(&9O;F-T:6]N(&$@Z73I(')E=&ERZ64@<&]U
M<B!U;F4@875T<F4@<F%I<V]N+@!6;W1R92!N879I9V%T975R('-E;6)L92!A
M=F]I<B!C:&%N9^D@9&5P=6ES(&QE(&3I8G5T(&1E('9O=')E('-E<W-I;VX@
M)7,N("!0;W5R('9O=')E('/I8W5R:73I+"!V;W5S(&1E=F5Z('9O=7,@<F5C
M;VYN96-T97(N`%9O=')E(&YA=FEG871E=7(@;F4@<W5P<&]R=&4@<&%S(&-E
M='1E(&]P=&EO;@!6;W1R92!N879I9V%T975R(&YE('!R96YD('!A<R!E;B!C
M;VUP=&4@8V5T=&4@;W!T:6]N(&0G:6UP<F5S<VEO;BX@4')E<W-E>B!#;VYT
M<O1L92]#;VUM86YD92`K(%`@<&]U<B!I;7!R:6UE<@!6;W1R92!F=7-E874@
M:&]R86ER92!A8W1U96R@.@!6;W1R92!A9V5N9&$@<&%R(&3I9F%U=`!6;W1R
M92!P<F]F:6P@<&%R(&3I9F%U="!A(.ETZ2!M;V1I9FGI+@!0<F]F:6P@<&%R
M(&3I9F%U=*`Z`%9O=')E(&YO;2!C;VUP;&5TH#H`5F]T<F4@8V]M<'1E(&$@
M97AP:7+I+@!6;W1R92!N;W5V96%U(&UO="!D92!P87-S92!P;W5R("5S(&5S
M=*`Z)7,`5F]S(&]P=&EO;G,@;VYT(.ETZ2!M:7-E<R#@(&IO=7(@<&]U<B!L
M82!D=7+I92!D92!C971T92!S97-S:6]N+@!6;W,@;W!T:6]N<R!O;G0@Z73I
M(&UI<V5S(.`@:F]U<BX`5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E;6ES
M(.`@>NER;P!6;W1R92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@X"!ZZ7)O
M+"!VZ7)I9FEE<B!V;W1R92!C;W5R<FEE<B!E="!C;VYN96-T97HM=F]U<R!A
M=F5Z('9O=')E(&YO=79E874@;6]T(&1E('!A<W-E+@!6;W1R92!M;W0@9&4@
M<&%S<V4@82!E>'!I<NDN`%9O<R!S97)V975R<R!D:7-T86YT<Z`Z`%EO=6=O
M<VQA=FEE`%IA[W)E`%IA;6)I90!::6UB86)W90!::7!P>0!;0V%C:&5R(&QE
M<R!C:71A=&EO;G-=`%M287!P;W)T(&1E('!R;V)LZ&UE70!;069F:6-H97(@
M;&4@=&5X=&4@8VETZ2`M`%M!9F9I8VAE<B!L92!T97AT92!C:73I("T@)7,@
M;&EG;F5S70!;R7;I;F5M96YT('-A;G,@;F]M70!;;&EG;F4@)7,@9&4@)7-=
M`%]!9&UI;FES=')A=&EO;@!?06QE<G1E`%]296-H97)C:&4@<VEM<&QE`$QI
M9VYE(&1E(%]C;VUM86YD90!?1&%T851R964`4W5P<')I;65R(&QA(%]R86YG
MZ64`R61I=%]E<@!!;&QE7W(@X`!?1W)O=7!E<P!?06ED90!0<F]P<E]IZ73I
M<R!D92!L)VEM86=E+BXN`%]);7!O<G1E<B]%>'!O<G1E<@!?0V]N;F5X:6]N
M`%]$Z6-O;FYE>&EO;@!?36]D:69I97(@=6X@;&EE;B!W96(N+BX`7TUE<R!A
M9V5N9&%S`%].;W5V96P@Z7;I;F5M96YT`%]/<'1I;VYS`%]097)M:7-S:6]N
M<P!);5]P<FEM97(`7U)E=&ER97(@=6X@;&EE;@!?4F5C:&5R8VAE`%]#;VYF
M:6=U<F%T:6]N`%!R;W!R:>ETZ7,@9'4@7W1A8FQE874`075?:F]U<F0G:'5I
M`%]5=&EL:7-A=&5U<G,`8V%R;F5T(&0G861R97-S97,`9&5S=&EN871A:7)E
M(&EN8V]N;G4`879A;G0@;&4@9.EB=70@9&4@;"?I=NEN96UE;G0`86=E;F1A
M`&-A;&UE`&EM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!D92!S;W)T
M:64`:6UP;W-S:6)L92!D)V]U=G)I<B!L)V5N='+I90!C;&EQ=65Z(&EC:0!E
M<G)E=7(@9"=U=&EL:7-A=&EO;B!D92!L82!L:6=N92!D92!C;VUM86YD90!E
M<G)E=7(@9&4@8V]N9FEG=7)A=&EO;@!A8G-E;F-E(&-R:71I<75E(&0G=6X@
M9FEC:&EE<B!S>7-TZ&UE`&5R<F5U<B!D92!F;W)M870@9&4@9&]N;NEE`&IO
M=7(`:F]U<BAS*0!J;W5R<P!E;G1RZ64@;F]N('1R;W5VZ0!E=F5N=',N8W-V
M`&5V96YT<RYI8W,`=&]M8F%N=`!F:6-H:65R`&1E<'5I<R!L92`E<R`H)7,I
M(.`@)7,@)7,`96X@<F%F86QE`&B@.@!H:`!N;VT@9"=H]'1E(&EN8V]N;G4`
M:6UMZ61I871E;65N=`!D86YS`&EN8V]R<&]RZ64`97)R975R(&0G96YT<NEE
M+W-O<G1I90!E<G)E=7(@;&]G:6-I96QL92!I;G1E<FYE`&QI9VYE<UT`97)R
M975R(&UK:7-O9G,@8V]D92`E9"!E;B!C<NEA;G0@;"=)4T\`;6T`;6]I<P!N
M;VT`;F]N('!R:7,@96X@8V]M<'1E`'!A<R!E;F-O<F4@<')I<R!E;B!C;VUP
M=&4`8FQO8RUN;W1E<P!L92`E<R#@("5S`.`@;&$@;>IM92!D871E`&QE(&WJ
M;64@:F]U<B!D92!L82!S96UA:6YE`'!O=7)C96YT86=E`'!E<FUI<W-I;VX@
M<F5F=7/I90!P:7AE;',`97)R975R(&1I<W1A;G1E(&1A;G,@;&4@<')O=&]C
M;VQE`',GZ6QE=F%N=`!S97)V:6-E(&YO;B!D:7-P;VYI8FQE+@!M;VYT<F5R
M(&QE<R!D:69FZ7)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`9FEX90!E
M<G)E=7(@<WES=.AM90!L:7-T92!D92!TXF-H97,`Z6-H96,@=&5M<&]R86ER
M90!E;G1R97H@;&4@;6]T(&1E('!A<W-E(&1E=7@@9F]I<R!P;W5R(&-O;F9I
M<FUE<@!U;FEF:>D`<V%N<R!N;VT`4^EL96-T:6]N(&0G=71I;&ES871E=7(`
M=D-A;&5N9&%R+VE#86QE;F1A<@!V0V%R9`!VR7;I;F5M96YT(&YO;B!T<F]U
M=NDN`&R@.@!W96%T:&5R+F-O;0!S96UA:6YE`'-E;6%I;F4H<RDL(&QEH#H`
M<V5M86EN97,`86YNZ64H<RD`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]H=5](52\`````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,``P,C`W
M,#$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+VAU
M7TA5+TQ#7TU%4U-!1T53+P``````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4P`#`R,C0V-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR
M;VYO;&ET:"]L;V-A;&4O:'5?2%4O3$-?34534T%'15,O:W)O;F]L:71H+FUO
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`U,#<U-S$`,3`T,3<S-C(W-3``,#(U,#4P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-X2!)4`````T`@`
M`!P```"<1@``PPL``!R-````````*+P```X````IO```#P```#B\```-````
M2+P```@```!6O```"P```%^\```,````:[P```0```!XO```&````'V\```;
M````EKP``"T```"RO```'0```."\```D````_KP``"D````CO0``&0```$V]
M```F````9[T```P```".O0``$@```)N]```D````KKT```D```#3O0``#P``
M`-V]```+````[;T``!\```#YO0``#@```!F^```H````*+X```@```!1O@``
M"@```%J^```5````9;X``!(```![O@``"P```(Z^```,````FKX``!T```"G
MO@``A0```,6^```.````2[\```H```!:OP``#0```&6_```.````<[\``!$`
M``""OP``#0```)2_```,````HK\```T```"OOP``E````+V_``!/````4L``
M`!T```"BP```'0```,#````*````WL````\```#IP```&````/G````,````
M$L$```H````?P0``!P```"K!```&````,L$```X````YP0``"@```$C!```*
M````4\$```X```!>P0``"````&W!```*````=L$```D```"!P0``)0```(O!
M```H````L<$``"0```#:P0``)@```/_!```N````)L(``!H```!5P@``,@``
M`'#"```X````H\(``%0```#<P@``40```#'#``!:````@\,``%<```#>PP``
M-````#;$```)````:\0```T```!UQ```!P```(/$```*````B\0```\```"6
MQ```!0```*;$```&````K,0``!$```"SQ```"````,7$```)````SL0```D`
M``#8Q```"````.+$```E````Z\0``"`````1Q0``$P```#+%```0````1L4`
M``\```!7Q0``"@```&?%```0````<L4```,```"#Q0``#P```(?%```4````
ME\4```D```"LQ0``"0```+;%```-````P,4``!(```#.Q0``&0```.'%```>
M````^\4``!D````:Q@``#P```#3&```/````1,8```T```!4Q@``"@```&+&
M```/````;<8```@```!]Q@``)````(;&```4````J\8``!````#`Q@``%@``
M`-'&```(````Z,8``$X```#QQ@``+0```$#'```9````;L<```<```"(QP``
M#````)#'```L````G<<```X```#*QP```P```-G'```/````W<<```L```#M
MQP``!0```/G'```4````_\<``!4````4R```%P```"K(```5````0L@``!(`
M``!8R```$P```&O(```5````?\@``!,```"5R```"@```*G(```4````M,@`
M``H```#)R```!P```-3(```'````W,@```4```#DR```!0```.K(```*````
M\,@```,```#[R```#0```/_(```7````#<D```H````ER0``"@```##)```(
M````.\D```\```!$R0``"P```%3)```'````8,D```T```!HR0``"@```';)
M```.````@<D``!@```"0R0``(P```*G)```.````S<D``!0```#<R0``%P``
M`/')```7````"<H``!<````AR@``$P```#G*```/````3<H```X```!=R@``
M'P```&S*```=````C,H```<```"JR@``!@```++*```(````N<H```\```#"
MR@``!@```-+*```*````V<H``!,```#DR@```P```/C*```+````_,H``!``
M```(RP``%0```!G+```5````+\L```<```!%RP``$````$W+```%````7LL`
M`!4```!DRP``$0```'K+```,````C,L``#L```"9RP``.````-7+```)````
M#LP```<````8S```%````"#,```#````-<P```4````YS```$````#_,```)
M````4,P``!,```!:S```.0```&[,```2````J,P```(```"[S```M````+[,
M```G````<\T``"P```";S0``*@```,C-```E````\\T```H````9S@``"0``
M`"3.```*````+LX```8````YS@``"0```$#.```'````2LX``"\```!2S@``
M-P```(+.```N````NLX``%4```#IS@``+0```#_/```M````;<\``#T```";
MSP``/P```-G/```M````&=```$````!'T```(P```(C0```C````K-```$``
M``#0T```+0```!'1```S````/]$``"4```!ST0``%0```)G1```9````K]$`
M`"D```#)T0``)````//1```H````&-(``!$```!!T@``"@```%/2```,````
M7M(```H```!KT@``$````';2```6````A](``!8```">T@``!P```+72```'
M````O=(``!0```#%T@``"@```-K2```(````Y=(``"<```#NT@``"````!;3
M```,````'],```<````LTP``!P```#33```&````/-,```4```!#TP``!P``
M`$G3```&````4=,```@```!8TP``*0```&'3```.````B],```H```":TP``
M!````*73```'````JM,```D```"RTP``!@```+S3```1````P],```<```#5
MTP``%@```-W3```$````]-,```@```#YTP``!@````+4```-````"=0```8`
M```7U```'@```![4```1````/=0```@```!/U```#0```%C4```,````9M0`
M``<```!SU```!````'O4```#````@-0```,```"$U```%P```(C4```)````
MH-0``!,```"JU```'0```+[4```)````W-0```@```#FU```$````._4```=
M`````-4```D````>U0``&P```"C5```$````1-4```@```!)U0``"````%+5
M``!!````6]4``!H```"=U0``*P```+C5```@````Y-4``!D````%U@``%0``
M`!_6```&````-=8```8````\U@``%0```$/6```)````6=8```T```!CU@``
M&````''6```B````BM8``"X```"MU@``'0```-S6```A````^M8``%0````<
MUP``*0```''7```*````F]<```<```"FUP``!P```*[7```)````MM<``!4`
M``#`UP``"````-;7```.````W]<```H```#NUP``#P```/G7```-````"=@`
M``\````7V```#0```"?8```)````-=@``!0````_V```!@```%38```8````
M6]@``!T```!TV```$P```)+8```1````IM@``!0```"XV```!````,W8```&
M````TM@``!0```#9V```5````.[8``!D````0]D```0```"HV0``#@```*W9
M```%````O-D```4```#"V0``&P```,C9```:````Y-D``!,```#_V0``$0``
M`!/:```1````)=H``!P````WV@``3@```%3:``!%````H]H``$4```#IV@``
M*@```"_;```V````6ML``#X```"1VP``/P```-#;```=````$-P``!`````N
MW```(0```#_<```%````8=P``!,```!GW```"P```'O<```3````A]P``!(`
M``";W```"@```*[<```/````N=P```T```#)W```$0```-?<```3````Z=P`
M``P```#]W```#`````K=```&````%]T```P````>W0``!@```"O=```7````
M,MT``!````!*W0``$0```%O=```(````;=T```4```!VW0``#````'S=```0
M````B=T```4```":W0``#0```*#=```&````KMT``!8```"UW0``!P```,S=
M```-````U-T```<```#BW0``"P```.K=```'````]MT```<```#^W0``"0``
M``;>```)````$-X```H````:W@``&0```"7>```]````/]X``!T```!]W@``
M#````)O>```0````J-X``!L```"YW@``"0```-7>```%````W]X``"4```#E
MW@``$@````O?```3````'M\``"L````RWP``.P```%[?```@````FM\```@`
M``"[WP``-@```,3?```A````^]\``!`````=X```"````"[@```,````-^``
M``8```!$X```!````$O@```/````4.````X```!@X```0````&_@```'````
ML.````H```"XX```#0```,/@```?````T>```!P```#QX```(0````[A```>
M````,.$``!D```!/X0``'@```&GA```;````B.$``"$```"DX0``+@```,;A
M```F````]>$``!P````<X@``'@```#GB```<````6.(``"8```!UX@``*P``
M`)SB```S````R.(``"8```#\X@``*P```"/C```X````3^,``!T```"(XP``
M%0```*;C```O````O.,``"````#LXP``$@````WD```I````(.0``!X```!*
MY```(````&GD```2````BN0``*(```"=Y```%@```$#E```C````5^4``"@`
M``![Y0``*0```*3E```H````SN4``!\```#WY0``%0```!?F```@````+>8`
M`"4```!.Y@``*````'3F```M````G>8``#````#+Y@``D@```/SF```A````
MC^<``!8```"QYP``'````,CG```F````Y><``"H````,Z```00```#?H``!$
M````>>@```P```"^Z```!P```,OH```'````T^@```8```#;Z```#P```.+H
M```2````\N@```T````%Z0``$````!/I```2````).D```<````WZ0``$P``
M`#_I```2````4^D```<```!FZ0``!````&[I```'````<^D``!````![Z0``
M$````(SI```,````G>D```X```"JZ0``#0```+GI```/````Q^D``!,```#7
MZ0``#0```.OI```H````^>D```,````BZ@``#0```";J```&````-.H``!$`
M```[Z@``%P```$WJ```;````9>H```X```"!Z@```@```)#J``!)````D^H`
M``4```#=Z@``$P```./J```0````]^H```\````(ZP``!````!CK```-````
M'>L```X````KZP```P```#KK```&````/NL```<```!%ZP``#@```$WK```(
M````7.L```\```!EZP``"````'7K```/````?NL```<```".ZP``$````);K
M```-````I^L``!````"UZP``#0```,;K```+````U.L```8```#@ZP``"0``
M`.?K```+````\>L```P```#]ZP``#`````KL```*````%^P``!$````B[```
M&0```#3L```+````3NP```T```!:[```(@```&CL```/````B^P``!L```";
M[```-````+?L```*````[.P``!@```#W[```$@```!#M```9````(^T``%P`
M```][0``%@```)KM```B````L>T```T```#4[0``!P```.+M```,````ZNT`
M`!0```#W[0``"P````SN```B````&.X``"\````[[@``"P```&ON```)````
M=^X``!D```"![@``"P```)ON```7````I^X``!<```"_[@``"0```-?N```'
M````X>X``!8```#I[@``$0````#O```/````$N\``!D````B[P``%@```#SO
M```.````4^\``!@```!B[P``"````'OO```-````A.\``"8```"2[P``.0``
M`+GO```.````\^\``$,````"\```"````$;P```2````3_```!\```!B\```
M"````(+P```+````B_```"\```"7\```#@```,?P```%````UO````<```#<
M\```"````.3P```&````[?```$4```#T\````P```#KQ```'````/O$```0`
M``!&\0``!P```$OQ```.````4_$```H```!B\0``#@```&WQ```*````?/$`
M``\```"'\0``$````)?Q```7````J/$``!4```#`\0``#@```-;Q```:````
MY?$``!$`````\@``&0```!+R```7````+/(```D```!$\@``!0```$[R```+
M````5/(```H```!@\@```@```&OR```%````;O(```T```!T\@``&P```(+R
M```7````GO(``!0```"V\@``"0```,OR```.````U?(```T```#D\@``$@``
M`/+R```$````!?,``#@````*\P``(````$/S```(````9/,```8```!M\P``
M"````'3S```(````??,```X```"&\P``>P```)7S```8````$?0``!@````J
M]```$0```$/T```'````5?0```4```!=]```&````&/T```>````?/0``!L`
M``";]```&0```+?T```Q````T?0``!L````#]0``&0```!_U```3````.?4`
M``<```!-]0``"````%7U```&````7O4```8```!E]0``#````&SU```.````
M>?4```T```"(]0``$P```);U```/````JO4``!X```"Z]0``&0```-GU```0
M````\_4```\````$]@``$````!3V```/````)?8```L````U]@``#P```$'V
M```,````4?8```\```!>]@``!P```&[V```&````=O8```P```!]]@``#@``
M`(KV```,````F?8``"@```"F]@``#P```,_V```(````W_8```8```#H]@``
M#P```._V```(````__8``!,````(]P``'@```!SW```A````._<``"````!=
M]P``&0```'[W```7````F/<``"4```"P]P``%P```-;W```6````[O<```0`
M```%^```&P````KX```-````)O@```P````T^````P```$'X```%````1?@`
M``@```!+^```"@```%3X```,````7_@```L```!L^```$````'CX```,````
MB?@```X```"6^```!````*7X```$````JO@``!,```"O^```%````,/X```,
M````V/@```D```#E^```#@```._X```+````_O@``!L````*^0``!P```";Y
M```$````+OD```<````S^0``"@```#OY```-````1OD```D```!4^0``!```
M`%[Y```#````8_D``!@```!G^0``"@```(#Y```$````B_D``"8```"0^0``
M#@```+?Y``!\````QOD``!4```!#^@``!0```%GZ```'````7_H```P```!G
M^@``"````'3Z```*````??H```8```"(^@``"````(_Z```"````F/H```8`
M``";^@``!@```*+Z```4````J?H```0```"^^@``%0```,/Z```-````V?H`
M`!````#G^@``&P```/CZ```&````%/L```0````;^P``"0```"#[```0````
M*OL```D````[^P``"0```$7[```&````3_L```4```!6^P``&@```%S[```(
M````=_L```8```"`^P``!````(?[```'````C/L``!D```"4^P``#@```*[[
M```'````O?L```<```#%^P``!0```,W[```)````T_L```H```#=^P``#@``
M`.C[```"````]_L```8```#Z^P``"P````'\```-````#?P```<````;_```
M"0```"/\```&````+?P``!(````T_```"0```$?\```'````4?P``!0```!9
M_```'0```&[\``!"````C/P``"4```#/_```)0```/7\```&````&_T```H`
M```B_0``!````"W]```)````,OT```@````\_0``$0```$7]```)````5_T`
M``8```!A_0``#0```&C]```&````=OT``#D```!]_0``/0```+?]```Z````
M]?T``!X````P_@``!0```$_^```.````5?X```0```!D_@``!@```&G^```'
M````</X``"$```!X_@``#0```)K^```5````J/X```8```"^_@``!````,7^
M```1````ROX```8```#<_@``"@```./^```B````[OX```0````1_P``!P``
M`!;_```$````'O\```4````C_P``'0```"G_```$````1_\```P```!,_P``
M#@```%G_```*````:/\```@```!S_P``"0```'S_```%````AO\``#H```",
M_P``,````,?_```U````^/\``"D````N``$`1P```%@``0`X````H``!`"D`
M``#9``$`/P````,!`0`N````0P$!`"T```!R`0$`'P```*`!`0`/````P`$!
M`!(```#0`0$`"P```.,!`0`'````[P$!`"8```#W`0$`/````!X"`0`I````
M6P(!`#H```"%`@$`)````,`"`0`F````Y0(!``@````,`P$`"@```!4#`0`)
M````(`,!``<````J`P$`(````#(#`0`@````4P,!`"8```!T`P$`"@```)L#
M`0`9````I@,!`"D```#``P$`%@```.H#`0`2`````00!``<````4!`$`"@``
M`!P$`0`,````)P0!``\````T!`$`$````$0$`0!`````500!`'````"6!`$`
M9@````<%`0#1````;@4!``X```!`!@$`"0```$\&`0`*````608!`!(```!D
M!@$`$P```'<&`0`,````BP8!``8```"8!@$`&````)\&`0`/````N`8!`!8`
M``#(!@$`$@```-\&`0`0````\@8!`!$````#!P$`'````!4'`0`C````,@<!
M`&H```!6!P$`#P```,$'`0`%````T0<!`!````#7!P$`"0```.@'`0`$````
M\@<!``L```#W!P$`(`````,(`0`4````)`@!``P````Y"`$`#````$8(`0`/
M````4P@!`!4```!C"`$`*0```'D(`0`J````HP@!`"8```#."`$`)P```/4(
M`0`I````'0D!`"H```!'"0$`&0```'()`0!"````C`D!`!$```#/"0$`$@``
M`.$)`0`3````]`D!`!0````("@$`#P```!T*`0`6````+0H!`!<```!$"@$`
M$````%P*`0`1````;0H!`#0```!_"@$`$P```+0*`0`2````R`H!`#4```#;
M"@$`%````!$+`0`'````)@L!``P````N"P$`(````#L+`0`0````7`L!`!0`
M``!M"P$`$0```((+`0`7````E`L!`!P```"L"P$`$P```,D+`0`4````W0L!
M`!H```#R"P$`$0````T,`0`:````'PP!`!X````Z#`$`&@```%D,`0`3````
M=`P!`!4```"(#`$`$0```)X,`0`7````L`P!`!0```#(#`$`%P```-T,`0`5
M````]0P!``D````+#0$`$````!4-`0`9````)@T!``0```!`#0$`!P```$4-
M`0`+````30T!`!$```!9#0$`!@```&L-`0`&````<@T!``8```!Y#0$`!0``
M`(`-`0`'````A@T!``<```".#0$`!0```)8-`0`6````G`T!``8```"S#0$`
M!@```+H-`0`$````P0T!``0```#&#0$`!P```,L-`0`.````TPT!``P```#B
M#0$`#````.\-`0`-````_`T!``H````*#@$`#@```!4.`0`%````)`X!`"@`
M```J#@$`#@```%,.`0`,````8@X!``\```!O#@$`"@```'\.`0`(````B@X!
M``D```"3#@$`*P```)T.`0`(````R0X!``0```#2#@$`"````-<.`0`F````
MX`X!`!(````'#P$`#P```!H/`0`&````*@\!``H````Q#P$`!P```#P/`0`(
M````1`\!`"````!-#P$`#0```&X/`0`)````?`\!``T```"&#P$`"@```)0/
M`0`4````GP\!``P```"T#P$`#0```,$/`0`)````SP\!``X```#9#P$`%@``
M`.@/`0`1````_P\!``D````1$`$`!@```!L0`0`#````(A`!``8````F$`$`
M&0```"T0`0`'````1Q`!``0```!/$`$`"P```%00`0`+````8!`!``<```!L
M$`$`!0```'00`0`'````>A`!`!8```""$`$`#0```)D0`0`-````IQ`!``H`
M``"U$`$`$````,`0`0`/````T1`!`!$```#A$`$`%P```/,0`0`*````"Q$!
M`!$````6$0$`'@```"@1`0`$````1Q$!``\```!,$0$`.@```%P1`0`%````
MEQ$!``P```"=$0$`'@```*H1`0`.````R1$!`!````#8$0$`"P```.D1`0`,
M````]1$!``D````"$@$`!P````P2`0`*````%!(!``D````?$@$`#@```"D2
M`0`0````.!(!`!L```!)$@$`&````&42`0`:````?A(!``H```"9$@$`"0``
M`*02`0`)````KA(!``H```"X$@$`#````,,2`0`/````T!(!``@```#@$@$`
M!@```.D2`0`<````\!(!``<````-$P$`!0```!43`0`+````&Q,!`$<````G
M$P$`#0```&\3`0`)````?1,!``0```"'$P$``P```(P3`0`3````D!,!`!,`
M``"D$P$`$P```+@3`0`*````S!,!``(```#7$P$`!````-H3`0`E````WQ,!
M``,````%%`$`!0````D4`0`J````#Q0!``H````Z%`$`!0```$44`0`$````
M2Q0!``H```!0%`$`#0```%L4`0`&````:10!``@```!P%`$`"````'D4`0`$
M````@A0!``4```"'%`$`&````(T4`0!H````IA0!``D````/%0$`#````!D5
M`0`0````)A4!``4````W%0$`!@```#T5`0`;````1!4!`"\```!@%0$`$```
M`)`5`0`*````H14!``\```"L%0$`"@```+P5`0`)````QQ4!`!,```#1%0$`
M&P```.45`0`8`````18!`!<````:%@$`&````#(6`0`?````2Q8!``X```!K
M%@$``P```'H6`0`'````?A8!``(```"&%@$`"````(D6`0`'````DA8!``<`
M``":%@$`"P```*(6`0`)````KA8!``H```"X%@$`"P```,,6`0`'````SQ8!
M`%$```#7%@$`$````"D7`0`,````.A<!``T```!'%P$`&@```%47`0!*````
M<!<!`!D```"[%P$`!@```-47`0`:````W!<!`"4```#W%P$`!@```!T8`0`&
M````)!@!`!\````K&`$`!@```$L8`0`)````4A@!`!@```!<&`$`%P```'48
M`0`H````C1@!``D```"V&`$`!@```,`8`0`-````QQ@!`"(```#5&`$`5P``
M`/@8`0`3````4!D!`",```!D&0$`$P```(@9`0`"````G!D!``L```"?&0$`
M"````*L9`0`-````M!D!``H```#"&0$`!P```,T9`0`4````U1D!``8```#J
M&0$`!@```/$9`0`(````^!D!``4````!&@$`"@````<:`0`.````$AH!``<`
M```A&@$`$P```"D:`0`5````/1H!``P```!3&@$`#0```&`:`0`*````;AH!
M``L```!Y&@$`,@```(4:`0`'````N!H!``P```#`&@$`#0```,T:`0`,````
MVQH!``D```#H&@$`"0```/(:`0`*````_!H!``<````'&P$`"0````\;`0`'
M````&1L!``H````A&P$`&P```"P;`0`/````2!L!`$(```!8&P$`$@```)L;
M`0`*````KAL!`!8```"Y&P$`#````-`;`0`-````W1L!`!````#K&P$`"0``
M`/P;`0`0````!AP!``<````7'`$`$@```!\<`0`$````,AP!``<````W'`$`
M!0```#\<`0`%````11P!``L```!+'`$`%````%<<`0`1````;!P!`!H```!^
M'`$`%@```)D<`0`4````L!P!`!<```#%'`$`&````-T<`0`<````]AP!`!D`
M```3'0$`!P```"T=`0`%````-1T!``T````['0$`#````$D=`0`)````5AT!
M`!$```!@'0$`"````'(=`0`7````>QT!``L```"3'0$`2@```)\=`0`,````
MZAT!`!\```#W'0$`&@```!<>`0`3````,AX!``0```!&'@$`"@```$L>`0`$
M````5AX!``T```!;'@$`#0```&D>`0`(````=QX!``H```"`'@$`"0```(L>
M`0`)````E1X!``@```"?'@$`#````*@>`0`)````M1X!``4```"_'@$`"0``
M`,4>`0`%````SQX!``<```#5'@$`!0```-T>`0`$````XQX!``(```#H'@$`
M"````.L>`0`,````]!X!`#@````!'P$`+````#H?`0`2````9Q\!`"D```!Z
M'P$`,@```*0?`0`E````UQ\!``H```#]'P$`+`````@@`0`N````-2`!`#,`
M``!D(`$`,P```)@@`0`X````S"`!``\````%(0$`&````!4A`0`+````+B$!
M`!0````Z(0$`$````$\A`0`L````8"$!`!P```"-(0$`#P```*HA`0`3````
MNB$!`!4```#.(0$`%````.0A`0`2````^2$!`!0````,(@$`%0```"$B`0`M
M````-R(!`"T```!E(@$`,0```),B`0`N````Q2(!`"\```#T(@$`+````"0C
M`0!B````42,!`!,```"T(P$`#0```,@C`0`-````UB,!``@```#D(P$`%P``
M`.TC`0`(````!20!``P````.)`$`*P```!LD`0`A````1R0!`!H```!I)`$`
M'````(0D`0`)````H20!`$4```"K)`$`00```/$D`0`$````,R4!`!,````X
M)0$`%````$PE`0`.````824!`!,```!P)0$`&````(0E`0`&````G24!``D`
M``"D)0$`"@```*XE`0`/````N24!``D```#))0$`$````-,E`0`'````Y"4!
M``X```#L)0$`!0```/LE`0`;`````28!``T````=)@$`"````"LF`0`#````
M-"8!``8````X)@$`%````#\F`0`1````5"8!``X```!F)@$`.````'4F`0`"
M````KB8!``8```"Q)@$`#@```+@F`0`%````QR8!``<```#-)@$`#@```-4F
M`0`&````Y"8!`"@```#K)@$`#````!0G`0`<````(2<!``0````^)P$`)@``
M`$,G`0`6````:B<!`!0```"!)P$`*0```)8G`0`7````P"<!`!\```#8)P$`
M7````/@G`0`4````52@!`#X```!J*`$`'P```*DH`0`0````R2@!``@```#:
M*`$`$@```.,H`0`'````]B@!``X```#^*`$`#`````TI`0`,````&BD!`!,`
M```G*0$`"@```#LI`0`=````1BD!`!D```!D*0$`!0```'XI`0`1````A"D!
M``@```"6*0$`!0```)\I`0`1````I2D!``D```"W*0$`)````,$I`0`2````
MYBD!`!4```#Y*0$`$@````\J`0`.````(BH!`!D````Q*@$`"````$LJ`0`-
M````5"H!``<```!B*@$`"@```&HJ`0`'````=2H!``\```!]*@$`!@```(TJ
M`0`+````E"H!`!H```"@*@$`!P```+LJ`0`(````PRH!``4```#,*@$`'P``
M`-(J`0`&````\BH!`!````#Y*@$`"`````HK`0`-````$RL!``@````A*P$`
M'@```"HK`0`2````22L!`"P```!<*P$`&@```(DK`0`)````I"L!``H```"N
M*P$`%0```+DK`0`0````SRL!``4```#@*P$`%````.8K`0`$````^RL!``<`
M````+`$`$`````@L`0`&````&2P!``<````@+`$`'@```"@L`0`H````1RP!
M`!X```!P+`$`"@```(\L`0`<````FBP!`!$```"W+`$`"P```,DL`0`:````
MU2P!`!0```#P+`$`!`````4M`0`$````"BT!``L````/+0$`!0```!LM`0`&
M````(2T!``@````H+0$`!@```#$M`0`*````."T!`!L```!#+0$`-````%\M
M`0`T````E"T!`"````#)+0$`*0```.HM`0`@````%"X!`$$````U+@$`&@``
M`'<N`0`H````DBX!`"D```"[+@$`4````.4N`0`B````-B\!``8```!9+P$`
M"````&`O`0`%````:2\!``X```!O+P$`"````'XO`0`9````AR\!`!D```"A
M+P$`*@```+LO`0`C````YB\!`!D````*,`$`+@```"0P`0`T````4S`!``@`
M``"(,`$`%P```)$P`0`*````J3`!``<```"T,`$`(0```+PP`0`,````WC`!
M``T```#K,`$`#````/DP`0`0````!C$!``X````7,0$`"P```"8Q`0`'````
M,C$!`!,````Z,0$`"````$XQ`0`+````5S$!``H```!C,0$`%````&XQ`0`/
M````@S$!`#(```"3,0$`"P```,8Q`0`.````TC$!``4```#A,0$`!0```.<Q
M`0`%````[3$!`!<```#S,0$`#P````LR`0`$````&S(!``H````@,@$`"0``
M`"LR`0`+````-3(!``T```!!,@$`#````$\R`0`.````7#(!``4```!K,@$`
M!````'$R`0`-````=C(!`#(```"$,@$`10```+<R`0`+````_3(!``H````)
M,P$`#P```!0S`0`3````)#,!`!,````X,P$`#P```$PS`0`,````7#,!``X`
M``!I,P$`#0```'@S`0`-````AC,!`!<```"4,P$`!P```*PS`0`>````M#,!
M`!0```#3,P$`%````.@S`0`&````_3,!``<````$-`$`#`````PT`0`0````
M&30!`!$````J-`$`#@```#PT`0`7````2S0!`"H```!C-`$`!@```(XT`0`)
M````E30!``\```"?-`$`#````*\T`0`-````O#0!`!$```#*-`$`"P```-PT
M`0`V````Z#0!``H````?-0$`(@```"HU`0`+````334!``\```!9-0$`?0``
M`&DU`0`R````YS4!`"4````:-@$`"````$`V`0`P````238!`#$```!Z-@$`
M+0```*PV`0`2````VC8!``X```#M-@$`!0```/PV`0`.`````C<!`!,````1
M-P$`$0```"4W`0`(````-S<!`!(```!`-P$`!P```%,W`0`1````6S<!`!,`
M``!M-P$`!P```($W`0`4````B3<!`!@```">-P$`!P```+<W`0`%````OS<!
M``P```#%-P$`#````-(W`0`2````WS<!``0```#R-P$`!P```/<W`0`*````
M_S<!``L````*.`$`#````!8X`0`.````(S@!``X````R.`$`!0```$$X`0`%
M````1S@!`"X```!-.`$`)@```'PX`0`C````HS@!``,```#'.`$`$@```,LX
M`0`&````WC@!`!X```#E.`$`&`````0Y`0`E````'3D!``T```!#.0$`'P``
M`%$Y`0`#````<3D!``<```!U.0$``@```'TY`0`,````@#D!`!4```"-.0$`
M"P```*,Y`0`9````KSD!`"````#).0$`$@```.HY`0`%````_3D!``H````#
M.@$`%0````XZ`0`2````)#H!``@````W.@$`#````$`Z`0`$````33H!``D`
M``!2.@$`!P```%PZ`0`+````9#H!``X```!P.@$`"@```'\Z`0`,````BCH!
M`%(```"7.@$`%P```.HZ`0`D`````CL!`!(````G.P$`!P```#H[`0`&````
M0CL!`!````!).P$`#@```%H[`0`.````:3L!`"````!X.P$`#````)D[`0`9
M````ICL!``T```#`.P$`%0```,X[`0`2````Y#L!``\```#W.P$`%`````<\
M`0`*````'#P!`!L````G/`$`$````$,\`0`<````5#P!`%@```!Q/`$`"P``
M`,H\`0`A````UCP!`"4```#X/`$`:0```!X]`0`:````B#T!`!<```"C/0$`
M&0```+L]`0`:````U3T!`!D```#P/0$`)0````H^`0`G````,#X!`!H```!8
M/@$`%P```',^`0`=````BSX!`"8```"I/@$`&P```-`^`0`J````[#X!`!D`
M```7/P$`'P```#$_`0`3````43\!``@```!E/P$`1````&X_`0`3````LS\!
M`$````#'/P$`!P````A``0`(````$$`!``D````90`$`%0```"-``0`-````
M.4`!`",```!'0`$`#0```&M``0`3````>4`!``@```"-0`$``P```)9``0`,
M````FD`!`$8```"G0`$`%P```.Y``0`.````!D$!`#\````500$`30```%5!
M`0`W````HT$!`%<```#;00$`!0```#-"`0`?````.4(!`"\```!90@$`"@``
M`(E"`0`3````E$(!`!````"H0@$`$0```+E"`0`(````RT(!``T```#40@$`
M+0```.)"`0`$````$$,!``T````50P$`%0```"-#`0`[````.4,!`$\```!U
M0P$`'P```,5#`0`6````Y4,!`"4```#\0P$`*````")$`0`<````2T0!``L`
M``!H1`$`(P```'1$`0`?````F$0!`"$```"X1`$`'0```-I$`0`E````^$0!
M`"`````>10$`)````#]%`0`@````9$4!`#````"%10$`"P```+9%`0`'````
MPD4!``T```#*10$`#````-A%`0`7````Y44!``8```#]10$`.0````1&`0`,
M````/D8!``<```!+1@$`"0```%-&`0`3````748!``D```!Q1@$`!````'M&
M`0`0````@$8!``@```"11@$`"````)I&`0`$````HT8!``L```"H1@$`#```
M`+1&`0`2````P48!`!$```#41@$`#````.9&`0`:````\T8!``\````.1P$`
M!P```!Y'`0`-````)D<!`!0````T1P$`#@```$E'`0`,````6$<!`!L```!E
M1P$`+````(%'`0`3````KD<!`!P```#"1P$`*````-]'`0`&````"$@!``<`
M```/2`$`$P```!=(`0`%````*T@!``0````Q2`$`%P```#9(`0`*````3D@!
M``P```!92`$`"0```&9(`0`&````<$@!``D```!W2`$`!@```(%(`0`(````
MB$@!``D```"12`$`"@```)M(`0`(````ID@!``H```"O2`$`"@```+I(`0`'
M````Q4@!`!$```#-2`$`!@```-](`0`.````YD@!``X```#U2`$`#0````1)
M`0`+````$DD!`!T````>20$`"P```#Q)`0`"````2$D!`!P```!+20$`!P``
M`&A)`0`&````<$D!`&0```!W20$`"0```-Q)`0`'````YDD!`"8```#N20$`
M.````!5*`0`:````3DH!`"H```!I2@$`.P```)1*`0`H````T$H!`#0```#Y
M2@$`&0```"Y+`0`5````2$L!``4```!>2P$`!P```&1+`0`(````;$L!``<`
M``!U2P$`!@```'U+`0`%````A$L!``<```"*2P$`#@```))+`0`)````H4L!
M``8```"K2P$`"````+)+`0`+````NTL!``<```#'2P$`"````,]+`0`'````
MV$L!`!8```#@2P$`"0```/=+`0`&`````4P!``L````(3`$`$````!1,`0`<
M````)4P!`!0```!"3`$`!P```%=,`0`1````7TP!``@```!Q3`$`#@```'I,
M`0`(````B4P!``4```"23`$`$````)A,`0`0````J4P!``8```"Z3`$`&0``
M`,%,`0`*````VTP!`!P```#F3`$`!P````--`0`%````"TT!`!`````130$`
M%````")-`0`+````-TT!``T```!#30$`*````%%-`0`8````>DT!`!<```"3
M30$`"0```*M-`0`$````M4T!``D```"Z30$`"@```,1-`0`'````STT!``(`
M``#730$`#@```-I-`0`(````Z4T!`#@```#R30$`(P```"M.`0`?````3TX!
M`#@```!O3@$`)@```*A.`0`Q````STX!`"<````!3P$`9````"E/`0`4````
MCD\!`"0```"C3P$`(P```,A/`0`C````[$\!`"L````04`$`(0```#Q0`0`D
M````7E`!`%4```"#4`$`.````-E0`0!*````$E$!`%L```!=40$`*````+E1
M`0`X````XE$!`"\````;4@$`10```$M2`0!*````D5(!`$8```#<4@$`,P``
M`"-3`0`H````5U,!`"P```"`4P$`)@```*U3`0`;````U%,!`#X```#P4P$`
M.@```"]4`0"I`0``:E0!`",````45@$`%P```#A6`0!(````4%8!`(4```"9
M5@$`,````!]7`0`E````4%<!`$$```!V5P$`6P```+A7`0!)````%%@!`#$`
M``!>6`$`:0```)!8`0`=````^E@!`!@````860$`*P```#%9`0`A````75D!
M`!\```!_60$`*P```)]9`0`F````RUD!`"<```#R60$`.@```!I:`0`=````
M55H!`!$```!S6@$`,P```(5:`0`E````N5H!`"<```#?6@$`(`````=;`0`R
M````*%L!`!\```!;6P$`,````'M;`0!I````K%L!`#$````67`$`00```$A<
M`0`S````BEP!`"4```"^7`$`/0```.1<`0!E````(ET!`$T```"(70$`+0``
M`-9=`0`G````!%X!`"\````L7@$`*````%Q>`0`N````A5X!`#````"T7@$`
M5````.5>`0`G````.E\!`%H```!B7P$`.@```+U?`0!(````^%\!`$H```!!
M8`$`'P```(Q@`0`R````K&`!`"\```#?8`$`+`````]A`0`M````/&$!`'$`
M``!J80$`9@```-QA`0!O````0V(!`+,```"S8@$`%P```&=C`0`E````?V,!
M`#(```"E8P$`*0```-AC`0`^`````F0!`"(```!!9`$`4@```&1D`0`B````
MMV0!`"4```#:9`$`"P````!E`0"Q````#&4!`"````"^90$`10```-]E`0`A
M````)68!`#````!'9@$`)0```'AF`0`<````GF8!`#$```"[9@$`!P```.UF
M`0`(````]68!``<```#^9@$`!`````9G`0`*````"V<!``T````69P$`"P``
M`"1G`0`.````,&<!``D````_9P$`"P```$EG`0`&````56<!``4```!<9P$`
M$````&)G`0`"````<V<!`%D```!V9P$`!0```-!G`0`2````UF<!``0```#I
M9P$`!P```.YG`0`(````]F<!``4```#_9P$``P````5H`0`0````"6@!``P`
M```::`$`$P```"=H`0`-````.V@!``(```!):`$`!P```$QH`0`'````5&@!
M``8```!<:`$`%````&-H`0`,````>&@!`!@```"%:`$`!@```)YH`0`$````
MI6@!`!(```"J:`$`#````+UH`0`#````RF@!`"H```#.:`$`!````/EH`0`&
M````_F@!``<````%:0$`'P````UI`0`U````+6D!`"X```!C:0$`+P```))I
M`0`7````PFD!`"(```#::0$`)0```/UI`0`@````(VH!`!L```!$:@$`&```
M`&!J`0`D````>6H!`!\```">:@$`&@```+YJ`0`A````V6H!`"````#[:@$`
M&@```!QK`0`R````-VL!`!D```!J:P$`&@```(1K`0`O````GVL!`"L```#/
M:P$`'P```/MK`0`C````&VP!`!\````_;`$`&@```%]L`0`A````>FP!`"4`
M``"<;`$`)@```,)L`0`E````Z6P!`"0````/;0$`&````#1M`0`=````36T!
M`"0```!K;0$`&````)!M`0`B````J6T!`"P```#,;0$`+P```/EM`0`5````
M*6X!`"4````_;@$`&0```&5N`0`\````?VX!`!\```"\;@$`(P```-QN`0`?
M`````&\!`"`````@;P$`&@```$%O`0`O````7&\!`!@```",;P$`)@```*5O
M`0`>````S&\!`"D```#K;P$`'@```!5P`0`Q````-'`!``D```!F<`$`#```
M`'!P`0`7````?7`!`"\```"5<`$`)````,5P`0`'````ZG`!``\```#R<`$`
M%`````)Q`0`.````%W$!``T````F<0$`)````#1Q`0`%````67$!``<```!?
M<0$`(@```&=Q`0`E````BG$!`!H```"P<0$`'0```,MQ`0`:````Z7$!``<`
M```$<@$`QP````QR`0`+````U'(!`!P```#@<@$`%0```/UR`0`&````$W,!
M``D````:<P$`"P```"1S`0`-````,',!``P````^<P$`%P```$MS`0`&````
M8W,!`#,```!J<P$`$P```)YS`0`3````LG,!``<```#&<P$`#P```,YS`0`'
M````WG,!`#(```#F<P$`!````!ET`0`A````'G0!`!,```!`=`$`#@```%1T
M`0`,````8W0!`!$```!P=`$`,@```()T`0`6````M70!``@```#,=`$`'0``
M`-5T`0`)````\W0!``H```#]=`$`%`````AU`0`*````'74!`!T````H=0$`
M"````$9U`0`?````3W4!``@```!O=0$`&@```'AU`0`G````DW4!``8```"[
M=0$`%0```,)U`0`'````V'4!``@```#@=0$`"0```.EU`0`_````\W4!``<`
M```S=@$`#P```#MV`0`.````2W8!`!````!:=@$`"0```&MV`0`)````=78!
M``@```!_=@$`$P```(AV`0`'````G'8!``@```"D=@$`&0```*UV`0`*````
MQW8!`!<```#2=@$`%````.IV`0`*````_W8!``P````*=P$`%P```!=W`0`$
M````+W<!`"H````T=P$`#````%]W`0`1````;'<!``<```!^=P$``@```(9W
M`0`0````B7<!`!@```":=P$``P```+-W`0`(````MW<!``D```#`=P$`!```
M`,IW`0`'````SW<!``<```#7=P$`!@```-]W`0`4````YG<!``<```#[=P$`
M#0````-X`0`+````$7@!`!0````=>`$`%0```#)X`0`.````2'@!`"\```!7
M>`$`(````(=X`0`<````J'@!`$@```#%>`$`3`````YY`0`5````6WD!``P`
M``!Q>0$`,0```'YY`0`%````L'D!`!(```"V>0$`/P```,EY`0`2````"7H!
M``H````<>@$`!@```"=Z`0`$````+GH!``0````S>@$`"@```#AZ`0`3````
M0WH!``4```!7>@$`!@```%UZ`0`&````9'H!``@```!K>@$`!````'1Z`0`,
M````>7H!``H```"&>@$`"0```)%Z`0`Y````FWH!`"X```#5>@$`*0````1[
M`0`%````+GL!`!@````T>P$`&0```$U[`0`?````9WL!`!T```"'>P$`$0``
M`*5[`0`"````MWL!``0```"Z>P$`"@```+][`0`$````RGL!``8```#/>P$`
M%````-9[`0`%````ZWL!``,```#Q>P$`#````/5[`0!%`````GP!`#(```!(
M?`$`,@```'M\`0`O````KGP!`!H```#>?`$`.@```/E\`0`T````-'T!`"@`
M``!I?0$`4P```))]`0"3````YGT!`"\```!Z?@$`0@```*I^`0`P````[7X!
M`"X````>?P$`&0```$U_`0`G````9W\!`#@```"/?P$`.````,A_`0`W````
M`8`!`'(````Y@`$`(````*R``0`U````S8`!`"$````#@0$`10```"6!`0`P
M````:X$!`"D```"<@0$`(0```,:!`0`H````Z($!`"D````1@@$`)@```#N"
M`0`E````8H(!`"@```"(@@$`*````+&"`0`B````VH(!`"L```#]@@$`10``
M`"F#`0!)````;X,!`$8```"Y@P$`/`````"$`0`P````/80!`!(```!NA`$`
M$P```(&$`0`0````E80!`'D```"FA`$`"0```""%`0"A````*H4!`',```#,
MA0$`?````$"&`0`K````O88!`%0```#IA@$`%P```#Z'`0`5````5H<!`"<`
M``!LAP$`%@```)2'`0`/````JX<!`!<```"[AP$`'P```-.'`0!`````\X<!
M`!\````TB`$`'````%2(`0!1````<8@!`!H```##B`$`%````-Z(`0`*````
M\X@!``4```#^B`$`!@````2)`0`(````"XD!`!(````4B0$`$````">)`0`3
M````.(D!`!T```!,B0$`#P```&J)`0`/````>HD!``\```"*B0$`!@```)J)
M`0`-````H8D!``0```"OB0$`"P```+2)`0`%````P(D!``4```#&B0$`!P``
M`,R)`0`%````U(D!`!0```#:B0$`#@```.^)`0`'````_HD!``@````&B@$`
M#P````^*`0`-````'XH!``H````MB@$`"````#B*`0`,````08H!``8```!.
MB@$`#P```%6*`0`'````98H!``8```!MB@$`%````'2*`0`&````B8H!``8`
M``"0B@$`#````)>*`0`1````I(H!`!<```"VB@$`"````,Z*`0`$````UXH!
M`!D```#<B@$`$0```/:*`0`*````"(L!`!@````3BP$`$P```"R+`0`<````
M0(L!`!$```!=BP$``P```&^+`0`&````<XL!``0```!ZBP$`!````'^+`0`/
M````A(L!``<```"4BP$`!````)R+`0`9````H8L!``<```"[BP$``@```,.+
M`0`1````QHL!``D```#8BP$`$@```.*+`0`7````]8L!``8````-C`$`)P``
M`!2,`0`(````/(P!``0```!%C`$`#P```$J,`0`3````6HP!``<```!NC`$`
M"P```':,`0`0````@HP!`!,```"3C`$`!P```*>,`0`1````KXP!``8```#!
MC`$`&````,B,`0`&````X8P!`!,```#HC`$`$````/R,`0`2````#8T!``8`
M```@C0$`#````">-`0`)````-(T!`!$````^C0$`(@```%"-`0`'````<XT!
M``L```![C0$`!0```(>-`0`1````C8T!``(```"?C0$`!````**-`0`+````
MIXT!``4```"SC0$`!P```+F-`0!G`0``P8T!`!0````ICP$`$P```#Z/`0`/
M````4H\!``4```!BCP$`"0```&B/`0`)````<H\!``,```!\CP$`%````("/
M`0`<````E8\!`"P```"RCP$`*P```-^/`0`A````"Y`!`"T````MD`$`'```
M`%N0`0`S````>)`!``L```"LD`$`%````+B0`0`L````S9`!``\```#ZD`$`
M%`````J1`0`3````'Y$!`!4````SD0$`"P```$F1`0`H````59$!``P```!^
MD0$`%0```(N1`0`;````H9$!`"$```"]D0$`"@```-^1`0`,````ZI$!`"H`
M``#WD0$`@P```"*2`0`6````II(!``<```"]D@$`$0```,62`0`5````UY(!
M``X```#MD@$`"@```/R2`0`/````!Y,!`!$````7DP$`F@```"F3`0!6````
MQ),!`"T````;E`$`'@```$F4`0`-````:)0!`!4```!VE`$`&0```(R4`0`/
M````II0!``L```"VE`$`#@```,*4`0`%````T90!`!````#7E`$`!P```.B4
M`0`'````\)0!`!````#XE`$`!@````F5`0`'````$)4!``8````8E0$`*```
M`!^5`0`D````2)4!`"D```!ME0$`*````)>5`0`\````P)4!`!X```#]E0$`
M.0```!R6`0!,````5I8!`&L```"CE@$`9P````^7`0!Q````=Y<!`&T```#I
MEP$`/````%>8`0`2````E)@!`!,```"GF`$`#````+N8`0`1````R)@!`!(`
M``#:F`$`!0```.V8`0`K````\Y@!`!(````?F0$`"@```#*9`0`)````/9D!
M``H```!'F0$`"0```%*9`0`S````7)D!`"T```"0F0$`&0```+Z9`0`&````
MV)D!`"$```#?F0$`"0````&:`0`1````"YH!``<````=F@$`%0```"6:`0`B
M````.YH!``\```!>F@$`$0```&Z:`0`6````@)H!`!H```"7F@$`'0```+*:
M`0`J````T)H!`!L```#[F@$`%P```!>;`0`;````+YL!`!4```!+FP$`%```
M`&&;`0`2````=IL!`!$```")FP$`+@```)N;`0`<````RIL!`!4```#GFP$`
M'0```/V;`0`9````&YP!`&4````UG`$`0@```)N<`0`P````WIP!``,````/
MG0$`"@```!.=`0`\````'IT!``X```!;G0$`"@```&J=`0`1````=9T!``L`
M``"'G0$`#@```).=`0`?````HIT!`!\```#"G0$`(````.*=`0`?`````YX!
M`!X````CG@$`'@```$*>`0`?````89X!`!X```"!G@$`%P```*">`0`B````
MN)X!`!8```#;G@$`!P```/*>`0`'````^IX!``4````"GP$`"@````B?`0`)
M````$Y\!``L````=GP$`$P```"F?`0`=````/9\!`!````!;GP$`#@```&R?
M`0`0````>Y\!`!(```",GP$`$0```)^?`0`)````L9\!`!<```"[GP$`%@``
M`-.?`0`@````ZI\!`!L````+H`$`,P```">@`0`+````6Z`!`!\```!GH`$`
M$@```(>@`0`>````FJ`!``\```"YH`$`$P```,F@`0`2````W:`!``\```#P
MH`$`(@````"A`0`8````(Z$!``<````\H0$`!@```$2A`0`(````2Z$!`"@`
M``!4H0$`!@```'VA`0`*````A*$!`!(```"/H0$`"0```**A`0`*````K*$!
M`!0```"WH0$`$P```,RA`0`M````X*$!``H````.H@$`$0```!FB`0`'````
M*Z(!`!,````SH@$`'````$>B`0`:````9*(!`#T```!_H@$`.@```+VB`0`)
M````^*(!``P````"HP$`$@````^C`0`(````(J,!``4````KHP$`!P```#&C
M`0`,````.:,!`!H```!&HP$`20```&&C`0`7````JZ,!``$```##HP$`!P$`
M`,6C`0`I````S:0!`"T```#WI`$`-````"6E`0`Y````6J4!``H```"4I0$`
M"@```)^E`0`-````JJ4!``D```"XI0$`"@```,*E`0`(````S:4!`#0```#6
MI0$`2`````NF`0`S````5*8!`%X```"(I@$`,@```.>F`0`R````&J<!`$4`
M``!-IP$`/@```).G`0`R````TJ<!`$8````%J`$`+@```$RH`0`[````>Z@!
M`$(```"WJ`$`,@```/JH`0`X````+:D!`#H```!FJ0$`)0```*&I`0`H````
MQZD!`#D```#PJ0$`.@```"JJ`0`Y````9:H!`!L```"?J@$`#````+NJ`0`@
M````R*H!``8```#IJ@$`"P```/"J`0`>````_*H!`"8````;JP$`!P```$*K
M`0`'````2JL!`!,```!2JP$`"0```&:K`0`(````<*L!`#4```!YJP$`"P``
M`*^K`0`'````NZL!`!````##JP$`!P```-2K`0`&````W*L!``4```#CJP$`
M!P```.FK`0`&````\:L!``L```#XJP$`+0````2L`0`6````,JP!`!(```!)
MK`$`"````%RL`0`'````9:P!`!````!MK`$`!0```'ZL`0`/````A*P!``<`
M``"4K`$`$P```)RL`0`)````L*P!``@```"ZK`$`!````,.L`0`-````R*P!
M``@```#6K`$`&@```-^L`0`1````^JP!``@````,K0$`"@```!6M`0`,````
M(*T!``<````MK0$`"0```#6M`0`5````/ZT!``,```!5K0$`+````%FM`0`&
M````AJT!`!,```"-K0$`*0```*&M`0`&````RZT!``8```#2K0$`$P```-FM
M`0`=````[:T!``@````+K@$`'````!2N`0`'````,:X!``D````YK@$`!P``
M`$.N`0!`````2ZX!`!X```",K@$`.P```*NN`0`J````YZX!`"@````2KP$`
M)````#NO`0`&````8*\!``4```!GKP$`&@```&VO`0`'````B*\!``L```"0
MKP$`(0```)RO`0`_````OJ\!`#L```#^KP$`(P```#JP`0`B````7K`!`%<`
M``"!L`$`+````-FP`0`2````!K$!``H````9L0$`"P```"2Q`0`)````,+$!
M`!<````ZL0$`"0```%*Q`0`/````7+$!``T```!LL0$`$@```'JQ`0`2````
MC;$!`!(```"@L0$`$P```+.Q`0`-````Q[$!`!,```#5L0$`!0```.FQ`0`9
M````[[$!`!H````)L@$`%P```"2R`0`9````/+(!`"0```!6L@$`!````'NR
M`0`+````@+(!`!,```",L@$`1````*"R`0!<````Y;(!``@```!"LP$`$@``
M`$NS`0`%````7K,!``0```!DLP$`'@```&FS`0`9````B+,!`!T```"BLP$`
M$0```,"S`0`>````TK,!`"T```#QLP$`90```!^T`0!3````A;0!`'L```#9
MM`$`-@```%6U`0!#````C+4!`$(```#0M0$`0P```!.V`0`S````5[8!`!(`
M``"+M@$`*````)ZV`0`&````Q[8!`!D```#.M@$`%````.BV`0`>````_;8!
M`!8````<MP$`%0```#.W`0`?````2;<!`!````!IMP$`)````'JW`0`H````
MG[<!`!$```#(MP$`$0```-JW`0`)````[+<!`!$```#VMP$`"@````BX`0`/
M````$[@!`!T````CN`$`$0```$&X`0`(````4[@!``0```!<N`$`#````&&X
M`0`-````;K@!``D```!\N`$`$0```(:X`0`&````F+@!`!X```"?N`$`!P``
M`+ZX`0`0````QK@!``H```#7N`$`#@```.*X`0`/````\;@!``,````!N0$`
M#`````6Y`0`1````$KD!`!$````DN0$`'0```#:Y`0!8````5+D!`"````"M
MN0$`$0```,ZY`0`5````X+D!`#8```#VN0$`!@```"VZ`0`%````-+H!`!\`
M```ZN@$`%P```%JZ`0`8````<KH!`#8```"+N@$`0P```,*Z`0`L````!KL!
M``D````SNP$`-````#V[`0`>````<KL!``T```"1NP$`"0```)^[`0`-````
MJ;L!``0```"WNP$`"P```+R[`0`:````R+L!`!@```#CNP$`.````/R[`0`4
M````-;P!``H```!*O`$`$````%6\`0`L````9KP!`"\```"3O`$`/@```,.\
M`0`Q`````KT!`"P````TO0$`'@```&&]`0!$````@+T!`"P```#%O0$`/@``
M`/*]`0`L````,;X!`#T```!>O@$`/P```)R^`0`B````W+X!`"@```#_O@$`
M-P```"B_`0`Q````8+\!`"T```"2OP$`+P```,"_`0`\````\+\!`"(````M
MP`$`)P```%#``0`_````>,`!`"L```"XP`$`%````.3``0`I````^<`!`"8`
M```CP0$`'@```$K!`0`1````:<$!`,0```![P0$`.@```$#"`0`I````>\(!
M`"L```"EP@$`+0```-'"`0`O````_\(!`#4````OPP$`(P```&7#`0`H````
MB<,!`"X```"RPP$`,0```.'#`0`Y````$\0!`#0```!-Q`$`D````(+$`0`T
M````$\4!`!@```!(Q0$`+0```&'%`0`K````C\4!`"\```"[Q0$`1````.O%
M`0!*````,,8!``\```![Q@$`!@```(O&`0`*````DL8!``H```"=Q@$`%0``
M`*C&`0`8````OL8!`!````#7Q@$`#@```.C&`0`4````]\8!``H````,QP$`
M*````!?'`0`/````0,<!``P```!0QP$`!````%W'`0`)````8L<!`!$```!L
MQP$`(@```'['`0`*````H<<!``\```"LQP$`%@```+S'`0`2````T\<!`!X`
M``#FQP$`$`````7(`0!+````%L@!``<```!BR`$`&````&K(`0`&````@\@!
M``\```"*R`$`%0```)K(`0`5````L,@!`!````#&R`$``@```-?(`0!=````
MVL@!``<````XR0$`#P```$#)`0`1````4,D!`!D```!BR0$`!0```'S)`0`1
M````@LD!`!(```"4R0$``P```*?)`0`#````J\D!``8```"OR0$`#@```+;)
M`0`(````Q<D!``8```#.R0$`#````-7)`0`0````XLD!``\```#SR0$`(0``
M``/*`0`?````)<H!`"$```!%R@$`%0```&?*`0`*````?<H!``8```"(R@$`
M"@```(_*`0`/````FLH!`!<```"JR@$`$0```,+*`0`7````U,H!`!4```#L
MR@$`#P````++`0`/````$LL!`!$````BRP$`*````#3+`0`1````7<L!`!T`
M``!ORP$`/@```(W+`0`-````S,L!`"````#:RP$`$P```/O+`0`:````#\P!
M`'4````JS`$`%P```*#,`0`K````N,P!`!(```#DS`$`!0```/?,`0`&````
M_<P!`!L````$S0$`!@```"#-`0`O````)\T!`$$```!7S0$`"@```)G-`0`*
M````I,T!`!4```"OS0$`#````,7-`0`2````TLT!`!(```#ES0$`!@```/C-
M`0`,````_\T!`#(````,S@$`%@```#_.`0`9````5LX!`"4```!PS@$`)@``
M`);.`0`6````O<X!`"8```#4S@$`"````/O.`0`+````!,\!`"P````0SP$`
M-````#W/`0`.````<L\!`$````"!SP$`"````,+/`0`5````R\\!`"<```#A
MSP$`"`````G0`0`/````$M`!`#T````BT`$`#P```&#0`0`,````<-`!``P`
M``!]T`$`"P```(K0`0`%````EM`!`%$```"<T`$`!````.[0`0`'````\]`!
M``D```#[T`$`#0````71`0`7````$]$!``\````KT0$`$P```#O1`0`1````
M3]$!`!4```!AT0$`&````'?1`0`>````D-$!`!H```"OT0$`%P```,K1`0`B
M````XM$!`!T````%T@$`(````"/2`0`>````1-(!``<```!CT@$`"````&O2
M`0`(````=-(!``<```!]T@$`%@```(72`0`%````G-(!``D```"BT@$`(0``
M`*S2`0`7````SM(!`!````#FT@$`#@```/?2`0`,````!M,!``P````3TP$`
M&0```"#3`0`#````.M,!`$,````^TP$`-@```(+3`0`2````N=,!``@```#,
MTP$`$0```-73`0`,````Y],!`!8```#TTP$`>@````O4`0`:````AM0!`!H`
M``"AU`$`$0```+S4`0`'````SM0!``0```#6U`$`)P```-O4`0`V`````]4!
M`#T````ZU0$`(@```'C5`0`J````F]4!`"P```#&U0$`&````//5`0`G````
M#-8!``H````TU@$`!P```#_6`0`,````1]8!``8```!4U@$`$````%O6`0`;
M````;-8!`!D```"(U@$`'P```*+6`0`=````PM8!`"D```#@U@$`*`````K7
M`0`-````,]<!``P```!!UP$`$@```$[7`0`,````8=<!`!<```!NUP$`"P``
M`(;7`0`*````DM<!``X```"=UP$`"P```*S7`0`,````N-<!`"````#%UP$`
M'P```.;7`0`;````!M@!`$T````BV`$`%P```'#8`0`&````B-@!``H```"/
MV`$`$0```)K8`0`$````K-@!`"<```"QV`$`,0```-G8`0`>````"]D!`!T`
M```JV0$`*P```$C9`0`J````=-D!`"P```"?V0$`+0```,S9`0`<````^MD!
M``8````7V@$`'````![:`0`.````.]H!`!<```!*V@$``P```&+:`0`#````
M9MH!``<```!JV@$`$````'+:`0`2````@]H!``T```"6V@$`%@```*3:`0`+
M````N]H!`"8```#'V@$`!@```.[:`0`$````]=H!`!(```#ZV@$`$@````W;
M`0`.````(-L!``<````OVP$`#@```#?;`0`/````1ML!`"$```!6VP$`!@``
M`'C;`0`(````?]L!``H```"(VP$`"````)/;`0`+````G-L!`!8```"HVP$`
M$0```+_;`0`#````T=L!`!0```#5VP$`"````.K;`0`&````\]L!`#D```#Z
MVP$`&````#3<`0",````3=P!`!D```#:W`$`#````/3<`0`&`````=T!``X`
M```(W0$`"````!?=`0`*````(-T!``<````KW0$`#````#/=`0`"````0-T!
M``@```!#W0$`#0```$S=`0`-````6MT!``8```!HW0$`&````&_=`0`.````
MB-T!`!$```"7W0$`%@```*G=`0`&````P-T!``8```#'W0$`!P```,[=`0`0
M````UMT!``@```#GW0$`"@```/#=`0`$````^]T!``4`````W@$`(`````;>
M`0`+````)]X!``8````SW@$`!0```#K>`0`0````0-X!`"0```!1W@$`$0``
M`';>`0`&````B-X!``L```"/W@$`!0```)O>`0`)````H=X!``H```"KW@$`
M%````+;>`0`%````R]X!``4```#1W@$`#0```-?>`0`.````Y=X!``T```#T
MW@$`#`````+?`0`+````#]\!`!(````;WP$`"````"[?`0`'````-]\!`!8`
M```_WP$`'````%;?`0!#````<]\!`"L```"WWP$`.````./?`0`)````'.`!
M``H````FX`$`!````#'@`0`)````-N`!``@```!`X`$`%````$G@`0`+````
M7N`!``8```!JX`$`#0```''@`0`&````?^`!`$````"&X`$`10```,?@`0!"
M````#>$!`"L```!0X0$`!0```'SA`0`/````@N$!``,```"2X0$`!@```);A
M`0`&````G>$!`!L```"DX0$`#````,#A`0`4````S>$!``@```#BX0$`"```
M`.OA`0`C````].$!``@````8X@$`!P```"'B`0`0````*>(!``P````ZX@$`
M$````$?B`0`$````6.(!``@```!=X@$`#````&;B`0`(````<^(!``L```!\
MX@$`%````(CB`0`/````G>(!``@```"MX@$`"````+;B`0`%````O^(!`#0`
M``#%X@$`-P```/KB`0`W````,N,!`"P```!JXP$`10```)?C`0!#````W>,!
M`"\````AY`$`6````%'D`0`T````JN0!`$H```#?Y`$`+0```"KE`0`0````
M6.4!`!````!IY0$`"P```'KE`0`#````AN4!`",```"*Y0$`0@```*[E`0`D
M````\>4!`#4````6Y@$`%P```$SF`0`@````9.8!``P```"%Y@$`#@```)+F
M`0`*````H>8!``P```"LY@$`+@```+GF`0`J````Z.8!`#\````3YP$`!@``
M`%/G`0`>````6N<!`#````!YYP$`'````*KG`0`6````Q^<!``8```#>YP$`
M"P```.7G`0`*````\><!`!````#\YP$`)0````WH`0!&````,^@!`)$```!Z
MZ`$`=`````SI`0#Q````@>D!``\```!SZ@$`#````(/J`0`-````D.H!`!L`
M``">Z@$`%P```+KJ`0`.````TNH!``4```#AZ@$`'````.?J`0`5````!.L!
M`!X````:ZP$`%0```#GK`0`3````3^L!`!8```!CZP$`%P```'KK`0`T````
MDNL!`(T```#'ZP$`$````%7L`0`%````9NP!`!(```!L[`$`"0```'_L`0`*
M````B>P!``H```"4[`$`*````)_L`0`7````R.P!`!````#@[`$`%0```/'L
M`0`0````!^T!`!8````8[0$`%P```"_M`0`6````1^T!`!,```!>[0$`$P``
M`'+M`0`<````ANT!`!L```"C[0$`(````+_M`0`_````X.T!`!D````@[@$`
M&````#KN`0`7````4^X!`!8```!K[@$`$@```(+N`0`<````E>X!`!L```"R
M[@$`$P```,[N`0`3````XNX!`#````#V[@$`&P```"?O`0`<````0^\!`$(`
M``!@[P$`'P```*/O`0`%````P^\!`!0```#)[P$`+0```-[O`0`C````#/`!
M`"$````P\`$`)@```%+P`0`E````>?`!`!T```"?\`$`(P```+WP`0`C````
MX?`!`!P````%\0$`(@```"+Q`0!!````1?$!`"(```"'\0$`)P```*KQ`0`G
M````TO$!`"````#Z\0$`(````!OR`0`C````//(!`"D```!@\@$`(@```(KR
M`0`C````K?(!``T```#1\@$`%P```-_R`0`8````]_(!``0````0\P$`"```
M`!7S`0`*````'O,!`!0````I\P$`!@```#[S`0`5````1?,!``0```!;\P$`
M"P```&#S`0`'````;/,!``8```!T\P$`!0```'OS`0`3````@?,!``8```"5
M\P$`"````)SS`0`&````I?,!``8```"L\P$`"@```+/S`0`0````OO,!`!H`
M``#/\P$`$````.KS`0`1````^_,!``H````-]`$`&````!CT`0`%````,?0!
M`#D````W]`$`%@```''T`0`1````B/0!`!$```":]`$`#@```*ST`0`+````
MN_0!`!(```#']`$`+P```-KT`0`+````"O4!``@````6]0$`"````!_U`0`D
M````*/4!`!(```!-]0$`#P```&#U`0`&````</4!``P```!W]0$`"0```(3U
M`0`%````CO4!`"0```"4]0$`$````+GU`0`*````RO4!`!````#5]0$`"@``
M`.;U`0`6````\?4!``T````(]@$`$P```!;V`0`'````*O8!`!@````R]@$`
M(P```$OV`0`G````;_8!``@```"7]@$`"@```*#V`0`#````J_8!``H```"O
M]@$`(@```+KV`0`'````W?8!``,```#E]@$`$0```.GV`0`2````^_8!``<`
M```.]P$`!0```!;W`0`'````'/<!`"H````D]P$`#0```$_W`0`2````7?<!
M``H```!P]P$`$P```'OW`0`7````C_<!``P```"G]P$`#@```+3W`0`.````
MP_<!``X```#2]P$`-````.'W`0`$````%O@!`!$````;^`$`0P```"WX`0`&
M````<?@!``4```!X^`$`)P```'[X`0`6````IO@!`#0```"]^`$`%0```/+X
M`0`.````"/D!`!,````7^0$`#P```"OY`0`0````._D!``\```!,^0$`'@``
M`%SY`0`?````>_D!`#4```";^0$`*P```-'Y`0`F````_?D!``@````D^@$`
M"````"WZ`0`$````-OH!``L````[^@$`"P```$?Z`0`1````4_H!``0```!E
M^@$`#0```&KZ`0`J````>/H!``T```"C^@$`#0```+'Z`0`F````O_H!`%$`
M``#F^@$`'0```#C[`0`-````5OL!``@```!D^P$`"````&W[`0`.````=OL!
M``X```"%^P$`%0```)3[`0`)````JOL!``(```"T^P$`#0```+?[`0`C````
MQ?L!``8```#I^P$`!0```/#[`0`)````]OL!``L`````_`$`"0````S\`0`)
M````%OP!`!0````@_`$`#@```#7\`0`&````1/P!``@```!+_`$`#P```%3\
M`0`$````9/P!``4```!I_`$`&0```&_\`0!K````B?P!``P```#U_`$`#P``
M``+]`0`@````$OT!``<````S_0$`!0```#O]`0`J````0?T!`#$```!L_0$`
M$0```)[]`0`*````L/T!`!D```"[_0$`"@```-7]`0`)````X/T!`"H```#J
M_0$`'@```!7^`0`I````-/X!`"@```!>_@$`(0```(?^`0`K````J?X!``\`
M``#5_@$`!0```.7^`0`'````Z_X!``(```#S_@$`#0```/;^`0`+````!/\!
M``4````0_P$`$````!;_`0`)````)_\!`!,````Q_P$`%@```$7_`0`&````
M7/\!`%D```!C_P$`'@```+W_`0`0````W/\!`!8```#M_P$`)`````0``@!F
M````*0`"`!@```"0``(`!P```*D``@`?````L0`"`#````#1``(`"`````(!
M`@`&````"P$"`!X````2`0(`!0```#$!`@`*````-P$"`"X```!"`0(`+0``
M`'$!`@`[````GP$"``0```#;`0(`$P```.`!`@`&````]`$"`"0```#[`0(`
M5@```"`"`@`?````=P("`!P```"7`@(`.0```+0"`@`"````[@("`!D```#Q
M`@(`!P````L#`@`2````$P,"`!$````F`P(`!P```#@#`@`4````0`,"``8`
M``!5`P(`!0```%P#`@`(````8@,"``4```!K`P(`$0```'$#`@`+````@P,"
M``<```"/`P(`'@```)<#`@`:````M@,"`!````#1`P(`$0```.(#`@`*````
M]`,"``L```#_`P(`+`````L$`@`'````.`0"`!````!`!`(`$````%$$`@`/
M````8@0"``D```!R!`(`#````'P$`@`-````B00"``H```"7!`(`"0```*($
M`@`*````K`0"``@```"W!`(`&P```,`$`@`>````W`0"`$H```#[!`(`%```
M`$8%`@`:````6P4"`!8```!V!0(`#P```(T%`@`0````G04"`!8```"N!0(`
M%@```,4%`@`@````W`4"``<```#]!0(`%@````4&`@`#````'`8"``<````@
M!@(`!0```"@&`@`%````+@8"``D````T!@(`$````#X&`@`2````3P8"`#,`
M``!B!@(`+@```)8&`@`B````Q08"`"0```#H!@(`%P````T'`@`?````)0<"
M`!D```!%!P(`!P```%\'`@`$````9P<"``P```!L!P(`#````'D'`@`/````
MA@<"`!$```"6!P(`!@```*@'`@`>````KP<"``D```#.!P(`8@```-@'`@`)
M````.P@"`"L```!%"`(`)0```'$(`@`/````EP@"``4```"G"`(`#````*T(
M`@`)````N@@"`!(```#$"`(`$0```-<(`@`&````Z0@"``\```#P"`(`#0``
M```)`@`,````#@D"``8````;"0(`$````"()`@`-````,PD"``H```!!"0(`
M"0```$P)`@`%````5@D"``<```!<"0(`!P```&0)`@`$````;`D"``,```!Q
M"0(`%````'4)`@`4````B@D"`%D```"?"0(`+0```/D)`@!$````)PH"`!L`
M``!L"@(`/0```(@*`@`[````Q@H"``\````""P(`0````!(+`@`I````4PL"
M`!X```!]"P(`'@```)P+`@`C````NPL"`#8```#?"P(`#0```!8,`@`*````
M)`P"`"$````O#`(`,````%$,`@`E````@@P"`!T```"H#`(`&0```,8,`@`5
M````X`P"`!4```#V#`(`#P````P-`@`4````'`T"`!4````Q#0(`(0```$<-
M`@`]````:0T"`#X```"G#0(`00```.8-`@`^````*`X"`#\```!G#@(`/0``
M`*<.`@!M````Y0X"`!X```!3#P(`%@```'(/`@`0````B0\"`!H```":#P(`
M)0```+4/`@`/````VP\"`!````#K#P(`.P```/P/`@`K````.!`"`"T```!D
M$`(`(````)(0`@`*````LQ`"`"D```"^$`(`*P```.@0`@`%````%!$"`"8`
M```:$0(`%@```$$1`@`.````6!$"``X```!G$0(`%P```'81`@`(````CA$"
M``H```"7$0(`#````*(1`@`.````KQ$"``T```"^$0(`+P```,P1`@`/````
M_!$"``\````,$@(`#````!P2`@`F````*1("``L```!0$@(`"````%P2`@`$
M````91("``0```!J$@(`$````&\2`@`.````@!("``L```"/$@(`-0```)L2
M`@`"````T1("``@```#4$@(`%P```-T2`@`,````]1("``<````"$P(`!@``
M``H3`@`1````$1,"`"L````C$P(`#0```$\3`@`<````71,"``0```!Z$P(`
M*P```'\3`@`A````JQ,"`!D```#-$P(`-P```.<3`@`C````'Q0"`!X```!#
M%`(`=P```&(4`@`7````VA0"`$@```#R%`(`)P```#L5`@`2````8Q4"``L`
M``!V%0(`%0```((5`@`&````F!4"``X```"?%0(`%````*X5`@`)````PQ4"
M`!$```#-%0(`#@```-\5`@`>````[A4"`!4````-%@(`!0```",6`@`0````
M*18"``H````Z%@(`"@```$46`@`:````4!8"``X```!K%@(`,@```'H6`@`5
M````K18"`!4```##%@(`&````-D6`@`3````\A8"`!\````&%P(`!P```"87
M`@`7````+A<"``L```!&%P(`%````%(7`@`4````9Q<"`!8```!\%P(`$```
M`),7`@`6````I!<"`!@```"[%P(`"P```-07`@`)````X!<"``4```#J%P(`
M'0```/`7`@`&````#A@"``\````5&`(`"````"48`@`2````+A@"``8```!!
M&`(`)````$@8`@`4````;1@"`#,```""&`(`%0```+88`@`'````S!@"``@`
M``#4&`(`'@```-T8`@`@````_!@"``L````=&0(`&P```"D9`@`'````11D"
M``4```!-&0(`(P```%,9`@`'````=QD"``@```!_&0(`)````(@9`@`[````
MK1D"`"T```#I&0(`"P```!<:`@`E````(QH"`"<```!)&@(`#0```'$:`@`:
M````?QH"`!````":&@(`!````*L:`@`.````L!H"``X```"_&@(`!P```,X:
M`@`.````UAH"``@```#E&@(`!0```.X:`@`)````]!H"`!T```#^&@(`)@``
M`!P;`@`_````0QL"`"@```"#&P(`)0```*P;`@`?````TAL"`#L```#R&P(`
M'@```"X<`@`J````31P"`#(```!X'`(`70```*L<`@`E````"1T"``T````O
M'0(`"````#T=`@`*````1AT"`!0```!1'0(`"@```&8=`@`1````<1T"`!8`
M``"#'0(`1P```)H=`@`E````XAT"`!H````('@(`.````",>`@!`````7!X"
M``D```"='@(`)@```*<>`@`+````SAX"`!0```#:'@(`)P```.\>`@`)````
M%Q\"``D````A'P(`"0```"L?`@`,````-1\"`!D```!"'P(`#````%P?`@`.
M````:1\"``X```!X'P(`#P```(<?`@`0````EQ\"``\```"H'P(`&P```+@?
M`@`:````U!\"`#4```#O'P(`"P```"4@`@`:````,2`"``4```!,(`(`%0``
M`%(@`@`%````:"`"`!X```!N(`(`%P```(T@`@`#````I2`"``P```"I(`(`
M$````+8@`@`%````QR`"``X```#-(`(`"````-P@`@`/````Y2`"``4```#U
M(`(`!P```/L@`@`0`````R$"`$D````4(0(`4````%XA`@`1````KR$"`!(`
M``#!(0(`$@```-0A`@`2````YR$"`!(```#Z(0(`%0````TB`@`2````(R("
M`!(````V(@(`$@```$DB`@`1````7"("`"<```!N(@(`"0```)8B`@`R````
MH"("`"L```#3(@(`$0```/\B`@`)````$2,"``P````;(P(`#P```"@C`@`/
M````.","`!````!((P(`$````%DC`@`L````:B,"`#(```"7(P(`!@```,HC
M`@`*````T2,"`!@```#<(P(`#0```/4C`@`.`````R0"`!4````2)`(`#0``
M`"@D`@!<````-B0"``H```"3)`(`)0```)XD`@`5````Q"0"`!8```#:)`(`
MD````/$D`@`L````@B4"`"8```"O)0(`"0```-8E`@`^````X"4"`$$````?
M)@(`.P```&$F`@`4````G28"``X```"R)@(`!0```,$F`@`3````QR8"`!P`
M``#;)@(`&````/@F`@`&````$2<"`"`````8)P(`"````#DG`@`3````0B<"
M`!L```!6)P(`!P```'(G`@`?````>B<"`!<```":)P(`$````+(G`@`$````
MPR<"`!(```#()P(`$P```-LG`@`4````[R<"``8````$*`(`!P````LH`@`3
M````$R@"``X````G*`(`#P```#8H`@`1````1B@"`!$```!8*`(`!@```&HH
M`@`'````<2@"`"@```!Y*`(`)````*(H`@`@````QR@"``@```#H*`(`#P``
M`/$H`@`&`````2D"`!@````(*0(`*0```"$I`@`I````2RD"``H```!U*0(`
M&````(`I`@`#````F2D"``@```"=*0(``P```*8I`@`2````JBD"`!0```"]
M*0(`"P```-(I`@`8````WBD"`",```#W*0(`%P```!LJ`@`&````,RH"``H`
M```Z*@(`%````$4J`@`7````6BH"``<```!R*@(`#````'HJ`@`&````ARH"
M``P```".*@(`"@```)LJ`@`1````IBH"`!8```"X*@(`%P```,\J`@`5````
MYRH"`'D```#]*@(`'P```'<K`@`O````ERL"`!0```#'*P(`"````-PK`@`'
M````Y2L"`!4```#M*P(`%P````,L`@`3````&RP"`!<````O+`(`%P```$<L
M`@`G````7RP"`!@```"'+`(`(@```*`L`@`=````PRP"`!(```#A+`(`)0``
M`/0L`@`1````&BT"`"8````L+0(`&````%,M`@`U````;"T"`&H```"B+0(`
M%P````TN`@`\````)2X"`$$```!B+@(`@P```*0N`@`H````*"\"`!\```!1
M+P(`)0```'$O`@`B````ER\"`!X```"Z+P(`+````-DO`@`X````!C`"`"<`
M```_,`(`'@```&<P`@`Z````AC`"`$$```#!,`(`*P````,Q`@!1````+S$"
M`",```"!,0(`)P```*4Q`@`4````S3$"``L```#B,0(`6P```.XQ`@`2````
M2C("`&P```!=,@(`"````,HR`@`)````TS("``H```#=,@(`%0```.@R`@`+
M````_C("`#L````*,P(`*0```$8S`@`W````<#,"`!8```"H,P(`!@```+\S
M`@`2````QC,"`$4```#9,P(`$@```!\T`@`/````,C0"`%4```!"-`(`3```
M`)@T`@`T````Y30"`)P````:-0(`"P```+<U`@`W````PS4"`"\```#[-0(`
M$@```"LV`@`O````/C8"`!D```!N-@(`&@```(@V`@`(````HS8"`!,```"L
M-@(`1````,`V`@`,````!3<"`!(````2-P(`-0```"4W`@!\````6S<"`%@`
M``#8-P(`+0```#$X`@`H````7S@"`$@```"(.`(`3@```-$X`@`H````(#D"
M`!0```!).0(`.````%XY`@`B````ESD"`#8```"Z.0(`(@```/$Y`@`L````
M%#H"`"(```!!.@(`*P```&0Z`@`?````D#H"`#X```"P.@(`%0```.\Z`@`'
M````!3L"`!`````-.P(`%````!X[`@`-````,SL"``L```!!.P(`40```$T[
M`@`,````GSL"`!X```"L.P(`$0```,L[`@`?````W3L"``D```#].P(`!0``
M``<\`@`8````#3P"``D````F/`(`"0```#`\`@`'````.CP"``<```!"/`(`
M"0```$H\`@`2````5#P"`!P```!G/`(`#P```(0\`@`?````E#P"`!````"T
M/`(`"````,4\`@`-````SCP"`"8```#</`(`"P````,]`@`*````#ST"`!@`
M```:/0(`)@```#,]`@`,````6CT"`"(```!G/0(`*P```(H]`@`+````MCT"
M``@```#"/0(`(0```,L]`@`-````[3T"`!D```#[/0(`&P```!4^`@`4````
M,3X"`!8```!&/@(`$@```%T^`@`%````<#X"``D```!V/@(`!@```(`^`@`(
M````ASX"``D```"0/@(`"P```)H^`@`(````ICX"``L```"O/@(`"@```+L^
M`@`'````QCX"`!0```#./@(`!P```.,^`@`0````ZSX"``H```#\/@(`"```
M``<_`@`,````$#\"`"$````=/P(`#````#\_`@`"````3#\"`",```!//P(`
M!0```',_`@`*````>3\"`'H```"$/P(`"@```/\_`@`(````"D`"`"H````3
M0`(`.@```#Y``@`:````>4`"`"X```"40`(`70```,-``@`C````(4$"`#,`
M``!%00(`+P```'E!`@`E````J4$"``8```#/00(`#0```-9!`@`(````Y$$"
M``D```#M00(`"````/=!`@`%`````$("``@````&0@(`$@````]"`@`*````
M(D("``D````M0@(`"P```#="`@`+````0T("`!H```!/0@(`"````&I"`@`)
M````<T("`!4```!]0@(`"@```)-"`@`*````GD("``4```"I0@(`+@```*]"
M`@`F````WD("`!@````%0P(`!P```!Y#`@`2````)D,"``D````Y0P(`#P``
M`$-#`@`S````4T,"``@```"'0P(`&````)!#`@`8````J4,"``8```#"0P(`
M!@```,E#`@`-````T$,"`!P```#>0P(`!@```/M#`@`)`````D0"``L````,
M1`(`'````!A$`@`+````-40"``T```!!1`(`*@```$]$`@`?````>D0"`!@`
M``":1`(`"0```+-$`@`&````O40"``L```#$1`(`$````-!$`@`-````X40"
M``,```#O1`(`#@```/-$`@`(`````D4"`$4````+10(`'0```%%%`@`O````
M;T4"`#````"?10(`*@```-!%`@`N````^T4"`"X````J1@(`C@```%E&`@`6
M````Z$8"`!P```#_1@(`&P```!Q'`@`:````.$<"`"(```!31P(`&P```'9'
M`@`:````DD<"`&,```"M1P(`.````!%(`@!A````2D@"`&D```"L2`(`(0``
M`!9)`@!-````.$D"`#8```"&20(`20```+U)`@!,````!TH"`$8```!42@(`
M*@```)M*`@`\````QDH"`$<````#2P(`'@```$M+`@`8````:DL"`",```"#
M2P(`'0```*=+`@#]`0``Q4L"`!T```##30(`'0```.%-`@!)````_TT"`*``
M``!)3@(`-````.I.`@`I````'T\"`$<```!)3P(`6@```)%/`@!D````[$\"
M`#(```!14`(`DP```(10`@`@````&%$"`!X````Y40(`-````%A1`@`<````
MC5$"`!\```"J40(`)````,I1`@`@````[U$"`"8````04@(`+P```#=2`@`:
M````9U("`!8```""4@(`,0```)E2`@`J````RU("`"0```#V4@(`/````!M3
M`@`N````6%,"`!H```"'4P(`,@```*)3`@!Q````U5,"`#L```!'5`(`.@``
M`(-4`@`R````OE0"`"D```#Q5`(`1P```!M5`@!M````8U4"`%\```#150(`
M)````#%6`@`Q````5E8"`#````"(5@(`,0```+E6`@`P````ZU8"`#,````<
M5P(`3@```%!7`@`R````GU<"`&8```#25P(`4````#E8`@!-````BE@"`%,`
M``#86`(`(P```"Q9`@!)````4%D"`"<```":60(`)P```,)9`@`D````ZED"
M`'@````/6@(`;0```(A:`@!W````]EH"`,X```!N6P(`'````#U<`@`L````
M6EP"`#8```"'7`(`+@```+Y<`@!0````[5P"`!P````^70(`0````%M=`@`8
M````G%T"`#\```"U70(`!0```/5=`@#(````^UT"`!4```#$7@(`1@```-I>
M`@`B````(5\"`#X```!$7P(`)P```(-?`@`<````JU\"`"P```#(7P(`"0``
M`/5?`@`)````_U\"`!8````)8`(``P```"!@`@`)````)&`"`!8````N8`(`
M#````$5@`@`-````4F`"``D```!@8`(`"P```&I@`@`)````=F`"``D```"`
M8`(`#0```(I@`@`'````F&`"`'4```"@8`(``@```!9A`@`6````&6$"``0`
M```P80(`!P```#5A`@`&````/6$"``4```!$80(`!0```$IA`@`5````4&$"
M``H```!F80(`$@```'%A`@`/````A&$"``(```"480(`!````)=A`@`'````
MG&$"``L```"D80(`$@```+!A`@`-````PV$"`!D```#180(`!@```.MA`@`%
M````\F$"`!D```#X80(`"@```!)B`@`#````'6("`%L````A8@(`!````'UB
M`@`&````@F("``<```")8@(`)P```)%B`@!,````N6("`$8````&8P(`1P``
M`$UC`@`J````E6,"`"X```#`8P(`,0```.]C`@`=````(60"`"(````_9`(`
M'````&)D`@`R````?V0"`"H```"R9`(`)````-UD`@`F`````F4"`"<````I
M90(`+@```%%E`@`K````@&4"`!T```"L90(`'@```,IE`@`I````Z64"`"H`
M```39@(`'P```#YF`@`C````7F8"`"$```""9@(`&0```*1F`@`B````OF8"
M`"P```#A9@(`,@````YG`@`S````06<"`"<```!U9P(`'0```)UG`@`D````
MNV<"`"D```#@9P(`'0````IH`@`G````*&@"`#@```!0:`(`.P```(EH`@`9
M````Q6@"`",```#?:`(`(`````-I`@`Z````)&D"`"(```!?:0(`)@```()I
M`@`D````J6D"`"4```#.:0(`'````/1I`@`L````$6H"`"0````^:@(`,```
M`&-J`@`>````E&H"`#$```"S:@(`(0```.5J`@`V````!VL"``D````^:P(`
M$````$AK`@`B````66L"`$<```!\:P(`+````,1K`@`,````\6L"``\```#^
M:P(`%P````YL`@`2````)FP"`!`````Y;`(`)P```$IL`@`&````<FP"``H`
M``!Y;`(`)0```(1L`@`H````JFP"`!L```#3;`(`*````.]L`@`<````&&T"
M``\````U;0(`]````$5M`@`5````.FX"`!P```!0;@(`%P```&UN`@`)````
MA6X"`!<```"/;@(`(@```*=N`@`=````RFX"`!L```#H;@(`'@````1O`@`)
M````(V\"`#X````M;P(`#P```&QO`@`6````?&\"``<```"3;P(`&P```)MO
M`@`1````MV\"`$X```#);P(`$````!AP`@`B````*7`"`!P```!,<`(`%```
M`&EP`@`8````?G`"`",```"7<`(`80```+MP`@`G````'7$"`!````!%<0(`
M)P```%9Q`@`1````?G$"`!(```"0<0(`&````*-Q`@`+````O'$"`!T```#(
M<0(`*0```.9Q`@`?````$'("``L````P<@(`,P```#QR`@`]````<'("``<`
M``"N<@(`$P```+9R`@`'````RG("``<```#2<@(`"0```-IR`@!)````Y'("
M``8````N<P(`#0```#5S`@`0````0W,"`!8```!4<P(`"P```&MS`@`,````
M=W,"``<```"$<P(`$0```(QS`@`/````GG,"`!$```"N<P(`'````,!S`@`7
M````W7,"`!0```#U<P(`&`````IT`@`,````(W0"``X````P=`(`+````#]T
M`@`.````;'0"`#8```![=`(`&@```+)T`@`0````S70"``X```#>=`(``P``
M`.UT`@`4````\70"`!L````&=0(``P```")U`@`)````)G4"``8````P=0(`
M`P```#=U`@`'````.W4"``,```!#=0(`!P```$=U`@`:````3W4"``H```!J
M=0(`#@```'5U`@`.````A'4"`!L```"3=0(`'````*]U`@`.````S'4"`#0`
M``#;=0(`&@```!!V`@`5````*W8"`%4```!!=@(`70```)=V`@`9````]78"
M``T````/=P(`,@```!UW`@`)````4'<"`!<```!:=P(`5@```')W`@`5````
MR7<"`!D```#?=P(`"@```/EW`@`$````!'@"``0````)>`(`%@````YX`@`5
M````)7@"``4````[>`(`!@```$%X`@`*````2'@"``T```!3>`(`!0```&%X
M`@`.````9W@"`!(```!V>`(`"````(EX`@`_````DG@"`#(```#2>`(`*0``
M``5Y`@`@````+WD"`!P```!0>0(`(P```&UY`@`H````D7D"`"````"Z>0(`
M%0```-MY`@`"````\7D"``0```#T>0(`#0```/EY`@`"````!WH"``8````*
M>@(`&0```!%Z`@`%````*WH"``0````Q>@(`$0```#9Z`@!X````2'H"`"0`
M``#!>@(`+@```.9Z`@`J````%7L"`"T```!`>P(`0P```&Y[`@`O````LGL"
M`",```#B>P(`2`````9\`@"U````3WP"`#@````%?0(`2@```#Y]`@`W````
MB7T"`#H```#!?0(`&0```/Q]`@`H````%GX"`#`````_?@(`.````'!^`@`F
M````J7X"`(X```#0?@(`(@```%]_`@!4````@G\"`"$```#7?P(`5P```/E_
M`@`N````48`"`"\```"`@`(`)@```+"``@`I````UX`"`$`````!@0(`,P``
M`$*!`@`O````=H$"`#\```"F@0(`'0```.:!`@`E````!(("`"@````J@@(`
M/0```%."`@`W````D8("`#L```#)@@(`4`````6#`@!-````5H,"`!````"D
M@P(`&P```+6#`@`4````T8,"`'4```#F@P(`"@```%R$`@#6````9X0"`(4`
M```^A0(`?@```,2%`@`X````0X8"`'H```!\A@(`'````/>&`@`E````%(<"
M`#<````ZAP(`*@```'*'`@`2````G8<"`"4```"PAP(`)````-:'`@!&````
M^X<"`"(```!"B`(`'````&6(`@!9````@H@"`"\```#<B`(`)@````R)`@`+
M````,XD"``4````_B0(`!@```$6)`@`(````3(D"`"(```!5B0(`#@```'B)
M`@`@````AXD"`"@```"HB0(`(````-&)`@`+````\HD"``\```#^B0(`#@``
M``Z*`@`'````'8H"``L````EB@(`"0```#&*`@`)````.XH"``8```!%B@(`
M"@```$R*`@`)````5XH"`!8```!AB@(`#@```'B*`@`-````AXH"``X```"5
MB@(`%````*2*`@`*````N8H"`!````#$B@(`!P```-6*`@`.````W8H"``H`
M``#LB@(`$0```/>*`@`(````"8L"``P````2BP(`%@```!^+`@`#````-HL"
M``T````ZBP(`"@```$B+`@`4````4XL"`!````!HBP(`!@```'F+`@`'````
M@(L"`"4```"(BP(`(@```*Z+`@`.````T8L"`!````#@BP(`$@```/&+`@`D
M````!(P"`!$````IC`(``P```#N,`@`#````/XP"``,```!#C`(`"0```$>,
M`@`5````48P"``<```!GC`(`!````&^,`@`C````=(P"``L```"8C`(``@``
M`*2,`@`5````IXP"``@```"]C`(`$0```,:,`@`1````V(P"``0```#JC`(`
M20```.^,`@`'````.8T"``,```!!C0(`+P```$6-`@`O````=8T"``L```"E
MC0(`!@```+&-`@`9````N(T"`!<```#2C0(`"````.J-`@`<````\XT"``4`
M```0C@(`'0```!:.`@`)````-(X"`"0````^C@(`&@```&..`@`@````?HX"
M``L```"?C@(`#````*N.`@`,````N(X"``T```#%C@(`*0```-..`@`*````
M_8X"`!\````(CP(`!0```"B/`@`7````+H\"``,```!&CP(``P```$J/`@`>
M````3H\"``,```!MCP(`!P```'&/`@`!````&P$``$T'``#?`@```````/(`
M``"T!P```````&,%``#<`````````/4#````````(P@``,`&``">`@``5`4`
M`/@$``"1!0``R`8```````!1"```:@$``,X&````````'@8``)`'``"J"```
M9@4``(4#``"X`0``M`````````"E`@``W0```)<```#6!P```````$4'```,
M"````````"H!``"G!0``'@<``(D#``!Y`P``PP<``,T'`````````````,H#
M````````80,```````"6````,P8``)<'``#$`0```````+L%``#-!0``@04`
M`````````````````(P&``!\!@``I0@``#@%``"M`@``*P,```8'````````
M5`,```````#)!0``*@<``/H%``"2!0```````/````"]`0``FP4```H$``!N
M!```[@4```0"``"%!P``````````````````10@```````"'!```#P(``,@%
M``"L`0``J`(``*H#````````GP8```````!4!P````````````!B!0``>P<`
M`*P&``!#!0``U````-$$````````*04``#X!``#"`@``Y`8``*8(````````
M`````.8#``"E`0````$``,T(``#*````B`8``($(``#\!P``Z`0```````"*
M`P```````+<`````````A`4``&<'```:`0``_@,``'H#````````?0(``+8$
M``#S`@``A@<``'T&```>`P```````.,%``!S`@`````````````"!@``O0@`
M``````#G!0```````-0$``#%"```>`8``!`$``":!0```````+D```!^`P``
M+@<``&$'```0`@````8``#D"``!4"````````)0$```P`0``RP0``,(#``!Q
M`P``[`4``#$"``"K!P``\`0``$P%``"U`@``W`<``)D%``!#`````````/\&
M``#(`P```````#T#``!W`0``10,``$H!```%!@``E`<``%`#``")!P``1P``
M`-P$````````0@@``(<(``!.!@``G`(``"$'```1!@``W`8`````````````
M`````)8#``#.`0``>P@``,`$``#F!@``'0```.@"```K!```K0$````````;
M`P``*`(``+@"``!9`0``;0$``-8&````````[0,``*<'````````L04`````
M````````L0@``*,&``"S````:@(`````````````@P@`````````````_0(`
M`/,!```/`P``"@$```$!```=!0``?`,``,$$``"0!@``_0,```````#W`@``
MWP0``+\"``!0!0``9`8``'``````````1@$``+$"```B`P``E04``$<(``!3
M!P``W0$````````)````MP0``(P'``"W`0``J0```,L"``"@!P``7````)0`
M```G!```KP(```0&```Q`0``+P0``+8`````````VP(``'X'``"U!P``&@``
M```````<"```>````$$"`````````````#<$``!?````2@,```````!P`0``
M`````-`#``""`@```````+($``!<`0``<04``',!``!B!P``UP```"P$``"K
M!@``Y`0``)8"``"G````$`,``,,$``#/!P``OP4````````U`P``S`<``.4&
M``!Q!```%@(````````F````1P(``!@'````````,`(``.$&``"Y`P``,@4`
M```````N"`````<``/P!```;!````````,@'``"8!P``D0<``/@!````````
MC04``*D!``!2`P``5@<``%@````6!@```````%<````S`@``/`(``#4$``"7
M!````````*8$``#P`@``%@$``!T$```;````(P8``/8````\!P``'@4``*T#
M``#[````HP@``+4(`````````````/`%``#8!0```````"8(````````KP0`
M```````5```````````````#!@``I`````````"M!P``\00```H(``"]!```
MR0````````"/!0````````````#/````7@0``'0$```*`P``Z@(``)<#```-
M!P````````\!````````2P<``!,```#X````+0<``)X#`````````````(P`
M```Y"```:P```#$````4`@``^P,```````"A!```+`(`````````````9@@`
M`&D%```;"```?@0````````B"```JP$```````!X"```;08``)T"````````
M_@4``*P(``")"````````.0%``","```10$`````````````[`0`````````
M````J@4``&P$````````````````````````$P<``#\#``!5````?`$``*L`
M``#B!```I0,``!P$```T!P``P0```/L"````````M0,``'`#```0`0``````
M`"L(````````=@0``,8!``!Y!```(@(``)T(``")````?@```)L(``#^````
M`````,X$`````````````*T%``!^!@``804``#L&``#6``````````````#>
M!```1P8``'4"``"O`P```````"8"``#@`0``@P(``.,!``#U`@``S`8`````
M`````````````,X'``#]!@``V````$L&```?````[@```,<!````````,00`
M`$`$````````NP```,8&`````````````%X`````````B`<```````!W!@``
MA@0``)(#```9"```6`(```````"I!P``F0(``!X$``"M!@```````,D$```^
M`@````````0(``!"!````````+,(``!@`P``@00``%``````````````````
M``!Q!P``3@$``(8(````````S@,```````"\!P``@````#0#```N`P``````
M`+`&``!F!P`````````````W`0````````($````````B@``````````````
M:0(```0``````````````),#``!?!@``<P,````````5`@``1`(``"$#````
M`````````%T$``";`@``/P(```````#T`@``H0@`````````````200``,\"
M````````6`@``/`!``!I!```@`$```@"``#!!@```````$`(````````708`
M`!X"``">!```?P,``!D$``#\!@```````)(`````````!`,``,L&``"O`0``
M`````)\```#("```U`,```````"\!`````````````#0`0```@```-D'```(
M`0``?````'H&```&`@``(`@``)0%````````OP8``!H(```/"```I@8``!X`
M```=`0```````*8``````````````!((```_"```U0,``(X#``#Q`@``````
M`'H``````````````)4!``!3`0```````#T```"!`P``304````````Y`P``
ME`(```X#``#H`````@4``$@%````````'P4``&P"``#]!0``QP@``)D'```F
M!```Z04`````````!```8@$``!P%``"S!```.08```````"'`0```````,\&
M`````````````(D$``"@`P``6@$``(D"``!M!0``408``*$&``!"!@``````
M`#0"````````R0<``%,$``"A`P``J@```*X(``#>!P``?`(``$P```!+`@``
M+@```",!``#I`@``J`$```8#```_!@```````*`!````````6P,``$D'``!'
M!0``;`,```````!_!@``(@<``.D!``![`0``V@,``!0&``#J!P``]````)X&
M````````Z@,```````#Y!0``-````)H#````````D@(``(,!````````NP(`
M`$(%````````RP<``"`$`````````````+<'```.!```K@4``'@%````````
M;@8``#L%`````````````($"````````#P0``&<```#.!0``@@@``#4"``#K
M`@``/P0```(#``"$!@``,@,```````"#!0``^08``.\%``!\!0```````-8"
M``"9`P``@`4``(`$```#!0```````#L'```I"```*`4``&@$```R!P``P04`
M`+(&``!E!````P0``-0!``"&````U`<```````#^!```D@@```````#Z!@``
MV@(``'H"``#I!@``V`(``&0!```\!@``4@```#T%``!5`0`````````````\
M!````````$X"```B`0``10```*0!```3!```X@$``+@```!("```````````
M``!3````90```)4````1`0````````H`````````M@,``$H&``!T`0``(0@`
M`%H"````````=08``%(!```]"```%P4``.T$``!$"````````!H'``!.!0``
M^0$``+0$```O!0``0P@``((#`````````````&0(````````0P<``.`#``"A
M!P`````````````Y`0``MP,``",%``#N!P``^0,``/H!``#%`P``N`8``+X"
M```E!@`````````%``!J!P``P@@``````````````````+$$``![`@``@@$`
M`*X'``"I"```N0<``%4'``!U!0``J@<``/4'``!F````2`,``,(!``#@`@``
M(`(``+X!``!-`P``Z@0``#0&`````````````(@"``!H````S08``#D'``"2
M!```40$``'4(```J"```5P$``#X(``"V!@```````.P&``#G`@``RP$``#P(
M``!+`0```````-,!````````S`0``!L%```W!P``EP(``$H```"^!```?`<`
M`'`'```#````E0(``(H"````````,@8``$T&```V`0``-P(``#H"````````
M`````&0#```U!P``Z@$``.D$``"(````3`$```4!``#B````[````+$#``#1
M!0``X0(````````/````#`$```T````0!P``E@$``,T#````````;P$``)`%
M``#V!P``8@@``%8(````````M0$``(<"``"A`@``A````"`!````````````
M````````````004``)4(``##`@```````#,(``!_!`````````````"H`P``
MS0$``),$``"8`@``.0```/`#````````S`,``/,```"^!0``5P4``*0%````
M````P````"`#``!`!@``]P,``&@%``"9````,P$``$`"``"+````N04```0!
M``#A!```108```````!>!@```````-8%``#5!```Q0$```````!>`@``$P4`
M`"D'````````O`8``$0#`````````````/\#````````]0$``#T'``#=!0``
M>P8``'4#```M!```O```````````````$0````````#5!@````````````"^
M!P``6@,``*P```#_`0``UP(``*L(``#!!P``3@0``/4&``"1!@``3`8``'(&
M`````````````((&```A!````````&@"``#8`P``70$``+`(``"\`@``)`$`
M``````!@!P``'@$``%D```"<!0``V@```(<#``"$!```Z0,``(,$````````
M0`$``)@````'!@```````-X%``"."```\P0``"4#```Z!P``40,``*`(``#E
M`0```````"`&```,`P``PP4``/<'```E!0`````````````*!P``T@<``',`
M````````4`0``'<"```7!````````&T"``!L!@```````)P!```?!@``P@8`
M``````":!```W0,```,"```:!0```````#H#`````````````$P#```F`P``
M`````````````````````.0'````````*P<``)P$``"=!````````$0'````
M````UP0``,$(``#%`@`````````````<`P``L`<``&(#````````)`,``"<'
M``!:!```/`$```````#M`0``Q``````````R"```W@```*````!W!0``````
M`+@%`````````````#T&``!I!P```````+H!```.`0``000``+D&```G!0``
MV0```*T`````````P@````8`````````&0(```T!``!D!P``H0```)8&```$
M!```=0$``%4$``"7"```A@(```````#%!@``(0$```L#```X!P``R0$```P%
M``!6`0``704`````````````T@0``/H'``",`@```````+('``!%!0``YP8`
M`&H%``!>`P``^0<``)D$``````````@``(`"``#.`````````/,%````````
MOP```!,&`````````````),(```?`P``!@4``"T#``#R`0``QP,``((%````
M`````````&8!````````50(```````#C!@```````+(```!(!P``:08```@`
M``"!````C0`````````M!@```````````````````````'D!````````(P,`
M```````+`@``R`(``/X&``"@!0``UP,```````"_`0``Q@4``!<`````````
MY00``!@```#N!@``G@4``.8"``!(`````````$D"``!;"```3`<```````#?
M!0``:`@``'<$```-!0```````'D'```V!P``:`<`````````````6P```/\%
M``"3!P```````&X```#0!P``!P@```````#M!P``/0$``$L#``#1!P``````
M``````!5!0``>@$``!,(``"L`@```````%X(````````RP```!L'``!V!0``
M`````#@"````````+@4``,4```"*!P```````'('``!/!@``GP4`````````
M````!P,``-X&```7!P``)@<```````!X`0``'08``%X!````````!P0``,0#
M```J!```O08``(4!```4!0``V@8``&8"``"O!0``,0<``,H'``#;!P``````
M`%$```#T!```:P0``,`#```S!```S`$```````````````````````"4`P``
MU0```#8$````````100``,\#``#<`@``F0$``&4#````````/@,``%$$``#D
M`P``<08`````````````<0$```````".!0```````$<!``"1````[`(`````
M``!1!P``90(``&`&``"L!```F@```)T%`````````````&@#````````````
M``H"`````````````(X!```F`0``P0$``(X````$!P``,04``.H````<`0``
M`````,H!``!&"`````````4'``!G`P```````'T!``#2````)@8``%@'``#3
M!@``#P8```("````````80@``(4&``!N`P```````'@'``#O`0```````*(`
M````````Q00```````!,!```,````,D(``#@!0``%0<`````````````+`4`
M`*X"````````R`0``,0$````````=@,``$P"````````6P4``)`(``"#`P``
MHP(```$#``"[!````````&,(````````,0@``#<`````````#@```$$'``#/
M`0```````*<$`````````````'0'``"(`0``=`8``%D#``!F!@```````)0&
M``"K!0``A0@``-0&``!T!0``2P@```````!(!```HP<```````"/!```````
M`,<%```!!````````&$```!)`P``&`,``#H(````````VP$``,P"``"H````
M9@,``,8$``#X!P``8@(``*T$``#C!```50@``&`(``"?`P``PP``````````
M````P`$```````"#!P``TP4``!T'`````````@<``$$(``!``P``.@$`````
M```_`0``U@,``#D%``"U!@``(@4```D!`````````````$('``"]````OP@`
M``````#"!```:@8``"8%`````````````$$#``!5`P``IP(````````)!P``
M+`@``````````````````+0#````````:0@``!,#``!T`P```0<`````````
M````:0```$0```"V"```'P(``$H%`````````````#\'```O"```_@<``/L!
M``#$!P````````````#B`@``/0(``"@(````````A0```!<&```9`0``T`0`
M`+D!``!8`0``I0````````#_!```PP@```````#2!0```````+4%``"T`0``
M`````&,&``#O````BP8```````##`P``V`$``,@`````````R`$``*,$``!3
M"````````,T"````````'P<``+,#``".`@``L@(```````"Z!0``!`4``*8#
M``!?`0``_P```)L#````````*@4``-L$``!B!```@`,````````E`0``````
M`+T#``"@`@``/@4``"`%``#\`P``PP8``)8%```X!@``(````+,&```P"```
MMP4``'D&``"5`P``S0```/$!``!$`0``>`,``.<'```6!0``H@,``&<%``!"
M`P``*P````````!*"`````````````!5!@``_P(``$D!```<!@```````#8`
M``"X!P```````/('```'!0```````/$``````````````-("``"V`@``+@8`
M`&H#``!U````(@0``(T!``#'!@``'0@``(T"``"+!P```````"<(````````
M`````&X%```\`P````````P``````````````#@```!8!````````.X!````
M````L@@``/(#```Z!```<P0```````"X!```TP<``-$"``"C````F`8`````
M`````````````(\!``````````````````#[!```@P8``(\```#2`P``6P<`
M`+T"``#)`P``S`4``'H%```<`@``;@(``&,"``#K````90@``!0$````````
M``````````#I!P``S`@``%D&````````>P0``/D$```?`0```````'L```"L
M!0``60@``(,```#E`P``>04``````````P```````*D"``"E!0``#0@`````
M```7"`````````X&````````;00``-,$``#F!```]@(``.T`````````G`8`
M``````">!P``W`4``)$(`````````````+D"``#[!@``"0(````````W`P``
M4@8``)\(``!W````````````````````4@<``%,"```)`P``P@<``.4"````
M````;P(``'4'```K!@```````+D$````````*@8```````!,"```0````#,'
M````````1@<``/<````'`0``@@0``"L!````````BP4``,`"```D````?P4`
M``$&```U"```Z@8``'P(``#7!P``$0@``*`&````````1P<``(\(```?!```
MH04``",```!'!```SP4``&L&````````V00````````U````)00``+\'``!/
M`@``(08``"<``````````````+@(``"\`P``T0$``"0'````````&@0``"D!
M``"J`0``]@8``/,'``#*!```#@4``/<&````````N0@``!4$``#9`0``&@8`
M`)(!```9````008``*4&``!P!````````#T$```(`P``DP(``+H#````````
M`````-P!````````_0$``.X"```L!P``T0````````!-"```ZP$``$\'```W
M"```$0(``$@"``````````````@%``"0````20````````!E`0``Q04``.@!
M``"W`@``^@0``'`(```E!P``Y0```#4%```N`@``V@4``.X$``#K!0``````
M`%<&``!C`P``DP4``*,!``#$"```````````````````(@8``"$`````````
M`@@``'(#````````/`4``%<$````````5@,```,(````````/P````8&``!O
M"````````#`#``!M!P``EP$``(L(````````:P@``*X`````````"`<``&`%
M``!?!P``VP4``.8```#X!0```````%$"``#*"```6`4```````#6!```WP$`
M`-`(```5`0``&0<``)\$``"]!P``J00``"L%``"F!P``F`$``'D"``!<!P``
M00$``#L$``"=`P``6P8`````````````_0```$4"``#G`P``70<``(X'``#'
M````;P8``)@$``#@!@``SP0```````````````````````#:`0``K@8``#($
M````````*`,````````:`P```````*\```!O!0``I`,``'X%``!]````4@0`
M``````"&`0``2`$```````"*"````P,```````#V`P``\P,``%8&``"0!```
M%P,``%8%``#M`@``1`0``!4%``#Y`````````"\````V!@``D@<``(T#``!]
M!0``ZP8``&$!```R````:P(``%`!``"<"```30``````````````"P4``&0$
M````````F`,``$D(``!J"```#`<```````#1`P``C`$``!(```#&````````
M`&P%````````F@(``)4&``!0!@```````*D&```T!````````+P(``"_`P``
MI`@```````#D`````````#L"``!&!@````````````"E!```>0```/X"````
M````W00```````!_!P```````)$"````````G@@``!`````B````A`$``)X`
M``"P`@```````%T"``#=!@``J04``*(&````````G`,``$8%``#O!```)`(`
M```````6"```%P$``','``#4`@``^0(````````V`@``G0$``*\'``"<!P``
MB@8``.L$``!M`````````*P#``!H`0``"P@``(@$````````O@@``/L%``"(
M!0``H@(```4```!#!```9P0``-@$``""!P``]`4``-X!``"1!```B`,``"<"
M``"K!`````````````!0`@``UP4``"\#``#>`@``E@@``"4`````````````
M`+````"\`0``W0<``/$'````````4@4``````````````````!D#``#@````
M*0```,,!``#9`@``H0$``+X&``!$!0````````````!'`P``[P,``'("``!Z
M"```AP```(D!``"'!0``````````````````%08````````O`0``*`0``+0(
M````````.`@``)`"```Y!```\@0``.\'````````=`````$(``!$!@``````
M`%P#```U!@```````,(%````````8`$``&\#``#>`P``L@,```X'``#B!P``
M+0```#X$```+!P``8P```(T$````````$`4``)H&````````````````````
M`````````.,```!?!0``[04``%L"````````D`,```````"Z!```I@4``"H#
M``#/"````````#0!``#O!@``H@@``+P%````````U0<```D%````````T08`
M``````"&`P``V@<```\%``"[`P```````*0'``#K!P``WP```&@&``#N`P``
MEP8``#,%````````"`@``&`$``!;`0``NP$``!@"``"K`P``5`8``!8$````
M`````````)D(``#$!@``8````.,"``!.!P``=P@```````!G"```IP@``&<!
M````````3P0``%`'``!_`@``O04```````!=`````````*@(``!K!0``;`$`
M`-L```"G`0``A00``/$%``#=`@``Q`4```````#U!0``800``$H"```3`@``
M*08``",$``"Z"```\08```````"B`0```````!T#``#."````````)T```"[
M!P``70,``-4%``!:!P`````````````E`@```````#H%```<````&08``/0#
M````````DP```+(%``!Y"````````!@$````````ZP,`````````````````
M``````!+!```LP4```````!?`@``*@```.H%``"7!0``^@(`````````````
MT@$``$T$``````````````````"0`0``8@8``*H"````````%`,``'T$``!"
M`0``F@$``&H$``#0!@``;P<``.@#``!)!0``$@0``'T#```V!0``$P$``.<$
M```2`P``6@8````````2!0````````4(``!1!0``FP0`````````````&`8`
M``````#L`0```````%D'``"S`@``F@<```````#3`@``\@8```````"W!@``
M`````"X$``!`!0``#`0``*@&```O`@``3P4``"D"````````8P$````````[
M`0```````'L#``#V`0``Y`$``(T&``!&`@``@`<``&$&```H````.P@``',(
M```'`@```````(D%``!D!0``QP0``*@%````````X`0```D$``#+`P``CP<`
M`+H````H!@``WP8```````!7`@````````<```",`P```````)(&```I`P``
MN@<```T&```@!P```````'X!``!Z!````````-(&```:`@```````)L!```V
M"```7@4````````K`@````````````!M`P```````*X$``!C!````@$``!$$
M``#B!0``XP,``+X#``"S`0``\`8``*T(```G`0``]P0`````````````,0,`
M`%D$```>"````````.$%``!/`0```````)\!``#A`P``2`8``%\(``!&````
M1@0```````"_!```+P<`````````````0P$`````````````CP(``(<'````
M```````````````2`0```````!("``"("```$04```````"=!@``L0<``"T"
M``#X`P````````T$````````0`<``)4$``"E!P````````,'```6````<0``
M`/X!``````````````````!V"````````#`$``#!`P``>@<``"@!``!N"```
M\@4``&P(```6!P``;0@````````8`0``A`(``"T(``"C!0``I`8``!`&````
M````T`````D(``";!P``F08``/L'``";!@``=@(``"@'``!R!0``=00`````
M``!#`P``L`0``&$"```E"```8`(``/H#``!/````&04`````````````_```
M`.0"``"8"```3@,```8!``!4`0``:0,``.@%``"3!@``$@8```T"``"4`0``
M/`````````#X!@```````$\(````````K@,``(D&``"G!@``&`@``/$#```P
M!P``.@```,0"```L````T`4``&D!``"I`P```````,T$``"-"```=`@``&L!
M```(!@``RP@``(4%````````H@0``/T'```J`@``208``%D"``!#!@``I`0`
M``````#;!@``A@8````````!!0``M`8```\'``"1`P````````````"O!@``
M&P8```````#H!P``,`4``'0"````````CP,``%<(``"S!P``/@<`````````
M````V0,``(X&``!E!@``,@$``+H&``"6!P``+04```````!S!0``>`(``%8$
M``````````````D&````````MP@``&4%`````````````*8!``!7!P``R0(`
M`!('``#3`P``4@(````````V`P``QP<``(H$``"&!0``<`8``%P&``"?!P``
MX@8``-4!``!8!@``9P8``+$!``#G````WP<```````#V!0````````````"J
M!@``+`$`````````````;P0``/4``````````````.$!```5"```<`4```L$
M``!6`````````'X"````````!@@``````````````P$``/P%``#R`@``A0(`
M`'8&``#0`@`````````````%`P``,@(``&L'``#7!@``A`<```$"````````
M?`0``),!``"+`@``>P4```````"-!P``P`@``&4'``#C!P``J`0``#L#```4
M````E`@``*,#```A!0``V`8``(L$``````````````T#``"Q````P`4``#@$
M``#E!P``X0<``'$"``!L````=@$``%,%```%!```!04````````4`0``)`@`
M`+$&``#4!0``8@```*@'``#&!P``E@0``/@"``#V!```B@4``/<!```A`@``
MTP```',&```,`@``#@(```````!<"```````````````````C`4``+8!````
M````P0(``,D&``"J!```4P8`````````````<0@``*0"``#W!0``````````
M````````V@0``","```G!@``G@$``%\#``!-`@``@08```````"T`@``````
M``L```!W`P``````````````````?@@``#$&``!?!```JP(`````````````
M,`8``'((``!!`````````-D%``#;`P``[08``$H$``!P`@```````'<'``!4
M!```<@```"D$````````604``+L&````````Y@<``,P`````````KP@``#@#
M``````````````````#.`@``9@0``)@%``!/`P``IP,``,`'```L`P``1@,`
M```"`````````````%P"```W!0``Q@@`````````````````````````````
M-0$``+X```#8!P```````&0"```*!0``N`,```````````````````````"!
M`0``````````````````/@8``($'`````````````!L"``!7`P``G0<``-D&
M``",!```;`<``/0!````````7`0``!$'``#H!@```````/0'``#O`@``-`4`
M``@$```*!@``CP8``,8"``!O`````````*8"``"["```BP,``(`(```_!0``
MA`@``)P`````````:@```#,#````````M00```````#L`P``#@@``%@#````
M````5@(``(H!```%`@``````````````````9P(```P&``#?`P``'P@``*X!
M``"U````+@$``#L```";`````````*('```1`P```````%H(````````Y04`
M`%L$``!V````-P8``'\!``!."```F@@``.8!````````'0(``.8%```0"```
M%`@``/P$``!:````+`8``$,"``!.`````````.D`````````70@``#X`````
M``````````````#5`@``E0<`````````````-`@````````8!0``RP4``%0"
M````````'`<```````"`!@```````,H&```Z!@``M@4```L!````````X`<`
M`/P"``!"`@``9``````````X`0``]00``'\(``"@!```<@0``!<"```5`P``
M(P<``"<#``!0"```>`0```````!3`P``:P,``&,'``!:!0``2P```'(!```+
M!@``U@$``((```#P!P``7@<``````````````````,<"``"Z`@``5````$H'
M`````````````!0'``#]!```0@```/0&``#B`P``)`0```````#%!P``30$`
M``````#Z`````````*P'``#L!P``,P`````````M`0``R@4``-<!````````
M`````*(%``".!````````+`%````````?P```,8#`````````````.<!````
M``````````<'````````2P4``"0&```O!@```````'T'``!2"```W`,``(0#
M``!<!0``)`4``/,&````````L@$```````"T!0```````'8'````````````
M`+`#`````````````/\'``"?`@```````.$`````````D0$``!8#``!N`0``
M!@0``(<&``"P`0``R@(``(L!``````````````````"V!P``?0@``&X'````
M```````````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E
M<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T
M(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B
M('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R
M96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*0`E9"`E<R!A;F0@)7,`)60@8V%L96YD87)S(&9O=6YD`"5D(&1A>7,@
M=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"!E=F5N=',`)60M9&%Y
M(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($1A>2AS*2`E<R!(;W5R*',I("5S
M($UI;G5T97,`)7,@1FEN9V5R<')I;G0`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@871T96YD965S`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D
M`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`
M)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O
M("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G
M<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z(%1H:7,@;65S<V%G92!M87D@
M;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F
M;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`H0VQI8VL@
M;VX@8V%L96YD87(@;F%M92!T;R!S=VET8V@@=&AE(&-A;&5N9&%R)W,@=FES
M:6)I;&ET>2!I;B!T:&4@;6%I;B!W:6YD;W<I`"H@061D('1H97-E(&)Y(&-L
M:6-K:6YG($%D9"`J`"H@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@
M9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`M+2!S96QE8W0@+2T`,2!A='1E;F1E90`Q(&5V96YT`#$@:&]U<@`Q
M,B!(;W5R($9O<FUA=``Q-2!M:6YU=&5S`#(P(&UI;G5T97,`,C0@2&]U<B!&
M;W)M870`,C0@:&]U<G,`,S`@;6EN=71E<P`\4')E=FEO=7,`/'-T<F]N9SY!
M='1E;F1E97,\+W-T<F]N9SX@*&]P=&EO;F%L*0`\<W1R;VYG/D1E<V-R:5]P
M=&EO;CPO<W1R;VYG/B`H;W!T:6]N86PI`#QS=')O;F<^2V5Y=V]R9',\+W-T
M<F]N9SX@*&]P=&EO;F%L*0`\<W1R;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@
M*&]P=&EO;F%L*0!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R
M('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO
M=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@
M961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97!T960`
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`
M061?=F%N8V5D(%-E87)C:`!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL
M9"!097)M:7-S:6]N`$%D9"!%=F5N=`!!9&0@2&5R93H`061D($YE=R!'<F]U
M<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S
M(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W(%)E
M;6]T92!#86QE;F1A<@!!9&0@82!N97<@979E;G0`061D(&$@;F5W('5S97(Z
M`$%D9"!A='1E;F1E97,`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!A='1E;F1E97,`061D('1O(&UY
M(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S
M<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F
M;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%D=F%N8V5D(%-E
M87)C:`!!9F=H86YI<W1A;@!!;&%R;0!!;&%R;2`E9"!D87ES(&)E9F]R90!!
M;&%R;2`E9"!H;W5R<R!B969O<F4`06QA<FT@)60@;6EN=71E<R!B969O<F4`
M06QA<FT@)60@=V5E:W,@8F5F;W)E`$%L87)M(#$@9&%Y(&)E9F]R90!!;&%R
M;2`Q(&AO=7(@8F5F;W)E`$%L87)M(#$@;6EN=71E(&)E9F]R90!!;&%R;2`Q
M('=E96L@8F5F;W)E`$%L87)M($1A=&4`06QA<FT@4W!A;B`H;6EN=71E<RD`
M06QA<FT@5&EM90!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM
M96YT.@!!;&P`06QL($%T=&5N9&5E<P!!;&P@075T:&5N=&EC871E9"!5<V5R
M<P!!;&P@1G5T=7)E`$%L;"!'<F]U<',`06QL(%!A<W0`06QL(%!E<FUI<W-I
M;VYS`$%L;"!6:7-I8FQE`$%L;"!D87D`06QL(&1A>2!E=F5N=`!!;&P@979E
M;G1S`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X
M:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S
M=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@
M861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!
M;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA
M`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!
M;G1I9W5A(&%N9"!"87)B=61A`$%N>0!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO
M;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3
M:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H
M5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`
M07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T
M92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`
M07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA
M;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF
M:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_
M`$%S<VEG;FUE;G0@8V]L=6UN<P!!=`!!='1A8VAE9"!I<R!A;B!I0V%L96YD
M87(@9FEL92!W:71H(&UO<F4@:6YF;W)M871I;VX@86)O=70@=&AE(&5V96YT
M+B!)9B!Y;W5R(&UA:6P@8VQI96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@
M>6]U(&-A;B!U<V4@=&AI<R!F:6QE('1O(&5A<VEL>2!U<&1A=&4@>6]U<B!L
M;V-A;"!C;W!Y(&]F('1H92!E=F5N="X`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N`$%T=&5N9&%N8V4`071T96YD965S`$%T=')I8G5T97,`075G
M=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A
M=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A
M:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA
M8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N
M9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D
M(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)
M4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F%S:6,@4V5A
M<F-H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T
M86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO
M="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV
M:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S
M`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`
M0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI
M<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0G5S>0!#35,`0U)#`$-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S`$-?86QE;F1A<@!#7V5L;"!0<F]P97)T:65S+BXN
M`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;%]E;F1A<@!#86QE
M;F1A<@!#86QE;F1A<B!3=6UM87)Y`$-A;&5N9&%R('-U8V-E<W-F=6QL>2!P
M=7)G960N`$-A;&5N9&%R<P!#86QE;F1A<G,@;75S="!H879E(&$@;F%M92X`
M0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D
M(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X
M=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!
M4"!S97)V97(Z("5S`$-A;B=T(&-R96%T92!A(&YE=R!E=F5N="X`0V%N)W0@
M;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;F-E;&QE9`!#86YC96QL960Z("5S`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E
M9V]R7WD`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A=&5G;W)Y`$-A>6UA;B!)
M<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E
M;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A
M=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI
M8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O
M<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&EF
M('EO=2!W86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@
M9&5L971E9"!E=F5N=',@8GD@96UA:6PZ`$-H;V]S92!I9B!Y;W4@=V%N="!T
M;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E
M;G1S+@!#:&]O<V4@:68@>6]U('=A;G0@=&\@<F5C96EV92!E;6%I;"!R96UI
M;F1E<G,@9F]R(&5V96YT<R!W:71H(&%L87)M<SH`0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D<F5S
M<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.@!#:&]O<V4@
M=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E(&EN('EO=7(@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N.@!#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E('=H
M96X@9V5N97)A=&EN9R!F<F5E+V)U<WD@55),<SH`0VAO;W-E('EO=7(@9&5F
M875L="!C86QE;F1A<BX`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET
M:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G
M<P!#;&5A<B!1=65R>0!#;&5A<B!A;&P@871T96YD965S`$-L96%R(&]U="!U
M<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,
M871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO
M<V4@5VEN9&]W`$-L;W-E('=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L
M;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R
M`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA('-E<&%R871E9"!V86QU97,`0V]M;6%N9`!#;VUM86YD(%-H96QL
M`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R
M<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R
M='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9FER;2!D
M96QE=&EO;B!O9B!E=F5N=',_`$-O;F9I<FUE9`!#;VYG;P!#;VYG;RP@5&AE
M($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D
M+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O
M;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B
M)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A
M:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]P>2!T:&4@55),(&)E;&]W(&9O
M<B!U<V4@=VAE<F5V97(@>6]U(&YE960@>6]U<B!&<F5E+T)U<WD@55),.@!#
M;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E
M.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO
M="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N
M("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG
M($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD
M(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@
M;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO
M="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET
M:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A
M:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U
M;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S
M<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N
M("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD
M:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T
M('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H
M97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A
M8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E
M<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@
M9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B
M87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T
M97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E($-A;&5N9&%R`$-R
M96%T92!A($YE=R!%=F5N=`!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O
M;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S
M:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0`
M0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM
M90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE
M<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C
M=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O
M=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E
M<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`
M1&%I;'DZ(%)E8W5R<R!E=F5R>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E
M($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y
M`$1A>2AS*0!$95]L971E`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM
M86P@;G5M8F5R<P!$96-L:6YE9`!$96-R96%S92!);F1E;G0`1&5F875L=`!$
M969A=6QT($-A;&5N9&%R`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@)7,`
M1&5L971E($-E;&P`1&5L971E($5V96YT`$1E;&5T92!'<F]U<`!$96QE=&4@
M3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@
M86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E<P!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`1&5L971E('1H
M92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL
M>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L
M(&]R(&%L;"!O8V-U<F5N8V5S/P!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E
M;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM
M90!$96YM87)K`$1E<V-R:5]P=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$
M97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I
M<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!#86QE;F1A<G,`1&ES<&QA>2!/
M<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E
M8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC
M871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@
M86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!S:&]W('1A
M<VMS('=H:6-H(&%R92!D=64@;VX@>6]U<B!C86QE;F1A<C\`1&]E<R!N;W0@
M<F5C=7(`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC
M86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$
M;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!$
M=64Z("5S`$1U<F%T:6]N`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D
M<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC
M92X`15)2`$5C=6%D;W(`161I=`!%9&ET("5S`$5D:70@071T96YD965S`$5D
M:70@0FQO8VL`161I="!#86QE;F1A<G,`161I="!'<F]U<`!%9&ET(%!E<FUI
M<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET(%)E;6]T92!#86QE;F1A<G,`161I="!A='1E;F1E97,`161I="!C
M871E9V]R:65S(&%N9"!C;VQO<G,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%
M9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%
M;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S
M96%R8V@@=&5R;7,`16Y?9`!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F
M<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/P!%;F0@1&%T90!%;F0@3VX`16YD(%1I;64`16YD
M('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O
M<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN
M8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O
M<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R(')E=')I979I;F<@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<SH@)7,`17)R;W(@=7!D871I;F<@<&%S
M<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I
M=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E
M;G0@861D960Z`$5V96YT(&1E;&5T960Z`$5V96YT(&5D:71E9#H`179E;G0@
M9G)O;2`E<R!T;R`E<P!%=F5N="!N;W0@9F]U;F0`179E;G1S(&UU<W0@:&%V
M92!A('-T87)T(&1A=&4N`$5V96YT<R!M=7-T(&AA=F4@82!T:71L92X`179E
M<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD
M<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R
M`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`
M17AP86YD($YA;65S`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I
M;VX@1&%T90!%>'!O;F5N=`!%>'!O<G0`17AP;W)T($-A;&5N9&%R`$9'($-O
M;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E
M9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&
M86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P
M>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T
M;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@
M=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD
M($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R
M.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``
M1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG
M;&5T($-!4%1#2$$`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R<P!&:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1
M=6%R=&5R`$9I>"!R871I;P!&;&EP`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O
M<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`
M1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R
M;W!O;&ET86X`1G)E90!&<F5E+T)U<WD@26YF;W)M871I;VX`1G)E;F-H($=U
M:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<P!&<FED87D`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$9U='5R90!'86)O;@!'86QL97)Y('1O('1A
M:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V%M90!'96YE<F%L`$=E
M;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I
M80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/
M<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=O
M=&\@)7,`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E
M96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M
M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D
M9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R
M;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P
M90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'
M=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA
M>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE
M:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E
M`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&ED90!(:61E
M("5S`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`
M2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(
M;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E
M<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E
M<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N
M=&%L.@!(;W5R*',I`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E
M<&]R="$I`$AO=R!L;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T:&4@
M9&%Y(&%N9"!W965K('9I97=S(&)E/P!(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!D87ES(&]F(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B!S:&]U;&0@=V4@9V5N97)A=&4_`$AO=R!M86YY(&9I
M96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R
M:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D
M<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E
M<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S
M`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO
M="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W
M('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT
M97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O
M>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H
M:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T
M;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`
M268@>6]U<B!E;6%I;"!C;&EE;G0@9&]E<VXG="!S=7!P;W)T(&E4:7`@<F5Q
M=65S=',@>6]U(&-A;B!U<V4@;VYE(&]F('1H92!F;VQL;W=I;F<@;&EN:W,@
M=&\@86-C97!T(&]R(&1E8VQI;F4@=&AE(&5V96YT+@H*5&\@86-C97!T('1H
M92!E=F5N=#H*)7,*"E1O(&%C8V5P="!T:&4@979E;G0@=&5N=&%T:79E;'DZ
M"B5S"@I4;R!D96-L:6YE('1H92!E=F5N=#H*)7,`26UA9V4@4')E=FEE=SH`
M26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E
M(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@0V%L
M96YD87(L(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@
M0V%L96YD87(`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`
M26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S
M97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R
M="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?
M0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E
M<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M
M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`
M26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R
M90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T
M:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`
M26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@
M9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!)
M;G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D
M9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME
M>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP
M92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S
M:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN
M=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L
M:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@
M<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@
M=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA
M;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L
M>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0
M*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N
M=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+
M87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y
M($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E
M`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N`$ME>7=O<F1S`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F
M`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA
M;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@
M,C0@:&]U<G,`3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S="!-;VYT:`!,
M87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D
M.@!,87-T(%EE87(`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87-T('=E96L`3&%T=FEA`$QA=P!,
M87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`
M3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$
M<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN
M($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UI="!T:&4@=&EM
M92!S<&%N('1O(&5X<&]R=#H`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI
M<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S
M8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E
M<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;U]C871I;VX`3&]A9&EN9RXN+@!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@
M<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S
M:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,
M;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L
M871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-
M30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`
M35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U
M8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME
M(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A
M`$UA;F%G92!R96UO=&4@8V%L96YD87)S+@!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R
M-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R
M9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H
M97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)
M<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`
M36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R
M=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!%=F5N=',`36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-
M87D`36%Y;W1T90!-90!-961I8VEN90!-965T:6YG`$UE;6)E<G,`365N=2!!
M;&%R;7,`365N=2!,:7-T`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G
M90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G
M92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@
M(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE
M9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A
M<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI;G5T92AS*0!-:7)R
M;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E
M<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N
M97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T
M:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE
M($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L
M=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F1A>0!-;VYG;VQI
M80!-;VYT:`!-;VYT:"!6:65W`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N
M=&AL>2!%=F5N=',@3&ES=`!-;VYT:&QY.B!296-U<G,@979E<GD`36]N=&AS
M($%H96%D`$UO;G1H<R!"969O<F4`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-
M;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D
M("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L
M>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@:4-A;&5N
M9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S=7!P
M;W)T960N`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U
M;G0@26YF;W)M871I;VX`37D@0V%L96YD87)S`$UY($-A;&5N9&%R<SH`37D@
M1G)E92]"=7-Y(%523`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N
M;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P
M86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@
M0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2
M979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T
M>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`
M3F5W($5V96YT`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R
M;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!C86QE;F1A<B!C<F5A
M=&5D(&%N9"!A=71O;6%T:6-A;&QY('-H87)E9"!W:71H(&9O;&QO=VEN9R!G
M<F]U<"AS*3H@)7,N`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E
M>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W
M:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`R-"!H
M;W5R<P!.97AT(#0@4&AA<V5S`$YE>'0@1&%Y`$YE>'0@36]N=&@`3F5X="!7
M965K`$YE>'0@665A<@!.97AT(&1A>0!.97AT(&]P=&EO;G,`3F5X="!W965K
M`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`
M3F\@86QA<FT`3F\@871T96YD965S`$YO(&%V86EL86)L92!C;VYF:6=U<F%T
M:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E
M;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+@!.;R!C86QE;F1A<G,@87)E(&%V86EL86)L92!T;R!G=65S
M=',N`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO
M(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@96YD
M(&1A=&4`3F\@979E;G1S('1O(&1I<W!L87D`3F\@9FEL92!U<&QO861E9`!.
M;R!F<F5E+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE(&9O<B`E<P!.
M;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N`$YO(&EC;VYS(&9O=6YD+@!.
M;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M
M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R
M('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN
M`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.
M;R!R96-U<G)E;F-E`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N
M`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QI
M9"!E;6%I;"!A9&1R97-S(&9O=6YD`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU
M<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L
M86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O
M<GD`3F]T(&9O=6YD`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P
M<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T
M:69I8V%T:6]N<P!.;W9E;6)E<@!.;W<`3G5M8F5R`$YU;6)E<B!O9B!C:&%R
M86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E
M<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N
M(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R
M`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@
M;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@
M:7,@;F]T(&-O<G)E8W0N`$]M86X`3VX@86QL(&-A;&5N9&%R<R!)(&AA=F4@
M<F5A9"!A8V-E<W,@=&\`3VX@86QL('-H;W=N(&-A;&5N9&%R<P!/;B!M>2!C
M86QE;F1A<G,@;VYL>0!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W
M`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S
M:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA;`!/<'1I;VYA;"!!='1E
M;F1E97,`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]V97)V:65W`$]W;F5R
M`$]W;F5R(%!E<FUI<W-I;VYS`$]W;F5R.B`E<P!004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$
M:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI
M8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!032!,
M:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@
M4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!4
M97)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A
M<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E
M9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R
M97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W
M:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R
M9',@;75S="!M871C:"X`4&%S="!%=F5N=',@3&ES=`!087-T90!087-T92!F
M<F]M(&-L:7!B;V%R9`!0871H`%!A='1E<FX`4&5N9&EN9R!3:6=N=7!S.@!0
M96]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M
M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI
M<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`
M4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT
M:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O
M<G1A;"!/<'1I;VYS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E
M<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=P!0<F5V:6]U<R!$87D`4')E=FEO=7,@5V5E:P!0<F5V:6]U<R!D87D`
M4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0
M<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E
M>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y
M($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`
M475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L
M96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`
M4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T
M:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296-U<B!5;G1I;`!296-U<G)E;F-E`%)E8W5R<F5N8V4@1&%T
M80!296-U<G)E;F-E($5N9"!$871E`%)E8W5R<F5N8V4@26YT97)V86P`4F5C
M=7)R96YC92!4>7!E`%)E8W5R<R!D86EL>0!296-U<G,@;6]N=&AL>0!296-U
M<G,@=V5E:VQY`%)E8W5R<R!Y96%R;'D`4F5D;V5S('EO=7(@;&%S="!A8W1I
M;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F
M<F5S:"!0;W)T86P@5FEE=SH`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D
M`%)E;6%R:W,`4F5M:6YD97(Z("5S`%)E;6]T92!#86QE;F1A<G,`4F5M;W1E
M($-A;&5N9&%R<SH`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%-U8G-C<FEP=&EO
M;B!54DP`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ`%)E;6]V90!296UO=F4@)7,`4F5M;W9E($%T=&5N9&5E`%)E;6]V92!"
M;&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P
M86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E
M<&QA8V4@97AI<W1I;F<@8V%L96YD87(@=VET:"!T:&4@:6UP;W)T960@;VYE
M/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@9&5L971E<R!A;&P@96YT<FEE<R!I
M;B!Y;W5R(&-U<G)E;G0@8V%L96YD87(N/"]S=')O;F<^`%)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E
M<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D($%T=&5N9&5E<P!297%U:7)E9"!&:65L9`!297-E
M=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<V5T('1O
M($1E9F%U;'1S`%)E<W!O;G-E`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S
M`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO
M;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O
M7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A
M=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E
M<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y
M<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE
M<W-A9VEN9P!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!3
M54-#15-3`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`
M4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6
M:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`
M4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL
M:71E(%!R;W9I9&5R`%-A='5R9&%Y`%-A=61I($%R86)I80!3879E`%-A=F4@
M(B5S(@!3879E("5S`%-A=F4@07,@3F5W`%-A=F4@071T96YD965S`%-A=F4@
M179E;G0`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M
M<P!38VEE;F-E`%-E87)C:`!396%R8V@@0V%L96YD87)S`%-E87)C:"!%;F=I
M;F5S`%-E87)C:"!297-U;'1S`%-E87)C:"!F;W(@8V%L96YD87)S(&-O;G1A
M:6YI;F<Z`%-E;&5C="!&:6QE<P!396QE8W0@82!C86QE;F1A<B!T;R!E9&ET
M`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A
M(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A
M9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L
M96-T(&%N(&]B:F5C=`!396QE8W0@8V%L96YD87)S('1O(&1I<W!L87DZ`%-E
M;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L87D@=&AE
M(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E(&1E9F%U;'0@=FEE=RX`4V5L
M96-T(&YO;F4`4V5L96-T('1H92!C86QE;F1A<B!T;R!I;7!O<G0@=&\Z`%-E
M;&5C="!T:&4@8V%L96YD87(H<RD@=&\@97AP;W)T(&9R;VT`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T
M('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F:7)S="!W965K9&%Y
M.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE
M('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE
M8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W.@!396QE8W0@=&AE('9I97<@=&\@
M9&ES<&QA>2!O;B!S=&%R='5P.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H92!P;W)T86PN
M`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E
M;F0@82!C86YC96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E;F1E97,@=VAE
M;B!D96QE=&EN9R!T:&ES(&5V96YT`%-E;F0@86X@96UA:6P@=&\@)7,`4V5N
M9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S
M879I;F<@=&AI<R!E=F5N=`!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!3
M97)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I
M;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!E;F0@9&%T90!3970@
M;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I
M9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!R96-U<G)E;F-E(&5N9"!D871E
M`%-E="!S=&%R="!D871E`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!F
M<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H97(@=7-E
M<G,G(&9R964O8G5S>2!O<'1I;VYS+@!3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F4@
M;F]T(&9O=6YD.B`E<P!3:&%R960@0V%L96YD87)S`%-H87)E9"!#86QE;F1A
M<G,Z`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!#86QE;F1A
M<@!3:&]W(&-A=&5G;W)Y(&QE9V5N9#\`4VAO=R!D96QE=&4L(&%L87)M+"!A
M;F0@<F5C=7)R96YC92!I8V]N<R!I;B!C86QE;F1A<B!V:65W<S\`4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&1U92!T87-K<R!I
M;B!T:&4@8V%L96YD87(_`%-H;W<@9G)E92]B=7-Y(&QE9V5N9#\`4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]N;'D@979E
M;G1S('1H870@:&%V92!A;B!A;&%R;2!S970_`%-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!S:&%R960@8V%L96YD87)S
M('-I9&4M8GDM<VED93\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R
M/P!3:&]W('1A<VMS('5S:6YG(&-A=&5G;W)Y(&-O;&]R<S\`4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:6UE(&]F(&1A>2!B
M971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_`%-H;W<@=7!L;V%D`%-H
M;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T
M:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`
M4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O
M<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N
M;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L
M>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@
M)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3
M;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H
M97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E
M<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C
M:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%?<G0`4W1A;F1A<F0`4W1A
M<B!4<F5K`%-T87)T($1A=&4`4W1A<G0@3VX`4W1A<G0@5&EM90!3=&%R="!Y
M96%R`%-T871?=7,`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@
M9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI
M<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`
M4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI
M=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E
M96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A
M9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@
M9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U
M;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`
M4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;F1A>0!3=6YN>0!3=6YR:7-E
M`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P
M97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N
M9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC
M(&QO9R!D96QE=&5D`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER
M:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4
M+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0
M<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O
M=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP
M(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E
M;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA
M=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E
M;G1A=&EV90!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`
M5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($5D:70@071T96YD965S('-C
M<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N="X@17AI=&EN9RX`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M
M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED
M92!O;FQY`%1H92!C86QE;F1A<B`B)7,B(&-A;FYO="!B92!D96QE=&5D+@!4
M:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!C<F5A=&5D+@!4:&4@8V%L96YD
M87(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@8V%L96YD87(@(B5S(B!H
M87,@8F5E;B!R96YA;65D('1O("(E<R(N`%1H92!C86QE;F1A<B`B)7,B(&AA
M<R!B965N('-A=F5D+@!4:&4@8V%L96YD87(@8V]U;&0@;F]T(&)E('!U<F=E
M9#H@)7,`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N
M`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BX`5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@
M<W1A<G0@9&%T92X`5&AE(&5V96YT("(E<R(@:&%S(&)E96X@861D960@=&\@
M(B5S(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%1H92!E=F5N
M="`B)7,B(&AA<R!B965N(&1E;&5T960@9G)O;2`B)7,B(&-A;&5N9&%R+"!W
M:&EC:"!W87,@;VX@)7,@870@)7,N`%1H92!E=F5N="`B)7,B(&AA<R!B965N
M(&5D:71E9"!O;B`B)7,B(&-A;&5N9&%R+"!W:&EC:"!I<R!O;B`E<R!A="`E
M<RX`5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@<W5C8V5S<V9U
M;&QY('-E;G0N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M`%1H92!F;VQL;W=I;F<@:7,@82!M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N
M(&]F('1H92!E=F5N=#H`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K
M87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y
M+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W
M<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET
M)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O
M=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V
M92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@
M=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT
M:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E
M(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@
M9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S
M86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@
M=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE
M(')E<75E<W0@=V%S(&EN8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T
M(&%R92!N96-E<W-A<GD@=&\@86-C97!T(&]R(&1E8VQI;F4@86X@979E;G0@
M87)E(&UI<W-I;F<N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H
M92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE
M('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O
M<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E
M;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`
M5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N
M;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I
M;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E
M9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H
M96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!E
M=F5N=',@;6%T8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N`%1H97)E(&%R
M92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ
M("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S`%1H
M97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R
M92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W
M87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<SH@
M)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R
M="X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F
M)RX`5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H
M:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@
M;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<P!4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1H=7)S9&%Y
M`%1I8VME=',`5&EM90!4:6UE(%-P7V%N`%1I;64@5')A8VMI;F<`5&EM92!F
M;W)M870`5&EM92!S96QE8W1I;VX`5&EM92!S<&%N`%1I;6]R+4QE<W1E`%1I
M=%]L90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(
M5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O
M<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A
M9V\`5')U92!O<B!F86QS90!4=0!4=65S9&%Y`%1U;FES:6$`5'5R:V5Y`%1U
M<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I
M8V]S($ES;&%N9',`5'5V86QU`%1Y<&4`5'EP92!Y;W5R(&-H;VEC93H@`%4N
M5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S
M=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S
M(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S`%5N86)L92!T;R!D
M96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T
M;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R
M86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E
M9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O
M(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92`B)7,B.B`E<P!5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R971R:65V
M92!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S`%5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@
M<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E
M<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`
M56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T
M871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI
M=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W
M;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R
M:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E
M('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E
M;G0M5'EP93H@)7,`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&1A=&5D.B`E<RX`
M57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A
M<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L
M871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@
M0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T
M(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@
M26YT97)F86-E`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E
M<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S
M(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S
M(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!6
M86QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S
M`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z
M=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H
M879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R
M;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`
M5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E
M<P!6:65W($1A>0!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@
M)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N
M4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA
M(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@
M1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI
M;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@
M8GD`5V5B`%=E8B!3:71E`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E:RAS
M*0!7965K;'D`5V5E:VQY.B!296-U<G,@979E<GD`5V5L8V]M90!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E
M<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R
M86-T97(_`%=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S(&5N
M9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S/P!7:&%T('1I;64@
M<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A
M<F4@;F\@96%R;&EE<B!E=F5N=',_`%=H97)E:7,@075S=')A;&EA(&UA<`!7
M:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET
M`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN
M;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!7;W)K(%=E96L`5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!9
M65E9`%EA:&]O(2!M87``665A<@!996%R;'D`665A<FQY.B!296-U<G,@979E
M<GD`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$
M12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE3
M25=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&5V96YT<RX`66]U(&%R92!N;W0@86X@871T96YD964@;V8@
M=&AE('-P96-I9FEE9"!E=F5N="X`66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"X`66]U(&-A;B!O;FQY('5S92!T:&ES(&9O<FT@9G)O;2!T:&4@161I="!!
M='1E;F1E97,@<V-R965N+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E(&%N(&5M86EL(&%D9')E
M<W,@8V]N9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T:6]N($]P
M=&EO;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F;W)E(&5V96YT
M(&YO=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N`%EO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N`%EO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@=&AE('-E;&5C=&5D(&-A
M;&5N9&%R+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!D96QE=&4@
M=&AI<R!E=F5N="X`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@961I
M="!T:&ES(&5V96YT+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H
M879E('-P96-I9FEE9"!A;B!I;G9A;&ED(&-A;&5N9&%R+@!9;W4@:&%V92!S
M=6-C97-S9G5L;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT
M+@!9;W4@:&%V92!S=6-C97-S9G5L;'D@9&5C;&EN960@871T96YD96YC92!T
M;R!T:&ES(&5V96YT+@!9;W4@:&%V92!T96YT871I=F5L>2!A8V-E<'1E9"!A
M='1E;F1E;F-E('1O('1H:7,@979E;G0N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@82!C86QE;F1A
M<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F
M:7)S="X`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W
M:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A
M=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P
M:&]N92!N=6UB97(`66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N
M(&5V96YT<R!A<F4@861D960@=&\@>6]U<B!C86QE;F1A<G,N`%EO=2!R97%U
M97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&1E;&5T960@
M9G)O;2!Y;W5R(&-A;&5N9&%R<RX`66]U(')E<75E<W1E9"!T;R!B92!N;W1I
M9FEE9"!W:&5N(&5V96YT<R!A<F4@961I=&5D(&EN('EO=7(@8V%L96YD87)S
M+@!9;W4@<F5Q=65S=&5D('1O(&)E(')E;6EN9&5D(&%B;W5T("5S+"!W:&EC
M:"!I<R!O;B`E<R!A="`E<RX`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D
M+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R
M($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C
M8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I
M;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO
M0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z
M`%EO=7(@9&5F875L="!C86QE;F1A<@!9;W5R(&1E9F%U;'0@:61E;G1I='D@
M:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R
M(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@
M<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C
M:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S
M=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@
M<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6TAI
M9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D
M(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;56YN86UE
M9"!E=F5N=%T`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?06QA
M<FT`7T)A<VEC(%-E87)C:`!?0TQ)`%]$96QE=&4@4F]W`%]%9&ET`%]';W1O
M`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%
M>'!O<G0`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7TUY($-A
M;&5N9&%R<P!?3F5W($5V96YT`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I
M;G0`7U)E;6]V92!,:6YK+BXN`%]396%R8V@`7U-E='5P`%]486)L92!0<F]P
M97)T:65S+BXN`%]4;V1A>0!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E
M92!U;FMN;W=N`&)E9F]R92!T:&4@979E;G0@<W1A<G1S`&-A;&5N9&%R`&-A
M;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U
M=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U
M<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T
M82!F;W)M870@97)R;W(`9&%Y`&1A>2AS*0!D87ES`&5D:70`96YT<GD@;F]T
M(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M`&=U<W1I;F<`:#H`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN<'5T
M+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`
M;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UO;G1H
M*',I`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`
M;F]T97!A9`!O;B`E<R!A="`E<P!O;B!T:&4@<V%M92!D871E`&]N('1H92!S
M86UE('=E96MD87D`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A
M:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T
M96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YN86UE9`!U
M<V5R('-E;&5C=`!V0V%R9`!V179E;G0@;F]T(&9O=6YD+@!W.@!W965K`'=E
M96LH<RD@;VXZ`'=E96MS`'EE87(H<RD`4')O:F5C="U)9"U697)S:6]N.B!+
M<F]N;VQI=&@@,BXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$W(#$P.C`P
M*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ."`Q,#HT-"LP,3`P
M"DQA<W0M5')A;G-L871O<CH@3&%S>FQO($PN(%1O<FYO8VD@/'1O<FQA<WI`
M>&5N:6$N<V]T92YH=3X*3&%N9W5A9V4M5&5A;3H@2'5N9V%R:6%N(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R!N87!P86P@97IE;/5T="D`
M("A!;'0M8FEL;&5N='G[("5S*0`@*"5S(&YA<"!M^FQV82D`("AM82D`("AH
M;VQN87`I`"`H=&5G;F%P*0`@.B``(B5S(B!N96T@86QK]FYY=G3A<BX`(B5S
M(B!N96T@Z7)VZ6YY97,@=N%L87-Z=.%S+@`B)7,B(&YI;F-S(&MO;F9I9W5R
MX6QV82!A($AO<F1E(%)E9VES=')Y8F5N+@`B)7,B(&9A<W1R=6MT^G)A+6UE
M9VIE;&5N[73U(&YE;2!T86SA;&AA=/,N`"(E<R(M="!H;WIZX6%D='5K(&$@
M8W-O<&]R=&]K:&]Z+@`B)7,B+70@:&]Z>N%A9'1U:R!A(&IO9V]S=6QT<^%G
M:2!R96YD<WIE<FAE>BX`(B5S(BUT(&YE;2!H;WIT=6L@;.ET<F4Z("5S+@`E
M+C)F34(@9F5L:&%S>F[A;'0@82`E+C)F34(@;65G96YG961E='1B]6P@*"4N
M,F8E)2D`)60@)7,@Z7,@)7,`)60@;F%P=.%R="!T86SA;'1U;FL`)60@;F%P
M(&WZ;'9A(&QE:N%R(&IE;'-Z87;A;F%K(.ER=NEN>65S<^EG92X`)60@96QF
M;V=L86QT<^%G`"5D(&YA<&]S(&5L]7)E:F5L>NES`"5S("T@1FEG>65L;65Z
M=&5TZ7,`)7,@;F%P("5S(/-R82`E<R!P97)C`"5S(&QE;GEO;6%T`"5S(&MA
M<F)A;G1A<G3A<VD@9F5L861A=&]K("T@;65G97+U<^UTZ7,`)7,@8F7A;&SM
M=.%S`"5S(&QO9VEN(&[I=B!I9^EN>6SI<P`E<R!S>F]L9^%L=&%TX7-I(&9E
M;'3I=&5L96L`02`B)7,B(&YE=OL@X6QL;VWA;GD@;>%R(&SI=&5Z:6LN`"5S
M(#H@)7,@)7,`)7,@<NES>G1V97;U`$$@)7,@9N%J;"!I;7!O<G3A;.%S82!S
M:6ME<F5S96X@;65G=/9R=.EN=`!!*'HI("5S(&OI<WIE;B#A;&P@87H@86SA
M8F)I(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K(&5L=NEG>NESZ7)E+DIE;/9L
M:F4@:VD@87IO:V%T(&$@9F5L861A=&\H:V$I="P@86UI*&ME*70@;6]S="!E
M;"!K[7;A;B!VZ6=E>FYI+@`E<R!K:73V;'3I<V4@<WK\:W/I9V5S`"5S('!E
M<F,`)7,@;F5M('1A;.%L:&%T\RX`)7,@+2`E<R`H]G-S>F5S96X@)7,I`"5S
M(&/M;6IE9WEZZ6ME`"5S(&YA<'3A<F$`)7,@9F5L:F5G>7KI<V5I`"5S(&9E
M;&%D871L:7-TX6IA`"5S.B!,96AE='/I9V5S+"!H;V=Y(&5Z(&$@;&5VZ6P@
M=F%L\VKA8F%N(&YE;2!A(&UE9V%D;W1T(&9E;&%D\W3S;"!S>N%R;6%Z:6LN
M($=O;F1O;&IA(&UE9RP@;6EE;/5T="!RX6MA='1I;G0@=F%L86UI<F4L('9A
M9WD@<WIE;>EL>65S(&EN9F]R;>%C:?-T(&%D(&UE9RX`*$MA='1I;G1S;VX@
M82!N87!TX7(@;F5VZ7)E+"!A(&;U86)L86MB86X@=F%L\R!M96=J96QE;NUT
MZ7,@8F4M(&EL;"X@:VEK87!C<V]LX7/A:&]Z*2X`*B!!>B!/2R!G;VUB<F$@
M:V%T=&EN='9A(&%D:G5K(&AO>GKA(&5Z96ME="`J`"H@2^ER:OQK(';A;&%S
M<WIO;B!C[6TH96LI970@*@`L('-ZZ6QL]FOI<V5K`"P@)7,@)7,M<R!S>NEL
M;/9KZ7-E:P`L(';A;'1O>O,@)7,@Z7,@)7,@:_9Z]G1T`"TM(';A;&%S<WIO
M;B`M+0`Q('+I<WIT=F5V]0`Q(&5L9F]G;&%L='/A9P`Q(/-R80`Q,B#S<N%S
M(&9O<FWA='5M`#$U('!E<F,`,C`@<&5R8P`R-"#S<N%S(&9O<FWA='5M`#(T
M(/-R80`S,"!P97)C`#Q%;/5Z]0`\<W1R;VYG/E+I<WIT=F5V]6L\+W-T<F]N
M9SX@*&]P8VEO;N%L:7,I`#QS=')O;F<^3&7M<N%S/"]S=')O;F<^("AO<&-I
M;V[A;&ES*0`\<W1R;VYG/DMU;&-S<WIA=F%K/"]S=')O;F<^("AO<&-I;V[A
M;&ES*0`\<W1R;VYG/DES;>ET;/5DZ7,\+W-T<F]N9SX@*&]P8VEO;N%L:7,I
M`$5Z96X@8FQO:VL@:&%S>F[A;&%TX6AO>B!E9WD@861A=&+A>FES(&%L<F5N
M9'-Z97(@<WK\:W/I9V5S+@!(96QY<F5H;WIH871A=&QA;B!H:6)A('3V<G3I
M;G0`02!L97;I;"!T:71K;W/M=.%SX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K
M=6QC<R!S>OQK<^EG97,N`$$@9&EG:73A;&ES86X@86SA[7)T(&QE=NEL(&5L
M;&5N]7)ZZ7/I:&5Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S('-Z_&MSZ6=E
M<RX`02!T:71K;W/M=&]T="!L97;I;"!D96OS9&]LX7/A:&]Z(&5G>2!N>6EL
M=N%N;W,@4$=0(&MU;&-S+"!E9WD@=&ET:V]S(%!'4"!K=6QC<R#I<R!E9WD@
M:F5L;6]N9&%T('-Z_&MSZ6=E<RX`02!L97;I;"!D:6=I=.%L:7,@86SA[7+A
M<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,L(&5G>2!T:71K;W,@4$=0
M(&MU;&-S(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+@!!('1I=&MO<^UT
M;W1T(&QE=NEL(&1E:_-D;VSA<^%H;WH@96=Y(&YY:6QVX6YO<R!3+TU)344@
M:W5L8W,L(&5G>2!T:71K;W,@4R]-24U%(&MU;&-S(.ES(&5G>2!J96QM;VYD
M870@<WK\:W/I9V5S+@!!(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%SX6AO>B!E
M9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<RP@96=Y('1I=&MO<R!3+TU)344@
M:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG97,N`$$@;&5VZ6P@=&ET
M:V]S[73A<^%H;WH@96=Y(&YY:6QVX6YO<R!3+TU)344@:W5L8W,@<WK\:W/I
M9V5S+@!$Z6QE;/5T="!B;W)U;'0@Z6<`1.EL96SU='0@9WEE;F=E(&5S]0!$
MZ6QE;/5T="!E<_4`1.EL96SU='1I('KA<&]R;VL`1.EL96SU='0@:/-ZX7!O
M<F]K`&1E+V1U`$%022!)1"`H82!P<F]G<F%M;WKA<VD@9F5L_&QE="!A>F]N
M;W/M=/-J82D`17)R]6P@87H@961I=&]R<O-L`$[I=FIE9WDN+BX`86)S>B!A
M;'5L`&%B<WH@:_9ZZ7``96QF;V=A9'9A`$YI;F-S(&IO9V]S=6QT<^%G82!A
M(%9&4R!A;&OV;GEV=.%R(&SI=')E:&]ZX7/A:&]Z+@!.:6YC<R!J;V=O<W5L
M='/A9V$@82!61E,@9N%J;"!LZ71R96AO>N%SX6AO>BX`0F5J96QE;G1K97KI
M<VD@:6YF;W)MX6-I\P!*96QS>O,`02!J;V=O<W5L='/A9R!F96P@=F%N(&;\
M9V=E<WIT=F4N`%#I;GK\9WEE:P!2Z7-Z;&5T97,@:V5R97/I<P!"979I=&5L
M`$%L8W-O<&]R="!LZ71R96AO>N%S80!*;V=O<W5L='/A9VD@86QC<V]P;W)T
M(&SI=')E:&]ZX7-A`-IJ(&5L9F]G;&%L='/A9P!!9&1J=6L@:&]Z>N$@:71T
M.@#::B!C<V]P;W)T(&SI=')E:&]ZX7-A`-IJ(&IO9V]S=6QT<^%G(&SI=')E
M:&]ZX7-A`$%L8W-O<&]R="!H;WIZX6%DX7-A("(E<R(M:&5Z`$IO9V]S=6QT
M<^%G:2!A;&-S;W!O<G0@:&]Z>N%A9.%S82`B)7,B+6AE>@#::B!TX79O;&D@
M;F%P=.%R(&AO>GKA863A<V$`VFH@96QF;V=L86QT<^%G(&)E[7+A<V$`VFH@
M9F5L:&%S>F[A;/,@;.ET<F5H;WKA<V$Z`%+I<WIT=F5V]6L@:&]Z>N%A9.%S
M80#::B!O<WIL;W`@:&]Z>N%A9.%S80#::B!T86=O:R!F96QVZ71E;&4`VFH@
M<.%R(&AO>GKA863A<V$`02AZ*2`E<R!M96[\="!A9&IU:R!H;WIZX2!A($UO
M>FEL;&$@;65N_'-O<FAO>@!!9&IU:R!H;WIZX2!A(&/M;6IE9WEZZ6MH97HZ
M`$%D:G5K(&$@<NES>G1V97;U:VCV>@!!9&IU:R!H;WIZX2!A(&/M;6IE9WEZ
MZ6ME;6AE>@#::B!F96QH87-Z;N%L\R!H;WIZX6%DX7-A`"(E<R(@9F5L:&%S
M>F[A;/-T(&AO>GKA861T=6L@82!R96YD<WIE<FAE>BP@9&4@;F5M('-I:V5R
M_&QT(&$@=/9B8FD@8F5J96QE;G1K97KI<VD@861A="!TX7)O;.%S83H@)7,N
M`"(E<R(@9F5L:&%S>F[A;/-T(&9E;'9E='3I:R!A(')E;F1S>F5R8F4N($UO
M<W0@;>%R(&)E:F5L96YT:V5Z:&5T+@!!(')E;F1S>F5R:&5Z(&YE;2!A9&AA
M=/-K(&AO>GKA(/IJ(&9E;&AA<WINX6SS:RX`0^UM`$/M;6IE9WEZZ6L`061M
M:6YI<WIT<N%C:?,@+2!J;V=O<W5L='/A9V]K(&%DX7-A('1O=N%B8FD@9F5L
M:&%S>F[A;/-K;F%K`$%D;6EN:7-Z='+A8VGS`$AI<F1E=.ES96L`4NES>FQE
M=&5S(&ME<F5SZ7,`069G86YI<WITX6X`1FEG>65L;65Z=&5TZ7,`1FEG>65L
M;65Z=&5TZ7,@)60@;F%P<&%L(&5L]71T90!&:6=Y96QM97IT973I<R`E9"#S
M<N%V86P@96SU='1E`$9I9WEE;&UE>G1E=.ES("5D('!E<F-C96P@96SU='1E
M`$9I9WEE;&UE>G1E=.ES("5D(&CI='1E;"!E;/5T=&4`1FEG>65L;65Z=&5T
MZ7,@,2!N87!P86P@96SU='1E`$9I9WEE;&UE>G1E=.ES(#$@\W+A=F%L(&5L
M]71T90!&:6=Y96QM97IT973I<R`Q('!E<F-C96P@96SU='1E`$9I9WEE;&UE
M>G1E=.ES(#$@:.ET=&5L(&5L]71T90!!(&9I9WEE;&UE>G1E=.ES(&3A='5M
M80!!(&9I9WEE;&UE>G1E=.ES(&ED]71A<G1A;6$@*'!E<F,I`$$@9FEG>65L
M;65Z=&5TZ7,@:61E:F4`06QBX6YI80!!;&?I<FEA`$%L:6%S`$5L:&5L>65Z
MZ7,`4F5N9&5ZZ7,Z`&%Z(/9S<WIE<V5T`$%Z(/9S<WIE<R!RZ7-Z='9E=O4`
M36EN9&5N(&YE;2!V96YDZ6<@9F5L:&%S>F[A;/,`;6EN9&5N(&$@:O9V]6)E
M;@!-:6YD96X@8W-O<&]R=`!M:6YD96X@82!M^FQT8F%N`$UI;F1E;B!J;V=O
M<W5L='/A9P!!>B#V<W-Z97,@;.%T:&%T\P!E9^ES>B!N87``16?I<WIN87!O
M<R!E;&9O9VQA;'1SX6<`07H@]G-S>F5S(&5L9F]G;&%L='/A9P!-:6YD(&$@
M;NEG>2!O;&1A;&]N(&QE9WEE;B!K97)E=`!%;F=E9&K\;FL@;65G('3V8F(@
M8^UM970@:7,`02!S;W)S>N%M;W,@9F5L<V]R;VSA<R!T[7!U<V$@=N%L=&]Z
M=&%T:&%T\R!L96=Y96X_`$WA<B!LZ71E>FEK`$E-4U`@8F5J96QE;G1K97KI
M<VD@<&%R86WI=&5R96L`3>%S:6LL($E-4U`@:F5L<WKS`$WA<VEK+"!)35-0
M(&)E:F5L96YT:V5ZZ7-I(&[I=@!-X7-I:R!E;6%I;"!C[6T`06QT97)N873M
M=B!S86)L;VYO:P!!;'1E<FYA=.UV('-Z]G9E9SH`06UE<FEK86D@4WIA;6]A
M`$$@;65G861O='0@Z7)TZ6L@;F5M(&9O9V%D:&%T\R!E;"X`27-M97)E=&QE
M;B!H:6)A('3V<G3I;G0N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI
M;2!P<F]X>6X@:V5R97-Z=/QL:2!I;G1E<FYE="!E;.ERZ7,`5N%L87-Z`$%N
M=&%R:W1I<WH`06YT:6=U82#I<R!"87)B=61A`&+A<FUE;'EI:P!!;&MA;&UA
M>N%S`$%L:V%L;6%ZX7-O:R!L:7-TX6IA`$%Z(&%L:V%L;6%ZX7,@:^ES>BX`
M02!K]GKV<R!TX7)T97+\;&5T(&%L8W-O<&]R=&IA:7)A(&ES(.ER=NEN>65S
M`$KS=N%H86=YX7,`2_9R_&QB96S\;&D@;>ER970`X7!R:6QI<P!A<F%B("A7
M:6YD;W=S+3$R-38I`$$@=/9M]G+M=&5T="#A;&QO;>%N>2!MZ7)E=&4`02!T
M]FWV<NUT971T(.%L;&]MX6YY(&YE=F4`0FEZ=&]S(&)E;FYE+"!H;V=Y('3V
M<O9L;FD@:^UVX6YJ82`E<R!B96IE;&5N=&ME>NES:2!I9^EN>>ET/P!":7IT
M;W,L(&AO9WD@=/9R]FQN:2!A:V%R:F$@(B5S(BUT(&%L8W-O<&]R=&IA:79A
M;"!E9WG\='0_`$%R9V5N=.UN80#6<FWI;GEO<G-ZX6<`]G)MZ6YY("A!4DU3
M0TE)+3@I`$W[=NES>F5T`$%R=6)A`%!O:&YP96D`07-C:6D@<F%J>F]K`,%Z
M<VEA+T-S96YD97,M\V-EX6YI('+I9VGS`$OI<FIE;B!A(')E;F1S>F5R(&UE
M9V5R]7/M=.ES="!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K(&5L=NEG>NES
M92!E;/5T=#\`2&]Z>N%R96YD96SI<VD@;W-Z;&]P;VL`(`!-96QLZ6ME;'1E
M;B!T86SA;&AA=/,@96=Y(&E#86QE;F1A<B#A;&QO;>%N>2P@;65L>2!T;W;A
M8F)I(&EN9F]R;>%C:?-V86P@<WIO;&?A;"!A>B!E<V5MZ6YY<O5L+B!!;65N
M;GEI8F5N(&%Z(-9N(&QE=F5L97KU<')O9W)A;6IA('3A;6]G871J82!A>B!I
M5&EP(&OI<NES96ME="P@86MK;W(@82!M96QLZ6ML970@<V5G[71SZ6?I=F5L
M(&OV;FYY96X@9G)I<W/M=&AE=&D@82!E<V5MZ6YY('-A:N%T(&YA<'3A<N%B
M86X@;&5V]2!PZ6QDX6YYX6YA:R!A9&%T86ET+@!.96ULZ71E>O4@8W-O<&]R
M=&]T(&OM<^ER96QT(&UE9R!T]G+V;&YI+@!.96ULZ71E>O4@:F]G;W-U;'1S
MX6=O="!K[7/I<F5L="!M96<@=/9R]FQN:2X`3F5M;.ET97KU(&IO9V]S=6QT
M<^%G;W0@:^USZ7)E;'0@;65G(&UE9W;A;'1O>G1A=&YI+@!.96ULZ71E>O4@
M:_9Z]G,@=.%R=&5R_&QE=&5T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT871N
M:2X`365G:F5L96[I<P!2Z7-Z='9E=O5K`%1U;&%J9&]N<^%G;VL`875G=7-Z
M='5S`$%U<WIT<N%L:6$`075S>G1R:6$`075T:%]C>7)S<6PZ(&$@<WK\:W/I
M9V5S(&EM87`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H7V-Y<G5S.B!A
M(&CA='3I<G-Z;VQGX6QT873A<R!N96T@<F5N9&5L:V5Z:6L@82!K[7;A;G0@
M:^EP97-SZ6=E:VME;"X`075T:%]C>7)U<SH@82!S>OQK<^EG97,@:6UA<"!B
M]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?9G1P.B!A('-Z_&MSZ6=E<R!F
M='`@8O5V[73I<R!N96T@=&%LX6QH873S+B!&;W)D[71S82!L92!A(%!(4"UT
M(&%Z("TM96YA8FQE+69T<"!O<&-I\W9A;"X`075T:%]I;6%P.B!A('-Z_&MS
MZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]K<F(U.B!A
M('-Z_&MSZ6=E<R!K<F(U(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]L
M9&%P.B!N96T@:&]Z:&%T\VL@;.ET<F4@^FH@9F5L:&%S>F[A;/-K($%C=&EV
M92!$:7)E8W1O<GD@97-E=.EN`$%U=&A?;&1A<#H@9F5L:&%S>F[A;/-K(&YE
M;2!T]G+V;&AE=/5K($%C=&EV92!$:7)E8W1O<GD@97-E=.EN`$%U=&A?;&1A
M<#H@82!S>OQK<^EG97,@3$1!4"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U
M=&A?;&1A<#H@)7,@9F5L:&%S>F[A;/,@:&]Z>N%A9.%S82!N96T@<VEK97+\
M;'0N($$@<WIE<G9E<B!VX6QA<WIA.B``075T:%]L9&%P.B`E<R!F96QH87-Z
M;N%L\R!T]G)LZ7-E(&YE;2!S:6ME<OQL=`!!=71H7VQD87`Z("5S(&9E;&AA
M<WINX6SS(&%D871A:6YA:R!M96?Z:NUTX7-A(&YE;2!S:6ME<OQL=`!!=71H
M7VQD87`Z(&$@9F5L:&%S>F[A;/-K(&YE;2!M\V1O<^UT:&%T\VL@06-T:79E
M($1I<F5C=&]R>2!E<V5TZ6X`075T:%]M8V%L.B!A('-Z_&MSZ6=E<R!-0T%,
M(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]S;6)A=71H.B!A('-Z_&MS
MZ6=E<R!S;6)A=71H(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`3F5M('-I:V5R
M_&QT(&%Z($E-05`@<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M
M=.%S+@!!(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@<VEK97+\;'0N`$$@
M9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!S:6ME<OQL="X@)7,`02!F96QH
M87-Z;N%L\R!A>F]N;W/M=.%SX70@82!2041)55,@<WIE<G9E<B!E;'5T87/M
M=&]T=&$N`$YE;2!S:6ME<OQL="!A>B!&5%`@<WIE<G9E<FAE>B!V86SS(&9E
M;&AA<WINX6SS87IO;F]S[73A<RX`3F5M('-I:V5R_&QT(&%Z(%--0B!S>F5R
M=F5R96X@=F%L\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N`$$@<F5N9&5L:V5Z
MZ7-R92#A;&SS(&UE>O5K.@!!>F5R8F%J9'ISX6X`02!G;VYO<WH@<F5N9'-Z
M97)G87ID82!M96YT<^EG96D`2.%T=.ER`$CA='3I<B!S>NUN`$YE;2!M96=F
M96QE;/4@:V5R8F5R;W,@:F5L<WKS+@!.96T@;65G9F5L96SU(&ME<F)E<F]S
M(&9E;&AA<WINX6SS;NEV+@!"86AA;>%K`$)A:')E:6X`8F%L=&D@*$E33RTX
M.#4Y+3$S*0!"86YG;&%D97,`0F%R8F%D;W,`02!G<F%F:6MU<R#A;&QO;>%N
M>6]K("(E<R(@86QK]FYY=G3A<F$@;F5M('1A;.%L:&%T\RX`86QA<'9O;F%L
M;VX`2V5R97/I<P!&96CI<F]R;W-Z;W)S>N%G`$)E;&=I=6T`0F5L:7IE`$)E
M;FEN`$)E<FUU9&$`0FAU=.%N`%-Z_&QE=.ES;F%P`$$@(B5S(B!B;&]K:R!A
M("(E<R(@<')O9W)A;6UA;"!N96T@=&%LX6QH873S+@!+Z7!E<FYY]7+I<WH@
M8F7A;&SM=.%S`$OI<&5R;GGU<NES>B!T[7!U<P!FZ6QK]G;I<@!";VSM=FEA
M`$ME9'9E;F,@=V5B8^UM96L`2V5R970`2V5R971V87-T86=SX6<Z`$ME<F5T
M96L`0F]S>FYI82U(97)C96=O=FEN80!-:6YD:V5T=/4`0F]T<W=A;F$`86QU
M;`!";W5V970M<WII9V5T`$)R87KM;&EA`$)R:70@26YD:6%I+?-C9>%N:2!4
M97+\;&5T`$)R=6YE:2!$87)U<W-A;&%M`$)U;&?A<FEA`$9E;'-O<F]LX7,`
M0G5R:VEN82!&87-O`$)U<G5N9&D`16QF;V=L86QT`%=E8F]L9&%L(&MA<F)A
M;G1A<G3A<P!#4D,`02!T86[Z<^UT=N%N>79I<W-Z879O;N%S:2!L:7-TX6L@
M*$-23"D@8^UM96D`3F%P=.%R`$-E;&QA('1U;&%J9&]N<^%G;VL`02!C86-H
M92!I;FEC:6%L:7KA;.%S82!N96T@9F5J97KU9/9T="!B92X`3F%P=.%R`$YA
M<'3A<@!.87!TX7(@]G-S>F5F;V=L86SS`$$@;F%P=.%R="!S:6ME<F5S96X@
M=/9R]FQT_&LN`$YA<'3A<F%K`$$@;F%P=.%R;F%K(&YE=F5T(&ME;&P@861N
M:2X`3GEU9V]D=`!+86UB;V1Z<V$`2V%M97)U;@!.96T@<VEK97+\;'0@82!J
M96QS>O-T(.%TX6QL[71A;FDL(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H
M;WHN`$$H>BD@(B5S(B#A;&QO;>%N>2!N96T@[7)H873S+@!!(&O\;'/U(&9E
M;&AA<WINX6SS:V%P8W-O;&%T+6ME>F5L]6L@;F5M(&%D;6EN:7-Z='+A;&AA
M=/-K+@!!(&OV=F5T:V5Z]2!)34%0('-Z97)V97(@;F5M(.ER:&5T]2!E;#H@
M)7,`3F5M(&QE:&5T<^EG97,@^FH@96QF;V=L86QT<^%G(&)E=FET96QE+@!!
M*'HI("(E<R(@X6QL;VWA;GD@;F5M(&YY:71H873S(&UE9RX`2V%N861A`$WI
M9W-E`$WI9W-E(&O\;&3V:R!H:6)A:F5L96YTZ7-T`&5L;6%R860`16QM87)A
M9#H@)7,`02AZ*2`B)7,B(.%L;&]MX6YY(&YE;2!T]G+V;&AE=/4N`$YE;2!T
M86SA;&AA=/,@87H@:61E:6=L96YE<R#A;&QO;>%N>6]K870@=&%R=&%L;6%Z
M\R!A;&OV;GEV=.%R+@!!("=T87)G971&:6QE)R!P87)A;>ET97(@;65G863A
M<V$@;NEL:_QL(&YE;2!F;VQY=&%T:&%T:G5K+@!!*'HI("(E<R(@86QK]FYY
M=G3A<B!N96T@=/9R]FQH973U+@!.96T@=/9R]FQH973U+"`E9"!A;&-S;W!O
M<G1J82!V86XN`$%Z(/IJ('-O<F)A<F5N9&5ZZ7,@;F5M(&QE:&5T<^EG97,L
M(&$@;65G861O='0@861A=&]K('-ZX6UA(&YE;2!E9WEE>FEK(&$@=.%R;VQT
M86OI=F%L+@!!(&UE9V%D;W1T('-ZX6UR82!N96T@:_QL9&AE=/4@96P@87H@
M_'IE;F5T+@!:]FQD+69O:VDM<WII9V5T96L`P6)R87-Z]G9E9P!3>F]L9^%L
M=&%T\P!+871E9_-R:6$`2V%T96?S<FGA:R#I<R!J96SV;.ES_&L`2V%T96?S
M<FEA`$MA:FWA;BUS>FEG971E:P!-;V)I;"!T96QE9F]N`$-E;&QA='5L86ID
M;VYSX6=O:P!#96QL82!B96QS]2!M87)G\SH`0V5L;&%T=6QA:F1O;G/A9V]K
M`$-E;&SA:R!K]GKV='1I('+I<SH`36]B:6P@=&5L969O;@!K96QT82`H25-/
M+3@X-3DM,30I`&OV>NEP`$OV>NEP+6%F<FEK86D@2_9Z=.%R<V%SX6<`:V5L
M970M975R\W!A:2`H25-/+3@X-3DM,BD`02!T86[Z<^UT=N%N>2!RZ7-Z;&5T
M96D`02!T86[Z<^UT=N%N>2!T=6QA:F1O;F]S80!486[Z<^UT=N%N>2!F96QH
M87-Z;N%LX7-I(&ERX6YY96QV96L`0W/A9`!6X6QT;WIT873A<P!!(&IE;'-Z
M\R#A=.%L;.UTX7-A`$%Z(-9N(.%L=&%L(&5L:_QL9/9T="!L979E;&5K96X@
M<WIE<F5P;/4@;NEV(.ES(&/M;2!M96=VX6QT;WIT873A<V$N`$$@:F5L96X@
M:V]N9FEG=7+A8VGS8F%N(&YE;2!L96AE='/I9V5S(&$@:F5L<WIA=F%K(&WS
M9&]S[73A<V$N($9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN`$MA<F%K
M=&5R`$QI;E]K96QL96[U<GKI<RXN+@!#:&EL90!+[6YA`&OM;F%I+"!E9WES
M>F5R^W/M=&5T="`H1T(R,S$R*0!K[6YA:2P@:&%G>6]MX6YY;W,@*$)I9S4I
M`%;A;&%S<WIO;B!K:2!E9WD@86QK86QM87KA<W0Z`%;A;&%S<WIO;B!J96QS
M>O-T`%;A;&%S<WIO;B!E9WD@9F5L:&%S>F[A;/-N979E=`!6X6QA<W-Z82!K
M:2!A(&3A='5M;VL@;65G:F5L96[M=.ES:2!F;W)MX6KA=#H`5N%L87-S>F$@
M:VDL(&AO9WD@:^ER+64@96UA:6QB96X@=/9R=.EN]2#I<G1E<^UTZ7-T(&%Z
M(/IJ+"!M\V1O<^UT;W1T+"!V86=Y('3V<O9L="!E;&9O9VQA;'1SX6=O:W+S
M;#H`365G861H871J82P@:&]G>2!KZ7(M92#I<G1E<^UTZ7-T(&%Z(/IJ+"!M
M\V1O<^UT;W1T+"!V86=Y('3V<O9L="!E;&9O9VQA;'1SX6=O:W+S;"X`5N%L
M87-S>F$@:VDL(&AO9WD@:^ER+64@:_QL]FX@96UA:6QB96X@=/9R=.EN]2!J
M96QZZ7-T(&%Z;VMR\VP@87H@96QF;V=L86QT<^%G;VMR\VPL(&UE;'EE:VAE
M>B!F:6=Y96QM97IT973I<R!V86X@<F5N9&5L=F4Z`%;A;&%S<WIA(&MI(&$@
M9F5L<V]R;VSA<R!T[7!U<^%T("AS>N%M;WIO='0@;&ES=.%K;N%L*0!-96QY
M:6L@8^UM:F5G>7KI:V5K8F5N(&ME<F5S<_QK(&$@;65G:.UV;W1T86L@:63U
M8F5O<WITX7-I(%523"UJZ70Z`$UE;'D@;F%P=.%R(&%D871A:2!J96QE;FIE
M;F5K(&UE9R!A>B#6;B!N>6EL=N%N;W,@:63U8F5O<WITX7/A8F%N.@!-96QY
M:6L@8^UM:F5G>7KI:V5K8F5N(&ME<F5S<_QK(&$@;65G:.UV;W1T86L@:63U
M8F5O<WITX7-I(%523"UJZ70Z`%;A;&%S<WIA(&MI(&%Z(-9N(&%L87#I<G1E
M;&UE>NES('-Z97)I;G1I(&YA<'3A<FKA=`!+87+A8W-O;GDM<WII9V5T96L`
M02AZ*2`E<R!C;&%S<R!D969I;NUC:?-J82!N96T@=&%LX6QH873S+@!$97+\
M;'0`5/9R;&D@87H@35-/9F9I8V4@=&%G96ME=`!!(&QE:^ER9&5ZZ7,@=/9R
M;.ES90!4]G+V;&K\:R!A>B#V<W-Z97,@;65G:.UV;W1T870`)7,@9F5L:&%S
M>F[A;/,@=/9R;.ES90!!(&9E;&AA<WINX6SS('3V<FSI<V4`02!F96QH87-Z
M;N%L\R!A9&%T86EN86L@=/9R;.ES90!%<W3I<F4@9&5R_&QT(.EG`$$@9F]L
M>71A=.%S:&]Z(&MA='1I;G1S;VX@87H@96?I<G)E;`!#;&EC:V%T96QL('-Z
M;VQGX6QT873A<R!(5%10+6X@:V5R97-Z=/QL`$%Z(&%B;&%K(&)E>N%RX7-A
M`$%Z(&%B;&%K(&)E>N%RX7-A`$)O<G5L="#I9P!296=G96P@9F5L:/5S(&ED
M]0!&96QH]7,@:63U`$OS:W5S>BUS>FEG971E:P!4_&YT97-S_&L@96P@87H@
M;VQD86QS\R!M96[\=`#6<W-Z97KA<G0@:V5R971E:P!+;VQU;6)I80!3>NUN
M`%-Z[6YVX6QA<WIT\P!3>NUN=N%L87-Z=.%S`$]S>FQO<&]K.@!!>B!O<WIL
M;W!O:R!C[6UE:0!6:6-C96L`5F5S<WKU=F5L(&5L=N%L87-Z=&]T="#I<G3I
M:V5K`%!A<F%N8W,`4&%R86YC<^ER=&5L;65Z]0!-96=J96=Y>NES`$[I=BP@
M96QN979E>NES`$-O;6]R92US>FEG971E:P!#Z6<`4WKA;>UT\V?I<&5K`$ED
M]6KA<N%S:2!H96QY>F5T`$ED]6KA<N%S:2!H96QY>F5T`$O\;/9N8G/I9V5K
M(&$@:V]N9FEG=7+A8VGS8F%N`$OI>FES>N%M[73S9^EP96MK96PL(&]K;W-T
M96QE9F]N;VMK86PL($]U=&QO;VMK86P@=F%L\R!A9&%T<WII;FMR;VYI>N%L
MX7,@:V]N9FEG=7+A8VGS:F$`02!K;VYF:6=U<N%C:?,@;>%R(&YE;2#I<G;I
M;GEE<RX`)7,@:V]N9FEG=7+A8VGS:F$`02!J96QS>O,@;65G97+U<^UTZ7-E
M`$%Z(&5L9F]G;&%L='/A9V]K('3V<FSI<V5K;W(@:^UVX6X@:_QL]FX@;65G
M97+U<^UTZ7-T/P!B:7IT;W,`2V]N9_,`2V]N9_-I($1E;6]K<F%T:6MU<R!+
M]GITX7)S87/A9P!3:6ME<G1E;&5N(&$@:V%P8W-O;&%T+@!3:6ME<G1E;&5N
M(&$@:V%P8W-O;&%T.B``02!N>6EL=N%N;W,@:W5L8W-O:R!S>F5R=F5R92!E
M;'5T87/M=&IA(&$@:V%P8W-O;&%T;W0N`$$@;GEI;';A;F]S(&MU;&-S;VL@
M<WIE<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA=&]T+B!/:V$Z("5S("@E
M<RD`4VEK97)T96QE;B!A>B!&5%`@<WIE<G9E<G)E;"!V86SS(&MA<&-S;VQA
M="X`4&%R=&YE<F5K`$$@<&%R=&YE<F5K970@<VEK97)E<V5N(&AO>GKA861T
M=6L@82!C[6UJ96=Y>NEKZ6AE>BX`02!T]FWV<NUT971T(.%L;&]MX6YY('3M
M<'5S83H@`"(E<R(@=&%R=&%L;6$`1F]L>71A=.%S`$-O;VLM<WII9V5T96L`
M4_QT:0!-X7-O;&IU:R#A=`!!(&WA<V]LX7,@;F5M('-I:V5R_&QT.B`E<P!!
M(&MI:F5L]FQT('+I<WH@;>%S;VSA<V$`06X@UFX@;GEI;';A;F]S(&ED]6)E
M;W-Z=.%S82!A>B!A;.%B8FD@55),+65N(.ER:&5T]2!E;#H`4WKA;6SA>N%S
M:2!A>F]N;W/M=/,`0V]S=&$@4FEC80!%;&5FX6YT8W-O;G1P87)T`$YE;2!S
M:6ME<OQL="!01U`M=F5L('1I=&MO<^UT86YI(&$@;&5V96QE=#H@`$$@;&5V
M96QE="!N96T@<VEK97+\;'0@4$=0(&%LX>URX7-S86P@96QLX71N:3H@`$$@
M;&5V96QE="!N96T@<VEK97+\;'0@87H@4R]-24U%('-Z86)VX6YY('-Z97)I
M;G0@=&ET:V]S[71A;FDN`$$@;&5V96QE="!N96T@<VEK97+\;'0@4R]-24U%
M(&%LX>URX7-S86P@96QLX71N:2X`02!P87)T;F5R(&%D871A:70@;F5M('-I
M:V5R_&QT(&5L=.%R;VQN:2X@)7,`07H@3$1!4"!S>F5R=F5R(&YE;2#I<FAE
M=/4@96PN`$YE;2!S:6ME<OQL="!E;&QE;O5R:7IN:2!A('-ZX6ULX6KA;B!R
M96YD96QK97KI<W)E(.%L;/,@]G-S>F5G970N("5S`$YE;2!S:6ME<OQL="!A
M>B!,1$%0('-Z97)V97)H97H@:V%P8W-O;/-D;FDN`$YE;2!S:6ME<OQL="!A
M*'HI("(E<R(@<WIE<G9E<G)E;"!&5%`@:V%P8W-O;&%T;W0@9F5L=F5N;FDZ
M("5S`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@:_9R;&5VZ6QL:7-TX70N
M("5S`$%Z(&%D871O:R!01U`@=&ET:V]S[73A<V+S;"!T]G)TZ6[U(&1E:_-D
M;VSA<V$@;F5M('-I:V5R_&QT.B``07H@861A=&]K(%,O34E-12!T:71K;W/M
M=.%S8O-L('3V<G3I;O4@9&5K\V1O;.%S82!N96T@<VEK97+\;'0N`$$@<&%R
M=&YE<B!T]G)LZ7-E(&YE;2!S:6ME<OQL="X@)7,`02!K]G)L97;I;&QI<W1A
M('3V<FSI<V4@;F5M('-I:V5R_&QT+B`E<P!.96T@<VEK97+\;'0@=/9R]FQN
M:2!A*'HI("(E<R(@<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N`$YE;2!S:6ME
M<OQL="!M96?A;&QA<.UT86YI(&$@8^UM>F5T="!E;6%I;"!C[6WI="X`3F5M
M('-I:V5R_&QT(&)E;VQV87-N:2!A('1E;&IE<R!C[6UJ96=Y>NEK970N`$YE
M;2!S:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@:_9R;&5VZ6QL:7-TX70N
M`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A:R!T96QJ
M97,@9F5L<V]R;VSA<^%T+@!!*'HI("(E<R(@<W1R873I9VEA(&YE;2!T86SA
M;&AA=/,N`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!H;WIH873S(&SI=')E
M+@!!(&YY:6QVX6YO<R!K=6QC<V]T(&YE;2!S:6ME<OQL="!M96=S>F5R97IN
M:2!A(&MU;&-S<WIE<G9E<G+U;"X`3F5M('-I:V5R_&QT("(E<R(M="#M<N%S
M:2!CZ6QL86P@;65G;GEI=&YI+@`E<R!N96T@;GEI=&AA=/,@;65G+@!!("5S
M(&MA<F)A;G1A<G3A<VD@;6]D=6P@;F5M(&YY:71H873S(&UE9P!!*'HI("(E
M<R(@86QK]FYY=G3A<B!N96T@;GEI=&AA=/,@;65G+@!!>B!,1$%0('-Z97)V
M97(@;F5M(.ER:&5T]2!E;"X`)7,@;F5M(&]L=F%S:&%T\RX`3F5M('-I:V5R
M_&QT(&$@:^UVX6YT(&9E;&AA<WINX6SS(&IE;'-Z87;A="#A=.%L;.UT86YI
M+B!!>B!M96=A9&]T="!A9&%T;VL@;F5M('9A9WD@;F5M('1E;&IE<V5N(&9E
M;&5L;F5K(&UE9RX@4'+S8N%L:F$@^FIR82P@=F%G>2!H82!T;W;A8F)I('-E
M9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+"!F;W)D=6QJ;VX@82!R96YD<WIE<F=A
M>F3A:&]Z+@!.96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&%Z(&5LZ7+I<VD@
M:F]G;W-U;'1SX6=O:V%T("A!0TPI`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@
M82!C[6UJ96=Y>NEK970N("5S`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K
M]G)L97;I;&QI<W3A="X@)7,`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV
M<FQE=NEL;&ES=.%K870N("5S`$YE;2!S:6ME<OQL="!M96=H873A<F]Z;FD@
M82!S>F5R=F5R(&OI<&5S<^EG96ET`$YE;2!S:6ME<OQL="!V:7-S>F'A;&SM
M=&%N:2!E>B!E<F5D971I(&MO;F9I9W5RX6-I\W0N`$$H>BD@(B5S(B!A;&OV
M;GEV=.%R(&YE;2!T]G+V;&AE=/4N`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@
M)7,@:V]N9FEG=7+A8VGS="X`3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A(&)A
M8VMU<"!K;VYF:6=U<N%C:?-T+@!.96T@<VEK97+\;'0@96QM96YT96YI(&$@
M8F%C:W5P(&MO;F9I9W5RX6-I\W0Z("5S`$YE;2!S:6ME<OQL="!E;&UE;G1E
M;FD@82AZ*2`B)7,B('-E='5P('5P9W)A9&4@<')O9W)A;6]T+@!.96T@<VEK
M97+\;'0@96QM96YT96YI(&$H>BD@)7,@8F%C:W5P(&MO;F9I9W5RX6-I\W0N
M`$$H>BD@)7,@:V]N9FEG=7+A8VGS<R#A;&QO;>%N>70@;F5M('-I:V5R_&QT
M(&5L;65N=&5N:2X@5F%G>2!H87-Z;N%L:F$@82`E<R!O;&1A;&]N(&QE=O4@
M;&5H973U<^EG96ME="P@=F%G>2!MX7-O;&IA(.%T(&%Z(&%LX6)B:2!K\V1O
M="!I9&4Z("5S+@!!>B!,1$%0('-Z97)V97)E;B!N96T@<VEK97+\;'0@96QV
MZ6=E>FYI(&$@:V5R97/I<W0N`"(E<R(@;F5M('9O;'0@=/9R]FQH973U+@!!
M('!A<G1N97(@861A=&%I="!N96T@<VEK97+\;'0@;?-D;W/M=&%N:2X@)7,`
M3F5M('-I:V5R_&QT(&$@:_9R;&5VZ6QL:7-T82!M\V1O<^UTX7-A+B`E<P!.
M96T@<VEK97+\;'0@96QM96YT96YI("(E<R(@:V]N9FEG=7+A8VGS:N%T.B`E
M<P!!($UO>FEL;&$@;65N_'-O<B!N96T@=&%LX6QH873S+B!%;&QE;O5R:7IZ
M92P@:&]G>2!M96<@=F%N+64@;GEI='9A+@!.96T@<VEK97+\;'0@(B5S(B!F
M96QH87-Z;N%L\VYA:R!J;V=O<W5L='/A9V]T(&%D;FD@82AZ*2`B)7,B(&UA
M<'#A:&]Z.B`E<P!+;W)LX71O<R!S>O9V96<`3W)S>N%G`%3A=F]K=&%TX7,`
M3.ET<F5H;WKA<P#::B!N87!TX7(@;.ET<F5H;WKA<V$`VFH@96QF;V=L86QT
M<^%G(&)E=FET96QE`$QI;FL@;.ET<F5H;WKA<V$`VFH@;.ET<F5H;WKA<V$`
M06QM87!PX6L@;.ET<F5H;WKA<V$`3.ET<F5H;WIV80!!>B!O8FIE:W1U;2!L
MZ71R96AO>O-JX6YA:R!J;V=O<W5L='/A9V%I`$AI=&5L:^%R='EA<WKA;0!(
M;W)VX71O<G-ZX6<`2W5B80!*96QE;FQE9VD`2F5L96YL96=I(#0@9N%Z:7,`
M02!J96QE;FQE9VD@9F5L:&%S>F[A;/-K87!C<V]L871O:P!0;VYT;W,@:63U
M`$$@:F5L96YL96=I(%523`!*96QE;FQE9VD@9F5L:&%S>F[A;/-K`$IE;&5N
M;&5G:2!I9/5JX7+A<P!!(&IE;&5N;&5G:2!I9/5JX7+A<VD@:&5L>7IE=#H`
M2F5L96YL96=I('-T[6QU<P!-:6QY96X@<&%R86YC<V]K(&9U<W-A;F%K(&QE
M(&%U=&]M871I:W5S86X@82`E<V)E('3V<G3I;O4@8F5J96QE;G1K97KI<VMO
M<BX`2VEVX6?A<P!!(&MI:F5L]FQT('+I<WH@:VEVX6?A<V$`0VEP<G5S`&-I
M<FEL;"`H2T])."U2*0!C:7)I;&P@*%=I;F1O=W,M,3(U,2D`8VER:6QL+75K
M<N%N("A+3TDX+54I`$-S96@@2_9Z=.%R<V%SX6<`1$0`1%-.("AA9&%T9F]R
M<N%S;&7M<O,@+2!LX7-D.B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E
M;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`&YA<&]N=&$`
M;F%P;VYT83H@;6EN9&5N`$1A=&%4<F5E(&+V;F?I<WKU`$%D871BX7II<V)A
M;B!V86SS(&ME<F5SZ7,`1.%T=6T`02!B9>ER:V5ZZ7,@;F%P:F$`1.%T=6T@
M:VEVX6QA<WITX7-A`&YA<`!N87``5/9R;.ES`$]S>FQO<"!T]G)LZ7-E`&1E
M8V5M8F5R`'-ZX6UO:P!E;'5T87/M=&]T=&$`0F5K97IDZ7,@:VEJ:F5B8@!!
M;&%PZ7)T96QM97IE='0`07H@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@;F%P
M=.%R`$%Z(&%L87#I<G1E;&UE>NES('-Z97)I;G1I('-Z[6X`06QA<.ER=&5L
M;65ZZ7,@<WIE<FEN=&D@87IO;F]S[73S`$%L87#I<G1E;&UE>F5T="!S:&5L
M;`!$969I;NUC:?-K`%3V<FSI<P`E<R!T]G)LZ7-E`$$@8V5L;&$@=/9R;.ES
M90!!>B!E;&9O9VQA;'1SX6<@=/9R;.ES90!!(&-S;W!O<G0@=/9R;.ES90!!
M(&YA<&SSX6QL;VWA;GD@=/9R;.ES90!!(&IO9V]S=6QT<^%G('3V<FSI<V4`
M3&5V96QE:R!T]G)LZ7-E`$$@8V5L;&$@=/9R;.ES90!!>B!O<WIL;W`@=/9R
M;.ES90!4]G+V;&K\:R!K:2!A(&UE9VSI=O4@86QT97)N873M=B!S86)L;VYT
M`$$@;&5V96QE:R!T]G)LZ7-E`"(E<R(@:F]G;W-U;'1SX6=A:6YA:R!T]G)L
MZ7-E`%3V<O9L:OQK("(E<R(@:F]G;W-U;'1SX6=A:70@Z7,@96YN96L@97-E
M=&QE9V5S(&%L8W-O<&]R=&IA:70_`$$@<V]R('3V<FSI<V4`02!K:7;A;&%S
M>G1O='0@87IO;F]S[73S('3V<FSI<V4`07H@86QM87!PX6L@=/9R;.ES90!!
M(&IE;&5N;&5G:2!O<WIL;W`@=/9R;.ES90!#<V%K(&5Z="!A>B!E;&9O9VQA
M;'1SX6=O="!T]G+V;&K\:RP@=F%G>2!E>G0@Z7,@87H@]G-S>F5S(&KV=O5B
M96QI="P@=F%G>2!P961I9R!A>B#V<W-Z97-E="P@:63U<&]N='3S;"!F_&=G
M971L96[\;#\`02!J96QE;FQE9VD@<V]R('3V<FSI<V4`5/9R]FQT_&L@82AZ
M*2`B)7,B('-E='5P('5P9W)A9&4@<')O9W)A;6]T+@!!(&OI>F)E<^UTZ7,@
M:61E:F4`1.%N:6$`3&7M<N%S`$%D:F]N(&QE[7+A<W0@82!P<F]B;.EMX7+S
M;`!,9>URX7,`4NES>FQE=&5K("AA($AO<F1E(&QO9V;A:FQB86X@:7,@;65G
M=&%LX6QH873S*3H`02!RZ7-Z;&5T96L@82!R96YD<WIE<F=A>F1A('-ZX6WA
M<F$@:^ES>OQL]2!N87!L\V;A:FQB82!K97+\;'1E:RX`1F5J;&5S>G3I<P!(
M87)M871P;VYT`$AA<FUA='!O;G0@:F5L96YL96<Z(`!(87)M871P;VYT.B``
M8F%L<O-L(&IO8F)R82#M<N%S`&IO8F)R\VP@8F%L<F$@[7+A<P!#[6UTX7(`
M365G:F5L96[M=.ES`$%Z(&ED]7!O;G1O:V%T(#(T(/-RX7,@9F]R;>%T=6UB
M86X@:F5L96[M='/\:R!M96<_`$YA<'3A<F%K(&UE9VIE;&5N[73I<V4`365G
M:F5L96[M=.ES:2!B9>%L;.UTX7-O:P!!('+I<WIL971E<R!E;/5R96IE;'KI
M<R!M96=J96QE;NUTZ7-E`$5L]7)E:F5L>NES(&UE9VIE;&5N[73I<V4@*')E
M</QL]73I<FDI`$UE9VIE;&5N[73I<VD@9F]R;>%T=6T`R7)T97/M=.ES(&$@
M:^EZ8F5S[71E='0@;&5VZ6P@<V]R<^%R\VP`1'IS:6)U=&D`3F4@=/9R]FQJ
M_&L`02!M86EN=&5N86YC92YP:'`@;F5M(.ER:&5T]2!E;"!K]GIV971L96[\
M;"X`02!H873A<FED]7,@9F5L861A=&]K(&ES(&IE;&5N:F5N96L@;65G(&$@
M;F%P=.%R8F%N/P!N96T@:7-MZ71L]61I:P!!>B!E;'/U('-O<B!A(&UE>O5K
M(&YE=F5I="!T87)T86QM87IZ83\@2&$@:6=E;BP@:F5L]FQJ92!K:2!E>G0Z
M`$1O;6EN:6MA`$1O;6EN:6MA:2!+]GITX7)S87/A9P!.:6YC<R!MZ6<@;&]G
M:6X@;F5V93\@26?I;GEE;&IE;B!E9WEE="X`3&5T]FQTZ7,`5/9L='/\:R!L
M92`E<RUT`%3V;'1S_&L@;&4@4$A0('!R;V=R86T@9F]R;>%JX6)A;B!A>B!E
M;&OI<WK\;'0@:V]N9FEG=7+A8VGS="X`3&5G]G)D_&SU(&QI<W1A`$OA8NUT
M\W-Z97)E:P!(873A<FED]3H@)7,`365D9&EG('1A<G0`96UA:6P`16UA:6QB
M]6P@4TU3+6O\;&3U(&UE9VAA:G3S+"!H82!A('1E;&5F;VYTX7)S87/A9R!B
M:7IT;W/M=&IA(&5Z="!A('-Z;VQGX6QT873A<W0N`$A)0D$`16-U861O<@!-
M\V1O<^UTX7,`)7,@;?-D;W/M=.%S80!!('+I<WIT=F5V]6L@;?-D;W/M=.%S
M80!";&]K:R!M\V1O<^UTX7,`3F%P=.%R86L@;?-D;W/M=.%S80!#<V]P;W)T
M(&WS9&]S[73A<P!*;V=O<W5L='/A9R!M\V1O<^UTX7,`2F]G;W-U;'1SX6=O
M:R!M\V1O<^UTX7-A`"5S(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S80!4
MX79O;&D@;F%P=.%R86L@8F7A;&SM=.%S80!!('+I<WIT=F5V]6L@;?-D;W/M
M=.%S80!+871E9_-R:>%K(.ES('-Z[6YE:6L@=N%L=&]Z=&%TX7-A`$UE;'EI
M:R!O<&-I\VMA="!VX6QT;WIT87-S=6LZ`"(E<R(@:F]G;W-U;'1SX6=A:6YA
M:R!M\V1O<^UTX7-A`"5S(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S80!/
M:W1A=.%S`$5G>6EP=&]M`%-A;'9A9&]R`$5L96TN+BX`87H@)VTG(&)E=/L@
M<WKI;&5S<^EG90!%;6%I;`!%;6%I;"!C[6T`07H@96UA:6P@8^UM96MN96L@
M96=Y97IN:?QK(&ME;&PN`$5M86EL('9I<W-Z86EG87IO;.%S<V%L`$5M86EL
M+5--4R#A=&KA<O,`2&%N9W5L871I:V]N;VL`W')E<R#\>F5N970N`$YI;F-S
M(&EL>65N+@!4]G+V;&K\:R!K:2!A(&ME<F5SZ7-E:V5T`%;I9P!%;F=E9&K\
M:R!M96<L(&AO9WD@:^EP96ME="!I;&QE<W-Z_&YK(&$@<WKV=F5G8F4@82!&
M;W3S9V%LZ7)IX6MB\VP_`$QE9WEE;B!J;V)B(&5GZ7)G;VUB8F%L(&5LZ7)H
M973U+"!K;VYT97AT=7-F_&=G]2!M96[\/P!!(&)E9F5J97KI<R!DX71U;6$`
M5NEG>O5D:6L`02!B969E:F5ZZ7,@:61E:F4`07H@=71O;'/S(.EV`,%T=N%L
M=.%S(&O\;/9N(&%B;&%K<F$`061J82!M96<@87IT(&$@8FEZ=&]N<^%G:2!K
MZ7)DZ7-T+"!A;65L>7)E(&UA:F0@=N%L87-Z;VQN:6$@:V5L;"!J96QS>F%V
MX6YA:R#A=.%L;.UTX7/A:&]Z+"!P;"X@)VAO9WD@:.UV:N%K(&$@:W5T>>%J
MX70_)SH`061J82!M96<@82!KZ7`@55),+6KI="!I='0`S7)J82!B92!A>B!A
M;.%B8FD@8F5T^VME=#H`16=Y96YL[73U:2U'=6EN96$`17)I=')E80!(:6)A
M`$AI8F$@=/9R=.EN="!A(&)L;VMK(&SI=')E:&]ZX7-A:V]R.B`E<P!(:6)A
M('3V<G3I;G0@87H@861A='-Z:6YK<F]N:7KA8VGS<R!J96P@=/9R;.ES96MO
M<CH@)7,`07H@861A='-Z:6YK<F]N:7KA8VGS<R!N87!L\^%L;&]MX6YY('3V
M<FSI<V4@;F5M('-I:V5R_&QT.B`E<P!(:6)A('3V<G3I;G0@87H@861A=&QE
M:^ERZ7-B96XZ("5S`$YE;2!S:6ME<OQL="!M96=T=61N:2`E<R!I9/5B96]S
M>G3A<^%T.B`E<P!(:6)A('3V<G3I;G0@82!J96QS>O,@;65G=N%L=&]Z=&%T
MX7-A:V]R.B`E<P!(:6)A(&%Z(&5M86EL(/QZ96YE=&)E;BX`02AZ*2`B)7,B
M(.%L;&]MX6YY<F$@;F5M('-I:V5R_&QT(.UR;FDN`,ES>G1O<G-ZX6<`171I
M\W!I80!.96UZ971I<^EG96L`175R\W!A`-IJ(&5L9F]G;&%L='/A9SH`07H@
M96QF;V=L86QT<^%G('3V<FSU9/9T=#H@`$%Z(&5L9F]G;&%L='/A9R!M\V1O
M<W5L=#H`)7,@Z7,@)7,@:_9Z]G1T:2!E;&9O9VQA;'1SX6=O:P!!>B!E;&9O
M9VQA;'1SX6<@;F5M('1A;.%L:&%T\P!!>B!E;&9O9VQA;'1SX6=H;WH@9.%T
M=6UO="!K96QL(')E;F1E;&YI+@!!>B!E;&9O9VQA;'1SX6=N86L@96QN979E
M>NES="!K96QL(&%D;FDN`#$U('!E<F-E;FOI;G0`,B!P97)C96YKZ6YT`#,P
M(&WA<V]D<&5R8V5N:^EN=``U('!E<F-E;FOI;G0`;6EN9&5N(&)E:F5L96YT
M:V5ZZ7-K;W(`9NEL\W+A;FOI;G0`<&5R8V5N:^EN=`!0Z6QD82#I<G3I:V5K
M.@!6Z6=R96AA:G3A<P!.>6ES<W5K('-ZZ70`02!C[6URZ7-Z;&5T('1E;&IE
M<W/I(&5GZ7-Z[73I<V4`2F5L96[M='/\:R!M96<@87H@;VQD86QS\R!M96[\
M=`!)='0@)RDG(&ME;&QE;F4@:_9V971K97IZ96X`271T(&-S=7!A<WH@<WKS
M;F%K('9A9WD@:63I>O5J96QB96X@;&5V]2!K97)E<^ES:2!K:69E:F5ZZ7-N
M96L@:V5L;&5N92!L96YN:64`07H@Z7)VZ6YY97-SZ6<@;&5JX7)A=&$`2VET
M97;U`$5X<&]R=.%LX7,`3F%P=.%R(&5X<&]R=.%LX7,`4WKM;@!!(&MO;F9I
M9W5RX6-I\R!&5%`M;B#A="!V86SS(&9E;'3V;'3I<V4`02!S>F5MZ6QY97,@
M8F7A;&SM=.%S;VMA="!N96T@<VEK97+\;'0@8F5O;'9A<VYI+@!!>B!,1$%0
M('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`07H@4TU"('-Z97)V97(@;F5M(.ER
M:&5T]2!E;"X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(BUB]6P@=/9R=.EN]2!M
MX7-O;.%S+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B+6)E('3V<G3I;O4@;>%S
M;VSA<RX`3F5M('-I:V5R_&QT(/IJ(%-!4TP@:V%P8W-O;&%T;W0@;.ET<F5H
M;WIN:2X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(BUB92!T]G)TZ6[U(.%T:&5L
M>65ZZ7,N`,%L;&]MX6YY:&]Z>N%FZ7+I<VD@:&EB83H@)7,`5&ES>G1A`$9A
M;&ML86YD+7-Z:6=E=&5K("A-86QV:6YA<RD`1F%R;V4M<WII9V5T96L`2&5L
M>7)E:&]Z:&%T871L86X@:&EB83H`1F%X`$9A>`!F96)R=>%R`$CU;>ER<^EK
M;&5TZ7)Z970`2/5MZ7)SZ6ML973I<GIE=#H@`$5G>2UE9WD@>N%P;W(`4WKS
M<G;A;GEO<V%N(&CS>N%P;W)O:P!-97KU(&WA=')I>`!&:6=L970@0T%05$-(
M02`H8F5T^VMI<F%K\R!H=6WA;G1E<WIT*0!&:61Z<VD`1N%J;`!!(&;A:FQO
M:R!S>N%M83H@)7,`02!FX6IL;VL@<WKA;6$Z("5S`$;A:FP@;65N961Z<V5R
M`$;A:FQNZ78`1N%J;"!K:6IE;/9LZ7,`1N%J;"!F96QT]FQTZ7-E`$;A:FQO
M:R!F96QT]FQTZ7-E(&YE;2!L96AE='/I9V5S+@!3>OMR]6L`2V5R97-S_&L`
M1FEN;F]R<WKA9P!E;'/U(&;I;`!E;'/U(&YE9WEE9`!6X6QT;WIA=&QA;B!M
MZ7)E=&%RX6YY`%3\:W+V>NES("AF]FPO;&4I`$OV9``E<R!M87!P82!N96T@
M;.ET97II:P!"973[<WKM;@#)=&5L96L`3VQY86X@8O9N9^ES>O5K('-ZX6WA
M<F$L(&%M:6L@;F5M(&IE;&5N[71I:R!M96<@82!KZ7!E:V5T`$5L]7)E:F5L
M>NES("AR97#\;/5TZ7)I*0!!>B!E;/5R96IE;'KI<R!I9/5T87)T86UA(&YA
M<&]K8F%N("AA>B!E;/5R96IE;'KI<R!N87!P86QI(.ES(.EJ<WIA:V%I(&%D
M871O:V%T('1A<G1A;&UA>BP@97KI<G0@82!N86=Y('-ZX6UO:R!S>NEL97,@
M8FQO:VMO="!E<F5D;>EN>65Z;F5K*0!%;&9E;&5J=&5T=&4@82!J96QS>F%V
MX70_`-MR;&%P:V5Z96SI<P!)9.EZ970`263I>F5T(&9A:G3A:F$`263I>F5T
M96L`263I>F5T96L@,@!&\W)U;6]K`%1O=N%B8NUTX7-O:P!0Z0!&<F%M92UE
M:P!&<F%N8VEA;W)S>N%G`$9R86YC:6%O<G-ZX6<`4WIA8F%D`$5L9F]G;&%L
M='/A9VD@:6YF;W)MX6-I\P!&<F%N8VEA($=U>6%N80!&<F%N8VEA(%!O;&EN
MZ7II80!&<F%N8VEA($3I;&D@5&5R_&QE=&5K`'#I;G1E:P!&96QA9/,`27+A
M;GDZ(`!2Z7-Z;&5T97,@;&7M<N%S`'1E;&EH;VQD`%1E;&IE<R!NZ78`2O9V
M]0!'86)O;@!-96QY:6L@9V%LZ7)IX6+S;"!V96=Y_&L@82!KZ7!E=`!+Z7!G
M86SI<FEA.@!'86UB:6$`2N%TZ6L`P6QT86SA;F]S(&%D871O:P!(;WIZ=6L@
M;.ET<F4@82AZ*2`E<R!K;VYF:6=U<N%C:?-JX70`02!K96QE=&ME>F5T="!K
M\V0`1W+Z>FEA`$[I;65T;W)S>N%G`$=HX6YA`$=I8G)A;'3A<@!+97)E<WIT
M;NEV`$=L;V+A;&ES(&)EX6QL[73A<V]K`$UE:&5T`$?V9&5L`$=O;V=L92!T
MZ7)KZ7``1V]O9VQE(&ME<F5SZ7,`56=RX7,@:61E.B`E<P!&96ME=&4O9F5H
MZ7(`1_9R]F=O<G-ZX6<`9_9R]F<@*$E33RTX.#4Y+3<I`$=R]FYL86YD`$=R
M96YA9&$`0W-O<&]R="!A9&UI;FES>G1RX6-I\P!!(&-S;W!O<G1NZ78@;6%R
M861H870@_')E<V5N`$=R;W5P7VQD87`Z("5S(&-S;W!O<G0@:&]Z>N%A9.%S
M82!N96T@<VEK97+\;'0N($$@<WIE<G9E<B!VX6QA<WIA.B``1W)O=7!?;&1A
M<#H@)7,@8W-O<&]R="!T]G)LZ7-E(&YE;2!S:6ME<OQL=`!'<F]U<%]L9&%P
M.B`E<R!C<V]P;W)T(&%D871A:6YA:R!M96?Z:NUTX7-A(&YE;2!S:6ME<OQL
M=`!#<V]P;W)T;VL`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!696YDZ6<@:F]G;W-U;'1SX6=O:P!696YDZ6=K]FYY=@!'=6EN96$`0FES
M<V%U+4=U:6YE80!'=7EA;F$`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA
M:FQA;F3S(&$@<V]R('5T;VQS\R!C96QLX6KA="!T]G+V;&YI+@!(5$U,07)E
M82!G>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA="!U=&]L<_,@
M;W-Z;&]PX70@=/9R]FQN:2X`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA
M:FQA;F3S(&$@=.%B;.%Z870@=71O;'/S('-O<N%T('3V<O9L;FDN`$$@2%14
M4"!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('1A;.%L:&%T\RX`2&%I=&D`
M2&%S:"!A;&=O<FET;75S`$OV9`!&96ILZ6,`1F5J;.EC`$AE87)D+2#I<R!-
M8T1O;F%L9"US>FEG971E:P!%<O5S('II=F%T87(`:.EB97(@*$E33RTX.#4Y
M+3@M22D`36%G87-SX6<`4V5G[71SZ6<`4V5G[71SZ6<@82!S>F5R:V5S>G3U
M(&AA<WINX6QA=.%H;WH`4V5G[71SZ6<`1NEL=&5K90!%>B!A(&;A:FP@96QE
M:F4Z`$YE(&UU=&%S<W-U:P!.92!M=71A<W-U:R`E<RUT`&YA9WD`2V5Z9/5L
M87``5F%T:6OA;G;A<F]S`$ME>F3U;&%P`$]T=&AO;FD@8^UM`%-Z96WI;'EE
M<R!A;&OV;GEV=.%R`$]T=&AO;FD@=&5L969O;@!(;VYD=7)A<P!(;VYG:V]N
M9P!(;W)D90!(;W)D92]+;VQA8CH@:&EBX7,@)7,@6$U,(&%D870@=F%N(&$H
M>BD@)7,@_'IE;F5T8F5N`$AO<F1E+TMO;&%B.B!N:6YC<R!A*'HI("5S(&]B
M:F5K='5M;F%K(&UE9V9E;&5L]2#\>F5N970`2&]R9&4O2V]L86(Z(&YI;F-S
M("5S('3M<'5S^B!O8FIE:W1U;2!A*'HI("5S(/QZ96YE=&)E;@!(;W)D92]+
M;VQA8CH@4VEK97)E<V5N('3V<O9L=/QK(&5Z=#H@)7,@(B5S(@!(;W)D92]+
M;VQA8CH@87H@:6YT96=RX6SS('!R;V=R86UH;WH@<WK\:W/I9V5S(&$@)V1O
M;7AM;"<@4$A0(&+U=NUTZ7,`2&]R9&4O2V]L86(Z(&YE;2!S:6ME<OQL="#Z
M:B!834P@9N%T(&SI=')E:&]Z;FD@82AZ*2`E<R!O8FIE:W1U;6AO>@!(;W)D
M92]+;VQA8CH@3F5M('-I:V5R_&QT('3V<O9L;FD@)7,M="`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@;F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A($U)344@
M240M:N%T(&$@:_9V971K97KU('3M<'5S^B!M96QLZ6ML971N96LZ("5S`$AO
M<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@<WII;FMR;VYI>N%L;FD@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z($YE;2!S:6ME<OQL="!A(&OV=F5T:V5Z]2!K
M]GKV<R!TX7)T97+\;&5T('-Z:6YK<F]N:7KA;.%S83H@)7,`2&]R9&4O2V]L
M86(Z(&ES;65R971L96X@:_9Z]G,@=.%R=&5R_&QE="`B)7,B`%;M>G-Z:6YT
M97,@=F]N86P`5NUZ<WII;G1E<R!M87)G\P!6[7IS>FEN=&5S.@#S<F$`2&]G
M>2!J=71O='0@:61E/R`H2^ER:OQK(.UR:F$@;65G(2D`02!N87!I(.ES(&AE
M=&D@;NEZ971E:V)E;B!M:6QY96X@:&]S<WKZ(&ED]65G>7/I9V5K('-Z97)E
M<&5L:F5N96L_`$CA;GD@;W-Z;&]P;W0@:^UVX6X@]G-S>F5O;'9A<WIT86YI
M/P!(X6YY(&YA<')A(&5L]7)E(&OI<WKM='/\;FL@:63U8F5O<WITX7-I(&EN
M9F]R;>%C:?-T/P!(X6YY(&UE>O4@*&]S>FQO<"D@=F%N/P!(X6YY('-O<G0@
M:^UVX6X@]G-S>F5O;'9A<WIT86YI/P!0X7)A=&%R=&%L;VT`4.%R871A<G1A
M;&]M.B``2'5M;W)I<W3A:P!-86=Y87)O<G-ZX6<`07H@24U!4"!L97;I;&SA
M9&$@;.ET<F5H;WKA<V$@;F5M('-I:V5R_&QT.B`E<P!!>B!)34%0(&QE=NEL
M;.%D82!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,`07H@24U!4"!L97;I;&SA
M9.%H;WH@=&%R=&]Z\R!K=O-T82!LZ71R96AO>N%S82!N96T@<VEK97+\;'0Z
M("5S`$E0(&/M;0!!>B!)4"!C[6T@;F5M(&AA=.%R;WIH873S(&UE9RX`07H@
M25`@8^UM(&YI;F-S(&$@;65G96YG961E='0@0TE$4B!T87)T;VWA;GEB86XN
M`%1I;'1O='0O;65G=N%L=&]Z;W1T($E0(&/M;2X`4V]R(&)E:6QL97-Z=.ES
M92!E9O9LZ0!)>FQA;F0`8W-A:R!I:V]N;VL`)7,@:6MO;FIA:0!I:V]N;VL@
MZ7,@<WKV=F5G`$%Z(&%Z;VYO<^UT\VAO>B!VX6QA<WIT;W1T(&5L;F5V97KI
M<SH`2&$@82!M96=J96QE;NUTZ7,@;F5M(&UE9V9E;&5L]2P@)7,@96=Y(/IJ
M(&%B;&%K8F%N('9A;/,@;65G;GEI=.%S:&]Z+@!(82#6;B!);G1E<FYE="!%
M>'!L;W)E<G0@:&%S>F[A;"P@Z7,@;F5M(&IE;&5N;F5K(&UE9R!A>B!I:V]N
M;VLL(&%K:V]R(';A;&%S<WIA(&5Z="!A>B!O<&-I\W0L(&UE;&QY96P@:VEK
M87!C<V]L:F$@82!03D<@:^EP96L@=')A;G-Z<&%R96YC:>%JX70N`$AA(&SA
M=&IA(&5Z="!A('-Z]G9E9V5T+"!D92!A(&OI<&5T(&YE;2P@86MK;W(@8O9N
M9^ES>O5P<F]G<F%M:F$@;F5M(&OI<&5S(&UE9VIE;&5N[71E;FD@82!S>F5R
M=F5R<F4@:_QL9&5N9/4@:^EP970N`$AA(&$@8O9N9^ES>O5P<F]G<F%M:F$@
M;F5M('3A;6]G871J82!A>B!I5&EP(&OI<NES96ME="P@86MK;W(@87H@86SA
M8F)I('-Z]G9E9V5K(&OV>OQL(&$@;65G9F5L96SU<F4@:V%T=&EN='9A(&3V
M;G1H970@82!M96=H[7;A<R!E;&9O9V%DX7/A<O-L+@H*02!M96=H[7;A<R!E
M;&9O9V%DX7-A.@HE<PH*02!M96=H[7;A<R!F96QTZ71E;&5S(&5L9F]G863A
M<V$Z"B5S"@I!(&UE9VCM=N%S('9I<W-Z875T87/M=.%S83H*)7,`16SU>F5T
M97,@;NEZ970Z`$$@:^EP(%523"UJ90!!(&OI<"!54DPM:F4Z`$UE;'EI:R!G
M86SI<FGA8O-L('9A;B!A(&OI<`!+Z7`@96)B]6P@82!G86SI<FGA8O-L.@!+
MZ7`@9F5L=/9L=.ES90!+Z7!E:P!.87!TX7(@:6UP;W)TX6SA<RP@)60N(&SI
M<.ES`$EM<&]R=.%LX7,L("5D+B!LZ7#I<P!.87!TX7(@:6UP;W)TX6SA<V$O
M97AP;W)TX6SA<V$`07H@:6UP;W)TX6QT(&UE>O4Z("5S`$%Z(&EM<&]R=.%L
M="!M97KU:SH`4V]R(&)E:6QL97-Z=.ES92!E>F%LX0!(:6+A<R!P87)A;F-S
M<&%R86WI=&5R+@!.96T@;65G9F5L96SU(&$@8F5J96QE;G1K97KI<VD@;NEV
M(.ES+W9A9WD@82!J96QS>O,N`$YE;2!M96=F96QE;/4@82!F96QH87-Z;N%L
M\VD@;NEV('9A9WD@87H@86QT97)N873M=B!C[6TN(%!R\V+A;&IA(/IJ<F$@
M=F%G>2!F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+"!H82!T;W;A8F)I
M('-E9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+@!"96ME>F3I<R!B96QJ96)B`$EN
M9&EA`$5G>65S(&9E;&AA<WINX6SS:P!);F1O;NEZ:6$`26YF;W)MX6-I\P!)
M;F9O<FWA8VGS`$%Z(&EN9F]R;>%C:?,@;>%R(&YE;2#A;&P@<F5N9&5L:V5Z
MZ7-R92X`3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6X`2^EP(&)E:6QL97-Z=.ES
M90!4X6)LX7IA="!B96EL;&5S>G3I<V4`3&EN:R!LZ71R96AO>N%S80!/<WIL
M;W`@8F5S>OIRX7-A(&5Z96SI`$]S>FQO<"!B97-Z^G+A<V$@97IU=.%N`$]S
M>FQO<"!B97-Z^G+A<V$@97IE;.D`4V]R(&)E<WKZ<N%S82!E>F%LX0!3;W(@
M8F5S>OIRX7-A(&5F]FSI`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>G5TX6X`
M0F5K97IDZ7,@8F5I;&QE<WITZ7-E(&5Z96SI`$AO>GIU;FL@;.ET<F4@86QT
M97)N873M=B!S86)L;VYT`$%D:F]N(&UE9R!E9WD@96UA:6P@8^UM970L(&UE
M;'ER92!E;&O\;&1H973U(&%Z(-9N(/IJ(&IE;'-Z879A.@!#96QL82!B96EL
M;&5S>G3I<V4@97IU=.%N`$-E;&QA(&)E:6QL97-Z=.ES92!E>F5LZ0!/<WIL
M;W`@8F5S>OIRX7-A(&5Z=73A;@!/<WIL;W`@8F5S>OIRX7-A(&5Z96SI`$QE
M=F5L96L@8F5MX7-O;.%S80!"96ME>F3I<R!B96EL;&5S>G3I<V4@97IU=.%N
M`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>F5LZ0!3;W(@8F5S>OIRX7-A(&5Z
M86SA`%-O<B!B97-Z^G+A<V$@96;V;.D`061J82!M96<@82!K[7;A;G0@=N%L
M87-Z="!A(&)I>G1O;G/A9VD@:^ER9.ES<F4Z`$OI<"!B96EL;&5S>G3I<V4O
M;?-D;W/M=.%S80!,:6YK(&)E:6QL97-Z=.ES92]M\V1O<^UTX7-A`$$@<WKA
M;6SA:N%N(&YI;F-S(&5LZ6<@9F5D97IE="#\>F5N971E="!K_&QD96YI(&$@
M:_9R;&5VZ6QL:7-TX7)A+@!!('-ZX6ULX6KA;B!N:6YC<R!E;.EG(&9E9&5Z
M970N`$5GZ7-Z`$5GZ7-Z('-ZX6UO:R!L:7-TX6IA`$AI8N%S+V5L9F]G861H
M871A=&QA;B!51$@@*%5S97(@1&%T82!(96%D97(I+@!(:6+A<R]E;&9O9V%D
M:&%T871L86X@6DE0('3V;?9R[73I<P!(:6+A<R]E;&9O9V%D:&%T871L86X@
M86QK86QM87KA<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&)A=&-H(&%Z;VYO
M<^UT\RX`02!K_&QD]G1T(&%D870@:&EBX7,O96QF;V=A9&AA=&%T;&%N+@!(
M:6+A<R]E;&9O9V%D:&%T871L86X@8^UM>NES+@!(:6+A<R]E;&9O9V%D:&%T
M871L86X@9N%J;"!F;W)MX71U;0!(:6+A<R]E;&9O9V%D:&%T871L86X@;&EC
M96YS>FMU;&-S+@!(:6+A<R]E;&9O9V%D:&%T871L86X@=N%R;W,N`$AI8N%S
M+V5L9F]G861H871A=&QA;B#\>F5N971T[7!U<RX`2&EBX7,O96QF;V=A9&AA
M=&%T;&%N('9A9WD@:&GA;GEZ\R!P<F]G<F%M;WKA<VEF96S\;&5T+6%Z;VYO
M<^UT\RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N('!A<F%MZ71E<F5K+@!(:6+A
M<R!A>B!O8FIE:W1U;2!E;.ERZ7-I(&IO9V]S=6QT<^%G82X`2&EBX7,O96QF
M;V=A9&AA=&%T;&%N('!A<G1N97)A>F]N;W/M=/,N`$AI8N%S+V5L9F]G861H
M871A=&QA;B!T97)MZ6MK\V0N`$AI8N%S+V5L9F]G861H871A=&QA;B!P<F]T
M;VMO;&PN`$AI8N%S+V5L9F]G861H871A=&QA;B!C[6UZ971T.B`B)7,B`$AI
M8N%S+V5L9F]G861H871A=&QA;B!M96=O<WIT;W1T(&]B:F5K='5M`$AI8N%S
M+V5L9F]G861H871A=&QA;B!F96QA9/-I(&/M;2X`2&EBX7,O96QF;V=A9&AA
M=&%T;&%N('5N:6-O9&4@861A="X`3GEI;';A;G1A<G3A<P!!(&MI:F5L]FSI
M<R!I;G9E<G3A;.%S80!)<N%N:2!)<WILX6T@2_9Z=.%R<V%SX6<`27)A:P#-
M<F]R<WKA9P!-86XM<WII9V5T`%-Z\W)VX6YY;W,@>FEV871A<F]K`$EZ<F%E
M;`!!('1A;OIS[71VX6YY(&MI863S:F$`9/5L=`!/;&%S>F]R<WKA9P!*86UA
M:6-A`&IA;G7A<@!*87#A;@!J87#A;B`H25-/+3(P,C(M2E`I`$IE<G-E>0!*
M;W)DX6YI80!J^FQI=7,`:OIN:75S`%-O<FMI>N%RX7,`:_9ZZ7!R92!R96YD
M97KI<P!S;W)K:7KA<N%S(&UI;F1KZ70@;VQD86QR80!S;W)K:7KA<N%S(&)A
M;')A`'-O<FMI>N%RX7,@:F]B8G)A`$MA>F%H<WITX6X`5&%R='-U:R!M96<@
M87H@97)E9&5T:70_`$ME;GEA`$$@:V5R8F5R;W,@<WIE<G9E<B!E;'5T87/M
M=&]T=&$@82!F96QH87-Z;N%L\V%Z;VYO<^UTX7-T+@!+97ID]2!K97)N96QF
M96IL97-Z=/5K`$MU;&-S(&SI=')E:&]ZX7-A`$$@:W5L8W,@;&5N>6]M871A
M`$MU;&-S:&]S<WKZ<^%G`$MU;&-S('3M<'5S`$$@:W5L8W,@:&%S>F[A;&%T
M80!!(&MU;&-S(&WA<B!LZ71E>FEK(&$@;GEI;';A;F]S(&MU;&-S<WIE<G9E
M<F5N+@!+=6QC<W-Z879A:P!'>65R96ME:P!+:7)I8F%T:0!+;W)E86D@3NEP
M:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<`2V]R96%I($OV>G3A<G-A<^%G
M`&MO<F5A:2`H155#+4M2*0!+=79A:70`2VER9VEZ:7-Z=.%N`%]497)V97KI
M<P!.>65L=@!,86]S>FD@3NEP:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<`
M87H@96QM^FQT(#(T(/-R80!U=&]L<_,@9NEL`%5T;VQS\R!M\V1O<^UTX7,`
M3?IL="!H\VYA<`!!>B!U=&]L<_,@:F5L<WKS=N%L=.%S`'5T;VQS\R!N96=Y
M960`571O;'/S(';A;'1O>G1A=.%S.@!M^FQT(.EV`%5T;VQS\R!B96IE;&5N
M=&ME>NES.B`E<P!5=&]L<_,@8F5J96QE;G1K97KI<SH@)7,L("5S(&/M;7+U
M;`!5=&]L<_,@8F5J96QE;G1K97KI<SH@;>EG('-O:&$@;F5M('9O;'0`;?IL
M="!HZ70`3&5T=&]R<WKA9P!*;V<`16QH96QY97KI<P!(86=Y:F$@_')E<V5N
M+"!H82!N96T@86MA<B!K97)E=&5T`$QI8F%N;VX`8F%L`$)A;"!O;&1A;&D@
M9F5J;.EC`$)A;"!O;&1A;&D@Z7)TZ6ME:P!,97-O=&AO`%-Z:6YT`$QI8NER
M:6$`3.UB:6%I($%R86(@4WIO8VEA;&ES=&$@3F%G>2!.Z7!I($OV>O9S<^EG
M`$QI96-H=&5N<W1E:6X`1WEE;F=E('-Z:73A;/,@97/U`$=Y96YG92!E<_4`
M1.EL96SU='0@9WEE;F=E(&5S]0!$Z6QU=.%N+V5S=&4@9WEE;F=E(&5S]0!'
M>65N9V4@>N%P;W(`1WEE;F=E('II=F%T87(`1WEE;F=E(&AA=F%ZX7,`1WEE
M;F=E(&CS>N%P;W(`2V]R;.%T;WIZ=6L@87H@97AP;W)TX6QA;F3S(&%D871O
M:R!I9/5I;G1E<G9A;&QU;>%T.@!,:6YK`$$@;&EN:R!I9&4@;75T870Z`$UE
M9VIE;&5N[73I<VMO<B!M=71A<W-O;B!E9WD@;&EN:R!A(&QE=NEL8^UM<O5L
M(&$@;&5VZ6SM<O,@86)L86MH;WH`3&EN:V5K`$QI;G5X`$QI<W3A>N%S("T@
M82!F96QH87-Z;N%L\R!LX71J82!A(&UA<'#A=`!!>B!A9&%T8N%Z:7-O:R!L
M:7-TX6IA`$%Z;VMN86L@82!TZ6WA:VYA:R!A(&QI<W3A:F$@86UI<O5L('-E
M9^UT<^EG(&MA<&AA=/,`07H@861A='3A8FSA:R!L:7-TX6IA`$QI<W1A(&%R
M8VCM=G5M`$QI<W1A('-E9^UT<^EG:^ERZ7,`3&ES=&$@87IO;F]S[73S`$QI
M<W1A('1U;&%J9&]N;W,`3&ES=&$@;&5VZ6SM<N%S`$QI<W1A(&9E;&ER871K
M;WKA<R`H<W5B<V-R:6)E*0!,:7-T82!L96ER871K;WKA<R`H=6YS=6)S8W)I
M8F4I`$$@9F5L:&%S>F[A;/-K87!C<V]L871O:R!K:6QI<W3A>N%S82!N96T@
M<VEK97+\;'0Z("5S`$$@9F5L:&%S>F[A;/-K(&MI;&ES=.%ZX7-A(&YE;2!S
M:6ME<OQL=#H@)7,`02!F96QH87-Z;N%L\VL@:VEL:7-TX7KA<V$@=&EL='9A
M('9A;BX`27)O9&%L;VT`3&ET=N%N:6$`2&5L>0!,973V;'3I<RXN+@!(96QY
M:2!I9/4Z(`!.>65L=BP@9.%T=6TL(&ED]0!(96QY`$)E:F5L96YT:V5ZZ7,`
M07H@96SU>O4@861A='-Z:6YK<F]N:7KA8VGS(&YA<&SSX6QL;VWA;GEA`$MI
M:F5L96YT:V5ZZ7,`0F5J96QE;G1K97KI<P!"96IE;&5N=&ME>NES<V5L(&MA
M<&-S;VQA=&]S(&9E;&%D871O:P!!(&)E:F5L96YT:V5ZZ7,@;F5M('-I:V5R
M_&QT+"!M97)T(')O<W-Z(&9E;&AA<WINX6SS;F5V970@=F%G>2!J96QS>O-T
M(&%D;W1T(&UE9RX`02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="X`2&]S
M<WKZ('-Z]G9E9P!3>F5R96QE;0!A;&%C<V]N>0!G]G+V9R!K:7-B973[:P!L
M871I;B!K:7-B973[:P!K:7-B973[<R!R\VUA:2!S>N%M;VL`3'5X96UB=7)G
M`$U-`$YA<&D@_'IE;F5T96L`07H@35,M5$Y%1B!M96QLZ6ML971B96X@;FEN
M8W,@861A="X`W%I%3D54`$UA:V'S`$UA:V5D\VYI80!-861A9V%S>FOA<@!6
M87+A>G-L870`3&5V96QE>NES`$5M86EL(&1O;6%I;B!K97IE;.ES`$QI;FL@
M:^ES>NUTZ7-E`$UA;&%W:0!-86QA:GII80!-86QD[78M<WII9V5T96L`36%L
M:0!-X6QT80!4X79O;&D@;F%P=.%R86L@:V5Z96SI<V4N`$%D871A:70@:V%T
M96?S<FGA:V)A('-O<F]L:&%T:F$N($5Z96L@:71T(&1E9FEN:>%L:&%T\VLL
M(&WS9&]S[71H873S:RP@=&]VX6)BX2!S>NUN96L@<F5N9&5L:&5T]6L@:&]Z
M>N%J=6LN`$UA<#(T('3I<FOI<`!-87!1=65S="!TZ7)KZ7``02!H;WIZX7)E
M;F1E;.ES96ME="!E;&UE;G1E='3\:RX`;>%R8VEU<P!-87)G\P!!>B!/;'9A
M<V]T="]/;'9A<V%T;&%N(&IE;'IE=&5K(&AA<WINX6QA=&$`3>%S(&IE;'IE
M=&5K("AP;"X@1F]N=&]S+TUE9W;A;&%S>F]L="D@:&%S>F[A;&%T80!-87)S
M:&%L;"US>FEG971E:P!-87)T:6YI<75E`$5G>6WA<VYA:R!M96=F96QE;/4@
M;65Z]6L`36%U<FETX6YI80!-875R:71I=7,`36%X:6WA;&ES(')E;F1E;&ME
M>NES<F4@X6QL\R!S>N%M;&'V<W-Z96<N`$%Z(/QZ96YE="!T^FP@<V]K('+I
M<WIB]6P@X6QL+@!!>B!E;&WZ;'0@,C0@\W)A(&UA>&EMX6QI<R!H]6WI<G/I
M:VQE=&4Z(`!!>B!E;&WZ;'0@-B#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK;&5T
M93H@`$%Z(&5L9F]G;&%L='/A9V]K(&UA>&EMX6QI<R!S>N%M80!!>B#V<W-Z
M96?U;VQD86P@8FQO:VMJ86EN86L@;6%X:6WA;&ES('-ZX6UA`$UA>&EMX6QI
M<R!H;W-S>@!MX6IU<P!-87EO='1E`,EN`$]R=F]S='5D;VWA;GD`365G8F5S
M>NELZ7,`5&%G;VL`1FEG>65L;65Z=&5TZ7-E:P!-96[\;&ES=&$`02!M96[\
M(&UE9VIE;&5NZ7-E.@!#96QLX6L@96=Y8F5O;'9A<WITX7-A`-QZ96YE=`!!
M(&1I9VETX6QI<V%N(&%LX>UR="#\>F5N970@:&ET96QE<RP@9&4@87H@86SA
M[7+S('1A;OIS[71VX6YYX70@;F5M('-I:V5R_&QT(&5L;&5N]7)I>FYI+@!,
M96KA<G0@87H@_'IE;F5T(.ER=NEN>65S<^EG92X`07H@_'IE;F5T('3M<'5S
M80!-971A<B!I9/5JX7+A<VIE;&5N=.ES`$$@365T87(@8FQO:VL@;F5M(.%L
M;"!R96YD96QK97KI<W)E+@!!($UE=&%R(&)L;VMK(&YE;2#A;&P@<F5N9&5L
M:V5ZZ7-R92X@02!RZ7-Z;&5T96L@82!R96YD<WIE<F=A>F1A('-ZX6WA<F$@
M:^ES>OQL]2!N87!L\V;A:FQB82!K97+\;'1E:RX`02!-971A<D1"(&YE;2#I
M<FAE=/4@96PN`$WS9'-Z97(`02AZ*2`B)7,B(&WS9'-Z97(@9&5F:6YIX6QA
M=&QA;@!!(&WS9'-Z97(@9&5F:6YIX6QA=&QA;BX@02!M96=H[79O='0@;?-D
M<WIE<CH@)7,`365T<FEK=7,`365X:6OS`$UI:W)O;NEZ:6%I(%-Z]G9E='/I
M9VD@P6QL86UO:P!K]GKI<`!-24U%('3M<'5S`$%Z(&5L;?IL="`R-"#S<F$@
M;&5G86QA8W-O;GEA8F(@:/5MZ7)SZ6ML971E.B``07H@96QM^FQT(#8@\W)A
M(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T93H@`$WI9R!N96T@=&5L="!E
M;"!A(&UI;FEMX6QI<R!I9/4@82!J96QS>O,@;65G=N%L=&]Z=&%TX7/A:&]Z
M`'!E<F,`5/QK<O9ZZ7,@*&IO8F(O8F%L*0!696=Y97,`2&GA;GEZ:6L@82!(
M5%107U)E<75E<W0@4$5!4B!C<V]M86<N`$MO;F9I9W5RX6-I\R!S>OQK<^EG
M97,N($5Z="!M;W-T(&ME;&P@;.ET<F5H;WIN:6$L(&AA(&AA<WINX6QN:2!A
M:V%R:F$@87H@86QK86QM87KA<W0N`$AIX6YY>FEK(&%Z(/QZ96YE="!A>F]N
M;W/M=/-J82X`2&GA;GEZ:6L@82!-86EL(%!%05(@8W-O;6%G+@!(:>%N>7II
M:R!A(&9E;&AA<WINX6SS:V%P8W-O;&%T(&%Z;VYO<^UT\VIA("AS97-S:6]N
M($E$*2X`2.D`3&5V96QE>NES(&UO8FEL=&5L969O;G+S;`!+]GIE<&5S`$$@
M;?-D;W/M=.%S(&3A='5M80!!>B!54DP@;?-D;W/M=.%S80!-;V1U;'5S`$UO
M;&1O=F%I($OV>G3A<G-A<^%G`$UO;F%C;P!HZ71F]0!-;VYG\VQI80!H\VYA
M<`!(879I(&UE9VIE;&5N[73I<P!(\VYA<"#I<R#I=@!H879O;G1A`$%Z(&5L
M9F]G;&%L='/A9V]K(&AA=FD@;&ES=.%J80!H879O;G1A.B!I<VWI=&SU9&EK
M(&UI;F1E;@!H\VYA<&]K:V%L(&5L]7)E`&CS;F%P<&%L(&MO<N%B8F%N`$UO
M;G1S97)R870`2&]L9&;A>FES;VL`02`E9"X@<V]R8F%N('3V8F(@;65Z]2!V
M;VQT+"!M:6YT(&$@=N%R="`E9"X`36%R;VMK\P!4]F)B;GEI<F4@9&5R_&QT
M`%3V8F)N>6ER92!B;W)U;'0`5/9B8FYY:7)E(&YA<&]S`'9I9WG\:R!L90!V
M:6=Y_&L@8F%L<F$`=FEG>?QK(&IO8F)R80!V:6=Y_&L@9O9L`'9I9WG\:R!L
M90!V:6=Y_&L@9O9L`$UO>F%M8FEK`%3V8F)S>FEN=/L@;&5G]G)D_&SU(&QI
M<W3A:P!-=6QT:6UA<"!.86=Y+4)R:71A;FYI82!TZ7)KZ7``5/9B8B!I0V%L
M96YD87(@:V]M<&]N96YS('9A;B!J96QE;CL@8W-A:R!E9WD@=D5V96YT(&AA
M<WINX6QA=&$@=.%M;V=A=&]T="X`5/9B8G-Z]G+V<R!VX6QA<WITX7,`0F5J
M96QE;G1K97KI<VD@8F7A;&SM=.%S;VL`0F5J96QE;G1K97KI<VD@861A=&%I
M;0!!>B#I;B!N87!TX7)A:6T`07H@Z6X@;F%P=.%R86EM.@!)9/5B96]S>G3A
M<VD@=V5B(&/M;65M`%-A:N%T(/9S<WIE9WKU(&]L9&%L86T`4V%JX70@]G-S
M>F5G>O4@;VQD86QA;2!T97)V97KI<V4`36EA;FUA<@!.14TL(&YE;2!E9WEE
M>F5M(&)E;&4N`$[I=@!.86WM8FEA`$YA=7)U`$YE<.%L`$AO;&QA;F1I80!(
M;VQL86YD($%N=&EL;.%K`$YE='-C87!E(&+A>FES+5523`!.971S8V%P92!T
M86[Z<^UT=N%N>6MI863A<VEJ;V<H0T$I+79I<W-Z879O;N%S:2!54DP`3F5T
M<V-A<&4@=&%N^G/M=';A;GEF96QH87-Z;N%LX7-I(&ERX6YY96QV(%523`!.
M971S8V%P92!T86[Z<^UT=N%N>6UE9_IJ[73A<VD@55),`$YE='-C87!E('1A
M;OIS[71VX6YY=FES<WIA=F]NX7-I(%523`!.971S8V%P92!34TP@<WIE<G9E
M<F[I=@!.971S8V%P92!T86[Z<^UT=N%N>2!M96=J96=Y>NES`$YE='-C87!E
M('1A;OIS[71VX6YY=.UP=7,`2.%L\WIA=`!S;VAA`-IJ+4MA;&5D\VYI80#:
M:B!K871E9_-R:6$`VFH@96QF;V=L86QT<^%G`-IJ(&QE=NEL("5S(&/M;7)E
M`/IJ:&]L9`#::B!F96QH87-Z;N%L\V[I=B`H;W!C:6]NX6QI<RD`VFHM6NEL
M86YD`-IJ(&YA<'3A<G0@:&]Z='5N:R!LZ71R92P@;65L>2!A=71O;6%T:6MU
M<V%N(&OV>O9S(&AA<WINX6QA=&)A(&ME<OQL(&$@:_9V971K97KU(&-S;W!O
M<G1O:VMA;#H@)7,N`-IJ(&IE;'-Z\P!!>B#Z:B!J96QS>O,@Z7)VZ6YY97-S
MZ6=E(&5K:V]R(&KA<B!L93H@)7@N`$$@;65G861O='0@^FH@:F5L<WIA=F%K
M(&YE;2!E9WEE>FYE:RX`VFH@86)L86L@*/QR97,I`$CM<F5K`$CM<F-S;W!O
M<G1O:P!+]G9E=&ME>O4`82!K]G9E=&ME>O4@,C0@\W)A`$OV=F5T:V5Z]2`T
M(&;A>FES`&WA<VYA<`!+]G9E=&ME>O4@:/-N87``:_9V971K97KU(&CI=`!K
M]G9E=&ME>O4@Z78`3>%S;F%P`$OV=F5T:V5Z]2!O<&-I\VL`:_9V971K97KU
M(&CI=`!+]G9E=&ME>O4^`$YI8V%R86=U80!.:6=E<@!.:6?I<FEA`.EJ<WIA
M:V$`3FEU90!.96T`3FEN8W,@9FEG>65L;65Z=&5TZ7,`;FEN8W-E;F5K('+I
M<WIT=F5V]6L`3FEN8W,@<F5N9&5L:V5ZZ7-R92#A;&SS(&MO;F9I9W5RX6-I
M\RP@86UI:&5Z(&OI<&5S="!A(&O\;/9N8G/I9V5K970@;65G(&QE:&5T;F4@
M;75T871N:2X`3FEN8W,@;&5H973U<^EG($E33R#A;&QO;>%N>6]K(&SI=')E
M:&]ZX7/A<F$N`$AIX6YY>FEK(&$@:_9T96=E;'0@9F5L9&]L9V]ZX7-H;WH@
M<WK\:W/I9V5S(&UI;G1A("AB871C:"!T96UP;&%T92DN`$$@:^UVX6YT(&AE
M;'EE;B!N:6YC<R!B;&]K:P!!>B!-0T%,(&9E;&AA<WINX6SS87IO;F]S[73A
M<VAO>B!N:6YC<R!M96=A9'9A(&$@;F%P=.%R(&YE=F4N`$$@=F5N9.EG(&9E
M;&AA<WINX6SS:R!RZ7-ZZ7)E(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92!N87!T
MX7(N`$YI;F-S(';A;'1O>N%S+@!%:&AE>B!A(&IO9V]S=6QT<^%G:&]Z(&YE
M;2!H;WIH873S(&SI=')E(&IO9V]S=6QT<^%G:2!A;&-S;W!O<G0N`$AIX6YY
M;WIN86L@82!K;VYF:6=U<N%C:?-S(&%D871O:R`E<RUH97HN`$%Z($944"!6
M1E,@;FEN8W,@:V]N9FEG=7+A;'9A+@!!>B!344P@5D93(&YI;F-S(&MO;F9I
M9W5RX6QV82X`07H@4U%,+49I;&4@5D93(&YI;F-S(&MO;F9I9W5RX6QV82X`
M07H@UFX@<WKA;6SA:N%N(&5L9F]G>6]T="!A(')E;F1E;&ME>NES<F4@X6QL
M\R#V<W-Z96<N`$YI;F-S(&/M;7KI<RX`;FEN8W,@=NEG90!.:6YC<R!M96=J
M96QE;NUT:&5T]2!E;&9O9VQA;'1SX6<`02!S>F5R=F5R<F4@;F5M('3V;'3U
M9/9T="!F96P@<V5M;6EL>65N(.%L;&]MX6YY`"5S(&ED]6)E;W-Z=.%S:2!A
M9&%T86D@;F5M(.ER:&5T]6L@96P`3F5M('1A;.%L:&%T\R!I0V%L96YD87(@
M861A="X`07H@:6MO;F]K(&YE;2!T86SA;&AA=/-K+@!.:6YC<R!M96=A9'9A
M(&$@:&5L>2X`3FEN8W,@;65G861V82!A(&AE;'DN`$%Z(/QZ96YE="#\<F5S
M+@!.:6YC<R!M96=A9'9A(&$@;NEV+@!.:6YC<R!M96=A9'9A(&$@<WKA;2X`
M3F4@;&5G>65N(&UE9V)O='+A;FMO>G1A=/,@:63I>F5T`$YI;F-S(&IE;'-Z
M\R!M96=A9'9A(&$@2%144"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A
M<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@87H@24U!4"!A;&%P^B!F96QH
M87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@
M82!+97)B97)O<R!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`
M3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!,;V=I;B!A;&%P^B!F96QH87-Z;N%L
M\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!005-3
M5T0@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN`$YI;F-S(&IE
M;'-Z\R!M96=A9'9A(&%Z(%--0B!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S
M[73A<VAO>BX`3FEN8W,@;65G861V82!A>B!/<&5N4U-,('!R;V=R86T@96SI
M<NES:2#Z='9O;F%L82X@07H@3W!E;E-33"!P<F]G<F%M('-Z_&MSZ6=E<R!A
M(%!+0U,@,3(@861A=&]K(&ME>F5LZ7/I:&5Z+@!.:6YC<R#Z:B!B96IE;&5N
M=&ME>NES:2!I9^EN>2X`3FEN8W,@:W;S=&$@8F7A;&SM='9A+@!.:6YC<R!I
M<VWI=&SU9.ES`$YE(&QE9WEE;F5K('9O;F%L86L@<V5H;VPN`$YI;F-S(&1E
M9FEN:>%L=F$@96QVX6QA<WIT\R!K87)A:W1E<BX`3F4@;&5G>65N(&ME<F5T
M`$YI;F-S(&EL>65N(&;A:FP`3FEN8W,@:61E:6=L96YE<R#A;&QO;>%N>6]K
M('3A<F]LX7/A<F$@<WIO;&?A;/,@86QK]FYY=G3A<BX`2&GA;GEZ:6L@82!F
M96QH87-Z;N%L\V[I=B#I<R]V86=Y(&$@:F5L<WKS+@!!('9I<W-Z86MA<&]T
M="!A9&%T;VL@;F5M(.ER=NEN>65S(%A-3"!A9&%T;VL`3F5M('1A;.%L:&%T
M\R#I<G;I;GEE<R!E;6%I;"!C[6T`3FEN8W,@861A=`!.:6YC<R!MZ6<@:V]N
M9FEG=7+A8VGS+"!G96YE<N%L:F]N(&5G>65T+@!.:6YC<R!MZ6<@:V]N9FEG
M=7+A8VGS:F$L(&=E;F5RX6QJ;VX@96=Y970N`&YI;F-S`&YI;F-S(&UE9V%D
M=F$@*&QE9WEE;B!A;&%PZ7)T96QM97IE='0I`&YO<F1I:W5S("A)4T\M.#@U
M.2TQ,"D`3F]R9F]L:RUS>FEG970`R7-Z86MI(&;I;'1E:V4`R7-Z86MI+4UA
M<FEA;F$M<WII9V5T96L`3F]R=NEG:6$`3F5M(&OI<_5B8@!.96T@:V]RX6)B
M86X`3F5M(&%L:_9N>79TX7(`;F5M('1A;.%L:&%T\P!!('!R;V=R86UN86L@
M97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!.:6YC<R!B9>%L
M;.UT=F$`3F5M('3A;6]G871O='0N`$9E;&IE9WEZZ7-E:P!.:6YC<R!B]FYG
MZ7-Z:&5T]2!A9&%T+"!TZ7)J96X@=FES<WIA+@#)<G1E<^UTZ7-E:P!N;W9E
M;6)E<@!M;W-T`%-ZX6T`2V%R86MT97)E:R!S>N%M80!/<WIL;W!O:R!S>N%M
M80!3;W)O:R!S>N%M80!!(&OV<FQE=NEL;&ES=&$@;?-D;W/M=.%SX6AO>B!N
M96T@861O='0@;65G('-ZX6UO:V%T+@!/2P!/8FIE:W1U;0!!>B!O8FIE:W1U
M;2!LZ71R96AO>O-J80!/:W3A;&ES('-ZX6T`;VMT\V)E<@!3>OMRZ7,`2&EV
M871A;"]M=6YK86AE;'D`02!RZ6=I(.ES(&%Z(/IJ(&IE;'-Z\VYA:R!K_&SV
M;F+V>FYI92!K96QL+@!!('+I9VD@:F5L<WKS`$$@<NEG:2!J96QS>O,@;F5M
M(&UE9V9E;&5L]2X`3VWA;@!-:6YD96X@;F%P=.%R8F%N+"!A;6EH97H@=F%N
M(&]L=F%SX7-I(&IO9V]M`$%Z(/9S<WIE<R!M96=J96QE;NUT971T(&YA<'3A
M<F)A;@!#<V%K(&$@<V%JX70@;F%P=.%R86EM8F%N`$-S86L@87H@24U!4"!S
M>F5R=F5R96L@=.%M;V=A=&KA:R!A(&UA<'#A:R!M96=O<WITX7/A="X`0W-A
M:R!M96=B;W1RX6YK;WIT873S(&EDZ7IE="!L96=Y96X`0W-A:R!E9WD@96UA
M:6P@8^UM(&%D:&%T\R!M96<N`$-S86L@82!T=6QA:F1O;F]S('9A9WD@82!R
M96YD<WIE<F=A>F1A(';A;'1O>G1A=&AA=&IA(&UE9R!E9WD@:_9Z]G,@=.%R
M=&5R_&QE="!T=6QA:F1O;F]SX70@=F%G>2!E;.ERZ7-I(&IO9V]S=6QT<^%G
M86ET`$YY:7-S=6L@;65G(/IJ(&%B;&%K8F%N`$]P96Y34TP@:&EB83H@3F5M
M('-I:V5R_&QT(&MI;GEE<FYI(&%Z(&%D871O:V%T(&%Z(&%LX>UR="!3+TU)
M344@<NES>F+U;`!.>6ES<W5K(&UE9R!E>G0@82!C[6UE="!E9WD@^FH@86)L
M86MB86X`3W!E<N%C:?-S(')E;F1S>F5R`';A;&%S>G1H873S`$]P8VEO;N%L
M:7,@<NES>G1V97;U:P!/<&-I\VL`)7,@8F7A;&SM=.%S86D`4V]R<WKA;6]S
M(&9E;'-O<F]LX7,`4WIE<G9E>F5T`%-Z97)V97IE=&D@96=Y<^EG`$UU;FMA
M<WIE<G9E>NES`$%Z(&%L:V%L;6%ZX7,@97)E9&5T:2!S86)L;VYJ80`E<R!E
M<F5D971I('-A8FQO;FIA:3H`16=YZ6(`16=YZ6(@:6YF;W)MX6-I\P#!='1E
M:VEN=.ES`%1U;&%J9&]N;W,`02!T=6QA:F1O;F]S(&IO9V]S=6QT<^%G86D`
M5'5L86ID;VYO<SH@)7,`02!004T@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE
M;2#A;&P@<F5N9&5L:V5ZZ7-R92X`4$5!4CHZ36%I;"!A;')E;F1S>F5R`%!'
M4"!D:6=I=.%L:7,@86SA[7+A<P!01U`M=F5L('1I=&MO<^UT;W1T(&%D870`
M4$=0(&YY:6QVX6YO<R!K=6QC<P!01U`M=F5L(&%LX>UR="]T:71K;W/M=&]T
M="!A9&%T`%!(4"!K\V0`1.EL=73A;B]E<W1E(&=Y96YG92!E<_4`1.EL=73A
M;B!E<_4`1.EL=73A;B]E<W1E('KA<&]R;VL`1.EL=73A;B]E<W1E(&AA=F%Z
MX7,`1.EL=73A;B]E<W1E(&CS>N%P;W)O:P!$Z6QU=.%N(&YA<'/\=.ES`$3I
M;'5TX6XO97-T92!Z:79A=&%R;VL`2&GA;GEZ:6L@82!03U-)6"!B]7;M=.ES
M`&)E;'/U(&UA<F?S`%!A:VES>G3A;@!086QA=0!086QE<WIT:6X@5&5R_&QE
M="`H;65G<WKA;&QT*0!086YA;6$`4.%P=6$@VFHM1W5I;F5A`%!A<F%G=6%Y
M`$WI<G/I:V5L=&5N(&)O<G5L=`!*96QS>O,`02!J96QS>O-T('-I:V5R97-E
M;B!M96=VX6QT;WIT871T=6LN`$YE;2!M96=F96QE;/4@:F5L<WKS`$$@4D%$
M2553(&9E;&AA<WINX6SS87IO;F]S[73A<VAO>B!J96QS>O,@<WK\:W/I9V5S
M+@!*96QS>O,@;65G97+U<^UTZ7-S96P`2F5L<WKS.@!*96QS>O,Z(`!!(&IE
M;'-Z879A:VYA:R!E9WEE>FYI_&L@:V5L;"X`07H@96QM^FQT(&5L9F]G;&%L
M='/A9V]K(&QI<W3A:F$`0F5I;&QE<WITZ7,`0F5I;&QE<WITX7,@82!VX6?S
M87-Z=&%L<O-L`-IT=F]N86P`3?-D:F$`VFH@9F5L:&%S>F[A;/-N86L@8F5J
M96QE;G1K97IE='1E:SH`16UB97)E:P!S>N%Z86SI:P!+87)B86YT87)TX7-I
M(&9E;&%D871O:R!VZ6=R96AA:G3A<V$`0F5J96QE;G1K97KI<VMO<B!H86IT
M<W5K(';I9W)E(&$@:V%R8F%N=&%R=.%S:2!F96QA9&%T;VMA=#\`5NEG;&5G
M97-E;B!T]G+V;&K\:R!K:2!E>G0@87H@96QF;V=L86QT<^%G;W0_`$IO9V]S
M=6QT<^%G`$$H>BD@(B5S(B!J;V=O<W5L='/A9V]T(&YE;2!T]G+V;'3\:RX`
MUFYN96L@;FEN8W,@96AH97H@96QE9V5N9/4@:F]G;W-U;'1SX6=A`$IO9V]S
M=6QT<^%G;VL`2F]G;W-U;'1SX6<@861M:6YI<WIT<N%C:?,`4WIE;>EL>65S
M(&%D871O:P!097)U`,%L;&%T:V5D=F5N8V5K`$;\;/9P+7-Z:6=E=&5K`%1E
M;&5F;VX`1NEN>6OI<&=A;.ER:6$`4&ET8V%I<FX`<&EX96P`2_9Z:&5L>65K
M`$MA='1I;G1S;VX@=F%L86UE;'EI:R!C96QLX7)A`$)I>G1O<V%N('3V<O9L
M;FD@86MA<FIA(&5Z="!A>B!E;&5M970Z`$OI<F5M(&5R]7/M='-E(&UE9RP@
M:&]G>2!V86SS8F%N('3V<O9L;FD@:^UVX6YJ82!E>G0@87H@96QE;65T+@!+
MZ7)E;2!A9&IO;B!M96<@96=Y(&CS;F%P;W0@Z7,@96=Y(.EV970N`$OI<F5M
M(&%D:F$@;65G(&%Z(/IJ(&MA=&5G\W)I82!N97;I=#H`2^ER96T@=F%L\W,@
M25`@8^UM970@861J;VX@;65G+@!+Z7)E;2!V86SS<R!DX71U;6]T(&%D:F]N
M(&UE9RP@96QL96[U<FEZ>F4@82!H\VYA<"!N87!J86ET+@!+Z7)E;2!V86SS
M<R!DX71U;6]T(&%D:F]N(&UE9RX`2^ER96T@<O9V:61E;B#M<FIA(&QE(&$@
M<')O8FSI;6$@;.EN>65GZ70N`$OI<F5M(&%D:F$@;65G(&$@8F5J96QE;G1K
M97KI<VD@;F5VZ70@Z7,@:F5L<WIA=N%T`$OI<F5M(&]L=F%S<V$@96P@82!K
M]G9E=&ME>O4@<WKV=F5G970N($$@<F5N9'-Z97(@:&%S>F[A;&%TX6YA:R!F
M96QTZ71E;&5I="!E;"!+14Q,(&9O9V%D;FEA+@!+Z7)E;2!A9&IA(&UE9R!A
M>B#Z:B!K871E9_-R:6$@;F5VZ70Z`$QE;F=Y96QO<G-ZX6<`4&]L:71I:V$`
M4WIA=F%ZX7-O:P!3>F5MZ6QY97,@:V5Z9/5O;&1A;`!0;W)T=6?A;&EA`$$@
M:^EP(&5L:&5L>65ZZ7-E`$$@=.%B;.%Z870@96QH96QY97KI<V4`2_9Z=F5T
M;&5N(&QE=NEL:_QL9.ES(&5B8F4@82!M87!PX6)A("A)34%0(&YE;2!M:6YD
M:6<@=F5S>FD@9FEG>65L96UB92D`07H@96QM^FQT("5S(/-R82!C<V%P863I
M:VUE;FYY:7/I9V4Z(`!#<V%P863I:SQB<B`O/G9A;/-S>NUN^W/I9P!0<F5F
M<U]L9&%P.B!N96T@=&%LX6QH873S(&$@<WK\:W/I9V5S($Q$05`@:VET97)J
M97-Z=.ES+@!0<F5F<U]S97-S:6]N.B!N96T@=&%LX6QH873S(&$@<WK\:W/I
M9V5S("AS97-S:6]N*2!K:71E<FIE<WITZ7,N`$SI9VYY;VWA<P!!('1E;F=E
M<G-Z:6YT;F5K(&UE9V9E;&5L]2!LZ6=N>6]MX7,Z(`!,Z6=N>6]MX7,Z(`!%
M;/5Z971E<R!M96=T96MI;G3I<P!!(&OI<"!E;/5Z971E<R!M96=T96MI;G3I
M<V4@^FH@86)L86MB86X`96SU>O4@;F%P`&5L]7KU(&CI=`!%;/5Z]2!N87``
M16SU>O4@;W!C:?-K`$$@9&]K=6UE;G1U;2!K:6YY;VUT873A<V$`5&ET:V]S
M(&MU;&-S`$AI8F%B96IE;&5N=.ES`$$@:&EB82!L9>URX7-A`%!R;VIE:W0@
M:V5Z96SI<P!!('!R;VUP="!S>O9V96=E`$YY:6QVX6YO<R!K=6QC<P!.>6EL
M=N%N;W,@:W5L8W/Z(&%L9V]R:71M=7,`3GEI;';A;F]S(&MU;&-S(&EN9F]R
M;>%C:?,`02!N>6EL=N%N;W,O=&ET:V]S(&MU;&-S<.%R="!N96T@<VEK97+\
M;'0@;.ET<F5H;WIN:2X`4'5E<G1O(%)I8V\`02!L979E;&5K(';I9VQE9V5S
M('3V<FSI<V4`2V%T87(`2V5R97/U+W!A<F%N8W,@<W1R:6YG`$MV\W1A`%)3
M02!N>6EL=N%N;W,@:W5L8W,@*"5D(&)I=&5S*0!2X61I\V=O;6)O<R!K:7;A
M;&%S>G3A<P!%<_4`17/U(&3I;&5L]71T`$5S]2!DZ6QU=.%N+V5S=&4`6N%P
M;W(`17/U(.ES(&AA=F%ZX7,`2&%V87-E<_4`5NEL971L96X@:63I>F5T`$%R
MX6YY`$]L=F%SX7,`3&5V96QE:R!O;'9A<^%S80!4Z6YY;&5G('3V<O9L:OQK
M("5S(&9E;&AA<WINX6SS=#\@17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT
M:&%T\R!V:7-S>F$N`%3I;GEL96<@=/9R]FQJ_&L@)7,@9F5L:&%S>F[A;/,@
M861A=&%I=#\@17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT:&%T\R!V:7-S
M>F$N`$UE9&1I9R!I<VWI=&SU9&EK`$ES;>ET;/5DZ7-I(&%D871O:P!)<VWI
M=&SU9.ES:2!A9&%T;VL`07H@:7-MZ71L]63I<R!VZ6=E`$%Z(&ES;>ET;/5D
MZ7-I(&ED]0!!>B!I<VWI=&SU9.ES(&9A:G3A:F$`3F%P;VYT82!I<VWI=&SU
M9&EK`$AA=F]N=&$@:7-MZ71L]61I:P!(971E;G1E(&ES;>ET;/5D:6L`R79E
M;G1E(&ES;>ET;/5D:6L`VFIR82!VZ6=R96AA:G1J82!A>B!U=&]L<_,@=N%L
M=&]Z=&%TX7-T`$9R:7-S[73I<P!!(&UE;OP@9&EN86UI:W5S(&5L96UE:6YE
M:R!F<FES<^UTZ7-I(&=Y86MO<FESX6=A.@!!>B#V<W-Z96=Z]6]L9&%L(&9R
M:7-S[73I<^EN96L@9WEA:V]R:7/A9V$Z`$]B:F5K='5M(&+V;F?I<WKU`$9R
M:7-S[73I<P!-96=J96=Y>NES96L`16ULZ6ME>G1E=/4Z("5S`%3A=F]L:2!N
M87!TX7)A:P!4X79O;&D@;F%P=.%R86LZ`%3A=F]L:2!S>F5R=F5R96L`5.%V
M;VQI(&YA<'3A<B!E;/5F:7IE=.ES:2`H<W5B<V-R:7!T:6]N*2!54DP`02!T
MX79O;&D@55),("AP;"X@:'1T<#HO+W=W=RYV86QA;6DN:'4O;65G=F%L86UI
M*3H`5/9R;.ES`"5S('3V<FSI<V4`02!M96=H[79O='0@96QTX79O;.UTX7-A
M`$)L;VMK('3V<FSI<V4`3W-Z;&]P('3V<FSI<V4`02!F;W)M871TX6SA<R!T
M]G)LZ7-E`$$@<.%R('3V<FSI<V4`5/9R]FQJ_&L@87H@96QM96YT971T('!R
M;V=R86UO="!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N>6]K870@=&%R
M=&%L;6%Z\R!A;&OV;GEV=.%RX6+S;"X`5F5G>?QK(&MI(`!696=Y_&L@:VD@
M97IT(&$@<NES>G0@82!D;VMU;65N='5M8O-L`$$@9F5L:&%S>F[A;/,@=/9R
M;.ES90`E<R!F96QH87-Z;N%L\R!T]G)LZ7-E`,UR:G5K(&9E;/QL(&$@:VEV
MX6QA<WIT;W1T(&/M;6IE9WEZZ6ME="!A>B!I;7!O<G3A;'1T86P_(#QS=')O
M;F<^1FEG>65L;65Z=&5TZ7,Z(&5Z(&MI=/9R;&D@87H@]G-S>F5S(&%D871O
M="!A(&IE;&5N;&5G:2!C[6UJ96=Y>NEK8O5L(3PO<W1R;VYG/@!!(&OI<NES
M(&YE;2!T96QJ97/M=&AE=/4N($$@:V%P;W1T(&AI8F%K\V0Z(`!!(&ME<F5S
M971T('-Z;VQGX6QT873A<R!N96T@=&%LX6QH873S+@!S>OQK<^EG97,`02!K
M]G1E;&5Z]65N(&UE9V%D86YD\R`B)7,B(&YE;2!S>F5R97!E;"`E<R!K;VYF
M:6=U<N%C:?-JX6)A;BX`02!K]G1E;&5Z]65N(&UE9V%D86YD\R`B)7,B(&YE
M;2!S>F5R97!E;"!A(%9&4R!K;VYF:6=U<N%C:?-JX6)A;BX`02!K]G1E;&5Z
M]65N(&UE9V%D86YD\R`B)7,B(&YE;2!S>F5R97!E;"!A(&MO;F9I9W5RX6-I
M\V)A;BX`4WK\:W/I9V5S('+I<WIT=F5V]6L`4WK\:W/I9V5S(&UE>O4`4F5S
M970`02!J96QS>O,@X73A;&SM=.%S80!!>B#6;B!J96QS>F%VX6YA:R#A=.%L
M;.UTX7-A`$ME>F1J_&L@^FIR82!A(&MI=/9L=.ES=`!6X6QA<WH`07H@=71O
M;'/S(&ME<F5SZ7,@=FES<WIAX6QL[73A<V$`17)E9&WI;GD`5FES<WIA(&%Z
M(&]P8VGS:VAO>@!!>B#Z:B!J96QS>O-T(.UR:F$@8F4@:7-MZ70`4NEU;FEO
M;@#!;&SM='-U:R!V:7-S>F$@82!K;VYF:6=U<N%C:?-T`%)I8V@@5&5X="!%
M9&ET;W(@;W!C:?-K`%1A;.%L\W,@:^ER9.ES96L`:F]B8@!*;V)B(&]L9&%L
M:2!F96ILZ6,`2F]B8B!O;&1A;&D@Z7)TZ6ME:P!3;W(@='5L86ID;VYSX6=O
M:RXN+@!3>F5R97``4F]MX6YI80!&;W)G873A<R`Q.#`@9F]K:V%L`$)A;')A
M(&9O<F=A=.%S`$IO8F)R82!F;W)G873A<P!3;W(@='5L86ID;VYSX6=O:P!3
M;W(@='5L86ID;VYSX6=O:P!3;W)O:SH`5F]N86QA:P!-:6YD96X@<V]R(.ES
M(&]S>FQO<"!K]GKV='0@;&5G>65N('9O;F%L`$-S86L@87H@;W-Z;&]P;VL@
M:_9Z]G1T(&QE9WEE;B!V;VYA;`!#<V%K(&$@<V]R;VL@:_9Z]G1T(&QE9WEE
M;B!V;VYA;`!&=71T873A<P!/<F]S>B!&]F1E<N%C:?,`4G5A;F1A`%,O34E-
M12!D:6=I=.%L:7,@86SA[7+A<P!3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T
M:71K;W/M=&]T="!L97;I;`!305-,(&9E;&AA<WINX6SS87IO;F]S[73A<R!N
M96T@=&%LX6QH873S+@!335,@:_QL9.ES`%-13"!P87)A;F-S(&$@:V5R97/I
M<VAE>@!34T@`4TE+15+<3%0`4WIO`%-Z96YT($EL;VYA+7-Z:6=E=`!386EN
M="!+:71T<R#I<R!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@Z7,@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="#I<R!'<F5N861I;F4M<WII9V5T96L`
M56=Y86YA>B!A(&9R86UE("A?<V5L9BD`4WIA;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;>D@Z7,@4'+M;F-I<&4`3?MH;VQD87,@:6YT97)N971E;.ERZ7,`<WIO
M;6)A=`!3>F'Z9"U!<N%B:6$`365N=.ES`"(E<R(@;65N=.ES90`E<R!M96YT
MZ7-E`-IJ:^EN="!M96YT<_QK(&5L`$$@<NES>G1V97;U:R!E;&UE;G3I<V4`
M07H@96QF;V=L86QT<^%G(&UE;G3I<V4`02!B9>%L;.UTX7-O:R!M96YTZ7-E
M`$UE;G1S_&L@96P@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0@4$A0('!R
M;V=R86T@9F]R;>%JX6)A;B!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N
M>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV=.%RX6)A;BX`)7,@:V]N9FEG=7+A
M8VGS:N%T(&5L;65N=&5T=/QK+@!%;&UE;G1E='3\:R!A('-E='5P('5P9W)A
M9&4@<')O9W)A;6]T(&ED93H@(B5S(@!3>O-R=N%N>6]S('II=F%T87)O:P!4
M=61O;>%N>0!+97)E<^ES`$ME<F5SZ7,@82!N87!TX7)A:V)A;@!+97)E<^ES
M:2!S>F]L9^%L=&%TX7-O:P!!(&ME<F5SZ7,@97)E9&WI;GEE`$ME<F5S<_QK
M(&$@;F%P=.%R86MB86XZ`,%L;&]MX6YY;VL@:VEVX6QA<WITX7-A`%;A;&%S
M<WIA(&MI(&$@;?-D;W/M=&%N:2!K[7;A;G0@;F%P=.%R=`!6X6QA<W-Z;VX@
M:VD@96=Y(&3A='5M;W0`365L>6EK(&-S;W!O<G1O="!K[7;A;FIA(&AO>GKA
M861N:0!6X6QA<W-Z82!K:2!A>B#Z:B!T=6QA:F1O;F]S=`!6X6QA<W-Z;VX@
M<WIE<G9E<G0`365L>6EK(&9E;&AA<WINX6SS="!K[7;A;FIA(&AO>GKA861N
M:0!-:6YD970@:VEJ96SV;&K\:P!6X6QA<W-Z82!K:2!A>B#V<W-Z97,@9.%T
M=6WV<W-Z971E=O5T+@!6X6QA<W-Z;VX@96=Y(&]B:F5K='5M;W0`5N%L87-S
M>F$@:VDL(&UE;'EI:R!N87!TX7)A:V%T(&OM=N%N:F$@;65G:F5L96[M=&5N
M:3H`365G97+U<^UTZ7-I(&]P8VGS:RP@:_QL]FYB]GKU(&[I>F5T96L@;65G
M:F5L96[M=.ES:2!F;W)MX6KA:2P@:6QL+B!A>B!A;&%PZ7)T96QM97IE='0@
M;NEZ970@X6QL[71H873S(&)E+@!%9WD@<V4@;&5G>65N(&MI:F5L]FQV90!6
MX6QA<W-Z82!K:2P@;65L>6EK(&YA<'3A<F)A(&OM=N%N:F$@87H@861A=&]K
M870@:6UP;W)TX6QN:3H`5N%L87-S>F$@:VDL(&UE;'EI:R!N87!TX7(H86LI
M8O-L(&OM=N%N:F$@87H@861A=&]K870@97AP;W)TX6QN:3H`5N%L87-S>F$@
M:VD@82!K[7;A;G0@:V%R86MT97(H96ME*70@87H@86SA8F)I(&QE:&5T]7/I
M9V5K(&OV>OQL+B!%>G5TX6X@(F-O<'DO<&%S=&4B(&WS9'-Z97)R96P@82!M
M96=F96QE;/4@:&5L>7)E(&WA<V]L:&%T:F$@]6ME="X`5N%L87-S>F$@:VD@
M82!DX71U;65L=N%L87-Z=/,@:V%R86MT97)T.@!6X6QA<W-Z82!K:2!A(&3A
M='5M(&9O<FWA='5MX70Z`%;A;&%S<WIA(&MI(&%Z(&5X<&]R=.%LX7,@9F]R
M;>%T=6WA=#H`5N%L87-S>F$@:VD@87H@:6UP;W)TX6QA;F3S(&;A:FQT.@!6
MX6QA<W-Z82!K:2!A(&CI="!E;'/U(&YA<&KA=#H`5N%L87-S>F$@:VD@87H@
M:6UP;W)TX6QA;F3S(&;A:FP@9F]R;>%T=6WA=#H`5N%L87-S>F$@:VDL(&UE
M;'EI:R!A>F]N;W/M=/-JX70@:^UVX6YJ82!M96=VX6QT;WIT871N:3H`5N%L
M87-S>F$@:VD@87H@:63U96QVX6QA<WIT\R!K87)A:W1E<G0Z`%;A;&%S<WIA
M(&MI(&%Z(&ED]2!F;W)MX71U;>%T.@!6X6QA<W-Z82!K:2P@:&]G>2!M:6QY
M96X@:63U:6YT97)V86QL=6UO="!J96QE;NUT<_QN:R!M96<Z`%;A;&%S<WIA
M(&MI+"!H;V=Y(&UI;'EE;B!NZ7IE="!J96QE;FIE;B!M96<@82!B96IE;&5N
M=&ME>NES('5TX6XZ`%;A;&%S<WIO;B!K:2!KZ70@96=Y;>%S;F%K(&UE9V9E
M;&5L]2!M97KU="X`365G861H873S+"!H;V=Y(&UI;'EE;B!E;&9O9VQA;'1S
MX6=O:V%T(&IE;&5N[71S_&YK(&UE9R!A>B#V<W-Z969O9VQA;/,@;NEZ971B
M96XN`%;A;&%S<WIA(&MI(&$@:^UVX6YT('-Z[6YE9WG\='1E<W0N`%;A;&%S
M<WIA(&MI(&%Z(-9N;F5K(&UE9V9E;&5L]2!N>65L=F5T.@!(:6)A:F5L96YT
MZ7,@:_QL9.ES90!335,@:_QL9.ES90!!>B!E<V5MZ6YY('3V<FSI<V4@97-E
M=.EN(&O\;&1J_&YK('3A:NEK;WIT873A<W0@86YN86L@96QM87)A9.%SX7+S
M;"!A>B#V<W-Z97,@<NES>G1V97;U;F5K`$QE=NEL:_QL9.ES("5S+6YE:P!+
M_&QD:OQN:R!P<F]G<F%M=N%L=&]ZX7-I(&EN9F]R;>%C:?-T+VUE9VCM=N%S
M="!A>B#V<W-Z97,@<NES>G1V97;U;F5K(&5N;F5K(&%Z(&5L9F]G;&%L='/A
M9VYA:R!A(&UE;G3I<V5K;W(`4WIE;F5GX6P`4WIE;GIO<CH@`'-Z97!T96UB
M97(`4WIE<F)I82#I<R!-;VYT96YE9W+S`%-O<F]Z871S>N%M`$$@<WIE<G9E
M<G3U;"!K87!O='0@861A="!H:6+A<RP@=F%G>2!N96T@X6QL(')E;F1E;&ME
M>NES<F4N`$$@9F5L:&%S>F[A;/-K87!C<V]L871O:R!A9&UI;FES>G1RX6-I
M\VIA`$QE:N%R="!A(&9E;&AA<WINX6SS:V%P8W-O;&%T(&%Z;VYO<^UT\VIA
M("AS97-S:6]N($E$*2X`1F5L:&%S>F[A;/-K87!C<V]L871O:P!(86QM87H`
M02!B969E:F5ZZ7,@9.%T=6UA`$QE:&5T]7/I9R!J96QS>F%VX6YA:R#A=.%L
M;.UTX7/A<F$L(&%B8F%N(&%Z(&5S971B96XL(&AA(&5L9F5L96IT96[I+@!!
M>B!I<VWI=&SU9.ES(';I9V4`02!K97ID970@9.%T=6UA`%3A=F]L:2!S>F5R
M=F5R96L@96SI<NES92#A;&SM=&AA=/,@8F4L(&UE;'EE:V5T(&%Z(&EN9'5L
M\V]L9&%LX6X@:^UVX6X@;65G:F5L96[M=&5N:2X`07H@UFX@:6QL+B!MX7,@
M9F5L:&%S>F[A;/-K(&5L9F]G;&%L='/A9VD@861A=&%I=F%L(&MA<&-S;VQA
M=&]S(&)EX6QL[73A<V]K+@!!(&OM=N%N="!N>65L=BP@:63U>O-N82#I<R!D
MX71U;69O<FWA='5M(&)EX6QL[73A<V$N`$)EX6QL[71H873S+"!H;V=Y(&UE
M;'EI:R!A;&MA;&UA>N%S(&IE;&5N:F5N(&UE9R!A(&)E:F5L96YT:V5ZZ7,@
M=73A;BP@;6EL>65N('-Z[6YE9WG\='1E<W0L(&]L9&%L9G)I<W/M=.ES:2!G
M>6%K;W)I<^%G;W0@:6QL+B!E9WGI8B!B9>%L;.UTX7-O:V%T('-Z97)E=&YE
M+@!"9>%L;.UTX7-O:P!!(&)EX6QL[73A<V]K870@;65G^FKM=/,@<')O9W)A
M;6]K(.%L;&YA:R!R96YD96QK97KI<W)E`$$@;65G861O='0@<&%R86WI=&5R
M('3V8F(@:&5L>65T(&ES(&IE;&5N=&AE=#H@`%-E>6-H96QL92US>FEG971E
M:P!!(&OV>O9S96X@:&%S>F[A;'0@861A=&9O<G+A<R!N96T@=&%LX6QH873S
M.B`E<P!+]GKV<V5N(&AA<WINX6QT(&YA<'3A<F%K`$OV>O9S96X@:&%S>F[A
M;'0@;F%P=.%R86LZ`%;A<^%R;.%S`%+V=FED(/9S<WIE9F]G;&%LX7,`16P@
M:^UVX6YJ82#I<FYI(&%Z(&5G>65S(&9U;FMC:?-K870@06QT+6)I;&QE;G1Y
M^RUK;VUB:6[A8VGS:VMA;"!I<S\`365G:F5L96[M=.ES`$UU=&%S<W5K(&$@
M;F%P=.%R=`!*96QE>GK\:R!K_&SV;B!A(&UE9VIE;&5N[71E='0@97-E;>EN
M>65K(&MA=&5G\W)IX6ET/P!!(&YA<'3A<B!M96=J96QE;NUTZ7-E:V]R(&QE
M9WEE;F5K+64@:6MO;F]K(&$@=/9R;.ES:2!F=6YK8VGS:&]Z+"!I;&PN(&$@
M9FEG>65L;65Z=&5TZ7-I+"!I<VWI=&SU9.ES:2!B9>%L;.UTX7-O:R!J96QZ
MZ7/I<F4_`$UU=&%S<W5K(&UE9R!A(&O\;/9N8G/I9V5K970@87H@96QM96YT
M971T(.ES(&%Z(/IJ;VYN86X@;.ET<F5H;WIO='0@:V]N9FEG=7+A8VGS(&OV
M>O9T="X`375T87-S=6L@82!H873A<FED]7,@9F5L861A=&]K870@82!N87!T
MX7)B86X_`$IE;/9L:OQK(&$@<WIA8F%D+V5L9F]G;&%L="!I9/5S>F%K;VMA
M=#\`36EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(@[7+S9&KI:R!K:2!A(&MO<N%B
M8FD@=71O;'/S(&)E:F5L96YT:V5ZZ7,@:61E:F4_`$-S86L@87IO:V%T(&%Z
M(&5L9F]G;&%L='/A9V]K870@;75T87-S=6LL(&%M:6MH97H@9FEG>65L;65Z
M=&5TZ7,@=F%N(')E;F1E;'9E/P!6X6QA<WIT:&%T\R!L96=Y96X@87H@97)E
M9&5T:2!M96=T87)TX7-A`$QE9WEE;B!DX71U;7;A;&%S>G3S`$$@:_9Z]G-E
M;B!H87-Z;N%L="!N87!TX7)A:V%T(&5G>6WA<R!M96QL971T(.%B<N%Z;VQJ
M=6L_`$QE9WEE;B!E9WD@=.%B;.%Z871K97IE;/4@;65N_'-O<C\`02!F96QA
M9&%T;VMA="!A(&MA=&5G\W)IX6IU:R!S>NUN96EV96P@:F5L96[M='/\:R!M
M96<_`$UU=&%S<W5K(&$@)7,@;65N_'0@82!B86P@;VQD86QO;C\`3NEZ>OQK
M(&UE9R!TX6)LX7IA="!C96QLX6EN86L@='5L86ID;VYSX6=A:70`3NEZ>OQK
M(&UE9R!TX6)LX7IA="!T=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G('3A8FSA
M>F%T('-O<F%I;F%K('1U;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@82!KZ7`@
M='5L86ID;VYSX6=A:70`02!H971I(&[I>F5T8F5N(&UU=&%S<W5K(&%Z(/-R
MX6MA="!A(&YA<&]K(&]S>FQO<&%I(&OV>O9T="!I<S\`375T87-S=6L@82!F
M96QT]FQTZ7-T`%KA<&]R;VL`6N%P;W)O:R!DZ6QE;/5T=`!:X7!O<F]K(&3I
M;'5TX6XO97-T90!(96QY:2!ZX7!O<F]K`$MI8W-I;GGM=.ES`$5L]7-Z]G(@
M:VEC<VEN>>UT96YI92!K96QL+"!V86=Y(&5L(&ME;&P@;6]Z9.UT86YI82!A
M(&AE;'EE="!E;&9O9VQA;/,@8FQO:VMO:V%T+@!3:65R<F$@3&5O;F4`VFH@
M9F5L:&%S>F[A;/-K(&)E:F5L96YT:V5ZZ7-E`$1I9VETX6QI<R!A;.'M<N%S
M`$$@9&EG:73A;&ES(&%LX>URX7,@86QG;W)I=&UU<V$`4WII;F=A</IR`$WI
M<F5T`$$@:V%R8F%N=&%R=.%S(&MI:&%G>>%S80!3>FQO=N%K:6$`4WIL;W;I
M;FEA`$AA=F%ZX7,`2/-ZX7!O<@!(\WKA<&]R;VL`2/-ZX7!O<F]K(&3I;&5L
M]71T`$OI<_4@9.EL=73A;FDO97-T:2!H\WKA<&]R;VL`02!H\R!MZ6QY<^EG
M93H@`$CS(';M>FUE;FYY:7/I9V5B96X@:VEF96IE>G9E.B``4V%L86UO;BUS
M>FEG971E:P!3>F]MX6QI80!$86QO:RP@=F5R<V5K`$$@<V]R8F%R96YD97KI
M<R!I<N%N>>%N86L@:VEVX6QA<WITX7-A`$9E;&%D\VD@8^UM`$3I;"U!9G)I
M:V$`9.EL+65U<O-P86D@*$E33RTX.#4Y+3,I`$3I;&DM1V5O<F=I82#I<R!$
MZ6QI(%-A;F1W:6-H+7-Z:6=E=&5K`$3I;&D@9NEL=&5K90!3>F]M<WKI9&]S
M(&-E;&SA:R!K]GKV='1I('3A=F]L<^%G`$$@8V5L;&$@=&%R=&%L;6$@Z7,@
M:V5R971E(&OV>O9T=&D@=.%V;VQSX6<`2&5L>6MI=/9L=/4`5.%V;VQSX6<`
M5.%V;VQSX6<@Z7,@8F5L<_4@;6%R9_,@8F7A;&SM=.%S`%-P86YY;VQO<G-Z
MX6<`4W!A;6%S<V%S<VEN92!B9>%L;.UTX7-O:P!3<&5C:>%L:7,@:V%R86MT
M97(@8F5V:71E;&4`02!C96QL82!K971TZ6)O;G3A<V$`07H@;W-Z;&]P(&ME
M='3I8F]N=.%S80!!('-O<B!K971TZ6)O;G3A<V$`4W!O<G0`4W+M($QA;FMA
M`$ME>F1E=`!3=&%N9&%R9`!3=&%R(%1R96L`2V5Z9/4@9.%T=6T`2V5Z9/5D
M:6L`2V5Z9.ES:2!I9/4`07H@96QS]2#I=@#!;&QA<&]T`,%L;&%M('9A9WD@
M=&%R=&]MX6YY`,%L;&%P;W0`365N=.ES:2!F;W)MX71U;0!#[6T@*'5T8V$I
M`.%T:/IZ;W1T`%-T<FEN9R!L:7-T80!4]G+V;&K\:R!A(&/M;6+U;"!A($`@
M=73A;FD@<NES>G0`4W3M;'5S(%M#4U-=`%9A`$$H>BD@(B5S(B!A;&OV;GEV
M=.%R(&YE;2!T86SA;&AA=/,N`%3A<F=Y`$O\;&1J_&L@96P`(B5S(B#Z:B!F
M96QH87-Z;N%L\R!B96IE;&5N=&ME>NES:2!KZ7)E;&WI="!T;W;A8F+M=&]T
M='5K+B#6;B!C<V%K(&OI<F5L;>EN96L@96QF;V=A9.%SX70@:_9V973U96X@
M='5D(&UA:F0@8F5J96QE;G1K97IN:2X`86QS\R!I;F1E>`!3:6ME<OQL=`!3
M:6ME<F5S96X@:&]Z>N%A9'1U:R`B)7,B+70@82!R96YD<WIE<FAE>BX`(B5S
M(B!F96QH87-Z;N%L\R!A9&%T86ET('-I:V5R97-E;B!T]G+V;'3\:R!A(')E
M;F1S>F5R8O5L+@!3:6ME<F5S96X@=/9R]FQT_&L@(B5S(BUT+@!3:6ME<F5S
M96X@96QTX79O;.UT;W1T=6L@(B5S(BUT(&$@<F5N9'-Z97)B]6PN`$$@:V]N
M9FEG=7+A8VGS="!S:6ME<F5S96X@=FES<WIAX6QL[71O='1U:RX@02!VX6QT
M;WKA<V]K(&UE9W1E:VEN=.ESZ6AE>B!F<FES<^UT<V4@87H@;VQD86QT+@!!
M(&)A8VMU<"!K;VYF:6=U<N%C:?-T(&5L;65N=&5T=/QK+@!3:6ME<F5S96X@
M96QM96YT971T_&L@82AZ*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="X`(B5S
M(B!A9&%T86EN86L@;?-D;W/M=.%S82!S:6ME<F5S96X@;65G=/9R=.EN="X`
M4VEK97)E<V5N(&5L;65N=&5T=/QK(&$@)7,@X6QL;VWA;GET+@!3>G5DX6X`
MUG-S>F5F;V=L86SA<P!.87!K96QT90!.87!N>75G=&$`=F%SX7)N87``;F%P
M;W,`3F%P:V5L=&4`3F%P:V5L=&4O;F%P;GEU9W1A`$YA<&ME;'1E.B``3F%P
M;GEU9W1A`$YA<&YY=6=T83H@`&9E;'/U(&EN9&5X`$]N;&EN92!K;VUM=6YI
M:^%C:?,@*&-H870I`%-U<FEN86UE`$-S86SA9&[I=@!3=F%L8F%R9"#I<R!*
M86X@36%Y96X`4WIVX7II9O9L9`!3=NED;W)S>N%G`%-VX6IC`$%Z(&%D871S
M>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>70@=/9R]FQT_&L`4WII;G1A
M:W1I:V%I(&AI8F$@82!K97)E<_5K:69E:F5ZZ7-B96X`4WKM<FEA:2!!<F%B
M($OV>G3A<G-A<^%G`%II=F%T87(`6FEV871A<BP@97+U<R!S>NEL`%II=F%T
M87)O:P!+;W)A:2!Z:79A=&%R;VL`5%-6("A404(@:V%R86MT97)R96P@96QV
MX6QA<WIT;W1T(.ER=.EK96LI(.%L;&]MX6YY`%3A8FSA>F%T`$$@=.%B;.%Z
M870@='5L86ID;VYSX6=A:0!!('3A8FSA>F%T('1U;&%J9&]N<^%G86D`5&%J
M=F%N`%1A:G9A;@!4861Z<VEK:7-Z=.%N`%1A;GKA;FEA:2!%9WEE<_QL="!+
M:7+A;'ESX6<`02!CZ6PZ`$9E;&%D871O:P!496QE9F]N<WKA;0!!>B!E;&WZ
M;'0@\W)A(&CU;>ER<^EK;&5T93H@`$CU;>ER<^EK;&5T`$CU;>ER<^EK;&5T
M.B``2/5MZ7)SZ6ML970\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S
M`$$H>BD@(B5S(B!S86)L;VX@;F5M('1A;.%L:&%T\RX`4V%B;&]N;VL@861M
M:6YI<WITX6-I\VIA`'1E<G9E>F5T=`!3>O9V96<`8W-A:R!S>O9V96<`4WKV
M=F5G96QH96QY97KI<P!S>O9V96<@=&5T96IE`$-S_`!T:&%I("A425,M-C(P
M*0!4:&%I9O9L9`!!(")2Z7-Z='9E=O5K(&WS9&]S[73A<V$B(&OI<&5R;GGU
M(&WA<B!ZX7)V82!V86XN($MI;.EPZ7,@:_9V971K97II:RX`07H@9G1P(&+U
M=NUTZ7,@;F5M('1A;.%L:&%T\RX`02!(:7-T;W)Y(')E;F1S>F5R(&W[:_9D
MZ7-E(&YI;F-S(&5N9V5DZ6QY97IV92X`02!(;W)D92]+;VQA8B!I;G1E9W+A
M8VGS(&5Z="!N96T@=.%M;V=A=&IA.B`B)7,B`$%Z($E-4U`@;F%P;/-ZX7-T
M(&YE;2!S:6ME<OQL="!M96=K97ID96YI+@!!($UA:6YT96YA;F-E.CH@;W-Z
M=.%L>2!B973V;'3I<V4@;F5M('-I:V5R_&QT`$%Z($]P8VGS(&%B;&%K(&)E
M>N%R;V1O='0N($MI;.EPZ7,@:_9V971K97II:RX`02!*;V=O<W5L='/A9V]K
M(&AA<WINX6QA=.%N86L@96SU9F5L=.ET96QE+"!H;V=Y(&$@<F5N9'-Z97)G
M87ID82!K;VYF:6=U<N%L:F]N(&5G>2!A(&IO9V]S=6QT<^%G:2!A9&%T;VMA
M="!T87)T\W-A;B!TX7)O;&YI(&OI<&5S(&%L<F5N9'-Z97)T+@!#<V%K(&%L
M=6P@;&5G>65N(&ME<F5T`$$@(B5S(B!N87!TX7(@;F5M('3V<O9L:&5T]2X`
M02`B)7,B(&YA<'3A<G0@;.ET<F5H;WIT=6LN`$$@(B5S(B!N87!TX7)T(&MI
M=/9R]FQT_&LN`$$@(B5S(B!N87!TX7)T(.%T;F5V97IZ_&L@(B5S(BUR92X`
M02`B)7,B(&YA<'3A<G0@96QM96YT971T_&LN`$$@;F%P=.%R(&YE;2!T]G+V
M;&AE=/4Z("5S`$$@<&%R=&YE<B!A>F]N;W/M=/-S>N%M82!N96T@=F]L="!M
M96=A9'9A+_QR97-E;B!M87)A9'0@=F%G>2!A>B!A9&%T8N%Z:7-B86X@;F5M
M('9O;'0@;65G=&%LX6QH873S+@!!('!A<G1N97(@861A=&%I="!S:6ME<F5S
M96X@:&]Z>N%A9'1U:R!A(&/M;6IE9WEZZ6OI:&5Z+@!+_&SV;N%L;/,@4$=0
M(&%LX>URX7-I(&)L;VMK('-Z_&MSZ6=E<R!A(&1I9VETX6QI<V%N(&%LX>UR
M="#\>F5N970@:&ET96QE<W/I9^EN96L@96QL96[U<GKI<^EH97HN`$$@:_9R
M;&5VZ6QL:7-T82!A>F]N;W/M=/-S>N%M82!N96T@=F]L="!M96=A9'9A+_QR
M97-E;B!M87)A9'0@=F%G>2!A>B!A9&%T8N%Z:7-B86X@;F5M('9O;'0@;65G
M=&%LX6QH873S+@!!(&OV<FQE=NEL;&ES=&$@;F5M('9O;'0@;65G861V82X`
M02!T:71K;W/M=.%S:2!S>F]L9^%L=&%TX7-O:VAO>B!B:7IT;VYSX6=O<R`H
M=&ET:V]S[71O='0I('=E8B!K87!C<V]L870@:V5L;"X`02!B969E:F5ZZ7,@
M9.%T=6UA(&OI<_5B8B!K96QL(&QE9WEE;BP@;6EN="!A(&ME>F1E=.DN`$$H
M>BD@(B5S(B#Z:B!E;&9O9VQA;'1SX6<@;65G:F5L96YT(&$H>BD@(B5S(B!N
M87!TX7)B86XL(&ED]7!O;G1J82`E<RP@)7,`02AZ*2`B)7,B(&5L9F]G;&%L
M='/A9R!T]G)L]63V='0@82AZ*2`B)7,B(&YA<'3A<F+S;"P@:63U<&]N=&IA
M("5S+"`E<R!V;VQT+@!!*'HI("(E<R(@96QF;V=L86QT<^%G(&WS9&]S=6QT
M(&$H>BD@(B5S(B!N87!TX7)B86XL(&ED]7!O;G1J82`E<RP@)7,N`$%Z(&5S
M96WI;GER]6P@;&5V96QE="!K_&QD=/QN:R`E<R!RZ7-ZZ7)E+@!!*'HI("5S
M(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@96=Y("5S(&)EX6QL
M[73A<VYA:RX`02AZ*2`E<R#A;&QO;>%N>6)A;B!S>F5R97!E;&YI92!K96QL
M96YE('9A;&%M:6QY96X@)7,@8F7A;&SM=.%S*&]K*6YA:RX`02!FX6IL(&YE
M;2!MX7-O;&AA=/,@]FYM86?A<F$N`$$@9N%J;&)A;B!N96T@=F]L="!A9&%T
M+@!!>B#\>F5N970@9F5J;.EC<V]R86D@82!K]G9E=&ME>O5K+@!!>B!E<V5M
MZ6YY('+I<WIL971E<R!L9>URX7-A.@!!('1E;&IE<R!KZ7!E<FYY]7,@_'IE
M;6WS9"!P<F]B;.EMX6MA="!O:V]Z:&%T(&%Z($EN=&5R;F5T($5X<&QO<F5R
M(&AA<WINX6QA=&$@97-E=.EN+"!M97)T(&5B8F5N(&]L>6%N('!R;V=R86UH
M:6+A:R!V86YN86LL(&%M:6ME="!N96T@='5D='5N:R!M96=K97+\;&YI+B!!
M(&OI<&5R;GGU:F4@;VQV87-H871A=&QA;F[A(';A;&AA="P@8FEZ;VYY;W,@
M961I=&]R(&9U;FMC:?-K(&AIX6YY;WIH871N86L@Z7,O=F%G>2!VX7)A=&QA
M;G5L(&QE9F%G>6AA="!A(&+V;F?I<WKU<')O9W)A;2X@5VEN9&]W<R`Y>"!H
M87-Z;N%L871A(&5S973I;B!N86=Y;VX@=F%L\W-Z[6[[+"!H;V=Y("='96YE
M<F%L('!R;W1E8W1I;VX@9F%U;'0G(&AI8F$@;6EA='0@^FIR82!K96QL(&EN
M9.UT86YI82!M86ID(&$@9^EPZ70N7&Y<;D9I9WEE;&UE>G1E='3\:R$@2V%T
M=&EN='-O;B!A>B!/2R!G;VUB<F$L(&AA(&WI9VES(&UE9R!K[7;A;FIA(&OM
M<^ER96QN:2!A('1E;&IE<R!KZ7!E<FYY]7,@_'IE;6WS9&]T+@!!("(E<R(@
M87IO;F]S[73S="!K:73V<O9L=/QK+@!#<V%K(&)A;"!O;&1A;&]N(&QE9WEE
M;B!K97)E=`!!($=N=5!'('!R;V=R86T@:&5L>>ET(&UE9R!K96QL(&%D;FD@
M82!#<GEP=%]P9W`Z.B!O<WITX6QY(&AA<WINX6QA=.%H;WHN`$$@;&5VZ6PL
M(&UE;'EE="`E<R!N87!JX6X@:_QL9/9T="`E<R!C[6UZ971T;F5K("(E<R(@
M=.%R9WEB86XL(&$@8^UM>F5T="!S>N%M[73S9^EPZ6X@;65G:F5L96YT+B!!
M<G)A(&YI;F-S(&=A<F%N8VEA+"!H;V=Y(&5L(&ES(&]L=F%S=.%K(&EL;"X@
M:&]G>2!M96?I<G1E='3I:RX`36D@;&5G>65N(&$@;&5VZ6SM<O,@86)L86MH
M;WH@;75T873S(&QI;FL@96QN979E>NES90!!(&UE>O5K('-ZX6UA(&-S86L@
M;G5M97)I:W5S(.ER=.EK(&QE:&5T+@!!>B!O<&5N<W-L(&UO9'5L('-Z_&MS
MZ6=E<R!A($AO<F1E7T-R>7!T7W-M:6UE.CH@;W-Z=.%L>2!H87-Z;N%L873A
M:&]Z+@!!("(E<R(@<WIE;>EL>65S(&)EX6QL[73A<R!N96T@;65N=&AE=/4@
M96PL(&UE<G0@;>ER971E(&UE9VAA;&%D:F$@82!M96=E;F=E9&5T="!M87AI
M;75M;W0`3F5M('1A;.%L:&%T\R!A>B!A('!R;V=R86T@82!S>F5R=F5R96XL
M(&%M:2!S>OQK<^EG97,@96YN96L@87H@861A='3M<'5S;F%K("@E<RD@82!M
M96=J96QE;NUTZ7/I:&5Z+@!!>B!I9.EZ]6IE;"!K87)A:W1E<B!C<V%K(&5G
M>65T;&5N(&MA<F%K=&5R(&QE:&5T+@!!(&UE9VCM=N%S(&%D871A:2!H:>%N
M>6]S86LN($%Z(&5S96WI;GEE;B!V86SS('+I<WIVZ71E;"!E;&9O9V%DX7/A
M:&]Z('9A9WD@96QU=&%S[73A<^%H;WH@<WK\:W/I9V5S(&%D871O:R!K]GK\
M;"!E9WEE<V5K(&YE;2#A;&QN86L@<F5N9&5L:V5ZZ7-R92X`2F]B8B#I<R!B
M86P@;VQD86QO;B!L96=Y96X@:V5R970`0W-A:R!J;V)B(&]L9&%L;VX@;&5G
M>65N(&ME<F5T`$%Z(&5L=N%L87-Z=/,@:V%R86MT97(@8W-A:R!E9WEE=&QE
M;B!K87)A:W1E<B!L96AE="X`02AZ*2`B)7,B('-Z97)V97)T('3V<O9L=/QK
M+@!!*'HI("(E<R(@<WIE<G9E<G0@96QM96YT971T_&LN`"5S(&)E:F5L96YT
M:V5ZZ7-I(&OI<F5L;>ET('3V<O9L=/QK+@!!(&UE9V%D;W1T('-O<B`H)60I
M(&YE;2!LZ71E>FEK+@!!*'HI("(E<R(@:61E:6=L96YE<R!FX6IL(&YE;2!L
MZ71E>FEK+@!!(&)E[7)T('-Z]G9E9R!N96T@96=Y97II:R!A(&OI<&5R;GGU
M;B!L97;U=F5L+@!!;'5L(.ES(&;V;/QL(&QE9WEE;B!K97)E=`!#<V%K(&9E
M;G0@;&5G>65N(&ME<F5T`$$@9F5L=/9L=/9T="!A9&%T;VL@87H@96SU>O4@
M;.EPZ7,@\W1A(&5L=F5S>G1E:RX`02!F96QT]FQT]G1T(&;A:FQT(&YE;2!S
M:6ME<OQL="!E;&UE;G1E;FDN`$$@=V5A=&AE<BYC;VT@8FQO:VL@;F5M(&AA
M<WINX6QH873S+@!!(&UE9VIE;&5NZ7-I('-T[6QU<R`H=&AE;65S*2!A;&OV
M;GEV=.%R("(E<R(@;F5M('1A;.%L:&%T\RX`3FEN8W,@82!K<FETZ7)I=6UO
M:VYA:R!M96=F96QE;/4@96QF;V=L86QT<^%G+@!.:6YC<V5N(';A;&%S>G1H
M873S(&]P8VGS+@!.:6YC<R!A(&QE=NEL(&)E;'-E:NEB96X@;65G:F5L96[M
M=&AE=/4@;65L;.EK;&5T+@!4^FP@<V]K(&MA<F%K=&5R('9A;B!E8F)E;B!A
M(&UE>O5B96XN(-9N("5S(&MA<F%K=&5R="!A9&]T="!M96<[(&$@;6%X:6WA
M;&ES86X@;65G861H873S('!E9&EG(&ME=F5S96)B+"!M:6YT("5S+@`B)7,B
M(&9E;&AA<WINX6SS;F%K(&$@<F5N9'-Z97)H97H@863A<V%K;W(@:&EB82!T
M]G)TZ6YT+B`E<P`B)7,B(&9E;&AA<WINX6SS(&%D871A:6YA:R!T]G)LZ7-E
M('-O<N%N(&AI8F$@;.EP971T(&9E;#H@`"(E<R(@<F5N9'-Z97)B]6P@=F%L
M\R!T]G)LZ7-E:V]R(&AI8F$@;.EP971T(&9E;#H@`"(E<R(@;?-D;W/M=.%S
M82!S;W+A;B!H:6)A(&SI<&5T="!F96PZ("5S`$%Z(.%L;&]MX6YY="!N96T@
M<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@)7,@;F5M('3V;'3U
M9/9T="!F96PN`$%Z(.%L;&]MX6YY="!N96T@<VEK97+\;'0@82!S>F5R=F5R
M<F4@9F5L=/9L=&5N:2X@)7,@;F%G>6]B8BP@;6EN="!A(&UA>&EMX6QI<V%N
M(&UE9V5N9V5D971T(&WI<F5T("@E9"!BX6IT*2X`07H@X6QL;VWA;GET(&YE
M;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI+B!!*'HI("5S(&;A
M:FQN86L@8W-A:R!E9WD@<NES>F4@=/9L=/5D]G1T(&;V;"X`2&EB82!T]G)T
MZ6YT(&$@;F%P=.%R(&5LZ7+I<V5K;W(Z("5S`$%Z(&5L9F]G;&%L='/A9R!H
M;WIZX6%DX7-A('-O<N%N(&AI8F$@=/9R=.EN=#H@)7,`02!L97;I;"!E('+I
M<WKI;F5K(&UE9VIE;&5N[73I<V5K;W(@:&EB82!T]G)TZ6YT`$%Z(&5L9F]G
M;&%L='/A9R!M\V1O<^UTX7-A('-O<N%N(&AI8F$@=/9R=.EN=#H@)7,`02!P
M87)T;F5R(&%D871O:R!I;7!O<G3A;.%S82!S;W+A;B!H:6)A('3V<G3I;G0N
M`$%Z(&E#86QE;F1A<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@:&EB82!T
M]G)TZ6YT+@!(:6+A<R!A(&UE9V%D;W1T(&MO;F9I9W5RX6-I\RX@3&5H970L
M(&AO9WD@;F5M('3V;'3V='0@:VD@96=Y('-Z_&MSZ6=E<R!M97KU="X`07H@
M96QF;V=L86QT<^%G(.%T:&5L>65ZZ7-E('-O<N%N(&AI8F$@=/9R=.EN=#H@
M)7,`02!P87)T;F5R:F5G>7KI:VME;"!K87!C<V]L871O<R!F96QA9&%T(';I
M9W)E:&%J=.%S82!S;W+A;B!H:6)A(&SI<&5T="!F96PN($OI<F5M('!R\V+A
M;&IA(&UE9R!KZ7/U8F(N`$AI8F$@=/9R=.EN="P@86UI:V]R(&%Z(&5S96WI
M;GER]6P@=.%JZ6MO>G1A=.%S="!A:V%R='5N:R!K_&QD96YI("5S('+I<WKI
M<F4Z("5S`$AI8F$@=/9R=.EN="!A('!A<G1N97(@861A=&%I;F%K(&9R:7-S
M[73I<V4@<V]RX6XN($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N`$$@:_9R
M;&5VZ6QL:7-T82!A9&%T86EN86L@9G)I<W/M=.ES92!S;W+A;B!H:6)A('3V
M<G3I;G0N($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N`$YE;2!V;VQT(&5X
M<&]R=.%L:&%T\R!E;&9O9VQA;'1SX6<N`$5Z(&%Z($E-05`@<WIE<G9E<B!N
M96T@=.%M;V=A=&IA(&$@;6%P<.%K:&]Z('9A;/,@:&]Z>N%FZ7+I<R!M96=O
M<WITX7/A="X`17H@;F5M('3[;FEK('-Z86+A;'EO<R!R87(@X6QL;VWA;GEN
M86LN`$5Z(&YE;2!T^VYI:R!S>F%BX6QY;W,@>FEP(.%L;&]MX6YY;F%K+@!%
M>B!N96T@=/MN:6L@Z7)VZ6YY97,@:^%R='EA<WKA;6YA:RX`17H@82!M96=H
M86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--
M4RUT(&O\;&1J_&YK(&$@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN
M8V]M*2!S>F]L9^%L=&%T\VX@X70N`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@
M=&5S>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A
M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI('-Z;VQGX6QT873S;B#A="X`17H@
M82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA
M=&]N(%--4RUT(&O\;&1J_&YK(&%Z('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E
M;6%I;"YC;VTI('-Z;VQGX6QT873S;B#A="X`17H@82!M96=H86IT\R!L96AE
M=/5VZ2!T97-Z:2P@:&]G>2!33510+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J
M_&YK(%9O9&%F;VYE('-ZX6UO:W)A(&$@5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2!S>F]L9^%L=&%T\VX@X70N($$@<WIO;&?A;'1A=.%S
M(&EGZ6YY8F5VZ71E;.EH97H@5F]D869O;F4@271A;'D@96UA:6P@8^UM('-Z
M_&MSZ6=E<RX`17H@82!M97KU(&YE;2!M87)A9&AA="#\<F5S+@!%8F)E;B!A
M(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@X6QL:&%T;F%K+@!%8F)E;B!A
M(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@Z7,@:V5T=/5S<&]N="!L96AE
M="X`16)B96X@82!M97KU8F5N(&-S86L@;VMTX6QI<R!S>N%M;VL@X6QL:&%T
M;F%K+@!%>B!A(&UE>O4@8W-A:R!V97-S>O5V96P@=F%G>2!S>O-K]GIZ96P@
M96QVX6QA<WIT;W1T(&5GZ7-Z('-ZX6UO:V%T('1A<G1A;&UA>FAA=`!%>B!A
M>B#I<G3I:R!C<V%K('-ZX6T@;&5H970N`$5B8F5N(&$@;65Z]6)E;B!H97AA
M9&5C:6WA;&ES(%)'0B!S>NUN:_-D(.%L;&AA="P@<&PN("<C,3(S-&%F)RX`
M27-M97)E=&QE;B!FX6IL9F]R;>%T=6TN`$5Z96X@861A=&]K:V%L(&MA<&-S
M;VQA=&]S(&9E;&%D871O:V%T(&$@<WIE<G9E<B!MX7(@96QVZ6=E>G1E+@!%
M>B`E<P!%>B!E9WD@2V]L86(@1W)O=7!W87)E(&]B:F5K='5M+B!!>B!I;'EE
M;B!O8FIE:W1U;2!M96=J96QE;NUTZ7/I:&5Z(&]L>6%N(&5M86EL(&ML:65N
M<W!R;V=R86T@<WK\:W/I9V5S+"!A;65L>2!KZ7!E<R!A($MO;&%B($=R;W5P
M=V%R92!F;W)MX71U;2!K97IE;.ESZ7)E+B!);'EE;B!E;6%I;"!K;&EE;G-E
M:R!L:7-TX6IA(&SA=&AA=/,@:71T.B`E<P!!('-Z97)V97(@_'IE;F5T93H@
M)7,`17IT(&$@;&5V96QE="!MX7,@:V%R86MT97)KZ7-Z;&5T=&5L("@E<RD@
M[7)TX6LL(&UI;G0@86UI="#6;B!H87-Z;N%L+@!%>B!A('-ZX6T@;F5M(&QE
M:&5T(&5G>6[I;"!K:7-E8F(N`$5Z(&$@<WIE<G9E<B!N96T@:^EP97,@:VEB
M;VYT86YI(&$@>FEP(&EL;"X@9WII<"#A;&QO;>%N>6]K870N`$5Z(&$@<F5N
M9'-Z97(@:F5L96YL96<@:6YA:W1I=N%L=F$@=F%N+@!%>B!A>B#I<G3I:R!C
M<V%K('-ZX6T@;&5H970N`$5Z="!A>B!A8FQA:R!C<V%K(&%Z($]P8VGS:R!A
M8FQA:V+S;"!H[79H873S`%9I;&SA;6SA<P!C<_QT]G)T]FL`2&EB86)E:F5L
M96YTZ7,M:V5Z96SI<P!)9/4`263U=&%R=&%M`$UU;FMA:63U+6YY:6QVX6YT
M87)TX7,`263U(&9O<FWA='5M`$ED]2!VX6QA<WITX7,`263U=&%R=&%M`$ME
M;&5T+51I;6]R`$5L;F5V97KI<P!%;&YE=F5ZZ7,`0^UM("AT;V]L=&EP*0!#
M[6UZ971T`$AA('3V8F(@96QE;65T(&ES(&MI(&%K87(@:F5L]FQN:2P@=&%R
M='-A(&QE;GEO;79A(&$@0V]N=')O;"`H4$,I('9A9WD@82!#;VUM86YD("A-
M86,I(&)I;&QE;G1Y^W0@82!K871T:6YTX7,@:_9Z8F5N+@!-80!(5$U,(&9O
M<G+A<V[I>F5T(&MI+V)E`%1O9V\`5&]K96QA=0!(;VQN87``5&]N9V$`9O9L
M_&P`3&5G9F5L<_4@9G)A;64@*%]T;W`I`$9O<F3M=.%S;VL`5')I;FED860@
MZ7,@5&]B86=O`$EG87H@=F%G>2!H86UI<P!+90!K961D`%1U;NEZ:6$`5/9R
M]FMO<G-ZX6<`=/9R]FL@*$E33RTX.#4Y+3DI`%3\<FMM96YI<WITX6X`5'5R
M:W,M(.ES($-A:6-O<RUS>FEG971E:P!4=79A;'4`5.UP=7,`S7)J82!B92P@
M;6ET(';A;&%S>G1O='0Z(`!55B!I;F1E>#H@`%523`!54DPL(&UE;'EE;B!E
M9WD@<')O9W)A;2!E;&9O9V%D:F$@82!S>F]L9^%L=&%T\R#A;'1A;"!K_&QD
M]G1T(&O\;&3V='0@:^EZ8F5S[73I<VD@:F5L96YTZ7-T`%523#H`56=A;F1A
M`%5K<F%J;F$`3F5M('-I:V5R_&QT(&$@5D93(&%L:_9N>73A<F)A(&)E;.EP
M;FDN`$$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6<@:6?I;GELZ7-E:V]R
M(&YE;2!S:6ME<OQL="!A>B!A9&%T;VL@96QTX7)O;.%S82X`3F5M('-I:V5R
M_&QT(&$H>BD@(B5S(B!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET
M(&UE9W;A;'1O>G1A=&YI+@!.96T@<VEK97+\;'0@82AZ*2`E<R\E<R!61E,@
M9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET(&UE9W;A;'1O>G1A=&YI+@!.
M96T@<VEK97+\;'0@82AZ*2`E<R!A;&OV;GEV=.%R8F$@8F5LZ7!N:2X`02AZ
M*2`B)7,B(.%L;&]MX6YY(&WI<F5T92!N96T@X6QL87#M=&AA=/,@;65G+@!!
M*'HI("(E<R\E<R(@X6QL;VWA;GD@;>ER971E(&YE;2#A;&QA<.UT:&%T\R!M
M96<N`$%Z(%-13"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN`$%Z(%-33"!K87!C
M<V]L870@;F5M(.EP[71H973U(&9E;"X`02!61E,@9N%J;"!N96T@;>%S;VQH
M873S(.%T+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B(%9&4R!A;&OV;GEV=.%R
M="!LZ71R96AO>FYI+@!.96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(%9&4R!A
M;&OV;GEV=.%R="X`3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@82!61E,@9N%J
M;'0N`$$H>BD@(B5S(B!61E,@;6%P<&$@;F5M(&AO>FAA=/,@;.ET<F4N`$YE
M;2!S:6ME<OQL="!LZ71R96AO>FYI(/QR97,@5D93(&;A:FQT+@!!('3V;?9R
M[71E='0@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!K:6)O;G1A;FDN`"(E<R(@
M;F5M('3V<O9L:&5T]2P@87H@86QK]FYY=G3A<B!N96T@_')E<RX`(B5S(B!T
M]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,`(B5S(B!T]G)LZ7-E(&YE;2!S:6ME
M<OQL=#H@)7,N`"5S(&YE;2!T]G+V;&AE=/4L(&%Z(&%L:_9N>79TX7(@;F5M
M(/QR97,N`$$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2!R96MU<GKM
M=F%N+@!!(%9&4R!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N`$$@5D93(&%L
M:_9N>79TX7(@;F5M('3V<O9L:&5T]3H@)7,N`$$H>BD@(B5S(B!61E,@9N%J
M;"!N96T@=/9R]FQH973U+@!!(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N`$$H
M>BD@(B5S(B!61E,@;6%P<&$@;F5M('3V<O9L:&5T]2X`3F5M(';I9V5Z:&5T
M\R!R96MU<GKM=B!T]G)LZ7,@82!61E,M8F5N.B`E<RX`3F5M(&AA=.%R;WIH
M873S(&UE9R!A(&IE;&5N;&5G(.ER=NEN>65S(&%L:_9N>73A<BX`02!T86[Z
M<^UT=N%N>2!RZ7-Z;&5T97,@861A=&%I(&YE;2!H873A<F]Z:&%T\VL@;65G
M`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@)7,@9&5F:6[M8VGS:N%T+@!!(%9&
M4R!FX6IL(&YE;2!H96QY97IH973S(.%T+@!!*'HI("(E<R(@5D93(&;A:FP@
M;F5M(&YY:71H873S(&UE9RX`02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G
M(.URX7-I(&/I;&QA;"X`02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G("X`
M02!T]FWV<NUT971T(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<N`$$@5D93
M(&;A:FP@;F5M(&]L=F%S:&%T\R`H82!F:6QE<VEZ92@I('-I:V5R=&5L96X@
M=F]L="DN`$$@5D93(&;A:FP@;F5M(&]L=F%S:&%T\R`H82!G971&:6QE4VEZ
M92@I('-I:V5R=&5L96X@=F]L="DN`$5Z(&$@9N%J;"!N96T@;VQV87-H873S
M.B``02!V9G-R;V]T(&%L:_9N>79TX7(@;F5M(&]L=F%S:&%T\RX`(B5S(B#A
M=&YE=F5ZZ7-E(&YE;2!S:6ME<OQL=#H@)7,`)7,@;F5M(&YE=F5Z:&5T]2#A
M="`E<R!NZ79R93H@;>%R(&SI=&5Z:6L@:6QY96X@;F5V^R!M87!P80!!(%9&
M4R!A;&OV;GEV=.%R(&YE;2!N979E>FAE=/4@X70N`$$@5D93(&%L:_9N>79T
MX7(@;F5M(&YE=F5Z:&5T]2#A=#H@)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N
M96T@;F5V97IH973U(.%T+@!!*'HI("5S+R5S(%9&4R!FX6IL(&YE;2!N979E
M>FAE=/4@X70N`$$@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`3F5M('-I
M:V5R_&QT(&5LZ7)N:2`E<R!I9/5B96]S>G3A<VD@861A=&%I="X`07H@)VUK
M:7-O9G,G('!R;V=R86T@;F5M(&9U='1A=&AA=/,N`$YE;2!S:6ME<OQL="!L
M969O<F3M=&%N:2!E>G0@82!7;W)D(&1O:W5M96YT=6UO=`!!*'HI("(E<R(@
M5D93(&;A:FP@;F5M(.UR:&%T\RX`02!61E,@9N%J;"!N96T@[7)H873S("AA
M(&-O<'DH*2!S:6ME<G1E;&5N('9O;'0I+@!!(%9&4R!FX6IL(&%D871A:2!N
M96T@[7)H873S:R!K:2X`02!61E,@9N%J;"#M<N%S82!K=O-T873Z;&SI<.ES
M(&UI871T(&YE;2!F96IE>FAE=/4@8F4N`&%LX6CZ>F]T=`!-Z6=S92!M96YT
M<_QK(&5L`%9I<W-Z879O;FIA(&%Z('5T;VQS\R!VX6QT;WIT873A<W0`02!K
M87!C<V]L870@9F5L=NET96SI="!K]G9E=/5E;B!VX7)A=&QA;B!VX6QA<WH@
MZ7)K97IE='0@82!S>F5R=F5R=/5L.B``5N%R871L86X@=N%L87-Z(.ER:V5Z
M971T(&$@<WIE<G9E<G3U;"!E<G)E.B``8F5S;W)O;&%T;&%N`%5N:6-O9&4@
M*%541BTX*0!%9WEE<_QL="!!<F%B($5M[7)SZ6=E:P!%9WEE<_QL="!+:7+A
M;'ESX6<`16=Y97/\;'0@P6QL86UO:P!%9WEE<_QL="#!;&QA;6]K+"!K:7-E
M8F(@:_QL<_4@<WII9V5T96L`96=Y<^EG`$ES;65R971L96X`27-M97)E=&QE
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!)<VUE<F5T;&5N(&-L:6US
M9VED("A#;&EE;G0@365S<V%G92!)1"DN`$$@;65G861O='0@:&5L>2!I<VUE
M<F5T;&5N+@!)<VUE<F5T;&5N(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!J96QS
M>O,N`%3A=F]L[71S=6L@96P@:6YN96X@82!L:6YK970`3FEN8W,@96QN979E
M>G9E`$)I>G1O;G/A9VD@;VMO:V+S;"!A(&9E;&AA<WINX6SS:2!P<F]G<F%M
M;VL@;F5M(&AA<WINX6QH871JX6L@82!+:7;A9^%S+TWA<V]LX7,O0F5I;&QE
M<WITZ7,@;?-D<WIE<G0N($MA='1I;G1S;VX@87H@3TL@9V]M8G)A+"!H82!A
M(&UO>FEL;&$N;W)G('=E8F]L9&%L;VX@96P@:^UVX6YJ82!O;'9A<VYI(&$@
M=&5C:&YI:V%I(&QE[7+A<W0@;65L>2!M96=A9&IA+"!H;V=Y86X@;&5H970@
M97IT(&WI9VES(&5N9V5DZ6QY97IN:2X`02!S>NUN('9I<W-Z8>%L;.UTX7-A
M`$ES;65R971L96X@=&%R=&%L;VUT[7!U<SH@)7,`3F5M('3A;6]G871O='0@
M97AT96YZ:?,`3?-D;W/M=.%S`"5S(&%D871A:6YA:R!M\V1O<^UTX7-A`$$@
M9F5L:&%S>F[A;/,@861A=&%I;F%K(&WS9&]S[73A<V$`(B5S(B!VX6QT;WKA
M<V%I="!E;&UE;G1E='3\:RX`)7,@=N%L=&]ZX7-A:70@96QM96YT971T_&LN
M`$%Z('5P9W)A9&4@<')O9W)A;6]T('3V<O9L=/QK+@!&96QT]FQTZ7,`07H@
M]G-S>F5S(&%L:V%L;6%ZX7,@:V]N9FEG=7+A8VGS:N%T(&9E;'3V;'3V='3\
M:R!A('-Z97)V97)R92X`;&%T:6X@;F%G>6)E=/MK`&YA9WEB973[<R!R\VUA
M:2!S>N%M;VL`57)U9W5A>0!(87-Z;N%L:G5K(&$@:F5L96YL96=I=#H@)7,`
M2&%S>F[A;&IU;FL@4U-,+70`06MK;W(@:&%S>F[A;&IU:RP@:&$@87H@24U3
M4"!S>F5R=F5R96X@;>%S(&$@8F5J96QE;G1K97KI<VD@;F5V_&YK+VIE;'-Z
M879U;FLN`$9E;&AA<WINX6SS:2!NZ78`)7,@9F5L:&%S>F[A;/,@;F5M(&IO
M9V]S=6QT("5S+7)E+@!&96QH87-Z;N%L\VL@861M:6YI<WIT<N%LX7-A`$$@
M<')O9W)A;2!H87-Z;N%L871A`$9E;&AA<WINX6SS:2!B9>%L;.UTX7-O:P!"
M96IE;&5N=&ME>NES(&IO9V]S=6QT<^%G(&EGZ6YY;.ES90!%>F5N(&$@<F5N
M9'-Z97)E;B!N:6YC<R!E;F=E9.EL>65Z=F4@87H@^FH@9F5L:&%S>F[A;/-K
M(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%GX6YA:R!I9^EN>6SI<V4N`$%Z
M(&9E;&AA<WINX6SS:2!A>F]N;W/M=/,@;F5M('1A;.%L:&%T\P!&96QH87-Z
M;N%L\VD@;NEV`$$H>BD@(B5S(B!F96QH87-Z;N%L\VD@;NEV(&WA<B!LZ71E
M>FEK+@!&96QH87-Z;N%L\VD@;NEV.@!&96QH87-Z;N%L\VD@;NEV.B``02!R
M96YD<WIE<B!F96QH87-Z;N%L\VDZ`-QZ8F5G:7-Z=.%N`$$@5D93(&%L:_9N
M>79TX7(@;F5M(&SI=&5Z:6LN`%-Z86)A9'/A9R!A;&%T=&D@875T;VUA=&EK
M=7,@96UA:6PM=N%L87-Z`$$@:_9V971K97KU(&AE;'EE:V5T('1A;.%L='5K
M.B``R7)VZ6YY97-SZ6<`07H@Z7)TZ6ME:V5T('!E<F-B96X@861J=6L@;65G
M+"!M;W-T86YT\VP@<WKA;>UT=F$N`$$@Z7)TZ6L@;F%G>6]B8BP@;6EN="!A
M(&QE9VYA9WEO8F(@;65G96YG961E='0@:&]S<WKZ<^%G.B`E<RX`R7)TZ6ME
M:P!6X6QA<WIT:&%T\R#I<G3I:V5K`%9A;G5A='4`=N%L=&]Z\P!696YE>G5E
M;&$`02!H:71E;&5S[73I<R!N96T@<VEK97+\;'0@+2!L96AE="P@:&]G>2!A
M(&QE=F5L970@=F%L86MI(&UE9W;A;'1O>G1A='1A+@!697)Z:?,`5F5R>FGS
M:_9V973I<P!&_&=G+B!E;&AE;'EE>NES`$;\9V?U;&5G97,@8F5L<_4@;6%R
M9_,`9OQG9_5L96=E<SH`;F%G>6]N(&UA9V%S`%9I971N86T`=FEE=&YA;6D@
M*%9)4T-)22D`)7,@;65G=&5K:6YTZ7-E`$YA<&D@;65G:F5L96[M=.ES`$O\
M;'/U('=E8F]L9&%L(&UE9VIE;&5N[73I<V4`2F5L96[M='/\:R!M96<L(&UI
M;G0@)7,`0G)I="!6:7)G:6XM<WII9V5T96L`06UE<FEK86D@5FER9VEN+7-Z
M:6=E=&5K`$SA=/-TX79O;'/A9P!,X73S=.%V;VQSX6<Z(`!6;V1A9F]N92!)
M=&%L>2!S>F]L9^%L=&%TX7,@4TU44"UN(&ME<F5S>G3\;`!&24=914Q-15I4
M153)4P!&24=914Q-15I4153)4R$@2\E:6D5,(%3!5D],S51302!%3"!!(%-#
M4DE05$54("5S+5+53"X`5TE.('-Z;VQGX6QT873A<R!(5%10+6X@X70`5V%L
M;&ES(.ES($9U='5N80!&:6=Y96QM97IT973I<P!3>F4`263U:N%RX7,@96SU
M<F5J96QZZ7,`07H@:63U:N%RX7-I(&%D871O:R!F;W)RX7-A`%=E8@!796)H
M96QY96L`<WIE<F1A`&CI=``E9"X@:.ET`&CI=`!H971E;G1E`&AE=&5N=&4Z
M(&ES;>ET;/5D:6L@;6EN9&5N`-QD=O9Z]FQJ_&L`W&1V]GKV;&K\:SH@)7,`
MW&1V]GKV;&K\:RP@)7,`;GEU9V%T+65U<O-P86D@*$E33RTX.#4Y+3$I`&YY
M=6=A="UE=7+S<&%I("A)4T\M.#@U.2TQ-2D`3GEU9V%T+5-Z86AA<F$`36EL
M>65N(&%L:V%L;6%ZX7-T(&UU=&%S<V]N("5S(&$@8F5J96QE;G1K97KI<R!U
M=.%N/P!-:2!A>B!E;';A;&%S>G3S(&MA<F%K=&5R/P!-:2!A>B!I9.EZ971K
M87)A:W1E<C\`2.%N>2#S<N%I9R!M=71A<W-U:R!A>B!I9/5T(&$@;F%P:2!I
M;&PN(&AE=&D@;NEZ971B96XL(&AA(&YI;F-S(&OI<_5B8FD@96QF;V=L86QT
M<^%G/P!(X6YY(/-RX73U;"!K97ID=F4@;75T87-S=6L@87H@:63U="!A(&YA
M<&D@:6QL+B!H971I(&[I>F5T8F5N+"!H82!N:6YC<R!K;W+A8F)I(&5L9F]G
M;&%L='/A9S\`5VAE<F5I<R!!=7-Z='+A;&EA('3I<FOI<`!-96QY:6L@8VEK
M;'5S`$UE;'EI:R!M;V1U;&]K870@86MT:7;A;&IU:R!A(%)I8V@@5&5X="!E
M9&ET;W)B86X_`%-ZZ6QE<W/I9P!3>NEL97-SZ6<@0U-3(&5G>7/I9V)E;@!!
M("5S(&UE;OP@<WKI;&5S<^EG92!A(&)A;"!O;&1A;&]N("AA(&OV=F5T:V5Z
M]2!B96IE;&5N=&ME>NES="!K]G9E=/5E;B!L97-Z(.ER=NEN>65S*0!!('3A
M8FSA>F%T('-ZZ6QE<W/I9V4`02!S>NEL97-SZ6<@;>ER=.EK96=Y<^EG90!3
M>NEL97-SZ6<Z`%=I:VD`4WKI;`!3>NEL(&$@<F5G9V5L:2#S<N%K8F%N`%-Z
MZ6QS96)E<W/I9R!C<V]M\V)A;@!3>NEL.@!3>NEL.B``0O9L8W-E<W/I9P!+
M[7;A;G/A9VQI<W1A`$UU;FMA`$UU;FMA:&5L>6D@8^UM`$UU;FMA:&5L>6D@
M=&5L969O;@!M=6YK86CI=`!!("5D+B!S;W)B86X@;F5M(&UE9V9E;&5L]2!A
M(&UE>O5K('-ZX6UA+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"X`3F5M(&UE9V9E
M;&5L]2!A(&UE>O5K('-ZX6UA+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"X`2&EB
MX7,@;V9F<V5T("@E9"D@82!61E,@9N%J;"!O;'9A<^%S86MO<BX`3&EN=7@@
M9F]R<N%S:_-D(&ME<F5S>G)E9F5R96YC:6$`6#4P.78S(&%L87!V973U(&MO
M<FSA=&]ZX7-O:P!8-3`Y=C,@:VET97)J97-Z=&5T="!K=6QC<VAA<WINX6QA
M=`!8-3`Y=C,@='5L86ID;VYO<R!A;'1E<FYA=.UV(&UE9VYE=F5ZZ7-E`%@U
M,#EV,R!T=6QA:F1O;F]S(&MU;&-S87IO;F]S[73S`%@U,#EV,R!K:71E<FIE
M<WITZ7-E:P!960!965E9`%EA:&]O(2!TZ7)KZ7``Z78`Z79E;G1E`.EV96YT
M93H@:7-MZ71L]61I:R!M:6YD96X`2F5M96X`26=E;@!)9V5N+"!B96QE9WEE
M>F5M+@!-;W-T($A434P@5$585"!M\V1B86X@=F%N+B!(87-Z;N%L:F$@82!;
M/#Y=(&=O;6)O="P@:&$@=FES<WIA(&%K87(@=N%L=&%N:2!A('-Z;VOA<V]S
M(&=R869I:W5S("A765-)5UE'*2!M96=J96QE;NUTZ7-R92X`3F5M(&AO>FAA
M="!LZ71R92`E9"!B;&]K:V[A;"!T]F)B970N`$YE;2!H;WIH870@;.ET<F4@
M=/9B8BP@;6EN="`E9"!E;&9O9VQA;'1SX6=O="X`UFX@;F5M('+I<WIT=F5V
M]6IE(&$@;65G:F5L]FQT(&5S96WI;GEN96LN`$%Z(-9N(&9E;&AA<WINX6SS
M87IO;F]S[73A<V$@;F5M('3V<G3I;G0@;65G+@!%>B!A>B!A8FQA:R!C<V%K
M(&$@(E+I<WIT=F5V]6L@;?-D;W/M=.%S82(@:^EP97)N>?5R]6P@:.UV:&%T
M\R!M96<N`$$@=&5L:F5S(&[I=F)E;B!N96T@<WIE<F5P96QH970@82`G7"<@
M:V%R86MT97(N`$YE;2!A9&]T="!M96<@Z7)VZ6YY97,@96UA:6P@8^UM970N
M`$YE;2!A9'1A(&UE9R!A(&UE9V9E;&5L=&5TZ7-T(&%Z(&EM<&]R=.%L="!F
MX6IL(.ES(&$H>BD@)7,@;65Z]6D@:_9Z]G1T+@!.:6YC<R!M96=A9'9A(&%Z
M(&5M86EL(&/M;64@87H@UFX@<WIE;>EL>65S(&%Z;VYO<^UT\VKA8F%N(&$@
M;&5V96QE>NES(&)EX6QL[73A<V%I(&OV>O9T="X@17IT(&UE9R!K96QL(&%D
M;FEA("5S:71T)7,@86AH;WHL(&AO9WD@97-E;>EN>65K<F4@<WKS;/,@;65G
M:.UV\VMA="!K_&QD:&5S<V5N(&$@<F5N9'-Z97(N`-9N;F5K(&YI;F-S(&IO
M9V]S=6QT<^%G82!E;&9O9VQA;'1SX6=O:V%T(&)E[7)N:6$@)7,M8F4N`-9N
M;F5K(&YI;F-S(&IO9V]S=6QT<^%G82!E;&9O9VQA;'1SX6=O:V%T(&)E[7)N
M:6$@82!K:7;A;&%S>G1O='0@;F%P=.%R8F$N`-9N;F5K(&YI;F-S(&IO9V]S
M=6QT<^%G82!T]G+V;&YI(&5Z="!A>B!E;&9O9VQA;'1SX6=O="X`UFYN96L@
M;FEN8W,@:F]G;W-U;'1SX6=A(&WS9&]S[71A;FD@97IT(&%Z(&5L9F]G;&%L
M='/A9V]T+@!3:6ME<F5S96X@:VEJ96QE;G1K97IE='0N`$AI8N%S+V5L9F]G
M861H871A=&QA;B!A(&UE9V%D;W1T(&YA<'3A<BX`UFX@96QF;V=A9'1A(&$@
M;65G:.UVX7-T(&5R<F4@87H@96QF;V=L86QT<^%G<F$N`-9N('9I<W-Z875T
M87/M=&]T=&$@82!RZ7-Z=NET96QT(&5Z96X@87H@96QF;V=L86QT<^%G;VXN
M`-9N(&9E;'3I=&5L97-E;B!E;&9O9V%D=&$@82!M96=H[7;A<W0N`$5G>2!M
M;V)I;'1E;&5F;VYS>N%M;W0@:V5L;"!M96=A9&YI82P@8W-A:R!A('-ZX6UJ
M96=Y96ME="P@97-E=&QE9R!E9WD@)RLG(&MA<F%K=&5R<F5L(&ME>F1V92P@
M:&$@;F5M>F5T:_9Z:2!TX7)C<^%ZX7-I(&WS9&]T(&OM=N%N(&AA<WINX6QN
M:2X`16QF;V=A9&AA=/,@Z7)TZ6ME="!K96QL(&UE9V%D;FEA+@!!($1A=&%4
M<F5E(&%L<F5N9'-Z97)T(&)E(&ME;&P@X6QL[71A;FD@82!B96IE;&5N=&ME
M>NES:2!J;V=O<W5L='/A9V]K(&EGZ6YY;.ESZ6AE>BX`02!61E,@86QR96YD
M<WIE<B!N:6YC<R!B9>%L;.UT=F$N`$5L]6)B(&QE(&ME;&P@[7)N:6$L(&AO
M9WD@;6EL>65N('!R;V)LZ6WA="!T87!A<WIT86QT+"!M:65L]71T(&5L:_QL
M9&D@82!H:6)A:F5L96YTZ7-T+@!-96<@:V5L;"!A9&YI(&5G>2!54DPM="P@
M86AO=F$@97H@82!L:6YK(&UU=&%T`$5L]7-Z]G(@:VD@:V5L;"!VX6QA<WIT
M86YI82!A('3V<FQE;F3U(&YA<'3A<G0N`$5L]7-Z]G(@:VD@:V5L;"!VX6QA
M<WIT86YI82!E9WD@8^UM970N`$MI(&ME;&P@=N%L87-Z=&%N:2!E9WD@=/9R
M;&5N9/4@<WIE<G9E<G0N`$UE9R!K96QL(&%D;FEA+"!H;V=Y(&UE;'EI:R!F
M96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N:F$@=/9R]FQN:2X`365G(&ME;&P@
M861N:6$@87H@96QTX79O;.UT86YD\R!F96QH87-Z;N%L\VD@;F5V970N`$UE
M9R!K96QL(&%D;FEA(&$@:&]Z>N%A9&%N9/,@9F5L:&%S>F[A;/,@;F5VZ70N
M`$UE9R!K96QL(&%D;FEA+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T
M86ET(&OM=N%N:F$@X73M<FYI+@!-96<@:V5L;"!A9&YI82!E9WD@<&%R86YC
M<V]T+@!-96<@:V5L;"!A9&YI82!A>B#Z:B!K871E9_-R:6$@;F5VZ70N`$]L
M87-Z;W)S>N%G:2!T96QE9F]N<WKA;6]T(&ME;&P@;65G861N:6$`R7)T97/M
M=.ES="!KZ7)T(&$@;F%P=.%R86EB86X@;65G:F5L96[U(/IJ(&5L9F]G;&%L
M='/A9V]K<O-L+@#)<G1E<^UTZ7-T(&OI<G0@82!N87!TX7)A:6+S;"!T]G+V
M;'0@96QF;V=L86QT<^%G;VMR\VPN`,ER=&5S[73I<W0@:^ER="!A(&YA<'3A
M<F%I8F%N(&WS9&]S[71O='0@96QF;V=L86QT<^%G;VMR\VPN`-9N(&9I9WEE
M;&UE>G1E=.ES="!KZ7)T("5S(&5L9F]G;&%L='/A9V=A;"!K87!C<V]L871B
M86XL(&%M:6YE:R!I9/5P;VYT:F$@)7,L("5S`$%Z(-9N("5S(&MA<&-S;VQA
M=&$@:63U=/IL;.EPZ7,@;6EA='0@;65G<WIA:V%D="X@2^ER96T@:F5L96YT
M:V5Z>F5N(&)E(/IJ<F$N`$%Z(-9N(&5M86EL(&/M;64`07H@UFX@9F5L863S
M:2`H1G)O;3HI(&/M;64Z`%-Z96WI;'EE<R!I;F9O<FWA8VGS`$%Z(-9N("5S
M(&MA<&-S;VQA=.%N86L@:V5Z9&5T92#S=&$@;65G=N%L=&]Z;W1T(&%Z(&EN
M=&5R;F5T(&/M;64N($)I>G1O;G/A9^%N86L@Z7)D96OI8F5N(&ES;>ET(&)E
M(&ME;&P@:F5L96YT:V5Z;FEE+@!!>B#6;B!N979E`$%Z(-9N(&9E;&AA<WIN
MX6SS87IO;F]S[73S(&%L<F5N9'-Z97)E(&YE;2!T97-Z:2!L96AE=/5VZ2!A
M>B#Z:B!F96QH87-Z;N%L\VL@;.ET<F5H;WKA<^%T+B!(82!A($AO<F1E(')E
M;F1S>F5R<F5L(&OM=N%N:F$@:V5Z96QN:2!A(&9E;&AA<WINX6SS:2!A9&%T
M;VMA="P@86MK;W(@;>%S:6L@9F5L:&%S>F[A;/-A>F]N;W/M=/,@86QR96YD
M<WIE<G)E('9A;B!S>OQK<^EG92X`07H@UFX@9F5L:&%S>F[A;/-A>F]N;W/M
M=/,@86QR96YD<WIE<F4@;F5M('1E<WII(&QE:&5T]7;I(&$@9F5L:&%S>F[A
M;/-K(&QI<W3A>N%SX70L('9A9WD@=F%L86UI(&]K8O-L(&QE=&EL=&]T=.%K
M(&5Z="!A(&QE:&5T]7/I9V5T+@!!>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82!M
M96=VX6QT;WIO='0@87H@UFX@)7,@;75N:V%K87!C<V]L873A;F%K(&ME>F1E
M=&4@\W1A+B!":7IT;VYSX6=A(.ER9&5KZ6)E;B!I<VWI="!B92!K96QL(&IE
M;&5N=&ME>FYI92X`07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;F5M('3A;6]G
M871J82!E>G0@82!L96AE=/5SZ6=E="X`07H@UFX@8O9N9^ES>O5P<F]G<F%M
M:F$@;F5M('3A;6]G871J82!E>G0@82!N>6]M=&%TX7-I(&]P8VGS="X@4'+S
M8N%L:F]N(&$@0W1R;"U0("AV86=Y($-O;6UA;F0M4"D@;&5N>6]MX7/A=F%L
M(&YY;VUT871N:2X`02!J96QE;FQE9R#I<G;I;GEE<R!I9/5Z\VYA.@!!>B#6
M;B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!N87!TX7)A`$%Z(-9N(&%L87#I
M<G1E;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\VIA(&UE9W;A;'1O>F]T="X`
M07H@UFX@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S[73S:F$Z`$%Z
M(-9N('1E;&IE<R!N979E.@!,96KA<G0@82!B96IE;&5N=&ME>NES:2!J;V=O
M<W5L='/A9V$N`$%Z(-9N("5S+7)E(&AA<WINX6QT(/IJ(&IE;'-Z879A.B`E
M<P!!>B#6;B#Z:B!B9>%L;.UTX7-A:70@Z7)VZ6YY97/M=&5T=/QK(&$@;6]S
M=&%N:2!B96IE;&5N=&ME>NES(&ED96KI<F4N`$%Z(-9N(/IJ(&)EX6QL[73A
M<V%I="!E;&UE;G1E='3\:RX`07H@UFX@:F5L<WIA=N%T(.%TX6QL[71O='1U
M:P!!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T='5K+"!NZ7IZ92!M96<@82!L
M979E;&5I="P@;6%J9"!J96QE;G1K97IZ96X@8F4@87H@^FH@:F5L<WKS=F%L
M+@!!>B#6;B!J96QS>F%VX6YA:R!L96KA<G0@87H@Z7)VZ6YY97-SZ6=I(&ED
M96IE+@!!>B#6;B#A;'1A;"!H87-Z;N%L="!TX79O;&D@<WIE<G9E<F5K.@!*
M=6=O<WILX79I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6TYE(&UU=&%S<W5K
M(&$@8F5I9.EZ971T('-Z]G9E9V5T70!;2&EB86IE;&5N=.ES70!;375T87-S
M=6L@82!B96EDZ7IE='0@<WKV=F5G970@+0!;375T87-S=6L@82!B96EDZ7IE
M='0@<WKV=F5G970@+2`E<R!S;W)=`%ME;&YE=F5ZZ7,@;NEL:_QL:2!E;&9O
M9VQA;'1SX6==`%LE<R\E<R!S;W)=`%]!9&UI;FES>G1RX6-I\P!&:6=Y96QM
M97IT973I<P!+97)E<^ES`%]087)A;F-S<V]R`%-O<G3V<FSI<P!-\V1O<^UT
MX7,`7U5G<N%S`%]#<V]P;W)T;VL`4V5?9^UT<^EG`$$@:^EP('1U;&%J9&]N
M<^%G86DN+BX`26UP;W)T+U]%>'!O<G0`0F5J96QE;G1K97KI<P!?2VEJ96QE
M;G1K97KI<P!!(&QI;FL@;?-D;W/M=.%S82XN+@!.87!TX7)A:5]M`-I?:B!E
M;&9O9VQA;'1SX6<`7T]P8VGS:P!?2F]G;W-U;'1SX6=O:P!?3GEO;71A=.%S
M`$$@;&EN:R!T]G)LZ7-E+BXN`$ME<F5?<^ES`%]"9>%L;.UTX7-O:P!4X6)L
MX7IA="!T=6QA:F1O;G/A9V]K`$U?80!?1F5L:&%S>F[A;/-K`&/M;6IE9WEZ
MZ6L`82!C[6UZ971T(&ES;65R971L96X`87H@97-E;>EN>2!E;/5T=`!N87!T
MX7(`;GEU9V]D=`!A(&MI;65N971I(.%L;&]MX6YY(&YE;2!H;WIH873S(&SI
M=')E`&$@8F5M96[U(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<`:V%T=&EN
M='-O;B!I9&4`<&%R86YC<W-O<FD@:&EB80!K;VYF:6=U<N%C:?-S(&AI8F$`
M:&GA;GEZ:6L@96=Y(&9O;G1O<R!R96YD<WIE<N%L;&]MX6YY`&%D871F;W)M
MX71U;2!H:6)A`&YA<`!N87``;F%P`&WS9&]S[73A<P!A>B!A9&%T(&YE;2!T
M86SA;&AA=/,`8W/V:VME;@!FX6IL`"5S("@E<RD@:7+A;GEB\VPL("5S("5S
M('-E8F5S<^EG9V5L`'-ZZ6QL]FOI<V5K`&TZ`&$@9^EP(&YE=F4@;F5M(&ES
M;65R=`!A>F]N;F%L:0!I;G!U="]O=71P=70@:&EB80!B96QS]2!P<F]G<F%M
M:&EB80!S;W)=`$%Z(&UK<VEO9G,@<')O9W)A;2`E9"!H:6)A:_-D9&%L(&QE
MX6QL="!A>B!)4T\@X6QL;VWA;GD@:^ES>NUTZ7-E(&OV>F)E;BX`+B!H\VYA
M<`!NZ78`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE9W9A
M;/-S[71V82X`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE
M9W9A;/-S[71V82X`:F5G>7IE='3V;6(`)7,L("5S`"!A(&CS;F%P('5G>6%N
M87IO;B!N87!JX6X`(&$@:.ET('5G>6%N87IO;B!N87!JX6X`<WKA>F%LZ6L`
M;FEN8W,@;65G9F5L96SU(&IO9V]S=6QT<^%G80!P:7AE;`!A9&%TX71V:71E
M;&D@*'!R;W1O:V]L;"D@:&EB80!E;65L:V5D:6L`82!S>F]L9^%L=&%TX7,@
M;F5M(.%L;"!R96YD96QK97KI<W)E`&[I>GK\:R!M96<@82!K_&SV;F)SZ6=E
M:V5T`'-M<S)E;6%I;"!S>F]L9^%L=&%TX7,@2%144"UN(.%T`';A;'1O>F%T
M;&%N`')E;F1S>F5R:&EB80!F96QA9&%T;&ES=&$`X71M96YE=&D@:&EB80!M
M96=E<O5S[73I<VOI;G0@:^ET<WIE<B#M<FIA(&)E(&$@:F5L<WKS=`!NZ78@
M;NEL:_QL`&$@9F5L:&%S>F[A;/,@X6QT86P@=N%L87-Z=&AA=/,`=D-A<F0`
M02!V179E;G0@;F5M('1A;.%L:&%T\RX`<WHZ`&CI=``N(&CI=&5N(&$@:_9V
M971K97KU(&YA<"AO:REO;CH`:.ET`"X@Z79B96X`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+VAU7TA5+VAE;'`N>&UL````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T,#8W`#$P-#$W,S8R-S4P`#`R
M,C,V,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TR(C\^
M"CPA+2T@2W)O;F]L:71H(#(N,2!H96QP.B!H=5](52`D2&]R9&4Z(&MR;VYO
M;&ET:"]L;V-A;&4O:'5?2%4O:&5L<"YX;6PL=B`Q+C(N,3(N,2`R,#`V+S`S
M+S`S(#$S.C0T.C$Q(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED
M/2)/=F5R=FEE=R(@<W1A=&4](G5P=&]D871E(B!M9#4](C$U.#4Y,C=D-#AE
M-#8R-V,W.3)F93`S,S)C-#%F9#,Y(CX*("`@(#QT:71L93Y+<F]N;VQI=&@@
M*$YA<'3A<BDZ(.%T=&5K:6YTZ7,\+W1I=&QE/@H@("`@/&AE861I;F<^36ER
M92!J\R!A($MR;VYO;&ET:"`H3F%P=.%R*3\\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($$@2W)O;F]L:71H(&5G>2!W96(@86QA</H@;F%P=.%R<')O9W)A
M;2X@07IO;B!T^FPL(&AO9WD@"B`@("!E;&9O9VQA;'1SX6=O:V%T(&QE:&5T
M(&SI=')E:&]Z;FDL(';A;'1O>G1A=&YI(.ES('3V<O9L;FDL(&5G>2!S;W(@
M"B`@("!E9WGI8B!D;VQG;W0@:7,@=.%M;V=A=#H@:7-MZ71L]63U(&5S96WI
M;GEE:V5T("AK:7;I=&5L96MK96P@Z7,@"B`@("!T]F)B9NEL92!T]G)LZ7-I
M(&QE:&5T]7/I9V=E;"DL(&%L87)M+"!I;7!O<G0@Z7,@97AP;W)T(&9U;FMC
M:?-K870*("`@("AI0V%L96YD87(@Z7,@0U-6(&9O<FWA='5M;VMK86PI+B!4
M]F)B9NEL92!NZ7IE="!H87-Z;N%L:&%T\RP@"B`@("!K]GKV<V5N(&AA<WIN
MX6QT(&YA<'3A<F%K(&ES(&SI=')E:&]Z:&%T\VLN($$@<')O9W)A;2!M=71A
M=&IA(&$@"B`@("!F96QA9&%T;VL@;&ES=.%JX70@*&%M96YN>6EB96X@97H@
M82!P<F]G<F%M("T@3F%G("T@=&5L97#M='9E('9A;BDL(`H@("`@=&]VX6)B
MX2!A>B!E;&9O9VQA;'1SX6=O:R!L:7-TX6KA="!A($AO<F1E(/9S<WIE9F]G
M;&%L\R!KZ7!E<FYY]6X@"B`@("!I<R!M96<@='5D:F$@:F5L96[M=&5N:2X*
M("`@(#PO<&%R83X*("`\+V5N=')Y/@H*("`\96YT<GD@:60](FUE;G4M=&]D
M87DB('-T871E/2)U<'1O9&%T92(@;60U/2)C-F0P8S!F,S8V,3<U83,X9#`V
M-35E9#DY-CEE9#1A-B(^"B`@("`\=&ET;&4^365N_#H@36$\+W1I=&QE/@H@
M("`@/&AE861I;F<^36$\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@/&D^
M36$\+VD^(&UE;OQP;VYT(&%Z(&%L87#I<G1E;&UE>F5T="!M\V1O;B`H:&%V
M:2P@:&5T:2P@;F%P:2!S=&(N(`H@("`@;NEZ971B96XL(&%H;V=Y(&%Z($]P
M8VGS:V)A;B!B92!V86X@X6QL[71V82D@:F5L96[M=&D@;65G(&%Z(&%Z;F%P
M:2`*("`@(&3A='5M;W0N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*"B`@/&5N
M=')Y(&ED/2)M96YU+4=O=&\B('-T871E/2)U<'1O9&%T92(@;60U/2(U-C8Q
M.3$W-S5B83DP8C<V.68R93-F-V-D9C(T8V)F82(^"B`@("`\=&ET;&4^365N
M_#H@56=RX7,\+W1I=&QE/@H@("`@/&AE861I;F<^56=RX7,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($%Z(#QI/E5G<N%S/"]I/B!M96[\<&]N="!E9WD@
M:VES(&9E;&)U:VMA;O,@86)L86MO="!J96QE;NUT(&UE9RP@"B`@("!M96QY
M8F5N(&=Y;W)S86X@:VEVX6QA<WIT:&%T\RP@:&]G>2!M96QY:6L@9.%T=6UR
M82!U9V]R:G5N:R`H<&PN(`H@("`@;65G861H873S(&%Z(.EV+"!A(&CS;F%P
M+"!A>B#I=B!V86QA:.%N>6%D:6L@:&5T92P@82!H\VYA<"!A9&]T="`*("`@
M(&YA<&IA*2X@4F5N9'-Z97)I;G0@97H@82!N87!TX7)B86X@=F%L\R!DX71U
M;7;A;&%S>G3A<R!L96=G>6]R<V%B8B`*("`@(&WS9&IA+@H@("`@/"]P87)A
M/@H@(#PO96YT<GD^"@H@(#QE;G1R>2!I9#TB;65N=2U$87DB('-T871E/2)U
M<'1O9&%T92(@;60U/2(S8V0V,F4Q,#$Q-C`U.&1B-3)A,35F96-D-V1D8F-B
M,"(^"B`@("`\=&ET;&4^365N_#H@3F%P/"]T:71L93X*("`@(#QH96%D:6YG
M/DYA<&D@;NEZ970\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@/&D^3F%P
M/"]I/B!M96[\<&]N="!A(&MI=N%L87-Z=&]T="!DX71U;2!N87!I(&[I>F5T
MZ70@:F5L96[M=&D@;65G+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"@H@(#QE
M;G1R>2!I9#TB;65N=2UW;W)K+7=E96LB('-T871E/2)U<'1O9&%T92(@;60U
M/2)F.6$V,S4X-6,X,61C838S.#@W93$S,&1B8F5A.3%D92(^"B`@("`\=&ET
M;&4^365N_#H@375N:V%HZ70\+W1I=&QE/@H@("`@/&AE861I;F<^375N:V%H
MZ70@;NEZ970\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@/&D^375N:V%H
MZ70\+VD^(&UE;OQP;VYT(&$@:VEVX6QA<WIT;W1T(&3A='5M:&]Z(&QE9VOV
M>F5L96)B(&5S]0H@("`@;75N:V%H971E="!J96QE;NUT:2!M96<@*&CI=&;U
M=/5L('#I;G1E:VEG*2X*("`@(#PO<&%R83X*("`\+V5N=')Y/@H*("`\96YT
M<GD@:60](FUE;G4M=V5E:R(@<W1A=&4](G5P=&]D871E(B!M9#4](C-D.&$S
M8F9D838R.6)B-F4P.3@Q.6(R938V,#4T-F4U(CX*("`@(#QT:71L93Y-96[\
M.B!(Z70\+W1I=&QE/@H@("`@/&AE861I;F<^2&5T:2!NZ7IE=#PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@02`\:3Y(Z70\+VD^(&UE;OQP;VYT(&$@:VEV
MX6QA<WIT;W1T(&3A='5M;W0@=&%R=&%L;6%Z\R!HZ70@861A=&%I=`H@("`@
M:F5L96[M=&D@;65G("@W(&YA<&]S(&[I>F5T*2X*("`@(#PO<&%R83X*("`\
M+V5N=')Y/@H*("`\96YT<GD@:60](FUE;G4M;6]N=&@B('-T871E/2)U<'1O
M9&%T92(@;60U/2(T8F4R,#4V.#<U-S<U96,Q9C5B,&8Y,C!A,61A8C8P."(^
M"B`@("`\=&ET;&4^365N_#H@2/-N87`\+W1I=&QE/@H@("`@/&AE861I;F<^
M2/-N87`@;NEZ970\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@/&D^2/-N
M87`\+VD^(&UE;OQP;VYT(&$@:VEVX6QA<WIT;W1T(&3A='5M;W0@=&%R=&%L
M;6%Z\R!H\VYA<"!A9&%T86ET"B`@("!J96QE;NUT:2!M96<N"B`@("`\+W!A
M<F$^"B`@/"]E;G1R>3X*"B`@/&5N=')Y(&ED/2)M96YU+6YE=RUE=F5N="(@
M<W1A=&4](G5P=&]D871E(B!M9#4](C,W-#`V8V,R964U,3`T,#@V,F1F,65A
M83)F-C0U9#1E(CX*("`@(#QT:71L93Y-96[\.B#::B!E;&9O9VQA;'1SX6<\
M+W1I=&QE/@H@("`@/&AE861I;F<^VFH@96QF;V=L86QT<^%G(&SI=')E:&]Z
MX7-A/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!>B`\:3[::B!E;&9O9VQA
M;'1SX6<\+VD^(&UE;OQP;VYT('-E9^UT<^EGZ79E;"#Z:B!E<V5MZ6YY="!R
M]F=Z[71H970*("`@(&$@;F%P=.%R8F%N+@H@("`@/"]P87)A/@H@(#PO96YT
M<GD^"@H@(#QE;G1R>2!I9#TB;65N=2UO<'1I;VYS(B!S=&%T93TB=7!T;V1A
M=&4B(&UD-3TB9#=D9C)C,&-D83@T8S@Y8S8S.&0Y9#9E-3DS,#<Y-S8B/@H@
M("`@/'1I=&QE/DUE;OPZ($]P8VGS:SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/
M<&-I\VL\+VAE861I;F<^"B`@("`\<&%R83X*("`@($%Z(#QI/D]P8VGS:SPO
M:3X@;65N_'!O;G0@<V5G[71SZ6?I=F5L('-Z96WI;'EE<R!I9^EN>65I;F5K
M(&UE9V9E;&5L]65N"B`@("#A;&SM=&AA=&IA(&)E(&$@<')O9W)A;2!T=6QA
M:F1O;G/A9V%I="P@;>%S($AO<F1E('!R;V=R86UM;V1U;&]K:V%L(`H@("`@
M=F%L\R!E9WG\='1M^VOV9.ESZ70L('3V8F(@:6QL+B!MX7-O:VMA;"!K]GKV
M<R!N87!TX7)A:V%T(&AA<WINX6QH870N"B`@("`\+W!A<F$^"B`@/"]E;G1R
M>3X*"B`@/&5N=')Y(&ED/2)M96YU+6EM<&]R="UE>'!O<G0B('-T871E/2)U
M<'1O9&%T92(@;60U/2(S-&)C.61F8S1D-C,P,F9C,3`Q,38Y-F$Q8CAD,6-A
M."(^"B`@("`\=&ET;&4^365N_#H@26UP;W)T+T5X<&]R=#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY);7!O<G0O17AP;W)T/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!!>B`\:3Y);7!O<G0O17AP;W)T/"]I/B!M96[\<&]N="!S96?M='/I
M9^EV96P@:6UP;W)TX6QH873S:R!I;&PN"B`@("!E>'!O<G3A;&AA=/-K(&$@
M;F%P=.%R:2!E;&9O9VQA;'1SX6=O:RX@2F5L96YL96<@0U-6("AC;VUM82!S
M97!A<F%T960@"B`@("!V86QU93H@=F5S<WKU=F5L(&5L=N%L87-Z=&]T="!A
M9&%T9F]R;>%T=6TI+"!-:6-R;W-O9G0@3W5T;&]O:R#I<R`*("`@('9#86QE
M;F1A<B]I0V%L96YD87(@9F]R;>%T=6WZ(&%D871O:R!I;7!O<G3A;&AA=/-K
M+B!%>'!O<G3A;&YI(&-S86L@"B`@("!#4U8@Z7,@:4-A;&5N9&%R(&9O<FWA
M='5M8F%N(&QE:&5T+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"@H@(#QE;G1R
M>2!I9#TB86QA<FUS(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-&,Q8S9F,V5B
M,3-A-#$V,#,Q9F9B964T9F-E.3EE83$B/@H@("`@/'1I=&QE/D9I9WEE;&UE
M>G1E=.ES("AA;&%R;2D\+W1I=&QE/@H@("`@/&AE861I;F<^1FEG>65L;65Z
M=&5TZ7-E:SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@02!P<F]G<F%M(.EB
M<F5S>G3U\W)A<WIE<OME;B!F:6=Y96QM97IT971N:2!T=61J82!A('-ZX6WM
M=/-GZ7`@"B`@("!F96QH87-Z;N%L\VKA="!A>B!E9WEE<R!E;&9O9VQA;'1S
MX6=O:W)A+B!!;&%PZ7)T96QM97KI<R!S>F5R:6YT(&%Z"B`@("!E;'/U(&9I
M9WEE;&UE>G1E=.ES="`Q-2!P97)C8V5L(&%Z(&5S96WI;GD@:V5Z9&5T92!E
M;/5T="!K87!J80H@("`@82!F96QH87-Z;N%L\RP@9&4@97H@<WIA8F%D;VX@
MX6QL[71H873S(&)E+"!K_&SV;BUK_&SV;B!A>B!E9WEE<R`*("`@(&5L9F]G
M;&%L='/A9V]K<F$N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*"B`@/&5N=')Y
M(&ED/2)R96-U<G)I;F<M979E;G1S(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M.#-A,&,S83AA,F0R9C5C93AB-34Q,&)D83(U-38T,V0B/@H@("`@/'1I=&QE
M/DES;>ET;/5D]2!E;&9O9VQA;'1SX6=O:SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY)<VWI=&SU9/4@96QF;V=L86QT<^%G;VL\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($%Z(&5G>65S(&5S96WI;GEE:VAE>B!T]F)B9NEL92!M\V1O;B#A
M;&SM=&AA=/,@8F4@87H@:7-MZ71L]63I<RX@07H*("`@(&5L9F]G;&%L='/A
M9V]K(&=Y86MR86X@96=Y<WIE<OL@;?-D;VX@:7-MZ71L]61N96LL('!L+B!A
M(#QI/FAA=FD\+VD^"B`@("!V86=Y(#QI/FAE=&D\+VD^(&ES;>ET;/5DZ7,@
M82!K:7;A;&%S>G1O='0@97-E;>EN>70@:&%V:2!I;&PN(&AE=&D*("`@(&ES
M;>ET]63I<_MVZ2!T97-Z:2X@07H@:7-MZ71L]63I<V5K(&)O;GEO;'5L=&%B
M8F%N(&ES(&UE9V%D:&%T\VLZ('!L+@H@("`@;6EN9&5N(&CS;F%P(&AA<FUA
M9&EK('#I;G1E:^EN+"!V86=Y(&UI;F1E;B!HZ71E;B!HZ71F]6XL('-Z97)D
MX6X@Z7,*("`@('#I;G1E:V5N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!!>B!I<VWI=&SU9.ES(&ED]71A<G1A;6$@8F5H873A<F]L:&%T\R!A>B!I
M<VWI=&SU9.ES="!VZ6?I="!J96QZ]0H@("`@9.%T=6T@;65G863A<^%V86PN
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%M96YN>6EB96X@;?-D;W/M
M='5N:R!E9WD@:7-MZ71L]63U(&5S96WI;GET+"!A:VMO<B!A(&WS9&]S[73A
M<PH@("`@87H@97-E;>EN>2#V<W-Z97,@96SU9F]R9'5LX7/A<F$@Z7)VZ6YY
M97,@;&5S>BX@06UE;FYY:6)E;B!E9WD@"B`@("!I<VWI=&SU9/4@96QF;V=L
M86QT<^%G(&5G>65T;&5N(&5L]69O<F1U;.%SX70@:^UVX6YJ=6L@;65G=N%L
M=&]Z=&%T;FDL"B`@("!A:VMO<B!S>OQN=&5S<_QK(&UE9R!A>B!I<VWI=&SU
M9.ESZ70L(&UA:F0@87H@/&D^VFIKZ6YT(&UE;G1S_&L@96P\+VD^"B`@("!G
M;VUB<F$@:V%T=&EN='9A(&UE;G1S_&L@96PN($5Z="!K]G9E=/5E;B!A>B!E
M<V5MZ6YY;F5K(&5Z(&%Z(`H@("`@96SU9F]R9'5LX7-A(&$@=/9B8FD@:7-M
MZ71L]63I<W3U;"!F_&=G971L96[\;"!M\V1O<^UT:&%T\RX*("`@(#PO<&%R
M83X*("`\+V5N=')Y/@H*("`\96YT<GD@:60](E!R:6YT:6YG(B!S=&%T93TB
M=7!T;V1A=&4B(&UD-3TB,F8Y,&0Q-&4S-&(W,35A,#4T9F(U,F)B.3$Y86,U
M9C@B/@H@("`@/'1I=&QE/DYY;VUT873A<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY!(&YA<'3A<B#I<R!A>B!E;&9O9VQA;'1SX6=O:R!K:6YY;VUT873A<V$\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@;F%P=.%R(&)I>F]N>6]S(&UE
M9VIE;&5N[73I<VD@;?-D:F%I="!K:2!L96AE="!N>6]M=&%T;FDN($5Z96MB
M96X*("`@(&%Z(&5S971E:V)E;B!A(&9E;'/U(&UE;OQS;W)B86X@;65G:F5L
M96YI:R!A(#QI/DYY;VUT873A<SPO:3X@:6MO;BX@"B`@("!%<G)E(&%Z(&EK
M;VYR82!K871T:6YT=F$@:VEN>6]M=&%T:&%T\R!A(&OI<&5R;GGU('1A<G1A
M;&UA+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"CPO:&5L<#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]J85]*
M4"\`````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<U,``P,C`V-30`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N
M;VQI=&@O;&]C86QE+VIA7TI0+TQ#7TU%4U-!1T53+P``````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4Q`#`R,C0T,@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O:F%?2E`O3$-?34534T%'
M15,O:W)O;F]L:71H+FUO````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R,3,Q,3$`,3`T,3<S-C(W-3$`
M,#(U,#`T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-X2!)4``````@0``!P````L(```704``#Q`````````L%4```X```"Q
M50``#P```,!5```(````T%4```P```#950``"0```.95```+````\%4``!\`
M``#\50``#@```!Q6```%````*U8``"@````Q5@``"@```%I6```5````958`
M`!(```![5@``#````(Y6```=````FU8```X```"Y5@``"@```,A6```-````
MTU8``!$```#A5@``#0```/-6```,`````5<```T````.5P``'0```!Q7```=
M````.E<```P```!85P``"@```&57```'````<%<```X```!X5P``#@```(=7
M```(````EE<``"X```"?5P``&@```,Y7```R````Z5<``#@````<6```5```
M`%58``!1````JE@``%H```#\6```5P```%=9```T````KUD```4```#D60``
M$0```.I9```(````_%D``"4````%6@``(````"M:```0````3%H```\```!=
M6@``$````&U:```#````?EH```\```""6@``%````)):```)````IUH```D`
M``"Q6@``#0```+M:```2````R5H``!D```#<6@``#P```/9:```/````!EL`
M``T````66P``"@```"1;```/````+UL```@````_6P``)````$A;```4````
M;5L``!8```""6P``"````)E;```9````HEL```<```"\6P``#````,1;```.
M````T5L```,```#@6P``#P```.1;```%````]%L``!0```#Z6P``%0````]<
M```7````)5P``!4````]7```$@```%-<```3````9EP``!4```!Z7```$P``
M`)!<```*````I%P``!0```"O7```"@```,1<```%````SUP```,```#57```
M#0```-E<```7````YUP```H```#_7```"@````I=```(````%5T```\````>
M70``"P```"Y=```'````.ET```H```!"70``(P```$U=```.````<5T``!0`
M``"`70``%P```)5=```7````K5T``!<```#%70``$P```-U=```?````\5T`
M``\````17@```P```"%>```+````)5X``!4````Q7@``!P```$=>```%````
M3UX``!$```!57@``#````&=>```[````=%X``#D```"P7@```@```.I>``"T
M````[5X``"<```"B7P``+````,I?```J````]U\``"4````B8```"@```$A@
M```)````4V````H```!=8```!@```&A@```O````;V```#<```"?8```+@``
M`-=@``!5````!F$``"T```!<80``+0```(IA```M````N&$``$````#F80``
M(P```"=B```C````2V(``"T```!O8@``,P```)UB```5````T6(``!D```#G
M8@``*0````%C```D````*V,``!$```!08P``"@```&)C```0````;6,``!8`
M``!^8P``%@```)5C```,````K&,```@```"Y8P``"@```,)C```$````S6,`
M``D```#28P``!@```-QC```1````XV,```<```#U8P``#0```/UC```$````
M"V0```,````09````P```!1D```7````&&0```D````P9```"0```#ID```(
M````1&0``!````!-9```"0```%YD```@````:&0``!D```")9```!@```*-D
M```5````JF0```D```#`9```#0```,ID```8````V&0``"(```#Q9```'0``
M`!1E```A````,F4``%0```!490``*0```*EE```'````TV4```D```#;90``
M%0```.5E```(````^V4```H````$9@``#P````]F```-````'V8```\````M
M9@``#0```#UF```)````2V8```8```!59@``$P```%QF```4````<&8```8`
M``"%9@``5````(QF```1````X68``!$```#S9@``'`````5G```V````(F<`
M`!T```!99P``(0```'=G```2````F6<```H```"L9P``$0```+=G```,````
MR6<```4```#69P``#````-QG```0````Z6<```4```#Z9P``#0````!H```&
M````#F@``!8````5:```!P```"QH```-````-&@```<```!":```"P```$IH
M```'````5F@``!D```!>:```#````'AH```0````A6@``!L```"6:```"0``
M`+)H```2````O&@``"L```#/:```.P```/MH```@````-VD``#8```!8:0``
M!````(]I```.````E&D``$````"C:0``'@```.1I```;`````VH``"$````?
M:@``'@```$%J```9````8&H``!X```!Z:@``&P```)EJ```F````M6H``!L`
M``#<:@``'@```/AJ```<````%VL``"8````T:P``,P```%MK```F````CVL`
M`"L```"V:P``.````.)K```O````&VP``!(```!+;```*0```%YL```2````
MB&P``",```";;```*````+]L```I````Z&P``!\````2;0``(````#)M```E
M````4VT``"$```!Y;0``'````)MM```F````N&T``$$```#?;0``!P```"%N
M```&````*6X``!(````P;@``$````$-N```2````5&X```<```!G;@``$P``
M`&]N```2````@VX```P```"6;@``*````*-N```#````S&X```T```#0;@``
M`@```-YN```%````X6X``!,```#G;@``$````/MN```-````#&\```,````:
M;P``!@```!YO```'````)6\```X````M;P``"````#QO```/````16\```\`
M``!5;P``$````&5O```-````=F\``!````"$;P``!@```)5O```)````G&\`
M``P```"F;P``#````+-O```1````P&\```L```#2;P``#0```-YO```B````
M[&\```H````/<```&````!IP```9````,W```!8```!-<```#0```&1P```,
M````<G```!0```!_<```"P```)1P```O````H'````L```#0<```%P```-QP
M```7````]'````<````,<0``%@```!1Q```/````*W$```T````[<0``)@``
M`$EQ```Y````<'$``$,```"J<0``"````.YQ```+````]W$``"\````#<@``
M!P```#-R```(````.W(```8```!$<@``!P```$MR```.````4W(```H```!B
M<@``"@```&UR```/````>'(``!````"(<@``%P```)ER```5````L7(```X`
M``#'<@``&@```-9R```1````\7(``!<````#<P``!0```!MS```-````(7,`
M`!L````O<P``#@```$MS```-````6G,``#@```!H<P``(````*%S```(````
MPG,```8```#+<P``"````-)S```.````VW,```4```#J<P``,0```/!S```9
M````(G0``!`````\=```#P```$UT```0````770```\```!N=```"P```'YT
M```/````BG0```P```":=```#P```*=T```'````MW0```8```"_=```#P``
M`,9T```(````UG0```8```#?=```#P```.9T```(````]G0``!,```#_=```
M'@```!-U```A````,G4``"````!4=0``&0```'5U```7````CW4``"4```"G
M=0``%P```,UU```(````Y74``!,```#N=0``%`````)V```,````%W8```D`
M```D=@``#@```"YV```+````/78``!L```!)=@``!P```&5V```$````;78`
M``H```!R=@``!0```'UV```&````@W8```(```"*=@``!@```(UV```&````
ME'8``!````";=@``"0```*QV```'````MG8``!D```"^=@``#@```-AV```*
M````YW8```<```#R=@``%````/IV```=````#W<```8````M=P``$0```#1W
M```)````1G<``!X```!0=P``#@```&]W```&````?G<```8```"%=P``!```
M`(QW```$````D7<```P```"6=P``"@```*-W```%````KG<```\```"T=P``
M!P```,1W```I````S'<``"0```#V=P``)@```!MX```@````0G@``"````!C
M>```)@```(1X```I````JW@``!8```#5>```"@```.QX```/````]W@``!``
M```'>0``0````!AY``!P````67D```X```#*>0``"0```-EY```*````XWD`
M``8```#N>0``&````/5Y```/````#GH``!8````>>@``$@```#5Z```0````
M2'H``!P```!9>@``(P```'9Z```/````FGH``!````"J>@``"P```+MZ```4
M````QWH```P```#<>@``#````.EZ```/````]GH``!4````&>P``*0```!Q[
M```J````1GL``"8```!Q>P``)P```)A[```I````P'L``"H```#J>P``&0``
M`!5\```1````+WP``!(```!!?```$P```%1\```4````:'P``!8```!]?```
M%P```)1\```0````K'P``!$```"]?```$P```,]\```2````XWP``#4```#V
M?```%````"Q]```4````07T``!<```!6?0``'````&Y]```:````BWT``!<`
M``"F?0``%0```+Y]```&````U'T```8```#;?0``!P```.)]```$````ZGT`
M``0```#O?0``!P```/1]```.````_'T```P````+?@``#````!A^```-````
M)7X``"@````S?@``#````%Q^```/````:7X```H```!Y?@``"````(1^```K
M````C7X```@```"Y?@``"````,)^```-````RWX```T```#9?@``"@```.=^
M```.````\GX``!8````!?P``$0```!A_```)````*G\```8````T?P``#@``
M`#M_```0````2G\```L```!;?P``&@```&=_```)````@G\```\```",?P``
M"````)Q_```&````I7\```<```"L?P``"P```+1_``!'````P'\```T````(
M@```$P```!:````3````*H```!,````^@````@```%*````E````58````0`
M``![@```&````("```!H````F8````4````"@0``#P````B!```#````&($`
M``<````<@0``!P```"2!```*````+($```L````W@0``!P```$.!``!1````
M2X$```8```"=@0``"0```*2!```)````KH$``%<```"X@0```@```!""```+
M````$X(```T````?@@``!@```"V"```%````-((```H````Z@@``!P```$6"
M```5````38(```D```!C@@``"0```&V"```*````=X(```<```""@@``"0``
M`(J"```'````E((```H```"<@@``#````*>"```-````M((``!````#"@@``
M$@```-."```$````YH(```<```#K@@``!0```/."```,````^8(```D````&
M@P``%P```!"#```$````*(,```T````M@P``"0```#N#```)````18,```P`
M``!/@P``.````%R#```E````E8,```H```"[@P``+````,:#```S````\X,`
M`#,````GA```.````%N$```/````E(0``!@```"DA```"P```+V$```4````
MR80``"P```#>A```%`````N%```2````((4``!0````SA0``+0```$B%```M
M````=H4``#$```"DA0``+@```-:%```O````!88``"P````UA@``8@```&*&
M```3````Q88``"$```#9A@``&@```/N&```)````%H<``$4````@AP``00``
M`&:'```$````J(<```D```"MAP``"@```+>'```%````PH<```@```#(AP``
M`P```-&'```X````U8<```(````.B```!@```!&(```.````&(@```<````G
MB```!@```"^(```I````-H@``!\```!@B```7````("(```4````W8@``#X`
M``#RB```"````#&)```'````.HD```X```!"B0``#````%&)```,````7HD`
M`!,```!KB0``"@```'^)```=````BHD``!$```"HB0``!0```+J)```1````
MP(D``"0```#2B0``%0```/>)```2````#8H```X````@B@``&0```"^*```(
M````28H```D```!2B@``!P```%R*```(````9(H``!(```!MB@``+````("*
M```:````K8H```D```#(B@``"@```-**```5````W8H```4```#SB@``%```
M`/F*```'````#HL``!`````6BP``!P```">+```>````+XL``"@```!.BP``
M'@```'>+```*````EHL``!$```"ABP``"P```+.+```:````OXL``!0```#:
MBP``!0```.^+```&````]8L``"````#\BP``*0```!V,``!!````1XP``"@`
M``")C```*0```+*,```%````W(P```X```#BC```+@```/&,```T````((T`
M``<```!5C0``(0```%V-```.````?XT```L```".C0``!P```)J-```3````
MHHT```H```"VC0``%````,&-```R````UHT```4````)C@``%P````^.```%
M````)XX```0````MC@``,@```#*.``!%````98X```L```"KC@``#````+>.
M```.````Q(X```T```#3C@``#0```.&.```7````[XX``!X````'CP``%```
M`":/```0````.X\``!$```!,CP``#@```%Z/```J````;8\```8```"8CP``
M"0```)^/```/````J8\```P```"YCP``"P```,:/```+````TH\```\```#>
MCP``,@```.Z/```(````(9```!(````JD```!0```#V0```1````0Y````@`
M``!5D```!P```%Z0```1````9I```!0```!XD```&````(V0```$````II``
M``X```"KD```#@```+J0```%````R9````,```#/D```'@```-.0```8````
M\I```"4````+D0``"0```#&1```#````.Y$```(````_D0``"````$*1```'
M````2Y$```L```!3D0``"@```%^1```,````:I$``!<```!WD0``!@```(^1
M```5````EI$``!(```"LD0``#P```+^1```4````SY$``%@```#DD0``(0``
M`#V2``!I````7Y(``!H```#)D@``%P```.22```9````_)(``!H````6DP``
M&0```#&3```E````2Y,``"<```!QDP``&@```)F3```7````M),``!T```#,
MDP``)@```.J3```;````$90``"H````ME```&0```%B4```?````<I0``!,`
M``"2E```"````*:4``!$````KY0``!,```#TE```0`````B5```)````294`
M``T```!3E0``#````&&5```7````;I4```X```"&E0``/P```)65```W````
MU94``%<````-E@``$0```&66```-````=Y8``"T```"%E@``!````+.6```5
M````N)8``#L```#.E@``'P````J7```6````*I<``"4```!!EP``*````&>7
M```?````D)<``!T```"PEP``,````,Z7```&````_Y<``#D````&F```!P``
M`$"8```)````2)@``!,```!2F```!````&:8```0````:Y@```X```!\F```
M!P```(N8```3````DY@``!<```"GF```"````+^8```*````R)@```<```#3
MF```$0```-N8```&````[9@```X```#TF```#0````.9```+````$9D```(`
M```=F0``!@```""9```)````)YD```<````QF0``%0```#F9```'````3YD`
M``8```!7F0``"P```%Z9```'````:ID```@```!RF0``!0```'N9```0````
M@9D``!````"2F0``!0```*.9```0````J9D```D```"ZF0``"0```,29```*
M````SID```(```#9F0``'P```-R9```C````_)D``#$````@F@``)P```%*:
M``!D````>IH``"0```#?F@``(P````2;```K````*)L``"$```!4FP``50``
M`':;``!*````S)L``%L````7G```*````'.<```X````G)P``#,```#5G```
M&P````F=```Z````)9T``*D!``!@G0``(P````J?``!(````+I\``$$```!W
MGP``6P```+F?``!)````%:```"$```!?H```'P```(&@```S````H:```"4`
M``#5H```,@```/N@```P````+J$``&D```!?H0``/0```,FA``!E````!Z(`
M`$T```!MH@``+0```+NB```G````Z:(``"@````1HP``+@```#JC```P````
M::,``"<```":HP``6@```,*C```Z````':0``$@```!8I```2@```*&D```?
M````[*0``#(````,I0``+P```#^E```L````;Z4``"T```"<I0``%P```,JE
M```E````XJ4``#(````(I@``*0```#NF```^````9:8``%(```"DI@``(@``
M`/>F```E````&J<``"````!`IP``10```&&G```A````IZ<``#````#)IP``
M)0```/JG```<````(*@``#$````]J```"````&^H```*````>*@```T```"#
MJ```"0```)&H```&````FZ@```4```"BJ```60```*BH```%`````JD```@`
M```(J0```@```!&I```'````%*D``"X````<J0``+P```$NI```7````>ZD`
M`!L```"3J0``&````*^I```D````R*D``!\```#MJ0``&@````VJ```@````
M**H``!H```!)J@``,@```&2J```9````EZH``"\```"QJ@``%````.&J```E
M````]JH``"(````<JP``)0```#^K```O````9:L``"8```"5JP``"0```+RK
M```,````QJL``!<```#3JP``!P```.NK```'````\ZL```<```#[JP``%0``
M``.L```&````&:P```D````@K```"P```"JL```3````-JP``!,```!*K```
M#P```%ZL```R````;JP``!,```"AK```#@```+6L```,````Q*P``!$```#1
MK```"````..L```)````[*P```H```#VK```%`````&M```(````%JT```@`
M```?K0``/P```"BM```'````:*T```<```!PK0``!P```'BM```"````@*T`
M``D```"#K0``!````(VM```'````DJT```<```":K0``!@```**M```4````
MJ:T```<```"^K0``#0```,:M```+````U*T``"\```#@K0``(````!"N```<
M````,:X``$@```!.K@``3````)>N```Q````Y*X```4````6KP``/P```!RO
M```2````7*\```P```!OKP``"@```'RO```)````AZ\``!@```"1KP``&0``
M`*JO```?````Q*\``!T```#DKP``$0````*P```"````%+````0````7L```
M!@```!RP```4````([````,````XL```#````#RP``!%````2;```!H```"/
ML```-0```*JP```H````X+```%,````)L0``+P```%VQ``!"````C;$``#``
M``#0L0``+@````&R```9````,+(``"<```!*L@``(````'*R```U````D[(`
M`$4```#)L@``,`````^S```I````0+,``"$```!JLP``*````(RS```I````
MM;,``"8```#?LP``)0````:T```H````++0``"@```!5M```(@```'ZT```P
M````H;0``!(```#2M```$P```.6T```0````^;0``'D````*M0``"0```(2U
M``!S````CK4``'P````"M@``%P```'^V```5````E[8``!8```"MM@``#P``
M`,2V```?````U+8``!0```#TM@``$`````FW```/````&K<```\````JMP``
M#P```#JW```-````2K<```L```!8MP``!0```&2W```%````:K<```<```!P
MMP``!0```'BW```4````?K<```X```"3MP``!P```**W```(````JK<```\`
M``"SMP``#0```,.W```*````T;<```@```#<MP``#````.6W```&````\K<`
M``\```#YMP``!P````FX```&````$;@``!0````8N```!@```"VX```&````
M-+@```P````[N```%P```$BX```(````8+@```H```!IN```!@```'2X```$
M````>[@```@```"`N```$P```(FX```0````G;@``!,```"NN```!P```,*X
M```&````RK@``"(```#1N```!P```/2X```%````_+@```L````"N0``!P``
M``ZY``!H`0``%KD```H```!_N@``#P```(JZ```'````FKH```<```"BN@``
M"P```*JZ```)````MKH``!,```#`N@``"P```-2Z```%````X+H``!$```#F
MN@``#P```/BZ```+````"+L``!4````4NP``"0```"J[```A````-+L```P`
M``!6NP``!0```&.[```1````:;L```\```![NP``"P```(N[```+````E[L`
M`!$```"CNP``'0```+6[```<````T[L```H```#PNP``"````/N[```*````
M!+P```H````/O```"@```!J\```'````);P``"8````MO```'````%2\```I
M````<;P``#$```";O```2@```,V\``!$````&+T``%````!=O0``2@```*Z]
M```L````^;T```4````FO@``%@```"R^```$````0[X``"\```!(O@``*P``
M`'B^```6````I+X``!X```"[O@``"@```-J^```$````Y;X``!(```#JO@``
M%````/V^```,````$K\```L````?OP``%````"N_```6````0+\``!X```!7
MOP``%````':_```2````B[\```P```">OP``#````*N_```2````N+\```H`
M``#+OP``+````-:_```1`````\```!8````5P```#````"S````F````.<``
M``0```!@P```"@```&7````$````<,````,```!UP```"````'G````$````
M@L````T```"'P```#P```)7````-````I<````\```"SP```#````,/````.
M````T,````P```#?P```#@```.S````(````^\````X````$P0``"````!/!
M```$````',$```0````AP0``#````";!```,````,\$```@```!`P0``#@``
M`$G!```(````6,$``!````!AP0``$@```'+!```&````A<$```H```",P0``
M*@```)?!```.````PL$``!0```#1P0``%@```.;!```4````_<$``!0````2
MP@``$@```"?"```:````.L(```X```!5P@``"````&3"```0````;<(``!8`
M``!^P@``!````)7"```$````FL(``!@```"?P@``#````+C"```Q````Q<(`
M`"X```#WP@``!````";#``"G````*\,``"H```#3PP``+````/[#```L````
M*\0``"8```!8Q```!````'_$```&````A,0```0```"+Q```!````)#$```Q
M````E<0``#8```#'Q```+@```/[$``!J````+<4``"D```"8Q0``*0```,+%
M```I````[,4``#4````6Q@``)0```$S&```E````<L8``"D```"8Q@``+P``
M`,+&```2````\L8``!8````%QP``*````!S'```7````1<<``!8```!=QP``
M!````'3'```&````><<``"````"`QP``'@```*''```(````P,<```8```#)
MQP``#@```-#'```$````W\<```P```#DQP```@```/''```*````],<```(`
M``#_QP``"`````+(```$````"\@```,````0R````P```!3(```0````&,@`
M``@````IR```!@```#+(```&````.<@```H```!`R```!@```$O(```E````
M4L@``"````!XR```"@```)G(```<````I,@```H```#!R```$@```,S(```@
M````W\@``"(`````R0``)@```"/)```F````2LD``$@```!QR0``,@```+K)
M```$````[<D```8```#RR0``#````/G)```$````!LH```@````+R@``"```
M`!3*```*````'<H```@````HR@``"@```#'*```(````/,H```0```!%R@``
M#````$K*```.````5\H```0```!FR@``,````&O*```0````G,H```X```"M
MR@``#@```+S*```S````R\H``"8```#_R@``(````";+```0````1\L```H`
M``!8RP``$@```&/+```2````=LL```(```")RP``!@```(S+```&````D\L`
M``0```":RP``"@```)_+```*````JLL``!````"URP``"````,;+```.````
MS\L```@```#>RP``!@```.?+```$````[LL```H```#SRP``#0```/[+```0
M````#,P``"0````=S```!````$+,```*````1\P``"8```!2S```,P```'G,
M```A````K<P``"0```#/S```!@```/3,```&````^\P``#8````"S0``*P``
M`#G-```I````9<T``"X```"/S0``+````+[-```@````Z\T``"<````,S@``
M'@```#3.```F````4\X``"8```!ZS@``*0```*'.```@````R\X``"8```#L
MS@``,@```!//```J````1L\``"P```!QSP``+````)[/```J````R\\``!<`
M``#VSP``*@````[0```5````.=```"0```!/T```)@```'30```F````F]``
M`!P```#"T```'P```-_0```J````_]```!T````JT0``(````$C1```F````
M:=$``$````"0T0```@```-'1```$````U-$``!(```#9T0``"````.S1```2
M````]=$```8````(T@``$@````_2```4````(M(```H````WT@``+P```$+2
M```(````<M(```@```![T@```@```(32```$````A](```X```",T@``#0``
M`)O2```*````J=(```(```"TT@``!````+?2```&````O-(```H```##T@``
M!@```,[2```&````U=(```P```#<T@``$````.G2```,````^M(```T````'
MTP``!````!73```)````&M,```X````DTP``#@```#/3```.````0M,```@`
M``!1TP``"````%K3```6````8],```@```!ZTP``$````(/3```2````E-,`
M`!(```"GTP``"````+K3```&````P],```X```#*TP``!````-G3```D````
MWM,```0````#U```"@````C4```*````$]0```0````>U```"@```"/4```.
M````+M0```H````]U```+@```$C4```H````=]0``$4```"@U```#````.;4
M```1````\]0``#<````%U0``"````#W5```(````1M4```H```!/U0``"0``
M`%K5```,````9-4```X```!QU0``#@```(#5```0````C]4``!````"@U0``
M%0```+'5```8````Q]4```P```#@U0``#@```.W5```2````_-4``!4````/
MU@``"@```"76```.````,-8``"L````_U@``$@```&O6```4````?M8``"X`
M``"3U@``)````,+6```(````Y]8```8```#PU@``"````/?6```6`````-<`
M``8````7UP``)P```![7```<````1M<```8```!CUP``!0```&K7```&````
M<-<```4```!WUP``"@```'W7```&````B-<```4```"/UP``"@```)77```$
M````H-<```0```"EUP``"````*K7```$````L]<```P```"XUP``%````,77
M```&````VM<``!T```#AUP``)````/_7```C````)-@``"(```!(V```(0``
M`&O8```?````C=@``"````"MV```'0```,[8```$````[-@``!<```#QV```
M%P````G9```2````(=D```H````TV0``#````#_9```4````3-D``"X```!A
MV0``"````)#9```$````F=D```8```">V0``"````*79```*````KMD```(`
M``"YV0```@```+S9```$````O]D```H```#$V0``!````,_9```$````U-D`
M`!4```#9V0``$````._9```"`````-H```D````#V@``#`````W:```<````
M&MH```@````WV@``$````$#:```,````4=H``!L```!>V@``%````'K:```&
M````C]H```0```"6V@``!@```)O:```&````HMH```H```"IV@``#@```+3:
M```%````P]H```0```#)V@``!````,[:```:````T]H``"(```#NV@``&@``
M`!';```K````+-L``"L```!8VP``,P```(3;```R````N-L``!````#KVP``
M#````/S;```2````"=P```@````<W```10```"7<``!9````:]P```X```#%
MW```"````-3<```)````W=P```0```#GW```'P```.S<```7````#-T``!\`
M```DW0``'P```$3=```<````9-T``"P```"!W0``*````*[=```,````U]T`
M``H```#DW0``$@```._=```0`````MX```H````3W@``"````![>```,````
M)]X```X````TW@``&````$/>```6````7-X``!@```!SW@``%@```(S>```:
M````H]X``!@```"^W@``%@```-?>```0````[MX```X```#_W@``#@````[?
M```.````'=\``!`````LWP``#@```#W?```.````3-\```P```!;WP``$```
M`&C?```2````>=\``"@```",WP``$````+7?```<````QM\``!T```#CWP``
M'`````'@```<````'N```!@````[X```&0```%3@```&````;N````0```!U
MX```!````'K@```$````?^````0```"$X```!@```(G@```(````D.````@`
M``"9X```!@```*+@```&````J>```",```"PX```"````-3@```&````W>``
M``0```#DX```!@```.G@```H````\.````H````9X0``!````"3A```,````
M*>$```H````VX0``"P```$'A```2````3>$``!X```!@X0``%````'_A```,
M````E.$```H```"AX0``$````*SA```4````O>$```@```#2X0``)````-OA
M```&`````.(```H````'X@``!````!+B```(````%^(```H````@X@``#P``
M`"OB```^````.^(``!@```!ZX@``%@```)/B```4````JN(``!0```"_X@``
M`@```-3B```M````U^(```H````%XP``(````!#C```P````,>,```0```!B
MXP``'````&?C```$````A.,```0```")XP``!@```([C```.````E>,```@`
M``"DXP``!````*WC``!"````LN,```@```#UXP``"0```/[C```"````".0`
M`%8````+Y````@```&+D```*````9>0```8```!PY```!````'?D```"````
M?.0```8```!_Y```!````(;D```.````B^0```0```":Y```!````)_D```$
M````I.0```0```"IY```!````*[D```$````L^0```H```"XY```"@```,/D
M```,````SN0``!````#;Y```#````.SD```$````^>0```P```#^Y```!```
M``OE```(````$.4```H````9Y0``%````"3E```"````.>4```H````\Y0``
M"````$?E```(````4.4```H```!9Y0``)@```&3E```>````B^4```H```"J
MY0``,@```+7E```H````Z.4``"@````1Y@``+````#KF```2````9^8``!P`
M``!ZY@``"@```)?F```@````HN8``!T```##Y@``(````.'F```:`````N<`
M`!H````=YP``(P```#CG```C````7.<``"<```"`YP``)P```*CG```E````
MT.<``"@```#VYP``70```!_H```8````?>@``"H```"6Z```&P```,'H```&
M````W>@``#@```#DZ```/````!WI```$````6ND```H```!?Z0``"@```&KI
M```&````=>D```8```!\Z0```@```(/I```T````AND```(```"[Z0``#```
M`+[I```2````R^D```8```#>Z0``"````.7I```R````[ND``"D````AZ@``
M0@```$OJ```4````CNH``$D```"CZ@``!````.WJ```*````\NH```T```#]
MZ@``#`````OK```$````&.L```0````=ZP``!````"+K```@````)^L``!8`
M``!(ZP``!@```%_K```2````9NL``!H```!YZP``#````)3K```*````H>L`
M``H```"LZP``%P```+?K```)````S^L```D```#9ZP``!````./K```*````
MZ.L``!P```#SZP``(P```!#L```0````-.P```L```!%[```#````%'L```:
M````7NP```@```!Y[```"````(+L```(````B^P``!8```"4[```"@```*OL
M```2````MNP``"0```#)[```'````.[L```*````"^T```P````6[0``"@``
M`"/M```0````+NT```@````_[0``!````$CM```(````3>T``!H```!6[0``
M(0```''M```^````D^T``"(```#2[0``*````/7M```&````'NX``!(````E
M[@``,````#CN```S````:>X```H```"=[@``'````*CN```$````Q>X```8`
M``#*[@``!````-'N```.````UNX```8```#E[@``$@```.SN```E````_^X`
M``@````E[P``$P```"[O```"````0N\```0```!%[P``-````$KO``!#````
M?^\```8```##[P``#````,KO```,````U^\```P```#D[P``#````/'O```(
M````_N\``!D````'\```$````"'P```2````,O```!0```!%\```$````%KP
M```L````:_````0```"8\```"0```)WP```,````I_````X```"T\```"@``
M`,/P```,````SO```!````#;\```%@```.SP```$`````_$```H````(\0``
M"````!/Q```0````'/$```0````M\0``!````#+Q```0````-_$```X```!(
M\0``'@```%?Q```$````=O$```8```![\0``!@```(+Q```$````B?$```0`
M``".\0``#P```)/Q```-````H_$``!L```"Q\0``"@```,WQ```#````V/$`
M``(```#<\0``!````-_Q```)````Y/$```X```#N\0``#@```/WQ```0````
M#/(``!<````=\@``!````#7R```B````.O(``!X```!=\@``&````'SR```@
M````E?(``"P```"V\@``'````./R``!2`````/,``"0```!3\P``'@```'CS
M```:````E_,``!X```"R\P``%@```-'S```8````Z/,``!,````!]```)```
M`!7T```>````.O0``!0```!9]```%@```&[T```J````A?0``"P```"P]```
M%P```-WT```7````]?0``!8````-]0``"````"3U```X````+?4``!$```!F
M]0``+````'CU```$````I?4```0```"J]0``#````*_U```4````O/4```P`
M``#1]0``,@```-[U```@````$?8``%<````R]@``#````(KV```,````E_8`
M`#P```"D]@``!````.'V```:````YO8``#H````!]P``)````#SW```K````
M8?<``"X```"-]P``)@```+SW```>````X_<``"0````"^```(@```"?X```$
M````2O@``#(```!/^```#````(+X```(````C_@``!0```"8^```!@```*WX
M```2````M/@```X```#'^```!````-;X```*````V_@```X```#F^```!@``
M`/7X```(````_/@```8````%^0``"@````SY```$````%_D```@````<^0``
M"````"7Y```.````+OD```(````]^0``!````$#Y```&````1?D```0```!,
M^0``%0```%'Y```$````9_D```0```!L^0``!@```''Y```"````>/D```L`
M``![^0```@```(?Y```&````BOD```8```"1^0``!@```)CY```(````G_D`
M``0```"H^0``#````*WY```(````NOD```(```##^0``'@```,;Y```6````
MY?D``#(```#\^0``+@```"_Z``!,````7OH``"0```"K^@``'@```-#Z```L
M````[_H``!X````<^P``7````#O[```\````F/L``%P```#5^P``)````#+\
M```F````5_P``"8```!^_```(@```*7\```:````R/P``.0```#C_```&@``
M`,C]``!'````X_T``#@````K_@``1P```&3^``!*````K/X``!X```#W_@``
M'@```!;_```R````-?\``"H```!H_P``*@```)/_```F````OO\``%X```#E
M_P``2P```$0``0!?````D``!`$\```#P``$`+0```$`!`0`K````;@$!`"L`
M``":`0$`,@```,8!`0`V````^0$!`"L````P`@$`3@```%P"`0`X````JP(!
M`$8```#D`@$`1@```"L#`0`F````<@,!`#8```"9`P$`*P```-`#`0`I````
M_`,!`"@````F!`$`&@```$\$`0`J````:@0!`#(```"5!`$`*P```,@$`0!.
M````]`0!`$8```!#!0$`*@```(H%`0`D````M04!`!0```#:!0$`3````.\%
M`0`I````/`8!`#$```!F!@$`*@```)@&`0`B````PP8!`$(```#F!@$`!```
M`"D'`0`$````+@<!``P````S!P$`!````$`'`0`&````10<!``0```!,!P$`
M6P```%$'`0`$````K0<!``0```"R!P$``@```+<'`0`$````N@<!`#````"_
M!P$`,0```/`'`0`5````(@@!`!8````X"`$`(````$\(`0`H````<`@!`"(`
M``"9"`$`'@```+P(`0`C````VP@!`!@```#_"`$`-@```!@)`0`9````3PD!
M`#0```!I"0$`%0```)X)`0`<````M`D!`!X```#1"0$`(@```/`)`0`A````
M$PH!`"`````U"@$`!````%8*`0`.````6PH!``@```!J"@$`!@```',*`0`$
M````>@H!``0```!_"@$`'````(0*`0`$````H0H!``\```"F"@$`$````+8*
M`0`4````QPH!`!0```#<"@$`$@```/$*`0`[````!`L!``H```!`"P$`&```
M`$L+`0`0````9`L!``H```!U"P$`"````(`+`0`)````B0L!``H```"3"P$`
M%````)X+`0`$````LPL!``8```"X"P$`,P```+\+`0`"````\PL!``D```#V
M"P$`!``````,`0`"````!0P!``0````(#`$``@````T,`0`&````$`P!``0`
M```7#`$`!````!P,`0`.````(0P!``@````P#`$`#0```#D,`0`1````1PP!
M`#````!9#`$`%@```(H,`0`4````H0P!`!P```"V#`$`'````-,,`0`L````
M\`P!``(````=#0$`,0```"`-`0`&````4@T!``P```!9#0$`$````&8-`0`$
M````=PT!``\```!\#0$`#P```(P-`0`3````G`T!`!<```"P#0$`#P```,@-
M`0`"````V`T!``(```#;#0$`!````-X-`0`.````XPT!``0```#R#0$`"@``
M`/<-`0`]`````@X!`!P```!`#@$`)P```%T.`0`H````A0X!`%$```"N#@$`
M-``````/`0`\````-0\!`#(```!R#P$`,@```*4/`0`3````V`\!`!P```#L
M#P$`&@````D0`0!-````)!`!`#H```!R$`$`(P```*T0`0`D````T1`!`"``
M``#V$`$`(@```!<1`0`D````.A$!`"0```!?$0$`)````(01`0`D````J1$!
M`"8```#.$0$`'@```/41`0`_````%!(!`!(```!4$@$`%P```&<2`0`:````
M?Q(!`&@```":$@$`#`````,3`0!V````$!,!`&@```"'$P$`#@```/`3`0`0
M````_Q,!`!4````0%`$`#````"84`0`8````,Q0!``\```!,%`$`$````%P4
M`0`.````;10!``H```!\%`$`!@```(<4`0`*````CA0!``H```"9%`$`!@``
M`*04`0`&````JQ0!``H```"R%`$`"````+T4`0`3````QA0!``T```#:%`$`
M"@```.@4`0`,````\Q0!``P`````%0$`#`````T5`0`,````&A4!``P````G
M%0$`#````#05`0`&````014!``P```!(%0$`!@```%45`0`.````7!4!``@`
M``!K%0$`!@```'05`0`(````>Q4!``H```"$%0$`#@```(\5`0`&````GA4!
M``X```"E%0$``@```+05`0`(````MQ4!``0```#`%0$`%@```,45`0`(````
MW!4!``H```#E%0$`"@```/`5`0`(````^Q4!`"4````$%@$`!@```"H6`0`%
M````,18!``P````W%@$`!````$06`0`!````=0```)X`````````H0$`````
M``#:`P``7P```.T"`````````````"`"``!E`@``NP``````````````?P$`
M`)D```!)`P``C0$``"H```#K`0``P@$``````````````````(D`````````
MT`(````````@`P``50(```````#(`0```````-<````(`0``X@$``!8"``"$
M````X`,``#4#```N`0``J0```%``````````J0(``,L!``"Z`P``^`$``)@#
M````````'@(``/H#````````*0```#@#``#\`P``[@,````````-````GP,`
M``H```#2`0``.0,``'$"``"R`P``2`,``-@!```Q`@``]`$````````%`P``
MW@(```````#4`@``E@,``'8#````````MP$````````G`0``H`$``$("``!-
M````U@$``#("````````^0$``%T!``!Q`0``P````-X!````````1P$`````
M``#]``````````````!=`@``&P$``(\````=````!`````$$```^`0``````
M`%4!````````BP(```````#S`0```````,@"``"9`P``A@$``$D!````````
M``````````"1`P``?`,`````````````\`,``)\"``#A`0``;P(``+0```!8
M`0``U0$``.$"``#9`P``\@```,P#``#W`0``-0```(<#```;`````````*P#
M`````````````.D#``#<`@```````/8``````````````*("````````UP(`
M`"@#```7`P``@P,``-`#``#1`@```0(```````!*`P``K@,```````"2````
MC0(``*H`````````,@,``*\`````````&@(``$0"````````^`,``"\!```X
M`````````)8!``"H`@```````&@!``![`0``!P$```````!$````Z0$``&0`
M``!D`P``.@$```````":```````````````_````/`(````````Z````P`$`
M```````H`@```````+4````*`@``Q@,``+(!```.`P``W0(``.P!``!:`0``
ME0```+8#``#)`0```````$X"``!]````B`(```````"=`@``Q0````````!\
M`0``=P,``.T`````````+0(``+,#```S`@```````'0"``!"`P``@@$`````
M``!1`P``80$``,0"``#L`P``1@,````````,`P``P0$``%L#````````&P(`
M`&`!``#^`P``@`(``*H!``!Q`P``=``````````=`P```````#H#``#-`0``
M80```*0`````````A`$``)<!````````)0$``(`#```1`0```````+@"``!Z
M`P````````````")`@``4P,``"@```!4````DP(``&<!``#E`0```````,\!
M``#@`@``+@(``-(#``"B````?`````````"8`@``#P$``(,"``".`P``(P$`
M`)8`````````JP,````````F`P``-0$``!<"``##`@``0````,0#``"T`0``
M?`(``"X#``"-````*0$``+``````````\P(``/H!````````.0```,L"````
M````J````!D#``#Z`@```````%(!```]`0``#P,```8````<`@``Y0,`````
M``!K`````````!X#```6`P```````(0#``"W````[````!,"``!?`P``````
M`+D#``#V`0``#@(```````#+`P``WP```+0"``!T`P```````)0#````````
MAP$``!$#``#/`@``;`````````!,`0``(0(``%D#````````^`````````!_
M`P``W@````````!M````A@```(X!``"Q````20```.<"```8`0``7`$``#P`
M````````V`,``"T!````````:`,``%@#``#,`0````````````!``0``````
M`(P!````````#@```/D```#[`@``;`(```````"F`0``5@$``%D```#H`0``
M<P```)D!````````>`````,!````````:0,``&X"```L`P``X`$```````!M
M`0``*P```.(#``!+`0``#0(``&(`````````8P(``)@!``#\`@``````````
M````````]P```/T"``#&`````````*L```!A`@``?@```&D"```_`0``B@(`
M``````!<`@``4`(``$H!``!+`P```````(4!````````Z````.<`````````
MY0(``"`````Z`@``,0$``!P```!X`0``DP$``.\```!2`@``-@(```````"M
M````````````````````N``````````7````%`$``&`#``!F`@```````/`!
M```=`0```````)4"``"7````U@```+0#``#-`P``D`$``)0!``!S`P``;P$`
M`-H``````````````````````````````!8```!/````70,``/4#``"Q`@``
M;`$```````".````<`,``)$!````````Y@$`````````````-`$``$T#```A
M````YP$``#$```"Z`@``)0```&0!``#$`````````"0!``!R`@``90``````
M```$`@``_@$``)8"````````"0,``$<```#K````R@,``*$"```J`0``HP(`
M`,T"````````NP(``-<#``````````````D"``````````````,#``""`P``
MB`$`````````````IP$``,<"``"_`@```````+$#````````J0$````````]
M`P```````!T"``#E````G0$``&`"`````````````+(`````````.P,``#8`
M``#R`P``J`$``!\````E`@```````!`"```-`0```````$4"``#^`@``^@``
M`&4!``#8`````````$P```"1`@``-````(\#``#N`0``+@```',"`````@``
M`````+L!```Y`0``0P````````#F`P``&P,``$T!``````````````$#````
M````'P(```````"9`@``P0,``.$#````````>P,``*`"``!T`0``^P````("
M````````<@$```````![`@``.P$``-L!```T`P``Q0(``'T#```J`@``6@(`
M`#`#````````"P(``!<!``"_`P``5P(``!$```"*`0``A@(``&0"````````
M`````/L!````````2P````````";````&0```+4#``!3`0```````-X#``!F
M`P````````````!6`````````#@!```L`@``TP`````````B`@``````````
M````````I`,``*P"``!3`@```````-$#``#9`@``G`$``!@```#3`0``'`,`
M````````````]`,```<```"5`0``>@```"T#``"L````WP,``(`!````````
M60(``.8```!#`@``````````````````U@(``$8```!Q`````````)0"``"%
M`P``@0```#@"``!I````7@,``*`#``````````````````!K`P``SP```(,`
M````````G``````````4`P````````L```!>`0``<`$``%H```":`@``-P``
M````````````!`$``$`#``!G`@```````"8``````````````$X```"'````
MHP$``%`#``!P`@``$@(``%0#``!%`P``CP$``(@#``#&`@``/`,``.H!````
M`````````.,````_`P``L`$``#T"``!X`P``6@,```````!I`0```````.,!
M``#L`@`````````````S````"`,``(`````P`0``N0(````````#`@``9@``
M`(P`````````[0,```````")`0``G`,``(("``#<`P```````-T!``"=`P``
MNP,````#``!&`0``KP,``*4!````````I0````````#G`P``!@$``,P````<
M`0``)0,``%L!```D`@``6P```/4```"V````(0$```4!```W`P``QP,``%4`
M``"G`@``:@,``,X"```K`0``A@,``-4#````````O0````````!7````C`,`
M`&X!````````-P$`````````````MP,```````!(`0``_`$```````"B`P``
M3P(``%<!```0`P``GP$``)(!``!?`0``:@``````````````?P(``!H```!,
M`P``1`,`````````````80,``&X#````````V@(````````2````Q@$`````
M````````5P,````````,`0``PP,``"<```!"````X@`````````\`0``O`$`
M`%L"``````````````\"```C`````````.T!``!+`@``N0$``.L"``#R`0``
M3@,``,<```!U`P```````-0```!2````I@(```````"P`P```````&H!````
M````"`(``-\!````````E0,``'T!``#;````B@```#0"``!K`@``+P(``!4`
M````````^P,``!0"```R`0``M@$``+H```#8`@``+P,````````2`P``%```
M`*4#``#9`0```````,(```#3`@``40```.0```#6`P``8@(``"\```"\`P``
M:@(``)L"`````````````%8#``!R`P```````)`````:`P``SP,```````"Y
M````)@(````````U`@```````((```")`P```````,4#``!#`0```````(,!
M``!-`@```@0``)`"``#$`0``\`(``%X```!"`0``$````'T"``#R`@``DP,`
M``````"<`@``J@(``!4#``"%`@```````&8!``"?````@0(````````1`@``
MZ0````````#N`@```@```*T#``#4`0``XP(``',!````````]P(``/,````M
M````"P$```````"U`@``K@(``%@"``!5`P``O@$``"<#````````^`(``-<!
M```W`@``60$``+\!````````00,``,@```#H`@``Q0$``-P!``"P`@``````
M`*<````B`0``RP```+<"````````K@```)<"``"G`P``&0$```````#K`P``
MJP$``!4!````````2@```````````````````$`"``"'`@``*0(``*(!````
M`````````(@```!0`0``N`,``'@"``!%````\P,``#T````+`P``8````+,!
M`````````````)$```#)````>0```%0!``!'`P``PP$``&,```##````LP(`
M````````````.P```$<"```,`@``@0$``/8"``#1````FP,``"0#````````
M``````````"X`0``[P,``+,```!!`@````````````#<````T@(``.H#```P
M`@``40$``*H#```6`0``\0$```````!^`@```````#X"``"I`P``#```````
M``!L`P``TP,``%T```#Y`@`````````````S`0```````,D#```:`0``````
M`#8#``"0`P``?@,```````"!`P```````&\```#;`P``N@$``"@!``"A`P``
M`````"8!``!!`0``K`$```````"K`@``U0(```````"+````3P,```````#;
M`@``?P```&(#```5`@``P@(``*@#``"2`@``P@,``"H#````````>0(``-0#
M```````````````````_`@````````````"F`P``:`(``"P```!N````7`,`
M`/0"```Y`@``1`$``/$``````````````.@#``"N`0``,0,```(#``#.`0``
M`````'H!```&`@``OP```'X!````````L@(``"L"``!)`@```````/T!```B
M`P```````)@```"^````"0```*0"``#J`````````#,#````````>@(``-T#
M``#,`@``=@(``(\"```2`0``H0```*8```#Q`P``_P,``'<"``"U`0``````
M`/P```#F`@``Y`$``-````!1`@`````````$``"M`@``#@$`````````````
M`````'4"``"^`P``<@````````!K`0``*0,```````"@````QP$`````````
M````!0```/0```#B`@``P0(```````!2`P``;P,``+P"````````=0$``!,`
M```>````G0```!X!```*`P````````````![````WP(``/\```">`0``````
M`&(!``":`0``I0(````````%`@``)P(```````!&`@``(P,``.0#``!V`0``
M0P,``$@````!`0``8P,``#L"``#W`P``_0,``*,```#@````A`(``,D"```@
M`0``P0```$X!``#_`@``\0(``!@#```3`0````````````#O`0```````(X"
M`````````````.X```!?`@``)````+$!``";`0``Z0(``)(#```?`P``\```
M`!`!``"O`@``>0$``'D#```)`0``O@(`````````````]0(``.$`````````
MBP$``!\!``!G`P``6````$\!``#=`````````````````````````,X`````
M````S0``````````````C0,``#(``````````````#`````#````^0,`````
M``"4`````````&<```#.`P``(P(``&T#``!*`@``V@$``+T!```K`P``7```
M``H!``#0`0``M@(``,`#``#*`0``EP,```````#2````C`(`````````````
M7@(```````":`P````$``-D```!P````G@,``,@#````````[P(```(!````
M`````````%,````3`P``#P```,H````(````````````````````]0$`````
M````````BP,```````!M`@``10$``'<```#^````O````/8#```8`@``!`,`
M`*T!````````!P,``(H#``!H````R@(``-4``````````````*,#``#``@``
M`````*0!``!,`@``T0$```T#```^````2`(````````A`P````````<"``#_
M`0``8P$``(4`````````&0(``+T"````````O0,``%8"````````5`(``"P!
M``"O`0``=P$``'8```#J`@``!@,``.0"``">`@``XP,`````````````(@``
M`#8!``!E`P``00```),````^`P`````````@*"5S(&1A>7,@86=O*0`@*$%C
M8V5S<VME>2`E<RD`("AT;V1A>2D`("AY97-T97)D87DI`"5D(&5V96YT<P`E
M<R`M($YO=&EC90`E<R!$87DH<RD@)7,@2&]U<BAS*2`E<R!-:6YU=&5S`"5S
M($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE
M;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T=&5N9&5E<P`E<R!F:6QE('-U
M8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S
M`"5S(&YO="!F;W5N9"X`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A
M<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``J($%D9"!T:&5S92!B>2!C
M;&EC:VEN9R!!9&0@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`M
M+2!S96QE8W0@+2T`,2!A='1E;F1E90`Q(&5V96YT`#$R($AO=7(@1F]R;6%T
M`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I
M<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`
M06-C97!T960`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A
M<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!9%]V86YC960@4V5A<F-H`$%D9`!!
M9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($5V96YT
M`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!
M9&0@82!N97<@4F5M;W1E($-A;&5N9&%R`$%D9"!A(&YE=R!E=F5N=`!!9&0@
M82!N97<@=7-E<CH`061D(&%T=&5N9&5E<P!!9&0@8V]L=6UN`$%D9"!N97<@
M;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E
M<W,@8F]O:P!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D
M9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%D<P!!9'9A;F-E
M9"!396%R8V@`06QA<FT`06QA<FT@)60@9&%Y<R!B969O<F4`06QA<FT@)60@
M:&]U<G,@8F5F;W)E`$%L87)M("5D(&UI;G5T97,@8F5F;W)E`$%L87)M("5D
M('=E96MS(&)E9F]R90!!;&%R;2`Q(&1A>2!B969O<F4`06QA<FT@,2!H;W5R
M(&)E9F]R90!!;&%R;2`Q(&UI;G5T92!B969O<F4`06QA<FT@,2!W965K(&)E
M9F]R90!!;&%R;2!$871E`$%L87)M(%-P86X@*&UI;G5T97,I`$%L87)M(%1I
M;64`06QI87,`06QL`$%L;"!!='1E;F1E97,`06QL($%U=&AE;G1I8V%T960@
M57-E<G,`06QL($9U='5R90!!;&P@1W)O=7!S`$%L;"!087-T`$%L;"!097)M
M:7-S:6]N<P!!;&P@5FES:6)L90!!;&P@9&%Y`$%L;"!E=F5N=',`06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`
M06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`
M06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E
M<W,`06QT97)N871E('1E;7!L871E<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N`$%N;VYY;6]U<R!0<F]X>0!!;GD`07!P;&EC871I;VX`07!P
M;&EC871I;VX@:7,@<F5A9'DN`$%P<')O=F4`07!R:6P`07)C:&EV92!&:6QE
M(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/P!!=`!!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!W:71H(&UO<F4@
M:6YF;W)M871I;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y;W5R(&UA:6P@8VQI
M96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@=&AI<R!F
M:6QE('1O(&5A<VEL>2!U<&1A=&4@>6]U<B!L;V-A;"!C;W!Y(&]F('1H92!E
M=F5N="X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&%N
M8V4`071T96YD965S`$%T=')I8G5T97,`075G=7-T`$%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"X`079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O
M;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N
M86UE+@!"87-I8R!396%R8V@`0FER=&AD87D`0FQO8VL@5'EP90!";VQD`$)O
M;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!"=6QL
M971E9"!,:7-T`$)U<WD`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<P!#7V%L96YD87(`0V%L7V5N9&%R`$-A;&5N9&%R`$-A;&5N9&%R(%-U;6UA
M<GD`0V%L96YD87)S`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M`$-A;B=T(&-R96%T92!A(&YE=R!E=F5N="X`0V%N8V5L`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#86YC96QL960`0V%N8V5L;&5D.B`E<P!#86YN;W0@9&5L
M971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N`$-A<'1I;VX`0V%T96=O<E]Y`$-A=&5G;W)I97,@
M86YD($QA8F5L<P!#871E9V]R>0!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE
M<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z
M`$-E;&QP:&]N90!#96YT97(`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!0;VQI8VEE<P!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B!E;6%I;',N`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E('1H
M92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z
M`$-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N`$-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@
M=7-E<@!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7:6YD;W<`0V]L;W(`0V]L
M;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE
M<P!#;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A;'5E<P!#;VUM86YD`$-O;6UA
M;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUP86YY`$-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O
M<F0`0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_`$-O;F9I<FUE9`!#;VYN
M96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]P>0!#;W!Y('-E;&5C=&EO
M;@!#;W!Y('1H92!54DP@8F5L;W<@9F]R('5S92!W:&5R979E<B!Y;W4@;F5E
M9"!Y;W5R($9R964O0G5S>2!54DPZ`$-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG
M;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC
M92X@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U
M;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5V97)T(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1R>0!#<F5A=&4`0W)E
M871E(&$@3F5W($5V96YT`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F
M;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R
M9"!N=6UB97(`0W5R<F5N="!4:6UE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`1$0`1&%I;'D`
M1&%I;'DZ(%)E8W5R<R!E=F5R>0!$871A5')E92!"<F]W<V5R`$1A=&4@4F5C
M96EV960`1&%Y`$1A>2AS*0!$95]L971E`$1E7VQE=&4@0V]L=6UN`$1E8V5M
M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L="!#
M86QE;F1A<@!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5L971E
M`$1E;&5T92`E<P!$96QE=&4@179E;G0`1&5L971E($=R;W5P`$1E;&5T92!0
M97)M:7-S:6]N`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E
M;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$97-C<FE?<'1I
M;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO
M<&UE;G0`1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0`1&ES<&QA>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L
M87D@3W!T:6]N<P!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@
M=VAI8V@@87)E(&1U92!O;B!Y;W5R(&-A;&5N9&%R/P!$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1U93H@)7,`1'5R
M871I;VX`12U-86EL`$5D:70@)7,`161I="!!='1E;F1E97,`161I="!";&]C
M:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS
M`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@4F5M;W1E($-A;&5N9&%R
M<P!%9&ET(&%T=&5N9&5E<P!%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<P!%
M9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!$871E`$5N9"!/;@!%
M;F0@5&EM90!%;FQA<F=E($5D:71O<@!%<G)O<@!%<G)O<B!R971R:65V:6YG
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,Z("5S`$5R<F]R('=I=&@@
M96UA:6P@;65S<V%G92X`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>'!A;F0`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X
M<&]R=`!%>'!O<G0@0V%L96YD87(`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S
M971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D
M('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&96)R=6%R>0!&
M:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@
M36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN9`!&;VYT
M($-O;&]R`$9O<FUS`$9O<G5M<P!&<@!&<F%M97,`1G)I9&%Y`$9U;&P@1&5S
M8W)I<'1I;VX`1G5L;"!.86UE`$=E;F5R86P`1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;@!'96YE<F%T960@0V]D90!':79E;B!.86UE`$=O=&\@)7,`1W)O
M=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='D`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%S:"U!;&=O<FET:&T`2&5A9&5R
M`$AE:6=H=`!(96QP`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R
M9&4`2&]R:7IO;G1A;"!2=6QE`$AO=7(H<RD`2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`
M26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS
M('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE
M8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`26UA
M9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V5S`$EM<&]R
M="!#86QE;F1A<BP@4W1E<"`E9`!);7!O<G0L(%-T97`@)60`26UP;W)T+T5X
M<&]R="!#86QE;F1A<@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE
M;&1S.@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8W)E87-E($EN9&5N=`!);F1I
M=FED=6%L(%5S97)S`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R
M`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN
M<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!C96QL(&%F=&5R`$EN
M<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C
M;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A
M<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E
M9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!)
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G9A;&ED(&%P<&QI8V%T
M:6]N+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L
M:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!)<W-U
M97(`271A;&EC`$IA;G5A<GD`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#
M96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT
M`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y
M($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E
M`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M2V5Y=V]R9',`3&%N9W5A9V4`3&%S="`R-"!H;W5R<P!,87-T($UO9&EF:65D
M`$QA<W0@36]N=&@`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87-T('=E96L`3&%Y;W5T`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]?8V%T:6]N`$QO8V%L92!A;F0@5&EM
M90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$U-`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`
M36%I;`!-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RX`36%N86=E('1H92!L:7-T
M(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@
M86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`
M36%R8V@`36%T8VAI;F<@9FEE;&1S`$UA>0!-965T:6YG`$UE;6)E<G,`365N
M=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E('9E<FEF:65D+@!-971H;V0`36EM92!4>7!E`$UI;G5T92AS
M*0!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`
M36\`36]B:6QE($UA:6P`36]D:69I960@1&%T90!-;VYD87D`36]N=&@`36]N
M=&@@5FEE=P!-;VYT:&QY`$UO;G1H;'DZ(%)E8W5R<R!E=F5R>0!-;W9E($1O
M=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V
M92!U<`!->2!!8V-O=6YT`$UY($-A;&5N9&%R<P!->2!#86QE;F1A<G,Z`$UY
M($9R964O0G5S>2!54DP`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F5T=V]R
M:P!.979E<@!.97<@0V%T96=O<GD`3F5W($5V96YT`$YE=R!5<V5R;F%M92`H
M;W!T:6]N86PI`$YE>'0`3F5X="`R-"!H;W5R<P!.97AT(%=E96L`3F5X="!W
M965K`$YO(&%T=&5N9&5E<P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!C86QE;F1A<G,@87)E
M(&%V86EL86)L92!T;R!G=65S=',N`$YO(&-H86YG92X`3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@
M<W5P<&QI960N`$YO(&5N9"!D871E`$YO(&5V96YT<R!T;R!D:7-P;&%Y`$YO
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S`$YO
M(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB
M97(@<W!E8VEF:65D+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG
M('-I9VYU<',N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.
M;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]T
M($%F=&5R`$YO="!"969O<F4`3F]T97,`3F]V96UB97(`3F]W`$YU;6)E<G,@
M;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI
M<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1O8F5R`$]F9FEC90!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@
M=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@
M9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P=&EO;F%L`$]P=&EO;G,`3W!T
M:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES
M871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@
M=&5M<&QA=&4`3W1H97(@26YF;W)M871I;VX`3W=N97(`3W=N97(@4&5R;6ES
M<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'
M4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U
M8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!0
M2%`@4VAE;&P`4&%D9&EN9P!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D
M.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI
M<&)O87)D`%!A='1E<FX`4&5N9&EN9R!3:6=N=7!S.@!097)C96YT`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUA;F5N=&QY(&1E;&5T92!T:&ES
M(&5V96YT/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I
M;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R
M;6%T:6]N`%!H;VYE`%!I>&5L<P!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@<')O=FED92!A('-U
M;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D`%!O;&QS`%!O<G1A;"!/<'1I;VYS`%!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2871I;P!296%D
M`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-U<B!5;G1I;`!2
M96-U<G,@9&%I;'D`4F5C=7)S(&UO;G1H;'D`4F5C=7)S('=E96ML>0!296-U
M<G,@>65A<FQY`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN
M86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296UO
M=&4@0V%L96YD87)S`%)E;6]T92!#86QE;F1A<G,Z`%)E;6]T92!397)V97)S
M`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!2
M96UO=F4`4F5M;W9E("5S`%)E;6]V92!!='1E;F1E90!296UO=F4@0FQO8VL`
M4F5M;W9E('!A:7(`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M`%)E<75I<F5D`%)E<75I<F5D($%T=&5N9&5E<P!297-E=`!297-E="!T;R!$
M969A=6QT<P!297-P;VYS90!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E
M=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2
M;VQE`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;@!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4U%,(%-H96QL`%-32`!380!3871U<F1A>0!3879E("5S`%-A=F4@07,@
M3F5W`%-A=F4@179E;G0`4V%V92!/<'1I;VYS`%-A=F5D("5S(&-O;F9I9W5R
M871I;VXN`%-E87)C:`!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@
M;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D
M9`!396QE8W0@8V]N9FER;6%T:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y
M('1H92!D:69F97)E;G0@=FEE=W,@86YD(&-H;V]S92!D969A=6QT('9I97<N
M`%-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.@!396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D
M871E(&9O<FUA=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@
M=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE(&9I<G-T('=E96MD87DZ
M`%-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C
M="!T:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C="!T:&4@=FEE=R!T;R!D
M:7-P;&%Y(&]N('-T87)T=7`Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@:6X@=&AE('!O<G1A;"X`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N
M9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL(&%T=&5N9&5E<R!W:&5N
M(&1E;&5T:6YG('1H:7,@979E;G0`4V5N9"!A;B!E;6%I;"!T;R`E<P!396YD
M('5P9&%T97,O:6YV:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A
M=FEN9R!T:&ES(&5V96YT`%-E<'1E;6)E<@!397)I86P@3G5M8F5R`%-E="!E
M;F0@9&%T90!3970@<F5C=7)R96YC92!E;F0@9&%T90!3970@<W1A<G0@9&%T
M90!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4VAA<F5D($-A;&5N9&%R
M<SH`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&-A=&5G;W)Y(&QE9V5N9#\`
M4VAO=R!D96QE=&4L(&%L87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I;B!C
M86QE;F1A<B!V:65W<S\`4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R
M/P!3:&]W(&9R964O8G5S>2!L96=E;F0_`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O;FQY(&5V96YT<R!T:&%T(&AA=F4@
M86X@86QA<FT@<V5T/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&EM92!O9B!D
M87D@8F5T=V5E;B!E86-H(&1A>2!I;B!W965K('9I97=S/P!3:')I;FL`4VAR
M:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@
M=V%Y(&9I<G-T`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET
M:&T`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-O=7)C92!A9&1R97-S`%-P86-I
M;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3=&%R="!/;@!3=&%R="!4:6UE`%-T871?=7,`4W1A=&4@;W(@4')O=FEN
M8V4`4W1A='5S`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1Y;&4@
M6T-34UT`4W4`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL
M>2!W<F]T92`E<P!3=6UM87)Y`%-U;F1A>0!3=7!E<G-C<FEP=`!3=7)N86UE
M`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R
M=&EE<P!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;G1A=&EV90!497AT($]N
M;'D`5&5X="!A;&EG;@!4:`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T
M96TN`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S
M:6]N<RX`5&AE(&-A;&5N9&%R("(E<R(@8V%N;F]T(&)E(&1E;&5T960N`%1H
M92!C86QE;F1A<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!C86QE;F1A
M<B`B)7,B(&AA<R!B965N(')E;F%M960@=&\@(B5S(BX`5&AE(&-A;&5N9&%R
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!C;VYT86-T($E$(&YU;6)E<B!W
M87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD
M(&EN('1H92!D871A8F%S92X`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S
M('-U8V-E<W-F=6QL>2!S96YT+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82X`5&AE(&9O;&QO=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I
M;VX@;V8@=&AE(&5V96YT.@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H
M879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E
M;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N
M8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H97)E
M(&%R92!N;R!E=F5N=',@;6%T8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N
M`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T
M(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET
M97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W
M87,@86X@97)R;W(@86-C97-S:6YG('1H92!C86QE;F1A<CH@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!E9&ET:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@
M97)R;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A
M:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N
M`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T
M:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI
M<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@
M=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES
M(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P
M=&EO;G,@=VEN9&]W`%1H=7)S9&%Y`%1I;64@4W!?86X`5&EM92!4<F%C:VEN
M9P!4:6UE('-P86X`5&ET7VQE`%1I=&QE`%1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O;6]R<F]W`%1U`%1U
M97-D87D`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@
M8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S
M(CH@)7,`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='D`56YA8FQE('1O(&1E;&5T92`E<RX`56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E=')I979E(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B!F;W(@)7,`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;@!5;F9I;&5D`%5N:VYO=VX`56YN86UE9`!5;G-U<'!O<G1E9"!%>'1E
M;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<'!E<B!L871I
M;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57-E($-U<G)E;G0Z("5S
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`57-E
M<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N86UE`%5S97)N86UE
M.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%9A8V%T:6]N`%9A
M;&ED:71Y`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9I97<@)7,`5V%R
M;FEN9P!790!7961N97-D87D`5V5E:P!7965K("5D`%=E96LH<RD`5V5E:VQY
M`%=E96ML>3H@4F5C=7)S(&5V97)Y`%=E;&-O;64`5V5L8V]M92!T;R`E<P!7
M96QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H870@=&EM92!S:&]U
M;&0@9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@
M;&%T97(@979E;G1S/P!7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V
M:65W<R!S=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T
M86)L90!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7;W)K(%=E96L`6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EE
M87)L>0!996%R;'DZ(%)E8W5R<R!E=F5R>0!997,`665S+"!)($%G<F5E`%EO
M=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S
M=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A
M=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@
M)7,N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@
M=&\@)7,N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N
M=',@=&\@=&AE('-E;&5C=&5D(&-A;&5N9&%R+@!9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!D96QE=&4@=&AI<R!E=F5N="X`66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@961I="!T:&ES(&5V96YT+@!9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N`%EO=2!H879E('-P96-I9FEE9"!A;B!I;G9A;&ED
M(&-A;&5N9&%R+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T
M('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E
M;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9
M;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@
M061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!C86QE;F1A<@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L
M;"!N86UE.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@
M<F5M;W1E('-E<G9E<G,Z`%M0<F]B;&5M(%)E<&]R=%T`6U5N;F%M960@979E
M;G1=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T)A<VEC(%-E
M87)C:`!?1&5L971E(%)O=P!?161I=`!?1V]T;P!?1W)O=7!S`%](96QP`%])
M;6%G92!0<F]P97)T:65S+BXN`%]);7!O<G0O17AP;W)T`%],;V<@:6X`7TQO
M9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]->2!#86QE;F1A<G,`7TYE=R!%=F5N
M=`!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U!R:6YT`%]296UO=F4@3&EN:RXN
M+@!?4V5A<F-H`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?5&]D87D`
M7U5S97)S`&%D9')E<W,@8F]O:P!B969O<F4@=&AE(&5V96YT('-T87)T<P!C
M86QE;F1A<@!C;&EC:R!H97)E`&1A>2AS*0!F:6QE`&UO;G1H*',I`&YO="!Y
M970@:6UP;&5M96YT960`;VX@=&AE('-A;64@9&%T90!O;B!T:&4@<V%M92!W
M965K9&%Y`'!E<F-E;G0`<&EX96QS`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FT`=6YN86UE9`!V0V%R9`!W965K*',I(&]N.@!Y96%R*',I
M`%!R;VIE8W0M260M5F5R<VEO;CH@:W)O;F]L:71H(#(N,"XQ"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-2TP,2TQ,B`P.#HP,"LP.3`P"DQA<W0M5')A;G-L871O<CH@2&ER
M;VUI($MI;75R82`\:&ER;VUI0'1A8RYT<W5K=6)A+F%C+FIP/@I,86YG=6%G
M92U496%M.B!*87!A;F5S92`\=6YK;F]W;D!U;FMN;W=N+F1O;6%I;CX*34E-
M12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/5-(24947TI)4PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M"@`@*"5S()/ZD4\I`(-!@TZ#6H-8@TR#0R`E<P`@*(VAD_HI`"`HC?"3^BD`
M)60@@T.#>(.3@V<`DLJ2;2`M("5S`"5S()/Z("5S((Z>BM0@)7,@E:H`)7,@
MDV2.<8YWEN0`)7,@2T(`)7,@E=N.YY&`C>R"S(IME$8`)7,@@U2#0X.3@T&#
M8H-V`"5S().OB-./\(V``"5S((+-BOF"R9&VC=V"M8+<@K>!0@`E<R".48G!
MCM(`)7,@@W2#0(-#@XN"S8-#@Y.#?(%;@V>"LX+J@MR"M8*]`"5S@JJ52Y=V
M@L6"MP`E<R"5J@`E<R""JH*@@NB"W(*Y@O&!0@`E<R""S(-!@VB#C(-8DJ``
M)7,@@LR77)+HE5P`)7,@@LR#@8."DJ``)7,@@LR#7H-8@TZ#BH-8@V<`*H%U
MDL>)P8%V@O"#3H.*@V*#3H*U@L22QXG!("H`*B"#08-H@XR#6(+PD4F1\(*U
M@L2)NH*S@J(@*@`M+2"129'P("TM`()0CE&)P8[2`()0@T.#>(.3@V<`,3*.
MGHK4C&".K@`R-(Z>BM2,8(ZN`#(T((Z>BM0`@K&"S(-U@XV#8H-.@LV#9H%;
M@UZ#>(%;@UB"JI5+EW:"Q8*W@4(`DG:6O9-)@LB#1X.)@5N"JI2MD+:"M8+<
M@K6"O0!01U",]HI*C*Z"JH.!@V*#6H%;@U>"S(C#C8:)NX+)E4N7=H+%@K>!
M0@!01U",]HI*C*Z"JH^0EKR"LX+J@KV#@8-B@UJ!6X-7@LR,GX_8@LF52Y=V
M@L6"MX%"`%!'4(SVBDJ,KH%!4$=0E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9
M@JJ(PXV&B;N#@8-B@UJ!6X-7@LR5G(V&@LF52Y=V@L6"MX%"`%!'4(SVBDJ,
MKH%!4$=0E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/
MD):\@LF52Y=V@L6"MX%"`%,O34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN@JB"
MYH+1@W"#6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7@LR5G(V&@LF52Y=V
M@L6"MX%"`%,O34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN@JB"YH+1@W"#6(-T
M@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/D):\@LF52Y=V@L6"MX%"`%,O34E-18SV
MBDJ,KH*J@X&#8H-:@5N#5X+,B,.-AHF[@LF52Y=V@L6"MX%"`$%-+U!-`(*Q
M@LR#1X-F@T*#7H%;@LF"PH*B@L0`CO.7G0!61E.#9H-"@XR#3H-G@XJ"S(WL
MD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0@!61E.#=(-`@T.#BX+,C>R0
MK(+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"`(-!@TJ#18.3@V>"S(-P@UB#
MCX%;@V@`@T&#2H-%@Y.#9X+-DX",BX*S@NJ"Q(*B@MR"MX%"`%]6C]J-UXR?
MC?4`DL>)P0"#5(-U@T^#BX%;@W:"\)+'B<$`@U2#=8-!@TZ#6H-8C*""\)+'
MB<$`@T.#>(.3@V>2QXG!`(*Q@K&"R9+'B<$Z`)!6@K6"HH-/@XN!6X-V@O"2
MQXG!`)!6@K6"HH+P@T&#3H-:@UB,H)+'B<$`D%:"M8*B@XJ#@H%;@V>#2H.,
M@Y.#7X%;@O"2QXG!`)!6@K6"HH-#@WB#DX-G@O"2QXG!`)!6BTN#AH%;@U6"
M\)+'B<&!1@".48G!CM*"\)+'B<$`@U*#B8.`@O"2QXG!`)!6BTN#@8.3@V^"
M\)+'B<&!1@"#>8-!@O"2QXG!`"5S((.!@VJ#A8%;@O`@36]Z:6QL82""S(-4
M@T.#:(-O@5N"R9+'B<&"MX+I`(-!@VB#C(-8DJ""R9+'B<$Z`(Z$@LR"S(-!
M@VB#C(-8DJ""R9+'B<$`@X:!6X-5@O"2QXG!`(.&@5N#58+,DL>)P8^(EYV"
MS9:SC/B"R8+(@L&"Q(*B@MR"MX%"`(]:CXH`@T&#:(.,@UB2H`"*QY>=`$%D
M<P"/VHW7C)^-]0",>)7Q`"5D()/ZD4^"R8QXE?$`)60@CIZ*U)%/@LF,>)7Q
M`"5D()6JD4^"R8QXE?$`)60@CU2*U)%/@LF,>)7Q`()0D_J13X+)C'B5\0""
M4(Z>BM213X+)C'B5\0""4)6JD4^"R8QXE?$`@E"/5(K4D4^"R8QXE?$`C'B5
M\9/ZE70`C'B5\8K4BG6!:96J@6H`C'B5\8Z>BM0`E<J6O`"14X+$`)%3@L2"
MS(Y1B<&.T@"14Y1&C]B#AH%;@U4`C:&,XY%3@L0`D5."Q(+,@T^#BX%;@W8`
MB=^+CI%3@L0`D5."Q(+,@T&#3H-:@UB,H`")>Y>7B<*47(+(@N""S)%3@L0`
MBMN"4)/Z`)%3@T.#>(.3@V<`E-2-AI5T@JN#BH-8@V>"\)#=DNB"Q8*K@NF"
MYH*D@LF"M8+<@K>"J8%(`(KY@LF1MHW=@K6"W(*W`)'CD=:"S"!)35-0((.-
M@T^#0X.3`)'CD=:"S"!)35-0((-P@UB#CX%;@V@`D>.1UH+,($E-4U`@@X:!
M6X-5EKP`D>.1UH+,@X&!6X.+@T&#:(.,@U@`D>.1UH+,@V6#DX-V@XR!6X-G
M`)5SD+."R))L@JJ.=Y+H@K."ZH+$@J*"W(*W`).]EKR#=H.-@TR#5H%;`(+'
M@NJ"Q8+@`(-!@W:#BH-0@5N#5H.'@Y,`@T&#=H.*@U"!6X-6@X>#DXYGEW")
MP@"/LY1&`()3C(X`@T&!6X-*@T.#=8-T@T"#0X.+@U2#0X-9`(-!@5N#2H-#
M@W66O``E<R""S(-4@T.#DX-!@V*#=I=VBX&"\)9[DY:"R8WMCYR"M8+$@J*"
MHH+%@K>"J8%(`)7;CN>-[(O&@LR.P(USD4^"R8IME$:"\(N!@M^"Z8+F@J2"
MR8*U@MR"MX*I@4@`CIZ*U`""L8+,@X&!6X.+@LF3695T@K."ZH+$@J*"Z8+,
M@LV!08-#@WB#DX-G@LR/VHW7@LF"PH*B@L2"S"!I0V%L96YD87(@@W2#0(-#
M@XN"Q8*W@4*"X(*U@4&#@8%;@XF"JB!I5&EP((+P@U2#?(%;@V>"M8+$@J*"
MZH+.@4&3695T@W2#0(-#@XN"J8+GBLB24(+)EUR2Z)5<@O"-6)!6@L6"JX+<
M@K>!0@"1MHW=@K6"R(*B@T^#BX%;@W:"\(WMCYR"M8+F@J2"QH*U@MR"M8*]
M@4(`D;:-W8*U@LB"HH-!@TZ#6H-8C*""\(WMCYR"M8+F@J2"QH*U@MR"M8*]
M@4(`D;:-W8*U@LB"HH-!@TZ#6H-8C*""\)72CU>"M8+F@J2"QH*U@MR"M8*]
M@4(`D;:-W8*U@LB"HHNDETR"\)72CU>"M8+F@J2"QH*U@MR"M8*]@4(`CE&)
MP0".48G!CM(`D:Z0JP""5XR.`$%U=&A?8WER<W%L.B"52Y=V@LA)34%0BF>2
MHXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]C>7)U<SH@@V^#8H-.@T>#
MDX-H@LV52Y=V@LB47)?-@O"73(*U@L2"HH+<@KF"\8%"`$%U=&A?8WER=7,Z
M()=VBX&"MX+I:6UA<(IGDJ."JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]F='`Z
M($944(IGDJ.+0)1<@JJ"W8+"@JF"Z(+<@KF"\2X@4$A0@O`@+2UE;F%B;&4M
M9G1P((-)@W:#5H.'@Y."\(+"@J^"Q(-2@Y.#<(-#@XN"M8+(@JB"M8+$@JV"
MOH*S@J*!0@!!=71H7VEM87`Z($E-05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y
M@O&!0@!!=71H7VMR8C4Z(&MR8C6*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!
M0@!!=71H7VQD87`Z($Q$05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!!
M=71H7VQD87`Z((.&@5N#52`E<R""\)+'B<&"Q8*K@MR"N8+Q@4*#5(%;@V^"
MS(F>DYHZ(`!!=71H7VQD87`Z((.&@5N#52`E<R""\(WMCYR"Q8*K@MR"N8+Q
M`$%U=&A?;&1A<#H@@X:!6X-5("5S((+PC5B05H+%@JN"W(*Y@O$`075T:%]M
M8V%L.B!-0T%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]S;6)A
M=71H.B!S;6)A=71HBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`E$:/V(+)
MCKB4<X*U@MR"M8*]`)1&C]B"R8ZXE'."M8+<@K6"O8%")7,`4D%$2553@U2!
M6X-O@LF"YH+HE$:/V(*JBY&4VX*S@NJ"W(*U@KV!0@!&5%"#5(%;@V^"S)1&
MC]B"R8ZXE'.!0@".9Y=PB<*47(+(@W2#0H%;@XN#:(%&`)1WC&D`E'>,:9!&
M`$ME<F]B97)O<R"#<(-8@X^!6X-H@JJ6LXSX@L6"MX%"`$ME<F]B97)O<R"#
MAH%;@U66O(*JEK.,^(+%@K>!0@"*R(C5C)^-]0"289"VD_H`@W6#C8-B@TZ#
M7H-#@W8`D;Z.F@"#=8-B@TZ#?8%;@TX`B8\`B8^"S)&^@K.!1@")CP")TX_P
MCY&"JP"1O99:`$--4P!#4D,`0U),()1ZE7J#?(-#@Y.#9P!?09=<DNB57`"7
M7)+HE5P`EUR2Z)5<`)=<DNB57(I4EW8`EUR2Z)5<`$E-05`@@U2!6X-O@LF0
MVI&Q@L6"JX+<@KF"\8+%@K6"O3H@)7,`D%:"M8*B@T.#>(.3@V>"\(WLD*R"
MQ8*K@MR"N8+Q@4(`@TR#@X.3@UJ#BP"/X8I1@XR#?(%;@V>"\(-,@X.#DX-:
M@XN"MX+I`(-,@X.#DX-:@XL`@TR#@X.3@UJ#BXW/@MV!1B5S`(-T@T"#0X.+
M("(E<R(@@O"-[8^<@L6"JX+<@KF"\8%"`(WLB\:#9H-"@XR#3H-G@XJ"JHRI
ME72"J8+H@MR"N8+Q@4(`@V:#0H.,@TZ#9X.*@5L@(B5S(B""\(WMCYR"Q8*K
M@MR"N8+Q@4(`C>V/G(+%@JN"W(*Y@O&!0HYQD;>"JB`E9""1MHW=@K6"W(*W
M@4(`E<""UY'6@J:"S)'.C]N"S)"4@JJ5VY&V@K."ZH+$@J*"Z9"4@L:-AX+M
M@LB"HH+,@L65P(+7D=:"IH*J@L6"JX+<@KF"\8%"`(YWDNB"LX+J@KV4U(V&
M@LF#@8-B@UJ!6X-7@O"4>I&7@L6"JX+<@KF"\8+%@K6"O8%"`)5<D>@`7UF5
MJI?>`)6JE]Z"QH.)@WB#BP"5JI?>`(QGD=&39)AB`(-:@XN1KI"K`(-:@XN6
MA)&0@48`@UJ#BY&ND*L`@UJ#BY==E)*!1@",9Y'1DV288@"2AHF;`(_8EKZ/
MD8+,C]J-UP"/V):^CY&#?(.*@U:!6P"5SXU8`)-DCG&#@8-#@XN"R8YGEW""
MMX+IEKR13X+&@T&#:(.,@UB"\)7/C5B"M8+<@K>!0@"#<(-8@X^!6X-H@O"1
M29'P`(.&@5N#59:\@O"129'P`)/ZE7257(ZFC&".KH%&`)=<DNB/[I7Q@6E&
M<F5E+T)U<WD@55),@6J,GXWUEW""S(-!@VB#C(-8DJ""\)%)D?"!1@"#9H-T
M@TB#BX-G@LR77)+HE5R"\)%)D?""M8+$@JV"OH*S@J*!0@"#3H.)@UB2Z(M@
M("5S((*JC*F5=(*I@NB"W(*Y@O&!0@"#AH%;@U6"S)'>BXZ!1B5S`(.&@5N#
M58_!BXX`@TZ#BH-B@TZ"MX+I@L:.GX+6`(-%@T*#DX-H@T6"\)7"@K:"Z0"0
M1@"01I%)D?``D$:129'P`)?Q@48`E_&#7H-#@V>#BP"#4H-^@V*#3H-8`(-2
M@Y.#?8OFD-B"Z(+,DFP`@U*#?8.3@V@`@U*#?8.3@VB#5H-&@XL`@U*#@8.3
M@V<`BZ22RI:\`(GOCM``D-V2Z(+,C;>5J@`E<R""\)#=DNB"MX+I`(-P@UB#
MCX%;@VB"\(IME$8`@T.#>(.3@V>"\(WMCYR"MX+IC=N"R8IME$:"M8+<@K>"
MJ8%(`(IMDN@`D-J1L8ZXE'.!0@",]H]/C*Z#5(%;@V^"UH+,D-J1L8*JBY&4
MVX*S@NJ"W(*U@KV!0@",]HI*C*Z#5(%;@V^"UH+,D-J1L8*JBY&4VX*S@NJ"
MW(*U@KV!0I>=EU*!1B5S("@E<RD`1E10@U2!6X-O@M:"S)#:D;&"R8ZXE'."
MM8+<@K6"O8%"`)A!EXV0YH+-@T&#:(.,@UB2H(+)DL>)P8*S@NJ"W(*U@KV!
M0@"#4H-S@5L`@U*#<X%;`(*@@LB"O8+,EUR2Z(_NE?$@55),@6F52Y=V@LB"
MQH*Q@NN"R8-2@W.!6X*U@L2.9Y=P@6J!1@"#@8-B@UJ!6X-7@LP@4$=0((C#
MC8:)NX*J@L6"JX+<@KF"\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!01U`@CY"6
MO(*J@L6"JX+<@KF"\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!3+TU)344@B,.-
MAHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(`@X&#8H-:@5N#5X+,(%,O34E-12"/
MD):\@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(`F$&7C9#F@O"2QXG!@L6"JX+<@KF"
M\8+%@K6"O8%")7,`3$1!4""#5(%;@V^"R8-O@T.#DX-H@L6"JX+<@KF"\8+%
M@K6"O8%"`(YCC8*"JHIME$:"Q8*K@MR"N8+Q@L6"M8*]@4(E<P"1EY!-D.:#
MBH-8@V>"JHWLD*R"Q8*K@MR"N8+Q@L6"M8*]@4(E<P!01U`@@V:!6X->@LR5
MG(V&B;N"JH+%@JN"W(*Y@O&"Q8*U@KV!0@!3+TU)344@@V:!6X->@LR5G(V&
MB;N"JH+%@JN"W(*Y@O&"Q8*U@KV!0@"809>-D.:"JHWMCYR"Q8*K@MR"N8+Q
M@L6"M8*]@4(E<P"1EY!-D.:#BH-8@V>"JHWMCYR"Q8*K@MR"N8+Q@L6"M8*]
M@4(E<P".\Y!-CM*"S)-DCG&#@8%;@XN#08-H@XR#6(*JBFV2Z(+%@JN"W(*Y
M@O&"Q8*U@KV!0@"#08-H@XR#6)*@@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q
M@L6"M8*]@4(`D9>039#F@XJ#6(-G@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q
M@L6"M8*]@4(`D9>039#F@XJ#6(-G@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q
M@L6"M8*]@4(`C/:*2HRN@O",KH-4@5N#;X*I@N>.YI.^@L6"JX+<@KF"\8+%
M@K6"O8%"`"5S((+PBDJ"KX+<@KF"\8+%@K6"O8%"`)7;CN>-[(O&@X*#5X.%
M@5N#BR`E<R""\(I*@J^"W(*Y@O&"Q8*U@KV!0@`E<R""JI/'@MV/;X*Y@MR"
MN8+Q@4(`@T&#:(.,@UB2H(+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7
MD$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7D$V0YH.*
M@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)#=DNB"\(RS@LF6WX*Y
M@MR"N8+Q@L6"M8*]@4(`)7,@D-V2Z(+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!
M0@"0W9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(`
M3$1!4""#5(%;@V^"JHR?C?6"Q8*K@MR"N8+Q@4(`F$&7C9#F@O"-6)!6@L6"
MJX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#6(-G@O"-6)!6@L6"JX+<@KF"
M\8+%@K6"O8%")7,`36]Z:6QL82""S(-4@T.#:(-O@5N"JHRIE72"J8+H@MR"
MN8+Q@4*#5(-#@VB#;X%;@O"*2H*B@L2)NH*S@J*!0@"-D0"-[)"L`)!6BTN#
M0X-X@Y.#9X+PC>R0K`"05HM+C>R0K`"#5(-U@W2#2(.+@U^"\(WLD*P`C>R0
MK)/Z`(WLD*R.TH+,@T&#3H-:@UB,H`"#3H.,@U>#8H-G@TJ!6X-HE-2-A@",
MNXW=@LR.GHK4`"5S((+6@LR#C8-/@TF#DXZ>@LF.P(US@K>"Z8->@UB#3H+P
MD-V2Z(*U@MR"MX%"`)#8@NB.YH+H`)#8@NB.YH+H`)/Z`):(D_H`EHB3^H%&
MC$J"Z)74@K4`1&%T851R964@B7N7EP"#9H%;@UZ.\Y!-`)/Z`)/ZBM0`7TR-
M[8^<`%],E_&"S(WMCYP`@E""48R.`(]<D&F0E`"2:8FZ@K""\)#S@JT`@V:#
M=(-(@XN#9Y=<DNB57`"#9H-T@TB#BX-GD$8`@V:#=(-(@XN#9R!)1`"-[8^<
M`"5S((+PC>V/G`"#0X-X@Y.#9X+PC>V/G`"#3X.+@5N#=H+PC>V/G`"#08-.
M@UJ#6(R@C>V/G`"#6H.+C>V/G`"7\8+,C>V/G`"1XY'6@V6#DX-V@XR!6X-G
M@LR-[8^<`(US@LR-[8^<`)%)D?""M8*]242"\(WMCYP`C+N-W8C*DG6"S)?Q
M@O"-[8^<`(R[C=V(RI)U@LR-<X+PC>V/G`"4>I&7CIZ*U`!?4)#@EKX`C^&*
M49/@EV6"S)#@EKX`D."6O@"/VHW7@JJ*QY>=CM*"S(*]@M^"R8M,F%Z"LX+J
M@MR"M8*]@4(`BDJ4K0"-MH*I@N>)18+6`(E%@JF"YXVV@M8`E5R.I@`R-(Z>
MBM257(ZF`)5<CJ:#28-V@U:#AX.3`(WMCYR"M8+(@J(`;6%I;G1E;F%N8V4N
M<&AP((+)DKR0VH-!@TZ#6H-8@K6"R(*B@L6"K8*^@K."H@"*^I/Z@LR"H(+I
M@UZ#6(-.@O"77)+HE5R"R95<CJ:"M8+<@K>"J8%(`(W%CXF"S)?Q@JJ#=(-"
M@5N#BX-HEKR"\(K<@O&"Q8*B@MR"MX*I/R""NX*D@LB"YX-@@T:#8H-.@K6"
MQ(*M@KZ"LX*B+@"#7X-%@Y.#C8%;@V@`)7,@@LR#7X-%@Y.#C8%;@V@`D+:0
MK(*U@KV0W9+H@O`@4$A0((-8@TZ#BH-V@V>"\(+&@K6"Q(-?@T6#DX.-@5N#
M:(*W@NF!0@"*^I/Z@48E<P",<)&QBOJ*U`"39(YQ@X&!6X.+`"5S((+PE=*/
M5P".48G!CM*"S)72CU<`@W6#C8-B@TZ"S)72CU<`@T^#BX%;@W:"S)72CU<`
M@T&#3H-:@UB,H(+,E=*/5P"#08-.@UJ#6(R@@LR5TH]7`"5S((+,@T&#3H-:
M@UB,H(+,E=*/5P"#BH."@5N#9X-*@XR#DX-?@5N"S)72CU<`CE&)P8[2@LR5
MTH]7`)6JE]Z"QI!&@LR5TH]7`(-)@W:#5H.'@Y."S)72CU>!1@`E<R""S(-!
M@TZ#6H-8C*""S)72CU<`DV2.<8.!@5N#BP"#@8%;@XN#08-H@XR#6`!%@X&!
M6X.+@T&#:(.,@UB"JHCJDG:"M8+(@J^"ZH+.@J*"KX+<@KF"\8%"`(OS@X&#
M8H-:@5N#5X+%@K>!0@")O8+@C*F"PH*I@NB"W(*Y@O&!0@"#38.#@XF#BH%;
M@JF"YXGFD9R"\)%]D_R"Q8*K@NF"YH*D@LF"M8+<@K>"J8%(`(E%@TZ#BH-B
M@TZ"Q8.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2`"/29>YD_J5=`"/29>YD_H`
MCTF7N8Z>BM0`@T>#9H-"@UZ!6XGFELJ"\)'E@JN"K0"#1X.)@5L`)7,@@K."
M\8+,EUR2Z(_NE?&.YI.^DH:"R8-'@XF!6Y2MD+:!1B5S`(.!@5N#BX-!@VB#
MC(-8@LR#1X.)@5N"Q8*W@4(`,365JI:(`#*5JI:(`#,PE:J6B``UE:J6B`"#
MC8-/@T.#DY:(`#,PE:J6B``QE:J6B`".=Y+HDFR"S)?A`([`C7,`DU>*2@"7
M3(SXBOJ,P`".=Y"4`(-'@TZ#6(-\@5N#9P"77)+HE5R"S(-'@TZ#6(-\@5N#
M9P"13XQID$8`D-V2Z(+P($944"""Q8-!@V*#=H.-@5N#:(*W@ND`@W:#C(-T
M@T"#C(.3@UB0W9+H@O".YI.^@L6"JX+<@KF"\8%"`$Q$05`@@U2!6X-O@LF0
MVI&Q@L6"JX+<@KF"\8+%@K6"O8%"`%--0B"#5(%;@V^"R9#:D;&"Q8*K@MR"
MN8+Q@L6"M8*]@4(`(B5S(B""J8+G@LR#4H-S@5N"R8ZXE'."M8+<@K6"O8%"
M`"(E<R(@@M:"S(-2@W.!6X+)CKB4<X*U@MR"M8*]@4(`D%:+2X+,(%-!4TP@
MD-J1L8+)CKB4<X*U@MR"M8*]@4(`(B5S(B""UH+,B-J3KH+)CKB4<X*U@MR"
MM8*]@4(`@E&,C@"#=(-`@T.#BY"4.B`E<R"#=(-`@T.#BP"#=(-`@T.#BY"4
M.B`E<R"#=(-`@T.#BP"#=(-`@T.#BX-]@VR!6X-7@X,`@W2#0(-#@XN6O`"#
M=(-`@T.#BY%)D?``@W2#0(-#@XN#08-B@W:#C8%;@V@`@W2#0(-#@XN#08-B
M@W:#C8%;@VB"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!0@"#=(-"@XN#7@"1
M>X*W`)6VCIJ01@"#=(-(@5N#@`"#=(-(@5N#B8.``(O@`)AG`(O@EVH`C]J"
MM8*BD."6O@".@9:\`)%3E,H`)7,@C5R0K(_NE?&"\)"VD*R"MX+I`)"VD*R"
MLX+J@KV#4H%;@V@`D*D`)7,@@LF(VI.N`(-/@XN!6X-VBL>7G0"#3X.+@5N#
M=I:\@LV+\Y22@L6"S8+(@J*"L8+&`(-/@XN!6X-V`(-1@UB#9X-!@TZ#6H-8
MC*``@U&#6(-G@W6#8H-.`$A45%`@E$:/V(*J@MV"PH*I@NB"W(*Y@O&!0@"#
M;H-B@U:#A8-!@XN#4X.*@UF#@`"#=X-B@U\`C8*"LP"#=X.+@W8`@WJ!6X.`
M`(ZID>Z"S(]:CXH`CJF1[H+,DV288I34C88`2&]R9&4`B:&0_`".GHK4`(*B
M@JV"PH+,E_&"\(R+C8>"M8+<@K>"J8%(`(-T@T*!6X.+@V@HC7,I@LR0E(+-
M@J*"K8+"@L6"MX*I@4@`@J*"K8+"@LR-<X+PC(N-AX*U@MR"MX*I@4@`24U!
M4""#@8%;@XN#>X-B@TZ#6(+,C>R0K(+)CKB4<X*U@MR"M8*].B`E<P!)34%0
M((.!@5N#BX-[@V*#3H-8@LR-[8^<@LF.N)1S@K6"W(*U@KTZ("5S`$E-05`@
M@X&!6X.+@WN#8H-.@UB#3H-(@5N#7H+,C>R0K(+)CKB4<X*U@MR"M8*].B`E
M<P!)4(-!@VB#C(-8@JJ+EHG"@K."ZH*]0TE$4H-U@XV#8H-.D^""R8*@@NB"
MW(*Y@O&!0@!)4)65C;V(X92]@L6"MX%"`(-!@T.#4H.3@LR"W0"#08-#@U*#
MDX+&@V6#3(-8@V<`242"S):\D4\`@N""M8+@D+."M8*ME5R.IH*S@NJ"R(*B
M@LB"YX%!)7,@@K6"Q)!6@K6"HH-%@T.#DX-H@5N"\(I*@J*"Q(FZ@K."HH%"
M`(+@@K6"X"!);G1E<FYE="!%>'!L;W)E<B""\(YG@L&"Q(*B@L2!08-!@T.#
M4H.3@JJ57(ZF@K."ZH+(@J*"R(+G@4&"L8*Q@O"129'P@K6"Q(FZ@K."HH%"
M`(GFD9R#=H.,@W*#A8%;`(GFD9P@55),`(GFD9P@55),.@")YI&<`)=<DNB5
M7(+,@T.#DX-\@5N#9X%!@UB#98-B@W8@)60`@T.#DX-\@5N#9X%!@UB#98-B
M@W8@)60`EUR2Z)5<@LR#0X.3@WR!6X-G+X-'@TZ#6(-\@5N#9P"#0X.3@WR!
M6X-G@K."ZH*]@W2#0H%;@XN#:(%&("5S`(-#@Y.#?(%;@V>"LX+J@KV#=(-"
M@5N#BX-H@48`BM2(X8+!@KV#08-.@U:#AX.3@U*!6X-H@JJ77H*F@N>"ZH+$
M@J*"W(*W@4(`@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI"S@K6"K8*@@NB"W(*Y
M@O&!0@"2:8FZ@K""\)!;@JT`C,*5RH.&@5N#50"#0X.3@W2#2(.!@5N#5H.'
M@Y,`7T^,XX+K@LF7\8+PD7V3_`")YI&<@O"1?9/\`)5<@O"1?9/\`(.*@Y.#
M3H+PD7V3_`!?0Y%/@LF7\8+PD7V3_`",NXW=B,J2=8+,C.."ZX+)E_&"\)%]
MD_P`C+N-W8C*DG6"S)%/@LF7\8+PD7V3_`",NXW=B,J2=8+,C.."ZX+)C7."
M\)%]D_P`C+N-W8C*DG6"S)%/@LF-<X+PD7V3_`",NXW=B,J2=8+,C.."ZX+)
MDFF7CH+PD7V3_`",NXW=B,J2=8+,D4^"R9)IEXZ"\)%]D_P`D>.1UH-E@Y.#
M=H.,@5N#9X+,D7V3_`",XX+K@LF#6H.+@O"1?9/\`)%/@LF#6H.+@O"1?9/\
M`(SC@NN"R9?Q@O"1?9/\`)%/@LF#6H.+@O"1?9/\`(SC@NN"R9)IEXZ"\)%]
MD_P`D4^"R9)IEXZ"\)%]D_P`C.."ZX+)C7."\)%]D_P`D4^"R8US@O"1?9/\
M`(GFD9R"S)%]D_R!7I7/C5@`@XJ#DX-.@LR1?9/\@5Z5SXU8`)&7D$V0YH+)
MD9>"Z8*]@M^"S(YCC8*"JI5SD:N"M8+$@J*"W(*W@4(`CF.-@H*JE7.1JX+%
M@K>!0@"5<Y"S@LB#08-V@XJ#4(%;@U:#AX.3@L6"MX%"`):SC/B"R(-F@5N#
M7H*JDO&/;X*S@NJ"W(*U@KTN`)&7@NB0YH+,@T&#:(.,@UB"JI5SD+."Q8*W
M@4(`C^.(RH+,@T&#3H-:@UB,H(*JE7.0LX+%@K>!0@",LX+,@T&#:(.,@UB"
MJI5SD+."Q8*W@4(`E7.0LX+(=6YI8V]D98-F@5N#7H+%@K>!0@"4K8USCM(`
MCLZ1S`""4(R.`()6C(X`@E6,C@"1M8*F@ND`DH:)FY&U@J8`E[R26Y&U@J8`
MC;:1M8*F`(E%D;6"I@!+97)B97)O<R"#5(%;@V^"JI1&C]B+D93;@K6"W(*U
M@KV!0@",KHWLD*R3^@",KHYWEN0`C*Z2MP",KH[ME]X`DV2.<8RN@JJ"MX+%
M@LF,]H]/C*Z#5(%;@V^"R9&VC=V"M8+<@K>!0@"#3(-#@X^!6X-H`(R^C.H`
M,C2.GHK4D4^"W(+%`(W%CTF5SXU8D_H`,8.6C(Z13X+<@L4`D4^)\8+,@XV#
M3X-#@Y,Z("5S`)%/B?&"S(.-@T^#0X.3.B`E,B1S((*I@N<@)3$D<P"13XGQ
M@LR#C8-/@T.#DSH@@LB"M0""4(]4BM213X+<@L4`@XR#0X-!@T6#9P"#9H%;
M@UZ#>(%;@UB(ZI>7`(-W@XN#=HV`EMJ"\)5<CJ:"MX+I`)5<@LR(ZI>7`(.&
M@5N#58+,@XJ#6(-G@LV6LXSX@LF"R(+!@L2"HH+<@K>!0@!?0X_JCXH`DFZ(
MYH+&CIZ*U`"/ZH^*`(.-@T^#0X.3`(.-@T^#08-%@V<`@XV#3X-#@Y,@@UZ#
M6(-.`(.&@5N#59:\@JF#<(-8@X^!6X-H@JJ0LX*U@JV"R(*B@KV"WX+)@XV#
M3X-#@Y."R8ZXE'."M8+<@K6"O8%"`(.-@T^#0X.3@LF.N)1S@K6"W(*U@KV!
M0@"#38.*@U:#@Y6VCIJ!:8^LE;:.FH%J`(.)@V6#DY6VCIJ!:8^LE;:.FH%J
M`(.-@5N#?9"4CIJ!:8^LE;:.FH%J`(R.`)-9E72"LX+J@KT@35,M5$Y%1B""
MS8-F@5N#7H+PBMR"\8+%@J*"W(*Y@O&!0@"39(YQ@X&!6X.+`(.*@X*!6X-G
M@TJ#C(.3@U^!6X+PD-V2Z(*U@MR"MX%"`)!&E72"KX*S@NJ"O8.)@WB#BX+P
MD<Z)GH*S@KF"Q)6JE]Z"\(K'EYV"M8+<@K>!0@""4HR.`(-T@T*!6X.+@VB"
M\(CJDG:"LX*Y@L2"HH+<@K<`@E2,C@")[XMC`(.!@Y.#;P"#@8-J@X6!6X."
M@5N#:`"#6H.+C(N-AP"6>Y6V`(.!@V*#6H%;@U>"S8R?C]B"Q8*K@MR"M8*]
M@JJ!08^0EKR.TH+,D&>,LX+-C)^/V(+%@JN"W(*Y@O&"Q8*U@KV!0@"#@8-<
M@V*#:`!-:6UE(%1Y<&4`E:H`D-V2Z(*J@J""Z(+<@KF"\8%"@K&"S(-!@W:#
MBH-0@5N#5H.'@Y."\(YGEW""MX+I@KV"WX+)@LV0W9+H@O"-[)"L@K>"Z95+
MEW:"JH*@@NB"W(*W@4(`C(X`C&>1T8.!@5N#BP"/0Y"SD_H`C(Z7:@",C@",
MCI5<CJ8`EHB,C@"6B(R.@4:,2H+HE=2"M0")NH+6`(VV@M8`B46"U@"/XX+6
M`(FZ@M8`C^."U@"#08-*@T6#DX-G`(Z$@LR77)+HE5P`CH2"S)=<DNB57(%&
M`(Z$@LR77)+HC^Z5\2!54DP`DZ^(TX*U@MR"N8+Q`):\D4\`@VR#8H-G@X^!
M6X-.`(+(@K4`D%:+2Y6JE]X`D%:#0X-X@Y.#9P"05H*U@J*#AH%;@U66O"B4
M0XC3*0".GP"-H8SC,C2.GHK4`)>(CU2"W(+%`)>(CU2"W(+%`(Y1B<&.TH+(
M@K4`C;>5JH+PE5R.IH*W@NF"O8+?@LR0W9+H@JJ"H(+H@MR"N8+Q@4(`@U&#
M6(-GEW""S)=<DNB57(+-@J""Z(+<@KF"\8%"`)7/C5B"R(*U@4(`@K&"S(-!
M@TZ#6H-8C*""R8+-@U2#=8-!@TZ#6H-8C*""S9+'B<&"Q8*K@MR"N8+Q@4(`
M1E10(%9&4R""S(U<D*R/[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@!344P@
M5D93((+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`%-13""#2H-E
M@U.#BH+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`(YCC8*"JH*@
M@NB"W(*Y@O&!0@"1EY!-D.:"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`(*B@L*"
MW(+%@N``E5R.IH*W@NF"UX*K@T.#>(.3@V>"S8*@@NB"W(*Y@O$`)7,@@K."
M\8+,EUR2Z(_NE?&"S8*@@NB"W(*Y@O$`@X&#8H-:@5N#5X*JCG>2Z(*S@NJ"
MQ(*B@MR"N8+Q@4(`EKR13X*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`E-2-AH*J
MCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`2%144""41H_8@LR#<(-8@X^!6X-H@JJ"
MH(+H@MR"N8+Q@4(`24U!4""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q
M@4(`2V5R8F5R;W,@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"`(.-
M@T^#0X.3()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@!005-35T0@
ME$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"`%--0B"41H_8@LR-7)"L
MC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`3W!E;E-33""#=H.-@T^#B8.`
M@LR#<(-8@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0D]P96Y34TP@@LT@4$M#4R`Q
M,B""S(-F@5N#7H+PB+6"I(+,@LF52Y=V@L6"MX%"`)7;EZ^"S(-4@T.#DX-!
M@V*#=H+(@K6!0@"#AH%;@U66O(*I@W"#6(./@5N#:(*JD9>"YX+J@MR"N8+Q
M@L6"M8*]@4(`EK.,^(+,6$U,@V:!6X->@JJ5U(+H@MR"M8*]`))L@LB"M0",
MLX+,D-V2Z(+)@V^!6X-7@X>#DX*J@J""Z(+<@KF"\8%"C<23>)#=DNB"\)"V
MD*R"M8+<@K>!0@""H(+(@KV"S)#=DNB"R8-O@5N#5X.'@Y."JH*@@NB"W(*Y
M@O&!0HW$DWB0W9+H@O"0MI"L@K6"W(*W@4(`@LB"M0""L8+J@N:"Z)%/`(*Q
M@NJ"YH+HC.,`@VV!6X-G`()0@E",C@"-H0"1EY!-D.:#BH-8@V>"\(U8D%:"
MO8+?@LR4U(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"O8%"`$]+`(-)@W6#5X-&
M@TZ#9P"#28-U@U>#1H-.@V>-[)"LCM(`@E""3XR.`(-)@W2#0H-8`(NDETR#
M=(-(@XN#7X+-($E-05`@@U2!6X-O@KZ"KX*J@U2#?(%;@V>"Q8*K@MR"MX%"
M`)-DCG&#@8%;@XN#08-H@XR#6(+-,8+"@KZ"KXYWDNB"Q8*K@MR"MX%"`(^*
METR.TH*I@U:#6(-E@X"*QY>=CM*"OH*O@JJ+I)=,@LR/BI=,C*""QH-!@TZ#
M6H-8C*""\)7/C5B"Q8*K@MR"MP"05HM+@T6#0X.3@VB!6X+)E5R.I@!/<&5N
M4U-,((-'@XF!6X%&4R]-24U%((^0EKR"LX+J@KV#<(%;@V>"J8+G@V:!6X->
M@O".YH+HCV^"N8+<@KF"\8+%@K6"O8%"`)1#B-,`@TF#=H-6@X>#DP`E<R"#
M28-V@U:#AX.3`(^'CYB5=(.*@UB#9P"19Y!$`)64CY``D*Z7G0",LX+,@T&#
M=H.*@U"!6X-6@X>#DX-E@Y.#=H.,@5N#9P"1O(+,@T.#DX-T@TB#@8%;@U:#
MAX.3`(^*ETR.T@"/BI=,CM*"S(-!@TZ#6H-8C*``4$%-()1&C]B"S8YGEW""
MQ8*K@MR"N8+Q@4(`4$=0()-DCG&/D):\`%!'4""(PXV&E;8`4$=0((SVBDJ,
MK@!01U`@CY"6O(W/+XC#C8:)NX-F@5N#7@!02%"#4H%;@V@`4$A0@U:#1H.+
M`):$D9``@W"#6(./@5N#:`"#<(-8@X^!6X-H@JJ0LX*U@JV"H(+H@MR"N8+Q
M`%)!1$E54R"41H_8@LR#<(-8@X^!6X-H@JJ52Y=V@L6"MX%"`(-P@UB#CX%;
M@VB"S(IME$8`@W"#6(./@5N#:#H`@W"#6(./@5N#:#H@`(-P@UB#CX%;@VB"
MJHCJDG:"M8+<@KF"\8%"`)-<@NB5=(*O`)-<@NB5=(*O`(-P@UZ!6X.3`)7;
MEZ^2AH+,@U2#0X.3@T&#8H-V@48`@W"!6X-:@Y.#9P"5VX[GD8"-[(+PCL"-
M<X*W@ND`@XV#3X-#@Y..GH+)E=N.YY&`C>R"\([`C7."M8+<@K>"J8%(`(*Q
M@LR#0X-X@Y.#9X+PC>V/G(*U@MR"MX*I@4@`@T&#3H-:@UB,H`"#08-.@UJ#
M6(N1E-L`@T&#3H-:@UB,H`"#08-.@UJ#6(R@@LR*QY>=`(S"D&R/[I7Q`)-D
MF&(`@W.#3H-:@XL`C(Z"QI1.@O"3_)?-@K6"Q(*M@KZ"LX*B@4(`D%:"M8*B
ME:J7WH+,EKR13X+PD_R7S8*U@L2)NH*S@J(Z`)"S@K6"HI/ZE72"\)/\E\V"
MM8+$@JV"OH*S@J(N((R.@LR3^I"4@O"#8(-&@V*#3H*U@L2"K8*^@K."HH%"
M`(_ABE&3X)=E@O"7=I;Q@K6"Q(*RBTR3_(*M@KZ"LX*B@4(`@X:!6X-5EKR"
MQH-P@UB#CX%;@VB"\)/\E\V"M8+$@JV"OH*S@J*!0@"3BI5;D)0`@WR!6X->
M@XN#28-V@U:#AX.3`%!R969S7VQD87`Z()5+EW:"R$Q$05"*9Y*CBT"47(*J
MC*F"PH*I@NB"W(*Y@O&!0@!0<F5F<U]L9&%P.B"52Y=V@LAS97-S:6]NBF>2
MHXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`@W:#C(-R@X6!6P"05H*U@J*#18-#
M@Y.#:(%;@LF)YI&<@O"57(ZF`(CSC?P`E.F6IXRN`(_ABE$`C^&*49/@EV6"
MS)#@EKX`C/:*2HRN`(SVCT^,KH-!@XN#4X.*@UF#@`",]H]/C*XOE.F6IXRN
M@JJ0MI"L@L6"JX+<@KF"\8+%@K6"O8%"`(-.@T>#BH%;`%)308SVCT^,KB@E
M9(-R@V*#9RD`E.0`D\>"W@"6>Y.6@LD@)7,@@O"-[8^<@K6"W(*W@JD_((*Q
M@LR1@(WL@LV,LX+)EM^"N8+<@KF"\8%"`)9[DY:"R8.&@5N#52`E<R""S(-F
M@5N#7H+PC>V/G(*U@MR"MX*I@4@@@K&"S)&`C>R"S8[F@NB/P8*Y@MR"N8+Q
M@4(`CTF7N9/Z`):(D_J,2H+HE=2"M0"6B(R.C$J"Z)74@K4`EHB/5(Q*@NB5
MU(*U`):(E$Z,2H+HE=2"M0""XH+HDKR"MP"3KI-)@X&#:H.%@5N"S(W$E5R.
MIHK4BG4Z`(-\@5N#7H.+@LR-Q)5<CJ8`@XJ#@H%;@V>#2H.,@Y.#7X%;`(.*
M@X*!6X-G@TJ#C(.3@U^!6X%&`(.*@X*!6X-G@U2!6X-R@U@`@XJ#@H%;@V=5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B``C>V/G``E<R""
M\(WMCYP`CE&)P8[F@NB.?H+?`(-U@XV#8H-.@O"-[8^<`(-Y@T&"\(WMCYP`
M@X:!6X-5@O"-[8^<`(.&@5N#58+PC>V/G#H@)7,`EW:+@8+)E=23FH+%@JN"
MW(*Y@O$Z(`"52Y![`)5+D'N.48G!CM(`@XJ#6H-B@V<`@V:#=(-(@XN#9X+)
MEM^"MP")GI.:`(R+B<H`@TF#=H-6@X>#DX+)EM^"Z0",LX+,C5R0K(+)EM^"
MMP"#98-,@UB#9X-'@V:#0H->@5N"S(-)@W:#5H.'@Y,`EO"*A`"-<Y&ND*L`
MC7.1KI"K`(US@48`CL"-<P!3+TU)344@B,.-AH^0EKP`4R]-24U%((C#C8:5
MM@!305-,()1&C]B"S8YGEW""Q8*K@MR"N8+Q@4(`4U%,((-6@T:#BP!34T@`
MDWD`DWF7:@`E<R""\)7;D;8`D%:+2X+&@K6"Q)7;D;8`@T.#>(.3@V>"\)7;
MD;8`@TF#=H-6@X>#DX+PE=N1M@`E<R"0W9+H@O"5VY&V@K6"W(*U@KV!0@",
MGXWU`)+'B<&"MX+I@T^#BX%;@W:"\)%)D?""M8+$@JV"OH*S@J(`D%:"M8*B
MCXJ.G8[2@O"129'P@K6"Q(*M@KZ"LX*B`(-4@5N#;X+PD4F1\(*U@L2"K8*^
M@K."H@"2QXG!@K>"Z8.&@5N#58+PD4F1\(*U@L2"K8*^@K."H@"*;91&@LR#
M28-V@U:#AX.3@N*57(ZFC&".KH+(@L>"\)%)D?""M8+<@K>!0@"#0X.3@WR!
M6X-G@K>"Z9=<DNB57(+PD4F1\(%&`)5+EW:"R)6VCIJ"\(FZ@LR#>X-B@TZ#
M6(*I@N>128+Q@L6#4H-S@5N"MX+I@L:!08-E@TR#6(-G@T>#BH-!@M:#>8%;
M@UB#9X+%@JN"W(*W@4(`D_J5=(+,B^:0V(+HE;:.FH+PCG>2Z(*U@L2"K8*^
M@K."HH%&`)/ZE72"S(Q@CJZ"\(YWDNB"M8+$@JV"OH*S@J*!1@"#1X-.@UB#
M?(%;@V>"S(Q@CJZ"\)%)D?"!1@"#0X.3@WR!6X-G@K>"Z8-T@T"#0X.+@O"1
M29'P@48`CU2"S(W%CXF"S)=JD_J"\)%)D?"!1@",LX-T@T"#0X.+@LR,8(ZN
M@O"129'P@48`E<^-6(*U@KV"HDE$@O"129'P.@".GHV/@LR+YI#8@NB5MHZ:
M@O".=Y+H@K6"Q(*M@KZ"LX*B@48`CIZ-CX+,C&".KH+PCG>2Z(*U@L2"K8*^
M@K."HH%&`)5<CJ:"MX+IBOJ*U(+PD4F1\(%&`(W%CXF"S)5<CJ:,8(ZN@O"1
M29'P@48`B.J2=H*W@NF"48+"@LR#=(-"@5N#BX-H@O"128+Q@L6"K8*^@K."
MHH%"`(-\@5N#7H.+B>:6RH+)E5R.IH*W@NF#0X-X@Y.#9X+PD4F1\(*U@MR"
MMX%"`)!&DK*"\)%)D?""M8+$@JV"OH*S@J(N`(R^C.J"\)%)D?""M8+$@JV"
MOH*S@J(Z`(_ABE&#C(-\@5N#9X+PD9>038*W@ND`4TU3()&7D$T`@K&"S(-#
M@WB#DX-G@O"-[8^<@K>"Z8Z>@LF.48G!CM*"R8-,@X.#DX-:@XN"S)+*DFV"
M\(]O@K<`)7,@@LF#@8%;@XN"\)&7@ND`@T.#>(.3@V>"\)7;D;:"M8*]CIZ!
M08Y1B<&.TI%3B/6"R9+*DFV"\(]O@K<`@EB,C@"2RI34`(])E[F3^H+PD-V2
MZ`",2H+HE=2"M8])E[F3^H+PD-V2Z`"*2HYND_J"\)#=DN@`@WR!6X->@XN"
MQ8-!@TZ#6H-8@K>"Z8.*@X*!6X-G@U2!6X-O@O"0W9+H@K6"W(*W@4(`C+Z,
MZH%!CIZ*U)'1@4&3^I5T@O"0W9+H@K6"W(*W@4(`BDJ.;HZ>@LR#08-V@XJ#
M4(%;@U:#AX.3@4&01I*R@4&#>8%;@U>-Q)5<CJ:!08*[@LR1O(+,E5R.IH-)
M@W:#5H.'@Y."\)%)D?""M8+$@JV"OH*S@J(N`(NDETR77)+HE5R!1@"*R))0
M@LB7=I;Q@48`@6F#@8-J@X6!6X+(@L>"Q8%J@U:#AX%;@V>#2H-B@V>#3(%;
M@JJ.9X*F@NF"YH*D@LF"M8+<@K>"J8%(`)5<CJ8`E:J7WH+,B?"0X(+PE5R.
MIH*U@MR"MX*I@4@`EUR2Z)5<@LR2AH+%C>V/G(%!C'B5\8%!C$J"Z)74@K6"
MS(-!@T.#4H.3@O"57(ZF@K6"W(*W@JF!2`"#7H-8@TZ"S(KZD_J"\)=<DNB5
M7(+)E5R.IH*U@MR"MX*I@4@`EUR2Z(_NE?&!:49R964O0G5D>8%J@LR)\)#@
M@O"57(ZF@K6"W(*W@JF!2`"#C8-/@T.#DXZ>@LF13XGQ@LR#C8-/@T.#DXZ>
MBM2"\)5<CJ:"M8+<@K>"J8%(`(QXE?&"S(*@@NF#0X-X@Y.#9X*^@J^"\)5<
MCJ:"M8+<@K>"J8%(`)5<D8"-[(.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2`")
MYI;*C;:"R2`E<R"#@8-J@X6!6X+PE5R.IH*U@MR"MX*I@4@`CU257(ZF@L6"
MX):(D_J.GHK4@O"57(ZF@K6"W(*W@JF!2`"/:X^L`(+<@KB7UX+H@LR#=8.-
M@V*#3H+PCVN/K(+<@KV"S8C:DZZ"LX*Y@L2"K8*^@K."HH%"`(-4@T.#DX-!
M@V*#=@"39(YQCY"6O`"39(YQCY"6O(-!@XN#4X.*@UF#@`"#5(-#@UD`E=N.
MYX+P@UB#3(-B@W:"MX+I`)&7D$V,LX-!@VB#C(-8`)==E)(`EUV4DH+&EH21
MD`"3P8[JE;:.FH+,D_R7S0"*2HYND_H`BDJ.;HZ>BM0`7U6/\Y'4`(]"@MR"
MO8+-C*<`C_.1U`"/6H^*E-22;@".YH_!@K60_`"#6(->@T.#BR!;0U-370"3
M^@".P(US`(FZE72"JP"0K(SW`"5S((+-CY&"JXV>@MR"ZH+<@K6"O0"*5)=V
M`)/ZEVH`C^.5=(*K`)"I`%135H-T@T"#0X.+`)5<`)5<D:Z0JP"57)&ND*L`
M@UZ#6(-.`)-DF&*4U(V&`)5SDN@`@V6#3(-8@V>"S(+=`)6VCIJ4>I)U`);8
M`(*REYB7<(*@@NB"JH+&@J2"LH*T@J*"W(*U@KV!0@!&5%`@BF>2HX*J@J""
MZ(+<@KF"\8%"`$UA:6YT96YA;F-E((-.@XF#6(+,D\>-GH+=@JJ0LX_M@LF-
M<X*F@MR"N8+Q@L6"M8*]`(-)@W:#5H.'@Y.#18-"@Y.#:(-%@O"5PH*V@MR"
MM8*]@4*/29>Y@K6"W(*W@4(`@T&#3H-:@UB,H(+PETR,^(+)@K>"Z8+)@LV*
MQY>=CM*"JH*[@LR#;X-B@TZ#1X.3@VB"\)#=DNB"MX+I@K&"QH*JE4N7=H+%
M@K>!0@"77)+HE5P@(B5S(B""S8WMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(`EUR2
MZ)5<("(E<R(@@LV-[8^<@K."ZH+<@K6"O8%"`)=<DNB57"`B)7,B((+-("(E
M<R(@@LF6O)%/@JJ5SXU8@K."ZH+<@K6"O8%"`)=<DNB57"`B)7,B((+-E=N1
MMH*S@NJ"W(*U@KV!0@"809>-D.9)1)34C8:"JHYWDNB"LX+J@LB"J8+!@KV"
MJ8%!B_."OH+!@KV"J8%!@J""Z8*B@LV#9H%;@UZ#>(%;@UB2AH+)C*F5=(*I
M@NB"W(*Y@O&"Q8*U@KV!0@"39(YQCY"6O(*S@NJ"O8.!@V*#6H%;@U>"\(R?
MC]B"MX+I@LF"S8%!4$=0((^0EKR"JI5+EW:"Q8*W@4(`D9>039#F2424U(V&
M@JJ.=Y+H@K."ZH+(@JF"P8*]@JF!08OS@KZ"P8*]@JF!08*@@NF"HH+-@V:!
M6X->@WB!6X-8DH:"R8RIE72"J8+H@MR"N8+Q@L6"M8*]@4(`D9>039#F2424
MU(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"O8%"`(C#C8:)NX+)@LV(P)%3@LB#
M18-&@W60VI&Q@JJ52Y=V@L6"MX%"`(-#@WB#DX-GDLJ2;8+-("5S((*S@O&"
MR9&7@N>"ZH+<@K6"O8%"`(-T@T"#0X.+@JJ#9H%;@UZ"\(K<@O&"Q8*B@MR"
MN8+Q@4(`B,B)NH+-@T.#>(.3@V>"S(_:C=>"Q8*W@48`DHV(TX%)((-T@XN#
M6(-.@XJ!6X.3@X*!6X-H@LT@26YT97)N970@17AP;&]R97(@@L6"S9;BD>B"
MJI2MD+:"MX+I@K&"QH*J@J""Z(+<@K>!:8-U@XF#18-5@LR#;X-/@L6"MX%J
M@4*)YI;*@LF#4X-^@JJ57(ZF@K."ZH*]@NB!05=I;F1O=W,@@JJ#3H.)@V*#
M5H.%@K6"O8+H@K>"Z8*I@N""M8+J@MR"N8+Q@4)<;H-T@XN#6(-.@XJ!6X.3
M@X*!6X-H@LF"MX+I@LB"YR!/2R""\(F?@K6"Q(FZ@K."HH%"`$E$("(E<R(@
M@LV-[8^<@K."ZH+<@K6"O8%"`$=N=5!'((-O@T.#:8.*@LR#<(-8@JH@0W)Y
M<'1?<&=P((-.@XF#6(+)D-V2Z(*S@NJ"Q(*B@NF52Y=V@JJ"H(+H@MR"MX%"
M`$AO<F1E7T-R>7!T7W-M:6UE@TZ#B8-8@LF"S6]P96YS<VR#@H-7@X6!6X.+
M@JJ52Y=V@L6"MX%"`(-V@XR#=(-`@XR#DX-8(B5S(H+-@V:!6X->@JJ#5(-#
M@UF0IXS`@O")>H*F@KV"O8+?E=N1MH+%@JN"W(*Y@O&"Q8*U@KTN`(*Q@LR#
M9H%;@UZ,7B@E<RF"\)5<CJ:"MX+I@KV"WX+,@W:#C8-/@XF#@(*J@K&"S(-6
M@UB#98.`@LF"W8+"@JF"Z(+<@KF"\8%"`(-4@5N#;R`B)7,B((+-C>V/G(*S
M@NJ"W(*U@KV!0@"#5(%;@V\@(B5S(B""S97;D;:"LX+J@MR"M8*]@4(`@T&#
M8H-V@XV!6X-H@V:!6X->@JJ2O)%/@LR#6(-E@V*#=H+%C\&.N(*U@MR"M8*]
M@4(`@T&#8H-V@XV!6X-H@V:!6X->@O"5VY&V@L6"JX+<@KF"\8+%@K6"O8%"
M`(R[C=V"S(KNCX""R8CJDG:"MX+I@T.#>(.3@V>"S8*@@NB"W(*Y@O&!0@"#
M0X.3@XF#0X.3E5R.IH+%@JN"Z964E:J"S8*@@NB"W(*Y@O&!0@"5MHZ:D)2"
MJH*Q@LR#=(-"@5N#BX-H@LF1O8G?@JR"W(*W+B`E<R""S)6VCIJ"JI/\E\V"
MLX+J@L2"HH+<@K<N("5S((C(B;J"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(-T
M@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S((+-
M@T&#8H-V@XV!6X-H@K."ZH+$@J*"W(*Y@O&!0@"#=(-`@T.#BX-!@V*#=H.-
M@5N#:(+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E<R""S8-T@T"#0X.+@LR#5(-#
M@UF0IXS`DFPH)62#;X-#@V<I@O")>H*F@L2"HH+<@K>!0@"#=(-`@T.#BX-!
M@V*#=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E<R""S8CJE92"S(+=
M@T&#8H-V@XV!6X-H@K."ZH+<@K6"O8%"`)=<DNB57(+,@T&#3H-:@UB2AH+)
M@T>#B8%;@JJ4K9"V@K6"W(*U@KV!1B`E<P"#0X-X@Y.#9X+,DL>)P9*&@LF#
M1X.)@5N"JI2MD+:"M8+<@K6"O8%&("5S`(-#@WB#DX-G@LR5TH]7DH:"R8-'
M@XF!6X*JE*V0MH*U@MR"M8*]@48@)7,`F$&7C9#F@V:!6X->@LR#0X.3@WR!
M6X-GDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4(`:4-A;&5N9&%R((-F@5N#
M7H+P@T.#DX-\@5N#9Y*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"`(-#@WB#
MDX-G@LR(VI.NDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@48@)7,`CG>2Z(*S
M@NJ"O8-!@VB#C(-8DJ""S)&`C>R2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!
M0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K."HH%"`(-#@WB#DX-GDLJ2;8+P("5S
M((*S@O&"R9&7D$V2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!1B5S`)A!EXV0
MYH+,C]J-UX+PC5B05I*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"C.."Q8W$
MDWB.P(US@K6"Q(*M@KZ"LX*B@4(`D9>039#F@XJ#6(-G@LR-6)!6DH:"R8-'
M@XF!6X*JE*V0MH*U@MR"M8*]@4*,XX+%C<23>([`C7."M8+$@JV"OH*S@J*!
M0@"#1X-.@UB#?(%;@V>"MX+I@T.#>(.3@V>"S8*@@NB"W(*Y@O&!0@""L8+,
M($E-05`@@U2!6X-O@LV+I)=,@W2#2(.+@U^"\(-4@WR!6X-G@K6"Q(*B@MR"
MN8+Q@4(`@K&"ZH+-ETR,^(+(<F%R@T&!6X-*@T.#=8+%@LV"R(*B@N:"I(+%
M@K>!0@""L8+J@LV73(SX@LAZ:7"#=(-`@T.#BX+%@LV"R(*B@N:"I(+%@K>!
M0@""L8+J@LV73(SX@LB#2H%;@VB4U(V&@L6"S8+(@J*"YH*D@L6"MX%"`(*Q
M@LR#=(-"@5N#BX-H@LV52Y![@L6"MX%"`(*Q@LR#=(-"@5N#BX-H@LV0KI"4
M@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0@""L8+,@W2#0H%;@XN#:(+-D)2.FH+&
M@U*#C8.3@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0@""L8+,@W2#0H%;@XN#:(+-
M.)!ID)2"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LV#
M4H.3@WV"W(*]@LV+\Y22@L6+YI#8@N>"ZH*]D*Z0E(+,@XJ#6(-G@L6"R(*M
M@L2"S8*B@J^"W(*Y@O&!0@""L8+,@W2#0H%;@XN#:(+-,3:0:5)'0I5<BTR"
MS)!&@U*!6X-H@LB"K8+$@LV"HH*O@MR"N8+Q@4*7X3HG(S$R,S1A9B<N`(*Q
M@LR#=(-`@T.#BXQ@CJZ"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!0@""L8+,
M@W2#2(%;@X""S8KY@LF/B)>=@K."ZH+$@J*"W(*W@4(`@U2!6X-O@JF"YX+,
MB9Z3FH%&)7,`@K&"S(.!@V*#6H%;@U>"S8*@@LB"O8*JCF>7<(*W@NF"S(+&
MB-F"R(+IE;:.FH-:@V*#9X%I)7.!:H+%CY&"J8+J@L2"HH+<@K>!0@""L8+,
ME-2-AH+-C<6/K(+%@N`Q@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0@""L8+,@U2!
M6X-O@L6"S7II<(+&9WII<(-T@T"#0X.+@O"35XI*@L6"JX+<@KF"\8%"`(*Q
M@LR#5H-8@V6#@(+-B.J.GI-)@LF6LXSX@LF"R(+!@L2"HH+<@K>!0@""L8+,
MDFR"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"`(*Q@LR#18-"@Y.#:(-%
M@LV#28-V@U:#AX.3@T6#0H.3@VB#18*I@N>,Q(]O@K."ZH+IE4N7=H*J@J""
MZ(+<@K>!0@"6V)=J`(KZBM0`@UZ#0X.`@U:!6X-G`(KZBM0`7TR57)'H`)5<
MD>@`E:&0E(+,C8"6VH+PD4F1\(*W@NF"R8+-@4%00X+%@LU#;VYT<F]L@TR#
M0X%!36%C@LB"YT-O;6UA;F2#3(-#@O")GX*U@LB"JH+G@TZ#BH-B@TZ"M8+<
M@K>!0@"-H9/Z`):^D_H`B<X`B<Z7:@!61E,@@W2#0(-#@XL@(B5S(B""S(-!
M@TZ#6H-8C*""S97/C5B"Q8*K@MR"N8+Q@4(`5D93((-T@T"#0X.+("5S+R5S
M((+,@T&#3H-:@UB,H(+-E<^-6(+%@JN"W(*Y@O&!0@`E<R""R97/C5B"Q8*K
M@MR"N8+Q@4(`4U-,((+%D-J1L8+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XN"
M\(-2@W.!6X+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*("(E<R(@@O"-
M[)"L@L6"JX+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XJ"\(WLD*R"Q8*K@MR"
MN8+Q@4(`5D93((-T@T"#0X.+@O"-[)"L@L6"JX+<@KF"\8%"`(OS@LP@5D93
M((-T@T"#0X.+@O"-[)"L@L6"JX+<@KF"\8%"`(-F@5N#7H+PB+./:X+%@JN"
MW(*Y@O&!0@`B)7,B@O"-[8^<@L6"JX+<@KF"\2X@@V:#0H.,@TZ#9X.*@JJ+
M\X+%@LV"H(+H@MR"N8+Q@4(`(B5S(B""\(WMCYR"Q8*K@MR"N8+Q@48E<P`E
M<X+PC>V/G(+%@JN"W(*Y@O$N((-F@T*#C(-.@V>#BH*JB_."Q8+-@J""Z(+<
M@KF"\8%"`"5S((+PC>V/G(+%@JN"W(*Y@O&!0@"/V):^CY&"S(_:C=>"JH[F
M@NB/;X*Y@MR"N8+Q`(BSCVN/D8S)@W2#0(-#@XN"\(I*@J^"W(*Y@O&!0@!V
M9G-R;V]T((-F@T*#C(-.@V>#BH+PD\>"WX+<@KF"\8%"`"5S((*S@O&"S)=<
MDNB/[I7Q@O"/BI.^@L6"JX+<@KF"\0""L8+,(%=O<F0@E;:/D8+PEGR6\X+%
M@JN"W(*Y@O&!0@")NI#\`)7/C5B"\([F@NB/P8*W`(RS@LF6WX*W`):BD*Z7
MG0"5<Y:^`):SEKP`@U2#?(%;@V>"M8+$@J*"R(*BBF>2HXYQ@L6"MP"-6)!6
M`"5S((+PC5B05H*W@NF!0@"#AH%;@U6"\(U8D%:"MX+I`(.)@V6#DY6VCIJ!
M:9'EE;:.FH%J`(.-@5N#?9"4CIJ!:9'EE;:.FH%J`(R[C=V"S))L@O".9Y=P
M@48E<P!)35-0((-4@5N#;X+,@X:!6X-5EKR!7H-P@UB#CX%;@VB"JHC9@LB"
MZ8_JC8>"R8YGEW""M8+<@K>!0@"#AH%;@U6*QY>=`(.&@5N#58%;@T.#DX->
M@5N#=(-&@T.#6`"#AH%;@U6#28-V@U:#AX.3`(.&@5N#59-OF%X`@X:!6X-5
MEKP`@X:!6X-5EKPZ`(.&@5N#59:\.B``@U:#6(-E@X"2AH+,@X:!6X-5@48`
MBWB)R0"73(SXD*L`C)^/V(ZXE',@+2""L8+,@X&#8H-:@5N#5X+-B?SB@H*S
M@NJ"Q(*B@NF"YH*D@L6"MX%"`)3%`"5S((+PC*F"Z0",>(V0`)"%`)"%EVH`
MCU0`D>8E9(]4`(]4BM0`EHB/5`"6B(]4@4:,2H+HE=2"M0""YH*D@K&"NP`E
M<R""R8+F@J2"L8*[`"5S((*S@O&!08+F@J2"L8*[`"5S@XV#3X-#@Y.,XX+'
M@LR#08-V@XJ#4(%;@U:#AX.3@O"57(ZF@K6"W(*W@JF!2`"+YI#8@NB5MHZ:
M@LV)O8+%@K>"J8%(`(CXEW"5MHZ:@LV)O8+%@K>"J8%(`)/ZE5R.IH+&CU25
M7(ZF@LR/29>YCIZ*U(+-@4@`D_J57(ZF@L:/5)5<CJ:"S(I*CFZ.GHK4@LV!
M2`"#98-,@UB#9X-'@V:#0H->@5N"S(-V@XF#3X-#@Y."\)%)D?""M8+<@K>!
M0@"5G0"-MH+)DG6"K25S@X&#:H.%@5N"S)6=@6F.GXGQ@LR#C8-/@T.#DX*I
M@N>73(SX@6HZ`)5<@LR5G0"+SI:QD.:"S(]:CXH`B\Z6L9#F@LR39)ABE-2-
MA@",CHO@`%@U,#EV,R"*[I9[D*>,P`!8-3`Y=C,@C*Z.9Y=PED``6#4P.78S
M(([ED<R.TH+,E<J6O`!8-3`Y=C,@CN61S([2@LR,KHZOE<J.<0!8-3`Y=C,@
MBF>2HXM`E%P`E$X`E$X`EHB43@"6B)1.@4:,2H+HE=2"M0""S8*B`).OB-."
MM8+<@K<`C:&"S8-E@TR#6(-G@X*!6X-H@L6"MX%"6SP^78-[@UZ#DX+%1U5)
M@X*!6X-H@LF5SXU8@L6"JX+<@K>!0@""H(+(@KV"S91&C]B"LX+J@L2"HH+<
M@KF"\8%"`):\D4^"S)*&@LD@)UPG((+&@J*"I)6VCIJ"S8YG@J:"W(*Y@O&!
M0@"73(SX@LB39(YQ@X&!6X.+@T&#:(.,@UB"Q8+-@J""Z(+<@KF"\8%"`(-#
M@Y.#?(%;@V>"LX+J@KV#=(-`@T.#BX+,@W2#0H%;@XN#:(+P)7.3X(+,D<Z)
MGH*W@NF#=(-"@5N#BX-H@LF#?8-B@W:"M8+$@MR"N8+Q+@""H(+(@KV"R8+-
M@T.#>(.3@V>"\"`E<R""R9+'B<&"MX+IC*",P(*J@J""Z(+<@KF"\8%"`(*@
M@LB"O8+)@LV129'P@K6"O9=<DNB57(+)@T.#>(.3@V>"\)+'B<&"MX+IC*",
MP(*J@J""Z(+<@KF"\0""H(+(@KV"R8+-@K&"S(-#@WB#DX-G@O"-[8^<@K>"
MZ8R@C,""JH*@@NB"W(*Y@O&!0@""H(+(@KV"R8+-@K&"S(-#@WB#DX-G@O"5
MTH]7@K>"Z8R@C,""JH*@@NB"W(*Y@O&!0@"#C8-/@T&#18-G@K6"W(*U@KTN
M`)5SD+."R)=<DNB57(+PCG>2Z(*U@MR"M8*]@4(`D+."M8*BDFR"\)/\E\V"
MM8+$B;J"LX*B@4(`@U2#0X.3@T&#8H-V@O"7F)=P@K>"Z8*]@M^"R8+-($1A
M=&%4<F5E((-O@V*#3H-'@Y.#:(+PD-V2Z(*W@NF52Y=V@JJ"H(+H@MR"MRX`
MC^&*48+,D^"798+PBTR/<8*U@L2"J8+G@4&/X8I1@XR#?(%;@V>"\)&7D$V"
MM8+$@JV"OH*S@J*!0@""L8*Q@LF#BH.3@TZ"MX+I55),@O"3_)?-@K6"Q(FZ
M@K."H@"-[8^<@K>"Z8+7@JN77)+HE5R"\)%)D?""M8+$B;J"LX*B@4(`@T&#
M:(.,@UB"\(W%CXF"R9%)D?""M8+$B;J"LX*B@4(`C>V/G(*W@NF#5(%;@V^"
M\(YWDNB"M8+$@JV"OH*S@J*!0@"/P8N.@K>"Z8.&@5N#59:\@O".=Y+H@K6"
MQ(*M@KZ"LX*B@4(`C>V/G(*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."
MHH%"`)+'B<&"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0@"-6)!6
M@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`CL"-<X*W@NF#08-.
M@U:#AX.3@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`D%:"M8*BE:J7WI:\@O"3_)?-
M@K6"Q(FZ@K."HH%"`"5S((-:@V*#5H.'@Y."S)=,C/B*^HS`@JJ0V(+J@L2"
MHH+<@K>!0HW$@XV#3X-#@Y."M8+$@JV"OH*S@J*!0@"39(YQ@X&!6X.+@T&#
M:(.,@U@`@J""R(*]@LP@1G)O;3H@@T&#:(.,@U@`@J""R(*]@LR#0X.3@W2#
M2(.!@5N#5H.'@Y,`@UJ#8H-6@X>#DR`E<R""S(K4@LF"H(+(@KV"S(-!@VB#
MC(-8@JJ5SXU8@K."ZH+<@K6"O8%"@UJ#3(.%@XJ#98-"@5N5VXSL@LR"O8+?
M@LF#C8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(`@J""R(*]@LR6O)%/`(*Q@LR4
M1H_8@V^#8H-.@T>#DX-H@L6"S8%!@X:!6X-5@LR#BH-8@V>"JH-4@WR!6X-G
M@K."ZH+$@J*"R(*B@JF!08*@@NF"HH+-B;V"YX*I@LR7G9=2@L6"L8+,BT"4
M7(*JEK.,^(+)@LB"P8+$@J*"W(*W@4(`@UJ#8H-6@X>#DR`E<R""S(K4@LF"
MH(+(@KV"S(-U@XF#18-5@JJ5SXU8@K."ZH+<@K6"O8%"@UJ#3(.%@XJ#98-"
M@5N5VXSL@LR"O8+?@LF#C8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(`@UZ#0X.`
M@UV!6X.3@48`@V:#=(-(@XN#9Y=<DNB57`""H(+(@KV"S(-F@W2#2(.+@V=)
M1#H`@J""R(*]@LR.@9:\`(-)@W:#5H.'@Y."\(U8D%:"M8+<@K6"O0"#BH."
M@5N#9X-4@5N#;SH`@6V/X8I1@XR#?(%;@V>!;@!;EK.6O(-#@WB#DX-G70!;
MC7,Z)7,O)7-=`%]!BL>7G0!?0HK(B-6,GXWU`%]$C7."\(WMCYP`7T65TH]7
M`%]'B-J3K@!?1X-/@XN!6X-V`%](@W>#BX-V`%])B>:1G(-V@XV#<(-E@T(N
M+BX`7TF#0X.3+X-!@T6#9P!?3(.-@T^#0X.3`%],@XV#3X-!@T6#9P!?38.*
M@Y.#3I7/C5@`7TV.A(+,EUR2Z)5<`%].D%:#0X-X@Y.#9P!?3X-)@W:#5H.'
M@Y,`7U"#08-.@UJ#6(R@`%]0B/.-_`!?4H.*@Y.#3HWMCYP`7U.,GXWU`%]3
M@UJ#8H-G@T&#8H-V`%]4E5R1KI"K`%]4C:&3^@!?58.&@5N#50"#08-H@XR#
M6)*@`(-#@WB#DX-GBDJ.;I%/`)=<DNB57`""L8*Q@O"#3H.*@V*#3@"3^@"#
M=(-`@T.#BP"#EHR.`(+<@KZ.P)&5@K."ZH+$@J*"W(*Y@O$`DZ^"MI/Z@LD`
MDZ^"MI=JD_J"R0"#<(%;@UJ#DX-G`(-S@TZ#6H.+`(IME$:"S(*]@M^#<(-8
M@X^!6X-H,I-XD_R7S8*U@L2)NH*S@J(`EKR6LX*U`'9#87)D`(]4@4&3KX*V
MD_J"R0"43HK4````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O:71?
M250O````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-3$`,#(P-S`R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O
M;F]L:71H+VQO8V%L92]I=%])5"],0U]-15-304=%4R\`````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,0`P,C(T-C<`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+VET7TE4+TQ#7TU%4U-!
M1T53+VMR;VYO;&ET:"YM;P```````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,30Q,S`U`#$P-#$W,S8R-S4Q
M`#`R-3`S-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#>$@25`````#T#```<````!!H``%4$``#L,P```````$!%```$````
M044```P```!&10``"0```%-%```+````744``!\```!I10``*````(E%```5
M````LD4```L```#(10``'0```-1%```*````\D4```T```#]10``#@````M&
M```-````&D8``!T````H1@``'0```$9&```/````9$8``!@```!T1@``!P``
M`(U&```.````E48```X```"D1@``"````+-&```*````O$8```4```#'1@``
M"0```,U&```)````UT8```@```#A1@``$````.I&```*````^T8``!`````&
M1P```P```!='```/````&T<```D````K1P``"0```#5'```-````/T<``!D`
M``!-1P``#P```&='```/````=T<```T```"'1P``#P```)5'```(````I4<`
M``@```"N1P``&0```+='```,````T4<```X```#>1P```P```.U'```/````
M\4<```4````!2```"@````=(```4````$D@```H````G2```!0```#)(```*
M````.$@```,```!#2```#0```$=(```7````54@```H```!M2```"@```'A(
M```/````@T@```L```"32```!P```)](```-````IT@```H```"U2```#@``
M`,!(```7````ST@``!<```#G2```$P```/](```/````$TD```8````C20``
M`P```"I)```+````+DD``!4````Z20``!0```%!)```[````5DD``#D```"2
M20```@```,Q)```G````STD``"P```#W20``*@```"1*```E````3TH```H`
M``!U2@``"0```(!*```&````BDH``!$```"12@``"@```*-*```(````KDH`
M``P```"W2@``"````,1*```.````S4H```H```#<2@``!````.=*```)````
M[$H```8```#V2@``!P```/U*```&````!4L```0````,2P```P```!%+```)
M````%4L``!,````?2P``"0```#-+```(````/4L``!````!&2P``"0```%=+
M```$````84L``!D```!F2P``!@```(!+```5````ATL```D```"=2P``#0``
M`*=+```'````M4L```D```"]2P``%0```,=+```(````W4L```\```#F2P``
M#0```/9+```/````!$P```T````43```!@```"),```&````*4P``%0````P
M3```!````(5,```.````BDP``!P```"93```'0```+9,```2````U$P```H`
M``#G3```#P```/),```1`````DT```P````430``!@```"%-```&````*$T`
M`!$````O30``!0```$%-```,````1TT```4```!430``!@```%I-```6````
M84T```<```!X30``#0```(!-```*````CDT```P```"930``$````*9-```;
M````MTT```D```#330``"````-U-```$````YDT```X```#K30``$@```/I-
M```?````#4X``"`````M3@``)0```$Y.```'````=$X```8```!\3@``$@``
M`(-.```-````EDX``!````"D3@``!P```+5.```3````O4X```<```#13@``
M#````-E.```.````YDX```\```#U3@``$P````5/```-````&4\``"@````G
M3P```P```%!/```-````5$\```(```!B3P``$P```&5/```0````>4\```T`
M``"*3P```P```)A/```&````G$\```<```"C3P``#@```*M/```(````ND\`
M``\```##3P``"````--/```0````W$\```T```#M3P``!@```/M/```)````
M`E````P````,4```#````!E0```+````)E````T````R4```(@```$!0```*
M````8U```!@```!N4```&0```(=0``!<````H5```!8```#^4```#````!51
M```4````(E$```L````W40``"P```$-1```)````3U$```D```!940``!P``
M`&-1```6````:U$```\```""40``#0```))1```F````H%$``#D```#'40``
M#@````%2``!#````$%(``"\```!44@``!P```(12```(````C%(```<```"5
M4@``#@```)U2```*````K%(```H```"W4@``$````,)2```7````TU(``!4`
M``#K4@``#@````%3```1````$%,``!<````B4P``#0```#I3```(````2%,`
M``8```!14P``"````%A3```%````85,``#$```!G4P``$P```)E3```0````
MK5,```\```"^4P``$````,Y3```/````WU,```\```#O4P``#````/]3```/
M````#%0```<````<5```!@```"14```/````*U0```@````[5```$P```$14
M```$````6%0```@```!=5```"@```&94```,````<50```L```!^5```#```
M`(I4```'````EU0```0```"?5```"@```*14```-````KU0```4```"]5```
M"@```,-4```F````SE0``!4```#U5```!0````M5```'````$54```P````9
M50``"````"95```&````+U4```@````V50```@```#]5```&````0E4```8`
M``!)50``"0```%!5```0````6E4```D```!K50``"0```'55```&````?U4`
M``0```"&50``!P```(M5```9````DU4```X```"M50```@```+Q5```-````
MOU4```<```#-50``%````-55```&````ZE4``!$```#Q50``!@````-6```$
M````"E8```H````/5@``!````!I6```%````'U8```4````E5@``$@```"M6
M```+````/E8```<```!*5@``*0```%)6```D````?%8``"8```"A5@``"```
M`,A6```2````T58```H```#D5@``#P```.]6```0````_U8```X````05P``
M"0```!]7```*````*5<```8````T5P``&````#M7```/````5%<``!8```!D
M5P``$@```'M7```0````CE<``!$```"?5P``$````+%7```+````PE<``!0`
M``#.5P``#````.-7```,````\%<```\```#]5P``%0````U8```I````(U@`
M`"H```!-6```)@```'A8```G````GU@``!D```#'6```$0```.%8```2````
M\U@``!,````&60``%````!I9```6````+UD``!<```!&60``$````%Y9```1
M````;UD``!,```"!60``%````)59```:````JED```D```#%60``!@```,]9
M```'````UED``!8```#>60``!````/59```$````^ED```<```#_60``"```
M``=:```'````$%H```@````86@``#0```"%:```-````+UH```H````]6@``
M#````$A:```-````55H```X```!C6@``%@```'):```1````B5H```D```";
M6@``!@```*5:```$````K%H```H```"Q6@``'@```+Q:```0````VUH``!H`
M``#L6@``"@````=;```)````$EL```P````<6P``#P```"E;```(````.5L`
M``8```!"6P``!P```$E;```+````45L```,```!=6P``$P```&%;```"````
M=5L```0```!X6P``"@```'U;```8````B%L``&@```"A6P``!0````I<```&
M````$%P```\````77````P```"=<```'````*UP```<````S7```"0```#M<
M```+````15P```T```!17```&@```%]<``!*````>EP```8```#%7```!@``
M`,Q<```)````TUP``!(```#=7````@```/!<```+````\UP```@```#_7```
M"@````A=```&````$UT```4````:70``"@```"!=```3````*UT``!4````_
M70``#````%5=```-````8ET```P```!P70``"@```'U=```,````B%T```T`
M``"570``"0```*-=```0````K5T``!(```"^70``!````-%=```'````UET`
M``4```#>70``#````.1=```)````\5T``!<```#[70``!````!->```*````
M&%X```0````C7@``#0```"A>```(````-EX```H````_7@``"0```$I>```(
M````5%X```D```!=7@``!0```&=>```,````;5X``"4```!Z7@``+````*!>
M```+````S5X``!0```#97@``'````.Y>```3````"U\```@````?7P``"```
M`"A?```K````,5\``!P```!=7P``10```'I?``!!````P%\```0````"8```
M"0````=@```'````$6````4````98```"````!]@```#````*&```!$````L
M8```#@```#Y@```"````36````X```!08```!P```%]@```&````9V```!0`
M``!N8```'P```(-@```(````HV````<```"L8```#@```+1@```*````PV``
M`!T```#.8```!0```.Q@```1````\F````4````$80``$0````IA```(````
M'&$```T````E80``"````#-A```)````/&$```H```!&80``%0```%%A```0
M````9V$```4```!X80``!````'YA```'````@V$``!````"+80``!P```)QA
M```>````I&$``"@```##80``'@```.QA```*````"V(``!$````68@``"P``
M`"AB```:````-&(``!0```!/8@``!@```&1B```&````:V(``#0```!R8@``
M-````*=B```I````W&(``"D````&8P``!0```#!C```.````-F,``!D```!%
M8P``&0```%]C```(````>6,``!<```""8P``"@```)IC```'````I6,``"$`
M``"M8P``#````,]C```-````W&,```P```#J8P``#@```/=C```'````!F0`
M`!,````.9```"````")D```%````*V0```0````Q9```"@```#9D```)````
M060```X```!+9```!````%ID```R````7V0``$4```"29```"P```-AD```*
M````Y&0```\```#O9```$P```/]D```3````$V4```\````G90``#````#=E
M```.````1&4```T```!390``#0```&%E```4````;V4```<```"$90``#```
M`(QE```0````F64``!$```"J90``#@```+QE```J````RV4```8```#V90``
M"0```/UE```/````!V8```P````79@``$0```"1F```+````-F8```H```!"
M9@``"P```$UF```/````668```@```!I9@``$@```')F```%````A68```X`
M``"+9@``$P```)IF```(````KF8```<```"W9@``$0```+]F```4````T68`
M`!@```#F9@``!P```/]F```%````!V<``!(````-9P``#@```"!G```.````
M+V<```4````^9P``!0```$1G```#````2F<```T```!.9P```@```%QG```(
M````7V<```<```!H9P``"P```'!G```*````?&<```P```"'9P``4@```)1G
M```7````YV<```8```#_9P``#@````9H```-````%6@``!4````C:```$@``
M`#EH```/````3&@``!0```!<:```6````'%H```A````RF@``&D```#L:```
M&@```%9I```7````<6D``!D```"):0``&@```*-I```9````OFD``"4```#8
M:0``&@```/YI```7````&6H``!T````Q:@``)@```$]J```;````=FH``"H`
M``"2:@``&0```+UJ```?````UVH``!,```#W:@``$P````MK```(````'VL`
M``D````H:P``#````#)K```7````/VL```X```!7:P``/P```&9K```W````
MIFL``%<```#>:P``'P```#9L```0````5FP``!$```!G;```"````'EL```-
M````@FP``"T```"0;```!````+YL```5````PVP``#L```#9;```'P```!5M
M```E````-6T``"@```!;;0``'P```(1M```A````I&T``!T```#&;0``)0``
M`.1M```@````"FX``"0````K;@``,````%!N```'````@6X```T```");@``
M#````)=N```0````I&X```P```"U;@``!P```,)N```$````RFX``!<```#/
M;@``"@```.=N```,````\FX```D```#_;@``"`````EO```*````$F\```@`
M```=;P``"@```"9O```'````,6\```8````Y;P```@```$!O```)````0V\`
M``<```!-;P``*````%5O```5````?F\```<```"4;P``"````)QO```'````
MI6\```8```"M;P``!P```+1O```.````O&\```D```#+;P``!@```-5O```(
M````W&\```L```#E;P``!P```/%O```'````^6\```@````!<```$`````IP
M```0````&W````<````L<```!0```#1P```4````.G````L```!/<```#0``
M`%MP```7````:7````D```"!<```"0```(MP```*````E7````<```"@<```
M`@```*AP```?````JW```"0```#+<```(P```/!P```K````%'$``"$```!`
M<0``+P```&)Q```S````DG$``#H```#&<0``(P````%R```A````)7(``!\`
M``!'<@``*P```&=R```G````DW(``#(```"[<@``+0```.YR```G````'',`
M`"@```!$<P``)P```&US```Z````E7,``!\```#0<P``(@```/!S```+````
M$W0``"`````?=```!P```$!T```(````2'0```<```!1=```"@```%ET```-
M````9'0```L```!R=```"0```'YT```&````B'0```4```"/=```!0```)5T
M```(````FW0```,```"D=````@```*AT```'````JW0```0```"S=```!```
M`+AT```@````O70``!D```#>=```%````/AT```D````#74``!D````R=0``
M"0```$QU```,````5G4```<```!C=0``!0```&MU```:````<74```L```",
M=0``!@```)AU```)````GW4```L```"I=0``#````+5U```7````PG4```8`
M``#:=0``$P```.%U```3````]74```X````)=@``$0```!AV```R````*G8`
M``@```!==@``"0```&9V```*````<'8``!0```![=@``"````)!V```(````
MF78```\```"B=@``#@```+)V```0````P78```D```#2=@``"0```-QV```(
M````YG8``!D```#O=@``"@````EW```,````%'<```(````A=P``$````"1W
M```#````-7<```D````Y=P``!````$-W```'````2'<```<```!0=P``%```
M`%AW```'````;7<```T```!U=P``"P```(-W```O````CW<``"````"_=P``
M'````.!W``!(````_7<``$P```!&>```!0```)-X```2````F7@```H```"L
M>```!@```+=X```%````OG@```8```#$>```"0```,MX```"````U7@``!0`
M``#8>```#````.UX```O````^G@``$(````J>0``,````&UY```N````GGD`
M`!D```#->0``)P```.=Y```I````#WH``"$````Y>@``*````%MZ```I````
MA'H``"8```"N>@``)0```-5Z```H````^WH``!(````D>P``$P```#=[```0
M````2WL```D```!<>P``<P```&9[```K````VGL``!<````&?```%0```!Y\
M```6````-'P```\```!+?```%````%M\```0````<'P``!,```"!?```#P``
M`)5\```/````I7P```T```"U?```"0```,-\```+````S7P```4```#9?```
M!0```-]\```'````Y7P```4```#M?```%````/-\```.````"'T```@````7
M?0``#P```"!]```*````,'T```@````[?0``#````$1]```&````47T```\`
M``!8?0``!P```&A]```4````<'T```8```"%?0``!@```(Q]```7````DWT`
M``0```"K?0```P```+!]```&````M'T```0```"[?0``"@```,!]```$````
MRWT``!D```#0?0``!@```.I]```(````\7T```0```#Z?0``$````/]]```3
M````$'X```<````D?@``!@```"Q^```&````,WX```8````Z?@``(@```$%^
M```1````9'X```L```!V?@``!````()^```+````AWX```4```"3?@``!P``
M`)E^``!K`0``H7X```8````-@```"@```!2````)````'X````\````I@```
M(````#F````H````6H```!````"#@```"@```)2````>````GX````D```"^
M@```#P```,B````-````V(```!````#F@```*0```/>````9````(8$```D`
M```[@0``%@```$6!```(````7($```X```!E@0``#@```'2!```&````@X$`
M``D```"*@0``!0```)2!```%````FH$```8```"@@0``"0```*>!```0````
ML8$```P```#"@0``$0```,^!```(````X8$``!4```#J@0``#P````""```-
M````$((``!4````>@@``)````#2"```8````68(``!D```!R@@``%0```(R"
M```8````HH(```T```"[@@``#P```,F"```L````V8(```<````&@P``#P``
M``Z#```*````'H,``!`````I@P``!P```#J#```/````0H,``!D```!2@P``
M!P```&R#```,````=(,```T```"!@P``!0```(^#```4````E8,``!P```"J
M@P``#P```,>#```.````UX,``!````#F@P``#@```/>#```/````!H0```\`
M```6A```$````":$```4````-X0``!<```!,A```&P```&2$```7````@(0`
M`!(```"8A```"````*N$```)````M(0```P```"^A```%P```,N$```&````
MXX0``$````#JA```/````"N%```$````:(4``#0```!MA0``-0```**%```P
M````V(4``#`````)A@``#````#J&```,````1X8```8```!4A@``$@```%N&
M```&````;H8```@```!UA@``#@```'Z&```*````C88``!,```"8A@``#@``
M`*R&```)````NX8```D```#%A@``!P```,^&```'````UX8```4```#?A@``
M"0```.6&```#````[X8```L```#SA@``&0```/^&```+````&8<```H````E
MAP``%P```#"'```)````2(<```4```!2AP``(@```%B'```(````>X<``!P`
M``"$AP``"0```*&'```-````JX<```<```"YAP``"@```,&'```5````S(<`
M``D```#BAP``%0```.R'```/`````H@``!4````2B```#0```"B(```&````
M-H@```@````]B```=````$:(```$````NX@``!$```#`B```)````-*(```C
M````]X@``!(````;B0``#@```"Z)```C````/8D``!4```!AB0``$@```'>)
M```&````BHD```8```"1B0``$@```)B)```&````JXD``!````"RB0``"```
M`,.)```(````S(D``!H```#5B0``!P```/")```0````^(D```H````)B@``
M#````!2*```1````(8H``"0````SB@``"@```%B*```(````8XH```4```!L
MB@``$@```'**```<````A8H``"@```"BB@``*0```,N*```\````]8H```4`
M```RBP``!````#B+```4````/8L``!0```!2BP``$````&>+```&````>(L`
M`!0```!_BP``"````)2+```+````G8L``!````"IBP``#0```+J+```4````
MR(L```T```#=BP``-0```.N+```&````(8P``!`````HC````@```#F,```;
M````/(P``!````!8C```#0```&F,```&````=XP```D```!^C```"````(B,
M```0````D8P```@```"BC```#P```*N,```)````NXP``!4```#%C```$0``
M`-N,```'````[8P```L```#UC```#@````&-```-````$(T```T````>C0``
M#P```"R-```7````/(T```L```!4C0``'@```&"-```;````?XT``&,```";
MC0``&````/^-```,````&(X``!0````EC@``"P```#J.```(````1HX``!``
M``!/C@``"````&".```*````:8X``!X```!TC@``%P```)..```-````JXX`
M`"L```"YC@``/@```.6.```-````)(\``$X````RCP``,P```(&/```)````
MM8\```8```"_CP``"P```,:/```5````TH\```\```#HCP``#P```/B/```1
M````")```!@````:D```&0```#.0```5````39```!4```!CD```&````'F0
M```/````DI````P```"BD```"@```*^0```.````NI````8```#)D```8P``
M`-"0```1````-)$```X```!&D0``#0```%61```/````8Y$```T```!SD0``
M#0```(&1```+````CY$``!(```";D0``"@```*Z1```'````N9$``!(```#!
MD0``"0```-21```I````WI$```8````(D@``"`````^2```-````&)(```\`
M```FD@``$````#:2```,````1Y(```8```!4D@``!0```%N2```+````89(`
M``\```!MD@``!0```'V2```+````@Y(``"H```"/D@``(````+J2```&````
MVY(```@```#BD@``#````.N2```(````^)(```4````!DP``!P````>3```#
M````#Y,```8````3DP``!P```!J3```$````(I,``!0````GDP``"@```#R3
M```-````1Y,```8```!5DP``!0```%R3```(````8I,``!D```!KDP``#P``
M`(63```%````E9,```X```";DP``"````*J3```6````LY,```8```#*DP``
M#P```-&3```'````X9,```4```#IDP``"````.^3```$````^),```8```#]
MDP``!0````24```7````"I0```P````BE```!@```"^4```:````-I0``!\`
M``!1E```&````'&4```'````BI0``!@```"2E```"@```*N4```/````MI0`
M`!,```#&E```$@```-J4```,````[90```P```#ZE```"`````>5```;````
M$)4``!$````LE0``&@```#Z5```3````694``!````!ME0``&````'Z5```2
M````EY4```P```"JE0``&P```+>5```5````TY4``!$```#IE0``&@```/N5
M```8````%I8``#`````OE@``-````&"6```M````E98``#$```##E@``(0``
M`/66```4````%Y<``!4````LEP``%0```$*7```7````6)<``!@```!PEP``
M&0```(F7```3````HY<``!0```"WEP``&P```,R7```6````Z)<``!````#_
MEP``"@```!"8```'````&Y@```<````CF```&````"N8```&````1)@```8`
M``!+F```#````%*8```-````7Y@```@```!MF```!@```':8```-````?9@`
M``\```"+F```"P```)N8```-````IY@``!4```"UF```$@```,N8```8````
MWI@``!,```#WF```$`````N9```'````')D```@````DF0``#P```"V9```I
M````/9D``!T```!GF0``*@```(69```*````L)D```8```"[F0``#````,*9
M```,````SYD```4```#<F0``!0```.*9```$````Z)D``!H```#MF0``!0``
M``B:```7````#IH```(````FF@``!0```"F:```8````+YH``!H```!(F@``
M5@```&.:```%````NIH```<```#`F@``%````,B:```&````W9H```@```#D
MF@``!@```.V:```-````])H```P````"FP``#0````^;```6````'9L``"4`
M```TFP``!P```%J;```&````8IL```8```!IFP``%@```'";```#````AYL`
M``L```"+FP``"````)>;```,````H)L```8```"MFP``!````+2;```/````
MN9L``!@```#)FP``&P```.*;```+````_IL```H````*G```%0```!6<```+
M````*YP```X````WG```#P```$:<```+````5IP``!<```!BG```%P```'J<
M```$````DIP```0```"7G````P```)R<```/````H)P```P```"PG```'0``
M`+V<```'````VYP``!$```#CG```"````/6<```/````_IP``!$````.G0``
M#P```""=```4````,)T``!$```!%G0``%````%>=```%````;)T``!,```!R
MG0``+0```(:=```H````M)T``!0```#=G0``&0```/*=```:````#)X``"``
M```GG@``#@```$B>```+````5YX``#8```!CG@``+P```)J>``!4````RIX`
M`$X````?GP``!P```&Z?```+````=I\```T```""GP``!````)"?```(````
ME9\```,```">GP``$0```**?```/````M)\```(```#$GP``#````,>?```'
M````U)\```<```#<GP``%@```.2?```J````^Y\```D````FH```!P```#"@
M```.````.*````D```!'H```%````%&@```%````9J```!(```!LH```#```
M`'^@```9````C*````H```"FH```$@```+&@```(````Q*````D```#-H```
M"@```->@```A````XJ```!4````$H0``!P```!JA```(````(J$```<````K
MH0``&````#.A```+````3*$``"0```!8H0``+@```'VA```G````K*$```@`
M``#4H0``#P```-VA```(````[:$``!P```#VH0``%@```!.B```$````*J(`
M``4````OH@``)P```#6B```C````7:(``"D```"!H@``+@```*NB```(````
MVJ(```\```#CH@``(@```/.B```@````%J,```D````WHP``'@```$&C```+
M````8*,```D```!LHP``*0```':C```1````H*,``!0```"RHP``$0```,>C
M```1````V:,```@```#KHP``&````/2C```(````#:0```<````6I```!P``
M`!ZD```.````)J0```T````UI```#P```$.D```%````4Z0``$,```!9I```
M3@```)VD```+````[*0```H```#XI```#P````.E```7````$Z4``!@````K
MI0``$@```$2E```5````5Z4``!,```!MI0``&````(&E```3````FJ4``"0`
M``"NI0``!````-.E```-````V*4``!````#FI0``$0```/>E```-````":8`
M`"H````7I@``!P```$*F```*````2J8``!0```!5I@``#@```&JF```5````
M>:8```P```"/I@``"@```)RF```.````IZ8``!(```"VI@``#````,FF```6
M````UJ8```<```#MI@``$````/6F```7````!J<```@````>IP``"0```">G
M```3````,:<``!D```!%IP``&````%^G```'````>*<```8```"`IP``&```
M`(>G```4````H*<``!0```"UIP``!@```,JG```&````T:<```8```#8IP``
M#````-^G```#````[*<```8```#PIP``"````/>G```0`````*@```P````1
MJ```#0```!ZH``!:````+*@``!T```"'J```!0```*6H```1````JZ@``!(`
M``"]J```(````-"H```?````\:@``!,````1J0``(0```"6I``!:````1ZD`
M`"P```"BJ0``<P```,^I```B````0ZH``!\```!FJ@``(P```(:J```?````
MJJH``"(```#*J@``)@```.VJ```C````%*L``!L````XJP``*````%2K```U
M````?:L``",```"SJP``+````->K```?````!*P``",````DK```'````$BL
M```3````9:P```D```!YK```"0```(.L```7````C:P``"@```"EK```&```
M`,ZL```_````YZP``"\````GK0``7@```%>M```M````MJT``!,```#DK0``
M%````/BM```(````#:X```\````6K@``+0```":N```&````5*X``!\```!;
MK@``0P```'NN```O````OZX``"(```#OK@``-````!*O```O````1Z\``#,`
M``!WKP``(0```*NO```A````S:\``!L```#OKP``(`````NP``!+````++``
M``H```!XL```$@```(.P```0````EK```!(```"GL```%0```+JP```*````
MT+````0```#;L```$@```."P```,````\[````X`````L0``"P````^Q```(
M````&[$```X````DL0``"P```#.Q```-````/[$```8```!-L0``!@```%2Q
M```#````6[$```L```!?L0``"````&NQ```:````=+$``!<```"/L0``"0``
M`*>Q```$````L;$```@```"VL0``"````+^Q```$````R+$```T```#-L0``
M!@```-NQ```(````XK$```H```#KL0``"P```/:Q```(`````K(```H````+
ML@``"@```!:R```1````(;(``!$````SL@``#0```$6R```(````4[(``!@`
M``!<L@``"P```'6R```-````@;(``!@```"/L@``"P```*BR```*````M+(`
M`!(```"_L@``#0```-*R```#````X+(``"````#DL@``+0````6S```E````
M,[,``"T```!9LP``(P```(>S```S````J[,``#X```#?LP``.````!ZT```C
M````5[0``"(```![M```(````)ZT```W````O[0``"@```#WM```)@```""U
M```P````1[4``#T```!XM0``00```+:U```H````^+4``"D````AM@``(```
M`$NV```J````;+8```T```"7M@``+````*6V```%````TK8```<```#8M@``
M!@```."V```2````Y[8``!(```#ZM@``"P````VW```2````&;<```8````L
MMP``!@```#.W```$````.K<```8````_MP``!````$:W```#````2[<```<`
M``!/MP``!````%>W```$````7+<``"8```!AMP``'@```(BW```9````I[<`
M`"H```#!MP``'@```.RW```*````"[@``!0````6N```#@```"NX```%````
M.K@``!D```!`N```#@```%JX```(````:;@```L```!RN```#P```'ZX```/
M````CK@``"(```">N```"````,&X```1````RK@``!8```#<N```$@```/.X
M```4````!KD``#@````;N0``"P```%2Y```,````8+D```P```!MN0``$P``
M`'JY```'````CKD```D```"6N0``$@```*"Y```,````L[D``!4```#`N0``
M"@```-:Y```*````X;D``!$```#LN0``(0```/ZY```*````(+H```P````K
MN@```P```#BZ```0````/+H```,```!-N@``"0```%&Z```)````6[H```P`
M``!EN@``#````'*Z```?````?[H```D```"?N@``#@```*FZ```-````N+H`
M`#````#&N@``'@```/>Z```@````%KL``%<````WNP``60```(^[```)````
MZ;L``!8```#SNP``#P````J\```*````&KP```8````EO```!P```"R\```4
M````-+P```(```!)O```&P```$R\```2````:+P``"X```![O```0P```*J\
M```K````[KP``#`````:O0``'@```$N]```I````:KT``"L```"4O0``)```
M`,"]```H````Y;T``"H````.O@``*@```#F^```K````9+X``"L```"0O@``
M$P```+R^```3````T+X``!,```#DO@``"P```/B^``"'````!+\``"D```",
MOP``&P```+:_```<````TK\``!,```#OOP``#`````/````5````$,```"<`
M```FP```%P```$[````3````9L```!````!ZP```#P```(O````)````F\``
M``T```"EP```"0```+/````&````O<````<```#$P```!@```,S````;````
MT\```!````#OP```#@````#!```2````#\$```T````BP0``"````##!```)
M````.<$```<```!#P0``$````$O!```&````7,$``!@```!CP0``!0```'S!
M```'````@L$``!D```"*P0``!0```*3!```&````JL$```D```"QP0``!@``
M`+O!```*````PL$```(```#-P0``&````-#!```&````Z<$```<```#PP0``
M!````/C!```0````_<$``!@````.P@``"````"?"```&````,,(```L````W
MP@``"````$/"```K````3,(``!,```!XP@``"P```(S"```)````F,(``!``
M``"BP@``"0```+/"```'````O<(```$```#)`@``'0(`````````````=0(`
M`/<!``"&`0```````)L"``!6````.@$```````#_```````````````:`@``
M5````.`"``#J````-P```,X!``#```````````````#2````@@$``-0`````
M`````````,X```!,`@``K0```",!``"B``````````````#V`0``10$``#@#
M````````1````.P!```&````5@$````````S`P``3``````````I`P``C```
M`),```#/````:0(```,#``"Y````?@```/8"``")`````````#<"``#&````
M2P$``.(```#<````*P(`````````````-@,``,<```!E`0``>`````````"3
M`@`````````````(````L@```*0!```B`@``AP$````````>````_```````
M```Q`0``G@(```````#R````>P``````````````C0(``#4`````````P@``
M`,@"``"H````-P$`````````````A0(``&4```#I```````````````!`@``
MKP(``*0"``#S`@``!````.T`````````)P(`````````````@@(``-,`````
M`````````)("```4`@``#@$````````Z`@```P$``-P!``"K`0``V````$0"
M````````G0(````````5`P``$P```#$#``````````````\!```4`P``<P(`
M``````#5`0``IP```,@!``"W`@``G````.H!````````N`````````#>`0``
M/`$``,0"``!3`@``BP(```````"0`0``D0$``/4!```N`P``)0,```````#%
M`0````````````#I`@``8P$```````#0`0``C0```&0!``"Y`@``````````
M```A`P``;0(``!`"``!1`@```````!D```"F`0```````+L"```'`P``B@$`
M`$(!``"``0``?````"H#````````8@(``.\"````````&P```/@"``!]````
M,`````8!````````:@$``#(````%`@```````(P!``!=````80(```0"``#*
M`@``J`(```P"``".`0``T0$```````!_`@``$P,``$H```"7`0``?0(`````
M``#W`@``G0$```<"``#6````G@```-<!``#F`@``%@,``*P```"X`0``$@$`
M``````"Q````^P```'X!``##`@``L@$``'0!``!T`@``W0```%`"```+`@``
M`````)(!``!_`0``4P$``)8!``"A`@``/0$``+("``#C`0`````````````"
M`P``40$``+T```#U`@``GP(``"P!```-````!0```"T````%`0``F`$``#X"
M```+`````````/H"``#,````8P````````#+````(@,``((````O`@``20$`
M`!4"```N`@```````(,```#C````^@```$0!```)`P``!`,``"L#``"\`@``
MI@```%8"```D`@``3P$``+X!```@````0P(``%@"````````%0````````"L
M`@``<`$``/D!``#*````<0```/4```"S`0```````)L`````````````````
M```+`P``BP$``#L```#I`0```@`````````!`0```````!@!```+`0``S0$`
M``````"$`0````(```````#,`@``D0`````#``!]`0``,P(``/X"```U`P``
M"@$``"P"``"M`0``EP```'$"`````````````"T!````````;0``````````
M`````````$,!````````ZP(``'H"````````L`$``#D#``#!`0``V0$``"D`
M`````````````'P!``!<`@``K@$```````!7`0```````+`````\`P``4@(`
M`.,"``"_`0``G`$``#L!``"8`@``M````&<!```U`0``4````,("``"_`@``
M-0(```````#2`0```````!,!``"S````N@```-P"````````````````````
M````,P$````````1`@```````!\#``#!````,0```#D!```K`0``B````$$`
M``#Q`0``=@(``!8```#7`@``:@```$@!``"I`0``````````````````2P``
M`,<"```N`0```````"<```!=`@``#@,```````!D`@``$`,``,\!```9`0``
M50(```````#5````<P```+4"```@`@``V@(````````D````4@$``&\!```0
M`0``&0(``"$```#\`0``J@``````````````:P$```````#+`@```````$8!
M`````````````&@!``"!````7P```)0!``#A`0``[````(8"``"9`0``````
M`#<#```)`````````"<!``"Z`0``J@(``*````!=`0```````(,!````````
MVP```'4`````````7@(``'@"``!Z```````````````D`P``;P````````#^
M`0``$@``````````````[@```,X"```>`P``\0```,,`````````WP```$L"
M``!2````+0,``)X!````````R`````````#2`@``&@```'(```".````Y@$`
M`&P!``#@`0``#@(``/8```"6````M`$```````"E`@``3@```#`"````````
MO`$``.8````Z````[0(``$<!``!S`0``N`(``,4```"A````1P```!<```#;
M`0```````'8!``"4````R0$`````````````SP(```````!H`@``]`$``)D`
M``!<`0``CP````("``#-````Q@(``&L````-`P``/P$```````!&`@``D`(`
M`#X```"I`````````%\!````````K0(``.T!````````````````````````
M60```)$"```S``````$``,,!``!H````:P(````````:`P````````````!F
M````9@$``(P"``!P````%P$``"4`````````O````-8!``!Q`0``)@(``'\`
M```=`P``$````/X````C````5P```#(#```,````CP$```````"V````````
M`"\```!N`0``,@(`````````````'P```(D"````````'0```+H"``!@````
M6````$P!``!.`@``E0(``!<"``#_`@``[P```#`#``#G`@``+@```!$!````
M````:0$``+T"``")`0``"`,``&P```!E`@``^`````````#W````````````
M``!;````>@$``)H!````````(`,``"8#``#H````3P(````````X`0``(P(`
M``````!W````GP$``)P"``!B`0```````&X````I`0``*`(```````#P````
M`0,```````!<````NP````````!J`@``_0```'X"``!;`0``50```"@#``!-
M`0``Y0(``"H"````````)0$``'4!````````4`$``*4!``!R`0``X```````
M````````MP$``,8!``!\`@````````````"+````10(`````````````````
M`(\"```J````]````)T``````````````-4"```8````30(```````"4`@``
MV`$`````````````!@(``+4!```@`0``A@````````"V`0``B`$```````!:
M`0``-`(``!H!``"%`0``@`(``'0```"V`@``%P,```````#``@``Q0(``/D`
M````````.`(``(<"``"[`0``"@,``````````````````&$````=`0``````
M`$4`````````00(``````````````````#8```!W`0``$0```%L"``#!`@``
M\P$``-D"````````\`$``(``````````\P```#P"```V`@``=@```-$"````
M````HP````````!:`@``[@(``%\"``"*`@``>0(``#8!``"A`0``J0(``,H!
M`````````````/L"```2`P``,`$``.L!``"H`0``>`$``#X!``#D````+`,`
M```````G`P``MP```.H"``#R`0```@$``$8````?`0``(P,````````4`0``
M.````*<"````````QP$``-\"```;`0``5`$```````"@`@``#0$``)H`````
M````FP$````````<`P``V0````````"N````/0(``+$"``"Y`0``I0```+X`
M````````00$``"$"``!.`0``K`$```````"C`0``.@,````````T`0``9P(`
M`$`"```*````OP```%,```#3`@```````*("`````````````*\```!)````
M3P```)\`````````0`$``)4!``"#`@``6@```"@````O`P``UP````````#:
M`0``"@(``#L"``#L`@```````.@"````````&0,```````"G`0``(@$``-8"
M``![`@``!@,``-0!`````````````$,````;`P``=P(``#D"``"9`@``R0``
M`!0````<`@```````(H```!N`@``2`(``'L!``#D`0``L`(```\`````````
M`````.@!````````5`(```````````````````````":`@``-`,```````"U
M````#`,`````````````%@(`````````````5P(``#(!`````````````#D`
M``"2````#0(``($"``!*`@``60$``````````````````.$````I`@``````
M`"L```#B`0``!`$````````>`@``;`(```````!Y`0``%0$```````#E````
M#P,``$T````_`````````*,"`````````````"P```!`````O@(``#L#``#:
M````^`$``-\!`````````````.4!``#,`0``````````````````)0(``%$`
M```<````&`(```````"(`@``AP```````````````````%@!``"D````1P(`
M```````<`0```````,T"```B`````````&`!````````^0(``.\!```T````
MYP```&\"``!@`@``,0(``%X!``!I````Y`(```P!````````"`(``(X"``#$
M`````````.$"``#1````9````/0"``#3`0``7@```*`!```A`0``````````
M```````````````````F`0``_0(``.X!````````&`,``.<!``#\`@``20(`
M`"H!```3`@``%@$````````#`@``DP$``-@"````````9@(````````2`@``
M'@$``-X````]````T`(``"@!``"5`````````!\"``"T`@``<@(````````)
M`0``^@$```````#+`0``"0(```````#K````+P$```@!```1`P```````$("
M``"0````@0$``&,"````````K@(``/`"``!(````50$```````#4`@``2@$`
M`*\!``"$`@``T`````````"F`@``X@(``%D"```'`0````````````"%````
MP@$```````#=`0``/0,``&(`````````&P(``"8```"Q`0``_0$``+,"``#`
M`0````````````#Q`@``+0(``-X"````````<`(``*H!````````^P$``'D`
M``#_`0``\@(``-T"`````````P````````!M`0``A````*L"````````JP``
M``4#```/`@``/P(``$(`````````)`$``#P`````````C0$````````'````
M9P```,0!``"6`@```````+T!``#;`@```````*(!``!A`0``EP(``)@````.
M`````"!A="``)60@)7,@86YD("5S`"5D(&5V96YT<P`E<R`M($YO=&EC90`E
M<R!$87DH<RD@)7,@2&]U<BAS*2`E<R!-:6YU=&5S`"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%T("5S("5S`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D
M`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S
M($-A;&5N9&%R`"H@061D('1H97-E(&)Y(&-L:6-K:6YG($%D9"`J`"H@4&QE
M87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN9R`E<R`E<P`L('9A
M<FEA8FQE(&9R;VT@)7,@=&\@)7,`,2!E=F5N=``Q,B!(;W5R($9O<FUA=``R
M-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!32!3:&]W97)S`$%-+U!-`$%B<V)O
M='1O;0!!8G-M:61D;&4`06-C97!T960`06-C;W5N="!087-S=V]R9`!!8V-O
M=6YT:6YG`$%D7W9A;F-E9"!396%R8V@`061D`$%D9"!#:&EL9"!'<F]U<`!!
M9&0@179E;G0`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D(&$@;F5W(%)E
M;6]T92!#86QE;F1A<@!!9&0@82!N97<@979E;G0`061D(&$@;F5W('5S97(Z
M`$%D9"!A='1E;F1E97,`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!U
M<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<R!";V]K`$%D
M;6EN:7-T<F%T:6]N`$%D<P!!9'9A;F-E9"!396%R8V@`06QA<FT`06QA<FT@
M1&%T90!!;&%R;2!3<&%N("AM:6YU=&5S*0!!;&%R;2!4:6UE`$%L:6=N`$%L
M:6=N;65N=#H`06QL`$%L;"!!='1E;F1E97,`06QL($%U=&AE;G1I8V%T960@
M57-E<G,`06QL($9U='5R90!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!
M;&P@5FES:6)L90!!;&P@9&%Y`$%L;"!D87D@979E;G0`06QL(&5V96YT<P!!
M;&P@9F]U<B!S:61E<P!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA
M=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T
M92!T97AT.@!!;G-W97(`06YY`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES
M(')E861Y+@!!<')I;`!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`070`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&%N8V4`071T
M96YD965S`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!"86-K9W)O=6YD`$)A
M<V5L:6YE`$)A<VEC(%-E87)C:`!":7)T:&1A>0!";&]C:R!3971T:6YG<P!"
M;&]C:R!4>7!E`$)O;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97)S`$)O='1O
M;0!"=7-Y`$--4P!#7V%L96YD87(`0U]E;&P@4')O<&5R=&EE<RXN+@!#86Q?
M96YD87(`0V%L96YD87(`0V%L96YD87(@4W5M;6%R>0!#86QE;F1A<G,`0V%L
M;0!#86XG="!C<F5A=&4@82!N97<@979E;G0N`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N8V5L;&5D`$-A;F-E;&QE9#H@)7,`0V%P=&EO;@!#
M871E9V]R7WD`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A=&5G;W)Y`$-E;&P@
M4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL
M('-P86-I;F<Z`$-E;G1E<@!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@>6]U<B!D969A=6QT(&-A
M;&5N9&%R+@!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U
M<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-L;W5D
M<P!#;&]U9'D`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L;W(@4&EC:V5R
M`$-O;',Z`$-O;6EC<P!#;VUM82!S97!A<F%T960@=F%L=65S`$-O;6UA;F0`
M0V]M;6%N9"!3:&5L;`!#;VYD:71I;VYS`$-O;F9I9W5R92`E<P!#;VYF:7)M
M(%!A<W-W;W)D`$-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S/P!#;VYF:7)M
M960`0V]N=&EN=64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@;W!E
M;B`E<RX`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN`$-O=7)S97,`0W)E871E`$-R96%T92!A($YE
M=R!%=F5N=`!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E
M9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-U<G)E;G0`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO
M;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!$1`!$86EL>3H@4F5C
M=7)S(&5V97)Y`$1A=&%4<F5E($)R;W=S97(`1&%T92!296-E:79E9`!$87D`
M1&%Y*',I`$1E7VQE=&4`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA
M;"!N=6UB97)S`$1E8VQI;F5D`$1E9F%U;'0@0V%L96YD87(`1&5F875L="!#
M;VQO<@!$96QE=&4`1&5L971E("5S`$1E;&5T92!%=F5N=`!$96QE=&4@1W)O
M=7``1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@
M86QT97)N871E('1E;7!L871E`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D
M(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H
M92!C=7)R96YT(&5V96YT(&]N;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL
M(&9U='5R92!O8V-U<F5N8V5S+"!O<B!A;&P@;V-C=7)E;F-E<S\`1&5L971E
M('1H92!C=7)R96YT(')O=P!$97-C<FE?<'1I;VX`1&5S8W)I8F4@=&AE(%!R
M;V)L96T`1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1I<F5C
M=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/
M<'1I;VYS`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@=&\@<VAO=R!T87-K<R!W:&EC
M:"!A<F4@9'5E(&]N('EO=7(@8V%L96YD87(_`$1O97,@;F]T(')E8W5R`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@4$A0('-C<FEP="X`1'5E.B`E<P!$=7)A=&EO;@!%9&ET
M("5S`$5D:70@071T96YD965S`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET
M(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@4F5M
M;W1E($-A;&5N9&%R<P!%9&ET(&%T=&5N9&5E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%;6%I;"!!9&1R97-S`$5N9"!$
M871E`$5N9"!/;@!%;F0@5&EM90!%<G)O<@!%<G)O<B!R971R:65V:6YG(&9R
M964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,Z("5S`$5V96YT(&9R;VT@)7,@
M=&\@)7,`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@
M,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@:&%L9B!H;W5R`$5V
M97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!O<G0`17AP
M;W)T($-A;&5N9&%R`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I
M<@!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R
M<P!&:6QE($UA;F%G97(`1FEL=&5R<P!&:6YD`$9I<G-T($AA;&8`1FER<W0@
M475A<G1E<@!&;&]A=`!&;VYT($-O;&]R`$9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M
M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)U;7,`1F]R=V%R
M9',`1G(`1G)A;65S`$9R:61A>0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO
M;@!&=6QL($UO;VX`1G5L;"!.86UE`$9U='5R90!'86UE`$=E;F5R86P`1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!';P!';V]G
M;&4@4V5A<F-H`$=O=&\@)7,`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7!S
M`$=U97-T(%!E<FUI<W-I;VYS`$AE:6=H=`!(96QP`$AE;6ES<&AE<F4`2&EG
M:`!(;U]M90!(;W)D90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`
M2&]U<BAS*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`
M25]N<V5R="!2;W<@0F5F;W)E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT
M`$ED96YT:71Y)W,@;F%M93H`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM
M86=E(%523#H`26UA9V5S`$EM<&]R="!#86QE;F1A<BP@4W1E<"`E9`!);7!O
M<G0L(%-T97`@)60`26UP;W)T+T5X<&]R="!#86QE;F1A<@!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!)
M;F1I=FED=6%L(%5S97)S`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK
M`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&-E;&P@
M869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`
M26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T('!A<F%G<F%P:"!A9G1E<@!)
M;G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R
M="!R;W<@8F5F;W)E`$EN<V5R="]-;V1I9GD@26UA9V4`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV96YT;W)Y
M`$ET86QI8P!*86YU87)Y`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2G5L>0!*
M=6YE`$IU<W1I9GD`2V5Y=V]R9',`3&%?>6]U=`!,86YG=6%G90!,87-T(#(T
M(&AO=7)S`$QA<W0@36]D:69I960`3&%S="!-;VYT:`!,87-T(%%U87)T97(`
M3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F
M<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA<W0@=V5E:P!,87EO=70`3&5F
M=`!,:6=H="!286EN`$QI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.@!,
M:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI
M=&5R871U<F4`3&]?8V%T:6]N`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I
M;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]W`$QO
M=V5R(')O;6%N(&YU;6)E<G,`34T`36%I;`!-86EL($%D;6EN`$UA;F%G92!R
M96UO=&4@8V%L96YD87)S+@!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87)C:`!-87)G:6X`
M36%T8VAI;F<@9FEE;&1S`$UA>0!-965T:6YG`$UE;6)E<G,`365N=2!,:7-T
M`$UE<F=E(&-E;&QS`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T<FEC
M`$UI9&1L90!-:6YU=&4H<RD`36ES<V5D($5V96YT<R!,:7-T`$UO`$UO8FEL
M92!-86EL`$UO9&5R871E`$UO9&EF>2!54DP`36]N9&%Y`$UO;G1H`$UO;G1H
M(%9I97<`36]N=&AL>2!%=F5N=',@3&ES=`!-;VYT:&QY.B!296-U<G,@979E
M<GD`36]N=&AS($%H96%D`$UO;G1H<R!"969O<F4`36]S=&QY($-L96%R`$UY
M($%C8V]U;G0`37D@0V%L96YD87)S`$UY($-A;&5N9&%R<SH`37D@4&]R=&%L
M`$UY(%!O<G1A;"!,87EO=70`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F5T
M=V]R:P!.979E<@!.97<@0V%T96=O<GD`3F5W($5V96YT`$YE=R!5<V5R;F%M
M92`H;W!T:6]N86PI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@,C0@:&]U
M<G,`3F5X="!$87D`3F5X="!-;VYT:`!.97AT(%=E96L`3F5X="!D87D`3F5X
M="!W965K`$YI9VAT`$YO(&%T=&5N9&5E<P!.;R!C86QE;F1A<G,@87)E(&%V
M86EL86)L92!T;R!G=65S=',N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN`$YO(&5N9"!D871E`$YO(&5V96YT<R!T;R!D
M:7-P;&%Y`$YO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"X`3F\@<&5N9&EN
M9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('9A;&ED(&5M86EL(&%D
M9')E<W,@9F]U;F0`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO;F4`3F]T(&9O=6YD`$YO="!S970`3F]T97,`3F]V
M96UB97(`3F]W`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$]+
M`$]B:F5C="!#<F5A=&]R`$]C=&]B97(`3V9F:6-E`$]P96X@:6X@82!N97<@
M=VEN9&]W`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!T:6]N
M86P`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A;FEZ:6YG`$]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]W;F5R`$]W;F5R(%!E<FUI<W-I;VYS`%!(4"!#;V1E`%!-($QI9VAT(%)A
M:6X`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!A<W0@179E;G1S($QI<W0`4&%S=&4`4&%T:`!0871T97)N
M`%!E;F1I;F<@4VEG;G5P<SH`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/P!097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N
M<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!0:&]T;W,`
M4&EX96QS`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N
M86UE(&%N9"!P87-S=V]R9`!0;VQL<P!0;W)T86P@3W!T:6]N<P!0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`
M4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0
M<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V
M:6]U<R!$87D`4')E=FEO=7,@5V5E:P!0<F5V:6]U<R!D87D`4')I;G0@9&]C
M=6UE;G0`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%%U
M97)Y`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%N9&]M($9O<G1U;F4`
M4F5A9`!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C=7(@56YT
M:6P`4F5C=7)R96YC90!296-U<G)E;F-E($1A=&$`4F5C=7)R96YC92!%;F0@
M1&%T90!296-U<G)E;F-E($EN=&5R=F%L`%)E8W5R<F5N8V4@5'EP90!296-U
M<G,@9&%I;'D`4F5C=7)S(&UO;G1H;'D`4F5C=7)S('=E96ML>0!296-U<G,@
M>65A<FQY`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;6%R:W,`4F5M:6YD97(Z
M("5S`%)E;6]T92!#86QE;F1A<G,`4F5M;W1E($-A;&5N9&%R<SH`4F5M;W1E
M(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E;6]V90!296UO=F4@)7,`4F5M;W9E($%T=&5N9&5E`%)E;6]V
M92!";&]C:P!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@
M=&AE`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U:7)E9`!297%U
M:7)E9"!!='1E;F1E97,`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-P;VYS90!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS
M`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N
M<P!2:61D;&5S`%)I9VAT`%)O7W<@4')O<&5R=&EE<RXN+@!2;W<@4')O<&5R
M=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6X`4TU3($UE<W-A
M9VEN9P!380!3871U<F1A>0!3879E("5S`%-A=F4@07,@3F5W`%-A=F4@179E
M;G0`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V5A<F-H`%-E87)C
M:"!%;F=I;F5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D
M`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@
M=7-E<B!T;R!A9&0`4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@
M=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@9&5F
M875L="!V:65W+@!396QE8W0@=&AE(&-A;&5N9&%R('1O(&EM<&]R="!T;SH`
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA
M=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F:7)S
M="!W965K9&%Y.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM
M92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C
M="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N('-T87)T=7`Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@
M:6X@=&AE('!O<G1A;"X`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N9"!A;B!E;6%I;"!T;R`E<P!396YS;W(Z(`!397!T96UB97(`4V5T
M(&5N9"!D871E`%-E="!R96-U<G)E;F-E(&5N9"!D871E`%-E="!S=&%R="!D
M871E`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE`%-H87)E9"!#86QE;F1A<G,`4VAA<F5D($-A
M;&5N9&%R<SH`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&-A
M=&5G;W)Y(&QE9V5N9#\`4VAO=R!D96QE=&4L(&%L87)M+"!A;F0@<F5C=7)R
M96YC92!I8V]N<R!I;B!C86QE;F1A<B!V:65W<S\`4VAO=R!D=64@=&%S:W,@
M:6X@=&AE(&-A;&5N9&%R/P!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO
M9V=I;F<@:6X_`%-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M
M('-E=#\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1A
M<VMS('5S:6YG(&-A=&5G;W)Y(&-O;&]R<S\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:6UE(&]F(&1A
M>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_`%-H;W=E<G,`4VAO
M=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VMI<"!-86EN=&5N86YC90!3;F]W
M(&1E<'1H.B``4W!A8VEN9P!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3=&%N9&%R9`!3
M=&%R="!$871E`%-T87)T($]N`%-T87)T(%1I;64`4W1A=%]U<P!3=&%T=7,`
M4W4`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5M;6%R
M>0!3=6X@4FES90!3=6X@4V5T`%-U;F1A>0!3=6YR:7-E`%-U;G)I<V4O4W5N
M<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P
M<&]R=`!4+5-T;W)M`%0M4W1O<FUS`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@
M<')O<&5R=&EE<P!487)G970Z`%1A<VMS`%1E;7`@9F]R(&QA<W0@:&]U<CH@
M`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R
M871I;VX`5&5N=&%T:79E`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@8V%L96YD
M87(@(B5S(B!C86YN;W0@8F4@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@
M<F5N86UE9"!T;R`B)7,B+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!S
M879E9"X`5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A
M<G0@9&%T92X`5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@<W5C
M8V5S<V9U;&QY('-E;G0N`%1H92!F;VQL;W=I;F<@:7,@82!M;W)E(&1E=&%I
M;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#H`5&AE(&ED96YT:71Y("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E
M(&YO(&5V96YT<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S`%1H
M97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!M;W9I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W87,@86X@97)R
M;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S`%1H
M97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R="X`5&AI<R!F:6QE(&9O<FUA
M="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&ES("5S+@!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`E<P!4:'5N9&5R`%1H=7)S9&%Y`%1I8VME=',`
M5&EM92!3<%]A;@!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<W!A
M;@!4:71?;&4`5&ET;&4`5&]D87D`5&]M;W)R;W<`5&]P`%1U`%1U97-D87D`
M5'EP90!54DPZ`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!D96QE=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`E<RX`
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T
M;R!R96YA;64@(B5S(CH@)7,`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F9I
M;&5D`%5N:71S`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N<V5T(&-O
M;&]R`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9#H@)7,N
M`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5S97(@061M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`57-E
M<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`57-E<FYA;64Z`%5S97)N
M86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`5F%C871I;VX`5F%R:6%B;&4`
M5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I
M;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65W($1A>0!6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%=E`%=E871H
M97(@1F]R96-A<W0`5V5B`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E:RAS
M*0!7965K;'DZ(%)E8W5R<R!E=F5R>0!796QC;VUE`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E
M<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&%T('1I;64@<VAO
M=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE<F4@87)E(&YO
M(&QA=&5R(&5V96YT<S\`5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@
M=FEE=W,@<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S
M/P!7:61T:`!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`
M5VEN9#H`5VEN9#H@`%=O<FL@5V5E:P!960!996%R;'DZ(%)E8W5R<R!E=F5R
M>0!997,L($D@06=R964`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M861D(&5V96YT<R!T;R`E<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@
M=&\@861D(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L96YD87(N`%EO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T92!T:&ES(&5V96YT+@!9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N
M`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@<W!E8VEF:65D
M(&%N(&EN=F%L:60@8V%L96YD87(N`%EO=2!M=7-T('-E;&5C="!A(&-A;&5N
M9&%R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S
M(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T
M960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W5R($5M86EL($%D9')E
M<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@
M3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I
M;64@>F]N93H`66]U<B!D969A=6QT(&-A;&5N9&%R`%EO=7(@9&5F875L="!I
M9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@<F5M;W1E('-E<G9E<G,Z
M`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;56YN86UE
M9"!E=F5N=%T`7T%D;6EN:7-T<F%T:6]N`%]"87-I8R!396%R8V@`7T1A=&%4
M<F5E`%]$96QE=&4@4F]W`%]%9&ET`%]';W1O`%]'<F]U<',`7TAE;'``7TEM
M86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQO9R!O=70`7TUO
M9&EF>2!,:6YK+BXN`%].97<@179E;G0`7T]P=&EO;G,`7U!E<FUI<W-I;VYS
M`%]0<FEN=`!?4F5M;W9E($QI;FLN+BX`7U-E87)C:`!?5&%B;&4@4')O<&5R
M=&EE<RXN+@!?5&]D87D`7U5S97)S`&)E9F]R92!T:&4@979E;G0@<W1A<G1S
M`&-A;&T`9&%Y`&1A>2AS*0!D87ES`&5V96YT<RYC<W8`9G)O;0!F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S`&QI;F5S70!M;VYT:"AS*0!N86UE`&]N('1H
M92!S86UE(&1A=&4`;VX@=&AE('-A;64@=V5E:V1A>0!P97)C96YT`'!I>&5L
M<P!R:7-I;F<`<W1E861Y`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O
M;F9I<FT`=D5V96YT(&YO="!F;W5N9"X`=V5A=&AE<BYC;VT`=V5E:P!W965K
M*',I(&]N.@!W965K<P!Y96%R*',I`%!R;VIE8W0M260M5F5R<VEO;CH@2W)O
M;F]L:71H('8P+C`N,PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ
M,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#(M,C,@,3<Z,C,M,#$P
M,`I,87-T+51R86YS;&%T;W(Z($UA<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O
M=F%N;T!U;FEB;V-C;VYI+FET/@I,86YG=6%G92U496%M.B!)=&%L:6%N(#QD
M979`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@86QL92``)60@)7,@92`E<P`E
M9"!E=F5N=&D`)7,@+2!!='1E;GII;VYE`"5S($=I;W)N;R]I("5S($]R82]E
M("5S($UI;G5T;R]I`"5S($]P97)A>FEO;FD@9&D@36%N=71E;GII;VYE("T@
M0V]N9F5R;6$`)7,@5&5R;6EN:2!D)U5S;P`E<R!A("5S("5S`$9I;&4@)7,@
M:6UP;W)T871O(&-O;B!S=6-C97-S;P`E<R!M:6YU=&D`)7,@;F]N('1R;W9A
M=&\N`"5S(&$@)7,@9&D@)7,`0V%L96YD87)I;R!D:2`E<P`J($%G9VEU;F=I
M('%U97-T:2!C;&EC8V%N9&\@<W4@06=G:75N9VD@*@`J(%-E;&5Z:6]N82!)
M;F1I<FEZ>F\O:2`J`"P@82`E<R`E<P`L('9A<FEA8FEL92!D82`E<R!A("5S
M`#$@979E;G1O`$9O<FUA=&\@,3(@;W)E`$9O<FUA=&\@,C0@;W)E`#(T(&]R
M90!-;W-T<F$@04T`04TO4$T`5F%I(&$`4F5G;VQE`$%C8V5T=&%T;P!!8V-O
M=6YT(%!A<W-W;W)D`$-O;G1A8FEL:71A)P!2:6-E<F-A($%?=F%N>F%T80!!
M9V=I=6YG:0!!9V=I=6YG:2!3;W1T;R!'<G5P<&\`06=G:75N9VD@179E;G1O
M`$%G9VEU;F=I('%U:3H`06=G:75N9VD@3G5O=F\@571E;G1E`$%G9VEU;F=I
M('5N(&YU;W9O($-A;&5N9&%R:6\@4F5M;W1O.@!!9V=I=6YG:2!U;B!N=6]V
M;R!E=F5N=&\`06=G:75N9VD@=6X@;G5O=F\@=71E;G1E.@!!9V=I=6YG:2!P
M87)T96-I<&%N=&D`06=G:75N9VD@=6X@;G5O=F\@;65M8G)O`$%G9VEU;F=I
M('!A:6\`06=G:75N9VD@=71E;G1E`$QA(&9U;GII;VYE(&1I(&%G9VEU;G1A
M('5T96YT:2!N;VX@Z"!A='1I=F$N`%)U8G)I8V$`06UM:6YI<W1R87II;VYE
M`%!U8F)L:6-I=.``4FEC97)C82!!=F%N>F%T80!!;&QA<FUE`$1A=&$@9&D@
M06QL87)M90!496UP;R!D:2!!;&QA<FUE("AM:6YU=&DI`$%L;&%R;64`06QL
M:6YE86UE;G1O`$%L;&EN96%M96YT;SH`5'5T=&D`5'5T=&D@:2!P87)T96-I
M<&%N=&D`5'5T=&D@9VQI(%5T96YT:2!!=71E;G1I8V%T:0!4=71T;R!I;"!&
M=71U<F\`5'5T=&D@:2!'<G5P<&D`5'5T=&D@:2!097)M97-S:0!4=71T:2!6
M:7-I8FEL:0!4=71T;R!I;"!G:6]R;F\`5'5T=&\@:6P@9VEO<FYO`%1U='1I
M(&=L:2!%=F5N=&D`5'5T=&D@:2!Q=6%T=')O(&QA=&D`571E;GIA($E-4U`@
M86QT97)N871I=F$`26YD:7)I>GIO(&5M86EL(&%L=&5R;F%T:79O`$%V=FES
M82!S=2!A9V=I;W)N86UE;G1I`%1E<W1O(&%L=&5R;F%T:79O.@!2:7-P;W-T
M80!1=6%L<VEA<VD`07!P;&EC87II;VYE`$%P<&QI8V%Z:6]N92!E)R!P<F]N
M=&$N`$%P<FEL90!396D@<VEC=7)O(&1I('9O;&5R(&5L:6UI;F%R92!L82!R
M:6-H:65S=&$@9&D@:7-C<FEZ:6]N92!P97(@)7,_`$-H:65D:2!C;VYF97)M
M82!P<FEM82!D:2!E<V5G=6ER92!O<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N
M90!!;&QE`%1E;G1A=&EV;R!D:2!C86YC96QL87II;VYE(&1I('5N(&=R=7!P
M;R!I;F5S:7-T96YT92X`5&5N=&%T:79O(&1I(&5L:6UI;F%Z:6]N92!D:2!U
M;B!P97)M97-S;R!I;F5S:7-T96YT92X`5&5N=&%T:79O(&1I(&UO9&EF:6-A
M(&1I('5N('!E<FUE<W-O(&EN97-I<W1E;G1E`%1E;G1A=&EV;R!D:2!M;V1I
M9FEC82!D:2!U;B!P97)M97-S;R!I;F5S:7-T96YT90!087)T96-I<&%N=&D`
M4&%R=&5C:7!A;G1I`$%G;W-T;P!#86UP:2!D:7-P;VYI8FEL:3H`4V9O;F1O
M`$)A<V5L:6YE`%)I8V5R8V$@5F5L;V-E`$-O;7!L96%N;F\`26UP;W-T87II
M;VYI($)L;V-C;P!4:7!O(&1I($)L;V-C;P!'<F%S<V5T=&\`4')E9F5R:71I
M`$UA<F=I;F4`36%R9VEN:0!"87-S;P!);7!E9VYA=&\`0TU3`$-?86QE;F1A
M<FEO`%!R;W!R:65TX"!D96QL92!#7V5L;&4N+BX`0V%L7V5N9&%R:6\`0V%L
M96YD87)I;P!3;VUM87)I;R!D96P@0V%L96YD87)I;P!#86QE;F1A<FD`0V%L
M;6\`26UP;W-S:6)I;&4@8W)E87)E('5N(&YU;W9O(&5V96YT;P!#86YC96QL
M80!%;&EM:6YA(%)A<'!O<G1O(&1I(%!R;V)L96UA`$5L:6UI;F%T;P!%;&EM
M:6YA=&\Z("5S`$]P>FEO;FD`0V%T96=O<FE?80!#871E9V]R:64@92!%=&EC
M:&5T=&4`0V%T96=O<FEA`%!R;W!R:65TX"!D96QL92!C96QL90!3<&5S<V]R
M92!C96QL93H`4')O<')I973@(&1E;&QE(&-E;&QE`%-P87II;R!C96QL93H`
M0V5N=')A`$UO9&EF:6-A`$UO9&EF:6-A(&YO;64L(&EN9&ER:7IZ;R!E(&9I
M<FUA(&-H92!V97)R86YN;R!V:7-U86QI>GIA=&D@9&%L;&4@<&5R<V]N92!C
M:&4@;&5G9V]N;R!E(')I<W!O;F1O;F\@86ET('1U;VD@;65S<V%G9VDN`$-I
M860`5F5R:69I7V-A($QI;FLN+BX`4V5L97II;VYA(&-O;64@=FES=6%L:7IZ
M87)E(&QE(&1A=&4Z`%-C96=L:2!I;"!T=6\@8V%L96YD87)I;R!D:2!D969A
M=6QT`$5L:6UI;F$@=71E;G1E.B`E<P!%;&EM:6YA('5T96YT90!%;&EM:6YA
M(&QE(&EN9F]R;6%Z:6]N:2!D96QL)W5T96YT90!#;&EC8V$@<&5R($-O;G1I
M;G5A<F4`0VAI=61I(&QA($9I;F5S=')A`$YU=F]L90!.=79O;&4`36%R9VEN
M:2!C;VQL87-S871I`$-O;&]R90!396QE>FEO;F$@0V]L;W)E`$-O;&]N;F4Z
M`%9I9VYE='1E`%9A;&]R:2!S97!A<F%T:2!D82!V:7)G;VQA`$-O;6%N9&\`
M4VAE;&P@9&D@0V]M86YD:0!#;VYD:7II;VYI`$-O;F9I9W5R82`E<P!#;VYF
M97)M82!087-S=V]R9`!#;VYF97)M82!C86YC96QL87II;VYE(&1E9VQI(&5V
M96YT:3\`0V]N9F5R;6%T;P!#;VYT:6YU80!#;W!I80!396QE>FEO;F4@;&$@
M8V]P:6$`3F]N(&5R82!P;W-S:6)I;&4@87!R:7)E("5S+@!);7!O<W-I8FEL
M92!I;G9E<G1I<F4@;&$@8V]N9FEG=7)A>FEO;F4N`$EM<&]S<VEB:6QE('-A
M;'9A<F4@;&$@8V]N9FEG=7)A>FEO;F4@)7,N`$EM<&]S<VEB:6QE('-A;'9A
M<F4@=6YA(&-O<&EA(&1I('-C;W)T82!D96QL82!C;VYF:6=U<F%Z:6]N90!#
M;W)S:0!#<F5A`$-R96$@=6X@;G5O=F\@979E;G1O`$-R96$@=6X@8V]L;&5G
M86UE;G1O`$-R96%N92!U;F\@;G5O=F\`0W)E871O`%!E<FUE<W-I(&1I($-R
M96%T;W)E`$-O<G)E;G1E`$]R82!A='1U86QE`$QA(%523"!A='1U86QE(.@`
M365T96\@071T=6%L90!#;VYD:7II;VYI(&%T='5A;&DZ(`!3=&EL92!A='1U
M86QE`$EM<&]S=&$@;&4@;W!E<F%Z:6]N:2!D82!E<V5G=6ER92!Q=6%N9&\@
M96YT<FD@:6X@)7,N`%1A9VQI80!396QE>FEO;F4@5&%G;&EA`$='`$=I;W)N
M86QI97)O.B!3:2!R:7!E=&4@;V=N:0!"<F]W<V5R($1A=&%4<F5E`$1A=&$@
M4FEC979U=&\`1VEO<FYO`$=I;W)N;RAI*0!%;%]I;6EN80!%7VQI;6EN82!#
M;VQO;FYA`$1I8V5M8G)E`$YU;65R;R!D96-I;6%L90!2:69I=71A=&\`0V%L
M96YD87)I;R!D:2!$969A=6QT`$-O;&]R92!D:2!$969A=6QT`$5L:6UI;F$`
M0V%N8V5L;&$@)7,`16QI;6EN82!%=F5N=&\`16QM:6YA($=R=7!P;P!%;&EM
M:6YA(&-E;&QA`$5L:6UI;F$@8V]L;VYN80!!=G9I<V$@<W4@86=G:6]R;F%M
M96YT:0!%;&UI;F$@<FEG80!%;&EM:6YA(&PG:61E;G1I=.`@<V5L97II;VYA
M=&$`16QI;6EN82!L82!C;VQO;FYA(&-O<G)E;G1E`$-A;F-E;&QA('-O;&\@
M;"=E=F5N=&\@8V]R<F5N=&4L('%U97-T;R!E=F5N=&\@92!T=71T92!L92!R
M:6-O<G)E;GIE(&9U='5R92P@;R!T=71T92!L92!R:6-O<G)E;GIE/P!%;&EM
M:6YA(&QA(')I9V$@8V]R<F5N=&4`1&5S8W)I7WII;VYE`$1E<V-R:79I(&EL
M(%!R;V)L96UA`$1E<V-R:7II;VYE`%-V:6QU<'!O`%!U;G1O(&1I(%)U9VEA
M9&$`0V%R=&5L;&$`5FES=6%L:7IZ80!6:7-U86QI>GIA(&YE;"!F;W)M871O
M(#(T(&]R93\`3W!Z:6]N:2!6:7-U86QI>GIA>FEO;F4`3F]N(&5L:6UI;F%R
M90!.;VX@86-C961E<F4@9&ER971T86UE;G1E(&$@;6%I;G1E;F%N8V4N<&AP
M`%9U;VD@;6]S=')A<F4@;&4@871T:79I=.`@8VAE('-O;F\@9&$@<W9O;&=E
M<F4@;F5L(&-A;&5N9&%R:6\_`$YO;B!S:2!R:7!E=&4`3&$@<')I;6$@<FEG
M82!C;VYT:65N92!L92!E=&EC:&5T=&4@9&D@8V%M<&\_($UA<F-A('-E('-I
M+"!L87-C:6$@=G5O=&$@<V4@;F\Z`%-C87)I8V$@;&$@8V]N9FEG=7)A>FEO
M;F4@9V5N97)A=&$@8V]M92!S8W)I<'0@4$A0+@!%;G1R;SH@)7,`1'5R871A
M`$UO9&EF:6-A("5S`$UO9&EF:6-A(%!A<G1E8VEP86YT:0!-;V1I9FEC82!"
M;&]C8V\`36]D:69I8V$@1W)U<'!O`$UO9&EF:6-A(%!E<FUE<W-I`$UO9&EF
M:6-A('!E<FUE<W-I('!E<B`E<P!-;V1I9FEC82!#86QE;F1A<FD@4F5M;W1I
M`$UO9&EF:6-A('!A<G1E8VEP86YT:0!-;V1I9FEC82!O<'II;VYI('!E<CH`
M36]D:69I8V$@<&5R;65S<VD@<&5R("5S`$EN9&ER:7IZ;R!%;6%I;`!$871A
M(&1I(&9I;F4`1FEN:7-C92!I;`!/<F%R:6\@9&D@1FEN90!%<G)O<F4`4VD@
M92<@=F5R:69I8V%T;R!U;B!E<G)O<F4@;F5L;"=I;7!O<G1A>FEO;F4@9&5L
M;&4@:6YF;W)M87II;VYI(&QI8F5R;R]O8V-U<&%T;R!D96QL)W5T96YT92`E
M<SH@)7,N`$5V96YT:2!D82`E<R!A("5S`$]G;FD@,34@;6EN=71I`$]G;FD@
M,B!M:6YU=&D`3V=N:2`S,"!S96-O;F1I`$]G;FD@-2!M:6YU=&D`3V=N:2!-
M97IZ)V]R80!/9VYI(&UI;G5T;P!686QO<FD@9&D@97-E;7!I;SH`17-E8W5Z
M:6]N90!%<W!O<G1A`$5S<&]R=&$@0V%L96YD87)I;P!#;VQO<F4@1D<`57!L
M;V%D("A#87)I8V%M96YT;RD@9FEL92!N;VX@<W5P<&]R=&%T;RX`1VEU<W1O
M`$9E8F)R86EO`%-I('-E;G1E(&-O;64`4VD@<V5N=&4@8V]M93H@`%!O8VAI
M($%C<75A>GIO;FD`1FEL92!-86YA9V5R`$9I;'1R:0!4<F]V80!0<FEM82!-
M971A)P!0<FEM;R!4<FEM97-T<F4`1FQO870`0V]L;W)E($9O;G0`4&5R(&)R
M;W=S97(@8VAE(&YO;B!S;W!P;W)T86YO(&QE(&EM;6%G:6YI`$AA:2!D:6UE
M;G1I8V%T;R!L82!T=6$@<&%S<W=O<F0_`$UO9'5L:0!);F1O=FEN;P!&;W)T
M=6YE(%1Y<&4`1F]R='5N97,`1F]R=6T`26YO;'1R:0!696X`1G)A;65S`%9E
M;F5R9.P`1&%L(`!$97-C<FEZ:6]N92!#;VUP;&5T80!,=6YA(%!I96YA`$YO
M;64@0V]M<&QE=&\`1G5T=7)O`$=I;V-O`$=E;F5R86QE`$=E;F5R82!#;VYF
M:6=U<F%Z:6]N92`E<R``0V]D:6-E($=E;F5R871O`%9A:2!A`%)I8V5R8V$@
M1V]O9VQE`%9A:2!A("5S`$%M;6EN:7-T<F%Z:6]N92!'<G5P<&D`1W)U<'!I
M`%!E<FUE<W-I($]S<&ET:0!!;'1E>GIA`$%I=71O`$5M:7-F97)O`$%L=&$`
M2&]?<F1E`$AO<F1E`%)I96UP:6UE;G1O($]R:7IZ;VYT86QE`$]R:7IZ;VYT
M86QE.@!/<F$H92D`475A;G1E(&-O;&]N;F4@=G5O:2!U;FER93\`475A;G1I
M(&-A;7!I("AC;VQO;FYE*2!C:2!S;VYO/P!1=6%N=&4@<FEG:&4@=G5O:2!U
M;FER93\`56UI9&ETX`!)7VYS97)I<V-I(&QA(')I9V$@<')I;6$`4V]L;R!)
M8V]N90!)8V]N92!C;VX@5&5S=&\`3F]M92!D96QL)TED96YT:73@.@!!;G1E
M<')I;64@26UM86=I;F4`55),($EM;6%G:6YE`%523"!);6UA9VEN90!);6UA
M9VEN:0!);7!O<G1A($-A;&5N9&%R:6\L(%-T97`@)60`26UP;W)T82P@4&%S
M<V\@)60`26UP;W)T82]%<W!O<G1A($-A;&5N9&%R:6\`0V%M<&\@:6UP;W)T
M871O.B`E<P!#86UP:2!I;7!O<G1A=&DZ`$EN7W-E<FES8VD@=6YA(')I9V$@
M9&]P;P!5=&5N=&D@26YD:79I9'5A;&D`26YF;W)M87II;VYE`$EN<V5R:7-C
M:2!U;F$@0U]O;&]N;F$@9&]P;P!);G-E<FES8VD@=6XG:6UM86=I;F4`26YS
M97)I<V-I(%1A8F5L;&$`26YS97)I<V-I($-O;&QE9V%M96YT;R!796(`26YS
M97)I<V-I(%]C;VQO;FYA(%!R:6UA`$EN<V5R:7-C:2!U;F$@;G5O=F$@8V]L
M;VYN82!D;W!O('%U96QL82!C;W)R96YT90!);G-E<FES8VD@=6YA(&YU;W9A
M(&-O;&]N;F$@<')I;6$@9&D@<75E;&QA(&-O<G)E;G1E`$EN<V5R:7-C:2!U
M;F$@;G5O=F$@<FEG82!D;W!O('%U96QL82!C;W)R96YT90!);G-E<FES8VD@
M=6YA(&YU;W9A(')I9V$@<')I;6$@9&D@<75E;&QA(&-O<G)E;G1E`$EN<V5R
M:7-C:2!U;B!T96UP;&%T92!A;'1E<FYA=&EV;P!);G-E<FES8VD@8V5L;&$@
M9&]P;P!);G-E<FES8VD@8V5L;&$@<')I;6$`06=G:75N9VD@8V]L;VYN82!D
M;W!O`$EN<V5R:7-C:2!C;VQO;FYA('!R:6UA`$EN<V5R:7-C:2!P87)A9W)A
M9F\@9&]P;P!);G-E<FES8VD@<&%R86=R869O('!R:6UA`$EN<V5R:7-C:2!R
M:6=A(&1O<&\`26YS97)I<V-I(')I9V$@<')I;6$`26YS97)I<V-I+TUO9&EF
M:6-A($EM;6%G:6YE`$%P<&QI8V%Z:6]N92!I;G9A;&ED82X`1&%T;R!N;VX@
M=F%L:61O+@!);G9E;G1A<FEO`$-O<G-I=F\`1V5N;F%I;P!':6%P<&]N97-E
M("A)4T\M,C`R,BU*4"D`3'5G;&EO`$=I=6=N;P!':75S=&EF:6-A=&\`4&%R
M;VQE(&-H:6%V90!?1F]R;6%T;P!,:6YG=6$`56QT:6UE(#(T(&]R90!5;'1I
M;6$@36]D:69I8V$`56QT:6UO(&UE<V4`56QT:6UO(%%U87)T;P!5;'1I;6\@
M06=G:6]R;F%M96YT;SH`56QT:6UO(&%C8V5S<V\Z("5S`%5L=&EM;R!A8V-E
M<W-O.B`E<R!D82`E<P!5;'1I;6\@86-C97-S;SH@36%I`%5L=&EM82!S971T
M:6UA;F$`1F]R;6%T;P!S:6YI<W1R80!0:6]G9VEA($QE9V=E<F$`4V5L97II
M;VYA(&EL(&QA<W-O(&1I('1E;7!O(&1A(&5S<&]R=&%R93H`16QE;F-A(&=L
M:2!A<F=O;65N=&D@9&D@06EU=&\`3F]N(.@@871T:79A(&QA(&9U;GII;VYE
M(&1I(&5L96YC;R!U=&5N=&DN`$QI=&5R871U<F$`3'5?;V=O`$]R82!L;V-A
M;&4Z(`!,:6YG=6$@92!/<F$`3'5O9V\`16YT<F$`17-C:0!#;VUP:71I(&1I
M(&EN:7II;R!S97-S:6]N90!"87-S80!N=6UE<FD@<F]M86YI('!I^2!B87-S
M:0!-30!0;W-T80!);F1I<FEZ>F\@06UM:6YI<W1R871O<F4`1V5S=&ES8VD@
M8V%L96YD87)I(')E;6]T:2X`1V5S=&ES8VD@;&$@;&ES=&$@9&5L;&4@8V%T
M96=O<FEE(&1A;F1O(&QO<F\@=6XG971I8VAE='1A(&4@87-S;V-I86YD;R!L
M;W)O('5N(&-O;&]R92X`36%R>F\`36%R9VEN90!#86UP:2!C;W)R:7-P;VYD
M96YT:0!-86=G:6\`26YC;VYT<F\`365M8G)I`$%P<FD@0V%R=&5L;&$`56YI
M<V-I($-E;&QE`$UE=&5O($%T='5A;&4`0FQO8VL@;F]N(&1I<W!O;FEB:6QE
M+@!$971T86=L:2!L;V=G871I('!E<B!L)V%M;6EN:7-T<F%T;W)E`&UE=')I
M8V\`0V5N=')O`$UI;G5T:0!%;&5N8V\@9&D@179E;G1I(%!E<G-I`$QU;@!-
M;V)I;&4@36%I;`!-;V1E<F%T;P!-;V1I9FEC82!54DP`3'5N963L`$UE<V4`
M5FES=6%L:7IZ82!-97-E`$5L96YC;R!-96YS:6QE(&1I($5V96YT:0!-96YS
M:6QM96YT93H@4VD@<FEP971E(&]G;FD`365S:2!!=F%N=&D`365S:2!0<FEM
M80!0<FEN8VEP86QM96YT92!397)E;F\`36EO($%C8V]U;G0`36EE:2!#86QE
M;F1A<FD`36EE:2!#86QE;F1A<FDZ`$UI;R!0;W)T86QE`$9O<FUA=&\@9&5L
M($UI;R!0;W)T86QE`$Y/+"!.3TX@4V]N;R!D)T%C8V]R9&\N`$YO;64`4F5T
M90!-86D`3G5O=F$@0V%T96=O<FEA`$YU;W9O($5V96YT;P!.=6]V;R!.;VUE
M(%5T96YT92`H3W!Z:6]N86QE*0!.;W1I>FEE`$=R=7!P:2!D:2!N;W1I>FEE
M`%!R;W-S:6UO`%!R;W-S:6UE(#(T(&]R90!':6]R;F\@<W5C8V5S<VEV;P!-
M97-E('-U8V-E<W-I=F\`4V5T=&EM86YA('-U8V-E<W-I=F$`1VEO<FYO('-U
M8V-E<W-I=F\`4V5T=&EM86YA('-U8V-E<W-I=F$`3F]T=&4`3F5S<W5N('!A
M<G1E8VEP86YT90!.97-S=6X@8V%L96YD87)I;R!D:7-P;VYI8FEL92!P97(@
M9VQI(&]S<&ET:2X`3F]N('!U;VD@8W)E87)E(&9I9VQI(&$@<75E<W1O('!E
M<FUE<W-O+@!.97-S=6YA(&1A=&$@9&D@9FEN90!.97-S=6X@979E;G1O(&1A
M(&UO<W1R87)E`$YE<W-U;B!C;VUP;&5A;FYO('1R;W9A=&\N`$YE<W-U;F$@
M<F5G:7-T<F%Z:6]N92!I;B!A='1E<V$N`$YE<W-U;F$@<F5G;VQA`$YE<W-U
M;B!L871O`$YE<W-U;B!D:7)E='1O<FEO('1E;7!O<F%N96\@9&ES<&]N:6)I
M;&4@<&5R(&QA(&-A8VAE+@!.97-S=6X@:6YD:7)I>GIO(&4M;6%I;"!V86QI
M9&\@Z"!S=&%T;R!T<F]V871O+@!.97-S=6YA('9E<G-I;VYE('1R;W9A=&$@
M;F5L;&$@8V]N9FEG=7)A>FEO;F4@;W)I9VEN86QE+B!296=E;F5R82!L82!C
M;VYF:6=U<F%Z:6]N92X`3F5S<W5N82!V97)S:6]N92!T<F]V871A(&YE;&QA
M('1U82!C;VYF:6=U<F%Z:6]N92X@4F5G96YE<F$@;&$@8V]N9FEG=7)A>FEO
M;F4N`$YE<W-U;F\`3F]N('1R;W9A=&\`3F]N(&EM<&]S=&%T;P!.;W1E`$YO
M=F5M8G)E`$]R80!.=6UE<F\@9&D@8V]L;VYN90!.=6UE<F\@9&D@<FEG:&4`
M3TL`4')O<')I971A<FEO`$]T=&]B<F4`569F:6-I;P!!<')I(&EN(&YU;W9A
M(&9I;F5S=')A`$%P<FD@<75E<W1O(&-O;&QE9V%M96YT;R!I;B!N=6]V82!F
M:6YE<W1R80!/<'II;VYA;&4`3W!Z:6]N:0!/<'II;VYI(&9O<B`E<P!'<F]U
M<%=A<F4`87!P;&EC87II;VYE(&EN=&5R;F$`06QT<F\`06QT<F4@26YF;W)M
M87II;VYI`%!R;W!R:65T87)I;P!097)M97-S:2!D96P@4')O<')I971A<FEO
M`$-O9&EC92!02%``4$T@4&EO9V=I82!,96=G97)A`%!A<W-W;W)D`%!A<W-W
M;W)D.@!087-S=V]R9#H@`$QE('!A<W-W;W)D(&1E=F]N;R!C;W)R:7-P;VYD
M97)E+@!%;&5N8V\@179E;G1I(%!A<W-A=&D`26YC;VQL80!097)C;W)S;P!-
M;V1E;&QO`%)E9VES=')A>FEO;FD@:6X@071T97-A.@!097)C96YT=6%L90!%
M<V5G=6D@;&4@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO;F4`17-E9W5I(&QE
M(&]P97)A>FEO;FD@9&D@;6%N=71E;GII;VYE(&%L(&QO9VEN/P!#86YC96QL
M82!Q=65S=&\@979E;G1O(&1E9FEN:71I=F%M96YT93\`4&5R;65S<VD`4&5R
M;65S<V\@3F5G871O`%!E<FUE<W-I`$%M;6EN:7-T<F%Z:6]N92!D96D@4&5R
M;65S<VD`26YF;W)M87II;VYI(%!E<G-O;F%L:0!&;W1O`%!I>&5L`%!R96=O
M(&-O;F9E<FUA<F4@96QI;6EN87II;VYE(&5L96UE;G1O.@!0<F5G;R!C;VYF
M97)M87)E(&5L:6UI;F%Z:6]N92!L:6YK.@!);G-E<FES8VD@=6X@;F]M92!P
M97(@;&$@;G5O=F$@8V%T96=O<FEA.@!$979I(&EN<V5R:7)E(&EL('1U;R!N
M;VUE('5T96YT92!E(&QA('!A<W-W;W)D`%-O;F1A9V=I`$]P>FEO;FD@4&]R
M=&%L90!0;W-I>FEO;F%M96YT;R!D:2!Q=65S=&$@:6UM86=I;F4N`%!O<VEZ
M:6]N86UE;G1O(&1I('%U97-T82!T86)E;&QA`%!R97-S:6]N90!0<F5S<VEO
M;F4@86P@;&EV96QL;R!D:2!M87)E.B``4')E<W-I;VYE.B``06YT97!R:6UA
M`$%N=&5P<FEM82!D96QL)VEM;6%G:6YE(&EN(&YU;W9A(&9I;F5S=')A`$=I
M;W)N;R!0<F5C961E;G1E`%-E='1I;6%N82!0<F5C961E;G1E`$=I;W)N;R!P
M<F5C961E;G1E`%-T86UP82!D;V-U;65N=&\@`%!R;V)L96UA`$1E<V-R:7II
M;VYE(&1E;"!P<F]B;&5M80!0<F]G971T:0!$;VUA;F1A`%!I;V=G:6$`4&EO
M9V=I82!0<F5S=&\`4&EO9V=I82!487)D:0!&;W)T=6YA($-A<W5A;&4`3&5G
M9VD`4VEC=7)O(&1I('9O;&5R(&5L:6UI8V%R925S/R!,)V]P97)A>FEO;F4@
M;F]N('!U;R<@97-S97)E(&%N;G5L;&%T80!3:6-U<F\@9&D@=F]L97(@96QI
M;6EN87)E(&D@9&%T:2!D:2`E<S\@3"=O<&5R87II;VYE(&YO;B!P=6\G(&5S
M<V5R92!A;FYU;&QA=&$`4FEP971I(&9I;F\`4FEC;W)R96YZ80!$871A(%)I
M8V]R<F5N>F$`1&%T82!D:2!&:6YE(')I8V]R<F5N>F$`26YT97)V86QL;R!D
M:2!2:6-O<G)E;GIA`%1I<&\@9&D@<FEC;W)R96YZ80!3:2!R:7!E=&4@;V=N
M:2!G:6]R;F\`4VD@<FEP971E(&]G;FD@;65S90!3:2!R:7!E=&4@;V=N:2!S
M971T:6UA;F$`4VD@<FEP971E(&]G;FD@86YN;P!!9V=I;W)N82!L82!V:7-U
M86QI>GIA>FEO;F4@4&]R=&%L93H`3F]T90!3;VQL96-I=&\Z("5S`$-A;&5N
M9&%R:2!296UO=&D`0V%L96YD87)I(%)E;6]T:3H`4V5R=F5R(%)E;6]T:0!5
M4DP@<F5M;W1A("AH='1P.B\O=W=W+F5S96UP:6\N8V]M+VAO<F1E*3H`16QI
M;6EN80!%;&EM:6YA("5S`$5L:6UI;F$@4&%R=&5C:7!A;G1E`$5L:6UI;F$@
M8FQO8V-O`%)I;75O=FD@1F]R;6%T=&%Z:6]N90!%;&EM:6YA('!A:6\`16QI
M;6EN82!I;`!%;&EM:6YA('5T96YT90!%;&EM:6YA('5T96YT93H@)7,`3V)B
M;&EG871O<FEO`%!A<G1E8VEP86YT:2!2:6-H:65S=&D`06YN=6QL80!!;FYU
M;&QA(%!A<W-W;W)D`$%N;G5L;&$@;&$@='5A(%!A<W-W;W)D`%)I<W!O<W1A
M`%)I<W5L=&%T:0!4;W)N82!A;&QE($]P>FEO;FDN`$EN=F5R=&D@;&$@0V]N
M9FEG=7)A>FEO;F4`3W!Z:6]N:2!%9&ET;W(@4FEC:"!497AT`%)I9&1L97,`
M1&5S=')A`%!R;W!R:65TX"!D96QL82!27VEG82XN+@!0<F]P<FEE=&$@9&5L
M;&$@<FEG80!0<F]P<FEE=.`@9&5L;&$@<FEG80!2:6=H93H`4F5G;VQE`$5S
M96=U:0!-97-S86=G:2!335,`4V%B`%-A8F%T;P!386QV82`E<P!386QV82!C
M;VUE($YU;W9O`%-A;'9A($5V96YT;P!386QV82!/<'II;VYI`%-A;'9A(&QA
M(&-O;F9I9W5R87II;VYE(&=E;F5R871E(&-O;64@<V-R:7!T(%!(4"!S=6QL
M82!C87)T96QL82!T96UP;W)A;F5A(&1E;"!T=6\@<V5R=F5R+@!386QV871O
M(&QA(&-O;F9I9W5R87II;VYE("5S+@!#97)C80!-;W1O<F4@9&D@<FEC97)C
M80!396QE>FEO;F$@=6YA(&1A=&$`4VQE>FEO;F$@=6X@9W)U<'!O(&1A(&%G
M9VEU;F=E<F4`4V5L97II;VYA('5N(&YU;W9O('!R;W!R:65T87)I;P!396QE
M>FEO;F$@=6X@<V5R=F5R`%-E;&5Z:6]N82!U;B!U=&5N=&4@9&$@86=G:75N
M9V5R90!38V5G;&D@;&4@;W!Z:6]N:2!D:2!C;VYF97)M82P@;&4@('9I<W5A
M;&EZ>F%Z:6]N:2!E('-C96=L:2!L82!V:7-U86QI>GIA>FEO;F4@9&D@9&5F
M875L="X`4V5L97II;VYA(&EL(&-A;&5N9&%R:6\@=F5R<V\@8W5I(&EM<&]R
M=&%R93H`4V5L97II;VYA(&D@8V%R871T97)I(&1I(&-U:2!H86D@8FES;V=N
M;R!D86QL92!C87-E;&QE('%U:2!S;W1T;RX@4'5O:2!Q=6EN9&D@8V]P:6%R
M;&4@92!I;F-O;&QA<FQE(&1A;&QA('1E>'1A<F5A+@!396QE>FEO;F$@:6P@
M9&5L:6UI=&%T;W)E(&1I(&1A=&$Z`%-E<V-E9VQI(&EL(&9O<FUA=&\@9&5L
M;&$@9&%T83H`4V5L97II;VYA(&EL(&9O<FUA=&\@<&5R(&5S<&]R=&%R93H`
M4V5L97II;VYA(&EL(&9I;&4@9&$@:6UP;W)T87)E.@!396QE>FEO;F$@:6P@
M<')I;6\@9VEO<FYO(&9E<FEA;&4Z`%-E;&5Z:6]N82!I;"!F;W)M871O(&1A
M(&-U:2!I;7!O<G1A<F4Z`%-E;&5Z:6]N82!I;"!D96QI;6ET871O<F4@9&5L
M;"=O<F$Z`%-C96=L:2!I;"!F;W)M871O(&1E;&PG;W)A.@!396QE>FEO;F$@
M:6P@;&%S<V\@9&D@=&5M<&\@9&$@;6]S=')A<F4Z`%-C96=L:2!L82!V:7-U
M86QI>GIA>FEO;F4@9&$@;6]S=')A<F4@9&]P;R!L)V%C8V5S<V\Z`%-E;&5Z
M:6]N82!D=64@8V%M<&D@8V]R<FES<&]N9&5N=&DN`%-E;&5Z:6]N82!Q=6%L
M:2!E=F5N=&D@;6]S=')A<F4@;F5L('!O<G1A;&4N`%-E;&5Z:6]N82!I;"!T
M=6\@<V-H96UA(&-O;&]R:2X`4V5L97II;VYA(&QA(&QI;F=U82!C:&4@<')E
M9F5R:7-C:3H`26YV:6$@:6P@<F5P;W)T(&1E;"!P<F]B;&5M80!);G9I82!U
M;B!E;6%I;"!A("5S`%-E;G-O<F4Z(`!3971T96UB<F4`26UP;W-T82!L82!D
M871A(&1I(&9I;F4`26UP;W-T82!L82!D871A(&1I(&9I;F4@9&5L;&$@<FEC
M;W)R96YZ80!);7!O<W1A(&QA(&1A=&$@9"=I;FEZ:6\`26UP;W-T:2!I('-E
M<G9E<B!R96UO=&D@86D@<75A;&D@=G5O:2!A8V-E9&5R92!D86P@='5O('!O
M<G1A;&4N`%-E;&5Z:6]N82!L82!L:6YG=6$@<')E9F5R:71A(&4@:6P@9G5S
M;R!O<F%R:6\N`$UO9&EF:6-A(&QA('1U82!A<'!L:6-A>FEO;F4@9&D@879V
M:6\L(&=L:2!S8VAE;6D@8V]L;W)E+"!E9"!A;'1R92!O<'II;VYI(&1I('9I
M<W5A;&EZ>F%Z:6]N92X`4V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L('-E
M='5P(&1I<W!O;FEB:6QE`$-A;&5N9&%R:2!#;VYD:79I<VD`0V%L96YD87)I
M($-O;F1I=FES:3H`4VAO<'!I;F<`0G)E=F4@4FEA<W-U;G1O`$1E9FEN:6%M
M;R!G;&D@86-C97-S:2!D82!T87-T:65R82!P97(@:2!L:6YK/P!-;W-T<F$`
M36]S=')A(&QA(&QE9V5N9&$@9&D@8V%L96YD87)I/P!-;W-T<F$@:6-O;F4@
M8V%N8V5L;&$L(&%L;&%R;64@92!R:6-O<G)E;GIE(&YE;&QE('9I<W1E(&-A
M;&5N9&%R:6\_`$UO<W1R82!L92!A='1I=FETX.`@9&$@<W9O;&=E<F4@;F5L
M(&-A;&5N9&%R:6\_`$UO<W1R82!L)W5L=&EM;R!L;V=I;B!A;&PG86-C97-S
M;S\`36]S=')O('-O;&\@9VQI(&5V96YT:2!C;VX@=6X@8V%M<&%N96QL;R!D
M:2!A;&QA<FUE/P!-;W-T<F$@=&%B96QL82!O<&5R87II;VYI(&YE;&QA(&)A
M<G)A(&1E;"!M96YU/P!-;W-T<F$@;&4@871T:79I=.`@=7-A;F1O(&D@8V]L
M;W)I(&1E;&QE(&-A=&5G;W)I93\`36]S=')A(&EL("5S($UE;F\@<W5L;&$@
M<VEN:7-T<F$_`$UO<W1R82!L92!0<F]P<FEE=.`@5&%B96QL82!#96QL80!-
M;W-T<F$@;&4@4')O<')I973@(%1A8F5L;&$`36]S=')A(&QE(%!R;W!R:65T
MX"!486)E;&QA(%)I9V$`36]S=')A(&EN=&5R=F%L;&D@9&D@;65Z>F$@;W)A
M(&YE;&QA('9I<W5A;&EZ>F%Z:6]N92!D:2!G:6]R;F\@92!S971T:6UA;F$_
M`$%C<75A>GIO;FD`06-Q=6%Z>F]N:2!A($)R979E`$%C<75A>GIO;FD@5&%R
M9&D`4V%L=&$@36%N=71E;GII;VYE`%!R;V9O;F1I=&$G(&1I(&YE=F4Z(`!3
M<&%Z:6%T=7)A`%-P86T`0V%R871T97)E(%-P96-I86QE`$1I=FED:2!#96QL
M80!$:79I9&D@8V]L;VYN80!$:79I9&D@4FEG80!3=&%N9&%R9`!$871A(&1I
M($EN:7II;P!#;VUI;F-I82!I;`!/<F$@9&D@26YI>FEO`%-T871I<P!3=&%T
M:7,`1&]M`%-O='1O<V-R:79I`%-U8V-E<W-O`%-A;'9A=&\@;&$@8V]N9FEG
M=7)A>FEO;F4N`%-C<FET=&\@8V]N('-U8V-E<W-O("5S`%)I87-S=6YT;P!!
M;&)A`%1R86UO;G1O`$1O;65N:6-A`$%L8F$`06QB82]4<F%M;VYT;P!!;&)A
M.B``5')A;6]N=&\`5')A;6]N=&\Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T;P!4
M+51E;7!E<W1A`%0M5&5M<&5S=&4`4')O<')I973@(%1A8F5L;&$`4')O<')I
M973@(%1A8F5L;&$`1&5S=&EN87II;VYE.@!!='1I=FETX`!496UP97)A='5R
M82!U;'1I;6$@;W)A.B``5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!!;6UI
M;FES=')A>FEO;F4@5&5M<&QA=&4`06QT97)N871I=FD`4V]L;R!497-T;P!!
M;&QI;F5A;65N=&\@=&5S=&\`5&5S=&\@:6X@86QT;P!':6\`1W)A>FEE(&1I
M(&%V97(@=7-A=&\@:6P@<VES=&5M82X`26P@8V%L96YD87)I;R`B)7,B(&YO
M;B!P=?D@97-S97)E(&-A;F-E;&QA=&\N`$EL(&-A;&5N9&%R:6\@(B5S(B#H
M('-T871O(&5L:6UI;F%T;RX`26P@8V%L96YD87)I;R`B)7,B(.@@<W1A=&\@
M<FEN;VUI;F%T;R!A("(E<R(N`$EL(&-A;&5N9&%R:6\@(B5S(B#H('-T871O
M('-A;'9A=&\N`$QA(&1A=&$@9&D@9FEN92!D979E(&5S<V5R92!D;W!O(&QA
M(&1A=&$@9&DG:6YI>FEO+@!,82!N;W1I9FEC87II;VYE(&1E;"!E=F5N=&\@
M82`E<R#H('-T871A(&EN=FEA=&$@8V]N('-U8V-E<W-O+@!);"!S96=U96YT
M92#H('5N82!D96-R:7II;VYE('!I^2!D971T86=L:6%T82!D96P@979E;G1O
M.@!,)VED96YT:73@("(E<R(@92<@<W1A=&$@96QI;6EN871A+@!);"!S97)V
M97(@(B5S(B!E)R!S=&%T;R!E;&EM:6YA=&\N`$EL('-E<G9E<B`B)7,B(&4G
M('-T871O('-A;'9A=&\N`$QA(')I8VAI97-T82!D:2!R96=I<W1R87II;VYE
M('!E<B`E<R#H('-T871A(&5L:6UI;F%T82X`26P@;6]D=6QO('=E871H97(N
M8V]M(&YO;B#H(&1I<W!O;FEB:6QE+@!.;VX@8VD@<V]N;R!F:6QE<R!I;B!Q
M=65S=&$@9&ER96-T;W)Y+@!%<G)O<F4@;F5L;"=I;7!O<G1A>FEO;F4@9&5I
M(&1A=&D@:4-A;&5N9&%R.B`E<RX`4VD@92<@=F5R:69I8V%T;R!U;B!E<G)O
M<F4@;F5L;"=I;7!O<G1A>FEO;F4@9&5L;"=E=F5N=&\Z("5S+@!3:2!E)R!V
M97)I9FEC871O('5N(&5R<F]R92!N96QL82!V:7-U86QI>GIA>FEO;F4@9&5L
M;"=E=F5N=&\Z("5S+@!%<G)O<F4@;F5L;"=E;&EM:6YA>FEO;F4@9&5L(&5V
M96YT;SH@)7,N`$5R<F]R92!N96QL)VEN=FEO(&1E;"!T=6\@:6YV:71O(&$@
M)7,Z("5S`$YO;B!C)V5R86YO(&5V96YT:2!D82!E<W!O<G1A<F4N`$EL(&9O
M;6%T;R!D:2!Q=65S=&\@9FEL92!N;VX@Z"!S=7!P;W)T871O+@!1=65S=&\@
M92<@)7,N`%%U97-T;R#H('%U96QL;R!C:&4@:6P@<V5V97(@:&$@:6YD:6-A
M=&\Z("5S`%1U;VYO`$=I;W9E9.P`5&EC:V5T`$=E<W1I;VYE(&1E;"!496UP
M;P!'97-T:6]N92!D96P@5&5M<&\`1F]R;6%T;R!/<F$`1V5S=&EO;F4@9&5L
M(%1E;7!O`%1I=&]L;P!4:71O;&\`3V=G:0!$;VUA;FD`06QT;P!-87(`36%R
M=&5D[`!4:7!O`%523#H`26UP;W-S:6)I;&4@8V]N;F5T=&5R<VD@86P@<V5R
M=F5R(%-13"X`26UP;W-S:6)I;&4@96QI;6EN87)E("(E<R(Z("5S`$EM<&]S
M<VEB:6QE(&5L:6UI;F%R92`E<RX`26UP;W-S:6)I;&4@8V%R:6-A<F4@;&4@
M9&5F:6YI>FEO;FD@9&D@)7,N`$EM<&]S<VEB:6QE(&5L:6UI;F%R92`B)7,B
M.B`E<P!3;W1T;VQI;F5A`$%N;G5L;&$@;&4@36]D:69I8VAE`$YO;B!!<F-H
M:79I871O`%5N:73@`$5L:6UI;F$@16QE;65N=&\@0V]R<F5N=&4`16QI;6EN
M82!#;VQO<F4`06=G:6]R;F$`06=G:6]R;F$@)7,`06=G:6]R;F$@=71E;G1E
M`$%G9VEO<FYA=&\Z("5S+@!38W)I<'0@9&D@86=G:6]R;F%M96YT;R!E;&EM
M:6YA=&\N`$%G9VEO<FYA`$YU;65R(')O;6%N:2!A;'1I`$%M;6EN:7-T<F%Z
M:6]N92!5=&5N=&D`26YT97)F86-C:6$@571E;G1E`%)E9VES=')A>FEO;F4@
M571E;G1E`$ES8W)I>FEO;F4@571E;G1E(&4G('-T871O(&1I<V%B:6QI=&%T
M;R!P97(@<75E<W1O('-I=&\N`$YO;64@571E;G1E`$YO;64@571E;G1E.@!.
M;VUE(%5T96YT93H`571E;G1I(&YE;"!S:7-T96UA.@!686-A;GIE`%9A<FEA
M8FEL90!#;VYT<F]L;&\@5F5R<VEO;F4`06QL:6YE86UE;G1O`%)I96UP:6UE
M;G1O(%9E<G1I8V%L90!697)T:6-A;&4Z`$UO;'1O($%L=&\`5FES=6%L:7IZ
M82!':6]R;F\`5FES=6%L:7IZ82!U;F$@<&%G:6YA('=E8B!E<W1E<FYA`%9I
M<VEB:6QI=.``5FES:6)I;&ETX#H@`$UE<@!0<F5V:7-I;VYE($UE=&5O`%=E
M8@!-97)C;VQE9.P`4V5T=&EM86YA`%-E='1I;6%N82`E9`!3971T:6UA;F$H
M92D`4V5T=&EM86YA;&UE;G1E.B!3:2!R:7!E=&4@;V=N:0!"96YV96YU=&\`
M0F5N=F5N=71O(&$@)7,`0F5N=F5N=71O+"`E<P!#:&4@87!P;&EC87II;VYE
M("5S(&1E=F4@;6]S=')A<F4@9&]P;R!I;"!L;V=I;C\`0V]S82!E)R!C87)A
M='1E<F4@9&5L:6UI=&%T;W)E`$-O<V$@92<@:6P@8V%R871T97)E('9I<F=O
M;&5T=&4_`$$@8VAE(&]R82!D979O;F\@9FEN:7)E(&EL(&=I;W)N;R!E(&QA
M('-E='1I;6%N82P@<75A;F1O(&YO;B!C:2!S;VYO(&5V96YT:2!S=6-C97-S
M:79I/P!!(&-H92!O<F$@9&5V;VYO(&EN:7II87)E(&EL(&=I;W)N;R!E(&QA
M('-E='1I;6%N82P@<75A;F1O(&YO;B!C:2!S;VYO(&5V96YT:2!P<F5C961E
M;G1I/P!,87)G:&5Z>F$`06UP:65Z>F$@9&5L;&$@=&%B96QL80!5;FETX"!,
M87)G:&5Z>F$`3&%R9VAE>GIA.@!696YT;SH`5F5N=&\Z(`!3971T:6UA;F$@
M;&%V;W)A=&EV80!!00!!;FYU86QM96YT93H@4VD@<FEP971E(&]G;FD`4VDL
M('-O;F\@9"=A8V-O<F1O`$YO;B!H86D@:6P@<&5R;65S<V\@9&D@86=G:75N
M9V5R92!E=F5N=&D@82`E<RX`3F]N(&AA:2!I;"!P97)M97-S;R!D:2!A9V=I
M=6YG97)E(&5V96YT:2!A;"!C86QE;F1A<FEO('-E;&5Z:6]N871O+@!.;VX@
M:&%I(&EL('!E<FUE<W-O(&1I(&-A;F-E;&QA<F4@;"=E=F5N=&\N`$YO;B!H
M86D@:6P@<&5R;65S<V\@9&D@;6]D:69I8V%R92!Q=65S=&\@979E;G1O+@!,
M82!S97-S:6]N92#H('-T871A('1E<FUI;F%T82X`2&%I('-P96-I9FEC871O
M('5N(&-A;&5N9&%R:6\@;F]N('9A;&ED;RX`1&5V:2!S96QE>FEO;F%R92!U
M;B!C86QE;F1A<FEO(&1A(&5L:6UI;F%R90!$979I('-E;&5Z:6]N87)E('5N
M(&EN9&ER:7IZ;R!P<FEM82X`1&5V:2!S<&5C:69I8V%R92!I;"!S97)V97(@
M9&$@96QI;6EN87)E+@!$979I('-P96-I9FEC87)E(&QO('5S97)N86UE(&1A
M(')I;75O=F5R92X`1&5V:2!S<&5C:69I8V%R92!L;R!U<V5R;F%M92!D82!R
M:6UU;W9E<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@9&$@86=G
M:75N9V5R92X`1&5V:2!S<&5C:69I8V%R92!L;R!U<V5R;F%M92!D82!A9V=I
M;W)N87)E+@!4=6\@26YD:7)I>GIO($5M86EL`%1U;R!);F1I<FEZ>F\@16UA
M:6P`5F]S=')A(&EN9F]R;6%Z:6]N90!);"!T=6\@;F]M90!);"!T=6\@8F%C
M:V5N9"!D:2!A=71E;G1I8V%Z:6]N92!N;VX@<W5P<&]R=&$@;&$@96QE;F-A
M>FEO;F4@9&5G;&D@=71E;G1I+"!O(&QA(&-A<F%T=&5R:7-T:6-A(.@@<W1A
M=&$@9&ES86)I;&ET871A('!E<B!Q=6%L8VAE(&UO=&EV;RX`26P@='5O(&)R
M;W=S97(@;F]N(&AA('%U97-T82!C87!A8FEL:71A)RX`26P@='5O(&9U<V\@
M;W)A<FEO(&%T='5A;&4Z`$EL('1U;R!C86QE;F1A<FEO(&1I(&1E9F%U;'0`
M261E;G1I=.`@9&D@1&5F875L=`!);"!T=6\@;F]M93H`22!T=6]I('-E<G9E
M<B!R96UO=&DZ`%M$;V-U;65N=&\@9&D@9&5S8W)I>FEO;F4@9&5L('!R;V)L
M96UA70!;36]S=')A(%1E<W1O('%U;W1A=&\@+0!;179E;G1O('-E;GIA(&YO
M;65=`%]!;6UI;FES=')A>FEO;F4`7U)I8V5R8V$@5F5L;V-E`%]$871A5')E
M90!?16QI;6EN82!2:6=A`%]-;V1I9FEC80!?5F%I(&$`7T=R=7!P:0!?06EU
M=&\`4')O<')I973@(&1E;&PG7TEM;6%G:6YE+BXN`%]);7!O<G1A+T5S<&]R
M=&$`7T9I;F4@<V5S<VEO;F4`7TUO9&EF:6-A($QI;FLN+BXZ`%].=6]V;R!%
M=F5N=&\`7T]P>FEO;FD`7U!E<FUE<W-I`%]3=&%M<&$`7T5L:6UI;F$@3&EN
M:RXN+@!?0V5R8V$`4')O<')I973@(&1E;&QA(%]486)E;&QA`%]/9V=I`%]5
M=&5N=&D`<')I;6$@8VAE(&EN:7II82!L)V5V96YT;P!C86QM;P!G:6]R;F\`
M9VEO<FYO*&DI`&=I;W)N:0!E=F5N=&DN8W-V`&1A`&1A;&QE("5S("@E<RD@
M86QL92`E<R`E<P!L:6YE95T`;65S92AI*0!N;VUE`&%L;&$@<W1E<W-A(&1A
M=&$`;&\@<W1E<W-O(&=I;W)N;R!F97)I86QE`'!E<F-E;G1O`'!I>&5L<P!A
M=6UE;G1A;F1O)P!C;W-T86YT90!D:6=I=&$@;&$@<&%S<W=O<F0@9'5E('9O
M;'1E('!E<B!C;VYF97)M87)E`'9%=F5N="!N;VX@=')O=F%T;RX`=V5A=&AE
M<BYC;VT`<V5T=&EM86YA`'-E='1I;6%N82AE*2!S=3H`<V5T=&EM86YE`&%N
M;F\H:2D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C
M86QE+VMO7TM2+P``````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S4Q`#`R,#8W-P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]L;V-A;&4O:V]?2U(O3$-?34534T%'15,O````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3$`,#(R-#8T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]K;U]+4B],
M0U]-15-304=%4R]K<F]N;VQI=&@N;6\`````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,C`T,0`Q,#0Q
M-S,V,C<U,0`P,C4P,S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````WA($E0````#J`0``'````&P/``"-`@``O!X```````#P
M*```#P```/$H```(`````2D```L````**0``#````!8I```H````(RD``!(`
M``!,*0``'0```%\I```(````?2D```4```"&*0``$0```(PI```)````GBD`
M``\```"H*0``#P```+@I```(````R"D```@```#1*0``&0```-HI```'````
M]"D```X```#\*0``!0````LJ```*````$2H``!0````<*@``"@```#$J```%
M````/"H```4```!"*@``"@```$@J```#````4RH```<```!7*@``#0```%\J
M```*````;2H```X```!X*@``#P```(<J```?````ERH```4```"W*@``.0``
M`+TJ```"````]RH```8```#Z*@``$0````$K```*````$RL``!`````>*P``
M"````"\K```$````."L```8````]*P``$0```$0K```'````5BL```0```!>
M*P``!@```&,K```-````:BL``!,```!X*P``!@```(PK```5````DRL```<`
M``"I*P``"````+$K```*````NBL```\```#%*P``#0```-4K```/````XRL`
M``T```#S*P``"0````$L```&````"RP```8````2+```#@```!DL```%````
M*"P``"H````N+```$P```%DL```,````;2P``!````!Z+```$0```(LL```%
M````G2P```4```"C+```!@```*DL```'````L"P``!````"X+```&P```,DL
M```$````Y2P```X```#J+```*0```/DL```2````(RT```T````V+0``!P``
M`$0M```.````3"T```T```!;+0```P```&DM```-````;2T```(```![+0``
M!0```'XM```3````A"T```0```"8+0```P```)TM```&````H2T```X```"H
M+0``"````+<M```/````P"T```\```#0+0``!P```.`M```0````Z"T```8`
M``#Y+0``"0`````N```,````"BX```L````7+@``#0```",N```*````,2X`
M`!D````\+@``7````%8N```6````LRX``!0```#*+@``"P```-\N```O````
MZRX```D````;+P``#P```"4O```F````-2\``$,```!<+P``"````*`O```+
M````J2\```<```"U+P``"````+TO```$````QB\```<```#++P``%P```-,O
M```1````ZR\```H```#]+P```@````@P```%````"S````D````1,```#0``
M`!LP```(````*3````8````R,```"````#DP```.````0C```!@```!1,```
M!0```&HP```0````<#```!````"!,```#P```)(P```+````HC````\```"N
M,```#````+XP```/````RS````X```#;,```!@```.HP```/````\3````@`
M```!,0``'@````HQ```A````*3$```,```!+,0``"````$\Q```,````6#$`
M``<```!E,0``"@```&TQ```"````>#$```8```![,0``!@```((Q```$````
MB3$```8```".,0``!````)4Q```'````FC$```(```"B,0``!@```*4Q```$
M````K#$``!$```"Q,0``(@```,,Q```,````YC$```H```#S,0``!0```/XQ
M```/````!#(``!(````4,@``"P```"<R```'````,S(``"D````[,@``)```
M`&4R```F````BC(``!(```"Q,@``"@```,0R```/````SS(``!````#?,@``
M#@```/`R```)````_S(```H````),P``%@```!0S```2````*S,``!`````^
M,P``$0```$\S```/````83,``!0```!Q,P``#````(8S```,````DS,```\`
M``"@,P``%0```+`S```I````QC,``"H```#P,P``)@```!LT```G````0C0`
M`"D```!J-```*@```)0T```1````OS0``!(```#1-```$P```.0T```4````
M^#0``!8````--0``%P```"0U```0````/#4``!$```!--0``$P```%\U```2
M````<S4```8```"&-0``!P```(TU```%````E34``!8```";-0``!````+(U
M```$````MS4```<```"\-0``#@```,0U```,````TS4```P```#@-0``#0``
M`.TU```(````^S4``!(````$-@``#P```!<V```(````)S8```X````P-@``
M%@```#\V```1````5C8```D```!H-@``!@```'(V```$````>38``!X```!^
M-@``$````)TV```:````KC8```@```#)-@``!@```-(V```'````V38```L`
M``#A-@``$P```.TV```3`````3<``!,````5-P```@```"DW```$````+#<`
M``T````Q-P``!0```#\W```&````13<```\```!,-P```P```%PW```'````
M8#<```H```!H-P``"P```',W```'````?S<```8```"'-P``"0```(XW```"
M````F#<```H```";-P``!@```*8W```%````K3<```<```"S-P``%0```+LW
M```)````T3<```<```#;-P``!P```.,W```%````ZS<```D```#Q-P``$P``
M`/LW```*````#S@```@````:.```"0```",X```S````+3@``#,```!A.```
M.````)4X```+````SC@```0```#:.```!0```-\X```(````Y3@``!$```#N
M.```#@`````Y```'````#SD``!\````7.0``!P```#<Y```.````/SD```P`
M``!..0``#````%LY```%````:#D``!$```!N.0``!P```(`Y```(````B#D`
M`!4```"1.0``!0```*<Y```4````K3D```0```#".0``!P```,<Y```'````
MSSD``!X```#7.0``'@```/8Y```4````%3H```4````J.@``!@```#`Z```H
M````-SH``"D```!@.@``!P```(HZ```A````DCH```P```"T.@``#@```,$Z
M```3````T#H```L```#D.@``#P```/`Z```3`````#L``!,````4.P``#P``
M`"@[```,````.#L```X```!%.P``#0```%0[```-````8CL``!<```!P.P``
M"P```(@[```%````E#L``!$```":.P``$0```*P[```%````OCL``!(```#$
M.P``!````-<[```.````W#L```X```#K.P``!0```/H[```"`````#P``!(`
M```#/```"````!8\```+````'SP```H````K/```#````#8\``!8````0SP`
M`&D```"</```&@````8]```7````(3T``!H````Y/0``&0```%0]```7````
M;CT``!T```"&/0``&P```*0]```?````P#T``!,```#@/0``"0```/0]```?
M````_CT``"@````>/@``)0```$<^```@````;3X``"0```"./@``(````+,^
M```$````U#X``!````#9/@``'````.H^```H````!S\```<````P/P``$P``
M`#@_```7````3#\```H```!D/P``#````&\_```)````?#\```H```"&/P``
M"````)$_```*````FC\```T```"E/P``"P```+,_```"````OS\```<```#"
M/P``!@```,H_```)````T3\```<```#;/P``!P```.,_```&````ZS\```L`
M``#R/P``$````/X_```0````#T````4````@0```!````"9````)````*T``
M``H````U0````@```$!````?````0T```"\```!C0```&P```)-````^````
MKT```",```#N0```'P```!)!```]````,D$``!\```!P00``(0```)!!```<
M````LD$```@```#/00``!0```-A!```0````WD$```(```#O00``!0```/)!
M```2````^$$```,````+0@``$`````]"```"````($(```<````C0@``!```
M`"M"```O````,$(``"4```!@0@``(````(9"```F````IT(```D```#.0@``
M#````-A"```7````Y4(```X```#]0@``#0````Q#```:````&D,```<````U
M0P``"P```#U#```3````24,``!,```!=0P``#@```'%#```,````@$,```@`
M``"-0P``%````)9#```.````JT,``!````"Z0P``!P```,M#```'````TT,`
M``(```#;0P``"0```-Y#```$````Z$,```<```#M0P``!P```/5#```&````
M_4,``!0````$1```!P```!E$```-````(40```L````O1```(````#M$```<
M````7$0``$@```!Y1```3````,)$```%````#T4``!(````510``"@```"A%
M```&````,T4```P````Z10``"@```$=%```)````4D4```(```!<10``!@``
M`%]%```4````9D4```,```![10``10```']%```9````Q44``$4```#?10``
M,````"5&```F````5D8``"4```!]1@``,````*-&```2````U$8``!,```#G
M1@``$````/M&```)````#$<``',````61P``*P```(I'```7````MD<``!8`
M``#.1P``#P```.5'``!`````]4<``!\````V2```$@```%9(```0````:4@`
M`!,```!Z2```'0```(Y(```/````K$@```\```"\2```"P```,Q(```%````
MV$@``!0```#>2```"````/-(```/````_$@```@````,20``#P```!5)```4
M````)4D```,````Z20``!@```#Y)```$````14D```8```!*20``"````%%)
M```$````6DD``!````!?20``$P```'!)```'````A$D```8```",20``!P``
M`)-)```%````FTD```0```"A20``"P```*9)```%````LDD```<```"X20``
M50$``,!)```,````%DL```<````C2P``!P```"M+```'````,TL``!<````[
M2P``%0```%-+```;````:4L```<```"%2P``"0```(U+```+````ETL```D`
M``"C2P``%````*U+```3````PDL```\```#62P``"P```.9+```4````\DL`
M``0````'3```!`````Q,```$````$4P```D````63```#@```"!,```)````
M+TP```H````Y3```!````$1,```%````24P```0```!/3```"0```%1,```.
M````7DP```D```!M3```"````'=,```'````@$P``!<```"(3````P```*!,
M```7````I$P```0```"\3````P```,%,```,````Q4P```0```#23```"0``
M`-=,```$````X4P```0```#F3```!````.M,```)````\$P```0```#Z3```
M!````/],```$````!$T```L````)30``#````!5-```$````(DT``!(````G
M30``!````#I-```$````/TT```8```!$30``!P```$M-```'````4TT```<`
M``!;30``!P```&--```&````:TT```8```!R30``!````'E-```.````?DT`
M``0```"-30``%0```))-```4````J$T```<```"]30``#0```,5-```+````
MTTT```0```#?30```P```.1-```&````Z$T```0```#O30``"0```/1-```1
M````_DT```0````03@``!````!5.```K````&DX``!````!&3@``"P```%=.
M```$````8TX```H```!H3@``"P```'-.```&````?TX```8```"&3@```@``
M`(U.```$````D$X```T```"53@``!````*-.```"````J$X```(```"K3@``
M"0```*Y.```$````N$X```0```"]3@``"````,).```$````RTX```L```#0
M3@``!````-Q.```'````X4X```D```#I3@``!P```/-.```'````^TX```<`
M```#3P``#`````M/``!-````&$\```P```!F3P``"0```'-/```$````?4\`
M`"H```""3P``"````*U/```)````MD\``"<```#`3P``0P```.A/```(````
M+%````L````U4```"````$%0```$````2E````0```!/4```!P```%10```,
M````7%````X```!I4```!P```'A0```"````@%````8```"#4```"````(I0
M```)````DU````D```"=4```"0```*=0```)````L5````L```"[4```#0``
M`,=0```$````U5````D```#:4```"0```.10```(````[E````L```#W4```
M"0````-1```$````#5$```,````240``#0```!91```(````)%$```T````M
M40``!@```#M1```3````0E$``!,```!640``!````&I1```#````;U$```L`
M``!S40``!````']1```)````A%$```(```".40``!@```)%1```&````F%$`
M``0```"?40``!@```*11```$````JU$```0```"P40``!````+51```$````
MNE$```8```"_40``!@```,91```>````S5$```<```#L40``"P```/11```%
M`````%(```8````&4@``"0````U2```%````%U(```(````=4@``$P```"!2
M```.````-%(``!,```!#4@``#@```%=2```&````9E(```T```!M4@``#```
M`'M2```.````B%(```@```"74@``"0```*!2```4````JE(```\```"_4@``
M#````,]2```0````W%(```@```#M4@``$````/92```)````!U,```<````1
M4P``#````!E3```.````)E,``!<````U4P``%P```$U3```7````95,``!<`
M``!]4P``&````)53```8````KE,```P```#'4P``#````-13```,````X5,`
M``P```#N4P``#@```/M3```.````"E0```P````95```#````"94```.````
M,U0```X```!"5```"````%%4```#````6E0```0```!>5```%````&-4```#
M````>%0```,```!\5```!````(!4```+````A50```D```"15```"0```)M4
M```+````I50```8```"Q5```"````+A4```/````P50```0```#15```$0``
M`-94```@````Z%0``!,````)50``"0```!U5```(````)U4```0````P50``
M&````#55```+````3E4``!L```!:50``!````'95```&````>U4```@```""
M50``#P```(M5```-````FU4```L```"I50``$````+55```"````QE4```0`
M``#)50``$````,Y5```#````WU4```@```#C50``#0```.Q5```#````^E4`
M``0```#^50``"0````-6```)````#58```8````75@``!@```!Y6```"````
M)58```(````H5@``"````"M6```&````-%8```(````[5@``!````#Y6```/
M````0U8```L```!35@``"0```%]6```(````:58```@```!R5@``"P```'M6
M```-````AU8```<```"55@``!P```)U6```'````I58``",```"M5@``'```
M`-%6```A````[E8```L````05P``!````!Q7```$````(5<```0````F5P``
M!P```"M7```'````,U<```0````[5P``$0```$!7```(````4E<```L```!;
M5P``"0```&=7```$````<5<```0```!V5P``"0```'M7```$````A5<```0`
M``"*5P``&0```(]7```&````J5<``!,```"P5P``!````,17```$````R5<`
M``8```#.5P``$P```-57```B````Z5<```D````,6```"````!98```$````
M'U@``"$````D6```'@```$98```(````95@``!````!N6```!P```']8```)
M````AU@```D```"16```!P```)M8```'````HU@```L```"K6```"0```+=8
M```)````P5@```D```#+6```"0```-58```)````WU@```D```#I6```$```
M`/-8```/````!%D```D````460``"@```!Y9```1````*5D```8````[60``
M#````$)9```$````3UD```<```!460``!P```%Q9```#````9%D```(```!H
M60``$@```&M9```&````?ED```D```"%60``"0```(]9```-````F5D``#P`
M``"G60``.P```.19```3````(%H```X````T6@``$P```$-:```1````5UH`
M``X```!I6@``$P```'A:```9````C%H``!\```"F6@``&````,9:```#````
MWUH``!(```#C6@``&````/9:```.````#UL```X````>6P``#@```"U;```0
M````/%L```0```!-6P``#0```%);```&````8%L``!H```!G6P``!````();
M```-````AUL```X```"56P``!P```*1;```'````K%L```<```"T6P``"0``
M`+Q;```)````QEL```D```#06P``"````-I;```+````XUL```(```#O6P``
M!````/);```$````]UL```@```#\6P``!`````5<```$````"EP```8````/
M7```!@```!9<```'````'5P```<````E7```!````"U<```&````,EP```0`
M```Y7```"0```#Y<```"````2%P``!@```!+7```(````&1<```>````A5P`
M`"T```"D7```'@```-)<```?````\5P``#\````170``&P```%%=```I````
M;5T``!@```"770``!@```+!=```$````MUT```T```"\70``"0```,I=```$
M````U%T```X```#970```@```.A=```1````ZUT```(```#]70``!@````!>
M```$````!UX``"T````,7@``)````#I>```H````7UX``"$```"(7@``!```
M`*I>```1````KUX``!````#!7@``!````-)>```$````UUX``!4```#<7@``
M"0```/)>```)````_%X```T````&7P``$````!1?```1````)5\```\````W
M7P``"````$=?```0````4%\```D```!A7P``"0```&M?```'````=5\```0`
M``!]7P```@```()?```&````A5\```(```",7P``!0```(]?```*````E5\`
M``0```"@7P``%````*5?```$````NE\``!8```"_7P``#@```-9?```7````
MY5\``!<```#]7P``*@```!5@```J````0&````0```!K8```"0```'!@```)
M````>F````4```"$8```"@```(I@```-````E6````0```"C8````@```*A@
M```$````JV````X```"P8````@```+]@```]````PF```!0`````80``/@``
M`!5A```I````5&$``"4```!^80``)0```*1A```L````RF$```P```#W80``
M"@````1B```$````#V(```4````48@``<P```!IB```G````CF(```P```"V
M8@``#````,-B```*````T&(``!\```#;8@``%@```/MB```-````$F,```\`
M```@8P``#````#!C```3````/6,```X```!18P``!@```&!C```)````9V,`
M``8```!Q8P``#@```'AC```*````AV,```X```"28P``"@```*%C```-````
MK&,```P```"Z8P```@```,=C```"````RF,```(```#-8P```P```-!C```"
M````U&,```0```#78P``"0```-QC```*````YF,```8```#Q8P``!````/AC
M```)````_6,```4````'9````@````UD```*````$&0```(````;9````@``
M`!YD```!````YP```)$```!B````7`$``%`!````````80$``%8`````````
M`````.P```#,`0``*````-P```!@````1P```"T`````````"`$```````"L
M````J`$``&4!``#%`0```````)\`````````/````&<!``".`0``@`$``-(!
M``#6`0`````````````)````^0```.<!``"_````/0$``#P!````````X@$`
M`%T!```D`0```````!````!1````(P$```````#.`0````````````"8`0``
M````````````````O@$``"4`````````I0$``+$!```L``````````````!(
M`0``H0$```X!```#````C@```,L!`````````````+@!``"I`0``\````&\!
M```$`0```````/L```!3`0```````!$!``#*````JP```+L```#D````Q`$`
M`'P```#&`0``"0$```````!]`0``L@``````````````H0`````````=````
M``````````#A````2`````````#I``````````````#/`0``OP$``$0```"(
M`0``K@```),!``#8`0``````````````````-@```$\````"`0``10$```\!
M``",`0```````(D```#B````=````+,`````````KP$``/$```````````$`
M`),```";````MP```$,!``#\````40$``%\```"X````=@$```````!9````
MP@$```````#*`0```````#H```!,`0``WP```((!````````-P$``(D!```A
M````BP$```P`````````9@```,@!``#6````S@```,@```"1`0``````````
M``!!````CP```#T```!)````-0$``-`!`````````````-D`````````QP$`
M`````````````````$H!`````````````&L````'`0``H@$````````&````
M`````!,````;`````````-<```#<`0``T0$```````"-`0``;0$``"H````B
M`0``Y0$``%,```"6`0````````````"W`0``/P$``````````````````$D!
M````````KP```(H```!U`0``Z0$``',!``#8````VP$`````````````TP``
M`.`!`````````````$X!`````````````/T`````````T@```-``````````
M`````%X````[`0``)@$``)@````>`````````)4!```A`0``QP`````````[
M````B@$``&L!``",````<`````````#:````?@```-T!``"`````````````
M````````<0````````"/`0``LP$``-,!``"<````M0```%(````Y````6P$`
M`,T!``"I````>P``````````````.0$``)`!``!J`0``:@```!4```"C````
M`````.L```"5````:`$``!P!```G````D````!L!``!:`0```````"T!````
M````]0```'D!````````(@```+8!``#5`0````````````#@````N0$``+T!
M``#+````P@```/<`````````'P```*<!`````````````'<!``"%`0``@@``
M`,$!``!S``````````````!'`0``G`$``/H```#9`0``M0$``,````!_`0``
M`````)H```!*````:`````$!```*`0``0`$``"X````F````70```$,`````
M````O````+`!``!F`0``-````#8!````````HP$``*P!``!D`0``U0``````
M``"V````>@$``&0```";`0``V@$``/,```#&`````````%4```#O````*@$`
M`.@!``!W````1`$``,T`````````U`$```````!8````+P$```````#A`0``
MY@$````````@`0``/P```)X````-`0``$0```)T!```(````-0````````!C
M`0``1@$``&X`````````>`$````````7`0``?0`````````^````@P```%D!
M``#X`````````"X!``"4````_P```+0!``!7`````````'@```"]````P`$`
M`!T!```%````%@$````````2`0````````P!````````M````!@!````````
MPP$``*0```#/````K@$```````"?`0```````%\!```8````L0```!0!```5
M`0``'```````````````?P```)D````K`0``-`$``$````#J`````````'(`
M````````6P```#,!``!-````,0$``!(````E`0``<@$```````"\`0```@``
M`#(!``!L`````````"L```#^````````````````````A`$``"<!``!\`0``
MI`$``$4```"%````#@```",```"-````3P$``'$!``"E````1@```*T!```L
M`0``@P$``)(!````````G@$``&4```#)`0``P0````,!````````8`$```<`
M````````Q0````````#E````WP$``"\```#R````;`$``-L```!I`0``[0``
M`&X!``#7`0```````"@!``!U````W@```%``````````*0```"0```##````
M``````4!````````&@```%P```"R`0``A@$```````"@`0``&0```.0!``"F
M`0``F@$``*H`````````.@$``.,````+`````````)<```!Y`````````&T`
M```X````#P```+D```"K`0``6@```&D```"G`````````&\```"'`0``````
M`.,!````````H````,P```"B```````````````>`0``4@$``#````"^````
M8@$``&,```!"````!````-X!``!P`0``J````$L```"!````N@$``'H````W
M`````````)(```"!`0``EP$`````````````0@$``-$```!8`0``80``````
M``"$``````````````!G````J@$``(@```"9`0```````)8`````````K0``
M`#,```#4`````````%8!``!-`0``>P$``#@!```^`0``50$``#`!``"=````
MR0````````"&````L````%0!```4````'P$``!D!```R````5P$``(L````-
M````7@$``-T```#N````$P$``'X!````````=`$```````!!`0``2P$``(<`
M```:`0```````+H`````````Y@```$X```!V````````````````````Q```
M````````````I@```/8```"4`0``(````#$```#T````%P`````````&`0``
MZ@$````````I`0``"@```.@```!,````5``````````6````$`$```L!``"[
M`0`````````@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`
M("AY97-T97)D87DI`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VX`)7,@86QR96%D>2!E>&ES=',N`"5S(&9I;&4@<W5C8V5S<V9U
M;&QY(&EM<&]R=&5D`#(T(&AO=7)S`$%-+U!-`$%B;W5T('1H:7,@961I=&]R
M`$%D9"!%=F5N=`!!9&0@82!N97<@979E;G0`061D(&$@;F5W('5S97(Z`$%D
M9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M<F5S<P!!9&UI;FES=')A=&EO;@!!;&%R;0!!;&%R;2!$871E`$%L87)M(%-P
M86X@*&UI;G5T97,I`$%L87)M(%1I;64`06QI87,`06QI9VX`06QI9VYM96YT
M.@!!;&P`06QL(&1A>0!!;&P@9&%Y(&5V96YT`$%L;"!E=F5N=',`06QL(&9O
M=7(@<VED97,`06QT97)N871E('1E>'0Z`$%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"X`07!R:6P`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T`$%U9W5S=`!!=F%I
M;&%B;&4@9FEE;&1S.@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0FER
M=&AD87D`0F]L9`!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!"
M;W1H`$)O='1O;0!"=6QL971E9"!,:7-T`$-?96QL(%!R;W!E<G1I97,N+BX`
M0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#87!T:6]N`$-A=&5G;W)Y
M`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L
M;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;G1E<@!#
M:&%N9V4`0VAE8U]K($QI;FLN+BX`0VAI;F$`0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-L96%R($U33V9F:6-E('1A9W,`
M0VQO<V4@5VEN9&]W`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E
M<G,`0V]L;W(`0V]L<SH`0V]M:6-S`$-O;7!A;GD`0V]N9FER;2!087-S=V]R
M9`!#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\`0V]P>0!#;W!Y('-E;&5C
M=&EO;@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<P!#<F5A=&4@82!.97<@179E;G0`0W)E871E(&$@;&EN:P!#=7)R96YT`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@<W1Y;&4`0W5T`$-U="!S96QE8W1I;VX`
M1$0`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E=F5R>0!$871E`$1A>0!$87DH<RD`
M1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E
M87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E
M;&5T92`E<P!$96QE=&4@179E;G0`1&5L971E(&-E;&P`1&5L971E(&-O;'5M
M;@!$96QE=&4@<F]W`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E
M('1H92!C=7)R96YT(&5V96YT(&]N;'DL('1H:7,@;V-C=7)R96YC92!A;F0@
M86QL(&9U='5R92!O8V-U<F5N8V5S+"!O<B!A;&P@;V-C=7)E;F-E<S\`1&5L
M971E('1H92!C=7)R96YT(')O=P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@)7,`1'5E.B`E<P!$=7)A=&EO
M;@!%9&ET`$5D:70@)7,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O
M<'1I;VYS(&9O<CH`16QE;65N="XN+@!%;0!%;6%I;`!%;6]T:6-O;G,`16UP
M='D@<F5S=6QT+@!%;F0@1&%T90!%;F0@3VX`16YD(%1I;64`16YL87)G92!%
M9&ET;W(`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5R<F]R`$5V97)Y(#$U
M(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E
M<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE
M('9A;'5E<SH`17AP86YD(%-I9&5B87(`17AP;W)T`$5X<&]R="!#86QE;F1A
M<@!&1R!#;VQO<@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&96)R=6%R>0!&
M:6QE($UA;F%G97(`1FEL=&5R<P!&;VYT($-O;&]R`$9R`$9R86UE<P!&<FED
M87D`1G)O;0!&=71U<F4`1V%M90!'97)M86YY`$=O`$AE:6=H=`!(96QP`$AE
M;'`@=7-I;F<@961I=&]R`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93H`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`2&]R:7IO;G1A
M;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W5R*',I
M`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!)7VYS97)T(%)O=R!"969O
M<F4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE
M.@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);7!O<G0O
M17AP;W)T($-A;&5N9&%R`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8W)E87-E($EN9&5N=`!);G-E
M<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN
M<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F
M;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H
M92!C=7)R96YT(&YO9&4`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@
M8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O
M<F4`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E
M9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R
M="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$ET86QI8P!*86YU
M87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2G5L>0!*=6YE`$IU
M<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F
M=`!*=7-T:69Y(%)I9VAT`$ME>7=O<F1S`$MO<F5A+"!297!U8FQI8R!O9@!+
M;W)E86X@*$550RU+4BD`3&%N9W5A9V4`3&%S="!L;V=I;CH@)7,`3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87-T('=E96L`
M3&%Y;W5T`$QE9G0`3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z`$QI
M<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]C
M871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]W97(@9W)E96L@
M;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E
M<G,`34T`36%I;`!-86ME(&QI;E]K+BXN`$UA<F-H`$UA<F=I;@!-871C:&EN
M9R!F:65L9',`36%Y`$UE971I;F<`365N=2!M;V1E.@!-97)G92!C96QL<P!-
M97-S86=E`$UI9&1L90!-:6YU=&4H<RD`36\`36]D:69Y(%523`!-;VYD87D`
M36]N=&@`36]N=&AL>0!-;VYT:&QY.B!296-U<G,@979E<GD`36]V92!$;W=N
M`$UO=F4@57``3F5T=V]R:P!.979E<@!.97<@179E;G0`3F5W('=I;F1O=R`H
M7V)L86YK*0!.97AT($UO;G1H`$YE>'0@9&%Y`$YE>'0@=V5E:P!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N`$YO(&5N9"!D871E`$YO;F4`3F]T97,`3F]V
M96UB97(`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3V-T;V)E
M<@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T
M:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/=&AE<@!/
M=&AE<B!);F9O<FUA=&EO;@!0861D:6YG`%!A<W-W;W)D`%!A<W-W;W)D<R!M
M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!A
M='1E<FX`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_`%!E<G-O;F%L($EN9F]R
M;6%T:6]N`%!H;VYE`%!I>&5L<P!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N
M97<@=VEN9&]W`%!R979I;W5S(&1A>0!0<FEN="!D;V-U;65N=`!0<F]B;&5M
M($1E<V-R:7!T:6]N`%)E8W5R(%5N=&EL`%)E8W5R<F5N8V4@1&%T80!296-U
M<G)E;F-E($5N9"!$871E`%)E8W5R<F5N8V4@26YT97)V86P`4F5C=7)R96YC
M92!4>7!E`%)E8W5R<R!D86EL>0!296-U<G,@;6]N=&AL>0!296-U<G,@=V5E
M:VQY`%)E8W5R<R!Y96%R;'D`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5M
M;W9E('!A:7(`4F5S970`4F5S970@=&\@1&5F875L=',`4F5T=7)N('1O($]P
M=&EO;G,`4FEG:'0`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]W(%!R;W!E
M<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4V$`4V%M92!F<F%M92`H7W-E
M;&8I`%-A='5R9&%Y`%-A=F4@07,@3F5W`%-A=F4@179E;G0`4V%V92!/<'1I
M;VYS`%-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L
M87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E(&1E9F%U;'0@=FEE
M=RX`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O
M>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I
M;7!O<G0Z`%-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3H`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1H92!T:6UE('-P86X@=&\@<VAO=SH`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!397!T96UB97(`4VAO
M=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R/P!3:&]W(&]N;'D@979E;G1S
M('1H870@:&%V92!A;B!A;&%R;2!S970_`%-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-I>F4`4VMI<"!-86EN
M=&5N86YC90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8VEN9P!3<&%C
M:6YG(&%N9"!P861D:6YG`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET
M(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3=&%R="!$871E`%-T87)T
M($]N`%-T87)T(%1I;64`4W1R:6ME=&AR;W5G:`!3='EL92!;0U-370!3=0!3
M=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6UM87)Y`%-U;F1A
M>0!3=7!E<G-C<FEP=`!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I
M97,`5&%S:W,`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!4:`!4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!E;F0@9&%T92!M=7-T(&)E
M(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@:61E;G1I='D@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V5R92!N;R!E=F5N=',@
M=&\@97AP;W)T+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`
M5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:'5R<V1A>0!4:71L90!4
M:71L92`H=&]O;'1I<"DZ`%1O`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4
M;W``5&]P(&9R86UE("A?=&]P*0!4=0!4=65S9&%Y`%1Y<&4`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@
M5V]R9"!D;V-U;65N=`!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G-E="!C;VQO
M<@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57-E
M<B!);G1E<F9A8V4`57-E<B!/<'1I;VYS`%5S97)N86UE`%5S97)S(&EN('1H
M92!S>7-T96TZ`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5FEE
M=R`E<P!787)N:6YG`%=E`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E:RAS
M*0!7965K;'D`5V5E:VQY.B!296-U<G,@979E<GD`5V5L8V]M90!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAA="!T:6UE
M('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD+"!W:&5N('1H97)E(&%R
M92!N;R!L871E<B!E=F5N=',_`%=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W
M965K('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V
M96YT<S\`5VED=&@`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED
M=&@Z`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=O<FL@5V5E:P!960!996%R
M;'D`665A<FQY.B!296-U<G,@979E<GD`665S`%EO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I
M;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S
M<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;2&ED92!1=6]T
M960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M
M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S
M70!?061M:6YI<W1R871I;VX`7T1E;&5T92!2;W<`7TAE;'``7TEM86=E(%!R
M;W!E<G1I97,N+BX`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS
M`%]296UO=F4@3&EN:RXN+@!?5&%B;&4@4')O<&5R=&EE<RXN+@!D87D`9&%Y
M*',I`&1A>7,`;&EN97-=`&UO;G1H*',I`&YA;64`;VX@=&AE('-A;64@9&%T
M90!O;B!T:&4@<V%M92!W965K9&%Y`'!E<F-E;G0`<&EX96QS`'5N;F%M960`
M=D-A<F0`=V5E:P!W965K*',I(&]N.@!W965K<P!Y96%R*',I`%!R;VIE8W0M
M260M5F5R<VEO;CH@2W)O;F]L:71H(#(N,"UC=G,*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`Q
M+3$Q+3`Y(#$V.C(Y*S`Y,#`*3&%S="U4<F%N<VQA=&]R.B!*+DD@2VEM(#QA
M<&]R:65`;F5T:6%N+F-O;3X*3&%N9W5A9V4M5&5A;3H@2V]R96%N(#QD979`
M;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]155#+4M2"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:70*`"`HM-S#X,6P("5S*0`@*+_`M,,I`"`HL[O`
MSRD`("B^[L&F*0`E<R#`K\'VL/RXKB#`V[[W("T@R*[`S@`B)7,BM,(@P,RY
MS"#`UKW`M,^TV2X`)7,@QL3`S\#,(,#3QO?&KK7'OOJ]P+3/M-DN`#(T(+W#
ML*,`O\#`_"^_P,C$`,#,(+^AM?#%S;3"`,#/P:0@P]^PH0"[];?.O^X@P,_!
MI"##W["AQ\^QX@"[];?.O^X@N^>_Z\#:(,/?L*$Z`,;DONXH<&%I<BD@P]^P
MH0"[Y[_KP-H@P]^PH0"[Y[_KP-H@P]^PH2"[Y[_KOLC'U`#!UKS2`+#\N*X`
MOLNXL@"^R[BR(,#/P-H`OLNXLB"PH[#=("BZT"D`OLNXLB"]P["C`+[SMO/`
MS+[NO;H`P:2WQ`#!I+?$.@"X\+7.`,?/M^<@L[NSNP#'S[?G(+.[L[L@P,_!
MI`#`_,.\(,#/P:0`N/"UYR`TN.D`M.O#O""QVP#`W[CXM<@@N:[`VK"A(,#6
MO<"TS[39+@`TO_D`P*_!]K#\N*Z]Q\?@P/P@R*[`SL?/L>(`O<.PHP`XO_D`
ML*&TR<?1(,?*M>4Z`+GHL.8`N>BPYB"[]K'R`+O]P,\`L;VPU`"PYK#H`+#F
ML.@@M<ZRL@"PYK#H`+CPM<X`OL:WH0"QXLBC(+BNO;K&K@!?9;R_(+S3O+HN
M+BX`P^N\T@"_P+?Y(+JXL.W'S['B(,/KO-(`Q+B\QP"Y_,'6`,C>M.O&^0"\
MOR"\T[RZ`+R_(,;DM?D`O+\@O-.\N@"\OR"PH[#=`,C>M.O&^0"PH;_NM:4`
MNJ^PY@!?:[BUQ:D@L,N[YRXN+@#!W[&Y`+SXO*T@N*Z]NL:N(,&^M_D@O+'%
MPP!-4[_`Q\>]NB#%U['7(,'VO^RQX@##HB"TW;'B`+_>PLJXM[3K(+3=L>(`
MQ]7#Q,'X(+#FL.@`N_:Q\@"_K3H`0V]M:6-S`,BXN^<`OL_(HR#(KL#.`,#/
MP:0@N^C!IKW#(,BNP,X_`+JYN^<`NKF[YP!-86EN=&5N86YC95]487-K(+CP
MM>(@)7,@N*8@OZT@O/8@OOB]P+3/M-DN`+OUM\Z_[B#`S\&D(+O]O+H`N+7%
MJ2"XN+7IL>(`Q_;`YP#']L#G(%523,"Z`,?VP.<@O;K%N,#/`,#:N*.QX@#`
MVKBCL>(`1$0`P,^ZL`"XQ<#/.B"YW[O]P,\@`+.OPJ4`P,\`P,\`7VR_K2"[
MZ,&F`#$RO_D`O/W`V@"SN[[NOK*QX@"QXKJ[`+'BNKL@O<2ZL,#:`+OHP:8`
M)7,@N^C!I@#`S\&D(+OHP:8`O+\@N^C!I@"_K2"[Z,&F`,?@(+OHP:8`Q_;`
MYR"_K2#!]K_R`,?VP.<@P,_!I+BX(+OHP:8L(,#,(+G?N_W`S\&DL/H@N/"U
MYR"^U<"XM\[`QR"YW[O]P,_!I"P@ML>TPB"X\+7G(+G?N_T@P,_!I"`_`,?V
MP.<@Q^`@P?:_\@"_P+?Y(+RSN.T`O+.X[0"\O+K.P:2ZN+"A(+#\N*[`VKBF
M(,"GQ]@@L>*WS[7'ON[!L[W`M,^TV2X`M?"WNL7DN*X`R*VXZ2"\L\&D`&UA
M:6YT96YA;F-E+G!H<+^A(,'WP:(@P:*QV<?/P?8@N+:\O+_D+@##N;GXPK`@
MQ^#`NB#'U[CQ(,#,N*?`NR"PKK#M(,#6O<"TS['N/R"QU[>XM-FXZ2P@OZFQ
MXKBF(,.\Q:G'S[R\O^0Z`+.[M\&YWK'B`"5S(+.[M\&YWK'B`,?2P,\Z("5S
M`+'BL*,`O/;!I``E<R"\]L&D`"5S(+''Q]$@O/;!I`"\L<7#N^?'UR"\]L&D
M.@"_Y+S2+BXN`&5M`,#,N-[`SP#`S+CPQKS$W`"PX;#Z(+[XP+T`P;ZWX2#`
MS\#:`,&^M^$@P,_`V@#!OK?A(+W#L*,`QNW!_;'B(,BNM.L`L=>XLB!54DP@
MP-2WP@"_P+?Y`#$UNM`@N+:TV0`S,,/*(+BVM-D`-;K0(+BVM-D`N/"UYR"W
MSK'7P,X`,S"ZT""XMK39`+C%NM``O[DZ`+_>PLJXM[3K(,BNP.4`P,V]NL;W
MQJX`P,_!I"#`S;VZQO?&K@#`_+#FN_8`R*^PYKRSP:0@P-"QXB"_P+?Y+@!,
M1$%0(+RMN?8@P:*\TR"]Q\;0`,;1O;H`,K_Y`,;$P,\@L/RXKL#:`,?*Q<T`
ML=O`VB"[]K'R`+'=`,?!M[G`TP"QW;_DP,\`P*?$H0"^U<"XM\X`L-3`TP"U
MML#/`+"AL>(`L_3`S`"UM;_RN+L`M;6_\KB[`,;$P,_`QR"]P\#;P,P@M-G`
MO;#Z(+"PO<"TS[39.@#!_2#!UKS2`,'](,#\R*VY^,BC`$AO<F1E`+SVQO*\
ML0"PH;?.(,.DO_(`L*&WSCH`O<,`Q]7$H;#M(+W-P+H@OZW`QR"\]@#'U[CQ
M*+^M*<#'(+SV/P#'U<2AL.T@O<W`NB#'X,#'(+SV`%]NOM6_H2#'X"##W["A
M`+[&P,S$W`"^QL#,Q-RP^B"YKL#:`+W$NK#`VB#`S+BG.@"QU[BR(+G,N*ZZ
MN+'B.@"QU[BR(%523`"QU[BR(%523#H`P,_!I"#`T\;WQJXOP,V]NL;WQJX`
ML*'!KK_"(,?7N/$Z("5S`+"AP:Z_PB#'U[CQ.@!?<[39P+V_H2#'X"##W["A
M`+7IOZF^LK'B`%]OM-G`O;^A(+^M(,/?L*$`L=>XLB##W["A`,>E(,/?L*$`
MP*4@N+7%J2##W["A`%]COM6_H2"_K2##W["A`,?VP.<@OZT@M=J_H2"[]2"_
MK2##W["A`,?VP.<@OZT@OM6_H2"[]2"_K2##W["A`,?VP.<@Q^`@M=J_H2"[
M]2#'X"##W["A`,?VP.<@Q^`@OM6_H2"[]2#'X"##W["A`,?VP.<@P?;!H2"U
MVK^A(+3<MO0@P]^PH0#']L#G(,'VP:$@OM6_H2"TW+;T(,/?L*$`M=J_H2"\
MOR##W["A`+[5OZ$@O+\@P]^PH0"UVK^A(+^M(,/?L*$`OM6_H2"_K2##W["A
M`+7:OZ$@M-RV]"##W["A`+[5OZ$@M-RV]"##W["A`+7:OZ$@Q^`@P]^PH0"^
MU;^A(,?@(,/?L*$`L=>XLB##W["A+[SVP:0`N+7%J2##W["A+[SVP:0`L>*_
M[\#,L>(`,;_Y`,#/NKL`P,^ZN[[N("A)4T\M,C`R,BU*4"D`-[_Y`#:_^0#!
MI+?$`+"AO^ZUI2#!I+?$`+[GPLH@P:2WQ`"_WL+*(,&DM\0`O\"XI<+*(,&D
MM\0`Q;"_]K7E`+3KQ]&YSK&Y`,?1L;F^[B`H155#+4M2*0"^\+[N`+BVP?:X
MMR"WSK'7P,XZ("5S`+BVP?:XMR"WSK'7P,XZ("5S+"#!HKS3(,"GQ*$Z("5S
M`+BVP?:XMR"WSK'7P,XZ(+[XP+T`N+;!]KBW(,'6`+>YP,R^QK_T`+_>PLH`
MP,V]NL;WQJX@O<.PHR"PH[#=(,&FQ]$Z`+6UO_*^RR"X\<+W`+OGO^O'TB"\
M]B"^^+3"(+OGO^O`VB"X\;?/+@#`I\2A`+?.L=?`S@"WSK'7OL:_]`"WSK'7
MP,X@O</`V\#;OO<`L=>XKKVZ(+S2N:[`V@"V\\:^(+S2N:[`V@"WSKBV(+S2
MN:[`VB"\_<#:`$U-`+C>P,\`7VNXM<6I(+BXM>FQXBXN+@`SO_D`L*'`Y<#:
MN*X`P,_$H<?/M,(@Q]>X\0`UO_D`N<S&PP"XWK2Z(+CPM>4`O+\@Q]7$H;'B
M`+C>O</!]@"PH;_NM:4`NM``O_D`55),(+SVP:0`O_F_Y,#/`+_Y`+C%O_D`
MO_FXMK39.B"YW[O]O_D@`+[&MZ&WSB#`S+6_`,"GM\X@P,RUOP"SU\:NO_;%
MJ0"[Y[_KOLC'U`"[];?.O^X@P,_!I`"[]2##HBA?8FQA;FLI`+39P+T@M-X`
MM-G`O2#`SP"TV<"](,'6`$944"!61E.XIB#`I\?1(+RSP:3!I+JXL*$@OOB]
MP+3/M-DN`%-13"!61E,@O+/!I,&DNKBPH2"^^+W`M,^TV2X`4U%,+49I;&4@
M5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN`,&^M^'`SR"^^+V_`+[XO;\`POS!
MM@`Q,;_Y`+^MP,<@O/8`Q^#`QR"\]@`Q,+_Y`+OU(,.BOZ$@N+7%J2"_K;'B
M`+RQQ<.[Y\?7`"5S(+RQQ<.[Y\?7`+S]P-H@N/&WSP"TW,.\`+'BQ;@`L>+%
MN"#!I+JX`,;DM?D`OL_(HP"^S\BCL*$@P,_$H<?/P?8@OLJ]P+3/M-DN`+K9
MP,RQX@#%K+BSNKBUY;^AO*T@NMG`S+'B`+#FM\X`P*_'_`#&V[R^QJX`P*_!
M]B"P_+BN(,#;OO<@O<?'X`#`S"#`S\&DP+L@O\_`_,CW(+OHP:;'S[W#L-J]
MP+3/L>X_`+"SP,X@P:2ZN`#`_,BMN?C(HP#'R+R_`+FNP::_H2"TZ\?1(+_D
MON#`NR#`U+?"Q]@@P=:\O+_D+@"[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'
MS[R\O^0`N<RXKKJXL>(`N_4@PZ*_H2"YS+BNNKBQX@#`S,#\(,#/`+FNO*T@
MP,Z\X@"YKL&F(+RSN.T`P;ZWX2#`SP"YW;JY(,#/`+G=NKD@P;ZWX<#/`+G=
MNKD@L*.PW0"YW;JY(,"OQ_P`N,7`SR"YW;JY`+C%O_D@N=VZN0"XQ<'6(+G=
MNKD`N,6SXB"YW;JY`+BVP?:XMR"X[;?)(+G=NKD`QN2^[BAP86ER*2"[Z,&F
M`,#4M\(@P^N\T@##RK'BL*K`N+?.`+_)O,?`N+?.(+6YOL:PH;'B`+_`N*7"
MR@!?=\?@(+S3O+HN+BX`OZK'T@#'X""\T[RZ`,?@(+S3O+H`Q^`Z`,7D`+"P
MP+H@Q\&WN<#3*%]S96QF*0#%Y+_DP,\`N_6WSB#`^L#E`,#/P:0@P/K`Y0"\
ML<7#N^?'UR#`^L#E`,BNP,X@O\F\Q\"[(+RQQ</'S[^I(,BMN.D@P^*WPK_)
MO,?`NR"\K;?.(+39N*.PU""\L<7#Q]6TS[39+@"^QK>A(+OSP-J_H;RM(,?*
MO^3'T2"YKL#:N*8@O+'%P\?/L.T@NKF[Y\?/OZD@NMF_J;/6P+B\O+_D+@"S
MK\#:(+&XNM#'I;W#(+RQQ<,Z`+.OP-H@Q_R]Q""\L<7#`,#3QO?&KL?2(,;$
MP,\@O+'%PSH`P];#RB#!UL'?P,\@O+'%PSH`O<.PHR#'_+W$(+RQQ<,`P^*W
MPKW#L*,@L*.PW2"\L<7#.@"USK"SP,<@P,_$H<?/M,(@Q]>X\2"\L<7#`,#:
MP=:[Y[_KQ\^TPB"^\+[NN*8@O+'%P\?/O+R_Y"X`N:[!IKG?N_T@NKBP[;RM
M(,#\O-O'S['B`#F_^0#`S\&DOZ&\K2#'TL#/(+JXL>(`OLNXLB"\L\&DM<@@
MP,_!I+BX(+JXL>(_`+R_(+S3O+K#HB"ZN+'B`,>E(+S3O+K#HB"ZN+'B`+^M
M(+S3O+K#HB"ZN+'B`+'7N+(@O-.\NL.B(+JXL>(`Q:FQX@#`K\'VL/RXKB"[
M_;>K`+R_L*.PW0"\OR"PYK#HO\T@L[N_ZR"[Y\#,P,<@L*.PW0"PQ;BN`+#%
MN*Z_S2##I+_LL>(`QJ^\]B"YKL#:(,#4M\(`O+\@NM#'T@"_K2"ZT,?2`,?@
M(+K0Q](`O</`VR#`S\#:`+W#P-L@P,_`V@"]P\#;(+W#L*,`L*&_[K6EP=D`
MO;K%N,#/6T-34UT`P,\`P::X\0#!IL/B`+[&MZ'#M\#:`+RZL/@`O^2^X`#`
MS[_DP,\`P*W#M\#:`,>E(+S3O+H`QZ4@O-.\N@#'TL#/`+FNP-J_K0"YKL#:
M`+FNP-H@P:2WQ`"X\0"[Y[_KQ]C!UKS%O*T@L*B[Y\?5M,^TV2X`P;ZWX<#/
MP+H@O</`V\#,NKBTV2#$O[[?(,?5M,^TV2X`QL3`S[^A(+[&N:NWL2#`VK?A
ML*$@OOB]P+3/M-DN`+[&MZ&TPB#`S"!M97-S86=E+W)F8S@R,B#&[<'VP,<@
MN-.XM+B[P-2TS[39+@"]Q+JPP-H@(B5S(B"PH2"[Z,&FM<>^^KW`M,^TV2X`
MP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+@#&Q,#/(+_#N*ZQXK^A
M(+FNP::PH2#`UKW`M,^TV2X@)7,@QL3`S\#,(+[WM\ZUY;7'P?8@OLJ^TKW`
MM,^TV2X`P,V]NL;WQJ['TB#`S\&DP,P@OOB]P+3/M-DN`,#,(+S]P-JTPB##
MUKS2Q]$@,<#:N*X@P,R[\\#,ONZ^WR#'U;3/M-DN`,#,(+"JP+H@O/W`VK^I
MOM\@Q]6TS[39+@"X\;_DP,\`P::X\0#%N,#,QK(HQ?C&P2DZ`+G>M,(@N^>V
M]P"_P+3#`$A434P@O-*]NB"ZN+'B`,"G`+OSP*<@Q\&WN<#3*%]T;W`I`,BM
M`,BMO^3`SP#`K\?\`%9&4R#&Q,#/("5S+R5SP,<@QMNYS+S'P+L@NJ^PYL?2
M(+SV(+[XO<"TS[39+@!V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`
MM,^TV2X`5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39
M+@#`S""_]K7EN:Z\K;BF(+JOL.;'TB"\]B"^^+W`M,^TV2X`N=C!V0"ZK[#F
MN^?'UR"UQ[6YN*ZQX@"XML'VN+<@N.VWR2##Z[S2`+^UL;D`N<RQN0#']L#G
M(+_DO-*_H2"XM<6I(,&FL,4`P,RXIR"^^,"]`+OVL?(@P::PQ0"V\\:^ONX@
MM.NYKL#:`+?.N+8@M.NYKL#:(+S]P-H`N^>_Z\#:(,#.Q<W&Y,#,O;H`N^>_
MZ\#:(+RQQ<.[Y\?7`+OGO^O`VKCM`+W#O;K%V\#'(+OGO^O`VCH`O/;!]R#!
MI+?$`+SVP?<@PZ2_\@`E<R"ZN+'B`+#FL.T`O/8`O/:_Y,#/`,'6`"5D(,'6
M`+GXPK`@P=:_H2``N,7!U@#!UKBVM-D@N=^[_3H@N=^[_<'6(`#(K[^U`,BO
MO[7'U;3/M-DA("5S(,#4M,^TV2X`R*^_M<?5M,^TV2P@)7,`L;BZT""YKL#:
MM,(@N:N^^<#4M,^Q[C\`P,Z_ZR"ZSLBCM,(@N:N^^<#4M,^Q[C\`P,\@N=<@
MP=:ZL""ZN+'B(,&^M^$@O<.PHRC`S\&D(,&^M^$@O<.PHRD_`,#/(+G7(,'6
MNK`@NKBQXB"]P\#;(+W#L*,HP,_!I""]P\#;(+W#L*,I/P"SRKKQ`,>EP,<@
ML\JZ\0"SRKKQ(+3<P*<`L\JZ\3H`P??`Y2#!UKS2.@#!]\#E(,#\R*VY^,BC
M`,'6P=\`65D`N,6SX@"SXKBVM-DZ(+G?N_VSX@"_N0!415A4N/"UY<#4M,^T
MV2X@6SP^72"Y]L:PP+L@M*FXH[CI(%=94TE764<@N/"UY;?.(+6YOL:PJ;3/
MM-DN`+?.L=>^QK_T(,?/O[2]P+3/M-DN`+FNP:8@NKBP[;RMN*8@NKBSN['B
MP/R_H2#`S+FNP::_H2"TZ\?1(+RSN.W`NR#`U+?"Q]B^WR#'U;3/M-DN`,#,
M(+BUQ:FPH2"PH;BNQ*&TPB!54DS`NR#`U+?"Q]B^WR#'U;3/M-DN`+OHP:;'
MTB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2X`P]^PH<?2(+OGO^O`
MVB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+@`E<R"\O+S'P,P@N+BWX;7'OOJ]
MP+3/M-DN(+39O<,@M\ZQU\#.Q\^\O+_D+@#`S+C>P,\@P=:\TCH`N-[`SR#!
MUKS2.@#!I+JX`,#,N*<Z`+3GO<7`QR#`SL'UQ:RV\\#,OO#&KK"A(+OGO^O`
MVB"X\;?/NKBQXKBF(,'VO_C'S\'V(+[*O<"TS[39+B"VQ[3"(+39N*4@P,S`
MK[?.(+OGO^O`VB"X\;?/NKBQXKBF(+OGO^O'TB"\]B"^^+W`M,^TV2X`NNJV
M\[_LP/JPH2#`S""QXK3)P+L@P?:_^,?/P?8@OLJ]P+3/M-DN`,?VP.<@O<.P
MH[3K.@"QXKJ[(+W$NK#`VCH`P/S#O"#`S+BG.@#`S""\O+S'(+6_OL@@O\F\
MQ\#,(,#ZP.6UR[3/M-DN`+_)O,?`S"#`^L#EM<>^^KW`M,^TV2X`6\#.O^L@
MO/NQXK'B70!;O\"W^2"ZN+#MQ\^QXET`6\#.O^L@NKBQXB`M`%O`SK_K(+JX
ML>(@+2`E<R#!V5T`6[;SP,X@)7,@+R`E<UT`7T&P_+BN`%]$Q^`@P?:_\@"U
MM;_RN+L`7TFQU[BR(+S3O+HN+BX`7TRWSK'7OL:_]`!?;;BUQ:D@O/;!I"XN
M+@!?3[RQQ<.[Y\?7`%]RN+7%J2"[Z,&F+BX`7W3'I2"\T[RZ+BXN`,#/`,#/
M`,#/`,'970"_^0#`S+BG`""PL,"ZLZ^_H0`@L+#`NB#!UK^A`,;;O+[&K@#'
MR+R_`,#,N*<@OOC`O0!V0V%R9`#!U@"Y^,*P(,'6OZ$Z`,'6`+/B````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]K<F]N;VQI=&@O;&]C86QE+VQT7TQ4+P``````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4Q`#`R,#<Q,``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O;'1?3%0O
M3$-?34534T%'15,O````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-3$`,#(R-#<U`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L
M:71H+VQO8V%L92]L=%],5"],0U]-15-304=%4R]K<F]N;VQI=&@N;6\`````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#,W,C`P-P`Q,#0Q-S,V,C<U,0`P,C4P-3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````!N!P``'```
M`(P[``#K"0``_'8```````"HG@``#@```*F>```/````N)X```@```#(G@``
M#````-&>```$````WIX```P```#CG@``"0```/">```/````^IX```L````*
MGP``'P```!:?```.````-I\```4```!%GP``*````$N?```*````=)\``!4`
M``!_GP``$@```)6?```+````J)\``!T```"TGP``#@```-*?```*````X9\`
M``T```#LGP``#@```/J?```1````":````T````;H```#````"F@```-````
M-J````8```!$H```'0```$N@```=````::````\```"'H```&````)>@```,
M````L*````<```"]H```#@```,6@```.````U*````@```#CH```+@```.R@
M```:````&Z$``#(````VH0``.````&FA``!4````HJ$``%$```#WH0``6@``
M`$FB``!7````I*(``#0```#\H@```@```#&C```*````-*,```4````_HP``
M!@```$6C```1````3*,```@```!>HP``"0```&>C```)````<:,```@```![
MHP``)0```(2C```@````JJ,``!````#+HP``#P```-RC```*````[*,``!``
M``#WHP```P````BD```/````#*0``!0````<I```"0```#&D```)````.Z0`
M``T```!%I```$@```%.D```9````9J0```\```"`I```#P```)"D```-````
MH*0```H```"NI```#P```+FD```(````R:0``"0```#2I```%````/>D```6
M````#*4```@````CI0``&0```"RE```'````1J4```P```!.I0``+````%NE
M```.````B*4```,```"7I0``#P```)NE```+````JZ4```4```"WI0``"@``
M`+VE```4````R*4```H```#=I0``!P```.BE```'````\*4```4```#XI0``
M!0```/ZE```*````!*8```,````/I@``#0```!.F```7````(:8```H````Y
MI@``"@```$2F```/````3Z8```L```!?I@``!P```&NF```-````<Z8```H`
M``"!I@``#@```(RF```8````FZ8``",```"TI@``#@```-BF```4````YZ8`
M`!<```#\I@``%P```!2G```7````+*<``!,```!$IP``#P```%BG```.````
M:*<``!\```!WIP``!P```)>G```&````GZ<```@```"FIP``#P```*^G```&
M````OZ<```H```#&IP``$P```-&G```#````Y:<```L```#IIP``%0```/6G
M```5````"Z@```<````AJ```!0```"FH```5````+Z@``!$```!%J```#```
M`%>H```[````9*@```D```"@J```!P```*JH```4````LJ@```,```#'J```
M!0```,NH```0````T:@```D```#BJ```$P```.RH```Y`````*D``!(````Z
MJ0```@```$VI``"T````4*D``"<````%J@``+````"VJ```J````6JH``"4`
M``"%J@``"@```*NJ```)````MJH```H```#`J@``!@```,NJ```)````TJH`
M``<```#<J@``+P```.2J```W````%*L``"X```!,JP``50```'NK```M````
MT:L``"T```#_JP``+0```"VL``!`````6ZP``",```"<K```(P```,"L```M
M````Y*P``#,````2K0``%0```$:M```9````7*T``"D```!VK0``)````*"M
M```1````Q:T```H```#7K0``#````.*M```*````[ZT``!````#ZK0``%@``
M``NN```6````(JX```<````YK@``!P```$&N```4````2:X```H```!>K@``
M"````&FN```(````<JX```P```![K@``!P```(BN```'````D*X```8```"8
MK@``!0```)^N```'````I:X```8```"MK@``"````+2N```.````O:X```H`
M``#,K@``!````->N```'````W*X```D```#DK@``!@```.ZN```1````]:X`
M``<````'KP``%@````^O```$````)J\```@````KKP``!@```#2O```-````
M.Z\```8```!)KP``'@```%"O```1````;Z\```@```"!KP``#0```(JO```,
M````F*\```<```"EKP``!````*VO```#````LJ\```,```"VKP``%P```+JO
M```)````TJ\``!,```#<KP``"0```/"O```(````^J\``!`````#L```"0``
M`!2P```$````'K````@````CL```"````"RP``!!````-;```"````!WL```
M&0```)BP```&````LK````8```"YL```%0```,"P```)````UK````T```#@
ML```&````.ZP```B````![$``"X````JL0``'0```%FQ```A````=[$``%0`
M``"9L0``*0```.ZQ```*````&+(```<````CL@``"0```"NR```5````-;(`
M``@```!+L@``#@```%2R```*````8[(```\```!NL@``#0```'ZR```/````
MC+(```T```"<L@``"0```*JR```4````M+(```8```#)L@``&````-"R```=
M````Z;(``!,````'LP``%````!NS```$````,+,```8````ULP``5````#RS
M```$````D;,```X```"6LP``!0```*6S```%````J[,``!L```"QLP``&@``
M`,VS```1````Z+,``!$```#ZLP``'`````RT```J````*;0``#8```!4M```
M$````(NT```A````G+0```4```"^M```$P```,2T```2````V+0```H```#K
MM```#P```/:T```1````!K4``!,````8M0``#````"RU```&````.;4```8`
M``!`M0``%P```$>U```1````7[4```@```!QM0``!0```'JU```,````@+4`
M`!````"-M0``!0```)ZU```-````I+4```8```"RM0``%@```+FU```'````
MT+4```T```#8M0``!P```.:U```+````[K4```<```#ZM0``!P````*V```)
M````"K8```H````4M@``&0```!^V```,````.;8``!````!&M@``&P```%>V
M```)````<[8```4```!]M@``)0```(.V```2````J;8``!,```"\M@``*P``
M`-"V```[````_+8``"`````XMP``-@```%FW```(````D+<```P```"9MP``
M!@```*:W```$````K;<```X```"RMP``"@```,&W```-````S+<``!X```#:
MMP``&P```/FW```A````%;@``!X````WN```&0```%:X```>````<+@``!L`
M``"/N```)@```*NX```;````TK@``!X```#NN```'`````VY```F````*KD`
M`#,```!1N0``)@```(6Y```K````K+D``#@```#8N0``+P```!&Z```2````
M0;H``"D```!4N@``$@```'ZZ``"B````D;H``!8````TNP``(P```$N[```H
M````;[L``"D```"8NP``*````,*[```?````Z[L``"`````+O```)0```"R\
M```A````4KP``!P```!TO```)@```)&\``!!````N+P```P```#ZO```!P``
M``>]```'````#[T```8````7O0``$@```!Z]```-````,;T``!`````_O0``
M$@```%"]```'````8[T``!,```!KO0``$@```'^]```'````DKT```0```":
MO0``!P```)^]```,````I[T```X```"TO0``#P```,.]```3````T[T```T`
M``#GO0``*````/6]```#````'KX```T````BO@``!@```#"^```1````-[X`
M`!<```!)O@``&P```&&^```.````?;X```(```",O@``!0```(^^```3````
ME;X``!````"IO@``!````+J^```-````O[X```X```#-O@```P```-R^```&
M````X+X```<```#GO@``#@```.^^```(````_KX```\````'OP``"````!>_
M```/````(+\```T````POP``$````#Z_```+````3[\```8```!;OP``"0``
M`&*_```,````;+\```P```!YOP``$0```(:_```9````F+\```L```"ROP``
M#0```+Z_```B````S+\```H```#OOP``&````/J_```9````$\```%P````M
MP```%@```(K````-````H<````<```"OP```#````+?````4````Q,````L`
M``#9P```(@```.7````O````",$```L````XP0``"0```$3!```9````3L$`
M``L```!HP0``%P```'3!```7````C,$```D```"DP0``!P```*[!```6````
MML$```\```#-P0``%@```-W!```.````],$``!@````#P@``"````!S"```-
M````)<(``"8````SP@``#@```%K"``!#````:<(```@```"MP@``$@```+;"
M```(````R<(```L```#2P@``+P```-["```.````#L,```4````=PP``!P``
M`"/#```(````*\,```8````TPP```P```#O#```'````/\,```<```!'PP``
M#@```$_#```*````7L,```H```!IPP``#P```'3#```0````A,,``!<```"5
MPP``%0```*W#```.````P\,``!$```#2PP``%P```.3#```)````_,,```4`
M```&Q```"P````S$```*````&,0```(````CQ```!0```";$```-````+,0`
M`!L````ZQ```%P```%;$```)````;L0```X```!XQ```#0```(?$```2````
ME<0``#@```"HQ```(````.'$```(`````L4```8````+Q0``"````!+%```(
M````&\4```X````DQ0``>P```#/%```8````K\4``!$```#(Q0``!P```-K%
M```%````XL4``#$```#HQ0``&0```!K&```'````-,8```@````\Q@``!@``
M`$7&```&````3,8``!,```!3Q@``$````&?&```/````>,8``!````"(Q@``
M#P```)G&```+````J<8```\```"UQ@``#````,7&```/````TL8```<```#B
MQ@``!@```.K&```,````\<8``"@```#^Q@``#P```"?'```(````-\<```8`
M``!`QP``#P```$?'```(````5\<``!,```!@QP``'@```'3'```A````D\<`
M`"````"UQP``&0```-;'```7````\,<``"4````(R```%P```"[(```$````
M1L@``!L```!+R```#0```&?(```#````=<@```@```!YR```"@```(+(```,
M````C<@```L```":R```!````*;(```3````J\@``!0```"_R```#````-3(
M```)````X<@```X```#KR```"P```/K(```;````!LD```<````BR0``!```
M`"K)```'````+\D```H````WR0``#0```$+)```)````4,D```0```!:R0``
M!0```%_)```#````9<D``!@```!IR0``"@```(+)```$````C<D``"8```"2
MR0``#@```+G)``!\````R,D``!4```!%R@``!0```%O*```'````8<H```P`
M``!IR@``"````';*```*````?\H```8```"*R@``"````)'*```"````FLH`
M``8```"=R@``!@```*3*```4````J\H```T```#`R@``$````,[*```;````
MW\H```8```#[R@``!`````++```)````!\L``!`````1RP``"0```"++```)
M````+,L```8````VRP``!0```#W+```:````0\L```@```!>RP``!@```&?+
M```$````;LL```<```!SRP``&0```'O+```.````E<L```<```"DRP``!P``
M`*S+```%````M,L```D```"ZRP``"@```,3+```"````S\L```8```#2RP``
M#0```-G+```'````Y\L```D```#ORP``!@```/G+```2`````,P```D````3
MS```!P```!W,```4````)<P``!T````ZS```!@```%C,```*````7\P```0`
M``!JS```"0```&_,```(````><P``!$```""S```"0```)3,```&````GLP`
M``T```"ES```!@```+/,```$````NLP``#D```"_S```/0```/G,```Z````
M-\T``!X```!RS0``!0```)'-```.````E\T```0```"FS0``!@```*O-```A
M````LLT``!4```#4S0``!@```.K-```$````\<T``!$```#VS0``!@````C.
M```*````#\X``"(````:S@``!````#W.```%````0LX``!T```!(S@``!```
M`&;.```,````:\X```H```!XS@``"````(/.```)````C,X```4```"6S@``
M.@```)S.```P````U\X``#4````(SP``*0```#[/``!'````:,\``#@```"P
MSP``*0```.G/```_````$]```"X```!3T```+0```(+0```?````L-````\`
M``#0T```$@```.#0```+````\]````<```#_T```)@````?1```I````+M$`
M`"0```!8T0``)@```'W1```(````I-$```H```"MT0``"0```+C1```'````
MPM$``"````#*T0``(````.O1```F````#-(```H````ST@``&0```#[2```I
M````6-(``!8```""T@``$@```)G2```'````K-(```H```"TT@``#P```+_2
M```0````S](``$````#@T@``9@```"'3```.````B-,```D```"7TP``"@``
M`*'3```2````K-,``!,```"_TP``#````-/3```&````X-,``!@```#GTP``
M#P````#4```6````$-0``!(````GU```$````#K4```1````2]0``!P```!=
MU```(P```'K4``!J````GM0```\````)U0``!0```!G5```0````']4```D`
M```PU0``!````#K5```+````/]4``!0```!+U0``#````&#5```,````;=4`
M``\```!ZU0``%0```(K5```I````H-4``"H```#*U0``)@```/75```G````
M'-8``"D```!$U@``*@```&[6```9````F=8``$(```"SU@``$0```/;6```2
M````"-<``!,````;UP``%````"_7```/````1-<``!8```!4UP``%P```&O7
M```0````@]<``!$```"4UP``-````*;7```3````V]<``!(```#OUP``-0``
M``+8```4````.-@```<```!-V```#````%78```@````8M@``!0```"#V```
M$0```)C8```7````JM@``!P```#"V```$P```-_8```1````\]@``!H````%
MV0``'@```"#9```:````/]D``!$```!:V0``%````&S9```7````@=D``!4`
M``"9V0``"0```*_9```9````N=D```0```#3V0``!P```-C9```+````X-D`
M`!$```#LV0``!@```/[9```&````!=H```8````,V@``!0```!/:```'````
M&=H```<````AV@``!0```"G:```6````+]H```8```!&V@``!@```$W:```$
M````5-H```0```!9V@``!P```%[:```.````9MH```P```!UV@``#````(+:
M```-````C]H```H```"=V@``#@```*C:```%````M]H``"@```"]V@``#@``
M`.;:```,````]=H```\````"VP``"@```!+;```(````'=L```D````FVP``
M*P```##;```(````7-L```0```!EVP``"````&K;```F````<]L``!(```":
MVP``#P```*W;```&````O=L```H```#$VP``!P```,_;```(````U]L``"``
M``#@VP``#0````'<```)````#]P```T````9W```"@```"?<```,````,MP`
M``T````_W```#@```$W<```6````7-P``!$```!SW```"0```(7<```&````
MC]P```,```"6W```!@```)K<```9````H=P```<```"[W```!````,/<```+
M````R-P```L```#4W```!P```.#<```'````Z-P``!8```#PW```#0````?=
M```-````%=T```H````CW0``$````"[=```/````/]T``!$```!/W0``%P``
M`&'=```*````>=T``!$```"$W0``"````);=```>````G]T```0```"^W0``
M#P```,/=```Z````T]T```4````.W@``#````!3>```>````(=X```X```!`
MW@``$````$_>```+````8-X```P```!LW@``"0```'G>```'````@]X```H`
M``"+W@``"0```);>```.````H-X``!````"OW@``&@```,#>```*````V]X`
M``D```#FW@``"0```/#>```*````^MX```P````%WP``#P```!+?```(````
M(M\```8````KWP``!P```#+?```+````.M\``$<```!&WP``#0```([?```)
M````G-\```0```"FWP```P```*O?```3````K]\``!,```##WP``$P```-??
M```*````Z]\```(```#VWP``!````/G?```E````_M\```,````DX```!0``
M`"C@```J````+N````H```!9X```!0```&3@```$````:N````H```!OX```
M#0```'K@```&````B.````@```"/X```"````)C@```$````H>````4```"F
MX```&````*S@``!H````Q>````D````NX0``#````#CA```%````1>$```8`
M``!+X0``&P```%+A```O````;N$``!````">X0``"@```*_A```/````NN$`
M``H```#*X0``"0```-7A```3````W^$``!L```#SX0``&`````_B```7````
M*.(```X```!`X@```P```$_B```'````4^(```@```!;X@``!P```&3B```'
M````;.(```D```!TX@``"@```'[B```+````B>(```<```"5X@``40```)WB
M```0````[^(```P`````XP``#0````WC```:````&^,``$H````VXP``!@``
M`('C```&````B.,```8```"/XP``'P```);C```&````MN,```D```"]XP``
M&````,?C```7````X.,```D```#XXP``!@````+D```-````">0``!(````7
MY```(@```"KD``!7````3>0``!,```"EY```(P```+GD```3````W>0```(`
M``#QY```"P```/3D```(`````.4```T````)Y0``"@```!?E```'````(N4`
M`!0````JY0``!@```#_E```&````1N4```@```!-Y0``!0```%;E```*````
M7.4```X```!GY0``!P```';E```3````?N4``!4```"2Y0``#````*CE```-
M````M>4```H```##Y0``"P```,[E```'````VN4```P```#BY0``#0```._E
M```,````_>4```D````*Y@``"0```!3F```*````'N8```<````IY@``"0``
M`#'F```'````.^8```H```!#Y@``&P```$[F``!"````:N8``!(```"MY@``
M"@```,#F```,````R^8```T```#8Y@``"0```.;F```0````\.8```<````!
MYP``$@````GG```$````'.<```<````AYP``!0```"GG```%````+^<```L`
M```UYP``%````$'G```1````5N<``!H```!HYP``%@```(/G```4````FN<`
M`!<```"OYP``&````,?G```<````X.<``!D```#]YP``!P```!?H```%````
M'^@```T````EZ```#````#/H```)````0.@```@```!*Z```%P```%/H```+
M````:^@``!,```!WZ```!````(OH```*````D.@```0```";Z```#0```*#H
M```(````KN@```H```"WZ```"0```,+H```(````S.@```P```#5Z```"0``
M`.+H```)````[.@```4```#VZ```!P```/SH```%````!.D```0````*Z0``
M#`````_I```X````'.D``"P```!5Z0``$@```(+I```I````E>D``#(```"_
MZ0``)0```/+I```*````&.H``"P````CZ@``+@```%#J```S````?^H``#,`
M``"SZ@``.````.?J```/````(.L``!@````PZP``"P```$GK```4````5>L`
M`!````!JZP``+````'OK```<````J.L``!,```#%ZP``%````-GK```2````
M[NL``!0````![```%0```!;L```M````+.P``"T```!:[```,0```(CL```N
M````NNP``"\```#I[```+````!GM``!B````1NT``!,```"I[0``"````+WM
M```(````QNT``"L```#/[0``(0```/OM```:````'>X``!P````X[@``"0``
M`%7N``!%````7^X``$$```"E[@``!````.?N```3````[.X``!0`````[P``
M#@```!7O```3````).\``!@````X[P``!@```%'O```)````6.\```H```!B
M[P``#P```&WO```)````?>\``!````"'[P``!P```)CO```.````H.\```4`
M``"O[P``&P```+7O```(````T>\```,```#:[P``!@```-[O```4````Y>\`
M`!$```#Z[P``#@````SP```X````&_````(```!4\```!@```%?P```.````
M7O````4```!M\```!P```'/P```.````>_````8```"*\```!````)'P```I
M````EO```!<```#`\```'P```-CP``!<````^/```!0```!5\0``'P```&KQ
M```0````BO$```@```";\0``!P```*3Q```.````K/$```P```"[\0``#```
M`,CQ```3````U?$```H```#I\0``'0```/3Q```9````$O(```4````L\@``
M$0```#+R```%````1/(``!$```!*\@``)````%SR```5````@?(``!(```"7
M\@``#@```*KR```9````N?(```@```#3\@``"0```-SR```"````YO(```T`
M``#I\@``"@```/?R```+`````O,```H````.\P``!P```!GS```(````(?,`
M``4````J\P``'P```##S```-````4/,```8```!>\P``$````&7S```(````
M=O,```T```!_\P``"````(WS```2````EO,``"P```"I\P``&@```-;S```)
M````\?,```H```#[\P``%0````;T```0````'/0```4````M]```%````#/T
M```$````2/0```<```!-]```$````%7T```&````9O0```<```!M]```'@``
M`'7T```H````E/0``!X```"]]```"@```-ST```1````Y_0```L```#Y]```
M&@````7U```4````(/4```0````U]0``!````#KU```+````/_4```4```!+
M]0``!@```%'U```(````6/4```8```!A]0``"@```&CU```;````<_4``#0`
M``"/]0``-````,3U```@````^?4``"D````:]@``(````$3V``!!````9?8`
M`!H```"G]@``*````,+V```I````Z_8``"(````5]P``!@```#CW```(````
M/_<```4```!(]P``#@```$[W```(````7?<``!D```!F]P``&0```(#W```J
M````FO<``",```#%]P``+@```.GW```T````&/@```@```!-^```%P```%;X
M```*````;O@```<```!Y^```(0```('X```,````H_@```T```"P^```#```
M`+[X```0````R_@```X```#<^```"P```.OX```'````]_@``!,```#_^```
M"````!/Y```+````'/D```H````H^0``%````#/Y```R````2/D```L```![
M^0``!0```(?Y```%````C?D``!<```"3^0``#P```*OY```$````N_D```H`
M``#`^0``"0```,OY```+````U?D```X```#A^0``!0```/#Y```$````]OD`
M``T```#[^0``,@````GZ``!%````//H```L```""^@``"@```([Z```/````
MF?H``!,```"I^@``$P```+WZ```/````T?H```P```#A^@``#@```.[Z```-
M````_?H```T````+^P``%P```!G[```>````,?L``!0```!0^P``!0```&7[
M```4````:_L```<```"`^P``#````(C[```0````E?L``!$```"F^P``#@``
M`+C[```J````Q_L```8```#R^P``"0```/G[```/`````_P```P````3_```
M#0```"#\```1````+OP```L```!`_```-@```$S\```*````@_P``"(```".
M_```"P```+'\```/````O?P``#(```#-_```"`````#]```2````"?T```4`
M```<_0``#@```"+]```3````,?T``!$```!%_0``"````%?]```'````8/T`
M`!$```!H_0``!P```'K]```4````@OT``!@```"7_0``!P```+#]```%````
MN/T```P```"^_0``#````,O]```2````V/T```0```#K_0``!P```/#]```*
M````^/T```L````#_@``#`````_^```.````'/X```X````K_@``!0```#K^
M```%````0/X``"X```!&_@``)@```'7^```C````G/X```,```#`_@``$@``
M`,3^```&````U_X``!X```#>_@``&````/W^```E````%O\```T````\_P``
M"0```$K_```#````5/\```<```!8_P``"@```&#_```"````:_\```P```!N
M_P``%0```'O_```+````D?\``!D```"=_P``(````+?_```2````V/\```4`
M``#K_P``"@```/'_```5````_/\``!(````2``$`"````"4``0`,````+@`!
M``<````[``$`"P```$,``0`*````3P`!``P```!:``$`4@```&<``0`7````
MN@`!``<```#2``$`!@```-H``0`.````X0`!``P```#P``$`#0```/T``0`5
M````"P$!`!(````A`0$`#P```#0!`0`4````1`$!`!L```!9`0$`$````'4!
M`0!8````A@$!`"$```#?`0$`:0````$"`0`:````:P(!`!<```"&`@$`&0``
M`)X"`0`:````N`(!`!D```#3`@$`)0```.T"`0`G````$P,!`!H````[`P$`
M%P```%8#`0`=````;@,!`"8```",`P$`&P```+,#`0`J````SP,!`!D```#Z
M`P$`'P```!0$`0`3````-`0!``@```!(!`$`1````%$$`0`3````E@0!`$``
M``"J!`$`!P```.L$`0`(````\P0!``D```#\!`$`%0````8%`0`-````'`4!
M`!,````J!0$``P```#X%`0`,````0@4!`$8```!/!0$`%P```)8%`0`.````
MK@4!`#\```"]!0$`-P```/T%`0!7````-08!`!\```"-!@$`+P```*T&`0`*
M````W08!`!````#H!@$`$0```/D&`0`(````"P<!``T````4!P$`+0```"('
M`0`$````4`<!`!4```!5!P$`.P```&L'`0!/````IP<!`!\```#W!P$`%@``
M`!<(`0`E````+@@!`"@```!4"`$`'````'T(`0`+````F@@!`!\```"F"`$`
M'0```,8(`0`E````Y`@!`"`````*"0$`)````"L)`0`@````4`D!`#````!Q
M"0$`"P```*()`0`'````K@D!``T```"V"0$`#````,0)`0`&````T0D!`#D`
M``#8"0$`#````!(*`0`'````'PH!``D````G"@$`$P```#$*`0`)````10H!
M``0```!/"@$`$````%0*`0`(````90H!``@```!N"@$`"P```'<*`0`,````
M@PH!`!H```"0"@$`#P```*L*`0`'````NPH!``T```##"@$`%````-$*`0`.
M````Y@H!``P```#U"@$`&P````(+`0`L````'@L!`!,```!+"P$`'````%\+
M`0`H````?`L!``8```"E"P$`!P```*P+`0`3````M`L!``4```#("P$`!```
M`,X+`0`7````TPL!``H```#K"P$`#````/8+`0`)`````PP!``8````-#`$`
M"0```!0,`0`(````'@P!``D````G#`$`"@```#$,`0`(````/`P!``H```!%
M#`$`"@```%`,`0`'````6PP!`!$```!C#`$`!@```'4,`0`.````?`P!``X`
M``"+#`$`#0```)H,`0`+````J`P!`!T```"T#`$`"P```-(,`0`"````W@P!
M``<```#A#`$`!@```.D,`0`)````\`P!``<```#Z#`$`.P````(-`0`H````
M/@T!`!4```!G#0$`!0```'T-`0`'````@PT!``@```"+#0$`!P```)0-`0`&
M````G`T!``4```"C#0$`!P```*D-`0`.````L0T!``D```#`#0$`!@```,H-
M`0`(````T0T!``L```#:#0$`!P```.8-`0`(````[@T!``<```#W#0$`%@``
M`/\-`0`)````%@X!``8````@#@$`"P```"<.`0`<````,PX!`!0```!0#@$`
M!P```&4.`0`(````;0X!``@```!V#@$`!0```'\.`0`0````A0X!`!````"6
M#@$`!@```*<.`0`9````K@X!``H```#(#@$`'````-,.`0`'````\`X!``4`
M``#X#@$`$````/X.`0`4````#P\!``L````D#P$`#0```#`/`0`7````/@\!
M``D```!6#P$`!````&`/`0`)````90\!``H```!O#P$`!P```'H/`0`"````
M@@\!``X```"%#P$`"````)0/`0`?````G0\!`#@```"]#P$`(P```/8/`0`X
M````&A`!`#$```!3$`$`)P```(40`0!D````K1`!`!0````2$0$`)````"<1
M`0`C````3!$!`"L```!P$0$`(0```)P1`0!5````OA$!`#@````4$@$`2@``
M`$T2`0!;````F!(!`"@```#T$@$`.````!T3`0`O````5A,!`#,```"&$P$`
M*````+H3`0`L````XQ,!`"<````0%`$`&P```#@4`0`^````5!0!`#H```"3
M%`$`J0$``,X4`0`C````>!8!`!<```"<%@$`2````+06`0"%````_18!`#``
M``"#%P$`00```+07`0!;````]A<!`$D```!2&`$`'0```)P8`0`8````NA@!
M`"$```#3&`$`'P```/48`0`K````%1D!`"$```!!&0$`'0```&,9`0`1````
M@1D!`#,```"3&0$`)0```,<9`0`G````[1D!`#(````5&@$`'P```$@:`0`P
M````:!H!`&D```"9&@$`/0````,;`0!E````01L!`$T```"G&P$`+0```/4;
M`0`G````(QP!`"\```!+'`$`*````'L<`0`N````I!P!`#````#3'`$`5```
M``0=`0`G````61T!`%H```"!'0$`.@```-P=`0!(````%QX!`$H```!@'@$`
M'P```*L>`0`R````RQX!`"\```#^'@$`+````"X?`0`M````6Q\!`'$```")
M'P$`;P```/L?`0"S````:R`!`!<````?(0$`)0```#<A`0`R````72$!`"D`
M``"0(0$`/@```+HA`0`B````^2$!`%(````<(@$`(@```&\B`0`E````DB(!
M``L```"X(@$`L0```,0B`0`@````=B,!`$4```"7(P$`(0```-TC`0`P````
M_R,!`"4````P)`$`'````%8D`0`Q````<R0!``<```"E)`$`"````*TD`0`'
M````MB0!``0```"^)`$`"@```,,D`0`-````SB0!``L```#<)`$`#@```.@D
M`0`)````]R0!``L````!)0$`!@````TE`0`%````%"4!`!`````:)0$``@``
M`"LE`0!9````+B4!``4```"()0$`$@```(XE`0`$````H24!``<```"F)0$`
M"````*XE`0`%````MR4!``,```"])0$`$````,$E`0`,````TB4!`!,```#?
M)0$`#0```/,E`0`"`````28!``<````$)@$`!P````PF`0`&````%"8!`!0`
M```;)@$`#````#`F`0`8````/28!``8```!6)@$`!````%TF`0`2````8B8!
M``P```!U)@$`*@```((F`0`$````K28!``8```"R)@$`!P```+DF`0`?````
MP28!`#4```#A)@$`+@```!<G`0`O````1B<!`!<```!V)P$`(````(XG`0`;
M````KR<!`!@```#+)P$`)````.0G`0`?````"2@!`!H````I*`$`(````$0H
M`0`:````92@!`#(```"`*`$`&0```+,H`0`O````S2@!`!0```#]*`$`*P``
M`!(I`0`?````/BD!`",```!>*0$`'P```((I`0`:````HBD!`"4```"]*0$`
M)@```.,I`0`E````"BH!`"0````P*@$`&````%4J`0`=````;BH!`"0```",
M*@$`&````+$J`0`B````RBH!`"4```#M*@$`&0```!,K`0`\````+2L!`!\`
M``!J*P$`(P```(HK`0`?````KBL!`"````#.*P$`&@```.\K`0`O````"BP!
M`!@````Z+`$`)@```%,L`0`>````>BP!`"D```"9+`$`'@```,,L`0`)````
MXBP!``P```#L+`$`%P```/DL`0`O````$2T!`"0```!!+0$`!P```&8M`0`/
M````;BT!`!0```!^+0$`#@```),M`0`-````HBT!`"0```"P+0$`!0```-4M
M`0`'````VRT!`"(```#C+0$`)0````8N`0`=````+"X!`!H```!*+@$`!P``
M`&4N`0#'````;2X!``L````U+P$`%0```$$O`0`&````5R\!``D```!>+P$`
M"P```&@O`0`,````="\!`!<```"!+P$`!@```)DO`0`S````H"\!`!,```#4
M+P$`$P```.@O`0`'````_"\!``\````$,`$`!P```!0P`0`R````'#`!`"$`
M``!/,`$`$P```'$P`0`.````A3`!``P```"4,`$`$0```*$P`0`R````LS`!
M``@```#F,`$`"0```.\P`0`*````^3`!`!0````$,0$`"@```!DQ`0`=````
M)#$!``@```!",0$`'P```$LQ`0`(````:S$!`!H```!T,0$`!@```(\Q`0`5
M````EC$!``<```"L,0$`"````+0Q`0`)````O3$!`#\```#',0$`!P````<R
M`0`/````#S(!``X````?,@$`$````"XR`0`)````/S(!``D```!),@$`"```
M`%,R`0`3````7#(!``<```!P,@$`"````'@R`0`9````@3(!``H```";,@$`
M%P```*8R`0`4````OC(!``H```#3,@$`#````-XR`0`7````ZS(!``0````#
M,P$`*@````@S`0`1````,S,!``<```!%,P$``@```$TS`0`0````4#,!`!@`
M``!A,P$`"P```'HS`0`#````AC,!``@```"*,P$`"0```),S`0`$````G3,!
M``<```"B,P$`!P```*HS`0`&````LC,!`!0```"Y,P$`!P```,XS`0`-````
MUC,!``L```#D,P$`%````/`S`0`5````!30!``X````;-`$`+P```"HT`0`@
M````6C0!`!P```![-`$`2````)@T`0!,````X30!``P````N-0$`,0```#LU
M`0`%````;34!`!(```!S-0$`/P```(8U`0`2````QC4!``H```#9-0$`!@``
M`.0U`0`$````ZS4!`!,```#P-0$`!0````0V`0`&````"C8!``8````1-@$`
M!````!@V`0`,````'38!``H````J-@$`"0```#4V`0`%````/S8!`!@```!%
M-@$`&0```%XV`0`?````>#8!`!T```"8-@$`$0```+8V`0`"````R#8!``0`
M``#+-@$`"@```-`V`0`&````VS8!`!0```#B-@$`!0```/<V`0`#````_38!
M``P````!-P$`10````XW`0`:````5#<!`#4```!O-P$`.@```*4W`0`H````
MX#<!`%,````).`$`+P```%TX`0!"````C3@!`#````#0.`$`+@````$Y`0`9
M````,#D!`"<```!*.0$`<@```'(Y`0`@````Y3D!`#4````&.@$`10```#PZ
M`0`P````@CH!`"D```"S.@$`(0```-TZ`0`H````_SH!`"D````H.P$`)@``
M`%([`0`E````>3L!`"@```"?.P$`*````,@[`0`B````\3L!`#`````4/`$`
M$@```$4\`0`3````6#P!`!````!L/`$`>0```'T\`0`)````]SP!`',````!
M/0$`?````'4]`0`K````\CT!`!<````>/@$`%0```#8^`0`6````3#X!``\`
M``!C/@$`'P```',^`0`?````DSX!`!P```"S/@$`40```-`^`0`4````(C\!
M``H````W/P$`!0```$(_`0`&````2#\!``@```!//P$`!0```%@_`0`2````
M7C\!`!````!Q/P$`$P```((_`0`=````EC\!``\```"T/P$`#P```,0_`0`/
M````U#\!``T```#D/P$`!````/(_`0`)````]S\!``L````!0`$`!0````U`
M`0`%````$T`!``<````90`$`!0```"%``0`4````)T`!``X````\0`$`!P``
M`$M``0`(````4T`!``\```!<0`$`"@```&Q``0`(````=T`!``P```"`0`$`
M!@```(U``0`/````E$`!``<```"D0`$`!@```*Q``0`4````LT`!``8```#(
M0`$`!@```,]``0`,````UD`!`!<```#C0`$`"````/M``0`$````!$$!``H`
M```)00$``P```!1!`0`&````&$$!``0````?00$`"@```"1!`0`*````+T$!
M``<````Z00$`!````$)!`0`$````1T$!`!D```!,00$``@```&9!`0`)````
M:4$!``8```!S00$`!@```'I!`0`G````@4$!``@```"I00$`!````+)!`0`/
M````MT$!`!,```#'00$`!P```-M!`0`0````XT$!`!,```#T00$`!P````A"
M`0`&````$$(!``8````70@$`$````!Y"`0`2````+T(!``8```!"0@$`"0``
M`$E"`0`B````4T(!``<```!V0@$`!P```'Y"`0`+````AD(!`!,```"20@$`
M!0```*9"`0`1````K$(!``(```"^0@$`"P```,%"`0`$````S4(!``L```#2
M0@$`!0```-Y"`0`'````Y$(!`%L!``#L0@$`$@```$A$`0`.````6T0!``L`
M``!J1`$`"````'9$`0`!````?T0!``L```"!1`$`"@```(U$`0`1````F$0!
M``P```"J1`$`,P```+=$`0`-````ZT0!``4```#Y1`$`*0```/]$`0`/````
M*44!``P````Y10$`$@```$9%`0`(````644!`!L```!B10$`$0```'Y%`0`*
M````D$4!``P```";10$`$P```*A%`0`1````O$4!``X```#.10$`$0```-U%
M`0`0````[T4!``8`````1@$`)@````=&`0`:````+D8!``X```!)1@$`%0``
M`%A&`0`1````;D8!``@```"`1@$`$P```(E&`0`3````G48!``L```"Q1@$`
M+````+U&`0`2````ZD8!`#T```#]1@$`20```#M'`0!E````A4<!`&8```#K
M1P$`:````%)(`0!I````NT@!`$`````E20$``@```&9)`0`*````:4D!``4`
M``!T20$`!@```'I)`0`2````@4D!``<```"420$`$0```)Q)`0`3````KDD!
M``<```#"20$`*P```,I)`0`H````]DD!``L````?2@$`$P```"M*`0`(````
M/TH!``\```!(2@$`!@```%A*`0`/````7TH!`!````!O2@$`#0```(!*`0`0
M````CDH!`!,```"?2@$`%0```+-*`0`A````R4H!`!,```#K2@$`&@```/]*
M`0`0````&DL!`!`````K2P$`%@```#Q+`0`,````4TL!`"T```!@2P$`&@``
M`(Y+`0`?````J4L!`!$```#)2P$`'````-M+`0`'````^$L!``X`````3`$`
M.0````],`0`(````24P!``@```!23`$`#@```%M,`0`,````:DP!``L```!W
M3`$`#P```(-,`0`E````DTP!`!$```"Y3`$`"````,M,`0`'````U$P!``@`
M``#<3`$`"````.5,`0`+````[DP!``0```#Z3`$`#0```/],`0`:````#4T!
M``L````H30$`#````#1-`0`,````04T!``L```!.30$`"@```%I-`0`3````
M94T!``P```!Y30$`%````(9-`0`4````FTT!`"$```"P30$`#@```-)-`0`?
M````X4T!`!T````!3@$`(@```!].`0`>````0DX!`!4```!A3@$`%````'=.
M`0`.````C$X!`!L```";3@$`!@```+=.`0`&````ODX!``<```#%3@$`&0``
M`,U.`0`)````YTX!``H```#Q3@$`$@```/Q.`0`(````#T\!``<````83P$`
M%0```"!/`0`7````-D\!``L```!.3P$`"````%I/`0`7````8T\!`!,```![
M3P$`&0```(]/`0`S````J4\!``D```#=3P$`"````.=/`0`5````\$\!``4`
M```&4`$`!0````Q0`0`=````$E`!``L````P4`$`(````#Q0`0`N````75`!
M`!4```",4`$``0```*)0`0"R````I%`!`"@```!740$`*@```(!1`0`K````
MJU$!`"L```#740$`"P````-2`0`(````#U(!``D````84@$`"0```")2`0`*
M````+%(!``@````W4@$`+P```$!2`0`L````<%(!`"X```"=4@$`4````,Q2
M`0`M````'5,!`"T```!+4P$`+0```'E3`0`_````IU,!`"D```#G4P$`*P``
M`!%4`0`M````/50!`#,```!K5`$`%````)]4`0`8````M%0!`"H```#-5`$`
M)P```/A4`0`.````(%4!``T````O50$`$0```#U5`0`%````3U4!``L```!5
M50$`(0```&%5`0`F````@U4!``<```"J50$`"0```+)5`0`6````O%4!``H`
M``#350$`"@```-Y5`0`.````Z54!`!(```#X50$`"P````M6`0`'````%U8!
M``<````?5@$`!P```"=6`0`(````+U8!``<````X5@$`"P```$!6`0`0````
M3%8!``L```!=5@$`"@```&E6`0`(````=%8!``<```!]5@$`!P```(56`0`0
M````C58!``<```">5@$`%@```*96`0`%````O58!``@```##5@$`"````,Q6
M`0`*````U58!``D```#@5@$`(````.I6`0`5````"U<!``D````A5P$`$0``
M`"M7`0`.````/5<!``D```!,5P$`!@```%97`0`#````75<!``,```!A5P$`
M%P```&57`0`,````?5<!`!0```"*5P$`#````)]7`0`+````K%<!`!8```"X
M5P$`"P```,]7`0`$````VU<!``@```#@5P$`"0```.E7`0!/````\U<!`"H`
M``!#6`$`'@```&Y8`0`&````C5@!``@```"46`$`'````)U8`0`)````NE@!
M``P```#$6`$`'````-%8`0`A````[E@!`"@````060$`'P```#E9`0`I````
M65D!`%@```"#60$`+````-Q9`0`*````"5H!``L````46@$`"P```"!:`0`+
M````+%H!``H````X6@$`#0```$-:`0`1````45H!`!````!C6@$`#@```'1:
M`0`0````@UH!`!(```"46@$`$P```*=:`0`3````NUH!``8```#/6@$`'```
M`-9:`0`>````\UH!`!,````26P$`$@```"9;`0`%````.5L!``@````_6P$`
M8@```$A;`0`(````JUL!`!8```"T6P$`!````,M;`0`&````T%L!`!P```#7
M6P$`&P```/1;`0`6````$%P!`!L````G7`$`(0```$-<`0`D````95P!`$@`
M``"*7`$`"P```--<`0`/````WUP!``8```#O7`$`&````/9<`0`=````#UT!
M`!L````M70$`&P```$E=`0`%````95T!`!,```!K70$`#@```']=`0`)````
MCET!``D```"870$`%@```*)=`0`;````N5T!``D```#570$`!@```-]=`0`2
M````YET!`!0```#Y70$`"P````Y>`0`5````&EX!``@````P7@$`'0```#E>
M`0`'````5UX!`!````!?7@$`"@```'!>`0`.````>UX!``<```"*7@$`"0``
M`))>`0`,````G%X!``<```"I7@$`%````+%>`0`/````QEX!`!4```#67@$`
M(@```.Q>`0`,````#U\!``8````<7P$`'````"-?`0`5````0%\!`!8```!6
M7P$`,0```&U?`0`^````GU\!`"<```#>7P$`,@````9@`0`%````.6`!``H`
M```_8`$`#@```$I@`0`)````66`!`!4```!C8`$`"@```'E@`0`6````A&`!
M`!X```";8`$`'P```+I@`0`A````VF`!`"(```#\8`$`'0```!]A`0`H````
M/6$!`!\```!F80$`*0```(9A`0`?````L&$!`"(```#080$`'@```/-A`0`J
M````$F(!`"L````]8@$`(P```&EB`0`I````C6(!`#````"W8@$`+P```.AB
M`0`5````&&,!`"X````N8P$`%0```%UC`0"W````<V,!`!(````K9`$`(@``
M`#YD`0`G````860!`"<```")9`$`)0```+%D`0`<````UV0!`"````#T9`$`
M+P```!5E`0`@````164!`"````!F90$`+````(=E`0!'````M&4!``\```#\
M90$`"`````QF`0`&````%68!``<````<9@$`$P```"1F`0`/````.&8!`!0`
M``!(9@$`%````%UF`0`'````<F8!`!````!Z9@$`&P```(MF`0`(````IV8!
M``0```"P9@$`!P```+5F`0`1````O68!`!$```#/9@$`%@```.%F`0`4````
M^&8!`!(````-9P$`,P```"!G`0`(````5&<!`!0```!=9P$`!@```')G`0`1
M````>6<!`!<```"+9P$`'P```*-G`0`2````PV<!``(```#69P$`!P```-EG
M`0`<````X6<!`!<```#^9P$`!````!9H`0`%````&V@!`!(````A:`$`!0``
M`#1H`0`)````.F@!``@```!$:`$`$@```$UH`0`'````8&@!`!4```!H:`$`
M"@```'YH`0`5````B6@!`!(```"?:`$`%````+)H`0`+````QV@!``@```#3
M:`$`"P```-QH`0`.````Z&@!``X```#W:`$`#@````9I`0`9````%6D!``T`
M```O:0$`$0```#UI`0`J````3VD!``\```!Z:0$`&@```(II`0`4````I6D!
M`#H```"Z:0$`$P```/5I`0`1````"6H!``8````;:@$`"@```")J`0`3````
M+6H!``D```!!:@$`+@```$MJ`0`M````>FH!``@```"H:@$`"0```+%J`0`=
M````NVH!``L```#9:@$`&@```.5J`0`:`````&L!``D````;:P$`!@```"5K
M`0`:````+&L!`!4```!':P$`%0```%UK`0`3````<VL!`!P```"':P$`"```
M`*1K`0`(````K6L!`"H```"V:P$`#0```.%K`0`B````[VL!``@````2;`$`
M%````!ML`0`*````,&P!``T````[;`$`-````$EL`0`9````?FP!``<```"8
M;`$`"@```*!L`0`&````JVP!`!$```"R;`$``P```,1L`0`)````R&P!``P`
M``#2;`$`$P```-]L`0`7````\VP!``\````+;0$`$````!MM`0`0````+&T!
M`!4````];0$`(````%-M`0`2````=&T!`!(```"';0$`%0```)IM`0`'````
ML&T!``<```"X;0$`"@```,!M`0`,````RVT!``(```#8;0$`"@```-MM`0`1
M````YFT!`!\```#X;0$`(0```!AN`0`*````.FX!``X```!%;@$`$P```%1N
M`0`;````:&X!`#L```"$;@$`)@```,!N`0`-````YVX!``@```#U;@$`#P``
M`/YN`0`.````#F\!`!,````=;P$`<@```#%O`0`9````I&\!`!(```"^;P$`
M"````-%O`0`&````VF\!`#0```#A;P$`#@```!9P`0`&````)7`!``@````L
M<`$`!P```#5P`0`&````/7`!`!0```!$<`$`#@```%EP`0`-````:'`!`!``
M``!V<`$`#0```(=P`0`;````E7`!``X```"Q<`$`"@```,!P`0`+````RW`!
M``<```#7<`$`"@```-]P`0`/````ZG`!`#P```#Z<`$`#@```#=Q`0`*````
M1G$!``<```!1<0$`$@```%EQ`0`-````;'$!`!P```!Z<0$`'0```)=Q`0`H
M````M7$!`"<```#><0$`'0````9R`0`<````)'(!`"(```!!<@$`&0```&1R
M`0`'````?G(!`!H```"&<@$`#````*%R`0`&````KG(!``<```"U<@$`"@``
M`+UR`0`,````R'(!`!,```#5<@$`!@```.ER`0`9````\'(!`!P````*<P$`
M#P```"=S`0`1````-W,!`!(```!)<P$`#P```%QS`0`B````;',!``<```"/
M<P$`!P```)=S`0`'````GW,!``P```"G<P$`$@```+1S`0`7````QW,!``L`
M``#?<P$`"@```.MS`0`%````]G,!`!D```#\<P$`#0```!9T`0`'````)'0!
M`"D````L=`$`$@```%9T`0"'````:70!`!H```#Q=`$`!@````QU`0`%````
M$W4!``P````9=0$`!@```"9U`0`(````+74!``H````V=0$`#````$%U`0`%
M````3G4!``D```!4=0$`"@```%YU`0`6````:74!`!(```"`=0$`%@```)-U
M`0`@````JG4!``P```#+=0$``P```-AU`0`$````W'4!`!````#A=0$`"```
M`/)U`0`-````^W4!``<````)=@$`!P```!%V`0`U````&78!``D```!/=@$`
M!P```%EV`0`(````878!`!,```!J=@$`%P```'YV`0`2````EG8!``<```"I
M=@$`"0```+%V`0`$````NW8!``L```#`=@$`!@```,QV`0`&````TW8!``<`
M``#:=@$`#@```.)V`0`)````\78!``L```#[=@$`"`````=W`0`6````$'<!
M``L````G=P$`!P```#-W`0`6````.W<!`"$```!2=P$`!@```'1W`0`)````
M>W<!``4```"%=P$`"0```(MW`0`'````E7<!``T```"==P$`#````*MW`0`'
M````N'<!``X```#`=P$`!@```,]W`0`$````UG<!`#,```#;=P$`-P````]X
M`0`V````1W@!`"````!^>`$`!@```)]X`0`/````IG@!``4```"V>`$`"```
M`+QX`0`>````Q7@!`!8```#D>`$`!P```/MX`0`'`````WD!`"`````+>0$`
M#0```"QY`0`)````.GD!`!L```!$>0$`!@```&!Y`0`)````9WD!`"0```!Q
M>0$`"````)9Y`0`,````GWD!``X```"L>0$`"````+MY`0`)````Q'D!``@`
M``#.>0$`,P```-=Y`0`O````"WH!`#(````[>@$`)@```&YZ`0!&````E7H!
M`#H```#<>@$`*@```!=[`0`R````0GL!`#(```!U>P$`,P```*A[`0`E````
MW'L!`!(````"?`$`$P```!5\`0`.````*7P!``L````X?`$`(````$1\`0`?
M````97P!`!\```"%?`$`'0```*5\`0`)````PWP!``L```#-?`$`"@```-E\
M`0`(````Y'P!`"<```#M?`$`*````!5]`0`P````/GT!``H```!O?0$`&0``
M`'I]`0`C````E'T!``X```"X?0$`%P```,=]`0`)````WWT!``\```#I?0$`
M%0```/E]`0`3````#WX!`"@````C?@$`:0```$Q^`0`5````MGX!`!````#,
M?@$`$0```-U^`0`9````[WX!`!H````)?P$`%0```"1_`0`'````.G\!`"4`
M``!"?P$`%0```&A_`0`9````?G\!`!(```"8?P$`#@```*M_`0`8````NG\!
M`!H```#3?P$`,0```.Y_`0"C````((`!`!4```#$@`$`!@```-J``0`7````
MX8`!``H```#Y@`$`"P````2!`0`+````$($!`!L````<@0$`$P```#B!`0`/
M````3($!``\```!<@0$`&0```&R!`0`O````AH$!`"X```"V@0$`+````.6!
M`0`K````$H(!`",````^@@$`(@```&*"`0`;````A8(!`$$```"A@@$`$@``
M`.."`0`6````]H(!`!D````-@P$`&````">#`0`/````0(,!`!<```!0@P$`
M&P```&B#`0`4````A(,!`!@```"9@P$`+P```+*#`0`=````XH,!`!D`````
MA`$`,0```!J$`0`2````3(0!``@```!?A`$`#P```&B$`0`D````>(0!`!0`
M``"=A`$`#P```+*$`0`;````PH0!`!0```#>A`$`&@```/.$`0`5````#H4!
M`!T````DA0$`(P```$*%`0`>````9H4!`!<```"%A0$`%````)V%`0`=````
MLH4!`!P```#0A0$`"P```.V%`0`:````^84!``8````4A@$`!@```!N&`0`)
M````(H8!`!,````LA@$`"````$"&`0`)````288!``@```!3A@$`!P```%R&
M`0`'````9(8!``8```!LA@$`"````'.&`0`7````?(8!``<```"4A@$`"0``
M`)R&`0`%````IH8!``@```"LA@$`!@```+6&`0`/````O(8!``X```#,A@$`
M$````-N&`0`1````[(8!``L```#^A@$`%`````J'`0`&````'X<!`"P````F
MAP$`$P```%.'`0`-````9X<!``\```!UAP$`"P```(6'`0`+````D8<!`!(`
M``"=AP$`)P```+"'`0`'````V(<!``8```#@AP$`"0```.>'`0`G````\8<!
M`!(````9B`$`%0```"R(`0`(````0H@!``D```!+B`$`"P```%6(`0`%````
M88@!`"4```!GB`$`%@```(V(`0`*````I(@!`!D```"OB`$`$````,F(`0`4
M````VH@!``L```#OB`$`'````/N(`0`I````&(D!`!@```!"B0$`$0```%N)
M`0`'````;8D!``4```!UB0$`"@```'N)`0`P````AHD!``<```"WB0$`!P``
M`+^)`0`1````QXD!`!,```#9B0$`!P```.V)`0`(````]8D!`!8```#^B0$`
M#@```!6*`0`.````)(H!`!`````SB@$`%0```$2*`0`7````6HH!``\```!R
MB@$`'0```(**`0`1````H(H!`!(```"RB@$`"0```,6*`0`@````SXH!``<`
M``#PB@$`"@```/B*`0`Y`````XL!``@````]BP$`%````$:+`0`O````6XL!
M`!L```"+BP$`%0```*>+`0`6````O8L!`!8```#4BP$`%0```.N+`0`0````
M`8P!`!@````2C`$`%0```"N,`0`>````08P!`!P```!@C`$`'0```'V,`0`*
M````FXP!``<```"FC`$`!@```*Z,`0`)````M8P!`!$```"_C`$`$````-&,
M`0`%````XHP!``L```#HC`$`"@```/2,`0`3````_XP!`%0````3C0$`%0``
M`&B-`0`-````?HT!``4```",C0$`"````)*-`0`:````FXT!`!H```"VC0$`
M&@```-&-`0`-````[(T!``(```#ZC0$`!````/V-`0`H`````HX!``,````K
MC@$`!0```"^.`0`*````-8X!``P```!`C@$`!@```$V.`0`&````5(X!``X`
M``!;C@$`$P```&J.`0`'````?HX!``D```"&C@$`"````)".`0`%````F8X!
M``4```"?C@$`'P```*6.`0!7````Q8X!``\````=CP$`$@```"V/`0`%````
M0(\!``<```!&CP$`(P```$Z/`0`Q````<H\!``T```"DCP$`"0```+*/`0`/
M````O(\!``L```#,CP$`"@```-B/`0`4````XX\!`"L```#XCP$`&@```"20
M`0`9````/Y`!`!````!9D`$`!@```&J0`0`&````<9`!``@```!XD`$`#```
M`(&0`0`&````CI`!``T```"5D`$`#@```*.0`0`.````LI`!``8```#!D`$`
M3````,B0`0`2````%9$!``T````HD0$`"P```#:1`0`6````0I$!`$0```!9
MD0$`!P```)Z1`0`%````II$!``<```"LD0$`(@```+21`0`(````UY$!``H`
M``#@D0$`&0```.N1`0`:````!9(!``D````@D@$`"0```"J2`0`%````-)(!
M`!@````ZD@$`(P```%.2`0!)````=Y(!`!````#!D@$`)P```-*2`0`0````
M^I(!``4````+DP$`#@```!&3`0`)````(),!``\````JDP$`"@```#J3`0`'
M````19,!`!,```!-DP$`!P```&&3`0`+````:9,!``D```!UDP$`!0```'^3
M`0`%````A9,!`!$```"+DP$`"@```)V3`0`8````J),!`!L```#!DP$`$0``
M`-V3`0`2````[Y,!``H````"E`$`#0````V4`0`'````&Y0!`!$````CE`$`
M%````#64`0`2````2I0!``\```!=E`$`$````&V4`0`1````?I0!`!$```"0
ME`$`$````**4`0`2````LY0!``H```#&E`$`)@```-&4`0`^````^)0!`!,`
M```WE0$`#0```$N5`0`0````694!`!$```!JE0$`#0```'R5`0`7````BI4!
M``D```"BE0$`#0```*R5`0`&````NI4!``@```#!E0$`!@```,J5`0`'````
MT94!``L```#9E0$`$@```.65`0`5````^)4!`"$````.E@$`'P```#"6`0`8
M````4)8!`!8```!IE@$`'````("6`0`>````G98!`!H```"\E@$`!P```->6
M`0`'````WY8!`!(```#GE@$`$````/J6`0`-````"Y<!``X````9EP$`(P``
M`"B7`0`1````3)<!`!8```!>EP$`"0```'67`0`/````?Y<!``@```"/EP$`
M%0```)B7`0`-````KI<!``X```"\EP$`#P```,N7`0`-````VY<!`!,```#I
MEP$`#P```/V7`0`)````#9@!``<````7F`$`"````!^8`0`&````*)@!``4`
M```OF`$`#````#68`0`E````0I@!`"(```!HF`$`%P```(N8`0`@````HY@!
M`#0```#$F`$`&0```/F8`0`.````$YD!`",````BF0$`*````$:9`0`M````
M;YD!`"T```"=F0$`,@```,N9`0`4````_ID!`!(````3F@$`$P```"::`0`+
M````.IH!`!(```!&F@$`,0```%F:`0`@````BYH!`!0```"LF@$`$@```,&:
M`0`0````U)H!`!(```#EF@$`'````/B:`0`M````%9L!`"T```!#FP$`,0``
M`'&;`0`N````HYL!`"\```#2FP$`+`````*<`0!@````+YP!`"````"0G`$`
M$@```+&<`0`1````Q)P!`"0```#6G`$`,0```/N<`0`9````+9T!`"4```!'
MG0$`#0```&V=`0!`````>YT!`$````"\G0$`!````/V=`0`$`````IX!`!4`
M```'G@$`#@```!V>`0`2````+)X!`!@````_G@$`"0```%B>`0`(````8IX!
M``P```!KG@$`#````'B>`0`'````A9X!``T```"-G@$`"@```)N>`0`-````
MIIX!``<```"TG@$`(0```+R>`0`)````WIX!``4```#HG@$`!P```.Z>`0`1
M````]IX!`!(````(GP$`$````!N?`0`S````+)\!``(```!@GP$`"````&.?
M`0`2````;)\!``L```!_GP$`!@```(N?`0`0````DI\!``8```"CGP$`!@``
M`*J?`0`O````L9\!`!@```#AGP$`*````/J?`0!6````(Z`!`!<```!ZH`$`
M(P```)*@`0`2````MJ`!``D```#)H`$`"@```-.@`0`-````WJ`!`!,```#L
MH`$`#`````"A`0`)````#:$!``P````7H0$`'P```"2A`0`7````1*$!``0`
M``!<H0$`$````&&A`0`*````<J$!`!$```!]H0$`)0```(^A`0`8````M:$!
M`!D```#.H0$`$P```.BA`0`A````_*$!``D````>H@$`!P```"BB`0`"````
M,*(!`!$````SH@$`"0```$6B`0`*````3Z(!``@```!:H@$`#0```&.B`0`*
M````<:(!``4```!\H@$`'@```(*B`0`;````H:(!``8```"]H@$`%0```,2B
M`0`*````VJ(!`!$```#EH@$`"P```/>B`0`7`````Z,!`"P````;HP$`&P``
M`$BC`0`,````9*,!``T```!QHP$`&P```'^C`0`8````FZ,!``8```"THP$`
M*P```+NC`0`&````YZ,!``X```#NHP$`'0```/VC`0`&````&Z0!``D````B
MI`$`'P```"RD`0`U````3*0!`!(```""I`$`!@```)6D`0`0````G*0!``8`
M``"MI`$`%@```+2D`0`4````RZ0!``0```#@I`$`!P```.6D`0`)````[:0!
M``D```#WI`$`"@````&E`0`)````#*4!``D````6I0$`"0```""E`0`;````
M*J4!`#4```!&I0$`/@```'RE`0`9````NZ4!`"<```#5I0$`'````/VE`0`\
M````&J8!`!@```!7I@$`%````'"F`0`N````A:8!`"8```"TI@$`!P```-NF
M`0`)````XZ8!``H```#MI@$`$@```/BF`0`+````"Z<!`!4````7IP$`$0``
M`"VG`0`I````/Z<!`"````!IIP$`+@```(JG`0`S````N:<!``8```#MIP$`
M%0```/2G`0`(````"J@!``@````3J`$`)````!RH`0`/````0:@!`!,```!1
MJ`$`"P```&6H`0`4````<:@!`!8```"&J`$`$````)VH`0`(````KJ@!`!,`
M``"WJ`$`"0```,NH`0`0````U:@!``\```#FJ`$`&````/:H`0`J````#ZD!
M``P````ZJ0$`!P```$>I`0`'````3ZD!`!X```!7J0$`%````':I`0`&````
MBZD!``L```"2J0$`#0```)ZI`0`&````K*D!`!$```"SJ0$`"````,6I`0`(
M````SJD!`!,```#7J0$`,````.NI`0!#````'*H!``\```!@J@$`#@```'"J
M`0`2````?ZH!`!L```"2J@$`%@```*ZJ`0`3````Q:H!`!,```#9J@$`%```
M`.VJ`0`5`````JL!`!,````8JP$`&P```"RK`0`D````2*L!`!H```!MJP$`
M!0```(BK`0`0````CJL!``@```"?JP$`#@```*BK`0`2````MZL!`!,```#*
MJP$`$````-ZK`0`L````[ZL!``@````<K`$`"P```"6L`0`2````,:P!``\`
M``!$K`$`$P```%2L`0`6````:*P!``T```!_K`$`/````(VL`0`)````RJP!
M`"(```#4K`$`$@```/>L`0`6````"JT!`"P````AK0$`"@```$ZM`0`/````
M6:T!``@```!IK0$`$P```'*M`0`5````AJT!``D```"<K0$`"0```*:M`0`*
M````L*T!`!,```"[K0$`"````,^M`0`7````V*T!`!P```#PK0$`!@````VN
M`0`(````%*X!`!(````=K@$`%````#"N`0`6````1:X!``0```!<K@$`"```
M`&&N`0`+````:JX!``X```!VK@$`#P```(6N`0`2````E:X!`!(```"HK@$`
M"````+NN`0`)````Q*X!`"@```#.K@$`'````/>N`0`:````%*\!``<````O
MKP$`$@```#>O`0`&````2J\!``X```!1KP$`&0```&"O`0`F````>J\!``L`
M``"AKP$`!P```*VO`0`#````M:\!``8```"YKP$`"````,"O`0`%````R:\!
M``\```#/KP$`%P```-^O`0`-````]Z\!`!T````%L`$`'0```".P`0`:````
M0;`!``4```!<L`$`"P```&*P`0`4````;K`!``D```"#L`$`"P```(VP`0`-
M````F;`!``P```"GL`$`%````+2P`0`/````R;`!`!0```#9L`$`5@```.ZP
M`0`8````1;$!``<```!>L0$`!P```&:Q`0`'````;K$!`!(```!VL0$`$```
M`(FQ`0`1````FK$!`!L```"LL0$`$P```,BQ`0`5````W+$!`"0```#RL0$`
M$P```!>R`0!0````*[(!`"````!\L@$`8@```)VR`0`;`````+,!`!H````<
MLP$`'0```#>S`0`;````5;,!`!X```!QLP$`(P```)"S`0`I````M+,!`!L`
M``#>LP$`&@```/JS`0`@````%;0!`"P````VM`$`)````&.T`0`C````B+0!
M`!H```"LM`$`&0```,>T`0`:````X;0!``H```#\M`$`1`````>U`0`2````
M3+4!`%$```!?M0$`"0```+&U`0`+````N[4!``@```#'M0$`%@```-"U`0`/
M````Y[4!`!4```#WM0$`"`````VV`0`8````%K8!`%`````OM@$`)@```("V
M`0`8````I[8!`$$```#`M@$`*`````*W`0!/````*[<!`!L```![MP$`*P``
M`)>W`0`(````P[<!`!(```#,MP$`$P```-^W`0`*````\[<!`!$```#^MP$`
M*0```!"X`0`&````.K@!`"(```!!N`$`10```&2X`0!-````JK@!`",```#X
MN`$`+0```!RY`0`E````2KD!`#<```!PN0$`(0```*BY`0`2````RKD!`"``
M``#=N0$`&````/ZY`0`<````%[H!`!\````TN@$`'@```%2Z`0`C````<[H!
M`"@```"7N@$`%````,"Z`0`&````U;H!``L```#<N@$`#0```.BZ`0`)````
M]KH!`"H`````NP$`"P```"N[`0`,````-[L!``<```!$NP$`$0```$R[`0`*
M````7KL!``4```!INP$`%@```&^[`0`)````AKL!``D```"0NP$`!````)J[
M`0`.````G[L!`!@```"NNP$`#@```,>[`0`'````UKL!`!4```#>NP$`'@``
M`/2[`0`0````$[P!``P````DO`$`&@```#&\`0`H````3+P!`!$```!UO`$`
M$0```(>\`0`F````F;P!``8```#`O`$`$0```,>\`0`&````V;P!``@```#@
MO`$`!@```.F\`0`=````\+P!``X````.O0$`$@```!V]`0`0````,+T!``<`
M``!!O0$`"0```$F]`0`*````4[T!``P```!>O0$`#0```&N]`0`)````>;T!
M``\```"#O0$`#P```).]`0`'````H[T!`!<```"KO0$`!@```,.]`0`2````
MRKT!``X```#=O0$`"0```.R]`0`.````]KT!`!@````%O@$`#0```!Z^`0`%
M````++X!``0````RO@$`!@```#>^`0`(````/KX!``@```!'O@$`5````%"^
M`0`T````I;X!`!D```#:O@$`!P```/2^`0`'````_+X!``H````$OP$`"@``
M``^_`0`+````&K\!``<````FOP$`"@```"Z_`0`5````.;\!``P```!/OP$`
M"@```%R_`0`,````9[\!``@```!TOP$`#````'V_`0`)````BK\!``<```"4
MOP$`&````)R_`0`+````M;\!``<```#!OP$`"@```,F_`0`E````U+\!`!@`
M``#ZOP$`!P```!/``0`(````&\`!``H````DP`$`!P```"_``0`3````-\`!
M`!,```!+P`$`"````%_``0`<````:,`!``T```"%P`$`'@```)/``0`)````
MLL`!``8```"\P`$`$````,/``0`5````U,`!``L```#JP`$`#0```/;``0`7
M````!,$!``H````<P0$`!P```"?!`0`+````+\$!``\````[P0$`#@```$O!
M`0`%````6L$!`!@```!@P0$`"0```'G!`0`<````@\$!`"P```"@P0$`$0``
M`,W!`0`S````W\$!`"8````3P@$`(P```#K"`0![````7L(!`!0```#:P@$`
M'@```._"`0`;````#L,!`"0````JPP$`'````$_#`0`_````;,,!`#0```"L
MPP$`10```.'#`0!#````)\0!`!\```!KQ`$`9````(O$`0`S````\,0!`"T`
M```DQ0$`)@```%+%`0`S````><4!`"H```"MQ0$`$P```-C%`0`8````[,4!
M`!P````%Q@$`?0$``"+&`0`7````H,<!`!(```"XQP$`.````,O'`0"!````
M!,@!`#P```"&R`$`-P```,/(`0!)````^\@!`$0```!%R0$`'@```(K)`0`3
M````J<D!`!@```"]R0$`&0```-;)`0`D````\,D!`!T````5R@$`(P```#/*
M`0`4````5\H!`!L```!LR@$`(0```(C*`0`7````JLH!`"T```#"R@$`#P``
M`/#*`0`P`````,L!`%L````QRP$`+````(W+`0!2````NLL!`#D````-S`$`
M'P```$?,`0`:````9\P!`",```""S`$`'````*;,`0`F````P\P!`",```#J
MS`$`1P````[-`0`;````5LT!`$<```!RS0$`+````+K-`0`]````Y\T!`#P`
M```ES@$`%@```&+.`0`P````><X!`"H```"JS@$`*@```-7.`0`M`````,\!
M`&<````NSP$`90```);/`0"K````_,\!`!8```"HT`$`+0```+_0`0`Q````
M[=`!`#`````?T0$`20```%#1`0`>````FM$!`$X```"YT0$`'`````C2`0`6
M````)=(!``<````\T@$`L0```$32`0`<````]M(!`$4````3TP$`*````%G3
M`0`S````@M,!`!H```"VTP$`'@```-'3`0`N````\-,!``D````?U`$`#@``
M`"G4`0`(````.-0!``8```!!U`$`#0```$C4`0`.````5M0!``X```!EU`$`
M$@```'34`0`,````A]0!``H```"4U`$`#````)_4`0`+````K-0!``P```"X
MU`$``P```,74`0!L````R=0!``@````VU0$`$````#_5`0`%````4-4!``<`
M``!6U0$`!0```%[5`0`%````9-4!``<```!JU0$`&0```'+5`0`(````C-4!
M`!4```"5U0$`#````*O5`0`%````N-4!``L```"^U0$`!P```,K5`0`'````
MTM4!`!4```#:U0$`"@```/#5`0`7````^]4!``8````3U@$`!0```!K6`0`;
M````(-8!``\````\U@$`)@```$S6`0`$````<]8!``8```!XU@$`!P```'_6
M`0`B````A]8!`$$```"JU@$`*````.S6`0`J````%=<!`!8```!`UP$`)P``
M`%?7`0`@````?]<!`!\```"@UP$`(P```,#7`0`>````Y-<!`!L````#V`$`
M(@```!_8`0`>````0M@!`"L```!AV`$`&@```(W8`0`I````J-@!`!4```#2
MV`$`*P```.C8`0`?````%-D!`",````TV0$`(0```%C9`0`<````>MD!`"8`
M``"7V0$`)P```+[9`0`C````YMD!`!X````*V@$`'````"G:`0`B````1MH!
M`"4```!IV@$`'0```(_:`0`E````K=H!`"8```#3V@$`'````/K:`0`Z````
M%]L!`"$```!2VP$`)0```'3;`0`C````FML!`"0```"^VP$`'@```./;`0`[
M`````MP!`!P````^W`$`)````%O<`0`@````@-P!`"L```"AW`$`(P```,W<
M`0`)````\=P!`!,```#[W`$`&@````_=`0`:````*MT!`!H```!%W0$`"@``
M`&#=`0`0````:]T!`!D```!\W0$`$@```);=`0`3````J=T!`"(```"]W0$`
M"````.#=`0`)````Z=T!`"0```#SW0$`)P```!C>`0`O````0-X!`"$```!P
MW@$`#````)+>`0#Z````G]X!`!$```":WP$`%0```*S?`0`*````PM\!``T`
M``#-WP$`%````-O?`0`/````\-\!`!\`````X`$`"````"#@`0`Q````*>`!
M`!P```!;X`$`&@```'C@`0`)````D^`!`!4```"=X`$`"P```+/@`0!%````
MO^`!`"\````%X0$`&0```#7A`0`0````3^$!`!0```!@X0$`%@```'7A`0`@
M````C.$!`!````"MX0$`$0```+[A`0`2````T.$!`!L```#CX0$`#````/_A
M`0`;````#.(!``D````HX@$`&P```#+B`0`*````3N(!`!P```!9X@$`"```
M`';B`0`C````?^(!``<```"CX@$`"0```*OB`0`)````M>(!`#$```"_X@$`
M!P```/'B`0`0````^>(!`!0````*XP$`$0```!_C`0`+````,>,!``T````]
MXP$`"0```$OC`0`7````5>,!``T```!MXP$`#````'OC`0`6````B.,!`!(`
M``"?XP$`%P```++C`0`5````RN,!``D```#@XP$`"P```.KC`0`9````]N,!
M``0````0Y`$`*@```!7D`0`/````0.0!``<```!0Y`$`!0```%CD`0`,````
M7N0!`!(```!KY`$`"P```'[D`0`#````BN0!``P```".Y`$`#````)OD`0`'
M````J.0!``H```"PY`$`"@```+OD`0`+````QN0!`!P```#2Y`$`!@```._D
M`0`2````]N0!``D````)Y0$`$P```!/E`0`4````)^4!``X````\Y0$`*P``
M`$OE`0`7````=^4!`!8```"/Y0$`.P```*;E`0`U````XN4!``P````8Y@$`
M)````"7F`0`&````2N8!`!$```!1Y@$`1@```&/F`0`/````JN8!``P```"Z
MY@$`!P```,?F`0`$````S^8!`!0```#4Y@$`!@```.GF`0`'````\.8!``@`
M``#XY@$`!@````'G`0`-````".<!``\````6YP$`#0```";G`0`%````-.<!
M`!X````ZYP$`(@```%GG`0`:````?.<!`!T```"7YP$`#P```+7G`0`"````
MQ><!``0```#(YP$`$````,WG`0`&````WN<!`!D```#EYP$`!P```/_G`0`$
M````!^@!`!`````,Z`$`1P```!WH`0`1````9>@!`"D```!WZ`$`.0```*'H
M`0`D````V^@!`$0`````Z0$`*P```$7I`0`[````<>D!`"@```"MZ0$`*0``
M`-;I`0`0`````.H!`",````1Z@$`90```#7J`0`;````F^H!`%@```"WZ@$`
M+@```!#K`0`6````/^L!`"T```!6ZP$`(@```(3K`0`P````I^L!`#,```#8
MZP$`)`````SL`0`C````,>P!`"<```!5[`$`$P```'WL`0`P````D>P!`#``
M``#"[`$`%P```//L`0`2````"^T!`!0````>[0$`3P```#/M`0`3````@^T!
M`&T```"7[0$`5`````7N`0`G````6NX!`!(```""[@$`'````)7N`0`:````
MLNX!`!0```#-[@$`(@```.+N`0`;````!>\!`!H````A[P$`7````#SO`0`6
M````F>\!``L```"P[P$`!@```+SO`0`'````P^\!``@```#+[P$`"@```-3O
M`0`;````W^\!`!8```#[[P$`&@```!+P`0`F````+?`!`!4```!4\`$`$0``
M`&KP`0`)````?/`!`!,```"&\`$`!````)KP`0`.````G_`!`!````"N\`$`
M"0```+_P`0`'````R?`!``<```#1\`$`"````-GP`0`;````XO`!``\```#^
M\`$`#`````[Q`0`+````&_$!`!$````G\0$`#@```#GQ`0`+````2/$!``<`
M``!4\0$`"@```%SQ`0`4````9_$!``<```!\\0$`#@```(3Q`0`7````D_$!
M``D```"K\0$`"P```+7Q`0`.````P?$!`!D```#0\0$`"P```.KQ`0`%````
M]O$!``T```#\\0$`!0````KR`0`)````$/(!``8````:\@$`"P```"'R`0`+
M````+?(!``8````Y\@$`!@```$#R`0`#````1_(!`!$```!+\@$``@```%WR
M`0`*````8/(!``@```!K\@$`"````'3R`0`F````??(!``H```"D\@$`!@``
M`*_R`0`,````MO(!`!````##\@$`#@```-3R`0`.````X_(!`!<```#R\@$`
M"0````KS`0`)````%/,!``0````>\P$`$````"/S`0`2````-/,!``<```!'
M\P$`#0```$_S`0`C````7?,!``H```"!\P$`!0```(SS`0`6````DO,!`!,`
M``"I\P$`!0```+WS`0`0````P_,!``(```#4\P$`"P```-?S`0`'````X_,!
M``P```#K\P$`"````/CS`0`%`````?0!``$``````0```````+4````P`P``
MT`8``!`%``!K`P``-0<``(4"``!E!```7@,`````````````J`$``!`$````
M````;`0``-`!````````O08``#8%``!V````0P<`````````````````````
M```\!`````````X'```^!P``CP,``#T'```M`@``Q04```L`````````:0,`
M`&0!```Y!```````````````````DP$```````"U!@``;00``(<%``#7!@``
M````````````````20````````"@`0`````````````U`0```````%T!``#K
M!0```````,<#``#>`````````-@%````````=P$```````#%`@```````$H!
M``"(`P```````(0```"=````U`4```````!7!@```````$$!``!O`0``%08`
M`-(```!"!0```````)$"``#W````!0(``$(&``""`P```````-8$``#H````
MEP```*`&```B`P``C`,```<#``!:`0``B@```"4$``#7`0``#0,``$H#````
M`````````-<````(`P````````````!J`@``!`(``&L%```L!0``6P,`````
M``!#`@``&0$``/L#````````;@4``)@"``!M`0``"````&X$````````````
M`#`%``!&!0``````````````````#`8``.8%``!(`0``$00`````````````
M`````-`$````````Z`8``!8#``#1!@``@0,``,0````_`@`````````````_
M```````````````=`P``;0(````````4!P``7@(```````!"`P``U@(``.$"
M```P!``````````````Q`0``H@(``)L#``#!!@``*@``````````````$@<`
M``````#&!0``%`,``$@&``#Z`P``-`8```````!U`@````````8'``#N````
M5`4``,4!``!5!P``RP8``*`#``"M!@``^04```````#:````I`(```````!E
M`P``9P0``.D%``!U````&00``#X&``!N`@``F0````8&````````JP4``.,!
M```;!0``.`<``,H!````````.@<`````````````K`0``*L$``!^!```0P,`
M`$$%``!U!0``J`8```````#*`````````&P&```B`0```0<``%`%``!1`P``
M8@0``&<"`````````````"4!``"B!0``R@,``!X'``!X!`````````````!F
M!P``+@8```````#9`0``W04``(P&``"E`@```````%@!```/!@``U04``&``
M``"_!0``C0$``$@'``!;`0``-00`````````````'`4``,0$``#(`@``N`$`
M``````#J!````````"4%````````G`8```````#P!0``]0```!8%``#S`P``
MJ08``"<#``#7!```MP4```````!3!`````````````"%!@``'@8``+D%````
M````4`8```````#2`@``@`,`````````````EP$``"(&`````````````"H"
M``#_!@``+P8``#<!``#N`@```````%`!```B!`````````,$``!A!@``\@4`
M`'\#```O!```DP```/4$``#"!@```````(P```#2`0``````````````````
MH@,```````#9!0``9`<``!X#```Z`````````$$$``!:!P``!P0``%4&``#<
M`0``#04```````!"!P``V`$``-$#````````^@8```````!D`@``8@(``&H!
M````````1`0``"4&```````````````````7````O`0``#T%``"F`@``````
M`*D!``"`!@``<`8``)(%``"[!0``#`````````"O````:P0```````!K!@``
M`````.(%````````N`,``*,`````````@@4``&8#````````!@````@%````
M`````````/L!````````_@4```````!9!@``40$````````L!```8`<``,,$
M```&!```3@8``,D````*!```%@````````"8!@``5`(``'<&``!1!@``````
M`.D!``#,!```)0<``,$#``#4!```B`0``$$&```O`0``P`4``)P"`````@``
M;`<``-X!``"+!@``7`,``#D"````````!`4```````!]!@``G04``#X#``"C
M`0``?@$````````X!0``&08``````````````````"T#````````3@,``-$"
M``````````````````"0````L0````````!F`@``R`0``%T#``!%!@``````
M``,````W!P```````#$'```V!@``]@8``%X&````````U`(``*H$```9!0``
M&`4``"D'`````````````/$!``#"````]@$``,H$``"A`0```````!L'````
M````"0<``)X&``!I!P```````.H#```%!0``)`(```8%```G!```3P8``-(#
M``#C!0```````'4#````````P0````````#N!@```````(D!``"-!@``:`$`
M`*(```#H`0``%P4```L$```!`P``\`$```0```#9`@```````.(#``#O````
M%@$``-X$```/!````````,`#``!J!@``)0```%`'```J!```70```#L`````
M````2P0``%@"``!*!P``5`,``(,%``"@````_P$``%L"`````````````#4#
M````````C00``'T%```+!P``:0$``$(!``#4`0``L0$``/,``````````@8`
M`((```"=!@````````````##!@```````*0&``!X!0``?P4``-L$``"V````
MZ00``'<$````````M00``*T$````````7@$``&<'``"Z!0``BP0``.L"``"^
M!```\P4```8#``!O````>`$``-``````````8P(``.(````2`@``L`8``#X`
M``#H`P```````%T&``!V!@``R`4`````````````N`4```````!?!0``E`$`
M`&H'```'!P``"`$``%4````:````/P0``&<%``"E`0```````%0!``"V`0``
M```````````L!@``\@8``/<#``"%!```4@(```$%``!>``````````($``!D
M!@````````````#C!@```````%\#```V`0``.P<``.D```#T`0``=P4``*$"
M``!&!P```````&D&````````S@,``&$%````````>0,``+0#```4!@``````
M`!L"```C`0```````,````#:`P`````````````]!@```````,0"``![!0``
MJ`(```````"%`0``$P``````````````8@8``',"```_`0``=00``#8```"Y
M!```U@```#$`````````=08``*@$``#-`0``80$``!(```````````````P$
M``!H`P``=P,``&@'``!+`0```````#0#``#3`0``/````!L$``!%!0``.@$`
M`#T$```2`0``D0,``(\"```)!0``1P4``.P&````````(00``&4&````````
MW@4```````#-````^P```$8#``#O`@``Q@8```````"6`@``7P```"0```#T
M!@``%````)X%``#8````EP4``$`'``"O!@``9`4``,D#```Y`````````!H&
M``!A`````````"L!``#<`P``IP,``.`$``"M!0``VP(``#(&``!5`@``5P4`
M``T```#S`@``P00``*4```!;!0````````````!8!P```````-,%```R!0``
M7````&4%`````````````.P`````````5P(``.X%``"G`0``(04``#D!``#^
M`P``*P0``(0%``!Y!````````$8&``#D`@``````````````````7`4`````
M``!^````I````)0```"B!@``9@0``-@#`````````````$$'``"5!```V0``
M``````#E!0```````'L"`````````````!@&``"3!0``RP$`````````````
MB@(``.`&```-!@```00``!D"```F`P``,`$``(X%``".!```MP,``+\````0
M!P``````````````````B@$``&\"``#>`@``7`(``````````````````$8$
M`````````````-4$``"M````-`0``%('``!5`P``*`$``)D#````````F```
M``````#]`0``308``(L````>`@``#@```/$```!6`@``I`$``.4```"]`@``
M&@(````````P!@``0`````````!;!`````````\%````````@08`````````
M````<P4``&,'``!%`0```````*T"```?!0``^P4``!$'``"V`@``<P$``/\%
M``!3`0``````````````````7P0````````Y!P``[`4```````#:!@``````
M``````#)!@```````!X%``!I`@``HP4``-8!``"*!0``/0,``-,```#A!0``
MGP```+T#``!%````J04```P%````````\@$``*,#```Z!```)@(````````@
M`P``<`4``.D"````````%P(```(#``"3`P```````$P$````````:@4`````
M`````````````&<&```%`P``````````````````````````````````@`$`
M`*4&``!\`@````````H&```;`0``N@$```````!F`0```````!$&````````
M_@```$\'``!?!P``0@(````````4`@``B@8``,\$``#\!@``G`,``(T"``!.
M`0``?`$``)8&````````*04`````````````7P$```````!)!@``W0$``$@"
M````````*````(8"``!J````)P(`````````````A`(``,T&```2!@``````
M`$8!````!@``E`8``````````````````$8````\`@``'`<``'(#```'`0``
M:`8```````"F!@``A`,```````!`!0``V00``,(#``#E!```K@8``!T&``#^
M`@```````+L"``!/`0```````%P!``!I````DP(``,8$``!3!P``\P8``*P&
M```G`0``M04````````<`P``BP$``,4``````````````*H````.!0``````
M`,P#```9!P``8@,```````##`0``)`4``/4"```H!P``N````(````#"!0``
M8P0``$D$``#$!0``'@$``!\```!9!P``]P0``%<$``!/````.P$``.T$``#D
M!```]`(``'8%``#G!@``S`$``-0&````````5@<``-\"``":`P``0P```"L'
M``!4!@``&@0``.0#``#:`@```````#\%``#@``````````````#_````````
M`(,#``":````-@<```````!M!@``<P0``$0#```7!@``=@$```````!-`P``
ML@$``%4$``"]`0``;@<````````X!@``F`$```````"S!0``"@(```````!:
M`@``;0<``/`#``"^!0``ZP8``-<"``"T`````````,@#``!Q`````````-$!
M``"'`P``$0(``!4!``#)!```6`8````````J!@``#`<```````#=!@``_0``
M`,X!`````````````/@#```B!P``D@8``#`"```M`````````)8````T!P``
M_`````4```"3!@``C`0``+8$````````D`$``"`'``#K`0``>08``.4"``"I
M`@````````````!``P``V@0``"0#```1```````````%````````G@,``!$%
M``#U!@```````,P````Q!@```````+$$```@!```$P8``!`"```O````````
M````````````OP,``'@"```G!@``[P0``(T#````````YP0````````X`P``
M_08``#`'``"E`P``J@$```````#`!@``I@0``'`!````````G@0``(H#``#1
M!```L`,``.\&``"S````1P8```````#%!```_P(``+@&``""!@``D`(``$4'
M````````E@,``,\!``"2````5@0``%X%``#+`@```````#L&```2`P``Z`0`
M`.@"``"#!```;P0``*8`````````C04````````_!P``8`0```\`````````
MVP4```````!:!0``````````````````H@0````````N!P``CP```)\!``!A
M!P````````````!D!```K@0``-,"````````"@$``"`&``!'`@``P0(``&,%
M```;`````````!@$``"<`0```````,<!``#-`@``F`0``-T```#'`@``````
M`-@&````````-@,```,"``#5`0``KP(``+\&``#7!0``8`$```H%````````
M``````L!``"8`P``:@,``)H!``!1`@``V@$````````5````F0(``",&``!B
M!0``&0```+L$```Q`@``,00``'`$````````-P,``,(!``#_`P``/`4````#
M``"W!````````.8!``"K`0``3`(``"T'```7`P``O`(``!4%```&`@``[@,`
M``````!%!````````+$"``"H!0``'0$``#D&``!E!P``204```````"/!```
M.@(``)H%``"Y!@``AP(``#($``!R!@``<`,`````````````%0<```````#E
M!@``_@$``%D````.`@```````'\$``"M`P``@0(```````#$`0``JP(``/$&
M``#G`0````````````#]`@``U0```/<!``"T!````````#('``"@!```````
M``````#=`@``8@```%H#``!F!0```````*8#``!\!@``#`$``(@!``!2`P``
M````````````````_`$``&<!``"G!@``>0$``,0&``"J!@``"`0```D#``"'
M`0``>@```+,"```@`@``Y`$``%<'``#2!````````'0%``!R!0``K0$``.X$
M``!<!@``LP8``&X!``"0`P``]`,````````D!````````%,"```0````E`,`
M```````=!0``0`8``%(```!Q!@``I`0``````````````````&,&````````
M)P````````!'!````````-T#``"`!```6````$\$``##`P``N@8``,P"```X
M````>@$``-L```!R`0``X0$``+4#```K`P``!0$``,L#``!Q!0``KP$``%8%
M``!0````&`,``+0"``!H````B@0``(0$``";!@```````$@%```:`0``````
M`%,&````````V`0``/4#``#]!```,04``"D"``!+`@``5`0``"D```#K`P``
M:`4``"X$``"R!@``E08``"@#````````'P$```````!7````]@```)8%``#F
M!@``WP4```````"<!0```````'D```!1!P````````````#F`````````$L#
M``#W!0``-@0``$4"```J`0``=`8```````"W`@`````````````@````C0``
M`-P&``!+!@``D`4``/\$``#G!0``Z08`````````````N`0````````M!```
MB`4``"$&``#\!0``C`$```L&``!X````````````````````'0<```X$``#B
M!```G`0``#,#```O`@``NP$``#,&``#E`0``[P,``/@$```+`@````0``!,'
M``!"````0`0``'`"``!V`P``4@8``+H"````````3`,`````````````N@``
M`"\'````````^08``/0```"G!```N@0``,\%``#'!@``_`0``),$``!/`P``
ME0,``+("````````;`,``$T!`````````````$X'```3`@``X0```+L#````
M`````````)(#``"R````4`(``````````````````(D```!H!```L08``+D!
M```F!```%`4``%X'``!,!0``%`0``,`!``"=`P``Q08``+T```!Z`P``````
M``4'``````````````\"```B`@``7P8``,T#```L`P```````-`#```*````
M`````.T&``#B!@``!P```#L#```:!P``*08``&P%```````````````````R
M`0``]`0``-$```!A`@``MP```!X$``!<!P```````#0%````````)P4`````
M``"9!```!`,``$<#```"!0``[`$``%<!``";!````````,L$``!9`P``V0,`
M`"\%``"U`0```````,4#``#-!```'P(`````````````;0,``+8%``!8!```
M#00``"\#``"!!```^`$``-@"``!6`P``,@```*P%``"[````AP0``'L!``"V
M`P``\@0```````"0!@``$P4``",%`````````````*D$```=!````````"P!
M`````````````#,$````````OP$``!(%``#,!0```````!`&```$!P``````
M`/L&```/`P``^`8````````J`P``@P(``%4%``!9!````````*@`````````
M^`(``-D&```I`P``_@0``/8"```3`0``R@(``.(!````````@P```+,$```2
M!```40```(X#````````80,````````<!@``%@8``,X&`````````````!D#
M``"7`@``Q@$``.T%```K`@``WP8````````#!0``XP,``&X&````````B00`
M``````#;!@``-P```,X%``!E````\`8```,'```C`````@```!@!``"'!@``
MC`(``)8!````````E`(``*4%``!8!0```````,$%````````4`0``-P```!\
M`P````````````!"!```[P4```T'```8````G0(```D&````````N0(``+``
M```I!```````````````````-P(``!$#````````-0(```,!``"N`@``````
M`!T```!K`0``8`8``-P%``#M`P```````-4"``"5````1P<```T!``"W`0``
M``````````!D`P``#@,``$@$``!S!@``#P<``/4!``"_`@``I00``'4!``#Z
M!```$P,```````#7`P``2@(```````"L`0```````.H%````````.@,``"X"
M``#[!```H@$```````!]````)@$``&X#``!)!P``````````````````TP,`
M`*,&```$!@``(@````````#/`P``0P8``!T"````````10,```````!,`0``
M-0```'$$````````/0$``#,%``!(`P````````````#Q!0```````+H#````
M``````````````"O!```>P```)X"``!-!```=@0``%@#````````!08``.("
M```[!0``/0(``(D%```L`@``00(`````````````/`8``(,&``"]!```3@``
M`'0!``"&````\00``!4$```S````^@(``%T%``!E`@```````*0#``!T`P``
M`````",$```W!```30<``!8"````````9@```*L````4`0``EP8``"@%````
M`````````"X!```-`@```````'X&```J!0``]@0``-\```!$!0```````-4#
M```F!@```````*8!``!@`P``J0,``(8#``#3!```400```$!````````````
M`)$$``!T````)`$``/$#``!*!`````````````!\!0``;`$``+D```#;`0``
M6@```#L$````````<````*`"``"=`0``E0$``.T`````````R0(````'``"R
M!0``O`$``+0!```U!@```````"@"``":`@``R0$```````"!!0``+04``(L%
M```.`0```````","````````=`0``*\#````````4P,``$@```!X!@``:`(`
M```````B!0``U@,``"$!``"[!@``O@8``#D%````````GP(``(($````````
MKP4``"P``````````````&H$`````````````*<%``"\`P``1`(``/D#``!#
M!0``A`8``+T%```W!@```````-L#``!R!````````"X````V`@``AP```$H&
M``"5!0``-````"$`````````M0(``$0&```K!@``F@0``.H!```\`0``````
M``````"(`@``*`0``/H!``!-!0````````("``!^`P````````````#M`0``
M:00``.@%```_`P``5`<``!,$````````8@$```P"``##````;````%P$```)
M`0``"@<```('````````Z@8``*$$``"!````"00``+X#```!`@``HP(``.,$
M``!=!P``WP,``!\$``#@`0``2@```%L````>````^````&L"````````CP8`
M`/(`````````(0,```````"\`````````$X%````````G@$``-(&``#Y````
M``````````#>!@``2P```+($``"W!@``4@$``+$%``!]`@````````````!.
M`@``JP8```L%````````(0<``.<#``!=!```A@0```````!O!0``)P<``&<#
M````````X0,```````#``@``8`4``,H&``"S`P``!00```8!```C!P``(`4`
M```````U!0````````P#``!Q`P``J0```%\"``#K````6@0```````"``@``
M>@0```````#D!@````````````"R`P``P`0``'X%``"P`@``;`(``(8&``#Z
M````O@```/T%```^`0``/0```(D#```F!P``TP8``%,```#Y!```GP4```$&
M```^`@`````````````(!P````````````#4`P``Y````%0````E`@``5@$`
M`)X`````````K@```/(#```X`@``J@(``&T%````````.@8``'H&``#@`P``
M]@,``'L#```M!@``.0,``!L#``!@`@``:04``&$$``")`@``+0$``#@!````
M````8@<``.8#``#!`0```````'0"``!,!P``1````.<````7!```QP``````
M``!'`0```````$,$```^!0````````(!``!>!````````*8%``!K!P``````
M``````#4````.P(``$H%````````00```$P```#K!```4@0``-(%````````
M````````````````A0```#H%``""`@``FP4```````#"!```;P,``#("``"A
M`````````'\```"(````Y0,``/,$``#D!0``!`$``*,$``";`@```````$`!
M``!2!0``404``&0```#P`@``604```````#Y`0``?00```````!3!0``X`4`
M`-8&``!O!@```````'8"``#\`P```````!`!``#P!```*`8``-`"``!\!```
MIP``````````````'P8``)8$`````````````&,!``".!@``&@4``$P&``#J
M````^0(``)<$``#T!0`````````````S`0``$0$```<"``![!@``20$`````
M```````````````````(!@```````'T!``"S`0````````````#5!@``E`4`
M`&X```"^`@``E0(``"X%``#X!0``*0$``&,```"7`P``"P,```````#[`@``
MS@```'<"``"A!0```````&4!``"1!0``GP0``%4!``#W`@``%P<``#X$``"K
M`P``````````````````A@4``,0#```5`@``]@4```````````````````,#
M```(`@````````````#A!@``D@(```````#F!```F@8```````#/!@``Q@``
M`*P`````````$`,``!\'```<!`````````<%``"<````[@$```````"%`P``
M*P````````"+`P````````````"A`P```````&8&``#'!0``3P4``#$#````
M````5@8``,\"````````\````#\&````````>`,``````````````````,\`
M``#(!@```````+`!``#>`P``W00````````A`@``IP(``.H"``#'!```1P``
M````````````RP4```````"T!0``5@```+D#``#Q`@``D08``!4#``"L`P``
M[`(``+0&````````2P4``````````````````(8!``!9`0```````)L```!$
M!P``'`$``($!```R`P``30````````"A!@``YP(`````````````[0(``(@&
M````````_@8``"H'``#.`@``)@4``%H&``##`@``^@4``)D!``!;!P``W`0`
M`)`$``#,!@``20,```````!&`@``20(``#,"``!!`P``\@(```````#]`P``
M>P0``*H#``!Z!0```````-\!``!=`@``%P$``*P"```6!P```````)D&```N
M`P``[`0``,D%````````S04``&T`````````Z0,``,8#```<`@``"@,``+8&
M````````````````````````30(```````#C`@``4`,``,X$````````R`$`
M`/<&```)`@```````+X!``"9!0``F`4``+\$````````?P$```X&``##!0``
ML0,``+P&``"2!```R@4``#P'``#C````E`0``"0'````````[`,``"8````W
M!0```````)\&````````9P```',`````````B08``$`"``!]`P``/`,`````
M`````````````%<#`````````````+P%``"?`P``C`4``"4#````````G00`
M`'\&``"$`0``.`0``"`!``````````````````#6!0``?````+@"``#F`@``
MI`4```````!R`@``2P<``-$%````````C@$``"P'````````L`0``!@"```T
M`0````````````#:!0```````(`%``#<`@``*P4```````#0!0``,````!L&
M```?`P``D0```*X%``!.!```R``````````<````X`(``'D"````````````
M`'H"``".`@``X00``&,#```8!P``1`$``$,!`````````````,("``#?!```
M[P$``%L&```)````?P(```````!K````<0$``#,'``"%!0``=P```)(!```/
M`0``!`0``'$"````````````````````````?@(``+`%```C`P```````(,!
M``!Y!0``<@```!H#````````3P(`````````````CP$``/P"``".````K@$`
M`!8$``!9`@``!P8````````D!@``H`4``*@#``"+`@```P8``#0"``"1`0``
M``````````#U!0``Q@(```````";`0``@@$``/,!``#+````CP4```````"J
M!0``K@,``',#````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H
M=&]D87DI`"`H>65S=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E9"!E=F5N
M=',`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($1A>2AS*2`E<R!(
M;W5R*',I("5S($UI;G5T97,`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:7,@
M<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F
M("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E
M<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"H@061D('1H97-E(&)Y(&-L:6-K
M:6YG($%D9"`J`"H@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S
M=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T
M("TM`#$@979E;G0`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@
M:&]U<G,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES
M(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!30!!32!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O
M<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P=&5D`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT
M(&9R;WIE;BX`06-C;W5N=&EN9P!!9%]V86YC960@4V5A<F-H`$%D9`!!9&0@
M0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($5V96YT`$%D
M9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@
M82!N97<@4F5M;W1E($-A;&5N9&%R`$%D9"!A(&YE=R!E=F5N=`!!9&0@82!N
M97<@=7-E<CH`061D(&%T=&5N9&5E<P!!9&0@8V]L=6UN`$%D9"!N97<@;65M
M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I
M9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@
M8F]O:P!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E
M<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9'9A;F-E9"!3
M96%R8V@`069G:&%N:7-T86X`06QA<FT`06QA<FT@1&%T90!!;&%R;2!3<&%N
M("AM:6YU=&5S*0!!;&%R;2!4:6UE`$%L8F%N:6$`06QG97)I80!!;&EA<P!!
M;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@071T96YD965S`$%L;"!!=71H96YT
M:6-A=&5D(%5S97)S`$%L;"!&=71U<F4`06QL($=R;W5P<P!!;&P@4&5R;6ES
M<VEO;G,`06QL(%9I<VEB;&4`06QL(&1A>0!!;&P@9&%Y(&5V96YT`$%L;"!E
M=F5N=',`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@
M97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A
M<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I
M;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z
M`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N
M<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`06YY`$%P<&QI
M8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3
M:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B
M80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G
M:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`070`071T86-H
M960@:7,@86X@:4-A;&5N9&%R(&9I;&4@=VET:"!M;W)E(&EN9F]R;6%T:6]N
M(&%B;W5T('1H92!E=F5N="X@268@>6]U<B!M86EL(&-L:65N="!S=7!P;W)T
M<R!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E('1H:7,@9FEL92!T;R!E87-I
M;'D@=7!D871E('EO=7(@;&]C86P@8V]P>2!O9B!T:&4@979E;G0N`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E;F1A;F-E`$%T=&5N9&5E
M<P!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I
M=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE
M('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%
M>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R
M;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"
M86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D
M;W,`0F%S96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R=7,`0F5L9VEU;0!"96QI
M>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!"
M;W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0G5S>0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?86QE
M;F1A<@!#7V5L;"!0<F]P97)T:65S+BXN`$-A;%]E;F1A<@!#86QE;F1A<@!#
M86QE;F1A<B!3=6UM87)Y`$-A;&5N9&%R<P!#86QM`$-A;6)O9&EA`$-A;65R
M;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!
M4"!S97)V97(Z("5S`$-A;B=T(&-R96%T92!A(&YE=R!E=F5N="X`0V%N861A
M`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N8V5L;&5D`$-A;F-E
M;&QE9#H@)7,`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD
M(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U
M="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R
M9&4`0V%P=&EO;@!#871E9V]R7WD`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A
M=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T
M:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN
M9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE
M<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O
M;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z`$-H<FES=&UA<R!)
M<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R
M`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R
M('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K
M871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB
M:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`
M0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A;'5E<P!#
M;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO
M<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#
M;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\`0V]N9FER;65D`$-O;F=O`$-O
M;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO
M;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N
M=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N
M`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@
M:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@)7,N
M`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`
M0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U
M<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R
M+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT
M`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@3F5W($5V96YT`$-R
M96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N=`!#=7)R96YT(%1I;64`0W5R<F5N
M="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``
M0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H
M2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%I;'DZ
M(%)E8W5R<R!E=F5R>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E
M:79E9`!$871E('-E;&5C=&EO;@!$87D`1&%Y*',I`$1E7VQE=&4`1&5?;&5T
M92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E
M8W)E87-E($EN9&5N=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92`E<P!$96QE=&4@179E;G0`1&5L
M971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@
M;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI
M<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!R;W<`1&5L971E('-E
M;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L
M971E('1H92!C=7)R96YT(&5V96YT(&]N;'DL('1H:7,@;V-C=7)R96YC92!A
M;F0@86QL(&9U='5R92!O8V-U<F5N8V5S+"!O<B!A;&P@;V-C=7)E;F-E<S\`
M1&5L971E('1H92!C=7)R96YT(')O=P!$96QI=F5R>2!T:6UE`$1E;FUA<FL`
M1&5S8W)I7W!T:6]N`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N
M`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO
M<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W
M('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D`1&ES<&QA>2`R-"UH;W5R
M('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II
M8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<`!$;V5S(&YO="!R96-U<@!$;V5S('1H92!F:7)S="!R
M;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI
M<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$
M;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!$=64Z("5S`$1U
M<F%T:6]N`$4M36%I;`!%4E(`16-U861O<@!%9&ET("5S`$5D:70@071T96YD
M965S`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I
M="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(%)E
M;6]T92!#86QE;F1A<G,`161I="!A='1E;F1E97,`161I="!O<'1I;VYS(&9O
M<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L
M(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M
M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`
M16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!$871E`$5N9"!/;@!%;F0@5&EM90!%
M;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@
M>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I
M86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@<F5T<FEE=FEN9R!F<F5E
M+V)U<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<P!%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5N
M="!F<F]M("5S('1O("5S`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$5X96-U=&4`17AP86YD`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E
M('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%
M>'!O;F5N=`!%>'!O<G0`17AP;W)T($-A;&5N9&%R`$9'($-O;&]R`$944"!U
M<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E
M<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`
M1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD
M<P!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H
M;W=E<G,`1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`
M1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E
M<G,`1FEN9`!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI
M=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`1G)I9&%Y`$9R;VT`1G)O;2!T:&4@`$9U;&P@
M1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=71U<F4`1V%B;VX`
M1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=A
M;64`1V5N97)A;`!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E
M9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@
M3F%M90!';P!';V5D96P`1V]O9VQE(%-E87)C:`!';W1O("5S`$=R87ES8V%L
M90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A
M`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)
M<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX
M+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI
M<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG
M:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO
M;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R
M:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=7(H<RD`2&]W(&1I9"!Y
M;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU
M;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO
M="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@
M0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E
M;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F
M<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`
M26UA9V5S`$EM<&]R="!#86QE;F1A<BP@4W1E<"`E9`!);7!O<G0L(%-T97`@
M)60`26UP;W)T+T5X<&]R="!#86QE;F1A<@!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@
M86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN
M9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I
M;VX`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!4
M86)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H
M(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN
M<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C
M;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H
M(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T
M97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM
M86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@
M8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED
M(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI
M9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI
M9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI
M<W-I;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T
M`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A
M+@!);G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER
M96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES
M<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N
M97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S
M=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T
M`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY
M80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME
M<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y
M($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97EW;W)D<P!+:61S`$MI<FEB
M871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO
M<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y
M>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I
M8R!297!U8FQI8P!,87-T(#(T(&AO=7)S`$QA<W0@2&%L9@!,87-T($UO9&EF
M:65D`$QA<W0@36]N=&@`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,87-T('=E96L`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP
M='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F
M="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I
M>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG
M:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W
M97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3
M;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6UI="!T:&4@=&EM92!S<&%N('1O(&5X
M<&]R=#H`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK
M<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`
M3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES
M="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]?
M8V%T:6]N`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM
M90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,
M;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E
M<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M
M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA
M9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`
M36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E(')E
M;6]T92!C86QE;F1A<G,N`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S
M;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1
M=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N
M<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@
M9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I
M="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE
M;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-965T:6YG`$UE;6)E<G,`365N
M=2!,:7-T`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D
M+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H
M;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@
M`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;G5T92AS*0!-:7)R;W(`36ES
M8V5L;&%N96]U<P!-:7-S960@179E;G1S($QI<W0`36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG
M(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@
M240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D
M:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-
M;VYD87D`36]N9V]L:6$`36]N=&@`36]N=&@@5FEE=P!-;VYT:"!A;F0@>65A
M<@!-;VYT:&QY`$UO;G1H;'D@179E;G1S($QI<W0`36]N=&AL>3H@4F5C=7)S
M(&5V97)Y`$UO;G1H<R!!:&5A9`!-;VYT:',@0F5F;W)E`$UO;G1S97)R870`
M36]O;B!0:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D
M>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O
M;F5N=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S=7!P;W)T960N`$UU
M;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($-A;&5N9&%R<P!->2!#
M86QE;F1A<G,Z`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`
M3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.
M971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E
M(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P
M;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C
M871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`
M3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@
M179E;G0`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE
M86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X
M=`!.97AT(#(T(&AO=7)S`$YE>'0@1&%Y`$YE>'0@36]N=&@`3F5X="!7965K
M`$YE>'0@9&%Y`$YE>'0@;W!T:6]N<P!.97AT('=E96L`3FEC87)A9W5A`$YI
M9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;R!A='1E;F1E97,`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-A;&5N9&%R<R!A<F4@879A
M:6QA8FQE('1O(&=U97-T<RX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U
M<'!L:65D+@!.;R!E;F0@9&%T90!.;R!E=F5N=',@=&\@9&ES<&QA>0!.;R!F
M:6QE('5P;&]A9&5D`$YO(&9R964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I
M;&%B;&4@9F]R("5S`$YO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"X`3F\@
M;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE
M('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E
M(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@
M8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S
M87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG
M;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L
M:60@96UA:6P@861D<F5S<R!F;W5N9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H
M=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES
M;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L
M86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T
M;W)Y`$YO="!F;W5N9`!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U
M<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO
M=F5M8F5R`$YO=P!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J
M96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT
M97(`3V9F:6-E`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@
M96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O
M=P!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3
M>7-T96T`3W!T:6]N86P`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D
M($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI
M>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R
M`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E
M9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-`%!-($QI9VAT(%)A:6X`4$T@4VAO
M=V5R<P!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`
M4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086QM($1A
M=&5";V]K`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L
M>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W
M;W)D<R!M=7-T(&UA=&-H+@!087-T($5V96YT<R!,:7-T`%!A<W1E`%!A<W1E
M(&9R;VT@8VQI<&)O87)D`%!A=&@`4&%T=&5R;@!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUA;F5N=&QY(&1E;&5T92!T:&ES(&5V96YT/P!097)M:7-S:6]N`%!E<FUI
M<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P
M:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M
M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1A;"!/<'1I;VYS`%!O<G1U
M9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@
M=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@
M8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R
M97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<`4')E=FEO=7,@1&%Y`%!R979I;W5S(%=E96L`4')E=FEO=7,@9&%Y
M`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`
M4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T
M97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E
M<G1O(%)I8V\`46%T87(`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`
M4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I
M;B!3:&]W97(`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A
M9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-U<B!5;G1I
M;`!296-U<G)E;F-E`%)E8W5R<F5N8V4@1&%T80!296-U<G)E;F-E($5N9"!$
M871E`%)E8W5R<F5N8V4@26YT97)V86P`4F5C=7)R96YC92!4>7!E`%)E8W5R
M<R!D86EL>0!296-U<G,@;6]N=&AL>0!296-U<G,@=V5E:VQY`%)E8W5R<R!Y
M96%R;'D`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E
M;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M:6YD97(Z("5S`%)E;6]T
M92!#86QE;F1A<G,`4F5M;W1E($-A;&5N9&%R<SH`4F5M;W1E(%-E<G9E<G,`
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E
M;6]V90!296UO=F4@)7,`4F5M;W9E($%T=&5N9&5E`%)E;6]V92!";&]C:P!2
M96UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E
M;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@
M9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@
M8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E
M<75I<F5D`%)E<75I<F5D($%T=&5N9&5E<P!297-E=`!297-E="!087-S=V]R
M9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<V5T('1O($1E9F%U;'1S`%)E<W!O
M;G-E`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@
M0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE
M<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R
M=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2
M;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W
M<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A
M;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@
M;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`
M4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI
M8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!3
M44P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE
M;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3871U<F1A
M>0!3875D:2!!<F%B:6$`4V%V92`E<P!3879E($%S($YE=P!3879E($5V96YT
M`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-C:65N8V4`4V5A<F-H
M`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E
M;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T
M(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!C;VYF:7)M
M871I;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V
M:65W<R!A;F0@8VAO;W-E(&1E9F%U;'0@=FEE=RX`4V5L96-T('1H92!C86QE
M;F1A<B!T;R!I;7!O<G0@=&\Z`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE
M8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O
M<G0Z`%-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3H`4V5L96-T('1H92!F;W)M
M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@=&AE(&ED96YT:71Y('EO
M=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`
M4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1H92!T:6UE('-P86X@
M=&\@<VAO=SH`4V5L96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A<G1U
M<#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!W:&EC:"!E
M=F5N=',@=&\@<VAO=R!I;B!T:&4@<&]R=&%L+@!396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N
M9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YD(&$@8V%N8V5L(&YO=&EF
M:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@=&AI<R!E
M=F5N=`!396YD(&%N(&5M86EL('1O("5S`%-E;F0@=7!D871E<R]I;G9I=&%T
M:6]N<R!T;R!A;&P@871T96YD965S('=H96X@<V%V:6YG('1H:7,@979E;G0`
M4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE
M9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T
M(&5N9"!D871E`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T(')E8W5R
M<F5N8V4@96YD(&1A=&4`4V5T('-T87)T(&1A=&4`4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P
M;&%Y(&]P=&EO;G,N`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`
M4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R
M.B``4V5Y8VAE;&QE<P!3:&%R960@0V%L96YD87)S`%-H87)E9"!#86QE;F1A
M<G,Z`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!C871E9V]R
M>2!L96=E;F0_`%-H;W<@9&5L971E+"!A;&%R;2P@86YD(')E8W5R<F5N8V4@
M:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_`%-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;BX`4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R
M/P!3:&]W(&9R964O8G5S>2!L96=E;F0_`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O;FQY(&5V96YT<R!T:&%T(&AA=F4@
M86X@86QA<FT@<V5T/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H
M;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO
M=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:6UE(&]F
M(&1A>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_`%-H;W<@=7!L
M;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAR:6YK
M`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`
M4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT
M96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<@4VAO=V5R`%-N;W<@9&5P
M=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N
M9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N
M`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN
M9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E
M;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!3=&%R="!$871E`%-T87)T($]N`%-T87)T(%1I
M;64`4W1A<G0@>65A<@!3=&%T7W5S`%-T871E(&]R(%!R;W9I;F-E`%-T871U
M<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H
M`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T
M>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S
M`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA
M<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YD87D`4W5N;GD`4W5N<FES90!3=6YR
M:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R
M:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T
M;W)M`%0M4W1O<FUS`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`
M5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#
M:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`
M5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@
M:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@061M
M:6YI<W1R871I;VX`5&5N=&%T:79E`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI
M9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!%9&ET($%T=&5N9&5E<R!S
M8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N($5X:71I;F<N`%1H92!&5%`@
M97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S
M:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R("(E<R(@
M8V%N;F]T(&)E(&1E;&5T960N`%1H92!C86QE;F1A<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!C86QE;F1A<B`B)7,B(&AA<R!B965N(')E;F%M960@
M=&\@(B5S(BX`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@<V%V960N`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!E;F0@9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A
M=&4N`%1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F
M=6QL>2!S96YT+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF
M+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92X`5&AE(&9O;&QO=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I
M;VX@;V8@=&AE(&5V96YT.@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H
M879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E
M;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I
M9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E
M;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD
M('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&5V96YT<R!M871C:&EN
M9R!T:&4@8W5R<F5N="!C<FET97)I82X`5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z
M("5S`%1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<P!4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M=`!4:&5R92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F
M;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4
M:&5R92!W87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E
M('=A<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T
M;R`E<SH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=E<F4@;F\@979E;G1S('1O
M(&5X<&]R="X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H
M87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@
M=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES
M(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N`%1H:7,@9F]R;2!H87,@
M86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A
M($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@
M>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V
M97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&AU<G-D87D`5&EC:V5T
M<P!4:6UE`%1I;64@4W!?86X`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4
M:6UE('-E;&5C=&EO;@!4:6UE('-P86X`5&EM;W(M3&5S=&4`5&ET7VQE`%1I
M=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET
M96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-
M86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U
M<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE
M("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E
M(&]R(&9A;'-E`%1U`%1U97-D87D`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H
M25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L
M86YD<P!4=79A;'4`5'EP90!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E
M>#H@`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N
M('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@
M8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S
M(CH@)7,`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='D`56YA8FQE('1O(&1E;&5T92`E<RX`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS
M`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@
M=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92`B)7,B.B`E<P!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R971R:65V92!F
M<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S`%5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S
M('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@=7-E<FYA
M;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N
M;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O
M;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII
M;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O
M<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5
M<&1A=&5D.B`E<RX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`
M57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R($EN=&5R9F%C90!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I
M;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92X`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@
M:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@
M;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC
M;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A
M;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!6
M96YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M
M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#
M;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC
M86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I
M97<@)7,`5FEE=R!$87D`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W
M(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S
M+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY
M('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!
M3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A
M=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE
M<BYC;VT`5V5B`%=E8B!3:71E`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E
M:RAS*0!7965K;'D`5V5E:VQY.B!296-U<G,@979E<GD`5V5L8V]M90!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E
M<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_`%=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S
M(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S/P!7:&%T('1I
M;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R
M92!A<F4@;F\@96%R;&EE<B!E=F5N=',_`%=H:6-H('!H87-E<P!7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I
M9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED
M=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9"!S
M<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!
M9&1R97-S`%=O<FL@4&AO;F4`5V]R:R!7965K`%@M4F5F`%@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@
M;6%P`%EE87)L>0!996%R;'DZ(%)E8W5R<R!E=F5R>0!996UE;@!997,`665S
M+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@8V%N(&]N;'D@=7-E('1H
M:7,@9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN`%EO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E<RX`66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R!T:&4@<V5L96-T960@
M8V%L96YD87(N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T
M92!T:&ES(&5V96YT+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E
M9&ET('1H:7,@979E;G0N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M(&AA=F4@<W!E8VEF:65D(&%N(&EN=F%L:60@8V%L96YD87(N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N
M;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L
M(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O
M('5S92!3:6=N=7!S+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO
M=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N`%EO=2!M
M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@
M86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@
M16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M
M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA
M;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&-A;&5N9&%R`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U
M<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L
M(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A
M<W-W;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R
M;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=`%M5;FYA;65D(&5V96YT70!;;&EN92`E<R!O
M9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"87-I8R!396%R8V@`7T-,20!?1&%T
M851R964`7T1E;&5T92!2;W<`7T5D:70`7T=O=&\`7T=R;W5P<P!?2&5L<`!?
M26UA9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&]G(&EN`%],
M;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3F5W($5V96YT`%]/<'1I;VYS`%]0
M97)M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK+BXN`%]396%R8V@`7U-E
M='5P`%]486)L92!0<F]P97)T:65S+BXN`%]4;V1A>0!?57-E<G,`861D<F5S
M<R!B;V]K`&)E9F]R92!T:&4@979E;G0@<W1A<G1S`&-A;&5N9&%R`&-A;&T`
M8VQI8VL@:&5R90!D87D`9&%Y*',I`&1A>7,`979E;G1S+F-S=@!E=F5N=',N
M:6-S`&9A;&QI;F<`9FEL90!F<F]M`&9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,`:#H`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C
M;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UO;G1H*',I`&YA;64`;F]T(&EM
M<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!O;B!T:&4@
M<V%M92!D871E`&]N('1H92!S86UE('=E96MD87D`<&5R8V5N=`!P:7AE;',`
M<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T
M96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N
M9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A;&5N9&%R+VE#
M86QE;F1A<@!V0V%R9`!V179E;G0@;F]T(&9O=6YD+@!W.@!W96%T:&5R+F-O
M;0!W965K`'=E96LH<RD@;VXZ`'=E96MS`'EE87(H<RD`4')O:F5C="U)9"U6
M97)S:6]N.B!+<F]N;VQI=&@@,BXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,3$M
M,S`@,3`Z-#,K,#(P,`I,87-T+51R86YS;&%T;W(Z(%9I;&EU<R!3=6US:V%S
M(#QV:6QI=7-`;&YK+FQT/@I,86YG=6%G92U496%M.B!,:71H=6%N:6%N(#QV
M:6QI=7-`;&YK+FQT/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,3,*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`H`("AP<FEE\"`E<R!D:65N87,I`"`H;7EG
M='5K87,@)7,I`"`H\&EA;F1I96XI`"`H=F%K87(I`"``)60@)7,@:7(@)7,`
M)60@X79Y:VEA:0`E9"UD:65N^"!P<F]G;F]ZZP`E<R`M('!A<W1A8F$`)7,@
M9&EE;F$H;W,L(/@I("5S('9A;&%N9&$H;W,L(/@I("5S(&UI;G5TZRCK<RP@
M:?@I`"5S(&%N='-P875D87,`)7,@2T(`)7,@<')O9FEL86MT:6MO<R!V96EK
M<VUA:2`M('!A='9I<G1I;FEM87,`)7,@<F5G:7-T<F%C:6IA`"5S(&YU;W-T
M871O<P`E<R!J874@96=Z:7-T=6]J82X`)7,@)7,@)7,`)7,@9F%I;&%S('/K
M:VUI;F=A:2#A:V5L=&%S`"5S('ER82!P<FEV86QO;6%S`"5S(&UI;G5TZW,`
M)7,@;F5R87-T87,N`&YU;R`E<R!I:VD@)7,@:?`@)7,`)7,@861R97/X(&MN
M>6=E;.L`)7,@:V%L96YD;W)I=7,`)7,@=?YR8?#X(&MN>6=E;.L`)7,@9&%R
M8O@@<^!R8?!A<P`E<SH@)7,`*B!.;W+K9&%M:2!P<FEDZW3A('-P875S:VET
M92!0<FEDZW1I("H`*B!087-I<FEN:VET92!A9')E<^`H=7,I("H`+"!G^W-I
M86D@)7,@)7,`+"!K:6YT82!N=6\@)7,@:6MI("5S`"TM('!A<VER:6YK:71E
M("TM`#$@X79Y:VES`#$R('9A;&%N9/@@9F]R;6%T87,`,C0@=F%L86YD^"!F
M;W)M871A<P`R-"!V86QA;F1O<P#0:6%M(&)L;VMU:2!R96EK86QI;F=A('9I
M971A(&1U;VUE;O@@8F%ZZVIE+@#!=GEK;R!R:6UT82!K;&%I9&$`3F]RZV1A
M;6D@=?YK;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@
M4$=0(')A:W3@+@!.;W+K9&%M:2!P871I:W)I;G1I('!A<VER8?!Y=.`@;&%I
M\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!01U`@<F%K=.`N`$YO<NMD
M86UI(&%T:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA
M(&ER('-L87!TX&KA(%!'4"!R86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@
M9G)A>N8N`$YO<NMD86UI('!A<VER8?!Y=&D@;&%I\&O@('!R:79A;&]T92!T
M=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!01U`@<F%K='5S+"!B96D@_FEN
M;W1I('-L87!TX&K@(&9R87KF+@!.;W+K9&%M:2!A=&MO9'5O=&D@;&%I\&O@
M('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!3+TU)344@
M<F%K='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+@!.;W+K9&%M:2!P
M87-I<F'P>71I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@
M<VQA<'3@:N$@4R]-24U%(')A:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F
M<F%ZYBX`3F]RZV1A;6D@=?YK;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5R
MZW1I('9I9?#@:N$@4R]-24U%(')A:W3@+@!!30!!32!R;V1Y;6%S`$%-+U!-
M`$%022!)1`!!<&EE(/#A(')E9&%K=&]R:?@`07!I92XN+@!6:7-I\&MA:2!A
M<&'H:6]J90!6:7-I\&MA:2!P97(@=FED=7+A`%!R:6EM=&$`4VES=&5M82!N
M971U<FD@=&5I<VGX('-U:W5R=&D@5D93(&MA=&%L;V?@+@!3:7-T96UA(&YE
M='5R:2!T96ES:?@@<W5K=7)T:2!61E,@9F%I;.`N`%-L87!T8?YO9&ES`%/@
M<VMA:71A('7^\&%L9'ET82X`07!S:V%I=&$`7T1E=&%L:2!P86EE\&MA`,%V
M97-T:0!3=6MU<G1I('!O9W)U<.$`4W5K=7)T:2!P;W1E:7-E<P!.875J87,@
MX79Y:VES`$)L;VMO(.%T97)P:6UA<SH`4W5K=7)T:2!N875JX"!G<G5PY@!3
M=6MU<G1I(&YA=6IA<R!T96ES97,`4W5K=7)T:2!N875JX"!N=71O;'5SX2!K
M86QE;F1O<FGX`%-U:W5R=&D@;F%U:N`@X79Y:^$`3F%U:F\@=F%R=&]T;VIO
M('-U:_MR:6UA<SH`4')I9.MT:2!D86QY=FEU<P!0<FEDZW1I('-T=6QP96SA
M`$YA=6KX(&YA<FGX('!R:63K:FEM87,`4W5K=7)T:2!P;W+@`%!R:63K=&D@
M)7,@;65N:74@<')I92!-;WII;&]S(.%R86YK:?@@:G5O<W1O<P#!=')A=6MT
M:2#A(&%D<F5S^"!K;GEG96SF.@#!=')A=6MT:2#A(&UA;F\@861R97/X(&MN
M>6=E;.8Z`%-U:W5R=&D@=F%R=&]T;VK@`%9A<G1O=&]J^"!K^W)I;6%S(&GP
M:G5N9W1A<RX`061R97-A<P!!9')E<_@@:VYY9V5LZP!!9&UI;FES=')U;W1I
M("T@9V%L:2!N=7-T871Y=&D@=&5I<V5S(&MI=&EE;7,@=F%R=&]T;VIA;7,`
M5F%L9'EM87,`0F%N97)I86D`1&5T86QI('!A:67P:V$`069G86YI<W1A;F%S
M`%!E<G-PZVII;6%S`%!E<G-PZVII;6\@9&%T80!097)S<.MJ:6UO('!A<VEK
M87)T;VII;6%S("AM:6YU=.MM:7,I`%!E<G-PZVII;6\@;&%I:V%S`$%L8F%N
M:6IA`$%L_GER87,`4')A=F%R9.L`3'EG:75O=&D`3'EG:6%V:6UA<SH`5FES
M:0!6:7-I(&1A;'EV:6%I`%9I<VD@<')I<VEJ=6YGYB!V87)T;W1O:F%I`%9I
M<VD@8OMS:6UI`%9I<V]S(&=R=7#K<P!6:7-O<R!T96ESZW,`5FES:2!M871O
M;6D`5FESX"!D:65NX`#!=GEK:7,@=FES86D@9&EE;F%I`%9I<VD@X79Y:VEA
M:0!6:7-O<R!K971U<FEO<R!P=7/K<P!,96ES=&D@:V5L973@(&%D<F5S^`!,
M96ES=&D@;F%U9&]T:2!S=7+[\&EU;W3@('/@<F'PX#\`2F%U(&5G>FES='5O
M:F$`06QT97)N871Y=G5S($E-4U`@<')I<VEJ=6YG:6UA<P!!;'1E<FYA='EV
M=7,@24U34"!S;&%P=&'^;V1I<P!!;'1E<FYA='EV=7,@24U34"!V87)T;W1O
M:F\@=F%R9&%S`$%L=&5R;F%T>79U<R!E;"X@<&'P=&\@861R97-A<P!!;'1E
M<FYA='EV^W,@\&%B;&]N86D`06QT97)N871Y=G5S('1E:W-T87,`06UE<FEK
M;W,@4V%M;V$`P79E9.MT92!N96QE:7-T:6[@(')E:6OP;>8N`$%N9&]R80!!
M;F=O;&$`06YG:6QA:0!!;F]N:6UI;FES('!R;WAY('-E<G9E<FES`$%T<V%K
M>6UA<P!!;G1A<FMT:61A`$%N=&EG=6$@:7(@0F%R8G5D80!"970@:W5R:0!-
M;V1U;&ES`$UO9'5L:7,@=F5I:VEA(&=E<F%I+@!0<FET86EK>71I(&ER('!O
M\&%K:6%M<P!0871V:7)T:6YT:0!"86QA;F1I<P!!<F%B:?!K82`H5VEN9&]W
M<RTQ,C4V*0!!<F-H>79O(&9A:6QO(&1Y9&ES`$%R8VAY=F\@9F%I;&\@<&%V
M861I;FEM87,`07(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2`E<R!R96=I<W1R
M86-I:F]S('!R8?!Y;>`_`$%R9V5N=&EN80!!<FWK;FEJ80!!<FWK;FGP:V$@
M*$%235-#24DM."D`365N87,`07)U8F$`2W)I<W1A=7,@_F5N9VEM;R#A(&1A
M;F?X('-A;&$`06-S:6D@;65N87,`07II:F$O4F%M:6]J;R!V86YD96YY;F\@
M<F5G:6]N87,`07(@<')A\'ET:2!P871V:7)T:6YT:2!P<F]F:6QA:W1I:V]S
M('9E:6MS;75S/P!0<FES:WER:6UO('-T=6QP96QI86D`(`!0<FEK86)I;G1A
M<R!F86EL87,@>7)A(&E#86QE;F1A<B!I;F9O<FUA8VEJ82!A<&EE(.%V>6OA
M+B!*96EG=2!J^W/X('!A\'1O(&ML:65N=&%S('!A;&%I:V\@:51I<"!U_FML
M875S87,L(&=A;&ET92!P86YA=61O=&D@\.$@9F%I;.`@871N875J:6YA;G0@
M;&]K86QI;W,@X79Y:VEO(&MO<&EJ;W,@9'5O;65N:7,N`$)A;F1O=&4@:?!T
M<FEN=&D@;F5E9WII<W1U;VIA;NAIX"!G<G5PYBX`0F%N9&]T92!I\'1R:6YT
M:2!N965G>FES='5O:F%NZ&EA<R!T96ES97,N`$)A;F1O=&4@<F5D86=U;W1I
M(&YE96=Z:7-T=6]J86[H:6%S('1E:7-E<RX`0F%N9&]T92!R961A9W5O=&D@
M;F5E9WII<W1U;VIA;G3A(&5L96UE;G3@+@!$86QY=F%V:6UA<P!$86QY=FEA
M:0!!=')I8G5T86D`4G5G<&K[=&ES`$%U<W1R86QI:F$`075S=')I:F$`075T
M:%]C>7)S<6PZ(&YE<F%S=&%S(')E:6MA;&EN9V%S($E-05`@;6]D=6QI<RX`
M075T:%]C>7)U<SH@8WER=7,@;F5T=7)I(')E:6MI86WX(&=A;&EM>6)I^"X`
M075T:%]C>7)U<SH@;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES
M+@!!=71H7V9T<#H@;F5R87-T87,@<F5I:V%L:6YG87,@1E10(&UO9'5L:7,N
M(%-U:V]M<&EL:75O:VET92!02%`@<W4@+2UE;F%B;&4M9G1P+@!!=71H7VEM
M87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($E-05`@;6]D=6QI<RX`075T:%]K
M<F(U.B!N97)A<W1A<R!R96EK86QI;F=A<R!K<F(U(&UO9'5L:7,N`$%U=&A?
M;&1A<#H@;F5R87-T87,@<F5I:V%L:6YG87,@3$1!4"!M;V1U;&ES+@!!=71H
M7VQD87`Z('-U:W5R=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO+B!397)V97)I
M;R!P<F%N9?!I;6%S.B``075T:%]L9&%P.B!I\'1R:6YT:2!V87)T;W1O:N`@
M)7,@;F5P879Y:V\`075T:%]L9&%P.B!A=&YA=6II;G1I('9A<G1O=&]JX"`E
M<R!N97!A=GEK;P!!=71H7VUC86PZ(&YE<F%S=&%S(')E:6MA;&EN9V%S($U#
M04P@;6]D=6QI<RX`075T:%]S;6)A=71H.B!N97)A<W1A<R!R96EK86QI;F=A
M<R!S;6)A=71H(&UO9'5L:7,N`%!R:7-I:G5N9W1I(&YE<&%V>6MO`%!R:7-I
M:G5N9W1I(&YE<&%V>6MO+B`E<P!2041)55,@<V5R=F5R:7,@;F5L96ED_FEA
M(&%U=&5N=&EF:6MU;W1I<RX`4')I<VEJ=6YG=&D@<')I92!&5%`@<V5R=F5R
M:6\@;F5P879Y:V\N`$=A;&EM:2!L875K86DZ`$%Z97)B86ED_F%N87,`0D]&
M2"!A='-I<')A\'EM86D`1F]N87,`1F]N;R!S<&%L=F$`3F5T96ES:6YG87,@
M:V5R8F5R;W,@<VQA<'1A_F]D:7,N`$YE=&5I<VEN9V%S(&ME<F)E<F]S('9A
M<G1O=&]J;R!V87)D87,N`$)A:&%M86D`0F%H<F5I;F%S`$)A;'1I\&MA("A)
M4T\M.#@U.2TQ,RD`0F%G;&%D9?!A<P!"87)B861O<V%S`%!A9W(N(&QI;FEJ
M;VIE`%!A<')A<W1O:FD@<&%I9?!K80!"86QT87)U<VEJ80!"96QG:6IA`$)E
M;&EZ87,`0F5N:6YA<P!"97)M=61A:0!"=71A;F%S`$=I;71A9&EE;FES`$)L
M;VMO('!A<F%M971R86D`0FQO:V\@=&EP87,`4&%S=&]R:6YT:0!";VQI=FEJ
M80!!=/YY;6]S`$MR8?!T87,`2W)A\'1O('-T;W)U;6%S.@!+<F'P=&%I`$)O
M<VYI:F$@:7(@2&5R8V5G;W9I;F$`5FES;W,`0F]T<W9A;F$`07!AZ&EO:F4`
M0G5V970@<V%L80!"<F%Z:6QI:F$`0G)I=/@@26YD:6IO<R!V86YD96YY;F\@
M=&5R:71O:F$`0G)U;NMJ875S(&1A<G5S86QE;6%S`$)U;&=A<FEJ80!3=?YY
M;>MT87,@<^!R8?!A<P!"=7)K:6YA<R!&87-A<P!"=7)U;F1I:F$`5?YI;71A
M`%164P!#4D,`0U),('!A<VMI<G-T>6UO('!U;FMT86D`2V%L7V5N9&]R:75S
M`%]#96SK<R!N=7-T871Y;6%I+BXN`$MA;%]E;F1O<FEU<P!+86QE;F1O<FEU
M<P!+86QE;F1O<FEA=7,@<V%N=')U;7!A`$MA;&5N9&]R:6%I`%)A;74`2V%M
M8F]D_F$`2V%M97+[;F%S`$YE=F5I:VEA(&%U=&]M871I;FES('-L87!T8?YO
M9/YI;R!P86ME:71I;6%S+"!S=7-I<VEE:VET92!S=2!A9&UI;FES=')A=&]R
M:75M:2X`3F5G86QI=2!P<FES:6IU;F=T:2!P<FEE($E-05`@<V5R=F5R:6\Z
M("5S`$YE<&%V>6MO('-U:W5R=&D@;F%U:F\@X79Y:VEO+@!+86YA9&$`073P
M875K=&D`073P875K=&D@<')O8FQE;6]S('!R86YE\&EMX`!!=/!A=6MT87,`
M073P875K=&$Z("5S`$YE9V%L:74@:?!T<FEN=&D@9F%I;&\@(B5S(BX`3F5G
M86QI=2!R87-T:2!L86EK:6YO:F\@:V%T86QO9V\N`$YE9V%L:74@87!D;W)O
M=&D@)W1A<F=E=$9I;&4G('!A<F%M971R;RX`3F5G86QI=2!I\'1R:6YT:2!K
M871A;&]G;R`B)7,B+@!.96=A;&EU(&GP=')I;G1I+B!%9WII<W1U;VIA("5D
M('!O\&%K:6%I+@!.96=A;&EU('!E<G+[\&EU;W1I+B#!=F5S=&%S(.%R8?#X
M('-K86GH:75S(&YE<W5T86UP82!S=2#A<F'P^"!S:V%IZ&EU;6D@9'5O;65N
M^"!B87KK:F4N`$YE9V%L:74@;G5K<F5I<'1I(/YI;G5TZW,@X2!N=7)O9'ET
MX"!N=6UE<N$N`$ME:7!V97)D:7,`4&%V861I;FEM87,`7TMA=&5G;W)I:F$`
M2V%T96=O<FEJ;W,`2V%T96=O<FEJ80!+86EM86[X('-A;&]S`$UO8FEL=7,@
M=&5L969O;F%S`$-E;.MS(&YU<W1A='EM86D`5&%R<&%I(&-E;.MS93H`0V5L
MZW,@;G5S=&%T>6UA:0!487)P86D@=&%R<"!C96QI^#H`36]B:6QU<VES('1E
M;&5F;VYA<P!+96QT^"`H25-/+3@X-3DM,30I`$-E;G1R90!#96YT<FENZW,@
M069R:6MO<R!297-P=6)L:6MA`$-E;G1R:6[K<R!%=7)O<&]S("A)4T\M.#@U
M.2TR*0!397)T:69I:V%T;R!D971A;.MS`%-E<G1I9FEK871O('1E:7/K<P#(
M861A<P!086ME:7-T:0!*^W/X('9A<F1O(&ER(&%D<F5S;RP@:W5R:75O<R!M
M871Y<R#^;6]NZW,L('-K86ET86YT>7,@:7(@871S86MI;NMJ86YT>7,@X2!*
M^W/X(&QA:?!K=7,L(&ME:71I;6%S+@!3:6UB;VQI<P!085]T:6MR:6YT:2!N
M=6]R;V3@+BXN`,AI;.L`2VEN:6IA`$MI;FEE=&GP:V$@<&%P<F%S=&$@*$="
M,C,Q,BD`2VEN:65T:?!K82!T<F%D:6-I;NL@*$)I9S4I`%!A<VER:6YK:71E
M('-L87!T8?YO9.$`4&%S:7)I;FMI=&4@=F%R=&]T;VIO('9A<F3@`%!A<VER
M:6YK:71E(&MA:7`@=F%I>F1U;W1I(&1A=&%S.@!087-I<FEN:VET92!S=7+[
M\&EU;W1O('/@<F'P;R!S=&EL:?@`4&%S:7)I;FMI=&4@861R97/X(&MN>6=E
M;.8L(&MU<FEO:F4@:67P:V]S:71E('7^:6UT=6UO(&EN9F]R;6%C:6IO<R!5
M4DPZ`$MA;.MD^"!S86QA`$ML87/K<R`E<R!NZW)A+@!':65D<F$`2?!T<FEN
M=&D@35,@3V9F:6-E(/YY;65S`%9A<G1O=&]J;R!D=6]M96[X('9A;'EM87,Z
M("5S`$GP=F%L>71I('9A<G1O=&]J;R!D=6]M96YI<P!)\'9A;'ET:2!V87)T
M;W1O:F\@9'5O;65N:7,`5.9S=&D`0VQI8VMA=&5L;"!P97(@2%144`!5_F1A
M<GET:2!L86YGX`!$96)E<W5O=&$`1&5B97-U;W1A`$MO:V]S;R`H2WEL:6YG
M;RD@<V%L;W,`5'7PZ&GX(&-E;&GX(&MR8?!T^"!R;V1Y;6%S`$MO;'5M8FEJ
M80!3<&%L=F$`4&%S:7)I;FMI=&4@<W!A;';@`%-P86QV;W,@<&%S:7)I;FMI
M;6%S`%-T=6QP96QI86DZ`%-T=6QP96QI^"!P879A9&EN:6UA:0!+;VUI:W-A
M:0!+86)L96QI86ES(&%T<VMI<G1O<R!R96EK\&WK<P!+;VUA;F1A`$MO;6%N
M9&ENZR!E:6QU=.L`2V]M96YT87)A<P!687)D87,O<&%V87)DZP!+;VUO<F%I
M`$MO;7!A;FEJ80!+;VUP:75T97)I86D`4^!L>6=O<P!.=7-T871Y;?@@<&%K
M96ET:6UA:0!+;VYF:6?[<G5O=&D@)7,`4VQA<'1A_F]D:7,@9&%R(&MA<G3@
M`%!A='9I<G1I;G1I('9I<_@@X79Y:VGX(&GP=')Y;FEMX#\`4&%T=FER=&EN
M=&%S`$MO;F=A<P!$96UO:W)A=&ENZR!+;VYG;R!297-P=6)L:6MA`%!R:7-I
M:G5N9W1I(&YE<&%V>6MO+@!0<FES:6IU;F=T:2!N97!A=GEK;SH@`%!R:7-I
M:G5N9W1I('!R:64@=FEE\/AJ^"!R86MT^"!S97)V97)I;R!N97!A=GEK;RX`
M4')I<VEJ=6YG=&D@<')I92!V:67P^&KX(')A:W3X('-E<G9E<FEO(&YE<&%V
M>6MO+"!N97,Z("5S("@E<RD`4')I<VEJ=6YG=&D@<')I92!&5%`@<V5R=F5R
M:6\@;F5P879Y:V\N`$MO;FMA:W1A:2!SZVMM:6YG86D@X71R875K=&D@X2!*
M^W/X(&%D<F5S^"!K;GEG96SF`%3F<W1I`$MU:V\@<V%L;W,`3&%I;>MS(/YI
M;G5TZW,`2V]P:6IU;W1I`$MO<&EJ=6]T:2!P87-I<FEN:VEMX`!+;W-T82!2
M:6MA`$1R86UB;&EO($MA=6QO($MR86YT87,`3F5P879Y:V\@=?YK;V1U;W1I
M(%!'4"!L86GP:V\N`$YE<&%V>6MO('!A<VER8?!Y=&D@4$=0(&QA:?!K;RX`
M3F5P879Y:V\@=?YK;V1U;W1I(%,O34E-12!L86GP:V\N`$YE<&%V>6MO('!A
M<VER8?!Y=&D@4R]-24U%(&QA:?!K;RX`3F5P879Y:V\@<')I9.MT:2!K;VYT
M86MT;RX@)7,`3F5P879Y:V\@875T96YT:69I:W5O=&ES(.$@3$1!4"!S97)V
M97+A+@!.97!A=GEK;R!P871I:W)I;G1I(&)A;&%N<V\N("5S`$YE<&%V>6MO
M('-U:W5R=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO(&%T
M:V]D=6]T:2!01U`@9'5O;65N^"X`3F5P879Y:V\@871K;V1U;W1I(%,O34E-
M12!D=6]M96[X+@!.97!A=GEK;R!I\'1R:6YT:2!K;VYT86MT;RX@)7,`3F5P
M879Y:V\@:?!T<FEN=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S`$YE<&%V
M>6MO(&YU<W1A='ET:2!G87;K:F\@96PN('!A\'1O(&%D<F5S;RX`4&%V>6MO
M(&=A=71I('9I<V]S(&%D<F5S^"!K;GEG96SK<RX`3F5P879Y:V\@9V%U=&D@
M=FES;R!D:7-T<FEB=6-I:F]S('/@<F'P;RX`3F5P879Y:V\@9V%U=&D@=FES
M;R!D:7-T<FEB=6-I:F]S('/@<F'P^"!SX')A\&\N`$YE<&%V>6MO(&=A=71I
M('9I9?!O:F\@<F%K=&\@:?`@<F%K=/@@<V5R=F5R:6\N`$YE9V%L:74@871I
M9&%R>71I("5S+@!.97!A=GEK;R!A=&ED87)Y=&D@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&EO("5S`$YE<&%V>6MO('-K86ET>71I("5S+@!.97!A=GEK;R!P
M86ME:7-T:2!S;&%P=&'^;V3^:6\@\&EA;2!V87)T;W1O:G5I+B!+86D@:W5R
M:2!A<F)A('9I<V$@:6YF;W)M86-I:F$@>7)A(&YE=&EK<VQI+B!086)A;F1Y
M:VET92!D87(@:V%R=.`@87)B82!S=7-I<VEE:VET92!S=2!S879O(&%D;6EN
M:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA;&EN9V$@<&%G86QB82X`3F5P879Y
M:V\@9V%U=&D@04-,`$YE<&%V>6MO(&=A=71I(&%D<F5S^"!K;GEG96SK<RX@
M)7,`3F5P879Y:V\@9V%U=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S`$YE
M<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ;W,@<^!R8?#X+B`E<P!.97!A=GEK
M;R!N=7-T871Y=&D@<V5R=F5R:6\@9V%L:6UY8FGX`$YE<&%V>6MO(&%T:V5I
M<W1I(&YU<W1A='EM^"X`3F5P879Y:V\@:?!S875G;W1I("5S(&YU<W1A='EM
M^"X`3F5P879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R!N=7-T871Y;?@@:V]P
M:6IO<RX`3F5P879Y:V\@<&%I9?!K82!,1$%0('-E<G9E<GEJ92X`3F5P879Y
M:V\@871N875J:6YT:2!K;VYT86MT;RX@)7,`3F5P879Y:V\@871N875J:6YT
M:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@<F%S=&D@36]Z
M:6QO<R#A<F%N:VGX(&IU;W-T;W,N(,%S:71I:VEN:VET92P@:V%D(&II(&%T
M:61A<GET82X`4FEB;W1A<R!T96MS=&%S`%9A;'-T>6+K`$MU<G-A:0!3=6MU
M<G1I`%-U:W5R=&D@;F%U:N`@X79Y:^$`4W5K=7)T:2!N=6]R;V3@`%-U:W5R
M=&D@;F%U:N`@87!R8?#@`%-U:W5R=&D@<&%K871A;&]G:75S`%-U:W5R=&$`
M4V%V:6YI;FMO('1E:7/K<P!+<F5D:71I;NMS(&MO<G1E;.MS(&YU;65R:7,`
M2W)O871I:F$`2W5B80!%:6YA;6%S`$1A8F%R=&EN:7,@;&%I:V%S`-!I=6\@
M;65T=2!54DP@>7)A`$1A8F%R=&ENZW,@;W)O('/@;'EG;W,`1&%B87)T:6[K
M<R!SX&QY9V]S.B``1&%B87)T:6YI<R!S=&EL:75S`%9E:6MS;?@L(&%T;&EE
M:V%M^"!P<FES:6IU;F=U<R!P<FEE("5S+"!N=7-T871Y;6%S+@!097)K96QT
M:0!097)K96QT:2!P87-I<FEN:VEMX`!+:7!R87,`2VER:6QI8V$@*$M/23@M
M4BD`2VER:6QI8V$@*%=I;F1O=W,M,3(U,2D`2VER:6QI8V$O56MR86EN:65T
M:?!K82`H2T])."U5*0#(96MI:F]S(%)E<W!U8FQI:V$`1$0`2V%S9&EE;@!+
M87-D:65N:6YI<SH@4&%S:6MA<G1O:F$@:V%S`$1U;VUE;O@@;65D_FEO(&YA
M<O!Y:VSK`$1A=&$`1V%U=&$`1&%T;W,@<&%S:7)I;FMI;6%S`$1I96YA`$1I
M96YA*&]S*0!)\'1R:6YT:0!)\'1R:6YT:2!?<W1U;'!E;.$`1W)U;V1I<P!$
M9?!I;71A:6YI86D@<VMA:>AI86D`4&%S:6)A:6?F<P!3=6UA_FEN=&D@871I
M=')A=6MI;>``4W1A;F1A<G1I;NL@<W!A;'9A`%-T86YD87)T:6YI<R!A<')A
M\&%S`$%P:6)RZ_YI;6%I`$GP=')I;G1I`$GP=')I;G1I("5S`$GP=')I;G1I
M(.%V>6OA`$GP=')I;G1I(&=R=7#F`$GP=')I;G1I('1E:7/F`%9I<VGP:V%I
M(&GP=')I;G1I(&QA:?!K=7,`2?!T<FEN=&D@8V5LY@!)\'1R:6YT:2!S='5L
M<&5LX0!)\'1R:6YT:2!E9WII<W1U;VIA;G3A(&%L=&5R;F%T>7;X(/!A8FQO
M;N``2?!T<FEN=&D@96EL=73F`$GP=')I;G1I('!A<VER:6YK=.`@87!R8?#@
M`$GP=')I;G1I(/#A('-T=6QP96SA`$GP=')I;G1I('1I:R#PX2#A=GEKX2P@
MX79Y:^$@:7(@=FES=7,@8OMS:6UU<RP@87)B82!V:7-K83\`2?!T<FEN=&D@
M\&G@(&5I;'5TY@!0<FES=&%T>6UO(&QA:6MA<P!$86YI:F$`7T%P<F'P>6UA
M<P!0<F]B;&5M;W,@87!R8?!Y;6%S`$%P<F'P>6UA<P!$971A;&EA=2`H=&%I
M<"!P870@_FG[<NMK:71E($AO<F1E(&QO9R!F86EL92DZ`$%D;6EN:7-T<F%T
M;W)I=6D@:?!S:?AS=&%S(&1E=&%L=7,@87!R8?!Y;6%S+@!6>7-T>6UA<P!$
M<NMG;G5M87,`1'+K9VYU;6%S('!A<VMU=&ENYB!V86QA;F3@.B``1'+K9VYU
M;6%S.B``2W)Y<'1I<R!I\"!K86ERZW,@X2!D9?!I;N8`2W)Y<'1I<R!I\"!D
M9?!I;NMS(.$@:V%I<N8`2V%T86QO9V%S`%)O9'ET:0!2;V1Y=&D@,C0M:?@@
M=F%L+B!F;W)M873@/P!686EZ9&%V:6UO(&YU<W1A='EM86D`4F]D>71I('!R
M;V=R;V[F("A4048I`%9A:7ID879I;6\@9F]R;6%T87,`3&%I\&MO('!R:7-T
M871Y;6\@<')A;F7P:6UA:0!$_FEB=71I<P!.971R:6YT:0!.97-I:W)E:7!K
M:71E('1I97-I;V=I86D@X2!M86EN=&5N86YC92YP:'``3F5P87-I:V%R=&]J
M80!!<B!P:7)M87,@X7)A\&%S('ER82!L875K;R!V87)D86D_`$1O;6EN:6MA
M`$1O;6EN:6MO<R!297-P=6)L:6MA`$%T<VES:?AS=&D`071S:7-I^'-T:2`E
M<P!!='-I<VGX<W1I('-U9V5N97)U;W1U<R!N=7-T871Y;75S(&MA:7`@4$A0
M('-K<FEP=.`N`$GP<VES:VQE:63^:6%N=&ES('/@<F'P87,`5F%I<W1A:0!4
M<G5K;>LZ("5S`%1R=6MMZP!%;"X@<&'P=&\@861R97-A<P!%4E(`16MV861O
M<F%S`%)E9&%G=6]T:2`E<P!$86QY=FGX(')E9&%G879I;6%S`$ME:7-T:2!B
M;&]K;R!P87)A;65T<G5S`%)E9&%G=6]T:2!G<G5PY@!2961A9W5O=&D@=&5I
M<V5S`%)E9&%G=6]T:2!T96ES97,`)7,@=&5I<VGX(')E9&%G879I;6%S`%)E
M9&%G=6]T:2!N=71O;'5S:75S(&MA;&5N9&]R:75S`%)E9&%G=6]T:2!D86QY
M=FEU<P!+96ES=&D@;G5S=&%T>6UU<SH`)7,@=&5I<VGX(')E9&%G879I;6%S
M`%5G9'EM87,`16=I<'1A<P!386QV861O<F%S`$5L96UE;G1A<RXN+@!%;0!%
M;"X@<&'P=&%S`$5L+B!P8?!T;R!A9')E<V%S`$5L+B!P8?!T;R!A9')E<V%I
M('1U<FD@<W5T87!T:2X`16PN('!A\'1O(&%D<F5S87,@<W4@<&%T=FER=&EN
M:6UU`-!Y<'-E;NMLZW,`WFEN=73K('1U\.AI82X`4F5Z=6QT871A<R!T=?#H
M:6%S+@!.96YU<F]DZW1E('!A:67P:V]S('1E<FUI;O@`3&5I<W1I('1E:W-T
M92#A=&5R<'1I('!A=F5I:W-LZVQI=7,@:?`@3G5O=')A=6OX(&=A;&5R:6IO
M<S\`P6IU;F=T:2!D9?!I;FEO:F\@<&5LZW,@;7EG='5K;R!M96YI=3\`4&%B
M86EG;W,@9&%T80!"86EG:6%S:0!086)A:6=O<R!L86EK87,`1V%L:6YI86D@
M;65T86D`2?!P;.MS=&D@<F5D86MT;W)I^`#!<F'P>6MI=&4@:VQA=7-I;>`L
M(&MU<FES(&IU;7,@8G5S('7^9'5O=&%S(&IE:6=U('!A;6ER\&ET92!S879O
M('-L87!T8?YO9.$L('!V>BXZ("=K;VMS('ER82!*^W/X(&=Y=OMN;R!V87)D
M87,_)SH`P79E<VMI=&4@<&%V96EK<VSK;&EO(%523`!%:W9A=&]R:6[K($=V
M:6[K:F$`17)I='+K:F$`2VQA:61A`$YE9V%L:74@9V%U=&D@)7,@=F%R=&]T
M;VIO('7^:6UT=6UO(&EN9F]R;6%C:6IO<SH@)7,`2VQA:61A(&QA:?!K92X`
M17-T:6IA`$5T:6]P:6IA`$5T;FENZW,`175R;W!A`,%V>6MI<R!N=6\@)7,@
M:6MI("5S`$MA<R`Q-2!M:6YUZ&GX`$MA<R`R(&UI;G5T97,`2V%S(#,P('-E
M:W5N9/YI^`!+87,@-2!M:6YU=&5S`$MI96MV:65N;R!P<FES:6IU;F=I;6\@
M;65T=0!+87,@<'5S=F%L86YDX0!+87,@;6EN=73F`%!A=GEZ9/YI=6DZ`%9Y
M:V1Y=&D`2?!S:VQE:7-T:0!296EK86QI;F=A<R`G*2<`4F5I:V%L:6YG87,@
M_F]D:7,@87)B82!K86)U=.MS92#A<F'P>71A<R!P86EE\&MO<R!K<FET97)I
M:G5S`$=A;&EO:FEM;R!D871A`$5K<W!O;F5N=.L`2?!K96QT:0!)\&ME;'1I
M(&MA;&5N9&]R:?@`5&5K<W1O('-P86QV80!.=7-T871Y;?@@<VEU;G1I;6%S
M('!E<B!&5%`N`$ML86ED82!N=7-K86ET86YT(&YU<W1A='EM=7,N`$YE<&%V
M>6MO('!R:7-I:G5N9W1I('!R:64@3$1!4"!S97)V97)I;RX`3F5P879Y:V\@
M<')I<VEJ=6YG=&D@<')I92!334(@<V5R=F5R:6\N`$YE<&%V>6MO(&YU:V]P
M:6IU;W1I(&GP("(E<R(N`$YE<&%V>6MO(&YU:V]P:6IU;W1I(.$@(B5S(BX`
M3F5P879Y:V\@<W5K=7)T:2!N875J;R!305-,(')Y\&EO+@!.97!A=GEK;R!P
M97)K96QT:2#A("(E<R(N`-!V96QN=7,`1F]L:VQA;F3X('-A;&]S("A-86QV
M:6YA:2D`1F%R97+X('-A;&]S`$9A:W-A<P!687-A<FES`$%T<F]D;R!L>6<`
M071R;V1O(&QY9SH@`%1R=6UP86QA:6MI<R!L:65T=7,`1FED_FES`$9A:6SX
M('-K86GH:75S.B`E<R!F86EL87,`1F%I;/@@<VMA:>AI=7,Z("5S(&9A:6QA
M:2CX*0!&86EL^"!T=F%R:WEM87,`1F%I;&\@<&%V861I;FEM87,`1F%I;&\@
M<&%S:7)I;FMI;6%S`$9A:6QO('-I=6YT:6UA<P!.87+P>6MLZR!N97!A;&%I
M:V\@9F%I;/@@<VEU;G1I;6\N`$9I;'1R86D`267P:V]T:0!3=6]M:6IA`%!I
M<FUO:FD@<'5SZP!0:7)M87-I<R!K971V:7)T:7,`3G5S=&%T>71A<R!K;V5F
M:6-I96YT87,`071V:7)K\.AI87,`2?!DZW-T>6UA<P!2^VMA<P!+871A;&]G
M87,@)7,@;F5E9WII<W1U;VIA`%1E:W-T;R!S<&%L=F$`36%I<W1A<P!.87+P
M>6MLZVUS+"!K=7)I;W,@;F5P86QA:6MO('!A=F5I:W-LZVQI^`!/<O@@<')O
M9VYO>NL@*%1!1BD`3W+X('!R;V=N;WKK<R!A<&EM=&ES("CA<VEDZVWK:VET
M92P@:V%D(/!I(&9U;FMC:6IA(&=R8?YI;F$@:7(@9&EE;F]S(&ER(&YA:W1I
M97,@<')O9VYO>N8[('!E<B!D:61E;&ES('-K86GH:75S(&=A;&D@<W5D87)K
M>71I(&1I>F%I;N`I`%!A;6ER\&]T92!S879O('-L87!T8?YO9.$_`$9O<FUO
M<P!&<F%ZZP!&<F%Z:?@@=&EP87,`1G)A>NMS`$9R87KK<R`R`$1I<VMU<VEJ
M;W,`4&5R<VEU;G1I;6%I`%!E;FLN`$MR8?!T:6[K<P!0<F%N8_MZ:6IA`%!R
M86YC^WII:F$L($UE=')O<&]L:7,`4')A;F/[>FEJ;W,@1W9I86YA`%!R86YC
M^WII:F]S(%!O;&EN97II:F$`4')A;F/[>FEJ;W,@<&EE=&ENZW,@=&5R:71O
M<FEJ;W,`4&5N:W1A9&EE;FES`$YU;P!.=6\@`%!I;&YA<R!A<')A\'EM87,`
M4&EL;F%T:7,`4&EL;F%S('9A<F1A<P!"^W-I;6%S`$=A8F]N87,`1V%L97)I
M:F$@:?`@:W5R:6]S(&GP(&MU<FEO<R!B=7,@<F]D;VUA<R!P879E:6MS;.ML
M:7,`1V%L97)I:F$Z`$=A;6)I:F$`WF%I9&EM87,`4&%G<FEN9&EN:6%I(&QA
M=6MA:0!'96YE<G5O=&D@)7,@;G5S=&%T>6UU<P!3=6=E;F5R=6]T87,@:V]D
M87,`1W)U>FEJ80!6;VMI971I:F$`1V%N80!':6)R86QT87)A<P!687)D87,`
M4F]D>71I`$=A9&5L:7,`1V]O9VQE('!A:67P:V$`4F]D>71I("5S`$YE<W!A
M;'9O=&%S`$=R86EK:6IA`$=R86EK:?!K82`H25-/+3@X-3DM-RD`1W)E;FQA
M;F1I:F$`1W)E;F%D80!'<G5P:?@@861M:6YI<W1R879I;6%S`$=R=7#K<R!V
M87)D87,@='5R:2!B^W1I(&YE='7PZ&EA<P!'<G5PZW,`1W9A9&5L=7#K`$=U
M86UA`$=V871E;6%L80!'97)N<VES`%-V9>AI^"!T96ESZW,`4W9EZ&GX(&MN
M>6=A`$=V:6[K:F$`0FES<V%U+4=V:6[K:F$`1V%J86YA`$A434P`2%1-3$%R
M96$@;F5G86QI(&GP=')I;G1I('!A<VMU=&ENZW,@8V5LZW,@96EL=73K:F4N
M`$A434Q!<F5A(&YE9V%L:2!I\')I;G1I('!A<VMU=&EN:6\@<W1U;'!E;&EO
M(&QE;G1E;.MJ92X`2%1-3$%R96$@;F5G86QI(&GP=')I;G1I('!A<VMU=&EN
MZW,@96EL=73K<R!L96YT96SK:F4N`%)E:6MA;&EN9V$@2%144"!A=71E;G1I
M9FEK86-I:F$N`$AA:71I<P!(87-H+4%L9V]R:71M87,`36EG;&$`06YT<F'P
M=.L`2&5R9&\@<V%L82!I<B!-86MD;VYA;&1O('-A;&]S`$AE8G)A:O@@*$E3
M3RTX.#4Y+3@M22D`075K\'1I<P!086=A;&)A`%)E9&%K=&]R:6%U<R!N875D
M;VII;6]S:2!P86=A;&)A`%!A9V%L8FEN:6YK87,`2&5M:7-F97)A`-!T86D@
MZ&EA('ER82!F86EL;R!P<F%D_FEA.@!3=F%R8G4`7U!O<G1A;&%S`-!V96YT
M87-I<R!3;W-T87,@*%9A=&EK86YO('9A;'-T:6IA*0!0;W)T86QA<P!.86WX
M(&%D<F5S87,`3F%M^"!T96QE9F]N87,`2&]N9/MR87,`2&]N:V]N9V%S`%!O
M<G1A;&%S`$AO<F1E+TMO;&%B.B!N971E:7-I;F=I("5S(%A-3"!D=6]M96YY
M<R#^:6YU=.MJ92`E<P!(;W)D92]+;VQA8CH@;V)J96MT;R`E<R!N96%T:71I
M;FMA(&IO:VEA(/YI;G5TZP!(;W)D92]+;VQA8CH@;V)J96MT;R!T:7!A<R`E
M<R!N97)A<W1A<R#^:6YU=.MJ92`E<P!(;W)D92]+;VQA8CH@)7,@(B5S(B!S
MZVMM:6YA:2!I\'1R:6YT80!(;W)D92]+;VQA8CH@:6YT96=R86-I:F]S('9A
M<FEK;&EU:W5I(')E:6MA;&EN9V%S("=D;VUX;6PG(%!(4"!M;V1U;&ES`$AO
M<F1E+TMO;&%B.B!N97!A=GEK;R!S=6MU<G1I(&YA=6IO(%A-3"!M963^:6\@
M;V)J96MT=6D@)7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO(&GP=')I;G1I("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!N97!A=GEK;R!G875T:2!-24U%($E$
M(&1A;&EA:2`E<R!T:7!O`$AO<F1E+TMO;&%B.B!N97!A=GEK;R!S=7-I;F-H
M<F]N:7IU;W1I("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!N97!A=GEK;R!S
M=7-I;F-H<F]N:7IU;W1I(&5L96UE;G3X.B`E<P!(;W)D92]+;VQA8CH@;F7^
M:6YO;6%S(&5L96UE;G1A<R`B)7,B`$AO<FEZ;VYT86QI(&QI;FEJ80!(;W)I
M>F]N=&%L=7,@=&%R<&%S`$AO<FEZ;VYT86QI86DZ`%9A;&%N9&$H;W,I`$MA
M:7`@Z&EA('!A=&5K;W1E/R`H4')A;F7P:VET92$I`$MI96L@<W1U;'!E;&GX
M(&YO<FET92!S=6IU;F=T:3\`2VEE:R!L875K^"`H<W1U;'!E;&GX*2!T96X@
M>7)A/P!+:65K(&5I;'7H:?@@;F]R:71E('-U:G5N9W1I/P!$<NMG;G5M87,`
M1'+K9VYU;6%S.B``2G5M;W)E<VMO<P!696YG<FEJ80!.97!A=GEK;R!S=6MU
M<G1I($E-05`@<&'P=&\@9.O^=73K<SH@)7,`3F5P879Y:V\@:?!T<FEN=&D@
M24U!4"!P8?!T;R!DZ_YU=.MS.B`E<P!.97!A=GEK;R!N=7-T871Y=&D@24U!
M4"!P8?!T;R!DZ_YU=.MS(&1Y9/YI;SH@)7,`25`@861R97-A<P!.97!A=GEK
M;R!G875T:2!)4"!A9')E<V\N`$E0(&%D<F5S87,@;F5T96ES:6YG86UE($-)
M1%(@8FQO:V4N`$E0('7^<F%K:6YT87,N`%_!=&5R<'1I(&5I;'5TYB!V:7+P
M=6IE`$ES;&%N9&EJ80!4:6L@<&EK=&]G<F%M;W,`4&EK=&]G<F%M;W,@<W4@
M=&5K<W1U`$%P<F'P;R!P879A9&EN:6UA<SH`2F5I(&YE9V%L:71E('!E<G-K
M86ET>71I(/!I;R!L86GP:V\L("5S+@!*96EG=2!M871O=&4@\&G@(/YI;G5T
MYB!V:65T;VH@<&%V96EK<VSK;&EO+"!K=7+A(&YO<FET92#A:V5L=&DL('1A
M:2!*^W/X(&YA<O!Y:VSK(&YE9V%L:2!J;R!A='9A:7ID=6]T:2X`4&%V96EK
M<VSK;&EO('!E<OYI^W)A`%!A=F5I:W-LZVQI;R!54DP`4&%V96EK<VSK;&EO
M(%523#H`4&%V96EK<VSK;&ES(&GP(&=A;&5R:6IO<P!0879E:6MS;.ML:7,@
M:?`@9V%L97)I:F]S.@!0879E:6MS;.ML:6\@X6OK;&EM87,`5F%I>F1A:0!+
M86QE;F1O<FEA=7,@X6OK;&EM87,L("5D+6%S(/YI;F=S;FES`,%KZVQI;6%S
M+"`E9"#^:6YG<VYI<P#!:V5L=&DO2?!K96QT:2!K86QE;F1O<FGX`$QA=6MA
M<R#A:V5L=&%S.B`E<P#!:V5L=&D@;&%U:V%I.@#!7W1E<G!T:2!E:6QU=.8@
M87!AZ&EO:F4`3F5T96ES:6YG87,@=F5I:W-M;R!K;V1A<RX`3F5T96ES:6YG
M87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES+@!.96ET
M96ES:6YG87,@=F%R=&]T;VIO('9A<F1A<R!A<F)A(&%L=&5R;F%T>79U<R!E
M;"X@<&'P=&\@861R97-A<RX@0F%N9'EK:71E(&1A<B!K87)TX"!A<F)A('-U
M<VES:65K:71E('-U('-A=F\@861M:6YI<W1R871O<FEU;6D@:F5I9W4@<F5I
M:V%L:6YG82!T;VQE<V[K('!A9V%L8F$N`%!A9&ED:6YT:2!A=&ET<F%U:VEM
MX`!);F1I:F$`26YD:79I9'5A;/MS('9A<G1O=&]J86D`26YD;VYE>FEJ80!)
M;F9O<FUA8VEJ80!);F9O<FUA8VEJ80#!=')A=6MT:2!S='5L<&5LX2!?9&7P
M:6[K:F4`P71E<G!T:2!P879E:6MS;.MLX0#!=&5R<'1I(&QE;G1E;.8`P71E
M<G!T:2!N=6]R;V3@`,%T97)P=&D@<W1U;'!E;.$@7VMA:7+K:F4`P71E<G!T
M:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L:6\@9&7P:6[K:F4`P71E
M<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L:6\@:V%I<NMJ90#!
M=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K<R!A<&'H:6]J90#!
M=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K<R!V:7+P=6IE`,%T
M97)P=&D@<&%R86=R86;@(&5L96UE;G1O(&%P8>AI;VIE`,%T97)P=&D@<&%R
M86=R86?@(&5L96UE;G1O('9I<O!U:F4`P71E<G!T:2!A;'1E<FYA='EV^"#P
M86)L;V[@`,%R8?!Y:VET92!E;"X@<&'P=&\@861R97/@+"#A(&MU<N$@;F]R
M:71E(&=A=71I(&YA=6K@('-L87!T8?YO9.$Z`,%T97)P=&D@8V5LYB!P;R!T
M;P#!=&5R<'1I(&-E;.8@<')I9?`@=&%I`,%T97)P=&D@<W1U;'!E;.$@9&7P
M:6[K:F4`P71E<G!T:2!S='5L<&5LX2!K86ERZVIE`,%T97)P=&D@;&%I\&MU
M<P#!=&5R<'1I('!A<F%G<F%FX"!P;R!T;P#!=&5R<'1I('!A<F%G<F%FX"!P
M<FEE\"!T86D`P71E<G!T:2!E:6QU=.8@<&\@=&\`P71E<G!T:2!E:6QU=.8@
M<')I9?`@=&%I`,%R8?!Y:VET92!R96EK:6%MX"!A='-A:WEMX"#A(&ML875S
M:6W@('9I<O!U:F4Z`,%T97)P=&DO<F5D86=U;W1I('!A=F5I:W-LZVSA`,%T
M97)P=&DO4F5D86=U;W1I(&YU;W)O9.``1&ES=')I8G5C:6IO<R!SX')A\'5I
M(&YU<VGX<W1I(&YE=?YT96YK82!K<F5D:71O+@!.977^=&5N:V$@:W)E9&ET
M;RX`4VMA:>AI=7,`4VMA:>AI^"!SX')A\&%S`$YE=&5I<VEN9V%S(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+@!.971E:7-I;F=A<R!M;V1U;&ES+@!.971E
M:7-I;F=A<R!)1"X`P79E<W1I(&YE=&5I<VEN9VD@9'5O;65N>7,N`$YE=&5I
M<VEN9V%S(&%D<F5S87,N`$YE=&5I<VEN9V%S(&9A:6QO(&9O<FUA=&%S`$YE
M=&5I<VEN9V%S(&US9U]T>7!E+@!.971E:7-I;F=A<R!A<F)A(&[K<F$@87!I
M7VED+@!087)A;65T<F%I(&YE=&5I<VEN9VD@87)B82!J^"!NZW)A+@!.971E
M:7-I;F=O<R!P879E;&1I;6]S('1E:7/K<RX`3F5T96ES:6YG87,@<')O=&]K
M;VQA<RX`3F5T96ES:6YG87,@;V)J96MT87,`3F5T96ES:6YG87,@<VEU;G3K
M:F\@861R97-A<RX`3F5T96ES:6YG:2!U;FEK;V1O(&1U;VUE;GES+@!);G9E
M;G1O<FEU<P!)<VQA;6GP:V$@27)A;F\@4F5S<'5B;&EK80!)<F%K87,`06ER
M:6IA`$UE;F\@<V%L80!)>F]L:75O=&]S(%0M875D<F]S`$EZ<F%E;&ES`$GP
M9&%VZVIA<P!+=7)S>79A<P!)=&%L:6IA`$IA;6%I:V$`4V%U<VES`$IA<&]N
M:6IA`$IA<&]N:?!K82`H25-/+3(P,C(M2E`I`$3^97)S:7,`2F]R9&%N:6IA
M`$QI97!A`$)I<OYE;&ES`%!I;&YA:0!,>6=I=6]T:2!C96YT<F4`3'EG=6]T
M:2!P:6QN86D`3'EG:75O=&D@:V%I<NMJ90!,>6=I=6]T:2!D9?!I;NMJ90!+
M87IA:W-T86YA<P!)\'-A=6=O=&D@;W)I9VEN86S@/P!+96YI:F$`3F5P879Y
M:V\@<')I<VEJ=6YG=&D@<')I92!+97)B97)O<R!S97)V97)I;RX`0G)A;F1U
M;VQI;R!N875J;VMA:0!286MT;R!K^W)I;6%S`%)A:W1O(&%T<W!A=61A<P!2
M86MT;R!I;&=I<P!286MT;R!T:7!A<P!286MT;R!P86YA=61O:FEM87,`4F%K
M=&%S(&IA=2!Y<F$@=FEE\/AJ^"!R86MT^"!S97)V97)Y:F4N`-YO9/YI86D`
M5F%I:V%I`$MI<FEB871I<P!$96UO:W)A=&ENZR!+;W+K:F]S($QI875D:65S
M(%)E<W!U8FQI:V$`2V]RZVIO<R!297-P=6)L:6MA`$MO<NMJ:65T:?!K82`H
M155#+4M2*0!+=79E:71A<P!+:7)G:7II:F$`7TGP9.MS='EM87,`2V%L8F$`
M3&%O<V\@1&5M;VMR871I;NL@3&EA=61I97,@4F5S<'5B;&EK80!087-K=71I
M;NMS(#(T('9A;&%N9&]S`$%N=')A('!U<^L`4&%S:W5T:6[A(&MA<G3@(')E
M9&%G=6]T80!087-K=71I;FES(&WK;G5O`%!A<VMU=&EN:7,@:V5T=FER=&ES
M`$%T;F%U:FEN=&$Z`%!A<VMU=&EN:7,@<')I<VEJ=6YG:6UA<SH@)7,`4&%S
M:W5T:6YI<R!P<FES:6IU;F=I;6%S.B`E<R!I\"!A9')E<V\@)7,`4')I<VEJ
M=6YGZW1E('!I<FW@(&MA<G3@`%!A<VMU=&ENZR!S879A:73K`$QA='9I:F$`
M5&5I<^L`2?!DZW-T>6UA<P!*96EG=2!N96YO<FET92!N96YA=61O=&D@:W)A
M\'3X+"!P86QI:VET92!T=?#H:>``3&EB86YA<P!+86ERZVIE`$MA:7)I;VII
M(&%N=')A\'3K`$MA:7)I;W-I;W,@<F5I:_!MZW,`3&5S;W1A<P!,:6)E<FEJ
M80!,:6)I:F]S($%R86+X($5M>7)A=&%I`$QI8VAT96[P=&5I;F%S`%-M=6QK
M=7,@;&EE='5S`$YE9&ED96QI<R!L:65T=7,`3F5D:61E;&ES(&QI971U<R!R
M>71E`$YE9&ED96QI<R!L:65T=7,@=F%K87)E`$YE9&ED96SK(&QI^W1I<P!.
M961I9&5L:7,@;&EE='5S('-U('!E<FO[;FEJ80!.961I9&5L:7,@<VYI96=A
M<P!.961I9&5LZR#P;&%P9')I8F$`3&EM97)I:V%S`$YU<W1A='ET:2!L86EK
M;R!T87)PX"!I\&ME;&EM=6DZ`$YU;W)O9&$`3G5O<F]D82#A.@!0861A<GET
M:2!E;"X@<&'P=&\@861R97/@(&YU;W)O9&$@X2!L86GP:V\@<F'P>6UO('!U
M<VQA<.$`3G5O<F]D;W,`3&EN=7@@;&%I;>MS(/YI;G5TZW,`4F]D>71I("T@
M=F%R=&]T;VIA<R!G86QI(&UA='ET:2!K871A;&]G;R!T=7)I;N$`4F]D>71I
M(&1U;VUE;O@@8F%Z:?@@<^!R8?#@`%)O9'ET:2!P86=A;&)O<R!T96UA<P!2
M;V1Y=&D@;&5N=&5L:?@@<^!R8?#@`$MO;F9E<F5N8VEJ;W,@87)C:'EV87,`
M2V]N9F5R96YC:6IO<R!P86=A;&)A`$MO;F9E<F5N8VEJ;W,@240`2V]N9F5R
M96YC:6IO<R!S879I;FEN:V%S`%)A\'ET:2#A(&MO;F9E<F5N8VEJX`!0<FES
M:6IU;F=T:2!P<FEE(&MO;F9E<F5N8VEJ;W,`071S:6IU;F=T:2!N=6\@:V]N
M9F5R96YC:6IO<P!687)T;W1O:O@@<^!R8?!A<R!U_F1R875S=&%S+@!,:71E
M<F%T^W)A`$QI971U=F$`7U9I971A`$MR875N82XN+@!6:65T:6YI<R!L86EK
M87,Z(`!,;VMA;.L@:7(@;&%I:V%S`%9I971A`%!R:7-I:G5N9W1I`$%T<VEJ
M=6YG=&D`4')I<VEJ=6YG:6UO(&1A<F)A:0!0<FES:6IU;F=T:2!N97!A=GEK
M;RX@3F5T96ES:6YG87,@2OMS^"!N=7)O9'ET87,@=F%R=&]T;VIO('9A<F1A
M<R!I<B]A<B!S;&%P=&'^;V1I<RX`4')I<VEJ=6YG=&D@;F5P879Y:V\N`$EL
M9V%S('1E:W-T87,`365I;.L`3F5S=F%R8G4`36'^;W-I;W,@9W)A:6MI\&MO
M<R!R86EDZW,`36'^;W-I;W,@;&]T>6YI\&MO<R!R86EDZW,`36'^:65J:2!R
M;VWK;FGP:VD@<VMA:>AI86D`3&EU:W-E;6)U<F=A<P!-30!-3U1$`%!R:6MA
M8FEN=&%M92!-4RU43D5&(&9A:6QE(&[K<F$@9'5O;>MN^"X`35-'`$UA:V%O
M`$UA:V5D;VYI:F$`36%D86=A<VMA<F%S`$UA9VEJ80!08?!T87,`4&'P=&\@
M=F%L9'EM87,`4W5K=7)T:2!?;G5O<F]DX"XN+@!-86QA=FES`$UA;&%I>FEJ
M80!-86QD>79A:0!-86QI<P!-86QT80!.=71O;'5S:?@@:V%L96YD;W)I^"!T
M=F%R:WEM87,N`$MA=&5G;W)I:O@@<^!R8?!O+"!K=7)I;VUS('!R:7-K:7)I
M86UI(&]B:F5K=&%I+"!I<B!S=2!J;VUI<R!S=7-I:G5S:?@@<W!A;';X(&ME
M:71I;6%S+@!-87`R-"#^96WK;&%P:7,`36%P475E<W0@_F5MZVQA<&ES`$MO
M=F%S`%!A<F'P=.L`4&'^>6WK=&D@:V%I<"!S:V%I='ET=7,O;F5S:V%I='ET
M=7,`4&'^>6WK=&D@:VET86ES(&%T<FEB=71A:7,@*'!V>BX@<W9A<F)U+V%T
M<V%K>71A*0!-87+P86QO('-A;&]S`$UA<G1I;FEK80!3=6IU;F=T:2!L875K
M86D`36%U<FET86YI:F$`36%U<FEC:6IU<P!-86MS:6UA;'5S(&MR961I=&%S
M+@!-86MS:6UA;'5S(/YI;G7H:?@@9&%L:?@@:VEE:VES(&GP96EK=F]T87,N
M`$UA:W,N('1E;7`N('!A<VLN(#(T('9A;#H@`$UA:W,N('1E;7`N('!A<VLN
M(#8@=F%L.B``36%K<VEM86QU<R!I;&=I<P!'96=U_NL`36]J;W3K`$UE9&EC
M:6YA`%-U<VER:6YK:6UA<P!.87)I86D`365N:74@<^!R8?!A<P!-96YI=2!R
M9?YI;6%S.@!3=6IU;F=T:2!C96QE<P#>:6YU=.L`3&%I\&MA<R!P879I<G1I
M;G1A<RP@=&'H:6%U(&YE<&%T=FER=&EN=&%S('!A<VER8?!I=7-I;R!A<VUE
M;G,@<V5R=&EF:6MA=&%S+@#>:6YU=.L@;F5I\'-I^'-T82X`WFEN=73K<R!T
M:7!A<P!/<F\@<V%L>6=O<P!/<F\@<^!L>6?X(&)L;VMO(&[K<F$N`$]R;R!S
MX&QY9_@@8FQO:V\@;NMR82X@061M:6YI<W1R871O<FEU:2!I\'-I^'-T87,@
M9&5T86QU<R!A<')A\'EM87,N`$UE=&]D87,`36%T86D`365K<VEK80!-:6MR
M;VYE>FEJ;W,@1F5D97)A8VENZW,@5F%L<W1I:F]S`%9I9'5R>6IE`$U)344@
M=&EP87,`36EN+B!T96UP+B!P87-K+B`R-"!V86PZ(`!-:6XN('1E;7`N('!A
M<VLN(#8@:&]U<G,Z(`!-:6YU=.LH<RD`071S<&EN9'ES`$MI=&]S`%!R86QE
M:7-T^"#A=GEK:?@@<^!R8?!A<P!.97)A<W1A<R!014%2($A45%!?4F5Q=65S
M="!P86ME=&%S+@!.=7-T871Y;?@@;NMR82X@2F5I9W4@;F]R:71E(&YA=61O
M=&D@\.$@;6]D=6SA+"!T=7)I=&4@:N$@<W5K;VYF:6?[<G5O=&DN`$[K<F$@
M_FEN=73K<R!)1"X`3F5R87-T87,@<F5I:V%L:6YG87,@4$5!4B!-86EL('!A
M:V5T87,N`$[K<F$@<V5S:6IO<R!)1"X`4&ER;2X`36]B:6QU<R!P8?!T87,`
M5FED=71I;FES`%)E9&%G879I;6\@9&%T80!+96ES=&D@55),`$UO9'5L:7,`
M36]L9&]V;W,@4F5S<'5B;&EK80!-;VYA:V%S`%!I<FUA9&EE;FES`$UO;F=O
M;&EJ80!-ZVYU;P!-ZVYU;P!-ZVYE<VEA:2!I<B!M971A:0!+87,@;>MN97/A
M`$WK;F5S:6YI<R#A=GEK:?@@<^!R8?!A<P!+87-MZVYE<VEN:7,N($MA<G1O
M:F%S:2!K87,`3>MN97-I86D@X2!P<FEE:^$`3>MN97-I86D@<')I9?`@=&%I
M`$UO;G-E<F%T87,`3>MN=6QI;R!F87KK<P!-87)O:V%S`$1A=6=I875S:6$@
M9VEE9')A`$1A=6=I875S:6$@87!S:6YA=6OF`$1A=6=I875S:6$@<V%U;.MT
M80!097)K96QT:2#^96UI874`4&5R:V5L=&D@:V%I<FEA=0!097)K96QT:2!D
M9?!I;FEA=0!097)K96QT:2!A=6OPZ&EA=0!097)KZVQI;6%S(/YE;7EN`%!E
M<FOK;&EM87,@875K\'1Y;@!-;WIA;6)I:V%S`$ME;&5T;R!L>6=I^"!I\'-I
M<VML96ED_FEA;G1I<R!SX')A\&%S`%)A<W1I(&ME;&D@:4-A;&5N9&%R(&MO
M;7!O;F5N=&%I.R!P86QA:6MO;6%S('1I:R!V179E;G0@=&EP87,N`$ME;&5T
M87,@<&%S:7)I;FMI;?@`36%N;R!SX'-K86ET80!-86YO(&MA;&5N9&]R:6%I
M`$UA;F\@:V%L96YD;W)I86DZ`$UA;F\@<&]R=&%L87,`36%N;R!P;W)T86QO
M(&GP9.MS='EM87,`36%I;FUA<F%S`$Y%+"!.15-55$E.2U4`5F%R9&%S`$YA
M;6EB:6IA`$YA=7)A<P!.97!A;&%S`$YY9&5R;&%N9&%I`$YY9&5R;&%N9/@@
M06YT:6QA:0!.971S8W!A<&4@8F%Z:6YI<R!54DP`3F5T<V-P864@<V5R:69I
M:V%T;R!A=/!A=6MI;6\@55),`$YE='-C<&%E('-E<G1I9FEK871O('1E:7-I
M^"!54DP`3F5T<V-A<&4@871N875J:6YO;6\@55),`$YE='-C87!E(&%T\&%U
M:VEM;R!54DP`3F5T<V-A<&4@4U-,('-E<G9E<FEO('9A<F1A<P!.971S8V%P
M92!S97)T:69I:V%T;R!A<')A\'EM87,`3F5T<V-A<&4@<V5R=&EF:6MA=&\@
M=&EP87,`5&EN:VQA<P!.:65K861A`$YA=6IO:FD@2V%L961O;FEJ80!.875J
M82!K871E9V]R:6IA`$YA=6IA<R#A<F'P87,`3F%U:F%S(&WK;G5L:7,`3F%U
M:F%S('9A<G1O=&]J;R!V87)D87,@*&YE8OMT:6YA<RD`3F%U:F]J:2!:96QA
M;F1I:F$`3F%U:F%M92!L86YG92`H7V)L86YK*0!.875J:65N;W,`3F%U:FEE
M;O@@9W)U<.MS`%-E:V%N=&ES`%-E:V%NZ&EO<R`R-"!V86QA;F1O<P!396MA
M;G1I(&1I96YA`%-E:V%N=&ES(&WK;G5O`%-E:V%N=&D@<V%V86ETZP!396MA
M;G1I(&1I96YA`%-E:V%N='ES(&YU<W1A='EM86D`4V5K86YT:2!S879A:73K
M`$YI:V%R86=V80!.:6=E<FES`$YI9V5R:6IA`$YA:W1I<P!.:75JZP!$86QY
M=FGX(&[K<F$`3F5U_G1E;FMA(&1U;VUE;O@@<VMI<G1U;?@@<&%R;V1Y;75I
M+@!.96YU<F]D>71A('-T<F%T96=I:F$@25-/(')A\'EM=6DN`$[K<F$@<W5D
MZW1I;FEO(/!A8FQO;F\N`$YU<F]D>71O:F4@<&]Z:6-I:F]J92!B;&]K;R!N
MZW)A`$YEX79E9.MT92!K86QE;F1O<FEA=7,@=F%R9&\@34-!3"!A=71E;G1I
M9FEK86-I:F]J92X`2V%L96YD;W)I^"!S=F7H:6%M<R!NZW)A+@!3:VER='5M
M^"!NZW)A+@#0:6]S('1E:7/K<R!N96=A;&D@='5RZW1I('!O=&5I<VGX+@!.
MZW)A(&EN9F]R;6%C:6IO<R!A<&EE("5S(&MO;F9I9_MR86-I:N`N`$[K<F$@
M:6YF;W)M86-I:F]S(&%P:64@1E10(%9&4R!K;VYF:6?[<F%C:6K@+@!.ZW)A
M(&EN9F]R;6%C:6IO<R!A<&EE(%-13"!61E,@:V]N9FEG^W)A8VEJX"X`3NMR
M82!I;F9O<FUA8VEJ;W,@87!I92!344PM1FEL92!61E,@:V]N9FEG^W)A8VEJ
MX"X`2W)E9&ET87,@:?!E:6MV;W1A<RX`3F7A=F5S=&%S(&=A=NMJ87,N`$[K
M<F$@<&%B86EG;W,@9&%T;W,`P79Y:VGX(&[K<F$`1F%I;&%S(&YE;G5S:?AS
M=&%S`$YE<&%V>6MO(&=A=71I("5S('9A<G1O=&]J;R!U_FEM='5M;R!I;F9O
M<FUA8VEJ;W,`3F5R87-T82!J;VMI^"!I0V%L96YD87(@9'5O;65N^"X`3F5N
M=7-T871Y=&$@=FEE=&]VZRX`3F7A<F'PZW1E(/YI;G5TZW,N`$YEX7)A\.MT
M92!V87)D;RX`3F7A<F'PZW1E(&YU;65R:6\N`$YE<F]D>71I(.'^96ED_FEA
M;NAI^"!F<F%Z:?@`3F7A=F5DZW1E('-L87!T8?YO9/YI;R!(5%10(&%U=&5N
M=&EF:6MA8VEJ86DN`$YEX79E9.MT92!S;&%P=&'^;V3^:6\@24U!4"!A=71E
M;G1I9FEK86-I:F%I+@!.9>%V963K=&4@<VQA<'1A_F]D_FEO($ME<F)E<F]S
M(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT92!S;&%P=&'^;V3^:6\@3&]G
M:6X@875T96YT:69I:V%C:6IA:2X`3F7A=F5DZW1E('-L87!T8?YO9/YI;R!0
M05-35T0@875T96YT:69I:V%C:6IA:2X`3F7A=F5DZW1E('-L87!T8?YO9/YI
M;R!334(@875T96YT:69I:V%C:6IA:2X`3F7A=F5S=&%S(&ME;&EA<R!I:VD@
M3W!E;E-33"!P86=R:6YD:6YI^"!F86EL^"X@3W!E;E-33"!R96EK86QI;F=A
M(&1A<F)U:2!S=2!02T-3(#$R(&1U;VUE;FEM:7,N`$YE<&%T=FER=&EN=/@@
M<F5G:7-T<F%C:6KX(&[K<F$N`$YE;F%U9&]T:2!S:VER='5K^`!.ZR!V:65N
M;VIE('!U<^MJ90!3<&%R=&EN:6UU:2!NZW)A(&QA:6MI;F]J;R!K871A;&]G
M;RX`5F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES(&YE;G5S
M:?AS=&%S+@!496ES:6YG^"!834P@9'5O;65N^"!NZW)A`$YE<F%S=&%S('1E
M:7-I;F=A<R!E;"X@<&'P=&\@861R97-A<RX`3NMR82!R96EK\&UI^`!+;VYF
M:6?[<F%C:6YI86UE(&9A:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E;F5R=6]K
M:71E(&YU<W1A='EM=7,N`$MO;F9I9_MR86-I;FEA;64@9F%I;&4@;NMR82!V
M97)S:6IO<RX@4&5R9V5N97)U;VMI=&4@;G5S=&%T>6UU<RX`3NMR80!.ZW)A
M`-!I875RZW,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK;R!S86QO<P#0:6%U<FEN
MZR!H96UI<V9E<F$`T&EA=7)I;NMS($UA<FEJ86[X('-A;&]S`$YO<G9E9VEJ
M80!.92!P;R!T;P!.92!P<FEE\"!T86D`3F4@:V%T86QO9V%S`$YE<F%S=&$`
M3F5R96%L:7IU;W1A+@!.96YU<F]D>71A`$YE<&%L86EK;VUA<RX`5?YR8?!A
M:0!.ZW)A(&O@('!E<OYI^W+K=&DL(&5I:VET92!A=&=A;"X`3&%P:W)I=&ES
M`$1A8F%R`$YU;65R:7,`4VEM8F]L:?@@<VMA:>AI=7,`4W1U;'!E;&GX('-K
M86GH:75S`$5I;'7H:?@@<VMA:>AI=7,`3F7A=F5S=&D@9&ES=')I8G5C:6IO
M<R!SX')A\&\@871N875J:6YI;6\@<VMA:>AI86DN`$]+`$]B:F5K=&%S`$]B
M:F5K=&\@<V%V:6YI;FMA<P!!\'1U;G1A:6YI<P!3<&%L:7,`WFEA=7)U;6\@
M9FEL=')A<P!/9FES87,`3VUA;F%S`$MA=&%L;V?X(&1A;&EJ:6W@<VD@<&%L
M86EK;R!T:6L@24U!4"!S97)V97)I86DN`%1I:R#A_F5I9/YI86[H:6]S(&9R
M87KK<P!,96ED_FEA;6%S('1I:R!V:65N87,@96PN('!A\'1O(&%D<F5S87,N
M`$5L96UE;G1O('-A=FEN:6YK;R!T96ES97,@9V%L:2!K96ES=&D@=&EK(&IO
M('-A=FEN:6YK87,@87)B82!S:7-T96UO<R!A9&UI;FES=')A=&]R:75S`$%T
M:61A<GET:2!N875J86UE(&QA;F=E`$%T:61A<GET:2#P:>`@;G5O<F]DX"!N
M875J86UE(&QA;F=E`$]P<F%C:6[K<R!S:7-T96UO<P!.96+[=&EN87,`3G5S
M=&%T>6UA:0`E<R!N=7-T871Y;6%I`%-U<OOP:75O=&%S('/@<F'P87,`3W)G
M86YI>F%C:6IA`%!A9&%L:6YY<P!3:7-T96UI;FEM87,`3W)I9VEN86QU<R!A
M<&QI:V%C:6IO<R#P86)L;VYA<P!/<FEG:6YA;/AS(/!A8FQO;F%I("5S.@!+
M:71A`$MI=&$@:6YF;W)M86-I:F$`4V%V:6YI;FMA<P!3879I;FEN:6MO('1E
M:7/K<P!.ZW)A(%!!32!A=71E;G1I9FEK86-I:F]S(&UE8VAA;FEZ;6\N`%!'
M4"!S:V%I=&UE;FEN:7,@<&%R8?!A<P!01U`@=?YK;V1U;W1A(&EN9F]R;6%C
M:6IA`%!'4"!V:67P87-I<R!R86MT87,`4$=0('!A<VER8?!Y=&DO=?YK;V1U
M;W1I(&1U;VUE;GES`%!(4"!K;V1A<P!02%`@0TQ)`%!-`%!-(&QE;F=V87,@
M;&EE='5S`%!-(&QI^W1I<P!032!4+6%U9')A`%!?2%`@0TQ)`%1A<G!A:2!C
M96SK<V4`4&%K:7-T86YA<P!086QA=0!5_FEM=&]J:2!086QE<W1I;F]S('1E
M<FET;W)I:F$`4&%L;2!K86QE;F1O<FEU<R`H1&%T94)O;VLI`%!A;F%M80!0
M87!U82!.875J;VII($=V:6[K:F$`4&%R86=V86IU<P!$86QI;F%I(&1E8F5S
M=6]T80!3;&%P=&'^;V1I<P!3;&%P=&'^;V1I<R!N971E:7-I;F=A<P!2041)
M55,@875T96YT:69I:V%C:6IA:2!R96EK:6$@<VQA<'1A_F]D_FEO+@!3;&%P
M=&'^;V1I<R!S=2!P871V:7)T:6YI;74`4VQA<'1A_F]D:7,Z`%-L87!T8?YO
M9&ES.B``4VQA<'1A_F]D_FEA:2!T=7)I('-U=&%P=&DN`%!R8>MJ=7-I^"#A
M=GEK:?@@<^!R8?!A<P#!:V5L=&D`P6ME;'1I(&GP(&QA:6MI;F]S:6]S('-A
M=6=Y:VQO<R`H8VQI<&)O87)D*0!+96QI87,`4&%S:6MA<G1O:FEM86D`3F5P
M871V:7)T:6YT;W,@<F5G:7-T<F%C:6IO<SH`WFUO;NMS`%!R;V-E;G1A:0!!
M=&QI:W1I('!R;V9I;&%K=&EN:75S('9E:6MS;75S`$%R(&%T;&EK=&D@<')O
M9FEL86MT:6YI=7,@=F5I:W-M=7,@<')I<VEJ=6YG:6UO(&UE='4_`$GP=')I
M;G1I(/#A(.%R8?#@/P!496ESZW,`3F5U_G1E;FMA('1E:7-I^`!496ESZW,`
M5&5I<VGX(&%D;6EN:7-T<F%V:6UA<P!!<VUE;FENZR!I;F9O<FUA8VEJ80!0
M97)U`$=Y=OMN86D`1FEL:7!I;F%I`%1E;&5F;VYA<P!.=6]T<F%U:V]S`%!I
M=&MR86YA<P!0:6MS96QI86D`0F%N86QY8NMS`$GP<VER:6YK:71E(&MU<FG@
M(&YO<G,@8V5LY@!0871V:7)T:6YK:71E+"!A<B!T:6MR86D@;F]R:71E(&GP
M=')I;G1I(/#A(&5L96UE;G3@.@!0871V:7)T:6YK:71E+"!A<B!T:6MR86D@
M;F]R:71E(&GP=')I;G1I(/!I;R!E;&5M96YT;R!N=6]R;V3@+@#!=F5S:VET
M92!MZVYE<^$@:7(@;65T=7,N`,%V97-K:71E(&YA=6IO<R!K871E9V]R:6IO
M<R!P879A9&EN:6W@.@#!=F5S:VET92!T96ES:6YGX"!)4"!A9')E<^`N`,%V
M97-K:71E('1E:7-I;F?@(&1A=.`L('!A=&EK<FEN:VET92!D:65N^"!S:V%I
MZ&GX(&WK;F5S>6IE+@#!=F5S:VET92!T96ES:6YGX"!L86EKX"X`07!R8?!Y
M:VET92!P<F]B;&5MX"X`3G5R;V1Y:VET92!S879O('9A<G1O=&]J;R!V87)D
MX"!B96D@<VQA<'1A_F]DX0#!=F5S:VET92!N875JX"!K871E9V]R:6IO<R!P
M879A9&EN:6W@.@!,96YK:6IA`%!O;&ET:6MA:0!"86QS879I;6%I`%!O<G1A
M;&\@;G5S=&%T>6UA:0!0;W)T=6=A;&EJ80!0879E:6MS;.ML:6\@<&]Z:6-I
M:F$`3&5N=&5LZW,@<&]Z:6-I:F$`2?!S875G;W1I(/!I86UE(&MA=&%L;V=E
M("AN96=A;&EO:F$@24U!4"D`2W)I='5L:6%I('!A<VLN("5S('9A;&%N9.`H
M87,I.B``4')E9G-?;&1A<#H@;F5R87-T87,@<F5I:V%L:6YG87,@3$1!4"!M
M;V1U;&ES+@!0<F5F<U]S97-S:6]N.B!N97)A<W1A<R!R96EK86QI;F=A<R!S
M97-I:O@@;6]D=6QI<RX`4VSK9VES`%-LZV=I<R!J^W)O<R!L>6=Y:F4Z(`!3
M;.MG:7,Z(`!097+^:?MR80!097+^:?MRZW1I('!A=F5I:W-LZVSA(&YA=6IA
M;64@;&%N9V4`06YK<W1E<V[K(&1I96YA`$%N:W-T97-N:7,@<'5S;&%P:7,`
M5F%K87(@9&EE;F$`06YK<W1E<VYI(&YU<W1A='EM86D`071S<&%U<V1I;G1I
M(&1O:W5M96YTX`!3;&%P=&%S:7,@<F%K=&%S`%!R;V)L96UA`%!R;V)L96UO
M<R!A<')A\'EM87,`4')O:F5K=&%I`%!R8?!Y;6%S('1E:W-T=6D`5FEE\&%S
M:7,@<F%K=&%S`%9I9?!O:F\@<F%K=&\@86QG;W)I=&UA<P!6:67P;VIO+W-L
M87!T;VIO(')A:W3X('!O<F$@;F5S=6=E;F5R=6]T82X`4'5E<G1O(%)I:V%S
M`$MA=&%R87,`4V%K:6YY<P!24T$@=FEE\&%S:7,@<F%K=&%S("@E9"!B:71A
M:2D`)U)A9&EO)R!P87-I<FEN:VEM87,`3&EE='5S`$QI971U<R!R>71E`$QI
M971U<R!V86MA<F4`3&G[=&ES`$%T<VET:6MT:6[K(&9R87KK`%-A;G1Y:VES
M`%-K86ET>71I`%!E<G-K86ET>71I(&QA:?!K86D`5&EK<F%I(&GP=')I;G1I
M("5S/R!'<F'^:6YT:2!A=&=A;"!N96)E9V%LZW-I=&4N`%1I:W)A:2!I\'1R
M:6YT:2!V87)T;W1O:F\@)7,@9'5O;65N:7,_($=R8?YI;G1I(&%T9V%L(&YE
M8F5G86SK<VET92X`4&%S:6MA<G1O:F$@:6MI`%!A<VEK87)T;VII;6%S`%!A
M<VEK87)T;VII;6\@9&%T80!087-I:V%R=&]J:6UO('!A8F%I9V]S(&1A=&$`
M4&%S:6MA<G1O:FEM;R!D8?YN=6UA<P!087-I:V%R=&]J:6UO(&+[9&%S`%!A
M:V%R=&]T:2!K87,@9&EE;N``4&%K87)T;W1I(&MA<R!MZVYE<^$`4&%K87)T
M;W1I(&MA<R!S879A:73F`%!A:V%R=&]T:2!K87,@;65T=7,`4&%K87)T;W1I
M(&%N:W-T97-NX2!V96EK<VW@`$%T;F%U:FEN=&D@:V%I<FEO:F\@;65N:74@
M96QE;65N='5S.@!!=&YA=6II;G1I('!O<G1A;&\@=F%I>F3@.@!296=E>`!3
MX')Y\&GX(&YA<O!Y:VSK`%!A<W1A8F]S`%!R:6UI;FEM87,Z("5S`$YU=&]L
MYB!K86QE;F1O<FEA:0!.=71O;.8@:V%L96YD;W)I86DZ`$YU=&]LYB!S97)V
M97)I86D`3G5T;VSF<R!54DP@*&AT='`Z+R]W=W<N<&%V>7ID>7,N8V]M+VAO
M<F1E*3H`2?!T<FEN=&D`2?!T<FEN=&D@)7,`4&'P86QI;G1I(&1A;'EV:75S
M`%!A\&%L:6YT:2!B;&]KX`!086YA:6MI;G1I('-T=6QP96SA`%!A;F%I:VEN
M=&D@9F]R;6%T879I;>``2?!T<FEN=&D@<&]RX`!)\'1R:6YT:2!A=&YA=6II
M;FEM;R!S:W)I<'3@(&GP('-E<G9E<FEO(&QA:6MI;F]J;R!K871A;&]G;RX`
M4&'P86QI;G1I`%!A\&%L:6YT:2#PX2!E;&5M96YTX"!I\"!D;VMU;65N=&\`
M2?!T<FEN=&D@=F%R=&]T;VK@`%9A<G1O=&]J;R!T<GEN:6UA<SH@)7,`3F5G
M86QI=2!A='-A:WET:2#A('7^:VQA=7/@+B!+;&%I9&]S(&MO9&%S.B``4')I
M=F%L;VUA<P!"^W1I;FD@9&%L>79I86D`2?`@;F%U:F\`4&%K96ES=&D@<VQA
M<'1A_F]DX0!3;&%P=&'^;V3^:6\@:V5I=&EM87,`071S=&%T>71I`$%T<V%K
M>6UA<P!297IU;'1A=&%I`$=RX?YT:2#A(&YU<W1A='EM=7,`4F5J^VYI:F$`
M071S=&%T>71I(&MO;F9I9_MR86-I:N``2%1-3"!R961A:W1O<FEA=7,@;G5S
M=&%T>6UA:0!-X7-LZW,`1&7P:6[K:F4`1&7P:6YI;VII(&%N=')A\'3K`$1E
M\&EN:6]S:6]S(')E:6OP;>MS`%]%:6QU=.MS(&YU<W1A='EM86DN+BX`4F]L
MZP!2=6UU;FEJ80!087-U:W1I(#$X,`!087-U:W1I(&MA:7+K;@!087-U:W1I
M(&1E\&ENZVX`16EL=73K<R!N=7-T871Y;6%I`$5I;'5TZW,@;G5S=&%T>6UA
M:0!%:6QU=.MS.@!3:VER='5K86D`4VMI<G1U:V%I('1A<G`@=FES^"!E:6QU
MZ&GX(&ER('-T=6QP96QI^`!3:VER='5K86D@=&EK('1A<G`@<W1U;'!E;&GX
M`%-K:7)T=6MA:2!T:6L@=&%R<"!E:6QUZ&GX`%9Y:V1Y=&D`4G5S:6IO<R!&
M961E<F%C:6IA`%)U86YD80!3+TU)344@<&%R8?!A<P!3+TU)344@=?YK;V1U
M;W1A<R!L86GP:V%S`$[K<F$@4T%33"!A=71E;G1I9FEK86-I:F]S(&UE8VAA
M;FEZ;6\N`%--4R#^:6YU=.MS`%-13"!#3$D`4U-(`%!!5EE+3P!37U%,($-,
M20#09?!T+@#0=F5N=&]J:2!(96QE;F$`4V%I;G0@2VET<V%S(&ER($YE=FES
M87,`4V%I;G0@3&EU8VEJ80#0=F5N=&%S:7,@4&5T<F%S(&ER($UI9V5L;VYA
M<P!386EN="!6:6YC96YT87,@:7(@1W)E;F%D:6YA:0!486UE('!AZ&EA;64@
M;&%N9V4@*%]S96QF*0!386UO80!386X@36%R:6YA<P!386\@5&]M92!I<B!0
M<FEN8VEPZP!086QY9&]V87,`T&7P=&%D:65N:7,`4V%U9&\@07)A8FEJ80!)
M\'-A=6=O=&D@)7,`2?!S875G;W1I(&MA:7`@;F%U:N``2?!S875G;W1I(.%V
M>6OA`$GP<V%U9V]T:2!N=7-T871Y;75S`$GP<V%U9V]T:2!S=6=E;F5R=6]T
M=7,@;G5S=&%T>6UU<R!K86EP(%!(4"!S:W)I<'3@(&K[<_@@<V5R=F5R:6\@
M;&%I:VEN86IA;64@:V%T86QO9V4N`"5S(&YU<W1A='EM86D@:?!S875G;W1I
M+@!-;VMS;&%S`$EE\&MO=&D`4&%I9?!K80!087-I<FEN:VET92!F86EL=7,`
M4&%S:7)I;FMI=&4@9&%TX`!087-I<FEN:VET92!G<G5PY@!087-I<FEN:VET
M92!N875JX"!S879I;FEN:^``4&%S:7)I;FMI=&4@<V5R=F5RX0!087-I<FEN
M:VET92!V87)T;W1O:N``4&%S:7)I;FMI=&4@=FES=7,@9&%T;W,@:V]M<&]N
M96YT=7,N`%!A<VER:6YK:71E(&]B:F5K=.``4&%T=FER=&EN:6UO(&YU<W1A
M='EM^"P@=F%I>F1A=FEM;R!B^V3X(&ER('-T86YD87)T:6YI;R!V86EZ9&%V
M:6UO('!A<VER:6YK:6UA<RX`4&%S:7)I;FMI=&4@:V%L96YD;W)I^"#A:^ML
M:6UU:3H`2?`@_F5M:6%U(&5S86[H:?@@<^!R8?#X('!A<VER:6YK:71E(')E
M:6MI86UU<R!S:6UB;VQI=7,N(%;K;&EA=2!G86QI=&4@:G5O<R!N=6MO<&EJ
M=6]T:2#A(&QA:?!KX"X`4&%S:7)I;FMI=&4@9&%T;W,@<VMI<G1U:^`Z`%!A
M<VER:6YK:71E(&1A=&]S(&9O<FUA=.`Z`%!A<VER:6YK:71E(&GP:^ML:6UO
M(&9O<FUA=.`Z`%!A<VER:6YK:71E(&9A:6S@(.%KZVQI;75I.@!087-I<FEN
M:VET92!P:7)MX"#P:6]K:6%D:65NX3H`4&%S:7)I;FMI=&4@X6ME;&EA;6\@
M9F%I;&\@9F]R;6%TX#H`4&%S:7)I;FMI=&4@87!R8?#@(&MU<N$@;F]R:71E
M(')E9&%G=6]T:3H`4&%S:7)I;FMI=&4@;&%I:V\@<VMI<G1U:^`Z`%!A<VER
M:6YK:71E(&QA:6MO(&9O<FUA=.`Z`%!A<VER:6YK:71E(&QA:6MO('1A<G#@
M(')O9'EM=6DZ`%!A<VER:6YK:71E('9A:7ID879I;6\@8OMDX"!P;R!P<FES
M:6IU;F=I;6\Z`%!A<VER:6YK:71E(&1U(&%T:71I;FMA;NAI=7,@;&%U:W5S
M+@#!=GEK:?@@<F]D>6UO('!O<G1A;&4@<&%S:7)I;FMI;6%S+@!087-I<FEN
M:VET92!S<&%L=O@@9&5R:6[A+@!087-I<FEN:VET92!N;W)I;>`@:V%L8N`Z
M`%-I^'-T:2!P<F]B;&5M;W,@<')A;F7P:6W@`%-I^'-T:2!335,`5')I;F%N
M="P@=FES:65M<R!D86QY=FEA;7,@:?!S:?AS=&D@<')A;F7P:6W@(&%P:64@
MX79Y:VEO(&YU=')A=6MI;>``2?!S:?AS=&D@;&%I\&O@("5S`$GP<V%U9V%N
M="P@=FES:65M<R!D86QY=FEA;7,@:?!S:?AS=&D@<')A;F7P:6UA(&%P:64@
MX79Y:VEO(&%T;F%U:FEN:6W@+W-U:_MR:6W@+@!396YE9V%L87,`4V5N<V]R
M:75S.B``4G5G<^MJ:7,`4V5R8FEJ82!I<B!-;VYT96YE9W)A<P!397)I:F]S
M(&YU;65R:7,`4V5S:6IO<R!)1"!P87-I8F%I9^LN`%)I;FMI;GES`$YU<F]D
M>6MI=&4@<&%B86EG;W,@9&%TX`!.=7-T871Y;6%I(&QE:63^:6%N='ES($IU
M;7,@<&%S:6ME:7-T:2!S;&%P=&'^;V3A+"!J96EG=2!JX2!K861A(&YO<G,@
M<&%M:7+P:71E+@!.=7)O9'EK:71E('!A<VEK87)T;VII;6\@<&%B86EG;W,@
M9&%TX`!.=7)O9'EK:71E('!R863^:6]S(&1A=.``3G5T;VQU<VGX('-E<G9E
M<FGX+"!K=7)I=6]S(&YO<FET92!M871Y=&D@:?`@<&]R=&%L;RP@;G5S=&%T
M>6UA:2X`2V%L8F]S+"!L86EK;R!Z;VYO<R!I<B!D871O<R!N=7-T871Y;6%I
M+@!0=7-L87!I;R!S<&%L=O@L(&%T<VEN875J:6YI;6\@9&'^;G5M;R!I<B!K
M:73X('9A:7ID879I;6\@<&%R86UE='+X(&YU<W1A='EM86DN`%)A<W1A<R!A
M=&YA=6II;FEM;R!S:W)I<'1A<P!3=2#P:75O('!A<F%M971R=2!G86QI;6]S
M(&ME;&EO<R!V:65T;W;K<SH@`%-E:?!E;&%I`$)E;F1R:2!K86QE;F1O<FEA
M:0!"96YD<FD@:V%L96YD;W)I86DZ`%!A<F1U;W1U=NL`5')U;7!A<R!A<')A
M\'EM87,`07(@;F%U9&]T:2!K;&%V:6%T^W)O<R!M>6=T=6MU<R!V86QD>6UU
M:3\`4F]D>71I`%)O9'ET:2!K871E9V]R:6KX('-P86QV^"!R96EK\&UE<S\`
M4F]D>71I('1R>6YI;6\L('!E<G-PZVII;6\@:7(@<&%S:6MA<G1O:FEM;R!P
M:6MT;V=R86UA<R!K86QE;F1O<FEU:F4_`%!A<F]D>71I('-K:7)T=6UU<R!T
M87)P(&GP<V%U9V]T;R!I<B!KX"!T:6L@<W5G96YE<G5O=&\@:V]N9FEG^W)A
M8VEN:6\@9F%I;&\N`%)O9'ET:2!E:6YA;75S(&1A<F)U<R!K86QE;F1O<FEU
M:F4_`%)O9'ET:2!U_FEM='5M;R!I;F9O<FUA8VEJ;W,@<W!A;';X(')E:6OP
M;65S/P!2;V1Y=&D@<&%S:W5T:6YI;R!P<FES:6IU;F=I;6\@;&%I:^`_`$%R
M(')O9'ET:2!T:6L@='5O<R!V96EK<VUU<R!K=7)I92!T=7)I('!E<G-PZVII
M;6\@_GEMYC\`4F]D>71I(&=A;&EM>6+F('!A;&EK=&D@;W)I9VEN86S@`%)O
M9'ET:2!P87)I<VEN:VEMX`!2;V1Y=&D@;&5N=&5LZW,@;W!E<F%C:6KX(&UE
M;FEU/P!2;V1Y=&D@)7,@;65N:74@:V%I<NMJ93\`4F]D>71I(&-E;.MS(&YU
M<W1A='EM^"!L86YGX`!2;V1Y=&D@;&5N=&5LZW,@;G5S=&%T>6WX(&QA;F?@
M`%)O9'ET:2!E:6QU=.MS(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@<&%V96EK
M<VSK;&EO(&YU<W1A='EM^"!L86YGX`!3879A:73K<R!R9?YI;64@<F]D>71I
M('1A<G#@('1A<G`@9&EE;O@_`%)O9'ET:2!F86EL^"#A:^ML:6W@`$QI^W1I
M<P!,:?MT:7,@<GET90!,:?MT:7,@=F%K87)E`%-U;6'^:6YT:0!3=6UA_FEN
M=&D@87)B82!P87-T=6UT:2!K86EM>6YI;FEU<R!B;&]K=7,`4VEE<F$@3&5O
M;NL`4F5G:7-T<F%C:6IA`%!A<F'P87,`4&%R8?!O(&%L9V]R:71M87,`4VEN
M9V%P^W)A<P!$>61I<P!0<F%L96ES=&D@<')O9FEL86MT:6O@`%-L;W9A:VEJ
M80!3;&]VZVYI:F$`4/MG80!3;FEE9V\@9WEL:7,Z(`!3;FEE9V\@:VEE:VES
M('9A;F1E;FEU.B``4V]L;VUO;F\@<V%L;W,`4V]M86QI80!$86EN;W,@:7(@
M16ELZW)A\.AI86D`4OOP:6%V:6UO('1V87)K;W,@<&%S:7)I;FMI;6%S`%-I
M=6YTZVIO(&%D<F5S87,`4&EE=/@@069R:6MA`%!I973X($5U<F]P;W,@*$E3
M3RTX.#4Y+3,I`%!I973X($3^;W)D_FEJ;W,@:7(@4&EE=/@@4V%N9'9IZ&\@
M<V%L;W,`4&EE=&ENZR!H96UI<V9E<F$`5&%R<&%S('1A<G`@8V5L:?@`5&%R
M<&%S('1A<G`@8V5LZW,@='5R:6YI;R!I<B!K<F'P=&ENZW,`5&%R<&%S`%1A
M<G!A:2!T87)P(&-E;&GX`%1A<G!A:0!)<W!A;FEJ80!3<&%M87,`4W!E8VEF
M:6YI^"!S:6UB;VQI^"#A=&5R<&EM87,`4&5R<VME;'1I(&-E;.8`4&5R<VME
M;'1I('-T=6QP96SA`%!E<G-K96QT:2!E:6QU=.8`4W!O<G1A<P#0<FD@3&%N
M:V$`4W1A;F1A<G1A<P!3=&%R(%1R96LG87,`4')A9/YI;W,@9&%T80!0<F%S
M:61E9&$`4')A9/YI;W,@;&%I:V%S`%!R861I;FEA:2!M971A:0!?0OMS96YA
M`%)A:F]N87,@87)B82!P<F]V:6YC:6IA`$+[<V5N80!3875G;VII;6\@9F]R
M;6%T87,`1V%T=NMS(&%D<F5S87,`5?YB<F%U:W1I`-YO9/YI^"!SX')A\&%S
M`$YU:6UT:2!D;VUE;N`@;G5O(&%D<F5S;P!3=&EL:75S(%M#4U-=`%-E:VTN
M`%1E;6$`P79E<W1I`$EN9&5K<V%S`%/K:VUI;F=A`$MO;F9I9_MR86-I:F$@
M871S=&%T>71A('/K:VUI;F=A:2X@4&5R:W)A=6MI=&4@<'5S;&%PX2P@:V%D
M('!A;6%T>71U;>MT92!P86ME:71U;75S+@!!='-A<F=I;NL@:V]N9FEG^W)A
M8VEJ;W,@:V]P:6IA('/K:VUI;F=A:2!I\'-A=6=O=&$N`"<E<R<@<^MK;6EN
M9V%I('7^<F'P>71A<RX`4W5D86YA<P!4=7)I;GES`%-A=6SK=&5K:7,`4V%U
M;.ML>6=I<P!396MM861I96YI<P!3875LZW1A`%-A=6SK=&5K:7,`4V%U;.MT
M96MI<R]3875LZVQY9&ES`%-A=6SK=&5K:7,Z(`!3875LZVQY9VES`%-A=6SK
M;'EG:7,Z(`!,86EP<VYI<P!!<'1A<FYA=FEM87,`4W5R:6YA;6%S`%!A=F%R
M9.L`4W9A;&)A<F1A<R!I<B!$_F%N;6%I;F%S`%-V87II;&%N9&%S`-!V961I
M:F$`T'9E:6-A<FEJ80!3:6YT86MSZW,@:VQA:61A('!A:67P:V]S(&MR:71E
M<FEJ=6IE`%-I<FEJ;W,@07)A8O@@4F5S<'5B;&EK80!4+6%U9')A`%0M875D
M<F]S`%135B!F86EL87,`3&5N=&5LZP!,96YT96SK<R!N=7-T871Y;6%I`$QE
M;G1E;.MS(&YU<W1A='EM86D`5&%I=F%N87,`5&%I=F%N87,L($MI;FEJ;W,@
M<')O=FEN8VEJ80!4863^:6MI<W1A;F%S`$IU;F=T:6[K(%1A;GIA;FEJ;W,@
M4F5S<'5B;&EK80!486EK:6YY<SH`1&%R8F%I`%1E;&5F;VYO(&YU;65R:7,`
M5&5M<"X@<&%S:RX@=F%L86YDX#H@`%1E;7!E<F%T^W)A`%1E;7!E<F%T^W)A
M.B``T&%B;&]N^"!A9&UI;FES=')A=FEM87,`0F%N9&]M87-I<P!496MS=&%S
M`%1I:R!T96MS=&%S`$QY9VEU;W1I('1E:W-TX`!496MS=&\@=FER\'5J90!+
M971V+@!486EL86YD:65T:?!K82`H5$E3+38R,"D`5&%I;&%N9&%S`$'H:?L@
M:V%D(&YA=61O:F%TZW,@<VES=&5M82X`1&%L>79I^"!R961A9V%V:6UO(&QA
M;F=A<R!U_F1A<GET87,N($GP96EN=2X`3NMR82!&5%`@;6]D=6QI;RX`2&]R
M9&4O2V]L86(@:6YT96=R86-I:F]S('9A<FEK;&EU:V%S(&YE<&%L86EK;R`B
M)7,B`$YE<&%V>6MO('7^:W)A=71I($UA:6YT96YA;F-E.CH@:VQA<^MS`$YU
M<W1A='EM^"!L86YG87,@=?YD87)Y=&%S+B!)\&5I;G4N`$IE:6=U(&YO<FET
M92!N875D;W1I(&YU<W1A='EM=7,L('!A<')A\'EK:71E(&MA9"!A9&UI;FES
M=')A=&]R:75S('-U:V]N9FEG^W)U;W3X('!A<W1O=FG@(&1U;VUE;O@@8F%Z
MYB!N=7-T871Y;6%M<R!S875G;W1I+@!4:6L@87!A=&ENZVIE('!U<^MJ90!+
M86QE;F1O<FEA=7,@(B5S(B!N96GP=')I;G1A<RX`2V%L96YD;W)I=7,@(B5S
M(B!I\'1R:6YT87,N`$MA;&5N9&]R:75S("(E<R(@<&5R=F%D:6YT87,@X2`B
M)7,B+@!+86QE;F1O<FEU<R`B)7,B(&GP<V%U9V]T87,N`$YEX7)A\.MT92!C
M;VYT86MT;R!)1"!N=6UE<FEO(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@
M8F%ZZVIE+@!+;VYT86MT87,@<^MK;6EN9V%I(.%T<F%U:W1A<R#A($K[<_@@
M861R97/X(&MN>6=E;.8N`$YO<NMD86UI('!A=&EK<FEN=&D@;&%I\&O@('!R
M:79A;&]T92!T=7+K=&D@871S:VERX"!01U`@<&%R8?!O(&)L;VO@+@!.9>%R
M8?#K=&4@9&ES=')I8G5C:6IO<R!SX')A\&\@240@87)B82!J:7,@;F5R87-T
M87,@9'5O;65N^"!B87KK:F4N`$YEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@
M<F'P;RX`4$=0('7^:V]D879I;6\@9V%L:6UY8NL@<F5I:V%L875J82!S875G
M875S('!R:7-I:G5N9VEM;RX@0F%N9'EK:71E(')A\'ET:2!H='1P<SHO+R!A
M9')E<V\@<')A9/YI;VIE+@!086)A:6=O<R!D871A('1U<FD@8OMT:2!VZVQE
M<V[K(&YE9W4@<')A9/YI;W,@9&%T82X`4')A;F7P:6UA<R!A<&EE(.%V>6OA
M('/K:VUI;F=A:2!I\'-I^'-T87,@)7,N`$9A:6QA<R`E<R!P<FEV86QO('1U
M<NMT:2`E<R!P87)A;65T<N`N`$9A:6QA<R`E<R!P<FEV86QO('1U<NMT:2!K
M86D@:W5R:75O<R`E<R!P87)A;65T<G5S+@!&86EL87,@;F5G86QI(&+[=&D@
M;G5K;W!I:G5O=&%S(&%N="!S87;F<RX`1F%I;&4@;NMR82!D=6]M96[X+@!2
M1D,X.#(@;&%I\&MO(&%N=')A\'3K<RX`1&5T86QE<VYI<R#A=GEK:6\@87!R
M8?!Y;6%S.@!*96EG=2!D:7)B871E($EN=&5R;F5T($5X<&QO<F5R(&YA<O!Y
M:VQE+"!P:6QN865K<F%N:7,@<F5D86MT;W)I875S(')E_FEM87,@9V%L:2!S
M=6ME;'1I('!R;V)L96WX+"!DZVP@\&EO<R!N87+P>6MLZW,@:VQA:63X+B!'
M86QI=&4@;F5M871Y=&D@:V%I(&MU<FGX(')E9&%K=&]R:6%U<R!E;&5M96YT
M^"X@2F5I9W4@;F%U9&]J871E(%=I;F1O=W,@.7@@3U,@9W)E:>AI875S:6%I
M(&K[<_@@:V]M<&EU=&5R:7,@<&%P<F'PZ&EA=7-I86D@;G5L=?`@<&%S:V5L
M8F1A;6%S(&%P:64@<&%G<FEN9&ENYB!K;&%I9.`N7&Y<;DK[<R!B=79O=&4@
M<&5R<W#K=&%S+B!*96EG=2!V:7-T:65K(&YO<FET92!I\&)A;F1Y=&D@<&EL
M;F%E:W)A;N$@<F7^:6W@('-P875S:VET92!/2RX`07!R8?!A<R`B)7,B(&GP
M=')I;G1A<RX`5&EK(&MA:7+K:F4@<'5SZVIE`$-R>7!T7W!Q<#HZ(&ML87-E
M:2!R96EK:6$@;G5R;V1Y=&D@:W5R('ER82!';G501R!F86EL86DN`$QA:?!K
M87,@:?!S:?AS=&%S("5S(&%D<F5S871U:2`E<R!T96UA("(E<R(@8G5V;R!P
M87)O9'ET87,N"E1AZ&EA=2!T86D@;F5G87)A;G1U;VIA(&MA9"!L86GP:V%S
M(&)U=F\@<&5R<VMA:71Y=&%S(&%R8F$@<W5P<F%S=&%S+@!0879A9&EN:6UA
M<R!K=7+A(&YA=61O<VET92!N=6]R;V1O:F4@X2!L86GP:V\@<F'P>6UO('!U
M<VQA<.$`2&]R9&5?0W)Y<'1?<VUI;64Z.B!K;&%S96D@<F5I:V%L:6YG87,@
M3W!E;E-33"!M;V1U;&ES+@!.96=A;&EU(&GP<V%U9V]T:2!N=7-T871Y;6\@
M(B5S(BP@;F5S(&1U;VUE;O@@9'ED:7,@=FER\'EJ82!L96ES=&ENX"!R:6+@
M`%!R;V=R86UA+"!S:VER=&$@<&5R_FG[<NMT:2#PX2!D=6]M96[X('1I<.`@
M*"5S*2P@;F5R87-T82!S:7-T96UO:F4N`%1I:R!K86ERZVIE(&ER(&1E\&EN
MZVIE('!U<^MS90!4:6L@9&7P:6[K:F4@<'5SZVIE`%-E<G9E<FES("(E<R(@
M:?!T<FEN=&%S+@!397)V97)I<R`B)7,B(&GP<V%U9V]T87,N`"5S(')E9VES
M=')A8VEJ;W,@<')A\'EM87,@:?!T<FEN=&%S+@!.=7)O9'ET82!E:6QU=.L@
M;F5E9WII<W1U;VIA+@!4:6L@=FER\'5T:6[K:F4@:7(@87!A=&ENZVIE('!U
M<^MS90!4:6L@87!A=&ENZVIE('!U<^MJ90!.=7-I^'-T:2!D=6]M96YY<R!P
M<F%R87-T:2X`3F5G86QI=2!I\'-A=6=O=&D@;G5S:?AS=&\@9F%I;&\N`%=E
M871H97(N8V]M(&)L;VMO(&[K<F$N`,%V>6MI^"!A=&ET:6YK86[H:?@@<&%I
M9?!K;W,@:W)I=&5R:6IU<R!NZW)A+@!.=7-T871Y;?@@;NMR82X`1&%L:?@L
M(&MU<FEA<R!G86QI;6$@<F]D>71I(&QA:?!K;R!T96MS=&4L(&[K<F$N`-!I
M86UE(&QA=6ME(.%V97-T82!P97(@9&%U9R!S:6UB;VQI^"X@2OMS(.%V963K
M=&4@)7,L(&\@;6%K<VEM86QU<R!S:V%IZ&EU<R`M("5S('-I;6)O;&EA:2X`
M4')O8FQE;6]S('-U(&9A:6SX('-I=6YT:6UU.B`E<R!N96YU<VGX<W1A<RX`
M3G5S:?AS=&D@9F%I;&\@;F5P879Y:V\N($9A:6QA<R`E<R!Y<F$@9&ED97-N
M:7,@;F5G=2!L96ED_FEA;6%S(&1Y9&ES("@E9"!B86ET86DI+@!.=7-I^'-T
M:2!F86EL;R!N97!A=GEK;RX@1F%I;&%S("5S('1I:R!D86QI;F%I(&YU<VGX
M<W1A<RX`2VQA:61A(&%T:61A<F%N="!K86QE;F1O<FGX.B`E<P!+;&%I9&$@
M<')I9&5D86YT(.%V>6OA.B`E<P!.96=A;&EU('!A<F]D>71I(/!I;W,@;&%I
M\&MO(&1A;&EE<P!+;&%I9&$@<F5D86=U;VIA;G0@X79Y:^$Z("5S`$ML86ED
M82#A:V5L:6%N="!K;VYT86MT:6YI=7,@9'5O;65N:7,N`$ML86ED82#A:V5L
M:6%N="!I0V%L96YD87(@9'5O;65N:7,N`$ML86ED82!K;VYF:6?[<F%C:6IO
M<R!F;W)M;VIE+B!'<F5IZ&EA=7-I86D@;F5U_G!I;&3K=&4@<F5I:VEA;?@@
M;&%U:_@N`$ML86ED82!P97)K96QI86YT(.%V>6OA.B`E<P!+;&%I9&$@871L
M:65K86YT(&YU<F]D>73@(&%D<F5S^"!K;GEG96SK<R!F=6YK8VEJX"X@4&%B
M86YD>6MI=&4@=NML:6%U+@!+;&%I9&$@<VEU;NAI86YT('!R86YE\&EMX"!A
M<&EE(.%V>6OA("5S.B`E<P!+;&%I9&$@871N875J:6YA;G0@:V]N=&%K=&EN
M:75S(&1U;VUE;FES+B!086)A;F1Y:VET92!VZVQI874N`$ML86ED82!A=&YA
M=6II;F%N="!D:7-T<FEB=6-I:F]S('/@<F'PX"X@4&%B86YD>6MI=&4@=NML
M:6%U+@#!=GEK:?@@:?!KZVQI;75I(&[K<F$N`-!I<R!)34%0('-E<G9E<FES
M(&YE<&%L86EK;R!K871A;&]G^"!D86QI:FEM;W-I+@!!=')O9&\L(&MA9"!T
M86D@;F5T=F%R:VEN9V%S(%)!4B!A<F-H>79A<RX`071R;V1O+"!K860@=&%I
M(&YE='9A<FMI;F=A<R!:25`@87)C:'EV87,N`$%T<F]D;RP@:V%D('1A:2!N
M971E:7-I;F=A<R!K;W)T96SK<R!N=6UE<FES+@#0:2!T=F%R:WEK;.L@;&5I
M9/YI82!S:?AS=&D@_FEN=71E<R!P97(@0VQI8VMA=&5L;"`H:'1T<#HO+V-L
M:6-K871E;&PN8V]M*2!P87-I;F%U9&]J86YT($A45%`@<')O=&]K;VQU`-!I
M('1V87)K>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S('!E<B!S;7,R96UA
M:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!P87-I;F%U9&]J86YT($A45%`@
M<')O=&]K;VQU`-!I('1V87)K>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S
M(%--5%`@<')O=&]K;VQU('!E<B!6;V1A9F]N92!)=&%L:6IO<R!V87)T=7,L
M('1I:R!6;V1A9F]N92!N=6UE<FEA;7,N($II(')E:6MA;&%U:F$@96PN('!A
M\'1O(&%D<F5S;R!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+@#0:7,@;&%U:V%S('!R:79A;&]M87,N`-!I86UE(&QA=6ME(&=A;&D@8OMT
M:2!T:6L@<W9E:6MI96II('-K86GH:6%I+@#0:6%M92!L875K92!G86QI(&+[
M=&D@=&EK('-K86GH:6%I(&ER(&1V:71A\&MI86DN`-!I86UE(&QA=6ME(&=A
M;&D@8OMT:2!T:6L@8?!T=6YT86EN:6%I('-K86GH:6%I+@#0:6%M92!L875K
M92!T=7)I(&+[=&D@:V%B;&5L:6%I<R!A<F)A('1A<G!A:7,@871S:VER=&D@
M<W9E:6MI96II('-K86GH:6%I`-!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH
M:75S+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-P86QV;W,@:V]D87,@
M4D="($AE>"!F;W)M871E+"!P879Y>F3^:75I("<C,3(S-$%&)RX`1F%I;&\@
M9F]R;6%T87,@;F5P86QA:6MO;6%S+@#0:2!F;W)M82!J874@87!D;W)O=&$N
M`%1A:2`E<RX`5&%I($MO;&%B($=R;W5P=V%R92!O8FIE:W1A<RX@3F]RZV1A
M;6D@<&5R_FG[<NMT:2!O8FIE:W3@('!R:79A;&]T92!T=7+K=&D@96PN('!A
M\'1O(&ML:65N=.`L(&MU<FES('-U<')A;G3@(/#A(&9O<FUA=.`N(%1O:VGX
M(&5L+B!P8?!T;R!K;&EE;G3X('/@<F'PX"!G86QI=&4@<F%S=&D@87!S:6QA
M;FOF("5S`%-E<G9E<FEO('!R86YE\&EM87,@=&]K<SH@)7,`T&ES(&QA:?!K
M87,@8G5V;R!P87)A\'ET87,@)7,@:V]D=6]T92X@2OMS(&YA=61O:F%T92!K
M:71O:VG@(&MO9'5O=.8N`-!I<R!S:V%IZ&EU<R!T=7)I(&+[=&D@9&ED97-N
M:7,@=?X@;G5LX2X`T&ES('-E<G9E<FES(&YE9V%L:2!I\&%R8VAY=G5O=&D@
M>FEP(&ER(&=Z:7`@9F%I;/@N`-!I('-I<W1E;6$@9&%B87(@:?!J=6YG=&$N
M`-!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S+@#0X2!L86YGX"!R96EK
M:6$@871I9&%R:6[K=&D@:?`@;G5S=&%T>6WX(&QA;F=O`%!E<FO[;FEJ80!+
M971V:7)T861I96YI<P!":6QI971A:0!,86EK87,`3&%I:U]O('1A<G!A<P!,
M86EK;R!A<'-K86ET80!,86EK;R!F;W)M871A<P!,86EK;R!P87-I<FEN:VEM
M87,`3&%I:V\@=&%R<&%S`%1I;6]R;&5S=.L`4&%V861I;FE?;6%S`%!A=F%D
M:6YI;6%S`%!A=F%D:6YI;6%S.@!+86T`3F]RZV1A;6D@<&%S:7)I;FMT:2!K
M96QE=.`@96QE;65N=/@L(&QA:6MY:VET92!#;VYT<F]L("A00RD@87)B82!#
M;VUM;F%D("A-86,I(&ML879I\.`L(&ER('!A<VER:6YK:71E('!E;&4N`-!I
M86YD:65N`%)O9'ET:2!(5$U,(&MO9.``5&]G87,`5&]K96QA=0!2>71O:@!4
M;VYG80!6:7+P=6IE`%9I<O!U=&EN:6%M92!L86YG92`H7W1O<"D`5F5R=&EM
M86D`5')I;FED861A<R!I<B!4;V)A9V%S`%1A:7`@87)B82!N90!!;G1R+@!!
M;G1R861I96YI<P!4=6YI<V%S`%1U<FMI:F$`5'5R:VGP:V$@*$E33RTX.#4Y
M+3DI`%1U<FMMZVYI:F$`5'5R:W-O(&ER($MA:6MO<V\@<V%L;W,`5'5V86QU
M`%1I<&%S`,%V97-K:71E('-A=F\@<&%S:7)I;FMI;>`Z(`!5+E8N(&EN9&5K
M<V%S.B``4VMR:7!T;R!P<FES=&%T>6UO('-T871U<V\@<F%P;W)T;R!54DP`
M55),.@!59V%N9&$`56MR86EN80!.97!A=GEK;R!P97)S:V%I='ET:2!61E,@
M:V%T86QO9V\N`$YE<&%V>6MO('!R:63K=&D@<&%P:6QD;VUO<R!V87)T;W1O
M:F\@<F5G:7-T<F%C:6IO<R!I;F9O<FUA8VEJ;W,N`$YE<&%V>6MO('!A:V5I
M<W1I(%9&4R!F86EL;R`B)7,B('1E:7-I^"X`3F5P879Y:V\@<&%K96ES=&D@
M=&5I<VGX(%9&4R!F86EL=6D@)7,O)7,N`$YE<&%V>6MO('!E<F5I=&D@X2`E
M<RX`3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!344P@<V5R=F5R:6\N`$YE
M<&%V>6MO('!R:7-I:G5N9W1I(%-33"!R9?YI;74N`$YE<&%V>6MO(&YU:V]P
M:6IU;W1I(%9&4R!F86EL;RX`3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO
M9V\@(B5S(BX`3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO9V\N`$YE<&%V
M>6MO('-U:W5R=&D@5D93(&9A:6QO+@!.97!A=GEK;R!S=6MU<G1I('1U\.AI
M;R!61E,@9F%I;&\N`$YE<&%V>6MO(&GP87)C:'EV=6]T:2!D=6]M96[X+@!.
M97!A=GEK;R!I\'1R:6YT:2`B)7,B+"!K871A;&]G87,@;F5T=?#H:6%S`$YE
M<&%V>6MO(&GP=')I;G1I("(E<R(Z("5S`$YE<&%V>6MO(&GP=')I;G1I("5S
M+"!K871A;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO(&GP=')I;G1I("5S+@!.
M97!A=GEK;R!R96MU<G-I\&MA:2!I\'1R:6YT:2!61E,@:V%T86QO9V\N`$YE
M<&%V>6MO(&GP=')I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@:?!T<FEN
M=&D@5D93(&MA=&%L;V=O.B`E<RX`3F5P879Y:V\@:?!T<FEN=&D@5D93(&9A
M:6QO("(E<R(N`$YE<&%V>6MO(&GP=')I;G1I(%9&4R!F86EL;RX`3F5P879Y
M:V\@<F5K=7)S:?!K86D@:?!T<FEN=&D@5D93.B`E<RX`3F5P879Y:V\@;G5S
M=&%T>71I(&1A8F%R=&EN:6\@:V%T86QO9V\N`$YE<&%V>6MO(&=A=71I('-E
M<G1I9FEK871O(&%P<F'P>6UO`$YE<&%V>6MO('7^:W)A=71I("5S(&%P<F'P
M>6UO+@!.97!A=GEK;R!P97)K96QT:2!61E,@9F%I;&\N`$YE<&%V>6MO(&%T
M:61A<GET:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y:V\@871I9&%R>71I(%9&
M4R!F86EL;R!R8?!Y;75I+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO
M+@!.97!A=GEK;R!A=&ED87)Y=&D@<W5S<&%U<W1O(&%R8VAY=F\N`$YE<&%V
M>6MO('!E<G-K86ET>71I('9F<W)O;W0@:V%T86QO9V\N`$YE<&%V>6MO('!E
M<G9A9&EN=&D@(B5S(CH@)7,`3F5P879Y:V\@<&5R=F%D:6YT:2`E<R#A("5S
M.B!T;VMS(&MA=&%L;V=A<R!J874@96=Z:7-T=6]J80!.97!A=GEK;R!P97)V
M861I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@
M:V%T86QO9V\Z("5S+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`B
M)7,B+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`E<R\E<RX`3F5P
M879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\N`$YE<&%V>6MO(&=A=71I("5S
M('9A<G1O=&]J;R!U_FEM='5M;R!I;F9O<FUA8VEJ;W,@<V5R=F5R>6IE`$YE
M<&%V>6MO('!A;&5I<W1I("=M:VES;V9S)RX`3F5P879Y:V\@:?!V97)S=&D@
M\&EO(%=O<F0@9&]K=6UE;G1O`$YE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO
M("(E<R(N`$YE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("AC;W!Y*"D@:VQA
M:61A*2X`3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@9'5O;65N^"X`4&%B
M<F%U:W1I`$%T\&%U:W1I('!A:V5I=&EM=7,`073P875K=&D@86YK<W1E<V[A
M('9E:6MS;>``3F5T:6OK=&$@<V5R=F5R:6\@:VQA:61A.B``3F5T:6OK=&$@
M<V5R=F5R:6\@:VQA:61A.B``3F5N=7)O9'ET80!5;FEK;V1A<R`H551&+3@I
M`$IU;F=T:6YI86D@07)A8O@@16UY<F%T86D`2G5N9W1I;NL@2V%R86QY<W3K
M`$IU;F=T:6[K<R!686QS=&EJ;W,`2G5N9W1I;FGX(%9A;'-T>6KX($%T;VME
M<V[K<R!S86QO<P!6:65N971A:0!.9?YI;F]M87,`3F7^:6YO;6%S(&%P:6US
M9VED("A!4$D@365S<V%G92!)1"DN`$YE_FEN;VUA<R!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!.9?YI;F]M87,@=F%R=&]T;VIO('9A<F1A<R!I
M<B]A<F)A('-L87!T8?YO9&ES+@!086YA:6MI;G1I(&YU;W)O9.`@\&EA;2!E
M;&5M96YT=6D`3F7A=F%R9&EN=&%S`%-A=6=U;6\@<W5M971I;6%I<R!N97!R
M:79I;&5G:6IU;W1I('-K<FEP=&%I(&YE9V%L:2!A=&QI:W1I(%!E<FOK;&EM
M;R]+;W!I:F%V:6UO+\%KZVQI;6\@<')O9W)A;6GP:V%I+B!.;W+K9&%M:2!P
M97+^:?MRZW1I('1E8VAN:6YE<R!D971A;&5S(&UO>FEL;&$N;W)G('1I;FML
M87!Y:F4L(&ER('-U_FEN;W1I(&MA:7`@<VMR:7!T86US(&QE:7-T:2!P<FEE
M:71I('!R:64@;&%I:VEN;W-I;W,@<V%U9WEK;&]S+"!P87-P875S:VET92!/
M2RX`3F5N875D;W1I('-P86QV;W,`4&SK=&EN>7,@;F5P86QA:6MO;6%S`$%T
M;F%U:FEN=&D`071N875J:6YT:2`E<P!!=&YA=6II;G1I('9A<G1O=&]JX`!!
M=&YA=6II;G1A.B`E<RX`071N875J:6YI;6\@<VMR:7!T87,@:?!T<FEN=&%S
M+@!.=7-I^'-T:0!6:7-I(&UO9'5L:?@@871N875J:6YI;6\@9F%I;&%I(.%K
M96QT:2#A('-E<G9E<N$N`$1I9/YI;W-I;W,@;&]T:6YI\&MO<R!R86EDZW,`
M1&ED:65J:2!R;VWK;FGP:VD@<VMA:>AI86D`57)U9W9A:G5S`$YA=61O=&D@
M9&%B87)T:6[F.B`E<P!.875D;W1I(%-33`!.875D;W1I(&IE:6=U('9A<G1O
M=&]J;R!V87)D87,O<VQA<'1A_F]D:7,@24U34"!S97)V97)I=6D@>7)A(&MI
M=&]K<RX`5F%R=&]T;VIA<R`E<R!N96%U=&]R:7IU;W1A<R!P<FGK:FEM=6D@
M<')I92`E<RX`5F%R=&]T;VKX(&%D;6EN:7-T<F%V:6UA<P!687)T;W1O:F\@
M<^!S86IA`%9A<G1O=&]J;R!N=7-T871Y;6%I`%9A<G1O=&]J^"!R96=I<W1R
M86-I:F$`5F%R=&]T;VKX(')E9VES=')A8VEJ82!I\&IU;F=T82X`5F%R=&]T
M;VIO('9A<F1A<P!687)T;W1O:F\@=F%R9&%S.@!687)T;W1O:F\@=F%R9&%S
M.B``5F%R=&]T;VIA:2#P:6]J92!S:7-T96UO:F4Z`%5Z8F5K:7-T86YA<P!6
M1E,@:V%T86QO9V%S(&YE96=Z:7-T=6]J82X`071O<W1O9V]S`%)A<W1O<R!T
M96ES:6YG;W,@=FEE=&]VZW,Z(`!'86QI;VII;6%S`%)E:6OP;>L@;6EN=73K
M;6ES(&YU;R!D86)A<BX`4F5I:_!MZW,`4F5I:_!MZW,@:?`@:W5R:?@@9V%L
M:6UA('!A<VER:6YK=&D`5F%N=6%T=0!+:6YT86YT:7,`5F5N97-U96QA`%!A
M='9I<G1I;FEM87,@;F5B86EG=&%S("T@\&ES(&QA:?!K87,@<W5G861I;G1A
M<RX`5F5R<VEJ80!697)S:6KX(&MO;G1R;VSK`$QY9VEU;W1I('9E<G1I:V%L
M:6%I`%9E<G1I:V%L=7,@=&%R<&%S`%9E<G1I:V%L=7,Z`$QA8F%I(&1I9&5L
M:7,`5FEE=&YA;6%S`%9I971N86UI971I\&MA("A625-#24DI`%!E<OYI^W+K
M=&D@)7,`4F]D>71I(&1I96[@`%)O9'ET:2!I\&]R:6[A('!U<VQA<.$`4&5R
M_FG[<NMT:2!K86EP("5S`$)R:73X(%9I<F3^:6YI:F]S('-A;&]S`$I!5B!6
M:7)D_FEN:6IO<R!S86QO<P!-871O;75M87,`36%T;VUU;6%S.B``5F]D869O
M;F4@271A;&EJ82!P97(@4TU44`!705).`$3+345324\A(2$@4$%465,@2=!4
M4DE.2TE412!32U))4%3`($G0("5S+@!686QI<R!I<B!&=71U;F$`1.MM97-I
M;P!4<F7H+@!/<O@@<')O9VYO>NL`3W+X('!R;V=N;WKK('!A9V%L`%=E871H
M97(N8V]M`%=75P!75U<@<'5S;&%P:7,`5')EZ&EA9&EE;FES`%-A=F%I=.L`
M)60@<V%V86ETZP!3879A:73K*',I`$MA<R!S879A:73F`$MA<W-A=F%I=&EN
M:7,N($MA<G1O:F%S:2!K87,`4W9E:6MI`%-V96EK:2!A='9Y:^8@X2`E<P!,
M86)A<RP@)7,`5F%K87+X("A)4T\M.#@U.2TQ*0!686MA<O@@*$E33RTX.#4Y
M+3$U*0!686MA<O@@4V%C:&%R80!+;VOA(&UO9'5LX2`E<R!T=7)I(')O9'ET
M:2!P;R!P<FES:6IU;F=I;6\_`$MO:W,@<VMI<G1U:V\@<VEM8F]L:7,_`$MO
M:W,@:V%B=>AI^"!S:6UB;VQI<S\`2W5R:2!V86QA;F1A(&1A<F)O(&1I96YO
M;6ES(&ER('-A=F%I=&=A;&EA:7,@>7)A('!A<VMU=&ENZS\`2V5L:6YTX"!V
M86QA;F1A('!R87-I9&5D82!D87)B;R!D:65N82!I<B!S879A:71G86QI<S\`
M2W5R:6]S(&9A>NMS`$A434P@<F5D86MT;W)I875S(&UO9'5L:?@@X6IU;F=I
M;6%S+@!0;&]T:7,`4&QO=&ES($-34R!M871A:7,`)7,@:V%I<FEO:F\@;65N
M:74@<&QO=&ES("AP86ME:71I;6%I(&)U<R!M871Y=&D@<&\@:VET;R!P<FES
M:6IU;F=I;6\I.@!,96YT96SK<R!P;&]T:7,`4&QOZ&EO(&UA=&%S`%!L;W1I
M<SH`5VEK:0!6ZVIO(&=R96ET:7,@;6%Z9V%I<P!6ZVIA<SH`5NMJ87,Z(`!)
M\&UI;G1I<P!$87)B87,`1&%R8F\@861R97-A<P!$87)B;R!T96QE9F]N87,`
M1&%R8F\@<V%V86ETZP!8+5)E9@!8-3`Y=C,@<&%G<FEN9&EN:6%I(&YU<W1A
M='EM86D`6#4P.78S(&GP<&SK<W1O(')A:W1O('!A;F%U9&]J:6UA<P!8-3`Y
M=C,@86QT97)N871Y=G5S('9A<F1A<P!8-3`Y=C,@<F%K=&\@:61E;G1I9FEK
M871O<FEU<P!8-3`Y=C,@;6]D=6QI86D`65D`65E960!986AO;R$@_F5MZVQA
M<&ES`$MA<VUE=`!+87-M971I;FES+B!+87)T;VIA<VD@:V%S`$IE;65N87,`
M5&%I<`!486EP+"!A\"!S=71I;FMU`$K[<R!E<V%T92!414M35$E.24%-12!2
M1=Y)344N($YO<NMD86UI(&=RX?YT:2#A(%=94TE764<@<W!A=7-K:71E(%L\
M/ETN`$K[<R!N97!R:7-I:G5N9^8N`%-A=F\@=F%R9&4@;F5G86QI=&4@;F%U
M9&]T:2!S:6UB;VQI;R`G7"<N`-!IX"!F;W)MX"!G86QI=&4@;F%U9&]T:2!T
M:6L@:?`@9&%L>79I^"!R961A9V%V:6UO(&QA;F=O+@#!=F5DZW1E(&YE=&5I
M<VEN9^`@96PN('!A\'1O(&%D<F5SX"X`3F5P<FEJ=6YGZW1E(&IO:VGX(&QA
M=6OX(&GP(.%K96QI86UO(&9A:6QO('!R:64@)7,@871I=&EN:V%M^"!L875K
M^"X`2OMS(&YE='5R:71E('1E:7-I^"!P<FEDZW1I(.%V>6MI^"!P<FEE("5S
M+@!*^W,@;F5T=7)I=&4@=&5I<VGX('!R:63K=&D@X79Y:VGX(.$@<&%S:7)I
M;FMTX"!K86QE;F1O<FGX+@!*^W,@;F5T=7)I=&4@=&5I<VGX(&GP=')I;G1I
M(/!I;R#A=GEK:6\N`$K[<R!N971U<FET92!T96ES:?@@<F5D86=U;W1I(/!I
M;R#A=GEK:6\N`$K[<R!A='-I:G5N9^MT92X`2OMS(&YU<F]DZW1E(&YE=&5I
M<VEN9^`@:V%L96YD;W)I^"X`5'5R:71E(.%V97-T:2!T96ES:6YGX"!T96QE
M9F]N;R!N=6UE<N$@*'1I:R!S:V%IZ&EU<R!I<B`G*R<L(&IE:6=U(&YO<FET
M92!N=7)O9'ET:2!T87)P=&%U=&ENX2!K;V3@*2X`P79E9.MT92!N971E:7-I
M;F?@(')E:6OP;>8N`$YO<NMD86UI(&YA=6=O=&ES(')E9VES=')A8VEJ;W,@
M<VES=&5M82P@='5R:71E('-U:V]N9FEG^W)U;W1I(&1U;VUE;O@@;65D_FEO
M('!O<VES=&5MYBX`4')I9?`@<VGX<V1A;6D@<')A;F7P:6W@+"!A<')A\'EK
M:71E('!R;V)L96W@+@#!<F'P>6MI=&4@;G5O<F]D;W,@55),`$YU<F]D>6MI
M=&4@:V%L96YD;W)I^"P@:W5R:>`@;F]R:71E(&GP=')I;G1I+@!6:7/X('!I
M<FUA(')E:6MI82!N=7)O9'ET:2!A9')E<^`N`%1U<FET92!P87-I<FEN:W1I
M('-E<G9E<N$L(&MU<N$@;F]R:71E(&GP=')I;G1I+@!.=7)O9'EK:71E('9A
M<G1O=&]J;R!V87)DX"P@:W5R:6\@9'5O;65N:7,@=')I;F%T92X`3G5R;V1Y
M:VET92!V87)T;W1O:F\@=F%R9.`@=')Y;FEM=6DN`$YU<F]D>6MI=&4@:W5R
M:6%M;R!V87)T;W1O:F\@=F%R9.`N`$YU<F]D>6MI=&4@871N875J:6YA;6\@
M=F%R=&]T;VIO('9A<F3@+@!.=7)O9'EK:71E('9E:6MS;>`N`$K[<R!T=7)I
M=&4@X79E<W1I(&YA=6IO<R!K871E9V]R:6IO<R!P879A9&EN:6W@+@`E<R!S
M97-I:F$@8F%I9^MS:2X@4')A\&]M92!P<FES:6IU;F=T:2!I\"!N875J;RX`
M2OMS^"!E;"X@<&'P=&\@861R97-A<SH`16PN('!A\'1O(&%D<F5S87,Z`$EN
M9F]R;6%C:6IA(&%P:64@2G5S`$YU;R`E<R!S97-I:F]S('!R863^:6]S(&K[
M<_@@25`@861R97-A<R!P87-I:V5I=.LN(%1U<FET92!P<FES:6IU;F=T:2!I
M\"!N875J;RX`2OMS^"!V87)D87,O<&%V87)DZP!*^W/X(&%U=&5N=&EF:6MA
M=FEM;R!S:7-T96UA(&YE<&%L86EK;R!V87)T;W1O:O@@<^!R8?!O+"!A<F)A
M(/!I(&9U;FMC:6IA('7^9')A=7-T82!DZVP@=&%M('1I:W+X('!R:67^87/H
M:?@N`$YU;R`E<R!S97-I:F]S('!R863^:6]S(&K[<_@@;F%R\'EK;.MS('1I
M<&%S('!A<VEK96ETZRX@5'5R:71E('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*
M^W/X(&YA<O!Y:VSK(&YE<&%L86EK;R#P:6]S(&=A;&EM>6+K<RX`2OMS^"!L
M86EK;R!J=6]S=&$Z`$K[<_@@<&%G<FEN9&EN:7,@:V%L96YD;W)I=7,`2OMS
M^"!S=&%N9&%R=&EN:7,@87!R8?!A<SH`2OMS^"!V87)D87,O<&%V87)DZSH`
M2OMS^"!N875J87,@)7,@<VQA<'1A_F]D:7,@>7)A.B`E<P!*^W/X(&YU<W1A
M='EM86D@871N875J:6YT:2X`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,`
M2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,N(%!A<VET:6MR:6YK:71E('-A
M=F\@<&'P=.`@:7(@<')I<VEJ=6YK:71E('-U(&YA=6IU('-L87!T8?YO9/YI
M=2X`2OMS^"!N=71O;.8@<V5R=F5R:6%I.@!*=6=O<VQA=FEJ80!:86ER87,`
M6F%M8FEJ80!::6UB86)VZP!%;F5R9VEN9V]S`%M087-LZW!T:2!C:71U;VIA
M;>`@=&5K<W3@70!;4')O8FQE;6]S('!R86YE\&EM87-=`%M2;V1Y=&D@8VET
M=6]J86W@('1E:W-TX"`M`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M("5S
M(&5I;'5T97-=`%M.9>%V87)D:6YT87,@X79Y:VES70!;96EL=73K("5S(&GP
M("5S70!?5F%L9'EM87,`4&%P<F%?<W1O:FD@<&%I9?!K80!?0TQ)`%]$=6]M
M96[X(&UE9&ES`%])\'1R:6YT:2!E:6QU=.8`4F5D86=U;W1I`%)O9%]Y=&D`
M1U]R=7#K<P!085]G86QB80!?4&%V96EK<VSK;&EO(&YU<W1A='EM86DN+BX`
MP6ME;'1I+U])\&ME;'1I`%!R:7-I7VIU;F=T:0!!='-I7VIU;F=T:0!?2V5I
M<W1I(&YU;W)O9.`N+@!.85]U:F%S(.%R8?!A<P!?3G5S=&%T>6UA:0!?5&5I
M<^MS`%-P875S9&EN=&D`7TGP=')I;G1I(&YU;W)O9.`N+BX`267P:V]T:0!?
M2V]N9FEG^W)A8VEJ80!?3&5N=&5LZW,@;G5S=&%T>6UA:2XN+@!?T&EA;F1I
M96X`5E]A<G1O=&]J86D`861R97/X(&MN>6=E;.L`<')I9?`@<')A<VED961A
M;G0@X79Y:VEU:0!+86QE;F1O<FEU<P!R86UU<P!S<&%U<VMI=&4@Z&EA`&1I
M96YA`&1I96YA*&]S*0!D:65N;W,`:79Y:VEA:2YC<W8`:79Y:VEA:2YI8W,`
M:W)E;G1A`&9A:6QA<P!N=6\`;G5O("5S("@E<RD@)7,@)7,`83H`='5O:F%U
M('!A=`!P87!R87-T:0!E:6QU=&5S70!M:VES;V9S(&ML86ED;W,@:V]D87,@
M)60@8F5D87)A;G0@25-/+@!MZVYU;RAI86DI`'9A<F1A<P!N97)E86QI>G5O
M=&$`9&%R(&YE<F5A;&EZ=6]T80!U_G)A\/@@:VYY9V5LZP!T=6\@<&'H:74@
M;65T=0!T82!P8>AIX"!S879A:73K<R!D:65NX`!P<F]C96YT86D`<&EK<V5L
M:6%I`&MY;&$`<F]D>71I('-K:7)T=6UU<P!S;7,R96UA:6P@<&5R($A45%``
M<W1A8FEL:0!D87)B^"!SX')A\&%S`'-L87!T8?YO9.$@='5R:71E(.%R8?!Y
M=&D@9'4@:V%R='5S`'5N:69I:W5O=&D`9&%L:7,`=F%R=&]T;VIO('!A<VER
M:6YK:6UA<P!V0V%L96YD87(O:4-A;&5N9&%R`'9#87)D`'9%=F5N="!N97)A
M<W1A<RX`<#H`=V5A=&AE<BYC;VT`<V%V86ETZP!S879A:73K*.MS*3H`<V%V
M86ETZW,`;65T86D`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:W)O;F]L:71H+VQO8V%L92]L=E],5B\`````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,0`P,C`W,30`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+VQV7TQ6+TQ#
M7TU%4U-!1T53+P``````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8R-S4Q`#`R,C4P,0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET
M:"]L;V-A;&4O;'9?3%8O3$-?34534T%'15,O:W)O;F]L:71H+FUO````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,S`U-S,`,3`T,3<S-C(W-3$`,#(U,#4T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-X2!)4`````XP```!P````T
M!P``,P$``$P.````````&!,``"@````9$P``'0```$(3```(````8!,```4`
M``!I$P``"0```&\3```/````>1,```@```")$P``!P```)(3```%````FA,`
M``H```"@$P``%````*L3```*````P!,```4```#+$P```P```-$3```'````
MU1,```T```#=$P``"@```.L3```?````]A,```4````6%````@```!P4```&
M````'Q0``!$````F%```"````#@4```&````010``!4```!(%```"````%X4
M```*````9Q0```P```!R%```!P```'\4```;````AQ0``"D```"C%```$@``
M`,T4```'````X!0```(```#H%```!0```.L4```3````\10```,````%%0``
M!@````D5```(````$!4``!`````9%0``!@```"H5```)````,14```P````[
M%0``7````$@5```4````I14```L```"Z%0``+P```,85```/````]A4``"8`
M```&%@``!P```"T6```(````-18```0````^%@``!P```$,6```%````2Q8`
M``T```!1%@``"````%\6```&````:!8```@```!O%@``!0```'@6```0````
M?A8``!````"/%@``#P```*`6```+````L!8```\```"\%@``#````,P6```/
M````V18```8```#I%@``#P```/`6```>`````!<``"$````?%P```P```$$7
M```(````11<```(```!.%P``!@```%$7```&````6!<```0```!?%P``!```
M`&07```,````:1<```H```!V%P``!0```($7```'````AQ<``!8```"/%P``
M$@```*87```0````N1<```<```#*%P``!````-(7```$````UQ<```@```#<
M%P``"````.47```*````[A<```D```#Y%P``'@````,8```0````(A@```@`
M```S&```!@```#P8```'````0Q@```(```!+&```!````$X8```%````4Q@`
M``\```!9&````P```&D8```'````;1@```<```!U&```"0```'T8```"````
MAQ@```8```"*&```!0```)$8```'````EQ@``!4```"?&```!0```+48```)
M````NQ@```H```#%&```"````-`8```)````V1@```L```#C&```!````.\8
M```%````]!@```@```#Z&```!P````,9```'````"QD``!$````3&0``"```
M`"49```'````+AD``!X````V&0``'@```%49```%````=!D``"@```!Z&0``
M*0```*,9```,````S1D``!,```#:&0``"P```.X9```/````^AD``!,````*
M&@``$P```!X:```/````,AH```P```!"&@``#@```$\:```-````7AH```T`
M``!L&@``"P```'H:```1````AAH``!$```"8&@``!````*H:```"````KQH`
M``@```"R&@``"P```+L:```*````QQH```P```#2&@``6````-\:```:````
M.!L``!<```!3&P``&@```&L;```9````AAL``!<```"@&P``'0```+@;```;
M````UAL``!\```#R&P``$P```!(<```)````)AP``#L````P'```'P```&P<
M```H````C!P``!````"U'```%P```,8<```*````WAP```@```#I'```"@``
M`/(<```"````_1P```<`````'0``!@````@=```%````#QT```(````5'0``
M+P```!@=```?````2!T``"$```!H'0``'````(H=```(````IQT```4```"P
M'0``!0```+8=```(````O!T```(```#%'0``!P```,@=```$````T!T``!0`
M``#5'0``)````.H=```F````#QX```P````V'@``!P```$,>```.````2QX`
M``P```!:'@``"````&<>```'````<!X```(```!X'@``"0```'L>```$````
MA1X```<```"*'@``!P```)(>```&````FAX``!0```"A'@``#0```+8>```+
M````Q!X``$@```#0'@``3````!D?```,````9A\```H```!S'P``"0```'X?
M```"````B!\```8```"+'P``%````)(?``!%````IQ\``#````#M'P``$```
M`!X@```?````+R```!````!/(```#P```&`@```#````<"````8```!T(```
M!````'L@```(````@"```!````")(```$P```)H@```%````KB````0```"T
M(```"P```+D@```%````Q2````<```#+(```3@$``-,@```J````(B(``!D`
M``!-(@``"@```&<B```%````<B(``!(```!X(@``&````(LB```.````I"(`
M``8```"S(@``#````+HB```3````QR(``"0```#;(@``$@`````C```,````
M$R,```0````@(P``"P```"4C```4````,2,```T```!&(P``&0```%0C```'
M````;B,```$```!V(P``!P```'@C```0````@",```\```"1(P``!@```*$C
M```;````J",```H```#$(P``$0```,\C```,````X2,```@```#N(P``'```
M`/<C```K````%"0``!<```!`)```#````%@D```"````920```@```!H)```
M&````'$D```%````BB0```8```"0)```"0```)<D```2````H20```4```"T
M)```"0```+HD```.````Q"0``$<```#3)```$P```!LE```-````+R4``"\`
M```])0``$@```&TE```B````@"4```T```"C)0``!@```+$E```%````N"4`
M``@```"^)0``!P```,<E```0````SR4```P```#@)0``!P```.TE```+````
M]24```4````!)@``$0````<F```2````&28``!`````L)@``&````#TF```/
M````5B8```P```!F)@``#@```',F```)````@B8``!,```",)@``'@```*`F
M```D````OR8```4```#D)@``"0```.HF```"````]"8```H```#W)@``!P``
M``(G```%````"B<```D````0)P``#````!HG```.````)R<```4````V)P``
M"0```#PG```;````1B<``!0```!B)P``$````'<G```(````B"<```8```"1
M)P``!@```)@G```+````GR<```8```"K)P``$````+(G```-````PR<``"8`
M``#1)P``&@```/@G```)````$R@```L````=*```!0```"DH```"````+R@`
M``4````R*```!0```#@H```0````/B@```4```!/*```"````%4H```$````
M7B@```D```!C*````@```&TH```)````<"@```<```!Z*```#````((H```:
M````CR@```4```"J*```#@```+`H```0````OR@```P```#0*```#0```-TH
M```0````ZR@```,```#\*```"``````I```)````"2D```@````3*0``!P``
M`!PI```0````)"D```8````U*0``!0```#PI```?````0BD``!D```!B*0``
M"````'PI```C````A2D``"T```"I*0``$0```-<I```2````Z2D```H```#\
M*0``$P````<J```F````&RH``!8```!"*@``$@```%DJ```7````;"H``!@`
M``"$*@``%0```)TJ```3````LRH```P```#'*@``(0```-0J```7````]BH`
M``0````.*P```@```!,K```)````%BL``!$````@*P``$0```#(K```0````
M1"L``&,```!5*P``'@```+DK```;````V"L``!T```#T*P``(````!(L```:
M````,RP``"@```!.+```(P```'<L```3````FRP``!P```"O+```"@```,PL
M```&````URP``!X```#>+```)@```/TL```2````)"T``!0````W+0``#0``
M`$PM```'````6BT```P```!B+0```@```&\M```'````<BT```D```!Z+0``
M"````(0M```"````C2T``"<```"0+0``&0```+@M```?````TBT``!\```#R
M+0``"@```!(N```)````'2X```<````G+@``"````"\N```"````."X```@`
M```[+@``!````$0N```2````22X``"$```!<+@``*P```'XN```/````JBX`
M``P```"Z+@``#P```,<N```1````URX```\```#I+@``"P```/DN```"````
M!2\```D````(+P``!@```!(O```*````&2\```D````D+P``#````"XO```9
M````.R\``!````!5+P``$````&8O```]````=R\``#L```"U+P``#````/$O
M```.````_B\```P````-,````@```!HP```*````'3```!H````H,```+P``
M`$,P```\````<S```!````"P,```&P```,$P```4````W3```!````#R,```
M!0````,Q```(````"3$```8````2,0``#````!DQ```0````)C$``!<````W
M,0``!0```$\Q```&````53$```T```!<,0``!P```&HQ```(````<C$```$`
M````````<````-8```!%`````````$H``````````````#$`````````Q0``
M`'$```#?````'0````````#;````I0``````````````*````!`````-````
MXP```-,```!?````````````````````!````*$`````````'P```*H`````
M````*@`````````7`````P```*,````P````Q@```#,`````````9````-4`
M````````)@```!X`````````/P```%L```"P````=@````````!-````#P``
M``````!6``````````````#.````7````+(```#7````4@```)P```"-````
M$P``````````````T0``````````````NP```&4`````````G@```$$```#9
M````60```&(`````````DP```'P```#+````&````)<```![`````````"\`
M``!"````=0```%$````V``````````````"$````#`````````")````@P``
M`)\```!/````I````'X`````````<@````````!)````E0```%T```!:````
M9P````````!J````4P```#0```"@````T@```)0`````````8P```(\```":
M````E@```!(`````````;P```$0```"=````/0````````#"````````````
M``!L````````````````````C@```````````````````+H`````````M```
M`!$````@````F0```'D```!H``````````````!@`````````$,```"\````
M4````,\````A````A@````@```"!````1P```,````"Q````=P```!L`````
M````(P```"<```!>````.``````````'````*0```#L````W````2P``````
M``#$`````````,P`````````1@```(H```#=````D@```(<`````````;0``
M``X````6````"0```#D```";````D0`````````%````80````````!F````
M``````````"%````X``````````N`````````*\```#(````W````%0```"L
M````F`````````""````X0````````"M`````@```*(```"``````````+X`
M``##````!@```,D```"(````&@```"T```"Y````3````-X````5````R@``
M`.(```!K``````````````"]````+``````````+````/````+<```!5````
M`````*8```#:````2`````H`````````P0```*<````Z````-0```$X```"K
M````S0```'0```"N````N````(P````B```````````````D````````````
M````````J````-0````4````5P`````````<````/@```+4```"V````J0``
M`-@```"+````&0```-`````E````6````"L`````````0````)````!Z````
MQP```+\```!N````````````````````<P```'\`````````>````#(```"S
M````:0```'T`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;@`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``R-"!H;W5R
M<P!!32]030!!9&0@179E;G0`061D(&$@;F5W(&5V96YT`$%D9"!P86ER`$%D
M9')E<W,`06QA<FT`06QA<FT@1&%T90!!;&%R;2!3<&%N("AM:6YU=&5S*0!!
M;&%R;2!4:6UE`$%L:6%S`$%L;`!!;&P@9&%Y`$%L;"!D87D@979E;G0`06QL
M(&5V96YT<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P<FEL
M`$%T`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!#86YC96P`
M0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A=&5G;W)Y`$-E;&P@4&AO;F4`0VQO
M<V4@5VEN9&]W`$-O;7!A;GD`0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-R
M96%T92!A($YE=R!%=F5N=`!#=7)R96YT`$1$`$1A:6QY`$1A:6QY.B!296-U
M<G,@979E<GD`1&%Y`$1A>2AS*0!$96-E;6)E<@!$969A=6QT($ED96YT:71Y
M`$1E;&5T90!$96QE=&4@)7,`1&5L971E($5V96YT`$1E;&5T92!T:&4@8W5R
M<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U
M<F4@;V-C=7)E;F-E<RP@;W(@86QL(&]C8W5R96YC97,_`$1E<V-R:6)E('1H
M92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$=64Z("5S`$1U
M<F%T:6]N`$5D:70`161I="`E<P!%;6%I;`!%;7!T>2!R97-U;'0N`$5N9"!$
M871E`$5N9"!/;@!%;F0@5&EM90!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M<&]R=`!%>'!O<G0@0V%L96YD87(`1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`
M1F5B<G5A<GD`1G(`1G)I9&%Y`$9U='5R90!'86UE`$AE;'``2&]M92!!9&1R
M97-S`$AO;64@4&AO;F4`2&]R9&4`2&]U<BAS*0!);7!O<G0O17AP;W)T($-A
M;&5N9&%R`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$IA
M;G5A<GD`2G5L>0!*=6YE`$ME>7=O<F1S`$QA;F=U86=E`$QA<W0@36]N=&@`
M3&%S="!W965K`$QI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.@!,:7-T
M($AE;'`@5&]P:6-S`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`
M36%R8V@`36%T8VAI;F<@9FEE;&1S`$UA>0!-965T:6YG`$UE<W-A9V4`36EN
M=71E*',I`$UO`$UO;F1A>0!-;VYT:`!-;VYT:&QY`$UO;G1H;'DZ(%)E8W5R
M<R!E=F5R>0!.979E<@!.97<@179E;G0`3F5X="!-;VYT:`!.97AT(&1A>0!.
M97AT('=E96L`3F\@96YD(&1A=&4`3F]N90!.;W1E<P!.;W9E;6)E<@!/8W1O
M8F5R`$]P=&EO;G,`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&%T=&5R
M;@!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R;6%N96YT;'D@
M9&5L971E('1H:7,@979E;G0_`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0`4')E=FEO=7,@9&%Y`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4F5C=7(@56YT:6P`4F5C=7)R96YC92!$871A`%)E8W5R<F5N8V4@
M16YD($1A=&4`4F5C=7)R96YC92!);G1E<G9A;`!296-U<G)E;F-E(%1Y<&4`
M4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`4F5C
M=7)S('EE87)L>0!296UO=F4@<&%I<@!297-E="!T;R!$969A=6QT<P!2971U
M<FX@=&\@3W!T:6]N<P!2;VQE`%-A`%-A='5R9&%Y`%-A=F4@07,@3F5W`%-A
M=F4@179E;G0`4V%V92!/<'1I;VYS`%-E;&5C="!C;VYF:7)M871I;VX@;W!T
M:6]N<RP@:&]W('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@
M8VAO;W-E(&1E9F%U;'0@=FEE=RX`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O
M(&EM<&]R=#H`4V5L96-T('1H92!F:7)S="!W965K9&%Y.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W.@!3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E<'1E;6)E<@!3
M:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A
M;&5N9&%R('9I97=S/P!3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_
M`%-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\`4VMI
M<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=&%R="!$
M871E`%-T87)T($]N`%-T87)T(%1I;64`4W4`4W5C8V5S<P!3=6YD87D`5&%S
M:W,`5&@`5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A
M<G0@9&%T92X`5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@97AP;W)T+@!4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+@!4:'5R<V1A>0!4:71L90!4;V1A>0!4;VUO<G)O=P!4
M=0!4=65S9&%Y`%1Y<&4`56YA8FQE('1O(&1E;&5T92`E<RX`56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5S
M97(@26YT97)F86-E`%5S97(@3W!T:6]N<P!5<V5R;F%M90!787)N:6YG`%=E
M`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E:RAS*0!7965K;'D`5V5E:VQY
M.B!296-U<G,@979E<GD`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T
M('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE
M<F4@87)E(&YO(&QA=&5R(&5V96YT<S\`5VAA="!T:6UE('-H;W5L9"!D87D@
M86YD('=E96L@=FEE=W,@<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI
M97(@979E;G1S/P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7;W)K(%=E96L`
M65D`665A<FQY`%EE87)L>3H@4F5C=7)S(&5V97)Y`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S
M92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@
M;V8@)7-=`&1A>0!D87DH<RD`9&%Y<P!M;VYT:"AS*0!O;B!T:&4@<V%M92!D
M871E`&]N('1H92!S86UE('=E96MD87D`=D-A<F0`=V5E:P!W965K*',I(&]N
M.@!W965K<P!Y96%R*',I`%!R;VIE8W0M260M5F5R<VEO;CH@,2XP"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-"TP.2TQ-2`R,#HU,BLP,C`P"DQA<W0M5')A;G-L871O<CH@
M279A<G,@4W1I=G)I;G,@/&EV87)S0&MR87-L879A+FQV/@I,86YG=6%G92U4
M96%M.B!,871V:6%N(#QI=F%R<T!K<F%S;&%V82YL=CX*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U
M-PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`)7,@57IT=7+G
M\&%N87,@;W!E<N)C:6IA<R`M(&%P<W1I<')I;N)J=6US`"5S(&1A=&YE('-E
M:VWN9VD@:65LXF3G=&$`,C0@<W1U;F1A<P!!32]030!0:65V:65N;W0@;F]T
M:6MU;74`4&EE=FEE;F]T(&IA=6YU(&YO=&EK=6UU`%!I979I96YO="!PXG)I
M`$%D<F5S90!!=&?B9&ENXFIU;7,`071GXF1I;N)J=6UA(&1A='5M<P!!=&?B
M9&ENXFIU;6$@;&%I:V$@<W!R[F1I<R`H;6EN^W3G<RD`071GXF1I;N)J=6UA
M(&QA:6MS`$%I>G-TXFIVXG)D<P!6:7-S`%9I<VD@9&EE;F%S`%9I<VD@9&EE
M;F%S(&YO=&EK=6UI`%9I<VD@;F]T:6MU;6D`3F]RXF3N=&$@;F5D97+N9V$@
M=N=R=.YB80!!<'+N;&ES`"T`075G=7-T<P!0:65E:F%M:64@;&%U:VDZ`$1Z
M:6WP86YA<R!D:65N80!!=&-E;'0`071C96QT('!R;V)LYVUA<R!P:65T96EK
M=6UU`$MA=&5G;W)I:F$`36]B:6QA:7,@=.)L<G5N:7,`06EZ=N=R="!L;V=U
M`%5Z\N=M=6US`$%P<W1I<')I;N)T(&YO=&EK=6UU(&1ZY_!A;G4`3F5I>F1E
M=N)S(&%T=N=R="!-86EN=&5N86YC95]487-K(&UO9'5L:2`E<P!)>G9E:61O
M="!J875N=2!N;W1I:W5M=0!087-R96EZYVIA:7,`1$0`26MD:65N87,`1&EE
M;N(Z($%T:^)R=&]T:65S(&MA=')U`$1I96YA`$1I96YA<P!$96-E;6)R:7,`
M4&%R87-TXB!I9&5N=&ETXG1E`$1ZYW-T`$1A='5M<R`E<P!$>N=S="!N;W1I
M:W5M=0!$>N=S="!T:6MA:2!E<V_P;R!N;W1I:W5M=2P@\&%JXB!U;B!V:7/B
M<R!NXFMA;6%JXG,@<F5I>N=S+"!V86EV:65N;>=R/P!!<')A:W-T:65T('!R
M;V)LYVUU`%!A<VMA:61R;VIU;7,`4^YKXFMA(&EN9F]R;>)C:6IA(&ER(&YO
M<_MT[G1A(&%D;6EN:7-T<F%T;W)A;2X`1&ES<&QE:F$@<&%R86UE=')I`$YA
M=B!T:67P87,@<&EE96IA<R!M86EN=&5N86YC92YP:'``4V%K87+B(&%R.B`E
M<P!);&=U;7,`3&%B;W0`3&%B;W0@)7,`12UP87-T<P!4=6OP<R!R97IU;'3B
M=',N`$)A:6=U(&1A='5M<P!"96ED>F%S`$)E:6=U(&QA:6MS`$OO^V1A`$MA
M=')A<R`Q-2!M:6[[=&5S`$MA=')A<R`S,"!S96MU;F1E<P!+871R87,@-2!M
M:6[[=&5S`$MA='+B('!I97-LYV?P86[B<R!R96EZYP!+871R=2!P=7-S='5N
M9'4`2V%T<G4@;6EN^W1I`%!A<F%U9W;G<G3N8F%S`$5K<W!O<G3G=`!%:W-P
M;W)TYW0@:V%L96YDXG)U`$YE:7ID97;B<R!S8?)E;70@:65S=&%T[FIU;75S
M+@!.96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2X`1F%K<W,`
M1F5B<G7B<FES`%!I`%!I96MT9&EE;F$`3N)K;W1NYP!3<.=L90!086SN9'KN
M8F$`3>)J87,@861R97-E`$WB:F%S('1E;&5F;VYS`$AO<F1E`%-T=6YD82AS
M*0!)979I;&MT+T5K<W!O<G3G="!K86QE;F3B<G4`265LXF3G=&%I<R!L875K
M<SH@)7,`265LXF3G=&EE(&QA=6MI.@!*86YVXG)I<P!*^VQI:G,`2OMN:6IA
M`$%T<VSG9W;B<F1I`%9A;&]D80!0YV3G:F%I<R!MYVYE<VES`%#G9.=JXB!N
M963G[V$`265R;V)E_F]T(&QA:6MA(&=R869I:W4@9&%T=2!E:W-P;W)T86T`
M4&%RXF3N="!P86SN9'KN8F%S('1E;6%T=7,`071R8?!A;N)S`%!I97-LYV=T
M:65S`$EZ:65T`$U-`%!A<W1S`$UA<G1S`%-A<VMA;F_P:64@;&%U:VD`36%I
M:G,`5&EK\&%NXG,`6FGR80!-:6[[=&4H<RD`4&D`4&ER;61I96YA`$WG;F5S
M:7,`2V%T<G4@;>=N97-I`$WG;F7P;W,Z($%T:^)R=&]T:65S(&MA=')U`$YE
M:V%D`$IA=6YS(&YO=&EK=6US`$[B:V_P86ES(&WG;F5S:7,`3N)K;_#B(&1I
M96YA`$[B:V_PXB!N963G[V$`3F%V(&)E:6=U(&1A='5M80!.878`4&EE>NYM
M97,`3F]V96UB<FES`$]K=&]B<FES`$]P8VEJ87,`0VET82!I;F9O<FWB8VEJ
M80!087)O;&4`5F5I9',`27IP:6QD[G0@=7IT=7+G\&%N87,@;W!E<N)C:6IA
M<P!$>N=S="#P;R!N;W1I:W5M=2!P:6QN[F+B`%3B;')U;FES`$S[9'IU(&YO
M<N)D:65T('!R;V)LYVUA<R!A;F]TXF-I:G4N`$S[9'IU(&YO<N)D:65T('-A
M=G4@;&EE=&]TXFIA(';B<F1U('5N('!A<F]L:0!)97!R:65K\.=JXB!D:65N
M80!0<F]B;.=M87,@87!R86MS=',`071KXG)T;VIA<P!!=&OB<G1O\&%NXG,@
M9&%T=6US`$%T:^)R=&_P86[B<R!I>G1E8^=J=6UA("AB96EG=2D@9&%T=6US
M`$%T:^)R=&_P86[B<R!I;G1E<G;B;',`071KXG)T;_!A;N)S(&QA:6MS`$%T
M:^)R=&]T:65S(&MA=')U(&1I96YU`$%T:^)R=&]T:65S(&MA=')U(&WG;F5S
M:0!!=&OB<G1O=&EE<R!I:R!N963G[W4`071KXG)T;W1I97,@:6L@9V%D=0!)
M>F1ZYW-T('#B<FD`071I97-T873N="!N;VML=7/G:G5M82!P87)A;65T<G5S
M`$%T9W)I97IT:65S('!I92!O<&-I:N)M`$QO;6$`4V4`4V5S=&1I96YA`%-A
M9VQA8N)T(&OB(&IA=6YU`%-A9VQA8N)T(&YO=&EK=6UU`%-A9VQA8N)T(&]P
M8VEJ87,`27IVYVQI971I97,@87!S=&EP<FENXFIU;6$@<&%R86UE=')U<RP@
M:7IVYVSN971I97,@=FEE;G4@;F\@=F%I<N)K:65M87!S:V%T97,@*&%T=.=L
M;VIU;6$I('9E:61I96TN`$EZ=N=L:65T:65S(&1A='5M82!A=&1A;.YTXFIU
M.@!)>G;G;&EE=&EE<R!D871U;6$@9F]R;>)T=3H`27IVYVQI971I97,@9&%T
M;FD@:V\@:65L87/N=#H`27IVYVQI971I97,@;F5DY^]A<R!P:7)M;R!D:65N
M=2X`27IVYVQI971I97,@;&%I:V$@9F]R;>)T=3H`27IVYVQI971I97,@;&%I
M:V$@<W!R[F1I(&-I:R!I;&=I('+B9.YT.@!)>G;G;&EE=&EE<R!D:79U<R!S
M861E<NYG=7,@;&%U:W5S+@!)>G;G;&EE=&EE<R!V86QO9'4Z`$YO<_MT[G0@
M<')O8FSG;6%S('!I971E:6MU;74`4V5P=&5M8G)I<P!2XF3N="``4N)D[G0@
M87(@;F]T:6MU;6EE;2!K86QE;F3B<N(_`%+B9.YT('1I:V%I(&YO=&EK=6UU
M<R!A<B!A=&?B9&ENXFIU;74_`$EZ;&%I<W0@=7IT=7+G\&%N=0#.<&'P;R!S
M:6UB;VQU(&EE=F%D90!3XFMU;6$@9&%T=6US`%/B:W-I97,`4^)K=6UA(&QA
M:6MS`%-V`%9E:6MS;64`4W;G=&1I96YA`%5Z9&5V=6UI`$-E`$)E:6=U(&1A
M='5M86T@:7(@:N)B^W0@=N=LXFL@:^(@<^)K=6UA+@!.878@;F]T:6MU;74@
M:V\@96MS<&]R=.=T`-!I;2!S:V%I=&QI;2!I<B!JXF+[="!V:7-M87H@,2X`
MT&%I(';G<G3N8F%I(&ER(&KB8OMT('-K86ET;&EM+@!#971U<F1I96YA`$YO
M<V%U:W5M<P#0;V1I96YA`%+N=&1I96YA`$]T`$]T<F1I96YA`%1I<',`3F5V
M87(@;F5O9'KG<W0@)7,N`$YE=F%R(&EE;.)DYW0@9&5F:6[N8VEJ=2!I96OP
M("5S+@!.878@:65S<.=J86US(&EN=&5R<')E=.=T(/!O(%=O<F0@9&]K=6UE
M;G1U`$%T8V5L="!I>FUA:?)A<P!.96%I>G!I;&3N=',`3&EE=&]TXFIA('-K
M871S`$QI971O=.)J82!O<&-I:F%S`$QI971O=.)J82!VXG)D<P!"<NYD:6[B
M:G5M<P!4<@!4<F7P9&EE;F$`3F5DY^]A`$YE9.?O87,@)60`3F5DY^]A*',I
M`$MA=')U(&YE9.?O=0!.963G[V$Z($%T:^)R=&]T:65S(&MA=')U`$QA:7!N
M:2!L^V1Z86T@)7,`3&%I<&YI(&S[9'IM+"`E<P!+XF3B(&QA:6OB(&1I96YA
M:2!U;B!N963G[V%I(&KB8F5I9'IA<RP@:F$@;F%V(&-I='4@:65R86MS='4_
M`$OB9.(@;&%I:^(@9&EE;F%I('5N(&YE9.?O86D@:N)SXFMA<RP@:F$@;F%V
M(&-I='4@:65R86MS='4_`$1A<F)A(&%D<F5S90!$87)B82!TXFQR=6YI<P!$
M87)B82!N963G[V$`1T<`2V%T<G4@9V%D=0!):V=A9'5S.B!!=&OB<G1O=&EE
M<R!K871R=0!!<')A:W-T:65T('!R;V)LYVUU('!I<FUS('!I971E:6MU;6$@
M<_MT[O!A;F%S+@!*^W-U("5S('-E<VEJ82!I<B!B96EG=7-I97,N($S[9'IU
M('!I97-LYV1Z:65T:65S(&%T:^)R=&]T:2X`2OMS=2!I;F9O<FWB8VEJ80!*
M^W-U(&]P8VEJ87,@:7(@<V%G;&%BXG1A<RX`6U!R;V)LYVUA<R!Z:?)O:G5M
M<UT`6W)I;F1A("5S(&YO("5S70!D:65N80!D:65N82AS*0!D:65N87,`;>=N
M97-I<R@M\&DI`'1A:N(@<&'PXB!D871U;>(`=&%JXB!P8?#B(&YE9.?O87,@
M9&EE;N(`=D-A<F0`;F5DY^]A`&YE9.=LXB@MXG,I(#H`;F5DY^]A<P!G861S
M*"UI*0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE
M+VYB7TY/+P``````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S4Q`#`R,#8V-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]L;V-A;&4O;F)?3D\O3$-?34534T%'15,O````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3$`,#(R-#4R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]N8E].3R],0U]-
M15-304=%4R]K<F]N;VQI=&@N;6\`````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-C<V-P`Q,#0Q-S,V
M,C<U,0`P,C4P-#``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0`````M`0``'````(0)``"1`0``[!(````````P&0``
M*````#$9```=````6AD``!T```!X&0``"````)89```%````GQD``!````"E
M&0```P```+89```)````NAD```\```#$&0``#0```-09```(````XAD```<`
M``#K&0``#P```/,9```%`````QH```H````)&@``%````!0:```*````*1H`
M``4````T&@```P```#H:```-````/AH```H```!,&@``"````%<:```'````
M8!H```T```!H&@``"@```'8:```?````@1H```,```"A&@``!0```*4:```"
M````JQH```H```"N&@``!@```+D:```1````P!H```P```#2&@``"````-\:
M```)````Z!H``!````#R&@``!@````,;```5````"AL```D````@&P``#0``
M`"H;```)````.!L```@```!"&P``"@```$L;```,````5AL``!8```!C&P``
M!P```'H;```;````@AL```D```">&P``*0```*@;```&````TAL``!(```#9
M&P``!P```.P;```'````]!L```(```#\&P``!0```/\;```3````!1P```,`
M```9'```!@```!T<```(````)!P``!`````M'```!@```#X<```)````11P`
M``P```!/'```7````%P<```,````N1P``!0```#&'```"P```-L<```O````
MYQP```<````7'0``#P```!\=```F````+QT```<```!6'0``"````%X=```$
M````9QT```<```!L'0``#@```'0=```.````@QT```4```"2'0``#0```)@=
M```-````IAT```@```"T'0``!@```+T=```(````Q!T```4```#-'0``$```
M`-,=```0````Y!T```\```#U'0``"P````4>```/````$1X```P````A'@``
M#P```"X>```&````/AX```\```!%'@``'@```%4>```A````=!X```,```"6
M'@``"````)H>```'````HQX```0```"K'@```@```+`>```&````LQX```8`
M``"Z'@``!````,$>```$````QAX```4```#+'@``#````-$>```*````WAX`
M``4```#I'@``!P```.\>```*````]QX```\````"'P``&````!(?```6````
M*Q\``!(```!"'P``$````%4?```'````9A\```0```!N'P``!````',?```(
M````>!\```<```"!'P``"````(D?```)````DA\```P```"<'P``#0```*D?
M```.````MQ\``!8```#&'P``$0```-T?```)````[Q\``!X```#Y'P``$```
M`!@@```)````*2````@````S(```!@```#P@```'````0R````(```!+(```
M!````$X@```%````4R````\```!9(````P```&D@```'````;2````H```!U
M(```!P```(`@```)````B"````(```"2(```!@```)4@```%````G"````<`
M``"B(```%0```*H@```,````P"````4```#-(```"0```-,@```$````W2``
M``0```#B(```"@```.<@```(````\B````D```#[(```#`````4A```+````
M$B$```0````>(0``!0```",A```(````*2$```,````R(0``!P```#8A```'
M````/B$```H```!&(0``$0```%$A```%````8R$```@```!I(0``!P```'(A
M```>````>B$``!X```"9(0``!0```+@A```H````OB$``"D```#G(0``#```
M`!$B```3````'B(```L````R(@``#P```#XB```3````3B(``!,```!B(@``
M#P```'8B```,````AB(```X```"3(@``#0```*(B```-````L"(```D```"^
M(@``#P```,@B```+````V"(```@```#D(@``$@```.TB```1`````",```@`
M```2(P``$0```!LC```$````+2,```(````R(P``"````#4C```+````/B,`
M``H```!*(P``#````%4C```&````8B,``%@```!I(P``&@```,(C```7````
MW2,``!D```#U(P``&@````\D```9````*B0``"4```!$)```%P```&HD```=
M````@B0``!L```"@)```'P```+PD```3````W"0``$````#P)```"0```#$E
M```[````.R4``!\```!W)0``*````)<E```0````P"4``!<```#1)0``"@``
M`.DE```(````]"4```H```#])0``!P````@F```"````$"8```<````3)@``
M!@```!LF```%````(B8```D````H)@``"0```#(F```"````/"8``"\````_
M)@``'P```&\F```A````CR8``!P```"Q)@``"````,XF```*````UR8```D`
M``#B)@``!@```.PF```%````\R8```4```#Y)@``"````/\F```"````""<`
M``<````+)P``!````!,G```F````&"<```P````_)P``!P```$PG```.````
M5"<```P```!C)P``"````'`G```'````>2<```(```"!)P``"0```(0G```$
M````CB<```<```"3)P``!P```)LG```&````HR<``!0```"J)P``#0```+\G
M```+````S2<``$@```#9)P``3````"(H```,````;R@```H```!\*```"0``
M`(<H```"````D2@```8```"4*```%````)LH``!%````L"@``#````#V*```
M$````"<I```?````."D``!````!8*0``#P```&DI```-````>2D```4```"'
M*0``!0```(TI```%````DRD```X```"9*0``"````*@I```-````L2D```H`
M``"_*0``"````,HI```&````TRD```<```#:*0``!@```.(I```7````Z2D`
M``,````!*@``!@````4J```$````#"H```0````1*@``"````!8J```0````
M'RH``!,````P*@``$P```$0J```%````6"H```0```!>*@``"P```&,J```%
M````;RH```<```!U*@``=0$``'TJ```H````\RL``!8````<+```*@```#,L
M```(````7BP```4```!G+```#````&TL```(````>BP``!$```"#+```%```
M`)4L```2````JBP```P```"]+```!P```,HL```,````TBP```4```#?+```
M"@```.4L```:````\"P```\````++0``!0```!LM```$````(2T```X````F
M+0``"P```#4M```*````02T```H```!,+0``&@```%<M```.````<BT``!T`
M``"!+0``!````)\M```%````I"T```8```"J+0``"0```+$M```&````NRT`
M`!,```#"+0``#````-8M```'````XRT```@```#K+0``$P```/0M```&````
M""X``!4````/+@``!P```"4N```+````+2X```@````Y+@``"````$(N```,
M````2RX```H```!8+@``%P```&,N```%````>RX``!X```"!+@``"0```*`N
M```I````JBX```<```#4+@``$@```-PN```)````[RX```D```#Y+@```@``
M``,O```&````!B\``!@````-+P```P```"8O```'````*B\```@````R+P``
M$0```#LO```%````32\```@```!3+P``#P```%PO``!B````;"\```L```#/
M+P``$0```-LO```+````[2\``"X```#Y+P```P```"@P```+````+#```!\`
M```X,```"P```%@P```(````9#````<```!M,```"@```'4P```/````@#``
M``\```"0,```!0```*`P```.````IC````X```"U,```#@```,0P```)````
MTS```!$```#=,```!````.\P```0````]#```!`````%,0``#P```!8Q```/
M````)C$```T````V,0``#````$0Q```0````43$```D```!B,0``$@```&PQ
M```=````?S$``"(```"=,0```P```,`Q```'````Q#$```8```#,,0``!```
M`-,Q```"````V#$```8```#;,0``!P```.(Q```%````ZC$```4```#P,0``
M!````/8Q```-````^S$```X````),@``!0```!@R```'````'C(```H````F
M,@``$````#$R```:````0C(``!L```!=,@``$P```'DR```0````C3(```8`
M``">,@``!````*4R```$````JC(```@```"O,@``"````+@R```%````P3(`
M``T```#',@``#0```-4R```2````XS(``!0```#V,@``&P````LS```7````
M)S,```L````_,P``)P```$LS```-````<S,```0```"!,P``"@```(8S```(
M````D3,```<```":,P```@```*(S```$````I3,```0```"J,P``$````*\S
M```#````P#,```0```#$,P``"@```,DS```'````U#,```H```#<,P```@``
M`.<S```&````ZC,```4```#Q,P``"0```/<S```6`````30```\````8-```
M!0```"@T```+````+C0```<````Z-```!0```$(T```+````2#0```D```!4
M-```"0```%XT```/````:#0``!<```!X-```!0```)`T```'````EC0```@`
M``">-````@```*<T```'````JC0```0```"R-```#````+<T```1````Q#0`
M``4```#6-```!P```-PT```'````Y#0``!T```#L-```(`````HU```'````
M*S4``"@````S-0``*````%PU```)````A34``!(```"/-0``"0```*(U```0
M````K#4``!D```"]-0``%@```-<U```1````[C4```P`````-@``#@````TV
M```.````'#8```L````K-@``"@```#<V```1````0C8```D```!4-@``#```
M`%XV```7````:S8``!T```"#-@``!````*$V```0````IC8```4```"W-@``
M`@```+TV```&````P#8```P```#'-@``#@```-0V```*````XS8```,```#N
M-@``80```/(V```4````5#<```\```!I-P``%````'DW```=````CC<``!,`
M``"L-P``*P```,`W```0````[#<``"(```#]-P``&0```"`X```2````.C@`
M`!,```!-.```40```&$X```)````LS@``#L```"].```)@```/DX```A````
M(#D``!4```!".0``%0```%@Y```*````;CD```4```!Y.0``"0```'\Y```&
M````B3D```(```"0.0``!P```),Y```&````FSD```@```"B.0``"0```*LY
M```)````M3D```(```"_.0``'````,(Y```D````WSD``!T````$.@``%@``
M`"(Z```'````.3H```L```!!.@``"P```$TZ```&````63H```8```!@.@``
M!0```&<Z```(````;3H```(```!V.@``!P```'DZ```$````@3H``"@```"&
M.@``#P```*\Z```-````OSH``!$```#-.@``"@```-\Z```*````ZCH```@`
M``#U.@```@```/XZ```&`````3L```,````(.P``!@````P[```'````$SL`
M``@````;.P``%````"0[```-````.3L```T```!'.P``50```%4[``!3````
MJSL```P```#_.P``#`````P\```*````&3P```(````D/```!0```"<\```2
M````+3P``#P```!`/```-@```'T\```/````M#P``!T```#$/```$````.(\
M```0````\SP```P````$/0``!P```!$]```&````&3T```4````@/0``$@``
M`"8]```'````.3T```X```!!/0``"P```%`]```$````7#T```4```!A/0``
M`P```&<]```%````:ST``!4```!Q/0```P```(<]```'````BST```4```"3
M/0```P```)D]```)````G3T```T```"G/0``$````+4]```3````QCT```4`
M``#:/0```P```.`]```*````Y#T```0```#O/0```@```/0]```!````D@``
M`"(```#C````B@```,4```#D````,@```/<```"D```````````````H`0``
M_````"P!```O````9P```(X`````````4P`````````!`0``!P```/$`````
M````V`````X!````````!0$``%H````)````90```/0```"T````8@```!X!
M``#V`````````,\```!-````60```!4!````````2P```"X`````````-0``
M`!\```!)````J````-0```"O````)P$``#,````B`0``DP````````!_````
M"P$`````````````'0$``+X````&`0``=````%$`````````IP``````````
M````#@```"4!````````P````'L````<````NP````````"+````"0$``"$!
M````````=P````````"/````W0```"8!``#O````&P$```H```#A````K```
M`&H```"@````LP```(4`````````F0````````#H````?@```,(`````````
M`````+P``````````@```/(`````````<@```!4`````````QP```)````":
M``````````````#)````5P```)@````=````6````'$```````````````@!
M````````)`$```````!O`````````)\```",````&P````````"N````[0``
M`!(```">````=0```)$`````````PP```!H!```#````U0```*8```#6````
M4`````````#P````V@```*D````4``````````````#^````/0```!,```!C
M````2@```&L````Z`````````-(````M````&`$``*L`````````OP```"8`
M``!Y````AP```"D!``#_`````````(8````C````K0```'````!Z````Z@``
M`!(!```-`0```````%\``````````````$,````T````1P```$8```!@````
M&@```($````C`0``0@```-D````7`0```````-\```#N`````````,T```!I
M````+0$```````#[`````````*,`````````Y0```$\``````````````'8`
M``!]````!`````H!``"(`````````/@```#$`````````!D!```<`0``?```
M`*4````8````!`$``#$```#0`````````#8````1````#P$```````";````
MX````!D```!6`````````$0```"$````N````.<```"6````3@``````````
M`````````"L````````````````````3`0````````````#F````@@```"D`
M`````0``L@```-<```#,`````````,L````'`0``,````(````!X````]0``
M`+$```#.````9````+4```!``````````)T```!(````^@```!$!``!,````
M`````%4````E````P0``````````````%P```/T````#`0``W````"@````\
M````"````#D```#>``````````L```!N`````````&@```#I````;```````
M```J`0``5````(,```!!````6P`````````W````70```#@```#B````````
M```````_````%@```!8!``#&````<P```.L`````````E0`````````@````
M'P$``)P````-````L````*$```"4````MP`````````G`````````$4````A
M``````````````#(````C0```&$````,`0``#````+8```"Y`````````%X`
M```^````^0`````````>`````````&T````0`0```````+T```")````!0``
M`"`!``!F``````````(!```K`0````````````#1```````````````[````
MR@`````````````````````````L````!@```-,````/`````````-L```"7
M`````````!0!``#S```````````````D````4@```+H```"B````[```````
M````````J@```%P````J````$``````E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R
M=&5D`"H@061D('1H97-E(&)Y(&-L:6-K:6YG($%D9"`J`#(T(&AO=7)S`$%-
M+U!-`$%D7W9A;F-E9"!396%R8V@`061D`$%D9"!%=F5N=`!!9&0@82!N97<@
M979E;G0`061D(&%T=&5N9&5E<P!!9&0@<&%I<@!!9&1R97-S`$%D=F%N8V5D
M(%-E87)C:`!!;&%R;0!!;&%R;2!$871E`$%L87)M(%-P86X@*&UI;G5T97,I
M`$%L87)M(%1I;64`06QI87,`06QL`$%L;"!!='1E;F1E97,`06QL($9U='5R
M90!!;&P@4&%S=`!!;&P@9&%Y`$%L;"!D87D@979E;G0`06QL(&5V96YT<P!!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N>0!!<')I;`!!=`!!
M='1E;F1A;F-E`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!"87-I8R!396%R
M8V@`0FER=&AD87D`0U]A;&5N9&%R`$-A;&5N9&%R(%-U;6UA<GD`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YC96QL960`0V%N8V5L;&5D.B`E
M<P!#871E9V]R7WD`0V%T96=O<GD`0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`
M0V]M;6$@<V5P87)A=&5D('9A;'5E<P!#;VUP86YY`$-O;F9I<FT@9&5L971I
M;VX@;V8@979E;G1S/P!#;VYF:7)M960`0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,`0W)E871E`$-R96%T92!A($YE=R!%=F5N
M=`!#<F5A=&5D`$-U<G)E;G0`1$0`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E=F5R
M>0!$87D`1&%Y*',I`$1E8V5M8F5R`$1E9F%U;'0@261E;G1I='D`1&5L971E
M`$1E;&5T92`E<P!$96QE=&4@179E;G0`1&5L971E('1H92!C=7)R96YT(&5V
M96YT(&]N;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL(&9U='5R92!O8V-U
M<F5N8V5S+"!O<B!A;&P@;V-C=7)E;F-E<S\`1&5S8W)I7W!T:6]N`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L87D`1&ES<&QA
M>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1U93H@)7,`1'5R871I;VX`161I=`!%9&ET("5S`$5D:70@071T96YD
M965S`$5D:70@871T96YD965S`$5M86EL`$5M86EL($%D9')E<W,`16UP='D@
M<F5S=6QT+@!%;F0@1&%T90!%;F0@3VX`16YD(%1I;64`17)R;W(`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!%>'!O<G0`17AP;W)T($-A;&5N9&%R`$9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`1F%X`$9E8G)U87)Y`$9I;'1E<G,`1FEN9`!&<@!&<FED87D`
M1G5T=7)E`$=A;64`2&5L<`!(;U]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N
M90!(;W)D90!(;W5R*',I`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$EM
M<&]R="!#86QE;F1A<BP@4W1E<"`E9`!);7!O<G0O17AP;W)T($-A;&5N9&%R
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$IA;G5A<GD`
M2G5L>0!*=6YE`$ME>7=O<F1S`$QA7WEO=70`3&%N9W5A9V4`3&%S="!(86QF
M`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA
M<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%S="!W
M965K`$QI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.@!,:7-T($AE;'`@
M5&]P:6-S`$QO7V-A=&EO;@!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!-30!-
M86EL`$UA<F-H`$UA=&-H:6YG(&9I96QD<P!-87D`365E=&EN9P!-96YU(&UO
M9&4Z`$UE<W-A9V4`36EN=71E*',I`$UO`$UO;F1A>0!-;VYT:`!-;VYT:&QY
M`$UO;G1H;'DZ(%)E8W5R<R!E=F5R>0!->2!#86QE;F1A<G,`3F5V97(`3F5W
M($5V96YT`$YE=W,`3F5X=`!.97AT($UO;G1H`$YE>'0@9&%Y`$YE>'0@=V5E
M:P!.;R!A='1E;F1E97,`3F\@96YD(&1A=&4`3F]N90!.;W1E<P!.;W9E;6)E
M<@!.;W<`3V-T;V)E<@!/<'1I;VYS`$]R9V%N:7II;F<`3W1H97(@26YF;W)M
M871I;VX`3W=N97(`4&%S<W=O<F0`4&%T=&5R;@!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_
M`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4')E=FEO=7,@9&%Y`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5C=7(@56YT:6P`
M4F5C=7)R96YC92!$871A`%)E8W5R<F5N8V4@16YD($1A=&4`4F5C=7)R96YC
M92!);G1E<G9A;`!296-U<G)E;F-E(%1Y<&4`4F5C=7)S(&1A:6QY`%)E8W5R
M<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`4F5C=7)S('EE87)L>0!296UO=F4@
M)7,`4F5M;W9E($%T=&5N9&5E`%)E;6]V92!P86ER`%)E<75I<F5D`%)E<75I
M<F5D($%T=&5N9&5E<P!297-E="!T;R!$969A=6QT<P!297-P;VYS90!2971U
M<FX@=&\@3W!T:6]N<P!2;VQE`%-A`%-A='5R9&%Y`%-A=F4@07,@3F5W`%-A
M=F4@179E;G0`4V%V92!/<'1I;VYS`%-E87)C:`!396QE8W0@8V]N9FER;6%T
M:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE
M=W,@86YD(&-H;V]S92!D969A=6QT('9I97<N`%-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@
M97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L
M96-T('1H92!F:7)S="!W965K9&%Y.@!396QE8W0@=&AE(&9O<FUA="!O9B!T
M:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C
M="!T:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@
M4')O8FQE;2!297!O<G0`4V5N9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L
M;"!A='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N=`!397!T96UB97(`
M4VAO=R!D96QE=&4L(&%L87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I;B!C
M86QE;F1A<B!V:65W<S\`4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R
M/P!3:&]W(&]N;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S970_`%-K
M:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W1A<G0@
M1&%T90!3=&%R="!/;@!3=&%R="!4:6UE`%-T871?=7,`4W4`4W5C8V5S<P!3
M=6YD87D`5&%S:W,`5&5N=&%T:79E`%1E>'0@3VYL>0!4:`!4:&4@96YD(&1A
M=&4@;75S="!B92!L871E<B!T:&%N('1H92!S=&%R="!D871E+@!4:&5R92!W
M97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H
M=7)S9&%Y`%1I;64@4W!?86X`5&EM92!S<&%N`%1I=%]L90!4:71L90!4;V1A
M>0!4;VUO<G)O=P!4=0!4=65S9&%Y`%1Y<&4`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5N9FEL960`57-E
M<B!);G1E<F9A8V4`57-E<B!/<'1I;VYS`%5S97)N86UE`%=A<FYI;F<`5V4`
M5V5D;F5S9&%Y`%=E96L`5V5E:R`E9`!7965K*',I`%=E96ML>0!7965K;'DZ
M(%)E8W5R<R!E=F5R>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@
M=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R
M92!A<F4@;F\@;&%T97(@979E;G1S/P!7:&%T('1I;64@<VAO=6QD(&1A>2!A
M;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE
M<B!E=F5N=',_`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=O<FL@5V5E:P!9
M60!996%R;'D`665A<FQY.B!296-U<G,@979E<GD`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O
M9B`E<UT`7T)A<VEC(%-E87)C:`!?161I=`!?1V]T;P!?2&5L<`!?26UP;W)T
M+T5X<&]R=`!?3&]G(&]U=`!?37D@0V%L96YD87)S`%].97<@179E;G0`7T]P
M=&EO;G,`7U!R:6YT`%]396%R8V@`7U1O9&%Y`&)E9F]R92!T:&4@979E;G0@
M<W1A<G1S`&1A>0!D87DH<RD`9&%Y<P!F<F]M`&UO;G1H*',I`&]N('1H92!S
M86UE(&1A=&4`;VX@=&AE('-A;64@=V5E:V1A>0!V0V%L96YD87(O:4-A;&5N
M9&%R`'9#87)D`'=E96L`=V5E:RAS*2!O;CH`=V5E:W,`>65A<BAS*0!0<F]J
M96-T+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`Q+C$*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`T
M+3`U+3$X(#(S.C,W*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!!;F1R96%S($=U
M;FQE:6MS:V%A<R`\86YD<F5A<T!G=6YL96EK<VMA87,N;F\^"DQA;F=U86=E
M+51E86TZ($YO<G=E9VEA;B`H0F]K;6%L*2`\:3$X;D!L:7-T<RYH;W)D92YO
M<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:70*`"5S('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R("T@0F5K<F5F
M=&5L<V4`)7,@9FEL96X@8FQE(&EM<&]R=&5R=``J($QE9V<@=&EL(&1I<W-E
M('9E9"#E(&ML:6MK92`G3&5G9R!T:6PG("H`,C0@=&EM97(`04TO4$T`079A
M;G-E<G0@4_AK`$QE9V<@=&EL`$QE9V<@=&EL(&AE;F1E;'-E`$QE9V<@=&EL
M(&YY(&AE;F1E;'-E`$QE9V<@=&EL(&1E;'1A:V5R90!,96=G('1I;"!P87(`
M061R97-S90!!=F%N<V5R="!3^&L`06QA<FT`06QA<FT@1&%T;P!!;&%R;2!)
M;G1E<G9A;&P@*&UI;G5T=&5R*0!!;&%R;2!4:61S<'5N:W0`06QI87,`06QL
M90!!;&QE(&1E;'1A:V5R90!!;&P@9G)A;71I9`!!;&P@9F]R=&ED`$AE;&4@
M9&%G96X`2&5N9&5L<V5N('9A<F5R(&AE;&4@9&%G96X`06QL92!H96YD96QS
M97(`16X@=6QO=FQI9R!V97)D:2!V87(@;W!P9VET="X`06QL90!A<')I;`!+
M;&]K:V$`1&5L=&%K97)E`&%U9W5S=`!4:6QG:F5N9V5L:6=E(&9E;'0Z`%-T
M86YD87)D('/X:P!"=7)S9&%G`$MA;&5N9&5R`$MA;&5N9&5R('-A;6UE;F1R
M86<`079B<GET`$%V8G)Y="!P<F]B;&5M<F%P<&]R=`!!=F)R=71T`$%V8G)U
M='0Z("5S`$MA=&5G;W)I`$MA=&5G;W)I`$UO8FEL=&5L969O;@!,=6MK('9I
M;F1U`$MO;6UA('-E<&%R97)T92!V97)D:65R`$9I<FUA`$)E:W)E9G0@<VQE
M='1I;F<@878@:&5N9&5L<V5R/P!"96MR969T970`2V%N(&EK:V4@Y7!N92!-
M86EN=&5N86YC95]487-K+6UO9'5L970@)7,`3W!P<F5T=`!,86<@970@;GD@
M:&5N9&5L<V4`3W!P<F5T=&5T`$[E=N9R96YD90!$1`!$86=L:6<`2'9E<B!D
M86<Z(%-K:F5R(&AV97(@9&%G`$1A9P!$86<H97(I`&1E<V5M8F5R`%-T86YD
M87)D:61E;G1I=&5T`%-L971T`%-L971T("5S`%-L971T92!H96YD96QS90!3
M;&5T="!B87)E(&=J96QD96YD92!H96YD96QS92P@9&5N;F4@:&5N9&5L<V5N
M(&]G(&%L;&4@9G)E;71I9&EG92!H96YD96QS97(L(&5L;&5R(&%L;&4@:&5N
M9&5L<V5R/P!"97-K<FEV96QS90!"97-K<FEV('!R;V)L96UE=`!"97-K<FEV
M96QS90!$971A;&IE<B!H87(@8FQI='0@;&]G9V5T(&9O<B!A9&UI;FES=')A
M=&]R96XN`%9I<P!6:7-I;F=S=F%L9P!):VME(.5P;B!M86EN96YA;F-E+G!H
M<"!D:7)E:W1E`$9O<F9A;&PZ("5S`%9A<FEG:&5T`%)E9&EG97(`4F5D:6=E
M<B`E<P!%;F1R92!D96QT86ME<F4`16YD<F4@9&5L=&%K97)E`&5P;W-T`$4M
M<&]S="!A9')E<W-E`%1O;70@<F5S=6QT870N`$%V<VQU='1E<R!D871O`$%V
M<VQU='1E<P!!=G-L=71T97,@:VQO:VME;@!&96EL`$AV97)T(#$U+B!M:6YU
M='0`2'9E<G0@,S`N('-E:W5N9`!(=F5R="`U+B!M:6YU='0`2'9E<B!I;FYL
M;V=G:6YG`$AV97(@:&%L=G1I;64`2'9E<G0@;6EN=71T`$5K<V5M<&5L=F5R
M9&EE<CH`16MS<&]R=&5R`$5K<W!O<G1E<B!K86QE;F1E<@!+86X@:6MK92!E
M;F1R92!I;G-T:6QL96EN9V5R+@!4:6QK;V)L:6YG('1I;"!,1$%0+7-E<G9E
M<B!F96EL970N`$9A>`!F96)R=6%R`$9I;'1E<@!&:6YN`$9R`$9R961A9P!&
M<F5M=&ED`%-P:6QL`$AJ96QP`$AJ96T`2&IE;6UE861R97-S90!496QE9F]N
M(&AJ96UM90!(;W)D90!4:6UE*'(I`$MU;B!I:V]N97(`26MO;F5R(&UE9"!T
M96MS=`!);7!O<G1E<B!K86QE;F1E<BP@<W1E9R`E9`!);7!O<G1E<B]%:W-P
M;W)T97(@2V%L96YD97(`26UP;W)T97)T92!F96QT.B`E<P!);7!O<G1E<G1E
M(&9E;'0Z`&IA;G5A<@!J=6QI`&IU;FD`4W1I:VMO<F0`571S965N9&4`4W!R
MY6L`4VES=&4@:&%L=&EM90!3:7-T92!K=F%R=&5R`%-I<W1E(&]P<&1A=&5R
M:6YG.@!3:7-T92!I;FYL;V=G:6YG.B`E<P!3:7-T92!I;FYL;V=G:6YG.B`E
M<R!F<F$@)7,`4VES=&4@:6YN;&]G9VEN9SH@06QD<FD`1F]R<FEG92!U:V4`
M079G<F5N<R!T:61S:6YT97)V86QL(&9O<B!E:W-P;W)T97)I;F<Z`$5M;F5R
M(&D@2&IE;'``4W1E9`!0;&%S<V5R:6YG`$QO9V<@:6YN`$QO9V<@=70`34T`
M4&]S=`!M87)S`%-A;7-V87)E;F1E(&9E;'0`;6%I`$WX=&4`365N>6UO9'5S
M.@!-96QD:6YG`$UI;G5T="AE<BD`36$`36%N9&%G`$WE;F5D`$WE;F5D=&QI
M9P!(=F5R(&WE;F5D.B!3:VIE<B!H=F5R`$UI;F4@:V%L96YD97)E<@!!;&1R
M:0!.>2!H96YD96QS90!.>6AE=&5R`$YE<W1E`$YE<W1E(&WE;F5D`$YE<W1E
M(&1A9P!.97-T92!U:V4`26YG96X@9&5L=&%K97)E`$EN9V5N(&%V<VQU='1N
M:6YG<R!D871O`$EN9V5N`$YO=&%T97(`;F]V96UB97(`3N4`;VMT;V)E<@!6
M86QG`$]R9V%N:7-E<FEN9P!!;FYE;B!I;F9O<FUA<VIO;@!%:6=E<@!087-S
M;W)D`$WX;G-T97(`571F^'(@=F5D;&EK96AO;&1S;W!E<F%S:F]N97(`4VQE
M='0@9&5N;F4@:&5N9&5L<V5N('!E<FUA;F5N=#\`5&5L969O;@!696YN;&EG
M<W0@9VD@970@<V%M;65N9')A9R!A=B!P<F]B;&5M970N`%9E;FYL:7-T('-K
M<FEV(&EN;B!B<G5K97)N879N(&]G('!A<W-O<F0`3F5S=&4@9&%G`%!R;V)L
M96UB97-K<FEV96QS90!!=G-L=71T97,`1VIE;G1A9V5N9&4@9&%T;P!3;'5T
M="!D871O(&9O<B!G:F5N=&%G:6YG`$=J96YT86=E;'-E<R!I;G1E<G9A;&P`
M1VIE;G1A9V5L<V5S('1Y<&4`4VMJ97(@9&%G;&EG`%-K:F5R(&WE;F5D;&EG
M`%-K:F5R('5K96YT;&EG`%-K:F5R(.5R;&EG`%1A(&)O<G0@)7,`5&$@8F]R
M="!D96QT86ME<F4`1FIE<FX@<&%R`$]B;&EG871O<FES:P!/8FQI9V%T;W)I
M<VME(&1E;'1A:V5R90!.=6QL<W1I;&P@=&EL('-T86YD87)D=F5R9&EE<@!3
M=F%R`%1I;&)A:V4@=&EL(%9A;&<`4F]L;&4`3/@`3/AR9&%G`$QA9W)E('-O
M;2!N>0!,86=R92!H96YD96QS90!,86=R92!686QG`%/X:P!696QG('9A;&<@
M9F]R(&)E:W)E9G1E;'-E+"!H=F]R9&%N(&1E('5L:6ME('9I<VEN9V5N92!S
M:V%L('!R97-E;G1E<F5S(&]G('9E;&<@96X@<W1A;F1A<F1V:7-I;F<N`%9E
M;&<@9&%T;W-K:6QL971E9VXZ`%9E;&<@9&%T;V9O<FUA=`!696QG(&5K<W!O
M<G0@9F]R;6%T.@!696QG(&9I;"!S;VT@<VMA;"!I;7!O<G1E<F5S.@!696QG
M(&;X<G-T92!U:V5D86<Z`%9E;&<@9F]R;6%T970@<.4@9FEL96X@<V]M('-K
M86P@:6UP;W)T97)E<SH`5F5L9R!T:61S9F]R;6%T.@!696QG('1I9'-I;G1E
M<G9A;&P@<V]M('-K86P@=FES97,Z`%9E;&<@=&\@<V%M<W9A<F5N9&4@9F5L
M="X`5F5L9R#X;G-K970@<W!RY6LZ`%-E;F0@<')O8FQE;7)A<'!O<G0`4V5N
M9"!O<'!D871E<FEN9V5R+VEN=FET87-J;VYE<B!T:6P@86QL92!D96QT86ME
M<F4@=F5D(&QA9W)I;F<@878@9&5N;F4@:&5N9&5L<V5N`'-E<'1E;6)E<@!6
M:7,@<VQE='0M+"!A;&%R;2T@;V<@9VIE;G1A9V5L<V5S:6MO;F5R(&D@:V%L
M96YD97)V:7-N:6YG/P!6:7,@;W!P9V%V97(@=&EL(&9O<F9A;&P@:2!K86QE
M;F1E<F5N/P!6:7,@8F%R92!H96YD96QS97(@<V]M(&AA<B!A;&%R;3\`2&]P
M<"!O=F5R('9E9&QI:V5H;VQD`%-P97-I86QT96=N:6YN=&%S=&EN9P!3=&%R
M="!D871O`%-T87)T`%-T87)T('1I9`!3=&%T=7,`4_@`4W5K<V5S<P!3^&YD
M86<`3W!P9V%V97(`1F]R96SX<&EG`$MU;B!T96MS=`!4;P!+86X@:6MK92!A
M=G-L=71T92!F^'(@<W1A<G0N`$1E="!E<B!I;F=E;B!H96YD96QS97(@Y2!E
M:W-P;W)T97)E+@!$971T92!T86QL970@;>4@=N9R92!M:6YS="`Q+@!$971T
M92!MY2!VYG)E(&5T('1A;&PN`%1O<G-D86<`5&ED<W!E<FEO9&4`5&ED<W!E
M<FEO9&4`5&ET=&5L`%1I='1E;`!)(&1A9P!)(&UO<F=E;@!4:0!4:7)S9&%G
M`%1Y<&4`2V%N(&EK:V4@;W9E<G-E='1E(&1E='1E(%=O<F0M9&]K=6UE;G1E
M=`!!;F=R92!E;F1R:6YG97(`56ML87-S:69I<V5R=`!"<G5K97)G<F5N<V5S
M;FET=`!,86=R92!686QG`$)R=6ME<FYA=FX`061V87)S96P`3VX`3VYS9&%G
M`%5K90!5:V4@)60`56ME*&5R*0!5:V5N=&QI9P!5:V5N=&QI9SH@4VMJ97(@
M:'9E<@!696QK;VUM96XL("5S`%9E;&MO;6UE;BP@)7,`2VQO:VME<VQE='0@
M9&%G+2!O9R!U:V5V:7-I;F=E<B!V:7-E<R!F<F5M('1I;"P@;VT@9&5T(&EK
M:V4@97(@;F]E;B!S96YE<F4@:&5N9&5L<V5R/P!+;&]K:V5S;&5T="!D86<M
M(&]G('5K979I<VEN9V5R('9I<V5S(&9R82P@;VT@9&5T(&EK:V4@97(@;F]E
M;B!T:61L:6=E<F4@:&5N9&5L<V5R/P!&:7)M86%D<F5S<V4`1FER;6%T96QE
M9F]N`$%R8F5I9'-U:V4`Y>4`Y7)L:6<`Q7)L:6<Z(%-K:F5R(&AV97)T`$1U
M(&WE(&)E<VMR:79E('!R;V)L96UE="!F^'(@9'4@:V%N('-E;F1E(&5N('!R
M;V)L96UR87!P;W)T+@!$:6X@)7,@=&EL:V]B:6YG(&AA<B!GY71T('5T+B!6
M96YN;&EG<W0@;&]G(&EN;B!I9VIE;BX`1&EN(&EN9F]R;6%S:F]N`$1I;F4@
M=F%L9R!H87(@8FQI='0@;W!P9&%T97)T`%M0<F]B;&5M<F%P<&]R=%T`6VQI
M;FIE("5S(&%V("5S70!3=&%N9&%R9"!S^&L`4F5D:6=E<@!'Y2!T:6P`2&IE
M;'``26UP;W)T97(O16MS<&]R=&5R`$QO9V<@=70`36EN92!K86QE;F1E<F4`
M3GD@:&5N9&5L<V4`5F%L9P!0<FEN=`!3^&L`22!D86<`9OAR(&AE;F1E;'-E
M;B!S=&%R=&5R`&1A9P!D86<H97(I`&1A9V5R`&9R80!MY6YE9"AE<BD`<.4@
M<V%M;64@9&%T;P!PY2!S86UM92!U:V4@9&%G`'9#86QE;F1E<B]I0V%L96YD
M97(`=D-A<F0`=6ME`'5K92AR*2!PY3H`=6ME<@#E<@`````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O;FQ?3DPO
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-3(`,#(P-C<U`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L
M:71H+VQO8V%L92]N;%].3"],0U]-15-304=%4R\`````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,@`P,C(T-C(`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+VYL7TY,+TQ#7TU%4U-!1T53
M+VMR;VYO;&ET:"YM;P```````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#`S,3,U`#$P-#$W,S8R-S4R`#`R
M-3`S,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25`````(<'```<````5#P``!,*``",>````````-B@```.````V:``
M``\```#HH```"````/B@```,`````:$```0````.H0``#````!.A```)````
M(*$```\````JH0``"P```#JA```?````1J$```X```!FH0``!0```'6A```H
M````>Z$```H```"DH0``%0```*^A```2````Q:$```L```#8H0``#````.2A
M```=````\:$```X````/H@``"@```!ZB```-````*:(```X````WH@``$0``
M`$:B```-````6*(```P```!FH@``#0```'.B```&````@:(``!T```"(H@``
M'0```*:B```/````Q*(``!@```#4H@``#````.VB```*````^J(```<````%
MHP``#@````VC```.````'*,```@````KHP``+@```#2C```:````8Z,``#(`
M``!^HP``.````+&C``!4````ZJ,``%$````_I```6@```)&D``!7````[*0`
M`#0```!$I0```@```'FE```*````?*4```4```"'I0``!@```(VE```1````
ME*4```@```"FI0``"0```*^E```)````N:4```@```##I0``)0```,RE```@
M````\J4``!`````3I@``#P```"2F```*````-*8``!`````_I@```P```%"F
M```/````5*8``!0```!DI@``"0```'FF```)````@Z8```T```"-I@``$@``
M`)NF```9````KJ8```\```#(I@``#P```-BF```-````Z*8```H```#VI@``
M#P````&G```(````$:<``"0````:IP``%````#^G```6````5*<```@```!K
MIP``&0```'2G```'````CJ<```P```"6IP``+````*.G```.````T*<```,`
M``#?IP``#P```..G```+````\Z<```4```#_IP``%`````6H```5````&J@`
M`!<````PJ```%0```$BH```2````7J@``!,```!QJ```%0```(6H```3````
MFZ@```H```"OJ```%````+JH```*````SZ@```<```#:J```!P```.*H```%
M````ZJ@```4```#PJ```"@```/:H```#`````:D```T````%J0``%P```!.I
M```*````*ZD```H````VJ0``"````$&I```/````2JD```L```!:J0``!P``
M`&:I```-````;JD```H```!\J0``#@```(>I```8````EJD``",```"OJ0``
M#@```-.I```4````XJD``!<```#WJ0``%P````^J```7````)ZH``!,````_
MJ@``#P```%.J```.````8ZH``!\```!RJ@``!P```)*J```&````FJH```@`
M``"AJ@``#P```*JJ```&````NJH```H```#!J@``$P```,RJ```#````X*H`
M``L```#DJ@``%0```/"J```5````!JL```<````<JP``!0```"2K```5````
M*JL``!$```!`JP``#````%*K```[````7ZL```D```";JP``!P```*6K```4
M````K:L```,```#"JP``!0```,:K```0````S*L```D```#=JP``$P```.>K
M```Y````^ZL``!(````UK````@```$BL``"T````2ZP``"<`````K0``+```
M`"BM```J````5:T``"4```"`K0``"@```*:M```)````L:T```H```"[K0``
M!@```,:M```)````S:T```<```#7K0``+P```-^M```W````#ZX``"X```!'
MK@``50```':N```M````S*X``"T```#ZK@``+0```"BO``!`````5J\``",`
M``"7KP``(P```+NO```M````WZ\``#,````-L```%0```$&P```9````5[``
M`"D```!QL```)````)NP```1````P+````H```#2L```#````-VP```*````
MZK```!````#UL```%@````:Q```6````';$```<````TL0``!P```#RQ```4
M````1+$```H```!9L0``"````&2Q```(````;;$```P```!VL0``!P```(.Q
M```'````B[$```8```"3L0``!0```)JQ```'````H+$```8```"HL0``"```
M`*^Q```I````N+$```X```#BL0``"@```/&Q```$````_+$```<````!L@``
M"0````FR```&````$[(``!$````:L@``!P```"RR```6````-+(```0```!+
ML@``"````%"R```&````6;(```T```!@L@``!@```&ZR```>````=;(``!$`
M``"4L@``"````*:R```-````K[(```P```"]L@``!P```,JR```$````TK(`
M``,```#7L@```P```-NR```7````W[(```D```#WL@``$P````&S```)````
M%;,```@````?LP``$````"BS```)````.;,```0```!#LP``"````$BS```(
M````4;,``$$```!:LP``(````)RS```9````O;,```8```#7LP``!@```-ZS
M```5````Y;,```D```#[LP``#0````6T```8````$[0``"(````LM```+@``
M`$^T```=````?K0``"$```"<M```5````+ZT```I````$[4```H````]M0``
M!P```$BU```)````4+4``!4```!:M0``"````'"U```.````>;4```H```"(
MM0``#P```).U```-````H[4```\```"QM0``#0```,&U```)````S[4``!0`
M``#9M0``!@```.ZU```8````];4``!T````.M@``$P```"RV```4````0+8`
M``0```!5M@``!@```%JV``!4````8;8```0```"VM@``#@```+NV```%````
MRK8```4```#0M@``&P```-:V```:````\K8``!$````-MP``$0```!^W```<
M````,;<``"H```!.MP``-@```'FW```=````L+<``!````#.MP``(0```-^W
M```%`````;@``!,````'N```$@```!NX```*````+K@```\````YN```$0``
M`$FX```3````6[@```P```!ON```!@```'RX```&````@[@``!<```"*N```
M$0```**X```(````M+@```4```"]N```#````,.X```0````T+@```4```#A
MN```#0```.>X```&````];@``!8```#\N```!P```!.Y```-````&[D```<`
M```IN0``"P```#&Y```'````/;D```<```!%N0``"0```$VY```*````5[D`
M`!D```!BN0``#````'RY```0````B;D``!L```":N0``"0```+:Y```%````
MP+D``"4```#&N0``$@```.RY```3````_[D``"L````3N@``.P```#^Z```@
M````>[H``#8```"<N@``"````-.Z```,````W+H```8```#IN@``!````/"Z
M```.````];H``$`````$NP``"@```$6[```-````4+L``!X```!>NP``&P``
M`'V[```A````F;L``!X```"[NP``&0```-J[```>````]+L``!L````3O```
M)@```"^\```;````5KP``!X```!RO```'````)&\```F````KKP``#,```#5
MO```)@````F]```K````,+T``#@```!<O0``+P```)6]```2````Q;T``"D`
M``#8O0``$@````*^``"B````%;X``!8```"XO@``(P```,^^```H````\[X`
M`"D````<OP``*````$:_```?````;[\``"````"/OP``)0```+"_```A````
MUK\``!P```#XOP``)@```!7```!!````/,````P```!^P```!P```(O````'
M````D\````8```";P```$@```*+````-````M<```!````##P```$@```-3`
M```'````Y\```!,```#OP```$@````/!```'````%L$```0````>P0``!P``
M`"/!```,````*\$```X````XP0``#P```$?!```3````5\$```T```!KP0``
M*````'G!```#````HL$```T```"FP0``!@```+3!```1````N\$``!<```#-
MP0``&P```.7!```.`````<(```(````0P@``!0```!/"```3````&<(``!``
M```MP@``!````#["```-````0\(```X```!1P@```P```&#"```&````9,(`
M``<```!KP@``#@```'/"```(````@L(```\```"+P@``"````)O"```/````
MI,(``!````"TP@``#0```,7"```0````T\(```L```#DP@``!@```/#"```)
M````]\(```P````!PP``#`````[#```1````&\,``!D````MPP``"P```$?#
M```-````4\,``"(```!APP``"@```(3#```8````C\,``!D```"HPP``7```
M`,+#```6````'\0```T````VQ```!P```$3$```,````3,0``!0```!9Q```
M"P```&[$```B````>L0``"\```"=Q```"P```,W$```)````V<0``!D```#C
MQ```"P```/W$```7````"<4``!<````AQ0``"0```#G%```'````0\4``!8`
M``!+Q0``#P```&+%```6````<L4```X```")Q0``&````)C%```(````L<4`
M``T```"ZQ0``)@```,C%```Y````[\4```X````IQ@``0P```#C&```(````
M?,8``!(```"%Q@``"````)C&```+````H<8``"\```"MQ@``#@```-W&```%
M````[,8```<```#RQ@``"````/K&```&`````\<```,````*QP``!P````['
M```$````%L<```<````;QP``#@```"/'```*````,L<```H````]QP``#P``
M`$C'```0````6,<``!<```!IQP``%0```(''```.````E\<``!H```"FQP``
M$0```,''```7````T\<```D```#KQP``!0```/7'```+````^\<```H````'
MR````@```!+(```%````%<@```T````;R```&P```"G(```7````1<@```D`
M``!=R```#@```&?(```-````=L@``!(```"$R```.````)?(```@````T,@`
M``@```#QR```!@```/K(```(`````<D```@````*R0``#@```!/)``![````
M(LD``!@```">R0``$0```+?)```'````R<D```4```#1R0``,0```-?)```9
M````"<H```<````CR@``"````"O*```&````-,H```8````[R@``$P```$+*
M```0````5LH```\```!GR@``$````'?*```/````B,H```L```"8R@``#P``
M`*3*```,````M,H```\```#!R@``!P```-'*```&````V<H```P```#@R@``
M*````.W*```/````%LL```@````FRP``!@```"_+```/````-LL```@```!&
MRP``$P```$_+```>````8\L``"$```""RP``(````*3+```9````Q<L``!<`
M``#?RP``)0```/?+```7````'<P```0````US```&P```#K,```-````5LP`
M``,```!DS```"````&C,```*````<<P```P```!\S```"P```(G,```$````
ME<P``!,```":S```%````*[,```,````P\P```D```#0S```#@```-K,```+
M````Z<P``!L```#US```!P```!'-```$````&<T```<````>S0``"@```";-
M```-````,<T```D````_S0``!````$G-```%````3LT```,```!4S0``&```
M`%C-```*````<<T```0```!\S0``)@```('-```.````J,T``'P```"WS0``
M%0```#3.```%````2LX```<```!0S@``#````%C.```(````9<X```H```!N
MS@``!@```'G.```(````@,X```(```")S@``!@```(S.```&````D\X``!0`
M``":S@``#0```*_.```0````O<X``!L```#.S@``!@```.K.```$````\<X`
M``D```#VS@``$`````#/```)````$<\```D````;SP``!@```"7/```%````
M+,\``!H````RSP``"````$W/```&````5L\```0```!=SP``!P```&+/```9
M````:L\```X```"$SP``!P```)//```'````F\\```4```"CSP``"0```*G/
M```*````L\\```(```"^SP``!@```,'/```-````R,\```<```#6SP``"0``
M`-[/```&````Z,\``!(```#OSP``"0````+0```'````#-```!0````4T```
M'0```"G0```&````1]````H```!.T```!````%G0```)````7M````@```!H
MT```$0```''0```)````@]````8```"-T```#0```)30```&````HM````0`
M``"IT```.0```*[0```]````Z-```#H````FT0``'@```&'1```%````@-$`
M``X```"&T0``!````)71```&````FM$``"$```"AT0``%0```,/1```&````
MV=$```0```#@T0``$0```.71```&````]]$```H```#^T0``(@````G2```$
M````+-(```4````QT@``'0```#?2```$````5=(```P```!:T@``"@```&?2
M```(````<M(```D```![T@``!0```(72```Z````B](``#````#&T@``-0``
M`/?2```I````+=,``$<```!7TP``.````)_3```I````V-,``#\````"U```
M+@```$+4```M````<=0``!\```"?U```#P```+_4```2````S]0```L```#B
MU```!P```.[4```F````]M0``"D````=U0``)````$?5```F````;-4```@`
M``"3U0``"@```)S5```)````I]4```<```"QU0``(````+G5```@````VM4`
M`"8```#[U0``"@```"+6```9````+=8``"D```!'U@``%@```''6```2````
MB-8```<```";U@``"@```*/6```/````KM8``!````"^U@``0````,_6``!P
M````$-<``&8```"!UP``#@```.C7```)````]]<```H````!V```$@````S8
M```3````']@```P````SV```!@```$#8```8````1]@```\```!@V```%@``
M`'#8```2````A]@``!````":V```$0```*O8```<````O=@``",```#:V```
M:@```/[8```/````:=D```4```!YV0``$````'_9```)````D-D```0```":
MV0``"P```)_9```4````J]D```P```#`V0``#````,W9```/````VMD``!4`
M``#JV0``*0````#:```J````*MH``"8```!5V@``)P```'S:```I````I-H`
M`"H```#.V@``&0```/G:``!"````$]L``!$```!6VP``$@```&C;```3````
M>]L``!0```"/VP``#P```*3;```6````M-L``!<```#+VP``$````./;```1
M````]-L``#0````&W```$P```#O<```2````3]P``#4```!BW```%````)C<
M```'````K=P```P```"UW```(````,+<```4````X]P``!$```#XW```%P``
M``K=```<````(MT``!,````_W0``$0```%/=```:````9=T``!X```"`W0``
M&@```)_=```1````NMT``!0```#,W0``%P```.'=```5````^=T```D````/
MW@``&0```!G>```$````,]X```<````XW@``"P```$#>```1````3-X```8`
M``!>W@``!@```&7>```&````;-X```4```!SW@``!P```'G>```'````@=X`
M``4```")W@``%@```(_>```&````IMX```8```"MW@``!````+3>```$````
MN=X```<```"^W@``#@```,;>```,````U=X```P```#BW@``#0```._>```*
M````_=X```X````(WP``!0```!??```H````'=\```X```!&WP``#````%7?
M```/````8M\```H```!RWP``"````'W?```)````AM\``"L```"0WP``"```
M`+S?```$````Q=\```@```#*WP``)@```-/?```2````^M\```\````-X```
M!@```!W@```*````).````<````OX```"````#?@```@````0.````T```!A
MX```"0```&_@```-````>>````H```"'X```#````)+@```-````G^````X`
M``"MX```%@```+S@```1````T^````D```#EX```!@```._@```#````]N``
M``8```#ZX```&0````'A```'````&^$```0````CX0``"P```"CA```+````
M-.$```<```!`X0``!P```$CA```6````4.$```T```!GX0``#0```'7A```*
M````@^$``!````".X0``#P```)_A```1````K^$``!<```#!X0``"@```-GA
M```1````Y.$```@```#VX0``'@```/_A```$````'N(```\````CX@``.@``
M`#/B```%````;N(```P```!TX@``'@```('B```.````H.(``!````"OX@``
M"P```,#B```,````S.(```D```#9X@``!P```./B```*````Z^(```D```#V
MX@``#@````#C```0````#^,``!H````@XP``"@```#OC```)````1N,```D`
M``!0XP``"@```%KC```,````9>,```\```!RXP``"````(+C```&````B^,`
M``<```"2XP``"P```)KC``!'````IN,```T```#NXP``"0```/SC```$````
M!N0```,````+Y```$P````_D```3````(^0``!,````WY```"@```$OD```"
M````5N0```0```!9Y```)0```%[D```#````A.0```4```"(Y```*@```([D
M```*````N>0```4```#$Y```!````,KD```*````S^0```T```#:Y```!@``
M`.CD```(````[^0```@```#XY```!`````'E```%````!N4``!@````,Y0``
M:````"7E```)````CN4```P```"8Y0``!0```*7E```&````J^4``!L```"R
MY0``+P```,[E```0````_N4```H````/Y@``#P```!KF```*````*N8```D`
M```UY@``$P```#_F```;````4^8``!@```!OY@``%P```(CF```.````H.8`
M``,```"OY@``!P```+/F```(````N^8```<```#$Y@``!P```,SF```)````
MU.8```H```#>Y@``"P```.GF```'````]>8``%$```#]Y@``$````$_G```,
M````8.<```T```!MYP``&@```'OG``!*````EN<```8```#AYP``!@```.CG
M```&````[^<``!\```#VYP``!@```!;H```)````'>@``!@````GZ```%P``
M`$#H```)````6.@```8```!BZ```#0```&GH```2````=^@``"(```"*Z```
M5P```*WH```3````!>D``",````9Z0``$P```#WI```"````4>D```L```!4
MZ0``"````&#I```-````:>D```H```!WZ0``!P```(+I```4````BND```8`
M``"?Z0``!@```*;I```(````K>D```4```"VZ0``"@```+SI```.````Q^D`
M``<```#6Z0``$P```-[I```5````\ND```P````(Z@``#0```!7J```*````
M(^H```L````NZ@``!P```#KJ```,````0NH```T```!/Z@``#````%WJ```)
M````:NH```D```!TZ@``"@```'[J```'````B>H```D```"1Z@``!P```)OJ
M```*````H^H``!L```"NZ@``0@```,KJ```2````#>L```H````@ZP``#```
M`"OK```-````..L``!````!&ZP``"0```%?K```0````8>L```<```!RZP``
M$@```'KK```$````C>L```<```"2ZP``!0```)KK```%````H.L```L```"F
MZP``%````++K```1````Q^L``!H```#9ZP``%@```/3K```4````"^P``!<`
M```@[```&````#CL```<````4>P``!D```!N[```!P```(CL```%````D.P`
M``T```"6[```#````*3L```)````L>P```@```"[[```%P```,3L```+````
MW.P``!,```#H[```!````/SL```*`````>T```0````,[0``#0```!'M```(
M````'^T```H````H[0``"0```#/M```(````/>T```P```!&[0``"0```%/M
M```)````7>T```4```!G[0``!P```&WM```%````=>T```0```![[0``#```
M`(#M```X````C>T``"P```#&[0``$@```//M```I````!NX``#(````P[@``
M)0```&/N```*````B>X``"P```"4[@``+@```,'N```S````\.X``#,````D
M[P``.````%CO```/````D>\``!@```"A[P``"P```+KO```4````QN\``!``
M``#;[P``+````.SO```<````&?```!,````V\```%````$KP```2````7_``
M`!0```!R\```%0```(?P```M````G?```"T```#+\```,0```/GP```N````
M*_$``"\```!:\0``+````(KQ``!B````M_$``!,````:\@``"````"[R```(
M````-_(``"L```!`\@``(0```&SR```:````CO(``!P```"I\@``"0```,;R
M``!%````T/(``$$````6\P``!````%CS```3````7?,``!0```!Q\P``#@``
M`(;S```3````E?,``!@```"I\P``!@```,+S```)````R?,```H```#3\P``
M#P```-[S```)````[O,``!````#X\P``!P````GT```.````$?0```4````@
M]```&P```";T```(````0O0```,```!+]```!@```$_T```4````5O0``!$`
M``!K]```#@```'WT```X````C/0```(```#%]```!@```,CT```.````S_0`
M``4```#>]```!P```.3T```.````[/0```8```#[]```!`````+U```I````
M!_4``!<````Q]0``'P```$GU``!<````:?4``!0```#&]0``/@```-OU```?
M````&O8``!`````Z]@``"````$OV```'````5/8```X```!<]@``#````&OV
M```,````>/8``!,```"%]@``"@```)GV```=````I/8``!D```#"]@``!0``
M`-SV```1````XO8```4```#T]@``$0```/KV```D````#/<``!4````Q]P``
M$@```$?W```.````6O<``!D```!I]P``"````(/W```)````C/<```(```"6
M]P``#0```)GW```*````I_<```L```"R]P``"@```+[W```'````R?<```@`
M``#1]P``!0```-KW```?````X/<```T`````^```!@````[X```0````%?@`
M``@````F^```#0```"_X```(````/?@``!(```!&^```+````%GX```:````
MAO@```D```"A^```"@```*OX```5````MO@``!````#,^```!0```-WX```4
M````X_@```0```#X^```!P```/WX```0````!?D```8````6^0``!P```!WY
M```>````)?D``"@```!$^0``'@```&WY```*````C/D``!$```"7^0``"P``
M`*GY```:````M?D``!0```#0^0``!````.7Y```$````ZOD```L```#O^0``
M!0```/OY```&`````?H```@````(^@``!@```!'Z```*````&/H``!L````C
M^@``-````#_Z```T````=/H``"````"I^@``*0```,KZ```@````]/H``$$`
M```5^P``&@```%?[```H````<OL``"D```";^P``(@```,7[```&````Z/L`
M``@```#O^P``!0```/C[```.````_OL```@````-_```&0```!;\```9````
M,/P``"H```!*_```(P```'7\```N````F?P``#0```#(_```"````/W\```7
M````!OT```H````>_0``!P```"G]```A````,?T```P```!3_0``#0```&#]
M```,````;OT``!````![_0``#@```(S]```+````F_T```<```"G_0``$P``
M`*_]```(````P_T```L```#,_0``"@```-C]```4````X_T``#(```#X_0``
M"P```"O^```%````-_X```4````]_@``%P```$/^```/````6_X```0```!K
M_@``"@```'#^```)````>_X```L```"%_@``#@```)'^```%````H/X```0`
M``"F_@``#0```*O^```R````N?X``$4```#L_@``"P```#+_```*````/O\`
M``\```!)_P``$P```%G_```3````;?\```\```"!_P``#````)'_```.````
MGO\```T```"M_P``#0```+O_```7````R?\``!X```#A_P``%````````0`%
M````%0`!`!0````;``$`!P```#```0`,````.``!`!````!%``$`$0```%8`
M`0`.````:``!`"H```!W``$`!@```*(``0`)````J0`!``\```"S``$`#```
M`,,``0`-````T``!`!$```#>``$`"P```/```0`V````_``!``H````S`0$`
M(@```#X!`0`+````80$!``\```!M`0$`,@```'T!`0`(````L`$!`!(```"Y
M`0$`!0```,P!`0`.````T@$!`!,```#A`0$`$0```/4!`0`(````!P(!``<`
M```0`@$`$0```!@"`0`'````*@(!`!0````R`@$`&````$<"`0`'````8`(!
M``4```!H`@$`#````&X"`0`,````>P(!`!(```"(`@$`!````)L"`0`'````
MH`(!``H```"H`@$`"P```+,"`0`,````OP(!``X```#,`@$`#@```-L"`0`%
M````Z@(!``4```#P`@$`+@```/8"`0`F````)0,!`",```!,`P$``P```'`#
M`0`2````=`,!``8```"'`P$`'@```(X#`0`8````K0,!`"4```#&`P$`#0``
M`.P#`0`)````^@,!``,````$!`$`!P````@$`0`*````$`0!``(````;!`$`
M#````!X$`0`5````*P0!``L```!!!`$`&0```$T$`0`@````9P0!`!(```"(
M!`$`!0```)L$`0`*````H00!`!4```"L!`$`$@```,($`0`(````U00!``P`
M``#>!`$`!P```.L$`0`+````\P0!``H```#_!`$`#`````H%`0!2````%P4!
M`!<```!J!0$`!P```((%`0`&````B@4!``X```"1!0$`#````*`%`0`-````
MK04!`!4```"[!0$`$@```-$%`0`/````Y`4!`!0```#T!0$`&P````D&`0`0
M````)08!`%@````V!@$`(0```(\&`0!I````L08!`!H````;!P$`%P```#8'
M`0`9````3@<!`!H```!H!P$`&0```(,'`0`E````G0<!`"<```##!P$`&@``
M`.L'`0`7````!@@!`!T````>"`$`)@```#P(`0`;````8P@!`"H```!_"`$`
M&0```*H(`0`?````Q`@!`!,```#D"`$`"````/@(`0!$`````0D!`!,```!&
M"0$`0````%H)`0`'````FPD!``@```"C"0$`"0```*P)`0`5````M@D!``T`
M``#,"0$`$P```-H)`0`#````[@D!``P```#R"0$`1@```/\)`0`7````1@H!
M``X```!>"@$`/P```&T*`0`W````K0H!`%<```#E"@$`'P```#T+`0`O````
M70L!``H```"-"P$`$0```)@+`0`(````J@L!``T```"S"P$`+0```,$+`0`$
M````[PL!`!4```#T"P$`.P````H,`0!/````1@P!`!\```"6#`$`%@```+8,
M`0`E````S0P!`"@```#S#`$`'````!P-`0`+````.0T!`!\```!%#0$`'0``
M`&4-`0`E````@PT!`"````"I#0$`)````,H-`0`@````[PT!`#`````0#@$`
M"P```$$.`0`'````30X!``T```!5#@$`#````&,.`0`&````<`X!`#D```!W
M#@$`#````+$.`0`'````O@X!``D```#&#@$`$P```-`.`0`)````Y`X!``0`
M``#N#@$`$````/,.`0`(````!`\!``@````-#P$`!````!8/`0`+````&P\!
M``P````G#P$`$0```#0/`0`,````1@\!`!H```!3#P$`#P```&X/`0`'````
M?@\!``T```"&#P$`%````)0/`0`.````J0\!``P```"X#P$`&P```,4/`0`L
M````X0\!`!,````.$`$`'````"(0`0`H````/Q`!``8```!H$`$`!P```&\0
M`0`3````=Q`!``4```"+$`$`!````)$0`0`7````EA`!``H```"N$`$`#```
M`+D0`0`)````QA`!``8```#0$`$`"0```-<0`0`(````X1`!``D```#J$`$`
M"@```/00`0`(````_Q`!``H````($0$`"@```!,1`0`'````'A$!`!$````F
M$0$`!@```#@1`0`.````/Q$!``X```!.$0$`#0```%T1`0`+````:Q$!`!T`
M``!W$0$`"P```)41`0`"````H1$!``<```"D$0$`!@```*P1`0`)````LQ$!
M``<```"]$0$`.P```,41`0`H`````1(!`!4````J$@$`!0```$`2`0`'````
M1A(!``@```!.$@$`!P```%<2`0`&````7Q(!``4```!F$@$`!P```&P2`0`.
M````=!(!``D```"#$@$`!@```(T2`0`(````E!(!``L```"=$@$`!P```*D2
M`0`(````L1(!``<```"Z$@$`%@```,(2`0`)````V1(!``8```#C$@$`"P``
M`.H2`0`<````]A(!`!0````3$P$`!P```"@3`0`(````,!,!``@````Y$P$`
M!0```$(3`0`0````2!,!`!````!9$P$`!@```&H3`0`9````<1,!``H```"+
M$P$`'````)83`0`'````LQ,!``4```"[$P$`$````,$3`0`4````TA,!``L`
M``#G$P$`#0```/,3`0`7`````10!``D````9%`$`!````",4`0`)````*!0!
M``H````R%`$`!P```#T4`0`"````110!``X```!(%`$`"````%<4`0`?````
M8!0!`#@```"`%`$`(P```+D4`0`X````W10!`#$````6%0$`)P```$@5`0!D
M````<!4!`!0```#5%0$`)````.H5`0`C````#Q8!`"L````S%@$`(0```%\6
M`0!5````@18!`#@```#7%@$`2@```!`7`0!;````6Q<!`"@```"W%P$`.```
M`.`7`0`O````&1@!`#,```!)&`$`*````'T8`0`L````IA@!`"<```#3&`$`
M&P```/L8`0`^````%QD!`#H```!6&0$`J0$``)$9`0`C````.QL!`!<```!?
M&P$`2````'<;`0"%````P!L!`#````!&'`$`00```'<<`0!;````N1P!`$D`
M```5'0$`'0```%\=`0`8````?1T!`"$```"6'0$`'P```+@=`0`K````V!T!
M`"$````$'@$`'0```"8>`0`1````1!X!`#,```!6'@$`)0```(H>`0`G````
ML!X!`#(```#8'@$`'P````L?`0`P````*Q\!`&D```!<'P$`/0```,8?`0!E
M````!"`!`$T```!J(`$`+0```+@@`0`G````YB`!`"\````.(0$`*````#XA
M`0`N````9R$!`#````"6(0$`5````,<A`0`G````'"(!`%H```!$(@$`.@``
M`)\B`0!(````VB(!`$H````C(P$`'P```&XC`0`R````CB,!`"\```#!(P$`
M+````/$C`0`M````'B0!`'$```!,)`$`;P```+XD`0"S````+B4!`!<```#B
M)0$`)0```/HE`0`R````("8!`"D```!3)@$`/@```'TF`0`B````O"8!`%(`
M``#?)@$`(@```#(G`0`E````52<!``L```![)P$`L0```(<G`0`@````.2@!
M`$4```!:*`$`(0```*`H`0`P````PB@!`"4```#S*`$`'````!DI`0`Q````
M-BD!``<```!H*0$`"````'`I`0`'````>2D!``0```"!*0$`"@```(8I`0`-
M````D2D!``L```"?*0$`#@```*LI`0`)````NBD!``L```#$*0$`!@```-`I
M`0`%````URD!`!````#=*0$``@```.XI`0!9````\2D!``4```!+*@$`$@``
M`%$J`0`$````9"H!``<```!I*@$`"````'$J`0`%````>BH!``,```"`*@$`
M$````(0J`0`,````E2H!`!,```"B*@$`#0```+8J`0`"````Q"H!``<```#'
M*@$`!P```,\J`0`&````URH!`!0```#>*@$`#````/,J`0`8`````"L!``8`
M```9*P$`!````"`K`0`2````)2L!``P````X*P$`*@```$4K`0`$````<"L!
M``8```!U*P$`!P```'PK`0`?````A"L!`#4```"D*P$`+@```-HK`0`O````
M"2P!`!<````Y+`$`(````%$L`0`;````<BP!`!@```".+`$`)````*<L`0`?
M````S"P!`!H```#L+`$`(`````<M`0`:````*"T!`#(```!#+0$`&0```'8M
M`0`O````D"T!`!0```#`+0$`*P```-4M`0`?`````2X!`",````A+@$`'P``
M`$4N`0`:````92X!`"4```"`+@$`)@```*8N`0`E````S2X!`"0```#S+@$`
M&````!@O`0`=````,2\!`"0```!/+P$`&````'0O`0`B````C2\!`"4```"P
M+P$`&0```-8O`0`\````\"\!`!\````M,`$`(P```$TP`0`?````<3`!`"``
M``"1,`$`&@```+(P`0`O````S3`!`!@```#],`$`)@```!8Q`0`>````/3$!
M`"D```!<,0$`'@```(8Q`0`)````I3$!``P```"O,0$`%P```+PQ`0`O````
MU#$!`"0````$,@$`!P```"DR`0`/````,3(!`!0```!!,@$`#@```%8R`0`-
M````93(!`"0```!S,@$`!0```)@R`0`'````GC(!`"(```"F,@$`)0```,DR
M`0`=````[S(!`!H````-,P$`!P```"@S`0#'````,#,!``L```#X,P$`%0``
M``0T`0`&````&C0!``D````A-`$`"P```"LT`0`,````-S0!`!<```!$-`$`
M!@```%PT`0`S````8S0!`!,```"7-`$`$P```*LT`0`'````OS0!``\```#'
M-`$`!P```-<T`0`R````WS0!`"$````2-0$`$P```#0U`0`.````2#4!``P`
M``!7-0$`$0```&0U`0`R````=C4!``@```"I-0$`"0```+(U`0`*````O#4!
M`!0```#'-0$`"@```-PU`0`=````YS4!``@````%-@$`'P````XV`0`(````
M+C8!`!H````W-@$`!@```%(V`0`5````638!``<```!O-@$`"````'<V`0`)
M````@#8!`#\```"*-@$`!P```,HV`0`/````TC8!``X```#B-@$`$````/$V
M`0`)`````C<!``D````,-P$`"````!8W`0`3````'S<!``<````S-P$`"```
M`#LW`0`9````1#<!``H```!>-P$`%P```&DW`0`4````@3<!``H```"6-P$`
M#````*$W`0`7````KC<!``0```#&-P$`*@```,LW`0`1````]C<!``<````(
M.`$``@```!`X`0`0````$S@!`!@````D.`$`"P```#TX`0`#````23@!``@`
M``!-.`$`"0```%8X`0`$````8#@!``<```!E.`$`!P```&TX`0`&````=3@!
M`!0```!\.`$`!P```)$X`0`-````F3@!``L```"G.`$`%````+,X`0`5````
MR#@!``X```#>.`$`+P```.TX`0`@````'3D!`!P````^.0$`2````%LY`0!,
M````I#D!``P```#Q.0$`,0```/XY`0`%````,#H!`!(````V.@$`/P```$DZ
M`0`2````B3H!``H```"<.@$`!@```*<Z`0`$````KCH!``0```"S.@$`$P``
M`+@Z`0`%````S#H!``8```#2.@$`!@```-DZ`0`$````X#H!``P```#E.@$`
M"@```/(Z`0`)````_3H!``4````'.P$`&`````T[`0`9````)CL!`!\```!`
M.P$`'0```&`[`0`1````?CL!``(```"0.P$`!````),[`0`*````F#L!``8`
M``"C.P$`%````*H[`0`%````OSL!``,```#%.P$`#````,D[`0!%````UCL!
M`!H````</`$`-0```#<\`0`Z````;3P!`"@```"H/`$`4P```-$\`0`O````
M)3T!`$(```!5/0$`,````)@]`0`N````R3T!`!D```#X/0$`)P```!(^`0!R
M````.CX!`"````"M/@$`-0```,X^`0!%````!#\!`#````!*/P$`*0```'L_
M`0`A````I3\!`"@```#'/P$`*0```/`_`0`F````&D`!`"4```!!0`$`*```
M`&=``0`H````D$`!`"(```"Y0`$`,````-Q``0`2````#4$!`!,````@00$`
M$````#1!`0!Y````14$!``D```"_00$`<P```,E!`0!\````/4(!`"L```"Z
M0@$`%P```.9"`0`5````_D(!`!8````40P$`#P```"M#`0`?````.T,!`!\`
M``!;0P$`'````'M#`0!1````F$,!`!0```#J0P$`"@```/]#`0`%````"D0!
M``8````01`$`"````!=$`0`%````($0!`!(````F1`$`$````#E$`0`3````
M2D0!`!T```!>1`$`#P```'Q$`0`/````C$0!``\```"<1`$`#0```*Q$`0`$
M````ND0!``D```"_1`$`"P```,E$`0`%````U40!``4```#;1`$`!P```.%$
M`0`%````Z40!`!0```#O1`$`#@````1%`0`'````$T4!``@````;10$`#P``
M`"1%`0`-````-$4!``H```!"10$`"````$U%`0`,````5D4!``8```!C10$`
M#P```&I%`0`'````>D4!``8```""10$`%````(E%`0`&````GD4!``8```"E
M10$`#````*Q%`0`7````N44!``@```#110$`!````-I%`0`*````WT4!``,`
M``#J10$`!@```.Y%`0`$````]44!``H```#Z10$`"@````5&`0`'````$$8!
M``0````81@$`!````!U&`0`9````(D8!``(````\1@$`"0```#]&`0`&````
M248!``8```!01@$`)P```%=&`0`(````?T8!``0```"(1@$`#P```(U&`0`3
M````G48!``<```"Q1@$`$````+E&`0`3````RD8!``<```#>1@$`!@```.9&
M`0`&````[48!`!````#T1@$`$@````5'`0`&````&$<!``D````?1P$`(@``
M`"E'`0`'````3$<!``<```!41P$`"P```%Q'`0`3````:$<!``4```!\1P$`
M$0```()'`0`"````E$<!``L```"71P$`!````*-'`0`+````J$<!``4```"T
M1P$`!P```+I'`0!G`0``PD<!`!,````J20$`#P```#Y)`0`*````3DD!``L`
M``!920$`!````&5)`0`+````:DD!`!$```!V20$`$P```(A)`0`.````G$D!
M`!T```"K20$`#P```,E)`0`%````V4D!`"@```#?20$`#@````A*`0`9````
M%TH!``X````Q2@$`"P```$!*`0`-````3$H!`"(```!:2@$`#0```'U*`0`*
M````BTH!`!$```"62@$`$````*A*`0`.````N4H!``L```#(2@$`$````-1*
M`0`/````Y4H!``8```#U2@$`)0```/Q*`0`@````(DL!`!(```!#2P$`&```
M`%9+`0`0````;TL!``L```"`2P$`#0```(Q+`0`/````FDL!``\```"J2P$`
M!P```+I+`0`N````PDL!`"@```#Q2P$`/@```!I,`0!-````64P!`&@```"G
M3`$`:P```!!-`0!N````?$T!`'$```#K30$`0````%U.`0`"````GDX!`!0`
M``"A3@$`!0```+9.`0`&````O$X!`!````##3@$`!P```-1.`0`)````W$X!
M``D```#F3@$`#````/!.`0`R````_4X!`#`````P3P$`$0```&%/`0`1````
M<T\!``X```"%3P$`$@```)1/`0`)````IT\!`!4```"Q3P$`%0```,=/`0`5
M````W4\!``\```#S3P$`%@````-0`0`5````&E`!`",````P4`$`'````%10
M`0`;````<5`!`!0```"-4`$`#P```*)0`0`6````LE`!``X```#)4`$`+0``
M`-A0`0`7````!E$!`!L````>40$`$P```#I1`0`J````3E$!``4```!Y40$`
M"0```']1`0`Q````B5$!``8```"[40$`#````,)1`0`1````SU$!``H```#A
M40$`!0```.Q1`0`3````\E$!`!(````&4@$`%0```!E2`0`3````+U(!`!``
M``!#4@$`$````%12`0`3````95(!`!$```!Y4@$`"@```(M2`0`3````EE(!
M``D```"J4@$`!P```+12`0`(````O%(!``4```#%4@$`"0```,M2`0`+````
MU5(!``0```#A4@$`#P```.92`0`@````]E(!`!`````74P$`#````"A3`0`.
M````-5,!``P```!$4P$`#@```%%3`0`-````8%,!`!X```!N4P$`$P```(U3
M`0`0````H5,!`!H```"R4P$`+````,U3`0`*````^E,!`!P````%5`$`&P``
M`")4`0`@````/E0!`!<```!?5`$`%@```'=4`0`3````CE0!`!````"B5`$`
M'P```+-4`0`'````TU0!``8```#;5`$`"````.)4`0`.````ZU0!``@```#Z
M5`$`"@````-5`0`2````#E4!``,````A50$`"@```"55`0`5````,%4!`!@`
M``!&50$`"@```%]5`0`%````:E4!`!<```!P50$`%@```(A5`0`+````GU4!
M`$(```"K50$`"@```.Y5`0`'````^54!`!,````!5@$`!0```!56`0`%````
M&U8!`!`````A5@$`"P```#)6`0`5````/E8!`$4```!45@$`$0```)I6`0`"
M````K%8!`-H```"O5@$`,@```(I7`0`Q````O5<!`"X```#O5P$`+P```!Y8
M`0`,````3E@!``H```!;6`$`"@```&98`0`(````<5@!``D```!Z6`$`"@``
M`(18`0`R````CU@!`#@```#"6`$`,0```/M8`0!7````+5D!`#````"%60$`
M,````+99`0`P````YUD!`$8````86@$`-````%]:`0`S````E%H!`#````#(
M6@$`-@```/E:`0`5````,%L!`!D```!&6P$`+@```&!;`0`D````CUL!`!,`
M``"T6P$`#````,A;`0`,````U5L!``L```#B6P$`$````.Y;`0`8````_UL!
M`!T````87`$`!P```#9<`0`'````/EP!`!8```!&7`$`"@```%U<`0`(````
M:%P!``D```!Q7`$`$````'M<`0`+````C%P!``8```"87`$`!@```)]<`0`%
M````IEP!``<```"L7`$`!@```+1<`0`*````NUP!`"P```#&7`$`$````/-<
M`0`(````!%T!``,````-70$`!P```!%=`0`)````&5T!``0````C70$`"@``
M`"A=`0`&````,UT!`!4````Z70$`!@```%!=`0`(````5UT!``D```!@70$`
M#0```&I=`0`(````>%T!`"$```"!70$`$0```*-=`0`)````M5T!`!$```"_
M70$`#````-%=`0`'````WET!``4```#F70$``P```.Q=`0`#````\%T!`!4`
M``#T70$`!P````I>`0`4````$EX!``<````G7@$`!@```"]>`0`2````-EX!
M``@```!)7@$`!````%)>`0`(````5UX!``@```!@7@$`4@```&E>`0`F````
MO%X!`"(```#C7@$`!@````9?`0`(````#5\!`!@````67P$`"@```"]?`0`.
M````.E\!`"(```!)7P$`)0```&Q?`0`P````DE\!`"0```##7P$`*@```.A?
M`0!Z````$V`!`#4```".8`$`"@```,1@`0`)````SV`!``H```#98`$`%0``
M`.1@`0`)````^F`!``\````$80$`#0```!1A`0`0````(F$!`!$````S80$`
M$````$5A`0`.````5F$!``T```!E80$`%@```'-A`0`&````BF$!`!T```"1
M80$`'@```*]A`0`2````SF$!`!$```#A80$`!@```/-A`0`(````^F$!`&$`
M```#8@$`"````&5B`0`3````;F(!``4```""8@$`!0```(AB`0`>````CF(!
M`!L```"M8@$`$P```,EB`0`7````W6(!`!,```#U8@$`+`````EC`0`W````
M-F,!`!D```!N8P$`$````(AC`0`D````F6,!``8```"^8P$`%````,5C`0`1
M````VF,!``T```#L8P$`$@```/IC`0`6````#60!`!,````D9`$`#````#AD
M`0`&````160!``<```!,9`$`&````%1D`0`1````;60!``@```!_9`$`!0``
M`(AD`0`-````CF0!``T```"<9`$`"0```*ID`0`+````M&0!``8```#`9`$`
M&````,=D`0`(````X&0!``T```#I9`$`"0```/=D`0`-`````64!``<````/
M90$`!P```!=E`0`)````'V4!``D````I90$`&P```#-E`0`/````3V4!`!,`
M``!?90$`*P```'-E`0`)````GV4!``4```"I90$`*````*]E`0`3````V&4!
M`!0```#L90$`.`````%F`0!'````.F8!`"(```""9@$`-0```*5F`0`(````
MVV8!``T```#D9@$`!@```/)F`0`(````^68!`!`````"9P$`4@```!-G`0`*
M````9F<!``D```!Q9P$`'0```'MG`0`B````F6<!`"````"\9P$`)0```-UG
M`0`<`````V@!`"T````@:`$`'P```$YH`0`C````;F@!`!P```"2:`$`'P``
M`*]H`0`>````SV@!`"D```#N:`$`,@```!AI`0`D````2VD!`"L```!P:0$`
M-P```)QI`0`]````U&D!`!,````2:@$`*````"9J`0`2````3VH!`,0```!B
M:@$`%````"=K`0`>````/&L!`"4```!;:P$`)P```(%K`0`C````J6L!`"(`
M``#-:P$`(0```/!K`0`D````$FP!`",````W;`$`'````%ML`0`G````>&P!
M`$<```"@;`$`#0```.AL`0`$````]FP!``D```#[;`$`!0````5M`0`;````
M"VT!``T````G;0$`#P```#5M`0`.````16T!``<```!4;0$`#P```%QM`0`0
M````;&T!``<```!];0$`!````(5M`0`'````BFT!``P```"2;0$`#@```)]M
M`0`+````KFT!`!(```"Z;0$`#0```,UM`0`N````VVT!``<````*;@$`$```
M`!)N`0`&````(VX!`!,````J;@$`&0```#YN`0`;````6&X!`!4```!T;@$`
M`@```(IN`0`)````C6X!`!T```"7;@$`$````+5N`0`%````QFX!``\```#,
M;@$`#@```-QN`0`#````ZVX!``<```#O;@$`#````/=N`0`0````!&\!``@`
M```5;P$`$0```!YO`0`)````,&\!`!4````Z;P$`$````%!O`0`/````86\!
M`!0```!Q;P$`"@```(9O`0`+````D6\!``P```"=;P$`%0```*IO`0`1````
MP&\!`!$```#2;P$`&@```.1O`0`-````_V\!``\````-<`$`*0```!UP`0`-
M````1W`!`"0```!5<`$`&@```'IP`0!H````E7`!`!@```#^<`$`"P```!=Q
M`0`*````(W$!``T````N<0$`%@```#QQ`0`,````4W$!`"0```!@<0$`+0``
M`(5Q`0`,````LW$!``@```#`<0$`(0```,EQ`0`*````ZW$!`!D```#V<0$`
M&@```!!R`0`)````*W(!``D````U<@$`%0```#]R`0`.````57(!`!T```!D
M<@$`#P```()R`0`9````DG(!``@```"L<@$`$````+5R`0`F````QG(!`"X`
M``#M<@$`$@```!QS`0`]````+W,!``@```!M<P$`%@```'9S`0`*````C7,!
M``T```"8<P$`,@```*9S`0`/````V7,!``4```#I<P$`#P```.]S`0`)````
M_W,!``8````)=`$``P```!!T`0`'````%'0!``@````<=`$`"P```"5T`0`3
M````,70!``T```!%=`$`#@```%-T`0`.````8G0!`!````!Q=`$`&0```()T
M`0`=````G'0!`!,```"Z=`$`'P```,YT`0`5````[G0!`!<````$=0$`"0``
M`!QU`0`&````)G4!``L````M=0$`"@```#EU`0`"````1'4!``8```!'=0$`
M"P```$YU`0`C````6G4!`!8```!^=0$`"0```)5U`0`-````GW4!``\```"M
M=0$`#P```+UU`0`^````S74!`"8````,=@$`"0```#-V`0`*````/78!``@`
M``!(=@$`"````%%V`0`/````6G8!`(L```!J=@$`'@```/9V`0`2````%7<!
M``<````H=P$`!````#!W`0`Z````-7<!`!<```!P=P$`!P```(AW`0`(````
MD'<!``<```"9=P$`!@```*%W`0`9````J'<!``\```#"=P$`#@```-)W`0`0
M````X7<!``X```#R=P$`#P````%X`0`,````$7@!``L````>>`$`$0```"IX
M`0`)````/'@!``H```!&>`$`#@```%%X`0`N````8'@!``L```"/>`$`"```
M`)MX`0`*````I'@!`!$```"O>`$`#@```,%X`0`4````T'@!`"8```#E>`$`
M*0````QY`0`H````-GD!`!T```!?>0$`'@```'UY`0`L````G'D!`"$```#)
M>0$`!````.MY`0`<````\'D!``\````->@$``P```!UZ`0`(````(7H!``D`
M```J>@$`"P```#1Z`0`,````0'H!``0```!->@$`'````%)Z`0`>````;WH!
M``T```".>@$`#````)QZ`0`.````J7H!``T```"X>@$`)P```,9Z`0`'````
M[GH!``8```#V>@$`!P```/UZ`0`,````!7L!``\````2>P$`%0```")[`0`'
M````.'L!``<```!`>P$`!````$A[`0`3````37L!``D```!A>P$`!P```&M[
M`0`P````<WL!`!<```"D>P$`@@```+Q[`0`7````/WP!``L```!7?`$`!P``
M`&-\`0`+````:WP!``@```!W?`$`"@```(!\`0`&````BWP!``H```"2?`$`
M`@```)U\`0`&````H'P!``D```"G?`$`&0```+%\`0`,````RWP!``\```#8
M?`$`'````.A\`0`'````!7T!``,````-?0$`!P```!%]`0`6````&7T!``H`
M```P?0$`#@```#M]`0`(````2GT!``4```!3?0$`,P```%E]`0`&````C7T!
M``8```"4?0$`!````)M]`0`(````H'T!`!@```"I?0$`$0```,)]`0`'````
MU'T!``D```#<?0$`!0```.9]`0`)````['T!``@```#V?0$``@```/]]`0`&
M`````GX!``T````)?@$`"@```!=^`0`+````(GX!``L````N?@$`$P```#I^
M`0`)````3GX!``<```!8?@$`#````&!^`0`?````;7X!``<```"-?@$`"@``
M`)5^`0`$````H'X!``D```"E?@$`"````*]^`0`,````N'X!``H```#%?@$`
M!@```-!^`0`-````UWX!``8```#E?@$`!````.Q^`0!`````\7X!`$0````R
M?P$`0@```'=_`0`A````NG\!``4```#<?P$`#P```.)_`0`%````\G\!``,`
M``#X?P$`(0```/Q_`0`8````'H`!``8````W@`$`!````#Z``0`;````0X`!
M``8```!?@`$`"````&:``0`B````;X`!``0```"2@`$`!0```)>``0`7````
MG8`!``0```"U@`$`#0```+J``0`/````R(`!``@```#8@`$`"0```.&``0`%
M````ZX`!`#T```#Q@`$`-@```"^!`0`[````9H$!`"H```"B@0$`.````,V!
M`0`Z````!H(!`"T```!!@@$`4@```&^"`0`P````PH(!`#D```#S@@$`*0``
M`"V#`0`0````5X,!`!@```!H@P$`#````(&#`0`#````CH,!`"0```"2@P$`
M)````+>#`0`B````W(,!`"$```#_@P$`"P```"&$`0`-````+80!``H````[
MA`$`"0```$:$`0`B````4(0!`"@```!SA`$`*````)R$`0`(````Q80!`!H`
M``#.A`$`,P```.F$`0`8````'84!`!(````VA0$`!P```$F%`0`3````484!
M`!8```!EA0$`$````'R%`0!1````C84!`)$```#?A0$`A````'&&`0`7````
M]H8!``X````.AP$`#P```!V'`0`4````+8<!`!4```!"AP$`$0```%B'`0`,
M````:H<!`!H```!WAP$`$P```)*'`0`<````IH<!`!4```##AP$`%0```-F'
M`0`/````[X<!`"(```#_AP$`*0```"*(`0"-````3(@!`!0```#:B`$`!0``
M`.^(`0`6````]8@!``D````,B0$`!````!:)`0`*````&XD!`!$````FB0$`
M$P```#B)`0`.````3(D!`!````!;B0$`%````&R)`0`G````@8D!`"D```"I
MB0$`)0```-.)`0`E````^8D!`#`````?B@$`,````%"*`0`=````@8H!`$4`
M``"?B@$`#P```.6*`0`1````]8H!`!$````'BP$`$P```!F+`0`2````+8L!
M`!4```!`BP$`%P```%:+`0`/````;HL!`!$```!^BP$`.0```)"+`0`=````
MRHL!`!<```#HBP$`.@````",`0`3````.XP!``<```!/C`$`#0```%>,`0`B
M````98P!`!4```"(C`$`$@```)Z,`0`9````L8P!`!D```#+C`$`%````.6,
M`0`2````^HP!`!X````-C0$`)````"R-`0`6````48T!`!(```!HC0$`%P``
M`'N-`0`3````DXT!`!<```"GC0$`"@```+^-`0`@````RHT!``0```#KC0$`
M!P```/"-`0`*````^(T!`!@````#C@$`!@```!R.`0`(````(XX!``<````L
MC@$`!@```#2.`0`'````.XX!``<```!#C@$`!0```$N.`0`4````48X!``8`
M``!FC@$`"````&V.`0`$````=HX!``0```![C@$`"0```(".`0`5````BHX!
M`!(```"@C@$`#P```+..`0`0````PXX!``H```#4C@$`$P```-^.`0`%````
M\XX!`"<```#YC@$`#@```"&/`0`-````,(\!`!,````^CP$`#0```%*/`0`+
M````8(\!``X```!LCP$`,P```'N/`0`+````KX\!``@```"[CP$`"````,2/
M`0`G````S8\!`!0```#UCP$`$0````J0`0`'````')`!``D````DD`$`!P``
M`"Z0`0`$````-I`!`"`````[D`$`$````%R0`0`-````;9`!`!````![D`$`
M#P```(R0`0`0````G)`!`!(```"MD`$`%@```,"0`0`=````UY`!`!D```#U
MD`$`#@````^1`0`'````'I$!``<````FD0$`!@```"Z1`0`8````-9$!``<`
M``!.D0$`!0```%:1`0`*````7)$!``X```!GD0$`!P```':1`0`'````?I$!
M`!T```"&D0$`#0```*21`0`,````LI$!``P```"_D0$`$@```,R1`0`,````
MWY$!``\```#LD0$`%P```/R1`0`-````%)(!`!`````BD@$`"````#.2`0`D
M````/)(!``0```!AD@$`$````&:2`0!!````=Y(!``4```"YD@$`#````+^2
M`0`A````S)(!``T```#ND@$`&0```/R2`0`*````%I,!``T````ADP$`"@``
M`"^3`0`(````.I,!``X```!#DP$`"@```%*3`0`1````79,!`!(```!ODP$`
M+P```(*3`0`*````LI,!``@```"]DP$`"````,:3`0`(````SY,!``P```#8
MDP$`%@```.63`0`'````_),!``D````$E`$`"`````Z4`0`,````%Y0!`$X`
M```DE`$`$P```'.4`0`+````AY0!``8```"3E`$`!````)J4`0`6````GY0!
M`!<```"VE`$`&````,Z4`0`)````YY0!``(```#QE`$`!````/24`0`B````
M^90!``,````<E0$`!0```""5`0`S````)I4!``H```!:E0$`!0```&65`0`&
M````:Y4!``T```!RE0$`#0```("5`0`&````CI4!``@```"5E0$`"0```)Z5
M`0`$````J)4!``4```"ME0$`'0```+.5`0!B````T94!``L````TE@$`#0``
M`$"6`0`%````3I8!``4```!4E@$`)@```%J6`0`W````@98!`!$```"YE@$`
M"@```,N6`0`5````UI8!``H```#LE@$`"0```/>6`0`<`````9<!`"<````>
MEP$`+0```$:7`0`L````=)<!``\```"AEP$``P```+&7`0`'````M9<!``L`
M``"]EP$`"P```,F7`0`%````U9<!``D```#;EP$`"@```.67`0`2````\)<!
M``<````#F`$`:0````N8`0`1````=9@!``L```"'F`$`"@```).8`0`?````
MGI@!`$T```"^F`$`!P````R9`0`(````%)D!``8````=F0$`'P```"29`0`&
M````1)D!``D```!+F0$`+0```%69`0`L````@YD!``<```"PF0$`!@```+B9
M`0`*````OYD!`!L```#*F0$`)0```.:9`0!A````#)H!`!8```!NF@$`*```
M`(6:`0`5````KIH!``(```#$F@$`#@```,>:`0`)````UIH!``\```#@F@$`
M"@```/":`0`'````^YH!`!<````#FP$`!@```!N;`0`'````(IL!``@````J
MFP$`!0```#.;`0`-````.9L!``T```!'FP$`"P```%6;`0`@````89L!`!\`
M``""FP$`#P```**;`0`,````LIL!``H```"_FP$`"0```,J;`0`'````U)L!
M`!8```#<FP$`%````/.;`0`3````")P!``P````<G`$`"@```"F<`0`+````
M-)P!``H```!`G`$`#````$N<`0`*````6)P!``H```!CG`$`'0```&Z<`0!,
M````C)P!`!0```#9G`$`#````.Z<`0`-````^YP!``X````)G0$`$0```!B=
M`0`,````*IT!`!(````WG0$`!0```$J=`0`E````4)T!``0```!VG0$`!P``
M`'N=`0`%````@YT!``4```")G0$`"0```(^=`0`3````F9T!`!(```"MG0$`
M&@```,"=`0`6````VYT!`!@```#RG0$`%P````N>`0`7````(YX!`!X````[
MG@$`&````%J>`0`'````<YX!``4```![G@$`#P```(&>`0`0````D9X!`!(`
M``"BG@$`"P```+6>`0`A````P9X!``T```#CG@$`%0```/&>`0`&````!Y\!
M``T````.GP$`"````!R?`0`/````)9\!``P````UGP$`#@```$*?`0`-````
M49\!``P```!?GP$`#P```&R?`0`-````?)\!``D```"*GP$`!0```)2?`0`'
M````FI\!``4```"BGP$`!````*B?`0`/````K9\!`#\```"]GP$`.0```/V?
M`0`3````-Z`!`"P```!+H`$`,@```'B@`0`F````JZ`!`!$```#2H`$`.@``
M`.2@`0`N````'Z$!`#,```!.H0$`,P```(*A`0`[````MJ$!`!(```#RH0$`
M&@````6B`0`.````(*(!`"$````OH@$`%0```%&B`0`N````9Z(!`!P```"6
MH@$`'0```+.B`0`6````T:(!`!0```#HH@$`%0```/VB`0`9````$Z,!`#(`
M```MHP$`,@```&"C`0`U````DZ,!`#,```#)HP$`-````/VC`0`Q````,J0!
M`&L```!DI`$`'0```-"D`0`.````[J0!``L```#]I`$`,`````FE`0`O````
M.J4!`",```!JI0$`(````(ZE`0`,````KZ4!`$D```"\I0$`0@````:F`0`$
M````2:8!`!````!.I@$`'````%^F`0`.````?*8!`!,```"+I@$`"````)^F
M`0`)````J*8!``<```"RI@$`"0```+JF`0`.````Q*8!``T```#3I@$`%0``
M`.&F`0`.````]Z8!`!$````&IP$`"````!BG`0`<````(:<!``@````^IP$`
M`@```$>G`0`%````2J<!`!````!0IP$`#P```&&G`0`,````<:<!`#\```!^
MIP$``@```+ZG`0`&````P:<!``X```#(IP$`!@```->G`0`'````WJ<!`!``
M``#FIP$`!P```/>G`0`$````_Z<!`#$````$J`$`&P```#:H`0`B````4J@!
M`%@```!UJ`$`&````,ZH`0!(````YZ@!`",````PJ0$`$````%2I`0`)````
M9:D!``8```!OJ0$`#@```':I`0`/````A:D!``P```"5J0$`$P```**I`0`+
M````MJD!`!T```#"J0$`&@```."I`0`&````^ZD!`!$````"J@$`"````!2J
M`0`/````':H!`"8````MJ@$`&0```%2J`0`3````;JH!`!0```""J@$`(```
M`)>J`0`(````N*H!``D```#!J@$``@```,NJ`0`9````SJH!`!(```#HJ@$`
M&0```/NJ`0`*````%:L!``P````@JP$`"````"VK`0`%````-JL!`!T````\
MJP$`#0```%JK`0`&````:*L!`!(```!OJP$`"````(*K`0`4````BZL!``H`
M``"@JP$`$@```*NK`0`P````OJL!`!H```#OJP$`"P````JL`0`,````%JP!
M`"$````CK`$`'0```$6L`0`'````8ZP!`!8```!KK`$``P```(*L`0`'````
MAJP!`!@```".K`$`!@```*>L`0`'````KJP!`"$```"VK`$`,0```-BL`0`H
M````"JT!``4````SK0$`$0```#FM`0`'````2ZT!``T```!3K0$`%P```&&M
M`0`$````>:T!``H```!^K0$`#````(FM`0`(````EJT!``8```"?K0$`"```
M`*:M`0`&````KZT!``H```"VK0$`%P```,&M`0`T````V:T!`#0````.K@$`
M(@```$.N`0`S````9JX!`"````":K@$`1P```+NN`0`=`````Z\!`"X````A
MKP$`+````%"O`0`E````?:\!``4```"CKP$`"````*FO`0`)````LJ\!``T`
M``"\KP$`"````,JO`0`A````TZ\!`!P```#UKP$`,````!*P`0`C````0[`!
M`#$```!GL`$`-@```)FP`0`)````T+`!`!@```#:L`$`"P```/.P`0`*````
M_[`!`"L````*L0$`"@```#:Q`0`+````0;$!``H```!-L0$`#0```%BQ`0`2
M````9K$!``T```!YL0$`"````(>Q`0`4````D+$!``D```"EL0$`#````*^Q
M`0`0````O+$!`!L```#-L0$`+````.FQ`0`+````%K(!``8````BL@$`!0``
M`"FR`0`=````+[(!`!0```!-L@$`!0```&*R`0`+````:+(!``H```!TL@$`
M"````'^R`0`.````B+(!``H```"7L@$`!0```**R`0`.````J+(!`$4```"W
ML@$`8@```/VR`0`+````8+,!``D```!LLP$`#@```':S`0`3````A;,!`!(`
M``"9LP$`#@```*RS`0`2````N[,!`!0```#.LP$`$@```..S`0`2````]K,!
M`!P````)M`$`(P```":T`0`9````2K0!``4```!DM`$`%````&JT`0`+````
M?[0!``\```"+M`$`$P```)NT`0`4````K[0!`!(```#$M`$`+@```->T`0`+
M````!K4!``X````2M0$`%0```"&U`0`0````-[4!`!$```!(M0$`$@```%JU
M`0`0````;;4!`$D```!^M0$`#````,BU`0`D````U;4!`!4```#ZM0$`%P``
M`!"V`0`]````*+8!``<```!FM@$`$P```&ZV`0`*````@K8!`!````"-M@$`
M$P```)ZV`0`=````LK8!``@```#0M@$`"@```-FV`0`1````Y+8!``<```#V
MM@$`&````/ZV`0`7````%[<!``@````OMP$`!@```#BW`0`+````/[<!``\`
M``!+MP$`%````%NW`0`#````<+<!``@```!TMP$`"P```'VW`0`2````B;<!
M`!,```"<MP$`$0```+"W`0`1````PK<!``8```#4MP$`"0```-NW`0`W````
MY;<!`#`````=N`$`+0```$ZX`0`'````?+@!`!,```"$N`$`!@```)BX`0`C
M````G[@!`!@```##N`$`)P```-RX`0`-````!+D!``D````2N0$``P```!RY
M`0`&````(+D!``H````GN0$``@```#*Y`0`)````-;D!`!$````_N0$`"```
M`%&Y`0`5````6KD!`!L```!PN0$`%````(RY`0`%````H;D!``H```"GN0$`
M%````+*Y`0`1````Q[D!``@```#9N0$`#````.*Y`0`*````[[D!`!$```#Z
MN0$`$P````RZ`0`.````(+H!`%T````ON@$`&@```(VZ`0`*````J+H!``8`
M``"SN@$`#````+JZ`0`.````Q[H!`!,```#6N@$`)````.JZ`0`=````#[L!
M`!0````MNP$`*````$*[`0`@````:[L!`!0```",NP$`9P```*&[`0`J````
M";P!`'0````TO`$`(P```*F\`0`;````S;P!`!P```#IO`$`'`````:]`0`<
M````([T!`"H```!`O0$`+````&N]`0`B````F+T!`!L```"[O0$`(````->]
M`0`Y````^+T!`"4````RO@$`00```%B^`0`9````FKX!`!L```"TO@$`&0``
M`-"^`0`+````ZKX!`$P```#VO@$`&P```$._`0!0````7[\!``<```"POP$`
M"````+B_`0`)````P;\!`!0```#+OP$`"P```."_`0`3````[+\!``D`````
MP`$`$P````K``0!>````'L`!`!T```!]P`$`%````)O``0!'````L,`!`#@`
M``#XP`$`6P```#'!`0`A````C<$!`#(```"OP0$`"@```.+!`0`2````[<$!
M``@`````P@$`$@````G"`0`_````',(!``D```!<P@$`%@```&;"`0!)````
M?<(!`&@```#'P@$`)@```###`0`8````5\,!`#````!PPP$`+@```*'#`0`G
M````T,,!`!````#XPP$`(@````G$`0`D````+,0!`"X```!1Q`$`*P```(#$
M`0`N````K,0!`#$```#;Q`$`,0````W%`0`0````/\4!``4```!0Q0$`"P``
M`%;%`0`*````8L4!``H```!MQ0$`+````'C%`0`,````I<4!``D```"RQ0$`
M#````+S%`0`7````R<4!``D```#AQ0$`!P```.O%`0`3````\\4!``D````'
MQ@$`"````!'&`0`&````&L8!``L````AQ@$`"P```"W&`0`0````.<8!``X`
M``!*Q@$`&P```%G&`0`0````=<8!``<```"&Q@$`%0```([&`0`8````I,8!
M``D```"]Q@$`"P```,?&`0`:````T\8!`"D```#NQ@$`$@```!C'`0`E````
M*\<!`"<```!1QP$`#P```'G'`0`*````B<<!`!H```"4QP$`!@```*_'`0`$
M````ML<!`!@```"[QP$`#@```-3'`0`0````X\<!``X```#TQP$`!0````/(
M`0`)````"<@!``D````3R`$`"0```!W(`0`*````)\@!``D````RR`$`"0``
M`#S(`0`)````1L@!``<```!0R`$`$@```%C(`0`&````:\@!``T```!RR`$`
M!0```(#(`0`)````AL@!``L```"0R`$`&@```)S(`0`+````M\@!``(```##
MR`$`"0```,;(`0`*````T,@!``D```#;R`$`!@```.7(`0!$````[,@!`"H`
M```QR0$`&````%S)`0`&````=<D!``P```!\R0$`"@```(G)`0`-````E,D!
M``8```"BR0$`!@```*G)`0`*````L,D!`!@```"[R0$`#````-3)`0`-````
MX<D!``\```#OR0$`"P```/_)`0`-````"\H!``@````9R@$`"@```"+*`0`8
M````+<H!``D```!&R@$`!@```%#*`0`+````5\H!`!@```!CR@$`'````'S*
M`0`*````F<H!``P```"DR@$`"P```+'*`0`%````O<H!`!(```##R@$`$@``
M`-;*`0`&````Z<H!`!L```#PR@$`#`````S+`0`A````&<L!``4````[RP$`
M!0```$'+`0`.````1\L!`",```!6RP$`"P```'K+`0`-````ALL!``X```"4
MRP$`"0```*/+`0`%````K<L!``P```"SRP$`#P```,#+`0`.````T,L!``(`
M``#?RP$`#P```.++`0`(````\LL!`"L```#[RP$`0````"?,`0`D````:,P!
M`"\```"-S`$`*````+W,`0`H````YLP!`%T````/S0$`$P```&W-`0`J````
M@<T!`!T```"LS0$`)0```,K-`0`=````\,T!`%D````.S@$`-````&C.`0!>
M````G<X!`%L```#\S@$`)@```%C/`0`]````?\\!`#,```"]SP$`.@```/'/
M`0`S````+-`!`#<```!@T`$`-0```)C0`0`>````SM`!`#L```#MT`$`2```
M`"G1`0#D`0``<M$!`"$```!7TP$`%````'G3`0!4````CM,!`((```#CTP$`
M0@```&;4`0`_````J=0!`'(```#IU`$`4@```%S5`0`@````K]4!`!4```#0
MU0$`'0```.;5`0`=````!-8!`"T````BU@$`'@```%#6`0`=````;]8!`!,`
M``"-U@$`.@```*'6`0`H````W-8!`"D````%UP$`0````"_7`0`8````<-<!
M`$````")UP$`:0```,K7`0`Z````--@!`&,```!OV`$`3````-/8`0`I````
M(-D!`#$```!*V0$`,@```'S9`0`P````K]D!`"T```#@V0$`,0````[:`0!4
M````0-H!`#,```"5V@$`6P```,G:`0!%````)=L!`$T```!KVP$`40```+G;
M`0`J````"]P!`#0````VW`$`+@```&O<`0`N````FMP!`"X```#)W`$`B```
M`/C<`0"&````@=T!`-`````(W@$`$P```-G>`0`F````[=X!`#D````4WP$`
M+````$[?`0!(````>]\!`"L```#$WP$`3````/#?`0`K````/>`!`"````!I
MX`$`"@```(K@`0#!````E>`!`!X```!7X0$`1P```';A`0`F````ON$!`#4`
M``#EX0$`)P```!OB`0`D````0^(!`#X```!HX@$`!@```*?B`0`)````KN(!
M``<```"XX@$`!````,#B`0`*````Q>(!``P```#0X@$`"P```-WB`0`,````
MZ>(!``D```#VX@$`"P````#C`0`&````#.,!``4````3XP$`$````!GC`0`#
M````*N,!`&<````NXP$`!P```);C`0`5````GN,!``0```"TXP$`!P```+GC
M`0`&````P>,!``4```#(XP$`"0```,[C`0`5````V.,!``L```#NXP$`$@``
M`/KC`0`-````#>0!``(````;Y`$`!P```![D`0`'````)N0!``<````NY`$`
M$@```#;D`0`,````2>0!`!@```!6Y`$`!@```&_D`0`$````=N0!``X```![
MY`$`#````(KD`0`K````E^0!``0```##Y`$`!P```,CD`0`(````T.0!`"L`
M``#9Y`$`1P````7E`0`Z````3>4!`#L```"(Y0$`(@```,3E`0`M````Y^4!
M`",````5Y@$`)@```#GF`0`J````8.8!`"4```"+Y@$`(P```+'F`0`L````
MU>8!`"$````"YP$`/````"3G`0`H````8><!`#H```"*YP$`(P```,7G`0`U
M````Z><!`"L````?Z`$`+@```$OH`0`N````>N@!`"D```"IZ`$`+@```-/H
M`0`K`````ND!`#`````NZ0$`+@```%_I`0`I````CND!`"D```"XZ0$`,P``
M`.+I`0`D````%NH!`"X````[Z@$`*@```&KJ`0`C````E>H!`$,```"YZ@$`
M*0```/WJ`0`L````)^L!`"P```!4ZP$`+0```('K`0`G````K^L!`#<```#7
MZP$`'0````_L`0`K````+>P!`"P```!9[`$`-P```(;L`0`L````ONP!``P`
M``#K[`$`$P```/CL`0`@````#.T!`#$````M[0$`)````%_M`0`)````A.T!
M``\```".[0$`'````)[M`0`4````N^T!`!````#0[0$`,0```.'M`0`(````
M$^X!``@````<[@$`(P```"7N`0`F````2>X!`"<```!P[@$`'P```)CN`0`)
M````N.X!`.$```#"[@$`$@```*3O`0`:````M^\!``D```#2[P$`#````-SO
M`0`4````Z>\!``X```#^[P$`&@````WP`0`&````*/`!`#<````O\`$`%0``
M`&?P`0`7````??`!``<```"5\`$`$P```)WP`0`+````L?`!`#P```"]\`$`
M*P```/KP`0`0````)O$!`!,````W\0$`$````$OQ`0`5````7/$!`#0```!R
M\0$`#@```*?Q`0`/````MO$!`!````#&\0$`&@```-?Q`0`+````\O$!`!L`
M``#^\0$`"P```!KR`0`D````)O(!``H```!+\@$`&P```%;R`0`'````<O(!
M`"<```!Z\@$`!P```*+R`0`)````JO(!``D```"T\@$`.P```+[R`0`&````
M^O(!``X````!\P$`$P```!#S`0`6````)/,!``H````[\P$`"````$;S`0`'
M````3_,!`!,```!7\P$`"P```&OS`0`-````=_,!`!P```"%\P$`#P```*+S
M`0`8````LO,!`!8```#+\P$`!0```.+S`0`'````Z/,!`!<```#P\P$`!```
M``CT`0`S````#?0!`!````!!]`$`#````%+T`0`"````7_0!`!$```!B]`$`
M(@```'3T`0`+````E_0!``,```"C]`$`!P```*?T`0`(````K_0!``0```"X
M]`$`!P```+WT`0`%````Q?0!``D```#+]`$`'0```-7T`0`&````\_0!``T`
M``#Z]`$`"@````CU`0`4````$_4!`!4````H]0$`$0```#[U`0`V````4/4!
M`!X```"']0$`&@```*;U`0!@````P?4!`&$````B]@$`"P```(3V`0`S````
MD/8!``<```#$]@$`%P```,SV`0!+````Y/8!`!0````P]P$`#P```$7W`0`(
M````5?<!``0```!>]P$`!````&/W`0`6````:/<!``4```!_]P$`!@```(7W
M`0`(````C/<!``0```"5]P$`"0```)KW`0`.````I/<!``@```"S]P$`!0``
M`+SW`0`7````PO<!`"````#:]P$`(0```/OW`0`E````'?@!`!````!#^`$`
M`@```%3X`0`$````5_@!``H```!<^`$`"0```&?X`0`=````<?@!``4```"/
M^`$``@```)7X`0`?````F/@!`$X```"X^`$`'@````?Y`0`S````)OD!`$P`
M``!:^0$`*@```*?Y`0!@````TOD!`#H````S^@$`3P```&[Z`0`V````OOH!
M`#,```#U^@$`$````"G[`0`G````.OL!`'P```!B^P$`)P```-_[`0!3````
M!_P!`%(```!;_`$`.````*[\`0`S````Y_P!`"8````;_0$`,P```$+]`0`T
M````=OT!`#D```"K_0$`.````.7]`0`_````'OX!`#\```!>_@$`+0```)[^
M`0`S````S/X!``X`````_P$`#@````__`0`-````'O\!`(,````L_P$`"```
M`+#_`0"-````N?\!`(@```!'``(`+@```-```@`4````_P`"`!,````4`0(`
M&````"@!`@`2````00$"`",```!4`0(`&@```'@!`@`8````DP$"`%8```"L
M`0(`%@````,"`@`+````&@("``4````F`@(`!@```"P"`@`(````,P("``4`
M```\`@(`&P```$("`@`1````7@("`!X```!P`@(`'P```(\"`@`8````KP("
M`!$```#(`@(`!P```-H"`@`1````X@("``0```#T`@(`"0```/D"`@`.````
M`P,"``D````2`P(`"````!P#`@`(````)0,"``4````N`P(`'````#0#`@`.
M````40,"``H```!@`P(`"0```&L#`@`/````=0,"``X```"%`P(`$P```)0#
M`@`'````J`,"``@```"P`P(`"@```+D#`@`2````Q`,"``<```#7`P(`"@``
M`-\#`@`6````Z@,"``@````!!`(`"P````H$`@`)````%@0"`!H````@!`(`
M"````#L$`@`$````1`0"``D```!)!`(``P```%,$`@`'````5P0"``4```!?
M!`(`"@```&4$`@`*````<`0"``8```![!`(`!P```(($`@`#````B@0"`!<`
M``".!`(``@```*8$`@`+````J00"``8```"U!`(`!P```+P$`@`M````Q`0"
M``D```#R!`(`!````/P$`@`3`````04"`!<````5!0(`"P```"T%`@`1````
M.04"`!,```!+!0(`!P```%\%`@`&````9P4"``@```!N!0(`$````'<%`@`2
M````B`4"``<```";!0(`"@```*,%`@`R````K@4"``<```#A!0(`"0```.D%
M`@`1````\P4"`!,````%!@(`!0```!D&`@`5````'P8"``(````U!@(`"P``
M`#@&`@`$````1`8"``@```!)!@(`!0```%(&`@`$````6`8"``$```"[!```
MSP8``"$%``!&`P```````(T!``!=`@``BP0```````#;!@``M@$``$H"``"%
M`````````-H%``!R`@``$0<``````````````````,<```!V!0```@0``.P%
M```E````PP,``*L#```B!P```````.D#``"1`0```````!0#````````CP(`
M``````!A````G`(``/L#``!E`P```````````````````````+X$``!+!0``
M$P````$'``!@!P``ZP$``%\"```K!````````&L"```:!````````"H!``#=
M!0`````````````F!0``B08``"L!``!M!@``E`4``.X"``!I`0``+P<``+`!
M``"[`@``YP```%4#``!]!@``)0<````````Y`0``(0,```````!#!P``\P``
M`)`&````````MP,```````#"!@``Y`8``'\$``!/`@``_`````````!4`@``
M`````,P$``!^!@``TP4`````````````/@<```````##!0```````'P#````
M````-0```-\&````````O`$```````#&!@``[@8```````!_!P``_@,``(('
M```)!````````&L'```^!```P@4``-8"``!C!P``#@```'P'```L````4```
M`*L!````````P@0``)\"``!&!```3`,``!\!``!>`0````````````!<!```
M``````````!4`0``>0```,4!````````]08`````````!P``EP``````````
M````A0(```````#_`@``7`8``.D!``#F````"P,``,P!``#``0``F`,``"X#
M``!T!0````````H'```(`P``^P```*H%``"Z!`````````````"0`P``500`
M``````#!!0``2`,``%T#``"`!```]@,```````"%!@``KP$``(0#``#%!```
M=0<``',```#:`0```````+8#```-!P``FP$``$0$``#5`0``.`8``$8```"(
M!```````````````````$@,``&H'````````<@$```````":!0```````)T&
M``#^`@``J08````````A````[P$```````!6!P``P@,``"$&``".!```5`8`
M`$($`````````````(<"````````C`8``&\#``"R`````````*8%``!3!```
M=0$``-X&``!7`@``I0,``,D$``!?`P``(@`````````N```````````````A
M`@``C````-D$``!B````Z00``&($```]!P```````````````````````'T"
M``"U!0````````````"/`P``'0(``'8'````````&04``"8"````````````
M`#4%``#)`P```````.(`````````404``'X#``#Y`0```````$4#```!`0``
M`````#0$````````6P4``%4"``"5`0``V08```````!G!0``:@$`````````
M````008``.$```!'````0````````````````````"X!````````/`,`````
M``"'!```/04``+L!``"W!0``^0(``"D&```6!```5P```&4$````````%`0`
M`($```#8`P``8P8``(X%``"5!@``[P,``(0``````````````)P$```#````
M.P<``-(%````````K`,``%X````/!P``]````-X%````````80$```````!L
M````I0```)D```"4`@``W`0``(P!``!E!P```````-T#```M`P``J`(`````
M``#.!```408```````#8!```M`0``)0$````````%@<```D"``#8`0``(0$`
M`)H"```8!0```````!0%``![`@```````'$!``#X!0``9`$```P&``#L`0``
M#0,```````!8`P``-@0``(<!```\````MP$``%<#``!-!@``\@,``'@'``!+
M````S`8``&4"````````'@4``!D"``!O!@``]0````(&``"K!@``S@(``&(#
M``"!!0``>P$``'X$``#G`@``9`<``-P%```@`0```````+(%```%!P``LP8`
M`(<````&!```QP,``"<&```O!@``@P,``#X"``#I`@``10<``%L#``#G`P``
M`````$$````C!0``Z`4```````"J!@``(`8``*0```!\`0``#P8``#@'````
M````P`,``,L$```"`@```````&L```#^`0````````````#*!@``NP8``'L`
M``"K````]P8``"X"``#Q!0``A@0``)L#``#%````\`,```8&``!.`0``-0$`
M`+0%``"0`0`````````````$````&@8``)T$``#!`@``9@````````#*````
M`````($'````````Y`0```````#`!```XP,```````#]`P```````/H"```J
M`P``0`4```````!^`@```````(D```#E!```8`0```````!=!```!@```%0`
M``#N!0``G`,``'4%``#E````:`,``!,$```K!0``\P8``(`#``!F`@``````
M`&4!```I`@``"`````````"K!````````&P&````````D0```(X"``"G!0``
M+@8```````![!@```````%8!```1!```/0$```````!:!```XP```',"``!W
M!0``$@4``-P`````````%`(``$X&```D!```(P(`````````````>P,``/$$
M`````````````&4&````````Y@$``,P```#:`P``E@``````````````````
M``````!I`P````````````#(`@``$0,``%@!``#P!@```````-8!```)`0``
M1````+<$``"D!````````#P!``!T`P``U00``*````!%!```:00``'T```#*
M!0``1`(``&X"``!+!@``0`8``&X!``#U`0```````,<$````````&P``````
M```0!@``6`0`````````````$`0``"D`````````2P(`````````````X`8`
M`)4%````````UP8``'(#```S````,`$```8"``"_`P```````#D'``!0`0``
M40,``%(&``!Y!```K@```%`'``"H`P```````*<"```9!```#P0``-X$``#R
M`0``I`$``.`"``#7!```4@4```````"3`@```````)("```'`P``````````
M``"_`@```````(8````*`P```````&X'````````)P<``&T'``"]`0``[`8`
M```````````````````````+`0``1`4``#4&``!4`P``P`4``!D!``!,!```
MY0,``'0```"5`P``LP$``%`%``!?!```0@$``,("``"U!@``<`$``'\!````
M``````````````"R!@``(@0````````W!P``=`<``+H#``"A!@``X@$``*\`
M``!U!```'`$```````#?!0```````)@$``#A`0``ZP0``/P%```7!```````
M`%0$``"J````(P<``*,$``#4`P```````$\'``!'`@``=P0``````````P``
MN04``#D%``!P!P```````(T&``!^!0```````#$&````````"P0``'(```#>
M`P``0P```-\`````````/0```)\`````````0@(``"\````9!@``)P(``&("
M````````W0(``,$$``#T`P``H0(``)`$``#+`P``2`0````````,````````
M````````````!P$````````0!0``B04``'\"``#S!0``8`,``+X&``"O!0``
MEP4``/4$````````````````````````;`0``*D"``"W`@``!`<``'T#``#H
M`@```````.8$```J`@``N@4```````"Q!```.`$```````"T`@``DP```,,$
M```W!0``30$``"X'````````^`8``%D"``#.`0``%00``(<#``#C!```;`$`
M`"`$````````=@0``%D``````````````)D&```D`@``10(`````````````
M%04```\``````````````-D#``"C`0``>@4``"H```"X!0``LP(```````#R
M!@``R`0``%<%``!)`0`````````````.`@``'0<``-$&````````'@``````
M``!&!0``+@0``"\"``#B!@``9`,````````O`0``3@0``+D"```'!@``````
M`(@````H`P``/@4``#(!```>!```TP$```````#(!0``G@(``-L!```Z`P``
MX@,``&<$`````````````!\'``!)`P``Y`4``$D'``"$!@``50```!`"```5
M`P``D@4``'H$``"\!@```````'H&```4````*@4```4$````````@````(8#
M````````F04``&$%```$`@``Y@(``"D!````````E0```.0```!I!0``````
M`+T%```C`0``T`$``&X```!X`P``H0```&4```#:`````````%4'``#!`P``
M;P0````````2````DP8``&0&``#E`@``=@$````````S`P``:`<``&,$``#\
M`P``:````$T%``"Z!@``8P(``.@`````````A0<``)D#``!:`P``<`8`````
M`````````````'('``!=`0````````````!J`@``=@``````````````=`(`
M``````#$!@``_0$```$%``!F`0````````````#1`@``-0,``!4!``!6````
M:@````````"V!@``Q`(``+`&````````````````````````'`<``$P&````
M````,P<```````#]````/P<``/$!``"]!```$``````````C````3`4``$\$
M````````=0,```````!%``````````L'`````````````#D$```)!@``&@``
M`#0```"`!0``6`8``*("``"/!0``[@```#`$````````<P,``#@%``"$`0``
MJ@$```````"=!0```````+L`````````*0<``!L$````````FP0``$,$``"3
M!0``>04``&D```````````````````"X!```$0$``%8&``#'!@```````-4&
M````````[@$``"@$``!D`@``(`<``"8$```>!P```````&X&```4`0``````
M`$4&``"6!@``J00``&(&````````EP$```,&`````````````%D#``"<!@``
M`````+L#``#X`0``DP$```\#````````0`,`````````````Z@(``-4"``!Z
M````:@8``-X`````````+`,``%X'``#O!0``\0,``,L%```E`P``````````
M````````F`8``+T"````````8````-<```!8!0``*````+$"``",!```````
M`.H```!:`@``E@$``$@"````````'`,```````!)`@``(P,``$<#``"N!@``
M`````-4```"8!0``>0<``#$"````````9@<``(8!```P!0``ZP8``/X%``#G
M!```$P<````````P`P``:P4``%0'``#"`0``)08`````````````````````
M````````[P0``+H"``````````````X$``#/!```_`8``$,#`````````P(`
M`"0&``"U!```6@4````````"!0``?P```.P"``"#`0```````+0`````````
M^@$````````\!P``,`<```````"#````?@````````!A`@``8`$``%4!````
M````1`$``,8#``"M!@``````````````````'0```.4&`````````````(8%
M``"\`@```````#4$``#Z!0``3`<``+D```!1`0``B@8``*4!```(`@``/`(`
M`&L#```Q````WP(``+P```!9!0``VP,``%(!````````L08`````````````
M`````%,#`````````P<``"P'````````0`(```````!)!@``;0(````````4
M!@```````.\&````````P0```%L&````````[0$``(T```!$!@```````'0$
M``!3!P```P$``#`"````````^`(```````"=````/P,``/\```"<!0``BP8`
M`-(&```^`0``%P<```````!Z`0``+`0``+D!````````A`(``"(#````````
M/P```$L!````````B@0```````!#`0``;P```'P%``"+`P```````!<`````
M````M0`````````2`0``D00```P!``!T!@```````,0!``#`````S@,``,0%
M``````````````\%`````````````,0```"_````8P```'$%```'````7@4`
M`-L$```#`P``!0(``/````!!`0``EP8``*P!``#G`0``-@8``'P&````````
M7````&,!``"E`@``*@0````````1````G0(```````"?`P``L@$``%,"````
M`````````+8"```R!```?04``,T&``!#`@``H`4``.4!``"2`P```````(@%
M``!K`0``N````,,&```I!0``HP(````````)!P``7@(```````#7`P``````
M``$"```;`0``$`,``#,$`````````````,D"```,!P``=P8``$,%````````
MT`4``'`$```Z!@```````.$"``":!```^P$````````8````F@,``&\!```@
M`P```08``%`"``#:`@``<`4``,8`````````O0,``-("``!7!@```````&0$
M```G`P```````!P"``">!0```````,\%``!@!0````````````#Y!@``2@``
M`#,"```R````P@```.D&``!A!P``\P(```````"`!@``"`<``#(&```!!```
M`````-$!``!.`@``_P8``!<#````````10$``,4&```M!```E`8`````````
M````>0$``,\```#3`P``W08``,,```!^`0``J@0``%4%``"8`0``;`<```X%
M````````@08``)D$````````X`0``*(#```````````````````X!```3P8`
M`)\$``!R!0``IP,````````J!P``RP$``*(!````````D04```````"_!@``
MH@4```````#[!@``80,```D```#Y`P``Z04``$X'``"#!0``+`(``$T`````
M`````````)$#````````"`0``!H'`````````````-\$``#E!0``_@0``*0%
M``"A!```#0```%L!``#'`@``3@4``(T"``#C`@```````&P"``"K!0``Y@,`
M`$@!``!7!```#08````````S!0``&@$```````#<`P``L@0``+0&````````
M+P,```````"S`P``7`4``&8$```[!@``!`$```````!*`0```````+,```!7
M`0``W00``)0`````````M`,``#,&`````````````-$```"/````````````
M````````M@0```````!&!P``>08```H%``#2!```T0,``"$'``"P`P``AP4`
M`!@!``#9````-`8``+````"Y!`````````X&``#@````*`$``(L"``""`@``
M2P0``"8&``#V!```GP4``&<"``"Y!@``#`0``,X%``"&`@``4P````````#3
M!```9@4``#T&``"Y`P```````*T%```5!P``I@0```T$`````````````)P!
M```=!````````.X#``!_!@```````)0#``#T!@```````'T$``!Q`@``%P8`
M`$@%``#$`P```````%H!``!=!P``]P(``-L"``!+!P``<P4``(T#``!<`0``
M(P8``````````````````*<&``#(`P``-`,``.X$``#,`P``800``%T````?
M!0``H`8``'````")`@``Y`,``*$#```:!0``?0<``.8%``!@`@```````"``
M````````-@,``"T%```"!P``V@0```````!0!@`````````````D!P``^P4`
M```````R`@````````````#0!```Q@$``-,````;`P``#P$``.`%```H!P``
M`````%\&```L!0```````&<!``"8`@``L`0``!\"``!!!`````````````!"
M`P``@@4````$``!\`@``508``-@```"3`P``1@8``#$'`````````````-8&
M```,!0```````*<$````````M0,``,`&`````````````!8"``"I`P``U04`
M`!@'``#V!@``$P(``)$"`````````````"<$``!U`@``<0```.T&````````
M/P$```,%```&!P``[````)(````D`0``E00``&T#``#X!````````!,%``#>
M`0```````-T!````````[`0```````#/`0``004`````````````D````-,"
M```A!```SP,``"X%```$!@``J@,```````#M`P``R`$`````````````U`(`
M`(4#``#\`0``"04``"L```#R!0``.0```$<'``!K!@```````*X#``!H`0``
M`0,``%,%```F!P``C@```'0!````````N@```&0```!M!```'`0``*D!``"#
M`@``H04``*`"``#/`@```````!\$``"L````'@(``(D#``#P`@```````(H%
M````````$@8``)8$``````````````````!J!0```````,D!``!^!P``^@,`
M`/\%````````'````*P%``"I``````````````!Q!```&`8```````!:````
M,@4```````"U`@``.@<``(,&``!Z`@``5@(``(`"``#H!@``/@8``#\&``"2
M`0```````!H"``#K````&P<``"8```!$!P``%08``#P%``"X`P```````!X&
M``#T!0``;0$``$0#```[`0```````#T$``!/!0``C00``*4%``"\!0``9P,`
M``````!9`0``'@$``-8#```+`@```````*P"``!<!P``*0,``"D$``""`0``
MV0$``,T#``#[!```L@,```````"5`@``_P$```T"``!/`0``-P0``%H&````
M`````````/`!```G````@`$``.,&``#]!@``UP(``-P!``"_`0``7`(`````
M``#8`@``Q0(``*T"``":`0``Q@0``"0`````````>`````````#W!0``>`0`
M`#0"```#!`````````````#4!0``4@<``)8#``"&!P``<0,```````!Y`@``
M]@```&8#``"M`0``<@8``$@`````````.@(``&,%````````<`,```````!K
M!`````````H&``#7`0``"@(```````"I!0``=P,``(L```#H`P``U@4``)L&
M``![!`````(```<"``#(````G0,`````````````(`4``/@````1`@``````
M`$(%`````````````.H#``"T`0````````````#*`0``$@(``/8%``!H!@``
M)P4```````"+`0```````*8"``"@`P``)`,`````````````FP4``.,%``#?
M`P````````````#\`@``X00``'D#``#K`@````8``(<&``#$!```````````
M```S`0``-`<```````!A!@``4`,````````2!P``EP,````````U`@``%@``
M`!T&``!B`0`````````````[`@``````````````````*P8``'@!```V!0``
MP0$``"4%``!W`0``4@```)X&```W!@``T`,```L%``"H!```E@(```````"*
M````7@,``((&```?````V0(``,T!```9`P``Y`$`````````````6@<``'H#
M``!1`@``B`(``.T%``!*!P``X@0```````!1!`````````````#Q````L04`
M`)H&````````)@$``*0#```Y!@``;P4``%\```!;`@``+0(``#P$``#A!@``
M`````````````````````,D``````````````%`$``!O!P``7@0``/\$``!`
M`0``30<``%(#```;!@``.@````X'`````````````,,"```^````'P,```0$
M````````^0```&8&``"N`0``_`0``#D#``#Y!```%@4```````"3!```\P,`
M``````!"!@``````````````````$04```````"W````M@```"H&``#J!@``
M[0````````!8!P``]0(``*X$``#0!@````````````!C`P``^`,``/L"``"?
M`0```````-@&``!9!```U`````````#<!@```````*X"``#T!```-@<``#H!
M````````L0```#$!``#R`@``O@$``'P$```B`0``K0```$H%```*!```=08`
M`,`"````````A`<```````#U`P``B@$``'\#``"=`0```````(P#``!)!0``
MZ@$``/$"``!,````C@$``,L`````````KP(``$\````P````&P(```````!B
M!P```````)($``"V!0``>`4``+L%`````````````"4!``#G!@```````($$
M``"*`P```````*`!`````````````($!````````F0(``&`&```6`P``O@,`
M``<%``!U``````````P"``#R!```$`<``.D```#Y!0``QP4``-0!``"E!@``
MS0(``+<&``!2`@``5@,``((#``"A`0``KP,``,D%``"0!0```````+`%````
M````Q04``%8%``">`0``X@(``.<%``!I!@`````````````"`P``$P8``)X$
M``````````````````"9`0``.````($#`````````````#L$````````#0$`
M`($"``!'!0``)@,``(L%``!H!````````$`'``!B!0``>`8``"L#``#O````
M1P8``+@&````````````````````````U@```%,!``"]````:`(``#H%``#?
M`0``T00````````V`@``708``!T%````````QP$``,H"``!-!```_0(`````
M``"'!P``````````````````O`,``,P"``!<`P``FP```(`'````````````
M`````````````````"\$````````0@<```````#(!@````````P#```(`0``
M/0,```````#*`P``40<``#<#```E`@``F@```.@!``!!`@``.P4````````%
M!@```````(0$````````1P$``$P"```Z!```2`<``&T%`````````````'`"
M```R!P``HP```"P!```5`@``_@8```````">````=P<``,T$``"6!0``K`8`
M`!<%```U!P```````#$#``!6!`````````````!8`@``V04``&H$``!+`P``
M``````````")`0``RP(``#@"``"O!````````'($``!I!P``?```````````
M`````````.0"````````(@4``$\#```T!0``!@,`````````````T@,``(($
M``"G`0```````+@"```M`0``B`$``+H!````````60<``#\"``!!`P``A`4`
M```````@`@```@$``*(`````````T@```)<"```D!0```````-T`````````
M<0<```````````````````````"2!@``XP$```0#``#>`@``D08``$8!```(
M!0``>`(``!8&````````904```````````````````4#``!;````%0```'L'
M``!7!P``>P4``#L```!Q!@``)00``+$!``##`0``-P```%($``#:!@``;@4`
M`/`%``!.````%@$``/4%```Y`@``\`0``$8"``"C!0```````.(%```9````
M/P4``,T%``!(!@``@P0``-8$``"K`@``S@8```````"L!```Y@8``/\#```(
M!@``+0<``.L%```H!0```````!@#``!4!0``!`4``!<!```/`@```````&@%
M````````-`$``"@"``#W````-@$``!@"``#;`````````!D'``!-`P````$`
M`+\%``"(!@```````&<'``",`@````````````"H!0``7P$``+X```"8````
M`````+,%````````G`````D#``"H`0````````````!N`P```````&D"``"^
M!0``M0$```````!J`P```````(\!````````Q@(``+@!```3`0``.P,``((`
M``"\!```I@,``$`$```0`0``]@(```````!N!````````"\%```Q!0``````
M`.\"````````/`8``,H$````````B@(``'<```"-!0``%`<``)L"``!?!P``
M&`0```(```!-`@``#04`````````````104``&P%``#.`````````'<"````
M````B`,``/H$````````'0,``(X&```'!P``2@0``#(#````````0@```(4$
M``#0`@``&P4``.$%`````````````/$&``!!!P``^@```.H%```W`@``````
M`*4$````````20```-4#````````RP8```````"S!```*`8``*H"````````
M#@$``',&````!0``U`8`````````````!0```.`!```.`P``!0$``+T&``!Z
M!P```````-```````````````.$#``#;!0``HP8``#\$````````<P<``.T"
M```+````!P0```H```!V`P``T@$``$D$``"_!```'@,``!,#``#^````````
M``````!_!0``J`8```````#]!0``T04``%X&``"C`P``K0,```````!'!```
MA0$``&P#``"7!```[`,``!$&````````!04``(8&``"/!````````'T!```Q
M!```I@````L&``!V`@``;0```&<&````````H`0```````#T`@``TP8``%\%
M````````[00``.L#``#8!0``(@8``-P"````````Z@0``.@$``"D`@``=@8`
M`*8!``!#!@``608``*8&```K!P``6P0````````V````(P0``/(````B`@``
M`````/,$``"Q`P``C`4``)\&``"0`@``@P<````````X`P``'P8```````#Z
M!@```````,4#``!*`P``````````````````4P8``$H&``"N!0```````/<#
M``"^`@``\P$``(4%``!O`@``KP8``#X#``!S`0``E`$``-<%```7`@``R08`
M`%L'```M`````````+("``".`P``40`````````W`0``````````````````
M_00``/8!```:`P``H@0``#`&`````````````*<```!G````'`8``+`"````
M````J`````H!````````*P(``',$``!8````S`4``"<!``")!```````````
M```&!0```````/<$``#&!0```````!T!`````````````,T```#!!@``````
M``````!=!0``$@0``.`#```<!0``]`$``*T$``"B!@```````$P!```L!@``
M]P$``$X#``#4!`````````````">`P``!@$``*0&``"/!@``/0(``&0%```M
M!@```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@
M*'EE<W1E<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60@979E;G1S`"5D+61A
M>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!$87DH<RD@)7,@2&]U<BAS*2`E
M<R!-:6YU=&5S`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M
M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S
M`"5S(&%T=&5N9&5E<P`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E
M<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@
M)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S
M($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@061D("H`*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("H`
M+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S
M96QE8W0@+2T`,2!A='1E;F1E90`Q(&5V96YT`#$R($AO=7(@1F]R;6%T`#(T
M($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T`04T@4VAO=V5R<P!!32]030!!4$D@240`
M06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O
M<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@
M4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061?=F%N8V5D
M(%-E87)C:`!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S
M:6]N`$%D9"!%=F5N=`!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W
M(%!E<FUI<W-I;VX`061D(&$@;F5W(%)E;6]T92!#86QE;F1A<@!!9&0@82!N
M97<@979E;G0`061D(&$@;F5W('5S97(Z`$%D9"!A='1E;F1E97,`061D(&-O
M;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU
M(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D
M9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@
M<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO
M;@!!9',`061V86YC960@4V5A<F-H`$%F9VAA;FES=&%N`$%L87)M`$%L87)M
M("5D(&1A>7,@8F5F;W)E`$%L87)M("5D(&AO=7)S(&)E9F]R90!!;&%R;2`E
M9"!M:6YU=&5S(&)E9F]R90!!;&%R;2`E9"!W965K<R!B969O<F4`06QA<FT@
M,2!D87D@8F5F;W)E`$%L87)M(#$@:&]U<B!B969O<F4`06QA<FT@,2!M:6YU
M=&4@8F5F;W)E`$%L87)M(#$@=V5E:R!B969O<F4`06QA<FT@1&%T90!!;&%R
M;2!3<&%N("AM:6YU=&5S*0!!;&%R;2!4:6UE`$%L8F%N:6$`06QG97)I80!!
M;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@071T96YD965S`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!&=71U<F4`06QL($=R;W5P<P!!;&P@
M4&%S=`!!;&P@4&5R;6ES<VEO;G,`06QL(%9I<VEB;&4`06QL(&1A>0!!;&P@
M9&%Y(&5V96YT`$%L;"!E=F5N=',`06QL(&9O=7(@<VED97,`06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L
M=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE
M`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`
M06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO
M;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A
M<F)U9&$`06YY`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I
M;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU3
M0TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!
M<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O
M;'5M;G,`070`071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@=VET:"!M
M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('1H92!E=F5N="X@268@>6]U<B!M86EL
M(&-L:65N="!S=7!P;W)T<R!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E('1H
M:7,@9FEL92!T;R!E87-I;'D@=7!D871E('EO=7(@;&]C86P@8V]P>2!O9B!T
M:&4@979E;G0N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E
M;F1A;F-E`$%T=&5N9&5E<P!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`
M075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@
M<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($94
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M
M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A
M9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U
M=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@
M34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I
M<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I
M;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z
M97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#
M;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R
M;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A
M;F=L861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R
M=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD
M87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`
M0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA
M<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES
M;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R
M=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0G5S>0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@
M4&]I;G1S`$-?86QE;F1A<@!#7V5L;"!0<F]P97)T:65S+BXN`$-A;%]E;F1A
M<@!#86QE;F1A<@!#86QE;F1A<B!3=6UM87)Y`$-A;&5N9&%R<P!#86QM`$-A
M;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&-R96%T92!A(&YE=R!E
M=F5N="X`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N
M8V5L;&5D`$-A;F-E;&QE9#H@)7,`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S
M=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R7WD`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL
M90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4
M<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@
M=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('1H
M92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z
M`$-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N`$-H<FES=&UA<R!)<VQA
M;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L
M96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S
M97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E
M;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]C;W,@
M*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`
M0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L
M=6UN('1I=&QE<P!#;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A;'5E<P!#;VUM
M86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S
M`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYF
M:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\`0V]N9FER;65D`$-O;F=O`$-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F
M86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN
M96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&EN
M=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O
M<'D@=&AE(%523"!B96QO=R!F;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO
M=7(@1G)E92]"=7-Y(%523#H`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-R96%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES
M="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S
M+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#
M;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R
M9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@
M9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D
M9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET
M:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+@!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A
M=&4@82!.97<@179E;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE
M`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R;6ES<VEO
M;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT`$-U
M<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R
M<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`
M0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R
M-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI
M8P!$1`!$86EL>0!$86EL>3H@4F5C=7)S(&5V97)Y`$1A=&%4<F5E($)R;W=S
M97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$87DH
M<RD`1&5?;&5T90!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU
M;6)E<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@0V%L96YD
M87(`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9FEN:71I;VYS
M`$1E;&5T90!$96QE=&4@)7,`1&5L971E($5V96YT`$1E;&5T92!'<F]U<`!$
M96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E
M;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R
M;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R
M<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U
M<F4@;V-C=7)E;F-E<RP@;W(@86QL(&]C8W5R96YC97,_`$1E;&5T92!T:&4@
M8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:5]P=&EO
M;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0
M;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I
M<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T
M`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES
M<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F
M;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO
M="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'``1&\@>6]U('=A;G0@=&\@<VAO=R!T87-K<R!W:&EC:"!A<F4@9'5E(&]N
M('EO=7(@8V%L96YD87(_`$1O97,@;F]T(')E8W5R`$1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D
M`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$1U93H@)7,`
M1'5R871I;VX`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="`E<P!%9&ET
M($%T=&5N9&5E<P!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S
M:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`
M161I="!296UO=&4@0V%L96YD87)S`$5D:70@871T96YD965S`$5D:70@8V%T
M96=O<FEE<R!A;F0@8V]L;W)S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R
M;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%
M;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S
M<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I
M8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C
M:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O
M($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/P!%;F0@1&%T90!%;F0@3VX`16YD(%1I;64`16YD('EE87(`16YL
M87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z
M`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<75A=&]R:6%L($=U:6YE80!%
M<FET<F5A`$5R<F]R`$5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N(&9O<B`E<SH@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%
M<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E;G0@9G)O;2`E<R!T
M;R`E<P!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S
M,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H
M86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E
M`$5X<&%N9`!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP
M;W)T`$5X<&]R="!#86QE;F1A<@!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E
M='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@
M=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U
M87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9I:FD`
M1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE
M($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D
M`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;F0`1FEN
M;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``
M1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R:61A>0!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N
M`$9U;&P@36]O;@!&=6QL($YA;64`1G5T=7)E`$=A8F]N`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'86UE`$=E;F5R86P`
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R
M9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E
M9&5L`$=O;V=L92!396%R8V@`1V]T;R`E<P!'<F%Y<V-A;&4`1W)E96-E`$=R
M965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI
M;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U
M<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!0
M97)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y
M86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`
M2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`
M2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E
M(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`
M2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E
M;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$
M(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN
M;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D
M9&EN9P!(;W)I>F]N=&%L.@!(;W5R*',I`$AO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F
M86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)
M4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L
M86YD`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M
M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P
M96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I
M8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O
M(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@
M55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!)
M;6%G92!U<&QO860`26UA9V5S`$EM<&]R="!#86QE;F1A<BP@4W1E<"`E9`!)
M;7!O<G0L(%-T97`@)60`26UP;W)T+T5X<&]R="!#86QE;F1A<@!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E
M<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A
M<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN
M9F\`26YF;W)M871I;VX`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM
M86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU
M;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C
M96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F
M=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E
M<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN
M<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E
M<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!)
M;G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T
M:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D
M+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F
M;W)M870`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P
M:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@
M<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@
M<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@
M=6YI8V]D92!D871A+@!);G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R
M;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y
M`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*
M=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`
M2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R
M:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN
M9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97EW;W)D
M<P!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`
M2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T(#(T(&AO=7)S`$QA<W0@2&%L
M9@!,87-T($UO9&EF:65D`$QA<W0@36]N=&@`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,87-T('=E96L`3&%T=FEA`$QA=P!,87EO
M=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F
M="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!
M<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI
M9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG
M:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@
M4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6UI="!T:&4@=&EM
M92!S<&%N('1O(&5X<&]R=#H`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI
M<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S
M8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,
M:71H=6%N:6$`3&]?8V%T:6]N`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!4
M87-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N
M`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R
M(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G
M`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A
M+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E
M<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA
M:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L
M=&$`36%N86=E(')E;6]T92!C86QE;F1A<G,N`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3
M965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@
M26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ
M=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A
M;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-965T:6YG
M`$UE;6)E<G,`365N=2!,:7-T`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S
M<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I
M9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S
M<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!-971H;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;G5T92AS
M*0!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S960@179E;G1S($QI<W0`36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S
M:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF
M:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC
M(&]F`$UO;F%C;P!-;VYD87D`36]N9V]L:6$`36]N=&@`36]N=&@@5FEE=P!-
M;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1H;'D@179E;G1S($QI<W0`36]N
M=&AL>3H@4F5C=7)S(&5V97)Y`$UO;G1H<R!!:&5A9`!-;VYT:',@0F5F;W)E
M`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE87(`
M36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F
M=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB
M:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@:4-A
M;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S
M=7!P;W)T960N`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($-A
M;&5N9&%R<P!->2!#86QE;F1A<G,Z`$UY($9R964O0G5S>2!54DP`37D@4&]R
M=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R
M964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE
M<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!
M(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A
M<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE
M=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!%=F5N=`!.97<@36]O;@!.
M97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W
M("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@,C0@:&]U<G,`
M3F5X="!$87D`3F5X="!-;VYT:`!.97AT(%=E96L`3F5X="!D87D`3F5X="!O
M<'1I;VYS`$YE>'0@=V5E:P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H
M=`!.:75E`$YO(&%T=&5N9&5E<P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP
M;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BX`3F\@8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S
M+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES
M('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C
M<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&5N9"!D
M871E`$YO(&5V96YT<R!T;R!D:7-P;&%Y`$YO(&9I;&4@=7!L;V%D960`3F\@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@)7,`3F\@
M:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N
M`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N
M=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.
M;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@
M8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V
M86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QI9"!E;6%I;"!A9&1R97-S
M(&9O=6YD`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO
M<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE
M;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@
M069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&9O=6YD`$YO
M="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3F]W`$YU;6)E
M<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB
M97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T
M;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z
M($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A
M<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG
M(%-Y<W1E;0!/<'1I;VYA;`!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R
M960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A
M;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L
M('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N
M97(`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP
M=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T`4$T@3&EG:'0@4F%I;@!032!3
M:&]W97)S`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A
M;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;&T@
M1&%T94)O;VL`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R
M=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W0@179E;G1S($QI<W0`4&%S=&4`4&%S
M=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0871T97)N`%!E;F1I;F<@4VEG;G5P
M<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_`%!E<FUI<W-I;VX`4&5R
M;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI
M<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E
M<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N
M`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A
M('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L
M(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S
M92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R
M>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N
M86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R=&%L($]P=&EO;G,`4&]R
M='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O
M9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``
M4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=P!0<F5V:6]U<R!$87D`4')E=FEO=7,@5V5E:P!0<F5V:6]U<R!D
M87D`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME
M>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T
M('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O
M4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0
M=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET
M*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!2
M86EN(%-H;W=E<@!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S
M<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8W5R(%5N
M=&EL`%)E8W5R<F5N8V4`4F5C=7)R96YC92!$871A`%)E8W5R<F5N8V4@16YD
M($1A=&4`4F5C=7)R96YC92!);G1E<G9A;`!296-U<G)E;F-E(%1Y<&4`4F5C
M=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`4F5C=7)S
M('EE87)L>0!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`
M4F5L871I;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UI;F1E<CH@)7,`4F5M
M;W1E($-A;&5N9&%R<P!296UO=&4@0V%L96YD87)S.@!296UO=&4@4V5R=F5R
M<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`
M4F5M;W9E`%)E;6]V92`E<P!296UO=F4@071T96YD964`4F5M;W9E($)L;V-K
M`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S
M="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``
M4F5Q=6ER960`4F5Q=6ER960@071T96YD965S`%)E<V5T`%)E<V5T(%!A<W-W
M;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S970@=&\@1&5F875L=',`4F5S
M<&]N<V4`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R
M="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D
M;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P
M97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T
M`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2
M;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U
M;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG
M`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE
M;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A='5R
M9&%Y`%-A=61I($%R86)I80!3879E("5S`%-A=F4@07,@3F5W`%-A=F4@179E
M;G0`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V-I96YC90!396%R
M8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&-O;F9I
M<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT
M('9I97=S(&%N9"!C:&]O<V4@9&5F875L="!V:65W+@!396QE8W0@=&AE(&-A
M;&5N9&%R('1O(&EM<&]R="!T;SH`4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM
M<&]R=#H`4V5L96-T('1H92!F:7)S="!W965K9&%Y.@!396QE8W0@=&AE(&9O
M<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@=&AE('1I;64@<W!A
M;B!T;R!S:&]W.@!396QE8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O;B!S=&%R
M='5P.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('=H:6-H
M(&5V96YT<R!T;R!S:&]W(&EN('1H92!P;W)T86PN`%-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3
M96YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F0@82!C86YC96P@;F]T
M:69I8V%T:6]N('1O(&%L;"!A='1E;F1E97,@=VAE;B!D96QE=&EN9R!T:&ES
M(&5V96YT`%-E;F0@86X@96UA:6P@=&\@)7,`4V5N9"!U<&1A=&5S+VEN=FET
M871I;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N
M=`!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E
M;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3
M970@96YD(&1A=&4`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@<F5C
M=7)R96YC92!E;F0@9&%T90!3970@<W1A<G0@9&%T90!3970@=7`@<F5M;W1E
M('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O
M<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N
M+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I
M<W!L87D@;W!T:6]N<RX`4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z(`!397EC:&5L;&5S`%-H87)E9"!#86QE;F1A<G,Z`%-H;W!P:6YG`%-H
M;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!C871E9V]R>2!L96=E;F0_`%-H;W<@
M9&5L971E+"!A;&%R;2P@86YD(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD
M87(@=FEE=W,_`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`
M4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R/P!3:&]W(&9R964O8G5S
M>2!L96=E;F0_`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\`4VAO=R!O;FQY(&5V96YT<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/P!3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@
M<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:6UE(&]F(&1A>2!B971W965N(&5A
M8V@@9&%Y(&EN('=E96L@=FEE=W,_`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO
M=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAR:6YK`%-H<FEN:R!O<B!M;W9E
M(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3
M:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R
M:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA
M`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@
M4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US
M`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F
M<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M
M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I
M;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O
M=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!$
M871E`%-T87)T($]N`%-T87)T(%1I;64`4W1A<G0@>65A<@!3=&%T7W5S`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B
M;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YD
M87D`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N
M<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R
M;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`
M4W=I='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I
M86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FUS`%135B!F:6QE`%1A
M8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@
M3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E
M<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5N=&%T:79E`%1E
M>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M
M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN
M`%1H92!%9&ET($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E
M;G0N($5X:71I;F<N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&-A;&5N9&%R("(E<R(@8V%N;F]T(&)E(&1E;&5T960N`%1H92!C
M86QE;F1A<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!C86QE;F1A<B`B
M)7,B(&AA<R!B965N(')E;F%M960@=&\@(B5S(BX`5&AE(&-A;&5N9&%R("(E
M<R(@:&%S(&)E96X@<V%V960N`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN
M('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S
M:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N
M960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H
M97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@
M=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S
M<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E;F0@9&%T92!M=7-T(&)E(&QA
M=&5R('1H86X@=&AE('-T87)T(&1A=&4N`%1H92!E=F5N="!N;W1I9FEC871I
M;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+@!4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@
M8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@
M9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@
M;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9O;&QO=VEN9R!I<R!A(&UO
M<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V96YT.@!4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H
M('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E
M<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO(&5V96YT<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82X`
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@
M<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T
M:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%C
M8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!A
M9&1I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@961I
M=&EN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U
M="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@;6]V:6YG
M('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@
M=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG(&%N
M(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<SH@)7,`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R="X`5&AI<R!)34%0('-E<G9E
M<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T
M:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O
M9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@
M=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES
M(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB
M97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@)R,Q,C,T868G+@!4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P
M;W)T960N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`
M5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E
M('9I<VET("5S`%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@
M86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C
M=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H
M=6YD97(`5&AU<G-D87D`5&EC:V5T<P!4:6UE`%1I;64@4W!?86X`5&EM92!4
M<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UE('-P86X`
M5&EM;W(M3&5S=&4`5&ET7VQE`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`
M5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O
M=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I
M;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U97-D87D`5'5N
M:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N
M`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP90!4>7!E('EO
M=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N
M86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L
M92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,`56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T
M92`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA
M8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@
M9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C
M="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`B)7,B
M.B`E<P!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M`%5N86)L92!T;R!R971R:65V92!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R
M("5S`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I
M;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N9&5R;&EN
M90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI
M8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG
M9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T
M:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP
M=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L
M;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T
M96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@
M:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D
M+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P
M9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D.B`E<RX`57!G<F%D92!S8W)I
M<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S
M`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`
M57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E
M<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($EN=&5R9F%C90!5<V5R($]P
M=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S
M(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`57-E<FYA
M;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A
M;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R
M;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E
M<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6
M:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!$87D`5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I
M;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@
M1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A
M=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E9&YE
M<V1A>0!7965K`%=E96L@)60`5V5E:RAS*0!7965K;'D`5V5E:VQY.B!296-U
M<G,@979E<GD`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T
M97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H870@=&EM92!S:&]U
M;&0@9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@
M;&%T97(@979E;G1S/P!7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V
M:65W<R!S=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_
M`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N
M:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z
M`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7
M;W)K(%=E96L`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@
M97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE87)L>3H@
M4F5C=7)S(&5V97)Y`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO
M=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL
M(&YA;64N`%EO=2!C86X@;VYL>2!U<V4@=&AI<R!F;W)M(&9R;VT@=&AE($5D
M:70@071T96YD965S('-C<F5E;BX`66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@
M979E;G1S('1O("5S+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A
M9&0@979E;G1S('1O('1H92!S96QE8W1E9"!C86QE;F1A<BX`66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N`%EO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="X`66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!S<&5C:69I960@86X@
M:6YV86QI9"!C86QE;F1A<BX`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I
M9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@8V%L
M96YD87(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%N(&%D9')E
M<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I
M9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@
M1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T
M($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9
M;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8V%L96YD87(`
M66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E
M('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II
M<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W
M(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`
M6U5N;F%M960@979E;G1=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T)A<VEC(%-E87)C:`!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?
M161I=`!?1V]T;P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN
M`%]);7!O<G0O17AP;W)T`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK
M+BXN`%]->2!#86QE;F1A<G,`7TYE=R!%=F5N=`!?3W!T:6]N<P!?4&5R;6ES
M<VEO;G,`7U!R:6YT`%]296UO=F4@3&EN:RXN+@!?4V5A<F-H`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?5&]D87D`7U5S97)S`&%D9')E<W,@8F]O
M:P!B969O<F4@=&AE(&5V96YT('-T87)T<P!C86QE;F1A<@!C86QM`&-L:6-K
M(&AE<F4`9&%Y`&1A>2AS*0!D87ES`&5V96YT<RYC<W8`979E;G1S+FEC<P!F
M86QL:6YG`&9I;&4`9G)O;0!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z
M`&EM;65D:6%T90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+@!M;VYT:"AS*0!N86UE`&YO="!I;7!L96UE
M;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;VX@=&AE('-A;64@
M9&%T90!O;B!T:&4@<V%M92!W965K9&%Y`'!E<F-E;G0`<&EX96QS`')I<VEN
M9P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`
M=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#86QE;F1A<B]I0V%L96YD
M87(`=D-A<F0`=D5V96YT(&YO="!F;W5N9"X`=SH`=V5A=&AE<BYC;VT`=V5E
M:P!W965K*',I(&]N.@!W965K<P!Y96%R*',I`%!R;VIE8W0M260M5F5R<VEO
M;CH@2W)O;F]L:71H(#(N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`T+3$R+3$Y(#$V
M.C0S*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!*86X@2W5I<&5R<R`\:G)K=6EP
M97)S0&QA=7=E<G-C;VQL96=E+FYL/@I,86YG=6%G92U496%M.B!$=71C:"`\
M:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@9&%G96X@9V5L961E
M;BD`("A3;F5L=&]E=',@)7,I`"`H=F%N9&%A9RD`("AG:7-T97)E;BD`(&]P
M(``E9"`E<R!E;B`E<P`E9"!G96)E=7)T96YI<W-E;@`E9"UD86<@=F]O<G5I
M='II8VAT`"5S("T@3W!M97)K:6YG`"5S(&1A9RAE;BD@)7,@=7)E;B`E<R!M
M:6YU=&5N`"5S('9I;F=E<F%F9')U:P`E<R!+0@`E<R!/;F1E<FAO=61S=V5R
M:WIA86UH961E;B`M($)E=F5S=&EG:6YG`"5S(&EN<V-H<FEJ=F5N`"5S(&=E
M8G)U:6ME<G-O=F5R965N:V]M<W0`)7,@8F5S=&%A="!A;"X`)7,@;W`@)7,@
M)7,`)7,@86%N=V5Z:6=E;@`E<R!B97-T86YD(&UE="!S=6-C97,@9V5I;7!O
M<G1E97)D`"5S(&ES('9E<F5I<W0`)7,@;6EN=71E;@`E<R!N:65T(&=E=F]N
M9&5N+@`E<R!T;W0@)7,@=F%N("5S`"5S)W,@861R97-B;V5K`"5S)W,@86=E
M;F1A`"5S)W,@;F]T:71I96)O96L`)7,G<R!T86ME;FQI:G-T`"5S.B`E<P`J
M($1E>F4@=&]E=F]E9V5N+"!K;&EK(&]P(%1O979O96=E;B`J`"H@4V5L96-T
M965R(&%D<F5S*'-E;BDL(&$N=2YB+B`J`"P@=VEN9'9L86=E;B`E<R`E<P`L
M('9A<FEA8F5L('9A;B`E<R!T;W0@)7,`+2T@<V5L96-T97)E;B`M+0`Q(&%A
M;G=E>FEG90`Q(&=E8F5U<G1E;FES`#$R('5U<G-W965R9V%V90`R-"!U=7)S
M=V5E<F=A=F4`,C0@=75R<P!%96X@9&%T86)A<V4@8F%C:V5N9"!I<R!V97)E
M:7-T('9O;W(@9&ET(&)L;VLN`$5R(&AE969T('II8V@@965N(&9A=&%L92!F
M;W5T('9O;W)G961A86X`165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES('9E
M<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@8V]D97)E;BX`165N(&]P96YB87)E
M(%!'4"!S;&5U=&5L(&ES('9E<F5I<W0@;VT@965N(&]N9&5R=&5K96YD(&)E
M<FEC:'0@=&4@=F5R:69IZW)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L
M+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V
M97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&1E8V]D97)E;BX`165N(&]P96YB
M87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W86-H='=O
M;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&]N9&5R
M=&5K96YE;BX`165N(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3
M+TU)344@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T
M(&]M(&5E;B!B97)I8VAT('1E(&1E8V]D97)E;BX`165N(&]P96YB87)E(%,O
M34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)344@<VQE=71E;"!E;B!W86-H='=O
M;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&]N9&5R
M=&5K96YE;BX`165N(&]P96YB87)E(%--24U%('-L975T96P@:7,@=F5R96ES
M="!O;2!E96X@8F5R:6-H="!T92!C;V1E<F5N+@!!30!"=6EE;B!V;V]R(#$R
M+C`P('5U<@!!32]030!!4$D@240`3W9E<B!D97IE(&5D:71O<@!/=F5R+BXN
M`$%B<V)O='1O;0!!8G-M:61D;&4`1V5A8V-E<'1E97)D`%1O96=A;F<@9V5W
M96EG97)D(&)I:B!H970@;6%K96X@=F%N(%9&4R!D:7)E8W1O<GDN`%1O96=A
M;F<@9V5W96EG97)D(&)I:B!H970@;6%K96X@=F%N(%9&4R!B97-T86YD+@!!
M8V-O=6YT=V%C:'1W;V]R9`!!8V-O=6YT(&)E=G)O<F5N+@!697)A;G1W;V]R
M9&EN9P!?56ET9V5B<F5I9"!Z;V5K96X`5&]E=F]E9V5N`$-H:6QD(&=R;V5P
M('1O979O96=E;@!#:&EL9"!R96-H="!T;V5V;V5G96X`1V5B975R=&5N:7,@
M=&]E=F]E9V5N`$AI97(@=&]E=F]E9V5N.@!.:65U=V4@9W)O97`@=&]E=F]E
M9V5N`$YI975W(')E8VAT('1O979O96=E;@!.:65U=V4@86=E;F1A(&]P(&%F
M<W1A;F0L('1O979O96=E;@!.:65U=V4@9V5B975R=&5N:7,@=&]E=F]E9V5N
M`$YI975W92!G96)R=6EK97(@=&]E=F]E9V5N.@!!86YW97II9V5N('1O979O
M96=E;@!+;VQO;2!T;V5V;V5G96X`3FEE=7=E(&QE9&5N('1O979O96=E;@!0
M86%R('1O979O96=E;@!(970@)7,@;65N=2!T;V5V;V5G96X@86QS(&5E;B!-
M;WII;&QA(%-I9&5B87(`5F]E9R!T;V4@86%N(&%D<F5S8F]E:SH`5F]E9R!T
M;V4@86%N(&UI:FX@861R97-B;V5K`$=E8G)U:6ME<B!T;V5V;V5G96X`5&]E
M=F]E9V5N('9A;B!G96)R=6EK97)S(&ES('5I=&=E<V-H86ME;&0N`$%D<F5S
M`$%D<F5S8F]E:P!"96AE97(@+2!R96-H=&5N('9O;W(@86YD97)E(&=E8G)U
M:6ME<G,@:6YS=&5L;&5N`$)E:&5E<@!!9'9E<G1E;G1I97,`56ET9V5B<F5I
M9"!Z;V5K96X`069G86YI<W1A;@!!;&%R;0!!;&%R;2`E9"!D86=E;B!V;V]R
M`$%L87)M("5D('5R96X@=F]O<@!!;&%R;2`E9"!M:6YU=&5N('9O;W(`06QA
M<FT@)60@=V5K96X@=F]O<@!!;&%R;2`Q(&1A9R!V;V]R`$%L87)M(#$@=75R
M('9O;W(`06QA<FT@,2!M:6YU=70@=F]O<@!!;&%R;2`Q('=E96L@=F]O<@!!
M;&%R;61A='5M`$%L87)M9'5U<B`H;6EN=71E;BD`06QA<FUT:6ID`$%L8F%N
M:>L`06QG97)I:F4`06QI87,`56ET;&EJ;F5N`%5I=&QI:FYI;F<Z`$%L;&4`
M06QL92!A86YW97II9V5N`$%L;&4@9V5A=71H96YT:6-E97)D92!G96)R=6EK
M97)S`$%L;&4@=&]E:V]M<W1I9V4`06QL92!G<F]E<&5N`$%L;&4@869G96QO
M<&5N`$%L;&4@<F5C:'1E;@!!;&QE('II8VAT8F%A<@!$92!G96AE;&4@9&%G
M`$=E:&5L92!D86<@9'5R96YD92!G96)E=7)T96YI<P!!;&QE(&=E8F5U<G1E
M;FES<V5N`$%L;&4@=FEE<B!Z:6ID96X`365E<F1E<F4@861R97-S96X@=&]E
M<W1A86X`26YS=&5L;&5N('9A;B!G96]R9&5N9&4@;&EJ<W0@='EP92!T;V5S
M=&%A;C\`0F5S=&%A="!A;`!!;'1E<FYA=&EE=F4@24U34"!A86YM96QD:6YG
M`$%L=&5R;F%T:65F($E-4U`@=V%C:'1W;V]R9`!!;'1E<FYA=&EE=F4@24U3
M4"!G96)R=6EK97)S;F%A;0!!;'1E<FYA=&EE9B!E+6UA:6QA9')E<P!!;'1E
M<FYA=&EE=F4@<VIA8FQO;F5N`$%L=&5R;F%T:65V92!T96MS=#H`06UE<FEK
M86%N<R!386UO80!%96X@;VYG96QD:6=E('=A87)D92!O<&=E9V5V96XN`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI96UE('!R;WAY`$%N='=O;W)D
M`$%N=&%R8W1I8V$`06YT:6=U82!E;B!"87)B=61A`$5L:P!4;V5P87-S:6YG
M`%1O97!A<W-I;F<@:7,@9V5R965D+@!/<"!C:&EL9'-H87)E<R!T;V5P87-S
M96X`1V]E9&ME=7)E;@!!<')I;`!!<F%B:7-C:"`H5VEN9&]W<RTQ,C4V*0!!
M<F-H:65F8F5S=&%N9'-G<F]O='1E`$%R8VAI969N86%M`%=E970@=2!Z96ME
M<B!D870@=2!H970@86%N;65L9&EN9W-V97)Z;V5K('9A;B`E<R!W:6QT('9E
M<G=I:F1E<F5N/P!!<F=E;G1I;FGK`$%R;65N:>L`07)M965N<R`H05)-4T-)
M22TX*0!+=6YS=`!!<G5B80!!<V-E;G-I;VX@96EL86YD`$%S8VEI(&MU;G-T
M`$%Z:>LO4&%C:69I<V-H92!296=I;P!/;2!B979E<W1I9VEN9R!V<F%G96X@
M=F]O<B!H970@=6ET=F]E<F5N('9A;B!O;F1E<FAO=61S=V5R:WIA86UH961E
M;C\`3W!D<F%C:'0@:V]L;VUM96X`3W``0FEJ9V5V;V5G9"!I<R!E96X@:4-A
M;&5N9&%R(&)E<W1A;F0@;65T(&UE97(@:6YF;W)M871I92!O=F5R(&1E(&=E
M8F5U<G1E;FES+B!786YN965R('5W(&UA:6QC;&EE;G0@:51I<"!V97)Z;V5K
M96X@;VYD97)S=&5U;G0L(&MU;G0@=2!D:70@8F5S=&%N9"!G96)R=6EK96X@
M;VT@965N=F]U9&EG('5W(&QO:V%L92!K;W!I92!V86X@9&4@9V5B975R=&5N
M:7,@8FEJ('1E('=E<FME;BX`4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD
M92!G<F]E<"!T92!V97)W:6ID97)E;BX`4&]G:6YG(&]M(&5E;B!N:65T(&)E
M<W1A86YD(')E8VAT('1E('9E<G=I:F1E<F5N+@!0;V=I;F<@;VT@965N(&YI
M970@8F5S=&%A;F0@<F5C:'0@=&4@8F5W97)K96XN`%!O9VEN9R!O;2!E96X@
M;FEE="!B97-T86%N9&4@<VAA<F4@=&4@8F5W97)K96XN`$%A;G=E>FEG:&5I
M9`!!86YW97II9V5N`$%T=')I8G5T96X`075G=7-T=7,`075S=')A;&GK`$]O
M<W1E;G)I:FL`075T:%]C>7)S<6PZ('9E<F5I<W1E(&EM87`@97AT96YT:64@
M;FEE="!G979O;F1E;BX`075T:%]C>7)U<SH@8F%C:V5N9"!H965F="!N:65T
M(&1E('9E<F5I<W1E(&)E:W=A86UH961E;BX`075T:%]C>7)U<SH@=F5R96ES
M=&4@:6UA<"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7V9T<#H@=F5R
M96ES=&4@1E10(&5X=&5N=&EE(&YI970@9V5V;VYD96XN($-O;7!I;&5E<B!0
M2%`@;65T(&1E("TM96YA8FQE+69T<"!O<'1I92X`075T:%]I;6%P.B!V97)E
M:7-T92!)34%0(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?:W)B-3H@
M=F5R96ES=&4@:W)B-2!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7VQD
M87`Z('9E<F5I<W1E($Q$05`@97AT96YT:64@;FEE="!G979O;F1E;BX`075T
M:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!T;V4@=&4@=F]E
M9V5N+B!$92!S97)V97(@;65L9'0Z(`!!=71H7VQD87`Z($YI970@:6X@<W1A
M870@9V5B<G5I:V5R("5S('1E('9E<G=I:F1E<F5N`$%U=&A?;&1A<#H@3FEE
M="!I;B!S=&%A="!G96)R=6EK97(@)7,@8FEJ('1E('=E<FME;@!!=71H7VUC
M86PZ('9E<F5I<W1E($U#04P@97AT96YT:64@;FEE="!G979O;F1E;BX`075T
M:%]S;6)A=71H.B!V97)E:7-T92!S;6)A=71H(&5X=&5N=&EE(&YI970@9V5V
M;VYD96XN`$%U=&AE;G1I8V%T:64@;6ES;'5K=`!!=71H96YT:6-A=&EE(&UI
M<VQU:W0N("5S`$%U=&AE;G1I8V%T:64@9V5W96EG97)D(&1O;W(@9&4@4D%$
M2553('-E<G9E<BX`075T:&5N=&EC871I92!O<"!&5%`@<V5R=F5R(&UI<VQU
M:W0N`$)E<V-H:6MB87)E('9E;&1E;CH`07IE<F)A:61Z:F%N`$)/1D@@17AC
M=7-E<P!!8VAT97)G<F]N9`!!8VAT97)G<F]N9&ML975R`$9O=70@:V5R8F5R
M;W-W86-H='=O;W)D+@!&;W5T92!K97)B97)O<V=E8G)U:6ME<G-N86%M+@!"
M86AA;6%S`$)A:')E:6X`0F%L=&ES8V@@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&]S`$)A<VES;&EJ;@!%96YV;W5D:6<@>F]E:V5N`%=I="!R
M=7-L86YD`$)E;&=IZP!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`5F5R
M:F%A<F1A9P!";&]K("(E<R(@=F%N('1O97!A<W-I;F<@(B5S(B!N:65T(&=E
M=F]N9&5N+@!";&]K:6YS=&5L;&EN9V5N`$)L;VMT>7!E`%9E=`!";VQI=FEA
M`$)O;VMM87)K<P!286YD`%)A;F1D:6MT93H`4F%N9&5N`$)O<VYIZR!E;B!(
M97)Z96=O=FEN80!"96ED96X`0F]T<W=A;F$`3VYD97)K86YT`$)O=79E="!E
M:6QA;F0`0G)A>FEL:>L`0G)I=',@26YD:7-C:&4@3V-E86%N(%1E<G)I=&]R
M:75M`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEJ90!/;F=E;W)D96YD92!L
M:6IS=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!"97IE=`!#35,`0U)#`$-23"!$
M:7-T<FEB=71I97!U;G1E;@!!7V=E;F1A`$-?96QE:6=E;G-C:&%P<&5N+BXN
M`%]!9V5N9&$`06=E;F1A`$%G96YD87-A;65N=F%T=&EN9P!!9V5N9&$G<P!+
M86QM`$-A;6)O9&IA`$MA;65R;V5N`$MA;B!W86-H='=O;W)D(&YI970@875T
M;VUA=&ES8V@@<F5S971T96XL(&YE96T@8V]N=&%C="!O<"!M970@9&4@<WES
M=&5E;6)E:&5E<F1E<BX`2V%N(&YI970@=F5R8FEN9&5N(&UE="!)34%0('-E
M<G9E<CH@)7,`2V%N(&=E96X@;FEE=7=E(&=E8F5U<G1E;FES(&UA:V5N+@!#
M86YA9&$`069B<F5K96X`4')O8FQE96UR87!P;W)T(&%F8G)E:V5N`$%F9V5B
M<F]K96X`069G96)R;VME;CH@)7,`2V%N(&)E<W1A;F0@(B5S(B!N:65T('9E
M<G=I:F1E<F5N+@!+86X@9V5E;B!T:6ID96QI:FME(&1I<F5C=&]R>2!V:6YD
M96XN`$MA;B!N:65T(&1O;W)G86%N('IO;F1E<B`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+@!+86X@9&ER96-T;W)Y("(E<R(@;FEE="!V97)W:6ID97)E;BX`
M2V%N(&YI970@=F5R=VEJ9&5R96X[("5D(&-H:6QD<F5N(&)E<W1A86XN`$MA
M;B!N:65T(&]P;FEE=7<@<F%N9W-C:&EK:V5N+"!H970@86%N=&%L(&EN=F]E
M<F5N(&]M(&]P;FEE=7<@=&4@<F%N9W-C:&EK:V5N(&MO;70@;FEE="!O=F5R
M965N(&UE="!H970@;W!G97-L86=E;B!A86YT86PN`$MA;B!B97)I8VAT(&YI
M970@;F%A<B!H970@;W!G96=E=F5N(&YU;6UE<B!V97)S='5R96XN`$MA87`@
M5F5R9&4`3W!S8VAR:69T`%]#871E9V]R:64`0V%T96=O<FEEZVX@96X@;&%B
M96QS`$-A=&5G;W)I90!#87EM86X@96EL86YD96X`5&5L+FYR+FUO8FEE;`!#
M96QE:6=E;G-C:&%P<&5N`$-E;"!V<FEJ92!R=6EM=&4Z`$-E;&5I9V5N<V-H
M87!P96X`0V5L<W!A=&GK<FEN9SH`5&5L+FYR+FUO8FEE;`!+96QT:7-C:"`H
M25-/+3@X-3DM,30I`$UI9&1E;@!#96YT<F%A;"!!9G)I:V%A;G-E(%)E<'5B
M;&EE:P!#96YT<F%A;"!%=7)O<&5E<R`H25-/+3@X-3DM,BD`0V5R=&EF:6-A
M871D971A:6QS`$-E<G1I9FEC86%T8F5L96ED`%1S:F%A9`!7:6IZ:6=E;@!7
M:6IZ:6<@9&4@;F%A;2P@861R97,@96X@;VYD97)T96ME;FEN9R!D:64@;65N
M('II970@8FEJ(&AE="!L97IE;B!E;B!B96%N='=O;W)D96X@=F%N('5W(&4M
M;6%I;',N`$MA<F%K=&5R`$-O;G1?<F]L965R(&QI;FLN+BX`0VAI;&D`0VAI
M;F$`0VAI;F5E<R!V97)E96YV;W5D:6=D("A'0C(S,3(I`$-H:6YE97,@=')A
M9&ET:6]N965L("A":6<U*0!+:65S(&5E;B!W86-H='=O;W)D`$MI97,@965N
M(&=E8G)U:6ME<G-N86%M`$MI97,@9&%T=6UW965R9V%V93H`2VEE<R!L:6IS
M='-T:6IL='EP92`H=F]O<B!G96]R9&5N9&4@;&EJ<W1E;BD`2VEE<R!H970@
M861R97-B;V5K('9O;W(@:&5T('IO96ME;B!V86X@=G)I:B]B97IE="!54DQS
M.@!+:65S('5W('-T86YD86%R9"!A9V5N9&$N`$-H<FES=&UA<R!E:6QA;F0`
M0VQA<W-D969I;FET:64@=F%N("5S(&YI970@9V5V;VYD96XN`$AE;&1E<@!-
M4T]F9FEC92!T86=S('=I<W-E;@!7:7,@9V5B<G5I:V5R.B`E<P!7:7,@9V5B
M<G5I:V5R`%=I<R!G96)R=6EK97)S9&%T80!+;&EK(&]M('9E<F1E<B!T92!G
M86%N`$-L:6-K871E;&P@=FEA($A45%``4VQU:70@<V-H97)M`%=O;&ME;@!"
M97=O;&MT`$-O8V]S("A+965L:6YG*2!E:6QA;F1E;@!);F=E:VQA<'1E(')A
M;F1E;@!#;VQO;6)I80!+;&5U<@!+;&5U<F5N:VEE>F5R`$ML975R<V5L96-T
M:64`2V]L;VUM96XZ`$MO;&]M=&ET96QS`%-T<FEP<P!+;VUM82!G97-C:&5I
M9&5N('=A87)D96X`3W!D<F%C:'0`3W!D<F%C:'1S:&5L;`!/<&UE<FMI;F<`
M06QG96UE;F4@;F%A;0!#;VUO<F5N`$)E9')I:F8`0V]M<'5T97)S`$-O;F1I
M=&EE<P!697)S8VAI;&QE;B!I;B!C;VYF:6=U<F%T:64`)7,@8V]N9FEG=7)E
M<F5N`$)E=F5S=&EG('=A8VAT=V]O<F0`5F5R=VEJ9&5R:6YG('9A;B!G96)E
M=7)T96YI<W-E;B!B979E<W1I9V5N/P!"979E<W1I9V0`2V]N9V\`2V]N9V\L
M($1E($1E;6]C<F%T:7-C:&4@4F5P=6)L:65K('9A;B!D90!697)B:6YD:6YG
M(&UI<VQU:W0N`%9E<F)I;F1I;F<@;6ES;'5K=#H@`%9E<F)I;F1I;F<L(&UE
M="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E:6=E<F0N`%9E
M<F)I;F1I;F<L(&UE="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G
M97=E:6=E<F0N(%)E9&5N.B`E<R`H)7,I`%9E<F)I;F1I;F<@;65T($944"!S
M97)V97(@;6ES;'5K="X`061R97-S96X@>FEJ;B!M970@<W5C8V5S(&%A;B!U
M=R!A9')E<V)O96L@=&]E9V5V;V5G9"X`1&]O<F=A86X`0V]O:R!E:6QA;F1E
M;@!#;V]K:64`2V]P:>MR96X`2V]P:65E<B!S96QE8W1I90!+;W!I965R(&1E
M(&]N9&5R<W1A86YD92!54DP@=F]O<B!G96)R=6EK+"!W86YN965R('4@=7<@
M5G)I:B]"97IE="!54DP@;F]D:6<@:&5E9G0Z`$-O<W1A(%)I8V$`279O;W)K
M=7-T`$MO;B!01U`@8F5R:6-H="!N:65T(&-O9&5R96XN`$MO;B!01U`@8F5R
M:6-H="!N:65T(&]N9&5R=&5K96YE;BX`2V]N(&)E<FEC:'0@;FEE="!3+TU)
M344@8V]D97)E;BX`2V]N(&)E<FEC:'0@;FEE="!3+TU)344@;VYD97)T96ME
M;F5N+@!+;VX@861R97,@)7,@;FEE="!T;V5V;V5G96XN`$MO;B!G965N('9E
M<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&UA:V5N+@!+;VX@=&5G;V5D
M("5S(&YI970@8V]N=')O;&5R96XN`$MO;B!G965N(&1I<W1R:6)U=&EE;&EJ
M<W0@)7,@;6%K96XN`$MO;B!01U`@9&%T82!N:65T(&1E8V]D97)E;BX`2V]N
M(%,O34E-12!D871A(&YI970@9&5C;V1E<F5N+@!+;VX@861R97,@)7,@;FEE
M="!V97)W:6ID97)E;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!V
M97)W:6ID97)E;BX`2V]N(&AE="!E+6UA:6QA9')E<R!V86X@9&4@;VYT=F%N
M9V5R(&YI970@8F5P86QE;BX`2V]N(&-O;7!L971E(&%D<F5S8F]E:R!N:65T
M(&]P:&%L96XN`$MO;B!C;VUP;&5T92!D:7-T<FEB=71I96QI:G-T(&YI970@
M;W!H86QE;BX`2V]N(&-O;7!L971E(&QI:G-T('9A;B!D:7-T<FEB=71I96QI
M:G-T96X@;FEE="!O<&AA;&5N+@!+;VX@9&4@;W!E;F)A<F4@<VQE=71E;"!N
M:65T('9E<FMR:6IG96X@=F%N(&1E('-L975T96QS97)V97(N`$MO;B`E<R!N
M:65T(&]P96YE;BX`2V]N(&]N9&5R:&]U9'-T86ME;FUO9'5L92`E<R!N:65T
M(&]P96YE;@!+;VX@)7,@;FEE="!L97IE;BX`2V]N(&AE="!W86-H='=O;W)D
M('9A;B!D92!G97=E;G-T92!G96)R=6EK97(@;FEE="!R97-E='1E;BX@4V]M
M;6EG92!O9B!A;&QE(&1E=&%I;',@>FEJ;B!N:65T(&IU:7-T+B!0<F]B965R
M(&]P;FEE=7<@;V8@;F5E;2!C;VYT86-T(&]P(&UE="!D92!S>7-T965M8F5H
M965R9&5R+"!W86YN965R('4@=F5R9&5R92!H=6QP(&YO9&EG(&AE969T+@!+
M;VX@04-,(&YI970@;W!H86QE;@!+;VX@861R97-B;V5K("5S(&YI970@;W!H
M86QE;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!O<&AA;&5N+@!+
M;VX@9&ES=')I8G5T:65L:6IS=&5N("5S(&YI970@;W!H86QE;BX`2V]N('-E
M<G9E<F)E:W=A86UH961E;B!N:65T(&]P:&%L96X`2V]N(&-O;F9I9W5R871I
M92!N:65T('1E<G5G>F5T=&5N+@!+;VX@8V]N9FEG=7)A=&EE("5S(&YI970@
M;W!S;&%A;BX`2V]N(&=E96X@8F%C:W5P8V]N9FEG=7)A=&EE(&]P<VQA86XN
M`$MO;B!D92!,1$%0+7-E<G9E<B!N:65T(&1O;W)Z;V5K96XN`$MO;B!A9')E
M<R`E<R!N:65T(&)I:G=E<FME;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@
M;FEE="!B:6IW97)K96XN`$MO;B!D92!-;WII;&QA(%-I9&5B87(@;FEE="!V
M:6YD96XN(%IO<F<@97)V;V]R(&1A="!D92!S:61E8F%R(&]P96X@:7,N`$=E
M=&5L9&4@=&5K<W0`3&%N9`!#=7)S=7-S96X`36%K96X`36%A:R!E96X@;FEE
M=7=E(&=E8F5U<G1E;FES`$UA86L@965N(&QI;FL`36%A:R!E96X@;FEE=7=E
M`$UA86L@<W5B;6%P<&5N`$=E;6%A:W0`16EG96YA87)R96-H=&5N`$-R961I
M=&-A<F1N=6UM97(`2W)O871IZP!#=6)A`$AU:61I9V4`2'5I9&EG92!T:6ID
M`$AU:61I9V4@55),(&ES`$AU:61I9R!W965R`$AU:61I9V4@8V]N9&ET:64Z
M(`!(=6ED:6=E('-T:6IL`$%A;G!A<W-E;B!V86X@=&%K96X@=&EJ9&5N<R!A
M86YM96QD:6YG(&)I:B`E<RX`2VYI<'!E;@!396QE8W1I92!K;FEP<&5N`$-Y
M<')U<P!#>7)I;&QI<V-H("A+3TDX+5(I`$-Y<FEL;&ES8V@@*%=I;F1O=W,M
M,3(U,2D`0WER:6QL:7-C:"]5:W)A:6YS("A+3TDX+54I`%1S:F5C:&ES8VAE
M(%)E<'5B;&EE:P!$1`!$86=E;&EJ:W,`1&%G96QI:FMS.B!H97)H86%L="!Z
M:6-H(&5L:V4`1&%T851R964@8G)O=W-E<@!$871U;0!$871U;2!/;G1V86YG
M96X`1&%T=6T@<V5L96-T:64`1&%G`$1A9RAE;BD`5F5R=VE?:F1E<F5N`%9E
M<E]W:6ID97(@:V]L;VT`1&5C96UB97(`1&5C:6UA;&4@9V5T86QL96X`069G
M96YO;65N`$EN<W!R:6YG96X@=F5R:VQE:6YE;@!3=&%N9&%A<F0@86=E;F1A
M`%-T86YD86%R9"!K;&5U<@!3=&%N9&%A<F0@:61E;G1I=&5I=`!$969I;FET
M:65S`%9E<G=I:F1E<F5N`%9E<G=I:F1E<B`E<P!697)W:6ID97(@9V5B975R
M=&5N:7,`1W)O97`@=F5R=VEJ9&5R96X`4F5C:'0@=F5R=VEJ9&5R96X`5F5R
M=VEJ9&5R(&5N('=I<R!B97)I8VAT96X`5F5R=VEJ9&5R(&-E;`!697)W:6ID
M97(@:V]L;VT`0F5S=&%A;F0@86QT97)N871I968@<VIA8FQO;VX@=F5R=VEJ
M9&5R96X`5F5R=VEJ9&5R(')I:@!'97-E;&5C=&5E<F1E(&ED96YT:71E:70@
M=F5R=VEJ9&5R96X`5F5R=VEJ9&5R(&1E(&AU:61I9V4@:V]L;VT`5F5R=VEJ
M9&5R(&%L;&5E;B!D92!H=6ED:6=E(&=E8F5U<G1E;FES+"!D:70@=F]O<G9A
M;"!E;B!A;&QE('1O96MO;7-T:6=E('9O;W)V86QL96XL(&]F(&%L;&4@=F]O
M<G9A;&QE;C\`5F5R=VEJ9&5R(&1E(&AU:61I9V4@<FEJ`$%F;&5V97)T:6ID
M`$1E;F5M87)K96X`3VUS8VA?<FEJ=FEN9P!"97-C:')I:F8@:&5T('!R;V)L
M965M`$)E<V-H<FEJ=FEN9P!$971A:6QS("AO;VL@:6X@2&]R9&4G<R!L;V=B
M97-T86YD*3H`1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E96UB
M96AE97)D97(N`$]N='=I:VME;&EN9P!$875W<'5N=`!$875W<'5N="!V;V]R
M(&AE="!A9F=E;&]P96X@=75R.B``1&%U=W!U;G0Z(`!2:6-H=&EN9R!L:6YK
M<R!N86%R(')E8VAT`%)I8VAT:6YG(')E8VAT<R!N86%R(&QI;FMS`$1I<F5C
M=&]R>0!7965R9V5V96X`,C0M=75R<R!T:6ID=V5E<F=A=F4_`%=E97)G879E
M;W!T:65S`%=E97)S=F]O<G-P96QL:6YG('1O;F5N("A4048I`%=E97)G879E
M9F]R;6%A=`!6;V]R8F5R96ED:6YG<VYO=&EF:6-A=&EE`$1J:6)O=71I`$YI
M970@=F5R=VEJ9&5R96X`;6%I;G1E;F%N8V4N<&AP(&YI970@9&ER96-T(&%A
M;G-P<F5K96X`5VEL="!U(&%F9V5R;VYD92!T86ME;B!O<"!U=R!A9V5N9&$@
M=V5E<F=E=F5N/P!(97)H86%L="!Z:6-H(&YI970`0F5V870@9&4@965R<W1E
M(')I:B!D92!V96QD;F%M96X_(%IO(&IA+"!D:70@:&]K:F4@86%N=FEN:V5N
M.@!$;VUI;FEC80!$;VUI;FEC86%N<V4@4F5P=6)L:65K`$1O=VYL;V%D96X`
M)7,@9&]W;FQO861E;@!$;W=N;&]A9"!G96=E;F5R965R9&4@8V]N9FEG=7)A
M=&EE(&%L<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&EJ<W0`1')U9W,`5F5R
M=F%L9&%T=6TZ("5S`%1I:F1S9'5U<@!%+4UA:6P`15)2`$5C=6%D;W(`0F5W
M97)K96X`)7,@8F5W97)K96X`06%N=V5Z:6=E;B!B97=E<FME;@!";&]K(&)E
M=V5R:V5N`$=R;V5P(&)E=V5R:V5N`%)E8VAT(&)E=V5R:V5N`%)E8VAT96X@
M8F5W97)K96X`4F5C:'1E;B!V86X@)R5S)R!B97=E<FME;@!!9V5N9&$G<R!O
M<"!A9G-T86YD+"!B97=E<FME;@!!86YW97II9V5N(&)E=V5R:V5N`$-A=&5G
M;W)I9>MN(&5N(&ML975R96X@8F5W97)K96X`3W!T:65S(&)E=V5R:V5N('9O
M;W(Z`%)E8VAT96X@=F%N("5S(&)E=V5R:V5N`$]N9&5R=VEJ<P!%9WEP=&4`
M16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%+6UA:6P`12UM86EL861R97,`
M12UM86EL861R97-S96X@;6]E=&5N(&]V97)E96YK;VUE;BX`12UM86EL(&UE
M="!B979E<W1I9VEN9P!%;6]T:6-O;G,`3&5E9R!B97)I8VAT+@!'965N(')E
M<W5L=&%A="X`3&5G92!Z;V5K=&5R;65N`$EN=F]E9V5N('9A;B!A9F)E96QD
M:6YG96X@=6ET(&9O=&]A;&)U;7,@:6X@=&5K<W0@:6YS8VAA:V5L96X_`%)E
M8VAT:VQI:VME;B!C;VYT97AT(&UE;G4@:6YS8VAA:V5L96X_`$5I;F1D871U
M;0!%:6YD:6=T(&]P`$5I;F1T:6ID`$5I;F1J86%R`%9E<F=R;V]T(&5D:71O
M<@!'965F(&5E;B!B979E:6QI9VEN9W-V<F%A9R!D:64@=2!G979R86%G9"!W
M;W)D="P@=V%N;F5E<B!H970@;F]D:6<@:7,@;VT@=7<@=V%C:'1W;V]R9"!T
M92!R97-E='1E;BP@8BYV+B`G=V%T(&ES(&1E(&YA86T@=F%N('5W(&AU:7-D
M:65R/R<Z`%9O97(@9&4@869B965L9&EN9R!54DP@:&EE<B!I;@!%<75A=&]R
M:6%A;"!'=6EN964`17)I=')E80!&;W5T`$9O=70@8FEJ(&AE="!O<&AA;&5N
M('9A;B!V<FEJ+V)E>F5T(&EN9F]R;6%T:64@=F]O<B`E<SH@)7,`1F]U="!M
M970@92UM86EL8F5R:6-H="X`17-T;&%N9`!%=&AI;W!IZP!%=&YI<V-H`$5U
M<F]P80!'96)E=7)T96YI<R!V86X@)7,@=&]T("5S`$5L:V4@,34@;6EN=71E
M;@!%;&ME(#(@;6EN=71E;@!%;&ME(#,P('-E8V]N9&5N`$5L:V4@-2!M:6YU
M=&5N`$5L:V4@86%N;65L9&EN9P!%;&L@:&%L9B!U=7(`16QK92!M:6YU=70`
M5F]O<F)E96QD=V%A<F1E;CH`56ET=F]E<F5N`%5I=&ML87!P96X`5F5R=V%C
M:'1T92`G*2<`5F5R=V%C:'1T92!E;FME;"!W;V]R9"!O9B!A86YG96AA86QD
M92!Z;V5K=&5R;0!697)V86QD871U;0!%>'!O;F5N=`!%>'!O<G1E<F5N`$%G
M96YD82!E>'!O<G1E<F5N`%9O;W)G<F]N9&ML975R`$944"!U<&QO860@=F%N
M('-E='5P`$]P:&%L96X@=F]O<FME=7)S:6YS=&5L;&EN9V5N(&UI<VQU:W0N
M`%9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&ES(&UI<VQU:W0N`%9E
M<F)I;F1I;F<@;65T(&1E(%--0BUS97)V97(@:7,@;6ES;'5K="X`2V]P:>MR
M96X@=6ET("(E<R(@:7,@;6ES;'5K="X`2V]P:>MR96X@;F%A<B`B)7,B(&ES
M(&UI<VQU:W0N`$UA:V5N('9A;B!N:65U=V4@4T%33"!V97)B:6YD:6YG(&ES
M(&UI<VQU:W0N`%9E<G!L86%T<V5N(&YA87(@(B5S(B!I<R!M:7-L=6MT+@!-
M;V]I`$9A;&ML86YD(&5I;&%N9&5N("A-86QV:6YA<RD`1F%R;^MR(&5I;&%N
M9&5N`$9A>`!&96)R=6%R:0!6;V5L="!A;',`5F]E;'0@86QS.B``16YK96QE
M(&)U:65N`$9I:FD`06%N=&%L(&)E<W1A;F1E;CH@)7,@8F5S=&%N9`!!86YT
M86P@8F5S=&%N9&5N.B`E<R!B97-T86YD96X`0F5S=&%N9&)E:&5E<@!"97-T
M86YD<VYA86T`0F5S=&%N9"!K:65Z96X`0F5S=&%N9'5P;&]A9`!"97-T86YD
M=7!L;V%D<R!W;W)D96X@;FEE="!O;F1E<G-T975N9"X`1FEL=&5R<P!6:6YD
M96X`1FEN;&%N9`!%97)S=&4@:&5L9G0`165R<W1E(&MW87)T86%L`%9E<FAO
M=61I;F<@:&5R<W1E;&QE;@!/;6ME<F5N`$1R:6IV96X`36ES=`!-87`@)7,@
M8F5S=&%A="!N:65T`$9O;G1K;&5U<@!6;V5D<V5L`%9O;W(@8G)O=W-E<G,@
M9&EE(&=E96X@869B965L9&EN9V5N(&]N9&5R<W1E=6YE;@!7965R<W9O;W)S
M<&5L;&EN9R`H5$%&*0!6;V]R=6ET>FEC:'1D86=E;B`H;65R:R!O<"!D870@
M:&5T(&=E9V5V96X@=F]O<G5I='II8VAT(&1A9V5N(&5N(&YA8VAT96X@9V5E
M9G0[(&5E;B!G<F]O="!A86YT86P@:V%N(')E<W5L=&5R96X@:6X@965N(&)R
M965D(&)L;VLI`%5W('=A8VAT=V]O<F0@=F5R9V5T96X_`$9O<FUU;&EE<F5N
M`$9O<G1U;F4`1F]R='5N971Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U
M;7,`1&]O<G-T=7)E;@!6<@!&<F%M97,`1G)A;FMR:6IK`$9R86YK<FEJ:RP@
M2&]O9F1S=&5D96QI:FL`1G)A;G,@1W5Y86YA`$9R86YS(%!O;'EN97-IZP!&
M<F%N<V4@6G5I9&5L:6IK92!497)R:71O<FEA`%9R:6ID86<`5F%N`%9A;B!D
M92``5F]L;&5D:6=E(&)E<V-H<FEJ=FEN9P!6;VQL92!M86%N`%9O;&QE9&EG
M92!N86%M`%1O96MO;7-T`$=A8F]N`$%L8G5M('=A87)U:70@9&4@869B965L
M9&EN9R!G96AA86QD(&1I96YT('1E('=O<F1E;@!!;&)U;3H`1V%M8FEA`%-P
M96P`06QG96UE96X`1V5N97)E97(@)7,@8V]N9FEG=7)A=&EE`$=E9V5N97)E
M97)D92!C;V1E`$=E;W)G:>L`1'5I='-L86YD`$=H86YA`$=I8G)A;'1A<@!6
M;V]R;F%A;0!'80!';V5D96P`1V]O9VQE('IO96ME;@!'82!N86%R("5S`$=R
M:6IS<V-H86%L`$=R:65K96YL86YD`$=R:65K<R`H25-/+3@X-3DM-RD`1W)O
M96YL86YD`$=R96YA9&$`1W)O97!S8F5H965R`$=R;V5P;F%M96X@;6]G96X@
M;FEE="!L965G('II:FX`1W)O97!E;@!'=6%D96QO=7!E`$=U86T`1W5A=&5M
M86QA`$=U97)N<V5Y`$=A<W0@<F5C:'1E;@!'87-T96YB;V5K`$=U:6YE90!'
M=6EN964M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A('=E:6=E<G0@;&%F
M(&]M(&1E(&QA871S=&4@8V5L(&EN(&1E(')I:B!T92!V97)W:6ID97)E;BX`
M2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@;&%A='-T92!K;VQO;2!I;B!D
M92!T86)E;"!T92!V97)W:6ID97)E;BX`2%1-3$%R96$@=V5I9V5R="!L868@
M;VT@9&4@;&%A='-T92!R:6H@:6X@9&4@=&%B96P@=&4@=F5R=VEJ9&5R96XN
M`$A45%`@875T:&5N=&EC871I92!N:65T(&=E=F]N9&5N+@!(86ET:0!(87-H
M+6%L9V]R:71H;64`3F5V96P`2V]P`$AE87)D(&5I;&%N9"!E;B!-8T1O;F%L
M9"!E:6QA;F1E;@!(96)R965U=W,@*$E33RTX.#4Y+3@M22D`2&]O9W1E`$AE
M;'``2&5L<"!B:6H@9V5B<G5I:R!V86X@961I=&]R`$AE;'!E<@!(86QF<F]N
M9`!(:65R(&ES(&AE="!B96=I;B!V86X@:&5T(&)E<W1A;F0Z`$AO;V<`2&]?
M;64`2&]L>2!3964@*%9A=&EC86%N<W1A9"D`2&]M90!!9')E<R`H<')I=NDI
M`%1E;"YN<BX@*'!R:7;I*0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R
M9&4O2V]L86(Z($]N9V5L9&EG92`E<R!834P@9&%T82!T96=E;F=E:V]M96X@
M:6X@8F5R:6-H="`E<P!(;W)D92]+;VQA8CH@1V5E;B!B97)I8VAT(&-O<G)E
M<W!O;F1E97)T(&UE="!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($=E96X@;V)J
M96-T('9A;B!T>7!E("5S(&=E=F]N9&5N(&EN(&)E<FEC:'0@)7,`2&]R9&4O
M2V]L86(Z("5S(&UE="!S=6-C97,@=F5R=VEJ9&5R9"`B)7,B`$AO<F1E+TMO
M;&%B.B!$92!I;G1E<F=R871I92!V97)E:7-T(&1E("=D;VUX;6PG(&5X=&5N
M<VEE`$AO<F1E+TMO;&%B.B!+86X@9V5E;B!N:65U=V4@6$U,(&)O;VT@;6%K
M96X@=F]O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($MA;B`E<R`B)7,B(&YI
M970@=F5R=VEJ9&5R96XZ("5S`$AO<F1E+TMO;&%B.B!.:65T(&EN('-T86%T
M(&AE="!-24U%($E$+"!V;V]R(&AE="!G961E96QT92!M970@='EP92`E<RP@
M;W`@=&4@:&%L96X`2&]R9&4O2V]L86(Z($MA;B`E<R`B)7,B(&YI970@<WEN
M8VAR;VYI<V5R96XZ("5S`$AO<F1E+TMO;&%B.B!+86X@9V5D965L9&4@8G)O
M;FYE;B!N:65T('-Y;F-H<F]N:7-E<F5N.B`E<P!(;W)D92]+;VQA8CH@3VYB
M96ME;F1E(&=E9&5E;&1E(&)R;VX@(B5S(@!(;W)I>F]N=&%L92!L:6IN`$AO
M<FEZ;VYT86QE('9R:6IE(')U:6UT90!(;W)I>F]N=&%A;#H`575R`$AO92!K
M=V%M('4@:&EE<C\@*$=R86%G(')A<'!O<G1A9V4A*0!(;V5V965L(&MO;&]M
M;65N('=I;'0@=2!S86UE;G9O96=E;C\`2&]E=F5E;"!V96QD96X@*&MO;&]M
M;65N*2!Z:6IN(&5R/P!(;V5V965L(')I:F5N('=I;'0@=2!S86UE;G9O96=E
M;C\`5F]C:'1I9VAE:60`5F]C:'1I9VAE:60Z(`!(=6UO<FES=&5N`$AO;F=A
M<FEJ90!-86ME;B!V86X@24U!4"!M86EL8F]X(&UI<VQU:W0Z("5S`%9E<G=I
M:F1E<F5N('9A;B!)34%0(&UA:6QB;W@@;6ES;'5K=#H@)7,`36%K96X@=F%N
M($E-05`@;6%I;&)O>"!Q=6]T82!M:7-L=6MT.B`E<P!)4"!!9')E<P!)4"!A
M9')E<R!N:65T(&)E<V-H:6MB86%R+@!)4"!A9')E<R!V86QT(&YI970@8FEN
M;F5N(&AE="!T;V5G97-T86YE($-)1%(@8FQO:RX`25`@;&]C:V1O=VX@;W9E
M<G1R961I;F<N`%)I:B!I7VYV;V5G96X@=F]O<@!)2G-L86YD`$%L;&5E;B!P
M:6-T;V=R86UM96X`4&EC=&]G<F%M;65N(&UE="!T96MS=`!)9&5N=&ET96ET
M<VYA86TZ`%=A;FYE97(@:&5T(&YI970@9V]E9"!W;W)D="!W965R9V5G979E
M;BP@)7,@;VT@:&5T(&EN(&5E;B!N:65U=R!S8VAE<FT@=&4@;W!E;F5N+@!!
M;',@=2!G965N('!I8W1O9W)A;6UE;B!Z:65T+"!B:6H@9V5B<G5I:R!V86X@
M26YT97)N970@17AP;&]R97(L(&MA;B!H970@;F]D:6<@>FEJ;B!D:70@=F%K
M:F4@86%N('1E('9I;FME;B!O;2!03D<@=')A;G-P87)A=&EE('5I="!T92!S
M8VAA:V5L96XN`%=A;FYE97(@=2!D:70@8F5R:6-H="!Z:65T+"!M86%R(&=E
M96X@869B965L9&EN9RP@9&%N(&MA;B!D92!A9F)E96QD:6YG(&1I92!U('=I
M;'0@=7!L;V%D96X@;FEE="!D;V]R('5W(&)R;W=S97(@=V]R9&5N('=E97)G
M96=E=F5N+@!!9F)E96QD:6YG<V)E;V]R9&5L:6YG.@!!9F)E96QD:6YG(%52
M3`!!9F)E96QD:6YG(%523#H`069B965L9&EN9R!U:70@86QB=6T`069B965L
M9&EN9R!U:70@86QB=6TZ`$%F8F5E;&1I;F=S=7!L;V%D`$%F8F5E;&1I;F=E
M;@!!9V5N9&$@:6UP;W)T97)E;BP@<W1A<"`E9`!);7!O<G1E<F5N+"!S=&%P
M("5D`$%G96YD82!I;7!O<G1E<F5N+V5X<&]R=&5R96X`1V5I;7!O<G1E97)D
M('9E;&0Z("5S`$=E:6UP;W)T965R9&4@=F5L9&5N.@!2:6H@:6YV;V5G96X@
M;F$`3VYJ=6ES=&4@8F5W97)K:6YG<V-O9&4@;W!G96=E=F5N+@!/;FIU:7-T
M92!G96)R=6EK97)S;F%A;2!E;B]O9B!W86-H='=O;W)D+@!/;FIU:7-T92!G
M96)R=6EK97)S;F%A;2!O9B!A;'1E<FYA=&EE9B!A9')E<RX@4')O8F5E<B!O
M<&YI975W(&]F(&YE96T@8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E
M<F1E<BP@=V%N;F5E<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H965F="X`5F5R
M9W)O;W0@:6YS<')I;F=I;F<`26YD:6$`26YD:79I9'5E;&4@9V5B<G5I:V5R
M<P!);F1O;F5S:>L`26YF;P!);F9O<FUA=&EE`$MO;&]M(&EN=F]E9V5N(&YA
M`$%F8F5E;&1I;F<@:6YV;V5G96X`5&%B96P@:6YV;V5G96X`5V5B;&EN:R!I
M;G9O96=E;@!?2V]L;VT@:6YV;V5G96X@=F]O<@!%96X@;FEE=7=E(&MO;&]M
M(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4`165N(&YI975W92!K;VQO;2!I;G9O
M96=E;B!V;V]R(&1E(&AU:61I9V4`165N(&YI975W92!R:6H@:6YV;V5G96X@
M;F$@9&4@:'5I9&EG90!%96X@;FEE=7=E(')I:B!I;G9O96=E;B!N82!D92!H
M=6ED:6=E`$5E;B!N:65U=V4@<&%R86=R86%F(&EN=F]E9V5N(&YA(&1E(&AU
M:61I9V4@;F]D90!%96X@;FEE=7=E('!A<F%G<F%A9B!I;G9O96=E;B!N82!D
M92!H=6ED:6=E(&YO9&4`06QT97)N871I968@<VIA8FQO;VX@:6YV;V5G96X`
M165N(&4M;6%I;&%D<F5S(&EN=F]E9V5N+"!W86%R('4@:&5T(&YI975W92!W
M86-H='=O;W)D(&MA;B!O;G1V86YG96XZ`$-E;"!I;G9O96=E;B!N80!#96P@
M:6YV;V5G96X@=F]O<@!+;VQO;2!I;G9O96=E;B!N80!+;VQO;2!I;G9O96=E
M;B!V;V]R`$)E<FEC:'1E;B!I;G9O96=E;@!087)A9W)A868@:6YV;V5G96X@
M;F$`4&%R86=R86%F(&EN=F]E9V5N('9O;W(`4FEJ(&EN=F]E9V5N(&YA`%)I
M:B!I;G9O96=E;B!V;V]R`$AE="!G97=E;G-T92!A;G1W;V]R9"!V;V]R(&1E
M(&)E=F5I;&EG:6YG<W9R86%G(&EN=F]E9V5N.@!!9F)E96QD:6YG(&EN=F]E
M9V5N+V%A;G!A<W-E;@!,:6YK(&EN=F]E9V5N+V%A;G!A<W-E;@!/;G9O;&1O
M96YD92!K<F5D:65T(&]M(&YA87(@9&4@9&ES=')I8G5T:65L:6IS="!T92!Z
M96YD96XN`$]N=F]L9&]E;F1E(&MR961I970`26YT96=E<@!);G1E9V5R(&QI
M:G-T`$]N9V5L9&EG92!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`3VYG96QD
M:6=E('1O97!A<W-I;F<N`$]N9V5L9&EG(&)A=&-H($E$+@!/;F=E;&1I9V4@
M9&%T82!O<&=E9V5V96XN`$]N9V5L9&EG(&)E<W1E;6UI;F=A9')E<RX`3VYG
M96QD:6<@=&EJ9&9O<FUA870`3VYG96QD:6<@;7-G7W1Y<&4N`$]N9V5L9&EG
M(&]F(&]N=&)R96ME;F0@87!I7VED+@!/;F=E;&1I9V4@;V8@;VYT8G)E:V5N
M9&4@<&%R86UE=&5R<RX`3VYG96QD:6<@<&%R96YT(')E8VAT+@!/;F=E;&1I
M9R!P<F]T;V-O;"X`3VYG96QD:6=E(&=E9&5E;&1E(&)R;VX`3VYG96QD:6<@
M8G)O;F%D<F5S+@!/;F=E;&1I9V4@=6YI8V]D92!D871A+@!);G9E;G1A<FES
M`$ER86XL($ES;&%M:71I<V-H92!297!U8FQI96L@=F%N`$ER86L`265R;&%N
M9`!%:6QA;F0@36%N`$=E:7-O;&5E<F1E(&]N=V5E<G-B=6EE;@!)<W)AZVP`
M56ET9V5V97(`0W5R<VEE9@!)=&%L:>L`2F%M86EC80!*86YU87)I`$IA<&%N
M`$IA<&%N<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YIZP!*=6QI`$IU
M;FD`=6ET;&EJ;F5N`$=E8V5N=')E97)D('5I=&QI:FYE;@!6;VQL961I9R!U
M:71L:6IN96X`3&EN:W,@=6ET;&EJ;F5N`%)E8VAT<R!U:71L:6IN96X`2V%Z
M86-H<W1A;@!/<FEG:6YE96P@8F5H;W5D96X_`$ME;FEA`$ME<F)E<F]S('-E
M<G9E<B!W96EG97)D92!A=71H96YT:6-A=&EE+@!+97)N96P@3F5W8FEE<P!3
M;&5U=&5L(&UA:V5N`%-L975T96QV:6YG97)A9F1R=6L`4VQE=71E;&QE;F=T
M90!3;&5U=&5L='EP90!3;&5U=&5L9V5B<G5I:P!$92!S;&5U=&5L(&)E<W1A
M870@86P@;W`@9&4@;W!E;F)A<F4@<VQE=71E;'-E<G9E<BX`5')E9G=O;W)D
M96X`2VEN9&5R96X`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:7-C:&4@5F]L
M:W-R97!U8FQI96L@=F%N`$MO<F5A+"!297!U8FQI96L@=F%N`$MO<F5A86YS
M("A%54,M2U(I`$MO97=E:70`2WER9VEE<VGK`$]?<&UA86L`5&%A;`!$96UO
M8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K($QA;P!!9F=E;&]P96X@,C0@=75R
M`$QA871S=&4@:&5L9G0`3&%A='-T(&=E=VEJ>FEG9`!!9F=E;&]P96X@;6%A
M;F0`3&%A='-T92!K=V%R=&EE<@!,86%T<W0@8FEJ9V5W97)K=#H`3&%A='-T
M92!A86YM96QD:6YG.B`E<P!,86%T<W1E(&%A;FUE;&1I;F<Z("5S('9A;B`E
M<P!,86%T<W1E(&%A;FUE;&1I;F<Z($YO;VET`$%F9V5L;W!E;B!W965K`$QE
M=&QA;F0`4F5C:'1E;@!/<&UA86L`3&%A="!L965G('9O;W(@9V5E;B!R86YD
M`$QI8F%N;VX`3&EN:W,`3&EN:W-E(&MO<`!,:6YK<V4@=V%A<F1E;@!,97-O
M=&AO`$QI8F5R:6$`3&EB:7-C:&4@07)A8FES8VAE($IA;6%H:7)I>6$`3&EE
M8VAT96YS=&5I;@!:86-H="!B=6ET:F4`3&EC:'1E(')E9V5N`%9R;V5G(&QI
M8VAT92!R96=E;@!,:6-H=&4@<F5G96X`3&EC:'1E(')E9V5N8G5I`$QI8VAT
M92!R96=E;B!M970@;VYW965R`$QI8VAT92!S;F5E=7<`3&EC:'1E('-N965U
M=V)U:0!,:6UE<FEC:P!"97!E<FL@9&4L('1E(&5X<&]R=&5R96XL('1I:F1S
M9'5U<CH`3&EN:P!,:6YK('=I:G-T(&YA87(Z`$QI;FL@:&5T(&4M;6%I;&%D
M<F5S(&%A;B!D92!N:65U=R!B97)I8VAT('!A9VEN82!T:6ID96YS('=E97)G
M879E`$QI;FMS`$QI;G5X($-O;VMI90!,:6IS="`M(&=E8G)U:6ME<B!K86X@
M9&4@;6%P('II96X`1&%T86)A<V5L:6IS=`!,:6IS="!V86X@:&5L<"!O;F1E
M<F1E;&5N`%1A8F5L;&EJ<W0`3&EJ<W0M07)C:&EE9@!,:6IS="U(96QP`$QI
M:G-T+4ED`$QI:G-T+45I9V5N86%R`$QI:G-T+5!O<W0`3&EJ<W0M26YS8VAR
M:6IV96X`3&EJ<W0M56ET<V-H<FEJ=F5N`%=E97)G979E;B!V86X@9V5B<G5I
M:V5R<VQI:G-T(&ES('5I=&=E<V-H86ME;&0N`$QI=&5R871U=7(`3&ET;W5W
M96X`7TQO8V%T:64`3&%D96XN+BX`3&]K86QE('1I:F0Z`$QA;F1I;G-T96QL
M:6YG(&5N('1I:F0`3&]C871I90!!86YM96QD96X`069M96QD96X`06%N;65L
M9'1A:V5N`$%A;FUE;&1I;F<@;6ES;'5K="!O;61A="!U=R!G96)R=6EK97)S
M;F%A;2!O9B!W86-H='=O;W)D(&]N:G5I<W0@:7,@:6YG979O97)D+@!!86YM
M96QD:6YG(&UI<VQU:W0N`$QA;F=E('1E:W-T`$QI969D90!,86%G`$=R:65K
M<V4@:VQE:6YE(&QE='1E<G,`3&%T:6IN<V4@:VQE:6YE(&QE='1E<G,`2VQE
M:6YE(%)O;65I;G-E(&=E=&%L;&5N`$QU>&5M8G5R9P!-30!-3U1$`$U3+51.
M148@8FEJ;&%G92!B979A='1E(&=E96X@9&%T82X`35-'`$UA8V%O`$UA8V5D
M;VYIZRP@1&4@=G)O96=E<F4@2F]E9V]S;&%V:7-C:&4@4F5P=6)L:65K('9A
M;@!-861A9V%S8V%R`$UA9VEE`$4M;6%I;`!-86EL8F5H965R9&5R`$UA86L@
M;&EN7VLN+BX`36%L87=I`$UA;&5I<VGK`$UA;&%D:79E;@!-86QI`$UA;'1A
M`$%G96YD82=S(&]P(&%F<W1A;F0L(&)E:&5R96XN`$)E:&5E<B!U=R!L:6IS
M="!M970@8V%T96=O<FEEZVX@96X@9&4@8V]R<F5S<&]N9&5R96YD92!K;&5U
M<F5N+"!W86%R;65E(&]N9&5R9&5L96X@=V]R9&5N(&=E;&%B96QD`$UA<#(T
M(&MA87)T`$UA<%%U97-T:V%A<G0`36%A<G0`36%R9V4`36%R:V5E<B!M970@
M1V5Z:65N+TYI970@1V5Z:65N('9L86=G96X`36%R:V5E<B!M970@86YD97)E
M('9L86=G96X@*&(N=BX@0F5L86YG<FEJ:R]"96%N='=O;W)D*0!-87)C:&%L
M;"!E:6QA;F1E;@!-87)T:6YI<75E`$]V97)E96YK;VUE;F1E('9E;&1E;@!-
M875R971A;FGK`$UA=7)I=&EU<P!-87AI;6%A;"!T;V5G97-T86%N(&MR961I
M970N`$UA>&EM=6T@8F5R:6-H=&]N9&5R9&5L96X@;W9E<G-C:')E9&5N+@!-
M87AI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@,C0@=75R.B``
M36%X:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N(#8@=75R.B``
M36%X:6UA;&4@;&5N9W1E`$UE:0!-87EO='1E`$=E;F5E<VMU;F1E`%9E<F=A
M9&5R:6YG`$QE9&5N`$UE;G5L:6IS=`!-96YU(&UO9&4Z`$-E;&QE;B!S86UE
M;G9O96=E;@!"97)I8VAT`$)E<FEC:'0@;65T('-U8V-E<R!G979E<FEF:65E
M<F0L(&UA87(@:&5T(&-E<G1I9FEC86%T('9A;B!D92!O;F1E<F=E=&5K96YD
M92!K;VX@;FEE="!W;W)D96X@9V5V97)I9FEE97)D+@!"97)I8VAT('9E<FQO
M<&5N+@!"97)I8VAT='EP90!-971A<B!7965R`$U%5$%2(&)L;VL@:7,@;FEE
M="!B97-C:&EK8F%A<BX`345405(@8FQO:R!I<R!N:65T(&)E<V-H:6MB86%R
M+B!$971A:6QS('II:FX@9V5L;V=D('9O;W(@9&4@<WES=&5E;6)E:&5E<F1E
M<BX`365T:&]D90!-971R:7-C:`!-97AI8V\`36EC<F]N97-IZRP@1F5D97)A
M;&4@4W1A=&5N('9A;@!-:61D96X`36EM92!T>7!E`$UI;FEM=6T@=&5M<&5R
M871U=7(@=F%N(&1E(&%F9V5L;W!E;B`R-"!U=7(Z(`!-:6YI;75M('1E;7!E
M<F%T=75R('9A;B!D92!A9F=E;&]P96X@-B!U=7(Z(`!-:6YU=&5N`$UI<G)O
M<@!!;&QE<FAA;F1E`$=E;6ES=&4@9V5B975R=&5N:7-S96YL:6IS=`!/;G1B
M<F5K96YD92!014%2(&UO9'5L92!(5%107U)E<75E<W0N`$]N=&)R96ME;F1E
M(&-O;F9I9W5R871I92X@52!D:65N="!D97IE(&YU('1E(&=E;F5R97)E;BP@
M=V%N;F5E<B!U(&1E>F4@=&]E<&%S<VEN9R!W:6QT(&=E8G)U:6ME;BX`3VYT
M8G)E:V5N9"!B97)I8VAT($E$+@!/;G1B<F5K96YD92P@=F5R96ES=&4L(%!%
M05(@;6]D=6QE($UA:6PN`$]N=&)R96ME;F0@<V5S<VEE($E$+@!-80!-;V)I
M96QE(&4M;6%I;`!'96UI9&1E;&0`5VEJ>FEG:6YG<V1A='5M`%=I:GII9R!5
M4DP`36]D=6QU<P!-;VQD879IZRP@4F5P=6)L:65K('9A;@!-;VYA8V\`36%A
M;F1A9P!-;VYG;VQIZP!-86%N9`!-86%N9'=E97)G879E`$UA86YD(&5N(&IA
M87(`36%A;F1E;&EJ:W,`36%A;F1E;&EJ:V4@9V5B975R=&5N:7-S96X@;&EJ
M<W0`36%A;F1E;&EJ:W,Z(&AE<FAA86QT('II8V@@96QK90!+;VUE;F1E(&UA
M86YD96X`36%A;F1E;B!V;V]R`$UO;G1S97)R870`36%A;F9A<V5N`$UA<F]K
M:V\`5F]O<FYA;65L:6IK(&]N8F5W;VQK=`!6;V]R;F%M96QI:FL@8F5W;VQK
M=`!6;V]R;F%M96QI:FL@>F]N;FEG`$YA87(@8F5N961E;@!.86%R(&QI;FMS
M`$YA87(@<F5C:'1S`$YA87(@8F]V96X`3F%A<B!B96YE9&5N`$YA87(@8F]V
M96X`36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&EJ<W1E;@!-
M965R9&5R92!I0V%L96YD87(@;VYD97)D96QE;B!G979O;F1E;CL@<VQE8VAT
M(.GI;B!V179E;G0@=V]R9'0@;VYD97)S=&5U;F0N`$UE97)V;W5D:6=E('-E
M;&5C=&EE`$UI:FX@86-C;W5N=`!-:6IN(&%G96YD82=S`$UI:FX@86=E;F1A
M)W,Z`$UI:FX@1G)E96)U<WD@55),`$UI:FX@<&]R=&%A;`!-:6IN('!O<G1A
M86QL87EO=70`0FER;6$`3F5E+"!I:R!A8V-E<'1E97(@9&4@=F]O<G=A87)D
M96X@3DE%5`!.86%M`$YA;6EB:>L`3F%U<G4`3F5P86P`3F5D97)L86YD`$YE
M9&5R;&%N9',@06YT:6QL96X`3F5T<V-A<&4@0F%S:7,@55),`$YE='-C87!E
M($-!(&EN=')E:VMI;F<@55),`$YE='-C87!E($-!(&)E;&5I9"!54DP`3F5T
M<V-A<&4@=F5R;FEE=7=I;F<@55),`$YE='-C87!E(&EN=')E:VMI;F<@55),
M`$YE='-C87!E(%-33"!S97)V97)N86%M`$YE='-C87!E(&-E<G1I9FEC86%T
M8V]M;65N=&%A<@!.971S8V%P92!C97)T:69I8V%A='1Y<&4`3F5T=V5R:P!.
M;V]I=`!.:65U=R!#86QE9&]N:>L`3FEE=7=E(&-A=&5G;W)I90!.:65U=V4@
M9V5B975R=&5N:7,`3FEE=7=E(&UA86X`3FEE=7=E(&=E8G)U:6ME<G-N86%M
M("AO<'1I;VYE96PI`$YI975W(%IE96QA;F0`3FEE=7<@<V-H97)M("A?8FQA
M;FLI`$YI975W<P!.:65U=W-G<F]E<&5N`%9O;&=E;F1E`%9O;&=E;F1E(#(T
M('5U<@!6;VQG96YD92!D86<`5F]L9V5N9&4@;6%A;F0`5F]L9V5N9&4@=V5E
M:P!6;VQG96YD92!D86<`5F]L9V5N9&4@;W!T:65S`%9O;&=E;F1E('=E96L`
M3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3F%C:'0`3FEU90!'965N(&%A;G=E
M>FEG96X`1V5E;B!B97-C:&EK8F%R92!C;VYF:6=U<F%T:65D871A(&]M('9E
M<G-C:&EL;&5N('1E(&QA=&5N('II96XN`$=E96X@8F5S8VAI:V)A<F4@<W1R
M871E9VEE('9O;W(@:&5T(&UA:V5N('9A;B!)4T\@:6UA9V5S+@!'965N(&)A
M=&-H<VIA8FQO;VXN`$5R(&)E<W1A870@9V5E;B!B;&]K(&]P(&1E(&=E=G)A
M86=D92!P;W-I=&EE`$=E96X@86=E;F1A;F%A;2!O<&=E9V5V96X@=F]O<B!-
M0T%,(&%U=&AE;G1I8V%T:64N`$=E96X@86=E;F1A)W,@8F5S8VAI:V)A87(@
M=F]O<B!G87-T96XN`$=E96X@=VEJ>FEG:6YG96XN`$%A;B!D:70@<F5C:'0@
M:W5N;F5N(&=E96X@8VAI;&0@<F5C:'1E;B!W;W)D96X@=&]E9V5V;V5G9"X`
M1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R("5S
M+@!'965N(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O;W(@
M1E10(%9&4RX`1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E
M;B!V;V]R(%-13"!61E,N`$=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O
M<&=E9V5V96X@=F]O<B!344PM8F5S=&%N9"!61E,N`$=E96X@:W)E9&EE="!M
M965R+@!'965N(&)E<W1E;6UI;F<@;W!G96=E=F5N+@!'965N(&5I;F1D871U
M;0!'965N(&=E8F5U<G1E;FES<V5N('=E97(@=&4@9V5V96X`1V5E;B!B97-T
M86YD('5P;&]A9&5D`$=E96X@=G)I:B]B97IE="!I;F9O<FUA=&EE(&)E<V-H
M:6MB86%R('9O;W(@)7,`1V5E;B!I0V%L96YD87)D871A(&=E=F]N9&5N+@!%
M<B!I<R!G965N(&QO8V%T:64@:6YG97-T96QD+@!'965N(&)E<FEC:'0@9V5L
M979E<F0N`$=E96X@;F%A;2!O<&=E9V5V96XN`$=E96X@9V5T86P@;W!G96=E
M=F5N+@!'965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S`$=E96X@=V%C:'1W;V]R
M9"!O<&=E9V5V96X@=F]O<B!(5%10(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C
M:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!)34%0(&%U=&AE;G1I8V%T:64N`$=E
M96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F%N($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!,;V=I;B!A
M=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V
M96X@=F]O<B!334(@875T:&5N=&EC871I92X`1V5E;B!P860@;F%A<B!D92!/
M<&5N4U-,(&)I;F%R>2!O<&=E9V5V96XN($1E($]P96Y34TP@8FEN87)Y(&ES
M(&YO9&EG(&]M('1E(&MU;FYE;B!W97)K96X@;65T(%!+0U,@,3(@9&%T82X`
M1V5E;B!H86YG96YD92!I;G-C:')I:G9I;F=E;BX`1V5E;B!L:6YIZW)I;F<`
M1V5E;B!Z:6ID96X`1V5E;B!T:6ID96QI:FL@9&ER96-T;W)Y(&)E<V-H:6MB
M86%R('9O;W(@8V%C:&4N`$=E96X@9V5B<G5I:V5R<VYA86T@96XO;V8@=V%C
M:'1W;V]R9"!V97)Z;VYD96XN`$=E96X@9V5L9&EG92!834P@9&%T82!T97)U
M9V=E<W1U=7)D`$=E96X@9V5L9&EG(&4M;6%I;&%D<F5S(&=E=F]N9&5N`$=E
M96X@=V%A<F1E;@!'965N('9E<G-I92!G979O;F1E;B!I;B!O<FEG:6YE;&4@
M8V]N9FEG=7)A=&EE+B!(97)G96YE<F5E<B!C;VYF:6=U<F%T:64N`$=E96X@
M=F5R<VEE(&=E=F]N9&5N(&EN('5W(&-O;F9I9W5R871I92X@2&5R9V5N97)E
M97(@8V]N9FEG=7)A=&EE+@!'965N`$=E96X@*'9E<G!L:6-H="D`3F]O<F0@
M175R;W!E97,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK(&5I;&%N9`!.;V]R9&5L
M:6IK(&AA;&9R;VYD`$UA<FEA;F5N`$YO;W)W96=E;@!.:65T(&YA`$YI970@
M=F]O<@!'965N(&1I<F5C=&]R>0!.:65T(&=E=F]N9&5N`$YI970@9V5I;7!L
M96UE;G1E97)D+@!.:65T(&EN9V5S=&5L9`!.:65T(&]N9&5R<W1E=6YD+@!.
M;W1I=&EE<P!.:65T<R!T92!B;&%D97)E;BP@9V$@=&5R=6<N`$YO=F5M8F5R
M`$YU`$=E=&%L`$%A;G1A;"!K87)A:W1E<G,`06%N=&%L(&MO;&]M;65N`$%A
M;G1A;"!R:6IE;@!'971A;&QE;B!N:65T(&]P9V5G979E;B!V;V]R(&)I:G=E
M<FME;B!I;B!E96X@9&ES=')I8G5T:65L:6IS="X`3TL`3V)J96-T`$]B:F5C
M=&5I9V5N86%R`$]C=&%A;`!/:W1O8F5R`$)E;&5D:6=I;F=F:6QT97(`2V%N
M=&]O<@!/;6%N`$%L;&5E;B!)34%0('-E<G9E<G,@;VYD97)S=&5U;F5N(&=E
M9&5E;&1E(&UA<'!E;BX`06QL965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S`%-L
M96-H="#IZ6X@92UM86EL861R97,@=&]E9V5S=&%A;BX`06QL965N(&1E(&5I
M9V5N86%R(&]F(&5E;B!S>7-T965M8F5H965R9&5R(&UA9R!D92!E:6=E;F%A
M<G)E8VAT96X@=F%N(&5E;B!S:&%R92!W:6IZ:6=E;@!/<&5N(&EN(&5E;B!N
M:65U=R!S8VAE<FT`3W!E;E-33"!F;W5T.B!K;VX@9V5E;B!D871A('5I="!H
M970@;VYD97)T96ME;F1E(%,O34E-12!O;F1E<F1E96P@:&%L96XN`$]P96YT
M(&1E>F4@;&EN:R!I;B!E96X@;FEE=7<@<V-H97)M`$)E<W1U<FEN9W-S>71E
M96T`3W!T:6]N965L`$]P=&EE<P!/<'1I97,@=F]O<B`E<P!'96]R9&5N9&4@
M;&EJ<W0`3W)G86YI<W1A=&EE`$]R9V%N:7-A=&EE(&5E;FAE:60`3W)G86YI
M<V5R96X`3W)I9VEN965L('1O97!A<W-I;F=S<VIA8FQO;VX`3W)I9VEN96QE
M('-J86)L;VYE;B!I;B`E<SH`06YD97)E`$%N9&5R92!I;F9O<FUA=&EE`$5I
M9V5N86%R`$5I9V5N86%R<F5C:'1E;@!004T@875T:&5N=&EC871I92!I<R!N
M:65T(&)E<V-H:6MB86%R+@!$:6=I=&%L92!01U`@:&%N9'1E:V5N:6YG`$=E
M8V]D965R9&4@4$=0(&1A=&$`3W!E;F)A<F4@4$=0('-L975T96P`3VYD97)T
M96ME;F1E+V=E8V]D965R9&4@4$=0(&1A=&$`4$A0(&-O9&4`4$A0('-H96QL
M`%!-`$QI8VAT92!R96=E;B!N82`Q,BXP,"!U=7(`0G5I96X@;F$@,3(N,#`@
M=75R`$]N=V5E<G-B=6EE;B!N82`Q,BXP,"!U=7(`4$A0(%]3:&5L;`!6<FEJ
M92!R=6EM=&4`4&%K:7-T86X`4&%L874`4&%L97-T:6IN<R!497)R:71O<FEU
M;2P@0F5Z970`4&%L;2!$871E0F]O:P!086YA;6$`4&%P=6$@3FEE=7<@1W5I
M;F5A`%!A<F%G=6%Y`$=E9&5E;'1E;&EJ:R!B97=O;&MT`%=A8VAT=V]O<F0`
M5V%C:'1W;V]R9"!O;FIU:7-T`%=A8VAT=V]O<F0@:7,@=F5R96ES="!V;V]R
M(%)!1$E54R!A=71H96YT:6-A=&EE+@!786-H='=O;W)D(&UE="!B979E<W1I
M9VEN9P!786-H='=O;W)D.@!786-H='=O;W)D.B``5V%C:'1W;V]R9&5N(&UO
M971E;B!O=F5R965N:V]M96XN`$%F9V5L;W!E;B!G96)E=7)T96YI<W-E;FQI
M:G-T`%!L86MK96X`4&QA:VME;B!V86YA9B!P<FEK8F]R9`!0860`4&%T<F]O
M;@!(86YG96YD92!I;G-C:')I:G9I;F=E;CH`365N<V5N`%!R;V-E;G0`3VYD
M97)H;W5D<W=E<FMZ86%M:&5D96X@=6ET=F]E<F5N`$]N9&5R:&]U9'-W97)K
M>F%A;6AE9&5N('5I='9O97)E;B!B:6H@86%N;65L9&EN9S\`1&5Z92!G96)E
M=7)T96YI<R!D969I;FET:65F('9E<G=I:F1E<F5N/P!296-H=`!4;V5G86YG
M(&=E=V5I9V5R9`!296-H=&5N`%)E8VAT96YB96AE97(`4&5R<V]O;FQI:FME
M(&EN9F]R;6%T:64`4&5R=0!(=6ES9&EE<F5N`%!H:6QI<'!I:FYE;@!496QE
M9F]O;@!&;W1O)W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`2VQI:R!I
M;B!E96X@8V5L+"!A+G4N8BX`0F5V97-T:6<L(&1A="!U(&1I="!E;&5M96YT
M('=I;'0@=F5R=VEJ9&5R96XL(&$N=2YB.@!"979E<W1I9RP@9&%T('4@9&ET
M(&5L96UE;G0@=VEL="!L;W-K;W!P96QE;BP@82YU+F(N`$=E968@965N(&UA
M86YD(&5N(&5E;B!J86%R+"!A+G4N8BX`165N(&YA86T@=F]O<B!D92!N:65U
M=V4@8V%T96=O<FEE(&EN=F]E<F5N+"!A+G4N8BXZ`$=E968@965N(&=E;&1I
M9R!)4"!A9')E<RP@82YU+F(N`$=E968@965N(&=E;&1I9V4@9&%T=6T@82YU
M+F(N+"!C;VYT<F]L965R(&AE="!A86YT86P@9&%G96X@:6X@9&4@;6%A;F0N
M`$=E968@965N(&=E;&1I9V4@=&EJ9"P@82YU+F(N`$=E968@965N('-A;65N
M=F%T=&EN9R!V86X@:&5T('!R;V)L965M+"!A+G4N8BX`1V5E9B!U=R!G96)R
M=6EK97)S;F%A;2!E;B!W86-H='=O;W)D+"!A+G4N8BX`1V5E9B!D92!N:65U
M=V4@8V%T96=O<FEE;F%A;2P@82YU+F(N.@!0;VQE;@!0;VQI=&EE:P!096EL
M:6YG96X`4&]R=&%A;&]P=&EE<P!0;W)T=6=A;`!0;W-I=&EO;F5R:6YG('9A
M;B!D97IE(&%F8F5E;&1I;F<`4&]S:71I;VYE<FEN9R!V86X@9&5Z92!T86)E
M;`!3='5U<B!N86%R(&1E>F4@;6%P("AN:65T(&%F9V5D=V]N9V5N(&1O;W(@
M24U!4"D`3F5E<G-L86<@=F%N(&1E(&%F9V5L;W!E;B`E<R!U<F5N.B``4')E
M9G-?;&1A<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N
M+@!0<F5F<U]S97-S:6]N.B!V97)E:7-T92!S97-S:64@97AT96YT:64@;FEE
M="!G979O;F1E;BX`3'5C:'1D<G5K`$QU8VAT9')U:R!O<"!Z965N:79E874Z
M(`!,=6-H=&1R=6LZ(`!"96]O<F1E;&5N`$)E;V]R9&5E;"!D92!A9F)E96QD
M:6YG(&EN(&5E;B!N:65U=R!S8VAE<FT`5F]R:6=E(&1A9P!6;W)I9V4@=V5E
M:P!6;W)I9V4@9&%G`%9O<FEG92!O<'1I97,`1&]C=6UE;G0@869D<G5K:V5N
M`%!R:79E('-L975T96P`4')O8FQE96T`4')O8FQE96UB97-C:')I:G9I;F<`
M4')O:F5C=&5N`%!R;VUP="!T96MS=`!/<&5N8F%R92!S;&5U=&5L`$]P96YB
M87)E('-L975T96P@86QG;W)I=&AM90!/<&5N8F%A<B]0<FEV92!S;&5U=&5L
M<&%A<B!N:65T(&=E9V5N97)E97)D+@!0=65R=&\@4FEC;P!1=6%T87(`475E
M<GD`4E-!(&]P96YB87)E('-L975T96P@*"5D(&)I="D`2V5U>F5R;VYD:F4@
M<V5L96-T:64`4F5G96X`5G)O96<@<F5G96X`3&%A="!R96=E;@!296=E;F)U
M:0!286YD;VT@1F]R='5N90!697)H;W5D:6YG`$QE>F5N`$QE97,@8F5R:6-H
M=&5N`"5S(&5C:'0@=F5R=VEJ9&5R96X_($1E>F4@8F5W97)K:6YG(&MA;B!N
M:65T(&]N9V5D86%N(&=E;6%A:W0@=V]R9&5N+@!'96)R=6EK97)S9&%T82!V
M86X@9V5B<G5I:V5R("5S(&5C:'0@=F5R=VEJ9&5R96X_($1E>F4@8F5W97)K
M:6YG(&MA;B!N:65T(&]N9V5D86%N(&=E;6%A:W0@=V]R9&5N+@!(97)H86%L
M('1O=`!(97)H86QI;F<`2&5R:&%L:6YG<V1A=&$`2&5R:&%L:6YG<V5I;F1D
M871U;0!(97)H86QI;F=S:6YT97)V86P`2&5R:&%L:6YG<W1Y<&4`2&5R:&%A
M;'0@9&%G96QI:FMS`$AE<FAA86QT(&UA86YD96QI:FMS`$AE<FAA86QT('=E
M:V5L:6IK<P!(97)H86%L="!J86%R;&EJ:W,`2&5R:&%A;'0@=7<@=F]R:6=E
M(&)E=V5R:VEN9P!697)V97)S(&1Y;F%M:7-C:&4@;65N=2!O;F1E<F1E;&5N
M.@!0;W)T86QW965R9V%V92!V97)V97)S96XZ`%)E9V5X`$)E=')E:VMI;F=E
M;B!B<F]W<V5R`$]P;65R:VEN9V5N`$AE<FEN;F5R:6YG.B`E<P!!9V5N9&$G
M<R!O<"!A9G-T86YD`$%G96YD82=S(&]P(&%F<W1A;F0Z`%-E<G9E<G,@;W`@
M869S=&%N9`!54DP@;W`@869S=&%N9"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%9E<G=I:F1E<F5N`"5S('9E<G=I:F1E<F5N`$%A;G=E>FEG
M92!V97)W:6ID97)E;@!";&]K('9E<G=I:F1E<F5N`$MO;&]M('9E<G=I:F1E
M<F5N`$]P;6%A:R!V97)W:6ID97)E;@!086%R('9E<G=I:F1E<F5N`%9E<G=I
M:F1E<B!H970@;W!G97-L86=E;B!S8W)I<'0@=6ET(&1E('1I:F1E;&EJ:V4@
M9&ER96-T;W)Y(&]P(&1E('-E<G9E<BX`5F5R=VEJ9&5R(&1E`%9E<G=I:F1E
M<B!D97IE(&YO9&4@=6ET(&AE="!D;V-U;65N=`!'96)R=6EK97(@=F5R=VEJ
M9&5R96X`5F5R=VEJ9&5R(&=E8G)U:6ME<CH@)7,`5F5R>F]E:R!K;VX@;FEE
M="!W;W)D96X@8F5A;G1W;V]R9"X@1V5R971O=7)N965R9&4@9F]U=&-O9&4Z
M(`!697)E:7-T`%9E<F5I<W1E(&%A;G=E>FEG96X`2&5R<W1E;&QE;@!297-E
M="!W86-H='=O;W)D`%)E<V5T('5W('=A8VAT=V]O<F0`2&5R<W1E;"!S=&%N
M9&%A<F1I;G-T96QL:6YG96X`06YT=V]O<F0`4F5S=6QT871E;@!497)U9R!N
M86%R(&]P=&EE<P!2975N:6]N`$-O;F9I9W5R871I92!T97)U9WIE='1E;@!2
M:6-H(%1E>'0@161I=&]R(&]P=&EE<P!286%D<V5L<P!296-H=',`4F5C:'1S
M92!K;W``4F5C:'1S92!W86%R9&5N`%)I7VIE:6=E;G-C:&%P<&5N+BXN`%)O
M;`!2;V5M96YIZP`Q.#`@9')A86EE;@!.86%R(&QI;FMS(&1R86%I96X`3F%A
M<B!R96-H=',@9')A86EE;@!2:6H@96EG96YS8VAA<'!E;@!2:6H@96EG96YS
M8VAA<'!E;@!2:6IE;CH`3&EN:>MR:6YG`$QI;FGK<FEN9R!Z86P@=F5R<V-H
M:6IN96X@='5S<V5N(&%L;&4@<FEJ96X@96X@:V]L;VUM96X`3&EN:>MR:6YG
M('IA;"!A;&QE96X@='5S<V5N(&MO;&]M;65N('9E<G-C:&EJ;F5N`$QI;FGK
M<FEN9R!Z86P@86QL965N('1U<W-E;B!R:6IE;B!V97)S8VAI:FYE;@!3=&%R
M=&5N`%)U<W-I<V-H92!&961E<F%T:64`4G=A;F1A`$-R>7!T;V=R869I<V-H
M92!3+TU)344@:&%N9'1E:V5N:6YG`%,O34E-12!G96-O9&5E<F0@8F5R:6-H
M=`!305-,(&%U=&AE;G1I8V%T:64@:7,@;FEE="!B97-C:&EK8F%A<BX`4TU3
M('9E<G-T=7)E;@!344P@<VAE;&P`4U-(`%-50T-%4P!37U%,('-H96QL`%IA
M`%-T($AE;&5N80!3="!+:71T<R!E;B!.979I<P!3="!,=6-I80!3="!0:65R
M<F4@96X@36EQ=65L;VX`4W0@5FEN8V5N="!E;B!D92!'<F5N861I;F5S`%IE
M;&9D92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@
M96X@4')I;F-I<&4`4V%T96QL:65T<')O=FED97(`6F%T97)D86<`4V%U9&D@
M07)A8FGK`"5S(&]P<VQA86X`3W!S;&%A;B!A;',@;FEE=7<`1V5B975R=&5N
M:7,@;W!S;&%A;@!/<'1I97,@;W!S;&%A;@!'96=E;F5R965R9&4@8V]N9FEG
M=7)A=&EE(&%L<R!02%`@<V-R:7!T(&]P9V5S;&%G96X@:6X@9&4@=&EJ9&5L
M:6IK92!D:7)E8W1O<GD@=F%N('5W('-E<G9E<BX`)7,@8V]N9FEG=7)A=&EE
M(&]P9V5S;&%G96X`5V5T96YS8VAA<`!:;V5K96X`6F]E:VUA8VAI;F5S`$MI
M97,@8F5S=&%N9&5N`%-E;&5C=&5E<B!E96X@9&%T=6T`4V5L96-T965R(&5E
M;B!G<F]E<"!O;2!T;V4@=&4@=F]E9V5N`%-E;&5C=&5E<B!E96X@;FEE=7=E
M(&5I9V5N86%R`%-E;&5C=&5E<B!E96X@<V5R=F5R`%-E;&5C=&5E<B!E96X@
M9V5B<G5I:V5R(&]M('1O92!T92!V;V5G96X`4V5L96-T965R(&%L;&4@9&%T
M=6UC;VUP;VYE;G1E;BX`4V5L96-T965R(&5E;B!O8FIE8W0`2VEE<R!B979E
M<W1I9VEN9W-O<'1I97,L(&AO92!D92!V97)S8VAI;&QE;F1E('=E97)G879E
M<R!W;W)D96X@869G96)E96QD(&5N(&MI97,@965N('-T86YD86%R9'=E97)G
M879E+@!396QE8W1E97(@9&4@86=E;F1A(&]M(&YA87(@=&4@:6UP;W)T97)E
M;CH`4V5L96-T965R(&1E(&)E;F]D:6=D92!K87)A:W1E<G,@=6ET(&1E(&]N
M9&5R<W1A86YD92!V86MJ97,N(%4@:W5N="!D97IE(&1A;B!K;W!IZW)E;B!E
M;B!P;&%K:V5N(&EN(&AE="!T96MS=&=E8FEE9"X`4V5L96-T965R(&AE="!D
M871U;7-C:&5I9&EN9W-T96ME;CH`4V5L96-T965R(&AE="!D871U;69O<FUA
M870Z`%-E;&5C=&5E<B!H970@97AP;W)T9F]R;6%A=#H`4V5L96-T965R(&AE
M="!I;7!O<G1B97-T86YD.@!396QE8W1E97(@9&4@965R<W1E('=E96MD86<Z
M`%-E;&5C=&5E<B!H970@9F]R;6%A="!V86X@:&5T(&)R;VYB97-T86YD.@!3
M96QE8W1E97(@9&4@:61E;G1I=&5I="!D:64@=2!W:6QT('=I:GII9V5N.@!3
M96QE8W1E97(@:&5T('1I:F1S8VAE:61I;F=S=&5K96XZ`%-E;&5C=&5E<B!H
M970@=&EJ9'-F;W)M86%T.@!396QE8W1E97(@965N('1I:F1S9'5U<G=E97)G
M879E.@!396QE8W1E97(@965N('=E97)G879E('=E;&ME('=O<F1T(&=E8G)U
M:6MT(&YA(&]P<W1A<G1E;CH`4V5L96-T965R('1W964@;W9E<F5E;FMO;65N
M9&4@=F5L9&5N+@!396QE8W1E97(@=V5L:V4@9V5B975R=&5N:7-S96X@=V]R
M9&5N('=E97)G96=E=F5N(&EN(&AE="!P;W)T86%L+@!396QE8W1E97(@=7<@
M:VQE=7)S8VAE;6$N`%-E;&5C=&5E<B!U=R!G97=E;G-T92!T86%L.@!0<F]B
M;&5E;7)A<'!O<G0@=F5R>F5N9&5N`%9E<GIE;F0@4TU3`%-T=75R(&5E;B!A
M9GIE9V=I;F<@86%N(&%L;&4@86%N=V5Z:6=E;B!B:6H@=F5R=VEJ9&5R96X@
M=F%N(&1E>F4@9V5B975R=&5N:7,`165N(&4M;6%I;"!V97)S='5R96X@86%N
M("5S`%-T=75R('5P9&%T97,O=6ET;F]D:6=I;F=E;B!A86X@86QL92!A86YW
M97II9V5N(&)I:B!O<'-L86%N('9A;B!D97IE(&=E8F5U<G1E;FES`%-E;F5G
M86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<G9IZR!E;B!-;VYT96YE9W)O`%-E
M<FEE;G5M;65R`%-E<W-I92!)1"!V97)L;W!E;BX`26YS=&5L;&5N`$5I;F1D
M871U;2!I;G-T96QL96X`26YS=&5L;&5N('9A;B!O<'1I97,@;VT@=2!T;V4@
M=&4@<W1A86X@=7<@=V%C:'1W;V]R9"!T92!R97-E='1E;BP@=V%N;F5E<B!U
M(&1I="!B96YT('9E<F=E=&5N+@!(97)H86QI;F=S96EN9&1A='5M(&EN<W1E
M;&QE;@!"96=I;F1A='5M(&EN<W1E;&QE;@!);G-T96QL96X@=F%N('-E<G9E
M<G,@;W`@869S=&%N9"!D:64@=2!W:6QT(&)E;F%D97)E;B!V86YU:70@=7<@
M<&]R=&%L+@!);G-T96QL96X@=F%N('5W(&=E=V5N<W1E('1A86PL('1I:F1Z
M;VYE(&5N(&1A='5M;W!T:65S+@!);G-T96QL96X@=F%N('5W(&]P<W1A<G1T
M;V5P87-S:6YG+"!K;&5U<G-C:&5M82P@<&%G:6YA=F5R=F5R<VEN9R!E;B!A
M;F1E<F4@=V5E<F=A=F5O<'1I97,N`%-E='5P('5P9W)A9&4@<V-R:7!T<R!B
M97-C:&EK8F%A<@!697)S8VAI;&QE;F1E(&QO8V%T:65S(&UO9V5L:6IK(&UE
M="!D92!P87)A;6%T97(Z(`!397EC:&5L;&5N`$=E9&5E;&1E(&%G96YD82=S
M.@!7:6YK96QE;@!+;W)T92!S86UE;G9A='1I;F<`1&EE;F5N('-N96QT;V5T
M<V5N('9O;W(@9&4@;65E<W1E(&QI;FMS(&=E9&5F:6YI965R9"!T92!W;W)D
M96X_`%=E97)G979E;@!4;V]N(&-A=&5G;W)I96QE9V5N9&$_`%9E<G=I:F1E
M<F5N+"!A;&%R;2!E;B!H97)H86QI;F=P:6-T;V=R86UM96X@=V5E<F=E=F5N
M(&EN(&%G96YD87=E97)G879E;C\`5F5R<V-H:6QL96X@;&%T96X@>FEE;B!T
M=7-S96X@9&4@:'5I9&EG92!O<&=E<VQA9V5N(&-O;F9I9W5R871I92!E;B!D
M92!N:65U=V4@9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92X`5&%A:W9E<G9A
M;&1A=&$@=V5E<F=E=F5N(&EN(&1E(&%G96YD83\`5&]O;B!6<FEJ+T)E>F5T
M(&QE9V5N9&$_`$QA871S=&4@86%N;65L9&EN9W-T:6ID('=E97)G979E;B!B
M:6H@86%N;65L9&5N/P!!;&QE96X@9V5B975R=&5N:7-S96X@;65T(&5E;B!A
M;&%R;2!W965R9V5V96X_`$]P=&EE('=E97)G979E;B!O;2!O<FEG:6YE96P@
M=&4@8F5W87)E;@!+:65Z97(@=V5E<F=E=F5N`%1A8F5L8F5W97)K:6YG<W1A
M86MB86QK('=E97)G979E;C\`)7,@;65N=2!A86X@9&4@;&EN:V5R:V%N="!W
M965R9V5V96X_`%1A8F5L8V5L96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E
M<B!W965R9V5V96X`5&%B96QE:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS=&5R
M('=E97)G979E;@!486)E;')I:F5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T
M97(@=V5E<F=E=F5N`$%F8F5E;&1I;F=S96EG96YS8VAA<'!E;B!D:6%L;V]G
M=F5N<W1E<B!W965R9V5V96X`(%1I:F0@=V5E<F=E=F5N('1U<W-E;B!E;&ME
M(&1A9R!I;B!W965K=V5E<F=A=F5N/P!5<&QO860@=V5E<F=E=F5N`$)U:65N
M`$)U:65N('9R;V5G`$)U:65N(&QA870`5F5R:VQE:6YE;@!697)K;&5I;B!O
M9B!V97)P;&%A=',@;F%B=7)I9V4@8FQO:VME;B!E97)S=`!3:65R<F$@3&5O
M;F4`26YT96ME;F5N`$AA;F1T96ME;FEN9P!(86YD=&5K96YI;F<@86QG;W)I
M=&AM90!3:6YG87!O<F4`1W)O;W1T90!/;F1E<FAO=60@;W9E<G-L86%N`%-L
M;W=A:VEJ90!3;&]V96YIZP!3;F5E=7<`4VYE975W=FQA86<`4VYE975W8G5I
M96X`4VYE975W8G5I96X@;&%A=`!3;F5E=7=D:65P=&4Z(`!3;F5E=7=E<75I
M=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!E:6QA;F1E;@!3;VUA;&GK`$QI
M961E<F5N(&5N(&=E9&EC:'1E;@!3;W)T965R=F]L9V]R9&4@<V5L96-T:64`
M0G)O;F%D<F5S`%IU:60@069R:6MA`%IU:60@175R;W!E97,@*$E33RTX.#4Y
M+3,I`%IU:60@1V5O<F=IZR!E;B!D92!:=6ED(%-A;F1W:6-H(&5I;&%N9&5N
M`%IU:61E;&EJ:R!H86QF<F]N9`!3<&%T:>MR:6YG('1U<W-E;B!A86YG<F5N
M>F5N9&4@8V5L;&5N`%-P871IZW)I;F<@='5S<V5N(&EN:&]U9"!E;B!R86YD
M(&EN(&-E;`!38VAE:61I;F=S=&5K96X`4W!A=&GK<FEN9P!3<&%T:>MR:6YG
M(&5N('9R:6IE(')U:6UT90!3<&%N:F4`4W!A;0!3<&5C:6%A;"!K87)A:W1E
M<B!I;G9O97(`0V5L(&]P<W!L:71S96X`2V]L;VT@;W!S<&QI='-E;@!2:6H@
M;W!S<&QI='-E;@!3<&]R=`!3<FD@3&%N:V$`4W1A;F1A87)D`%-T87(@5')E
M:P!"96=I;F1A='5M`$)E9VEN="!O<`!"96=I;G1I:F0`4W1A<G1J86%R`%-T
M871?=7,`4W1A870@;V8@<')O=FEN8VEE`%-T871U<P!/<'-L86=F;W)M86%T
M`$%D<F5S`$1O;W)H86QE;@!3=')I;F=L:6IS=`!3=')I<"!D;VUE:6X@=F%N
M(&AE="!A9')E<P!3=&EJ;"!;0U-370!:;P!/;F1E<G=E<G``0F5V97-T:6=E
M;@!3=6)S8W)I<'0`4W5C8V5S`$-O;F9I9W5R871I92!M970@<W5C8V5S('1E
M<G5G9V5Z970N(%9E<FYI975W(&]M('=I:GII9VEN9V5N('1E('II96XN`$)A
M8VMU<&-O;F9I9W5R871I92!M970@<W5C8V5S<R!O<&=E<VQA9V5N+@`E<R!M
M970@<W5C8V5S(&=E<V-H<F5V96X`4V]E9&%N`%-A;65N=F%T=&EN9P!:;VYS
M;W!G86YG`%IO;G-O;F1E<F=A;F<`6F]N9&%G`%IO;FYI9P!:;VYS;W!G86YG
M`%IO;G-O<&=A;F<O6F]N<V]N9&5R9V%N9P!:;VYS;W!G86YG.B``6F]N<V]N
M9&5R9V%N9P!:;VYS;VYD97)G86YG.B``4W5P97)S8W)I<'0`3VYD97)S=&5U
M;FEN9P!3=7)I;F%M90!!8VAT97)N86%M`%-P:71S8F5R9V5N(&5N($IA;B!-
M87EE;@!3=V%Z:6QA;F0`6G=E9&5N`%IW:71S97)L86YD`%-Y;G1A>&9O=70@
M:6X@>F]E:W1E<FUE;@!3>7)I<V-H92!!<F%B:7-C:&4@4F5P=6)L:65K`$]N
M=V5E<G-B=6D`3VYW965R<V)U:65N`%135B!B97-T86YD`%1A8F5L`%1A8F5L
M96EG96YS8VAA<'!E;@!486)E;&5I9V5N<V-H87!P96X`5&%I=V%N`%1A:7=A
M;BP@4')O=FEN8VEE('9A;B!#:&EN80!4861Z:FEK:7-T86X`5&%N>F%N:6$L
M(%9E<F5N:6=D92!297!U8FQI96L@=F%N`$1O96PZ`%1A:V5N`%1E;&5F;V]N
M;G5M;65R`%1E;7!E<F%T=75R('9A;B!H970@869G96QO<&5N('5U<CH@`%1E
M;7!E<F%T=75R`%1E;7!E<F%T=75R.B``4VIA8FQO;VYB96AE97(`5F]O<FQO
M<&EG`%1E:W-T`$%L;&5E;B!T96MS=`!496MS="!U:71L:6IN96X`5&5K<W1B
M;W9E;FMA;G0`1&\`5&AA:7,@*%1)4RTV,C`I`%1H86EL86YD`$)E9&%N:W0@
M=F]O<B!H970@9V5B<G5I:V5N('9A;B!H970@<WES=&5E;2X`2&5T($%A;G=E
M>FEG96X@8F5W97)K96X@<V-H97)M(&ES(&YI970@;65E<B!A86YW97II9RX@
M069S;'5I=&5N+@!$92!&5%`@97AT96YT:64@:7,@;FEE="!B97-C:&EK8F%A
M<BX`1&4@2&]R9&4O2V]L86(@:6YT96=R871I92!O;F1E<G-T975N="`B)7,B
M(&YI970`1&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!W97)D(&YI970@9V5L861E
M;@!(970@3W!T:65S<V-H97)M(&ES(&=E<VQO=&5N+B!!9G-L=6ET96XN`$1E
M(&)E:&5E<F1E<B!D:65N="!E96X@<&5R;6%N96YT(')E8VAT96YB86-K96YD
M('1E(&-O;F9I9W5R97)E;B!A;',@=2!R96-H=&5N('=I;'0@9V5B<G5I:V5N
M+@!!;&QE96X@9&4@;VYD97)K86YT`$1E(&%G96YD82`B)7,B(&MA;B!N:65T
M('=O<F1E;B!V97)W:6ID97)D+@!$92!A9V5N9&$@(B5S(B!I<R!V97)W:6ID
M97)D+@!$92!A9V5N9&$@(B5S(B!I<R!H97)N;V5M9"!N86%R("(E<R(N`$1E
M(&%G96YD82`B)7,B(&ES(&]P9V5S;&%G96XN`$AE="!C;VYT86-T($E$(&YU
M;6UE<B!I<R!N:65T(&]P9V5G979E;BP@;&5E9R!G96QA=&5N(&]F(&ES(&YI
M970@9V5V;VYD96X@:6X@9&4@9&%T86)A<V4N`$AE="!A9')E<R!I<R!M970@
M<W5C8V5S(&%A;B!U=R!A9')E<V)O96L@=&]E9V5V;V5G9"X`2&5T(&QO<V=E
M:V]P<&5L9&4@4$=0(&]N9&5R=&5K96YI;F=S8FQO:R!I<R!V97)E:7-T(&]M
M(&AE="!O;F1E<G1E:V5N9&4@8F5R:6-H="!T92!V97)I9FGK<F5N+@!(970@
M9&ES=')U8G5T:65L:6IS="!)1"!I<R!N:65T(&]P9V5G979E;BP@;&5E9R!G
M96QA=&5N(&]F(&ES(&YI970@9V5V;VYD96X@:6X@9&4@9&%T86)A<V4N`$1E
M(&1I<W1R:6)U=&EE;&EJ<W0@:7,@;FEE="!O<&=E9V5V96XN`$1E(&-O9&5E
M<FUO9V5L:6IK:&5D96X@=F5R96ES96X@965N(&)E=F5I;&EG9&4@=V5B=F5R
M8FEN9&EN9RX`1&4@96EN9&1A='5M(&1I96YT(&QA=&5R('1E('II:FX@9&%N
M(&1E('-T87)T9&%T=6TN`$1E(&=E8F5U<G1E;FES;F]T:69I8V%T:64@:7,@
M;65T('-U8V-E<R!V97)Z;VYD96X@;F%A<B`E<RX`2&5T(&)E<W1A;F0@)7,@
M9&EE;G0@965N("5S(&EN<W1E;&QI;F<@=&4@8F5V871T96XN`$AE="!B97-T
M86YD("5S(&1I96YT(&5N:6=E("5S(&EN<W1E;&QI;F=E;B!T92!B979A='1E
M;BX`2&5T(&)E<W1A;F0@:V%N(&YI970@;F%A<B!Z:6-H>F5L9B!G96MO<&EE
M97)D('=O<F1E;BX`2&5T(&)E<W1A;F0@8F5V871T92!G965N(&1A=&$N`$AE
M="!V;VQG96YD92!Z:6IN(&1E(&MO<'!E;B!V86X@9&ET(&UE<W-A9V4O<F9C
M.#(R(&)E<FEC:'0N`$AE="!V;VQG96YD92!I<R!E96X@;65E<B!G961E=&%I
M;&QE97)D92!B97-C:')I:G9I;F<@=F%N(&1E(&=E8F5U<G1E;FES.@!686X@
M9&4@=F]L;&5D:6<@<V-H97)M(&UO9&4@:7,@8F5K96YD+"!D870@9&ET('!R
M;V)L96UE;B!K86X@=F5R;V]R>F%K96X@;65T($EN=&5R;F5T($5X<&QO<F5R
M+"!V86YW96=E(&)R;W=S97)B=6=S('=A87(@=VEJ(&YI970@;VUH965N(&MU
M;FYE;BX@2&5T(&ES(&UO9V5L:6IK(&1A="!U(')O;6UE;"!I;B!H970@8F5E
M;&1S8VAE<FTL(&=E8G)E:R!A86X@961I=&]R9G5N8W1I97,@96XO;V8@<F%N
M9&]M(&)R;W=S97(M(&-R87-H97,@97)V86%R="X@5V%N;F5E<B!U=R!S>7-T
M965M(%=I;F1O=W,@.7@@:7,L(&ES(&AE="!W86%R<V-H:6IN;&EJ:R!D870@
M=2!E96X@)T%L9V5M96YE($)E=F5I;&EG:6YG<R!&;W5T)R!K<FEJ9W0L(&5N
M(&]P;FEE=7<@9&EE;G0@=&4@:&5R<W1A<G1E;BY<;EQN52!B96YT(&=E=V%A
M<G-C:'5W9"X@1')U:R!O<"!/2R!W86YN965R('4@=&]C:"!D92!V;VQL961I
M9R!S8VAE<FT@961I=&]R('=I;'0@<')O8F5R96XN`$1E(&ED96YT:71E:70@
M(B5S(B!I<R!V97)W:6ID97)D+@!!;&QE96X@9&4@;&EN:V5R:V%N=`!$92!P
M;&%A=',@=F%N(&AE="!';G501R!P<F]G<F%M;6$@9&EE;G0@;W!G96=E=F5N
M('1E('=O<F1E;B!I;B!D92!#<GEP=%]P9W`Z.B!C;&%S<RX`2&5T(&)E<FEC
M:'0@=F5R<W1U=7)D(&]P("5S(&%A;B`E<R!M970@;VYD97)W97)P("(E<R(@
M:7,@=V5E<F=E9V5V96XN"D1I="!I<R!G965N(&=A<F%N=&EE(&1A="!H970@
M8F5R:6-H="!I<R!G96QE>F5N(&]F(&)E9W)E<&5N+@!$92!N86%M(&1I92!G
M96)R=6EK="!W;W)D="!B:6H@;&EN:V5N(&YA87(@9&4@;FEE=7<@8F5R:6-H
M="!P86=I;F$`1&4@;W!E;G-S;"!M;V1U;&4@:7,@=F5R96ES="!V;V]R(&1E
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`$1E('9O;W)K975R<VEN<W1E
M;&QI;F<@(B5S(B!K;VX@;FEE="!W;W)D96X@;W!G97-L86=E;BP@;VUD870@
M9&4@9&%T82!D92!M87AI;75M('1O96QA871B87)E(&=R;V]T=&4@;W9E<G-C
M:')I:F1T+@!(970@<')O9W)A;6UA(&]M(&1I="!D871A='EP92`H)7,I('1E
M(&)E:VEJ:V5N+"!W97)D(&YI970@;W`@:&5T('-Y<W1E96T@9V5V;VYD96XN
M`$%L;&5E;B!D92!R96-H=&5R+2!E;B!L:6YK97)K86YT`$%L;&5E;B!D92!R
M96-H=&5R:V%N=`!$92!S97)V97(@(B5S(B!I<R!V97)W:6ID97)D+@!$92!S
M97)V97(@(B5S(B!I<R!O<&=E<VQA9V5N+@!(970@86%N;65L9&EN9W-V97)Z
M;V5K('9O;W(@)7,@:7,@=F5R=VEJ9&5R9"X`1&4@;W!G96=E=F5N(')I:B!B
M97-T86%T(&YI970N`$%L;&5E;B!D92!B;W9E;BT@96X@;VYD97)K86YT`$%L
M;&5E;B!D92!B;W9E;FMA;G0`1&4@=7!L;V%D960@9&%T82!I<R!N82!D92!V
M;V]R9V%A;F1E('-T87`@=F5R;&]R96X@9V5G86%N+@!(970@=7!L;V%D960@
M8F5S=&%N9"!I<R!N:65T(&]P9V5S;&%G96XN`$AE="!W96%T:&5R+F-O;2!B
M;&]K(&ES(&YI970@8F5S8VAI:V)A87(N`$5R('II:FX@9V5B975R=&5N:7-S
M96X@9&EE(&]V97)E96YK;VUE;B!M970@9&4@:'5I9&EG92!C<FET97)I82X`
M1V5E;B!O<'1I97,@8F5S8VAI:V)A87(N`$5R('II:FX@9V5E;B!O;F1E<F1E
M;&5N+"!W96QK92!I;FQI;F4@=V5E<F=E9V5V96X@:W5N;F5N('=O<F1E;BX`
M17(@>FEJ;B!T92!V965L(&MA<F%K=&5R<R!I;B!D:70@=F5L9"X@52!H965F
M="`E<R!K87)A:W1E<G,@;W!G96=E=F5N.R!U(&1I96YT(&UI;F1E<B!D86X@
M)7,@;W`@=&4@9V5V96XN`$5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U
M<&QO860Z($=E96X@)7,@=V5R9"!G975P;&]A9"X`165N('!R;V)L965M(&UE
M="!D92!B97-T86YD<W5P;&]A9#H@2&5T("5S(&ES(&=R;W1E<B!D86X@9&4@
M;6%X:6UU;2!T;V5L86%T8F%R92!G<F]O='1E("@E9"!B>71E<RDN`$5E;B!P
M<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($AE="`E<R!I<R!S;&5C
M:'1S(&=E9&5E;'1E;&EJ:R!G975P;&]A9"X`165N(&9O=70@8FEJ(&1E('1O
M96=A;F<@=F%N(&1E(&%G96YD83H@)7,`165N(&9O=70@8FEJ(&AE="!T;V5V
M;V5G96X@=F%N(&1E(&=E8F5U<G1E;FES.B`E<P!%96X@9F]U="!B:6H@:&5T
M(&)E:VEJ:V5N('9A;B!D:70@8F5R:6-H=&]N9&5R9&5E;`!%96X@9F]U="!B
M:6H@:&5T(&)E=V5R:V5N('9A;B!D92!G96)E=7)T96YI<SH@)7,`165N(&9O
M=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D92!A9')E<V1A=&$N`$5E;B!F
M;W5T(&)I:B!H970@:6UP;W)T97)E;B!V86X@9&4@:4-A;&5N9&%R9&%T82X`
M165N(&9O=70@:6X@:&5T(&-O;F9I9W5R871I969O<FUU;&EE<BX@36ES<V-H
M:65N(&)E;G0@=2!E96X@=F5R<&QI8VAT('9E;&0@=F5R9V5T96XN`$5E;B!F
M;W5T(&)I:B!H970@=F5R<&QA871S96X@=F%N(&1E(&=E8F5U<G1E;FES.B`E
M<P!%96X@9F]U="!B:6H@:&5T('5I='9O97)E;B!V86X@9&4@;W!G96=E=F5N
M(&%D<F5S8F]E:V9U;F-T:64N(%!R;V)E97(@;&%T97(@;W!N:65U=RP@82YU
M+F(N`$5E;B!F;W5T(&)I:B!H970@=F5R>F5N9&5N('9A;B!E96X@9V5B975R
M=&5N:7-N;W1I9FEC871I92!N86%R("5S.B`E<P!%96X@9F]U="!M970@:&5T
M(&)I:G=E<FME;B!V86X@9&4@861R97-D971A:6QS+B!0<F]B965R(&QA=&5R
M(&]P;FEE=7<L(&$N=2YB+@!%96X@9F]U="!M970@:&5T(&)I:G=E<FME;B!V
M86X@9&4@9&ES=')I8G5T:65L:6IS="X@4')O8F5E<B!L871E<B!O<&YI975W
M+"!A+G4N8BX`17(@>FEJ;B!G965N(&=E8F5U<G1E;FES<V5N('1E(&5X<&]R
M=&5R96XN`$1E>F4@24U!4"!S97)V97(@;VYD97)S=&5U;G0@9V5E;B!D96QI
M;F<@=F%N(&UA<'!E;BX`1&ET(&QI:FMT(&YI970@965N(&=E;&1I9R!R87(@
M8F5S=&%N9"!T92!Z:6IN+@!$:70@;&EJ:W0@;FEE="!E96X@9V5L9&EG('II
M<"!B97-T86YD('1E('II:FXN`$1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@
M:V%A<G1N=6UM97(@=&4@>FEJ;BX`1&ET('-T=75R<')O9W)A;6UA(&=E969T
M(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD
M96XL(&0N;2YV+B!D92!(5%10($%020!$:70@<W1U=7)P<F]G<F%M;6$@9V5E
M9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD
M96XL(&0N;2YV+B!D92!(5%10($%020!$:70@<W1U=7)P<F]G<F%M;6$@9V5E
M9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@4TU44"!D+FTN
M=BX@9&4@5F]D869O;F4@271A;'D@9V%T97=A>2!T92!V97)Z96YD96X@;F%A
M<B!6;V1A9F]N92!N=6UM97)S+B!(:65R=F]O<B!I<R!E96X@5F]D869O;F4@
M271A;'D@92UM86EL861R97,@*&AT='`Z+R]W=W<N,3DP+FET*2!N;V]D>F%K
M96QI:FLN`$1I="!V96QD(&ES('9E<F5I<W0`1&ET('9E;&0@;6%G(&%L;&5E
M;B!I;G1E9V5R<R!B979A='1E;BX`1&ET('9E;&0@;6%G(&%L;&5E;B!G971A
M;&QE;B!E;B!D92!D=6)B96QE('!U;G0@8F5V871T96XN`$1I="!V96QD(&UA
M9R!A;&QE96X@;V-T86%L('=A87)D96X@8F5V871T96XN`$1I="!V96QD(&1I
M96YT(&5E;B!K;VUM82!O9B!S<&%T:64@9V5S8VAE:61E;B!L:6IS="!M970@
M:6YT96=E<G,@=&4@>FEJ;@!$97IE('=A87)D92!D:65N="!E96X@9V5L9&EG
M(&=E=&%L('1E('II:FXN`$1I="!V96QD(&1I96YT(&5E;B!K;&5U<F-O9&4@
M:6X@4D="($A%6"UF;W)M86%T('1E(&)E=F%T=&5N+"!B+G8N("<C,3(S-&%F
M)RX`1&ET(&)E<W1A;F1S9F]R;6%A="!W;W)D="!N:65T(&]N9&5R<W1E=6YD
M+@!$:70@9F]R;75L:65R(&ES(')E961S('9E<G=E<FMT+@!$:70@:7,@)7,N
M`$1I="!I<R!E96X@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@3VT@9&ET(&]B
M:F5C="!W965R('1E(&=E=F5N(&AE969T('4@965N(&4M;6%I;"!C;&EE;G0@
M;F]D:6<@9&EE(&AE="!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A="!B96=R:6IP
M="X@5F]O<B!E96X@;&EJ<W0@;65T(&1E>F4@92UM86EL8VQI96YT<RP@8F5Z
M;V5K("5S+"!A+G4N8BX`1&ET(&ES('=A="!D92!S97)V97(@;65L9'0Z("5S
M`$1I="!B97)I8VAT(&ES(&EN(&5E;B!A;F1E<F4@:V%R86MT97)S970@*"5S
M*2!G97-C:')E=F5N+"!D86X@=7<@96EG96XN`$1I="!G971A;"!D:65N="!T
M96YM:6YS=&4@Z>EN('1E('II:FXN`$1E>F4@<V5R=F5R(&MA;B!G965N('II
M<"!E;B!G>FEP(&)E<W1A;F1E;B!U:71P86MK96XN`$AE="!S>7-T965M(&ES
M(&UO;65N=&5E;"!U:71G97-C:&%K96QD+@!$97IE('=A87)D92!D:65N="!E
M96X@9V5T86P@=&4@>FEJ;BX`1&ET('-C:&5R;2!D:65N="!A86YG97)O97!E
M;B!T92!W;W)D96X@=F%N=6ET(&5E;B!/<'1I97-S8VAE<FT`3VYW965R`$1O
M;F1E<F1A9P!4:6-K971S`%1I:F0`5&EJ9'-D7W5U<@!4:6ID<&QA;FYI;F<`
M5&EJ9&9O<FUA870`5&EJ9'-E;&5C=&EE`%1I:F1S9'5U<@!4:6UO<BU,97-T
M90!?5&ET96P`5&ET96P`5&ET96P@*'1O;VQT:7`I.@!!86X`3VT@;65E<F1E
M<F4@;VYD97)D96QE;B!T92!S96QE8W1E<F5N+"!H;W5D(&1E($-O;G1R;VP@
M*%!#*2!O9B!#;VUM86YD("A-86,I('1O971S('9A<W0@=&EJ9&5N<R!K;&EK
M:V5N+@!686YD86%G`$A434P@8G)O;B!O;7-C:&%K96QE;@!4;V=O`%1O:V5L
M874`36]R9V5N`%1O;F=A`$)O=F5N:V%N=`!";W9E;G-T92!F<F%M92`H7W1O
M<"D`5F5R=&%L:6YG96X`5')I;FED860@96X@5&]B86=O`%1R=64@;V8@9F%L
M<V4`1&D`1&EN<V1A9P!4=6YE<VGK`%1U<FMI:F4`5'5R:W,@*$E33RTX.#4Y
M+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!E;B!#86EC;W,@96EL86YD96X`5'5V
M86QU`%1Y<&4`5'EP('5W(&ME=7IE.B``52Y6+B!I;F1E>#H@`%523"!V;V]R
M('5W(&%F;&5V97)I;F=S<W1A='5S<F%P<&]R="!S8W)I<'0`55),.@!/96=A
M;F1A`$]E:W)A[VYE`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!A86X@
M=&4@<W!R96ME;BX`3FEE="!I;B!S=&%A="!E>'1R82!G96)R=6EK97)S:6YF
M;W)M871I92!T;V4@=&4@=F]E9V5N(&)I:B!I;G-C:')I:G9E;BX`3FEE="!I
M;B!S=&%A="!D92!R96-H=&5N('9A;B!61E,@8F5S=&%N9"`B)7,B('1E('=I
M:GII9V5N+@!.:65T(&EN('-T86%T(&1E(')E8VAT96X@=F%N(%9&4R!B97-T
M86YD("5S+R5S('1E('=I:GII9V5N+@!.:65T(&EN('-T86%T('1E('=I:GII
M9V5N(&YA87(@)7,N`$YI970@:6X@<W1A870@;65T(&1E(%-13"!S97)V97(@
M=&4@=F5R8FEN9&5N+@!.:65T(&EN('-T86%T(&UE="!34TP@=&4@=F5R8FEN
M9&5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&MO<&GK<F5N+@!.
M:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@(B5S(B!T92!M86ME;BX`3FEE
M="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E(&UA:V5N+@!.:65T(&EN('-T
M86%T(%9&4R!B97-T86YD('1E(&UA:V5N+@!.:65T(&EN('-T86%T(&5E;B!L
M965G(%9&4R!B97-T86YD('1E(&UA:V5N+@!.:65T(&EN('-T86%T(&1A=&$@
M=6ET('1E('!A:VME;BX`3FEE="!I;B!S=&%A="`B)7,B('1E('9E<G=I:F1E
M<F5N+"!D92!D:7)E8W1O<GD@:7,@;FEE="!L965G`$YI970@:6X@<W1A870@
M;VT@(B5S(CH@)7,@=&4@=F5R=VEJ9&5R96X`3FEE="!I;B!S=&%A="`E<R!T
M92!V97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y(&ES(&YI970@;&5E9P!.:65T
M(&EN('-T86%T(&]M("5S('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:65F('1E('9E<G=I:F1E<F5N+@!.:65T
M(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@=F5R=VEJ9&5R96XN`$YI970@
M:6X@<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!V97)W:6ID97)E;BX`3FEE
M="!I;B!S=&%A="!61E,@8F5S=&%N9"`B)7,B('1E('9E<G=I:F1E<F5N+@!.
M:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E('9E<G=I:F1E<F5N+@!.:65T
M(&EN('-T86%T(%9&4R`E<R!R96-U<G-I968@=&4@=F5R=VEJ9&5R96XN`$YI
M970@:6X@<W1A870@:'5I9&EG92!D:7)E8W1O<GD@=&4@8F5P86QE;BX`3FEE
M="!I;B!S=&%A="!C97)T:69I8V%A=&1E=&%I;',@=6ET('1E(&9I;'1E<F5N
M`$YI970@:6X@<W1A870@;VT@9&4@9&5F:6YI=&EE('9A;B`E<R!T92!L861E
M;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!V97)P;&%A='-E;BX`
M3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"`B)7,B('1E(&]P96YE;BX`3FEE
M="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!O<&5N96X@=F]O<B!S8VAR:6IV
M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;W!E;F5N+@!.:65T
M(&EN('-T86%T(&AE="!I;F=E<&%K=&4@8F5S=&%N9"!T92!O<&5N96XN`$YI
M970@:6X@<W1A870@=F9S<F]O="!D:7)E8W1O<GD@=&4@;W!E;F5N+@!.:65T
M(&EN('-T86%T("(E<R(@=&4@:&5R;F]E;65N.B`E<P!.:65T(&EN('-T86%T
M(&]M("5S('1E(&AE<FYO96UE;B!N86%R("5S.B!B97-T96UM:6YG<VUA<"!B
M97-T86%T(&%L`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!H97)N
M;V5M96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!H97)N
M;V5M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!H97)N
M;V5M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@)7,O)7,@=&4@:&5R
M;F]E;65N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&AE<FYO96UE
M;BX`3FEE="!I;B!S=&%A="!V<FEJ+V)E>F5T(&EN9F]R;6%T:64@;W`@=&4@
M:&%L96X@=F]O<B`E<P!+86X@)VUK:7-O9G,G(&YI970@=6ET=F]E<F5N+@!.
M:65T(&EN('-T86%T(&1I="!7;W)D(&1O8W5M96YT('1E('9E<G1A;&5N`$YI
M970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!S8VAR:6IV96XN`$YI
M970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@<V-H<FEJ=F5N("AC;W!Y*"D@
M9F%I;&5D*2X`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9'-D871A('1E('-C
M:')I:G9E;BX`3VYD97)S=')E<&5N`$AE<G-T96P@=VEJ>FEG:6YG96X`1&]E
M="!U=R!L86%T<W1E(&)E=V5R:VEN9R!T96YI970`3VYV97)W86-H="!A;G1W
M;V]R9"!V86X@9&4@<V5R=F5R(&]P('9E<F)I;F1I;F<Z(`!/;G9E<G=A8VAT
M(&%N='=O;W)D('9A;B!S97)V97(@86%N.B``3VYB96YO96UD`%5N:6-O9&4@
M*%541BTX*0!697)E;FEG9&4@07)A8FES8VAE($5M:7)A=&5N`%9E<F5N:6=D
M($MO;FEN9VMR:6IK`%9E<F5N:6=D92!3=&%T96X`5F5R96YI9V1E(%-T871E
M;BP@:VQE:6YE(&)U:71E;B!L:6=G96YD92!E:6QA;F1E;@!%96YH961E;@!/
M;F)E:V5N9`!/;F)E:V5N9"!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!/
M;F)E:V5N9"!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!/;F)E:V5N
M9&4@9V5B<G5I:V5R<VYA86T@;V8@=V%C:'1W;V]R9"X`2&5T(&AU:61I9V4@
M96QE;65N="!L;W-K;W!P96QE;@!/;F)E;F]E;60`3FEE="!G97)E8VAT:6=D
M92!S8W)I<'1S(&MU;FYE;B!P<F]G<F%M;6%M871I9R!N:65T($MN:7!P96XO
M2V]P:>MR96XO4&QA:VME;BP@=F%N=V5G92!B979E:6QI9VEN9W-R961E;F5N
M+B!+;&EK(&]P($]+(&]M(&5E;B!T96-H;FES8VAE(&]P;65R:VEN9R!O<"!M
M;WII;&QA+F]R9R!T92!B96MI:FME;B!H;V4@=2!E96X@<V-R:7!T('1O97-T
M86%T(&AE="!P<FEK8F]R9"!T92!B96YA9&5R96XN`$ML975R('1E<G5G<W1E
M;&QE;@!.:65T(&]N9&5R<W1E=6YD92!E>'1E;G1I90!":6IW97)K96X`)7,@
M8FEJ=V5R:V5N`$=E8G)U:6ME<B!B:6IW97)K96XN`"5S(&)I:F=E=V5R:W0N
M`%5P9W)A9&4@<V-R:7!T('9E<G=I:F1E<F0N`%5P;&]A9`!!;&QE('1O97!A
M<W-I;F<@<V5T=7!B97-T86YD96X@;F%A<B!D92!S97)V97(@9V5U<&QO860N
M`$QA=&EJ;G-E(&AO;V9D;&5T=&5R<P!'<F]T92!2;VUE:6YS92!G971A;&QE
M;@!5<G5G=6%Y`$=E8G)U:6L@:'5I9&EG93H@)7,`1V5B<G5I:R!34TP`1V5B
M<G5I:V5N('=A;FYE97(@;F%A;2]W86-H='=O;W)D('9E<G-C:&EL="!M970@
M24U34"!S97)V97(N`$=E8G)U:6ME<B`E<R!I<R!N:65T(&=E875T;W)I<V5E
M<F0@=F]O<B`E<RX`1V5B<G5I:V5R<V)E:&5E<@!'96)R=6EK97)S:6YT97)F
M86-E`$=E8G)U:6ME<G-O<'1I97,`1V5B<G5I:V5R<W)E9VES=')A=&EE`$=E
M8G)U:6ME<G-R96=I<W1R871I92!I<R!U:71G97-C:&%K96QD(&]P(&1E>F4@
M<VET92X`1V5B<G5I:V5R<VYA86T`1V5B<G5I:V5R<VYA86TZ`$=E8G)U:6ME
M<G-N86%M.B``1V5B<G5I:V5R<R!I;B!H970@<WES=&5E;3H`3V5Z8F5K:7-T
M86X`5D93(&1I<F5C=&]R>2!B97-T86%T(&YI970N`$%F=V5Z:6=H96ED`$=E
M=F]N9&5N(&=E;&1I9V4@;&]C871I97,@8F5V871T96XZ(`!'96QD:6=H96ED
M`%=A87)D92!I;B!M:6YU=&5N('9A;F%F(&YU+@!786%R9&5N`%=A87)D96X@
M=V%A<G5I="!G97-E;&5C=&5E<F0@:V%N('=O<F1E;@!686YU871U`%9A<FEA
M8F5L90!696YE>G5E;&$`5F5R:69I8V%T:64@;6ES;'5K="`M(&5R(&MA;B!M
M970@9&ET(&)E<FEC:'0@9V5K;F]E:60@>FEJ;BX`5F5R<VEE`%9E<G-I96-O
M;G1R;VQE`%9E<G1I:V%A;"!U:71L:6IN96X`5F5R=&EK86QE('9R:6IE(')U
M:6UT90!697)T:6MA86PZ`$5R9R!H;V]G`%9I971N86T`5FEE=&YA;65E<R`H
M5DE30TE)*0`E<R!B96MI:FME;@!$86<@=V5E<F=E=F5N`$)E:VEJ:R!E96X@
M97AT97)N92!W96)P86=I;F$`0F5K:6IK96X@86QS("5S`$UA86=D96X@96EL
M86YD96XL($)R:71S90!-86%G9&5N(&5I;&%N9&5N+"!6+E,N`%II8VAT`%II
M8VAT.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!704%24T-(55=)
M3D<A(2$@(%9%4E=)2D1%4B!30U))4%0@2$%.1$U!5$E'(%5)5"`E<RX`5V%L
M;&ES(&5N($9U='5N80!786%R<V-H=7=I;F<`5V\`5V5E<G-V;V]R=6ET>FEC
M:'0`5V5E<F)E<FEC:'0@9V5G979E;G,@9V5L979E<F0@9&]O<@!796%T:&5R
M+F-O;0!796(`5V5B<VET90!7;V5N<V1A9P!7965K`%=E96L@)60`5V5K96X`
M5V5K96QI:FMS`%=E:V5L:6IK<SH@:&5R:&%A;'0@>FEC:"!E;&ME`%=E;&MO
M;0!796QK;VT@8FEJ("5S`%=E;&MO;2P@)7,`5V5S=&5R<R`H25-/+3@X-3DM
M,2D`5V5S=&5R<R`H25-/+3@X-3DM,34I`%=E<W1E;&EJ:V4@4V%H87)A`%=E
M;&ME('1O97!A<W-I;F<@9&EE;G0@)7,@=V5E<B!T92!G979E;B!N82!A86YM
M96QD:6YG/P!7870@:7,@:&5T('-C:&5I9&EN9W-K87)A:W1E<C\`5V%T(&ES
M(&AE="!C:71A871K87)A:W1E<C\`5V5L:V4@=&EJ9"!D:65N96X@9&%G+2!E
M;B!W965K=V5E<F=A=F5N('1E(&5I;F1I9V5N+"!W86YN965R(&5R(&=E96X@
M;&%T97)E(&=E8F5U<G1E;FES<V5N('II:FX_`%=E;&ME('1I:F0@9&EE;F5N
M(&1A9RT@96X@=V5E:W=E97)G879E;B!T92!B96=I;FYE;BP@=V%N;F5E<B!E
M<B!G965N(&5E<F1E<F4@9V5B975R=&5N:7-S96X@>FEJ;C\`5V5L:V4@9F%S
M96X`5V5L:V4@<&QU9VEN<R!V;V]R(&1E(%)I8V@@5&5X="!E9&ET;W(@:6YS
M8VAA:V5L96XN`$)R965D=&4`0G)E961T92!I;B!#4U,@965N:&5D96X`0G)E
M961T92!V86X@:&5T("5S(&UE;G4@86%N(&1E(&QI;FME<FMA;G0@*&%K=&EE
M9B!B:6H@=F]L9V5N9&4@86%N;65L9&EN9RDZ`$)R965D=&4@=F%N(&1E('1A
M8F5L`$)R965D=&4@965N:&5I9`!"<F5E9'1E.@!7:6MI`%=I;F0`5VEN9'-N
M96QH96ED(&EN(&MN;W!E;@!7:6YD.@!7:6YD.B``5VEJ<VAE:60`5V5R:P!7
M97)K861R97,`5&5L+FYR+B`H=V5R:RD`5V5R:W=E96L`6"U2968`6#4P.78S
M(&)A<VES8F5P97)K:6YG96X`6#4P.78S('5I=&=E8G)E:60@<VQE=71E;&=E
M8G)U:6L`6#4P.78S(&%L=&5R;F%T:65V92!O;F1E<G=E<G!N86%M`%@U,#EV
M,R!O;F1E<G=E<G`@<VQE=71E;&ED96YT:69I8V%T;W(`6#4P.78S(&5X=&5N
M=&EE<P!*2@!*2DI*`%EA:&]O(2!M87``2F%A<FQI:FMS`$IA87)L:6IK<SH@
M:&5R:&%A;'0@>FEC:"!E;&ME`$IE;65N`$IA`$IA+"!I:R!A8V-E<'1E97(@
M9&4@=F]O<G=A87)D96X`52!B96YT(&EN(%1%2U-4($U/1$4N($=E8G)U:6L@
M9&4@6SP^72!K;F]P(&]M(&YA87(@5UE325=91R!T97)U9R!T92!S8VAA:V5L
M96XN`%4@8F5N="!N:65T(&=E875T:&5N=&EF:6-E97)D+@!5(&MU;G0@9V5E
M;B`G7"<@:V%R86MT97(@:6X@=7<@=F]L;&5G92!N86%M(&AE8F)E;BX`52!K
M=6YT(&1I="!F;W)M=6QI97(@86QL965N(&=E8G)U:6ME;B!V86YU:70@:&5T
M($%A;G=E>FEG96X@8F5W97)K96X@<V-H97)M+@!5(&AE969T(&=E96X@9V5L
M9&EG(&4M;6%I;&%D<F5S(&]P9V5G979E;BX`52!H965F="!G965N('9E;&1E
M;B!U:70@:&5T(&=E:6UP;W)T965R9&4@8F5S=&%N9"!G96MO<'!E;&0@;65T
M(&1E(&]V97)E96YK;VUS=&EG92!V96QD96X@:6X@)7,N`%4@:&5E9G0@9V5E
M;B!R96-H="!O;2!G96)E=7)T96YI<W-E;B!A86X@)7,@=&]E('1E('9O96=E
M;BX`52!H965F="!G965N(')E8VAT(&]M(&=E8F5U<G1E;FES<V5N(&%A;B!D
M92!G97-E;&5C=&5E<F1E(&%G96YD82!T;V4@=&4@=F]E9V5N+@!5(&AE969T
M(&=E96X@<F5C:'0@;VT@9&5Z92!G96)E=7)T96YI<R!T92!V97)W:6ID97)E
M;BX`52!H965F="!G965N(')E8VAT(&]M(&1E>F4@9V5B975R=&5N:7,@=&4@
M8F5W97)K96XN`%4@8F5N="!A9F=E;65L9"X`52!H965F="!E96X@;VYG96QD
M:6=E(&%G96YD82!O<&=E9V5V96XN`%4@9&EE;G0@965N(&=E;&1I9R!M;V)I
M96P@;G5M;65R(&EN('1E('9O97)E;BP@86QL965N(&-I:F9E<G,@;65T(&5E
M;B!O<'1I;VYE;&4@)RLG('9O;W(@:&5T(&EN=&5R;F%T:6]N86QE(&MI97-V
M;V]R=F]E9W-E;"X`52!D:65N="!E96X@9V5L9&EG92!W86%R9&4@;W`@=&4@
M9V5V96XN`%4@9&EE;G0@965N($1A=&%4<F5E(&)A8VME;F0@=&4@8V]N9FEG
M=7)E<F5N(&]M(&EN<V-H<FEJ=FEN9V5N('1E(&MU;FYE;B!G96)R=6EK96XN
M`%4@9&EE;G0@:&5T('!R;V)L965M('1E(&)E<V-H<FEJ=F5N+"!V;V]R9&%T
M('4@:&5T('!R;V)L965M<F%P<&]R="!K=6YT('9E<GIE;F1E;BX`52!D:65N
M="!E96X@55),(&EN('1E('9O97)E;B!W86%R;F%A<B!D97IE(&QI;FL@=F5R
M=VEJ<W0`52!D:65N="!E96X@86=E;F1A('1E('-E;&5C=&5R96X@;VT@=&4@
M=F5R=VEJ9&5R96XN`%4@9&EE;G0@965R<W0@965N(&%D<F5S('1E('-E;&5C
M=&5R96XN`%4@9&EE;G0@965N('-E<G9E<B!T92!S96QE8W1E<F5N(&]M('1E
M('9E<G=I:F1E<F5N+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T
M92!G979E;B!O;2!T92!W:7-S96XN`%4@9&EE;G0@965N(&=E8G)U:6ME<G-N
M86%M(&]P('1E(&=E=F5N(&]M('1E('9E<G=I:F1E<F5N+@!5(&1I96YT(&5E
M;B!G96)R=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!T;V4@=&4@=F]E9V5N
M+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!B
M:6H@=&4@:W5N;F5N('=E<FME;BX`52!D:65N="!E96X@8F5W97)K:6YG(&]P
M('1E(&=E=F5N('=E;&ME('5I=&=E=F]E<F0@;6]E="!W;W)D96XN`%4@9&EE
M;G0@965N(&YI975W92!C871E9V]R:65N86%M(&]P('1E(&=E=F5N+@!5=R`E
M<R!S97-S:64@:7,@=F5R;&]P96XN($]P;FEE=7<@86%N;65L9&5N+"!A+G4N
M8BX`57<@92UM86EL861R97,`57<@5F%N.B!A9')E<SH`57<@:6YF;W)M871I
M90!5=R!I;G1E<FYE=&%D<F5S(&ES(&=E=VEJ>FEG9"!S:6YD<R!H970@8F5G
M:6X@=F%N('5W("5S('-E<W-I92X@3VT@=7<@=F5I;&EG:&5I9"!T92!B97-C
M:&5R;65N+"!D:65N="!U('II8V@@;W!N:65U=R!A86X@=&4@;65L9&5N+@!5
M=R!N86%M.@!(970@=V5E<F=E=F5N('9A;B!E96X@9V5B<G5I:V5R<VQI:G-T
M('=O<F1T(&YI970@;VYD97)S=&5U;F0@9&]O<B!U=R!A=71H96YT:6-A=&EE
M(&)A8VME;F0L(&]F(&1E>F4@;W!T:64@:7,@;VT@86YD97)E(')E9&5N96X@
M=6ET9V5S8VAA:V5L9"X`57<@8G)O=W-E<B!L:6IK="!T92!Z:6IN(&=E=VEJ
M>FEG9"!S:6YD<R!H970@8F5G:6X@=F%N('5W("5S('-E<W-I92X@3VT@=7<@
M=F5I;&EG:&5I9"!T92!B97-C:&5R;65N+"!D:65N="!U('II8V@@;W!N:65U
M=R!A86X@=&4@;65L9&5N+@!5=R!B<F]W<V5R(&]N9&5R<W1E=6YT(&1E>F4@
M;6]G96QI:FMH96ED(&YI970N`%5W(&AU:61I9V4@=&EJ9'IO;F4Z`%5W('-T
M86YD86%R9"!A9V5N9&$`57<@<W1A;F1A87)D(&ED96YT:71E:70Z`%5W('9O
M;&QE9&EG92!N86%M.@!5=R!N:65U=V4@=V%C:'1W;V]R9"!V;V]R("5S(&ES
M.B`E<P!5=R!O<'1I97,@>FEJ;B!B:6IG97=E<FMT+@!5=R!W86-H='=O;W)D
M(&ES(&=E<F5S970`57<@=V%C:'1W;V]R9"!I<R!V97)N:65U=V0L(&-O;G1R
M;VQE97(@=7<@92UM86EL(&5N(&UE;&0@86%N(&UE="!U=R!N:65U=V4@=V%C
M:'1W;V]R9"X`57<@<V5R=F5R<R!O<"!A9G-T86YD.@!*;V5G;W-L879IZP!:
M8>]R90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6U9E<F)E<F<@86%N9V5H86%L
M9&4@=&5K<W1=`%M0<F]B;&5E;7)A<'!O<G1=`%M!86YG96AA86QD92!T96MS
M="!W965R9V5V96X@+0!;06%N9V5H86%L9&4@=&5K<W0@+2`E<R!R96=E;'-=
M`%M/;F)E;F]E;61E(&=E8F5U<G1E;FES70!;<F5G96P@)7,@=F%N("5S70!"
M7V5H965R`$5E;E]V;W5D:6<@>F]E:V5N`%]#3$D`7T1A=&%4<F5E`%9E<E]W
M:6ID97(@<FEJ`%]"97=E<FME;@!'82!?;F%A<@!?1W)O97!E;@!?2&5L<`!?
M069B965L9&EN9W-E:6=E;G-C:&%P<&5N+BXN`%]);7!O<G0O17AP;W)T`%]!
M86YM96QD96X`7T%F;65L9&5N`%]7:6IZ:6<@;&EN:RXN+@!?36EJ;B!A9V5N
M9&$G<P!.:65U7W=E(&=E8F5U<G1E;FES`%]/<'1I97,`7U)E8VAT96X`05]F
M9')U:VME;@!?5F5R=VEJ9&5R(&QI;FLN+BX`7UIO96ME;@!?26YS=&5L;&5N
M`%]486)E;&5I9V5N<V-H87!P96XN+BX`7U9A;F1A86<`1V5?8G)U:6ME<G,`
M061R97-B;V5K`'9O;W(@9&4@9V5B975R=&5N:7,@8F5G:6YT`$MA;&5N9&5R
M`$MA;&T`2VQI:R!H:65R`&1A9P!D86<H96XI`&1A9V5N`&5V96YT<RYC<W8`
M979E;G1S+FEC<P!D86QE;F0`8F5S=&%N9`!V86X`=F%N(&1E("5S("@E<RD@
M;W`@)7,@)7,`:#H`;VYM:61D96QI:FL`:6YL:6YE`')E9V5L<UT`;6MI<V]F
M<R!F;W5T8V]D92`E9"!B:6H@:&5T(&%A;FUA:V5N('9A;B!)4T\N`&UA86YD
M*&5N*0!N86%M`&YI970@=F%N('1O97!A<W-I;F<`3F]G(&YI970@=F%N('1O
M97!A<W-I;F<`;F]T:71I96)O96L`3W`@9&5Z96QF9&4@9&%T=6T`3W`@9&5Z
M96QF9&4@=V5E:V1A9P!P<F]C96YT`'!I>&5L<P!S=&EJ9V5N9`!T;V]N('9E
M<G-C:&EL;&5N`'-M<S)E;6%I;"!V:6$@2%144`!S=&%B:65L`'1A:V5N;&EJ
M<W0`5F]E<BP@=&5R(&)E=F5S=&EG:6YG+"!H970@=V%C:'1W;V]R9"!T=V5E
M(&UA86P@:6X`=6YI9FEE9`!O;F)E;F]E;60`1V5B<G5I:V5R<V5L96-T:64`
M=D-A;&5N9&%R+VE#86QE;F1A<@!V0V%R9`!V179E;G0@;FEE="!G979O;F1E
M;BX`=SH`=V5A=&AE<BYC;VT`=V5E:P!W965K(&]P.@!W96ME;@!J86%R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI
M=&@O;&]C86QE+VYN7TY/+P``````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4R`#`R,#<P,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O;FY?3D\O3$-?34534T%'15,O
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3(`,#(R
M-#8W`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]N
M;E].3R],0U]-15-304=%4R]K<F]N;VQI=&@N;6\`````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-C4U
M,P`Q,#0Q-S,V,C<U,@`P,C4P-#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````WA($E0`````,`0``'````'P(``!G`0``W!``
M``````!X%@``"P```'D6```H````A18``!4```"N%@``'0```,06```(````
MXA8```4```#K%@``"0```/$6```/````^Q8```\````+%P``"````!L7```(
M````)!<``!D````M%P``!P```$<7```.````3Q<```4```!>%P``"@```&07
M```4````;Q<```H```"$%P``!0```(\7```#````E1<```<```"9%P``#0``
M`*$7```*````KQ<``!\```"Z%P``!0```-H7```Y````X!<```(````:&```
M)P```!T8```L````11@``"H```!R&```!@```)T8```1````I!@```@```"V
M&```!@```+\8```5````QA@```@```#<&```"@```.48```1````\!@```P`
M```"&0``!P````\9```0````%QD``!L````H&0``*P```$09```>````<!D`
M`!L```"/&0``&P```*L9```S````QQD``"\```#[&0``*0```"L:```2````
M51H```<```!H&@```@```'`:```%````<QH``!,```!Y&@```P```(T:```&
M````D1H```@```"8&@``$````*$:```&````LAH```D```"Y&@``#````,,:
M``!<````T!H``!0````M&P``"P```$(;```O````3AL```\```!^&P``)@``
M`(X;```'````M1L```@```"]&P``!````,8;```'````RQL```4```#3&P``
M#0```-D;```(````YQL```8```#P&P``"````/<;```%`````!P``!`````&
M'```$````!<<```/````*!P```L````X'```#P```$0<```,````5!P```\`
M``!A'```!@```'$<```/````>!P``!X```"('```(0```*<<```#````R1P`
M``@```#-'```#````-8<```"````XQP```8```#F'```!@```.T<```$````
M]!P``!0```#Y'```!@````X=```$````%1T```P````:'0``"@```"<=```%
M````,AT```<````X'0``%@```$`=```2````5QT``!````!J'0``!P```'L=
M```$````@QT```0```"('0``"````(T=```(````EAT```D```"?'0``'@``
M`*D=```0````R!T``!H```#9'0``"````/0=```&````_1T```<````$'@``
M`@````P>```E````#QX```0````U'@``!0```#H>```/````0!X```,```!0
M'@``!P```%0>```'````7!X```<```!D'@``"0```&P>```)````=AX```(`
M``"`'@``!@```(,>```%````BAX```<```"0'@``%0```)@>```2````KAX`
M``<```#!'@``!0```,D>```)````SQX```H```#9'@``"````.0>```)````
M[1X``#,```#W'@``"P```"L?```:````-Q\```0```!2'P``!0```%<?```(
M````71\```<```!F'P``!P```&X?```1````=A\```@```"('P``%0```)$?
M```'````IQ\``!X```"O'P``*````,X?```>````]Q\``!H````6(```!0``
M`#$@```H````-R```"D```!@(```#````(H@```3````ER```#(```"K(```
M!````-X@```+````XR````\```#O(```$P```/\@```3````$R$```\````G
M(0``#````#<A```.````1"$```T```!3(0``#0```&$A```&````;R$```L`
M``!V(0``!0```((A```1````B"$``!$```":(0``!````*PA```"````L2$`
M``@```"T(0``"P```+TA```*````R2$```P```#4(0``6````.$A```:````
M.B(``!<```!5(@``&@```&TB```9````B"(``!<```"B(@``'0```+HB```;
M````V"(``!D```#T(@``'P````XC```3````+B,```D```!"(P``!````$PC
M```?````42,``"@```!Q(P``$````)HC```7````JR,```H```##(P``"```
M`,XC```*````UR,```(```#B(P``!P```.4C```&````[2,```4```#T(P``
M`@```/HC```Q````_2,``#@````O)```+P```&@D```?````F"0``"$```"X
M)```'````-HD```(````]R0```4`````)0``!0````8E```"````#"4```<`
M```/)0``!````!<E```F````'"4```P```!#)0``!@```%`E```3````5R4`
M``X```!K)0``#````'HE```(````AR4``!0```"0)0``!P```*4E```"````
MK24```D```"P)0``!````+HE```'````OR4```<```#')0``!@```,\E```4
M````UB4```T```#K)0``"P```/DE``!(````!28``$P```!.)@``#````)LF
M```*````J"8```D```"S)@```@```+TF```&````P"8``!0```#')@``#```
M`-PF``!%````Z28``"8````O)P``)0```%8G```P````?"<``!````"M)P``
M<P```+XG```?````,B@``!````!2*```#P```&,H```#````<R@```8```!W
M*```!````'XH```(````@R@``!````",*```$P```)TH```%````L2@```0`
M``"W*```"P```+PH```%````R"@```<```#.*```9@$``-8H```*````/2H`
M`"@```!(*@``%````'$J```6````ABH```@```"=*@``!0```*8J```0````
MK"H``!,```"]*@``$P```-$J```,````Y2H```\```#R*@``'@````(K```'
M````(2L```X````I*P``!0```#@K```)````/BL``!<```!(*P``#@```&`K
M```%````;RL```0```!U*P``"P```'HK```1````ABL```X```"8*P``(P``
M`*<K```%````RRL``#L```#1*P```0````TL```M````#RP``"\````]+```
M+@```&TL```&````G"P``!,```"C+```!P```+<L```&````ORP``!4```#&
M+```"````-PL```,````Y2P``!8```#R+```#@````DM```%````&"T``!``
M```>+0``'P```"\M```K````3RT``!T```![+0``(````)DM```<````NBT`
M`#````#7+0``-@````@N```L````/RX``!(```!L+@``"0```'\N```"````
MB2X```8```",+@``%````),N```#````J"X```<```"L+@``"````+0N```1
M````O2X```4```#/+@``"````-4N```-````WBX``&@```#L+@``$0```%4O
M```)````9R\``"8```!Q+P``$0```)@O```C````JB\```L```#.+P``"```
M`-HO```%````XR\```@```#I+P``!@```/(O```.````^2\```D````(,```
M!0```!(P```-````&#````0````F,```$````"LP```0````/#````\```!-
M,```#P```%TP```/````;3````P```!],```$````(HP```'````FS```!(`
M``"C,```'P```+8P```C````UC````0```#Z,```!P```/\P```-````!S$`
M``(````5,0``!@```!@Q```'````'S$```0````G,0``%````"PQ```'````
M03$```4```!),0``#P```$\Q```/````7S$```4```!O,0``"@```'4Q```7
M````@#$``!,```"8,0``$````*PQ```&````O3$```0```#$,0``!````,DQ
M```)````SC$```4```#8,0``"@```-XQ```B````Z3$``!(````,,@``(```
M`!\R```*````0#(```@```!+,@``!P```%0R```"````7#(``"4```!?,@``
M!@```(4R```$````C#(``!````"1,@```P```*(R```$````IC(```D```"K
M,@``!P```+4R```)````O3(```8```#',@```@```,XR```&````T3(```4`
M``#8,@``"````-XR```6````YS(``!4```#^,@``"````!0S```%````'3,`
M``H````C,P``"P```"XS```)````.C,```H```!$,P``.````$\S```/````
MB#,``"````"8,P``!0```+DS```'````OS,```@```#',P``!P```-`S```*
M````V#,``!$```#C,P``!P```/4S```5````_3,```<````3-```'````!LT
M```L````.#0``!\```!E-```%@```(4T```'````G#0``"4```"D-```)```
M`,HT```)````[S0``!8```#Y-```+P```!`U```#````0#4```D```!$-0``
M#@```$XU```3````734``!,```!Q-0``#@```(4U```,````E#4```X```"A
M-0``#P```+`U```+````P#4```4```#,-0``"0```-(U```)````W#4``!T`
M``#F-0``%@````0V```%````&S8```(````A-@``!P```"0V```,````+#8`
M``T````Y-@``$````$<V``!G````6#8``!D```#`-@``#P```-HV```=````
MZC8``!,````(-P``#P```!PW```9````+#<``!@```!&-P``$````%\W```0
M````<#<``!,```"!-P``"0```)4W```#````GS<``"8```"C-P``+P```,HW
M```5````^C<``!H````0.```"0```"LX```%````-3@```X````[.````@``
M`$HX```'````33@```8```!5.```"````%PX```"````93@``"D```!H.```
M-0```)(X```H````R#@``"4```#Q.```'@```!<Y```>````-CD```<```!5
M.0``!@```%TY```%````9#D```(```!J.0``!@```&TY```$````=#D``"@`
M``!Y.0``#P```*(Y```(````LCD``!0```"[.0``$0```-`Y```0````XCD`
M``H```#S.0``%````/XY```(````$SH```(````<.@``!@```!\Z```$````
M)CH```<````K.@``!P```#,Z```)````.SH``!4```!%.@``#P```%LZ```,
M````:SH``%8```!X.@``6````,\Z```/````*#L```\````X.P``"P```$@[
M```"````5#L```4```!7.P``%0```%T[```.````<SL``#H```"".P``*@``
M`+T[```M````Z#L``#(````6/```#P```$D\``!Y````63P``"8```#3/```
M$````/H\```0````"ST```,````</0```P```"`]```%````)#T```8````J
M/0``#````#$]```/````/CT```4```!./0``!````%0]```(````63T```4`
M``!B/0```@```&@]```!````^0```'(```!Q````D@````````"[````:```
M`'@```"4````.P`````````E`````````'0```#B````G@```.0`````````
M``$``!8`````````;0`````````>````!@```*,```#-`````````!L````,
M````F0````````#1````;@`````````+`0``^P```,@`````````FP```*(`
M````````RP````X``````````````+P```"J````V0````4!```=````,@``
M`*8````X`````P```+D```#G````C0```-L`````````;P``````````````
M(````",```!S``````````````!F````DP```,(```"D`````````%P```#Z
M````.@```*<````'`0``'````"H```#?`````````(X```"5````/@``````
M````````[````#8```#<````X0````````!A``````````H!``!\````````
M``````"1````*P```#,```!5``````````````!.````"````/$```!%````
M`````"D```#F``````````````#)````&```````````````E@```*@```#,
M````N@```(D```!_````KP````````"(````00````L`````````2@````(!
M``!V````JP```.,```"!````K````&````#$````M@``````````````[0``
M`*D````/````3````)\````$````L``````````-`````````-0```#%````
MP````$@```#_````70````````"]````(0```!D```"_````]0```)P````U
M`````````!4````\````!`$``%D`````````/P```"X```#.````5````(\`
M``!6``````````````!^````QP```.D````G````K0```"0`````````````
M`.H``````````````$``````````7P`````````&`0``L0````D!```#`0``
M7@```(4``````````````$<```!E````:@```%H```#2````1`````````#W
M````<````!0```"8``````````````![````)@````````!B````T````-,`
M``"+````:0`````````0````1@```*$`````````'P```*X```!#````=P``
M`/T```#P`````````%<````L````Q@````4````T``````````<```#S````
M>0````````"'````0@```.@```#6````C`````````````````````````#@
M`````````#<```"#````(@``````````````_@```,$````]`````````((`
M```,`0``]````-H```"@````6P```,H```"^````$P```.X```"=````6```
M`-<``````````````.4```#=````\@```'H```#V````,0````````#K````
MEP```$T`````````+P````````!/````[P```+,```"`````V````'T`````
M````20```!(```"X````A@```&0```!G````2P```+4````)````=0```%,`
M```H`````````#D```!K````,````&P```"0``````````@!````````F@``
M`,\```#>`````````/@````7````40```%(```"W``````````````"R````
M``````H`````````_`````(````M`````````-4```"$````8P```!$`````
M````4````(H```"T`````````,,`````````I0```!H````!`0``````````
M```````````````E<R`M($YO=&EC90`E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!F
M:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``R-"!H;W5R<P!!32]030!!9&0@
M179E;G0`061D(&$@;F5W(&5V96YT`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I
M<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`
M061M:6YI<W1R871I;VX`06QA<FT`06QA<FT@1&%T90!!;&%R;2!3<&%N("AM
M:6YU=&5S*0!!;&%R;2!4:6UE`$%L:6%S`$%L;`!!;&P@9&%Y`$%L;"!D87D@
M979E;G0`06QL(&5V96YT<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%P<FEL`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M
M86EN=&5N86YC92!O<&5R871I;VYS/P!!=`!!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!"
M:7)T:&1A>0!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A=&5G;W)Y
M`$-E;&P@4&AO;F4`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-O
M;7!A;GD`0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&1E;&5T:6]N(&]F(&5V
M96YT<S\`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+@!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,`0W)E871E(&$@3F5W($5V96YT`$-U<G)E;G0`1$0`1&%I;'D`
M1&%I;'DZ(%)E8W5R<R!E=F5R>0!$87D`1&%Y*',I`$1E8V5M8F5R`$1E9F%U
M;'0@261E;G1I='D`1&5L971E`$1E;&5T92`E<P!$96QE=&4@179E;G0`1&5L
M971E('1H92!C=7)R96YT(&5V96YT(&]N;'DL('1H:7,@;V-C=7)R96YC92!A
M;F0@86QL(&9U='5R92!O8V-U<F5N8V5S+"!O<B!A;&P@;V-C=7)E;F-E<S\`
M1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ES<&QA>2!/
M<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M`$1U93H@)7,`1'5R871I;VX`161I=`!%9&ET("5S`$5M86EL`$5M<'1Y(')E
M<W5L="X`16YD($1A=&4`16YD($]N`$5N9"!4:6UE`$5R<F]R`$5V97)Y(#$U
M(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E
M<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE
M('9A;'5E<SH`17AP;W)T`$5X<&]R="!#86QE;F1A<@!&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A>`!&96)R=6%R>0!&:6QE($UA;F%G97(`1G(`1G)I9&%Y`$9U
M='5R90!'86UE`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P<P!(96QP`$AO
M;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO=7(H<RD`26UP;W)T+T5X
M<&]R="!#86QE;F1A<@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE
M;&1S.@!*86YU87)Y`$IU;'D`2G5N90!+97EW;W)D<P!,86YG=6%G90!,87-T
M('=E96L`3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z`$QI<W0@2&5L
M<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]C871I;VX`
M3&]G(&EN`$QO9R!O=70`34T`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+@!-86EL`$UA<F-H`$UA=&-H:6YG(&9I96QD<P!-87D`365E
M=&EN9P!-96UB97)S`$UE<W-A9V4`36EM92!4>7!E`$UI;G5T92AS*0!-;P!-
M;VYD87D`36]N=&@`36]N=&AL>0!-;VYT:&QY.B!296-U<G,@979E<GD`3D\L
M($D@1&\@3D]4($%G<F5E`$YE='=O<FL`3F5V97(`3F5W($5V96YT`$YE>'0@
M36]N=&@`3F5X="!D87D`3F5X="!W965K`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!E;F0@9&%T90!.
M;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;VYE`$YO=&5S`$YO=F5M8F5R
M`$]C=&]B97(`3W!T:6]N<P!/=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!0
M87-S=V]R9',@;75S="!M871C:"X`4&%T=&5R;@!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/P!097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\`4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&AO;F4`4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9`!0<F5V:6]U<R!D87D`4')O8FQE;2!$
M97-C<FEP=&EO;@!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+@!296%D`%)E8W5R(%5N=&EL`%)E8W5R<F5N8V4@
M1&%T80!296-U<G)E;F-E($5N9"!$871E`%)E8W5R<F5N8V4@26YT97)V86P`
M4F5C=7)R96YC92!4>7!E`%)E8W5R<R!D86EL>0!296-U<G,@;6]N=&AL>0!2
M96-U<G,@=V5E:VQY`%)E8W5R<R!Y96%R;'D`4F5M;W9E`%)E;6]V92!P86ER
M`%)E<V5T`%)E<V5T('1O($1E9F%U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)O
M;&4`4V$`4V%T=7)D87D`4V%V92!!<R!.97<`4V%V92!%=F5N=`!3879E($]P
M=&EO;G,`4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES
M<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@9&5F875L="!V
M:65W+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@
M=&AE(&9I<G-T('=E96MD87DZ`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E
M;&5C="!T:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3
M97!T96UB97(`4VAO=P!3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_
M`%-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\`4VMI
M<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=&%R="!$
M871E`%-T87)T($]N`%-T87)T(%1I;64`4W4`4W5C8V5S<P!3=6YD87D`5&%S
M:W,`5&@`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U
M8V-E<W-F=6QL>0!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@96YD(&1A=&4@;75S="!B92!L
M871E<B!T:&%N('1H92!S=&%R="!D871E+@!4:&5R92!W97)E(&YO(&5V96YT
M<R!T;R!E>'!O<G0N`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H=7)S9&%Y`%1I=&QE
M`%1O9&%Y`%1U`%1U97-D87D`5'EP90!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`57!D871E`%5S97(@061M
M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`57-E<B!/<'1I;VYS`%5S97)N
M86UE`%5S97)S(&EN('1H92!S>7-T96TZ`%=A<FYI;F<`5V4`5V5D;F5S9&%Y
M`%=E96L`5V5E:R`E9`!7965K*',I`%=E96ML>0!7965K;'DZ(%)E8W5R<R!E
M=F5R>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@=&EM92!S:&]U
M;&0@9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@
M;&%T97(@979E;G1S/P!7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V
M:65W<R!S=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_
M`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=O<FL@5V5E:P!960!996%R;'D`
M665A<FQY.B!296-U<G,@979E<GD`665S+"!)($%G<F5E`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!2
M97!O<G1=`%ML:6YE("5S(&]F("5S70!D87D`9&%Y*',I`&1A>7,`;6]N=&@H
M<RD`;VX@=&AE('-A;64@9&%T90!O;B!T:&4@<V%M92!W965K9&%Y`'9#87)D
M`'=E96L`=V5E:RAS*2!O;CH`=V5E:W,`>65A<BAS*0!0<F]J96-T+4ED+59E
M<G-I;VXZ($MR;VYO;&ET:"`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP-BTP
M."`P,CHS.2LP,3`P"DQA<W0M5')A;G-L871O<CH@4&5R+5-T:6%N(%9A=&YE
M(#QP<W9`;W)S=&$N;W)G/@I,86YG=6%G92U496%M.B!.;W)W96=I86X@3GEN
M;W)S:R`\;GEN;W)S:T!O<G-T82YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"5S("T@3F]T:7,`)7,@
M=F5D;&EK96AA;&1S;W!E<F%S:F]N87(@+2!3=&%D9F5S=&EN9P`E<R!6:6QK
MY7(@9F]R(&%V=&%L90!&:6QA("5S('9A<G0@:6UP;W)T97)T`#(T('1I;6%R
M`$%-+U!-`$QE9V<@=&EL(&AE;F1I;F<`3&5G9R!T:6P@;GD@:&5N9&EN9P!,
M96=G('1I;"!N>2!B<G5K87(Z`$QE9V<@=&EL('!A<@!,96=G('1I;"!B<G5K
M87(`3&5G9R!T:6P@8G)U:V%R87(@97(@<VSE='0@878N`$%D<F5S<V4`061M
M:6YI<W1R97)I;F<`06QA<FT`06QA<FUD871O`$%L87)M:6YT97)V86QL("AM
M:6YU='0I`$%L87)M=&ED<W!U;FMT`$%L:6%S`$%L;&4`2&5I;&4@9&%G96X`
M5F%R97(@:&5I;&4@9&%G96X`06QL92!H96YD:6YG87(`16EN('5L;W9L96<@
M=F5R9&D@=F%R="!S<&5S:69I<V5R="X`07!R:6P`4W#X<B!O;2!S=&%D9F5S
M=&EN9R!F^'(@:_AY<FEN9R!A=B!V961L:6ME:&%L9'-O<&5R87-J;VYA<C\`
M(`!0<OAV9&4@Y2!S;&5T=&4@96D@:6MK:F4M96MS:7-T97)A;F1E(&=R=7!P
M92X`4'+X=F1E(.4@<VQE='1E(&5I;B!I:VMJ92UE:W-I<W1E<F%N9&4@=&EL
M9V%N9RX`4'+X=F1E(.4@96YD<F4@96EN(&EK:VIE+65K<VES=&5R86YD92!T
M:6QG86YG+@!!=6=U<W0`5&EL9VIE;F=E;&5G92!F96QT.@!"=7)S9&%G`$%V
M8G)Y=`!!=F)R>70@<')O8FQE;7)A<'!O<G0`2V%T96=O<FD`36]B:6QT96QE
M9F]N`$ML:6MK(&9O<B#E(&AA;&1E(&9R86T`3'5K:R!V:6YD875G970`1FER
M;6$`4W1A9&9E<W0@<&%S<V]R9`!3=&%D9F5S="!S;&5T=&EN9R!A=B!H96YD
M:6YG87(_`$]P<&MO<&QI;F<@;6]T(&]F9F5N=&QE9R!N^&MK96QT96YA<B!N
M96MT82X`2W5N;F4@:6MK:F4@4$=0+6MO9&4@;65L9&EN9RX`2W5N;F4@:6MK
M:F4@4$=0+7-I9VYE<F4@;65L9&EN9RX`2W5N;F4@:6MK:F4@9&5K;V1E(%!'
M4"UD871A+@!+=6YN92!I:VMJ92!A=F=J97)E(&UO='1A:V%R96X@<VD@92UP
M;W-T861R97-S92X`2W5N;F4@:6MK:F4@<VMA9F9E(&]F9F5N=&QE9R!N^&MK
M96P@9G+E(&[X:VME;'1E;F%R96XN`$MU;FYE(&EK:VIE(&]P;F4@36%I;G1E
M;F%N8V5?5&%S:RUM;V1U;&5N("5S`$]P<')E='0@;GD@:&5N9&EN9P!.;W9E
M<F%N9&4`1$0`1&%G;&5G`$MV87(@9&%G.B!3:VIE<B!K=F%R`$1A9P!D86<H
M87(I`$1E<V5M8F5R`%-T86YD87)D:61E;G1I=&5T`%-L971T`%-L971T("5S
M`%-L971T(&AE;F1I;F<`4VQE='0@8F5R<F4@9VIE;&1A;F1E(&AE;F1I;F<L
M(&1E;FYE(&;X<F5K;VUS=&5N(&]G(&%L;&4@9G)A;71I9&EG92!F^')E:V]M
M<W1E<BP@96QL97(@86QL92!F^')E:V]M<W1E<C\`4VMI;&1R92!P<F]B;&5M
M970`4VMI;&1R:6YG`$1E=&%L:F%R(&5R(&QO9V=A(&9O<B!A9&UI;FES=')A
M=&]R96XN`%9I<VEN9W-A;'1E<FYA=&EV`$EK:VIE(&)R=6L@;6%I;G1E;F%N
M8V4N<&AP(&1I<F5K=&4N`$9O<F9E;&PZ("5S`$1U<F%T:6]N`$5N9')E`$5N
M9')E("5S`$4M<&]S=`!4;VUT(')E<W5L=&%T+@!3;'5T=&1A=&\`4VQU='0`
M4VQU='1I9'-P=6YK=`!&96EL`$MV87)T(#$U+B!M:6YU='0`2W9A<G0@,S`N
M('-E:W5N9`!+=F%R="`U+B!M:6YU='0`2W9A<B!I;FYL;V=G:6YG`$MV87(@
M:&%L=F4@=&EM90!+=F%R="!M:6YU='0`16MS96UP96QV97)D:6%R.@!%:W-P
M;W)T`$5K<W!O<G1E<B!K86QE;F1E<@!+=6YN92!I:VMJ92!H96YT92!I;FYS
M=&EL;&EN9V%R`$MU;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN
M`$9A:W,`1F5B<G5A<@!&:6QH86YD<V%M:6YG`$9R`$9R961A9P!&<F%M=&ED
M`%-P96P`1W)U<'!E861M:6YI<W1R97)I;F<`1W)U<'!E<@!(:F5L<`!!9')E
M<W-E+"!P<FEV870`5&5L969O;BP@<')I=F%T`$AO<F1E`'1I;64O=&EM87(`
M26UP;W)T+V5K<W!O<G0@:V%L96YD97(`26UP;W)T97)T92!F96QT.B`E<P!)
M;7!O<G1E<G1E(&9E;'0Z`$IA;G5A<@!*=6QI`$IU;FD`3OAK:V5L;W)D`%-P
M<N5K`$;X<G)E('9E:V4`079G<F5N<R!T:61S:6YT97)V86QL(&9O<B!E:W-P
M;W)T.@!6:7,@96UN92!F<N4@2&IE;'``3&ES=&EN9R!A=B!B<G5K87)A<B!E
M<B!S;.5T="!A=BX`4&QA<W-E<FEN9P!,;V=G(&EN;@!,;V=G('5T`$U-`$U3
M+51.148M=F5D;&5G9R!I;FYE:&5L9'0@:6YG96X@9&%T82X`12UP;W-T`$UA
M<G,`4V%M<W9A<F%N9&4@9F5L=`!-86D`3?AT90!-961L96UM87(`365L9&EN
M9P!-24U%+71Y<&4`;6EN=71T`$WE`$WE;F1A9P!-Y6YA9`!-Y6YA9&QE9P!+
M=F%R(&WE;F%D.B!3:VIE<B!K=F%R`$Y%22P@96<@97(@24M+2D4@<V%M9`!.
M971T=F5R:P!!;&1R:0!.>2!H96YD:6YG`$YE<W1E(&WE;F%D`$YE<W1E(&1A
M9P!.97-T92!V96ME`$EN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@
M<W!E<VEF:7-E<G0@9F]R(%-13"!61E,N`$EN9V5N('-L=71T9&%T;P!);F=E
M;B!G>6QD:6=E(%A-3"UD871A(')E='5R;F5R=`!);F=E;@!.;W1A=&%R`$YO
M=F5M8F5R`$]K=&]B97(`06QT97)N871I=@!!;FYA;B!I;F9O<FUA<VIO;@!0
M87-S;W)D`%!A<W-O<F1A(&WE('-A;7-V87)E+@!-^&YS=&5R`$OX>7(@=F5D
M;&EK96AA;&1S;W!E<F%S:F]N87(`2_AY<B!V961L:6ME:&%L9'-O<&5R87-J
M;VYA<B!V960@:6YN;&]G9VEN9S\`4VQE='0@9&5N;F4@:&5N9&EN9V$@<&5R
M;6%N96YT/P!4:6QG86YG<V%D;6EN:7-T<F5R:6YG`%1E;&5F;VX`4VMR:78@
M:6YN(&5I="!S86UA;F1R86<@878@<')O8FQE;65T+@!3:W)I=B!I;FX@9&ET
M="!B<G5K87)N86UN(&]G('!A<W-O<F0`1OAR<F4@9&%G`%-K:6QD<FEN9R!A
M=B!P<F]B;&5M970`3V9F96YT;&5G+W!R:79A="!N^&MK96QP87(@=F%R="!I
M:VMJ92!G96YE<F5R="X`3&5S`%-K:F5R('1I;`!296=E;&9A<W0@9&%T80!2
M96=E;&9A<W0@<VQU='1D871O`%)E9V5L9F%S="!I;G1E<G9A;&P`4F5G96QF
M87-T('1Y<&4`4VMJ97(@9&%G;&5G`%-K:F5R(&WE;F%D;&5G`%-K:F5R(&MV
M87(@=F5K90!3:VIE<B#E<FQE9P!&:F5R;@!&:F5R;B!P87(`3G5L;'-T:6QL
M`$YU;&QS=&EL;"!T:6P@<W1A;F1A<F1V97)D:6%R`%1I;&)A:V4@=&EL(&%L
M=&5R;F%T:78`4F]L;&4`3&$`3&%U<F1A9P!,86=R92!S;VT@;GD`3&%G<F4@
M:&5N9&EN9P!,86=R92!A;'1E<FYA=&EV`%9E;"!A;'1E<FYA=&EV(&9O<B!S
M=&%D9F5S=&EN9RP@:V]R;&5I<R!D96D@=6QI:V4@=FES:6YG86YE('-K86P@
M<')E<V5N=&5R87-T(&]G('9E;"!E:2!S=&%N9&%R9'9I<VEN9RX`5F5L('-K
M:6QJ971E:6MN(&9O<B!D871O.@!696P@9&%T;V9O<FUA=#H`5F5L(&9I;"!S
M;VT@<VMA;"!I;7!O<G1E<F%S=#H`5F5L(&;X<G-T92!V96ME9&%G.@!696P@
M=&ED<V9O<FUA=#H`5F5L('1I9'-I;G1E<G9A;&P@Y2!V:7-E.@!696P@=&\@
M<V%M<W9A<F%N9&4@9F5L="X`5F5L(&9A<F=E<VMJ96UA+@!696P@^&YS:V$@
M<W!RY6LZ`%-E;F0@<')O8FQE;7)A<'!O<G0`4V5P=&5M8F5R`%9I<P!6:7,@
M;W!P9^5V97(@=&EL(&9O<F9A;&P@:2!K86QE;F1E<F5N/P!6:7,@8F5R<F4@
M:&5N9&EN9V%R('-O;2!H87(@96EN(&%L87)M(&%K=&EV97)T/P!(;W!P(&]V
M97(@=F5D;&EK96AA;&0`26YN=&%S=&EN9R!A=B!S<&5S:6%L=&5I:VX`4W1A
M<G1D871O`%-T87)T`%-T87)T=&ED<W!U;FMT`%/X`%-U:W-E<W,`4_AN9&%G
M`$]P<&?E=F5R`%1O`$ML87-S82!-86EN=&5N86YC93HZ('9A<G0@:6MK:F4@
M;&%S=&$@:6YN`$MR>7!T97)I;F=S9G5N:W-J;VYA;F4@:W)E=B!E:2!S:6MK
M97(@;F5T=&]P<&MO<&QI;F<N`%-L=71T9&%T;R!MY2!V97)E('-E:6YA<F4@
M96YN('-T87)T9&%T;RX`1&5T('9A<B!I;F=E;B!H96YD:6YG87(@Y2!E:W-P
M;W)T97)E+@!$971T92!T86QE="!MY2!V97)E(&UI;G-T(&5I;BX`1&5N;F4@
M=F5R9&EE;B!MY2!V97)E(&5I="!T86PN`%1O<G-D86<`5&ET=&5L`$D@9&%G
M`%1Y`%1Y<V1A9P!4>7!E`$MA;B!I:VMJ92!O;7-E=&IE(&1E='1E(%=O<F0M
M9&]K=6UE;G1E="X`06YG<F4@96YD<FEN9V%R`$]P<&1A=&5R`$)R=6MA<F%D
M;6EN:7-T<F5R:6YG`$)R=6MA<F=R96YS97-N:71T`$)R=6MA<F%L=&5R;F%T
M:78`0G)U:V%R;F%M;@!"<G5K87)A<B!I('-Y<W1E;65T.@#%='9A<FEN9P!/
M;@!/;G-D86<`5F5K90!696ME("5D`%9E:V4H<BD`2W9A<B!V96ME`$MV87(@
M=F5K93H@4VMJ97(@:W9A<@!696QK;VUE;B!T:6P@)7,`5F5L:V]M96XL("5S
M`%#E(&MV82!T:61S<'5N:W0@<VMA;"!D86<M(&]G('9E:V5V:7-I;F=A<B!S
M;'5T=&4L(&[E<B!D970@97(@:6YG96X@<V5I;F%R92!H96YD:6YG87(_`%#E
M(&MV82!T:61S<'5N:W0@<VMA;"!D86<M(&]G('9E:V5V:7-I;F=A<B!S=&%R
M=&4L(&[E<B!D970@97(@:6YG96X@=&ED;&5G87)E(&AE;F1I;F=A<C\`061R
M97-S92P@87)B96ED`%1E;&5F;VXL(&%R8F5I9`!!<F)E:61S=F5K90#%Q0#%
M<FQE9P!+=F%R="#E<CH@4VMJ97(@:W9A<G0`2F$L(&5G(&5R('-A;60`1'4@
M;>4@<VMI;&1R92!P<F]B;&5M970@9OAR(&1U(&MA;B!S96YD92!P<F]B;&5M
M<F%P<&]R=&5N+@!$=2!MY2!S<&5S:69I<V5R92!E:70@8G)U:V%R;F%M;B#E
M(&9J97)N92X`1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!L
M96=G92!T:6PN`-AK=&$@9&D@*"5S*2!H87(@9^5T="!U="!PY2!T:60N($QO
M9V<@:6YN('#E(&YY='0N`$1I;B!I;F9O<FUA<VIO;@!,:7-T:6YG(&%V(&)R
M=6MA<F%R(&5R(&EK:VIE('-T^'1T82!A=B!B86MR92!A=71E;G1I<V5R:6YG
M+"!E;&QE<B!F=6YK<VIO;F5N(&AA<B!A=B!E:6X@96QL97(@86YN86X@9W)U
M;FX@8FQI='0@<VSE='0@878N`$%L=&5R;F%T:79A(&1I;F4@:&%R(&)L:71T
M(&]P<&1A=&5R=&4N`%M0<F]B;&5M<F%P<&]R=%T`6VQI;FIE("5S(&%V("5S
M70!D86<`9&%G`&1A9V%R`&WE;F%D(`!PY2!S86UE(&1A=&\`<.4@<V%M92!V
M96ME9&%G`'9#87)D`'9E:V4`=F5K92!PY3H`=F5K97(`Y7(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A
M;&4O<&Q?4$PO````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-3(`,#(P-S`Q`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:W)O;F]L:71H+VQO8V%L92]P;%]03"],0U]-15-304=%4R\`````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,@`P,C(T-C8`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+W!L7U!,+TQ#
M7TU%4U-!1T53+VMR;VYO;&ET:"YM;P``````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,34P-#8W`#$P-#$W
M,S8R-S4R`#`R-3`T-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#>$@25`````(X#```<````C!P``+T$``#\.````````/!+
M``!(````\4L```X````Z3```#P```$E,```-````64P```@```!G3```"P``
M`'!,```,````?$P``!L```")3```+0```*5,```D````TTP``"D```#X3```
M&0```")-```,````/$T```L```!)30``$0```%5-```.````9TT```4```!V
M30``*````'Q-```(````I4T```H```"N30``$@```+E-```=````S$T```X`
M``#J30``"@```/E-```-````!$X```X````23@``$0```"%.```,````,TX`
M``T```!`3@``!@```$Y.```,````54X```X```!B3@``#@```'%.```(````
M@$X```D```")3@``&@```)-.```R````KDX``#@```#A3@``5````!I/``!1
M````;T\``%H```#!3P``5P```!Q0```T````=%````4```"I4```$0```*]0
M```(````P5```!````#*4```#P```-M0```*````ZU````D```#V4```"0``
M``!1```-````"E$``!(````840``#P```"M1```/````.U$```H```!+40``
M#P```%91```(````9E$``"0```!O40``%````)11```6````J5$```@```#`
M40``+0```,E1```9````]U$```<````14@``#@```!E2```#````*%(```L`
M```L4@``!0```#A2```*````/E(``!0```!)4@``"@```%Y2```'````:5(`
M``<```!Q4@``!0```'E2```7````?U(```H```"74@``#P```*)2```'````
MLE(```T```"Z4@``"@```,A2```8````TU(```X```#L4@``%````/M2```7
M````$%,``!<````H4P``%P```$!3```/````6%,``!\```!H4P``!P```(A3
M```&````D%,```@```"74P``#P```*!3```&````L%,```H```"W4P``"P``
M`,)3```5````SE,```<```#D4P``!0```.Q3```1````\E,```P````$5```
M"0```!%4```'````&U0```4````C5```.0```"E4```"````8U0```H```!F
M5```!@```'%4```)````>%0```<```""5```+P```(I4```N````NE0``%4`
M``#I5```+0```#]5```M````;54``"T```";50``(P```,E5```C````[54`
M`"T````15@``,P```#]6```5````<U8``!D```")5@``*0```*-6```D````
MS58``!$```#R5@``"@````17```,````#U<```H````<5P``$````"=7```6
M````.%<``!8```!/5P``!P```&97```'````;E<``!0```!V5P``"@```(M7
M```'````EE<```<```">5P``!@```*97```%````K5<```<```"S5P``!@``
M`+M7```(````PE<```X```#+5P``"@```-I7```'````Y5<```D```#M5P``
M%@```/=7```$````#E@```8````36```"````!I8```#````(U@```,````G
M6```$P```"M8```(````/U@```@```!(6```00```%%8```@````DU@```8`
M``"T6```!@```+M8```5````PE@``!@```#86```(@```/%8```=````%%D`
M``H````R60``%0```#U9```(````4UD```H```!<60``#P```&=9```/````
M=UD```D```"'60``%````)%9```8````IED``!T```"_60``$P```-U9```1
M````\5D```0````#6@``!@````A:``!4````#UH```X```!D6@``1````'-:
M```%````N%H```4```"^6@``$0```,1:```1````UEH``!P```#H6@``$```
M``5;```1````%EL```P````H6P``%P```#5;```0````35L```@```!>6P``
M!0```&=;```,````;5L``!````!Z6P``#0```(M;```'````F5L```T```"A
M6P``!P```*];```'````MUL```<```"_6P``%````,=;```)````W%L```H`
M``#F6P``#````/%;```0````_EL```4````/7```)0```!5<```2````.UP`
M`!,```!.7```*P```&)<```[````CEP``"````#*7```-@```.M<```0````
M(ET```@````S70``#````#Q=```$````25T```X```!.70``'@```%U=```;
M````?%T``"$```"870``'@```+I=```>````V5T``"X```#X70``&P```"=>
M```>````0UX``#,```!B7@``+P```)9>```@````QEX``"D```#G7@``'@``
M`!%?```6````,%\``$$```!'7P``!P```(E?```2````D5\```T```"D7P``
M$````+)?```2````PU\```<```#67P``!````-Y?```,````XU\``"@```#P
M7P```P```!E@```&````'6````X````D8````@```#-@```%````-F```!,`
M```\8```!````%!@```#````56````8```!98```#@```&!@```(````;V``
M``T```!X8```$````(9@```3````EV```!,```"K8```#````+]@```,````
MS&```!$```#98```&0```.M@```+````!6$```T````180``&P```!]A```T
M````.V$```H```!P80``&````'MA```9````E&$``!8```"N80``+P```,5A
M```'````]6$``!0```#]80``"P```!)B```O````'F(```D```!.8@``%@``
M`%AB```/````;V(```@```!_8@``#0```(AB```F````EF(```@```"]8@``
M$@```,9B```(````V6(```L```#B8@``!0```.YB```(````]&(```8```#]
M8@``!P````1C```'````#&,```H````48P``#P```!]C```0````+V,``!<`
M``!`8P``$0```%AC```7````:F,```4```""8P``"P```(AC```%````E&,`
M`!L```":8P``"0```+9C```.````P&,```T```#/8P``(````-UC```(````
M_F,```8````'9```"`````YD```1````%V0```<````I9```!0```#%D```3
M````-V0```<```!+9```"````%-D```&````7&0``!````!C9```#P```'1D
M```0````A&0```\```"59```"P```*5D```/````L60```P```#!9```#P``
M`,YD```'````WF0```8```#F9```#@```.UD```&````_&0```\````#90``
M(0```!-E```9````-64``!<```!/90``%P```&=E```;````?V4```T```";
M90``#````*EE```#````MF4```@```"Z90``!````,-E```,````R&4```D`
M``#590``#@```-]E```+````[F4``!L```#Z90``!P```!9F```'````'F8`
M``0````F9@``%0```"MF```"````068```8```!$9@``#0```$MF```0````
M668``!L```!J9@``!@```(9F```$````C68```4```"29@``!@```)AF```$
M````GV8```<```"D9@``!0```*QF```)````LF8```(```"\9@``#0```+]F
M```&````S68```D```#49@``!P```-YF```&````YF8```H```#M9@``!```
M`/AF```)````_68```@````'9P``!@```!!G```-````%V<```8````E9P``
M!````"QG```%````,6<``"$````W9P``!````%EG```$````7F<```4```!C
M9P``'0```&EG```$````AV<```P```",9P``"@```)EG```(````I&<```D`
M``"M9P``!0```+=G```I````O6<```<```#G9P``!P```.]G```'````]V<`
M``H```#_9P``#P````IH```0````&F@```8````K:```%@```#)H```2````
M26@``!````!<:```!0```&UH```)````<V@```0```!]:```#````()H```7
M````CV@``!P```"G:```$P```,1H```4````V&@``!D```#M:```!`````=I
M```'````#&D```8````4:0``!@```!MI```%````(FD```<````H:0``!P``
M`#!I```%````.&D```8````^:0``!````$5I```$````2FD```H```!/:0``
M!0```%II```,````8&D```\```!M:0``"@```'UI```(````B&D``"L```"1
M:0``"````+UI```$````QFD```@```#+:0``)@```-1I```2````^VD```8`
M```.:@``"@```!5J```'````(&H```@````H:@``(````#%J```.````4FH`
M`!8```!A:@``$0```'AJ```)````BFH```8```"4:@``!P```)MJ```'````
MHVH``!8```"K:@``#0```,)J```>````T&H``!````#O:@``&@````!K```)
M````&VL```H````E:P``#````#!K```/````/6L```@```!-:P``!@```%9K
M```'````76L```L```!E:P``1P```'%K```-````N6L```,```#':P``"@``
M`,MK```"````UFL```0```#9:P```P```-YK```%````XFL``"H```#H:P``
M"@```!-L```$````'FP```8````C;```"````"IL```(````,VP```0````\
M;```!0```$%L``!H````1VP```4```"P;```!@```+9L```0````O6P```H`
M``#.;```#P```-EL```*````Z6P```D```#T;````P```/YL```'`````FT`
M``<````*;0``"@```!)M```+````'6T```<````I;0``&@```#%M``!*````
M3&T```8```"7;0``"0```)YM```)````J&T```(```"R;0``#0```+5M```*
M````PVT```<```#.;0``%````-9M```&````ZVT```8```#R;0``"````/EM
M```%`````FX```<````(;@``%0```!!N```*````)FX```L````Q;@``!P``
M`#UN```)````16X```D```!/;@``"@```%EN```'````9&X```D```!L;@``
M!P```'9N```*````?FX```H```");@``"0```)1N```'````GFX```<```"F
M;@``!0```*YN```%````M&X```L```"Z;@``%````,9N```'````VVX```4`
M``#C;@``#0```.EN```,````]VX```D````$;P``"P````YO```$````&F\`
M``H````?;P``"````"IO```,````,V\```D```!`;P``"0```$IO```%````
M5&\```<```!:;P``!````&)O```*````9V\``"X```!R;P``"P```*%O```0
M````K6\``"T```"^;P``+0```.QO```Q````&G```"T```!,<```+@```'IP
M```O````J7```"P```#9<```!`````9Q```.````"W$```8````:<0``$```
M`"%Q```'````,G$```X````Z<0``!0```$EQ```&````3W$```@```!6<0``
M$0```%]Q```.````<7$```(```"`<0``!P```(-Q```&````BW$```0```"2
M<0``'P```)=Q```4````MW$```<```#,<0``#@```-1Q```,````XW$``!,`
M``#P<0``"@````1R```%````#W(``!$````5<@``$0```"=R```D````.7(`
M`!4```!><@``$@```'1R```.````AW(``!D```"6<@``"````+!R```)````
MN7(```H```##<@``"````,YR```%````UW(```8```#=<@``$````.1R```(
M````]7(```@```#^<@``$@````=S```:````&G,```D````U<P``"@```#]S
M```5````2G,```4```!@<P``%````&9S```'````>W,``!X```"#<P``*```
M`*)S```*````RW,```\```#6<P``%````.9S```$````^W,```L`````=```
M!0````QT```(````$G0``#0````;=```-````%!T```@````A70``!H```"F
M=```*````,%T```I````ZG0```8````4=0``"````!MU```'````)'4```P`
M```L=0``"P```#EU```'````174``!,```!-=0``"@```&%U```4````;'4`
M``\```"!=0``,@```)%U```+````Q'4```4```#0=0``!0```-9U```7````
MW'4```L```#T=0``#P````!V```3````$'8``!,````D=@``#P```#AV```,
M````2'8```X```!5=@``#0```&1V```-````<G8``!X```"`=@``%````)]V
M```.````M'8```8```##=@``#````,IV```-````UW8```L```#E=@``"@``
M`/%V```+````_'8```\````(=P``!0```!AW```.````'G<``!,````M=P``
M$0```$%W```'````4W<``!$```!;=P``!P```&UW```8````=7<```0```".
M=P``!P```)-W```*````FW<```L```"F=P``#````+)W```.````OW<``!(`
M``#.=P``!@```.%W```8````Z'<``"4````!>```"0```"=X```#````,7@`
M``H````U>````@```$!X```,````0W@``!4```!0>```"P```&9X```9````
M<G@``"````",>```!0```*UX```*````LW@```@```"^>```#````,=X```)
M````U'@```<```#>>```"@```.9X```,````\7@```P```#^>```&@````MY
M```7````)GD``!H````^>0``&0```%EY```G````<WD``!H```";>0``%P``
M`+9Y```=````SGD``!L```#L>0``&0````AZ```?````(GH``!,```!">@``
M!P```%9Z```)````7GH```T```!H>@```P```'9Z```_````>GH``#<```"Z
M>@``5P```/)Z```%````2GL```H```!0>P``#0```%M[```$````:7L``!\`
M``!N>P``)0```(Y[```H````M'L``!T```#=>P``#````/M[```9````"'P`
M``D````B?```$P```"Q\```)````0'P```0```!*?```$````$]\```(````
M8'P```@```!I?```#P```')\```'````@GP```P```"*?```&P```)=\```L
M````LWP```4```#@?```!````.9\```7````ZWP```H````#?0``#`````Y]
M```)````&WT```D````E?0``"@```"]]```(````.GT```H```!#?0``$0``
M`$Y]```.````8'T```(```!O?0``!P```')]```&````>GT```<```"!?0``
M)@```(E]```X````L'T``!H```#I?0``*@````1^```9````+WX```4```!)
M?@``!@```$]^```.````5GX```@```!E?@``"0```&Y^```&````>'X```L`
M``!_?@``%````(M^```&````H'X``!D```"G?@``"@```,%^```<````S'X`
M``4```#I?@``$````.]^```)`````'\```(````*?P``"`````U_```?````
M%G\``"\````V?P``(P```&9_```A````BG\``!\```"L?P``)P```,Q_```?
M````]'\``#$````4@```00```$:````S````B(```"4```"\@```+P```.*`
M```?````$H$``"\````R@0``+````&*!```7````CX$``"(```"G@0``10``
M`,J!```P````$((```@```!!@@``!````$J"```+````3X(```4```!;@@``
M`@```&&"``!9````9((```4```"^@@``!````,2"```'````R8(```4```#1
M@@``$P```->"```-````ZX(```(```#Y@@``!P```/R"```'````!(,```8`
M```,@P``%````!.#```,````*(,```8````U@P``!````#R#```$````08,`
M``8```!&@P``!P```$V#```7````58,``!H```!M@P``)@```(B#```,````
MKX,``!0```"\@P``#@```-&#```-````X(,```<```#N@P``!P```/:#```5
M````_H,```8````4A```!@```!N$```'````(H0```X````JA```#````#F$
M```1````1H0```@```!8A```'0```&&$```)````?X0```H```")A```%```
M`)2$```*````J80```@```"TA```!P```+V$```)````Q80```<```#/A```
M"````->$```'````X(0``!D```#HA```"@````*%```7````#84``!0````E
MA0``$0```#J%```'````3(4```(```!4A0```P```%>%```)````6X4```0`
M``!EA0``!P```&J%```'````<H4```8```!ZA0``%````(&%```'````EH4`
M``T```">A0``"P```*R%```4````N(4``!4```#-A0``#@```..%```O````
M\H4``#$````BA@``/P```%2&```,````E(8```H```"AA@``"0```*R&```"
M````MH8```0```"YA@``!@```+Z&```4````Q88```4```#:A@```P```."&
M```,````Y(8``!D```#QA@``10````N'```F````48<``"4```!XAP``$@``
M`)Z'```3````L8<``!````#%AP``>0```-:'```)````4(@``'(```!:B```
M<P```,V(```7````08D``!8```!9B0``#P```'")```?````@(D``$````"@
MB0``'P```.&)```4`````8H```H````6B@``!0```"&*```&````)XH```@`
M```NB@``$````#>*```/````2(H```0```!8B@``"P```%V*```'````:8H`
M``4```!QB@``!P```'>*```(````?XH```\```"(B@``"````)B*```,````
MH8H```\```"NB@``!@```+Z*```&````Q8H```P```#,B@``"````-F*```#
M````XHH```8```#FB@``!````.V*```$````\HH```@```#WB@``!`````"+
M```'````!8L``!`````-BP``$P```!Z+```'````,HL```4````ZBP``!```
M`$"+```+````18L```4```!1BP``!P```%>+``!*`0``7XL``$,```"JC```
M#@```.Z,```2````_8P``!$````0C0``!P```"*-```(````*HT```H````S
MC0``(@```#Z-```O````88T``!T```"1C0``(@```*^-```>````THT```H`
M``#QC0``"@```/R-```0````!XX```\````8C@``!0```"B.```G````+HX`
M``\```!6C@``#@```&:.```0````=8X``"(```"&C@``$````*F.```(````
MNHX``!$```##C@``#0```-6.```3````XXX```L```#WC@``#@````./```&
M````$H\```T````9CP``$@```">/```2````.H\```@```!-CP``"@```%:/
M```7````88\``#\```!YCP``2````+F/``!<`````I```%D```!?D```8@``
M`+F0``!?````')$``$$```!\D0``!0```+Z1```.````Q)$```X```#3D0``
M#@```.*1```2````\9$```4````$D@``#P````J2```,````&I(``!`````G
MD@``%@```#B2```4````3Y(``!D```!DD@``#0```'Z2```5````C)(```H`
M``"BD@``'@```*V2```;````S)(``"````#HD@``$0````F3```M````&Y,`
M`"8```!)DP``!0```'"3```-````=I,```<```"$DP``"@```(R3```%````
MEY,```L```"=DP``'````*F3```+````QI,```<```#2DP``"````-J3```%
M````XY,``",```#IDP``#P````V4```5````'90```H````SE```%0```#Z4
M```3````5)0``!<```!HE```#````("4```7````C90``!<```"EE```(P``
M`+V4```8````X90``!,```#ZE```)0````Z5```&````-)4```8````[E0``
M"````$*5```/````2Y4```D```!;E0``"@```&65```)````<)4``!````!Z
ME0``"0```(N5```(````E94``!$```">E0``#@```+"5```)````OY4```<`
M``#)E0``!0```-&5```]````UY4```$````5E@``"````!>6```(````()8`
M``D````IE@``!P```#.6```X````.Y8``#@```!TE@``6P```*V6```W````
M"9<``#<```!!EP``-P```'F7```N````L9<``#(```#@EP``-P```!.8```]
M````2Y@``"$```")F```)0```*N8```O````T9@``#$````!F0``#@```#.9
M```+````0ID```P```!.F0```P```%N9```)````7YD``!0```!IF0``'P``
M`'Z9```,````GID```<```"KF0``%@```+.9```*````RID```@```#5F0``
M!@```-Z9```&````Y9D```4```#LF0``!P```/*9```&````^ID```@````!
MF@``$`````J:```)````&YH```<````EF@``"````"V:```4````-IH```,`
M``!+F@``"````$^:```(````6)H```,```!AF@```P```&6:```;````:9H`
M``@```"%F@``!P```(Z:``!/````EIH``"T```#FF@``!@```!2;```)````
M&YL``!D````EFP``'0```#^;```L````79L``"````"*FP``&0```*N;```6
M````Q9L```D```#<FP``"0```.:;```3````\)L``!,````$G```"0```!B<
M```6````(IP``!H````YG```'P```%2<```5````=)P``!8```"*G```!```
M`*&<```%````IIP``$8```"LG```#P```/.<```S`````YT```4````WG0``
M!0```#V=```+````0YT``!<```!/G0``(````&>=```7````B)T``!8```"@
MG0``#````+>=```9````Q)T```T```#>G0``"````.R=```%````]9T```T`
M``#[G0``#`````F>```-````%IX```<````DG@``!P```"R>```)````-)X`
M``8````^G@``!0```$6>```5````2YX```D```!AG@``!P```&N>```.````
M<YX```\```""G@``!0```)*>```=````F)X``!P```"VG@``'0```-.>```L
M````\9X``#L````>GP``*0```%J?```^````A)\```X```##GP``"````-*?
M```+````VY\```<```#GGP``#0```.^?```K````_9\``"@````IH```+@``
M`%*@```K````@:```"H```"MH```.0```-B@```E````$J$``"@````XH0``
M+0```&&A```S````CZ$``"8```##H0``+0```.JA```@````&*(``"(````Y
MH@``10```%RB```$````HJ(``!4```"GH@``"P```+VB```+````R:(``!8`
M``#5H@``"0```.RB```$````]J(```L```#[H@``-P````>C```&````/Z,`
M``0```!&HP``#P```$NC```"````6Z,```H```!>HP``&P```&FC```$````
MA:,```4```"*HP```P```)"C```-````E*,```@```"BHP``#@```*NC```2
M````NJ,``!0```#-HP``%````.*C```.````]Z,```H````&I```$````!&D
M```9````(J0```P````\I```#````$FD```;````5J0``#H```!RI```"P``
M`*VD```8````N:0``!4```#2I```%````.BD```T````_:0```4````RI0``
M#0```#BE```$````1J4``#````!+I0``!P```'RE```F````A*4``!(```"K
MI0``!P```+ZE```)````QJ4``"X```#0I0``'0```/^E```C````':8```@`
M``!!I@``"P```$JF```)````5J8```P```!@I@``!@```&VF```'````=*8`
M``D```!\I@``"@```(:F```1````D:8``!$```"CI@``&````+6F```5````
MSJ8``!@```#DI@``!0```/VF```(`````Z<```4````,IP``)0```!*G```)
M````.*<``!````!"IP``$````%.G```V````9*<``!````";IP``"0```*RG
M```0````MJ<``!````#'IP``!P```-BG```$````X*<``!<```#EIP``!P``
M`/VG```'````!:@```8````-J```$0```!2H```1````)J@``!(````XJ```
M$````$NH```4````7*@``!0```!QJ```#P```(:H```5````EJ@```<```"L
MJ```!@```+2H```,````NZ@```<```#(J```$P```-"H```J````Y*@``!\`
M```/J0``(````"^I```B````4*D``!,```!SJ0``"P```(>I```0````DZD`
M``0```"DJ0``!````*FI```%````KJD```\```"TJ0``"P```,2I```+````
MT*D```\```#<J0``)@```.RI```&````$ZH```D````:J@``"````"2J```2
M````+:H```(```!`J@``!P```$.J```0````2ZH``!,```!<J@``+@```'"J
M```&````GZH```(```"FJ@``!0```*FJ```&````KZH```,```"VJ@``!@``
M`+JJ```%````P:H```D```#'J@```P```-&J```3````U:H```8```#IJ@``
M"@```/"J```'````^ZH``!`````#JP``"0```!2K```$````'JL```D````C
MJP``"````"VK```&````-JL```T````]JP``!@```$NK```$````4JL```4`
M``!7JP``%P```%VK```%````=:L```8```![JP``!@```(*K```<````B:L`
M``@```"FJP``#````*^K```)````O*L```@```#&JP``"````,^K```%````
MV*L``"4```#>JP``"@````2L```%````#ZP```@````5K```"P```!ZL```/
M````*JP``!$````ZK```!P```$RL```9````5*P``!0```!NK```$0```(.L
M```%````E:P```D```";K```!````*6L```-````JJP``!L```"XK```'0``
M`-2L```:````\JP``!T````-K0``!````"NM```$````,*T```@````UK0``
M!@```#ZM```'````1:T```8```!-K0``!P```%2M```'````7*T```<```!D
MK0``!@```&RM```&````<ZT```@```!ZK0``"@```(.M```%````CJT``!``
M``"4K0``#0```*6M```.````LZT```H```#"K0``,0```,VM```.````_ZT`
M``8````.K@``"````!6N```H````'JX```\```!'K@``!@```%>N```)````
M7JX```L```!HK@``!0```'2N```$````>JX``!8```!_K@``&P```):N```9
M````LJX``!$```#,K@``!0```-ZN```'````Y*X```<```#LK@``!0```/2N
M```-````^JX``!P````(KP``%@```"6O```G````/*\```4```!DKP``#```
M`&JO```.````=Z\``!D```"&KP``!P```*"O```'````J*\```<```"PKP``
M%@```+BO``!7````SZ\``!L````GL```!0```$.P```*````2;````(```!4
ML```!````%>P```#````7+````4```!@L```"0```&:P```*````<+````8`
M``![L```!@```(*P```'````B;````@```"1L```!````)JP```%````G[``
M`%L```"EL```!@````&Q```(````"+$```\````1L0``"0```"&Q```-````
M*[$```H````YL0``"0```$2Q```#````3K$```<```!2L0``"0```%JQ```*
M````9+$```X```!OL0``"0```'ZQ```?````B+$``%H```"HL0``!@````.R
M```(````"K(```D````3L@```@```!VR```4````(+(```H````UL@``"```
M`$"R```2````2;(```8```!<L@``#````&.R```(````<+(```<```!YL@``
M"@```(&R```<````C+(```H```"IL@``#0```+2R```&````PK(```T```#)
ML@``#@```->R```/````YK(```X```#VL@``#@````6S```.````%+,```@`
M```CLP``!0```"RS```*````,K,```4````]LP``!P```$.S```%````2[,`
M``4```!1LP``"````%>S```3````8+,```0```!TLP``!0```'FS```.````
M?[,```X```".LP``#@```)VS```-````K+,```H```"ZLP``$````,6S```.
M````UK,```X```#ELP``$````/2S```)````!;0```4````/M```!P```!6T
M```$````';0```H````BM```&0```"VT```1````1[0``!````!9M```*P``
M`&JT```K````EK0``"\```#"M```*P```/*T```L````'K4``"T```!+M0``
M*@```'FU```$````I+4```<```"IM0``"````+&U```5````NK4```P```#0
MM0``#@```-VU```%````[+4```4```#RM0``"````/BU```-`````;8```X`
M```/M@```@```!ZV```+````(;8```4````MM@``!````#.V```G````.+8`
M`!0```!@M@``!0```'6V```(````>[8```L```"$M@``%P```)"V```+````
MJ+8```0```"TM@``#P```+FV```0````R;8``"<```#:M@``$@````*W```:
M````%;<``!,````PMP``+````$2W```'````<;<```L```!YMP``#````(6W
M```(````DK<```4```";MP``!@```*&W```1````J+<```@```"ZMP``!0``
M`,.W```3````R;<``!8```#=MP``!@```/2W```'````^[<``!,````#N```
M!0```!>X```0````';@```<````NN```&@```#:X```M````4;@```L```!_
MN```#P```(NX```3````F[@```0```"ON```"````+2X```'````O;@```@`
M``#%N```)````,ZX```@````\[@``!\````4N0``&P```#2Y```6````4+D`
M`"8```!GN0``!@```(ZY```*````E;D```<```"@N0``#P```*BY```.````
MN+D```<```#'N0``#0```,^Y```/````W;D``!L```#MN0``'@````FZ```Z
M````*+H```D```!CN@``!0```&VZ```)````<[H``!X```!]N@``#@```)RZ
M```0````J[H``!8```"\N@``%0```-.Z```/````Z;H``!<```#YN@``%P``
M`!&[```7````*;L``!,```!!NP``(0```%6[```6````=[L```X```".NP``
M!````)V[```)````HKL```P```"LNP``"0```+F[```$````P[L``!````#(
MNP``%@```-F[```%````\+L```T```#VNP``$P````2\```<````&+P```8`
M```UO```#P```#R\```'````3+P``!D```!4O```"@```&Z\```'````>;P`
M`!(```"!O```#````)2\```-````H;P``!P```"OO```!0```,R\```&````
MTKP``!T```#9O```*````/>\```+````(+T```,````LO0``#````#"]```"
M````/;T```T```!`O0``$P```$Z]```+````8KT``!<```!NO0``&0```(:]
M```%````H+T```H```"FO0``!@```+&]```0````N+T```L```#)O0``"0``
M`-6]```4````W[T```P```#TO0``#0````&^```;````#[X``!0````KO@``
M&````$"^```@````6;X``!P```!ZO@``&P```)>^```5````L[X``!D```#)
MO@``&@```..^```8````_KX``!\````7OP``&0```#>_```'````4;\```@`
M``!9OP``#0```&*_```%````<+\``#X```!VOP``-0```+6_``!6````Z[\`
M``P```!"P```"````$_````+````6,````4```!DP```+0```&K````S````
MF,```#L```#,P```%P````C!```,````(,$``#`````MP0``!@```%[!```0
M````9<$```@```!VP0``"````'_!```8````B,$```@```"AP0``"````*K!
M```.````L\$```<```#"P0``$0```,K!```A````W,$``!(```#^P0``"0``
M`!'"```$````&\(``!D````@P@``#P```#K"```/````2L(```X```!:P@``
M"0```&G"```-````<\(```P```"!P@``#0```(["```4````G,(```P```"Q
MP@```@```+["```%````P<(```8```#'P@``"@```,["```@````V<(``"``
M``#ZP@``%@```!O#```@````,L,``!D```!3PP``!0```&W#```)````<\,`
M`!0```!]PP``!P```)+#```%````FL,```<```"@PP``"@```*C#```%````
ML\,```8```"YPP``!@```,##```+````Q\,```@```#3PP``!P```-S#```.
M````Y,,```L```#SPP```@```/_#```)`````L0``"0````,Q```,0```#'$
M```@````8\0``!P```"$Q```'````*'$```C````OL0``"````#BQ```,P``
M``/%``!'````-\4``"X```!_Q0``+````*[%```X````V\4``"H````4Q@``
M*@```#_&```J````:L8``!8```"5Q@``(0```*S&``!"````SL8``#@````1
MQP``"````$K'```$````4\<```P```!8QP``"0```&7'```"````;\<``%X`
M``!RQP``"0```-''```$````V\<```<```#@QP``!0```.C'```1````[L<`
M`!``````R````@```!'(```&````%,@```<````;R```!@```"/(```4````
M*L@```P````_R```!@```$S(```#````4\@```0```!7R```!@```%S(```'
M````8\@``!H```!KR```(P```(;(```M````JL@```T```#8R```'````.;(
M```/`````\D```,````3R0``"````!?)```)````(,D``!L````JR0``"@``
M`$;)```'````4<D```<```!9R0``#0```&')```1````;\D``!<```"!R0``
M$0```)G)```F````J\D``!(```#2R0``$P```.7)```7````^<D```H````1
MR@``!P```!S*```'````),H```D````LR@``!@```#;*```'````/<H```@`
M``!%R@``$````$[*```-````7\H``!H```!MR@``)````(C*```/````K<H`
M``L```"]R@```@```,G*```#````S,H```4```#0R@``!P```-;*```*````
MWLH``!$```#IR@``"@```/O*```;````!LL```8````BRP``"P```"G+```*
M````-<L``!4```!`RP``%@```%;+```0````;<L``#,```!^RP``-P```+++
M``!/````ZLL```X````ZS```#0```$G,```/````5\P```(```!GS```!```
M`&K,```&````;\P``!@```!VS```!0```(_,```#````E<P``!````"9S```
M$````*K,```G````N\P``#,```#CS```,@```!?-```1````2LT```X```!<
MS0``$````&O-``"!````?,T```H```#^S0``70````G.``!>````9\X``!P`
M``#&S@``$P```./.```<````]\X``"`````4SP``0````#7/```F````=L\`
M`!4```"=SP``"@```+//```$````OL\```8```##SP``"````,K/```4````
MT\\```X```#HSP``!````/?/```,````_,\```8````)T```!@```!#0```(
M````%]````@````@T```#0```"G0```&````-]````P````^T```#````$O0
M```-````6-````P```!FT```$````'/0```)````A-````4```".T```"@``
M`)30```#````G]````0```"CT```$0```*C0```(````NM````@```##T```
M$````,S0```9````W=````D```#WT```!0````'1```'````!]$``!0````/
MT0``"````"31```)````+=$```$```#3`0``'@$``!D#``"W`@``H@(``!\`
M````````S0(```````````````````````#=`@````````````!E`P``````
M`$`!``!7`@```````$D```"&`@``B@$``"<#``"'````2P```$\#````````
M`@(``($````^`P``1P````````!H`0``,@```)$!``![````\0```$,#``"3
M````D@````(#```S`0``$````%L!``"K````M@(``%8!```$`P``````````
M``!2`P``D@(``'(!``!,````.@,``,0!``#^````P0````X#````````0`(`
M``````"-````7`,``#\`````````5`(````````=`@``C0$``.`"``"S`0``
M;@(``&\!```6`0``Z`(```P!``#1`@```````(T#````````T0$``)P```"Y
M`0``"0(`````````````%P````````#I`````````-0``````````````,H!
M```>```````````````````````````````)`0``A`$``&L#``!B````````
M`"4#````````R`(``&0!````````<`$``````````````````)\!``#!`0``
M!`(``!X#``#)`@``G`(``%\````9`0``=@,``.H!``#U`0``?`$``)8````(
M`0``WP$`````````````S`(``-$```#.````$0,```8"````````6@``````
M``!\`@``J0$``)\``````````````&T!````````Q`(``/`!``"K`0``H0(`
M````````````L0(``*8"```-`````````"@!``!$`````````(P"```A`@``
MK````!,"````````+@(``&T"```4`0``PP```!L!````````,P``````````
M`````````$8#```6`@``NP$``-H!```+`@```````.@```"I````O@```*$!
M``#7`0``CP$``&P#``!X`@``1`,``)D"``!U`````````!(````1`0``4@(`
M`!P`````````L@````````#C`0``ZP```,8"```]`@``(`(``(X!```.````
M,0```!0"``#/`0``-0$``'L"``!W`@``````````````````60````````"!
M`P``80(``$,!```K`0``Y`(```````!(`P```````'("````````0@$``/D"
M``#9`@``D@$``*P"``#K`@``A0(```0!````````BP,``.,```!!````"@,`
M`&@#````````)0(``/````"'`P``$@,``'D"```Y`0```````*H```#$````
M>P,``$T!````````&0```/`"``#S`@``E`$``(@`````````Z0$```T"``!Z
M`@```````%X````"````$P```(("````````F`````````#<`@``<P``````
M```U`@``*0,``),!``!0````(`,`````````````)@```#0!````````````
M``````#'`````````&T#``!?`@``9@(````````<`P```P(``'D!``"1````
M-P$``/0!```^`@``G0$``'`#``#U`@``^@(``.\"`````````````+H!````
M``````````````#M`````````$$"````````+P(````````;````$`$`````
M``!&`@``+0(``-H"``#)`0``)````,P!``#X`0``X0$``((!````````/0``
M`'T#`````````````)D``````````````(,```!'`@```````-\"````````
M`````'D```!L`@``,`,```````!(`@``#@(``&`````/`@``/`,````````V
M`@``<@````8#``#T`@``O0```,````"U````$P$``($!````````_`(``&8!
M``"L`0``D`(``'\!``"?`@``C`,``$("``!]`````````&P````1`@``L@(`
M`-8!``!9`P``(`$``!<"```X`@``&@(``"L"```8`P``P@$``+8!```*````
M"P```'@#`````````````-D!``#]````B@`````````+`P``[0(``,\"``"S
M````3P$``&0#``"I`@``]0```$$#``````````````````!F````)0$`````
M``!V`0``Z0(``-L"``!G`@`````````"``#Y`0``60$``*T```"Z````B`$`
M`*@"`````````````#H"``"5`@``OP(``,L```"#`0````````````"4`@``
MQ0$````````H````.`,``'D#``"N````SP```"P"``#&`0``80```',#```,
M`@```````+\!``"0``````````````!0`P``DP(``)8"`````````````/@"
M``!,`P``X@$``*T"````````&@```,4````Z````EP$``'<!``!3````YP$`
M`$@```!``P``H@$```````!2`0``B0(````````<`@```````)@"````````
MG0```!4`````````'P,`````````````20,``'$"``#6`````````$T#```O
M````50,``#<"``#E`@``H0```'H!``"P`@``5`$```````"T`````````.0`
M``!C`@``V`$``!\!``#"`@````````````!A`P``90$```````!F`P``````
M`+\```!,`@``````````````````'@(```````#M`0``*@(``.X"``"7`@``
M=0(``$X"``#A`@``Z@(``!`#````````1P,``*0```"R`0``````````````
M````7@,``&H#`````P``S`````````".````C`$``.@!``![`0``````````
M``#4`0``A0$```````#2`@``-````,,!``"O`0``70(``/\```"U`@``````
M`*H"````````*`,``.,"````````40$``"<`````````#`,``&D#```&`0``
M]@```',"``!$`@``+0$``!@````K`P``HP```&`#```J`P``I0$``$<!````
M````2P(`````````````L0$``"D````Y`@``.````*`"```4`P``^P``````
M``#5`@``7@$``$4#``"[`@```````%<#```_`0``M`$``(\"``#]`0``````
M`%,#``".`P```````#L!````````-@$````````7`P``B0$`````````````
MW@(``&,```#=`````````$0!``#>````!0```$T"````````?P(`````````
M````AP$``%H#```U`P``S@$```P````V`P``?@```#`````L`0``^P$``*``
M````````'0,`````````````R0```#0"``!*`````````(8!``!]`@``U0``
M``````!O`P``(@(``",!```L````5P````````!`````;0```+<!``!\`P``
M<@,````````]`0```````#("``#0`````````/(!``#L`@``'0```&0```!L
M`0``L0```#,"```A`0```````(<"``!I`@````````````#V`@``:0$``"H`
M````````2@$``%`"``"5`0``N0```(\```#K`0``O````$X#``".`@``[P$`
M`&X````Q`@``+P,``/X"```_`@``0P(``$8```!S`0````````````!T````
MKP(``"$`````````4P(``````````````````/$"``":`@``0@,````````R
M`0````````T#````````C`````````#3````Q@```.P```!8````O@$`````
M``#V`0``"@(``#D```#(`0````````````"+`@``L`$```````"%`P``<```
M``@#``!;`@``10(``/X!````````A@````X!``!:`@``Q0(``#X!```"`0``
M&P,``.4```#.`@``-@```)X"``!9`@``=`(``!D"````````8@(````````'
M`0````````@`````````W@$``,L"``!@`0```````!4#``";`0``PP(``(,"
M````````)P(``$H"````````A@,``%0```";`@``O0(```\!````````N`$`
M`&L"``#7`@```````#<`````````A`(`````````````(0,``%0#````````
M:@```"(!`````````````#`"```#``````````````"]`0``)@,```````!E
M`@``U0$``/T"`````````````%L#``"@`0``*0(``&H"``!^`0``T`(``"0#
M````````6`,``%8"``#G`````````.\``````````````$L!``!5`@``````
M`"````!>`@``N`(``.X````2`0``U@(```L!``!1````<0$`````````````
MN````'\#````````@`,``(````!.````+`,``#\#``!V`@``*P```/@```"M
M`0``7P,``$@!```:`0``^@```$\"```X`0```````"H!````````,P,``"<!
M```U````!@```%(``````````````+0"``#_`@``8P,``,$"``#Z`0``````
M``$!``#R`@```````(D#``">`0``\P$``%P"```]`P``G`$``*0"``"V````
MY@(```````#A`````````-0"```%`P``.P(```````!-````&`$```\#``!<
M`0```````,<!`````````````*4````;`@``)@$``(4```":`0```````-L`
M``#(````Y`$`````````````MP```",````C`P``(P(``"T#``"=`@``0@``
M````````````_P$```````"G`@````````````````````````0```"1`@``
M*`(````````'````E````"X```!/````,@,``'4#``!B`0``@0(``&,!``"+
M`0``#P```-\```!D`@``%@,``/0`````````3@$``+H"``">````Z@``````
M````````C0(``'T!``"E`@``40(```$#``!1`P``[`$``%H!````````%```
M`&H!``#\```````````````O`0``I@```!H#``!6````@P,``%\!```0`@``
MUP```%8#``"8`0``!0$```````!8`@``2P,``/$!```P`0``(@,``'<```!Q
M`````````*@!```3`P```````````````````````&`"````````P`(``$D"
M````````F@``````````````V0```%L````\`0``B`(```````!!`0``\@``
M`+P!````````V`````<#``#N`0````````````!I````?`````$"```[`P``
M;P(``+`````[````;@$```````"$`P``,0,```````#+`0``)0`````````I
M`0```````#P``````````````*8!````````:P$````````T`P``<0,``+X"
M``""````W0$``/<```""`P``\P````````")````R@```'`"``!T`P``"0``
M`%@!``#<`0``+0```'\````1````=P,``'H#``!*`P``M0$``*0!```5`0``
M%0(```````"J`0``/@```.````#B`@``)`$``+D"```N`0``JP(``(`!``!,
M`0``B@,``,`!```Q`0``;@,``&(#``#*`@```````+L````Y`P``T@$`````
M``````````````````#3`@``)`(``(`"````````IP```&4`````````````
M`*X!``#:````0P```)4```#8`@``$@(``%T!`````0``Y@$``'X"``!=`P``
M)@(``.4!````````W````$4```#"````;P````````";````+@,``$4!``!^
M`P``"@$```````!0`0``9P```%T````%`@```````.(`````````%@```'4!
M``#[`@```````)8!````````=`$``,<"``!5`0```````/<"``"0`0``&`(`
M`$8!``"N`@``VP$``+,"```B````.@$``*<!``"B````%P$``(H"``#2````
M'P(```````!K`````````*,"``#0`0``20$``&@"````````>`$``.`!``"(
M`P``"`(``&<!``#\`0``5P$``*@````=`0``S0```'@```#-`0````````,!
M``!<````-P,``(L`````````!P(````````<`0```P,```````"O````Y@``
M`)D!````````#0$``#P"``!G`P````````D#``"\`@``80$``'H`````````
M`````(0`````````YP(```````#Y`````````%4```"7````4P$``'8```!H
M````HP$``/<!````("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H)7,@
M9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D
M87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`B)7,B(&ES(&YO="!A('9A
M;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES
M=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"5D("5S(&%N9"`E<P`E<R`M
M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG97)P<FEN=``E<R!+
M0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S
M(%-E='5P`"5S(%-I9VX@57``)7,@86QR96%D>2!E>&ES=',N`"5S(&9I;&4@
M<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@
M0F]O:P`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+2T@<V5L
M96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S
M`#Q0<F5V:6]U<P!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+@!!32]030!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8V-O=6YT
M(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9"!%=F5N
M=`!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`
M061D(&$@;F5W(&5V96YT`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D
M9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY
M(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!
M;&%R;0!!;&%R;2!$871E`$%L87)M(%-P86X@*&UI;G5T97,I`$%L87)M(%1I
M;64`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L;"!!=71H96YT:6-A=&5D(%5S
M97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!D87D`06QL(&1A
M>2!E=F5N=`!!;&P@979E;G1S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!
M;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@
M24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA
M=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5X=#H`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!
M;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`07!P;&EC871I;VX`
M07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<')O=F4`07!R:6P`07)C:&EV92!&
M:6QE(%-I>F4`07)C:&EV92!.86UE`$%R9V5N=&EN80!!<FUE;FEA`$%R=6)A
M`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/P!!=`!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`
M075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P
M('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA
M8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N
M9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D
M(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)
M4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S
M`$)L;V-K(%1Y<&4`0F]L:79I80!";V]K;6%R:W,`0F]S;FEA(&%N9"!(97)Z
M96=O=FEN80!";W1H`$)R87II;`!"=6QG87)I80!#35,`0U)#`$-?96QL(%!R
M;W!E<G1I97,N+BX`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P
M87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A
M`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F
M:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%P92!697)D90!#871E
M9V]R:65S(&%N9"!,86)E;',`0V%T96=O<GD`0V5L;"!0:&]N90!#96QL(%!R
M;W!E<G1I97,`0V5L;"!P<F]P97)T:65S`$-E;&QP:&]N90!#96QT:6,@*$E3
M3RTX.#4Y+3$T*0!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T
M:69I8V%T92!/=VYE<@!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAO;W-E(&$@<&%S<W=O<F0`
M0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S
M.@!#:')I<W1M87,@27-L86YD`$-L:6-K('1O($-O;G1I;G5E`$-L;W-E(%=I
M;F1O=P!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R
M`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N
M`$-O;'5M;B!T:71L97,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`
M0V]M;W)O<P!#;VUP86YY`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U=&5R
M<P!#;VYD:71I;VYS`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O
M;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N
M;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@
M*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]P
M>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92X`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I
M=&EN9RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!U
M;FQI;FL@(B5S(BX`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R
M+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1R>0!#<F5A
M=&4@82!.97<@179E;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE
M`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE
M`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T
M`$-Y<')U<P!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$86EL>3H@4F5C=7)S
M(&5V97)Y`$1A=&4`1&%Y`$1A>2AS*0!$95]L971E($-O;'5M;@!$96-E;6)E
M<@!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!097)M
M:7-S:6]N<P!$969A=6QT('!E<FUI<W-I;VYS`$1E;&5T92!%=F5N=`!$96QE
M=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M
M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E
M;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L
M971E('1H92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!P97)M:7-S:6]N(&%N
M9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96YM87)K`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:FEB;W5T:0!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E
M<P!$<G5G<P!$=7)A=&EO;@!%+4UA:6P`16-U861O<@!%9&ET("5S`$5D:70@
M1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M
M:7-S:6]N<R!F;W(@)7,`16=Y<'0`16P@4V%L=F%D;W(`16UA:6P`16UA:6P@
M861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E
M+@!%;7!T>2!R97-U;'0N`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE
M;G4_`$5N9"!$871E`$5N9"!/;@!%;F0@5&EM90!%<75A=&]R:6%L($=U:6YE
M80!%<FET<F5A`$5R<F]R`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%
M=&AI;W!I80!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP;W)T`$5X<&]R
M="!#86QE;F1A<@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B
M)7,B+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86QK;&%N9"!)<VQA;F1S
M("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9E
M8G)U87)Y`$9I:FD`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9O;V0`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9R
M`$9R86YC90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S`$9R:61A>0!&<F]M`$=A8F]N`$=A;6)I
M80!'86UE`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=O`$=O;V=L92!396%R
M8V@`1W)E96-E`$=R965N;&%N9`!'<F5N861A`$=R;W5P<P!'=6%D96QO=7!E
M`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U:6YE80!'=6EN96$M0FES<V%U
M`$=U>6%N80!(5$U,`$AA:71I`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<P!(96QP`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A
M<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S("(E<R(`2&]U<BAS*0!(=6YG87)Y`$EC96QA;F0`26-O;G,@
M3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!);6%G97,`
M26UP;W)T+T5X<&]R="!#86QE;F1A<@!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);F1I80!);F1O;F5S:6$`26YF;P!);G-E<G0@26UA
M9V4`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS
M92!K97DN`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD
M`$ES<F%E;`!)<W-U97(`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IO
M<F1A;@!*=6QY`$IU;F4`2V%Z86MH<W1A;@!+96YY80!+97D@0W)E871I;VX`
M2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97EW;W)D<P!+
M:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+=7=A:70`2WER9WEZ<W1A;@!,
M85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S
M="!L;V=I;CH@3F5V97(`3&%S="!W965K`$QA='9I80!,97-O=&AO`$QI8F5R
M:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI;6ET
M('1H92!T:6UE('-P86X@=&\@97AP;W)T.@!,:7-T($AE;'`@5&]P:6-S`$QI
M<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&AU86YI80!,;V%D:6YG+BXN
M`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN
M`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2X`3&]G:6X@9F%I;&5D+@!,;W<`3'5X96UB;W5R9P!-30!-3U1$`$U31P!-
M86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8`36%D86=A<V-A<@!-86EL`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<F-H`$UA<F=I;@!-87)S:&%L
M;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N
M:6$`36%U<FET:75S`$UA>0!-87EO='1E`$UE971I;F<`365N=2!M;V1E.@!-
M97)G92!C96QL<P!-97-S86=E`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE>&EC;P!-:6UE(%1Y
M<&4`36EN=71E*',I`$UO`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U
M;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYD87D`36]N9V]L
M:6$`36]N=&@`36]N=&AL>0!-;VYT:&QY.B!296-U<G,@979E<GD`36]N='-E
M<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO=F4@1&]W;@!-;W9E($QE9G0`
M36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ
M=64`37D@06-C;W5N=`!->2!0;W)T86P`37EA;FUA<@!.86UI8FEA`$YA=7)U
M`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='=O
M<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($5V96YT
M`$YE=R!:96%L86YD`$YE=W,`3F5X="!-;VYT:`!.97AT(&1A>0!.97AT(&]P
M=&EO;G,`3F5X="!W965K`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI=64`
M3F\@8VAA;F=E+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@)7,N`$YO(&5N9"!D871E`$YO(&9I;&4@=7!L;V%D960`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N
M=&EC871I;VXN`$YO;F4`3F]R9F]L:R!)<VQA;F0`3F]R=V%Y`$YO="!I;7!L
M96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1I8V4`
M3F]V96UB97(`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3TL`
M3V-T;V)E<@!/9F9I8V4`3VUA;@!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N`$]P96X@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F
M;W(@)7,`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI
M>FEN9P!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N
M<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I
M9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC
M($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3
M:&5L;`!07TA0(%-H96QL`%!A:VES=&%N`%!A;&%U`%!A;F%M80!087!U82!.
M97<@1W5I;F5A`%!A<F%G=6%Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C
M=`!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O
M<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C
M;&EP8F]A<F0`4&%T=&5R;@!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!0
M97)M:7-S:6]N`%!E<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O<FUA=&EO
M;@!097)U`%!H:6QI<'!I;F5S`%!H;VYE`%!I=&-A:7)N`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M
M96YT+@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!O;&%N9`!0;W)T=6=A;`!0<F5V:65W`%!R979I;W5S
M(&1A>0!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN
M9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="D`4F5C=7(@56YT:6P`4F5C=7)R96YC92!$871A`%)E8W5R
M<F5N8V4@16YD($1A=&4`4F5C=7)R96YC92!);G1E<G9A;`!296-U<G)E;F-E
M(%1Y<&4`4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W965K
M;'D`4F5C=7)S('EE87)L>0!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M;W1E(%-E<G9E<G,`4F5M;W9E
M`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!P86ER`%)E;6]V
M92!T:&4`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<V5T`%)E<V5T
M(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S970@=&\@1&5F875L
M=',`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)I8V@@5&5X
M="!%9&ET;W(@3W!T:6]N<P!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A
M=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W('!R;W!E<G1I97,`4G5S<VEA;B!&
M961E<F%T:6]N`%)W86YD80!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!344P@4VAE;&P`
M4U-(`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N
M9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N
M`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;6]A`%-A;B!-
M87)I;F\`4V%T=7)D87D`4V%U9&D@07)A8FEA`%-A=F4@(B5S(@!3879E("5S
M`%-A=F4@179E;G0`4V%V92!/<'1I;VYS`%-E;&5C="!&:6QE<P!396QE8W0@
M=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!3
M96QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE(&9I<G-T('=E
M96MD87DZ`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE
M;2!297!O<G0`4V5N96=A;`!397!T96UB97(`4V5R:6%L($YU;6)E<@!3970`
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E>6-H96QL97,`
M4VAO<G0@4W5M;6%R>0!3:&]W`%-H;W<@9'5E('1A<VMS(&EN('1H92!C86QE
M;F1A<C\`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3
M:&]W(&]N;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S970_`%-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-I97)R82!,96]N90!3:6=N('5P
M(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I
M=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`
M4VQO=F5N:6$`4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]U=&@@069R:6-A
M`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3<&%I;@!3<&%M`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P
M;&ET(')O=P!3<FD@3&%N:V$`4W1A<G0@1&%T90!3=&%R="!/;@!3=&%R="!4
M:6UE`%-T871E(&]R(%!R;W9I;F-E`%-T<F5E="!!9&1R97-S`%-U`%-U8FIE
M8W0`4W5B;6ET`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@
M(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5D86X`4W5N9&%Y`%-U
M;G)I<V4O4W5N<V5T`%-U<FEN86UE`%-W87II;&%N9`!3=V5D96X`4W=I='IE
M<FQA;F0`4WER:6%N($%R86(@4F5P=6)L:6,`5&%I=V%N`%1A:7=A;BP@4')O
M=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5X="!/;FQY`%1H
M`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE
M(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A<G0@9&%T92X`
M5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E
M<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@
M8F5E;B!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S
M(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V
M:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W97)E(&YO(&5V96YT<R!T
M;R!E>'!O<G0N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+@!4:'5R<V1A>0!4:6UE`%1I;64@9F]R;6%T`%1I=&QE`%1O
M`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N
M`%1O9&%Y`%1O9V\`5&]K96QA=0!4;VYG80!4<FEN:61A9"!A;F0@5&]B86=O
M`%1R=64@;W(@9F%L<V4`5'4`5'5E<V1A>0!4=6YI<VEA`%1U<FME>0!4=7)K
M:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5V86QU`%1Y<&4`55),
M.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`56YI=&5D($%R86(@16UI
M<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FMN;W=N`%5N
M;F%M960`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&QO860`57)U
M9W5A>0!5<V5R($EN=&5R9F%C90!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R
M871I;VX`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`
M57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB
M96MI<W1A;@!686-A=&EO;@!686YU871U`%9E;F5Z=65L80!697)S:6]N`%9I
M970@3F%M`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W
M(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S
M+"!5+E,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5B`%=E9&YE
M<V1A>0!7965K`%=E96L@)60`5V5E:RAS*0!7965K;'D`5V5E:VQY.B!296-U
M<G,@979E<GD`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T
M97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!7;W)K(%=E96L`65D`65E960!996%R;'D`665A
M<FQY.B!296-U<G,@979E<GD`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@16UA:6P@
M061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT
M:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I
M80!:86ER90!:86UB:6$`6FEM8F%B=V4`6U!R;V)L96T@4F5P;W)T70!?061M
M:6YI<W1R871I;VX`7T-,20!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%],
M;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M
M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]5<V5R<P!A9&1R97-S
M(&)O;VL`8V%L96YD87(`9&%Y`&1A>2AS*0!D87ES`&9I;&4`;6]N=&@H<RD`
M;F%M90!N;W1E<&%D`&]N('1H92!S86UE(&1A=&4`;VX@=&AE('-A;64@=V5E
M:V1A>0!U;FYA;65D`'9#87)D`'=E96L`=V5E:RAS*2!O;CH`=V5E:W,`>65A
M<BAS*0!0<F]J96-T+4ED+59E<G-I;VXZ(#`N,"XT"E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,BTP,2TR,B`R,CHP,"LP,3`P"DQA<W0M5')A;G-L871O<CH@36%C:65K(%5H
M;&EG(#QM=6AL:6=`=7,N961U+G!L/@I,86YG=6%G92U496%M.B!-52`\;75H
M;&EG0'5S+F5D=2YP;#X*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`H`)7,@+2!G;W1O=WD@9&\@=WEK;VYA;FEA
M(&-Y:VQI8WIN>6-H(&]P97)A8VII('IA>FYA8WIO;GEC:"!P;VYIOV5J+@`@
M*"5S(&1N:2!T96UU*0`H:VQU8WH@9&]S=.IP=2`E<RD`("AW(&-IL6=U("5S
M(&1N:2D`("AD>FFV*0`@*&IU=')O*0`@*'=C>F]R86HI`"(E<R(@;FEE(&IE
M<W0@<')A=VEDLV]W>6T@=WEB;W)E;2X`(B5S(B!N:64@:F5S="!S:V]N9FEG
M=7)O=V%N>2!W(')E:F5S=')Z92!(;W)D92X`561ALV\@<VGJ(&1O9&'F("(E
M<R(@9&\@9W)U<"X`561ALV\@<VGJ(&1O9&'F("(E<R(@9&\@=7!R87=N:67Q
M+@`B)7,B(&YI92!Z;W-T8;,@=71W;W)Z;VYY.B`E<RX`)60@)7,@:2`E<P`E
M<R`M(%5W86=A`$%D;6EN:7-T<F%C:F$@)7,`)7,@;V1C:7-K('!A;&-A`"5S
M(&M"`"5S("T@;W!E<F%C:F4@8WEK;&EC>FYE("T@<&]T=VEE<F1Z96YI90!+
M;VYF:6=U<F%C:F$@)7,`4F5J97-T<F%C:F$@)7,`)7,@:G6_(&ES=&YI96IE
M+@!I;7!O<G0@<&QI:W4@)7,@=WEK;VYA;GD@<&]P<F%W;FEE`"5S(&IE<W0@
M=WEM86=A;GD`)7,@;6EN=70`)7,@;FEE>FYA;&5Z:6]N>2X`)7,@9&\@)7,@
M>B`E<P!+<VFQOVMA(&%D<F5S;W=A("5S`$YO=&%T;FEK("5S`$QI<W1A('IA
M9&'Q("5S`"5S.B`E<P`M+2!W>6)I97)Z("TM`#$R+6=O9'II;FYY(&9O<FUA
M=``R-"UG;V1Z:6YN>2!F;W)M870`,C0@9V]D>BX`/%!O<')Z961N:0!.87-T
ML7!ILR!BL[%D(&MR>71Y8WIN>0!0;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L
M:6-Z;GD@4$=0(&1O('IA<WIY9G)O=V%N:6$@=VEA9&]M;[9C:2X`4&]T<GIE
M8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!S<')A=V1Z96YI82!P
M;V1P:7-A;F5J('=I861O;6^V8VDN`%!O=')Z96)N92!SL2!K;'5C>B!P=6)L
M:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A>B!H87.S;R!D;R!O
M9'-Z>69R;W=A;FEA('=I861O;6^V8VDN`%!O=')Z96)N92!SL2!K;'5C>B!P
M=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A>B!H87.S;R!D
M;R!P;V1P:7-A;FEA('=I861O;6^V8VDN`%!O=')Z96)N92!SL2!K;'5C>B!P
M=6)L:6-Z;GD@4R]-24U%+"!K;'5C>B!P<GEW871N>2!3+TU)344@;W)A>B!H
M87.S;R!D;R!O9'-Z>69R;W=A;FEA('=I861O;6^V8VDN`%!O=')Z96)N92!S
ML2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C>B!P<GEW871N>2!3+TU)
M344@;W)A>B!H87.S;R!D;R!P;V1P:7-A;FEA('=I861O;6^V8VDN`%!O=')Z
M96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!334E-12!D;R!Z87-Z>69R;W=A
M;FEA('=I861O;6^V8VDN`$%-+U!-`$\@='EM(&5D>71O<GIE`$\@<')O9W)A
M;6EE+BXN`$AA<[-O(&1O(&MO;G1A`$MO;G1O('IA8FQO:V]W86YE+@!+;VYT
M80!$;V1A:B!Z9&%R>F5N:64`1&]D86H@='5T86HZ`$1O9&%J(&YO=[$@9W)U
M<.H`1&]D86H@;F]W92!U<')A=VYI96YI90!$;V1A:B!N;W=E('ID87)Z96YI
M90!$;V1A:B!N;W=E9V\@=;]Y=&MO=VYI:V$Z`$1O9&%J(&MO;'5M;NH`1&]D
M86H@;F]W>6-H(&-ZLV]N:_-W`$1O9&%J('!A<NH`1&]D86H@;65N=2`E<R!D
M;R!P87-K82!-;WII;&QI`$1O9&%J(&1O(&MS:;&_:VD@861R97-O=V5J.@!$
M;V1A:B!D;R!M;VIE:B!K<VFQ>FMI(&%D<F5S;W=E:@!$;V1A:B!UOWET:V]W
M;FEK80!$;V1A;F\@(B5S(B!D;R!S>7-T96UU+B!-;[]E<WH@<VGJ('IA;&]G
M;W=AYBX`1&]D87=A;FEE('6_>71K;W=N:6OS=R!J97-T('=YLV%C>F]N92X`
M061R97,`061M:6YI<W1R86-J80!296ML86UY`$%F9V%N:7-T86X`06QA<FT`
M1&%T82!A;&%R;74`0WIA<R!T<G=A;FEA(&%L87)M=2`H;6EN=71Y*0!#>F%S
M(&%L87)M=0!!;&)A;FEA`$%L9VEE<FEA`$%L:6%S`%=S>GES8WD@=7=I97)Z
M>71E;&YI96YI('6_>71K;W=N:6-Y`%=S>GES=&MI92!G<G5P>0!7<WIY<W1K
M:64@=7!R87=N:65N:6$`0V&S>2!D>FEE\0!:9&%R>F5N:64@8V&S;V1Z:65N
M;F4`5W-Z>7-T:VEE('ID87)Z96YI80!0;WIW\VP@;F$@=VEE;&4@861R97/S
M=P!*=;\@:7-T;FEE:F4`06QT97)N871Y=VYY(&QO9VEN($E-4U``06QT97)N
M871Y=VYY(&AA<[-O($E-4U``06QT97)N871Y=VYA(&YA>G=A('6_>71K;W=N
M:6MA($E-4U``06QT97)N871Y=VYY(&%D<F5S(&5M86EL`$%L=&5R;F%T>7=N
M>2!T96MS=#H`6F]S=&&S82!P;V1A;F$@;FEE<')A=VEDLV]W82!W87)T;[;F
M+@!!;F1O<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;6]W92!0<F]X>0!/9'!O
M=VEE9+P`06YT87)K='ED80!!<&QI:V%C:F$`07!L:6MA8VIA(&=O=&]W80!:
M871W:65R9+P`:W=I96-I9?$`5VEE;&MOMN8@87)C:&EW=6T`3F%Z=V$@87)C
M:&EW=6T`07)G96YT>6YA`$%R;65N:6$`07)U8F$`4&]P<F^V(&\@<&]T=VEE
M<F1Z96YI92!P<GIE9"!W>6MO;F%N:65M(&]P97)A8VII(&-Y:VQI8WIN>6-H
M/P!O`$%T<GEB=71Y`'-I97)P:67Q`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?
M8WER=7,Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA
M(&EM87`N`$%U=&A?8WER=7,Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@
M<F]Z<WIE<GIE;FEA(&EM87`N`$%U=&A?9G1P.B!.:64@>FYA;&5Z:6]N;R!W
M>6UA9V%N96=O(')O>G-Z97)Z96YI82!&5%`N(%-K;VUP:6QU:B!02%`@>B!P
M87)A;65T<F5M("TM96YA8FQE("X`075T:%]I;6%P.B!.:64@>FYA;&5Z:6]N
M;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!)34%0+@!!=71H7VMR8C4Z($YI
M92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&MR8C4N`$%U
M=&A?;&1A<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N
M:6$@3$1!4"X`075T:%]L9&%P.B!.:64@=61ALV\@<VGJ('5S=6ZQYB!UOWET
M:V]W;FEK82`E<P!!=71H7VQD87`Z($YI92!U9&&S;R!S:>H@=6%K='5A;&YI
MYB!UOWET:V]W;FEK82`E<P!!=71H7VUC86PZ($YI92!Z;F%L97II;VYO('=Y
M;6%G86YE9V\@<F]Z<WIE<GIE;FEA($U#04PN`$%U=&A?<VUB875T:#H@3FEE
M('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@<VUB875T:"X`
M57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ`%5W:65R>GET96QN
M:65N:64@;FEE('!O=VEO9+-O('-IZBX@)7,`57=I97)Z>71E;&YI96YI92!O
M9')Z=6-O;F4@<')Z97H@<V5R=V5R(%)!1$E54RX`57=I97)Z>71E;&YI96YI
M92!D;R!S97)W97)A($944"!N:64@<&]W:6]DLV\@<VGJ+@!$;W-TZG!N92!P
M;VQA.@!!>F5R8F5J9+]A;@!7>6WS=VMI($)/1D@`5+-O`$MO;&]R('2S80!:
MLV4@:&%SLV\@2V5R8F5R;W-A+@!:LV$@;F%Z=V$@=;]Y=&MO=VYI:V$@2V5R
M8F5R;W-A`%=Y<W!Y($)A:&%M80!"86AR86IN`$)ALW1Y8VMI("A)4T\M.#@U
M.2TQ,RD`0F%N9VQA9&5S>@!":6&S;W)UM@!"96QG:6$`0F5L:7IE`$)E;FEN
M`$)E<FUU9'D`0FAU=&%N`'5R;V1Z:6YY`%5S=&%W:65N:6$@8FQO:W4`5'EP
M(&)L;VMU`$)O;&EW:6$`6F%KLV%D:VD`0F^V;FEA(&D@2&5R8V5G;W=I;F$`
M3V)A`$)R87IY;&EA`$)ULV=A<FEA`$--4P!#4D,`5[-AMF-I=V^V8VD@:V]M
M\W)K:2XN+B`H7V,I`$MA;6)O9+]A`$MA;65R=6X`3FEE('5D8;-O('-IZB!Z
M<F5S971O=V'F(&AA<[-A(&%U=&]M871Y8WIN:64L('-K;VYT86MT=6H@<VGJ
M('H@861M:6YI<W1R871O<F5M+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ
M('H@<V5R=V5R96T@24U!4#H@)7,`2V%N861A`%IA;FEE8VAA:@!!;G5L=6H@
M<F%P;W)T(&\@<')O8FQE;6EE`$YI92!M;[]N82!S:V%S;W=AYB!P;&EK=2`B
M)7,B`$YI92!U9&&S;R!S:>H@>FYA;&6\YB!K871A;&]G=2!T>6UC>F%S;W=E
M9V\N`$YI92!M;[]N82!S:V%S;W=AYB!K871A;&]G=2`B)7,B`%=Y<W!Y(%II
M96QO;F5G;R!0<GIY;+%D:V$`2V%T96=O<FEE(&D@;WIN86-Z96YI80!+871E
M9V]R:6$`5&5L+B!K;VTN`%>S8;9C:7=OMF-I(&MO;?-R:VD`5[-AMF-I=V^V
M8VD@:V]M\W)K:0!496PN(&MO;2X`0V5L='EC:VD@*$E33RTX.#4Y+3$T*0!2
M97!U8FQI:V$@IG)O9&MO=V5J($%F<GEK:0"F<F]D:V]W;V5U<F]P96IS:VD@
M*$E33RTX.#4Y+3(I`%-Z8WIE9_.S>2!C97)T>69I:V%T=0!7LV&V8VEC:65L
M(&-E<G1Y9FEK871U`$-Z860`6FUI9?$`6FUI9?$@:6UIZBP@;F%Z=VES:V\@
M:2!A9')E<RP@:W3S<GD@:6YN:2!W:61ZL2!W(%1W;VEC:"!L:7-T86-H(&5M
M86EL+@!3<')A=V2\(&QI;FLN+BX`6F%Z;F%C>B!P;WIY8VKJ(&1L82!K=/-R
M96H@8VAC97-Z('=Y:V]N8>8@;W!E<F%C:NHN`$-H:6QE`$-H:6YY`%!O9&%J
M(&AA<[-O`%!O9&%J(&YA>G?J('6_>71K;W=N:6MA`%=Y8FEE<GH@<W!O<_-B
M('=YMG=I971L86YI82!D870Z`%=Y<W!A($)OOV5G;R!.87)O9'IE;FEA`$ML
M:6MN:6H@8GD@:V]N='EN=6]W8>8`6F%M:VYI:B!O:VYO`%=Y<W!Y($MO:V]S
M;W=E("A+965L:6YG82D`4V-H;W=A:B!P87-E:P!+;VQU;6)I80!+;VQO<@!7
M>6)I97)Z(&MO;&]R`%=Y8O-R(&MO;&]R=0!4>71ULWD@:V]L=6UN`$MO;65N
M9&$`4&]WLV]K80!+;VUE;G1A<GH`2V]M;W)Y`$9I<FUA`%-T=_-R>B!W:6%D
M;VUOMN8@*"5S*0!+;VUP=71E<GD`5V%R=6YK:0!3:V]N9FEG=7)U:B`E<P!0
M;W1W:65R9+P@:&%SLV\`2V]N9V\`1&5M;VMR871Y8WIN82!297!U8FQI:V$@
M2V]N9V\`4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@<VGJ+@!0;[.Q8WIE;FEE
M(&YI92!P;W=I;V2S;R!S:>HZ(`!/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P
M=6)L:6-Z;F5G;R!S97)W97)A+@!/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P
M=6)L:6-Z;F5G;R!S97)W97)A+B!0;W?S9#H@)7,@*"5S*0!"L[%D('!O9&-Z
M87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@1E10+@!+;VYT86MT>2!Z;W-T
M8;-Y('!O;7FV;&YI92!D;V1A;F4@9&\@5'=O:F5J(&MS:;&_:VD@861R97-O
M=V5J+@!:87=A<G1OMN8@(B5S(@!+;VYY;G5U:@!7>7-P>2!#;V]K80!3:V]P
M:75J`%-K;W!I=6H@=WEB\W(`3FEE('5D8;-O('-IZB!Z87-Z>69R;W=AYB`H
M4$=0*2!W:6%D;VUOMF-I+@!.:64@=61ALV\@<VGJ('!O9'!I<V'F("A01U`I
M('=I861O;6^V8VDN`$YI92!U9&&S;R!S:>H@>F%S>GEF<F]W8>8@*%,O34E-
M12D@=VEA9&]M;[9C:2X`3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4R]-24U%
M*2!W:6%D;VUOMF-I+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R
M=V5R96T@3$1!4"X`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E
M<F5M("(E<R(@<&]P<GIE>B!&5%`Z("5S`$YI92!U9&&S;R!S:>H@;V1S>GEF
M<F]W8>8@9&%N>6-H(%!'4"X`3FEE('5D8;-O('-IZB!O9'-Z>69R;W=AYB!D
M86YY8V@@4R]-24U%+@!.:64@=61ALV\@<VGJ('5S=&%L:>8@861R97-U(&4M
M;6%I;"!O9&)I;W)C>2X`3FEE('5D8;-O('-IZB!U>GES:V'F('H@<V5R=V5R
M82!K;'5C>F$@<&)U;&EC>FYE9V\N`$YI92!U9&&S;R!S:>H@;W1W;W)Z>>8@
M(B5S(B!D;R!Z87!I<W4N`$YI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I
M;G1E;F%N8V5?5&%S:R`E<P!.:64@;6^_;F$@;W1W;W)Z>>8@:V%T86QO9W4@
M(B5S(@!.:64@=61ALV\@<VGJ('-K87-O=V'F('!L:6MU("(E<R(N`$YI92!U
M9&&S;R!S:>H@>FYA;&6\YB!P87-K82!-;WII;&QI+B!5<&5W;FEJ('-IZBP@
MOV4@:F5S="!O;B!O='=A<G1Y+@!+<F%J`%5T=_-R>B!N;W=E('ID87)Z96YI
M90!3='?S<GH@;&EN:P!3='?S<GH@;F]WL0!.=6UE<B!K87)T>2!K<F5D>71O
M=V5J`$-H;W)W86-J80!+=6)A`$]B96-N>2!C>F%S`%-P97)S;VYA;&EZ=6H@
M>F%D86YI82!U<G5C:&%M:6%N92!P<GIY(&QO9V]W86YI=2!D;R`E<RX`5WET
M;FEJ`$-Y<'(`4F5P=6)L:6MA($-Z96-H`$1$`$-O9'II96YN:64`8V]D>FEE
M;FYI93H@<&]W=&%R>F$@<VGJ(&-O`$1A=&$`1'II9?$`9&YI`%]5<W7Q(&MO
M;'5M;NH`9W)U9'II9?$`1&]M>;9L;GD@:V]L;W(`1&]M>;9L;F$@=&^_<V%M
M;[;F`$1O;7FV;&YE('5P<F%W;FEE;FEA`$1O;7FV;&YE('5P<F%W;FEE;FEA
M`'5S=?$@>F1A<GIE;FEE`%5S=?$@1W)U<.H`57-U\2!U<')A=VYI96YI80!5
M<W7Q(&D@=WEC>GFVYB!W:6%D;VUOMF-I`%5S=?$@:V]M\W)KZ@!5<W7Q(&MO
M;'5M;NH`4VMA<W5J('5P<F%W;FEE;FEA(&1L82`B)7,B`%-K87-O=V'F('5P
M<F%W;FEE;FEA(&1L82`B)7,B(&D@=W-Z>7-T:VEE('!O9"UU<')A=VYI96YI
M83\`57-U\2!W:65R<WH`4VMA<W5J('=Y8G)A;K$@=&^_<V%M;[;F`%5S=?$@
M86MT=6%L;K$@:V]L=6UNZ@!5<W7Q(&%K='5A;&YY('=I97)S>@!3:V%S;W=A
MYB!T;R!U<')A=VYI96YI92!I('=S>GES=&MI92!P;V0M=7!R87=N:65N:6$_
M`$1A;FEA`$]P:7-Z('!R;V)L96T`;W!I<P!3>F-Z96?SLWD@>F]S=&&S>2!Z
M86QO9V]W86YE(&1L82!A9&UI;FES=')A=&]R82X`2V%T86QO9P!7>;9W:65T
M;"!C>F%S('<@9F]R;6%C:64@,C0M9V]D>FEN;GEM/P!/<&-J92!W>;9W:65T
M;&%N:6$`1+]I8G5T:0!.:64@:V%S=6H`0G)A:R!B97IP;[9R961N:65G;R!D
M;W-TZG!U(&1O(&UA:6YT96YA;F-E+G!H<`!$;VUI;FEK82`H5W-P\VQN;W1A
M($1O;6EN:6MI*0!$;VUI;FEK86YA("A297!U8FQI:V$@1&]M:6YI:V'Q<VMA
M*0"F8VFQ9VYI:@"F8VFQ9VYI:B`E<P!.87)K;W1Y:VD`0WIA<R!T<G=A;FEA
M`$4M;6%I;`!%:W=A9&]R`&5D>71U:B`E<P!5<W7Q($=R=7#J`%IM:67Q('5P
M<F%W;FEE;FEE`%IM:67Q('5P<F%W;FEE;FEA`%IM:67Q('5P<F%W;FEE;FEA
M(&1L82`E<P!:;6EE\2!U<W1A=VEE;FEA(&1L83H`6FUI9?$@=7!R87=N:65N
M:6$@9&QA("5S`$5G:7!T`%-A;'=A9&]R`$5M86EL`$%D<F5S>2!E;6%I;"!M
M=7-ZL2!D;R!S:65B:64@<&%S;W=AYBX`16UO=&EK;VYY`%!U<W1A('=I861O
M;6^VYBX`0G)A:R!R97IU;'1A=/-W+@!7L[%C>GGF(&UE;G4@:V]N=&5K<W1O
M=V4@<&]D('!R87=Y;2!P<GIY8VES:VEE;2!M>7-Z>3\`9&%T82!Z86MO\6-Z
M96YI80!K;_%C>K%C('<`8WIA<R!Z86MO\6-Z96YI80!'=VEN96$@4O-W;FEK
M;W=A`$5R>71R96$`0K.Q9`!"L[%D('!R>GD@>F%P:7-I92`B)7,B+@!%<W1O
M;FEA`$5T:6]P:6$`175R;W!A`$-O(&MAOV1E(#$U(&UI;G5T`$-O(&MAOV1E
M(#(@;6EN=71Y`$-O(&MAOV1E(#,P('-E:W5N9`!#;R!K8;]D92`U(&UI;G5T
M`$-O(&MAOV1E('IA;&]G;W=A;FEE`$-O(&MAOV1E('#SLR!G;V1Z:6YY`$-O
M(&MAOV2Q(&UI;G5TZ@!0<GIY:[-A9&]W92!W87)T;[9C:3H`5WEK;VYA:@!2
M;WIW:?$`4F]Z=VGQ('!A<V5K`$5K<W!O<G0`16MS<&]R='5J(&MA;&5N9&%R
M>@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@3$1!4"X`
M0K.Q9"!P;V1C>F%S(&MO<&EO=V%N:6$@>B`B)7,B+@!"L[%D('!O9&-Z87,@
M:V]P:6]W86YI82!D;R`B)7,B+@!"L[%D('!O9&-Z87,@<')Z96YO<WIE;FEA
M(&1O("(E<R(N`$9A;&ML86YD>2`H36%L=VEN>2D`5WES<'D@3W=C>F4`0K.Q
M9"!K<GET>6-Z;GDZ(`!&86MS`&QU='D`1FEDOVD`365N962_97(@<&QI:_-W
M`$YA>G=A('!L:6MU`%=Y8O-R('!L:6MU`%=G<GEW86YI92!P;&EK=0!79W)Y
M=V%N:64@<&QI:_-W(&YI92!J97-T(&]B<[-U9VEW86YE+@!&:6QT<GD`1FEN
M;&%N9&EA`$IE9'IE;FEE`%IA<&]M;FEALV6V(&AA<[-A/P!0:0!&<F%N8VIA
M`$=U:F%N82!&<F%N8W5S:V$`4&]L:6YE>FIA($9R86YC=7-K80!&<F%N8W5S
M:VEE(%1E<GET;W)I82!0;[-U9&YI;W=E(&D@06YT87)K='EC>FYE`%!IL71E
M:P!/9`!'86)O;@!'86UB:6$`1W)A`$YI96UC>0!':&%N80!':6)R86QT87(`
M262\`%=Y<WIU:VEW87)K82!';V]G;&4`1W)E8VIA`$=R96YL86YD:6$`1W)E
M;F%D80!'<G5P>2!D>7-K=7-Y:FYE`$=W861E;'5P80!'=6%M`$=W871E;6%L
M80!'=65R;G-E>0!'=VEN96$`1W=I;F5A($)I<W-A=0!'=6IA;F$`2%1-3`!(
M86ET:0!7>7-P>2!(96%R9"!I($UC1&]N86QD80!0;VUO8P!7>7-O:VD`7U-T
M87)T`%=A='EK86X@*%-T;VQI8V$@07!O<W1O;'-K82D`4&]C>K%T96L`061R
M97,@9&]M;W=Y`%1E;"X@9&]M+@!(;VYD=7)A<P!(;VYG2V]N9P!(;W)D90!(
M;W)D92]+;VQA8CH@561ALV\@<VGJ('5S=6ZQYB`E<R`B)7,B`&=O9'II;F$H
M>2D`5^IG<GD`27-L86YD:6$`5'EL:V\@:6MO;GD`26MO;GD@>B!T96MS=&5M
M`$YA>G=A('1OOW-A;6^V8VDZ`$=R869I:V$`:6UP;W)T+V5K<W!O<G0@:V%L
M96YD87)Z80!);7!O<G1O=V%N92!P;VQE.B`E<P!);7!O<G1O=V%N92!P;VQA
M.@!);F1I90!);F1O;F5Z:F$`26YF;P!7:VQE:B!O8G)A>F5K`%=Y<[-A;F4@
M;FEE<')A=VEDLV]W92!D86YE+@!.:65P<F%W:62S;W=Y(&%D<F5S(&1O8V5L
M;W=Y+@!.:65P<F%W:62S;W=Y(&9O<FUA="!P;&EK=0!.:65P<F%W:62S;W=Y
M(&ML=6-Z(&QI8V5N8VII+@!)<F%N`$ER86L`27)L86YD:6$`27IR865L`%=Y
M9&%W8V$`5[-O8VAY`$IA;6%J:V$`<W1Y8WIE\0!*87!O;FEA`$IO<F1A;@!L
M:7!I96,`8WIE<G=I96,`2V%Z86-H<W1A;@!+96YI80!4=V]R>F5N:64@:VQU
M8WIA`$]D8VES:R!K;'5C>F$`1+-U9V^VYB!K;'5C>F$`5'EP(&ML=6-Z80!+
M;'5C>B!J=;\@:7-T;FEE:F4@;F$@<'5B;&EC>FYY;2!S97)W97)Z92!K;'5C
M>GDN`'.S;W=A(&ML=6-Z;W=E`$1Z:65C:0!+:7)I8F%T:0!+;W)E8?%S:V$@
M4F5P=6)L:6MA($QU9&]W;RU$96UO:W)A='EC>FYA`%)E<'5B;&EK82!+;W)E
M:0!+=7=E:G0`2VER9VES=&%N`%=Y9VRQ9"`H7WDI`$KJ>GEK`$QA;W,`3W-T
M871N:64@;&]G;W=A;FEE.B`E<P!/<W1A=&YI92!L;V=O=V%N:64Z("5S('H@
M)7,`3W-T871N:64@;&]G;W=A;FEE.B!N:6=D>0!0;W!R>F5D;FD@='ED>FEE
M\0"C;W1W80!,97-O=&AO`$QI8F5R:6$`3&EB:6$`3&EE8VAT96YS=&5I;@!/
M9W)A;FEC>B!O:W)E<R!D;&$@96MS<&]R='4Z`%=YMG=I971L('1E;6%T>2!P
M;VUO8WD`3&ES=&]W86YI92!UOWET:V]W;FEK\W<@:F5S="!W>;.Q8WIO;F4N
M`$QI='=A`*-A9&]W86YI92XN+@!#>F%S(&QO:V%L;GDZ(`!5<W1A=VEE;FEA
M(&QO:V%L;F4@:2!C>F%S`$UI96IS8V4`6F%L;V=U:@!7>6QO9W5J`%IA9&%N
M:6$@<')Z>2!L;V=O=V%N:74`3&]G;W=A;FEE(&YI92!P;W=I;V2S;R!S:>HL
M('!O;FEE=V&_('!O9&&S9;8@;FEE<')A=VEDLV]W92!H87.S;R!L=6(@;F%Z
M=^H@=;]Y=&MO=VYI:V$N`$QO9V]W86YI92!N:64@<&]W:6]DLV\@<VGJ+@!.
M:7-K:0!,=6MS96UB=7)G`$U-`$U/5$0`35-'`$UA:V%U`$UA8V5D;VYI80!-
M861A9V%S:V%R`%!O8WIT80!-86QA=VD`36%L97IJ80!-86QE9&EW>0!-86QI
M`$UA;'1A`%IA<GJQ9'IA:B!L:7-TL2!K871E9V]R:6DL(&MT\W)Y;6D@8NID
M>FEE<WH@;WIN86-Z8;,@<&]Z>6-J92P@:2!K;VQO<F%M:2!Z(&YI;6D@>G=I
ML7IA;GEM:2X`;6%R>F5C`$UA<F=I;F5S`%=Y<W!Y($UA<G-H86QL80!-87)T
M>6YI:V$`4&%S=6JQ8V4@<&]L80!-875R971A;FEA`$UA=7)I=&EU<P!M86H`
M36%J;W1T80!S<&]T:V%N:64`5')Y8B!M96YU.@!0;[.Q8WH@:V]M\W)K:0!7
M:6%D;VUOMN8`0FQO:R`B365T87(B(&YI92!J97-T(&1O<W3J<&YY+@!";&]K
M(")-971A<B(@;FEE(&IE<W0@9&]S=.IP;GDN(%-Z8WIE9_.S>2!Z9&%R>F5N
M:6$@>F]S=&&S>2!Z86QO9V]W86YE(&1L82!A9&UI;FES=')A=&]R82X`365K
M<WEK`%1Y<"!-:6UE`&UI;G5T82AY*0!0;P!/<W1A=&YI82!M;V1Y9FEK86-J
M80!:;6EE\2!L:6YK`$UOLV1A=VEA`%)E<'5B;&EK82!-;[-D87=I:0!-;VYA
M:V\`<&]N:65D>FEALV5K`$UO;F=O;&EA`$UI97-IL6,`0V\@;6EE<VFQ8P!M
M:65S:>IC>FYI93H@<&]W=&%R>F$@<VGJ(&-O`$UO;G1S97)R870`1F%Z>2!K
M<VGJOWEC80!-87)O:V\`4')Z97-U\2!W(&3SLP!0<GIE<W7Q('<@;&5W;P!0
M<GIE<W7Q('<@<')A=V\`4')Z97-U\2!W(&?S<NH`4')Z96YI9;8@=R!D\[,`
M4')Z97-U\2!W(&?S<NH`36]Z86UB:6L`2V]N=&\`3?-J('!O<G1A;`!":7)M
M80!.86UI8FEA`$YA=7)U`$YE<&%L`$AO;&%N9&EA`$%N='EL92!(;VQE;F1E
M<G-K:64`4VEEY@!.:6=D>0!.;W=A($MA;&5D;VYI80!.;W=A(&MA=&5G;W)I
M80!.;W=E('ID87)Z96YI90!.;W=A(%IE;&%N9&EA`%=I861O;6^V8VD`3F%S
M=.IP;GD@;6EE<VFQ8P!.87-TZG!N>2!D>FEE\0!.87-TZG!N92!O<&-J90!.
M87-TZG!N>2!T>61Z:67Q`$YI:V%R86=U80!.:6=E<@!.:6=E<FEA`$YI=64`
M0F5Z('IM:6%N+@!"<F%K(&MO;F9I9W5R86-J:2!D;&$@)7,N`&YI92!M82!D
M871Y(&MO\6-A`$YI92!W9W)A;F\@<&QI:W4`3FEE('!O9&%N;R!H87.S82!D
M;&$@=7=I97)Z>71E;&YI96YI82!(5%10+@!.:64@<&]D86YO(&AA<[-A(&1L
M82!U=VEE<GIY=&5L;FEE;FEA($E-05`N`$YI92!P;V1A;F\@:&%SLV$@9&QA
M('5W:65R>GET96QN:65N:6$@2V5R8F5R;W,N`$YI92!P;V1A;F\@:&%SLV$@
M9&QA('5W:65R>GET96QN:65N:6$@3$1!4"X`3FEE('!O9&%N;R!H87.S82!D
M;&$@=7=I97)Z>71E;&YI96YI82!,3T=)3BX`3FEE('!O9&%N;R!H87.S82!D
M;&$@=7=I97)Z>71E;&YI96YI82!005-35T0N`$YI92!P;V1A;F\@:&%SLV$@
M9&QA('5W:65R>GET96QN:65N:6$@4TU"+@!B<F%K`$YO<F9O;&L`3F]R=V5G
M:6$`3FEE('IA:6UP;&5M96YT;W=A;F\N`$YI975S=&%W:6]N90!.:65O8G.S
M=6=I=V%N90!5=V%G:0!5=V%G80!L:7-T;W!A9`!,:6-Z8F$@:V]L=6UN`$QI
M8WIB82!W:65R<WIY`$]+`'!AO&1Z:65R;FEK`$)I=7)O`$]M86X`5'?S:B!J
M961E;B!A9')E<R!E+6UA:6P@:F5S="!D;WIW;VQO;GDN`$]T=_-R>B!W(&YO
M=WEM(&]K;FEE`$]P8VIE`$]P8VIE("5S`$]R9V%N:7IA8VIA`$IE9&YO<W1K
M82!O<F=A;FEZ86-Y:FYA`$]R9V%N:7IA=&]R`$EN;F4`26YN92!I;F9O<FUA
M8VIE`$EN;F4@=7!R87=N:65N:6$`57=I97)Z>71E;&YI96YI92!004T@;FEE
M(&IE<W0@9&]S=.IP;F4N`$-Y9G)O=WD@<&]D<&ES(%!'4`!7:6%D;VUOMN8@
M>F%S>GEF<F]W86YA(%!'4`!+;'5C>B!P=6)L:6-Z;GD@4$=0`%=I861O;6^V
MYB!Z87-Z>69R;W=A;F$O<&]D<&ES86YA(&ML=6-Z96T@4$=0`$MO9"!02%``
M4&]WLV]K82!02%``4&]WLV]K82!07TA0`%!A:VES=&%N`%!A;&%U`%!A;F%M
M80!087!U82U.;W=A($=W:6YE80!087)A9W=A:@!(87.S;P!(87.S;R!N:65P
M<F%W:62S;W=E`$AA<[-O('H@<&]T=VEE<F1Z96YI96T`2&%SLV\Z`$AA<[-O
M.B``2&%SLV\@;75S:2!P87-O=V'F+@!7:VQE:@!7:VQE:B!Z92!S8VAO=VMA
M`%=Z;W)Z96,`5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4`5WEK;VYA:B!C
M>6ML:6-Z;F4@;W!E<F%C:F4@<&]D8WIA<R!L;V=O=V%N:6$_`%5P<F%W;FEE
M;FEE`%5P<F%W;FEE;FEA(&1L80!);F9O<FUA8VIE(&]S;V)I<W1E`%!E<G4`
M1FEL:7!I;GD`5&5L969O;@!0:71C86ER;@!.82!P97=N;R!U<W5NL>8@=&5N
M('=Y8G)A;GD@96QE;65N=#H`3F$@<&5W;F\@=7-U;K'F('=Y8G)A;GD@96QE
M;65N=#H`4')O<WKJ('!O9&'F('!O<')A=VYY(&%D<F5S($E0+@!0<F]S>NH@
M<&]D8>8@<&]P<F%W;GD@8WIA<RX`4')O<WKJ(&]P:7-AYB!P<F]B;&5M+@!0
M<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S;P!0;VQS:V$`
M4&]R='5G86QI80!0;V1G;+%D`%!O<')Z961N:2!D>FEE\0!+;'5C>B!P<GEW
M871N>0!0<F]B;&5M`$]P:7,@<')O8FQE;74`2VQU8WH@<'5B;&EC>FYY`$%L
M9V]R>71M(&ML=6-Z82!P=6)L:6-Z;F5G;P!);F9O<FUA8VIE(&\@:VQU8WIU
M('!U8FQI8WIN>6T`4&%R82!K;'5C>GD@;W-O8FES='EC:"!N:64@>F]S=&&S
M82!W>6=E;F5R;W=A;F$@<&]M>;9L;FEE+@!0;W)T;W)Y:V\`2V%T87(`6F%P
M>71A;FEE`$ML=6-Z('!U8FQI8WIN>2!24T$@*"5D(&)I=/-W*0!0;W=T87)Z
M86YI92!D;P!D871A('!O=W1A<GIA;FEA`&1A=&$@:V_Q8V$@<&]W=&%R>F%N
M:6$`<')Z961Z:6&S('!O=W1A<GIA;FEA`'1Y<"!P;W=T87)Z86YI80!P;W=T
M87)Z82!S:>H@8V]D>FEE;FYI90!P;W=T87)Z82!S:>H@8V\@;6EE<VFQ8P!P
M;W=T87)Z82!S:>H@8V\@='ED>FEE\0!P;W=T87)Z82!S:>H@8V\@<F]K`$]D
MMG=I9;\@9'EN86UI8WIN92!E;&5M96YT>2!M96YU.@!/9+9W:66_('=I9&]K
M('-E<G=I<W4Z`%ID86QN92!S97)W97)Y`%5S=?$`57-U\2!B;&]K`%5S=?$@
M:V]L=6UNZ@!5<W7Q('!A<NH`57-U\0!5<W7Q('6_>71K;W=N:6MA`%ID86QN
M92!UOWET:V]W;FEK83H@)7,`2V%S=6H`5WEC>GFVYB!H87.S;P!7>6-Z>;;F
M(%1W;VIE(&AA<[-O`%!R>GEW<O/F('5S=&%W:65N:6$@9&]M>;9L;F4`5WEN
M:6MI`%!O=W+S="!D;R!O<&-J:0!2975N:6]N`%)O>F)U9&]W86YY(&5D>71O
M<B!T96MS='4`4W1A;F]W:7-K;P!2=6UU;FEA`$]B<O/F(&\@,3@P('-T;W!N
M:0!/8G+SYB!W(&QE=V\`3V)R\^8@=R!P<F%W;P!7LV&V8VEW;[9C:2!R>NID
M=2!0<F]P97)T:65S`%)O<VIA`%)U86YD80!7:6%D;VUOMN8@>F%S>GEF<F]W
M86YA(%,O34E-10!5=VEE<GIY=&5L;FEE;FEE(%-!4TP@;FEE(&IE<W0@9&]S
M=.IP;F4N`%!O=VQO:V$@4U%,`%-32`!0;W>S;VMA(%-?44P`4V\`IG=IZG1A
M($AE;&5N80!386EN="!+:71T<R!I($YE=FES`%-A:6YT($QU8VEA`%-A:6YT
M+5!I97)R92!I($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@:2!'<F5N861Y;GD`
M4V%M;V$`4V%N($UA<FEN;P!S;V)O=&$`07)A8FEA(%-A=61Y:G-K80!:87!I
M<WH@(B5S(@!:87!I<WH@)7,`6F%P86UIZG1A:B!Z9&%R>F5N:64`6F%P:7-Z
M(&]P8VIE`%=Y8FEE<GH@<&QI:VD`5WEB:65R>B!Z;F%K('!O9'II8;-U(&1A
M='DZ`%=Y8FEE<GH@9F]R;6%T(&1A='DZ`%=Y8FEE<GH@<&QI:R!D;R!I;7!O
M<G1U.@!7>6)I97)Z('!I97)W<WIY(&1Z:67Q('1Y9V]D;FEA.@!7>6)I97)Z
M('1OOW-A;6^VYB!D;R!Z;6EA;GDZ`%=Y8FEE<GH@>FYA:R!P;V1Z:6&S=2!D
M871Y.@!7>6)I97)Z(&9O<FUA="!C>F%S=3H`5WEB:65R>B!P;VMA>GEW86YY
M(&]K<F5S.@!7>6)I97)Z(&1W82!P87-U:K%C92!P;VQA+@!7>6)I97)Z('-C
M:&5M870@:V]L;W+S=RX`5WEB:65R>B!T=_-J('!R969E<F]W86YY(&KJ>GEK
M.@!7>;9L:6H@<F%P;W)T(&\@<')O8FQE;6EE`%-E;F5G86P`=W)Z97-I9?$`
M3G5M97(@<V5R>6IN>0!5<W1A=P!5<W1A=R!Z9&%L;F4@<V5R=V5R>2P@9&\@
M:W3S<GEC:"!C:&-E<WH@;6EEYB!D;W-TZG`@>B!S97)W:7-U+@!5<W1A=R!P
M<F5F97)O=V%N>2!JZGIY:RP@<W1R96;J(&-Z87-O=[$@:2!O<&-J92!D871Y
M+@!5<W1A=R!U<[-U9^H@<&]C>K%T:V]WL2P@<V-H96UA="!K;VQO<O-W+"!O
M9+9W:66_86YI92!S=')O;GD@:2!I;FYE(&]P8VIE('=YMG=I971L86YI80!+
M;VYF:6=U<F%C:F$`4WIE<WIE;&4`2W+S=&MI(&]P:7,`4&]K8;\`0WIY('!O
M:V%Z>7=AYB!Z861A;FEA('1E<FUI;F]W92!W(&MA;&5N9&%R>G4_`%!O:V%Z
M>7=AYB!C>F%S(&]S=&%T;FEE9V\@>F%L;V=O=V%N:6$@<&\@;&]G;W=A;FEU
M/P!#>GD@<&]K87IY=V'F('1Y;&MO('1E('=Y9&%R>F5N:6$L(&MT\W)Y;2!P
M<GIY<&ES86YO(&%L87)M/P!0;VMAOR!M96YU("5S('!O(&QE=V5J/P!3:65R
M<F$@3&5O;F4`6F%R96IE<W1R=6H@<VGJ+"!J9;9L:2!J97-Z8WIE('1E9V\@
M;FEE('IR;V)ILV6V`%!O9'!I<P!!;&=O<GET;2!P;V1P:7-U`%-I;F=A<'5R
M`%=I96QK;[;F`%!O;6GQ(&]P97)A8VIE(&-Y:VQI8WIN90!3LV]W86-J80!3
MLV]W96YI80!7>7-P>2!386QO;6]N80!3;VUA;&EA`%!OLW5D;FEO=V$@069R
M>6MA`%!OLW5D;FEO=V]E=7)O<&5J<VMI("A)4T\M.#@U.2TS*0!'96]R9VEA
M(%!OLW5D;FEO=V$`2&ES>G!A;FEA`%-P86T`161Y8VIA('IN86OS=R!S<&5C
M:F%L;GEC:`!0;V1Z:65L(&MO;?-R:^H`4&]D>FEE;"!K;VQU;6[J`%!O9'II
M96P@=VEE<G-Z`%-R:2!,86YK80!D871A('!O8WJQ=&MU`%!O8WJQ=W-Z>2!O
M9`!C>F%S('!O8WJQ=&MU`%=O:F5W\V2\='=O(&QU8B!S=&%N`$%D<F5S(&1O
M;6]W>0!.:0!496UA=`!7>;9L:6H`4&]W;V1Z96YI90!59&&S;R!S:>H@9&]D
M8>8@(B5S(B!D;R!S>7-T96UU+@!59&&S;R!S:>H@=7-U;K'F("(E<R(@>B!S
M>7-T96UU+@!59&&S;R!S:>H@=7-U;K'F("(E<R(N`%5D8;-O('-IZB!U<W5N
ML>8@(B5S(B!Z('-Y<W1E;74N`%5D8;-O('-IZB!U86MT=6%L;FGF("(E<R(`
M4W5D86X`;FEE9'II96QA`%=S8VCS9"]Z86-H\V0@<[-O\6-A`%-U<FEN86T`
M4W5A>FD`4WIW96-J80!3>G=A:F-A<FEA`%-Y<FEA`%1A:G=A;@!486IW86X`
M5&%DOWEK:7-T86X`5&%N>F%N:6$`>F%D86YI80!.=6UE<B!T96QE9F]N=0!4
M>6QK;R!T96MS=`!#>@!486IL86YD:6$`1'IIZFMU:F5M>2!Z82!K;W)Z>7-T
M86YI92!Z('-E<G=I<W4N`$1A=&$@:V_Q8V$@;75S:2!B>>8@</.\;FEE:G-Z
M82!N:;\@9&%T82!P;V-ZL71K=2X`5&^_<V%M;[;F("(E<R(@>F]S=&&S82!U
M<W5N:>IT82X`4V5R=V5R("(E<R(@>F]S=&&S('5S=6YIZG1Y+@!397)W97(@
M(B5S(B!Z;W-T8;,@>F%P:7-A;GDN`$)L;VL@=V5A=&AE<BYC;VT@;FEE(&IE
M<W0@9&]S=.IP;GDN`$YI92!M82"_861N>6-H(&1O<W3J<&YY8V@@;W!C:FDN
M`%=Y<W2Q<&FS('!R;V)L96T@<')Z>2!D;V1A=V%N:74@(B5S(B!D;R!S>7-T
M96UU.B`E<P!7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@9&%N>6-H
M(&1L82!UOWET:V]W;FEK82`B)7,B('<@<WES=&5M:64Z(`!7>7-TL7!ILR!P
M<F]B;&5M('!R>GD@=7-U=V%N:74@(B5S(B!Z('-Y<W1E;74N`%=Y<W2Q<&FS
M('!R;V)L96T@<')Z>2!U86MT=6%L;FEA;FEU("(E<R(Z("5S`%=Y<W2Q<&FS
M(&*SL60@<&]D8WIA<R!W>;9W:65T;&%N:6$@=&5J(&-ZZK9C:2!W:6%D;VUO
MMF-I`$YI92!B>;-O('ID87)Z9?$L(&MT\W)E(&UOOVYA(&5K<W!O<G1O=V'F
M+@!0;&EK(&YI92!W>6=LL61A(&YA('!O<')A=VYE(&%R8VAI=W5M(%)!4BX`
M4&QI:R!N:64@=WEG;+%D82!N82!P;W!R87=N92!A<F-H:7=U;2!:25`N`%1O
M('!O;&4@:F5S="!W>6UA9V%N92X`5&\@<&]L92!M=7-I(&)YYB!P;W!R87=N
ML2!L:6-Z8K$N`%=I861O;6^VYB!Z;W-T8;-A(&YA<&ES86YA('<@:6YN96H@
M;FF_('1W;VIA('-T<F]N:64@:V]D;W=E:B`H)7,I+@!496X@<V5R=V5R(&YI
M92!P;W1R869I(')O>G!A:V]W>7=AYB!A<F-H:7?S=R!Z:7`@:2!G>FEP+@!C
M>G=A<G1E:P!#>F%S`$9O<FUA="!C>F%S=0!:9&%R>F5N:64`1&\`06)Y('=Y
M8G)AYB!W:65L;VMR;W1N92!P;VQA('!R>GET<GIY;6%J('!R>GEC:7-K($-T
M<FP@*%!#*2!L=6(@0V]M;6%N9"`H36%C*2!P;V1C>F%S(&ML:6MA;FEA+@!-
M\VH@=VED;VL`5&]G;P!4;VME;&%U`%1O;F=A`%1R>6YI9&%D(&D@5&]B86=O
M`%!R87=D82!L=6(@9F&S<WH`5W0`=W1O<F5K`%1U;F5Z:F$`5'5R8VIA`%1U
M<F5C:VD@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=79A;'4`='EP`%52
M3#H`56=A;F1A`%5K<F%I;F$`0K.Q9"!P;V1C>F%S('IM:6%N>2!D;R`E<RX`
M0K.Q9"!P;V1C>F%S(')O>G!A:V]W>7=A;FEA(&1A;GEC:"X`3FEE(&UOOVYA
M('!R>F5TLW5M86-Z>>8@=&5G;R!D;VMU;65N='4@5V]R9"UA`$-O9FYI:B!Z
M;6EA;GD`6FIE9&YO8WIO;F4@16UI<F%T>2!!<F%B<VMI90!7:65L:V$@0G)Y
M=&%N:6$`55-!`$YI97IN86YE`$)E>B!N87IW>0!.:65O8G.S=6=I=V%N92!R
M;WIS>F5R>F5N:64`56%K='5A;&YI:@!:8;-A9'5J`%5R=6=W86H`5VED;VL@
M;VMI96YK80!/<&-J92!UOWET:V]W;FEK80!296IE<W1R86-J82!UOWET:V]W
M;FEK80!.87IW82!UOWET:V]W;FEK80!5OWET:V]W;FEK(&\@;F%Z=VEE("(E
M<R(@:G6_(&ES=&YI96IE+@!.87IW82!UOWET:V]W;FEK83H`3F%Z=V$@=;]Y
M=&MO=VYI:V$Z(`!5OWET:V]W;FEC>2!W('-Y<W1E;6EE.@!5>F)E:VES=&%N
M`%=A:V%C:F4`5F%N=6%T=0!796YE>G5E;&$`5V5R<VIA`%=I971N86T`5VED
M;VL@)7,`4&]K8;\@<W1R;V[J(%=75P!0;VMAOR!J86MO("5S`$)R>71Y:G-K
M:64@5WES<'D@1'II97=I8WIE`%=Y<W!Y($1Z:65W:6-Z92!3=&%N\W<@6FIE
M9&YO8WIO;GEC:`!786QL:7,@:2!&=71U;F$`3W-T<GIEOV5N:64`IG(`5U=7
M`+9R;V1A`%1Y9'II9?$`='ED>FEE\2`E9`!T>61Z:67Q*'1Y9V]D;FEE*0!#
M;R!T>61Z:67Q`'1Y9V]D;FEO=V\Z('!O=W1A<GIA('-IZB!C;P!7:71A;7D`
M5VET86UY('<@)7,`5VET86UY+"`E<P!:86-H;V1N:2`H25-/+3@X-3DM,2D`
M6F%C:&]D;FD@*$E33RTX.#4Y+3$U*0!386AA<F$@6F%C:&]D;FEA`$IA:[$@
M87!L:6MA8VKJ(&UA("5S('=YMG=I971L8>8@<&\@>F%L;V=O=V%N:74@<VGJ
M/P!*86MI92!W='EC>FMI(&%K='EW;W=AYB!W(%)O>F)U9&]W86YY;2!E9'ET
M;W)Z92!T96MS='4N`%-Z97)O:V^VYB!L97=E9V\@;65N=2`E<R`H>FUI86YA
M('IA8WIN:64@;V)O=VFQ>GEW8>8@<')Z>2!N87-TZG!N>6T@;&]G;W=A;FEU
M*3H`061R97,@9&\@<')A8WD`5&5L+B!D;R!P<F%C>0!4>61Z:67Q(')O8F]C
M>GD`4E(`4E)24@!#;R!R;VL`<F]C>FYI93H@<&]W=&%R>F$@<VGJ(&-O`$IE
M;65N`%1A:P!486LL('IG861Z86T@<VGJ`%=Y;&]G;W=ALV6V('-IZBX`375S
M:7-Z(&]P:7-AYB!P<F]B;&5M('IA;FEM(&=O('=YMFQE<WHN`$UU<VES>B!O
M:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F+@!-
M=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z(&1O
M9&'F+@!4=_-J(&%D<F5S(&4M;6%I;`!4=_-J(&%D<F5S($]D.@!4=V]J92!I
M;F9O<FUA8VIE`%1W\VH@861R97,@:6YT97)N971O=WD@<VGJ('IM:65N:;,@
M;V0@<&]C>K%T:W4@<V5S:FD@)7,N(%<@>G=IL7IK=2!Z(&)E>G!I96-Z9?%S
M='=E;2!4=V]J96=O(&MO;G1A(&UU<VES>B!Z86QO9V]W8>8@<VGJ('!O;F]W
M;FEE+@!4=V]J92!I;6GJ`%1E;B!S>7-T96T@875T96YT>6MA8VII(&YI92!O
M8G.S=6=U:F4@9&]D87=A;FEA('6_>71K;W=N:6OS=RP@;'5B('1A(&]P8VIA
M('IO<W1ALV$@=WFSL6-Z;VYA+@!496X@<WES=&5M(&%U=&5N='EK86-J:2!N
M:64@;V)SLW5G=6IE(&QI<W1O=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@=&$@
M;W!C:F$@>F]S=&&S82!W>;.Q8WIO;F$N`%1W;VIA(&]B96-N82!S=')E9F$@
M8WIA<V]W83H`1&]M>;9L;F$@=&^_<V%M;[;F.@!4=V]J92!P9;-N92!I;6GJ
M(&D@;F%Z=VES:V\Z`%1W;VEM(&YO=WEM(&AA<[-E;2!W("5S(&IE<W0Z("5S
M`%1W;VIE('5S=&%W:65N:6$@>F]S=&&S>2!U86MT=6%L;FEO;F4@;F$@8WIA
M<R!T<G=A;FEA('1E:B!S97-J:2X`5'=O:F4@=7-T87=I96YI82!Z;W-T8;-Y
M('5A:W1U86QN:6]N92X`5'=O:F4@>F1A;&YE('-E<G=E<GDZ`$IU9V]SLV%W
M:6$`6F%I<@!:86UB:6$`6FEM8F%B=V4`6U)A<&]R="!O('!R;V)L96UI95T`
M7T%D;6EN:7-T<F%C:F$`7T-,20!?57-U\2!W:65R<WH`7T=R=7!Y`%]0;VUO
M8P!?6F%L;V=U:@!?5WEL;V=U:@!:;6EE\2!L:6YK+BXN`%]/<&-J90!?57!R
M87=N:65N:6$`57-U\2!L:6YK+BXN`%]+;VYF:6=U<F%C:F$`7U6_>71K;W=N
M:6-Y`&MS:;&_:V$@861R97-O=V$`:V%L96YD87)Z`&1Z:67Q`&1Z:67Q*&1N
M:2D`9&YI`'!L:6L`;6EE<VFQ8RAM:65S:;%C92D`3F%Z=VES:V\`;F]T871N
M:6L`=R!T>6T@<V%M>6T@9&YI=0!W('1Y;2!S86UY;2!D;FEU('1Y9V]D;FEA
M`&)E>B!N87IW>0!V0V%R9`!T>61Z:67Q`'1Y9'II9?$H='EG;V1N:64I('<Z
M`'1Y9V]D;FEE`')O:RAL871A*0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O<'1?0E(O
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-3(`,#(P-S`Q`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L
M:71H+VQO8V%L92]P=%]"4B],0U]-15-304=%4R\`````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,@`P,C(T-C8`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+W!T7T)2+TQ#7TU%4U-!1T53
M+VMR;VYO;&ET:"YM;P```````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-3`P,3$U`#$P-#$W,S8R-S4R`#`R
M-3`S,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25`````.<(```<````5$<``.$+``",C@```````!"^```.````$;X`
M``\````@O@``#0```#"^```(````/KX```L```!'O@``#````%.^```$````
M8+X``!@```!EO@``&P```'Z^```M````FKX``!T```#(O@``)````.:^```I
M````"[\``!D````UOP``)@```$^_```,````=K\``!(```"#OP``)````):_
M```)````N[\```\```#%OP``"P```-6_```?````X;\```X````!P```!0``
M`!#````H````%L````@````_P```"@```$C````5````4\```!(```!IP```
M"P```'S````,````B,```!T```"5P```A0```+/````.````.<$```H```!(
MP0``#0```%/!```.````8<$``!$```!PP0``#0```(+!```,````D,$```T`
M``"=P0``!@```*O!``"4````LL$``$\```!'P@``'0```)?"```=````M<(`
M``H```#3P@``#P```-["```8````[L(```P````'PP``"@```!3#```'````
M'\,```8````GPP``#@```"[#```*````/<,```H```!(PP``#@```%/#```(
M````8L,```H```!KPP``"0```';#```E````@,,``"@```"FPP``)````,_#
M```F````],,``"X````;Q```&@```$K$```R````9<0``#@```"8Q```5```
M`-'$``!1````)L4``%H```!XQ0``5P```-/%```T````*\8```(```!@Q@``
M"0```&/&```-````;<8```<```![Q@``"@```(/&```/````CL8```4```">
MQ@``!@```*3&```1````J\8```@```"]Q@``"0```,;&```)````T,8```@`
M``#:Q@``)0```./&```@````"<<``!,````JQP``$````#['```/````3\<`
M``H```!?QP``$````&K'```#````>\<```\```!_QP``%````(_'```)````
MI,<```D```"NQP``#0```+C'```2````QL<``!D```#9QP``'@```//'```9
M````$L@```\````LR```#P```#S(```-````3,@```H```!:R```#P```&7(
M```(````=<@``"0```!^R```%````*/(```6````N,@```@```#/R```3@``
M`-C(```M````)\D``!D```!5R0``!P```&_)```,````=\D``"P```"$R0``
M#@```+')```#````P,D```\```#$R0``"P```-3)```%````X,D``!0```#F
MR0``%0```/O)```7````$<H``!4````IR@``$@```#_*```3````4LH``!4`
M``!FR@``$P```'S*```*````D,H``!0```";R@``"@```+#*```'````N\H`
M``<```##R@``!0```,O*```%````T<H```H```#7R@```P```.+*```-````
MYLH``!<```#TR@``"@````S+```*````%\L```@````BRP``#P```"O+```+
M````.\L```<```!'RP``#0```$_+```*````7<L```X```!HRP``&````'?+
M```C````D,L```X```"TRP``%````,/+```7````V,L``!<```#PRP``%P``
M``C,```3````(,P```\````TS```#@```$3,```?````4\P``!T```!SS```
M!P```)',```&````F<P```@```"@S```#P```*G,```&````N<P```H```#`
MS```$P```,O,```#````W\P```L```#CS```$````._,```5`````,T``!4`
M```6S0``!P```"S-```0````-,T```4```!%S0``%0```$O-```1````8<T`
M``P```!SS0``.P```(#-```X````O,T```D```#US0``!P```/_-```4````
M!\X```,````<S@``!0```"#.```0````)LX```D````WS@``$P```$'.```Y
M````5<X``!(```"/S@```@```*+.``"T````I<X``"<```!:SP``+````(+/
M```J````K\\``"4```#:SP``"@````#0```)````"]````H````5T```!@``
M`"#0```)````)]````<````QT```+P```#G0```W````:=```"X```"AT```
M50```-#0```M````)M$``"T```!4T0``/0```(+1```_````P-$``"T`````
MT@``0````"[2```C````;](``",```"3T@``0````+?2```M````^-(``#,`
M```FTP``)0```%K3```5````@-,``!D```"6TP``*0```+#3```D````VM,`
M`"@```#_TP``$0```"C4```*````.M0```P```!%U```"@```%+4```0````
M7=0``!8```!NU```%@```(74```'````G-0```<```"DU```%````*S4```*
M````P=0```@```#,U```)P```-74```(````_=0```P````&U0``!P```!/5
M```'````&]4```8````CU0``!0```"K5```'````,-4```8````XU0``"```
M`#_5```I````2-4```X```!RU0``"@```('5```$````C-4```<```"1U0``
M"0```)G5```&````H]4``!$```"JU0``!P```+S5```6````Q-4```0```#;
MU0``"````.#5```&````Z=4```T```#PU0``!@```/[5```>````!=8``!$`
M```DU@``"````#;6```-````/]8```P```!-U@``!P```%K6```$````8M8`
M``,```!GU@```P```&O6```7````;]8```D```"'U@``$P```)'6```=````
MI=8```D```##U@``"````,W6```0````UM8``!T```#GU@``"0````77```;
M````#]<```0````KUP``"````##7```(````.=<``$$```!"UP``&@```(37
M```K````G]<``"````#+UP``&0```.S7```5````!M@```8````<V```!@``
M`"/8```5````*M@```D```!`V```#0```$K8```8````6-@``"(```!QV```
M+@```)38```=````P]@``"$```#AV```5`````/9```I````6-D```H```""
MV0``!P```(W9```'````E=D```D```"=V0``%0```*?9```(````O=D```X`
M``#&V0``"@```-79```/````X-D```T```#PV0``#P```/[9```-````#MH`
M``D````<V@``%````";:```&````.]H``!@```!"V@``'0```%O:```3````
M>=H``!$```"-V@``%````)_:```$````M-H```8```"YV@``%````,#:``!4
M````U=H``&0````JVP``!````(_;```.````E-L```4```"CVP``!0```*G;
M```;````K]L``!H```#+VP``$P```.;;```1````^ML``!$````,W```'```
M`![<``!.````.]P``$4```"*W```10```-#<```J````%MT``#8```!!W0``
M/@```'C=```_````M]T``!T```#WW0``$````!7>```A````)MX```4```!(
MW@``$P```$[>```+````8MX``!,```!NW@``$@```(+>```*````E=X```\`
M``"@W@``#0```+#>```1````OMX``!,```#0W@``#````.3>```&````\=X`
M``P```#XW@``!@````7?```7````#-\``!`````DWP``$0```#7?```(````
M1]\```4```!0WP``#````%;?```0````8]\```4```!TWP``#0```'K?```&
M````B-\``!8```"/WP``!P```*;?```-````KM\```<```"\WP``"P```,3?
M```'````T-\```<```#8WP``"0```.#?```)````ZM\```H```#TWP``&0``
M`/_?```]````&>```!T```!7X```#````'7@```0````@N```!L```"3X```
M"0```*_@```%````N>```"4```"_X```$@```.7@```3````^.```"L````,
MX0``.P```#CA```@````=.$```@```"5X0``-@```)[A```A````U>$``!``
M``#WX0``"`````CB```,````$>(```8````>X@``!````"7B```/````*N(`
M``X````ZX@``0````$GB```'````BN(```H```"2X@``#0```)WB```?````
MJ^(``!P```#+X@``(0```.CB```>````"N,``!D````IXP``'@```$/C```;
M````8N,``"$```!^XP``+@```*#C```F````S^,``!P```#VXP``'@```!/D
M```<````,N0``"8```!/Y```*P```';D```S````HN0``"8```#6Y```*P``
M`/WD```X````*>4``!T```!BY0``%0```(#E```O````EN4``"````#&Y0``
M$@```.?E```I````^N4``!X````DY@``(````$/F```2````9.8``*(```!W
MY@``%@```!KG```C````,><``"@```!5YP``*0```'[G```H````J.<``!\`
M``#1YP``%0```/'G```@````!^@``"4````HZ```*````$[H```M````=^@`
M`#````"EZ```D@```-;H```A````:>D``!8```"+Z0``'````*+I```F````
MO^D``"H```#FZ0``00```!'J``!$````4^H```P```"8Z@``!P```*7J```'
M````K>H```8```"UZ@``#P```+SJ```2````S.H```T```#?Z@``$````.WJ
M```2````_NH```<````1ZP``$P```!GK```2````+>L```<```!`ZP``!```
M`$CK```'````3>L``!````!5ZP``$````&;K```,````=^L```X```"$ZP``
M#0```)/K```/````H>L``!,```"QZP``#0```,7K```H````T^L```,```#\
MZP``#0````#L```&````#NP``!$````5[```%P```"?L```;````/^P```X`
M``!;[````@```&KL``!)````;>P```4```"W[```$P```+WL```0````T>P`
M``\```#B[```!````/+L```-````]^P```X````%[0```P```!3M```&````
M&.T```<````?[0``#@```"?M```(````-NT```\````_[0``"````$_M```/
M````6.T```<```!H[0``$````'#M```-````@>T``!````"/[0``#0```*#M
M```+````KNT```8```"Z[0``"0```,'M```+````R^T```P```#7[0``#```
M`.3M```*````\>T``!$```#\[0``&0````[N```+````*.X```T````T[@``
M(@```$+N```;````9>X``#0```"![@``"@```+;N```8````P>X``!D```#:
M[@``7````/3N```6````4>\``"(```!H[P``#0```(OO```'````F>\```P`
M``"A[P``%````*[O```+````P^\``"(```#/[P``+P```/+O```+````(O``
M``D````N\```&0```#CP```+````4O```!<```!>\```%P```';P```)````
MCO````<```"8\```%@```*#P```1````M_````\```#)\```&0```-GP```6
M````\_````X````*\0``&````!GQ```(````,O$```T````[\0``)@```$GQ
M```Y````</$```X```"J\0``0P```+GQ```(````_?$``!(````&\@``'P``
M`!GR```(````.?(```L```!"\@``+P```$[R```.````?O(```4```"-\@``
M!P```)/R```(````F_(```8```"D\@``10```*OR```#````\?(```<```#U
M\@``!````/WR```'`````O,```X````*\P``"@```!GS```.````)/,```H`
M```S\P``#P```#[S```0````3O,``!<```!?\P``%0```'?S```.````C?,`
M`!H```"<\P``$0```+?S```9````R?,``!<```#C\P``"0```/OS```%````
M!?0```L````+]```"@```!?T```"````(O0```4````E]```#0```"OT```;
M````.?0``!<```!5]```%````&WT```)````@O0```X```",]```#0```)OT
M```2````J?0```0```"\]```.````,'T```@````^O0```@````;]0``!@``
M`"3U```(````*_4```@````T]0``#@```#WU``![````3/4``!@```#(]0``
M&````.'U```1````^O4```<````,]@``!0```!3V```8````&O8``!X````S
M]@``&P```%+V```9````;O8``#$```"(]@``&P```+KV```9````UO8``!,`
M``#P]@``!P````3W```(````#/<```8````5]P``!@```!SW```,````(_<`
M``X````P]P``#0```#_W```3````3?<``!X```!A]P``&0```(#W```0````
MFO<```\```"K]P``$````+OW```/````S/<```L```#<]P``#P```.CW```,
M````^/<```\````%^```!P```!7X```&````'?@```P````D^```#@```#'X
M```,````0/@``"@```!-^```#P```';X```(````AO@```8```"/^```#P``
M`);X```(````IO@``!,```"O^```'@```,/X```A````XO@``"`````$^0``
M&0```"7Y```7````/_D``"4```!7^0``%P```'WY```6````E?D```0```"L
M^0``&P```+'Y```-````S?D```P```#;^0```P```.CY```%````[/D```@`
M``#R^0``"@```/OY```,````!OH```L````3^@``$````!_Z```,````,/H`
M``X````]^@``"P```$SZ```$````6/H```0```!=^@``$P```&+Z```4````
M=OH```P```"+^@``"0```)CZ```.````HOH```L```"Q^@``&P```+WZ```'
M````V?H```0```#A^@``!P```.;Z```*````[OH```T```#Y^@``"0````?[
M```$````$?L```4````6^P```P```!S[```8````(/L```H````Y^P``!```
M`$3[```F````2?L```X```!P^P``?````'_[```5````_/L```4````2_```
M!P```!C\```,````(/P```@````M_```"@```#;\```&````0?P```@```!(
M_````@```%'\```&````5/P```8```!;_```%````&+\```$````=_P``!4`
M``!\_```#0```)+\```0````H/P``!L```"Q_```!@```,W\```$````U/P`
M``D```#9_```$````./\```)````]/P```D```#^_```!@````C]```%````
M#_T``!H````5_0``"````##]```&````.?T```0```!`_0``!P```$7]```9
M````3?T```X```!G_0``!P```';]```'````?OT```4```"&_0``"0```(S]
M```*````EOT```X```"A_0```@```+#]```&````L_T```L```"Z_0``#0``
M`,;]```'````U/T```D```#<_0``!@```.;]```2````[?T```D`````_@``
M!P````K^```4````$OX``!T````G_@``0@```$7^```E````B/X``"4```"N
M_@``!@```-3^```*````V_X```0```#F_@``"0```.O^```(````]?X``!$`
M``#^_@``"0```!#_```&````&O\```T````A_P``!@```"__```$````-O\`
M`#D````[_P``/0```'7_```Z````L_\``!X```#N_P``!0````T``0`.````
M$P`!``0````B``$`!@```"<``0`'````+@`!`"$````V``$`#0```%@``0`5
M````9@`!``8```!\``$`!````(,``0`1````B``!``8```":``$`"@```*$`
M`0`B````K``!``0```#/``$`!P```-0``0`$````W``!``4```#A``$`'0``
M`.<``0`$````!0$!``P````*`0$`#@```!<!`0`*````)@$!``@````Q`0$`
M"0```#H!`0`%````1`$!`#H```!*`0$`,````(4!`0`U````M@$!`"D```#L
M`0$`1P```!8"`0`X````7@(!`"D```"7`@$`/P```,$"`0`N`````0,!`"T`
M```P`P$`'P```%X#`0`/````?@,!`!(```".`P$`"P```*$#`0`'````K0,!
M`"8```"U`P$`/````-P#`0`I````&00!`#H```!#!`$`)````'X$`0`F````
MHP0!``@```#*!`$`"@```-,$`0`)````W@0!``<```#H!`$`(````/`$`0`@
M````$04!`"8````R!0$`"@```%D%`0`9````9`4!`"D```!^!0$`%@```*@%
M`0`2````OP4!``<```#2!0$`"@```-H%`0`,````Y04!``\```#R!0$`$```
M``(&`0!`````$P8!`'````!4!@$`9@```,4&`0#1````+`<!``X```#^!P$`
M"0````T(`0`*````%P@!`!(````B"`$`$P```#4(`0`,````20@!``8```!6
M"`$`&````%T(`0`/````=@@!`!8```"&"`$`$@```)T(`0`0````L`@!`!$`
M``#!"`$`'````-,(`0`C````\`@!`&H````4"0$`#P```'\)`0`%````CPD!
M`!````"5"0$`"0```*8)`0`$````L`D!``L```"U"0$`(````,$)`0`4````
MX@D!``P```#W"0$`#`````0*`0`/````$0H!`!4````A"@$`*0```#<*`0`J
M````80H!`"8```","@$`)P```+,*`0`I````VPH!`"H````%"P$`&0```#`+
M`0!"````2@L!`!$```"-"P$`$@```)\+`0`3````L@L!`!0```#&"P$`#P``
M`-L+`0`6````ZPL!`!<````"#`$`$````!H,`0`1````*PP!`#0````]#`$`
M$P```'(,`0`2````A@P!`#4```"9#`$`%````,\,`0`'````Y`P!``P```#L
M#`$`(````/D,`0`0````&@T!`!0````K#0$`$0```$`-`0`7````4@T!`!P`
M``!J#0$`$P```(<-`0`4````FPT!`!H```"P#0$`$0```,L-`0`:````W0T!
M`!X```#X#0$`&@```!<.`0`3````,@X!`!4```!&#@$`$0```%P.`0`7````
M;@X!`!0```"&#@$`%P```)L.`0`5````LPX!``D```#)#@$`$````-,.`0`9
M````Y`X!``0```#^#@$`!P````,/`0`+````"P\!`!$````7#P$`!@```"D/
M`0`&````,`\!``8````W#P$`!0```#X/`0`'````1`\!``<```!,#P$`!0``
M`%0/`0`6````6@\!``8```!Q#P$`!@```'@/`0`$````?P\!``0```"$#P$`
M!P```(D/`0`.````D0\!``P```"@#P$`#````*T/`0`-````N@\!``H```#(
M#P$`#@```-,/`0`%````X@\!`"@```#H#P$`#@```!$0`0`,````(!`!``\`
M```M$`$`"@```#T0`0`(````2!`!``D```!1$`$`*P```%L0`0`(````AQ`!
M``0```"0$`$`"````)40`0`F````GA`!`!(```#%$`$`#P```-@0`0`&````
MZ!`!``H```#O$`$`!P```/H0`0`(`````A$!`"`````+$0$`#0```"P1`0`)
M````.A$!``T```!$$0$`"@```%(1`0`4````71$!``P```!R$0$`#0```'\1
M`0`)````C1$!``X```"7$0$`%@```*81`0`1````O1$!``D```#/$0$`!@``
M`-D1`0`#````X!$!``8```#D$0$`&0```.L1`0`'````!1(!``0````-$@$`
M"P```!(2`0`+````'A(!``<````J$@$`!0```#(2`0`'````.!(!`!8```!`
M$@$`#0```%<2`0`-````91(!``H```!S$@$`$````'X2`0`/````CQ(!`!$`
M``"?$@$`%P```+$2`0`*````R1(!`!$```#4$@$`"````.82`0`>````[Q(!
M``0````.$P$`#P```!,3`0`Z````(Q,!``4```!>$P$`#````&03`0`>````
M<1,!``X```"0$P$`$````)\3`0`+````L!,!``P```"\$P$`"0```,D3`0`'
M````TQ,!``H```#;$P$`"0```.83`0`.````\!,!`!````#_$P$`&P```!`4
M`0`8````+!0!`!H```!%%`$`"@```&`4`0`)````:Q0!``D```!U%`$`"@``
M`'\4`0`,````BA0!``\```"7%`$`"````*<4`0`&````L!0!`!P```"W%`$`
M!P```-04`0`%````W!0!``L```#B%`$`1P```.X4`0`-````-A4!``D```!$
M%0$`!````$X5`0`#````4Q4!`!,```!7%0$`$P```&L5`0`3````?Q4!``H`
M``"3%0$``@```)X5`0`$````H14!`"4```"F%0$``P```,P5`0`%````T!4!
M`"H```#6%0$`"@````$6`0`%````#!8!``0````2%@$`"@```!<6`0`-````
M(A8!``8````P%@$`"````#<6`0`(````0!8!``0```!)%@$`!0```$X6`0`8
M````5!8!`&@```!M%@$`"0```-86`0`,````X!8!`!````#M%@$`!0```/X6
M`0`&````!!<!`!L````+%P$`+P```"<7`0`0````5Q<!``H```!H%P$`#P``
M`',7`0`*````@Q<!``D```".%P$`$P```)@7`0`;````K!<!`!@```#(%P$`
M%P```.$7`0`8````^1<!`!\````2&`$`#@```#(8`0`#````01@!``<```!%
M&`$``@```$T8`0`(````4!@!``<```!9&`$`!P```&$8`0`+````:1@!``D`
M``!U&`$`"@```'\8`0`+````BA@!``<```"6&`$`40```)X8`0`0````\!@!
M``P````!&0$`#0````X9`0`:````'!D!`$H````W&0$`&0```((9`0`&````
MG!D!`!H```"C&0$`)0```+X9`0`&````Y!D!``8```#K&0$`'P```/(9`0`&
M````$AH!``D````9&@$`&````",:`0`7````/!H!`"@```!4&@$`"0```'T:
M`0`&````AQH!``T```".&@$`$@```)P:`0`B````KQH!`%<```#2&@$`$P``
M`"H;`0`C````/AL!`!,```!B&P$``@```'8;`0`+````>1L!``@```"%&P$`
M#0```(X;`0`*````G!L!``<```"G&P$`%````*\;`0`&````Q!L!``8```#+
M&P$`"````-(;`0`%````VQL!``H```#A&P$`#@```.P;`0`'````^QL!`!,`
M```#'`$`%0```!<<`0`,````+1P!``T````Z'`$`"@```$@<`0`+````4QP!
M`#(```!?'`$`!P```)(<`0`,````FAP!``T```"G'`$`#````+4<`0`)````
MPAP!``D```#,'`$`"@```-8<`0`'````X1P!``D```#I'`$`!P```/,<`0`*
M````^QP!`!L````&'0$`#P```"(=`0!"````,AT!`!(```!U'0$`"@```(@=
M`0`6````DQT!``P```"J'0$`#0```+<=`0`0````Q1T!``D```#6'0$`$```
M`.`=`0`'````\1T!`!(```#Y'0$`!`````P>`0`'````$1X!``4````9'@$`
M!0```!\>`0`+````)1X!`!0````Q'@$`$0```$8>`0`:````6!X!`!8```!S
M'@$`%````(H>`0`7````GQX!`!@```"W'@$`'````-`>`0`9````[1X!``<`
M```''P$`!0````\?`0`-````%1\!``P````C'P$`"0```#`?`0`1````.A\!
M``@```!,'P$`%P```%4?`0`+````;1\!`$H```!Y'P$`#````,0?`0`?````
MT1\!`!H```#Q'P$`$P````P@`0`$````("`!``H````E(`$`!````#`@`0`-
M````-2`!``T```!#(`$`"````%$@`0`*````6B`!``D```!E(`$`"0```&\@
M`0`(````>2`!``P```""(`$`"0```(\@`0`%````F2`!``D```"?(`$`!0``
M`*D@`0`'````KR`!``4```"W(`$`!````+T@`0`"````PB`!``@```#%(`$`
M#````,X@`0`X````VR`!`"P````4(0$`$@```$$A`0`I````5"$!`#(```!^
M(0$`)0```+$A`0`*````UR$!`"P```#B(0$`+@````\B`0`S````/B(!`#,`
M``!R(@$`.````*8B`0`/````WR(!`!@```#O(@$`"P````@C`0`4````%",!
M`!`````I(P$`+````#HC`0`<````9R,!``\```"$(P$`$P```)0C`0`5````
MJ",!`!0```"^(P$`$@```-,C`0`4````YB,!`!4```#[(P$`+0```!$D`0`M
M````/R0!`#$```!M)`$`+@```)\D`0`O````SB0!`"P```#^)`$`8@```"LE
M`0`3````CB4!``T```"B)0$`#0```+`E`0`(````OB4!`!<```#')0$`"```
M`-\E`0`,````Z"4!`"L```#U)0$`(0```"$F`0`:````0R8!`!P```!>)@$`
M"0```'LF`0!%````A28!`$$```#+)@$`!`````TG`0`3````$B<!`!0````F
M)P$`#@```#LG`0`3````2B<!`!@```!>)P$`!@```'<G`0`)````?B<!``H`
M``"()P$`#P```),G`0`)````HR<!`!````"M)P$`!P```+XG`0`.````QB<!
M``4```#5)P$`&P```-LG`0`-````]R<!``@````%*`$``P````XH`0`&````
M$B@!`!0````9*`$`$0```"XH`0`.````0"@!`#@```!/*`$``@```(@H`0`&
M````BR@!``X```"2*`$`!0```*$H`0`'````IR@!``X```"O*`$`!@```+XH
M`0`H````Q2@!``P```#N*`$`'````/LH`0`$````&"D!``(````=*0$`)@``
M`"`I`0`6````1RD!`!0```!>*0$`*0```',I`0`7````G2D!`!\```"U*0$`
M7````-4I`0`4````,BH!`#X```!'*@$`'P```(8J`0`0````IBH!``@```"W
M*@$`$@```,`J`0`'````TRH!``X```#;*@$`#````.HJ`0`,````]RH!`!,`
M```$*P$`"@```!@K`0`=````(RL!`!D```!!*P$`!0```%LK`0`1````82L!
M``@```!S*P$`!0```'PK`0`1````@BL!``D```"4*P$`)````)XK`0`2````
MPRL!`!4```#6*P$`$@```.PK`0`.````_RL!`!D````.+`$`"````"@L`0`)
M````,2P!``(````[+`$`#0```#XL`0`'````3"P!``H```!4+`$`!P```%\L
M`0`/````9RP!``8```!W+`$`"P```'XL`0`:````BBP!``H```"E+`$`!P``
M`+`L`0`(````N"P!``4```#!+`$`'P```,<L`0`&````YRP!`!````#N+`$`
M"````/\L`0`-````""T!``@````6+0$`'@```!\M`0`2````/BT!`"P```!1
M+0$`&@```'XM`0`)````F2T!``H```"C+0$`%0```*XM`0`0````Q"T!``4`
M``#5+0$`%````-LM`0`$````\"T!``<```#U+0$`$````/TM`0`&````#BX!
M``<````5+@$`'@```!TN`0`H````/"X!`!X```!E+@$`"@```(0N`0`<````
MCRX!`!$```"L+@$`"P```+XN`0`:````RBX!`!0```#E+@$`!````/HN`0`$
M````_RX!``L````$+P$`!0```!`O`0`&````%B\!``@````=+P$`!@```"8O
M`0`*````+2\!`!L````X+P$`-````%0O`0`T````B2\!`"````"^+P$`*0``
M`-\O`0`@````"3`!`$$````J,`$`&@```&PP`0`H````AS`!`"D```"P,`$`
M4````-HP`0`B````*S$!``8```!.,0$`"````%4Q`0`%````7C$!``X```!D
M,0$`"````',Q`0`9````?#$!`!D```"6,0$`*@```+`Q`0`C````VS$!`!D`
M``#_,0$`+@```!DR`0`T````2#(!``@```!],@$`%P```(8R`0`*````GC(!
M``<```"I,@$`(0```+$R`0`,````TS(!``T```#@,@$`#````.XR`0`0````
M^S(!``X````,,P$`"P```!LS`0`'````)S,!`!,````O,P$`"````$,S`0`+
M````3#,!``H```!8,P$`%````&,S`0`/````>#,!`#(```"(,P$`"P```+LS
M`0`%````QS,!``4```#-,P$`!0```-,S`0`7````V3,!``\```#Q,P$`!```
M``$T`0`*````!C0!``D````1-`$`"P```!LT`0`-````)S0!``P````U-`$`
M#@```$(T`0`%````430!``0```!7-`$`#0```%PT`0`R````:C0!`$4```"=
M-`$`"P```.,T`0`*````[S0!``\```#Z-`$`$P````HU`0`3````'C4!``\`
M```R-0$`#````$(U`0`.````3S4!``T```!>-0$`#0```&PU`0`7````>C4!
M``<```"2-0$`'@```)HU`0`4````N34!``4```#.-0$`%````-0U`0`&````
MZ34!``<```#P-0$`#````/@U`0`0````!38!`!$````6-@$`#@```"@V`0`J
M````-S8!``8```!B-@$`"0```&DV`0`/````<S8!``P```"#-@$`#0```)`V
M`0`1````GC8!``L```"P-@$`-@```+PV`0`*````\S8!`"(```#^-@$`"P``
M`"$W`0`/````+3<!`'T````]-P$`,@```+LW`0`E````[C<!``@````4.`$`
M,````!TX`0`Q````3C@!`"T```"`.`$`$@```*XX`0`.````P3@!``4```#0
M.`$`#@```-8X`0`3````Y3@!`!$```#Y.`$`"`````LY`0`2````%#D!``<`
M```G.0$`$0```"\Y`0`3````03D!``<```!5.0$`%````%TY`0`8````<CD!
M``<```"+.0$`!0```),Y`0`,````F3D!``P```"F.0$`$@```+,Y`0`$````
MQCD!``<```#+.0$`"@```-,Y`0`+````WCD!``P```#J.0$`#@```/<Y`0`.
M````!CH!``4````5.@$`!0```!LZ`0`N````(3H!`"8```!0.@$`(P```'<Z
M`0`#````FSH!`!(```"?.@$`!@```+(Z`0`>````N3H!`!@```#8.@$`)0``
M`/$Z`0`-````%SL!``D````E.P$`'P```"\[`0`#````3SL!``<```!3.P$`
M"@```%L[`0`"````9CL!``P```!I.P$`%0```'8[`0`+````C#L!`!D```"8
M.P$`(````+([`0`2````TSL!``4```#F.P$`"@```.P[`0`5````]SL!`!(`
M```-/`$`"````"`\`0`,````*3P!``0````V/`$`"0```#L\`0`'````13P!
M``L```!-/`$`#@```%D\`0`*````:#P!``P```!S/`$`4@```(`\`0`7````
MTSP!`"0```#K/`$`$@```!`]`0`'````(ST!``8````K/0$`$````#(]`0`.
M````0ST!``X```!2/0$`(````&$]`0`,````@CT!`!D```"//0$`#0```*D]
M`0`5````MST!`!(```#-/0$`#P```.`]`0`4````\#T!``H````%/@$`&P``
M`!`^`0`0````+#X!`!P````]/@$`6````%H^`0`+````LSX!`"$```"_/@$`
M:0```.$^`0`:````2S\!`!<```!F/P$`&0```'X_`0`:````F#\!`!D```"S
M/P$`)0```,T_`0`G````\S\!`!H````;0`$`%P```#9``0`=````3D`!`"8`
M``!L0`$`&P```)-``0`J````KT`!`!D```#:0`$`'P```/1``0`3````%$$!
M``@````H00$`1````#%!`0`3````=D$!`$````"*00$`!P```,M!`0`(````
MTT$!``D```#<00$`%0```.9!`0`-````_$$!`",````*0@$`#0```"Y"`0`3
M````/$(!``@```!00@$``P```%E"`0`,````74(!`$8```!J0@$`%P```+%"
M`0`.````R4(!`#\```#80@$`30```!A#`0`W````9D,!`%<```">0P$`!0``
M`/9#`0`?````_$,!`"\````<1`$`"@```$Q$`0`3````5T0!`!````!K1`$`
M$0```'Q$`0`(````CD0!``T```"71`$`+0```*5$`0`$````TT0!``T```#8
M1`$`%0```.9$`0`[````_$0!`$\````X10$`'P```(A%`0`6````J$4!`"4`
M``"_10$`*````.5%`0`<````#D8!``L````K1@$`(P```#=&`0`?````6T8!
M`"$```![1@$`'0```)U&`0`E````NT8!`"````#A1@$`)`````)'`0`@````
M)T<!`#````!(1P$`"P```'E'`0`'````A4<!``T```"-1P$`#````)M'`0`7
M````J$<!``8```#`1P$`.0```,='`0`,`````4@!``<````.2`$`"0```!9(
M`0`3````($@!``D````T2`$`!````#Y(`0`0````0T@!``@```!42`$`"```
M`%U(`0`$````9D@!``L```!K2`$`#````'=(`0`2````A$@!`!$```"72`$`
M#````*E(`0`:````MD@!``\```#12`$`!P```.%(`0`-````Z4@!`!0```#W
M2`$`#@````Q)`0`,````&TD!`!L````H20$`+````$1)`0`3````<4D!`!P`
M``"%20$`*````*))`0`&````RTD!``<```#220$`$P```-I)`0`%````[DD!
M``0```#T20$`%P```/E)`0`*````$4H!``P````<2@$`"0```"E*`0`&````
M,TH!``D````Z2@$`!@```$1*`0`(````2TH!``D```!42@$`"@```%Y*`0`(
M````:4H!``H```!R2@$`"@```'U*`0`'````B$H!`!$```"02@$`!@```*)*
M`0`.````J4H!``X```"X2@$`#0```,=*`0`+````U4H!`!T```#A2@$`"P``
M`/]*`0`"````"TL!`!P````.2P$`!P```"M+`0`&````,TL!`&0````Z2P$`
M"0```)]+`0`'````J4L!`"8```"Q2P$`.````-A+`0`:````$4P!`"H````L
M3`$`.P```%=,`0`H````DTP!`#0```"\3`$`&0```/%,`0`5````"TT!``4`
M```A30$`!P```"=-`0`(````+TT!``<````X30$`!@```$!-`0`%````1TT!
M``<```!-30$`#@```%5-`0`)````9$T!``8```!N30$`"````'5-`0`+````
M?DT!``<```"*30$`"````))-`0`'````FTT!`!8```"C30$`"0```+I-`0`&
M````Q$T!``L```#+30$`$````-=-`0`&````Z$T!`!P```#O30$`%`````Q.
M`0`'````(4X!`!$````I3@$`"````#M.`0`.````1$X!``@```!33@$`!0``
M`%Q.`0`0````8DX!``D```!S3@$`$````'U.`0`&````CDX!`!D```"53@$`
M"@```*].`0`<````NDX!``<```#73@$`!0```-].`0`0````Y4X!`!0```#V
M3@$`"P````M/`0`-````%T\!`"@````E3P$`&````$Y/`0`7````9T\!``D`
M``!_3P$`!````(E/`0`)````CD\!``H```"83P$`!P```*-/`0`"````JT\!
M``X```"N3P$`"````+U/`0`X````QD\!`",```#_3P$`'P```"-0`0`X````
M0U`!`"8```!\4`$`,0```*-0`0`G````U5`!`&0```#]4`$`%````&)1`0`D
M````=U$!`",```"<40$`(P```,!1`0`K````Y%$!`"$````04@$`)````#)2
M`0!5````5U(!`#@```"M4@$`2@```.92`0!;````,5,!`"@```"-4P$`.```
M`+93`0`O````[U,!`$4````?5`$`2@```&54`0!&````L%0!`#,```#W5`$`
M*````"M5`0`L````5%4!`"8```"!50$`&P```*A5`0`^````Q%4!`#H````#
M5@$`J0$``#Y6`0`C````Z%<!`!<````,6`$`2````"18`0"%````;5@!`#``
M``#S6`$`)0```"19`0!!````2ED!`%L```",60$`20```.A9`0`Q````,EH!
M`&D```!D6@$`'0```,Y:`0`8````[%H!`"L````%6P$`(0```#%;`0`?````
M4UL!`"L```!S6P$`)@```)];`0`G````QEL!`#H```#N6P$`'0```"E<`0`1
M````1UP!`#,```!97`$`)0```(U<`0`G````LUP!`"````#;7`$`,@```/Q<
M`0`?````+UT!`#````!/70$`:0```(!=`0`Q````ZET!`$$````<7@$`,P``
M`%Y>`0`E````DEX!`#T```"X7@$`90```/9>`0!-````7%\!`"T```"J7P$`
M)P```-A?`0`O`````&`!`"@````P8`$`+@```%E@`0`P````B&`!`%0```"Y
M8`$`)P````YA`0!:````-F$!`#H```"180$`2````,QA`0!*````%6(!`!\`
M``!@8@$`,@```(!B`0`O````LV(!`"P```#C8@$`+0```!!C`0!Q````/F,!
M`&8```"P8P$`;P```!=D`0"S````AV0!`!<````[90$`)0```%-E`0`R````
M>64!`"D```"L90$`/@```-9E`0`B````%68!`%(````X9@$`(@```(MF`0`E
M````KF8!``L```#49@$`L0```.!F`0`@````DF<!`$4```"S9P$`(0```/EG
M`0`P````&V@!`"4```!,:`$`'````')H`0`Q````CV@!``<```#!:`$`"```
M`,EH`0`'````TF@!``0```#::`$`"@```-]H`0`-````ZF@!``L```#X:`$`
M#@````1I`0`)````$VD!``L````=:0$`!@```"EI`0`%````,&D!`!`````V
M:0$``@```$=I`0!9````2FD!``4```"D:0$`$@```*II`0`$````O6D!``<`
M``#":0$`"````,II`0`%````TVD!``,```#9:0$`$````-UI`0`,````[FD!
M`!,```#[:0$`#0````]J`0`"````'6H!``<````@:@$`!P```"AJ`0`&````
M,&H!`!0````W:@$`#````$QJ`0`8````66H!``8```!R:@$`!````'EJ`0`2
M````?FH!``P```"1:@$``P```)YJ`0`J````HFH!``0```#-:@$`!@```-)J
M`0`'````V6H!`!\```#A:@$`-0````%K`0`N````-VL!`"\```!F:P$`%P``
M`)9K`0`B````KFL!`"4```#1:P$`(````/=K`0`;````&&P!`!@````T;`$`
M)````$UL`0`?````<FP!`!H```"2;`$`(0```*UL`0`@````SVP!`!H```#P
M;`$`,@````MM`0`9````/FT!`!H```!8;0$`+P```'-M`0`4````HVT!`"L`
M``"X;0$`'P```.1M`0`C````!&X!`!\````H;@$`&@```$AN`0`A````8VX!
M`"4```"%;@$`)@```*MN`0`E````TFX!`"0```#X;@$`&````!UO`0`=````
M-F\!`"0```!4;P$`&````'EO`0`B````DF\!`"P```"U;P$`+P```.)O`0`5
M````$G`!`"4````H<`$`&0```$YP`0`\````:'`!`!\```"E<`$`(P```,5P
M`0`?````Z7`!`"`````)<0$`&@```"IQ`0`O````17$!`!@```!U<0$`)@``
M`(YQ`0`>````M7$!`"D```#4<0$`'@```/YQ`0`Q````'7(!``D```!/<@$`
M#````%ER`0`7````9G(!`"\```!^<@$`)````*YR`0`'````TW(!``\```#;
M<@$`%````.MR`0`.`````',!``T````/<P$`)````!US`0`%````0G,!``<`
M``!(<P$`(@```%!S`0`E````<W,!`!H```"9<P$`'0```+1S`0`:````TG,!
M``<```#M<P$`QP```/5S`0`+````O70!`!P```#)=`$`%0```.9T`0`&````
M_'0!``D````#=0$`"P````UU`0`-````&74!``P````G=0$`%P```#1U`0`&
M````3'4!`#,```!3=0$`$P```(=U`0`3````FW4!``<```"O=0$`#P```+=U
M`0`'````QW4!`#(```#/=0$`!`````)V`0`A````!W8!`!,````I=@$`#@``
M`#UV`0`,````3'8!`!$```!9=@$`,@```&MV`0`6````GG8!``@```"U=@$`
M'0```+YV`0`)````W'8!``H```#F=@$`%````/%V`0`*````!G<!`!T````1
M=P$`"````"]W`0`?````.'<!``@```!8=P$`&@```&%W`0`G````?'<!``8`
M``"D=P$`%0```*MW`0`'````P7<!``@```#)=P$`"0```-)W`0`_````W'<!
M``<````<>`$`#P```"1X`0`.````-'@!`!````!#>`$`"0```%1X`0`)````
M7G@!``@```!H>`$`$P```'%X`0`'````A7@!``@```"->`$`&0```)9X`0`*
M````L'@!`!<```"[>`$`%````--X`0`*````Z'@!``P```#S>`$`%P````!Y
M`0`$````&'D!`"H````=>0$`#````$AY`0`1````57D!``<```!G>0$``@``
M`&]Y`0`0````<GD!`!@```"#>0$`"P```)QY`0`#````J'D!``@```"L>0$`
M"0```+5Y`0`$````OWD!``<```#$>0$`!P```,QY`0`&````U'D!`!0```#;
M>0$`!P```/!Y`0`-````^'D!``L````&>@$`%````!)Z`0`5````)WH!``X`
M```]>@$`+P```$QZ`0`@````?'H!`!P```"=>@$`2````+IZ`0!,`````WL!
M`!4```!0>P$`#````&9[`0`Q````<WL!``4```"E>P$`$@```*M[`0`_````
MOGL!`!(```#^>P$`"@```!%\`0`&````''P!``0````C?`$`!````"A\`0`*
M````+7P!`!,````X?`$`!0```$Q\`0`&````4GP!``8```!9?`$`"````&!\
M`0`$````:7P!``P```!N?`$`"@```'M\`0`)````AGP!`#D```"0?`$`+@``
M`,I\`0`I````^7P!``4````C?0$`&````"E]`0`9````0GT!`!\```!<?0$`
M'0```'Q]`0`1````FGT!``(```"L?0$`!````*]]`0`*````M'T!``0```"_
M?0$`!@```,1]`0`4````RWT!``4```#@?0$``P```.9]`0`,````ZGT!`$4`
M``#W?0$`,@```#U^`0`R````<'X!`"\```"C?@$`&@```--^`0`Z````[GX!
M`#0````I?P$`*````%Y_`0!3````AW\!`),```#;?P$`+P```&^``0!"````
MGX`!`#````#B@`$`+@```!.!`0`9````0H$!`"<```!<@0$`.````(2!`0`X
M````O8$!`#<```#V@0$`<@```"Z"`0`@````H8(!`#4```#"@@$`(0```/B"
M`0!%````&H,!`#````!@@P$`*0```)&#`0`A````NX,!`"@```#=@P$`*0``
M``:$`0`F````,(0!`"4```!7A`$`*````'V$`0`H````IH0!`"(```#/A`$`
M*P```/*$`0!%````'H4!`$D```!DA0$`1@```*Z%`0`\````]84!`#`````R
MA@$`$@```&.&`0`3````=H8!`!````"*A@$`>0```)N&`0`)````%8<!`*$`
M```?AP$`<P```,&'`0!\````-8@!`"L```"RB`$`5````-Z(`0`7````,XD!
M`!4```!+B0$`)P```&&)`0`6````B8D!``\```"@B0$`%P```+")`0`?````
MR(D!`$````#HB0$`'P```"F*`0`<````28H!`%$```!FB@$`&@```+B*`0`4
M````TXH!``H```#HB@$`!0```/.*`0`&````^8H!``@`````BP$`!0````F+
M`0`2````#XL!`!`````BBP$`$P```#.+`0`=````1XL!``\```!EBP$`#P``
M`'6+`0`/````A8L!``8```"5BP$`#0```)R+`0`$````JHL!``D```"OBP$`
M"P```+F+`0`%````Q8L!``4```#+BP$`!P```-&+`0`%````V8L!`!0```#?
MBP$`#@```/2+`0`'`````XP!``@````+C`$`#P```!2,`0`-````)(P!``H`
M```RC`$`"````#V,`0`,````1HP!``8```!3C`$`#P```%J,`0`'````:HP!
M``8```!RC`$`%````'F,`0`&````CHP!``8```"5C`$`#````)R,`0`1````
MJ8P!`!<```"[C`$`"````-.,`0`$````W(P!`!D```#AC`$`$0```/N,`0`*
M````#8T!`!@````8C0$`$P```#&-`0`<````18T!`!$```!BC0$``P```'2-
M`0`&````>(T!``0```!_C0$`!````(2-`0`/````B8T!``H```"9C0$`"@``
M`*2-`0`'````KXT!``0```"WC0$`!````+R-`0`9````P8T!``<```#;C0$`
M`@```..-`0`"````YHT!`!$```#IC0$`"0```/N-`0`&````!8X!`!(````,
MC@$`%P```!^.`0`&````-XX!`"<````^C@$``@```&:.`0`(````:8X!``0`
M``!RC@$`#P```'>.`0`3````AXX!``<```";C@$`"P```*..`0`0````KXX!
M`!,```#`C@$`!P```-2.`0`1````W(X!``8```#NC@$`&````/6.`0`&````
M#H\!`!,````5CP$`$````"F/`0`2````.H\!``(```!-CP$`!@```%"/`0`,
M````5X\!``D```!DCP$`$0```&Z/`0`B````@(\!``<```"CCP$`!P```*N/
M`0`+````LX\!`!,```"_CP$`!0```-./`0`1````V8\!``(```#KCP$`"P``
M`.Z/`0`$````^H\!``L```#_CP$`!0````N0`0`'````$9`!`*D!```9D`$`
M$````,.1`0`5````U)$!``T```#JD0$`!P```/B1`0`)`````)(!``@````*
MD@$``P```!.2`0`8````%Y(!`!X````PD@$`+P```$^2`0`K````?Y(!`"D`
M``"KD@$`+0```-62`0`9`````Y,!`"H````=DP$`"@```$B3`0`:````4Y,!
M`!X```!NDP$`"@```(V3`0`2````F),!``H```"KDP$`'P```+:3`0`7````
MUI,!``4```#NDP$`*````/23`0`2````'90!``X````PE`$`$P```#^4`0`-
M````4Y0!``H```!AE`$`$````&R4`0`@````?90!`)(```">E`$`$````#&5
M`0`*````0I4!`!(```!-E0$`#0```&"5`0`;````;I4!``P```"*E0$`#P``
M`)>5`0`6````IY4!``8```"^E0$`F0```,65`0!4````7Y8!`"@```"TE@$`
M*````-V6`0`(````!I<!``T````/EP$`&````!V7`0`/````-I<!``X```!&
MEP$`"````%67`0`&````7I<!`!````!EEP$`"@```':7`0`*````@9<!`!``
M``",EP$`"````)V7`0`*````II<!`!````"QEP$`*0```,*7`0`F````[)<!
M`"H````3F`$`)0```#Z8`0`\````9)@!`!4```"AF`$`0P```+>8`0!)````
M^Y@!`%4```!%F0$`30```)N9`0!R````Z9D!`&H```!<F@$`1@```,>:`0`"
M````#IL!`!`````1FP$`%@```"*;`0`.````.9L!`!````!(FP$`$@```%F;
M`0`%````;)L!``8```!RFP$`$0```'F;`0`(````BYL!``D```"4FP$`"0``
M`)Z;`0`&````J)L!`"4```"OFP$`(P```-6;`0`0````^9L!``X````*G`$`
M$0```!F<`0`&````*YP!`!(````RG`$`"0```$6<`0`;````3YP!`"$```!K
MG`$`$````(V<`0`.````GIP!`!0```"MG`$`&````,*<`0`E````VYP!`"H`
M```!G0$`(````"R=`0`5````39T!`!H```!CG0$`%P```'Z=`0`0````EIT!
M`!<```"GG0$`#0```+^=`0`U````S9T!`",````#G@$`)@```">>`0`1````
M3IX!`%@```!@G@$`-@```+F>`0`E````\)X!``@````6GP$`%0```!^?`0`W
M````-9\!``T```!MGP$`"````'N?`0`1````A)\!``L```"6GP$`!0```**?
M`0`4````J)\!`!4```"]GP$`%P```-.?`0`7````ZY\!`!(````#H`$`$P``
M`!:@`0`5````*J`!`!4```!`H`$`#0```%:@`0`:````9*`!`!````!_H`$`
M!P```)"@`0`'````F*`!``<```"@H`$`!P```*B@`0`,````L*`!``4```"]
MH`$`$P```,.@`0`;````UZ`!``T```#SH`$`#`````&A`0`.````#J$!`!``
M```=H0$`#@```"ZA`0`(````/:$!`!$```!&H0$`#0```%BA`0`2````9J$!
M`!P```!YH0$`+P```):A`0`)````QJ$!`!8```#0H0$`%@```.>A`0`8````
M_J$!`!X````7H@$`%````#:B`0`2````2Z(!``\```!>H@$`(0```&ZB`0`=
M````D*(!``<```"NH@$`!@```+:B`0`(````O:(!``T```#&H@$`"````-2B
M`0`)````W:(!`!(```#GH@$`"P```/JB`0`)````!J,!`!,````0HP$`&```
M`"2C`0`J````/:,!``<```!HHP$`$@```'"C`0`%````@Z,!`!8```")HP$`
M$@```*"C`0`/````LZ,!`$(```##HP$`.@````:D`0`)````0:0!``<```!+
MI`$`$P```%.D`0`$````9Z0!``4```!LI`$`#0```'*D`0`*````@*0!`!<`
M``"+I`$`0P```*.D`0`5````YZ0!``(```#]I`$`U@````"E`0`D````UZ4!
M`"L```#\I0$`*@```"BF`0`P````4Z8!``@```"$I@$`#0```(VF`0`)````
MFZ8!``8```"EI@$`"0```*RF`0`'````MJ8!`#L```"^I@$`/0```/JF`0`Z
M````.*<!`%\```!SIP$`.0```-.G`0`Y````#:@!`$4```!'J`$`10```(VH
M`0`Y````TZ@!`%(````-J0$`*@```&"I`0`L````BZD!`$D```"XJ0$`.0``
M``*J`0`_````/*H!`"4```!\J@$`%0```**J`0`9````N*H!`"P```#2J@$`
M)@```/^J`0`F````)JL!`!,```!-JP$`"@```&&K`0`1````;*L!``4```!^
MJP$`#````(2K`0`9````D:L!`!L```"KJP$`!P```,>K`0`'````SZL!`!4`
M``#7JP$`"@```.VK`0`(````^*L!`#0````!K`$`$````#:L`0`0````1ZP!
M``H```!8K`$`!P```&.L`0`&````:ZP!``4```!RK`$`"````'BL`0`%````
M@:P!``L```"'K`$`,@```).L`0`6````QJP!``T```#=K`$`!P```.NL`0`'
M````\ZP!``D```#[K`$`!0````6M`0`1````"ZT!``8````=K0$`%````"2M
M`0`%````.:T!``@````_K0$`!@```$BM`0`+````3ZT!``8```!;K0$`(@``
M`&*M`0`&````A:T!``@```",K0$`%````)6M`0`,````JJT!``<```"WK0$`
M!P```+^M`0`#````QZT!``,```#+K0$`&@```,^M`0`'````ZJT!`!H```#R
MK0$`+0````VN`0`'````.ZX!``8```!#K@$`$````$JN`0`B````6ZX!``<`
M``!^K@$`'@```(:N`0`%````I:X!``@```"KK@$`"````+2N`0!:````O:X!
M`"$````8KP$`/````#JO`0`L````=Z\!`"$```"DKP$`(0```,:O`0`&````
MZ*\!``@```#OKP$`'@```/BO`0`)````%[`!``T````AL`$`)@```"^P`0`Q
M````5K`!`#8```"(L`$`*````+^P`0`O````Z+`!`&T````8L0$`.@```(:Q
M`0`*````P;$!``8```#,L0$`"0```-.Q`0`*````W;$!`!(```#HL0$`"0``
M`/NQ`0`,````!;(!`!`````2L@$`%@```".R`0`1````.K(!`!8```!,L@$`
M%@```&.R`0`0````>K(!`!4```"+L@$`!@```*&R`0`;````J+(!`!L```#$
ML@$`%P```."R`0`;````^+(!`!@````4LP$`!@```"VS`0`'````-+,!`!``
M```\LP$`7````$VS`0!@````JK,!``0````+M`$`$@```!"T`0`%````([0!
M``4````IM`$`'````"^T`0`9````3+0!`!0```!FM`$`$0```'NT`0`2````
MC;0!`!H```"@M`$`60```+NT`0!.````%;4!`$@```!DM0$`.@```*VU`0!&
M````Z+4!`$<````OM@$`1@```'>V`0`8````OK8!``\```#7M@$`+P```.>V
M`0`&````%[<!`!0````>MP$`#P```#.W`0`;````0[<!`!,```!?MP$`#P``
M`'.W`0`8````@[<!`!(```"<MP$`%0```*^W`0`3````Q;<!``T```#9MP$`
M!@```.>W`0`2````[K<!``<````!N`$`#@````FX`0`6````&+@!``\````O
MN`$`"````#^X`0`#````2+@!`!````!,N`$`#@```%VX`0`%````;+@!`!,`
M``!RN`$`"@```(:X`0`=````D;@!``<```"ON`$`$````+>X`0`(````R+@!
M``0```#1N`$`!P```-:X`0`'````WK@!``P```#FN`$`"````/.X`0`)````
M_+@!`!H````&N0$`/@```"&Y`0`F````8+D!``T```"'N0$`$````)6Y`0`@
M````IKD!``H```#'N0$`!0```-*Y`0`?````V+D!`!$```#XN0$`$@````JZ
M`0`R````';H!`$(```!0N@$`(0```).Z`0`(````M;H!`$<```"^N@$`*```
M``:[`0`0````+[L!``D```!`NP$`"@```$J[`0`&````5;L!``8```!<NP$`
M$@```&.[`0`.````=KL!`$X```"%NP$`"P```-2[`0`*````X+L!``\```#K
MNP$`+````/N[`0`G````*+P!`#0```!0O`$`+P```(6\`0`F````M;P!`"L`
M``#<O`$`)@````B]`0`E````+[T!`#T```!5O0$`,@```).]`0`I````QKT!
M`"\```#PO0$`)@```""^`0`T````1[X!`$8```!\O@$`00```,.^`0`]````
M!;\!`#T```!#OP$`1P```(&_`0`L````R;\!`"@```#VOP$`1@```!_``0`J
M````9L`!`!0```"1P`$`-0```*;``0`H````W,`!`"P````%P0$`&````#+!
M`0#)````2\$!`!P````5P@$`,@```#+"`0`R````9<(!`#0```"8P@$`,0``
M`,W"`0`I````_\(!`"H````IPP$`*@```%3#`0`R````?\,!`#4```"RPP$`
M20```.C#`0`[````,L0!`*D```!NQ`$`+````!C%`0`E````1<4!`"@```!K
MQ0$`-@```)3%`0`R````R\4!`%D```#^Q0$`3@```%C&`0`-````I\8!``0`
M``"UQ@$`!@```+K&`0`%````P<8!``P```#'Q@$`$0```-3&`0`-````YL8!
M``X```#TQ@$`$`````/'`0`&````%,<!`!4````;QP$`&P```#''`0`'````
M3<<!``0```!5QP$`!0```%K'`0`.````8,<!``X```!OQP$`"@```'['`0`-
M````B<<!`!,```"7QP$`"P```*O'`0`0````M\<!``P```#(QP$`-@```-7'
M`0`&````#,@!``X````3R`$`!@```"+(`0`1````*<@!`!<````[R`$`&P``
M`%/(`0`0````;\@!``(```"`R`$`2@```(/(`0`+````SL@!`!4```#:R`$`
M%0```/#(`0`:````!LD!``0````AR0$`$P```";)`0`/````.LD!``,```!*
MR0$`!@```$[)`0`(````5<D!``\```!>R0$`"````&[)`0`0````=\D!``@`
M``"(R0$`$````)')`0`&````HLD!``T```"IR0$`"@```+?)`0`1````PLD!
M``P```#4R0$`"@```.')`0`'````[,D!``H```#TR0$`#@```/_)`0`.````
M#LH!``T````=R@$`"P```"O*`0`1````-\H!`!H```!)R@$`#@```&3*`0`.
M````<\H!`",```""R@$`'````*;*`0`\````P\H!``T`````RP$`'@````[+
M`0`6````+<L!`&$```!$RP$`%0```*;+`0`T````O,L!``\```#QRP$`"0``
M``',`0`*````"\P!`!,````6S`$`"0```"K,`0`U````-,P!`#<```!JS`$`
M#P```*+,`0`0````LLP!`"4```##S`$`$@```.G,`0`@````_,P!`"`````=
MS0$`"0```#[-`0`&````2,T!`!L```!/S0$`#@```&O-`0`2````>LT!`!D`
M``"-S0$`%0```*?-`0`.````O<T!`!D```#,S0$`!P```.;-`0`+````[LT!
M`"8```#ZS0$`,@```"'.`0`*````5,X!`$@```!?S@$`"@```*C.`0`4````
ML\X!`!\```#(S@$`!@```.C.`0`)````[\X!`#````#YS@$`$````"K/`0`&
M````.\\!``X```!"SP$`!P```%'/`0`'````6<\!`%0```!ASP$``P```+;/
M`0`'````NL\!``8```#"SP$`"0```,G/`0`4````T\\!``P```#HSP$`#@``
M`/7/`0`,````!-`!`!`````1T`$`$0```"+0`0`9````--`!`!8```!.T`$`
M%````&70`0`9````>M`!`!$```"4T`$`&0```*;0`0`9````P-`!``@```#:
MT`$`!0```./0`0`+````Z=`!``L```#UT`$``@````'1`0`&````!-$!`!(`
M```+T0$`)P```![1`0`8````1M$!`!D```!?T0$`"0```'G1`0`3````@]$!
M`!0```"7T0$`'````*S1`0`(````R=$!`$8```#2T0$`+P```!G2`0`*````
M2=(!``@```!4T@$`#0```%W2`0`,````:](!``\```!XT@$`B@```(C2`0`<
M````$],!`!@````PTP$`$````$G3`0`(````6M,!``0```!CTP$`%P```&C3
M`0`K````@-,!`"@```"LTP$`&@```-73`0`P````\-,!`!T````AU`$`$0``
M`#_4`0`3````4=0!``<```!EU`$`!P```&W4`0`&````==0!``8```!\U`$`
M$@```(/4`0`0````EM0!``\```"GU`$`%````+?4`0`I````S-0!`"````#V
MU`$`#P```!?5`0`.````)]4!`!`````VU0$`#@```$?5`0`,````5M4!``X`
M``!CU0$`"P```'+5`0`3````?M4!``@```"2U0$`"````)O5`0`.````I-4!
M`!8```"SU0$`#````,K5`0`U````U]4!`!$````-U@$`"````!_6`0`(````
M*-8!``\````QU@$`%0```$'6`0`E````5]8!`!L```!]U@$`(P```)G6`0`B
M````O=8!`!@```#@U@$`&@```/G6`0`E````%-<!`!D````ZUP$`$@```%37
M`0`%````9]<!`!D```!MUP$`"P```(?7`0`+````D]<!``,```"?UP$`!0``
M`*/7`0`)````J=<!`!````"SUP$`$@```,37`0`1````U]<!``H```#IUP$`
M#P```/37`0`.````!-@!``P````3V`$`!````"#8`0`'````)=@!`"`````M
MV`$`(0```$[8`0`7````<-@!``\```"(V`$`$@```)C8`0`0````J]@!`"(`
M``"\V`$`!P```-_8`0`)````Y]@!``D```#QV`$`#P```/O8`0`/````"]D!
M``D````;V0$`!0```"79`0`*````*]D!``4````VV0$`$P```#S9`0`,````
M4-D!``8```!=V0$`*0```&39`0`.````CMD!`(,```"=V0$`$0```"':`0`+
M````,]H!``4````_V@$`#0```$7:`0`&````4]H!``@```!:V@$`!@```&/:
M`0`1````:MH!``,```!\V@$`!P```(#:`0`&````B-H!`!0```"/V@$`!0``
M`*3:`0`8````JMH!``\```##V@$`$@```-/:`0`<````YMH!``L````#VP$`
M`@````_;`0`%````$ML!`!(````8VP$`"0```"O;`0`-````-=L!``8```!#
MVP$`!0```$K;`0`@````4-L!``@```!QVP$`!@```'K;`0`$````@=L!``4`
M``"&VP$`&@```(S;`0`-````I]L!``<```"UVP$`"````+W;`0`$````QML!
M``D```#+VP$`#0```-7;`0`.````X]L!``(```#RVP$`!@```/7;`0`,````
M_-L!`!,````)W`$`"@```!W<`0`0````*-P!``8````YW`$`$@```$#<`0`*
M````4]P!``<```!>W`$`%P```&;<`0`I````?MP!`$H```"HW`$`)P```//<
M`0`I````&]T!``8```!%W0$`"0```$S=`0`$````5MT!``D```!;W0$`"```
M`&7=`0`7````;MT!`!````"&W0$`!0```)?=`0`,````G=T!``8```"JW0$`
M!````+'=`0!!````MMT!`$(```#XW0$`00```#O>`0`A````?=X!``4```"?
MW@$`#@```*7>`0`'````M-X!``D```"\W@$`"0```,;>`0`;````T-X!`!``
M``#LW@$`%0```/W>`0`&````$]\!``4````:WP$`#P```"#?`0`*````,-\!
M``H````[WP$`'@```$;?`0`'````9=\!``P```!MWP$`!````'K?`0`'````
M?]\!`"0```"'WP$`!@```*S?`0`4````L]\!`!$```#(WP$`$````-K?`0`(
M````Z]\!``D```#TWP$`!0```/[?`0`[````!.`!`#8```!`X`$`0P```'?@
M`0`I````N^`!`$(```#EX`$`0@```"CA`0`K````:^$!`$H```"7X0$`+P``
M`.+A`0`Y````$N(!`"\```!,X@$`$````'SB`0`1````C>(!``L```"?X@$`
M!P```*OB`0`M````L^(!`%,```#AX@$`*0```#7C`0`^````7^,!`"$```">
MXP$`*````,#C`0`'````Z>,!``D```#QXP$`"@```/OC`0`'````!N0!`"0`
M```.Y`$`)@```#/D`0`M````6N0!``L```"(Y`$`&P```)3D`0`M````L.0!
M`!@```#>Y`$`$P```/?D`0`(````"^4!``X````4Y0$`#@```"/E`0`.````
M,N4!`!,```!!Y0$`1````%7E`0!^````FN4!`'$````9Y@$`WP```(OF`0`;
M````:^<!``T```"'YP$`#@```)7G`0`1````I.<!`!(```"VYP$`#P```,GG
M`0`'````V><!`!D```#AYP$`$@```/OG`0`8````#N@!`!,````GZ`$`$@``
M`#OH`0`3````3N@!`"@```!BZ`$`'@```(OH`0"$````JN@!`!(````OZ0$`
M!0```$+I`0`4````2.D!``D```!=Z0$`"@```&?I`0`*````<ND!`!\```!]
MZ0$`%````)WI`0`.````LND!``X```#!Z0$`$P```-#I`0`5````Y.D!`"0`
M``#ZZ0$`)@```!_J`0`C````1NH!`"4```!JZ@$`(0```)#J`0`C````LNH!
M`!T```#6Z@$`10```/3J`0`3````.NL!`!0```!.ZP$`$P```&/K`0`4````
M=^L!`!$```",ZP$`%@```)[K`0`7````M>L!`!(```#-ZP$`$P```.#K`0`\
M````].L!`!8````Q[`$`%````$CL`0`^````7>P!`!4```"<[`$`#@```++L
M`0`1````P>P!`"T```#3[`$`$P````'M`0`3````%>T!`"`````I[0$`'0``
M`$KM`0`?````:.T!`!T```"([0$`&P```*;M`0`A````PNT!`!P```#D[0$`
M(P````'N`0`A````)>X!`"````!'[@$`(````&CN`0`=````B>X!`!,```"G
M[@$`&P```+ON`0`=````U^X!`!L```#U[@$`&````!'O`0`*````*N\!`!``
M```U[P$`&@```$;O`0`&````8>\!``<```!H[P$`#0```'#O`0`4````?N\!
M``8```"3[P$`!P```)KO`0`'````HN\!``8```"J[P$`!P```+'O`0`'````
MN>\!``4```#![P$`%0```,?O`0`&````W>\!``@```#D[P$`!0```.WO`0`%
M````\^\!``H```#Y[P$`$0````3P`0`*````%O`!`!(````A\`$`$0```#3P
M`0`+````1O`!`!(```!2\`$`!@```&7P`0`J````;/`!`!$```"7\`$`$```
M`*GP`0`:````NO`!`!````#5\`$`#0```.;P`0`,````]/`!`"\````!\0$`
M#@```#'Q`0`(````0/$!``@```!)\0$`*````%+Q`0`4````>_$!`!````"0
M\0$`!@```*'Q`0`+````J/$!``<```"T\0$`!@```+SQ`0`A````P_$!`!``
M``#E\0$`#0```/;Q`0`2````!/(!``H````7\@$`$````"+R`0`-````,_(!
M`!,```!!\@$`"@```%7R`0`0````8/(!`!\```!Q\@$`$P```)'R`0`-````
MI?(!``<```"S\@$``P```+OR`0`&````O_(!`!\```#&\@$`!@```.;R`0`(
M````[?(!`!(```#V\@$`$P````GS`0`&````'?,!``0````D\P$`!P```"GS
M`0`6````,?,!``T```!(\P$`#0```%;S`0`+````9/,!`!0```!P\P$`%@``
M`(7S`0`7````G/,!`!D```"T\P$`"@```,[S`0`-````V?,!``8```#G\P$`
M*P```.[S`0`$````&O0!`!$````?]`$`.P```#'T`0`%````;?0!``\```!S
M]`$`(0```(/T`0`6````I?0!`!<```"\]`$`#@```-3T`0`,````X_0!``D`
M``#P]`$`!P```/KT`0`*`````O4!``D````-]0$`#@```!?U`0`0````)O4!
M`"`````W]0$`(0```%CU`0`G````>O4!``H```"B]0$`"````*WU`0`'````
MMO4!``T```"^]0$`#````,SU`0`2````V?4!``8```#L]0$`"````//U`0`G
M````_/4!``L````D]@$`"````##V`0`2````.?8!`#P```!,]@$`#P```(GV
M`0`+````F?8!``0```"E]@$`!0```*KV`0`;````L/8!`!P```#,]@$`'```
M`.GV`0`*````!O<!``(````1]P$`!````!3W`0`A````&?<!``,````[]P$`
M!0```#_W`0`I````1?<!``H```!O]P$`!@```'KW`0`'````@?<!`!@```")
M]P$`#@```*+W`0`&````L?<!``<```"X]P$`"````,#W`0`$````R?<!``4`
M``#.]P$`&@```-3W`0`\````[_<!`!`````L^`$`$P```#WX`0`5````4?@!
M``4```!G^`$`!@```&WX`0`>````=/@!`#,```"3^`$`#@```,?X`0`)````
MUO@!`!8```#@^`$`"@```/?X`0`(`````OD!`!D````+^0$`+````"7Y`0`I
M````4OD!`"@```!\^0$`&````*7Y`0`A````OOD!``X```#@^0$`!````._Y
M`0`'````]/D!``(```#\^0$`"````/_Y`0`'````"/H!``<````0^@$`#@``
M`!CZ`0`-````)_H!``T````U^@$`#P```$/Z`0`(````4_H!`%<```!<^@$`
M$@```+3Z`0`0````Q_H!``L```#8^@$`&P```.3Z`0!0`````/L!`!T```!1
M^P$`!@```&_[`0`=````=OL!`"<```"4^P$`!P```+S[`0`&````Q/L!`"``
M``#+^P$`!````.S[`0`)````\?L!`"D```#[^P$`*````"7\`0`G````3OP!
M``D```!V_`$`!P```(#\`0`(````B/P!`!D```"1_`$`(@```*O\`0!9````
MSOP!`!@````H_0$`)@```$']`0`6````:/T!``,```!__0$`#0```(/]`0`'
M````D?T!``\```"9_0$`"P```*G]`0`&````M?T!`!4```"\_0$`!@```-+]
M`0`-````V?T!``@```#G_0$``P```/#]`0`3````]/T!``D````(_@$`"P``
M`!+^`0`8````'OX!`!4````W_@$`#@```$W^`0`0````7/X!``H```!M_@$`
M#````'C^`0`]````A?X!``@```##_@$`$@```,S^`0`4````W_X!`!<```#T
M_@$`#`````S_`0`0````&?\!``\````J_P$`"P```#K_`0`&````1O\!``4`
M``!-_P$`"@```%/_`0`E````7O\!`!<```"$_P$`2P```)S_`0`0````Z/\!
M``L```#Y_P$`$`````4``@`.````%@`"``\````E``(`%P```#4``@`*````
M30`"`!0```!8``(`"````&T``@`4````=@`"``0```"+``(`!P```)```@`%
M````F``"``4```">``(`!P```*0``@`3````K``"`!0```#```(`(@```-4`
M`@`B````^``"`!P````;`0(`'````#@!`@`@````50$"`"4```!V`0(`'P``
M`)P!`@`$````O`$"``4```#!`0(`#@```,<!`@`.````U@$"``L```#E`0(`
M%0```/$!`@`(````!P("`!<````0`@(`#0```"@"`@!5````-@("``H```",
M`@(`&@```)<"`@`?````L@("`!0```#2`@(`"````.<"`@`2````\`("``<`
M```#`P(`$0````L#`@`0````'0,"``L````N`P(`"P```#H#`@`.````1@,"
M``L```!5`P(`"P```&$#`@`/````;0,"``X```!]`P(`"````(P#`@`)````
ME0,"``4```"?`P(`!P```*4#`@`%````K0,"``0```"S`P(``P```+@#`@`,
M````O`,"`!,```#)`P(`00```-T#`@`U````'P0"`!<```!5!`(`*0```&T$
M`@`Y````EP0"`"\```#1!`(`$@````$%`@`X````%`4"`#@```!-!0(`/0``
M`(8%`@`]````Q`4"`$(````"!@(`&````$4&`@`9````7@8"``X```!X!@(`
M&0```(<&`@`6````H08"`#@```"X!@(`)0```/$&`@`8````%P<"`"`````P
M!P(`(````%$'`@`;````<@<"`!D```".!P(`&P```*@'`@`4````Q`<"`#$`
M``#9!P(`,0````L(`@`U````/0@"`#(```!S"`(`,P```*8(`@`P````V@@"
M`'<````+"0(`&0```(,)`@`6````G0D"``D```"T"0(`"@```+X)`@`B````
MR0D"``D```#L"0(`$P```/8)`@`T````"@H"`"4````_"@(`(````&4*`@`O
M````A@H"``L```"V"@(`40```,(*`@!-````%`L"``<```!B"P(`%P```&H+
M`@`5````@@L"``P```"8"P(`$````*4+`@`6````M@L"``<```#-"P(`"```
M`-4+`@`)````W@L"`!(```#H"P(`#@```/L+`@`1````"@P"``\````<#`(`
M#@```"P,`@`)````.PP"`!@```!%#`(`#````%X,`@`(````:PP"``4```!T
M#`(`!@```'H,`@`4````@0P"`!$```"6#`(`$````*@,`@!"````N0P"``(`
M``#\#`(`!@```/\,`@`1````!@T"``4````8#0(`!P```!X-`@`/````)@T"
M``H````V#0(`*@```$$-`@`,````;`T"`!X```!Y#0(``P```)@-`@`"````
MG`T"`#(```"?#0(`'````-(-`@`9````[PT"`#<````)#@(`&````$$.`@`H
M````6@X"`(8```"##@(`&`````H/`@!!````(P\"`"$```!E#P(`$P```(</
M`@`(````FP\"`!4```"D#P(`!@```+H/`@`,````P0\"``X```#.#P(`"P``
M`-T/`@`6````Z0\"``L`````$`(`'`````P0`@`6````*1`"``4```!`$`(`
M$@```$80`@`+````61`"``P```!E$`(`&@```'(0`@`0````C1`"`"4```">
M$`(`$P```,00`@`6````V!`"`!P```#O$`(`$0````P1`@`F````'A$"``H`
M``!%$0(`%````%`1`@`"````91$"`!8```!H$0(`$````'\1`@`2````D!$"
M``\```"C$0(`$@```+,1`@`/````QA$"`!4```#6$0(`'@```.P1`@`5````
M"Q("``8````A$@(`"0```"@2`@`%````,A("`!T````X$@(`!@```%82`@`0
M````71("``@```!N$@(`%````'<2`@`%````C!("`!L```"2$@(`#P```*X2
M`@`M````OA("`!4```#L$@(`!@````(3`@`'````"1,"`!@````1$P(`&0``
M`"H3`@`%````1!,"`!X```!*$P(`!````&D3`@`&````;A,"`!0```!U$P(`
M!P```(H3`@`+````DA,"`"````">$P(`+0```+\3`@`D````[1,"``D````2
M%`(`'````!P4`@`0````.10"``H```!*%`(`&P```%44`@`4````<10"``0`
M``"&%`(`%````(L4`@`)````H!0"``@```"J%`(`!0```+,4`@`(````N10"
M``8```#"%`(`!@```,D4`@`A````T!0"`#<```#R%`(`/P```"H5`@`B````
M:A4"`#````"-%0(`*````+X5`@!%````YQ4"`"(````M%@(`*````%`6`@`E
M````>18"`%4```"?%@(`*@```/46`@`'````(!<"``@````H%P(`!P```#$7
M`@`0````.1<"``@```!*%P(`%````%,7`@`4````:!<"`#````!]%P(`+0``
M`*X7`@`8````W!<"`#4```#U%P(`/0```"L8`@`'````:1@"`!D```!Q&`(`
M"0```(L8`@`0````E1@"`"(```"F&`(`#````,D8`@`/````UA@"``P```#F
M&`(`$0```/,8`@`2````!1D"``T````8&0(`"````"89`@`5````+QD"``@`
M``!%&0(`"P```$X9`@`-````6AD"`!H```!H&0(`#0```(,9`@`\````D1D"
M``H```#.&0(`!0```-D9`@`)````WQD"``4```#I&0(`&@```.\9`@`1````
M"AH"``4````<&@(`#@```"(:`@`0````,1H"`!$```!"&@(`#````%0:`@`/
M````81H"``\```!Q&@(`!P```($:`@`#````B1H"``T```"-&@(`.@```)L:
M`@!.````UAH"``L````E&P(`"0```#$;`@`2````.QL"`!<```!.&P(`%@``
M`&8;`@`1````?1L"`!(```"/&P(`$@```*(;`@`3````M1L"`!$```#)&P(`
M%0```-L;`@`)````\1L"`"8```#[&P(`'0```"(<`@`%````0!P"`!4```!&
M'`(``P```%P<`@`+````8!P"``P```!L'`(`#P```'D<`@`0````B1P"`!(`
M``":'`(`*@```*T<`@`'````V!P"``H```#@'`(`%````.L<`@`-`````!T"
M``X````.'0(`$@```!T=`@`+````,!T"`#L````\'0(`"0```'@=`@`<````
M@AT"``\```"?'0(`$P```*\=`@"#````PQT"`#\```!''@(`+@```(<>`@`+
M````MAX"`#D```#"'@(`.@```/P>`@`V````-Q\"`!H```!N'P(`$0```(D?
M`@`&````FQ\"`!````"B'P(`$````+,?`@`8````Q!\"``@```#='P(`#0``
M`.8?`@`*````]!\"`!$```#_'P(`'0```!$@`@`'````+R`"`!4````W(`(`
M&@```$T@`@`(````:"`"``<```!Q(`(`$0```'D@`@`2````BR`"`!D```">
M(`(`!@```+@@`@`'````OR`"``\```#'(`(`%0```-<@`@`4````[2`"`!4`
M```"(0(`%0```!@A`@`'````+B$"``8````V(0(`,0```#TA`@`G````;R$"
M`"8```"7(0(`"````+XA`@`/````QR$"``8```#7(0(`'P```-XA`@`A````
M_B$"`"8````@(@(`"P```$<B`@`4````4R("`"8```!H(@(``P```(\B`@`'
M````DR("`!4```";(@(``P```+$B`@`,````M2("`!$```#"(@(`"P```-0B
M`@`4````X"("`!@```#U(@(`%`````XC`@`%````(R,"``H````I(P(`$P``
M`#0C`@`4````2","``8```!=(P(`#@```&0C`@`&````<R,"``D```!Z(P(`
M"0```(0C`@`0````CB,"`!0```"?(P(`#0```+0C`@`-````PB,"`%H```#0
M(P(`%@```"LD`@`U````0B0"`!0```!X)`(`!P```(TD`@`)````E20"`!$`
M``"?)`(`%````+$D`@`6````QB0"`!\```#=)`(`%0```/TD`@`@````$R4"
M`!(````T)0(`(0```$<E`@`8````:24"`!4```"")0(`(P```)@E`@`0````
MO"4"`"<```#-)0(`$P```/4E`@`>````"28"`&@````H)@(`%0```)$F`@`F
M````IR8"`'````#.)@(`(0```#\G`@`<````82<"`"(```!^)P(`(@```*$G
M`@`C````Q"<"`"D```#H)P(`+0```!(H`@`A````0"@"`!P```!B*`(`*0``
M`'\H`@`V````J2@"`"8```#@*`(`*0````<I`@`?````,2D"`!\```!1*0(`
M'````'$I`@`*````CBD"`%8```"9*0(`&````/`I`@!.````"2H"``<```!8
M*@(`"````&`J`@`(````:2H"`!,```!R*@(`#P```(8J`@`M````EBH"`!<`
M``#$*@(`%0```-PJ`@`'````\BH"``<```#Z*@(`$@````(K`@!/````%2L"
M`!\```!E*P(`%@```(4K`@!)````G"L"`#H```#F*P(`/@```"$L`@!F````
M8"P"``P```#'+`(`,@```-0L`@`P````!RT"``D````X+0(`(P```$(M`@`6
M````9BT"`!<```!]+0(`!P```)4M`@`&````G2T"`$````"D+0(`!@```.4M
M`@`-````["T"`!X```#Z+0(`3````!DN`@!`````9BX"`"(```"G+@(`(```
M`,HN`@`T````ZRX"`"H````@+P(`(P```$LO`@`.````;R\"`"H```!^+P(`
M+0```*DO`@`M````UR\"`!P````%,`(`,P```"(P`@`H````5C`"`#(```!_
M,`(`*````+(P`@`Z````VS`"``T````6,0(`!@```"0Q`@`/````*S$"`!(`
M```[,0(`%0```$XQ`@`'````9#$"`$(```!L,0(`"@```*\Q`@`)````NC$"
M``H```#$,0(`%P```,\Q`@`)````YS$"``<```#Q,0(`$@```/DQ`@`*````
M##("``D````7,@(`!````"$R`@`'````)C("``@````N,@(`#P```#<R`@`4
M````1S("`!8```!<,@(`'0```',R`@`-````D3("``<```"?,@(`$````*<R
M`@`/````N#("`!(```#(,@(`#0```-LR`@`8````Z3("`"@````",P(`#@``
M`"LS`@`?````.C,"`"D```!:,P(`"0```(0S`@`+````CC,"`!0```":,P(`
M!P```*\S`@`$````MS,"`!\```"\,P(`#@```-PS`@`.````ZS,"``T```#Z
M,P(`"`````@T`@`)````$30"``@````;-`(`!@```"0T`@`)````*S0"``P`
M```U-`(`"0```$(T`@`,````3#0"``L```!9-`(`"0```&4T`@`3````;S0"
M``@```"#-`(`&````(PT`@`+````I30"``<```"Q-`(`'@```+DT`@`F````
MV#0"``P```#_-`(``P````PU`@`A````$#4"``<````R-0(`!@```#HU`@!T
M````034"``H```"V-0(`!P```,$U`@`G````R34"`$````#Q-0(`&@```#(V
M`@`E````338"`$0```!S-@(`*0```+@V`@`]````XC8"`!L````@-P(`%@``
M`#PW`@`%````4S<"``8```!9-P(`"0```&`W`@`*````:C<"``<```!U-P(`
M"@```'TW`@`)````B#<"`!0```"2-P(`"P```*<W`@`*````LS<"``P```"^
M-P(`#````,LW`@`'````V#<"``@```#@-P(`"0```.DW`@`4````\S<"``L`
M```(.`(`!@```!0X`@`%````&S@"``L````A.`(`!@```"TX`@`F````-#@"
M`!@```!;.`(`"@```'0X`@`6````?S@"``L```"6.`(`%````*(X`@`+````
MMS@"``8```##.`(`%@```,HX`@`&````X3@"`!8```#H.`(`!@```/\X`@`:
M````!CD"``L````A.0(`%@```"TY`@`%````1#D"``<```!*.0(`$@```%(Y
M`@`@````93D"``L```"&.0(`#0```)(Y`@`M````H#D"`!L```#..0(`&```
M`.HY`@`*`````SH"``4````..@(`#0```!0Z`@`4````(CH"`!<````W.@(`
M`P```$\Z`@`3````4SH"``D```!G.@(`/0```'$Z`@`C````KSH"`"D```#3
M.@(`,P```/TZ`@`E````,3L"`#0```!7.P(`)P```(P[`@!I````M#L"`!<`
M```>/`(`)````#8\`@`9````6SP"`!L```!U/`(`)@```)$\`@`8````N#P"
M`"(```#1/`(`9P```/0\`@!"````7#T"`%0```"?/0(`;@```/0]`@`M````
M8SX"`#L```"1/@(`+P```,T^`@!%````_3X"`$(```!#/P(`0P```(8_`@`X
M````RC\"`#,````#0`(`.````#=``@`N````<$`"`!L```"?0`(`-````+M`
M`@`M````\$`"`-<!```>00(`'P```/9"`@`7````%D,"`$H````N0P(`=P``
M`'E#`@`S````\4,"`"4````E1`(`00```$M$`@!<````C40"`%H```#J1`(`
M*@```$5%`@!Y````<$4"`",```#J10(`%@````Y&`@`H````)48"`!T```!.
M1@(`&@```&Q&`@`M````AT8"`"4```"U1@(`)0```-M&`@`Z`````4<"`",`
M```\1P(`%@```&!'`@`X````=T<"`"4```"P1P(`*@```-9'`@`M`````4@"
M`#8````O2`(`'P```&9(`@`X````AD@"`&T```"_2`(`,0```"U)`@!"````
M7TD"`"X```"B20(`)P```-%)`@!`````^4D"`&,````Z2@(`2````)Y*`@`E
M````YTH"`"<````-2P(`+@```#5+`@`D````9$L"`"X```")2P(`,````+A+
M`@!?````Z4L"`",```!)3`(`;P```&U,`@`]````W4P"`%@````;30(`60``
M`'1-`@`C````SDT"`#4```#R30(`*@```"A.`@`J````4TX"`"\```!^3@(`
M:P```*Y.`@!Q````&D\"`'$```",3P(`N0```/Y/`@`9````N%`"`"\```#2
M4`(`,`````)1`@`M````,U$"`%(```!A40(`)0```+11`@!3````VE$"`"@`
M```N4@(`(@```%=2`@`*````>E("`-@```"%4@(`)@```%Y3`@!8````A5,"
M`",```#>4P(`.`````)4`@`H````.U0"`!X```!D5`(`.0```(-4`@`$````
MO50"``P```#"5`(`"````,]4`@`$````V%0"``H```#=5`(`&0```.A4`@`/
M`````E4"``\````250(`"0```")5`@`+````+%4"``<````X50(`!@```$!5
M`@`/````1U4"``0```!750(`6````%Q5`@`$````M54"`!<```"Z50(`!```
M`-)5`@`'````UU4"``8```#?50(`!0```.95`@`$````[%4"`!4```#Q50(`
M"0````=6`@`1````$58"`!,````C5@(``P```#=6`@`+````.U8"``<```!'
M5@(`!P```$]6`@`2````5U8"``T```!J5@(`%````'A6`@`&````C58"``0`
M``"45@(`&@```)E6`@`-````M%8"``,```#"5@(`*P```,96`@`$````\E8"
M``8```#W5@(`!P```/Y6`@`A````!E<"`$`````H5P(`,0```&E7`@`R````
MFU<"`!L```#.5P(`,@```.I7`@`U````'5@"`"0```!36`(`(P```'A8`@`>
M````G%@"`"0```"[6`(`'P```.!8`@`=`````%D"`"4````>60(`(P```$19
M`@`>````:%D"`#0```"'60(`&P```+Q9`@`<````V%D"`#$```#U60(`%@``
M`"=:`@`R````/EH"`"$```!Q6@(`)0```)-:`@`D````N5H"`!\```#>6@(`
M)````/Y:`@`J````(UL"`"@```!.6P(`*@```'=;`@`F````HEL"`!\```#)
M6P(`(@```.E;`@`K````#%P"`!T````X7`(`)````%9<`@`O````>UP"`#(`
M``"K7`(`&@```-Y<`@`G````^5P"`!P````A70(`/````#Y=`@`D````>UT"
M`"8```"@70(`)0```,==`@`F````[5T"`"`````47@(`,0```#5>`@`>````
M9UX"`"<```"&7@(`(P```*Y>`@`N````TEX"`"<````!7P(`+@```"E?`@`*
M````6%\"`!,```!C7P(`%@```'=?`@`S````CE\"`"8```#"7P(`#0```.E?
M`@`/````]U\"`!8````'8`(`"P```!Y@`@`.````*F`"`"P````Y8`(`"```
M`&9@`@`,````;V`"`"<```!\8`(`*@```*1@`@`@````SV`"`!\```#P8`(`
M'````!!A`@`(````+6$"`-0````V80(`#0````MB`@`>````&6("`!8````X
M8@(`"0```$]B`@`-````66("`!$```!G8@(`$````'EB`@`/````BF("`!\`
M``":8@(`!@```+IB`@!+````P6("`!P````-8P(`'````"IC`@`'````1V,"
M`!(```!/8P(`#````&)C`@`V````;V,"``@```"F8P(`)P```*]C`@`9````
MUV,"`!0```#Q8P(`$@````9D`@`4````&60"`#(````N9`(`'P```&%D`@`'
M````@60"`!<```")9`(`"````*%D`@`)````JF0"`!0```"T9`(`"P```,ED
M`@`;````U60"``8```#Q9`(`*@```/AD`@`(````(V4"`",````L90(`*P``
M`%!E`@`'````?&4"`!<```"$90(`!P```)QE`@`(````I&4"``D```"M90(`
M/@```+=E`@`&````]F4"`!(```#]90(`%````!!F`@`/````)68"``D````U
M9@(`"@```#]F`@`&````2F8"`!,```!19@(`!@```&5F`@`3````;&8"`"$`
M``"`9@(`$@```*)F`@`9````M68"`!4```#/9@(`#````.5F`@`.````\F8"
M`!H````!9P(`!P```!QG`@`M````)&<"``P```!29P(`#P```%]G`@`'````
M;V<"``,```!W9P(`$0```'MG`@`<````C6<"``L```"J9P(``P```+9G`@`(
M````NF<"``P```##9P(`!@```-!G`@`)````UV<"``D```#A9P(`#````.MG
M`@`;````^&<"``D````4:`(`#P```!YH`@`-````+F@"`!8````\:`(`%P``
M`%-H`@`0````:V@"`"\```!\:`(`'0```*QH`@`<````RF@"`&4```#G:`(`
M8@```$UI`@`:````L&D"``L```#+:0(`,````-=I`@`'````"&H"`!<````0
M:@(`10```"AJ`@`1````;FH"`!(```"`:@(`"````)-J`@`$````G&H"``4`
M``"A:@(`$0```*=J`@`:````N6H"``8```#4:@(`!P```-MJ`@`)````XVH"
M`!````#M:@(`"````/YJ`@`2````!VL"``X````::P(`#P```"EK`@!%````
M.6L"`#8```!_:P(`*0```+9K`@`%````X&L"`!D```#F:P(`)`````!L`@`B
M````)6P"`"@```!(;`(`$````'%L`@`"````@FP"``0```"%;`(`"P```(IL
M`@`#````EFP"``H```":;`(`%````*5L`@`%````NFP"``,```#`;`(`$```
M`,1L`@!/````U6P"`#,````E;0(`-0```%EM`@`R````CVT"`!H```#";0(`
M40```-UM`@`K````+VX"`"\```!;;@(`4P```(MN`@"A````WVX"`#(```"!
M;P(`0P```+1O`@`N````^&\"`"T````G<`(`%@```%5P`@`E````;'`"`"D`
M``"2<`(`*0```+QP`@`U````YG`"`(4````<<0(`)````*)Q`@!"````QW$"
M`"4````*<@(`1P```#!R`@`K````>'("`"T```"D<@(`*@```-)R`@`S````
M_7("`"X````Q<P(`+@```&!S`@`P````CW,"`#````#`<P(`+0```/%S`@`R
M````'W0"`#0```!2=`(`30```(=T`@!+````U70"`$H````A=0(`.P```&QU
M`@`W````J'4"`!8```#@=0(`(````/=U`@`0````&'8"`'P````I=@(`"```
M`*9V`@!P````KW8"`'(````@=P(`@````)-W`@`F````%'@"`%X````[>`(`
M%P```)IX`@`1````LG@"`",```#$>`(`%@```.AX`@`2````_W@"`!0````2
M>0(`'````"=Y`@!`````1'D"`!X```"%>0(`&0```*1Y`@!0````OGD"`!(`
M```/>@(`&````")Z`@`*````.WH"``4```!&>@(`!@```$QZ`@`(````4WH"
M``4```!<>@(`%@```&)Z`@`7````>7H"`!8```"1>@(`(0```*AZ`@`1````
MRGH"`!````#<>@(`#@```.UZ`@`%````_'H"`!$````">P(`!````!1[`@`)
M````&7L"``\````C>P(`!P```#-[`@`(````.WL"``<```!$>P(`!@```$Q[
M`@`:````4WL"`!(```!N>P(`"0```(%[`@`,````BWL"`!````"8>P(`#P``
M`*E[`@`,````N7L"``<```#&>P(`"P```,Y[`@`)````VGL"`!````#D>P(`
M"@```/5[`@`+`````'P"`!H````,?`(`!0```"=\`@`)````+7P"`!4````W
M?`(`%0```$U\`@`9````8WP"``8```!]?`(`!0```(1\`@`C````BGP"`!D`
M``"N?`(`"P```,A\`@`C````U'P"`!0```#X?`(`*P````U]`@`9````.7T"
M``,```!3?0(`!@```%=]`@`$````7GT"``8```!C?0(`%P```&I]`@`+````
M@GT"``L```".?0(`!0```)I]`@`'````H'T"``(```"H?0(`&P```*M]`@`%
M````QWT"``(```#-?0(``@```-!]`@`;````TWT"``@```#O?0(`"P```/A]
M`@`5````!'X"`!@````:?@(`!P```#-^`@`S````.WX"``(```!O?@(`!P``
M`')^`@`$````>GX"`!````!_?@(`%@```)!^`@`.````IWX"``L```"V?@(`
M#0```,)^`@`/````T'X"``L```#@?@(`"0```.Q^`@`&````]GX"`!@```#]
M?@(`"````!9_`@`4````'W\"`!$````T?P(`$@```$9_`@`"````67\"``<`
M``!<?P(`#P```&1_`@`0````='\"`!````"%?P(`+````)9_`@`)````PW\"
M``@```#-?P(`$@```-9_`@`3````Z7\"``4```#]?P(`%@````.``@`"````
M&H`"``L````=@`(`!@```"F``@`-````,(`"``<````^@`(`!@```$:``@`!
M````MP(```````"2`0``3@@``(8&``!]"```A04``'X'```'"````````*,%
M``"S!```'P4```P&`````````````!X%``!/!```40<``!X"``#+!0``<P(`
M`*8#``!N`P``````````````````\08``)<%```'`@``/P8``)8%```!"```
MDP,```````#-`0```````%````#S!@```````%,!```=`0```````+$!``#>
M`P```````-<(``!W!0```````.$$``!"`0``UP<``'P%```D!@``W```````
M``!O!@```````+L"```7!@```P<``/D#``#T!0``)P```)4````B`0``LP,`
M`)('``#]`P``E@0`````````````C@(`````````````>P8``&4$````````
MF0`````````K!```(P<``$D!``"3!0``;P0``)4#``#_!0``_P(``,$!````
M````C0```.P"````````7P```,0!``"T!0``:P$``%("``!>"```(`(``)``
M```P`P```````!8#``````````````````!9`0``>@```(\(```N!P``.`0`
M`-H```!0!@``3`8`````````````'@<``#H&``#.!@``+`(``/8```":`@``
M0P4``+P&````````=P```$P(```.`@``T@4``'`"```=!@```````*T"``#V
M`@``*`$``"@#```M`P``[`8``*,#```O`P``A0@```0$``#G`P```````&$'
M``"S"```L`4``+<!``!8!````````'<"``"(`@```````(0`````````,P8`
M`,8"``!C````6@$```````"P````?@0``-H$```8!0``#08``.\%``"/`@``
M?`<`````````````]@,```````!#!@``A0<``,((``"7`````````&H#````
M````,@4``&4#````````&`,`````````````CP,``&<&``"%`0``N@(`````
M``"4!`````````````#D`0``7@<``&,(```]`0``2@<```D#````````(P@`
M`````````````````-0"```2!@```````.`"``"&`@``+@0````````R!@``
MY`@```````"#`@``1@8``'T`````````UP(``!$!``#+!```;@(```T$````
M````]0<``/`&````````Z`8``(X``````````````","`````````````/H!
M``"\`P``1````*T%``#<"```)00``*,(```Q"```N`8``(D!```X`P``UP,`
M```````4"````````/`$``!+!@``?`0``#,!````````8`8`````````````
M)@8`````````````#0,``+D```"5"```:@8``%L#``#]!@``10,``/@!````
M````:0@```````#1`@``R08``*T`````````R0(``(4```!V````0@4``,,(
M``"A````<`8``.P#```2`0``B@,````````]`P``^P0``"@$```R"```C`0`
M```````N"```]@8``#\!```.`P``ZP$```````!A``````````0'``!X!```
M`````&8$````````5@4``",#``!"````X@(``(,$``"8!P``H````,P#``!C
M!@```````*<`````````F`4``!$#``!7"```YP@``(,'``"<`@``UP8``,@(
M``!;`@```````"("``#Y!@``7`@````````Y!@``O0```/`#```N!0``$```
M`'0$``!R````[@```+L#``#B!@```````````````````````)X!````````
M+0<````````<`P``DP8```````#J`0``;0<```````"-!```N0<````````6
M!0``\P4``!0```#>!````````%8'`````````P8``)$%````````10@`````
M`````````````&`"``````````````````#6`P``]P(``-$!``#C"```@0(`
M`'$!``#O`P``D0(``%4```#D!@``&08```0(``"J`@``=`$``-@#``"%!```
M)0```*$#````````>@$```````"L`P``^P8``"H!```9!```C0@``+P(````
M````6@(``*(#````````F`$``(0#`````````````!4!```W!P``````````
M``#=!P``,`@``+8%``"V"````````%\&```9"```F0$``+8&```!!P``R0``
M`/````"W"```%@8``(L%``#``0````````````!-!P``M@$``)L"```^`P``
MN00``!<```"B`0```````(('``#'!0``)0<``,4$```:!P``4`(``'D%``"*
M`@``"0`````````T"```#P(``/@```#\!@``-0,``"\"```%````F@@`````
M``!&!0``_P,``+T%``"F!0```````-8"`````````````!T$``!6"```U`0`
M``````!E`@```````````````````````+H#``!5`0```````#X%``!<`P``
M@@(``!\'``"R"```R@(``,D!``"X`P``,@(``,\"``!G!```2`$``)L$````
M````````````````````#@$``!$%``"$"````````,$'``!/`P```````'(!
M```V`0````````````#+````#P@``#P(```+````Y@8```L"```(`0``P@$`
M`/P$```_!0``Q`,``,0%``!_"```QP0```````!R!@``2@8```````"@`0``
MD0$``&@&```E`P```````#H!``"6!@``^`8``&L$``!P!P```````%D'```Y
M!0``\@(``*(`````````,04``!8"``"D"```908``&````!2"```L`<``&L&
M```T`@```````,`'``#*!@``N@4``/0!``!$`@``N@`````````Y````T04`
M`!,```"H````X@0``)`!``"B!0``>P(``/\'``#8`0``70@```````#Y`0``
M_@8``(0'``#S!```6@8````````(`@```````",!``!4!P``<`,``(D%``#9
M`P````````````"#`P``U@<``"8"```@"```C@4``$P$``#S`P``CP8``&D!
M``#'`P``RP<``$8#``"Z`0``H`(```````"-!P``2`<``%X!``!W!@``I08`
M`-('`````````@$``*L%``!(!0``T00``!,'```D````6`(``)@`````````
M>0<``+,"```Y!```@`$``)<(``!!`P``````````````````90$``*@(````
M````6@```$4&````````I`(```````#Z!@```````-0'``!?`@``<@,``%<%
M````````10<``'`%``"0!```10(``/D%``"C````D00```\&````````````
M`%<&`````````````!X$```Q`@``8P(``#\```#H`0``K````&P$``!7`P``
MX@,`````````````!`````H```#Z!P```````&`'``"8!@```````'T'``"+
M!P``IP4``!L"``#;!@``CP$``'4#```7!0``UP0``$0!```D`P```````#T`
M``":`P``>P```)T$``"F!```````````````````6`8``(X#``!F`@``XP8`
M`.4$```````````````````[!@``'`<`````````````GP0``)P'````````
M(@<``%4%``#."````````$<!``#I!P``EP,``$D"````````Z`0```````!K
M!P``-`0``+T$```?`P``C04``!`%``"F`@```````-0````E`@``````````
M```;!@``:P```/<``````````````),(``#Q`````````'<$````````````
M`%T"````````?`,````````J!```O`(``&0"``!`!0``3P8```````"M!P``
M3P(``+4```!9"```#04``````````````````',#``"3`````````&X```"1
M````DP$``&8!``")````X@4```````!B`P``0`0```````#+`0``^`<``!L(
M````````4`<``$T&``!$!P```````.`&````````XP$``&0&```X````+04`
M``````!Z!````````*0#``"N`0``[`<``"0!``#2`P```````/8%```Q!@``
MJP<``*8```#3`@```````%$$``#>````8@8``)<!``"I"```*0<``#<!``"O
M`0``K@(``+(```#%!P```````%P&``"L!```#`,```````"&`P``;@0`````
M``#.!0``3@,``&D%`````````````*L&``"!!@``L`$``!P```#!`@``````
M````````````]@$``-8&````````,P0```````"<!```+`<``(P'``#I`P``
MF@0``'4!``"T!P``5@$``!H#```2!```:P,``'<!```G!0``F04```````!A
M!@``SP$``#T$````````L0(``-0%``![!0``&@8``,P&``#=`P``XP,`````
M``#:!0``8`@``*8(``##!@```````-T$```&`````````)\'``#=!@``X@``
M`.P!``"S````J@4``#<"``#T`@```````.((````````8@@``$4!``"8"```
M`````!(%``````````````````#F`0``2`8``)T(````````$`,```````#^
M!P``BP@``,4`````````R0<``(D'``!X!P``3P<``#,```!@!```O@4`````
M``"`!```EP8``-L#```A"```:`,```````!3"````````.4"``#H!0``N0@`
M`$("````````S@<```````"=`0``+00```````"9"```GP$``#8#```*!P``
M5`$``+8`````````A@0````````1````\@4``/L"``#`````Q@0```````"/
M!P``5@,``,<```!X``````````````!5"``````````````Q````,@$``(H(
M``";!0``%`0```````#S!P````````````!7!```>0(``.L%````````20``
M```````1!@``0@0```<%```0!`````````````!_`P``6P4``$D(```Z!```
MO0$``"D!```+!@``'0,``)4"``!N`0``]`<``.`'``"'!P`````````````E
M!0``G@````````"T!@```0$``````````````````%(``````````````"D$
M````````/@@``-4(``"'!````````!4%``#(!0``U0<``,<"``!)!0``\@,`
M`&H$``!U"`````````````!I````8@$``(0$``"S!@```P4``$8$````````
M2P<````````%!P``=`@``*,"``!2`P``"08``!("````````OP```/L'````
M`````````"L%```%!@````````````!,`0``/0(``/@$``#R!P``````````
M``!M`@``#P$``(T&````````G`$``$\!``#]`0``>0@``*\%```G!P``P`0`
M`,D#```'!```000``'D$``!_`0``W`,``-P"``""`0````````````#V!P``
M0P`````````5`@``=04``)0!```X!@```0(`````````````#P<``-$(````
M````700``'D&```R!```+0@``#0%```J`@``@P@``)<"``"N!@``)08`````
M``!8`````````%$&``!Q!P```````!\&````````-@(``$\(```)`@``[@,`
M`.H&```[`0`````````````U!P``H0<``&,#````````G@<```<```!8!0``
MW@@``,($``!1`P``2P````````"I`````````$0%``!"`P``?P<``%D````U
M`@``MP0``(4&````````(04```````````````````@%``!#`@``60,``(H!
M````````Z@,``!X`````````*`(```````#[`0``Y04``)8````V!P``$@,`
M`&D#`````````````#,#``#R!@```````&P'````````Q``````````$!@``
MSP4```````#=`0``*@,``*D&``!&````?@8``,H'``#F!0```````)T%``"'
M!@``;P$``-D!````!@``1P@``!D```#;!0```````.@"``"5!@``/P,``,D%
M``!9`@``(0```-`````N`0``0@<``+X'``!Q`@``'@$``!`!````````704`
M`!0%````````*0```+`#``#5!0``%`,``"H%``"Z!@``(0<``&@`````````
MYP$``!\`````````W@4``'$````T!@``6P````````!""```5`(`````````
M````50<``/,!```Q`0``*P(``'`````O`0```````.4&````````!@$``.H$
M``"A!@``+0```.4```!O"`````,`````````````3@```(((```2````````
M`'\$```J"``````````````1!P``<`0```````#@!0```````.8"``"P!```
MHP8``"8#``!S"```KP<``%X&````````>P0``!P$```D!0```````,8'``!8
M!P``BP(``"T&```:"```<P8``&<%``#K````(P0```$&```>`P``,P4``+$#
M``!C!```!P$``.,```#3`0``ZP(``&D$``#\!P````````````"G`P``;04`
M`'D```!?`0``M`,``"\$``````````````````"!!0``PP0``$T!``",`P``
MQ`@``````````````````-`"``"=!P````````````!*`0``K08``!,#``#P
M!0``[0````@(``"H!0``"00```\$````````6`,``#H'```C!0``````````
M```R````.@(```@#``!4``````````````!]!```DP0``!L%````````J@<`
M`&X'``"L"```40@``/X!``"C!```,`0``"@'````````T08```````#`!@``
M^00``&D&```(!P``?````%0$``#W!0```````)X"``#,!```3P```,\#``#&
M````Z00``````````````````+\'``#]!0``S`(``'@!``"O!```5@(``,T%
M``#U!```[00```````!Z!@```````-\$``!]!@````````L$```E`0``````
M`,(```"-`0``````````````````P@4``+@!`````````````-8$```F!0``
M`````(`%``"V!P``N`0``*4"```?`0``004``*<$````````N04``$P'````
M````IP(``,(#``!@`P````````````!3`@```````)0&``"E`0```````"`%
M```2"````````.\'```Q`P````````````"A!```=00`````````````````
M````````````PP$``.\````K`````````.\"``#3!0``"@(````"``#%!0``
M70,```````"^`P``H04``%,$```L"````00```````#0`0```````-@&``#S
M`````````$T```#?"```9@8``)L&````````3@0``,4"```3!@``2P@``"P#
M``"6`@````````````!:!P``/`0```````#I`````````)P```">!@``@@``
M`*@#``#,!P``%P0```````#T````^@0``(P%``#T!````````)P%``"S!0``
MW`<```````#]````'04``/L%````````F0(``.T"````````Y0<``-T%``#F
M!```Q`0``-H'``!D`P``GP8``#\(```/````"`8```((````````JP(`````
M``#U`@``.0<````````W"```E`4```($``#9!```9`0``#8%``!>!0``````
M``````##`P```````/T'``"'"```+@(``"`'``"0!@``+`8``,$%````````
M`````($!``!!`0``T@0``)8!```9`@``T@(``-0#```W!0``008``#4!``#2
M`````````#D#```N`P``*P$``$4```#5!```.P@```$#``#/!@``90@``(D"
M``````````````````#-```````````(``!?"```,`````P````G!@``&`@`
M`+D"```]!P``JP$``"0$``"4`@``J0$``,\'``#?`0```````'0#``"[`0``
M`````$@$```^`````````.$"````````8@(``#\'````!P``[P8``'\"``!L
M`@``70```"`#``"I`@``=P<``)L!````````(0(````````X!0``U08``$0$
M```$`@``,00``'P"``"J!```VP@``$8"````````XP0```````!7`@``````
M`"$&``"J!@``?0,``+(%`````````````"X```!X`@``R@4``(`#````````
M;`@``%,'``#3```````````````W````>@,``#P```!=!P``500``"<"```O
M!P``E04```\%``"'`P``I@$``/(!``"(!@``-@```'D!````````BP0``/0#
M```'!@````````,#```G!````@<``#\"````````:@<``+("``!2!@``YP(`
M`$T%````````R@0``,L"``!^!0``-@8``$8!````````2@4``'H'``#L````
M*0,``%L&```2!P```````'8$``#G!@``=P@``-,(```*`P``2P$``,0'````
M````P`,``*X$```Z````$00``)@"``!?!0```````.8#``"0`@``````````
M```S"```;P,``%(!``!1`@``D0<``%L(``"B!@``[P$``+,!````````X04`
M`(X$``#P!P``F@```%,&``"E"```-P8``,T#```@````B`$``+\"``!J"```
M*P,``!L#``!*`@``^P```.$```!2!0``G0```!8```"[!```S@,``-D(````
M`````````)D#``"("```,`<``(D#``!%!0```04``($```#N`@``O````,P%
M```X"```W`$``!@&```W`P``.P<``'("````````/@(``"D%``!E!0``````
M`(8(```3!```)`<```````##````P@8``&T(``!M`P``U@@`````````````
MZ`````````!5`@``N`<```````"Z!P```@8``&\```#F"```NP```'$&``!V
M`P```````.P%````````5P<``+T#```O````C0,``),'``"'!0``KP@``%@!
M```E"```O0@``,0"``#J`@```````*@!``!&"```*P@``*P&``"7!P``S08`
M`&,!``#R!```.P````````"*!@``R`$``$@"``"?`P```````"P!``!)!@``
MY0$``!`(``!V!@```````-@(````````D0,``-8%``!``0``R`8``'0'```.
M!P```````-0&```\`@``Y0,``-4!``","`````````````!G`P```````)\`
M``"^`@``T`<`````````````\0,``#0!``!?`P``Z`,`````````````O@0`
M`*$(``#/!```S0(`````````````9@,``#P'````````!`$``-@'````````
M.`$``*,'``"#`0````````````#^!0``X0,``%D%``!-!```>@@````````=
M"```%`$```````"8!```"P$``/<&`````````````,4(``"0!P``!04``'0&
M```F"```-````#P!````````*````%D$`````````````&\%```J````4P,`
M``````#Z!0``[`0````````5!@``N`4```D(``""!```6P0```````"2`P``
M?@,``&$"```5"```A`8``"((``##!P``#`<``'L!``"2!@``O`<``(,%``!`
M!@```````$`"```-!P```````/D"``#-!P``IP8``-X"```A!```#P,`````
M``#U!@```````!$(``"Q!@``E00``'(%``!+`P`````````````=!P``H`@`
M`-@"``#^`P``JP0``%8&````````8@0``#4&``!I!P``0P$``'8%``"@!P``
MR`0``&L"``!C!0```````+$'``"\!0``OP$``````````````````&@(````
M````H@(``-X'````````X`$``,L(````````6@4``%<!```.!@``I`<``$D$
M````````*`@``-L!`````````````!P!``!X!0``H@0``.H```!'!P``H`8`
M`+4"````````'@8``&T````R!P``@`<``%X#``"M!```OP@```````"!!```
MG`8``#\$``![!P``D`@``-8```!#!```M`@``)(`````````BP8``"`$``"D
M`0``]@0``,D$````````7````+T"``"V`P``5P```'P(````````_P```.,"
M``#?!@``)`@``(`"``!F````S@```(\%``!^````00```(L```#F!P``````
M``````"P!@``80$``+0!``#:"```F00``*@&````````A0(``-D%``"D!0``
MU0````````#\`````````.`#``````````````````".!@``P`4`````````
M````&04``/<$```;!```T0<```````"=!@``JP@``/<!``````````$``"<#
M``#*`P```````"(&``"W!@``,@,``'H"````````K@<``/$!``#C!0``````
M````````````V0(`````````````_00``*0```"L!P``1@<``(D(``#U!0``
M30@``"H&``"4"```;@8``.(!```,`0``2P(````%```4!P``M0,``'0````[
M!```HP$`````````````6@,``$L%``!A`P``B08```````"`````````````
M```H!@```````#`"``!4`P``<@@``,$#``#0!@``X`0```````",````PP(`
M``````!$`P``MP```*<(``#Z`P``"P<`````````````_`(``%H$````````
M)@```+P$````````BP$``+D#````````\P(``,8#```:`0``&0<``'$%``"(
M!P```````$0(``#F````?0(``````````````````#D"``#8!```(0$`````
M``"D!@``B`0``!`&``#G````3`````8%````````&@4``',%``#+!@``*0@`
M``````!%!```M00````````*!0```````)4!```T`P``^`(``),"````````
M%00``$H#```L!````````-D&```&`P````````````!$!@````````````!.
M`@``J@@`````````````_@(``#4```"%`P``!`4``$(&````````A`4``+0"
M``"6`P``K@@``%8$``"7!```804``.X'``"H`@``/@$``*H#``#.!```1P``
M``````"I!P```````.$(``"(`P``H@<```````"&!0```````&P&``#T!@``
M`````-\#```#`````````((&``">"````P@``+`"``#Q!````````(D$````
M````WP```%D&``"(```````````````4!@``9@<``#D(``!1`0```````#4(
M``#M!P``^`,``-H&``!.!P``L@<``%X"``"*````P08```````#5`@``````
M`*H!``#'!P``M0<``((%````````(@0```````"I!```9P$```T"``",`0``
M`````+T&``"=`@``S@$``$<#````````?@(``$<&``#:`P``=`(``',```!<
M`@``Z04```X```"_!@``_`,````````.!```C@$```````#4`0```````-L$
M``#"`@``*0(``/(```!<!P``L@8`````````````D`4````````[`P``&0,`
M``L(``"6!P``1P(``%H(``"^````20<``!@'``#``@``;00``%@(``!!"```
M7`4``"D&``"^"````````+(#``!@!0```````$@```#X!0``X0$``-(!``!`
M`P``NP4``"\&````````6P$``!,%````````'`8``````````````````(<`
M`````````````````````````````!4'``#M`0``Q@@``'4"````````@`@`
M`+4&``#&`0``WP(``!4``````````````$,'````````#`(``-$```";"```
M`````)H'```W!```?@$``'8(````````F08``"P%```C````@0<``)((```Z
M`P``(@,``-\%````````%0,````````8````:@4`````````````````````
M``"A`0```````%\$``"_`P``;`,``#4%````````CP````````#9````````
M`)0````F`0``%P(``(H%``````````````````!F"```;08``,\(````````
M`````$,(````````````````````````'0```*`$````````^P,``+0$``#0
M!0``,`4``'X(``!E!P``+P4````````+`P``508``.L&````````S`$``*\"
M```&!P``Q08``+<'````````;@4``)`#````````.`<``*<!``"&````.P(`
M```````V"```VP(`````````````9@4```0#`````````````*<'``#!````
M2`,``/$'``!2!````````!8'```Q!P``YP0``!@$``#@"```!P,```````!W
M`P``:`$``)8(``````````````D%``"E````%@0``.$'``!("````P(`````
M``#D`P```P0``',!``!L!0```````#T(````````Y`<``*P!``#O!```3`,`
M``````!,`@``U@$``*`#``#:`0``A@$``-\'``!0"```L0```!@"````````
MT@@``!$"``"E!0``800``/\!``#(`@``Y`0```````"<`P``K`(``/4#````
M````_`4``,@#```L`````````"`!``!V`0``JP```/H"````````7@```.0%
M``#$!@``W@$``"8'``!5`P``AP(``'4`````````M@0````````X`@``B@<`
M```````*`0```````#`!````````````````````````````````````````
MQP8``%X$`````````````#T%````````N`@``&X(``"2!0``"@0``$T#``"N
M!0``/@0``#0'```?!```KP,``%('``#_!```"@8``$`(``#3!P``5`8````$
M``!_````(@4``-P$``">!0``NP@``&0'``#'`0````````H(``#4"```````
M``````#Y`````````-P&``!]!0``>@4```8$```A`P``[@8``-@```#&!0``
M]0$``.L$``#*"```````````````````;0$``-T(``#^````M````$<$```^
M!P``K@,``$X&```,"````````+H$``![`P``<@<``$P%``#U````'`4``'D#
M``"&!P``M04````````D`@``8@```.0"``"K`P``$P(`````````````````
M``X(```\`P``<00``&@%``#A!@``2@0``",&```:!```R0@``*T#``!R!```
MD08``&P```#=````0`<```````#:`@``0```````````````&`$```````!6
M````<`$``%,``````````````-<```!B!0``SP````````#`"```=0<``*4$
M```9`0```````)P(``````````````````"W!0``````````````````````
M``````!3!0``!@(```````#N!0``TP0``/H```!P"```4`0``,H`````````
MS0@`````````````R@$`````````````.@4``,('``"-`@``K0@``&H!````
M````I@8``-,&``!X"```GP4``&P!``!;!P``J04``%P$``!S!P``````````
M```?`@``````````````````C`8``"(`````````GP(``*P%````````````
M`&@"```3"```P00`````````````````````````````&P<`````````````
M9P<``+X&````````Y0@````````%`0`````````````M`0``A`$```8(``#0
M"```"``````````#`0``1P4``'8'````````G@0```````!0`0``OP0`````
M``````````````T````H!0``ZP,``#4$````````!00``/$%``#M`P``Y```
M`-T"```<"`````````````"5!P``8`$``!`'``#B!P```````%\'````````
MV`4``'L(````````Z@4```````"Y!@```````"8$``#<!0`````````````+
M!0``!P<```````"O````.0$``-`#``!4!0``!@8``*@$``#I`0``:P4``'T!
M`````````````$L$``!<`0```````'8"````````@0,``.T&``"J````<P0`
M`)L#````````/`4``*`%``#N!```?P8`````````````3P4```````#,````
M+0(```````"[!P``F@$```````"+`P``F@8``)X#``!.!0``3@$``+@"```S
M!P``&P$```````!1````70$``)H%```>"```:@```!`"````````9````,X"
M``#%`P``I`0``+$%``"4!P``\`(``!<'``#7!0``J`<``#,"``"U"```````
M`!<(``!H!P``P0@``)D'````````_@0```(%```-`0``D@0``-X&``!-`@``
M``````````"E!P``%P,``(<!``"?"```Z08``-<!```)!P```````"\(``!X
M!@```````($(``"M`0``>`,``-(&``#Q`@``L@$``$H```!Q`P``Q@8``(,&
M```@!@``#`4``+$$````````[04``'\%``""`P```@```&@$```N!@``S00`
M`!<!``##!0``LP<``````````````````#L%```,!```]P<``,@'``#@````
M`````%`%````````I0,``/`!``"`!@```````(X(````````9P(``$$"````
M````RP,``$D#``",`@``O`$``#`&```-"```D0@`````````````;P<```4(
M```6"`````````````#I`@````````D!````````FP<``(@%````````OP4`
M`"<!``!!!P``80@`````````````H@@``````````````````&0(```G"```
M`````"L&`````````````!0"``!J`@``CP0``&<```"[!@``E`,``!8!``!4
M"```-@0```````";````J0,``)("``"Y`0``_`$``&,'``#C!P``#@4``(0"
M``#N`0``N@@``&('``"#`````````+T'``!E`````````+`(````````&@(`
M`'P&``!O`@``KP8``*X`````````/08```````"=`P``QP@`````````````
M`````-L'```;````.@@```4#```=`@``:0(```````"Q"```YP<``!P"``#3
M`P````````````!T!0``````````````````T`0``/T"```?"```=08``-D'
M```J!P```````+@`````````H0(``/<#``!1!0``&@```&0%``"W`P``/@8`
M`,4!``!*"```L@0```````"F!P````````````".!P``*P<``.@'````````
MVP````````!=!@````````````!G"````@,``.L'```%`@``U0,``&L(``#,
M"```/`8``+4!``!#`P``$P$````````(!```?`$``````````````@(``/D'
M``"V`@``B@0``.H'``#G!0```````/\&````````4`,``+X!``"8`P``T0,`
M`&0!``!Q"```R``````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@
M;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@8V%L96YD87)S(&9O=6YD`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"!E=F5N=',`
M)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($1A>2AS*2`E<R!(;W5R
M*',I("5S($UI;G5T97,`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3
M:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T
M<RX`)7,@870@)7,@)7,`)7,@871T96YD965S`"5S(&9I;&4@<W5C8V5S<V9U
M;&QY(&EM<&]R=&5D`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O
M>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T
M('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@
M9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@
M0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S
M.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US
M('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O
M<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I
M;F9O<FUA=&EO;BX`*$-L:6-K(&]N(&-A;&5N9&%R(&YA;64@=&\@<W=I=&-H
M('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE(&UA:6X@=VEN9&]W
M*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!!9&0@*@`J(%!L96%S92!S96QE
M8W0@861D<F5S<RAE<RD@*@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@871T96YD
M964`,2!E=F5N=``Q(&AO=7(`,3(@2&]U<B!&;W)M870`,34@;6EN=71E<P`R
M,"!M:6YU=&5S`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#,P(&UI;G5T97,`
M/%!R979I;W5S`#QS=')O;F<^071T96YD965S/"]S=')O;F<^("AO<'1I;VYA
M;"D`/'-T<F]N9SY$97-C<FE?<'1I;VX\+W-T<F]N9SX@*&]P=&EO;F%L*0`\
M<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO<'1I;VYA;"D`/'-T<F]N9SY2
M96-U<G)E;F-E/"]S=')O;F<^("AO<'1I;VYA;"D`02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!30!!32!#;&]U9',`04T@3&EG
M:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-
M+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T
M;VT`06)S;6ED9&QE`$%C8V5P=&5D`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U
M;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D7W9A;F-E9"!396%R8V@`061D`$%D
M9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@179E;G0`
M061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D
M9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R`B)7,B`$%D9"!A(&YE=R!296UO=&4@0V%L96YD87(`061D(&$@;F5W
M(&5V96YT`$%D9"!A(&YE=R!U<V5R.@!!9&0@871T96YD965S`$%D9"!C;VQU
M;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@
M=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO
M=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!
M9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`061V86YC
M960@4V5A<F-H`$%F9VAA;FES=&%N`$%L87)M`$%L87)M("5D(&1A>7,@8F5F
M;W)E`$%L87)M("5D(&AO=7)S(&)E9F]R90!!;&%R;2`E9"!M:6YU=&5S(&)E
M9F]R90!!;&%R;2`E9"!W965K<R!B969O<F4`06QA<FT@,2!D87D@8F5F;W)E
M`$%L87)M(#$@:&]U<B!B969O<F4`06QA<FT@,2!M:6YU=&4@8F5F;W)E`$%L
M87)M(#$@=V5E:R!B969O<F4`06QA<FT@1&%T90!!;&%R;2!3<&%N("AM:6YU
M=&5S*0!!;&%R;2!4:6UE`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!
M;&EG;FUE;G0Z`$%L;`!!;&P@071T96YD965S`$%L;"!!=71H96YT:6-A=&5D
M(%5S97)S`$%L;"!&=71U<F4`06QL($=R;W5P<P!!;&P@4&%S=`!!;&P@4&5R
M;6ES<VEO;G,`06QL(%9I<VEB;&4`06QL(&1A>0!!;&P@9&%Y(&5V96YT`$%L
M;"!E=F5N=',`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S
M<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A
M9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E
M;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E
M>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I
M9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!
M;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T
M:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`06YY`$%P<&QI8V%T:6]N`$%P<&QI
M8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H
M:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A
M8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@
M3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M
M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N
M($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R
M(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T`$%T=&%C:&5D(&ES(&%N(&E#
M86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@
M979E;G0N($EF('EO=7(@;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I<"!R97%U
M97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P9&%T92!Y
M;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+@!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!S:&%R92X`071T96YD86YC90!!='1E;F1E97,`071T<FEB=71E
M<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I
M;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5
M;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!
M=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V
M97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!
M=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K
M9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D
M+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT
M:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A
M<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"87-I
M8R!396%R8V@`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A
M`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E
M<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`
M0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O
M<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O
M='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T
M960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!"=7-Y`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U]A;&5N9&%R`$-?96QL(%!R;W!E<G1I
M97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L7V5N9&%R
M`$-A;&5N9&%R`$-A;&5N9&%R(%-U;6UA<GD`0V%L96YD87(@<W5C8V5S<V9U
M;&QY('!U<F=E9"X`0V%L96YD87)S`$-A;&5N9&%R<R!M=7-T(&AA=F4@82!N
M86UE+@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T
M97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T
M;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@8W)E871E(&$@;F5W(&5V96YT+@!#
M86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N8V5L;&5D`$-A;F-E;&QE9#H@)7,`0V%N;F]T(&1E
M;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@
M<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU
M;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T
M(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O
M('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R
M`$-A=&5G;W)?>0!#871E9V]R:65S(&%N9"!,86)E;',`0V%T96=O<GD`0V%Y
M;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P
M861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO
M;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A
M;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T
M:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E
M(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN
M9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R
M<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3
M:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I
M`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E
M(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O
M<V4@:68@>6]U('=A;G0@=&\@8F4@;F]T:69I960@;V8@;F5W+"!E9&ET960L
M(&%N9"!D96QE=&5D(&5V96YT<R!B>2!E;6%I;#H`0VAO;W-E(&EF('EO=2!W
M86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E
M9"!E=F5N=',N`$-H;V]S92!I9B!Y;W4@=V%N="!T;R!R96-E:79E(&5M86EL
M(')E;6EN9&5R<R!F;W(@979E;G1S('=I=&@@86QA<FUS.@!#:&]O<V4@;&ES
M="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('1H92!A
M9&1R97-S(&)O;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z`$-H
M;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U
M<WD@:6YF;W)M871I;VXZ`$-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU
M9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!54DQS.@!#:&]O<V4@>6]U
M<B!D969A=6QT(&-A;&5N9&%R+@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC
M92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&%L;"!A='1E;F1E97,`0VQE87(@
M;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R
M:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%14
M4`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S
M960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R
M('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM82!S
M97!A<F%T960@=F%L=65S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT
M`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET
M:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF
M:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@
M86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O
M;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F9I<FT@9&5L971I;VX@
M;V8@979E;G1S/P!#;VYF:7)M960`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C
M=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y
M<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT
M:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S
M`$-O<'D@<V5L96-T:6]N`$-O<'D@=&AE(%523"!B96QO=R!F;W(@=7-E('=H
M97)E=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y(%523#H`0V]S="!)1`!#
M;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@
M(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK
M("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E
M(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N
M=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!#86QE;F1A<@!#<F5A=&4@82!.
M97<@179E;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T
M92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E
M9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT`$-U<G)E;G0@
M-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N
M="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N
M="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP
M<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$
M1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A:6QY.B!2
M96-U<G,@979E<GD`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``
M1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$87DH<RD`
M1&5?;&5T90!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E
M<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#
M86QE;F1A<@!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L
M="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E("5S`$1E;&5T92!#
M96QL`$1E;&5T92!%=F5N=`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE
M=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T
M92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O
M;FQY+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E
M<RP@;W(@86QL(&]C8W5R96YC97,_`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`
M1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T
M:6UE`$1E;FUA<FL`1&5S8W)I7W!T:6]N`$1E<V-R:6)E('1H92!0<F]B;&5M
M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S
M="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`
M1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D`1&ES
M<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($-A;&5N9&%R<P!$:7-P;&%Y
M($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O
M<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF
M:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT('1O('-H;W<@
M=&%S:W,@=VAI8V@@87)E(&1U92!O;B!Y;W5R(&-A;&5N9&%R/P!$;V5S(&YO
M="!R96-U<@!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN
M:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S
M`$1U93H@)7,`1'5R871I;VX`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y
M(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V
M:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@)7,`161I="!!='1E;F1E97,`
M161I="!";&]C:P!%9&ET($-A;&5N9&%R<P!%9&ET($=R;W5P`$5D:70@4&5R
M;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S`$5D:70@4F5M;W1E($-A;&5N9&%R<P!%9&ET(&%T=&5N9&5E<P!%9&ET
M(&-A=&5G;W)I97,@86YD(&-O;&]R<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M
M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y
M`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y
M('-E87)C:"!T97)M<P!%;E]D`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!$871E`$5N9"!/;@!%;F0@5&EM90!%
M;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@
M>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H
M92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S
M>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R
M<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@<F5T<FEE=FEN9R!F<F5E
M+V)U<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<P!%<G)O<B!U<&1A=&EN9R!P
M87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W
M<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%
M=F5N="!A9&1E9#H`179E;G0@9&5L971E9#H`179E;G0@961I=&5D.@!%=F5N
M="!F<F]M("5S('1O("5S`$5V96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E
M+@!%=F5N=',@;75S="!H879E(&$@=&ET;&4N`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU
M=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`
M17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!.86UE<P!%
M>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D
M(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE
M;G0`17AP;W)T`$5X<&]R="!#86QE;F1A<@!&1R!#;VQO<@!&5%`@=7!L;V%D
M(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&
M86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE
M9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E
M=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I
M9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@
M0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S
M96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T
M960N`$9I;'1E<G,`1FEN9`!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A
M<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D
M;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD
M(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D
M/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE
M<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@
M365T<F]P;VQI=&%N`$9R964`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R96YC
M:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,`1G)I9&%Y`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I
M;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=71U<F4`1V%B;VX`1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=A;64`1V5N97)A
M;`!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E
M;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B
M86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C
M:`!';W1O("5S`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I
M`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E
M;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO
M;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`
M2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG
M;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U
M.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(
M96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`
M2&ED90!(:61E("5S`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M
M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W5R*',I`$AO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I`$AO=R!L;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T
M<R!O;B!T:&4@9&%Y(&%N9"!W965K('9I97=S(&)E/P!(;W<@;6%N>2!C;VQU
M;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!D87ES(&]F
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S:&]U;&0@=V4@9V5N97)A=&4_`$AO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET
M>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E
M<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W
M:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I
M;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O
M;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@
M8G)O=W-E<BX`268@>6]U<B!E;6%I;"!C;&EE;G0@9&]E<VXG="!S=7!P;W)T
M(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@;VYE(&]F('1H92!F;VQL;W=I
M;F<@;&EN:W,@=&\@86-C97!T(&]R(&1E8VQI;F4@=&AE(&5V96YT+@H*5&\@
M86-C97!T('1H92!E=F5N=#H*)7,*"E1O(&%C8V5P="!T:&4@979E;G0@=&5N
M=&%T:79E;'DZ"B5S"@I4;R!D96-L:6YE('1H92!E=F5N=#H*)7,`26UA9V4@
M4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL
M97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!)
M;7!O<G0@0V%L96YD87(L(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R
M="]%>'!O<G0@0V%L96YD87(`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D
M(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I
M=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK
M`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS
M97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@
M;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R
M87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E
M`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI
M;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E
M9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A
M=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L
M:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI
M9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI
M9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI
M<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O
M9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B
M`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N
M`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C
M=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)
M<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET
M86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E3
M3RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE
M=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H
M`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N`$ME>7=O<F1S`$MI9',`2VER:6)A=&D`2V]R
M96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E
M<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,
M85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC`$QA<W0@,C0@:&]U<G,`3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S
M="!-;VYT:`!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S
M="!5<&1A=&5D.@!,87-T(%EE87(`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87-T('=E96L`3&%T
M=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A
M;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E
M;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I
M;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,
M:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W
M:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE
M<FEC:P!,:6UI="!T:&4@=&EM92!S<&%N('1O(&5X<&]R=#H`3&EN:P!,:6YK
M('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M
M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`
M3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S
M`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI
M<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B
M<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL
M960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;U]C871I;VX`
M3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T
M:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O
M=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E
M96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU
M;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C
M;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA
M:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-
M86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!R96UO=&4@8V%L96YD87)S+@!-
M86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E
M;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S
M('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N
M<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@
M9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I
M="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU
M;6)E<B!O9B!%=F5N=',`36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-90!-961I8VEN90!-965T
M:6YG`$UE;6)E<G,`365N=2!!;&%R;7,`365N=2!,:7-T`$UE;G4@;6]D93H`
M365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T
M87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T
M960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@
M;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4
M>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I
M<F5D`$UI;G5T92AS*0!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S960@179E
M;G1S($QI<W0`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-
M:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET
M(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES
M<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G
M92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO
M9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O
M=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYD87D`36]N9V]L:6$`36]N=&@`
M36]N=&@@5FEE=P!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1H;'D@179E
M;G1S($QI<W0`36]N=&AL>3H@4F5C=7)S(&5V97)Y`$UO;G1H<R!!:&5A9`!-
M;VYT:',@0F5F;W)E`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L
M9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R
M;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`
M36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D
M;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE(&E#86QE;F1A<B!C;VUP
M;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!V179E;G0@:7,@<W5P<&]R=&5D+@!-
M=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R
M;6%T:6]N`$UY($-A;&5N9&%R<P!->2!#86QE;F1A<G,Z`$UY($9R964O0G5S
M>2!54DP`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@
M22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE
M<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),
M`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC
M>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W
M;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!%=F5N
M=`!.97<@365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P
M=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@8V%L96YD87(@8W)E871E9"!A;F0@
M875T;VUA=&EC86QL>2!S:&%R960@=VET:"!F;VQL;W=I;F<@9W)O=7`H<RDZ
M("5S+@!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?
M8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@,C0@:&]U<G,`3F5X
M="`T(%!H87-E<P!.97AT($1A>0!.97AT($UO;G1H`$YE>'0@5V5E:P!.97AT
M(%EE87(`3F5X="!D87D`3F5X="!O<'1I;VYS`$YE>'0@=V5E:P!.97AT/@!.
M:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%L87)M
M`$YO(&%T=&5N9&5E<P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BX`3F\@8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+@!.;R!C
M:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@
M;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&5N9"!D871E`$YO
M(&5V96YT<R!T;R!D:7-P;&%Y`$YO(&9I;&4@=7!L;V%D960`3F\@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@)7,`3F\@:4-A;&5N
M9&%R(&1A=&$@=V%S(&9O=6YD+@!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I
M;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S
M=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I
M960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H
M('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@
M8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A
M+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<F5C=7)R
M96YC90!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E
M<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L:60@96UA:6P@
M861D<F5S<R!F;W5N9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O
M<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!2
M96=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI
M8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T
M:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W
M87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!F
M;W5N9`!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`
M3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EF:6-A=&EO
M;G,`3F]V96UB97(`3F]W`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.
M=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S
M<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/
M2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E
M(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@
M9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C
M;W)R96-T+@!/;6%N`$]N`$]N(&%L;"!C86QE;F1A<G,@22!H879E(')E860@
M86-C97-S('1O`$]N(&%L;"!S:&]W;B!C86QE;F1A<G,`3VX@;7D@8V%L96YD
M87)S(&]N;'D`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M
M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N86P`3W!T:6]N86P@071T96YD965S
M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A
M=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=F5R=FEE=P!/=VYE<@!/=VYE
M<B!097)M:7-S:6]N<P!/=VYE<CH@)7,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A
M;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y
M`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL
M`%!-`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`
M4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`
M4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`
M4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W
M;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I
M;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W0@179E;G1S
M($QI<W0`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0871T97)N
M`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!O;B!L;V=I;C\`4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_
M`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M
M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP
M<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S
M`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@
M8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E
M(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES
M=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N
M9`!0;VQI=&EC<P!0;VQL<P!0;W)T86P@3W!T:6]N<P!0;W)T=6=A;`!0;W-I
M=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I
M`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET
M871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E
M(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@1&%Y`%!R979I;W5S
M(%=E96L`4')E=FEO=7,@9&%Y`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C
M=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N
M`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!
M;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A
M=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO
M('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO
M=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE
M`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5C=7(@56YT:6P`4F5C=7)R96YC90!296-U<G)E;F-E
M($1A=&$`4F5C=7)R96YC92!%;F0@1&%T90!296-U<G)E;F-E($EN=&5R=F%L
M`%)E8W5R<F5N8V4@5'EP90!296-U<G,@9&%I;'D`4F5C=7)S(&UO;G1H;'D`
M4F5C=7)S('=E96ML>0!296-U<G,@>65A<FQY`%)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W
M<V5R`%)E;&]A9`!296UA<FMS`%)E;6EN9&5R.B`E<P!296UO=&4@0V%L96YD
M87)S`%)E;6]T92!#86QE;F1A<G,Z`%)E;6]T92!397)V97)S`%)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M
M;W9E("5S`%)E;6]V92!!='1E;F1E90!296UO=F4@0FQO8VL`4F5M;W9E(&-O
M;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297!L86-E(&5X:7-T:6YG
M(&-A;&5N9&%R('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N
M:6YG.B!4:&ES(&1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT
M(&-A;&5N9&%R+CPO<W1R;VYG/@!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"!!='1E;F1E97,`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O
M<F0`4F5S970@66]U<B!087-S=V]R9`!297-E="!T;R!$969A=6QT<P!297-P
M;VYS90!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T
M:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I
M9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG
M:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N
M+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E
M(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U
M;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O
M;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I
M86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG
M;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H
M96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%
M4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD
M($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H
M7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E
M`%-A=&5L;&ET92!0<F]V:61E<@!3871U<F1A>0!3875D:2!!<F%B:6$`4V%V
M90!3879E("(E<R(`4V%V92`E<P!3879E($%S($YE=P!3879E($%T=&5N9&5E
M<P!3879E($5V96YT`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A
M=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@
M5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($-A;&5N9&%R<P!396%R
M8V@@16YG:6YE<P!396%R8V@@4F5S=6QT<P!396%R8V@@9F]R(&-A;&5N9&%R
M<R!C;VYT86EN:6YG.@!396QE8W0@1FEL97,`4V5L96-T(&$@8V%L96YD87(@
M=&\@961I=`!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!3
M96QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S
M97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N
M=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&-A;&5N9&%R<R!T;R!D:7-P
M;&%Y.@!396QE8W0@8V]N9FER;6%T:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P
M;&%Y('1H92!D:69F97)E;G0@=FEE=W,@86YD(&-H;V]S92!D969A=6QT('9I
M97<N`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T
M('1O.@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!E>'!O<G0@
M9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE
M(&9I<G-T('=E96MD87DZ`%-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R
M8V4@9FEL93H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM
M92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C
M="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N('-T87)T=7`Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@
M:6X@=&AE('!O<G1A;"X`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N9"!335,`4V5N9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL
M(&%T=&5N9&5E<R!W:&5N(&1E;&5T:6YG('1H:7,@979E;G0`4V5N9"!A;B!E
M;6%I;"!T;R`E<P!396YD('5P9&%T97,O:6YV:71A=&EO;G,@=&\@86QL(&%T
M=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V96YT`%-E;F5G86P`4V5N<V]R
M.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M
M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I
M;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T
M(&5N9"!D871E`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T(')E8W5R
M<F5N8V4@96YD(&1A=&4`4V5T('-T87)T(&1A=&4`4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN`%-E="!Y;W5R(&9R964O8G5S>2!C86QE;F1A<G,@86YD('EO=7(@;W=N
M(&%N9"!O=&AE<B!U<V5R<R<@9G)E92]B=7-Y(&]P=&EO;G,N`%-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y
M8VAE;&QE<P!3:&%R92!N;W0@9F]U;F0Z("5S`%-H87)E9"!#86QE;F1A<G,`
M4VAA<F5D($-A;&5N9&%R<SH`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO
M=P!3:&]W($-A;&5N9&%R`%-H;W<@8V%T96=O<GD@;&5G96YD/P!3:&]W(&1E
M;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R
M('9I97=S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@9'5E('1A<VMS(&EN('1H92!C86QE;F1A<C\`4VAO=R!F<F5E+V)U<WD@
M;&5G96YD/P!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M`%-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\`4VAO
M=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('-H
M87)E9"!C86QE;F1A<G,@<VED92UB>2US:61E/P!3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_`%-H;W<@=&%S:W,@=7-I;F<@8V%T96=O<GD@8V]L
M;W)S/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W
M('1I;64@;V8@9&%Y(&)E='=E96X@96%C:"!D87D@:6X@=V5E:R!V:65W<S\`
M4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T
M90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO
M=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T
M`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG
M;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K
M:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO
M=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z
M(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`
M4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O
M=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R
M(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3
M<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`
M4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T85]R
M=`!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@1&%T90!3=&%R="!/;@!3=&%R
M="!4:6UE`%-T87)T('EE87(`4W1A=%]U<P!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR
M;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N9&%Y
M`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E
M=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA
M;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W
M:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R
M;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!4
M4U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L
M92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G
M970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R
M.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O
M/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O
M=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!496YT871I=F4`5&5X=`!4
M97AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I
M`%1H86EL86YD`%1H92!%9&ET($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@;&]N
M9V5R('!R97-E;G0N($5X:71I;F<N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L
M:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U
M8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI
M=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V%L
M96YD87(@(B5S(B!C86YN;W0@8F4@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E
M<R(@:&%S(&)E96X@8W)E871E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@<F5N86UE
M9"!T;R`B)7,B+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S`%1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E
M;F0@9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N`%1H
M92!E=F5N="`B)7,B(&AA<R!B965N(&%D9&5D('1O("(E<R(@8V%L96YD87(L
M('=H:6-H(&ES(&]N("5S(&%T("5S+@!4:&4@979E;G0@(B5S(B!H87,@8F5E
M;B!D96QE=&5D(&9R;VT@(B5S(B!C86QE;F1A<BP@=VAI8V@@=V%S(&]N("5S
M(&%T("5S+@!4:&4@979E;G0@(B5S(B!H87,@8F5E;B!E9&ET960@;VX@(B5S
M(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%1H92!E=F5N="!N
M;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+@!4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE
M(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F
M;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9F]L;&]W:6YG
M(&ES(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z
M`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L
M96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U
M9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M
M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET
M;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@
M268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY
M('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M
M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E
M9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F
M97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A
M=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R
M;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO
M="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R97%U97-T('=A<R!I
M;F-O;7!L971E+B!3;VUE('!A<F%M971E<G,@=&AA="!A<F4@;F5C97-S87)Y
M('1O(&%C8V5P="!O<B!D96-L:6YE(&%N(&5V96YT(&%R92!M:7-S:6YG+@!4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W
M("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B
M(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T
M(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O
M='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R
M+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y
M("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@979E;G1S(&UA=&-H:6YG
M('1H92!C=7)R96YT(&-R:71E<FEA+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@
M9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<P!4:&5R92!W87,@86X@97)R
M;W(@861D:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R
M(&5D:71I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F
M="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&UO
M=FEN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN
M9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N`%1H:7,@24U!4"!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H
M:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS
M,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F
M;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@
M8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@
M;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@
M3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:'5R<V1A>0!4:6-K971S`%1I;64`
M5&EM92!3<%]A;@!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L
M96-T:6]N`%1I;64@<W!A;@!4:6UO<BU,97-T90!4:71?;&4`5&ET;&4`5&ET
M;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I
M`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L
M<V4`5'4`5'5E<V1A>0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U
M.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U
M=F%L=0!4>7!E`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),
M`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!5
M4DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E
M;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE
M('1O(&1E;&5T92`B)7,B.B`E<P!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S
M+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>0!5;F%B;&4@=&\@9&5L971E("5S+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5
M;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N
M86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@(B5S(CH@)7,`56YA8FQE
M('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A
M9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<P!5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O
M($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H
M551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N
M:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M
M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E
M9"!#;VYT96YT+51Y<&4Z("5S`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A
M=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!D871E
M9#H@)7,N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`
M57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U
M87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R($EN=&5R9F%C90!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I
M;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R
M;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L
M90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO
M;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R
M=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI
M`%9I97<@)7,`5FEE=R!$87D`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N
M80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7961N97-D87D`
M5V5E:P!7965K("5D`%=E96LH<RD`5V5E:VQY`%=E96ML>3H@4F5C=7)S(&5V
M97)Y`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!3
M86AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E
M<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&%T('1I;64@<VAO=6QD(&1A
M>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R
M(&5V96YT<S\`5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@
M<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/P!7:&5R
M96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED
M=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T
M:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R
M;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I
M<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5V]R:R!7965K
M`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG
M(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P
M.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87(`665A<FQY
M`%EE87)L>3H@4F5C=7)S(&5V97)Y`%EE;65N`%EE<P!997,L($D@06=R964`
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!E=F5N=',N`%EO=2!A<F4@
M;F]T(&%N(&%T=&5N9&5E(&]F('1H92!S<&5C:69I960@979E;G0N`%EO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;VYL>2!U<V4@=&AI<R!F
M;W)M(&9R;VT@=&AE($5D:70@071T96YD965S('-C<F5E;BX`66]U(&-A;FYO
M="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@
M:&%V92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S
M;VYA;"!);F9O<FUA=&EO;B!/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S
M:&5R925S(&)E9F]R92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT
M+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O
M("5S+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S
M('1O('1H92!S96QE8W1E9"!C86QE;F1A<BX`66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N`%EO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="X`66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+@!9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C
M86QE;F1A<BX`66]U(&AA=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N
M9&5N8V4@=&\@=&AI<R!E=F5N="X`66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E
M8VQI;F5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="X`66]U(&AA=F4@=&5N
M=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU
M<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<V5L96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P
M<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=2!R97%U97-T960@
M=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&%D9&5D('1O('EO=7(@
M8V%L96YD87)S+@!9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@
M979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U<B!C86QE;F1A<G,N`%EO=2!R
M97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&5D:71E
M9"!I;B!Y;W5R(&-A;&5N9&%R<RX`66]U(')E<75E<W1E9"!T;R!B92!R96UI
M;F1E9"!A8F]U="`E<RP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.
M86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T
M:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8V%L96YD87(`66]U
M<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S
M(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X
M<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`
M6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O
M8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D
M(%1E>'0@+2`E<R!L:6YE<UT`6U5N;F%M960@979E;G1=`%ML:6YE("5S(&]F
M("5S70!?061M:6YI<W1R871I;VX`7T%L87)M`%]"87-I8R!396%R8V@`7T-,
M20!?1&%T851R964`7T1E;&5T92!2;W<`7T5D:70`7T=O=&\`7T=R;W5P<P!?
M2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&]G
M(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?37D@0V%L96YD87)S`%].
M97<@179E;G0`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]0<FEN=`!?4F5M;W9E
M($QI;FLN+BX`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`
M7U1O9&%Y`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`
M8F5F;W)E('1H92!E=F5N="!S=&%R=',`8V%L96YD87(`8V%L;0!C86YN;W0@
M8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE
M<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R
M;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E
M<G)O<@!D87D`9&%Y*',I`&1A>7,`961I=`!E;G1R>2!N;W0@9F]U;F0`979E
M;G1S+F-S=@!E=F5N=',N:6-S`&9A;&QI;F<`9FEL90!F<F]M`&9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK
M;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E
M<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&UO;G1H*',I`&YA;64`;F]T(&EM
M<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!O;B`E<R!A
M="`E<P!O;B!T:&4@<V%M92!D871E`&]N('1H92!S86UE('=E96MD87D`<&5R
M8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN
M('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF
M9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@
M97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@
M<V5L96-T`'9#86QE;F1A<B]I0V%L96YD87(`=D-A<F0`=D5V96YT(&YO="!F
M;W5N9"X`=SH`=V5A=&AE<BYC;VT`=V5E:P!W965K*',I(&]N.@!W965K<P!Y
M96%R*',I`%!R;VIE8W0M260M5F5R<VEO;CH@2W)O;F]L:71H"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-BTP,BTQ-B`Q-CHT,"TP,C`P"DQA<W0M5')A;G-L871O<CH@1F%B
M:6\@1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R/@I,86YG=6%G92U496%M.B!"
M<F%Z:6QI86X@4&]R='5G=65S92`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*6"U'96YE<F%T;W(Z($M"86)E;"`Q+C,N,0I0;'5R86PM1F]R;7,Z("!N
M<&QU<F%L<STR.R!P;'5R86P]*&X@/B`Q*3L*`"`H)7,@9&EA<R!A='+A<RD`
M("A496-L82!D92!!=&%L:&\@)7,I`"`H96T@)7,@9&EA<RD`("AH;VIE*0`@
M*&%M86YHXRD`("AO;G1E;2D`(&$@`"(E<R(@3N-O(.D@=6T@9&ER973S<FEO
M+@`G)7,G(&[C;R#I('5M82!E<V-O;&AA(';A;&ED82X`)R5S)R!NXV\@97-T
MX2!C;VYF:6=U<F%D;R!N;R!296=I<W1R;R!D;R!(;W)D92X`<F5N9&5R:7IA
M9&]R(&1E(.%R=F]R92`B)7,B(&[C;R!E;F-O;G1R861O+@`B)7,B(&9O:2!A
M9&EC:6]N861O(&%O('-I<W1E;6$@9&4@9W)U<&]S+@`B)7,B(&9O:2!A9&EC
M:6]N861O(&%O('-I<W1E;6$@9&4@<&5R;6ES<_5E<RX`(B<E<R(@;N-O(&9O
M:2!C<FEA9&\Z("5S+@`E+C)F34(@=7-A9&]S(&1E)2XR9DU"('!E<FUI=&ED
M;W,@*"4N,F8E)2D`)60@)7,@92`E<P`E9"!A9V5N9&%S(&[C;R!E;F-O;G1R
M861A<P`E9"!D:6%S(&%TZ2!S=6$@<V5N:&$@97AP:7)A<BX`)60@979E;G1O
M<P`E9"!P<F5V:7/C;R!D;R!D:6$`)7,@+2!!=FES;P`E<R!$:6$H<RD@)7,@
M2&]R82AS*2`E<R!-:6YU=&]S`$EM<')E<W/C;R!$:6=I=&%L(&1E("5S`"5S
M($M"`"5S($]P97)AY_5E<R!D92!-86YU=&5NY^-O("T@0V]N9FER;6'GXV\`
M0V]N9FEG=7)AY^-O(&1E("5S`$-A9&%S=')O(&1E("5S`"5S(%1E<FUO<R!D
M;R!!8V]R9&\`)7,@:N$@97AI<W1E+@`E<R!A("5S("5S`"5S('!A<G1I8VEP
M86YT97,`07)Q=6EV;R`E<R!I;7!O<G1A9&\@8V]M('-U8V5S<V\`)7,@97-T
MX2!P<F]N=&\@<&%R82!E>&5C=71A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E
M;N?C;R!M87)C861A<R!A8F%I>&\N($UA<G%U92!A(&-A:7AA('!A<F$@<75A
M;'%U97(@;W!E<F'GXV\@<75E('9O8^H@<75E:7)A(&5X96-U=&%R(&1E<W1A
M('9E>BX`)7,@Z2!O8G)I9V%T\W)I;P`E<R!M:6YU=&]S`"5S(&[C;R!E;F-O
M;G1R861O+@`E<R!A("5S(&1E("5S`$-A=.%L;V=O(&1E($5N9&5R9>=O<R!D
M92`E<P!!9V5N9&$@9&4@)7,`06YO=&'G]65S(&1E("5S`$QI<W1A(&1E(%1A
M<F5F87,@9&4@)7,`)7,Z("5S`"5S.B!%<W1A(&UE;G-A9V5M('!O9&4@;N-O
M('-E<B!D92!Q=65M(&5L82!D:7H@<V5R+B!4;VUE(&-U:61A9&\@8V]M('%U
M86QQ=65R(&QI;FL@<')E<V5N=&4@;F5L82!O=2!E;2!F;W)N96-E<B!A;R!R
M96UE=&5N=&4@<75A;'%U97(@:6YF;W)M8>?C;R!P97-S;V%L+@`H0VQI<75E
M(&YO(&YO;64@9&$@86=E;F1A('!A<F$@86QT97)A<B!A('9I<W5A;&EZ8>?C
M;R!D82!A9V5N9&$@;F$@:F%N96QA('!R:6YC:7!A;"D`*B!!9&EC:6]N92!E
M<W1E<R!C;&EC86YD;R!E;2!!9&EC:6]N87(@*@`J(%!O<B!F879O<B!S96QE
M8VEO;F4@;RAS*2!E;F1E<F7G;RAS*2`J`"P@8G)I<V$@`"P@8G)I<V$@)7,@
M)7,`+"!V87)IX79E;"!D92`E<R!P87)A("5S`"TM('-E;&5C:6]N92`M+0`Q
M('!A<G1I8VEP86YT90`Q(&5V96YT;P`Q(&AO<F$`1F]R;6%T;R`Q,B!(;W)A
M<P`Q-2!M:6YU=&]S`#(P(&UI;G5T;W,`1F]R;6%T;R`R-"!(;W)A<P`R-"!H
M;W)A<P`S,"!M:6YU=&]S`#Q0X6=I;F$@06YT97)I;W(`/'-T<F]N9SY087)T
M:6-I<&%N=&5S/"]S=')O;F<^("AO<&-I;VYA;"D`/'-T<F]N9SY$7V5S8W)I
MY^-O/"]S=')O;F<^("AO<&-I;VYA;"D`/'-T<F]N9SY086QA=G)A<RUC:&%V
M93PO<W1R;VYG/B`H;W!C:6]N86PI`#QS=')O;F<^4F5P971IY^-O/"]S=')O
M;F<^("AO<&-I;VYA;"D`56T@8V]N96-T;W(@9&4@8F%N8V\@9&4@9&%D;W,@
MZ2!O8G)I9V%T\W)I;R!P87)A(&5S=&4@8FQO8V\N`%5M(&5R<F\@9F%T86P@
M;V-O<G)E=0!5;6$@8VAA=F4@</IB;&EC82!01U`@Z2!O8G)I9V%T\W)I82!P
M87)A(&-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P^F)L
M:6-A(%!'4"#I(&]B<FEG873S<FEA('!A<F$@=F5R:69I8V%R('5M82!M96YS
M86=E;2!A<W-I;F%D82X`56UA(&-H879E('!R:79A9&$@4$=0(&4@=6UA('-E
M;FAA('/C;R!O8G)I9V%T\W)I87,@<&%R82!D97-C<FEP=&]G<F%F87(@=6UA
M(&UE;G-A9V5M+@!5;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@<V5N:&$@
M<^-O(&]B<FEG873S<FEA<R!P87)A(&%S<VEN87(@=6UA(&UE;G-A9V5M+@!5
M;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O
M34E-12!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@9&5S8W)I
M<'1O9W)A9F%R('5M82!M96YS86=E;2X`56UA(&-H879E('#Z8FQI8V$@4R]-
M24U%+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@<V5N:&$@<^-O
M(&]B<FEG873S<FEA<R!P87)A(&%S<VEN87(@=6UA(&UE;G-A9V5M+@!5;6$@
M8VAA=F4@</IB;&EC82!3+TU)344@Z2!O8G)I9V%T\W)I82!P87)A(&-R:7!T
M;V=R869A<B!U;6$@;65N<V%G96TN`$%-`$YU=F5N<R!M871U=&EN87,`0VAU
M=F$@1G)A8V$@5F5S<&5R=&EN80!#:'5V82!M871U=&EN80!#:'5V87,@;6%T
M=71I;F%S`$YE=F%S8V%S($UA='5T:6YA<P!!32]030!!4$D@240`4V]B<F4@
M97-T92!E9&ET;W(`4V]B<F4N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V5I
M=&$`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!D:7)E=/-R:6\@5D93+@!!8V5S
M<V\@;F5G861O(&%O(&-R:6%R(&%R<75I=F\@5D93+@!3=6%S($EN9F]R;6'G
M]65S`%-E;FAA(&1A($-O;G1A`$-O;G1A(&1E<V%T:79A9&$N`$-O;G1A<P!0
M97-Q=6ES82!!7W9A;N=A9&$`061I8VEO;F%R`$%D:6-I;VYA<B!'<G5P;R!3
M=6)O<F1I;F%D;P!!9&EC:6]N87(@4&5R;6ES<_5E<R!3=6)O<F1I;F%D87,`
M061I8VEO;F%R($5V96YT;P!!9&EC:6]N92!!<75I.@!!9&EC:6]N87(@3F]V
M;R!'<G5P;P!!9&EC:6]N87(@3F]V82!097)M:7-SXV\`061I8VEO;F%R('5M
M(&=R=7!O('-U8F]R9&EN861O(&$@)R5S)P!!9&EC:6]N87(@=6UA('!E<FUI
M<W/C;R!S=6)O<F1I;F%D82!A("<E<R<`061I8VEO;F%R('5M82!N;W9A($%G
M96YD82!296UO=&$`061I8VEO;F%R(&YO=F\@979E;G1O`$%D:6-I;VYA<B!U
M;2!N;W9O('5S=>%R:6\Z`$%D:6-I;VYA<B!P87)T:6-I<&%N=&5S`$%D:6-I
M;VYA<B!C;VQU;F$`061I8VEO;F%R(&YO=F]S(&UE;6)R;W,`061I8VEO;F%R
M('!A<@!!9&EC:6]N87(@;R!-96YU("5S(&-O;6\@=6UA($)A<G)A($QA=&5R
M86P@9&\@36]Z:6QL80!!9&EC:6]N87(@86\@8V%TX6QO9V\@9&4@96YD97)E
MYV]S.@!!9&EC:6]N87(@86\@;65U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!!
M9&EC:6]N87(@=7-UX7)I;P`G)7,G(&%D:6-I;VYA9&\@86\@<VES=&5M82P@
M;6%S(&[C;R!P=61E(&EN8VQU:7(@:6YF;W)M8>?U97,@861I8VEO;F%I<R!D
M;R!C861A<W1R;SH@)7,N`"5S(&%D:6-I;VYA9&\@86\@<VES=&5M82X@5F]C
MZB!P;V1E('-E(&-O;F5C=&%R(&%G;W)A+@!!9&GGXV\@9&4@=7-UX7)I;W,@
M97-TX2!D97-A8FEL:71A9&$N`$5N9&5R9>=O`$-A=.%L;V=O(&1E($5N9&5R
M9>=O<P!!9&UI;FES=')A<B`M(&-O;F9I9W5R82!P97)M:7-S]65S('!A<F$@
M;W5T<F]S('5S=>%R:6]S`$%D;6EN:7-T<F'GXV\`06[Z;F-I;W,`4&5S<75I
M<V$@079A;N=A9&$`069E9V%N:7-TXV\`079I<V\`079I<V%R("5D(&1I87,@
M86YT97,`079I<V%R("5D(&AO<F%S(&%N=&5S`$%V:7-A<B`E9"!M:6YU=&]S
M(&%N=&5S`$%V:7-A<B`E9"!S96UA;F%S(&%N=&5S`$%V:7-A<B`Q(&1I82!A
M;G1E<P!!=FES87(@,2!H;W)A(&%N=&5S`$%V:7-A<B`Q(&UI;G5T;R!A;G1E
M<P!!=FES87(@,2!S96UA;F$@86YT97,`1&%T82!D;R!A=FES;P!$=7)AY^-O
M(&1O($%V:7-O("AM:6YU=&]S*0!(;W+A<FEO(&1O($%V:7-O`$%L8N)N:6$`
M07)GZ7)I80!!<&5L:61O`$%L:6YH87(`06QI;FAA;65N=&\Z`%1O9&]S`%1O
M9&]S(%!A<G1I8VEP86YT97,`5&]D;W,@57-UX7)I;W,@075T96YT:6-A9&]S
M`%1O9&]S($9U='5R;W,`5&]D;W,@1W)U<&]S`%1O9&]S(%!A<W-A9&]S`%1O
M9&%S(%!E<FUI<W/U97,`5&]D;W,@5FES[79E:7,`1&EA('1O9&\`179E;G1O
M(&\@9&EA('1O9&\`5&]D;W,@979E;G1O<P!4;V1O<R!Q=6%T<F\@;&%D;W,`
M4&5R;6ET:7(@;?IL=&EP;&]S(&5N9&5R9>=O<P!097)M:71I<B!C;VYF:6=U
M<F%R(&\@=&EP;R!D92!L:7-T87,@;W)D96YA9&%S/P!*X2!E>&ES=&4`3&]G
M:6X@24U34"!!;'1E<FYA=&EV;P!396YH82!)35-0($%L=&5R;F%T:79A`%5S
M=>%R:6\@24U34"!!;'1E<FYA=&EV;P!%;F1E<F7G;R!D92!E+6UA:6P@86QT
M97)N871I=F\`36]D96QO<R!A;'1E<FYA=&EV;W,`5&5X=&\@86QT97)N871I
M=F\Z`%-A;6]A($%M97)I8V%N80!5;2!V86QO<B!I;&5G86P@9F]I(&5S<&5C
M:69I8V%D;RX`3V-O<G)E=2!U;2!E<G)O(&1E<V-O;FAE8VED;RX`06YD;W)R
M80!!;F=O;&$`06YG=6EL;&$`4')O>'D@86[T;FEM;P!297-P;W-T80!!;G3A
M<G1I9&$`06YT:6=U82!E($)A<F)A9&]S`%%U86QQ=65R('5M`$%P;&EC8>?C
M;P!,:7-T82!D92!!<&QI8V'G]65S`$$@87!L:6-AY^-O(&5S=.$@<')O;G1A
M+@!!<&QI8V%R(&%O<R!#;VUP87)T:6QH86UE;G1O<R!3=6)O<F1I;F%D;W,`
M07!R;W9A<@!486UA;FAO($%P<F]X:6UA9&\`06)R:6P`07+A8FEC;R`H5VEN
M9&]W<RTQ,C4V*0!486UA;FAO(&1O($%R<75I=F\`3F]M92!D;R!!<G%U:79O
M`%9O8^H@=&5M(&-E<G1E>F$@<75E('%U97(@<F5M;W9E<B!A('-O;&EC:71A
MY^-O(&1E(&-A9&%S=')O(&1E("5S/P!6;V/J('1E;2!C97)T97IA('%U92!D
M97-E:F$@97AC;'5I<B`G)7,G(&4@<V5U<R!S=6)G<G5P;W,_`$%R9V5N=&EN
M80!!<FWJ;FEA`$%R;>IN:6\@*$%235-#24DM."D`07)T90!!<G5B80!);&AA
M($%S8V5N<^-O`$%R=&4@07-C:6D`P7-I82]296=IXV\@9&\@4&%C[69I8V\`
M4V]L:6-I=&%R(&-O;F9I<FUAY^-O(&%N=&5S(&1E(&5X96-U=&%R(&%S(&]P
M97)AY_5E<R!D92!M86YU=&5NY^-O/P!#;VQU;F%S(&1E(&1E<VEG;F'GXV\`
MP',`4V4@96YC;VYT<F$@86YE>&%D;R!U;2!A<G%U:79O(&E#86QE;F1A<B!C
M;VT@;6%I<R!I;F9O<FUAY_5E<R!S;V)R92!O(&5V96YT;RX@4V4@<V5U(&-L
M:65N=&4@9&4@8V]R<F5I;R!S=7!O<G1A(')E<75I<VGG]65S(&E4:7`L('9O
M8^H@<&]D92!U=&EL:7IA<B!E<W1E(&%R<75I=F\@<&%R82!A='5A;&EZ87(@
M9F%C:6QM96YT92!S=6$@8_-P:6$@;&]C86P@9&\@979E;G1O+@!496YT;W4@
M97AC;'5I<B!U;2!G<G5P;R!I;F5X:7-T96YT92X`5&5N=&]U(&5X8VQU:7(@
M=6UA('!E<FUI<W/C;R!NXV\@97AI<W1E;G1E+@!496YT;W4@961I=&%R('5M
M82!P97)M:7-SXV\@;N-O(&5X:7-T96YT92X`5&5N=&]U(&5D:71A<B!U;2!C
M;VUP87)T:6QH86UE;G1O(&[C;R!E>&ES=&5N=&4N`%!R97-E;N=A`%!A<G1I
M8VEP86YT97,`071R:6)U=&]S`$%G;W-T;P!!=7-T<N%L:6$`P75S=')I80!!
M=71H7V-Y<G-Q;#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:6UA
M<"!N96-E<W/A<FEA+@!!=71H7V-Y<G5S.B!/(&-O;F5C=&]R(&[C;R!P;W-S
M=6D@87,@8V%P86-I9&%D97,@;F5C97-SX7)I87,N`$%U=&A?8WER=7,Z($[C
M;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82X`
M075T:%]F='`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($944"!N
M96-E<W/A<FEA+B!#;VUP:6QE(&\@4$A0(&-O;2!A(&]PY^-O("TM96YA8FQE
M+69T<"X`075T:%]I;6%P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C
M;R!I;6%P(&YE8V5S<^%R:6$N`$%U=&A?:W)B-3H@3N-O(&9O:2!E;F-O;G1R
M861A(&$@97AT96YSXV\@:W)B-2!N96-E<W/A<FEA+@!!=71H7VQD87`Z($EN
M8VQU<^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!%>&-L=7/C;R!D92!U<W7A<FEO<R!N
MXV\@Z2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@3$1!4"!N96-E<W/A
M<FEA+@!!=71H7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R(&\@=7-UX7)I
M;R`E<RX@27-T;R!F;VD@;R!Q=64@;R!S97)V:61O<B!R97!O<G1O=3H@`$%U
M=&A?;&1A<#H@26UP;W-S[79E;"!R96UO=F5R(&\@=7-UX7)I;R`E<P!!=71H
M7VQD87`Z($EM<&]S<^UV96P@871U86QI>F%R(&\@=7-UX7)I;R`E<P!!=71H
M7VQD87`Z($%T=6%L:7IAY^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D
M82!P87)A($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@3N-O(&9O:2!E
M;F-O;G1R861A(&$@97AT96YSXV\@34-!3"!N96-E<W/A<FEA+@!!=71H7W-M
M8F%U=&@Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O('-M8F%U=&@@
M;F5C97-SX7)I82X`075T96YT:6-AY^-O(&YO('-E<G9I9&]R($E-05`@9F%L
M:&]U+@!&86QH82!N82!A=71E;G1I8V'GXV\`1F%L:&$@;F$@875T96YT:6-A
MY^-O.B`E<P!!=71E;G1I8V'GXV\@<F5J96ET861A('!E;&\@<V5R=FED;W(@
M4D%$2553+@!!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U
M+@!!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!334(@9F%L:&]U+@!#86UP
M;W,@9&ES<&]N[79E:7,Z`$%Z97)B86EJXV\`1&5S8W5L<&%S(&1O($)/1D@`
M1G5N9&\`0V]R(&1E($9U;F1O`%-E;FAA(&ME<F)E<F]S(&EN8V]R<F5T82X`
M57-UX7)I;R!K97)B97)O<R!I;F-O<G)E=&\N`$)A:&%M87,`0F%H<F%I;@!"
MX6QT:6-O("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!.XV\@
M9F]I(&5N8V]N=')A9&\@;R!D:7)E=/-R:6\@8F%S92!D92!I;6%G96YS("<E
M<R<N`$QI;FAA(&1E(%!A<G1I9&$`4&5S<75I<V$@4VEM<&QE<P!"96QO<OIS
M<VEA`$+I;&=I8V$`0F5L:7IE`$)E;FEN`$)E<FUU9&%S`$)U=.-O`$%N:79E
M<G/A<FEO`$[C;R!F;VD@96YC;VYT<F%D;R!O(&)L;V-O("(E<R(@9&$@87!L
M:6-AY^-O("(E<R(N`$-O;F9I9W5R8>?U97,@9&\@0FQO8V\`5&EP;R!D92!"
M;&]C;P!.96=R:71O`$)O;.UV:6$`1F%V;W)I=&]S`$)O<F1A`$QA<F=U<F$@
M9&$@8F]R9&$Z`$)O<F1A<P!"\W-N:6$@92!(97)Z96=O=FEN80!!;6)O<P!"
M;W1S=6%N80!2;V1A<.D`26QH82!";W5V970`0G)A<VEL`%1E<G)I=/-R:6\@
M9&\@3V-E86YO(,UN9&EC;R!);F=LZG,`0G)U;F5I`$)U;&?A<FEA`$QI<W1A
M(&-O;2!-87)C861O<F5S`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$]C=7!A9&\`
M0TU3`$-20P!0;VYT;W,@9&4@1&ES=')I8G5IY^-O($-23`!?06=E;F1A`%!R
M;W!R:65D861E<R!D82!#Z5]L=6QA+BXN`$$@;&ES=&$@9&4@9&ES=')I8G5I
MY^-O(&[C;R!F;VD@97-P96-I9FEC861A+@!!9U]E;F1A`$%G96YD80!297-U
M;6\@9&$@06=E;F1A`$$@86=E;F1A(&9O:2!R96UO=FED82!C;VT@<W5C97-S
M;RX`06=E;F1A<P!!9V5N9&%S(&1E=F5M('!O<W-U:7(@=6T@;F]M92X`0V%L
M;6\`0V%M8F]D:F$`0V%M87+U97,`3N-O(.D@<&]S<^UV96P@9V5R87(@=6UA
M(&YO=F$@<V5N:&$@875T;VUA=&EC86UE;G1E+"!E;G1R92!E;2!C;VYT871O
M(&-O;2!O(&%D;6EN:7-T<F%D;W(N`$[C;R!C;VYS:6=O(&=R879A<B!O(&%R
M<75I=F\@(B5S(@!.XV\@Z2!P;W-S[79E;"!A9&UI;FES=')A<B!G97)E;F-I
M861O<F5S(&5X=&5R;F]S(&1E('-E<W/C;RX`3N-O(.D@<&]S<^UV96P@8V]N
M96-T87(@86\@<V5R=FED;W(@24U!4#H@)7,`3N-O(&-O;G-I9V\@8W)I87(@
M=6T@;F]V;R!E=F5N=&\N`$[C;R!C;VYS:6=O(&%B<FER(&\@87)Q=6EV;R`B
M)7,B+@!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@4F5L873S<FEO(&1E(%!R
M;V)L96UA`$-A;F-E;&%D;P!#86YC96QA9&\Z("5S`$[C;R#I('!O<W/M=F5L
M(&5X8VQU:7(@;R!A<G%U:79O("(E<R(N`$[C;R#I('!O<W/M=F5L(&5N8V]N
M=')A<B!U;2!D:7)E=/-R:6\@=&5M<&]RX7)I;RX`3N-O(.D@<&]S<^UV96P@
M8V]N=&EN=6%R('-E;2!O('!A<N)M971R;R`G=&%R9V5T1FEL92<N`$[C;R#I
M('!O<W/M=F5L(&5X8VQU:7(@;R!D:7)E=/-R:6\@(B5S(BX`3N-O(.D@<&]S
M<^UV96P@97AC;'5I<BP@)60@<&]S<W5I('-U8F]R9&EN861O<RX`3N-O(.D@
M<&]S<^UV96P@<F5O<F1E;F%R+"!N^FUE<F\@9&4@<F5G:7-T<F]S(&9O<FYE
M8VED;W,@<&%R82!R96]R9&5N87(@;N-O(&-O<G)E<W!O;F1E(&%O(&[Z;65R
M;R!A<FUA>F5N861O+@!.XV\@Z2!P;W-S[79E;"!R;W1E87(@;65N<V%G96T@
M<&%R82!O(&[Z;65R;R!E<W!E8VEF:6-A9&\N`$-A8F\@5F5R9&4`5.UT=6QO
M`$]P97)A9&]R80!#7V%T96=O<FEA`$-A=&5G;W)I87,@92!.;VUE<P!#871E
M9V]R:6$`26QH87,@0V%Y;6%N`%1E;&5F;VYE($-E;'5L87(`4')O<')I961A
M9&5S(&1A($/I;'5L80!-87)G96T@9&$@8^EL=6QA.@!0<F]P<FEE9&%D97,@
M9&$@0^EL=6QA`$5S<&'G86UE;G1O(&1A(&/I;'5L83H`5&5L969O;F4@8V5L
M=6QA<@!#Z6QT:6-O("A)4T\M.#@U.2TQ-"D`0V5N=')O`%)E</IB;&EC82!D
M82#!9G)I8V$@0V5N=')A;`!%=7)O<&$@0V5N=')A;"`H25-/+3@X-3DM,BD`
M1&5T86QH97,@9&\@0V5R=&EF:6-A9&\`4')O<')I973A<FEO(&1O($-E<G1I
M9FEC861O`%!O;.UT:6-A<R!D;R!#97)T:69I8V%D;P!48VAA9&4`06QT97)A
M<@!!;'1E<F4@4W5A(%-E;FAA`$%L=&5R87(@;R!N;VUE(&4@;R!E;F1E<F7G
M;R!Q=64@87,@<&5S<V]A<R!VZF5M('%U86YD;R!E;&%S(&SJ96T@92!R97-P
M;VYD96T@<W5A<R!M96YS86=E;G,N`$%L=&5R8>?C;R!D92!S96YH82!NXV\@
MZ2!S=7!O<G1A9&$@;F$@8V]N9FEG=7)AY^-O(&%T=6%L+B`@16YT<F4@96T@
M8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R+@!#:&%R`%9E<FEF:6-A<B!,
M:6Y?:RXN+@!#:&EL90!#:&EN80!#:&ENZG,@4VEM<&QI9FEC861O("A'0C(S
M,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2D`17-C;VQH82!A($%P;&EC
M8>?C;SH`17-C;VQH82!U;6$@<V5N:&$`17-C;VQH82!U;2!U<W7A<FEO`$5S
M8V]L:&$@8V]M;R!E>&EB:7(@9&%T87,Z`$5S8V]L:&$@<V4@=F]CZB!Q=65R
M('-E<B!N;W1I9FEC861O('!O<B!E+6UA:6P@<V]B<F4@979E;G1O<R!N;W9O
M<RP@961I=&%D;W,@92!E>&-L=>UD;W,Z`$5S8V]L:&$@<V4@=F]CZB!Q=65R
M('-E<B!N;W1I9FEC861O('-O8G)E(&5V96YT;W,@;F]V;W,L(&5D:71A9&]S
M(&4@97AC;'7M9&]S+@!%<V-O;&AA('-E('9O8^H@<75E<B!R96-E8F5R('!O
M<B!E+6UA:6P@;&5M8G)E=&5S(&1E(&5V96YT;W,@8V]M(&%V:7-O<SH`17-C
M;VQH82!O('1I<&\@9&4@97-T:6QO(&1E(&QI<W1A<R`H<&%R82!L:7-T87,@
M;W)D96YA9&%S*0!%<V-O;&AA(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S('!A
M<F$@<&5S<75I<V%R('!O<B!54DQS(&QI=G)E+V]C=7!A9&\Z`$5S8V]L:&$@
M82!A9V5N9&$@<75E('9O8^H@<75E<B!I;F-L=6ER(&5M('-U87,@;&ES=&%G
M96YS($QI=G)E+T]C=7!A9&\Z`$5S8V]L:&$@;R!C873A;&]G;R!D92!E;F1E
M<F7G;W,@<&%R82!P97-Q=6ES87(@<&]R(%523',@;&EV<F4O;V-U<&%D;SH`
M17-C;VQH82!A(&%G96YD82!P861RXV\N`$EL:&%S($-H<FES=&UA<P!.XV\@
M9F]I(&5N8V]N=')A9&$@82!D969I;FGGXV\@9&4@8VQA<W-E(&1E("5S+@!,
M:6UP87(`3&EM<&%R('1A9W,@35-/9F9I8V4`17AC;'5I<B!U<W7A<FEO`%)E
M;6]V97(@=&]D;W,@<&%R=&EC:7!A;G1E<P!%>&-L=6ER('5S=>%R:6\Z("5S
M`$5X8VQU:7(@=7-UX7)I;P!%>&-L=6ER(&1A9&]S(&1O('5S=>%R:6\`0^EU
M(&%B97)T;R!A(%1A<F1E`$-L:7%U92!P87)A($-O;G1I;G5A<@!#;&EC:V%T
M96QL('9I82!(5%10`$9E8VAA<B!*86YE;&$`3G5V96YS`$YU8FQA9&\@<&5L
M82!-86YHXP!.=6)L861O`$EL:&%S(&1E($-O8V]S`$-O;G1R86ER($)A<G)A
M($QA=&5R86P`0V]N=')A:7(@8F]R9&%S`$-O;/1M8FEA`$-O<@!086QH971A
M(&1E($-O<F5S`%-E;&7GXV\@9&4@0V]R`$-O;',Z`%3M='5L;W,@9&%S($-O
M;'5N87,`475A9')I;FAO<P!686QO<F5S('-E<&%R861O<R!P;W(@=NUR9W5L
M80!#;VUA;F1O`$QI;FAA(&1E($-O;6%N9&\`0V]M96YT87(`3F]M90!#;VUO
M<F]S`$5M<')E<V$`0V]M<'5T861O<F5S`$-O;F1IY^-O`$-O;F1IY_5E<P!$
M:69E<F5NYV%S(&1E($-O;F9I9W5R8>?C;P!#;VYF:6=U<F'GXV\@9&4@<VEN
M8W)O;FEZ8>?C;R!C;VT@4$1!<RP@4VUA<G1P:&]N97,@92!/=71L;V]K+@!#
M;VYF:6=U<F'GXV\@;F5C97-S:71A(&1E(&%T=6%L:7IAY^-O+@!#;VYF:6=U
M<F%R("5S`$-O;F9I<FUE(&$@4V5N:&$`0V]N9FER;6%R(&$@97AC;'5SXV\@
M9&4@979E;G1O<S\`0V]N9FER;6%D;P!#;VYG;P!#;VYG;RP@4F5P^F)L:6-A
M($1E;6]C<N%T:6-A(&1O`$9A;&AA(&YA(&-O;F5XXV\N`$9A;&AA(&YA(&-O
M;F5XXV\Z(`!#;VYE>.-O(')E8W5S861A('!E;&\@<V5R=FED;W(@9&4@8VAA
M=F5S('#Z8FQI8V%S+@!#;VYE>.-O(')E8W5S861A('!E;&\@<V5R=FED;W(@
M9&4@8VAA=F5S('#Z8FQI8V%S+B!-;W1I=F\Z("5S("@E<RD`02!C;VYE>.-O
M(&%O('-E<G9I9&]R($944"!F86QH;W4N`$-O;G1A=&]S`$]S(&-O;G1A=&]S
M(&9O<F%M(&%D:6-I;VYA9&]S(&-O;2!S=6-E<W-O(&%O('-E=2!C873A;&]G
M;R!D92!E;F1E<F7G;W,N`%1I<&4@9&4@8V]N=&7Z9&\@9&\@87)Q=6EV;R!C
M;VUP<FEM:61O.B``0V]N=&7Z9&\@9&4@)R5S)P!#;VYT:6YU87(`26QH87,@
M0V]O:P!#;V]K:64`0V]P:6%R`$9A;&AA(&YA(&/S<&EA.B`E<P!#;W!I87(@
M<V5L9>?C;P!#;W!I92!A(%523"!A8F%I>&\@<&%R82!U=&EL:7IA<B!O;F1E
M('9O8^H@;F5C97-S:71E(&1E('-U82!54DP@3&EV<F4O3V-U<&%D;SH`240@
M9&4@0W5S=&\`0V]S=&$@4FEC80!#;W-T82!D;R!-87)F:6T`26UP;W-S[79E
M;"!C<FEP=&]G<F%F87(@82!M96YS86=E;2!C;VT@4$=0.B``26UP;W-S[79E
M;"!A<W-I;F%R(&$@;65N<V%G96T@8V]M(%!'4#H@`$[C;R!F;VD@<&]S<^UV
M96P@8W)I<'1O9W)A9F%R(&$@;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O
M:2!P;W-S[79E;"!A<W-I;F%R(&$@;65N<V%G96T@8V]M(%,O34E-12X`3N-O
M(&9O:2!P;W-S[79E;"!A9&EC:6]N87(@8V]N=&%T;RX@)7,`3N-O(&9O:2!P
M;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O
M<W/M=F5L('9E<FEF:6-A<B!O('-A;&1O+B`E<P!);7!O<W/M=F5L(&-O;F5C
M=&%R(&%O('-E<G9I9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@8V]N96-T
M87(@86\@<V5R=FED;W(@)R5S)R!U=&EL:7IA;F1O($944#H@)7,`3N-O(&9O
M:2!P;W-S[79E;"!C<FEA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`
M26UP;W-S[79E;"!D97-C<FEP=&]G<F%F87(@;W,@9&%D;W,@4$=0.B``3N-O
M(&9O:2!P;W-S[79E;"!D97-C<FEP=&]G<F%F87(@;R!D861O(%,O34E-12X`
M3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER(&\@8V]N=&%T;RX@)7,`3N-O(&9O
M:2!P;W-S[79E;"!E>&-L=6ER(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E
M<P!.XV\@9F]I('!O<W/M=F5L(&5X8VQU:7(@;R!S8W)I<'0@9&4@871U86QI
M>F'GXV\@9&4@8V]N9FEG=7)AY^-O("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@
M9&5T97)M:6YA<B!O(&5N9&5R9>=O(&1E(&4M;6%I;"!D;R!D97-T:6YA=.%R
M:6\N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!O(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C
M;VUP;&5T86UE;G1E(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+@!.XV\@9F]I
M('!O<W/M=F5L(&]B=&5R(&-O;7!L971A;65N=&4@82!L:7-T82!D92!L:7-T
M87,@9&4@9&ES=')I8G5IY^-O+@!.XV\@9F]I('!O<W/M=F5L(&-A<G)E9V%R
M(&$@97-T<F%TZ6=I82`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&\@
M9&ER973S<FEO("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!C:&%V
M92!P^F)L:6-A(&$@<&%R=&ER(&1O('-E<G9I9&]R(&1E(&-H879E<RX`3N-O
M(&9O:2!P;W-S[79E;"!A8G)I<B`G)7,G('!A<F$@9W)A=F'GXV\N`$EM<&]S
M<^UV96P@86)R:7(@)7,N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!M\V1U
M;&\@)TUA:6YT96YA;F-E7U1A<VLG("5S`$[C;R!F;VD@<&]S<^UV96P@86)R
M:7(@;R!D:7)E=/-R:6\@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES
M87(@;F\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!L97(@)7,N
M`$[C;R!F;VD@<&]S<^UV96P@9V5R87(@=6UA(&YO=F$@<V5N:&$@<&%R82!O
M('5S=>%R:6\@<V]L:6-I=&%D;RX@06QG=6YS(&]U('1O9&]S(&]S(&1E=&%L
M:&5S(&[C;R!E<W3C;R!C;W)R971O<RX@5&5N=&4@;F]V86UE;G1E(&]U(&5N
M=')E(&5M(&-O;G1A=&\@8V]M(&\@861M:6YI<W1R861O<B!S92!V;V/J(&YE
M8V5S<VET82!D92!M86ES(&%J=61A+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R
M(&$@04-,`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@;R!C873A;&]G;R!D92!E
M;F1E<F7G;W,N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!L:7-T82!D
M92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@
M;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!O
M8G1E<B!A<R!C87!A8VED861E<R!D;R!S97)V:61O<@!.XV\@9F]I('!O<W/M
M=F5L(')E=F5R=&5R(&$@8V]N9FEG=7)AY^-O+@!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@;R!D:7)E=/-R:6\@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!S
M86QV87(@82!C;VYF:6=U<F'GXV\@)7,N`$[C;R!F;VD@<&]S<^UV96P@<V%L
M=F%R('5M(&)A8VMU<"!D82!C;VYF:6=U<F'GXV\N`$[C;R!F;VD@<&]S<^UV
M96P@<V%L=F%R('5M(&)A8VMU<"!D82!C;VYF:6=U<F'GXV\Z("5S`$[C;R!F
M;VD@<&]S<^UV96P@<V%L=F%R(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E
M(&-O;F9I9W5R8>?C;R!E;3H@)R5S)RX`3N-O(&-O;G-E9W5I('-A;'9A<B!O
M(&)A8VMU<"!D;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX`3N-O(&-O
M;G-E9W5I('-A;'9A<B!O(&%R<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+B!6
M;V/J('!O9&4@;W4@=71I;&EZ87(@=6UA(&1A<R!O<.?U97,@<&%R82!S86QV
M87(@;R!C\V1I9V\@9&4@=F]L=&$@96T@)7,@;W4@8V]P:6%R(&UA;G5A;&UE
M;G1E(&\@8_-D:6=O(&%B86EX;R!P87)A("5S+@!.XV\@9F]I('!O<W/M=F5L
M('!E<W%U:7-A<B!N;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@;R!L:6YK("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@871U86QI
M>F%R(&\@8V]N=&%T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!A='5A;&EZ87(@
M82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@
M9W)A=F%R(&$@8V]N9FEG=7)AY^-O(&1E("<E<R<Z("5S`$[C;R!F;VD@<&]S
M<^UV96P@96YC;VYT<F%R(&$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA+B!#
M97)T:69I<75E+7-E('%U92!E;&$@97-TX2!A8F5R=&$N`$[C;R!F;VD@<&]S
M<^UV96P@9&%R(&%O('5S=>%R:6\@)7,@;W,@<V5G=6EN=&5S(&1I<F5I=&]S
M('!A<F$@82!P87-T82`G)7,G.B`E<P!497AT;R!C;VYT861O`%!A[7,`0W5R
M<V]S`$-R:6%R`$-R:6%R($%G96YD80!#<FEA<B!.;W9O($5V96YT;P!#<FEA
M<B!U;2!L:6YK`$-R:6%R('5M82!N;W9A`$-R:6%R('-U8B!P87-T87,`0W)I
M861O`%!E<FUI<W/U97,@9&\@8W)I861O<@!.^FUE<F\@9&\@8V%R=.-O(&1E
M(&-RZ61I=&\`0W)OX6-I80!#=6)A`$%T=6%L`#0@1F%S97,@071U86ES`%-E
M<W/U97,@071U86ES`$AO<F$@071U86P`02!54DP@871U86P@Z0!5<W7A<FEO
M<R!N;R!M;VUE;G1O`$-L:6UA($%T=6%L`$-O;F1IY^-O(&%T=6%L.B``17-T
M:6QO(&%T=6%L`$-U<W1O;6EZ82!T87)E9F%S(&$@<V5R96T@97AE8W5T861A
M<R!A;R!C;VYE8W1A<B!A("5S+@!#;W)T87(`0V]R=&%R('-E;&7GXV\`0VAI
M<')E`$-I<NUL:6-O("A+3TDX+5(I`$-I<NUL:6-O("A7:6YD;W=S+3$R-3$I
M`$-I<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5*0!297#Z8FQI8V$@5&-H96-A
M`$1$`$133B`H=F5J82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1I87)I86UE;G1E
M`$1IX7)I;SH@4F5P971E(&$@8V%D80!.879E9V%D;W(@9&4@1&%T851R964`
M4&5S<75I<V$@;F\@0F%N8V\@9&4@1&%D;W,`1&%T80!$871A(&1E(%)E8V5B
M:6UE;G1O`%-E;&7GXV\@9&4@9&%T80!$:6$`1&EA*',I`$5X8U]L=6ER`$5?
M>&-L=6ER($-O;'5N80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E8W5S
M861O`%)E8W5A<B!)9&5N=&'GXV\`4&%D<N-O`$%G96YD82!0861RXV\`0V]R
M(%!A9'+C;P!)9&5N=&ED861E(%!A9'+C;P!3:&5L;"!0861RXV\`1&5F:6YI
MY_5E<P!%>&-L=6ER`$5X8VQU:7(@)7,`17AC;'5I<B!CZ6QU;&$`17AC;'5I
M<B!%=F5N=&\`17AC;'5I<B!'<G5P;P!%>&-L=6ER($QO9P!%>&-L=6ER(%!E
M<FUI<W/C;P!%>&-L=6ER(&4@<'5R9V%R(&UE;G-A9V5N<P!%>&-L=6ER(&/I
M;'5L80!%>&-L=6ER(&-O;'5N80!%>&-L=6ER(&UO9&5L;R!S=6)S=&ET=71O
M(&5X:7-T96YT90!%>&-L=6ER('!E<FUI<W/U97,@<&%R82`G)7,G`$5X8VQU
M:7(@<&5R;6ES<_5E<R!P87)A("<E<R<@92!Q=6%L<75E<B!O=71R82!S=6(M
M<&5R;6ES<^-O/P!%>&-L=6ER(&QI;FAA`$5X8VQU:7(@:61E;G1I9&%D92!S
M96QE8VEO;F%D80!%>&-L=6ER(&$@8V]L=6YA(&%T=6%L`$5X8VQU:7(@<V]M
M96YT92!O(&5V96YT;R!A='5A;"P@97-T82!O8V]R<NIN8VEA(&4@=&]D87,@
M9G5T=7)A<R!O8V]R<NIN8VEA<R!O=2!T;V1A<R!O8V]R<NIN8VEA<S\`17AC
M;'5I<B!A(&QI;FAA(&%T=6%L`%-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C
M;VYF:6=U<F'GXV\@)R5S)R!E>&-L=>UD;RX`2&]R82!D92!E;G1R96=A`$1I
M;F%M87)C80!$95]S8W)IY^-O`$1E<V-R979A(&\@<')O8FQE;6$`1&5S8W)I
MY^-O`$1E=&%L:&5S("AT86UBZ6T@;F\@<F5G:7-T<F\@9&4@871I=FED861E
M<R!D;R!(;W)D92DZ`$]S(&1E=&%L:&5S(&9O<F%M(&=R879A9&]S(&5M(&QO
M9R!P87)A(&\@861M:6YI<W1R861O<BX`1&5S96YV;VQV:6UE;G1O`%!O;G1O
M(&1E($]R=F%L:&\`4&]N=&\@9&4@3W)V86QH;R!P87)A(&$@^FQT:6UA(&AO
M<F$Z(`!0;VYT;R!D92!/<G9A;&AO.B``1&ER9>?C;R!D82!E<W%U97)D82!P
M87)A(&1I<F5I=&$`1&ER9>?C;R!D82!D:7)E:71A('!A<F$@97-Q=65R9&$`
M1&ER973S<FEO`$5X:6)I<@!%>&EB:7(@96T@9F]R;6%T;R`R-"!H;W)A<S\`
M17AI8FER($%G96YD87,`3W#G]65S(&1E($5X:6)IY^-O`$5X:6)I<B!P<F5V
M:7/C;R!D971A;&AA9&$`17AI8FER('!R979I<^-O("A4048I`$5X:6)I<B!F
M;W)M871O`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.XV\@
M97AC;'5I<@!.XV\@86-E<W-E(&1I<F5T86UE;G1E(&UA:6YT96YA;F-E+G!H
M<`!6;V/J('%U97(@97AI8FER('1A<F5F87,@96YC97)R861A<R!E;2!S=6$@
M86=E;F1A/P!.XV\@<F5P971E`$$@<')I;65I<F$@;&EN:&$@8V]N=.EM(&]S
M(&YO;65S(&1O<R!C86UP;W,_(%-E('-I;2P@8VQI<75E(&YE<W1A(&-A:7AA
M.@!$;VUI;FEC86YA`%)E</IB;&EC82!$;VUI;FEC86YA`$[C;R!T96T@=6UA
M(&-O;G1A/R!#861A<W1R92US92X`0F%I>&%R`$)A:7AA<B`E<P!"86EX87(@
M82!C;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@<V-R:7!T(%!(4"X`3&ES
M=&$@9&4@<V5L9>?C;P!$<F]G87,`5F5N8VEM96YT;SH@)7,`1'5R8>?C;P!#
M;W)R96EO`$-O;F5C=&]R(&1O(&=A=&5W87D@14UA:6PM<&%R82U335,L('!A
M<F$@;W!E<F%D;W)A<R!Q=64@9&ES<&]N:6)I;&EZ86T@97-T92!S97)V:>=O
M+@!%4E(`17%U861O<@!%9&ET87(`161I=&%R("5S`$5D:71A<B!087)T:6-I
M<&%N=&5S`$5D:71A<B!";&]C;P!%9&ET87(@06=E;F1A<P!%9&ET87(@1W)U
M<&\`161I=&%R(%!E<FUI<W/C;P!%9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@
M4&5R;6ES<_5E<R!P87)A("5S`$5D:71A<B!!9V5N9&%S(%)E;6]T87,`161I
M=&%R('!A<G1I8VEP86YT97,`161I=&%R(&-A=&5G;W)I87,@92!C;W)E<P!%
M9&ET87(@;W#G]65S(&1E.@!%9&ET87(@<&5R;6ES<_5E<R!P87)A("5S`$5D
M:71A<B!P97)M:7-S]65S('!A<F$@)7,`161U8V'GXV\`16=I=&\`16P@4V%L
M=F%D;W(`16QE;65N=&\N+BX`16T`12UM86EL`$5N9&5R9>=O(&1E($4M36%I
M;`!/(&5N9&5R9>=O(&1E(&4M;6%I;"!D979E(&-O<G)E<W!O;F1E<BX`365N
M<V%G96T@8V]M(&-O;F9I<FUAY^-O`$=A=&5W87D@9&4@14UA:6PM<&%R82U3
M35,`16UO=&EC;VYS`$UE;G-A9V5M(&5M(&)R86YC;RX`4F5S=6QT861O(&5M
M(&)R86YC;RX`5&5R;6]S(&1E('!E<W%U:7-A(&5M(&)R86YC;P!!8V%B82!%
M;0!(86)I;&ET87(@:6YS97+GXV\@9&4@:6UA9V5N<R!A('!A<G1I<B!D82!'
M86QE<FEA(&1E($EM86=E;G,@;F\@=&5X=&\_`$AA8FEL:71A<B!M96YU(&1E
M(&-O;G1E>'1O(&-O;2!O(&)O=.-O(&1I<F5I=&\_`$1A=&$@1FEN86P`06-A
M8F$@16T`2&]RX7)I;R!&:6YA;`!&:6YA;"!D;R!A;F\`075M96YT87(@161I
M=&]R`$9O<FYEYV$@=6UA('!E<F=U;G1A(&1E('-E9W5R86[G82!A('%U86P@
M=F]CZB!S97+A('!E<F=U;G1A9&\@<V4@=F]CZB!N96-E<W-I=&%R(&=E<F%R
M('5M82!N;W9A('-E;FAA+"!E>"X@)W%U86P@;R!N;VUE(&1O('-E=2!C86-H
M;W)R;S\G.@!&;W)N9>=A(&$@55),(&1A(&EM86=E;2!A<75I`$1I9VET92!A
M<R!L971R87,@86)A:7AO.@!'=6ENZ2!%<75A=&]R:6%L`$5R:71RZ6EA`$5R
M<F\`17)R;R!A;R!C<FEA<B!B;&]C;SH@)7,`17)R;R!A;R!E>&-L=6ER(.)N
M8V]R82!D92!S:6YC<F]N:7IAY^-O.B`E<P!%<G)O(&%O(&5X8VQU:7(@;&]G
M(&1E('-I;F-R;VYI>F'GXV\Z("5S`$5R<F\@86\@;V)T97(@8V]N=&7Z9&\Z
M("5S`$5R<F\@86\@;V)T97(@:6YF;W)M8>?C;R!L:79R92]O8W5P861O(&1E
M("5S.B`E<P!%<G)O(&%O(&%T=6%L:7IA<B!A('-E;FAA.B`E<P!%<G)O(&YA
M(&UE;G-A9V5M+@!%<G)O(&=R879A;F1O("<E<R<N`$5S=/1N:6$`171I\W!I
M80#)=&YI8V\`175R;W!A`$5V96YT;R!A9&EC:6]N861O.@!%=F5N=&\@97AC
M;'7M9&\Z`$5V96YT;R!E9&ET861O.@!%=F5N=&\@9&4@)7,@<&%R82`E<P!%
M=F5N=&]S(&1E=F5M('!O<W-U:7(@=6UA(&1A=&$@9&4@:6[M8VEO+@!%=F5N
M=&]S(&1E=F5M('!O<W-U:7(@=6T@=.UT=6QO+@!#861A(#$U(&UI;G5T;W,`
M0V%D82`R(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@;6EN=71O
M<P!#861A($-O;F5XXV\`0V%D82!M96EA(&AO<F$`0V%D82!M:6YU=&\`5F%L
M;W)E<R!D92!E>&5M<&QO.@!%>&5C=71A<@!%>'!A;F1I<@!%>'!A;F1I<B!.
M;VUE<P!%>'!A;F1I<B!"87)R82!,871E<F%L`$5S<&5R861O("<I)P!%<W!E
M<F%D;R!U;6$@<&%L879R82!O=2!T97)M;R!D92!P97-Q=6ES82!E;G1R92!A
M<W!A<P!$871A(&1E($5X<&ER8>?C;P!%>'!O96YT90!%>'!O<G1A<@!%>'!O
M<G1A<B!!9V5N9&$`0V]R(&1O('!R:6UE:7)O('!L86YO`$-O;F9I9W5R8>?C
M;R!D92!E;G9I;R!D92!A<G%U:79O<R!&5%``1F%L:&$@;V)T96YD;R!P<F5F
M97+J;F-I87,N`$9A;&AA(&%O(&-O;F5C=&%R(&%O('-E<G9I9&]R($Q$05`N
M`$9A;&AA(&%O(&-O;F5C=&%R(&%O('-E<G9I9&]R(%--0BX`1F%L:&$@86\@
M8V]P:6%R(&1E("(E<R(N`$9A;&AA(&%O(&-O<&EA<B!P87)A("(E<R(N`$9A
M;&AA(&%O(&-R:6%R('5M82!N;W9A(&-O;F5XXV\@4T%33"X`1F%L:&$@86\@
M;6]V97(@<&%R82`B)7,B+@!&86QH82!A;R!O8G1E<CH@)7,`2G5S=&\`26QH
M87,@1F%L:VQA;F0@*$UA;'9I;F%S*0!);&AA<R!&87)O90!%<G)O($9A=&%L
M.@!&87@`1F%X97,`1F5V97)E:7)O`%-E;G-AY^-O(%3I<FUI8V$`4V5N<V'G
MXV\@=.ER;6EC83H@`%!A;F-A9&%S(&1E($-H=79A`$YE=F4@1G)A8V$`36%T
M<FEZ(&1O(&-A;7!O`$9I9VQE="!#05!40TA!`$9O;G1E($9I9VQE=`!&:6II
M`&%R<75I=F\`0V]N=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\`0V]N
M=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F]S`$=E<F5N8VEA9&]R(&1E
M($%R<75I=F]S`$YO;64@9&\@07)Q=6EV;P!396QEY^-O(&1E(&%R<75I=F\`
M16YV:6\@9&4@87)Q=6EV;P!%;G9I;R!D92!A<G%U:79O<R!NXV\@Z2!S=7!O
M<G1A9&\N`$9I;'1R;W,`16YC;VYT<F%R`$9I;FSB;F1I80!0<FEM96ER82!-
M971A9&4`4')I;65I<F\@475A<G1O`%1A>&$@9FEX80!':7)A<@!$:7-P;W-I
MY^-O`$[I=F]A`%!A<W1A("5S(&[C;R!E>&ES=&4`0V]R(&1A($9O;G1E`$-O
M;6ED80!087)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P;W)T86T@:6UA9V5N
M<P!0<F5V:7/C;R`H5$%&*0!$:6%S(%!R979I<W1O<R`H3F]T92!Q=64@82!P
M<F5V:7/C;R!R971O<FYA9&$@97AI8F4@86UB;W,@9&EA(&4@;F]I=&4[('5M
M(&[Z;65R;R!M=6ET;R!A;'1O(&%Q=6D@<&]D92!R97-U;'1A<B!E;2!U;2!B
M;&]C;R!E>'1E;G-O*0!%<W%U96-E=2!A('-E;FAA/P!&;W)M=6SA<FEO<P!3
M;W)T90!4:7!O(&1E(%-O<G1E`%-O<G1E<P!3;W)T97,@,@!&\W)U;G,`4F5D
M:7)E8VEO;F%M96YT;W,`4V5X`%%U861R;W,`1G)A;N=A`$9R86[G82!-971R
M;W!O;&ET86YA`$QI=G)E`$EN9F]R;6'GXV\@3&EV<F4O3V-U<&%D;P!'=6EA
M;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A`%1E<G)I=/-R:6]S($9R
M86YC97-E<R!D;R!3=6P`4V5X=&$M1F5I<F$`1&4`1&\H82D`1&5S8W)IY^-O
M($-O;7!L971A`$QU82!#:&5I80!.;VUE($-O;7!L971O`$9U='5R;P!'86+C
M;P!'86QE<FEA(&1E(&]N9&4@;V)T97(@87,@:6UA9V5N<P!'86QE<FEA.@!'
MXFUB:6$`2F]G;P!'97)A;`!'97)A<B!A($-O;F9I9W5R8>?C;R!D92`E<P!#
M\V1I9V\@1V5R861O`$=E\W)G:6$`06QE;6%N:&$`1V%N80!':6)R86QT87(`
M4')I;65I<F\@3F]M90!/<.?U97,@1VQO8F%I<P!)<@!';V5D96P`1V]O9VQE
M($UA<&%S`%!E<W%U:7-A<B!N;R!';V]G;&4`27(@4&%R82`E<P!%<V-A;&$@
M9&4@0VEN>F%S`$=RZ6-I80!'<F5G;R`H25-/+3@X-3DM-RD`1W)O96SB;F1I
M80!'<F%N861A`$%D;6EN:7-T<F'GXV\@9&4@1W)U<&]S`$YO;65S(&1E(&=R
M=7!O<R!NXV\@9&5V96T@97-T87(@96T@8G)A;F-O`$=R;W5P7VQD87`Z($EM
M<&]S<^UV96P@861I8VEO;F%R(&=R=7!O("5S+B!)<W1O(.D@;R!Q=64@;R!S
M97)V:61O<B!D:7-S93H@`$=R;W5P7VQD87`Z($EM<&]S<^UV96P@97AC;'5I
M<B!G<G5P;R`E<P!'<F]U<%]L9&%P.B!);7!O<W/M=F5L(&%T=6%L:7IA<B!G
M<G5P;R`E<P!'<G5P;W,`1W5A9&%L=7!E`$=U86T`1W5A=&5L86UA`$=U97)N
M<V5Y`%!E<FUI<W/U97,@9&4@0V]N=FED861O`$QI=G)O(&1E(%9I<VET87,`
M1W5I;ND`1W5I;NDM0FES<V%U`$=U:6%N80!(5$U,`$A434Q!<F5A('-E(&YE
M9V$@8V]V87)D96UE;G1E(&$@97AC;'5I<B!A(/IL=&EM82!CZ6QU;&$@9&$@
M;&EN:&$N`$A434Q!<F5A('-E(&YE9V$@8V]V87)D96UE;G1E(&$@97AC;'5I
M<B!A(/IL=&EM82!C;VQU;F$@9&$@=&%B96QA+@!(5$U,07)E82!S92!N96=A
M(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@;&EN:&$@9&$@=&%B
M96QA+@!!=71E;G1I8V'GXV\@2%144"!NXV\@96YC;VYT<F%D82X`2&%I=&D`
M06QG;W)I=&UO($AA<V@`3F5B;&EN80!#86)EYV%L:&\`0V%B9>=A;&AO`$EL
M:&$@2&5A<F0@92!);&AA<R!-8T1O;F%L9`!496UP97-T861E($9O<G1E`$AE
M8G)E=2`H25-/+3@X-3DM."U)*0!!;'1U<F$`06IU9&$`06IU9&$@9&\@961I
M=&]R`$%S<VES=&5N=&4`2&5M:7-FZ7)I;P!!<75I(&5S=.$@;R!I;NUC:6\@
M9&\@87)Q=6EV;SH`3V-U;'1A<@!,96UB<F5T93H@)7,`06QT80!)7V[M8VEO
M`%-A;G1A(%/I("A#:61A9&4M17-T861O(&1O(%9A=&EC86YO*0!);NUC:6\`
M16YD97)EYV\@4F5S:61E;F-I86P`1&ER973S<FEO(%!E<W-O86P`1F]N92!2
M97-I9&5N8VEA;`!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z($1A9&\@6$U,("5S(&EN=N%L:61O(&5N8V]N=')A9&\@;F$@;65N<V%G
M96T@)7,`2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G96T@8V]R<F5S<&]N
M9&4@86\@;V)J971O("5S`$AO<F1E+TMO;&%B.B!.96YH=6T@;V)J971O(&1O
M('1I<&\@)7,@9F]I(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,`2&]R9&4O
M2V]L86(Z(%)E;6]V:61O(&-O;2!S=6-E<W-O("5S("(E<R(`2&]R9&4O2V]L
M86(Z($$@96YG:6YE(&1E(&EN=&5G<F'GXV\@<F5Q=65R(&$@97AT96YSXV\@
M4$A0("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L(&-R:6%R('5M
M82!N;W9A(.%R=F]R92!834P@<&%R82!O(&]B:F5T;R`E<P!(;W)D92]+;VQA
M8CH@26UP;W-S[79E;"!R96UO=F5R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!);7!O<W/M=F5L(&]B=&5R(&$@:61E;G1I9FEC8>?C;R!-24U%('!A<F$@
M82!P87)T92!D;R!T:7!O("5S`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L('-I
M;F-R;VYI>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L
M('-I;F-R;VYI>F%R(&-O;7!A<G1I;&AA;65N=&]S.B`E<P!(;W)D92]+;VQA
M8CH@0V]M<&%R=&EL:&%M96YT;R!D97-C;VYH96-I9&\@(B5S(@!,:6YH82!(
M;W)I>F]N=&%L`$UA<F=E;2!H;W)I>F]N=&%L`$AO<FEZ;VYT86PZ`$AO<F$H
M<RD`0V]M;R!V;V/J(&-H96=O=2!A<75I/R`H4&]R(&9A=F]R(&-O;75N:7%U
M92$I`%%U86P@9&5V92!S97(@;R!I;G1E<G9A;&\@9&4@=&5M<&\@82!S97(@
M97AI8FED;R!N87,@=FES=6%L:7IAY_5E<R!D92!D:6$@92!S96UA;F$_`%%U
M86YT87,@8V]L=6YA<R!V;V/J(&=O<W1A<FEA(&1E(&UE<V-L87(_`$%S(&EN
M9F]R;6'G]65S(&QI=G)E+V]C=7!A9&\@9&5V92!S97(@9V5R861A(&-O;2!Q
M=6%N=&]S(&1I87,_`%%U86YT;W,@8V%M<&]S("AC;VQU;F%S*2!E>&ES=&5M
M/P!1=6%N=&%S(&QI;FAA<R!V;V/J(&=O<W1A<FEA(&1E(&UE<V-L87(_`%5M
M:61A9&4`56UI9&%D93H@`$AU;6]R:7-T87,`2'5N9W+M80!&86QH82!A;R!C
M<FEA<B!C86EX82!P;W-T86P@24U!4#H@)7,`1F%L:&$@86\@97AC;'5I<B!C
M86EX82!P;W-T86P@24U!4#H@)7,`1F%L:&$@86\@8W)I87(@<75O=&$@9&$@
M8V%I>&$@<&]S=&%L($E-05`Z("5S`$5N9&5R9>=O($E0`$5N9&5R9>=O($E0
M(&[C;R!D:7-P;V[M=F5L+@!%;F1E<F7G;R!)4"!NXV\@97-TX2!N;R!B;&]C
M;R!P97)M:71I9&\@0TE$4BX`5FEO;&'GXV\@9&\@8FQO<75E:6\@25`N`$E?
M;G-I<F$@3&EN:&$@06YT97,`27-LXFYD:6$`4V]M96YT92#-8V]N97,`S6-O
M;F5S('!A<F$@)7,`S6-O;F5S(&4@=&5X=&\`3F]M92!D82!I9&5N=&ED861E
M.@!392!NXV\@9F]R(&5X:6)I9&\@8V]R<F5T86UE;G1E+"`E<R!P87)A(&%B
M<NTM;&\@96T@=6UA(&YO=F$@:F%N96QA+@!392!V;V/J(&[C;R!VZB!N96YH
M=6T@[6-O;F4@86\@=71I;&EZ87(@;R!);G1E<FYE="!%>'!L;W)E<BP@=F]C
MZB!P;V1E(&-H96-A<B!E<W1A(&-A:7AA('!A<F$@9&5S86)I;&ET87(@82!T
M<F%N<W!A<NIN8VEA(%!.1RX`4V4@=F]CZB!VZB!E<W1A(&UE;G-A9V5M(&UA
M<R!NXV\@82!I;6%G96TL(&$@:6UA9V5M('%U92!V;V/J('%U97(@96YV:6%R
M(&[C;R!P;V1E('-E<B!E>&EB:61A('!E;&\@<V5U(&YA=F5G861O<BX`4V4@
M<V5U(&-L:65N=&4@9&4@92UM86EL(&[C;R!S=7!O<G1A('-O;&EC:71AY_5E
M<R!I5&EP('9O8^H@<&]D92!U<V%R('5M(&1O<R!S96=U:6YT97,@;&EN:W,@
M<&%R82!A8V5I=&%R(&]U(')E8W5S87(@;R!E=F5N=&\N"@I087)A(&%C96ET
M87(@;R!E=F5N=&\Z"B5S"@I087)A(&%C96ET87(@=&5M<&]R87)I86UE;G1E
M(&\@979E;G1O.@HE<PH*4&%R82!R96-U<V%R(&\@979E;G1O.@HE<P!0<NDM
M=FES=6%L:7IAY^-O(&1A($EM86=E;3H`55),(&1A($EM86=E;0!54DP@9&$@
M26UA9V5M.@!);6%G96T@9&$@9V%L97)I80!);6%G96T@9&$@9V%L97)I83H`
M16YV:6\@9&4@26UA9V5M`$EM86=E;G,`26UP;W)T87(@06=E;F1A+"!087-S
M;R`E9`!);7!O<G1A<BP@4&%S<V\@)60`26UP;W)T87(O17AP;W)T87(@06=E
M;F1A`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R=&%D;W,Z`$EN
M7W-E<FER($QI;FAA($%P\W,`0_-D:6=O(&1E(&'GXV\@9F]R;F5C:61O(&5S
M=.$@:6YC;W)R971O+@!5<W7A<FEO(&4O;W4@<V5N:&$@:6YC;W)R971O<RX`
M57-UX7)I;R!O=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!I;F-O<G)E=&]S+B!4
M96YT92!N;W9A;65N=&4@;W4@96YT<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI
M;FES=')A9&]R('-E('9O8^H@;F5C97-S:71A(&1E(&UA:7,@86IU9&$N`$%U
M;65N=&%R($ED96YT8>?C;P#-;F1I80!5<W7A<FEO<R!I;F1I=FED=6%I<P!)
M;F1O;NES:6$`26YF;W)M8>?C;P!);F9O<FUAY^-O`$[C;R!E>&ES=&5M(&]P
MY_5E<R!D:7-P;V[M=F5I<RX`26YS97)I<B!#7V]L=6YA($%P\W,`26YS97)I
M<B!);6%G96T`26YS97)I<B!486)E;&$`26YS97)I<B!,:6YK(&1A(%=E8@!)
M;G-E<FER(%]#;VQU;F$@06YT97,`26YS97)I<B!U;6$@;F]V82!C;VQU;F$@
M87#S<R!A(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@8V]L=6YA(&%N=&5S(&1A
M(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@;&EN:&$@87#S<R!A(&%T=6%L`$EN
M<V5R:7(@=6UA(&YO=F$@;&EN:&$@86YT97,@9&$@871U86P`26YS97)I<B!U
M;2!P87+A9W)A9F\@87#S<R!O(&%T=6%L`$EN<V5R:7(@=6T@<&%RX6=R869O
M(&%N=&5S(&1O(&%T=6%L`$EN<V5R:7(@=6T@;6]D96QO(&%L=&5R;F%T:79O
M`$9O<FYEYV$@=6T@96YD97)EYV\@9&4@92UM86EL(&YO('%U86P@=F]CZB!P
M;V1E(')E8V5B97(@82!N;W9A('-E;FAA.@!);G-E<FER(&/I;'5L82!A</-S
M`$EN<V5R:7(@8^EL=6QA(&%N=&5S`$EN<V5R:7(@8V]L=6YA(&%P\W,`26YS
M97)I<B!C;VQU;F$@86YT97,`26YS97)I<B!M96YS86=E;G,`26YS97)I<B!P
M87+A9W)A9F\@87#S<P!);G-E<FER('!A<N%G<F%F;R!A;G1E<P!);G-E<FER
M(&QI;FAA(&%P\W,`26YS97)I<B!L:6YH82!A;G1E<P!&;W)N9>=A(&$@<F5S
M<&]S=&$@;V)R:6=A=/-R:6$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R86[G
M83H`26YS97)I<B]!;'1E<F%R($EM86=E;0!);G-E<FER+T%L=&5R87(@3&EN
M:P!#<NED:71O(&EN<W5F:6-I96YT92!P87)A(&5N=FEA<B!P87)A(&$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O+@!#<NED:71O(&EN<W5F:6-I96YT92X`3OIM
M97)O($EN=&5I<F\`3&ES=&$@9&4@26YT96ER;W,`0T15("A#86)EYV%L:&\@
M9&4@1&%D;W,@9&4@57-UX7)I;RD@:6YVX6QI9&\N`$1A9&]S(%I)4"!I;G;A
M;&ED;W,`07!L:6-AY^-O(&EN=N%L:61A+@!)9&5N=&EF:6-AY^-O(&1O(&)A
M=&-H(&EN=N%L:61A+@!$861O<R!E;G9I861O<R!SXV\@:6YVX6QI9&]S+@!%
M;F1E<F7G;R!D92!D97-T:6YO(.D@:6YVX6QI9&\N`$9O<FUA=&\@9&\@87)Q
M=6EV;R#I(&EN=N%L:61O`$[Z;65R;R!D92!L:6-E;N=A(&EN=N%L:61O+@!,
M;V-A;&EZ8>?C;R!F;W)N96-I9&$@Z2!I;G;A;&ED82X`5&EP;R!D82!M96YS
M86=E;2#I(&EN=N%L:61O+@!!<&E?:60@Z2!I;G;A;&ED;R!O=2!E<W3A(&9A
M;'1A;F1O+@!087+B;65T<F]S(&EN=N%L:61O<R!O=2!F86QT86YD;RX`4&5R
M;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L:61A<RX`4&5R;6ES<_5E<R!D;R!P
M86D@<^-O(&EN=N%L:61A<RX`0_-D:6=O(&1O('!R;V1U=&\@Z2!I;G;A;&ED
M;RX`4')O=&]C;VQO(&EN=N%L:61O+@!$97-T:6YA=.%R:6\@:6YVX6QI9&\Z
M("<E<R<`3V)J971O(&-O;7!A<G1I;&AA9&\@:6YVX6QI9&\`1F]N=&4@9&\@
M96YD97)EYV\@:6YVX6QI9&$N`$1A9&]S('5N:6-O9&4@:6YVX6QI9&]S+@!)
M;G9E;G3A<FEO`$EN=F5R=&5R('-E;&7GXV\`27+C+"!297#Z8FQI8V$@27-L
MXFUI8V$@9&\`27)A<75E`$ER;&%N9&$`26QH82!D;R!(;VUE;0!496UP97-T
M861E<R!)<V]L861A<P!)<W)A96P`16UI<W-O<@!)=.%L:6-O`$ETX6QI80!*
M86UA:6-A`$IA;F5I<F\`2F%PXV\`2F%P;V[J<R`H25-/+3(P,C(M2E`I`$IE
M<G-E>0!*;W)DXFYI80!*=6QH;P!*=6YH;P!*=7-T:69I8V%R`$%L:6YH87(@
M86\@0V5N=')O`$IU<W1I9FEC87(`06QI;FAA<B#@($5S<75E<F1A`$%L:6YH
M87(@X"!$:7)E:71A`$-A>F%Q=6ES=.-O`$UA;G1E<B!O(&]R:6=I;F%L/P!1
M=>IN:6$`4V5R=FED;W(@:V5R8F5R;W,@<F5J96ET;W4@82!A=71E;G1I8V'G
MXV\N`$YO=F%T;W,@9&4@2V5R;F5L`$-R:6'GXV\@9&4@0VAA=F4`26UP<F5S
M<^-O($1I9VET86P@9&$@0VAA=F4`5&%M86YH;R!D82!#:&%V90!4:7!O(&1A
M($-H879E`%5S;R!D82!#:&%V90!#:&%V92!JX2!E>&ES=&4@;F\@<V5R=FED
M;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!086QA=G)A<RUC:&%V90!#<FEA;N=A
M<P!+:7)I8F%T:0!#;W+I:6$L(%)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T
M:6-A(&1A`$-O<NEI82P@4F5P^F)L:6-A(&1A`$-O<F5A;F\@*$550RU+4BD`
M2W5W86ET`%%U:7)G=6ES=.-O`$QA7WEO=70`261I;VUA`$QA;R!297#Z8FQI
M8V$@1&5M;V-RX71I8V$@4&]P=6QA<@#:;'1I;6%S(#(T(&AO<F%S`-IL=&EM
M82!-971A9&4`VFQT:6UA($UO9&EF:6-AY^-O`-IL=&EM;R!-ZG,`1V5R87(@
M3F]V82!396YH80#:;'1I;6\@475A<G1O`-IL=&EM82!!='5A;&EZ8>?C;SH`
MVFQT:6UO($%N;P#:;'1I;6\@;&]G:6XZ("5S`-IL=&EM;R!L;V=I;CH@)7,@
MX"!P87)T:7(@9&4@)7,`VFQT:6UO(&QO9VEN.B!.=6YC80#:;'1I;6$@<V5M
M86YA`$QE=/1N:6$`3&5I`$QA>6]U=`!$96EX82!V87II;R!S92!Q=6ES97(@
M<V5M(&)O<F1A`$SM8F%N;P!%<W%U97)D80!#86)EYV%L:&\@97-Q=65R9&\`
M5F%L;W)E<R!D82!E<W%U97)D80!,97-O=&\`06UO<@!,:6+I<FEA`$SM8FEA
M(,%R86)E($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!#:&EV:7-C;T9R86-O
M`$-H=79A($9R86-A`$-H=79A($9R86-A($UA='5T:6YA`$-H=79A($9R86-A
M(%9E<W!E<G1I;F$`3&5V97,@4&%N8V%D87,@9&4@0VAU=F$`0VAU=F%S($9R
M86-A<R!C;VT@5')O=O5E<P!.979E($9R86-A`$)R979E($YE=F%S8V$`4&_J
M;6%S`$QI;6ET87(@;R!I;G1E<G9A;&\@9&4@=&5M<&\@<&%R82!E>'!O<G1A
M<CH`3&EN:P!,:6YK(&%P;VYT82!P87)A.@!,:6=A<B!O(&5N9&5R9>=O(&1E
M(&4M;6%I;"#@('#A9VEN82!D92!C;VUP;W-IY^-O(&%O(&5X:6)I<@!,:6YK
M<P!#;V]K:64@9&\@3&EN=7@`3&ES=&%R("T@=7-UX7)I;R!P;V1E('9E<B!A
M('!A<W1A`$QI<W1A<B!"86YC;W,@9&4@1&%D;W,`3&ES=&%R(%3S<&EC;W,@
M9&4@06IU9&$`3&ES=&%R(%1A8F5L87,`3&ES="U!<F-H:79E`$QI<W0M2&5L
M<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E
M`$QI<W0M56YS=6)S8W)I8F4`02!L:7-T86=E;2!D92!S97-S]65S(&9A;&AO
M=3H@)7,`02!L:7-T86=E;2!D92!U<W7A<FEO<R!F86QH;W4Z("5S`$QI<W1A
M9V5M(&1E('5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861A+@!,:71E<F%T=7)A
M`$QI='7B;FEA`%)E7V=IXV\`0V%R<F5G86YD;RXN+@!(;W)A(&QO8V%L.B``
M3&]C86QI>F'GXV\@92!(;W)A`%)E9VGC;P!#;VYE8W1A<@!,;V<@9&$@<V5S
M<^-O(&1E('-I;F-R;VYI>F'GXV\@86YT97)I;W(`1&5S8V]N96-T87(`0V]N
M96-T87(`5&%R969A<R!D92!#;VYE>.-O`$\@;&]G:6X@9F%L:&]U('!O<G%U
M92!S974@=7-UX7)I;R!O=2!S96YH82!E<W1A=F$@:6YC;W)R971A+@!&86QH
M82!D92!,;V=I;BX`5&5X=&\@;&]N9V\`06UO<@!"86EX80!!;&9A8F5T;R!G
M<F5G;R!E;2!M:6[Z<V-U;&\`06QF86)E=&\@;&%T:6YO(&5M(&UI;OIS8W5L
M;P!.^FUE<F]S(')O;6%N;W,@96T@;6EN^G-C=6QO`$QU>&5M8G5R9V\`34T`
M34]41`!/(&%N97AO($U3+51.148@;N-O(&-O;G3I;2!D861O<RX`35-'`$UA
M8V%O`$UA8V5D;VYI82P@06YT:6=A(%)E</IB;&EC82!)=6=O<VSA=FEA(&1A
M`$UA9&%G87-C87(`3>%G:6-O`$-O<G)E:6\`061M:6YI<W1R861O<B!D;R!#
M;W)R96EO`$-R:6%R(&QI;E]K+BXN`$UA;&%W:0!-86SA<VEA`$UA;&1I=F%S
M`$UA;&D`36%L=&$`1V5R96YC:6%R(&%G96YD87,@<F5M;W1A<RX`1V5R96YC
M:6$@82!L:7-T82!D92!C871E9V]R:6%S(&4@87,@8V]R97,@87-S;V-I861A
M<R!A(&5L87,N`$UA<&5A;65N=&\@36%P,C0`36%P96%M96YT;R!-87!1=65S
M=`!-87!E86UE;G1O<R!G<F%V861O<RX`36%RYV\`36%R9V5M`$UA<F-A<B!C
M;VT@9FQA9W,@3&ED82].XV\@3&ED80!-87)C87(@8V]M(&]U=')O<R!F;&%G
M<R`H97@N($EM<&]R=&%N=&4O4F5S<&]N9&ED82D`26QH87,@36%R<VAA;&P`
M36%R=&EN:6-A`$-A;7!O<R!C;W)R97-P;VYD96YT97,`36%U<FETXFYI80!-
M875R[6-I;P!#<NED:71O(&WA>&EM;R!P97)M:71I9&\N`$[Z;65R;R!MX7AI
M;6\@9&4@<&%R=&5S(&1A(&UE;G-A9V5M(&5X8V5D974N`%1E;7!E<F%T=7)A
M(&WA>&EM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E<F%T=7)A(&WA
M>&EM82!N87,@^FQT:6UA<R`V(&AO<F%S.B``3OIM97)O($WA>&EM;R!D92!%
M=F5N=&]S`$[Z;65R;R!-X7AI;6\@9&4@0FQO8V]S(&1E(%!O<G1A;`!486UA
M;FAO(&WA>&EM;P!-86EO`$UA>6]T=&4`174`365D:6-I;F$`4F5U;FGC;P!-
M96UB<F]S`$%V:7-O<R!D92!-96YU`$QI<W1A(&1E($UE;G4`36]D;R!D;R!M
M96YU.@!-97-C;&%R(&/I;'5L87,`365N<V%G96T`365N<V%G96T@5F5R:69I
M8V%D82!C;VT@4W5C97-S;R!M87,@;R!C97)T:69I8V%D;R!D;R!A<W-I;F%N
M=&4@;N-O('#T9&4@<V5R('9E<FEF:6-A9&\N`$UE;G-A9V5M(&5X<&ER861A
M+@!4:7!O(&1E(&UE;G-A9V5M`$-L:6UA($UE=&%R`$)L;V-O($UE=&%R(&[C
M;R!D:7-P;V[M=F5L+@!";&]C;R!-971A<B!NXV\@9&ES<&]N[79E;"X@1&5T
M86QH97,@9F]R86T@9W)A=F%D;W,@96T@;&]G('!A<F$@;R!A9&UI;FES=')A
M9&]R+@!/($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861O+@!-Z71O9&\`3>ET
M;V1O("<E<R<@;N-O(&5S=.$@9&5F:6YI9&\`3>ET;V1O(&[C;R!D969I;FED
M;RX@3>ET;V1O(&-H86UA9&\Z("5S`$WI=')I8V$`3>EX:6-O`$UI8W)O;NES
M:6$L($5S=&%D;W,@1F5D97)A9&]S(&1A`$UE:6\`5&EP;R!-:6UE`%1E;7!E
M<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E<F%T
M=7)A(&WM;FEM82!N87,@^FQT:6UA<R`V(&AO<F%S.B``261A9&4@;>UN:6UA
M(&1A('-E;FAA(&%I;F1A(&[C;R!E>'!I<F]U`$UI;G5T;RAS*0!%<W!E;&AO
M`$1I=F5R<V]S`$QI<W1A(&1E($5V96YT;W,@4&5R9&ED;W,`4&%C;W1E(%!%
M05(@2%144%]297%U97-T(&9A;'1A;F1O+@!#;VYF:6=U<F'GXV\@9F%L=&%N
M9&\N(%9O8^H@=&5M('%U92!G97)A<B!E;&$@86=O<F$@<V4@=F]CZB!Q=65R
M('5T:6QI>F%R(&5S=&$@87!L:6-AY^-O+@!)1"!D82!M96YS86=E;2!F86QT
M86YD;RX`4&%C;W1E(&]B<FEG873S<FEO(%!%05(@36%I;"!F86QT86YD;RX`
M240@9&$@<V5S<^-O(&9A;'1A;F1O+@!396<`0V]R<F5I;R!-\W9E;`!-;V1E
M<F%R`$1A=&$@36]D:69I8V%D80!!;'1E<F%R(%523`!-\V1U;&\`36]L9&]V
M82P@4F5P^F)L:6-A(&1A`$WT;F%C;P!396=U;F1A+49E:7)A`$UO;F?S;&EA
M`$WJ<P!6:7-U86QI>F'GXV\@365N<V%L`$WJ<R!E(&%N;P!-96YS86QM96YT
M90!,:7-T82!D92!%=F5N=&]S($UE;G-A:7,`365N<V%L.B!297!E=&4@82!C
M861A`%!R\WAI;6]S($UE<V5S`$UE<V5S($%N=&5R:6]R97,`36]N='-E<G)A
M=`!&87-E<R!D82!,=6$`36%I<R!C86UP;W,@96YC;VYT<F%D;W,@;F$@;&EN
M:&$@)60@<75E(&\@;OIM97)O(&5S<&5R861O("5D+@!-87)R;V-O<P!'<F%N
M9&4@4&%R=&4@3&EM<&$`1W)A;F1E(%!A<G1E($YU8FQA9&\`1W)A;F1E(%!A
M<G1E($5N<V]L87)A9&\`36]V97(@06)A:7AO`$UO=F5R(.`@17-Q=65R9&$`
M36]V97(@X"!$:7)E:71A`$UO=F5R($%C:6UA`$%B86EX;P!!8VEM80!-;^=A
M;6)I<75E`$QI<W1A<R!D92!S96QEY^-O(&1E(&WZ;'1I<&QO<R!N[79E:7,`
M36%P87,@26YG;&5S97,@375L=&EM87``3?IL=&EP;&]S(&-O;7!O;F5N=&5S
M(&E#86QE;F1A<B!E;F-O;G1R861O<SL@<V]M96YT92!U;2!V179E;G0@Z2!S
M=7!O<G1A9&\N`%-E;&7GXV\@;?IL=&EP;&$`36EN:&$@0V]N=&$`4W5A<R!)
M;F9O<FUAY_5E<P!-:6YH87,@06=E;F1A<P!-:6YH87,@06=E;F1A<SH`36EN
M:&$@55),($QI=G)E+T]C=7!A9&\`365U(%!O<G1A;`!-974@3&%Y;W5T(&1E
M(%!O<G1A;`!":7)MXFYI80!.PT\L($5U($[#3R!#;VYC;W)D;P!.;VUE`$YA
M;>UB:6$`3F%U<G4`3F5P86P`2&]L86YD80!!;G1I;&AA<R!(;VQA;F1E<V%S
M`%523"!"87-E(&1O($YE='-C87!E`%523"!D92!2979O9V'GXV\@9&4@0T$@
M9&\@3F5T<V-A<&4`55),(&1E('!O;.UT:6-A<R!D92!#02!D;R!.971S8V%P
M90!54DP@9&4@4F5N;W9AY^-O(&1O($YE='-C87!E`%523"!D92!2979O9V'G
MXV\@9&\@3F5T<V-A<&4`3F]M92!D;R!S97)V:61O<B!34TP@9&\@3F5T<V-A
M<&4`0V]M96YTX7)I;R!D;R!C97)T:69I8V%D;R!D;R!.971S8V%P90!4:7!O
M(&1E(&-E<G1I9FEC861O(&1O($YE='-C87!E`%)E9&4`3G5N8V$`3F]V82!#
M86QE9/1N:6$`3F]V82!#871E9V]R:6$`3F]V;R!%=F5N=&\`3F]V82!-96YS
M86=E;2!P87)A("5S`$QU82!.;W9A`$YO=F\@57-UX7)I;R`H;W!C:6]N86PI
M`$YO=F$@6F5LXFYD:6$`3F]V82!A9V5N9&$@8W)I861A(&4@875T;VUA=&EC
M86UE;G1E(&-O;7!A<G1I;&AA9&$@8V]M(&\H<RD@<V5G=6EN=&4H<RD@9W)U
M<&\H<RDZ("5S+@!.;W9A('-E;FAA`$YO=F$@<V5N:&$@97AP:7)A<N$@96T@
M)7@N`$%S(&YO=F%S('-E;FAA<R!NXV\@<^-O(&EG=6%I<RX`3F]V82!J86YE
M;&$@*%]B;&%N:RD`3F]T[6-I87,`1W)U<&]S(&1E($YO=.UC:6%S`%!R\WAI
M;6$`4'+S>&EM87,@,C0@:&]R87,`4'+S>&EM87,@-"!&87-E<P!0<O-X:6UO
M($1I80!0<O-X:6UO($WJ<P!0<O-X:6UA(%-E;6%N80!0<O-X:6UO($%N;P!0
M<O-X:6UO(&1I80!0<O-X:6UA<R!O<.?U97,`4'+S>&EM82!396UA;F$`4'+S
M>&EM83X`3FEC87+A9W5A`$YI9V5R`$YI9^ER:6$`3F]I=&4`3FEU90!.XV\`
M3F5N:'5M($%V:7-O`$YE;FAU;2!087)T:6-I<&%N=&4`3F5N:'5M(&1A9&\@
M9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV96P@<&%R82!E>&EB:7(@87,@9&EF
M97)E;N=A<RX`3F5N:'5M82!E<W1R873I9VEA(&1I<W!O;NUV96P@<&%R82!C
M<FEA<B!I;6%G96YS($E33RX`3F5N:'5M(&UO9&5L;R!D92!B871C:"X`3F5N
M:'5M(&)L;V-O(&5X:7-T92!N82!P;W-IY^-O('-O;&EC:71A9&$`3F5N:'5M
M(&YO;64@9&4@86=E;F1A(&9O<FYE8VED;R!P87)A(&$@875T96YT:6-AY^-O
M($U#04PN`$YE;FAU;6$@86=E;F1A(&5S=.$@9&ES<&]N[79E;"!P87)A(&-O
M;G9I9&%D;W,N`$YE;FAU;6$@86QT97)AY^-O+@!.96YH=6T@<W5B;W)D:6YA
M9&\@<&]D92!S97(@861I8VEO;F%D;R!A(&5S=&$@<&5R;6ES<^-O+@!.96YH
M=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P
M87)A("5S+@!.96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S
M<&5C:69I8V%D82!P87)A($944"!61E,N`$YE;FAU;6$@:6YF;W)M8>?C;R!D
M92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@4U%,(%9&4RX`3F5N
M:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@
M<&%R82!344PM1FEL92!61E,N`$YE;FAU;2!C<NED:71O(')E<W1A;G1E+@!.
M96YH=6T@9&5S=&EN;R!F;W)N96-I9&\N`%-E;2!D871A(&9I;F%L`$YE;FAU
M;2!E=F5N=&\@<&%R82!E>&EB:7(`3F5N:'5M(&%R<75I=F\@96YV:6%D;P!.
M96YH=6UA(&EN9F]R;6'GXV\@;&EV<F4O;V-U<&%D;R!E<W3A(&1I<W!O;NUV
M96P@<&%R82`E<P!.96YH=6T@9&%D;R!I0V%L96YD87(@9F]I(&5N8V]N=')A
M9&\N`$YE;FAU;2#M8V]N92!E;F-O;G1R861O+@!.96YH=6UA(&QO8V%L:7IA
MY^-O(&-O;F9I9W5R861A+@!.96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R
M861A+@!.96YH=6UA(&UE;G-A9V5M(&9O<FYE8VED82X`3F5N:'5M(&YO;64@
M97-P96-I9FEC861O+@!.96YH=6T@;OIM97)O(&5S<&5C:69I8V%D;RX`4V5M
M('-O<G1E<R!O9F5N<VEV87,`3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R
M82!A(&%U=&5N=&EC8>?C;R!(5%10+@!.96YH=6UA('-E;FAA(&9O<FYE8VED
M82!P87)A(&$@875T96YT:6-AY^-O($E-05`N`$YE;FAU;6$@<V5N:&$@9F]R
M;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@2V5R8F5R;W,N`$YE;FAU;6$@
M<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@3&]G:6XN`$YE
M;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@4$%3
M4U=$+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-A
MY^-O(%--0BX`3F5N:'5M('!A=&@@<&%R82!O(&)I;N%R:6\@9&\@3W!E;E-3
M3"!F;VD@9F]R;F5C:61O+B!/(&)I;N%R:6\@9&\@3W!E;E-33"#I(&YE8V5S
M<^%R:6\@<&%R82!M86YI<'5L87(@;W,@9&%D;W,@4$M#4R`Q,BX`3F5N:'5M
M(&-A9&%S=')O('!E;F1E;G1E+@!1=6]T82!NXV\@8V]N9FEG=7)A9&$N`%)E
M<&5T:>?C;P!396T@;&EN:&%S`$YE;FAU;2!S97!A<F%D;W(@9F]I(&5S<&5C
M:69I8V%D;RX`4V5M(&QA9&]S`$%R<75I=F\@:6YE>&ES=&5N=&4`3F5N:'5M
M(&1I<F5T\W)I;R!T96UP;W+A<FEO(&1I<W!O;NUV96P@<&%R82!O(&-A8VAE
M+@!.96YH=6T@=7-UX7)I;R!E+V]U('-E;FAA(&9O<FYE8VED;W,N`$YE;FAU
M;2!D861O(%A-3"!VX6QI9&\@<F5T;W)N861O`$YE;FAU;2!E;F1E<F7G;R!D
M92!E+6UA:6P@=N%L:61O(&9O:2!E;F-O;G1R861O`%-E;2!V86QO<F5S`$YE
M;FAU;2!V97)SXV\@96YC;VYT<F%D82!N82!C;VYF:6=U<F'GXV\@;W)I9VEN
M86PN($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O+@!.96YH=6UA('9E
M<G/C;R!E;F-O;G1R861A(&YA('-U82!C;VYF:6=U<F'GXV\N($=E<F4@;F]V
M86UE;G1E(&$@8V]N9FEG=7)AY^-O+@!.96YH=6UA`$YE;FAU;6$@*'5S;R!I
M;7!L[6-I=&\I`$[S<F1I8V\@*$E33RTX.#4Y+3$P*0!);&AA($YO<F9O;&L`
M2&5M:7-FZ7)I;R!.;W)T90!);&AA<R!-87)I86YA(&1O($YO<G1E`$YO<G5E
M9V$`3N-O($%P\W,`3N-O($%N=&5S`$[C;R#I('5M(&1I<F5T\W)I;P!.XV\@
M96YC;VYT<F%D;P!.XV\@26UP;&5M96YT861O+@!.XV\@8V]N9FEG=7)A9&\`
M3N-O('-U<&]R=&%D;RX`06YO=&'G]65S`$YA9&$@<&%R82!E>&EB:7(L('9O
M;'1E+@!.;W1I9FEC8>?U97,`3F]V96UB<F\`06=O<F$`3OIM97)O`$[Z;65R
M;R!D92!C87)A8W1E<F5S`$[Z;65R;R!D92!C;VQU;F%S`$[Z;65R;R!D92!L
M:6YH87,`3OIM97)O(&[C;R!E<W!E8VEF:6-A9&\@<&%R82!A='5A;&EZ8>?C
M;R!N82!L:7-T82!D92!D:7-T<FEB=6GGXV\N`$]+`$]B:F5T;P!#<FEA9&]R
M(&1O($]B:F5T;P!/8W1A;`!/=71U8G)O`$9I;'1R;R!O9F5N<VEV;P!%<V-R
M:73S<FEO`%-E;FAA<R!A;G1I9V$@92!N;W9A(&1E=F5M('-E<B!D:69E<F5N
M=&5S+@!396YH82!A;G1I9V$`4V5N:&$@86YT:6=A(&[C;R!E<W3A(&-O<G)E
M=&$N`$]MXP!%;0!%;2!T;V1A<R!A<R!A9V5N9&%S('%U92!E=2!T96YH;R!A
M8V5S<V\@9&4@;&5I='5R80!%;2!T;V1A<R!A<R!A9V5N9&%S(&5X:6)I9&%S
M`%-O;65N=&4@96T@;6EN:&%S(&%G96YD87,`4V]M96YT92!S97)V:61O<F5S
M($E-05`@<W5P;W)T86T@<&%S=&%S(&-O;7!A<G1I;&AA9&%S+@!3;VUE;G1E
M('-O<G1E<R!O9F5N<VEV87,`4V]M96YT92!U;2!E;F1E<F7G;R!D92!E+6UA
M:6P@<&5R;6ET:61O+@!3;VUE;G1E(&\@<')O<')I973A<FEO(&]U(&\@861M
M:6YI<W1R861O<B!D;R!S:7-T96UA('!O9&5M(&%L=&5R87(@87,@<&5R;6ES
M<_5E<R!D92!P<F]P<FEE9&%D92!O=2!P<F]P<FEE=.%R:6\@9&4@=6T@8V]M
M<&%R=&EL:&%M96YT;P!!8G)I<B!E;2!U;6$@;F]V82!J86YE;&$`17)R;R!D
M;R!/<&5N4U-,.B!.XV\@<'5D92!E>'1R86ER(&1A9&]S(&1A('!A<G1E(&%S
M<VEN861A(%,O34E-12X`06)R92!E<W1E(&QI;FL@96T@=6UA(&YO=F$@:F%N
M96QA`%-I<W1E;6$@3W!E<F%C:6]N86P`3W!C:6]N86P`4&%R=&EC:7!AY^-O
M(&]P8VEO;F%L`$]PY_5E<P!/<.?U97,@9&4@)7,`3&ES=&$@3W)D96YA9&$`
M3W)G86YI>F'GXV\`56YI9&%D92!/<F=A;FEZ86-I;VYA;`!/<F=A;FEZ86YD
M;P!-;V1E;&\@;W)I9VEN86P@9&4@87!L:6-AY^-O`$UO9&5L;R!O<FEG:6YA
M;"!E;2`E<SH`3W5T<F\`3W5T<F%S($EN9F]R;6'G]65S`%9I<^-O($=E<F%L
M`%!R;W!R:65TX7)I;P!097)M:7-S]65S(&1O(%!R;W!R:65TX7)I;P!0<F]P
M<FEE=.%R:6\Z("5S`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N
M[79E;"X`0V]N96-T;W(@4$5!4CHZ36%I;`!!<W-I;F%T=7)A($1I9VET86P@
M4$=0`$1A9&]S($-R:7!T;V=R869A9&]S(&-O;2!01U``0VAA=F4@4/IB;&EC
M82!01U``1&%D;W,@07-S:6YA9&]S+T-R:7!T;V=R869A9&]S(&-O;2!01U``
M0_-D:6=O(%!(4`!,:6YH82!D92!#;VUA;F1O(%!(4`!030!#:'5V82!&<F%C
M82!697-P97)T:6YA`$-H=79A(%9E<W!E<G1I;F$`0VAU=F%S(%9E<W!E<G1I
M;F%S`$YE=F4@5F5S<&5R=&EN80!.979A<V-A(%9E<W!E<G1I;F$`3F5V92!6
M97-P97)T:6YA`%1R;W9O861A<R!697-P97)T:6YA<P!%<W3A(&9A;'1A;F1O
M(&$@97AT96YSXV\@4$]325@`3&EN:&$@9&4@0V]M86YD;R!07TA0`$UA<F=E
M;0!087%U:7-TXV\`4&%L874`4&%L97-T:6YO+"!497)R:73S<FEO($]C=7!A
M9&\`4&%N86WA`%#A<'5A($YO=F$@1W5I;ND`4&%R86=U86D`4&%R8VEA;&UE
M;G1E($YU8FQA9&\`4V5N:&$`4V5N:&$@86QT97)A9&$@8V]M('-U8V5S<V\N
M`%-E;FAA(&EN8V]R<F5T80!396YH82!O8G)I9V%T\W)I82!P87)A(&$@875T
M96YT:6-AY^-O(%)!1$E54RX`4V5N:&$@8V]M(&-O;F9I<FUAY^-O`%-E;FAA
M.@!396YH83H@`%-E;FAA<R!D979E;2!S97(@:6=U86ES+@!,:7-T82!D92!%
M=F5N=&]S(%!A<W-A9&]S`$-O;&%R`$-O;&%R(&1A(.%R96$@9&4@=')A;G-F
M97+J;F-I80!0871H`$UO9&5L;P!#861A<W1R;W,@4&5N9&5N=&5S.@!097-S
M;V%S`%!O<F-E;G1A9V5M`$5X96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5N
MY^-O`$5X96-U=&%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%O(&-O;F5C
M=&%R/P!%>&-L=6ER(&5S=&4@979E;G1O('!E<FUA;F5N=&5M96YT93\`4&5R
M;6ES<^-O`%!E<FUI<W/C;R`B)7,B(&[C;R!E>&-L=>UD82X`4&5R;6ES<^-O
M($YE9V%D80!097)M:7-S]65S`$%D;6EN:7-T<F'GXV\@9&4@4&5R;6ES<_5E
M<P!);F9O<FUAY_5E<R!097-S;V%I<P!097)U`$%N:6UA:7,@9&4@17-T:6UA
MY^-O`$9I;&EP:6YA<P!496QE9F]N90!&;W1O<P!0:71C86ER;@!0:7AE;',`
M0VQI8VCI`%!O<B!F879O<B!C;&EQ=64@96T@86QG=6UA(&/I;'5L80!0;W(@
M9F%V;W(@8V]N9FER;64@<75E('9O8^H@<75E<B!R96UO=F5R(&5S=&4@96QE
M;65N=&\Z`%!O<B!F879O<B!C;VYF:7)M92!Q=64@=F]CZB!Q=65R(')E;6]V
M97(@;R!L:6YK(&1E<W1E(&5L96UE;G1O+@!0;W(@9F%V;W(@9F]R;F7G82!U
M;2!MZG,@92!U;2!A;F\N`%!O<B!F879O<B!F;W)N9>=A('5M(&YO;64@<&%R
M82!A(&YO=F$@8V%T96=O<FEA.@!0;W(@9F%V;W(@9F]R;F7G82!U;2!E;F1E
M<F7G;R!)4"!VX6QI9&\N`%!O<B!F879O<B!F;W)N9>=A('5M82!D871A(';A
M;&ED82P@=F5R:69I<75E(&\@;OIM97)O(&1E(&1I87,@;F\@;>IS+@!0;W(@
M9F%V;W(@9F]R;F7G82!U;6$@:&]R82!VX6QI9&$N`%!O<B!F879O<B!F;W)N
M9>=A('5M(')E<W5M;R!D;R!P<F]B;&5M82X`4&]R(&9A=F]R(&9O<FYEYV$@
M<V5U('5S=>%R:6\@92!S96YH80!0;W(@9F%V;W(@;&5I82!O('1E>'1O(&$@
M<V5G=6ER+B!6;V/J($1%5D4@8V]N8V]R9&%R(&-O;2!O<R!T97)M;W,@9&4@
M=7-O(&1O('-I<W1E;6$N`%!O<B!F879O<B!D:6=I=&4@;R!N;VUE(&1A(&YO
M=F$@8V%T96=O<FEA.@!0;VST;FEA`%!O;.UT:6-A`$5N<75E=&4`3W#G]65S
M(&1O(%!O<G1A;`!0;W)T=6=A;`!0;W-IY^-O(&1E<W1A(&EM86=E;0!0;W-I
MY^-O(&1E<W1A('1A8F5L80!%;G9I92!P87)A(&5S=&$@<&%S=&$@*&[C;R#I
M(&]B<FEG861O('!E;&\@24U!4"D`4')E8VEP:71AY^-O('!A<F$@82AS*2#Z
M;'1I;6$H<RD@)7,@:&]R82AS*3H@`%!R96-I<&ET8>?C;SQB<B`O/F-H86YC
M90!0<F5F<U]L9&%P.B!%>'1E;G/C;R!,1$%0(&]B<FEG873S<FEA(&[C;R!E
M;F-O;G1R861A+@!0<F5F<U]S97-S:6]N.B!%>'1E;G/C;R!D92!S97-SXV\@
M;V)R:6=A=/-R:6$@;N-O(&5N8V]N=')A9&$N`%!R97-SXV\`4')E<W/C;R!E
M;2!N[79E;"!D;R!M87(Z(`!0<F5S<^-O.B``4'+I+79I<W5A;&EZ8>?C;P!0
M<F5V97(@82!I;6%G96T@96T@=6UA(&YO=F$@:F%N96QA`$1I82!!;G1E<FEO
M<@!396UA;F$@06YT97)I;W(`1&EA(&%N=&5R:6]R`$]PY_5E<R!A;G1E<FEO
M<F5S`$EM<')I;6ER(&1O8W5M96YT;P!#:&%V92!0<FEV861A`%!R;V)L96UA
M`$1E<V-R:>?C;R!D;R!0<F]B;&5M80!0<F]J971O<P!497AT;R!B<F5V90!#
M:&%V92!0^F)L:6-A`$%L9V]R:71M;R!D82!#:&%V92!0^F)L:6-A`$-H879E
M(%#Z8FQI8V$`4&%R(&1E(&-H879E<R!0^F)L:6-A+U!R:79A9&$@;N-O(&9O
M<F%M(&=E<F%D;W,@8V]M('-U8V5S<V\N`%!O<G1O(%)I8V\`46%T87(`0V]N
M<W5L=&%R`%%A=&%R`$-H879E(%#Z8FQI8V$@4E-!("@E9"!B:70I`$)O=/5E
M<R!D92!S96QEY^-O`$-H=79A`$-H=79A($UA='5T:6YA`$-H=79A(%9E<W!E
M<G1I;F$`4&%N8V%D87,@9&4@0VAU=F$`0VAU=F$@92!.979E`$-H=79A('!A
M<F$@3F5V90!3;W)T92!!;&5A=/-R:6$`4F5L8>?C;P!,97(`3&5R(&UE;G-A
M9V5N<P!%>&-L=6ER(')E86QM96YT92`E<S\@17-T82!O<&5R8>?C;R!NXV\@
M<&]D92!S97(@9&5S9F5I=&$N`%)E;6]V97(@<F5A;&UE;G1E(&]S(&1A9&]S
M(&1O('5S=>%R:6\@)7,_($5S=&$@;W!E<F'GXV\@;N-O('!O9&4@<V5R(&1E
M<V9E:71A+@!297!E=&ER($%TZ0!297!E=&GGXV\`1&%D;W,@9&$@4F5P971I
MY^-O`$1A=&$@1FEN86P@9&$@4F5P971IY^-O`$EN=&5R=F%L;R!D92!297!E
M=&GGXV\`5&EP;R!D92!297!E=&GGXV\`4F5P971E(&1I87)I86UE;G1E`%)E
M<&5T92!M96YS86QM96YT90!297!E=&4@<V5M86YA;&UE;G1E`%)E<&5T92!A
M;G5A;&UE;G1E`%)E9F%Z('-U82#Z;'1I;6$@8>?C;P!!='5A;&EZ87(`071U
M86QI>F%R($UE;G4@9&4@16QE;65N=&]S($1I;N)M:6-O<SH`071U86QI>F%R
M($5X:6)IY^-O(&1O(%!O<G1A;#H`4F5G97@`3F%V96=A9&]R(&1E(%)E;&'G
M]65S`$QE<@!/8G-E<G9AY_5E<P!,96UB<F5T93H@)7,`06=E;F1A<R!296UO
M=&%S`$%G96YD87,@4F5M;W1A<SH`4V5R=FED;W)E<R!296UO=&]S`%523"!2
M96UO=&$@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F5R
M`%)E;6]V97(@)7,`4F5M;W9E<B!087)T:6-I<&%N=&4`4F5M;W9E<B!";&]C
M;P!296UO=F5R(&-O;'5N80!296UO=F5R(&9O<FUA=&'GXV\`4F5M;W9E<B!P
M87(`4F5M;W9E<B!S8W)I<'0@9W)A=F%D;R!N;R!D:7)E=/-R:6\@=&5M<&]R
MX7)I;R!D;R!S97)V:61O<BX`4F5M;W9E<B!O`%)E;6]V97(@97-T92!N\R!D
M;R!D;V-U;65N=&\`4F5M;W9E<B!U<W7A<FEO`%)E;6]V97(@=7-UX7)I;SH@
M)7,`4W5B<W1I='5I<B!A(&%G96YD82!E>&ES=&5N=&4@<&5L82!A9V5N9&$@
M:6UP;W)T861A/SQS=')O;F<^071E;N?C;SH@27-S;R!E>&-L=6ERX2!T;V1O
M<R!O<R!R96=I<W1R;W,@9&4@<W5A(&%G96YD82!A='5A;"X\+W-T<F]N9SX`
M4V]L:6-I=&'GXV\@;N-O('#T9&4@<V5R(')E<W!O;F1I9&$N($/S9&EG;R!D
M92!E<G)O(')E=&]R;F%D;SH@`$\@<V5R=FGG;R!R97%U:7-I=&%D;R!NXV\@
M<&]D92!S97(@96YC;VYT<F%D;RX`3V)R:6=A=/-R:6\`)R5S)R!O8G)I9V%T
M\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@)7,N
M`"<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N
M9FEG=7)AY^-O(%9&4RX`)R5S)R!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C
M:69I8V%D;R!N82!C;VYF:6=U<F'GXV\N`%!A<G1I8VEP86YT97,@3V)R:6=A
M=/-R:6]S`$-A;7!O($]B<FEG873S<FEO`$QI;7!A<@!'97)A<B!.;W9A(%-E
M;FAA`$=E<F%R($YO=F$@4V5N:&$`4F5T;W)N87(@<&%R82!O<R!P861R]65S
M`%)E<W!O<W1A`-IL=&EM;R!1=6%R=&\`4F5S=6QT861O<P!2971O<FYA<B#@
M($]PY_5E<P!$:6=I=&4@82!N;W9A('-E;FAA(&YO=F%M96YT90!2975N:>-O
M`%)E=F5R=&5R($-O;F9I9W5R8>?C;P!/<.?U97,@9&\@161I=&]R(%)I8V@@
M5&5X=`!#:&%R861A<P!$:7)E:71A`$-A8F7G86QH;R!D:7)E:71O`%9A;&]R
M97,@9&$@9&ER96ET80!0<F]P<FEE9&%D97,@9&$@7TQI;FAA+BXN`$9U;N?C
M;P!2;VWJ;FEA`$=I<F%R(#$X,"!G<F%U<P!':7)A<B!P87)A(&$@17-Q=65R
M9&$`1VER87(@<&%R82!A($1I<F5I=&$`4')O<')I961A9&5S(&1A($QI;FAA
M`%!R;W!R:65D861E<R!D82!L:6YH80!,:6YH87,Z`$QI;FAA<P!,:6YH87,@
M87!A<F5C97+C;R!E;G1R92!T;V1A<R!A<R!L:6YH87,@92!C;VQU;F%S`$QI
M;FAA<R!A<&%R96-E<N-O('-O;65N=&4@96YT<F4@8V]L=6YA<P!,:6YH87,@
M87!A<F5C97+C;R!S;VUE;G1E(&5N=')E(&QI;FAA<P!%>&5C=71A<@!&961E
M<F'GXV\@4G5S<V$`4G5A;F1A`$%S<VEN871U<F$@0W)I<'1O9W+A9FEC82!3
M+TU)344`365N<V%G96T@0W)I<'1O9W)A9F%D82!C;VT@4R]-24U%`$%U=&5N
M=&EC8>?C;R!305-,(&[C;R!E<W3A(&1I<W!O;NUV96PN`$-O<G)E:6\@4TU3
M`$QI;FAA(&1E(&-O;6%N9&\@4U%,`%-E;G1E;N=A(%-13"!P87)A('!E<W%U
M:7-A<R!D92!V86QO<F5S`%-32`!354-%4U-/`$QI;FAA(&1E(&-O;6%N9&\@
M4U]13`!386(`4V%N=&$@2&5L96YA`%/C;R!+:71T<R!E($YE=FES`%-A;G1A
M($QU>FEA`%/C;R!0961R;R!E($UI<75E;&]N`%/C;R!6:6-E;G1E(&4@1W)A
M;F%D:6YA<P!-97-M;R!Q=6%D<F\@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%/C;R!4;VWI(&4@4'+M;F-I<&4`4')O=F5D;W(@9&4@4V%TZ6QI=&4`4^%B
M861O`$%RX6)I82!3875D:71A`%-A;'9A<@!386QV87(@)7,`4V%L=F%R("5S
M`%-A;'9A<B!#;VUO($YO=F\`4V%L=F%R(%!A<G1I8VEP86YT97,`4V%L=F%R
M($5V96YT;P!386QV87(@3W#G]65S`%-A;'9A<B!C;VYF:6=U<F'GXV\@9V5R
M861A(&-O;6\@=6T@<V-R:7!T(%!(4"!P87)A(&\@9&ER973S<FEO('1E;7!O
M<N%R:6\@9&\@<V5U('-E<G9I9&]R+@!#;VYF:6=U<F'GXV\@)7,@<V%L=F$N
M`%-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@<V%L=F\@
M96TZ("<E<R<N`%1E;7!E<W1A9&5S($ES;VQA9&%S`$-IZFYC:6$`4&5S<75I
M<V%R`%!E<W%U:7-A<B!!9V5N9&%S`$5N9VEN97,@9&4@4&5S<75I<V$@`%)E
M<W5L=&%D;W,@9&$@4&5S<75I<V$`4&5S<75I<V%R('!O<B!A9V5N9&%S(&-O
M;G1E;F1O.@!396QE8VEO;F4@;W,@07)Q=6EV;W,`4V5L96-I;VYE('5M82!A
M9V5N9&$@<&%R82!E9&ET87(`4V5L96-I;VYE('5M82!D871A`%-E;&5C:6]N
M92!U;2!G<G5P;R!P87)A(&%D:6-I;VYA<@!396QE8VEO;F4@=6T@;F]V;R!M
M96UB<F\`4V5L96-I;VYE('5M('-E<G9I9&]R`%-E;&5C:6]N92!U;2!U<W7A
M<FEO('!A<F$@861I8VEO;F%R`%-E;&5C:6]N87(@=&]D;W,`4V5L96-I;VYE
M('1O9&]S(&]S(&-O;7!O;F5N=&5S(&1E(&1A=&$N`%-E;&5C:6]N92!U;2!O
M8FIE=&\`4V5L96-I;VYE(&%S(&%G96YD87,@82!E>&EB:7(Z`%-E;&5C:6]N
M92!O<.?U97,@9&4@8V]N9FER;6'GXV\L(&-O;6\@97AI8FER(&1I9F5R96YT
M97,@=FES=6%L:7IAY_5E<R!E(&5S8V]L:&$@=6UA('9I<W5A;&EZ8>?C;R!P
M861RXV\N`$[C;R!S96QE8VEO;F%R(&YE;FAU;0!396QE8VEO;F4@82!A9V5N
M9&$@<&%R82!O;F1E(&EM<&]R=&%R.@!396QE8VEO;F4@;W,@8V%R86-T97)E
M<R!Q=64@=F]CZB!P<F5C:7-A(&YA(&-A:7AA(&%B86EX;RX@5F]CZB!P;V1E
M(&5N=.-O(&-O<&GA+6QO<R!E(&-O;.$M;&]S(&YA(.%R96$@9&4@=&5X=&\N
M`%-E;&5C:6]N92!U;2!D96QI;6ET861O<B!D92!D871A.@!396QE8VEO;F4@
M;R!F;W)M871O(&1E(&1A=&$Z`%-E;&5C:6]N92!O(&9O<FUA=&\@<&%R82!E
M>'!O<G1A<CH`4V5L96-I;VYE(&\@87)Q=6EV;R!P87)A(&EM<&]R=&%R.@!3
M96QE8VEO;F4@;R!P<FEM96ER;R!D:6$@9&$@<V5M86YA.@!396QE8VEO;F4@
M;R!F;W)M871O(&1O(&%R<75I=F\@9&4@;W)I9V5M.@!396QE8VEO;F4@82!I
M9&5N=&ED861E('%U92!V;V/J('%U97(@86QT97)A<CH`4V5L96-I;VYE('5M
M(&1E;&EM:71A9&]R(&1E(&AO<F$Z`%-E;&5C:6]N92!O(&9O<FUA=&\@9&4@
M:&]R83H`4V5L96-I;VYE(&\@=&5M<&\@9&4@9'5R8>?C;R!P87)A(&5X:6)I
M<CH`4V5L96-I;VYE(&$@=FES=6%L:7IAY^-O('!A<F$@97AI8FER(&YA(&EN
M:6-I86QI>F'GXV\Z`%-E;&5C:6]N92!D;VES(&-A;7!O<R!C;W)R97-P;VYD
M96YT97,N`%-E;&5C:6]N92!Q=6%I<R!E=F5N=&]S(&5X:6)I<B!N;R!P;W)T
M86PN`%-E;&5C:6]N92!S974@97-Q=65M82!D92!C;W)E<RX`4V5L96-I;VYE
M('-E=2!I9&EO;6$@<')E9F5R:61O.@!%;G9I87(@4F5L873S<FEO(&1E(%!R
M;V)L96UA`$5N=FEA<B!335,`16YV:6%R('5M82!N;W1I9FEC8>?C;R!D92!C
M86YC96QA;65N=&\@<&%R82!T;V1O<R!P87)T:6-I<&%N=&5S(&%O(&5X8VQU
M:7(@97-T92!E=F5N=&\`16YV:6%R('5M(&4M;6%I;"!P87)A("5S`$5N=FEA
M<B!A='5A;&EZ8>?U97,O8V]N=FET97,@<&%R82!T;V1O<R!O<R!P87)T:6-I
M<&%N=&5S(&%O('-A;'9A<B!E<W1E(&5V96YT;P!396YE9V%L`%-E;G-O<CH@
M`%-E=&5M8G)O`%-E<G9I82!E($UO;G1E;F5G<F\`3OIM97)O(&1E(%/I<FEE
M`$1A9&]S(&1O('-E<G9I9&]R(&5R<F%D;W,@;W4@;N-O(&1I<W!O;NUV96ES
M+@!!9&UI;FES=')A9&]R(&1E(%-E<W/C;P!)1"!D82!397-SXV\@97AP:7)O
M=2X`4V5S<_5E<P!!:G5S=&%R`$1E9FEN:7(@9&%T82!F:6YA;`!#;VYF:6=U
M<F$@87,@;W#G]65S('!A<F$@<&5R;6ET:7(@=F]CZB!G97)A<B!U;6$@;F]V
M82!S96YH82!S92!V;V/J(&5S<75E8^HM;&$N`$1E9FEN:7(@9&%T82!F:6YA
M;"!D82!R97!E=&GGXV\`1&5F:6YI<B!D871A(&1E(&EN[6-I;P!#;VYF:6=U
M<F$@;W,@<V5R=FED;W)E<R!R96UO=&]S('%U92!V;V/J('%U97(@86-E<W-A
M<B#@('!A<G1I<B!D;R!P;W)T86PN`$1E9FEN92!A<R!O<.?U97,@;&EV<F4O
M;V-U<&%D;RP@<W5A<R!E(&1E(&]U=')O<R!U<W7A<FEO<RX`0V]N9FEG=7)A
M('-E=2!I9&EO;6$@<')E9F5R:61O+"!F=7-O(&AO<N%R:6\@92!O<.?U97,@
M9&4@9&%T82X`0V]N9FEG=7)A('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@97-Q
M=65M82!D92!C;W)E<RP@871U86QI>F'GXV\@9&4@<.%G:6YA<R!E(&]U=')A
M<R!O<.?U97,@9&4@97AI8FGGXV\N`$-O;F9I9W5R8>?C;P!38W)I<'1S(&1E
M(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<P!$:79E
M<G-A<R!L;V-A;&ED861E<R!P;W-S[79E:7,@8V]M(&\@<&%RXFUE=')O.B``
M4V5I8VAE;&5S`$-O;7!A<G1I;&AA;65N=&\@;N-O(&5N8V]N=')A9&\Z("5S
M`$%G96YD87,@0V]M<&%R=&EL:&%D87,`06=E;F1A<R!#;VUP87)T:6QH861A
M<SH`0V]M<')A<P!297-U;6\`5&5C;&%S(&1E(&%T86QH;R!D979E<N-O('-E
M<B!D969I;FED87,@<&%R82!A(&UA:6]R:6$@9&]S(&QI;FMS/P!%>&EB:7(`
M17AI8FER($%G96YD80!%>&EB:7(@;&5G96YD82!D87,@8V%T96=O<FEA<S\`
M17AI8FER(&]S(.UC;VYE<R!D92!E>&-L=7/C;RP@879I<V\@92!R97!E=&GG
MXV\@;F%S('9I<W5A;&EZ8>?U97,@9&$@86=E;F1A/P!%>&EB:7(@87,@9&EF
M97)E;N=A<R!E;G1R92!A(&-O;F9I9W5R8>?C;R!A='5A;"!E(&$@;F]V82!G
M97)A9&$N`$5X:6)I<B!T87)E9F%S('9E;F-I9&%S(&YA(&%G96YD83\`17AI
M8FER(&QE9V5N9&$@9&4@;&EV<F4O;V-U<&%D;S\`17AI8FER(&1A=&$@92!H
M;W)A(&1A(/IL=&EM82!C;VYE>.-O(&%O('-E(&-O;F5C=&%R/P!%>&EB:7(@
M<V]M96YT92!E=F5N=&]S(&-O;2!A=FES;R!D969I;FED;S\`17AI8FER(&$@
M;W#GXV\@9&4@;6%N=&5R(&\@;W)I9VEN86P`17AI8FER('-E;&5T;W(`17AI
M8FER(&%G96YD87,@8V]M<&%R=&EL:&%D87,@;&%D;RUA+6QA9&\_`$5X:6)I
M<B!B87)R82!D92!M96YU(&-O;2!O<&5R8>?U97,@9&4@=&%B96QA/P!%>&EB
M:7(@=&%R969A<R!U=&EL:7IA;F1O(&-O<F5S(&1E(&-A=&5G;W)I83\`17AI
M8FER(&\@365N=2`E<R#@(&5S<75E<F1A/P!%>&EB:7(@9&GA;&]G;R!D92!0
M<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D82!486)E;&$`17AI8FER(&1IX6QO
M9V\@9&4@4')O<')I961A9&5S(&1A(%1A8F5L80!%>&EB:7(@9&GA;&]G;R!D
M92!0<F]P<FEE9&%D97,@9&4@3&EN:&%S(&1A(%1A8F5L80!%>&EB:7(@9&GA
M;&]G;R!D92!P<F]P<FEE9&%D97,@9&4@:6UA9V5M`$5X:6)I<B!A<R!H;W)A
M<R!E;G1R92!C861A(&1I82!N87,@=FES=6%L:7IAY_5E<R!S96UA;F%I<S\`
M17AI8FER('5P;&]A9`!#:'5V87,`0VAU=F%S(&UA=&EN86ES`$-H=79A<R!6
M97-P97)T:6YA<P!#:'5V87,@;F%S(')E9&]N9&5Z87,`4F5D=7II<@!0<FEM
M96ER86UE;G1E(')E9'5Z82!O=2!T:7)E(&1O(&-A;6EN:&\@;RAS*2!B;&]C
M;RAS*2!A9&IA8V5N=&4H<RD`4V5R<F$@3&5O80!296=I<W1R87(`07-S:6YA
M='5R80!!;&=O<FET;6\@9&$@07-S:6YA='5R80!#:6YG87!U<F$`5&%M86YH
M;P!)9VYO<F%R($UA;G5T96[GXV\`17-L;W;A<75I80!%<VQO=F5N:6$`3F5V
M90!.979A<V-A`$YE=F%S8V%S`$-H=79A<R!M871I;F%I<P!.979A<V-A<R!6
M97-P97)T:6YA<P!0<F]F=6YD:61A9&4@9&$@3F5V93H@`$5Q=6EV86QE;G1E
M(&1E(&YE=F4@96T@X6=U83H@`$EL:&%S(%-A;&]MXV\`4V]MX6QI80!#86[G
M]65S("8@4&]E;6%S`$]R9&5N87(@<V5L9>?C;P!%;F1E<F7G;R!D92!O<FEG
M96T`P69R:6-A(&1O(%-U;`!3=6P@175R;W!E=2`H25-/+3@X-3DM,RD`4W5L
M(&1A($=E;W)G:6$@92!3=6P@9&%S($EL:&%S(%-A;F1U[6-H90!(96UI<V;I
M<FEO(%-U;`!%<W!AYV\@96YT<F4@8^EL=6QA<R!A9&IA8V5N=&5S`$5S<&'G
M;R!E;G1R92!O(&-O;G1E^F1O(&4@8F]R9&$@9&$@8^EL=6QA`$5S<&'G861O
M<@!%<W!AYV%M96YT;P!%<W!AYV%M96YT;R!E(&UA<F=E;0!%<W!A;FAA`%-P
M86T`16YT<F%D82!D92!#87)A8W1E<F5S($5S<&5C:6%I<P!$:79I9&ER(&/I
M;'5L80!$:79I9&ER(&-O;'5N80!$:79I9&ER(&QI;FAA`$5S<&]R=&5S`%-R
M:2!,86YK80!)7VYI8VEA<@!0861RXV\`4W1A<B!4<F5K`$1A=&$@26YI8VEA
M;`!);FEC:6$@16T`2&]R82!);FEC:6%L`$%N;R!I;FEC:6%L`%-I=%]U8>?C
M;P!%<W1A9&\@;W4@4')O=NUN8VEA`%-I='5AY^-O`$9O<FUA=&\@9&\@87)M
M87IE;F%M96YT;P!.;VUE(&1A(%)U80!4<F'G861O`$QI<W1A(&1E(&-A9&5I
M87,@9&4@8V%R86-T97)E<P!2971I<F%R(&$@<&%R=&4@9&\@9&]M[6YI;R!D
M;R!E;F1E<F7G;P!%<W1I;&\@6T-34UT`1&]M`%-U8F1I<F5T\W)I;R`G)7,G
M(&[C;R!E;F-O;G1R861O+@!!<W-U;G1O`$5N=FEA<@!%;G9I861A(&$@<V]L
M:6-I=&'GXV\@9&4@861I8VEO;F%R("(E<R(@86\@<VES=&5M82X@5F]CZB!N
MXV\@<&]D92!C;VYE8W1A<BUS92!A=.D@<75E('-U82!S;VQI8VET8>?C;R!S
M96IA(&%P<F]V861A+@!3=6)S8W)E=F5R`%-U8V5S<V\`)R5S)R!A9&EC:6]N
M861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N`$]S(&1A9&]S(&1O('5S=>%R
M:6\@)R5S)R!F;W)A;2!R96UO=FED;W,@9&\@<VES=&5M82!C;VT@<W5C97-S
M;RX`)R5S)R!E>&-L=>UD;R!C;VT@<W5C97-S;RX`17AC;'7M9&\@)R5S)R!D
M;R!S:7-T96UA(&-O;2!S=6-E<W-O+@!#;VYF:6=U<F'GXV\@<F5V97)T:61A
M(&-O;2!S=6-E<W-O+B!!='5A;&EZ92!P87)A('9E<B!A<R!A;'1E<F'G]65S
M+@!"86-K=7`@9&$@8V]N9FEG=7)AY^-O('-A;'9A(&-O;2!S=6-E<W-O+@!/
M(&)A8VMU<"!D;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<R!F;VD@<V%L
M=F\@8V]M('-U8V5S<V\N`"<E<R<@871U86QI>F%D;R!C;VT@<W5C97-S;P`E
M<R!G<F%V861O(&-O;2!S=6-E<W-O`%-U9.-O`%)E<W5M;P!!;6%N:&5C97(`
M4/1R+61O+5-O;`!$;VUI;F=O`$5N<V]L87)A9&\`06UA;FAE8V5R`$%M86YH
M96-E<B]0]'(M9&\M4V]L`$%M86YH96-E<CH@`%#T<BUD;RU3;VP`4/1R+61O
M+5-O;#H@`%-O8G)E<V-R979E<@!3=7!O<G1E`%-U<FEN86UE`%-O8G)E;F]M
M90!3=F%L8F%R9"!E($IA;B!-87EE;@!3=6%Z:6SB;F1I80!3=>EC:6$`4W7M
MYV$`3N-O(&5X8VQU:7(`4WEN8TU,`$5R<F\@9&4@<VEN=&%X92!N;W,@=&5R
M;6]S(&1A('!E<W%U:7-A`%)E</IB;&EC82#!<F%B92!D82!3[7)I80!496UP
M97-T861E`%1E;7!E<W1A9&5S(&4@5F5N=&%N:6$`5&5M<&5S=&%D97,`5&5M
M<&5S=&%D97,@36%T:6YA:7,`07)Q=6EV;R!44U8`5&%B96QA`%!R;W!R:65D
M861E<R!D82!486)E;&$`5&%B96QA`%!R;W!R:65D861E<R!D82!T86)E;&$`
M5&%I=V%N`%1A:7=A;BP@4')O=NUN8VEA(&1A($-H:6YA`%1A:FEQ=6ES=.-O
M`%1A;GKB;FEA+"!297#Z8FQI8V$@9&$`06QV;SH`5&%R969A<P!.^FUE<F\@
M9&4@5&5L969O;F4`5&5M<&5R871U<F$@<&%R82!A(/IL=&EM82!H;W)A.B``
M5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!496UP97)A='5R83QB<B`O/B@E
M<T%L=&$E<R\E<T)A:7AA)7,I("9D96<[)7,`36]D96QO("<E<R<@;N-O(&5N
M8V]N=')A9&\N`$%D;6EN:7-T<F'GXV\@9&4@36]D96QO<P!0<F]V:7/S<FEO
M`%1E>'1O`%-O;65N=&4@5&5X=&\`06QI;FAA;65N=&\@9&4@5&5X=&\`0F]R
M9&$@<W5P97)I;W(@9&\@5&5X=&\`475I`%1A:6QA;F3J<R`H5$E3+38R,"D`
M5&%I;.)N9&EA`$$@=&5L82!%9&ET87(@4&%R=&EC:7!A;G1E<R!NXV\@97-T
MX2!M86ES(&1I<W!O;NUV96PN(%-A:6YD;RX`02!E>'1E;G/C;R!&5%`@;N-O
M(&5S=.$@9&ES<&]N[79E;"X`3R!H:7-T\W)I8V\@9&\@<VES=&5M82!E<W3A
M(&1E<V%B:6QI=&%D;RX`02!E;F=I;F4@9&4@:6YT96=R8>?C;R!(;W)D92]+
M;VQA8B!NXV\@<W5P;W)T82`B)7,B`$\@;&]G($E-4U`@;N-O('!O9&4@<V5R
M(&EN:6-I86QI>F%D;RX`02!C;&%S<V4@(DUA:6YT96YA;F-E(B!NXV\@9F]I
M(&-A<G)E9V%D82!C;VT@<W5C97-S;P!!(&IA;F5L82!D92!/<.?U97,@9F]I
M(&9E8VAA9&$N(%-A:6YD;RX`3R!A9&UI;FES=')A9&]R('!R96-I<V$@8V]N
M9FEG=7)A<B!U;2!C;VYE8W1O<B!P97)M86YE;G1E(&1E(%!E<FUI<W/U97,@
M<V4@=F]CZB!Q=65R('5T:6QI>F%R(%!E<FUI<W/U97,N`%-O;65N=&4@;R!L
M861O(&1E(&)A:7AO`$$@86=E;F1A("(E<R(@;N-O('!O9&4@<V5R(&5X8VQU
M[61A+@!!(&%G96YD82`B)7,B(&9O:2!C<FEA9&$N`$$@86=E;F1A("(E<R(@
M9F]I(&5X8VQU[61A+@!!(&%G96YD82`B)7,B(&9O:2!R96YO;65A9&$@<&%R
M82`B)7,B+@!!(&%G96YD82`B)7,B(&9O:2!S86QV82X`02!A9V5N9&$@;N-O
M('#T9&4@<V5R(')E;6]V:61A.B`E<P!/(&[Z;65R;R!)1"!D;R!C;VYT871O
M(&[C;R!F;VD@97-P96-I9FEC861O+"!D96EX861O(&5M(&)R86YC;R!O=2!N
MXV\@9F]I(&5N8V]N=')A9&\@;F\@8F%N8V\@9&4@9&%D;W,N`$\@8V]N=&%T
M;R!F;VD@861I8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S974@8V%TX6QO9V\@
M9&4@96YD97)EYV]S+@!087)A('9E<FEF:6-A<B!A(&UE;G-A9V5M(&%S<VEN
M861A(.D@;F5C97-SX7)I;R!U;2!B;&]C;R!S97!A<F%D;R!D82!A<W-I;F%T
M=7)A(%!'4"X`3R!)1"!D82!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O
M:2!E<W!E8VEF:6-A9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@
M96YC;VYT<F%D;R!N;R!B86YC;R!D92!D861O<RX`02!L:7-T82!D92!D:7-T
M<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF:6-A9&$N`$%S(&9U;N?U97,@9&4@
M8W)I<'1O9W)A9FEA(')E<75E<F5M('5M82!C;VYE>.-O('=E8B!S96=U<F$N
M`$$@9&%T82!F:6YA;"!D979E('-E<B!M86EO<B!Q=64@82!D871A(&EN:6-I
M86PN`$\@979E;G1O("(E<R(@9F]I(&%D:6-I;VYA9&\@;F$@86=E;F1A("(E
M<R(L(&\@<75A;"!S97+A(&5M("5S(.!S("5S+@!/(&5V96YT;R`B)7,B(&9O
M:2!E>&-L=>UD;R!D82!A9V5N9&$@(B5S(BP@;R!Q=6%L(&5R82!E;2`E<R#@
M<R`E<RX`3R!E=F5N=&\@(B5S(B!F;VD@86QT97)A9&\@;F$@86=E;F1A("(E
M<R(L(&\@<75A;"!S97+A(&5M("5S(.!S("5S+@!!(&YO=&EF:6-AY^-O(&1E
M(&5V96YT;R!P87)A("5S(&9O:2!E;G9I861A(&-O;2!S=6-E<W-O+@!/(&%R
M<75I=F\@)7,@9&5V97)I82!C;VYT97(@=6UA(&-O;F9I9W5R8>?C;R!D92`E
M<RX`3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N=&5R(&%L9W5M87,@8V]N9FEG
M=7)AY_5E<R!D92`E<RX`3R!A<G%U:79O(&[C;R!P;V1E('-E<B!C;W!I861O
M('!A<F$@96QE(&UE<VUO+@!/(&%R<75I=F\@;N-O(&-O;G3I;2!D861O<RX`
M4V5G=65M(&]S(&-A8F7G86QH;W,@9&5S=&$@;65N<V%G96TO;65N<V%G96T@
M<F9C.#(R+@!396=U92!U;6$@9&5S8W)IY^-O(&UA:7,@9&5T86QH861A(&1O
M(&5V96YT;SH`R2!S86)I9&\@<75E(&\@;6]D;R!T96QA(&-H96EA(&-A=7-A
M('!R;V)L96UA<R!C;VT@;R!);G1E<FYE="!%>'!L;W)E<BP@96T@=FER='5D
M92!D92!B=6=S(&1O(&YA=F5G861O<B!Q=64@;O-S(&[C;R!E<W1A;6]S(&%P
M=&]S(&$@8V]N=&]R;F%R+B!6;V/J('!O9&4@;V)S97)V87(@97)R;W,@9&4@
M97AI8FGGXV\L(&9A;'1A(&1E(&9U;N?U97,@9&\@961I=&]R(&4O;W4@=')A
M=F%M96YT;W,@86QE873S<FEO<R!D;R!N879E9V%D;W(N(%-E('-E=2!S:7-T
M96UA(.D@5VEN9&]W<R`Y>"#I(&UU:71O('!R;W;A=F5L('%U92!V;V/J(')E
M8V5B82!U;2!E<G)O(&1E("=&86QH82!'97)A;"!D92!0<F]T9>?C;R<@92!P
M<F5C:7-A<N$@<F5I;FEC:6%R+B!<;EQN(%9O8^H@9F]I(&%V:7-A9&\N(%!O
M<B!F879O<B!P<F5S<VEO;F4@3TL@<V4@=F]CZB!A:6YD82!Q=65R('1E;G1A
M<B!U<V%R(&\@961I=&]R(&1E('1E;&$@8VAE:6$N`$$@:61E;G1I9&%D92`B
M)7,B(&9O:2!E>&-L=>UD82X`4V]M96YT92!O(&QA9&\@97-Q=65R9&\`02!L
M;V-A;&EZ8>?C;R!D;R!B:6[A<FEO(&1O($=N=5!'(&1E=F4@<V5R(&9O<FYE
M8VED82#@(&-L87-S92`B0W)Y<'1?<&=P(BX`02!M96YS86=E;2!E;G9I861A
M(&5M("5S('!A<F$@)7,@8V]M(&\@87-S=6YT;R`B)7,B(&9O:2!E>&EB:61A
M+@I)<W1O(&[C;R!G87)A;G1E('%U92!A(&UE;G-A9V5M(&9O:2!L:61A(&]U
M(&5N=&5N9&ED82X`3R!N;VUE('5T:6QI>F%D;R!A;R!V:6YC=6QA<B!A('#A
M9VEN82!D92!C;VUP;W-IY^-O`$\@;OIM97)O(&1E(&-A;7!O<R!D979E('-E
M<B!N=6WI<FEC;RX`3R!M\V1U;&\@;W!E;G-S;"#I(&]B<FEG873S<FEO('!A
M<F$@82!C;&%S<V4@(DAO<F1E7T-R>7!T7W-M:6UE(BX`02!P<F5F97+J;F-I
M82`B)7,B(&[C;R!P;V1E('-E<B!S86QV82!P;W)Q=64@<V5U<R!D861O<R!E
M>&-E9&5R86T@;R!T86UA;FAO(&WA>&EM;R!P97)M:71I9&\`3R!P<F]G<F%M
M82!U=&EL:7IA9&\@<&%R82!V:7-U86QI>F%R(&5S=&4@=&EP;R!D92!D861O
M("@E<RD@;N-O(&9O:2!E;F-O;G1R861O(&YO('-I<W1E;6$N`$\@8V%R86-T
M97)E('!A<F$@8VET8>?C;R!D92!S97(@87!E;F%S('5M+@!!('-O;&EC:71A
MY^-O(&[C;R!F;VD@8V]M<&QE=&%D82X@06QG=6YS('!A<N)M971R;W,@<75E
M('/C;R!N96-E<W/A<FEO<R!P87)A(&%C96ET87(@;W4@<F5C=7-A<B!U;2!E
M=F5N=&\@97-TXV\@9F%L=&%N9&\N`%-O;65N=&4@;W,@;&%D;W,@9&ER96ET
M;R!E(&5S<75E<F1O`%-O;65N=&4@;R!L861O(&1I<F5I=&\`3R!S97!A<F%D
M;W(@9&5V92!S97(@=6T@^FYI8V\@8V%R86-T97)E+@!/('-E<G9I9&]R("(E
M<R(@9F]I(&5X8VQU[61O+@!/('-E<G9I9&]R("(E<R(@9F]I('-A;'9O+@!!
M('-O;&EC:71AY^-O(&1E(&-A9&%S=')O(&1E("5S(&9O:2!E>&-L=>UD82X`
M02!L:6YH82!E<W!E8VEF:6-A9&$@*"5D*2!NXV\@97AI<W1E+@!/(&%R<75I
M=F\@=&5M<&]RX7)I;R`B)7,B(&[C;R!E>&ES=&4N`$\@=&5X=&\@<75E('9O
M8^H@9&EG:71O=2!NXV\@8V]R<F5S<&]N9&4@86\@=&5X=&\@;F$@=&5L82X`
M4V]M96YT92!O<R!L861O<R!D92!C:6UA(&4@9&4@8F%I>&\`4V]M96YT92!O
M(&QA9&\@9&4@8VEM80!/<R!D861O<R!E;G9I861O<R!F;W)A;2!P97)D:61O
M<R!D97-D92!O('!A<W-O(&%N=&5R:6]R+@!/(&%R<75I=F\@96YV:6%D;R!N
MXV\@</1D92!S97(@<V%L=F\N`$\@8FQO8V\@(G=E871H97(N8V]M(B!NXV\@
M97-TX2!D:7-P;V[M=F5L+@!/(&1I<F5T\W)I;R!D92!T96UA<R`G)7,G(&[C
M;R!F;VD@96YC;VYT<F%D;RX`3N-O(&5X:7-T96T@979E;G1O<R!C;W)R97-P
M;VYD96YT97,@86\@8W)I=.ER:6\@871U86PN`$[C;R!E>&ES=&5M(&]PY_5E
M<R!D:7-P;V[M=F5I<RX`3N-O(&5X:7-T96T@<&%R=&5S('%U92!P;W-S86T@
M<V5R(&5X:6)I9&%S(&EN8V]R<&]R861A<RX`17AI<W1E;2!M=6ET;W,@8V%R
M86-T97)E<R!N97-T92!C86UP;RX@5F]CZB!P<F5E;F-H974@8V]M("5S(&-A
M<F%C=&5R97,[('9O8^H@9&5V92!P<F5E;F-H97(@8V]M("5S(&]U(&UE;F]S
M+@!(;W5V92!U;2!P<F]B;&5M82!A9&EC:6]N86YD;R`G)7,G(&%O('-I<W1E
M;6$Z("5S`$AO=79E('5M('!R;V)L96UA(&%O(&5X8VQU:7(@9&\@<VES=&5M
M82!O<R!D861O<R!D;R!U<W7A<FEO("<E<R<Z(`!(;W5V92!U;2!P<F]B;&5M
M82!A;R!E>&-L=6ER("<E<R<@9&\@<VES=&5M83H@`$AO=79E('5M('!R;V)L
M96UA(&%O(&%T=6%L:7IA<B`G)7,G.B`E<P!(;W5V92!U;2!P<F]B;&5M82!C
M;VT@;R!E;G9I;R!D;R!A<G%U:79O.B!.96YH=6T@)7,@9F]I(&5N=FEA9&\N
M`$AO=79E('5M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\N($\@
M)7,@97)A(&UA:6]R('%U92!O('1A;6%N:&\@;>%X:6UO('!E<FUI=&ED;R`H
M)60@8GET97,I+@!(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A
M<G%U:79O+B!/("5S(&9O:2!E;G9I861O('!A<F-I86QM96YT92X`2&]U=F4@
M=6T@97)R;R!A;R!A8V5S<V%R(&$@86=E;F1A.B`E<P!(;W5V92!U;2!E<G)O
M(&%O(&%D:6-I;VYA<B!O(&5V96YT;SH@)7,`2&]U=F4@=6T@97)R;R!A;R!E
M>&EB:7(@97-T82!P87)T92!D82!M96YS86=E;0!(;W5V92!U;2!E<G)O(&%O
M(&5D:71A<B!O(&5V96YT;SH@)7,`2&]U=F4@=6T@97)R;R!A;R!I;7!O<G1A
M<B!O<R!D861O<R!D;R!C;VYT871O+@!(;W5V92!U;2!E<G)O(&%O(&EM<&]R
M=&%R(&]S(&1A9&]S(&1O(&E#86QE;F1A<BX`2&]U=F4@=6T@97)R;R!N;R!F
M;W)M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('9O8^H@9&5I>&]U
M('5M(&-A;7!O(&]B<FEG873S<FEO(&5M(&)R86YC;RX`2&]U=F4@=6T@97)R
M;R!A;R!M;W9E<B!O(&5V96YT;SH@)7,`2&]U=F4@=6T@97)R;R!A;R!E>&5C
M=71A<B!A(&9U;N?C;R!D92!C873A;&]G;R!D92!E;F1E<F7G;W,@97-P96-I
M9FEC861A+B!0;W(@9F%V;W(@=&5N=&4@;F]V86UE;G1E(&UA:7,@=&%R9&4N
M`$AO=79E('5M(&5R<F\@86\@96YV:6%R('5M82!N;W1I9FEC8>?C;R!D92!E
M=F5N=&\@<&%R82`E<SH@)7,`2&]U=F4@=6T@97)R;R!A;R!A='5A;&EZ87(@
M;W,@9&5T86QH97,@9&\@8V]N=&%T;RX@4&]R(&9A=F]R('1E;G1E(&YO=F%M
M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T=6%L:7IA<B!A
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E;G1E(&YO=F%M
M96YT92!M86ES('1A<F1E+@!.XV\@97AI<W1I86T@979E;G1O<R!P87)A(&5X
M<&]R=&%R+@!%<W1E('-E<G9I9&]R($E-05`@;N-O('-U<&]R=&$@<&%S=&%S
M(&-O;7!A<G1I;&AA9&%S+@!%<W1E(&[C;R!P87)E8V4@<V5R('5M(&%R<75I
M=F\@<F%R(';A;&ED;RX`17-T92!NXV\@<&%R96-E('-E<B!U;2!A<G%U:79O
M('II<"!VX6QI9&\N`$5S=&4@;N-O('!A<F5C92!S97(@=6T@;OIM97)O(&1E
M(&-A<G3C;R!VX6QI9&\N`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@
M;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K
M871E;&PN8V]M*2P@=71I;&EZ86YD;R!A($%022!(5%10`$5S=&4@8V]N96-T
M;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@9V%T97=A
M>2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=71I;&EZ86YD
M;R!O($%022!(5%10`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N
M<V%G96YS(&%T<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PN8V]M*2P@=71I;&EZ86YD;R!O($%022!(5%10`$5S=&4@8V]N
M96-T;W(@<&5R;6ET92!E;G9I87(@=6UA(&UE;G-A9V5M('9I82!33510(&%T
M<F%VZ7,@9&\@5F]D869O;F4@271A;&EA;F\L('-O;65N=&4@<&%R82!N^FUE
M<F]S(%9O9&%F;VYE+B#)(&]B<FEG873S<FEO('!O<W-U:7(@=6UA(&-O;G1A
M(&YO(%9O9&%F;VYE($ET86QI86YO("AH='1P.B\O=W=W+C$Y,"YI="DN`$5S
M=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RX`17-T92!C86UP;R!P;V1E(&-O;G1E
M<B!A<&5N87,@;OIM97)O<R!I;G1E:7)O<RX`17-T92!C86UP;R!P;V1E(&-O
M;G1E<B!A<&5N87,@;OIM97)O<R!E(';M<F=U;&$N`$5S=&4@8V%M<&\@<&]D
M92!C;VYT97(@87!E;F%S('9A;&]R97,@;V-T86ES+@!%<W1E(&-A;7!O(&1E
M=F4@<V5R('5M82!L:7-T82!D92!N^FUE<F]S(&EN=&5I<F]S('-E<&%R861A
M('!O<B!V[7)G=6QA<R!O=2!E<W!AYV]S`$5S=&4@8V%M<&\@9&5V92!S97(@
M=6T@;OIM97)O(';A;&ED;RX`17-T92!C86UP;R!D979E(&-O;G1E<B!U;2!C
M\V1I9V\@9&4@8V]R(&5M(&9O<FUA=&\@4D="($AE>&$L('!O<B!E>&5M<&QO
M("<C,3(S-&%F)RX`17-T92!F;W)M871O(&1E(&%R<75I=F\@;N-O(.D@<W5P
M;W)T861O+@!%<W1E(&9O<FUU;.%R:6\@:N$@9F]I('!R;V-E<W-A9&\N`$ES
M=&\@Z2`E<RX`17-T92#I('5M(&]B:F5T;R!+;VQA8B!'<F]U<'=A<F4N(%!A
M<F$@=FES=6%L:7IA<B!E<W1E(&]B:F5T;R!V;V/J('!R96-I<V%RX2!D92!U
M;2!C;&EE;G1E(&1E(&-O<G)E:6\@<75E(&5N=&5N9&$@;R!F;W)M871O($MO
M;&%B($=R;W5P=V%R92X@4&%R82!U;6$@;&ES=&$@9&4@8VQI96YT97,@9&4@
M8V]R<F5I;R!C;VT@97-T87,@9G5NY_5E<R!P;W(@9F%V;W(@=FES:71E("5S
M`$ES=&\@9F]I(&\@<75E(&\@<V5R=FED;W(@<F5T;W)N;W4Z("5S`$5S=&$@
M;65N<V%G96T@9F]I(&5S8W)I=&$@96T@=6T@8V]N:G5N=&\@9&4@8V%R86-T
M97)E<R`H)7,I('%U92!NXV\@Z2!O(&UE<VUO('%U92!O('-E=2X`17-T92!N
M^FUE<F\@9&5V92!S97(@<&5L;R!M96YO<R!U;2X`17-T92!S97)V:61O<B!N
MXV\@<&]D92!D97-C;VUP<FEM:7(@87)Q=6EV;W,@>FEP(&4@9WII<"X`17-T
M92!S:7-T96UA(&5S=.$@871U86QM96YT92!D97-A=&EV861O+@!%<W1E('9A
M;&]R(&1E=F4@<V5R('5M(&[Z;65R;RX`17-T82!J86YE;&$@9&5V92!S97(@
M8VAA;6%D82!A('!A<G1I<B!D82!J86YE;&$@9&4@3W#G]65S`%)A:6\`475I
M;G1A+49E:7)A`$)I;&AE=&5S`$AO<F$`26YT97)V7V%L;P!!8V]M<&%N:&%M
M96YT;R!D92!(;W+A<FEO`$9O<FUA=&\@9&4@:&]R80!396QEY^-O(&1E(&AO
M<F$`26YT97)V86QO`%1I;6]R($QE<W1E`%]4[71U;&\`5.UT=6QO`$%S<W5N
M=&\@*&1I8V$I.@!087)A`%!A<F$@<V5L96-I;VYA<B!M^FQT:7!L;W,@[71E
M;G,L('-E9W5R92!A('1E8VQA($-O;G1R;VP@*%!#*2!O=2!#;VUM86YD("A-
M86,I(&%O(&-L:6-A<BX`2&]J90!4<F]C87(@<&%R82!C\V1I9V\@2%1-3`!4
M;V=O`%1O:V5L874`06UA;FCC`%1O;F=A`%1O<&\`475A9')O(&1O(%1O<&\@
M*%]T;W`I`%1R861UY_5E<P!4<FEN9&%D92!E(%1O8F%G;P!697)D861E:7)O
M(&]U(&9A;'-O`%1E<@!497+G82U&96ER80!4=6[M<VEA`%1U<G%U:6$`5'5R
M8V\@*$E33RTX.#4Y+3DI`%1U<F-O;65N:7-TXV\`26QH87,@5'5R:W,@92!#
M86EC;W,`5'5V86QU`%1I<&\`4')E96YC:&$@8V]M('-U82!E<V-O;&AA.B``
MS6YD:6-E(%4N5BXZ(`!54DP`55),(&1O('-E=2!R96QA=/-R:6\@9&4@<VET
M=6'GXV\@9&4@96YT<F5G80!54DPZ`%5G86YD80!58W+B;FEA`$EM<&]S<^UV
M96P@86-E<W-A<B!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(&%D:6-I;VYA
M<B!I;F9O<FUAY_5E<R!E>'1R87,@9&4@=7-UX7)I;R!A;R!R96=I<W1R87(N
M`$EM<&]S<^UV96P@86QT97)A<B!P97)M:7-SXV\@9&\@87)Q=6EV;R!61E,@
M(B5S(BX`26UP;W-S[79E;"!A;'1E<F%R('!E<FUI<W/C;R!D;R!A<G%U:79O
M(%9&4R`E<R\E<RX`26UP;W-S[79E;"!A;'1E<F%R('!A<F$@)7,N`$EM<&]S
M<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D;R!A<G%U:79O(&1E("(E<R(N
M`$EM<&]S<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D;R!A<G%U:79O(&1E
M("(E<R\E<R(N`$EM<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@4U%,
M+@!);7!O<W/M=F5L(&-O;F5C=&%R('5T:6QI>F%N9&\@4U-,+@!);7!O<W/M
M=F5L(&-O<&EA<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!C<FEA<B!D:7)E
M=/-R:6\@5D93("(E<R(N`$EM<&]S<^UV96P@8W)I87(@9&ER973S<FEO(%9&
M4RX`26UP;W-S[79E;"!C<FEA<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!R
M96YO;65A<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&-R:6%R(&%R
M<75I=F\@5D93('9A>FEO+@!);7!O<W/M=F5L(&1E<V-O;7!R:6UI<B!D861O
M<RX`26UP;W-S[79E;"!E>&-L=6ER("(E<R(L(&\@9&ER973S<FEO(&[C;R!E
M<W3A('9A>FEO+@!);7!O<W/M=F5L(&5X8VQU:7(@(B5S(CH@)7,`26UP;W-S
M[79E;"!E>&-L=6ER("(E<R(Z("5S+@!);7!O<W/M=F5L(&5X8VQU:7(@)7,L
M(&\@9&ER973S<FEO(&[C;R!E<W3A('9A>FEO`$EM<&]S<^UV96P@97AC;'5I
M<B`E<RX`26UP;W-S[79E;"!E>&-L=6ER(')E8W5R<VEV86UE;G1E(&\@9&ER
M973S<FEO(%9&4RX`26UP;W-S[79E;"!E>&-L=6ER(&1I<F5T\W)I;R!61E,N
M`$EM<&]S<^UV96P@97AC;'5I<B!D:7)E=/-R:6\@5D93.B`E<RX`26UP;W-S
M[79E;"!E>&-L=6ER(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@97AC
M;'5I<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!E>&-L=6ER(&%R<75I=F\@
M5D93("(E<R(N`$EM<&]S<^UV96P@97AC;'5I<B!61E,@<F5C=7)S:79A;65N
M=&4Z("5S+@!);7!O<W/M=F5L(&1E=&5R;6EN87(@;R!D:7)E=/-R:6\@871U
M86PN`$EM<&]S<^UV96P@97AT<F%I<B!D971A;&AE<R!D;R!C97)T:69I8V%D
M;P!);7!O<W/M=F5L(&-A<G)E9V%R(&$@9&5F:6YIY^-O(&1E("5S+@!);7!O
M<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@86)R:7(@
M87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!A8G)I<B!A<G%U:79O(%9&
M4R!P87)A(&=R879AY^-O+@!);7!O<W/M=F5L(&%B<FER(&%R<75I=F\@5D93
M+@!);7!O<W/M=F5L(&%B<FER(&%R<75I=F\@8V]M<')I;6ED;RX`26UP;W-S
M[79E;"!L97(@87)Q=6EV;R!61E,@*&9I;&5S:7IE*"D@9F%L:&]U*2X`26UP
M;W-S[79E;"!L97(@87)Q=6EV;R!61E,@*&=E=$9I;&53:7IE*"D@9F%L:&]U
M*2X`26UP;W-S[79E;"!L97(@;R!A<G%U:79O.B``26UP;W-S[79E;"!L97(@
M82!R86EZ(&1O(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@<F5N;VUE87(@
M(B5S(CH@)7,`26UP;W-S[79E;"!R96YO;65A<B`E<R!P87)A("5S.B!A('!A
M<W1A(&1E(&1E<W1I;F\@:N$@97AI<W1E`$EM<&]S<^UV96P@<F5N;VUE87(@
M;R!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(')E;F]M96%R(&1I<F5T\W)I
M;R!61E,Z("5S+@!);7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93("(E
M<R(N`$EM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,@)7,O)7,N`$EM
M<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@;V)T
M97(@82!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\@9&4@)7,`26UP;W-S[79E
M;"!E>&5C=71A<B`G;6MI<V]F<R<N`$EM<&]S<^UV96P@=')A9'5Z:7(@97-T
M92!D;V-U;65N=&\@5V]R9`!);7!O<W/M=F5L(&=R879A<B!A<G%U:79O(%9&
M4R`B)7,B+@!);7!O<W/M=F5L(&=R879A<B!A<G%U:79O(%9&4R`H8V]P>2@I
M(&9A;&AO=2DN`$EM<&]S<^UV96P@9W)A=F%R(&1A9&]S(&1O(&%R<75I=F\@
M5D93+@!);7!O<W/M=F5L(&=R879A<B!A<G%U:79O(%9&4RP@<75O=&$@97AC
M961E<N$N`%-U8FQI;FAA9&\`1&5S9F%Z97(@06QT97)AY_5E<P!$97-F87H@
M<W5A(/IL=&EM82!AY^-O`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED
M;W(@9'5R86YT92!A(&-O;F5XXV\Z(`!297-P;W-T82!I;F5S<&5R861A(&1O
M('-E<G9I9&]R('!A<F$Z(`!396T@8V%T96=O<FEA`%5N:6-O9&4@*%541BTX
M*0!%;6ER861O<R#!<F%B97,@56YI9&]S`%)E:6YO(%5N:61O`$5S=&%D;W,@
M56YI9&]S`$EL:&%S(%!E<FEFZ7)I8V%S($UE;F]R97,@9&]S($5S=&%D;W,@
M56YI9&]S`%5N:61A9&5S`$1E<V-O;FAE8VED;P!A<&EM<V=I9"!D97-C;VYH
M96-I9&\@*$%022!-97-S86=E($E$*2X`8VQI;7-G:60@9&5S8V]N:&5C:61O
M("A#;&EE;G0@365S<V%G92!)1"DN`$YE;FAU;6$@;&]C86QI>F'GXV\@8V]N
M9FEG=7)A9&$N`%5S=>%R:6\@;W4@<V5N:&$@9&5S8V]N:&5C:61O<RX`1&5S
M=FEN8W5L87(@;R!E;&5M96YT;R!A='5A;`!396T@3F]M90!38W)I<'1S(&[C
M;R!P<FEV:6QE9VEA9&]S(&[C;R!P;V1E;2!U=&EL:7IA<B!#;W)T87(O0V]P
M:6%R+T-O;&%R('!O<B!R87KU97,@9&4@<V5G=7)A;N=A+B!#;&EQ=64@96T@
M3TL@<&%R82!V97(@82!N;W1A('3I8VYI8V$@96T@;6]Z:6QL82YO<F<@82!Q
M=6%L(&5N<VEN82!C;VUO('!E<FUI=&ER('-C<FEP=',@86-E<W-A<F5M(&$@
MX7)E82!D92!T<F%N<V9E<NIN8VEA+@!$97-M87)C87(@8V]R`$-O;G1E;G0M
M5'EP92!NXV\@<W5P;W)T861O.B`E<P!%>'1E;G/C;R!.XV\@4W5P;W)T861A
M`$%T=6%L:7IA<@`E<R!A='5A;&EZ861O`$%T=6%L:7IA<B!U<W7A<FEO`"<E
M<R<@871U86QI>F%D;RX`071U86QI>F%D;SH@)7,N`%-C<FEP="!D92!A='5A
M;&EZ8>?C;R!R96UO=FED;RX`16YV:6%R`%1O9&]S(&%R<75I=F]S(&1E("!C
M;VYF:6=U<F'G]65S(&1A<R!A<&QI8V'G]65S(&9O<F%M(&5N=FEA9&]S(&%O
M('-E<G9I9&]R+@!!;&9A8F5T;R!L871I;F\@96T@;6%I^G-C=6QO`$[Z;65R
M;W,@<F]M86YO<R!E;2!M86GZ<V-U;&\`57)U9W5A:0!5=&EL:7IA<B!!='5A
M;#H@)7,`571I;&EZ87(@4U-,`%5T:6QI>F%R('-E(&\@;F]M92]S96YH82#I
M(&1I9F5R96YT92!N;R!S97)V:61O<B!)35-0+@!5<W7A<FEO<P!5<W7A<FEO
M("5S(&[C;R!E<W3A(&%U=&]R:7IA9&\@<&%R82`E<RX`061M:6YI<W1R8>?C
M;R!D92!5<W7A<FEO<P!);G1E<F9A8V4@9&\@57-UX7)I;P!/<.?U97,@9&4@
M57-UX7)I;W,`4F5G:7-T<F\@9&4@57-UX7)I;W,`4F5G:7-T<F\@9&4@57-U
MX7)I;W,@97-TX2!D97-A8FEL:71A9&\@;F5S=&4@<VET92X`0V]N=&$@9&4@
M=7-UX7)I;R!NXV\@96YC;VYT<F%D80!5<W7A<FEO`%5S=>%R:6\@)R5S)R!J
MX2!E>&ES=&4N`%5S=>%R:6\Z`%5S=>%R:6\Z(`!5<W7A<FEO<R!N;R!S:7-T
M96UA.@!5>F)E<75I<W3C;P!/(&1I<F5T\W)I;R!61E,@;N-O(&5X:7-T92X`
M1NER:6%S`$QO8V%L:7IAY_5E<R!VX6QI9&%S(&5N8V]N=')A9&%S(&EN8VQU
M96TZ(`!686QI9&%D90!686QO<B!E;2!M:6YU=&]S(&$@<&%R=&ER(&1E(&%G
M;W)A+@!/('9A;&]R(&5S=.$@86-I;6$@9&\@=&%M86YH;R!MX7AI;6\@9&4@
M)7,N`%9A;&]R97,`5F%L;W)E<R!P87)A('-E;&5C:6]N87(`5F%N=6%T=0!6
M87)IX79E;`!696YE>G5E;&$`1F%L:&$@;F$@=F5R:69I8V'GXV\@+2!E<W1A
M(&UE;G-A9V5M('!O9&4@=&5R('-I9&\@861U;'1E<F%D82X`5F5R<^-O`$-O
M;G1R;VQE(&1E(%9E<G/C;P!!;&EN:&%M96YT;R!V97)T:6-A;`!-87)G96T@
M=F5R=&EC86P`5F5R=&EC86PZ`$UU:71O($%L=&$`5FEE=&[C`%9I971N86UI
M=&$@*%9)4T-)22D`5F5R("5S`%9I<W5A;&EZ8>?C;R!$:>%R:6$`5FES=6%L
M:7IA<B!U;6$@<.%G:6YA('=E8B!E>'1E<FYA`%9I<W5A;&EZ87(@8V]M;R`E
M<P!);&AA<R!6:7)G96YS+"!"<FETXFYI8V%S`$EL:&%S(%9I<F=E;G,L($4N
M52Y!+@!6:7-I8FEL:61A9&4`5FES:6)I;&ED861E.B``5F]D869O;F4@271A
M;&EA;F\@=FEA(%--5%``051%3L?#3P!!5$5.Q\-/(2$A(%)%34]602!/(%-#
M4DE05"!-04Y504Q-14Y412!$12`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!E
M($9U='5N80!!=&5NY^-O`%%U80!0<F5V:7/C;R!D;R!496UP;P!$861O<R!D
M;R!#;&EM82!F;W)N96-I9&\@<&]R`%=E871H97(N8V]M`%=E8@!3:71E(%=E
M8@!1=6%R=&$M1F5I<F$`4V5M86YA`%-E;6%N82`E9`!396UA;F$H<RD`4V5M
M86YA;&UE;G1E`%-E;6%N86QM96YT93H@4F5P971E(&$@8V%D80!"96TM=FEN
M9&\`0F5M+79I;F1O(&%O("5S`$)E;2UV:6YD;RP@)7,`3V-I9&5N=&%L("A)
M4T\M.#@U.2TQ*0!/8VED96YT86P@*$E33RTX.#4Y+3$U*0!386AA<F$@3V-I
M9&5N=&%L`%%U92!A<&QI8V'GXV\@)7,@9&5V97)I82!E>&EB:7(@87#S<R!A
M(&-O;F5XXV\_`%%U86P@;R!C87)A8W1E<F4@9&5L:6UI=&%D;W(_`%%U86P@
M;R!C87)A8W1E<F4@9&4@8VET8>?C;S\`02!Q=64@:&]R87,@9&5V97+C;R!F
M:6YA;&EZ87(@87,@=FES=6%L:7IAY_5E<R!D92!D:6$@92!S96UA;F$L('%U
M86YD;R!NXV\@:&]U=F5R(&5V96YT;W,@;6%I<R!T87)D93\`02!Q=64@:&]R
M87,@9&5V97+C;R!I;FEC:6%R(&%S('9I<W5A;&EZ8>?U97,@9&4@9&EA(&4@
M<V5M86YA+"!Q=6%N9&\@;N-O(&AO=79E<B!E=F5N=&]S(&UA:7,@8V5D;S\`
M36%P87,@075S=')A;&EA;F]S(%=H97)E:7,`475A:7,@9F%S97,`475A:7,@
M<&QU9VEN<R!H86)I;&ET87(@<&%R82!O(&5D:71O<B!2:6-H(%1E>'0N`$QA
M<F=U<F$`3&%R9W5R82!E;2!U;FED861E<R!#4U,`3&%R9W5R82!D;R!M96YU
M("5S(&1O(&QA9&\@97-Q=65R9&\@*'1E<N$@969E:71O(&YA('!R\WAI;6$@
M8V]N97CC;RDZ`$QA<F=U<F$@9&$@=&%B96QA`%5N:61A9&4@9&4@3&%R9W5R
M80!,87)G=7)A.@!7:6MI`%9E;G1O`%9E;G1O<R!P96QA(&UA;FCC`%9E;&]C
M:61A9&4@9&\@=F5N=&\@96T@;O-S`%9E;G1O.@!696YT;SH@`%-A8F5D;W)I
M80!,:7-T82!D92!P961I9&]S`%1R86)A;&AO`$5N9&5R9>=O($-O;65R8VEA
M;`!&;VYE($-O;65R8VEA;`!$:6%S($-O;65R8VEA:7,`3OIM97)O(&EN8V]R
M<F5T;R!D92!C86UP;W,@;F$@;&EN:&$@)60N($5S<&5R861O<R`E9"P@96YC
M;VYT<F%D;W,@)60N`$[Z;65R;R!E<G)A9&\@9&4@8V%M<&]S+B!%<W!E<F%D
M;W,@)60L(&5N8V]N=')A9&]S("5D+@!/9F9S970@)60@:6YC;W)R971O(&%O
M(&QE<B!O(&%R<75I=F\@5D93+@!8+5)E9@!297-T<FGG]65S($+A<VEC87,@
M6#4P.78S`%5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U,#EV,P!.
M;VUE($%L=&5R;F%T:79O(&1E($%S<W5N=&\@6#4P.78S`$ED96YT:69I8V%D
M;W(@9&$@0VAA=F4@9&4@07-S=6YT;R!8-3`Y=C,`17AT96YS]65S(%@U,#EV
M,P!!00!!04%!`$UA<&$@66%H;V\A`$%N;P!!;G5A;&UE;G1E`$%N=6%L.B!R
M97!E=&4@82!C861A`$SJ;65N`%-I;0!3:6TL($5U($-O;F-O<F1O`%9O8^H@
M97-TX2!E;2!-3T1/(%1%6%1/+B`@571I;&EZ82!O(&)O=.-O(%L\/ET@<&%R
M82!V;VQT87(@<&%R82!O(&UO9&\@5UE325=91RX`5F]CZB!NXV\@97-TX2!A
M=71O<FEZ861O(&$@8W)I87(@;6%I<R!D92`E9"!B;&]C;W,N`%9O8^H@;N-O
M(&5S=.$@875T;W)I>F%D;R!A(&-R:6%R(&UA:7,@<75E("5D(&5V96YT;W,N
M`%9O8^H@;N-O(.D@=6T@<&%R=&EC:7!A;G1E(&1O(&5V96YT;R!E<W!E8VEF
M:6-A9&\N`%9O8^H@;N-O(&5S=.$@875T96YT:6-A9&\N`%9O8^H@<&]D92!U
M=&EL:7IA<B!E<W1E(&9O<FUU;.%R:6\@<V]M96YT92!A('!A<G1I<B!D82!T
M96QA($5D:71A<B!087)T:6-I<&%N=&5S+@!6;V/J(&[C;R!P;V1E('1E<B!O
M(&-A<F%C=&5R(%P@;F\@<V5U(&YO;64N`%9O8^H@;N-O(&9O<FYE8V5U('5M
M(&5N9&5R9>=O(&1E(&4M;6%I;"!VX6QI9&\N`%9O8^H@;N-O(&UA<&5O=2!N
M96YH=6T@8V%M<&\@9&\@87)Q=6EV;R!I;7!O<G1A9&\@86]S(&-A;7!O<R!C
M;W)R97-P;VYD96YT97,@96T@)7,N`%9O8^H@;N-O('1E;2!U;2!E;F1E<F7G
M;R!D92!E+6UA:6P@8V]N9FEG=7)A9&\@;F%S('-U87,@3W#G]65S(&1E($EN
M9F]R;6'G]65S(%!E<W-O86ES+B!6;V/J(&1E=F4@9&5F:6YI<B!U;2`E<V%Q
M=6DE<R!A;G1E<R!D92!E;G9I87(@87,@;F]T:69I8V'G]65S(&1E(&5V96YT
M;W,N`%9O8^H@;N-O('1E;2!P97)M:7-SXV\@9&4@861I8VEO;F%R(&5V96YT
M;W,@96T@)7,N`%9O8^H@;N-O('1E;2!P97)M:7-S]65S(&1E(&%D:6-I;VYA
M<B!E=F5N=&]S(&YA(&%G96YD82!S96QE8VEO;F%D82X`5F]CZB!NXV\@=&5M
M('!E<FUI<W/C;R!D92!E>&-L=6ER(&5S=&4@979E;G1O+@!6;V/J(&[C;R!T
M96T@<&5R;6ES<^-O(&1E(&5D:71A<B!E<W1E(&5V96YT;RX`5F]CZB!F;VD@
M9&5S8V]N96-T861O+@!6;V/J(&5S<&5C:69I8V]U('5M82!A9V5N9&$@:6YV
MX6QI9&$N`%9O8^H@86-E:71O=2!A('!A<G1I8VEP8>?C;R!N97-T92!E=F5N
M=&\N`%9O8^H@<F5C=7-O=2!A('!A<G1I8VEP8>?C;R!N97-T92!E=F5N=&\N
M`%9O8^H@86-E:71O=2!P<F]V:7-O<FEA;65N=&4@<&%R=&EC:7!A<B!D97-T
M92!E=F5N=&\N`%9O8^H@9&5V92!P<F5E;F-H97(@=6T@;OIM97)O(&1E('1E
M;&5F;VYE(&-E;'5L87(@=N%L:61O+"!S;VUE;G1E(&3M9VET;W,@8V]M('5M
M(&]P8VEO;F%L("<K)R!P87)A(&1I<V-A9V5M(&1E('!R969I>&\@:6YT97)N
M86-I;VYA;"X`5F]CZB!D979E('!R965N8VAE<B!U;2!V86QO<B!VX6QI9&\N
M`%9O8^H@9&5V92!C;VYF:6=U<F%R('5M(&-O;F5C=&]R($1A=&%4<F5E('!A
M<F$@=71I;&EZ87(@0V%D87-T<F]S+@!6;V/J(&1E=F4@8V]N9FEG=7)A<B!U
M;2!C;VYE8W1O<B!61E,N`%9O8^H@9&5V92!D97-C<F5V97(@;R!P<F]B;&5M
M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R:6\@9&4@<')O8FQE;6$N`%9O
M8^H@9&5V92!F;W)N96-E<B!A(%523"!O;F1E(&\@;&EN:R!A<&]N=&$`5F]C
MZB!D979E('-E;&5C:6]N87(@=6UA(&%G96YD82!P87)A(&5X8VQU:7(N`%9O
M8^H@9&5V92!S96QE8VEO;F%R('5M(&5N9&5R9>=O('!R:6UE:7)O+@!6;V/J
M(&1E=F4@<V5L96-I;VYA<B!U;2!S97)V:61O<B!P87)A('-E<B!E>&-L=>UD
M;RX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R82!E>&-L
M=6ER+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(')E
M;6]V97(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@
M861I8VEO;F%R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P
M87)A(&%T=6%L:7IA<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M82!AY^-O
M('!A<F$@97AE8W5T87(N`%9O8^H@9&5V92!P<F5E;F-H97(@=6T@;F]M92!P
M87)A(&$@;F]V82!C871E9V]R:6$N`%9O8^H@<')E8VES82!F;W)N96-E<B!U
M;2!N^FUE<F\@9&4@=&5L969O;F4@:71A;&EA;F\`5F]CZB!S;VQI8VET;W4@
M<V5R(&YO=&EF:6-A9&\@<75A;F1O(&5V96YT;W,@<^-O(&%D:6-I;VYA9&]S
M(&5M('-U87,@86=E;F1A<RX`5F]CZB!S;VQI8VET;W4@<V5R(&YO=&EF:6-A
M9&\@<75A;F1O(&5V96YT;W,@<^-O(&5X8VQU[61O<R!D92!S=6%S(&%G96YD
M87,N`%9O8^H@<V]L:6-I=&]U('-E<B!N;W1I9FEC861O('%U86YD;R!E=F5N
M=&]S('/C;R!E9&ET861O<R!E;2!S=6%S(&%G96YD87,N`%9O8^H@<V]L:6-I
M=&]U('-E<B!A=FES861O('-O8G)E("5S+"!Q=64@<V5RX2!E;2`E<R`@X',@
M)7,N`%-U82!S97-SXV\@)7,@97AP:7)O=2X@4&]R(&9A=F]R+"!C;VYE8W1E
M+7-E(&YO=F%M96YT92X`4V5U($5N9&5R9>=O(&1E($4M;6%I;`!3974@16YD
M97)EYV\@9&4@4F5M971E;G1E("A$93HI.@!3=6%S($EN9F]R;6'G]65S`%-E
M=2!%;F1E<F7G;R!D92!);G1E<FYE="!M=61O=2!D97-D92!O(&EN[6-I;R!D
M92!S=6$@<V5S<^-O("5S+B!087)A('!R;W1E9V5R('-U82!S96=U<F%NYV$@
M=F]CZB!D979E(&-O;F5C=&%R+7-E(&YO=F%M96YT92X`4V5U($YO;64`4V5U
M(&)A8VME;F0@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&%D:>?C;R!D
M92!U<W7A<FEO<RP@;W4@82!F=6[GXV\@9F]I(&1E<V%B:6QI=&%D82!P;W(@
M86QG=6UA(&]U=')A(')A>N-O+@!3974@8F%C:V5N9"!D92!A=71E;G1I8V'G
MXV\@;N-O('-U<&]R=&$@;&ES=&%G96T@9&4@=7-UX7)I;W,L(&]U(&$@9G5N
MY^-O(&9O:2!D97-A8FEL:71A9&$@<&]R(&%L9W5M82!O=71R82!R87KC;RX`
M4V5U(&YA=F5G861O<B!P87)E8V4@=&5R(&%L=&5R861O(&1E<V1E(&\@:6[M
M8VEO(&1E('-U82!S97-SXV\@)7,N(%!A<F$@<')O=&5G97(@<W5A('-E9W5R
M86[G82P@=F]CZB!D979E(&-O;F5C=&%R+7-E(&YO=F%M96YT92X`4V5U(&YA
M=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&9U;N?C;RX`4V5U(&YA=F5G861O
M<B!NXV\@<W5P;W)T82!E<W1A(&]PY^-O(&1E(&EM<')E<W/C;RX@4')E<W-I
M;VYE($-O;G1R;VPO3W!T:6]N("L@4"!P87)A(&EM<')I;6ER+@!3974@9G5S
M;R!H;W+A<FEO(&%T=6%L.@!3=6$@86=E;F1A('!A9'+C;P!3=6$@:61E;G1I
M9&%D92!P861RXV\@9F]I(&%L=&5R861A+@!3=6$@:61E;G1I9&%D92!P861R
MXV\Z`%-E=2!N;VUE(&-O;7!L971O.@!3=6$@8V]N97CC;R!E>'!I<F]U+@!3
M=6$@;F]V82!S96YH82!P87)A("5S(.DZ("5S`%-U87,@;W#G]65S(&9O<F%M
M(&%T=6%L:7IA9&%S('!O<B!C875S82!D82!D=7)AY^-O(&1E<W1A('-E<W/C
M;RX`4W5A<R!O<.?U97,@9F]R86T@871U86QI>F%D87,N`%-U82!N;W9A('-E
M;FAA(&9O:2!G97)A9&$`4W5A(&YO=F$@<V5N:&$@9F]I(&=E<F%D82P@=F5R
M:69I<75E('-E=2!E+6UA:6P@92!C;VYE8W1E+7-E(&-O;2!S=6$@;F]V82!S
M96YH82X`4W5A('-E;FAA(&5X<&ER;W4N`%-E=7,@<V5R=FED;W)E<R!R96UO
M=&]S.@!)=6=O<VSA=FEA`%IA:7)E`%KB;6)I80!::6UB86)W90!::7!P>0!;
M3V-U;'1A<B!497AT;R!#:71A9&]=`%M296QA=/-R:6\@9&4@4')O8FQE;6%=
M`%M%>&EB:7(@5&5X=&\@0VET861O("T`6T5X:6)I<B!497AT;R!#:71A9&\@
M+2`E<R!L:6YH87-=`%M%=F5N=&\@<V5M(&YO;65=`%ML:6YH82`E<R!D92`E
M<UT`7T%D;6EN:7-T<F'GXV\`079I<V\`4&5S<75I<V$@7U-I;7!L97,`7T-,
M20!$871A7U1R964`15]X8VQU:7(@0V]L=6YA`%]%9&ET87(`7TER(%!A<F$`
M7T=R=7!O<P!!7VIU9&$`4')O<')I961A9&5S(&1A(%]);6%G96TN+BX`26UP
M;W)T87(O15]X<&]R=&%R`%]#;VYE8W1A<@!?1&5S8V]N96-T87(`05]L=&5R
M87(@3&EN:RXN+@!-:6YH87,@7T%G96YD87,`7TYO=F\@179E;G1O`%]/<.?U
M97,`7U!E<FUI<W/U97,`25]M<')I;6ER`%]296UO=F5R($QI;FLN+BX`7U!E
M<W%U:7-A<@!#;VYF:6=U<F%?<@!0<F]P<FEE9&%D97,@9&$@7U1A8F5L82XN
M+@!?2&]J90!?57-UX7)I;W,`8V%TX6QO9V\@9&4@96YD97)EYV]S`&-A=.%L
M;V=O(&1E(&5N9&5R9>=O<P!A;G1E<R!D92!I;FEC:6%R(&\@979E;G1O`&%G
M96YD80!C86QM;P!I;7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@9&4@9&5S=&EN
M;P!I;7!O<W/M=F5L(&%B<FER(&$@;W)I9V5M`&-L:7%U92!A<75I`&5R<F\@
M9&4@<VEN=&%X92!D82!L:6YH82!D92!C;VUA;F1O`&5R<F\@9&4@8V]N9FEG
M=7)AY^-O`'5M(&%R<75I=F\@8W+M=&EC;R!D;R!S:7-T96UA(&5S=.$@9F%L
M=&%N9&\`97)R;R!N;R!F;W)M871O(&1O<R!D861O<P!D:6$`9&EA*',I`&1I
M87,`961I=&%R`')E9VES=')O(&[C;R!E;F-O;G1R861O`&5V96YT;W,N8W-V
M`&5V96YT;W,N:6-S`'%U961A`&%R<75I=F\`9&4`82!P87)T:7(@9&4@)7,@
M*"5S*2#@("5S("5S`&)R:7-A`&@Z`&AH`&YO;64@9&\@:&]S="#I(&1E<V-O
M;FAE8VED;P!I;65D:6%T;P!I;F-O<G!O<F%D;P!E<G)O(&1E(&5N=')A9&$O
M<V'M9&$`97)R;R!I;G1E<FYO(&1O('!R;V=R86UA`&QI;FAA<UT`8_-D:6=O
M(&1E(&5R<F\@)60@9&\@;6MI<V]F<R!E;G%U86YT;R!G97)A=F$@82!)4T\N
M`&UM`&WJ<RAE<RD`;F]M90!NXV\@:6UP;&5M96YT861O`&[C;R!I;7!L96UE
M;G1A9&\@86EN9&$`8FQO8V\@9&4@;F]T87,`96T@)7,@X',@)7,`;F$@;65S
M;6$@9&%T80!N82!M97-M82!S96UA;F$`<&]R8V5N=&%G96T`4&5R;6ES<^-O
M`'!I>&5L<P!E<G)O(')E;6]T;R!N;R!P<F]T;V-O;&\`;F%S8V5N=&4`<V5R
M=FGG;R!I;F1I<W!O;NUV96P`97AI8FER(&1I9F5R96[G87,`<VUS,F5M86EL
M('9I82!(5%10`'-S`&5S=.%V96P`97)R;R!D92!S:7-T96UA`&QI<W1A(&1E
M('1A<F5F87,`9F%L:&$@=&5M<&]RX7)I80!P<F5E;F-H82!S=6$@<V5N:&$@
M9'5A<R!V97IE<R!P87)A(&-O;F9I<FUA<@!U;FEF:6-A9&\`<V5M(&YO;64`
M<V5L9>?C;R!D92!U<W7A<FEO`'9#86QE;F1A<B]I0V%L96YD87(`=D-A<F0`
M=D5V96YT(&[C;R!E;F-O;G1R861O+@!W.@!W96%T:&5R+F-O;0!S96UA;F$`
M<V5M86YA*',I(&5M.@!S96UA;F%S`&%N;RAS*0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]L;V-A;&4O<'1?0E(O:&5L<"YX;6P`````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,C0W,S(`,3`T,3<S-C(W-3(`,#(R,S8P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_>&UL('9E<G-I;VX]
M(C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3$B/SX*/"$M+2`D2&]R9&4Z(&MR
M;VYO;&ET:"]L;V-A;&4O<'1?0E(O:&5L<"YX;6PL=B`Q+C$@,C`P-"\Q,2\P
M-"`R,#HR,#HU-2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M3W9E<G9I97<B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y+<F]N;VQI
M=&@Z(%9I<^-O($=E<F%L/"]T:71L93X*("`@(#QH96%D:6YG/D\@<75E(.D@
M:W)O;F]L:71H/SPO:&5A9&EN9SX*("`@(#QP87)A/@I+<F]N;VQI=&@@Z2!U
M;2!C86QE;F3A<FEO(&1E(&EN=&5R9F%C92!796(N($5M(&%D:>?C;R!A<R!F
M=6[G]65S(&YE8V5S<^%R:6%S(&1E(&-R:6'GXV\L(&UO9&EF:6-AY^-O(&4@
M<F5M;^?C;R!D92!E=F5N=&]S+"!E;&4@871U86QM96YT92!S=7!O<G1A(')E
M<&5T:>?C;R!D92!E=F5N=&]S("AC;VT@97AC97-S]65S(&4@=N%R:6%S(&]P
MY_5E<R!D92!R96UOY^-O*2P@86QA<FUE<RP@9G5NY_5E<R!D92!I;7!O<G1A
MY^-O(&4@97AP;W)T8>?C;RP@=FES=6%L:7IAY^-O(&1A($QI<W1A(&1E(%1A
M<F5F87,@*$YA9RP@<V4@97-T:79E<B!I;G-T86QA9&\I+"!E(&$@<&]S<VEB
M:6QI9&%D92!D92!M;W-T<F%R(&]S(&5V96YT;W,@;F$@=&5L82!D92!S=6WA
M<FEO(&1O($AO<F1E+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ
M"CQE;G1R>2!I9#TB3W9E<G9I97<B/@H@("`@/'1I=&QE/DMR;VYO;&ET:#H@
M3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE861I;F<^5VAA="!I<R!K<F]N;VQI
M=&@_/"]H96%D:6YG/@H@("`@/'!A<F$^"DMR;VYO;&ET:"!I<R!A('=E8BUB
M87-E9"!C86QE;F1A<B!A<'!L:6-A=&EO;BX@($EN(&%D9&ET:6]N('1O('1H
M92!R97%U:7)E9"!F=6YC=&EO;G,@;V8@8W)E871I;F<L(&UO9&EF>6EN9RP@
M86YD(&1E;&5T:6YG(&5V96YT<RP@:70@8W5R<F5N=&QY('-U<'!O<G1S(')E
M8W5R<FEN9R!E=F5N=',@*'=I=&@@97AC97!T:6]N<R!A;F0@=F%R:6]U<R!D
M96QE=&EO;B!O<'1I;VYS*2P@86QA<FUS+"`@:6UP;W)T(&%N9"!E>'!O<G0@
M9G5N8W1I;VYS("AI0V%L96YD87(@86YD(%!A;&T@1&%T84)O;VL@*%!$0BD@
M9F]R;6%T<RDL(&E#86QE;F1A<B!I;G9I=&%T:6]N<RP@;75L=&EP;&4@8V%L
M86YD97(@=FEE=W,L('-H87)E9"!C86QE;F1A<G,L(&1I<W!L87D@;V8@5&%S
M:R!,:7-T("A.86<I('1A<VMS("AI9B!487-K<R!,:7-T(&ES(&EN<W1A;&QE
M9"DL(&%N9"!A8FEL:71Y('1O('-H;W<@979E;G1S(&EN('1H92!(;W)D92!S
M=6UM87)Y('-C<F5E;BX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB;65N=2UT;V1A>2(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/DUE;G4Z($AO:F4\+W1I=&QE/@H@("`@/&AE861I;F<^2&]J
M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3R!I=&5M(&1E(&UE;G4@/&D^
M2&]J93PO:3X@;6]S=')A<N$@<W5A(&5X:6)IY^-O('!A9'+C;R`H;>IS+"!S
M96UA;F$L(&1I82P@971C+B!#;VUO(&-O;F9I9W5R861O(&5M($]PY_5E<RD@
M<&%R82!A(&1A=&$@871U86PN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E
M;G1R>3H*/&5N=')Y(&ED/2)M96YU+71O9&%Y(CX*("`@(#QT:71L93Y-96YU
M.B!4;V1A>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY4;V1A>3PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AE(#QI/E1O9&%Y/"]I/B!M96YU(&ET96T@=VEL
M;"!D:7-P;&%Y('EO=7(@9&5F875L="!V:65W("AM;VYT:"P@=V5E:RP@9&%Y
M+"!E=&,N(&%S('-E="!I;B!/<'1I;VYS*2!F;W(@=&AE(&-U<G)E;G0@9&%T
M92X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB;65N=2U';W1O(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365N
M=3H@27(@4&%R83PO=&ET;&4^"B`@("`\:&5A9&EN9SY)<B!087)A/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!/(&ET96T@9&4@;65N=2`\:3Y)<B!087)A
M/"]I/B!M;W-T<F%RX2!U;6$@<&5Q=65N82!J86YE;&$@<&]P+75P(&YA('%U
M86P@=F]CZB!P;V1E(')A<&ED86UE;G1E('-E;&5C:6]N87(@;R!A;F\L(&WJ
M<RP@<V5M86YA(&1O(&%N;RP@;W4@9&EA(&1O(&WJ<R!P87)A(#QI/FER('!A
M<F$\+VD^+B!%<W1A(.D@9V5R86QM96YT92!A(&9O<FUA(&UA:7,@<N%P:61A
M(&1E(&UO=F5R+7-E(&YO(&-A;&5N9.%R:6\N"B`@("`\+W!A<F$^"CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU+4=O=&\B/@H@("`@/'1I
M=&QE/DUE;G4Z($=O=&\\+W1I=&QE/@H@("`@/&AE861I;F<^1V]T;SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(#QI/D=O=&\\+VD^(&UE;G4@:71E
M;2!W:6QL(&1I<W!L87D@82!S;6%L;"!P;W`M=7`@=VEN9&]W(&EN('=H:6-H
M('EO=2!C86X@<75I8VML>2!S96QE8W0@82!Y96%R+"!M;VYT:"P@=V5E:R!O
M9B!T:&4@>65A<BP@;W(@9&%Y(&]F('1H92!M;VYT:"!T;R`\:3YG;R!T;SPO
M:3XN("!4:&ES(&ES('5S=6%L;'D@=&AE('%U:6-K97-T('=A>2!T;R!M;W9E
M('=I=&AI;B!T:&4@8V%L96YD87(N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^
M/"]E;G1R>3X*("`\96YT<GD@:60](FUE;G4M1&%Y(B!S=&%T93TB=6YK;F]W
M;B(^"B`@("`\=&ET;&4^365N=3H@1&EA/"]T:71L93X*("`@(#QH96%D:6YG
M/D5X:6)IY^-O($1I83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3R!I=&5M
M(&1E(&UE;G4@/&D^1&EA/"]I/B!M;W-T<F%RX2!A(&5X:6)IY^-O("=$:6$G
M(&1O(&1I82!A='5A;&UE;G1E('-E;&5C:6]N861O+@H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB;65N=2U$87DB/@H@("`@
M/'1I=&QE/DUE;G4Z($1A>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY$87D@5FEE
M=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(#QI/D1A>3PO:3X@;65N
M=2!I=&5M('=I;&P@9&ES<&QA>2!T:&4@9&%Y('9I97<@;V8@=&AE(&-U<G)E
M;G1L>2!S96QE8W1E9"!D87DN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E
M;G1R>3X*("`\96YT<GD@:60](FUE;G4M=V]R:RUW965K(B!S=&%T93TB=6YK
M;F]W;B(^"B`@("`\=&ET;&4^365N=3H@0V]M97)C:6%L/"]T:71L93X*("`@
M(#QH96%D:6YG/D5X:6)IY^-O($-O;65R8VEA;#PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@3R!I=&5M(&1E(&UE;G4@/&D^0V]M97)C:6%L/"]I/B!M;W-T
M<F%RX2!A(&5X:6)IY^-O("=#;VUE<F-I86PG("A396=U;F1A(.`@4V5X=&$I
M(&UA:7,@<'+S>&EM82!A;R!D:6$@871U86QM96YT92!S96QE8VEO;F%D;RX*
M("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](FUE
M;G4M=V]R:RUW965K(CX*("`@(#QT:71L93Y-96YU.B!7;W)K(%=E96L\+W1I
M=&QE/@H@("`@/&AE861I;F<^5V]R:R!7965K(%9I97<\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1H92`\:3Y7;W)K(%=E96L\+VD^(&UE;G4@:71E;2!W
M:6QL(&1I<W!L87D@=&AE('=O<FL@=V5E:R!V:65W("A-;VYD87D@=&AR;W5G
M:"!&<FED87DI(&-L;W-E<W0@=&\@=&AE(&-U<G)E;G1L>2!S96QE8W1E9"!D
M87DN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](FUE;G4M=V5E:R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE
M;G4Z(%-E;6%N83PO=&ET;&4^"B`@("`\:&5A9&EN9SY%>&EB:>?C;R!396UA
M;F$\+VAE861I;F<^"B`@("`\<&%R83X*("`@($\@:71E;2!D92!M96YU(#QI
M/E-E;6%N83PO:3X@;6]S=')A<N$@82!E>&EB:>?C;R`G4V5M86YA)R`H97AI
M8FGGXV\@9&]S(#<@9&EA<RD@9&$@<V5M86YA(&-O;G1E;F1O(&\@9&EA(&%T
M=6%L;65N=&4@<V5L96-I;VYA9&\N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES
M:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU+7=E96LB/@H@("`@/'1I=&QE/DUE
M;G4Z(%=E96L\+W1I=&QE/@H@("`@/&AE861I;F<^5V5E:R!6:65W/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@/&D^5V5E:SPO:3X@;65N=2!I=&5M
M('=I;&P@9&ES<&QA>2!T:&4@=V5E:R!V:65W("@W(&1A>2!V:65W*2!F;W(@
M=&AE('=E96L@8V]N=&%I;FEN9R!T:&4@8W5R<F5N=&QY('-E;&5C=&5D(&1A
M>2X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB;65N=2UM;VYT:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE
M;G4Z($WJ<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%>&EB:>?C;R!-ZG,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($\@:71E;2!D92!M96YU(#QI/DWJ<SPO
M:3X@;6]S=')A<N$@82!E>&EB:>?C;R`G3>IS)R!D;R!MZG,@8V]N=&5N9&\@
M;R!D:6$@871U86QM96YT92!S96QE8VEO;F%D;RX*("`@(#PO<&%R83X*/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](FUE;G4M;6]N=&@B/@H@("`@
M/'1I=&QE/DUE;G4Z($UO;G1H/"]T:71L93X*("`@(#QH96%D:6YG/DUO;G1H
M(%9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92`\:3Y-;VYT:#PO
M:3X@;65N=2!I=&5M('=I;&P@9&ES<&QA>2!T:&4@;6]N=&@@=FEE=R!F;W(@
M=&AE(&UO;G1H(&-O;G1A:6YI;F<@=&AE(&-U<G)E;FQY('-E;&5C=&5D(&1A
M>2X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB;65N=2UN97<M979E;G0B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L
M93Y-96YU.B!.;W9O($5V96YT;SPO=&ET;&4^"B`@("`\:&5A9&EN9SY!9&EC
M:6]N86YD;R!U;2!.;W9O($5V96YT;SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@3R!I=&5M(&1E(&UE;G4@/&D^3F]V;R!%=F5N=&\\+VD^('!E<FUI=&4@
M=F]CZB!C<FEA<B!U;2!N;W9O(&5V96YT;R!P87)A('-E<B!A9&EC:6]N861O
M(&%O(&-A;&5N9.%R:6\N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R
M>3H*/&5N=')Y(&ED/2)M96YU+6YE=RUE=F5N="(^"B`@("`\=&ET;&4^365N
M=3H@3F5W($5V96YT/"]T:71L93X*("`@(#QH96%D:6YG/D%D9"!A($YE=R!%
M=F5N=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(#QI/DYE=R!%=F5N
M=#PO:3X@;65N=2!I=&5M('=I;&P@86QL;W<@>6]U('1O(&-R96%T92!A(&YE
M=R!E=F5N="!T;R!B92!A9&1E9"!T;R!A(&-A;&5N9&%R+@H@("`@/"]P87)A
M/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)M96YU+6]P=&EO
M;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-96YU.B!/<.?U97,\
M+W1I=&QE/@H@("`@/&AE861I;F<^3W#G]65S/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!/(&ET96T@9&4@;65N=2`\:3Y/<.?U97,\+VD^('!E<FUI=&4@
M=F]CZB!C;VYF:6=U<F%R(#QI/D]PY_5E<SPO:3X@*&]U('!R969E<NIN8VEA
M<RD@<75E(&-O;G1R;VQA;2!A(&%P87+J;F-I82!E(&-O;7!O<G1A;65N=&\@
M9&\@:W)O;F]L:71H+"!A(&EN=&5R8>?C;R!D;R!K<F]N;VQI=&@@8V]M(&\@
M2&]R9&4@92!O=71R87,@87!L:6-AY_5E<R!(;W)D92P@9V5R96YC:6$@8V%L
M96YDX7)I;W,@;?IL=&EP;&]S(&4@8V]M<&%R=&EL:&%D;W,L(&4@9V5R96YC
M:6$@8_-D:6=O<R!D92!C871E9V]R:6%S('!A<F$@979E;G1O<RX*("`@(#PO
M<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](FUE;G4M;W!T
M:6]N<R(^"B`@("`\=&ET;&4^365N=3H@3W!T:6]N<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY/<'1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@
M/&D^3W!T:6]N<SPO:3X@;65N=2!I=&5M(&%L;&]W<R!Y;W4@=&\@<V5T(#QI
M/D]P=&EO;G,\+VD^("AO<B!P<F5F97)E;F-E<RD@=&AA="!C;VYT<F]L('1H
M92!L;V]K(&%N9"!F965L(&]F(&MR;VYO;&ET:"P@:W)O;F]L:71H)W,@:6YT
M97)A8W1I;VX@=VET:"!(;W)D92!A;F0@;W1H97(@2&]R9&4@87!P;&EC871I
M;VYS+"!M86YA9V4@;75L=&EP;&4@86YD('-H87)E9"!C86QE;F1A<G,L(&%N
M9"!M86YA9V4@8V%T96=O<GD@8V]D97,@9F]R(&5V96YT<RX*("`@(#PO<&%R
M83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UI;7!O
M<G0M97AP;W)T(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365N=3H@
M26UP;W)T87(O17AP;W)T87(\+W1I=&QE/@H@("`@/&AE861I;F<^26UP;W)T
M87(O17AP;W)T87(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($\@:71E;2!D
M92!M96YU(#QI/DEM<&]R=&%R+T5X<&]R=&%R/"]I/B!P97)M:71E('9O8^H@
M:6UP;W)T87(@;W4@97AP;W)T87(@979E;G1O<R!D;R!C86QE;F3A<FEO+B!!
M='5A;&UE;G1E('9O8^H@<&]D92!I;7!O<G1A<B!A<G%U:79O<R!N;R!F;W)M
M871O($-35B!E($UI8W)O<V]F="!/=71L;V]K+B!6;V/J('-O;65N=&4@<&]D
M92!E>'!O<G1A<B!N;R!F;W)M871O($-35BX*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](FUE;G4M:6UP;W)T+65X<&]R="(^
M"B`@("`\=&ET;&4^365N=3H@26UP;W)T+T5X<&]R=#PO=&ET;&4^"B`@("`\
M:&5A9&EN9SY);7!O<G0O17AP;W)T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4:&4@/&D^26UP;W)T+T5X<&]R=#PO:3X@;65N=2!I=&5M(&%L;&]W<R!Y
M;W4@=&\@:6UP;W)T(&]R(&5X<&]R="!C86QE;F1A<B!E=F5N=',N("!#=7)R
M96YT;'D@>6]U(&-A;B!I;7!O<G0@9FEL97,@:6X@0U-6+"!-:6-R;W-O9G0@
M3W5T;&]O:RP@4&%L;2!$871E0F]O:RP@86YD('9#86QE;F1A<B]I0V%L96YD
M87(@9F]R;6%T<RX@(%EO=2!C86X@97AP;W)T('1O(&]N;'D@0U-6(&%N9"!I
M0V%L96YD87(@9F]R;6%T<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB86QA<FUS(B!S=&%T93TB=6YK;F]W;B(^"B`@
M("`\=&ET;&4^079I<V]S/"]T:71L93X*("`@(#QH96%D:6YG/D%V:7-O<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@2W)O;F]L:71H('!O9&4@9V5R87(@
M879I<V]S('!A<F$@979E;G1O<R!N;R!C86QE;F3A<FEO+B!0;W(@<&%D<N-O
M+"!O('!R:6UE:7)O(&%V:7-O(.D@9V5R861O(&-I;G'\96YT82!M:6YU=&]S
M(&%N=&5S(&1O(&%P;VYT86UE;G1O('-E<B!I;FEC:6%D;RP@;6%S(&\@879I
M<V\@<&]D92!S97(@8V]N9FEG=7)A9&\@*'!O<B!E=F5N=&\I('!A<F$@<V5R
M(&1A9&\@82!Q=6%S92!Q=6%L<75E<B!I;G1E<G9A;&\@86YT97,@9&\@:6[M
M8VEO(&1O(&5V96YT;RX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y
M.@H\96YT<GD@:60](F%L87)M<R(^"B`@("`\=&ET;&4^06QA<FUS/"]T:71L
M93X*("`@(#QH96%D:6YG/D%L87)M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@2W)O;F]L:71H(&-A;B!G96YE<F%T92!A;&%R;7,@9F]R(&5V96YT<R!I
M;B!A(&-A;&5N9&%R+B`@0GD@9&5F875L="P@=&AE(&9I<G-T(&%L87)M(&ES
M(&=E;F5R871E9"!F:69T965N(&UI;G5T97,@8F5F;W)E('1H92!A<'!O:6YT
M;65N="!I<R!S=7!P;W-E9"!T;R!S=&%R="P@8G5T('1H92!A;&%R;2!C86X@
M8F4@<V5T("AP97(@979E;G0I('1O(&]C8W5R(&%T(&%L;6]S="!A;GD@:6YT
M97)V86P@8F5F;W)E('1H92!E=F5N="!S=&%R="!T:6UE+@H@("`@/"]P87)A
M/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)R96-U<G)I;F<M
M979E;G1S(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4F5P971IY^-O
M(&1E($5V96YT;W,\+W1I=&QE/@H@("`@/&AE861I;F<^4F5P971IY^-O(&1E
M($5V96YT;W,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5V96YT;W,@<&]D
M96T@<V5R(&-R:6%D;W,@<&%R82!R97!E=&ER96T@9&4@=N%R:6%S(&UA;F5I
M<F%S+B!-=6ET;W,@979E;G1O<R!R97!E=&5M+7-E(&9R97%U96YT96UE;G1E
M(&1E(&9O<FUA<R!C;W-T=6UE:7)A<RX@4&]R(&5X96UP;&\L(&$@<F5P971I
MY^-O(#QI/DUE;G-A;#PO:3X@9F%Z(&\@979E;G1O('-E;&5C:6]N861O(')E
M<&5T:7(M<V4@=6UA('9E>B!P;W(@;>IS(&4@82!R97!E=&GGXV\@/&D^4V5M
M86YA;&UE;G1E/"]I/B!F87H@;R!E=F5N=&\@<V5L96-I;VYA9&\@<F5P971I
M<BUS92!U;2!V97H@<&]R('-E;6%N82X@17-T97,@=&EP;W,@9&4@979E;G1O
M<R!P;V1E;2!S97(@8V]N9FEG=7)A9&]S('!A<F$@<F5P971I<F5M+7-E(&1E
M(&UA;F5I<F%S(&UA:7,@8V]M<&QE>&%S.B!P;W(@97AE;7!L;RP@=6T@979E
M;G1O('%U92!O8V]R<F$@;F$@^FQT:6UA(%-E>'1A+49E:7)A(&1E(&-A9&$@
M;>IS+"!O=2!U;2!E=F5N=&\@<75E(&]C;W)R82!N82!396=U;F1A+"!1=6%R
M=&$L(&4@4V5X=&$M1F5I<F$@9&4@8V%D82!S96UA;F$N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@(%9O8^H@=&%M8NEM('!O9&4@<F5S=')I;F=I<B!Q
M=6%N=&\@=&5M<&\@=6T@979E;G1O('-E(')E<&5T:7+A(&%O('-E;&5C:6]N
M87(@/&D^4F5P971I<B!A=.D\+VD^('!A<F$@82!R97!E=&GGXV\@9&\@979E
M;G1O+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!.;W)M86QM96YT92P@
M=6UA(&UO9&EF:6-AY^-O(&5M('5M(&5V96YT;R!R97!E=&ED;R!S92!A<&QI
M8V%RX2!A('1O9&%S(&%S(&]C;W)RZFYC:6%S(&1E<W1E(&5V96YT;RX@56T@
M^FYI8V$@;V-O<G+J;F-I82!D92!U;2!E=F5N=&\@<F5P971I9&\@<&]D92!S
M97(@;6]D:69I8V%D82!E9&ET86YD;R!A(&]C;W)RZFYC:6$L(')E;6]V96YD
M;R!S=6$@:6YF;W)M8>?C;R!D92!R97!E=&GGXV\L(&4@96YTXV\@97-C;VQH
M96YD;R!A(&]PY^-O(#QI/E-A;'9A<B!#;VUO($YO=F\\+VD^+B!!(&]C;W)R
MZFYC:6$@<V5L96-I;VYA9&$@<&]D92!A9V]R82!S97(@;6]D:69I8V%D82!I
M;F1E<&5N9&5N=&5M96YT92!D87,@;W5T<F%S(&]C;W)RZFYC:6%S+@H@("`@
M/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<F5C=7)R
M:6YG+65V96YT<R(^"B`@("`\=&ET;&4^4F5C=7)R:6YG($5V96YT<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY296-U<G)I;F<@179E;G1S/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!%=F5N=',@8V%N(&)E(&UA9&4@=&\@<F5P96%T(&EN
M('9A<FEO=7,@=V%Y<RX@36%N>2!E=F5N=',@<F5P96%T(&EN(&-E<G1A:6X@
M9G)E<75E;G1L>2!U<V5D('=A>7,N($9O<B!E>&%M<&QE+"!T:&4@/&D^36]N
M=&AL>3PO:3X@<F5C=7)R96YC92!T>7!E<R!M86ME('1H92!S96QE8W1E9"!I
M=&5M(')E<&5A="!E86-H(&UO;G1H(&%N9"!T:&4@/&D^5V5E:VQY/"]I/B!R
M96-U<G)E;F-E('1Y<&4@;6%K97,@=&AE('-E;&5C=&5D(&ET96T@<F5P96%T
M(&5A8V@@<&5R('=E96LN(%1H97-E(&-A;B!B92!M861E('1O(')E<')E<V5N
M="!E=F5N=',@=&AA="!R97!E870@:6X@8V]M<&QE>"!W87ES.B!F;W(@97AA
M;7!L92P@86X@:71E;2!T:&%T(&]C8W5R<R!O;B!T:&4@;&%S="!&<FED87D@
M;V8@96%C:"!M;VYT:"P@;W(@86X@:71E;2!T:&%T(&]C8W5R<R!O;B!-;VYD
M87DL(%=E9&YE<V1A>2P@86YD($9R:61A>2!E=F5R>2!W965K+B`*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@66]U(&-A;B!A;'-O(')E<W1R:6-T(&AO
M=R!L;VYG(&%N(&5V96YT(')E<&5A=',@8GD@<V5L96-T:6YG('1H92`\:3YE
M;F0@9&%T93PO:3X@9F]R('1H92!E=F5N="=S(')E8W5R<F5N8V4N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@($YO<FUA;&QY+"!A(&UO9&EF:6-A=&EO
M;B!T;R!A(')E<&5A=&EN9R!E=F5N="!A<'!L:65S('1O(&%L;"!O8V-U<G)E
M;F-E<R!O9B!T:&%T(&5V96YT+B!!('-I;F=L92!O8V-U<G)E;F-E(&]F(&$@
M<F5P96%T:6YG(&5V96YT(&-A;B!B92!M;V1I9FEE9"!B>2!E9&ET:6YG('1H
M92!O8V-U<G)E;F-E+"!R96UO=FEN9R!I=',@<F5C=7)R96YC92!I;F9O<FUA
M=&EO;BP@86YD('1H96X@8VAO;W-I;F<@=&AE(#QI/E-A=F4@87,@3F5W/"]I
M/B!O<'1I;VX@9G)O;2!T:&4@4F5P96%T(&UE;G4N(%1H92!S96QE8W1E9"!O
M8V-U<G)E;F-E(&-A;B!N;W<@8F4@;6]D:69I960@:6YD97!E;F1E;G1L>2!O
M9B!T:&4@;W1H97(@;V-C=7)E;F-E<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM
M+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB4')I;G1I;F<B('-T871E/2)U;FMN
M;W=N(CX*("`@(#QT:71L93Y);7!R:6UI;F1O/"]T:71L93X*("`@(#QH96%D
M:6YG/DEM<')I;6EN9&\@0V%L96YDX7)I;W,@92!%=F5N=&]S/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#97)T87,@97AI8FGG]65S('/C;R!P<F]J971A
M9&%S('!A<F$@<V5R96T@:6UP<FEM[79E:7,N(%%U86YD;R!E;2!U;6$@9&5S
M=&%S(&5X:6)IY_5E<RP@;R#M8V]N92`\:3Y);7!R:6UI<CPO:3X@87!A<F5C
M97+A(&YO('1O<&\@9&$@8F%R<F$@9&4@;65N=2X@57-E(&5S=&4@[6-O;F4@
M<&%R82!I;7!R:6UI<B!A(&5X:6)IY^-O(&%T=6%L+@H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB4')I;G1I;F<B/@H@("`@
M/'1I=&QE/E!R:6YT:6YG/"]T:71L93X*("`@(#QH96%D:6YG/E!R:6YT:6YG
M($-A;&5N9&%R<R!A;F0@179E;G1S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!#97)T86EN('9I97=S(&%R92!D97-I9VYE9"!T;R!B92!P<FEN=&%B;&4N
M("!7:&5N(&EN(&]N92!O9B!T:&5S92!V:65W<RP@82`\:3Y0<FEN=#PO:3X@
M:6-O;B!W:6QL(&%P<&5A<B!I;B!T:&4@=&]P(&UE;G4@8F%R+B`@57-E('1H
M:7,@;65N=2!I8V]N('1O('!R:6YT('1H92!C=7)R96YT('9I97<N"B`@("`\
M+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*/"]H96QP/@H`````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]P=%]05"\`````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,@`P,C`W
M,C$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+W!T
M7U!4+TQ#7TU%4U-!1T53+P``````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4R`#`R,C4P-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR
M;VYO;&ET:"]L;V-A;&4O<'1?4%0O3$-?34534T%'15,O:W)O;F]L:71H+FUO
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`U,#(R,#0`,3`T,3<S-C(W-3(`,#(U,#4T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-X2!)4`````L0@`
M`!P```"D10``F0L``"R+````````D+D``$T```"1N0``OP```-^Y``!D````
MG[H``+X````$NP``D````,.[``!#````5+P``#P```"8O```*P```-6\```N
M`````;T``"D````PO0``*````%J]``!%````@[T``$<```#)O0``2@```!&^
M``!'````7+X``$4```"DO@``2````.J^```Y````,[\``$8```!MOP``2```
M`+2_```P````_;\``$4````NP```1@```'3```!,````N\```#0````(P0``
M,@```#W!``!I````<,$``#````#:P0``)0````O"``"(````,<(``$````"Z
MP@``]@```/O"``!*````\L,``"P````]Q```A0```&K$``!(````\,0```X`
M```YQ0``#P```$C%```-````6,4```@```!FQ0``"P```&_%```,````>\4`
M``0```"(Q0``&P```(W%```M````J<4``!T```#7Q0``)````/7%```I````
M&L8``!D```!$Q@``#````%[&```1````:\8```D```!]Q@``)0```(?&```/
M````K<8```L```"]Q@``$0```,G&```?````V\8```X```#[Q@``!0````K'
M```H````$,<```@````YQP``"@```$+'```5````3<<``!(```!CQP``"P``
M`';'```,````@L<``!T```"/QP``$P```*W'```.````P<<```H```#0QP``
M#0```-O'```N````Z<<```X````8R```$0```"?(```-````.<@```P```!'
MR```#0```%3(```&````8L@``!T```!IR```'0```(?(```*````I<@```\`
M``"PR```&````,#(```,````V<@``!L```#FR```"@````+)```'````#<D`
M``X````5R0``#@```"3)```(````,\D```D````\R0``&P```$;)```>````
M8LD``!H```"!R0``'````)S)``!"````N<D``"X```#\R0``&@```"O*```R
M````1LH``#@```!YR@``5````++*``!1````!\L``%H```!9RP``5P```+3+
M```T````#,P```(```!!S```"0```$3,```-````3LP```<```!<S```"@``
M`&3,```/````;\P```4```!_S```!@```(7,```1````C,P```@```">S```
M"0```*?,```)````L<P```@```"[S```)0```,3,```@````ZLP``!`````+
MS0``#P```!S-```*````+,T``!`````WS0```P```$C-```/````3,T``!0`
M``!<S0``"0```''-```)````>\T```T```"%S0``$@```)/-```9````ILT`
M`!X```#`S0``&0```-_-```/````^<T```\````)S@``#0```!G.```*````
M)\X```\````RS@``"````$+.```?````2\X``"0```!KS@``$````)#.```4
M````H<X``!8```"VS@``"````,W.``!.````ULX``"T````ESP``'P```%//
M```9````<\\```<```"-SP``#````)7/```L````HL\```X```#/SP```P``
M`-[/```/````XL\```L```#RSP``!0```/[/```4````!-```!4````9T```
M%P```"_0```5````1]```!(```!=T```$P```'#0```5````A-```!,```":
MT```"@```*[0```4````N=````H```#.T```!P```-G0```'````X=````4`
M``#IT```!0```._0```*````]=````,`````T0``#0````31```7````$M$`
M``H````JT0``"@```#71```(````0-$```\```!)T0``"P```%G1```'````
M9=$```T```!MT0``"@```'O1```.````AM$``!@```"5T0``(P```*[1```.
M````TM$``!0```#AT0``%P```/;1```7````#M(``!<````FT@``$P```#[2
M```/````4M(```X```!BT@``'P```''2```=````D=(```<```"OT@``!@``
M`+?2```(````OM(```\```#'T@``!@```-?2```*````WM(``!,```#IT@``
M`P```/W2```+`````=,``!4````-TP``%0```"/3```'````.=,``!````!!
MTP``!0```%+3```5````6-,``!$```!NTP``#````(#3```[````C=,``#@`
M``#)TP``"0````+4```'````#-0``!0````4U````P```"G4```%````+=0`
M`!`````SU```"0```$34```3````3M0``#D```!BU```$@```)S4```"````
MK]0``+0```"RU```)P```&?5```L````C]4``"H```"\U0``)0```.?5```*
M````#=8```D````8U@``"@```"+6```&````+=8```D````TU@``!P```#[6
M```O````1M8``#<```!VU@``+@```*[6``!5````W=8``"T````SUP``+0``
M`&'7```M````C]<``$````"]UP``(P```/[7```C````(M@``"T```!&V```
M,P```'38```5````J-@``!D```"^V```*0```-C8```D`````MD``!$````G
MV0``"@```#G9```,````1-D``!@```!1V0``"@```&K9```0````==D``!8`
M``"&V0``%@```)W9```'````M-D```<```"\V0``%````,39```*````V=D`
M``@```#DV0``"````.W9```,````]MD```<````#V@``!P````O:```&````
M$]H```4````:V@``!P```"#:```&````*-H```@````OV@``*0```#C:```.
M````8MH```H```!QV@``!````'S:```'````@=H```D```")V@``!@```)/:
M```1````FMH```<```"LV@``%@```+3:```$````R]H```@```#0V@``!@``
M`-G:```-````X-H```8```#NV@``'@```/7:```1````%-L``"(````FVP``
M%@```$G;```(````8-L```T```!IVP``#````'?;```'````A-L```0```",
MVP```P```)';```#````E=L``!<```"9VP``"0```+';```3````N]L``!T`
M``#/VP``"0```.W;```(````]]L``!0`````W```#0```!7<```0````(]P`
M``D````TW```&P```#[<```$````6MP```@```!?W```"````&C<``!!````
M<=P``"````"SW```&0```-3<```&````[MP```8```#UW```%0```/S<```)
M````$MT```T````<W0``&````"K=```B````0]T``"X```!FW0``'0```)7=
M```A````L]T``%0```#5W0``*0```"K>```*````5-X```<```!?W@``"0``
M`&?>```5````<=X```@```"'W@``#@```)#>```*````G]X```\```"JW@``
M#0```+K>```/````R-X```T```#8W@``"0```.;>```4````\-X```8````%
MWP``&`````S?```=````)=\``!,```!#WP``$0```%??```4````:=\```0`
M``!^WP``!@```(/?``!4````BM\```0```#?WP``#@```.3?``!$````\]\`
M``4````XX```!0```#[@```;````1.```!H```!@X```$0```'O@```1````
MC>```!P```"?X```*@```+S@```V````Y^```$T````>X0``'0```&SA```0
M````BN$``"$```";X0``)0```+WA```9````X^$```4```#]X0``$P````/B
M```3````%^(``!(````KX@``"@```#[B```/````2>(```T```!9X@``$0``
M`&?B```3````>>(```P```"-X@``!@```)KB```,````H>(```8```"NX@``
M%P```+7B```0````S>(``!$```#>X@``"````/#B```%````^>(```P```#_
MX@``$`````SC```%````'>,```T````CXP``!@```#'C```6````..,```<`
M``!/XP``#0```%?C```0````9>,```D```!VXP``!P```(#C```+````B.,`
M``L```"4XP``!P```*#C```'````J.,``!0```"PXP``"0```,7C```)````
MS^,```H```#9XP``&0```.3C```=````_N,```P````<Y```$````"GD```;
M````.N0```D```!6Y```!0```&#D```E````9N0``!(```",Y```$P```)_D
M```K````L^0``#L```#?Y```(````!OE```V````/.4``"$```!SY0``$```
M`)7E```(````IN4```P```"OY0``!@```+SE```$````P^4```X```#(Y0``
M0````-?E```0````&.8```H````IY@``#0```#3F```>````0N8``!L```!A
MY@``(0```'WF```>````G^8``!D```"^Y@``'@```-CF```;````]^8``"X`
M```3YP``%P```$+G```F````6N<``#````"!YP``&P```++G```>````SN<`
M`!P```#MYP``)@````KH```K````,>@``#,```!=Z```)@```)'H```K````
MN.@``#@```#DZ```'0```!WI```5````.^D``"\```!1Z0``(````('I```2
M````HND``"D```"UZ0``'@```-_I```2````_ND``*(````1Z@``%@```+3J
M```C````R^H``"@```#OZ@``*0```!CK```H````0NL``!\```!KZP``%0``
M`(OK```@````H>L``"4```#"ZP``*````.CK```M````$>P``#`````_[```
MD@```'#L```A`````^T``!8````E[0``'````#SM```F````6>T``"H```"`
M[0``00```*OM``!$````[>T```P````R[@``!P```#_N```'````1^X```8`
M``!/[@``$@```%;N```-````:>X``!````!W[@``$@```(CN```'````F^X`
M`!,```"C[@``$@```+?N```'````RNX```0```#2[@``!P```-?N```0````
MW^X```P```#P[@``#@```/WN```/````#.\``!,````<[P``#0```##O```H
M````/N\```,```!G[P``#0```&OO```&````>>\``!$```"`[P``%P```)+O
M```;````JN\```X```#&[P```@```-7O```%````V.\``!,```#>[P``$```
M`/+O```$`````_````T````(\```#@```!;P```#````)?````8````I\```
M!P```##P```.````./````@```!'\```#P```%#P```(````8/````\```!I
M\```!P```'GP```0````@?````T```"2\```$````*#P```3````L?```!,`
M``#%\```"P```-GP```&````Y?````L```#L\```"0```/CP```,`````O$`
M``P````/\0``$0```!SQ```9````+O$```L```!(\0``#0```%3Q```B````
M8O$``!L```"%\0``-````*'Q```*````UO$``!@```#A\0``&0```/KQ``!<
M````%/(``!8```!Q\@``+P```(CR```B````N/(```T```#;\@``!P```.GR
M```,````\?(``!0```#^\@``"P```!/S```B````'_,``"\```!"\P``"P``
M`'+S```)````?O,``!D```"(\P``"P```*+S```7````KO,``!<```#&\P``
M"0```-[S```'````Z/,```<```#P\P``%@```/CS```/````#_0``!D````?
M]```%@```#GT```.````4/0``!@```!?]```"````'CT```-````@?0``"8`
M``"/]```.0```+;T```.````\/0``$,```#_]```"````$/U```2````3/4`
M``@```!?]0``"P```&CU```O````=/4```X```"D]0``!0```+/U```'````
MN?4```@```#!]0``!@```,KU```#````T?4```<```#5]0``!````-WU```)
M````XO4```<```#L]0``#@```/3U```*`````_8```H````.]@``#P```!GV
M```0````*?8``!<````Z]@``%0```%+V```.````:/8``!H```!W]@``$0``
M`)+V```9````I/8``!<```"^]@``"0```-;V```%````X/8```L```#F]@``
M"@```/+V```"````_?8```4`````]P``#0````;W```;````%/<``!<````P
M]P``"0```$CW```.````4O<```T```!A]P``$@```&_W```X````@O<``"``
M``"[]P``"````-SW```&````Y?<```@```#L]P``"````/7W```.````_O<`
M`'L````-^```&````(GX``!`````HO@``!$```#C^```!P```/7X```%````
M_?@``#$````#^0``&0```#7Y```3````3_D```<```!C^0``!P```&OY```(
M````<_D```8```!\^0``!@```(/Y```3````BOD``!X```">^0``&0```+WY
M```K````U_D``!`````#^@``#P```!3Z```0````)/H```\````U^@``"P``
M`$7Z```/````4?H```P```!A^@``#P```&[Z```'````?OH```H```"&^@``
M!@```)'Z```.````F/H```P```"G^@``*````+3Z```/````W?H```@```#M
M^@``!@```/;Z```/````_?H``!8````-^P``"````"3[```3````+?L``!X`
M``!!^P``(0```&#[```@````@OL``!D```"C^P``%P```+W[```E````U?L`
M`!<```#[^P``!````!/\```;````&/P```T````T_```#````$+\```#````
M3_P```@```!3_```"@```%S\```,````9_P```L```!T_```$````(#\```,
M````D?P```0```">_```$P```*/\```4````M_P```P```#,_```"0```-G\
M```.````X_P```L```#R_```&P```/[\```'````&OT```0````B_0``!P``
M`"?]```*````+_T```T````Z_0``"0```$C]```$````4OT```4```!7_0``
M`P```%W]```8````8?T```H```!Z_0``!````(7]```F````BOT```X```"Q
M_0``?````,#]```5````/?X```4```!3_@``!P```%G^```,````8?X```@`
M``!N_@``"@```'?^```&````@OX```@```")_@``%@```)+^```2````J?X`
M``(```"\_@``!@```+_^```&````QOX``!0```#-_@``%0```.+^```-````
M^/X``!`````&_P``&P```!?_```&````,_\```0````Z_P``"0```#__```0
M````2?\```D```!:_P``"0```&3_```&````;O\```4```!U_P``!0```'O_
M```:````@?\```@```"<_P``!@```*7_```$````K/\```<```"Q_P``&0``
M`+G_```.````T_\``"(```#B_P``!P````4``0`'````#0`!``X````5``$`
M!0```"0``0`)````*@`!``H````T``$``@```#\``0`&````0@`!``T```!)
M``$`!P```%<``0`)````7P`!``8```!I``$`$@```'```0`)````@P`!``<`
M``"-``$`%````)4``0`=````J@`!`!$```#(``$`!@```-H``0`*````X0`!
M``0```#L``$`"0```/$``0`(````^P`!`!$````$`0$`$0```!8!`0`)````
M*`$!``8````R`0$`#0```#D!`0`&````1P$!``0```!.`0$`.0```%,!`0`]
M````C0$!`#H```#+`0$`'@````8"`0`%````)0(!``X````K`@$`!````#H"
M`0`&````/P(!`"$```!&`@$`#0```&@"`0`5````=@(!``8```",`@$`!```
M`),"`0`1````F`(!``8```"J`@$`H````+$"`0`*````4@,!`"(```!=`P$`
M!````(`#`0`'````A0,!``0```"-`P$`)0```)(#`0`%````N`,!`!T```"^
M`P$`!````-P#`0`,````X0,!``H```#N`P$`"````/D#`0`)`````@0!``4`
M```,!`$`&P```!($`0`Z````+@0!`#````!I!`$`-0```)H$`0`I````T`0!
M`"X```#Z!`$`1P```"D%`0`X````<04!`"D```"J!0$`/P```-0%`0`N````
M%`8!`"T```!#!@$`'P```'$&`0`/````D08!`!(```"A!@$`"P```+0&`0`'
M````P`8!`"8```#(!@$`*0```.\&`0!+````&0<!`"0```!E!P$`)@```(H'
M`0`(````L0<!``H```"Z!P$`"0```,4'`0`'````SP<!`"````#7!P$`(```
M`/@'`0`F````&0@!``H```!`"`$`&0```$L(`0`I````90@!`!8```"/"`$`
M$@```*8(`0`'````N0@!``H```#!"`$`#P```,P(`0`0````W`@!`$````#M
M"`$`<````"X)`0!F````GPD!``X````&"@$`"0```!4*`0`*````'PH!`!(`
M```J"@$`$P```#T*`0`,````40H!``8```!>"@$`&````&4*`0`/````?@H!
M`!8```"."@$`$@```*4*`0`0````N`H!`!$```#)"@$`'````-L*`0`C````
M^`H!`&H````<"P$`#P```(<+`0`%````EPL!`!````"="P$`"0```*X+`0`$
M````N`L!``L```"]"P$`(````,D+`0`:````Z@L!`!0````%#`$`#````!H,
M`0`,````)PP!``\````T#`$`%0```$0,`0`I````6@P!`"H```"$#`$`)@``
M`*\,`0`G````U@P!`"D```#^#`$`*@```"@-`0`9````4PT!`$(```!M#0$`
M$0```+`-`0`2````P@T!`!,```#5#0$`%````.D-`0`/````_@T!`!8````.
M#@$`%P```"4.`0`0````/0X!`!$```!.#@$`-````&`.`0`3````E0X!`!(`
M``"I#@$`-0```+P.`0`4````\@X!``<````'#P$`#`````\/`0`@````'`\!
M`!`````]#P$`%````$X/`0`1````8P\!`!<```!U#P$`'````(T/`0`3````
MJ@\!`!0```"^#P$`&@```-,/`0`1````[@\!`!H`````$`$`'@```!L0`0`:
M````.A`!`!,```!5$`$`%0```&D0`0`1````?Q`!`!<```"1$`$`%````*D0
M`0`7````OA`!`!4```#6$`$`"0```.P0`0`9````]A`!``0````0$0$`!P``
M`!41`0`+````'1$!`!$````I$0$`!@```#L1`0`&````0A$!``8```!)$0$`
M!0```%`1`0`'````5A$!``<```!>$0$`!0```&81`0`6````;!$!``8```"#
M$0$`!@```(H1`0`$````D1$!``0```"6$0$`!P```)L1`0`.````HQ$!``P`
M``"R$0$`#````+\1`0`-````S!$!``H```#:$0$`#@```.41`0`%````]!$!
M`"@```#Z$0$`#@```",2`0`,````,A(!``\````_$@$`"@```$\2`0`(````
M6A(!``D```!C$@$`*P```&T2`0`(````F1(!``0```"B$@$`"````*<2`0`F
M````L!(!`!(```#7$@$`#P```.H2`0`&````^A(!``H````!$P$`!P````P3
M`0`(````%!,!`"`````=$P$`#0```#X3`0`)````3!,!``T```!6$P$`"@``
M`&03`0`,````;Q,!``T```!\$P$`#@```(H3`0`6````F1,!`!$```"P$P$`
M"0```,(3`0`%````S!,!``8```#2$P$``P```-D3`0`&````W1,!`!D```#D
M$P$`!P```/X3`0`$````!A0!``L````+%`$`"P```!<4`0`'````(Q0!``<`
M```K%`$`%@```#,4`0`-````2A0!``T```!8%`$`"@```&84`0`0````<10!
M``\```""%`$`$0```)(4`0`7````I!0!``H```"\%`$`$0```,<4`0`(````
MV10!`!X```#B%`$`!`````$5`0`/````!A4!`#H````6%0$`!0```%$5`0`,
M````5Q4!`!X```!D%0$`#@```(,5`0`0````DA4!``L```"C%0$`#````*\5
M`0`)````O!4!``<```#&%0$`"@```,X5`0`)````V14!``X```#C%0$`$```
M`/(5`0`:`````Q8!``H````>%@$`"0```"D6`0`)````,Q8!`!0````]%@$`
M"@```%(6`0`,````718!``\```!J%@$`"````'H6`0`&````@Q8!``<```"*
M%@$`"P```)(6`0!'````GA8!``T```#F%@$`"0```/06`0`$````_A8!``,`
M```#%P$`$P````<7`0`3````&Q<!`!,````O%P$`"@```$,7`0`"````3A<!
M``0```!1%P$`)0```%87`0`#````?!<!``4```"`%P$`*@```(87`0`*````
ML1<!``4```"\%P$`!````,(7`0`*````QQ<!``T```#2%P$`0````.`7`0`3
M````(1@!``8````U&`$`"````#P8`0`(````11@!``0```!.&`$`!0```%,8
M`0`8````61@!`&@```!R&`$`"0```-L8`0`,````Y1@!``4```#R&`$`!@``
M`/@8`0`;````_Q@!`"\````;&0$`$````$L9`0`*````7!D!``\```!G&0$`
M"@```'<9`0`)````@AD!`!,```",&0$`&P```*`9`0`8````O!D!`!<```#5
M&0$`#@```.T9`0`#````_!D!``<`````&@$`"`````@:`0`'````$1H!``<`
M```9&@$`"0```"$:`0`*````*QH!``L````V&@$`+0```$(:`0`5````<!H!
M`#````"&&@$`)````+<:`0`'````W!H!`%$```#D&@$`$````#8;`0`,````
M1QL!``T```!4&P$`&@```&(;`0!*````?1L!`!D```#(&P$`!@```.(;`0`:
M````Z1L!``8````$'`$`!@````L<`0`?````$AP!``8````R'`$`"0```#D<
M`0`8````0QP!`!<```!<'`$`"0```'0<`0`&````?AP!``T```"%'`$`$@``
M`),<`0`B````IAP!`%<```#)'`$`$P```"$=`0`C````-1T!`!,```!9'0$`
M`@```&T=`0`+````<!T!``@```!\'0$`#0```(4=`0`*````DQT!``8```">
M'0$`!P```*4=`0`4````K1T!``8```#"'0$`!@```,D=`0`(````T!T!``4`
M``#9'0$`"@```-\=`0`.````ZAT!``<```#Y'0$`$P````$>`0`5````%1X!
M``P````K'@$`#0```#@>`0`*````1AX!``L```!1'@$`!P```%T>`0`,````
M91X!``T```!R'@$`#````(`>`0`)````C1X!``D```"7'@$`"@```*$>`0`'
M````K!X!``D```"T'@$`!P```+X>`0`*````QAX!`!L```#1'@$`0@```.T>
M`0`2````,!\!``H```!#'P$`#````$X?`0`-````6Q\!`!````!I'P$`"0``
M`'H?`0`0````A!\!``<```"5'P$`$@```)T?`0`$````L!\!``<```"U'P$`
M!0```+T?`0`%````PQ\!``L```#)'P$`%````-4?`0`1````ZA\!`!H```#\
M'P$`%@```!<@`0`4````+B`!`!<```!#(`$`&````%L@`0`<````="`!`!D`
M``"1(`$`!P```*L@`0`%````LR`!``T```"Y(`$`#````,<@`0`)````U"`!
M``@```#>(`$`%P```.<@`0`+````_R`!`!,````+(0$`!````!\A`0`*````
M)"$!``0````O(0$`#0```#0A`0`-````0B$!``@```!0(0$`"@```%DA`0`)
M````9"$!``@```!N(0$`#````'<A`0`)````A"$!``4```".(0$`"0```)0A
M`0`%````GB$!``<```"D(0$`!0```*PA`0`$````LB$!``(```"W(0$`#@``
M`+HA`0`(````R2$!``P```#2(0$`.````-\A`0`L````&"(!`!(```!%(@$`
M*0```%@B`0`R````@B(!`"4```"U(@$`"@```-LB`0`V````YB(!`"P````=
M(P$`%0```$HC`0`N````8",!`#,```"/(P$`,P```,,C`0`X````]R,!``\`
M```P)`$`&````$`D`0`+````620!`#L```!E)`$`%````*$D`0`0````MB0!
M`"P```#')`$`'````/0D`0`4````$24!`!,````F)0$`%0```#HE`0`4````
M4"4!`!(```!E)0$`%````'@E`0`5````C24!`"T```"C)0$`+0```-$E`0`Q
M````_R4!`"T````Q)@$`+@```%\F`0`O````CB8!`"P```"^)@$`8@```.LF
M`0`3````3B<!``T```!B)P$`"````'`G`0`(````>2<!`"L```"")P$`(0``
M`*XG`0`:````T"<!`!P```#K)P$`"0````@H`0!%````$B@!`$$```!8*`$`
M!````)HH`0`3````GR@!`!0```"S*`$`#@```,@H`0`3````UR@!`!@```#K
M*`$`!@````0I`0`)````"RD!``H````5*0$`#P```"`I`0`)````,"D!`!``
M```Z*0$`!P```$LI`0`.````4RD!``4```!B*0$`&P```&@I`0`&````A"D!
M`&D```"+*0$`"````/4I`0`#````_BD!``8````"*@$`%`````DJ`0`1````
M'BH!``X````P*@$`.````#\J`0`"````>"H!``8```![*@$`#@```((J`0`:
M````D2H!``4```"L*@$`!P```+(J`0`.````NBH!``8```#)*@$`!````-`J
M`0`I````U2H!`!<```#_*@$`'P```!<K`0!<````-RL!`!0```"4*P$`/@``
M`*DK`0`?````Z"L!`!`````(+`$`"````!DL`0`2````(BP!``<````U+`$`
M#@```#TL`0`(````3"P!``P```!5+`$`#````&(L`0`3````;RP!``H```"#
M+`$`'0```(XL`0`9````K"P!``4```#&+`$`$0```,PL`0`%````WBP!`!$`
M``#D+`$`)````/8L`0`5````&RT!`!(````Q+0$`#@```$0M`0`9````4RT!
M``@```!M+0$`"0```'8M`0`"````@"T!``T```"#+0$`"@```)$M`0`'````
MG"T!``\```"D+0$`!@```+0M`0`+````NRT!``H```#'+0$`!P```-(M`0`(
M````VBT!``4```#C+0$`'P```.DM`0`-````"2X!``8````7+@$`$````!XN
M`0`(````+RX!``T````X+@$`"````$8N`0`2````3RX!`"P```!B+@$`&@``
M`(\N`0`)````JBX!``H```"T+@$`%0```+\N`0`0````U2X!``4```#F+@$`
M%````.PN`0`$`````2\!``<````&+P$`$`````XO`0`&````'R\!``<````F
M+P$`'@```"XO`0`H````32\!`!X```!V+P$`"@```)4O`0`<````H"\!`!$`
M``"]+P$`"P```,\O`0`:````VR\!``\```#V+P$`%`````8P`0`$````&S`!
M``0````@,`$`"P```"4P`0`%````,3`!``8````W,`$`"````#XP`0`&````
M1S`!``H```!.,`$`&P```%DP`0`T````=3`!`#0```"J,`$`(````-\P`0`I
M`````#$!`"`````J,0$`00```$LQ`0`:````C3$!`"@```"H,0$`*0```-$Q
M`0!1````^S$!`"\```!-,@$`(@```'TR`0`&````H#(!``@```"G,@$`!0``
M`+`R`0`.````MC(!``@```#%,@$`&0```,XR`0`9````Z#(!`!4````",P$`
M%@```!@S`0`J````+S,!`",```!:,P$`&0```'XS`0`N````F#,!`#0```#'
M,P$`"````/PS`0`7````!30!``H````=-`$`!P```"@T`0`A````,#0!``P`
M``!2-`$`#0```%\T`0`,````;30!`!````!Z-`$`#@```(LT`0`+````FC0!
M``<```"F-`$`$P```*XT`0`(````PC0!``L```#+-`$`"@```-<T`0`4````
MXC0!``\```#W-`$`,@````<U`0`+````.C4!``4```!&-0$`!0```$PU`0`7
M````4C4!``\```!J-0$`!````'HU`0`*````?S4!``D```"*-0$`"P```)0U
M`0`-````H#4!``P```"N-0$`#@```+LU`0`%````RC4!``0```#0-0$`#0``
M`-4U`0`R````XS4!`$4````6-@$`"P```%PV`0`*````:#8!``\```!S-@$`
M$P```(,V`0`3````ES8!``\```"K-@$`#````+LV`0`.````R#8!``T```#7
M-@$`#0```.4V`0`7````\S8!`!X````+-P$`%````"HW`0`%````/S<!`!0`
M``!%-P$`!P```%HW`0`,````8C<!`!````!O-P$`$0```(`W`0`.````DC<!
M`"H```"A-P$`!@```,PW`0`)````TS<!``\```#=-P$`#````.TW`0`-````
M^C<!`!$````(.`$`"P```!HX`0`V````)C@!``H```!=.`$`(@```&@X`0`+
M````BS@!``\```"7.`$`,@```*<X`0`E````VC@!``@`````.0$`,`````DY
M`0`Q````.CD!`"T```!L.0$`$@```)HY`0`.````K3D!`!(```"\.0$`!0``
M`,\Y`0`.````U3D!`!,```#D.0$`$0```/@Y`0`(````"CH!``<````3.@$`
M&@```!LZ`0`(````-CH!`!$````_.@$`!P```%$Z`0`4````63H!`!@```!N
M.@$`!P```(<Z`0`%````CSH!``P```"5.@$`#````*(Z`0`2````KSH!``0`
M``#".@$`!P```,<Z`0`*````SSH!``L```#:.@$`#````.8Z`0`.````\SH!
M``X````".P$`!0```!$[`0`%````%SL!`"X````=.P$`)@```$P[`0`C````
M<SL!``,```"7.P$`$@```)L[`0`&````KCL!`!X```"U.P$`&````-0[`0`E
M````[3L!``T````3/`$`"0```"$\`0`#````*SP!``<````O/`$`"@```#<\
M`0`1````0CP!``(```!4/`$`#````%<\`0`5````9#P!``L```!Z/`$`&0``
M`(8\`0`@````H#P!`!(```#!/`$`!0```-0\`0`*````VCP!`!4```#E/`$`
M$@```/L\`0`(````#CT!``P````7/0$`!````"0]`0`'````*3T!``D````Q
M/0$`"P```#L]`0`*````1ST!``P```!2/0$`4@```%\]`0`7````LCT!`"0`
M``#*/0$`$@```.\]`0`'`````CX!``8````*/@$`#@```!$^`0`.````(#X!
M`"(````O/@$`'0```%(^`0`,````<#X!`!$```!]/@$`#0```(\^`0`5````
MG3X!`!(```"S/@$`#P```,8^`0`4````UCX!`!L```#K/@$`$`````<_`0!8
M````&#\!`"$```!Q/P$`:0```),_`0`:````_3\!`!<````80`$`&0```#!`
M`0`:````2D`!`!D```!E0`$`)0```']``0`G````I4`!`!H```#-0`$`%P``
M`.A``0`=`````$$!`"8````>00$`&P```$5!`0`J````84$!`!D```",00$`
M'P```*9!`0`3````QD$!``@```#:00$`1````.-!`0`3````*$(!`$`````\
M0@$`!P```'U"`0`(````A4(!``D```".0@$`%0```)A"`0`-````KD(!`",`
M``"\0@$`$P```.!"`0`#````]$(!``P```#X0@$`1@````5#`0`7````3$,!
M``X```!D0P$`/P```'-#`0`P````LT,!`#<```#D0P$`5P```!Q$`0`%````
M=$0!`!\```!Z1`$`+P```)I$`0`*````RD0!`!,```#51`$`$0```.E$`0`(
M````^T0!``T````$10$`+0```!)%`0`$````0$4!``T```!%10$`%0```%-%
M`0`[````:44!`$\```"E10$`'P```/5%`0`6````%48!`"L````L1@$`)0``
M`%A&`0`H````?D8!`!P```"G1@$`"P```,1&`0`C````T$8!`!\```#T1@$`
M(0```!1'`0`=````-D<!`"4```!41P$`(````'I'`0`D````FT<!`"````#`
M1P$`,````.%'`0`+````$D@!``<````>2`$`#0```"9(`0`,````-$@!`!<`
M``!!2`$`!@```%E(`0`Y````8$@!``P```":2`$`!P```*=(`0`9````KT@!
M``D```#)2`$`$P```--(`0`)````YT@!``0```#Q2`$`$````/9(`0`*````
M!TD!``@````220$`"````!M)`0`$````)$D!``L````I20$`#````#5)`0`2
M````0DD!`!$```!520$`#````&=)`0`:````=$D!``\```"/20$`!P```)])
M`0`-````ITD!`!0```"U20$`#@```,I)`0`,````V4D!`!L```#F20$`+```
M``)*`0`3````+TH!`!P```!#2@$`*````&!*`0`&````B4H!``<```"02@$`
M$P```)A*`0`%````K$H!``0```"R2@$`%P```+=*`0`*````STH!``P```#:
M2@$`"0```.=*`0`&````\4H!``D```#X2@$`"0````)+`0`(````#$L!``D`
M```52P$`"@```!]+`0`(````*DL!``H````S2P$`"@```#Y+`0`'````24L!
M`!$```!12P$`!@```&-+`0`8````:DL!``X```"#2P$`#@```))+`0`-````
MH4L!``L```"O2P$`'0```+M+`0`+````V4L!``(```#E2P$`!P```.A+`0`&
M````\$L!`&4```#W2P$`"0```%U,`0`'````9TP!`"8```!O3`$`.````)9,
M`0`:````STP!`"H```#J3`$`.P```!5-`0`H````44T!`#0```!Z30$`&0``
M`*]-`0`5````R4T!``4```#?30$`!P```.5-`0`(````[4T!``<```#V30$`
M!@```/Y-`0`%````!4X!``<````+3@$`#@```!-.`0`)````(DX!``8````L
M3@$`"````#-.`0`+````/$X!``<```!(3@$`"````%!.`0`'````64X!`!8`
M``!A3@$`"0```'A.`0`&````@DX!``L```")3@$`'````)5.`0`4````LDX!
M``<```#'3@$`$0```,].`0`(````X4X!``X```#J3@$`"````/E.`0`%````
M`D\!`!`````(3P$`$````!E/`0`&````*D\!`!D````Q3P$`"@```$M/`0`<
M````5D\!``<```!S3P$`!0```'M/`0`0````@4\!`!0```"23P$`"P```*=/
M`0`-````LT\!`"@```#!3P$`&````.I/`0`7`````U`!``D````;4`$`!```
M`"50`0`)````*E`!``H````T4`$`!P```#]0`0`"````1U`!``X```!*4`$`
M"````%E0`0`?````8E`!`#X```""4`$`.````,%0`0`C````^E`!`#@````>
M40$`)@```%=1`0`Q````?E$!`"<```"P40$`9````-A1`0`4````/5(!`"0`
M``!24@$`(P```'=2`0`C````FU(!`"L```"_4@$`(0```.M2`0!5````#5,!
M`#@```!C4P$`2@```)Q3`0!;````YU,!`"@```!#5`$`.````&Q4`0`O````
MI50!`#,```#55`$`*`````E5`0`L````,E4!`"<```!?50$`&P```(=5`0`^
M````HU4!`#H```#B50$`J0$``!U6`0`H````QU<!`",```#P5P$`%P```!18
M`0!(````+%@!`(4```!U6`$`,````/M8`0!!````+%D!`%L```!N60$`20``
M`,I9`0`=````%%H!`!@````R6@$`(0```$M:`0`?````;5H!`"L```"-6@$`
M(0```+E:`0`G````VUH!`!T````#6P$`$0```"%;`0`S````,UL!`"4```!G
M6P$`)P```(U;`0`R````M5L!`!\```#H6P$`,`````A<`0!I````.5P!`"L`
M``"C7`$`,0```,]<`0!!`````5T!`#,```!#70$`)0```'==`0`]````G5T!
M`&4```#;70$`30```$%>`0`M````CUX!`"<```"]7@$`+P```.5>`0`H````
M%5\!`"X````^7P$`,````&U?`0!4````GE\!`"<```#S7P$`@P```!M@`0!:
M````GV`!`#H```#Z8`$`2````#5A`0!*````?F$!`!\```#)80$`,@```.EA
M`0`O````'&(!`"P```!,8@$`+0```'EB`0!Q````IV(!`&\````98P$`LP``
M`(EC`0`7````/60!`"4```!59`$`,@```'MD`0`I````KF0!`#X```#89`$`
M(@```!=E`0!2````.F4!`"(```"-90$`)0```+!E`0`+````UF4!`+$```#B
M90$`(````)1F`0!%````M68!`"$```#[9@$`+@```!UG`0`P````3&<!`"4`
M``!]9P$`'````*-G`0`Q````P&<!``<```#R9P$`"````/IG`0`'`````V@!
M``0````+:`$`"@```!!H`0`-````&V@!``L````I:`$`#@```#5H`0`)````
M1&@!``L```!.:`$`!@```%IH`0`%````86@!`!````!G:`$``@```'AH`0!9
M````>V@!``4```#5:`$`$@```-MH`0`$````[F@!``<```#S:`$`"````/MH
M`0`%````!&D!``,````*:0$`$`````YI`0`*````'VD!``P````J:0$`$P``
M`#=I`0`-````2VD!``(```!9:0$`!P```%QI`0`'````9&D!``8```!L:0$`
M%````'-I`0`,````B&D!`!@```"5:0$`!@```*YI`0`$````M6D!`!(```"Z
M:0$`#````,UI`0`#````VFD!`"H```#>:0$`!`````EJ`0`&````#FH!``<`
M```5:@$`'P```!UJ`0`U````/6H!`"X```!S:@$`+P```*)J`0`7````TFH!
M`"````#J:@$`&P````MK`0`8````)VL!`"0```!`:P$`'P```&5K`0`:````
MA6L!`"````"@:P$`&@```,%K`0`R````W&L!`!D````/;`$`&@```"EL`0`O
M````1&P!`!0```!T;`$`*P```(EL`0`?````M6P!`",```#5;`$`'P```/EL
M`0`:````&6T!`"4````T;0$`)@```%IM`0`E````@6T!`"0```"G;0$`&```
M`,QM`0`=````Y6T!`"0````#;@$`&````"AN`0`B````06X!`!4```!D;@$`
M)0```'IN`0`9````H&X!`#P```"Z;@$`'P```/=N`0`C````%V\!`!\````[
M;P$`(````%MO`0`:````?&\!`"\```"7;P$`&````,=O`0`F````X&\!`!X`
M```'<`$`*0```"9P`0`>````4'`!``D```!O<`$`#````'EP`0`7````AG`!
M`"\```"><`$`)````,YP`0`'````\W`!``\```#[<`$`%`````MQ`0`.````
M('$!``T````O<0$`)````#UQ`0`%````8G$!``<```!H<0$`(@```'!Q`0`E
M````DW$!`!,```"Y<0$`&@```,UQ`0`=````Z'$!`!H````&<@$`!P```"%R
M`0#'````*7(!``L```#Q<@$`&0```/UR`0`5````%W,!``P````M<P$`!@``
M`#IS`0`)````07,!``L```!+<P$`#0```%=S`0`,````97,!`!T```!R<P$`
M%P```)!S`0`&````J',!`#,```"O<P$`$P```.-S`0`3````]W,!``<````+
M=`$`!@```!-T`0`/````&G0!``<````J=`$`,@```#)T`0`A````970!`!,`
M``"'=`$`#@```)MT`0`,````JG0!`!$```"W=`$`,@```,ET`0`0````_'0!
M``@````-=0$`'0```!9U`0`)````-'4!``H````^=0$`!0```$EU`0`4````
M3W4!``H```!D=0$`'0```&]U`0`(````C74!`!\```"6=0$`"````+9U`0`:
M````OW4!`"<```#:=0$`!@````)V`0`5````"78!``<````?=@$`"````"=V
M`0`)````,'8!`#\````Z=@$`!P```'IV`0`/````@G8!``X```"2=@$`$```
M`*%V`0`)````LG8!``D```"\=@$`"````,9V`0`3````SW8!``<```#C=@$`
M"````.MV`0`9````]'8!``H````.=P$`%P```!EW`0`4````,7<!``H```!&
M=P$`#````%%W`0`7````7G<!``0```!V=P$`*@```'MW`0`1````IG<!``<`
M``"X=P$`"0```,!W`0`"````RG<!`!````#-=P$`&````-YW`0`+````]W<!
M``,````#>`$`"`````=X`0`)````$'@!``0````:>`$`!P```!]X`0`'````
M)W@!``8````O>`$`%````#9X`0`'````2W@!``T```!3>`$`"P```&%X`0`4
M````;7@!`!4```"">`$`#@```)AX`0`O````IW@!`"````#7>`$`'````/AX
M`0!(````%7D!`$P```!>>0$`#````*MY`0`Q````N'D!``4```#J>0$`$@``
M`/!Y`0`_`````WH!`!(```!#>@$`"@```%9Z`0`&````87H!``0```!H>@$`
M!````&UZ`0`*````<GH!`!,```!]>@$`!0```)%Z`0`&````EWH!``8```">
M>@$`"0```*5Z`0`$````KWH!``P```"T>@$`"@```,%Z`0`)````S'H!`"``
M``#6>@$`!0```/=Z`0`8````_7H!`!D````6>P$`'P```#![`0`=````4'L!
M`!$```!N>P$``@```(![`0`$````@WL!``H```"(>P$`!@```)-[`0`4````
MFGL!``4```"O>P$``P```+5[`0`,````N7L!`$4```#&>P$`&@````Q\`0`U
M````)WP!`#H```!=?`$`*````)A\`0!3````P7P!`),````5?0$`+P```*E]
M`0!"````V7T!`#`````<?@$`+@```$U^`0`9````?'X!`"<```"6?@$`<@``
M`+Y^`0`@````,7\!`#4```!2?P$`(0```(A_`0!%````JG\!`#````#P?P$`
M*0```"&``0`A````2X`!`"@```!M@`$`*0```):``0`F````P(`!`"4```#G
M@`$`*`````V!`0`H````-H$!`"(```!?@0$`*P```(*!`0`\````KH$!`#``
M``#K@0$`$@```!R"`0`3````+X(!`!````!#@@$`>0```%2"`0`)````SH(!
M`'(```#8@@$`<P```$N#`0!\````OX,!`"L````\A`$`5````&B$`0`7````
MO80!`!4```#5A`$`%@```.N$`0`/`````H4!`&4````2A0$`'P```'B%`0!`
M````F(4!`!\```#9A0$`'````/F%`0!1````%H8!`!0```!HA@$`"@```'V&
M`0`%````B(8!``8```".A@$`"````)6&`0`%````GH8!`!(```"DA@$`$```
M`+>&`0`3````R(8!`!T```#<A@$`#P```/J&`0`/````"H<!``\````:AP$`
M`P```"J'`0`-````+H<!``0````\AP$`"0```$&'`0`+````2X<!``4```!7
MAP$`!0```%V'`0`'````8X<!``4```!KAP$`%````'&'`0`.````AH<!``<`
M``"5AP$`"````)V'`0`/````IH<!``T```"VAP$`"@```,2'`0`(````SX<!
M``P```#8AP$`!@```.6'`0`/````[(<!``<```#\AP$`!@````2(`0`%````
M"X@!`!0````1B`$`!@```":(`0`&````+8@!``P````TB`$`%0```$&(`0`7
M````5X@!``@```!OB`$`!````'B(`0`*````?8@!``,```"(B`$`!@```(R(
M`0`$````DX@!``0```"8B`$`"@```)V(`0`*````J(@!``8```"SB`$`!P``
M`+J(`0`$````PH@!``<```#'B`$`!````,^(`0`9````U(@!``<```#NB`$`
M`@```/:(`0`"````^8@!``D```#\B`$`!@````:)`0`&````#8D!`"<````4
MB0$``@```#R)`0`(````/XD!``0```!(B0$`"P```$V)`0`)````68D!``\`
M``!CB0$`$P```'.)`0`'````AXD!`!````"/B0$`$P```*")`0`'````M(D!
M``8```"\B0$`!@```,.)`0`0````RHD!`!(```#;B0$``@```.Z)`0`&````
M\8D!``D```#XB0$`,P````**`0`B````-HH!``<```!9B@$`!P```&&*`0`'
M````:8H!``L```!QB@$`$P```'V*`0`%````D8H!`!$```"7B@$``@```*F*
M`0`+````K(H!``0```"XB@$`"P```+V*`0`%````R8H!``<```#/B@$`<@$`
M`->*`0!S````2HP!`+@```"^C`$`0@```'>-`0#`````NHT!`)````![C@$`
M1@````R/`0`W````4X\!`#,```"+CP$`-@```+^/`0`O````]H\!`"X````F
MD`$`:````%60`0!E````OI`!`&<````DD0$`90```(R1`0!G````\I$!`&\`
M``!:D@$`/P```,J2`0!D````"I,!`$,```!ODP$`+P```+.3`0!-````XY,!
M`$0````QE`$`2@```':4`0`S````P90!`#@```#UE`$`;@```"Z5`0`N````
MG94!`"T```#,E0$`B````/J5`0!B````@Y8!``\!``#FE@$`3@```/:7`0`T
M````19@!`(L```!ZF`$`4`````:9`0`0````5YD!`!4```!HF0$`%````'Z9
M`0`'````DYD!``D```";F0$`"````*69`0`%````KID!`!X```"TF0$`+@``
M`-.9`0`L`````IH!`"D````OF@$`+@```%F:`0`8````B)H!``H```"AF@$`
M$0```*R:`0`*````OIH!`"L```#)F@$`$P```/6:`0`0````"9L!`!`````:
MFP$`(0```"N;`0`4````39L!``4```!BFP$`*````&B;`0`-````D9L!``T`
M``"?FP$`$P```*V;`0`-````P9L!``L```#/FP$`$````-N;`0`@````[)L!
M`!L````-G`$`$````"F<`0`*````.IP!`!8```!%G`$`/P```%R<`0`-````
MG)P!``\```"JG`$`$````+J<`0`+````RYP!``T```#7G`$`!@```.6<`0`E
M````[)P!`"0````2G0$`#0```#>=`0`3````19T!`!4```!9G0$`#0```&^=
M`0`;````?9T!``X```"9G0$`"````*B=`0`;````L9T!`!,```#-G0$`"```
M`.&=`0`)````ZIT!`!\```#TG0$`'````!2>`0`A````,9X!`!L```!3G@$`
M6````&^>`0`T````R)X!`!4```#]G@$`/0```!.?`0!.````49\!`&H```"@
MGP$`:0````N@`0!P````=:`!`&\```#FH`$`0@```%:A`0`"````F:$!``\`
M``"<H0$`$@```*RA`0`.````OZ$!`!,```#.H0$`#P```.*A`0`%````\J$!
M``8```#XH0$`$P```/^A`0`)````$Z(!``\````=H@$`$0```"VB`0`&````
M/Z(!`"$```!&H@$`(P```&BB`0`6````C*(!`!````"CH@$`#0```+2B`0`1
M````PJ(!``D```#4H@$`%0```-ZB`0`9````]*(!`!`````.HP$`$0```!^C
M`0`5````,:,!`!@```!'HP$`'P```&"C`0`D````@*,!`",```"EHP$`&```
M`,FC`0`:````XJ,!`!<```#]HP$`$````!6D`0`7````)J0!`!(````^I`$`
M*P```%&D`0`N````?:0!`!<```"LI`$`&````,2D`0`<````W:0!`!0```#Z
MI`$`60````^E`0`J````::4!`"H```"4I0$`*@```+^E`0`(````ZJ4!`!(`
M``#SI0$`-P````:F`0`-````/J8!``@```!,I@$`$````%6F`0`+````9J8!
M``4```!RI@$`$P```'BF`0`4````C*8!`!8```"AI@$`%@```+BF`0`1````
MSZ8!`!(```#AI@$`%````/2F`0`4````":<!``T````>IP$`&@```"RG`0`-
M````1Z<!``<```!5IP$`!P```%VG`0`'````9:<!``<```!MIP$`#````'6G
M`0`$````@J<!`!8```"'IP$`(@```)ZG`0`-````P:<!``\```#/IP$`#@``
M`-^G`0`3````[J<!``X````"J`$`"@```!&H`0`4````'*@!`!`````QJ`$`
M%P```$*H`0`<````6J@!`#````!WJ`$`"0```*BH`0`8````LJ@!`!X```#+
MJ`$`(P```.JH`0`1````#JD!`!0````@J0$`$@```#6I`0`/````2*D!`",`
M``!8J0$`'0```'RI`0`'````FJD!``8```"BJ0$`!P```*FI`0`:````L:D!
M``@```#,J0$`"@```-6I`0`1````X*D!``@```#RJ0$`"0```/NI`0`1````
M!:H!`!H````7J@$`!P```#*J`0`2````.JH!``4```!-J@$`%@```%.J`0`>
M````:JH!``\```")J@$`/P```)FJ`0`[````V:H!``D````5JP$`!P```!^K
M`0`3````)ZL!``0````[JP$`!0```$"K`0`0````1JL!``H```!7JP$`%```
M`&*K`0`\````=ZL!`!4```"TJP$``@```,JK`0#9````S:L!`"T```"GK`$`
M,@```-6L`0`Q````"*T!`#`````ZK0$`#````&NM`0`-````>*T!``D```"&
MK0$`!@```)"M`0`)````EZT!``<```"AK0$`.P```*FM`0`[````Y:T!`#H`
M```AK@$`7P```%RN`0`Y````O*X!`#D```#VK@$`.0```#"O`0!+````:J\!
M`"T```"VKP$`,````.2O`0`Y````%;`!`#\```!/L`$`%0```(^P`0`9````
MI;`!`#(```"_L`$`)@```/*P`0`3````&;$!``H````ML0$`$````#BQ`0`>
M````2;$!``4```!HL0$`#````&ZQ`0`>````>[$!`",```":L0$`!@```+ZQ
M`0`%````Q;$!`!4```#+L0$`"P```.&Q`0`(````[;$!``H```#VL0$`#@``
M``&R`0`,````$+(!``<````=L@$`!@```"6R`0`%````++(!``<````RL@$`
M!0```#JR`0`2````0+(!`#(```!3L@$`%P```(:R`0`-````GK(!``<```"L
ML@$`!P```+2R`0`*````O+(!``4```#'L@$`$P```,VR`0`&````X;(!`!(`
M``#HL@$`!0```/NR`0`(`````;,!``0````*LP$`"P````^S`0`&````&[,!
M`"4````BLP$`$0```$BS`0`K````6K,!`!X```"&LP$`"````*6S`0`.````
MKK,!``T```"]LP$`!P```,NS`0`'````T[,!``,```#;LP$``P```-^S`0`:
M````X[,!``L```#^LP$`(`````JT`0`K````*[0!``L```!7M`$`"@```&.T
M`0`7````;K0!`!(```"&M`$`%0```)FT`0`+````K[0!`"$```"[M`$`!0``
M`-VT`0`(````X[0!``@```#LM`$`7@```/6T`0`H````5+4!`!T```!]M0$`
M!@```)NU`0`(````HK4!`!\```"KM0$`"0```,NU`0`-````U;4!`"0```#C
MM0$`+P````BV`0`R````.+8!`"8```!KM@$`)@```)*V`0!=````N;8!`#X`
M```7MP$`%P```%:W`0`'````;K<!``H```!VMP$`$@```(&W`0`)````E+<!
M``P```">MP$`$````*NW`0`8````O+<!`!<```#5MP$`&````.VW`0`8````
M!K@!``D````?N`$`%0```"FX`0`'````/[@!`!D```!'N`$`&P```&&X`0`9
M````?;@!`!,```"7N`$`&````*NX`0`2````Q+@!``<```#7N`$`6P```-^X
M`0`)````.[D!`!4```!%N0$`-@```%NY`0`2````DKD!`!H```"EN0$`'0``
M`,"Y`0`9````WKD!`!<```#XN0$`'0```!"Z`0`>````+KH!`#(```!-N@$`
M2````("Z`0!'````R;H!`"4````1NP$`#0```#>[`0`L````1;L!`"<```!R
MNP$`'0```)J[`0`&````N+L!`!P```"_NP$`'@```-R[`0`>````^[L!`!H`
M```:O`$`&@```#6\`0`+````4+P!`!4```!<O`$`$P```'*\`0`-````AKP!
M``8```"4O`$`#P```)N\`0`(````J[P!`!4```"TO`$`%@```,J\`0`1````
MX;P!`!4```#SO`$`!0````F]`0`&````#[T!`!$````6O0$`"````"B]`0`3
M````,;T!``(```!%O0$`'@```$B]`0`'````9[T!`!,```!OO0$`$@```(.]
M`0`)````EKT!``H```"@O0$`"0```*N]`0`*````M;T!``<```#`O0$`!P``
M`,B]`0`-````T+T!``P```#>O0$`"````.N]`0`)````]+T!`!H```#^O0$`
M(@```!F^`0`-````/+X!`!@```!*O@$`'````&.^`0`*````@+X!`!X```"+
MO@$`'@```*J^`0`/````R;X!`!````#9O@$`,````.J^`0`_````&[\!`"$`
M``!;OP$`/````'V_`0`H````NK\!``X```#COP$`"0```/*_`0`*````_+\!
M``X````'P`$`!@```!;``0`/````'<`!`$8````MP`$`%@```'3``0`7````
MB\`!`!P```"CP`$`+@```,#``0`L````[\`!`#`````<P0$`+P```$W!`0`I
M````?<$!`"D```"GP0$`)@```-'!`0`Y````^,$!`"(````RP@$`,````%7"
M`0!"````AL(!`#$```#)P@$`,@```/O"`0`E````+L,!`#(```!4PP$`.0``
M`(?#`0!.````P<,!`#4````0Q`$`.````$;$`0!#````?\0!`"0```##Q`$`
M%@```.C$`0!/````_\0!`"D```!/Q0$`$@```'G%`0`[````C,4!`"(```#(
MQ0$`&````.O%`0#5````!,8!`!H```#:Q@$`+0```/7&`0`P````(\<!`#$`
M``!4QP$`,@```(;'`0`I````N<<!`!8```#CQP$`+@```/K'`0`W````*<@!
M`#H```!AR`$`/0```)S(`0`Z````VL@!`)H````5R0$`*P```+#)`0`?````
MW,D!`"@```#\R0$`-P```"7*`0`V````7<H!`%8```"4R@$`60```.O*`0`-
M````1<L!``0```!3RP$`!@```%C+`0`%````7\L!`!$```!ERP$`$0```'?+
M`0`.````B<L!`!````"8RP$`!@```*G+`0`5````L,L!`!L```#&RP$`%```
M`.++`0`1````]\L!``@````)S`$`%@```!+,`0`)````*<P!``X````SS`$`
M#P```$+,`0`1````4LP!``T```!DS`$`0P```'+,`0`&````MLP!`!$```"]
MS`$`$P```,_,`0`1````X\P!`!<```#US`$`&P````W-`0`/````*<T!``(`
M```YS0$`"P```#S-`0`3````2,T!`!P```!<S0$`!````'G-`0`0````?LT!
M`!````"/S0$``P```*#-`0`&````I,T!``@```"KS0$`#P```+3-`0`(````
MQ,T!`!````#-S0$`"````-[-`0`2````Y\T!``L```#ZS0$`%@````;.`0`/
M````'<X!`!$````MS@$`%@```#_.`0`6````5LX!``H```!MS@$`!P```'C.
M`0`,````@,X!``H```"-S@$`#@```)C.`0`-````I\X!`!$```"US@$`&@``
M`,?.`0`.````XLX!``X```#QS@$`)`````#/`0`:````)<\!`#@```!`SP$`
M#0```'G/`0`?````A\\!`!D```"GSP$`;@```,'/`0`8````,-`!`#8```!)
MT`$`)P```(#0`0`2````J-`!``D```"[T`$`"@```,70`0`3````T-`!``D`
M``#DT`$`,````.[0`0`[````']$!``\```!;T0$`$````&O1`0`A````?-$!
M`!(```">T0$`(P```+'1`0`C````U=$!``H```#YT0$`"0````32`0`'````
M#M(!`!P````6T@$`%@```#/2`0`>````2M(!`!8```!IT@$`%P```(#2`0`9
M````F-(!``<```"RT@$`"P```+K2`0`J````QM(!`#D```#QT@$`#0```"O3
M`0!*````.=,!``@```"$TP$`%````(W3`0`'````HM,!``H```"JTP$`-P``
M`+73`0`3````[=,!``8````!U`$`#P````C4`0`'````&-0!`!,````@U`$`
M`P```#34`0`4````.-0!``8```!-U`$`"P```%34`0`)````8-0!`!0```!J
MU`$`#````'_4`0`,````C-0!`!$```"9U`$`$0```*O4`0`7````O=0!`!H`
M``#5U`$`%````/#4`0`9````!=4!`!$````?U0$`&0```#'5`0`7````2]4!
M``@```!CU0$`!@```&S5`0`8````<]4!``L```",U0$``@```)C5`0`3````
MF]4!`!\```"OU0$`'P```,_5`0`8````[]4!`!(````(U@$`#P```!O6`0`/
M````*]8!`!4````[U@$`/@```%'6`0`R````D-8!``H```##U@$`"````,[6
M`0`-````U]8!``H```#EU@$`#P```/#6`0"B`````-<!`!X```"CUP$`30``
M`,+7`0`0````$-@!`!(````AV`$`!````#38`0`U````.=@!`"@```!OV`$`
M%@```)C8`0`&````K]@!`!0```"VV`$`*````,O8`0`%````]-@!``8```#Z
MV`$`$0````'9`0`I````$]D!`"`````]V0$`-````%[9`0`/````D]D!``X`
M``"CV0$`$````++9`0`.````P]D!``P```#2V0$`#@```-_9`0`+````[MD!
M`!````#ZV0$`"`````O:`0`+````%-H!``@````@V@$`%0```"G:`0`,````
M/]H!`#\```!,V@$`$0```(S:`0`(````GMH!``@```"GV@$`$P```+#:`0`3
M````Q-H!`!4```#8V@$`*P```.[:`0`G````&ML!`"(```!"VP$`(0```&7;
M`0`8````A]L!`!H```"@VP$`)0```+O;`0`9````X=L!``,```#[VP$`&0``
M`/_;`0`+````&=P!``L````EW`$``P```#'<`0`)````-=P!``@````_W`$`
M"@```$C<`0`1````4]P!``T```!EW`$`$````'/<`0`$````A-P!`"````")
MW`$`(0```*K<`0`3````S-P!``\```#@W`$`$P```/#<`0`7````!-T!`"X`
M```<W0$`!P```$O=`0`)````4]T!``D```!=W0$`$````&?=`0`0````>-T!
M``L```")W0$`"````)7=`0`)````GMT!``@```"HW0$`%@```+'=`0`,````
MR-T!``8```#5W0$`*0```-S=`0`.````!MX!`(D````5W@$`'0```)_>`0`'
M````O=X!``4```#%W@$`#0```,O>`0`%````V=X!``<```#?W@$`!@```.?>
M`0`(````[MX!`"0```#WW@$`$P```!S?`0`#````,-\!``@````TWP$`$@``
M`#W?`0`5````4-\!`!@```!FWP$`#P```'_?`0`2````C]\!`"<```"BWP$`
M"P```,K?`0`"````UM\!``,```#9WP$`$@```-W?`0`)````\-\!``T```#Z
MWP$`!@````C@`0`'````#^`!`!(````7X`$`(````"K@`0`(````2^`!`!,`
M``!4X`$`!````&C@`0`%````;>`!`!4```!SX`$`#0```(G@`0`@````E^`!
M``<```"XX`$`'0```,#@`0`/````WN`!`!$```#NX`$`"0````#A`0`,````
M"N$!``(````7X0$`!0```!KA`0`/````(.$!``H````PX0$`$@```#OA`0`&
M````3N$!`!(```!5X0$`"P```&CA`0`'````=.$!`!<```!\X0$`)@```)3A
M`0`3````N^$!``8```#/X0$`"0```-;A`0`$````X.$!`!8```#EX0$`"```
M`/SA`0`6````!>(!`!8````<X@$`$````#/B`0`%````1.(!``P```!*X@$`
M(````%?B`0`$````>.(!`$4```!]X@$`1@```,/B`0!%````"N,!`"4```!0
MXP$`$@```';C`0`3````B>,!``<```"=XP$`"0```*7C`0`6````K^,!`!``
M``#&XP$`%0```-?C`0`&````[>,!``4```#TXP$`%````/KC`0`%````#^0!
M`)P````5Y`$`"@```++D`0`>````O>0!``@```#<Y`$`"@```.7D`0`$````
M\.0!`#,```#UY`$`!0```"GE`0`<````+^4!``0```!,Y0$`$````%'E`0`0
M````8N4!`!8```!SY0$`#````(KE`0`%````E^4!`!H```"=Y0$`,@```+CE
M`0`W````Z^4!`$`````CY@$`+````&3F`0`R````D>8!`$$```#$Y@$`2@``
M``;G`0`Q````4><!`$4```"#YP$`-0```,GG`0`W````_^<!`"<````WZ`$`
M$````%_H`0`5````<.@!``L```"&Z`$`!P```)+H`0`H````FN@!`"````##
MZ`$`0@```.3H`0`A````)^D!`!\```!)Z0$`"````&GI`0`*````<ND!``H`
M``!]Z0$`%````(CI`0`I````G>D!`"<```#'Z0$`,````._I`0`+````(.H!
M`!D````LZ@$`*0```$;J`0`:````<.H!`!0```"+Z@$`%````*#J`0`-````
MM>H!`!````##Z@$`$P```-3J`0!$````Z.H!`'T````MZP$`@@```*OK`0`3
M````+NP!``T```!"[`$`#@```%#L`0`1````7^P!`!(```!Q[`$`%@```(3L
M`0`'````F^P!`!T```"C[`$`$@```,'L`0`<````U.P!`!,```#Q[`$`$@``
M``7M`0`5````&.T!`"P````N[0$`+````%OM`0!M````B.T!`!4```#V[0$`
M$@````SN`0`8````'^X!`!8````X[@$`"@```$_N`0`*````6NX!`"$```!E
M[@$`'0```(?N`0`6````I>X!``X```"\[@$`#@```,ON`0`5````VNX!`!4`
M``#P[@$`*@````;O`0`I````,>\!`"D```!;[P$`*````(7O`0`G````KN\!
M`"D```#6[P$`&@````#P`0!5````&_`!`!,```!Q\`$`%0```(7P`0`5````
MF_`!`!0```"Q\`$`$0```,;P`0`7````V/`!`!<```#P\`$`%`````CQ`0`3
M````'?$!`#H````Q\0$`&````&SQ`0`9````A?$!`#X```"?\0$`%0```-[Q
M`0`'````]/$!`!$```#\\0$`(`````[R`0`3````+_(!`!,```!#\@$`'@``
M`%?R`0`B````=O(!`!T```"9\@$`&P```+?R`0`:````T_(!`"(```#N\@$`
M$@```!'S`0`<````)/,!`"$```!!\P$`'````&/S`0`8````@/,!`!L```"9
M\P$`$P```+7S`0`;````R?,!`!P```#E\P$`'`````+T`0`8````'_0!``H`
M```X]`$`&@```$/T`0`3````7O0!`!0```!R]`$`"P```(?T`0`4````D_0!
M`!````"H]`$`!P```+GT`0`'````P?0!`!(```#)]`$`!P```-ST`0`'````
MY/0!``4```#L]`$`%0```/+T`0`&````"/4!`!L````/]0$`!0```"OU`0`%
M````,?4!``H````W]0$`!P```$+U`0`*````2O4!`!4```!5]0$`%````&OU
M`0`8````@/4!`!4```"9]0$`$P```*_U`0`L````P_4!`!,```#P]0$`$```
M``3V`0`:````%?8!`!0````P]@$`#0```$7V`0`3````4_8!`#$```!G]@$`
M#@```)GV`0`&````J/8!``D```"O]@$`)P```+GV`0`3````X?8!`!````#U
M]@$`!@````;W`0`3````#?<!``L````A]P$`!@```"WW`0`A````-/<!`!``
M``!6]P$`$@```&?W`0`1````>O<!``H```",]P$`$@```)?W`0`4````JO<!
M`!(```"_]P$`&````-+W`0`5````Z_<!``T````!^`$`!P````_X`0`4````
M%_@!``,````L^`$`"@```##X`0`A````._@!``8```!=^`$`"````&3X`0`5
M````;?@!`!(```"#^`$`!@```);X`0`'````G?@!`#,```"E^`$`#````-GX
M`0`3````YO@!``D```#Z^`$`$@````3Y`0`5````%_D!`!$````M^0$`%0``
M`#_Y`0`-````5?D!``0```!C^0$`"@```&CY`0`D````<_D!``<```"8^0$`
M%````*#Y`0!)````M?D!``@```#_^0$`#P````CZ`0`E````&/H!`!4````^
M^@$`&````%3Z`0`.````;?H!`!````!\^@$`#@```(WZ`0`+````G/H!``T`
M``"H^@$`$P```+;Z`0`3````ROH!`!<```#>^@$`+````/;Z`0`+````(_L!
M`!4````O^P$`!@```$7[`0`9````3/L!``T```!F^P$`#````'3[`0`:````
M@?L!``4```"<^P$`!@```*+[`0`$````J?L!`!(```"N^P$`5@```,'[`0`6
M````&/P!``L````O_`$`!````#O\`0`%````0/P!`!@```!&_`$`&0```%_\
M`0`:````>?P!``H```"4_`$``@```)_\`0`$````HOP!`",```"G_`$``P``
M`,O\`0`%````S_P!`"@```#5_`$`"@```/[\`0`%````"?T!``<````/_0$`
M&````!?]`0`1````,/T!`%$```!"_0$`$@```)3]`0`&````I_T!``<```"N
M_0$`"````+;]`0`$````O_T!``4```#$_0$`&@```,K]`0!D````Y?T!``H`
M``!*_@$`#0```%7^`0`%````8_X!``8```!I_@$`&0```'#^`0`X````BOX!
M``X```##_@$`"0```-+^`0`7````W/X!``H```#T_@$`"````/_^`0`9````
M"/\!`"\````B_P$`*0```%+_`0`H````?/\!`!(```"E_P$`!````+C_`0`'
M````O?\!``@```#%_P$`"````,[_`0`'````U_\!``X```#?_P$`#0```.[_
M`0`,````_/\!`#8````)``(`'P```$```@`Q````8``"`"4```"2``(`"```
M`+@``@!9````P0`"`!$````;`0(`$````"T!`@`2````/@$"`!D```!1`0(`
M3@```&L!`@`=````N@$"``8```#8`0(`'P```-\!`@`'````_P$"``8````'
M`@(`(`````X"`@`&````+P("``D````V`@(`)P```$`"`@`F````:`("``D`
M``"/`@(`!P```)D"`@`*````H0("`!D```"L`@(`)0```,8"`@!+````[`("
M`!@````X`P(`'0```%$#`@`6````;P,"``,```"&`P(`#0```(H#`@`(````
MF`,"`!,```"A`P(`#0```+4#`@`&````PP,"``8```#*`P(`%````-$#`@`4
M````Y@,"``T```#[`P(`"`````D$`@`#````$@0"``P````6!`(`"0```",$
M`@`+````+00"`!@````Y!`(`$P```%($`@`.````9@0"``L```!U!`(`"@``
M`($$`@`+````C`0"`!$```"8!`(`#P```*H$`@`2````N@0"`!,```#-!`(`
M!@```.$$`@`5````Z`0"`!0```#^!`(`!0```!,%`@`&````&04"``4````@
M!0(`%P```"8%`@`@````/@4"`$D```!?!0(`$0```*D%`@`-````NP4"`!,`
M``#)!0(`%````-T%`@`9````\@4"``P````,!@(`%````!D&`@`0````+@8"
M`!$````_!@(`!````%$&`@`4````5@8"``4```!K!@(`!0```'$&`@`7````
M=P8"`!,```"/!@(`%````*,&`@`<````N`8"`"$```#5!@(`&0```/<&`@`9
M````$0<"`!T````K!P(`(@```$D'`@`<````;`<"``0```")!P(`!0```(X'
M`@`.````E`<"``X```"C!P(`"P```+('`@`(````O@<"`"(```#'!P(`#0``
M`.H'`@`4````^`<"``@````-"`(`$@```!8(`@`'````*0@"`!$````Q"`(`
M$````$,(`@`+````5`@"``L```!@"`(`#@```&P(`@`+````>P@"``\```"'
M"`(`#@```)<(`@`(````I@@"`!8```"O"`(`$@```,8(`@`<````V0@"``4`
M``#V"`(`!````/P(`@`#`````0D"``X````%"0(`"0```!0)`@`1````'@D"
M`%$````P"0(`/P```(()`@`>````P@D"`"0```#A"0(`00````8*`@`O````
M2`H"`!$```!X"@(`/@```(H*`@`N````R0H"`!P```#X"@(`.@```!4+`@!*
M````4`L"`%<```";"P(`7````/,+`@`0````4`P"`"(```!A#`(`#@```(0,
M`@!'````DPP"`!@```#;#`(`%0```/0,`@`R````"@T"`"$````]#0(`(0``
M`%\-`@`>````@0T"`",```"@#0(`'P```,0-`@`9````Y`T"`!L```#^#0(`
M$P```!H.`@`Y````+@X"`#D```!H#@(`/0```*(.`@`Y````X`X"`#H````:
M#P(`.P```%4/`@`X````D0\"`'$```#*#P(`'0```#P0`@`-````6A`"``H`
M``!H$`(`"0```',0`@`P````?1`"`#L```"N$`(`*0```.H0`@`W````%!$"
M``L```!,$0(`2P```%@1`@!&````I!$"``8```#K$0(`%P```/(1`@`5````
M"A("``\````@$@(`$````#`2`@`7````01("`!````!9$@(`#P```&H2`@`.
M````>A("`!,```")$@(`#@```)T2`@`1````K!("``P```"^$@(`#@```,L2
M`@`%````VA("`",```#@$@(`!`````03`@!@````"1,"``@```!J$P(`!0``
M`',3`@`&````>1,"`!0```"`$P(`$0```)43`@`0````IQ,"`%(```"X$P(`
M`@````L4`@`'````#A0"`!(````6%`(`(````"D4`@`%````2A0"``<```!0
M%`(`&P```%@4`@`(````=!0"`!````!]%`(`,@```(X4`@`6````P10"`#(`
M``#8%`(`=@````L5`@`5````@A4"`$X```"8%0(`(@```.<5`@`1````"A8"
M``@````<%@(`%0```"46`@`&````.Q8"``P```!"%@(`!P```$\6`@`.````
M5Q8"``L```!F%@(`%@```'(6`@`+````B18"`!P```"5%@(`&````+(6`@`%
M````RQ8"`!(```#1%@(`!````.06`@`2````Z18"`"4```#\%@(`%@```"(7
M`@`5````.1<"`!$```!/%P(`(P```&$7`@`*````A1<"``P```"0%P(``@``
M`)T7`@`4````H!<"`!,```"U%P(`#````,D7`@`.````UA<"``L```#E%P(`
M$P```/$7`@`-````!1@"``H````3&`(`'P```!X8`@`2````/A@"`!<```!1
M&`(`$````&D8`@`&````>A@"`!````"!&`(`%0```)(8`@`6````J!@"``T`
M``"_&`(`&````,T8`@`Q````YA@"`!T````8&0(`#@```#89`@`/````11D"
M`"0```!5&0(`&0```'H9`@`%````E!D"`!$```":&0(`!P```*P9`@`&````
MM!D"`!8```"[&0(`!P```-(9`@`+````VAD"`"````#F&0(`-`````<:`@`?
M````/!H"``D```!<&@(`(@```&8:`@`0````B1H"``H```":&@(`&P```*4:
M`@`-````P1H"`!0```#/&@(`!````.0:`@`4````Z1H"``D```#^&@(`"```
M``@;`@`+````$1L"``X````=&P(`!@```"P;`@`*````,QL"`"$````^&P(`
M/P```&`;`@!`````H!L"`"0```#A&P(`+0````8<`@`J````-!P"`$<```!?
M'`(`)````*<<`@`S````S!P"`$,`````'0(`80```$0=`@`T````IAT"`"T`
M``#;'0(`!P````D>`@`(````$1X"``D````:'@(`$````"0>`@`4````-1X"
M`!L```!*'@(`&P```&8>`@`9````@AX"`!L```"<'@(`,````+@>`@`E````
MZ1X"`"(````/'P(`.@```#(?`@!"````;1\"``<```"P'P(`&0```+@?`@`)
M````TA\"``@```#<'P(`(````.4?`@`,````!B`"``\````3(`(`#````",@
M`@`1````,"`"`!0```!"(`(`#0```%<@`@`(````92`"`!4```!N(`(`"0``
M`(0@`@`/````CB`"``T```">(`(`&@```*P@`@`8````QR`"`#L```#@(`(`
M"@```!PA`@`/````)R$"``8````W(0(`&@```#XA`@`0````62$"``4```!J
M(0(`#0```'`A`@`0````?B$"``D```"/(0(`#````)DA`@`,````IB$"``X`
M``"S(0(`!P```,(A`@`#````RB$"``T```#.(0(`-@```-PA`@!(````$R("
M``L```!<(@(`"0```&@B`@`2````<B("`!<```"%(@(`%@```)TB`@`1````
MM"("`!(```#&(@(`$@```-DB`@`3````["("`!$`````(P(`&````!(C`@`E
M````*R,"`"$```!1(P(`$0```',C`@`5````A2,"``L```";(P(`#````*<C
M`@`3````M","`!0```#((P(`$@```-TC`@`I````\","``<````:)`(`"@``
M`"(D`@`4````+20"``T```!")`(`#@```%`D`@`2````7R0"``L```!R)`(`
M/````'XD`@`)````NR0"`!P```#%)`(`$@```.(D`@`6````]20"`$`````,
M)0(`)````$TE`@`-````<B4"`#P```"`)0(`.@```+TE`@`V````^"4"`!P`
M```O)@(`$0```$PF`@`8````7B8"``8```!W)@(`%P```'XF`@`<````EB8"
M`!D```"S)@(`"````,TF`@`*````UB8"`!T```#A)@(`"P```/\F`@`0````
M"R<"``<````<)P(`%0```"0G`@`5````.B<"``D```!0)P(`!P```%HG`@`4
M````8B<"`!$```!W)P(`&0```(DG`@`%````HR<"``<```"I)P(`"0```+$G
M`@`0````NR<"``\```#,)P(`%0```-PG`@`5````\B<"``<````(*`(`!@``
M`!`H`@`Q````%R@"`"D```!)*`(`)0```',H`@`(````F2@"``\```"B*`(`
M$P```+(H`@`?````QB@"`!X```#F*`(`'P````4I`@`-````)2D"``P````S
M*0(``P```$`I`@`'````1"D"``T```!,*0(`%0```%HI`@`#````<"D"``P`
M``!T*0(`$0```($I`@`+````DRD"`!0```"?*0(`&````+0I`@`5````S2D"
M`!P```#C*0(`(P`````J`@`3````)"H"`!8````X*@(`!@```$\J`@`.````
M5BH"``<```!E*@(`"@```&TJ`@`,````>"H"`!````"%*@(`#@```)8J`@`.
M````I2H"`%H```"T*@(`&`````\K`@`L````*"L"`!4```!5*P(`!P```&LK
M`@`(````<RL"`!(```!\*P(`%0```(\K`@`K````I2L"`"0```#1*P(`%```
M`/8K`@`8````"RP"`!,````D+`(`(0```#@L`@`8````6BP"`!8```!S+`(`
M)````(HL`@`H````KRP"`!4```#8+`(`7P```.XL`@`L````3BT"`%\```![
M+0(`(0```-LM`@`=````_2T"`",````;+@(`'P```#\N`@`C````7RX"`"<`
M``"#+@(`+0```*LN`@`C````V2X"`!T```#]+@(`)````!LO`@`J````0"\"
M`"0```!K+P(`*````)`O`@`@````N2\"`"(```#:+P(`'0```/TO`@`*````
M&S`"`%T````F,`(`&P```(0P`@!6````H#`"`!0```#W,`(`"0````PQ`@`(
M````%C$"`!,````?,0(`#P```#,Q`@`K````0S$"`!4```!O,0(`"````(4Q
M`@`3````CC$"`&````"B,0(`(P````,R`@`8````)S("`#\```!`,@(`.P``
M`(`R`@!0````O#("`'`````-,P(`"@```'XS`@`E````B3,"`"\```"O,P(`
M"0```-\S`@`;````Z3,"`!<````%-`(`!P```!TT`@`-````)30"`#X````S
M-`(`!P```'(T`@`2````>C0"`!X```"--`(`1@```*PT`@!)````\S0"`#$`
M```]-0(`'@```&\U`@`[````CC4"`"T```#*-0(`+@```/@U`@`G````)S8"
M``X```!/-@(`+````%XV`@`W````BS8"`"L```##-@(`'0```.\V`@!!````
M#3<"`#8```!/-P(`/P```(8W`@`U````QC<"`#@```#\-P(`%````#4X`@`*
M````2C@"`!,```!5.`(`%@```&DX`@`8````@#@"``@```"9.`(`,0```*(X
M`@`*````U#@"``H```#?.`(`)@```.HX`@`*````$3D"`!<````<.0(`%@``
M`#0Y`@`'````2SD"`!$```!3.0(`$0```&4Y`@`*````=SD"`!8```"".0(`
M!````)DY`@`%````GCD"``8```"D.0(`#P```*LY`@`2````NSD"`!````#.
M.0(`'0```-\Y`@`-````_3D"``<````+.@(`$````!,Z`@`@````)#H"`!(`
M``!%.@(`#0```%@Z`@`:````9CH"`"8```"!.@(`#@```*@Z`@`?````MSH"
M`"\```#7.@(`"0````<[`@`+````$3L"`!@````=.P(`$````#8[`@`6````
M1SL"`!D```!>.P(`#@```'@[`@`0````ASL"``T```"8.P(`"0```*8[`@`M
M````L#L"``T```#>.P(`!@```.P[`@`)````\SL"``P```#].P(`#`````H\
M`@`,````%SP"``T````D/`(`!P```#(\`@`3````.CP"``8```!./`(`'```
M`%4\`@`8````<CP"``\```"+/`(`"````)L\`@`>````I#P"`!L```##/`(`
M#````-\\`@`#````[#P"``<```#P/`(`"````/@\`@!N`````3T"`!````!P
M/0(`!P```($]`@`G````B3T"`$8```"Q/0(`'````/@]`@`G````%3X"`$0`
M```]/@(`,0```((^`@!`````M#X"`!P```#U/@(`%@```!(_`@`2````*3\"
M``8````\/P(`#0```$,_`@`*````43\"``<```!</P(`"0```&0_`@`-````
M;C\"`!$```!\/P(`#P```(X_`@`*````GC\"``P```"I/P(`$````+8_`@`'
M````QS\"``@```#//P(`!P```-@_`@`4````X#\"`!0```#U/P(`#P````I`
M`@`%````&D`"`"4````@0`(`%0```$9``@`*````7$`"`!0```!G0`(`"P``
M`'Q``@`4````B$`"``L```"=0`(`!@```*E``@`6````L$`"`!8```#'0`(`
M!P```-Y``@`'````YD`"`!D```#N0`(`"`````A!`@`%````$4$"``<````7
M00(`$@```!]!`@`;````,D$"``L```!.00(`#0```%I!`@`M````:$$"`"$`
M``"600(`&````+A!`@`)````T4$"``4```#;00(`#````.%!`@`4````[D$"
M``T````#0@(``P```!%"`@`3````%4("`!(````I0@(`'P```#Q"`@!`````
M7$("`#P```"=0@(`(P```-I"`@`T````_D("`#$````S0P(`-````&5#`@`B
M````FD,"`&(```"]0P(`%@```"!$`@`H````-T0"`!T```!@1`(`'P```'Y$
M`@`J````GD0"`!\```#)1`(`;@```.E$`@`[````6$4"`%8```"410(`<0``
M`.M%`@`M````748"`#P```"+1@(`+P```,A&`@`X````^$8"`"L````Q1P(`
M,````%U'`@`P````CD<"`!P```"_1P(`.@```-Q'`@`T````%T@"`+\!``!,
M2`(`*P````Q*`@`?````.$H"`!8```!82@(`5@```&]*`@",````QDH"`#,`
M``!32P(`0````(=+`@!:````R$L"`%`````C3`(`(@```'1,`@`5````ETP"
M`!T```"M3`(`'0```,M,`@`J````Z4P"`!P````430(`)0```#%-`@`C````
M5TT"`!8```![30(`-P```))-`@`J````RDT"`"@```#U30(`,````!Y.`@`:
M````3TX"`#````!J3@(`8@```)M.`@`M````_DX"`#0````L3P(`10```&%/
M`@`R````IT\"`"L```#:3P(`1P````90`@!E````3E`"`%H```"T4`(`*P``
M``]1`@`I````.U$"`#$```!E40(`)@```)=1`@`N````OE$"`"P```#M40(`
M60```!I2`@`E````=%("`)4```":4@(`;````#!3`@`_````G5,"`%P```#=
M4P(`6@```#I4`@`=````E50"`#(```"S5`(`)0```.94`@`E````#%4"`"L`
M```R50(`;@```%Y5`@!K````S54"`,`````Y5@(`&0```/I6`@`G````%%<"
M`#X````\5P(`+0```'M7`@!1````J5<"`"<```#[5P(`7````"-8`@`I````
M@%@"`!X```"J6`(`"@```,E8`@#>````U%@"`!X```"S60(`.P```-)9`@`I
M````#EH"`$(````X6@(`/0```'M:`@`E````N5H"`"````#?6@(`/P````!;
M`@`(````0%L"``P```!)6P(`"````%9;`@`)````7UL"``X```!I6P(`$P``
M`'A;`@`0````C%L"`!(```"=6P(`#0```+!;`@`+````OEL"``<```#*6P(`
M!@```-);`@`.````V5L"``0```#H6P(`7````.U;`@`$````2EP"`!$```!/
M7`(`$@```&%<`@`(````=%P"``8```!]7`(`#@```(1<`@`$````DUP"`!8`
M``"87`(`"@```*]<`@`)````NEP"`!$```#$7`(`$P```-9<`@`#````ZEP"
M``L```#N7`(`%````/I<`@`4````#UT"`!(````D70(`#@```#==`@`5````
M1ET"``8```!<70(`!````&-=`@`6````:%T"``T```!_70(``P```(U=`@`T
M````D5T"``0```#&70(`$P```,M=`@`'````WUT"`"0```#G70(`4`````Q>
M`@`Y````75X"`#H```"77@(`'P```-)>`@`G````\EX"`"(````:7P(`)@``
M`#U?`@`H````9%\"`",```"-7P(`)0```+%?`@`L````UU\"`"<````$8`(`
M.P```"Q@`@`=````:&`"`"(```"&8`(`.````*E@`@`7````XF`"`#0```#Z
M8`(`)0```"]A`@`I````56$"`"P```!_80(`)P```*QA`@`L````U&$"`"T`
M```!8@(`-0```"]B`@`A````96("`"4```"'8@(`*@```*UB`@`R````V&("
M`"4````+8P(`+````#%C`@`;````7F,"`"4```!Z8P(`'@```*!C`@!"````
MOV,"`"8````"9`(`*@```"ED`@`M````5&0"`"X```""9`(`)@```+%D`@`P
M````V&0"`"0````)90(`+@```"YE`@`K````764"`#@```")90(`'0```,)E
M`@`*````X&4"`!,```#K90(`&0```/]E`@`L````&68"`",```!&9@(`#0``
M`&IF`@`/````>&8"`!8```"(9@(`"P```)]F`@`9````JV8"`"H```#%9@(`
M"````/!F`@`,````^68"`"$````&9P(`,@```"AG`@`8````6V<"`"L```!T
M9P(`*P```*!G`@`D````S&<"``@```#Q9P(`Y@```/IG`@`1````X6@"`"X`
M``#S:`(`%@```")I`@`,````.6D"``D```!&:0(`#0```%!I`@`5````7FD"
M`!$```!T:0(`$````(9I`@`I````EVD"`"(```#!:0(`!@```.1I`@!%````
MZVD"`!P````Q:@(`'0```$YJ`@`=````;&H"``L```"*:@(`$P```)9J`@`)
M````JFH"`%(```"T:@(`*@````=K`@`=````,FL"`!<```!0:P(`%````&AK
M`@`7````?6L"`"@```"5:P(`&````+YK`@`2````UVL"`"0```#J:P(`$P``
M``]L`@`4````(VP"``P````X;`(`&````$5L`@`8````7FP"`!<```!W;`(`
M"````(]L`@`L````F&P"``D```#%;`(`*0```,]L`@`H````^6P"``<````B
M;0(`&P```"IM`@`'````1FT"``@```!.;0(`"0```%=M`@`\````86T"``8`
M``">;0(`$P```*5M`@`4````N6T"``X```#.;0(`"0```-UM`@`*````YVT"
M`"````#R;0(`$P```!-N`@`-````)VX"``L````U;@(`%@```$%N`@`2````
M6&X"`!@```!K;@(`&````(1N`@`,````G6X"``X```"J;@(`&````+EN`@`$
M````TFX"`"\```#7;@(`#P````=O`@`%````%V\"``<````=;P(``P```"5O
M`@`1````*6\"`",````[;P(`"P```%]O`@`#````:V\"``8```!O;P(`#```
M`'9O`@`&````@V\"``D```"*;P(`"0```)1O`@`,````GF\"`!D```"K;P(`
M#````,5O`@`1````TF\"`!````#D;P(`%@```/5O`@`7````#'`"``4````D
M<`(`+P```"IP`@`?````6G`"`!X```!Z<`(`7````)EP`@!:````]G`"``D`
M``!1<0(`*0```%MQ`@`'````A7$"`!<```"-<0(`/@```*5Q`@`1````Y'$"
M`!(```#V<0(`"`````ER`@`$````$G("``4````7<@(`#0```!UR`@`:````
M*W("``8```!&<@(`!P```$UR`@`)````57("`!$```!?<@(`"````'%R`@`2
M````>G("`!(```"-<@(`"0```*!R`@`P````JG("`!0```#;<@(`&0```/!R
M`@`D````"G,"`"(````O<P(`)0```%)S`@`0````>',"``(```")<P(`!```
M`(QS`@`+````D7,"``H```"=<P(`$0```*AS`@`%````NG,"``,```#`<P(`
M#0```,1S`@!'````TG,"`!4````:=`(`,@```#!T`@!%````8W0"`#D```"I
M=`(`4@```.-T`@"J````-G4"`"X```#A=0(`1````!!V`@`K````578"`"H`
M``"!=@(`#P```*QV`@`C````O'8"`'8```#@=@(`(@```%=W`@!.````>G<"
M`"\```#)=P(`-@```/EW`@`]````,'@"`"L```!N>`(`*````)IX`@`I````
MPW@"`"<```#M>`(`,````!5Y`@`T````1GD"`"T```![>0(`*0```*EY`@`L
M````TWD"`"X`````>@(`0````"]Z`@`Q````<'H"`"8```"B>@(`%````,EZ
M`@`0````WGH"`'L```#O>@(`"@```&M[`@!X````=GL"`'H```#O>P(`>0``
M`&I\`@`P````Y'P"`&$````5?0(`%````'=]`@`<````C'T"`!(```"I?0(`
M#0```+Q]`@"#````RGT"`"8```!.?@(`.0```'5^`@`B````KWX"`"````#2
M?@(`:P```/-^`@`;````7W\"``H```![?P(`!0```(9_`@`&````C'\"``@`
M``"3?P(`!0```)Q_`@`7````HG\"`!D```"Z?P(`%P```-1_`@`B````['\"
M`!$````/@`(`$````"&``@`.````,H`"``,```!!@`(`#P```$6``@`(````
M58`"``<```!>@`(`#@```&:``@`'````=8`"``@```!]@`(`!P```(:``@`&
M````CH`"`!<```"5@`(`$@```*V``@`'````P(`"``4```#(@`(`$@```,Z`
M`@`4````X8`"``P```#V@`(`!P````.!`@`+````"X$"``D````7@0(`$P``
M`"&!`@`)````-8$"``T````_@0(`"````$V!`@`7````5H$"``4```!N@0(`
M#0```'2!`@`)````@H$"`!````",@0(`&0```)V!`@`*````MX$"``4```#"
M@0(`"P```,B!`@`#````U($"``8```#8@0(`!````-^!`@`%````Y($"``L`
M``#J@0(`"P```/:!`@`&`````H("``H````)@@(`"````!2"`@`,````'8("
M``(````J@@(`$P```"V"`@`'````08("``(```!)@@(``@```$R"`@`(````
M3X("``@```!8@@(`!P```&&"`@`L````:8("``(```"6@@(`!P```)F"`@`$
M````H8("``X```"F@@(`#@```+6"`@`0````Q(("`!4```#5@@(`$````.N"
M`@`-````_(("`!8````*@P(`"P```"&#`@`&````+8,"``<````T@P(`$@``
M`#R#`@`2````3X,"``(```!B@P(`!P```&6#`@`0````;8,"`"H```!^@P(`
M-@```*F#`@`)````X(,"``@```#J@P(`"P```/.#`@`<````_X,"`!,````<
MA`(`!0```#"$`@`6````-H0"``8```!-A`(`"P```%2$`@`&````8(0"``T`
M``!GA`(`!P```'6$`@`&````?80"``$```"#!```R````#(````J!P``PP``
M``````"7!```AP$``+(`````````7P8``$X!``!;"```N00``*,%``"*`0``
M`````.0'````````(@<``%D````J!```_00``(4&``##!P``PP8``(L'``""
M!```G@,``/X!`````````````*L$``#_!@``"P4```D'`````P``)@<`````
M```O!@``!0,```````!Z!0``Z@```-L'````````9P@``.0"```A!P``R@$`
M````````````8P0``'T%````````]P<``#<````O!`````````````";!@``
M`P@``,8!````````"0(``*L&``!K`P````````````#G!`````````````"[
M`@``50(```````"F!@``Y@,```````#,`@``;0(```T#``"7!P``00``````
M```D`0``.P@``/H&``````````````````"&!@```````.P$``!=!0``2@``
M```````U`P``[`4``*<%``#X!0``&@<`````````````6@4``(<#``#8`@``
M)0(```0(``"!!0``.P8``&0&``"&````B0(``/0`````````$04``#\!``"H
M"```/@0``)P&``"J"```1P8``&H#``",!@```````#T#``!%`@``0@(`````
M```4!@``9@4``'0#``!/!```90```.P#``!@`0``\P4```````"<`P``10,`
M``````!-`@```04``%,#``!"!P``JP@```````#1!0````````````!0`0``
M1`0``-`!`````````````.,!``#;!0``C`,``,0%``"R!@``1P0````````;
M`@``1P````\%````````Y0<`````````````Q@<``(`"``!Y`P``*`@``*`$
M``#'!P```````'(&``"^!```Q`,```````!?!0``C@```#\$``"9!P``V`4`
M````````````HP0``)("```D!````````)\"``!M````<`$```````!I"```
M9P$``-X&``!9!````````&,#``!4"```P@$``&<'```]`@``O@8``$@#```?
M`@``J@$```````"+`0``B0<``&D%``"6"```6@0``'4'```S!P``P00``&((
M`````````````/H#```&!@```````&@!``"1`@``X0<``&0%``#[!```1`,`
M```````,`@``L0<``.@'````````M@8``!4$``"E`0``````````````````
M\0$```````!#`P``>0(``*H&``#Y!@```````!<'``!\`0```````"<"``#"
M!```C@8``````````````````'\!``!&!```8`<``!\(````````10```$\(
M``"F!P```P0``'0"````````Z@<``,\!``#3````\0<``)X$``#]````````
M`'\%```R"```.@(``&8'```G`P``=@@``%,!````````70```/(#``"#!P``
M@@4```P&``"Z!0``C@<``*H````R!@``Z0<``.@&```=`@``XP<``/('``"8
M`P``.P`````````<`0``]0<```````#7`P``#P,``.\"``#A!0``!P4``%('
M````````9P(```````````````0`````````````#P@``!X%``"."```"@0`
M`#$`````"````````$@!``"Y!0``*@(``/\````D````G`(``.H!``!2!```
M`````&H$````````=`<``)P!````````YP4``'`#``#+`0``3@```.@"``!Z
M"```SP,`````````````>P0``*0"``!@`P``%@0```````"R`0``>@<``+<%
M````````G`<```````!9!0``J04````````"!```<@```.8"````````I0<`
M`$`(```M`@```````#H#```4`@````````````"D`P``IP$``,D!``#*!@``
M`````+\!``"3!```"P8``-P```!]`@``I@```!P```"<!```#08``!H$```7
M`@``H0$``+,'``"$!P``\````+H"``"`!@``EP@```````#Y!```@@(``*@$
M````````)`4``.<!``!7`0``)@4``&D!``"J`@``V@(```8#``!6````5`,`
M`#T%``#.`@``\0(``$0'```[!P``@0(``-$&`````````````(X!```5`@``
M+`0``*(`````````]@4`````````````\`8``&L!``!L`````````!,#````
M````TP,``"P```!P!0``%0$``,4&``"]!@``$@0```````!"````+`$``*,"
M``#6`P``3P8``&,(``"R`@```````$D!````````$P8``$0(``#5`0``````
M`'8&```@````````````````````J0(``,<#``!U````[0$``'`(``#W!```
M`````#P(``!,!````````"X%```$!@``^@```(D$````````M``````````5
M````V`<``$H$```0````<0,``&\!````````_P0``%$```#H!```=04``&T$
M``"(!````````!T!``"1!```4@4``%0'``!(!```K0(``#X&``"<"```:@@`
M`.\$````````>`0```````#$`@```````"P&``!.!0``*@,``*P!``"#`@``
MI0(``-<%``#!`0``O00``,H`````````2@4``/0#```O!0``,04``-X'````
M````'`(``#$!``!V`````````,T"```K!```L`<``)T```"V!P```````'L"
M`````````````,D$``!L"`````````````"<````B`@``%0"```E````R08`
M`#D'``#]`@``;P(``'8!``!8!@``&@8``'X(```O!P``P`,``#L"```T!0``
MI@4``%`$```#!@``S0,``+`$```!!````P$``,\'````````$`4```````!:
M`P``@P```!`(``!J!@``C0````````!<!```J0$``+,&```1!```=P,`````
M``!)`P```````.$&``#!````OP8```H````'!```N`8`````````````!```
M`#H(``!G`P````````````!M!P``$@8``-4#``!X``````````````!W`@``
M+00``!X````*`@``U@(```````#M`@``EP$``(@"```T!P``F`$```````#E
M`0````````$&``#X`0``KP4``!0`````````^0<``%$!```9!```I@@`````
M``!9`@``GP8```````!8!0``B`8``"4&``"1````S@,``&8$``#X!@``/00`
M`!X"````````V`,``*`'```*!@```````%\#````````>0``````````````
MB@@``+4%``"/"````````)@(```G`0``+P$``*$(```)`P``@@<``),'````
M````M`0``/8#```F!```L``````````=!````````+L%````````<P```!D'
M``"W!P``?0$``.,#``##`@``!0@``/L````V!```^P(``%0`````````X```
M``````!I!P``;`0```````!M`P``[P4``*X"`````````````'4&``!T````
MV@8``"D!```<`P``^0```.(!``"X!P``]@8``'L#```3````A0@``"4(```8
M````_@4``!0#``!A!@``SP```"D"````````]0$``!H!``!B`@``J`(``+P!
M``!:`0``=P$``&D````-"```8@$```\!```X`@``*@4``!\'``".!```?P0`
M`"@!``#1`0``70$``$8&````````&0@``*\#``"0!0```````"0'``#6`0``
M5P8``)$(````````%@4`````````````VP```'P'``"%`P``MP(``"X&``!!
M`P``DP8``#@'``!E"```1P@``-D%``!;!P``;P0``,`'``"Y````&0(``+\'
M``!R`P``OP(``+X```#+!```P@8``'8"``#>`````````$`"``"-!P``?0``
M`*T%``!"!```?@<``$$%``"H!@``/@4``!D&``#S`0``;@<``,4#````````
M70<```````"=!````````/4&``!%`0``!@(``%P"```Z!P```@````````",
M!```&`$``),```#-`0``UP<````````S!0``JP4``$H&``!/`0````(``,H'
M``#I!```;@8````````3`0``+@0``"L(``!J!0``6`0``$,(``#;`@``````
M`-`"````````E````!8&``!1"```Q0(```````"Y`P``-@8``*4(``#R!0``
MH````'T#``#?!P``2P,``*,`````````?@4``*@'``#'`@``2P<``)@````L
M`P``M0$``,(```"`!P``80@``"$!``#7!```T@(``*<&``#N`P``U@```$8(
M``!Q`0````````````"6`0``S@0``"<%````````)@8```````"`!```\@``
M`%H"```\!@``T0<```````"[`0``F@@```````#5!```ZP0``)@'``#?!0``
M/@,``%4#``#(`0````````````#/!`````````````!C`0``1````)@"````
M````6@<`````````````U@0``.$!``!8`@``;0$``)X"```[`0``K`4``"D$
M``#6!0``>P<``&\`````````BP8``!L```!S`@``404```````!S!P``M`(`
M`(<$``"\!@```````"T````W!0``>04``((#``!R"```^P,``,8&````````
M#0```.T#``#G`P``60<``"T'``##`0``0@,`````````````F0```.`'````
M!@```````,8%``#I!0``?@$```\'````````R`0``````````````P,``,8$
M``#+!0``9P```*`(```P`P```````%,%````````+`4``'$"```Z!0``````
M`````````0``M00``.T'````````7@`````````4!P``````````````!P``
M]0```%T"``#B!P````````````#;!@``I00``!0(``"D!P``V00``.8````@
M"```;P,`````````````>`(``%T&``#&`P```````+,"```K`@``!@4`````
M```.!@``-`0``.($``"6!@``\04``(4"``"^!0``!P(`````````````<08`
M`+8$``!>`P``CP$``+$!````````0P0``#8!`````````````(D````U"```
M504``!$#``!>"```V0<``(T&``!R!0``0P(``+X"``!I`@``=@<``)4`````
M````0@@``*T&``"&"```V0```%P'``##`P```````````````````````,0!
M``#\!@```````)`&``"!`0``+@```&4&``"Z!````````'<'````````````
M````````````X@8``#$(```R!0``!P8``.4#```?````904``*$&````````
M`@<``.4&``!4!@``0`8``````````````````",!```[`P````````````#0
M!P``P@4``'X`````````^@(``,X&``".`P``H@$``-(!``"F`@``OP4``&8(
M``#_`@````````L$````````308``.T$``"5!0``S`,``(8$```I`P``<@$`
M`)H'``"@!0``*P$``&\(```B`P````````$'``!P````[P$```T%``!`!0``
MY`8``"P'``!``0```````+,%``#]`P``2P8`````````````7@$``,`"````
M`````````$L```#+`@``10<``````````````````"($``!K````=`8``)4!
M`````````````#`$``"(`0``,`8``)\#``#A!```=`$``$4%```=!P``Z@,`
M`-`$``#V`0``S00``#,````."```F@8```0!``"M````J00```0'```_!P``
M`````.,$``!>!@``%@(```````";`@``M@```&('````````!`0```T!````
M````C0(``)$!``#E````J`4``-\"```4!```$@,``#4%``"'!0``[`$``#H!
M`````````````````````````````*0$``"/!```<`(```(&```Q!P``````
M``````#S`@```````/$$```Y`@``F@4``$4(``"[!@``BP````````#=`P``
M'`4``#,"````````;P4``````````````````"P"``"=!P```````),%````
M```````````````*`0`````````````"!0``G0(``%$#``#O!P``3`@``%`&
M``!F`@```````!@(``!E`@``G0$``+(%``!O!@```````,4'````````$0$`
M`)0&````````K`(``.,%``!?````P08``($(``"!!P``K@```%P(``!L!P``
M50````````#/`@``/P,``/0$``!H`P`````````````+`0``-08``-0$``"I
M`P``4`(``*\(```?`P``#P````````!2`0````````````![````UP$``$`#
M``":`0``/P4`````````````<P$``*@!``#3!@``"P<````````1`@``````
M```````(`@``_`0``+,`````````A0````````"0!P``T@<``&D$```O"```
MQ````)$#``!'`P``[0`````````(`0``^P4```4&``!7!```,P0``-,'````
M````4`,``$`$````````.04``#('````````E`4``/4"``#'````$`<``)(`
M`````````````.H$```^`0``W`(``,T````W"```[@$``-X%```)!```S04`
M`!L#``!W!0``5`$``%(#``!W!@``C0$```````#H`0``@@$``)H#``"$````
M00$``,4!```D"```A@4``/H!``!)!0``G`4``````````````````*$"``#U
M!```700```````!X"```?@8``-@&``"\````G@<``!L$``![`0``4P0``',$
M``#]!P``-P,```````#4!@``20<``&4$``#,!````````)0'```&!```'P4`
M``````#L`@``2P@``$T```!0!P``]P(```((``#3!0``3@(``%`(``"P!0``
M``````````#J`@``FP`````````V"```J@0``-0!``"E`P`````````````8
M!@``YP<``(`(````````AP@``$,%``"I!@``]`$```X`````````6P$`````
M`````````````'8#``!2"````````)4(````````H@,```````!F````_04`
M`+8!`````````````'P#````````?P,``*<$``#Y`0``?00``,<$``!F`0``
M'`8``'<$``!X!0``$`$```D&``!3`````````````````````````*0!``#1
M`@``>@0``/$#```&"```QP$``-(%``!H!P``M@(``$$'````````TP(``%<(
M``!7`P``0````)`"````````L`@``!<%```7!```;`8``%8#````````B08`
M`+P"```P`0``/`0``)(%```A!0``$08````````"`@```````#X'``!6`@``
M)P0`````````````1`$``$P'``!C!0``3`,``/@$````````````````````
M````<`8`````````````%P,```````"\!P``DP$``$H(```Q`P``GP@`````
M```'`P````````````!'`0``KP0``&@%``#J!0``608``(0"```C!```\P8`
M`#0&````````K`<```````#;`P``EP,``(<```#D`0``F@0``'D'``"*`@``
M3@@``$<'``!<`0``,@(``"L%```6````4P8``*8!``#H!0```````#`(``#4
M`@``D04```````!Q````*P,``*D`````````200``*D(````````I04``*T(
M````````M`,```````#K!P````````````#I````H@4```````!R`@``````
M`/8````B`@```````#(#````````N@8``*X$``#B`````````&L$``"+!```
MX`(``*<(``!"!@```````!L(```>`P``C0,``-L!``!.!P``F08``$(!``"W
M`0``R`,``%T(```B````R@,``'T(````````Q`0``)$&```G!P```````)T#
M````!0```````!8(``"#"```2@<```````!)`@``Y`,``,P'``"]!0``L`(`
M``````#!`P``X`0```T'``#+````R@0```````!M"```O`,``!L!```:"```
M`````&(&```H````YP```"4#```*"```W00`````````````A`$``$0%```*
M!0```````"$(````````V0$``'L(````````B````"4$``"Z`P```````-D&
M``">!@``L@0``+4"``````````````````!1!@``"`8``(0%``"O`@``````
M``````!_!P``;@0``'X"``!'!0``30<``+`#``"X!0```````(\```#_`0``
M``````````":`@``M`4``(````!@!0``+P,``)H```!?`@``F`4````````\
M````L0(`````````````JP$``'<```#^`@``<@<``!<!```(`````````/<`
M``!Z`0``W04``-H#``!/`@``7P$``&0'```_"```9P4``'P(````````````
M``````#6!P``\08``'P&``!<!@``%04``"P(``"[`P``E@(```````"2`0``
M,P8``)L%````````*0<```````!;````?````($#```````````````````-
M!```_`<``#0!``!P!```!@<``!T&``#\````/P```%P```#N!P``.0```)T&
M``#1`P``^0,``&,&``!(!P```````#``````````T@,``.X%````````````
M`"T&``#0`P```````#T'``#<!P```````$\%````````7P0``(<"```,!P``
MBP(`````````````-00```````"J!0``<P8```````"D"```#`@```````#-
M!@``5@8``%4'``!4!```E@4```````#F!0``*P```),(``"O!P``Z```````
M``!(!0```````"`!````````$0```/0"````````/@(```````#F!```````
M`'X$`````````````"@'``"O`0``3@0``-$```","````````-T"````````
M*`0``,L#``#`!````````)`$``#\`@``IP(``-4"`````````````-`%``"V
M`P``+P```)$'``"!````M08``-T'````````WP$``.$`````````$@@``",`
M``!K`@``80<``%\'``"P`0``70,``%H```#*!0``;P<```````"9"```,0(`
M`#4!````````]@<``/P!```$`@````````````"5`P``EP(``!0%````````
MA@,``/`"``!L`P``"P```,4%``";!P``K@@``*H#````````K`0```````!_
M"````````+H```"\!0``L04```````!D`````````%@#``!Y!```F04``$T!
M``!/!P``8@0```````#@`0``V@$``.L#`````````````&4#``!.`P``U`4`
M```````I!@``_@8``'P$```/!@``X@,``&8&``!8!P``L0@``'8%````````
M$@<``$@&```("```V@4```````!;!@````````````#I`0````````````!+
M`@``J````,@&```>!P``AP<```````!0!0``:````.X$``#:````H`,`````
M``"C!@``@P4``.4$```)````7P@```````!@"`````````````!A`P``^@0`
M`/`#````````008``#P'``````````````````!H!````````&P"``#5!@``
MP0<``/@#```A`@``CP4````````J"```%P8`````````````R0,`````````
M````.08``!(```!B`P``OP0``*X!````````A`0``/X$``!T!```S`$``-<"
M```*!P```P(````````C"```KP8`````````````````````````````2@,`
M`.`#``#(!0```````"@%``#.!0``X@4``)0"``"]!P``2`@``-\#``#6!@``
MOP```/L'```W!@``20```#4"``"'!@``B04``%,(``"M!P``0P8``,0&````
M````Q00``$X&````````'0@```````"``0````````````!P!P``````````
M``!F`P```````#D(``"Q````CP(``!4(```#````GP$``%````#S!P``1P(`
M`(H$````````E@````````#S````A@(``)\%``#-!P``;08```8!``!(````
M`````$4$````````7@<```````!"!0``ZP````````!C!P``G@$``$8!```4
M`0```````*8#``#<!@```````&X`````````"04``&$"````````ZP(``%P%
M``#8````)P@```````!;`P``F0(``"T(````````]@(```````!H`@``\`<`
M`-P%`````````````+T"``#R`@```````)8#``">"````````(H```!#!P``
M=0,``,4```"X!````````-H'``#H`P``#@$```````#:!```6P0```4'````
M````W@$``!<`````````=0(`````````````$@$``/X'``!M!0``WP``````
M``"C`P```````-X"```1"```60$```<````D`P``^@<``#T!``"A`P``````
M``````!#````>`,``*0`````````$`8`````````````=00`````````````
MO0$``/T&```T`P``<00``#8'``"+"```-0<```4$``"K`@``0P$``#@#````
M``````````````#&````#`4```````!6!P```````+L$``!S"```MP```&X(
M```%`0``P`4```````"3`P````````X#````````KP```)8'``!N!0``````
M`)````!K!P```@$```4```!K"```YP8``"8```#]`0````````````"J!P``
MT@0``-4```!W"`````````````"!!@``(@8``!`#````````N`(``"<````S
M`P``-P$``,D`````````?`4``$`'``#)`@```````"((````````#@<``)0!
M``!@!````````!4&``!8`0``?`(``)0$``!4!0``800``.$#````````````
M`#8#``#&`@```````%$'``"]````X0(````````(!````````+4`````````
M`````+0!``"/`P``FP0``(,!````````F0,``&4'````````'04``.`%````
M````E@0```````"4`P``?P8``/`$```%`@``]`4``),"``"A!0```````/\#
M```.`@``TP0```$(`````````````"`#````````A04``&X!``!Z`P``````
M`)0(```Y!```304``%4&``"L!@``T@8``(0&``#3`0```````&@(``#R!```
M```````````_!@``[`8``#P%``!E`0``5@0``'H"``!1!````````)<%``#7
M`````````#0"``"?!P``JP````````"C`0``K@4``-<&```F`P``=`4``%<%
M``"^`0``G04``#H```"Q!```]04```````"="````````,X!```N"```H@8`
M``\"``#G`@```````*T#``#T!P````````````!I`P```````/`%```3!```
M`````.L&``"H`P``'0,````````%!0```````)@&``#/!@``5@@`````````
M````.@0```````#Y!0``LP,``-D"``!A`````````*`&``!U`0``WP8`````
M````````7@(``.`&``##!0``````````````````U0<``,$"``"(!P``A@<`
M````````````U`,``"$&``!&````$P4```````#"!P``S@```%@(```X!```
ML08```$"``````````````````````````````````!6!0``(0````@%```<
M"````````)\`````````^@4```$#``!D!````````.L%````````:@$``+\#
M````````_@````````!C````-P0````````B`0``.0$``$8%``"""```RP8`
M`+L'``!$!@``'`0``#@```!S`P``<P4````````N`@``(`0``,$%``"@`@``
M'@8``#`%``#S`P```````$P!````````108``$$(``!7!P```````/\%``!)
M"```[@````````"L`P``3`8``'T&`````````````'($``!_`@```````$$"
M```N`0``W`0```````"N!@``P``````````,!````````/@```"G`P``````
M`)($``#R`0```````!T````X!@``1`(``!H```#4!P``.`4````````?`0``
MD@,``'@!````````U04``,`!`````````````)(&``````````````<!```N
M`P``#@0``,,$``!J`@``(P<````````Q!@``9`(``-D#``"+!0``^P8``,L'
M````````%@<``)4"````````P@(``.8!```>"```6P(``'$'```/!```A`@`
M`$H"```*`P``I`8``````````````````*T!``"-!````````",#``#N!@``
M(P4``$L$````````@00``(`%``!9"```:P4```````";`P``&0,````````)
M"```H`$``-L$``#I!@``'@0``"`&```O`@``*0@``$P````M`P``$P(``)@$
M````````LP0``#D#``!Z````:P8```,'``#>!```-0````````#=`0``6@@`
M`.T&````````````````````````%@$`````````````4@8```````!T"```
M`````#X(```[!```[@(```````"X`P``>`8```@#````````K00``#0```!G
M!@``````````````````#`,``"<&``"*`P``(`(``#$$``"W`P``````````
M`````````````"0"````````500`````````````)0$``*L'````````/@``
M`*('````````C0@`````````````A0<``((```#2`````````"8!``#E`@``
M`````(\&``#"`P``3`4``'D!````````IP<``$\#``!6`0``8````"$$``!&
M`P``<04``*X'````````````````````````.@8```````#L!P``$@(``#@!
M``#8`0``>0@```````",`0``S`8`````````````````````````````$P<`
M`,\%````````B@8``(X"```;!0``4@```/`!``"S`0``,P$``)('``#>`P``
MA`,``&D&``#K`0``"P,``,H"``"*!P``O@<``!\$````````Y@<````````+
M`@``]P4``/X#```$!0``&P8``&(%``!3`@``000``!@%``#O````F00``,<%
M```F`@``D`$``/@"``"U`P``1@<``+8%````````H@(``+<&````````EP8`
M````````````EP```/$```"\!``````````````0`@``8`(``#T&``!7````
M\@8````````\`P``FP$``*$````[!0``2`(```8````I!0``GP0``*,(````
M````>P8``"`'``#1!```BP,``.D"``````````````````"C!P```````)`#
M````````-@4``.H&``!B````&`0``+('````````P`8``%D#````````````
M``````#X!P```````+@!`````````````#P!```W`@```````+H'```D!@``
M;`$``'D&``#I`P```````+(#````````*@8``/,$``"P!@``H@@```P!``",
M`@``B`,``#($```]"```R`<``"@&``````````````````!^`P``30,``#@(
M``"Y`@```````%("````````+0$``+0&``!X!P```````!\&``"A!```````
M`*X#``!D"`````````L(````````%0,````````V`@``:@<``!H%````````
M``````````"F!```B`4``&<$```A`P````````````!V!````````*<```!7
M`@``JP,``!X!````````C`4```(#```C`@````````0#``!-"```_`4``"(%
M`````````````.\#``#D````&@(``+H!````````3P```"8(````````:`8`
M`/P#``#W!@``M`<``"X'````````7`,``+D'`````````````)L(``#<`0``
M`````&`&``#C!@``*`(``.8&``````````````````!>!```&0$```````"0
M"``````````````9!0``S````-\$```J````MP0``.0%``!Q"```>@8`````
M``#D!```N08``%$"``"%!```,`<``-0```#,!0````````````"Y`0``6P4`
M```````3"```B0@``'4(````````;@(``.4%``!8````XP(``&X#```T"```
M`````$L!````````L0,``!L'``"&`0``$0<``+T#``!,`@``O@,``/D"``"[
M````(P8```````"D!0``W0```(,#````````*P<`````````````]@0``,X'
M```I````!P<``(`#```0!```;`4``!P'```-`@````````X%``!A`0``4P<`
M`#`"``#B`@```````"`%``")`0``1@(```````#<`P``E0<``"4%``"X````
M`````&0!```6`P``H0<``(D#``!D`P``J0<``)D!``"E!@``^P$``'L%``#(
M`@``]P,``-T&```!`0``/P(``(P``````````P4``!<(````````?P```(,&
M`````````````$L%``"E````C@4``,D'``"*!0```````"H!``"2"```T`8`
M`.P````E!P`````````````2!0``50@``!H#````````!P@``!D````\`@``
MQP8``$D&````````````````````````````````````````C`<``-````#)
M!0```````&H```"5!@``300``!@'```K!@``/0`````````W!P``A0$``*P(
M````````K````,0'``#T!@``*`,``+4'``"B!``````````````S"```&`(`
M`(T%```8`P``"0$````````(!P``50$``%H&```,`````````&,"````````
MXP```(\'``">!0``[04`````````````%0<```````#O!@```````%X%````
M````_P<``/<!```V````+04``-@$``"5!````````'T'``!*`0``804``)X`
M```R`0```````((&``#U`P```"`@+4TL("TM;65S<V%G93U-15-304=%("!5
M<V4@=&AI<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D969A=6QT
M(&]N97,N`"`@+6$L("TM861D/49)3$4@("`@("`@($%D9"!T:&ES(%!/(&9I
M;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T;PH@("`@("`@("`@("`@
M("`@("`@("`@("!I;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R
M96YT(&)R86YC:"!T;PH@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V5N
M97)A=&5D(&-O;7!E;F1I=6TN`"`@+6(L("TM8F%S93TO4$%42"`@1G5L;"!P
M871H('1O('1H92`H2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H870@<VAO=6QD
M(&)E"B`@("`@("`@("`@("`@("`@("`@=7-E9"X`("`M8RP@+2UC;VUP96YD
M:75M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI<R!C;VUP
M96YD:75M(&9I;&4*("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@
M;V8@=&AE(&1E9F%U;'0@;VYE("AC;VUP96YD:75M+G!O(&EN('1H90H@("`@
M("`@("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+@`@("UC
M+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE
M(&EN<W1E860@;V8@=&AE(&1E9F%U;'0*("`@("`@("`@("`@("`@("`@("`@
M("`@(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T
M;W)Y*2X`("`M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S
M(&9R;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S+@`@("UD+"`M+61I<F5C=&]R
M>3U$25(@("!#<F5A=&4@8V]M<&5N9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2X`
M("`M:"P@+2UH96QP("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+@`@
M("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N
M`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N`"`@
M+6PL("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92X`("`M;2P@
M+2UM;V1U;&4]34]$54Q%("`@($)U:6QD($U/(&9I;&5S(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#
M;&5A;G5P(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS
M(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@("!#<F5A=&4@82!03R!F:6QE(&]N;'D@9F]R('1H:7,@*$AO
M<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!0
M3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M
M+6UO9'5L93U-3T153$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T
M(&UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN`"`@
M+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M
M+@`@("US+"`M+7-T871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S
M=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL92X`("`M="P@+2UT97-T("`@("`@
M("!3:&]W('1H92!E>&5C=71E9"!C;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N
M>71H:6YG+@`@(&-L96%N=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@
M9G)O;2!U;G1R86YS;&%T960@86YD(&]B<V]L971E(&5N=')I97,N`"`@8V]M
M;6ET("`@("`@0V]M;6ET('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E
M<BX`("!C;VUM:70M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93
M('-E<G9E<BX`("!C;VUP96YD:75M("!296)U:6QD('1H92!C;VUP96YD:75M
M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E<G=R:71E<R!T:&4*("`@("`@("`@
M("`@("!C=7)R96YT(&-O;7!E;F1I=6TN`"`@97AT<F%C="`@("`@1V5N97)A
M=&4@4$\@=&5M<&QA=&4@*"YP;W0I(&9I;&5S+@`@(&AE;'`@("`@("`@(%-H
M;W<@=&AI<R!H96QP(&UE<W-A9V4N`"`@:6YI="`@("`@("`@0W)E871E(&]N
M92!O<B!M;W)E(%!/(&9I;&5S(&9O<B!A(&YE=R!L;V-A;&4N(%=A<FYI;F<Z
M(%1H:7,*("`@("`@("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!0
M3R!F:6QE<R!O9B!T:&ES(&QO8V%L92X`("!M86ME("`@("`@("!"=6EL9"!B
M:6YA<GD@34\@9FEL97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I;&5S+@`@
M(&UA:V4M:&5L<"`@($UA<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP
M(&9I;&4@8F5I;F<@=7`M=&\M9&%T92!A;F0*("`@("`@("`@("`@("!P<F5P
M87)E('1H92!F:6QE(&9O<B!T:&4@;F5X="!E>&5C=71I;VX@;V8@=7!D871E
M+6AE;'`N(%EO=0H@("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME
M+6AE;'`@049415(@=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H90H@("`@
M("`@("`@("`@(&AE;'`@9FEL92X`("!M97)G92`@("`@("!-97)G92!T:&4@
M8W5R<F5N="!03R!F:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@
M9FEL92X`("!U<&1A=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q
M=65N="X`("!U<&1A=&4M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG
M960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H(%A-3"!H96QP"B`@("`@("`@
M("`@("`@9FEL92!A;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O
M;F5S+@`@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G
M;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B
M('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R
M96%T960Z("5S+@`E9"`E<R!A;F0@)7,`)60@8GET97,@=W)I='1E;BX`)60@
M979E;G1S`"5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4`
M)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N
M`"5S($1A>2AS*2`E<R!(;W5R*',I("5S($UI;G5T97,`)7,@1FEN9V5R<')I
M;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N
M=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@871T96YD965S
M`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(&YO="!W<FET
M86)L92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N
M`"5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T)R!F:7)S
M="X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE
M;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`*B!!9&0@
M=&AE<V4@8GD@8VQI8VMI;F<@061D("H`*B!0;&5A<V4@<V5L96-T(&%D9')E
M<W,H97,I("H`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L
M92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T`,2!A='1E;F1E90`Q(&5V96YT`#$R($AO=7(@1F]R;6%T
M`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P`\8CY!='1E;F1E
M97,\+V(^("AO<'1I;VYA;"D`/&(^1&5S8W)I7W!T:6]N/"]B/B`H;W!T:6]N
M86PI`#QB/DME>7=O<F1S/"]B/B`H;W!T:6]N86PI`#QB/E)E8W5R<F5N8V4\
M+V(^("AO<'1I;VYA;"D`/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I
M;&4@)7,N"D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N`$$@9&%T86)A
M<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A
M;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T`04T@0VQO=61S
M`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO
M=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`
M06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C
M8V]U;G1I;F<`061?=F%N8V5D(%-E87)C:`!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!%=F5N=`!!9&0@2&5R93H`061D
M($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O
M=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D
M(&$@;F5W(%)E;6]T92!#86QE;F1A<@!!9&0@82!N97<@979E;G0`061D(&$@
M;F5W('5S97(Z`$%D9"!A='1E;F1E97,`061D(&-O;'5M;@!!9&0@;F5W(&UE
M;6)E<G,`061D('!A:7(`061D('!E;W!L92!F<F]M(&UY($%D9')E<W,@0F]O
M:P!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1H
M97-E('!E;W!L90!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D
M<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RX`061D:6YG(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.@!!9&1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D
M;6EN:7-T<F%T:6]N`$%D<P!!9'9A;F-E9"!396%R8V@`069G:&%N:7-T86X`
M06QA<FT`06QA<FT@)60@9&%Y<R!B969O<F4`06QA<FT@)60@:&]U<G,@8F5F
M;W)E`$%L87)M("5D(&UI;G5T97,@8F5F;W)E`$%L87)M("5D('=E96MS(&)E
M9F]R90!!;&%R;2`Q(&1A>2!B969O<F4`06QA<FT@,2!H;W5R(&)E9F]R90!!
M;&%R;2`Q(&UI;G5T92!B969O<F4`06QA<FT@,2!W965K(&)E9F]R90!!;&%R
M;2!$871E`$%L87)M(%-P86X@*&UI;G5T97,I`$%L87)M(%1I;64`06QB86YI
M80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!='1E
M;F1E97,`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($9U='5R90!!;&P@
M1W)O=7!S`$%L;"!087-T`$%L;"!097)M:7-S:6]N<P!!;&P@5FES:6)L90!!
M;&P@9&%Y`$%L;"!D87D@979E;G0`06QL(&5V96YT<P!!;&P@9F]U<B!S:61E
M<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-
M4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-
M4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E
M('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@
M:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R
M(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO
M=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D
M80!!;GD`07!P;&EC871I;VX`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY
M('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R
M:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R
M8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I
M;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C
M96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!
M<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T`$%T=&%C:&5D(&ES
M(&%N(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U
M="!T:&4@979E;G0N($EF('EO=7(@;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I
M<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P
M9&%T92!Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+@!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD86YC90!!='1E;F1E97,`071T
M<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N
M9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`
M075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R
M96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E
M<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A
M=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E
M<P!"86-K('1O($-A;&5N9&%R($]P=&EO;G,`0F%C:V=R;W5N9`!"86-K9W)O
M=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S
M('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN90!"87-I8R!396%R8V@`
M0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!"
M:7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O
M=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!"
M;V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S
M;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V
M970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GD`0G)U;F5I($1A<G5S<V%L86T`0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO
M9'5L92`E<RXN+@!"=6EL9&EN9R!L;V-A;&4@)7,N+BX@`$)U;&=A<FEA`$)U
M;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0G5S>0!#35,`0U)#
M`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?86QE;F1A<@!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;%]E
M;F1A<@!#86QE;F1A<@!#86QE;F1A<B!$97-C<FEP=&EO;@!#86QE;F1A<B!.
M86UE`$-A;&5N9&%R(%-U;6UA<GD`0V%L96YD87)S`$-A;&5N9&%R<R!M=7-T
M(&AA=F4@82!N86UE+@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M`$-A;B=T(&-R96%T92!A(&YE=R!E=F5N="X`0V%N861A`$-A;F-E;`!#86YC
M96P@4')O8FQE;2!297!O<G0`0V%N8V5L;&5D`$-A;F-E;&QE9#H@)7,`0V%N
M;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D
M97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O
M97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#
M871E9V]R7WD`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A=&5G;W)Y`$-A>6UA
M;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D
M9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE
M`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF
M:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@
M8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@
M870@=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@
M*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@
M<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E
M9"!L:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F
M;W(@9G)E92]B=7-Y(%523',Z`$-H;V]S92!T:&4@8V%L96YD87)S('1H870@
M>6]U('=A;G0@=&\@8F4@:6YC;'5D960@:6X@>6]U<B!&<F5E+T)U<WD@;&ES
M=&EN9W,Z`$-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N`$-H<FES=&UA
M<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L
M96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`0VQE86YI;F<@
M=7`@;&]C86QE("5S+BXN(`!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L
M96%R(&%L;"!A='1A;F1E97,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S
M97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N
M=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S
M`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`
M0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#
M;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU
M;6X@=&ET;&5S`$-O;6EC<P!#;VUM82!S97!A<F%T960@=F%L=65S`$-O;6UA
M;F0`0V]M;6%N9"!3:&5L;`!#;VUM86YD(&]P=&EO;G,Z`$-O;6UA;F1S.@!#
M;VUM96YT`$-O;6UI='1I;F<Z`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N
M>0!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O
M;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S
M=V]R9`!#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\`0V]N9FER;65D`$-O
M;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N
M;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@
M*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S
M(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O
M<'D@<V5L96-T:6]N`$-O<'D@=&AE(%523"!B96QO=R!F;W(@=7-E('=H97)E
M=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y(%523#H`0V]P>6EN9R`E<R!T
M;R`E<P!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S
M(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C;W!Y("5S('1O("5S`$-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!C
M<F5A=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.@!#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M
M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@
M=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S
M(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@
M;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L
M9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O
M=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S
M`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M
M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@
M=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A($YE=R!%=F5N
M=`!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F
M;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R
M9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0`0W5R<F5N="`T(%!H87-E
M<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P
M=6)L:6,`1$0`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E=F5R>0!$871A5')E92!"
M<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`
M1&%Y*',I`$1E7VQE=&4`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA
M;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E
M9F%U;'0@0V%L96YD87(`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y
M`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M:7-S:6]N<P!$969I
M;FET:6]N<P!$96QE=&4`1&5L971E("(E<R(`1&5L971E("5S`$1E;&5T92!%
M=F5N=`!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N
M9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E
M;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI
M<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L
M96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE
M=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E(&%N
M9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R(&%L;"!O8V-U<F5N8V5S/P!$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES('!E<FUI<W-I;VX@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T960@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:5]P
M=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E
M=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@
M`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L
M969T`$1I<F5C=&]R>0!$:7-M:7-S`$1I<W!L87D`1&ES<&QA>2`R-"UH;W5R
M('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E
M8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E
M`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO
M=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U92!O;B!Y;W5R(&-A
M;&5N9&%R/P!$;V5S(&YO="!R96-U<@!$;V5S('1H92!F:7)S="!R;W<@8V]N
M=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z
M`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A
M9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@
M<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!$=64Z("5S`$1U<F%T:6]N
M`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@(B5S(@!%9&ET("5S`$5D
M:70@071T96YD965S`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI
M<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET(%)E;6]T92!#86QE;F1A<G,`161I="!A='1E;F1E97,`161I="!C
M871E9V]R:65S(&%N9"!C;VQO<G,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%
M9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G
M92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD($1A=&4`
M16YD($]N`$5N9"!4:6UE`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R
M(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@
M:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4`16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D
M(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;@!%<75A=&]R:6%L($=U:6YE
M80!%<FET<F5A`$5R<F]R`$5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N(&9O<B`E<SH@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+@!%<G)O<B!W<FET:6YG("(E<R(N`$5R<F]R.B``17-T;VYI80!%=&AI;W!I
M80!%=&AN:6,`175R;W!E`$5V96YT(&9R;VT@)7,@=&\@)7,`179E;G1S(&UU
M<W0@:&%V92!A('-T87)T(&1A=&4N`$5V96YT<R!M=7-T(&AA=F4@82!T:71L
M92X`179E;G1S(&UU<W0@:&%V92!A;B!E;F0@9&%T92!O<B!A(&1U<F%T:6]N
M+@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M96-U=&EN9SH`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%
M>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER
M871I;VX@1&%T90!%>'!O;F5N=`!%>'!O<G0`17AP;W)T($-A;&5N9&%R`$5X
M=')A8W1I;F<@9G)O;2`E<RXN+B``1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S
M971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D
M('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86ER`$9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R
M<F]R.@!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W
M(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&
M:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@
M36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN9`!&:6YL
M86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&
M;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`
M1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&
M;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E
M='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A
M(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U
M;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&
M;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C=&]R:65S.@!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R964O0G5S>2!)
M;F9O<FUA=&EO;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E
M;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R:61A>0!&<F]M`$9R;VT@=&AE
M(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1G5T=7)E
M`$9U>GIY`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE
M<GDZ`$=A;6)I80!'86UE`$=E;F5R86P`1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;@!'96YE<F%T960@0V]D90!'96YE<F%T:6YG('-T871U<R!F;W(@;6]D
M=6QE("5S+BXN`$=E;W)G:6$`1V5R;6%N>0!'971O<'0@17)R;W(Z(`!':&%N
M80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE(%-E87)C
M:`!';W1O("5S`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I
M`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI<W-I;VYS`$=R
M;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T
M(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E
M<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3
M=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U
M<VEN9R!E9&ET;W(`2&5L<&5R`$AE;'!E<B!A<'!L:6-A=&EO;B!T;R!C<F5A
M=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E"F9R
M86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RX*1F]R(&%N(&EN=')O9'5C
M=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R>2X`
M2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M`$AI9&4`2&ED92`E<P!(:6=H`$AI<W1O<GD@96YT<GD@;F%M97,@;75S="!B
M92!N;VXM96UP='D`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`2&]R9&4@=')A;G-L871I;VX@9V5N97)A=&]R`$AO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@
M=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@
M<WEN8VAR;VYI<V5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A
M=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I
M;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-
M24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B
M.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT
M86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W5R*',I`$AO=R!D:60@>6]U(&=E
M="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&1A>7,@:6YT;R!T:&4@
M9G5T=7)E('-H;W5L9"!W92!G96YE<F%T92!F<F5E+V)U<WD@:6YF;W)M871I
M;VX@9F]R/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I
M='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N
M<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET
M(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN
M(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T
M:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@
M<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@
M=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O
M=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA
M9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L
M;V%D`$EM86=E<P!);7!O<G0@0V%L96YD87(L(%-T97`@)60`26UP;W)T+"!3
M=&5P("5D`$EM<&]R="]%>'!O<G0@0V%L96YD87(`26UP;W)T960@9FEE;&0Z
M("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N
M=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R
M;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN:71I
M86QI>FEN9R!M;V1U;&4@)7,N+BX@`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN
M<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R
M="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!)
M;G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O
M;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G
M97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E
M9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI
M<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:
M25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$
M+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E
M(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?
M='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M
M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN
M=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L
M:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L
M:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3
M=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU
M87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A
M;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U
M;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P
M(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@
M1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97EW
M;W)D<P!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+
M4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T(#(T(&AO=7)S`$QA<W0@
M2&%L9@!,87-T($UO9&EF:65D`$QA<W0@36]N=&@`3&%S="!1=6%R=&5R`$QA
M<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87-T('=E96L`3&%S=',`3&%T=FEA
M`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N
M`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$
M<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN
M($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6UI
M="!T:&4@=&EM92!S<&%N('1O(&5X<&]R=#H`3&EN:P!,:6YK('!O:6YT<R!T
M;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L
M<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,
M:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI
M<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET
M97)A='5R90!,:71H=6%N:6$`3&]?8V%T:6]N`$QO861I;F<@;&EB<F%R:65S
M+BXN`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E
M`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`
M3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%
M1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G
M87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%K
M92!S=7)E('1H870@>6]U(&AA=F4@4$5!4B!I;G-T86QL960@86YD(&EN('EO
M=7(@:6YC;'5D92!P871H+@!-86MI;F<@9&ER96-T;W)Y("5S`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!R96UO=&4@8V%L
M96YD87)S+@!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P
M`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`
M36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-
M875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!L96YG=&@`36%Y
M`$UA>6]T=&4`365D:6-I;F4`365E=&EN9P!-96UB97)S`$UE;G4@3&ES=`!-
M96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<F=I;F<@86QL("5S+G!O(&9I;&5S
M('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG(&QO8V%L92`E<RXN+B``
M365R9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN
M+BX@`$UE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO9'5L92`E<RXN+@!-97-S
M86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG
M;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S
M86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO
M9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=')I8P!-97AI8V\`36EC<F]N97-I
M82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-
M:6YU=&4H<RD`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<V5D($5V96YT<R!,
M:7-T`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN
M9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@
M:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@
M;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T
M90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QE`$UO9'5L=7,`36]L
M9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F1A>0!-;VYG;VQI80!-;VYT
M:`!-;VYT:"!6:65W`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N=&AL>2!%
M=F5N=',@3&ES=`!-;VYT:&QY.B!296-U<G,@979E<GD`36]N=&AS($%H96%D
M`$UO;G1H<R!"969O<F4`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O
M`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E
M($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`
M36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<P!-=6QT:7!L92!I0V%L96YD87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O
M;F4@=D5V96YT(&ES('-U<'!O<G1E9"X`375L=&EP;&4@<V5L96-T:6]N`$UY
M($%C8V]U;G0`37D@0V%L96YD87)S`$UY($-A;&5N9&%R<SH`37D@1G)E92]"
M=7-Y(%523`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/
M+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T
M:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!5
M4DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L
M:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T
M:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE
M='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($5V
M96YT`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L
M86YD`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`
M3F5X="`R-"!H;W5R<P!.97AT(#0@4&AA<V5S`$YE>'0@1&%Y`$YE>'0@36]N
M=&@`3F5X="!7965K`$YE>'0@9&%Y`$YE>'0@;W!T:6]N<P!.97AT('=E96L`
M3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.
M;R!);F9O<FUA=&EO;@!.;R!A;&%R;0!.;R!A='1E;F1E97,`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-A;&5N9&%R<R!A<F4@879A
M:6QA8FQE('1O(&=U97-T<RX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P97)M:7-S
M:6]N<R!A<F4@=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X`3F\@8VAI
M;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]M
M;6%N9"!S<&5C:69I960N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.
M;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&5N
M9"!D871E`$YO(&5N=')Y('=I=&@@=&AE(&ED("(E<R(@97AI<W1S(&EN('1H
M92!O<FEG:6YA;"!H96QP(&9I;&4N`$YO(&5V96YT<R!T;R!D:7-P;&%Y`$YO
M(&9I;&4@=7!L;V%D960`3F\@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V
M86EL86)L92!F;W(@)7,`3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+@!.
M;R!L;V-A;&4@<W!E8VEF:65D+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO
M8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE
M('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E
M(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3$1!
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO
M9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,
M(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S
M<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I
M9VYU<',N`$YO(')E8W5R<F5N8V4`3F\@<G5L97,`3F\@<VED97,`3F\@=&5M
M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960`3F\@=F%L:60@96UA:6P@861D<F5S<R!F;W5N9`!.;R!V86QU
M97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y
M+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H
M97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O
M<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!F;W5N9`!.;W0@:6UP;&5M96YT960N
M`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN`$YO=&EC90!.;W1I8V4Z($EM<&]R=&EN9R!I<R!N;W0@
M<&]S<VEB;&4@=VET:"!T:&ES(&-O;F9I9W5R871I;VX@9'5E('1O(&$@8G5G
M(&EN('1H92!U;F1E<FQY:6YG(&-A;&5N9&%R(&1R:79E<BX`3F]V96UB97(`
M3F]W`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L
M=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J
M96-T($-R96%T;W(`3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,`3V-T86P`
M3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO
M="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/
M<'1I;VYA;`!/<'1I;VYA;"!T;R!A='1E;F0`3W!T:6]N<P!/<'1I;VYS(&9O
M<B`E<P!/<'1I;VYS.@!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N
M:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]W;F5R`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3
M:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-
M`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO
M=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4%](4"!3:&5L;`!0861D:6YG`%!A
M:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`
M4&%L;2!$871E0F]O:P!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S="!%=F5N=',@3&ES=`!087-T
M90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!A='1E<FX`4&5N9&EN9R!3
M:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN/P!097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\`4&5R;6ES<VEO
M;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N
M:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E
M<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`
M4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T
M:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE
M;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E
M(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N
M=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@
M9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`
M4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S
M=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S
M97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG
M('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@
M=&AE('-Y<W1E;2X`4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI
M<W1S+FAO<F1E+F]R9RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N
M86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R=&%L($]P=&EO;G,`4&]R
M='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O
M9B!T:&ES('1A8FQE`%!O<W-I8FQE($UE971I;F<@5&EM90!0;W-S:6)L92!-
M965T:6YG(%1I;65S`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R
M90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`
M4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S($1A
M>0!0<F5V:6]U<R!7965K`%!R979I;W5S(&1A>0!0<F5V:6]U<R!O<'1I;VYS
M`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$
M97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U
M8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R
M=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2
M861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN
M(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R
M='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E
M;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N`%)E8W5R(%5N=&EL`%)E8W5R<F5N8V4`4F5C=7)R
M96YC92!$871A`%)E8W5R<F5N8V4@16YD($1A=&4`4F5C=7)R96YC92!);G1E
M<G9A;`!296-U<G)E;F-E(%1Y<&4`4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT
M:&QY`%)E8W5R<R!W965K;'D`4F5C=7)S('EE87)L>0!2961O97,@>6]U<B!L
M87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F
M<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`
M4F5M87)K<P!296UI;F1E<CH@)7,`4F5M;W1E($-A;&5N9&%R<P!296UO=&4@
M0V%L96YD87)S.@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92`E<P!296UO
M=F4@071T96YD964`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E
M(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F
M<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`
M4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E
M<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E
M9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U
M;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9`!297%U:7)E9"`B)7,B(&YO="!S
M<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M071T96YD965S`%)E<75I<F5D($9I96QD`%)E<75I<F5D('1O(&%T=&5N9`!2
M97-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<V5T
M('1O($1E9F%U;'1S`%)E<W!O;G-E`%)E<W5L=',`4F5S=6QT<R`H:6YC;'5D
M:6YG($AO<F1E*3H`4F5S=6QT<SH`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO
M;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O
M7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A
M=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E
M<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y
M<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE
M<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!37V%V
M92`B)7,B($%S($YE=P!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD
M($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H
M7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E
M`%-A=&5L;&ET92!0<F]V:61E<@!3871U<F1A>0!3875D:2!!<F%B:6$`4V%V
M90!3879E("5S`%-A=F4@)R5S)P!3879E($%S($YE=P!3879E($5V96YT`%-A
M=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC
M90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H(%)E<W5L=',`4V5A<F-H
M:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<P!396%R8VAI;F<@9V5T=&5X
M="!B:6YA<FEE<RXN+@!396QE8W0@1FEL97,`4V5L96-T(&$@8V%L96YD87(`
M4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@
M;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D
M9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C
M=`!396QE8W0@8V]N9FER;6%T:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y
M('1H92!D:69F97)E;G0@=FEE=W,@86YD(&-H;V]S92!D969A=6QT('9I97<N
M`%-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.@!396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D
M871E(&9O<FUA=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@
M=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE(&9I<G-T('=E96MD87DZ
M`%-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C
M="!T:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C="!T:&4@=FEE=R!T;R!D
M:7-P;&%Y(&]N('-T87)T=7`Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@:6X@=&AE('!O<G1A;"X`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N
M9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL(&%T=&5N9&5E<R!W:&5N
M(&1E;&5T:6YG('1H:7,@979E;G0`4V5N9"!A;B!E;6%I;"!T;R`E<P!396YD
M('5P9&%T97,O:6YV:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A
M=FEN9R!T:&ES(&5V96YT`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E
M<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@240@97AP:7)E9"X`
M4V5T`%-E="!E;F0@9&%T90!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E
M="!R96-U<G)E;F-E(&5N9"!D871E`%-E="!S=&%R="!D871E`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!O=VX@86YD(&]T:&5R('5S97(G<R!F<F5E
M+V)U<WD@;W!T:6]N<RX`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W
M:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H87)E(&YO="!F;W5N
M9#H@)7,`4VAA<F5D($-A;&5N9&%R<SH`4VAO<'!I;F<`4VAO<G0@4W5M;6%R
M>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\`4VAO=P!3:&]W($-A;&5N9&%R`%-H;W<@8V%T96=O<GD@;&5G96YD/P!3
M:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A
M;&5N9&%R('9I97=S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VXN`%-H;W<@9'5E('1A<VMS(&EN('1H92!C86QE;F1A<C\`4VAO=R!F<F5E
M+V)U<WD@;&5G96YD/P!3:&]W(&AA;&8@:&]U<B!S;&]T<R!I;B!D87D@86YD
M('=E96L@=FEE=W,_`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\`4VAO=R!O;FQY(&5V96YT<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T
M/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H
M;W<@<VAA<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_`%-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T87-K<R!U<VEN9R!C871E9V]R
M>2!C;VQO<G,_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@
M=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&EM92!O9B!D87D@8F5T=V5E;B!E86-H(&1A>2!I;B!W965K('9I
M97=S/P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R
M<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;B!U<"!I9B!N;W0@<F5G
M:7-T97)E9`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O
M<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-K:7!P960N+BX`4VQO=F%K:6$`
M4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3
M:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M
M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C
M92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN
M(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I
M;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L
M:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T85]R="!/
M;@!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@1&%T90!3=&%R="!/;@!3=&%R
M="!4:6UE`%-T87)T('EE87(`4W1A=%]U<P!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@`%-T;W)A9V4@9F]R;6%T
M`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B
M:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q
M=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C
M8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U
M;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E
M;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E
M<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U
M8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T
M92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N9&%Y`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z
M97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R
M86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M
M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L
M87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S
M(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E;G1A=&EV
M90!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H
M5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+@!4:&4@)7,@:&5L<"!F:6QE(&9O<B`E<R!D;V5S;B=T('EE="!E>&ES
M="X@0W)E871I;F<@82!N97<@;VYE+@!4:&4@161I="!!='1E;F1E97,@<V-R
M965N(&ES(&YO(&QO;F=E<B!P<F5S96YT+B!%>&ET:6YG+@!4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U3
M4"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I
M;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R
M871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO
M;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H
M92!B;W1T;VT@<VED92!O;FQY`%1H92!C86QE;F1A<B`B)7,B(&-A;FYO="!B
M92!D96QE=&5D+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!C<F5A=&5D
M+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@8V%L
M96YD87(@(B5S(B!H87,@8F5E;B!R96YA;65D('1O("(E<R(N`%1H92!C86QE
M;F1A<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@8V]N=&%C="!)1"!N=6UB
M97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@96YD(&1A=&4@;75S
M="!B92!L871E<B!T:&%N('1H92!S=&%R="!D871E+@!4:&4@979E;G0@;F]T
M:69I8V%T:6]N('1O("5S('=A<R!S=6-C97-S9G5L;'D@<V5N="X`5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C
M86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F;VQL;W=I;F<@
M:7,@82!M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#H`
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G
M<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI
M9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@
M=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@
M(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE
M(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@
M<W1A<G0@=VET:"`\/WAM;`!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W
M:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O
M('1H92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R
M969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@
M9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S
M:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N
M(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!E=F5N=',@;6%T8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N`%1H
M97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N
M("5S+@!4:&5R92!D;V5S;B=T('EE="!E>&ES="!A(&AE;'`@9FEL92!F;W(@
M)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y
M<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A
M<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ
M92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D
M+@!4:&5R92!W87,@86X@97)R;W(@86-C97-S:6YG('1H92!C86QE;F1A<CH@
M)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@979E;G0Z("5S`%1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M`%1H97)E('=A<R!A;B!E<G)O<B!E9&ET:6YG('1H92!E=F5N=#H@)7,`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O
M<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H
M97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@
M=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E
M<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+@!4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S
M(&%N(&5R<F]R('-E;F1I;F<@86X@979E;G0@;F]T:69I8V%T:6]N('1O("5S
M.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@97AP
M;W)T+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI
M9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K
M871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER
M97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L
M9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@
M:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL
M92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E
M861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L
M86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@
M=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H
M92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@
M96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-C<FEP="!M
M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F4N`%1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1H=7)S9&%Y`%1I8VME=',`
M5&EM90!4:6UE(%-P7V%N`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM
M92!S96QE8W1I;VX`5&EM92!S<&%N`%1I;6]R+4QE<W1E`%1I=%]L90!4:71L
M90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C
M90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H
M7W1O<"D`5')A;G-L871E9`!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O
M8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U97-D87D`5'5N:7-I80!4=7)K97D`
M5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<P!4=79A;'4`5'EP90!4>7!E('EO=7(@8VAO:6-E.B``
M52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y
M('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@
M86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S
M(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L
M971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@
M=&\@9&5L971E("(E<R(Z("5S`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N
M`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y`%5N86)L92!T;R!D96QE=&4@)7,N`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B
M;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("(E<R(Z("5S
M`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA
M8FQE('1O(')E=')I979E(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,`
M56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2X`56YK;F]W;B!C;VUM86YD.B`E<P!5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO
M=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`
M56YS970@8V]L;W(`56YS=7!P;W)T960@0V]N=&5N="U4>7!E+@!5;G-U<'!O
M<G1E9"!%>'1E;G-I;VX`56YT<F%N<VQA=&5D`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&1A=&5D.B`E<RX`57!D871I
M;F<@)7,@:&5L<"!F:6QE(&9O<B`E<RX`57!G<F%D92!S8W)I<'0@9&5L971E
M9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O
M;6%N(&YU;6)E<G,`57)U9W5A>0!5<V%G93H`57-E($-U<G)E;G0Z("5S`%5S
M92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`57-E<B!/<'1I
M;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@<&5R;6ES<VEO;G,`
M57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA
M;64Z`%5S97)N86UE.B``57-E<G,`57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB
M96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO
M;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A
M;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA
M>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F
M<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F
M86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W
M:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!6
M97)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`
M5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@1&%Y`%9I97<@86X@
M97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB
M:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A
M(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@86YD
M($9U='5N80!787)N:6YG`%=A<FYI;F<Z(`!790!796%T:&5R($9O<F5C87-T
M`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B
M(%-I=&4`5V5D;F5S9&%Y`%=E96L`5V5E:R`E9`!7965K*',I`%=E96ML>0!7
M965K;'DZ(%)E8W5R<R!E=F5R>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X
M-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAA
M="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD+"!W:&5N('1H
M97)E(&%R92!N;R!L871E<B!E=F5N=',_`%=H870@=&EM92!S:&]U;&0@9&%Y
M(&%N9"!W965K('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L
M:65R(&5V96YT<S\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA
M8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@
M0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B
M;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN
M9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T
M<P!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=O<FL@5V5E:P!7<FET
M:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S+@!8+5)E9@!8-3`Y=C,@0F%S
M:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME
M>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A
M(&UA<`!996%R;'D`665A<FQY.B!296-U<G,@979E<GD`665M96X`665S`%EE
M<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^
M72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N
M;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A;B!O;FQY('5S92!T
M:&ES(&9O<FT@9G)O;2!T:&4@161I="!!='1E;F1E97,@<V-R965N+@!9;W4@
M9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@:&%V
M92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S;VYA
M;"!);F9O<FUA=&EO;B!/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S:&5R
M925S(&)E9F]R92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT+@!9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O("5S
M+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O
M('1H92!S96QE8W1E9"!C86QE;F1A<BX`66]U(&1O(&YO="!H879E('!E<FUI
M<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N`%EO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="X`66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+@!9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE
M;F1A<BX`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M`%EO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N`%EO
M=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@<F5Q
M=65S=&5D('1O(&)E(')E;6EN9&5D(&%B;W5T("5S+"!W:&EC:"!I<R!O;B`E
M<R!A="`E<RX`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0
M('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U
M;'0@8V%L96YD87(`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@
M;F%M93H`66]U<B!G971T97AT('9E<G-I;VX@:7,@=&]O(&]L9"!A;F0@9&]E
M<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN"DYO="!A;&P@<W1R:6YG<R!W
M:6QL(&)E(&5X=')A8W1E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@
M<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;
M56YN86UE9"!E=F5N=%T`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO
M;@!?070`7T)A<VEC(%-E87)C:`!?0TQ)`%]$871A5')E90!?1&5L971E(%)O
M=P!?161I=`!?1V]T;P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S
M+BXN`%]);7!O<G0O17AP;W)T`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,
M:6YK+BXN`%]->2!#86QE;F1A<G,`7TYE=R!%=F5N=`!?3W!T:6]N<P!?4&5R
M;6ES<VEO;G,`7U!R:6YT`%]296UO=F4@3&EN:RXN+@!?4V5A<F-H`%]3971U
M<`!?4VAO=P!?5&%B;&4@4')O<&5R=&EE<RXN+@!?5&]D87D`7U5S97)S`&%D
M9')E<W,@8F]O:P!A;B!E<G)O<B!H87,@;V-C=7)E9#H`8F5F;W)E('1H92!E
M=F5N="!S=&%R=',`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E`&1A>0!D87DH
M<RD`9&%Y<P!D;VYE`&5V96YT<RYC<W8`979E;G1S+FEC<P!F86EL960`9F%L
M;&EN9P!F:6QE`&9O=6YD.B``9G)O;0!F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S`&=U<W1I;F<`:#H`:&@`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&UO;G1H
M*',I`&YA;64`;F]T(&-H86YG960`;F]T(&9O=6YD`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;VX@=&AE('-A;64@9&%T
M90!O;B!T:&4@<V%M92!W965K9&%Y`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S
M:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`
M=&%S:R!L:7-T`'1H92!(;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S
M(&1O97,@;F]T(&5X:7-T.@!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C
M;VYF:7)M`'5N:69I960`=6YN86UE9`!U<&1A=&5D`'5S97(@<V5L96-T`'9#
M86QE;F1A<B]I0V%L96YD87(`=D-A<F0`=D5V96YT(&YO="!F;W5N9"X`=SH`
M=V5A=&AE<BYC;VT`=V5E:P!W965K*',I(&]N.@!W965K<P!Y96%R*',I`%!R
M;VIE8W0M260M5F5R<VEO;CH@2W)O;F]L:71H+3`N,"XS+6-V<PI297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ,R`Q-SHQ,RLP,C`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#$M,3(M,#8@,38Z,C`M,#,P,`I,87-T+51R86YS;&%T;W(Z(%-A
M;75E;"!-;W1A(#QS86UU96Q`8G5M97)A;F=U92YC;VT^"DQA;F=U86=E+51E
M86TZ($)R87II;&EA;B!0;W)T=6=U97-E(#QD979`;&ES=',N:&]R9&4N;W)G
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X+6)I=`H`("`M32P@+2UM97-S86=E/4U%3E-!1T5-(%5S87(@97-T82!M
M96YS86=E;2!D92!C;VUE=&EM96YT;R!E;2!V97H@9&$*("`@("`@("`@("`@
M("`@("`@("`@("`@(&UE;G-A9V5M('!O<B!O;6ES<^-O+@`@("UA+"`M+6%D
M9#U!4E%5259/("`@("!!9&EC:6]N87(@97-T92!A<G%U:79O(%!/(&%O(&-O
M;7#J;F1I;RX@571I;"!P87)A"B`@("`@("`@("`@("`@("`@("`@("`@(&EN
M8VQU:7(@=6T@8V]M<.IN9&EO(&1E('5M(')A;6\@9&EF97)E;G1E(&YO"B`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;7#J;F1I;R!G97)A9&\N`"`@+6(L
M("TM8F%S93TO0T%-22`@0V%M:6YH;R!P87)A(&\@9&ER96-T\W)I;R!B87-E
M("A(;W)D92D@82!U<V%R+@`@("UC+"`M+6-O;7!E;F1I=6T]05)152`@26YT
M96=R87(@;F]V87,@=')A9'7G]65S(&$@97-T92!A<G%U:79O(&1E(&-O;7#J
M;F1I;PH@("`@("`@("`@("`@("`@("`@("`@("`@92!NXV\@86\@8V]M<.IN
M9&EO('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O(&YA"B`@("`@("`@("`@
M("`@("`@("`@("`@("!P87-T82!H;W)D92]P;RX`("`M8RP@+2UC;VUP96YD
M:75M/4%2454@(%5S87(@97-T92!A<G%U:79O(&1E(&-O;7#J;F1I;R!E;2!V
M97H@9&\@87)Q=6EV;PH@("`@("`@("`@("`@("`@("`@("`@("`@<&]R(&]M
M:7-SXV\@*&-O;7!E;F1I=6TN<&\@;F$@<&%S=&$@:&]R9&4O<&\N`"`@+60L
M("TM9&5B=6<@("`@("`@36]S=')A<B!M96YS86=E;G,@9&4@97)R;R!D;W,@
M8FENX7)I;W,@97AE8W5T861O<RX`("`M9"P@+2UD:7)E8W1O<GD]4$%35$$@
M0W)I87(@=6T@8V]M<.IN9&EO(&YE<W1A('!A<W1A+@`@("UH+"`M+6AE;'`@
M("`@("`@($UO<W1R87(@97-T82!M96YS86=E;2!D92!A:G5D82X`("`M;"P@
M+2UL;V-A;&4];&Q?0T,@("`@(%5S87(@87!E;F%S(&5S=&$@;&]C86QI>F'G
MXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V%R(&5S=&$@;&]C86QI
M>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@(%5S87(@97-T82!L;V-A
M;&EZ8>?C;RX`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-O;G-T<G5I<B!A
M<G%U:79O<R!-3R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@
M("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/
M("`@($QI;7!A<B!A<G%U:79O<R!03R!A<&5N87,@<&%R82!E<W1E(&WS9'5L
M;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@+2UM
M;V1U;&4]3=-$54Q/("`@($-O;65T97(@87,@=')A9'7G]65S(&%P96YA<R!P
M87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R
M9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@0W)I87(@;R!A<G%U:79O
M(%!/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@
M("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@26YT
M96=R87(@87)Q=6EV;W,@4$\@87!E;F%S('!A<F$@97-T92!M\V1U;&\*("`@
M("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN`"`@+6TL("TM;6]D=6QE
M/4W31%5,3R`@("!!8W1U86QI>F%R(&%R<75I=F]S(&1E(&%J=61A(&%P96YA
M<R!P87)A(&5S=&4*("`@("`@("`@("`@("`@("`@("`@("`@(&WS9'5L;R`H
M2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@06-T=6%L:7IA<B!A
M<&5N87,@97-T92!M\V1U;&\@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($=E<F%R(&%R8VAI=F\@4$]4(&%P96YA<R!P87)A(&5S=&4@;?-D
M=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@("UN+"`M
M+6YO+6-O;7!E;F1I=6T@("`@3N-O(&EN=&5G<F%R(&YO=F%S('1R861UY_5E
M<R!N;R!C;VUPZFYD:6\N`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!.XV\@
M=7-A<B!U;2!C;VUPZFYD:6\N`"`@+7,L("TM<W1A=&ES=&EC<R`@("`@("!'
M=6%R9&%R(&5S=&%T[7-T:6-A<R!D92!T<F%D=>?C;R!N=6T@9FEC:&5I<F\@
M;&]C86PN`"`@+70L("TM=&5S="`@("`@("`@36]S=')A<B!O<R!P<F]G<F%M
M87,@82!E>&5C=71A<B!M87,@;N-O(&\@9F%Z97(N`"`@8VQE86YU<"`@("`@
M3&EM<&%R(&]F(&%R<75I=F]S(%!/(&1E(&5N=')A9&%S('!O<B!T<F%D=7II
M<B!O=2!O8G-O;&5T87,N`"`@8V]M;6ET("`@("`@0V]M971E<B!A<R!T<F%D
M=>?U97,@;F\@<V5R=FED;W(@0U93+@`@(&-O;6UI="UH96QP($-O;65T97(@
M87)Q=6EV;W,@9&4@86IU9&$@;F\@<V5R=FED;W(@0U93+@`@(&-O;7!E;F1I
M=6T@(%)E8V]N<W1R=6ER(&\@87)Q=6EV;R!D92!C;VUPZFYD:6\N($%T96[G
MXV\Z($\@;F]V;R!A<G%U:79O"B`@("`@("`@("`@("`@<V]B<F5P]64M<V4@
M86\@86YT:6=O+@`@(&5X=')A8W0@("`@($=E<F%R(&%R<75I=F]S(&UO9&5L
M;R!03R`H+G!O="DN`"`@:&5L<"`@("`@("`@36]S=')A<B!E<W1A(&UE;G-A
M9V5M(&1E(&%J=61A+@`@(&EN:70@("`@("`@($-R:6%R('5M(&]U(&UA:7,@
M87)Q=6EV;W,@4$\@<&%R82!U;6$@;F]V82!L;V-A;&EZ8>?C;RX*("`@("`@
M("`@("`@("!!=&5NY^-O.B!/<R!N;W9O<R!A<G%U:79O<R!S;W!R97#U96TM
M<V4@86]S(&%N=&EG;W,N`"`@;6%K92`@("`@("`@0V]N<W1R=6ER(&%R<75I
M=F]S(&)I;N%R:6]S($U/(&$@<&%R=&ER(&1O<R!A<G%U:79O<PH@("`@("`@
M("`@("`@(%!/(&5S<&5C:69I8V%D;W,N`"`@;6%K92UH96QP("`@36%R8V%R
M('1O9&%S(&%S(&5N=')A9&%S(&YO(&%R<75I=F\@6$U,(&1E(&%J=61A(&-O
M;6\@97-T86YD;PH@("`@("`@("`@("`@(&%C='5A;&EZ861A<R!E('!R97!A
M<F%R(&\@87)Q=6EV;R!P87)A(&$@<'+S>&EM82!E>&5C=>?C;PH@("`@("`@
M("`@("`@(&1E('5P9&%T92UH96QP+B!$979E+7-E(&5X96-U=&%R(&UA:V4M
M:&5L<"!$15!/25,@9&4*("`@("`@("`@("`@("!U<&1A=&4M:&5L<"!E(&1E
M(')E=F5R(&\@87)Q=6EV;R!D92!A:G5D82X`("!M97)G92`@("`@("!);G1E
M9W)A<B!O(&%R<75I=F\@4$\@8V]R<F5N=&4@8V]M(&\@87)Q=6EV;R!M;V1E
M;&\@4$\@8V]R<F5N=&4N`"`@=7!D871E("`@("`@17AE8W5T87(@97AT<F%C
M="!E(&UE<F=E(&5M('-E<77J;F-I82X`("!U<&1A=&4M:&5L<"!%>'1R86ER
M('1O9&%S(&%S(&5N=')A9&%S(&YO=F%S(&4@;6]D:69I8V%D87,@9&\@87)Q
M=6EV;R!D90H@("`@("`@("`@("`@(&%J=61A(%A-3"!E;2!I;F=LZG,@92!I
M;G1E9W+A+6QA<R!C;VT@87,@97AI<W1E;G1E+@`@)B,Q-3$[("5S(&5S=.$@
M<')O;G1O('!A<F$@969E8W1U87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[G
MXV\@;6%R8V%D87,@86)A:7AO+@`@*"5S(&1I87,@871RX7,I`"`H0VAA=F4@
M9&4@86-E<W-O("5S*0`@*&1E;G1R;R!D92`E<R!D:6%S*0`@*&AO:F4I`"`H
M86UA;FCC*0`@*&]N=&5M*0`@8V]M(``B)7,B(&[C;R#I('5M82!E<V-O;&AA
M(';A;&ED82X`(B5S(B!NXV\@97-TX2!C;VYF:6=U<F%D;R!N;R!296=I<W1O
M(&1O($AO<F1E+@`B)7,B(')E<')E<V5N=&%D;W(@9&4@X7)V;W)E(&[C;R!E
M;F-O;G1R861O+@`B)7,B(&9O:2!A9&EC:6]N861O(&%O('-I<W1E;6$@9&4@
M9W)U<&]S+@`B)7,B)R!F;VD@861I8VEO;F%D;R!A;R!S:7-T96UA(&1E('!E
M<FUI<W/U97,N`"(E<R(@;N-O(&9O:2!C<FEA9&\Z("5S+@`E9"`E<R!E("5S
M`"5D(&)Y=&5S(&5S8W)I=&]S`"5D(&5V96YT;W,`)60@9&4@)60@96YT<F%D
M82!M87)C861A<R!C;VUO(&%C='5A;&EZ861A<P!P<F5V:7/C;R!D92`E9"!D
M:6%S`"5S("T@3F]T:69I8V'GXV\`)7,@061M:6YI<W1R8>?C;P`E<R!$:6$H
M<RD@)7,@2&]R82AS*2`E<R!-:6YU=&\H<RD`)7,@26UP<F5S<^-O($1I9VET
M86P`)7,@2T(`)7,@3W!E<F'G]65S(&1E($UA;G5T96[GXV\@+2!#;VYF:7)M
M8>?C;P!#;VYF:6=U<F%R("5S`"5S(%-U8G-C<F5V97(`)7,@5&5R;6]S(&1O
M($%C;W)D;P`E<R!JX2!E>&ES=&4N`"5S(&5M("5S("5S`"5S('!A<G1I8VEP
M86YT97,`87)Q=6EV;R`E<R!I;7!O<G1A9&\@8V]M('-U8V5S<V\`;N-O('-E
M('!O9&4@97-C<F5V97(@96T@)7,N`"5S(.D@;V)R:6=A=/-R:6\`)7,@;6EN
M=71O<P`E<R!NXV\@9F]I(&5N8V]N=')A9&\N`"5S(&[C;R!F;VD@96YC;VYT
M<F%D;RX@17AE8W5T87(@)W1R86YS;&%T:6]N(&5X=')A8W0G('!R:6UE:7)O
M+@`E<R!A("5S(&1E("5S`$-O;G1A8W1O<R!D92`E<P!#86QE;F3A<FEO(&1E
M("5S`$YO=&%S(&1E("5S`%1A<F5F87,@9&4@)7,`)7,Z("5S`"H@061I8VEO
M;F4M;W,@8VQI8V%N9&\@96T@061I8VEO;F%R("H`*B!0;W(@9F%V;W(@<V5L
M96-C:6]N92!E;F1E<F7G;RAS*2`J`"P@8V]M(')A:F%D87,`+"!C;VT@<F%J
M861A<R`E<R`E<P`L('9A<FGA=F5L(&1E("5S(&$@)7,`+2T@97-C;VQH82`M
M+0`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T`,2!P87)T:6-I<&%N=&4`
M,2!E=F5N=&\`1F]R;6%T;R!D92`Q,B!H;W)A<R`H04TO4$TI`$9O<FUA=&\@
M9&4@,C0@:&]R87,`,C0@:&]R87,`/$%N=&5R:6]R`#QB/E!A<G1I8VEP86YT
M97,\+V(^("AO<&-I;VYA;"D`/&(^1&5S7V-R:>?C;SPO8CX@*&]P8VEO;F%L
M*0`\8CY086QA7W9R87,M0VAA=F4\+V(^("AO<&-I;VYA;"D`/&(^4F5P971I
MY^-O/"]B/B`H;W!C:6]N86PI`&5T:7%U971A(#QG971T97AT/B!P;W(@9F5C
M:&%R(&YO(&9I8VAE:7)O("5S+@I!8G)I;F1O(&$@971I<75E=&$@96YC;VYT
M<F%D82!N82!L:6YH82`E9"X`17-T92!B;&]C;R!E>&EG92!U;2!M96-A;FES
M;6\@=7-A;F1O(&)A<V5S(&1E(&1A9&]S+@!/8V]R<F5U('5M(&5R<F\@9F%T
M86P`R2!N96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%!'4"!P87)A(&5N
M8W)I<'1A<B!A(&UE;G-A9V5M+@#)(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z
M8FQI8V$@4$=0('!A<F$@=F5R:69I8V%R(&$@87-S:6YA='5R82!D92!U;6$@
M;65N<V%G96T`4&%R82!D96-I9G)A<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S
M<^%R:6%S('5M82!C:&%V92!P^F)L:6-A(%!'4"P@=6UA(&-H879E('!R:79A
M9&$@4$=0(&4@=6UA(&9R87-E+7!A<W-E+@!087)A(&%S<VEN87(@=6UA(&UE
M;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!01U`L
M('5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!F<F%S92UP87-S92X`4&%R
M82!D96-I9G)A<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C
M:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-24U%
M(&4@=6UA(&9R87-E+7!A<W-E+@!087)A(&%S<VEN87(@=6UA(&UE;G-A9V5M
M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M
M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M82!F<F%S92UP87-S92X`R2!N
M96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%,O34E-12!P87)A(&5N8W)I
M<'1A<B!U;6$@;65N<V%G96TN`$%-`$[Z=F5N<R!D92!M86YHXP!#:'5V:7-C
M;W,@9&4@36%N:.,`0VAU=F$@9&4@;6%N:.,`06=U86-E:7)O<R!D92!M86YH
MXP!.97;U97,@9&4@;6%N:.,`04TO4$T`05!)($E$`$%C97)C82!D97-T92!E
M9&ET;W(`06-E<F-A+BXN`$)A<V5S(&%L:6YH861A<P!#96YT<F]S(&%L:6YH
M861O<P!!8V5I=&4`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!P87-T82!61E,N
M`$%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q=6EV;R!61E,N`%!A;&%V<F$M
M4&%S<V4@9&$@0V]N=&$`0V]N=&$@8V]N9V5L861A+@!#;VYT86)I;&ED861E
M`%!R;V-U<F$@7T%V86[G861A`$%D:6-I;VYA<@!!9&EC:6]N87(@1W)U<&\@
M1FEL:&\`061I8VEO;F%R(%!E<FUI<W/C;R!&:6QH80!!9&EC:6]N87(@179E
M;G1O`$%C<F5S8V5N=&%R($%Q=6DZ`$%D9&EC:6]N87(@3F]V;R!'<G5P;P!!
M9&EC:6]N87(@3F]V82!097)M:7-SXV\`061I8VEO;F%R('5M(&=R=7!O(&9I
M;&AO(&$@(B5S(@!!9&EC:6]N87(@=6UA('!E<FUI<W/C;R!F:6QH82!A("(E
M<R(`061I8VEO;F%R('5M(&YO=F\@0V%L96YDX7)I;R!296UO=&\`061I8VEO
M;F%R('5M(&YO=F\@979E;G1O`$%D:6-I;VYA<B!N;W9O('5T:6QI>F%D;W(Z
M`$%D:6-I;VYA<B!P87)T:6-I<&%N=&5S`$%D:6-I;VYA<B!C;VQU;F$`061I
M8VEO;F%R(&YO=F]S(&UE;6)R;W,`061I8VEO;F%R('!A<F-E:7)O`$%D:6-I
M;VYA<B!P97-S;V%S(&1O(&UE=2!,:79R;R!D92!%;F1E<F7G;W,`061I8VEO
M;F%R(&\@365N=2`E<R!C;VUO($)A<G)A($QA=&5R86P@36]Z:6QL80!!9&EC
M:6]N87(@97-T87,@<&5S<V]A<P!!9&EC:6]N87(@86]S($-O;G1A8W1O<SH`
M061I8VEO;F%R(&%O<R!M975S(&-O;G1A8W1O<P!!9&EC:6]N87(@=71I;&EZ
M861O<@!!9&EC:6]N96D@(B5S(B!A;R!S:7-T96UA+"!M87,@;N-O('!U9&4@
M861I8VEO;F%R(&EN9F]R;6'GXV\@9&4@<W5B<V-R:>?C;R!A9&EC:6]N86PZ
M("5S+@!!9&EC:6]N96D@(B5S(B!A;R!S:7-T96UA+B!*X2!P;V1E(&5N=')A
M<BX`061I8VEO;F%N9&\@;F]V;W,@87)Q=6EV;W,@86\@<F5P;W-I=/-R:6\Z
M`$$@861IY^-O(&1E('5T:6QI>F%D;W)E<R!E<W3A(&1E<V%C=&EV861A+@!%
M;F1E<F7G;P!,:79R;R!D92!%;F1E<F7G;W,`061M:6YI<W1R87(@+2!A=')I
M8G5I<B!P97)M:7-S]65S(&$@;W5T<F]S('5T:6QI>F%D;W)E<P!!9&UI;FES
M=')AY^-O`$%N^FYC:6]S`%!R;V-U<F$@079A;N=A9&$`069E9V%N:7-TXV\`
M079I<V\`079I<V\@)60@9&EA<R!A;G1E<P!!=FES;R`E9"!H;W)A<R!A;G1E
M<P!!=FES;R`E9"!M:6YU=&]S(&%N=&5S`$%V:7-O("5D('-E;6%N87,@86YT
M97,`079I<V\@,2!D:6$@86YT97,`079I<V\@,2!H;W)A(&%N=&5S`$%V:7-O
M(#$@;6EN=71O(&%N=&5S`$%V:7-O(#$@<V5M86YA(&%N=&5S`$1A=&$@9&\@
M079I<V\`1'5R8>?C;R!D;R!!=FES;R`H;6EN=71O<RD`2&]R82!D;R!!=FES
M;P!!;&+B;FEA`$%R9^EL:6$`06QC=6YH80!!;&EN:&%R`$%L:6YH86UE;G1O
M.@!4=61O`%1O9&]S(&]S(%!A<G1I8VEP86YT97,`5&]D;W,@;W,@571I;&EZ
M861O<F5S($%U=&5N=&EC861O<P!4;V1O(&\@1G5T=7)O`%1O9&]S(&]S($=R
M=7!O<P!4;V1O(&\@4&%S<V%D;P!4;V1A<R!A<R!097)M:7-S]65S`%1U9&\@
M;R!6:7/M=F5L`%1O9&\@;R!D:6$`179E;G1O(&1E('1O9&\@;R!D:6$`5&]D
M;W,@;W,@979E;G1O<P!4;V1O<R!O<R`H<75A=')O*2!L861O<P!097)M:71I
M<B!M^FQT:7!L;W,@96YD97)EYV]S`%!E<FUI=&ER(&%T<FEB=6GGXV\@9&\@
M=&EP;R!D92!L:7-T87,@;W)D96YA9&%S/P!*X2!E>&ES=&4`16YT<F%D82!)
M35-0($%L=&5R;F%T:79A`%!A;&%V<F$M4&%S<V4@24U34"!!;'1E<FYA=&EV
M80!.;VUE(&1E(%5T:6QI>F%D;W(@24U34"!!;'1E<FYA=&EV;P!%;F1E<F7G
M;R!I;G;A;&ED;P!-;V1E;&]S(&%L=&5R;F%T:79O<P!497AT;R!A;'1E<FYA
M=&EV;SH`4V%M;V$@06UE<FEC86YA`$9O:2!E<W!E8VEF:6-A9&\@=6T@=F%L
M;W(@:6YVX6QI9&\N`$]C;W)R974@=6T@97)R;R!D97-C;VYH96-I9&\N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&$`16YT<F5P;W-T;R`H<')O>'DI($%N\VYI
M;6\`4F5S<&]S=&$`06YTX7)C=&EC;P!!;G3M9W5A(&4@0F%R8G5D80!1=6%L
M<75E<@!!<&QI8V'GXV\`07!L:6-AY^-O('!R;VYT82X`07!L:6-A<B!A(%!A
M<G1I;&AA<R!&:6QH87,`07!R;W9A<@!486UA;FAO($%P<F]X:6UA9&\`06)R
M:6P`07+A8FEC;R`H5VEN9&]W<RTQ,C4V*0!486UA;FAO(&1O($9I8VAE:7)O
M(&1E($%R<75I=F\`3F]M92!D;R!!<G%U:79O`%1E;2!A(&-E<G1E>F$@<75E
M('%U97(@<F5M;W9E<B!O('!E9&ED;R!D92!S=6)S8W)IY^-O('!A<F$@)7,@
M/P!496T@82!C97)T97IA('%U92!Q=65R(')E;6]V97(@(B5S(B!E('%U86ES
M<75E<B!S=6(M9W)U<&]S/P!!<F=E;G1I;F$`07)MZ6YI80!!<FWI;FEO("A!
M4DU30TE)+3@I`$%R=&4`07)U8F$`26QH82!D92!!<V-E;G/C;P!!<G1E($%3
M0TE)`%)E9VGC;R#!<VEA+U!A8^UF:6-O`%!E9&ER(&-O;F9I<FUAY^-O(&%N
M=&5S(&1E(')E86QI>F%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O/P!#;VQU
M;F%S(&1E(&%T<FEB=6GGXV\`P',`16T@86YE>&\@97-TX2!U;2!A<G%U:79O
M(&E#86QE;F1A<B!C;VT@;6%I<R!I;F9O<FUAY^-O('-O8G)E(&\@979E;G1O
M+B!392!O('-E=2!C;&EE;G1E(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@<W5P
M;W)T87(@<&5D:61O<R!I5&EP+"!P;V1E('5S87(@97-T92!F:6-H96ER;R!P
M87)A(&%C='5A;&EZ87(@8V]M(&9A8VEL:61A9&4@82!S=6$@8_-P:6$@;&]C
M86P@9&\@979E;G1O+@!496YT871I=F$@9&4@<F5M;^?C;R!D92!U;2!G<G5P
M;R!I;F5X:7-T96YT92X`5&5N=&%T:79A(&1E(')E;6_GXV\@9&4@=6UA('!E
M<FUI<W/C;R!I;F5X:7-T96YT92X`5&5N=&%T:79A(&1E(&5D:>?C;R!D92!U
M;6$@<&5R;6ES<^-O(&EN97AI<W1E;G1E+@!496YT871I=F$@9&4@961IY^-O
M(&1E('5M82!P87)T:6QH82!I;F5X:7-T96YT92X`4&%R=&EC:7!AY^-O`%!A
M<G1I8VEP86YT97,`071R:6)U=&]S`$%G;W-T;P!!=7-T<N%L:6$`P75S=')I
M80!!=71H7V-Y<G-Q;#H@02!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@;N-O
M(&9O:2!E;F-O;G1R861A+@!!=71H7V-Y<G5S.B!/(&UE8V%N:7-M;R!NXV\@
M=&5M(&%S(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S+@!!=71H7V-Y<G5S.B!!
M(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N
M`$%U=&A?9G1P.B!!(&5X=&5N<^-O($944"!N96-E<W/A<FEA(&[C;R!F;VD@
M96YC;VYT<F%D82X@0V]M<&EL92!O(%!(4"!C;VT@82!O<.?C;R`M+65N86)L
M92UF='`N`$%U=&A?:6UA<#H@02!E>'1E;G/C;R!)34%0(&YE8V5S<^%R:6$@
M;N-O(&9O:2!E;F-O;G1R861A+@!!=71H7VMR8C4Z($$@97AT96YSXV\@:W)B
M-2!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]L9&%P.B!!
M(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N
M`$%U=&A?;&1A<#H@26UP;W-S[79E;"!A9&EC:6]N87(@=71I;&EZ861O<B`E
M<RX@16ES(&\@<75E(&\@<V5R=FED;W(@9&ES<V4Z(`!!=71H7VQD87`Z($EM
M<&]S<^UV96P@<F5M;W9E<B!O('5T:6QI>F%D;W(@)7,`075T:%]L9&%P.B!)
M;7!O<W/M=F5L(&%C='5A;&EZ87(@;R!U=&EL:7IA9&]R("5S`$%U=&A?;6-A
M;#H@02!E>'1E;G/C;R!-0T%,(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R
M861A+@!!=71H7W-M8F%U=&@Z($$@97AT96YSXV\@<VUB875T:"!N96-E<W/A
M<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`02!A=71E;G1I8V'GXV\@9F%L:&]U
M`$$@875T96YT:6-AY^-O(&9A;&AO=2X@)7,`02!A=71E;G1I8V'GXV\@9F]I
M(')E:F5I=&%D82!P96QO('-E<G9I9&]R(%)!1$E54RX`02!A=71E;G1I8V'G
MXV\@;F\@<V5R=FED;W(@1E10(&9A;&AO=2X`0V%M<&]S(&1I<W!O;NUV96ES
M.@!!>F5R8F%I:N-O`$1E<V-U;'!A<R`B0D]&2"(`5F]L=&%R(.!S($]PY_5E
M<R!D92!#86QE;F3A<FEO`$9U;F1O`$-O<B!D;R!&=6YD;P!086QA=G)A+5!A
M<W-E(&ME<F)E<F]S(&5R<F%D82X`3F]M92!D92!5=&EL:7IA9&]R(&ME<F)E
M<F]S(&5R<F%D;RX`0F%A;6%S`$)A<NEM`$+A;'1I8V\@*$E33RTX.#4Y+3$S
M*0!"86YG;&%D96-H90!"87)B861O<P!,:6YH82!B87-E`%!R;V-U<F$@0N%S
M:6-A`$)I96QO<G+Z<W-I80!"Z6QG:6-A`$)E;&EZ90!"96YI;0!"97)M=61A
M`$)U=.-O`$1A=&$@9&4@;F%S8VEM96YT;P!/(&)L;V-O("(E<R(@9&$@87!L
M:6-AY^-O("(E<R(@;N-O(&9O:2!E;F-O;G1R861O+@!#;VYF:6=U<F'G]65S
M(&1E($)L;V-O<P!4:7!O(&1E($)L;V-O`$YE9W)I=&\`0F]L[79I80!-87)C
M861O<F5S`$)O<F1A`$5S<&5S<W5R82!D82!B;W)D83H`0F]R9&%S`$+S<VYI
M82U(97)Z96=O=FEN80!!;6)A<P!";W1S=6%N80!"87-E`$EL:&$@0F]U=F5T
M`$)R87-I;`!497)R:73S<FEO($)R:73B;FEC;R!D;R!/8V5A;F\@S6YD:6-O
M`$)R=6YE:2!$87)U<W-A;&%M`$-O;G-T<G5I;F1O(&%R<75I=F]S($U/('!A
M<F$@;R!M\V1U;&\@)7,N+BX`0V]N<W1R=6EN9&\@;&]C86QI>F'GXV\@)7,N
M+BX@`$)U;&?A<FEA`$QI<W0@271E;6EZ861A`$)U<G%U:6YA($9A<V\`0G5R
M^FYD:0!/8W5P861O`$--4P!#4D,`4&]N=&]S(&1E($1I<W1R:6)U:>?C;R!#
M4DP`0U]A;&5N9.%R:6\`4')O<')I961A9&5S(&1A*',I($/I7VQU;&$H<RDN
M+BX`26YI8VEA;&EZ8>?C;R!D82`B8V%C:&4B(&[C;R!F;VD@8V]N8VQU[61A
M+@!#86Q?96YDX7)I;P!#86QE;F3A<FEO`$1E<V-R:>?C;R!D;R!#86QE;F3A
M<FEO`$YO;64@9&\@0V%L96YDX7)I;P!3=6WA<FEO(&1O($-A;&5N9.%R:6\`
M0V%L96YDX7)I;W,`3W,@8V%L96YDX7)I;W,@=.IM(&1E('1E<B!U;2!N;VUE
M`$-A;&UO`$-A;6)O9&IA`$-A;6%R]65S`$[C;R!P;W-S;R!R96EN:6-I87(@
M82!P86QA=G)A+7!A<W-E(&%U=&]M871I8V%M96YT92P@8V]N=&%C=&4@;R!S
M974@861M:6YI<W1R861O<B!D92!S:7-T96UA<RX`26UP;W-S[79E;"!C;VYE
M8W1A<B!A;R!S97)V:61O<B!)34%0.B`E<P!);7!O<W/M=F5L(&-R:6%R(&YO
M=F\@979E;G1O+@!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@4F5L873S<FEO
M(&1E(%!R;V)L96UA<P!#86YC96QA9&\`0V%N8V5L861O.B`E<P!.XV\@8V]N
M<VEG;R!R96UO=F5R(&\@9FEC:&5I<F\@(B5S(BX`3N-O(&-O;G-I9V\@96YC
M;VYT<F%R('5M(&1I<F5C=/-R:6\@=&5M<&]RX7)I;RX`26UP;W-S[79E;"!C
M;VYT:6YU87(@<V5M(&\@<&%RXFUE=')O("=T87)G971&:6QE)RX`3N-O(&9O
M:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@(B5S(BX`26UP;W-S[79E;"!R
M96UO=F5R+"!E>&ES=&5M("5D(&9I;&AO<RX`3N-O(.D@<&]S<^UV96P@<F5O
M<F1E;F%R.B!O(&[Z;65R;R!D92!E;G1R861A<R!F;W)N96-I9&%S(&[C;R!C
M;W)R97-P;VYD92!A;R!N^FUE<F\@9W5A<F1A9&\N`$[C;R!F;VD@<&]S<^UV
M96P@96YC86UI;FAA<B!A(&UE;G-A9V5M('!A<F$@;R!N^FUE<F\@:6YD:6-A
M9&\N`%)E</IB;&EC82!D92!#86)O(%9E<F1E`$QE9V5N9&$`0V%T96=O<E]I
M80!#871E9V]R:6%S(&4@0V]R97,`0V%T96=O<FEA`$EL:&%S($-A:6WC;P!4
M96QE9F]N92!#96QU;&%R`%!R;W!R:65D861E<R!D87,@0^EL=6QA<P!%;F-H
M:6UE;G1O(&1A<R!#Z6QU;&%S.@!0<F]P<FEE9&%D97,@9&%S(&/I;'5L87,`
M17-P8>=A;65N=&\@9&%S(&/I;'5L87,Z`%1E;&5M\W9E;`!#Z6QT:6-O("A)
M4T\M.#@U.2TQ-"D`0V5N=')A<@!297#Z8FQI8V$@0V5N=')O($%F<FEC86YA
M`$5U<F]P82!#96YT<F%L("A)4T\M.#@U.2TR*0!0;W)M96YO<F5S(&1O($-E
M<G1I9FEC861O`$1O;F\@9&\@0V5R=&EF:6-A9&\`4&]L[71I8V%S(&1E($-E
M<G1I9FEC861O`%)E</IB;&EC82!D;R!#:&%D90!!;'1E<F%R`$%L=&5R92!O
M(&YO;64@92!E;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!V97+C;R!Q=6%N9&\@
M;&5R96T@92!R97-P;VYD97)E;2#@<R!S=6%S(&UE;G-A9V5N<RX`0V%R86-T
M97)E`%9E<FE?9FEC87(@3&EG8>?C;RXN+@!-87)Q=64@87,@;W!E<F'G]65S
M('%U92!D97-E:F$@97AE8W5T87(@;F5S=&4@;6]M96YT;RX`4F5P^F)L:6-A
M(&1O($-H:6QE`%)E</IB;&EC82!0;W!U;&%R(&1A($-H:6YA`$-H:6[J<R!3
M:6UP;&EF:6-A9&]S("A'0C(S,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG
M-2D`17-C;VQH82!A('!A;&%V<F$M<&%S<V4`17-C;VQH82!U;2!.;VUE(&1E
M(%5T:6QI>F%D;W(`17-C;VQH82!C;VUO(&UO<W1R87(@87,@9&%T87,Z`$5S
M8V]L:&$@;R!E<W1I;&\@9&%S(&QI<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D
M87,I`$5S8V]L:&$@;W,@;&EV<F]S(&1E(&5N9&5R9>=O<R!N;W,@<75A:7,@
M<')O8W5R87(@<&]R(%523"!,:79R92]/8W5P861O.@!%<V-O;&AA(&]S(&-A
M;&5N9.%R:6\@<75E('!R971E;F1E(&EN8VQU:7(@;F%S(&QI<W1A<R!D92!,
M:79R92]/8W5P861O.@!%<V-O;&AA(&\@<V5U(&-A;&5N9.%R:6\@<&]R(&]M
M:7-SXV\N`$EL:&$@9&\@3F%T86P`3N-O(&9O:2!E;F-O;G1R861A(&$@9&5F
M:6YIY^-O(&1A(&-L87-S92`E<RX`3&EM<&%N9&\@;W,@87)Q=6EV;W,@4$\@
M9&\@;?-D=6QO("5S+BXN`$QI;7!A;F1O(&$@;&]C86QI>F'GXV\@)7,N+BX@
M`$QI;7!A<@!,:6UP87(@971I<75E=&%S(&1O($U33V9F:6-E`%)E;6]V97(@
M=&]D;W,@;W,@<&5R=&EC:7!A;G1E<P!,:6UP87(@9&%D;W,@9&\@=71I;&EZ
M861O<CH@)7,`3&EM<&%R(&1A9&]S(&1O('5T:6QI>F%D;W(`3&EM<&%R(&1A
M9&]S(&1O('5T:6QI>F%D;W(`3&EM<&$@5&%R9&4`0VQI<75E('!A<F$@0V]N
M=&EN=6%R`$-L:6-K871E;&P@=FEA($A45%``1F5C:&%R(&IA;F5L80!.^G9E
M;G,`3OIV96YS($UA=&EN86ES`$5N979O861O`$EL:&%S($-O8V]S("A+965L
M:6YG*0!#;VQA<'-A<B!"87)R82!,871E<F%L`$)O<F1A<R!#;VQA<'-A9&%S
M`%)E</IB;&EC82!D82!#;VST;6)I80!#;W)E<P!086QE=&4`4V5L96/GXV\@
M9&4@8V]R97(`0V]L=6YA<SH`5.UT=6QO<R!D87,@8V]L=6YA<P!"1`!686QO
M<F5S('-E<&%R861O<R!P;W(@=NUR9W5L87,`0V]M86YD;P!#;VYS;VQA(&1E
M($-O;6%N9&]S`$]PY_5E<R!D;R!C;VUA;F1O.@!#;VUA;F1O<SH`0V]M96YT
MX7)I;P!#;VUE=&5N9&\`3F]M92!#;VUU;0!#;VUO<F]S`$5M<')E<V$`17-C
M<F5V97(@*"5S*0!#;VUP=71A9&]R97,`0V]N9&GGXV\`0V]N9&GG]65S`$1I
M9F5R96[G87,@9&4@0V]N9FEG=7)AY^-O`$$@8V]N9FEG=7)AY^-O(&5S=.$@
M9&5S86-T=6%L:7IA9&$`0V]N9FEG=7)A<B`E<P!#;VYF:7)M92!A(%!A;&%V
M<F$M4&%S<V4`0V]N9FER;6$@<F5M;^?C;R!D92!E=F5N=&]S/P!#;VYF:7)M
M861O`%)E</IB;&EC82!$96UO8W+A=&EC82!D;R!#;VYG;P!297#Z8FQI8V$@
M1&5M;V-RX71I8V$@9&\@0V]N9V\`0V]N97CC;R!F86QH;W4N`$-O;F5XXV\@
M9F%L:&]U.B``0V]N97CC;R!A;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC
M87,@<F5C=7-A9&$N`$-O;F5XXV\@86\@<V5R=FED;W(@9&4@8VAA=F5S('#Z
M8FQI8V%S(')E8W5S861A+B!287KC;SH@)7,@*"5S*0!#;VYE>.-O(&%O('-E
M<G9I9&]R($944"!R96-U<V%D82X`0V]N=&%C=&]S(&%D:6-I;VYA9&]S(&-O
M;2!S=6-E<W-O(&%O('-E=2!L:79R;R!D92!E;F1E<F7G;W,N`%1I<&\@9&4@
M8V]N=&7Z9&\@9&\@87)Q=6EV;R!C;VUP<FEM:61O.B``0V]N=&7Z9&\@9&4@
M)7,`0V]N=&EN=6%R`$EL:&%S($-O;VL`0F]L:6YH;R!C:&ENZG,`0V]P:6%R
M`$-O<&EA<B!S96QE8^?C;P!#;W!I92!O(%523"!A8F%I>&\@<&%R82!U<V%R
M(&]N9&4@9F]R(&YE8V5S<^%R:6\@=6T@55),($QI=G)E+T]C=7!A9&\Z`$-O
M<&EA;F1O(&1E("5S('!A<F$@)7,`4F5P^F)L:6-A(&1A($-O<W1A(%)I8V$`
M4F5P^F)L:6-A(&1A($-O<W1A(&1O($UA<F9I;0!.XV\@9F]I('!O<W/M=F5L
M(&5N8W)I<'1A<B!A(&UE;G-A9V5M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV
M96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV
M96P@96YC<FEP87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.XV\@9F]I('!O
M<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.XV\@9F]I
M('!O<W/M=F5L(&%D:6-I;VYA<B!O(&-O;G1A8W1O+B`E<P!&86QH82!N82!L
M:6=AY^-O("AB:6YD*2!A;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M
M=F5L('9E<FEF:6-A<B!O('-A;&1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&-O
M;F5C=&%R(&%O('-E<G9I9&]R("(E<R(@=7-A;F1O($944#H@)7,`3N-O(&9O
M:2!P;W-S[79E;"!C;W!I87(@)7,@<&%R82`E<P!.XV\@9F]I('!O<W/M=F5L
M(&-R:6%R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S
M[79E;"!C<FEA<B!P87-T82!D92!L;V-A;&EZ8>?C;R!P87)A(&$@;&]C86QI
M>F'GXV\@)7,Z`$[C;R!F;VD@<&]S<^UV96P@9&5S96YC<FEP=&%R(&]S(&1A
M9&]S(&-O;2!O(%!'4"X`3N-O(&9O:2!P;W-S[79E;"!D97-E;F-R:7!T87(@
M;W,@9&%D;W,@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R
M(&-O;G1A8W1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;&ES=&$@
M9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@
M;R`B<V-R:7!T(B!D92!A8W1U86QI>F'GXV\@(B5S(BX`3N-O(&9O:2!P;W-S
M[79E;"!D971E<FUI;F%R(&\@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S
M;FEC;R!D;R!D97-T:6YA=.%R:6\N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@
M;R!L:79R;R!D92!E;F1E<F7G;W,@8V]M<&QE=&\N`$[C;R!F;VD@<&]S<^UV
M96P@;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\@8V]M<&QE=&$N`$[C
M;R!F;VD@<&]S<^UV96P@;V)T97(@82!L:7-T82!C;VUP;&5T82!D87,@;&ES
M=&%S(&1E(&1I<W1R:6)U:>?C;RX`26UP;W-S[79E;"!C87)R96=A<B!E<W1R
M873I9VEA("(E<R(N`$EM<&]S<^UV96P@;6MD:7(@(B5S(BX`3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!A(&-H879E('#Z8FQI8V$@82!P87)T:7(@9&\@<V5R
M=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!.XV\@9F]I('!O<W/M=F5L(&%B
M<FER("(E<R(@<&%R82!E<V-R:71A+@!.XV\@<'5D92!A8G)I<B`E<RX`3N-O
M(&9O:2!P;W-S[79E;"!A8G)I<B!O(&WS9'5L;R!D92!-86YU=&5NY^-O(&1E
M(%1A<F5F87,@)7,`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!P87-T82`B)7,B
M+@!.XV\@9F]I('!O<W/M=F5L(&QE<B`E<RX`3N-O(&9O:2!P;W-S[79E;"!R
M96EN:6-I87(@82!P86QA=G)A+7!A<W-E(&1O('5T:6QI>F%D;W(@:6YD:6-A
M9&\N($%L9W5M(&]U('1O9&]S(&]S('!O<FUE;F]R97,@;N-O(&5S=&%V86T@
M8V]R<F5C=&]S+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!O=2!C;VYT86-T
M92!O('-E=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('-E('!R96-I<V%R
M(&1E(&UA:7,@86IU9&$N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@04-,`$[C
M;R!F;VD@<&]S<^UV96P@;V)T97(@;&EV<F\@9&4@96YD97)EYV]S+B`E<P!.
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@
M)7,`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!L:7-T87,@9&4@9&ES=')I8G5I
MY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&-O;7!E=.IN8VEA
M<R!D;R!S97)V:61O<@!.XV\@9F]I('!O<W/M=F5L(')E=F5R=&5R(&$@8V]N
M9FEG=7)AY^-O+@!);7!O<W/M=F5L(')M9&ER("(E<R(N`$[C;R!F;VD@<&]S
M<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R8>?C;R!D92`E<RX`3N-O(&9O:2!P
M;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A
M+@!.XV\@9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@
M<V%L=F%G=6%R9&$Z("5S`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!O(")S
M8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R!E;3H@(B5S(BX`3N-O(&9O:2!P;W-S
M[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A("5S
M+@!.XV\@9F]I('!O<W/M=F5L(&=U87)D87(@;R!A<G%U:79O(&1E(&-O;F9I
M9W5R8>?C;R`E<RX@4&]D92!U<V%R('5M82!D87,@;W#G]65S('!A<F$@9W5A
M<F1A<B!O(&/S9&EG;R!E;2`E<R!O=2!C;W!I87(@;6%N=6%L;65N=&4@;R!C
M\V1I9V\@86)A:7AO('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV96P@<')O8W5R
M87(@;F\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!D97-L:6=A
M<B`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&%C='5A;&EZ87(@8V]N=&%C=&\N
M("5S`$[C;R!F;VD@<&]S<^UV96P@86-T=6%L:7IA<B!A(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!A(&-O
M;F9I9W5R8>?C;R!P87)A("(E<R(Z("5S`$[C;R!E;F-O;G1R96D@82!"87)R
M82!,871E<F%L(&1O($UO>FEL;&$N($%S<V5G=7)E+7-E('%U92!A(&)A<G)A
M(&QA=&5R86P@97-TX2!A8F5R=&$N`$[C;R!F;VD@<&]S<^UV96P@871R:6)U
M:7(@86\@=71I;&EZ861O<B`B)7,B(&]S('-E9W5I;G1E<R!D:7)E:71O<R!S
M;V)R92!A('!A<W1A("(E<R(Z("5S`%1E>'1O($-O;G1A9&\`4&'M<P!#=7)S
M;W,`0W)I87(`0W)I87(@3F]V;R!%=F5N=&\`0W)I87(@=6UA(&QI9V'GXV\`
M0W)I87(@=6UA(&YO=F$`0W)I87(@<W5B+7!A<W1A<P!#<FEA9&\`4&5R;6ES
M<_5E<R!D;R!#<FEA9&]R`$[Z;65R;R!D;R!C87)TXV\@9&4@8W+I9&ET;P!2
M97#Z8FQI8V$@9&$@0W)OX6-I80!297#Z8FQI8V$@9&4@0W5B80!#;W)R96YT
M90!1=6%T<F\@9F%S97,@8V]R<F5N=&5S`$1A=&$O2&]R80!54DP@8V]R<F5N
M=&4@Z0!%<W1A9&\@9&\@5&5M<&\`4VET=6'GXV\@86-T=6%L.B``17-T:6QO
M(&%C='5A;`!097)S;VYA;&EZ87(@87,@=&%R969A<R!Q=64@<V5RXV\@97AE
M8W5T861A<R!A<75A;F1O(&\@;&]G:6X@;F\@)7,N`$-O<G1A<@!#;W)T87(@
M82!S96QE8^?C;P!297#Z8FQI8V$@9&4@0VAI<')E`$-I<NUL:6-O("A+3TDX
M+5(I`$-I<NUL:6-O("A7:6YD;W=S+3$R-38I`$-I<NUL:6-O+U5C<F%N:6%N
M;R`H2T])."U5*0!297#Z8FQI8V$@0VAE8V$`1$0`1&EA<FEA;65N=&4`1&GA
M<FEO.B!297!E=&4@8V%D80!.879E9V%D;W(@9&4@P7)V;W)E(&1E($1A9&]S
M`$1A=&$`1&%T82!D92!296-E<.?C;P!396QE8^?C;R!D92!D871A`$1I80!$
M:6$H<RD`4F5?;6]V97(`4F5M;W9E<B!#;U]L=6YA`$1E>F5M8G)O`$[Z;65R
M;W,@9&5C:6UA:7,`1&5C;&EN;W4`4F5D=7II<B!I;F1E;G1AY^-O`%!O<B!/
M;6ES<^-O`$-A;&5N9.%R:6\@<&]R($]M:7-SXV\`0V]R(%!O<B!/;6ES<^-O
M`$ED96YT:61A9&4@4&%D<N-O`%!E<FUI<W/U97,@4&]R($]M:7-SXV\`4&5R
M;6ES<_5E<R!P;W(@;VUI<W/C;P!$969I;FGG]65S`%)E;6]V97(`4F5M;W9E
M<B`B)7,B`%)E;6]V97(@)7,`4F5M;W9E<B!E=F5N=&\`4F5M;W9E<B!'<G5P
M;P!296UO=F5R(%!E<FUI<W/C;P!296UO=F5R(&4@<'5R9V%R(&UE;G-A9V5N
M<P!296UO=F5R(&/I;'5L80!296UO=F5R(&-O;'5N80!296UO=F5R(&UO9&5L
M;R!A;'1E<FYA=&EV;R!E>&ES=&5N=&4`4F5M;W9E<B!P97)M:7-S]65S(&1E
M("(E<R(`4F5M;W9E<B!P97)M:7-S]65S('!A<F$@)R5S)R!E('%U86ES<75E
M<B!S=6(M<&5R;6ES<_5E<S\`4F5M;W9E<B!L:6YH80!296UO=F5R(&ED96YT
M:61A9&4@<V5L96-C:6]N861A`%)E;6]V97(@82!C;VQU;F$@8V]R<F5N=&4`
M4F5M;W9E<B!O(&%P96YA<R!O(&5V96YT;R!C;W)R96YT92P@;R!E=F5N=&\@
M8V]R<F5N=&4@92!T;V1A<R!A<R!O8V]R<NIN8VEA<R!F=71U<F%S+"!O=2!T
M;V1A<R!A<R!O8V]R<NIN8VEA<S\`4F5M;W9E<B!A(&QI;FAA(&-O<G)E;G1E
M`%)E;6]V97(@97-T82!P97)M:7-SXV\@92!T;V1A<R!A<R!S=6%S('-U8BUP
M97)M:7-S]65S/P`B4V-R:7!T(B!D92!A8W1U86QI>F'GXV\@(B5S(B!R96UO
M=FED;RX`36]M96YT;R!D92!E;G1R96=A`$1I;F%M87)C80!$97-C<E]IY^-O
M`$1E<V-R979A(&\@4')O8FQE;6$`1&5S8W)IY^-O`%!O<FUE;F]R97,@*'1A
M;6+I;2!N;R!R96=I<W1O+"`B;&]G(BP@9&\@2&]R9&4I.@!/<R!D971A;&AE
M<R!F;W)A;2!E;G9I861O<R!P87)A(&\@861M:6YI<W1R861O<B!D;R!S:7-T
M96UA+@!$97-E;G9O;'9I;65N=&\`4&]N=&\@9&4@3W)V86QH;P!0;VYT;R!D
M92!/<G9A;&AO(&YA(/IL=&EM82!H;W)A.B``4&]N=&\@9&4@;W)V86QH;SH@
M`$1I<F5CY^-O(&1A(&5S<75E<F1A('!A<F$@82!D:7)E:71A`$1I<F5CY^-O
M(&1A(&1I<F5I=&$@<&%R82!A(&5S<75E<F1A`$1I<F5C=/-R:6\`1&5S8V%R
M=&%R`$UO<W1R87(`36]S=')A<B!T96UP;W,@8V]M(#(T(&AO<F%S/P!/<.?U
M97,@9&4@5FES=6%L:7IAY^-O`$UO<W1R87(@<')E=FESXV\@<&]R;65N;W)I
M>F%D80!-;W-T<F%R('!R979I<^-O("A4048I`$9O<FUA=&\@9&4@=FES=6%L
M:7IAY^-O`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.XV\@
M<F5M;W9E<@!.XV\@=71I;&EZ92!O(&UA:6YT96YA;F-E+G!H<"!D:7)E8W1A
M;65N=&4`1&5S96IA(&UO<W1R87(@<')A>F\@9FEN86P@9&%S('1A<F5F87,@
M;F\@<V5U(&-A;&5N9.%R:6\_`$[C;R!S92!R97!E=&4`02!P<FEM96ER82!L
M:6YH82!C;VYTZ6T@;W,@;F]M97,@9&]S(&-A;7!O<S\@4V4@<VEM+"!A<W-I
M;F%L87(@97-T82!C86EX83H`1&]M:6YI8V$`4F5P^F)L:6-A($1O;6EN:6-A
M;F$`4F5C96)E<@!296-E8F5R("5S`$1E<V-A<G)E9V%R(&$@8V]N9FEG=7)A
MY^-O(&=E<F%D82!C;VUO('5M(")S8W)I<'0B(%!(4"X`3&ES=&$@9&4@9&5S
M96YR;VQA<@!$<F]G87,`4')A>F\@9FEN86PZ("5S`$1U<F'GXV\`0V]R<F5I
M;R!E;&5C='+S;FEC;P!%4E(`4F5P^F)L:6-A(&1O($5Q=6%D;W(`161I=&%R
M`$5D:71A<B`B)7,B`$5D:71A<B`E<P!%9&ET87(@4&%R=&EC:7!A;G1E<P!%
M9&ET87(@0FQO8V\`161I=&%R($=R=7!O`$5D:71A<B!097)M:7-S]65S`$5D
M:71A<B!097)M:7-S]65S`$5D:71A<B!P97)M:7-S]65S(&1E("5S`$5D:71A
M<B!#86QE;F3A<FEO<R!296UO=&]S`$5D:71A<B!P87)T:6-I<&%N=&5S`$5D
M:71A<B!C871E9V]R:6%S(&4@8V]R97,`161I=&%R(&]PY_5E<R!D93H`161I
M=&%R('!E<FUI<W/U97,@9&4@(B5S(@!%9&ET87(@<&5R;6ES<_5E<R!D92`E
M<P!%9'5C8>?C;P!%9VEP=&\`4F5P^F)L:6-A(&1E($5L(%-A;'9A9&]R`$5L
M96UE;G1O+BXN`$5M`$-O<G)E:6\@16QE8W1R\VYI8V\`16YD97)EYV\@9&4@
M0V]R<F5I;R!%;&5C='+S;FEC;P!/<R!E;F1E<F7G;W,@=.IM('%U92!C;VEN
M8VED:7(N`$UE;G-A9V5M(&-O;2!C;VYF:7)M8>?C;P!3[6UB;VQO<R!D92!%
M;6_GXV\`365N<V%G96T@=F%Z:6$N`%-E;2!R97-U;'1A9&]S+@!396T@=&5R
M;6]S(&1E('!R;V-U<F$`06-T:79A<B!I;G-E<N?C;R!D92!I;6%G96YS(&1E
M($=A;&5R:6%S($9O=&]G<N%F:6-A<R!N;R!T97AT;S\`06-T:79A<B!M96YU
M(&1E(&-O;G1E>'1O(&YO(&)O=.-O(&1I<F5I=&\@9&\@<F%T;S\`1&%T82!F
M:6YA;`!!8V%B82!E;0!(;W+A<FEO(&9I;F%L`$%N;R!D92!F:6T`075M96YT
M87(@161I=&]R`$EN=')O9'5Z82!U;6$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A
M('%U92!S97+A(&-O;G9I9&%D;R!A(')E<W!O;F1E<B!S92!P<F5C:7-A<B!D
M92!R96EN:6-I87(@82!S=6$@<&%L879R82UP87-S92P@92YG+BP@)V-O;6\@
M<V4@8VAA;6$@;R!S974@86YI;6%L(&1E(&5S=&EM8>?C;S\G.@!);G1R;V1U
M>F$@;R!54DP@9&$@:6UA9V5M(&%Q=6D`16YT<F%D87,Z("5D('1O=&%L+"`E
M9"!A8W1U86QI>F%D87,L("5D(&YO=F%S+"`E9"!A;'1E<F%D87,L("5D(&1E
M<V-O;FAE8VED87,`1W5I;ND@17%U871O<FEA;`!%<W1A9&\@9&$@17)I=')E
M:6$`17)R;P!%<G)O(&1E<V-A<G)E9V%N9&\@:6YF;W)M8>?C;R!L:79R92]O
M8W5P861O(&1E("5S.B`E<P!%<G)O(&YA(&UE;G-A9V5M(&1E(&-O<G)E:6\@
M96QE8W1R\VYI8V\N`$5R<F\@86\@97-C<F5V97(@(B5S(BX`17)R;SH@`%)E
M</IB;&EC82!D82!%<W3S;FEA`%)E</IB;&EC82!$96UO8W+A=&EC82!&961E
M<F%L(&1A($5T:?-P:6$`R71I8V\`175R;W!A`$5V96YT;R!D92`E<R!A("5S
M`$]S(&5V96YT;W,@=.IM(&1E('1E<B!U;6$@9&%T82!D92!I;NUC:6\N`$]S
M(&5V96YT;W,@=.IM(&1E('1E<B!U;2!T[71U;&\N`$]S(&5V96YT;W,@=.IM
M(&1E('1E<B!U;6$@9&%T82!F:6YA;"!O=2!U;6$@9'5R8>?C;RX`0V%D82`Q
M-2!M:6YU=&]S`$-A9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D
M82`U(&UI;G5T;W,`0V%D82!%;G1R861A`$-A9&$@;65I82!H;W)A`$-A9&$@
M;6EN=71O`%9A;&]R97,@97AE;7!L;SH`17AE8W5T87(`17AE8W5T86YD;SH`
M17AP86YD:7(`36]S=')A<B!"87)R82!,871E<F%L`"<I)R!E<W!E<F%D;P!%
M<W!E<F%V82!U;6$@<VEM<&QE<R!P86QA=G)A(&]U('5M('1E<FUO(&1E('!R
M;V-U<F$@96YT<F4@87-P87,`1&%T82!D92!%>'!I<F'GXV\`17AP;V5N=&4`
M17AP;W)T87(`17AP;W)T87(@8V%L96YDX7)I;P!%>'1R86EN9&\@9&4@)7,N
M+BX@`$-O<B!D;R!0<FEM96ER;R!0;&%N;P!#87)R96=A<B!C;VYF:6=U<F'G
MXV\@9&4@:6YS=&%L8>?C;R!P;W(@1E10`$[C;R!F;VD@<&]S<^UV96P@<'5X
M87(@87,@<')E9F5RZFYC:6%S+@!&86QH82!N82!L:6=AY^-O(&%O('-E<G9I
M9&]R($Q$05`N`$9A;&AA(&YA(&QI9V'GXV\@86\@<V5R=FED;W(@4TU"+@!&
M86QH82!A;R!C;W!I87(@9&4@(B5S(BX`1F%L:&$@86\@8V]P:6%R('!A<F$@
M(B5S(BX`1F%L:&$@86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!305-,+@!&
M86QH82!A;R!M;W9E<B!P87)A("(E<R(N`$)O;0!);&AA<R!&86QK;&%N9"`H
M36%L=FEN87,I`$EL:&%S($9A<F]E`$5R<F\@1F%T86PZ`$9A>`!&979E<F5I
M<F\`07!A<F5N=&$`07!A<F5N=&$Z(`!!;&=U;G,@06=U86-E:7)O<P!!;&=U
M;G,@3F5V]65S`$UA=')I>B!D92!C86UP;W,`1FEJ:0!#;VYT86=E;2!D92!!
M<G%U:79O<SH@)7,@87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@
M87)Q=6EV;W,`1V5S=.-O(&1E($9I8VAE:7)O<P!.;VUE(&1O($%R<75I=F\`
M4V5L96/GXV\@9&\@87)Q=6EV;P!#87)R96=A;65N=&\@9&4@87)Q=6EV;P!#
M87)R96=A;65N=&]S(&1E(&9I8VAE:7)O<R!NXV\@<^-O('-U<&]R=&%D;W,N
M`$9I;'1R;W,`4&5S<75I<V%R`$9I;FSB;F1I80!1=6%R=&\@0W)E<V-E;G1E
M`%%U87)T;R!#<F5S8V5N=&4`1FEX87(@<N%C:6\`26YV97)T97(`1FQU='5A
M;G1E`$YE=F]E:7)O`$$@<&%S=&$@)7,@;N-O(&5X:7-T92X`0V]R(&1O(%1E
M>'1O`$-O;6ED80!087)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P;W)T86T@
M:6UA9V5N<P!0<F5V:7/C;R`H5$%&*0!$:6%S(&1E(%!R979I<^-O("AN;W1E
M+7-E('%U92!A<R!P<F5V:7/U97,@:6YC;'5E;2!T86YT;R!D:6%S(&-O;6\@
M;F]I=&5S.R!U;2!V86QO<B!D96UA<VEA9&\@9W)A;F1E('!O9&4@<F5S=6QT
M87(@;G5M(&)L;V-O(&UU:71O(&QA<F=O*0!%<W%U96-E=2US92!D82!P86QA
M=G)A+7!A<W-E/P!-;V1E;&]S`$1I=&]S`%1I<&\@9&4@9&ET;W,`1&ET;W,`
M1&ET;W,@,@!&\W)U;G,`4F5E;G9I;W,`07!L:6-AY_5E<R`H;?-D=6QO<RD@
M96YC;VYT<F%D87,Z("5S`%!A<W1A<R!E;F-O;G1R861A<SH`-BZJ`$UO;&1U
M<F%S`%)E</IB;&EC82!&<F%N8V5S80!&<F%NYV$L($UE=')O<&]L:71A;F$`
M26YF;W)M8>?C;R!,:79R92]/8W5P861O`$=U:6%N82!&<F%N8V5S80!0;VQI
M;NES:6$@1G)A;F-E<V$`5&5R<F%S($%U<W1R86ES(&4@06YTX7)C=&EC87,@
M1G)A;F-E<V%S`'-E>'1A+69E:7)A`$1E`$1E(`!$97-C<FGGXV\@0V]M<&QE
M=&$`3'5A($-H96EA`$YO;64@0V]M<&QE=&\`1G5T=7)O`$1I9G5S87,`4F5P
M^F)L:6-A($=A8F]N97-A`$=A;&5R:6$@9&4@;VYD92!R971I<F%R(&$@:6UA
M9V5M`$=A;&5R:6$Z`%)E</IB;&EC82!D82!'XFUB:6$`2F]G;P!'97)A;`!'
M97)A<B!#;VYF:6=U<F'GXV\@)7,`0_-D:6=O($=E<F%D;P!'97)A;F1O(&\@
M97-T861O(&1O(&WS9'5L;R`E<RXN+@!'9?-R9VEA`%)E</IB;&EC82!&961E
M<F%L(&1A($%L96UA;FAA`$5R<F\@96T@9V5T;W!T.@!297#Z8FQI8V$@9&\@
M1V%N80!':6)R86QT87(`3F]M92!0<O-P<FEO`$ER`$?V9&5L`%!E<W%U:7-A
M($=O;V=L90!)<B!P87)A("5S`$[M=F5I<R!D92!C:6YZ96YT;P!'<NEC:6$`
M1W)E9V\@*$E33RTX.#4Y+3<I`$=R;VYE;.)N9&EA`$=R86YA9&$`061M:6YI
M<W1R8>?C;R!D92!'<G5P;W,`3F]M97,@9&4@9W)U<&]S(&[C;R!P;V1E;2!E
M<W1A<B!V87II;W,`4&5R;6ES<_5E<R!D92!G<G5P;P!'<G5P;W,`1W5A9&%L
M=7!E`$=U86T`4F5P^F)L:6-A(&1A($=U871E;6%L80!'=65R;G-E>0!097)M
M:7-S]65S(&1A<R!6:7-I=&%S`%!E<FUI<W/U97,@9&%S(%9I<VET87,`3&EV
M<F\@9&4@5FES:71A<P!'=6ENZ0!'=6ENZ2U":7-S874`4F5P^F)L:6-A($-O
M+6]P97)A=&EV82!D82!'=6EA;F$`2%1-3`!/($A434Q!<F5A(')E8W5S82US
M92!C;V)A<F1E;65N=&4@82!R96UO=F5R(&$@^FQT:6UA(&/I;'5L82!D82!L
M:6YH82X`3R!(5$U,07)E82!R96-U<V$M<V4@8V]B87)D96UE;G1E(&$@<F5M
M;W9E<B!A(/IL=&EM82!C;VQU;F$@9&$@=&%B96QA+@!/($A434Q!<F5A(')E
M8W5S82US92!C;V)A<F1E;65N=&4@82!R96UO=F5R(&$@^FQT:6UA(&QI;FAA
M(&1A('1A8F5L82X`075T96YT:6-AY^-O($A44%`@;N-O(&9O:2!E;F-O;G1R
M861A+@!297#Z8FQI8V$@9&\@2&%I=&D`06QG;W)I=&UO(&1E(")(87-H(@!.
M96)L:6YA`$-A8F7G86QH;P!);&AA<R!(96%R9"!E($UC1&]N86QD`%1E;7!O
M<F%L+50@1F]R=&4`2&5B<F5U("A)4T\M.#@U.2TX+4DI`$%L='5R80!!:G5D
M80!!:G5D82!S;V)R92!O(&5D:71O<@!!:G5D80!!<&QI8V'GXV\@875X:6QI
M87(@<&%R82!C<FEA<B!E(&UA;G1E<B!T<F%D=>?U97,@9&$@<&QA=&%F;W)M
M80I(;W)D92!E(&1A<R!S=6%S(&%P;&EC8>?U97,@*&WS9'5L;W,I+@I087)A
M('5M82!I;G1R;V1UY^-O(&QE<B!O(&9I8VAE:7)O(%)%041-12!N97-T82!P
M87-T82X`2&5M:7-FZ7)I;P!!<75I(&5S=.$@;R!I;NUC:6\@9&\@87)Q=6EV
M;SH`17-C;VYD97(`3V-U;'1A<B`E<P!!;'1A`$YO;65S(&1A<R!E;G1R861A
M<R!H:7-T\W)I87,@;N-O('!O9&5M(&5S=&%R('9A>FEO<P!#85]S80!%<W1A
M9&\@9&$@0VED861E(&1O(%9A=&EC86YO`$-A<V$`16YD97)EYV\@9&4@0V%S
M80!496QE9F]N92!D92!#87-A`%)E</IB;&EC82!D87,@2&]N9'5R87,`2&]N
M9W5E8V]N9W5E`$AO<F1E`$=E<F%D;W(@9&4@=')A9'7G]65S($AO<F1E`$AO
M<F1E+TMO;&%B.B!$861O<R!834P@)7,@:6YVX6QI9&]S(&YA(&UE;G-A9V5M
M("5S`$AO<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E<W!O;F1E
M(&%O(&]B:F5C=&\@)7,`2&]R9&4O2V]L86(Z($YE;FAU;2!O8FIE8W1O(&1O
M('1I<&\@)7,@96YC;VYT<F%D;R!N82!M96YS86=E;2`E<P!(;W)D92]+;VQA
M8CH@4F5M;^?C;R!D92`E<R`B)7,B('1E=F4@<W5C97-S;P!(;W)D92]+;VQA
M8CH@4VEN8W)O;FEZ8>?C;R!D92`E<R`B)7,B('1E=F4@<W5C97-S;P!(;W)D
M92]+;VQA8CH@3R!M;W1O<B!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N
M<^-O(%!(4"`G9&]M>&UL)P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E
M;"!C<FEA<B!U;6$@;F]V82#A<G9O<F5S(%A-3"!P87)A(&\@;V)J96-T;R`E
M<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@
M240@34E-12!P87)A(&$@<&%R=&4@9&4@=&EP;R`E<P!(;W)D92]+;VQA8CH@
M3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B!P87)T:6QH
M87,Z("5S`$AO<F1E+TMO;&%B.B!087)T:6QH82`B)7,B(&1E<V-O;FAE8VED
M80!4<F'G;R!(;W)I>F]N=&%L`$5N8VAI;65N=&\@:&]R:7IO;G1A;`!(;W)I
M>F]N=&%L.@!(;W)A*',I`$-O;6\@8VAE9V]U(&%Q=6D_("A0;W(@9F%V;W(@
M<F5P;W)T92UO(2D`475A;G1A<R!C;VQU;F%S('!R971E;F1E(&IU;G1A<C\`
M073I('%U86YT;W,@9&EA<R!N;R!F=71U<F\@9&5V96UO<R!G97)A<B!I;F9O
M<FUAY^-O(&QI=G)E+V]C=7!A9&\_`%%U86YT;W,@8V%M<&]S("AC;VQU;F%S
M*2!E>&ES=&5M/P!1=6%N=&%S(&QI;FAA<R!P<F5T96YD92!J=6YT87(_`$AU
M;6ED861E`$AU;6ED861E.B``2'5M;W)I<W1A<P!297#Z8FQI8V$@9&$@2'5N
M9W)I80!!(&-R:6'GXV\@9&$@8V%I>&$@<&]S=&%L($E-05`@9F%L:&]U.B`E
M<P!296UOY^-O(&1A(&-A:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,`0W)I
M8>?C;R!D92!Q=6]T82!D92!C86EX82!P;W-T86P@24U!4"!F86QH;W4Z("5S
M`$5N9&5R9>=O($E0`$5N9&5R9>=O($E0(&EN9&ES<&]N[79E;"X`16YD97)E
MYV\@25`@9F]R82!D;R!B;&]C;R!#2412('!E<FUI=&ED;RX`5FEO;&'GXV\@
M9&4@8FQO<75E:6\@9&4@25``25]N<V5R:7(@3&EN:&$@06YT97,`4F5P^F)L
M:6-A(&1A($ES;.)N9&D`07!E;F%S(,UC;VYE<P#-8V]N97,@8V]M(%1E>'1O
M`$YO;64@9&$@:61E;G1I9&%D93H`4V4@;N-O(&9O<B!M;W-T<F%D;R!C;W)R
M96-T86UE;G1E+"`E<R!P87)A(&\@86)R:7(@;G5M82!N;W9A(&IA;F5L82X`
M4V4@;N-O('9I<B!Q=6%L<75E<B#M8V]N92!A;R!U<V%R(&\@26YT97)N970@
M17AP;&]R97(L('!O9&4@<')E8VES87(@9&4@<V5L96-C:6]N87(@97-T82!C
M86EX82!P87)A(&1E<VQI9V%R(&$@=')A;G-P87+J;F-I82X`4V4@=FER(&5S
M=&$@;65N<V%G96T@;FUA<R!NXV\@82!I;6%G96T@<')O<')I86UE;G1E(&1I
M=&$L(&$@:6UA9V5M('%U92!P<F5T96YD92!C87)R96=A<B!NXV\@<&]D92!S
M97(@;6]S=')A9&$@<&5L;R!S974@;F%V96=A9&]R+@!0<F5V:7/C;R!D82!)
M;6%G96TZ`%523"!D82!I;6%G96T`55),(&1A(&EM86=E;3H`26UA9V5M(&1E
M(&=A;&5R:6$`26UA9V5M(&1E(&=A;&5R:6$Z`$-A<G)E9V%M96YT;R!D82!I
M;6%G96T`26UA9V5N<P!);7!O<G1A<B!#86QE;F3A<FEO+"!087-S;R`E9`!)
M;7!O<G1A<BP@4&%S<V\@)60`26UP;W)T87(O17AP;W)T87(@0V%L96YDX7)I
M;P!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O<R!I;7!O<G1A9&]S.@!);E]S
M97)I<B!,:6YH82!$97!O:7,`0_-D:6=O(&1E(&%CY^-O(&EN=')O9'5Z:61O
M(&5S=.$@:6YC;W)R96-T;RX`3F]M92!D92!U=&EL:7IA9&]R(&]U('!A;&%V
M<F$M<&%S<V4@97)R861O<RX`3F]M92!D92!U=&EL:7IA9&]R(&]U(&5N9&5R
M9>=O(&%L=&5R;F%T:79O(&5R<F%D;W,N($-O;G1A8W1E(&\@<V5U(&%D;6EN
M:7-T<F%D;W(@9&4@<VES=&5M82!P87)A(&]B=&5R(&%J=61A+@!!=6UE;G1A
M<B!A($EN9&5N=&'GXV\`4F5P^F)L:6-A(&1A(,UN9&EA`%5T:6QI>F%D;W)E
M<R!);F1I=FED=6%I<P!297#Z8FQI8V$@9&$@26YD;V[I<VEA`$EN9F]R;6'G
MXV\`26YF;W)M8>?C;P!);F9O<FUAY^-O(&KA(&[C;R!E<W3A(&1I<W!O;NUV
M96P`26YI8VEA;&EZ86YD;R!O(&WS9'5L;R`E<RXN+B``26YS97)I<B!#7V]L
M=6YA($1E<&]I<P!);G-E<FER($EM86=E;0!);G-E<FER(%1A8F5L80!);G-E
M<FER($QI9V'GXV\@X"!796(`26YS97)I<B!?0V]L=6YA($%N=&5S`$EN<VER
M:7(@=6UA(&YO=F$@8V]L=6YA(&1E<&]I<R!D82!C;W)R96YT90!);G-I<FER
M('5M82!N;W9A(&-O;'5N82!A;G1E<R!D82!C;W)R96YT90!);G-I<FER('5M
M82!N;W9A(&QI;FAA(&1E<&]I<R!D82!C;W)R96YT90!);G-I<FER('5M82!N
M;W9A(&QI;FAA(&%N=&5S(&1A(&-O<G)E;G1E`$EN<V5R:7(@=6T@<&%RX6=R
M869O(&%P\W,@;R!N\R!C;W)R96YT90!);G-E<FER('5M('!A<N%G<F%F;R!A
M;G1E<R!D;R!N\R!C;W)R96YT90!);G-I<FER(&UO9&5L;R!A;'1E<FYA=&EV
M;P!);G1R;V1U>F$@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC
M;R!O;F1E('!O<W-A(')E8V5B97(@82!N;W9A('!A;&%V<F$M<&%S<V4Z`$EN
M<VER:7(@8^EL=6QA(&%P\W,`26YS97)I<B!CZ6QU;&%S(&%N=&5S`$EN<V5R
M:7(@8^EL=6QA(&1E<&]I<P!);G-E<FER(&-O;'5N82!A;G1E<P!);G-E<FER
M(&UE;G-A9V5N<P!);G-E<FER('!A<N%G<F%F;R!A;G1E<P!);G-E<FER('!A
M<N%G<F%F;R!A;G1E<P!);G-E<FER(&QI;FAA(&1E<&]I<P!);G-E<FER(&QI
M;FAA(&%N=&5S`$EN=')O9'5Z82!A(')E<W!O<W1A(&5X:6=I9&$@<&%R82!A
M('!E<F=U;G1A(&1E('-E9W5R86[G83H`26YS97)I<B]-;V1I9FEC87(@26UA
M9V5M`$EN<V5R:7(O36]D:69I8V%R($QI9V'GXV\`0W+I9&ET;R!I;G-U9FEC
M:65N=&4@<&%R82!E;G9I87(@<&%R82!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C
M;RX`0W+I9&ET;R!I;G-U9FEC:65N=&4N`$EN=&5I<F\`3&ES=&$@9&4@:6YT
M96ER;W,`541(("A5<V5R($1A=&$@2&5A9&5R*2!I;G;A;&ED;RX`1&%D;W,@
M6DE0(&EN=N%L:61O<P!!<&QI8V'GXV\@:6YVX6QI9&$N`$E$(&1E(&QO=&4@
M*")B871C:"(I(&EN=N%L:61O+@!/<R!D861O<R!S=6)M971I9&]S('/C;R!I
M;G;A;&ED;W,N`$5N9&5R9>=O(&1E(&1E<W1I;F\@:6YVX6QI9&\N`$9O<FUA
M=&\@9&\@87)Q=6EV;R!I;G;A;&ED;P!#:&%V92!D82!L:6-E;N=A(&EN=N%L
M:61A+@!,;V-A;&EZ8>?C;R!I;G;A;&ED82!E<W!E8VEF:6-A9&$N`&US9U]T
M>7!E(&EN=N%L:61O+@!A<&E?:60@:6YVX6QI9&\@;W4@96T@9F%L=&$N`%!A
M<N)M971R;W,@:6YVX6QI9&]S(&]U(&5M(&9A;'1A+@!097)M:7-SXV\@<&%R
M96YT86P@:6YVX6QI9&$N`$E$(&1E('!A<F-E:7)O(&EN=N%L:61O+@!#\V1I
M9V\@9&4@<')O9'5T;R!I;G;A;&ED;RX`4')O=&]C;VQO(&EN=N%L:61O+@!$
M97-T:6YA=.%R:6\@:6YVX6QI9&\Z("(E<R(`3V)J96-T;R!D92!P87)T:6QH
M82!I;G;A;&ED;P!%;F1E<F7G;R!D82!O<FEG96T@:6YVX6QI9&\N`$1A9&]S
M('5N:6-O9&4@:6YVX6QI9&]S+@!);G9E;G3A<FEO`%)E</IB;&EC82!)<VSB
M;6EC82!D;R!)<N-O`%)E</IB;&EC82!D;R!)<F%Q=64`4F5P^F)L:6-A(&1A
M($ER;&%N9&$`26QH82!D92!-86X`5&5M<&]R86ES+50@27-O;&%D;W,`17-T
M861O(&1E($ES<F%E;`!%;6ES<V]R`$ETX6QI8V\`4F5P^F)L:6-A($ET86QI
M86YA`$IA;6%I8V$`2F%N96ER;P!*87#C;P!*87!O;NIS("A)4T\M,C`R,BU*
M4"D`2F5R<V5Y`%)E:6YO($AA<VAE;6ET82!D82!*;W)DXFYI80!*=6QH;P!*
M=6YH;P!*=7-T:69I8V%R`$-E;G1R87(`2G5S=&EF:6-A<@!*=7-T:69I8V%R
M(.`@17-Q=65R9&$`2G5S=&EF:6-A<B#@($1I<F5I=&$`4F5P^F)L:6-A(&1O
M($-A>F%Q=6ES=.-O`%!R97-E<G9A<B!O(&]R:6=I;F%L/P!297#Z8FQI8V$@
M9&\@477I;FEA`$\@<V5R=FED;W(@2V5R8F5R;W,@<F5J96ET;W4@82!A=71E
M;G1I8V'GXV\N`$YO=F%T;W,@;F\@(DME<FYE;"(`0W)I8>?C;R!D82!#:&%V
M90!);7!R97-SXV\@9&EG:71A;"!D82!C:&%V90!#;VUP<FEM96YT;R!D82!C
M:&%V90!4:7!O(&1A($-H879E`%5T:6QI>F'GXV\@9&$@0VAA=F4`02!C:&%V
M92!JX2!E>&ES=&4@;F\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!0
M86QA=G)A<RUC:&%V90!-:?ID;W,`475I<FEB871I`%)E</IB;&EC82!0;W!U
M;&%R($1E;6]C<N%T:6-A(&1A($-O<F5I80!297#Z8FQI8V$@9&$@0V]R96EA
M`$-O<F5A;F\@*$550RU+4BD`2W5W86ET`%)E</IB;&EC82!1=6ER9W5I>F4`
M7T1I<W!O<VGGXV\`261I;VUA`%)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T
M:6-A($QA;P#:;'1I;6%S(#(T(&AO<F%S`%%U87)T;R!$96-R97-C96YT90#:
M;'1I;6\@36]D:69I8V%D;P#:;'1I;6\@3>IS`%%U87)T;R!$96-R97-C96YT
M90#:;'1I;6$@06-T=6%L:7IAY^-O.@#:;'1I;6$@96YT<F%D83H@)7,`VFQT
M:6UA(&5N=')A9&$Z("5S(&1E("5S`-IL=&EM82!E;G1R861A.B!.=6YC80#:
M;'1I;6$@<V5M86YA`$1U<F'GXV\`4F5P^F)L:6-A(&1A($QE=/-N:6$`3&5I
M`$1I<W!O<VGGXV\`1&5I>&%R('9A>FEO('!A<F$@9FEC87(@<V5M(&)O<F1A
M`$SM8F%N;P!%<W%U97)D80!#86)EYV%L:&\@9&$@97-Q=65R9&$`5F%L;W)E
M<R#@(&5S<75E<F1A`$QE<V]T;P!,:6+I<FEA`$=R86YD92!*86UA:&ER:7EA
M(%-O8VEA;&ES=&$@4&]P=6QA<B#!<F%B92!D82!,[6)I80!,:7-T96YS=&%I
M;F4`0VAU=F$@(DUO;&AA+51O;&]S(@!#:'5V:7-C;W,`0VAU=FES8V]S($UA
M=&EN86ES`$-H=79I<V-O<R!697-P97)T:6YO<P!097%U96YO($%G=6%C96ER
M;P!#:'5V:7-C;R!C;VT@5')O=F]A9&$`475E9&$@9&4@3F5V90!.979E`"),
M:6UE<FEC:R(`3&EM:71A<B!A(&=A;6$@=&5M<&]R86P@82!E>'!O<G1A<CH@
M`$QI9V'GXV\`3&EG8>?C;R!A<&]N=&$@<&%R83H`3&EG87(@;R!E;F1E<F7G
M;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(.`@<.%G:6YA(&1E(&-O;7!O<VGG
MXV\@86\@;6]S=')A<@!,:6=AY_5E<P!";VQI;FAO(&QI;G5XZG,`3&ES=&$@
M+2!O('5T:6QI>F%D;W(@<&]D92!V97(@82!P87-T80!,:7-T87(@0F%S97,@
M9&4@1&%D;W,`36]S=')A<B!4\W!I8V]S(&1E($%J=61A`$QI<W1A<B!486)E
M;&%S`$QI<W1A9V5M+4%R<75I=F\`3&ES=&%G96TM06IU9&$`240@9&$@3&ES
M=&$`3&ES=&%G96TM1&]N;P!,:7-T86=E;2U3=6)M:7-S]65S`$QI<W1A9V5M
M+5-U8G-C<FET87,`3&ES=&%G96TM3N-O('-U8G-C<FET87,`02!L:7-T86=E
M;2!D92!U=&EL:7IA9&]R97,@97-TX2!D97-A8W1I=F%D82X`3&ET97)A='5R
M83H`4F5P^F)L:6-A(&1A($QI='7B;FEA`$QO7V-A;`!#87)R96=A;F1O(&)I
M8FQI;W1E8V%S+BXN`$-A<G)E9V%N9&\N+BX`5&5M<&\@;&]C86PZ`$QO8V%L
M:7IAY^-O(&4@1G5S;R!(;W+A<FEO`$QO8V%L`$5N=')A<@!386ER`%1A<F5F
M87,@9&4@16YT<F%D80!!(&%U=&5N=&EC8>?C;R!F86QH;W4@<&]R(&\@3F]M
M92!D92!5=&EL:7IA9&]R(&]U(&$@4&%L879R82U087-S92!E<W1A<F5M(&EN
M8V]R<F5C=&]S+@!!(&%U=&5N=&EC8>?C;R!F86QH;W4N`%1E>'1O(&QO;F=O
M`$%M;W(`0F%I>&\`3&5T<F%S(&=R96=A<R!M:6[Z<V-U;&%S`$QE=')A<R!L
M871I;F%S(&UI;OIS8W5L87,`3OIM97)O<R!R;VUA;F]S(&UI;OIS8W5L;W,`
M3'5X96UB=7)G;P!-30!-3U1$`$\@86YE>&\@35,M5$Y%1B!NXV\@8V]N=&EN
M:&$@9&%D;W,N`$U31P!-86-A=0!-86-E9/-N:6$L($%N=&EG82!297#Z8FQI
M8V$@2G5G;W-L879A(&1A`$UA9&%GX7-C87(`36%G:6$`0V]R<F5I;P!!9&UI
M;FES=')AY^-O(&1E($-O<G)E:6\`1F%Z97(@;&E?9V'GXV\N+BX`07-S96=U
M<F4M<V4@9&4@<75E('1E;2!O(%!%05(@:6YS=&%L861O(&4@;F\@8V%M:6YH
M;R!D92!I;F-L=7/U97,@*&EN8VQU9&4@<&%T:"DN`$-R:6%N9&\@82!P87-T
M82`E<P!-86QA=6D`36%LX7-I80!-86QD:79A<P!-86QI`$UA;'1A`$=E<FER
M(&-A;&5N9.%R:6]S(')E;6]T;W,N`$=I<F$@82!L:7-T82!D92!C871E9V]R
M:6%S('%U92!P;V1E(&%T<FEB=6ER(&%O<R!I=&5N<RP@8F5M(&-O;6\@87,@
M8V]R97,@<75E(&QH97,@97-TXV\@87-S;V-I861A<RX`36%P82!-87`R-`!-
M87!A($UA<%%U97-T`$UA<N=O`$UA<F=E;0!-87)C87(@8V]M;R!,:61A+T[C
M;R!L:61A`$UA<F-A<B!D92!O=71R87,@9F]R;6%S("AE+F<N+"!);7!O<G1A
M;G1E+U!O<B!R97-P;VYD97(I`$EL:&%S($UA<G-H86QL`$UA<G1I;FEC80!#
M86UP;W,@<75E(&-O<G)E<W!O;F1E;0!-875R:73B;FEA`$UA=7+M8VEO`$WA
M>&EM;R!C<NED:71O('!E<FUI=&ED;RX`3>%X:6UO(&[Z;65R;R!D92!P87)T
M97,@;G5M82!M96YS86=E;2!E>&-E9&ED;RX`5&5M<&5R871U<F$@;>%X:6UA
M(&YA<R#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA(&YA
M<R#Z;'1I;6%S(#8@:&]R87,Z(`!#;VUP<FEM96YT;R!MX7AI;6\`36%I;P!-
M87EO='1E`$UE9&EC:6YA`$5N8V]N=')O`$UE;6)R;W,`3&ES=&$@9&4@365N
M=7,`36]D;R!D;R!M96YU.@!5;FER(&/I;'5L87,`26YT96=R86YD;R!T;V1O
M<R!O<R!F:6-H96ER;W,@)7,N<&\@8V]M(&\@8V]M<.IN9&EO+BXN`$EN=&5G
M<F%N9&\@82!L;V-A;&EZ8>?C;R`E<RXN+B``26YT96=R86YD;R!O(&%R<75I
M=F\@4$\@9&4@)7,@8V]M(&\@8V]M<.IN9&EO+BXN(`!);G1E9W)A;F1O(&$@
M=')A9'7GXV\@9&\@;?-D=6QO("5S+BXN`$UE;G-A9V5M`$UE;G-A9V5N(%9E
M<FEF:6-A9&$@8V]M(%-U8V5S<V\L(&UA<R!O(&-E<G1I9FEC861O(&1O('-U
M8G-C<FET;W(@;N-O('#T9&4@<V5R('9E<FEF:6-A9&\N`$UE;G-A9V5M(&5X
M<&ER;W4N`%1I<&\@9&4@;65N<V%G96T`365T96]R;VQO9VEA($U%5$%2`$)L
M;V-O($U%5$%2(&EN9&ES<&]N[79E;"X`0FQO8V\@345405(@:6YD:7-P;V[M
M=F5L+B!/<R!P;W)M96YO<F5S(&9O<F%M(')E9VES=&%D;W,@<&%R82!O(&%D
M;6EN:7-T<F%D;W(N`$$@365T87)$0B!NXV\@97-TX2!C;VYE8W1A9&$N`$WI
M=&]D;P!/(&WI=&]D;R`B)7,B(&[C;R!E<W3A(&1E9FEN:61O`$WI=')I8V\`
M3>EX:6-O`$UI8W)O;NES:6$L($5S=&%D;W,@1F5D97)A9&]S(&1A`$-E;G1R
M;P!4:7!O($U)344`5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#(T
M(&AO<F%S`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`V(&AO<F%S
M`$UI;G5T;RAS*0!%<W!E;&AO`$UI<V-E;.)N96$`3&ES=&$@9&4@179E;G1O
M<R!&86QH861O<P!086-O=&4@2%144%]297%U97-T(&1O(%!%05(@96T@9F%L
M=&$N`$-O;F9I9W5R8>?C;R!E;2!F86QT82X@5&5RX2!D92!A(&=E<F%R(&%G
M;W)A('-E('%U:7-E<B!U<V%R(&5S=&$@87!L:6-AY^-O+@!)1"!D82!M96YS
M86=E;2!E;2!F86QT82X`4&%C;W1E($UA:6P@9&\@4$5!4B!E;2!F86QT82X`
M240@9&$@<V5S<^-O(&5M(&9A;'1A+@`R+JH`0V]R<F5I;R!-\W9E;`!-;V1E
M<F%D;P!$871A(&1E($UO9&EF:6-AY^-O`$UO9&EF:6-A<B!54DP`3?-D=6QO
M`$WS9'5L;P!297#Z8FQI8V$@9&$@36]L9&]V80!0<FEN8VEP861O(&1O($WS
M;F%C;P!S96=U;F1A+69E:7)A`$UO;F?S;&EA`$WJ<P!6:7-T82!D92!-ZG,`
M3>IS(&4@86YO`$UE;G-A;&UE;G1E`$QI<W1A(&1E($5V96YT;W,@365N<V%I
M<P!-96YS86PZ(%)E<&5T92!C861A`$UE<V5S(.`@1G)E;G1E`$UE<V5S($%T
M<N%S`$UO;G1S97)R870`1F%S92!D82!,=6$`4F5I;F\@9&4@36%R<F]C;W,`
M4V]B<F5T=61O($QI;7!O`%-O8G)E='5D;R!%;F5V;V%D;P!3;V)R971U9&\@
M4V]L87)E;F=O`$1E<V-E<@!-;W9E<B!P87)A(&$@17-Q=65R9&$`36]V97(@
M<&%R82!A($1I<F5I=&$`4W5B:7(`1&5S8V5R`%-U8FER`%)E</IB;&EC82!D
M92!-;^=A;6)I<75E`$QI<W1A<R!D92!D97-E;G)O;&%R(&UU;'1I+6[M=F5L
M`$WZ;'1I<&QO<R!C;VUP;VYE;F5T92!I0V%L96YD87(@96YC;VYT<F%D;W,[
M(&%P96YA<R!S92!S=7!O<G1A('5M('9%=F5N="X`4V5L96/GXV\@;?IL=&EP
M;&$`02!-:6YH82!#;VYT80!/<R!-975S($-A;&5N9.%R:6]S`$]S($UE=7,@
M0V%L96YDX7)I;W,Z`$]S($UE=7,@55),($QI=G)E+T]C=7!A9&\`3R!-974@
M4&]R=&%L`$1I<W!O<VGGXV\@9&\@4&]R=&%L`%5N:>-O(&1E($UY86YM87(`
M3N-O+"!NXV\@8V]N8V]R9&\`3F]M90!297#Z8FQI8V$@9&$@3F%M[6)I80!.
M875R=0!.97!A;`!296EN;R!D;W,@4&'M<V5S($)A:7AO<P!!;G1I;&AA<R!(
M;VQA;F1E<V%S`%523"!D92!"87-E($YE='-C87!E`%523"!D92!2979O9V'G
MXV\@0T$@3F5T<V-A<&4`55),(&-O;2!A('!O;.UT:6-A(&1E($-!($YE='-C
M87!E`%523"!D92!296YO=F'GXV\@3F5T<V-A<&4`55),(&1E(%)E=F]G8>?C
M;R!.971S8V%P90!.;VUE(&1O('-E<G9I9&]R(%-33"!.971S8V%P90!#;VUE
M;G3A<FEO(&1E(&-E<G1I9FEC861O($YE='-C87!E`%1I<&\@9&4@8V5R=&EF
M:6-A9&\@3F5T<V-A<&4`4F5D90!.=6YC80!.;W9A($-A;&5D\VYI80!.;W9A
M($-A=&5G;W)I80!.;W9O($5V96YT;P!,=6$@3F]V80!.;W9O($YO;64@9&4@
M571I;&EZ861O<B`H;W!C:6]N86PI`$YO=F$@6F5LXFYD:6$`3F]V82!J86YE
M;&$@*%]B;&%N:RD`3F]T[6-I87,`1W)U<&]S(&1E($YO=.UC:6%S`%!R\WAI
M;6\`4'+S>&EM87,@,C0@:&]R87,`4'+S>&EM87,@-"!&87-E<P!0<O-X:6UO
M($1I80!0<O-X:6UO($WJ<P!0<O-X:6UA(%-E;6%N80!0<O-X:6UO(&1I80!0
M<O-X:6UA<R!O<.?U97,`4'+S>&EM82!S96UA;F$`4'+S>&EM83X`4F5P^F)L
M:6-A(&1A($YI8V%RX6=U80!297#Z8FQI8V$@9&\@3NUG97(`4F5P^F)L:6-A
M($9E9&5R86P@9&$@3FEG97)I80!.;VET90!.:75E`$[C;P!396T@26YF;W)M
M8>?C;P!396T@879I<V\`4V5M('!A<G1I8VEP86YT97,`3N-O(&CA(&1A9&]S
M(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<R!E;2!R96QAY^-O(&%O<R!Q
M=6%I<R!M;W-T<F%R(&1I9F5R96[G87,N`$[C;R!HX2!N96YH=6UA(&5S=')A
M=.EG:6$@9&ES<&]N[79E;"!P87)A(')E86QI>F%R(&EM86=E;G,@25-/+@!.
MXV\@:.$@;6]D96QO(&1E(&QO=&4@(F)A=&-H(BX`3N-O(&5X:7-T92!B;&]C
M;R!N82!P;W-IY^-O(&EN9&EC861A`$[C;R!F;VD@9F]R;F5C:61O('5M(&YO
M;64@9&4@8V%L96YDX7)I;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN`$[C
M;R!HX2!C86QE;F3A<FEO<R!D:7-P;V[M=F5I<R!P87)A(&-O;G9I9&%D;W,N
M`%-E;2!M;V1I9FEC8>?U97,N`$[C;R!S92!P;V1E(&%D:6-I;VYA<B!P97)M
M:7-S]65S(&1E(&9I;&AO<R!A8F%I>&\@9&5S=&4@;NUV96PN`$[C;R!S92!P
M;V1E(&%D:6-I;VYA<B!F:6QH;W,@82!E<W1A('!E<FUI<W/C;RX`3F5N:'5M
M(&-O;6%N9&\@97-P96-I9FEC861O+@!.XV\@9F]I(&5S<&5C:69I8V%D82!A
M(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O('!A<F$@)7,N`$[C;R!F;VD@
M97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@<&%R
M82!61E,@8F%S96%D;R!E;2!&5%`N`$[C;R!F;VD@97-P96-I9FEC861A(&$@
M:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@;F5C97-SX7)I82!P87)A(&\@
M5D93(&)A<V5A9&\@96T@4U%,+@!.XV\@9F]I(&5S<&5C:69I8V%D82!A(&EN
M9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&YE8V5S<^%R:6$@<&%R82!O(%9&
M4R!B87-E861O(&5M(%-13"U&:6QE+@!#<NED:71O(&5S9V]T;W4N`$YE;FAU
M;2!D97-T:6YA=.%R:6\@9F]I(&9O<FYE8VED;RX`4V5M(&1A=&$@9FEN86P`
M3N-O(&5X:7-T92!Q=6%L<75E<B!E;G1R861A(&-O;2!O(&ED("(E<R(@;F\@
M87)Q=6EV;R!D92!A:G5D82!O<FEG:6YA;"X`4V5M(&5V96YT;W,@<&%R82!M
M;W-T<F%R`$[C;R!S92!C87)R96=O=2!N861A+@!);F9O<FUAY^-O(&QI=G)E
M+V]C=7!A9&\@<&%R82`E<R!E<W3A(&EN9&ES<&]N[79E;`!.XV\@<V4@96YC
M;VYT<F]U(&1A9&]S(&E#86QE;F1A<BX`3F5N:'5M82!L;V-A;&EZ8>?C;R!E
M<W!E8VEF:6-A9&$N`$9A;'1A(&EN9&EC87(@=6UA(&QO8V%L:7IAY^-O+@!!
M(&QO8V%L:7IAY^-O(&[C;R!F;VD@97-P96-I9FEC861A+@!.96YH=6UA(&UE
M;G-A9V5M(&9O:2!F;W)N96-I9&$N`$YE;FAU;2!N;VUE(&5S<&5C:69I8V%D
M;RX`3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A9&\N`%-E;2!D:71O<R!O9F5N
M<VEV;W,`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@
M875T96YT:6-AY^-O($A45%`N`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M
M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!)34%0+@!.XV\@9F]I(&9O<FYE
M8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@2V5R8F5R
M;W,N`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U
M=&5N=&EC8>?C;R!,1$%0+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A
M<W-E('!A<F$@82!A=71E;G1I8V'GXV\@3&]G:6XN`$[C;R!F;VD@9F]R;F5C
M:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!005-35T0N
M`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N
M=&EC8>?C;R!334(N`$[C;R!F;VD@:6YD:6-A9&\@8V%M:6YH;R!P87)A(&\@
M8FENX7)I;R!/<&5N4U-,+B!/(&)I;N%R:6\@3W!E;E-33"#I(&YE8V5S<^%R
M:6\@<&%R82!T<F%B86QH87(@8V]M(&1A9&]S(%!+0U,@,3(N`$[C;R!HX2!S
M=6)S8W)IY_5E<R!P96YD96YT97,N`%-E;2!R97!E=&GGXV\`4V5M('1R8>=O
M<P!396T@;&%D;W,`3N-O(&CA('!A<W1A('1E;7!O<N%R:6$@9&ES<&]N[79E
M;"!P87)A(")C86-H92(N`$[C;R!F;W)A;2!E;G9I861O<R!O(&YO;64@9&\@
M=71I;&EZ861O<B!O=2!A('!A;&%V<F$M<&%S<V4N`$[C;R!F;W)A;2!R971O
M<FYA9&]S(&1A9&]S(&5M(%A-3"!VX6QI9&]S`$[C;R!S92!E;F-O;G1R;W4@
M96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!VX6QI9&\`4V5M('9A
M;&]R97,`3N-O(&9O:2!E;F-O;G1R861A('9E<G/C;R!N82!C;VYF:6=U<F'G
MXV\@;W)I9VEN86PN(%)E9V5N97)A<B!C;VYF:6=U<F'GXV\N`$[C;R!F;VD@
M96YC;VYT<F%D82!V97)SXV\@;F$@<W5A(&-O;F9I9W5R8>?C;RX@4F5G96YE
M<F%R(&-O;F9I9W5R8>?C;RX`3F5N:'5M`$YE;FAU;2`H=7-A<B!I;7!L[6-I
M=&\I`$[S<F1I8V\@*$E33RTX.#4Y+3$P*0!);&AA(&1E($YO<F9O;&L`2&5M
M:7-FZ7)I;R!.;W)T90!);&AA<R!-87)I86YA<R!D;R!.;W)T90!296EN;R!D
M82!.;W)U96=A`$YU;F-A($1E<&]I<R!D90!.=6YC82!!;G1E<R!D90!.XV\@
MZ2!U;2!D:7)E8W3S<FEO`$[C;R!E;F-O;G1R861O`$[C;R!I;7!L96UE;G1A
M9&$N`%!O<B!A=')I8G5I<@!.XV\@<W5P;W)T861O+@!.;W1A<P!.861A('!A
M<F$@;F%V96=A<BP@=F]L=&4@<&%R82!T<N%S+@!.;W1A`$YO=&$Z($EM<&]R
M=&%R(&[C;R#I('!O<W/M=F5L(&-O;2!E<W1A(&-O;F9I9W5R8>?C;R!D979I
M9&\@82!U;2!E<G)O(&YO(&UE8V%N:7-M;R!D92!C86QE;F3A<FEO+@!.;W9E
M;6)R;P!!9V]R80!.^FUE<F\`3OIM97)O(&1E(&-A<F%C=&5R97,`3OIM97)O
M(&1E(&-O;'5N87,`3OIM97)O(&1E(&QI;FAA<P!.82!L:7-T82!D92!D:7-T
M<FEB=6GGXV\@:.$@;OIM97)O<R!Q=64@;N-O(&9O<F%M(&5S<&5C:69I8V%D
M;W,@<&%R82!A8W1U86QI>F'GXV\N`$]+`$]B:F5C=&\`0W)I861O<B!D;R!/
M8FIE8W1O`%!E<FUI<W/U97,@9&\@8W)I861O<B!D;R!O8FIE8W1O`$]C=&%L
M`$]U='5B<F\`1FEL=')O(&1E(&UA=&5R:6%L(&]F96YS:79O`$=A8FEN971E
M`%-U;'1A;F%T;R!D;R!/;>,`4_,@;W,@<V5R=FED;W)E<R!)34%0('-U<&]R
M=&%M('!A<W1A<R!P87)T:6QH861A<RX`07!E;F%S(&1I=&]S(&]F96YS:79O
M<P!3\R#I('!E<FUI=&ED;R!U;2!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T
M<O-N:6-O+@!!<&5N87,@;R!D;VYO(&]U('5M(&%D;6EN:7-T<F%D;W(@9&4@
M<VES=&5M87,@<&]D92!A;'1E<F%R(&$@=&ET=6QA<FED861E(&1E('5M82!P
M87)T:6QH82!O=2!A<R!P97)M:7-S]65S(&1O('-E=2!D;VYO`$%B<F4@;G5M
M82!N;W9A(&IA;F5L80!%<G)O($]P96Y34TPZ($[C;R!F;VD@<&]S<^UV96P@
M97AT<F%I<B!D861O<R!D92!U;6$@<&%R=&4@87-S:6YA9&$@8V]M(%,O34E-
M12X`06)R92!E<W1A(&QI9V'GXV\@;G5M82!N;W9A(&IA;F5L80!3:7-T96UA
M($]P97)A=&EV;P!/<&-I;VYA;`!087)T:6-I<&'GXV\@;W!C:6]N86P`3W#G
M]65S`$]PY_5E<R!D;R`E<P!/<.?U97,Z`$QI<W1A($]R9&5N861A`$]R9V%N
M:7IAY^-O`%5N:61A9&4@3W)G86YI>F%C:6]N86P`3W)G86YI>F'GXV\`36]D
M96QO(&]R:6=I;F%L(&1A(&%P;&EC8>?C;P!-;V1E;&]S(&]R:6=I;F%I<R!E
M;2`E<SH`3W5T<F\`3W5T<F%S($EN9F]R;6'G]65S`$1O;F\`4&5R;6ES<_5E
M<R!D;R!$;VYO`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E
M;"X`07-S:6YA='5R82!$:6=I=&%L(%!'4`!$861O<R!E;F-R:7!T861O<R!0
M1U``0VAA=F4@4/IB;&EC82!01U``1&%D;W,@07-S:6YA9&]S+T5N8W)I<'1A
M9&]S(&-O;2!01U``0_-D:6=O(%!(4`!#;VUA;F1O<R!02%``4$T`0VAU=FES
M8V]S('!E;&$@5&%R9&4`06=U86-E:7)O<R!D92!487)D90!.979E(.`@5&%R
M9&4`3F5V]65S(.`@5&%R9&4`4V]L(.`@5&%R9&4`5&5M<&]R86ES+50@X"!4
M87)D90!#;VUA;F1O<R!07TA0`$5N8VAI;65N=&\`4F5P^F)L:6-A($ES;.)M
M:6-A(&1O(%!A<75I<W3C;P!297#Z8FQI8V$@9&4@4&%L874`5&5R<FET\W)I
M;R!086QE<W1I;FEA;F\`1&%T94)O;VL@9&\@4&%L;0!086YA;>$`4&%P=6$@
M3F]V82!'=6ENZ0!297#Z8FQI8V$@9&\@4&%R86=U86D`4&%R8VEA;&UE;G1E
M($5N8V]B97)T;P!086QA=G)A+5!A<W-E`%!A;&%V<F$M4&%S<V4@:6YC;W)R
M96-T80!086QA=G)A+5!A<W-E(&YE8V5S<^%R:6$@<&%R82!A=71E;G1I8V'G
MXV\@4D%$2553`%!A;&%V<F$M4&%S<V4@8V]M(&-O;F9I<FUAY^-O`%!A;&%V
M<F$M4&%S<V4Z`%!A;&%V<F$M4&%S<V4Z(`!!<R!P86QA=G)A<RUP87-S92!T
MZFT@9&4@<V5R(&EG=6%I<RX`3&ES=&$@9&4@179E;G1O<R!087-S861O<P!#
M;VQA<@!#;VQA<B!D92!R96-O<G1E<P!#86UI;FAO`%!A9'+C;P!3=6)S8W)I
MY_5E<R!096YD96YT97,Z`%!E<W-O87,`4&5R8V5N=&%G96T`17AE8W5T87(@
M3W!E<F'G]65S(&1E($UA;G5T96[GXV\`17AE8W5T87(@;W!E<F'G]65S(&1E
M(&UA;G5T96[GXV\@87%U86YD;R!D82!E;G1R861A/P!296UO=F5R(&5V96YT
M;R!P97)M86YE;G1E;65N=&4_`%!E<FUI<W/C;P!!('!E<FUI<W/C;R`B)7,B
M(&[C;R!F;VD@<F5M;W9I9&$N`%!E<FUI<W/C;R!.96=A9&$`4&5R;6ES<_5E
M<P!!9&UI;FES=')AY^-O(&1E(%!E<FUI<W/U97,`4&5R;6ES<_5E<R!D90!)
M;F9O<FUAY_5E<R!097-S;V%I<P!097+Z`$%N:6UA:7,@9&4@17-T:6UAY^-O
M`$9I;&EP:6YA<P!496QE9F]N90!&;W1O9W)A9FEA<P!);&AA<R!0:71C86ER
M;@!0[7AE:7,`4&QA=&ET=61E<P!0;W(@9F%V;W(@8VQI<75E('-O8G)E('5M
M82!CZ6QU;&$`4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E86QM96YT92!P<F5T
M96YD92!R96UO=F5R(&5S=&4@96QE;65N=&\Z`%!O<B!F879O<B!C;VYF:7)M
M92!S92!R96%L;65N=&4@<')E=&5N9&4@9&5S;&EG87(@97-T92!E;&5M96YT
M;RX`4&]R(&9A=F]R(&EN=')O9'5Z82!U;2!MZG,@92!U;2!A;F\N`%!O<B!F
M879O<B!I;G1R;V1U>F$@;R!N;VUE(&1A(&YO=F$@8V%T96=O<FEA.@!0;W(@
M9F%V;W(@:6YT<F]D=7IA('5M(&5N9&5R9>=O($E0(';A;&ED;RX`4&]R(&9A
M=F]R(&EN=')O9'5Z82!U;6$@9&%T82!VX6QI9&$[('9E<FEF:7%U92!O(&[Z
M;65R;R!D92!D:6%S(&1O(&WJ<RX`4&]R(&9A=F]R(&EN=')O9'5Z82!U;6$@
M:&]R82!VX6QI9&$N`%!O<B!F879O<BP@9F]R;F7G82!U;6$@8G)E=F4@9&5S
M8W)IY^-O(&1O('!R;V)L96UA+@!0;W(@9F%V;W(L(&EN=')O9'5Z82!O('-E
M=2!.;VUE(&1E(%5T:6QI>F%D;W(@92!A('-U82!086QA=G)A+5!A<W-E`%!O
M<B!F879O<B!L96EA(&\@=&5X=&\@<V5G=6EN=&4N(%1E;2!D92!#3TY#3U)$
M05(@8V]M(&]S('1E<FUO<R!D97-T92!A8V]R9&\@<&%R82!U<V%R(&\@<VES
M=&5M82X`4&]R(&9A=F]R(')E<&]R=&4@;W,@97)R;W,@<&%R82!I,3AN0&QI
M<W1S+FAO<F1E+F]R9P!0;W(@9F%V;W(@:6YT<F]D=7IA(&\@;F]M92!D82!N
M;W9A(&-A=&5G;W)I83H`4&]L\VYI80!0;VSM=&EC80!3;VYD86=E;G,`3W#G
M]65S(&1O(%!O<G1A;`!297#Z8FQI8V$@4&]R='5G=65S80!0;W-I8VEO;F%M
M96YT;R!D97-T82!I;6%G96T`4&]S:6-I;VYA;65N=&\@9&5S=&$@=&%B96QA
M`%!O<W/M=F5L($AO<F$@9&\@16YC;VYT<F\`4&]S<^UV96ES($AO<F%S(&1E
M($5N8V]N=')O`")0;W-T(B!P87)A(&5S=&$@<&%S=&$@*&[C;R#I(')E<75I
M<VET;R!D;R!)34%0*0!0<F5C:7!I=&'GXV\@;F%S(/IL=&EM87,@)7,@:&]R
M82AS*3H@`%!R;V)A8FEL:61A9&4@9&4\8G(@+SY0<F5C:7!I=&'GXV\`4')E
M9G-?;&1A<#H@02!E>'1E;G/C;R!,1$%0(&YE8V5S<^%R:6$@;N-O(&9O:2!E
M;F-O;G1R861A+@!0<F5F<U]S97-S:6]N.B!!(&5X=&5N<^-O(&1E('-E<W/C
M;R!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`4')E<W/C;P!0<F5S
M<^-O(&%O(&[M=F5L(&1O(&UA<CH@`%!R97-SXV\Z(`!0<F5V:7/C;P!0<F5V
M97(@82!I;6%G96T@;G5M82!N;W9A(&IA;F5L80!$:6$@06YT97)I;W(`4V5M
M86YA($%N=&5R:6]R`$1I82!A;G1E<FEO<@!/<.?U97,@86YT97)I;W)E<P!)
M;7!R:6UI<B!O(&1O8W5M96YT;P!#:&%V92!0<FEV861A`%!R;V)L96UA`$1E
M<V-R:>?C;R!D;R!0<F]B;&5M80!0<F]J96-T;W,`365N<V%G96TM<')O;G1O
M`$-H879E(%#Z8FQI8V$`06QG;W)I=&UO(&1E($-H879E(%#Z8FQI8V$`26YF
M;W)M8>?C;R!3;V)R92!A($-H879E`$\@<&%R(&1E(&-H879E<R!0=6)L:6-A
M+U!R:79A9&$@;N-O(&9O:2!G97)A9&$@8V]M('-U8V5S<V\N`%!O<G1O(%)I
M8V\`17-T861O(&1O(%%A=&%R`%!E9&ED;P!#:&%V92!0^F)L:6-A(%)302`H
M)60@8FET*0!396QE8^?C;R`B<N%D:6\B`$-H=79A`$-H=79A($UA=&EN86P`
M0VAU=F$@5F5S<&5R=&EN80!!9W5A8V5I<F\`0VAU=F$@92!.979E`$-H=79A
M(&$@3F5V90!$:71O($%L96%T\W)I;P!296QAY^-O`$QE<@!,97(@;65N<V%G
M96YS`%%U97(@;65S;6\@<F5M;W9E<B`E<S\@17-T82!O<&5R8>?C;R!NXV\@
M=&5M(')E9W)E<W-O+@!296UO=F5R(&UE<VUO(&]S(&1A9&]S(&1O('5T:6QI
M>F%D;W(@)7,_($5S=&$@;W!E<F'GXV\@;N-O('1E;2!R96=R97-S;RX`4F5P
M971I<B!!=.D`4F5P971IY^-O`$1A9&]S(&1E(%)E<&5T:>?C;P!$871A($9I
M;F%L(&1A(%)E<&5T:>?C;P!);G1E<G9A;&\@9&4@4F5P971IY^-O`%1I<&\@
M9&4@4F5P971IY^-O`%)E<&5T92!D:6%R:6%M96YT90!297!E=&4@;65N<V%L
M;65N=&4`4F5P971E('-E;6%N86QM96YT90!297!E=&4@86YU86QM96YT90!2
M969A>B!A('-U82#Z;'1I;6$@86/GXV\`4F5F<F5S8V%R($5L96UE;G1O<R!D
M92!-96YU($1I;N)M:6-O.@!2969R97-C87(@5FES=6%L:7IAY^-O(&1O(%!O
M<G1A;#H`17AP<F5S<^-O(%)E9W5L87(`3F%V96=A9&]R(&1E(%)E;&'G]65S
M`$]B<V5R=F'G]65S`$QE;6)R971E.B`E<P!#86QE;F3A<FEO<R!296UO=&]S
M`$-A;&5N9.%R:6]S(%)E;6]T;W,Z`%-E<G9I9&]R97,@4F5M;W1O<P!54DP@
M4F5M;W1O("AH='1P.B\O=W=W+F5X96UP;&\N<'0O:&]R9&4I.@!296UO=F5R
M`%)E;6]V97(@)7,`4F5M;W9E<B!087)T:6-I<&%N=&4`4F5M;W9E<B!";&]C
M;P!296UO=F5R(&-O;'5N80!296UO=F5R(&9O<FUA=&'GXV\`4F5M;W9E<B!P
M87(`4F5M;W9E<B!O(")S8W)I<'0B(&=U87)D861O(&1A('!A<W1A('1E;7!O
M<N%R:6$@9&\@<V5R=FED;W(N`%)E;6]V97(@;P!296UO=F5R(&5S=&4@;O,@
M9&\@9&]C=6UE;G1O`%)E;6]V97(@571I;&EZ861O<@!296UO=F5R('5T:6QI
M>F%D;W(Z("5S`$[C;R!F;VD@<&]S<^UV96P@<F5S<&]N9&5R(&%O('!E9&ED
M;RX@0_-D:6=O(&1E(&5R<F\@9&5V;VQV:61O.B``3R!S97)V:>=O('!E9&ED
M;R!NXV\@9F]I(&5N8V]N=')A9&$N`$EN9&ES<&5N<^%V96P`(B5S(B!O8G)I
M9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@
M9&4@)7,N`"(E<R(@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@
M;F$@8V]N9FEG=7)AY^-O(%9&4RX`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I
M(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\N`%!A<G1I8VEP86YT97,@
M26YD:7-P96YSX79E:7,`0V%M<&\@3V)R:6=A=/-R:6\`26YD:7-P96YSX79E
M;"!P87)T:6-I<&%R`$QI;7!A<@!296EN:6-I87(@4&%L879R82U087-S90!2
M96EN:6-I92!A(%-U82!086QA=G)A+5!A<W-E`%)E<&]R(%9A;&]R97,@<&]R
M($]M:7-SXV\`4F5S<&]S=&$`4F5S=6QT861O<P!297-U;'1A9&]S("AI;F-L
M=6EN9&\@2&]R9&4I.@!297-U;'1A9&]S.@!6;VQT87(@X',@3W#G]65S`%)E
M=6YIXV\`4D5V97)T97(@0V]N9FEG=7)AY^-O`$]PY_5E<R!D92!%9&GGXV\@
M4FEC80!!9&EV:6YH87,`1&ER96ET80!#86)EYV%L:&\@9&$@9&ER96ET80!6
M86QO<F5S(.`@9&ER96ET80!0<F]P<FEE9&%D97,@9&$@3&EN7VAA+BXN`%)E
M9W)A`%)O;>EN:6$`4F]D87(@,3@P`%)O9&%R(.`@17-Q=65R9&$`4F]D87(@
MX"!D:7)E:71A`%!R;W!R:65D861E<R!D82!,:6YH80!0<F]P<FEE9&%D97,@
M9&$@;&EN:&$`3&EN:&%S.@!4<F'G;W,`5')AYV]S(&%P87)E8V5RXV\@96YT
M<F4@=&]D87,@87,@;&EN:&%S(&4@8V]L=6YA<P!4<F'G;W,@87!A<F5C97+C
M;R!A<&5N87,@96YT<F4@87,@8V]L=6YA<P!4<F'G;W,@87!A<F5C97+C;R!A
M<&5N87,@96YT<F4@;&EN:&%S`$5X96-U=&%R`$9E9&5R8>?C;R!2=7-S80!2
M97#Z8FQI8V$@9&\@4G5A;F1A`$%S<VEN871U<F$@0W)I<'1O9W+A9FEC82!3
M+TU)344`365N<V%G96T@16YC<FEP=&%D82!C;VT@4R]-24U%`$%U=&5N=&EC
M8>?C;R!305-,(&EN9&ES<&]N[79E;"X`365N<V%G96YS(%--4P!#;VUA;F1O
M<R!344P`4U-(`%-50T534T\`0V]M86YD;W,@4U]13`!'<F%V87(@(B5S(B!#
M;VUO($YO=F\`<^%B`%-A;G1A($AE;&5N80!3XV\@2VET=',@92!.979I<P!3
M86YT82!,^F-I80!3XV\@4&5D<F\@92!-:7%U96QO;@!3XV\@5FEC96YT92!E
M($=R96YA9&EN97,`365S;6$@;6]L9'5R82`H7W-E;&8I`$5S=&%D;R!);F1E
M<&5N9&5N=&4@9&$@4V%M;V$`4F5P^F)L:6-A(%-E<F5N[7-S:6UA(&1E(%/C
M;R!-87)I;F\`4^-O(%1O;>D@92!0<NUN8VEP90!&;W)N96-E9&]R(&1O(%-A
M=.EL:71E`'/A8F%D;P!!<N%B:6$@4V%U9&ET80!'=6%R9&%R`$=U87)D87(@
M)7,`1W5A<F1A<B`G)7,G`$=R879A<B!#;VUO($YO=F\`1W5A<F1A<B!%=F5N
M=&\`1W5A<F1A<B!/<.?U97,`1W5A<F1A<B!C;VYF:6=U<F'GXV\@9V5R861A
M(&-O;6\@=6T@(G-C<FEP="(@4$A0(&YO(&1I<F5C=/-R:6\@=&5M<&]RX7)I
M;R!D;R!S974@<V5R=FED;W(N`$=U87)D96D@8V]N9FEG=7)AY^-O("5S+@!'
M=6%R9&5I(&\@(G-C<FEP="(@9&4@86-T=6%L:7IAY^-O(&5M.B`B)7,B+@!4
M96UP;W)A:7,M5"!$:7-P97)S;W,`0VGJ;F-I80!0<F]C=7)A<@!-;W1O<F5S
M(&1E(%!R;V-U<F$`4F5S=6QT861O<R!D82!0<F]C=7)A`%!R;V-U<F%N9&\@
M87!L:6-AY_5E<R`H;?-D=6QO<RD@2&]R9&4@96T@)7,`4')O8W5R86YD;R!O
M<R!B:6[A<FEO<R!D92!G971T97AT+BXN`%-E;&5C8VEO;F%R($%R<75I=F]S
M`%-E;&5C8VEO;F4@=6T@8V%L96YDX7)I;P!396QE8V-I;VYE('5M82!D871A
M`%-E;&5C8VEO;F4@=6T@9W)U<&\@82!A8W)E<V-E;G1A<@!396QE8V-I;VYA
M<B!U;2!N;W9O(&1O;F\`4V5L96-C:6]N92!U;2!S97)V:61O<@!396QE8V-I
M;VYE('5M('5T:6QI>F%D;W(@82!A9&EC:6]N87(`4V5L96-C:6]N92!T;V1O
M<R!O<R!C;VUP;VYE;G1E<R!D82!D871A+@!396QE8V-I;VYE('5M(&]B:F5C
M=&\`4V5L96-C:6]N92!O<.?U97,@9&4@8V]N9FER;6'GXV\L(&-O;6\@;6]S
M=')A<B!A<R!D:69E<F5N=&%S('9I<W1A<R!E('%U86P@82!V:7-T82!P;W(@
M;VUI<W/C;RX`4V5L96-I;VYE(&\@8V%L96YDX7)I;R!P87)A(&\@<75A;"!I
M;7!O<G1A<CH`4V5L96-C:6]N92!O<R!C87)A8W1E<F5S(&YA<R!C86EX87,@
M86)A:7AO+B!0;V1E<N$@96YTXV\@8V]P:>$M;&]S(&4@8V]LX2UL;W,@;F$@
MX7)E82!D92!T97AT;RX`4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A(&1A
M=&$Z`%-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&1A=&$Z`%-E;&5C8VEO;F4@
M;R!F;W)M871O(&1E(&5X<&]R=&'GXV\Z`%-E;&5C:6]N92!O(&%R<75I=F\@
M82!I;7!O<G1A<CH`4V5L96-I;VYE(&\@<')I;65I<F\@9&EA(&1A('-E;6%N
M83H`4V5L96-C:6]N92!O(&9O<FUA=&\@9&\@9FEC:&5I<F\@9F]N=&4Z`%-E
M;&5C8VEO;F4@82!I9&5N=&ED861E('%U92!P<F5T96YD92!A;'1E<F%R.@!3
M96QE8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&%S(&AO<F%S.@!396QE8V-I;VYE
M(&\@9F]R;6%T;R!D82!H;W)A.@!396QE8VEO;F4@82!G86UA('1E;7!O<F%L
M(&$@;6]S=')A<CH`4V5L96-I;VYE(&$@=FES=&$@82!M;W-T87(@87#S<R!A
M(&5N=')A9&$Z`%-E;&5C8VEO;F4@9&]I<R!C86UP;W,@<F5L86-I;VYA9&]S
M+@!396QE8VEO;F4@<75E(&5V96YT;W,@;6]S=')A<B!N;R!P;W)T86PN`$5S
M8V]L:&$@;R!S974@8V]N:G5N=&\@9&4@8V]R97,N`%-E;&5C8VEO;F4@;R!S
M974@:61I;VUA('!R969E<FED;SH`16YV:6%R(%)E;&%T\W)I;R!D92!0<F]B
M;&5M87,`16YV:6%R(%--4P!%;G9I87(@=6UA(&YO=&EF:6-AY^-O(&1E(&-A
M;F-E;&%M96YT;R!A('1O9&]S(&]S('!A<G1I8VEP86YT97,@<75A;F1O('-E
M(')E;6]V97(@97-T92!E=F5N=&\`16YV:6%R('5M82!M96YS86=E;2!P87)A
M("5S`$5N=FEA<B!A8W1U86QI>F'G]65S+V-O;G9I=&5S(&$@=&]D;W,@;W,@
M<&%R=&EC:7!A;G1E<R!Q=6%N9&\@97-T92!E=F5N=&\@9F]R(&=U87)D861O
M`%)E</IB;&EC82!D;R!396YE9V%L`"!396YS;W(Z(`!3971E;6)R;P!3Z7)V
M:6$@92!-;VYT96YE9W)O`$[Z;65R;R!D92!3Z7)I90!$861O<R!D;R!S97)V
M:61O<B!E<G)A9&]S(&]U(&EN9&ES<&]N[79E:7,N`$E$(&1E('-E<W/C;R!E
M>'!I<F]U+@!!=')I8G5I<@!!=')I8G5I<B!D871A(&9I;F%L`$5S=&%B96QE
MYV$@;W#G]65S('%U92!L:&4@<&5R;6ET86T@<F5I;FEC:6%R(&$@<W5A('!A
M;&%V<F$M<&%S<V4@<V4@86QG=6UA('9E>B!D96QA('-E(&5S<75E8V5R+@!%
M<W!E8VEF:6-A<B!D871A(&9I;F%L(&1A(')E<&5T:>?C;P!%<W!E8VEF:6-A
M<B!D871A(&EN:6-I86P`17-P96-I9FEC87(@<V5R=FED;W)E<R!R96UO=&]S
M('%U92!D97-E:F$@86-E9&5R(&YO('-E=2!P;W)T86PN`$1E9FEN82!A<R!O
M<.?U97,@9&4@;&EV<F4O;V-U<&%D;R!P87)A('-I(&4@<&%R82!O<R!O=71R
M;W,N`%-E;&5C8VEO;F4@;R!S974@:61I;VUA('!R969E<FED;RP@;R!S974@
M9G5S;R!H;W+A<FEO(&4@87,@<W5A<R!O<.?U97,@9&4@9&%T87,N`$5S8V]L
M:&$@82!S=6$@87!L:6-AY^-O(&EN:6-I86PL(&\@97-Q=65M82!D92!C;W)E
M<RP@;R!R969R97-C86UE;G1O(&1E('#A9VEN87,@92!O=71R87,@;W#G]65S
M(&1E('9I<W5A;&EZ8>?C;RX`0V]N9FEG=7)A<@`B4V-R:7!T<R(@9&4@86-T
M=6%L:7IAY^-O(&1I<W!O;NUV96ES`%;A<FEA<R!L;V-A;&EZ8>?U97,@<&]S
M<^UV96ES(&-O;2!O('!A<N)M971R;SH@`%-E:6-H96QE<P!087)T:6QH82!N
MXV\@96YC;VYT<F%D83H@)7,`0V%L96YDX7)I;R!087)T:6QH861O<SH`0V]M
M<')A<P!"<F5V92!3=6WA<FEO`$1E=F5M+7-E(&1E9FEN:7(@=&5C;&%S(&1E
M(&%C97-S;R!P87)A(&$@;6%I;W)I82!D87,@;&EG8>?U97,_`$UO<W1R87(`
M36]S=')A<B!#86QE;F3A<FEO`$UO<W1R87(@;&5G96YD82!D92!C871E9V]R
M:6%S/P!-;W-T<F%R(.UC;VYE<R!D92!R96UOY^-O+"!A=FES;R!E(')E<&5T
M:>?C;R!N87,@=FES=&%S(&1O(&-A;&5N9.%R:6\_`$UO<W1R87(@9&EF97)E
M;N=A<R!E;G1R92!A(&-O;F9I9W5R8>?C;R!G=6%R9&%D82!E(&%Q=64@9F]I
M(&%G;W)A(&=E<F%D82X`36]S=')A<B!T87)E9F%S(&-O;2!P<F%Z;R!E>&-E
M9&ED;R!N;R!C86QE;F3A<FEO/P!-;W-T<F%R(&QE9V5N9&$@;&EV<F4O;V-U
M<&%D;S\`36]S=')A<B!I;G1E<G9A;&]S(&1E(&UE:6$@:&]R82!N87,@=FES
M=&%S(&1E(&1I82!E('-E;6%N83\`36]S=')A<B!M;VUE;G1O(&1A(/IL=&EM
M82!E;G1R861A(&YO('-I<W1E;6$_`$UO<W1R87(@<V]M96YT92!E=F5N=&]S
M(&-O;2!A=FES;R!C;VYF:6=U<F%D;S\`36]S=')A<B!O<.?C;R!P87)A('!R
M97-E<G9A<B!O(&]R:6=I;F%L`$UO<W1R87(@<&%L971E`$UO<W1R87(@8V%L
M96YDX7)I;W,@<&%R=&EL:&%D;W,@;&%D;R!A(&QA9&\_`$UO<W1R87(@82!B
M87)R82!D92!M96YU(&-O;2!A<R!O<&5R8>?U97,@<V]B<F4@=&%B96QA<S\`
M36]S=')A<B!T87)E9F%S('5S86YD;R!C;W)E<R!D92!C871E9V]R:6%S/P!-
M;W-T<F%R(&\@365N=2`E<R#@(&5S<75E<F1A/P!-;W-T<F%R(&$@8V%I>&$@
M9&4@9&GA;&]G;R!D87,@4')O<')I961A9&5S(&1E($/I;'5L87,@9&4@5&%B
M96QA/P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I961A
M9&5S(&1E(%1A8F5L87,`36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S
M(%!R;W!R:65D861E<R!D92!,:6YH87,@9&4@5&%B96QA`$UO<W1R87(@82!C
M86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@26UA9V5M`$UO
M<W1R87(@:&]R82!D;R!D:6$@96YT<F4@8V%D82!D:6$@;F%S('9I<W1A<R!D
M92!S96UA;F$_`$UO<W1R87(@8V%R<F5G86UE;G1O`$%G=6%C96ER;W,`06=U
M86-E:7)O<R!-871I;F%I<P!!9W5A8V5I<F]S(%9E<W!E<G1I;F]S`$%G=6%C
M96ER;W,@;F$@5FEZ:6YH86[G80!%;F-O;&AE<@!%;F-O;&AA(&]U(&UO=F$@
M;RAS*2!B;&]C;RAS*2!V:7II;FAO*',I('!R:6UE:7)O`%-E<G)A($QEXV\`
M4W5B<V-R979E<@!3=6)S8W)E=F$L('-E(&%I;F1A(&[C;R!E<W3A(')E9VES
M=&%D;P!!<W-I;F%T=7)A`$%L9V]R:71M;R!D92!!<W-I;F%T=7)A`%)E</IB
M;&EC82!D92!3:6YG87!U<F$`5&%M86YH;P!386QT87(@36%N=71E;N?C;P!.
MXV\@<')O8V5S<V%D;RXN+@!%<VQO=N%Q=6EA`%)E</IB;&EC82!D82!%<VQO
M=NEN:6$`3F5V90!.97;C;P!.97;U97,`3F5V]65S($UA=&EN86ES`$YE=O5E
M<R!697-P97)T:6YO<P!!;'1U<F$@9&4@;F5V93H@`$UO<W1R87(@97%U:79A
M;&5N=&4@;F$@X6=U83H@`$EL:&%S(%-A;&]MXV\`4V]MX6QI80!#86[G]65S
M(&4@4&]E;6%S`%-E;&5CY^-O(&1O('-E;G1I9&\@9&$@;W)D96YAY^-O`$5N
M9&5R9>=O(&1E(&]R:6=E;0#!9G)I8V$@9&\@4W5L`$5U<F]P82!D;R!3=6P@
M*$E33RTX.#4Y+3,I`$=E\W)G:6$@9&\@4W5L(&4@26QH87,@4V%N9'=I8V@@
M9&\@4W5L`$AE;6ES9NER:6\@4W5L`$5S<&'G;R!E;G1R92!CZ6QU;&%S(&%D
M:F%C96YT97,`17-P8>=O(&5N=')E(&\@8V]N=&7Z9&\@92!A(&)O<F1A(&1E
M('5M82!CZ6QU;&$`17-P8>=A9&]R`$5S<&'G86UE;G1O`$5S<&'G86UE;G1O
M(&4@96YC:&EM96YT;P!296EN;R!D92!%<W!A;FAA`$-O<G)E:6\@;N-O('-O
M;&EC:71A9&\`26YS97)I<B!#87)A8W1E<B!%<W!E8VEA;`!$:79I9&ER(&/I
M;'5L80!!9&EC:6]N87(@8V]L=6YA`$1I=FED:7(@;&EN:&$`1&5S<&]R=&]S
M`%)E</IB;&EC82!$96UO8W+A=&EC82!3;V-I86QI<W1A(&1O(%-R:2!,86YK
M80!);FE?8VEA+7-E($5M`%!A9'+C;P!3=&%R(%1R96L`1&%T82!);FEC:6%L
M`$EN:6-I82US92!%;0!(;W)A($EN:6-I86P`06YO(&1E(&EN[6-I;P!%<W1A
M7V1O`$5S=&%D;R!O=2!0<F]V[6YC:6$`17-T861O`$5S=&%D;R!D82!L;V-A
M;&EZ8>?C;R`E<RXN+B``1F]R;6%T;R!D92!A<FUA>F5N86UE;G1O`$5N9&5R
M9>=O(&1E(%)U80!287-U<F%D;P!,:7-T82!D92!C861E:6%S(&1E(&-A<F%C
M=&5R97,`4F5T:7)A<B!D;VWM;FEO(&1O(&5N9&5R9>=O`$5S=&EL;R!;0U-3
M70!D;VT`07-S=6YT;P!3=6)M971E<@!&;VD@<W5B;65T:61O('!E9&ED;R!P
M87)A(&%D:6-I;VYA<B`B)7,B(&%O('-I<W1E;6$N($[C;R!P;V1E<N$@96YT
M<F%R(&5N<75A;G1O(&\@<V5U('!E9&ED;R!NXV\@9F]R(&%P<F]V861O+@!)
M;F9E<FEO<B#@(&QI;FAA`%-U8V5S<V\`(B5S(B!A9&EC:6]N861O(&-O;2!S
M=6-E<W-O(&%O('-I<W1E;6$N`$QI;7!E>F$@9&\@<VES=&5M82!D;W,@9&%D
M;W,@9&\@=71I;&EZ861O<B`B)7,B(')E86QI>F%D82!C;VT@<W5C97-S;RX`
M4F5M;^?C;R!D92`B)7,B(&-O;2!S=6-E<W-O+@!296UOY^-O(&1E("(E<R(@
M9&\@<VES=&5M82!C;VT@<W5C97-S;RX`0V]N9FEG=7)AY^-O(')E=F5R=&ED
M82!C;VT@<W5C97-S;RX@4F5C87)R96=U92!P87)A('9E<B!A<R!M=61A;N=A
M<RX`0V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A(&=U87)D861A(&-O;2!S
M=6-E<W-O+@!&:6-H96ER;R!D92!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R
M9&$@)7,@9W5A<F1A9&\@8V]M('-U8V5S<V\N`"(E<R(@86-T=6%L:7IA9&\@
M8V]M('-U8V5S<V\`)7,@97-C<FET;R!C;VT@<W5C97-S;P!297#Z8FQI8V$@
M9&\@4W5DXV\`4F5S=6UO`$YA<V-E<B!D;R!3;VP`4/1R(&1O(%-O;`!D;VUI
M;F=O`%-O;&%R96YG;P!.87-C97(@9&\@4V]L`$YA<V-E<B]0]'(@9&\@4V]L
M`$YA<V-E<B!D;R!3;VPZ(`!0]'(@9&\@4V]L`%#T<B!D;R!3;VPZ(`!3=7!E
M<FEO<B#@(&QI;FAA`%-U<&]R=&4`4W5R:6YA;64`07!E;&ED;P!3=F%L8F%R
M9"!E($IA;B!-87EE;@!296EN;R!D82!3=6%Z:6SB;F1I80!296EN;R!D82!3
M=>EC:6$`4W7MYV$`17)R;R!D92!S:6YT87AE(&YO<R!T97)M;W,@9&4@<')O
M8W5R80!297#Z8FQI8V$@P7)A8F4@4^UR:6$`5&5M<&]R86PM5`!496UP;W)A
M;"U4(&4@5F5N=&]S;P!496UP;W)A:7,M5`!496UP;W)A:7,M5"!-871I;F%I
M<P!!<G%U:79O(%135@!486)E;&$`4')O<')I961A9&5S(&1A(%1A8F5L80!0
M<F]P<FEE9&%D97,@9&$@=&%B96QA`$9O<FUO<V$`1F]R;6]S80!297#Z8FQI
M8V$@9&\@5&%D:FEQ=6ES=.-O`%1A;GKB;FEA`$%L=F\Z`%1A<F5F87,`3OIM
M97)O(&1E(%1E;&5F;VYE`%1E;7!E<F%T=7)A(&1A(/IL=&EM82!H;W)A.@!4
M96UP97)A='5R80!496UP97)A='5R83H@`%1E;7!E<F%T=7)A/&)R("\^*"5S
M06QT825S+R5S0F%I>&$E<RD@)F1E9SLE<P!/(&UO9&5L;R`B)7,B(&[C;R!F
M;VD@96YC;VYT<F%D;RX`061M:6YI<W1R8>?C;R!D92!-;V1E;&]S`%1E;G1A
M=&EV80!497AT;P!!<&5N87,@5&5X=&\`06QI;FAA;65N=&\@9&\@=&5X=&\`
M5&]P;R!D;R!T97AT;P`U+JH`5&%I;&%N9.IS("A425,M-C(P*0!296EN;R!D
M82!486ELXFYD:6$`3V)R:6=A9&\@<&]R('5S87(@97-T92!S:7-T96UA+@!/
M(&%R<75I=F\@9&4@86IU9&$@)7,@<&%R82`E<R!NXV\@97AI<W1E(&%I;F1A
M+B!#<FEA;F1O('5M(&YO=F\N`$\@96-RXR!%9&GGXV\@9&4@4&%R=&EC:7!A
M;G1E<R!JX2!NXV\@97-TX2!P<F5S96YT92X@4V%I;F1O+@!!(&5X=&5N<^-O
M($944"!NXV\@97-TX2!D:7-P;V[M=F5L+@!/(&5N9V5N:&\@9&4@:6YT96=R
M8>?C;R!(;W)D92]+;VQA8B!NXV\@<W5P;W)T82`B)7,B`$\@<F5G:7-T;R`H
M(FQO9R(I($E-4U`@;N-O('#T9&4@<V5R(&EN:6-I86QI>F%D;RX`02!C;&%S
M<V4@36%I;G1E;F%N8V4Z.B!NXV\@9F]I(&-A<G)E9V%D82!C;VT@<W5C97-S
M;P!!(&IA;F5L82!D92!/<.?U97,@9F5C:&]U+B!38>UN9&\N`$\@861M:6YI
M<W1R861O<B!T96T@9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@9&4@<&5R
M;6ES<_5E<R!P97)M86YE;G1E('-E('%U:7-E<B!U<V%R(%!E<FUI<W/U97,N
M`$%P96YA<R!O(&QA9&\@:6YF97)I;W(`3R!C86QE;F3A<FEO("(E<R(@;N-O
M('#T9&4@<V5R(')E;6]V:61O+@!/(&-A;&5N9.%R:6\@(B5S(B!F;VD@8W)I
M861O+@!/(&-A;&5N9.%R:6\@(B5S(B!F;VD@<F5M;W9I9&\N`$\@8V%L96YD
MX7)I;R`B)7,B(&9O:2!R96YO;65A9&\@8V]M;R`B)7,B+@!/(&-A;&5N9.%R
M:6\@(B5S(B!F;VD@9W5A<F1A9&\N`$\@;OIM97)O(&1E($E$(&1O(&-O;G1A
M8W1O(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E;2!B<F%N
M8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@9&%D;W,N`$\@
M8V]N=&%C=&\@9F]I(&%D:6-I;VYA9&\@X"!L:7-T82!D92!C;VYT86-T;W,@
M8V]M('-U8V5S<V\N`$\@8FQO8V\@9&4@87-S:6YA='5R82!01U`@9&5S=&%C
M861O(.D@;F5C97-SX7)I;R!P87)A('9E<FEF:6-A<B!U;6$@;65N<V%G96T@
M87-S:6YA9&$N`$\@240@9&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F
M;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O
M(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@9&%D;W,N`$$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861A+@!!<R!F=6YC:6]N
M86QI9&%D97,@9&4@96YC<FEP=&'GXV\@97AI9V5M('5M82!L:6=AY^-O('-E
M9W5R82X`02!D871A(&9I;F%L(&1E=F4@<V5R(&UA:6]R('%U92!A(&1A=&$@
M:6YI8VEA;"X`02!N;W1I9FEC8>?C;R!D92!E=F5N=&\@<&%R82`E<R!F;VD@
M96YV:6%D82!C;VT@<W5C97-S;RX`3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N
M=&5R('5M(&%T<FEB=71O("5S+@!/(&%R<75I=F\@)7,@9&5V97)I82!C;VYT
M97(@86QG=6YS(&%T<FEB=71O<R`E<RX`3R!F:6-H96ER;R!NXV\@<&]D92!S
M97(@8V]P:6%D;R!P87)A('-I('!R\W!R:6\N`$\@9FEC:&5I<F\@;N-O(&-O
M;G3I;2!D861O<RX`06)A:7AO(&5S=.-O(&]S(&-A8F7G86QH;W,@9&5S=&$@
M;65N<V%G96TO;65N<V%G96T@<F9C.#(R+@!396=U92US92!U;6$@9&5S8W)I
MY^-O(&UA:7,@<&]R;65N;W)I>F%D82!D;R!E=F5N=&\Z`$\@;6]D;R!D92!E
M8W+C(&EN=&5I<F\@8V%U<V$@<')O8FQE;6%S(&YO($EN=&5R;F5T($5X<&QO
M<F5R+"!D979I9&\@82!E<G)O<R!N;R!N879E9V%D;W(@<75E(&[C;R!C;VYS
M96=U:6UO<R!U;'1R87!A<W-A<BX@(%!O9&4@<W5R9VER(&QI>&\L('!O9&5M
M(&1E<V%P87)E8V5R(&9U;F-I;VYA;&ED861E<R!D;R!E9&ET;W(@92]O=2!O
M('-E=2!N879E9V%D;W(@<&]D92!A8F]R=&%R+B!392!O('-E=2!S:7-T96UA
M(.D@=6T@5VEN9&]W<R`Y>"P@Z2!M=6ET;R!P<F]VX79E;"!Q=64@;V)T96YH
M82!U;2`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!E('!R96-I<V4@9&4@
M<F5I;FEC:6%R(&\@<VES=&5M82Y<;EQN1F]I(&%V:7-A9&\N("!0;W(@9F%V
M;W(@<')E<W-I;VYE($]+('-E(&%I;F1A(&%S<VEM('%U:7-E<B!E>'!E<FEM
M96YT87(@;R!E9&ET;W(@9&4@96-RXR!I;G1E:7)O+@!/(&9I8VAE:7)O(&1E
M(&%J=61A("5S(&[C;R!C;VUEYV$@8V]M(#P_>&UL`$$@:61E;G1I9&%D92`B
M)7,B(&9O:2!R96UO=FED82X`07!E;F%S(&\@;&%D;R!E<W%U97)D;P!!(&QO
M8V%L:7IAY^-O(&1O(&%R<75I=F\@97AE8W5TX79E;"!D92!';G501R!T96T@
M9&4@<V5R(&EN9&EC861A(.`@8VQA<W-E($-R>7!T7W!G<#HZ+@!!(&UE;G-A
M9V5M(&5N=FEA9&$@96T@)7,@<&%R82`E<R!C;VT@87-S=6YT;R`B)7,B(&9O
M:2!M;W-T<F%D82X*3N-O(&CA(&=A<F%N=&EA(&1E('%U92!A(&UE;G-A9V5M
M('1E;FAA('-I9&\@<F5A;&UE;G1E(&QI9&$@;W4@8V]M<')E96YD:61A+@!/
M(&YO;64@82!U<V%R('%U86YD;R!L:6=A;F1O(.`@<.%G:6YA(&1E(&-O;7!O
M<VGGXV\`3R!M\V1U;&\@;W!E;G-S;"#I(&YE8V5S<^%R:6\@<&%R82!A(&-L
M87-S92!(;W)D95]#<GEP=%]S;6EM93HZ+@!!(&]PY^-O("(E<R(@;N-O('#T
M9&4@<V5R(&=U87)D861A+"!P;VES(&]S('-E=7,@9&%D;W,@97AC961E;2!A
M(&1I;65N<^-O(&WA>&EM82!P97)M:71I9&$`3R!P<F]G<F%M82!U<V%D;R!P
M87)A('9E<B!E<W1E('1I<&\@9&4@9&%D;W,@*"5S*2!NXV\@9F]I(&5N8V]N
M=')A9&\@;F\@<VES=&5M82X`07!E;F%S(&]S(&QA9&]S(&5S<75E<F1O(&4@
M9&ER96ET;P!!<&5N87,@;R!L861O(&1I<F5I=&\`3R!S97)V:61O<B`B)7,B
M(&9O:2!R96UO=FED;RX`3R!S97)V:61O<B`B)7,B(&9O:2!G=6%R9&%D;RX`
M3R!P961I9&\@9&4@<W5B<V-R:>?C;R!D92`E<R!F;VD@<F5M;W9I9&\N`$$@
M;&EN:&$@:6YD:6-A9&$@;N-O(&5X:7-T92X`3R!A<G%U:79O('1E;7!O<N%R
M:6\@(B5S(B!NXV\@97AI<W1E+@!!<&5N87,@;W,@;&%D;W,@<W5P97)I;W(@
M92!I;F9E<FEO<@!!<&5N87,@;R!L861O('-U<&5R:6]R`$]S(&1A9&]S(&-A
M<G)E9V%D;W,@<&5R9&5R86TM<V4@9&5S9&4@;R!P87-S;R!A;G1E<FEO<BX`
M3R!A<G%U:79O(&-A<G)E9V%D;R!NXV\@</1D92!S97(@9W5A<F1A9&\N`$\@
M8FQO8V\@=V5A=&AE<BYC;VT@;N-O(&5S=.$@9&ES<&]N[79E;"X`3F5N:'5M
M(&5V96YT;R!D92!A8V]R9&\@8V]M(&\@8W)I=.ER:6\@8V]R<F5N=&4N`$[C
M;R!HX2!O<.?U97,@9&ES<&]N[79E:7,N`$[C;R!HX2!P87)T97,@<75E('!O
M<W-A;2!S97(@;6]S=')A9&%S(&5M(&QI;FAA+@!(X2!D96UA<VEA9&]S(&-A
M<F%C=&5R97,@;F5S=&4@8V%M<&\N($EN=')O9'5Z:74@)7,@8V%R86-T97)E
M<SL@=&5M(&1E(&EN=')O9'5Z:7(@;65N;W,@9&\@<75E("5S+@!.XV\@97AI
M<W1E(&%I;F1A('5M(&%R<75I=F\@9&4@86IU9&$@<&%R82`E<RX`3V-O<G)E
M=2!U;2!P<F]B;&5M82!N82!A9&GGXV\@9&4@(B5S(B!A;R!S:7-T96UA.B`E
M<P!/8V]R<F5U('5M('!R;V)L96UA(&%O(&QI;7!A<B!O<R!D861O<R!D;R!U
M=&EL:7IA9&]R("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B;&5M
M82!N82!R96UOY^-O(&1E("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P
M<F]B;&5M82!A;R!A8W1U86QI>F%R("(E<R(Z("5S+@!(;W5V92!U;2!P<F]B
M;&5M82!C;VT@;R!C87)R96=A;65N=&\@9&\@9FEC:&5I<F\Z("5S(&[C;R!F
M;VD@8V%R<F5G861O+@!/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A<G)E
M9V%M96YT;R!D;R!A<G%U:79O.B!/("5S(&5X8V5D92!O('1A;6%N:&\@;>%X
M:6UO('!E<FUI=&ED;R`H)60@8GET97,I+@!/8V]R<F5U('5M('!R;V)L96UA
M(&-O;2!O(&-A<G)E9V%M96YT;R!D;R!A<G%U:79O.B!/("5S(&9O:2!A<&5N
M87,@<&%R8VEA;&UE;G1E(&-A<G)E9V%D;RX`3V-O<G)E=2!U;2!E<G)O(&%O
M(&%C961E<B!A;R!C86QE;F3A<FEO.B`E<P!/8V]R<F5U('5M(&5R<F\@86\@
M861I8VEO;F%R(&\@979E;G1O.B`E<P!/8V]R<F5U('5M(&5R<F\@86\@;6]S
M=')A<B!E<W1A('!A<G1E(&1A(&UE;G-A9V5M`$]C;W)R974@=6T@97)R;R!A
M;R!E9&ET87(@;R!E=F5N=&\Z("5S`$]C;W)R974@=6T@97)R;R!A;R!I;7!O
M<G1A<B!D861O<R!D92!C;VYT86-T;RX`3V-O<G)E=2!U;2!E<G)O(&%O(&EM
M<&]R=&%R(&1A9&]S(&E#86QE;F1A<BX`3V-O<G)E=2!U;2!E<G)O(&YO(&9O
M<FUU;.%R:6\@9&4@8V]N9FEG=7)AY^-O+B!486QV97H@=&5N:&$@;VUI=&ED
M;R!U;2!C86UP;R!O8G)I9V%T\W)I;RX`3V-O<G)E=2!U;2!E<G)O(&%O(&UO
M=F5R(&\@979E;G1O.B`E<P!/8V]R<F5U('5M(&5R<F\@86\@86)R:7(@;R!A
M<G%U:79O("5S+B!%>'!E<FEM96YT92!E>&5C=71A<B!T<F%N<VQA=&EO;BYP
M:'`@8V]M(&$@;W#GXV\@+60@<&%R82!C;VYS96=U:7(@=F5R(&%S(&UE;G-A
M9V5N<R!D92!E<G)O(&1O(&%N86QI<V%D;W(@6$U,+@!/8V]R<F5U('5M(&5R
M<F\@86\@<F5A;&EZ87(@82!F=6[GXV\@9&4@;&EV<F\@9&4@96YD97)EYV]S
M(&5S<&5C:69I8V%D82X@4&]R(&9A=F]R('1E;G1E(&1E(&YO=F\@;6%I<R!T
M87)D92X`3V-O<G)E=2!U;2!E<G)O(&%O(&5N=FEA<B!U;6$@;F]T:69I8V'G
MXV\@9&\@979E;G1O('!A<F$@)7,Z("5S`$]C;W)R974@=6T@97)R;R!A;R!A
M8W1U86QI>F%R(&]S('!O<FUE;F]R97,@9&\@8V]N=&%C=&\N(%!O<B!F879O
M<B!T96YT92!D92!N;W9O(&UA:7,@=&%R9&4N`$]C;W)R974@=6T@97)R;R!A
M;R!A8W1U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B!0;W(@9F%V
M;W(@=&5N=&4@9&4@;F]V;R!M86ES('1A<F1E+@!.XV\@:.$@979E;G1O<R!P
M87)A(&5X<&]R=&%R+@!%<W1E('-E<G9I9&]R($E-05`@;N-O('-U<&]R=&$@
M<&%R=&EL:&$@9&4@<&%S=&%S+@!.XV\@<&%R96-E('-E<B!U;2!A<G%U:79O
M(')A<B!VX6QI9&\N`$[C;R!P87)E8V4@<V5R('5M(&%R<75I=F\@>FEP(';A
M;&ED;RX`3N-O('!A<F5C92!S97(@=6UA(&[Z;65R;R!D92!C87)TXV\@=N%L
M:61O+@!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS
M86=E;G,@871R87;I<R!D;R!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L
M;"YC;VTI+"!U<V%N9&\@82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E
M<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@871R87;I<R!D;R!S;7,R;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!U<V%N9&\@82!!4$D@2%144`!%
M<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@
M=FEA(%--5%`@871R87;I<R!D82!6;V1A9F]N92!)=.%L:6$@92!A<&5N87,@
M<&%R82!N^FUE<F]S(%9O9&%F;VYE+B!%>&EG92!U;6$@8V]N=&$@9&4@8V]R
M<F5I;R!E;&5C='+S;FEC;R!N82!6;V1A9F]N92!)=.%L:6$@*&AT='`Z+R]W
M=W<N,3DP+FET*2X`17-T92!C86UP;R#I(&]B<FEG873S<FEO+@!%<W1E(&-A
M;7!O('!O9&4@8V]N=&5R(&%P96YA<R!I;G1E:7)O<RX`17-T92!C86UP;R!P
M;V1E(&%P96YA<R!C;VYT97(@;OIM97)O<R!E(&\@<^UM8F]L;R!D;VES+7!O
M;G1O<RX`17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O
M8W1A:7,N`$5S=&4@8V%M<&\@=&5M(&1E(&-O;G1E<B!U;6$@;&ES=&$@9&4@
M:6YT96ER;W,@<V5P87)A9&]S('!O<B!E<W!AYV]S(&]U(';M<F=U;&%S+@!%
M<W1E(&-A;7!O('1E;2!D92!S97(@=6T@;OIM97)O(';A;&ED;RX`17-T92!C
M86UP;R!T96T@9&4@8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@;F\@9F]R;6%T
M;R!21T(@:&5X861E8VEM86PL('!O<B!E>&5M<&QO("<C,3(S-&%F)RX`17-T
M92!F;W)M871O(&1E(&9I8VAE:7)O(&[C;R#I('-U<&]R=&%D;RX`17-T92!M
M;V1E;&\@:N$@9F]I('!R;V-E<W-A9&\N`$ES=&\@Z2`E<RX`17-T92#I('5M
M(&]B:F5C=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!E<W1E(&]B:F5C
M=&\@<')E8VES82!D92!U;2!C;&EE;G1E(&1E(&-O<G)E:6\@96QE8W1R\VYI
M8V\@<75E(&-O;FAEYV$@;R!F;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R
M82!U;6$@;&ES=&$@9&4@8VQI96YT97,@9&4@8V]R<F5I;R!E;&5C='+S;FEC
M;R!N97-S87,@8VER8W5N<W3B;F-I87,@=FES:71E("5S`$5I<R!O('%U92!O
M('-E<G9I9&]R(&1I<W-E.B`E<P!%<W1A(&UE;G-A9V5M(&9O:2!E<V-R:71A
M(&YU;2!C\V1I9V\@*"5S*2!D:69E<F5N=&4@9&\@<V5U+@!%<W1E(&[Z;65R
M;R!P<F5C:7-A(&1E('-E<B!P96QO(&UE;F]S('5M+@!%<W1E(")S8W)I<'0B
M('1E;2!S97(@97AE8W5T861O(&$@<&%R=&ER(&1E('5M82!L:6YH82!D92!C
M;VUA;F1O<RX`17-T92!S97)V:61O<B!NXV\@8V]N<V5G=64@9&5S8V]M<')I
M;6ER(&%R<75I=F]S('II<"!O=2!G>FEP+@!%<W1E('-I<W1E;6$@96YC;VYT
M<F$M<V4@9&5S86-T:79A9&\N`$5S=&$@=F%L;W(@=&5M(&1E('-E<B!U;2!N
M^FUE<F\N`$5S=&$@:F%N96QA('1E;2!D92!S97(@8VAA;6%D82!A('!A<G1I
M<B!D92!U;6$@:F%N96QA(&1E($]PY_5E<P!4<F]V;V%D80!Q=6EN=&$M9F5I
M<F$`0FEL:&5T97,`1&%T82](;W)A`$=?86UA(%1E;7!O<F%L`%-E9W5I;65N
M=&\@5&5M<&]R86P`1F]R;6%T;R!D;R!T96UP;P!396QE8^?C;R!D871A+VAO
M<F$`1V%M82!T96UP;W)A;`!4:6UO<BU,97-T90!4[71U7VQO`%3M='5L;P!4
M[71U;&\@*&1I8V$I.@!087)A`%!A<F$@<V5L96-C:6]N87(@;?IL=&EP;&]S
M(&ET96YS+"!C87)R96=U92!E;2!#;VYT<F]L("A00RD@;W4@0V]M;6%N9"`H
M36%C*2!E;G%U86YT;R!C;&EC87(N`$AO:F4`5')O8V%R($9O;G1E($A434P`
M4F5P^F)L:6-A(%1O9V]L97-A`%1O<75E;&%U`$%M86YHXP!296EN;R!D;R!4
M;VYG80!4;W!O`$UO;&1U<F$@9&4@=&]P;R`H7W1O<"D`5')A9'5Z:61A<P!4
M<F%D=>?U97,`5')I;F1A9&4@92!4;V)A9V\`5F5R9&%D96ER;R!O=2!F86QS
M;P`S+JH`=&5RYV$M9F5I<F$`4F5P^F)L:6-A(&1A(%1U;NUS:6$`4F5P^F)L
M:6-A(&1A(%1U<G%U:6$`5'5R8V\@*$E33RTX.#4Y+3DI`%1U<G%U96UE;FES
M=.-O`$EL:&%S(%1U<F-A<R!E($-A:6-O<P!4=79A;'4`5&EP;P!%<V-R979A
M(&$@<W5A(&5S8V]L:&$Z`,UN9&EC92!5+E8N.B``55),`%523"!D;R!S974@
M<F5L873S<FEO(&1E(&5S=&%D;R!D;R!E;G9I;R!D92`B<V-R:7!T<R(`55),
M.@!297#Z8FQI8V$@9&\@56=A;F1A`%5C<N)N:6$`3N-O(&9O:2!P;W-S[79E
M;"!A8V5D97(@X"!P87-T82!61E,N`$[C;R!F;VD@<&]S<^UV96P@861I8VEO
M;F%R(&EN9F]R;6'GXV\@9&4@=71I;&EZ861O<B!E>'1R82!A<75A;F1O(&1A
M('-U8G-C<FGGXV\N`$[C;R!F;VD@<&]S<^UV96P@;75D87(@87,@<&5R;6ES
M<_5E<R!D;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&UU
M9&%R(&%S('!E<FUI<W/U97,@9&\@87)Q=6EV;R!61E,@)7,O)7,N`$[C;R!F
M;VD@<&]S<^UV96P@;75D87(@<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!L
M:6=A<B!A;R!S97)V:61O<B!344PN`$[C;R!F;VD@<&]S<^UV96P@;&EG87(@
M=7-A;F1O(%-33"X`3N-O(&9O:2!P;W-S[79E;"!C;W!I87(@;R!A<G%U:79O
M(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4R`B)7,B
M+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@<&%S=&$@5D93+@!.XV\@9F]I
M('!O<W/M=F5L(&-R:6%R(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV
M96P@8W)I87(@=6T@87)Q=6EV;R!61E,@=F%Z:6\N`$[C;R!F;VD@<&]S<^UV
M96P@9&5S8V]M<')I;6ER(&]S(&1A9&]S+@!.XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@(B5S(BP@<&]I<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA+@!.XV\@
M8V]N<VEG;R!R96UO=F5R("(E<R(Z("5S+@!.XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@(B5S(CH@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B`E<RP@
M<&]I<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA`$[C;R!C;VYS:6=O(')E;6]V
M97(@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4R!R
M96-U<G-I=F%M96YT92X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S
M=&$@5D93+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,Z
M("5S+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O(%9&4R`B
M)7,B+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O(%9&4RX`
M3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(')E8W5R<VEV86UE;G1E.B`E<RX`
M3N-O(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&$@<&%S=&$@8V]R<F5N=&4N
M`$[C;R!F;VD@<&]S<^UV96P@97AT<F%I<B!O<R!P;W)M96YO<F5S(&1O(&-E
M<G1I9FEC861O`$EM<&]S<^UV96P@;&5R(&$@9&5F:6YIY^-O(&1E("5S+@!.
MXV\@9F]I('!O<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@
M<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@9F]I('!O
M<W/M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,@<&%R82!E<V-R:71A+@!.XV\@
M9F]I('!O<W/M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S
M<^UV96P@86)R:7(@;R!A<G%U:79O(&-O;7!R:6UI9&\N`$[C;R!C;VYS:6=O
M(&QE<B!O(&%R<75I=F\Z(`!.XV\@9F]I('!O<W/M=F5L(&QE<B!A('!A<W1A
M('9F<W)O;W0N`$[C;R!C;VYS:6=O(')E;F]M96%R("(E<R(Z("5S+@!.XV\@
M9F]I('!O<W/M=F5L(')E;F]M96%R("5S(&-O;6\@)7,Z(&$@<&%S=&$@9&4@
M9&5S=&EN;R!JX2!E>&ES=&4`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A
M('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A('!A<W1A
M(%9&4SH@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@;R!A<G%U:79O
M(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&\@87)Q=6EV
M;R!61E,@)7,O)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV
M;R!61E,N`$[C;R!C;VYS:6=O(&]B=&5R(&EN9F]R;6'GXV\@;&EV<F4O;V-U
M<&%D;R!D92`E<P!.XV\@9F]I('!O<W/M=F5L(&5X96-U=&%R("=M:VES;V9S
M)RX`3N-O(&9O:2!P;W-S[79E;"!C;VYV97)T97(@97-T92!D;V-U;65N=&\@
M5V]R9`!.XV\@9F]I('!O<W/M=F5L(&5S8W)E=F5R(&%R<75I=F\@5D93("(E
M<R(N`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@;R!A<G%U:79O(%9&4R`H
M8V]P>2@I(&9A;&AO=2DN`$[C;R!C;VYS:6=O(')E;6]V97(@)R5S)SH@)7,N
M`%-U8FQI;FAA9&\`1&5S9F%Z97(@06QT97)AY_5E<P!$97-F87H@82!S=6$@
M^FQT:6UA(&%CY^-O`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@
M;F$@8V]N97CC;SH@`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@
M83H@`%-E;2!C871E9V]R:6$`56YI8V]D92`H551&+3@I`$5M:7)A9&]S(,%R
M86)E<R!5;FED;W,`4F5I;F\@56YI9&\`17-T861O<R!5;FED;W,@9&$@06WI
M<FEC80!);&AA<R!-96YO<F5S($1I<W1A;G1E<R!D;W,@17-T861O<R!5;FED
M;W,`56YI9&%D97,`1&5S8V]N:&5C:61O`&%P:6US9VED("A)1"!D92!-96YS
M86=E;2!D92!!4$DI+@!C;&EM<V=I9"!D97-C;VYH96-I9&\@*$E$(&1E($UE
M;G-A9V5M(&1E($-L:65N=&4I+@!#;VUA;F1O(&1E<V-O;FAE8VED;SH@)7,`
M1F]I(&9O<FYE8VED82!U;6$@;&]C86QI>F'GXV\@9&5S8V]N:&5C:61A+@!.
M;VUE(&1E('5T:6QI>F%D;W(@;W4@<&%L879R82UP87-S92!E<G)A9&]S`%)E
M;6]V97(@;&EG8>?C;R!D;R!E;&5M96YT;R!C;W)R96YT90!396T@;F]M90!0
M;W(@<F%Z]65S(&1E('-E9W5R86[G82P@(G-C<FEP=',B('-E;2!P<FEV:6SI
M9VEO(&[C;R!P;V1E;2!A8V5D97(@82!#;W)T87(O0V]P:6%R+T-O;&%R('!R
M;V=R86UA=&EC86UE;G1E+B!#87)R96=U92!E;2!/2R!P87)A('9E<B!U;6$@
M;F]T82!TZ6-N:6-A(&5M(&UO>FEL;&$N;W)G('%U92!L:&4@;6]S=')A<N$@
M8V]M;R!A=71O<FEZ87(@=6T@(G-C<FEP="(@82!A8V5D97(@86]S(')E8V]R
M=&5S+@!296UO=F5R(&-O;&]R8>?C;P!4:7!O(&1E(&-O;G1E^F1O("A#;VYT
M96YT+51Y<&4I(&[C;R!S=7!O<G1A9&\N`$5X=&5N<^-O(&[C;R!3=7!O<G1A
M9&$`4&]R('1R861U>FER`$UO9&EF:6-A<@!!8W1U86QI>F%R("5S`$%C='5A
M;&EZ87(@=71I;&EZ861O<@`B)7,B(&%C='5A;&EZ861O+@!!8W1U86QI>F%D
M;SH@)7,N`$%C='5A;&EZ86YD;R!A<G%U:79O(&1E(&%J=61A("5S('!A<F$@
M)7,N`")38W)I<'0B(&1E(&%C='5A;&EZ8>?C;R!R96UO=FED;RX`57!L;V%D
M`$-A<G)E9V%D;W,@;F\@<V5R=FED;W(@=&]D;W,@;W,@87)Q=6EV;W,@9&4@
M:6YS=&%L8>?C;R!D92!A<&QI8V'G]65S+@!,971R87,@;&%T:6YA<R!E;2!M
M86GZ<V-U;&%S`$[Z;65R;W,@<F]M86YO<R!E;2!M86GZ<V-U;&%S`%)E</IB
M;&EC82!/<FEE;G1A;"!D;R!5<G5G=6%I`%5T:6QI>F'GXV\Z`%5S87(@;R!#
M;W)R96YT93H@)7,`57-A<B!34TPN`%5S87(@<V4@;R!N;VUE(&1E('5T:6QI
M>F%D;W(@;W4@82!P86QA=G)A+7!A<W-E(&9O<F5M(&1I9F5R96YT97,@;F\@
M<V5R=FED;W(@24U34"X`571I;&EZ861O<B`E<R!NXV\@97-TX2!A=71O<FES
M861O('!A<F$@)7,N`$%D;6EN:7-T<F'GXV\@9&4@571I;&EZ861O<F5S`$EN
M=&5R9F%C92!D;R!U=&EL:7IA9&]R`$]PY_5E<R!D;R!5=&EL:7IA9&]R`%)E
M9VES=&\@9&4@571I;&EZ861O<F5S`$\@4F5G:7-T;R!D92!5=&EL:7IA9&]R
M97,@97-TX2!I;F%C=&EV;RX`4&5R;6ES<_5E<R!D;R!U=&EL:7IA9&]R`$YO
M;64@9&4@571I;&EZ861O<@!/($YO;64@9&4@571I;&EZ861O<B`B)7,B(&KA
M(&5X:7-T92X`3F]M92!D92!5=&EL:7IA9&]R.@!.;VUE(&1E(%5T:6QI>F%D
M;W(Z(`!5=&EL:7IA9&]R97,`571I;&EZ861O<F5S(&1O('-I<W1E;6$Z`%)E
M</IB;&EC82!D;R!5>F)E<75I<W3C;P!!('!A<W1A(%9&4R!NXV\@97AI<W1E
M+@!!=7/J;F-I80!!<R!L;V-A;&EZ8>?U97,@=N%L:61A<R!E;F-O;G1R861A
M<R!I;F-L=65M.@!686QI9&%D92X`5F%L;W(@96T@;6EN=71O<R!A('!A<G1I
M<B!D97-T92!I;G-T86YT92X`5F%L;W(@97AC961E(&\@8V]M<')I;65N=&\@
M;>%X:6UO(&1E("5S+@!686QO<F5S`%!O<W/M=F5L('9A;&]R97,@82!E<V-O
M;&AE<@!686YU871U`%9A<FGA=F5L`%9E;F5Z=65L80!697)I9FEC8>?C;R!F
M86QH;W4@+2!E<W1A(&UE;G-A9V5M('!O9&4@=&5R('-I9&\@861U;'1E<F%D
M82X`5F5R<^-O`$-O;G1R;VQO(&1E(%9E<G/U97,`06QI;FAA;65N=&\@5F5R
M=&EC86P`0V%LYV\@5F5R=&EC86P`5F5R=&EC86PZ`$UU:71O($%L=&\`4F5P
M^F)L:6-A(%-O8VEA;&ES=&$@9&\@5FEE=&YA;64`5FEE=&YA;6ET82`H5DE3
M0TE)*0!6:7-U86QI>F%R("5S`$UO<W1R87(@1&EA`%9E<B!U;6$@<.%G:6YA
M(&5X=&5R;F$`5FES=6%L:7IA<B!C;VUO("5S`$EL:&%S(%9I<F=E;G,@0G)I
M=.)N:6-A<P!);&AA<R!6:7)G96YS($%M97)I8V%N87,`5FES:6)I;&ED861E
M`%9I<VEB:6QI9&%D93H@`%9O9&%F;VYE($ETX6QI82!V:6$@4TU44`!!5DE3
M`$%414['PT\A(2$@4D5-3U9!($\@(E-#4DE05"(@34%.54%,345.5$4@1$4@
M)7,N`%=A;&QI<R!E($9U='5N80!!=FES;P!!=FES;SH@`#0NJ@!0<F5V:7/C
M;R!D;R!496UP;P!$861O<R!M971E;W)O;/-G:6-O<R!F;W)N96-I9&]S('!O
M<@!796%T:&5R+F-O;0!796(`4.%G:6YA`'%U87)T82UF96ER80!396UA;F$`
M4V5M86YA("5D`%-E;6%N82AS*0!396UA;F%L;65N=&4`4V5M86YA;&UE;G1E
M.B!R97!E=&4@8V%D80!"96TM=FEN9&$H;RD`0F5M+79I;F1A*&\I(&$@)7,`
M0F5M+79I;F1A*&\I+"`E<P!/8VED96YT86P@*$E33RTX.#4Y+3$I`$]C:61E
M;G1A;"`H25-/+3@X-3DM,34I`%-A87)A`%%U92!A<&QI8V'GXV\@9&5V92!O
M("5S(&UO<W1R87(@87#S<R!A(&5N=')A9&$_`%%U86P@Z2!O(&-A<F%C=&5R
M92!D96QI;6ET861O<C\`475A;"#I(&\@8V%R86-T97)E(&1E(&-I=&'GXV\_
M`$$@<75E(&AO<F%S(&1E=F5M('1E<FUI;F%R(&%S('9I<W1A<R!D92!D:6$@
M92!S96UA;F$L('%U86YD;R!NXV\@:&]U=F5R(&5V96YT;W,@<&]S=&5R:6]R
M97,_`$$@<75E(&AO<F%S(&1E=F5M(&-O;67G87(@87,@=FES=&%S(&1E(&1I
M82!E('-E;6%N82P@<75A;F1O(&[C;R!H;W5V97(@979E;G1O<R!A;G1E<FEO
M<F5S/P!1=64@9F%S97,`475E(")P;'5G:6YS(B!A8W1I=F%R('!A<F$@82!%
M9&GGXV\@4FEC82X`3&%R9W5R80!,87)G=7)A(&5M('5N:61A9&5S($-34P!,
M87)G=7)A(&1O($UE;G4@)7,@X"!E<W%U97)D82`H=&5M(&5F96ET;R!N82!P
M<O-X:6UA(&5N=')A9&$I.@!,87)G=7)A(&1A('1A8F5L80!5;FED861E(&1E
M(&QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT;P!696YT;R!-871I;F%L`%9E
M;&]C:61A9&4@9&\@=F5N=&\@96T@;O-S`%9E;G1O.@!696YT;SH@`%-A8F5D
M;W)I80!,:7-T87,@9&4@1&5S96IO<P!4<F%B86QH;P!%;F1E<F7G;R`H16UP
M<F5G;RD`5&5L969O;F4@*$5M<')E9V\I`$-O;65R8VEA;`!%<V-R979E;F1O
M(&%R<75I=F\@9&4@86IU9&$@86-T=6%L:7IA9&\@<&%R82`E<RX`4F5F97+J
M;F-I87,@8W)U>F%D87,`4F5S=')IY_5E<R!"X7-I8V%S(%@U,#EV,P!5=&EL
M:7IAY^-O(&1E($-H879E($5X=&5N9&ED82!8-3`Y=C,`3F]M92!!;'1E<FYA
M=&EV;R!D92!3=6IE:71O(%@U,#EV,P!)9&5N=&EF:6-A9&]R($-H879E(&1E
M(%-U:F5I=&\@6#4P.78S`$5X=&5N<_5E<R!8-3`Y=C,`04$`04%!00!-87!A
M(%EA:&]O(0!!;G5A;&UE;G1E`$%N=6%L.B!R97!E=&4@<&]R`$GI;65N`%-I
M;0!3:6TL($-O;F-O<F1O`$5S=.$@96T@34]$3R!D92!415A4+B`@57-E(&\@
M8F]TXV\@6SP^72!P87)A('1R;V-A<B!P87)A(&\@;6]D;R!625-504PN`$[C
M;R!E<W3A(&%U=&5N=&EC861O+@!.XV\@<&]D92!T97(@;R!C87)A8W1E<F4@
M)UPG(&YO('-E=2!N;VUE(&-O;7!L971O+@!3\R!P;V1E('5S87(@97-T92!F
M;W)M=6SA<FEO(&$@<&%R=&ER(&1O(&5C<N,@161IY^-O(&1E(%!A<G1I8VEP
M8>?U97,`3N-O(&EN=')O9'5Z:74@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;R!VX6QI9&\N`$[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O
M(&%R<75I=F\@:6UP;W)T861O('!A<F$@;W,@8V%M<&]S(&-O<G)E<W!O;F1E
M;G1E<R!E;2`E<RX`3N-O('1E;2!U;2!E;F1E<F7G;R!D92!C;W)R96EO(&5L
M96-T<O-N:6-O(&-O;F9I9W5R861O(&YA<R!S=6%S($]PY_5E<R!D92!);F9O
M<FUAY^-O(%!E<W-O86PN(%1E;2!D92!C;VYF:6=U<F%R('5M("5S87%U:25S
M('!A<F$@<75E(&QH92!P;W-S86T@<V5R(&5N=FEA9&%S(&YO=&EF:6-AY_5E
M<RX`3N-O('1E;2!P97)M:7-SXV\@<&%R82!A9&EC:6]N87(@979E;G1O<R!A
M("5S+@!.XV\@=&5M('!E<FUI<W/C;R!P87)A(&%D:6-I;VYA<B!E=F5N=&]S
M(&%O(&-A;&5N9.%R:6\@<V5L96-C:6]N861O+@!.XV\@=&5M('!E<FUI<W/C
M;R!P87)A(')E;6]V97(@97-T92!E=F5N=&\N`$[C;R!T96T@<&5R;6ES<^-O
M('!A<F$@961I=&%R(&5S=&4@979E;G1O+@!!8V%B;W4@9&4@<V%I<BX`17-P
M96-I9FEC;W4@=6T@8V%L96YDX7)I;R!I;G;A;&ED;RX`5&5M(&1E(&EN=')O
M9'5Z:7(@=6T@;OIM97)O(&1E('1E;&5M\W9E;"!VX6QI9&\L('/S(&-O;2!D
M[6=I=&]S+"!M87,@8V]M('5M("<K)R!O<&-I;VYA;"!P87)A(&\@<')E9FEX
M;R!I;G1E<FYA8VEO;F%L+@!496T@9&4@:6YT<F]D=7II<B!U;2!V86QO<B!V
MX6QI9&\N`%1E;2!D92!C;VYF:6=U<F%R('5M(&UE8V%N:7-M;R!BX7-I8V\@
M<&%R82!$871A5')E92!S92!Q=6ES97(@=7-A<B!3=6)S8W)IY_5E<P!496T@
M9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@8F%S92!P87)A(&\@5D93+@!$
M979E(&1E<V-R979E<B!O('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!O(')E
M;&%T\W)I;RX`5&5M(&1E(&EN=')O9'5Z:7(@;R!54DP@9&\@<F5C=7)S;R!Q
M=64@97-T82!L:6=AY^-O('-E(')E9F5R90!496T@9&4@<V5L96-C:6]N87(@
M=6T@8V%L96YDX7)I;R!A(')E;6]V97(N`%1E;2!D92!S96QE8V-I;VYA<B!P
M<FEM96ER;R!U;2!E;F1E<F7G;RX`5&5M(&1E('-E;&5C8VEO;F%R('5M('-E
M<G9I9&]R(&$@<F5M;W9E<BX`1&5V92!E<W!E8VEF:6-A<B!O('5T:6QI>F%D
M;W(@82!L:6UP87(N`$1E=F4@97-P96-I9FEC87(@;R!N;VUE(&1O('5T:6QI
M>F%D;W(@82!R96UO=F5R+@!496T@9&4@97-P96-I9FEC87(@;R!N;VUE(&1O
M('5T:6QI>F%D;W(@82!A9&EC:6]N87(N`%1E;2!D92!E<W!E8VEF:6-A<B!O
M('5T:6QI>F%D;W(@82!A8W1U86QI>F%R+@!496T@9&4@97-P96-I9FEC87(@
M82!A8^?C;R!A(&1E<V5M<&5N:&%R+@!496T@9&4@:6YT<F]D=7II<B!U;2!N
M;W9O(&YO;64@9&4@8V%T96=O<FEA+@!496T@9&4@9F]R;F5C97(@=6T@;OIM
M97)O(&1E('1E;&5F;VYE(&ET86QI86YO`%!E9&EU('!A<F$@<V5R(')E8V]R
M9&%D;R!A8V5R8V$@9&4@)7,L('%U92!T96T@;'5G87(@82`E<R!E;2`E<RX`
M02!S=6$@<V5S<^-O("5S(&5X<&ER;W4N(%!O<B!F879O<B!E;G1R92!D92!N
M;W9O+@!/('-E=2!%;F1E<F7G;R!D92!#;W)R96EO($5L96-T<O-N:6-O.@!/
M('-E=2!E;F1E<F7G;R`B1&4Z(@!!('-U82!);F9O<FUAY^-O`$\@<V5U(&5N
M9&5R9>=O($E0('!A<F5C92!T97(@;75D861O(&1E<V1E(&\@:6[M8VEO(&1A
M('-E<W/C;R`E<RX@4&%R82!G87)A;G1I<B!A('-U82!S96=U<F%NYV$L(&1E
M=F4@875T96YT:6-A<BUS92!D92!N;W9O+@!/(%-E=2!.;VUE`$\@<V5U(&UE
M8V%N:7-M;R!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@861IY^-O(&1E
M('5T:6QI>F%D;W)E<R!O=2!E<W1A(&]PY^-O(&9O:2!D97-A8W1I=F%D82!P
M;W(@86QG=6T@;W5T<F\@;6]T:79O+@!/('-E=2!M96-A;FES;6\@9&4@875T
M96YT:6-AY^-O(&[C;R!S=7!O<G1A(&QI<W1A9V5M(&1E('5T:6QI>F%D;W)E
M<R!O=2!E<W1A(&]PY^-O(&9O:2!D97-A8W1I=F%D82!P;W(@86QG=6T@;W5T
M<F\@;6]T:79O+@!/('-E=2!N879E9V%D;W(@<&%R96-E('1E<B!M=61A9&\@
M9&5S9&4@;R!I;NUC:6\@9&$@<V5S<^-O("5S+B!087)A(&=A<F%N=&ER(&$@
M<W5A('-E9W5R86[G82P@9&5V92!A=71E;G1I8V%R+7-E(&1E(&YO=F\N`$\@
M<V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&9U;F-I;VYA;&ED861E
M+@!/('-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@97-T82!O<.?C;R!D92!I
M;7!R97-SXV\N(%!R97-S:6]N92!#;VYT<F]L+T-O;6UA;F0@*R!0('!A<F$@
M:6UP<FEM:7(N`$9U<V\@:&]RX7)I;R!A8W1U86PZ`$\@<V5U(&-A;&5N9.%R
M:6\@<&]R(&]M:7-SXV\`261E;G1I9&%D92!P861RXV\Z`$YO;64@8V]M<&QE
M=&\`02!S=6$@=F5R<^-O(&1O(&=E='1E>'0@Z2!D96UA<VEA9&\@86YT:6=A
M+"!NXV\@<W5P;W)T86YD;R!02%`@9&4@9F]R;6$@;F%T:79A+B!.96T@=&]D
M87,@87,@8V%D96EA<R!D92!C87)A8W1E<F5S('-E<N-O(&5X=')A[61A<RX`
M02!S=6$@;F]V82!P86QA=G)A+7!A<W-E('!A<F$@)7,@Z3H@)7,`07,@<W5A
M<R!O<.?U97,@9F]R86T@86QT97)A9&%S(&%TZ2!A;R!F:6YA;"!D97-T82!S
M97-SXV\N`$%S('-U87,@;W#G]65S(&9O<F%M(&%C='5A;&EZ861A<RX`02!S
M=6$@<&%L879R82UP87-S92!F;VD@<F5C<FEA9&$`02!S=6$@<&%L879R82UP
M87-S92!F;VD@<F5C<FEA9&$L('9E<FEF:7%U92!O('-E=2!C;W)R96EO(&5L
M96-T<O-N:6-O(&4@96YT<F4@8V]M(&$@<W5A(&YO=F$@<&%L879R82UP87-S
M92X`3W,@<V5U<R!S97)V:61O<F5S(')E;6]T;W,Z`$IU9V]S;.%V:6$`6F%I
M<F4`6N)M8FEA`%II;6)A8G7I`%II<'!Y`%M%<V-O;F1E<B!497AT;R!#:71A
M9&]=`%M296QA=/-R:6\@9&4@4')O8FQE;6%S72``6TUO<W1R87(@5&5X=&\@
M0VET861O("T`6TUO<W1R87(@5&5X=&\@0VET861O("T@)7,@;&EN:&%S70!;
M179E;G1O('-E;2!N;VUE70!;;&EN:&$@)7,@9&4@)7-=`%]!9&UI;FES=')A
MY^-O`,!?<P!0<F]C=7)A(%]"X7-I8V$`7T-O;G-O;&$`P7)?=F]R90!?4F5M
M;W9E<B!,:6YH80!%9&E?=&%R`%])<B!P87)A`%]'<G5P;W,`05]J=61A`%!R
M;W!R:65D861E<R!D82!?26UA9V5M`$EM<&]R=&%R+T5?>'!O<G1A<@!?16YT
M<F%R`%]386ER`%]-;V1I9FEC87(@3&EG8>?C;P!/<R!?365U<R!#86QE;F3A
M<FEO<P!?3F]V;R!%=F5N=&\`7T]PY_5E<P!?4&5R;6ES<_5E<P!);5]P<FEM
M:7(`7U)E;6]V97(@3&EG8>?C;RXN+@!?4')O8W5R87(`7T-O;F9I9W5R8>?C
M;P!-;W-T<F%?<@!0<F]P<FEE9&%D97,@9&$@7U1A8F5L80!?2&]J90!?571I
M;&EZ861O<F5S`&-O;G1A8W1O<P!O8V]R<F5U('5M(&5R<F\Z`&%N=&5S(&1E
M(&\@979E;G1O(&-O;67G87(`8V%L96YDX7)I;P!C86QM;P!C;&EQ=64@87%U
M:0!D:6$`9&EA*',I`&1I87,`9F5I=&\`979E;G1O<RYC<W8`979A;G1O<RYI
M8W,`9F%L:&]U`&1I;6EN=6EN9&\`9FEC:&5I<F\`96YC;VYT<F%D;SH@`&1E
M`&1O("5S("@E<RD@X',@)7,@)7,`<F%J861A<P!H.@!H:`!I;65D:6%T;P!E
M;2!L:6YH80!L:6YH87-=`$5R<F\@;6MI<V]F<R!C;VT@8_-D:6=O("5D(&%O
M(&-O;G-T<G5I<B!)4T\N`&UM`&UE<RAE<RD`;F]M90!S96T@86QT97)AY_5E
M<P!NXV\@96YC;VYT<F%D;P!NXV\@:6UP;&5M96YT861A`&%I;F1A('!O<B!I
M;7!L96UE;G1A<@!C861E<FYO(&1E(&YO=&%S`&YA(&UE<VUA(&1A=&$`;F\@
M;65S;6\@9&EA(&1A('-E;6%N80!P97)C96YT86=E;0!P[7AE:7,`<W5B:6YD
M;P!M;W-T<F%R(&1I9F5R96[G87,`<VUS,F5M86EL('9I82!(5%10`'-S`&5S
M=.%V96P`;&ES=&$@9&4@=&%R969A<P!/(&9I8VAE:7)O(%!/('!A<F$@;R!L
M;V-A;&4@)7,@;N-O(&5X:7-T92X`:6YT<F]D=7IA(&$@<&%L879R82UP87-S
M92!D=6%S('9E>F5S+"!P87)A(&-O;F9I<FUAY^-O`'5N:69I8V%D;P!S96T@
M;F]M90!A8W1U86QI>F%D;P!S96QE8V-I;VYA9&$@<&5L;R!U=&EL:7IA9&]R
M`'9#86QE;F1A<B]I0V%L96YD87(`=D-A<F0`=D5V96YT(&[C;R!E;F-O;G1R
M861O+@!2965N8SH`=V5A=&AE<BYC;VT`<V5M86YA`'-E;6%N82AS*2!E;3H`
M<V5M86YA<P!A;F\H<RD`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O<F]?4D\O````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-3(`,#(P-S$S`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO
M8V%L92]R;U]23R],0U]-15-304=%4R\`````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<U,@`P,C(U,#``(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]K<F]N;VQI=&@O;&]C86QE+W)O7U)/+TQ#7TU%4U-!1T53+VMR;VYO
M;&ET:"YM;P```````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#(Q-C`T`#$P-#$W,S8R-S4R`#`R-3`T-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#>$@25
M`````*8````<````3`4``-\```!\"@```````/@-```H````^0T```@````B
M#@``!0```"L.```)````,0X```\````[#@``"````$L.```'````5`X```4`
M``!<#@``!0```&(.```'````:`X``!\```!P#@```@```)`.```1````DPX`
M``@```"E#@``"````*X.```&````MPX``!4```"^#@``"````-0.```*````
MW0X```P```#H#@``!P```/4.```I````_0X``!(````G#P```@```#H/```%
M````/0\``!,```!##P```P```%</```&````6P\``!````!B#P``#````',/
M```4````@`\``"\```"5#P``#P```,4/```F````U0\```@```#\#P``!P``
M``40```%````#1````T````3$```!@```"$0```%````*!```!`````N$```
M$````#\0```/````4!````L```!@$```#P```&P0```,````?!````\```")
M$```'@```)D0```A````N!````,```#:$````@```-X0```&````X1````0`
M``#H$```!````.T0```,````\A````H```#_$```!0````H1```'````$!$`
M`!(````8$0``$````"L1```(````/!$```D```!%$0``$````$\1```(````
M8!$```8```!I$0``!P```'`1```"````>!$```0```![$0``#P```(`1```'
M````D!$```<```"8$0```@```*`1```&````HQ$```4```"J$0``!P```+`1
M```5````N!$```4```#.$0``"0```-01```*````WA$```@```#I$0``"0``
M`/(1```+````_!$```0````($@``!0````T2```'````$Q(``!$````;$@``
M"````"T2```'````-A(``!X````^$@``!0```%T2```H````8Q(``"D```",
M$@``#````+82```3````PQ(```L```#7$@``"P```.,2```1````[Q(``!$`
M```!$P``!````!,3```"````&!,```@````;$P``"@```"03```,````+Q,`
M`!H````\$P``%P```%<3```9````;Q,``!<```")$P``'0```*$3```;````
MOQ,``!\```#;$P``$P```/L3```H````#Q0``!`````X%```%P```$D4```(
M````810```(```!J%```!P```&T4```&````=10```(```!\%```+P```'\4
M```A````KQ0``!P```#1%```"````.X4```%````]Q0```4```#]%````@``
M``,5```'````!A4```0````.%0``)@```!,5```,````.A4```X```!'%0``
M#````%85```(````8Q4```<```!L%0```@```'05```)````=Q4```0```"!
M%0``!P```(85```&````CA4``!0```"5%0``#0```*H5```+````N!4```P`
M``#$%0``"@```-$5```)````W!4```(```#F%0``!@```.D5```4````\!4`
M`$4````%%@``,````$L6```0````?!8``!\```"-%@``$````*T6```/````
MOA8```,```#.%@``!@```-(6```$````V18```@```#>%@``$````.<6```3
M````^!8```4````,%P``!````!(7```+````%Q<```4````C%P``!P```"D7
M``!B`0``,1<``"@```"4&```"0```+T8```%````QQ@``!````#-&```%```
M`-X8```/````\Q@```8````#&0``!@````H9```%````$1D```H````7&0``
M(P```"(9```"````1AD``!0```!)&0``#0```%X9```(````;!D```D```!U
M&0``$0```'\9```)````D1D```T```";&0``$0```*D9```(````NQD``"@`
M``#$&0``%````.T9```"`````AH```8````%&@``&P````P:```"````*!H`
M``8````K&@``%````#(:```0````1QH``!````!8&@``,0```&D:```0````
MFQH``"<```"L&@``!@```-0:```+````VQH```4```#G&@``&0```.T:```*
M````!QL```8````2&P``$P```!D;```4````+1L``!,```!"&P``%````%8;
M```3````:QL``!````!_&P``$@```)`;```9````HQL``"8```"]&P```P``
M`.0;```#````Z!L```8```#L&P```P```/,;```$````]QL```\```#\&P``
M$@````P<```%````'QP```8````E'```$0```"P<```2````/AP```4```!1
M'```$````%<<```:````:!P```<```"#'```"0```(L<```+````E1P```(`
M``"A'```#0```*0<```=````LAP```D```#0'```!0```-H<```#````X!P`
M``0```#D'```!````.D<```%````[AP``!L```#T'```"0```!`=```-````
M&AT```X````H'0``#@```#<=```3````1AT``!(```!:'0``!P```&T=```$
M````=1T```<```!Z'0``#P```((=```&````DAT```4```"9'0``(@```)\=
M```'````PAT``"<```#*'0``,````/(=```/````(QX``!0````S'@``"P``
M`$@>```/````5!X``!T```!D'@``$0```((>```0````E!X```,```"E'@``
M!P```*D>```2````L1X```\```#$'@``%````-0>```<````Z1X``"(````&
M'P``&P```"D?```<````11\``"(```!B'P``&P```(4?```8````H1\``#0`
M``"Z'P``%0```.\?```6````!2````D````<(````P```"8@```&````*B``
M``@````Q(````P```#H@```^````/B```!8```!](```*````)0@```#````
MO2````4```#!(````P```,<@```#````RR````4```#/(````P```-4@```N
M````V2```!0````((0``%````!TA```2````,B$```H```!%(0``!P```%`A
M```#````6"$```@```!<(0``"0```&4A```,````;R$```H```!\(0``(```
M`(<A```<````J"$``!$```#%(0``$@```-<A```3````ZB$``!0```#^(0``
M`@```!,B```%````%B(``!L````<(@``.@```#@B```[````<R(``!8```"O
M(@``&@```,8B```1````X2(``!$```#S(@```@````4C```&````"",```0`
M```/(P``!P```!0C```/````'",``!H````L(P``$0```$<C```)````62,`
M`!````!C(P``"0```'0C```%````?B,```$`````````%0````4```"9````
M20```%8```!K````-0```(4```!M````D@```#\```!A````C@``````````
M```````````````\````:@```*,````J`````````(P````"````-```````
M```H````=@```"X```!\````)P````H````2````"0```'\```!*````````
M`&(`````````#0````````!T````,@```$P```!#```````````````I````
M1@```*````!0````%P```)8````E````/@```!\`````````3@```"(````#
M````BP```($```!W````9P```)0```"<````+````$T`````````EP```$``
M```Q`````````)$```!8````7````"\`````````+0```)X````6````````
M``\```"F````.@```&4```"?````AP```&D````F````#````!D`````````
M`````!@```````````````L````4````5``````````X`````````&X```!1
M````=0``````````````)````#L```"0````?0```(,````.````70```&,`
M``"`````$0``````````````E0```%<````>````8````!P````:````9@``
M````````````7P```)L```!X``````````````!^````6P````8```!"````
M*P```````````````````(T```!5`````````&\```"*````;````#<```!P
M````G0```!T`````````(```````````````B0```!````"8````````````
M````````-@`````````;````7@```%,```!Z````1P```!,`````````!```
M`&0```"3````1````((```"$`````````&@```"E````10`````````'````
M``````````!!`````````$@```!/````,P```*(````(````,````*$```":
M`````````',```!Q`````````%D```!+`````````%H````C`````````#D`
M``![````/0```(\`````````A@```(@```````````````````!Y````(0``
M`'(`````````4@```*0`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`R-"!H;W5R<P!!32]030!!9&0@179E;G0`061D(&$@
M;F5W(&5V96YT`$%D9"!P86ER`$%D9')E<W,`06QA<FT`06QI87,`06QL(&1A
M>0!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%T`$%V86EL86)L
M92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%T96=O<GD`0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`
M0V]M<&%N>0!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#<F5A=&4@82!.97<@179E;G0`1$0`1&%I;'D`1&%I;'DZ(%)E8W5R
M<R!E=F5R>0!$87D`1&%Y*',I`$1E9F%U;'0@261E;G1I='D`1&5L971E($5V
M96YT`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$=7)A=&EO
M;@!%9&ET("5S`$5M86EL`$5M<'1Y(')E<W5L="X`16YD($]N`$5R<F]R`$5V
M97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T
M97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%
M>&%M<&QE('9A;'5E<SH`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`1G(`1G)I
M9&%Y`$=A;64`2&5L<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!(
M;W5R*',I`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA
M;F=U86=E`$QA<W0@=V5E:P!,:7-T($AE;'`@5&]P:6-S`$QO8V%T:6]N`$QO
M9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE971I;F<`
M365S<V%G90!-;P!-;VYD87D`36]N=&@`36]N=&AL>0!-;VYT:&QY.B!296-U
M<G,@979E<GD`3F5V97(`3F5W($5V96YT`$YE>'0@36]N=&@`3F5X="!D87D`
M3F5X="!W965K`$YO(&5N9"!D871E`$YO;F4`3F]T97,`3W!T:6]N<P!/=&AE
M<B!);F9O<FUA=&EO;@!087-S=V]R9`!0871T97)N`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!R979I;W5S(&1A>0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%)E8W5R(%5N=&EL`%)E;6]V92!P86ER`%)E<V5T('1O($1E9F%U;'1S
M`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V$`4V%T=7)D87D`4V%V92!%=F5N
M=`!3879E($]P=&EO;G,`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!F:7)S="!W965K9&%Y
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@=&AE('1I;64@<W!A
M;B!T;R!S:&]W.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T
M`%-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\`4VMI
M<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=&%R="!/
M;@!3=0!3=6-C97-S`%-U;F1A>0!4:`!4:&4@96YD(&1A=&4@;75S="!B92!L
M871E<B!T:&%N('1H92!S=&%R="!D871E+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4
M:'5R<V1A>0!4:71L90!4;V1A>0!4=0!4=65S9&%Y`%1Y<&4`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S
M97(@26YT97)F86-E`%5S97(@3W!T:6]N<P!5<V5R;F%M90!787)N:6YG`%=E
M`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E:VQY`%=E96ML>3H@4F5C=7)S
M(&5V97)Y`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`5V]R:R!7965K`%E9`%EE87)L>0!996%R;'DZ(%)E8W5R
M<R!E=F5R>0!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@26YF
M;W)M871I;VX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O
M8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!D87D`9&%Y*',I`&1A>7,`
M;6]N=&@H<RD`;VX@=&AE('-A;64@9&%T90!O;B!T:&4@<V%M92!W965K9&%Y
M`'9#87)D`'=E96L`=V5E:RAS*2!O;CH`=V5E:W,`>65A<BAS*0!0<F]J96-T
M+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`Q+C`*4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`S+3`S
M+3`Q(#$R.C`P("LP,C`P"DQA<W0M5')A;G-L871O<CH@175G96X@2&]A;F-A
M/&5U9V5N:$!U<F)A;BUG<F%F>"YR;SX*3&%N9W5A9V4M5&5A;3H@4F]M86YI
M86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`)7,@3W!E<F%T:75N
M:2!D92!M96YT96YA;G1A("T@0V]N9FER;6%R90`R-"!D92!O<F4`04TO4$T`
M061A=6=A(&5V96YI;65N=`!!9&%U9V$@979E;FEM96YT(&YO=0!!9&%U9V$@
M<&5R96-H96$`061R97-A`$%L87)M80!!;&EA<P!4;V%T82!Z:75A`%,M82!S
M<&5C:69I8V%T(&\@=F%L;V%R92!I;F-O<F5C=&$N`$QA`$-I;7!U<FD@9&ES
M<&]N:6)I;&4Z`%II(&1E(&YA<W1E<F4`0V%L96YD87(`4F5N=6YT87)E`%)E
M;G5N=&$@;&$@4F%P;W)T`$-A=&5G;W)I90!496QE9F]N($UO8FEL`$EN8VAI
M9&4@9F5R96%S=')A`$-O;7!A;FEA`$YU('!O="!D97-C:&ED92!M;V1U;'5L
M(&1E($UE;G1E;F%N=&$@)7,`0W)E87)E(&5V96YI;65N="!N;W4`6EH`6FEL
M;FEC`%II;&YI8SH@4F5P971A<F4@;&$@9FEE8V%R90!::0!::2AL92D`261E
M;G1I=&%T92!);7!L:6-I=&$`4W1E<F=E(&5V96YI;65N=`!$97-C<FEE('!R
M;V)L96UA`$1E=&%L:6D@:6YR96=I<W1R871E(&EN($Q/1R!P96YT<G4@861M
M:6YI<W1R871O<BX`069I<V5A>F$@;W!T:75N:0!492!R;V<@;G4@86-C97-A
M(&1I<F5C="!M86EN=&5N86YC92YP:'``1'5R871A`$5D:71E87IA("5S`$5M
M86EL`$5M<'1Y(')E<W5L="X@+2!D92!T<F%D=7,`4V9A<G-I="!D90!%<F]A
M<F4`3R!D871A(&QA(#$U(&UI;G5T90!/(&1A=&$@;&$@,S`@<V5C=6YD90!,
M82!F:65C87)E(#4@;6EN=71E`$QA(&9I96-A<F4@0V]N96-T87)E`$\@9&%T
M82!L82`S,"!M:6YU=&4`26X@9FEE8V%R92!M:6YU=`!%>&5M<&QE(&1E('9A
M;&]R:3H`3G4@<&]T(&-I=&D@<')E9F5R:6YT96QE+@!.=2!M82!P;W0@8V]N
M96-T82!L82!S97)V97)U;"!D92!,1$%0+@!&87@`5FEN`%9I;F5R:0!*;V,`
M2&5L<`!!9')E<V$@9&4@86-A<V$`5&5L969O;G5L(&1E(&%C87-A`$AO<F1E
M`$]R82AE*0!#:6UP(&EM<&]R=&%T.B`E<P!#:6UP=7)I(&EM<&]R=&%T93H`
M3&EM8F$`56QT:6UA('-A<'1A;6%N80!,:7-T82!S=6)I96-T96QO<B!D:6X@
M2&5L<`!,;V-A=&EE`$-O;F5C=&%R90!$96-O;F5C=&%R90!,3`!#;W)E<W!O
M;F1E;G1A`$-I;7!U<FD@<&]T<FEV:71E("T@9&4@=')A9'5S`$EN=&%L;FER
M90!-97-A:@!,=6X`3'5N:0!,=6YA`$QU;F%R`$QU;F%R.B!392!R97!E=&$@
M;&$@9FEE8V%R90!.:6-I;V1A=&$`179E;FEM96YT(&YO=0!,=6YA('5R;6%T
M;V%R90!::75A('5R;6%T;V%R90!387!T86UA;F$@=7)M871O87)E`$9A<F$@
M9&%T82!D92!F:6YA;`!.:6-I('5N`$YO=&4`3W!T:75N:0!!;'1E(&EN9F]R
M;6%T:6D`4&%R;VQA`$UO9&5L`$5X96-U=&$@3W!E<F%T:75N:6QE(&1E($UE
M;G1E;F%N=&$`5&5L969O;@!492!R;V<@<W!E8VEF:6-A('5N('-U;6%R(&%L
M('!R;V)L96UE:2X`5&4@<F]G(&EN=')O9'4@=6X@;G5M92!D92!U=&EL:7IA
M=&]R('-I(&\@<&%R;VQA`%II=6$@<')E8V5D96YT80!$97-C<FEE<F5A('!R
M;V)L96UE:0!297!E=&$@<&%N80!3=&5R9V4@<&5R96-H96$`4F5S971E87IA
M(&QA('9A;&]R:2!I;7!L:6-I=&4`26YA<&]I(&QA(&]P=&EU;FD`4F]L92`M
M(&1E('1R861U<P!386T`4V%M8F%T80!386QV96%Z82!E=F5N:6UE;G0`4V%L
M=F%Z82!/<'1I=6YI`$1E;&EM:71A=&]R(&1E(&1A=&$Z`$9O<FUA='5L(&1E
M(&%F:7-A<F4@82!D871E:3H`4V5L96-T96%Z82!P<FEM82!Z:2!D:6X@<V%P
M=&%M86YA.@!&;W)M871U;"!D92!A9FES87)E(&$@;W)E:3H`4V5L96-T96%Z
M82!I;G1E<G9A;"!D92!T:6UP.@!396QE8W1E87IA(&1O=6$@8VEM<'5R:2!P
M;W1R:79I=&4N`%-E;&5C=&5A>F$@;&EM8F$@<')E9F5R871A.@!4<FEM:71E
M(%)A<&]R="!D92!%<F]A<F4`069I<V%R92!N=6UA:2!A(&5V96YI;65N=&5L
M;W(@8V%R92!A=2!S971A=&$@86QA<FUA/P!387)I('!E<W1E($UE;G1E;F%N
M=&$`0V%R86-T97)E(%-P96-I86QE("XN+@!);F-E<&4@;&$`1'5M`%-U8V-E
M<P!$=6UI;FEC80!*;VD`1&%T82!D92!S9F%R<VET('1R96)U:64@<V$@9FEE
M(&UA:2!N;W5A(&1E8V%T(&1A=&$@9&4@:6YC97!U="X`5F%L;V%R96$@;6EN
M:6UA(&5S=&4@,0!!8V5A<W1A('9A;&]A<F4@=')E8G5I92!S82!F:64@;G5M
M97)I8V$N`$IO:0!4:71L=0!!>FD`36%R`$UA<G1I`%1I<`!.=2!P;W0@=')A
M9'5C92!A8V5S="!D;V-U;65N="!7;W)D("T@9&4@=')A9'5S`$%N=6QE87IA
M(%-C:&EM8F%R:6QE`$EN=&5R9F%T82!U=&EL:7IA=&]R`$]P=&EU;FD@571I
M;&EZ871O<@!5=&EL:7IA=&]R`$%T96YT:64`36EE`$UI97)C=7)I`%-A<'1A
M;6%N80!387!T86UA;F$@)60`4V%P=&%M:6YA;`!387!T86UA;F%L.B!392!R
M97!E=&$@;&$@9FEE8V%R90!":6YE(&%I('9E;FET(&EN('-I<W1E;75L("5S
M`$)I;F4@86D@=F5N:70L("5S`$%D<F5S82!L82!397)V:6-I=0!496QE9F]N
M(&QA(%-E<G9I8VEU`%-A<'1A;6%N82!L=6-R871O87)E`$%!`$%N=6%L`$%N
M=6%L.B!392!R97!E=&$@;&$@9FEE8V%R90!4<F5B=6EE('-A(&1E<V-R:6D@
M<')O8FQE;6$@:6YA:6YT92!D92!A('1R:6UI=&4@<F%P;W)T=6PN`%-E<VEU
M;F5A('1A(&1E("5S(&$@97AP:7)A="X@5&4@<F]G('-A(&9A8VD@3&]G($EN
M(&1I;B!N;W4N`$EN9F]R;6%T:6D@9&5S<')E('1I;F4`3W!T:75N:6QE(&%U
M(&9O<W0@<V%L=F%T92X`6U)A<&]R="!0<F]B;&5M85T`6VQI;FEA("5S(&1I
M;B`E<UT`>FD`>FDH;&4I`'II;&4`;'5N82AI*0!I;B!A8V5E87-I(&1A=&$`
M:6X@86-E96%S:2!Z:2!A('-A<'1A;6%N:6D`=D-A<F0@+2!D92!T<F%D=7,`
M<V%P=&%M86YA`'-A<'1A;6%N82AI*2!L83H`<V%P=&%M86YI`&%N*&DI````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O<G5?4E4O````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3(`
M,#(P-S(W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L
M92]R=5]252],0U]-15-304=%4R\`````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<U,@`P,C(U,30`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]K<F]N;VQI=&@O;&]C86QE+W)U7U)5+TQ#7TU%4U-!1T53+VMR;VYO;&ET
M:"YM;P```````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#4U,S<U`#$P-#$W,S8R-S4R`#`R-3`W-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`(P!```<````?`P``!T"``#<&````````%`A```H````42$``!T```!Z(0``
M#@```)@A```.````IR$```@```"V(0``!0```+\A```3````Q2$```D```#9
M(0``"0```.,A```/````[2$```@```#](0``)`````8B```'````*R(``"P`
M```S(@``#@```&`B```%````;R(```H```!U(@``%````(`B```*````E2(`
M``4```"@(@```P```*8B```7````JB(```H```#"(@``#P```,TB```'````
MW2(```T```#E(@``"@```/,B```C````_B(``!0````B(P``%P```#<C```7
M````3R,``!\```!G(P``"P```(<C```5````DR,```4```"I(P``.0```*\C
M```"````Z2,``"P```#L(P``*@```!DD```&````1"0``!$```!+)```"```
M`%TD```.````9B0```H```!U)```!@```(`D```5````AR0``!4```"=)```
M"````+,D```*````O"0``%0```#')```1````!PE```3````824``!P```!U
M)0``#````)(E```0````GR4```<```"P)0``'0```+@E```;````UB4``"D`
M``#R)0``$@```!PF```0````+R8``!,```!`)@``!P```%0F```,````7"8`
M`"@```!I)@```@```)(F```%````E28``!,```";)@``!````*\F```#````
MM"8```8```"X)@``"````+\F```-````R"8``!````#6)@``!@```.<F```)
M````[B8```P```#X)@``&`````4G``!<````'B<``!0```![)P``"P```)`G
M```O````G"<```D```#,)P``%@```-8G```/````[2<``"8```#])P``0P``
M`"0H```(````:"@```L```!Q*```!P```'TH```(````A2@```0```".*```
M!P```),H```*````FR@``!<```"F*```$0```+XH```%````T"@```T```#6
M*```(````.0H```(````!2D```8````.*0``"````!4I```%````'BD``!``
M```D*0``#P```#4I```0````12D```\```!6*0``"P```&8I```/````<BD`
M``P```""*0``#P```(\I```&````GRD```8```"F*0``#P```*TI```>````
MO2D``"$```#<*0```P```/XI```(`````BH```0````+*@``#````!`J```'
M````'2H```(````E*@``!@```"@J```0````+RH```8```!`*@``!````$<J
M```.````3"H```(```!;*@``#0```%XJ```&````;"H``!$```!S*@``!P``
M`(4J```$````C2H```H```"2*@``(@```)TJ```%````P"H```0```#&*@``
M#````,LJ```*````V"H```4```#C*@``!P```.DJ```*````\2H```\```#\
M*@``$`````PK```&````'2L```\````D*P``%@```#0K```2````2RL``!``
M``!>*P``$````&\K```'````@"L```0```"(*P``!````(TK```(````DBL`
M``<```";*P``"````*,K```.````K"L``!8```"[*P``$0```-(K```)````
MY"L```8```#N*P``'@```/4K```0````%"P```\````E+```"````#4L```&
M````/BP```<```!%+```!0```$TL```+````4RP```(```!?+```!````&(L
M``!H````9RP```4```#0+```#P```-8L```#````YBP```<```#J+```"@``
M`/(L```'````_2P```D````%+0```@````\M```&````$BT```4````9+0``
M!P```!\M```5````)RT```L````]+0``"0```$DM```)````4RT```H```!=
M+0``!P```&@M```)````<"T```<```!Z+0``"@```((M```6````C2T```4`
M``"D+0``#````*HM```)````MRT```0```#!+0``"@```,8M```(````T2T`
M``P```#:+0``"0```.<M```+````\2T```D```#]+0``!`````<N```3````
M#"X```4````@+@``"````"8N```"````+RX```<````R+@``!P```#HN```.
M````0BX```H```!1+@``$0```%PN```(````;BX```D```!W+@``"@```($N
M```'````C"X``!X```"4+@``*````+,N```>````W"X```H```#[+@``%```
M``8O```%````&R\``"D````A+P``*````$LO```I````="\```P```">+P``
M$````*LO```'````O"\``!,```#$+P``!````-@O```+````W2\```\```#I
M+P``$P```/DO```3````#3````\````A,```#````#$P```.````/C````T`
M``!-,```#0```%LP```'````:3```!X```!Q,```%````)`P```.````I3``
M`"H```"T,```!@```-\P```,````YC````L```#S,```!0```/\P```1````
M!3$``!$````7,0``&````"DQ```$````0C$```(```!',0``"````$HQ```+
M````4S$```H```!?,0``#````&HQ```/````=S$```H```"',0``6````)(Q
M```+````ZS$``!H```#W,0``%P```!(R```:````*C(``!D```!%,@``)P``
M`%\R```7````AS(``!T```"?,@``&P```+TR```9````V3(``!\```#S,@``
M$P```!,S```)````)S,``#\````Q,P``-P```'$S``!7````J3,```4````!
M-```#0````<T```M````%30```0```!#-```'P```$@T```E````:#0``"@`
M``".-```'P```+<T```=````US0```8```#U-```!````/PT```0`````34`
M`!,````2-0``%P```"8U```*````/C4```@```!)-0``"@```%(U```"````
M734```<```!@-0``!@```&@U```'````;S4``#0```!W-0``%0```*PU```&
M````PC4```X```#)-0``!0```-@U```)````WC4```(```#H-0``+P```.LU
M```A````&S8``!\````]-@``'P```%TV```P````?38``"\```"N-@``'P``
M`-XV```A````_C8``!P````@-P``"````#TW```'````1C<```L```!.-P``
M!0```%HW```"````8#<``%D```!C-P``!0```+TW```"````PS<```<```#&
M-P``!````,XW```F````TS<```P```#Z-P``!@````<X```R````#C@```0`
M``!!.```#@```$8X```,````53@```@```!B.```"0```&LX```*````=3@`
M``<```"`.```&0```(@X```'````HC@```(```"J.````P```*TX```)````
ML3@```0```"[.```!P```,`X```'````R#@```8```#0.```%````-<X```-
M````[#@```L```#Z.```+P````8Y``!(````-CD``$P```!_.0``#````,PY
M```Q````V3D``#\````+.@``#````$LZ```*````6#H```D```!C.@```@``
M`&TZ```&````<#H``!0```!W.@```P```(PZ```9````D#H``$4```"J.@``
M,````/`Z```2````(3L``!,````T.P``$````$@[```)````63L``!<```!C
M.P``%@```'L[```/````DCL``!\```"B.P``%````,([```0````USL```\`
M``#H.P``#P```/@[```'````"#P```4````0/```"````!8\```(````'SP`
M``P````H/```!@```#4\```&````/#P```,```!#/```!@```$<\```$````
M3CP```0```!3/```"````%@\```0````83P``!,```!R/```!P```(8\```%
M````CCP```0```"4/```"P```)D\```%````I3P```<```"K/```50$``+,\
M```E````"3X``!P````O/@``"@```$P^```*````5SX```<```!B/@``!0``
M`&H^```.````<#X``!````!_/@``"0```)`^```6````FCX```T```"Q/@``
M&````+\^```%````V#X``#,```#>/@``"@```!(_```+````'3\``!`````I
M/P``(0```#H_```1````7#\```D```!N/P```P```'@_```,````?#\```H`
M``")/P``"0```)0_```+````GC\``!(```"J/P``"P```+T_```>````R3\`
M`!,```#H/P``!P```/P_```6````!$```",````;0```"@```#]````)````
M2D````8```!40```0@```%M````!````GD```"0```"@0```*@```,5````&
M````\$````\```#W0```#0````=!```*````%4$```H````@00``!@```"M!
M```8````,D$``!$```!+00``"0```%U!```4````9T$``"$```!\00``/@``
M`)Y!```4````W4$``!@```#R00``#`````M"```+````&$(```@````D0@``
M%0```"U"```>````0T(``"H```!B0@``%0```(U"```5````HT(```D```"Y
M0@``!P```,-"```-````RT(``"(```#90@```@```/Q"```)````_T(``!4`
M```)0P``!````!]#```$````)$,```D````I0P``!P```#-#```1````.T,`
M`!0```!-0P``!P```&)#```*````:D,```\```!U0P``&0```(5#``!2````
MGT,``!````#R0P``"`````-$```V````#$0```<```!#1```)@```$M$```2
M````<D0``"P```"%1```00```+)$```)````]$0```P```#^1```!@````M%
M```,````$D4```T````?10``$````"U%```-````/D4``!4```!,10``"0``
M`&)%```%````;$4``!(```!R10``+@```(5%```.````M$4```T```##10``
M#P```-%%```&````X44```\```#H10``#P```/A%```0````"$8```X````9
M1@``%````"A&```.````/48```T```!,1@``$````%I&```)````:T8```<`
M``!U1@``&````'U&```C````ED8``"4```"Z1@``!````.!&```'````Y48`
M``0```#M1@``"0```/)&```'````_$8```(````$1P``!P````='```9````
M#T<```<````I1P``!````#%'```&````-D<```<````]1P``#@```$5'```&
M````5$<```4```!;1P``"0```&%'```)````:T<```D```!U1P``-````']'
M```&````M$<```8```"[1P``#@```,)'```0````T4<```8```#B1P``"0``
M`.E'```-````\T<``!`````!2```#````!)(```(````'T@```X````H2```
M&````#=(```6````4$@``!,```!G2```#````'M(```&````B$@```0```"/
M2```!````)1(```.````F4@```D```"H2```!````+)(```7````MT@``"<`
M``#/2```'P```/=(```.````%TD```4````F20``,@```"Q)```9````7TD`
M``L```!Y20``#````(5)```$````DDD```4```"720``#@```)U)```$````
MK$D```(```"Q20``!0```+1)```R````NDD```0```#M20``$````/))```#
M`````TH```<````'2@``"P````]*```)````&TH```D````E2@```@```"]*
M```+````,DH```4````^2@``"@```$1*```6````3TH```D```!F2@``$```
M`'!*```1````@4H``!(```"32@``$0```*9*```0````N$H``!$```#)2@``
M#@```-M*```/````ZDH```<```#Z2@``#P````)+```-````$DL```<````@
M2P``#P```"A+```.````.$L``!(```!'2P``$````%I+```2````:TL```T`
M``!^2P```P```(Q+```2````D$L```<```"C2P``!@```*M+```"````LDL`
M``<```"U2P``"0```+U+```1````QTL```H```#92P``$0```.1+```&````
M]DL```8```#]2P``!@````1,```'````"TP``"`````33```-````#1,```=
M````:4P```4```"'3```!@```(U,```'````E$P``"$```"<3```(P```+Y,
M```R````XDP```\````530``$P```"5-```)````.4T``!$```!#30``!@``
M`%5-```)````7$T```X```!F30``%@```'5-```0````C$T```L```"=30``
M"0```*E-```*````LTT```L```"^30``"````,I-```(````TTT``",```#<
M30``%0````!.```0````%DX``"<````G3@``!P```$].```,````5TX```P`
M``!D3@``"````'%.```/````>DX``!8```"*3@``'P```*%.```(````P4X`
M``(```#*3@``!P```,U.```3````U4X``!$```#I3@``$P```/M.```/````
M#T\```L````?3P``5@```"M/```.````@D\``"````"13P``%0```+)/```9
M````R$\``!0```#B3P``'P```/=/```D````%U```"D````\4```'@```&90
M```3````A5```!````"94```'````*I0```(````QU```$T```#04```10``
M`!Y1``!,````9%$```H```"Q40``$@```+Q1```F````SU$```@```#V40``
M*0```/]1```I````*5(``"@```!34@``(@```'Q2```9````GU(```8```"Y
M4@``!@```,!2```4````QU(```\```#<4@``$P```.Q2```+`````%,```H`
M```,4P``#````!=3```"````)%,```0````G4P``!@```"Q3```'````,U,`
M`"@````[4P``(@```&13```+````AU,``!0```"34P``!@```*A3```,````
MKU,```(```"\4P``+0```+]3```4````[5,``!0````"5```%P```!=4```W
M````+U0``"L```!G5```(````)-4```G````M%0``"````#<5```!P```/U4
M```'````!54``!(````-50``"0```"!5```$````*E4``$,````O50``!P``
M`'-5```"````>U4```<```!^50```P```(95```K````BE4``!(```"V50``
M"0```,E5``!(````TU4```P````<5@``&@```"E6```6````1%8``!````!;
M5@``$````&Q6```0````?58```L```".5@``%0```)I6```(````L%8```(`
M``"Y5@```P```+Q6```%````P%8```8```#&5@``"0```,U6```)````UU8`
M``L```#A5@``%P```.U6```5````!5<``!0````;5P``)0```#!7``!<````
M5E<``%L```"S5P``!`````]8```Q````%%@``#H```!&6```#0```(%8```/
M````CU@```X```"?6````@```*Y8```(````L5@``!0```"Z6````@```,]8
M```4````TE@``$@```#G6```00```#!9```*````<ED``!8```!]60``#P``
M`)19```)````I%D```P```"N60``&0```+M9```)````U5D``!X```#?60``
M$0```/Y9```6````$%H``!$````G6@``"@```#E:```&````1%H```8```!+
M6@``!0```%):```)````6%H```4```!B6@``"@```&A:```,````<UH```0`
M``"`6@``"0```(5:```#````CUH```<```"36@``"````)M:```-````I%H`
M`!0```"R6@``#P```,=:```%````UUH```8```#=6@``"@```.1:```&````
M[UH```8```#V6@```0```.````!O`0``E````(4```#:````9``````````C
M````*P`````````Y````%0$````````-`0``8@```%L!``"@````@P$`````
M``!C````!P$``````````````````.(```!`````70```/8```!%`0``````
M``````"*`````````,<```!,`0``T@````````""`````````)X```#&````
M-`$````````*`0``B`$``%<!````````$0$````````H`````````/<```!F
M````(@```````````````````%$!``!*``````````````"A````5@``````
M```;`0``&@$``,L`````````HP```!X!```3````$@```$$!```F````VP``
M``````"N`````````"4`````````:0```!8```!2`0``[@```+0```"(````
M```````````\`0``)P`````````1````LP```.0```"E````$P$``/D```!M
M`0``1P$``*P`````````FP``````````````>`$``"H!```?````;@```"D!
M``"P`````````"D`````````Q`````8````O``````````````#T````````
M`(\````]`0```````-T````D````70$``!````!?`````````'D`````````
M(P$``*<`````````4P`````````%`0``#`$``&H````^````>`````````#K
M````?P$``&L!``!'``````````````#C`````````$0!```@````0P````D!
M````````A@$``'0```!2````@````````````````````%H```#/````@0``
M`$$````(`0````````````!I`0``+````(8`````````'`$``-<````P````
M:`$``.\`````````U0```*(```!4`0``50```*T````U`0```````*\```!A
M````"P````(`````````T````!D```"$`0``'P$``*H````9`0``+@$``)<`
M``![`0``,P$``,@```"2````Z@```#T`````````W````!@!````````````
M`$L!```H`0``F0```+L````O`0``90````````!>```````````````X````
M$@$``(`!``"=````'````$\```"K`````````+8````>````-P$``"T!```4
M````MP``````````````F@```.<```"?````P@````````!]````]0``````
M`````````````'P````D`0``2@$``#`!```5````>0$```````"-````#P$`
M`#@!``#1`````````#$!``!<`0``-````,D`````````30``````````````
M+`$``$T!```#````?@$``&(!``!+````"P$```````#``````P$``(P````^
M`0``S0```'H!````````R@```$(```"6````O````&``````````C`$`````
M``##````=P$``(0```#.````?0$```````!C`0``_````!L```!V`0``?`$`
M`$\!````````8`$``%P```!V`````0$```````!S````>P``````````````
M%@$``(,`````````&````#$```!P````20```)P``````````````+(```#,
M````D0````0!``!F`0``U`````````""`0``Y@```(4!```M`````````!T`
M```=`0``Z0```',!`````````@$```````!?`0``(0```/\`````````````
M`-D```"F````=0$```@````)````B@$```````````````````````!>`0``
M``````````!H````?@```-@```!1````5P```+\```#Z````,@$``%4!``!N
M`0``Z````&H!`````````````$`!``#S``````````\```!Z````[0````0`
M``!D`0```````%0````,````!0`````!```R````60$``.4```!0`0``2```
M``````!W````3@$``/`````*`````````"8!````````\@````<```#^````
M`````(D```!R`0``C@````````"^````=0```$X````[`0``4P$`````````
M````*@```'(`````````(`$```````!G`0``;`$``#8`````````\0```&P`
M````````90$``+D```!6`0```````#,```!(`0``<0$````````.````9P``
M``````!&```````````````K`0``.0$``/T````4`0``D````(<````U````
M&@```.$```!#`0``6`$```````#3````=`$``$D!``!O````WP````````#!
M```````````````0`0``I`````````"Q``````````````!_````````````
M```7`0``)0$```````"!`0``^````)@```#>````.P```(L````7````(0$`
M`#\!```G`0```````#H````W``````````````!0````B0$``+T`````````
M!@$``.P```!9````6````+@```"H````6@$``"X````.`0````````````!,
M`````````$0``````````````%L````\````E0```+H````V`0``Q0``````
M```_`````````&L```!A`0``^P`````````-````10```(L!````````;0``
M`"(!``"U````0@$``),``````````````*D`````````U@```'`!``!&`0``
M`````'$````Z`0``AP$````E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$%-+U!-`$%C
M8V]U;G0@26YF;W)M871I;VX`061D($5V96YT`$%D9"!(97)E.@!!9&0@82!N
M97<@979E;G0`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R`$%D9')E<W,`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`06QA<FT`06QA<FT@
M1&%T90!!;&%R;2!3<&%N("AM:6YU=&5S*0!!;&%R;2!4:6UE`$%L:6%S`$%L
M;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M
M:7-S:6]N<P!!;&P@9&%Y`$%L;"!D87D@979E;G0`06QL(&5V96YT<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;'1E<FYA=&4@24U3
M4"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M90!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P
M<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<')I;`!!<VL@9F]R
M(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<S\`070`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!";&]C
M:R!3971T:6YG<P!";&]C:R!4>7!E`$-A;F-E;`!#86YC96P@4')O8FQE;2!2
M97!O<G0`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A=&5G;W)Y`$-E;&P@4&AO
M;F4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H
M96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#;&]S92!7:6YD;W<`0V]L;&%P
M<V4@4VED96)A<@!#;VUP86YY`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N`$-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S/P!#;W5L9"!N;W0@;W!E
M;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#<F5A=&4@82!.97<@179E
M;G0`0W)E871E(&$@;F5W(&]N90!#<F5A=&]R(%!E<FUI<W-I;VYS`$-U<G)E
M;G0`0W5R<F5N="!4:6UE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L
M;V=O;B!T;R`E<RX`1$0`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E=F5R>0!$871E
M`$1A>0!$87DH<RD`1&5C96UB97(`1&5F875L="!#;VQO<@!$969A=6QT($ED
M96YT:71Y`$1E;&5T90!$96QE=&4@)7,`1&5L971E($5V96YT`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL
M>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L
M(&]R(&%L;"!O8V-U<F5N8V5S/P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$
M:7-P;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$=64Z("5S`$1U<F%T:6]N`$5D:70`161I="`E<P!%9&ET($)L
M;V-K`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z
M`$5M86EL`$5M<'1Y(')E<W5L="X`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\`16YD($1A=&4`16YD($]N`$5N9"!4:6UE`$5R<F]R`$5V97)Y
M(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`
M179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X<&%N9`!%>'!O<G0`17AP
M;W)T($-A;&5N9&%R`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$9E8G)U87)Y
M`$9I;&4`1FEL92!-86YA9V5R`$9I;'1E<G,`1G(`1G)I9&%Y`$9U;&P@1&5S
M8W)I<'1I;VX`1G5T=7)E`$=A;64`1VQO8F%L($]P=&EO;G,`1V\`1V]O9VQE
M(%-E87)C:`!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`2&5A9&5R<P!(96QP
M`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.@!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO
M=7(H<RD`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@0V%L
M96YD87(`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YD
M:79I9'5A;"!5<V5R<P!*86YU87)Y`$IU;'D`2G5N90!+97EW;W)D<P!,85]Y
M;W5T`$QA;F=U86=E`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R
M;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%S="!W965K`$QA>6]U=`!,:6UI
M="!T:&4@=&EM92!S<&%N('1O(&5X<&]R=#H`3&ES="!(96QP(%1O<&EC<P!,
M;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`
M3&]G:6X@5&%S:W,`34T`36%I;`!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O
M<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S
M(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87)C:`!-871C
M:&EN9R!F:65L9',`36%Y`$UE971I;F<`365N=2!M;V1E.@!-97-S86=E`$UI
M;G5T92AS*0!-;P!-;VYD87D`36]N=&@`36]N=&AL>0!-;VYT:&QY.B!296-U
M<G,@979E<GD`36]O;B!0:&%S97,`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E
M(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$YE=F5R`$YE=R!#871E9V]R>0!.97<@
M179E;G0`3F5W<P!.97AT($UO;G1H`$YE>'0@9&%Y`$YE>'0@;W!T:6]N<P!.
M97AT('=E96L`3F\@96YD(&1A=&4`3F\@=F%L=65S`$YO;F4`3F]R=&AE<FX@
M2&5M:7-P:&5R90!.;W1E<P!.;W9E;6)E<@!/2P!/8W1O8F5R`$]P=&EO;G,`
M3W!T:6]N<R!F;W(@)7,`3W)G86YI>FEN9P!/=&AE<B!);F9O<FUA=&EO;@!0
M87-S=V]R9`!087-S=V]R9#H`4&%S<W=O<F0Z(`!0871T97)N`%!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUA;F5N=&QY(&1E;&5T92!T:&ES(&5V
M96YT/P!097)M:7-S:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4')E=FEO=7,@9&%Y
M`%!R979I;W5S(&]P=&EO;G,`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N
M`%)E860`4F5C=7(@56YT:6P`4F5C=7)R96YC92!$871A`%)E8W5R<F5N8V4@
M16YD($1A=&4`4F5C=7)R96YC92!);G1E<G9A;`!296-U<G)E;F-E(%1Y<&4`
M4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`4F5C
M=7)S('EE87)L>0!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296UO=&4@4V5R=F5R<P!296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E
M`%)E;6]V92!";&]C:P!296UO=F4@<&%I<@!297-E=`!297-E="!T;R!$969A
M=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,`4F]L90!380!3871U<F1A>0!3879E($%S($YE=P!3879E($5V96YT`%-A
M=F4@3W!T:6]N<P!396QE8W0@82!S97)V97(`4V5L96-T(&%L;`!396QE8W0@
M8V]N9FER;6%T:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F
M97)E;G0@=FEE=W,@86YD(&-H;V]S92!D969A=6QT('9I97<N`%-E;&5C="!N
M;VYE`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T
M92!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T
M:&4@9FER<W0@=V5E:V1A>3H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T
M:&4@=&EM92!S<&%N('1O('-H;W<Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!397!T96UB
M97(`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-H;W)T(%-U
M;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@
M;&EN:W,_`%-H;W<`4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R/P!3
M:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;VYL
M>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\`4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/P!3:')I;FL`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-O=71H97)N($AE
M;6ES<&AE<F4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W1A<G0@1&%T90!3
M=&%R="!/;@!3=&%R="!4:6UE`%-U`%-U8FIE8W0`4W5B;6ET`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5N9&%Y`%-U;G)I<V4O
M4W5N<V5T`%1A<VMS`%1E>'0@3VYL>0!4:`!4:&4@96YD(&1A=&4@;75S="!B
M92!L871E<B!T:&%N('1H92!S=&%R="!D871E+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4
M:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N`%1H=7)S9&%Y`%1I8VME=',`5&EM92!F;W)M870`5&ET;&4`5&\`5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D
M87D`5'4`5'5E<V1A>0!4>7!E`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<&1A=&4`57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5
M<V5R($EN=&5R9F%C90!5<V5R($]P=&EO;G,`57-E<FYA;64`57-E<FYA;64Z
M`%5S97)N86UE.B``5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%=A<FYI;F<`5V4`5V5B`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E:RAS
M*0!7965K;'D`5V5E:VQY.B!296-U<G,@979E<GD`5V5L8V]M92!T;R`E<P!7
M96QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V
M:65W<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\`5VAA
M="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@<W1A<G0L('=H96X@
M=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/P!7:&EC:"!P:&%S97,`5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+@!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F
M96-T(&]N(&YE>'0@;&]G+6EN*3H`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`
M5V]R:R!7965K`%E9`%EE87)L>0!996%R;'DZ(%)E8W5R<R!E=F5R>0!997,`
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!.86UE`%EO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA
M;64Z`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!R96UO
M=&4@<V5R=F5R<SH`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`
M7T%D;6EN:7-T<F%T:6]N`%]'<F]U<',`7TAE;'``7TQO9R!O=70`7T]P=&EO
M;G,`7U!E<FUI<W-I;VYS`%]3971U<`!?57-E<G,`9&%Y`&1A>2AS*0!D87ES
M`&5D:70`;6]N=&@H<RD`;VX@=&AE('-A;64@9&%T90!O;B!T:&4@<V%M92!W
M965K9&%Y`'5N;F%M960`=D-A<F0`=V5E:P!W965K*',I(&]N.@!W965K<P!Y
M96%R*',I`%!R;VIE8W0M260M5F5R<VEO;CH@2W)O;F]L:71H('8Q+C`*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO
M;BU$871E.B`R,#`R+3$Q+3$P(#$W.C0U*S`S,#`*3&%S="U4<F%N<VQA=&]R
M.B!&961O<B!!+B!&971I<V]V(#QF869`<W-C+G)U/@I,86YG=6%G92U496%M
M.B!&961O<B!!+B!&971I<V]V(#QF869`<W-C+G)U/@I-24U%+59E<G-I;VXZ
M(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0U`Q,C4Q
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`,[OY?#@]NC_(._N
MY.3E\.;JZ"`E<R`M(,_NY/+BY?#FY.7MZ.4`U.#IZR`E<R#S\>_E^.WN(.CL
M[^[P\NCP[N+@[0`Q,BWWX/'NXN[I`#(T+??@\>[B[ND`,C0@]^#QX`!!32]0
M30#3]^7R[>#_(.?@[^CQ_`#$[N'@XNCR_"#Q[N'[\NCE`,3NX>#BZ/+\.@#$
M[N'@XNCR_"#M[N+NY2#Q[N'[\NCE`,3NX>#BZ/+\(._@\/,`Q.[AX.+H\OP@
M36]Z:6QL82!3:61E8F%R`,#D\.7Q`,W@\?+P[NGJZ"`M(//Q\N#M[N+JX"#O
M\.#B(.3K_R#D\//CZ/4@[^[K_.?NXN#RY>OEZ0#3[_#@XNOE[>CE`,W@[^[L
MZ.W@[>CE`,3@\N`@[>#O[NSH[>#MZ/\`Q.OH\N7K_.WN\?+\(.W@[^[LZ.W@
M[>C_("CLZ.WS\OLI`,+PY>S_(.W@[^[LZ.W@[>C_`,_QY>+D[NWH[`#"\>4`
MPO'E(.+N^.7D^.CE`,+QY2#C\//O[_L`PO'E(._PX.+@`,K@YN3[Z2#DY>W\
M`,7FY>3MY>+M[N4@\>[A^_+HY0#"\>4@\>[A^_+H_P#0X.?PY?CH\OP@[N_E
M\.#VZ.@@\>X@\>_H\>K@[.@`P.O\\N7P[>#RZ.+M^^D@25--4`#/X/#NZ_PZ
M`,CL_R#O[NO\Y^[BX/+EZ_\@25--4#H`P?OK[B#SZN#GX.WN(.WEZN[P\.7J
M\NWNY2#G[>#WY>WHY2X`S_#HZ^[FY>WHY0#-X/'R\.[E[>X`P._PY>O\`,?@
M[_#@^.CBX/+\(._NY/+BY?#FY.7MZ.4@[^7PY>0@XOOO[NOMY>WHY>P@[N_E
M\.#VZ.D@[N'QZ_/FZ.+@[>C_/P#"`,_N[_ORZN`@\^3@Z^CR_"#MY?'S^>7Q
M\N+S_OGHY2#O\.#BX`#/[N_[\NK@(/#EY.#J\NCP[N+@\OP@[>7Q\_GE\?+B
M\_[YZ.4@[_#@XN``P.+C\_'R`,3N\?+S[^W[Y2#O[NO_.@#$Y>W\(/#NYN3E
M[>C_`,W@\?+P[NGJX#H`T.#Q^.CPY>WHY0#.\NSE[>``SO+LY>W@(.[R]^7R
MX"#N(._P[N'KY>SE`,K@\N7C[O#HZ"#H(.SE\NKH`,K@\N7C[O#H_P#*Z^7R
M[O?MX/\@\.#DZ.[QXO_G_`#-X/'R\.[IZN@@Z.SE[>@L(.#D\.7QX"P@[^[D
M[^CQZ"X`SO+LY?+\\N4@].O@YNK@[.@@[N_E\.#VZ/XHZ.@I+"#J[O+N\/OE
M(,+[(/7N\NCRY2#N\?/YY?'RXNCR_"X`POOAY?#H\N4@[_#HZ^[FY>WHY3H`
MU.[P[.#R(.[R[N'PX.;E[>C_(.3@\OLZ`,?@ZO#[\OP@[NKM[@#3X?#@\OP@
M[.7M_@#*[NSOX.WH_P#*[NWTZ./S\.#VZ/\@\_'RX/#EZ^``S^[D\N+E\.;D
MY>WHY2#SY.#KY>WH_R#Q[N'[\NCI`,WE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@
M36%I;G1E;F%N8V5?5&%S:R`E<P#1[N?DX/+\(.WNXN[E(/'NX?ORZ.4`T>[G
MY.#R_"#M[N+[Z2#O\.[TZ.O\`-'NY^3@\N7K_`#2Y>KS^>7E`-+EZO/YY>4@
MXO#E[/\`Q^#DX/?H+"#GX._S\>K@Y>S[Y2#O\.@@XO7NY.4@XB`E<P#$Q`#%
MYN7D[>7B[>X`S^[B\N[P_^7R\?\@Y>;EY.WEXNWN`,3@\N``Q.7M_`#$Y>W\
M*.3MZ"D`Q.7JX.'P_`#6XN7R(._N(//L[NOWX.WH_@#/\.[TZ.O\(._N(//L
M[NOWX.WH_@#3Y.#KZ/+\`-/DX.OH\OP@)7,`T^3@Z^CR_"#Q[N'[\NCE`-/D
MX.OH\OP@XOOA\.#M[?OI(._P[O3HZ_P`T^3@Z^CR_"#R[NO\ZNX@Y.#M[>[E
M(/'NX?ORZ.4L(/WR[B#Q[N'[\NCE(.@@XO'E(.'SY//YZ.4@\>[A^_+H_RP@
MZ.OH(.+QY2#Q[N'[\NC_/P#.[^CXZ/+E(._P[N'KY>SS`,[OZ/'@[>CE`,_N
MY/#NX>WN\?+H(.'[Z^@@Y^#OZ/'@[?L@XB#F\_#MX.L@Y.O_(.#D[.CMZ/'R
M\.#R[O#@+@#*X/+@Z^[C`,[R[N'PX.;@\OP@XO#E[/\@XB`R-"WWX/'NXN[L
M(/3N\.S@\N4_`,W@\?+P[NGJZ"#NX>[K[O?JZ`#-Y2#B^^?[XN#I\N4@;6%I
M;G1E;F%N8V4N<&AP(.WE[^[Q\.7D\?+BY>WM[@#"(._E\.+NZ2#Q\O#NZN4@
M\^K@Y^#M^R#H[.7MX"#O[NOEZ3\@Q?'KZ"#DX"P@[^[Q\N#B_/+E(./@Z^[W
MZO,Z(`#'X./P\^?H\OP`Q^#C\//GZ/+\("5S`,3N.B`E<P#$Z^CRY>O\[>[Q
M\OP`T.7DX.KRZ/#NXN#R_`#0Y>3@ZO+H\.[BX/+\("5S`-#EY.#J\NCP[N+@
M\OP`T_'RX.WNXNK@(._PX.(@Y.O_("5S`,W@\?+P[NGJZ`!%;6%I;`#-\^OE
MXN[I(/#EY_/K_/+@\BX`RN[M\N7J\?+M[N4@[.7M_B#O[B#MX.;@\NCH(._P
MX.+NZ2#J[>[OZN@@[/OXZ`#$X/+@(.[J[NWWX.WH_P#'X.K@[??HXN#E\O'_
M`,+PY>S_(.[J[NWWX.WH_P#.^.CAZN``RN#FY/OE(#$U(.SH[?/R`,K@YN3[
MY2`R(.SH[?/R^P#*X.;D^^4@,S`@\>7J\^WD`,K@YN3[Y2`U(.SH[?/R`,K@
MYN3[Z2#PX.<@[_#H(.+U[N3E`,K@YN3[Y2#O[NOWX/'@`,K@YN3S_B#LZ.WS
M\O,`S_#H[.7P(.?MX/?E[>CI.@#0X/'XZ/#H\OP`W>KQ[^[P\@#=ZO'O[O#R
MZ/#NXN#R_"#JX.OE[>3@\/P`PN[Q\?+@[>[BZ^7MZ.4@[>#Q\O#NY>H@[>4@
M\^3@Z^[Q_"X`S>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0
M+@#4X.KQ`-3EXO#@Z_P`U.#IZP#5\.#MZ.OH^>``U.CK_/+P^P#/\@#/__+M
MZ/;@`,_NZ^WNY2#N[^CQX.WHY2#O\.[AZ^7L^SH`P?/D\_GEY0#(X_#@`,_N
M\/+@ZP#/Y?#EZ?+H`,_NZ/'J(.(@1V]O9VQE`,/P\^_O^P##[O'R_`#'X./N
MZ^[BZN@`S^[D\>K@Y^K@`,_NZ_/XX/#HY0#-Z.;E(._PY>3Q\N#BZ^7MX"#H
M[?3N\.S@]NC_(.CG(/'@[.[C[B#MX/?@Z^`@].#IZ^`Z`,_N\/+@ZP#/[O#R
MX.L`Q.[LX/CMZ.D@X.3PY?$`Q.[LX/CMZ.D@\N7KY?3N[0#/[O#RX.L`U^#Q
M*/?@\?LI`-+NZ_SJ[B#HZN[MZN@`R.KN[>KH(/$@\N7J\?+N[`#([/\@[_#N
M].CK_SH`RN#P\NCMZN@`R.SO[O#R+"#XX.,@)60`R.SO[O#R+]WJ\>_N\/(@
MZN#KY>WDX/#_`,CL[^[P\NCP[N+@[>X@[^[KY3H@)7,`R.SO[O#RZ/#NXN#M
M^R#O[NO_.@#/[NO\Y^[BX/+EZ^@`W^WBX/#\`,C^Z_P`R/[M_`#*Z_[WY>+[
MY2#QZ^[BX`#0X/'JZ^#DZN``W^?[Z@#/\.7D^^3S^>CI(.+U[N0@X?OK.B`E
M<P#/\.7D^^3S^>CI(.+U[N0@X?OK.B`E<R#Q(.KN[._\_O+E\.`@)7,`S_#E
MY/OD\_GHZ2#B]>[D(.WE(.?@].CJ\>CP[N+@[0#/\.[XZ^#_(.WEY.7K_P#"
M^_7NY`#.X_#@[>CWY>WHY2#]ZO'O[O#RZ/#SY>SNX^X@XO#E[.7M[>[C[B#O
M\.[LY>;S\NK@.@#1[^CQ[NH@\.#GY.7K[N(@[^[D\>K@Y^KH`,ONZN#KZ.?@
M]NC_`-#@\>_NZ^[FY>WHY0#"]>[D`,+[]>[D`-/WY?+MX/\@Y^#OZ/'\`,+U
M[N0`S,P`S^[W\N``S>#Q\O#NZ>K@(/'OZ/'JX"#JX/+EX^[PZ.D@Z"#VXN7R
M[N(@Z/4@[O+NX?#@YN7MZ/\`S.#P\@#1[N+OX.3@_OGHY2#O[NO_`,S@Z0#"
M\?+PY??@`-#EYNCL(.SE[?XZ`-'N[N'YY>WHY0#,Z.WS\N`H^RD`S^T`S^[M
MY>3EZ_SMZ.H`S.7Q__8`Q>;E[.7Q__?M[@#/[N+R[O#_Y?+Q_R#EYN7LY?'_
M]^WN`-3@Y_L@R_/M^P#OY?#E[.7Q\NCR_"#B[>CG`._E\.7LY?'RZ/+\(.+K
MY>+N`._E\.7LY?'RZ/+\(.+O\.#B[@#OY?#E[.7Q\NCR_"#BXN7P]0#OY?#E
M[.7Q\NCR_"#B[>CG`._E\.7LY?'RZ/+\(.+BY?#U`-/WY?+MX/\@Y^#OZ/'\
M`,+@^.`@Z.WT[O#LX/;H_P#-Z.KNX^3@`,WNXN#_(.K@\N7C[O#H_P#-[N+N
MY2#Q[N'[\NCE`,WNXN[Q\N@`T>OEY//^^>CI(.SE\?_V`-'KY>3S_OGHZ2#D
MY>W\`-'KY>3S_OG@_R#Q\O#@[>CVX`#1Z^7D\_[YX/\@[>7DY>O_`,WE\B#D
MX/+[(.[J[NWWX.WH_P#-Y2#N[_#EY.7KY>WN`,WE\@#1Y>+E\.WNY2#O[NOS
M^.#PZ.4`Q^#LY?+JZ`#-[O_A\/P`3TL`SNKR_^'P_`#-X/'R\.[IZN@`S>#Q
M\O#NZ>KH(.3K_SH@)7,`SO#CX.W@Z>?E\`#/\.[WX/\@Z.WT[O#LX/;H_P#/
MX/#NZ_P`S^#P[NO\`,_@\.[K_`#.X?#@Y^7V`,[Q\_GE\?+BZ^7MZ.4@[N_E
M\.#VZ.D@[^[DY.7PYNKH`,+[[^[K[>CR_"#N[^7PX/;HZ"#NX?'K\^;HXN#M
MZ/\@[_#H(.+U[N3E(.(@\>CQ\N7L\S\`S>#B\>7CY.`@\^3@Z^CR_"#]\NX@
M\>[A^_+HY3\`S_#@XN``R^CW[?OE`-+EZ^7T[NT`PN+EY.CRY2#MX.?BX.WH
MY2#M[N+NZ2#JX/+EX^[PZ.@Z`,_NYN#K\^GQ\N`L(/'N[N'YZ/+E(/'S\OP@
M[_#NX>OE[/LN`,_NYN#K\^GQ\N`L(.+BY>3H\N4@PN#XZ"#H[/\@[^[K_.?N
MXN#RY>O_(.@@[^#P[NO\`,_PY>3[Y//YZ.D@Y.7M_`#/\.7D^^3S^>#_(/'R
M\.#MZ/;@`,_P[N'KY>S@/P#.[^CQX.WHY2#O\.[AZ^7L^P#7Z/+@\OP`S^[B
M\N[P(.3N`,3@[>W[Y2#O[N+R[O#@`,3@\N`@[NKN[??@[>C_(._NXO+N\.``
MR.WRY?#BX.L@[^[B\N[PX`#2Z.\@[^[B\N[PX`#%YN7D[>7B[>X`Q>;E[.7Q
M__?M[@#%YN7MY>3EZ_SM[@#%YN7C[N3M[@#.X>WNXNCR_`#.X>WNXNO_\OP@
MY.CMX.SH]^7QZNCE(._S[>KR^R#LY>W^.@#.X>WNXNO_\OP@Z.WT[O#LX/;H
M_CH`S^[W\N[B^^4@\>7PXN7PX`#`Y/#E\2#QY?#BY?#@("CMX._PZ.SE\"!H
M='1P.B\O;6%I;"YR=2D`T^3@Z^CR_`#3Y.#KZ/+\(.'K[NH`T^3@Z^CR_"#O
MX/#S`-'A\.[QZ/+\`-'A\.[Q(//Q\N#M[N+NZ@#"Y?#M\_+\\?\@ZB#MX/'R
M\.[IZN#L`,W@\?+P[NGJZ"#BZ.?SX.O\[>[C[B#PY>3@ZO+N\.``T?;E[>#P
MZ.D`T>$`T?/AX>[RX`#1[O7PX.WH\OP@ZN#J(.WNXN[E`-'N]?#@[>CR_"#Q
M[N'[\NCE`-'N]?#@[>CR_"#MX/'R\.[IZN@`POOAY?#H\N4@\>7PXN7P`,+[
MX?#@\OP@XO'E`,+[X>[P(//Q\N#M[N+NZB#O[N3RXN7PYN3E[>C_+"#JX.H@
M[O+NX?#@YN#R_"#PX.?KZ/?M^^4@XNCD^RP@XOOA[O`@XNCDX"#O[B#S[.[K
M]^#MZ/XN`,[R[.7MZ/+\(.+[X>[P`,+[X>7PZ/+E(/#@Y^3EZ^CRY>O\(._N
MZ^7I(.3@\OLZ`,+[X>7PZ/+E(/3N\.S@\B#DX/+[.@#"^^'E\.CRY2#TX.GK
M(.3K_R#H[._N\/+@`,WEY.7K_R#MX/?H[>#E\O'_(/$Z`,+[X>7PZ/+E(._P
M[O3HZ_P@Y.O_(.W@\?+P[NGJZ#H`POOAY?#H\N4@[O+NX?#@YN7MZ/\@].[P
M[.#R(.+PY>SE[>@Z`,+[X>7PZ/+E(.[R[N'PX.;@Y>S[Z2#O\.[LY>;S\N[J
M(.+PY>SE[>@Z`,+[X>7PZ/+E(.3BX"#Q[N+OX.3@_OGH]2#O[NO_+@#"X/C@
M(/;BY?+NXN#_(/'UY>S@`-_G^^H@[O+NX?#@YN7MZ/\`S^[QZ^#R_"#Q[N[A
M^>7MZ.4@[B#O\.[AZ^7LY0#1Y>WR_^'P_`#$[N_NZ^WH\N7K_.W[Y2#O[O?R
M[N+[Y2#QY?#BY?#@+"#J(.KN\N[P^^P@XOL@]>[RZ/+E(.CLY?+\(.3N\?+S
M[R#HYR#/[O#RX.O@+@#3\?+@[>[BZN`@_^?[ZN`@XOOB[N3@+"#B\.7LY>WM
M[ND@Y^[M^R#H(/3N\.S@\N`@[O+NX?#@YN7MZ/\@XO#E[.7MZ"X`T_'RX.WN
MXNK@(._PZ.ONYN7MZ/\@[^X@\^SNZ_?@[>C^+"#VXN7R[N+NZ2#Q]>7L^R#H
M(._P[O?H]2#N[_;HZ2#N\N[A\.#FY>WH_P#/\.CK[N;E[>C_`,KPX/+J[N4@
M[N'NX?GE[>CE.@#.[_#EY.7KZ/+\(.'[\?+P^^4@ZNO@XNCXZ"#DZ_\@\?'[
MZ^[J/P#/[NK@Y^#R_`#/[NK@Y_OBX/+\(.(@ZN#KY>WDX/#E(//Q\N#PY>+X
MZ.4@Y^#DX/?H/P#/[NK@Y_OBX/+\(.CM].[P[.#VZ/X@[B#O\.7D^^3S^>7L
M(.+U[N3E/P#/[NK@Y_OBX/+\(/+NZ_SJ[B#Q[N'[\NC_(/$@[N_NXN7YY>WH
MY>P_`,_NZN#GX/+\(.SE[?X@[N_E\.#VZ.D@\2#RX.'KZ/;@[.@`SO+NX?#@
MYN#R_"#LY>W^("5S(/'KY>+@/P#1\^?H\OP`T.#G[.7P`,_P[N_S\?+H\OP@
M[^[DY.7PYNKS`-[F[>[E(._NZ_/XX/#HY0#1[^7VZ.#K_.W[Y2#QZ.SB[NO[
M`,3@\N`@[>#WX.O@`,W@]^CMX.7R\?\`PO#E[/\@[>#WX.O@`,+Q`-+E[.``
MR/'JX/+\`-/Q[^7X[>X`T?+@\.#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE[>`@
MXB#TX.GK.B`E<P#-[N+@_R#J[NWTZ./S\.#VZ/\@\>[U\.#MY>W@(.(Z("5S
M`,+N\>KPY?'E[?SE`,+PY>S_(.+N\?7NY.`OY^#JX/+@`,?@Y.#WZ`#2[NO\
MZNX@\N7J\?(`U_(`Q.#RX"#NZN[M]^#MZ/\@Y.[KYNW@(.'[\OP@[^[GYN4@
MY.#R^R#MX/?@Z^`N`-'E\.+E\"`E<R#A^^L@\^3@Z^7M`-'E\.+E\"`E<R#A
M^^L@\>[GY.#M`,WE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN`-'N[N'YY>WHY2#B
M(.WEXN7P[>[L(/3N\.S@\N4@Z"#MY2#L[N;E\B#A^_+\(.[R[N'PX.;E[>X`
MSOCHX>K@(._PZ"#N\N[A\.#FY>WHZ"#]\N[I(/?@\?+H(/'N[N'YY>WH_P#1
M[N'[\NC_(.3K_R#]ZO'O[O#RX"#MY2#MX.GDY>W[+@#=\NX@]^CQZ^X@[>4@
M[.[FY?(@X?OR_"#LY>W\^.4@Y>3H[>CV^RX`W?+N(.?MX/?E[>CE(.3NZ^;M
M[B#A^_+\(/?H\>ON["X`U^7RXN7PXP#'X._P[O'[`-3N\.S@\B#N\N[A\.#F
MY>WH_P#'X./NZ^[B[NH`RN[L\P#7\N[A^R#B^^'PX/+\(.WE\>KNZ_SJ[B#]
MZ^7LY>WR[N(L(//DY?#FZ.+@Z?+E(.W@YN#R[ND@ZNO@XNCF\R!#=')L`-'E
MX^[D[?\`PO(`PO+N\.WHZ@#2Z.\`W?+N\B#D[NKS[.7M\B!7;W)D(.WE(.SN
MYN7R(.'[\OP@[^7PY>+EY.7M+@#.\NSE[>CR_"#HY^SE[>7MZ/\`S_#H[.7M
MZ/+\`,CQ[^[K_.?SY?+Q_R#E\>OH(.+@^.@@Z.S_+^_@\.[K_"#DZ_\@24U3
M4"#QY?#BY?#@(.[RZ^CWX/[R\?\@[O(@\N7J\_GH]0#/[NO\Y^[BX/+EZ_P`
MS^[K_.?NXN#RY>O\\>KHZ2#H[?+E\/3EZ?$`S>#Q\O#NZ>KH(._NZ_SG[N+@
M\N7K_P#([/\@[^[K_.?NXN#RY>O_`,CL_R#O[NO\Y^[BX/+EZ_\`R.S_(._N
MZ_SG[N+@\N7K_P#/\.[Q[.[R\"`E<P#/[NK@Y^#R_"#BY>$M\?+PX.WH]O,`
MPNWH[.#MZ.4`T?``PN7A`-'PY>3@`,WEY.7K_P#-Y>3EZ_\@)60`S>7DY>O_
M*.@I`,7FY>WEY.7K_.WN`,_NXO+N\/_E\O'_(.7FY>WEY.7K_.WN`,3NX?#N
M(._NYN#K[N+@\OP@XB`E<P#$[N'P[B#O[N;@Z^[BX/+\+"`E<P#7\NX@[O+N
MX?#@YN#R_"#O[O'KY2#B]>[DX"#B(/'H\?+E[/,Z`,K@ZNCL(.+PY>SE[>7L
M(.?@ZN#M]^CBX/+\(.[R[N'PX.;@\OP@Y.7M_"#HZ^@@[>7DY>O^+"#O\.@@
M[O+Q\_+Q\N+HZ"#A[NOEY2#O[N?D[>CU(/'NX?ORZ.D_`-$@ZN#J[N/N(.+P
MY>SE[>@@[>#WZ.W@\OP@[O+NX?#@YN#R_"#DY>W\(.CKZ"#MY>3EZ_XL(._P
MZ"#N\O'R\_+Q\N+HZ"#A[NOEY2#PX.WMZ/4@\>[A^_+HZ3\`U.#GX`#*X.KH
MY2#N[_;HZ"#A\^3S\B#D[O'R\^_M^R#B(.+HY_/@Z_SM[NP@\.7DX.KR[O#E
M`-CH\.CMX"#LY>W^("5S(/'KY>+@("CA\^3E\B#O\.CLY>WE[>`@[_#H(/'K
MY>3S_OGE["#B]>[DY2D`T.#A[O?HZ2#@Y/#E\0#0X.'N]^CI(/+EZ^7T[NT`
MT.#A[O?@_R#MY>3EZ_\`P\,`Q>;EX^[D[>X`S^[B\N[P_^7R\?\@Y>;EX^[D
M[>X`Q.``POL@XOOXZ^@@Z.<@\>CQ\N7L^RX`POL@Y.[KYNW[(.[OZ/'@\OP@
M[_#NX>OE[/LL(._PY>;DY2#WY>P@\>SNYN7RY2#N\N[QZ^#R_"#Q[N[A^>7M
MZ.4@[B#MY>DN`,+@^.`@)7,@\>7Q\>C_(.?@ZN[M]^CKX/'\+B#/[N;@Z_/I
M\?+@+"#B[NGDZ/+E(.(@\>CQ\N7L\R#GX.WNXNXN`,+@^"!%;6%I;#H`PN#X
M(.#D\.7Q(.[R[_#@XNCRY>O_.@#"X/C@(.CM].[P[.#VZ/\`PN#XY2#H[/\Z
M`-?@\>[B[ND@[^[_\0#"X/@@[_#N].CK_"#O[B#S[.[K]^#MZ/XZ`,+@^.4@
MZ.S_.@#"X/CH(.W@\?+P[NGJZ"#A^^OH(.[A[>[BZ^7M^RX`T?+N\.[M[>CI
M(/'E\.+E\#H`6]'N[N'YY>WHY2#N(._P[N'KY>SE70!;\?+P[NK@("5S(.CG
M("5S70#3[_#@XNOE[>CE`,/P\^_O^P#/[NSN^?P`POOU[N0`S>#Q\O#NZ>KH
M`,_PX.+@`,_PZ.ONYN7MZ/\`S^[K_.?NXN#RY>OH`.3E[?P`Y.7M_"CD[>@I
M`.3MZ`#/\.#BZ/+\`.SE\?_V*/LI`.(@\N[R(.;E(.3E[?P`XB#R[O(@YN4@
MY.7M_"#MY>3EZ^@`\N7J\?(@\>[NX?GE[>C_`'9#87)D`.WEY.7K_P#MY>3E
MZ_\HZ"DZ`.WEY.7KZ`#C[N0H^RD`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+VQO8V%L92]S:U]32R\`````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,@`P,C`W,#4`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+W-K7U-++TQ#7TU%4U-!1T53+P``
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4R`#`R,C0W
M,@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O<VM?
M4TLO3$-?34534T%'15,O:W)O;F]L:71H+FUO````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-C<S,S4`
M,3`T,3<S-C(W-3(`,#(U,#4W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````Q`@``!P````\1@``MPL``%R,````
M````.+L```X````YNP``#P```$B[```-````6+L```@```!FNP``"P```&^[
M```,````>[L```0```"(NP``&````(V[```;````IKL``"T```#"NP``'0``
M`/"[```D````#KP``"D````SO```&0```%V\```F````=[P```P```">O```
M$@```*N\```D````OKP```D```#CO```#P```.V\```+````_;P``!\````)
MO0``#@```"F]```%````.+T``"@````^O0``"````&>]```*````<+T``!4`
M``![O0``$@```)&]```+````I+T```P```"PO0``'0```+V]``"%````V[T`
M``X```!AO@``"@```'"^```-````>[X```X```")O@``$0```)B^```-````
MJKX```P```"XO@``#0```,6^```&````T[X``)0```#:O@``3P```&^_```=
M````O[\``!T```#=OP``"@```/N_```/````!L```!@````6P```#````"_`
M```*````/,````<```!'P```!@```$_````.````5L````H```!EP```"@``
M`'#````.````>\````@```"*P```"@```)/````)````GL```"4```"HP```
M*````,[````D````]\```"8````<P0``+@```$/!```:````<L$``#(```"-
MP0``.````,#!``!4````^<$``%$```!.P@``6@```*#"``!7````^\(``#0`
M``!3PP```@```(C#```)````B\,```T```"5PP``!P```*/#```*````J\,`
M``\```"VPP``!0```,;#```&````S,,``!$```#3PP``"````.7#```)````
M[L,```D```#XPP``"`````+$```E````"\0``"`````QQ```$P```%+$```0
M````9L0```\```!WQ```"@```(?$```0````DL0```,```"CQ```#P```*?$
M```4````M\0```D```#,Q```"0```-;$```-````X,0``!(```#NQ```&0``
M``'%```>````&\4``!D````ZQ0``#P```%3%```/````9,4```T```!TQ0``
M"@```(+%```/````C<4```@```"=Q0``)````*;%```4````R\4``!8```#@
MQ0``"````/?%``!.`````,8``"T```!/Q@``&0```'W&```'````E\8```P`
M``"?Q@``+````*S&```.````V<8```,```#HQ@``#P```.S&```+````_,8`
M``4````(QP``%`````['```5````(\<``!<````YQP``%0```%''```2````
M9\<``!,```!ZQP``%0```(['```3````I,<```H```"XQP``%````,/'```*
M````V,<```<```#CQP``!P```.O'```%````\\<```4```#YQP``"@```/_'
M```#````"L@```T````.R```%P```!S(```*````-,@```H````_R```"```
M`$K(```/````4\@```L```!CR```!P```&_(```-````=\@```H```"%R```
M#@```)#(```8````G\@``",```"XR```#@```-S(```4````Z\@``!<`````
MR0``%P```!C)```7````,,D``!,```!(R0``#P```%S)```.````;,D``!\`
M``![R0``'0```)O)```'````N<D```8```#!R0``"````,C)```/````T<D`
M``8```#AR0``"@```.C)```3````\\D```,````'R@``"P````O*```0````
M%\H``!4````HR@``%0```#[*```'````5,H``!````!<R@``!0```&W*```1
M````<\H```P```"%R@``.P```)+*```X````SLH```D````'RP``!P```!'+
M```#````&<L```4````=RP``$````"/+```)````-,L``!,````^RP``.0``
M`%++```"````C,L``+0```"/RP``)P```$3,```L````;,P``"H```"9S```
M)0```,3,```*````ZLP```D```#US```"@```/_,```&````"LT```D````1
MS0``!P```!O-```O````(\T``#<```!3S0``+@```(O-``!5````NLT``"T`
M```0S@``+0```#[.```]````;,X``#\```"JS@``+0```.K.``!`````&,\`
M`",```!9SP``(P```'W/``!`````H<\``"T```#BSP``,P```!#0```E````
M1-```!4```!JT```&0```(#0```I````FM```"0```#$T```*````.G0```1
M````$M$```H````DT0``#````"_1```*````/-$``!````!'T0``%@```%C1
M```6````;]$```<```"&T0``!P```([1```*````EM$```@```"AT0``)P``
M`*K1```(````TM$```P```#;T0``!P```.C1```'````\-$```8```#XT0``
M!0```/_1```'````!=(```8````-T@``"````!32```I````'=(```X```!'
MT@``"@```%;2```$````8=(```<```!FT@``"0```&[2```&````>-(``!$`
M``!_T@``!P```)'2```6````F=(```0```"PT@``"````+72```&````OM(`
M``T```#%T@``!@```-/2```>````VM(``!$```#YT@``"`````O3```-````
M%-,```P````BTP``!P```"_3```$````-],```,````\TP```P```$#3```7
M````1-,```D```!<TP``$P```&;3```=````>M,```D```"8TP``"````*+3
M```0````J],``!T```"\TP``"0```-K3```;````Y-,```0`````U```"```
M``74```(````#M0``$$````7U```&@```%G4```K````=-0``"````"@U```
M&0```,'4```5````V]0```8```#QU```!@```/C4```5````_]0```D````5
MU0``#0```!_5```8````+=4``"(```!&U0``+@```&G5```=````F-4``"$`
M``"VU0``5````-C5```I````+=8```H```!7U@``!P```&+6```)````:M8`
M`!4```!TU@``"````(K6```.````D]8```H```"BU@``#P```*W6```-````
MO=8```\```#+U@``#0```-O6```)````Z=8```8```#SU@``&````/K6```3
M````$]<``!$````GUP``%````#G7```$````3M<```8```!3UP``%````%K7
M``!4````;]<``&0```#$UP``!````"G8```.````+M@```4````]V```!0``
M`$/8```3````2=@``!$```!=V```$0```&_8```<````@=@``$X```">V```
M10```.W8``!%````,]D``"H```!YV0``-@```*39```^````V]D``#\````:
MV@``'0```%K:```0````>-H``"$```")V@``!0```*O:```3````L=H```L`
M``#%V@``$P```-':```2````Y=H```H```#XV@``#P````/;```-````$]L`
M`!$````AVP``$P```#/;```,````1]L```8```!4VP``#````%O;```&````
M:-L``!<```!OVP``$````(?;```1````F-L```@```"JVP``!0```+/;```,
M````N=L``!````#&VP``!0```-?;```-````W=L```8```#KVP``%@```/+;
M```'````"=P```T````1W```!P```!_<```+````)]P```<````SW```!P``
M`#O<```)````0]P```D```!-W```"@```%?<```9````8MP``#T```!\W```
M'0```+K<```,````V-P``!````#EW```&P```/;<```)````$MT```4````<
MW0``)0```"+=```2````2-T``!,```!;W0``*P```&_=```[````F]T``"``
M``#7W0``"````/C=```V`````=X``"$````XW@``$````%K>```(````:]X`
M``P```!TW@``!@```('>```$````B-X```\```"-W@``#@```)W>``!`````
MK-X```H```#MW@``#0```/C>```?````!M\``!P````FWP``(0```$/?```>
M````9=\``!D```"$WP``'@```)[?```=````O=\``!L```#;WP``(````/??
M```N````&.```"8```!'X```'````&[@```>````B^```!P```"JX```)@``
M`,?@```K````[N```#,````:X0``)@```$[A```K````=>$``#@```"AX0``
M'0```-KA```5````^.$``"\````.X@``(````#[B```2````7^(``"D```!R
MX@``'@```)SB```@````N^(``!(```#<X@``H@```._B```6````DN,``",`
M``"IXP``*````,WC```I````]N,``"@````@Y```'P```$GD```5````:>0`
M`"````!_Y```)0```*#D```H````QN0``"T```#OY```,````!WE``"2````
M3N4``"$```#AY0``%@````/F```<````&N8``"8````WY@``*@```%[F``!!
M````B>8``$0```#+Y@``#````!#G```'````'><```<````EYP``!@```"WG
M```/````-.<``!(```!$YP``#0```%?G```0````9><``!(```!VYP``!P``
M`(GG```3````D><``!(```"EYP``!P```+CG```$````P.<```<```#%YP``
M$````,WG```0````WN<```P```#OYP``#@```/SG```-````"^@```\````9
MZ```$P```"GH```-````/>@``"@```!+Z````P```'3H```-````>.@```8`
M``"&Z```#@```(WH```"````G.@``$D```"?Z```!0```.GH```3````[^@`
M`!`````#Z0``#P```!3I```$````).D```T````IZ0``#@```#?I```#````
M1ND```8```!*Z0``!P```%'I```.````6>D```@```!HZ0``#P```''I```(
M````@>D```\```"*Z0``!P```)KI```0````HND```T```"SZ0``$````,'I
M```-````TND```L```#@Z0``!@```.SI```)````\^D```L```#]Z0``#```
M``GJ```,````%NH```H````CZ@``$0```"[J```9````0.H```L```!:Z@``
M#0```&;J```B````=.H``!L```"7Z@``-````+/J```*````Z.H``!@```#S
MZ@``&0````SK``!<````)NL``!8```"#ZP``(@```)KK```-````O>L```<`
M``#+ZP``#````-/K```4````X.L```L```#UZP``(@````'L```O````).P`
M``L```!4[```"0```&#L```9````:NP```L```"$[```%P```)#L```7````
MJ.P```D```#`[```!P```,KL```6````TNP``!$```#I[```#P```/OL```9
M````"^T``!8````E[0``#@```#SM```8````2^T```@```!D[0``#0```&WM
M```F````>^T``#D```"B[0``#@```-SM``!#````Z^T```@````O[@``$@``
M`#CN```?````2^X```@```!K[@``"P```'3N```O````@.X```X```"P[@``
M!0```+_N```'````Q>X```@```#-[@``!@```-;N```#````W>X```<```#A
M[@``!````.GN```'````[NX```X```#V[@``"@````7O```.````$.\```H`
M```?[P``#P```"KO```0````.N\``!<```!+[P``%0```&/O```.````>>\`
M`!H```"([P``$0```*/O```9````M>\``!<```#/[P``"0```.?O```%````
M\>\```L```#W[P``"@````/P```"````#O````4````1\```#0```!?P```;
M````)?```!<```!!\```%````%GP```)````;O````X```!X\```#0```(?P
M```2````E?````0```"H\```.````*WP```@````YO````@````'\0``!@``
M`!#Q```(````%_$```@````@\0``#@```"GQ``![````./$``!@```"T\0``
M&````,WQ```1````YO$```<```#X\0``!0````#R```8````!O(``!X````?
M\@``&P```#[R```9````6O(``#$```!T\@``&P```*;R```9````PO(``!,`
M``#<\@``!P```/#R```(````^/(```8````!\P``!@````CS```,````#_,`
M``X````<\P``#0```"OS```3````.?,```\```!-\P``'@```%WS```9````
M?/,``!````"6\P``#P```*?S```0````M_,```\```#(\P``"P```-CS```/
M````Y/,```P```#T\P``#P````'T```'````$?0```8````9]```#````"#T
M```.````+?0```P````\]```*````$GT```/````<O0```@```""]```!@``
M`(OT```/````DO0```@```"B]```$P```*OT```>````O_0``"$```#>]```
M(`````#U```9````(?4``!<````[]0``)0```%/U```7````>?4``!8```"1
M]0``!````*CU```;````K?4```T```#)]0``#````-?U```#````Y/4```4`
M``#H]0``"````.[U```*````]_4```P````"]@``"P````_V```0````&_8`
M``P````L]@``!````#GV```$````/O8``!,```!#]@``%````%?V```,````
M;/8```D```!Y]@``#@```(/V```+````DO8``!L```">]@``!P```+KV```$
M````PO8```<```#']@``"@```,_V```-````VO8```D```#H]@``!````/+V
M```%````]_8```,```#]]@``&`````'W```*````&O<```0````E]P``)@``
M`"KW```.````4?<``'P```!@]P``%0```-WW```%````\_<```<```#Y]P``
M#`````'X```(````#O@```H````7^```!@```"+X```(````*?@```(````R
M^```!@```#7X```&````//@``!0```!#^```!````%CX```5````7?@```T`
M``!S^```$````('X```;````DO@```8```"N^```!````+7X```)````NO@`
M`!````#$^```"0```-7X```)````W_@```8```#I^```!0```/#X```:````
M]O@```@````1^0``!@```!KY```$````(?D```<````F^0``&0```"[Y```.
M````2/D```<```!7^0``!P```%_Y```%````9_D```D```!M^0``"@```'?Y
M```"````@OD```8```"%^0``"P```(SY```-````F/D```<```"F^0``"0``
M`*[Y```&````N/D```D```"_^0``!P```,GY```4````T?D``!T```#F^0``
M0@````3Z```E````1_H``"4```!M^@``!@```)/Z```*````FOH```0```"E
M^@``"0```*KZ```(````M/H``!$```"]^@``"0```,_Z```&````V?H```T`
M``#@^@``!@```.[Z```$````]?H``#D```#Z^@``/0```#3[```Z````<OL`
M`!X```"M^P``!0```,S[```.````TOL```0```#A^P``!@```.;[```'````
M[?L``"$```#U^P``#0```!?\```&````)?P```0````L_```$0```#'\```&
M````0_P```H```!*_```(@```%7\```$````>/P```<```!]_```!````(7\
M```%````BOP``!T```"0_```!````*[\```,````L_P```X```#`_```"@``
M`,_\```(````VOP```D```#C_```!0```.W\```Z````\_P``#`````N_0``
M-0```%_]```I````E?T``$<```"__0``.`````?^```I````0/X``#\```!J
M_@``+@```*K^```M````V?X``!\````'_P``#P```"?_```2````-_\```L`
M``!*_P``!P```%;_```F````7O\``#P```"%_P``*0```,+_```Z````[/\`
M`"0````G``$`)@```$P``0`(````<P`!``H```!\``$`"0```(<``0`'````
MD0`!`"````"9``$`(````+H``0`F````VP`!``H````"`0$`&0````T!`0`I
M````)P$!`!8```!1`0$`$@```&@!`0`'````>P$!``H```"#`0$`#````(X!
M`0`/````FP$!`!````"K`0$`0````+P!`0!P````_0$!`&8```!N`@$`T0``
M`-4"`0`.````IP,!``D```"V`P$`"@```,`#`0`2````RP,!`!,```#>`P$`
M#````/(#`0`&````_P,!`!@````&!`$`#P```!\$`0`6````+P0!`!(```!&
M!`$`$````%D$`0`1````:@0!`!P```!\!`$`(P```)D$`0!J````O00!``\`
M```H!0$`!0```#@%`0`0````/@4!``D```!/!0$`!````%D%`0`+````7@4!
M`"````!J!0$`%````(L%`0`,````H`4!``P```"M!0$`#P```+H%`0`5````
MR@4!`"D```#@!0$`*@````H&`0`F````-08!`"<```!<!@$`*0```(0&`0`J
M````K@8!`!D```#9!@$`0@```/,&`0`1````-@<!`!(```!(!P$`$P```%L'
M`0`4````;P<!``\```"$!P$`%@```)0'`0`7````JP<!`!````##!P$`$0``
M`-0'`0`T````Y@<!`!,````;"`$`$@```"\(`0`U````0@@!`!0```!X"`$`
M!P```(T(`0`,````E0@!`"````"B"`$`$````,,(`0`4````U`@!`!$```#I
M"`$`%P```/L(`0`<````$PD!`!,````P"0$`%````$0)`0`:````60D!`!$`
M``!T"0$`&@```(8)`0`>````H0D!`!H```#`"0$`$P```-L)`0`5````[PD!
M`!$````%"@$`%P```!<*`0`4````+PH!`!<```!$"@$`%0```%P*`0`)````
M<@H!`!````!\"@$`&0```(T*`0`$````IPH!``<```"L"@$`"P```+0*`0`1
M````P`H!``8```#2"@$`!@```-D*`0`&````X`H!``4```#G"@$`!P```.T*
M`0`'````]0H!``4```#]"@$`!@````,+`0`&````"@L!``0````1"P$`!```
M`!8+`0`'````&PL!``X````C"P$`#````#(+`0`,````/PL!``T```!,"P$`
M"@```%H+`0`.````90L!``4```!T"P$`*````'H+`0`.````HPL!``P```"R
M"P$`#P```+\+`0`*````SPL!``@```#:"P$`"0```.,+`0`K````[0L!``@`
M```9#`$`!````"(,`0`(````)PP!`"8````P#`$`$@```%<,`0`&````:@P!
M``H```!Q#`$`!P```'P,`0`(````A`P!`"````"-#`$`#0```*X,`0`)````
MO`P!``T```#&#`$`"@```-0,`0`4````WPP!``P```#T#`$`#0````$-`0`)
M````#PT!``X````9#0$`%@```"@-`0`1````/PT!``D```!1#0$`!@```%L-
M`0`#````8@T!``8```!F#0$`&0```&T-`0`'````APT!``0```"/#0$`"P``
M`)0-`0`+````H`T!``<```"L#0$`!0```+0-`0`'````N@T!`!8```#"#0$`
M#0```-D-`0`-````YPT!``H```#U#0$`$``````.`0`/````$0X!`!$````A
M#@$`%P```#,.`0`*````2PX!`!$```!6#@$`"````&@.`0`>````<0X!``0`
M``"0#@$`#P```)4.`0`Z````I0X!``4```#@#@$`#````.8.`0`>````\PX!
M``X````2#P$`$````"$/`0`+````,@\!``P````^#P$`"0```$L/`0`'````
M50\!``H```!=#P$`"0```&@/`0`.````<@\!`!````"!#P$`&P```)(/`0`8
M````K@\!`!H```#'#P$`"@```.(/`0`)````[0\!``D```#W#P$`"@````$0
M`0`,````#!`!``\````9$`$`"````"D0`0`&````,A`!`!P````Y$`$`!P``
M`%80`0`%````7A`!``L```!D$`$`1P```'`0`0`-````N!`!``D```#&$`$`
M!````-`0`0`#````U1`!`!,```#9$`$`$P```.T0`0`3`````1$!``H````5
M$0$``@```"`1`0`$````(Q$!`"4````H$0$``P```$X1`0`%````4A$!`"H`
M``!8$0$`"@```(,1`0`%````CA$!``0```"4$0$`"@```)D1`0`-````I!$!
M``8```"R$0$`"````+D1`0`(````PA$!``0```#+$0$`!0```-`1`0`8````
MUA$!`&@```#O$0$`"0```%@2`0`,````8A(!`!````!O$@$`!0```(`2`0`&
M````AA(!`!L```"-$@$`+P```*D2`0`0````V1(!``H```#J$@$`#P```/42
M`0`*````!1,!``D````0$P$`$P```!H3`0`;````+A,!`!@```!*$P$`%P``
M`&,3`0`8````>Q,!`!\```"4$P$`#@```+03`0`#````PQ,!``<```#'$P$`
M`@```,\3`0`(````TA,!``<```#;$P$`!P```.,3`0`+````ZQ,!``D```#W
M$P$`"@````$4`0`+````#!0!``<````8%`$`40```"`4`0`0````<A0!``P`
M``"#%`$`#0```)`4`0`:````GA0!`$H```"Y%`$`&0````05`0`&````'A4!
M`!H````E%0$`)0```$`5`0`&````9A4!``8```!M%0$`'P```'05`0`&````
ME!4!``D```";%0$`&````*45`0`7````OA4!`"@```#6%0$`"0```/\5`0`&
M````"18!``T````0%@$`(@```!X6`0!7````018!`!,```"9%@$`(P```*T6
M`0`3````T18!``(```#E%@$`"P```.@6`0`(````]!8!``T```#]%@$`"@``
M``L7`0`'````%A<!`!0````>%P$`!@```#,7`0`&````.A<!``@```!!%P$`
M!0```$H7`0`*````4!<!``X```!;%P$`!P```&H7`0`3````<A<!`!4```"&
M%P$`#````)P7`0`-````J1<!``H```"W%P$`"P```,(7`0`R````SA<!``<`
M```!&`$`#`````D8`0`-````%A@!``P````D&`$`"0```#$8`0`)````.Q@!
M``H```!%&`$`!P```%`8`0`)````6!@!``<```!B&`$`"@```&H8`0`;````
M=1@!`$(```"1&`$`$@```-08`0`*````YQ@!`!8```#R&`$`#`````D9`0`-
M````%AD!`!`````D&0$`"0```#49`0`0````/QD!``<```!0&0$`$@```%@9
M`0`$````:QD!``<```!P&0$`!0```'@9`0`%````?AD!``L```"$&0$`%```
M`)`9`0`1````I1D!`!H```"W&0$`%@```-(9`0`4````Z1D!`!<```#^&0$`
M&````!8:`0`<````+QH!`!D```!,&@$`!P```&8:`0`%````;AH!``T```!T
M&@$`#````((:`0`)````CQH!`!$```"9&@$`"````*L:`0`7````M!H!``L`
M``#,&@$`2@```-@:`0`,````(QL!`!\````P&P$`&@```%`;`0`3````:QL!
M``0```!_&P$`"@```(0;`0`$````CQL!``T```"4&P$`#0```*(;`0`(````
ML!L!``H```"Y&P$`"0```,0;`0`)````SAL!``@```#8&P$`#````.$;`0`)
M````[AL!``4```#X&P$`"0```/X;`0`%````"!P!``<````.'`$`!0```!8<
M`0`$````'!P!``(````A'`$`"````"0<`0`,````+1P!`#@````Z'`$`+```
M`',<`0`2````H!P!`"D```"S'`$`,@```-T<`0`E````$!T!``H````V'0$`
M+````$$=`0`N````;AT!`#,```"='0$`,P```-$=`0`X````!1X!``\````^
M'@$`&````$X>`0`+````9QX!`!0```!S'@$`$````(@>`0`L````F1X!`!P`
M``#&'@$`#P```.,>`0`3````\QX!`!4````''P$`%````!T?`0`2````,A\!
M`!0```!%'P$`%0```%H?`0`M````<!\!`"T```">'P$`,0```,P?`0`N````
M_A\!`"\````M(`$`+````%T@`0!B````BB`!`!,```#M(`$`#0````$A`0`-
M````#R$!``@````=(0$`%P```"8A`0`(````/B$!``P```!'(0$`*P```%0A
M`0`A````@"$!`!H```"B(0$`'````+TA`0`)````VB$!`$4```#D(0$`00``
M`"HB`0`$````;"(!`!,```!Q(@$`#@```(4B`0`3````E"(!`!@```"H(@$`
M!@```,$B`0`)````R"(!``H```#2(@$`#P```-TB`0`)````[2(!`!````#W
M(@$`!P````@C`0`.````$",!``4````?(P$`&P```"4C`0`-````02,!``@`
M``!/(P$``P```%@C`0`&````7",!`!0```!C(P$`$0```'@C`0`.````BB,!
M`#@```"9(P$``@```-(C`0`&````U2,!``X```#<(P$`!0```.LC`0`'````
M\2,!``X```#Y(P$`!@````@D`0`H````#R0!``P````X)`$`'````$4D`0`$
M````8B0!`"8```!G)`$`%@```(XD`0`4````I20!`"D```"Z)`$`%P```.0D
M`0`?````_"0!`%P````<)0$`%````'DE`0`^````CB4!`!\```#-)0$`$```
M`.TE`0`(````_B4!`!(````')@$`!P```!HF`0`.````(B8!``P````Q)@$`
M#````#XF`0`3````2R8!``H```!?)@$`'0```&HF`0`9````B"8!``4```"B
M)@$`$0```*@F`0`(````NB8!``4```##)@$`$0```,DF`0`)````VR8!`"0`
M``#E)@$`$@````HG`0`5````'2<!`!(````S)P$`#@```$8G`0`9````52<!
M``@```!O)P$`"0```'@G`0`"````@B<!``T```"%)P$`"@```),G`0`'````
MGB<!``\```"F)P$`!@```+8G`0`+````O2<!`!H```#))P$`"@```.0G`0`'
M````[R<!``@```#W)P$`!0`````H`0`?````!B@!``8````F*`$`$````"TH
M`0`(````/B@!``T```!'*`$`"````%4H`0`>````7B@!`!(```!]*`$`+```
M`)`H`0`:````O2@!``D```#8*`$`"@```.(H`0`5````[2@!`!`````#*0$`
M!0```!0I`0`4````&BD!``0````O*0$`!P```#0I`0`0````/"D!``8```!-
M*0$`!P```%0I`0`>````7"D!`"@```![*0$`'@```*0I`0`*````PRD!`!P`
M``#.*0$`$0```.LI`0`+````_2D!`!H````)*@$`%````"0J`0`$````.2H!
M``0````^*@$`"P```$,J`0`%````3RH!``8```!5*@$`"````%PJ`0`&````
M92H!`!L```!L*@$`-````(@J`0`T````O2H!`"````#R*@$`*0```!,K`0`@
M````/2L!`$$```!>*P$`&@```*`K`0`H````NRL!`"D```#D*P$`4`````XL
M`0`B````7RP!``8```""+`$`"````(DL`0`%````DBP!``X```"8+`$`"```
M`*<L`0`9````L"P!`!D```#*+`$`*@```.0L`0`C````#RT!`!D````S+0$`
M+@```$TM`0`T````?"T!``@```"Q+0$`%P```+HM`0`*````TBT!``<```#=
M+0$`(0```.4M`0`,````!RX!``T````4+@$`#````"(N`0`0````+RX!``X`
M``!`+@$`"P```$\N`0`'````6RX!`!,```!C+@$`"````'<N`0`+````@"X!
M``H```",+@$`%````)<N`0`/````K"X!`#(```"\+@$`"P```.\N`0`%````
M^RX!``4````!+P$`!0````<O`0`7````#2\!``\````E+P$`!````#4O`0`*
M````.B\!``D```!%+P$`"P```$\O`0`-````6R\!``P```!I+P$`#@```'8O
M`0`%````A2\!``0```"++P$`#0```)`O`0`R````GB\!`$4```#1+P$`"P``
M`!<P`0`*````(S`!``\````N,`$`$P```#XP`0`3````4C`!``\```!F,`$`
M#````'8P`0`.````@S`!``T```"2,`$`#0```*`P`0`7````KC`!``<```#&
M,`$`'@```,XP`0`4````[3`!``4````",0$`%`````@Q`0`&````'3$!``<`
M```D,0$`#````"PQ`0`0````.3$!`!$```!*,0$`#@```%PQ`0`7````:S$!
M`"H```"#,0$`!@```*XQ`0`)````M3$!``\```"_,0$`#````,\Q`0`-````
MW#$!`!$```#J,0$`"P```/PQ`0`V````"#(!``H````_,@$`(@```$HR`0`+
M````;3(!``\```!Y,@$`?0```(DR`0`R````!S,!`"4````Z,P$`"````&`S
M`0`P````:3,!`#$```":,P$`+0```,PS`0`2````^C,!``X````--`$`!0``
M`!PT`0`.````(C0!`!,````Q-`$`$0```$4T`0`(````5S0!`!(```!@-`$`
M!P```',T`0`1````>S0!`!,```"--`$`!P```*$T`0`4````J30!`!@```"^
M-`$`!P```-<T`0`%````WS0!``P```#E-`$`#````/(T`0`2````_S0!``0`
M```2-0$`!P```!<U`0`*````'S4!``L````J-0$`#````#8U`0`.````0S4!
M``X```!2-0$`!0```&$U`0`%````9S4!`"X```!M-0$`)@```)PU`0`C````
MPS4!``,```#G-0$`$@```.LU`0`&````_C4!`!X````%-@$`&````"0V`0`E
M````/38!``T```!C-@$`"0```'$V`0`?````>S8!``,```";-@$`!P```)\V
M`0`*````IS8!``(```"R-@$`#````+4V`0`5````PC8!``L```#8-@$`&0``
M`.0V`0`@````_C8!`!(````?-P$`!0```#(W`0`*````.#<!`!4```!#-P$`
M$@```%DW`0`(````;#<!``P```!U-P$`!````((W`0`)````AS<!``<```"1
M-P$`"P```)DW`0`.````I3<!``H```"T-P$`#````+\W`0!2````S#<!`!<`
M```?.`$`)````#<X`0`2````7#@!``<```!O.`$`!@```'<X`0`0````?C@!
M``X```"/.`$`#@```)XX`0`@````K3@!``P```#..`$`&0```-LX`0`-````
M]3@!`!4````#.0$`$@```!DY`0`/````+#D!`!0````\.0$`"@```%$Y`0`;
M````7#D!`!````!X.0$`'````(DY`0!8````ICD!``L```#_.0$`(0````LZ
M`0`E````+3H!`&D```!3.@$`&@```+TZ`0`7````V#H!`!D```#P.@$`&@``
M``H[`0`9````)3L!`"4````_.P$`)P```&4[`0`:````C3L!`!<```"H.P$`
M'0```,`[`0`F````WCL!`!L````%/`$`*@```"$\`0`9````3#P!`!\```!F
M/`$`$P```(8\`0`(````FCP!`$0```"C/`$`$P```.@\`0!`````_#P!``<`
M```]/0$`"````$4]`0`)````3CT!`!4```!8/0$`#0```&X]`0`C````?#T!
M``T```"@/0$`$P```*X]`0`(````PCT!``,```#+/0$`#````,\]`0!&````
MW#T!`!<````C/@$`#@```#L^`0`_````2CX!`$T```"*/@$`-P```-@^`0!7
M````$#\!``4```!H/P$`'P```&X_`0`O````CC\!``H```"^/P$`$P```,D_
M`0`0````W3\!`!$```#N/P$`"`````!``0`-````"4`!`"T````70`$`!```
M`$5``0`-````2D`!`!4```!80`$`.P```&Y``0!/````JD`!`!\```#Z0`$`
M%@```!I!`0`E````,4$!`"@```!700$`'````(!!`0`+````G4$!`",```"I
M00$`'P```,U!`0`A````[4$!`!T````/0@$`)0```"U"`0`@````4T(!`"0`
M``!T0@$`(````)E"`0`P````ND(!``L```#K0@$`!P```/="`0`-````_T(!
M``P````-0P$`%P```!I#`0`&````,D,!`#D````Y0P$`#````'-#`0`'````
M@$,!``D```"(0P$`$P```))#`0`)````ID,!``0```"P0P$`$````+5#`0`(
M````QD,!``@```#/0P$`!````-A#`0`+````W4,!``P```#I0P$`$@```/9#
M`0`1````"40!``P````;1`$`&@```"A$`0`/````0T0!``<```!31`$`#0``
M`%M$`0`4````:40!``X```!^1`$`#````(U$`0`L````FD0!`!,```#'1`$`
M'````-M$`0`H````^$0!``8````A10$`!P```"A%`0`3````,$4!``4```!$
M10$`!````$I%`0`7````3T4!``H```!G10$`#````')%`0`)````?T4!``8`
M``")10$`"0```)!%`0`&````FD4!``@```"A10$`"0```*I%`0`*````M$4!
M``@```"_10$`"@```,A%`0`*````TT4!``<```#>10$`$0```.9%`0`&````
M^$4!``X```#_10$`#@````Y&`0`-````'48!``L````K1@$`'0```#=&`0`+
M````548!``(```!A1@$`'````&1&`0`'````@48!``8```")1@$`9````)!&
M`0`)````]48!``<```#_1@$`)@````='`0`X````+D<!`!H```!G1P$`*@``
M`()'`0`[````K4<!`"@```#I1P$`-````!)(`0`9````1T@!`!4```!A2`$`
M!0```'=(`0`'````?4@!``@```"%2`$`!P```(Y(`0`&````ED@!``4```"=
M2`$`!P```*-(`0`.````JT@!``D```"Z2`$`!@```,1(`0`(````RT@!``L`
M``#42`$`!P```.!(`0`(````Z$@!``<```#Q2`$`%@```/E(`0`)````$$D!
M``8````:20$`"P```"%)`0`0````+4D!``8````^20$`'````$5)`0`4````
M8DD!``<```!W20$`$0```'])`0`(````D4D!``X```":20$`"````*E)`0`%
M````LDD!`!````"X20$`$````,E)`0`&````VDD!`!D```#A20$`"@```/M)
M`0`<````!DH!``<````C2@$`!0```"M*`0`0````,4H!`!0```!"2@$`"P``
M`%=*`0`-````8TH!`"@```!Q2@$`&````)I*`0`7````LTH!``D```#+2@$`
M!````-5*`0`)````VDH!``H```#D2@$`!P```.]*`0`"````]TH!``@```#Z
M2@$`.`````-+`0`C````/$L!`#@```!@2P$`)@```)E+`0`Q````P$L!`"<`
M``#R2P$`9````!I,`0`4````?TP!`"0```"43`$`(P```+E,`0`C````W4P!
M`"L````!30$`(0```"U-`0`D````3TT!`%4```!T30$`.````,I-`0!*````
M`TX!`%L```!.3@$`*````*I.`0`X````TTX!`"\````,3P$`10```#Q/`0!*
M````@D\!`$8```#-3P$`,P```!10`0`H````2%`!`"P```!Q4`$`)@```)Y0
M`0`;````Q5`!`#X```#A4`$`.@```"!1`0"I`0``6U$!`",````%4P$`%P``
M`"E3`0!(````05,!`(4```"*4P$`,````!!4`0`E````050!`$$```!G5`$`
M6P```*E4`0!)````!54!`#$```!/50$`:0```(%5`0`=````ZU4!`!@````)
M5@$`*P```")6`0`A````3E8!`!\```!P5@$`*P```)!6`0`A````O%8!`"<`
M``#>5@$`.@````97`0`=````05<!`!$```!?5P$`,P```'%7`0`E````I5<!
M`"<```#+5P$`(````/-7`0`R````%%@!`!\```!'6`$`,````&=8`0!I````
MF%@!`#$````"60$`00```#19`0`S````=ED!`"4```"J60$`/0```-!9`0!E
M````#EH!`$T```!T6@$`+0```,):`0`G````\%H!`"\````86P$`*````$A;
M`0`N````<5L!`#````"@6P$`5````-%;`0`G````)EP!`%H```!.7`$`.@``
M`*E<`0!(````Y%P!`$H````M70$`'P```'A=`0`R````F%T!`"\```#+70$`
M+````/M=`0`M````*%X!`'$```!67@$`9@```,A>`0!O````+U\!`+,```"?
M7P$`%P```%-@`0`E````:V`!`#(```"18`$`*0```,1@`0`^````[F`!`"(`
M```M80$`4@```%!A`0`B````HV$!`"4```#&80$`"P```.QA`0"Q````^&$!
M`"````"J8@$`10```,MB`0`A````$6,!`#`````S8P$`)0```&1C`0`<````
MBF,!`#$```"G8P$`!P```-EC`0`(````X6,!``<```#J8P$`!````/)C`0`*
M````]V,!``T````"9`$`"P```!!D`0`.````'&0!``D````K9`$`"P```#5D
M`0`&````060!``4```!(9`$`$````$YD`0`"````7V0!`%D```!B9`$`!0``
M`+QD`0`2````PF0!``0```#59`$`!P```-ID`0`(````XF0!``4```#K9`$`
M`P```/%D`0`0````]60!``P````&90$`$P```!-E`0`-````)V4!``(````U
M90$`!P```#AE`0`'````0&4!``8```!(90$`#````$]E`0`8````7&4!``8`
M``!U90$`!````'QE`0`2````@64!``P```"490$``P```*%E`0`J````I64!
M``0```#090$`!@```-5E`0`'````W&4!`!\```#D90$`-0````1F`0`N````
M.F8!`"\```!I9@$`%P```)EF`0`B````L68!`"4```#49@$`(````/IF`0`;
M````&V<!`!@````W9P$`)````%!G`0`?````=6<!`!H```"59P$`(0```+!G
M`0`@````TF<!`!H```#S9P$`,@````YH`0`9````06@!`!H```!;:`$`+P``
M`'9H`0`K````IF@!`!\```#2:`$`(P```/)H`0`?````%FD!`!H````V:0$`
M(0```%%I`0`E````<VD!`"8```"9:0$`)0```,!I`0`D````YFD!`!@````+
M:@$`'0```"1J`0`D````0FH!`!@```!G:@$`(@```(!J`0`L````HVH!`"\`
M``#0:@$`%0````!K`0`E````%FL!`!D````\:P$`/````%9K`0`?````DVL!
M`",```"S:P$`'P```-=K`0`@````]VL!`!H````8;`$`+P```#-L`0`8````
M8VP!`"8```!\;`$`'@```*-L`0`I````PFP!`!X```#L;`$`,0````MM`0`)
M````/6T!``P```!';0$`%P```%1M`0`O````;&T!`"0```"<;0$`!P```,%M
M`0`4````R6T!``X```#>;0$`#0```.UM`0`%````^VT!``<````!;@$`(@``
M``EN`0`E````+&X!`!H```!2;@$`'0```&UN`0`:````BVX!``<```"F;@$`
MQP```*YN`0`+````=F\!`!P```"";P$`%0```)]O`0`&````M6\!``D```"\
M;P$`"P```,9O`0`-````TF\!``P```#@;P$`%P```.UO`0`&````!7`!`#,`
M```,<`$`$P```$!P`0`3````5'`!``<```!H<`$`#P```'!P`0`'````@'`!
M`#(```"(<`$`!````+MP`0`A````P'`!`!,```#B<`$`#@```/9P`0`,````
M!7$!`!$````2<0$`,@```"1Q`0`6````5W$!``@```!N<0$`'0```'=Q`0`)
M````E7$!``H```"?<0$`%````*IQ`0`*````OW$!`!T```#*<0$`"````.AQ
M`0`?````\7$!``@````1<@$`&@```!IR`0`G````-7(!``8```!=<@$`%0``
M`&1R`0`'````>G(!``@```""<@$`"0```(MR`0`_````E7(!``<```#5<@$`
M#P```-UR`0`.````[7(!`!````#\<@$`"0````US`0`)````%W,!``@````A
M<P$`!P```"IS`0`(````,G,!`!D````[<P$`"@```%5S`0`7````8',!`!0`
M``!X<P$`"@```(US`0`,````F',!`!<```"E<P$`!````+US`0`J````PG,!
M``P```#M<P$`$0```/IS`0`'````#'0!``(````4=`$`$````!=T`0`8````
M*'0!``L```!!=`$``P```$UT`0`(````470!``D```!:=`$`!````&1T`0`'
M````:70!``<```!Q=`$`!@```'ET`0`4````@'0!``<```"5=`$`#0```)UT
M`0`+````JW0!``X```"W=`$`+P```,9T`0`@````]G0!`!P````7=0$`2```
M`#1U`0!,````?74!`!4```#*=0$`#````.!U`0`Q````[74!``4````?=@$`
M$@```"5V`0`_````.'8!`!(```!X=@$`"@```(MV`0`&````EG8!``0```"=
M=@$`!````*)V`0`*````IW8!`!,```"R=@$`!0```,9V`0`&````S'8!``8`
M``#3=@$`"````-IV`0`$````XW8!``P```#H=@$`"@```/5V`0`)`````'<!
M`#D````*=P$`+@```$1W`0`I````<W<!``4```"==P$`&````*-W`0`9````
MO'<!`!\```#6=P$`'0```/9W`0`1````%'@!``(````F>`$`!````"EX`0`*
M````+G@!``0````Y>`$`!@```#YX`0`4````17@!``4```!:>`$``P```&!X
M`0`,````9'@!`$4```!Q>`$`,@```+=X`0`R````ZG@!`"\````=>0$`&@``
M`$UY`0`Z````:'D!`#0```"C>0$`*````-AY`0!3`````7H!`),```!5>@$`
M+P```.EZ`0!"````&7L!`#````!<>P$`+@```(U[`0`9````O'L!`"<```#6
M>P$`.````/Y[`0`X````-WP!`#<```!P?`$`<@```*A\`0`@````&WT!`#4`
M```\?0$`(0```')]`0!%````E'T!`#````#:?0$`*0````M^`0`A````-7X!
M`"@```!7?@$`*0```(!^`0`F````JGX!`"4```#1?@$`*````/=^`0`H````
M('\!`"(```!)?P$`*P```&Q_`0!%````F'\!`$D```#>?P$`1@```"B``0`\
M````;X`!`#````"L@`$`$@```-V``0`3````\(`!`!`````$@0$`>0```!6!
M`0`)````CX$!`*$```"9@0$`<P```#N"`0!\````KX(!`"L````L@P$`5```
M`%B#`0`7````K8,!`!4```#%@P$`)P```-N#`0`6`````X0!``\````:A`$`
M%P```"J$`0`?````0H0!`$````!BA`$`'P```*.$`0`<````PX0!`%$```#@
MA`$`&@```#*%`0`4````384!``H```!BA0$`!0```&V%`0`&````<X4!``@`
M``!ZA0$`!0```(.%`0`2````B84!`!````"<A0$`$P```*V%`0`=````P84!
M``\```#?A0$`#P```.^%`0`/````_X4!``8````/A@$`#0```!:&`0`$````
M)(8!``D````IA@$`"P```#.&`0`%````/X8!``4```!%A@$`!P```$N&`0`%
M````4X8!`!0```!9A@$`#@```&Z&`0`'````?88!``@```"%A@$`#P```(Z&
M`0`-````GH8!``H```"LA@$`"````+>&`0`,````P(8!``8```#-A@$`#P``
M`-2&`0`'````Y(8!``8```#LA@$`%````/.&`0`&````"(<!``8````/AP$`
M#````!:'`0`1````(X<!`!<````UAP$`"````$V'`0`$````5H<!`!D```!;
MAP$`$0```'6'`0`*````AX<!`!@```"2AP$`$P```*N'`0`<````OX<!`!$`
M``#<AP$``P```.Z'`0`&````\H<!``0```#YAP$`#P```/Z'`0`*````#H@!
M``H````9B`$`!P```"2(`0`$````+(@!``0````QB`$`&0```#:(`0`'````
M4(@!``(```!8B`$``@```%N(`0`1````7H@!``D```!PB`$`!@```'J(`0`2
M````@8@!`!<```"4B`$`!@```*R(`0`G````LX@!``(```#;B`$`"````-Z(
M`0`$````YX@!``\```#LB`$`$P```/R(`0`'````$(D!``L````8B0$`$```
M`"2)`0`3````-8D!``<```!)B0$`$0```%&)`0`&````8XD!`!@```!JB0$`
M!@```(.)`0`3````BHD!`!````">B0$`$@```*^)`0`"````PHD!``8```#%
MB0$`#````,R)`0`)````V8D!`!$```#CB0$`(@```/6)`0`'````&(H!``<`
M```@B@$`"P```"B*`0`3````-(H!``4```!(B@$`$0```$Z*`0`"````8(H!
M``L```!CB@$`!````&^*`0`+````=(H!``4```"`B@$`!P```(:*`0!-`0``
MCHH!`!````#<BP$`%P```.V+`0`+````!8P!``8````1C`$`"0```!B,`0`(
M````(HP!``H````KC`$`%````#:,`0`9````2XP!`"T```!EC`$`)0```).,
M`0`E````N8P!`",```#?C`$`'P````.-`0`M````(XT!``H```!1C0$`%P``
M`%R-`0`J````=(T!``L```"?C0$`$P```*N-`0`-````OXT!`!4```#-C0$`
M"P```..-`0`%````[XT!`"T```#UC0$`#0```"..`0`=````,8X!`!4```!/
MC@$`#P```&6.`0`1````=8X!``T```"'C@$`'````)6.`0!T````LHX!``X`
M```GCP$`"````#:/`0`1````/X\!``T```!1CP$`%@```%^/`0`+````=H\!
M`!<```""CP$`&@```)J/`0`&````M8\!`+\```"\CP$`3````'R0`0`@````
MR9`!`!P```#JD`$`"P````>1`0`2````$Y$!`!T````FD0$`$````$21`0`*
M````59$!``D```!@D0$`"````&J1`0`2````<Y$!``@```"&D0$`"0```(^1
M`0`2````F9$!``@```"LD0$`"0```+61`0`/````OY$!`"8```#/D0$`(P``
M`/:1`0`I````&I(!`"<```!$D@$`,````&R2`0`9````G9(!`#8```"WD@$`
M/0```.Z2`0!0````+),!`$\```!]DP$`6````,V3`0!6````)I0!`#@```!]
ME`$`#````+:4`0`4````PY0!`!<```#8E`$`$0```/"4`0`5`````I4!`!T`
M```8E0$`"````#:5`0`&````/Y4!``\```!&E0$`!````%:5`0`0````6Y4!
M``\```!LE0$`"P```'R5`0`R````B)4!`#````"[E0$`$0```.R5`0`.````
M_I4!`!$````-E@$`"0```!^6`0`7````*98!``8```!!E@$`&0```$B6`0`7
M````8I8!``X```!ZE@$`!P```(F6`0`.````D98!`!$```"@E@$`'@```+*6
M`0`<````T98!`!X```#NE@$`$P````V7`0`3````(9<!`!$````UEP$`#0``
M`$>7`0`-````59<!``H```!CEP$`)@```&Z7`0`3````E9<!`!@```"IEP$`
M$@```,*7`0!4````U9<!`#<````JF`$`)````&*8`0`&````AY@!``<```".
MF`$`-@```):8`0`-````S9@!``<```#;F`$`%@```..8`0`*````^I@!``4`
M```%F0$`$0````N9`0`3````'9D!`!(````QF0$`%0```$29`0`0````6ID!
M`!,```!KF0$`$P```'^9`0`3````DYD!``P```"GF0$`'````+29`0`*````
MT9D!``@```#<F0$`"````.69`0`%````[ID!``@```#TF0$`"P```/V9`0`&
M````"9H!`!`````0F@$`(P```"&:`0`-````19H!``X```!3F@$`#0```&*:
M`0`,````<)H!`!````!]F@$`"0```(Z:`0`2````F)H!``\```"KF@$`$P``
M`+N:`0`6````SYH!`"L```#FF@$`"P```!*;`0`D````'IL!`!<```!#FP$`
M)````%N;`0`=````@)L!`!0```">FP$`$@```+.;`0`.````QIL!`!P```#5
MFP$`%@```/*;`0`'````"9P!``8````1G`$`"````!B<`0`.````(9P!``<`
M```PG`$`"@```#B<`0`1````0YP!``D```!5G`$`"0```%^<`0`0````:9P!
M`!@```!ZG`$`*@```).<`0`(````OIP!`!$```#'G`$`!0```-F<`0`/````
MWYP!``P```#OG`$`,0```/R<`0`O````+IT!``D```!>G0$`"````&B=`0`&
M````<9T!``4```!XG0$`$````'Z=`0`,````CYT!`!4```"<G0$`-````+*=
M`0`!````YYT!`,D```#IG0$`*````+.>`0`G````W)X!`"0````$GP$`,0``
M`"F?`0`%````6Y\!``D```!AGP$`"````&N?`0`&````=)\!``D```![GP$`
M!P```(6?`0`W````C9\!`"\```#%GP$`-@```/6?`0!>````+*`!`#4```"+
MH`$`-0```,&@`0!*````]Z`!`$L```!"H0$`-0```(ZA`0!"````Q*$!`#$`
M```'H@$`-````#FB`0!,````;J(!`#4```"[H@$`.P```/&B`0`L````+:,!
M`!8```!:HP$`&@```'&C`0`F````C*,!`"L```"SHP$`*P```-^C`0`1````
M"Z0!``L````=I`$`#````"FD`0`'````-J0!``T````^I`$`%P```$RD`0`D
M````9*0!``8```")I`$`!P```)"D`0`)````F*0!``@```"BI`$`*````*ND
M`0`/````U*0!`!$```#DI`$`"@```/:D`0`(`````:4!``8````*I0$`!0``
M`!&E`0`'````%Z4!``4````?I0$`"@```"6E`0`G````,*4!`!````!8I0$`
M"0```&FE`0`%````<Z4!``<```!YI0$`!P```(&E`0`%````B:4!``T```"/
MI0$`!@```)VE`0`3````I*4!``,```"XI0$`"````+RE`0`&````Q:4!``T`
M``#,I0$`"````-JE`0`@````XZ4!`!$````$I@$`"0```!:F`0`2````(*8!
M``P````SI@$`!P```$"F`0`-````2*8!``,```!6I@$``P```%JF`0`4````
M7J8!``D```!SI@$`%````'VF`0`R````DJ8!``D```#%I@$`"````,^F`0`1
M````V*8!`!H```#JI@$`"0````6G`0`9````#Z<!``D````IIP$`"````#.G
M`0`'````/*<!`$L```!$IP$`)````)"G`0`M````M:<!`"@```#CIP$`)```
M``RH`0`A````,:@!``8```!3J`$`!@```%JH`0`8````8:@!``<```!ZJ`$`
M"P```(*H`0`A````CJ@!`"0```"PJ`$`+@```-6H`0`E````!*D!`"T````J
MJ0$`8````%BI`0`N````N:D!`!(```#HJ0$`!P```/NI`0`*`````ZH!`!,`
M```.J@$`"0```"*J`0`1````+*H!``\````^J@$`$````$ZJ`0`0````7ZH!
M`!````!PJ@$`$````(&J`0`/````DJH!``D```"BJ@$`%P```*RJ`0`A````
MQ*H!`!0```#FJ@$`&````/NJ`0`#````%*L!``8````8JP$`$0```!^K`0!5
M````,:L!`%P```"'JP$`!````.2K`0`6````Z:L!``4`````K`$`!`````:L
M`0`2````"ZP!``\````>K`$`'````"ZL`0`D````2ZP!`%<```!PK`$`3P``
M`,BL`0!*````&*T!`#````!CK0$`5````)2M`0!-````Z:T!`%X````WK@$`
M)@```):N`0`/````O:X!`",```#-K@$`!0```/&N`0`:````]ZX!``T````2
MKP$`'0```""O`0`9````/J\!`!4```!8KP$`&P```&ZO`0`1````BJ\!`!D`
M``"<KP$`$P```+:O`0`-````RJ\!``8```#8KP$`#````-^O`0`'````[*\!
M`!<```#TKP$`$@````RP`0`.````'[`!``@````NL`$`!0```#>P`0`+````
M/;`!``L```!)L`$`!P```%6P`0`/````7;`!``8```!ML`$`&````'2P`0`&
M````C;`!`!4```"4L`$`"````*JP`0`*````L[`!``8```"^L`$`"@```,6P
M`0`(````T+`!``0```#9L`$`!````-ZP`0`7````X[`!`$P```#[L`$`)```
M`$BQ`0`/````;;$!``X```!]L0$`(0```(RQ`0`)````KK$!``4```"XL0$`
M'````+ZQ`0`1````V[$!`!(```#ML0$`+@````"R`0`]````+[(!`"````!M
ML@$`"````(ZR`0`P````E[(!`!H```#(L@$`"@```..R`0`*````[K(!``\`
M``#YL@$`!@````FS`0`)````$+,!`!<````:LP$`#P```#*S`0!;````0K,!
M``D```">LP$`$@```*BS`0`M````N[,!`"L```#ILP$`+P```!6T`0`M````
M1;0!`"$```!SM`$`)@```)6T`0`E````O+0!`"D```#BM`$`*0````RU`0`U
M````-K4!`"L```!LM0$`)````)BU`0`F````O;4!`"$```#DM0$`*@````:V
M`0`Z````,;8!`"X```!LM@$`)````)NV`0`P````P+8!`#D```#QM@$`)0``
M`"NW`0`A````4;<!`#0```!SMP$`)0```*BW`0`9````SK<!`"\```#HMP$`
M(P```!BX`0`F````/+@!`!H```!CN`$`L0```'ZX`0`2````,+D!`"````!#
MN0$`*0```&2Y`0`I````CKD!`#$```"XN0$`(@```.JY`0`A````#;H!`"4`
M```ON@$`*0```%6Z`0`L````?[H!`#H```"LN@$`+````.>Z`0"3````%+L!
M`"4```"HNP$`&P```,Z[`0`F````ZKL!`"\````1O`$`+P```$&\`0!&````
M<;P!`$0```"XO`$`#0```/V\`0`'````"[T!``4````3O0$`"````!F]`0`1
M````(KT!`!4````TO0$`#@```$J]`0`-````6;T!`!4```!GO0$`"0```'V]
M`0`,````A[T!`!4```"4O0$`"@```*J]`0`$````M;T!``@```"ZO0$`#P``
M`,.]`0`0````T[T!``P```#DO0$`#P```/&]`0`5`````;X!`!`````7O@$`
M%````"B^`0`-````/;X!`$(```!+O@$`"@```(Z^`0`0````F;X!``8```"J
MO@$`#P```+&^`0`"````P;X!`$L```#$O@$`!0```!"_`0`9````%K\!`",`
M```POP$`%P```%2_`0`%````;+\!``X```!ROP$`#````(&_`0`#````CK\!
M``@```"2OP$`"````)N_`0`1````I+\!``@```"VOP$`$````+^_`0`*````
MT+\!`!$```#;OP$`#0```.V_`0`:````^[\!`!,````6P`$`&P```"K``0`C
M````1L`!``D```!JP`$`!P```'3``0`)````?,`!``T```"&P`$`#@```)3`
M`0`/````H\`!``X```"SP`$`#0```,+``0`:````T,`!``T```#KP`$`#@``
M`/G``0`G````",$!`!8````PP0$`*P```$?!`0`.````<\$!`!@```""P0$`
M%P```)O!`0!8````L\$!`!<````,P@$`,0```"3"`0`-````5L(!``8```!D
MP@$`!@```&O"`0`/````<L(!``4```""P@$`*P```(C"`0`L````M,(!``4`
M``#AP@$`"0```.?"`0`>````\<(!``L````0PP$`$@```!S#`0`2````+\,!
M``<```!"PP$`%0```$K#`0`F````8,,!`!(```"'PP$`%0```)K#`0`;````
ML,,!`!@```#,PP$`$0```.7#`0`5````]\,!``D````-Q`$`"0```!?$`0`C
M````(<0!`#<```!%Q`$`#````'W$`0`]````BL0!``@```#(Q`$`%@```-'$
M`0`>````Z,0!``@````'Q0$`"P```!#%`0`R````',4!`!````!/Q0$`!0``
M`&#%`0`*````9L4!``<```!QQ0$`!@```'G%`0`#````@,4!``<```"$Q0$`
M!P```(S%`0`*````E,4!`!(```"?Q0$`#````++%`0`1````O\4!``\```#1
MQ0$`#0```.'%`0`-````[\4!`!0```#]Q0$`&P```!+&`0`2````+L8!`!D`
M``!!Q@$`%P```%O&`0`6````<\8!`!0```"*Q@$`"P```)_&`0`%````J\8!
M``@```"QQ@$`"@```+K&`0`"````Q<8!``4```#(Q@$`$````,[&`0`C````
MW\8!`!,````#QP$`$@```!?'`0`)````*L<!``\````TQP$`$0```$3'`0`:
M````5L<!``<```!QQP$`+0```'G'`0`K````I\<!``\```#3QP$`!0```./'
M`0`-````Z<<!``L```#WQP$`#@````/(`0!V````$L@!`!,```")R`$`'P``
M`)W(`0`0````O<@!``<```#.R`$`!0```-;(`0`=````W,@!`#$```#ZR`$`
M+P```"S)`0`>````7,D!`$P```![R0$`(````,C)`0`:````Z<D!`!H````$
MR@$`"````!_*`0`'````*,H!``<````PR@$`!@```#C*`0`0````/\H!`!$`
M``!0R@$`$0```&+*`0`3````=,H!`!8```"(R@$`(@```)_*`0`9````PLH!
M`!````#<R@$`#@```.W*`0`1````_,H!``\````.RP$`%0```![+`0`/````
M-,L!``P```!$RP$`"@```%'+`0`'````7,L!``@```!DRP$`#````&W+`0`4
M````>LL!``X```"/RP$`-P```)[+`0`/````ULL!``@```#FRP$`!@```._+
M`0`3````]LL!``L````*S`$`&@```!;,`0`@````,<P!`"H```!2S`$`*0``
M`'W,`0`?````I\P!`"````#'S`$`*@```.C,`0`?````$\T!`!@````SS0$`
M!0```$S-`0`=````4LT!``\```!PS0$`#@```(#-`0`#````C\T!``0```"3
MS0$`!P```)C-`0`-````H,T!``\```"NS0$`"P```+[-`0`5````RLT!``L`
M``#@S0$`!0```.S-`0`%````\LT!`!<```#XS0$`&0```!#.`0`/````*LX!
M``L````ZS@$`#````$;.`0`/````4\X!`"8```!CS@$`!@```(K.`0`%````
MD<X!``8```"7S@$`#0```)[.`0`*````K,X!``L```"WS@$`!@```,/.`0`.
M````RLX!``0```#9S@$`%P```-[.`0`+````]LX!``<````"SP$`*@````K/
M`0`/````-<\!`(,```!%SP$`$@```,G/`0`)````W,\!``<```#FSP$`"P``
M`.[/`0`'````^L\!``D````"T`$`!`````S0`0`-````$=`!``,````?T`$`
M!0```"/0`0`*````*=`!`!,````TT`$`!0```$C0`0`=````3M`!`!(```!L
MT`$`%````'_0`0`:````E-`!``8```"OT`$``@```+;0`0`)````N=`!``L`
M``##T`$`!````,_0`0`*````U-`!``D```#?T`$`!0```.G0`0`F````[]`!
M``@````6T0$`!@```!_1`0`#````)M$!``D````JT0$`)P```#31`0`.````
M7-$!``<```!KT0$`!P```'/1`0`%````>]$!``D```"!T0$`"P```(O1`0`'
M````E]$!``8```"?T0$`"P```*;1`0`0````LM$!``P```##T0$`#0```-#1
M`0`&````WM$!``<```#ET0$`!P```.W1`0`4````]=$!`!T````*T@$`/P``
M`"C2`0`L````:-(!`#$```"5T@$`!P```,?2`0`*````S](!``0```#:T@$`
M"0```-_2`0`(````Z=(!`!T```#RT@$`"0```!#3`0`&````&M,!``T````A
MTP$`!@```"_3`0`$````-M,!`#(````[TP$`-````&[3`0`T````H],!`",`
M``#8TP$`!0```/S3`0`=`````M0!``0````@U`$`"````"74`0`(````+M0!
M`"0````WU`$`"P```%S4`0`%````:-0!``@```!NU`$`'P```'?4`0`(````
ME]0!``@```"@U`$`%@```*G4`0`%````P-0!``@```#&U`$`!@```,_4`0`&
M````UM0!``<```#=U`$`!0```.74`0`-````Z]0!`!````#YU`$`#0````K5
M`0`(````&-4!``D````AU0$`!0```"O5`0`[````,=4!`#@```!MU0$`/```
M`*;5`0`G````X]4!`#@````+U@$`0````$36`0`P````A=8!`#H```"VU@$`
M-0```/'6`0`^````)]<!`"D```!FUP$`$@```)#7`0`6````H]<!``T```"Z
MUP$`"0```,C7`0`J````TM<!`#P```#]UP$`'````#K8`0!0````5]@!`!T`
M``"HV`$`'````,;8`0`'````X]@!``D```#KV`$`"0```/78`0`(````_]@!
M`"@````(V0$`)P```#'9`0`E````6=D!``D```!_V0$`&@```(G9`0`O````
MI-D!`"8```#4V0$`$0```/O9`0`&````#=H!``D````4V@$`#````![:`0`,
M````*]H!``\````XV@$`-@```$C:`0""````?]H!`'8````"VP$`Y@```'G;
M`0`/````8-P!``L```!PW`$`#````'S<`0`1````B=P!`!(```";W`$`$```
M`*[<`0`'````O]P!`!P```#'W`$`#P```.3<`0`7````]-P!`!0````,W0$`
M$@```"'=`0`/````--T!`!\```!$W0$`*@```&3=`0"&````C]T!`!$````6
MW@$`!0```"C>`0`7````+MX!``D```!&W@$`!````%#>`0`*````5=X!`!X`
M``!@W@$`$0```'_>`0`.````D=X!``X```"@W@$`#````*_>`0`3````O-X!
M`!X```#0W@$`(````._>`0`>````$-\!`"`````OWP$`'P```%#?`0`A````
M<-\!`!L```"2WP$`.````*[?`0`/````Y]\!`!$```#WWP$`$`````G@`0`2
M````&N`!``T````MX`$`$@```#O@`0`4````3N`!`!````!CX`$`$@```'3@
M`0`R````A^`!`!8```"ZX`$`%````-'@`0`]````YN`!`!0````DX0$`"@``
M`#GA`0`3````1.$!`$$```!8X0$`&P```)KA`0`3````MN$!`!(```#*X0$`
M'0```-WA`0`8````^^$!`!8````4X@$`%P```"OB`0`>````0^(!`!H```!B
MX@$`*````'WB`0`C````IN(!`!H```#*X@$`%0```.7B`0`6````^^(!`!$`
M```2XP$`%P```"3C`0`9````/.,!`!D```!6XP$`%P```'#C`0`(````B.,!
M`!````"1XP$`!````*+C`0`$````I^,!``4```"LXP$`"P```++C`0`/````
MON,!``8```#.XP$`"0```-7C`0`'````W^,!``D```#GXP$`!P```/'C`0`&
M````^>,!``@`````Y`$`!@````GD`0`&````$.0!``,````7Y`$``P```!OD
M`0`(````'^0!`!(````HY`$`$0```#OD`0`.````3>0!``\```!<Y`$`"@``
M`&SD`0`2````=^0!``0```"*Y`$`*````(_D`0`2````N.0!`!````#+Y`$`
M&````-SD`0`+````]>0!``D````!Y0$`#@````OE`0`M````&N4!``T```!(
MY0$`!````%;E`0`(````6^4!`"(```!DY0$`$@```(?E`0`&````FN4!``D`
M``"AY0$`!P```*OE`0`%````L^4!``0```"YY0$`$P```+[E`0`1````TN4!
M`!4```#DY0$`#P```/KE`0`4````"N8!``X````?Y@$`%@```"[F`0`,````
M1>8!`!@```!2Y@$`'0```&OF`0`;````B>8!``\```"EY@$`"````+7F`0`%
M````ON8!``8```#$Y@$`(0```,OF`0`'````[>8!``4```#UY@$`#@```/OF
M`0`-````"N<!``<````8YP$`!@```"#G`0`'````)^<!``4````OYP$`#P``
M`#7G`0`/````1><!``H```!5YP$`#P```&#G`0`1````<.<!`!8```""YP$`
M%````)GG`0`.````KN<!`!8```"]YP$`"````-3G`0`A````W><!``4```#_
MYP$`$0````7H`0`V````%^@!``4```!.Z`$`#````%3H`0`C````8>@!`!8`
M``"%Z`$`%````)SH`0`7````L>@!``P```#)Z`$`"0```-;H`0`'````X.@!
M``H```#HZ`$`"0```//H`0`.````_>@!`!`````,Z0$`'0```!WI`0`C````
M.^D!`"X```!?Z0$`"@```([I`0`%````F>D!``<```"?Z0$`#@```*?I`0`-
M````MND!`!$```#$Z0$`!@```-;I`0`+````W>D!`"8```#IZ0$`"````!#J
M`0`+````&>H!`!0````EZ@$`40```#KJ`0`4````C.H!``D```"AZ@$`!0``
M`*OJ`0`%````L>H!`!,```"WZ@$`%0```,OJ`0`3````X>H!``L```#UZ@$`
M`@````'K`0`*````!.L!`"H````/ZP$``P```#KK`0`%````/NL!``H```!$
MZP$`"@```$_K`0`%````6NL!``4```!@ZP$`'@```&;K`0`2````A>L!``8`
M``"8ZP$`"````)_K`0`(````J.L!``0```"QZP$`!0```+;K`0`>````O.L!
M`&$```#;ZP$`"@```#WL`0`-````2.P!`!(```!6[`$`!0```&GL`0`%````
M;^P!`"<```!U[`$`-````)WL`0`3````TNP!``@```#F[`$`#````._L`0`*
M````_.P!``D````'[0$`&@```!'M`0`L````+.T!`"H```!9[0$`*0```(3M
M`0`8````KNT!`!X```#'[0$`#P```.;M`0`#````]NT!``<```#Z[0$``@``
M``+N`0`(````!>X!``H````.[@$`"````!GN`0`+````(NX!``L````N[@$`
M$````#KN`0`,````2^X!``8```!8[@$`20```%_N`0`9````J>X!``H```##
M[@$`#0```,[N`0`<````W.X!`$T```#Y[@$`(````$?O`0`&````:.\!`!T`
M``!O[P$`*````(WO`0`(````MN\!``8```"_[P$`'0```,;O`0`%````Y.\!
M``@```#J[P$`*@```//O`0`I````'O`!`"X```!(\`$`"0```'?P`0`1````
M@?`!``4```"3\`$`'@```)GP`0!=````N/`!`!`````6\0$`(0```"?Q`0`1
M````2?$!``,```!;\0$`#````%_Q`0`&````;/$!`!4```!S\0$`"P```(GQ
M`0`'````E?$!``D```"=\0$`!@```*?Q`0`(````KO$!``D```"W\0$`!@``
M`,'Q`0`.````R/$!``P```#7\0$`!P```.3Q`0`9````[/$!`!,````&\@$`
M$````!KR`0`-````*_(!``H````Y\@$`#````$3R`0`Y````4?(!``8```"+
M\@$`#@```)+R`0`0````H?(!`!````"R\@$`#0```,/R`0`.````T?(!``\`
M``#@\@$`#0```/#R`0`-````_O(!``T````,\P$`"````!KS`0`>````(_,!
M`$X```!"\P$`$0```)'S`0`*````H_,!`!<```"N\P$`#@```,;S`0`.````
MU?,!`"H```#D\P$`"@````_T`0`4````&O0!``<````O]`$`$````#?T`0`$
M````2/0!``<```!-]`$`!0```%7T`0`%````6_0!``D```!A]`$`$````&OT
M`0`5````?/0!`"T```"2]`$`'````,#T`0`Q````W?0!`"H````/]0$`&0``
M`#KU`0`=````5/4!`!@```!R]0$`!````(OU`0`%````D/4!``X```"6]0$`
M#@```*7U`0`,````M/4!`!(```#!]0$``P```-3U`0`C````V/4!``L```#\
M]0$`4`````CV`0`*````6?8!`"````!D]@$`&@```(7V`0`2````H/8!``0`
M``"S]@$`$````+CV`0`%````R?8!`!8```#/]@$`$@```.;V`0`/````^?8!
M`!(````)]P$`$@```!SW`0`/````+_<!``\````_]P$`$0```$_W`0`2````
M8?<!``P```!T]P$`"0```('W`0`%````B_<!``<```"1]P$``P```)GW`0`$
M````G?<!``,```"B]P$`#````*;W`0`0````L_<!`%(```#$]P$`0````!?X
M`0`=````6/@!`"X```!V^`$`-0```*7X`0!%````V_@!``T````A^0$`-@``
M`"_Y`0`B````9OD!`"<```")^0$`)P```+'Y`0`L````V?D!``X````&^@$`
M)````!7Z`0`6````.OH!`!T```!1^@$`%````&_Z`0`X````A/H!`"8```"]
M^@$`'````.3Z`0`:`````?L!`!<````<^P$`'````#3[`0`A````4?L!`!L`
M``!S^P$`%P```(_[`0`L````I_L!`"P```#4^P$`,`````'\`0`M````,OP!
M`"X```!@_`$`*P```(_\`0!>````N_P!`"`````:_0$`%P```#O]`0`.````
M4_T!``@```!B_0$`'@```&O]`0`)````BOT!``\```"4_0$`0````*3]`0`Q
M````Y?T!`!\````7_@$`)@```#?^`0`.````7OX!`%4```!M_@$`3````,/^
M`0`&````$/\!`"(````7_P$`#@```#K_`0`0````2?\!`!D```!:_P$`!@``
M`'3_`0`*````>_\!``P```"&_P$`#@```)/_`0`)````HO\!`!8```"L_P$`
M"P```,/_`0`3````S_\!``@```#C_P$`(@```.S_`0`+````#P`"``@````;
M``(`!0```"0``@`%````*@`"``P````P``(`#0```#T``@`-````2P`"`#X`
M``!9``(``@```)@``@`&````FP`"``T```"B``(`"0```+```@`'````N@`"
M`!$```#"``(`"@```-0``@`E````WP`"``L````%`0(`(@```!$!`@`$````
M-`$"`#8````Y`0(`'@```'`!`@`6````CP$"`"X```"F`0(`%````-4!`@`H
M````Z@$"`&H````3`@(`%````'X"`@!$````DP("`!\```#8`@(`#P```/@"
M`@`)````"`,"`!,````2`P(`"@```"8#`@`-````,0,"``\````_`P(`"P``
M`$\#`@`4````6P,"``T```!P`P(`&0```'X#`@`5````F`,"``,```"N`P(`
M$0```+(#`@`'````Q`,"``@```#,`P(`#P```-4#`@`,````Y0,"`",```#R
M`P(`$0```!8$`@`4````*`0"`!T````]!`(`$````%L$`@`G````;`0"``<`
M``"4!`(`"0```)P$`@`)````I@0"`!0```"P!`(`$@```,4$`@`2````V`0"
M`!H```#K!`(`$@````8%`@`/````&04"`!8````I!0(`"@```$`%`@`)````
M2P4"``@```!5!0(`$````%X%`@`2````;P4"``8```""!0(`$0```(D%`@`(
M````FP4"`!$```"D!0(`!0```+8%`@`;````O`4"``\```#8!0(`+@```.@%
M`@`2````%P8"``8````J!@(`!P```#$&`@`8````.08"`!@```!2!@(`!@``
M`&L&`@`2````<@8"``4```"%!@(`!````(L&`@`9````D`8"``4```"J!@(`
M!P```+`&`@`7````N`8"`"<```#0!@(`'@```/@&`@`%````%P<"`!L````=
M!P(`$@```#D'`@`%````3`<"`!(```!2!P(`$0```&4'`@`$````=P<"``\`
M``!\!P(`"````(P'`@`'````E0<"``H```"=!P(`"````*@'`@`%````L0<"
M`"````"W!P(`,P```-@'`@`\````#`@"`!P```!)"`(`)P```&8(`@`@````
MC@@"`#X```"O"`(`&@```.X(`@`@````"0D"`"\````J"0(`6````%H)`@`G
M````LPD"``8```#;"0(`"````.()`@`&````ZPD"`!(```#R"0(`"P````4*
M`@`9````$0H"`!D````K"@(`+````$4*`@`?````<@H"`!L```"2"@(`-@``
M`*X*`@`\````Y0H"``0````B"P(`%0```"<+`@`&````/0L"``8```!$"P(`
M)````$L+`@`2````<`L"`!4```"#"P(`$@```)D+`@`9````K`L"`!$```#&
M"P(`#0```-@+`@`'````Y@L"``X```#N"P(`"````/T+`@`6````!@P"``P`
M```=#`(`&@```"H,`@`;````10P"`#@```!A#`(`"0```)H,`@`%````I`P"
M``4```"J#`(`!0```+`,`@`;````M@P"`!(```#2#`(`!````.4,`@`)````
MZ@P"``L```#T#`(`$``````-`@`.````$0T"`!T````@#0(`#P```#X-`@`%
M````3@T"``4```!4#0(`#````%H-`@`U````9PT"`%D```"=#0(`#@```/<-
M`@`*````!@X"`!`````1#@(`&@```"(.`@`3````/0X"``X```!1#@(`%0``
M`&`.`@`7````=@X"`!<```".#@(`%````*8.`@`>````NPX"``<```#:#@(`
M(@```.(.`@`;````!0\"``\````A#P(`$@```#$/`@`-````1`\"``@```!2
M#P(`#P```%L/`@`3````:P\"`!0```!_#P(`$0```)0/`@`;````I@\"`"T`
M``#"#P(`"0```/`/`@`,````^@\"`!,````'$`(`#@```!L0`@`0````*A`"
M`!8````[$`(`#0```%(0`@`Z````8!`"``D```";$`(`'P```*40`@`5````
MQ1`"`!D```#;$`(`B@```/40`@`[````@!$"`"8```"\$0(`"@```.,1`@`^
M````[A$"`#\````M$@(`.P```&T2`@`4````J1("``P```"^$@(`$````,L2
M`@`-````W!("`!(```#J$@(`(````/T2`@`'````'A,"`!8````F$P(`"```
M`#T3`@`4````1A,"`!(```!;$P(`!P```&X3`@`3````=A,"`"@```"*$P(`
M!P```+,3`@`&````NQ,"``\```#"$P(`#@```-(3`@`5````X1,"``0```#W
M$P(`"````/P3`@`,````!10"``P````2%`(`#0```!\4`@`1````+10"`!$`
M```_%`(`!P```%$4`@`%````610"`#0```!?%`(`)````)04`@`D````N10"
M``<```#>%`(`#P```.84`@`&````]A0"`!P```#]%`(`(0```!H5`@`D````
M/!4"``X```!A%0(`"0```'`5`@`>````>A4"``,```"9%0(`!@```)T5`@`*
M````I!4"``(```"O%0(`#````+(5`@`3````OQ4"``L```#3%0(`%0```-\5
M`@`9````]14"`!8````/%@(`!0```"86`@`*````+!8"`!,````W%@(`%@``
M`$L6`@`&````8A8"``X```!I%@(`!@```'@6`@`+````?Q8"``D```"+%@(`
M#P```)46`@`1````I18"``X```"W%@(`$0```,86`@!5````V!8"`!T````N
M%P(`,0```$P7`@`/````?A<"``0```".%P(`!@```),7`@`3````FA<"``L`
M``"N%P(`$0```+H7`@`<````S!<"``X```#I%P(`&@```/@7`@`-````$Q@"
M`!L````A&`(`&````#T8`@`.````5A@"`!\```!E&`(`#@```(48`@`@````
ME!@"``X```"U&`(`+````,08`@!=````\1@"``P```!/&0(`+@```%P9`@`M
M````BQD"`&H```"Y&0(`)````"0:`@`6````21H"`!<```!@&@(`&0```'@:
M`@`8````DAH"`"$```"K&@(`)@```,T:`@`B````]!H"`!0````7&P(`)0``
M`"P;`@`O````4AL"`!D```""&P(`,P```)P;`@`9````T!L"``X```#J&P(`
M&````/D;`@`*````$AP"`$L````='`(`$````&D<`@!*````>AP"``<```#%
M'`(`"````,T<`@`)````UAP"`!0```#@'`(`#0```/4<`@`T`````QT"`!0`
M```X'0(`'0```$T=`@`'````:QT"``X```!S'0(`&````((=`@`[````FQT"
M`",```#7'0(`%P```/L=`@!.````$QX"`'0```!B'@(`+P```-<>`@!X````
M!Q\"``H```"`'P(`*````(L?`@`W````M!\"``@```#L'P(`'````/4?`@`2
M````$B`"`!,````E(`(`"````#D@`@`,````0B`"`#8```!/(`(`"````(8@
M`@`1````CR`"`!X```"A(`(`2P```,`@`@!)````#"$"`"8```!6(0(`,P``
M`'TA`@`Y````L2$"`#,```#K(0(`*````!\B`@`@````2"("`"<```!I(@(`
M)P```)$B`@`O````N2("`"$```#I(@(`+`````LC`@`F````.","`"T```!?
M(P(`)@```(TC`@`S````M","`!````#H(P(`"````/DC`@`-`````B0"``\`
M```0)`(`#@```"`D`@`'````+R0"`#0````W)`(`#````&PD`@`0````>20"
M``8```"*)`(`$@```)$D`@`(````I"0"``<```"M)`(`$````+4D`@`)````
MQB0"``D```#0)`(`"````-HD`@`0````XR0"`!````#T)`(`%0````4E`@`7
M````&R4"``T````S)0(`(@```$$E`@`2````9"4"``@```!W)0(`#@```(`E
M`@`5````CR4"``\```"E)0(`#````+4E`@`F````PB4"``X```#I)0(`'P``
M`/@E`@`E````&"8"``D````^)@(`!@```$@F`@`2````3R8"``H```!B)@(`
M!````&TF`@`;````<B8"``X```".)@(`#P```)TF`@`/````K28"``8```"]
M)@(`"0```,0F`@`)````SB8"``H```#8)@(`"0```.,F`@`.````[28"``8`
M``#\)@(`#`````,G`@`.````$"<"``4````?)P(`%````"4G`@`$````.B<"
M``\````_)P(`"````$\G`@`+````6"<"``\```!D)P(`&0```'0G`@`*````
MCB<"``(```"9)P(`(````)PG`@`'````O2<"``<```#%)P(`<@```,TG`@`+
M````0"@"``8```!,*`(`)@```%,H`@`^````>B@"`!P```"Y*`(`)P```-8H
M`@!1````_B@"`"$```!0*0(`,@```'(I`@`?````I2D"`!0```#%*0(`!0``
M`-HI`@`%````X"D"``P```#F*0(`"P```/,I`@`&````_RD"``<````&*@(`
M#`````XJ`@`2````&RH"``X````N*@(`"P```#TJ`@`-````22H"``L```!7
M*@(`!P```&,J`@`'````:RH"``H```!S*@(`%````'XJ`@`)````DRH"``<`
M``"=*@(`"P```*4J`@`A````L2H"``8```#3*@(`*````-HJ`@`%`````RL"
M``4````)*P(`#P````\K`@`%````'RL"``H````E*P(`"0```#`K`@`'````
M.BL"`!(```!"*P(`$@```%4K`@`&````:"L"`!8```!O*P(`"P```(8K`@`(
M````DBL"``4```";*P(`!0```*$K`@`/````IRL"`!P```"W*P(`!P```-0K
M`@`)````W"L"`"8```#F*P(`'`````TL`@`-````*BP"``D````X+`(`!```
M`$(L`@`(````1RP"`!````!0+`(`"0```&$L`@`"````:RP"``<```!N+`(`
M,P```'8L`@`?````JBP"`"<```#*+`(`(0```/(L`@`J````%"T"`"D````_
M+0(`6@```&DM`@`1````Q"T"`"0```#6+0(`'````/LM`@`;````&"X"`"8`
M```T+@(`&@```%LN`@`B````=BX"`%\```"9+@(`+@```/DN`@!)````*"\"
M`&P```!R+P(`'@```-\O`@`P````_B\"`#`````O,`(`/@```&`P`@!`````
MGS`"`#X```#@,`(`-````!\Q`@`H````5#$"`#$```!],0(`*P```*\Q`@`?
M````VS$"`#H```#[,0(`)0```#8R`@#+`0``7#("`!P````H-`(`#P```$4T
M`@`_````530"`'P```"5-`(`0P```!(U`@`:````5C4"`#(```!Q-0(`7@``
M`*0U`@!(`````S8"`"$```!,-@(`=0```&XV`@`7````Y#8"`!````#\-@(`
M'@````TW`@`9````+#<"`!@```!&-P(`)P```%\W`@`@````AS<"`!X```"H
M-P(`,0```,<W`@`9````^3<"`!`````3.`(`-````"0X`@`C````63@"`"$`
M``!].`(`(0```)\X`@`O````P3@"`"(```#Q.`(`.0```!0Y`@!4````3CD"
M`"\```"C.0(`1P```-,Y`@`P````&SH"`"<```!,.@(`00```'0Z`@!>````
MMCH"`$4````5.P(`*P```%L[`@`H````ASL"`#````"P.P(`)0```.$[`@`L
M````!SP"`"L````T/`(`5@```&`\`@`H````MSP"`$\```#@/`(`.0```#`]
M`@!*````:CT"`$D```"U/0(`(@```/\]`@`S````(CX"`"P```!6/@(`+```
M`(,^`@`M````L#X"`&4```#>/@(`6@```$0_`@!C````GS\"`)T````#0`(`
M%0```*%``@`C````MT`"`"\```#;0`(`+P````M!`@!!````.T$"`"````!]
M00(`5````)Y!`@`G````\T$"`"$````;0@(`"P```#U"`@"U````24("`!<`
M``#_0@(`2````!=#`@`?````8$,"`#8```"`0P(`(@```+=#`@`>````VD,"
M`"P```#Y0P(`!P```"9$`@`'````+D0"``<````V1`(``P```#Y$`@`.````
M0D0"``T```!11`(`"P```%]$`@`*````:T0"``T```!V1`(`"P```(1$`@`&
M````D$0"``<```"71`(`&0```)]$`@`#````N40"`%L```"]1`(`!````!E%
M`@`G````'D4"``0```!&10(`!P```$M%`@`&````4T4"``4```!:10(`!```
M`&!%`@`3````944"``@```!Y10(`$0```()%`@`5````E$4"``(```"J10(`
M!@```*U%`@`'````M$4"``<```"\10(`#````,1%`@`.````T44"``8```#@
M10(``P```.=%`@`4````ZT4"``P`````1@(``P````U&`@`G````$48"``0`
M```Y1@(`!@```#Y&`@`(````148"`#````!.1@(`1P```']&`@`N````QT8"
M`"\```#V1@(`&P```"9'`@`O````0D<"`#(```!R1P(`)````*5'`@`A````
MRD<"`",```#L1P(`*````!!(`@`C````.4@"`"$```!=2`(`*@```'](`@`I
M````JD@"`"(```#42`(`,P```/=(`@`>````*TD"`!\```!*20(`,````&I)
M`@`M````FTD"`"(```#)20(`)@```.Q)`@`E````$TH"`"`````Y2@(`*0``
M`%I*`@`I````A$H"`"4```"N2@(`+P```-1*`@`<````!$L"`"$````A2P(`
M)0```$-+`@`I````:4L"`"````"32P(`*@```+1+`@`^````WTL"`$$````>
M3`(`'0```&!,`@`D````?DP"`"$```"C3`(`0````,5,`@`E````!DT"`"D`
M```L30(`*````%9-`@`I````?TT"`",```"I30(`-0```,U-`@`@`````TX"
M`"H````D3@(`)0```$].`@`Y````=4X"`"<```"O3@(`-0```-=.`@`,````
M#4\"``P````:3P(`%````"=/`@`O````/$\"`",```!L3P(`"P```)!/`@`7
M````G$\"``X```"T3P(`%@```,-/`@`(````VD\"``<```#C3P(`(@```.M/
M`@`E````#E`"`!X````T4`(`)P```%-0`@`E````>U`"``P```"A4`(`ZP``
M`*Y0`@`/````FE$"`"L```"J40(`&````-91`@`,````[U$"``\```#\40(`
M&`````Q2`@`?````)5("`!(```!%4@(`'P```%A2`@`&````>%("`#4```!_
M4@(`%@```+52`@`4````S%("``<```#A4@(`$P```.E2`@`*````_5("`#P`
M```(4P(`"@```$53`@`H````4%,"`!,```!Y4P(`%P```(U3`@`8````I5,"
M`!<```"^4P(`.````-93`@`@````#U0"`!(````P5`(`)````$-4`@`3````
M:%0"`!0```!\5`(`%0```)%4`@`*````IU0"`!<```"R5`(`"0```,I4`@`=
M````U%0"``@```#R5`(`'````/M4`@`F````&%4"``<````_50(`(P```$=5
M`@`'````:U4"``@```!S50(`"0```'Q5`@`T````AE4"``8```"[50(`$```
M`,)5`@`5````TU4"`!0```#I50(`"P```/Y5`@`,````"E8"``<````75@(`
M"P```!]6`@`,````*U8"`!P````X5@(`#P```%56`@`8````958"`!D```!^
M5@(`"P```)A6`@`-````I%8"`!<```"R5@(`"0```,I6`@`K````U%8"``P`
M````5P(`#P````U7`@`)````'5<"``(````G5P(`$0```"I7`@`8````/%<"
M``L```!55P(``P```&%7`@`+````95<"``8```!Q5P(`!@```'A7`@`)````
M?U<"``X```")5P(`"````)A7`@`4````H5<"``<```"V5P(`"P```+Y7`@`+
M````RE<"``X```#65P(`+0```.57`@`:````$U@"`!H````N6`(`30```$E8
M`@!,````EU@"`"$```#D6`(`"@````99`@`Z````$5D"``4```!,60(`%@``
M`%)9`@`W````:5D"``T```"A60(`#@```*]9`@`&````OED"``0```#%60(`
M!@```,I9`@`+````T5D"`!<```#=60(`!P```/59`@`(````_5D"``<````&
M6@(`"`````Y:`@`%````%UH"``\````=6@(`$````"U:`@`/````/EH"`#X`
M``!.6@(`,0```(U:`@`D````OUH"``4```#D6@(`&@```.I:`@`A````!5L"
M`"$````G6P(`(P```$E;`@`1````;5L"``(```!_6P(`!````();`@`*````
MAUL"``,```"26P(`!0```)9;`@`1````G%L"``4```"N6P(``P```+1;`@`)
M````N%L"`$P```#"6P(`)0````]<`@`P````-5P"`"L```!F7`(`&````))<
M`@!`````JUP"`"T```#L7`(`)0```!I=`@!?````0%T"`(@```"@70(`*```
M`"E>`@`X````4EX"`"D```"+7@(`)@```+5>`@`3````W%X"`!T```#P7@(`
M,`````Y?`@`M````/U\"`#(```!M7P(`>0```*!?`@`<````&F`"`%,````W
M8`(`(@```(M@`@`_````KF`"`#0```#N8`(`+@```"-A`@`A````4F$"`"P`
M``!T80(`-@```*%A`@`V````V&$"`#4````/8@(`,P```$5B`@`H````>6("
M`"(```"B8@(`)@```,5B`@!$````[&("`$0````Q8P(`1P```'9C`@`[````
MOF,"`$P```#Z8P(`%````$=D`@`T````7&0"``\```"19`(`;P```*%D`@`)
M````$64"`*(````;90(`>P```+YE`@!P````.F8"`"@```"K9@(`5````-1F
M`@`:````*6<"`!H```!$9P(`*0```%]G`@`7````B6<"``H```"A9P(`'0``
M`*QG`@`=````RF<"`#0```#H9P(`(P```!UH`@`8````06@"`%0```!::`(`
M'@```*]H`@`7````SF@"``H```#F:`(`!````/%H`@`&````]F@"``@```#]
M:`(`!0````9I`@`5````#&D"`!,````B:0(`&0```#9I`@`E````4&D"`!8`
M``!V:0(`$````(UI`@`.````GFD"``8```"M:0(`$@```+1I`@`$````QVD"
M``D```#,:0(`#P```-9I`@`(````YFD"``H```#O:0(`"````/II`@`)````
M`VH"`!8````-:@(`#@```"1J`@`-````,VH"``P```!!:@(`$0```$YJ`@`/
M````8&H"``T```!P:@(`"P```'YJ`@`&````BFH"``<```"1:@(`$P```)EJ
M`@`'````K6H"``L```"U:@(`%@```,%J`@`%````V&H"``T```#>:@(`!P``
M`.QJ`@`/````]&H"`!<````$:P(`"````!QK`@`)````)6L"`"4````O:P(`
M&P```%5K`@`,````<6L"`"0```!^:P(`$@```*-K`@`>````MFL"`!0```#5
M:P(``P```.IK`@`(````[FL"``,```#W:P(`$0```/MK`@`*````#6P"``H`
M```8;`(`!0```"-L`@`%````*6P"``(````O;`(`(0```#)L`@`(````5&P"
M``(```!=;`(``@```&!L`@`6````8VP"``@```!Z;`(`"````(-L`@`4````
MC&P"`!8```"A;`(`"````+AL`@`M````P6P"``(```#O;`(`"0```/)L`@`$
M````_&P"`!`````!;0(`%P```!)M`@`/````*FT"``\````Z;0(`#@```$IM
M`@`5````66T"``<```!O;0(`$@```'=M`@`%````BFT"`!L```"0;0(`!0``
M`*QM`@`6````LFT"`!$```#);0(`$@```-MM`@`"````[FT"``@```#Q;0(`
M#P```/IM`@`+````"FX"``T````6;@(`)````"1N`@`+````26X"``P```!5
M;@(`$P```&)N`@`3````=FX"``4```"*;@(`%0```)!N`@`"````IFX"``L`
M``"I;@(`!@```+5N`@`2````O&X"``8```#/;@(`!@```-9N`@`!````````
M``@(``!N!0``T````*@$``!E````F@$`````````````!00``,,%``"D`0``
MO`,`````````````Y@<``#<```!,````H0```!8%````````/P8```````#B
M!```0`<```````"8!0``%0@```````````````````````!"`@```````#\`
M``#D!@``408``(4$``"<!0``$P<``"@%``#T````K0,``'<%````````````
M`'H%``!&!```30,``'<'````````<@0``/,%````````PP0``%X&``!^`0``
M2`8``.D'``!5`0```````),`````````RP4```````!5!P``U08``$H!````
M````J@<``*X!````````D@$``/T!``">!P``Y@0```````!T!@``\P(``.4#
M`````````````.0%``#.!@``+`(```````#>`@``.0$``(,````-!@``Z@``
M```````6`0```````+$'````````4`<``#D%``!J!0``[````*8'```P"```
MTP$````````Q!0``N0,``'$#``#D!P``4`0``%('``#9`P````````````#2
M!P``'`(```````#C`0``^0,``!X!``!]`P``1`@``/X&````````>`,``.(&
M``#^`P``(@@``"$&````````AP<```````#K`@``6@(``/P```!2`0``U0,`
M`````````````````)0!``!M`0``8P(```4#````````3`@`````````````
M`````((````G`0``40````````!6`P``F@4``$<(```L!```=@,```````"M
M`0````````````"$!0``!0$``(@#````````Z`0``'\'````````>P```*4$
M```3`P``]0<``$L%``!4`@````````T%````````1````"`#``#B`@``^P<`
M```````C`@`````````````#!@``>@8``,4'````````.`8``+<'``"N!@``
M@0<``)P```#Y!0```````(T```!#"```Q0````H#``"K"```X`$``(\'````
M````+``````````3!@``U@4``%$$``!K!0```````-`%```9"```*`$``$,$
M```]!0``"P0``%,```!["```0P$``%4````@!P```````!0%```<`P``[P4`
M`'`$``#.`0``,`8``*\&``",!0````````````"=!```M0,``,4"``!R````
M-0<``+T%``"H!0``4@@``"L&``"4!@``5P<``,@!``!Y````GP4``)P(````
M````DP<``"`(````````H0(`````````````R08``+0"````````(`0``($(
M``"H`@```````#@#````````@`@`````````````/@```!($````````````
M`!@#``"=`````````,0$``!L"```;0,``-X'``">`@``3P<```````!F!```
MN`,``&X``````````````#T"``#G`@``80<``#L"````````D0(```````"[
M`0``*0```$H&````````=0@```````#<`P```````,$!``#4!@``3`0`````
M```9`P``!P4``(<`````````=0(``*X'```8````"`<``)````#Q!```````
M`.0```"B!P``S0(``#H%``"S`P``-0,``,D'````````@@0``+H(``#8!```
M``````````"8`P```````+(%``"#!0``504`````````````P`$```````!I
M`````````'`"``#-!```(@(```````!K`@``7P```'@'`````````````"4'
M````````7@,``!<%``"&`0```````),$```*`@``\0,`````````````>@``
M`#,#``"]!@``&0<``+`'````````*@$``.X'``#1!```^P(```````!%!0``
M<@4``*@(``````````````````"0!```P@``````````````TP8```````!/
M!0``O@<``'\```````````,```````!``P``5`,``"\```"O!P```````",$
M``!P!@``4`(``$`!``#/`P``,@@``.X!``"="```I@```)<#```Y`P``JP4`
M`+((````````B04`````````````#@<``+,&``#"!P``'````"H&````````
ME0<`````````````G@`````````=!P``/0```#`$```'`P````````("``!A
M!0``*`(```````````````````````!P`P``!P(```8`````````:0<`````
M``"`!P``WP````````#,!0``+P<````````3!```+@@````````/`P``000`
M`````````````````.D&``"!`0``F00````````6`P``R@(``-\$``"0!0``
M``````````#,````Y0$``#,`````````RP<``,0'````````508```T!````
M`````08``"$```"["```3P```%T&```K!0``E`<``(X```"$`0``O@4`````
M```]!@``_@$``&L`````````E@<``'P(``!;!```#`8`````````````H`$`
M`%8'``#N!0``;P(``"$%``!Z`0``EP4``#P&``"Y`0``Q@(``)H"``#2`0``
MKP$``,0!`````````````"0!``!#`P``WP4``(L#``"V`@``?`<````````X
M!``````````````J!P``#0@``*D&``"P````70$``*T````E"````````#<"
M``!N!P``#P0``',$``";`@``IP<``(0&```.`0``L`0`````````````````
M```````4"```XP<``/`'``#2````M@$``)`(``#(`P``_`,``/,#``#>`0``
M```````````>!0````````````!I!@``8@0``'T(``##`````````"$"``#:
M`0``I`(``%,&``!;"````````)D"``"E`@``!`0```````"#!```````````
M```4`0``M`4```D!``!F!@```````/T$```5`@``GP<`````````````NP``
M`"T!``!#`@``Q@<``"T%````````*@@``-$&``"N!0``7`0`````````````
M,0,`````````````;@@``````````````````"$(```.!```<@(``)(%````
M`````````/8'``#S`````````"<$``"3`P``HP,``-$#````````%0,``)T!
M``#Z!```,`4``.X&`````````````($$`````````````(H(```&`0``````
M`+H%``````````````````"J!`````````````"8!P``^@<````````=`0``
MTP,``$<'````````_`(```````!M"```8`(`````````````'P4```P$````
M````:0(```````"O`P``]@8``*H"``#?`P```````*P!````````E0,``+<&
M``#H!0``O`0````````?!P``O00``+0(``!-!0``[`<``#$'``!5`P``````
M`/8$```9!@``>P,``/H```#D!```#P```/@#````````$@<``%L%``#A!P``
MR``````````3!0``C04``#D`````````600``"8$``"G!```2````"0(``#?
M!@``*P@``$P&````````<P@``%("``#U`@```````&,```"'`@``F0$```D(
M``"^!```/`,``!,!``!V!P``QP(``$T&``!H`0``RP(````````I`@``F@,`
M`/D$``#`!P``U0```&T"``"R`P``W@8```,%``#Q!0``%`(``&8'``"5`0``
M-P@``````````````````'$'``#`!@``+0@``"8'`````````````"4&```5
M!0``V00``,P'````````C@8``(<&``#T!@``80$`````````````````````
M````````8P$``%X$```R`0``K`4``)L!``#"!0``_0,``+8'````````9@@`
M`/$````:````40@``*$&````````9@$``!(`````````AP$``,4#````````
M3P@``+P'``!7``````````,!``!8"```````````````````F08``/('``#V
M!0``C`8```````"\!0```````#P'``!S!@``\@(```````!3`P``>0,`````
M``#U`0``@@<``'\%````````I@@``%,$``!:!@```````-@"``"G````H`<`
M``$!````````500``/0%``!:"`````````````!B!@``Z`(```````#@````
MU@```,@&``!X`0``*08```4&``"^`P```````)0#``#2!````````*0(``#L
M!0``:`8```````#*!```,P(``(\%``!C`P``L08```````"6!````@8``!$$
M``"K!@``R@4``/,&``">!```SP$`````````````S0,````````#````N@``
M`*L!``"1!```(`$``"D'``!<``````````````#U!```A`,``#T!```>"```
M)0(``/4```#=!```I````'X&``!."```:00``#@```")`0``<P<``!`'````
M````#@,````````'````<`@``$P%``"%`0``&0(```````!I`0```````'H(
M```E!0``2@0``)@$``"[!0``#`4``#D'``#-!P``S`(``'4'```Y"```A0@`
M``````"*`0``V````%@&``#C!0``8P<``,("``!"!@``CP@``/L#``"%`P``
M'P0``#0&``"F`P``7P8``)0"``!$!P``CP0``/``````````Z04``(8(``#$
M!0```````+\(``"!`````````',#``"\`0``(P```*H```"_`0``D`(``'(&
M``"V`P``A@,``$L&``#W!````P<````````8`0``'P(``)@(``#U`P``U```
M``````#;`0``00<``'8%``#R!0```````'8&`````````````&`#````````
M:`,```````"K!```GP,``#L'``"S!0```````/<```!N`@``_@(``(H%``"5
M````5@0``$@'``#"`P``^@$``+<!``!!!0``6`$``````````````````!T`
M````````C@0```,"``!]!@``J`,``.8&``"Y!```F0<``'('```@!@``````
M````````````1`0``)0$``!%"```B`(``.8#``!6`@````````````"G`P``
M6@4````````9!0```````*,%``!$!@``'P8```````"I!0````````````"4
M"``````````````5!P```````,$%```U`````````(D$``!`"```1P```&$(
M``!("````````#D&``#%!`````````````"-`@``>`4``"H$``"Y````20``
M`$(!``"=!0``'@<````````^!0```````&$&```$!0``M@@````(``"O"```
MMP(``-@%``"N`P```````*`(```Y`@``00,``#@'``!*`P``(0,``-H$``#5
M`0``_P,`````````````'`@``#("````````L@$``*$#`````````````$(`
M``!J"```@@8``(<$```7!P``'0(``-H%``!F!0``EP@```````!+`@``6@,`
M`$4"`````````````&\$``!P`0``Z@$``+4"``!%!```F04``*,'``!Y`0``
MMP@``'H"````````````````````````EP$````````=!@``8````(<(``!P
M!P``R`0```L(``#+`P``40$`````````````$08``*\%``#F````'04`````
M````````2P`````$``!7`P``;@$```(!``"J"```-`(``*X(``"C!```-@@`
M``````"F!@``3P,``'@```"""```R@,```````#""``````````````<`0``
M3P(``-L%``#W`P``YP```!8&````````3P$```````#=`0```````*@!````
M``````````````#"!@``8P@``)8%````````P0```+L$```_`@``A@``````
M``"?"```DP@``+P&``!"!0```````"0```!0"```````````````````[`,`
M```````;````#P<``,\$````````]`$``!L%``"F`@``=0````````!B!0``
M`````)P!```8`@``+0,``+T#``!(!```3@4````````2`@``L00``(@!``#D
M`@```````/8!``!_"```+`<``-(&````````&0$``*<%````````Y`,``)X%
M```;!``````````````D!@``T`,``,L&``#;!P``1P(```````!B`P``````
M`$X$```^`P``/`0``-`$``#P!`````````````"&`@``M0```#@"```$!@``
M`````&P```!\`@```````.X$``#\`0``N@(``+H$```4!```HP@``%8(````
M````\`(````%``"V````X08``!<(``![!0``B0(``-<"``!G!```>`8`````
M```[`P``=P,``/T&``"P!@``U@,````````B`P``Y`$```````">`P``,```
M`((%`````````````*D"``!$!0``MP0``"8%``#A`P``!0(``"0'````````
MT@(``-X#``"S!```P@$``"4!```&`P``>@<``!8"``#<````*````*`"``#H
M`P``-`0``-\'```B!````````'P$```*``````````````"=`P``I`4``"H`
M```G!0``,`<``%`#``"1!0``>P0``&@``````````````)D#``#=!0``\0(`
M`.H&```*"```]@,``!(%``!4!@``Q08``!((```%!P``H`4```````"^````
M6P<```````!J````H04``#4"```T!0```````&0"``"J!@``4@0``%P'````
M`````````+T"``"+````#P$```````!B`@```````)P'````````XP0``!<#
M``!+!P``A`(``$`$``"$"```"0```$X&``!]`@``RP$``'D'``!W`0``M@8`
M``````"E!@``\P0```````"1!@``$04``*,!``":!````````$8&````````
M`````.H#````````IP(````````G````+P(``/P'``#-`0``<````%L!````
M````9@,``#0(`````````````!8```#B!0````````````#S`0``-@(``+X!
M``!K!```:`@``/H%``"A`0``>@,``,T```"Y!@``Y04``#T$``!>````T`(`
M```````D`@``'`4`````````````)P@``.,&``!'`P``?00``(<%````````
M@`0``(T'```W`P```````+(```!T````S@<``$0"``"&!P``>P(``,$$``#1
M`````````"T$``#^````C````&P&``"_!0``3`$``.('``!%````8`8``'T!
M``#4`@``XP```!0```!/!```60(``#<&``#)````D`8``&<(``#I`0``\08`
M`!0#``!-!P``LP```(,&```(!@``#00``)$#``#B`P``C@(``%\!````````
M`````*<(``"=`@``J00``+\``````````````/0"```V`0```````*@'````
M````S`8``%0%``#=!@``[@(``'D$``"1!P``:`4```````"5`@``BP8``(`"
M````````#0<``*D(``"[`@```````.$%``#Z`P``>0(``$D$``#-!0``C@@`
M```````K!P``E@```*4!`````````````,`%``!E`P``:P<``.\!``#0`0``
MB`4``.\`````````7@4``$P#``!V`@``KP(````````<!P``008``+$!```X
M`0``SP<``$8(``#\!```#0,````````.````K`@``)P&````````\@0``%\"
M``"T`0``40,```````#6`0```````/T%``#/````-`$``)\&``!S````"P4`
M`.D$``#4`0``6P,``!`!``!0````P@0``.\&```8!@```````(,!````````
M#`(``&D%``##`P``50@``)(```#6`@``6`<```````#0!@```````(X%``#`
M"```I0,``$<%``!U`0``<0`````````="```S@``````````````````````
M`````````````#H"``"@````3@,``'<$````````7P4``&\#```>!```````
M`'D%```:"``````````````'!```108``-L$```$"````````'0(``#U!@``
MP0<``&\```!`!0``9`$``.<#``#<`0```````#L%``"*!@``)@8``)("``#^
M!0``)`,``"P#```\"```G@8``-\!``!Q!0``P0,``!,"````````U@0``&(`
M```````````````````F`0``@0(``)H(````````KP```#0#``"=!@``````
M`#X(``#\!@``^`$``$4#````````,08``%0`````````N`@```````":!P``
M`````$H```"@!@``;@,```P```"L!P``<`4``(@'``````````````<(````
M`````````!@%```"!```XP,``*`#``#Y`0``H00``"$'```Z````UP0``-(%
M``!J!@``2`4``+`#``!<!0``)`0``*P#``#M`@```````)(&````````(@``
M`)L#``!+"```*@(``%D'````````V04`````````````N`4``"(%``"+"```
M`````````````````````````````````````,H`````````"00``/@"``"\
M`@``V`<``*H!```I`P``I0<``"D%``!1!0``.@8``"\(``#1`@``IP8``($%
M``!``@``00@``"\!``"!`P``Y00``&,%``")`P`````````````A`0``'P,`
M`+T`````````=@@``)$```"5!```&`0``%\#``!8!0``!04```````"9"```
M`````/\!``!C!````0(``(D&``````````````````!'`0``6@$``$@"````
M`````````.$``````````````&L!``!4!```-0@``'4%````````F`8``.@`
M``")"```,P$``-4"````````MP,```$$``"K!P``_P8`````````````8@$`
M`,D!``````````````````"Q````20@``%P"``#``P``(P4``+H#```H!P``
M?@(```0'``"4````O0<`````````````VP(```@!``")````8`<```````#:
M`P``*P$``$T(`````````````*,&`````0```````"P!``#]!P``/````.(`
M``",!```Q0$``(L"``"*`P``Y@$``/@'```H!@``FP<```````"_`@``L@8`
M`*T'```G`@``U`4``*L"``!M!0```````$0#````````A`0``/L$``!"!P``
M=P(``!P&````````70`````````*!P``2`,``.(!``#6!P``8`@``+L'``#`
M`@``=`4``"X"```^!```^08``*T&``"3!@``N@8``%D&````````+@<``&@$
M``!T!```:P8``"T"``"6!@``-P<``"@$``!)!P``F@8```@`````````"P$`
M`'P```"T!P`````````````2`P``904``*((``#>!0``(`(``````````@``
M`````*4```!N!````````(T!``#1!0```````&\'```T!P``<@@`````````
M````9P```,8!``"]`0```````"H#``"S!P``I@0``'P#````````G`0`````
M``#,!```]@```(`&````````B````/(&``"Y"```*00``)((```Y!```````
M`*X$``#R`````````,,"``#:!@``,@4```X&```1"````````&<"``#7!P``
M-@<``+4(```U!````````"8#``#>!````````+,"``!#!@```````.4'``#9
M`0``?P,``%X'`````````````"L$``#:`@``+P8``(4"``!/!@``9`0``%D%
M``#O`P``TP```%L```"#"```/0,``!L'```U`0``[P<``)D````E````4`4`
M```````+`P``0@,``'4&``#E````40(``"@(```&!P``)`4````````;`@``
MO`@``+$%``!K`P``E@,``"X$``!G!0``L@<``+,(```5`````````)(#``!E
M`0```````.L!``#&!@``&@(```@$````````$`,``+4&````````60@``!8(
M``#.!0```````"`%``!O"```?`$``$8```"K`P``?@,``(H`````````R04`
M`-P%```[`0```````!H$````````O`````````!]!0``^P8``"T&````````
MLP$`````````````!`(``#0```!>`0``+`@`````````````"@8``.`%``#W
M!P``=`<``)P"``````````````D&``"6"```1@4````````:!0``N`<``.@&
M``"/`P```P0``)P#``#1`0``2P,``"@#```."```]@(``"4#```7````V0``
M`&P!``"0`P``&P8``#(#```````````````````:!P``:@,```$%``#G!@``
MGP(```8(````````^`4``)`!````````,`$``/L!``#R`P``<0@```````!)
M`0``900```````!U!```:@0```````!]!P```````%@#``!3!P``VP,``)0%
M``!T`@``FP8```````"2!```I@$``(\!``!7`@```````(P#``"]"```V`$`
M```````(!0``L@(``!<&```5!@``.@@``(P"``!X!````````(`#``""`@``
M`````*$'```3"```Q@,``"<'`````````````!$"``#0!P``U00``.@'``"B
M`@``[`(````````C!@``,0(``%<$``#O!```S08``)\$````````]`0`````
M``#7````W0,``/@```",!P``O@@``!<"``!_`0``0@0``'L'``"E!0``````
M`*X"``!G!P``80(`````````````!P8```````"Y!0``YP0```````"-`P``
M[`$```````!A`````@,``&@"``#Q!P``=P`````````>!@```````.L%``!^
M"````````$8"``!^!P``=@```((!```Q`0``!`,``+0````X!0``SP(`````
M```P`P```````/$!```$````<0(`````````````M`0``"$$``"-"```UP,`
M`$8'```\`0``5`@``)('````````ZP0`````````````X`0``%D!````````
M208``,$(````````[0<``"T'``"5!@``$`(```D"``#@!P``OP8```````#>
M`````````"\$```N`P``L0(``#X"``#(!P````````````!3"```H`0``+$#
M``!R`0``=@0``'4#``!`!@```````(8&``#:!P``I@4``%0'``#1!P``-P$`
M``T"``#C`@````````P#``!L!P``-@0````````C"````````/H"````````
M``````X%``!&`0``7`@````````]!P``\`4``/\"``#N`P``&@,``!$#````
M`````````.`#``!O`0``K`(````````0"````````/@$```O`P``#`<`````
M````````#@(``-D&```F````R0(````````?`0``6```````````````J@,`
M`*<!```J!0``L`(``$T$``"+!0````````````````````````L```"T!@``
M$0<``'$$````````0P<``.T$``!6!@``M`,``"L"``"U!```I`,``%(#````
M````(P,``#\(````````10$``!(&``!Q!@```````(8$```X"```X00`````
M````````1P8```````"%!P```````+\'``#M!@```````$D"````````GP$`
M```````9````-04````````]"```B@<``.L```#<`@``CP8``,8```#\!0``
M6`(``#H'`````````````,,&``#A`0``;@8```````!3`0``UP$```````!D
M`P``"P(``$````"P"```)@(```````"8`@``5P8``,4%````````````````
M``!=`P``4@8``%(```!T`P````````````#+!```NP,```\&``"W!0``````
M`*0'```````````````````W!0``5@4``%L&```,`0``/`4`````````````
M`````)@```#3!````````!`$``"1"````````%@$``"D!@``@P,``*D`````
M````!@8``,@%````````SP8``+D"``"=!P``ZP,``&<&``!<`0``````````
M``!6````(@$```````!4`0``[04``$P"``":````?P(``'8!``#[!0``C00`
M`(@(`````````````+D'``"3!0``60````````![`0````````((``#E!@``
M,P@``.`"``"J!0``,@<``&`$```[````R0,``)8"``","```'`0`````````
M````KP0``*T(``"Q"````````%T"``!0`0````````````#G`0``!@(`````
M```V`P``5@$``"P&`````````````/<&````````30(```````#(`@``9P$`
M`(D'````````4P(``!L(`````````````#H$``##`0```````/X'``!J`0``
M00$``+4!``#;````+@$````````:`0``-@8```````"+!P``_0````````!9
M`P``TP(```````"&!0``"04`````````````Q`@``+@"````````HP(``%X(
M``#.!```>P8````````>`P``,0`````````["```-08``/X$````!P``/P<`
M`&$#``"(!```00(``%\$``!.`0``$`8``(4`````````&`@``$X```">`0``
ML`$``+`%``"I`0``%@<```````"B`0``+P4``(H$```@````%@0```````#_
M!P``20,``*L```!S`@``_P0```````!7!0``W0<``#H!``"#`@``2@@``#X!
M```1````J`8``.D```#W`0``/@<``+H'````````?P0```````!Y"```;`4`
M`````````````````%`&``!.`@````````````!3!0``^0(``&8"``"V!```
M?@4``*T%````````U0<``%H```!5`@``S@,``-,'``#;!@````````````#Z
M!@``=`$```\(```;`0``FP@``'T`````````C@<``-@&``!.!P``````````
M``!J`@``.P8```````#:````Q@0``)X(````````V`,``+8%``!-````_P``
M`-,%``!M````'P@``!<$``";!```Z@0``.T#``!-`0```````&@'``#Y!P``
MFP4```4(``"M`@``_0(``,8%````````5P@```````!<!@``10<``!0&``"`
M!0````````````!*`@``2P0````````V!0``E0@``!<!``#.`@``U@8```$#
M``!D!P```````'H$````!@``W`<``.H%```!"````````#,&```S!0``,P<`
M``````##"```<P4``#H#`````````````!$!``#T!P``NP8```````#)!```
M`````%L"``"7`@``!P<``&D(````````UP8```````"L!@``H@```-\"``"U
M!P```````%$'``"/`````````#X&````````%00``+\#``#4!```*P,``*P$
M````````P````$,```!#!0``,@0```,#```+!@``N`0```````#=````204`
M`!L#```>`@```````#P"````````QP$``````````````````"D(```=!```
M`````&((````````+@4`````````````,0@``%X"`````````````$H%``#$
M`P``<@,``.T!```9!````````,$&``"I`P``,@8``,<````)!P``$`4`````
M``#I`P``U`<``,\%``"'`P``&@8``&L(``"B!0``8P8``-T"``!E!P``DP$`
M``````"5!0``9`````````!Y!@``Y@(``.D"```C!P````````````#S!P``
M`````.<%`````````````,<'``#L!````````,H&````````00```*$(````
M`````````+X"```'`0``;0<``)L```!+`0``]04``,<#`````````````"8(
M``#!`@``QP0````````[!````````*(&``"E"```C08``(4&```V````RP``
M`#(```!X`@``"`,``,H'```)`P``:0,```H$```G!@``EP0```T`````````
M@```````````````+@8```````"R!```/P,``-0#``!<`P````````````#[
M``````````````#W`@``_P4```````#G!P``R@$``/`&````````N`````0!
M``!(`0``90(``&`!``"U!0``O@8```````!?!P```````(X#``#$````;`0`
M`+\$```B!P```````$8#``"6`0``?`4```(%``"$!P```````,<&````````
M`````(@&````````&`<````````_`0``700``'X$``!S`0``!0```.$"``#P
M`P```````.T`````````#P4```````#9!P``0@@``$0!````````%`<``.8%
M````````A````"D!``#O`@```````#,$``"!!@``7P@``&0&``#L!@``!@0`
M`'<(``````````````````#@!@``6@<``&$$`````````````&4(``"H````
M2@<```````#2`P``U04```````````````````('``!:!```Z@<``#\%``"Z
M`0``P`0``*,```#P`0``UP4``&T&``!G`P``'0,``*D'`````````````!,`
M``!B!P``#`@`````````````,`(``%(%```/`@``=P8``%T'````````````
M`)<```"N`````````#$$``#W!0```````````````````P@`````````````
MEP<``,0"``#X!@```````,0&```B!@``MP```*0$``!L`P`````````````!
M!P```````*(#``"X!@````````(```!^````QP4``'@(``!F````GP````8%
M```C`0``?P8``"4$``"#!P```````!````!@!0``3`<``"T````*`0``ZP8`
M`'$!``!O!0``C`$```````!=!0``S`$``!4!````````908```````!="```
MC@$``*P```##!P``D`<``(`!```+!P```````*($``#R`0``+`4``!(!``!J
M!P``*P```'P&```?````Z`$``"<#``"3`@``1P0```````"8`0``-P0``&P"
M````````"`(``%<!````````EP8``((#``#K!P``CP(``&0(````````[@``
M`+@!``!O!@```````(4%``#J`@``'@`````````N````BP0``,P#```*!0``
M`````(H"``"1`0```````/0#``#<!@``;00``-D"``"M!```Y0(``#\$``!D
M!0``W`0``/D`````````BP$````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME
M>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE
M<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@
M:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`
M(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S
M(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@8V%L96YD87)S(&9O
M=6YD`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"!E
M=F5N=',`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($1A>2AS*2`E
M<R!(;W5R*',I("5S($UI;G5T97,`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U
M<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y
M(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@871T96YD965S`"5S(&9I;&4@<W5C
M8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E
M<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K
M`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z
M("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@
M8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I
M;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S
M;VYA;"!I;F9O<FUA=&EO;BX`*$-L:6-K(&]N(&-A;&5N9&%R(&YA;64@=&\@
M<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE(&UA:6X@
M=VEN9&]W*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!!9&0@*@`J(%!L96%S
M92!S96QE8W0@861D<F5S<RAE<RD@*@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E
M<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@
M871T96YD964`,2!E=F5N=``Q(&AO=7(`,3(@2&]U<B!&;W)M870`,34@;6EN
M=71E<P`R,"!M:6YU=&5S`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#,P(&UI
M;G5T97,`/%!R979I;W5S`#QS=')O;F<^071T96YD965S/"]S=')O;F<^("AO
M<'1I;VYA;"D`/'-T<F]N9SY$97-C<FE?<'1I;VX\+W-T<F]N9SX@*&]P=&EO
M;F%L*0`\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO<'1I;VYA;"D`/'-T
M<F]N9SY296-U<G)E;F-E/"]S=')O;F<^("AO<'1I;VYA;"D`02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!30!!32!#;&]U9',`
M04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W
M97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!
M8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P=&5D`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D
M`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D7W9A;F-E9"!396%R8V@`
M061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@
M179E;G0`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S
M:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R
M;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!296UO=&4@0V%L96YD87(`061D
M(&$@;F5W(&5V96YT`$%D9"!A(&YE=R!U<V5R.@!!9&0@871T96YD965S`$%D
M9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K
M.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`
M061V86YC960@4V5A<F-H`$%F9VAA;FES=&%N`$%L87)M`$%L87)M("5D(&1A
M>7,@8F5F;W)E`$%L87)M("5D(&AO=7)S(&)E9F]R90!!;&%R;2`E9"!M:6YU
M=&5S(&)E9F]R90!!;&%R;2`E9"!W965K<R!B969O<F4`06QA<FT@,2!D87D@
M8F5F;W)E`$%L87)M(#$@:&]U<B!B969O<F4`06QA<FT@,2!M:6YU=&4@8F5F
M;W)E`$%L87)M(#$@=V5E:R!B969O<F4`06QA<FT@1&%T90!!;&%R;2!3<&%N
M("AM:6YU=&5S*0!!;&%R;2!4:6UE`$%L8F%N:6$`06QG97)I80!!;&EA<P!!
M;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@071T96YD965S`$%L;"!!=71H96YT
M:6-A=&5D(%5S97)S`$%L;"!&=71U<F4`06QL($=R;W5P<P!!;&P@4&%S=`!!
M;&P@4&5R;6ES<VEO;G,`06QL(%9I<VEB;&4`06QL(&1A>0!!;&P@9&%Y(&5V
M96YT`$%L;"!E=F5N=',`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_
M`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T
M92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R
M;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N
M871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD
M;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!
M;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`06YY`$%P<&QI8V%T:6]N
M`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY
M('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R
M:6P`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@
M86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R=`!!<G5B80!!
M<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N
M`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/P!!=`!!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL
M92!W:71H(&UO<F4@:6YF;W)M871I;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y
M;W5R(&UA:6P@8VQI96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U(&-A
M;B!U<V4@=&AI<R!F:6QE('1O(&5A<VEL>2!U<&1A=&4@>6]U<B!L;V-A;"!C
M;W!Y(&]F('1H92!E=F5N="X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N`$%T=&5N9&%N8V4`071T96YD965S`$%T=')I8G5T97,`075G=7-T`$%U
M<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q
M=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I
M=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I
M<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D
M9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`
M075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I
M8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I
M96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K
M9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E
M<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%N9VQA9&5S:`!"87)B
M861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M0F%S96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`
M0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A
M<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO
M8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@
M=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T
M:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U
M;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0G5S
M>0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?86QE;F1A<@!#
M7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T
M960N`$-A;%]E;F1A<@!#86QE;F1A<@!#86QE;F1A<B!3=6UM87)Y`$-A;&5N
M9&%R('-U8V-E<W-F=6QL>2!P=7)G960N`$-A;&5N9&%R<P!#86QE;F1A<G,@
M;75S="!H879E(&$@;F%M92X`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#
M86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&-R96%T92!A
M(&YE=R!E=F5N="X`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC
M96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;F-E;&QE9`!#86YC96QL960Z
M("5S`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A
M<'1I;VX`0V%T96=O<E]Y`$-A=&5G;W)I97,@86YD($QA8F5L<P!#871E9V]R
M>0!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#
M96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E
M;&QP:&]N90!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E<G1I
M9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@
M4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA
M;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N
M('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG
M('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R
M96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&]O<V4@07!P
M;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE
M`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&EF('EO=2!W
M86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E
M9"!E=F5N=',@8GD@96UA:6PZ`$-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N
M;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S+@!#
M:&]O<V4@:68@>6]U('=A;G0@=&\@<F5C96EV92!E;6%I;"!R96UI;F1E<G,@
M9F]R(&5V96YT<R!W:71H(&%L87)M<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D<F5S<R!B;V]K
M<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.@!#:&]O<V4@=&AE(&-A
M;&5N9&%R<R!T;R!I;F-L=61E(&EN('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N.@!#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E('=H96X@9V5N
M97)A=&EN9R!F<F5E+V)U<WD@55),<SH`0VAO;W-E('EO=7(@9&5F875L="!C
M86QE;F1A<BX`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A
M<B!1=65R>0!#;&5A<B!A;&P@871T96YD965S`$-L96%R(&]U="!U<V5R.B`E
M<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L
M:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN
M9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG
M*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`
M0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A
M;'5E<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M
M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I
M;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F
M;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K
M+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`
M0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\`
M0V]N9FER;65D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D
M.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R
M97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)
M<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C
M=&EO;@!#;W!Y('1H92!54DP@8F5L;W<@9F]R('5S92!W:&5R979E<B!Y;W4@
M;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ`$-O<W1A(%)I8V$`0V]T92!D)TEV
M;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A
M<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I
M;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@
M;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F
M<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R
M:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R
M;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I
M=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D
M('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@0V%L96YD87(`
M0W)E871E(&$@3F5W($5V96YT`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W
M(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI
M<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N
M=`!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4
M:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T
M:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI
M>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L
M96-T:6]N`$-Y<')U<P!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B
M+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A:6QY.B!296-U<G,@979E<GD`1&%T
M851R964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I
M=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$87DH<RD`1&5?;&5T90!$95]L971E
M($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C
M<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#86QE;F1A<@!$969A=6QT
M($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET
M:6]N<P!$96QE=&4`1&5L971E("5S`$1E;&5T92!#96QL`$1E;&5T92!%=F5N
M=`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R
M<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@86QL(&]C8W5R
M96YC97,_`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U
M<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S
M8W)I7W!T:6]N`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE
M;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O
M:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D`1&ES<&QA>2`R-"UH;W5R('1I
M;65S/P!$:7-P;&%Y($-A;&5N9&%R<P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA
M>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I
M<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T
M:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E
M(&1U92!O;B!Y;W5R(&-A;&5N9&%R/P!$;V5S(&YO="!R96-U<@!$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$
M;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL
M;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$1U93H@)7,`1'5R871I
M;VX`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="`E<P!%9&ET($%T=&5N
M9&5E<P!%9&ET($)L;V-K`$5D:70@0V%L96YD87)S`$5D:70@1W)O=7``161I
M="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N
M<R!F;W(@)7,`161I="!296UO=&4@0V%L96YD87)S`$5D:70@871T96YD965S
M`$5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S`$5D:70@;W!T:6]N<R!F;W(Z
M`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F
M;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`
M16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A
M=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`
M16UP='D@<V5A<F-H('1E<FUS`$5N7V0`16YA8FQE(&EN<V5R=&EO;B!O9B!I
M;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD($1A=&4`16YD($]N`$5N9"!4
M:6UE`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT
M97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R
M96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T
M:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@
M)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!R971R:65V:6YG
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,Z("5S`$5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R
M<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R
M;W!E`$5V96YT(&%D9&5D.@!%=F5N="!D96QE=&5D.@!%=F5N="!E9&ET960Z
M`$5V96YT(&9R;VT@)7,@=&\@)7,`179E;G0@;F]T(&9O=6YD`$5V96YT<R!M
M=7-T(&AA=F4@82!S=&%R="!D871E+@!%=F5N=',@;75S="!H879E(&$@=&ET
M;&4N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P
M('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA
M;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`
M17AP86YD`$5X<&%N9"!.86UE<P!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G
M*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%
M>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R="!#86QE;F1A
M<@!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A
M;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@
M;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T
M<FEX`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z
M("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I
M;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I
M;'1E<G,`1FEN9`!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&
M:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M
M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O
M<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P
M;VQI=&%N`$9R964`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R96YC:"!'=6EA
M;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,`1G)I9&%Y`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L
M;"!-;V]N`$9U;&P@3F%M90!&=71U<F4`1V%B;VX`1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=A;64`1V5N97)A;`!'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`
M1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`
M1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!';W1O("5S`$=R87ES8V%L90!'
M<F5E8V4`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`
M1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`
M1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M
M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA
M`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A
M8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S
M:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@
M86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96EG:'0`2&5L
M<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES
M('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9&4`2&ED92`E<P!(:6=H
M`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M
M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`
M2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D
M871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO
M(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B
M.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E
M+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G
M9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP
M92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ
M;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]U
M<BAS*0!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(
M;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@=&AE(&1A>2!A;F0@
M=V5E:R!V:65W<R!B93\`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2&]W(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@<VAO=6QD('=E(&=E;F5R871E/P!(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N
M9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T
M(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"
M969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W
M:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EF('EO=7(@
M96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP(')E<75E<W1S('EO
M=2!C86X@=7-E(&]N92!O9B!T:&4@9F]L;&]W:6YG(&QI;FMS('1O(&%C8V5P
M="!O<B!D96-L:6YE('1H92!E=F5N="X*"E1O(&%C8V5P="!T:&4@979E;G0Z
M"B5S"@I4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY.@HE<PH*5&\@
M9&5C;&EN92!T:&4@979E;G0Z"B5S`$EM86=E(%!R979I97<Z`$EM86=E(%52
M3`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A
M;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T($-A;&5N9&%R+"!3
M=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($-A;&5N9&%R
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@
M4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O
M;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@
M879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`
M26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"
M969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P
M87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T
M92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y
M;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@
M869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`
M26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P
M87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T
M(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I
M<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-
M;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F
M9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D
M871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!)
M;G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L
M:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A
M<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B
M:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@
M9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T
M960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC
M80!*86YU87)Y`$IA<&%N`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I
M9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*
M=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N
M96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,
M96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2V5Y=V]R9',`2VED<P!+:7)I8F%T
M:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E
M82P@4F5P=6)L:6,@;V8`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG
M=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T(#(T
M(&AO=7)S`$QA<W0@2&%L9@!,87-T($UO9&EF:65D`$QA<W0@36]N=&@`3&%S
M="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`
M3&%S="!996%R`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,`3&%S="!L;V=I;CH@3F5V97(`3&%S="!W965K`$QA='9I80!,87<`3&%Y
M;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE
M9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,
M:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I
M>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,
M871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R
M`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EM:70@
M=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z`$QI;FL`3&EN:R!P;VEN=',@=&\Z
M`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W
M:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@
M5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES
M="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T
M+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]?8V%T:6]N`$QO861I;F<N+BX`
M3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO
M9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A
M:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`
M3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M
M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L
M878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M
M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L
M:0!-86QT80!-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RX`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA
M<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W
M:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R
M<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R
M:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S
M86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@179E
M;G1S`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L
M96YG=&@`36%Y`$UA>6]T=&4`364`365D:6-I;F4`365E=&EN9P!-96UB97)S
M`$UE;G4@06QA<FUS`$UE;G4@3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS
M`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N
M`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`
M365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN
M:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:6YU=&4H
M<RD`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@
M2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E
M('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A
M<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO
M`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%52
M3`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYD87D`
M36]N9V]L:6$`36]N=&@`36]N=&@@5FEE=P!-;VYT:"!A;F0@>65A<@!-;VYT
M:&QY`$UO;G1H;'D@179E;G1S($QI<W0`36]N=&AL>3H@4F5C=7)S(&5V97)Y
M`$UO;G1H<R!!:&5A9`!-;VYT:',@0F5F;W)E`$UO;G1S97)R870`36]O;B!0
M:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E
M>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D
M>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O
M;F5N=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S=7!P;W)T960N`$UU
M;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M
M871I;VX`37D@0V%L96YD87)S`$UY($-A;&5N9&%R<SH`37D@1G)E92]"=7-Y
M(%523`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)
M($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R
M;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`
M3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N
M(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O
M<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($5V96YT
M`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T
M:6]N86PI`$YE=R!:96%L86YD`$YE=R!C86QE;F1A<B!C<F5A=&5D(&%N9"!A
M=71O;6%T:6-A;&QY('-H87)E9"!W:71H(&9O;&QO=VEN9R!G<F]U<"AS*3H@
M)7,N`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B
M;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`R-"!H;W5R<P!.97AT
M(#0@4&AA<V5S`$YE>'0@1&%Y`$YE>'0@36]N=&@`3F5X="!7965K`$YE>'0@
M665A<@!.97AT(&1A>0!.97AT(&]P=&EO;G,`3F5X="!W965K`$YE>'0^`$YI
M8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@86QA<FT`
M3F\@871T96YD965S`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@
M=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G
M>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.
M;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+@!.;R!C86QE;F1A<G,@87)E(&%V86EL86)L92!T;R!G=65S=',N`$YO(&-H
M86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L
M969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@96YD(&1A=&4`3F\@
M979E;G1S('1O(&1I<W!L87D`3F\@9FEL92!U<&QO861E9`!.;R!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE(&9O<B`E<P!.;R!I0V%L96YD
M87(@9&%T82!W87,@9F]U;F0N`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO
M;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U
M<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE
M9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R96-U<G)E
M;F-E`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S
M`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QI9"!E;6%I;"!A
M9&1R97-S(&9O=6YD`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC
M:70I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE
M<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R
M90!.;W0@82!D:7)E8W1O<GD`3F]T(&9O=6YD`$YO="!I;7!L96UE;G1E9"X`
M3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RX`3F]T:69I8V%T:6]N<P!.;W9E;6)E<@!.;W<`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R
M9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VX@86QL(&-A
M;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\`3VX@86QL('-H;W=N(&-A
M;&5N9&%R<P!/;B!M>2!C86QE;F1A<G,@;VYL>0!/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T
M=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@
M:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA
M;`!/<'1I;VYA;"!!='1E;F1E97,`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]V97)V:65W`$]W;F5R`$]W;F5R(%!E<FUI<W-I;VYS`$]W;F5R.B`E<P!0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I
M;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D
M($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M80!02%`@0V]D90!02%`@4VAE;&P`4$T`4$T@3&EG:'0@4F%I;@!032!3:&]W
M97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M
M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I
M;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@
M0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M`%!A<W0@179E;G1S($QI<W0`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`
M4&%T:`!0871T97)N`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6%N96YT;'D@9&5L971E
M('1H:7,@979E;G0_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D
M96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U
M`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L
M<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N
M`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A
M('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L
M(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S
M92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R
M>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT
M+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y
M<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA
M;F0`4&]L:71I8W,`4&]L;',`4&]R=&%L($]P=&EO;G,`4&]R='5G86P`4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I
M=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R
M92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S($1A>0!0<F5V:6]U
M<R!7965K`%!R979I;W5S(&1A>0!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O
M8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO
M;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@
M06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP
M86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1
M871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I
M;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H
M;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N
M90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E8W5R(%5N=&EL`%)E8W5R<F5N8V4`4F5C=7)R96YC
M92!$871A`%)E8W5R<F5N8V4@16YD($1A=&4`4F5C=7)R96YC92!);G1E<G9A
M;`!296-U<G)E;F-E(%1Y<&4`4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY
M`%)E8W5R<R!W965K;'D`4F5C=7)S('EE87)L>0!2961O97,@>6]U<B!L87-T
M(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O
M=W-E<@!296QO860`4F5M87)K<P!296UI;F1E<CH@)7,`4F5M;W1E($-A;&5N
M9&%R<P!296UO=&4@0V%L96YD87)S.@!296UO=&4@4V5R=F5R<P!296UO=&4@
M4W5B<V-R:7!T:6]N(%523`!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP
M;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92`E<P!296UO=F4@071T96YD
M964`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I
M;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I
M;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R!D96QE=&5S(&%L
M;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SX`
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!2
M97%U:7)E9`!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@071T96YD965S`%)E<75I<F5D
M($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O
M<F0`4F5S970@=&\@1&5F875L=',`4F5S<&]N<V4`4F5S=&]R92!,87-T(%%U
M97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S
M=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H
M="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A
M=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE
M<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A
M`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O
M<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`
M4V%T=7)D87D`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`
M4V%V92!!<R!.97<`4V%V92!!='1E;F1E97,`4V%V92!%=F5N=`!3879E($]P
M=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A
M<F-H`%-E87)C:"!#86QE;F1A<G,`4V5A<F-H($5N9VEN97,`4V5A<F-H(%)E
M<W5L=',`4V5A<F-H(&9O<B!C86QE;F1A<G,@8V]N=&%I;FEN9SH`4V5L96-T
M($9I;&5S`%-E;&5C="!A(&-A;&5N9&%R('1O(&5D:70`4V5L96-T(&$@9&%T
M90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E
M;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL
M`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T
M`%-E;&5C="!C86QE;F1A<G,@=&\@9&ES<&QA>3H`4V5L96-T(&-O;F9I<FUA
M=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I
M97=S(&%N9"!C:&]O<V4@9&5F875L="!V:65W+@!396QE8W0@;F]N90!396QE
M8W0@=&AE(&-A;&5N9&%R('1O(&EM<&]R="!T;SH`4V5L96-T('1H92!C86QE
M;F1A<BAS*2!T;R!E>'!O<G0@9G)O;0!396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`
M4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@
M:6UP;W)T.@!396QE8W0@=&AE(&9I<G-T('=E96MD87DZ`%-E;&5C="!T:&4@
M9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!S
M<&%N('1O('-H;W<Z`%-E;&5C="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N('-T
M87)T=7`Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=VAI
M8V@@979E;G1S('1O('-H;W<@:6X@=&AE('!O<G1A;"X`4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z
M`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N9"!A(&-A;F-E;"!N
M;W1I9FEC871I;VX@=&\@86QL(&%T=&5N9&5E<R!W:&5N(&1E;&5T:6YG('1H
M:7,@979E;G0`4V5N9"!A;B!E;6%I;"!T;R`E<P!396YD('5P9&%T97,O:6YV
M:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V
M96YT`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N
M=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO
M="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D
M+@!397-S:6]N<P!3970`4V5T(&5N9"!D871E`%-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="X`4V5T(')E8W5R<F5N8V4@96YD(&1A=&4`4V5T('-T87)T(&1A
M=&4`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R(&9R964O8G5S>2!C86QE
M;F1A<G,@86YD('EO=7(@;W=N(&%N9"!O=&AE<B!U<V5R<R<@9G)E92]B=7-Y
M(&]P=&EO;G,N`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO
M;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A
M=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE
M<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T
M<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T
M:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&%R92!N;W0@9F]U;F0Z("5S
M`%-H87)E9"!#86QE;F1A<G,`4VAA<F5D($-A;&5N9&%R<SH`4VAO<'!I;F<`
M4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W($-A;&5N9&%R`%-H;W<@8V%T96=O
M<GD@;&5G96YD/P!3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E
M(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/P!3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VXN`%-H;W<@9'5E('1A<VMS(&EN('1H92!C86QE;F1A
M<C\`4VAO=R!F<F5E+V)U<WD@;&5G96YD/P!3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E
M(&%N(&%L87)M('-E=#\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3
M:&]W('!I8VME<@!3:&]W('-H87)E9"!C86QE;F1A<G,@<VED92UB>2US:61E
M/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&%S:W,@
M=7-I;F<@8V%T96=O<GD@8V]L;W)S/P!3:&]W('1H92`E<R!-96YU(&]N('1H
M92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9P!3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C:"!D
M87D@:6X@=V5E:R!V:65W<S\`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S
M($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3
M:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA
M='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@
M36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E
M<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R
M<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@
M;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3
M;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3
M<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`
M4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU
M;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A7W)T`%-T86YD87)D
M`%-T87(@5')E:P!3=&%R="!$871E`%-T87)T($]N`%-T87)T(%1I;64`4W1A
M<G0@>65A<@!3=&%T7W5S`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R
M86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN
M9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#
M4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3
M=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA
M<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YD87D`4W5N;GD`4W5N
M<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@
M`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R
M9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`
M4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C
M:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@
M86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A
M8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@
M3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E
M<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E
M9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI
M<W1R871I;VX`5&5N=&%T:79E`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`
M5&5X='1O<`!4:`!4:&%I;&%N9`!4:&4@161I="!!='1E;F1E97,@<V-R965N
M(&ES(&YO(&QO;F=E<B!P<F5S96YT+B!%>&ET:6YG+@!4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R
M871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L
M;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z
M.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B
M;W1T;VT@<VED92!O;FQY`%1H92!C86QE;F1A<B`B)7,B(&-A;FYO="!B92!D
M96QE=&5D+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!C<F5A=&5D+@!4
M:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@8V%L96YD
M87(@(B5S(B!H87,@8F5E;B!R96YA;65D('1O("(E<R(N`%1H92!C86QE;F1A
M<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@8V%L96YD87(@8V]U;&0@;F]T
M(&)E('!U<F=E9#H@)7,`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@
M=&AA;B!T:&4@<W1A<G0@9&%T92X`5&AE(&5V96YT("(E<R(@:&%S(&)E96X@
M861D960@=&\@(B5S(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N
M`%1H92!E=F5N="`B)7,B(&AA<R!B965N(&1E;&5T960@9G)O;2`B)7,B(&-A
M;&5N9&%R+"!W:&EC:"!W87,@;VX@)7,@870@)7,N`%1H92!E=F5N="`B)7,B
M(&AA<R!B965N(&5D:71E9"!O;B`B)7,B(&-A;&5N9&%R+"!W:&EC:"!I<R!O
M;B`E<R!A="`E<RX`5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@
M<W5C8V5S<V9U;&QY('-E;G0N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O
M(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL
M;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R
M(&UE<W-A9V4N`%1H92!F;VQL;W=I;F<@:7,@82!M;W)E(&1E=&%I;&5D(&1E
M<V-R:7!T:6]N(&]F('1H92!E=F5N=#H`5&AE(&9U;&P@<V-R965N(&UO9&4@
M:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L
M;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L
M92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G
M92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A
M;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`
M5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@
M:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE
M(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E
M`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE(')E<75E<W0@=V%S(&EN8V]M<&QE=&4N(%-O;64@<&%R86UE
M=&5R<R!T:&%T(&%R92!N96-E<W-A<GD@=&\@86-C97!T(&]R(&1E8VQI;F4@
M86X@979E;G0@87)E(&UI<W-I;F<N`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M
M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T
M96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y
M;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E
M96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED
M92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P
M<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@
M;F\@979E;G1S(&UA=&-H:6YG('1H92!C=7)R96YT(&-R:71E<FEA+@!4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O
M(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E
M<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E
M<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES
M=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B
M;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE
M("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M`%1H97)E('=A<R!A;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E
M<P!4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N=#H@)7,`5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`
M5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I;F<@=&AE(&5V96YT.B`E<P!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S`%1H97)E('=A
M<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B
M;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W
M87,@86X@97)R;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@
M)7,Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C
M="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E
M>'!O<G0N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A
M;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R
M,S1A9B<N`%1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI
M<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S
M+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T
M:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:'5R
M<V1A>0!4:6-K971S`%1I;64`5&EM92!3<%]A;@!4:6UE(%1R86-K:6YG`%1I
M;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;64@<W!A;@!4:6UO<BU,97-T
M90!4:71?;&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@
M;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G
M;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O
M<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@
M5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5E<V1A>0!4=6YI<VEA`%1U<FME
M>0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L
M=0!4>7!E`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%52
M3"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ
M`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL
M92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T
M92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O
M(&1E;&5T92`B)7,B.B`E<P!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E
M;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE
M<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&
M:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@(B5S(CH@)7,`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N(&9O<B`E<P!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE
M('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H
M8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S
M="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@`%5N9FEL960`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D
M;VT`56YI=&5D(%-T871E<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN
M;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U
M<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO
M=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO
M=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L
M;W(`56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<P!5;G-U<'!O<G1E9"!%
M>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D
M("(E<R(N`%5P9&%T960Z("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5
M<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@
M;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!);G1E<F9A8V4`57-E<B!/<'1I;VYS`%5S
M97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`
M57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA
M;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A
M;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@
M;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A
M;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!6
M97)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A
M;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=R`E
M<P!6:65W($1A>0!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@
M)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N
M4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA
M(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@
M1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI
M;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@
M8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E9&YE<V1A>0!7965K`%=E
M96L@)60`5V5E:RAS*0!7965K;'D`5V5E:VQY.B!296-U<G,@979E<GD`5V5L
M8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@4V%H87)A
M`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@
M=&AE('%U;W1E(&-H87)A8W1E<C\`5VAA="!T:6UE('-H;W5L9"!D87D@86YD
M('=E96L@=FEE=W,@96YD+"!W:&5N('1H97)E(&%R92!N;R!L871E<B!E=F5N
M=',_`%=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S('-T87)T
M+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V96YT<S\`5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I
M;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES
M=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=O<FL@5V5E:P!7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L
M(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&
M4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E
M>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R`%EE87)L>0!996%R
M;'DZ(%)E8W5R<R!E=F5R>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@979E;G1S+@!9;W4@87)E(&YO="!A
M;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF:65D(&5V96YT+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&]N;'D@=7-E('1H:7,@9F]R;2!F
M<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN`%EO=2!C86YN;W0@:&%V
M92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@
M86X@96UA:6P@861D<F5S<R!C;VYF:6=U<F5D(&EN('EO=7(@4&5R<V]N86P@
M26YF;W)M871I;VX@3W!T:6]N<RX@66]U(&UU<W0@<V5T(&]N92`E<VAE<F4E
M<R!B969O<F4@979E;G0@;F]T:69I8V%T:6]N<R!C86X@8F4@<V5N="X`66]U
M(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E<RX`
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R!T
M:&4@<V5L96-T960@8V%L96YD87(N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S
M:6]N('1O(&1E;&5T92!T:&ES(&5V96YT+@!9;W4@9&\@;F]T(&AA=F4@<&5R
M;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N`%EO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X`66]U(&AA=F4@<W!E8VEF:65D(&%N(&EN=F%L:60@8V%L96YD
M87(N`%EO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E;F1E;F-E
M('1O('1H:7,@979E;G0N`%EO=2!H879E('-U8V-E<W-F=6QL>2!D96-L:6YE
M9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N`%EO=2!H879E('1E;G1A=&EV
M96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="X`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E
M;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C
M="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@<F5Q=65S=&5D('1O(&)E
M(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N
M9&%R<RX`66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT
M<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+@!9;W4@<F5Q=65S
M=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET960@:6X@
M>6]U<B!C86QE;F1A<G,N`%EO=2!R97%U97-T960@=&\@8F4@<F5M:6YD960@
M86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@
M4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R
M96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-A;&5N9&%R`%EO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I
M<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%M5;FYA;65D(&5V96YT70!;;&EN92`E<R!O9B`E<UT`
M7T%D;6EN:7-T<F%T:6]N`%]!;&%R;0!?0F%S:6,@4V5A<F-H`%]#3$D`7T1A
M=&%4<F5E`%]$96QE=&4@4F]W`%]%9&ET`%]';W1O`%]'<F]U<',`7TAE;'``
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQO9R!I;@!?
M3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7TUY($-A;&5N9&%R<P!?3F5W($5V
M96YT`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK
M+BXN`%]396%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]4;V1A
M>0!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&)E9F]R
M92!T:&4@979E;G0@<W1A<G1S`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`
M9&%Y`&1A>2AS*0!D87ES`&5N=')Y(&YO="!F;W5N9`!E=F5N=',N8W-V`&5V
M96YT<RYI8W,`9F%L;&EN9P!F:6QE`&9R;VT`9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D
M:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W
M87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@
M;6%K:6YG($E33RX`;6T`;6]N=&@H<RD`;F%M90!N;W0@:6UP;&5M96YT960`
M;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`&]N("5S(&%T("5S`&]N('1H
M92!S86UE(&1A=&4`;VX@=&AE('-A;64@=V5E:V1A>0!P97)C96YT`'!E<FUI
M<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`
M<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S
M;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K
M(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A
M;&5N9&%R+VE#86QE;F1A<@!V0V%R9`!V179E;G0@;F]T(&9O=6YD+@!W.@!W
M96%T:&5R+F-O;0!W965K`'=E96LH<RD@;VXZ`'=E96MS`'EE87(H<RD`4')O
M:F5C="U)9"U697)S:6]N.B!+<F]N;VQI=&@@,BXQ"E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`V+3`Q+3,Q(#(S.C0Q*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-BTP,BTP,B`R,SHU.2LP,3`P"DQA<W0M5')A;G-L871O<CH@279A;B!.;W)I
M<R`\=FEX0'9A>FMA+G-K/@I,86YG=6%G92U496%M.B!3;&]V86L@/'9I>$!V
M87IK82YS:SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@."UB:70*`"`H<')E9"`E<R!D\F%M:2D`("A+;.%V97-O=N$@
M<VMR871K82`E<RD`("AO("5S(&1N[2D`*&1N97,I`"`H>F%J=')A*0`@*';H
M97)A*0`@<OUC:&QO<[L@`"(E<R(@;FEE(&IE(&%D<F5SX7(N`"(E<R(@;FEE
M(&IE('!L871NX2!V;[5B82X`(B5S(B!N:64@:F4@;F%K;VYF:6=U<F]V86[I
M('8@<F5G:7-T<FD@2&]R9&4N`'IO8G)A>F]V8>@@<W1R;VUU("(E<R(@;F5B
M;VP@;N%J9&5N_2X`4VMU<&EN82`B)7,B(&)O;&$@<')I9&%NX2!D;R!S>7-T
MZ6UU+@!0<N%V;R`B)7,B(&)O;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+@`B)7,B
M(&YE8F]L;R!M;[YNZ2!V>71V;W)INSH@)7,N`%!O=;YI=/UC:"`E+C)F34(@
M>B!D;W9O;&5N_6-H("4N,F9-0B`H)2XR9B4E*0`E9"`E<R!A("5S`"5D(&[A
M:F1E;OUC:"!K86QE;F3A<F]V`"5D(&1N[2!D;R!V>7!RN6%N:6$@<&QA=&YO
M<W1I(%;AN6AO(&AE<VQA+@`E9"!U9&%L;W-T[0!P<F5D<&]V9>\@;F$@)60@
M9&[M`"5S("T@4&]Z;N%M:V$`)7,@9"X@)7,@:&]D+B`E<R!M:6XN`$]D=&QA
MZ&]K("5S`"5S($M"`$]P97+A8VEE(/ID<KYB>2!P<F4@87!L:6OA8VEU("5S
M("T@4&]T=G)D96YI90!.87-T879E;FEE("5S`%)E9VES=')O=F%N:64@9&\@
M87!L:6OA8VEE("5S`%!O9&UI96YK>2!P;W6^:71I82`E<P`E<R!UOB!E>&ES
M='5J92X`)7,@=F\@=OVY:V4@)7,@)7,`)7,@^NAA<W1N[6MO=@!S^F)O<B`E
M<R#Z<W!EN6YE(&EM<&]R=&]V86[]`$%P;&EKX6-I82`E<R!J92!P<FEP<F%V
M96[A(&YA('9Y:V]N86YI92!O<&5RX6-I[2#Z9'*^8GDN3WIN8>AT92"Y='9O
M<NAE:R!P<FD@;W!E<N%C:>%C:"P@:W1O<ND@8VAC971E('9Y:V]N8;L@=&5R
M87HN`%!OOF%D=6IE('-A("5S`"5S(&UI;OIT`"5S(&YE8F]L(&[A:F1E;OTN
M`"5S(&&^("5S('H@)7,`061R97/A<B!P;W6^[79A=&6U82`E<P!+86QE;F3A
M<B`E<P!0;WINX6UK>2!P;W6^[79A=&6U82`E<P!:;WIN86T@^FQO:"!P;W6^
M[79A=&6U82`E<P`E<SH@)7,`)7,Z(%3A=&\@<W!RX79A(&YE;75S[2!B>;L@
M;V0@;V1O<VEE;&%T9;5A+"!K=&]R_2!S82!Z;V)R87IU:F4@86MO(&]D;W-I
M96QA=&6U('-P<N%V>2X@6F%C:&]V86IT92!O<&%T<FYO<[L@<')I(&ML:6MA
M;NT@;F$@;&EN:WD@=B!S<'+A=F4@86QE8F\@<&]S:WET;W9A;NT@;W-O8F[]
M8V@@:6YF;W)MX6-I[2!O9&]S:65L871EM6]V:2X`*$ML:6MN:71E(&YA(&UE
M;F\@:V%L96YDX7)A+"!A8GD@<W1E('!R97!L:2!J96AO('9I9&ET9;5N;W.[
M('8@:&QA=FYO;2!O:VYE*0`J(%!R:61A:G1E(&ML:6MN=73M;2!N82!0<FED
M8;L@*@`J(%!R;W/M;2!V>6)E<G1E(&%D<F5S=2AY*2`J`"P@;N%R87IO=OT@
M`"P@=B!NX7)A>F]C:"`E<R`E<P`L('!R96UE;F[A('8@<F]Z<V%H=2`E<R!A
MOB`E<P`M+2!V>6)E<G1E('-I("TM`#$@^NAA<W1N[6L`,2!U9&%L;W.[`#$@
M:&]D:6YA`#$R+6AO9&EN;W;](&9O<FWA=``Q-2!M:6[Z=``R,"!M:6[Z=&$`
M,C0M:&]D:6YO=OT@9F]R;>%T`#(T(&AO9.UN`#,P(&UI;OIT80`\4')E9&-H
MX61Z86KZ8V$`/'-T<F]N9S[:Z&%S=&[M8VD\+W-T<F]N9SX@*&YE<&]V:6YN
M[2D`/'-T<F]N9SY0;U]P:7,\+W-T<F]N9SX@*&YE<&]V:6YN_2D`/'-T<F]N
M9SY+M?KH;W;I('-L;W;A/"]S;&]VX3X@*&YE<&]V:6YNZ2D`/'-T<F]N9SY/
M<&%K;W9A;FEE/"]S=')O;F<^("AN97!O=FEN;NDI`%!R92!T96YT;R!B;&]K
M(&IE('!OOF%D;W9A;OT@9&%T86+A>F]V_2!B86-K96YD+@!6>7-K>71L82!S
M82!ZX79AOF[A(&-H>6)A`$YA('IAN6EF<F]V86YI92!S<'+A=GD@:F4@<&^^
M861O=F%N_2!V97)E:F[](%!(4"!KM?KH+@!.82!O=F5R96YI92!P;V1P[7-A
M;F5J('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J;OT@4$=0(&NU^N@N`$YA
M(&1EN6EF<F]V86YI92!S<'+A=GD@<_H@<&]T<F5B;NDZ('9E<F5J;OT@4$=0
M(&NU^N@L('!R:7;A=&YY(%!'4"!KM?KH(&$@:&5S;&\N`$YA('!O9'#M<V%N
M:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9R96IN_2!01U`@:[7ZZ"P@<')I
M=N%T;GD@4$=0(&NU^N@@82!H97-L;RX`3F$@9&6Y:69R;W9A;FEE('-P<N%V
M>2!S^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH+"!P<FEVX71N
M>2!3+TU)344@:[7ZZ"!A(&AE<VQO+@!.82!P;V1P[7-A;FEE('-P<N%V>2!S
M^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH+"!P<FEVX71N>2!3
M+TU)344@:[7ZZ"!A(&AE<VQO+@!.82!Z8;EI9G)O=F%N:64@<W!RX79Y(&IE
M('!OOF%D;W9A;OT@=F5R96IN_2!334E-12!KM?KH+@!0<F5D<&]L=61N[6T`
M4')E9'!O;'5D;NUM(&]B;&'H;F\`4')E9'!O;'5D;NUM(+5A:&O](&3AON\`
M4')E9'!O;'5D;NUM(&3AON\`4')E9'!O;'5D;NUM('!R96CA;FMY`%!R961P
M;VQU9&[M;2!S;F5H;W;I('!R96CA;FMY`#$R(&AO9.UN`$%022!)1`!/('1O
M;71O(&5D:71O<F4`3RXN+@!!8G-O;/IT;GD@<W!O9&]K`$%B<V]L^G1N>2!S
M=')E9`!!:V-E<'1O=F%NX0!0<FD@=GET=N%R86[M(%9&4R!A9')E<^%R82!B
M;VP@>F%M:65T;G5T_2!P<NUS='5P+@!0<FD@=GET=N%R86[M(%9&4R!S^F)O
M<G4@8F]L('IA;6EE=&YU=/T@<'+M<W1U<"X`26YF;W)MX6-I92!O(/KH=&4`
M2&5S;&\@<')E(/KH970`VNAE="!Z86)L;VMO=F%N_2X`VNAT;W9A;FEE`%]2
M;WJY[7)E;ND@=GEHM6%DX79A;FEE`%!R:61ANP!0<FED8;L@<&]D<FEA9&5N
M^B!S:W5P:6YU`%!R:61ANR!P;V1R:6%D96[I('!RX79O`%!R:61ANR!U9&%L
M;W.[`%!R:61ANSH`4')I9&&[('-K=7!I;G4`4')I9&&[(&YO=ND@<'+A=F\`
M4')I9&&[(&1CZ7)S:W4@<VMU<&EN=2!D;R`B)7,B`%!R:61ANR!D8^ER<VME
M('!RX79O(&1O("(E<R(`4')I9&&[(&YO=OT@=GID:6%L96[](&MA;&5N9.%R
M`%!R:61ANR!N;W;Z('5D86QO<[L`4')I9&&[('!O=;[M=F%T9;5A.@!0<FED
M8;L@^NAA<W1N[6MO=@!0<FED8;L@<W3E<&5C`%!R:61ANR#H;&5N;W8`4')I
M9&&[('#A<@!0<FED8;L@;65N=2`E<R!A:V\@0F_H;OT@<&%N96P@36]Z:6QL
M>0!0<FED8;L@9&\@861R97/A<F$Z`%!R:61ANR!D;R!M]&IH;R!A9')E<^%R
M80!0<FED8;L@<&]UONUV871EM6$`(B5S(B!B;VP@<')I9&%N_2!D;R!S>7-T
MZ6UU+"!A;&4@;F5M;[YN;R!P<FED8;L@[V%LN6EE('!R:6AL87-O=F%C:64@
M:6YF;W)MX6-I93H@)7,N`"(E<R(@8F]L('!R:61A;OT@9&\@<WES=.EM=2X@
M5&5R87H@<V$@;?2^971E('!R:6ALX7-INRX`4')I9.%V86YI92!P;W6^[79A
M=&6U;W8@:F4@>F%KX7IA;NDN`$%D<F5S80!!9')E<^%R`$%D;6EN:7-T<N%C
M:6$@+2!N87-T879E;FEE('!RX78@<')E(&EN_6-H('!O=;[M=F%T9;5O=@!!
M9&UI;FES='+A8VEA`%)E:VQA;7D`4F]ZN>UR96[I('9Y:+5A9.%V86YI90!!
M9F=A;FES=&%N`$%L87)M`$%L87)M("5D(&1N[2!P<F5D`$%L87)M("5D(&AO
M9.UN('!R960`06QA<FT@)60@;6EN+B!P<F5D`$%L87)M("5D('3]OF3R;W8@
M<')E9`!!;&%R;2`Q(&1E\B!P<F5D`$%L87)M(#$@:&]D:6YU('!R960`06QA
M<FT@,2!M:6[Z='4@<')E9`!!;&%R;2`Q('3]OF1E\B!P<F5D`$3A='5M(&%L
M87)M=0!2;WIPY'1I92!A;&%R;74@*'8@;6EN^G1A8V@I`,AA<R!A;&%R;74`
M06QBX6YS:V\`06R^[7)S:V\`06QI87,`6F%R;W9N8;L`6F%R;W9N86YI93H`
M5KEE=&MY`%:Y971C:2#ZZ&%S=&[M8VD`5KEE=&-I(&%U=&5N=&EF:6MO=F%N
M[2!P;W6^[79A=&5L:6$`5KEE=&MY(&)U9/IC90!6N65T:WD@<VMU<&EN>0!6
MN65T:WD@;6EN=6SI`%:Y971K>2!P<N%V80!6N65T:WD@=FED:71EM6[I`$MA
MOF3](&1E\@!+8;YD;V1E;F[A('5D86QO<[L`5KEE=&MY('5D86QO<W1I`%:Y
M971K>2"Y='ER:2!S=')A;GD`4&]V;VQINR!V:6%C97+I(&%D<F5S>0!0;W9O
M;&F[(&YA<W1A=F5N:64@='EP=2!Z;W)A9&5NZ6AO('IO>FYA;74_`%6^(&5X
M:7-T=6IE`$%L=&5R;F%T[79N92!P<FEH;&%S;W9A8VEE(&UE;F\@24U34`!!
M;'1E<FYA=.UV;F4@:&5S;&\@24U34`!!;'1E<FYA=.UV;F4@<&]UONUV871E
MM7-KZ2!M96YO($E-4U``06QT97)N873M=FYA(&4M;6%I;&]VX2!A9')E<V$`
M06QT97)N873M=FYE(+EA8FSS;GD`06QT97)N873M=FYY('1E>'0Z`$%M97)I
M8VOA(%-A;6]A`$)O;&$@>F%D86[A(&YE<&QA=&[A(&AO9&YO=&$`3F%S=&%L
M82!N97INX6UA(&-H>6)A+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N
M>6UNZ2!P<F]X>0!/9'!O=F7O`$%N=&%R:W1I:V$`06YT:6=U82!A($)A<F)U
M9&$`I75B;W9OM6[A`$%P;&EKX6-I80!:;WIN86T@87!L:6OA8VGM`$%P;&EK
MX6-I82!J92!P<FEP<F%V96[A+@!!<&QI:V]V8;L@;F$@<&]D<FEA9&5NZ2!Z
M9&EEM6%NZ2!P<FEEZ&EN:WD`4V-H=N%L:;L`4')I8FQIOF[A('9EM6MO<[L`
M07!R[6P`5F6U:V]SNR!A<F-H[79U`$UE;F\@87)C:.UV=0!.86]Z86H@8VAC
M971E('9Y;6%Z8;L@OFEA9&]SNR!O('!R:6ALX7-E;FEE("<E<R<_`$YA;WIA
M:B!C:&-E=&4@=GEM87IANR`B)7,B(&$@=KEE=&MY('!O9'-K=7!I;GD_`$%R
M9V5N=.UN80!!<FWI;G-K;P!5;65N:64`07)U8F$`3W-T<F]V($%S8V5N<VEO
M;@!!<V-I:2!U;65N:64`P7II82]086-I9FEC:_T@<F5G:?-N`%9YOF%D;W9A
MNR!P;W1V<F1E;FEE('!R960@=GEK;VYA;NUM(&]P97+A8VGM(/ID<KYB>3\`
M3P!6('!R[6QO:&4@:F4@<_IB;W(@:4-A;&5N9&%R(',@9&5T86EL;OUM:2!I
M;F9O<FWA8VEA;6D@;R!U9&%L;W-T:2X@06L@5N&Y(&4M;6%I;&]V_2!K;&EE
M;G0@<&]D<&]R=6IE('!OOFEA9&%V:WD@:51I<"P@;?2^971E('1E;G1O('/Z
M8F]R('!O=;YINR!N82!J961N;V1U8VCZ(&%K='5A;&EZX6-I=2!68;EE:B!L
M;VOA;&YE:B!K\W!I92!U9&%L;W-T:2X`4&]K=7,@;R!V>6UA>F%N:64@;F5E
M>&ES='5J^F-E:B!S:W5P:6YY+@!0;VMU<R!O('9Y;6%Z86YI92!N965X:7-T
M=6KZ8V5H;R!P<N%V82X`4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J^F-E:&\@
M<'+A=F$N`%!O:W5S(&\@^G!R879U(&YE97AI<W1U:OIC96AO('ID:66U86[I
M:&\@;V)J96MT=2X`VNAA<[L`VNAA<W1N[6-I`$%T<FEB^G1Y`$%U9W5S=`!!
M=7-T<N%L:6$`4F%K^G-K;P!!=71H7V-Y<G-Q;#H@4&^^861O=F%NZ2!R;WJY
M[7)E;FEE(&EM87`@;F5B;VQO(&[A:F1E;NDN`$%U=&A?8WER=7,Z(&)A8VME
M;F0@;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN`$%U=&A?8WER=7,Z('!O
MOF%D;W9A;ND@<F]ZN>UR96YI92!I;6%P(&YE8F]L;R!NX6ID96[I+@!!=71H
M7V9T<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($944"!N96)O;&\@;N%J9&5N
MZ2X@4VMO;7!I;'5J=&4@4$A0(',@<')E<.UN8>AO;2`M+65N86)L92UF='`N
M`$%U=&A?:6UA<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($E-05`@;F5B;VQO
M(&[A:F1E;NDN`$%U=&A?:W)B-3H@<&^^861O=F%NZ2!R;WJY[7)E;FEE(&MR
M8C4@;F5B;VQO(&[A:F1E;NDN`$%U=&A?;&1A<#H@<')I9.%V86YI92!P;W6^
M[79A=&6U;W8@;FEE(&IE('!O9'!O<F]V86[I('!R92!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@=GEM87KA=F%N:64@<&]UONUV871EM6]V(&YI92!J
M92!P;V1P;W)O=F%NZ2!P<F4@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z
M('!OOF%D;W9A;ND@<F]ZN>UR96YI92!,1$%0(&YE8F]L;R!NX6ID96[I+@!!
M=71H7VQD87`Z($YE<&]D87)I;&\@<V$@<')I9&&[('!O=;[M=F%T9;5A("5S
M+B!397)V97(@;V1P;W9E9&%L.B``075T:%]L9&%P.B!N97!O9&%R:6QO('-A
M(&]D<W1RX6YINR!P;W6^[79A=&6U82`E<P!!=71H7VQD87`Z(&YE<&]D87)I
M;&\@<V$@86MT=6%L:7IO=F&[('!O=;[M=F%T9;5A("5S`$%U=&A?;&1A<#H@
M86MT=6%L:7KA8VEA('!O=;[M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;N$@
M<')E($%C=&EV92!$:7)E8W1O<GD`075T:%]M8V%L.B!P;[YA9&]V86[I(')O
M>KGM<F5N:64@34-!3"!N96)O;&\@;N%J9&5NZ2X`075T:%]S;6)A=71H.B!P
M;[YA9&]V86[I(')O>KGM<F5N:64@<VUB875T:"!N96)O;&\@;N%J9&5NZ2X`
M075T96YT:69I:^%C:6$@<&]M;V-O=2!)34%0('-E<G9E<F$@>FQY:&%L82X`
M075T96YT:69I:^%C:6$@>FQY:&%L80!!=71E;G1I9FEKX6-I82!Z;'EH86QA
M+B`E<P!397)V97(@4D%$2553('IA;6EE=&]L(&%U=&5N=&EF:6OA8VEU+@!!
M=71E;G1I9FEKX6-I82!P;VUO8V]U($944"!S97)V97)A('IL>6AA;&$N`$%U
M=&5N=&EF:6OA8VEA('!O;6]C;W4@4TU"('-E<G9E<F$@>FQY:&%L82X`1&]S
M='5P;ND@<&]L;[YK>3H`07IE<F)A:F2^86X`0D]&2"!%>&-U<V5S`%!O>F%D
M:64`1F%R8F$@<&]Z861I80!:;.D@:&5S;&\@<')E(&ME<F)E<F]S+@!:;.D@
M<&]UONUV871EM7-KZ2!M96YO('!R92!K97)B97)O<RX`0F%H86UY`$)A:')A
M:FX`0F%N9VQA9.FY`$)A<F)A9&]S`%!R:67H:6YO:R!S(&=R869I:V]U("(E
M<R(@;F5B;VP@;N%J9&5N_2X`6N%K;&%D;OT@<FEA9&]K`%KA:VQA9&[I(&BU
M861A;FEE`$)I96QO<G5S:V\`0F5L9VEC:V\`0F5L:7IE`$)E;FEN`$)E<FUU
M9'D`0G5TX6X`3F%R;V1E;FEN>0!";&]K("(E<R(@87!L:6OA8VEE("(E<R(@
M;F5B;VP@;N%J9&5N_2X`3F%S=&%V96YI82!B;&]K=0!4>7`@8FQO:W4`5'7H
M;ND`0F]L[79I80!:X6QOOFMY`$]K<F%J`*GM<FMA(&]K<F%J83H`3VMR86IE
M`$)O<VYA(&$@2&5R8V5G;W9I;F$`3V)E`$)O='-W86YA`$)O='1O;0!";W5V
M970@27-L86YD`$)R87KM;&EA`$)R:71S:^D@^GIE;6EE('8@26YD:6-K;VT@
M;V-EX6YE`$)R=6YE:2!$87)U<W-A;&%M`$)U;&AA<G-K;P!:;WIN86T@<R!O
M9'+AOFMA;6D`0G5R:VEN82!&87-O`$)U<G5N9&D`6F%N97!RX7ID;F5N_0!#
M35,`0U)#`$1I<W1R:6)UZ&[I(&)O9'D@0U),`$M?86QE;F3A<@!6;&%S=&YO
M<W1I(%]B=6YK>2XN+@!);F-I86QI>N%C:6$@=GER;W9NX79A8V5J('!A;>1T
M:2!N96)O;&$@9&]K;V[H96[A+@!+86Q?96YDX7(`2V%L96YDX7(`2V%L96YD
MX7)O=OT@<_IH<FX`2V%L96YDX7(@^G-P9;EN92!V>6UA>F%N_2X`2V%L96YD
MX7)E`$MA;&5N9.%R92!M=7-I82!M8;L@;65NX2X`0F5Z=F5T<FEE`$MA;6)O
M9+YA`$MA;65R=6X`3F5P;V1A<FEL;R!S82!A=71O;6%T:6-K>2!O8FYO=FF[
M(&AE<VQO+"!K;VYT86MT=6IT92!S=F]J:&\@861M:6YI<W1RX71O<F$N`$YE
M<&]D87)I;&\@<V$@>F%P[7-ANR!D;R!S^F)O<G4@(B5S(@!.96UOOFYO(&%D
M;6EI<W1R;W9ANR!E>'1E<F[I(&]V;.%D8>AE('-E9&5N[2X`3F5P;V1A<FEL
M;R!S82!S<&]J:;L@<R!)34%0('-E<G9E<F]M.B`E<P!.97!O9&%R:6QO('-A
M('9Y='9O<FF[(&YO=OH@=61A;&]SNRX`3F5P;V1A<FEL;R!S82!O='9O<FF[
M('/Z8F]R("(E<R(N`$MA;F%D80!:<G6Y:;L`6G)UN6F[('-P<N%V=2!O('!R
M;V)LZ6UE`%IR=;EE;ND`6G)UN65NZ3H@)7,`3F5P;V1A<FEL;R!S82!V>6UA
M>F&[('/Z8F]R("(E<R(N`$YE<&]D87)I;&\@<V$@;N%J<[L@9&_H87-N_2!A
M9')E<^%R+@!.96UOOFYO('!O:W)AZ&]V8;L@8F5Z('!A<F%M971R82`G=&%R
M9V5T1FEL92<N`$YE<&]D87)I;&\@<V$@;V1S='+A;FF[(&%D<F5SX7(@(B5S
M(BX`3F5M;[YN;R!O9'-T<N%N:;LL(&5X:7-T=6IE("5D(&YA<VQE9&]V;NUK
M;W8N`$YE;6^^;F\@<')E=7-P;W)I861ANRP@<&_H970@<&]L;[YI96L@<')E
M('!R975S<&]R:6%D86YI92!N97/Z:&QA<^T@<R!P;^AT;VT@=6QOOF5N_6-H
M('!O;&^^:65K+@!.97!O9&%R:6QO('-A('-M97)O=F&[('-P<N%V=2!N82!U
M<NAE;ND@Z.US;&\N`$MA<'9E<F1S:^D@;W-T<F]V>0!4:71U;&]K`$MA=&5G
M\W)?:6$`2V%T96?S<FEE(&$@<&]P:7-K>0!+871E9_-R:6$`2V%J;6%N<VOI
M(&]S=')O=GD`36]B:6QN_2!T96QE9O-N`%9L87-T;F]S=&D@8G5N:WD`5GEP
M;&YE;FEE(&)U;FMY.@!6;&%S=&YO<W1I(&)U;FMY`%)O>F]S='5P(&)U;FEE
M:SH`36]B:6QN_2!T96QE9O-N`$1O('-T<F5D=0!3=')E9&]A9G)I8VOA(')E
M<'5B;&EK80!0;V1R;V)NZ2!I;F9O<FWA8VEE(&\@8V5R=&EF:6OA=&4`5FQA
M<W1N[6L@8V5R=&EF:6OA='4`4&]L:71I:WD@<')E(&-E<G1I9FEKX71Y`,AA
M9`!:;65N:;L`6FUE;FF[(%9AN64@:&5S;&\`3F%S=&%V96YI92!M96YA(&$@
M861R:65S+"!K=&]RZ2!V:61I82"U=61I82P@:V7O(.CM=&%J^B!A(&]D<&]V
M961A:OH@;F$@5F&Y92!E+6UA:6QY+@!:;65N82!H97-L82!N:64@:F4@=B!A
M:W1UX6QN96H@:V]N9FEG=7+A8VEI('!O9'!O<F]V86[A+B`@2V]N=&%K='5J
M=&4@<W9O:FAO(&%D;6EN:7-T<N%T;W)A+@!:;F%K`%-?:V]N=')O;&]V8;L@
M;&EN:W4N+BX`0VAI;&4`R.UN80!6>6)E<G1E(&%P;&EKX6-I=3H`6G9OM71E
M('-I(&AE<VQO`%IV;[5T92!S:2!P;W6^[79A=&6U<VOI(&UE;F\`5GEB97)T
M92!S</1S;V(@>F]B<F%Z;W9A;FEA(&3A='5M;W8Z`%9Y8F5R=&4@<VDL(.AI
M(&-H8V5T92!B>;L@=7!O>F]R;F5N_2!N82!N;W;I+"!U<')A=F5NZ2!A;&5B
M;R!V>6UA>F%NZ2!U9&%L;W-T:2!E;6%I;&]M.@!6>6)E<G1E('-I+"#H:2!C
M:&-E=&4@8GF[('5P;WIO<FYE;OT@;F$@;F]VZ2P@=7!R879E;ND@86QE8F\@
M=GEM87IA;ND@=61A;&]S=&DN`%9Y8F5R=&4@<VDL(.AI(&-H8V5T92!D;W-T
MX79ANR!E;6%I;&]M('!R:7!O;6EE;FMY('!R92!U9&%L;W-T:2!S(&%L87)M
M;VTZ`%9Y8F5R=&4@='EP(+ET_6QU('IO>FYA;74@*'!R92!Z;W)A9&5NZ2!Z
M;WIN86UY*0!6>6)E<G1E(&%D<F5SX7(L(&MT;W+]('-A('!O=;YI:F4@;F$@
M:+5A9&%N:64@55),(',@:6YF;W)MX6-I86UI(&\@>F%N97!RX7ID;F5N;W-T
M:3H`5GEB97)T92!K86QE;F3A<F4L(&MT;W+I('-A('IA:')N^B!D;R!I;F9O
M<FWA8VEA;6GM(&\@5F&Y96H@>F%N97!RX7ID;F5N;W-T:3H`5GEB97)T92!K
M86QE;F3A<F4L(&MT;W+I('-A('IA:')N^B!P<FD@9V5N97)O=F%N[2!54DP@
M<R!I;F9O<FWA8VEA;6D@;R!68;EE:B!Z86YE<'+A>F1N96YO<W1I.@!6>6)E
M<G1E('-I(%;AN2!P<F5D;F%S=&%V96[](&MA;&5N9.%R+@!6:6%N;^AN_2!O
M<W1R;W8`1&5F:6[M8VEA('1R:65D>2`E<R!N96)O;&$@;N%J9&5NX2X`2F%S
M;F\`3V1S='+A;FF[('!R[6MA>GD@35-/9F9I8V4`5GEM87IANR!D;W1A>@!/
M9'-T<N%N:;L@=KEE=&O]8V@@^NAA<W1N[6MO=@!/9'-T<N%N:;L@<&]UONUV
M871EM6$Z("5S`$]D<W1RX6YINR!P;W6^[79A=&6U80!6>6UA>F&[('!O=;[M
M=F%T9;5S:^D@^F1A:F4`3F5S:_1R('9Y:F%S;F5N:64`2VQI:VYI=&4@<')E
M('!O:W)AZ&]V86YI90!#;&EC:V%T96QL(&-E>B!(5%10`%IA='9O<FF[(&]K
M;F\`3V)L86MY`%+A;F\@;V)L8>AN;P!/8FQAZ&YO`$-O8V]S("A+965L:6YG
M*2!)<VQA;F1S`%IB86QINR!";^AN_2!P86YE;`!:8F%L96[I(&]K<F%J90!+
M;VQU;6)I80!&87)B80!6_6)E<B!F87)B>0!6_6)E<B!F87)B>0!3=.5P8V4Z
M`$YA9'!I<WD@<W3E<&-O=@!+;VUI:W,`2&]D;F]T>2!O9&1E;&5NZ2#H:6%R
M:V]U`%!R[6MA>@!0<NUK87IO=OT@:6YT97)P<F5T97(`2V]M96YTX7(`0F6^
M;ND@;65N;P!+;VUO<GD`4W!O;&_H;F]SNP!0;^CM=&'H90!3=&%V`%-T878`
M4F]Z9&EE;'D@=B!K;VYF:6=U<N%C:6D`2V]N9FEG=7+A8VEA('!R92!S>6YC
M:')O;FEZX6-I=2!S(%!$02P@:6YT96QI9V5N=&[];6D@=&5L96;S;FUI(&$@
M3W5T;&]O:V]M+@!+;VYF:6=U<N%C:6$@<&]T<F5B=6IE(&%K='5A;&EZX6-I
M=2X`2V]N9FEG=7)O=F&[("5S`%!O='9R[W1E(&AE<VQO`%!O='9R9'IO=F&[
M('9Y;6%ZX79A;FEE('5D86QO<W3M/P!0;W1V<F1E;ND`2V]N9V\`1&5M;VMR
M871I8VOA(')E<'5B;&EK82!+;VYG;P!3<&]J96YI92!Z;'EH86QO+@!3<&]J
M96YI92!Z;'EH86QO.B``2[7ZZ"!B;VP@>F%M:65T;G5T_2!S97)V97)O;2!V
M97)E:F[]8V@@:[7ZZ&]V+@!+M?KH(&)O;"!Z86UI971N=73]('-E<G9E<F]M
M('9E<F5J;OUC:"!KM?KH;W8N($3T=F]D.B`E<R`H)7,I`%-P;VIE;FEE(',@
M1E10('-E<G9E<F]M('IL>6AA;&\N`$MO;G1A:W1Y`$MO;G1A:W1Y(&)O;&D@
M^G-P9;EN92!V;&^^96[A(&1O(%;AN6AO(&%D<F5SX7)A+@!4>7`@:V]M<')I
M;6]V86[I:&\@<_IB;W)U.@!/8G-A:"`B)7,B`%!O:W)AZ&]V8;L`0V]O:V]V
M92!O<W1R;W9Y`$-O;VMI90!+;W#M<F]V8;L`2V]P[7)O=F%N:64@>FQY:&%L
M;SH@)7,`2V]P[7)O=F&[(';]8F5R`%-K;W#M<G5J=&4@55),('5V961E;OH@
M;FF^N6EE(&$@<&]UOFET92!J=2!A:V\@55),(',@:6YF;W)MX6-I86UI(&\@
M5F&Y96H@>F%N97!RX7ID;F5N;W-T:2X`2V]S=&%R:6MA`%!O8G)EOFEE('-L
M;VYO=FEN>0!.97!O9&%R:6QO('-A('IAN6EF<F]V8;L@<W!RX79U('!O;6]C
M;W4@4$=0.B``3F5P;V1A<FEL;R!S82!P;V1P[7-ANR!S<'+A=G4@<&]M;V-O
M=2!01U`Z(`!.97!O9&%R:6QO('-A('IAN6EF<F]V8;L@<W!RX79U('!O;6]C
M;W4@4R]-24U%+@!.97!O9&%R:6QO('-A('!O9'#M<V&[('-P<N%V=2!P;VUO
M8V]U(%,O34E-12X`3F5P;V1A<FEL;R!S82!P<FED8;L@:V]N=&%K="X@)7,N
M`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!,1$%0('-E<G9E<G4N`$YE<&]D
M87)I;&\@<V$@<')I<&]J:;L@:R!,1$%0('-E<G9E<G4`3F5P;V1A<FEL;R!S
M82!O=F5R:;L@>F]S=&%T;VL@;F$@^NAT92X@)7,`3F%S=&%L82!C:'EB82!P
M<FD@<'+M<W1U<&4@:R!,1$%0('-E<G9E<G4`3F5P;V1A<FEL;R!S82!P<FEP
M;VIINR!K('-E<G9E<G4@(B5S(B!P;VUO8V]U($944#H@)7,`3F5P;V1A<FEL
M;R!S82!V>71V;W)INR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO
M('-A(&1EN6EF<F]V8;L@4$=0(/ID86IE.B``3F5P;V1A<FEL;R!S82!D9;EI
M9G)O=F&[(%,O34E-12#Z9&%J92X`3F5P;V1A<FEL;R!S82!V>6UA>F&[(&MO
M;G1A:W0N("5S`$YE<&]D87)I;&\@<V$@=GEM87IANR!Z;WIN86T@<'+M:F5M
M8V]V+B`E<P!.97!O9&%R:6QO('-A('9Y;6%Z8;L@<VMR:7!T(&YA('5P9W)A
M9&4@:V]N9FEG=7+A8VEE("(E<R(N`$YE<&]D87)I;&\@<V$@=7+H:;L@92UM
M86EL;W;Z(&%D<F5S=2!P<NUJ96UC=2X`3F5P;V1A<FEL;R!S82!S=&EA:&YU
MNR!C96S](&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@>NUS:V&[(&MO;7!L971N
M_2!Z;WIN86T@<'+M:F5M8V]V+@!.97!O9&%R:6QO('-A('KM<VMANR!K;VUP
M;&5T;OT@>F]Z;F%M('IO>FYA;6]V('!R[6IE;6-O=BX`3F5P;V1A<FEL;R!S
M82!N8>CM=&&[('-T<F%TZ6=I=2`B)7,B+@!.97!O9&%R:6QO('-A('-P=7-T
M:;L@;6MD:7(@(B5S(BX`3F5P;V1A<FEL;R!S82!Z[7-K8;L@=F5R96IN_2!K
MM?KH('IO('-E<G9E<F$@:[7ZZ&]V+@!.97!O9&%R:6QO('-A(&]T=F]R:;L@
M(B5S(B!P<F4@>N%P:7,N`$YE<&]D87)I;&\@<V$@;W1V;W)INR`E<RX`3F5P
M;V1A<FEL;R!S82!O='9O<FF[(&UO9'5L($UA:6YT96YA;F-E7U1A<VL@)7,`
M3F5P;V1A<FEL;R!S82!O='9O<FF[(&%D<F5SX7(@(B5S(BX`3F5P;V1A<FEL
M;R!S82!P<FEP;VIINR!N82!,1$%0('-E<G9E<BX`3F5P;V1A<FEL;R!S82!P
M<F7H[71ANR`E<RX`3F5P;V1A<FEL;R!S82!O8FYO=FF[(&AE<VQO('IA9&%N
MZ6AO('!O=;[M=F%T9;5A+B!.:65K=&]RZ2!A;&5B;R!VN65T:WD@<&]D<F]B
M;F]S=&D@;FEE('/Z('-P<N%V;F4N(%-K^G-T92!T;R!Z;F]V=2!A;&5B;R!K
M;VYT86MT=6IT92!6X;EH;R!A9&UI;FES='+A=&]R82P@86L@<&]T<F5B=6IE
M=&4@<&]M;V,N`$YE;6^^;F\@>NUS:V&[($%#3`!.97!O9&%R:6QO('-A('KM
M<VMANR!A9')E<^%R+B`E<P!.97!O9&%R:6QO('-A('KM<VMANR!Z;WIN86T@
M<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO('-A('KM<VMANR!Z;WIN86UY('!R
M[6IE;6-O=B`E<P!.96UOOFYO('KM<VMANR!I;F9O<FWA8VEE(&\@=FQA<W1N
M;W-T:6%C:"!S97)V97)A`$YE<&]D87)I;&\@<V$@=G+A=&F[(&MO;F9I9W5R
MX6-I=2X`3F5P;V1A<FEL;R!S82!S<'5S=&F[(')M9&ER("(E<R(N`$YE<&]D
M87)I;&\@<V$@=6QOOFF[(&MO;F9I9W5RX6-I=2`E<RX`3F5P;V1A<FEL;R!S
M82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I92X`3F5P;V1A<FEL;R!S82!U
M;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I93H@)7,`3F5P;V1A<FEL;R!S82!U
M;&^^:;L@<VMR:7!T(&YA('5P9W)A9&4@;F%S=&%V96[M(&1O.B`B)7,B+@!.
M97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A8VEE("5S+@!.
M97!O9&%R:6QO('-A('IA<.US8;L@:V]N9FEG=7)AZ&[]('/Z8F]R("5S+B!-
M]+YE=&4@<&]UOFF[(&YI96MT;W+Z('H@;6^^;F]S=.T@;F$@>N%P:7,@:_-D
M=2!N82`E<R!A;&5B;R!S:V]P[7)O=F&[(')UZ&YE(&OS9"!U=F5D96[](&YI
MOKEI92!D;R`E<RX`3F5P;V1A<FEL;R!S82!HM6%D8;L@;F$@3$1!4"!S97)V
M97)I+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@(B5S(BX`3F5P;V1A<FEL;R!S
M82!A:W1U86QI>F]V8;L@:V]N=&%K="X@)7,`3F5P;V1A<FEL;R!S82!A:W1U
M86QI>F]V8;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,`3F5P;V1A<FEL;R!S82!Z
M87#M<V&[(&MO;F9I9W5RX6-I=2!P<F4@(B5S(CH@)7,`3F5M;[YN;R!NX6IS
MNR!";^AN_2!P86YE;"!-;WII;&QY+B!3:V]N=')O;'5J=&4L(+YE(&IE('!A
M;F5L(&]T=F]R96[]+@!0;W6^[79A=&6U;W9I("(E<R(@<V$@;F5P;V1A<FEL
M;R!P<FED8;L@<'+A=F$@<')E('!R:67H:6YO:R`B)7,B.B`E<P!0;^CM=&%N
M_2!T97AT`$MR86II;F$`2W5R>GD`5GET=F]R:;L`5GET=F]R:;L@:V%L96YD
MX7(`5GET=F]R:;L@;F]V^B!U9&%L;W.[`%9Y='9O<FF[(&QI;FMU`%9Y='9O
M<FF[(&YO=OT`5GET=F]R:;L@<&]D<')I9>AI;F]K`%9Y='9O<F5NZ0!0<N%V
M82!T=F]R8W4`R.US;&\@:W)E9&ET;F5J(&MA<G1Y`$-H;W)VX71S:V\`2W5B
M80!!:W1UX6QN90!!:W1UX6QN92`T(&;A>GD`06MT=>%L;F4@<V5D96YI80!!
M:W1UX6QN>2#H87,`06MT=>%L;F$@55),(&IE`$%K='7A;&YI('!O=;[M=F%T
M96QI80!!:W1UX6QN92!P;^AA<VEE`$%K='7A;&YE('!O9&UI96YK>3H@`$%K
M='7A;&YY(+ET_6P`3F%S=&%V96YI92#Z;&]H+"!K=&]RZ2!S82!S</JYNV%J
M^B!P<FD@<')I:&SA<V5N[2!D;R!A<&QI:^%C:64@)7,N`%9Y<W1R:6AN^KL`
M5GES=')I:&[ZNR!V_6)E<@!#>7!R=7,`R&5S:^$@<F5P=6)L:6MA`$1$`$13
M3B`H<&]Z<FD@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$96YN90!$96YN93H@;W!A
M:V]V86YI92!K8;YD_6-H`%!R97IE<F'H(&3A=&]VZ6AO('-T<F]M=2`H1&%T
M851R964I`%9Y:+5A9.%V86YI92!V(&1A=&%BX7IE`$3A='5M`$3A='5M('!R
M:6IA=&EA`%;]8F5R(&3A='5M=0!$9?(`1&7R*&1N:2D`5GE?;6%Z8;L`3U]D
M<W1RX6YINR!S=.5P96,`1&5C96UB97(`1&5S:6%T:V]VZ2#H[7-L80!/9&UI
M971N=73I`%IM96ZY:;L@;V1S861E;FEE`%!R961N87-T879E;ND`5N&Y('!R
M961N87-T879E;OT@:V%L96YDX7(`4')E9&YA<W1A=F5NX2!F87)B80!68;EA
M('!R961N87-T879E;N$@:61E;G1I=&$`4')E9&YA<W1A=F5N_2!P<NUK87IO
M=OT@:6YT97)P<F5T97(`1&5F:6[M8VEE`%9Y;6%Z8;L`6FUA>F&[("5S`%9Y
M;6%Z8;L@8G5N:W4`6FUA>F&[('5D86QO<[L`5GEM87IANR!S:W5P:6YU`%9Y
M;6%Z8;L@>N%Z;F%M`%9Y;6%Z8;L@<'+A=F\`5GEM87IANR!A(&]D<W1RX6YI
MNR!S<'+A=GD`5GEM87IANR!B=6YK=0!6>6UA>F&[('-TY7!E8P!6>6UA>F&[
M(&5X:7-T=6KZ8W4@86QT97)N873M=FYU(+EA8FSS;G4`5GEM87IANR!P<N%V
M82!P<F4@(B5S(@!#:&-E=&4@=GEM87IANR`B)7,B(&$@=KEE=&MY(&IE:&\@
M<&]D<'+A=F$_`%9Y;6%Z8;L@<FEA9&]K`%9Y;6%Z8;L@=GEB<F%N^B!I9&5N
M=&ET=0!6>6UA>F&[(&%K='7A;&YY('-TY7!E8P!6>6UA>F&[(&EB82!A:W1U
MX6QN=2!U9&%L;W.[+"!T96YT;R!V_7-K>70@82!VN65T:WD@8G5D^F-E(';]
M<VMY='D@86QE8F\@=KEE=&MY(';]<VMY='D_`%9Y;6%Z8;L@86MT=>%L;GD@
M<FEA9&]K`%-K<FEP="!N82!U<&=R861E(&MO;F9I9W5RX6-I92`B)7,B(&)O
M;"!V>6UA>F%N_2X`R&%S(&1O<G7H96YI80!$X6YS:V\`4&]?<&ES`%!O<.VY
M=&4@<')O8FSI;0!0;W!I<P!0;V1R;V)N;W-T:2`H=&EEOB!V(&QO9V]V86-O
M;2!S^F)O<F4@2&]R9&4I`$1E=&%I;'D@8F]L:2!Z87IN86UE;F%NZ2!P<F4@
M861M:6YI<W1RX71O<F$N`%;]=F]J`%)O<V[](&)O9`!2;W-N_2!B;V0@>F$@
M<&]S;&5D;OH@:&]D:6YU.B``4F]S;OT@8F]D.B``4VUE<B!ZM6%V82!D;W!R
M879A`%-M97(@<W!R879A(&1OM6%V80!!9')E<^%R`$YA<W1A=F5N:64@>F]B
M<F%Z96YI80!:;V)R87IO=F&[(.AA<R!V(#(T+6AO9&EN;W9O;2!F;W)MX71E
M/P!:;V)R87IINR!K86QE;F3A<F4`3F%S=&%V96YI92!Z;V)R87IE;FEA`%IO
M8G)A>FF[('!O9')O8F[Z('!R961P;W9E[P!:;V)R87IINR!P<F5D<&]V9>\@
M*%1!1BD`1F]R;>%T('IO8G)A>F5N:6$`4&]T=G)D96YI92!O(&1O<G7H96[M
M`$2^:6)U='-K;P!.979Y;6%Z8;L`3F5P;W6^[79A:G1E('!R:6%M;R!M86EN
M=&5N86YC92YP:'``0VAC971E('IO8G)A>FF[(/IL;VAY('!O('1E<FWM;F4@
M=F\@5F&Y:6-H(&MA;&5N9.%R;V-H/P!.96]P86MU:F4@<V$`3V)S86AU:F4@
M<')V_2!R:6%D;VL@;N%Z=GD@<&]L[3\@06L@X6YO+"!Z8;EK<G1N:71E('!O
M;.WH:V\Z(`!$;VUI;FEC80!$;VUI;FEKX6YS:V$@<F5P=6)L:6MA`$YE;>%T
M92#ZZ&5T/R!:87)E9VES=')U:G1E('-A+@!3=&EA:&YUNP!3=&EA:&YUNR`E
M<P!3=&EA:&YUNR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A8VEU(&%K;R!02%`@
M<VMR:7!T+@!:;WIN86T@<R!V_6)E<F]M`$1R;V=Y`%1E<FWM;CH@)7,`5')V
M86YI90!%+6UA:6P`15)2`$5K=N%D;W(`57!R879INP!5<')A=FF[("5S`%5P
M<F%V:;L@^NAA<W1N[6MO=@!5<')A=FF[(&)L;VL`57!R879INR!K86QE;F3A
M<F4`57!R879INR!S:W5P:6YU`%5P<F%V:;L@<'+A=F\`57!R879INR!P<N%V
M80!5<')A=FF[('!RX79A('!R92`E<P!5<')A=FF[('9Z9&EA;&5NZ2!K86QE
M;F3A<F4`57!R879INR#ZZ&%S=&[M:V]V`%5P<F%V:;L@:V%T96?S<FEE(&$@
M9F%R8GD`57!R879INR!N87-T879E;FEA('!R93H`57!R879INR!P<N%V82!P
M<F4@(B5S(@!5<')A=FF[('!RX79A('!R92`E<P!6>F1E;.%V86YI90!%9WEP
M=`!386QVX61O<@!%;&5M96YT+BXN`$5M`$5M86EL`$4M;6%I;&]VX2!A9')E
M<V$`12UM86EL;W;I(&%D<F5S>2!M=7-I82!B>;L@<F]V;F%KZ2X`12UM86EL
M(',@<&]T=G)D96[M;0!"<N%N82!%;6%I;"UN82U335,`16UO=&EK;VYY`%!R
MX7ID;F$@<W!RX79A+@!0<N%Z9&YY(';]<VQE9&]K+@!0<N%Z9&YE('!O9&UI
M96YK>2!HM6%D86YI80!?2V]N:65C`%!O=F]L:;L@=FQOOF5N:64@;V)RX7IK
M;W8@>B!'86SI<FGM(&1O('1E>'1U/P!0;W9O;&F[(&MO;G1E>'1O=ND@;65N
M=2!P<F4@<')A=ND@=&QAZ&ED;&\_`$3A='5M('5K;V[H96YI80!+;V[H[0#(
M87,@=6MO;NAE;FEA`$MO;FEE8R!R;VMA`%IVY.BY:;L@961I=&]R`%IA9&%J
M=&4@8F5Z<&7H;F]S=&[Z(&]TX7IK=2P@;F$@:W1O<OH@8G5D971E(&UU<VEE
MNR!O9'!O=F5D8;L@86L@>F%B=61N971E(&AE<VQO+"!N87!R+B`G86MO('-A
M('9O;.$@;6]J92!Z=FEE<F%T:V\_)SH`6F%D86IT92!54DP@;V)RX7IK80!:
M861A:G1E('#M<VUE;N$@=79E9&5NZ2!N:;ZY:64Z`%)O=F[M:V]VX2!'=6EN
M96$`17)I=')E80!#:'EB80!#:'EB82!P<FD@=GET=N%R86[M(&)L;VMU.B`E
M<P!#:'EB82!P<FD@=GEM87KA=F%N[2!U:V]T=F5N:6$@<WEN8VAR;VYI>N%C
M:64Z("5S`$-H>6)A('!R:2!V>6UA>N%V86[M('KA>FYA;74@<WEN8VAR;VYI
M>N%C:64Z("5S`$-H>6)A('!R:2!Z[7-K879A;NT@;V)S86AU.B`E<P!.87-T
M86QA(&-H>6)A('!R:2!I;7!O<G1E(&EN9F]R;>%C:>T@;R!Z86YE<'+A>F1N
M96YO<W1I('!O=;[M=F%T9;5A.B`E<SH@)7,N`$-H>6)A('!R:2!A:W1U86QI
M>N%C:6D@:&5S;&$Z("5S`$-H>6)A('8@92UM86EL;W9E:B!S<'+A=F4N`$-H
M>6)A('!R:2!Z87!I<V]V86[M("(E<R(N`$5S=/-N<VMO`$5T:?-P:6$`171N
M:6-KZ0!%=7+S<&$`4')I9&%NX2!U9&%L;W.[.@!6>6UA>F%NX2!U9&%L;W.[
M.@!5<')A=F5NX2!U9&%L;W.[.@!59&%L;W.[(&]D("5S(&1O("5S`%5D86QO
M<[L@;F5B;VQA(&[A:F1E;N$`561A;&]S=&D@;75S:6$@;6&[(&3A='5M('IA
MZ&EA=&MU+@!59&%L;W-T:2!M=7-I82!M8;L@=&ET=6PN`$MAOF3]8V@@,34@
M;6EN^G0`2V&^9.D@,B!M:6[Z='D`2V&^9/UC:"`S,"!S96OZ;F0`2V&^9/UC
M:"`U(&UI;OIT`%!R:2!K8;YD;VT@<')I:&SA<V5N[0!+8;YD^B!P;VQH;V1I
M;G4`2V&^9/H@;6EN^G1U`$YA<'+M:VQA9#H`4W!U<W1INP!2;WIB86QINP!$
M;W!L;FF[(&UE;N$`4F]Z8F%L:;L@0F_H;OT@<&%N96P`3^AA:^%V82!S82`G
M*2<`3^AA:^%V82!S82!S;&]V;R!A;&5B;R!P;V1M:65N:V$@:+5A9&%N:6$@
M=B#Z=F]D>F]V:^%C:`!$X71U;2!E>'!I<N%C:64`17AP;VYE;G0`17AP;W)T
M`$5X<&]R=&]V8;L@:V%L96YDX7(`1F%R8F$@=&5X='4`3F%H<F&[(&MO;F9I
M9W5RX6-I=2!N82!&5%``3F5P;V1A<FEL;R!S82!Z[7-K8;L@;F%S=&%V96YI
M82X`3F%S=&%L82!C:'EB82!P<FD@<W!O:F5N[2!S($Q$05`@<V5R=F5R;VTN
M`$YA<W1A;&$@8VAY8F$@<')I('!R[7-T=7!E(&L@4TU"('-E<G9E<G4N`$YE
M<&]D87)I;&\@<V$@:V]P[7)O=F&[('H@(B5S(BX`3F5P;V1A<FEL;R!S82!K
M;W#M<F]V8;L@9&\@(B5S(BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!N;W;I
M(%-!4TP@<W!O:F5N:64N`$YE<&]D87)I;&\@<V$@<')E<W5N^KL@9&\@(B5S
M(BX`3F5P;V1A<FEL;R!S82!Z[7-K8;LZ("5S`$1O8G+I`$9A;&ML86YD<VOI
M(&]S=')O=GD@*$UA;';M;GDI`$9A97)S:^D@;W-T<F]V>0!:X79AOF[A(&-H
M>6)A.@!&87@`1F%X>0!&96)R=>%R`%!O8VET('1E<&QO='D`4&]C:70@=&5P
M;&]T>3H@`$UA;.D@>G+AOFMY`$UA;.D@<VYE:&]VZ2!P<F5HX6YK>0!-871I
M8V$@<&]L[0!&:62^:0!3^F)O<@!0;^AE="!S^F)O<F]V.B`E<R!S^F)O<@!0
M;^AE="!S^F)O<F]V.B`E<R!S^F)O<F]V`%-P<N%V8V$@<_IB;W)O=@!-96YO
M('/Z8F]R=0!6_6)E<B!S^F)O<G4`3F%H<F%T:64@<_IB;W)U`$YA:'+A=F%N
M:64@<_IB;W)O=B!N:64@:F4@<&]D<&]R;W9A;NDN`$9I;'1R90!.X6ISNP!&
M[6YS:V\`4')VX2!P;VQO=FEC80!0<G;A(+ET=G*[`%!E=F[]('!O;65R`$]T
M;^AINP!0;.%V86KZ8VD@=&5X=`!(;6QA`%!R:67H:6YO:R`E<R!N965X:7-T
M=6IE`$9A<F)A('#M<VUA`%!O=')A=F$`4')E('!R96AL:6%D8>AE+"!K=&]R
MZ2!N97!O9'!O<G5J^B!O8G+A>FMY`%!R961P;W9E[R`H5$%&*0!0<F5D<&]V
M9>\@;F$@=79E9&5N_2!P;^AE="!D;NT@*'!A;>1T86IT92!N82!T;RP@OF4@
M<')E9'!O=F7O(&IE('!R92!D;FD@86H@;F]C:2!A('1A:R!M]+YE('9EM6OI
M(.CM<VQO('9Y='9O<FF[('9EM6UI(+EI<F]K_2!B;&]K*0!:86)U9&QI('-T
M92!H97-L;S\`1F]R;75LX7)E`$9O<G1U;F$`5'EP(&9O<G1U;GD`1F]R='5N
M>0!&;W)T=6YY(#(`1O-R80!0<F5S;65R;W9A;FEA`%!I80!2X6UC90!&<F%N
M8_IZ<VMO`$9R86YC^GIS:V\@*$5U<O-P82D`5F^U;OT`26YF;W)MX6-I82!O
M('IA;F5P<N%Z9&YE;F]S=&D`1G)A;F/Z>G-K82!'=6%Y86YA`$9R86YC^GIS
M:V$@4&]L>6[I>FEA`$9R86YC^GIS:V4@:G6^;ND@=&5R:73S<FGA`%!I871O
M:P!/9`!:;R!S;65R=2``VG!L;OT@<&]P:7,`4W!L;@!#96SI(&UE;F\Z`$)U
M9/IC;F]SNP!'86)U;@!'86SI<FEA+"!Z(&MT;W)E:B!C:&-E=&4@=GII8;L@
M;V)RX7IO:P!'86SI<FEA.@!'86UB:6$`2')A`%:Y96]B96-NZ0!'96YE<F]V
M8;L@:V]N9FEG=7+A8VEU('!R92!A<&QI:^%C:74@)7,`1V5N97)O=F%N_2!K
M\V0`1V5O<F=I80!.96UE8VMO`$=H86YA`$=I8G)A;'3A<@!+<G-T;ND@;65N
M;P!/9&]S;&&[`$=O961E;`!';V]G;&4@36%P<P!(M6%D8;L@;F$@1V]O9VQE
M`%!R96ISNR!N82`E<P!/9'1I96YE(+EE9&5J`$=RZ6-K;P!'<O-N<VMO`$=R
M96YA9&$`061M:6YI<W1RX6-I82!S:W5P[6X`365NX2!S:W5P[6X@;F5S;?H@
M8GF[('!RX7ID;F4`1W)O=7!?;&1A<#H@3F5P;V1A<FEL;R!S82!P<FED8;L@
M<VMU<&EN=2`E<RX@4V5R=F5R(&]D<&]V961A;#H@`$=R;W5P7VQD87`Z(&YE
M<&]D87)I;&\@<V$@=GEM87IANR!S:W5P:6YU("5S`$=R;W5P7VQD87`Z(&YE
M<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('-K=7!I;G4@)7,`4VMU<&EN>0!'
M=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`%!RX79A(&%N;VYY
M;6[]8V@@<&]UONUV871EM6]V`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I
M<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!N961O=F]L[2!V>6UA>F&[('!O
M<VQE9&[Z(&)U;FMU('8@<FEA9&MU+@!(5$U,07)E82!N961O=F]L[2!V>6UA
M>F&[('!O<VQE9&[]('-TY7!E8R!V('1A8G6U:V4N`$A434Q!<F5A(&YE9&]V
M;VSM('9Y;6%Z8;L@<&]S;&5D;OT@<FEA9&]K('8@=&%B=;5K92X`2%144"!A
M=71E;G1I9FEKX6-I82!N96)O;&$@;N%J9&5NX2X`2&%I=&D`06QG;W)I=&UU
M<R!H87-H;W9A8V5J(&9U;FMC:64`3W!A<@!(;&%V:>AK80!(;&%V:>AK>0!(
M96%R9&]V(&]S=')O=B!A($UC1&]N86QD;W9E(&]S=')O=GD`4VEL;N$@8OIR
M:V$`5OVY:V$`4&]M;V-N[6L`4&]M;V-N[6L@<')E('!O=;[M=F%N:64@961I
M=&]R80!0;VUO8V[M:P!0;VQO9W6U80!4=2!J92!Z8>AI871O:R!S^F)O<G4Z
M`%-K<GF[`%-K<GF[("5S`%9Y<V]KX0!$;U]M;W8`5F%T:6OA;@!$;VUO=@!$
M;VWA8V$@861R97-A`$1O;>%C:2!P<FEEZ&EN;VL`5&5L96;S;B!D;VUO=@!(
M;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z('8@<W!RX79E
M("5S(&)O;&D@;N%J9&5NZ2!N97!L871NZ2`E<R!834P@^F1A:F4`2&]R9&4O
M2V]L86(Z(',@;V)J96MT;VT@)7,@;F5K;W)EN7!O;F1U:F4@OFEA9&YA('-P
M<N%V82X`2&]R9&4O2V]L86(Z('8@<W!RX79E("5S(&YE8F]L(&[A:F1E;OT@
MOFEA9&5N(&]B:F5K="!T>7!U("5S`$AO<F1E+TMO;&%B.B#Z<W!EN6YE(&]D
M<W1RX6YE;ND@)7,@(B5S(@!(;W)D92]+;VQA8CH@:6YT96=RX6-I82!V>;YA
M9'5J92!02%`@<F]ZN>UR96YI92`G9&]M>&UL)P!(;W)D92]+;VQA8CH@;F5P
M;V1A<FEL;R!S82!V>71V;W)INR!N;W;](%A-3"!S=')O;2!P<F4@;V)J96MT
M("5S`$AO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A(&]D<W1RX6YINR`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!Z[7-K8;L@34E-
M12!)1"!P<F4@Z&%SNR!T>7!U("5S`$AO<F1E+TMO;&%B.B!N97!O9&%R:6QO
M('-A('-Y;F-H<F]N:7IO=F&[("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!N
M97!O9&%R:6QO('-A('-Y;F-H<F]N:7IO=F&[('ID:66U86[I(&]B:F5K='DZ
M("5S`$AO<F1E+TMO;&%B.B!N97INX6UY('ID:66U86[](&]B:F5K="`B)7,B
M`$AO<FEZ;VYTX6QN82#H:6%R80!(;W)I>F]N=.%L;F4@=GEP;&YE;FEE`$AO
M<FEZ;VYTX6QN93H`2&]D:6YA*'DI`$%K;R!S=&4@<V$@<V5M(&1O<W1A;&D_
M("A0<F]S[6T@;F%H;.%S=&4A*0!!:^D@9&QHZ2!M86KZ(&)YNR#H87-O=ND@
M^G-E:WD@=B!D96YN;VT@82!T_;YD96YN;VT@;N%HM6%D93\`2V^U:V\@<W3E
M<&-O=B!C:&-E=&4@>FSZZ&F[/P!0<F4@86O]('!OZ&5T(&1N[2!D;R!B=63Z
M8VYO<W1I('-A(&WA('9Y9V5N97)O=F&[(&EN9F]R;>%C:6$@;R!Z86YE<'+A
M>F1N96YO<W1I/P!:861A:G1E('!OZ&5T('!O;.T@*'-TY7!C;W8I/P!+;[5K
M;R!R:6%D:V]V(&-H8V5T92!Z;/KH:;L_`%9L:&MO<[L`5FQH:V]SNSH@`$AU
M;6]R:7-T:0!-8>]A<G-K;P!.97!O9&%R:6QO('-A('9Y='9O<FF[($E-05`@
M<V-H<N%N:W4Z("5S`$YE<&]D87)I;&\@<V$@=GEM87IANR!)34%0('-C:'+A
M;FMU.B`E<P!.97!O9&%R:6QO('-A('9Y='9O<FF[($E-05`@:W;S='4Z("5S
M`$E0(&%D<F5S80!)4"!A9')E<V$@;FEE(&IE(&1O<W1U<&[A+@!)4"!A9')E
M<V$@;FEE(&IE('8@<N%M8VD@9&]V;VQE;NEH;R!#2412(&)L;VMU+@!0;W)U
MN65N:64@<')A=FED;&$@;R!P979N96H@25`@861R97-E+@!6;&^^:;L@:[7Z
MZ"!?<')E9`!)<VQA;F0`26)A(&EK;VYY`$EK;VYY('!R92`E<P!):V]N>2!A
M('1E>'0`3N%Z;W8@:61E;G1I='DZ`$%K('-A(&YE>F]B<F%Z[2!K;W)E:W1N
M92P@)7,@82!O='9O<NT@<V$@=B!N;W9O;2!O:VYE+@!!:R!N979I9.UT92!P
M<FD@<&]UOFET[2!);G1E<FYE="!%>'!L;W)E<F$@OFEA9&YE(&EK;VYY+"!P
M;W1R96)U:F5T92!Z8;EK<G1N^KL@=/IT;R!V;[5B=2!P<F4@=GEP;G5T:64@
M<')I97-V:71N;W-T:2!03D<@;V)RX7IK;W8N`$%K('9I9.UT92!T^G1O('-P
M<N%V=2!A(&YE=FED[71E(&]B<N%Z;VLL(&]B<N%Z;VLL(&MT;W+]('-T92!C
M:&-E;&D@;F%H<F&[+"!N96WTOF4@8GF[('IO8G)A>F5N_2!V;R!68;EO;2!P
M<F5H;&EA9&'H:2X`06L@5N&Y(&5M86EL;W;](&ML:65N="!N97!O9'!O<G5J
M92!P;[YI861A=FMY(&E4:7`L(&WTOF5T92!P;W6^:;L@:F5D;G4@>B!N87-L
M961U:OIC:6-H(&QI;FEE:VYA(&%K8V5P=&]V86YI92!A;&5B;R!O9&UI971N
M=71I92!U9&%L;W-T:2X*"E!R92!A:V-E<'1O=F%N:64@=61A;&]S=&DZ"B5S
M"@I0<F4@<')E9&)EOF[I(&%K8V5P=&]V86YI93H*)7,*"E!R92!O9&UI971N
M=71I92!U9&%L;W-T:3H*)7,`56OAOFMA(&]B<N%Z:V$Z`%523"!O8G+A>FMA
M`%523"!O8G+A>FMA.@!/8G+A>F]K('H@9V%LZ7)I90!/8G+A>F]K('H@9V%L
MZ7)I93H`3F%H<F%T:64@;V)RX7IK=0!/8G+A>FMY`$EM<&]R=&]V8;L@:V%L
M96YDX7(L(&MR;VL@)60`26UP;W)T+"!K<F]K("5D`$EM<&]R="]%>'!O<G0@
M:V%L96YDX7)A`$EM<&]R=&]V86[I('!O;&4Z("5S`$EM<&]R=&]V86[I('!O
M;&EA.@!6;&^^:;L@:[7ZZ"!?>F$`0F]L('IA9&%N_2!N97-P<N%V;GD@:_-D
M(&%K8VEE+@!.97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&$O86QE8F\@
M:&5S;&\`3F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!A;'1E
M<FYA=.UV;F$@861R97-A+B!3:_IS=&4@=&\@>FYO=G4@86QE8F\@:V]N=&%K
M='5J=&4@<W!RX79C=2!6X;EH;R!S>7-TZ6UU+"!A:R!P;W1R96)U:F5T92!P
M;VUO8RX`6G;DZ+EINR!O9'-A9&5N:64`26YD:6$`2F5D;F]T;&EV[2!P;W6^
M[79A=&5L:6$`26YD;V[I>FEA`$EN9F\`26YF;W)MX6-I90!);F9O<FWA8VEE
M('6^(&YI92!S^B!D;W-T=7!NZ2X`5FQOOFF[(%]S=.5P96,@>F$`5FQOOFF[
M(&]B<N%Z;VL`5FQOOFF[('1A8G6U:W4`5FQOOFF[(&QI;FMU`%9L;[YINR!?
M<W3E<&5C('!R960`5FQOOFF[(&YO=OT@<W3E<&5C('IA(&%K='7A;&YY`%9L
M;[YINR!N;W;]('-TY7!E8R!P<F5D(&%K='7A;&YY`%9L;[YINR!N;W;](')I
M861O:R!Z82!A:W1UX6QN>0!6;&^^:;L@;F]V_2!R:6%D;VL@<')E9"!A:W1U
MX6QN>0!6;&^^:;L@;V1S=&%V96,@>F$@86MT=>%L;GD@8F]D`%9L;[YINR!O
M9'-T879E8R!P<F5D(&%K='7A;&YY(&)O9`!6;&^^:;L@86QT97)N873M=FYU
M(+EA8FSS;G4`6F%D86IT92!E+6UA:6QO=OH@861R97-U+"!N82!K=&]R^B!D
M;W-T86YE=&4@;F]VZ2!H97-L;SH`5FQOOFF[(&)U;FMU('IA`%9L;[YINR!B
M=6YK=2!P<F5D`%9L;[YINR!S=.5P96,@>F$`5FQOOFF[('-TY7!E8R!P<F5D
M`%9L;[YT92!S<'+A=GD`5FQOOFF[(&]D<W1A=F5C('IA`%9L;[YINR!O9'-T
M879E8R!P<F5D`%9L;[YINR!R:6%D;VL@>F$`5FQOOFF[(')I861O:R!P<F5D
M`%IA9&%J=&4@<&^^861O=F%N^B!O9'!O=F7O(&YA(&)E>G!EZ&YO<W1N^B!O
M=.%Z:W4Z`%9L;[YINR]U<')A=FF[(&]B<N%Z;VL`5FQOOFF[+W5P<F%V:;L@
M;&EN:W4`3F$@;V1O<VEE;&%N:64@<')E('IO>FYA;2!P<NUJ96UC;W8@;F5M
MX71E(&1O<W1A=&_H;OT@:W)E9&ET+@!.961O<W1A=&_H;OT@:W)E9&ET+@!#
M96SI(.CM<VQO`%IO>FYA;2!C96S]8V@@Z&ES96P`3F5P;&%D;ND@541(("A5
M<V5R($1A=&$@2&5A9&5R+"!(;&%V:>AK82!P;W6^[79A=&6U<VO]8V@@^F1A
M:F]V*2X`3F5P;&%T;ND@^F1A:F4@9F]R;>%T=2!:25`N`$YE<&QA=&[A(&%P
M;&EKX6-I82X`3F5P;&%T;ND@240@9.%V:WDN`$)O;&D@;V1O<VQA;ND@;F5P
M;&%T;ND@^F1A:F4N`$YE<&QA=&[A(&-I9;5O=N$@861R97-A+@!.97!L871N
M_2!F;W)MX70@<_IB;W)U`$YE<&QA=&[](&QI8V5NZ&[](&NU^N@N`$)O;&$@
M>F%D86[A(&YE<&QA=&[A(&QO:V%L:71A+@!.97!L871NX2!H;V1N;W1A(&US
M9U]T>7!E+@!.97!L871NX2!A;&5B;R!C:/UB86KZ8V$@:&]D;F]T82!A<&E?
M:60N`$YE<&QA=&[I(&%L96)O(&-H_6)A:OIC92!P87)A;65T<F4N`$YE<&QA
M=&[I(')O9&GH;W9S:^D@<'+A=F\N`$YE<&QA=&[I(&ED('!A<G1N97)A+@!.
M97!L871N_2!K\V0@<')O9'5K='4N`$YE<&QA=&[]('!R;W1O:V]L`$YE<&QA
M=&[]('!R[6IE;6-A.B`B)7,B`$YE<&QA=&[](&]B:F5K="!Z9&EEM6%N:6$`
M3F5P;&%T;N$@>F1R;VIO=N$@861R97-A+@!.97!L871NZ2#Z9&%J92!U;FEC
M;V1E+@!);G9E;G3A<@!);G9E<G1O=F&[(';]8F5R`$ERX6X`27)A:P#-<G-K
M;P!)<VQE(&]F($UA;@!/:F5D:6YE;.D@8OIR:WD`27IR865L`%9Y9&%V871E
MM0!+=7)Z[79A`%1A;&EA;G-K;P!*86UA:FMA`$IA;G7A<@!*87!O;G-K;P!*
M97)S97D`2F]R9.%N`$KZ;`!*^FX`6F%R;W9N8;L`6F%R;W9N8;L@9&\@<W1R
M961U`%IA<F]V;F&[(&1O(&)L;VMU`%IA<F]V;F&[(':U879O`%IA<F]V;F&[
M('9P<F%V;P!+87IA8VAS=&%N`%!O;F5C:&&[(&]R:6=I;N%L/P!+9?)A`$ME
M<F)E<F]S('-E<G9E<B!Z86UI971O;"!A=71E;G1I9FEKX6-I=2X`2V5R;F5L
M+6YO=N'H:6MO=FEA`%9Y='9O<F5N:64@:[7ZZ&$`1&EG:73A;&YY(&]D=&QA
MZ&]K(&NU^NAA`$3EOFMA(&NU^NAA`%1Y<"!KM?KH80!0;W6^:71I92!KM?KH
M80!+M?KH('6^(&5X:7-T=6IE(&YA('-E<G9E<FD@=F5R96IN_6-H(&NU^NAO
M=BX`2[7ZZ&]VZ2!S;&]VX0!$971I`$MI<FEB871I`*5U9&]V;V1E;6]K<F%T
M:6-KX2!R97!U8FQI:V$@2_-R96$`2_-R96IS:^$@<F5P=6)L:6MA`$MU=F%J
M=`!+:7)G:;ES:V\`5GI?:+5A9`!*87IY:P!,86]S`%!O<VQE9&[]8V@@,C0@
M:&]D[6X`4&]S;&5D;N$@<&]L;W9I8V$`4&]S;&5D;N$@86MT=6%L:7KA8VEA
M`%!O<VQE9&[](&UE<VEA8P!0;W-L961NX2!Z;65N82!H97-L80!0;W-L961N
MX2"Y='9RNP!0;W-L961NX2!A:W1U86QI>N%C:6$Z`%!O<VQE9&[](')O:P!0
M;W-L961NZ2!P<FEH;.%S96YI93H@)7,`4&]S;&5D;ND@<')I:&SA<V5N:64Z
M("5S('H@)7,`4&]S;&5D;ND@<')I:&SA<V5N:64Z(&YI:V1Y`%!O<VQE9&[]
M('3]OF1E\@!,;W1YN7-K;P!0<N%V;P!6>FBU860`3F5C:&%J=&4@<'+A>F1N
M92!P<F4@OFEA9&5N(&]K<F%J`$QI8F%N;VX`5K5A=F\`2&QA=FGH:V$@=K5A
M=F\`2&]D;F]T>2!VM6%V;P!,97-O=&AO`-IR;W9E\@!,:6+I<FEA`$SM8GEA
M`$QI8VAT96ZY=&%J;G-K;P"E86AKZ2!M<FAO;&5N:64`I6%H:_T@9.&^[P!2
MX6YO(+5A:&O](&3AON\`3F5S:_1R(+5A:&O](&3AON\`I6%H:^D@9&&^[V]V
MZ2!P<F5HX6YK>0"E86AK_2!DX;[O(',@:')M96[M;0"E86AKZ2!S;F6^96YI
M90"E86AKZ2!S;F5H;W;I('!R96CA;FMY`$QI;65R:6-K`$]B;65D>FF[(')O
M>G-A:"#H87-O=B!P<F4@97AP;W)T+@!,:6YK80!,:6YK82!U:V%Z=6IE(&YA
M.@!0<F5P;VIINR!E+6UA:6QO=OH@861R97-U('-O('-T<N%N:V]U(&YA('#M
M<V%N:64@<&^Y='D`3&EN:WD`3&EN=7@@0V]O:VEE`%IO>FYA;2`M('!O=;[M
M=F%T9;4@=79I9.T@<')I9>AI;F]K`%9Y<.US8;L@>F]Z;F%M(&1A=&%BX7H`
M6F]Z;F%M('3I;2!0;VUO8V[M:V$`5GEP[7-ANR!Z;WIN86T@=&%B=6QI96L`
M3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES
M="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`6F]B<F%Z
M96YI92!S961E;NT@>FQY:&%L;SH@)7,`6F]B<F%Z96YI92!P;W6^[79A=&6U
M;W8@>FQY:&%L;SH@)7,`6F]B<F%Z;W9A;FEE('IO>FYA;74@<&]UONUV871E
MM6]V(&IE('IA:^%Z86[I+@!,:71E<F%T^G)A`$QI='9A`$UI95]S=&\`3F'H
M[71A=F$@<V$N+BX`36EE<W1N>2#H87,Z(`!,;VMA;&EZX6-I82!A(.AA<P!-
M:65S=&\`4')I:&SA<V5N:64`6N%Z;F%M>2!P<F5D8VCA9'IA:OIC96H@<WEN
M8VAR;VYI>N%C:64`3V1H;.%S:;L`4')I:&SA<V5N:64`VFQO:'D@<')I('!R
M:6ALX7-E;NT`4')I:&SA<V5N:64@>FQY:&%L;RP@<')E=&^^92!S=&4@>F%D
M86QI(&YE<W!RX79N92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S;&\N
M`%!R:6ALX7-E;FEE('IL>6AA;&\N`$1L:/T@=&5X=`!,X7-K80!.[7IK80!-
M86SI(&=RZ6-K92!P[7-M96[A`$UA;.D@;&%T:6YS:^D@<.US;65NX0!-86SI
M('+M;7-K92#H[7-L:6-E`$QU>&5M8G5R<VMO`$U-`%-P<N%V82!D\F$`4'+M
M;&]H82!-4RU43D5&(&YE;V)S86AO=F%L82"^:6%D;F4@^F1A:F4N`$U31P!-
M86-A;P!-86-E9/-N<VMO`$UA9&%G87-K87(`3>%G:6$`4&^Y=&$`4&]S;&&[
M(&4M;6%I;"!A9&UI;FES='+A=&]R;W9I`%9Y='9O<FF[(&QI;E]K=2XN+@!-
M86QA=VD`36%L86IZ:6$`36%L961I=GD`36%L:0!-86QT80!3<')A=F]V8;L@
M=GID:6%L96[I(&MA;&5N9.%R92X`4W!R879O=F&[('IO>FYA;2!K871E9_-R
M:>TL(',@:W1O<OUM:2!O>FYAZ'5J971E('!O;&^^:WD@82!F87)B>2!A<V]C
M:6]V86[I(',@=/UM:71O(&MA=&5G\W)I86UI+@!-87!A($UA<#(T`$UA<&$@
M36%P475E<W0`36%P;W9A;FEA('5L;[YE;NDN`$UA<F5C`$]K<F%J`$]Z;F'H
M:;L@<'+M>FYA:VUI(%!R9>CM=&%NZ2].97!R9>CM=&%NZ0!/>FYAZ&F[(&EN
M_6UI('!R[7IN86MM:2`H;F%P<BX@1/1L9;YI=.DO6F]D<&]V961A;NDI`$UA
M<G-H86QL;W9E(&]S=')O=GD`36%R=&EN:6L`6FAO9&[I('!O;&EA`$UA=7)E
M=.%N:6$`36%U<NUT:75S`$UA>&EMX6QN>2!P;W9O;&5N_2!K<F5D:70N`$)O
M;"!P<F5K<F_H96[](&UA>&EMX6QN>2!P;^AE="#H87-T[2!S<'+A=GDN`$YA
M:G9YN;EI82!T97!L;W1A('IA('!O<VQE9&[]8V@@,C0@:&]D[6XZ(`!.86IV
M>;FY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ(`!-87AI;>%L
M;GD@<&_H970@=61A;&]S=.T`36%X:6WA;&YY('!OZ&5T(&)L;VMO=B!P;W)T
MX6QU`$UA>&EMX6QN82!DY;YK80!-X6H`36%Y;W1T90!*80!-961I8^UN80!3
M=')E=&YU=&EE`,AL96YO=FEA`$UE;G4@86QA<FUY`%IO>FYA;2!M96YU`%IO
M8G)A>F5N:64@;65N=3H`6FSZZ&F[(&)U;FMY`%-P<N%V80!3<'+A=F$@8F]L
M82#Z<W!EN6YE(&]V97)E;N$L(&%L92!C97)T:69I:^%T('!O9'!I<W4@<V$@
M;F5P;V1A<FEL;R!O=F5R:;LN`%!L871N;W.[('-P<N%V>2!V>7!RN6%L82X`
M5'EP('-P<N%V>0!0;^AA<VEE($UE=&%R`-ID86IE($UE=&%R(&YI92!S^B!D
M;W-T=7!NZ2X`VF1A:F4@365T87(@;FEE('/Z(&L@9&ES<&]Z[6-I:2X@1&5T
M86EL>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82X`4WES
M=.EM($UE=&%R1$(@;FEE(&IE('!R:7!O:F5N_2X`365T\V1A`$UE=/-D82`B
M)7,B(&YI92!J92!D969I;F]V86[A`$YE9&5F:6YO=F%NX2!M973S9&$N(%9O
M;&%NZ2!Z(&UE=/-D>3H@)7,`365T<FEC:^D`365X:6-O`$UI:W)O;NEZ<VME
M(&9E9&5R873M=FYE(+ETX71Y`%-T<F5D`%1Y<"!-:6UE`$YA:FYIOKEI82!T
M97!L;W1A('IA('!O<VQE9&[]8V@@,C0@:&]D[6XZ(`!.86IN:;ZY:6$@=&5P
M;&]T82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ(`!-:6YI;>%L;F$@9&]B82!P
M;&%T;F]S=&D@:&5S;&$@9;ET92!N979Y<'*Y86QA`$UI;OIT82AY*0!:<FMA
M9&QO=F\@;V)RX71INP!2]'IN90!#:/UB82!B86SM:R!014%2($A45%!?4F5Q
M=65S="X`0VC]8F$@:V]N9FEG=7+A8VEA+B!!:R!C:&-E=&4@<&]UONUV8;L@
M=/IT;R!A<&QI:^%C:74L(&UU<^UT92!T97)A>B!V>6=E;F5R;W9ANR!K;VYF
M:6=U<N%C:74N`$-H_6)A($E$('-P<N%V>2X`0VC]8F$@<&^^861O=F%N_2!0
M14%2(&)A;.UK($UA:6PN`$-H_6)A($E$(')E;.%C:64N`%!O;@!-;V)I;&[]
M(&UA:6P`36EE<FYY`$3A='5M('!O<VQE9&YE:B!Z;65N>0!5<')A=FF[(%52
M3`!-;V1U;'5S`$UO;&1A=G-K;P!-;VYA:V\`4&]N9&5L;VL`36]N9V]L<VMO
M`$UE<VEA8P!-97-AZ&[](&[A:+5A9`!-97-I86,@82!R;VL`365S8>AN90!:
M;WIN86T@;65S8>AN_6-H('5D86QO<W3M`$UE<V'H;F4Z(&]P86MO=F%N:64`
M365S:6%C;W8@9&]P<F5D=0!-97-I86-O=B!P<F5D`$UO;G1S97)R870`365S
M8>ANZ2!FX7IY`$YA(')I861K=2`E9"!B;VQO(&[A:F1E;OUC:"!V:6%C('!O
M;.T@86MO(&_H86OA=F%N_6-H("5D+@!-87)O:V\`4')E=F&^;F4@:F%S;F\`
M4')E=F&^;F4@;V)L8>AN;P!0<F5V8;YN92!S;&YEZ&YO`%!R97-U;OJ[(&1O
M;'4`4')E<W5N^KL@=K5A=F\`4')E<W5N^KL@=G!R879O`%!R97-U;OJ[(&AO
M<F4`4')E<W5N^KL@9&]L=0!0<F5S=6[ZNR!H;W)E`$UO>F%B;6EK`%9I86/Z
M<F]V\F]VZ2!V>6)E<F%C:64@>F]Z;F%M>0!";VQO(&[A:F1E;OUC:"!V:6%C
M97)O(&MO;7!O;F5N=&]V(&E#86QE;F1A<CL@<&]D<&]R;W9A;OT@:F4@:6)A
M(&IE9&5N('9%=F5N="X`5FEA8V[A<V]B;OT@=OUB97(`36]J92!K;VYT;P!)
M;F9O<FWA8VEE(&\@;6]J;VT@^NAT90!-;VIE(&MA;&5N9.%R90!-;VIE(&MA
M;&5N9.%R.@!-;VIA(%523"!S(&EN9F]R;>%C:6%M:2!O('IA;F5P<N%Z9&YE
M;F]S=&D`3?1J('!O<G3A;`!6>FBU860@;?1J:&\@<&]R=.%L=0!->6%N;6%R
M`$YI92P@3D53VDA,05/-32X`365N;P!.86WM8FEA`$YA=7)U`$YE<.%L`$AO
M;&%N9'-K;P!(;VQA;F1S:^D@06YT:6QY`%KA:VQA9&[A(%523"!.971S8V%P
M90!54DP@<')E('IN97!L871N96YI92!C97)T:69I:^%T;W8@0T$@3F5T<V-A
M<&4`55),('!R92!P;VQI=&EK=2!#02!.971S8V%P90!54DP@<')E(&]B;F]V
M96YI92!P;&%T;F]S=&D@8V5R=&EF:6OA=&]V($YE='-C87!E`%523"!P<F4@
M>FYE<&QA=&YE;FEE(&-E<G1I9FEKX71O=B!.971S8V%P90!-96YO(%-33"!S
M97)V97)A($YE='-C87!E`$MO;65N=.%R(&-E<G1I9FEKX71U($YE='-C87!E
M`%1Y<"!C97)T:69I:^%T=2!.971S8V%P90!3:66[`$YI:V1Y`$YO=N$@2V%L
M963S;FEA`$YO=N$@:V%T96?S<FEA`$YO=N$@=61A;&]SNP!.;W;A('-P<N%V
M82!P<F4@)7,`3F]V`$YO=ND@<&]UONUV871EM7-KZ2!M96YO("AN97!O=FEN
M;NDI`$YO=OT@6NEL86YD`$YO=OT@:V%L96YDX7(@8F]L('9Y='9O<F5N_2!A
M(&%U=&]M871I8VMY('-A('ID:66U82!S;R!S:W5P:6YO=2`H<VMU<&EN86UI
M*3H@)7,N`$YO=ND@:&5S;&\`4&QA=&YO<[L@;F]VZ6AO(&AE<VQA('9Y<'*Y
M[2`E>"X`3F]VZ2!H97-LX2!N:64@<_H@<F]V;F%KZ2X`3F]VZ2!O:VYO("A?
M8FQA;FLI`$YE=W,`1&ES:W5S;ND@<VMU<&EN>0#/86QE:@!.87-L961U:OIC
M:6-H(#(T(&AO9.UN`$YA<VQE9'5J^F-E(#0@9N%Z>0!.87-L961U:OIC:2!D
M9?(`3F%S;&5D=6KZ8VD@;65S:6%C`$YA<VQE9'5J^F-I('3]OF1E\@!.87-L
M961U:OIC:2!R;VL`3F%S;&5D=6KZ8VD@9&7R`,]A;+EI92!N87-T879E;FEA
M`$YA<VQE9'5J^F-I('3]OF1E\@!.87-L961U:OIC83X`3FEK87)A9W5A`$YI
M9V5R`$YI9^ER:6$`3F]C`$YI=64`3FEE`*YI861E;B!A;&%R;0"N:6%D;FD@
M^NAA<W1N[6-I`$YI92!S^B!D;W-T=7!NZ2"^:6%D;F4@:V]N9FEG=7)AZ&[I
M(/ID86IE+"!P<F4@:W1O<ND@8GD@<V$@9&%L:2!Z;V)R87IINR!R;WID:65L
M>2X`4')E('9Y=';A<F%N:64@25-/(&]B<F%Z;W8@;FEE(&IE(&L@9&ES<&]Z
M[6-I:2"^:6%D;F$@<W1R873I9VEA+@!.965X:7-T=6IE(+EA8FSS;F$@<')E
M(&3A=FMU+@!.82!P;[YA9&]V86YE:B!P;WKM8VEI(&YE97AI<W1U:F4@OFEA
M9&5N(&)L;VLN`%!R92!-0T%,(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A
M;ND@;65N;R!K86QE;F3A<F$N`%!R92!N97!R:6ALX7-E;OUC:"!P;W6^[79A
M=&6U;W8@;FEE('/Z(&L@9&ES<&]Z[6-I:2"^:6%D;F4@:V%L96YDX7)E+@"N
M:6%D;F$@>FUE;F$N`$L@=&]M=71O('!RX79U(&YE;6^^;F\@<')I9&&[(+YI
M861N92!P;V1R:6%D96[I('!RX79A+@!0<F4@)7,@;F5B;VQA('5RZ&5NX2!K
M;VYF:6=U<N%C:6$N`%!R92!&5%`@5D93(&YE8F]L82!U<NAE;N$@:V]N9FEG
M=7+A8VEA+@!0<F4@4U%,(%9&4R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I
M82X`4')E(%-13"U&:6QE(%9&4R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I
M82X`KFEA9&5N(&MR961I="X`3F5B;VQO(+EP96-I9FEK;W9A;ND@;6EE<W1O
M('5RZ&5N:6$N`*YI861N>2!DX71U;2!U:V]NZ&5N:6$`KFEA9&YE('5D86QO
M<W1I(&YA('IO8G)A>F5N:64`4_IB;W(@;F5B;VP@;F%H<F%N_2X`4')E("5S
M(&YI92!J92!K(&1I<W!O>NUC:6D@:6YF;W)MX6-I82!O('IA;F5P<N%Z9&YE
M;F]S=&D`3F5B;VQI(&[A:F1E;ND@OFEA9&YE(/ID86IE(&E#86QE;F1A<BX`
M3F5B;VQI(&[A:F1E;ND@OFEA9&YE(&EK;VYY+@!.:64@:F4@;F%S=&%V96[A
M(&QO:V%L:71A+@!.96)O;&$@>F%D86[A(&QO:V%L:71A+@!.96)O;&$@>F%D
M86[A(+YI861N82!S<'+A=F$N`$YE8F]L;R"Y<&5C:69I:V]V86[I(+YI861N
M92!M96YO+@!.96)O;&\@N7!E8VEF:6MO=F%NZ2#H[7-L;RX`KFEA9&YE('5R
MX;YL:7;I(&9O<G1U;GD`4')E($A45%`@875T96YT:69I:^%C:74@;F5B;VQO
M('IA9&%NZ2!H97-L;RX`4')E($E-05`@875T96YT:69I:^%C:74@;F5B;VQO
M('IA9&%NZ2!H97-L;RX`4')E($ME<F)E<F]S(&%U=&5N=&EF:6OA8VEU(&YE
M8F]L;R!Z861A;ND@:&5S;&\N`%!R92!,;V=I;B!A=71E;G1I9FEKX6-I=2!N
M96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@4$%34U=$(&%U=&5N=&EF:6OA8VEU
M(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!334(@875T96YT:69I:^%C:74@
M;F5B;VQO('IA9&%NZ2!H97-L;RX`3F5B;VQA('IA9&%NX2!C97-T82!K('!R
M;V=R86UU($]P96Y34TPN(%!R;V=R86T@3W!E;E-33"!J92!P;W1R96)N_2!N
M82!P<N%C=2!S(/ID86IM:2!02T-3(#$R+@"N:6%D;F4@<')E8FEE:&%J^F-E
M('!R:6ALX7-E;FEA+@!+=O-T82!N:64@:F4@;F%S=&%V96[A+@!"97H@;W!A
M:V]V86YI80!"97H@Z&EA<@!.96)O;""Y<&5C:69I:V]V86[](&]D9&6U;W9A
MZ"X`0F5Z('-T<N%N`%/Z8F]R(&YE;N%J9&5N_0!0<F4@=GER;W9NX79A8VEU
M('!A;>2[(&YI92!J92!D;W-T=7!N_2"^:6%D96X@9&_H87-N_2!P<FEEZ&EN
M;VLN`$YE8F]L;R!O9&]S;&%NZ2!P;W6^[79A=&6U<VOI(&UE;F\@82]A;&5B
M;R!H97-L;RX`3F5B;VQI('9RX71E;ND@<&QA=&[I(%A-3"#Z9&%J90!.96)O
M;&$@;N%J9&5NX2!P;&%T;N$@92UM86EL;W;A(&%D<F5S80"N:6%D;F4@:&]D
M;F]T>0!6('#T=F]D;F5J(&MO;F9I9W5RX6-I:2!N96)O;&$@;N%J9&5NX2"^
M:6%D;F$@=F5R>FEA+B!6>6=E;F5R=6IT92!Z;F]V=2!K;VYF:6=U<N%C:74N
M`%8@:V]N9FEG=7+A8VEI(&YE8F]L82!NX6ID96[A(+YI861N82!V97)Z:6$N
M(%9Y9V5N97)U:G1E('IN;W9U(&MO;F9I9W5RX6-I=2X`KFEA9&YA`*YI861N
M92`H<&]UOFF[(&EM<&QI8VET;OH@:&]D;F]T=2D`3W-T<F]V($YO<F9O;&L`
M4V5V97)NX2!P;VQO9W6U80!3979E<F[I($UA<FGA;G-K92!O<W1R;W9Y`$[S
M<G-K;P!.97!L873M('!O`$YE<&QA=.T@<')E9`!.:64@:F4@861R97/A<@!.
M96[A:F1E;ND`3FEE(&IE(&EM<&QE;65N=&]V86[I+@!.96YA<W1A=F5NZ0!.
M:64@:F4@<&]D<&]R;W9A;NDN`%!O>F[A;6MY`$YIZ"!N82!P<F5Z97)A;FEE
M+"!V<N&[=&4@<V$@<W#DNRX`57!O>F]R;F5N:6$`3F]V96UB97(`5&5R87H`
MR.US;&\`4&_H970@>FYA:V]V`%!OZ&5T('-TY7!C;W8`4&_H970@<FEA9&MO
M=@!0<F4@86MT=6%L:7KA8VEU('IO>FYA;74@<'+M:F5M8V]V(&YE8F]L:2"Y
M<&5C:69I:V]V86[I(.CM<VQA+@!/2P!/8FIE:W0`075T;W(@;V)J96MT=0!/
M<VUIZ&MO=OT`3VMT\V)E<@!&:6QT97(@;F$@;F%DX79K>0!0<F%C;W9I<VMO
M`%-T87+I(&$@;F]VZ2!H97-L;R!M=7-I82!B>;L@;V1L:;ENZ2X`4W1A<ND@
M:&5S;&\`4W1A<ND@:&5S;&\@;F5B;VQO('IA9&%NZ2!S<'+A=FYE+@!/;>%N
M`%!R92!VN65T:WD@:V%L96YDX7)E+"!K=2!K=&]R_6T@;>%M('!R[7-T=7`@
M;F$@Z.UT86YI90!0<F4@=KEE=&MY('IO8G)A>F5NZ2!K86QE;F3A<F4`26)A
M('!R92!M;VIE(&MA;&5N9.%R90!)8F$@24U!4"!S97)V97)Y('!O9'!O<G5J
M^B!Z9&EEM6%NZ2!P<FEEZ&EN:WDN`$EB82!U<N&^;&EVZ2!F;W)T=6YY`$IE
M('!R[7!U<W1NX2!I8F$@:F5D;F$@92UM86EL;W;A(&%D<F5S82X`5FQA<W1N
M[6MA(&%L96)O('!RX79A('9L87-T;NUK82!P<F4@>F1I9;5A;OT@;V)J96MT
M(&WTOF4@>FUE;FF[(&EB82!V;&%S=&[M:R!A;&5B;R!S>7-TZ6UO=OT@861M
M:6YI<W1RX71O<@!/='9O<FF[('8@;F]V;VT@;VMN90!#:'EB82!/<&5N4U-,
M.B!N97!O9&%R:6QO('-A('KM<VMANR#Z9&%J92!Z('!O9'#M<V%N96H@Z&%S
M=&D@4R]-24U%+@!/='9O<FF[('3Z=&\@;&EN:W4@=B!N;W9O;2!O:VYE`$]P
M97)AZ&[]('-Y<W3I;0!6;VQI=&6U;ND`3F5P;W9I;F[M(/KH87-T;NUC:0!.
M87-T879E;FEA`$YA<W1A=F5N:6$@)7,`6F]R861E;OT@>F]Z;F%M`$]R9V%N
M:7KA8VEA`$]R9V%N:7IAZ&[A(&IE9&YO=&MA`$]R9V%N:7IO=F%N:64`4/1V
M;V1NX2"Y86)L\VYA(&%P;&EKX6-I90!0]'9O9&[I(+EA8FSS;GD@=B`E<SH`
M26[I`,]A;+EI92!I;F9O<FWA8VEE`%!R96BU860`5FQA<W1N[6L`4'+A=F$@
M=FQA<W1N[6MA`%9L87-T;NUK.B`E<P!004T@875T96YT:69I:^%C:6$@;FEE
M(&IE(&1O<W1U<&[A+@!014%2.DUA:6P@8F%C:V5N9`!$:6=I=.%L;GD@<&]D
M<&ES(%!'4`#:9&%J92!Z8;EI9G)O=F%NZ2!P;VUO8V]U(%!'4`!01U`@=F5R
M96IN_2!KM?KH`-ID86IE('!O9'#M<V%NZ2]Z8;EI9G)O=F%NZ2!P;VUO8V]U
M(%!'4`!02%`@:_-D`%!(4"!3:&5L;`!0;W!O;'5D;NT`4&]P;VQU9&[M(+5A
M:&O](&3AON\`4&]P;VQU9&[M('!R96CA;FMY`%!O<&]L=61N[2!S;F6^96YI
M90!0;W!O;'5D;NT@<VYE:&]VZ2!P<F5HX6YK>0!0;W!O;'5D;NT@<VYEOF5N
M:64`4&]P;VQU9&[M(&+Z<FMY`$-H_6)A(')O>KGM<F5N:64@4$]325@`4%](
M4"!3:&5L;`!6>7!L;F5N:64`4&%K:7-T86X`4&%L875S:^D@;W-T<F]V>0!0
M86QE<W3M;G-K92#Z>F5M:64`4&%N86UA`%!A<'5A($YO=N$@1W5I;F5A`%!A
M<F%G=6%Y`,AI87-T;^AN92!O8FQAZ&YO`$AE<VQO`$AE<VQO(&)O;&\@^G-P
M9;EN92!Z;65N96[I+@!.97-P<N%V;F4@:&5S;&\`4')E(&%U=&5N=&EF:6OA
M8VEU(%)!1$E54R!J92!V>;YA9&]V86[I(&AE<VQO+@!(97-L;R!S('!O='9R
M9&5N[6T`2&5S;&\Z`$AE<VQO.B``2&5S;.$@;75S:6$@8GF[(')O=FYA:^DN
M`%IO>FYA;2!M:6YU;/UC:"!U9&%L;W-T[0!6;&^^:;L`5FQOOFF[('IO('-C
M:'+A;FMY`$-E<W1A`%9Z;W(`4')E8FEE:&%J^F-E(')E9VES='+A8VEE.@"E
M=61I80!097)C96YT`%9Y:V]N8;L@;W!E<N%C:64@^F1ROF)Y`%9Y:V]N8;L@
M;W!E<N%C:64@^F1ROF)Y('!R:2!P<FEH;.%S96[M/P!.871R=F%L;R!V>6UA
M>F&[('3Z=&\@=61A;&]SNS\`4'+A=F\`4'+A=F\@(B5S(B!N96)O;&\@=GEM
M87IA;NDN`%!R[7-T=7`@>F%M:65T;G5T_0!0<N%V80!!9&UI;FES='+A8VEA
M('!RX78`3W-O8F[I(&EN9F]R;>%C:64`4&5R=0!$;VWA8V4@>G9I97)A=.$`
M1FEL:7#M;GD`5&5L96;S;@!&;W1O9W)A9FEE`%!I=&-A:7)N`$)O9&]V`$ML
M:6MN:71E('!R;W/M;2!D;R!N96IA:V5J(&)U;FMY`%!O='9R[W1E('!R;W/M
M;2P@OF4@8VAC971E(&]D<W1RX6YINR!T96YT;R!E;&5M96YT.@!0;W1V<N]T
M92!P<F]S[6TL(+YE(&-H8V5T92!O9'-T<N%N:;L@;&EN:W4@>B!T;VAT;R!E
M;&5M96YT=2X`6F%D86IT92!P<F]S[6T@;65S:6%C(&$@<F]K+@!:861A:G1E
M('!R;W/M;2!M96YO('!R92!N;W;Z(&MA=&5G\W)I=3H`6F%D86IT92!P<F]S
M[6T@<&QA=&[Z($E0(&%D<F5S=2X`6F%D86IT92!P<F]S[6T@<&QA=&[](&3A
M='5M+"!S:V]N=')O;'5J=&4@<&_H970@9&[M('8@;65S:6%C:2X`6F%D86IT
M92!P<F]S[6T@<&QA=&[](.AA<RX`4')O<^UM('5V9>]T92!Z:')N=71I92!P
M<F]B;.EM=2X`4')O<^UM('IA9&%J=&4@<W9O:F4@<&]UONUV871EM7-KZ2!M
M96YO(&$@:&5S;&\`4')EZ.UT86IT92!S:2!P<F]S[6T@;F%S;&5D=6KZ8VD@
M=&5X="X@3553S51%('/Z:&QA<VF[(',@<&]D;6EE;FMA;6D@<&]UONUV86YI
M82!S>7-TZ6UU+@!:861A:G1E('!R;W/M;2!M96YO('!R92!N;W;Z(&MA=&5G
M\W)I=3H`4&^U<VMO`%!O;&ET:6MA`$%N:V5T>0!.87-T879E;FEA('!O<G3A
M;'4`4&]R='5G86QS:V\`56UI97-T;F5N:64@=&]H=&\@;V)RX7IK=0!5;6EE
M<W1N96YI92!T96IT;R!T86)UM6MY`$]D;W-L8;L@9&\@=&]H=&\@<')I9>AI
M;FMA("AN979Y;G5C=6IE($E-05`I`%IRX;YK>2!Z82!P;W-L961N_6-H("5S
M(&AO9.UN.B``4')A=F1E<&]D;V)N;W.[/&)R("\^>G+AOF]K`%!R969S7VQD
M87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!,1$%0(&YE8F]L;R!NX6ID96[I
M+@!0<F5F<U]S97-S:6]N.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<V5S<VEO
M;B!N96)O;&\@;N%J9&5NZ2X`5&QA:P!4;&%K(&YA(/IR;W9N:2!M;W)A.B``
M5&QA:SH@`%5KX;YK80!:;V)R87IINR!U:^&^:W4@;V)RX7IK=2!V(&YO=F]M
M(&]K;F4`4')E9&-HX61Z86KZ8VD@9&7R`%!R961C:.%D>F%J^F-I('3]OF1E
M\@!0<F5D8VCA9'IA:OIC:2!D9?(`4')E9&-HX61Z86KZ8V4@;F%S=&%V96YI
M80!6>71L8>AINR!D;VMU;65N=`!0<FEVX71N>2!KM?KH`%!R;V)LZ6T`4&]P
M:7,@<')O8FSI;74`4')O:F5K='D`5OUZ=F$@;F$@>F%D86YI92!T97AT=0!6
M97)E:F[](&NU^N@`06QG;W)I=&UU<R!V97)E:F[I:&\@:[7ZZ&$`26YF;W)M
MX6-I92!O('9E<F5J;F]M(&NU^NAI`%9E<F5J;OTO<')I=N%T;GD@:[7ZZ&]V
M_2!PX7(@;F5B;VP@^G-P9;EN92!V>6=E;F5R;W9A;OTN`%!O<G1O<FEK;P!+
M871A<@!$;W1A>@!+=O-T80!24T$@=F5R96IN_2!KM?KH("@E9"!B:71O=BD`
M4')E<.UN8>@@<R!V_6)E<F]M`$3AON\`4N%N;R!DX;[O`$YE<VOT<B!DX;[O
M`$1AON]O=ND@<')E:.%N:WD`1.&^[R!S;R!S;F5H;VT`1.&^[R!P<F5C:.%D
M>F%J^F-I('8@<VYEOF5N:64`3N%H;V1NX2!F;W)T=6YA`%!O;65R`,CM=&&[
M`,CM=&&[('-P<N%V>0!.86]Z86H@=GEM87IANR`E<S\@5/IT;R!O<&5RX6-I
M=2!N96UOOFYO('9RX71INR!S<.2[+@!.86]Z86H@=GEM87IANR!P;W6^[79A
M=&6U<VOI(/ID86IE('!R92!P;W6^[79A=&6U82`E<S\@5/IT;R!O<&5RX6-I
M=2!N96UOOFYO('9RX71INR!S<.2[+@!/<&%K=6IE('-A(&O];0!/<&%K;W9A
M;FEE`-ID86IE(&]P86MO=F%N:6$`1.%T=6T@=6MO;NAE;FEA(&]P86MO=F%N
M:6$`26YT97)V86P@;W!A:V]V86YI80!4>7`@;W!A:V]V86YI80!O<&%K=6IE
M('-A(&MAOF1O9&5N;F4`;W!A:W5J92!S82!K8;YD_2!M97-I86,`3W!A:W5J
M92!S82!K8;YD_2!T_;YD9?(`;W!A:W5J92!S82!R87H@<F_H;F4`5G+A=&D@
M<W#DNR!68;EU('!O<VQE9&[Z(&%K8VEU`$]B;F]V:;L`3V)N;W9INR!E;&5M
M96YT>2!D>6YA;6EC:^EH;R!M96YU.@!/8FYO=FF[('IO8G)A>F5N:64@<&]R
M=.%L=3H`4F5G=6SA<FYY(';]<F%Z`%!R96AL:6%D8>@@=GJ[86AO=@!:;F]V
M=2!N8>CM=&&[`%!O<W1R96AY`%!R:7!O;6EE;FMA.B`E<P!6>F1I86QE;ND@
M:V%L96YDX7)E`%9Z9&EA;&5NZ2!K86QE;F3A<F4Z`%9Z9&EA;&5NZ2!S97)V
M97)Y`%523"!V>F1I86QE;NEH;R!P<FEH;.%S96YI80!6>F1I86QE;N$@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`3V1S='+A;FF[`$]D
M<W1RX6YINR`E<P!/9'-T<N%N:;L@^NAA<W1N[6MA`$]D<W1RX6YINR!B;&]K
M`$]D<W1RX6YINR!S=.5P96,`3V1S='+A;FF[(&9O<FWA=&]V86YI90!/9'-T
M<N%N:;L@<.%R`$]D<W1RX6YINR!U;&^^96[]('-K<FEP="!Z(&1OZ&%S;NEH
M;R!P<FEEZ&EN:V$@;F$@<V5R=F5R:2X`3V1S='+A;FF[`$]D<W1RX6YINR!T
M96YT;R!B;V0@>B!D;VMU;65N='4`3V1S='+A;FF[('!O=;[M=F%T9;5A`$]D
M<W1RX6YINR!P;W6^[79A=&6U83H@)7,`4')E<.US8;L@97AI<W1U:OIC:2!K
M86QE;F3A<B!I;7!O<G1O=F%N_6T@:V%L96YDX7)O;3\@/'-T<F]N9SY687)O
M=F%N:64Z('1O=&\@=GEM8;YE(':Y971K>2!P;VQOOFMY('9O(%9AN6]M(&%K
M='7A;&YO;2!K86QE;F3A<FDN/"]S=')O;F<^`$YA('!OOFEA9&%V:W4@;F5B
M;VQO(&UOOF[I(&]D<&]V961ANRX@3N%V<F%T;W;](&OS9"!C:'EB>3H@`%!O
MOF%D;W9A;OH@<VQUOF)U('-A(&YE<&]D87)I;&\@;N%J<[LN`%!OOF%D;W9A
M;OT`5B!K;VYF:6=U<N%C:6D@)7,@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^
M861O=F%NX2!P;VQOOFMA("(E<R(`5B!K;VYF:6=U<N%C:6D@5D93(&YI92!J
M92"Y<&5C:69I:V]V86[A('!OOF%D;W9A;N$@<&]L;[YK82`B)7,B`%8@:V]N
M9FEG=7+A8VEI(&YI92!J92"Y<&5C:69I:V]V86[A('!OOF%D;W9A;N$@<&]L
M;[YK82`B)7,B`%!OOF%D;W9A;NT@^NAA<W1N[6-I`%!O=FEN;ND@<&]L90!6
M>6UA>F&[(&9O<FUU;.%R`$]B;F]V:;L@:&5S;&\`3V)N;W9INR!68;EE(&AE
M<VQO`$]B;F]V:;L@;F$@<')E9&YA<W1A=F5NZ2!H;V1N;W1Y`$]D<&]V9>\`
M3V)N;W9INR!P;W-L961N_2!D;W1A>@!6_7-L961K>0!.X79R870@;F$@;F%S
M=&%V96YI80!:861A:G1E(&YO=ND@:&5S;&\`4F5U;FEO;@!6<N%T:;L@:V]N
M9FEG=7+A8VEU`$YA<W1A=F5N:6$@<F]ZN>UR96[I:&\@=&5X=&]VZ6AO(&5D
M:71O<G4`2.%D86YK>0!6<')A=F\`2&QA=FGH:V$@=G!R879O`$AO9&YO='D@
M=G!R879O`%9L87-T;F]S=&D@7W)I861K82XN+@!2;VQA`%)U;75N<VMO`$]T
M;^AINR!O(#$X,`!/=&_H:;L@=K5A=F\`3W1OZ&F[('9P<F%V;P!6;&%S=&YO
M<W1I(')I861K80!6;&%S=&YO<W1I(')I861K80!2:6%D:WDZ`,AI87)Y`,AI
M87)Y('-A('IO8G)A>FEA(&UE9'II(':Y971K_6UI(')I861K86UI(&$@<W3E
M<&-A;6D`R&EA<GD@<V$@>F]B<F%Z:6$@:6)A(&UE9'II('-TY7!C86UI`,AI
M87)Y('-A('IO8G)A>FEA(&EB82!M961Z:2!R:6%D:V%M:0!3<'5S=&F[`%)U
M<VOA(&9E9&5RX6-I80!2=V%N9&$`4R]-24U%(&MR>7!T;V=R869I8VO]('!O
M9'!I<P!3<'+A=F$@>F&Y:69R;W9A;N$@<&]M;V-O=2!3+TU)344`4T%33"!A
M=71E;G1I9FEKX6-I82!N:64@:F4@9&]S='5P;N$N`%!O<VEE;&%N:64@4TU3
M`%-13"!3:&5L;`!344P@<'+M:V%Z('!R92!HM6%D86YI92!H;V1N]'0`4U-(
M`-I34$5#2`!37U%,(%-H96QL`%-O`%-VY'3A($AE;&5N80!3=N1T_2!+:71T
M<R!A($YE=FES`%-VY'3A($QU8VEA`%-V+B!0:65R<F4@82!-:7%U96QO;@!3
M=N1T_2!6:6YC96YT(&$@1W)E;F%D:6YY`%1E;B!I<W3]('+A;65C("A?<V5L
M9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A(%!R:6YC:7!E`%-A=&5L
M:71N_2!P;W-K>71O=F%T9;4`4V]B;W1A`%-A=61S:^$@07+A8FEA`%5L;[YI
MNP!5;&^^:;L@(B5S(@!5;&^^:;L@)7,`56QOOFF[(&%K;R!N;W;Z`%5L;[YI
MNR#ZZ&%S=&[M:V]V`%5L;[YINR!U9&%L;W.[`%5L;[YINR!N87-T879E;FEA
M`%5L;[YINR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A8VEU(&%K;R!02%`@<VMR
M:7!T(&1O(&1OZ&%S;NEH;R!P<FEEZ&EN:V$@5N&Y:&\@<V5R=F5R82X`2V]N
M9FEG=7+A8VEA("5S(&)O;&$@=6QOOF5NX2X`4VMR:7!T(&YA('5P9W)A9&4@
M;F%S=&%V96[M(&)O;"!U;&^^96[](&1O.B`B)7,B+@!/:F5D:6YE;.D@8OIR
M:WD`5F5D80!(M6%D8;L`4')E:+5A9&&[(&MA;&5N9.%R90!6>6BU863A=F'H
M90!6_7-L961K>2!HM6%D86YI80!(M6%D8;L@:V%L96YDX7)E(&]B<V%H=6KZ
M8V4Z`%9Y8F5R=&4@<_IB;W)Y`%9Y8F5R=&4@:V%L96YDX7(@;F$@^G!R879U
M`%9Y8F5R=&4@9.%T=6T`5GEB97)T92!S:W5P:6YU(&YA('!R:61A;FEE`%9Y
M8F5R=&4@;F]VZ6AO('9L87-T;NUK80!6>6)E<G1E('-E<G9E<@!6>6)E<G1E
M('!O=;[M=F%T9;5A(&YA('!R:61A;FEE`%9Y8F5R=&4@=KEE=&MY`%9Y8F5R
M=&4@=KEE=&MY(&MO;7!O;F5N='D@9.%T=6UU`%9Y8F5R=&4@;V)J96MT`%9Y
M8F5R=&4@:V%L96YDX7)E+"!K=&]RZ2!S82!M86KZ('IO8G)A>F]V8;LZ`%9Y
M8F5R=&4@;6^^;F]S=&D@<&]T=G)D96[M+"!A:V\@<V$@;6%J^B!Z;V)R87IO
M=F&[('+T>FYE(&[A:+5A9'D@82!V>6)E<G1E(&EM<&QI8VET;OT@;N%HM6%D
M+@!:<G6Y:;L@=OUB97(`5GEB97)T92!K86QE;F3A<BP@9&\@:W1O<NEH;R!S
M82!MX2!I;7!O<G1O=F&[.@!6>6)E<G1E(&MA;&5N9.%R*&4I+"!K=&]RZ2!S
M82!M86KZ(&5X<&]R=&]V8;L`5GEB97)T92!Z;F%K>2P@:W1O<ND@<&]T<F5B
M=6IE=&4L('H@;VMI96YO:R!N:;ZY:64N(%!O=&]M(&EC:"!M]+YE=&4@<VMO
M<.UR;W9ANR!A('9L;[YINR!Z('1E>'1O=NEH;R!P;[5A+@!6>6)E<G1E(&]D
M9&6U;W9AZ"!V;R!F;W)MX71E(&3A='5M=3H`5GEB97)T92!F;W)MX70@9.%T
M=6UU.@!6>6)E<G1E(&9O<FWA="!E>'!O<G1U.@!6>6)E<G1E('/Z8F]R('!R
M92!I;7!O<G0Z`%9Y8F5R=&4@<')V_2!D9?(@=/V^9/)A.@!6>6)E<G1E(&9O
M<FWA="!Z9')O:F]VZ6AO('/Z8F]R=3H`5GEB97)T92!I9&5N=&ET=2P@:W1O
M<OH@8VAC971E('IM96YINSH`5GEB97)T92!O9&1EM6]V8>@@=F\@9F]R;>%T
M92#H87-U.@!6>6)E<G1E(&9O<FWA="#H87-U.@!6>6)E<G1E(.AA<V]V_2!R
M;WIS86@@<')E('IO8G)A>F5N:64Z`%9Y8F5R=&4@;N%HM6%D+"!K=&]R_2!S
M82!Z;V)R87KM('!O('!R:6ALX7-E;NTZ`%9Y8F5R=&4@9'9E('IH;V1NZ2!P
M;VQI82X`5GEB97)T92P@:W1O<ND@=61A;&]S=&D@<V$@;6%J^B!Z;V)R87II
MNR!V('!O<G3A;&DN`%9Y8F5R=&4@<VD@9F%R96)N^B!S8VCI;74`5GEB97)T
M92!J87IY:SH`4&]S;&&[('-P<N%V=2!O('!R;V)LZ6UE`%!O<VQANR!335,`
M4&]S;&&[('5P;WIO<FYE;FEE(&\@>G)UN65N[2!VN65T:_UM(/KH87-T;NUK
M;VT@<')I('9Y;6%Z86[M('1E:G1O('5D86QO<W1I`%!O<VQANR!E+6UA:6P@
M)7,`4&]S;&&[(&%K='5A;&EZX6-I92]P;WIVX6YK>2!VN65T:_UM(/KH87-T
M;NUK;VT@<')I('5L;[YE;NT@=&5J=&\@=61A;&]S=&D`4V5N96=A;`!396YZ
M;W(Z(`!397!T96UB97(`4W)B<VMO(&$@R&EE<FYA(&AO<F$`4^ER:6]VZ2#H
M[7-L;P#:9&%J92!Z;R!S97)V97)A('/Z(&YE<W!RX79N92!A;&5B;R!N:64@
M<_H@9&]S='5P;NDN`$%D;6EN:7-T<N%C:6$@<V5D96[M`%!L871N;W.[($E$
M('-E9&5N:6$@=GEP<KEA;&$N`%-E9&5N:6$`36YOOFEN82!H;V1N]'0`3F%S
M=&%V:;L@9.%T=6T@=6MO;NAE;FEA`$YA<W1A=G1E(&UOOFYO<W1I(&YA(&]B
M;F]V96YI92!6X;EH;R!H97-L82!A:R!H;R!Z86)U9&YE=&4N`$YA<W1A=FF[
M(&3A='5M('5K;V[H96YI82!O<&%K;W9A;FEA`$YA<W1A=FF[(&3A='5M('IA
MZ&EA=&MU`$YA<W1A=F5N:64@=GID:6%L96[]8V@@<V5R=F5R;W8L(&MU(&MT
M;W+];2!C:&-E=&4@<')I<W1U<&]V8;L@>B!6X;EH;R!P;W)TX6QU+@!.87-T
M879INR!68;EE(&MA;&5N9.%R92!S(&EN9F]R;>%C:6]U(&\@>F%N97!RX7ID
M;F5N;W-T:2!A(&YA<W1A=F5N:6$@>F%N97!RX7ID;F5N;W-T:2!P<F4@5N%S
M(&$@:6[]8V@@<&]UONUV871EM6]V+@!6>6)E<G1E(&IA>GEK+"#H87-O=OH@
M>O-N=2!A(&YA<W1A=F5N:6$@9.%T=6UU+@!.87-T879E;FEE(&%P;&EKX6-I
M92!S</JYNV%N96H@<')I(+ET87)T92P@9F%R96)N96H@<V-HZ6UY+"!I;G1E
M<G9A;'4@;V)N;W9O=F%N:6$@<W1RX6YK>2!A(&EN_6-H('9L87-T;F]S=.T@
M>F]B<F%Z96YI82X`3F%S=&%V96YI90!3^B!D;W-T=7!NZ2!S:W)I<'1Y(&YA
M('5P9W)A9&4@;F%S=&%V96[M`$1O(/IV86AY('!R:6-HX61Z82!N:65K;[5K
M;R!L;VMA;.UT('!O;6]C;W4@<&%R86UE=')A.B``4V5Y8VAE;'D`6F1I9;5A
M;FEE(&YE8F]L;R!NX6ID96[I.B`E<P!:9&EEM6%NZ2!K86QE;F3A<F4`6F1I
M9;5A;ND@:V%L96YDX7)E.@!3:&]P<&EN9P!+<N%T:WD@<_IH<FX`36%J^B!S
M82!P<F4@=N3HN6EN=2!L:6YI96L@=GET=F]R:;L@<VMR871K;W;I(&MLX79E
M<WD_`%IO8G)A>FF[`%IO8G)A>FF[(&MA;&5N9.%R`%IO8G)A>FF[(&QE9V5N
M9'4@<')E(&MA;&5N9.%R/P!:;V)R87IINR!I:V]N>2!P<F4@=GEM87IA;FEE
M+"!A;&%R;2!A(&]P86MO=F%N:64@=B!K86QE;F3A<F]V_6-H(&[A:+5A9&]C
M:#\`6F]B<F%Z:;L@<F]Z9&EE;'D@;65D>FD@<'+A=F4@=6QOOF5N;W4@82!N
M;W9O=GEG96YE<F]V86YO=2!K;VYF:6=U<N%C:6]U+@!:;V)R87IINR#Z;&]H
M>2!P;R!T97)M[6YE('8@:V%L96YDX7)I/P!:;V)R87IINR!L96=E;F1U('!R
M92!I;F9O<FWA8VEE(&\@>F%N97!RX7ID;F5N;W-T:3\`3>$@<V$@<')I('!R
M:6ALX7-E;NT@>F]B<F%Z:;L@Z&%S('!O<VQE9&[I:&\@<')I:&SA<V5N:6$_
M`%IO8G)A>FF[(&QE;B!U9&%L;W-T:2P@:W1O<ND@;6%J^B!N87-T879E;OT@
M86QA<FT@/P!:;V)R87IINR!M;[YN;W.[(&YA('!O;F5C:&%N:64@;W)I9VEN
MX6QU`%IO8G)A>FF[(&[A<W1R;VH@;F$@=OUB97(@9F%R:65B`%IO8G)A>FF[
M('ID:66U86[I(&MA;&5N9.%R92!V962U82!S96)A/P!:;V)R87IINR!M96YU
M('!R92!O<&5RX6-I92!S('1A8G6U:V%M:3\`6F]B<F%Z:;L@^FQO:'D@<R!P
M;W6^:73M;2!F87)I96(@<')E(&MA=&5G\W)I93\`6F]B<F%Z:;L@;65N=2`E
M<R!N82"U879E:B!S=')A;F4_`%IO8G)A>FF[(&1I86SS9R!S('9L87-T;F]S
MNV%M:2!B=6YK>2!T86)UM6MY`%IO8G)A>FF[(&1I86SS9R!S('9L87-T;F]S
MNV%M:2!T86)UM6MY`%IO8G)A>FF[(&1I86SS9R!S('9L87-T;F]SNV%M:2!R
M:6%D:W4@=&%B=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@
M;V)RX7IK=0!:;V)R87IINR#H87,@;65D>FD@:V&^9/UM(&3R;VT@=B!T_;YD
M96YN;VT@;N%HM6%D93\`6F]B<F%Z:;L@;F%H<F%NZ0!0<F5HX6YK>0!2X6YO
M('!R96CA;FMY`$YE<VOT<B!P<F5HX6YK>0!:<N&^:WD@=B!O:V]L[0!:;65N
MN6F[`$YA:G!R=B!M=7/M=&4@>FUE;KEINR!A;&5B;R!P<F5S=6[ZNR!S=7-E
M9&[](&)L;VLH>2D`4VEE<G)A($QE;VYE`%IA<F5G:7-T<F]V8;L@<V$`4&]D
M<&ES`$%L9V]R:71M=7,@<&]D<&ES=0!3:6YG87!U<@!69;5K;W.[`%!R97-K
M;^AINR#Z9'*^8G4`4VQO=F5N<VMO`%-L;W9I;G-K;P!3;F6^96YI90!3;F5H
M;W;A('!R96CA;FMA`%-N96AO=ND@<')E:.%N:WD`4N%N;R!S;F5H;W;I('!R
M96CA;FMY`$YE<VOT<B!S;F5H;W;I('!R96CA;FMY`$CE8FMA('-N96AU.B``
M36YOOG-T=F\@=F]D>2!E:W9I=F%L96YT;ND@<VYE:'4Z(`"I86QA;?IN;W9E
M(&]S=')O=GD`4V]MX6QS:V\`4&EE<VYE(&$@8N%S;F4`5OUB97(@<VUE<G4@
M=')I961E;FEA`%ID<F]J;W;A(&%D<F5S80!*=;YNX2!!9G)I:V$`2G6^;N$@
M1V5O<F=I82!A(%-O=71H(%-A;F1W:6-H($ES;&%N9',`2G6^;N$@<&]L;V=U
MM6$`365D>F5R82!M961Z:2!S=7-E9&[];6D@8G5N:V%M:0!-961Z97)A(&UE
M9'II(&]B<V%H;VT@82!O:W)A:F]M(&)U;FMY`$]D9&6U;W9AZ`!/9'-T=7``
M3V1S='5P(&$@=GEP;&YE;FEE`*EP86YI96QS:V\`4W!A;0!6;&^^96YI92"Y
M<&5C:>%L;GEC:"!Z;F%K;W8`4F]Z9&5L:;L@8G5N:W4`4F]Z9&5L:;L@<W3E
M<&5C`%)O>F1E;&F[(')I861O:P"I<&]R='D`4W+M($QA;FMA`%IAZ&EA7W1O
M:P"I=&%N9&%R9&[I`%-T87(@5')E:P!$X71U;2!Z8>AI871K=0!:8>CM;F$`
MR&%S('IAZ&EA=&MU`%!OZ&EA=&_H;OT@<F]K`%-T85]V`*ETX70@86QE8F\@
M<')O=FEN8VEA`%-T878`1F]R;>%T('5L;[YE;FEA`$)Y9&QI<VMO`%!R9;EK
M<G1N=73I`%IO>FYA;2!R9;MA>F-O=@!/9'-T<N%N:;L@9&]MZ6YU('H@861R
M97-Y`*ET_6P@6T-34UT`3F4`4&]D<')I9>AI;F]K("(E<R(@;F5B;VP@;N%J
M9&5N_2X`4')E9&UE=`!/9&]S;&&[`%!OOFEA9&%V:V$@;F$@<')I9&%N:64@
M(B5S(B!D;R!S>7-TZ6UU(&)O;&$@;V1O<VQA;N$N($YE;?2^971E('-A('!R
M:6ALX7-INRP@:_UM(&YE8G5D92!68;EA('!OOFEA9&%V:V$@<V-H=N%L96[A
M+@!$;VQN_2!I;F1E>`#:<W!E8V@`4')I9&%N:64@(B5S(B!D;R!S>7-TZ6UU
M(&)O;&\@^G-P9;ENZ2X`5GEM87IA;FEE(/ID86IO=B!Z;R!S>7-TZ6UU('!R
M92!P;W6^[79A=&6U82`B)7,B(&)O;&\@^G-P9;ENZ2X`5GEM87IA;FEE("(E
M<R(@8F]L;R#Z<W!EN6[I+@!6>6UA>F%N:64@(B5S(B!Z;R!S>7-TZ6UU(&)O
M;&\@^G-P9;ENZ2X`3N%V<F%T(&MU(&MO;F9I9W5RX6-I:2!B;VP@^G-P9;EN
M_2X@4')E('IO8G)A>F5N:64@>FUI96X@>FYO=G4@;F'H[71A:G1E('-T<N%N
M:W4N`%KA;&]H82!K;VYF:6=U<N%C:64@8F]L82!U;&^^96[A+@!:X6QOOF[]
M(&MO;F9I9W5R8>AN_2!S^F)O<B`E<R!B;VP@^G-P9;EN92!U;&^^96[]+@!!
M:W1U86QI>N%C:6$@(B5S(B!B;VQA(/IS<&6Y;N$N`%KA<&ES("5S(&)O;"#Z
M<W!EN6[]`%-U9.%N`%/Z:')N`%;]8VAO9"!S;&YK80!:X7!A9"!S;&YK80!.
M961EM6$`4VQN9>AN;P!6_6-H;V0@<VQN:V$`5OUC:&]D+WKA<&%D('-L;FMA
M`%;]8VAO9"!S;&YK83H@`%KA<&%D('-L;FMA`%KA<&%D('-L;FMA.B``2&]R
M;OT@:6YD97@`4&]D<&]R80!3=7)I;F%M`%!R:65Z=FES:V\`4W9A;&)A<F0@
M82!*86X@36%Y96X`4W9A>FEJ<VMO`*EVZ61S:V\`J79A:NAI87)S:V\`6N%Z
M;F%M>2!O('-Y;F-H<F]N:7KA8VEI('9Y;6%Z86[I`%-Y;F--3`!3>6YT86MT
M:6-KX2!C:'EB82!V('!O9&UI96YK86-H(&BU861A;FEA`%/]<FEA`$+Z<FMA
M`$+Z<FMA(&$@=F5T97)N;P!"^G)K>0!2X6YO(&+Z<FMY`%135B!S^F)O<@!4
M86)UM6MA`%9L87-T;F]S=&D@=&%B=;5K>0!6;&%S=&YO<W1I('1A8G6U:WD`
M5&%I=V%N`%1A:7=A;BP@<')O=FEN8VEA(,CM;GD`5&%DOFEK:7-T86X`5&%N
M>N%N:6$`0VEEM3H`VFQO:'D`5&5L96;S;FYE(.CM<VQO`%1E<&QO=&$@>F$@
M<&]S;&5D;OH@:&]D:6YU.B``5&5P;&]T80!497!L;W1A.B``5&5P;&]T83QB
M<B`O/B@E<TUA>"5S+R5S36EN)7,I("9D96<[)7,`J6%B;/-N82`B)7,B(&YE
M8F]L82!NX6ID96[A+@!3<'+A=F$@N6%B;/-N`%!R961B9;YN_0!497AT`$EB
M82!T97AT`%IA<F]V;F%N:64@=&5X='4`5&5X="!H;W)E`*ET`%1H86IS:V\`
M3V)R87IO=FMA(%5P<F%V:;L@^NAA<W1N[6MO=B!UOB!N965X:7-T=6IE+B!+
M;VYI96,N`%)O>KGM<F5N:64@1E10(&YI92!J92!D;W-T=7!NZ2X`26YT96=R
MX6-I82!(;W)D92]+;VQA8B!N97!O9'!O<G5J92`B)7,B`$E-4U`@>N%Z;F%M
M('-A(&YE<&]D87)I;&\@=6QOOFF[+@!4<FEE9&$@36%I;G1E;F%N8V4Z.B!S
M82!N96YAZ.UT86QA(/IS<&6Y;F4`3VMN;R!S(&YA<W1A=F5N:6%M:2!S82!Z
M871V;W)I;&\N($MO;FEE8RX`061M:6YI<W1RX71O<B!M=7/M(&YA:V]N9FEG
M=7)O=F&[('!E<FUA;F5N=&[](&)A8VME;F0@<')E(%!RX79A+"!A:R!C:&-E
M=&4@<&]UONUV8;L@4'+A=F$N`$EB82!S<&]D;N$@<W1R86YA`$MA;&5N9.%R
M("(E<R(@<V$@;F5P;V1A<FEL;R!V>6UA>F&[+@!+86QE;F3A<B`B)7,B(&)O
M;"!V>71V;W)E;OTN`$MA;&5N9.%R("(E<R(@8F]L('9Y;6%Z86[]+@!+86QE
M;F3A<B`B)7,B(&)O;"!P<F5M96YO=F%N_2!N82`B)7,B+@!+86QE;F3A<B`B
M)7,B(&)O;"!U;&^^96[]+@!+86QE;F3A<B!S82!N97!O9&%R:6QO('9Y;6%Z
M8;LZ("5S`$E$(.CM<VQO(&MO;G1A:W1U(&YE8F]L;R"Y<&5C:69I:V]V86[I
M+"!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE(&%L96)O(&YE8F]L;R!NX6ID96[I
M('8@9&%T86+A>F4N`$MO;G1A:W0@8F]L(/IS<&6Y;F4@=FQOOF5N_2!D;R!6
MX;EH;R!A9')E<^%R82X`3F$@;W9E<F5N:64@<&]D<.US86YE:B!S<'+A=GD@
M:F4@<&^^861O=F%N_2!O9&1E;&5N_2!B;&]K(',@4$=0('!O9'!I<V]M+@!)
M1"!Z;WIN86UU('!R[6IE;6-O=B!B=>\@;F5B;VQO(+EP96-I9FEK;W9A;NDL
M(&%L96)O(&)O;&\@<&]N96-H86[I('!RX7ID;F4@86QE8F\@;F5B;VQO(&[A
M:F1E;ND@=B!D871A8N%Z92X`3F5B;VP@=7+H96[]('IO>FYA;2!P<NUJ96UC
M;W8N`*EI9G)O=F%N:64@=GF^861U:F4@8F5Z<&7H;ND@<')I<&]J96YI92`H
M:'1T<',I+@!$9?(@=6MO;NAE;FEA(&UU<^T@;F%S;&5D;W9ANR!AOB!P;R!D
M;FD@>F'H871I82X`1&\@:V%L96YDX7)A("(E<R(@8F]L82!P<FED86[A('5D
M86QO<[L@(B5S(BP@:W1O<N$@:F4@)7,@;R`E<RX`6B!K86QE;F3A<F$@(B5S
M(B!B;VQA('9Y;6%Z86[A('5D86QO<[L@(B5S(BP@:W1O<N$@8F]L82`E<R!O
M("5S+@!6(&MA;&5N9.%R:2`B)7,B(&)O;&$@=7!R879E;N$@=61A;&]SNR`B
M)7,B+"!K=&]RX2!J92`E<R!O("5S+@!5<&]Z;W)N96YI92!N82!U9&%L;W.[
M('!R92`E<R!B;VQO(/IS<&6Y;F4@;V1O<VQA;NDN`%/Z8F]R("5S(&)Y(&UA
M;"!O8G-A:&]V8;L@;F%S=&%V96YI92`E<RX`4_IB;W(@)7,@8GD@;6%L(&]B
M<V%H;W9ANR!N:65K=&]RZ2!N87-T879E;FEA("5S+@!:9')O:F]V_2!A(&-I
M9;5O=OT@<_IB;W(@;75S:6$@8GF[(&]D;&FY;NDN`%/Z8F]R(&YE;V)S86AO
M=F%L(+YI861N92#Z9&%J92X`3F%S;&5D=6KZ(&AL879IZ&MY('1E:G1O('-P
M<N%V>2!V;R!F;W)MX71E(&UE<W-A9V4O<F9C.#(R+@!.87-L961U:F4@9&5T
M86EL;F5JN>T@<&]P:7,@=61A;&]S=&DZ`$-E;&]O8G)A>F]V:V]V_2!R9;YI
M;2!S</1S;V)U:F4@<')O8FSI;7D@=B!);G1E<FYE="!%>'!L;W)E<FD@:W;T
M;&D@8VAY8N%M('!R96AL:6%D8>AA+"!K=&]RZ2!S82!NX6T@;F5P;V1A<FEL
M;R!O8NUSNRX@3?2^=2!S82!P<F5J879INR!N97-P<N%V;GEM('IO8G)A>F5N
M[6TL(&-H_6)A:OIC:6UI(&9U;FMC:6%M:2!E9&ET;W)A(&$O86QE8F\@;N%H
M;V1N_6UI('#A9&UI('!R96AL:6%D8>AA+B!!:R!J92!6X;D@<WES=.EM(%=I
M;F1O=W,@.7@L(&IE('9EM6UI('!R879D97!O9&]B;NDL(+YE('-A('IO8G)A
M>NT@8VAY8F$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@82!B=61E=&4@
M;75S:66[(')EN71A<G1O=F&[('!OZ.UT8>@N7&Y<;E9A<F]V86QI('-M92!6
MX7,N(%-T;&'H=&4@<')O<^UM($]+(&%K(&YA;WIA:B!C:&-E=&4@<&]UOFF[
M(&5D:71O<B!V(&-E;&]O8G)A>F]V:V]V;VT@<F6^:6UE+@!)9&5N=&ET82`B
M)7,B(&)O;&$@=GEM87IA;N$N`$EB82"U87;A('-T<F%N80!4<FEE9&$@0W)Y
M<'1?<&=P.CH@<&]T<F5B=6IE('!O>FYANR!U;6EE<W1N96YI92!P<F]G<F%M
M=2!';G501RX`4W!RX79A(&]D;W-L86[A("5S('!R92`E<R!S('!R961M971O
M;2`B)7,B(&)O;&$@>F]B<F%Z96[A+@I.965X:7-T=6IE(':Y86L@>N%R=6MA
M+""^92!S<'+A=F$@8F]L82!P<F7H[71A;N$@86QE8F\@<&]C:&]P96[A+@!-
M96YO+"!K=&]RZ2!S82!MX2!P;W6^:;L@<')I(&QI;FMO=F%N[2!N82!S='+A
M;FMU(&YA('#M<V%N:64@<W!RX78@`%!OZ&5T('!O;.T@;75S[2!B>;L@Z.US
M;&\N`%1R:65D82!(;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L
M(&]P96YS<VPN`$YA<W1A=F5N:64@(B5S(B!S82!N97!O9&%R:6QO('5L;[YI
MNRP@<')E=&^^92!J96AO(/ID86IE('!R96MR8>AU:OH@;6%X:6WA;&YU('!O
M=F]L96[Z('9EM6MO<[L`4')O9W)A;2!P;W6^[79A;OT@;F$@>F]B<F%Z96YI
M92!T;VAT;R#Z9&%J;W;I:&\@='EP=2`H)7,I(&YE8F]L(&[A:F1E;OTN`%IN
M86L@8VETX6-I92!M=7/M(&)YNR!J961E;B!Z;F%K+@!0;[YI861A=FMA(&YE
M8F]L82#Z<&QNX2X@0VC]8F%J^B!N:65K=&]RZ2!P87)A;65T<F4L(&MT;W+I
M('/Z(&YE=GEH;G5T;ND@<')E(&%K8V5P=&]V86YI92!A;&5B;R!Z86UI971N
M=71I92!U9&%L;W-T:2X`26)A('!R87;A(&$@M6%VX2!S=')A;F$`26)A('!R
M87;A('-T<F%N80!/9&1EM6]V8>@@;75S[2!B>;L@:F5D96X@>FYA:RX`4V5R
M=F5R("(E<R(@8F]L('9Y;6%Z86[]+@!397)V97(@(B5S(B!B;VP@=6QOOF5N
M_2X`KFEA9&]SNR!O('!R:6ALX7-E;FEE("5S(&)O;&$@=GEM87IA;N$N`*EP
M96-I9FEK;W9A;OT@<FEA9&]K(&YE97AI<W1U:F4N`$1OZ&%S;OT@<_IB;W(@
M(B5S(B!N965X:7-T=6IE+@!:861A;OT@=&5X="!N:64@:F4@<F]V;F%K_2!A
M:V\@=&5X="!N82!O8G)A>F]V:V4N`$EB82!H;W)NX2!A('-P;V1NX2!S=')A
M;F$`26)A(&AO<F[A('-T<F%N80!.86AR86[I(/ID86IE('-A(&]D('!R961C
M:.%D>F%J^F-E:&\@:W)O:W4@<W1R871I;&DN`$YA:')A;OT@<_IB;W(@<V$@
M;F5P;V1A<FEL;R!U;&^^:;LN`$)L;VL@=V5A=&AE<BYC;VT@;FEE(&IE(&1O
M<W1U<&[]+@!0<FEEZ&EN;VL@=.EM("(E<R(@;F5B;VP@;N%J9&5N_2X`KFEA
M9&YE('5D86QO<W1I(&YE=GEH;W9U:OH@86MT=>%L;GEM(&MR:73I<FGA;2X`
MKFEA9&YE(&YA<W1A=F5N:6$@;FEE('/Z(&1O<W1U<&[I+@"N:6%D;F4@86QT
M97)N873M=FYE(.AA<W1I(&YE;6^^;F\@>F]B<F%Z:;L@=B!T96QE('-P<N%V
M>2X`5B!T;VUT;R!P;VQI(&IE('!R[6QIN2!V9;5A('IN86MO=BX@6F%D86QI
M('-T92`E<R!Z;F%K;W8[(&UU<^UT92!Z861ANR!M96YE:B!A:V\@)7,N`$YA
M<W1A;&$@8VAY8F$@<')I('!R:63A=F%N[2`B)7,B(&1O('-Y<W3I;74Z("5S
M`$YA<W1A;&$@8VAY8F$@<')I(&]D<W1R8?)O=F%N[2!P;W6^[79A=&6U<VO]
M8V@@^F1A:F]V("(E<R(@>F\@<WES=.EM=3H@`$YA<W1A;&$@8VAY8F$@<')I
M(&]D<W1R8?)O=F%N[2`B)7,B('IO('-Y<W3I;74Z(`!.87-T86QA(&-H>6)A
M('!R:2!A:W1U86QI>N%C:6D@(B5S(CH@)7,`5GES:WET;VP@<V$@<')O8FSI
M;2!S(&YA:'+A=F%N[6T@<_IB;W)U.B"N:6%D96X@)7,@;F5B;VP@;F%H<F%N
M_2X`5GES:WET;VP@<V$@<')O8FSI;2!S(&YA:'+A=F%N[6T@<_IB;W)U.B`E
M<R!B;VP@=N3HN>T@86MO(&YA:G;DZ+GM('!O=F]L96[](&QI;6ET("@E9"!B
M86IT;W8I+@!6>7-K>71O;"!S82!P<F]B;.EM(',@=6ML861A;NUM('/Z8F]R
M=3H@)7,@8F]L(&YA:')A;OT@;&5N(.AI87-T;^AN92X`3F%S=&%L82!C:'EB
M82!P<FD@<'+M<W1U<&4@:W4@:V%L96YDX7)U.B`E<P!.87-T86QA(&-H>6)A
M('!R:2!P<FEDX79A;NT@=61A;&]S=&DZ("5S`$YA<W1A;&$@8VAY8F$@<')I
M('IO8G)A>F]V86[M('1E:G1O(.AA<W1I('-P<N%V>0!.87-T86QA(&-H>6)A
M('!R:2#Z<')A=F4@=61A;&]S=&DZ("5S`$YA<W1A;&$@8VAY8F$@<')I(&EM
M<&]R=&4@^F1A:F]V(&\@:V]N=&%K=&4N`$YA<W1A;&$@8VAY8F$@<')I(&EM
M<&]R=&4@^F1A:F]V(&E#86QE;F1A<BX`3F%S=&%L82!C:'EB82!V(&MO;F9I
M9W5R8>AN;VT@9F]R;75LX7)I+B!0<F%V9&5P;V1O8FYE('-T92!N979Y<&QN
M:6QI('!OOF%D;W9A;ND@<&]L92X`3F%S=&%L82!C:'EB82!P<FD@<')E<_IV
M86[M('5D86QO<W1I.B`E<P!.87-T86QA(&-H>6)A('!R:2!V>6MO;N%V86[M
M('5RZ&5N96H@9G5N:V-I92!A9')E<^%R82X@4')O<^UM('-K^G-T92!T;R!N
M97-K]'(N`$YA<W1A;&$@8VAY8F$@<')I('!O<VEE;&%N[2!U<&]Z;W)N96YI
M82!N82!U9&%L;W.[("5S.B`E<P!.87-T86QA(&-H>6)A('!R:2!A:W1U86QI
M>N%C:6D@9&5T86EL;W8@:V]N=&%K='4N(%!R;W/M;2!S:_IS=&4@=&\@;F5S
M:_1R+@!.87-T86QA(&-H>6)A('!R:2!A:W1U86QI>N%C:6D@>F]Z;F%M=2!P
M<NUJ96UC;W8N(%!R;W/M;2!S:_IS=&4@=&\@>FYO=G4N`$YI92!S^B"^:6%D
M;F4@=61A;&]S=&D@<')E(&5X<&]R="X`5&5N=&\@24U!4"!S97)V97(@;F5P
M;V1P;W)U:F4@>F1I9;5A;FEE('!R:67H:6YK;W8N`%1O=&\@<')A=F1E<&]D
M;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!R87(N`%1O=&\@<')A=F1E<&]D
M;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!Z:7`N`%1O=&\@<')A=F1E<&]D
M;V)N92!N:64@:F4@<&QA=&[I(.CM<VQO(&MA<G1Y+@!496YT;R!O=FSA9&'H
M('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@8V5Z(&)RX6YU($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<&]M;V-O=2!(5%10($%020!4
M96YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@8V5Z(&)R
MX6YU(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI('!O;6]C;W4@2%144"!!4$D`
M5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V(&-E>B!B
M<N%N=2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!P;VUO8V]U
M($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L8;L@<W!R
MX79Y(&-E>B!33510(&-E>B!B<N%N=2!6;V1A9F]N92!)=&%L>2`H:6)A(&YA
M(.CM<VQA(%9O9&%F;VYE*2X@5GF^861U:F4@92UM86EL;W;](/KH970@5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&]T;R!P;VQE(&IE
M('!O=FEN;NDN`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US;&$N
M`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US;&$@82!D=F]J8F]D
M:W4N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@;W-M:>AK;W;I(&AO
M9&YO='DN`%1O=&\@<&]L92!M=7/M(&)YNR!Z;WIN86T@Z.US96P@;V1D96QE
M;OUC:"#H:6%R:V]U(&%L96)O(&UE9'IE<F]U`%1O=&\@<&]L92!M=7/M(&)Y
MNR!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M=7/M(&]B<V%H;W9ANR!K\V0@
M9F%R8GD@=B"Y97-T;N%S=&MO=F]M(&9O<FWA=&4@4D="+"!N87!R[6ML860@
M)R,Q,C,T868G+@!496YT;R!F;W)MX70@<_IB;W)U(&YI92!J92!P;V1P;W)O
M=F%N_2X`5&5N=&\@9F]R;75LX7(@=;X@8F]L('-P<F%C;W9A;OTN`%1O=&\@
M:F4@)7,N`%1O=&\@:F4@;V)J96MT($MO;&%B($=R;W5P=V%R92X@4')E('IO
M8G)A>F5N:64@=&]H=&\@;V)J96MT=2!P;W1R96)U:F5T92!E+6UA:6QO=NEH
M;R!K;&EE;G1A+"!K=&]R_2!R;WIU;6EE(&9O<FWA='4@2V]L86(@1W)O=7!W
M87)E+B!0<F4@>F]Z;F%M('1A:_UC:'1O(&ML:65N=&]V(&YA=KET[79T92!P
M<F]S[6T@)7,`5&]T;R!O>F[A;6EL('-E<G9E<CH@)7,`5.%T;R!S<'+A=F$@
M8F]L82!N87#M<V%NX2!V(&EN96H@86MO(%9A;6D@<&]UONUV86YE:B!Z;F%K
M;W9E:B!S861E("@E<RDN`%1O=&\@Z.US;&\@;75S[2!B>;L@;F%J;65N96H@
M,2X`5&5N=&\@<V5R=F5R(&YE9&]KX;YE(&1E:V]M<')I;6]V8;L@<_IB;W)Y
M('II<"!A(&=Z:7`N`%-Y<W3I;2!J92!M;VUE;G3A;&YE(&1E86MT:79O=F%N
M_2X`5.%T;R!H;V1N;W1A(&UU<^T@8GF[(.CM<V5L;N$N`%1O=&\@;VMN;R!M
M=7/M(&)YNR!Z879O;&%NZ2!Z(&]K;F$@3F%S=&%V96[M`$AR;65N:64`J71V
M<G1O:P!4:6-K971S`,AA<P#(87-O=OT@<F]Z<U]A:`!4:6UE(%1R86-K:6YG
M`$9O<FWA="#H87-U`%;]8F5R(.AA<W4`R&%S;W;](')O>G-A:`!4:6UO<BU,
M97-T90!4:71U7VP`5&ET=6QO:P!.861P:7,@*&)U8FQI;F]V_2!V_7!I<RDZ
M`%!R90!0<F4@=OUB97(@=FEA8V5R_6-H('!O;&^^:65K(&1ROG1E('!OZ&%S
M(&ML:6MA;FEA(&MLX79E<W4@0V]N=')O;"`H4$,I(&%L96)O($-O;6UA;F0@
M*$UA8RDN`$1N97,`4')E<&[ZNR!Z;V)R87IE;FEE('ID<F]J;W;I:&\@:_-D
M=2!(5$U,`%1O9V\`5&]K96QA=0!:86IT<F$`5&]N9V$`5G)C:`!6<F-H;OT@
M<N%M96,@*%]T;W`I`%!R96ML861Y`%1R:6YI9&%D(&$@5&]B86=O`%!R879D
M82!A;&5B;R!N97!R879D80!5=`!5=&]R;VL`5'5N:7-K;P!4=7)E8VMO`%1U
M<FMM96YI<W1A;@!4=7)K<R!A($-A:6-O<P!4=79A;'4`5'EP`%IA9&%J=&4@
M5F&Y=2!V;[5B=3H@`%4N5BX@:6YD97@Z(`!54DP`55),(%;AN6AO('-K<FEP
M='4@<')E('-P<N%V=2!O(&1O<G7H96[M`%523#H`56=A;F1A`%5K<F%J:6YA
M`$YE<&]D87)I;&\@<V$@=7-K=71OZ&YINR!P<NUS='5P(&L@5D93(&%D<F5S
MX7)U+@!.97!O9&%R:6QO('-A('!R:61ANR#O86RY:64@:6YF;W)MX6-I92!O
M('!O=;[M=F%T9;5O=FD@<')I(')E9VES='+A8VEI+@!.97!O9&%R:6QO('-A
M('IM96YINR!P<N%V;R!P<F4@5D93('/Z8F]R("(E<R(N`$YE<&]D87)I;&\@
M<V$@>FUE;FF[('!RX79O('!R92!61E,@<_IB;W(@)7,O)7,N`$YE<&]D87)I
M;&\@<V$@>FUE;FF[(&YA("5S+@!.97!O9&%R:6QO('-A('-K;VYT<F]L;W9A
MNR!V9;5K;W.[('/Z8F]R=2`B)7,B+@!.97!O9&%R:6QO('-A('-K;VYT<F]L
M;W9ANR!V9;5K;W.[('/Z8F]R=2`B)7,O)7,B+@!.97!O9&%R:6QO('-A('-P
M;VIINR!S(%-13"!S97)V97)O;2X`3F5P;V1A<FEL;R!S82!S<&]J:;L@<&]M
M;V-O=2!34TPN`$YE<&]D87)I;&\@<V$@<VMO<.UR;W9ANR!61E,@<_IB;W(N
M`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93(&%D<F5SX7(@(B5S(BX`3F5P
M;V1A<FEL;R!S82!V>71V;W)INR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S
M82!V>71V;W)INR!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@
M5D93('!R:67H:6YO:R`B)7,B+@!.97!O9&%R:6QO('-A('9Y='9O<FF[('!R
MX7ID;GD@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A(&1E:V]M<')I;6]V8;L@
M^F1A:F4N`$YE<&]D87)I;&\@<V$@=GEM87IANR`B)7,B+"!A9')E<^%R(&YI
M92!J92!P<N%Z9&YY+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@(B5S(CH@)7,`
M3F5P;V1A<FEL;R!S82!V>6UA>F&[("(E<R(Z("5S+@!.97!O9&%R:6QO('-A
M('9Y;6%Z8;L@)7,L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GD`3F5P;V1A<FEL
M;R!S82!R96MU<GKM=FYE('9Y;6%Z8;L@5D93(&%D<F5SX7(N`$YE<&]D87)I
M;&\@<V$@=GEM87IANR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!V>6UA
M>F&[(%9&4R!A9')E<^%R.B`E<RX`3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&
M4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('/Z8F]R
M+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('!R:67H:6YO:R`B)7,B+@!.
M97!O9&%R:6QO('-A(')E:W5R>NUV;F4@=GEM87IANR!61E,Z("5S+@!.97!O
M9&%R:6QO('-A('5RZ&F[(&%K='7A;&YY(&%D<F5SX7(N`$YE<&]D87)I;&\@
M<V$@>FES=&F[('!O9')O8FYO<W1I(&\@8V5R=&EF:6OA=&4N`$YE;6^^;ND@
M;F%H<F&[(&1E9FEN[6-I=2`E<RX`3F5P;V1A<FEL;R!S82!P<F5S=6[ZNR!6
M1E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(@(B5S
M(BX`3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B!N82!ZX7!I<RX`
M3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S
M82!O='9O<FF[(&MO;7!R:6UO=F%N_2!A<F-H[78N`$YE<&]D87)I;&\@<V$@
M<')EZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA(&9I;&5S:7IE*"D@>FQY:&%L
M82DN`$YE<&]D87)I;&\@<V$@<')EZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA
M(&=E=$9I;&53:7IE*"D@>FQY:&%L82DN`$YE<&]D87)I;&\@<V$@<')EZ.UT
M8;L@<_IB;W(Z`$YE<&]D87)I;&\@<V$@Z.UT8;L@861R97/A<B!V9G-R;V]T
M+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@(B5S(CH@)7,`3F5P;V1A<FEL
M;R!S82!P<F5M96YO=F&[("5S(&YA("5S.B!C:66U;W;]('!R:67H:6YO:R!U
MOB!E>&ES='5J90!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93(&%D<F5S
MX7(N`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@861R97/A<CH@)7,N
M`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(@(B5S(BX`3F5P
M;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<B`E<R\E<RX`3F5P;V1A
M<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S82!Z
M[7-K8;L@:6YF;W)MX6-I=2!O('IA;F5P<N%Z9&YE;F]S=&D@)7,`3F5P;V1A
M<FEL;R!S82!S<'5S=&F[("=M:VES;V9S)RX`3F5P;V1A<FEL;R!S82!P<F5L
M;[YINR!T96YT;R!D;VMU;65N="!7;W)D`$YE<&]D87)I;&\@<V$@>F%P[7-A
MNR!61E,@<_IB;W(@(B5S(BX`3F5P;V1A<FEL;R!S82!Z87#M<V&[(%9&4R!S
M^F)O<B`H9G5N:V-I82!C;W!Y*"D@>FQY:&%L82DN`$YE<&]D87)I;&\@<V$@
M>F%P[7-ANR#Z9&%J92!61E,@<_IB;W)U+@!.97!O9&%R:6QO('-A('IA<.US
M8;L@5D93('/Z8F]R+"!K=O-T82!J92!P<F5K<F_H96[A+@!0;V3H:6%R:VYU
M=.D`6G)UN6F[('IM96YY`%IR=;GM('!O<VQE9&[Z(&%K8VEU`$YE;^AA:^%V
M86[A(&]D<&]V9>\@;V0@<V5R=F5R82!P;^AA<R!S<&]J96YI83H@`$YE;^AA
M:^%V86[A(&]D<&]V9>\@;V0@<V5R=F5R82!N83H@`$YE;F%S=&%V96[A`%-P
M;VIE;ND@87)A8G-KZ2!E;6ERX71Y`%9EM6OA($)R:73A;FEA`%-P;VIE;ND@
MN73A='D@06UE<FEC:^D`2F5D;F]T:WD`3F5Z;N%M90!.97INX6UE(&%P:6US
M9VED("A!4$D@365S<V%G92!)1"DN`$YE>F[A;64@8VQI;7-G:60@*$-L:65N
M="!-97-S86=E($E$*2X`0F]L82!Z861A;N$@;F5P;&%T;N$@;&]K86QI=&$N
M`$YE>F[A;64@<&]UONUV871EM7-KZ2!M96YO(&%L96)O(&AE<VQO+@!/9'-T
M<N%N:;L@;&EN:W4@>B!A:W1UX6QN96AO(&5L96UE;G1U`$YE<&]M96YO=F%N
MX0!.97!R:79I;&5G;W9A;ND@<VMR:7!T>2!N96UA:OH@>B!B97IP9>AN;W-T
M;OUC:"!D]'9O9&]V('!R[7-T=7`@:R!V;[5BX6T@5GES=')I:&[ZNR]+;W#M
M<F]V8;LO5FQOOFF[+B!+;&EK;FET92!N82!/2R!A('IO8G)A>NT@<V$@=&5C
M:&YI8VOA(&EN9F]R;>%C:6$@;F$@<W1RX6YK92!M;WII;&QA+F]R9RP@:W1O
M<N$@5N%S(&EN9F]R;75J92P@86MO('5M;[YN:;L@<VMR:7!T=2!P<NUS='5P
M(&L@<V-H<N%N:V4N`$]D<W1RX6YINR!F87)B=0!.97!O9'!O<F]V86[]('1Y
M<"!O8G-A:'4@*$-O;G1E;G0M5'EP92DZ("5S`$YE<&]D<&]R;W9A;ND@<F]Z
MN>UR96YI90!!:W1U86QI>N%C:6$`06MT=6%L:7IO=F&[("5S`$%K='5A;&EZ
M;W9ANR!P;W6^[79A=&6U80!!:W1U86QI>N%C:6$@(B5S(B!B;VQA(/IS<&6Y
M;N$N`$%K='5A;&EZ;W9A;NDZ("5S+@!3:W)I<'0@;F$@=7!G<F%D92!B;VP@
M=GEM87IA;OTN`$YA:')ANP!6N65T:WD@<_IB;W)Y(',@:V]N9FEG=7+A8VEO
M=2!B;VQI(&YA:')A;ND@;F$@<V5R=F5R+@!69;5KZ2!L871I;G-KZ2!P[7-M
M96[A`%9EM6OI('+M;7-K92#H[7-L:6-E`%5R=6=U87D`4&]UOFF[(&%K='7A
M;&YE.B`E<P!0;W6^:;L@4U-,`%!O=;YI=&4@=B!P<NUP861E+""^92!J92!M
M96YO+VAE<VQO(&]D;&FY;ND@<')E($E-4U`@<V5R=F5R+@!0;W6^[79A=&6U
M`%!O=;[M=F%T9;4@)7,@;FEE(&IE(&%U=&]R:7IO=F%N_2!N82`E<RX`4W!R
MX79A('!O=;[M=F%T9;5O=@!0;W6^[79A=&6U<VOI(')O>FAR86YI90!0;W6^
M[79A=&6U<VOI(&YA<W1A=F5N:6$`4F5G:7-T<N%C:6$@<&]UONUV871EM6$`
M4F5G:7-T<N%C:6$@<&]UONUV871EM6]V(&)O;&$@<')E('1E;G1O('-Y<W3I
M;2!Z86OA>F%NX2X`4&]UONUV871EM7-K_2#ZZ&5T(&YE8F]L(&[A:F1E;OT`
M4&]UONUV871EM7-KZ2!M96YO`%!O=;[M=F%T9;5S:^D@;65N;R`B)7,B('6^
M(&5X:7-T=6IE+@!0;W6^[79A=&6U<VOI(&UE;F\Z`%!O=;[M=F%T9;5S:^D@
M;65N;SH@`%!O=;[M=F%T96QI82!S>7-TZ6UU.@!5>F)E:VES=&%N`%9&4R!A
M9')E<^%R(&YE97AI<W1U:F4N`$1O=F]L96YK80!0;&%T;ND@=6UI97-T;F5N
M:6$@>F%HX/)A:OHZ(`!0;&%T;F]SNP!0;&%T;F]SNR!V(&UI;OIT86-H(&]D
M=&5R87HN`$AO9&YO=&$@<')E:W)OZ&EL82!M87AI;>%L;G4@9.6^:W4@)7,N
M`$AO9&YO='D`2&]D;F]T>2P@>B!K=&]R_6-H('-I(&WTOF5T92!V>6)R8;L`
M5F%N=6%T=0!0<F5M96YNX0!696YE>G5E;&$`3W9E<F5N:64@>FQY:&%L;R`M
M('3A=&\@<W!RX79A(&UO:&QA(&)YNR!S9F%LN6]V86[A+@!697)Z:6$`36%N
M8;YM96YT('9E<GII[0!697)T:6OA;&YE('IA<F]V;F%N:64`5F5R=&EKX6QN
M92!V>7!L;F5N:64`5F5R=&EKX6QN93H`5F6U;6D@=GES;VOA`%9I971N86T`
M6F]B<F%Z:;L@)7,`6F]B<F%Z:;L@9&7R`%IO8G)A>FF[(&5X=&5R;OH@=W=W
M('-T<N%N:W4`6F]B<F%Z:;L@86MO("5S`$)R:71S:^D@4&%N96YS:^D@;W-T
M<F]V>0!!;65R:6-KZ2!086YE;G-KZ2!O<W1R;W9Y`%9I9&ET9;5N;W.[`%9I
M9&ET9;5N;W.[.B``5F]D869O;F4@271A;'D@8V5Z(%--5%``5D%23U9!3DE%
M`%503UI/4DY%3DE%(2$A($]$4U12P=)412!32U))4%0@6B`E<R!25<A.12X`
M5TE.(&-E>B!(5%10`%=A;&QI<R!A($9U='5N80!687)O=F%N:64`4W0`4')E
M9'!O=F7O('!OZ&%S:6$`VF1A:F4@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H
M97(N8V]M`%=E8@!75U<@<W1RX6YK80!3=')E9&$`5/V^9&7R`%3]OF1E\B`E
M9`!4_;YD9?(H=/V^9&YE*0!4_;YD96YN90!4_;YD96YN93H@;W!A:W5J92!S
M80!6:71A:G1E`%;M=&$@5N%S("5S`%9I=&%J=&4L("5S`%KA<&%D;N$@4V%H
M87)A`$MT;W+Z(&%P;&EKX6-I=2!MX2`E<R!Z;V)R87IINR!P;R!P<FEH;.%S
M96[M/P!!:_T@:F4@>FYA:R!P<F4@;V1D9;5O=F'H/P!!:_T@:F4@>FYA:R!P
M<F4@^G9O9'IO=FMU/P!+=&]R_6T@Z&%S;VT@;>$@:V]NZ&F[(&1E;F[](&$@
M=/V^9&5N;OT@;N%HM6%D+"!A:R!N:64@<_H@;F5S:V]RN6EE('5D86QO<W1I
M/P!+=&]R_6T@Z&%S;VT@;>$@>F'H[6YANR!D96YN_2!A('3]OF1E;F[](&[A
M:+5A9"P@86L@;FEE('/Z('-K;W*Y:64@=61A;&]S=&D_`$UA<&$@075S='+A
M;&EE('!R92!S;'6^8G4@5VAE<F5I<P!+=&]RZ2!FX7IY`$MT;W+I('KA<W5V
M;ND@;6]D=6QY('!O=F]L:;L@<')E(')O>KGM<F5N_2!T97AT;W;](&5D:71O
M<BX`J>UR:V$`J>UR:V$@=B!J961N;W1KX6-H($-34P"I[7)K82!M96YU("5S
M(':U879O("AP<F5J87;M('-A('!R:2#O86RY;VT@<')I:&SA<V5N[2DZ`*GM
M<FMA('1A8G6U:WD`2F5D;F]T:V$@N>UR:WD`J>UR:V$Z`%=I:VD`5FEE=&]R
M`%+A;F\@=FEE=&]R`%+]8VAL;W.[('9E=')A('8@=7IL;V-H`%9I971O<CH`
M5FEE=&]R.B``3?ID<F]SNP!7:7-H;&ES=`!0<N%C80!!9')E<V$@9&\@<'+A
M8V4`5&5L96;S;B!D;R!P<N%C90!0<F%C;W9N_2!T_;YD9?(`3F5S<'+A=FYY
M('!OZ&5T('!O;.T@;F$@<FEA9&MU("5D+B!/Z&%KX79A('-A("5D+"!N8;EL
M;R!S82`E9"X`3F5S<'+A=FYY('!OZ&5T('!O;.TN($_H86OA=F$@<V$@)60L
M(&YAN6QO('-A("5D+@!:;/T@;V9F<V5T("5D('!R:2#H[71A;NT@5D93('/Z
M8F]R=2X`6"U2968`6N%K;&%D;ND@;V)M961Z96YI82!8-3`Y=C,`4&]UOFET
M:64@<F]ZN>UR96[I:&\@:[7ZZ&$@6#4P.78S`$%L=&5R;F%T[79N92!M96YO
M('-U8FIE:W1U(%@U,#EV,P!)9&5N=&EF:6OA=&]R(&NU^NAA('-U8FIE:W1U
M(%@U,#EV,P!8-3`Y=C,@<F]ZN>UR96YI80!960!965E9`%EA:&]O(2!M87``
M4F]K`%)OZ&YE`%)OZ&YE.B!O<&%K=6IE('-A`$IE;65N`$%N;P!3^FAL87/M
M;2X`4W1E('8@5$585$]63TT@4D6N24U%+B!0;W6^:71E('1L8>AI9&QO(%L\
M/ET@;F$@<')E<&YU=&EE(&YA<W#DNR!D;R!765-)5UE'+@!.96WTOF5T92!V
M>71V;W)INR!V:6%C(&%K;R`E9"!B;&]K;W8N`$YE;>%T92!O<'+A=FYE;FEE
M('9Y='9O<FF[('9I86,@86MO("5D('5D86QO<W3M+@!.:64@<W1E(/KH87-T
M;NUK;VT@N7!E8VEF:6MO=F%N96H@=61A;&]S=&DN`$YI92!S=&4@875T96YT
M:69I:V]V86[]+@!496YT;R!F;W)M=6SA<B!M]+YE=&4@<&]UOFF[(&EB82!Z
M(&]B<F%Z;W9K>2!5<')A=FF[(/KH87-T;NUK;W8N`%9O(%9AN6]M('!L;F]M
M(&UE;F4@;F5M]+YE=&4@<&]UOFF[('IN86L@)UPG+@!.97IA9&%L:2!S=&4@
M<&QA=&[Z(&4M;6%I;&]V^B!A9')E<W4N`$YE=7+H:6QI('-T92!V>KMA:"!M
M961Z:2"^:6%D;GEM:2!P;VQI86UI('H@:6UP;W)T;W9A;NEH;R!S^F)O<G4@
M82!Z;V1P;W9E9&%J^F-I;6D@<&^U86UI('8@)7,N`%8@3W-O8F[]8V@@:6YF
M;W)MX6-IX6-H(&YE;>%T92!N87-T879E;OH@92UM86EL;W;Z(&%D<F5S=2X@
M375S[71E(&IU(&YA<W1A=FF[("5S='4E<R!S:_1R+"!A:V\@<V$@8G5D^B!P
M;W-I96QANR!U<&]Z;W)N96YI82!N82!U9&%L;W-T:2X`3F5MX71E('!RX79O
M(&YA('!R:61A;FEE('5D86QO<W3M(&1O("5S+@!.96WA=&4@<'+A=F\@;F$@
M<')I9&%N:64@=61A;&]S=.T@:R!V>6)R86[I;74@:V%L96YDX7)U+@!.96WA
M=&4@<'+A=F\@;F$@=GEM87IA;FEE('1E:G1O('5D86QO<W1I+@!.96WA=&4@
M<'+A=F\@;F$@^G!R879U('1E:G1O('5D86QO<W1I+@!";VQI('-T92!O9&AL
MX7-E;OTN`%IA9&%L:2!S=&4@;F5P;&%T;OT@:V%L96YDX7(N`-IS<&6Y;F4@
M<W1E(&%K8V5P=&]V86QI(/KH87.[(&YA('1E:G1O('5D86QO<W1I+@#:<W!E
MN6YE('-T92!O9&UI971L:2#ZZ&%SNR!N82!T96IT;R!U9&%L;W-T:2X`4')E
M9&)EOFYE('-T92!A:V-E<'1O=F%L:2#ZZ&%SNR!N82!T96IT;R!U9&%L;W-T
M:2X`375S[71E('IA9&&[('!L871NZ2#H[7-L;R!M;V)I;&[I:&\@=&5L96;S
M;G4L(&MT;W+I(&]B<V%H=6IE(&EB82#H[7-L82!S('9O;&ET9;5N_6T@<')E
M9FEX;VT@)RLG('!R92!M961Z:6[A<F]D;OT@9F]R;>%T+@!-=7/M=&4@>F%D
M8;L@<&QA=&[Z(&AO9&YO='4N`$%B>2!S=&4@;6]H;&D@<&]UONUV8;L@4F5G
M:7-T<N%C:64L(&UU<^UT92!N86IS:_1R(&YA:V]N9FEG=7)O=F&[($1A=&%4
M<F5E(&)A8VME;F0N`$UU<^UT92!N86MO;F9I9W5R;W9ANR!61E,@8F%C:V5N
M9"X`375S[71E('!O<.US8;L@<')O8FSI;2!P<F5D=/UM+"!A:V\@;V1ON6QE
M=&4@<W!RX79U(&\@<')O8FSI;64N`$UU<^UT92!Z861ANR!54DP@861R97-U
M+"!N82!K=&]R^B!TX71O(&QI;FMA('5K87IU:F4`375S[71E('9Y8G)ANR!K
M86QE;F3A<BP@:W1O<OT@;>$@8GF[('9Y;6%Z86[]+@!-=7/M=&4@=GEB<F&[
M(&%S<&_R(&IE9&YU(&%D<F5S=2X`375S[71E('9Y8G)ANR!S97)V97(L(&MT
M;W+](&WA(&)YNR!V>6UA>F%N_2X`375S[71E('5RZ&F[(&UE;F\@<&]UONUV
M871EM6$L(&MT;W+I:&\@8VAC971E('9Y;6%Z8;LN`$UU<^UT92!U<NAINR!M
M96YO('!O=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!V>6UA>F&[+@!-=7/M
M=&4@=7+H:;L@;65N;R!P;W6^[79A=&6U82P@:W1O<NEH;R!C:&-E=&4@<')I
M9&&[+@!-=7/M=&4@=7+H:;L@<&]UONUV871EM6$L(&MT;W+]('-A(&WA(&%K
M='5A;&EZ;W9ANRX`375S[71E('5RZ&F[(&%K8VEU+"!K=&]RX2!S82!MX2!V
M>6MO;F&[+@!-=7/M=&4@>F%D8;L@;65N;R!N;W9E:B!K871E9_-R:64N`$UU
M<^UT92!Z861ANR!T86QI86YS:V4@=&5L96;S;FYE(.CM<VQO`%9YOF%D;W9A
M;&D@<W1E('5P;WIO<FYE;FEE(&YA('5D86QO<W1I('!R:61A;ND@9&\@5F&Y
M:6-H(&MA;&5N9.%R;W8N`%9YOF%D;W9A;&D@<W1E('5P;WIO<FYE;FEE(&YA
M('5D86QO<W1I('9Y;6%Z86[I('H@5F&Y:6-H(&MA;&5N9.%R;W8N`%9YOF%D
M;W9A;&D@<W1E('5P;WIO<FYE;FEE(&YA('5P<F%V96YI92!U9&%L;W-T:2!V
M;R!68;EI8V@@:V%L96YDX7)O8V@N`%!OOF%D;W9A;&D@<W1E('5P;WIO<FYE
M;FEE(&YA('5D86QO<[L@)7,L(&MT;W+A(&IE("5S(&\@)7,N`%!L871N;W.[
M(%9AN65J(')E;.%C:64@<')E(&%P;&EKX6-I=2`E<R!V>7!RN6%L82X@4')O
M<^UM('!R:6ALX7-T92!S82!Z;F]V=2X`5F&Y82!%;6%I;&]VX2!A9')E<V$`
M5F&Y82!%;6%I;&]VX2!A9')E<V$@<&]UOFETX2!P<F4@;V1C:.%D>F%J^F-U
M('!ON71U.@!68;EE(&EN9F]R;>%C:64`5F&Y82!I;G1E<FYE=&]VX2!A9')E
M<V$@<V$@>FUE;FEL82!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0
M<F4@5F&Y=2!B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN
M`%9AN64@;65N;P!6X;D@875T96YT:69I:V'H;OT@;6]D=6P@;F5P;V1P;W)U
M:F4@<')I9.%V86YI92!P;W6^[79A=&6U;W8N($%K('-I(+YE;.%T92!P;W6^
M:;L@2&]R9&4@;F$@<W!RX79U('!O=;[M=F%T9;5S:_UC:"#ZZ'1O=BP@;75S
M[71E('!O=;YINR!I;OT@875T96YT:69I:V'H;OT@8F%C:V5N9"X`5N&Y(&%U
M=&5N=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('IO8G)A>F]V86YI92!Z
M;WIN86UU('!O=;[M=F%T9;5O=BP@86QE8F\@8F]L82!TX71O(&UOOFYO<[L@
M>B!N96IA:^EH;R!D]'9O9'4@>F%KX7IA;N$N`%IDX2!S82P@OF4@5N&Y('!R
M96AL:6%D8>@@<V$@>FUE;FEL(&]D('IAZ&EA=&MU(%9AN65J(')E;.%C:64@
M)7,N(%!R92!68;EU(&)E>G!EZ&YO<[L@<V$@;75S[71E('IN;W9U('!R:6AL
MX7-INRX`5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU
M+@!6X;D@<')E:&QI861AZ"!N97!O9'!O<G5J92!T^G1O(&9U;FMC:74@=&QA
MZ&4N(%-T;&'H=&4@0V]N=')O;"]#;VUM86YD("L@4"!P<F4@=&QAZ"X`5F&Y
M82!A:W1UX6QN82#H87-O=N$@>O-N83H`5N&Y('!R961N87-T879E;OT@:V%L
M96YDX7(`5F&Y82!P<F5D;F%S=&%V96[A(&ED96YT:71A(&)O;&$@>FUE;F5N
MX2X`4')E9&YA<W1A=F5NX2!I9&5N=&ET83H`5F&Y92!M96YO.@!0;&%T;F]S
MNR!6X;EH;R#ZZ'1U('9Y<'*Y86QA+@!68;EE(&YO=ND@:&5S;&\@<')E("5S
M(&IE.B`E<P!68;EE(&YA<W1A=F5N:6$@8F]L:2!A:W1U86QI>F]V86[I('!R
M92!T;W1O('-E9&5N:64N`%9AN64@;F%S=&%V96YI82!B;VQI(&%K='5A;&EZ
M;W9A;NDN`%9AN64@:&5S;&\@8F]L;R!O8FYO=F5NZ0!68;EE(&AE<VQO(&)O
M;&\@;V)N;W9E;NDL('-K;VYT<F]L=6IT92!S:2!P;[ET=2!A('!R:6ALX7-T
M92!S82!S(%9AN>UM(&YO=OUM(&AE<VQO;2X`4&QA=&YO<[L@5N&Y:&\@:&5S
M;&$@=GEP<KEA;&$N`%9AN64@=GID:6%L96[I('-E<G9E<GDZ`$IU:&]S;.%V
M:6$`6F%I<@!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6U-K<GF[(&-I=&]V86[]
M('1E>'1=`%M3<'+A=F$@;R!P<F]B;.EM95T`6UIO8G)A>FF[(&-I=&]V86[]
M('1E>'0@+0!;6F]B<F%Z:;L@8VET;W9A;OT@=&5X="`M("5S(')I861K;W9=
M`%M.97!O;65N;W9A;N$@=61A;&]SNUT`6W)I861O:R`E<R!Z("5S70!?061M
M:6YI<W1RX6-I80!?06QA<FT`7UKA:VQA9&[I(&BU861A;FEE`%]#3$D`7T1A
M=&%4<F5E`%]6>6UA>F&[(')I861O:P!?57!R879INP!?4')E:G.[(&YA`%]3
M:W5P:6YY`%]0;VUO8V[M:P!6;&%S=&YO<W1I(%]O8G+A>FMU+BXN`%]);7!O
M<G0O17AP;W)T`%]0<FEH;.%S:;L@<V$`7T]D:&SA<VF[('-A`%]5<')A=FF[
M(&QI;FMU+BXN`%]-;VIE(&MA;&5N9.%R90!?3F]VX2!U9&%L;W.[`%].87-T
M879E;FEA`%]0<N%V80!?5&QAZ&F[`$]D<W1?<N%N:;L@;&EN:W4N+BX`7TBU
M861ANP!.85]S=&%V96YI90!6;&%S=&YO<W1I(%]T86)UM6MY+BXN`%]$;F5S
M`%!O7W6^[79A=&5L:6$`861R97/A<@!A9')E<^%T(&YE>F[A;7D`<')E9"!Z
M8>AI871K;VT@=61A;&]S=&D`:V%L96YDX7(`8F5Z=F5T<FEE`&YE<&]D87)I
M;&\@<V$@=GET=F]R:;L@=OUS='5P;OT@<_IB;W(`;F5P;V1A<FEL;R!S82!O
M='9O<FF[('9S='5P`&ML:6MN:71E('-E;0!C:'EB82!P<FD@<&]UOFET[2!P
M<NUK87IO=NEH;R!R:6%D:W4`8VAY8F$@:V]N9FEG=7+A8VEE`&-H_6)A(&3T
M;&6^:73]('-Y<W3I;6]V_2!S^F)O<@!C:'EB82!F;W)MX71U(/ID86IO=@!D
M9?(`9&7R*&1N:2D`9&YI`'!O;&^^:V$@;F5NX6ID96[A`&5V96YT<RYC<W8`
M979E;G1S+FEC<P!K;&5SX0!S^F)O<@!O9`!Z;R!S;65R=2`E<R`H)7,I('+]
M8VAL;W.[;W4@)7,@)7,`;N%R87IO=OT`=CH`:&@`;F5Z;N%M92!M96YO(&AO
M<W1I=&6U80!O:V%MOFET90!V('-P<N%V90!C:'EB82!V<W1U<'4O=OUS='5P
M=0!I;G1E<F[A(&-H>6)A('-O9G1VZ7)U`')I861K;W9=`'!OZ&%S('9Y=';A
M<F%N:6$@25-/(&YA<W1A;&$@8VAY8F$@;6MI<V]F<R`E9`!M;0!M97-I86,H
M92D`;65N;P!N96EM<&QE;65N=&]V86[I`'IA=&EAM2!N96EM<&QE;65N=&]V
M86[I`'!O>F[A;6MO=OT@8FQO:P!59&%L;W.[("5S(&\@)7,`=&5N(&ES=/T@
M9.%T=6T`=&5N(&ES=/T@9&7R('8@=/V^9&YI`'!E<F-E;G0`<'+M<W1U<"!Z
M86UI971N=73]`&)O9&]V`'9Z9&EA;&5NX2!C:'EB82!V('!R;W1O:V]L90!S
M=/IP80!S;'6^8F$@;FEE(&IE(&1O<W1U<&[A`'IO8G)A>FF[(')O>F1I96QY
M`'-M<S)E;6%I;"!C97H@2%144`!S<P!U<W3A;&5N_0!S>7-TZ6UO=N$@8VAY
M8F$`>F]Z;F%M(/IL;V@`9&_H87-NX2!C:'EB80!P<F4@<&]T=G)D96YI92!Z
M861A:G1E(&AE<VQO(&1V86MRX70`=6YI9FEK;W9A;ND`;F5P;VUE;F]V86[A
M`&1E9FEN=6IE('!O=;[M=F%T9;4`=D-A;&5N9&%R+VE#86QE;F1A<@!V0V%R
M9`!V179E;G0@;F5B;VP@;N%J9&5N_2X`N3H`=V5A=&AE<BYC;VT`=/V^9&7R
M`'3]OF1E\BAT_;YD;F4I(&YA.@!T_;YD;F4`<F]K*'DI````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+VQO8V%L92]S=E]312\`````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,@`P,C`W,3(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+W-V7U-%+TQ#7TU%4U-!1T53+P``
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4R`#`R,C0W
M-P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L;V-A;&4O<W9?
M4T4O3$-?34534T%'15,O:W)O;F]L:71H+FUO````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-S4S,C0`
M,3`T,3<S-C(W-3(`,#(U,#8Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````20D``!P```!D2@``80P``*R4````
M````,,8``$@````QQ@``#@```'K&```/````B<8```P```"9Q@``#0```*;&
M```(````M,8```L```"]Q@``#````,G&```$````UL8``!@```#;Q@``&P``
M`/3&```M````$,<``!T````^QP``)````%S'```I````@<<``!D```"KQP``
M)@```,7'```,````[,<``!(```#YQP``)`````S(```)````,<@```\````[
MR```"P```$O(```?````5\@```X```!WR```!0```(;(```H````C,@```@`
M``"UR```"@```+[(```5````R<@``!(```#?R```"P```/+(```,````_L@`
M`!T````+R0``%````"G)```F````/LD``"<```!ER0``)@```(W)``"%````
MM,D```X````ZR@``"@```$G*```-````5,H``"<```!BR@``(````(K*```.
M````J\H``!<```"ZR@``(@```-+*```U````]<H``!$````KRP``#0```#W+
M```,````2\L```T```!8RP``!@```&;+``"4````;<L``$\````"S```'0``
M`%+,```=````<,P```H```".S```#P```)G,```8````J<P```P```#"S```
M"@```,_,```'````VLP```8```#BS```#@```.G,```*````^,P```H````#
MS0``#@````[-```(````'<T```H````FS0``"0```#'-```E````.\T``"@`
M``!AS0``)````(K-```F````K\T``"X```#6S0``&@````7.```R````(,X`
M`#@```!3S@``5````(S.``!1````X<X``%H````SSP``5P```([/```T````
MYL\```(````;T```"0```![0```-````*-````<````VT```"@```#[0```/
M````2=````4```!9T```!@```%_0```1````9M````@```!XT```"0```('0
M```)````B]````X```"5T```"````*30```E````K=```"````#3T```$P``
M`/30```0````"-$```\````9T0``"@```"G1```'````--$``!`````\T0``
M`P```$W1```&````4=$```\```!8T0``%````&C1```)````?=$```D```"'
MT0``#0```)'1```2````G]$``!D```"RT0``'@```,S1```9````Z]$```\`
M```%T@``#P```!72```-````)=(```H````ST@``#P```#[2```(````3M(`
M`"0```!7T@``%P```'S2```4````E-(``!````"IT@``%@```+K2```(````
MT=(``$X```#:T@``+0```"G3```9````5],```<```!QTP``#````'G3```L
M````AM,```X```"STP```P```,+3```/````QM,```L```#6TP``!0```.+3
M```4````Z-,``!4```#]TP``%P```!/4```5````*]0``!(```!!U```$P``
M`%34```5````:-0``!,```!^U```"@```)+4```4````G=0```H```"RU```
M!P```+W4```'````Q=0```4```#-U```!0```-/4```*````V=0```,```#D
MU```#0```.C4```7````]M0```H````.U0``"@```!G5```(````)-4```\`
M```MU0``"P```#W5```'````2=4```T```!1U0``"@```%_5```.````:M4`
M`!@```!YU0``(P```)+5```.````MM4``!0```#%U0``%P```-K5```7````
M\M4``!<````*U@``$P```"+6```/````-M8```X```!&U@``*0```%76```?
M````?]8``!T```"?U@``!P```+W6```&````Q=8```@```#,U@``#P```-76
M```&````Y=8```H```#LU@``$P```/?6```#````"]<```L````/UP``$```
M`!O7```5````+-<``!4```!"UP``!P```%C7```0````8-<```4```!QUP``
M%0```'?7```1````C=<```P```"?UP``.P```*S7```X````Z-<```D````A
MV```!P```"O8```4````,]@```,```!(V```!0```$S8```0````4M@```D`
M``!CV```$P```&W8```Y````@=@``!(```"[V````@```,[8```Y````T=@`
M`+0````+V0``)P```,#9```L````Z-D``"H````5V@``)0```$#:```*````
M9MH```D```!QV@``"@```'O:```&````AMH```D```"-V@``!P```)?:```O
M````G]H``#<```#/V@``+@````?;``!5````-ML``"T```",VP``+0```+K;
M```]````Z-L``#\````FW```+0```&;<``!`````E-P``",```#5W```(P``
M`/G<``!`````'=T``"T```!>W0``,P```(S=```E````P-T``!4```#FW0``
M&0```/S=```I````%MX``"0```!`W@``*````&7>```1````CMX``!$```"@
MW@``"@```++>```$````O=X```P```#"W@``"@```,_>```0````VMX``!8`
M``#KW@``%@````+?```'````&=\```<````AWP``%````"G?```*````/M\`
M``@```!)WP``"````%+?```(````6]\```8```!DWP``)P```&O?```(````
MD]\```P```"<WP``!P```*G?```'````L=\```8```"YWP``!0```,#?```'
M````QM\```8```#.WP``"````-7?```I````WM\```X````(X```"@```!?@
M```)````(N````X````LX```!````#O@```'````0.````D```!(X```!@``
M`%+@```1````6>````<```!KX```%@```'/@```$````BN````@```"/X```
M!@```)C@```-````G^````8```"MX```'@```+3@```%````T^```!$```#9
MX```"````.O@```-````].````P````"X0``#`````_A```'````'.$```0`
M```DX0```P```"GA```#````+>$``!<````QX0``"0```$GA```3````4^$`
M`!T```!GX0``"0```(7A```(````C^$``!````"8X0``'0```*GA```)````
MQ^$``!L```#1X0``!````.WA```(````\N$```@```#[X0``"@````3B``!!
M````#^(``!H```!1X@``*P```&SB```@````F.(``!D```"YX@``%0```-/B
M```&````Z>(```8```#PX@``%0```/?B```)````#>,```T````7XP``&```
M`"7C```B````/N,``"X```!AXP``'0```)#C```A````KN,``"D```#0XP``
M"@```/KC```'````!>0```<````-Y```"0```!7D```5````'^0```@````U
MY```#@```#[D```*````3>0```\```!8Y```#0```&CD```/````=N0```T`
M``"&Y```"0```)3D```4````GN0```8```"SY```&````+KD```=````T^0`
M`!,```#QY```$0````7E```4````%^4```0````LY0``#````#'E```&````
M/N4``!0```!%Y0``%P```%KE``!4````<N4``&0```#'Y0``!````"SF```.
M````,>8``$0```!`Y@``!0```(7F```%````B^8``!L```"1Y@``&@```*WF
M```3````R.8``!$```#<Y@``$0```.[F```1`````.<``!P````2YP``3@``
M`"_G``!%````?N<``$4```#$YP``*@````KH```V````->@``#X```!LZ```
M/P```*OH```=````Z^@``!`````)Z0``(0```!KI```%````/.D``!,```!"
MZ0``"P```%;I```3````8ND``!(```!VZ0``"@```(GI```/````E.D```T`
M``"DZ0``$0```++I```3````Q.D```P```#8Z0``#````.7I```&````\ND`
M``P```#YZ0``!@````;J```7````#>H``!`````EZ@``$0```#;J```(````
M2.H```4```!1Z@``#````%?J```0````9.H```4```!UZ@``#0```'OJ```&
M````B>H``!8```"0Z@``!P```*?J```-````K^H```<```"]Z@``"P```,7J
M```'````T>H```<```#9Z@``"0```.'J```4````Z^H```D`````ZP``"0``
M``KK```*````%.L``!D````?ZP``/0```#GK```=````=^L```P```"5ZP``
M$````*+K```;````L^L```D```#/ZP``!0```-GK```E````W^L``!(````%
M[```$P```!CL```K````+.P``#L```!8[```(````)3L```(````M>P``#8`
M``"^[```(0```/7L```0````%^T```@````H[0``#````#'M```&````/NT`
M``0```!%[0``#P```$KM```.````6NT``$````!I[0``"@```*KM```'````
MM>T```H```"][0``#0```,CM```>````UNT``!\```#U[0``&P```!7N```<
M````,>X``"$```!.[@``'@```'#N```9````C^X``!X```"I[@``&P```,CN
M```A````Y.X``"X````&[P``)@```#7O```;````7.\``!P```!X[P``'@``
M`)7O```<````M.\``"8```#1[P``*P```/CO```S````)/```"8```!8\```
M*P```'_P```X````J_```!T```#D\```'0````+Q```5````(/$``!4````V
M\0``+P```$SQ```@````?/$``!(```"=\0``(````+#Q```I````T?$``!X`
M``#[\0``'@```!KR```@````.?(``!(```!:\@``H@```&WR```6````$/,`
M`",````G\P``*````$OS```I````=/,``"@```">\P``'P```,?S```5````
MY_,``!4```#]\P``(````!/T```E````-/0``"@```!:]```+0```(/T```P
M````L?0``)(```#B]```(0```'7U```6````E_4``!8```"N]0``'````,7U
M```F````XO4``"H````)]@``00```#3V``!$````=O8```P```"[]@``!P``
M`,CV```'````T/8```8```#8]@``#P```-_V```2````[_8```T````"]P``
M$````!#W```2````(?<```<````T]P``$P```#SW```2````4/<```<```!C
M]P``!````&OW```'````</<``!````!X]P``$````(GW```,````FO<```X`
M``"G]P``#0```+;W```/````Q/<``!,```#4]P``#0```.CW```H````]O<`
M``,````?^```#0```"/X```&````,?@``!$````X^```%P```$KX```;````
M8O@```X```!^^````@```(WX```%````D/@``!,```"6^```$````*KX```/
M````N_@```0```#+^```#0```-#X```.````WO@```,```#M^```!@```/'X
M```'````^/@```X`````^0``"`````_Y```/````&/D```@````H^0``#P``
M`#'Y```'````0?D``!````!)^0``#0```%KY```0````:/D```T```!Y^0``
M"P```(?Y```1````D_D```D```"E^0``!@```*_Y```)````MOD```L```#`
M^0``#````,SY```,````V?D```H```#F^0``$0```/'Y```9`````_H```L`
M```=^@``#0```"GZ```B````-_H```\```!:^@``&P```&KZ```T````AOH`
M``H```"[^@``&````,;Z```2````W_H``!D```#R^@``7`````S[```6````
M:?L``!````"`^P``(@```)'[```-````M/L```<```#"^P``#````,K[```F
M````U_L```P```#^^P``%`````O\```+````(/P``"(````L_```+P```$_\
M```+````?_P```D```"+_```&0```)7\```+````K_P``!<```"[_```%P``
M`-/\```)````Z_P```<```#U_```%@```/W\```1````%/T```\````F_0``
M&0```#;]```6````4/T```X```!G_0``!P```';]```(````?OT```T```"'
M_0``)@```)7]```Y````O/T```X```#V_0``0P````7^```2````2?X``!\`
M``!<_@``"````'S^```+````A?X``"\```"1_@``#@```,'^```%````T/X`
M``<```#6_@``"````-[^```&````Y_X``$4```#N_@```P```#3_```'````
M./\```0```!`_P``!P```$7_```.````3?\```H```!<_P``#@```&?_```*
M````=O\```\```"!_P``$````)'_```7````HO\``!4```"Z_P``#@```-#_
M```:````W_\``!$```#Z_P``&0````P``0`7````)@`!``D````^``$`!0``
M`$@``0`+````3@`!``H```!:``$``@```&4``0`%````:``!``T```!N``$`
M&P```'P``0`7````F``!`!0```"P``$`"0```,4``0`.````SP`!``T```#>
M``$`$@```.P``0`$````_P`!``,````$`0$`"`````@!`0`&````$0$!``@`
M```8`0$`"````"$!`0`.````*@$!`!@````Y`0$`&````%(!`0`%````:P$!
M`!@```!Q`0$`'@```(H!`0`;````J0$!`!D```#%`0$`,0```-\!`0`8````
M$0(!`!L````J`@$`$P```$8"`0`3````6@(!``<```!N`@$`"````'8"`0`&
M````?P(!``8```"&`@$`#````(T"`0`.````F@(!``T```"I`@$`$P```+<"
M`0`/````RP(!`!X```#;`@$`&0```/H"`0`0````%`,!``\````E`P$`$```
M`#4#`0`/````1@,!``L```!6`P$`#P```&(#`0`,````<@,!``\```!_`P$`
M!P```(\#`0`&````EP,!``P```">`P$`#@```*L#`0`,````N@,!`"@```#'
M`P$`#P```/`#`0`(``````0!``8````)!`$`#P```!`$`0`(````(`0!`!,`
M```I!`$`'@```#T$`0`A````7`0!`"````!^!`$`&0```)\$`0`7````N00!
M`"4```#1!`$`%P```/<$`0`6````#P4!``0````F!0$`&P```"L%`0`-````
M1P4!``P```!5!0$``P```&(%`0`%````9@4!``@```!L!0$`"@```'4%`0`,
M````@`4!``L```"-!0$`$````)D%`0`,````J@4!``X```"W!0$`"P```,8%
M`0`$````T@4!``0```#7!0$`$P```-P%`0`4````\`4!``P````%!@$`"0``
M`!(&`0`.````'`8!``L````K!@$`&P```#<&`0`'````4P8!``0```!;!@$`
M!P```&`&`0`*````:`8!``T```!S!@$`&````($&`0`*````F@8!``0```"E
M!@$`)@```*H&`0`.````T08!`'P```#@!@$`%0```%T'`0`%````<P<!``<`
M``!Y!P$`#````($'`0`(````C@<!``H```"7!P$`!@```*('`0`(````J0<!
M``(```"R!P$`!@```+4'`0`&````O`<!`!0```##!P$`!````-@'`0`)````
MW0<!`!4```#G!P$`#P```/T'`0`1````#0@!`!H````?"`$`#0```#H(`0`0
M````2`@!`!L```!9"`$`!@```'4(`0`$````?`@!``D```"!"`$`$````(L(
M`0`)````G`@!``D```"F"`$`!@```+`(`0`%````MP@!`!H```"]"`$`"```
M`-@(`0`&````X0@!``0```#H"`$`!P```.T(`0`9````]0@!``X````/"0$`
M!P```!X)`0`'````)@D!``4````N"0$`"0```#0)`0`*````/@D!``X```!)
M"0$``@```%@)`0`&````6PD!``L```!B"0$`#0```&X)`0`'````?`D!``D`
M``"$"0$`!@```(X)`0`%````E0D!``D```";"0$`!P```*4)`0`$````K0D!
M`!0```"R"0$`0@```,<)`0`E````"@H!`"4````P"@$`!@```%8*`0`$````
M70H!``D```!B"@$`"````&P*`0`1````=0H!``X```"'"@$`"0```)8*`0`&
M````H`H!``T```"G"@$`!@```+4*`0`$````O`H!`#D```#!"@$`/0```/L*
M`0`Z````.0L!`!X```!T"P$`!0```),+`0`.````F0L!``0```"H"P$`!@``
M`*T+`0`'````M`L!`"$```"\"P$`#0```-X+`0`5````[`L!``8````"#`$`
M$@````D,`0`$````'`P!`!$````A#`$`!@```#,,`0`*````.@P!`"(```!%
M#`$`!````&@,`0`'````;0P!``0```!U#`$`!0```'H,`0`$````@`P!``P`
M``"%#`$`#@```)(,`0`*````H0P!``@```"L#`$`"0```+4,`0`%````OPP!
M`#H```#%#`$`,``````-`0`U````,0T!`"D```!G#0$`1P```)$-`0`X````
MV0T!`"D````2#@$`/P```#P.`0`N````?`X!`"T```"K#@$`'P```-D.`0`/
M````^0X!`!(````)#P$`"P```!P/`0`'````*`\!`"8````P#P$`/````%</
M`0`I````E`\!`#H```"^#P$`)````/D/`0`F````'A`!``@```!%$`$`"@``
M`$X0`0`)````61`!``<```!C$`$`(````&L0`0`@````C!`!`"8```"M$`$`
M"@```-00`0`9````WQ`!`"D```#Y$`$`%@```",1`0`2````.A$!``<```!-
M$0$`"@```%41`0`,````8!$!``\```!M$0$`$````'T1`0!`````CA$!`'``
M``#/$0$`9@```$`2`0#1````IQ(!``X```!Y$P$`"0```(@3`0`*````DA,!
M`!(```"=$P$`$P```+`3`0`,````Q!,!``8```#1$P$`&````-@3`0`/````
M\1,!`!8````!%`$`$@```!@4`0`0````*Q0!``H````\%`$`$0```$<4`0`<
M````610!`",```!V%`$`:@```)H4`0`/````!14!``4````5%0$`$````!L5
M`0`)````+!4!``0````V%0$`"P```#L5`0`@````1Q4!`!0```!H%0$`#```
M`'T5`0`,````BA4!``\```"7%0$`%0```*<5`0`I````O14!`"H```#G%0$`
M)@```!(6`0`G````.18!`"D```!A%@$`*@```(L6`0`9````MA8!`!$```#0
M%@$`$@```.(6`0`3````]18!`!0````)%P$`#P```!X7`0`6````+A<!`!<`
M``!%%P$`$````%T7`0`1````;A<!`#0```"`%P$`$P```+47`0`2````R1<!
M`#4```#<%P$`%````!(8`0`'````)Q@!``P````O&`$`*P```#P8`0`@````
M:!@!`!````")&`$`%````)H8`0`1````KQ@!`!<```#!&`$`'````-D8`0`3
M````]A@!`!0````*&0$`&@```!\9`0`1````.AD!`!H```!,&0$`'@```&<9
M`0`:````AAD!`!,```"A&0$`%0```+49`0`1````RQD!`!<```#=&0$`%```
M`/49`0`7````"AH!`!4````B&@$`"0```#@:`0`0````0AH!`!D```!3&@$`
M!````&T:`0`'````<AH!``L```!Z&@$`$0```(8:`0`&````F!H!``8```"?
M&@$`!@```*8:`0`%````K1H!``<```"S&@$`!P```+L:`0`%````PQH!`!8`
M``#)&@$`!@```.`:`0`&````YQH!``0```#N&@$`!````/,:`0`'````^!H!
M``X`````&P$`#`````\;`0`,````'!L!``T````I&P$`!0```#<;`0`H````
M/1L!``P```!F&P$`#P```',;`0`*````@QL!``@```".&P$`"0```)<;`0`K
M````H1L!``@```#-&P$`!````-8;`0`(````VQL!``4```#D&P$`)@```.H;
M`0`2````$1P!``\````D'`$`!@```#0<`0`*````.QP!``<```!&'`$`"```
M`$X<`0`@````5QP!``T```!X'`$`"0```(8<`0`-````D!P!``H```">'`$`
M%````*D<`0`,````OAP!``T```#+'`$`"0```-D<`0`.````XQP!`!8```#R
M'`$`$0````D=`0`)````&QT!``8````E'0$`"````"P=`0`#````-1T!``8`
M```Y'0$`&0```$`=`0`'````6AT!``0```!B'0$`"P```&<=`0`+````<QT!
M``<```!_'0$`!0```(<=`0`'````C1T!`!8```"5'0$`#0```*P=`0`*````
MNAT!``T```#%'0$`"@```-,=`0`0````WAT!``\```#O'0$`$0```/\=`0`7
M````$1X!``H````I'@$`$0```#0>`0`(````1AX!`!X```!/'@$`!````&X>
M`0`/````<QX!`#H```"#'@$`!0```+X>`0`,````Q!X!`!X```#1'@$`#@``
M`/`>`0`0````_QX!``L````0'P$`#````!P?`0`)````*1\!``<````S'P$`
M"@```#L?`0`)````1A\!``X```!0'P$`$````%\?`0`;````<!\!`!@```",
M'P$`&@```*4?`0`*````P!\!``D```#+'P$`"0```-4?`0`*````WQ\!``P`
M``#J'P$`#P```/<?`0`(````!R`!``8````0(`$`!P```!<@`0`%````'R`!
M``L````E(`$`1P```#$@`0`-````>2`!``D```"'(`$`!````)$@`0`#````
MEB`!`!,```":(`$`$P```*X@`0`3````PB`!``8```#6(`$`"P```-T@`0`*
M````Z2`!``(```#T(`$`!````/<@`0`E````_"`!``,````B(0$`!0```"8A
M`0`J````+"$!``H```!7(0$`!0```&(A`0`$````:"$!``H```!M(0$`#0``
M`'@A`0`&````AB$!``@```"-(0$`"````)8A`0`$````GR$!``4```"D(0$`
M&````*HA`0!H````PR$!``D````L(@$`#````#8B`0`0````0R(!``4```!4
M(@$`!@```%HB`0`;````82(!`"\```!](@$`$````*TB`0`*````OB(!``\`
M``#)(@$`"@```-DB`0`)````Y"(!`!,```#N(@$`&P````(C`0`8````'B,!
M`!<````W(P$`&````$\C`0`?````:",!``X```"((P$``P```)<C`0`'````
MFR,!``(```"C(P$`"````*8C`0`'````KR,!`!0```"W(P$`$P```,PC`0`0
M````X",!``T```#Q(P$`#@```/\C`0`6````#B0!``<````E)`$`"P```"TD
M`0`)````.20!``H```!#)`$`"P```$XD`0`'````6B0!`%$```!B)`$`$```
M`+0D`0`,````Q20!``T```#2)`$`&@```.`D`0!*````^R0!`!D```!&)0$`
M!@```&`E`0`:````9R4!`"4```"")0$`!@```*@E`0`&````KR4!`!\```"V
M)0$`!@```-8E`0`)````W24!`!@```#G)0$`%P`````F`0`H````&"8!``D`
M``!!)@$`!@```$LF`0`-````4B8!`"(```!@)@$`5P```(,F`0`3````VR8!
M`",```#O)@$`$P```!,G`0`"````)R<!``L````J)P$`"````#8G`0`-````
M/R<!``H```!-)P$`!P```%@G`0`4````8"<!``8```!U)P$`!@```'PG`0`(
M````@R<!``4```",)P$`"@```)(G`0`.````G2<!``<```"L)P$`$P```+0G
M`0`5````R"<!``P```#>)P$`#0```.LG`0`*````^2<!``L````$*`$`,@``
M`!`H`0`'````0R@!``P```!+*`$`#0```%@H`0`,````9B@!``D```!S*`$`
M"0```'TH`0`*````AR@!``<```"2*`$`"0```)HH`0`'````I"@!``H```"L
M*`$`!P```+<H`0`;````OR@!``\```#;*`$`0@```.LH`0`2````+BD!``H`
M``!!*0$`%@```$PI`0`,````8RD!``T```!P*0$`$````'XI`0`)````CRD!
M`!````"9*0$`!P```*HI`0`2````LBD!``0```#%*0$`!P```,HI`0`%````
MTBD!``0```#8*0$`#````-TI`0`%````ZBD!``L```#P*0$`%````/PI`0`1
M````$2H!`!0````C*@$`%P```#@J`0`8````4"H!`!P```!I*@$`&0```(8J
M`0`'````H"H!``4```"H*@$`#0```*XJ`0`,````O"H!``D```#)*@$`$0``
M`-,J`0`(````Y2H!`!<```#N*@$`"P````8K`0!*````$BL!``P```!=*P$`
M'P```&HK`0`:````BBL!`!,```"E*P$`!````+DK`0`*````OBL!``0```#)
M*P$`#0```,XK`0`-````W"L!``@```#J*P$`"@```/,K`0`)````_BL!``D`
M```(+`$`"````!(L`0`,````&RP!``D````H+`$`!0```#(L`0`)````."P!
M``4```!"+`$`!P```$@L`0`%````4"P!``0```!6+`$``@```%LL`0`.````
M7BP!``@```!M+`$`#````'8L`0`X````@RP!`"P```"\+`$`$@```.DL`0`I
M````_"P!`#(````F+0$`)0```%DM`0`*````?RT!`"P```"*+0$`+@```+<M
M`0`S````YBT!`#,````:+@$`.````$XN`0`/````ARX!`!0```"7+@$`&```
M`*PN`0`+````Q2X!`!0```#1+@$`$````.8N`0`L````]RX!`!P````D+P$`
M#P```$$O`0`3````42\!`!4```!E+P$`%````'LO`0`2````D"\!`!0```"C
M+P$`%0```+@O`0`M````SB\!`"T```#\+P$`,0```"HP`0`N````7#`!`"\`
M``"+,`$`+````+LP`0`3````Z#`!``P```#\,`$`#0````DQ`0`-````%S$!
M``@````E,0$`%P```"XQ`0`(````1C$!``P```!/,0$`*P```%PQ`0`A````
MB#$!`!H```"J,0$`'````,4Q`0`)````XC$!`$4```#L,0$`00```#(R`0`/
M````=#(!``0```"$,@$`$P```(DR`0`.````G3(!`!,```"L,@$`&````,`R
M`0`&````V3(!``D```#@,@$`"@```.HR`0`/````]3(!``D````%,P$`$```
M``\S`0`'````(#,!``X````H,P$`!0```#<S`0`;````/3,!``8```!9,P$`
M#0```&`S`0`(````;C,!``,```!W,P$`!@```'LS`0`4````@C,!`!$```"7
M,P$`#@```*DS`0`X````N#,!``(```#Q,P$`!@```/0S`0`.````^S,!``4`
M```*-`$`!P```!`T`0`.````&#0!``8````G-`$`*````"XT`0`,````5S0!
M`!P```!D-`$`!````($T`0`"````AC0!`"8```")-`$`%@```+`T`0`4````
MQS0!`"D```#<-`$`%P````8U`0`?````'C4!`%P````^-0$`%````)LU`0`^
M````L#4!`!\```#O-0$`$`````\V`0`(````(#8!`!(````I-@$`%````#PV
M`0`'````438!``X```!9-@$`#````&@V`0`,````=38!`!,```""-@$`"@``
M`)8V`0`=````H38!`!D```"_-@$`!0```-DV`0`1````WS8!``@```#Q-@$`
M!0```/HV`0`1`````#<!``D````2-P$`)````!PW`0`2````03<!`!4```!4
M-P$`$@```&HW`0`.````?3<!`!D```",-P$`"````*8W`0`)````KS<!``(`
M``"Y-P$`#0```+PW`0`'````RC<!``H```#2-P$`!P```-TW`0`/````Y3<!
M``8```#U-P$`"P```/PW`0`:````"#@!``H````C.`$`!P```"XX`0`(````
M-C@!``4````_.`$`'P```$4X`0`&````93@!`!````!L.`$`"````'TX`0`-
M````AC@!``@```"4.`$`'@```)TX`0`2````O#@!`"P```#/.`$`&@```/PX
M`0`)````%SD!``H````A.0$`%0```"PY`0`0````0CD!``4```!3.0$`%```
M`%DY`0`$````;CD!``<```!S.0$`$````'LY`0`&````C#D!``<```"3.0$`
M'@```)LY`0`H````NCD!`!X```#C.0$`"@````(Z`0`<````#3H!`!$````J
M.@$`"P```#PZ`0`:````2#H!`!0```!C.@$`!````'@Z`0`$````?3H!``L`
M``"".@$`!0```(XZ`0`&````E#H!``@```";.@$`!@```*0Z`0`*````JSH!
M`!L```"V.@$`-````-(Z`0`T````!SL!`"`````\.P$`*0```%T[`0`@````
MASL!`$$```"H.P$`&@```.H[`0`H````!3P!`"D````N/`$`40```%@\`0!0
M````JCP!`%<```#[/`$`+````%,]`0`B````@#T!``8```"C/0$`"````*H]
M`0`%````LST!``X```"Y/0$`"````,@]`0`9````T3T!`!D```#K/0$`%0``
M``4^`0`J````&SX!``@```!&/@$`(P```$\^`0`9````<SX!`"X```"-/@$`
M-````+P^`0`(````\3X!`!<```#Z/@$`"@```!(_`0`'````'3\!`"$````E
M/P$`#````$<_`0`-````5#\!``P```!B/P$`$````&\_`0`.````@#\!``L`
M``"//P$`!P```)L_`0`3````HS\!``@```"W/P$`"P```,`_`0`*````S#\!
M`!0```#7/P$`#P```.P_`0`R````_#\!``L````O0`$`#@```#M``0`%````
M2D`!``4```!00`$`!0```%9``0`7````7$`!``\```!T0`$`!````(1``0`*
M````B4`!``D```"40`$`"P```)Y``0`-````JD`!``P```"X0`$`#@```,5`
M`0`%````U$`!``0```#:0`$`#0```-]``0`R````[4`!`$4````@00$`"P``
M`&9!`0`*````<D$!``\```!]00$`$P```(U!`0`3````H4$!``\```"U00$`
M#````,5!`0`.````TD$!``T```#A00$`#0```.]!`0`7````_4$!``<````5
M0@$`'@```!U"`0`4````/$(!``4```!10@$`%````%="`0`&````;$(!``<`
M``!S0@$`(P```'M"`0`,````GT(!`!````"L0@$`$0```+U"`0`.````ST(!
M`!<```#>0@$`*@```/9"`0`&````(4,!``D````H0P$`#P```#)#`0`,````
M0D,!``T```!/0P$`$0```%U#`0`7````;T,!``L```"'0P$`-@```)-#`0`*
M````RD,!`"(```#50P$`"P```/A#`0`/````!$0!`'T````41`$`"P```))$
M`0`@````GD0!`"<```"_1`$`*P```.=$`0`)````$T4!`#(````=10$`)0``
M`%!%`0`(````=D4!`#````!_10$`,0```+!%`0`M````XD4!`!(````01@$`
M#@```"-&`0`4````,D8!``4```!'1@$`#@```$U&`0`3````7$8!`!$```!P
M1@$`"````()&`0`2````BT8!``<```">1@$`$0```*9&`0`3````N$8!``<`
M``#,1@$`%````-1&`0`8````Z48!``<````"1P$`!0````I'`0`,````$$<!
M``P````=1P$`$@```"I'`0`$````/4<!``<```!"1P$`"@```$I'`0`+````
M54<!``P```!A1P$`#@```&Y'`0`.````?4<!``4```",1P$`!0```))'`0`N
M````F$<!`"8```#'1P$`(P```.Y'`0`#````$D@!`!(````62`$`!@```"E(
M`0`>````,$@!`!@```!/2`$`)0```&A(`0`-````CD@!``D```"<2`$`'P``
M`*9(`0`#````QD@!``<```#*2`$`"@```-)(`0`"````W4@!``P```#@2`$`
M%0```.U(`0`+`````TD!`!D````/20$`(````"E)`0`2````2DD!``4```!=
M20$`"@```&-)`0`5````;DD!`!(```"$20$`"````)=)`0`,````H$D!``0`
M``"M20$`"0```+))`0`'````O$D!``L```#$20$`#@```-!)`0`*````WTD!
M``P```#J20$`4@```/=)`0`7````2DH!`"0```!B2@$`$@```(=*`0`'````
MFDH!``8```"B2@$`$````*E*`0`.````NDH!``X```#)2@$`(````-A*`0`,
M````^4H!`!D````&2P$`#0```"!+`0`5````+DL!`!(```!$2P$`#P```%=+
M`0`4````9TL!``H```!\2P$`&P```(=+`0`0````HTL!`!P```"T2P$`6```
M`-%+`0`+````*DP!`"$````V3`$`)0```%A,`0!I````?DP!`!H```#H3`$`
M%P````--`0`9````&TT!`!H````U30$`&0```%!-`0`E````:DT!`"<```"0
M30$`&@```+A-`0`7````TTT!`!T```#K30$`)@````E.`0`;````,$X!`"H`
M``!,3@$`&0```'=.`0`?````D4X!`!<```"Q3@$`$P```,E.`0`(````W4X!
M`$0```#F3@$`$P```"M/`0!`````/T\!``<```"`3P$`"````(A/`0`)````
MD4\!`!4```";3P$`#0```+%/`0`C````OT\!``T```#C3P$`$P```/%/`0`(
M````!5`!``,````.4`$`#````!)0`0!&````'U`!`!<```!F4`$`#@```'Y0
M`0`_````C5`!`$T```#-4`$`-P```!M1`0!7````4U$!``4```"K40$`'P``
M`+%1`0`O````T5$!``H````!4@$`$P````Q2`0`0````(%(!`!$````Q4@$`
M"````$-2`0`-````3%(!`"T```!:4@$`!````(A2`0`-````C5(!`!4```";
M4@$`.P```+%2`0!/````[5(!`!\````]4P$`%@```%U3`0`E````=%,!`"@`
M``":4P$`'````,-3`0`+````X%,!`",```#L4P$`'P```!!4`0`A````,%0!
M`!T```!25`$`)0```'!4`0`@````EE0!`"0```"W5`$`(````-Q4`0`P````
M_50!``L````N50$`!P```#I5`0`-````0E4!``P```!050$`%P```%U5`0`&
M````=54!`#D```!\50$`#````+95`0`'````PU4!``D```#+50$`$P```-55
M`0`'````Z54!``D```#Q50$`!````/M5`0`0`````%8!``@````15@$`"```
M`!I6`0`$````(U8!``L````H5@$`#````#16`0`2````058!`!$```!45@$`
M#````&96`0`:````<U8!``\```".5@$`!P```)Y6`0`-````IE8!`!0```"T
M5@$`#@```,E6`0`,````V%8!`"P```#E5@$`$P```!)7`0`<````)E<!`"@`
M``!#5P$`!@```&Q7`0`'````<U<!`!,```![5P$`!0```(]7`0`$````E5<!
M`!<```":5P$`"@```+)7`0`,````O5<!``D```#*5P$`!@```-17`0`)````
MVU<!``8```#E5P$`"````.Q7`0`)````]5<!``4```#_5P$`"@````58`0`(
M````$%@!``H````96`$`"@```"18`0`'````+U@!`!$````W6`$`!@```$E8
M`0`.````4%@!``X```!?6`$`#0```&Y8`0`+````?%@!`!T```"(6`$`"P``
M`*98`0`"````LE@!`!P```"U6`$`!P```-)8`0`&````VE@!`&0```#A6`$`
M"0```$99`0`'````4%D!`"8```!860$`.````']9`0`:````N%D!`"H```#3
M60$`.P```/Y9`0`H````.EH!`#0```!C6@$`&0```)A:`0`5````LEH!``4`
M``#(6@$`!P```,Y:`0`(````UEH!``<```#?6@$`!@```.=:`0`%````[EH!
M``<```#T6@$`#@```/Q:`0`)````"UL!``8````56P$`"````!Q;`0`+````
M)5L!``<````Q6P$`"````#E;`0`'````0EL!`!8```!*6P$`"0```&%;`0`&
M````:UL!``L```!R6P$`$````'Y;`0`&````CUL!`!P```"66P$`%````+-;
M`0`'````R%L!`!$```#06P$`"````.);`0`.````ZUL!``@```#Z6P$`!0``
M``-<`0`0````"5P!``D````:7`$`$````"1<`0`&````-5P!`!D````\7`$`
M"@```%9<`0`<````85P!``<```!^7`$`!0```(9<`0`$````C%P!`!````"1
M7`$`%````*)<`0`+````MUP!``T```##7`$`*````-%<`0`8````^EP!`!<`
M```370$`"0```"M=`0`:````-5T!`!0```!070$`!````&5=`0`)````:ET!
M``H```!T70$`!P```']=`0`"````AUT!``X```"*70$`"````)E=`0`?````
MHET!`",```#"70$`.````.9=`0`C````'UX!`!\```!#7@$`.````&->`0`F
M````G%X!`#$```##7@$`)P```/5>`0!D````'5\!`!0```""7P$`)````)=?
M`0`C````O%\!`",```#@7P$`*P````1@`0`A````,&`!`"0```!28`$`'```
M`'=@`0!5````E&`!`#@```#J8`$`2@```"-A`0!;````;F$!`"@```#*80$`
M.````/-A`0`O````+&(!`$4```!<8@$`2@```*)B`0!&````[6(!`"H````T
M8P$`,P```%]C`0`H````DV,!`"P```"\8P$`)P```.EC`0`F````$60!`!L`
M```X9`$`/@```%1D`0`Z````DV0!`",```#.9`$`%P```/)D`0`9````"F4!
M`$@````D90$`A0```&UE`0`P````\V4!`"4````D9@$`00```$IF`0!;````
MC&8!`$D```#H9@$`,0```#)G`0!I````9&<!`!T```#.9P$`&````.QG`0`K
M````!6@!`"$````Q:`$`'P```%-H`0`K````<V@!`"8```"?:`$`(0```,9H
M`0`I````Z&@!`"<````2:0$`.@```#II`0`=````=6D!`!$```"3:0$`,P``
M`*5I`0`E````V6D!`#@```#_:0$`)P```#AJ`0`@````8&H!`#(```"!:@$`
M'P```+1J`0`P````U&H!`&D````%:P$`,0```&]K`0!!````H6L!`#,```#C
M:P$`)0```!=L`0`]````/6P!`&4```![;`$`30```.%L`0`M````+VT!`"<`
M``!=;0$`+P```(5M`0`H````M6T!`"X```#>;0$`*P````UN`0`P````.6X!
M`"H```!J;@$`/@```)5N`0!4````U&X!`"<````I;P$`6@```%%O`0`Z````
MK&\!`$@```#G;P$`2@```#!P`0`?````>W`!`#(```";<`$`'0```,YP`0`C
M````['`!`"\````0<0$`+````$!Q`0`M````;7$!`'$```";<0$`9@````UR
M`0!O````='(!`+,```#D<@$`%P```)AS`0`E````L',!`#(```#6<P$`*0``
M``ET`0`^````,W0!`"(```!R=`$`4@```)5T`0`B````Z'0!`"4````+=0$`
M"P```#%U`0`@````/74!`$4```!>=0$`(0```*1U`0`P````QG4!`"4```#W
M=0$`'````!UV`0`Q````.G8!``<```!L=@$`"````'1V`0`'````?78!``0`
M``"%=@$`"@```(IV`0`-````E78!``L```"C=@$`#@```*]V`0`)````OG8!
M``L```#(=@$`!@```-1V`0`%````VW8!`!````#A=@$``@```/)V`0!9````
M]78!``4```!/=P$`$@```%5W`0`$````:'<!``<```!M=P$`"````'5W`0`%
M````?G<!``,```"$=P$`$````(AW`0`,````F7<!`!,```"F=P$`#0```+IW
M`0`"````R'<!``<```#+=P$`!P```--W`0`&````VW<!`!0```#B=P$`#```
M`/=W`0`8````!'@!``8````=>`$`!````"1X`0`2````*7@!``P````\>`$`
M`P```$EX`0`J````37@!``0```!X>`$`!@```'UX`0`'````A'@!`!\```",
M>`$`-0```*QX`0`N````XG@!`"\````1>0$`%P```$%Y`0`?````67D!`"(`
M``!Y>0$`)0```)QY`0`@````PGD!`!L```#C>0$`&````/]Y`0`D````&'H!
M`!\````]>@$`&@```%UZ`0`A````>'H!`"````":>@$`&@```+MZ`0`R````
MUGH!`!D````)>P$`&@```"-[`0`O````/GL!`!0```!N>P$`*P```(-[`0`?
M````KWL!`",```#/>P$`'P```/-[`0`:````$WP!`"$````N?`$`)0```%!\
M`0`F````=GP!`"4```"=?`$`)````,-\`0`8````Z'P!`!T````!?0$`)```
M`!]]`0`8````1'T!`"(```!=?0$`+````(!]`0`O````K7T!`!4```#=?0$`
M)0```/-]`0`9````&7X!`#P````S?@$`'P```'!^`0`C````D'X!`!\```"T
M?@$`(````-1^`0`:````]7X!`"\````0?P$`&````$!_`0`F````67\!`!X`
M``"`?P$`*0```)]_`0`>````R7\!`#$```#H?P$`"0```!J``0`,````)(`!
M`!<````Q@`$`+P```$F``0`D````>8`!``<```">@`$`'P```*:``0`/````
MQH`!`!0```#6@`$`#@```.N``0`-````^H`!`"0````(@0$`!0```"V!`0`'
M````,X$!`"(````[@0$`)0```%Z!`0`:````A($!`!T```"?@0$`&@```+V!
M`0`'````V($!`,<```#@@0$`"P```*B"`0`<````M((!`!4```#1@@$`!@``
M`.>"`0`)````[H(!`!@```#X@@$`"P```!&#`0`-````'8,!``P````K@P$`
M%P```#B#`0`&````4(,!`#,```!7@P$`$P```(N#`0`3````GX,!``<```"S
M@P$`#P```+N#`0`'````RX,!`#(```#3@P$`!`````:$`0`A````"X0!`!,`
M```MA`$`#@```$&$`0`,````4(0!`!$```!=A`$`,@```&^$`0`6````HH0!
M``@```"YA`$`'0```,*$`0`)````X(0!``H```#JA`$`%````/6$`0`*````
M"H4!`!T````5A0$`"````#.%`0`?````/(4!``@```!<A0$`&@```&6%`0`G
M````@(4!``8```"HA0$`%0```*^%`0`'````Q84!``@```#-A0$`"0```-:%
M`0`_````X(4!``<````@A@$`#P```"B&`0`.````.(8!`!````!'A@$`"0``
M`%B&`0`)````8H8!``@```!LA@$`$P```'6&`0`'````B88!``@```"1A@$`
M&0```)J&`0`*````M(8!``H```"_A@$`"0```,J&`0`7````U(8!`!0```#L
MA@$`"@````&'`0`,````#(<!`!<````9AP$`!````#&'`0`J````-H<!``P`
M``!AAP$`$0```&Z'`0`'````@(<!``(```"(AP$`$````(N'`0`8````G(<!
M``L```"UAP$``P```,&'`0`(````Q8<!`!,```#.AP$`%P```.*'`0`)````
M^H<!``0````$B`$`!P````F(`0`'````$8@!``8````9B`$`%````""(`0`'
M````-8@!``T````]B`$`"P```$N(`0`4````5X@!`!4```!LB`$`#@```(*(
M`0`O````D8@!`"````#!B`$`'````.*(`0!(````_X@!`$P```!(B0$`%0``
M`)6)`0`,````JXD!`#$```"XB0$`!0```.J)`0`2````\(D!`#\````#B@$`
M$@```$.*`0`*````5HH!``8```!AB@$`!````&B*`0`$````;8H!``H```!R
MB@$`$P```'V*`0`%````D8H!``8```"7B@$`!@```)Z*`0`(````I8H!``0`
M``"NB@$`#````+.*`0`*````P(H!``D```#+B@$`.0```-6*`0`N````#XL!
M`"D````^BP$`!0```&B+`0`9````;HL!`!$```"(BP$``@```)J+`0`$````
MG8L!``H```"BBP$`!````*V+`0`&````LHL!`!0```"YBP$`!0```,Z+`0`#
M````U(L!``P```#8BP$`10```.6+`0`R````*XP!`#(```!>C`$`+P```)&,
M`0`:````P8P!`#4```#<C`$`.@```!*-`0`T````38T!`"@```""C0$`DP``
M`*N-`0`O````/XX!`$(```!OC@$`,````+*.`0`N````XXX!`!D````2CP$`
M)P```"R/`0`X````5(\!`#@```"-CP$`-P```,:/`0!R````_H\!`"````!Q
MD`$`-0```)*0`0`A````R)`!`$4```#JD`$`,````#"1`0`I````89$!`"$`
M``"+D0$`*````*V1`0`I````UI$!`"8`````D@$`)0```">2`0`H````39(!
M`"@```!VD@$`(@```)^2`0`K````PI(!`$4```#ND@$`20```#23`0!&````
M?I,!`#P```#%DP$`,`````*4`0`2````,Y0!`!,```!&E`$`$````%J4`0!Y
M````:Y0!``D```#EE`$`H0```.^4`0!S````D94!`'P````%E@$`*P```(*6
M`0!4````KI8!`!<````#EP$`%0```!N7`0`G````,9<!`!8```!9EP$`#P``
M`'"7`0`7````@)<!`!\```"8EP$`0````+B7`0`?````^9<!`!P````9F`$`
M40```#:8`0`:````B)@!`!0```"CF`$`"@```+B8`0`%````PY@!``8```#)
MF`$`"````-"8`0`%````V9@!`!(```#?F`$`$````/*8`0`3`````YD!`!T`
M```7F0$`#P```#69`0`/````19D!``\```!5F0$`!@```&69`0`-````;)D!
M``0```!ZF0$`"0```'^9`0`+````B9D!``4```"5F0$`!0```)N9`0`'````
MH9D!``4```"IF0$`%````*^9`0`.````Q)D!``<```#3F0$`"````-N9`0`/
M````Y)D!``T```#TF0$`"@````*:`0`(````#9H!``P````6F@$`!@```".:
M`0`/````*IH!``<````ZF@$`!@```$*:`0`%````29H!`!0```!/F@$`!@``
M`&2:`0`&````:YH!``P```!RF@$`$0```'^:`0`7````D9H!``@```"IF@$`
M!````+*:`0`9````MYH!`!$```#1F@$`"@```..:`0`%````[IH!`!@```#T
MF@$`$P````V;`0`<````(9L!`!$````^FP$``P```%";`0`&````5)L!``0`
M``!;FP$`!````&";`0`/````99L!``H```!UFP$`"@```(";`0`'````BYL!
M``0```"3FP$`&0```)B;`0`'````LIL!``(```"ZFP$``@```+V;`0`1````
MP)L!``D```#2FP$``@```-R;`0`&````WYL!`!(```#FFP$`%P```/F;`0`&
M````$9P!`"<````8G`$``@```$"<`0`(````0YP!``0```!,G`$`#P```%&<
M`0`3````89P!``<```!UG`$`"P```'V<`0`0````B9P!`!,```":G`$`!P``
M`*Z<`0`1````MIP!``8```#(G`$`&````,^<`0`&````Z)P!`!,```#OG`$`
M$`````.=`0`2````%)T!``(````GG0$`!@```"J=`0`,````,9T!``D````^
MG0$`$0```$B=`0`B````6IT!``<```!]G0$`!P```(6=`0`+````C9T!`!,`
M``"9G0$`!0```*V=`0`1````LYT!``(```#%G0$`"P```,B=`0`$````U)T!
M``L```#9G0$`!0```.6=`0`'````ZYT!`&8!``#SG0$`3````%J?`0`1````
MIY\!`!(```"YGP$`#P```,R?`0`.````W)\!``<```#KGP$`"@```/.?`0`'
M````_I\!``0````&H`$`&`````N@`0`=````)*`!`"P```!"H`$`'0```&^@
M`0`@````C:`!`"8```"NH`$`%P```-6@`0`H````[:`!``P````6H0$`%0``
M`".A`0`K````.:$!``P```!EH0$`#@```'*A`0`1````@:$!`",```"3H0$`
M$@```+>A`0`%````RJ$!`",```#0H0$`"````/2A`0`*````_:$!`!,````(
MH@$`#P```!RB`0`+````+*(!``P````XH@$`%@```$6B`0`5````7*(!`$,`
M``!RH@$`(@```+:B`0`Q````V:(!`&\````+HP$`"````'NC`0`*````A*,!
M``H```"/HP$`-P```)JC`0`B````TJ,!`!````#UHP$`&P````:D`0`@````
M(J0!`#````!#I`$`$````'2D`0`,````A:0!`!,```"2I`$`$````*:D`0`&
M````MZ0!`(D```"^I`$`30```$BE`0`R````EJ4!`!,```#)I0$`"P```-VE
M`0`1````Z:4!`!T```#[I0$`"@```!FF`0`+````)*8!``H````PI@$`!P``
M`#NF`0`0````0Z8!``H```!4I@$`"@```%^F`0`0````:J8!``D```![I@$`
M"@```(6F`0`+````D*8!`",```"<I@$`)@```,"F`0`C````YZ8!`"0````+
MIP$`+````#"G`0`<````7:<!`#L```!ZIP$`10```+:G`0!6````_*<!`%,`
M``!3J`$`60```*>H`0!6`````:D!`#X```!8J0$``@```)>I`0`.````FJD!
M`!,```"IJ0$`#@```+VI`0`0````S*D!`!@```#=J0$`!0```/:I`0`&````
M_*D!``H````#J@$`!0````ZJ`0`&````%*H!``8````;J@$`$0```"*J`0`*
M````-*H!`"4````_J@$`)````&6J`0`0````BJH!`!(```";J@$`#````*ZJ
M`0`&````NZH!``@```#"J@$`$@```,NJ`0`)````WJH!``P```#HJ@$`%```
M`/6J`0`9````"JL!`!(````DJP$`#@```#>K`0`2````1JL!`!<```!9JP$`
M'@```'&K`0`C````D*L!`!H```"TJP$`&````,^K`0`:````Z*L!`!,````#
MK`$`$````!>L`0`7````**P!``T```!`K`$`*@```$ZL`0`8````>:P!`!8`
M``"2K`$`$P```*FL`0`9````O:P!`!,```#7K`$`3P```.NL`0`Q````.ZT!
M`"0```!MK0$`!@```)*M`0`)````F:T!`#0```"CK0$`#@```-BM`0`&````
MYZT!`!$```#NK0$`"@````"N`0`%````"ZX!`!0````1K@$`%0```":N`0`6
M````/*X!`!4```!3K@$`$0```&FN`0`3````>ZX!`!,```"/K@$`$P```*.N
M`0`*````MZX!`!H```#"K@$`"````-VN`0`(````YJX!``@```#OK@$`!0``
M`/BN`0`'````_JX!``H````&KP$`!````!&O`0`.````%J\!`!P````EKP$`
M#0```$*O`0`,````4*\!``T```!=KP$`$0```&NO`0`,````?:\!``H```"*
MKP$`#P```)6O`0`.````I:\!``\```"TKP$`%0```,2O`0`F````VJ\!``L`
M```!L`$`&@````VP`0`=````*+`!`"$```!&L`$`&````&BP`0`/````@;`!
M`!````"1L`$`$0```**P`0`O````M+`!`!L```#DL`$`&P````"Q`0`'````
M'+$!``8````DL0$`"````"NQ`0`,````-+$!``0```!!L0$`"0```$:Q`0`3
M````4+$!`!````!DL0$`"P```'6Q`0`1````@;$!`!8```"3L0$`'P```*JQ
M`0`'````RK$!`!(```#2L0$`!0```.6Q`0`6````Z[$!``\````"L@$`#```
M`!*R`0`Q````'[(!`$(```!1L@$`"0```)2R`0`(````GK(!`!0```"GL@$`
M!0```+RR`0`%````PK(!`!````#(L@$`"P```-FR`0`9````Y;(!`#L```#_
ML@$`$@```#NS`0`"````3K,!`$8```!1LP$`R0```)BS`0`O````8K0!`#0`
M``"2M`$`+@```,>T`0`M````]K0!``H````DM0$`"0```"^U`0`(````.;4!
M``<```!"M0$`"@```$JU`0`)````5;4!`",```!?M0$`-````(.U`0`B````
MN+4!`$8```#;M0$`(0```"*V`0`A````1+8!`$,```!FM@$`0@```*JV`0`?
M````[;8!`$`````-MP$`)P```$ZW`0`J````=K<!`$,```"AMP$`(0```.6W
M`0`G````![@!`"P````ON`$`&@```%RX`0`>````=[@!`"H```"6N`$`*P``
M`,&X`0`K````[;@!`!(````9N0$`#@```"RY`0`*````.[D!``<```!&N0$`
M#0```$ZY`0`(````7+D!``T```!EN0$`'P```'.Y`0`C````D[D!``<```"W
MN0$`!P```+^Y`0`5````Q[D!``H```#=N0$`!@```.BY`0`&````[[D!``@`
M``#VN0$`!@```/^Y`0`I````!KH!``@````PN@$`!P```#FZ`0`+````0;H!
M``<```!-N@$`!@```%6Z`0`%````7+H!``<```!BN@$`!@```&JZ`0`*````
M<;H!`"<```!\N@$`$@```*2Z`0`(````M[H!``@```#`N@$`#@```,FZ`0`#
M````V+H!``<```#<N@$`"0```.2Z`0`#````[KH!``D```#RN@$`!0```/RZ
M`0`7`````KL!``0````:NP$`"````!^[`0`&````*+L!``T````ONP$`"0``
M`#V[`0`G````1[L!``0```!ONP$`!@```'2[`0`)````>[L!``H```"%NP$`
M#````)"[`0`,````G;L!``<```"JNP$`"````+*[`0`#````N[L!``,```"_
MNP$`%P```,.[`0`)````V[L!`!8```#ENP$`)````/R[`0`)````(;P!``@`
M```KO`$`%@```#2\`0`6````2[P!``D```!BO`$`'````&R\`0`%````B;P!
M``@```"/O`$`!P```)B\`0`*````H+P!`$4```"KO`$`'0```/&\`0`X````
M#[T!`"(```!(O0$`'0```&N]`0`7````B;T!``8```"AO0$`!@```*B]`0`5
M````K[T!``@```#%O0$`#````,Z]`0`5````V[T!`!\```#QO0$`*P```!&^
M`0`:````/;X!`",```!8O@$`,0```'R^`0`)````KKX!``8```"XO@$`"```
M`+^^`0`)````R+X!`!<```#2O@$`"````.J^`0`.````\[X!``P````"OP$`
M$0````^_`0`.````(;\!`!$````POP$`#@```$*_`0`,````4;\!`!4```!>
MOP$`"0```'2_`0`<````?K\!`!T```";OP$`$@```+F_`0`/````S+\!`!(`
M``#<OP$`!0```.^_`0`*````];\!``4`````P`$`$P````;``0`7````&L`!
M`%4````RP`$`8@```(C``0`#````Z\`!`!,```#OP`$`*0````/!`0`%````
M+<$!``0````SP0$`'````#C!`0`>````5<$!`!$```!TP0$`#0```(;!`0`1
M````E,$!``P```"FP0$`&P```+/!`0!3````S\$!`%,````CP@$`4P```'?"
M`0`D````R\(!`#$```#PP@$`00```"+#`0`]````9,,!`!L```"BPP$`!0``
M`+[#`0`>````Q,,!``4```#CPP$`%0```.G#`0`+````_\,!`!0````+Q`$`
M$P```"#$`0`/````-,0!`!(```!$Q`$`$P```%?$`0`8````:\0!`!,```"$
MQ`$`#0```)C$`0`-````IL0!``0```"TQ`$`"P```+G$`0`(````Q<0!`!<`
M``#.Q`$`%0```.;$`0`2````_,0!``@````/Q0$`!````!C%`0`-````'<4!
M``<````KQ0$`"0```#/%`0`/````/<4!``L```!-Q0$`%@```%G%`0`(````
M<,4!``\```!YQ0$`"0```(G%`0`$````D\4!``<```"8Q0$`!P```*#%`0`(
M````J,4!`!4```"QQ0$`!P```,?%`0`%````S\4!``4```#5Q0$`&````-O%
M`0!0````],4!`"$```!%Q@$`#@```&?&`0`1````=L8!`!\```"(Q@$`"0``
M`*C&`0`%````LL8!``4```"XQ@$`&0```+[&`0`:````V,8!`"P```#SQ@$`
M-````"#'`0`H````5<<!``D```!^QP$`)0```(C'`0`B````KL<!``\```#1
MQP$`"````.''`0`,````ZL<!``8```#WQP$`!P```/['`0`:````!L@!`!$`
M```AR`$`0@```#/(`0`*````=L@!``L```"!R`$`"@```(W(`0`/````F,@!
M`"$```"HR`$`(@```,K(`0`@````[<@!`"$````.R0$`)````##)`0`C````
M5<D!`!\```!YR0$`)@```)G)`0`A````P,D!`"0```#BR0$`*0````?*`0`E
M````,<H!`!T```!7R@$`'@```'7*`0`@````E,H!`!L```"UR@$`)@```-'*
M`0`M````^,H!`"L````FRP$`(@```%++`0`K````=<L!`#<```"ARP$`'0``
M`-G+`0`=````]\L!`!D````5S`$`&0```"_,`0`P````2<P!`"$```!ZS`$`
M$@```)S,`0`A````K\P!`"@```#1S`$`&@```/K,`0`8````%<T!`!X````N
MS0$`$0```$W-`0"V````7\T!`!(````6S@$`'````"G.`0`E````1LX!`"8`
M``!LS@$`(````)/.`0`D````M,X!`!H```#9S@$`&@```/3.`0`D````#\\!
M`"0````TSP$`*P```%G/`0`L````A<\!`"<```"RSP$`C````-K/`0`?````
M9]`!`!4```"'T`$`%0```)W0`0`>````L]`!`"D```#2T`$`*0```/S0`0!$
M````)M$!`$0```!KT0$`"P```+#1`0`$````O-$!``8```#!T0$`!0```,C1
M`0`.````SM$!`!0```#=T0$`"@```/+1`0`(````_=$!``\````&T@$`!@``
M`!;2`0`6````'=(!`!$````TT@$`"````$;2`0`$````3](!``<```!4T@$`
M$````%S2`0`/````;=(!``L```!]T@$`#@```(G2`0`0````F-(!``X```"I
MT@$`$@```+C2`0`,````R](!`#8```#8T@$`"`````_3`0`+````&-,!``8`
M```DTP$`$@```"O3`0`8````/M,!`!L```!7TP$`"````'/3`0`"````?-,!
M``8```!_TP$`$P```(;3`0`2````FM,!``X```"MTP$`!0```+S3`0`.````
MPM,!``@```#1TP$``P```-K3`0`'````WM,!``<```#FTP$`#@```.[3`0`(
M````_=,!``D````&U`$`!@```!#4`0`-````%]0!``<````EU`$`$````"W4
M`0`,````/M0!`!$```!+U`$`#````%W4`0`,````:M0!`!$```!WU`$`"0``
M`(G4`0`&````D]0!``D```":U`$`"P```*34`0`/````L-0!``P```#`U`$`
M"P```,W4`0`1````V=0!`!P```#KU`$`"P````C5`0`-````%-4!`!\````B
MU0$`%````$+5`0`:````5]4!`#$```!RU0$`"@```*35`0`5````K]4!`!(`
M``#%U0$`%0```-C5`0!9````[M4!`!(```!(U@$`%0```%O6`0`D````<=8!
M``L```"6U@$`!P```*+6`0`-````JM8!`"L```"XU@$`#````.36`0`1````
M\=8!``L````#UP$`(@````_7`0`O````,M<!``H```!BUP$`"0```&W7`0`>
M````=]<!``L```"6UP$`&P```*+7`0`;````OM<!``<```#:UP$`!````.+7
M`0`7````Y]<!``X```#_UP$`%0````[8`0`<````)-@!`!<```!!V`$`#@``
M`%G8`0`*````:-@!``@```!SV`$`"P```'S8`0`B````B-@!`#,```"KV`$`
M#0```-_8`0`Y````[=@!`!<````GV0$`(P```#_9`0`%````8]D!``@```!I
MV0$`+0```'+9`0`*````H-D!``8```"KV0$`"````++9`0`+````N]D!``8`
M``#'V0$`5@```,[9`0`#````)=H!``<````IV@$`!0```#':`0`(````-]H!
M``\```!`V@$`"P```%#:`0`2````7-H!``L```!OV@$`$````'O:`0`2````
MC-H!`!D```"?V@$`%````+G:`0`/````SMH!`!L```#>V@$`&````/K:`0`;
M````$]L!`!L````OVP$`"@```$O;`0`'````5ML!``L```!>VP$`"@```&K;
M`0`"````==L!``8```!XVP$`#````'_;`0`E````C-L!`"````"RVP$`%@``
M`-/;`0`,````ZML!`!````#WVP$`#@````C<`0`0````%]P!``0````HW`$`
M!````"W<`0`)````,MP!``D````\W`$`!P```$;<`0`'````3MP!``\```!6
MW`$`(0```&;<`0`8````B-P!``,```"AW`$`'0```*7<`0`L````P]P!`"L`
M``#PW`$`'````!S=`0`W````.=T!`"D```!QW0$`(P```)O=`0`7````O]T!
M`!H```#7W0$`!P```/+=`0`(````^MT!``8````#W@$`!@````K>`0`0````
M$=X!`!$````BW@$`$````#3>`0`8````1=X!`!<```!>W@$`(@```';>`0`=
M````F=X!``X```"WW@$`#@```,;>`0`/````U=X!``T```#EW@$`$````//>
M`0`/````!-\!``L````4WP$`$@```"#?`0`#````,]\!``D````WWP$`#@``
M`$'?`0`2````4-\!``X```!CWP$`+P```'+?`0`-````HM\!``@```"PWP$`
M"0```+G?`0`2````P]\!``T```#6WP$`(````.3?`0`E````!>`!`"8````K
MX`$`)0```%+@`0`C````>.`!`",```"<X`$`*P```,#@`0`B````[.`!`!H`
M```/X0$``P```"KA`0`.````+N$!``@````]X0$`"P```$;A`0`#````4N$!
M``4```!6X0$`"````%SA`0`)````9>$!``L```!OX0$`#P```'OA`0`2````
MB^$!``H```">X0$`#@```*GA`0`.````N.$!``0```#'X0$``P```,SA`0`3
M````T.$!`!4```#DX0$`#````/KA`0`'````!^(!``8````/X@$`#@```!;B
M`0`:````)>(!``8```!`X@$``P```$?B`0`'````2^(!``T```!3X@$`#@``
M`&'B`0`7````<.(!``@```"(X@$``P```)'B`0`E````E>(!``T```"[X@$`
M3@```,GB`0`4````&.,!``@````MXP$`"@```#;C`0`1````0>,!``H```!3
MXP$`#````%[C`0`%````:^,!``X```!QXP$``@```(#C`0`%````@^,!``D`
M``")XP$`$P```)/C`0`%````I^,!``X```"MXP$`&@```+SC`0`3````U^,!
M`!@```#KXP$`(`````3D`0`.````)>0!`!(````TY`$`&0```$?D`0`&````
M8>0!``0```!HY`$`"0```&WD`0`7````=^0!``@```"/Y`$`$0```)CD`0`(
M````JN0!``4```"SY`$`&````+GD`0`(````TN0!``8```#;Y`$`!````.+D
M`0`&````Y^0!`!T```#NY`$`#0````SE`0`(````&N4!``@````CY0$`!0``
M`"SE`0`)````,N4!``<````\Y0$`%0```$3E`0`"````6N4!``8```!=Y0$`
M#````&3E`0`-````<>4!``H```!_Y0$`"````(KE`0`4````D^4!``0```"H
MY0$`"````*WE`0`'````MN4!``,```"^Y0$`$P```,+E`0`]````UN4!`"8`
M```4Y@$`*0```#OF`0`'````9>8!``0```!MY@$`"0```'+F`0`(````?.8!
M`!````"%Y@$`$P```);F`0`'````JN8!``8```"RY@$`#0```+GF`0`&````
MQ^8!``0```#.Y@$`,0```-/F`0`V````!><!`#,````\YP$`&@```'#G`0`%
M````B^<!``P```"1YP$`!0```)[G`0`&````I.<!``@```"KYP$`&````+3G
M`0`2````S><!`!<```#@YP$`!````/CG`0`-````_><!``4````+Z`$`$0``
M`!'H`0`-````(^@!``@````QZ`$`%P```#KH`0`#````4N@!``8```!6Z`$`
M`P```%WH`0`$````8>@!``,```!FZ`$`"P```&KH`0`*````=N@!``P```"!
MZ`$`"````([H`0`)````E^@!``4```"AZ`$`/0```*?H`0`Q````Y>@!`#\`
M```7Z0$`'0```%?I`0!!````=>D!`#<```"WZ0$`*````._I`0`Y````&.H!
M`"X```!2Z@$`,@```('J`0`A````M.H!`!$```#6Z@$`%0```.CJ`0`,````
M_NH!``D````+ZP$`+P```!7K`0!#````1>L!`"0```")ZP$`1P```*[K`0`D
M````]NL!`",````;[`$`"0```#_L`0`*````2>P!``H```!4[`$`!@```%_L
M`0`E````9NP!`"8```",[`$`,````+/L`0`)````Y.P!`!X```#N[`$`*@``
M``WM`0`:````..T!`!````!3[0$`!@```&3M`0`-````:^T!``T```!Y[0$`
M#P```(?M`0`2````E^T!`#L```"J[0$`D0```.;M`0!D````>.X!`+\```#=
M[@$`%0```)WO`0`*````L^\!``L```"^[P$`$0```,KO`0`2````W.\!``X`
M``#O[P$`!@```/[O`0`;````!?`!`!(````A\`$`'````#3P`0`4````4?`!
M`!$```!F\`$`"````'CP`0`1````@?`!`"0```"3\`$`*@```+CP`0!N````
MX_`!``H```!2\0$`!@```%WQ`0`6````9/$!``H```![\0$`!````(;Q`0`+
M````B_$!`"<```"7\0$`%````+_Q`0`+````U/$!``T```#@\0$`#P```.[Q
M`0`3````_O$!`"4````2\@$`)````#CR`0`<````7?(!`!X```!Z\@$`(0``
M`)GR`0`@````N_(!`!8```#<\@$`$0```//R`0`0````!?,!`!,````6\P$`
M$@```"KS`0`2````/?,!`!4```!0\P$`%````&;S`0`0````>_,!``\```",
M\P$`*0```)SS`0`1````QO,!`!$```#8\P$`.P```.KS`0`4````)O0!``8`
M```[]`$`#````$+T`0`G````3_0!`"$```!W]`$`%@```)GT`0`5````L/0!
M`!(```#&]`$`%@```-GT`0`<````\/0!`!,````-]0$`%0```"'U`0`:````
M-_4!`!@```!2]0$`'0```&OU`0`A````B?4!`"$```"K]0$`%0```,WU`0`4
M````X_4!`!0```#X]0$`&`````WV`0`:````)O8!`!@```!!]@$`%@```%KV
M`0`+````<?8!``\```!]]@$`!````(WV`0`$````DO8!``8```"7]@$`"P``
M`)[V`0`1````JO8!``8```"\]@$`"P```,/V`0`&````S_8!``<```#6]@$`
M!P```-[V`0`'````YO8!``4```#N]@$`%0```/3V`0`&````"O<!``D````1
M]P$`!````!OW`0`$````(/<!``<````E]P$`#0```"WW`0`,````._<!``X`
M``!(]P$`#````%?W`0`%````9/<!`"D```!J]P$`#0```)3W`0`+````HO<!
M``L```"N]P$`"0```+KW`0`0````Q/<!`#````#5]P$`"0````;X`0`$````
M$/@!``@````5^`$`!0```![X`0`)````)/@!``@````N^`$`$0```#?X`0`&
M````2?@!``D```!0^`$`!P```%KX`0`%````8O@!``0```!H^`$`$P```&WX
M`0`,````@?@!``T```".^`$`#0```)SX`0`1````JO@!``\```"\^`$`$@``
M`,SX`0`*````W_@!`!8```#J^`$`'@````'Y`0`:````(/D!``P````[^0$`
M"````$CY`0`(````4?D!``,```!:^0$`!@```%[Y`0`E````9?D!``<```"+
M^0$`!P```)/Y`0`-````F_D!``T```"I^0$`!P```+?Y`0`$````O_D!``<`
M``#$^0$`!@```,SY`0`-````T_D!``<```#A^0$`"````.GY`0`)````\OD!
M`!,```#\^0$`%0```!#Z`0`-````)OH!`!(````T^@$`"````$?Z`0`,````
M4/H!``@```!=^@$`(@```&;Z`0`$````B?H!`!````".^@$`0@```)_Z`0`&
M````XOH!``0```#I^@$`'P```.[Z`0`.````#OL!``\````=^P$`#@```"W[
M`0`,````//L!``D```!)^P$`!P```%/[`0`*````6_L!``D```!F^P$`#@``
M`'#[`0`0````?_L!`"4```"0^P$`)0```+;[`0`B````W/L!``H```#_^P$`
M!P````K\`0`&````$OP!``D````9_`$`"P```"/\`0`)````+_P!``4````Y
M_`$`"````#_\`0`(````2/P!``4```!1_`$`$````%?\`0!.````:/P!`!@`
M``"W_`$`"0```-#\`0`&````VOP!``,```#A_`$`$````.7\`0`0````]OP!
M`!0````'_0$`!@```!S]`0`*````(_T!``D````N_0$``@```#C]`0`$````
M._T!`",```!`_0$``P```&3]`0`%````:/T!``H```!N_0$`"@```'G]`0`&
M````A/T!``8```"+_0$`"P```)+]`0`-````GOT!``8```"L_0$`"````+/]
M`0`*````O/T!``0```#'_0$`!0```,S]`0`7````TOT!`'8```#J_0$`"P``
M`&'^`0`.````;?X!`!<```!\_@$`!````)3^`0`(````F?X!`!4```"B_@$`
M+P```+C^`0`-````Z/X!``H```#V_@$`#@````'_`0`+````$/\!``D````<
M_P$`%````";_`0`S````._\!`"@```!O_P$`)P```)C_`0`3````P/\!`!H`
M``#4_P$`#0```.__`0`#````_?\!``<````!``(``P````D``@`'````#0`"
M``0````5``(`"P```!H``@`0````)@`"``X````W``(`"0```$8``@`0````
M4``"`!L```!A``(`"0```'T``@`)````AP`"``D```"1``(`"0```)L``@`/
M````I0`"``H```"U``(`30```,```@`>````#@$"``T````M`0(`"@```#L!
M`@`A````1@$"`$P```!H`0(`&0```+4!`@`%````SP$"`!\```#5`0(`+@``
M`/4!`@`'````)`("``8````L`@(`"P```#,"`@`&````/P("``<```!&`@(`
M)P```$X"`@`F````=@("`"H```"=`@(`"0```,@"`@`&````T@("``<```#9
M`@(`+P```.$"`@!5````$0,"`!4```!G`P(`)P```'T#`@`3````I0,"``(`
M``"Y`P(`#````+P#`@`(````R0,"``P```#2`P(`"@```-\#`@`'````Z@,"
M``D```#R`P(`!@```/P#`@`&`````P0"``D````*!`(`!0```!0$`@`(````
M&@0"``P````C!`(`"````#`$`@`3````.00"`!4```!-!`(`#@```&,$`@`0
M````<@0"``D```"#!`(`"````(T$`@`R````E@0"``<```#)!`(`#P```-$$
M`@`1````X00"`!````#S!`(`"@````0%`@`.````#P4"``P````>!0(`"@``
M`"L%`@`*````-@4"``H```!!!0(`"@```$P%`@`'````5P4"``X```!?!0(`
M'````&X%`@`W````BP4"``<```##!0(`"@```,L%`@`4````U@4"``X```#K
M!0(`#P```/H%`@`6````"@8"``H````A!@(`$````"P&`@`'````/08"`!@`
M``!%!@(`!````%X&`@`'````8P8"``4```!K!@(`!````'$&`@`.````=@8"
M``4```"%!@(`#0```(L&`@`7````F08"``\```"Q!@(`%@```,$&`@`9````
MV`8"`!<```#R!@(`'`````H'`@`6````)P<"``<````^!P(`!@```$8'`@`.
M````30<"``L```!<!P(`"P```&@'`@`7````=`<"``8```",!P(`'````),'
M`@`+````L`<"`$0```"\!P(`#0````$(`@`B````#P@"`!H````R"`(`%0``
M`$T(`@`'````8P@"``T```!K"`(`!0```'D(`@`/````?P@"`!````"/"`(`
M"0```*`(`@`+````J@@"``L```"V"`(`"````,((`@`)````RP@"`!,```#5
M"`(`"P```.D(`@`&````]0@"``D```#\"`(`!0````8)`@`'````#`D"``0`
M```4"0(`!````!D)`@`#````'@D"`!$````B"0(`"P```#0)`@`.````0`D"
M`#L```!/"0(`,P```(L)`@`2````OPD"`"\```#2"0(`,@````(*`@`G````
M-0H"``X```!="@(`/````&P*`@`O````J0H"`#0```#9"@(`-`````X+`@`X
M````0PL"`!(```!\"P(`$P```(\+`@`8````HPL"``\```"\"P(`%P```,P+
M`@`3````Y`L"`#8```#X"P(`'0```"\,`@`5````30P"`!(```!C#`(`$@``
M`'8,`@`;````B0P"`!,```"E#`(`%0```+D,`@`:````SPP"`"X```#J#`(`
M+@```!D-`@`R````2`T"`"\```![#0(`,````*L-`@`M````W`T"`!T````*
M#@(`$P```"@.`@`4````/`X"`!````!1#@(`"P```&(.`@`9````;@X"``H`
M``"(#@(`#P```),.`@`L````HPX"`"X```#0#@(`(@```/\.`@`<````(@\"
M``L````_#P(`50```$L/`@!&````H0\"``X```#H#P(`!0```/</`@`<````
M_0\"``P````:$`(`$````"<0`@`2````.!`"``4```!+$`(`"@```%$0`@`)
M````7!`"``\```!F$`(`#0```'80`@`1````A!`"``H```"6$`(`"P```*$0
M`@`,````K1`"`"````"Z$`(``P```-L0`@`-````WQ`"``@```#M$`(``@``
M`/80`@`&````^1`"``P`````$0(`#@````T1`@`+````'!$"`$(````H$0(`
M`@```&L1`@`&````;A$"``T```!U$0(`!0```(,1`@`'````B1$"`!D```"1
M$0(`!@```*L1`@`N````LA$"`!````#A$0(`'0```/(1`@`$````$!("``,`
M```5$@(`,@```!D2`@`9````3!("`!D```!F$@(`*@```(`2`@`<````JQ("
M`"````#($@(`60```.D2`@`4````0Q,"`$<```!8$P(`&0```*`3`@`.````
MNA,"``8```#)$P(`&@```-`3`@`<````ZQ,"``T````(%`(`%````!84`@`.
M````*Q0"``P````Z%`(`$@```$<4`@`*````6A0"`!P```!E%`(`&0```((4
M`@`%````G!0"`!,```"B%`(`"````+84`@`%````OQ0"`!````#%%`(`"0``
M`-84`@`F````X!0"`!,````'%0(`%0```!L5`@`2````,14"`!$```!$%0(`
M&0```%85`@`'````<!4"``@```!X%0(``@```($5`@`3````A!4"``X```"8
M%0(`$@```*<5`@`/````NA4"`!H```#*%0(`#P```.45`@`:````]14"`!0`
M```0%@(`"0```"46`@`*````+Q8"``@````Z%@(`!0```$,6`@`)````218"
M``8```!3%@(`$````%H6`@`(````:Q8"``X```!T%@(`"````(,6`@`2````
MC!8"`!(```"?%@(`*````+(6`@`8````VQ8"``D```#T%@(`"@```/X6`@`9
M````"1<"`!,````C%P(`"@```#<7`@`B````0A<"``8```!E%P(`!P```&P7
M`@`8````=!<"``D```"-%P(`!P```)<7`@`:````GQ<"`"L```"Z%P(`&P``
M`.87`@`*`````A@"`!\````-&`(`#0```"T8`@`,````.Q@"`!D```!(&`(`
M%0```&(8`@`$````>!@"``<```!]&`(`#````(48`@`'````DA@"``4```":
M&`(`"````*`8`@`&````J1@"``@```"P&`(`&````+D8`@`F````TA@"`"T`
M``#Y&`(`&@```"<9`@`@````0AD"`!\```!C&0(`1````(,9`@`<````R!D"
M`!T```#E&0(`)`````,:`@!;````*!H"`%L```"$&@(`2@```.`:`@`B````
M*QL"`!<```!.&P(`!0```&8;`@`'````;!L"``X```!T&P(`$P```(,;`@`(
M````EQL"`!<```"@&P(`&0```+@;`@`/````TAL"`"X```#B&P(`"````!$<
M`@`B````&AP"`!@````]'`(`'P```%8<`@`[````=AP"``4```"R'`(`%0``
M`+@<`@`+````SAP"``\```#:'`(`(P```.H<`@`.````#AT"`!`````='0(`
M#@```"X=`@`8````/1T"`!$```!6'0(`#@```&@=`@`'````=QT"`!(```!_
M'0(`!P```)(=`@`$````FAT"``T```"?'0(`%0```*T=`@`8````PQT"`"\`
M``#<'0(`"P````P>`@`1````&!X"``4````J'@(`!0```#`>`@`%````-AX"
M`!P````\'@(`"P```%D>`@`$````91X"``L```!J'@(`"0```'8>`@`*````
M@!X"``P```"+'@(`#0```)@>`@`7````IAX"``L```"^'@(``P```,H>`@`/
M````SAX"`#D```#>'@(`2@```!@?`@`-````8Q\"``H```!Q'P(`&0```'P?
M`@`8````EA\"`!@```"O'P(`$0```,@?`@`1````VA\"`!,```#L'P(`$P``
M```@`@`0````%"`"`!P````E(`(`"0```$(@`@`@````3"`"`!,```!M(`(`
M!0```($@`@`1````AR`"``@```"9(`(`"P```*(@`@`G````KB`"``X```#6
M(`(`#@```.4@`@`/````]"`"``P````$(0(`&@```!$A`@`C````+"$"``<`
M``!0(0(`"@```%@A`@`1````8R$"``T```!U(0(`#@```(,A`@`3````DB$"
M`!D```"F(0(`"P```,`A`@`S````S"$"``<`````(@(`(`````@B`@`1````
M*2("`!4````[(@(`>P```%$B`@`-````S2("`!P```#;(@(`00```/@B`@`S
M````.B,"``@```!N(P(`,````'<C`@`L````J","``T```#5(P(`-@```.,C
M`@`W````&B0"`#````!2)`(`%P```(,D`@`3````FR0"`!8```"O)`(`"0``
M`,8D`@`2````T"0"`!(```#C)`(`(0```/8D`@`$````&"4"`!@````=)0(`
M"````#8E`@`;````/R4"`!(```!;)0(`!P```&XE`@`7````=B4"`"(```".
M)0(`!0```+$E`@`%````MR4"``L```"])0(`"P```,DE`@`4````U24"``0`
M``#J)0(`"````.\E`@`*````^"4"``X````#)@(`#````!(F`@`0````'R8"
M`!`````P)@(`!@```$$F`@`&````2"8"`"L```!/)@(`(P```'LF`@`@````
MGR8"``,```#`)@(`"````,0F`@`&````S28"``\```#4)@(`&P```.0F`@`G
M`````"<"``\````H)P(`"````#@G`@`A````02<"``,```!C)P(`!@```&<G
M`@`)````;B<"``(```!X)P(`#````'LG`@`5````B"<"``L```">)P(`&0``
M`*HG`@`>````Q"<"`!$```#C)P(`!0```/4G`@`*````^R<"`!4````&*`(`
M$@```!PH`@`&````+R@"``P````V*`(`!0```$,H`@`*````22@"``@```!4
M*`(`#````%TH`@`/````:B@"``4```!Z*`(`$P```(`H`@!,````E"@"`!T`
M``#A*`(`)0```/\H`@`1````)2D"``D````W*0(``P```$$I`@`-````12D"
M``H```!3*0(`"P```%XI`@`A````:BD"``H```",*0(`(0```)<I`@`.````
MN2D"`!D```#(*0(`#0```.(I`@`+````\"D"`!T```#\*0(`"0```!HJ`@`6
M````)"H"``\````[*@(`#P```$LJ`@!-````6RH"``H```"I*@(`(0```+0J
M`@`K````UBH"`&`````"*P(`&@```&,K`@`1````?BL"`!(```"0*P(`'@``
M`*,K`@`7````PBL"`!L```#:*P(`'0```/8K`@`8````%"P"`!`````M+`(`
M(P```#XL`@`<````8BP"`!@```!_+`(`,````)@L`@`5````R2P"`!D```#?
M+`(`'````/DL`@`5````%BT"``H````L+0(`2@```#<M`@`9````@BT"`$@`
M``"<+0(`!P```.4M`@`(````[2T"``D```#V+0(`%@`````N`@`+````%RX"
M`#,````C+@(`%@```%<N`@`8````;BX"``D```"'+@(`!````)$N`@`.````
MEBX"`$D```"E+@(`'0```.\N`@`/````#2\"`#X````=+P(`-@```%PO`@`Y
M````DR\"`%L```#-+P(`!0```"DP`@`T````+S`"`"4```!D,`(`#````(HP
M`@`4````ES`"`!````"L,`(`$0```+TP`@`&````SS`"``X```#6,`(`-@``
M`.4P`@`$````'#$"``T````A,0(`'P```"\Q`@`^````3S$"`$P```".,0(`
M)0```-LQ`@`R`````3("`"L````T,@(`(````&`R`@`I````@3("``L```"K
M,@(`)````+<R`@`A````W#("`"(```#^,@(`'@```"$S`@`7````0#,"`!,`
M``!8,P(`$P```&PS`@`B````@#,"`"H```"C,P(`$````,XS`@`&````WS,"
M``T```#F,P(`"P```/0S`@`1`````#0"``D````2-`(`+P```!PT`@`,````
M3#0"``H```!9-`(`"````&0T`@`0````;30"``<```!^-`(`"0```(8T`@`'
M````D#0"`!````"8-`(`"0```*DT`@`)````LS0"``,```"]-`(`!P```,$T
M`@`)````R30"`!````#3-`(`#@```.0T`@`)````\S0"`!H```#]-`(`#```
M`!@U`@`'````)34"`!$````M-0(`%@```#\U`@`*````5C4"``D```!A-0(`
M(@```&LU`@`0````CC4"`",```"?-0(`*P```,,U`@`)````[S4"``D```#Y
M-0(`%P````,V`@`'````&S8"``0````C-@(`'0```"@V`@`)````1C8"``L`
M``!0-@(`"````%PV`@`'````938"``D```!M-@(`"P```'<V`@`(````@S8"
M``D```",-@(`!0```)8V`@`*````G#8"``H```"G-@(`"````+(V`@`'````
MNS8"``<```##-@(`$0```,LV`@`&````W38"``X```#D-@(`"@```/,V`@`,
M````_C8"``L````+-P(`&P```!<W`@`*````,S<"``(````^-P(`(0```$$W
M`@`&````8S<"``8```!J-P(`<P```'$W`@`(````Y3<"``8```#N-P(`&P``
M`/4W`@`G````$3@"``\````Y.`(`'0```$DX`@!(````9S@"`!P```"P.`(`
M'P```,TX`@`2````[3@"``@`````.0(`!0````DY`@`/````#SD"``H````?
M.0(`"@```"HY`@`&````-3D"``8````\.0(`"@```$,Y`@`2````3CD"``P`
M``!A.0(`"@```&XY`@`,````>3D"``<```"&.0(`!P```(XY`@`(````ECD"
M``D```"?.0(`%@```*DY`@`)````P#D"``<```#*.0(`!P```-(Y`@`:````
MVCD"``8```#U.0(`%P```/PY`@`&````%#H"``<````;.@(`%0```",Z`@`)
M````.3H"`!````!#.@(`!P```%0Z`@`&````7#H"`!,```!C.@(`$0```'<Z
M`@`3````B3H"``8```"=.@(`!@```*0Z`@`*````JSH"``@```"V.@(`!```
M`+\Z`@`)````Q#H"``0```#..@(`#0```-,Z`@`B````X3H"``H````$.P(`
M#`````\[`@`I````'#L"`!<```!&.P(`%@```%X[`@`*````=3L"`!L```"`
M.P(`%@```)P[`@`$````LSL"``L```"X.P(`#0```,0[`@`'````TCL"``(`
M``#:.P(`#@```-T[`@`(````[#L"`"(```#U.P(`'P```!@\`@!%````.#P"
M`",```!^/`(`(````*(\`@`U````PSP"`"$```#Y/`(`)P```!L]`@`K````
M0ST"`&0```!O/0(`$@```-0]`@`A````YST"`!<````)/@(`&````"$^`@`N
M````.CX"`!@```!I/@(`(````((^`@`A````HSX"`#X```#%/@(`(P````0_
M`@!/````*#\"`$@```!X/P(`)@```,$_`@`_````Z#\"`"D````H0`(`-P``
M`%)``@`Q````BD`"`#H```"\0`(`(0```/=``@`I````&4$"`"\```!#00(`
M+@```'-!`@`G````HD$"`"<```#*00(`(0```/)!`@`V````%$("`#8```!+
M0@(`&P```()"`@`1````GD("`!8```"P0@(`2P```,="`@!P````$T,"`#@`
M``"$0P(`*@```+U#`@`U````Z$,"`&(````>1`(`5````(%$`@`K````UD0"
M`%L````"10(`'````%Y%`@`/````>T4"`"$```"+10(`%@```*U%`@`5````
MQ$4"`"T```#:10(`'`````A&`@`;````)48"`"T```!!1@(`'0```&]&`@`]
M````C48"`!D```#+1@(`#0```.5&`@`N````\T8"`"<````B1P(`-@```$I'
M`@`I````@4<"`!P```"K1P(`)@```,A'`@`@````[T<"`#8````02`(`4```
M`$=(`@`Q````F$@"`$,```#*2`(`+`````Y)`@`C````.TD"`#<```!?20(`
M8P```)=)`@!,````^TD"`"````!(2@(`+````&E*`@`S````EDH"`"\```#*
M2@(`'@```/I*`@`@````&4L"`"$````Z2P(`(````%Q+`@`T````?4L"`%\`
M``"R2P(`*@```!),`@!1````/4P"`#<```"/3`(`/````,=,`@`_````!$T"
M`!T```!$30(`*@```&)-`@`:````C4T"`"@```"H30(`+0```-%-`@`M````
M_TT"`!4````M3@(`@P```$-.`@!W````QTX"`(`````_3P(`R````,!/`@`9
M````B5`"`",```"C4`(`+@```,=0`@`G````]E`"`$<````>40(`(@```&91
M`@!0````B5$"`!<```#:40(`)````/)1`@`.````%U("`!,````F4@(`00``
M`#I2`@`D````?%("`"X```"A4@(`)P```-!2`@`D````^%("`#H````=4P(`
M!````%A3`@`'````75,"``<```!E4P(``P```&U3`@`*````<5,"``\```!\
M4P(`"@```(Q3`@`'````EU,"``D```"?4P(`"````*E3`@`&````LE,"``4`
M``"Y4P(`$0```+]3`@`$````T5,"`%L```#64P(`!````#)4`@`/````-U0"
M``0```!'5`(`!P```$Q4`@`'````5%0"``4```!<5`(``P```&)4`@`0````
M9E0"``X```!W5`(`$P```(94`@`1````FE0"``(```"L5`(`!@```*]4`@`(
M````ME0"``<```"_5`(`%````,=4`@`,````W%0"`!8```#I5`(`!@````!5
M`@`#````!U4"``\````+50(`"@```!M5`@`#````)E4"`"@````J50(`!```
M`%-5`@`&````6%4"``<```!?50(`%P```&=5`@!(````?U4"`"D```#(50(`
M+````/)5`@`7````'U8"`"4````W5@(`)@```%U6`@`I````A%8"`!T```"N
M5@(`&@```,Q6`@`9````YU8"`!L````!5P(`&````!U7`@`7````-E<"`!T`
M``!.5P(`&P```&Q7`@`8````B%<"`"<```"A5P(`&````,E7`@`8````XE<"
M`"<```#[5P(`%0```"-8`@`C````.5@"`!D```!=6`(`'0```'=8`@`;````
ME5@"`!@```"Q6`(`'@```,I8`@`B````Z5@"`!T````,60(`)@```"I9`@`B
M````45D"`!@```!T60(`&@```(U9`@`E````J%D"`!<```#.60(`(0```.99
M`@`P````"%H"`#,````Y6@(`$P```&U:`@`F````@5H"`!X```"H6@(`/@``
M`,=:`@`?````!EL"`",````F6P(`(0```$I;`@`D````;%L"`!X```"16P(`
M,P```+!;`@`8````Y%L"`"$```#]6P(`(````!]<`@`S````0%P"`"(```!T
M7`(`-P```)=<`@`,````SUP"``\```#<7`(`&0```.Q<`@`I````!ET"`!\`
M```P70(`$````%!=`@`B````85T"``\```"$70(`%0```)1=`@`.````JET"
M`!````"Y70(`&P```,I=`@`'````YET"``4```#N70(`*0```/1=`@`D````
M'EX"`!<```!#7@(`(@```%M>`@`D````?EX"``<```"C7@(`U````*M>`@`,
M````@%\"`!L```"-7P(`%````*E?`@`)````OE\"``P```#(7P(`'````-5?
M`@`3````\E\"`!$````&8`(`#P```!A@`@`;````*&`"``D```!$8`(`,@``
M`$Y@`@`(````@6`"`!````"*8`(`!P```)M@`@`2````HV`"``H```"V8`(`
M-@```,%@`@`)````^&`"`"0````"80(`%@```"=A`@`2````/F$"`!4```!1
M80(`%````&=A`@`F````?&$"`!P```"C80(`#````,!A`@`<````S6$"``T`
M``#J80(`#@```/AA`@`5````!V("``H````=8@(`&````"AB`@`(````06("
M`"D```!*8@(`"0```'1B`@`/````?F("`"H```".8@(`!@```+EB`@`5````
MP&("``<```#68@(`"````-YB`@`)````YV("`#L```#Q8@(`!P```"UC`@`0
M````-6,"`!(```!&8P(`$@```%EC`@`)````;&,"``L```!V8P(`!P```()C
M`@`5````BF,"``<```"@8P(`"````*AC`@`7````L6,"``L```#)8P(`#0``
M`-5C`@`,````XV,"`!<```#P8P(`&0````AD`@`$````(F0"``4````G9`(`
M&0```"UD`@`$````1V0"`"P```!,9`(`#````'ED`@`1````AF0"``<```"8
M9`(``@```*!D`@`,````HV0"``X```"P9`(`"P```+]D`@`$````RV0"``D`
M``#09`(`$P```-ID`@`6````[F0"``8````%90(`!0````QE`@`(````$F4"
M``D````;90(`"````"5E`@`5````+F4"``D```!$90(`$0```$YE`@`-````
M8&4"`!D```!N90(`&@```(AE`@`-````HV4"`#(```"Q90(`'@```.1E`@`C
M`````V8"`%<````G9@(`6@```']F`@`7````VF8"``L```#R9@(`,P```/YF
M`@`%````,F<"`!$````X9P(`0@```$IG`@`+````C6<"``H```"99P(`!@``
M`*1G`@`$````JV<"``0```"P9P(`"@```+5G`@`4````P&<"``4```#59P(`
M!@```-MG`@`&````XF<"``H```#I9P(`!@```/1G`@`.````^V<"``\````*
M:`(`"P```!IH`@`T````)F@"`"H```!;:`(`)P```(9H`@`%````KF@"`!X`
M``"T:`(`#@```--H`@`"````XF@"``0```#E:`(`"@```.IH`@`"````]6@"
M``4```#X:`(`%````/YH`@`%````$VD"``(````9:0(`$0```!QI`@!#````
M+FD"`"X```!R:0(`)P```*%I`@`G````R6D"`!@```#Q:0(`(P````IJ`@!"
M````+FH"`",```!Q:@(`)@```)5J`@!V````O&H"`#@````S:P(`1@```&QK
M`@`S````LVL"`#4```#G:P(`#P```!UL`@`D````+6P"`"P```!2;`(`*```
M`']L`@`X````J&P"`%X```#A;`(`(````$!M`@!'````86T"`"0```"I;0(`
M00```,YM`@`H````$&X"`"P````Y;@(`'@```&9N`@`J````A6X"`#````"P
M;@(`,0```.%N`@`U````$V\"`#0```!);P(`*@```'YO`@`D````J6\"`"H`
M``#.;P(`00```/EO`@!#````.W`"`#\```!_<`(`-0```+]P`@`R````]7`"
M`!`````H<0(`$0```#EQ`@`/````2W$"`&P```!;<0(`"0```,AQ`@"I````
MTG$"`%\```!\<@(`=P```-QR`@`N````5',"`%@```"#<P(`%0```-QS`@`5
M````\G,"`",````(=`(`%P```"QT`@`7````1'0"`!L```!<=`(`'P```'AT
M`@`Y````F'0"`",```#2=`(`(P```/9T`@!8````&G4"`!H```!S=0(`$@``
M`(YU`@`+````H74"``4```"M=0(`!@```+-U`@`(````NG4"``4```##=0(`
M$@```,EU`@`,````W'4"`!0```#I=0(`'@```/YU`@`2````'78"``X````P
M=@(`#P```#]V`@`%````3W8"``T```!5=@(`!````&-V`@`)````:'8"``L`
M``!R=@(`!0```'YV`@`(````A'8"``@```"-=@(`!@```)9V`@`5````G78"
M``X```"S=@(`"0```,)V`@`)````S'8"``X```#6=@(`#P```.5V`@`,````
M]78"``X````"=P(`#0```!%W`@`(````'W<"`!`````H=P(`!````#EW`@`&
M````/G<"``4```!%=P(`%P```$MW`@`%````8W<"``H```!I=P(`"0```'1W
M`@`/````?G<"`!8```".=P(`"````*5W`@`%````KG<"`!0```"T=P(`%0``
M`,EW`@`*````WW<"``8```#J=P(`#P```/%W`@`1`````7@"`!@````3>`(`
M#0```"QX`@`#````.G@"``<````^>`(`!0```$9X`@`%````3'@"`!@```!2
M>`(`#0```&MX`@`-````>7@"``@```"'>`(``P```)!X`@`9````E'@"``D`
M``"N>`(``@```+AX`@`"````NW@"``\```"^>`(`!@```,YX`@`!````U7@"
M``8```#7>`(`#P```-YX`@`7````[G@"``8````&>0(`%@````UY`@`"````
M)'D"``D````G>0(`!````#%Y`@`2````-GD"`!(```!)>0(`$````%QY`@`,
M````;7D"``P```!Z>0(`$0```(=Y`@`'````F7D"``T```"A>0(`!@```*]Y
M`@`,````MGD"``@```##>0(`&@```,QY`@`/````YWD"`!(```#W>0(``@``
M``IZ`@`'````#7H"``D````5>@(`#0```!]Z`@`/````+7H"`"L````]>@(`
M!````&EZ`@`'````;GH"``L```!V>@(`$P```()Z`@`%````EGH"``X```"<
M>@(``@```*MZ`@`+````KGH"``4```"Z>@(`"0```,!Z`@`&````RGH"``(`
M``#1>@(``0```!P)````````R0```.P$``"Y`@``M0$``!L'``#C!```````
M````````````RP```)8%``#$!0``<@8````````0`@```````/4(``"6!P``
M$0$``-`$````````3P(```````#Q`@``H0$``&(````D!0``<@<``(P&``!&
M!P``7P<``,@````E"0```````'8"```#`P```````"X%``!7!@``.@,`````
M``!P`@``\`,``#@!```*`0```````"<```"!!```Q0@```````#*`P``%`<`
M`!,"```Z`0``>P8``$,$``!'"```B`@```````!O`@``4@<```````":!```
M`````*`````C"```[@$``-<'``!)````MP@```````#Y!P````````````"6
M````NP@```````#E`P``MP0``%`"````````A@8``.(&``#="```````````
M`````````````!8!``!X!0``(`0``$P(``!Y"```I@8``&4(````````G@0`
M`)D#```X`P``[P4```,(````!```RP8``($'```7`P``'PD``"8"``#I`@``
MN`4``.<"``"6"```O`4``/$#``#1`@```````$,!````````^````/,$```\
M!```BP<``$,%```S!P``$@(``&P%````````C`$``*<'``"S!P``=0<``-((
M``"(!@``YP0``*`%``"`!@``=0``````````````CP```.@'````````````
M`&0(```J`0``(0(``#$$``#Y"```>`<```````!S````L@<``+@"``!D`0``
M?@```$X#``#H````;`0``'P(`````@``\`(````&``"*"```IP0``"8%````
M````;P4``'0#`````````````(<(```C`@``'P@``+T'``#E!P```````"H"
M```R`P```````*X!``#["```U00``*@'`````````````+`(````````N@$`
M``0&```$!```_0(``&X(```M!```TP8```````""!0```````/@(```B!P``
ME0```)`(``!U`@``N````)H'```."````````#D'``!B"```]0<``,H%``!\
M!@``[00``'\#``!'!@``N`8``*T(```3!0``-````,(%````````=@@``'`$
M``!H`P``\0$```````#A!````````-,'``"8`P``300``)@```#R!@``<`,`
M``````!Y````G04``'\%``"F!```PP(````````R!0``"`4````````%"```
M.@8```````!T!@``O0(``.H'``!=!P``B`<``!0`````````0@,```````!6
M"```+`(```````!(`0``V@(````````-````L00``!<```"5`@``_04``*,#
M``#[`@````````````#7`0``.P```#@```#@`0``'0D``#0)```)`0``````
M``````"V`P````````````!4!```_`0````````\"```%`@``'(!```("```
M<P$``-H#````````<@0``$D!``!O````]0,``!@(```S!@``:P$```````#Q
M!P``)@0```$%``#1`0``F`(``````````````````-@#``"N`P``!0,`````
M``"N`@``P@(``-T#``!,`0``A00```0(``"7`P``1P0``$D$````````,P@`
M`*8'``"T`````00``*(#```-"```VP0````````X"````````%H"``#)`0``
MUP8``&X!````````````````````````Z@4``,P&``#&`P``H@@``+4%``!L
M!@``N@@``/T````6"```2`8``%P&````````X@```-H(``!L`0``>00``(X$
M```-"0``]@(``"<#```,!```"P0``),#``"4!0``E`8``)T!``#Z!P``````
M`'L'```$`P``R`(``!P#``!%!0``F0<``"T)````````T04```````#@!@``
MB@0```````#2````@`$``#0'`````````````.8"``!M`0``Z0```/H(``!6
M!0```````,((```'!```<0(``(@!``#]!```D00``%<%``!W"```N08``"()
M```Z"0``<@@``(T"``"-"```VP4``)P&``#2!````P$``"$)``##!```````
M```````/"```/P(``/H$``#9`0``%@(```````#V!0```````%L!``"O!@``
M>P$```,'``!+!0``/0@``'X'````````I`<``%(&```R`````````!$&````
M````[@,``-X%``""!```>@4``-<(``!@`````````+``````````>`(``/<(
M``#F!0``[`@``*D'``!G"````````*4&```P!```/@```"D(``#3!0``-0$`
M`.\'``!!!P```````,P!```["0``-`8``,\"````````0`4``#0(```1`P``
M#P`````````:!```````````````````\@4``)<```!3`P``+@````````!L
M"````````+X$````````K`0````````Y````Q@$``!<)```/!0```````',"
M````````3@4``+T`````````Y@````````#R`@``.P(``+T&````````*`(`
M`-`(``"8!P``9@```(D%``#3````%0```````````````````&@'``!K`P``
M```````````(`````````)4&``#9"```M@0```````#.!0``F@```,T(``#F
M`P``9P,``$L&```B"````````.\(``!!"````````#(!```.!@``N`$``.0"
M``"N"```+P4``&\$``"F`@``\P$``,$%``#S"````````-L#``#]!@``C@4`
M`-4'``!!````I`4``!@"``!.!```0`8```````#0`@``"0@``.`"``!P````
M```````(`````````P4``)\#``"(!```Y`$```````#Z!0`````````````!
M!P``O04``!4#```N`0``P`<````````O````O00``%(#``"P`0``$0(``&\'
M```%"0``G`<```````"7!0``+0@```````!#`P``9P$``!((``!&`0``>P@`
M`.,(``!I`P``(P<``,$```")`@``'`<``!4)``!4!@``3`(``,,!``"[````
M`````!<%``!@!`````````````#V!P``PP@````````V"0``&`8``#$!``#3
M"`````````8!``!I!@``6`(````````Y!0``S@$```````!H````0P``````
M```S`@````````X```"*!P``G`$``.8'``!,`P``'@4``.<%``#*!P``````
M`+0#``#K!0``@`(``)\"``"G!0```````)X"````````D@(``+P$``#?!```
M.0@``!$%``"A!0``GP<````````O!````````-T"``!@!0``"@<``"@(````
M``````````````!."`````````````"@!@```````-H'``#J"```-P$`````
M```'`@```````$@'``!*`0``*`,``.X&````````T````#8'``#2!0``8P,`
M``\!``!>!```?@(``)X(``!Q!```$@D``,<"``!``@``N`,``-H%``#!!```
MB08``+`'``"&!P``,P0``.L&``#."```YP,``!P!````````"@,``!L"````
M````'`4``````````````````!\"``"M!0``U@4```````!1!P``4P``````
M````````:@4``/<"````````'@```(8"```%`@`````````````U!```;04`
M`%X!```J!@``P`,```````"8`0``AP0``+\"``"]"```5P,```0!``"'`@``
MJ`@````````E"```7P,``$4$```M`@``708``!(!`````````````%@%``#,
M````/@D```````#K"```S@(``+`$```^!@``:@,````````G"```7@(``!D(
M```>!P```````%4```!?!0``<0<```$&``"K!```PP,```````#>!P``7@8`
M`(X#````````%`(``"(&``"&!```B@,``%L$``"H!0``!@(``!L(``!8````
M`````"P)```````````````````L````````````````````&00``($(``"#
M!@````````````"A!@``Q`<``+(&````````L@0``/<'``"K!P``A0,`````
M``!N!0``6`<``-\%```D!````````&D(````````#`8``"8#````````````
M`,D'``#7````?@0``$@```"F````C0```&D"```L!0``_@0``&H"````````
M&`,``-@!`````````````"\#``!3!0``V@0```````"*`0``_`(```````#]
M`P``C@@```,$``#^````7`(``(`#``#&````#0(``!(%``````````````8'
M``#G!P``````````````````F0``````````````^04``-$```#G"```````
M````````````!P4``%@&``"\"```%@<``#D#``````````````````#L!P``
M`````/L#``"-!0``W@$``*(&`````````````)8&``">!P```````%H%``"/
M!```A`8```$#``!X`P``S`<``.X$``!U!@``:@<```````#Q"```/@0`````
M```G!@``+0,`````````````H0<``&0&```7`@``*0D``!$)````````````
M`/<```"&`0``*P@``#("`````````@,``/`!``"+`P````````P!```)````
M?`(``(P"`````````````,T#``![````,@@`````````````4P@````````Q
M`@``4P<``"X$``#D!0``DP8```````"*!@``4@4`````````````````````
M```""```O`(``.T(``":"```$P$``(X!``"5`0``@P(````````_!@``````
M``````!7````=0@``),```!M!@``$00`````````````A@@``(T&``#.!P``
M3P$``(X``````````````.8&``">`P``5@<``#4)````````&`````````#'
M!P``FP,``,`%``!4`0````````````"=````N@(``%T`````````:@@``,`!
M``"E`0``$`@```````#X`P``:`0``"`#````````U`<``#4"``":!@``````
M`!`!````````.@(``'4!``"[`P``Q`8``(P$````````50$``/@$````````
MZ0@```````!$"```L`4``(\(`````````````"4!````````Z00``$()``#I
M!P``:P0``/H!``!0!@``)P0``*D%```O!P`````````````\"0``S`4```L`
M``"J`P````````($``````````````\#````````108```(%```=`@``JP,`
M````````````@@,``%@$``!X!`````````````!#"```Q@(``(0"``#U`@``
M30````````"W`@``_P(``"8(````````Y`,``!H%````````$P,``,`"``"^
M`0```````*,!``"W`P``'0,```H&``"^"``````````````8!```A`<`````
M``!;`@``M@@``%T$``!0!P`````````)```'"````PD``#L!``#.!@``6@0`
M````````````MP4``!X"``#,!`````````````"?````K`<``%H!````````
M$`8``"$````[!P``0@@``````````````````/('````````````````````
M`````````#L$``"'!0``1@0``%8```#?````70(``-0%``#Q!```#`D``',$
M``"\`````````),"``#-````008``(P````""0``8P@````````F"0``!`D`
M`-T!```8!P``#00``#T!``!9"```GP0```4&``#T````E`0``*0`````````
MM00`````````````/`,``)`#````````50(``"T&``""````E`(``-4`````
M`````````)H"````````+PD``,L(``"\`0``P````%8"````````W`4`````
M``#-`@``I04``(D'``#)!0``'04````````;!0```````"T'``!'!P``````
M`!L)``!@`P``90,``"D'``"1`0``J@8`````````````Q@4``%L#````````
M000``)0!```5"```*P$``(\!``"&!0``(P8``+8'``#?!P``R`4``$<```"T
M`@``W0<``#8#``"@`0```````-P$``!+`@``O@<``)T&```E`````````(4"
M`````````````,,'````````D0<````````;!@``)`(``!(&``"B!P``]08`
M`$P```"/!P``V04``,T%``#*`@``90$``"<"``"=`@``$`4``/,"```=!P``
MK`@``,$'``!E!P``1@@```````!7"```P08``$X"``!F!@```````-T````O
M`@``[04``*X%``#^!@``P@``````````````'@,````````W````-@0``/0$
M````````VP$``,`(````````"P@``)P#``"J"```.`0``%P$```0!P``_@4`
M``````#=!```;P,``,D&``#I!0``K08``/<$``!K!0``0`D``)$%```?!0``
MBP```&L`````````'P```'4%``!0!```N04``%X%``````````````@$````
M````"`8``.\!``#\!P``#0,``+<&``#L`0````````````"^!0``+@<``*L%
M````````F0(``(`'```%!```S`,``#H$```J"````````%8#``"1!@``I`8`
M``````#"!P````````````!G!```````````````````2`,``+D(```("0``
MU`8``+$!``!$`P```````'0```!D!0``YP```&$$``!%"0``=P$```````"]
M`P``NP4``#,%``"_`P``Z`4``+P#```B`@``ZP$``'D#``!$!```I@,```D&
M```\!@``WP8``/8&``!4!P``@P0``,8$``!/````SP<``&,%``!+!```Y@0`
M``````"M````U@@`````````````H`(``)(%``#!`P``!P```$$!``!B`P``
M"P$``,L"```R"0``/@4```\&``!0"```L@$``,D#````````!0<```````#.
M!```CP4```````"[!@``T@,```L#```!"````````+0%```]!0``=@<``!4$
M``!M!```1`<``,P(````````R`<``````````````````'T(````````````
M`.<&````````W`,``#0#``!\`P``RP,```,&``!]!P``!`4```@!``"3!```
M`````'L%````````K0<``-$(``#Y`0``H@$``"P&```/`@``-P8``(("``"I
M````5`,``'L"``!:"```I0,```X"``#W`P``50@```````!A"```*`4``"0(
M````````$`,``%T(``#6`0``0PD```````#H!@``Z`@``%H#``#$`0``````
M`'(```##````3P,``,@(``"\!P``FP4``*8%``")`0``,P,``"`&``!Z`P``
MSP4``.T#````````^@8``/L$````````7P8``)`%``#I`0```````)H#``!2
M"````P(``/\&```W!0``,`(``````````````````````````````````(L!
M``"T"````````/L```!E`@```````"8&``")`````````*X$```1"```1@(`
M`#(&``"O`P```````-0#``#_`P``7P````````#A!P```````&(%``!?"```
MW@@``!X&`````````````.P```!!`P``C00``(X&``"[!```````````````
M````R`$``*("``")"```5`4````%```?!P```````(D#````````:P<``*,'
M````````LP8``%@(````````?P$``/`$``"'!@``J`$``"D%``!9````>`$`
M`&T(``!*!P```````&,"```@`@```````!$```#D!@```````%T!````````
MW`$``$``````````>04``(<!``!"`````````'0!``!R`P``8`<`````````
M``````````````"J`0```````','```5`@``(P0``.(%``!S!0``^@```+,%
M``#J`P``!@D``%X'````````)`````````"6!```EP8``-L`````````:P8`
M`*H$``#M!P```````.H&````````>`@``*H%````````3P0``&T"````````
M`````"L&````````4P0``(4(``!M`P```````.H`````````/`$```````#4
M"```````````````````&0$``#`!``#^"```D`<````````G"0``*PD``.H$
M```;!```*@,``*`#``#-!```#````)4'``!;!P```P```'\$````````KP4`
M`'0'``#(`P``U`(```````#R`P``C0<``"@````P!P``"P(```\'``",!P``
ML04```````"A`P``MP$``$('`````````````((!``!Q`P``WP(``$T%````
M````80$```````#'`P``<@4```````!]!```/```````````````6P4`````
M``!9`P````````````!H`0``'P,```````#7`@````````````!I!```0`$`
M`%D"``!*````F@4``"H%```Q!0``A`,````````?!@```````)T(``!C!P``
M=`0``.0'``!B!P``V@`````````T!0``LP0``/L&``"F`0````````````"!
M!0``V`(``!8$``"L!@```````/`'``#C!P``IP```*\'``#T!0``N`0``)P%
M``!J!```-@(```````![!````````"D```"O"```QP8``'\"``"5!0``````
M``````#L!0``Q@@``)L"````````5`@``*D#``!*`P``-0,``.$"``!V!@``
M`````,\````]````#08``+D#``")!```LP(```````!^!0``-@@``&`!``!&
M````60$``/P!``"U"```80<``)(&````````%@,```````"""```QP@`````
M``"7!```!@4``,`$``!!"0```````/$```"@!P``X`,``(X"``#B!P``Y0(`
M`,4$```4"0``K`,``.4`````````;P8``+$#```."0``(0@``)H!````````
M`````+`&```````````````'````````Q0(```````"!!@``*00``#0$``"D
M"```/@@``&8$``!Y`0``*0,``!L!````````7@@``+`"``!]!0``:`(``-('
M````````L@4``+$&````````^P$``'D"``!9!P```````/D```!A!@``P0@`
M`&<&``#\!0``NP<`````````````M`$```8#``"1"```#@<``.8(``#V!```
M`````$\&``!^"````````'T!````````?`<``!$'````````"00``+`#````
M````3@$``,,&````````8`@``#,!``!Z````*P4``/D#````````CP(``"\!
M``#X!0``V0,````````*!```6`$``"X#````````2`(```````#1!```&0D`
M`/0'``!V`P``[P,`````````````X04``-\(````````M0<`````````````
MR@@``+\```"J`@``6@<``)0(```=!@``\P<``!0&````````=@```+("````
M````/@$``$`$``````````````4!``!V!0``%P8````````L`P``[@4```<#
M`````````````,0(``!'"0``>@0```\)``";!@```````.T&```A`P``N@<`
M``````!Q`0``*P0``(,!````````-@4``#4(```-!0``<0@`````````````
MO`8``/L'```_!P```@8````````!`@``LP,`````````````>0<``%8$``#Y
M!@```````$0%````````I0(``'T"``"V`0``$````+L"``!)"```7`4`````
M``"'!P``1@,``'$&``#%`0``@P<``#H'````````.0D``-0$``!#!P``4P(`
M`+8`````````D`$``-D'```%!0``10(````````(!P``Q0<``,0"```X"0``
M`````$D'```H`0``U@0``&L"````````R`0``/\`````````N@4````````)
M!P```````/($````````0@(``#L#````````?@,``*`$````````'0``````
M```L!P````````````#\````BP0``.,&````````504``-0!````````RP0`
M```````Q!@````````````!-!@``=P(``%<'`````````````.(!```L!```
MSP8``/8(```\!0``1`````````#P!@``&0,``)@$``!]`P```````#<'``">
M`0``<0```)@%``!N`@``WP$``(0(``!D!P```````,T!``#+!0``A`0``'<#
M```)!0``-@8``.T!``!_````10<``-T%```J"0``N@8`````````````H0(`
M`.0(``"X!P``!`````P%````````X0$```H)```+"0``(0<``"$&``!0````
M``````````!0`P``]P8``+$```#*`0``F0$``.($```/!```.`8``&T````0
M!````````(L(``"(!0``40$```````#W`0``````````````````````````
M```_`P````````````!N!@``R@8```0'``!.!@``8@8```L%``#'`0``8`(`
M`*0#``#;!P``2`4``/<%````````I@@``"($``#$````OP<```````"L!0``
ME0@```````!L`@``[@<``.X```"(`@``/00``$`(```,!P```````*$```#K
M````Y`0``&$%``#/`0``G00```````"`"```JP$```````#'`````````$H"
M``#5!0``:`4```L&```5!@``TP0````````"````````````````````'0$`
M`$`#```*`@```````-L&``!1!0``2@8``/0!```K`P``E`,```<&```@"0``
M`````!X)```'`0``A`4``'L#````````````````````````J@```#0!````
M`````````-<#``"Q`@``5P$```````#Z`P```````,T&``#U!0``$@,`````
M```Q`P``T0,``-@$``"_`0``/0(````````Y!```*P(``$P'``!P"```/08`
M``````!+"```30(```````#;"````````.$```";"```E@,```````!-`0``
M;`<```````!1!````````,<$``!H!@```````)$#``"``````````)X&``#H
M`P``/P$``$T(``"Q"```Q0,``'@&```_"```@P```*\"``#T!@``X`@``/\%
M``";`0``[P```"D!```,`P``80(```L'``#,`@``HP8``.4%``"9!```````
M`&<%```W"```*@`````````Q"```^`8``#\%``"3"```F`@``,4&````````
M6P8``*L&``!C!@``&@(`````````````2@@``,$!`````0``X`<``-`%````
M````A04````````!`0``5@8``($#```U!@```````!H(```U!P```````!D%
M``!5`P```````"$$``#P!0``10,``)$```#S````Y@$`````````````````
M`(L%``"2!````````$,"``!M!P``:@$``&0#````````/@,```X%``#^!P``
M-`(``/@'````````DP<````````F!P``_`8``+\(```O!@```````&4$``!A
M`P``&0````8$`````````````.D&````````X@,``&0$``#'!0```````-$&
M``"Z!````````!T$````````[`,``!`)``#K`P``IP,``#,```!'`@``T`$`
M`&8'``!9!0```````,\#``#"`0``T@$``$D)``!`!P``&0(``'`!```,"```
MR@0`````````````!0```#4%```7!P``R`8``&L(``````````````````#T
M`@``=P<``'`%``"7!P``?`$``!L#``!S`P``@0$```@"```<`@``E@(``)L$
M``"^`@``908``!\!````````%P0```````"2`0```````.,#````````(`@`
M`#D!````````E0,``(T!``!$!@``9@@``(@``````````````%<"```E`P``
M+@(```````#8"````````)8!``!3`0``^00```````"M`@``U@,``%\$``!V
M`0``Q`,```@#``"/!@```````#<$``!I````2P<``+(```#>````\@@`````
M``#P"```*`8```````#9!@``IP8``*(%````````>````$4!``!$`@``2@4`
M``````!C!```3P<``%$"```6"0``U@(```````#%````2P,``*P!``"_!```
MU0$```````#6!P```````"X)``"4!P``,`8``-D"`````````````.L'``#4
M````90```)X%```.`P``?0````````!F!0``!P<```````!+````]@$`````
M````````^0(``-@```"A!````````.<!``"O!```20(``!<(``!;"```````
M`&<````W"0```````(4'```K````A0````````#"!`````````````#T"```
MU0@``(T#```W`@``````````````````-@```-`&```O"```TP,``*D!``"`
M!```R@```/\(``"E!P``H@0``-4"``##!0````````````"H`P``,PD``+<'
M```3"0``U08``(P%``#H`@```````.4!``!<"```U@```(('```4!0``J0@`
M``````#A!@``P0(``/````!'`0``(@4``!P(````````,`,``'`&``!L````
M`````-$'````````'`0```````"2!P``%@4``'X&``",`P```````*T!````
M`````````#````"*````"@`````````B`0``"@@``+4&````````:0$``(\#
M```["```408``-@'```&````6`,``#`)````````&P```+@(````````````
M``````#M`@``RP$``$\%``!V!```/PD``$D%``#J`0``KP```#T#``"E````
M%04``"<'```&!@````````````";!P``N00``+8&``"H!```704``#<#``"'
M`P```````"H'``#^`0``T@(```````#C`0``4`$``-<$``#2!@``X@(``,\$
M``"K`@`````````````="````````+(#```"!P``M`<```````#N`@``E```
M`",#```D"0``0@8``"@)``"5!```7P(```````!)!@``\04```````"+!@``
MV00``%`%`````````````&$`````````DP4```````"#`P``A08``&H&``#>
M!@``&@,``'<$```L"```-0```)`"````````9P(``#H```#L!@``FP```.,"
M``#D````=`4``)<!````````````````````````]0$``($"```R!```.`(`
M```````^!P``+`$``%($``!_!P``HP0``*X```!R`@``J08```````#6!@``
MG@```$4```!Z!P``600```````!L`P```````"$!```"`0``%`$``*@```!-
M`P```````)@&```.!```%@8``-H!``!3!@``/@(``#$'```)"0``.P8``*\!
M``"9!@``1`$``````````````````"`'``!=`P``W`(```````#S`P``;@<`
M`%H```"K"````````#$)```Q`````````.4&``!_!@``;P@``"X(```B`P``
MO@```"@'``!W````H@```+D```!.`````````'P%``#R`````````"T!``!+
M`0```````.`````:!@``TP$`````````````%P$``!0$```E`@``/P```)P`
M```E!@``&@D``"0!``#^`@``GP4``'4$``#>`P``M0(``#`%``#0!P``````
M`.\$```&"```(`$``(`%``!,!```7````!X$``!Y!@``9@$``$0)````````
M```````````*!0```````'X!``!%"```=`@``/@"``"G`0````,``'P```#J
M`@``$@0``*P"``#.````-@$``($```"3`0``<P8``!4!``"9"```\P4``.T`
M``"T!@``508``!,&``#>!```0@$``*4(````````>@(``*,```#K`@``````
M````````````;P$```````#N"`````````````"K````;@```#`(``!:!@``
M50<``%$#```2````3`4```````!N`P``J0(`````````````=`(``-P&``"$
M````#0$``$H$``!4`@``2`@````````G!0``R0(``&,```!;`````````+D'
M``"N!P```````*,(````````/`(``!@)``#:!@``_0$````````D!P``9```
M`+,(``!E!0``&`$```````"<"```^`$``*0"```C`0```````*,"``#<"```
M`````-@%````````$P```/8#``!("0``/0<```````#L`@``*08``(8```"*
M`@``(@`````````M````'@$``&("``"Z``````````````!C`0```````+,!
M``!F`P``````````````````NP$```````#E"```3@<``.((```D!@``.0(`
M`/T'```.`0`````````````M!0````````````"9!0``D@@``.$(```X!0``
M````````````````7`$``/8`````````G0<``"H$``!)`P``500``,`&```)
M`@```````#L%``"C!0``O@,```````"W````M0```'<%``!,!@``IP(``,\(
M``````````````````"J!P``M@4``,8'``#@!```(04```$)```Z"```````
M`+H#``!!`@``M`0``&D%````````O0$``-4#``#[!0``?P@``/P(```G`0``
M`@(``!8````<!@``0@0````````@````\@$```````!S"````````)(#````
M`````````&(!``!7!```/`<``+X&``"0!````````.4$````````OP4``+8"
M```I`@``I`0````````)`P``A0$``&0"```Y!@``&@<``)T#``!Q!0``A`$`
M```````C!0``>@8`````````````C`@``/T(``"R"````````/\!```:`0``
MN0$``!4'`````````````&X$`````````````&<'````````G`0``!\$````
M````XP4``!D&```8!0``*`0``-<%``````````````````!2`0``&0<`````
M`````````````%$(````````/P0``$@$``!W!@``=0,``%$```#_!P``L0<`
M`+,`````````1@8``/H"``#$!````````/X#```-!P``````````````````
MRP<``!('``"?`0``?`0``/4$``"0`````````#H%````````7P$```````"1
M`@```````)\(``#@!0``VP(``+\&```D`P````````````#%!0``>@$``*4$
M````````1P,``(@#`````````````-D```"L`````````"4'````````*P<`
M``````""!@``EP@``````````````````*T#``"*!0``)00``%("``!!!0``
MEP(``*X&``!F`@```````.@$```3!P``R00``-X"``````````````````"#
M"````````.D#```F`0````````````"2````608`````````````%`,``*$(
M```>"````````",)`````````````*T$```F````:0<``%8!``#"`P``````
M```````$`@```````/$&``#)"```C@<```````#"!@``4@````````!-!P``
MBP(``.\"``"&`P``]0```.L$``#H`0``1@D``$,&``#.`P```````'T&``#&
M!@``WP,````````N!@``7@,```<)````````@P4```````#O!@````````P"
M````````J`8``#('``!<!P```````!P``````````````$\(``#<````````
M`$(%``````````````````#S!@``:`@``-@&``!B!````````-P'````````
M/0D```````"'`````````/\$````````1P4``!,(```:````W08``)\&``#-
M!P```````'H(```@!0``_`,``-`#```3!```X0,``%0`````````7@```/0#
M```E!0``D`8``*<(``"U`P``J00``.,````C`````````)P"``"@"```8`8`
M``````#3`@``7`,``*0!``!&!0``.`<``'`'``"H`@``:@`````@)B,Q-3$[
M("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H4F5A9"!O;FQY*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H
M=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER
M96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO
M;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U
M<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E
M9"!C86QE;F1A<G,@9F]U;F0`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N`"5D(&5V96YT<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I
M8V4`)7,@1&%Y*',I("5S($AO=7(H<RD@)7,@36EN=71E<P`E<R!&:6YG97)P
M<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!A='1E;F1E
M97,`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:&%S(&-A;F-E
M;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S
M="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N`"5S
M(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS
M*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q
M=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(')E<75E<W1S('EO
M=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R('!R
M97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@=&\@861D
M('1O("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N`"5S
M('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O
M=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.
M;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@
M;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@
M;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`*$-L
M:6-K(&]N(&-A;&5N9&%R(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S
M('9I<VEB:6QI='D@:6X@=&AE(&UA:6X@=VEN9&]W*0`J($%D9"!T:&5S92!B
M>2!C;&EC:VEN9R!!9&0@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@
M*@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@871T96YD964`,2!E=F5N=``Q(&AO
M=7(`,3(@2&]U<B!&;W)M870`,34@;6EN=71E<P`R,"!M:6YU=&5S`#(T($AO
M=7(@1F]R;6%T`#(T(&AO=7)S`#,P(&UI;G5T97,`/%!R979I;W5S`#QS=')O
M;F<^071T96YD965S/"]S=')O;F<^("AO<'1I;VYA;"D`/'-T<F]N9SY$97-C
M<FE?<'1I;VX\+W-T<F]N9SX@*&]P=&EO;F%L*0`\<W1R;VYG/DME>7=O<F1S
M/"]S=')O;F<^("AO<'1I;VYA;"D`/'-T<F]N9SY296-U<G)E;F-E/"]S=')O
M;F<^("AO<'1I;VYA;"D`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D
M(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A
M('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G
M92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!30!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN
M`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U
M="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C
M8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U
M;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%C=&EO;G,`061?=F%N8V5D(%-E87)C
M:`!!9&0`061D("5S`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES
M<VEO;@!!9&0@179E;G0`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE
M=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!296UO=&4@0V%L
M96YD87(`061D(&$@;F5W(&5V96YT`$%D9"!A(&YE=R!U<V5R.@!!9&0@871T
M96YD965S`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&AI<R!T
M;R!M>2!C86QE;F1A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@871T
M96YD965S`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N
M`$%D<P!!9'9A;F-E9"!396%R8V@`069G:&%N:7-T86X`06QA<FT`06QA<FT@
M)60@9&%Y<R!B969O<F4`06QA<FT@)60@:&]U<G,@8F5F;W)E`$%L87)M("5D
M(&UI;G5T97,@8F5F;W)E`$%L87)M("5D('=E96MS(&)E9F]R90!!;&%R;2`Q
M(&1A>2!B969O<F4`06QA<FT@,2!H;W5R(&)E9F]R90!!;&%R;2`Q(&UI;G5T
M92!B969O<F4`06QA<FT@,2!W965K(&)E9F]R90!!;&%R;2!$871E`$%L87)M
M(%-P86X@*&UI;G5T97,I`$%L87)M(%1I;64`06QB86YI80!!;&=E<FEA`$%L
M:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!='1E;F1E97,`06QL($%U
M=&AE;G1I8V%T960@57-E<G,`06QL($9U='5R90!!;&P@1W)O=7!S`$%L;"!0
M87-T`$%L;"!097)M:7-S:6]N<P!!;&P@5FES:6)L90!!;&P@9&%Y`$%L;"!D
M87D@979E;G0`06QL(&5V96YT<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT
M:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT
M97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`
M06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!
M;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@97)R;W(@;V-C=7)R
M960@9F]L;&]W:6YG('1H:7,@;&EN:SH@)7,`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!
M;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R
M`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!;GD`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!
M<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`
M07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N
M=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!
M<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N
M`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`070`071T86-H960@
M:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S
M96YT`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I
M;F9O<FUA=&EO;B!A8F]U="!T:&4@979E;G0N($EF('EO=7(@;6%I;"!C;&EE
M;G0@<W5P<&]R=',@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I
M;&4@=&\@96%S:6QY('5P9&%T92!Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V
M96YT+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD86YC
M90!!='1E;F1E97,`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R
M:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N
M=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE
M(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!=V%I=&EN
M9R!297-P;VYS90!!>F5R8F%I:F%N`$%Z=7(`0D]&2"!%>&-U<V5S`$)A8VMG
M<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N
M`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I
M8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R(%1I;64`0F%R('1I;64`
M0F%R8F%D;W,`0F%R8FEE`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@
M;F]T(&9O=6YD+@!"87-E;&EN90!"87-I8R!396%R8V@`0F5L87)U<P!"96QG
M:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C
M:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3
M971T:6YG<P!";&]C:R!4>7!E`$)L=64@36]O;@!";'5E(&%N9"!7:&ET90!"
M;VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S
M.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N
M80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y`$)R;W=N`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A
M<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<FYT($]R86YG90!"
M=7)U;F1I`$)U<WD`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#
M7V%L96YD87(`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N
M;W0@8V]M<&QE=&5D+@!#86Q?96YD87(`0V%L96YD87(`0V%L96YD87(@4W5M
M;6%R>0!#86QE;F1A<B!S=6-C97-S9G5L;'D@<'5R9V5D+@!#86QE;F1A<G,`
M0V%L96YD87)S(&UU<W0@:&%V92!A(&YA;64N`$-A;&T`0V%M8F]D:6$`0V%M
M97)O;VX`0V%M;W5F;&%G90!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T
M('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S`$-A;B=T(&-R96%T92!A(&YE=R!E=F5N="X`0V%N)W0@;W!E;B!F
M:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-A;F-E;&QE9`!#86YC96QL960Z("5S`$-A;FYO="!D96QE=&4@9FEL92`B
M)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO
M="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N
M;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@
M8VAI;&1R96X@97AI<W0N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G
M;W)?>0!#871E9V]R:65S(&%N9"!,86)E;',`0V%T96=O<GD`0V%Y;6%N($ES
M;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG
M.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L
M=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U
M8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T
M92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC
M:65S`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@66]U<B!087-S
M=V]R9`!#:&%N9V4@9&5F875L="!I9&5N=&ET>0!#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R
M9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A
M=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?
M:R!,:6YK+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W
M;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&EF('EO=2!W86YT('1O
M(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N
M=',@8GD@96UA:6PZ`$-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE
M9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S+@!#:&]O<V4@
M:68@>6]U('=A;G0@=&\@<F5C96EV92!E;6%I;"!R96UI;F1E<G,@9F]R(&5V
M96YT<R!W:71H(&%L87)M<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D<F5S<R!B;V]K<R!T;R!S
M96%R8V@@9F]R(&9R964O8G5S>2!54DQS.@!#:&]O<V4@=&AE(&-A;&5N9&%R
M<R!T;R!I;F-L=61E(&EN('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.@!#
M:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E('=H96X@9V5N97)A=&EN
M9R!F<F5E+V)U<WD@55),<SH`0VAO;W-E('EO=7(@9&5F875L="!C86QE;F1A
M<BX`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R
M>0!#;&5A<B!A;&P@871T96YD965S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A
M<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O
M($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L
M;W-E('=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H
M2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B
M;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L
M96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA('-E<&%R
M871E9"!V86QU97,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M
M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!L971E9`!#;VUP;W-E($UE
M<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC
M:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I
M9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M
M(%!A<W-W;W)D`$-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S/P!#;VYF:7)M
M960`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O
M;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F
M:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`
M0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O
M<'D@=&AE(%523"!B96QO=R!F;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO
M=7(@1G)E92]"=7-Y(%523#H`0V]R;F9L;W=E<@!#;W-T($E$`$-O<W1A(%)I
M8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z
M(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C
M:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@
M1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P
M('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L
M;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E
M<R<N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@)R5S
M)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@
M;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@;W!E;B!D
M:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S
M<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@
M=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V
M92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B
M:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD
M(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<FUD:7(@)R5S)RX`0V]U;&0@
M;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`
M0V]U;&0@;F]T('5N;&EN:R`G)7,G+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A
M8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#
M;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T
M:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#
M;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@0V%L
M96YD87(`0W)E871E(&$@3F5W($5V96YT`$-R96%T92!A(&QI;FL`0W)E871E
M(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871E9`!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`
M0W5R<F5N=`!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R
M<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N
M="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#
M=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`
M0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E=F5R>0!$
M871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C
M96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1A>2AS*0!$95]L971E`$1E7VQE
M=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L:6YE9`!$
M96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-A;&5N9&%R`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN
M:71I;VYS`$1E;&5G871E('!O<VET:6]N`$1E;&5G871E9`!$96QE=&4`1&5L
M971E("5S`$1E;&5T92!#96QL`$1E;&5T92!%=F5N=`!$96QE=&4@1W)O=7``
M1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E
M;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(&5V
M96YT(&]N;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL(&9U='5R92!O8V-U
M<F5N8V5S+"!O<B!A;&P@;V-C=7)E;F-E<S\`1&5L971E('1H92!C=7)R96YT
M(')O=P!$96QE=&4@=&AI<R!L:6YK`$1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E;GD@<F5Q=65S
M=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;@!$97-C
M<FE?<'1I;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N
M=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I
M;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_`$1I<W!L87D@0V%L96YD87)S`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES
M<&QA>2!F;W)M870`1&EV:61E<@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W
M86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U92!O;B!Y;W5R(&-A;&5N
M9&%R/P!$;V5S(&YO="!R96-U<@!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O
M;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@
M=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R
M=6=S`$1U93H@)7,`1'5R871I;VX`12U-86EL`$5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@)7,`161I="!!='1E;F1E
M97,`161I="!";&]C:P!%9&ET($-A;&5N9&%R<P!%9&ET($=R;W5P`$5D:70@
M4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@
M9F]R("5S`$5D:70@4F5M;W1E($-A;&5N9&%R<P!%9&ET(&%T=&5N9&5E<P!%
M9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<P!%9&ET(&]P=&EO;G,@9F]R.@!%
M9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R
M("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M
M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T
M8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E
M=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M
M<'1Y('-E87)C:"!T97)M<P!%;E]D`$5N9`!%;F0@1&%T90!%;F0@3VX`16YD
M(%1I;64`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@=&AE(&EM86=E
M(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<G)O<@!%<G)O
M<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H
M;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T
M:6YG(&-O;G1E;G0Z("5S`$5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N(&9O<B`E<SH@)7,`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N
M`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W<FET:6YG("(E
M<R(N`$5R<F]R('=R:71I;F<@)R5S)RX`17-T;VYI80!%=&AI;W!I80!%=&AN
M:6,`175R;W!E`$5V96YT(&%D9&5D.@!%=F5N="!D96QE=&5D.@!%=F5N="!E
M9&ET960Z`$5V96YT(&9R;VT@)7,@=&\@)7,`179E;G0@;F]T(&9O=6YD`$5V
M96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E+@!%=F5N=',@;75S="!H879E
M(&$@=&ET;&4N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M96-U=&4`17AP86YD`$5X<&%N9"!.86UE<P!%>'!A;F0@4VED96)A<@!%>'!E
M8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R="!#
M86QE;F1A<@!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`
M1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B
M)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A
M:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`
M1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD
M<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`
M1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE
M;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL
M90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I
M;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO
M860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN9`!&
M:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O
M<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U
M;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E
M+"!-971R;W!O;&ET86X`1G)E90!&<F5E+T)U<WD`1G)E92]"=7-Y($EN9F]R
M;6%T:6]N`$9R964O0G5S>2!297!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E
M+T)U<WD@4F5Q=65S="!297-P;VYS90!&<F5N8V@@1W5I86YA`$9R96YC:"!0
M;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R:61A>0!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1G5T=7)E`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M`$=A;&QE<GDZ`$=A;6)I80!'86UE`$=E;F5R86P`1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA
M;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E
M9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1V]T;R`E<P!'<F%Y<V-A
M;&4`1W)E96-E`$=R965N`$=R965N;&%N9`!'<F5N861A`$=R97D`1W)O=7`@
M061M:6YI<W1R871I;VX`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U
M<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD
M87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A;0!'=6%T96UA;&$`
M1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W0@4V5R=FEC97,`1W5E
M<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM
M`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI
M`$AE:6=H=`!(96EG:'0@*&EN('!I>&5L<RD`2&5L<`!(96QP('5S:6YG(&5D
M:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z`$AI9&4`2&ED92`E<P!(:6=H`$AO7VUE`$AO;64`2&]M
M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`
M2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D
M871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO
M(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B
M.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E
M+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G
M9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP
M92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ
M;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]U
M<BAS*0!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(
M;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@=&AE(&1A>2!A;F0@
M=V5E:R!V:65W<R!B93\`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2&]W(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@<VAO=6QD('=E(&=E;F5R871E/P!(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N
M9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T
M(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"
M969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W
M:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EF('EO=7(@
M96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP(')E<75E<W1S('EO
M=2!C86X@=7-E(&]N92!O9B!T:&4@9F]L;&]W:6YG(&QI;FMS('1O(&%C8V5P
M="!O<B!D96-L:6YE('1H92!E=F5N="X*"E1O(&%C8V5P="!T:&4@979E;G0Z
M"B5S"@I4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY.@HE<PH*5&\@
M9&5C;&EN92!T:&4@979E;G0Z"B5S`$EM86=E(%!R979I97<Z`$EM86=E(%52
M3`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A
M;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T($-A;&5N9&%R+"!3
M=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($-A;&5N9&%R
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E
M<W,`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L
M(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN
M<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R
M="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R
M="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU
M;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F
M=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`
M26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E
M`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E
M9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED($%C=&EO;B!S96QE
M8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E
M9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@
M9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@
M<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN
M=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED
M(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED
M('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT
M;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`
M27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA
M<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY
M`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S
M=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V5N>6$`2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y($9I
M;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2V5Y=V]R
M9',`2VED<P!+:7)I8F%T:0!+;VQA8@!+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%
M54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="`R-"!H;W5R<P!,
M87-T($AA;&8`3&%S="!-;V1I9FEE9`!,87-T($UO;G1H`$QA<W0@4&%S<W=O
M<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@665A
M<@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@
M;&]G:6XZ($YE=F5R`$QA<W0@=V5E:P!,871V:6$`3&%V96YD97(`3&%W`$QA
M>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,
M969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`
M3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($)L
M=64`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`
M3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@
M=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM
M97)I8VL`3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z`$QI;FL`3&EN
M:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE
M`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E
M<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]?8V%T:6]N
M`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A
M=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,
M;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E
M<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,;WEO;&$`3&]Y;VQA($)L=64`3'5X
M96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!
M9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!R96UO=&4@8V%L96YD87)S+@!-86YA9V4@=&AE
M(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W
M:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R
M:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`
M36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-
M87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA
M=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!%
M=F5N=',`36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M
M(&QE;F=T:`!-87D`36%Y;W1T90!-90!-961I8VEN90!-965T:6YG`$UE971I
M;F<@0V%N8V5L;&%T:6]N`$UE971I;F<@26YF;W)M871I;VX`365E=&EN9R!0
M<F]P;W-A;`!-965T:6YG(%)E<&QY`$UE971I;F<@57!D871E`$UE971I;F<@
M57!D871E(%)E<75E<W0`365M8F5R<P!-96YU($%L87)M<P!-96YU($QI<W0`
M365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A
M9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I
M;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T
M<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI
M9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N
M;W0@>65T(&5X<&ER960`36EN=71E*',I`$UI<G)O<@!-:7-C96QL86YE;W5S
M`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S
M<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`
M36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-
M;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U
M8FQI8R!O9@!-;VYA8V\`36]N9&%Y`$UO;F=O;&EA`$UO;G1H`$UO;G1H(%9I
M97<`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT:&QY($5V96YT<R!,:7-T
M`$UO;G1H;'DZ(%)E8W5R<R!E=F5R>0!-;VYT:',@06AE860`36]N=&AS($)E
M9F]R90!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD
M(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S
M=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W
M;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E
M('5P`$UO>F%M8FEQ=64`36]Z:6QL80!-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE(&E#86QE;F1A<B!C;VUP
M;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!V179E;G0@:7,@<W5P<&]R=&5D+@!-
M=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R
M;6%T:6]N`$UY($-A;&5N9&%R<P!->2!#86QE;F1A<G,Z`$UY($9R964O0G5S
M>2!54DP`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@
M22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE6%0`3F5E9',@
M06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S
M`$YE='-C87!E($)A<V4@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C
M87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.
M971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E
M9V]R>0!.97<@179E;G0`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`3F5W
M(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W(&-A;&5N9&%R
M(&-R96%T960@86YD(&%U=&]M871I8V%L;'D@<VAA<F5D('=I=&@@9F]L;&]W
M:6YG(&=R;W5P*',I.B`E<RX`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W
M:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`
M3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT
M(#(T(&AO=7)S`$YE>'0@-"!0:&%S97,`3F5X="!$87D`3F5X="!-;VYT:`!.
M97AT(%=E96L`3F5X="!996%R`$YE>'0@9&%Y`$YE>'0@;W!T:6]N<P!.97AT
M('=E96L`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU
M90!.;P!.;R!);F9O<FUA=&EO;@!.;R!A;&%R;0!.;R!A='1E;F1E97,`3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/
M(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-A;&5N9&%R<R!A
M<F4@879A:6QA8FQE('1O(&=U97-T<RX`3F\@8VAA;F=E+@!.;R!C:&EL9')E
M;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<V-R:7!T
M:6]N(&9O=6YD`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!E;F0@9&%T
M90!.;R!E=F5N=',@=&\@9&ES<&QA>0!.;R!F:6QE('5P;&]A9&5D`$YO(&9R
M964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S`$YO(&E#
M86QE;F1A<B!D871A('=A<R!F;W5N9"X`3F\@:6-O;G,@9F]U;F0N`$YO(&QO
M8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A
M9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E
M8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@
M<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970`3F\@<75O=&$@<V5T+@!.
M;R!R96-U<G)E;F-E`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N
M`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QI
M9"!E;6%I;"!A9&1R97-S(&9O=6YD`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N(%!A<G1I8VEP
M86YT`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)F;VQK($ES;&%N9`!.
M;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.
M;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO
M="!F;W5N9`!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E
M9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EC90!.
M;W1I9FEC871I;VYS`$YO=F5M8F5R`$YO=P!.=6UB97(`3G5M8F5R(&]F(&-H
M87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B
M97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D
M<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;@!/;B!A;&P@8V%L96YD87)S($D@
M:&%V92!R96%D(&%C8V5S<R!T;P!/;B!A;&P@<VAO=VX@8V%L96YD87)S`$]N
M(&UY(&-A;&5N9&%R<R!O;FQY`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@
M;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;F%L`$]P=&EO;F%L
M($%T=&5N9&5E<P!/<'1I;VYA;"!087)T:6-I<&%N=`!/<'1I;VYS`$]P=&EO
M;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T
M:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@
M26YF;W)M871I;VX`3W9E<G9I97<`3W=N97(`3W=N97(@4&5R;6ES<VEO;G,`
M3W=N97(Z("5S`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'
M4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!030!032!,:6=H="!2
M86EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R
M<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I
M;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN
M96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C
M:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W
M;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A
M<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T($5V96YT<R!,:7-T`%!A<W1E`%!A
M<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&%T=&5R;@!096YD:6YG(%-I9VYU
M<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M`%!E<FUA;F5N=&QY(&1E;&5T92!T:&ES(&5V96YT/P!097)M:7-S:6]N`%!E
M<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`
M4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N
M86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H
M;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R979I97<@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T86P@
M3W!T:6]N<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O
M<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S<VEB;&4@365E=&EN9R!4:6UE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M;W-T;G5K90!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0
M<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q
M=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0
M<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S($1A>0!0
M<F5V:6]U<R!7965K`%!R979I;W5S(&1A>0!0<F5V:6]U<R!O<'1I;VYS`%!R
M:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C
M<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI
M8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T
M92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@
M4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B
M;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A
M<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@
M=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G
M97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8W5R(%5N=&EL
M`%)E8W5R<F5N8V4`4F5C=7)R96YC92!$871A`%)E8W5R<F5N8V4@16YD($1A
M=&4`4F5C=7)R96YC92!);G1E<G9A;`!296-U<G)E;F-E(%1Y<&4`4F5C=7)S
M(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`4F5C=7)S('EE
M87)L>0!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!2
M96=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!296UE
M;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!296UI;F1E<CH@)7,`
M4F5M;W1E($-A;&5N9&%R<P!296UO=&4@0V%L96YD87)S.@!296UO=&4@4V5R
M=F5R<P!296UO=&4@4W5B<V-R:7!T:6]N(%523`!296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92`E<P!2
M96UO=F4@071T96YD964`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M
M;W9E(&9O<FUA='1I;F<`4F5M;W9E(&9R;VT@;7D@8V%L96YD87(`4F5M;W9E
M('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F
M<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`
M4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O<G1E9"!O
M;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R!D96QE=&5S(&%L;"!E;G1R:65S
M(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SX`4F5P;'D@4V5N
M="X`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET
M:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q
M=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DZ("5S`%)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER
M960`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D($%T=&5N9&5E<P!297%U:7)E9"!&:65L
M9`!297%U:7)E9"!087)T:6-I<&%N=`!297-E=`!297-E="!087-S=V]R9`!2
M97-E="!9;W5R(%!A<W-W;W)D`%)E<V5T('1O($1E9F%U;'1S`%)E<W!O;G-E
M`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS
M`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A
M=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2
M:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2
M;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG
M:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&
M961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`
M4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!3
M7U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V
M:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L
M9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T
M96QL:71E(%!R;W9I9&5R`%-A='5R9&%Y`%-A=61I($%R86)I80!3879E`%-A
M=F4@(B5S(@!3879E("5S`%-A=F4@07,@3F5W`%-A=F4@071T96YD965S`%-A
M=F4@179E;G0`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T
M;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@0V%L96YD87)S`%-E87)C:"!%
M;F=I;F5S`%-E87)C:"!297-U;'1S`%-E87)C:"!F;W(@8V%L96YD87)S(&-O
M;G1A:6YI;F<Z`%-E;&5C="!&:6QE<P!396QE8W0@82!C86QE;F1A<B!T;R!E
M9&ET`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C
M="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T
M;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`
M4V5L96-T(&%N(&]B:F5C=`!396QE8W0@8V%L96YD87)S('1O(&1I<W!L87DZ
M`%-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L87D@
M=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E(&1E9F%U;'0@=FEE=RX`
M4V5L96-T(&YO;F4`4V5L96-T('1H92!C86QE;F1A<B!T;R!I;7!O<G0@=&\Z
M`%-E;&5C="!T:&4@8V%L96YD87(H<RD@=&\@97AP;W)T(&9R;VT`4V5L96-T
M('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W
M+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T
M97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L
M96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F:7)S="!W965K
M9&%Y.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E
M;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!3
M96QE8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W.@!396QE8W0@=&AE('9I97<@
M=&\@9&ES<&QA>2!O;B!S=&%R='5P.@!396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RX`4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H92!P;W)T
M86PN`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD($QA=&5S="!);F9O<FUA=&EO;@!396YD
M(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F0@82!C86YC96P@;F]T:69I
M8V%T:6]N('1O(&%L;"!A='1E;F1E97,@=VAE;B!D96QE=&EN9R!T:&ES(&5V
M96YT`%-E;F0@86X@96UA:6P@=&\@)7,`4V5N9"!U<&1A=&5S+VEN=FET871I
M;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N=`!3
M96YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G
M<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A
M:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S
M<VEO;G,`4V5T`%-E="!E;F0@9&%T90!3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N`%-E="!R96-U<G)E;F-E(&5N9"!D871E`%-E="!S=&%R="!D871E`%-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S
M(&%N9"!Y;W5R(&]W;B!A;F0@;W1H97(@=7-E<G,G(&9R964O8G5S>2!O<'1I
M;VYS+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES
M<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F4@;F]T(&9O=6YD.B`E<P!3:&%R
M960@0V%L96YD87)S`%-H87)E9"!#86QE;F1A<G,Z`%-H;W!P:6YG`%-H;W)T
M(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_`%-H;W<`4VAO=R!#86QE;F1A<@!3:&]W(&-A=&5G;W)Y(&QE
M9V5N9#\`4VAO=R!D96QE=&4L(&%L87)M+"!A;F0@<F5C=7)R96YC92!I8V]N
M<R!I;B!C86QE;F1A<B!V:65W<S\`4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N+@!3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_`%-H
M;W<@9G)E92]B=7-Y(&QE9V5N9#\`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/P!3:&]W(&]N;'D@979E;G1S('1H870@:&%V92!A;B!A
M;&%R;2!S970_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P
M:6-K97(`4VAO=R!S:&%R960@8V%L96YD87)S('-I9&4M8GDM<VED93\`4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1A<VMS('5S:6YG
M(&-A=&5G;W)Y(&-O;&]R<S\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2
M;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:6UE(&]F(&1A>2!B971W965N(&5A8V@@9&%Y(&EN
M('=E96L@=FEE=W,_`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L
M>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK
M`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`
M4VEG;F%T=7)E($%L9V]R:71H;0!3:6UP;&5X`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H
M;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO
M=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O
M<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC
M80!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD
M<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P
M86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C
M;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A7W)T`%-T86YD
M87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!$871E`%-T87)T($]N`%-T87)T
M(%1I;64`4W1A<G0@>65A<@!3=&%T7W5S`%-T871E(&]R(%!R;W9I;F-E`%-T
M871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O
M=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R
M97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3
M=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`
M4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C
M97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R
M;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YD87D`
M4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T
M`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M
M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I
M='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R
M(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M
M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%13
M5B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE
M('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`
M5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E
M=#H`5&%S:W,`5&5A;`!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@
M:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO
M="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5N=&%T:79E`%1E
M;G1A=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D
M`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A4
M25,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T
M96TN`%1H92`E<R!L:6YK('1O("5S(&AA<R!B965N(')E;6]V960N`%1H92!%
M9&ET($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N($5X
M:71I;F<N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H
M92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE
M($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V%L96YD87(@(B5S(B!C86YN
M;W0@8F4@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@8W)E
M871E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@<F5N86UE9"!T;R`B)7,B+@!4:&4@
M8V%L96YD87(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&-A;&5N9&%R(&-O
M=6QD(&YO="!B92!P=7)G960Z("5S`%1H92!C86QE;F1A<B!D871A(&ES(&EN
M=F%L:60`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N
M`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BX`5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@
M<W1A<G0@9&%T92X`5&AE(&5V96YT("(E<R(@:&%S(&)E96X@861D960@=&\@
M(B5S(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%1H92!E=F5N
M="`B)7,B(&AA<R!B965N(&1E;&5T960@9G)O;2`B)7,B(&-A;&5N9&%R+"!W
M:&EC:"!W87,@;VX@)7,@870@)7,N`%1H92!E=F5N="`B)7,B(&AA<R!B965N
M(&5D:71E9"!O;B`B)7,B(&-A;&5N9&%R+"!W:&EC:"!I<R!O;B`E<R!A="`E
M<RX`5&AE(&5V96YT(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N
M`%1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL
M>2!S96YT+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I
M;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN
M9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4
M:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9O
M;&QO=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE
M(&5V96YT.@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4
M:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&EN:R!H87,@8F5E;B!R96UO
M=F5D`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@
M9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S
M96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I
M<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G
M92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S
M92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R
M(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L
M92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA
M<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE
M('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@
M8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R
M97%U97-T('=A<R!I;F-O;7!L971E+B!3;VUE('!A<F%M971E<G,@=&AA="!A
M<F4@;F5C97-S87)Y('1O(&%C8V5P="!O<B!D96-L:6YE(&%N(&5V96YT(&%R
M92!M:7-S:6YG+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@
M<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S
M<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!S<&5C:69I
M960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E
M9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D
M;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M
M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T
M;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R
M964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S
M(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&5V96YT
M<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82X`5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`
M5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET
M97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W
M87,@86X@97)R;W(@86-C97-S:6YG('1H92!C86QE;F1A<CH@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A
M<R!A;B!E<G)O<B!E9&ET:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T
M:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE
M;&0N`%1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@=&AE(&5V96YT.B`E<P!4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@86X@979E;G0@;F]T:69I8V%T
M:6]N('1O("5S.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V5R92!N;R!E=F5N
M=',@=&\@97AP;W)T+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R
M=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4
M:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN
M<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M
M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9I;&4@
M9F]R;6%T(&ES(&YO="!S=7!P;W)T960N`%1H:7,@9F]R;2!H87,@86QR96%D
M>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T
M96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:'5R<V1A>0!4:6-K971S`%1I
M;64`5&EM92!3<%]A;@!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@
M<V5L96-T:6]N`%1I;64@<W!A;@!4:6UO<BU,97-T90!4:71?;&4`5&ET;&4`
M5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`
M5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T
M;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@
M9F%L<V4`5'4`5'5E<V1A>0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S
M`%1U=F%L=0!4>7!E`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``
M55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N
M('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE("5S+R5S`%5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O
M<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B
M)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E
M<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E
M("(E<R(Z("5S`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L
M92!T;R!D96QE=&4@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E
M860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92`B)7,B.B`E<P!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R971R:65V92!F
M<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S`%5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O
M=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FAA;F1L960@8V]M<&]N96YT
M(&]F('1Y<&4Z("5S`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER
M871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO
M=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`
M56YS970@8V]L;W(`56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<P!5;G-U
M<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S
M<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&1A
M=&5D.B`E<RX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U
M9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T
M:6]N`%5S97(@26YT97)F86-E`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A
M=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S
M97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M
M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C
M=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS
M(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R
M;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E
M<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA
M8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S
M86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S
M:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!6
M97)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)
M22D`5FEE=R`E<P!6:65W($1A>0!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I97<@87,@)7,`5FEE=R!E=F5N=`!6:65W('1A<VL`5FER9VEN($ES;&%N
M9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6
M:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I
M82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&
M;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`
M5V5B`%=E8B!3:71E`%=E8F)P;&%T<V5N("T@4V]B97(`5V5B8G!L871S96X@
M+2!3;V)E<B!.15<`5V5D;F5S9&%Y`%=E96L`5V5E:R`E9`!7965K*',I`%=E
M96ML>0!7965K;'DZ(%)E8W5R<R!E=F5R>0!796QC;VUE`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H
M25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E
M;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\`5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD+"!W
M:&5N('1H97)E(&%R92!N;R!L871E<B!E=F5N=',_`%=H870@=&EM92!S:&]U
M;&0@9&%Y(&%N9"!W965K('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N
M;R!E87)L:65R(&5V96YT<S\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H
M('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED
M=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`
M5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S
M<P!7;W)K(%!H;VYE`%=O<FL@5V5E:P!7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O
M9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E9
M65D`66%H;V\A(&UA<`!996%R`%EE87)L>0!996%R;'DZ(%)E8W5R<R!E=F5R
M>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%
M+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)
M5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@8FQO8VMS+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@979E;G1S+@!9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T
M:&4@<W!E8VEF:65D(&5V96YT+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+@!9;W4@8V%N(&]N;'D@=7-E('1H:7,@9F]R;2!F<F]M('1H
M92!%9&ET($%T=&5N9&5E<R!S8W)E96XN`%EO=2!C86YN;W0@:&%V92!T:&4@
M)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@
M96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&\@;F]T(&AA=F4@
M86X@96UA:6P@861D<F5S<R!C;VYF:6=U<F5D(&EN('EO=7(@4&5R<V]N86P@
M26YF;W)M871I;VX@3W!T:6]N<RX@66]U(&UU<W0@<V5T(&]N92`E<VAE<F4E
M<R!B969O<F4@979E;G0@;F]T:69I8V%T:6]N<R!C86X@8F4@<V5N="X`66]U
M(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E<RX`
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R!T
M:&4@<V5L96-T960@8V%L96YD87(N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S
M:6]N('1O(&1E;&5T92!T:&ES(&5V96YT+@!9;W4@9&\@;F]T(&AA=F4@<&5R
M;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N`%EO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X`66]U(&AA=F4@<W!E8VEF:65D(&%N(&EN=F%L:60@8V%L96YD
M87(N`%EO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E;F1E;F-E
M('1O('1H:7,@979E;G0N`%EO=2!H879E('-U8V-E<W-F=6QL>2!D96-L:6YE
M9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N`%EO=2!H879E('1E;G1A=&EV
M96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="X`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E
M;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C
M="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@<F5Q=65S=&5D('1O(&)E
M(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N
M9&%R<RX`66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT
M<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+@!9;W4@<F5Q=65S
M=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET960@:6X@
M>6]U<B!C86QE;F1A<G,N`%EO=2!R97%U97-T960@=&\@8F4@<F5M:6YD960@
M86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@
M4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R
M96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-A;&5N9&%R`%EO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I
M<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%M5;FYA;65D(&5V96YT70!;;&EN92`E<R!O9B`E<UT`
M7T%D;6EN:7-T<F%T:6]N`%]!;&%R;0!?0F%S:6,@4V5A<F-H`%]#3$D`7T1A
M=&%4<F5E`%]$96QE=&4@4F]W`%]%9&ET`%]';W1O`%]'<F]U<',`7TAE;'``
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQO9R!I;@!?
M3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7TUY($-A;&5N9&%R<P!?3F5W($5V
M96YT`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK
M+BXN`%]396%R8V@`7U-E='5P`%]3:&]W`%]486)L92!0<F]P97)T:65S+BXN
M`%]4;V1A>0!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N
M`&)E9F]R92!T:&4@979E;G0@<W1A<G1S`&-A;&5N9&%R`&-A;&T`8V%N;F]T
M(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H
M97)E`&-L;V-K`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T
M:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F
M;W)M870@97)R;W(`9&%Y`&1A>2AS*0!D87ES`&5D:70`96YT<GD@;F]T(&9O
M=6YD`&5V96YT<RYC<W8`979E;G1S+FEC<P!F86QL:6YG`&9I;&4`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U
M;FMN;W=N`&EM;65D:6%T90!I;@!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R
M`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R
M(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;6]N=&@H<RD`;F%M90!N
M;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`&]N
M("5S(&%T("5S`&]N('1H92!S86UE(&1A=&4`;VX@=&AE('-A;64@=V5E:V1A
M>0!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R
M;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO
M=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y
M<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`
M=7-E<B!S96QE8W0`=D-A;&5N9&%R+VE#86QE;F1A<@!V0V%R9`!V179E;G0@
M;F]T(&9O=6YD+@!W.@!W96%T:&5R+F-O;0!W965K`'=E96LH<RD@;VXZ`'=E
M96MS`'EE87(H<RD`4')O:F5C="U)9"U697)S:6]N.B!+<F]N;VQI=&@@,BXQ
M"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$T(#$P.C`V*S`Q,#`*4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-BTP,BTQ-"`Q-3HP,"LP,3`P"DQA<W0M5')A;G-L
M871O<CH@2F]A<75I;2!(;VUR:6=H875S96X@/&IO:&]`=V5B8G!L871S96XN
M<V4^"DQA;F=U86=E+51E86TZ(%-W961I<V@@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET"@`@)B,Q-3$[("5S(&MO;6UE<B!A='0@=71F]G)A(&1E('5N
M9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A=',@;F5D86XN`"`H
M)7,@9&%G87(@<V5D86XI`"`H<VYA8F)T86YG96YT("5S*0`@*%-K<FEV<VMY
M9&1A9"D`("AO;2`E<R!D86=A<BD`("AI9&%G*0`@*&EM;W)G;VXI`"`H:6?E
M<BD`(&ML(``G)7,G(.1R(&EN=&4@96X@:V%T86QO9RX`)R5S)R#D<B!I;G1E
M(&5T="!G;V1KY&YT('9A;"X`)R5S)R#D<B!I;G1E(&MO;F9I9W5R97)A="!I
M($AO<F1E<F5G:7-T<F5R="X`5'+D9&AA;G1E<F%R96X@9O9R("5S('-A:VYA
M<RX`)R5S)R!L861E<R!T:6QL(&D@9W)U<'!S>7-T96UE="X`)R5S)R!L861E
M<R!T:6QL(&D@8F5H]G)I9VAE='-S>7-T96UE="X`)R5S)R!S:V%P861E<R!I
M;G1E.B`E<RX`)2XR9DU"(&%N=N1N="!A=B`E+C)F34(@=&EL;.5T970@*"4R
M9B4E*0`E9"`E<R!O8V@@)7,`)60@:V%L96YD<F%R(&AI='1A9&5S`$1I='0@
M;/9S96YO<F0@=7!P:/9R(&%T="!GY&QL82!O;2`E9"!D86=A<BX`)60@:.1N
M9&5L<V5R`"5D+61A9W-P<F]G;F]S`"5S("T@1O9R(&OD;FYE9&]M`"5S(&1A
M9RAA<BD@)7,@=&EM;2AA<BD@)7,@;6EN=70H97(I`$9I;F=E<G!R:6YT(&;V
M<B`E<P`E<R!+0@`E<R!5;F1E<FCE;&QS9G5N:W1I;VX@+2!"96MRY&9T96QS
M90`E<R!3971U<``E<R!A;FWD;&%N`%1JY&YS=&5A=G1A;"!F]G(@)7,`)7,@
M9FEN;G,@<F5D86XN`"5S(&ML("5S("5S`"5S(&1E;'1A9V%R90`E<RUF:6QE
M;B#D<B!I;7!O<G1E<F%D`"5S(&AA<B!A;FYU;&QE<F%T("5S+@`E<R!H87(@
M<W9A<F%T('#E(&5N(&)E9^1R86X@;VT@:6YF;W)M871I;VX@86YGY65N9&4@
M;&5D:6<O=7!P=&%G96XN`"5S(&AA<B!S=F%R870@<.4@:6YB:G5D86X@=&EL
M;"`E<RX`)7,@:&%R('-K:6-K870@9&EG(&EN9F]R;6%T:6]N(&]M(&QE9&EG
M+W5P<'1A9V5N+@`E<R!K;VUM97(@871T('5T9O9R82!D92!U;F1E<FCE;&QS
M86MT:79I=&5T97)N82!S;VT@;6%R:V5R871S(&YE9&%N+B!-87)K97)A(&1E
M(&%K=&EV:71E=&5R('-O;2!D=2!V:6QL('5T9O9R82X`)7,@:W+D=G,`)7,@
M;6EN=71E<@`E<R!S86MN87,N`"5S(&5F=&5R9G+E9V%R(&EN9F]R;6%T:6]N
M(&]M(&[D<B!D=2#D<B!L961I9R]U<'!T86=E;BX`)7,@969T97)F<N5G87(@
M9&EN(&[D<G9A<F\@=FED("5S+@`E<R!T:6QL("5S(&%V("5S`"5S('9I;&P@
M;.1G9V$@=&EL;"!T:6QL("5S+@`E<R!V:6QL(&?V<F$@9&EG(&UE9'9E=&5N
M(&]M("5S+@`E<R!V:6QL(&5R:.5L;&$@9&5N('-E;F%S=&4@:6YF;W)M871I
M;VYE;B!O;2`E<RX`061R97-S8F]K(&;V<B`E<P`E<W,@:V%L96YD97(`06YT
M96-K;FEN9V%R(&;V<B`E<P!5<'!G:69T97(@9O9R("5S`"5S.B`E<P`E<SH@
M365D9&5L86YD970@:V%N<VME(&EN=&4@Y'(@9G+E;B!D96X@<V]M(&1E="!V
M97)K87(N(%9A<B!F]G)S:6MT:6<@;65D(&%T="!F]FQJ82!LY&YK87(@96QL
M97(@<VMI8VMA(&%V<^1N9&%R96X@<&5R<V]N;&EG(&EN9F]R;6%T:6]N+@`H
M2VQI8VMA('#E(&MA;&5N9&5R;F%M;F5T(&;V<B!A='0@Y&YD<F$@:V%L96YD
M97)N<R!S>6YL:6=H970@:2!H=79U9&;V;G-T<F5T*0`J($SD9V<@=&EL;"!D
M96T@:.1R(&=E;F]M(&%T="!K;&EC:V$@)TSD9V<@=&EL;"<@*@`J(%;D;&H@
M861R97-S*&5R*2`J`"P@<W1O<FUB>6%R`"P@<W1O<FUB>6%R("5S("5S`"P@
M=F%R:65R86YD92!M96QL86X@)7,@;V-H("5S`"TM(';D;&H@+2T`,2!D96QT
M86=A<F4`,2!HY&YD96QS90`Q('1I;6UE`#$R+71I;6UA<G-F;W)M870`,34@
M;6EN=71E<@`R,"!M:6YU=&5R`#(T+71I;6UA<G-F;W)M870`,C0@=&EM;6%R
M`#,P(&UI;G5T97(`/$;V<F5GY65N9&4`/'-T<F]N9SY$96QT86=A<F4\+W-T
M<F]N9SX@*'9A;&9R:2D`/'-T<F]N9SY"97-K<FE?=FYI;F<\+W-T<F]N9SX@
M*'9A;&9R:2D`/'-T<F]N9SY.>6-K96QO<F0\+W-T<F]N9SX@*'9A;&9R:2D`
M/'-T<F]N9SY5<'!R97!N:6YG/"]S=')O;F<^("AV86QF<FDI`$5N(&1A=&%B
M87-K;W!P;&EN9R!K<N1V<R!F]G(@86MT=65L;'0@8FQO8VLN`$5T="!F871A
M;'0@9F5L(&AA<B!I;G1RY&9F870`16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D
M=G,@9O9R(&%T="!K<GEP=&5R82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK
M(%!'4"UN>6-K96P@:W+D=G,@9O9R(&%T="!V97)I9FEE<F$@971T('-I9VYE
M<F%T(&UE9&1E;&%N9&4N`$5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K
M96P@<V%M="!L]G-E;F]R9"!K<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T
M(&UE9&1E;&%N9&4N`$5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@
M<V%M="!L]G-E;F]R9"!K<N1V<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E
M;&%N9&4N`$5N('!U8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M
M="!L]G-E;F]R9"!K<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E
M;&%N9&4N`$5N('!U8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M
M="!L]G-E;F]R9"!K<N1V<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N
M9&4N`$5N('!U8FQI:R!3+TU)344M;GEC:V5L(&MRY'9S(&;V<B!A='0@:W)Y
M<'1E<F$@971T(&UE9&1E;&%N9&4N`$%-`$;V<FUI9&1A9W-M;VQN`$SD='0@
M9O9R;6ED9&%G<W)E9VX`1O9R;6ED9&%G<W)E9VX`1O9R;6ED9&%G<W-K=7)A
M<@!&]G)M:61D86=S<VMU<F%R(&UE9"!S;O8`04TO4$T`05!)($E$`$]M(&5D
M:71O<FX`3VTN+BX`0F]T=&5N`$UI='1E;@!!8V-E<'1E<F$@8F5GY')A;@!!
M8V-E<'1E<F%D`$)E:/9R:6=H970@<V%K;F%S(&%T="!S:V%P82!61E,M;6%P
M<"X`0F5H]G)I9VAE="!S86MN87,@871T('-K87!A(%9&4RUF:6PN`$MO;G1O
M:6YF;W)M871I;VX`3/9S96YO<F0@9O9R(&MO;G1O`$MO;G1O="!F<GES=`!"
M=61G970`Q71GY')D97(`05]V86YC97)A9"!S]FMN:6YG`$SD9V<@=&EL;`!,
MY&=G('1I;&P@)7,`3.1G9R!T:6QL('5N9&5R9W)U<'``;.1G9R!T:6QL('5N
M9&5R8F5H]G)I9VAE=`!,Y&=G('1I;&P@:.1N9&5L<V4`3.1G9R!T:6QL(&CD
M<CH`3.1G9R!T:6QL(&YY(&=R=7!P`$SD9V<@=&EL;"!N>2!B96CV<FEG:&5T
M`$SD9V<@=&EL;"!U;F1E<F=R=7!P('1I;&P@)R5S)P!,Y&=G('1I;&P@=6YD
M97)B96CV<FEG:&5T('1I;&P@)R5S)P!,Y&=G('1I;&P@;GD@9FKD<G)K86QE
M;F1E<@!,Y&=G('1I;&P@96X@;GD@:.1N9&5L<V4`3.1G9R!T:6QL(&5N(&YY
M(&%N=N1N9&%R93H`3.1G9R!T:6QL(&1E;'1A9V%R90!,Y&=G('1I;&P@:V]L
M=6UN`$SD9V<@=&EL;"!N>6$@;65D;&5M;6%R`$SD9V<@=&EL;"!P87(`3.1G
M9R!T:6QL(&UE;GEN(&;V<B`E<R!S;VT@36]Z:6QL82!3:61E8F%R`$SD9V<@
M=&EL;"!I(&UI;B!K86QE;F1E<@!,Y&=G('1I;&P@:2!A9')E<W-B;VLZ`$SD
M9V<@=&EL;"!D96QT86=A<F4`3.1G9R!T:6QL(&D@;6EN(&%D<F5S<V)O:P!,
MY&=G('1I;&P@86YVY&YD87)E`$QA9&4@=&EL;"`G)7,G('1I;&P@<WES=&5M
M970L(&UE;B!K=6YD92!I;G1E(&SD9V=A('1I;&P@97AT<F$@(&EN9F]R;6%T
M:6]N.B`E<RX`3&%D92!T:6QL("<E<R<@=&EL;"!S>7-T96UE="X@1'4@:V%N
M(&QO9V=A(&EN(&YU+@!5<'!LY&=G(&%V(&%N=N1N9&%R92#D<B!I;F%K=&EV
M97)A="X`061R97-S`$%D<F5S<V)O:P!!9&UI;FES=')A=&EO;B`M(&%N9V4@
M8F5H]G)I9VAE="!F]G(@86YD<F$@86YVY&YD87)E`$%D;6EN:7-T<F%T:6]N
M`%)E:VQA;0!!=F%N8V5R860@<_9K;FEN9P!!9F=A;FES=&%N`$%L87)M`$%L
M87)M("5D(&1A9V%R(&EN;F%N`$%L87)M("5D('1I;6UA<B!I;FYA;@!!;&%R
M;2`E9"!M:6YU=&5R(&EN;F%N`$%L87)M("5D('9E8VMO<B!I;FYA;@!!;&%R
M;2`Q(&1A9R!I;FYA;@!!;&%R;2`Q('1I;6UA(&EN;F%N`$%L87)M(#$@;6EN
M=70@:6YN86X`06QA<FT@,2!V96-K82!I;FYA;@!!;&%R;61A='5M`%1I9"!M
M96QL86X@86QA<FT@*&UI;G5T97(I`$%L87)M=&ED`$%L8F%N:65N`$%L9V5R
M:65T`$%L:6%S`$IU<W1E<F$`2G5S=&5R:6YG.@!!;&QA`$%L;&$@9&5L=&%G
M87)E`$%L;&$@875T96YT:7-E<F%D92!A;G;D;F1A<F4`06QL82!F<F%M=&ED
M80!!;&QA(&=R=7!P97(`06QL82!T:61I9V%R90!!;&QA(&)E:/9R:6=H971E
M<@!!;&QA('-Y;FQI9V$`2&5L82!D86=E;@!(96QD86=S:.1N9&5L<V4`06QL
M82!HY&YD96QS97(`06QL82!F>7)A('-I9&]R`%1I;&SE="!F;&5R82!A9')E
M<W-E<@!4:6QLY70@:6YS=.1L;&YI;F<@9O9R('-O<G1E<F%D(&QI<W1A/P!&
M:6YN<R!R961A;@!!;'1E<FYA=&EV($E-4U`M:6YL;V=G;FEN9P!!;'1E<FYA
M=&EV="!L]G-E;F]R9"!F]G(@24U34`!!;'1E<FYA=&EV="!A;G;D;F1A<FYA
M;6X@9O9R($E-4U``06QT97)N871I=B!E+7!O<W0@861R97-S`$%L=&5R;F%T
M:78@;6%L;`!!;'1E<FYA=&EV('1E>'0Z`$%M97)I:V%N<VMA(%-A;6]A`$5T
M="!F96P@=7!P<W1O9"!NY'(@;.1N:V5N("@E<RD@<VMU;&QE(&%N=N1N9&%S
M`$5T="!F96QA:W1I9W0@=N1R9&4@86YG879S+@!%='0@;VOD;G0@9F5L(&AA
M<B!I;G1RY&9F870`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM('!R
M;WAY`%-V87(`06YT87)K=&ES`$%N=&EG=6$@;V-H($)A<F)U9&$`=FEL:V5N
M('-O;2!H96QS=`!!<'!L:6MA=&EO;@!!<'!L:6MA=&EO;G-L:7-T80!!<'!L
M:6MA=&EO;F5N(.1R(&ML87(N`%9E<FMS=.1L;"!T:6QL('5N9&5R=71D96QN
M:6YG87(`1V]D:^1N;@!5;F=E9N1R;&EG('-T;W)L96L`87!R:6P`07)A8FES
M:R`H5VEN9&]W<RTQ,C4V*0!!<FMI=F9I;'-T;W)L96L`07)K:79F:6QN86UN
M`,1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@=&$@8F]R="!B96?D<F%N(&;V
M<B`E<S\`Q'(@9&5T('/D:V5R="!A='0@9'4@=FEL;"!R861E<F$@)R5S)R!O
M8V@@979E;G1U96QL82!U;F1E<F=R=7!P97(_`$%R9V5N=&EN80!!<FUA;FEE
M;@!!<FUE;FES:R`H05)-4T-)22TX*0!+;VYS=`!!<G5B80!!<V-E;G-I;VX@
M27-L86YD`$%S8VEI(&MO;G-T`$%S:65N+U-T:6QL82!H879S<F5G:6]N96X`
M1G+E9V$@969T97(@8F5K<N1F=&5L<V4@:6YN86X@=6YD97)HY6QL<V%K=&EV
M:71E=&5R('5T9O9R<S\`5&EL;&1E;&YI;F=S:V]L=6UN`$ML`$)I9F]G860@
MY'(@96X@:4-A;&5N9&5R(&9I;"!M960@971T('-V87(@<.4@96X@8F5GY')A
M;B!S;VT@9'4@<VMI8VMA="P`16X@:4-A;&5N9&%R+69I;"!M960@;65R(&EN
M9F]R;6%T:6]N(&]M(&CD;F1E;'-E;B!H87(@8FEF;V=A=',N($]M(&1I;B!E
M+7!O<W1K;&EE;G0@<W3V9&5R(&E4:7`M9O9R9G+E9VYI;F=A<B!SY2!K86X@
M9'4@86YVY&YD82!D96X@8FEF;V=A9&5F:6QE;B!F]G(@871T(&5N:V5L="!U
M<'!D871E<F$@9&EN(&QO:V%L82!K;W!I82!A=B!HY&YD96QS96XN`$;V<G/V
M:R!T:6QL(&%T="!R861E<F$@96X@9W)U<'`@<V]M(&EN=&4@9FEN;G,N`$;V
M<G/V:R!T:6QL(&%T="!R861E<F$@96X@8F5H]G)I9VAE="!S;VT@:6YT92!F
M:6YN<RX`1O9R<_9K(&%T="#D;F1R82!E;B!B96CV<FEG:&5T('-O;2!I;G1E
M(&9I;FYS+@!&]G)S]FL@871T(.1N9')A(&5N('5T9&5L;FEN9R!S;VT@:6YT
M92!F:6YN<RX`1&5L=&%G86YD90!$96QT86=A<F4`071T<FEB=70`875G=7-T
M:0!!=7-T<F%L:65N`-9S=&5R<FEK90!!=71H7V-Y<G-Q;#H@24U!4"UE>'1E
M;G-I;VX@<V%K;F%S+@!!=71H7V-Y<G-Q;#H@2V]P<&QI;F=E;B!S86MN87(@
M9G5N:W1I;VYE<B!S;VT@:W+D=G,N`$%U=&A?8WER=7,Z($E-05`M97AT96YS
M:6]N('-A:VYA<RX`075T:%]F='`Z($944"UT:6QLY&=G('-A:VYA<RX@2V]M
M<&EL97)A(%!(4"!M960@<W=I=&-H96X@+2UE;F%B;&4M9G1P+@!!=71H7VEM
M87`Z($E-05`M97AT96YS:6]N('-A:VYA<RX`075T:%]K<F(U.B!K<F(U+65X
M=&5N<VEO;B!S86MN87,N`$%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!L
MY&=G82!T:6QL(&%N=N1N9&%R92!I($%C=&EV92!$:7)E8W1O<GD`075T:%]L
M9&%P.B!$970@9^5R(&EN=&4@871T(')A9&5R82!A;G;D;F1A<F4@9G+E;B!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@3$1!4"UT:6QLY&=G('-A:VYA
M<RX`075T:%]L9&%P.B!+86X@:6YT92!LY&=G82!T:6QL(&%N=N1N9&%R92`G
M)7,G+B!397)V97)N('-V87)A9&4Z(`!!=71H7VQD87`Z($MA;B!I;G1E(')A
M9&5R82!A;G;D;F1A<F4@)7,`075T:%]L9&%P.B!+86X@:6YT92!U<'!D871E
M<F$@86YVY&YD87)E("5S`$%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!U
M<'!D871E<F$@86YVY&YD87)E(&D@06-T:79E($1I<F5C=&]R>2X`075T:%]M
M8V%L.B!-0T%,+65X=&5N<VEO;B!S86MN87,N`$%U=&A?<VUB875T:#H@<VUB
M875T:"UE>'1E;G-I;VX@<V%K;F%S+@!!=71E;G1I<V5R:6YG('1I;&P@24U!
M4"US97)V97(@;6ES<VQY8VMA9&5S+@!!=71E;G1I<V5R:6YG(&UI<W-L>6-K
M861E<P!!=71E;G1I<V5R:6YG(&UI<W-L>6-K861E<RX@)7,`075T96YT:7-E
M<FEN9R!A=G9I<V%D97,@878@4D%$2553+7-E<G9E<FXN`$%U=&5N=&ES97)I
M;F<@=&EL;"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RX`075T96YT:7-E<FEN
M9R!T:6QL(%--0BUS97)V97(@;6ES<VQY8VMA9&5S+@!4:6QL9^1N9VQI9V$@
M9N1L=#H`5N1N=&%R('#E('-V87(`07IE<F)A:6IA;@!!>G5R8FSE`$)/1D@M
M=7)SY&MT97(`0F%K9W)U;F0`0F%K9W)U;F1S9N1R9P!&96QA:W1I9W0@;/9S
M96YO<F0@9O9R($ME<F)E<F]S`$9E;&%K=&EG="!A;G;D;F1A<FYA;6X@9O9R
M($ME<F)E<F]S`$)A:&%M87,`0F%H<F%I;@!"86QT:7-K("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)T:60`4F%D=&ED`$)A<F)A9&]S`$)A<F)I90!"
M87-K871A;&]G("<E<R<@9O9R(&)I;&1E<B!H:71T861E<R!I;G1E+@!"87-L
M:6YJ90!3]FMN:6YG`%9I=')Y<W-L86YD`$)E;&=I96X`0F5L:7IE`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`$;V9&5L<V5D86<`0FQO8VL@)R5S)R!F]G(@87!P
M;&EK871I;VX@)R5S)R!S86MN87,N`$)L;V-K:6YS=.1L;&YI;F=A<@!";&]C
M:W1Y<`!";.4@;>5N90!";.5T="!O8V@@=FET=`!&970`0F]L:79I80!";VMM
MY')K96X`4F%M`%)A;6)R961D.@!286UA<@!";W-N:65N(&]C:"!(97)Z96=O
M=FEN80!"Y61A`$)O='-W86YA`$)O='1E;@!";W5V970@27-L86YD`$)R87-I
M;&EE;@!"<FET=&ES:V$@=&5R<FET;W)I970@:2!);F1I<VMA(&]C96%N96X`
M0G)U;@!"<G5N96D`0G5L9V%R:65N`%!U;FMT;&ES=&$`0G5R:VEN82!&87-O
M`$)RY&YD($]R86YG90!"=7)U;F1I`%5P<'1A9V5N`$--4P!#4D,`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`2U]A;&5N9&5R`$-?96QL(&EN<W3D;&QN:6YG
M87(N+BX`0V%C:&5I;FET:65R:6YG(.1R(&EN=&4@9G5L;'-TY&YD:6<N`$M?
M86QE;F1E<@!+86QE;F1E<@!+86QE;F1E<G-A;6UA;F9A='1N:6YG`$MA;&5N
M9&5R;B!H87(@<F5N<V%T<RX`2V%L96YD<F%R`$MA;&5N9')A<B!MY7-T92!H
M82!E='0@;F%M;BX`3'5G;G0`2V%M8F]D:F$`2V%M97)U;@!+86UO=69L86=E
M`$MA;B!I;G1E(&YO;&QS=.1L;&$@;/9S96YO<F0@875T;VUA=&ES:W0L(&MO
M;G1A:W1A(&1I;B!A9&UI;FES=')A=/9R+@!+86X@:6YT92!S:W)I=F$@=&EL
M;"!F:6P@)R5S)P!$970@9^5R(&EN=&4@871T(&%D;6EN:7-T<F5R82!E>'1E
M<FYA('-E<W-I;VYS:&%N=&5R87)E+@!+86X@:6YT92!K;VYT86MT82!)34%0
M+7-E<G9E<FXZ("5S`$MA;B!I;G1E('-K87!A(&5N(&YY(&CD;F1E;'-E`$MA
M;B!I;G1E(/9P<&YA(&9I;"`G)7,G`$MA;F%D80!!=F)R>70`079B<GET('!R
M;V)L96UR87!P;W)T`$%V8G)U=&5N`$%V8G)U=&5N.B`E<P!+86X@:6YT92!R
M861E<F$@)R5S)RX`2V%N(&EN=&4@:&ET=&$@96X@=&5M<'+D<B!M87!P+@!+
M86X@:6YT92!F;W)T<^1T=&$@=71A;B`G;>5L9FEL)RUP87)A;65T97(N`$MA
M;B!I;G1E(')A9&5R82!M87!P("<E<R<N`$MA;B!I;G1E(')A9&5R83L@)60@
M8F%R;B!E>&ES=&5R87(N`$MA;B!I;G1E(&1I<FEG97)A(&UE9&1E;&%N9&4@
M=&EL;"!A;F=I=F5T(&YU;6UE<BX`2V%P(%9E<F1E`%)U8G)I:P!/<&5R873V
M<@!+871E9V]R7VD`2V%T96=O<FEE<B!O8V@@<G5B<FEK97(`2V%T96=O<FD`
M0V%Y;6%N($ES;&%N9',`36]B:6QT96QE9F]N`$-E;&QI;G-TY&QL;FEN9V%R
M`$-E;&QU=&9Y;&QN860Z`$-E;&QI;G-TY&QL;FEN9V%R`$-E;&QM96QL86YR
M=6TZ`$UO8FEL=&5L969O;@!#96QT:7-K("A)4T\M.#@U.2TQ-"D`0V5N=')E
M<F%D`$-E;G1R86QA9G)I:V%N<VMA(')E<'5B;&EK96X`0V5N=')A;&5U<F]P
M96ES:R`H25-/+3@X-3DM,BD`0V5R=&EF:6MA=&1E=&%L:F5R`$-E<G1I9FEK
M873D9V%R90!#97)T:69I:V%T<&]L:6-I97,`5&-H860`3W)D9O9R86YD90#$
M;F1R80#$;F1R82!D:71T(&SV<V5N;W)D`,1N9')A(&;V<G9A;&0@:61E;G1I
M=&5T`,1N9')A(&YA;6X@;V-H(&%D<F5S<R!S;VT@;6]T=&%G87)N82!S97(@
M;N1R(&1E(&SD<V5R(&]C:"!S=F%R87(@<.4@9&EN82!M961D96QA;F1E;BX`
M071T(&)Y=&$@;/9S96YO<F0@<W3V9',@:6YT92!M960@9&5N(&YU=F%R86YD
M92!K;VYF:6=U<F%T:6]N96XN("!687(@9V]D(&MO;G1A:W1A(&%D;6EN:7-T
M<F%T]G)E;BX`5&MN`$MO;G1R;VQL97)A(&SD;FLN+BX`36%R:V5R82!D92!A
M:W1I=FET971E<B!D=2!V:6QL('5T9O9R82!N=2X`0VAI;&4`2VEN80!+:6YE
M<VES:W0@9O9R96YK;&%T("A'0C(S,3(I`$MI;F5S:7-K="!T<F%D:71I;VYE
M;&QT("A":6<U*0!6Y&QJ(&%P<&QI:V%T:6]N.@!6Y&QJ(&SV<V5N;W)D`%;D
M;&H@86YVY&YD87)N86UN`%;D;&H@Y71GY')D.@!6Y&QJ(&AU<B!D871U;2!S
M:V%L;"!V:7-A<SH`5N1L:B!O;2!D=2!V:6QL(&)L:2!I;F9O<FUE<F%D(&]M
M(&YY82P@Y&YD<F%D92!E;&QE<B!R861E<F%D92!HY&YD96QS97(@=FEA(&4M
M<&]S=#H`5N1L:B!O;2!D=2!V:6QL(&)L:2!I;F9O<FUE<F%D(&]M(&YY82P@
MY&YD<F%D92!E;&QE<B!R861E<F%D92!HY&YD96QS97(@=FEA(&4M<&]S="X`
M5N1L:B!O;2!D=2!V:6QL(&)L:2!N;W1I9FEE<F%D(&]M(&YY82P@Y&YD<F%D
M92!E;&QE<B!R861E<F%D92!HY&YD96QS97(@=FEA(&4M<&]S=#H`5N1L:B!L
M:7-T<W1I;"`H9O9R('-O<G1E<F%D92!L:7-T;W(I`%;D;&H@861R97-S8F]K
M(&;V<B!S]FMN:6YG(&%V(&QE9&EG+W5P<'1A9V5N(%523#H`5N1L:B!D92!K
M86QE;F1R87(@9'4@=FEL;"!I;FML=61E<F$@:2!L:7-T;FEN9R!A=B!L961I
M9R]U<'!T86=E;CH`5N1L:B!K86QE;F1R87(@871T(&EN:VQU9&5R82!NY'(@
M;&5D:6<O=7!P=&%G96XM55),97(@<VMA<&%S.@!6Y&QJ(&1I;B!F]G)V86QD
M82!K86QE;F1E<BX`2G5L]FX`2VQA<W-D969I;FET:6]N(&;V<B`E<R!S86MN
M87,N`%)E;G-A`%)E;G-A($U33V9F:6-E+71A9V=A<@!296YS82!F<N5G80!2
M96YS82!A;&QA(&1E;'1A9V%R90!296YS82!A;G;D;F1A<F4Z("5S`%)E;G-A
M(&%N=N1D;F%R90!296YS82!A;G;D;F1A<F1A=&$`4V5N87)E('5P<&ML87)N
M86YD90!+;&EC:V$@9O9R(&%T="!F;W)T<^1T=&$`0VQI8VMA=&5L;"!V:6$@
M2%144`!3=.1N9R!F]FYS=&5R`%-TY&YG(&;V;G-T97(`36]L;@!4:61I9V$@
M;6]L;@!-;VQN:6YG=`!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!+;VUP<FEM
M97)A('-I9&]FY&QT970`2V]M<')I;65R861E(')A;6%R`$MO;&]M8FEA`$;D
M<F<`1N1R9VAA;G1E<F%R90!&Y')G=F%L`$MO;'5M;F5R.@!+;VQU;6X@<G5B
M<FEK97(`3'5S=&EG:&5T97(`2V]M;6%S97!A<F5R861E(';D<F1E;@!+;VUM
M86YD;P!+;VUM86YD;V;V;G-T97(`2V]M;65N=&%R`$YA;6X`0V]M;W)O<P!&
M]G)E=&%G`%-L=71F]G)D`%-K<FEV(&UE9&1E;&%N9&4@*"5S*0!$871O<F5R
M`%;D9&5R`%;D9&5R`$MO;F9I9W5R871I;VYS<VMI;&QN861E<@!);G-TY&QL
M;FEN9V%R(&;V<B!A='0@<WEN:W)O;FES97)A(&UE9"!H86YD9&%T;W)E<BP@
M<VUA<G1A('1E;&5F;VYE<B!O8V@@3W5T;&]O:P!+;VYF:6=U<F%T:6]N(&)E
M:/9V97(@=7!P9&%T97)A<RX`2V]N9FEG=7)E<F$@)7,`0F5K<N1F=&$@;/9S
M96YO<F0`0F5K<N1F=&$@<F%D97)I;F<@878@:.1N9&5L<V5R/P!"96MRY&9T
M860`2V]N9V\`2V]N9V\`1O9R8FEN9&5L<V4@;6ES<VQY8VMA9&5S+@!&]G)B
M:6YD96QS92!M:7-S;'EC:V%D97,Z(`!&]G)B:6YD96QS92!M960@<'5B;&EK
M(&YY8VME;'-E<G9E<B!N96MA9&5S+@!&]G)B:6YD96QS92!M960@<'5B;&EK
M(&YY8VME;'-E<G9E<B!N96MA9&5S.B`E<R`H)7,I`$;V<F)I;F1E;'-E(&UE
M9"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RX`2V]N=&%K=&5R`$MO;G1A:W1E
M<B!L861E<R!T:6QL(&D@9&EN(&%D<F5S<V)O:RX`26YN96CE;&QS='EP(&;V
M<B!K;VUP<FEM97)A9"!F:6PZ(`!);FYE:.5L;"!I("<E<R<`1F]R='/D='0`
M0V]O:R!)<VQA;F1S`$-O;VMI90!+;W!I97)A`$MO<&EE<FEN9R!M:7-S;'EC
M:V%D97,Z("5S`$MO<&EE<F$@;6%R:V5R:6YG`$MO<&EE<F$@;.1N:V5N(&YE
M9&%N(&[D<B!D=2!B96CV=F5R(&EN9G)O;6%T:6]N(&]M(&QE9&EG+W5P<'1A
M9V5N.@!-86IS8FQO;6UA`$MO<W1N861S+4E$`$-O<W1A(%)I8V$`16QF96YB
M96YS:W5S=&5N`$MA;B!I;G1E(%!'4"UK<GEP=&5R82!M961D96QA;F1E+@!+
M86X@:6YT92!01U`M:W)Y<'1E<F$@;65D9&5L86YD93H@`$MA;B!I;G1E(%!'
M4"US:6=N97)A(&UE9&1E;&%N9&4N`$MA;B!I;G1E(%!'4"US:6=N97)A(&UE
M9&1E;&%N9&4Z(`!+86X@:6YT92!3+TU)344M:W)Y<'1E<F$@;65D9&5L86YD
M92X`2V%N(&EN=&4@4R]-24U%+7-I9VYE<F$@;65D9&5L86YD92X`2V%N(&EN
M=&4@;.1G9V$@=&EL;"!K;VYT86MT+B`E<P!-:7-S;'EC:V%D97,@871T(&MO
M;G1A:W1A($Q$05`@<V5R=F5R+@!+86X@:6YT92!V97)I9FEE<F$@:V]N=&]S
M86QD;RX@)7,`2W5N9&4@:6YT92!A;G-L=71A('1I;&P@3$1!4"US97)V97(N
M`$MA;B!I;G1E(&MO;G1A:W1A('-E<G9E<B`G)7,G('9I82!&5%`Z("5S`$MA
M;B!I;G1E('-K87!A(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,`2V%N(&EN=&4@
M9&5K<GEP=&5R82!01U`M9&%T82X`2V%N(&EN=&4@9&5K<GEP=&5R82!01U`M
M9&%T83H@`$MA;B!I;G1E(&1E:W)Y<'1E<F$@4R]-24U%+61A=&$N`$MA;B!I
M;G1E(')A9&5R82!K;VYT86MT+B`E<P!+86X@:6YT92!R861E<F$@9&ES=')I
M8G5T:6]N<VQI<W1A+B`E<P!+86X@:6YT92!R861E<F$@=7!P9W)A9&5R:6YG
M<W-C<FEP="!T:6QL.B`E<RX`2V%N(&EN=&4@8F5S=.1M;6$@;6]T=&%G87)E
M;G,@95!O<W0M861R97-S+@!+86X@:6YT92!HY&UT82!K;VUP;&5T="!A9')E
M<W-B;VLN`$MA;B!I;G1E(&CD;71A(&MO;7!L971T(&1I<W1R:6)U=&EO;G-L
M:7-T82X`2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@;&ES=&$@]G9E<B!D:7-T
M<FEB=71I;VYS;&ES=&]R+@!+86X@:6YT92!L861D82!S=')A=&5G:2`G)7,G
M+@!+86X@:6YT92!L861D82!S=')A=&5G:2`G)7,G+@!+86X@:6YT92!S:V%P
M82!M87!P("<E<R<N`$MA;B!I;G1E('-K87!A(&UA<'`@)R5S)RX`2V%N(&EN
M=&4@:.1M=&$@<'5B;&EK(&YY8VME;"!F<N5N(&YY8VME;'-E<G9E<FXN`$MA
M;B!I;G1E(/9P<&YA("<E<R<@9O9R('-K<FEV:6YG+@!+86X@:6YT92#V<'!N
M82`E<RX`2V%N(&EN=&4@]G!P;F$@)R5S)R!F]G(@<VMR:79I;F<N`$MA;B!I
M;G1E(/9P<&YA($UA:6YT96YA;F-E7U1A<VL@;6]D=6P@)7,`2V%N(&EN=&4@
M]G!P;F$@;6%P<&5N("<E<R<`2V%N(&EN=&4@]G!P;F$@;6%P<"`G)7,G`$MA
M;B!I;G1E(&MO;G1A:W1A($Q$05`@<V5R=F5R+@!+86X@:6YT92!LY'-A("5S
M+@!$970@9VEC:R!I;G1E(&%T="#E=&5R<W3D;&QA(&SV<V5N;W)D970@9O9R
M(&1E;B!A;F=I=FYA(&%N=N1N9&%R96XN($[E9V]N(&5L;&5R(&[E9W)A(&%V
M('5P<&=I9G1E<FYA(.1R(&EN=&4@:V]R<F5K=&$N($;V<G/V:R!I9V5N(&5L
M;&5R(&MO;G1A:W1A(&%D;6EN:7-T<F%T]G)E;B!O;2!D=2!B96CV=F5R(&AJ
MY&QP+@!+86X@:6YT92!HY&UT82!!0TP`2V%N(&EN=&4@:.1M=&$@861R97-S
M8F]K+B`E<P!+86X@:6YT92!HY&UT82!D:7-T<FEB=71I;VYS;&ES=&$N("5S
M`$MA;B!I;G1E(&CD;71A(&1I<W1R:6)U=&EO;G-L:7-T;W(N("5S`$MA;B!I
M;G1E(&CD;71A(&1S97)V97)F=6YK=&EO;F5R`$MA;B!I;G1E(.5T97)S=.1L
M;&$@:V]N9FEG=7)A=&EO;F5N+@!+86X@:6YT92!R861E<F$@;6%P<"`G)7,G
M+@!+86X@:6YT92!R861E<F$@;6%P<"`G)7,G+@!+86X@:6YT92!S<&%R82!K
M;VYF:6=U<F%T:6]N(&;V<B`E<RX`2V%N(&EN=&4@<W!A<F$@8F%C:W5P+6MO
M;F9I9W5R871I;VXN`$MA;B!I;G1E('-P87)A(&5N(&)A8VMU<"UK;VYF:6=U
M<F%T:6]N.B`E<RX`2V%N(&EN=&4@<W!A<F$@=7!P9W)A9&5R:6YG<W-C<FEP
M="!T:6QL.B`E<RX`2V%N(&EN=&4@<W!A<F$@8F%C:W5P+6MO;F9I9W5R871I
M;VX@)7,N`$MA;B!I;G1E('-P87)A(&MO;F9I9W5R871I;VYS9FEL96X@)7,N
M($1U(&MA;B!A;G1I;F=E;B!A;G;D;F1A(&5N(&%V(&%L=&5R;F%T:79E;B!A
M='0@<W!A<F$@:V]D96X@=&EL;"`E<R!E;&QE<B!K;W!I97)A(&MO9&5N(&YE
M9&%N('1I;&P@)7,N`$MA;B!I;G1E('/V:V$@:2!,1$%0+6MA=&%L;V=E;BX`
M2V%N(&EN=&4@<F%D97)A("<E<R<N`$MA;B!I;G1E(')A9&5R82`G)7,G+@!+
M86X@:6YT92!U<'!D871E<F$@:V]N=&%K="X@)7,`2V%N(&EN=&4@=7!P9&%T
M97)A(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,`2V%N(&EN=&$@<W!A<F$@:V]N
M9FEG=7)A=&EO;B!F]G(@)R5S)SH@)7,`2V%N(&EN=&4@:&ET=&$@36]Z:6QL
M87,@<VED;V;D;'0N(%9E<FEF:65R82!A='0@<VED;V;D;'1E="#D<B#V<'!E
M="X`2V%N(&EN=&4@9V4@86YVY&YD87)E;B`G)7,G(&%N9VEV;F$@<N1T=&EG
M:&5T97(@=&EL;"!M87!P96X@)R5S)SH@)7,`4N1K;F%D('1E>'0`3&%N9`!+
M=7)S97(`4VMA<&$`4VMA<&$@:V%L96YD97(`4VMA<&$@96X@;GD@:.1N9&5L
M<V4`4VMA<&$@;.1N:P!3:V%P82!N>0!3:V%P82!U;F1E<FUA<'``4VMA<&%D
M`$)E:/9R:6=H971E<B!F]G(@Y&=A<F$`2W)E9&ET:V]R='-N=6UM97(`2W)O
M871I96X`2W5B80!!:W1U96QL`$%K='5E;&QA(#0@9F%S97(`06MT=65L;"!S
M97-S:6]N`$%K='5E;&P@=&ED`$%K='5E;&P@55),(.1R`$%K=&EV82!A;G;D
M;F1A<F4`06MT=65L;'0@=N1D97(`06MT=65L;&$@=FEL;&MO<CH@`$%K='5E
M;&P@<W1I;`!3:W+D9&1A<G-Y(&%K=&EV:71E=&5R('-O;2!K]G)S('9I9"!I
M;FQO9VYI;F<@=&EL;"`E<RX`2VQI<'`@=70`2VQI<'`@=7)V86P`0WEP97)N
M`$MY<FEL;&ES:R`H2T])."U2*0!+>7)I;&QI<VL@*%=I;F1O=W,M,3(U,2D`
M2WER:6QL:7-K+U5K<F%I;G-K("A+3TDX+54I`%1J96-K:65N`$1$`$1A9VQI
M9P!$86=L:6<Z(%5P<')E<&$@=F%R`$1A=&%4<F5E(&)LY&1D<F%R90!$871A
M8F%S=7!P<VQA9P!$871U;0!$871U;2!M;W1T86=E=`!$871U;79A;`!$86<`
M1&%G*&%R*0!?4F%D97)A`%]2861E<F$@:V]L=6UN`&1E8V5M8F5R`$1E8VEM
M86QE<@!!=F+V:G0`36EN<VMA(&EN9')A9P!&]G)V86QT`$;V<G9A;&0@:V%L
M96YD97(`1O9R=F%L9"!FY')G`$;V<G9A;&0@:61E;G1I=&5T`$;V<G9A;'0@
M<VMA;`!$969I;FET:6]N97(`1&5L96=E<F$@<&]S:71I;VX`1&5L96=E<F%D
M`%)A9&5R80!2861E<F$@)7,`4F%D97)A(&-E;&P`4F%D97)A(&CD;F1E;'-E
M`%)A9&5R82!G<G5P<`!2861E<F$@;&]G9P!2861E<F$@8F5H]G)I9VAE=`!2
M861E<F$@;V-H(')E;G-A(&UE9&1E;&%N9&5N`%)A9&5R82!C96QL`%)A9&5R
M82!K;VQU;6X`4F%D97)A(&)E9FEN=&QI9R!A;'1E<FYA=&EV;6%L;`!2861E
M<F%D92!M961D96QA;F1E;@!2861E<F$@8F5H]G)I9VAE="!F]G(@)R5S)P!2
M861E<F$@8F5H]G)I9VAE="!F]G(@)R5S)R!O8V@@=6YD97)B96CV<FEG:&5T
M97(_`%)A9&5R82!R860`4F%D97)A('9A;&0@:61E;G1I=&5T`%)A9&5R82!U
M;F1E<FUA<'!A<@!2861E<F$@86MT=65L;"!K;VQU;6X`4F%D97)A(&5N8F%R
M="!A:W1U96QL(&CD;F1E;'-E+"!A:W1U96QL('-A;70@9G)A;71I9&$@9O9R
M96MO;7-T97(@96QL97(@86QL82!F]G)E:V]M<W1E<C\`4F%D97)A(&%K='5E
M;&P@<F%D`%)A9&5R82!D96X@:.1R(&SD;FME;@!2861E<F%D92!U<'!G<F%D
M97)I;F=S<V-R:7!T970@)R5S)RX`3&5V97)A;G-T:60`1&%N;6%R:P!!=G-L
MY2!B96?D<F%N`$%V<VSE(&)E9^1R86X@;VT@;&5D:6<O=7!P=&%G96XM:6YF
M;W)M871I;VX`7T)E<VMR:79N:6YG`$)E<VMR:78@<')O8FQE;65T`$)E<VMR
M:79N:6YG`$1E=&%L:F5R("AO8VMSY2!I($AO<F1E<R!L;V=G9FEL*3H`1&5T
M86QJ97(@:&%R(&QO9V=A=',@9O9R('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BX`
M571V96-K;&EN9P!$86=G<'5N:W0`1&%G9W!U;FMT(&;V<B!S96YA<W1E('1I
M;6UE;CH@`$1A9V=P=6YK=#H@`%)I:W1N:6YG(';D;G-T97(@=&EL;"!H]F=E
M<@!2:6MT;FEN9R!H]F=E<B!T:6QL(';D;G-T97(`2V%T86QO9P!6:7-A`%9I
M<V$@,C0M=&EM;6%R<R!K;&]C:V$_`%9I<V$@:V%L96YD<F%R`%9I<VYI;F=S
M:6YS=.1L;&YI;F=A<@!6:7-A(&1E=&%L:F5R860@9O9R=71SY&=E;'-E`%9I
M<V$@9O9R=71SY&=E;'-E("A4048I`%9I<VYI;F=S9F]R;6%T`$%V<VMI;&IA
M<F4`1&II8F]U=&D`4F%D97)A(&EN=&4`06YVY&YD(&EN=&4@;6%I;G1E;F%N
M8V4N<&AP(&1I<F5K=`!6:6QL(&1U('9I<V$@=7!P9VEF=&5R('-O;2#D<B!K
M;&%R82!I(&1I;B!K86QE;F1E<C\`57!P<F5P87,@:6YT90!);FYE:.5L;&5R
M(&;V<G-T82!R861E;B!FY&QT;F%M;F5N/R!/;2`G:F$G+"!M87)K97)A(&CD
M<CH`1&]M:6YI:V%N<VMA(')E<'5B;&EK96X`2&%R(&1U(&EN9V5T(&MO;G1O
M/R!296=I<W1R97)A(&1I9RX`2.1M=&$`2.1M=&$@)7,`2.1M=&$@9V5N97)E
M<F%D(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I<'0N`$1R;W!P;&ES=&$`
M1')O9V5R`$ML87(Z("5S`%9A<F%K=&EG:&5T`$4M<&]S=`!$<FEV<G5T:6X@
M9O9R($4M<&]S="!T:6QL(%--4RUB<GEG9V$[(&;V<B!O<&5R873V<F5R('-O
M;2!T:6QL:&%N9&%HY6QL97(@9&5N;F$@=&KD;G-T+@!&14P`16MU861O<@#$
M;F1R80#$;F1R82`E<P#$;F1R82!D96QT86=A<F4`Q&YD<F$@8FQO8VL`4F5D
M:6=E<F$@:V%L96YD<F%R`,1N9')A(&=R=7!P`,1N9')A(&)E:/9R:6=H970`
MQ&YD<F$@8F5H]G)I9VAE=&5R`,1N9')A(&)E:/9R:6=H971E<B!F]G(@)7,`
MQ&YD<F$@9FKD<G)K86QE;F1R87(`Q&YD<F$@9&5L=&%G87)E`,1N9')A(&MA
M=&5G;W)I97(@;V-H(&;D<F=E<@#$;F1R82!I;G-TY&QL;FEN9V%R(&;V<CH`
MQ&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`G)7,G`,1N9')A(&)E:/9R:6=H971E
M<B!F]G(@)R5S)P!5=&)I;&1N:6YG`$5G>7!T96X`16P@4V%L=F%D;W(`16QE
M;65N="XN+@!%;0!%+7!O<W0`12UP;W-T861R97-S`$4M<&]S=&%D<F5S<V5R
M(&WE<W1E('-TY&UM82#V=F5R<F5N<RX`12UP;W-T;65D9&5L86YD92!M960@
M8F5K<N1F=&5L<V4`12UP;W-T('1I;&P@4TU3+6)R>6=G80!+Y&YS;&]I:V]N
M97(`5&]M="!M961D96QA;F1E+@!4;VUT(')E<W5L=&%T+@!4;VUT('/V:VMR
M:71E<FEA`%-L=70`4VQU=`!3;'5T9&%T=6T`4VQU=&$@9&5N`%-L=71T:60`
M4VQU="#E<@!&]G)S=&]R82!E9&ET;W(`06YG92!S]FMVY&<@*%523"D@=&EL
M;"!B:6QD96X@:.1R`%-+<FEV(&)O:W-TY'9E<FYA(&YE9&%N.@!&96P`1F5L
M('9I9"!S:V%P86YD92!A=B!B;&]C:SH@)7,`1F5L('9I9"!R861E<FEN9R!A
M=B!S>6YK<F]N:7-E<FEN9W-MY')K93H@)7,`1F5L('9I9"!R861E<FEN9R!A
M=B!S>6YK<F]N:7-E<FEN9W-L;V=G.B`E<P!&96P@;N1R(&EN;F5HY6P@:.1M
M=&%D97,Z("5S`$MA;B!I;G1E(&CD;71A(&EN9F]R;6%T:6]N(&]M(&QE9&EG
M+W5P<'1A9V5N(&;V<B`E<SH@)7,`1F5L('5N9&5R('/D;F1N:6YG(&%V('-V
M87)S;65D9&5L86YD93H@)7,`1F5L('9I9"!U<'!D871E<FEN9R!A=B!L]G-E
M;F]R9#H@)7,`1F5L('9I9"!S:W)I=FYI;F<@)R5S)RX`1F5L('9I9"!S:W)I
M=FYI;F<@878@)R5S)RX`17-T;&%N9`!%=&EO<&EE;@!%=&YI<VL`175R;W!A
M`$CD;F1E;'-E('-K87!A9#H`2.1N9&5L<V4@<F%D97)A9#H`2.1N9&5L<V4@
MY&YD<F%D.@!(Y&YD96QS92!F<N5N("5S('1I;&P@)7,`2.1N9&5L<V5N(&AI
M='1A9&5S(&EN=&4`2.1N9&5L<V5R(&WE<W1E(&AA(&5T="!S=&%R=&1A='5M
M+@!(Y&YD96QS97(@;>5S=&4@:&$@96X@<G5B<FEK+@!687(@,34Z92!M:6YU
M=`!687)A;FYA;B!M:6YU=`!687(@,S`Z92!S96MU;F0`5F%R(#4Z92!M:6YU
M=`!687)J92!I;FQO9V=N:6YG`%9A<FIE(&AA;'9T:6UM90!687)J92!M:6YU
M=`!%>&5M<&5L('#E(';D<F1E;CH`2_9R`$5X<&%N9&5R80!%>'!A;F1E<F$@
M;F%M;@!%>'!A;F1E<F$@<VED;V;D;'0`1O9R=N1N=&%D92`G*2<`1O9R=N1N
M=&%D92!E;G-K:6QT(&]R9"!E;&QE<B!C:71E<F%T('/V:V)E9W)E<'``1O9R
M9F%L;&]D871U;0!%>'!O;F5N=`!%>'!O<G1E<F$`17AP;W)T97)A(&MA;&5N
M9&5R`$;V<F=R=6YD<V;D<F<`3&%D9&$@=7!P(&MO;F9I9W5R871I;VX@=FEA
M($944"X`36ES<VQY8VMA9&5S(&%T="!HY&UT82!I;G-TY&QL;FEN9V%R+@!-
M:7-S;'EC:V%D97,@871T(&MO;G1A:W1A($Q$05`@<V5R=F5R+@!-:7-S;'EC
M:V%D97,@871T(&MO;G1A:W1A(%--0B!S97)V97(N`$UI<W-L>6-K861E<R!A
M='0@:V]P:65R82!F<N5N("<E<R<N`$UI<W-L>6-K861E<R!A='0@:V]P:65R
M82!T:6QL("<E<R<N`$UI<W-L>6-K861E<R!A='0@<VMA<&$@;GD@4T%33"UF
M]G)B:6YD96QS92X`36ES<VQY8VMA9&5S(&%T="!F;'ET=&$@=&EL;"`G)7,G
M+@!-:7-S;'EC:V%D97,@871T(&CD;71A.B`E<P!"<F$`1F%L:VQA;F1S]F%R
M;F$`1N1R]F%R;F$`1F%T86QT(&9E;#H`1F%X`$9A>&%R`&9E8G)U87)I`$OD
M;FYS('-O;0!+Y&YN<R!S;VTZ(`!&Y71A;&EG82!S:W5R87(`1N5T86QI9V$@
M<V[V<VMU<F%R`$;D;'1M871R:7,`1FEG;&5T($-!4%1#2$$`1FEG;&5T='EP
M<VYI='0`1FEJ:0!&:6P`06YT86P@9FEL97(Z("5S(&9I;`!!;G1A;"!F:6QE
M<CH@)7,@9FEL97(`1FEL:&%N=&5R87)E`$9I;&YA;6X`1FEL=F%L`$9I;'5P
M<&QA9&1N:6YG`$9I;'5P<&QA9&1N:6YG('-T]F1S(&EN=&4N`$9I;'1E<@!3
M]FL`1FEN;&%N9`!&]G)S=&$@:&%L=F%N`$;V<G-T82!K=F%R=&5N`$UA<'`@
M)7,@97AI<W1E<F%R(&EN=&4N`$9O;G1FY')G`$UA=`!&]G(@=V5B8FSD<V%R
M92!S;VT@:6YT92!S=/9D97(@8FEL9&5R`%!R;V=N;W,@*%1!1BD`06YT86P@
M9&%G87(@9O9R('!R;V=N;W,@*'9A<FIE(&1A9R!B971Y9&5R(&5N('!R;V=N
M;W,@9O9R(&1A9R!O8V@@96X@9O9R(&YA='0I`$=L]FUT(&1I='0@;/9S96YO
M<F0_`$9O<FUU;.1R`%9I<VAE='-O<F0`5'EP(&%V('9I<VAE='-O<F0`5FES
M:&5T<V]R9`!6:7-H971S;W)D(#(`1F]R=6T`5FED87)B969O<F1R87(`1G(`
M4F%M87(`1G)A;FMR:6ME`$9R86YK<FEK92P@365T<F]P;VP`3&5D:6<`3&5D
M:6<O57!P=&%G96X`3&5D:6<O57!P=&%G96XM:6YF;W)M871I;VX`3&5D:6<O
M57!P=&%G96X@<W9A<@!,961I9R]U<'!T86=E;BUF]G)F<N5G86X`4W9A<B!P
MY2!L961I9R]U<'!T86=E;BUF]G)F<N5G86X`1G)A;G-K82!'=6EA;F$`1G)A
M;G-K82!0;VQY;F5S:65N`$9R86YS:V$@<_9D<F$@=&5R<FET;W)I97(`1G)E
M9&%G`$9RY6X`1G+E;B!D96X@`$9U;&QS=.1N9&EG(&)E<VMR:79N:6YG`$9U
M;&QMY6YE`$9U;&QS=.1N9&EG="!N86UN`$9R86UT:61A`$=A8F]N`$=A;&QE
M<FD@871T('1A(&)I;&0@9G+E;@!'86QL97)I.@!'86UB:6$`4W!E;`!!;&QM
MY&X`1V5N97)E<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,`1V5N97)E<F%D(&MO
M9`!'96]R9VEE;@!4>7-K;&%N9`!':&%N80!':6)R86QT87(`1O9R;F%M;@!'
M;&]B86QA(&EN<W3D;&QN:6YG87(`3TL`1V]E9&5L`$=O;V=L96MA<G1O<@!'
M;V]G;&5S]FMN:6YG`$?E('1I;&P@)7,`1W+E<VMA;&$`1W)E:VES:R`H25-/
M+3@X-3DM-RD`1W+V;@!'<O9N;&%N9`!'<F%N861A`$=RY0!'<G5P<&%D;6EN
M:7-T<F%T:6]N`$=R;W5P7VQD87`Z($MA;B!I;G1E(&SD9V=A('1I;&P@9W)U
M<'`@)R5S)RX@4V5R=F5R;B!S=F%R861E.B``1W)O=7!?;&1A<#H@2V%N(&EN
M=&4@<F%D97)A(&=R=7!P("<E<R<`1W)O=7!?;&1A<#H@2V%N(&EN=&4@=7!P
M9&%T97)A(&=R=7!P("<E<R<`1W)U<'!E<@!'=6%M`$=U871E;6%L80!'=65R
M;G-E>0!'Y'-T8F5H]G)I9VAE=&5R`%1JY&YS=&5R(&;V<B!GY'-T97(`1^1S
M=&)O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=6EN96$`2%1-3`!(5$U,07)E
M82!VY&=R87(@871T(')A9&5R82!S:7-T82!C96QL96X@:2!E;B!R860N`$A4
M34Q!<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(&MO;'5M;F5N(&D@96X@
M=&%B96QL+@!(5$U,07)E82!VY&=R87(@871T(')A9&5R82!S:7-T82!R861E
M;B!I(&5N('1A8F5L;"X`2%144"!!=71E;G1I<V5R:6YG('-A:VYA<RX`2&%I
M=&D`2&%S:&%L9V]R:71M`$1I;6UA`%)U8G)I:P!2=6)R:6ME<@!(96%R9"T@
M;V-H($UC1&]N86QD]F%R;F$`2W)A9G1I9V$@Y7-K<VMU<F%R`$AE8G)E:7-K
M("A)4T\M.#@U.2TX+4DI`$CV:F0`2/9J9"`H<&EX;&%R*0!(:N1L<`!(:N1L
M<"!M960@961I=&]R;@!(:N1L<&9U;FMT:6]N`$AE;6ES9N1R`$CD<B#D<B!B
M]G)J86X@878@9FEL96XZ`$?V;0!']FT@)7,`2/9G`$AE7VT`2&5M`$%D<F5S
M<RP@:&5M`$AE;6MA=&%L;V<`5&5L969O;BP@:&5M`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@3V=I;'1I9W0@)7,@6$U,+61A=&$@
M<.5T<N1F9F%D97,@:2!M961D96QA;F1E("5S`$AO<F1E+TMO;&%B.B!);F=E
M="!M961D96QA;F1E(&UA=&-H87(@;V)J96MT970@)7,`2&]R9&4O2V]L86XZ
M($EN9V5T(&]B:F5K="!A=B!T>7!E;B`E<R!H:71T861E<R!I(&UE9&1E;&%N
M9&5T("5S`$AO<F1E+TMO;&%B.B!2861E<F%D92`E<R`G)7,G`$AO<F1E+TMO
M;&%B.B!);G1E9W)A=&EO;G-M;W1O<FX@:W+D=F5R("=D;VUX;6PG+71I;&SD
M9V=E="!F]G(@4$A0`$AO<F1E+TMO;&%B.B!+86X@:6YT92!S:V%P82!N>71T
M(%A-3"UT<N1D(&;V<B!O8FIE:W0@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E
M(')A9&5R82`E<R`G)7,G.B`E<P!(;W)D92]+;VQA8CH@2V%N(&EN=&4@:.1M
M=&$@34E-1$4M240@9O9R(&1E;&5N(&UE9"!T>7`@)7,`2&]R9&4O2V]L86(Z
M($MA;B!I;G1E('-Y;FMR;VYI<V5R82`E<R`G)7,G.B`E<P!(;W)D92]+;VQA
M8CH@2V%N(&EN=&4@<WEN:W)O;FES97)A('5T9&5L;FEN9V%R.B`E<P!(;W)D
M92]+;VQA8CH@3VOD;F0@=71D96QN:6YG("<E<R<`2&]R:7-O;G1E;&P@;&EN
M:F4`2&]R:7-O;G1E;&P@=71F>6QL;F%D`$AO<FES;VYT96QL.@!4:6UM+V4O
M87(`2'5R(&AA;6YA9&4@9'4@:.1R/R`H5F%R(&=O9"!R87!P;W)T97)A(&1E
M='1A(2D`2'5R(&SE;F=A('-K86QL('1I9'!O<W1E<FYA('9A<F$@:2!D92!D
M86=L:6=A(&]C:"!V96-K;W9I<V$@=GEE<FYA/P!(=7(@;>5N9V$@:V]L=6UN
M97(@=FEL;"!D=2!S;.4@:6AO<#\`1O9R(&AU<B!MY6YG82!D86=A<B!F<F%M
MY70@=FEL;"!D=2!G96YE<F5R82!L961I9RTO=7!P=&%G96YI;F9O<FUA=&EO
M;C\`2'5R(&WE;F=A(&;D;'0@*&MO;'5M;F5R*2!F:6YN<R!D970_`$AU<B!M
MY6YG82!R861E<B!V:6QL(&1U('-LY2!S86UM86X_`$9U:W1I9VAE=`!&=6MT
M:6=H970Z`$AU;6]R:7-T97(`56YG97)N`%-K87!A;F1E(&%V($E-05`M;6%P
M<"!M:7-S;'EC:V%D93H@)7,`4F%D97)I;F<@878@24U!4"UM87!P(&UI<W-L
M>6-K861E<SH@)7,`4VMA<&%N9&4@878@<75O=&$@9O9R($E-05`M;6%P<"!M
M:7-S;'EC:V%D97,Z("5S`$E0+6%D<F5S<P!)4"UA9')E<W,@Y'(@:6YT92!T
M:6QL9^1N9VQI9RX`25`M861R97-S(.1R(&EN=&4@:6YO;2!G;V1KY&YT($-)
M1%(M8FQO8VLN`$;V<G/V:R!A='0@:W)I;F=GY2!)4"ULY7,N`$E?;F9O9V$@
M<F%D(&;V<F4`27-L86YD`$5N8F%R="!I:V]N97(`26MO;F5R(&;V<B`E<P!)
M:V]N97(@;65D('1E>'0`261E;G1I=&5T96YS(&YA;6XZ`$]M(&1E="!I;G1E
M('9I<V%S(&MO<G)E:W0L("5S(&;V<B!A='0@]G!P;F$@:2!N>71T(&;V;G-T
M97(N`$]M(&1U(&EN=&4@<V5R(&[E9W)A(&EK;VYE<B!NY'(@9'4@86YVY&YD
M97(@26YT97)N970@17AP;&]R97(L('/E(&MA;B!D=2!B96CV=F$@;6%R:V5R
M82!D96YN82!R=71A(&;V<B!A='0@<W3D;F=A(&%V(&=E;F]M<VMI;FQI9V$@
M4$Y'+6)I;&1F:6QE<BX`3VT@9'4@<V5R(&1E;FYA('1E>'0@;65N(&EN9V5N
M(&)I;&0L('/E(&MA;B!I;G1E(&1I;B!W96)B;.1S87)E('9I<V$@9&5N(&)I
M;&0@9'4@9O9R<_9K97(@;&%D9&$@=7!P+@!/;2!D:6X@92UP;W-T:VQI96YT
M(&EN=&4@<W3V9&5R(&E4:7`L('/E(&MA;B!D=2!A;G;D;F1A(&5N(&%V(&;V
M;&IA;F1E(&SD;FMA<B!A='0@86-C97!E=&5R82!E;&QE<B!A=F+V:F$@:.1N
M9&5L<V5N+@I&]G(@871T(&%C8V5P=&5R83H*)7,*1O9R(&%T="!P<F5L:6UI
M;N1R="!A8V-E<'1E<F$Z"B5S"D;V<B!A='0@879B]FIA.@HE<P!&]G)H86YD
M<V=R86YS:V$@8FEL9#H`0FEL9&%D<F5S<P!":6QD861R97-S.@!":6QD(&9R
MY6X@9V%L;&5R:0!":6QD(&9RY6X@9V%L;&5R:3H`3&%D9&$@=7!P(&)I;&0`
M0FEL9&5R`$EM<&]R=&5R82!K86QE;F1E<BP@<W1E9R`E9`!);7!O<G1E<F$L
M('-T96<@)60`26UP;W)T97)A+T5X<&]R=&5R82!K86QE;F1E<@!);7!O<G1E
M<F%D92!FY&QT.B`E<P!);7!O<G1E<F%D92!FY&QT.@!0Y6?E96YD90!);E]F
M;V=A(')A9"!E9G1E<@!&96QA:W1I=B!A:W1I=FET971S:V]D('-P96-I9FEC
M97)A9"X`1F5L86MT:6=T(&%N=N1N9&%R;F%M;B!O8V@O96QL97(@;/9S96YO
M<F0N`$]G:6QT:6=T(&%N=N1N9&%R;F%M;B!E;&QE<B!A;'1E<FYA=&EV(&%D
M<F5S<RX@1O9R<_9K(&EG96X@96QL97(@:V]N=&%K=&$@861M:6YI<W1R873V
M<F5N(&]M(&1U(&)E:/9V97(@:&KD;'`N`-9K82!I;F1R86<`26YD:65N`$EN
M9&EV:61U96QL82!A;G;D;F1A<F4`26YD;VYE<VEE;@!);F9O`$EN9F]R;6%T
M:6]N`$EN9F]R;6%T:6]N(.1R(&EN=&4@=&EL;&?D;F=L:6<@;.1N9W)E+@!)
M;F9O9V$@:U]O;'5M;B!E9G1E<@!);F9O9V$@8FEL9`!);F9O9V$@=&%B96QL
M`$EN9F]G82!W96)B;.1N:P!);F9O9V$@7VMO;'5M;B!F]G)E`$EN9F]G82!N
M>2!K;VQU;6X@969T97(@86MT=65L;"!K;VQU;6X`26YF;V=A(&YY(&MO;'5M
M;B!F]G)E(&%K='5E;&P@:V]L=6UN`$EN9F]G82!R860@969T97(@86MT=65L
M;"!R860`26YF;V=A(&YY(')A9"!F]G)E(&5K='5E;&P@<F%D`$EN9F]G82!P
M87)A9W)A9B!E9G1E<B!A:W1U96QL(&YO9`!);F9O9V$@<&%R86=R868@9O9R
M92!A:W1U96QL(&YO9`!);F9O9V$@86QT97)N871I=B!M86QL`$EN9F]G82!C
M96QL(&5F=&5R`$EN9F]G82!C96QL(&;V<F4`26YF;V=A(&MO;'5M;B!E9G1E
M<@!);F9O9V$@:V]L=6UN(&;V<F4`26YF;V=A(&UE9&1E;&%N9&5N`$EN9F]G
M82!P87)A9W)A9B!E9G1E<@!);F9O9V$@<&%R86=R868@9O9R90!);F9O9V$@
M<F%D(&5F=&5R`$EN9F]G82!R860@9O9R90!!;F=E(&5R9F]R9')A="!S=F%R
M('1I;&P@<^1K97)H971S9G+E9V%N.@!);F9O9V$OQ&YD<F$@8FEL9`!);F9O
M9V$OQ&YD<F$@;.1N:P!/=&EL;'+D8VML:6<@:W)E9&ET(&;V<B!A='0@<VMI
M8VMA('1I;&P@9&ES=')I8G5T:6]N<VQI<W1A+@!/=&EL;'+D8VML:6<@:W)E
M9&ET+@!(96QT86P`2&5L=&%L<VQI<W1A`$]G:6QT:6<@Y71GY')D(&;V<B!D
M96X@:.1R(&MO;7!O;F5N=&5N+@!/9VEL=&EG(%5$2"`H)W5S97(@9&%T82!H
M96%D97(G*2X`3V=I;'1I9W0@6DE0+6%R:VEV9&%T80!&96QA:W1I9R!A<'!L
M:6MA=&EO;BX`1F5L86MT:6=T(&)A=&-H+4E$`$9E;&%K=&EG(&1A=&$@<VMI
M8VMA9"X`1F5L86MT:6<@9&5S=&EN871I;VYS861R97-S+@!&96QA:W1I9W0@
M9FEL9F]R;6%T`$]G:6QT:6<@;&EC96YS;GEC:V5L+@!&96QA:W1I9R!O<G0@
M<W!E8VEF:6-E<F%D+@!&96QA:W1I9R!M961D96QA;F1E7W1Y<"X`1F5L86MT
M:6<@96QL97(@<V%K;F%D(&%P:5]I9"X`1F5L86MT:6=T(&5L;&5R('-A:VYA
M9"!P87)A;65T97(N`$9E;&%K=&EG(/9V97)L:6=G86YD92!B96CV<FEG:&5T
M+@!&96QA:W1I9W0@<&%R=&YE<BUI9"X`1F5L86MT:6<@<')O9'5K=&MO9"X`
M1F5L86MT:6=T('!R;W1O:V]L;"X`1F5L86MT:6<@;6]T=&%G87)E.B`G)7,G
M`$9E;&%K=&EG="!U=&1E;&YI;F=S;V)J96MT`$9E;&%K=&EG(&%V<^1N9&%R
M861R97-S+@!&96QA:W1I9W0@=6YI8V]D92UD871A`$EN=F5N=&%R:65R`$EN
M=F5R=&5R82!U<G9A;`!)<F%N`$ER86L`27)L86YD`$ES;&4@;V8@36%N`$5N
M<W1A:V$@Y7-K<VMU<F%R`$ES<F%E;`!5=&;D<F1A="!A=@!+=7)S:78`271A
M;&EE;@!*86UA:6-A`&IA;G5A<FD`2F%P86X`2F%P86YS:R`H25-/+3(P,C(M
M2E`I`$IE<G-E>0!*;W)D86YI96X`:G5L:0!J=6YI`$IU<W1E<F$`0V5N=&5R
M:G5S=&5R80!*=7-T97)A(&KD;70`5N1N<W1E<FIU<W1E<F$`2/9G97)J=7-T
M97)A`$ME;GEA`$ME<F)E<F]S<V5R=F5R;B!A=G9I<V%D92!A=71E;G1I<V5R
M:6YG96XN`$YY8VME;"!S:V%P860`1FEN9V5R<')I;G0`3GEC:V5L;.1N9V0`
M3GEC:V5L='EP`$YY8VME;&%N=N1N9&%N9&4`3GEC:V5L(&9I;FYS(')E9&%N
M('#E(&1E;B!P=6)L:6MA(&YY8VME;'-E<G9E<FXN`$YY8VME;&]R9`!"87)N
M`$MI<FEB871I`$MO;&%B`$YO<F1K;W)E80!3>61K;W)E80!+;W)E86YS:R`H
M155#+4M2*0!+=7=A:70`2VER9VES=&%N`$QA7WEO=70`4W!RY6L`3&%O<P!3
M96YA<W1E(#(T('1I;6UA<FYA`%-I<W1A(&AA;'9A;@!396YA<W0@Y&YD<F%D
M`$;V<G)A(&WE;F%D96X`3/9S96YO<F0@Y&YD<F%D97,`4VES=&$@:W9A<G1A
M;&5T`%-E;F%S="!U<'!D871E<F%D.@!&]G)R82#E<F5T`%-E;F%S=&4@:6YL
M;V=G;FEN9SH@)7,`4V5N87-T92!I;FQO9V=N:6YG.B`E<R!F<N5N("5S`%-E
M;F%S=&4@:6YL;V=G;FEN9SH@06QD<FEG`$;V<G)A('9E8VMA;@!,971T;&%N
M9`!,879E;F1E<@!,86<`3&%Y;W5T`$SD;6YA('1O;2!F]G(@871T('-TY&YG
M82!A=B!K86YT;&EN:F4`3&EB86YO;@!6Y&YS=&5R`%;D;G-T97)R=6)R:6L`
M5N1N<W1E<G;D<F1E;@!,97-O=&AO`$YI=N4`3&EB97)I80!,:6)Y96X`3&EE
M8VAT96YS=&5I;@!,:G5S8FSE`$1U9V=R96=N`$SD='0@<F5G;@!,Y'1T(&;V
M<FUI9&1A9W-R96=N`$SD='0@969T97)M:61D86=S<F5G;@!,Y'1T(')E9VYS
M:W5R`$SD='0@<F5G;B!M960@Y7-K80!,Y'1T('-N]@!,Y'1T('-N]G-K=7(`
M3&EM97)I8VL`0F5G<N1N<V$@=&ED<W-P86YN970@9O9R(&5X<&]R=&5N.@!,
MY&YK`$SD;FME;B!P96MA<B!PY3H`3.1N:V$@92UP;W-T861R97-S96X@=&EL
M;"!F=6YK=&EO;F5N(&;V<B!A='0@<VMA<&$@;GET="!M961D96QA;F1E`$SD
M;FMA<@!+86MA`$QI<W1A("T@86YVY&YD87)E(&MA;B!S92!M87!P96X`5FES
M82!D871A8F%S97(`5FES82!H:N1L<.1M;F5N`$QI<W1A('1A8F5L;&5R`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$1E="!G:6-K
M(&EN=&4@871T(&QI<W1A('-E<W-I;VYE<CH@)7,`1&5T(&=I8VL@:6YT92!A
M='0@;&ES=&$@86YVY&YD87)E.B`E<P!,:7-T;FEN9R!A=B!A;G;D;F1A<F4@
M879A:W1I=F5R860N`$QI='1E<F%T=7(`3&ET875E;@!?4&QA=',`3&%D9&%R
M+BXN`$QO:V%L('1I9#H@`%)E9VEO;F%L=`!0;&%T<P!,;V=G82!I;@!,;V=G
M82!U=`!,;V=I;@!,;V=I;F%K=&EV:71E=&5R`$EN;&]G9VYI;F<@;6ES<VQY
M8VMA9&5S+B!4<F]L:6=T=FES('9A<B!A;G;D;F1A<FYA;6X@96QL97(@;/9S
M96YO<F0@9F5L86MT:6=T+@!);FQO9V=N:6YG(&UI<W-L>6-K861E<RX`3.5N
M9R!T97AT`$OD<FQE:P!,Y6<`1W)E:VES:V$@9V5M96YE<@!,871I;G-K82!G
M96UE;F5R`%-MY2!R;VUE<G-K82!S:69F<F]R`$QO>6]L80!,;WEO;&$@0FSE
M`$QU>&5M8G5R9P!-30!-3U1$`$U3+51.148@8FEL86=A(&EN;F5H]FQL(&EN
M9V5N(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:65N`$UA9V%G87-K87(`36%G
M:7-K`$4M<&]S=`!%+7!O<W1A9&UI;@!3:V%P82!LY&YK+BXN`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<FYA`$UA;&D`36%L=&$`2&%N=&5R82!F:N1R<FMA
M;&5N9')A<BX`56YD97)HY6QL(&QI<W1A;B!M960@:V%T96=O<FEE<B!D=2!A
M;G;D;F1E<B!F]G(@871T(&MA=&5G;W)I<V5R82!P;W-T97(@;65D(&]C:"!F
MY')G97)N82!S;VT@=&EL;&CV<B!D97-S82!K871E9V]R:65R+@!-87`R-"UK
M87)T80!-87!1=65S="UK87)T80#6=F5R<^1T=&YI;F=A<B!S<&%R861E+@!M
M87)S`$UA<F=I;F%L`$9L86=G82!S;VT@;.1S="]O;.1S=`!&;&%G9V$@;65D
M(&%N;F%N('-T871U<R`H="!E>"!V:6MT:6=T+V)E<W9A<F%T*0!-87)S:&%L
M;/9A<FYA`$UA<G1I;FEQ=64`36%T8VAA;F1E(&;D;'0`36%U<FET86YI96X`
M36%U<FET:75S`$UA>"!T:6QLY71E;B!K<F5D:70N`$=RY&YS(&;V<B!M87@@
M86YT86P@9&5L87(@:2!M961D96QA;F1E(/9V97)S:W)I9&5N+@!(]F=S=&$@
M=&5M<&5R871U<F4@<V5N87-T92`R-"!T:6UM87)N83H@`$CV9W-T82!T96UP
M97)A='5R92!S96YA<W1E(#8@=&EM;6%R;F$Z(`!-87@@86YT86P@:.1N9&5L
M<V5R`$UA>&EM86QT(&%N=&%L('!O<G1A;&)L;V-K`$UA>&EM86P@;.1N9V0`
M;6%J`$UA>6]T=&4`2F%G`$UE9&EC:6X`3?9T90!!=F)O:V$@;?9T90!-]G1E
M<VEN9F]R;6%T:6]N`$WV=&5S9O9R9G+E9V%N`$WV=&5S<W9A<@!-]G1E<W5P
M<&1A=&5R:6YG`%5P<&1A=&5R:6YG<V)E9^1R86X@;VT@;?9T90!-961L96UM
M87(`365N>6%L87)M`$UE;GEL:7-T80!-96YY;.1G93H`4VSE(&EH;W`@8V5L
M;&5R`$UE9&1E;&%N9&4`365D9&5L86YD970@=F5R:69I97)A9&5S(&UE;B!D
M96X@<VEG;F5R861E<R!C97)T:69I:V%T(&MU;F1E(&EN=&4@=F5R:69I97)A
M<RX`365D9&5L86YD92!GY&QL97(@:6YT92!LY&YG<F4N`$UE9&1E;&%N9&5T
M>7``365T87)VY&1E<@!-971A<F)L;V-K970@Y'(@:6YT92!T:6QL9^1N9VQI
M="X`365T87(M8FQO8VL@96H@=&EL;&?D;F=L:6=T+B!$971A;&IE<B!H87(@
M;&]G9V%T<R!F]G(@<WES=&5M861M:6YI<W1R873V<F5N+@!-971A<D1"(.1R
M(&EN=&4@86YS;'5T96XN`$UE=&]D`$UE=&]D96X@)R5S)R#D<B!I;G1E(&1E
M9FEN:65R860`365T;V1E;B!H87(@:6YT92!D969I;F5R871S+B!!;G)O<&%D
M(&UE=&]D.B`E<P!-971R:7-K`$UE>&EK;P!-:6MR;VYE<VEE;@!-:71T96X`
M36EM971Y<`!,Y&=S=&$@=&5M<&5R871U<B!S96YA<W1E(#(T('1I;6UA<FYA
M.B``3.1G<W1A('1E;7!E<F%T=7(@<V5N87-T92`V('1I;6UA<FYA.B``36EN
M<W1A(&SV<V5N;W)D<^5L9&5R(&AA<B!I;G1E('5P<&[E='1S(.1N`$UI;G5T
M*&5R*0!3<&5G;&$`1&EV97)S90!/8FQI9V%T;W)I<VMT('!A:V5T('-A:VYA
M<R`H4$5!4B!(5%107U)E<75E<W0I+@!+;VYF:6=U<F%T:6]N('-A:VYA<RX@
M1'4@;>5S=&4@<VMA<&$@9&5N(&YU(&]M(&1U('9I;&P@86YVY&YD82!D96X@
M:.1R(&%P<&QI:V%T:6]N96XN`%-A:VYA<B!M961D96QA;F1E+4E$+@!/8FQI
M9V%T;W)I<VMT('!A:V5T('-A:VYA<R`H4$5!4B!-86EL*2X`4V%K;F%R('-E
M<W-I;VYS+4E$+@!-Y0!-;V)I;"!E+7!O<W0`36]D97)E<F$`Q&YD<F%D(&1A
M='5M`,1N9')A(&SD;FL`36]D=6QU<P!-;VQD879I96X`36]N86-O`$WE;F1A
M9P!-;VYG;VQI970`3>5N860`3>5N861S=GD`3>5N860@;V-H(.5R`$WE;F%T
M;&EG`$WE;F%T;&EG82!HY&YD96QS97(`36]N871L:6<Z(%5P<')E<&$@=F%R
M`$WE;F%D97(@9G)A;>5T`$WE;F%D97(@=&ED:6=A<F4`36]T<V5R<F%T`$WE
M;F9A<V5R`$9L97(@9N1L="!H:71T861E<R!PY2!R860@)60@Y&X@9&5T(&;V
M<G;D;G1A9&4@)60N`$UA<F]C:V\`365S=&%D96QS(&ML87)T`$UE<W1A9&5L
M<R!M;VQN:6=T`$UE<W1A9&5L<R!S;VQI9W0`1FQY='1A(&YE9`!&;'ET=&$@
M=N1N<W1E<@!&;'ET=&$@:/9G97(`1FQY='1A('5P<`!&;'ET=&$@;F5D`$9L
M>71T82!U<'``36_G86UB:7%U90!-;WII;&QA`$9L97)N:7;E<VQI<W1A`$UU
M;'1I;6%P(%-T;W)B<FET86YN:65N:V%R=&$`1FQE<F$@:4-A;&1E;F5R+61E
M;&%R(&AI='1A9&5S.R!E;F)A<G0@96X@=D5V96YT('-T]F1S+@!&;&5R=F%L
M`$UI='0@:V]N=&\`36EN(&MO;G1O:6YF;W)M871I;VX`36EN82!K86QE;F1R
M87(`36EN82!K86QE;F1R87(Z`$UI;B!L961I9R]U<'!T86=E;BU54DP`36EN
M('!O<G1A;`!-:6X@<&]R=&%L;&%Y;W5T`$UY86YM87(`3D5*+"!*86<@86-C
M97!T97)A<B!I;G1E`$YA;6X`3F%M:6)I80!.875R=0!.95A4`$)E:/9V97(@
MY71GY')D`$YE<&%L`$YE9&5R;.1N9&5R;F$`3F5D97)LY&YD<VMA($%N=&EL
M;&5R;F$`3F5S8V%P92!B87,M55),`$YE='-C87!E(&;V<FYY96QS92U54DP`
M3F5T<V-A<&4@Y71E<FMA;&QE;'-E+5523`!.971S8V%P92!34TPM<V5R=F5R
M;F%M;@!.971S87!E(&-E<G1I9FEK871S:V]M;65N=&%R`$YE='-A<&4@8V5R
M=&EF:6MA='-T>7``3N1T=F5R:P!!;&1R:6<`3GEA($MA;&5D;VYI96X`3GD@
M:V%T96=O<FD`3GD@:.1N9&5L<V4`3GET="!M961D96QA;F1E('1I;&P@)7,`
M3GEMY6YE`$YY='0@86YVY&YD87)N86UN("AV86QF<FET="D`3GEA(%IE96QA
M;F0`3GD@:V%L96YD97(@<VMA<&%D(&]C:"!A=71O;6%T:7-K="!D96QA9"!M
M960@9O9L:F%N9&4@9W)U<'`H97(I.B`E<RX`3GET="!L]G-E;F]R9`!.>71T
M(&SV<V5N;W)D(&MO;6UE<B!A='0@9^4@=70@)7@N`$SV<V5N;W)D(&WE<W1E
M('9A<F$@<V%M;6$N`$YY='0@9O9N<W1E<B`H7V)L86YK*0!.>6AE=&5R`$YY
M:&5T<V=R=7!P97(`3N1S=&$`3N1S=&$@,C0@=&EM;6%R`$MO;6UA;F1E(#0@
M9F%S97(`3N1S=&$@9&%G`$[D<W1A(&WE;F%D`$[D<W1A('9E8VMA`$[D<W1A
M(.5R`$[D<W1A(&1A9P!.Y'-T82!I;G-TY&QL;FEN9V%R`$[D<W1A('9E8VMA
M`$[D<W1A/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.871T`$YI=64`3F5J
M`$EN9V5N(&EN9F]R;6%T:6]N`$EN9V5T(&%L87)M`$EN9V$@9&5L=&%G87)E
M`$1E="!F:6YN<R!I;F=E="!K;VYF:6=U<F%T:6]N<V1A=&$@871T('9I<V$@
M<VMI;&QN861E<B!F]G(N`$EN9V5N('1I;&QGY&YG;&EG('-T<F%T96=I(&;V
M<B!A='0@<VMA<&$@25-/+6EM86=E+@!);G1E(&5N(&)A=&-H;6%L;"X`1&5T
M(&9I;FYS(&EN9V5T(&)L;V-K('#E(&1E;B!B96?D<F1A('!O<VET:6]N96X`
M26YG970@:V%L96YD97)N86UN(&;V<B!-0T%,(&%U=&5N=&ES97)I;F<@86YG
M:79E="X`26YG82!K86QE;F1R87(@=&EL;&?D;F=L:6=A(&;V<B!GY'-T97(N
M`$EN9V5N(.1N9')I;F<N`$EN9V$@=6YD97)B96CV<FEG:&5T97(@:V%N(&SD
M9V=A<R!T:6QL(&1E;B!HY'(@8F5H]G)I9VAE=&5N+@!);F=E;B!K;VYF:6=U
M<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R("5S+@!);F=E;B!K;VYF
M:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R($944"!61E,N`$EN
M9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@4U%,
M(%9&4RX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N
M(&;V<B!344PM9FEL(%9&4RX`26YG96X@:W)E9&ET(&MV87(N`$)E<VMR:79N
M:6YG('-A:VYA<RX`26YG96X@;6]T=&%G87)E(&%N9VEV96XN`$EN9V5T('-L
M=71D871U;0!);F=A(&CD;F1E;'-E<B!A='0@=FES80!);F=E;B!F:6P@=7!P
M;&%D9&%D`$EN9V5N(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N('1I
M;&QGY&YG;&EG(&;V<B`E<P!I0V%L96YD87(@:6YF;W)M871I;VX@<V%K;F%S
M+@!);F=A(&EK;VYE<B!H:71T861E<RX`26YG96X@;W)T(&%N9VEV96XN`$EN
M9V5N(&]R="!A;F=I=F5N+@!);F=E="!M961D96QA;F1E(&)I9F]G861E<RX`
M26YG970@;F%M;B!A;F=I=F5T+@!);F=E;B!N=6UM97(@86YG:79E="X`26YG
M82!O9O9R<VOD;61A('9I<VAE='-O<F0`26YG970@;/9S96YO<F0@9O9R($A4
M5%`M875T96YT:7-E<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@
M24U!4"UA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V
M<B!+97)B97)O<RUA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N
M;W)D(&;V<B!,;V=I;BUA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV
M<V5N;W)D(&;V<B!005-35T0M875T96YT:7-E<FEN9R!A;F=I=F5T+@!);F=E
M="!L]G-E;F]R9"!F]G(@4TU"+6%U=&5N=&ES97)I;F<@86YG:79E="X`26YG
M82!VY&YT86YD92!R96=I<W1R97)I;F=A<BX`26YG96X@:W9O=&$@86YG:79E
M;@!);F=E;B!K=F]T82!A;F=I=F5N+@!);F=E;B!U<'!R97!N:6YG`$EN9V$@
M<F5G;&5R`$EN9V5N(&%V9W+D;G-A<F4@86YG:79E;BX`26YG82!S:61O<@!)
M;F=E;B!SY61A;B!F:6P`26YG96X@=&5M<&]RY')K871A;&]G('1I;&QGY&YG
M;&EG(&;V<B!C86-H92X`26YG970@86YVY&YD87)N86UN(&]C:"]E;&QE<B!L
M]G-E;F]R9"!S:VEC:V%T+@!);F=E="!G:6QT:6<@6$U,+61A=&$@<F5T=7)N
M97)A9&5S`$=O9&OD;F0@92UP;W-T861R97-S('-A:VYA<RX`26YG82!VY')D
M96X`26YG96X@=F5R<VEO;B!H:71T861E<R!I(&1E;B!U<G-P<G5N9VQI9V$@
M:V]N9FEG=7)A=&EO;F5N+B#%=&5R<VMA<&$@:V]N9FEG=7)A=&EO;F5N+@!)
M;F=E;B!V97)S:6]N(&AI='1A9&5S(&D@9&EN(&MO;F9I9W5R871I;VXN(,5T
M97)S:V%P82!K;VYF:6=U<F%T:6]N96XN`$EC:V4M9&5L=&%G87)E`$EN9V5N
M`$EN9V5N("AA;G;D;F0@=6YD97)F]G)S=.5D9"D`3F]R9F]L:_9A<FYA`$YO
M<G)A(&AE;6ES9N1R96X`3F]R<F$@36%R:6%N8?9A<FYA`$YO<F=E`$EN=&4@
M969T97(`26YT92!F]G)E`$EN=&4@96X@:V%T86QO9P!(:71T861E<R!I;G1E
M`$5J(&EM<&QE;65N=&5R860N`$5J(&%N9VEV96X`4W3V9',@:6YT92X`06YT
M96-K;FEN9V%R`$EN9V5N=&EN9R!A='0@=FES82P@9^4@=&EL;&)A:V$N`$]"
M4P!.;W1I9FEE<FEN9V%R`&YO=F5M8F5R`$YU`$YU;6UE<@!!;G1A;"!T96-K
M96X`06YT86P@:V]L=6UN97(`06YT86P@<F%D97(`3G5M;65R(&EN=&4@<W!E
M8VEF:6-E<F%D92!F]G(@871T('5P<&1A=&5R82!I(&1I<W1R:6)U=&EO;G-L
M:7-T86XN`$]+`$]B:F5K=`!/8FIE:W1S:V%P87)E`$]K=&%L`&]K=&]B97(`
M1FEL=&5R(&;V<B!O9O9R<VOD;61H971E<@!+;VYT;W(`1V%M;6%L="!O8V@@
M;GET="!L]G-E;F]R9"!FY7(@:6YT92!V87)A('-A;6UA+@!'86UM86QT(&SV
M<V5N;W)D`$=A;6UA;'0@;/9S96YO<F0@Y'(@9F5L86MT:6=T`$]M86X`1&5N
M`$;V<B!A;&QA(&MA;&5N9&5R87(@<V]M(&IA9R!H87(@;.1S8F5H]G)I9VAE
M="!T:6QL`$;V<B!A;&QA('9I<V%D92!K86QE;F1R87(`16YB87)T(&;V<B!M
M:6YA(&MA;&5N9')A<@!$96QA9&4@;6%P<&%R('-T]F1S(&5N8F%R="!A=B!)
M34%0+7-E<G9R87(`16YB87)T(&]F]G)S:^1M9&$@=FES:&5T<V]R9`!%;F1A
M<W0@96X@92UP;W-T861R97-S('1I;&SE=&5N+@!%;F1A<W0@Y&=A<F4@96QL
M97(@<WES=&5M861M:6YI<W1R873V<B!K86X@Y&YD<F$@Y&=A<F4@96QL97(@
M8F5H]G)I9VAE=&5R('#E(&5N('5T9&5L;FEN9P#6<'!N82!I(&YY='0@9O9N
M<W1E<@!/<&5N4U-,+69E;#H@1&5T(&=I8VL@:6YT92!A='0@97AT<F%H97)A
M(&1A=&$@9G+E;B!S:6=N97)A9"!3+TU)344M9&5L+@#6<'!N82!LY&YK(&D@
M;GET="!F]FYS=&5R`$]P97)A=&EV<WES=&5M`%9A;&9R:0!%:B!O8FQI9V%T
M;W)I<VMA(&1E;'1A9V%R90!)8VME(&]B;&EG871O<FES:V$@9&5L=&%G87)E
M`$EN<W3D;&QN:6YG87(`26YS=.1L;&YI;F=A<B!F]G(@)7,`4V]R=&5R860@
M;&ES=&$`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;G-E;FAE=`!/<F=A;FES
M97)A`%5R<W!R=6YG;&EG(&%P<&QI:V%T:6]N<VUA;&P`57)S<')U;F=L:6=A
M(&UA;&QA<B!I("5S.@!!;FYA;@!!;F1R82!I;G-TY&QL;FEN9V%R`-9V97)S
M:6MT`,1G87)E`,1G87)B96CV<FEG:&5T97(`Q&=A<F4Z("5S`%!!32U!=71E
M;G1I<V5R:6YG(.1R(&EN=&4@=&EL;&?D;F=L:6<N`%!%05(Z.DUA:6PM:V]P
M<&QI;F<`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!0=6)L:6L@4$=0+6YY8VME;`!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M`%!(4"UK;V0`4$A0+7-K86P`4$T`3.1T="!F]G)M:61D86=S<F5G;@!&]G)M
M:61D86=S<F5G;@!%9G1E<FUI9&1A9W-S:W5R87(`169T97)M:61D86=S<V[V
M`$5F=&5R;6ED9&%G<W-K=7)A<B!M960@<V[V`$5F=&5R;6ED9&%G<W-O;`#%
M<VMS:W5R87(@<.4@969T97)M:61D86=E;@!03U-)6"UT:6QLY&=G('-A:VYA
M<P!07TA0+7-K86P`571F>6QL;F%D.@!086MI<W1A;@!086QA=0!086QE<W1I
M;F$`4&%N86UA`%!A<'5A+4YY82!'=6EN96$`4&%R86=U87D`1&5L=FES(&UO
M;&YI9W0`3/9S96YO<F0`3/9S96YO<F0@Y&YD<F%D97,N`$SV<V5N;W)D(&9E
M;&%K=&EG=`!,]G-E;F]R9"!K<N1V<R!F]G(@4D%$2553(&%U=&5N=&ES97)I
M;F<N`$SV<V5N;W)D(&UE9"!B96MRY&9T96QS90!,]G-E;F]R9#H`3/9S96YO
M<F0Z(`!,]G-E;F]R9"!MY7-T92!V87)A(&QI:V$N`$;V<F9L=71N82!HY&YD
M96QS97(`2VQI<W1R82!I;@!+;&ES=')A(&EN(&9RY6X@=7)K;&EP<'-H86YT
M97)A<F5N`%/V:W;D9P!-]FYS=&5R`%;D;G1A;F1E(')E9VES=')E<FEN9V%R
M.@!-Y&YN:7-K;W(`4')O8V5N=`!5=&;V<B!U;F1E<FCE;&QS9G5N:W1I;VYE
M<@!5=&;V<B!U;F1E<FCE;&QS86MT:79I=&5T97(@=FED(&EN;&]G9VYI;F<_
M`%)A9&5R82!HY&YD96QS96X@<&5R;6%N96YT/P!"96CV<FEG:&5T`$)E:/9R
M:6=H970@)R5S)R!R861E<F%D97,@:6YT92X`Q71K;VUS="!N96MA9`!"96CV
M<FEG:&5T97(`0F5H]G)I9VAE='-A9&UI;FES=')A=&EO;@!097)S;VYL:6<@
M:6YF;W)M871I;VX`4&5R=0!(=7-D:G5R`$9I;&EP<&EN97)N80!496QE9F]N
M`$9O=&]N`%!I=&-A:7)N`%!I>&QA<@!+;&EC:.EE<@!687(@9V]D(&ML:6-K
M82!I(&5N(&-E;&P`0F5K<N1F=&$@871T(&1U('9I;&P@<F%D97)A('9A;&0@
M<&]S=#\`0F5K<N1F=&$@871T(&1U('9I;&P@<F%D97)A(&%K='5E;&QT(&5L
M96UE;G0N`%9A<B!G;V0@86YG92!MY6YA9"!O8V@@Y7(N`%9A<B!G;V0@86YG
M92!N86UN(&;V<B!K871E9V]R:6XZ`%9A<B!G;V0@86YG92!G;V1KY&YD($E0
M+6%D<F5S<RX`5F%R(&=O9"!A;F=E(&5T="!G:6QT:6=T(&1A='5M.R!K;VYT
M<F]L;&5R82!A;G1A;&5T(&1A9V%R(&D@;>5N861E;BX`5F%R(&=O9"!A;F=E
M(&5N(&=O9&OD;F0@=&ED+@!687(@9V]D('-U;6UE<F$@9&ET="!P<F]B;&5M
M+@!!;F=E(&1I='0@86YVY&YD87)N86UN(&]C:"!L]G-E;F]R9"X`5F%R(&=O
M9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E>'0N($1U($W%4U1%('-A;71Y8VMA
M(&UE9"!V:6QL:V]R96X@9O9R(&%T="!A;G;D;F1A('-Y<W1E;65T+@!687(@
M9V]D(&SD<R!I9V5N;VT@9O9L:F%N9&4@=&5X="X@1'4@3<535$4@<V%M='EC
M:V$@;65D('9I;&QK;W)E;B!F]G(@871T(&%N=N1N9&$@<WES=&5M970N`$MO
M;G1R;VQL97)A(&;V;&IA;F1E(&EN9F]R;6%T:6]N(&]C:"!VY&QJ('-E9&%N
M(&5N(&AA;F1L:6YG(&D@;65N>6X*;F5D86XN`%;D;&H@96X@:&%N9&QI;F<@
M9G+E;B!M96YY;B!N961A;BX`06YG92!N>71T(&MA=&5G;W)I;F%M;CH`4&]L
M96X`4&]L:71I:P!5;F1E<G/V:VYI;F=A<@!0;W)T86QI;G-TY&QL;FEN9V%R
M`%!O<G1U9V%L`%!O<VET:6]N97)I;F<@878@8FEL9&5N`%!O<VET:6]N97)I
M;F<@878@=&%B96QL96X`3?9J;&EG(&WV=&5S=&ED`%-K<FEV('1I;&P@9&5N
M(&CD<B!M87!P96X@*&5J('1V:6YG870@878@24U!4"D`4&]S=&YU:V4`3F5D
M97)B]G)D(&1E('-E;F%S=&4@)7,@=&EM;6%R;F$Z(`!#:&%N<R!T:6QL/&)R
M+SYN961E<F+V<F0`075T:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K;F%S+@!0
M<F5F<U]S97-S:6]N.B!/8FQI9V%T;W)I<VMT('-E<W-I;VYS=&EL;.1G9R!H
M:71T861E<R!I;G1E+@!4<GEC:P!,=69T=')Y8VL@=FED(&AA=F5T.B``3'5F
M='1R>6-K.B``1O9R:&%N9'-V:7-N:6YG`$;V<FAA;F1S9W)A;G-K82!B:6QD
M(&D@;GET="!F]FYS=&5R`$;V<F5GY65N9&4@9&%G`$;V<F5GY65N9&4@=F5C
M:V$`1O9R96?E96YD92!D86<`1O9R96?E96YD92!I;G-TY&QL;FEN9V%R`%-K
M<FEV('5T(&1O:W5M96YT`%!R:79A=&$@;GEC:V5L`%!R;V)L96T`4')O8FQE
M;6)E<VMR:79N:6YG`%!R;VIE:W0`5&5X=`!0=6)L:6L@;GEC:V5L`%!U8FQI
M:R!N>6-K96QA;&=O<FET;0!0=6)L:6L@;GEC:V5L:6YF;W)M871I;VX`1F5L
M('9I9"!G96YE<F5R:6YG(&%V('!U8FQI:W0O<')I=F%T(&YY8VME;'!A<BX`
M4'5E<G1O(%)I8V\`4F5N<V$@;65D9&5L86YD96X`46%T87(`1G+E9V$`2W9O
M=&$`4'5B;&EK(%)302UN>6-K96P@*"5D(&)I=&%R*0!%;G-K:6QT('9A;`!2
M96=N`%1I9&EG="!R96=N`%-E;G0@<F5G;@!296=N<VMU<F%R`%)E9VX@;V-H
M('-N]@!296=N('1I;&P@<V[V`%-L=6UP;>1S<VEG="!V:7-H971S;W)D`$;V
M<FCE;&QA;F1E`$SD<P!,Y',@;65D9&5L86YD96X`4^1K97)T(&%T="!D=2!V
M:6QL(')A9&5R82`E<S\@4F%D97)I;F=E;B!K86X@:6YT92#E;F=R87,N`%/D
M:V5R="!A='0@9'4@=FEL;"!R861E<F$@86YVY&YD87)D871A(&;V<B`E<S\@
M4F%D97)I;F=E;B!K86X@:6YT92#E;F=R87,N`%5P<')E<&$@=&EL;',`57!P
M<F5P;FEN9P!);F9O<FUA=&EO;B!O;2!U<'!R97!N:6YG`%-L=71D871U;2!F
M]G(@=7!P<F5P;FEN9P!);G1E<G9A;&P@9O9R('5P<')E<&YI;F<`5'EP(&%V
M('5P<')E<&YI;F<`1&%G;&EG('5P<')E<&YI;F<`3>5N871L:6<@=7!P<F5P
M;FEN9P!696-K;W9I<R!U<'!R97!N:6YG`,5R;&EG('5P<')E<&YI;F<`1_9R
M(&]M(&1I;B!S96YA<W1E(&EN;6%T;FEN9P!5<'!D871E<F$`57!P9&%T97)A
M(&1Y;F%M:7-K82!M96YY96QE;65N=#H`57!P9&%T97)A('!O<G1A;'9Y.@!2
M96=E>`!6:7-A(&;V<FCE;&QA;F1E;@!,861D82!O;0!+;VUM96YT87)E<@!+
M;VT@:6CE9R!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;BX`4.5M:6YN
M96QS93H@)7,`1FKD<G)K86QE;F1R87(`1FKD<G)K86QE;F1R87(Z`$9JY')R
M<V5R=G)A<@!0<F5N=6UE<F%T:6]N<V%D<F5S<R`H55),*0!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!482!B;W)T`%1A(&)O<G0@)7,`
M5&$@8F]R="!D96QT86=A<F4`5&$@8F]R="!B;&]C:P!482!B;W)T(&MO;'5M
M;@!482!B;W)T(&9O<FUA=&5R:6YG`%1A(&)O<G0@9G+E;B!M:6X@:V%L96YD
M97(`5&$@8F]R="!P87(`4F%D97)A('-P87)A="!S:W)I<'0@9G+E;B!S97)V
M97)N<R!T96UP;W+D<FMA=&%L;V<N`%1A(&)O<G0`4F%D97)A(&1E;FYA(&YO
M9"!F<N5N(&1O:W5M96YT970`5&$@8F]R="!A;G;D;F1A<F4`5&$@8F]R="!A
M;G;D;F1A<F4Z("5S`$5R<^1T="!B969I;G1L:6<@:V%L96YD97(@;65D(&1E
M;B!I;7!O<G1E<F%D93\@/'-T<F]N9SY687)N:6YG.B!!;&QA('!O<W1E<B!I
M(&%K='5E;&P@:V%L96YD97(@:V]M;65R(&%T="!R861E<F%S+CPO<W1R;VYG
M/@!3=F%R('-K:6-K870N`%-V87)A(&%T="!B96?D<F%N(&EN=&4@<W3V9',`
M4W9A<F$@;65D(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N(&;V<B!K
M;VUM86YD92!T=N4@;>5N861E<BX`4W9A<F$@;65D(&1E;B!B96?D<F1A(&QE
M9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N96XN`%-V87(Z("5S`$)E9^1R86X@
M:W5N9&4@:6YT92!B97-V87)A<RX@4F5T=7)N97)A9"!F96QK;V0Z(`!$96X@
M969T97)F<N5G861E('1JY&YS=&5N(&MU;F1E(&EN=&4@:&ET=&%S+@!/8FQI
M9V%T;W)I<VMT`$5R9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N
M9FEG=7)A=&EO;F5N(&%V("5S+@!%<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG
M:79E;B!I(&MO;F9I9W5R97)I;F=E;B!A=B!61E,N`$5R9F]D<F%D("<E<R<@
MY'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)E<FEN9V5N+@!/8FQI9V%T;W)I
M<VMA(&1E;'1A9V%R90!/8FQI9V%T;W)I<VMT="!FY&QT`$]B;&EG871O<FES
M:R!D96QT86=A<F4`Q71E<G-TY&QL`,5T97)S=.1L;"!L]G-E;F]R9`#%=&5R
M<W3D;&P@;/9S96YO<F0`Q71E<G-TY&QL('1I;&P@9W)U;F1I;G-TY&QL;FEN
M9V%R`%-V87(`Q7-T97)TY&QL('-E;F%S=&4@9G+E9V%N`%)E<W5L=&%T`,5T
M97)VY&YD('1I;&P@:6YS=.1L;&YI;F=A<@!!;F=E(&YY='0@;/9S96YO<F0`
M4NEU;FEO;@#%=&5R<W3D;&P@:V]N9FEG=7)A=&EO;@!);G-TY&QL;FEN9V%R
M(&;V<B!2:6-H(%1E>'0@161I=&]R`$?E=&]R`$CV9V5R`$CV9V5R<G5B<FEK
M`$CV9V5R=N1R9&5N`%)A7V1I;G-TY&QL;FEN9V%R+BXN`%)O;&P`4G5MY&YI
M96X`4F]T97)A(#$X,`!2;W1E<F$@=N1N<W1E<@!2;W1E<F$@:/9G97(`4F%D
M:6YS=.1L;&YI;F=A<@!2861I;G-TY&QL;FEN9V%R`%)A9&5R.@!,:6YJ97(`
M3&EN:F5R('9I<V%S(&UE;&QA;B!A;&QA(')A9&5R(&]C:"!K;VQU;6YE<@!,
M:6YJ97(@=FES87,@96YB87)T(&UE;&QA;B!K;VQU;6YE<@!,:6YJ97(@=FES
M87,@96YB87)T(&UE;&QA;B!R861E<@!+]G(`4GES<VQA;F0`4G=A;F1A`%,O
M34E-12!S:6=N871U<@!3+TU)344M:W)Y<'1E<F%T(&UE9&1E;&%N9&4`4T%3
M3"UA=71E;G1I<V5R:6YG(.1R(&EN=&4@=&EL;&?D;F=L:6<N`%--4R!M961D
M96QA;F1E;@!344PM<VMA;`!344PM<V5K=F5N<R!F]G(@=7!P<VQA9R!A=B!V
MY')D96X`4U-(`$Q90TM!5`!37U%,+7-K86P`3/8`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&]C:"!.979I<P!386EN="!,=6-I80!386EN="U0:65R<F4@
M;V-H($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@;V-H($=R96YA9&EN97)N80!3
M86UM82!R86T@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&]C
M:"!0<FEN8VEP90!3871T96QI=&QE=F5R86YT]G(`3/9R9&%G`%-A=61I87)A
M8FEE;@!3<&%R80!3<&%R82`G)7,G`%-P87)A("5S`%-P87)A('-O;2!N>0!3
M<&%R82!D96QT86=A<F4`4W!A<F$`4W!A<F$@:6YS=.1L;&YI;F=A<@!3<&%R
M82!G96YE<F5R860@:V]N9FEG=7)A=&EO;B!S;VT@4$A0+7-K<FEP="!T:6QL
M(&1I;B!S97)V97)S("!T96UP+6MA=&%L;V<N`%-P87)A9&4@:V]N9FEG=7)A
M=&EO;B!F]G(@)7,N`%-P87)A9&4@=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL
M.B`E<RX`4W!R:61D82#E<VMS:W5R87(`5F5T96YS:V%P`%/V:P!3]FL@:V%L
M96YD<F%R`%/V:VUO=&]R97(`4_9K<F5S=6QT870`4_9K(&;V<B!K86QE;F1R
M87(@<V]M(&EN;F5HY6QL97(Z`%;D;&H@9FEL97(`5N1L:B!K86QE;F1E<B!S
M;VT@<VMA;&P@<F5D:6=E<F%S`%;D;&H@971T(&1A='5M`%;D;&H@9W)U<'`@
M871T(&SD9V=A('1I;&P`5N1L:B!N>2#D9V%R90!6Y&QJ('-E<G9E<@!6Y&QJ
M(&%N=N1N9&%R92!A='0@;.1G9V$@=&EL;`!6Y&QJ(&%L;&$`5N1L:B!D871U
M;6MO;7!O;F5N=&5R+@!6Y&QJ(&5T="!O8FIE:W0`5FES82!K86QE;F1R87(Z
M`%;D;&H@:6YS=.1L;&YI;F=A<B!F]G(@8F5K<N1F=&5L<V5R(&]C:"!H=7(@
M=GEE<B!S:V%L;"!V:7-A<R!S86UT(&;V<G9A;&0@=GDN`%;D;&H@:6YG96X`
M5N1L:B!K86QE;F1E<B!A='0@:6UP;W)T97)A('1I;&PZ`%;D;&H@:V%L96YD
M97(O:V%L96YD<F%R(&%T="!E>'!O<G1E<F$@9G+E;CH`06YG92!D92!T96-K
M96X@9'4@8F5H]G9E<B!I(')U=&]R;F$@;F5D86XN($1U(&MA;B!S961A;B!K
M;W!I97)A(&]C:"!K;&ES=')A(&EN(&1E;2!I('1E>'1A<G5T86XN`%;D;&H@
M879G<N1N<V%R92!F]G(@9&%T=6TZ`%;D;&H@9&%T=6UF;W)M870Z`%;D;&H@
M97AP;W)T9F]R;6%T.@!6Y&QJ(&9I;"!S;VT@<VMA;&P@:6UP;W)T97)A<SH`
M5N1L:B!F]G)S=&$@=F5C:V]D86=E;CH`5N1L:B!F;W)M870@<.4@:6UP;W)T
M9FEL96XZ`%;D;&H@:61E;G1I=&5T(&1U('9I;&P@Y&YD<F$Z`%;D;&H@879G
M<N1N<V%R92!F]G(@=&ED.@!6Y&QJ('1I9'-F;W)M870Z`%;D;&H@=&ED<VEN
M=&5R=F%L;"!S;VT@<VMA;&P@=FES87,Z`%;D;&H@=GD@<V]M('9I<V%S('9I
M9"!S=&%R=#H`5N1L:B!T=N4@;6%T8VAA;F1E(&;D;'0Z`%;D;&H@=FEL:V$@
M:.1N9&5L<V5R('-O;2!S:V%L;"!V:7-A<R!I('!O<G1A;&5N+@!6Y&QJ(&1I
M='0@9N1R9W-C:&5M82X`06YG92!D:71T(&;V<G9A;&1A('-P<N5K.@!3:VEC
M:V$@<V5N87-T92!I;F9O<FUA=&EO;F5N`%-K:6-K82!P<F]B;&5M<F%P<&]R
M=`!3:VEC:V$@4TU3`%-K:6-K82!E;B!A;FYU;&5R:6YG<VYO=&EF:65R:6YG
M('1I;&P@86QL82!D96QT86=A<F4@;N1R(&CD;F1E;'-E;B!R861E<F%S`%-K
M:6-K82!M961D96QA;F1E('1I;&P@)7,`4VMI8VMA('5P<&1A=&5R:6YG+VEN
M8FIU9&YI;F=A<B!T:6QL(&%L;&$@9&5L=&%G87)E(&[D<B!HY&YD96QS96X@
M<W!A<F%S`%-E;F5G86P`4V5N<V]R.B``<V5P=&5M8F5R`%-E<F)I96X@;V-H
M($UO;G1E;F5G<F\`4V5R:65N=6UM97(`4V5R=F5R:6YS=.1L;&YI;F=A<B!F
M96QA:W1I9V$@96QL97(@:6YA:W1I=B!S97)V97(N`%-E<W-I;VYS861M:6YI
M<W1R871I;VX`4V5S<VEO;G,M240@:&%R(&?E='0@=70N`%-E<W-I;VYE<@!3
MY'1T`$%N9V4@<VQU=&1A='5M`$MO;F9I9W5R97)A(&%L=&5R;F%T:78@<V]M
M(&WV:FQI9V?V<B#E=&5R<W3D;&QN:6YG(&%V(&)O<G1G;/9M="!L]G-E;F]R
M9"X`06YG92!S;'5T9&%T=6T@9O9R('5P<')E<&YI;F<`06YG92!S=&%R=&1A
M='5M`$MO;F9I9W5R97)A(&9JY')R<V5R=G)A<B!S;VT@9'4@=FEL;"!K;VUM
M82#E="!F<N5N(&1I;B!P;W)T86PN`$%N9V4@9&EN82!O8V@@86YD<F%S(&EN
M<W3D;&QN:6YG87(@9O9R(&QE9&EG+W5P<'1A9V5N+@!!;F=E(&1I='0@9O9R
M=F%L9&$@<W!RY6LL('1I9'-Z;VX@8V]H(&1A='5M:6YS=.1L;&YI;F=A<BX`
M4^1T="!D:71T(&EN:71I86QA(&%P<&QI:V%T:6]N+"!FY')G<V-H96UA+"!S
M:61U<'!D871E<FEN9R!O8V@@86YD<F$@=FES;FEN9W-I;G-TY&QL;FEN9V%R
M+@!3971U<`!+;VYF:6=U<F%T:6]N<W5P<&=R861E<FEN9W-S:W)I<'0@9FEN
M;G,@=&EL;&?D;F=L:6=A`$1E="!F:6YN<R!F;&5R82!O<G1E<B!M960@<&%R
M86UE=&5R;CH`4V5Y8VAE;&QE<FYA`%5T9&5L;FEN9R!S86MN87,Z("5S`$1E
M;&%D92!K86QE;F1R87(`1&5L861E(&MA;&5N9')A<CH`2&%N9&5L`$MO<G0@
M<W5M;65R:6YG`%-K86QL(&=E;G;D9W-T86YG96YT97(@9&5F:6YE<F%S(&;V
M<B!D92!F;&5S=&$@;.1N:V%R/P!6:7-A`%9I<V$@:V%L96YD97(`5FES82!F
M]G)K;&%R:6YG(&;V<B!K871E9V]R:65R/P!6:7-A(&EK;VYE<B!F]G(@<F%D
M97)A+"!A;&%R;2!O8V@@Y71E<FMO;6UA;F1E(&D@:V%L96YD97)V>65R/P!6
M:7-A('-K:6QL;F%D97(@;65L;&%N(&1E;B!A:W1U96QL82!O8V@@9&5N(&YY
M;&EG96X@<VMA<&%D92!K;VYF:6=U<F%T:6]N96XN`%9I<V$@9O9R9F%L;&YA
M('5P<&=I9G1E<B!I(&MA;&5N9&5R;C\`5FES82!F]G)K;&%R:6YG(&;V<B!I
M;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;C\`5FES82!S96YA<W1E(&EN
M;&]G9VYI;F=S=&ED('9I9"!I;FQO9V=N:6YG/P!6:7-A(&5N8F%R="!HY&YD
M96QS97(@;65D(&%L87)M/P!6:7-A(&EN<W3D;&QN:6YG(&;V<B!A='0@8F5H
MY6QL82!O<FEG:6YA;`!6:7-A('!A;&5T=`!6:7-A(&1E;&%D92!K86QE;F1R
M87(@<VED82!V:60@<VED83\`5FES82`G=&%B96QL86MT:79I=&5T97(G(&D@
M;65N>6X_`%9I<V$@=7!P9VEF=&5R(&UE9"!K871E9V]R:6;D<F=E<C\`5FES
M82!M96YY(&;V<B`E<R!T:6QL(';D;G-T97(_`%1A8F5L;&-E;&QI;G-TY&QL
M;FEN9V%R`%1A8F5L;&EN<W3D;&QN:6YG87(`5&%B96QL:6YS=.1L;&YI;F=A
M<@!6:7-A(&1I86QO9W)U=&$@9O9R(&)I;&1E9V5N<VMA<&5R`%9I<V$@:VQO
M8VMS;&%G(&UE;&QA;B!V87)J92!D86<@:2!V96-K;W9Y/P!6:7-A('5P<&QA
M9&1N:6YG`%-K=7)A<@!4:61I9V$@<VMU<F%R`%-E;F$@<VMU<F%R`%-K=7)A
M<B!I(&[D<FAE=&5N`$;V<FUI;G-K80!+<GEM<"!E;&QE<B!F;'ET=&$@8F]R
M="!NY')L:6=G86YD92!B;&]C:R!F]G)S=`!3:65R<F$@3&5O;F4`4F5G:7-T
M<F5R80!3:6=N871U<@!3:6=N871U<F%L9V]R:71M`%-I;7!L97@`4VEN9V%P
M;W)E`%-T;W)L96L`079B<GET('5N9&5R:.5L;`!3;&]V86MI96X`4VQO=F5N
M:65N`%-N]@!3;O9S:W5R`%-N]G-K=7)A<@!4:61I9V$@<V[V<VMU<F%R`%-E
M;F$@<V[V<VMU<F%R`%-N]F1J=7`Z(`!-;W1S=F%R86YD92!S;O8@:2!V871T
M96XZ(`!386QO;6]N]F%R;F$`4V]M86QI80!3Y6YG97(@;V-H(&1I:W1E<@!3
M;W)T97)I;F=S:6]R9&YI;F=S=F%L`&OD;&QA9')E<W,`4WED869R:6MA`%/V
M9')A($=E;W)G:6$@;V-H(%-Y<W-A;F1W:6-H]F%R;F$`4^1D<F$@:&5M:7-F
MY')E;@!5=')Y;6UE(&UE;&QA;B!I;G1I;&QI9V=A;F1E(&-E;&QE<@!5=')Y
M;6UE(&UE;&QA;B!I;FYE:.5L;"!O8V@@:V%N=&5N(&D@8V5L;&5N`$UE;&QA
M;G)U;0!-96QL86YR=6T`365L;&%N<G5M(&]C:"!U=&KD;6YI;F<`4W!A;FEE
M;@!3<&%M`$EN;6%T;FEN9R!A=B!S<&5C:65L;&$@=&5C:V5N`$1E;&$@8V5L
M;`!$96QA(&MO;'5M;@!$96QA(')A9`!3<&]R=&5R`%-R:2!,86YK80!3=&%?
M<G1A(&1E;@!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0`4W1A<G1D871U;0!3
M=&%R=&$@9&5N`%-T87)T=&ED`%-T87)TY7(`4W1A=%]U<P!3=&%T(&5L;&5R
M(')E9VEO;@!3=&%T=7,`3&%G<FEN9W-F;W)M870`1V%T=6%D<F5S<P!'96YO
M;7-T<G5K96X`4W1RY&YG;&ES=&$`5&$@8F]R="!D;VWD;B!F<N5N(&%D<F5S
M<V5N`%-T:6P@6T-34UT`4_8`2V%N(&EN=&4@:&ET=&$@=6YD97)K871A;&]G
M("<E<R<N`,1R96YD90!3:VEC:V$`1&EN(&)E9^1R86X@871T(&SD9V=A('1I
M;&P@(B5S(B!T:6QL('-Y<W1E;65T(&AA<B!S:VEC:V%T<RX@1'4@:V%N(&EN
M=&4@;&]G9V$@:6X@:6YN86X@9&EN(&)E9^1R86X@:&%R(&%C8V5P=&5R871S
M+@!.961SY&YK=`!,>6-K870`)R5S)R!L861E<R!T:6QL(&D@<WES=&5M970N
M`%)A9&5R861E(&EN9F]R;6%T:6]N(&]M(&%N=N1N9&%R92`G)7,G+@`G)7,G
M(')A9&5R861E<RX`)R5S)R!T;V=S(&)O<G0@9G+E;B!S>7-T96UE="X`2V]N
M9FEG=7)A=&EO;F5N(&AA<B#E=&5R<W3D;&QT<RX@3&%D9&$@;VT@<VED86X@
M9O9R(&%T="!S92!F]G+D;F1R:6YG87(N`%-P87)A9&4@8F%C:W5P:V]N9FEG
M=7)A=&EO;BX`4W!A<F%D92!B86-K=7!K;VYF:6=U<F%T:6]N("5S+@`G)7,G
M('5P<&1A=&5R861E<RX`4VMR978@)7,`4W5D86X`4V%M;6%N<W3D;&QN:6YG
M`%-O;'5P<&?E;F<`4V]L;F5D9^5N9P!3]FYD86<`4V]L:6=T`%-O;'5P<&?E
M;F<`4V]L=7!P9^5N9R]N961GY6YG`%-O;'5P<&?E;F<Z(`!3;VQN961GY6YG
M`%-O;&YE9&?E;F<Z(`!5<'!H]FID`%-U<'!O<G0`4W5R:6YA;64`169T97)N
M86UN`%-V86QB87)D(&]C:"!*86X@36%Y96X`4W=A>FEL86YD`%-V97)I9V4`
M4V-H=V5I>@!3>6MR;VYI<V5R:6YG<VQO9V<@<F%D97)A9`!3>6YC34P`4WEN
M=&%X9F5L(&D@<_9K:W)I=&5R:6$`4WER:65N`,5S:W-K=7(`Q7-K<VMU<F%R
M(&]C:"!B;.5S:6=T`,5S:W-K=7)A<@!4:61I9V$@Y7-K<VMU<F%R`%135BUF
M:6P`5&%B96QL`%1A8F5L;&EN<W3D;&QN:6YG87(`5&%B96QL=7!P<^1T=&YI
M;F<`5&%B96QL:6YS=.1L;&YI;F=A<@!486EW86X`5&%I=V%N`%1A:FEK:7-T
M86X`5&%N>F%N:6$`3>5L.@!5<'!G:69T97(`5&5A;`!496QE9F]N;G5M;65R
M`$CV9W-T82!T96UP97)A='5R('-E;F%S=&4@=&EM;65N.B``5&5M<&5R871U
M<@!496UP97)A='5R.B``5&5M<&5R871U<CQB<B`O/B@E<TUA>"5S+R5S36EN
M)7,I("9D96<[)7,`2V%N(&EN=&4@:&ET=&$@;6%L;"`E<RX`06YVY&YD87)A
M9&UI;FES=')A=&EO;@!0<F5L:6UI;N1R`$=O9&OD;FX@8F5GY')A;B!P<F5L
M:6UI;N1R=`!0<F5L:6UI;N1R="!A8V-E<'1E<F%T`%1E>'0`16YB87)T('1E
M>'0`5&5X=&IU<W1E<FEN9P!497AT=&]P`%1O`%1H86D@*%1)4RTV,C`I`%1H
M86EL86YD`%1A8VL@9O9R(&%T="!D=2!A;G;D;F1E<B!S>7-T96UE="X`3.1N
M:V5N("5S('1I;&P@)7,@:&%R(')A9&5R871S+@!6>6X@9O9R(')E9&EG97)I
M;F<@878@9&5L=&%G87)E(.1R(&EN=&4@=&EL;&?D;F=L:6<@;.1N9W)E+B!!
M=G-L=71A<BX`1E10+71I;&SD9V=E="#D<B!I;G1E('1I;&QGY&YG;&EG="X`
M2&ES=&]R:6MS>7-T96UE="#D<B!A=F%K=&EV97)A="X`2&]R9&4O2V]L86(M
M:6YT96=R871I;VYS9W+D;G-S;FET=&5T('-T]F1E<B!I;G1E("(E<R(`24U3
M4"UL;V=G96X@:W5N9&4@:6YT92!I;FET:65R87,N`$ML87-S96X@36%I;G1E
M;F%N8V4Z.B!K=6YD92!I;G1E(&QA9&1A<P!);G-TY&QL;FEN9W-F]FYS=')E
M="!H87(@<W3D;F=T<RX@079S;'5T87(N`$%D;6EN:7-T<F%T]G)E;B!MY7-T
M92!K;VYF:6=U<F5R82!E;B!P97)M86YE;G0@0F5H]G)I9VAE=',M:V]P<&QI
M;F<@;VT@9'4@=FEL;"!A;G;D;F1A($)E:/9R:6=H971E<BX`16YB87)T(&YE
M9')E('-I9&%N`$MA;&5N9&5R("<E<R<@:W5N9&4@:6YT92!R861E<F%S+@!+
M86QE;F1E<B`G)7,G('-K87!A9&5S+@!+86QE;F1E<B`G)7,G(')A9&5R861E
M<RX`3F%M;F5T('#E(&MA;&5N9&5R("<E<R<@:&%R(.1N9')A=',@=&EL;"`G
M)7,G+@!+86QE;F1E<FX@)R5S)R!S<&%R861E<RX`2V%L96YD97(@)R5S)R!K
M=6YD92!I;G1E(')E;G-A<RX`2V%L96YD97)I;F9O<FUA=&EO;F5N(.1R(&9E
M;&%K=&EG`$MO;G1A:W1E;G,@240@86YG879S(&EN=&4@96QL97(@:W5N9&4@
M:6YT92!H:71T87,@:2!D871A8F%S96XN`$MO;G1A:W1E;B!L861E<R!T:6QL
M(&D@861R97-S8F]K96XN`$1E;B!L]G-G:F]R9&$@4$=0+7-I9VYA='5R96X@
M:W+D=G,@9O9R(&%T="!V97)I9FEE<F$@9&5T('-I9VYE<F%D92!M961D96QA
M;F1E="X`1&ES=')I8G5T:6]N<VQI<W1A;G,@240@86YG879S(&EN=&4@96QL
M97(@:W5N9&4@:6YT92!H:71T87,@:2!D871A8F%S96XN`$1I<W1R:6)U=&EO
M;G-L:7-T86X@:&%R(&EN=&4@86YG:79I=',N`$MR>7!T97)I;F=S9G5N:W1I
M;VYE<FYA(&MRY'9E<B!E;B!SY&ME<B!W96)F]G)B:6YD96QS92`H2%144%,I
M+@!3;'5T9&%T=6T@;>5S=&4@=F%R82!S96YA<F4@Y&X@<W1A<G1D871U;0!(
MY&YD96QS92`G)7,G(&AA<B!S:V%P871S(&D@:V%L96YD97)N("5S+"!D96X@
M)7,@:VP@)7,N`$CD;F1E;'-E("<E<R<@:&%R(')A9&5R871S(&9RY6X@)7,L
M(&1E;B`E<R!K;"`E<RX`2.1N9&5L<V4@)R5S)R`H)7,I(&AA<B#D;F1R871S
M.R!HY&YD96QS96X@Y'(@9&5N("5S(&ML("5S+@!(Y&YD96QS96X@;&%D97,@
M=&EL;"!I(&MA;&5N9&5R;BX`2.1N9&5L<V5N;W1I9FEE<FEN9R!T:6QL("5S
M(&AA<B!S:VEC:V%T<RX`1FEL96X@)7,@<VMA;&P@:6YN96CE;&QA(&5N(&EN
M<W3D;&QN:6YG(&;V<B`E<RX`1FEL96X@)7,@<VMA;&P@:6YN96CE;&QA(&EN
M<W3D;&QN:6YG87(@9O9R("5S+@!&:6QE;B!K86X@:6YT92!K;W!I97)A<R!T
M:6QL('-I9R!S:N1L=BX`1FEL96X@:V%N(&EN=&4@:V]P:65R87,@=&EL;"!S
M:6<@<VKD;'8N`$9I;&5N(&EN;F5H]FQL(&EN9V5N(&EN9F]R;6%T:6]N+@!(
M=79U9&;D;'0@9O9R(&1E='1A(&UE9&1E;&%N9&4O<F9C.#(R;65D9&5L86YD
M92!F]FQJ97(`1O9L:F%N9&4@Y'(@96X@;65R(&1E=&%L:F5R860@8F5S:W)I
M=FEN9R!A=B!HY&YD96QS96XZ`$ED96YT:71E=&5N("<E<R<@<F%D97)A9&5S
M+@!"87)A(';D;G-T97(@<VED80!,Y&YK96X@:&%R('1A9VET<R!B;W)T`%/V
M:W;D9V5N('1I;&P@1VYU4$<M<')O9W)A;6UE="!MY7-T92!V87)A(&%N9VEV
M96X@=&EL;"!K;&%S<V5N($-R>7!T7W!G<#HZ+@!-961D96QA;F1E="!S:VEC
M:V%T("5S('1I;&P@)7,@;65D(.1R96YD92`B)7,B(&AA<B!V:7-A=',N"D1E
M='1A(.1R(&EN9V5N(&=A<F%N=&D@9O9R(&%T="!M961D96QA;F1E="!H87(@
M;.1S=',N`$YA;6YE="!S;VT@<VMA;&P@86YVY&YD87,@9O9R(&%T="!LY&YK
M82!T:6QL('-K87!A+7-I9&%N`$%N=&%L(&;D;'0@;>5S=&4@=F%R82!E='0@
M;G5M97)I<VMT(';D<F1E+@!-;V1U;&5N(&]P96YS<VP@:W+D=G,@878@:VQA
M<W-E;B!(;W)D95]#<GEP=%]S;6EM93HZ+@!);G-TY&QL;FEN9V5N("(E<R(@
M:W5N9&4@:6YT92!S<&%R87,@<.4@9W)U;F0@878@871T(&1A=&%MY&YG9&5N
M(/9V97)S:W)I=F5R(&1E;B!M87AI;6%L="!T:6QLY71N80!0<F]G<F%M;65T
M('-O;2!A;G;D;F1S(&;V<B!A='0@=FES82!D96X@:.1R(&UE9&1E;&%N9&5T
M>7!E;B`H)7,I('-A:VYA<R!PY2!S>7-T96UE="X`5&5C:VYE="!F]G(@8VET
M97)I;F<@;>5S=&4@=F%R82!E='0@=&5C:V5N+@!"96?D<F%N(.1R(&EN=&4@
M:V]M<&QE='0N($[E9W)A('!A<F%M971R87(@<V]M(&MRY'9S(&;V<B!A='0@
M86-C97!T97)A(&5L;&5R(&%V8O9J82!S86MN87,N`$)A<F$@:/9G97(@;V-H
M(';D;G-T97(@<VED;W(`0F%R82!H]F=E<B!S:61A`%-E<&%R871O<FX@;>5S
M=&4@=F%R82!E='0@=&5C:V5N+@!397)V97(@)R5S)R!R861E<F%D97,N`%-E
M<G9E<B`G)7,G('-P87)A9&5S+@!0<F5N=6UE<F%T:6]N<V)E9^1R86X@9O9R
M("5S(&AA<B!T86=I=',@8F]R="X`06YG:79E;B!R860@*"5D*2!F:6YN<R!I
M;G1E+@!!;F=I=F5N(')A9"!E>&ES=&5R87(@:6YT92X`57!P9VEF=&5N(&AA
M<B!L86=T<R!T:6QL(&D@9&EN('5P<&=I9G1S;&ES=&$N`%1E;7!O<N1R(&9I
M;"`G)7,G(&9I;FYS(&EN=&4N`%1E>'1E;B!D=2!M871A="!I;B!S=.1M;65R
M(&EN=&4@]G9E<F5N<R!M960@=&5X=&5N('#E('-KY')M96X`0F%R82!T;W!P
M(&]C:"!B;W1T96X@<VED80!"87)A('1O<'!S:61A`%5P<&QA9&1A="!D871A
M(&;V<G-V86YN('-E9&%N(&;V<F5GY65N9&4@<W1E9RX`1&5N('5P<&QA9&1A
M9&4@9FEL96X@:W5N9&4@:6YT92!S<&%R87,N`$QE9&EG+W5P<'1A9V5N+6EN
M9F]R;6%T:6]N(&;V<B!A;G;D;F1A<F5N(&AA<B!S<&%R871S+@!796%T:&5R
M+F-O;2UB;&]C:V5T(.1R(&EN=&4@=&EL;&?D;F=L:6=T+@!496UA:V%T86QO
M9R`G)7,G(&9I;FYS(&EN=&4N`$EN9V$@:.1N9&5L<V5R(&UA=&-H87(@86MT
M=65L;'0@=7)V86PN`$EN9V$@:6YS=.1L;&YI;F=A<B!T:6QL9^1N9VQI9V$N
M`$1E="!F:6YN<R!I;F=A(&%L=&5R;F%T:79A(&1E;&%R('-O;2!K86X@=FES
M87,@:6YL:6YE+@!&]G(@;>5N9V$@=&5C:V5N(&D@9N1L=&5T+B!$=2!H87(@
M86YG971T("5S('1E8VME;CL@;6%X:6UA;'0@86YT86P@=&5C:V5N(.1R("5S
M+@!0<F]B;&5M(&UE9"!A='0@;.1G9V$@=&EL;"`G)7,G('1I;&P@<WES=&5M
M970Z("5S`%!R;V)L96T@;65D(&%T="!R96YS82!I;F9O<FUA=&EO;B!O;2!A
M;G;D;F1A<F4@)R5S)R!F<N5N('-Y<W1E;65T.B``4')O8FQE;2!M960@871T
M('1A(&)O<G0@)R5S)R!F<N5N('-Y<W1E;65T.B``4')O8FQE;2!V:60@=7!P
M9&%T97)I;F<@878@)R5S)SH@)7,`4')O8FQE;2!V:60@=7!P;&%D9&YI;F<@
M878@9FEL96XN($EN9V$@)7,@;&%D9&%D97,@=7!P+@!$970@=7!P<W1O9"!P
M<F]B;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;CH@)7,@Y'(@<W3V<G)E
M(.1N(&UA>&EM86QT('1I;&SE=&5N('-T;W)L96L@*"5D(&)Y=&5S*2X`1&5T
M('5P<'-T;V0@<')O8FQE;2!V:60@=7!P;&%D9&YI;F<@878@9FEL96XZ("5S
M(&QA9&1A9&5S(&5N8F%R="!U<'`@9&5L=FES+@!&96P@=FED(.5T:V]M<W0@
M878@:V%L96YD97)N.B`E<P!$970@=7!P<W1O9"!F96P@=FED('1I;&SD9V<@
M878@:.1N9&5L<V5N.B`E<P!$970@=7!P<W1O9"!E='0@9F5L('9I9"!V:7-N
M:6YG(&%V(&UE9&1E;&%N9&5D96QE;BX`1&5T('5P<'-T;V0@9F5L('9I9"!R
M961I9V5R:6YG(&%V(&CD;F1E;'-E;CH@)7,`1F5L('9I9"!I;7!O<G0@878@
M:V]N=&%K=&1A=&$N`$9E;"!V:60@:6UP;W)T(&%V(&CD;F1E;'-E;CH@)7,N
M`$9E;"!V:60@:6UP;W)T(&%V(&E#86QE;F1A<B!D871A+@!&96P@=FED(&EM
M<&]R="!A=B!U<'!G:69T96XZ("5S+@!&96P@=FED(&EM<&]R="!A=B!I;F9O
M<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;CH@)7,N`$5T="!F96P@<.5T<N1F
M9F%D97,@:2!F;W)M=6SD<F5T+B!+;VYT<F]L;&5R82!A='0@9'4@:6YT92!G
M;/9M="!F>6QL82!I(&5T="!O8FQI9V%T;W)I<VMT(&;D;'0N`$1E="!U<'!S
M=&]D(&9E;"!V:60@9FQY='0@878@:.1N9&5L<V4Z("5S+@!$970@9VEC:R!I
M;G1E(&%T="!U=&;V<F$@9&5N(&)E9^1R9&$@861R97-S8F]K<V9U;FMT:6]N
M96XN(%9A<B!G;V0@9O9R<_9K('-E;F%R92X`1&5T('5P<'-T;V0@9F5L('9I
M9"!SY&YD;FEN9R!A=B!N;W1I9FEE<FEN9R!T:6QL("5S.B`E<P!&96P@=FED
M('5P<&1A=&5R:6YG(&%V(&MO;G1A:W1U<'!G:69T97(N($;V<G/V:R!I9V5N
M('-E;F%R92X`1F5L('9I9"!U<'!D871E<FEN9R!A=B!D:7-T<FEB=71I;VYS
M;&ES=&%N+B!&]G)S]FL@:6=E;B!S96YA<F4N`$EN9V$@:.1N9&5L<V5R(&%T
M="!E>'!O<G1E<F$N`$1I;B!)34%0+7-E<G9E<B!S=/9D97(@:6YT92!D96QA
M9&4@;6%P<&%R+@!$96YN82!H86YD;&EN9R!S=/9D<R!I;G1E+@!$96YN82!F
M=6YK=&EO;B#D<B!I;G1E(&EM<&QE;65N=&5R860@Y&XN`$9I;&5N('9E<FMA
M<B!I;G1E('9A<F$@971T(&=I;'1I9W0@4D%2+6%R:VEV+@!&:6QE;B!V97)K
M87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%I)4"UA<FMI=BX`1F5L86MT:6=T
M(&MO<G1N=6UM97(N`$1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@
M871T('-K:6-K82!M961D96QA;F1E;B!V:6$@0VQI8VMA=&5L;"UB<GEG9V%N
M("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=E;F]M(&%T="!A;G;D;F1A($A4
M5%`@05!).G0N`$1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T
M('-K:6-K82!M961D96QA;F1E;B!V:6$@5TE.+6)R>6=G86X@*&AT='`Z+R]W
M:6YP;&,N8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT`$1E;FYA
M(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K:6-K82!M961D96QA
M;F1E;B!V:6$@<VUS,F5M86EL+6)R>6=G86X@*&AT='`Z+R]S;7,R96UA:6PN
M8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT`$1E;FYA(&1R:79R
M=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K:6-K82!M961D96QA;F1E;B!V
M:6$@4TU44"!G96YO;2!6;V1A9F]N92!)=&%L:65N+6)R>6=G86X@*&5N8F%R
M="!T:6QL(%9O9&%F;VYN=6UM97(I+B!$<FEV<G5T:6YE;B!K<N1V97(@971T
M(&4M<&]S=&MO;G1O(&AO<R!6;V1A9F]N92!)=&%L:65N("AH='1P.B\O=W=W
M+C$Y,"YI="DN`$;D;'1E="!MY7-T92!V87)A(&EF>6QL="X`1N1L=&5T(&;E
M<B!E;F)A<G0@:6YN96CE;&QA(&AE;'1A;"X`1N1L=&5T(&;E<B!E;F)A<G0@
M:6YN96CE;&QA('-I9F9R;W(@;V-H(&MO;&]N+@!&Y&QT970@9N5R(&5N8F%R
M="!I;FYE:.5L;&$@;VMT86QA('1A;"X`1N1L=&5T('-K86QL('9A<F$@96X@
M:V]M;6$M(&5L;&5R(&UE;&QA;G-L86=S<V5P87)A<F%D(&QI<W1A(&UE9"!H
M96QT86P`1N1L=&5T(&WE<W1E('9A<F$@971T(&=O9&OD;G0@=&%L+@!$971T
M82!FY&QT(&WE<W1E(&EN;F5HY6QL82!E;B!21T(M9N1R9VMO9"!I(&AE>&%D
M96-I;6%L="!F;W)M870L('0@97@@)R,Q,C,T868G+@!&:6QF;W)M871E="!S
M=/9D<R!I;G1E+@!$971T82!F;W)M=6SD<B!H87(@<F5D86X@8F5A<F)E=&%T
M<RX`1&5T(&CD<B#D<B`E<RX`4V5R=F5R;B!S=F%R861E.B`E<P!-961D96QA
M;F1E="!S:W)E=G,@:2!E;B!A;FYA;B!T96-K96YU<'!SY'1T;FEN9R`H)7,I
M(.1N(&1I;B!E9V5N+@!$970@:.1R(&YU;7)E="!MY7-T92!V87)A(&UI;G-T
M(&5T="X`4V5R=F5R;B!K86X@:6YT92!P86-K82!U<'`@>FEP(&]C:"!G>FEP
M(&9I;&5R+@!3>7-T96UE="#D<B!F]G(@=&EL;&;D;&QE="!A=F%K=&EV97)A
M="X`1&5T(&CD<B!VY')D970@;>5S=&4@=F%R82!N=6UE<FES:W0N`$1E='1A
M(&;V;G-T97(@;>5S=&4@86YR;W!A<R!F<N5N(&5T="!K;VYF:6=U<F%T:6]N
M<V;V;G-T97(`Q7-K80!4;W)S9&%G`,1R96YD96X`5&ED`%1I9'-S<%]A;FX`
M5&ED<W)E9&]V:7-N:6YG`%1I9'-F;W)M870`5&ED<W9A;`!4:61S<W!A;FX`
MUG-T=&EM;W(`5&ET95]L`%1I=&5L`%)U8G)I:R`H=&]O;'1I<"DZ`%1I;&P`
M1O9R(&%T="!M87)K97)A(&9L97)A('9A;"P@:.5L;"!N960@0W1R;"`H4$,I
M(&5L;&5R($-O;6UA;F0@*$UA8RD@=&%N9V5N=&5N(&[D<B!D=2!K;&EC:V%R
M+@!)9&%G`%9I<V$@2%1-3"UKY&QL80!4;V=O`%1O:V5L874`26UO<F=O;@!4
M;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0#6=F5R<^1T=&YI;F=A<@!4<FEN
M:61A9"!O8V@@5&]B86=O`%-A;G0@96QL97(@9F%L<VMT`%1I`%1I<V1A9P!4
M=6YI<VEE;@!4=7)K:65T`%1U<FMI<VL@*$E33RTX.#4Y+3DI`%1U<FMM96YI
M<W1A;@!4=7)K<RT@;V-H($-A:6-O<_9A<FYA`%1U=F%L=0!4>7``06YG92!D
M:71T('9A;#H@`%56+6EN9&5X.B``55),`%523"!F]G(@9&ET="!L979E<F%N
M<W)A<'!O<G1E<FEN9W-S:W)I<'0`55),.@!59V%N9&$`56MR86EN80!+86X@
M:6YT92!LY'-A(%9&4RUM87!P+@!$970@9VEC:R!I;G1E(&%T="!LY&=G82!T
M:6QL('5T]FMA9"!A;G;D;F1A<FEN9F]R;6%T:6]N('9I9"!R96=I<W1E<FEN
M9RX`2V%N(&EN=&4@Y&YD<F$@8F5H]G)I9VAE="!F]G(@5D93+69I;"`E<RX`
M2V%N(&EN=&4@Y&YD<F$@8F5H]G)I9VAE="!F]G(@5D93+69I;"`E<R\E<RX`
M2V%N(&EN=&4@Y&YD<F$@=&EL;"`E<RX`2V%N(&EN=&4@:V]N=')O;&QE<F$@
M9FEL<W1O<FQE:R`E<R\E<P!+86X@:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R
M;&5K('#E("5S+@!+86X@:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R;&5K('#E
M("5S+R5S+@!+86X@:6YT92!K;VYT86MT82!344PM<V5R=F5R+@!+86X@:6YT
M92!K;VYT86MT82!V:6$@4U-,+@!+86X@:6YT92!K;W!I97)A(%9&4RUF:6PN
M`$MA;B!I;G1E('-K87!A(%9&4RUM87!P("5S+@!+86X@:6YT92!S:V%P82!6
M1E,M;6%P<"X`2V%N(&EN=&4@<VMA<&$@5D93+69I;"X`2V%N(&EN=&4@<VMA
M<&$@5D93+6UA<'`@)R5S)RX`2V%N(&EN=&4@<VMA<&$@=&]M(%9&4RUF:6PN
M`$MA;B!I;G1E('!A8VMA('5P<"!D871A+@!+86X@:6YT92!R861E<F$@)7,L
M(&UA<'!E;B#D<B!I;G1E('1O;2X`2V%N(&EN=&4@<F%D97)A("<E<R<Z("5S
M`$MA;B!I;G1E(')A9&5R82`G)7,G.B`E<P!+86X@:6YT92!R861E<F$@)7,L
M(&UA<'!E;B#D<B!I;G1E('1O;2X`2V%N(&EN=&4@<F%D97)A("<E<R<N`$MA
M;B!I;G1E(')A9&5R82!61E,M;6%P<"!R96MU<G-I=G0N`$MA;B!I;G1E(')A
M9&5R82!61E,M;6%P<"X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P.B`E<RX`
M2V%N(&EN=&4@<F%D97)A(%9&4RUF:6P@)7,N`$MA;B!I;G1E(')A9&5R82!6
M1E,M9FEL+@!+86X@:6YT92!R861E<F$@5D93+6UA<'`@)R5S)RX`2V%N(&EN
M=&4@<F%D97)A(%9&4R!R96MU<G-I=G0Z("5S+@!+86X@:6YT92!A=F?V<F$@
M86MT=65L;"!M87!P+@!+86X@:6YT92!E>'1R86AE<F$@0V5R=&EF:6MA='-D
M971A;&IE<@!+86X@:6YT92!L861D82!D969I;FET:6]N96X@878@)7,N`$MA
M;B!I;G1E(&9L>71T82!61E,M9FEL+@!+86X@:6YT92#V<'!N82!61E,M9FEL
M("5S+@!+86X@:6YT92#V<'!N82!61E,M9FEL(&;V<B!S:W)I=FYI;F<N`$MA
M;B!I;G1E(/9P<&YA(%9&4RUF:6PN`$MA;B!I;G1E(/9P<&YA(&MO;7!R:6UE
M<F%T(&%R:VEV+@!+86X@:6YT92!LY'-A(%9&4RUF:6P@*&9I;&5S:7IE*"D@
M;6ES<VQY8VMA9&5S*2X`2V%N(&EN=&4@;.1S82!61E,M9FEL("AG971&:6QE
M4VEZ92@I(&UI<W-L>6-K861E<RDN`$MA;B!I;G1E(&SD<V$@9FEL.B``2V%N
M(&EN=&4@;.1S82!K871A;&]G96X@9O9R("=V9G-R;V]T)RX`2V%N(&EN=&4@
M8GET82!N86UN('#E("<E<R<Z("5S`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2`E
M<R!T:6QL("5S.B!D97-T:6YA=&EO;G-M87!P(&9I;FYS(')E9&%N`$MA;B!I
M;G1E(&)Y=&$@;F%M;B!PY2!61E,M;6%P<"X`2V%N(&EN=&4@8GET82!N86UN
M('#E(%9&4RUM87!P.B`E<RX`2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUF
M:6P@)7,N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+R5S+@!+
M86X@:6YT92!B>71A(&YA;6X@<.4@5D93+69I;"X`2V%N(&EN=&4@:.1M=&$@
M:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96X@9O9R("5S`$MA;B!I;G1E
M(&OV<F$@)VUK:7-O9G,G+@!+86X@:6YT92#V=F5R<^1T=&$@5V]R9&1O:W5M
M96YT970`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`E<RX`2V%N(&EN
M=&4@<VMR:79A('1I;&P@5D93+69I;"`H8V]P>2@I(&UI<W-L>6-K861E<RDN
M`$MA;B!I;G1E('-K<FEV82!D871A('1I;&P@5D93+69I;"X`2V%N(&EN=&4@
M<VMR:79A('1I;&P@5D93+69I;"P@:W9O=&$@<VMU;&QE(/9V97)S:W)I9&%S
M+@!5;F1E<G-T<G5K96X`Q6YG<F$@Y&YD<FEN9V%R`,5N9W)A<B!D:6X@<V5N
M87-T92#E=&?D<F0`3W;D;G1A="!S=F%R(&9RY6X@<V5R=F5R('#E(&;V<F)I
M;F1E;'-E.B``3W;D;G1A="!S=F%R(&9RY6X@<V5R=F5R('1I;&PZ(`!%:B!K
M871E9V]R:7-E<F%D`$EC:V4@:&%N=&5R860@:V]M<&]N96YT(&%V('1Y<#H@
M)7,`56YI8V]D92`H551&+3@I`$;V<F5N861E($%R86)E;6ER871E;@!3=&]R
M8G)I=&%N;FEE;@!&]G)E;G1A(%-T871E<FYA`$%M97)I:V%N<VMA(%-T:6QL
M86AA=G/V87)N80!%;FAE=&5R`$]KY&YD`$]KY&YT(&=RY&YS<VYI='1S;65D
M9&5L86YD96ED("AA<&EM<V=I9"DN`$]KY&YT(&ML:65N=&UE9&1E;&%N9&5I
M9"`H8VQI;7-G:60I+@!/:^1N9"!O<G0@<W!E8VEF:6-E<F%D+@!/:^1N="!A
M;G;D;F1A<FYA;6X@96QL97(@;/9S96YO<F0N`%1A(&)O<G0@;.1N:V5N(&9R
MY6X@;G5V<F%N9&4@96QE;65N=`!.86UN;/9S`$EC:V4M<')I=FEL:6=E<F%D
M92!S:W)I<'0@:V%N(&EN=&4@:V]M;6$@Y70@2VQI<'`@=70O2V]P:65R82]+
M;&ES=')A+69U;FMT:6]N97)N82!A=B!SY&ME<FAE='-S:^1L+B!+;&EC:V$@
M3TL@9O9R(&%T="!S92!E;B!T96MN:7-K(&)E<VMR:79N:6YG(&9RY6X@;6]Z
M:6QL82YO<F<@;VT@:'5R(&1U(&MA;B!T:6QLY71A(&%T="!S:W)I<'0@:V]M
M;65R(.5T('5R:VQI<'`N`%1A(&)O<G0@9N1R9P!#;VYT96YT+51Y<&4@<W3V
M9',@:6YT93H@)7,`5&EL;.1G9V5T('-T]F1S(&EN=&4`57!P9&%T97)A`%5P
M<&1A=&5R82`E<P!5<'!D871E<F$@<W1A='5S('#E('-V87)A;F1E`%5P<&1A
M=&5R82!A;G;D;F1A<F4`57!P9&%T97)A9&4@)R5S)RX`57!P9&%T97)A9#H@
M)7,N`%5P<&1A=&5R:6YG<W-C<FEP="!R861E<F%T+@!,861D82!U<'``3&%D
M9&%D92!U<'`@86QL82!K;VYF:6=U<F%T:6]N<V9I;&5R('1I;&P@<V5R=F5R
M;BX`5F5R<V%L97(`4F]M97)S:V$@<VEF9G)O<@!5<G5G=6%Y`$%N=N1N9"!A
M:W1U96QL.B`E<P!!;G;D;F0@4U-,`$%N=N1N9"!O;2!N86UN+VSV<V5N;W)D
M(.1R(&%N;F]R;'5N9&$@9O9R($E-4U`M<V5R=F5R+@!!;G;D;F1A<F4`06YV
MY&YD87)E("5S(.1R(&EN=&4@8F5H]G)I9R!F]G(@)7,N`$%N=N1N9&%R861M
M:6YI<W1R871I;VX`06YVY&YD87)G<N1N<W-N:71T`$%N=N1N9&%R:6YS=.1L
M;&YI;F=A<@!!;G;D;F1A<G)E9VES=')E<FEN9P!!;G;D;F1A<G)E9VES=')E
M<FEN9R!H87(@879A:W1I=F5R871S+@!!;G;D;F1A<FMO;G1O="!H:71T861E
M<R!I;G1E`$%N=N1N9&%R;F%M;@!!;G;D;F1A<FYA;6X@)7,@9FEN;G,@<F5D
M86XN`$%N=N1N9&%R;F%M;CH`06YVY&YD87)N86UN.B``06YVY&YD87)E(&D@
M<WES=&5M970Z`%5Z8F5K:7-T86X`5D93+6UA<'`@97AI<W1E<F%R(&EN=&4N
M`%-E;65S=&5R`$=I;'1I9V$@<&QA='-E<B!S;VT@:&ET=&%D97,@:6YK;'5D
M97)A<CH@`$=I;'1I9VAE=`!-:6YU=&5R(&9RY6X@;G4`5N1R9&5T(/9V97)S
M=&EG97(@9&5T(&CV9W-T82!T:6QLY71N82`H)7,I`%;D<F1E;@!6Y')D96X@
M871T(';D;&IA(&9RY6X`5F%N=71A=0!687)I86)E;`!696YE>G5E;&$`5F5R
M:69I97)I;F<@;6ES<VQY8VMA9&5S("T@;65D9&5L86YD970@:V%N(&AA(&UA
M;FEP=6QE<F%T<RX`5F5R<VEO;@!697)S:6]N:&%N=&5R:6YG`%9E<G1I:V%L
M(&IU<W1E<FEN9P!697)T:6MA;"!U=&9Y;&QN860`5F5R=&EK86PZ`%;D;&1I
M9W0@:/9G`%9I971N86T`5FEE=&YA;65S:7-K("A625-#24DI`%9I<V$@)7,`
M5FES82!D86<`5FES82!E;B!E>'1E<FX@=V5B8G-I9&$`5FES82!S;VT@)7,`
M5FES82!HY&YD96QS90!6:7-A('5P<&=I9G0`2G5N9V9R=?9A<FYA+"!"<FET
M=&ES:V$`2G5N9V9R=?9A<FYA+"!!;65R:6MA;G-K80!3:6MT`%-I:W0Z`%9O
M9&%F;VYE($ET86QI96X@=FEA(%--5%``5D%23@!605).24Y'(2$A(%)!1$52
M02!32U))4%1%5"!-04Y514Q,5"!&4L5.("5S+@!724X@=FEA($A45%``5V%L
M;&ES(&]C:"!&=71U;F$`5F%R;FEN9P!/;@!6Y&1E<G!R;V=N;W,`5N1D97)D
M871A(&9RY6X`=V5A=&AE<BYC;VT`5V5B8@!796)B<&QA=',`5V5B8G!L871S
M96X@+2!3;V)E<@!796)B<&QA='-E;B`M(%-O8F5R($Y9`$]N<V1A9P!696-K
M80!696-K82`E9`!696-K+V$O;W(`5F5C:V]V:7,`5F5C:V]V:7,Z(%5P<')E
M<&$@=F%R`%;D;&MO;6UE;@!6Y&QK;VUM96X@=&EL;"`E<P!6Y&QK;VUM96XL
M("5S`%;D<W1E<FSD;F1S:R`H25-/+3@X-3DM,2D`5N1S=&5R;.1N9'-K("A)
M4T\M.#@U.2TQ-2D`5N1S=')A(%-A:&%R80!6:6QK96X@87!P;&EK871I;VX@
M<VMA;&P@)7,@=FES82!E9G1E<B!I;FQO9V=N:6YG/P!6:6QK96X@Y'(@879G
M<N1N<VYI;F=S=&5C:VYE=#\`5FEL:V5T(.1R('1E8VMN970@9O9R(&-I=&5R
M860@=&5X=#\`4.4@=FEL:V5N('1I9"!S:V%L;"!D86<M(&]C:"!V96-K;W9Y
M97(@<VQU=&$@;N1R(&1E="!I;G1E(&9I;FYS(&[E9W)A('-E;F%R92!HY&YD
M96QS97(_`%#E('9I;&ME;B!T:60@<VMA;&P@9&%G+2!O8V@@=F5C:V]V>65R
M('-T87)T82!NY'(@9&5T(&EN=&4@9FEN;G,@;N5G<F$@=&ED:6=A<F4@:.1N
M9&5L<V5R/P!7:&5R96ES($%U<W1R86QI96YK87)T80!6:6QK82!F87-E<@!6
M:6QK82!P;'5G:6X@<VMA;&P@86MT:79E<F%S(&;V<B!2:6-H(%1E>'0@961I
M=&]R;BX`0G)E9&0`0G)E9&0@:2!#4U,M=6YI=',`0G)E9&0@<.4@;65N>6X@
M9O9R("<E<R<@=&EL;"!VY&YS=&5R("AGY&QL97(@9G+E;B!NY'-T82!I;FQO
M9V=N:6YG`%1A8F5L;&)R961D`$)R961D96YH970`0G)E9&0Z`%=I:VD`5FEN
M9`!4:61I9R!V:6YD`%9I;F1H87-T:6=H970@:2!K;F]P`%9I;F0Z`%9I;F0Z
M(`!6:7-D;VT`UFYS:V5L:7-T80!!<F)E=&4`061R97-S+"!A<F)E=&4`5&5L
M969O;BP@87)B971E`$%R8F5T<W9E8VMA`$9E;"!A;G1A;"!FY&QT('#E(')A
M9"`E9"X@1O9R=N1N=&%D92`E9"P@:&ET=&%D92`E9"X`1F5L(&%N=&%L(&;D
M;'0N($;V<G;D;G1A9&4@)60L(&AI='1A9&4@)60N`$9E;"!P;W-I=&EO;B`E
M9"!V:60@;.1S;FEN9R!A=B!61E,M9FEL+@!8+5)E9@!8-3`Y5C,@573V:V%D
M(&YY8VME;&%N=N1N9&YI;F<`6#4P.58S+71I;&SD9V<`65D`65E960!986AO
M;R$@;6%P`,5R`,5R;&EG`,5R;&EG.B!5<'!R97!A('9A<FIE`%EE;65N`$IA
M`$IA+"!J86<@<V%M='EC:V5R`$1U(&AA<B!A:W1I=F5R870@=&5X=&SD9V4N
M($%N=N1N9"!;/#Y=(&;V<B!A='0@Y71E<F?E('1I;&P@5UE325=91RX`1'4@
M:&%R(&EN=&4@8F5H]G)I9VAE="!S:V%P82!F;&5R(.1N("5D(&)L;V-K+@!$
M=2!FY7(@:6YT92!S:V%P82!F;&5R(.1N("5D(&CD;F1E;'-E<BX`1'4@Y'(@
M:6YT92!E;B!D96QT86=A<F4@=&EL;"!HY&YD96QS96XN`$1U(.1R(&EN=&4@
M875T96YT:7-E<F%D+@!$=2!K86X@:6YT92!A;G;D;F1A("=<)R!I(&1I='0@
M;F%M;@!$=2!K86X@96YD87-T(&%N=N1N9&$@9&5T(&CD<B!F;W)M=6SD<F5T
M(&9RY6X@=GEN(.1N9')A(&1E;'1A9V%R92X`1'4@:V%N(&EN=&4@86YVY&YD
M82`G7"<@:2!D:71T(&YA;6X`1'4@86YG878@:6YT92!E;B!G;V1KY&YD(&4M
M<&]S=&%D<F5S<RX`1'4@:&%R(&EN9V5N(&4M<&]S=&%D<F5S<R!K;VYF:6=U
M<F5R860@:2!D:6YA(&EN<W3D;&QN:6YG87(N($1U(&WE<W1E(&%N9V4@96X@
M)7-HY'(E<R!I;FYA;B!N;W1I9FEE<FEN9V%R(&MA;B!S:VEC:V%S+@!$=2!H
M87(@:6YT92!B96CV<FEG:&5T(&%T="!LY&=G82!T:6QL(&CD;F1E;'-E<B!T
M:6QL("5S+@!$=2!H87(@:6YT92!B96CV<FEG:&5T(&%T="!LY&=G82!T:6QL
M(&CD;F1E;'-E<B!T:6QL(&%K='5E;&P@:V%L96YD97(N`$1U(&AA<B!I;G1E
M(&)E:/9R:6=H970@871T(')A9&5R82!A:W1U96QL(&CD;F1E;'-E+@!$=2!H
M87(@:6YT92!B96CV<FEG:&5T(&%T="!R961I9V5R82!A:W1U96QL(&CD;F1E
M;'-E+@!$=2#D<B!U=&QO9V=A9"X`1'4@:&%R(&%N9VEV:70@96X@9F5L86MT
M:6<@:V%L96YD97(N`$1U(&AA<B!A8V-E<'1E<F%T(&1E;'1A9V%N9&4@=&EL
M;"!HY&YD96QS96XN`$1U(&AA<B!A=F+V:G0@9&5L=&%G86YD92!T:6QL(&CD
M;F1E;'-E;BX`1'4@:&%R('!R96QI;6ENY')T(&%C8V5P=&5R870@9&5L=&%G
M86YD92!T:6QL(&CD;F1E;'-E;BX`1'4@;>5S=&4@86YG92!E='0@9VEL=&EG
M="!M;V)I;&YU;6UE<CL@96YB87)T('-I9F9R;W(@;V-H(&5T="`G*R<@9O9R
M92!I;G1E<FYA=&EO;F5L;'0@<')E9FEX+@!$=2!A;F=A=B!I;G1E(&5T="!G
M;V1KY&YT(';D<F1E+@!$=2!MY7-T92!K;VYF:6=U<F5R82!E;B!$871A5'+D
M9',M:V]P<&QI;F<@9O9R(&%T="!A;G;D;F1A(')E9VES=')E<FEN9P!$=2!M
MY7-T92!K;VYF:6=U<F5R82!E;B!61E,M:V]P<&QI;F<`1'4@;>5S=&4@8F5S
M:W)I=F$@<')O8FQE;65N+"!I;FYA;B!D=2!K86X@<F%P<&]R=&5R82!E='0@
M<')O8FQE;2X`1'4@;>5S=&4@86YG92!E;B!54DP@<V]M(&SD;FME;B!P96MA
M<B!PY0!$=2!MY7-T92!A;F=E(&5N(&MA;&5N9&5R('-O;2!S:V%L;"!R861E
M<F%S+@!$=2!MY7-T92!A;F=E(&5N(&%D<F5S<R!F]G)S="X`1'4@;>5S=&4@
M86YG92!E;B!S97)V97(@<V]M('-K86QL(')A9&5R87,N`$1U(&WE<W1E(&%N
M9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@<F5N<V%S+@!$=2!MY7-T
M92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(')A9&5R87,N`$1U
M(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@;.1G9V%S
M('1I;&PN`$1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA
M;&P@=7!P9&%T97)A<RX`1'4@;>5S=&4@86YG92!E;B#E=&?D<F0@<V]M('-K
M86QL('5T9O9R87,N`$1U(&WE<W1E(&%N9V4@971T(&YY='0@:V%T96=O<FEN
M86UN+@!$=2!MY7-T92!A;F=E(&5T="!I=&%L:65N<VMT('1E;&5F;VYN=6UM
M97(`1'4@8F5GY')D92!N;W1I9FEE<FEN9R!NY'(@:.1N9&5L<V5R(&QA9&5S
M('1I;&P@:2!D:6YA(&MA;&5N9')A<BX`1'4@8F5GY')D92!N;W1I9FEE<FEN
M9R!NY'(@:.1N9&5L<V5R(')A9&5R861E<R!F<N5N(&1I;F$@:V%L96YD<F%R
M+@!$=2!B96?D<F1E(&YO=&EF:65R:6YG(&[D<B!HY&YD96QS97(@Y&YD<F%D
M97,@:2!D:6YA(&MA;&5N9')A<BX`1'4@8F5GY')D92!A='0@8FQI('#E;6EN
M9"!O;2`E<RP@<V]M(.1R(&1E;B`E<R!K;"`E<RX`1&EN("5S('-E<W-I;VX@
M:&%R('5P<&CV<G0N(%9A<B!G;V0@;&]G9V$@:6X@:6=E;BX`1&EN(&4M<&]S
M=&%D<F5S<P!$:6X@1G+E;CH@861R97-S.@!$:6X@:6YF;W)M871I;VX`1&EN
M(&EN=&5R;F5T861R97-S(&AA<B#D;F1R871S(&5F=&5R(&%T="!D=2!L;V=G
M870@:6X@=&EL;"`G)7,G+B!&]G(@871T('-K>61D82!D:6<L(&WE<W1E(&1U
M(&QO9V=A(&EN(&EG96XN`$1I='0@;F%M;@!$:6X@875T96YT:7-E<FEN9W-K
M;W!P;&EN9R!S=/9D97(@:6YT92!U<'!LY&=G(&%V(&%N=N1N9&%R92X@3VT@
M9'4@=FEL;"!A;G;D;F1A($AO<F1E(&;V<B!A='0@861M:6YI<W1R97)A(&%N
M=N1N9&%R92!SY2!MY7-T92!D=2!A;G;D;F1A(&5N(&%N;F%N(&%U=&5N=&ES
M97)I;F=S:V]P<&QI;F<N`$1I='0@875T96YT:7-E<FEN9W-K;W!P;&EN9R!S
M=/9D97(@:6YT92!L:7-T;FEN9R!A=B!A;G;D;F1A<F4L(&5L;&5R('/E(.1R
M(&9U;FMT:6]N96X@879S=.1N9V0N`$1I;B!W96)B;.1S87)E+VEN=&5R;F5T
M861R97-S(&AA<B#D;F1R871S(&5F=&5R(&%T="!D=2!L;V=G870@:6X@=&EL
M;"`G)7,G+B!&]G(@871T('-K>61D82!D:6<L(&WE<W1E(&1U(&QO9V=A(&EN
M(&EG96XN`$1I;B!W96)B;.1S87)E('-T]F1E<B!I;G1E(&1E;B!HY'(@9G5N
M:W1I;VYE;BX`1&EN('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@=71S:W)I9G1S
M9G5N:W1I;VYE;BX@5')Y8VL@0W1R;"]/<'1I;VX@*R!0(&;V<B!A='0@<VMR
M:79A('5T+@!$:6X@86MT=65L;&$@=&ED<WIO;CH`1&EN(&;V<G9A;&1A(&MA
M;&5N9&5R`$1I;B!F]G)V86QD82!I9&5N=&ET970@:&%R(.1N9')A=',N`$1I
M;B!F]G)V86QD82!I9&5N=&ET970Z`$1I='0@9G5L;'-TY&YD:6=A(&YA;6XZ
M`$1I;B!I;FQO9V=N:6YG(&AA<B!GY71T('5T+@!$:71T(&YY82!L]G-E;F]R
M9"!F]G(@)7,@Y'(Z("5S`$1I;F$@:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T
M97)A=',@9O9R(&1E;B!HY'(@<V5S<VEO;F5N+@!$:6YA(&EN<W3D;&QN:6YG
M87(@:&%R('5P<&1A=&5R871S+@!$:71T(&SV<V5N;W)D(&AA<B!B;&EV:70@
MY71E<G-TY&QL=`!$:71T(&SV<VYO<F0@:&%R(.5T97)S=.1L;'1S+"!K;VYT
M<F]L;&5R82!D:6X@92UP;W-T(&]C:"!L;V=G82!I;B!M960@9&ET="!N>6$@
M;/9S96YO<F0N`$1I='0@;/9S96YO<F0@:&%R(&?E='0@=70N`$1I;F$@9FKD
M<G)S97)V<F%R.@!*=6=O<VQA=FEE;@!:86ER90!:86UB:6$`6FEM8F%B=V4`
M6FEP<'D`6T?V;2!C:71E<F%D('1E>'1=`%M&96QR87!P;W)T70!;5FES82!C
M:71E<F%D('1E>'0@+0!;5FES82!C:71E<F%D('1E>'0@+2`E<R!R861E<ET`
M6TYA;6YL]G,@:.1N9&5L<V5=`%MR860@)7,@878@)7-=`%]!9&UI;FES=')A
M=&EO;@!!;&%R;0!%;FME;"!S]FMN:6YG`%]#3$D`7T1A=&%4<N1D`%]2861E
M<F$@<F%D`,1N9')A`%]'Y2!T:6QL`%]'<G5P<&5R`%](:N1L<`!?0FEL9&EN
M<W3D;&QN:6YG87(N+BX`7TEM<&]R="]%>'!O<G0`7TQO9V=A(&EN`%],;V=G
M82!U=`#$7VYD<F$@;.1N:RXN+@!?36EN82!K86QE;F1R87(`7TYY(&CD;F1E
M;'-E`%]);G-TY&QL;FEN9V%R`%]"96CV<FEG:&5T97(`571S:W)I9G0`7U1A
M(&)O<G0@;.1N:RXN+@!?4_9K`%]3971U<`!?5FES80!?5&%B96QL:6YS=.1L
M;&YI;F=A<BXN+@!?261A9P!?06YVY&YD87)E`&%D<F5S<V)O:P!O:^1N9"!M
M;W1T86=A<F4`:6YN86X@:.1N9&5L<V5N(&+V<FIA<@!K86QE;F1E<@!L=6=N
M=`!K86X@:6YT92!S:V%P82!U=&9I;`!K86X@:6YT92#V<'!N82!I;F1A=&$`
M:VQI8VMA(&CD<@!K;&]C:V$`:V]M;6%N9&]R861S9F5L`&MO;F9I9W5R871I
M;VYS9F5L`&MR:71I<VL@<WES=&5M9FEL('-A:VYA<P!D871A9F]R;6%T9F5L
M`&1A9P!D86<H87(I`&1A9V%R`.1N9')A`'!O<W1E;B!K=6YD92!I;G1E(&AI
M='1A<P!HY&YD96QS97(N8W-V`&CD;F1E;'-E<BYI8W,`9F%L;&%N9&4`9FEL
M`&9RY6X@9&5N("5S("@E<RD@:VP@)7,@)7,`<W1O<FUB>6%R`&@Z`&AH`&]K
MY&YD(';D<F1D871O<@!G96YA<W0`:0!I;FQI;F4`8F5A<F)E=&YI;F=S9F5L
M`$EN=&5R;G0@87!P;&EK871I;VYS9F5L`')A9&5R70!F96QK;V0@)60@9G+E
M;B!M:VES;V9S`&UM`&WE;F%D*&5R*0!N86UN`&EN=&4@:6UP;&5M96YT97)A
M9`!I;G1E(&EM<&QE;65N=&5R860`86YT96-K;FEN9W-B;&]C:P!D96X@)7,@
M:VP@)7,`<.4@<V%M;6$@9&%G`'#E('-A;6UA('9E8VMO9&%G`'!R;V-E;G0`
MY71K;VUS="!N96MA9`!P:7AL87(`<')O=&]K;VQL9F5L`'-T:6=A;F1E`%1J
MY&YS=&5N(.1R(&5J('1I;&QGY&YG;&EG`'9I<V$@<VMI;&QN861E<@!S;7,R
M96UA:6P@=FEA($A45%``<W,`<W1A9&EG=`!S>7-T96UF96P`=7!P9VEF='-L
M:7-T80!T:6QL9N1L;&EG="!F96P`86YG92!L]G-E;F]R9&5T('1VY2!GY6YG
M97(@9O9R(&%T="!B96MRY&9T80!E;F%D`&YA;6YL]G,`86YVY&YD87)V86P`
M=D-A;&5N9&%R+VE#86QE;F1A<@!V0V%R9`!V179E;G0@<V%K;F%S+@!W.@!W
M96%T:&5R+F-O;0!V96-K80!V96-K82!PY3H`=F5C:V]R`.5R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:W)O;F]L:71H+VQO8V%L92]T<E]44B\`````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,@`P,C`W,C4`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+W1R7U12+VAE
M;'`N>&UL````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(S-C`P`#$P-#$W
M,S8R-S4R`#`R,C,W-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M
M.#@U.2TY(C\^"CPA+2T@)$AO<F1E.B!K<F]N;VQI=&@O;&]C86QE+W1R7U12
M+VAE;'`N>&UL+'8@,2XQ+C(N,2`R,#`U+S$P+S$X(#$R.C(W.C,X(&IA;B!%
M>'`@)"`M+3X*/&AE;'`^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)/=F5R=FEE=R(^"B`@("`\=&ET;&4^2W)O;F]L:71H.B!/=F5R=FEE=SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY7:&%T(&ES($MR;VYO;&ET:#\\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($MR;VYO;&ET:"!I<R!A('=E8BUB87-E9"!C
M86QE;F1A<B!A<'!L:6-A=&EO;BX@($EN(&%D9&ET:6]N('1O('1H90H@("`@
M<F5Q=6ER960@9G5N8W1I;VYS(&]F(&-R96%T:6YG+"!M;V1I9GEI;F<L(&%N
M9"!D96QE=&EN9R!E=F5N=',L(&ET"B`@("!C=7)R96YT;'D@<W5P<&]R=',@
M<F5C=7)R:6YG(&5V96YT<R`H=VET:"!E>&-E<'1I;VYS(&%N9"!V87)I;W5S
M(&1E;&5T:6]N"B`@("!O<'1I;VYS*2P@86QA<FUS+"!I;7!O<G0@86YD(&5X
M<&]R="!F=6YC=&EO;G,@*&E#86QE;F1A<B!A;F0@0U-6(&9O<FUA=',I+`H@
M("`@:4-A;&5N9&%R(&EN=FET871I;VYS+"!M=6QT:7!L92!C86QE;F1A<B!V
M:65W<RP@<VAA<F5D(&-A;&5N9&%R<RP@9&ES<&QA>0H@("`@;V8@5&%S:R!,
M:7-T("A.86<I('1A<VMS("AI9B!487-K<R!,:7-T(&ES(&EN<W1A;&QE9"DL
M(&%N9"!A8FEL:71Y('1O('-H;W<*("`@(&5V96YT<R!I;B!T:&4@2&]R9&4@
M<W5M;6%R>2!S8W)E96XN"B`@("`\+W!A<F$^"CPO96YT<GD^"BTM/@H*/&5N
M=')Y(&ED/2)/=F5R=FEE=R(@;60U/2(Q-3@U.3(W9#0X930V,C=C-SDR9F4P
M,S,R8S0Q9F0S.2(@<W1A=&4](G5P=&]D871E(CX*/'1I=&QE/DMR;VYO;&ET
M:#H@1V5N96P@0F%K_?X\+W1I=&QE/@H\:&5A9&EN9SY+<F]N;VQI=&@@;F5D
M:7(_/"]H96%D:6YG/@H\<&%R83X*2W)O;F]L:71H(&'P('1A8F%N;/T@=&%K
M=FEM('5Y9W5L86UA<_UD_7(NW>=E<FES:6YD92P@:6AT:7EAYR!D=7ED=6=U
M;G5Z('EA<F%T;6$L9&7P:?YT:7)M92!V92!S:6QM92!I_FQE;6QE<FEN:2!B
M87+];F3]<OUR+D%Y<OUC82!T96MR87(@961E;B!O;&%Y;&%R_2`H:7-T:7-N
M82!V92#G9?YI=&QI('-I;&UE('-EYV5N96ML97)I*2P@:&%T_7)L871M86QA
M<OTL86QM82!V92!V97)M92!S9>=E;F5K;&5R:6YI("AE;&5K=')O;FEK('1A
M:W9I;2!V92!C<W8@9F]R;75N9&$I+"!E;&5K=')O;FEK('1A:W9I;2!D879E
M=&EY96QE<FDL(.=O:R!S9>=E;F5K;&D@=&%K=FEM(&]L87EL87+]("P@<&%Y
M;&'^=/UR_6QM_?X@=&%K=FEM;&5R("P@9_9R978@;&ES=&5S:6YI;B!G]G+\
M;G3\;&5N;65S:2`H9_9R978@;&ES=&5S:2!Y_&ML96YM:?YS92DL('9E(&1E
M(&%N87-A>69A(&5K<F%N_6YD82!O;&%Y;&%R_2!G]G+\;G3\;&5M92!Y971E
M;F7P:6YE('-A:&EP=&ER+@H\+W!A<F$^"CPO96YT<GD^"@H\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB;65N=2UT;V1A>2(^"B`@("`\=&ET;&4^
M365N=3H@5&]D87D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4:&4@/&D^5&]D
M87D\+VD^(&UE;G4@:71E;2!W:6QL(&1I<W!L87D@>6]U<B!D969A=6QT('9I
M97<@*&UO;G1H+"!W965K+`H@("`@9&%Y+"!E=&,N(&%S('-E="!I;B!/<'1I
M;VYS*2!F;W(@=&AE(&-U<G)E;G0@9&%T92X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*+2T^"@H\96YT<GD@:60](FUE;G4M=&]D87DB(&UD-3TB8S9D,&,P9C,V
M-C$W-6$S.&0P-C4U960Y.38Y960T838B('-T871E/2)U<'1O9&%T92(^"CQT
M:71L93Y-96[\.B!"=6?\;CPO=&ET;&4^"CQP87)A/@I"=6?\;B!M96[\('-E
MYV5N9?!I+/YU(&%N:VD@9V7G97)L:2!T87)I:'1E('-I>FEN('9A<G-A>?UL
M86X@;VQA<F%K(&%T86W]_B!O;&1U\'5N=7H@87EA<FQA<OT@*$%Y+$AA9G1A
M+$?\;B!V<RXN('-EYV5N96L@9/QZ96YI;FDI(&?V<OQN=/QL97(N"CPO<&%R
M83X*/"]E;G1R>3X*"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M
M96YU+4=O=&\B/@H@("`@/'1I=&QE/DUE;G4Z($=O=&\\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!4:&4@/&D^1V]T;SPO:3X@;65N=2!I=&5M('=I;&P@9&ES
M<&QA>2!A('-M86QL('!O<"UU<"!W:6YD;W<@:6X@=VAI8V@@>6]U"B`@("!C
M86X@<75I8VML>2!S96QE8W0@82!M;VYT:"P@=V5E:R!O9B!T:&4@>65A<BP@
M;W(@9&%Y(&]F('1H92!M;VYT:"!T;R`\:3YG;PH@("`@=&\\+VD^+B`@5&AI
M<R!I<R!U<W5A;&QY('1H92!Q=6EC:V5S="!W87D@=&\@;6]V92!W:71H:6X@
M=&AE(&-A;&5N9&%R+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R
M>2!I9#TB;65N=2U';W1O(B!M9#4](C4V-C$Y,3<W-6)A.3!B-S8Y9C)E,V8W
M8V1F,C1C8F9A(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^365N_#H@1VET
M/"]T:71L93X*/'!A<F$^"D=I="!M96[\('-EYV5N9?!I+&O\Y_QK(&)I<B!P
M96YC97)E8VEK(&'G87(N5F4@YV]K(&C]>FS](&)I<B#^96MI;&1E('-EYW1I
M\&EN:7H@>?UL_6X@:&5R:&%N9VD@8FER(&%Y('9E>6$@:&%F=&%S_6YA+"!Y
M861A(&%Y_6X@:&5R:&%N9VD@8FER(&?\;OQN92!G:71M96YI>FD@<V%G;&%R
M+D)U('-EYV5N96L@=&%K=FEM(&GG97)I<VEN9&4@:&%R96ME="!E=&UE;FEN
M(&5N(&C]>FS]('9E(&5N('/]:R!T97)C:6@@961I;&5N('EO;'5D=7(N"CPO
M<&%R83X*/"]E;G1R>3X*"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)M96YU+41A>2(^"B`@("`\=&ET;&4^365N=3H@1&%Y/"]T:71L93X*("`@
M(#QP87)A/@H@("`@5&AE(#QI/D1A>3PO:3X@=&%B('=I;&P@9&ES<&QA>2!T
M:&4@9&%Y('9I97<@;V8@=&AE(&-U<G)E;G1L>2!S96QE8W1E9`H@("`@9&%Y
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB;65N=2U$
M87DB(&UD-3TB,V-D-C)E,3`Q,38P-3AD8C4R83$U9F5C9#=D9&)C8C`B('-T
M871E/2)U<'1O9&%T92(^"CQT:71L93Y-96[\.B!'_&X\+W1I=&QE/@H\<&%R
M83X*1_QN('-E:VUE<VDL_G4@86YK:2!G9>=E<FQI('-EYVEL;6G^(&?\;F1E
M;B!B8?YL87EA<F%K(&\@9_QN_"!G]G+\;G3\;&5R+@H\+W!A<F$^"CPO96YT
M<GD^"@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB;65N=2UW;W)K
M+7=E96LB/@H@("`@/'1I=&QE/DUE;G4Z(%=O<FL@5V5E:SPO=&ET;&4^"B`@
M("`\<&%R83X*("`@(%1H92`\:3Y7;W)K(%=E96L\+VD^('1A8B!W:6QL(&1I
M<W!L87D@=&AE('=O<FL@=V5E:R!V:65W("A-;VYD87D@=&AR;W5G:`H@("`@
M1G)I9&%Y*2!C;&]S97-T('1O('1H92!C=7)R96YT;'D@<V5L96-T960@9&%Y
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB;65N=2UW
M;W)K+7=E96LB(&UD-3TB9CEA-C,U.#5C.#%D8V$V,S@X-V4Q,S!D8F)E83DQ
M9&4B('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y-96[\.B#'86S]_FUA($AA
M9G1A<_T\+W1I=&QE/@H\<&%R83X*QV%L_?YM82!(869T87/]('-E:VUE<VDL
M_G4@86YK:2!G9>=E<FQI('-EYVEL;6G^(&?\;F4@96X@>6%K_6X@YV%L_?YM
M82!H869T87/];OT@*'!A>F%R=&5S:2U#=6UA*2!G]G+\;G3\;&5R+@H\+W!A
M<F$^"CPO96YT<GD^"@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB
M;65N=2UW965K(CX*("`@(#QT:71L93Y-96YU.B!7965K/"]T:71L93X*("`@
M(#QP87)A/@H@("`@5&AE(#QI/E=E96L\+VD^('1A8B!W:6QL(&1I<W!L87D@
M=&AE('=E96L@=FEE=R`H-R!D87D@=FEE=RD@9F]R('1H92!W965K"B`@("!C
M;VYT86EN:6YG('1H92!C=7)R96YT;'D@<V5L96-T960@9&%Y+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB;65N=2UW965K(B!M9#4]
M(C-D.&$S8F9D838R.6)B-F4P.3@Q.6(R938V,#4T-F4U(B!S=&%T93TB=7!T
M;V1A=&4B/@H\=&ET;&4^365N_#H@2&%F=&$\+W1I=&QE/@H\<&%R83X*2&%F
M=&$@<V5K;65S:2S^=2!A;FMI(&=EYV5R;&D@<V7G:6QM:?X@9_QN9&5N(&)A
M_FQA>6%R86L@=/QM(&AA9G1A>?T@*#<@9_QN*2!G]G+\;G3\;&5R+@H\+W!A
M<F$^"CPO96YT<GD^"@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60]
M(FUE;G4M;6]N=&@B/@H@("`@/'1I=&QE/DUE;G4Z($UO;G1H/"]T:71L93X*
M("`@(#QP87)A/@H@("`@5&AE(#QI/DUO;G1H/"]I/B!T86(@=VEL;"!D:7-P
M;&%Y('1H92!M;VYT:"!V:65W(&9O<B!T:&4@;6]N=&@@8V]N=&%I;FEN9PH@
M("`@=&AE(&-U<G)E;FQY('-E;&5C=&5D(&1A>2X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*+2T^"@H\96YT<GD@:60](FUE;G4M;6]N=&@B(&UD-3TB-&)E,C`U
M-C@W-3<W-65C,68U8C!F.3(P83%D86(V,#@B('-T871E/2)U<'1O9&%T92(^
M"CQT:71L93Y-96[\.B!!>3PO=&ET;&4^"CQP87)A/@I!>2!S96MM97-I+/YU
M(&%N:VD@9V7G97)L:2!S9>=I;&UI_B!G_&YD96X@8F'^;&%Y87)A:R!T_&T@
M87DG_2!G]G+\;G3\;&5R+@H\+W!A<F$^"CPO96YT<GD^"@H\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB;65N=2UN97<M979E;G0B/@H@("`@/'1I
M=&QE/DUE;G4Z($YE=R!%=F5N=#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%1H
M92`\:3Y.97<@179E;G0\+VD^(&UE;G4@:71E;2!W:6QL(&%L;&]W('EO=2!T
M;R!C<F5A=&4@82!N97<@979E;G0@=&\@8F4*("`@(&%D9&5D('1O(&$@8V%L
M96YD87(N"B`@("`\+W!A<F$^"CPO96YT<GD^"BTM/@H*/&5N=')Y(&ED/2)M
M96YU+6YE=RUE=F5N="(@;60U/2(S-S0P-F-C,F5E-3$P-#`X-C)D9C%E86$R
M9C8T-60T92(@<W1A=&4](G5P=&]D871E(CX*/'1I=&QE/DUE;G4Z665N:2!O
M;&%Y/"]T:71L93X*/'!A<F$^"EEE;FD@;VQA>2!M96[\<_P@<V7G96YE:VQE
M<FD@=&%K=FEM9&4@>65N:2!O;&%Y;&%R(&]L=?YT=7)M86W]>F$@:7II;B!V
M97)I<BX*/"]P87)A/@H\+V5N=')Y/@H*"CPA+2T@16YG;&ES:"!E;G1R>3H*
M/&5N=')Y(&ED/2)M96YU+6]P=&EO;G,B/@H@("`@/'1I=&QE/DUE;G4Z($]P
M=&EO;G,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4:&4@/&D^3W!T:6]N<SPO
M:3X@;65N=2!I=&5M(&%L;&]W<R!Y;W4@=&\@<V5T(#QI/D]P=&EO;G,\+VD^
M("AO<@H@("`@<')E9F5R96YC97,I('1H870@8V]N=')O;"!T:&4@;&]O:R!A
M;F0@9F5E;"!O9B!+<F]N;VQI=&@L($MR;VYO;&ET:"=S"B`@("!I;G1E<F%C
M=&EO;B!W:71H($AO<F1E(&%N9"!O=&AE<B!(;W)D92!A<'!L:6-A=&EO;G,L
M(&%N9"!M86YA9V4@;75L=&EP;&4*("`@(&%N9"!S:&%R960@8V%L96YD87)S
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB;65N=2UO
M<'1I;VYS(B!M9#4](F0W9&8R8S!C9&$X-&,X.6,V,SAD.60V934Y,S`W.3<V
M(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^365N=3IS9>=E;F5K;&5R/"]T
M:71L93X*/'!A<F$^"E-EYV5N96ML97(@;65N_'/\('-EYV5N96ML97)I(.=O
M:VQU('9E('!A>6QA_OUL86X@=&%K=FEM;&5R:2!Y]FYE=&ER('9E($AO<F1E
M('9E(&1I\&5R($AO<F1E('5Y9W5L86UA;&%R_7EL82!E=&MI;&7^:6T@:>=I
M;F1E9&ER('9E(&)I>F4@2W)O;F]L:71H:6X@8F%K_?[];OT@=F4@>6]R=6UL
M87G]_OUN_2!K;VYT<F]L(&5T;65M:7IE(&EZ:6X@=F5R:7(N"CPO<&%R83X*
M/"]E;G1R>3X*"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU
M+6EM<&]R="UE>'!O<G0B/@H@("`@/'1I=&QE/DUE;G4Z($EM<&]R="]%>'!O
M<G0\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4:&4@/&D^26UP;W)T+T5X<&]R
M=#PO:3X@;65N=2!I=&5M(&%L;&]W<R!Y;W4@=&\@:6UP;W)T(&]R(&5X<&]R
M="!C86QE;F1A<@H@("`@979E;G1S+B`@0W5R<F5N=&QY('EO=2!C86X@:6UP
M;W)T(&9I;&5S(&EN($-35BP@36EC<F]S;V9T($]U=&QO;VLL(&%N9`H@("`@
M=D-A;&5N9&%R+VE#86QE;F1A<B!F;W)M871S+B`@66]U(&-A;B!E>'!O<G0@
M=&\@;VYL>2!#4U8@86YD(&E#86QE;F1A<@H@("`@9F]R;6%T<RX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*+2T^"@H\96YT<GD@:60](FUE;G4M:6UP;W)T+65X
M<&]R="(@;60U/2(S-&)C.61F8S1D-C,P,F9C,3`Q,38Y-F$Q8CAD,6-A."(@
M<W1A=&4](G5P=&]D871E(CX*/'1I=&QE/DUE;G4Z06S];2!V92!']FYD97)I
M;3PO=&ET;&4^"CQP87)A/@I!;/UM+T?V;F1E<FEM(&UE;OP@<V7G96YE\&D@
M=&%K=FEM(&]L87EL87+];OT@86QM86YA('9E>6$@9_9N9&5R;65N92!I>FEN
M('9E<FER+B#>=2!A;B!#4U8L($UI8W)O<V]F="!/=71L;V]K('9E('9#86QE
M;F1A<B]I0V%L96YD87(@9F]R;6%T_6YD86MI(&1O<WEA;&%R_2!A;&%B:6QI
M<G-I;BX@4V%D96-E($-35B!V92!I0V%L96YD97(@9F]R;6%T_6YD86MI(&1O
M<WEA;&%R_2!G]FYD97)E8FEL:7)S:6XN"CPO<&%R83X*/"]E;G1R>3X*"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)A;&%R;7,B/@H@("`@/'1I
M=&QE/D%L87)M<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($MR;VYO;&ET:"!C
M86X@9V5N97)A=&4@86QA<FUS(&9O<B!E=F5N=',@:6X@82!C86QE;F1A<BX@
M($)Y(&1E9F%U;'0L('1H90H@("`@9FER<W0@86QA<FT@:7,@9V5N97)A=&5D
M(&9I9G1E96X@;6EN=71E<R!B969O<F4@=&AE(&%P<&]I;G1M96YT(&ES"B`@
M("!S=7!P;W-E9"!T;R!S=&%R="P@8G5T('1H92!A;&%R;2!C86X@8F4@<V5T
M("AP97(@979E;G0I('1O(&]C8W5R(&%T(&%L;6]S=`H@("`@86YY(&EN=&5R
M=F%L(&)E9F]R92!T:&4@979E;G0@<W1A<G0@=&EM92X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*+2T^"@H\96YT<GD@:60](F%L87)M<R(@;60U/2(T8S%C-F8S
M96(Q,V$T,38P,S%F9F)E931F8V4Y.65A,2(@<W1A=&4](G5P=&]D871E(CX*
M/'1I=&QE/D%L87)M;&%R/"]T:71L93X*/'!A<F$^"DMR;VYO;&ET:"!O;&%Y
M;&%R(&GG:6X@8FER('1A:W9I;61E(&%L87)M;&%R(&]L=?YT=7)A8FEL:7(N
M($]T;VUA=&EK(&]L87)A:RP@:6QK(&%L87)M('1O<&QA;G3];OUN(&)A_FQA
M;6%S_6YD86X@,34@9&%K:6MA(/9N8V5Y92!O;'7^='5R=6QU<B!A;6$@8G4@
M86QA<FT@;VQA>?UN(&)A_FQA;6%S_6YD86X@]FYC92!O;&%N(&AE<FAA;F=I
M(&)I<B!A<F%L_6L@;VQA<F%K=&$@87EA<FQA;F%B:6QI<BX*/"]P87)A/@H\
M+V5N=')Y/@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G)E8W5R
M<FEN9RUE=F5N=',B/@H@("`@/'1I=&QE/E)E8W5R<FEN9R!%=F5N=',\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!%=F5N=',@8V%N(&)E(&UA9&4@=&\@<F5P
M96%T(&EN('9A<FEO=7,@=V%Y<RX@36%N>2!E=F5N=',@<F5P96%T(&EN"B`@
M("!C97)T86EN(&9R97%U96YT;'D@=7-E9"!W87ES+B!&;W(@97AA;7!L92P@
M=&AE(#QI/DUO;G1H;'D\+VD^(')E8W5R<F5N8V4*("`@('1Y<&5S(&UA:V4@
M=&AE('-E;&5C=&5D(&ET96T@<F5P96%T(&5A8V@@;6]N=&@@86YD('1H92`\
M:3Y7965K;'D\+VD^"B`@("!R96-U<G)E;F-E('1Y<&4@;6%K97,@=&AE('-E
M;&5C=&5D(&ET96T@<F5P96%T(&5A8V@@<&5R('=E96LN(%1H97-E(&-A;B!B
M90H@("`@;6%D92!T;R!R97!R97-E;G0@979E;G1S('1H870@<F5P96%T(&EN
M(&-O;7!L97@@=V%Y<SH@9F]R(&5X86UP;&4L(&%N(&ET96T*("`@('1H870@
M;V-C=7)S(&]N('1H92!T:&ER9"!&<FED87D@;V8@96%C:"!M;VYT:"P@;W(@
M86X@:71E;2!T:&%T(&]C8W5R<R!O;@H@("`@36]N9&%Y+"!7961N97-D87DL
M(&%N9"!&<FED87D@979E<GD@=V5E:RX@"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@(%EO=2!C86X@86QS;R!R97-T<FEC="!H;W<@;&]N9R!A;B!E=F5N
M="!R97!E871S(&)Y('-E;&5C=&EN9R!T:&4@/&D^96YD"B`@("!D871E/"]I
M/B!F;W(@=&AE(&5V96YT)W,@<F5C=7)R96YC92X*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@3F]R;6%L;'DL(&$@;6]D:69I8V%T:6]N('1O(&$@<F5P
M96%T:6YG(&5V96YT(&%P<&QI97,@=&\@86QL(&]C8W5R<F5N8V5S"B`@("!O
M9B!T:&%T(&5V96YT+B!!('-I;F=L92!O8V-U<G)E;F-E(&]F(&$@<F5P96%T
M:6YG(&5V96YT(&-A;B!B92!M;V1I9FEE9"!B>0H@("`@961I=&EN9R!T:&4@
M;V-C=7)R96YC92P@<F5M;W9I;F<@:71S(')E8W5R<F5N8V4@:6YF;W)M871I
M;VXL(&%N9"!T:&5N"B`@("!C:&]O<VEN9R!T:&4@/&D^4V%V92!A<R!.97<\
M+VD^(&]P=&EO;B!F<F]M('1H92!297!E870@;65N=2X@5&AE('-E;&5C=&5D
M"B`@("!O8V-U<G)E;F-E(&-A;B!N;W<@8F4@;6]D:69I960@:6YD97!E;F1E
M;G1L>2!O9B!T:&4@;W1H97(@;V-C=7)E;F-E<RX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*+2T^"@H\(2TM($)54D%322!%2U-)2R!612!+3U15($],3553(2$M
M+3X*/&5N=')Y(&ED/2)R96-U<G)I;F<M979E;G1S(B!M9#4](C@S83!C,V$X
M83)D,F8U8V4X8C4U,3!B9&$R-34V-#-D(B!S=&%T93TB=7!T;V1A=&4B/@H\
M=&ET;&4^5&5K<F%R;&%Y86X@3VQA>6QA<CPO=&ET;&4^"CQP87)A/@I/;&%Y
M_6X@<V]N('1E:W)A<FQA;FUA('1A<FEH:6YI(&)E;&ER;&5Y97)E:R!T96MR
M87)L86YM87/];OT@<V]N;&%N9/UR86)I;&ER<VEN:7HN"CPO<&%R83X*/'!A
M<F$^"D]L87EL87(@9&7P:?YI:R#^96MI;&QE<F1E('1E:W)A<FQA;F%C86L@
M_F5K:6QD92!Y87#];&W]_B!O;&%B:6QI<BX@0FER(.=O:R!O;&%Y(&)E;&QI
M(&%R86S]:VQA<FQA('1E:W)A<FQA<BX@UG)N9?!I;BP@87EL_6L@;VQA<F%K
M('1E:W)A<FQA>6%N('1I<"!S9>=I;&ER<V4@:&5R(&%Y('1E:W)A<FQA<FQA
M<B!V92!H869T86S]:R!T96MR87)L87EA;B!T:7`@<V7G:6QI<G-E('-EYVEL
M96X@]O!E(&AE<B!H869T82!K96YD:6YI('1E:W)A<FQA>6%C86MT_7(N($)U
M;FQA<B!K87)M8?[]:R!Y]FYL97)L92!G]G-T97)I;&5N(&]L87EL87(@>6%P
M_6QA8FEL:7(Z(-9R;F7P:6XL(&)I<B#V\&4@:&5R(&%Y_6X@_.?\;F/\(&-U
M;6%S_2!O;'5Y;W(L('9E>6$@8FER(/;P92!H869T86[];B!087IA<G1E<VDL
M(,=A<OYA;6)A+"!V92!#=6UA(&?\;FQE<FD@;VQU_G5Y;W(N"D%Y;OT@>F%M
M86YD82!B:7(@;VQA>?UN(&YE(&MA<B!S_')E9&4@;F4@:V%D87(@=&5K<F%R
M;&%Y86-A\/UN_2!O;&%Y_6X@<V]N;&%N9/UR;6$@=&%R:6AI;FD@<V7G97)E
M:R!A>6%R;&%Y86)I;&ER:7HN"DYO<FUA;&1E+"!T96MR87)L87EA;B!B:7(@
M;VQA>?UN(&1E\&G^:6UI(&)U(&]L87G];B!B_'3\;B!O;'7^=6UL87+];F$@
M=7EG=6QA;OUR+E1E:W)A<FQA(&UE;OQS_&YD96X@>6%P_6QA;B!P96L@YV]K
M(&%Y87+];F$@87)D_6YD86X@665N:2#^96ML:7EL92!K87ED9722:2!S9>=E
M<F5K(&1E\&G^:6ML:6ML97(@>6%P_6QA8FEL:7(N(%-EYVEL96X@;VQA>2!D
M:?!E<B!O;&%Y;&%R9&%N(&)A\/UM<_UZ(&]L87)A:R!D9?!I_G1I<FEL96-E
M:W1I<BX*/"]P87)A/@H\+V5N=')Y/@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\
M96YT<GD@:60](E!R:6YT:6YG(CX*("`@(#QT:71L93Y0<FEN=&EN9SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY0<FEN=&EN9R!#86QE;F1A<G,@86YD($5V96YT
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0V5R=&%I;B!V:65W<R!A<F4@
M9&5S:6=N960@=&\@8F4@<')I;G1A8FQE+B`@5VAE;B!I;B!O;F4@;V8@=&AE
M<V4@=FEE=W,L(&$*("`@(#QI/E!R:6YT/"]I/B!I8V]N('=I;&P@87!P96%R
M(&EN('1H92!T;W`@;65N=2!B87(N("!5<V4@=&AI<R!M96YU(&EC;VX@=&\*
M("`@('!R:6YT('1H92!C=7)R96YT('9I97<N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"BTM/@H*/&5N=')Y(&ED/2)0<FEN=&EN9R(@;60U/2(R9CDP9#$T93,T
M8C<Q-6$P-31F8C4R8F(Y,3EA8S5F."(@<W1A=&4](G5P=&]D871E(CX*/'1I
M=&QE/L?]:W3]($%L;6$\+W1I=&QE/@H\:&5A9&EN9SY/;&%Y;&%R_2!V92!4
M86MV:6UL97)I;B#'_6MT_7/]/"]H96%D:6YG/@H\<&%R83X*4V%Y9F%N_6X@
M9/QZ9_QN(&]L87)A:R#G_6MT_7/];OUN(&%L_6YA8FEL:6YM97-I;FD@<V'P
M;&%Y86X@9_9R_&YT_&QE;64@;65K86YI>FUA<_T@8G5L=6YM86MT863]<BX@
M0G4@;65K86YI>FUA;OUN(.=A;/W^;6%S_2!S;VYU8W5N9&$@<V%Y9F%D82!G
M]GK\:V5C96L@;VQA;B!Y87K]8_T@:6MO;G5N82!T_6ML87EA<F%K(.?]:W3]
M(&%L86)I;&ER<VEN:7HN"CPO<&%R83X*/"]E;G1R>3X*"@H\+VAE;'`^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE+WIH7T-.+P``````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S4R`#`R,#8W-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L
M;V-A;&4O>FA?0TXO3$-?34534T%'15,O````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-3(`,#(R-#8Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]Z:%]#3B],0U]-15-304=%4R]K<F]N
M;VQI=&@N;6\````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#(P-S(S,P`Q,#0Q-S,V,C<U,@`P,C4P,S,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````#+!```'````'0F``!E!@``S$P```````!@9@``#@```&%F```/````
M<&8```@```"`9@``#````(EF```$````EF8```\```";9@``"P```*MF```.
M````MV8```4```#&9@``*````,QF```*````]68``!4`````9P``$@```!9G
M```+````*6<``!T````U9P``#@```%-G```*````8F<```T```!M9P``#@``
M`'MG```&````BF<```\```"19P``&````*%G```,````NF<```@```#'9P``
M+@```-!G```:````_V<``#(````::```.````$UH``!4````AF@``%$```#;
M:```6@```"UI``!7````B&D``#0```#@:0``!0```!5J```&````&VH``!$`
M```B:@``"````#1J```E````/6H``"````!C:@``#P```(1J```*````E&H`
M``\```"?:@``%````*]J```)````Q&H```D```#.:@``#0```-AJ```2````
MYFH```\```#Y:@``#P````EK```/````&6L```@````I:P``)````#)K```(
M````5VL``!D```!@:P``!P```'IK```L````@FL```X```"O:P```P```+YK
M```+````PFL```4```#.:P``"@```-1K```4````WVL```H```#T:P``!P``
M`/]K```'````!VP```4````/;````P```!5L```7````&6P```H````Q;```
M#P```#QL```'````3&P```T```!4;```"@```&)L```8````;6P```X```"&
M;```%````)5L```7````JFP``!<```#";```$P```-IL```.````[FP``!\`
M``#];```!P```!UM```&````)6T```@````L;0``#P```#5M```*````16T`
M`!,```!0;0``"P```&1M```5````<&T``!4```"&;0``!P```)QM```%````
MI&T``!4```"J;0``$0```,!M```,````TFT``#L```#?;0``"0```!MN```'
M````)6X``!0````M;@``!0```$)N```0````2&X``!,```!9;@``.0```&UN
M```"````IVX``"<```"J;@``+````-)N```J````_VX``"4````J;P``"@``
M`%!O```&````6V\```D```!B;P``!P```&QO```O````=&\``#<```"D;P``
M+@```-QO``!5````"W```"T```!A<```+0```(]P```M````O7```$````#K
M<```(P```"QQ```C````4'$``"T```!T<0``,P```*)Q```5````UG$``!D`
M``#L<0``*0````9R```D````,'(``!$```!5<@``"@```&=R```0````<G(`
M`!8```"#<@``%@```)IR```'````L7(```<```"Y<@``%````,%R```*````
MUG(```@```#A<@``!P```.IR```'````\G(```8```#Z<@``!0````%S```'
M````!W,```8````/<P``"````!9S```.````'W,```H````N<P``!````#ES
M```'````/G,```D```!&<P``%@```%!S```(````9W,```T```!P<P``!@``
M`'YS```>````A7,``!$```"D<P``"````+9S```-````OW,```P```#-<P``
M!P```-IS```#````XG,```,```#F<P``%P```.IS```$`````G0```@````'
M=```"````!!T```@````&70```8````Z=```!@```$%T```5````2'0``!@`
M``!>=```'0```'=T``!4````E70``"D```#J=```"@```!1U```(````'W4`
M``X````H=0``"@```#=U```4````0G4``!@```!7=0``'0```'!U```3````
MCG4``!0```"B=0``!````+=U```&````O'4```4```##=0``!0```,EU```;
M````SW4``!H```#K=0``$0````9V```1````&'8``!P````J=@``$````$=V
M```A````6'8``!$```!Z=@``#````(QV```&````F78``!<```"@=@``"```
M`+AV```%````P78```P```#'=@``!@```-1V```'````VW8```T```#C=@``
M!P```/%V```+````^78```<````%=P``!P````UW```*````%7<```P````@
M=P``$````"UW```;````/G<```4```!:=P``)0```&!W```3````AG<``#L`
M``":=P``(````-9W```,````]W<```X````$>```"@```!-X```-````'G@`
M`!X````L>```&P```$MX```A````9W@``!X```")>```'@```*AX```;````
MQW@``!X```#C>```,P````)Y```O````-GD``"D```!F>0``$@```)!Y```6
M````HWD``"@```"Z>0``(````.-Y```A````!'H``$$````F>@``!P```&AZ
M```2````<'H``!(```"#>@``$P```)9Z```2````JGH```<```"]>@``!```
M`,5Z```'````RGH```P```#2>@``#P```-]Z```3````[WH```T````#>P``
M#0```!%[```&````'WL``!$````F>P``%P```#A[```;````4'L```X```!L
M>P```@```'M[```%````?GL``!,```"$>P``!````)A[```-````G7L```X`
M``"K>P```P```+I[```&````OGL```@```#%>P``#P```,Y[```0````WGL`
M``8```#O>P``"0```/9[```,`````'P```P````-?```$0```!I\```9````
M+'P``%P```!&?```#0```*-\```'````L7P``!0```"Y?```"P```,Y\```B
M````VGP``"\```#]?```"P```"U]```)````.7T``!D```!#?0``"P```%U]
M```7````:7T``!<```"!?0``"0```)E]```6````HWT```\```"Z?0``#@``
M`,I]```(````V7T```T```#B?0``)@```/!]``!#````%WX```@```!;?@``
M$@```&1^```(````=WX```L```"`?@``+P```(Q^```.````O'X```<```#+
M?@``"````--^```&````W'X```,```#C?@``!P```.=^```$````[WX```<`
M``#T?@``"@```/Q^```*````!W\```\````2?P``$````")_```7````,W\`
M`!$```!+?P``%P```%U_```%````=7\```L```![?P``!0```(=_```;````
MC7\``!<```"I?P``"0```,%_```.````RW\```T```#:?P``"````.A_```&
M````\7\```@```#X?P``"`````&````.````"H```!$````9@```!P```"N`
M```%````,X````<````Y@```"````$&````&````2H```!````!1@```$```
M`&*````/````<X````L```"#@```#P```(^````,````GX````\```"L@```
M!P```+R````&````Q(````\```#+@```"````-N````&````Y(````\```#K
M@```$P```/N````>````#X$``"$````N@0``(````%"!```9````<8$``!<`
M``"+@0``)0```*.!```7````R8$``!L```#A@0``#0```/V!```#````"X(`
M``@````/@@``"@```!B"```,````(X(```0````P@@``$P```#6"```4````
M28(```P```!>@@``"0```&N"```+````=8(``!L```"!@@``!P```)V"```'
M````I8(```H```"M@@``#0```+B"```)````QH(```0```#0@@``&````-6"
M```*````[H(``'P```#Y@@``!0```':#```'````?(,```P```"$@P``"```
M`)&#```&````FH,```@```"A@P```@```*J#```&````K8,```T```"T@P``
M$````,*#```&````TX,```0```#:@P``"0```-^#```0````Z8,```D```#Z
M@P``"0````2$```&````#H0```4````5A```!@```!N$```$````(H0``!D`
M```GA```!P```$&$```'````280```4```!1A```"0```%>$```*````880`
M``(```!LA```#0```&^$```)````?80```8```"'A```$@```(Z$```)````
MH80```<```"KA```%````+.$```=````R(0```8```#FA```"@```.V$```$
M````^(0```D```#]A```"`````>%```1````$(4```D````BA0``!@```"R%
M```-````,X4```8```!!A0``!````$B%```>````384```4```!LA0``#@``
M`'*%```&````@84``"$```"(A0``%0```*J%```$````P(4``!$```#%A0``
M!@```->%```B````WH4``!T````!A@``!````!^&```,````)(8```H````Q
MA@``"````#R&```)````188```4```!/A@``#P```%6&```'````988``"0`
M``!MA@``"````)*&```*````FX8```<```"FA@``(````*Z&```@````SX8`
M`"8```#PA@``&0```!>'```I````,8<```<```!;AP``"@```&.'```/````
M;H<```P```!^AP``!@```(N'```/````DH<``!8```"BAP``$@```+F'```0
M````S(<``!P```#=AP``#P```/J'```%````"H@``!`````0B```"0```"&(
M```$````*X@```L````PB```#````#R(```/````28@``!D```!9B```#P``
M`'.(```3````@X@``!(```"7B```!P```*J(```,````LH@``"````"_B```
M%````."(```1````]8@``!<````'B0``'````!^)```3````/(D``!$```!0
MB0``&@```&*)```>````?8D``!H```"<B0``$0```+>)```7````R8D``!4`
M``#AB0``&0```/>)```$````$8H```<````6B@``"P```!Z*```&````*HH`
M``8````QB@``!@```#B*```%````/XH```<```!%B@``!P```$V*```%````
M58H``!8```!;B@``!@```'**```&````>8H```0```"`B@``!````(6*```.
M````BHH```P```"9B@``#````*:*```-````LXH```H```#!B@``#@```,R*
M```%````VXH``"@```#AB@``#`````J+```/````%XL```H````GBP``"```
M`#*+```)````.XL``"L```!%BP``"````'&+```(````>HL``"8```"#BP``
M$@```*J+```/````O8L```8```#-BP``"@```-2+```(````WXL``"````#H
MBP``"0````F,```,````$XP```T````@C```#@```"Z,```6````/8P``!$`
M``!4C```"0```&:,```&````<(P```8```!WC```!P```'Z,```'````AHP`
M``<```".C```%@```):,```-````K8P``!X```"[C```!````-J,```%````
MWXP``!X```#EC```$`````2-```,````%8T```D````BC0``!P```"R-```*
M````-(T```D````_C0``#@```$F-```0````6(T``!H```!IC0``"@```(2-
M```)````CXT```P```"9C0``#P```*:-```(````MHT```8```"_C0``!P``
M`,:-```%````SHT``$<```#4C0``#0```!R.```*````*HX```(````UC@``
M!````#B.```E````/8X```,```!CC@``!0```&>.```J````;8X```H```"8
MC@``!````*..```*````J(X```8```"SC@``"````+J.```(````PXX```0`
M``#,C@``!0```-&.```%````UXX``!L```#=C@``+P```/F.```0````*8\`
M``H````ZCP``#P```$6/```*````58\```D```!@CP``&P```&J/```8````
MAH\``!<```"?CP``#@```+>/```#````QH\```<```#*CP``!P```-*/```'
M````VH\```H```#BCP``!P```.V/``!1````]8\``!````!'D```#````%B0
M```:````99```$H```"`D```!@```,N0```&````TI````8```#9D```'P``
M`."0```)`````)$``!@````*D0``%P```".1```)````.Y$```8```!%D0``
M5P```$R1```3````I)$``!,```"XD0```@```,R1```+````SY$```T```#;
MD0``!P```.F1```4````\9$```8````&D@``!@````V2```(````%)(```4`
M```=D@``#@```".2```'````,I(``!4````ZD@``"@```%"2```+````6Y(`
M``<```!GD@``"0```&^2```)````>9(```H```"#D@``!P```(Z2```)````
MEI(```<```"@D@``"@```*B2```2````LY(```H```#&D@``"0```-&2```0
M````VY(```<```#LD@``$@```/22```'````!Y,```4````/DP``!0```!63
M```+````&Y,``!0````GDP``$0```#R3```8````3I,``!P```!GDP``&0``
M`(23```'````GI,```4```"FDP``#0```*R3```)````NI,```@```#$DP``
M%P```,V3```+````Y9,``!,```#QDP``!`````64```*````"I0```@````5
ME```#````!Z4```)````*Y0```D````UE```!0```#^4```'````190```4`
M``!-E```!````%.4```I````6)0``#(```""E```+@```+64```S````Y)0`
M`#,````8E0``.````$R5```+````A94``!````"1E0``$P```**5```M````
MMI4``"T```#DE0``,0```!*6```N````1)8``"\```!SE@``+````*.6```3
M````T)8``"L```#DE@``&@```!"7```)````*Y<``$4````UEP``00```'N7
M```$````O9<``!0```#"EP``#@```->7```3````YI<``!@```#ZEP``!@``
M`!.8```)````&I@```H````DF```#P```"^8```.````/Y@```4```!.F```
M"````%28```&````79@``!0```!DF```$0```'F8```.````BY@```(```":
MF```#@```)V8```%````K)@```<```"RF```!@```+J8```$````P9@``"D`
M``#&F```'P```/"8``!<````$)D``!0```!MF0``!P```(*9```.````BID`
M``P```"9F0``#````*:9```3````LYD``!T```#'F0``&0```.69```%````
M_YD``!$````%F@``$0```!>:```D````*9H``!4```!.F@``$@```&2:```.
M````=YH``!D```"&F@``"````*":```)````J9H```@```"SF@``!0```+R:
M```?````PIH```8```#BF@``$````.F:```(````^IH```@````#FP``+```
M``R;```:````.9L```D```!4FP``"@```%Z;```5````:9L```4```!_FP``
M%````(6;```$````FIL```<```"?FP``$````*>;```>````N)L``"@```#7
MFP``'@````"<```*````'YP``!H````JG```%````$6<```$````6IP```L`
M``!?G```!0```&N<```&````<9P```@```!XG```(````(&<``!!````HIP`
M`!H```#DG```*````/^<```I````*)T```8```!2G0``!0```%F=```(````
M7YT``"H```!HG0``(P```).=```N````MYT``#0```#FG0``"````!N>```7
M````))X```H````\G@``!P```$>>```,````3YX``!````!<G@``"P```&V>
M```3````>9X```@```"-G@``"P```):>```*````HIX``!0```"MG@``,@``
M`,*>```+````]9X```4````!GP``%P````>?```/````'Y\```4````OGP``
M!````#6?```-````.I\``#(```!(GP``"P```'N?```/````AY\``!,```"7
MGP``$P```*N?```/````OY\```P```#/GP``#@```-R?```-````ZY\```T`
M``#YGP``%P````>@```4````'Z````4````TH```!P```#J@```.````0J``
M`"H```!1H```!@```'R@```,````@Z````L```"0H```-@```)R@```+````
MTZ````\```#?H```,@```.^@```%````(J$``!$````HH0``!P```#JA```1
M````0J$```<```!4H0``!````%RA```'````8:$```H```!IH0``"P```'2A
M```,````@*$```,```"-H0``$@```)&A```&````I*$``!X```"KH0``&```
M`,JA```E````XZ$```T````)H@``"0```!>B```#````(:(```<````EH@``
M`@```"VB```,````,*(``!4````]H@``"P```%.B```9````7Z(``"````!Y
MH@``$@```)JB```%````K:(```H```"SH@``%0```+ZB```2````U*(```@`
M``#GH@``#````/"B```'````_:(```L````%HP``"@```!&C```,````'*,`
M`%(````IHP``%P```'RC```5````E*,``!(```"JHP``#P```+VC```4````
MS:,``!L```#BHP``6````/ZC``!I````5Z0``!H```#!I```%P```-RD```:
M````]*0``!D````/I0``&@```"FE```7````1*4``!T```!<I0``&P```'JE
M```9````EJ4``!\```"PI0``$P```-"E```'````Y*4```@```#LI0``"0``
M`/6E```5````_Z4```T````5I@``$P```".F```#````-Z8``#\````[I@``
M-P```'NF``!7````LZ8``"\````+IP``"@```#NG```(````1J<```T```!/
MIP``+0```%VG```$````BZ<``!\```"0IP``)0```+"G```H````UJ<```L`
M``#_IP``'0````NH```&````*:@```P````PJ```!P```#VH```)````1:@`
M`!,```!/J```"0```&.H```$````;:@``!````!RJ```"````(.H```(````
MC*@```P```"5J```#P```**H```'````LJ@``!0```"ZJ```#@```,^H```,
M````WJ@``!L```#KJ```+`````>I```3````-*D```4```!(J0``!````$ZI
M```7````4ZD```D```!KJ0``"````'6I```*````?JD```@```")J0``"@``
M`)*I```*````G:D``!$```"HJ0``#@```+JI```.````R:D```T```#8J0``
M"P```.:I```"````\JD```<```#UJ0``!@```/VI```)````!*H```<````.
MJ@``%0```!:J```%````+*H```<````RJ@``"````#JJ```'````0ZH```8`
M``!+J@``!P```%*J```.````6JH```D```!IJ@``!@```'.J```(````>JH`
M``L```"#J@``!P```(^J```(````EZH```<```"@J@``%@```*BJ```)````
MOZH```8```#)J@``"P```-"J```4````W*H```@```#QJ@``!@```/JJ```9
M`````:L```H````;JP``'````":K```'````0ZL```4```!+JP``$````%&K
M```4````8JL```L```!WJP``#0```(.K```7````D:L```0```"IJP``"0``
M`*ZK```"````N*L```X```"[JP``"````,JK```?````TZL``",```#SJP``
M,0```!>L```G````2:P``$H```!QK```.````+RL```O````]:P``"@````E
MK0``+````$ZM```;````>ZT``#X```"7K0``2````-:M``!!````'ZX``%L`
M``!AK@``20```+VN```A````!Z\``!\````IKP``*P```$FO```A````=:\`
M`#,```"7KP``)0```,NO```G````\:\``#`````9L```:0```$JP```]````
MM+```&4```#RL```30```%BQ```O````IK$``"X```#6L0``5`````6R```?
M````6K(``#(```!ZL@``+P```*VR```L````W;(``"T````*LP``%P```#BS
M```E````4+,``#(```!VLP``*0```*FS```^````T[,``"(````2M```4@``
M`#6T```E````B+0```L```"NM```(0```+JT```P````W+0``"4````-M0``
M'````#.U```Q````4+4```@```""M0``!````(NU```-````D+4```L```">
MM0``#@```*JU```+````N;4```4```#%M0```@```,NU``!9````SK4```4`
M```HM@``$@```"ZV```$````0;8```<```!&M@``!0```$ZV```3````5+8`
M``T```!HM@```@```':V```'````>;8```<```"!M@``!@```(FV```4````
MD+8```P```"EM@``&````+*V```&````R[8```0```#2M@``$@```->V```,
M````ZK8```0```#WM@``!@```/RV```'`````[<``!\````+MP``-0```"NW
M```N````8;<``"\```"0MP``%P```,"W```;````V+<``!@```#TMP``)```
M``VX```?````,K@``!H```!2N```&@```&VX```O````B+@``"L```"XN```
M'P```.2X```C````!+D``!\````HN0``&@```$BY```E````8[D``"8```")
MN0``)0```+"Y```8````UKD``!T```#ON0``)`````VZ```8````,KH``"(`
M``!+N@``)0```&ZZ```?````E+H``",```"TN@``'P```-BZ```@````^+H`
M`!H````9NP``)@```#2[```>````6[L``!X```!ZNP``"0```)F[```,````
MH[L``!<```"PNP``+P```,B[```D````^+L```\````=O```%````"V\```.
M````0KP```T```!1O```)````%^\```%````A+P```<```"*O```'0```)*\
M```5````L+P```8```#&O```"0```,V\```+````U[P``!<```#CO```!@``
M`/N\```S`````KT```<````VO0``(0```#Z]```3````8+T```X```!TO0``
M#````(.]```1````D+T``#(```"BO0``"````-6]```)````WKT```H```#H
MO0``%````/.]```*````"+X``!T````3O@``"````#&^```?````.KX```@`
M``!:O@``&@```&.^```&````?KX```<```"%O@``"````(V^```)````EKX`
M`#\```"@O@``!P```."^```/````Z+X```@```#XO@``$P````&_```'````
M%;\``!D````=OP``"@```#>_```7````0K\``!0```!:OP``"@```&^_```,
M````>K\``!<```"'OP``!````)^_```J````I+\``!$```#/OP``!P```.&_
M```"````Z;\``!````#LOP```P```/V_```(`````<````D````*P```!```
M`!3````'````&<````<````AP```!@```"G````4````,,````<```!%P```
M#0```$W````+````6\```!0```!GP```%0```'S````.````DL```"\```"A
MP```(````-'````<````\L```$@````/P0``3````%C!```3````I<$```4`
M``"YP0``!@```+_!```,````QL$```H```#3P0``"0```-[!```1````Z,$`
M``(```#ZP0``!````/W!```*`````L(```8````-P@``%````!3"```%````
M*<(```P````OP@``10```#S"```H````@L(``%,```"KP@``&0```/_"```@
M````&<,``#4````ZPP``10```'##```P````ML,``"@```#GPP``)@```!#$
M```E````-\0``"@```!=Q```*````(;$```P````K\0``!(```#@Q```$```
M`//$``!Y````!,4```D```!^Q0``<P```(C%``!\````_,4``"L```!YQ@``
M%P```*7&```?````O<8``!0```#=Q@``"@```/+&```%````_<8```8````#
MQP``"`````K'```0````$\<```\````DQP```P```#3'```&````.,<```0`
M```_QP``!````$3'```9````2<<```(```!CQP``"0```&;'```(````<,<`
M``0```!YQP``#P```'['```3````CL<``!````"BQP``$P```+/'```B````
MQ\<```<```#JQP``"P```/+'```%````_L<```(````$R```"P````?(```$
M````$\@```L````8R```!0```"3(```'````*L@``%@!```RR```"@```(O)
M```,````ELD```<```"CR0``!P```*O)```"````L\D``!(```"VR0``"P``
M`,G)```'````U<D```4```#=R0``$@```./)```'````]LD```L```#^R0``
M"0````K*```+````%,H``!(````@R@``"0```#/*```%````/<H```H```!#
MR@``#P```$[*```&````7LH```P```!ER@``$@```'+*```*````A<H```D`
M``"0R@``'0```)K*```4````N,H``"4```#-R@``+0```//*```\````(<L`
M`$````!>RP``0````)_+``!&````X,L``"<````GS```!0```$_,```(````
M5<P```X```!>S```!P```&W,```;````=<P``!L```"1S```"P```*W,```$
M````N<P```H```"^S```#````,G,```(````ULP```H```#?S```"@```.K,
M```(````]<P```H```#^S```#0````G-```-````%\T```8````ES0``'P``
M`"S-```(````3,T``!D```!5S0``!````&_-```?````=,T```0```"4S0``
M"````)G-```&````HLT```0```"IS0``"````*[-```/````M\T```@```#'
MS0``"@```-#-```*````V\T```0```#FS0``!````.O-```0````\,T```H`
M```!S@``"`````S.```$````%<X```H````:S@``"````"7.```4````+LX`
M``8```!#S@``#@```$K.```.````6<X```X```!HS@``"````'?.```*````
M@,X``!4```"+S@``!@```*'.```&````J,X```8```"OS@``"````+;.```&
M````O\X``!````#&S@``"````-?.```.````X,X``!(```#OS@``!`````+/
M```$````!\\``!<````,SP``#````"3/```,````,<\``!H````^SP``!@``
M`%G/```(````8,\``!8```!ISP``!@```(#/```*````A\\```\```"2SP``
M'0```*+/```"````P,\``!L```##SP``&0```-_/```;````^<\``!D````5
MT```!````"_0```$````--````@````YT```!@```$+0```J````2=```",`
M``!TT```*0```)C0``!K````PM```"@````NT0``*````%?1```H````@-$`
M`"<```"IT0``&@```-'1```:````[-$``"@````'T@``+@```##2```)````
M7](```P```!IT@``$````';2```-````A](```L```"5T@``"````*'2```(
M````JM(``!(```"ST@``%````,;2```*````V](```0```#FT@``&````.O2
M```(````!-,```@````-TP``"````!;3```&````'],```8````FTP``!```
M`"W3```*````,M,```0````]TP``!````$+3```(````1],```@```!0TP``
M!````%G3```(````7M,```0```!GTP``%````&S3```(````@=,```@```"*
MTP``!````)/3```.````F-,```0```"GTP``"````*S3```(````M=,```H`
M``"^TP``!@```,G3```,````T-,```,```#=TP``"@```.'3```&````[-,`
M``8```#STP``!@```/K3```:`````=0```8````<U```!````"/4```,````
M*-0``!(````UU```$@```$C4```Q````6]0``!D```"-U```!@```*?4```$
M````KM0```@```"SU```"````+S4```6````Q=0```H```#<U```$0```.?4
M```(````^=0```@````"U0``!`````O5```$````$-4```0````5U0``!```
M`!K5```1````']4```\````QU0``"````$'5```.````2M4```T```!9U0``
M!@```&?5```5````;M4```P```"$U0``"````)'5```$````FM4```H```"?
MU0``"````*K5```$````L]4```8```"XU0``!````+_5```$````Q-4```@`
M``#)U0``!````-+5```&````U]4```8```#>U0``!````.75```$````ZM4`
M``<```#OU0``"````/?5```-`````-8```0````.U@``"@```!/6```*````
M'M8``"L````IU@``&@```%76```(````<-8```@```!YU@``"@```(+6```(
M````C=8``!0```"6U@``&````*O6```7````Q-8``!<```#<U@``%````/36
M```2````"=<``!4````<UP``'0```#+7```=````4-<``!<```!NUP``#```
M`(;7```7````D]<``!@```"KUP``$P```,37```6````V-<``#````#OUP``
M!````"#8```,````)=@```P````RV```#````#_8```*````3-@```@```!7
MV```!````&#8```$````9=@```@```!JV```"````'/8```*````?-@```@`
M``"'V```"````)#8```(````F=@``!$```"BV```%P```+38```:````S-@`
M``H```#GV````@```/+8```$````]=@```8```#ZV```!`````'9```(````
M!MD```@````/V0```@```!C9```"````&]D```8````>V0``"````"79```,
M````+MD```0````[V0``!P```$#9```(````2-D```H```!1V0``"````%S9
M```.````9=D``#,```!TV0``"````*C9```$````L=D```@```"VV0``!```
M`+_9```=````Q-D``!<```#BV0``!````/K9```(````_]D``!8````(V@``
M"@```!_:```(````*MH```@````SV@``!````#S:```1````0=H```@```!3
MV@``"````%S:```&````9=H```8```!LV@``'````'/:```I````D-H```@`
M``"ZV@``#@```,/:```$````TMH```<```#7V@``'@```-_:```(````_MH`
M``@````'VP``!````!#;```(````%=L```0````>VP``"````"/;```$````
M+-L```<````QVP``"````#G;```*````0ML```@```!-VP``"````%;;```.
M````7]L```@```!NVP``#@```'?;```$````AML```@```"+VP``"````)3;
M```5````G=L```P```"SVP``"````,#;```)````R=L```D```#3VP``"```
M`-W;```&````YML```@```#MVP``!````/;;```*````^]L```H````&W```
M"@```!'<```$````'-P```@````AW```"@```"K<```$````-=P```H````Z
MW```"@```$7<```)````4-P```@```!:W```"@```&/<```)````;MP```<`
M``!XW```!````(#<```$````A=P```8```"*W```!@```)'<```$````F-P`
M``P```"=W```#0```*K<```0````N-P``!4```#)W```%````-_<```0````
M]-P``!`````%W0``&P```!;=```0````,MT``!T```!#W0``"````&'=```$
M````:MT```0```!OW0``"````'3=```*````?=T```0```"(W0``$P```(W=
M```1````H=T```H```"SW0``"````+[=```(````Q]T``!4```#0W0``!@``
M`.;=```$````[=T```8```#RW0``!@```/G=```(`````-X```0````)W@``
M#@````[>```(````'=X``$X````FW@``!````'7>```$````>MX```@```!_
MW@``!````(C>```$````C=X```@```"2W@``!@```)O>```$````HMX```H`
M``"GW@``#@```++>```&````P=X```8```#(W@```@```,_>```(````TMX`
M``0```#;W@``!````.#>```*````Y=X```0```#PW@``!@```/7>```$````
M_-X``!(````!WP``"````!3?```$````'=\```0````BWP``"````"??```"
M````,-\```0````SWP``"P```#C?```$````1-\```0```!)WP``$P```$[?
M```&````8M\```@```!IWP``"@```'+?```2````?=\```8```"0WP``"@``
M`)??```$````HM\```@```"GWP``"````+#?```(````N=\```@```#"WP``
M!@```,O?```0````TM\```8```#CWP``!````.K?```1````[]\```0````!
MX```"0````;@```$````$.```!`````5X```%P```";@```$````/N````X`
M``!#X```!````%+@```1````5^````8```!IX```!````'#@```(````=>``
M``@```!^X```"````(?@```(````D.````4```"9X```!@```)_@```"````
MIN````T```"IX```!````+?@```&````O.````8```##X```%0```,K@```5
M````X.```!T```#VX```$````!3A```@````)>$```0```!&X0``"````$OA
M```*````5.$```@```!?X0``!````&CA```-````;>$``!$```![X0``#```
M`(WA```)````FN$``!,```"DX0``"````+CA```$````P>$```@```#&X0``
M"@```,_A```$````VN$```0```#?X0``"````.3A```,````[>$```X```#Z
MX0``"`````GB```-````$N(``!$````@X@``!````#+B```&````-^(``!D`
M```^X@``#P```%CB```/````:.(```\```!XX@``#@```(CB```0````E^(`
M`!````"HX@``%@```+GB```3````T.(```\```#DX@``#P```/3B```/````
M!.,``!$````4XP``$````";C```&````-^,```8````^XP``!````$7C```&
M````2N,```8```!1XP``!````%CC```&````7>,```8```!DXP``!````&OC
M```,````<.,``!(```!]XP``!@```)#C```$````E^,```0```"<XP``!```
M`*'C```$````IN,```@```"KXP``"````+3C```(````O>,```H```#&XP``
M"@```-'C```&````W.,``!(```#CXP``"````/;C```(````_^,```@````(
MY```"````!'D```(````&N0``"@````CY```!@```$SD```.````4^0```0`
M``!BY```!````&?D```-````;.0```8```!ZY```"@```('D```$````C.0`
M``0```"1Y```!@```);D```&````G>0```D```"DY```#@```*[D```4````
MO>0``!8```#2Y```!````.GD```(````[N0```@```#WY```!@````#E```&
M````!^4```@````.Y0``!@```!?E```*````'N4``!$````IY0``!````#OE
M```$````0.4``!T```!%Y0``#````&/E```1````<.4```\```""Y0``$P``
M`)+E```1````IN4``!$```"XY0``#P```,KE```3````VN4``!0```#NY0``
M!`````/F```&````".8```H````/Y@``"@```!KF```$````)>8```0````J
MY@``!````"_F```$````-.8``"L````YY@``"0```&7F```&````;^8```(`
M``!VY@``"````'GF```;````@N8```,```">Y@``"````*+F```,````J^8`
M``P```"XY@``!````,7F```(````RN8```8```#3Y@``"````-KF```(````
MX^8```0```#LY@``!@```/'F```$````^.8``!(```#]Y@``)````!#G```*
M````-><```H```!`YP``#````$OG```*````6.<```@```!CYP``%P```&SG
M```8````A.<``!<```"=YP``#````+7G```"````PN<```H```#%YP``!```
M`-#G```$````U><```D```#:YP``!````.3G```L````Z><```L````6Z```
M"````"+H```3````*^@``"L````_Z```!````&OH```$````<.@```8```!U
MZ```$@```'SH```)````C^@``!@```"9Z```%P```++H```$````RN@```0`
M``#/Z```-P```-3H```0````#.D``!`````=Z0``!@```"[I```(````->D`
M``@````^Z0``!````$?I```(````3.D```8```!5Z0``!@```%SI```$````
M8^D```(```!HZ0``!@```&OI```$````<ND```8```!WZ0``"@```'[I```(
M````B>D```8```"2Z0``!````)GI```$````GND```0```"CZ0``!````*CI
M```$````K>D```0```"RZ0``"````+?I```$````P.D```@```#%Z0``"```
M`,[I```0````U^D```0```#HZ0``"P```.WI```(````^>D```0````"Z@``
M!@````?J```$````#NH```P````3Z@``$P```"#J```7````-.H``!,```!,
MZ@``$0```&#J```$````<NH```0```!WZ@``#````'SJ```&````B>H```0`
M``"0Z@``$0```)7J```&````I^H```\```"NZ@``!````+[J```&````P^H`
M``8```#*Z@``"@```-'J```&````W.H```@```#CZ@``!@```.SJ```(````
M\^H```0```#\Z@``!@````'K```:````".L``!\````CZP``%P```$/K```<
M````6^L``!L```!XZP``(````)3K```$````M>L```H```"ZZP``$````,7K
M```;````UNL``!L```#RZP``'P````[L```<````+NP``!T```!+[```&@``
M`&GL```3````A.P``!,```"8[```&0```*SL```&````QNP``"\```#-[```
M,0```/WL```"````+^T``!8````R[0``"````$GM```&````4NT```X```!9
M[0``!````&CM```&````;>T```8```!T[0``#````'OM```(````B.T```8`
M``"1[0``!@```)CM```$````G^T```8```"D[0``"````*OM```$````M.T`
M``(```"Y[0``"@```+SM```&````Q^T```0```#.[0``!@```-/M```$````
MVNT``",```#?[0``$P````/N```F````%^X```X````^[@``!````$WN```)
M````4NX```@```!<[@``!````&7N```(````:NX``!````!S[@``%````(3N
M```$````F>X```@```">[@``"@```*?N```-````LNX```P```#`[@``#```
M`,WN```,````VNX``!8```#G[@``#````/[N```(````"^\```@````4[P``
M!````!WO```0````(N\```8````S[P``#@```#KO```&````2>\```0```!0
M[P``'0```%7O```(````<^\```4```!\[P``!@```(+O```-````B>\```0`
M``"7[P``!````)SO```$````H>\```0```"F[P``"@```*OO```,````MN\`
M`!,```##[P``#P```-?O```$````Y^\```@```#L[P``!````/7O```$````
M^N\```8```#_[P``!`````;P```$````"_````@````0\```%0```!GP```F
M````+_```!$```!6\```$0```&CP```6````>O````0```"1\```!````);P
M```&````F_```"L```"B\```%@```,[P```I````Y?```"\````/\0``!```
M`#_Q```,````1/$```8```!1\0``!````%CQ```&````7?$```H```!D\0``
M"````&_Q```(````>/$```0```"!\0``"````(;Q```(````C_$```P```"8
M\0``&@```*7Q```(````P/$```8```#)\0``%````-#Q```$````Y?$```0`
M``#J\0``!````._Q```(````]/$``"4```#]\0``"````"/R```(````+/(`
M``H````U\@``"````$#R```(````2?(```@```!2\@``"````%OR```(````
M9/(```@```!M\@``"````';R```-````?_(```H```"-\@``!````)CR```*
M````G?(``"@```"H\@``!````-'R```(````UO(```8```#?\@``)P```.;R
M```(````#O,```P````7\P``%P```"3S```$````//,```P```!!\P``!```
M`$[S```(````4_,``!(```!<\P``!````&_S```2````=/,```L```"'\P``
M"````)/S```(````G/,```0```"E\P``&P```*KS```/````QO,```\```#6
M\P``%@```.;S```.````_?,```0````,]```"@```!'T```*````'/0```0`
M```G]```!@```"ST```*````,_0```X````^]```"@```$WT```4````6/0`
M`!(```!M]```$@```(#T```&````D_0```@```":]```$````*/T```*````
MM/0```8```"_]```"@```,;T```'````T?0```@```#9]```"````.+T```(
M````Z_0``#H```#T]```#P```"_U```6````/_4``!(```!6]0``#@```&GU
M```4````>/4``!$```"-]0``,````)_U``!#````T/4```T````4]@``$0``
M`"+V```3````-/8``!$```!(]@``#0```%KV```1````:/8``!0```!Z]@``
M%P```(_V```0````I_8```T```"X]@``#````,;V```2````T_8```@```#F
M]@``!````._V```L````]/8```0````A]P``#P```";W```$````-O<``"$`
M```[]P``(P```%WW```Z````@?<``!P```"\]P``$P```-GW```$````[?<`
M``@```#R]P``(0```/OW```$````'?@``!D````B^```(````#SX```;````
M7?@```H```!Y^```$P```(3X```$````F/@``!<```"=^```!````+7X```$
M````NO@```@```"_^```$@```,CX```$````V_@```@```#@^```$P```.GX
M```5````_?@```H````3^0``'````![Y```2````._D```P```!.^0``"```
M`%OY```3````9/D``!$```!X^0``+````(KY```&````M_D```X```"^^0``
M"````,WY```,````UOD``!0```#C^0``!````/CY```(````_?D```8````&
M^@``"`````WZ```(````%OH```(````?^@``"````"+Z```$````*_H```8`
M```P^@``"````#?Z```&````0/H```0```!'^@``!````$SZ```$````4?H`
M``0```!6^@``#0```%OZ```,````:?H```0```!V^@``!````'OZ```$````
M@/H```8```"%^@``!````(SZ```)````D?H```8```";^@``!````*+Z```&
M````I_H```0```"N^@``!````+/Z```1````N/H```0```#*^@``%@```,_Z
M```4````YOH```T```#[^@``$@````G[```=````'/L``!`````Z^P``!```
M`$O[```$````4/L``!4```!5^P``)P```&O[```%````D_L```@```"9^P``
M"````*+[```2````J_L```0```"^^P``!@```,/[```(````ROL```0```#3
M^P``!@```-C[```&````W_L```X```#F^P``#P```/7[```1````!?P``!@`
M```7_```'````##\```6````3?P``"@```!D_```&P```(W\```9````J?P`
M`!T```##_```'0```.'\```1````__P``!D````1_0``,@```"O]```O````
M7OT``#$```"._0``+P```,#]```7````\/T``!<````(_@``%@```"#^```3
M````-_X``!\```!+_@``$P```&O^```9````?_X``!$```"9_@``0@```*O^
M```D````[OX``#D````3_P``+P```$W_```7````??\``!L```"5_P``.```
M`+'_```/````ZO\``"4```#Z_P``'@```"```0`>````/P`!`!L```!>``$`
M$0```'H``0`9````C``!`!L```"F``$`&P```,(``0`D````W@`!``\````#
M`0$`/0```!,!`0`3````40$!``@```!E`0$`$P```&X!`0`M````@@$!`!<`
M``"P`0$`#P```,@!`0`D````V`$!``8```#]`0$`!`````0"`0`(````"0(!
M``@````2`@$`"````!L"`0`+````)`(!``@````P`@$`!@```#D"`0!/````
M0`(!``0```"0`@$`#0```)4"`0`$````HP(!``H```"H`@$`!````+,"`0`0
M````N`(!``8```#)`@$`!@```-`"`0`&````UP(!``8```#>`@$`!@```.4"
M`0`5````[`(!``H````"`P$`$@````T#`0`&````(`,!``0````G`P$`#@``
M`"P#`0`,````.P,!``4```!(`P$`!@```$X#`0`&````50,!`!(```!<`P$`
M'0```&\#`0`>````C0,!`!\```"L`P$`#@```,P#`0`2````VP,!`!(```#N
M`P$`%P````$$`0`2````&00!`!(````L!`$`$0```#\$`0`:````400!`!$`
M``!L!`$`$@```'X$`0`6````D00!`!<```"H!`$`$@```,`$`0`5````TP0!
M`!,```#I!`$`$````/T$`0`2````#@4!`!<````A!0$`$@```#D%`0`2````
M3`4!`!$```!?!0$`%@```'$%`0`8````B`4!`!8```"A!0$`'@```+@%`0`?
M````UP4!`!@```#W!0$`$@```!`&`0`7````(P8!`!8````[!@$`!@```%(&
M`0`(````608!``0```!B!@$`'@```&<&`0`;````A@8!``X```"B!@$`$```
M`+$&`0`$````P@8!``0```#'!@$`)````,P&`0`$````\08!``8```#V!@$`
M$P```/T&`0`.````$0<!``0````@!P$`!P```"4'`0`(````+0<!``\````V
M!P$`!````$8'`0`E````2P<!``8```!Q!P$`'0```'@'`0`(````E@<!``H`
M``"?!P$`"````*H'`0`(````LP<!`!L```"\!P$`!@```-@'`0`'````WP<!
M``8```#G!P$`#0```.X'`0`,````_`<!`!$````)"`$`!````!L(`0`2````
M(`@!``8````S"`$`&````#H(`0`"````4P@!``@```!6"`$`!````%\(`0`(
M````9`@!`"0```!M"`$`!````)((`0`(````EP@!``0```"@"`$`#P```*4(
M`0`'````M0@!``P```"]"`$`"@```,H(`0`.````U0@!``P```#D"`$`!@``
M`/$(`0`(````^`@!`!T````!"0$`!````!\)`0`;````)`D!`!````!`"0$`
M!````%$)`0`&````5@D!``@```!="0$`!````&8)`0`$````:PD!``8```!P
M"0$``@```'<)`0`%````>@D!``(```"`"0$`!````(,)`0`&````B`D!``0`
M``"/"0$`"0```)0)`0`(````G@D!`!$```"G"0$`$@```+D)`0`(````S`D!
M`",```#5"0$`#P```/D)`0`-````"0H!`!8````7"@$`%@```"X*`0`(````
M10H!``4```!."@$`!@```%0*`0`*````6PH!``H```!F"@$`!@```'$*`0`-
M````>`H!``(```"&"@$``@```(D*`0`,````C`H!``0```"9"@$`!@```)X*
M`0`$````I0H!``L```"J"@$`/0```+8*`0`A````]`H!`"4````6"P$`"P``
M`#P+`0`7````2`L!`#\```!@"P$`(0```*`+`0`<````P@L!`!4```#?"P$`
M$P```/4+`0`3````"0P!`!,````=#`$`$P```#$,`0`>````10P!`!````!D
M#`$`"````'4,`0!1````?@P!``@```#0#`$`*P```-D,`0!1````!0T!`!L`
M``!7#0$`$P```',-`0`/````APT!``\```"7#0$`"````*<-`0`&````L`T!
M``8```"W#0$`"````+X-`0`*````QPT!`!0```#2#0$``@```.<-`0`"````
MZ@T!``(```#M#0$`!````/`-`0`3````]0T!``,````)#@$`!`````T.`0`"
M````$@X!``0````5#@$`"0```!H.`0`)````)`X!``@````N#@$`#@```#<.
M`0`:````1@X!``8```!A#@$`"````&@.`0`%````<0X!``4```!W#@$`$```
M`'T.`0`"````C@X!``,```"1#@$``@```)4.`0`"````F`X!``$````H`0``
MY@``````````````<`(````````=`@``-P$``(<"``````````````H!```9
M!```%P```+8#``#?`0``?`(``````````````````)($````````;@$`````
M`````````P0``,,$```Z`@```````*<!``#\`0``B0,``+L#``!F`0``H00`
M`"D$``"W`0``6@````````#%!```N`0```<"``!3`P``J`,`````````````
M``````````#N`P``+@,``%\````H!```_@``````````````OP````````"P
M`0```P```/H!``")`0``;P,```````"J`@``X@(```D$``!V````;P(`````
M````````N@$``.\!````````+0$```````"P`P``700``*\!``"4!```N0(`
M``````#E`0``/````-P```"[````LP````````"\!```AP$``&\$````````
MP0(``.H!``#.````^P```',$```O!```3@```.H#```T`@``F@````$"``!V
M`@``3P(``&$!``#3````R`$``)X$````````(P```!@$``"0`@``O````&@`
M``"G````J`(`````````````K0$``,D````+`@``9@,``%<"```>!```-0``
M`,H```"8`@``P0$``+P#`````````````"D"``!>`````````!X```#H````
M`````/\!``#D`````````#H#``!``@``>`0```````"4`P``I@$``-D"``"Z
M`P``:P$``#,#``#\```````````````[`@```````'D!``!I`@```````'D#
M`````````````+4!````````4`$````````M`@``W0$```````#]````5@(`
M```#```F`0``:0,``"$#``"T`@``F`$``!$!``!&`@``>`(``)$#``!D`P``
MGP$```D!````````3P$```4``````````````.T#``#2`P``&P0``'T```#U
M`P``&0(```8$```L````S`$``/X"``"7``````````````#<`0``FP,```X#
M````````````````````````^0,``/H#``"$`0``M0(``$T$```1````5`$`
M``````#P````L`(``'4!`````````````#\```#U`@``0`$`````````````
M``````````#2`@``XP```*`$````````Z0,``/`"`````````````+D$````
M`````````,0$```"````.P,```````!>`0``#P$``)@#``"(`P``]`(``)D"
M``"``0````````D"```(!`````````````"$!```=@$``)P$```=`0``9```
M`+0#``#``0```P(``"D!``#B`````````#P$``!3````^`$```````!8`P``
M`````%4!``#V`@``]P,``#L!````````+`$``/,!````````W@,``(,`````
M```````````````Y`0``MP,``$D#``#A`P``H`,```````"1!```00```,$#
M``````````````````"<`P``1@$``%L"````````.`````````!C`@``\0,`
M`,D!``!M````%P(``)8``````````````-$"````````Y0(``%<#````````
M`````+T$``"3`@``%`$``#P#```J`0``1P```/4!``"'`P``P00``*0"``!#
M`@``C````*X"```;`````````'($```L`@``K@$``"T$```/!```@@```-0"
M``"Z````````````````````OP(``*H!```/`````````#L````O`@``````
M`!T#``#7````$`$``%`````K!```/P(``,0#``"(`0``V0```*0#````````
M`````!@#````````'`(``(4"``!Z!````````"8#`````````````*("```A
M````[@(``)L$````````V0$```````#4`P``+P$```0````"`@```````&,$
M```U`0``<0(``#,$``````````````````#'!```=`,``-L"``#'````[@``
M`%("````````C@,``)T$``!(`@``70$``.H````0!```+`,``/0!``!J````
M`````)<$````````$@$```H$``#I``````````````#D`@``1`(``(D"```A
M!```_0$``%H$````````L0```%H"`````````````,\!````````T0$``',`
M``````````````````!R`@``PP$``#8````I````K`$``,\#````````P@$`
M`(\```!M`0```````-,"````````A0,``.L!````````#P(``-$`````````
MX0````````"O!````````*@```"*`P```````-@#``"B````OP0`````````
M````!`,```````#%`0``BP(``/D```!$```````````````Q!```K0(`````
M```\`@``;````.<#```````````````````J`P``@0(```````#$````50``
M`*8#````````````````````````/`$```````"6`0``JP```/,#````````
M[`(``````````````````-8```"V````,P(``&4#``"!`0``C@0```````!/
M!```%P0``*T$```A`0``7`(``-<!```?!```U@(``/P#``!A`P```P,``(@"
M``"5`0```````-$#``!9!```HP```%4$``"9`P```````'8$``"6`@``BP$`
M`!H!``!]!```E0,``$$$````````:@,``'L$``"F`@``.00`````````````
M-P```"($``""!```2````%$"``#[`@```````````````````````#H```"#
M!```"P0````````X`0``6P0``.`#``!(`0```````!T$```5`P``+0``````
M```V!```#0$``.D"```@!````````+X!``````````````````"'!```````
M``\#````````W@(``',!```.`0``/0$``(4$``#L`0``S0```"$"```^`0``
M``````0"``"L!```(@$``/0```">`P````````````#3`P```````#@#``"^
M````K`(```4!``#(`P``H@0````````@`0``9P,``*P```#7`@```````%`"
M``"C!````````!H"``!>`@``<@,``.8"```E!````````/H```#W`@``HP$`
M``````#*`@```````'$#````````:P(``%T```"]`P``^@(```````"#`P``
M)`(``#0$``!>!````````*L"````````0@,````````&``````````X$``""
M`@``^0$``"\#`````````````!0#````````=P```'X#``!8!```:`0``,T#
M````````(P(``%(`````````]P```",$```M`P``Y@$``,L!```-`P``````
M`.<!``"?!```DP,``-L`````````L@```$,!``!@`P`````````````!`0``
M`````(T#`````````````%`$``!6`0```````)@```!%`P``@`0```````!,
M`0``9P(```````!Z`@``<@````````"A`0``Y0```,8#``!=`P``N0$``-H`
M``!M!```N@0``&T"``#R`@``,@,``$4$``"I``````````````!U````````
M`,L#````````N`(``(H"```-`@``T````#$!``"[`0``7P0```````"%````
M`````'X```!H`0``X`$``(D$``",!```I`$``-`#```8`0``1@```/$!``"C
M`P``Q@```,H#````````&P$```````!"`@``2P0``+@#``"B`0``V@$``$P"
M```;`P``_@$``'D```"5````4P(````````!`P```````/`!``#O`P``T@``
M``L#``#H`@```````/L!````````PP(``#X#``!U!```>@```,X"````````
M`````*<"``!3!```C`,``)8#``!P````@@$``"0!``!X`P``J0(```````!_
M`@``U@,``&$"`````````````"<$```,`P```````'4#``!S`P``\@$``'L`
M```3`P``)P$````````T`0``C@```#X$````````H0````````#%`@``N@(`
M`/\"``!9````CP(``'<#``#V`P````````````!Z`P``D`$```````#:`P``
M,P``````````````````````````````-0,``'L#``#I`0```````),$``"2
M````2@,``,($```?````M0````````#E`P``G0$``!("````````XP$`````
M```$`0``````````````````7@,``%H!``#C`@``U0````````!7````````
M`'`#``#(!```/0(``'8#````````IP,``'X$``!U`@```````+,$``#``P``
MX````%$#```4`````````'0"``"]`@```````$T!```*`P``C@(``"@#```U
M!```(`(``*X#``"7`0``10$``'D$``!4`````````"`#`````````````!0$
M``#K`@``)P````````#^`P``W0(``$H`````````S0$``&<$``#,`P``````
M`"````!W`0``00$``)(!``!B`P`````````````%`P``HP(``$T"```5`@``
M$0(```````#*!`````````````"$````DP````@#``"^!````````$<!```T
M`P```````$P```#J`@``2@(```````#C`P``I0(``"8$```P`P``B@```.T"
M````````70(`````````````=P0```````#$`@```P$``&4$````````````
M`%L!``!I!```G`````($````````$@,``&D!``#?`P``2@0```P$``!K`P``
M0P,``)<#```<`P``QP,``,`"````````G@```"L#```"`0``W@```/8!``"R
M`@``FP(``$H!``!$`0``"````)$```!)!```>0(`````````````9P$``/<!
M````````5`0``#8#``!``P``.0````````!F````NP(``+<$```(`@``@P$`
M`,8$```U`@``6P```,L$```N````;@0``+\#``"\`@```````$T````W!```
MD0(``(0#``"``P``[@$``$````!S`@``FP$``.(!``"I`0`````````````%
M!```'P$``(H!``#(`@``3@$``#X"```K````&`(`````````````````````
M```8````VP,```````"``@``:`(``#($``!L`0``,````%8$```C`P``3@0`
M`$@$```&`@``F@0```````!O`0``S`(````````0`P```````(@```#O````
M`````*0$``"9`0``;@,``&0!``#\`@```````,D$``!E`@``Z`$``+(!```]
M`P``!@$````````P`0``'P(``*0````I`P``N0,```````![`@```````-L!
M````````Q@(```````!@`@``=`0``&<```#$`0``\@,``+0````B````````
M`*$#``!9`0````````<!``!M`P``5`,``/T"``!P!```A@,```````#+````
M``````````"?`@``B0```$\#``!"`0````````````#_`P``8`$``"X$``"W
M````C0(``*8$``!<````GP```(L$``!6`P``?P0```````"E`P``_P```.$!
M``"\`0``3`,`````````````Q0````````#L`P``:@$``/@#````````O@,`
M`&8$``!@````4`,``%4#``#]`P```````!D!``!+`0``P````*L#``#`!```
M#````"4#````````!@,``)(#````````6`(``-T```#K`P``)@(``)H"``#X
M````-P(``,<"```>`0``:@0``&($``##`P``*`(``.<````(`0``F`0``+4$
M``!&`P``%@(``"0$```<!`````````````!I````````````````````L`0`
M`!X#``!_````"P```+\!``"+````,`(`````````````%@$``(8```"U`P``
M`````*\"```E`@``$P(``*H$``#4`0``,0,```````!1`0``````````````
M````'@(``*<$```2````BP,``(8!``!@!```^P,``'(!````````P0```"0`
M``#L````G0```)H#````````)`,``$<$``"M````@0````````#X`@``L0(`
M`$L#```_`P````````````">`@```````$4"``#O`@``L0$``!0"````````
MU@$```T```"N!````````!4```"R`P``F0```$D"``"=`@````````````#0
M`@``KP```%(!````````5P0```````!_`0``P@```*`"``#,````````````
M``"H!````````#,!``!W`@``Y`$``*H`````````DP$``+$$``#*`0``#@(`
M`(\#``"4`0``L0,``)\#````````1`0``'@```#5`@``I@```)<"``""`P``
M;@(``&0"``#/`@``"0,``&("````````YP(```````"I`P``-@$``*`!````
M`````00``(X!```Q`@``&@0```0$``!E````<0$``'P````6!```WP(``-@!
M````````+@$``&P#````````?0$``-`!``"H`0``"@```-\`````````Y`,`
M`&\```"<`@``60,````````<````Y@,``%$$```N`@``6@,``",!``"N````
MA@(``*(#```K`0```````-D#````````D```````````````UP,``#T````=
M`````````#0```#-`@```````!,$``"T`0``?`,``#L$``"^`@``D0$`````
M````````CP0``(8$``!B`0```````"H$``"]`````````,4#``#"`@``$`(`
M```````9````9@(````!`````````````'\#``"/`0``7P$``,@````R````
M`````/$"``!2!```!P```'$$``!^`@``*@(``%P!```6`P``NP0``/,"````
M````&0,```````"2`@``>P$```````"S`0``%@```)H!``!L`@```````#D"
M``#5`P```````$,$````````>@$``$L```#"`P``6`$``,X!``!<`P``?0(`
M`#$`````````8P````````!\!```R0(``"4`````````800``!H#``!Q````
M:P0``,D#```Z`0``4@,````$``"X````%P$``!$#``"#`@```````%P$````
M````/@````X````_`0``;`0`````````````LP,``.$"``#<`P``````````
M``#4````+`0```````!X`0``?@$``$0#```<`0``30,``*T#``"%`0``.`0`
M`$$#`````````````*P#````````V`(``%0"``"=`P``!P0`````````````
MC0```#8"````````2`,```````"V`0``?`$````````F````#00``+($``#.
M`P``!P,``!L"```H`````````)D$```%`@``50(``$\```!#````E@0``(P"
M````````#`$``#@"```1!```"0````````!;`P``Q@$````````Z!```````
M````````````FP````````#5`0``^0(````````Y`P``"P$``.(#``!]`P``
M`````/,````K`@``X`(``"H````B`@``T@$```````"$`@```````(T$``"V
M!```B@0``+D``````````````%\"``"@````8P,``(````!T`````````-@`
M```G`P``+P````````"0!```0`0``+,"``"E`0``9`0```````"X`0``)P(`
M`#("``!'`@````````````"(!````````#\$``!3`0``J@,``*4```!K````
M:@(``$L"``"0`P``20$````````5`0``8P$``-T#``"A`@``&@```"(#````
M````10```+````"O`P``[0```#<#``#3`0``MP(``-P"``",`0``SP``````
M``!N````]@```($#``!.`@``/00``$($``!!`@``3`0``$D````3````=`$`
M`*L!``#U````W@$``!($``"5`@``$````)P!``"T!```E00`````````````
MG@$``!4$````````]`,```````!H`P``'P,``.L```!E`0``QP$```````"I
M!```@00``%8```#P`P```````*4$```,`@```````)0```"'````60(``'`!
M``##````C0$``+T!```7`P``V@(``$X#````````\@```%@```"V`@``````
M`$(`````````8@```"4!``"4`@``7P,``.@#``#Q````JP0``.T!````````
M40`````"```"`P``"@(```````!'`P```````&$```!7`0``1@0````````R
M`0``$P$``#`$``#+`@```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S
M*0`@*'1O9&%Y*0`@*'EE<W1E<F1A>2D`(&%T(``E9"UD87D@9F]R96-A<W0`
M)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:7,@<F5Q=6ER
M960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S
M.B`E<P`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S
M`"TM('-E;&5C="`M+0`R-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D
M:71O<@!!8F]U="XN+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U
M;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI
M;&0@4&5R;6ES<VEO;@!!9&0@179E;G0`061D($AE<F4Z`$%D9"!.97<@1W)O
M=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!E=F5N=`!!9&0@82!N
M97<@=7-E<CH`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=7-E<@!!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$%D9')E<W,`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F
M9VAA;FES=&%N`$%L87)M`$%L87)M($1A=&4`06QA<FT@4W!A;B`H;6EN=71E
M<RD`06QA<FT@5&EM90!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QL`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;"!D87D`06QL(&1A>2!E=F5N=`!!;&P@979E;G1S`$%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,
M;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5
M<V5R;F%M90!!;'1E<FYA=&4@=&5M<&QA=&5S`$%M97)I8V%N(%-A;6]A`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`
M06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N=&%R8W1I8V$`06YT:6=U82!A
M;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`
M07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7
M:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-
M4T-)22TX*0!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S:6$O4&%C:69I8R!2
M96=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%T`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!
M=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF
M='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@
M56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D
M`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`
M0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K
M97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/
M+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F5L87)U<P!"96QG:75M
M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R!3
M971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]S
M;FEA(&%N9"!(97)Z96=O=FEN80!";W1S=V%N80!";W5V970@27-L86YD`$)R
M87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A
M<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`
M0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-A;&T`
M0V%M8F]D:6$`0V%M97)O;VX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N
M;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M("(E<R(N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D
M+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#
M87!E(%9E<F1E`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`
M0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E
M=&%I;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAI;&4`
M0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAR:7-T;6%S
M($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQI
M8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-L;W5D<P!#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]M
M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE
M`$-O;6]R;W,`0V]M<&%N>0!#;VYD:71I;VYS`$-O;F9I9W5R92`E<P!#;VYF
M:7)M(%!A<W-W;W)D`$-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S/P!#;VYG
M;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE
M8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"X`0V]O:R!)<VQA;F1S`$-O<'D@<V5L96-T:6]N
M`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC
M(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D("5S+@!#;W5L
M9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!S97)V97(G
M<R!C87!A8FEL:71I97,`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN`$-O=6YT<GD`0W)E871E(&$@3F5W($5V96YT`$-R96%T
M92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D
M(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N=`!#=7)R96YT(%1I;64`0W5R
M<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL
M90!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%I;'DZ(%)E8W5R<R!E=F5R
M>0!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1A>2AS
M*0!$96-E;6)E<@!$96-R96%S92!);F1E;G0`1&5F875L="!)9&5N=&ET>0!$
M96QE=&4`1&5L971E("5S`$1E;&5T92!%=F5N=`!$96QE=&4@1W)O=7``1&5L
M971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E(&%N
M9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R(&%L;"!O8V-U<F5N8V5S/P!$
M96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S
M8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO
M=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E
M8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R
M('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)M870`1&II8F]U
M=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O
M;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P
M(&1O=VX@;&ES=`!$=64Z("5S`$1U<F%T:6]N`$4M36%I;`!%4E(`16-U861O
M<@!%9&ET`$5D:70@)7,`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R
M;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL(&%D9')E<W-E<R!M=7-T
M(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP
M='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;F0@1&%T90!%;F0@3VX`16YD
M(%1I;64`16YD('EE87(`16YL87)G92!%9&ET;W(`17%U871O<FEA;"!'=6EN
M96$`17)I=')E80!%<G)O<@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S
M`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA
M;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&ER871I;VX@1&%T90!%
M>'!O;F5N=`!%>'!O<G0`17AP;W)T($-A;&5N9&%R`$944"!U<&QO860@;V8@
M<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE
M9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y
M`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9I:FD`1FEL92!#;W5N=#H@)7,@
M9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.
M86UE`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&
M:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R
M871I;P!&;&EP`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A
M<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R;7,`1F]R
M='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R=6US`$9O<G=A<F1S`$9R
M`$9R86YC90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)I9&%Y
M`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U
M;&P@3F%M90!&=71U<F4`1V%B;VX`1V%M8FEA`$=A;64`1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;@!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=I=F5N($YA;64`1V\`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E
M`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!
M9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'
M<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S
M="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`
M1W5Y86YA`$A434P`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA
M:71I`$AA<V@M06QG;W)I=&AM`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O
M9B!T:&4@9FEL93H`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R:7IO;G1A;"!2=6QE`$AO=7(H<RD`2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5N
M9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$EC
M96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T+T5X<&]R="!#86QE;F1A
M<@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8W)E87-E($EN9&5N=`!);F1I80!)
M;F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN
M<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T90!);G-E<G0@;65S<V%G97,`26YS97)T+TUO9&EF>2!);6%G90!)
M;G-E<G0O36]D:69Y($QI;FL`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO
M;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`
M26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R
M;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED('-O
M=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-R
M865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N
M`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU
M;F4`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*
M=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@
M0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`
M2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`2V5Y=V]R9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A
M;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,86YG=6%G90!,86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!1=6%R
M=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87-T('=E96L`3&%T=FEA
M`$QA>6]U=`!,96)A;F]N`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*
M86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EM:70@=&AE('1I;64@<W!A;B!T
M;R!E>'!O<G0Z`$QI;FL`3&EN:W,`3&ES="`M('5S97(@8V%N('-E92!T:&4@
M9F]L9&5R`$QI<W0@2&5L<"!4;W!I8W,`3&ES="U!<F-H:79E`$QI<W0M2&5L
M<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E
M`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M3&ET97)A='5R90!,:71H=6%N:6$`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@
M5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QU>&5M8F]U<F<`34T`
M34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U3
M1P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8`36%D86=A<V-A<@!-86EL`$UA:6P@061M:6X`36%L87=I`$UA;&%Y
M<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%R8V@`36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-
M871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&UE<W-A
M9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-
M87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87D`36%Y
M;W1T90!-965T:6YG`$UE;6)E<G,`365N=2!M;V1E.@!-97-S86=E`$UE<W-A
M9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R
M=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER
M960N`$UE<W-A9V4@='EP90!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE
M>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI;64@5'EP
M90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO
M=7)S.B``36EN=71E*',I`$UI<G)O<@!-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S
M:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&EF:65D($1A=&4`
M36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9&%Y`$UO
M;F=O;&EA`$UO;G1H`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N=&AL>3H@
M4F5C=7)S(&5V97)Y`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!
M8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L
M($D@1&\@3D]4($%G<F5E`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N
M9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R
M`$YE=R!#86QE9&]N:6$`3F5W($5V96YT`$YE=R!-;V]N`$YE=R!5<V5R;F%M
M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B;&%N:RD`
M3F5W<P!.97AT($UO;G1H`$YE>'0@9&%Y`$YE>'0@;W!T:6]N<P!.97AT('=E
M96L`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@96YD(&1A=&4`3F\@9FEL92!U
M<&QO861E9`!.;R!L;V-A=&EO;B!I<R!S970N`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!E
M;F1I;F<@<VEG;G5P<RX`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V
M86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO;F4`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA
M;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N
M9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R
M>0!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W9E;6)E<@!.=6UB97(`3G5M8F5R
M(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O
M=W,`3TL`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9I8V4`3VUA
M;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T
M`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`
M3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L
M(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`
M4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`
M4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087-S=V]R9`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!0871T97)N`%!E;F1I;F<@4VEG;G5P<SH`4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E
M;G0_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R
M<V]N86P@26YF;W)M871I;VX`4&5R=0!0:&EL:7!P:6YE<P!0:&]N90!0:&]T
M;W,`4&ET8V%I<FX`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;VQA
M;F0`4&]L;',`4&]R='5G86P`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEO=7,@9&%Y`%!R979I;W5S
M(&]P=&EO;G,`4')I=F%T92!+97D`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J
M96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I
M=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C
M97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%)302!0=6)L:6,@2V5Y("@E
M9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2871I;P!296%D`%)E860@;65S<V%G
M97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5C=7(@56YT:6P`4F5C=7)R96YC92!$871A`%)E8W5R<F5N
M8V4@16YD($1A=&4`4F5C=7)R96YC92!);G1E<G9A;`!296-U<G)E;F-E(%1Y
M<&4`4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`
M4F5C=7)S('EE87)L>0!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H
M(%!O<G1A;"!6:65W.@!296=E>`!296UA<FMS`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I
M<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@
M=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5S970`4F5S970@=&\@1&5F
M875L=',`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)O;&4`
M4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2
M=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A
M<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN
M9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4V$`4V%I;G0@2&5L96YA`%-A:6YT
M($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD
M($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A
M;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N
M9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%T=7)D87D`4V%U9&D@
M07)A8FEA`%-A=F4@)7,`4V%V92!!<R!.97<`4V%V92!%=F5N=`!3879E($]P
M=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+@!396QE8W0@82!G<F]U<"!T;R!A9&0`
M4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U
M<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T
M(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF
M9F5R96YT('9I97=S(&%N9"!C:&]O<V4@9&5F875L="!V:65W+@!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L
M96-T('1H92!F:7)S="!W965K9&%Y.@!396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@=&AE('1I;64@
M<W!A;B!T;R!S:&]W.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N96=A;`!396YS;W(Z
M(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB
M97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R
M>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\`4VAO=P!3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_`%-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O;FQY(&5V
M96YT<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/P!3:&]W('!I8VME<@!3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:')I;FL`4VEE<G)A($QE;VYE
M`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P
M;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3
M;F]W(&1E<'1H.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]R="!O<F1E
M<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W)I($QA;FMA`%-T
M86YD87)D`%-T87)T($1A=&4`4W1A<G0@3VX`4W1A<G0@5&EM90!3=&%R="!Y
M96%R`%-T871E(&]R(%!R;W9I;F-E`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!
M9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W4`4W5B:F5C=`!3
M=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY('=R;W1E("5S
M`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YD87D`4W5N<FES
M90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U
M<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A
M;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WER
M:6%N($%R86(@4F5P=6)L:6,`5%-6(&9I;&4`5&%I=V%N`%1A:7=A;BP@4')O
M=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP
M(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E
M;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1H`%1H86D@
M*%1)4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y
M<W1E;2X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE
M($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL
M>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&5N
M9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A<G0@9&%T92X`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H
M92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@
M:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A
M=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=E<F4@;F\@979E;G1S
M('1O(&5X<&]R="X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T
M('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E
M<RX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5R<V1A>0!4:6UE`%1I;64@5')A
M8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`
M5&ET;&4`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C
M;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA
M=0!4;VYG80!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`
M5'5E<V1A>0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4
M=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4
M>7!E`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),.@!59V%N
M9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E
M=&%I;',`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S
M="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET
M960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@
M3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@=7-E<FYA
M;64@;W(@<&%S<W=O<F0N`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`
M57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BX`57)U9W5A>0!5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($EN=&5R9F%C
M90!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<FYA
M;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`
M57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A
M=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y
M`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686YU871U`%9A
M<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!6
M97)S:6]N($-O;G1R;VP`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6
M:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6
M:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R
M96-A<W0`5V5B`%=E8B!3:71E`%=E9&YE<V1A>0!7965K`%=E96L@)60`5V5E
M:RAS*0!7965K;'D`5V5E:VQY.B!296-U<G,@979E<GD`5V5L8V]M90!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E
M<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_`%=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S
M(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S/P!7:&%T('1I
M;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R
M92!A<F4@;F\@96%R;&EE<B!E=F5N=',_`%=I;F0@<W!E960@:6X@:VYO=',`
M5VEN9#H`5VEN9#H@`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=O<FL@5V5E
M:P!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY
M`%EE87)L>3H@4F5C=7)S(&5V97)Y`%EE;65N`%EE<RP@22!!9W)E90!9;W4@
M87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I
M=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U
M(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U
M<B!%;6%I;"!!9&1R97-S`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`
M66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA
M:7)E`%IA;6)I80!::6UB86)W90!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S
M(&]F("5S70!D87D`9&%Y*',I`&1A>7,`9FEL90!F<F]M('1H92`E<R`H)7,I
M(&%T("5S("5S`&@Z`&EM;65D:6%T90!M;VYT:"AS*0!N86UE`&YO="!I;7!L
M96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&]N('1H92!S86UE(&1A=&4`
M;VX@=&AE('-A;64@=V5E:V1A>0!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE
M<BYC;VT`=V5E:P!W965K*',I(&]N.@!W965K<P!Y96%R*',I`%!R;VIE8W0M
M260M5F5R<VEO;CH@2W)O;F]L:71H(#(N,"UC=G,*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R
M+3`U+3(V(#$P.C4U*S`X,#`*3&%S="U4<F%N<VQA=&]R.B!::&%N9R!";R`\
M8F]O>FAA;F=`<V1B+F%C+F-N/@I,86YG=6%G92U496%M.B!::&%N9R!";R`\
M8F]O>FAA;F=`<V1B+F%C+F-N/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]1T(R,S$R"D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@S.S'L"D`("B_[+W=O/P@)7,I
M`"`HO?',["D`("C7\LSL*0#3V@#7[KW\("5D(,SLQOC/\]2DL:@`)7,@+2"Q
MN,W\PKP`)7,@UKC.Q@`E<R!+0@`E<R#.K+NDLMG7]R`M(,BWR,\`)7,@UZ*R
MX0`E<R#-K-+BS^[$OP`E<R#2T;3FU-H`)7,@U-H@)7,@)7,`SL2\_B`E<R#2
MT;6\R.O-ZK/)`+'8T.C2JB`E<P`E<R"WU@#5TK*[M;T@)7,N`"`E<R"UO2`E
M<R"YLB`E<P`E<SH@)7,`+"#5\[?G("5S("5S`"RQY+NOP;^TTR`E<R"UO2`E
M<P`M+2#1H=3Q("TM`#(T(-"ARK'6Q@"TR\?XO^FQV-#KTJK6N+:HROV^W;_B
MM_[.\;;++@"WHLGZP<O2N[CVT<_6V+7$M.W.\P#3^[S3P]S3RKS^++NYT.C2
MJM/0TKNX]B!01U`@N:N_JL/<U+\N`-/[T>G6I-+1QZG#^[7$T\J\_BR[N=#H
MTJK3T-*[N/8@4$=0(+FKOZK#W-2_+@#3^[WBP]S3RKS^++NYT.C2JM/0TKNX
M]KFKOZH@4$=0(,/<U+\LR[W#W"!01U`@P]S4ORS2U+RPO]K![BX`T_O6M-#0
MT\J\_L>IP_LLN[G0Z-*JT]#2N[CVN:N_JB!01U`@P]S4ORS+O</<(%!'4"##
MW-2_+-+4O+"_VL'N+@#3^[WBP]S3RKS^++NYT.C2JM/0TKNX]KFKOZH@4TU)
M344@P]S4ORS+O</<(%--24U%(,/<U+\LTM2\L+_:P>XN`-/[UK30T-/*O/['
MJ</[++NYT.C2JM/0TKNX]KFKOZH@4R]-24U%(,/<U+\LR[W#W"!3+TU)344@
MP]S4ORS2U+RPO]K![BX`T_N\T\/<T\J\_BR[N=#HTJK3T-*[N/8@4TU)344@
MN:N_JL/<U+\N`$%-+U!-`$%022"QX+K%`+G8T]K5XKCVL>"\K<;W`+G8T]HN
M+BX`R*C/WK*[U^,LSMZWJ+VHP:(@5D93(,2_PKPN`,BHS]ZRN]?C+,[>MZB]
MJ,&B(%9&4R#.Q+S^+@#5R[K%TM&VL[WA+@"]X=7*`-#"U/;/PKRVU^D`T,+4
M]L_"O+;(J,_>`-#"U/;*PKS^`-3:M,O0PM3VH[H`T,+4]M/#NZ?7Z0#0PM3V
MR*C/W@#0PM3VTKO*PKS^`-#"U/;2N[CVT\.[ISH`T,+4]M*[N/:SR=2Q.@#0
MPM3VMM0`T,+4]B`E<R#.JB!-;WII;&QA(%-I9&5B87(@LLNUI0#0PM3VT\.[
MIP#0PM3VT\.[I[7$N:;$W+6QQ["QN[G8L=4N`+78UK<`L\G.JKG<P.W4L2`M
M(,ZJQN3+_-/#NZ?%Y-;#R*C/W@"YW,#M`+GCN.:YW,#M`+"BN+NZN0"^K\J^
M`+ZORK[(U<;:`+ZORKZ\Y+CT("BWUM;3*0"^K\J^RK&\Y`"PHK;[L,W$X=''
M`+"BMON\L,#[T<<`L?##^P#+^=/0`,OYT]#2T='IUJ2UQ-/#NZ<`R_G3T-/#
MNZ?7Z0#+^=/0R*C/W@#5^\C5`-7[R-70U,K"O/X`R_G3T,K"O/X`U,K0[;;@
MN/:UY]?3T\J\_K78UK<`TM&TYM3:`+'DN/P@24U34""UQ\*\`+'DN/P@24U3
M4"##W,+K`+'DN/P@24U34"#3P[NG`+'DN/S$H[#F`,/`RO3(^,2FT<<`TKNX
M]K*[NL^WJ+7$UK6QN\JYT\,N`+"RM<"V^P"PLKCGP*T`L+*YY\"M`,3DP_NT
M^L#M`,3/O*O6W@"PLLSAN<^\L+#-MONRO+3O`-.FT\.SS-#R`-.FT\.SS-#R
MTM&^S=#W`-.FT\.UO<OYT]#/PKRVN;+/[0#%^M>\`,O$U,(`L*+`K;*NSL0@
M*%=I;F1O=W,M,3(U-BD`T;G+]<[$O/ZT\]"A`-&YR_7.Q+S^P_NSQ@#$^LBW
MMJC2JLF^L_T@)7,@M<37HK+APO`@/P"PHKCYS:(`T<?#P,3AT<<`T<?#P,3A
MT<?.Q"`H05)-4T-)22TX*0"PHL*SL,T`L*+)K<O)R+JUN@#1Q];>+\RKQKW1
M\[78Q_@`UK30T,ZLNZ2RV=?WQ[#/U,J^R+?(S[;4N["_\C\`U-H`RM3-O,F^
ML_W2N[CVLKNTYM3:M<33P[NGU^DN`,K4S;S)OK/]TKNX]K*[M.;4VK7$R*C/
MWBX`RM3-O+'@O*W2N[CVLKNTYM3:M<33P[NGU^DN`,K4S;RQX+RMTKNX]K*[
MM.;4VK7$N;+/[2X`RO30U`"PR]3"`+#$M//`^]''`+#"M=C`^P!!=71H7V-R
M>7-Q;#H@U=*RN[6]R_G0Z-*JM<0@:6UA<"#`J=6YU^F\_BX`075T:%]C>7)U
M<SH@M_[.\;;+LJ+.M,SAN:FXP\_NUJ>SUBX`075T:%]C<GEU<SH@U=*RN[6]
MR_G0Z-*JM<0@:6UA<"#`J=6YU^F\_BX`075T:%]F='`Z(-72LKNUO<OYT.C2
MJK7$($944"#`J=6YU^F\_B['Z];8T,*QX-+K(%!(4""RHL?2O-/(ZR`M+65N
M86)L92UF='`@T:'/[BS`_<CG(&-O;F9I9W5R92`M+65N86)L92UF='``075T
M:%]I;6%P.B#5TK*[M;W+^=#HTJJUQ"!)34%0(,"IU;G7Z;S^+@!!=71H7VMR
M8C4Z(-72LKNUO<OYT.C2JK7$(&MR8C4@P*G5N=?IO/XN`$%U=&A?;&1A<#H@
MU=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\_BX`075T:%]L9&%P.B#.WK>H
MT,+4]M/#NZ<@)7,N(+?^SO'&][O8TZ8Z`$%U=&A?;&1A<#H@SMZWJ,F^L_W3
MP[NG("5S`$%U=&A?;&1A<#H@SMZWJ+C\T,+3P[NG("5S`$%U=&A?;6-A;#H@
MU=*RN[6]R_G0Z-*JM<0@34-!3"#`J=6YU^F\_BX`075T:%]S;6)A=71H.B#5
MTK*[M;W+^=#HTJJUQ"!S;6)A=71H(,"IU;G7Z;S^+@#1Z=:DRJ>PW"X`T>G6
MI,JGL-PN("5S`%)!1$E54R#1Z=:DM.W.\RX`1E10(-'IUJ2T[<[S+@"_R=/#
MM<37UK;..@"PHLC[L-V]K@"QL[ZPT=7)JP!K97)B97)O<R##W,+KM.W.\RX`
M:V5R8F5R;W,@T\.[I\/[M.W.\RX`L,VY_L+MR+JUN@"PS<'6`+*HPMZUQ+JC
MSL0@*$E33RTX.#4Y+3$S*0##S[S3P*VY^@"PS;#-MN#+N0"PU[;MPM[+N0"Q
MR,#[RK$`LJ[`^]?(`+&TQ/X`L-G$O;3SR+JUN@"RN[6D`,GZR-4`Q_B_Z<7D
MUL,`Q_B_Z<#@T,T`M-;,Y0"RH\#[SJS1QP#*Z<>I`+*HR[G$X=''NLVZVLC[
MN.?.K,3'`+*IM,3-W\3)`+*HSJS,V+6Z`+#-SO<`TZ+*]-.AMLC1\\'LM=@`
MSL3`LP"QH[S3P/O1QP#/[L2_M_NZQ0"RO+RJQ,FWJ,OW`+*\PJ&USP#$VLC=
MN=S`[<^US;,`0U)#`$-23""WUK*\M>,`P>.\MK?G`+SMQM+5KP"_IL+SPJ$`
MSMZWJ,&JN_K6P2!)34%0(+?^SO'&]SH@)7,`O-/$P[3S`,BAS_L`R*'/^\[*
MS.*QJ+CF`,[>MZC)OK/]SL2\_B`B)7,B+@#.WK>HR;ZS_<2_PKP@(B5S(BX`
MSMZWJ-;8U^FAH\OYS.&YJ;7$O,?"O,K]Q+_3Z\_(Q[#+^;&CM.:UQ,K]OMVR
MN[?[+@#.WK>HM*O+S=#%SZ*UO=:XMJBUQ+K%PNLN`+?PM<.]QP#`X+'P`+^J
MPOS(NK6Z`-+&MJ^UY[NP`,C[MOO,V,[$("A)4T\M.#@U.2TQ-"D`UM"WQ[FR
MNLVY^@#6T,6W("A)4T\M.#@U.2TR*0#&OM:DS[B]V@#&OM:DLM_"U`#5I[7#
M`+C\N,0`UL?`^P#6T+GZ`+SRS.76T,[$("A'0C(S,3(I`+>QS.76T,[$("A"
M:6<U*0#1H=3QP]S"ZP#1H=3QTKNX]M/#NZ?#^P#(U<;:S]3*OK>]RKTZ`,JE
MM:ZUN@#5TK*[M;T@)7,@M<3`X+'PMJC2Y2X`L+3*\['JO/R\S-#X`+G8L=6T
ML+_:`-3&P;\`O\:_QLNYR+JUN@"XY\+7L<C1QP#1U<FK`+7WR:O%S`"_J,VH
M`,/\P>X`P_S![KW%L;X`QL#"VP#-J-/#P_L`O\;$IL+>`+FKR[X`S/6\_@#%
MY-;#("5S`,BWR,_#W,+K`,BWMJC)OK/]RL*\_C\`N-6Y^P"XU;G[N;*ZS;GZ
M`,&LO=/*I[#<.B``P:R]T];!N:N_JL/<U+^W_L[QQO?*L=3BOMR^^"X@U*W2
M\CH@)7,@*"5S*0#!K+W3UL$@1E10(,[$O/ZW_L[QQO?*I[#<+@"_XK_+R+JU
MN@"XM-;&T:'4\0"XY\NYM._`Z+S3`+_&S-BUS\W?`,[>MZC2U"!01U`@O-/#
MW-/*O/XN`,[>MZC.JB!01U`@UK30T-/*O/['J</[+@#.WK>HTM0@4R]-24U%
M(+S3P]S3RKS^+@#.WK>HSJH@4R]-24U%(-/*O/['J</[+@#.WK>HL/.VJ"!,
M1$%0(+?^SO'&]P#.WK>HO>+#W"!01U`@ROV^W2X`SMZWJ+WBP]P@4R]-24U%
M(,K]OMTN`,[>MZB^]K:HRM6\_LC+M<2UY]?3T\J\_K78UK<N`,[>MZC7U,/<
MU+^W_L[QQO?(H;7#N:N_JL/<U+\N`,[>MZBT\K^JSJR[I+FDU_?$H[_I("5S
M`,[>MZBVP<BA("5S+@#.WK>HML'(H;3FR*&_V-;&L>TH04-,*0#.WK>HML'(
MH;?^SO'&][7$S^"YV,S8T-0`SMZWJ+&CM.8@)7,@M<3%Y-;#+@#.WK>HLNG5
MTB!,1$%0(""W_L[QQO<N`-72LKNUO2!-;WII;&QA(%-I9&5B87(N(,?KR+?(
MSR!S:61E8F%R(,K'M_&T\K^J+@"Y^KS2`+VHP:+2N]#"RL*\_@"]J,&BU]/.
MQ+S^O-``O:C!HM7?M<3(J,_>`-#%T\._J+K%PNL`O\O"WK78T<<`N<6PS0#$
MO\>P`+6QQ[#*L;SD`+6QQ[#,[,;X`+6QQ[#7M+_V.B``M;''L+?GN/$`O/3'
MT-&AU/$`R/O&UL*WR[D`SO?`[[;[SL0@*$M/23@M4BD`SO?`[[;[SL0@*%=I
M;F1O=W,M,3(U,2D`SO?`[[;[SL0OSMJ_R\"\SL0@*$M/23@M52D`O=V_R[FR
MNLVY^@#(U0##O\C5`,C5.B##OP#(U<;:`,K5M;W(U<;:`-&AU/'(U<;:`,SL
M`,SL`,JNMO[4P@"\]<G9R_7%Q0#$K,C/R>VWW<JVL?``R;ZS_0#)OK/]("5S
M`,F^L_W*PKS^`,F^L_W3P[NGU^D`R;ZS_<BHS]X`R;ZS_:&BQ^6_U=/*O/X`
MM,O)OK/]MJ_7][VKS-?3P[6].KWVQ+_'L,K"O/XLQ+_'L+RPTM2Z\\K"O/XL
MN_++^=/0`+7=R\W*L;SD`+6DPO,`SLK,XL/HRO8`P^C*]@#/N+W:("C'Z[+.
MO[P@2&]R9&4@O,?"O,[$O/XI.@#/N+W:Q^NRSK^\S[7-L[G<P.VUQ\*\+@#1
MT+>B`,*VM>/.PK;(`-?NNO/2N]"ARK&UQ,*VM>/.PK;(.B``PK:UX\["ML@Z
M(`"TT]?SUL'3T@"TT]/2UL'7\P#$O\*\`-+4(#(T(-"ARK'6QL_4RKX_`,_4
MRK[1H<_N`,_4RKZX\<J]`+RJLKS,X0"RN\F^L_T`LKO2JM:QO=.TYLBA(&UA
M:6YT96YA;F-E+G!H<`"UVM*[L<J\Q\*\RL>W\;#\NJS7UK;.P_NSQC\@R.>Y
M^\K'Q^O1H=3Q+@"VX,/7Q.&\TP"VX,/7Q.&\T[FRNLVY^@#/PM38`,_"U-@@
M)7,`S\+4V,GZL\FUQ,7DUL/.Q+S^SJH@4$A0(+/,T/(N`,_"P*VRR[6E`,JQ
MQMHZ("5S`,JQQMH`M>?7T]/*O/X`M.W.\P"V\KG/MN"V^P"QX+RM`+'@O*T@
M)7,`L>"\K<?XO^D`L>"\K=/#NZ?7Z0"QX+RMR*C/W@"QX+RMR*C/W@"QX+RM
M("5S(+7$R*C/W@"QX+RMT:'/[@"QX+RM("5S(+7$R*C/W@"PH[RP`,CXMOO-
MW[;@`+7GU]/3RKS^`+7GU]/3RKS^M=C6M['8T.O.Q[K/+@"UY]?3T\J\_LBW
MR,\`L>W'Z;?[NL4`O]6PU]#%O/XN`+_5L->]X;G[+@"]X<KXR-7&V@"]X<KX
MT]H`O>'*^,JQO.0`Q.JUUP"WQ;3SL>"\K<;W`+/@M<"\N,3:T<<`MO+!HLS8
MP._1QP"T[<[S`+"NR;/$X=''`+"CR/NV[;'(T<<`Q;?6W@##OR`Q-2"WUM;3
M`,._(#,P(,/KUM,`P[\@-2"WUM;3`,._M,ZUQ\*\`,._(#,P(+?6UM,`P[\@
M,2"WUM;3`+>VP/W6M3H`UK30T`#5N;^J`+6]QMK(U0"]XLNUU+$`M;RS]@"U
MO+/VT-"SS,C5P/H`1E10(,G/M*O%Y-;#+@"VP<BAQJNZP\7DUL/*I[#<`,[>
MMZC!K+W3($Q$05`@M_[.\<;W+@#.WK>HP:R]TR!334(@M_[.\<;W+@"XM-;&
MRJ>PW-?4("(E<R(N`+BTUL;*I[#<M;T@(B5S(BX`SMZWJ+VHP:+2N[CVT,*U
MQ"!305-,(,&LO=,N`-+&MJ^UO2`B)7,BRJ>PW"X`MZC`O+_+N*/(NK6Z("C"
M[;;[SJS$R<NYR+JUNBD`MZC"WLBZM;H`M*O5Y@"V_M3"`+C0OO7/\<K'`+C0
MOO7/\<K'.B``[+.\PP#.Q+S^ROW$OSH@)7,@N/;.Q+S^`,[$O/[*_<2_.B`E
M<R#.Q+S^`,[$O/ZYW,#MQO<`SL2\_L/[L\8`SL2\_LG/M*L`SL2\_LG/M*NY
MIL3<SK2QN]:GL]8N`+G]PLO&]P"WTL"\`,G/L.O4P@#)S\_2U,(`N<RVJ+'(
MP/T`MZW7J@#$O\*\("5S(+*[M.;4V@#7UM#-T=7)JP#4I+&HS.S*_2`HU*2Q
MJ,SLROVP_,"HL-?,[-+4O+#2N;SDM<3*_;[=.\CGN?O4I+&HS.S*_;W/LZ2]
MJ]6\T\.QR+W/O^VW^;7$L.;#YBD`M+#,Y0#+X\/\`,OCP_S`X-#-`,OCP_P`
MPMO,LP#7U+:OUZK0Q0#0Q\;:SN4`MZBY^@"WJ,KTN>?1Q\3'`+>HRO2RH\#[
MQ.'.]]''`-#'QMK.Y0"\Q+S^R,L`M-,`S>K5^\/HRO8`POK4P@#(J\/[`,2_
MQ["\L-+4NO,`O-/%[@"XU+'(T<<`T\[/MP"R^LGZ("5S(+7$S[7-L\7DUL,`
MN/'"L[RJT<<`M<*Y^@#ER,3)`-:QLKS"WLW3`,/[`->JM;T`1V]O9VQE(,O1
MR_<`N]*VR`#/H\"P`,^CP+#.Q"`H25-/+3@X-3DM-RD`N/'!ZL"\`+CQP=;$
MR;3O`-/#NZ?7Z;G<P.T`T\.[I]?IP_NSQK*[M<._U;#7`-/#NZ?7Z0"YS[7"
MPM[&U;6Z`+G8M;H`SJ.UV,+MP*T`N/&V]\[WM;H`M\._S<BHS]X`M\._S<'T
MT=0`O+C$VM''`+RXQ-K1Q['(R=RYLKK-N?H`N>?1Q\3'`$A434P`U=*RN[6]
M($A45%`@T>G6I"X`NJ.UV`#4T[35+<OCMZ@`L>W-MP"ZU;7"NLW"]+6QP,W(
MNK6Z`,^CLJ[`M,[$("A)4T\M.#@U.2TX+4DI`+#OUOH`L>"\K<;WRKG3P[#O
MUOH`L._6^@#5XL#ORL?.Q+S^M<2_JLJ\.@#H\[79N-0`RM?2LP#*U]*SM=C6
MMP#*U]*SM>>[L`"ZZ;:\P*W+N0#6T+GZS^.XVP!(;W)D90#+KL:]S]\`RK$`
MU]:VSLK]Q+^YLKS&/P#*JK;(`,JJML@Z(`#0V='`P/L`24U!4"#3RL_DO:C!
MHLJGL-PZ("5S`$E-05`@T\K/Y,F^L_W*I[#<.B`E<P!)34%0(-/*S^2TQ<7,
MQ>36P[VHP:+*I[#<.B`E<P!)4""UV-:WSMZWJ,JYT\,N`$E0(+78UK>RHK*[
MU-H@0TE$4B"UQ+W3RMS'^+_IUM`N`+'YM;H`UKO3T,V\L>H`S;RQZKRPSL37
MU@#)S[2KS;S&K`#-O,:L`+OCR.LL(+*]UN@@)60`M;S(ZR^UO+/VT-"SS,C5
MP/H`N^/(Z]?6MLXZ("5S`+OCR.O7UK;..@#*Y,CKLKO5_<BWM<37]]/#PNLN
M`-3VO-/+]<7%`-.AML@`N/:Q\-/#NZ<`TZ&VR,3ASO?1QP#0Q<^B`-#%SZ(`
MLN7(Z['MN/$`LN7(Z\WXPN?!K+W3`++ER.N_R<SFM/K$H[#F`++ER.O3RKS^
M`++ER.LOL>2X_,V\QJP`LN7(ZR^QY+C\S?C"Y\&LO=,`U?O*_0#5^\K]P=``
MSM[0I[7$(%5$2"C3P[NGROV^W;'MS;<I+@#.WM"GM<33IM/#L\S0\BX`SM[0
MI[7$Q?JTSKK%PNLN`,SAO;NUQ,K]OMW.WM"G+@#.WM"GM<3$O['JUZ'6MP"R
MN[K/MZBUQ,[$O/ZX\<J]`,[>T*>UQ"!M<V=?='EP92X`SM[0I[7$N_+5TK*[
MM;T@87!I7VED+@#.WM"GM<2[\M72LKNUO;+.ROTN`+*[NL^WJ+7$N+C(J,_>
M+@#.WM"GM<3-J-&VT*W2Z2X`SM[0I[7$P+34M->AUK<N`,[>T*>UQ,WRT\/"
MZ\K]OMTN`-+!P,K2P<NYP+RYLKK-N?H`TL'`K;_+`+"NMOO`O`#"_+6Z`-+4
MR:O!T`#'J;>BU=\`T+',Y0#2XK3SP/L`T<#"\KS3`-*[U,(`2F%P86X@*,C5
ML;XI`,C5SL0@*$E33RTR,#(R+4I0*0#4\\[WM;H`U+RUJ0#&W]3"`,'YU,(`
MUL/6T`#7\]/2MM3&ZP"_O]?SMM3&ZP"_O]/2MM3&ZP"Y_LCXO\O+N<RY`+&C
MP?34K='Y(#\`O\_$X=''`$ME<F)E<F]S(,C/UJ2T[<[S+@##W-2_O:C!H@##
MW-2_S-C5]P##W-2_LZ2VR`##W-2_P.#0S0##W-2_T^^WJ`"UL<>PM<2YJ[^J
MP]S4O[?^SO'&]];0+-+1OJVTYM3:Q/JUQ,/<U+\N`+G8O/RTR@"[^<#OL,W+
MN;FRNLVY^@"SK\_*`+JKN?H`NJO.Q"`H155#+4M2*0"_QLW^S-@`O*JV^[RJ
MR[G,N0#3[]'4`,#/SLX`S\*PZ]3"`,_"S]+4P@#)S[3.N/S0PCH`R<_2N[3.
MM<?"O#H@)7,`R<_2N[3.M<?"O#H@)7,@U]0@)7,`R<_2N[3.M<?"O#H@M=K2
MN[3.M<?"O`#)S];<`,"MS='.K-''`+#FP^;%Y-;#`,#HL,W$VP#`L\OWS=``
MP/NQR,#OT<<`P/NQR-''`,'0UJ>VV,J_M<<`S][6QK6\L_;*L;SDO.2X]#H`
MP:R]TP#!K+W3`,'0L_8@+2#3P[NGO\G2U+^TM;W5XKCVSL2\_KS0`,'0L_;+
MM</WL>K,X@#,UL+;T\.[I]?I+<[$O/ZY\0#,UL+;T\.[I]?I+<?SUOH`S-;"
MV]/#NZ?7Z2W*MK'PNL7"ZP#,UL+;T\.[I]?I+=.UT]#5WP#,UL+;T\.[I]?I
M+;S$O/[(RP#,UL+;T\.[I]?I+;:IU,0`S-;"V]/#NZ?7Z2W(H<_[MJG4Q`#!
MT+/VT\.[I[7$N:;$W+&[N=BQU0#.Q-&G`,&BS-7-\`"UL;78RK&\Y#H@`+78
MQ_C3Z\JQO.0`M=BUXP"UQ\*\`->BS_H`M<?"O`"UQ\*\RJ>PW"P@Q^N\[++I
MQ/JUQ-/#NZ?#^[K-P]S"ZRP@R+NZ\];8RM0N`+7'PKS*I[#<+@#"K,FML:0`
MU,(`P[_(U=#%SZ(`35,M5$Y%1B"XO;S3SL2\_M;0P[O3T,K]OMTN`$U31P#6
MT+GZL,3#Q0#"[<;DMMFYLKK-N?H`PNVT[[S3R[F\T[6Z`-/*O/X`T\J\_KG<
MP.T`PNW`K<W^`,+MP+3.]]''`,+MMONT^K?R`,+MP/L`PNVV^LO[`,C]U,(`
ML>J\Q[/)(+^TN?TOSK2_M+G]`+'JO,>SR<;DR_RUQ,JVL?`@*,#]R.<N(-;8
MTJHOTM&[V+BT*0#"[<G<MOO(NK6Z`,+MS.'$X;_+M;H`U?W4VL:EQ>37UK;.
M`,.KP._+_L3AT<<`PZO`[\?SR[D`N+V\_LK]Q+_2T;.LL_:]T\K<R<_/WBX`
MU^Z]_"`R-"#0H<JQM<37[KC?SL*VR#H@`-?NO?P@-B#0H<JQM<37[KC?SL*V
MR#H@`+W3RMS7[K3SLZ2VR`#,[`#"[=2\S-C(NK6Z`+OATND`L\G4L0#1H;6E
MQ*/*O3H`T\J\_@#3RKS^T>G6I-+1S>JSR2RUJ\K'T\.[I[7$QZG#^\BTSMZW
MJ,VHN?W1Z=:D+@#0Q<^BTM&Y_<;:+@#0Q<^BP.#0S0!-971A<B#'^+_ISMZW
MJ,JYT\,N`$UE=&%R(,?XO^G.WK>HRKG3PRX@S[B]VL?KLLZ_O,^US;.YW,#M
MM<?"O"X`M[VWJ`"YJ];&`,2KSO>XYP##W+_+PM[$X<[WT<?!JK#NN?H`36EM
M92#`X-#-`-?NO?P@,C0@T*'*L;7$U^ZUS<["ML@Z(`#7[KW\(#8@T*'*L;7$
MU^ZXW\["ML@Z(`"WUM;3`-.SR>0`Q>36P\[$O/[2Q<JG+B#(Y[G[TJK*N=/#
MU>*X]M.FT\.SS-#RQ/JQV-#KS];4VK[-LOK)^LO[+@#5TK*[M;W0Q<^BM<0@
M240N`-72LKNUO;OAQMJUQ"!)1"X`T,?&VM*[`-#0MJ_3RKS^`+C\T,+(U<;:
M`,2CO^D`Q*:V^[;@S=\`Q*;$R;CG`-#'QMK2NP##R;G%`-3"`-3"NLW$Z@##
MO]3"`-3".B##OP##R<S8R/O`K<S8`-3"P<'3K[_W`,2FPN6XYP#/PM+&`-?S
MTL8`T]+2Q@#)S]+&`,_"TL8`R<_2Q@#$JLFCL<B_RP"XM-&A`,[2M<35R[K%
M`,[2M<3#Q;NG`,[2M<3#Q;NGTK/#YL7DUL,`P^6UZ0"RNRS.TK*[S:S2X@#$
MR</7L<C1QP#HI\*S`,3ALK2V^P"ZR<"\`+K)RO2PLK78P=#+N0"[^=/:3F5T
M<V-A<&4@M<3-^-:W`$YE='-C87!E(%-33""W_L[QQO?#^[/&`$YE='-C87!E
M(,C/UJ2UQ,7ZUZ(`3F5T<V-A<&4@R,_6I,#@T,T`S?C"YP"TT\ZT`-#"OZ;`
M[[;@Q.'1QP#0PLK"O/X`T,+4P@#0PM/#NZ?#^R`HM\>QV-*J*0#0PL[WP+P`
MT,*TL+_:("A?8FQA;FLI`-#"SL4`S\*X]M3"`,_"TKO,[`#/PM*[N/;1H<_N
M`,_"TKO6W`#$X;S3P*VYSP#$X<C5MOL`Q.'(U<#[T<<`S>W)SP#%IK"CM;H`
MR_G6N+:HM<3.N];#R<_#N]/0Q_B_Z;3FU-H`P[O3T,SAN:G(U<#ZP_NSQM+4
MN:D@34-!3"#1Z=:D+@##N]/0UKBVJ+7$("5S(,7DUL/0Q<^B+@##N]/0UKBV
MJ+7$($944"!61E,@Q>36P]#%SZ(N`,.[T]#6N+:HM<0@4U%,(%9&4\7DUL/0
MQ<^B+@##N]/0UKBVJ+7$(%-13"U&:6QE(%9&4\7DUL/0Q<^B+@#3P-2V`,[$
MO/[.M,G/M*L`SKO6P]#%SZ+)T,ZTQ>36PP##N]/0UKBVJ,/<PNO2U+FI($A4
M5%`@T>G6I"X`P[O3T-:XMJC#W,+KTM2YJ2!)34%0(-'IUJ0N`,.[T]#6N+:H
MP]S"Z]+4N:D@2V5R8F5R;W,@T>G6I"X`P[O3T-:XMJC#W,+KTM2YJ2!,;V=I
M;B#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI(%!!4U-71"#1Z=:D+@##N]/0UKBV
MJ,/<PNO2U+FI(%--0B#1Z=:D+@##N]/0M/W)\[7$UZ*RX<GJQ^LN`,[>U-VT
MYL2_PKR_R;FIO^S(H2X`P[O3T+K/MZBUQ"!834P@ROV^W;&[M*N[V`"_U;#7
MUK4`U*W*O,7DUL/.Q+S^UM#5TK*[M;VPYK&^T,7/HBX@UMC0PK+ZR?K%Y-;#
MSL2\_BX`U-K$^K7$Q>36P\[$O/[6T-72LKNUO;#FL;[0Q<^B+B#6V-#"LOK)
M^L7DUL/.Q+S^+@#.W@#(U;;ZPOS.Q"`H25-/+3@X-3DM,3`I`,6UN*._R[6Z
M`+&QL.O'\@"QL<+MP._1Q\3)R+JUN@#%LLW^`+?'UJZZ\P"WQ]:NQ[``LKO*
MQ]*[N/;$O\*\`,ZTL;O6I[/6`+&XS?S"O`#*KM*[U,(`ROW7U@#7UK?[ROT`
MU]:VSLK]Q+\`L<K*_0!/2P"VU,_SO:C!HM7?`+#+O?C.NP#*KM3"`+#LN:O*
MT@"PHL+\`-:[T]`@24U!4""W_L[QQO?6I[/6SL2\_KS0N;+/[;FFQ-PN`-:[
MO=/*W-*[N/;3RKS^M=C6MRX`UKO3T-.UT]#5W]/KS[7-L[G<P.W4L;_)TM2Q
MY+C\N;+/[<BHS]X`U-K0PK2PO]K6T+3ROZH`T:'/[@`E<R"UQ-&AS^X`S^[$
MO['@NL4`U^G6KP#7Z=:OM:7.NP#4K<J\TZ;3P[/,T/+$H[#F`-3:("5S.B#6
MT+7$U*W*O,2CL.8N`,;DR_P`QN3+_-#%SZ(`T[73T-7?R*C/W@!004T@T>G6
MI,[>T*<N`%!'4"#*_=?6QZG#^P!01U`@O-/#W-?*P<\`4$=0(+FKOZK#W-2_
M`%!'4"#2T<>IP_LOTM&\T\/<(-?*P<\`4$A0(+/,T/*T^L+K`%!(4""]Q;&^
M`+#-N_G+N<RY`,7!P,T`L,W`U<NYS+FQN]6\P>S'^`"PS<3#PNT`L,VRO-''
MT,*\N,3:T<<`L,W`K;GG`,/<PNL`P[O3T-:XMJC#W,+KTM2YJ2!2041)55,@
MT>G6I"X`P]S"Z\BWR,\`P]S"ZSH`P]S"ZSH@`,/<PNNQV-#KSL>ZSRX`S/G)
MSP#,^<G/`,*WOK8`T?G*O0"T_<GSM<?"O*.Z`-:TT-#.K+NDLMG7]P"UQ\*\
MNO/6M-#0SJR[I++9U_<_`-/`OL/)OK/]M,O*PKS^/P#(J,_>`,BHS]ZYW,#M
M`,[2M<0`P]C"LP"WQL+)L?8`M>>[L`#5U<:L`,:DS-B_M;6Z`,?KRN3(Z]*[
MN/;4PK?=O+#$ZK?=+@#'Z\KDR.O2N[CVNL^WJ+7$R-7&VCO1H=3QM,O4PK?=
MM<3(U<;:+@#'Z\KDR.NZS[>HM<3*L;SD+@#'Z\SAN:G.RLSBM<35JM*J+@#'
MZ\KDR.O$^K7$T\.[I\/[O+##W,+K`+*HP+P`S;;&L0#&S\S1T<``M=W+S=/*
MO/ZUO=7BN/;.Q+S^O-`@*&YO="!E;F9O<F-E9"!B>2!)34%0*0#7[KW\("5S
M(-"ARK&UQ+VUT^K!OSH@`%!R969S7VQD87`Z(-72LKNUO<OYT.C2JK7$($Q$
M05`@P*G5N=?IO/XN`%!R969S7W-E<W-I;VXZ(-72LKNUO<OYT.C2JK7$('-E
M<W-I;VX@P*G5N=?IO/XN`,;XT;D`NJ/&O</FQOC1N3H@`,;XT;DZ(`#4I,#`
M`,>PTKO(U0#)S]*[N/;1H<_N`,N]P]S#W-2_`,[*S.+#Z,KV`->HL+@`S.'*
MOL3:R-T`N:N_JL/<U+\`N:N_JL/<U+_1W<OC`+FKOZHOR[W#W,/<U+^VU+*B
MSK2QN[+ZR?HN`+*HMN#`Z+CW`+^HR_ZV^P!24T$@N:N_JL/<U+\@*"5D(,Z[
M*0"UI=&A`+'(PLH`ML'(H0"VP<BAT\J\_@#5YK7$TJK)OK/]("5S(,+P/R#5
MXL_NLMG7][VKSMZWJ+O6N+0N`-;8N+36L;6]`-;8N+3(U<;:`-;8N+2]V-:Y
MR-4`UMBXM+SDN/0`UMBXM-#-S*P`P[_(U=;8N+0`P[_4PM;8N+0`P[_6W-;8
MN+0`P[_$ZM;8N+0`R*'/^[BTU*T`RZ+0PL/%NZ?*T\V\.@"YYM3RL>VT[\J]
M`,;`PML`U+:SS+?^SO'&]P#4MK/,S?C6MR`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ`,F^L_T`R;ZS_<?XO^D`R;ZS_;;4`-?4M_[.\<;WU-VT
MYL2_PKS6T,F^L_W2T;&CM.:UQ,7DUL.SS-#R+@#)OK/]T\.[IP#)OK/]T\.[
MISH@)7,`T.C'\\ZTL;O/[-.F.B"T[<[SNL7"ZSH`UMC)Z`#6V,GHN]C$VK:H
MUK4`O>&Y^P"WM;O8T:'/[@!2975N:6]N("C!],3AS?JUNBD`O<?)JP!2;VUA
M;FEA("C"WL+MQ.'1QRD`T/W7JB`Q.#`@ML@`S_+7\]#]UZH`S_+3TM#]UZH`
MUK30T`!2=7-S:6%N($9E9&5R871I;VX@*+;MPM[+N2D`4G=A;F1A("C"K+"R
MM.\I`%,O34E-12"\T\/<QZG#^P#3RKS^TM'*N=/#(%,O34E-12"\T\/<`%-!
M4TP@T>G6I,[>T*<N`-#%SZ(`ROV^W;_BO<6QO@"\T\/<UM6VR[OZ`+/)N:8`
MT,?&VL'Y`,JENM7`U<3#M;H`RJ6[^;7"NLW!T,ZLR[D`RJ7"K,[WT<>UN@#*
MI<:DL*.V^[K-PO._R\+7R+JUN@#*I<[$R:W,V+K-N/'!UL3)M.\`S:S2N[CV
MM+"_VB`H7W-E;&8I`,CXQ*;1QP#*I<+MP:;%M0#*I;;@P\"ZS<;5P=;.]['(
M`,[`T,?,X;FIU=\`T,?&VL'Y`,FSS-BPHL"MLJX`L:.TYB`E<P#![;3FT,*U
MM0"THK3FRL*\_@"QH[3FT:'/[@"]J[+ZR?JUQ,7DUL/.Q+S^TM0@4$A0(-/O
MT=2X\<J]L:.TYK6]Q/JUQ+?^SO'&]]3=M.;$O\*\UM`N`,7DUL,@)7,@TM&Q
MH[3F+@#1H=3QTKNX]M/#NZ?7Z=/#TM30PM3V`-&AU/'2N\Z[T,*UQ-.UT]#5
MWP#1H=3QTKNRO[?^SO'&]P#1H=3QTKO.N]/#NZ?3P]+4T,+4]@#1H=3QR_G3
MT,C5QMK7Z;S^+@#1H=3QR.>ZSL_4RKZX]];6LKO-K+7$S]3*OK?GN/'2U+RP
MR+'*H;7$S]3*OK?GN/$`T]K2U,_"M<2TL+_:UM#1H<BAQ/K2JK7$U]:W^R[2
MU,KSL>JXM-;&R_G1H<[$U]8LR+NZ\\SYR<_.Q+S^L>"\K<?X+@#1H=3QR-7&
MVK?6N/0Z`-&AU/'(U<;:R-7&VKCQRKTZ`-&AU/'.Q+S^TM2UO,CKROV^W3H`
MT:'4\<._UMRUQ+7:TKO,[#H`T:'4\<JQO.2WUKCT.@#1H=3QR-7&VLJQO.2X
M\<J].@#'Z]&AU/'*L;SDM[;.I]+4S]3*O@#1H=3QS^"[I<:EQ>2UQ+;^N/;7
MUK;.+@#1H=3QQ/JUQ-'5R:O%Y-;#`-&AU/'&J[K#T^_1U#H`M*O+S<[*S.*W
MM-.F`%-E;F5G86P@*,C[Q-J\T[;[*0"TJ[C0QO<Z(`"^Q=3"`%-E<F)I82!A
M;F0@36]N=&5N96=R;R`HR/NV^\ZLT<?3Z\/)S-C$X;CGPMXI`-#RNL4`N^'&
MVB!)1"#2T;G]QMHN`,7DUL,`Q>36P]2VL\RW_L[QQO?)S\KTT]K$^K7$N/;(
MR]6^S*@N`,7DUL/$^K7$QJNZP]/OT=0L(,JQQ_C2U+RPR-7&VKCQRKTN`,7D
MUL/$^K7$QO3*O-.FT\.SS-#R+-'5R:O%Y-;#+-*SP^:X_-#"QK7"RBR\L,;D
MR_S/U,J^T:'/[BX`T]"ZP[RXN/:UV+7CNLW5XKCVLL[*_=/0N=@Z(`!397EC
M:&5L;&5S("C(^\[TMOLI`+FZSN\`O/*VS-6JTJH`RL>W\<ZJM/.RO[?=M<3!
MK+W3MJC2Y;_LO=VYIL3<O/P_`,_4RKX`U-K0T+/,R-7`^M;0S]3*OK3ZL.S*
MPL_N/P##O[3.M<?"O+KSS]3*OLG/TKNTSK7$M<?"O,JQO.0@/P#6N\_4RK[3
MT,GHMJB^K\J^U_?3P[7$RL*\_C\`S]3*OK7CT:'&]P#3VM?SL=_/U,J^("5S
M(+++M:4_`,K5R_4`4VEE<G)A($QE;VYE("C*J-?3R;VY^BD`UZ*RX0#'J</[
M`,>IP_O1W<OC`%-I;F=A<&]R92`HT,*\T\;"*0"T\]"A`,+4N?W.K+ND`%-L
M;W9A:VEA("C+N<+EMZ6_RRD`4VQO=F5N:6$@*,NYPN6WI<3AT<<I`+O]T:G)
M[K;(.B``4V]L;VUO;B!)<VQA;F1S("C+]\+>P\7(NK6Z*0!3;VUA;&EA("C+
M]\+MP/O1QRD`Q<7!T+>]S_+1H=3Q`,"TU+2UV-:W`%-O=71H($%F<FEC82`H
MQ,^WQRD`Q,_%MR`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',`Q,^PZ\?R`%-P86EN("C.][#@T<`I
M`,"LN_C3RKS^`,S8RN+7UK?[RN3(ZP!3<FD@3&%N:V$@*,NYP._`O+^H*0"Q
MZM>\`,;TRKS(U<;:`+^JRKS3V@#&],J\RK&\Y`#&],J\Q.JWW0#*H0"QH[3F
MN/'*O0"]UK7``,F^L_W/WP#7UK?[M*[!T`#0Q\;:S.P`UO?6O`#,X;V[`,_"
ML>H`L\FYI@#2T;/)N::XLKC'("5S`%-U9&%N("C+U;6D*0#5JM*J`,C5L_8`
MR-7"Y`#0Q\;:S.P`R-6S]@#(U;/V+\C5PN0`R-6S]CH@`,C5PN0`R-7"Y#H@
M`,G/L>H`UJ>SU@!3=7)I;F%M92`HR]7`^\3/*0"TPKK%`%-V86QB87)D(&%N
M9"!*86X@36%Y96X`4W=A>FEL86YD("C*M\W?O,/`O"D`4W=E9&5N("C(\+7D
M*0!3=VET>F5R;&%N9"`HR/#*ORD`4WER:6%N($%R86(@4F5P=6)L:6,@*-#P
MP/O1QRD`5$%"(+?6N/2X\<J]SL2\_@#,J,WE`,RHS>4`5&%J:6MI<W1A;B`H
MR_Z\JLNYS+DI`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8@*,RYR=#$
MX=''*0#$O['J.@"T^K#LRL+/[@"UY[NPNL7"ZP#7[KW\TKO0H<JQM<3.PK;(
M.B``SL*VR`#.PK;(.B``Q*.PYKG<P.T`Q-K(W0"TO\[$U]8`T,?&VLO$`,RI
MSL0@*%1)4RTV,C`I`%1H86EL86YD("C,J;GZ*0#0N]"[Q/K*N=/#L;[/M<VS
M+@!&5%`@T=/)["AE>'1E;G-I;VXISM[0IRX`36%I;G1E;F%N8V4@P."Q\+*B
MSK2SR;FFU-C(ZP#1H<_NM+"_VM+4N=BQU2[`Z[^JUM`N`-'IUJ33RKS^QZG#
M^]#HTJK3T-*[N/;2T;WBOZJUQ"!01U`@Q_B_Z2X`T.C2JM*[N/:^K;G]O-/#
MW+7$S?C"Y\&LO=,N`+WAROC(U<;:L=C0Z+3ST]J_JLJ\R-7&VBX`SL2\_B`E
M<R#3IKC#L/RZK-*[N/8@)7,@Q>36PRX`SL2\_B`E<R#3IKC#L/RZK-*[T*D@
M)7,@Q>36PRX`M,O.Q+S^UM##N]/0ROV^W2X`TM3/PLK'(')F8S@R,B#3RKS^
MM<2Q[<VW+@!';G501R"V_M2JSL2\_K7$PK>^MK'8T.NVJ-+EU-H@0W)Y<'1?
M<&=P.CH@P."Q\-;0+@!(;W)D95]#<GEP=%]S;6EM93HZ(,#@L?`LL=C0Z-*J
MT]`@;W!E;G-S;"#$H[_I+@"TR\:KNL,@(B5S(B#*_;[=TO+.JK.LN?W7[K3S
MO=/*W-:U+,OYTM3.WK>HL;NQH[3F`-/#TM2\[,K3M,O*_;[=P.#0S2`H)7,I
M(+7$L\S0\K*BLKNTYM3:T]K/M<VSR<\N`+3+M_[.\<;W("(E<R(@TM&QN\F^
ML_TN`+3+M_[.\<;W("(E<R(@TM&QN[&CM.8N`"5S(+7$UZ*RX=#HQ_/2T;&[
MR;ZS_2X`UKBVJ+7$O,?"O+*BLKNTYM3:+@"TT\G/TKNX]K*]UNC6KKKSR<^T
MJ[7$ROV^W=+%RJ<N`,G/M*O.Q+S^LJ+.M+&[L:.TYBX`=V5A=&AE<BYC;VT@
MQ_B_Z<[>MZC*N=/#+@#.WKB]O/Z_R=:QO=.T\K^J+@"TR]?6ML[6T+#\NJS,
MJ[;@M<37ULK]+L3ZTM'*Y,CK("5S(+CVU];*_3O$^LKDR.NUQ-?6ROVQV-#K
MT*'3VB`E<RX`R<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@)7,@SK2QN\G/M*LN
M`,G/M*O.Q+S^RK&WHLGZTKNX]L[*S.(Z("5S(+3ST*&SK+G]O=/*W-?NM//6
MM2`H)60@8GET97,I+@#)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB.B"]]K*_M]:U
MQ"`E<R#.Q+S^L;O)S[2K+@"\[,K3T\J\_LJQMZ+)^M*[N/:T[<[S+@"[X\CK
MM,O-J-&VLK[*_;[=RK&WHLGZM.W.\RX`U-K%Y-;#M+#,Y=;0MZ+)^L'+TKNX
M]K3MSO,NT]"_R<3<Q/K2Q<*IP<NQV-#KS.[0M+7$U]:VSBX`P[O3T,K"O/Z_
MR;6\L_8N`+3+($E-05`@M_[.\<;WLJ+.M-:GL];.Q+S^O-"WUL_MN:;$W"X`
MU>++QKKULKO*Q]7]R+>UQ"!R87(@T;G+]<[$O/XN`-7BR\:Z];*[RL?5_<BW
MM<0@>FEP(-&YR_7.Q+S^+@#5XLO&NO6RN\K'U?W(M[7$T,73P[^HNL7"ZRX`
MM,O7UK;.RL>QV-#HTJJUQ"X`M,O7UK;.Q-K(W=:[O=/*W-7[ROW*_=?6+@"T
MR]?6ML[$VLC=UKN]T\K<ROW7UKRPP["ZQ2X`M,O7UK;.Q-K(W=:[O=/*W+#+
MO?C6QLK]UK4N`+3+U]:VSL3:R-VQV-#KSJJVNKK%N_*_U;#7M]:X]+7$ROW7
MU@"QV-#KRL?2N[CVROW7UBX`M,O7UK;.Q-K(W;'8T.NP_+JLTKO7Z<JNP?F]
M^-;&M<0@4D="(-'5R:NT^L+K+,#]R.<@)R,Q,C,T868G+@#5XKCVM+#,Y=+1
ML;NTIL#MN?TN`-7BRL<@)7,N`+3+ROW6M=?NR=FQV-#KRL<@,2X`M,NW_L[Q
MQO?.WK>HMM0@>FEP(+RP(&=Z:7`@N/'*O<[$O/Z]^-#0O>+1N<OU`+3+S[7-
ML[6QQ[#*Q\VCT\.UQ->TS*PN`+'8T.O*Q]*[N/;*_=?6+@"TR[2PO]JQV-#K
MTJK3R=&AS^ZTL+_:*$]P=&EO;BG+^;KTO=``T,?&VLO$`,JQO.0`RK&\Y->W
MU]D`RK&\Y+CQRKT`RK''^-&AU/$`5&EM;W(M3&5S=&4`RL*\_L/[L\8`RM6\
M_LC+`,CGN?O2JKBTT:$LQ^O4VK7CT:'*\['JM<3-K,JQL+0@0V]N=')O;+S\
M*+CVR,N\QLOCN_HI(+OR($-O;6UA;F2\_"C&N[G[O,;+X[OZ*2X`O?',[`!(
M5$U,(-2MRKS.Q+S^`+;@N.<`S="_R\#-R+JUN@#,P+S3`,S8P:+$X;3ONLVV
MX+#-N.<`U>:[\KS9`-#'QMJV_@#0Q\;:MOX`S;O$X<NY`,W!MOK&Y`#-P;;Z
MQN3.Q"`H25-/+3@X-3DM.2D`S<&_XL+\R[G,N0#,V+_+R[FZS;^MO\;+N<BZ
MM;H`S;S-W\*L`-#-RKT`RN3(Z\3ZM<31H=3Q.B``U\_-XL_?UKC*_3H@`,WX
MUK<Z`,[:N,FT[P#.VK_+P+P`SMZWJ+3FR*$@5D93(,2_PKPN`->BLN'*L<[>
MMZC4]KS3MN[-XK7$T\.[I]#%SZ(N`,[>MZBXQ+'D(%9&4R#.Q+S^("(E<R(@
MM<3(J,_>+@#.WK>HL>2X_"!61E,@SL2\_B`E<R\E<R"UQ,BHS]XN`,[>MZBQ
MY+C\SJH@)7,N`,[>MZC*N=/#(%-33"#!K+W3+@#.WK>HN+36QB!61E,@SL2\
M_BX`SMZWJ+VHP:(@5D93(,2_PKP@(B5S(BX`SMZWJ+VHP:(@5D93(,2_PKPN
M`,[>MZB]J,&B(%9&4R#.Q+S^+@#.WK>HO:O*_;[=O>+1N<OU+@#.WK>HR;ZS
M_2`E<RRTR\2_PKRRHK?'O]6PUP#.WK>HM=VYZ<F^L_W$O\*\+@#.WK>HR;ZS
M_2!61E,@Q+_"O"X`SMZWJ,F^L_T@5D93(,2_PKPZ("5S+@#.WK>HR;ZS_2!6
M1E,@SL2\_B`B)7,B+@#.WK>HR;ZS_2!61E,@SL2\_BX`SMZWJ+7=N>G)OK/]
M(%9&4SH@)7,N`,[>MZC%T+;/M;''L+7$Q+_"O"X`SMZWJ+WBOZK&OM:DS[B]
MV@#.WK>HTL:VKR!61E,@SL2\_BX`SMZWJ+3ROZH@5D93(,[$O/X@(B5S(BX`
MSMZWJ-"TR.L@5D93(,[$O/XN`,[>MZBT\K^J(%9&4R#.Q+S^+@#.WK>HM/*_
MJM&YR_7.Q+S^+@#.WK>HML'(H2!V9G-R;V]T(,2_PKPN`,[>MZBQY+C\(%9&
M4R#$O\*\M<3#^[/&+@#.WK>HR;ZS_2!61E,@Q+_"O#H@)7,N`,[>MZBQY+C\
M(%9&4R#.Q+S^("(E<R(@M<3#^[/&+@#.WK>HL>2X_"!61E,@SL2\_B`E<R\E
M<R"UQ,/[L\8N`,[>MZBQY+C\(%9&4R#.Q+S^M<3#^[/&+@#.WK>HUZJ[NR!7
M;W)D(,[$O/X`SMZWJ-"TR.L@5D93("(E<R(@SL2\_BX`SMZWJ-"TR.L@5D93
M(,[$O/[*_;[=+@#/PKNNS]\`R*'/^[C\N,0`N+34K0"W_L[QQO?!K+W3RK&W
MHLGZSK34I,;:M<2[V-.F.B``MZ+)^LZTU*3&VK7$N]C3IBS3R;?^SO'&]SH@
M`,WRT\/"ZR`H551&+3@I`+"BP*VRKL&JNL_'];.DN?H`TZ*Y^@##P+GZ`%5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P"UI=2J`,ZTUJJU
MQ`#.M-:JM<33P[NGP_N[\L/<PNLN`,ZTUJ>SUK7$P*G5N</[`+'DN/P`N/S0
MPB`E<P"X_-#"T\.[IP"X_-#"L\S0\M+1R;ZS_2X`R<^TJP#2T<G/M*O+^=/0
MTZ;3P[/,T/*UQ,7DUL/.Q+S^M;VW_L[QQO<N`,[:P*VYYP#3P[NG("5S(,ZT
MS:BY_2`E<R"UQ,K:R*C1Z=:D+@#3P[NGN=S`[0#*N=/#U=^]T[_:`-/#NZ?1
MH<_N`-/#NZ?7HK+A`+3+U;[,J+7$T\.[I]>BLN'/M<VSTM'-H]/#+@#3P[NG
MP_L`T\.[I\/[.@#3P[NG.B``S[7-L];0M<33P[NG.@#.VM?(L?"_R\NYS+D`
M5D93(,2_PKRRHK*[M.;4VBX`O-G&V@#2T=72M;W3T-"GM<2UV+7C.B``T]#0
MI]#4`-+4M];6T\ZJM:7.NRBTT\_6U-K&\,OC*0#6M0#-W\*SL*+-O`"QY+NO
M`,ZOQ-K(\,"M`-'IUJ3*I[#<("T@M,O3RKS^O\G$W-+1U.+(R\G#U]2TV[C$
M+@"PYK&^`+#FL;Z_V-;&`-2]Q,\`U+W$S\[$("A625-#24DI`+SLRM,@)7,`
MU-K0PK2PO]JT\K^J`-+4("5S(++IO[0`TZ+*],ZLMON^J<BZM;H`P\#*],ZL
MOJG(NK6Z`,3<O/NVR`#$W+S[ML@Z(`#2XK3SP/NW_+7"M^>UY]#%N:O+OLVX
MN?T@4TU44`"^K[CF`+ZON.8A(2$@M-,@)7,@RM:VK\F^L_VSS-#R+@#-W\#[
MR[FZS;B[S;S(NK6Z`+ZON.8`T,?&VLC]`,SLQOC4I++B`,WXU;X`S?C5O@#0
MQ\;:R/T`UMP`UMP@)60`UMP`P[_6W`#6W#H@P[\`N[;3K0"[MM.MM;T@)7,`
MN[;3K2P@)7,`SO?%MR`H25-/+3@X-3DM,2D`SO?%MR`H25-/+3@X-3DM,34I
M`,[WR/:Y_L"M`+7'PKRZ\].FN,//R,_4RKX@)7,@Q,32N[CVTZ;3P[/,T/(_
M`-?6MLZUQ+?6N/37UK?[/P#2_<KVM<3'L+6\M_L_`,C5T^O6W+7$O>'6N<_4
MRK[*L;SDH[\`R-73Z];<M<3&],J\S]3*OLJQO.2COP"WY\O9*+W:*0"WY\O9
M.@"WY\O9.B``L.RYJ\K2M=C6MP"P[+FKRM*UY[NP`,G/L.#(U0!8-3`Y=C,@
MP*G5N</[`,3J`,3J`%EA:&]O("$@M=C-O`##O\3J`,3J.B##OP#2LL/%`,K'
MM<0LSM+-K-+B`,3ZM;''L,JYT\.TO\[$U]:QX-"TQ*/*O2X@RKG3PR!;/#Y=
M(+"TQ:6_R<?0N[O.JLWXTK.QX-"TQ*/*O2X`Q/JRHLZTRN3(Z]*[N/:ZS[>H
MM<2UY]?3T\J\_K78UK<N`,3ZLJ+.M-/)M;S(Z[7$SL2\_M;0MM33L\C.NL[7
MUK;.M;T@)7,`Q/K2T;ZMUZ+/^BX`Q/JQV-#KRN3(Z]*[N/:ZS[>HM<36M2X`
MQ/JQV-#KS\BYYKNNNL/*_;[=RO<H1&%T851R964IM_[.\;;+LL7$W+S,T/C*
MN=/#T,+3P[NGUZ*RX;?^SO$N`,?KP^C*]L[*S.*CK-3:Q/JTJ\O-SLK,XK&H
MN.;6KL>P+@#$^K'8T.O*Y,CKM,O!K+W3R_G6N,_RM<3-^-:W`,?KUKBVJ-*J
MR;ZS_;7$M_[.\<;W+@#'Z]:XMJC2JLF^L_VUQ-/#NZ<N`,?KUKBVJ-*JT,+4
M]K7$T\.[IRX`Q^O6N+:HTJJX_-#"M<33P[NG+@#'Z]:XMJC2JM:TT-"UQ-?W
MT\,N`,3ZM<0@)7,@N^'&VM+1N?W*L2['Z];8T,*UQ\*\+@#$^K7$M>?7T]/*
MO/ZUV-:W`,3ZM<30Q<^B`-?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<32
M\LS8S?BUV-:WTM&QY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8
MT,*UQ\*\+@#$^K7$T-7#^P#$^K7$T>G6I+;+LJ+.M-:GL];!T+/VT\.[I[OR
MN,.YIL3<TM&QN[G8L=4N`-?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<3D
MK\#`QO?+QKKUTM&QY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8
MT,*UQ\*\+@#$^K7$Y*_`P,;WLJ+.M-:GL];5XKCVN:;$W"X`Q/JUL<>PR_G%
MY-;#M<3*L<?X.@#$^K7$T:'/[M+1N/S0PBX`Q/JUQ-2VL\RW_L[QQO<Z`,3/
MR[G`K;?R`-3ZTL&V^P#4WK'(T<<`O?*PS;*\SJ0`6\[*S.*QJ+CF70!;SKO3
MVM#0("5S(+FR("5S(-#070#(U0#(U0#(U0#.Q+S^`+33("5S("@E<RD@T]H@
M)7,@)7,`RK$Z`,&BO+0`U,(`P_NSQ@#)T,ZTRK7/UBX`R=#.M,JUS]8N`-3:
MS:S2N\SL`-3:P[_6W+7$M=K2N\SL`-39M,[*Y,CKQ/JUQ,/<PNO2U,BWR,_.
MWL[S`,ZTP_S#^P#3P[NGT:'4\0!V0V%R9`#0Q\;:.@!W96%T:&5R+F-O;2#-
M^-6^`-;<`-;<.@#6W`#$Z@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]L;V-A;&4O>FA?5%<O````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3(`,#(P-S(V`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+VQO8V%L92]Z:%]45R],0U]-15-304=%
M4R\````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,@`P
M,C(U,3,`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O;&]C86QE
M+WIH7U17+TQ#7TU%4U-!1T53+VMR;VYO;&ET:"YM;P``````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#$T
M,38W`#$P-#$W,S8R-S4R`#`R-3`W,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````*X(```<````C$4``),+``#\
MB@```````$BY```.````2;D```\```!8N0``#0```&BY```(````=KD```L`
M``!_N0``#````(NY```$````F+D``!@```"=N0``&P```+:Y```M````TKD`
M`!T`````N@``)````!ZZ```I````0[H``!D```!MN@``)@```(>Z```,````
MKKH``!(```"[N@``)````,ZZ```)````\[H```\```#]N@``"P````V[```?
M````&;L```X````YNP``!0```$B[```H````3KL```@```!WNP``"@```("[
M```5````B[L``!(```"ANP``"P```+2[```,````P+L``!T```#-NP``A0``
M`.N[```.````<;P```H```"`O```#0```(N\```.````F;P``!$```"HO```
M#0```+J\```,````R+P```T```#5O```!@```..\``"4````ZKP``$\```!_
MO0``'0```,^]```=````[;T```H````+O@``#P```!:^```8````)KX```P`
M```_O@``"@```$R^```'````5[X```8```!?O@``#@```&:^```*````=;X`
M``H```"`O@``#@```(N^```(````FKX```H```"CO@``"0```*Z^```E````
MN+X``"@```#>O@``)`````>_```F````++\``"X```!3OP``&@```(*_```R
M````G;\``#@```#0OP``5`````G```!1````7L```%H```"PP```5P````O!
M```T````8\$```(```"8P0``"0```)O!```-````I<$```<```"SP0``"@``
M`+O!```/````QL$```4```#6P0``!@```-S!```1````X\$```@```#UP0``
M"0```/[!```)````",(```@````2P@``)0```!O"```@````0<(``!,```!B
MP@``$````';"```/````A\(```H```"7P@``$````*+"```#````L\(```\`
M``"WP@``%````,?"```)````W,(```D```#FP@``#0```/#"```2````_L(`
M`!D````1PP``'@```"O#```9````2L,```\```!DPP``#P```'3#```-````
MA,,```H```"2PP``#P```)W#```(````K<,``"0```"VPP``%````-O#```6
M````\,,```@````'Q```3@```!#$```M````7\0``!D```"-Q```!P```*?$
M```,````K\0``"P```"\Q```#@```.G$```#````^,0```\```#\Q```"P``
M``S%```%````&,4``!0````>Q0``%0```#/%```7````2<4``!4```!AQ0``
M$@```'?%```3````BL4``!4```">Q0``$P```+3%```*````R,4``!0```#3
MQ0``"@```.C%```'````\\4```<```#[Q0``!0````/&```%````"<8```H`
M```/Q@```P```!K&```-````'L8``!<````LQ@``"@```$3&```*````3\8`
M``@```!:Q@``#P```&/&```+````<\8```<```!_Q@``#0```(?&```*````
ME<8```X```"@Q@``&````*_&```C````R,8```X```#LQ@``%````/O&```7
M````$,<``!<````HQP``%P```$#'```3````6,<```\```!LQP``#@```'S'
M```?````B\<``!T```"KQP``!P```,G'```&````T<<```@```#8QP``#P``
M`.''```&````\<<```H```#XQP``$P````/(```#````%\@```L````;R```
M$````"?(```5````.,@``!4```!.R```!P```&3(```0````;,@```4```!]
MR```%0```(/(```1````F<@```P```"KR```.P```+C(```X````],@```D`
M```MR0``!P```#?)```4````/\D```,```!4R0``!0```%C)```0````7LD`
M``D```!OR0``$P```'G)```Y````C<D``!(```#'R0```@```-K)``"T````
MW<D``"<```"2R@``+````+K*```J````Y\H``"4````2RP``"@```#C+```)
M````0\L```H```!-RP``!@```%C+```)````7\L```<```!IRP``+P```''+
M```W````H<L``"X```#9RP``50````C,```M````7LP``"T```",S```/0``
M`+K,```_````^,P``"T````XS0``0````&;-```C````I\T``",```#+S0``
M0````._-```M````,,X``#,```!>S@``)0```)+.```5````N,X``!D```#.
MS@``*0```.C.```D````$L\``"@````WSP``$0```&#/```*````<L\```H`
M``!]SP``$````(C/```6````F<\``!8```"PSP``!P```,?/```'````S\\`
M`!0```#7SP``"@```.S/```(````]\\``"<`````T```"````"C0```,````
M,=````<````^T```!P```$;0```&````3M````4```!5T```!P```%O0```&
M````8]````@```!JT```*0```'/0```.````G=````H```"LT```!````+?0
M```'````O-````D```#$T```!@```,[0```1````U=````<```#GT```%@``
M`._0```$````!M$```@````+T0``!@```!31```-````&]$```8````IT0``
M'@```##1```1````3]$```@```!AT0``#0```&K1```,````>-$```<```"%
MT0``!````(W1```#````DM$```,```"6T0``%P```)K1```)````LM$``!,`
M``"\T0``'0```-#1```)````[M$```@```#XT0``$`````'2```=````$M(`
M``D````PT@``&P```#K2```$````5M(```@```!;T@``"````&32``!!````
M;=(``!H```"OT@``(````,K2```9````Z](``!4````%TP``!@```!O3```&
M````(M,``!4````ITP``"0```#_3```-````2=,``!@```!7TP``(@```'#3
M```N````D],``!T```#"TP``(0```.#3``!4`````M0``"D```!7U```"@``
M`('4```'````C-0```D```"4U```%0```)[4```(````M-0```X```"]U```
M"@```,S4```/````U]0```T```#GU```#P```/74```-````!=4```D````3
MU0``%````!W5```&````,M4``!@````YU0``'0```%+5```3````<-4``!$`
M``"$U0``%````);5```$````J]4```8```"PU0``%````+?5``!4````S-4`
M`&0````AU@``!````(;6```.````B]8```4```":U@``!0```*#6```;````
MIM8``!H```#"U@``$P```-W6```1````\=8``!$````#UP``'````!77``!.
M````,M<``$4```"!UP``10```,?7```J````#=@``#8````XV```/@```&_8
M```_````KM@``!T```#NV```$`````S9```A````'=D```4````_V0``$P``
M`$79```+````6=D``!,```!EV0``$@```'G9```*````C-D```\```"7V0``
M#0```*?9```1````M=D``!,```#'V0``#````-O9```&````Z-D```P```#O
MV0``!@```/S9```7`````]H``!`````;V@``$0```"S:```(````/MH```4`
M``!'V@``#````$W:```0````6MH```4```!KV@``#0```'':```&````?]H`
M`!8```"&V@``!P```)W:```-````I=H```<```"SV@``"P```+O:```'````
MQ]H```<```#/V@``"0```-?:```)````X=H```H```#KV@``&0```/;:```]
M````$-L``!T```!.VP``#````&S;```0````>=L``!L```"*VP``"0```*;;
M```%````L-L``"4```"VVP``$@```-S;```3````[]L``"L````#W```.P``
M`"_<```@````:]P```@```",W```-@```)7<```A````S-P``!````#NW```
M"````/_<```,````"-T```0````5W0``#P```!K=```.````*MT``$`````Y
MW0``"@```'K=```-````A=T``!\```"3W0``'````+/=```A````T-T``!X`
M``#RW0``&0```!'>```>````*]X``!T```!*W@``&P```&C>```@````A-X`
M`"X```"EW@``)@```-3>```<````^]X``!X````8WP``'````#??```F````
M5-\``"L```![WP``,P```*??```F````V]\``"L````"X```.````"[@```=
M````9^```!4```"%X```+P```)O@```@````R^```!(```#LX```*0```/_@
M```>````*>$``"````!(X0``$@```&GA``"B````?.$``!8````?X@``(P``
M`#;B```H````6N(``"D```"#X@``*````*WB```?````UN(``!4```#VX@``
M(`````SC```E````+>,``"@```!3XP``+0```'SC```P````JN,``)(```#;
MXP``(0```&[D```6````D.0``!P```"GY```)@```,3D```J````Z^0``$$`
M```6Y0``1````%CE```,````G>4```<```"JY0``!P```++E```&````NN4`
M``\```#!Y0``$@```-'E```-````Y.4``!````#RY0``$@````/F```'````
M%N8``!,````>Y@``$@```#+F```'````1>8```0```!-Y@``!P```%+F```0
M````6N8```P```!KY@``#@```'CF```-````A^8```\```"5Y@``$P```*7F
M```-````N>8``"@```#'Y@```P```/#F```-````].8```8````"YP``$0``
M``GG```7````&^<``!L````SYP``#@```$_G```"````7N<``$D```!AYP``
M!0```*OG```3````L><``!````#%YP``#P```-;G```$````YN<```T```#K
MYP``#@```/GG```#````".@```8````,Z```!P```!/H```.````&^@```@`
M```JZ```#P```#/H```(````0^@```\```!,Z```!P```%SH```0````9.@`
M``T```!UZ```$````(/H```-````E.@```L```"BZ```!@```*[H```)````
MM>@```L```"_Z```#````,OH```,````V.@```H```#EZ```$0```/#H```9
M`````ND```L````<Z0``#0```"CI```B````-ND``!L```!9Z0``-````'7I
M```*````JND``!@```"UZ0``&0```,[I``!<````Z.D``!8```!%Z@``(@``
M`%SJ```-````?^H```<```"-Z@``#````)7J```4````HNH```L```"WZ@``
M(@```,/J```O````YNH```L````6ZP``"0```"+K```9````+.L```L```!&
MZP``%P```%+K```7````:NL```D```""ZP``!P```(SK```6````E.L``!$`
M``"KZP``#P```+WK```9````S>L``!8```#GZP``#@```/[K```8````#>P`
M``@````F[```#0```"_L```F````/>P``#D```!D[```#@```)[L``!#````
MK>P```@```#Q[```$@```/KL```?````#>T```@````M[0``"P```#;M```O
M````0NT```X```!R[0``!0```('M```'````A^T```@```"/[0``!@```)CM
M```#````G^T```<```"C[0``!````*OM```'````L.T```X```"X[0``"@``
M`,?M```.````TNT```H```#A[0``#P```.SM```0````_.T``!<````-[@``
M%0```"7N```.````.^X``!H```!*[@``$0```&7N```9````=^X``!<```"1
M[@``"0```*GN```%````L^X```L```"Y[@``"@```,7N```%````T.X```T`
M``#6[@``&P```.3N```7`````.\``!0````8[P``"0```"WO```.````-^\`
M``T```!&[P``$@```%3O```$````9^\``#@```!L[P``(````*7O```(````
MQN\```8```#/[P``"````-;O```(````W^\```X```#H[P``>P```/?O```8
M````<_```!$```",\```!P```)[P```%````IO```!@```"L\```'@```,7P
M```;````Y/```!D`````\0``,0```!KQ```;````3/$``!,```!H\0``!P``
M`'SQ```(````A/$```8```"-\0``!@```)3Q```,````F_$```X```"H\0``
M#0```+?Q```3````Q?$``!X```#9\0``&0```/CQ```0````$O(```\````C
M\@``$````#/R```/````1/(```L```!4\@``#P```&#R```,````</(```\`
M``!]\@``!P```(WR```&````E?(```P```"<\@``#@```*GR```,````N/(`
M``\```#%\@``"````-7R```&````WO(```\```#E\@``"````/7R```3````
M_O(``!X````2\P``(0```#'S```@````4_,``!D```!T\P``%P```([S```E
M````IO,``!<```#,\P``%@```.3S```$````^_,``!L`````]```#0```!ST
M```,````*O0```,````W]```!0```#OT```(````0?0```H```!*]```#```
M`%7T```+````8O0``!````!N]```#````'_T```$````C/0``!,```"1]```
M%````*7T```,````NO0```D```#']```#@```-'T```+````X/0``!L```#L
M]```!P````CU```$````$/4```<````5]0``"@```!WU```-````*/4```D`
M```V]0``!````$#U```%````1?4```,```!+]0``&````$_U```*````:/4`
M``0```!S]0``)@```'CU```.````G_4``'P```"N]0``%0```"OV```%````
M0?8```<```!']@``#````$_V```(````7/8```H```!E]@``!@```'#V```(
M````=_8```(```"`]@``!@```(/V```&````BO8``!0```"1]@``!````*;V
M```5````J_8```T```#!]@``$````,_V```;````X/8```8```#\]@``!```
M``/W```)````"/<``!`````2]P``"0```"/W```)````+?<```8````W]P``
M!0```#[W```(````1/<```8```!-]P``!````%3W```'````6?<``!D```!A
M]P``#@```'OW```'````BO<```<```"2]P``!0```)KW```)````H/<```H`
M``"J]P```@```+7W```&````N/<```L```"_]P``#0```,OW```'````V?<`
M``D```#A]P``!@```.OW```2````\O<```D````%^```!P````_X```4````
M%_@``!T````L^```0@```$KX```E````C?@``"4```"S^```!@```-GX```*
M````X/@```0```#K^```"0```/#X```(````^O@``!$````#^0``"0```!7Y
M```&````'_D```T````F^0``!@```#3Y```$````._D``!X```!`^0``!0``
M`%_Y```.````9?D```0```!T^0``!@```'GY```'````@/D``"$```"(^0``
M#0```*KY```5````N/D```8```#.^0``!````-7Y```1````VOD```8```#L
M^0``"@```//Y```B````_OD```0````A^@``!P```";Z```$````+OH```4`
M```S^@``'0```#GZ```$````5_H```P```!<^@``#@```&GZ```*````>/H`
M``@```"#^@``"0```(SZ```%````EOH``#H```"<^@``,````-?Z```U````
M"/L``"D````^^P``1P```&C[```X````L/L``"D```#I^P``/P```!/\```N
M````4_P``"T```""_```'P```+#\```/````T/P``!(```#@_```"P```//\
M```'````__P``"8````'_0``/````"[]```I````:_T``#H```"5_0``)```
M`-#]```F````]?T```@````<_@``"@```"7^```)````,/X```<````Z_@``
M(````$+^```@````8_X``"8```"$_@``"@```*O^```9````MOX``"D```#0
M_@``$@```/K^```'````#?\```H````5_P``#````"#_```/````+?\``!``
M```]_P``0````$[_``!P````C_\``&8```````$`T0```&<``0`.````.0$!
M``D```!(`0$`"@```%(!`0`2````70$!`!,```!P`0$`#````(0!`0`&````
MD0$!`!@```"8`0$`#P```+$!`0`6````P0$!`!(```#8`0$`$````.L!`0`1
M````_`$!`!P````.`@$`(P```"L"`0!J````3P(!``\```"Z`@$`!0```,H"
M`0`0````T`(!``D```#A`@$`!````.L"`0`+````\`(!`"````#\`@$`%```
M`!T#`0`,````,@,!``P````_`P$`#P```$P#`0`5````7`,!`"D```!R`P$`
M*@```)P#`0`F````QP,!`"<```#N`P$`*0```!8$`0`J````0`0!`!D```!K
M!`$`0@```(4$`0`1````R`0!`!(```#:!`$`$P```.T$`0`4`````04!``\`
M```6!0$`%@```"8%`0`7````/04!`!````!5!0$`$0```&8%`0`T````>`4!
M`!,```"M!0$`$@```,$%`0`U````U`4!`!0````*!@$`!P```!\&`0`,````
M)P8!`"`````T!@$`$````%4&`0`4````9@8!`!$```![!@$`%P```(T&`0`<
M````I08!`!,```#"!@$`%````-8&`0`:````ZP8!`!$````&!P$`&@```!@'
M`0`>````,P<!`!H```!2!P$`$P```&T'`0`5````@0<!`!$```"7!P$`%P``
M`*D'`0`4````P0<!`!<```#6!P$`%0```.X'`0`)````!`@!`!`````."`$`
M&0```!\(`0`$````.0@!``<````^"`$`"P```$8(`0`1````4@@!``8```!D
M"`$`!@```&L(`0`&````<@@!``4```!Y"`$`!P```'\(`0`'````AP@!``4`
M``"/"`$`%@```)4(`0`&````K`@!``8```"S"`$`!````+H(`0`$````OP@!
M``<```#$"`$`#@```,P(`0`,````VP@!``P```#H"`$`#0```/4(`0`*````
M`PD!``X````."0$`!0```!T)`0`H````(PD!``X```!,"0$`#````%L)`0`/
M````:`D!``H```!X"0$`"````(,)`0`)````C`D!`"L```"6"0$`"````,()
M`0`$````RPD!``@```#0"0$`)@```-D)`0`2``````H!``\````3"@$`!@``
M`",*`0`*````*@H!``<````U"@$`"````#T*`0`@````1@H!``T```!G"@$`
M"0```'4*`0`-````?PH!``H```"-"@$`%````)@*`0`,````K0H!``T```"Z
M"@$`"0```,@*`0`.````T@H!`!8```#A"@$`$0```/@*`0`)````"@L!``8`
M```4"P$``P```!L+`0`&````'PL!``<````F"P$`!````"X+`0`+````,PL!
M``L````_"P$`!P```$L+`0`'````4PL!`!8```!;"P$`#0```'(+`0`-````
M@`L!``H```"."P$`$````)D+`0`/````J@L!`!$```"Z"P$`%P```,P+`0`*
M````Y`L!`!$```#O"P$`"`````$,`0`>````"@P!``0````I#`$`#P```"X,
M`0`Z````/@P!``4```!Y#`$`'@```'\,`0`.````G@P!`!````"M#`$`"P``
M`+X,`0`,````R@P!``D```#7#`$`!P```.$,`0`*````Z0P!``D```#T#`$`
M#@```/X,`0`0````#0T!`!L````>#0$`&````#H-`0`:````4PT!``H```!N
M#0$`"0```'D-`0`)````@PT!``H```"-#0$`#````)@-`0`/````I0T!``@`
M``"U#0$`!@```+X-`0`'````Q0T!``4```#-#0$`"P```-,-`0!'````WPT!
M``T````G#@$`"0```#4.`0`$````/PX!``,```!$#@$`$P```$@.`0`3````
M7`X!`!,```!P#@$`"@```(0.`0`"````CPX!``0```"2#@$`)0```)<.`0`#
M````O0X!``4```#!#@$`*@```,<.`0`*````\@X!``4```#]#@$`!`````,/
M`0`*````"`\!``T````3#P$`!@```"$/`0`(````*`\!``@````Q#P$`!```
M`#H/`0`%````/P\!`!@```!%#P$`:````%X/`0`)````QP\!``P```#1#P$`
M!0```-X/`0`&````Y`\!`!L```#K#P$`+P````<0`0`0````-Q`!``H```!(
M$`$`#P```%,0`0`*````8Q`!``D```!N$`$`$P```'@0`0`;````C!`!`!@`
M``"H$`$`%P```,$0`0`8````V1`!`!\```#R$`$`#@```!(1`0`#````(1$!
M``<````E$0$``@```"T1`0`(````,!$!``<````Y$0$`!P```$$1`0`+````
M21$!``D```!5$0$`"@```%\1`0`+````:A$!``<```!V$0$`40```'X1`0`0
M````T!$!``P```#A$0$`&@```.X1`0!*````"1(!`!D```!4$@$`!@```&X2
M`0`:````=1(!`"4```"0$@$`!@```+82`0`&````O1(!`!\```#$$@$`!@``
M`.02`0`)````ZQ(!`!@```#U$@$`%P````X3`0`H````)A,!``D```!/$P$`
M!@```%D3`0`-````8!,!`"(```!N$P$`5P```)$3`0`3````Z1,!`",```#]
M$P$`$P```"$4`0`"````-10!``L````X%`$`"````$04`0`-````310!``H`
M``!;%`$`!P```&84`0`4````;A0!``8```"#%`$`!@```(H4`0`(````D10!
M``4```":%`$`"@```*`4`0`.````JQ0!``<```"Z%`$`$P```,(4`0`5````
MUA0!``P```#L%`$`#0```/D4`0`*````!Q4!``L````2%0$`,@```!X5`0`'
M````414!``P```!9%0$`#0```&85`0`,````=!4!``D```"!%0$`"0```(L5
M`0`*````E14!``<```"@%0$`"0```*@5`0`'````LA4!``H```"Z%0$`&P``
M`,45`0!"````X14!`!(````D%@$`"@```#<6`0`6````0A8!``P```!9%@$`
M#0```&86`0`0````=!8!``D```"%%@$`$````(\6`0`'````H!8!`!(```"H
M%@$`!````+L6`0`'````P!8!``4```#(%@$`!0```,X6`0`+````U!8!`!0`
M``#@%@$`$0```/46`0`:````!Q<!`!8````B%P$`%````#D7`0`7````3A<!
M`!@```!F%P$`'````'\7`0`9````G!<!``<```"V%P$`!0```+X7`0`-````
MQ!<!``P```#2%P$`"0```-\7`0`1````Z1<!``@```#[%P$`%P````08`0`+
M````'!@!`$H````H&`$`#````',8`0`?````@!@!`!H```"@&`$`$P```+L8
M`0`$````SQ@!``H```#4&`$`!````-\8`0`-````Y!@!``@```#R&`$`"@``
M`/L8`0`)````!AD!``D````0&0$`"````!H9`0`,````(QD!``D````P&0$`
M!0```#H9`0`)````0!D!``4```!*&0$`!P```%`9`0`%````6!D!``0```!>
M&0$``@```&,9`0`(````9AD!``P```!O&0$`.````'P9`0`L````M1D!`!(`
M``#B&0$`*0```/49`0`R````'QH!`"4```!2&@$`"@```'@:`0`L````@QH!
M`"X```"P&@$`,P```-\:`0`S````$QL!`#@```!'&P$`#P```(`;`0`8````
MD!L!``L```"I&P$`%````+4;`0`0````RAL!`"P```#;&P$`'`````@<`0`/
M````)1P!`!,````U'`$`%0```$D<`0`4````7QP!`!(```!T'`$`%````(<<
M`0`M````G!P!`"T```#*'`$`,0```/@<`0`N````*AT!`"\```!9'0$`+```
M`(D=`0!B````MAT!`!,````9'@$`#0```"T>`0`-````.QX!``@```!)'@$`
M%P```%(>`0`(````:AX!``P```!S'@$`*P```(`>`0`A````K!X!`!H```#.
M'@$`'````.D>`0`)````!A\!`$4````0'P$`00```%8?`0`$````F!\!`!,`
M``"='P$`%````+$?`0`.````QA\!`!,```#5'P$`&````.D?`0`&`````B`!
M``D````)(`$`"@```!,@`0`/````'B`!``D````N(`$`$````#@@`0`'````
M22`!``X```!1(`$`!0```&`@`0`;````9B`!``T```""(`$`"````)`@`0`#
M````F2`!``8```"=(`$`%````*0@`0`1````N2`!``X```#+(`$`.````-H@
M`0`"````$R$!``8````6(0$`#@```!TA`0`%````+"$!``<````R(0$`!@``
M`#HA`0`H````02$!``P```!J(0$`'````'<A`0`$````E"$!``(```"9(0$`
M)@```)PA`0`6````PR$!`!0```#:(0$`*0```.\A`0`?````&2(!`%P````Y
M(@$`%````)8B`0`^````JR(!`!\```#J(@$`$`````HC`0`(````&R,!`!(`
M```D(P$`!P```#<C`0`.````/R,!``P```!.(P$`#````%LC`0`3````:",!
M``H```!\(P$`'0```(<C`0`9````I2,!``4```"_(P$`$0```,4C`0`(````
MUR,!``4```#@(P$`$0```.8C`0`)````^",!`"0````")`$`$@```"<D`0`5
M````.B0!`!(```!0)`$`#@```&,D`0`9````<B0!``@```",)`$`"0```)4D
M`0`"````GR0!``T```"B)`$`"@```+`D`0`'````NR0!``\```##)`$`!@``
M`-,D`0`+````VB0!`!H```#F)`$`"@````$E`0`'````#"4!``@````4)0$`
M!0```!TE`0`?````(R4!``8```!#)0$`$````$HE`0`(````6R4!``T```!D
M)0$`"````'(E`0`>````>R4!`!(```":)0$`+````*TE`0`:````VB4!``D`
M``#U)0$`"@```/\E`0`5````"B8!`!`````@)@$`!0```#$F`0`4````-R8!
M``0```!,)@$`!P```%$F`0`0````628!``8```!J)@$`!P```'$F`0`>````
M>28!`"@```"8)@$`'@```,$F`0`*````X"8!`!P```#K)@$`$0````@G`0`+
M````&B<!`!H````F)P$`%````$$G`0`$````5B<!``0```!;)P$`"P```&`G
M`0`%````;"<!``8```!R)P$`"````'DG`0`&````@B<!`!L```"))P$`-```
M`*4G`0`T````VB<!`"`````/*`$`*0```#`H`0`@````6B@!`$$```![*`$`
M&@```+TH`0`H````V"@!`"D````!*0$`4````"LI`0`B````?"D!``8```"?
M*0$`"````*8I`0`%````KRD!``X```"U*0$`"````,0I`0`9````S2D!`!D`
M``#G*0$`*@````$J`0`C````+"H!`!D```!0*@$`+@```&HJ`0`T````F2H!
M``@```#.*@$`%P```-<J`0`*````[RH!``<```#Z*@$`(0````(K`0`,````
M)"L!``T````Q*P$`#````#\K`0`0````3"L!``X```!=*P$`"P```&PK`0`'
M````>"L!`!,```"`*P$`"````)0K`0`+````G2L!``H```"I*P$`%````+0K
M`0`/````R2L!`#(```#9*P$`"P````PL`0`%````&"P!``4````>+`$`!0``
M`"0L`0`7````*BP!``\```!"+`$`!````%(L`0`*````5RP!``D```!B+`$`
M"P```&PL`0`-````>"P!``P```"&+`$`#@```),L`0`%````HBP!``0```"H
M+`$`#0```*TL`0`R````NRP!`$4```#N+`$`"P```#0M`0`*````0"T!``\`
M``!++0$`$P```%LM`0`3````;RT!``\```"#+0$`#````),M`0`.````H"T!
M``T```"O+0$`#0```+TM`0`7````RRT!``<```#C+0$`'@```.LM`0`4````
M"BX!``4````?+@$`%````"4N`0`&````.BX!``<```!!+@$`#````$DN`0`0
M````5BX!`!$```!G+@$`#@```'DN`0`J````B"X!``8```"S+@$`"0```+HN
M`0`/````Q"X!``P```#4+@$`#0```.$N`0`1````[RX!``L````!+P$`-@``
M``TO`0`*````1"\!`"(```!/+P$`"P```'(O`0`/````?B\!`'T```".+P$`
M,@````PP`0`E````/S`!``@```!E,`$`,````&XP`0`Q````GS`!`"T```#1
M,`$`$@```/\P`0`.````$C$!``4````A,0$`#@```"<Q`0`3````-C$!`!$`
M``!*,0$`"````%PQ`0`2````93$!``<```!X,0$`$0```(`Q`0`3````DC$!
M``<```"F,0$`%````*XQ`0`8````PS$!``<```#<,0$`!0```.0Q`0`,````
MZC$!``P```#W,0$`$@````0R`0`$````%S(!``<````<,@$`"@```"0R`0`+
M````+S(!``P````[,@$`#@```$@R`0`.````5S(!``4```!F,@$`!0```&PR
M`0`N````<C(!`"8```"A,@$`(P```,@R`0`#````[#(!`!(```#P,@$`!@``
M``,S`0`>````"C,!`!@````I,P$`)0```$(S`0`-````:#,!``D```!V,P$`
M`P```(`S`0`'````A#,!``H```",,P$``@```)<S`0`,````FC,!`!4```"G
M,P$`"P```+TS`0`9````R3,!`"````#C,P$`$@````0T`0`%````%S0!``H`
M```=-`$`%0```"@T`0`2````/C0!``@```!1-`$`#````%HT`0`$````9S0!
M``D```!L-`$`!P```'8T`0`+````?C0!``X```"*-`$`"@```)DT`0`,````
MI#0!`%(```"Q-`$`%P````0U`0`D````'#4!`!(```!!-0$`!P```%0U`0`&
M````7#4!`!````!C-0$`#@```'0U`0`.````@S4!`"````"2-0$`#````+,U
M`0`9````P#4!``T```#:-0$`%0```.@U`0`2````_C4!``\````1-@$`%```
M`"$V`0`*````-C8!`!L```!!-@$`$````%TV`0`<````;C8!`%@```"+-@$`
M"P```.0V`0`A````\#8!`"4````2-P$`:0```#@W`0`:````HC<!`!<```"]
M-P$`&0```-4W`0`:````[S<!`!D````*.`$`)0```"0X`0`G````2C@!`!H`
M``!R.`$`%P```(TX`0`=````I3@!`"8```##.`$`&P```.HX`0`J````!CD!
M`!D````Q.0$`'P```$LY`0`3````:SD!``@```!_.0$`1````(@Y`0`3````
MS3D!`$````#A.0$`!P```"(Z`0`(````*CH!``D````S.@$`%0```#TZ`0`-
M````4SH!`",```!A.@$`#0```(4Z`0`3````DSH!``@```"G.@$``P```+`Z
M`0`,````M#H!`$8```#!.@$`%P````@[`0`.````(#L!`#\````O.P$`30``
M`&\[`0`W````O3L!`%<```#U.P$`!0```$T\`0`?````4SP!`"\```!S/`$`
M"@```*,\`0`3````KCP!`!````#"/`$`$0```-,\`0`(````Y3P!``T```#N
M/`$`+0```/P\`0`$````*CT!``T````O/0$`%0```#T]`0`[````4ST!`$\`
M``"//0$`'P```-\]`0`6````_ST!`"4````6/@$`*````#P^`0`+````93X!
M`",```!Q/@$`'P```)4^`0`A````M3X!`!T```#7/@$`)0```/4^`0`@````
M&S\!`"0````\/P$`(````&$_`0`P````@C\!``L```"S/P$`!P```+\_`0`-
M````QS\!``P```#5/P$`%P```.(_`0`&````^C\!``P````!0`$`!P````Y`
M`0`)````%D`!`!,````@0`$`"0```#1``0`$````/D`!`!````!#0`$`"```
M`%1``0`(````74`!``0```!F0`$`"P```&M``0`,````=T`!`!(```"$0`$`
M$0```)=``0`,````J4`!``\```"V0`$`!P```,9``0`-````SD`!`!0```#<
M0`$`#@```/%``0`,`````$$!`!L````-00$`+````"E!`0`3````5D$!``8`
M``!J00$`!P```'%!`0`3````>4$!``4```"-00$`!````)-!`0`7````F$$!
M``H```"P00$`#````+M!`0`)````R$$!``8```#200$`"0```-E!`0`&````
MXT$!``@```#J00$`"0```/-!`0`*````_4$!``@````(0@$`"@```!%"`0`*
M````'$(!``<````G0@$`$0```"]"`0`&````04(!``X```!(0@$`#@```%="
M`0`-````9D(!``L```!T0@$`'0```(!"`0`+````GD(!``(```"J0@$`'```
M`*U"`0`'````RD(!``8```#20@$`9````-E"`0`)````/D,!``<```!(0P$`
M)@```%!#`0`X````=T,!`!H```"P0P$`*@```,M#`0`[````]D,!`"@````R
M1`$`-````%M$`0`9````D$0!`!4```"J1`$`!0```,!$`0`'````QD0!``@`
M``#.1`$`!P```-=$`0`&````WT0!``4```#F1`$`!P```.Q$`0`.````]$0!
M``D````#10$`!@````U%`0`(````%$4!``L````=10$`!P```"E%`0`(````
M,44!``<````Z10$`%@```$)%`0`)````644!``8```!C10$`"P```&I%`0`0
M````=D4!``8```"'10$`'````(Y%`0`4````JT4!``<```#`10$`$0```,A%
M`0`(````VD4!``X```#C10$`"````/)%`0`%````^T4!`!`````!1@$`$```
M`!)&`0`&````(T8!`!D````J1@$`"@```$1&`0`<````3T8!``<```!L1@$`
M!0```'1&`0`0````>D8!`!0```"+1@$`"P```*!&`0`-````K$8!`"@```"Z
M1@$`&````.-&`0`7````_$8!``D````41P$`!````!Y'`0`)````(T<!``H`
M```M1P$`!P```#A'`0`"````0$<!``X```!#1P$`"````%)'`0`X````6T<!
M`",```"41P$`.````+A'`0`F````\4<!`#$````82`$`)P```$I(`0!D````
M<D@!`!0```#72`$`)````.Q(`0`C````$4D!`",````U20$`*P```%E)`0`A
M````A4D!`"0```"G20$`50```,Q)`0`X````(DH!`$H```!;2@$`6P```*9*
M`0`H`````DL!`#@````K2P$`+P```&1+`0!%````E$L!`$H```#:2P$`1@``
M`"5,`0`S````;$P!`"@```"@3`$`+````,E,`0`F````]DP!`!L````=30$`
M/@```#E-`0`Z````>$T!`",```"S30$`%P```-=-`0!(````[TT!`(4````X
M3@$`,````+Y.`0`E````[TX!`$$````53P$`6P```%=/`0!)````LT\!`#$`
M``#]3P$`:0```"]0`0`=````F5`!`!@```"W4`$`*P```-!0`0`A````_%`!
M`!\````>40$`*P```#Y1`0`A````:E$!`"<```",40$`.@```+11`0`=````
M[U$!`!$````-4@$`,P```!]2`0`E````4U(!`"<```!Y4@$`(````*%2`0`R
M````PE(!`!\```#U4@$`,````!53`0!I````1E,!`#$```"P4P$`00```.)3
M`0`S````)%0!`"4```!85`$`/0```'Y4`0!E````O%0!`$T````B50$`+0``
M`'!5`0`G````GE4!`"\```#&50$`*````/95`0`N````'U8!`#````!.5@$`
M5````']6`0`G````U%8!`%H```#\5@$`.@```%=7`0!(````DE<!`$H```#;
M5P$`'P```"98`0`R````1E@!`"\```!Y6`$`+````*E8`0`M````UE@!`!<`
M```$60$`)0```!Q9`0`R````0ED!`"D```!U60$`/@```)]9`0`B````WED!
M`%(````!6@$`(@```%1:`0`E````=UH!``L```"=6@$`L0```*E:`0`@````
M6UL!`$4```!\6P$`(0```,);`0`P````Y%L!`"4````57`$`'````#M<`0`Q
M````6%P!``<```"*7`$`"````))<`0`'````FUP!``0```"C7`$`"@```*A<
M`0`-````LUP!``L```#!7`$`#@```,U<`0`)````W%P!``L```#F7`$`!@``
M`/)<`0`%````^5P!`!````#_7`$``@```!!=`0!9````$UT!``4```!M70$`
M$@```'-=`0`$````AET!``<```"+70$`"````)-=`0`%````G%T!``,```"B
M70$`$````*9=`0`3````MUT!``T```#+70$``@```-E=`0`'````W%T!``<`
M``#D70$`!@```.Q=`0`4````\UT!``P````(7@$`&````!5>`0`&````+EX!
M``0````U7@$`$@```#I>`0`,````35X!``,```!:7@$`!````%Y>`0`&````
M8UX!``<```!J7@$`'P```')>`0`U````DEX!`"X```#(7@$`+P```/=>`0`7
M````)U\!`"(````_7P$`)0```&)?`0`@````B%\!`!L```"I7P$`&````,5?
M`0`D````WE\!`!\````#8`$`&@```"-@`0`A````/F`!`"````!@8`$`&@``
M`(%@`0`R````G&`!`!D```#/8`$`&@```.E@`0`O````!&$!`!0````T80$`
M*P```$EA`0`?````=6$!`",```"580$`'P```+EA`0`:````V6$!`"$```#T
M80$`)0```!9B`0`F````/&(!`"4```!C8@$`)````(EB`0`8````KF(!`!T`
M``#'8@$`)````.5B`0`8````"F,!`"(````C8P$`+````$9C`0`O````<V,!
M`!4```"C8P$`)0```+EC`0`9````WV,!`#P```#Y8P$`'P```#9D`0`C````
M5F0!`!\```!Z9`$`(````)ID`0`:````NV0!`"\```#69`$`&`````9E`0`F
M````'V4!`!X```!&90$`*0```&5E`0`>````CV4!`#$```"N90$`"0```.!E
M`0`,````ZF4!`!<```#W90$`+P````]F`0`D````/V8!``<```!D9@$`#P``
M`&QF`0`4````?&8!``X```"19@$`#0```*!F`0`D````KF8!``4```#39@$`
M!P```-EF`0`B````X68!`"4````$9P$`&@```"IG`0`=````16<!`!H```!C
M9P$`!P```'YG`0#'````AF<!``L```!.:`$`'````%IH`0`5````=V@!``8`
M``"-:`$`"0```)1H`0`+````GF@!``T```"J:`$`#````+AH`0`7````Q6@!
M``8```#=:`$`,P```.1H`0`3````&&D!`!,````L:0$`!P```$!I`0`/````
M2&D!``<```!8:0$`,@```&!I`0`$````DVD!`"$```"8:0$`$P```+II`0`.
M````SFD!``P```#=:0$`$0```.II`0`R````_&D!`!8````O:@$`"````$9J
M`0`=````3VH!``D```!M:@$`"@```'=J`0`4````@FH!``H```"7:@$`'0``
M`*)J`0`(````P&H!`!\```#):@$`"````.EJ`0`:````\FH!``8````-:P$`
M%0```!1K`0`'````*FL!``@````R:P$`"0```#MK`0`_````16L!``<```"%
M:P$`#P```(UK`0`.````G6L!`!````"L:P$`"0```+UK`0`)````QVL!``@`
M``#1:P$`$P```-IK`0`'````[FL!``@```#V:P$`&0```/]K`0`*````&6P!
M`!<````D;`$`%````#QL`0`*````46P!``P```!<;`$`%P```&EL`0`$````
M@6P!`"H```"&;`$`#````+%L`0`1````OFP!``<```#0;`$``@```-AL`0`0
M````VVP!`!@```#L;`$`"P````5M`0`#````$6T!``@````5;0$`"0```!YM
M`0`$````*&T!``<````M;0$`!P```#5M`0`&````/6T!`!0```!$;0$`!P``
M`%EM`0`-````86T!``L```!O;0$`%````'MM`0`5````D&T!``X```"F;0$`
M+P```+5M`0`@````Y6T!`!P````&;@$`2````"-N`0!,````;&X!`!4```"Y
M;@$`#````,]N`0`Q````W&X!``4````.;P$`$@```!1O`0`_````)V\!`!(`
M``!G;P$`"@```'IO`0`&````A6\!``0```",;P$`!````)%O`0`*````EF\!
M`!,```"A;P$`!0```+5O`0`&````NV\!``8```#";P$`"````,EO`0`$````
MTF\!``P```#7;P$`"@```.1O`0`)````[V\!`#D```#Y;P$`+@```#-P`0`9
M````8G`!`!\```!\<`$`'0```)QP`0`1````NG`!``(```#,<`$`!````,]P
M`0`*````U'`!``0```#?<`$`!@```.1P`0`4````ZW`!``4`````<0$``P``
M``9Q`0`,````"G$!`$4````7<0$`,@```%UQ`0`R````D'$!`"\```##<0$`
M&@```/-Q`0`Z````#G(!`#0```!)<@$`*````'YR`0!3````IW(!`),```#[
M<@$`+P```(]S`0!"````OW,!`#`````"=`$`+@```#-T`0`9````8G0!`"<`
M``!\=`$`.````*1T`0`X````W70!`#<````6=0$`<@```$YU`0`@````P74!
M`#4```#B=0$`(0```!AV`0!%````.G8!`#````"`=@$`*0```+%V`0`A````
MVW8!`"@```#]=@$`*0```"9W`0`F````4'<!`"4```!W=P$`*````)UW`0`H
M````QG<!`"(```#O=P$`*P```!)X`0!%````/G@!`$D```"$>`$`1@```,YX
M`0`\````%7D!`#````!2>0$`$@```(-Y`0`3````EGD!`!````"J>0$`>0``
M`+MY`0`)````-7H!`*$````_>@$`<P```.%Z`0!\````57L!`"L```#2>P$`
M5````/Y[`0`7````4WP!`!4```!K?`$`)P```(%\`0`6````J7P!``\```#`
M?`$`%P```-!\`0`?````Z'P!`$`````(?0$`'P```$E]`0`<````:7T!`%$`
M``"&?0$`&@```-A]`0`4````\WT!``H````(?@$`!0```!-^`0`&````&7X!
M``@````@?@$`$@```"E^`0`0````/'X!`!,```!-?@$`'0```&%^`0`/````
M?WX!``\```"/?@$`#P```)]^`0`&````KWX!``T```"V?@$`!````,1^`0`)
M````R7X!``L```#3?@$`!0```-]^`0`%````Y7X!``<```#K?@$`!0```/-^
M`0`4````^7X!``X````.?P$`!P```!U_`0`(````)7\!``\````N?P$`#0``
M`#Y_`0`*````3'\!``@```!7?P$`#````&!_`0`&````;7\!``\```!T?P$`
M!P```(1_`0`&````C'\!`!0```"3?P$`!@```*A_`0`&````KW\!``P```"V
M?P$`%P```,-_`0`(````VW\!`!D```#D?P$`$0```/Y_`0`*````$(`!`!@`
M```;@`$`$P```#2``0`<````2(`!`!$```!E@`$``P```'>``0`&````>X`!
M``0```""@`$`#P```(>``0`*````EX`!``H```"B@`$`!````*V``0`$````
MLH`!`!D```"W@`$`!P```-&``0`"````V8`!``(```#<@`$`$0```-^``0`)
M````\8`!``8```#[@`$`$@````*!`0`7````%8$!``8````M@0$``@```#2!
M`0`(````-X$!``0```!`@0$`#P```$6!`0`3````58$!``<```!I@0$`"P``
M`'&!`0`0````?8$!`!,```".@0$`!P```**!`0`1````JH$!``8```"\@0$`
M&````,.!`0`&````W($!`!,```#C@0$`$````/>!`0`2````"((!``(````;
M@@$`!@```!Z"`0`,````)8(!``D````R@@$`$0```#R"`0`B````3H(!``<`
M``!Q@@$`!P```'F"`0`+````@8(!`!,```"-@@$`!0```*&"`0`1````IX(!
M``(```"Y@@$`"P```+R"`0`$````R((!``L```#-@@$`!0```-F"`0`'````
MWX(!`&4!``#G@@$`"@```$V$`0`,````6(0!``H```!EA`$`!P```'"$`0`'
M````>(0!``<```"`A`$``@```(B$`0`1````BX0!`!@```"=A`$`*P```+:$
M`0`:````XH0!`!T```#]A`$`$P```!N%`0`1````+X4!`"D```!!A0$`#0``
M`&N%`0`0````>84!`!L```"*A0$`"0```*:%`0`2````L(4!``L```##A0$`
M$0```,^%`0`'````X84!``4```#IA0$`$@```.^%`0`'`````H8!``<````*
MA@$`"P```!*&`0`)````'H8!``L````HA@$`"P```#2&`0`2````0(8!`#P`
M``!3A@$`"0```)"&`0`%````FH8!``H```"@A@$`#P```*N&`0`*````NX8!
M``H```#&A@$`"@```-&&`0`*````W(8!``8```#GA@$`60```.Z&`0`N````
M2(<!`!(```!WAP$`#@```(J'`0`'````F8<!``P```"AAP$`$@```*Z'`0`*
M````P8<!``P```#,AP$`"````-F'`0`&````XH<!``D```#IAP$`!P```/.'
M`0`'````^X<!``D````#B`$`"0````V(`0`'````%X@!``8````?B`$`(@``
M`":(`0`>````28@!`!X```!HB`$`'````(>(`0`=````I(@!`!0```#"B`$`
M)0```->(`0`M````_8@!`$`````KB0$`1````&R)`0!$````L8D!`$H```#V
MB0$`)P```$&*`0`$````:8H!``@```!NB@$`"````'>*`0`(````@(H!``@`
M``")B@$`"````)**`0`)````FXH!``@```"EB@$`#@```*Z*`0`'````O8H!
M``8```#%B@$`!@```,R*`0`&````TXH!`!L```#:B@$`&P```/:*`0`(````
M$HL!``H````;BP$`"P```":+`0`$````,HL!``H````WBP$`!````$*+`0`*
M````1XL!``H```!2BP$`"````%V+`0`)````9HL!``@```!PBP$`"````'F+
M`0`1````@HL!`!````"4BP$`$@```*6+`0`*````N(L!``\```##BP$`#```
M`-.+`0`(````X(L!``T```#IBP$`!@```/>+`0`9````_HL!``\````8C`$`
M$````"B,`0`*````.8P!`#,```!$C`$`*P```'B,`0`;````I(P!``0```#`
MC`$`!@```,6,`0`A````S(P!``0```#NC`$`!````/.,`0`(````^(P!`!0`
M```!C0$`!````!:-`0`+````&XT!``T````GC0$`#0```#6-`0`+````0XT!
M``H```!/C0$`#````%J-`0`,````9XT!``H```!TC0$`"````'^-`0`/````
MB(T!``@```"8C0$`%````*&-`0`4````MHT!``@```#+C0$`!````-2-`0`)
M````V8T!``0```#CC0$`#````.B-`0`2````]8T!``@````(C@$`"````!&.
M`0`(````&HX!``@````CC@$`"@```"R.`0`$````-XX!``H````\C@$`"```
M`$>.`0`&````4(X!`!8```!7C@$`%P```&Z.`0`&````AHX!``X```"-C@$`
M#@```)R.`0`0````JXX!`!````"\C@$`"````,V.`0`(````UHX!`!T```#?
MC@$`$P```/V.`0`5````$8\!`!`````GCP$`#P```#B/`0`3````2(\!``P`
M``!<CP$`!````&F/`0`5````;H\!`"H```"$CP$`!````*^/`0`(````M(\!
M``P```"]CP$`#@```,J/`0`2````V8\!``0```#LCP$`"````/&/`0`$````
M^H\!`!<```#_CP$`"@```!>0`0`*````(I`!`!H````MD`$`)````$B0`0`2
M````;9`!`!(```"`D`$`%@```).0`0`$````JI`!`!````"OD`$`$````,"0
M`0`(````T9`!``\```#:D`$`&P```.J0`0`(````!I$!``0````/D0$`A@``
M`!21`0`9````FY$!`!D```"UD0$`&0```,^1`0`9````Z9$!``@````#D@$`
M"`````R2`0`$````%9(!``0````:D@$`%````!^2`0`0````-)(!`"H```!%
MD@$`(P```'"2`0`I````E)(!`&L```"^D@$`*````"J3`0`H````4Y,!`#$`
M``!\DP$`,0```*Z3`0`H````X),!`"D````)E`$`'````#.4`0`<````4)0!
M`#$```!ME`$`*````)^4`0`N````R)0!`!0```#WE`$`"0````R5`0`,````
M%I4!`!`````CE0$`#0```#25`0`-````0I4!``L```!0E0$`%0```%R5`0`$
M````<I4!``@```!WE0$`$@```("5`0`8````DY4!`!````"LE0$`#@```+V5
M`0`8````S)4!`!,```#EE0$`$0```/F5`0`4````"Y8!``0````@E@$`"```
M`"66`0`'````+I8!`!`````VE@$`#P```$>6`0`,````5Y8!`!````!DE@$`
M#0```'66`0`$````@Y8!`"$```"(E@$`"````*J6`0`(````LY8!``0```"\
ME@$`$@```,&6`0`$````U)8!``0```#9E@$`"````-Z6`0`$````YY8!`"T`
M``#LE@$`!````!J7`0`1````'Y<!``0````QEP$`#0```#:7`0`-````1)<!
M`!X```!2EP$`&````'&7`0`3````BI<!``@```">EP$`&0```*>7`0`0````
MP9<!``0```#2EP$`"````->7`0`#````X)<!``H```#DEP$`"````.^7`0`/
M````^)<!`!,````(F`$`"````!R8`0`&````)9@!``H````LF`$`$0```#>8
M`0`&````29@!`!<```!0F`$`!@```&B8`0`1````;Y@!`!$```"!F`$`)@``
M`).8`0`1````NI@!`!H```#,F`$`#@```.>8`0`2````]I@!``\````)F0$`
M!````!F9`0`,````'ID!``8````KF0$`"@```#*9`0`2````/9D!``\```!0
MF0$`(P```&"9`0`2````A)D!`!H```"7F0$`,0```+*9`0`9````Y)D!`!,`
M``#^F0$`"````!*:`0`&````&YH!``H````BF@$`!````"V:`0`9````,IH!
M``@```!,F@$`"@```%6:`0`+````8)H!``H```!LF@$`"P```'>:`0`(````
M@YH!`!8```",F@$`!````*.:`0`E````J)H!`!$```#.F@$`"````.":`0`*
M````Z9H!``@```#TF@$`"P```/V:`0`$````"9L!``P````.FP$`&P```!N;
M`0`M````-YL!``0```!EFP$`#0```&J;`0`,````>)L!``P```"%FP$`$0``
M`)*;`0`/````I)L!``T```"TFP$`"````,*;`0`2````RYL!``T```#>FP$`
M*````.R;`0`D````%9P!`!<````ZG`$`$@```%*<`0`>````99P!`"(```"$
MG`$`'@```*><`0`3````QIP!`!D```#:G`$`%0```/2<`0`"````"IT!`!0`
M```-G0$`"````"*=`0`0````*YT!``X````\G0$`"@```$N=`0`0````5IT!
M``8```!GG0$`#@```&Z=`0`4````?9T!``@```"2G0$`!````)N=`0`&````
MH)T!``(```"GG0$`%P```*J=`0`*````PIT!``@```#-G0$`$P```-:=`0`$
M````ZIT!``8```#OG0$`#@```/:=`0`#````!9X!``@````)G@$`!````!*>
M`0`*````%YX!``0````BG@$`"````">>`0`$````,)X!``0````UG@$`$```
M`#J>`0`$````2YX!``0```!0G@$`!````%6>`0`$````6IX!``0```!?G@$`
M-````&2>`0`-````F9X!``<```"GG@$`"````*^>`0`8````N)X!``8```#1
MG@$`#````-B>`0`R````Y9X!``D````8GP$`"@```"*?`0`;````+9\!`"D`
M``!)GP$`&@```'.?`0`&````CI\!`!\```"5GP$`%````+6?`0`-````RI\!
M``0```#8GP$`%P```-V?`0`$````]9\!``P```#ZGP$`!`````>@`0`6````
M#*`!`!<````CH`$`&````#N@`0`5````5*`!`!D```!JH`$`%P```(2@`0`7
M````G*`!`!(```"TH`$`%````,>@`0`4````W*`!`!````#QH`$`%@````*A
M`0`B````&:$!`!0````\H0$`$P```%&A`0`5````9:$!`!(```![H0$`%```
M`(ZA`0`6````HZ$!`!T```"ZH0$`%0```-BA`0`7````[J$!`!D````&H@$`
M$@```""B`0`2````,Z(!`!T```!&H@$`%0```&2B`0`,````>J(!`!<```"'
MH@$`$@```)^B`0`6````LJ(!``P```#)H@$`2P```-:B`0`G````(J,!`!(`
M``!*HP$`%````%VC`0`4````<J,!`!@```"'HP$`#0```*"C`0`2````KJ,!
M`!,```#!HP$`$0```-6C`0`5````YZ,!`!D```#]HP$`%````!>D`0!,````
M+*0!`!8```!YI`$`#@```)"D`0`2````GZ0!`!0```"RI`$`&0```,>D`0`J
M````X:0!`"T````,I0$`!@```#JE`0`$````0:4!``0```!&I0$`!````$NE
M`0`*````4*4!``P```!;I0$`#````&BE`0`,````=:4!``P```""I0$`!```
M`(^E`0`,````E*4!``H```"AI0$`$@```*RE`0`+````OZ4!``0```#+I0$`
M"````-"E`0`(````V:4!``@```#BI0$`#````.NE`0`(````^*4!``P````!
MI@$`"@````ZF`0`?````&:8!``0````YI@$`!````#ZF`0`1````0Z8!`!$`
M``!5I@$`%P```&>F`0`:````?Z8!`!L```":I@$``@```+:F`0!5````N:8!
M``0````/IP$`!@```!2G`0`,````&Z<!``H````HIP$`!````#.G`0`(````
M.*<!``@```!!IP$``@```$JG`0`"````3:<!``8```!0IP$`"@```%>G`0`&
M````8J<!``H```!IIP$`!````'2G`0`(````>:<!``0```""IP$`"@```(>G
M`0`(````DJ<!``X```";IP$`%0```*JG`0`$````P*<!``0```#%IP$`!P``
M`,JG`0`*````TJ<!``@```#=IP$`"````.:G`0`(````[Z<!``@```#XIP$`
M#@````&H`0`*````$*@!``@````;J`$`$@```"2H`0`.````-Z@!`"````!&
MJ`$`!@```&>H`0`8````;J@!``X```"'J`$`,P```):H`0`,````RJ@!`!4`
M``#7J`$`"````.VH`0`.````]J@!``8````%J0$`"`````RI`0`$````%:D!
M`!T````:J0$`%P```#BI`0`$````4*D!``@```!5J0$`%@```%ZI`0`*````
M=:D!``@```"`J0$`"````(FI`0`$````DJD!``0```"7J0$`$0```)RI`0`*
M````KJD!``@```"YJ0$`#@```,*I`0`.````T:D!``@```#@J0$`"````.FI
M`0`1````\JD!``8````$J@$`'`````NJ`0`>````**H!``8```!'J@$`*0``
M`$ZJ`0`3````>*H!`",```",J@$`$P```+"J`0`$````Q*H!``<```#)J@$`
M'````-&J`0`*````[JH!``0```#YJ@$`"````/ZJ`0`$````!ZL!``@````,
MJP$`!````!6K`0`2````&JL!``0````MJP$`!P```#*K`0`,````.JL!``@`
M``!'JP$`"@```%"K`0`(````6ZL!``@```!DJP$`"````&VK`0`,````=JL!
M``X```"#JP$`#````)*K`0`.````GZL!``@```"NJP$`#@```+>K`0`,````
MQJL!``0```#3JP$`#````-BK`0`6````Y:L!``<```#\JP$`"`````2L`0`,
M````#:P!`!4````:K`$`#````#"L`0`3````/:P!``@```!1K`$`"0```%JL
M`0`)````9*P!``P```!NK`$`!@```'NL`0`J````@JP!`!,```"MK`$`"```
M`,&L`0`&````RJP!``@```#1K`$`"````-JL`0`*````XZP!`#P```#NK`$`
M$@```"NM`0`>````/JT!`!0```!=K0$`!````'*M`0`4````=ZT!`!L```",
MK0$`&P```*BM`0`6````Q*T!`!P```#;K0$`%P```/BM`0`5````$*X!`!(`
M```FK@$`$P```#FN`0`$````3:X!``T```!2K@$`"P```&"N`0`+````;*X!
M``L```!XK@$`#P```(2N`0`9````E*X!`!4```"NK@$`"@```,2N`0`)````
MSZX!``H```#9K@$`"0```.2N`0`(````[JX!``H```#WK@$`"0````*O`0`'
M````#*\!``0````4KP$`!````!FO`0`(````'J\!``H````GKP$`"````#*O
M`0`&````.Z\!``8```!"KP$`!````$FO`0`*````3J\!``@```!9KP$`#0``
M`&*O`0`0````<*\!`!<```"!KP$`%@```)FO`0`0````L*\!`!````#!KP$`
M&P```-*O`0`0````[J\!``P```#_KP$`!`````RP`0`N````$;`!``T```!`
ML`$`"0```$ZP`0`$````6+`!``0```!=L`$`!````&*P`0`$````9[`!``8`
M``!LL`$`!@```'.P`0`(````>K`!``@```"#L`$`"P```(RP`0`3````F+`!
M`!$```"LL`$`"````+ZP`0`(````Q[`!``@```#0L`$`"````-FP`0`5````
MXK`!``8```#XL`$`!````/^P`0`.````!+$!``8````3L0$`!````!JQ`0`(
M````'[$!``@````HL0$`!````#&Q`0`"````-K$!``X````YL0$`"````$BQ
M`0`$````4;$!`!L```!6L0$`#@```'*Q`0!.````@;$!``H```#0L0$`!```
M`-NQ`0`$````X+$!``@```#EL0$`!````.ZQ`0`&````\[$!``0```#ZL0$`
M"````/^Q`0`&````"+(!``0````/L@$`#0```!2R`0`4````(K(!``0````W
ML@$`#````#RR`0`:````2;(!`"$```!DL@$`&P```(:R`0`&````HK(!``8`
M``"IL@$``@```+"R`0`(````L[(!``0```"\L@$`!````,&R`0`*````QK(!
M``P```#1L@$`!0```-ZR`0`/````Y+(!``0```#TL@$`!````/FR`0`2````
M_K(!`!`````1LP$`%@```"*S`0`.````.;,!``P```!(LP$`%````%6S`0`$
M````:K,!``0```!OLP$`!@```'2S`0`+````>[,!``L```"'LP$`!P```).S
M`0`$````F[,!``T```"@LP$`$P```*ZS`0`4````PK,!`!(```#7LP$`"```
M`.JS`0`0````\[,!`"D````$M`$`&P```"ZT`0`;````2K0!``0```!FM`$`
M%0```&NT`0`+````@;0!`!0```"-M`$`"````**T`0`(````J[0!``@```"T
MM`$`#P```+VT`0`@````S;0!``\```#NM`$`#````/ZT`0`1````"[4!``P`
M```=M0$`"0```"JU`0`"````-+4!``0````WM0$`!````#RU`0`A````0;4!
M``8```!CM0$`%P```&JU`0`$````@K4!``0```"'M0$`#@```(RU`0`$````
MF[4!``0```"@M0$`$0```*6U`0`$````M[4!``8```"\M0$``@```,.U`0`$
M````QK4!`!$```#+M0$``@```-VU`0`(````X+4!``8```#IM0$`"````/"U
M`0`3````^;4!`!`````-M@$`!0```!ZV`0`P````)+8!`!X```!5M@$`+```
M`'2V`0`A````H;8!`"X```##M@$`)@```/*V`0`A````&;<!`#$````[MP$`
M(0```&VW`0`=````C[<!`!P```"MMP$`!@```,JW`0`(````T;<!``4```#:
MMP$``@```."W`0`6````X[<!`!L```#ZMP$`%0```!:X`0`B````++@!``T`
M``!/N`$`$0```%VX`0`$````;[@!``8```!TN`$`"````'NX`0`0````A+@!
M`!4```"5N`$`%0```*NX`0`=````P;@!``<```#?N`$`$````.>X`0`@````
M^+@!``X````9N0$`#@```"BY`0`&````-[D!``@````^N0$`"@```$>Y`0`/
M````4KD!`#````!BN0$`:0```).Y`0`^````_;D!`'X````\N@$`"0```+NZ
M`0`(````Q;H!``D```#.N@$`#````-BZ`0`-````Y;H!``@```#SN@$`!```
M`/RZ`0`2`````;L!``T````4NP$`#P```"*[`0`,````,KL!``D````_NP$`
M#@```$F[`0`3````6+L!`!H```!LNP$`1@```(>[`0`(````SKL!``P```#7
MNP$`"@```.2[`0`0````[[L!``0`````O`$`!`````6\`0`-````"KP!`!``
M```8O`$`"````"F\`0`(````,KP!``P````[O`$`$````$B\`0`<````6;P!
M`!P```!VO`$`&````).\`0`8````K+P!`!H```#%O`$`&@```."\`0`.````
M^[P!`!L````*O0$`$````":]`0`0````-[T!``X```!(O0$`#@```%>]`0`(
M````9KT!``X```!OO0$`#@```'Z]`0`,````C;T!``P```":O0$`#P```*>]
M`0`-````M[T!`!$```#%O0$`(0```->]`0`)````^;T!``0````#O@$`!@``
M``B^`0`;````#[X!`!`````KO@$`#P```#R^`0`/````3+X!``\```!<O@$`
M#@```&R^`0`.````>[X!``T```"*O@$`"P```)B^`0`0````I+X!`!8```"U
MO@$`$P```,R^`0`-````X+X!`!$```#NO@$`#0````"_`0`/````#K\!`!$`
M```>OP$`#P```#"_`0`/````0+\!`!$```!0OP$`!````&*_`0`(````9[\!
M`"````!POP$`#0```)&_`0`0````G[\!`!(```"POP$`"````,._`0`/````
MS+\!``8```#<OP$`!````.._`0`.````Z+\!`!````#WOP$`!`````C``0`,
M````#<`!`!(````:P`$`!@```"W``0`-````-,`!``0```!"P`$`!````$?`
M`0`$````3,`!``0```!1P`$`"````%;``0`(````7\`!``@```!HP`$`"@``
M`''``0`*````?,`!``P```"'P`$`$@```)3``0`(````I\`!``@```"PP`$`
M"````+G``0`(````PL`!``@```#+P`$`"````-3``0`H````W<`!``8````&
MP0$`!`````W!`0`3````$L$!`"T````FP0$`&0```%3!`0`-````;L$!``\`
M``!\P0$`"@```(S!`0`*````E\$!``0```"BP0$`)P```*?!`0`,````S\$!
M``8```#<P0$`#````./!`0`&````\,$!`!(```#WP0$`!@````K"`0`)````
M$<(!``8````;P@$`#@```"+"`0`4````,<(!`!8```!&P@$`!@```%W"`0`1
M````9,(!``0```!VP@$`"````'O"`0`0````A,(!``0```"5P@$`"````)K"
M`0`&````H\(!`!````"JP@$`$@```+O"`0`?````SL(!`!H```#NP@$`!```
M``G#`0`$````#L,!``@````3PP$`"````!S#`0`&````)<,!``@````LPP$`
M!````#7#`0`&````.L,!``8```!!PP$`$0```$C#`0`$````6L,!``D```!?
MPP$`(````&G#`0`$````BL,!`!\```"/PP$`"@```*_#`0`,````NL,!``@`
M``#'PP$`#P```-##`0`-````X,,!`!$```#NPP$`#P````#$`0`/````$,0!
M``T````@Q`$`$0```"[$`0`0````0,0!`!(```!1Q`$`%@```&3$`0`$````
M>\0!`!(```"`Q`$`!@```)/$`0`)````FL0!``H```"DQ`$`"@```*_$`0`$
M````NL0!``0```"_Q`$`!````,3$`0`$````R<0!``@```#.Q`$`+0```-?$
M`0`)````!<4!``0````/Q0$`!````!3%`0`"````&<4!``P````<Q0$`#```
M`"G%`0`,````-L4!`!,```!#Q0$``@```%?%`0`(````6L4!`!L```!CQ0$`
M`P```'_%`0`,````@\4!`#D```"0Q0$`%P```,K%`0`$````XL4!``0```#G
MQ0$`"````.S%`0`-````]<4!``\````#Q@$`$P```!/&`0`3````)\8!``L`
M```[Q@$`#@```$?&`0`3````5L8!`"````!JQ@$`"@```(O&`0`-````EL8!
M``0```"DQ@$`!````*G&`0`2````KL8!`"0```#!Q@$`'0```.;&`0`7````
M!,<!``H````<QP$`%P```"?'`0`4````/\<!``\```!4QP$`%P```&3'`0`8
M````?,<!`!<```"5QP$`#````*W'`0`,````NL<!``P```#'QP$`!````-3'
M`0`2````V<<!``(```#LQP$`!````._'`0`$````],<!``0```#YQP$`"```
M`/['`0`&````!\@!``D````.R`$`"@```!C(`0`$````(\@!`"X````HR`$`
M"P```%?(`0`(````8\@!`!,```!LR`$`*P```(#(`0`1````K,@!``0```"^
MR`$`$@```,/(`0`:````UL@!``0```#QR`$`#P```/;(`0`N````!LD!``0`
M```UR0$`"0```#K)`0`8````1,D!`!<```!=R0$`%````'7)`0`$````BLD!
M``0```"/R0$`!````)3)`0`>````F<D!`#4```"XR0$`$````.[)`0`<````
M_\D!`!`````<R@$`!@```"W*`0`(````-,H!``0````]R@$`"````$+*`0`(
M````2\H!``0```!4R@$`'P```%G*`0`/````><H!``8```")R@$`#P```)#*
M`0`"````H,H!``8```"CR@$`!@```*K*`0`$````L<H!``P```"VR@$`!@``
M`,/*`0`(````RLH!``@```#3R@$`"````-S*`0`$````Y<H!`",```#JR@$`
M!@````[+`0`(````%<L!``@````>RP$`"````"?+`0`$````,,L!``0````U
MRP$`!````#K+`0`$````/\L!``0```!$RP$`!````$G+`0`5````3LL!`!``
M``!DRP$`*0```'7+`0`$````G\L!``@```"DRP$`#````*W+`0`*````NLL!
M``L```#%RP$`$0```-'+`0`(````X\L!`!````#LRP$`#@```/W+`0`+````
M#,P!``0````8S`$`$@```!W,`0`,````,,P!``X````]S`$`$@```$S,`0`C
M````7\P!`!4```"#S`$`%0```)G,`0`5````K\P!`!$```#%S`$`$0```-?,
M`0`7````Z<P!`!,````!S0$`$0```!7-`0`(````)\T!``0````PS0$`'```
M`#7-`0`(````4LT!``8```!;S0$`"0```&+-`0`$````;,T!`!4```!QS0$`
M%````(?-`0`I````G,T!``8```#&S0$`$0```,W-`0`-````W\T!``\```#M
MS0$`!````/W-`0`(`````LX!``8````+S@$`#````!+.`0`&````'\X!``8`
M```FS@$`!@```"W.`0`&````-,X!``8````[S@$`"@```$+.`0`&````3<X!
M``8```!4S@$`%````%O.`0`,````<,X!`!(```!]S@$`!````)#.`0`-````
ME<X!``(```"CS@$``@```*;.`0`,````J<X!`!D```"VS@$`&@```-#.`0`-
M````Z\X!`!H```#YS@$`(0```!3/`0`;````-L\!``D```!2SP$`&P```%S/
M`0`7````>,\!`!P```"0SP$`&P```*W/`0`@````R<\!``L```#JSP$`"P``
M`/;/`0`$`````M`!``X````'T`$`"@```!;0`0`;````(=`!`!8````]T`$`
M"P```%30`0`0````8-`!`!$```!QT`$`"P```(/0`0`+````C]`!``L```";
MT`$`&P```*?0`0`;````P]`!`!\```#?T`$`'````/_0`0`=````'-$!`!H`
M```ZT0$`2````%71`0`3````GM$!``X```"RT0$``@```,'1`0`&````Q-$!
M`!4```#+T0$`!@```.'1`0`(````Z-$!`!,```#QT0$`%P````72`0`7````
M'=(!`!0````UT@$`!@```$K2`0`K````4=(!`"T```!]T@$``@```*O2`0`1
M````KM(!`!8```#`T@$`&0```-?2`0`&````\=(!`!@```#XT@$`#0```!'3
M`0`&````'],!``8````FTP$`#````"W3`0`&````.M,!``T```!!TP$`!@``
M`$_3`0`(````5M,!``8```!?TP$`$@```&;3`0`(````>=,!``8```""TP$`
M!````(G3`0`$````CM,!``8```"3TP$`"````)K3`0`$````H],!`!D```"H
MTP$``@```,+3`0`$````Q=,!``H```#*TP$`!@```-73`0`$````W-,!``8`
M``#ATP$`%P```.C3`0`&`````-0!``P````'U`$`"P```!34`0`"````(-0!
M`!8````CU`$`$P```#K4`0`0````3M0!`",```!?U`$`$P```(/4`0`F````
ME]0!``X```"^U`$`+0```,W4`0`2````^]0!``@````.U0$`!@```!?5`0`.
M````'M4!``0````MU0$`!@```#+5`0`(````.=4!``0```!"U0$`"````$?5
M`0`$````4-4!`!````!5U0$`%````&;5`0`$````>]4!``@```"`U0$`!```
M`(G5`0`&````CM4!``H```"5U0$`"@```*#5`0`-````J]4!`!````"YU0$`
M#````,K5`0`,````U]4!``P```#DU0$`%@```/'5`0`*````"-8!``@````3
MU@$`!````!S6`0`(````(=8!``@````JU@$`"````#/6`0`(````/-8!``8`
M``!%U@$`"````$S6`0`4````5=8!``H```!JU@$`!````'76`0`3````>M8!
M``P```".U@$`,````)O6`0`/````S-8!`"$```#<U@$`$0```/[6`0`$````
M$-<!``0````5UP$`#0```!K7`0`*````*-<!`!T````SUP$`"````%'7`0`%
M````6M<!``8```!@UP$`#0```&?7`0`.````==<!``0```"$UP$`!````(G7
M`0`$````CM<!``0```"3UP$`"@```)C7`0`$````H]<!``8```"HUP$`#```
M`*_7`0`3````O-<!``\```#0UP$`!````.#7`0`3````Y=<!``@```#YUP$`
M!`````+8`0`(````!]@!``0````0V`$`"P```!78`0`$````(=@!`!0````F
MV`$`!````#O8`0`$````0-@!``@```!%V`$`!````$[8`0`0````4]@!`!,`
M``!DV`$`&P```'C8`0`5````E-@!`!4```"JV`$`&````,#8`0`F````V=@!
M`!4`````V0$`$0```!;9`0`:````*-D!`"X```!#V0$`$P```'+9`0`-````
MAMD!``0```"4V0$`!````)G9`0`,````GMD!`!$```"KV0$`"````+W9`0`(
M````QMD!`"L```#/V0$`%@```/O9`0`.````$MH!`"D````AV@$`+P```$O:
M`0`$````>]H!``P```"`V@$`!@```(W:`0`$````E-H!`!(```"9V@$`!@``
M`*S:`0`&````L]H!``8```"ZV@$`"@```,':`0`(````S-H!``@```#5V@$`
M!````-[:`0`(````X]H!``0```#LV@$`"````/':`0`(````^MH!``P````#
MVP$`#````!#;`0`:````'=L!`!8````XVP$`#````$_;`0`$````7-L!``@`
M``!AVP$`%@```&K;`0`&````@=L!``(```"(VP$`!@```(O;`0`&````DML!
M``0```"9VP$`!@```)[;`0`&````I=L!``@```"LVP$`!````+7;`0`$````
MNML!``@```"_VP$`)0```,C;`0`R````[ML!``@````AW`$`!````"K<`0`(
M````+]P!``H````XW`$`"````$/<`0`(````3-P!``@```!5W`$`"````%[<
M`0`(````9]P!``@```!PW`$`"````'G<`0`(````@MP!`!4```"+W`$`%0``
M`*'<`0`*````M]P!``H```#"W`$`!````,W<`0`$````TMP!``@```#7W`$`
M"@```.#<`0`+````Z]P!``H```#WW`$`*`````+=`0`$````*]T!``<````P
MW0$`#````#C=`0`(````1=T!``@```!.W0$`"````%?=`0`&````8-T!`"<`
M``!GW0$`!````(_=`0`4````E-T!``H```"IW0$`#@```+3=`0!8````P]T!
M`!<````<W@$`$0```#3>`0`&````1MX!`!H```!-W@$`%P```&C>`0`5````
M@-X!``P```"6W@$`"````*/>`0`$````K-X!``@```"QW@$`#0```+K>`0`,
M````R-X!``0```#5W@$`$````-K>`0`$````Z]X!``@```#PW@$`#@```/G>
M`0`2````"-\!``@````;WP$`#@```"3?`0`$````,]\!``0````XWP$`"```
M`#W?`0`&````1M\!``L```!-WP$`!````%G?`0`2````7M\!``L```!QWP$`
M$````'W?`0`0````CM\!``8```"?WP$`!@```*;?`0`"````K=\!``0```"P
MWP$`#````+7?`0`(````PM\!``8```#+WP$`!````-+?`0`;````U]\!``\`
M``#SWP$`#P````/@`0`6````$^`!``X````JX`$`!````#G@`0`*````/N`!
M``H```!)X`$`!````%3@`0`,````6>`!``8```!FX`$`%P```&W@`0`L````
MA>`!`!8```"RX`$`&0```,G@`0`S````X^`!`!(````7X0$`$@```"KA`0`5
M````/>$!`"@```!3X0$`"@```'SA`0`&````A^$!`!L```".X0$`!````*KA
M`0`)````K^$!``<```"YX0$`"````,'A`0`(````RN$!``@```#3X0$`"```
M`-SA`0`X````Y>$!``\````>X@$`%P```"[B`0`(````1N(!``0```!/X@$`
M!````%3B`0`*````6>(!``@```!DX@$`"````&WB`0`/````=N(!``@```"&
MX@$`$@```(_B`0`,````HN(!`!0```"OX@$`$@```,3B`0`.````U^(!`!8`
M``#FX@$`"````/WB`0`1````!N,!``P````8XP$`$P```"7C`0`H````.>,!
M``8```!BXP$`%P```&GC`0`2````@>,!`$,```"4XP$`#0```-CC`0`1````
MYN,!``T```#XXP$`$P````;D`0`1````&N0!`!4````LY`$`%0```$+D`0`-
M````6.0!`!$```!FY`$`%````'CD`0`7````C>0!`!<```"EY`$`'P```+WD
M`0`0````W>0!``T```#NY`$`#````/SD`0`(````">4!`"X````2Y0$`$0``
M`$'E`0`S````4^4!`!(```"'Y0$`"````)KE`0`$````H^4!`"P```"HY0$`
M!````-7E`0`;````VN4!``@```#VY0$`#P```/_E`0`$````#^8!``@````4
MY@$`#````!WF`0`H````*N8!``X```!3Y@$`#````&+F`0`A````;^8!`!X`
M``"1Y@$`(P```+#F`0`Z````U.8!``0````/YP$`#````!3G`0`<````(><!
M`!,````^YP$`#0```%+G`0`*````8.<!`!$```!KYP$`!````'WG`0`(````
M@N<!`"$```"+YP$`!````*WG`0`*````LN<!`!0```"]YP$`,@```-+G`0`?
M````!>@!`!<````EZ`$`&0```#WH`0`@````5^@!`!L```!XZ`$`"@```)3H
M`0`6````G^@!`!0```"VZ`$`&0```,OH`0`5````Y>@!`!8```#[Z`$`%```
M`!+I`0`2````)^D!`!0````ZZ0$`(@```$_I`0`(````<ND!``@```![Z0$`
M"````(3I`0`(````C>D!``H```"6Z0$`!````*'I`0`7````IND!``0```"^
MZ0$`!````,/I`0`(````R.D!`!(```#1Z0$`!````.3I`0`(````Z>D!`!,`
M``#RZ0$`%0````;J`0`"````'.H!``0````?Z@$`!````"3J`0`(````*>H!
M``@````RZ@$`"@```#OJ`0`<````1NH!`!(```!CZ@$`!@```';J`0`,````
M?>H!``@```"*Z@$`$P```)/J`0`1````I^H!`"P```"YZ@$`!@```.;J`0`&
M````[>H!``0```#TZ@$`"@```/GJ`0`.````!.L!``@````3ZP$`#````!SK
M`0`(````*>L!``@````RZP$`!@```#OK`0`$````0NL!`!0```!'ZP$`"```
M`%SK`0`$````9>L!``H```!JZP$`"````'7K`0`&````?NL!``@```"%ZP$`
M"````([K`0`&````E^L!``(```">ZP$`!````*'K`0`(````INL!``0```"O
MZP$`!@```+3K`0`&````N^L!`!@```#"ZP$`"@```-OK`0`&````YNL!`!$`
M``#MZP$`!````/_K`0`$````!.P!`#\````)[`$`!````$GL`0`$````3NP!
M`!D```!3[`$`)0```&WL`0`/````D^P!`!@```"C[`$`)0```+SL`0`5````
MXNP!`!@```#X[`$`#P```!'M`0`/````(>T!``P````Q[0$`!````#[M`0`$
M````0^T!``0```!([0$`!@```$WM`0`"````5.T!``0```!7[0$`"0```%SM
M`0`&````9NT!``0```!M[0$`!@```'+M`0`$````>>T!``0```!^[0$`$0``
M`(/M`0`$````E>T!`!8```":[0$`%````+'M`0`-````QNT!`!(```#4[0$`
M#@```.?M`0`,````]NT!`!0````#[@$`'0```!CN`0`$````-NX!``@````[
M[@$`!````$3N`0`,````2>X!`!````!6[@$`!````&?N`0`(````;.X!``@`
M``!U[@$`!````'[N`0`$````@^X!`!4```"([@$`)P```)[N`0`%````QNX!
M``@```#,[@$`"````-7N`0`2````WNX!``0```#Q[@$`!@```/;N`0`A````
M_>X!`!`````?[P$`"````##O`0`$````.>\!``0````^[P$`!@```$/O`0`(
M````2N\!``P```!3[P$`!@```&#O`0`.````9^\!``\```!V[P$`'P```(;O
M`0`8````IN\!`"$```"_[P$`%````.'O`0`<````]N\!`!8````3\`$`.P``
M`"KP`0`&````9O`!`!<```!M\`$`$P```(7P`0`3````F?`!`!H```"M\`$`
M$P```,CP`0`6````W/`!`"8```#S\`$`'P```!KQ`0`H````.O$!`#H```!C
M\0$`#P```)[Q`0`;````KO$!`!D```#*\0$`/0```.3Q`0`]````(O(!`#T`
M``!@\@$`&P```)[R`0`=````NO(!`!T```#8\@$`$P```/;R`0`1````"O,!
M`!D````<\P$`'0```#;S`0`5````5/,!``8```!J\P$`,````''S`0!E````
MHO,!`!X````(]`$`#P```"?T`0`O````-_0!`#$```!G]`$`+P```)GT`0`5
M````R?0!`"\```#?]`$`"`````_U`0`&````&/4!`!D````?]0$`%P```#GU
M`0`7````4?4!`!8```!I]0$`$P```(#U`0`3````E/4!`!T```"H]0$`"```
M`,;U`0`&````S_4!`!\```#6]0$`$P```/;U`0`9````"O8!`!@````D]@$`
M&0```#WV`0`-````5_8!`!$```!E]@$`0@```'?V`0`D````NO8!`"4```#?
M]@$`'P````7W`0`<````)?<!`"0```!"]P$`.0```&?W`0`O````H?<!`!X`
M``#1]P$`'````/#W`0`7````#?@!`!P````E^`$`&P```$+X`0`B````7O@!
M`#@```"!^`$`&P```+KX`0`Q````UO@!`"0````(^0$`*P```"WY`0`I````
M6?D!``\```"#^0$`)0```)/Y`0`>````N?D!`!X```#8^0$`&P```/?Y`0`1
M````$_H!`!D````E^@$`&P```#_Z`0`;````6_H!`"0```!W^@$`#P```)SZ
M`0`]````K/H!`!4```#J^@$`$P````#[`0`(````%/L!`&H````=^P$`#@``
M`(C[`0`S````E_L!`!,```#+^P$`+0```-_[`0`7````#?P!``\````E_`$`
M)````#7\`0`"````6OP!``8```!=_`$`"````&3\`0`$````;?P!``H```!R
M_`$`"````'W\`0`(````AOP!``@```"/_`$`"````)C\`0`+````H?P!``H`
M``"M_`$`"````+C\`0`/````P?P!``8```#1_`$`2P```-C\`0`$````)/T!
M``L````I_0$`"P```#7]`0`'````0?T!``0```!)_0$`#````$[]`0`$````
M6_T!`!$```!@_0$`#@```'+]`0`&````@?T!``8```"(_0$`!@```(_]`0`2
M````EOT!``\```"I_0$`%0```+G]`0`,````S_T!`!@```#<_0$`#P```/7]
M`0`$````!?X!``X````*_@$`#````!G^`0`$````)OX!``4````K_@$`#P``
M`#'^`0`0````0?X!`!(```!2_@$`'P```&7^`0`>````A?X!`!\```"D_@$`
M#@```,3^`0`6````T_X!`!D```#J_@$`%@````3_`0`2````&_\!`!(````N
M_P$`%P```$'_`0`2````6?\!`!(```!L_P$`%P```'__`0`8````E_\!`!$`
M``"P_P$`'0```,+_`0`1````X/\!`!$```#R_P$`&@````0``@`,````'P`"
M`!$````L``(`$@```#X``@`6````40`"`!<```!H``(`$@```(```@`7````
MDP`"`!4```"K``(`$P```,$``@`0````U0`"`!<```#F``(`$@```/X``@`7
M````$0$"`!(````I`0(`$@```#P!`@`/````3P$"`"8```!?`0(`*0```(8!
M`@`.````L`$"`!8```"_`0(`$0```-8!`@`G````Z`$"`!@````0`@(`%@``
M`"D"`@`>````0`("`!\```!?`@(`&````'\"`@`9````F`("`!,```"R`@(`
M$@```,8"`@`7````V0("`"(```#Q`@(`%@```!0#`@`@````*P,"``0```!,
M`P(`"````%$#`@`$````6@,"`!X```!?`P(`&P```'X#`@`&````F@,"``X`
M``"A`P(`)P```+`#`@`5````V`,"`!0```#N`P(`)`````,$`@`$````*`0"
M``8````M!`(`)0```#0$`@`D````6@0"``\```!_!`(`%P```(\$`@`2````
MIP0"``8```"Z!`(`C0```,$$`@`(````3P4"`#$```!8!0(`#@```(H%`@`$
M````F04"``<```">!0(`"@```*8%`@`+````L04"``L```"]!0(`#P```,D%
M`@`$````V04"`",```#>!0(`#`````(&`@`,````#P8"`!`````<!@(`#@``
M`"T&`@`(````/`8"`#4```!%!@(`!@```'L&`@`?````@@8"``H```"B!@(`
M"@```*T&`@`*````N`8"``H```##!@(`'0```,X&`@`0````[`8"``H```#]
M!@(`%P````@'`@`+````(`<"``@````L!P(`#P```#4'`@`5````10<"`!$`
M``!;!P(`!````&T'`@`2````<@<"``8```"%!P(`&````(P'`@`"````I0<"
M``@```"H!P(`$@```+$'`@`$````Q`<"`!0```#)!P(`)````-X'`@`$````
M`P@"``@````("`(`"````!$(`@`(````&@@"``4````C"`(`!@```"D(`@`/
M````,`@"``\```!`"`(`!P```%`(`@`&````6`@"``P```!?"`(`"@```&P(
M`@`F````=P@"`",```">"`(`!@```,((`@`(````R0@"`!T```#2"`(`!```
M`/`(`@`;````]0@"``T````1"0(`$0```!\)`@`$````,0D"``8````V"0(`
M"````#T)`@`,````1@D"`!````!3"0(`!````&0)`@`$````:0D"``8```!N
M"0(``@```'4)`@`%````>`D"``(```!^"0(`!````($)`@`&````A@D"``0`
M``"-"0(`"0```)()`@`(````G`D"`!$```"E"0(`$@```+<)`@`9````R@D"
M`",```#D"0(`#P````@*`@`/````&`H"`!8````H"@(`%@```#\*`@`6````
M5@H"``@```!M"@(`(@```'8*`@`$````F0H"`!,```">"@(`(P```+(*`@`(
M````U@H"``@```#?"@(`!0```.@*`@`(````[@H"``(```#W"@(`!@```/H*
M`@`(`````0L"``4````*"P(`!@```!`+`@`$````%PL"``@````<"P(`!```
M`"4+`@`*````*@L"``H````U"P(`!@```$`+`@`X````1PL"`#````"`"P(`
M$P```+$+`@`3````Q0L"`!4```#9"P(`#0```.\+`@`"````_0L"``(`````
M#`(`#`````,,`@`"````$`P"``0````3#`(`!@```!@,`@`,````'PP"``(`
M```L#`(`"P```"\,`@`]````.PP"`!D```!Y#`(`'P```),,`@`;````LPP"
M``L```#/#`(`)P```-L,`@`A`````PT"`"$````E#0(`)0```$<-`@!.````
M;0T"`!T```"\#0(`*````-H-`@`7`````PX"`!D````;#@(`"P```#4.`@`=
M````00X"`"$```!?#@(`(0```($.`@`A````HPX"`%,```#%#@(`%P```!D/
M`@!!````,0\"`"@```!S#P(`(0```)P/`@`<````O@\"`!\```#;#P(`&0``
M`/L/`@`5````%1`"`!4````K$`(`%0```$$0`@`5````5Q`"`!4```!M$`(`
M$P```(,0`@`7````EQ`"`"(```"O$`(`+@```-(0`@`N`````1$"`"X````P
M$0(`0@```%\1`@`>````HA$"`!````#!$0(`%P```-(1`@`(````ZA$"`%,`
M``#S$0(`"````$<2`@!6````4!("`"T```"G$@(`40```-42`@`;````)Q,"
M`#8```!#$P(`$P```'H3`@`.````CA,"`!D```"=$P(`$P```+<3`@`)````
MRQ,"``\```#5$P(`&````.43`@`;````_A,"``\````:%`(`$@```"H4`@`Z
M````/10"``\```!X%`(`#P```(@4`@`5````F!0"``P```"N%`(`#P```+L4
M`@`1````RQ0"``H```#=%`(`"@```.@4`@`+````\Q0"`!(```#_%`(`#@``
M`!(5`@`4````(14"``8````V%0(`!@```#T5`@`*````1!4"``@```!/%0(`
M"@```%@5`@`(````8Q4"``8```!L%0(`!@```',5`@`&````>A4"``8```"!
M%0(`#0```(@5`@`+````EA4"``8```"B%0(`!@```*D5`@`-````L!4"``P`
M``"^%0(`"````,L5`@`&````U!4"``8```#;%0(`!@```.(5`@`/````Z14"
M``8```#Y%0(`!@`````6`@`-````!Q8"``8````5%@(`"````!P6`@`&````
M)18"``P````L%@(`!@```#D6`@`0````0!8"``P```!1%@(`!````%X6`@`.
M````8Q8"``@```!R%@(`$@```'L6`@`,````CA8"``(```";%@(``@```)X6
M`@`"````H18"``H```"D%@(`"@```*\6`@`*````NA8"``0```#%%@(``@``
M`,H6`@`3````S18"``0```#A%@(``P```.86`@`"````ZA8"`!(```#M%@(`
M!``````7`@`0````!1<"``T````6%P(`#````"07`@`#````,1<"``(````U
M%P(``@```#@7`@`$````.Q<"``D```!`%P(`"0```$H7`@`&````5!<"``H`
M``!;%P(`"````&87`@`.````;Q<"``8```!^%P(`"````(47`@`$````CA<"
M`!````"3%P(`!````*07`@`,````J1<"``@```"V%P(`$P```+\7`@`"````
MTQ<"``0```#6%P(`"````-L7`@`&````Y!<"``P```#K%P(`&@```/@7`@`$
M````$Q@"``8````8&`(`"@```!\8`@`3````*A@"``4````^&`(`#@```$08
M`@`%````4Q@"`!````!9&`(``@```&H8`@`#````;1@"``(```!Q&`(``@``
M`'08`@`!````X00``$@%```\!P```````+`%``""````$@````````"E!@``
M`````&($````````N0```+````">!P````````````"4````$@@``'\&````
M````H0$```\!``!1!0``?0```%`!``"1"```=`4``$,#```S!```FP<``.D$
M`````````````+@"````````'@8``*T$``!O"```W@$``,P%````````5`@`
M`#8$````````?0@``.\#````````T0(```````#_!0``*00``$$```"$!0``
M`P<``%\#``#^!0``M@$``&4```!?!@``,@````````"\!0```````#,"``"C
M!P```````%,&``!6!@``A00``#X#`````````04``!D'```S!0``X04``"D"
M``!@!P``L`0````````7!P``;0$```````"]`P``J`8``)0!````````````
M```````G`0``;`8``.\`````````"P0``&0!``"6`P``X@8``(\#```<````
M4@<``-T'``##`@`````````````D!````````"L&````````1P,``%<!``"3
M`P```````&\%``"5"````````*X(``#(!````@0```$(```1!P``J@8``",`
M```@`````````.4%``#:!0``OP```.X!``#L`@``%0@``#D#``"!!0``P@<`
M`.$&````````6`0``.L$``#H!P``B`$``$H'`````````````'4!``!%"```
M=@````````#M`0``OP0``*0&``"\````X`$``*P(``!-`@``!`,``*0'``!V
M`@``KP(`````````````+P$``*`%``"A!```M@4``$\%````````%P0`````
M```<`P``8P8````````J"```Y`8``#X(``#K!0``I@,```````#+`P``)`4`
M``````"-"````````$$%``#\!P````````````#&`@```````+0&``!0`@``
M^P```%\%````````5````(X(````````2`@``*$(```A!````````&X'````
M````R@,``*````"N`0``7P(```````"*`P``4P@``/$"``#]!P``:00``$D'
M``#W!@``]0<``(<(``!\!@``]08```@"``````````````````!*`P``[00`
M`(L$``!J!@``90,``)X%``!*`@```P```!H!```9`P``)@8```````"A!0``
M(`$```4'````````A@@``%T$```'!````````-<'``!$!P```````"X!``#=
M!0```````#T&```&````@P0`````````````X@$```````#2````UP```'@#
M```Q`0``J@$``/0$````````"@$```````#+`0``>0,```````!U`P``````
M`#0#`````````````&P(``"$!P``+P0``.X'``!V!```"0$``)T%``"!`P``
M\`$``%0%```]`@```````$$"````````<0<`````````````>@(``'H!``"?
M!@``1`$```````#L!@```````&8#``![````'P,``)(%``#3!```:P@``"0!
M``#@`@``&@8```````!T"````````)L$``"H`P``D0<`````````````U08`
M``````")````A`,```H'``#'`````````+\#``!8`P``_P(``)D!``#W!0``
M`````/````#<`@``?`<``'0$``#'!```=@<``/@$``"X`0``,@(````````T
M"```)@````````!A`0``6@$````````>"```Y````(P#``!%`0``'P8``!H'
M````````R@``````````````Q@```,0"````````J`<``*(#``!"`@``3P0`
M`%H$``!4`0``I@(``````````````````!4!```*````%0<``+L!````````
M]0,``(,"``````````````````!/````-`0``%D$``":!@``[08````````U
M!@``6`<```````"3"```YP0``+@#``#?`@````````(%```L!@``Y@```$L#
M``!F`@``_P$``%H"```,!@``6@8```````".`P``7P0``#4```!K`P``2`(`
M`&D%```-!0```````",%``#A`P``YP8``(@'``#R!```$P@``%X!````````
M&@0```````"S!0``[P0``/H"```D````*0,``-@"``#A`````````.8%````
M````EP(``,T#````````!@4``+4!``#Q`P``0`8```````";"````````"X&
M``"T!P``I0,```````!M!P``AP```&P'````````9P``````````````<```
M`#@"``#'!0``3P@``,X"``![!P``&@````````#K!@``SP4```````#B!P``
MGP0``)H#````````Y@$``%H'``!D!0``E0<``(P$``"C"```L0```($&````
M````,`4``````````````````````````````````&$'``#4`@``8P```$,!
M``!)`@``?08``,("``!$`````````#,(````````````````````````````
M`$L'``":!0``2`$``!`(````````Q`0``$D#``!7!```,04```((``![`P``
M``````````"V`@``/`,``*T&```9`0``'0,``/D$```,!0``G0```"\&``!=
M!P``U04``,$```"3`0``E`8````````V`@````````$$```]!`````,``)`$
M``"Z!0``:@,``&@(```^``````(```````"`!@```````!````#V!0``=@8`
M``````"/!@``Z````-\&``")`0``100`````````````ZP```*4%````````
M&@,``',$``!P!P``L0(``)8%``!>`@``V0,``-,`````````I0@```````"C
M`0``7P```(\`````````S04``````````````````!`%````````,`$``#D$
M``#1!P``O`8``(4'````````>@```&4$````````GP$``,D"````````20``
M```````@"```M`,``$T!````````"P(``#`(``">!@``RP````\$````````
M_00``'<(```$`@``UP8``'`!``!*````9`@```H%``!)!0``/P4```@(``#>
M!0`````````````[````[0,```````!@`P``T`,``/P#``!V!0``TP,``(,!
M``"J!0``AP4``.("``!,````E@0``/8!``!=`@``````````````````&`(`
M`/$`````````(04``$$'``"8!0``<0(``*,"```4!````````*$'``#W````
M10,``$(&``"9`@```````!8$```3!P``F08``/`#````````A0,``#`#````
M````*P<``*L&``"#!P``B00``*L%``!4!@``QP<```````"B````````````
M``!@`0``C08```````"8``````````````"W`P``)`(```````#9!0``/0$`
M`-(%``#-!P``504```````#<`P```````&,"``"J!P```````(H!````````
M&`,``",&````````<P<``!`!``!<!@``K`<``,H"``!6!P``RP0```````#)
M````J00``(X```!(!````````'\$```.`@``&08``-D'`````````````)4!
M```K"```A`0``````````````````(8%``#M`@``;@```-@!````````````
M`#P`````````Z@<``&8%``"*`@```````,D!````````)@0````````0`@``
MX@4``$D!``"L````O`(```````#/`P````````````!A`@``.@4``&(%``!B
M`0``4@@``*T```#C````````````````````Q0(```````"D`0``:P<``)8&
M```(`````````,`'``!!"```F0<``.4$````````3`8`````````````^P0`
M``````#)!P````````````!X````5@$`````````````VP0``-@&````````
M``````````#H!````````&H%``!^!@``YP$```````!X!0``T@0``"H$````
M`````````%@%````````?P`````````#!@```````#T```#C`0``_`````\%
M````````Q`$```````"A`@``O0```(X&``#E````]`````H$```7`@``6@4`
M``````"@!P``)@$``/0!``!U!0``G0(``+L``````````````%L(```4!@``
M/@<``!8&````````B0<```````!R`0```````)T'````````;04```8!``"0
M`0``%08``-T&```*!@``=P8``)@#````````E08``'L!``!U!P``)0$``*<'
M``#O`@````````X$``#P!P``WP4``#L&``"'!```$08``,$%``!R!P``P@0`
M`',"``#"`P``=````#$$``"``@``V@0``-<!``!,!````````.`#``!@````
M`````'D!````````O@(``````````````P$``*P$``#$!@``0P<``'8(````
M````;`(``*L!````````S08``+4$``#4!P```````"T#````````+04`````
M````````K04``($```!M"```H`8``/8#``#W`@```````$X(````````````
M`,4%``!L!```,0<``+4'``!!!@```P@```("`````````````,0'``#I`P``
M9`````````!L````G@@``,$&``#D!0``000```````"U!0``&P4``%,'``"^
M!```?`@``&X(``"5`@``1@8``)P(```,!`````````````!@"```BP<``)<(
M````````Z08``)H(``"=`P``!00``.0'``!'`0````````````#:````````
M``````!G"```;`4```L!``"="````````#4!```S!P``%P@````````J!0``
M`````,X!``#*!0```````/4"````````V@<``*D```#[`P``@`,``",$````
M````3@0```````"3!P``D`8```\```#P!```1@```%,```!-"```H0,``/("
M```T````<0$``!(#``"`!0``7@0```@$``#D`P``)@(``%`'``!3`@``)@,`
M`!8'````````30,``'(````?`0``\@$``*L````I`0``\@4``'<#``#F!P``
M`````/@&```E````"08````````'`@``_P0``#<(``!K!0```````(X'```E
M`@``/P```+<"``#]`P``T`4`````````````:0,``!0#``"E!P```````"P%
M``#X````T00```````"/!P```````'X#```G!0```````*<#``"$`0``QP,`
M`$`'````````^P<````````G"```IP0````````3`P```````,H$``"_!P``
MZ@4```````!&!```VP$``!8(``"K`P``I@@``&\"```4`@``_08``/\````1
M`P``-00``)0(``#J`P``@0(``+`#``!<`P``?@0```````!X!P``)P0```\(
M````````"0```',%```P!```(P,``+H$````````*08`````````````*@(`
M`!@&`````````````#(&``#)!0``F@<``````````````````)<!``#"`0``
M`````/@!```G`P``&04``(H'``#0!```#@4``'`$```=!````````$H!````
M`````````&L$``"]!```=`$```(!````````MP$``)T&```Z````I00``*0`
M``!A````#P8``/$&``!:`P``2P```+L#``!*!```S@4```````#6!```E04`
M``````!N!@``50$```````!+`0``>P@``,H'```A````S@,```````!"`0``
MH@<``,8'```+````&@(```````#8````*0````````#Q!```D`,```````#<
M!@``U0````````"#!0``+08``-(#```T`@``9@@``&@!````````Q```````
M```?!0``G@```*T"```D!P```````/X&``#-`@``P`,```````"3!@``4@``
M``<&``#N`P``4`4``&H`````````Z0<``%D&```F!P````````````#6!P``
M9`<``',&``"'!P``=P$``#<$``"<!```:`0````'``!>!P``T0`````````D
M"`````````````````````````````!R!0``'P@``"H!``!O!P```````((%
M``!%!0``!`<``!T````$!```W@<``.0$````````E0``````````````````
M`````````````````"(&``#0````/`4``/0'````````=@$``.,#``#5!```
M2@4``'@(````````DP(``$4"````````>@@``(L(``"2`@``NP(``,P!```V
M````40,``%(!```[`P``?@(``$`(``!@!0``R`(```````"(````R`<``-<"
M```7````>P(`````````````4P4``"@```"B!0``T`<``+<$````````````
M`$4'```]"```00$````````[!0``+00``,`"````````Z@(``-H&``"?!0``
M`````)('````````^@4``+H&``#>`@``;00`````````````*P$``#D"``!.
M!@``4```````````````IP```%(#``"J!```$`8``%<"``"B`0``7`<``#8%
M``#X!P``B0@```````#G`P``#00```````#N!`````````````##````"`$`
M`````````````````#H'``!5`P``\@,``,`!``#,`@````0`````````````
M[`0```````#]````)@4``'D``````````````*($``"<`@``3@4``"H'````
M````(@<``+($`````````````((#````````&`0``&8'`````````````$D$
M``#-!```Y`$```D(``#D`@``Z04``&4!``"S!@``;@(``($'``"&!@``#`(`
M``$!``!"!0``7P<``(4!```;!P``S````"P'````````"04````(``"3!```
M`````&(&``"M`0``2````"<'````````_@<``!$"``#\!0``5@```)D$````
M``````````(#``#F!```OP(``/0%``##`P```````+(%``"8!@``5@(``*4"
M``"V!@``(@,```````!0`P``(`<``"$(``!]!```7@````<```!H!@``F@(`
M`(,(``"$!@``1@$````````[`0``#0@```````#T`P```````#H"``!&`@``
M(@4``-L'````````[P4``/X!````````L0$``"P(``#F`P``J@(``/0&``"D
M!0``LP0``&,(```L`P``[@8``$P(``#)`P``.04``)<&``#+!0``6`8``!`'
M```D`P`````````````/`@``3@<``,<!````````L@<```````#[!0``````
M`!,$``#$!0``\P0``(H(``"4!```+`(``-8%``!4!```GP<``"X"```$`0``
M=P0``#L'````````+P`````````M!P``D@@``.,$``#&!@``R@$```````"S
M`@``B04```````"8!P```````*@```"Z````LP,``&P#``"5`P``-`8``!X'
M```Z"`````````````"9!0``J0<``$8(```B"```W@8``!0'``!<`0``````
M`*<%``!D`P``2`8``+0%```6````1P8``!P$````````<`8``#,```#E`P``
M`````.@#``"F!````````-X$```M"````````.`````O!P``W0$``.\'````
M````]00```````#Z!P``S`<`````````````!`@```<'```9`@``O08``(@#
M``#5`0``10```",'```(`P``^P8```````!L`0``*04```````!Y!P``/P,`
M``````"P`0`````````````#`@``9P$``%`$````````,@,``%D%````````
M:0$``!@!````````6`(``%D`````````L0,``(\(``!;`P``;P```+X%````
M`````````"H#``#)!@``]@```*,````P`@``N@(``````````````````%("
M````````Q`,`````````````+@4``-('`````````````-\!````````U0<`
M``````#"````QP(````````=!P``*`@``'4```#P`@``$P8``%T#````````
MLP<``````````````````%<````9````40$````````2!@```````"D(``#R
M````_P<``#($```H`@``6@@``$0%``#.!@``S@```&8```"N`@``!@(``.<%
M``!;`0``5`,``$$#``"H`0``U0(``$4&``!1`@``!````+L&```1"```;@0`
M`(($```(!@``=`8``'$$``!_`@```````%(%``#Z!@``)0<``,\&````````
MR@8``',(```'"```8`0```````"*!0````````````"`````$0```)``````
M`````````!('``#%````0`0``)<%````````:`4``$,`````````(0<``)L"
M``#K`0``^08````````'`P``508``%@!````````.`0``+@'````````3P$`
M`)<```!I!@``DP4``/H!```%`P``8@@``)($``!*!@``-0@``!P%```^!```
M``````````"I!@``D@```/T"``!>`P``SP(``/,#``#&!```$04``+<```!4
M`@``#0,``'\!``#=`@``5P8``-H#``!Z!P``T08```````"*````?0(`````
M````````$P(``.<"`````````````#\!``"I`0```0(``"D'````````K@4`
M`)8`````````J@,`````````````'`<```````#:`@``)`8``'<```#/!P``
MI@8``)<'``!X!```RP(```````!=!@``*P4``'`%````!0```````%<(``!4
M!P``Z0````````!$`@``&P(```````!\````!04``$`#`````````````#<%
M``"G"```"`<```````#[`0```````(L#``!1!@``9P<``)`%``#6`@``JP(`
M`(H$``#J`````````(\"``#;`@``H`,```````"0!P``4P,```````"P!@``
MKP<``$`%``!N`P``V`0```````"(`@``>00```````#`!@````````````"O
M!````````*H(```>`@``!08``.P!``#4`P`````````````A!@``V0(``&X%
M```9!```C`8``.@%````````^`4``/0"``"/!0``!@0``#@&```6`0``B08`
M````````````?`0``)T!``#J!````````+@&````````BP```$,$````````
MGP```"4&```J!@``T`(``)0"``!+!```J`0``'4$```;`0``NP0````````?
M!```Y0<```````!&!0``C0$``(P%```5!```C`(``)X#```.`P```````&\#
M```;````/@(``"(!``"<````:`,``!P!``!Z`P``F@```,@#``"R`P``Y08`
M`%D(``#F!@```````#((``"L!@``J`(``-X```!'"```L@8``(P(``"Y`P``
MH`@``#(%````````"P4```X```"8"```6P<````````^!@``%`$```````"4
M!0```````#L"```Y!@``_`(``+8#``!D`@``=`(````````E!0``%P,``"$#
M``!C!```2P(``$`!``"R`0``20@``#P(``"G`@``BP4``-,'``![!@``(@``
M`+8$``#X`@````````````!^"```W@,``!0`````````40```(P```!\`0``
MK`$``,`$``"%````F`0```P(``"K!```N08``,@%``!,!P``4`8`````````
M````-`$``(P'````````M`$``.P```"M!P``-P,``&4%````!@``L`(``"P!
M``"?"````````*D(````````5P,``$0(``!\`@```````!("````````PP<`
M``````">`0``8`(```````!/`P``+`0``)@!``"$`@``;P8`````````````
M_04````````-!P``"0<``&(#``"O!@```````",!``!>"```-04```\'``"S
M````L04``!($``#3!0```````!4#```0!```?P,``&,%``#;!@``U`0`````
M````````)0@``%$'``````````$```@%````````\`4``)L#``#%`0``]P0`
M`/<#``"K"```@@8``*,$````````VP4``)<#``";!0``@0@``"`$``!"`P``
MFP8``!4%``#N````XP<``"T!``#%!@``'@4````````-`0``Z@8```````!E
M!P``B0,``#@(`````````````"@'`````````````````````````````!8"
M````````8@````T&````````#0````````"J````)P```*P"``#.!P``&P8`
M``````")`@``0P(```````!$!@``.`4``"@&``"2`P```````/D#````````
M<@@````````:!0``[P8``!X!``"N!````````!P(``!G!0``Q00```````"W
M!@``>P0```````#R!@``R````(`(``"7!```AP8``(8#```G!@``7P@``(L"
M```H!0``*P`````````P````30<``!L#``#Y!0``RP8``(4"````````"@@`
M`"4#``````````````````#9!```,0@``#`'``!,!0``!`8``(("``!A!@``
M`````*D%``#0`0``G`4``+4```!2!@``<@,``*<&``#3`@``:````$0$````
M````PP$``%8(```@!@``WP````D"`````````````&4"```\!@```````%P%
M``"Z`P``.`$``!4"``#8`P```````(<"````````\`8``!@(``!.`0``-0,`
M``````#S````!0```'T'````````#@@``*T(``#!`0``D04```````#=!```
M,0,```````!E!@```@```-8#````````50(``)D```"*!@``%@4``$,(``#N
M`@``+0(```````!`````A`@``(\!``!Z!0``[`,``'($````````D@8``+@`
M```=!@``L08```````!8"```B`@``.P%``!(`P``#@<```````"(!```?P<`
M````````````<0,``"`#``!M!@``PP8``'H&``#U````WP<``&L&``"@!```
M.@$``*@%``"N!@```````'4(````````(`(```````#/````@@$``*\`````
M````+P@```````!U`@```````+D"```3!0``^0$``.D!``"8`@```````)H$
M``":`0```````&<#``!R`@```````%P$```X`P``#`<``%T(``"6`0``````
M`&$%``#5`P``Q@$``%P````]!0``T@(``````````````````$@'```W!P``
M+@@````````2!0``H@@``(T%```:"```B`8``+X'``#%!P``/@$``!$$``!\
M`P``0@```#H&``"D`@``W0```)`"````````P`4``#<!``!7!0```````'<"
M```!!@``^@````````#-`0```````.`'``!F`0``,@<``+P!``!C`P``?@$`
M`/P&````````M08``,8%````````=@,``#8(``````````````````#Y````
MM0(``,P#```!!P``@0$``.,&``!-!```GP(```````#1`P``Z`8```P!````
M````;@$``&@'````````T04``!T(``#.!```I0``````````````(0(``-\$
M```8!0``X@```!$!```<!@```````&H!``"_!0``!@@``#L(``#S`0``A@$`
M`&L"````````/`0```````"Y!```0@@``&$#``!I!P```````!<&``##!```
M:`(``!8#````````FP$``*8!`````````P,```````#H`0``@`0``'H$``#@
M!```HP,``#@'```9"````````"\"`````````````&("```H!```-0(``'$%
M````````G`<```````#N!0``3@,````````Q`@``[0<``.<`````````````
M``````#8!0``;0```.4!``"%"`````````````"%!0```````$<"````````
MG@(`````````````H`$``.($`````````````'`#```%`0``J`@``!X$```_
M!@`````````````_"```%0```-D```#3!@``O@,``%D!``#4!0``O`,``+P'
M``"W!P``#`,``.`&``"M`P``NP<```````````````````<%````````'0$`
M`($$`````````````.T%```?````VP,```P```#```````````````#/!```
M`````+X&````````>`(``,4#``"_!@``U@8``/$'`````````@<```````!_
M"```C0````````!$`P``SP$```````!D!@``3@(``'`"```&!@``^@0``*(&
M``"T!`````````H#``!9`P```````&T#````````Z`(```````!;!```Z@$`
M`"$!``!O!```S`0``-,!``"]`0``C@(``-0&````````L@(```````#-````
M`````.D"``````````````````#^`@``LP$``'<'````````B`4``+P$```'
M`0``^`,```X&``!Y!@```@8``"P```!F!```=`<``+8```"[!0``<@8``$H(
M``#S!@``,P$```````!<`@``"P@``$<'````````60<``'D(````````````
M`"8(``"&!````````&$$``!6!0```````%4$``!O`0``$P``````````````
M`````!<%``"E`0``P@8``,@&````````@@<``!,!``!I`@``:P$``"@!```B
M!```G`,``%T!``!G`@````````$#``!Q````4@0``.`%```N````3P8``&<&
M``!+!@``CP0```````"X!```W`<``+$'````````0P4```````"-!```!`4`
M`'T#``"I`@```````.8"``"""```6P```%P(``"#````D0,``*<!```8````
M`````/P!```Z`P``Y0(```````"2`0``_P,``-(!``#)!```]P<``-0!``"+
M`0``&`<``$P#``#V!P``*P(``.\!```7`0``/0,``#D`````````0@<``*0(
M``"-!P``_@,``(8"``!Y`@``D0(``*,&``"1!```D0```'`(``#Q!0``U@``
M``````!E"```(@(``$X````^!0``\P(```````````````````````!;`@``
MV`<``","```E!```:@0```````"Y!P```````'X`````````C@0``+`'``"3
M````5@0``%<'``"6!P``!0@``%`(``!Y!0```````-<%```N`P``@P8``*\%
M``#K`P``P00```````!5!P```````-\#``#[`@``3`(``#\$``#!`@``6@``
M`#\"``#"!0``-P(``&('````````E00``-P````;"```M`(```````#Q`0``
M``````````"W!0```````,,%````````50@```````"Z`0````````````!9
M`@``@`$``',`````````70```%4````W````D08``!0%````````````````
M```@!0``8P$```````"N!P``,0```(X!`````````````#4'````````1P``
M`*$`````````0`(``/<!``!I`````````#$&``#V!@``+P4``*\#``#&`P``
MK@,``)X$``#K!P``'0(``*8%````````_P8```,$``"`!P``W`$```````#V
M`@``V@$```````#<!````````%,!````````1P0```````"]!0``0@0``#H$
M```V!@``(P@``(8```!_!0```````.<'`````````````#@`````````2P@`
M``````#9!@``P0,``',!```.`0``308``%@```"F`````````&<$``"&!P``
M&P0``$D&`````````````&D(``!J!P``````````````````BP8``*8'``".
M!0``7P$``.(#``!X`0```````%L%``#V!```G00``,L'```J`````````'L%
M`````````````/X$````````X0$``-D!``!1"```1@,``(<!``"U`P``````
M`-<#```]!P``)P(```8'``!>!0``-P8``+T"``!X!@``O@$``$P!```H`P``
M"00``'0#````````K`4``)8(``"D`P``P0<```L#````````4P0``/H#``"@
M`@``N`4``#0'``"]!P``S`8``*\!``#U!0``?0$```````"D!```/`(``)D(
M```&`P``\P4````````4"```XP4```L'```V!P``304``+X```#A!P``````
M````````````N04``/T!````````A08`````````````+0````````#<!0``
MVP```.T`````````"@(``!X````N!P``.0<``/X```!F!@````````````!'
M!0``.0@``(,#``#4````704``&H(````````OP$``'T%``#Y`@```````/('
M``"$````'P<````````=!0```````-$!````````K@```.L"```+!@``^0<`
M`+D!``"I`P````````````"T````30```'$(```/`P```````%L&``"?`P``
MT`8````````>`P``"0,``(P!``!#!@``T@8``)L````0`P````````````"4
M`P``]0$```````"-`@``````````````````.P0```````#S!P``G`$``$\"
M``"B`@``2P4````````V`P``UP0``*L'``!J`@``?@4`````````````_`0`
M``,%``#A`@```````&,'````````+P,``+H'``!@!@````````````!>!@``
M`````'4&```````````````````P!@```````)D#``#C`@``L@```'$&```R
M`0``U@$```````"<!@``=P4```````"C!0``!0(``)8"```T!0``1@<``&T"
M``!/!P```````)0'``"'`P``C0,``#,&``````````````T"``"V!P``'`(`
M```````?`@```````,<&```K`P``*P0```````"L`P`````````````Y`0``
M/P<``!(!`````````````#,#``"1`0``R`$`````````````[`<``+$$``!S
M`P``W0,``%$$`````````````%8#``!K````+@0``*$&``"0"```/`$``#8!
M``!D!```?`4``&$(``!^!P`````````@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@
M*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S
M(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@
M;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E
M;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`
M(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F
M34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@8V%L96YD87)S
M(&9O=6YD`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E
M9"!E=F5N=',`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($1A>2AS
M*2`E<R!(;W5R*',I("5S($UI;G5T97,`)7,@1FEN9V5R<')I;G0`)7,@2T(`
M)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3
M971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E
M861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@871T96YD965S`"5S(&9I;&4@
M<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE
M8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E
M<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!"
M;V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`
M)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@
M:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK
M<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P
M97)S;VYA;"!I;F9O<FUA=&EO;BX`*$-L:6-K(&]N(&-A;&5N9&%R(&YA;64@
M=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE(&UA
M:6X@=VEN9&]W*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!!9&0@*@`J(%!L
M96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`L(&=U<W1I;F<@`"P@9W5S=&EN
M9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM
M`#$@871T96YD964`,2!E=F5N=``Q(&AO=7(`,3(@2&]U<B!&;W)M870`,34@
M;6EN=71E<P`R,"!M:6YU=&5S`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#,P
M(&UI;G5T97,`/%!R979I;W5S`#QS=')O;F<^071T96YD965S/"]S=')O;F<^
M("AO<'1I;VYA;"D`/'-T<F]N9SY$97-C<FE?<'1I;VX\+W-T<F]N9SX@*&]P
M=&EO;F%L*0`\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO<'1I;VYA;"D`
M/'-T<F]N9SY296-U<G)E;F-E/"]S=')O;F<^("AO<'1I;VYA;"D`02!D871A
M8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!30!!32!#;&]U
M9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3
M:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN
M+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P=&5D`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W
M;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D7W9A;F-E9"!396%R
M8V@`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!
M9&0@179E;G0`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M
M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!296UO=&4@0V%L96YD87(`
M061D(&$@;F5W(&5V96YT`$%D9"!A(&YE=R!U<V5R.@!!9&0@871T96YD965S
M`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@
M)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B
M;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E
M<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!
M9',`061V86YC960@4V5A<F-H`$%F9VAA;FES=&%N`$%L87)M`$%L87)M("5D
M(&1A>7,@8F5F;W)E`$%L87)M("5D(&AO=7)S(&)E9F]R90!!;&%R;2`E9"!M
M:6YU=&5S(&)E9F]R90!!;&%R;2`E9"!W965K<R!B969O<F4`06QA<FT@,2!D
M87D@8F5F;W)E`$%L87)M(#$@:&]U<B!B969O<F4`06QA<FT@,2!M:6YU=&4@
M8F5F;W)E`$%L87)M(#$@=V5E:R!B969O<F4`06QA<FT@1&%T90!!;&%R;2!3
M<&%N("AM:6YU=&5S*0!!;&%R;2!4:6UE`$%L8F%N:6$`06QG97)I80!!;&EA
M<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@071T96YD965S`$%L;"!!=71H
M96YT:6-A=&5D(%5S97)S`$%L;"!&=71U<F4`06QL($=R;W5P<P!!;&P@4&%S
M=`!!;&P@4&5R;6ES<VEO;G,`06QL(%9I<VEB;&4`06QL(&1A>0!!;&P@9&%Y
M(&5V96YT`$%L;"!E=F5N=',`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R
M;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L
M=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT
M97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`
M06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E
M<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`06YY`$%P<&QI8V%T
M:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P
M<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`
M07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE
M`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E
M;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`
M07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO
M;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T`$%T=&%C:&5D
M(&ES(&%N(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A
M8F]U="!T:&4@979E;G0N($EF('EO=7(@;6%I;"!C;&EE;G0@<W5P<&]R=',@
M:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY
M('5P9&%T92!Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+@!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD86YC90!!='1E;F1E97,`
M071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C
M:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!
M=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@
M24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@
M9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)A8VMG<F]U
M;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A
M9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC
M<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)A<VEC(%-E
M87)C:`!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU
M=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N
M;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI
M=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M
M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,
M:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$)U<WD`0TU3`$-20P!#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<P!#7V%L96YD87(`0U]E;&P@4')O<&5R=&EE<RXN
M+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86Q?96YD87(`0V%L
M96YD87(`0V%L96YD87(@4W5M;6%R>0!#86QE;F1A<B!S=6-C97-S9G5L;'D@
M<'5R9V5D+@!#86QE;F1A<G,`0V%L96YD87)S(&UU<W0@:&%V92!A(&YA;64N
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,`0V%N)W0@8W)E871E(&$@;F5W(&5V96YT+@!#86XG
M="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE
M;2!297!O<G0`0V%N8V5L;&5D`$-A;F-E;&QE9#H@)7,`0V%N;F]T(&1E;&5T
M92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R7WD`
M0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A=&5G;W)Y`$-A>6UA;B!)<VQA;F1S
M`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L
M;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H
M25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`
M0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T
M86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#
M:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P
M;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE
M`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&EF('EO=2!W
M86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E
M9"!E=F5N=',@8GD@96UA:6PZ`$-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N
M;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S+@!#
M:&]O<V4@:68@>6]U('=A;G0@=&\@<F5C96EV92!E;6%I;"!R96UI;F1E<G,@
M9F]R(&5V96YT<R!W:71H(&%L87)M<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D<F5S<R!B;V]K
M<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.@!#:&]O<V4@=&AE(&-A
M;&5N9&%R<R!T;R!I;F-L=61E(&EN('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N.@!#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E('=H96X@9V5N
M97)A=&EN9R!F<F5E+V)U<WD@55),<SH`0VAO;W-E('EO=7(@9&5F875L="!C
M86QE;F1A<BX`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A
M<B!1=65R>0!#;&5A<B!A;&P@871T96YD965S`$-L96%R(&]U="!U<V5R.B`E
M<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L
M:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN
M9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG
M*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`
M0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A
M;'5E<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M
M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I
M;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F
M;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K
M+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`
M0V]N9FER;2!087-S=V]R9`!#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\`
M0V]N9FER;65D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D
M.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R
M97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)
M<VQA;F1S`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O
M<'D@=&AE(%523"!B96QO=R!F;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO
M=7(@1G)E92]"=7-Y(%523#H`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E
M<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z
M("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD
M:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`
M0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B
M+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A
M<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO
M="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O
M:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E
M<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S
M92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N
M("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O
M=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL
M:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R
M:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@
M<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#
M;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!#86QE;F1A<@!#<F5A=&4@
M82!.97<@179E;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R
M96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R;6ES<VEO;G,`
M0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT`$-U<G)E
M;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E
M;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``
M0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H
M2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$86EL>3H@4F5C=7)S(&5V97)Y`$1A
M=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E
M:79E9`!$871E('-E;&5C=&EO;@!$87D`1&%Y*',I`$1E7VQE=&4`1&5?;&5T
M92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E
M8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V%L96YD87(`1&5F875L
M="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI
M=&EO;G,`1&5L971E`$1E;&5T92`E<P!$96QE=&4@0V5L;`!$96QE=&4@179E
M;G0`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U
M<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R(&%L;"!O8V-U
M<F5N8V5S/P!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M<V-R:5]P=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M
M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P
M;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H
M="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\`1&ES<&QA>2!#86QE;F1A<G,`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$
M:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U
M=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!S:&]W('1A<VMS('=H:6-H(&%R
M92!D=64@;VX@>6]U<B!C86QE;F1A<C\`1&]E<R!N;W0@<F5C=7(`1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`
M1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!$=64Z("5S`$1U<F%T
M:6]N`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@)7,`161I="!!='1E
M;F1E97,`161I="!";&]C:P!%9&ET($-A;&5N9&%R<P!%9&ET($=R;W5P`$5D
M:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@4F5M;W1E($-A;&5N9&%R<P!%9&ET(&%T=&5N9&5E
M<P!%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T
M8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E
M=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M
M<'1Y('-E87)C:"!T97)M<P!%;E]D`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H
M="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!$871E`$5N9"!/;@!%;F0@5&EM
M90!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T
M;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO
M8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D
M96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E
M<P!%<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@
M)7,Z("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W<FET
M:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5N
M="!A9&1E9#H`179E;G0@9&5L971E9#H`179E;G0@961I=&5D.@!%=F5N="!F
M<F]M("5S('1O("5S`$5V96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E+@!%
M=F5N=',@;75S="!H879E(&$@=&ET;&4N`$5V97)Y(#$U(&UI;G5T97,`179E
M<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S
M`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA
M;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!.86UE<P!%>'!A
M;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP:7)A=&EO;B!$871E`$5X<&]N
M96YT`$5X<&]R=`!%>'!O<G0@0V%L96YD87(`1D<@0V]L;W(`1E10('5P;&]A
M9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`
M1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL
M960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&
M96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&
M97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z
M("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I
M;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YD`$9I;FQA;F0`1FER<W0@
M2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&
M;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B
M<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4
M048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R
M96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M
M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T
M('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O
M<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&
M<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E90!&<F5E+T)U<WD@26YF
M;W)M871I;VX`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC
M:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<FED87D`1G)O;0!&<F]M('1H92``
M1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9U='5R90!'
M86)O;@!'86QL97)Y.@!'86UB:6$`1V%M90!'96YE<F%L`$=E;F5R871E("5S
M($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY
M`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@
M36%P<P!';V]G;&4@4V5A<F-H`$=O=&\@)7,`1W)A>7-C86QE`$=R965C90!'
M<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M
M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U
M<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U"
M:7-S874`1W5Y86YA`$A434P`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O
M<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I
M;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93H`2&ED90!(:61E("5S`$AI9V@`2&]?;64`2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`
M2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N
M=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C
M="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z
M(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE
M`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W5R*',I`$AO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!L;VYG('-H
M;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T:&4@9&%Y(&%N9"!W965K('9I97=S
M(&)E/P!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(;W<@;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S:&]U
M;&0@=V4@9V5N97)A=&4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F
M86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)
M7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O
M<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S
M97(N`$EF('EO=7(@96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP
M(')E<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T:&4@9F]L;&]W:6YG(&QI
M;FMS('1O(&%C8V5P="!O<B!D96-L:6YE('1H92!E=F5N="X*"E1O(&%C8V5P
M="!T:&4@979E;G0Z"B5S"@I4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV
M96QY.@HE<PH*5&\@9&5C;&EN92!T:&4@979E;G0Z"B5S`$EM86=E(%!R979I
M97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!)
M;6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T
M($-A;&5N9&%R+"!3=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O17AP
M;W)T($-A;&5N9&%R`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L
M9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A
M;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO
M;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!)
M;G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E
M<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S
M<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`
M26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C
M;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A
M9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B
M969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L
M:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@
M6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)
M1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS
M92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G
M7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@
M;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!)
M;G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A
M;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A
M;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O
M9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`
M271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R
M,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y
M($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG
M:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S
M`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@
M5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!+97EW;W)D<P!+:61S`$MI<FEB871I`$MO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI
M8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U
M=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,
M87-T(#(T(&AO=7)S`$QA<W0@2&%L9@!,87-T($UO9&EF:65D`$QA<W0@36]N
M=&@`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D
M871E9#H`3&%S="!996%R`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S
M(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%S="!W965K`$QA='9I80!,
M87<`3&%Y;W5T`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E
M<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C
M:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN
M($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H
M="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO
M=V5R`$QI;65R:6-K`$QI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.@!,
M:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T
M($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE
M;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB
M90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E
M<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]?8V%T:6]N`$QO861I
M;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO
M=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W
M97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!
M='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O
M;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C
M87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I
M`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E(')E;6]T92!C
M86QE;F1A<G,N`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M
M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-
M87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D
M*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S
M`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O
M9B!%=F5N=',`36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI
M;75M(&QE;F=T:`!-87D`36%Y;W1T90!-90!-961I8VEN90!-965T:6YG`$UE
M;6)E<G,`365N=2!!;&%R;7,`365N=2!,:7-T`$UE;G4@;6]D93H`365R9V4@
M8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B
M=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I
M9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E
M<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E
M9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S
M=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:6YU=&4H<RD`36ER<F]R
M`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R
M871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO
M;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-
M86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S
M`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYD87D`36]N9V]L:6$`
M36]N=&@`36]N=&@@5FEE=P!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1H
M;'D@179E;G1S($QI<W0`36]N=&AL>3H@4F5C=7)S(&5V97)Y`$UO;G1H<R!!
M:&5A9`!-;VYT:',@0F5F;W)E`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R
M92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E
M9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@
M4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``
M36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',`375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O;F5N=',@9F]U
M;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S=7!P;W)T960N`$UU;'1I<&QE('-E
M;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@
M0V%L96YD87)S`$UY($-A;&5N9&%R<SH`37D@1G)E92]"=7-Y(%523`!->2!0
M;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!
M9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T
M:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S
M8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S
M8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`
M3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($5V96YT`$YE=R!-97-S
M86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE
M=R!:96%L86YD`$YE=R!C86QE;F1A<B!C<F5A=&5D(&%N9"!A=71O;6%T:6-A
M;&QY('-H87)E9"!W:71H(&9O;&QO=VEN9R!G<F]U<"AS*3H@)7,N`$YE=R!P
M87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="`R-"!H;W5R<P!.97AT($1A>0!.97AT
M($UO;G1H`$YE>'0@5V5E:P!.97AT(%EE87(`3F5X="!D87D`3F5X="!O<'1I
M;VYS`$YE>'0@=V5E:P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.
M:6=H=`!.:75E`$YO`$YO(&%L87)M`$YO(&%T=&5N9&5E<P!.;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8V%L96YD87)S(&%R92!A=F%I
M;&%B;&4@=&\@9W5E<W1S+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N`$YO(&5N9"!D871E`$YO(&5V96YT<R!T;R!D:7-P;&%Y`$YO(&9I
M;&4@=7!L;V%D960`3F\@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL
M86)L92!F;W(@)7,`3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+@!.;R!I
M8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P
M<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I
M960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R96-U<G)E
M;F-E`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S
M`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QI9"!E;6%I;"!A
M9&1R97-S(&9O=6YD`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC
M:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H
M97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A
M>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&9O
M=6YD`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.
M;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:69I8V%T:6]N
M<P!.;W9E;6)E<@!.;W<`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+
M`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9FEC90!/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P
M87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VX`
M3VX@86QL(&-A;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\`3VX@86QL
M('-H;W=N(&-A;&5N9&%R<P!/;B!M>2!C86QE;F1A<G,@;VYL>0!/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W
M`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S
M:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA;`!/<'1I;VYA;"!!='1E
M;F1E97,`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]V97)V:65W`$]W;F5R
M`$]W;F5R(%!E<FUI<W-I;VYS`$]W;F5R.B`E<P!004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$
M:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI
M8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@
M4VAE;&P`4$T`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@
M4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I
M;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L
M874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P
M=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D
M`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O
M<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A
M=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A
M<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W0@179E;G1S($QI
M<W0`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0871T97)N`%!E
M;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N
M86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\`4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S
M:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN
M97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R=&%L($]P=&EO;G,`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI
M<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N
M(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA
M;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ
M(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N
M97<@=VEN9&]W`%!R979I;W5S($1A>0!0<F5V:6]U<R!7965K`%!R979I;W5S
M(&1A>0!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@
M2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M
M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI
M8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!1=6]T
M80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I
M;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3
M;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E
M860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M8W5R(%5N=&EL`%)E8W5R<F5N8V4`4F5C=7)R96YC92!$871A`%)E8W5R<F5N
M8V4@16YD($1A=&4`4F5C=7)R96YC92!);G1E<G9A;`!296-U<G)E;F-E(%1Y
M<&4`4F5C=7)S(&1A:6QY`%)E8W5R<R!M;VYT:&QY`%)E8W5R<R!W965K;'D`
M4F5C=7)S('EE87)L>0!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H
M`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A
M;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M
M87)K<P!296UI;F1E<CH@)7,`4F5M;W1E($-A;&5N9&%R<P!296UO=&4@0V%L
M96YD87)S.@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92`E<P!296UO=F4@
M071T96YD964`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!2
M96UO=F4@=7-E<CH@)7,`4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H
M('1H92!I;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R!D96QE
M=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T
M<F]N9SX`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+@!297%U:7)E9`!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@071T96YD965S`%)E
M<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@
M4&%S<W=O<F0`4F5S970@=&\@1&5F875L=',`4F5S<&]N<V4`4F5S=&]R92!,
M87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE
M=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E
M<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI
M80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O
M<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`
M4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T53
M4P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@
M3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!3
M86EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?
M<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`
M4V%T96QL:71E(%!R;W9I9&5R`%-A='5R9&%Y`%-A=61I($%R86)I80!3879E
M`%-A=F4@(B5S(@!3879E("5S`%-A=F4@07,@3F5W`%-A=F4@071T96YD965S
M`%-A=F4@179E;G0`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4
M+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@0V%L96YD87)S`%-E87)C
M:"!%;F=I;F5S`%-E87)C:"!297-U;'1S`%-E87)C:"!F;W(@8V%L96YD87)S
M(&-O;G1A:6YI;F<Z`%-E;&5C="!&:6QE<P!396QE8W0@82!C86QE;F1A<B!T
M;R!E9&ET`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E
M;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E
M<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@8V%L96YD87)S('1O(&1I<W!L
M87DZ`%-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L
M87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E(&1E9F%U;'0@=FEE
M=RX`4V5L96-T(&YO;F4`4V5L96-T('1H92!C86QE;F1A<B!T;R!I;7!O<G0@
M=&\Z`%-E;&5C="!T:&4@8V%L96YD87(H<RD@=&\@97AP;W)T(&9R;VT`4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`
M4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F:7)S="!W
M965K9&%Y.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z
M`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W.@!396QE8W0@=&AE('9I
M97<@=&\@9&ES<&QA>2!O;B!S=&%R='5P.@!396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RX`4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H92!P
M;W)T86PN`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@
M4TU3`%-E;F0@82!C86YC96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E;F1E
M97,@=VAE;B!D96QE=&EN9R!T:&ES(&5V96YT`%-E;F0@86X@96UA:6P@=&\@
M)7,`4V5N9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L;"!A='1E;F1E97,@
M=VAE;B!S879I;F<@=&AI<R!E=F5N=`!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!E;F0@9&%T
M90!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!R96-U<G)E;F-E(&5N
M9"!D871E`%-E="!S=&%R="!D871E`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@
M>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H
M97(@=7-E<G,G(&9R964O8G5S>2!O<'1I;VYS+@!3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y
M;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R
M969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3
M971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`
M4VAA<F4@;F]T(&9O=6YD.B`E<P!3:&%R960@0V%L96YD87)S`%-H87)E9"!#
M86QE;F1A<G,Z`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S
M<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!#
M86QE;F1A<@!3:&]W(&-A=&5G;W)Y(&QE9V5N9#\`4VAO=R!D96QE=&4L(&%L
M87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I;B!C86QE;F1A<B!V:65W<S\`
M4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@
M=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&1U92!T
M87-K<R!I;B!T:&4@8V%L96YD87(_`%-H;W<@9G)E92]B=7-Y(&QE9V5N9#\`
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]N
M;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S970_`%-H;W<@<&EC:V5R
M`%-H;W<@<VAA<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_`%-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T87-K<R!U<VEN9R!C871E
M9V]R>2!C;VQO<G,_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&EM92!O9B!D87D@8F5T=V5E;B!E86-H(&1A>2!I;B!W965K
M('9I97=S/P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO
M=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:65R
M<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H
M;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L
M;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO
M=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4V]L
M;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R
M('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A
M8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN
M`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T85]R=`!3=&%N9&%R9`!3
M=&%R(%1R96L`4W1A<G0@1&%T90!3=&%R="!/;@!3=&%R="!4:6UE`%-T87)T
M('EE87(`4W1A=%]U<P!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G
M92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@
M;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-3
M70!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B
M;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@
M8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY
M(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R
M960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S
M(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A
M=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S
M9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A
M;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N9&%Y`%-U;FYY`%-U;G)I
M<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3
M=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y
M;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N
M9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L
M90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU
M;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A
M='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T
M<F%T:6]N`%1E;G1A=&EV90!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E
M>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($5D:70@071T
M96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N="X@17AI=&EN9RX`
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AO<F1E
M+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E
M<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE
M($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL
M>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE
M(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT
M(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI
M<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V%L96YD87(@(B5S
M(B!C86YN;W0@8F4@9&5L971E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E
M96X@8W)E871E9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE(&-A;&5N9&%R("(E<R(@:&%S(&)E96X@<F5N86UE9"!T;R`B)7,B
M+@!4:&4@8V%L96YD87(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&-A;&5N
M9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S`%1H92!C;VYT86-T($E$(&YU
M;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T
M(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E;F0@9&%T92!M
M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N`%1H92!E=F5N="`B
M)7,B(&AA<R!B965N(&%D9&5D('1O("(E<R(@8V%L96YD87(L('=H:6-H(&ES
M(&]N("5S(&%T("5S+@!4:&4@979E;G0@(B5S(B!H87,@8F5E;B!D96QE=&5D
M(&9R;VT@(B5S(B!C86QE;F1A<BP@=VAI8V@@=V%S(&]N("5S(&%T("5S+@!4
M:&4@979E;G0@(B5S(B!H87,@8F5E;B!E9&ET960@;VX@(B5S(B!C86QE;F1A
M<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N`%1H92!E=F5N="!N;W1I9FEC871I
M;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+@!4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B
M92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9F]L;&]W:6YG(&ES(&$@;6]R
M92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z`%1H92!I9&5N
M=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED
M92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N
M(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S
M<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D
M(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A
M8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O
M=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H
M92!R97%U97-T('=A<R!I;F-O;7!L971E+B!3;VUE('!A<F%M971E<G,@=&AA
M="!A<F4@;F5C97-S87)Y('1O(&%C8V5P="!O<B!D96-L:6YE(&%N(&5V96YT
M(&%R92!M:7-S:6YG+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E
M(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y
M(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R
M960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S
M(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&5V96YT
M<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82X`5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`
M5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET
M97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W
M87,@86X@97)R;W(@86-C97-S:6YG('1H92!C86QE;F1A<CH@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@979E;G0Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A
M<R!A;B!E<G)O<B!E9&ET:6YG('1H92!E=F5N=#H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!M;W9I;F<@=&AE(&5V96YT.B`E<P!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('-E;F1I;F<@86X@979E;G0@;F]T:69I8V%T:6]N('1O("5S.B`E<P!4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL
M<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@97AP;W)T+@!4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II
M<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F:6QE(&9O<FUA
M="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C
M;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N
M8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=P!4:'5N9&5R`%1H=7)S9&%Y`%1I8VME=',`5&EM90!4:6UE
M(%-P7V%N`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I
M;VX`5&EM92!S<&%N`%1I;6]R+4QE<W1E`%1I=%]L90!4:71L90!4:71L92`H
M=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI
M;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O
M:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')I
M;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U97-D87D`5'5N
M:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N
M`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP90!4>7!E('EO
M=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DPZ`%5G86YD80!5:W)A
M:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`
M56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S
M(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B
M.B`E<P!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@
M9&5L971E("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C
M=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N
M(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I
M;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!R96YA;64@(B5S(CH@)7,`56YA8FQE('1O(')E;F%M92`E<R!T
M;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<P!5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S
M('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W
M<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI
M<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z
M("5S`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P
M9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!D871E9#H@)7,N`%5P9W)A9&4@
M<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I
M;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T
M=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z
M("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($EN=&5R9F%C
M90!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A
M8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A
M9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@
M<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI
M<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``
M5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A
M;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L
M80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`
M5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R
M>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6
M:65W($1A>0!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`
M5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`
M5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--
M5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/
M32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`
M5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`
M5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E9&YE<V1A>0!7965K`%=E96L@
M)60`5V5E:RAS*0!7965K;'D`5V5E:VQY.B!296-U<G,@979E<GD`5V5L8V]M
M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y
M+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T
M(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q
M=6]T92!C:&%R86-T97(_`%=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K
M('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S/P!7
M:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE
M;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_`%=H97)E:7,@075S=')A
M;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@
M=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7
M:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P
M965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7;W)K(%=E96L`5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"X`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C
M="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R
M`%EE87)L>0!996%R;'DZ(%)E8W5R<R!E=F5R>0!996UE;@!997,`665S+"!)
M($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@979E;G1S+@!9
M;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF:65D(&5V96YT
M+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&]N;'D@=7-E
M('1H:7,@9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN`%EO
M=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@
M;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@
M9&\@;F]T(&AA=F4@86X@96UA:6P@861D<F5S<R!C;VYF:6=U<F5D(&EN('EO
M=7(@4&5R<V]N86P@26YF;W)M871I;VX@3W!T:6]N<RX@66]U(&UU<W0@<V5T
M(&]N92`E<VAE<F4E<R!B969O<F4@979E;G0@;F]T:69I8V%T:6]N<R!C86X@
M8F4@<V5N="X`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V
M96YT<R!T;R`E<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D
M(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L96YD87(N`%EO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O(&1E;&5T92!T:&ES(&5V96YT+@!9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N`%EO=2!H
M879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@<W!E8VEF:65D(&%N(&EN
M=F%L:60@8V%L96YD87(N`%EO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E<'1E
M9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N`%EO=2!H879E('-U8V-E<W-F
M=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N`%EO=2!H
M879E('1E;G1A=&EV96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E
M=F5N="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M`%EO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N`%EO
M=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@<F5Q
M=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T
M;R!Y;W5R(&-A;&5N9&%R<RX`66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE
M9"!W:&5N(&5V96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S
M+@!9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R
M92!E9&ET960@:6X@>6]U<B!C86QE;F1A<G,N`%EO=2!R97%U97-T960@=&\@
M8F4@<F5M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(
M;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S
M92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN
M="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-A;&5N
M9&%R`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA
M`%IA:7)E`%IA;6)I80!::6UB86)W90!;2&ED92!1=6]T960@5&5X=%T`6U!R
M;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=`%M5;FYA;65D(&5V96YT70!;;&EN92`E<R!O
M9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]!;&%R;0!?0F%S:6,@4V5A<F-H`%]#
M3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]%9&ET`%]';W1O`%]'<F]U<',`
M7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQO
M9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7TUY($-A;&5N9&%R<P!?
M3F5W($5V96YT`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V
M92!,:6YK+BXN`%]396%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN
M`%]4;V1A>0!?57-E<G,`861D<F5S<R!B;V]K`&)E9F]R92!T:&4@979E;G0@
M<W1A<G1S`&-A;&5N9&%R`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N
M;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&1A>0!D87DH<RD`9&%Y<P!E
M;G1R>2!N;W0@9F]U;F0`979E;G1S+F-S=@!E=F5N=',N:6-S`&9I;&4`9G)O
M;0!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S
M="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@
M97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UM`&UO;G1H
M*',I`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`
M;F]T97!A9`!O;B`E<R!A="`E<P!O;B!T:&4@<V%M92!D871E`&]N('1H92!S
M86UE('=E96MD87D`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A
M:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S
M`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL
M=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE
M9`!U;FYA;65D`'5S97(@<V5L96-T`'9#86QE;F1A<B]I0V%L96YD87(`=D-A
M<F0`=D5V96YT(&YO="!F;W5N9"X`=SH`=V5A=&AE<BYC;VT`=V5E:P!W965K
M*',I(&]N.@!W965K<P!Y96%R*',I`%!R;VIE8W0M260M5F5R<VEO;CH@2W)O
M;F]L:71H(#(N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#$M,#4@,34Z
M,#0K,#@P,`I03RU2979I<VEO;BU$871E.B`R,#`S+3`Q+3`X(#$P.C4S*S`Q
M,#`*3&%S="U4<F%N<VQA=&]R.B!$879I9"!#:&%N9R`\9&%V:61`=&UV+F=O
M=BYT=SX*3&%N9W5A9V4M5&5A;3H@5')A9&ET:6]N86P@0VAI;F5S92`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U"24<U"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#@M8FET"@`@*"5S(*31JV4I`"`HI]:QML'D("5S*0`@
M*"5S(*31I+HI`"`HI+6DT2D`("BI^J31*0`@**Q1I-$I`*GS`"(E<R(@I*.L
M3Z1`K=.EV+_]`"(E<R(@I*.L3Z1`K=.FLZ[$JKJ_[[[<+@`B)7,B(*E\I;RF
M8B!(3U)$12"JNK7YI57`R2A296=I<W1R>2FDI+-=J7<N`*?DI*.H["`B)7,B
M('1R964@<F5N9&5R97(N`"(E<R*D=Z:HI5RJNJ5;I$JH[+ASLM6H=++.I*0N
M`"(E<R*D=Z5;I$K%=JVMJ'2RSBX`(B5S(JC#I;RKV*7?.B`E<RX`I'>HSZ7.
M("4N,F9-0B`LKF6V<2`E+C)F34(@++/1OFP@*"4N,F8E)2D`)60@)7,@I4BD
MSB`E<P"GY*CL("5D(*W3IN:HQK[D`+/,JO&D0*:XL4N]6,7<I_.I\R`E9""D
MT:ME+@`E9""MTZC&I?,`L\RJ\2`E9""DT:[PMDBY=[/X`"5S("T@L\:GT;_]
M`"5S(*31("5S(*[)("5S(*3``"5S(*O\K[X`)7,@2T(`)7,@NOO%0+[>IT`@
M+2"]5+M[`"5S(+-=J7<`)7,@M?FE50`E<R"F4+=.MK6EV``E<R"D=Z9SIF(`
M)7,@IF(@)7,@)7,`)7,@I5BN=:1(K?L`P,FNUR`E<R"D=[;7I$JGN::H`"5S
M(*1WM$ZD5:9#J,:VM:JZNOO%0+[>IT"T3KK\+B"]T*GSIKFNR:3$O^^G0;=1
MK6Z^WJ=`JKJVM:78+@"ELKO=K6X@)7,`)7,@I,``I^2DHZCL("5S+@`@)7,@
MJ.P@)7,@ID`@)7,`)7.JNK-QL%2__0`E<ZJZIN:HQK[D`"5SJKJSQJ?1O_T`
M)7.JNJO=O^S#KP`E<SH@)7,`)7,Z(+-OJ\JK2*7SI*.D0*EWKW6ET:M(I*2J
MNK%(I?.D2*G2L4BU;RX@O="J8+=.I%6F0ZG2IK.JNKKTN/2S<[6RIK.E::_@
MK*JZ?*=!JKJMTZ1(N.JNQBX`*,))O^^FYJC&ON2F5[K9I4BDP;2KIN:HQK[D
MIF*E1+7XM:&DI*JZI6FHHZG**0`J(,))O^^W<[Q7I4BGN::H("H`*B"]T+_O
MOMRF8:=]("H`+""P?:VW(``L(+!]K;<@)7,@)7,`+,7<I,:V<;%Q("5S(*CL
M("5S`"TM(+_OOMP@+2T`,2"F[*58KG6D2*W[`#$@K=.HQJ7S`#$@I'"NR0`Q
M,B"D<*[)J.X`,34@I,#$P0`R,""DP,3!`#(T(*1PKLFH[@`R-""D<*[)J.X`
M,S`@I,#$P0"D5Z1`K;8`/'-T<F]N9SZE6*YUI$BM^SPO<W1R;VYG/B`HJT2E
MLK:W*0`\<W1R;VYG/K1YK7H\+W-T<F]N9SX@*+_OMK4I7W``/'-T<F]N9S[#
M]L'DIG(\+W-T<F]N9SX@*+_OMK4I`#QS=')O;F<^K:N]QCPO<W1R;VYG/B`H
MO^^VM2D`IKFPS[;TI;*VMZUNJ_RI=[CJKL:N=Z;XJD&ZW2X`M6^ES:1&I$"M
MT\19K:NJNK_YNWX`L?VE6[%+MFRE\RS!V;O=K6ZFLZ1`K=,@4$=0(*2]MGVJ
M]\9?+@"Q_<7GP]*D=\.QL[FJNK9LI?,LP=F[W:UNIK.D0*W3(%!'4""DO;9]
MJO?&7RX`L?VXT;%+MFRE\RS!V;O=K6ZFLZ1`K=.DO;9](%!'4""J]\9?+*AP
ML4L@4$=0(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_;#UIN:V;*7SP[&SN2S!V;O=
MK6ZFLZ1`K=.DO;9](%!'4""J]\9?+*APL4L@4$=0(*KWQE\LI4BDSK-QP_:D
M9J5/+@"Q_;C1L4NV;*7S+,'9N]VM;J:SI$"MTZ2]MGT@4TU)344@JO?&7RRH
M<+%+(%--24U%(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_;#UIN:V;*7SP[&SN2S!
MV;O=K6ZFLZ1`K=.DO;9](%,O34E-12"J]\9?+*APL4L@4R]-24U%(*KWQE\L
MI4BDSK-QP_:D9J5/+@"Q_:5;L4NV;*7S+,'9N]VM;J:SI$"MTR!334E-12"D
MO;9]JO?&7RX`I%>DR`"DR*MEIK.VLP"DR*MEI'"K0@"DR*MEIK.K0@"DR*ME
ML'VK0@"DR*MEL'VSMP"DR*ME+Z3(J^$`05!)(+USN+D`P_:I\[-OK=.]<[_H
MOKD`P_:I\RXN+@"EOZ15I.@`I;^DI*6A`*1WL;6H_`#%=JVMI*.HK"RU3*IK
MJ]BEWR!61E,@I=B__2X`Q7:MK:2CJ*PLM4RJ:ZO8I=\@5D93(,#)KM<N`+%B
MN+FXZK!4`+%BN+F[4+%+O5@`L6*XN:1WK>&ULBX`M;*Q8@"V:;:EMVJT35]V
M`+=SO%<`MW.\5Z:XN'.RU0"W<[Q7I&S%=JVM`+=SO%>HQJ7S`*9BIKFW<[Q7
M.@"W<[Q7N'.RU0"W<[Q7Q7:MK0"W<[Q7IKBX<[+5J.P@(B5S(@"W<[Q7IKC%
M=JVMIMPB)7,B`+=SO%>D0*W3N[>ZW:;FJ,:^Y`"W<[Q7I$"HQJ7S`+=SO%>D
M0*W3J,^ESJK,.@"W<[Q7I5BN=:1(K?L`MW.\5\3FINP`MW.\5Z1`K=.FJ*W[
M.@"W<[Q7N>\`MW.\5R`E<R"LL"!-;WII;&QA(*JZI,"MM@"W<[Q7J.RJNK-Q
ML%2__3H`MW.\5ZCLI]JJNK-QL%2__0"W<[Q7J,^ESJK,`*1WMW.\5R`B)7,B
M(*CLJ'2RSJ2D+B"F_;5,JFNW<[Q7PT*E?JJZM?FE5;CJL%0Z("5S+@"D=[=S
MO%<@(B5S(B"H[*ATLLZDI"X@IT&R>Z9BI6FE2+9IIN:U;J1*I$8N`+=SO%>H
MSZ7.JLRJNJ5<K^"EV*MELU'#]K.L+@"F8:=]`+-QL%2__0"FJ*RPNMZR>JW[
M("T@K+"HY*5,J,^ESJK,LUVI=\5VK:T`NMZR>@"\<Z=I`+9IMJ6W:K1-`$%F
M9VAA;FES=&%N("BJ_+1)IKTI`,2UI=P`)60@I-&K9<2UI=P`)60@I'"NR:ME
MQ+6EW``E9""DP,3!JV7$M:7<`"5D(+9GJV7$M:7<`#$@I-&K9<2UI=P`,2"D
M<*[)JV7$M:7<`#$@I,#$P:MEQ+6EW``Q(+9GJV7$M:7<`,2UI=RDZ;3!`,2U
MI=RVH;EJ("BDP,3!*0#$M:7<KLFVH0!!;&)A;FEA("BJ_+JXI-JEIZC(*0!!
M;&=E<FEA("BJ_+JXI,ZG4:C(*0"V;*7SIT^F5P"Y[[OT`+GON_2DZ*:A.@"I
MTJ:S`*G2IK.E6*YUI$BM^P"ITJ:SI'?%Y\/2JKJHSZ7.JLP`J=*FLZ6\J-,`
MJ=*FL[ASLM4`J=*FL[E,I6@`J=*FL\5VK:T`J=*FLZ5IJ*.JN@"^XZ3I`+[C
MI.FIRJC&I?,`J=*FLZC&I?,`I7ZNV+UU`*2YLURF;K18K=.Y<:1LMFRE\Z9A
MIWT`I+FS7,7<I_.VM:78O7.XN:JZJZRZ03\`I'>F<Z9B`,7<I_,@24U34""U
M;J1*`,7<I_,@24U34""Q2[U8`,7<I_,@24U34""HSZ7.JLP`Q=RG\[EQI&RV
M;*7SINVG?0#%W*?SO,NJ3P"TP*5.I.6F<@!!;65R:6-A;B!386UO82`HK/S$
M4K#MPL2\KZC(*0"D0*W3M4RNQ*JZK<BS4:C/I<XN`+5OI<VD1J1`K=.EO*J^
MJKJ_^;M^+@!!;F1O<G)A("BF=[E$IM4I`$%N9V]L82`HIG>M]*G4*0!!;F=U
M:6QL82`HIG>F8ZG4KG$I`+#.IE>E3K)ZIG.H^@"UJJ[7`$%N=&%R8W1I8V$@
M**MNMZ6D:K.P*0!!;G1I9W5A(&%N9"!"87)B=61A("BF=[2CI<JN<:3.I-JZ
MN*6LN4:N<2D`I?2F6`#`LZ7.M7NFH0#`LZ7.M7NFH;)-L^8`P+.ESK5[IJ&D
M=[1.NOP`KDVESJCLJ=*FLZJZIKBF0*C)`*?EK>,`N7>F]*1JI'``I7RDZP"J
M_*G4IT*DY2`H5VEN9&]W<RTQ,C4V*0#`H\%9P,FD:J1P`,"CP5G`R:97NMD`
MIT&]5*EWK6ZG4K"C("5S(*JZM?FE5;;<(#\`IT&]5*EWK6ZG4K"C("(E<R(@
MI4BDSJ7TIO.JNJ:XN'.RU2`_`$%R9V5N=&EN82`HJORNVJ?**0!!<FUE;FEA
M("BHR*S\I:>HR"D`J,BL_*6GJ,BDY2`H05)-4T-)22TX*0##P+-.`$%R=6)A
M("BJ_+Y\I-JN<2D`07-C96YS:6]N($ES;&%N9`"DY:9RP\"S3@"HR*QW+Z33
MI:VL=J9AL,\`L/6FYK[>IT"Z^\5`JV7%XZ7<O52[>[GON-P_`*3`L'3$YJ;L
M`*[)MJ$`P_:I\[-OK=.HQJ7SJKJG\Z9HL%2NIZ1WJOZE6Z9B(&E#86QE;F1A
M<B#`R:[7I*0N(*9PJD>G0:JZMFRE\[Y<Q:JS;L7II.2TJ2!I5&EP(*=!I6FE
M2+NTJ?:JNJC/I<ZS;ZW3JOZE\\#)KM>A0;%.J,:E\[W&NW.H[*=!JKJFYJC&
MON2DI"X`P'RXU:=2L*.D0*W3I*.F<Z9BJKJX<[+5+@#`?+C5IU*PHZ1`K=.D
MHZ9SIF*JNL5VK:TN`,!\N-6]<[_HI$"MTZ2CIG.F8JJZN'.RU2X`P'RXU;US
MO^BD0*W3I*.F<Z9BJKJF0*C)+@"E6*YUI$BM^P"E6*YUI$BM^P#$W:G*`*1+
MI.L`075S=')A;&EA("B_1*1JIU&HR"D`075S=')I82`HMOBF8:=1*0!!=71H
M7V-R>7-Q;#H@I^2DHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RX`075T:%]C
M>7)U<SH@IOBJ0;K=J,.EO+2CJ-&XT[:UI.2TJ2X`075T:%]C<GEU<SH@I^2D
MHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RX`075T:%]F='`Z(*?DI*.H[*G2
MN]VM;JJZ($944""IM:;YKDVE\RZ]T*VKMW.]<\2V(%!(4""HPZ5"I5ND2B`M
M+65N86)L92UF='`@O^^VM2RHTJ9P(&-O;F9I9W5R92`M+65N86)L92UF='``
M075T:%]I;6%P.B"GY*2CJ.RITKO=K6ZJNB!)34%0(*FUIOFN3:7S+@!!=71H
M7VMR8C4Z(*?DI*.H[*G2N]VM;JJZ(&MR8C4@J;6F^:Y-I?,N`$%U=&A?;&1A
M<#H@MW.\5ZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!L,@`075T
M:%]L9&%P.B"G4K"CJ,^ESJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]JD&P
MR`!!=71H7VQD87`Z(*?DI*.H[*G2N]VM;JJZ($Q$05`@J;6F^:Y-I?,N`$%U
M=&A?;&1A<#H@M4RJ:[=SO%>HSZ7.JLP@)7,N(*;XJD&^N:9>P+,Z`$%U=&A?
M;&1A<#H@M4RJ:[*^L*.HSZ7.JLP@)7,`075T:%]L9&%P.B"U3*IKI_.W<ZC/
MI<ZJS"`E<P!!=71H7VQD87`Z(*?SMW.HSZ7.JLRS;[:UI5ROX*78JV6HPZ2C
MI.2TJ:78O_VJ0;#(`$%U=&A?;6-A;#H@I^2DHZCLJ=*[W:UNJKH@34-!3""I
MM:;YKDVE\RX`075T:%]S;6)A=71H.B"GY*2CJ.RITKO=K6ZJNB!S;6)A=71H
M(*FUIOFN3:7S+@!)34%0(*;XJD&^N<7GP]*_^;M^+@#%Y\/2I:*QT2X`Q>?#
MTJ6BL=$N("5S`%)!1$E54R#%Y\/2O_F[?BX`1E10(,7GP]*_^;M^+@!334(@
MQ>?#TK_YNWXN`*5II<ZJNL3FINPZ`$%Z97)B86EJ86X@**C(MNNK]+5-*0"M
M2;2Z`*U)M+K#0Z;B`&ME<F)E<F]S(+%+O5B_^;M^+@!K97)B97)O<R"HSZ7.
MJLRF5[K9O_F[?BX`0F%H86UA<R`HI-JKHK"H*0!"86AR86EN("BDVJI,*0"J
M:<.YJKJN_*3E("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:"`HJ7.E6ZG4*0!"
M87)B861O<R`HI-JHJ:9H*0"GY*2CJ.RYSZ7<I=B__2`B)7,B+@"P\KUU`+#R
MI;NW:K1-`$)E;&%R=7,`0F5L9VEU;2`HI/&G4:[)*0!"96QI>F4@**BIJ+VT
MM2D`0F5N:6X@**BIN><I`$)E<FUU9&$@**;*O'VY1BD`0FAU=&%N("BDHZ2F
M*0"ES:3I`*?DI*.H[,"SI<ZU>Z:A(B4R)',BJKJPS[;T(B4Q)',B+@"PS[;T
MLUVI=P"PS[;TJZRZ00"RRL7I`$)O;&EV:6$@**S!IU&Z^ZC(*0"NT<72`*[8
MO74`KMB]=:1JI'``KMB]=0!";W-N:6$@86YD($AE<GIE9V]V:6YA("BJ::1H
MI:>HR*3.ML+!R:WTNONHNBD`I?ZSH0!";W1S=V%N82`HJFFEOJBZ*0"IL[.A
M`$)O=79E="!)<VQA;F0`0G)A>FEL("BDVJ;H*0!"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T@**A:M=PI`$)U;&=A
M<FEA("BK3Z5;IU&HR"D`MK6EV++%N+D`0G5R:VEN82!&87-O("BEK+18K\>J
M:Z_!*0!"=7)U;F1I("B[6K:IIF$I`*:CN$P`JJFML;K>LGH`0U)#`$-23""D
MP+.APDD`IN:HQK[D7V$`P'BF<Z[FI+JN92XN+E]E`*?6J/JJ[*ELI,:I?*6\
MI[FFJ"X`IN:HQK[D7V4`IN:HQK[D`*;FJ,:^Y+I+K6X`IN:HQK[DI'>GN::H
MLDVJQ2X`IN:HQK[D`*;FJ,:^Y*6RMK>M;J:SI$"MTZ97NMDN`+ESK\6MMP!#
M86UB;V1I82`HK%JN2+GK*0!#86UE<F]O;B`HL]BSP;:I*0"U3*IKIMNPRJVK
MN&VQ2[U8++W0P7"UN*=!JKJH=++.NMZR>JW[+@"U3*IKO&>D2L#)KM<@(B5S
M(@"U3*IKLW.]=:;<($E-05`@IOBJ0;ZY.B`E<P"U3*IKJ]BEW[=SJ,:E\P"U
M3*IKMGVQTL#)KM<@(B5S(BX`0V%N861A("BE6ZZSI&HI`*CZKO@`J/JN^+#=
MPT2F7K/X`*1WJ/JN^`"D=ZCZKO@Z("5S`+5,JFNG4K"CP,FNUR`B)7,B+@"G
MY*2CJ.R\R*9SI=B__2X`K\JDUB`G=&%R9V5T1FEL92<@L-&\QK5,JFO$?L3R
MLT*R>BX`M4RJ:[*^L*.EV+_]("(E<R(N`+5,JFNROK"C.R`E9""MTZ1LMK"D
M=Z9SIF(N`+5,JFNMJ[+5H4.ITK2CJ-&JNK!/O_V\QJ78NU"E_:MEJ=+`>*9S
MJKJXZJ[&I*.RQ2X`M4RJ:[;'L&7"LK!4J.RK_*EWJKJXN;U8+@!#87!E(%9E
M<F1E("BZ^[QWJ*0I`+NAJ?JDY:9R`*3`P_Y?>0"DP,/^NU"\T,72`*3`P_X`
M0V%Y;6%N($ES;&%N9',@*+9]L-*X<ZYQ*0"FYK#*N7&XW`#`>*9SKN:DNJYE
M`,!XIG.NYKG4I5(Z`,!XIG.NYJ2ZKF4`P'BF<Z[FMJ&V6CH`IN:PRKEQN-P`
MMNNZN*]3I.4@*$E33RTX.#4Y+3$T*0"X;:2D`$-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R`HI*2K1*9`J4VPZBD`I*2\VB`H25-/+3@X-3DM,C``OLS#TK+3
MN&``OLS#TK[6IK.JS`"^S,/2K$:UI@!#:&%D("BL9+QW*0"G\Z?O`*?SI^^G
M0:JZL4N]6`"G\Z?OIT&JNJJZI?ZF5Z5(I,ZF7K9LIF&G?2X`I=BK9:JZLUVI
M=ZC#I;RDY+2IL4N]6,7<I_,N(+W0P7"UN*=!JKJZWK)ZK?LN`*9RI+@`P,NL
M9+-SM;(N+BY?:P!#:&EL92`HM+RG42D`0VAI;F$@**2DL.HI`,*RQ>FDI*3E
M("A'0C(S,3(I`*6_Q>FDI*3E("A":6<U*0"_[[[<P+.ESK5[IJ$Z`+_OOMRQ
M2[U8`+_OOMRD0*W3J,^ESJK,IE>ZV0"DZ;3!Q>.EW*3HIJ$Z`+?MJ,:E\[-1
MMW.\5RR]<[_HJ<ZG4K"CKLFL3Z=?I4BV;*7SLW&JOCH`M^VHQJ7SLU&W<[Q7
M++USO^BISJ=2L*.NR:Q/IU^S4;-QJKXN`*UNJ,^ESK9LI?.S<:J^JKJFYJC&
MON0Z`+_OOMRVM:78JZRZ0:JZK;>NY@"_[[[<LW&P5+_]I4BW:K1-JL6VHB^F
MH[A,NO2G?3H`O^^^W*K%MJ(OIJ.X3+KTIWVITJUNI5VG=*JZIN:HQK[D.@"_
M[[[<LW&P5+_]I4BE6Z1*JL6VHB^FH[A,NO2G?3H`O^^^W*=!JKJY=[-=IN:H
MQK[D+@!#:')I<W1M87,@27-L86YD("BX=+W/KG$I`*?DI*.H["`E<R"JNL/^
MIT^I=[AQ+@"TN`"R3;"CMTRS;B!/9F9I8V4@O-#%T@"R3;"CK&2XWP"R3;"C
MJ=*FLZ58KG6D2*W[`+)-L*.HSZ7.JLPZ("5S`+)-L*.HSZ7.JLP`LDVPHZC/
MI<ZJS*JZN.JNQ@"QW\+@M+@`J_:WQKFKP>2E2,1^Q/(`0VQI8VMA=&5L;""S
M>KE,($A45%``P_:SK+7XM:$`MK.V<0"FK:9HMK,`L[$`0V]C;W,@*$ME96QI
M;F<I($ES;&%N9',`I^G%?+CJKL:GJ`"GZ<5\P^2LR0!#;VQO;6)I82`HK?2M
MVZ3QJ,@I`,-#IN(`O=6FXKU,`#$VMFFF[,-#IN*E3KU8`,3F.@#$YJ;LO-##
M1`"E9+-Q`+-RPDFDP+EJK<@`J5*E3P"GY::XJ5*E3P"U^[W7`+K9J4D`0V]M
M;W)O<R`HK.R\K\.Y*0"DO:5Q`+EQN*,`P/2YT@"Q^*7S`*YTLJ<`NU`@4$1!
M(+1XI%>KK+EQN*,LM+R\>JNLI.*^]Z5(I,X@3W5T;&]O:R"JNJ90J$*S7:EW
M+@"S7:EWN.JNQKE,M,$N`+-=J7<@)7,`O52[>[%+O5@`IU*PHZC&I?.NR:Q/
MIU^[W:UNO52[>R`_`*1WO52[>P!#;VYG;R`HK>BJ1RD`0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92`HK>BJ1Z9`J4VPZBD`LW.ULJ6B
ML=$N`+-SM;*EHK'1.B``LW.ULJ;<I+VV?:KWQE^F^*I!OKFNR;Y$J=HN`+-S
MM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^1*G:+B"M[*9=.B`E<R`H)7,I`+-SM;*F
MW"!&5%`@P,FNUZ;XJD&^N:6BL=$N`+-SM;BD2`"P3[_]I'>FJ*5<IF&W<[Q7
MIMRG0:JZLW&P5+_]I*0N`,"CP5G`R:[7JKJDNJYEJZRZ03H@`"(E<R(@P,FN
MUZ2ZKF4`Q'[$\@!#;V]K($ES;&%N9',@**SLITJX<ZYQ*0"]QKMS`+W&NW.E
MHK'1.B`E<P"]QKMS`*=!JKJJQ;:B+Z:CN$RZ]*=]IG"D53H`0V]S=&$@4FEC
M82`HK?2TM:1JOJ2E6RD`0V]T92!D)TEV;VER92`HMDBD^J[\J:0I`+5,JFNE
M2"!01U`@I5NQ2[9LI?,Z(`"U3*IKI4@@4$=0(+#UIN:V;*7SP[&SN3H@`+5,
MJFNE2"!3+TU)344@I5NQ2[9LI?,N`+5,JFNLL"!3+TU)344@MFRE\\.QL[DN
M`+5,JFNW<[Q7LW.UN*1(+B`E<P"U3*IKP[2ULB!,1$%0(*;XJD&^N0"U3*IK
MP[2ULB!L9&%P(*;XJD&^N0"U3*IKP,NL9+=LKW$N("5S`+5,JFNS<[6RIMP@
M;&1A<""F^*I!OKD`M4RJ:[-SM;*FW*;XJD&^N2`B)7,B(*C/I<X@1E10.B`E
M<P"U3*IKJ]BEW[!TN&VX<[+5+B`E<P"U3*IKN-&Q2R!01U`@N.JNQCH@`+5,
MJFNXT;%+(%,O34E-12"XZJ[&+@"U3*IKIU*PH[-SM;BD2"X@)7,`M4RJ:Z=2
ML*.P=+AMLDVSYBX@)7,`M4RJ:Z=2L*.G\[=SM7NFH2`B)7,B+@"U3*IKJ$VI
M=Z:LI?.D2*JZN7&D;+9LI?.F[*=]+@"U3*IKP/*H^J>YON.JNK-QL%2__2X`
MM4RJ:\#RJ/JGN;[CJKJP=+AMLDVSYBX`M4RJ:\#RJ/JP=+AMLDVSYJ2DJKJX
M<[+5+@"U3*IKN/RD2K6FLJ0@(B5S(BX`M4RJ:ZO8I=^EV+_]("(E<R(N`+5,
MJFNFVZKWQE^F^*I!OKFH^K%OI+VV?:KWQE\N`+5,JFNV?;'2("(E<R(@I4B\
M9Z1*+@"U3*IKMGVQTB`E<RX`M4RJ:[9]L=*Z^\5`I'6G0+S2LM4@)7,`M4RJ
M:[9]L=*EV+_]("(E<R(N`+5,JFNS<[&U($Q$05`@(*;XJD&^N2X`M4RJ:\6J
MJ/H@)7,N`+5,JFNMJ[=SLUVI=ZC/I<ZJS*JZL4N]6"X@LZ&DP*JZLM.X8*2C
MI;^]5"X@O=#!<+6XIT&JNJATLLZZWK)ZK?NE2*CSIU6S0K)Z+@"U3*IKQ:JH
M^J9SJ/JQL:CNJNTH06-C97-S($-O;G1R;VP@3&ES="D`M4RJ:\6JJ/JS<;!4
MO_TN("5S`+5,JFO%JJCZL'2X;;)-I54N("5S`+5,JFO%JJCZL'2X;;)-I54N
M("5S`+5,JFO%JJCZIOBJ0;ZYJKJLV\/VKU.IR@"U3*IKIEZT7[-=J7<N`+5,
MJFNG4K"CI=B__2`B)7,B+@"U3*IKP'BF<R`E<R"JNK-=J7<N`+5,JFO`>*9S
ML\:E][-=J7<N`+5,JFO`>*9SL\:E][-=J7<Z("5S+@"U3*IKP'BF<Z?SMW.U
M>Z:AJ.PZ("(E<R(N`+5,JFO`>*9SL\:E][-=J7<@)7,N`+5,JFO`>*9SLUVI
M=\#))7,N(*=!I6FE2*C/I<XE<Z2DJKJHY*5,I5ROX,!XIG.S7:EWJ<ZDXK#*
MO<:[<Z15K;&U>Z:AO5BH["`E<RX`M4RJ:[=JM$T@3$1!4"`@IOBJ0;ZY+@"U
M3*IKIU*PHR`B)7,B+@"U3*IKI_.W<[-SM;BD2"X@)7,`M4RJ:Z?SMW.P=+AM
MLDVE52X@)7,`M4RJ:\+0O&<@(B5S(CH@)7,@JKJS7:EW+@"GY*2CJ.P@36]Z
M:6QL82"JNJ3`K;8N(+W0O52[>Z3`K;:L3Z=?MGVQTBX`M4RJ:[WAI*FHSZ7.
MJLP@(B5S(B"D5:9#Q7:MK:CLJTBE\Z=8("(E<R(Z("5S`*?>LTZE>0"PZJYA
M`+W2JNT`J]BEWP"KV*7?IN:HQK[D`*O8I=^D0+=SJ,:E\P"KV*7?I$"MT[-S
MM;(`J]BEWZ1`K=.W<ZJZ`*O8I=^FN*M(I?.G6`"KV*7?`*O8I=^JS*JZQ7:M
MK0"K2*7.I62XN;U8`$-R;V%T:6$@**=*P[FFZ*C(*0!#=6)A("BE:J3:*0"E
MV*ME`*78JV6W?+3!`*78JV6NR;:A`*78JV6Z]*=]`*78JV6JNJC/I<ZJS`"E
MV*MEI-&N\`"EV*MEJKJJK*IP.B``I=BK9:JZK;>NY@"FVZUQI$"HQ[5NI$HE
M<ZOAJ=*M;K#UIN:JNJ1UIT`N`+#%I%4`L,6D50!#>7!R=7,@*,')M+:PQ[2U
M*0"FZ*B]NKBDY2`H2T])."U2*0"FZ*B]NKBDY2`H5VEN9&]W<RTQ,C4Q*0"F
MZ*B]NKBDY2^O4:=*Q/6DY2`H2T])."U5*0!#>F5C:"!297!U8FQI8R`HL;:G
M2J9`J4VPZBD`I.D`N.JNQJC3M[VF5[K9("B]T+#1IM(@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*0"H0Z3I`*3I.B"H0P"^\*JLN.JNQL)SQ/T`N.JNQJYWMVJT30"D
MZ;3!`*:LJ.RDZ;3!`+_OOMRDZ;3!`*31`*31`*=2L*-?;`"G4K"CQ.:F[%]L
M`*11I$>DZP"D4;9IINR\QJ9R`,'"M;0`M.ZDUL%9L<8`N7>S70"Y=[-=IN:H
MQK[D`+EWLUW#0Z;B`+EWLUVJNJBMI??#T:=/`+EWLUVI4J5/N-&J4KZY*%-H
M96QL*0"I=[AQ`*=2L*,`IU*PHR`E<P"G4K"CP'BF<Z[F`*=2L*.HQJ7S`*=2
ML*.X<[+5`*=2L*.L]K_]`*=2L*/%=JVM`*=2L*.A0K)-JL6V;*7S`*=2L*/`
M>*9SKN8`IU*PH\3FINP`IU*PH[)[IG.JNK3`I4Z\RZI/`*=2L*,B)7,BJKK%
M=JVM`+U4J7>M;J=2L*,B)7,BJKK%=JVMI4BDSJ:XQ7:MK2`_`*=2L*.F0P"G
M4K"CJ=*_[[[<JKJHK:7WP]&G3[CJKL8`IU*PHZ78JV6JNL3FINP`IKFG4K"C
ML,JG0+%.KDVESJCL.K;(I=BK9:C&I?,LI=BK9:3.I4BKX:C&I?,LJ<ZITJ:S
M`*=2L*.EV*MEJKJF0P"G\[=SM7NFH2`B)7,B(*1WIU*PHRX`N[RP9:[)MJ$`
M1&5N;6%R:R`HI*:SP2D`M'FM>E]P`+#=PT2T>:UZ`+1YK7H`LM.X8"`HO="P
MT:;2($AO<F1E(+!/O_W`R:[7*3H`LM.X8+W0L-&FTJATLLZZWK)ZM6Z__2X`
MK..U;P#%4\))M\6KUP"SS*OAI$"D<*[)JKK%4\))M\6KUSH@`,53PDFWQ:O7
M.B``L7&EJJ;<I6L`L7&E:Z;<I:H`I=B__0#%XZ7<`*5((#(T(*1PKLFH[L7C
MI=P_`,7CI=RFYJC&ON0`Q>.EW+_OMK4`Q>.EW+C4LM.JNKEWL_@`Q>.EW+EW
ML_@@*%1!1BD`Q>.EW*[FIJ$`ML>P9:9>L?@`1&II8F]U=&D@**9.I:RF82D`
MI*.G4K"C`*2CK6ZJO;&UIG.H^B!M86EN=&5N86YC92YP:'``IF*FYJC&ON2D
MI,7CI=RH[+3!JKJKW;_LJ,:VM2`_`*2CK:N]Q@"RQ*1`M:>P3[_]K$^G7Z5=
MIW3$YJ;LIE>ZV3\@IG"J1ZQ/O="DQ+_O+@!$;VUI;FEC82`HIFBI^J6GI5LI
M`$1O;6EN:6-A;B!297!U8FQI8R`HIFBI^J6GI5NF0*E-L.HI`,'9J%.FL[%B
MN+FVW#\@M?FE52X`I%6X_`"D5;C\("5S`*15N/RS7:EWP,FNUZ5TIG.LL"!0
M2%`@M7NFH2X`I%6IU*5<K^"J[0##Q*M^`*CLM,$Z("5S`+3!MJ$`N7&D;+9L
MI?,`O_F[?@!%8W5A9&]R("BDS*7*IFBZN"D`O7._Z`"]<[_H("5S`+USO^BE
M6*YUI$BM^P"]<[_HL,^V]`"]<[_HIN:HQK[D`+USO^BX<[+5`+USO^C%=JVM
M`+USO^C%=JVM`+USO^@E<ZJZQ7:MK0"]<[_HN[>ZW:;FJ,:^Y`"]<[_HI5BN
M=:1(K?L`O7._Z*3`P_Z[4,-#IN(`O7._Z+_OMK4`O7._Z"(E<R*JNL5VK:T`
MO7._Z"5SJKK%=JVM`+'0J'P`16=Y<'0@**Y*I,XI`$5L(%-A;'9A9&]R("C"
MQ+JXI<NF:"D`I+BE\RXN+@"Y<:1LMFRE\P"Y<:1LMFRE\Z9AIWT`N7&D;+9L
MI?.F[:=]I;*VMZ=KIE@N`+EQI&RV;*7SO52[>P!%;6%I;"UT;RU335,@N6BY
M1+ZY`*KML:&RQ;BY`*K%I=6K2*7S+@"JQ:75M;*J1RX`JL6EU;=JM$VVM:78
M`+6RI_1?9`"DN;-<IMO#P+19M*&D2K?3I/FH[*M(I?.DI"BZ]*VVO7.\9[S2
MIJ$I(#\`L=*PRK?&N:NE:\'DI5ROX*KM/P"ULJ?TI.FTP0"ULJ?TJ?,`M;*G
M]*[)MJ$`M;*G]*9^I?<`J?&D:KUSO^B^N0"F<*I'IT&[W:UNK:NS7;%+O5@L
MO="_Z:1*I$"MTZ9WI?ZPW:5Y+*C2IG`@)Z=!PV2JJZJZIE>ZV2`_)SH`IF*F
MN;_II$J\=KFSJKJZ]*=]`$5Q=6%T;W)I86P@1W5I;F5A("BHJKE$M%BDNJC(
M*0!%<FET<F5A("BDS*7?KU.HO:9W*0"_^;M^`*O8I=^PS[;T)7.NR;5OI<V_
M^;M^`*=2L*.F4*A"P>/"23H@)7,@KLFU;Z7-O_F[?@"G4K"CIE"H0K!/O_TZ
M("5S(*[)M6^ES;_YNWX`Q:JH^J2ZKF4Z)7,@KLFU;Z7-O_F[?@"U3*IKQ:JH
M^B5S.B5SJKJJQ;:B+Z:CN$RXZK!4`*?SMW.Q2[U8.B`E<R"NR;5OI<V_^;M^
M`+QGI$H@(B5S(B"NR;5OI<V_^;M^+@!%<W1O;FEA("BW4JA&I:>HR"D`171H
M:6]P:6$@**;GK\&D\:C(*0"ZV+':`$5U<F]P92`HO-JL=RD`J,:E\Z1WMW.\
M5SH`J,:E\Z1WIU*PHRX`J,:E\Z1WO7._Z#H`J,:E\[%Q("5S(*CL("5S`*C&
MI?.ELK:WK6ZFLZ1`K=.QTJELI.FTP2X`J,:E\Z6RMK>M;J:SI$"MTZ97NMDN
M`*A#(#$U(*3`Q,$`J$,@,B"DP,3!`*A#(#,P(*SMQ,$`J$,@-2"DP,3!`*A#
MIKBU;J1*`*A#(#,P(*3`Q,$`J$,@,2"DP,3!`+UDJ-*MR#H`L/6FY@"N:;9]
M`*EMIE?!<K3Z`*YIMGVXZJ[&IZ@`K6ZH1"`G*2<`J.RTP:3I`+C1NZ&M^P"V
MUZ58`+;7I5BFYJC&ON0`JV6TNL-#IN(`1E10(*17ML>S7:EW+@#%JJCZL+ZF
M;K-=J7>EHK'1`+5,JFNS<[UUIMP@3$1!4""F^*I!OKDN`+5,JFNS<[UUIMP@
M4TU"(*;XJD&^N2X`O<:[<Z6BL=&FVR`B)7,B+@"]QKMSI:*QT:CL("(E<R(N
M`+5,JFNKV*7?I$"MT[=SJKH@4T%33""S<[&U+@"W:+*^I:*QT:CL("(E<R(N
M`,)>J/JEHK'1.B`E<P"TMK-Q`$9A;&ML86YD($ES;&%N9',@JFO$]:=*NM:X
M<ZYQ("BPJ+JXNONOQ[2UN'.N<2D`1F%R;V4@27-L86YD<P#$6:VKO_F[?CH`
MML>O=0"VQZ]U`*1'I.L`MU#$L0"W4,2Q.B``I/*D\JM"`+5UO,BP?;.W`,3F
MINRP?:9#`$9I:FD@*+2TP-DI`,#)KM>\QJ78.B`E<R"MT\#)KM<`P,FNU[S&
MI=@Z("5S(,#)KM<`P,FNU\%@NMX`P,FNUZ97NMD`P,FNU[_OOMP`P,FNUZ17
MML<`P,FNUZ17ML>E7*_@I;RS4:3DM*DN`+E,PF^^N0"GY+1-`$9I;FQA;F0@
M**KBQ/4I`*17I6*DZP"D5ZFV`*E4J7>D\:C2`*17I%7$0:W+`*]"L,H`P_H`
MI=B__2`E<R"DHZ9SIF(`IG*KK,-#IN(`K;FJJP"F7:RPPG/$_;ZYJ,.EO*3D
MM*F\=KFSI5ROX"X`KO"V2+EWL_@@*%1!1BD`N7>S^*31O,8@*+EWL_BDT;S&
MI5VL0:75I-&E2*3.J5VVH:JZN.JNQCNF<*I'N7>S^*31O,:X^ZKXL4ZF^Z7.
MI/&X^[QEM%2JNJJIK;$I`*?1L$^Q2[U8(#\`JNVSY@"D<+MY`*1PNWG#_JNL
M`*1PNWD`I'"[>2`R`+W7OL(`IMNPRL+@JT@`K%"TP:2M`*[8K%L`1G)A;F-E
M("BJ:[#J*0!&<F%N8V4L($UE=')O<&]L:71A;@"JQ;:B`*5II<ZNR;:AN.JP
M5`!&<F5N8V@@1W5I86YA("BJ:\3=NURHR*BZ*0!&<F5N8V@@4&]L>6YE<VEA
M("BJ:\3=K,&G4:6GINBHR"D`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M`*Q0M,&DK0"Q2*7SI$@`L7$`I[F^X[1YK7H`NJ&DZP"E_J97`*78JV6DSJ5(
MJ^$`1V%B;VX@**5;M%XI`,/`M%DZ`$=A;6)I82`HI<RD\:C(*0"Y0\"X`*1`
MK^L`LJ.ES2`E<R"MTZATLLZS7:EW`*1WLJ.ES:JZLUVI=[CJKL8`1V5O<F=I
M82`HL^RJ=JC(ID"I3;#J*0!'97)M86YY("B\=[#J*0!':&%N82`HK7NOQRD`
M1VEB<F%L=&%R("BJO:6LP[FJ^RD`IE>ZV0"K9:FY`*WTO'>ZN`!';V]G;&4@
MIF&YSP!';V]G;&4@MVJT30"ROJ;<("5S`*;'MJ4`1W)E96-E("BGQL.^*0"G
MQL.^I.4@*$E33RTX.#4Y+3<I`$=R965N;&%N9"`HKN:SKL3UKG$I`&=R96YA
M9&$@**[FM^>OQ[E&*0"X<[+5NMZR>@"X<[+5IE>ZV:2CL6^JQ:75`$=R;W5P
M7VQD87`Z(+5,JFNW<[Q7N'.RU2`E<RX@IOBJ0;ZYIE[`LSH@`$=R;W5P7VQD
M87`Z(+5,JFNG4K"CN'.RU2`E<P!'<F]U<%]L9&%P.B"U3*IKI_.W<[ASLM4@
M)7,`N'.RU0!'=6%D96QO=7!E("BM]+QWK*6TMBD`1W5A;2`HP_:N<2D`1W5A
M=&5M86QA("BERJ9AL*BIU"D`KN:NIJ;HKG$`J-.[J\5VK:T`LUBKR*]DJ*4`
M1W5I;F5A("BT6*2ZJ,@I`$=U:6YE82U":7-S874@*+18I+JHR*3QK\&F0*E-
ML.HI`$=U>6%N82`HNURHR*BZ*0"V5Z3ELW.ULKMYJ*4`I^2DHZCL($A45%`@
MQ>?#TBX`2&%I=&D@**[\IF$I`,+XM.HMNG2ZX@#&1P"J[<!9`*KMP%D`2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`*1JN7"K0@"GQJ="J-.D
MY2`H25-/+3@X-3DM."U)*0"PJJO7`+NAJ?H`O7._Z+ZYJ,^ESKNAJ?H`NZ&I
M^@"E8K)Y`+-ON,RL3\#)KM>JNK9]J6PZ`,'TPL,`P?3"PR5S`+"J`*YA7VT`
M2&]L>2!3964@*+'KO\VIHRD`KF$`INVN8:9AIWT`KF&EV+_]`*;MKF&Y<;C<
M`$AO;F1U<F%S("BGN[.CJ=2TM2D`2&]N9R!+;VYG("BMN[3D*0!(;W)D90!(
M;W)D92]+;VQA8CH@MFRE\R`E,B1S(*2DN4JH[+5,KL2JNB`E,21S(%A-3+CJ
MKL8`2&]R9&4O2V]L86(Z(+5,MFRE\[Y!IEBJJZ7S("5S`$AO<F1E+TMO;&%B
M.B"V;*7S("4R)',@I*2GY*2CJ.RJJZ7SJZRZ02`E,21S`$AO<F1E+TMO;&%B
M.B"D=Z:HI5RJNK*^L*,@)7,@(B5S(@!(;W)D92]+;VQA8CH@ON.F6*1UM7N[
MW:UN("=D;VUX;6PG(*JZ(%!(4""IM:;Y`$AO<F1E+TMO;&%B.B"U3*IKJ]BE
MWR`E<R"JJZ7SJKH@6$U,(+[P`$AO<F1E+TMO;&%B.B"U3*IKLKZPHR`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@M4RJ:\#RJ/JSH:7W("5S(*NLND&JNB!-
M24U%(,/1IT^XN;U8`$AO<F1E+TMO;&%B.B"U3*IKIE"H0B`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@M4RJ:Z90J$*DP*C).B`E<P!(;W)D92]+;VQA8CH@
MI;RJOJJZI,"HR2`B)7,B`*3TI:V]=0"D]*6MN=2E4@"D]*6M.@"NR0"G0:9P
MIO.H[*:Y(#\@*+W0L=2M>B$I`*3INU"V9\#+M?BJNJJZL\RD<,7CI=RSYJ;L
M/P"G0:UNIEBHUJ9HI-:MT\3FINRI3S\`P+.XT[GOI;RHT[*CI<VT6*31JL6V
MHB^FH[A,N.JP5*E//P#$YJ;LO,:EV*9`K7`_`*=!K6ZF6*C6IFBDUJ9#J4\_
M`+?#J]<`M\.KUSH@`+?&O5VD:JYV`$AU;F=A<GD@**9)I/JG42D`24U!4""V
M;+UCJ]BEWZ6BL=$Z("5S`$E-05`@MFR]8Z=2L*.EHK'1.B`E<P!)34%0(+9L
MO6.ZS[K0L'2X;:O8I=^EHK'1.B`E<P!)4""F[*=]`$E0(*;LIWVU3*IKJ,^E
MSBX`25`@INRG?:C#I*.F8B!#2412(*JZI+FS7+#/MO2DI"X`IF*KX:VQM*&D
M2J9#7VX`26-E;&%N9"`HID*N<2D`K\*YSZ7<`"5SJKJYSZ7<`+G/I=RDSJ3E
MIG(`J*VE]\/1IT^JNJ97NMDZ`*9PJD>U3*IKI;^]5*9AQ>.EW"P@)7,@I4BE
M=+9]L=*V;*7SJ?.W<[7XM:&W[:2D+@"HSZ7.($EN=&5R;F5T($5X<&QO<F5R
M(,)SQ/V^N:[)IG"J1ZA3IK.LW:CLI?2F\ZJZI'"YSZ7<+""G0:5IK^"[W:UN
MI,2_[[-OK=.VM:78I4C#]K.L(%!.1R"\=KFSJKK!],+#KL2J1RX`IG"J1ZS=
MJ.RS;ZMHJ%.FL[QVN;.JNK!4KJ<LLV^J[:7<IT&JNL)SQ/V^N;5,JFO%XZ7<
MI%>VQZJZO':YLRX`IG"J1Z=!JKJV;*7SOES%JK-NQ>FDHZ3DM*D@:51I<""]
MT*A$+*=!I6FHSZ7.I%6F0Z7TI$"S<[6RJ-.QM:C\J<ZP^ZG:J,:E\RX*"K&U
MJ/RFN:C&I?,Z"B5S"@J\R*[)L;6H_*:YJ,:E\SH*)7,*"K#[J=JFN:C&I?,Z
M"B5S`+QVN;.Y=\3].@"\=KFSNO2G?0"\=KFSNO2G?3H`O':YLZC3IMO#P+19
M`+QVN;.HTZ;;P\"T63H`I%>VQ[QVN;,`O':YLP"VUZ1*IN:HQK[D+*A"QDH@
M)60`MM>D2BP@J$+&2B`E9`"VUZ1*+[;7I5BFYJC&ON0`MM>D2L3FINPZ("5S
M`+;7I$K$YJ;L.@"F8JOAK;&TH:1*ID-?<P"_Z:1*I*.EO[U4JKJG0*7.O5@N
M`+W0P,NL9*=!JKJHSZ7.JLRF5[K9I,ZQ2[U8`*C/I<ZJS*97NMFDHZ6_O52I
MSJK,N7&D;+9LI?.F[:=]I'?%W*?S+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH
M\Z=5LT*R>BX`O%>E6\%9L<8`26YD:6$@**9,J]<I`*W3IT^HSZ7.JLP`26YD
M;VYE<VEA("BF3*6G*0"XZK!4`+CJL%0`M4RE::7.JKJXZK!4+@"F8JOAK;&T
MH:1*Q.:F[%]O`+2AI$JYSZ3Y`+2AI$JJ[:[F`+2AI$JZ]+CTLW.UL@"F8JME
MK;&TH:1*Q.:F[%]#`*9BI=BK9<3FINRKX:VQM*&D2J1`K=.W<\3FINP`IF*E
MV*MEQ.:F[*MEK;&TH:1*I$"MT[=SQ.:F[`"F8J78JV6F0ZOAK;&TH:1*I$"M
MT[=SID,`IF*EV*MEID.K9:VQM*&D2J1`K=.W<Z9#`*9BI=BK9;A@PDFKX:VQ
MM*&D2J1`K=.L<;BH`*9BI=BK9;A@PDFK9:VQM*&D2J1`K=.L<;BH`+2AI$JE
M:;3`I4Z\RZI/`+=SL4N]6+%.L4BU;ZCLLV^MT[9LI?.F8:=].@"F8JOAK;&T
MH:1*P'BF<Z[F`*9BJV6ML;2AI$K`>*9SKN8`IF*KX:VQM*&D2L3FINP`IF*K
M9:VQM*&D2L3FINP`M*&D2K9LI?,`IF*KX:VQM*&D2JQQN*@`IF*K9:VQM*&D
M2JQQN*@`IF*KX:VQM*&D2J9#`*9BJV6ML;2AI$JF0P"F=Z7^L-VE>:JZM:JN
MUSH`M*&D2B_%W*?SO':YLP"TH:1*+\7<I_.Z]+CTLW.UL@#"2;S&I*.HK*5(
MIMRI\[5,JFNVQ[!EM;FP=+AMN'.RU2X`PDF\QJ2CJ*PN`+[CO,8`ON.\QJ9#
M`+5,KL2JNB!51$@HJ,^ESJK,N.JNQJKMP%DI+@"U3*[$JKH@6DE0(+CJKL8N
M`+5,KL2JNL"SI<ZU>Z:A+@"U3*[$JKJGY::XN+F]6"X`L&6E6*JZN.JNQK5,
MKL0N`+5,KL2JNJ78O-"F[:=]`+5,KL2JNL#)KM>NYJ:A`+5,KL2JNK'"Q7:]
M6"X`M4RNQ*JZIF&PSRX`M4RNQ*JZ(&US9U]T>7!E+@"U3*[$JKJISJ?DI*.H
M["!A<&E?:60N`+5,KL2JNJG.I^2DHZCLL-&\QBX`M4RNQ*JZI/?%=JVM+@"U
M3*[$JKJYV:;QP]&G3[U8+@"U3*[$JKJRHZM^O5@N`+5,KL2JNK-QL%2H\ZEW
M+@"U3*[$JKJFK*7SI$@Z(B5S(@"U3*[$JKJDP*C)JJNE\RX`M4RNQ*JZJ-.W
MO:;MIWTN`+5,KL2JNKA5L.J]6+CJKL8N`+CJLJ,`IEZT7[_OOMP`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B`HI>RNU"D`27)A<2`HI>RIU*=**0!)<F5L
M86YD("BW4KJXQ/4I`$ES;&4@;V8@36%N("BPTJYQ*0"GO;.AN7"K0@!)<W)A
M96P@**5(IN*F0RD`P[&U;ZK,`+'7Q>D`271A;'D@*+AQI&JG42D`2F%M86EC
M82`HI/JV4J5;*0"D0*3K`$IA<&%N("BDZ:6[*0"DZ:3E("A)4T\M,C`R,BU*
M4"D`OT&FZ*YQ`$IO<F1A;B`HK/FEN2D`I$.DZP"DNZ3K`+GON_0`N&VDI`"E
MJJ5KN>^[]`"^8:6JN>^[]`"^8:5KN>^[]`!+87IA:VAS=&%N`*M/KV2M[+S+
M(#\`2V5N>6$@**K6J,@I`$ME<F)E<F]S(+M[P]*_^;M^+@"NUJ3?MW.DX@"J
M]\9?J]BEWP"J]\9?KU.\>`"J]\9?JOBKUP"J]\9?JZRZ00"J]\9?NWFJ:P"E
MV*MEJKJDO;9]JO?&7Z;XJD&^N:2D+*1WN&>F<Z9BIT&JNJKWQE\N`,/VP>2F
M<@"HX+6C`$MI<FEB871I("BP\JB]I-JTM2D`2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8@**5?P?HI`$MO<F5A+"!297!U8FQI8R!O
M9B`HJV[!^BD`P?JDY2`H155#+4M2*0!+=7=A:70@**SLJ\*O4RD`2WER9WEZ
M<W1A;@"JJ:VQL'2X;5]Y`+MYJ*4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,@*+QDL.HI`+/,JO$@,C0@I'"NR0"D5:5BI.L`L\RJ\:1`IKBG
M\[=S`*17K=.DZP"SS*KQI$"FN+%+O5C%W*?SJ?,`I%6IMJ3K`*17IKBG\[=S
M.@"D5Z1`IGX`I%>D0*:XM6ZD2CH@)7,`I%>D0*:XM6ZD2CH@)7,@IML@)7,`
MI%>D0*:XM6ZD2CH@LL2D0*:XM6ZD2@"D5Z1`MF<`3&%T=FEA("BIU++FNONH
MR"D`JFNKWP"JJ:VQL'2X;0!,96)A;F]N("B^I*3:N>`I`*6JP^0`I:K#Y*KM
MP%D`I:K#Y*W(`$QE<V]T:&\@*+_@K\&FJRD`3&EB97)I82`HO^"D\;?GJ,@I
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$@**=1I/&HR"D`3&EE8VAT96YS=&5I
M;B`HID.DY+2PM+6U;BD`MTRK0@"D<*M"`*:MIK.D<*M"`+'?IK.D<*M"`*1P
ML'VK0@"D<*M"IK.Y<`"D<+.W`*1PL'VSMP"EM*ION-8`K:VH[K;7I5BNR;:A
MMJ&Y:CH`LW.UL@"S<[6RPDFH[#H`Q>.EW*[)LW.ULK9LI?.F[:=]J.R]<[QG
MMFRE\ZVVK;$`LW.UL@"F0Z58("T@J,^ESJK,I6FE2*S=J.RS;ZW3JTBE\Z=8
M`*9#I5BXZJ[&KG<`ID.E6+NAJ?J\T,-$`*9#I5BJ[:[F`+!1O=>X<[+5+<#)
MKM?"9`"P4;W7N'.RU2VH1*=5`+!1O=>X<[+5+</1IT^XN;U8`+!1O=>X<[+5
M+;[6IK.JS`"P4;W7N'.RU2VQ2*7SI$@`L%&]U[ASLM4MK7&^7`"P4;W7N'.R
MU2VH^J[XK7&^7`"F0Z58MWRTP:6BL=$Z("5S`*9#I5BHSZ7.JLREHK'1.B`E
M<P"F0Z58J,^ESJK,JKJE7*_@LU'#]K.L`*3EOL<`3&ET:'5A;FEA("BEW[.S
MJ7LI`*9APDE?8P"X_*1*I*0N+BX`M^VF8:[)MJ$Z(`"F8;#/NU"NR;:A`*9A
MPDD`M6ZD2@"U;J58`+5NI$H`M6ZD2J1UIT``M6ZD2J6BL=$L(+W0P,NL9+O5
MI%6JNJ7.I.&F5ZE-L4N]6"P@M4VKX:VKN-4N`+5NI$JEHK'1+@"J^*5Y`+=2
ML:$`IT,`I'"\9Z?&P[Z\QJ9R`*1PO&>IU*1"O,:F<@"D<+QGP[FPJ+S&IG(`
M3'5X96UB;W5R9R`HOV.TR[/Y*0"DZP"H0Z3IL%2NIP!-4RU43D5&(*K^I5O`
MR:[7I*2H4Z:SN.JNQBX`35-'`$UA8V%O("B_1*KY*0!-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8@*+"HJ.2Y>:9`J4VPZBD`
M36%D86=A<V-A<B`HL*BY1J5;M+6E6RD`Q5VS3@"V;*7S`+9LI?.ZWK)Z`*O8
MI=^S<[6R7VLN+BX`36%L87=I("BPJ*G4J\(I`$UA;&%Y<VEA("BPJ*C3INBH
MR"D`36%L9&EV97,@*+"HNKBF8:32*0!-86QI("BPJ*=1*0!-86QT82`HL*BZ
MN*5,*0"ZWK)ZIFBMT[NWNMVFYJC&ON0N`+K>LGJG0:JZI,##_BRHPZ5"K+"D
MP,/^LUVI=\-#IN(N`$UA<#(T(*9AN<\`36%P475E<W0@IF&YSP"D5*3K`,/D
MK,D`O-"P3Z:H(*S=N4POI;RLW;E,`+S0L$^FJ*CDI4RJNL/1IT\@**C2IG`N
M(*VKK6XOI'>F7L+0*0!-87)S:&%L;"!)<VQA;F1S("BPJ*Y,NKBX<ZYQ*0!-
M87)T:6YI<75E("BPJ+2CI:>G2JYQ*0"DQ[!TQ.:F[*2D`$UA=7)I=&%N:6$@
M**U4IU&V\*6GJ,@I`$UA=7)I=&EU<R`HO*^HO:;HM+4I`*2YLURJNK/,I&K"
M2;S&+@"J_J7SO,:EV*1WME>E6*2YLURD5ZVM+@"SS*KQ(#(T(*1PKLFJNK/,
ML*JWQ:O7.B``L\RJ\2`V(*1PKLFJNK/,L*JWQ:O7.B``J,:E\Z17K:V\QJ78
M`+#/MO2D5ZVMO,:EV`"DN;-<L\RD:JKXJ]<`I*VDZP!-87EO='1E("BPJ*SY
MKU.N<2D`I]H`PN6^QP"W?,2S`*:HK?L`I=B__<2UI=P`I5ROX*KM`+_OL^:\
MTJ:A.@"F6*C6P'BF<Z[F`+9LI?,`MFRE\\7GP]*D=Z>YIJ@LIOVL3ZC/I<ZJ
MS*JZP[&SN:MOM4RJ:[-QN4S%Y\/2+@#"LK!4I'>Y3+3!+@#"LK!4JZRZ00!-
M971A<B"PS[;TM4RJ:ZC/I<XN`$UE=&%R(+#/MO2U3*IKJ,^ESBX@LM.X8+W0
ML-&FTJATLLZZWK)ZM6Z__2X`365T87)$0B"I?*6\LW.QM2X`I.BJ:P"DZ*IK
M("(E<R(@I;RS4:EWN'$`I.BJ:Z6\J7>X<2X@I4BI2:5SI.BJ:SH@)7,`I+VH
M[@!-97AI8V\@*+ZEINBM]"D`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9B`HL4NG2L.YI:>FZ*C(*0"DI+:A`$UI;64@JZRZ00"SS*KQ(#(T(*1P
MKLFJNK/,IT.WQ:O7.B``L\RJ\2`V(*1PKLFJNK/,L*JWQ:O7.B``L\RU=;%+
MO5BNQ+3!J7REO*CLM,$`I,#$P0"L3:YG`,+XMK4`I^2DHZCL(%!%05(@I5VX
MRR!(5%107U)E<75E<W0N`+-=J7?`R;_RI:(N(*9PJD>M;JC/I<ZS;ZW3P+.E
MSK5[IJ&G0:6RMK>R>Z9BM$ZRHZ7-I4PN`*?DI*.H[,*RL%2JNB!)1"X`I^2D
MHZCLI;*VMZJZ(%!%05(@I5VXRR!-86EL+@"GY*2CJ.RW?+3!JKH@240N`*Q0
MM,&D0`"FYK#*MFRE\P"WQ:E-`*?SMW.DZ;3!`*W7I^^Z]*=]`+S2LM4`36]L
M9&]V82P@4F5P=6)L:6,@;V8@*+RONKBF:*7+*0!-;VYA8V\@*+ROK\>M]"D`
MK%"TP:1``$UO;F=O;&EA("B[6*5J*0"DZP"DZ\#+M?@`I.NDSJ9^`*A#I.L`
MJ$.DZZC&I?.F0ZKM`*3K.B"H0P"EO*C3I.N\Q@"E2*MEI.N\Q@"[6+;KJ=2O
M4P"DZZS;`*9BLL0E9*;FI^2H[*JZQ.:F[+S&I=BD=[97I5BY=[3!)60N`+RO
MK*6M]`"F:+:SKLFTN`"F:+:SKLFSL0"TN*[)IFBVLP"D5;*^`*6JLKX`I6NR
MO@"D5[*^`*15LKX`I%>RO@!-;WIA;6)I<75E("BR]J14I/&G2BD`O<:_[Z:A
MI%6IU*5<K^"J[0"U;[)[IFBMTR!I0V%L96YD87(@I+BE\SL@MLBE=:3DM*D@
M=D5V96YT+@"]QK_O`*?:JKJQ8KBY`*?:JKJQ8KBYN.JP5`"GVJJZIN:HQK[D
M`*?:JKJFYJC&ON0Z`*?:JKJJQ;:B+Z:CN$RZ]*=]`*W3I$BON*5X`*W3I$BO
MN*5XK;:ML;!TN&T`37EA;FUA<B`HO7&H;"D`I*,LI]JDHZ90MTX`IE>ZV0!.
M86UI8FEA("BHNJ;,I/&HR"D`3F%U<G4@*+_5OGPI`$YE<&%L("BEIZIYNK@I
M`$YE=&AE<FQA;F1S("BR_,3U*0!.971H97)L86YD<R!!;G1I;&QE<R`HLOS$
MW:9WIF&F0[2U*0!.971S8V%P92"LL+#RPJ:JNKKTIWT`3F5T<V-A<&4@OLS#
MTJ=`O&^Z]*=]`$YE='-C87!E(+[,P]*L1K6FNO2G?0!.971S8V%P92"G\[=S
MNO2G?0!.971S8V%P92"G0+QONO2G?0!.971S8V%P92!34TP@IOBJ0;ZYIE>Z
MV0!.971S8V%P92"^S,/2JKJU^;C1`$YE='-C87!E(+[,P]*KK+I!`+KTN/2D
M=:CC`+%QI;P`3F5W($-A;&5D;VYI82`HMW.SV*B]IFBEIZC(*0"W<[Q7I,##
M_@"W<ZC&I?,`O&>K2+6Y("5S`+=SI.L`MW.HSZ7.JLRF5[K9("BK1*6RK6XI
M`$YE=R!:96%L86YD("BOPZ;HQ/4I`+=SJKJFYJC&ON2D=ZO8I[2HPZ5"L4ZF
MV[#*I,"HR;6YN'.RU3H@)7,N`+=SL4N]6`"W<[%+O5BQ3JGS)7BH[+3!+@"W
M<[%+O5BDH[+%IE@N`+=SM?BUH2`H7V)L86YK*0"W<[M$`+=SNT2X<[+5`*15
MI$"H0@"EO*C3(#(T(*1PKLD`I%6D0*31`*15K=.DZP"D5:1`MF<`I%6D0*9^
M`*15I$"DT0"D5:1`K=._[[:U`*15I$"V9P"D5:1`K;8`3FEC87)A9W5A("BE
MIZ5;J=2ERBD`3FEG97(@**6GI.DI`$YI9V5R:6$@**E@I,ZG4:C(*0"QWZ17
M`$YI=64@**_#KDJN<2D`IU\`M4P`J%.FLZ58KG6D2*W[`+5,I6FHT<7CI=RN
M=+*GJKJS7:EWN.JNQBX`M4RE::7.JKJUIK*DJ]BS>2!)4T\@O':YLRX`J%.F
MLZ?EIKB\RZ:A+@"ITJO\J7>JNJ;LN&VD5ZA3IK.PS[;TIG.F8@"H4Z:SM*.H
MT:;FJ,:^Y*97NMFE2*C1($U#04P@Q>?#TBX`J%.FLZ7TIO.FYJC&ON2E::C1
MJ-.[JZC/I<XN`*A3IK/%W*?S+@"U3*IKIF*EV*MEQ7:MK:2DO%>E6Z:XQ7:M
MK2X`J%.FLZO\J7>JNB`E<R"S7:EWN.JP5"X`J%.FLZO\J7>JNB!&5%`@5D93
M(+-=J7>XZK!4+@"H4Z:SJ_RI=ZJZ(%-13"!61E.S7:EWN.JP5"X`J%.FLZO\
MJ7>JNB!344PM1FEL92!61E.S7:EWN.JP5"X`M4RST;YLPDF\QBX`I;RTHZC1
MI=BJNBX`I<.[MP"U3*C&I?.E::C1Q>.EW`#`R:[7I;RD5[;'`*A3IK/#]JGS
M)7.JNJJZJL6VHB^FH[A,N.JP5`"GY*2CJ.P@:4-A;&5N9&%R(+CJKL8N`*?D
MI*.H[+G/I=PN`*;LN&VXZK!4J7REO+-=J7<`J7REO+2CJ-&F[+AMN.JP5"X`
MI;RTHZC1PK*P5"X`I;RK_*EWIE>ZV2X`I;RK_*EWN+F]6"X`J%.FLZO\J7>Q
M2[U8I4BHT2!(5%10(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@24U!4"#%Y\/2
M+@"H4Z:SJ_RI=[%+O5BE2*C1($ME<F)E<F]S(,7GP](N`*A3IK.K_*EWL4N]
M6*5(J-$@3&]G:6X@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!005-35T0@Q>?#
MTBX`J%.FLZO\J7>Q2[U8I4BHT2!334(@Q>?#TBX`I;R_Z:1*($]P96Y34TP@
MI$>DN+#UIN;`R:JZI?ZX]*Y\+B!02T-3(#$R(+-7KN:JNJ5;L4NXZJ[&N]VM
M;J7.J.RXT[5[IJ$N`*A3IK.KW;QFJKJU^:55I=.]T"X`NL^ZT+!TPT*EO+-=
MJ7<`M4P`M4RNYKUU`*E\I;RK_*EWQ.:F[*3`N6JF<J2X+@"U3*[8O74`M4RF
MN<#)KM<`M4R\R*9SI=B__:5IJ-&GUJCZ+@"EO+;'L&6HSZ7.JLRF5[K9J<ZQ
M2[U8+@"U3*5II<ZJNB!834P@N.JNQK-1ML>F7@"GY*2CJ.RFLZ[$JKJY<:1L
MINVG?0"JQ:75K<@`K>RI;+-=J7?`R:2DI^2DHZCLJJFEN[CJL%0N(*VKMW.R
MHZ7-LUVI=\#)+@"F8J=!JKJS7:EWP,FDI*?DI*.H[*JII;NXZK!4+B"MJ[=S
MLJ.ES;-=J7?`R2X`M4P`M4P@*'5S92!I;7!L:6-I="D`I.FFU;#2I.4@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9"`HO]6ZUJ=*KG$I`*5?I6*R>0!.
M;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y("BNOZO"*0"K1*2GJ^$`
MJT2DIZME`*2CK$^D0*W3I=B__0"GY*2CJ.P`M7NFH:E\I;RGN::H+@"DH[-=
MJ7<`I;RS4:3DM*D`L\:GT;_]`*A3IK.E:<)SQ/VJNBRF7J5H+@"S<:J^O^^V
MM0"D4:1`I.L`LGNF8@"\QJ9R`*9RI+B\Q@"F<J2XO&6KUP"FYKS&`*?SMW.P
M=+AMN'.RU:[)I;RK_*EWO,:EV"X`3TL`JJNE\P"JJZ7SJ]BEWZK,`*1+MFFF
M[`"D4:3K`+_LI+VKQP"W<[%+O5BELK:WNU#"PK%+O5BDHZ90+@#"PK%+O5@`
MPL*Q2[U8I*.EO[U4`$]M86X@**K\L-(I`*GS`*G2IK.GVJ_@Q:JH^JJZJKJF
MYJC&ON0`J=*FL\7CI=RDI*JZIN:HQK[D.@"E=:VMJ?.GVJJZIN:HQK[D`*5U
MIK,@24U!4""F^*I!OKFDY+2IJTBE\Z=8I,"HR:5<K^`N`*5UI+FS7*1`K=.V
M;*7SINVG?2X`I76FL[[6IK.JS+M0J'2RSKK>LGJM^Z5II4C%W*?SID"HR<5V
MK:T`IF*W<ZJZM?BUH;9]L=(`3W!E;E-33""_^;M^.B"U3*IKL7$@4R]-24U%
M(,.QL[FJ_J7SN-&V?;CJKL8N`*9BMW.JNK7XM:&V?;'2LW.UL@"G0+=^J'2R
MS@"K1*6RMK<`JT2ELK:WI5BN=:1(K?L`O^^VM0`E<[_OMK4`MK6EV+USN+D`
MLM7"M`"RU<*TL^:F[`"RU<*T`*WLJ6S`LZ7.M7NFH;S+JD\`IF(@)7,Z(*2D
MJKJM[*ELO,NJ3RX`J.2E3`"HY*5,N.JP5`"WI\9;`+[6IK.JS`"^UJ:SJLS%
M=JVM`+[6IK.JS#H@)7,`4$%-(,7GP]*U3*[$+@!014%2.CJV;*7SIOBJ0;K=
M`%!'4""\QJ;LP[&SN0!01U`@I5NQ2[CJKL8`4$=0(*2]MGVJ]\9?`%!'4""D
M=\.QL[DOI'>E6[%+(+CJKL8`4$A0(+5[IJ&]6`!02%`@K_.]6@"D5:3(`*3(
MJ^&D<*M"`*3(J^&P?:M"`*3(J^&FL[.W`*3(J^&P?;.W`*3(J^&TN`"DR*OA
MN7"K0@!03U-)6"!E>'1E;G-I;VX@O_*EH@!02%`@K_.]6E](`+G4I5(`4&%K
M:7-T86X@**3:L/*TM:E:*0!086QA=2`HJ:VO6RD`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9"`HI-JPQ[2UJ5JF^[OBL,\I`%!A;F%M82`HI-JN
ML["H*0!087!U82!.97<@1W5I;F5A("BDVJ6LJ,BW<[18I+JHR"D`4&%R86=U
M87D@**3:J=2F8RD`IFBVLP"Q2[U8`+%+O5C%W*?SI[FFJ"X`L4N]6*2CI;^]
M5`"H4Z:SJ_RI=[%+O5BE2*C1(%)!1$E54R#%Y\/2+@"Q2[U8O52[>P"Q2[U8
M.@"Q2[U8.B``L4N]6*6RMK>G:Z98+@"Y3*5HJKJHQJ7SID.J[0"V2Z17`+9+
MI%<`N/2N?`"\RZ:A`*O=O&:U;K_]H4<`IJBM^P"FRJ3`I/$`L/6FYKK[Q4"^
MWJ=``+5NI$JKX;#UIN:Z^\5`OMZG0#\`I<.D6Z=2L*.FN:C&I?,_`,5VK:T`
M(B5S(JJZQ7:MK:6\LU&G4K"C+@"F<ZCZOD2IV@#%=JVM`,5VK:VZWK)Z`*?:
MJKH`4&5R=2`HK[6^?"D`PV2JJP!0:&EL:7!P:6YE<R`HM>&KW[NK*0"Y<;C<
M`,/`M%D`4&ET8V%I<FX`N;.OP`"]T+9II$K`>*9SKN;"2;_O`+W0O52I=ZUN
MLKZPHZ:YI+BE\SH`O="]5*EWIT&M;J2DPE^FN:2XI?.JNK-SM;(N`+W0O^FD
M2J1`K=.DZZ7WI,ZF?J7W+@"]T+_II$JW<[Q7I,##_JJZIE>ZV3H`O="_Z:1*
MI$"MTZ:SKL2JNB!)4""F[*=]`+W0O^FD2J1`K=.FLZ[$JKJDZ;3!.Z3$O^^F
MN:3KI?>JNJ3IM,$N`+W0O^FD2J1`K=.FLZ[$JKJNR;:A+@"]T+2CJ-&PW<-$
MJKJZ2ZUN+@"]T+_II$JG0:JZJ,^ESJK,IE>ZV:3.L4N]6`"]T+Y<Q:JD5:9#
MI+JN92ZG0:6RMK>F4+=.LV^HQZC&MK6D?J_@J,^ESJATLLXN`+W0O^FD2K=S
MJKJDP,/^IE>ZV3H`4&]L86YD("BJ:<3U*0"L1JIV`*?KLKP`K=.D2*^XI7B_
M[[:U`%!O<G1U9V%L("BXLK7EI/HI`+QVN;.F[+AM`*KMKN:F[+AM`+N\L&6V
M;*7SJ.RS;ZW3JTBE\Z=8("AN;W0@96YF;W)C960@8GD@24U!4"D`L\RJ\2`E
M<R"D<*[)JKJML*M"MG$Z(`"ML*M"/&)R("\^OO>R=@!0<F5F<U]L9&%P.B"G
MY*2CJ.RITKO=K6ZJNB!,1$%0(*FUIOFN3:7S+@!0<F5F<U]S97-S:6]N.B"G
MY*2CJ.RITKO=K6ZJNB!S97-S:6]N(*FUIOFN3:7S+@"N\,"C`*[\I:VML:[P
MP*,Z(`"N\,"C.B``N7?$_0"F8K=SJKJU^+6AN7?$_;QVN;,`JV6D0*3I`*ME
MI$"V9P"K9:1`I.D`I%>D0*W3O^^VM0"F0Z9,I.6E\P"H<+%+JO?&7P"PW<-$
M`+#=PT2T>:UZ`+%-KM<`M*.EW*2ZKF4`I+VV?:KWQE\`I+VV?:KWQE^Z=+KB
M`*2]MGVJ]\9?N.JP5`"DO;9]+ZAPL4NJ]\9?N>^HPZ6\LU&RHZ7-+@!0=65R
M=&\@4FEC;R`HJFFF:+ZDIE4I`%%A=&%R("BE9+E&*0"L9+C?`+K/NM"P=+AM
M`%)302"DO;9]JO?&7R`H)60@INRDN"D`O^^^W+9S`*M"`*:MIK.K0@"QWZ:S
MJT(`L'VK0@"K0J:SL[<`JT+"X+.W`,!(OO>D<+MY`*3QLG8`Q:JH^@#%JJCZ
MMFRE\P"O=:JZK6ZG4K"C("5S(+;</R"S;[:UOMZG0+%.M4RJ:ZOLM%\N`*]U
MJKJM;K)-L*.HSZ7.JLP@)7,@JKJXZJ[&MMP@/R"S;[:UOMZG0+%.M4RJ:ZOL
MM%\N`*VKO<:JO:CL`*VKO<8`K:N]QJ3IM,$`K:N]QKI)I.ZDZ0"MJ[W&MJ&Y
M:@"MJ[W&JZRZ00"H0Z3IK:N]Q@"H0Z3KK:N]Q@"H0[9GK:N]Q@"H0Z9^K:N]
MQ@"H^J[XM%^M[`"MJ[=SON.R>@"MJ[=SON.R>K#*ND&EV+_]I+BE\SH`K:NW
M<[[CLGJMTZ1(K[BE>*2ZKF4Z`+%@LU>J[:7<IJ$`P_;!<,)SQ/V^N0"MJ\6J
M`+7[O=<`M*._]#H@)7,`N[>ZW:;FJ,:^Y`"[M[K=IN:HQK[D.@"[M[K=IOBJ
M0;ZY`+NWNMVZ]*=]("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`
MLKZPHP"ROK"C("5S`+*^L*.E6*YUI$BM^P"ROK"CL,^V]`"ROK"CQ.:F[`"E
M:+"CKN:FH0"ROK"CN>\`IMNF^*I!OKF\R*9SI=B__:2DLKZPHZ1WP'BF<ZJZ
MLUVI=[5[IJ$N`+*^L*,`IMNDY:7SI*2ROK"CIKFD0+A@PDD`LKZPHZC/I<ZJ
MS`"ROK"CJ,^ESJK,.B`E<P"E2+;7I$JJNJ;FJ,:^Y+AMM*NF<Z9BJKJFYJC&
MON0_(#QS=')O;F<^Q+6G:3H@LV^Q3K=\IU*PHZ78JV6FYJC&ON2DI*JZJ=*F
MLZSVO_TN/"]S=')O;F<^`+O=J$2EO+-1IE[`LSH@O_F[?KBYO5@Z`*?DI*.H
M[*G2N]VJNJI!L,@N`*6RMK>M;@`E,B1S(*JZLUVI=Z6RMK>K_*EW("(E,21S
M(@!61E,@JKJS7:EWI;*VMZO\J7<@(B5S(@"S7:EWN.JNQJ6RMK>K_*EW("(E
M<R(`I;*VMZ58KG6D2*W[`*6RMK?$YJ;L`*VKLUT`K:NS7;%+O5@`K:NS7:=!
MJKJQ2[U8.@"MJ[-=IEZDNJEWK<@`IE["T`"F7J9SL\RKX:1`K=.L9+C?`+6R
MJD<`JO"F7K_OMK4`ID&FN+_II$JW<[%+O5@`4F5U;FEO;B`HKV2EIZGTKG$I
M`*9>M%^S7:EW`+KTK;:]<[_HOKF_[[:U`,&\NWD`I6O#Y`"E:\/DJNW`60"E
M:\/DK<@`ID.DNJYE7W<N+BX`J*2FX@!2;VUA;FEA("C#N;"HI:>HR"D`L=O"
MX"`Q.#`@J]<`L&:NR;!W(#DP(*O7L=O"X`"VMJ[)L'<@.3`@J]>QV\+@`*9#
MI+JN90"F0Z2ZKF4`ID,`KN:]=0#$YJ;LNU"F0Z[FO74`Q.:F[*[FO74`ID.N
MYKUU`+#UIN8`4G5S<VEA;B!&961E<F%T:6]N("BK6,.YM+4I`%)W86YD82`H
MOV.F=[E&*0!3+TU)344@I5NQ2\.QL[D`MFRE\Z1WJ,^ESB!3+TU)344@I5NQ
M2P!305-,(,7GP]*U3*[$+@#"LK!4`+CJKL:N=Z_SO5H`I5NQ2[+7NMV^]P"F
MJ*5<`+CJKL:N=Z_SO5I?40"L4+3!I+L`4V%I;G0@2&5L96YA("BX=+NNL,>O
MQRD`4V%I;G0@2VET=',@86YD($YE=FES("BX=*=*J+VTM:9HNM:DSJ6GNONT
MM2D`4V%I;G0@3'5C:6$@*+ATQ5.FZ*C(*0!386EN="!0:65R<F4@86YD($UI
M<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S("BX=*3E
MM,NDSJ[FM^>HNJ1"*0"F4*1`K=.U^+6A("A?<V5L9BD`4V%M;V$@*,+$O*^H
MR+ASKG$I`%-A;B!-87)I;F\@*+ATL*BG4;_5*0!386\@5&]M92!A;F0@4')I
M;F-I<&4@*+ATIFBL_*3.M+:J3*;HI/$I`+W#K%"THZC1JLP`K%"TP:2[`%-A
M=61I($%R86)I82`HJ$:O4:9AJORIU*="*0#`>*9S`,!XIG,@(B5S(@#`>*9S
M("5S`*5TIG.W<\#)`,!XIG.D2*W[`,!XIG.HQJ7S`,!XIG._[[:U`+%.LJ.E
MS:JZLUVI=\#)I4@@4$A0(+MYJ*6NYJ:AP'BF<ZCLIT&JNJ;XJD&^N;S(IG.E
MV+_]I*0N`+-=J7<@)7,@I'?`>*9S+@"G\[=SM7NFH:1WP'BF<ZCL.B`B)7,B
M+@"Y<ZQ0N7"K0@"L[+['`+=JM$T`MVJT3:;FJ,:^Y`"W:K1-I-[`N@"W:K1-
MM;*J1P"W:K1-IN:HQK[DI5VG=#H`O^^^W,#)KM<`O^^^W*UNO7._Z*JZIN:H
MQK[D`+_OOMRD0*W3I.FTP0"_[[[<I$"MT[ASLM6ESJ5(MW.\5P"_[[[<I$"F
M[+=SJKJ^UJ:SJLP`O^^^W*1`LZ&F^*I!OKD`O^^^W*1`INRHSZ7.JLRESJ5(
MMW.\5P"_[[[<J=*FLP"_[[[<J=*FLZ3IM,&DN*7S+@"_[[[<I$"MTZJKI?,`
MO^^^W*UNQ>.EW*JZIN:HQK[D.@"_[[[<IG"F\\7CI=RF5;K8I*.F4*JZP,NU
M^*5(I,ZDNJEWJKK`R[7X`*2CO^^^W`"_[[[<IN:HQK[DI4BVUZ1*N.JNQJCL
M.@"_[[[<K6ZVUZ58JKJFYJC&ON0`J?.E2*15JKJU^+6AI*2_[ZCZIT&M;JJZ
MIG*DN"ZE2+?&N:N]QKMSJ=*_[Z3EIG(LM4VKX;9+I%>DY:7SO7._Z+#/+@"_
M[[[<I.FTP:3`N6HZ`+_OOMRDZ;3!I.FTP:[FIJ$Z`+_OOMRVUZ58KN:FH3H`
MO^^^W,#)KM>E2+;7I$JXZJ[&.@"_[[[<J$.V9ZJZLL2D0*31.@"_[[[<J-.W
MO<#)KM>JNJJZKN:FH3H`O^^^W+']Q=RG\ZJZJ*VE]\/1IT\Z`+_OOMRNR;:A
MI,"Y:CH`O^^^W*3IM,&NR;:AKN:FH3H`O="_[[[<KLFVH;UDL_*E2,7CI=P`
MO^^^W+5NI$JKX:JZJKK`R[7XI.BJ:SH`O^^^W*S;I*RDQ[!TJKJD1ZW3Q.:F
M["X`O^^^W*7.J-/%XZ7<J?.MTZ1(K[BE>*2DJKJHQJ7S+@"_[[[<IT&JNL-#
MIN*P=+AM`+_OOMRPOJ9NNWFHI3H`ML>P9;#=PT2DS\"S`+;'L&7"LK!4`+?M
MJ,:E\[-1IU*PHZOAH4&VQ[!EI$"MTZCZKOBS<:J^M;FITJ:SI5BN=:1(K?L`
MML>P9:1`J\JV;*7SM;D@)7,`M^VHQJ7SLU'`>*9SJ^&A0;;'L&6D0*W3I_.W
M<R_!W+W0LW&JOK6YJ=*FLZ58KG6D2*W[`%-E;F5G86P@*+;KI+JE6[JX*0"W
M4+3ZOKDZ(`"D1:3K`%-E<F)I82!A;F0@36]N=&5N96=R;R`HMNNZN+K[J,B[
M4+M8KU.EIZWTP[DI`*?'N+D`IOBJ0;ZYN.JNQK_YNWZISJK,M4RJ:ZC/I<XN
M`+=\M,&ZWK)Z`+=\M,$@240@I'>Y3+3!+@"W?+3!`*[6J/JDZ+;T`+-=J7>U
MLJ?TI.FTP0"DN;-<IT&I\Z?1L$^Q2[U8JKJNR:W4+*5II4BFVZ;FK:NS7;%+
MO5@N`+-=J7>MJ[W&NDFD[J3I`+-=J7>V?:ELI.FTP0"S7:EWN[>ZW:;XJD&^
MN:17Q-VI\Z=!JKJMTZ1(K[BE>"X`LUVI=Z;;I':ISJ5,I$BJNJK%MJ(OIJ.X
M3+_OMK4N`+-=J7>G0:JZL+ZF;KMYJ*4L(*[)L,^E2*3.I.FTP:[FIJ$N`+-=
MJ7>G0:JZL=*I;,"SI<ZU>Z:A+,-#IN*P=+AM+*VVK;&G\[=SP%>R=BRDSJCD
MI4S%XZ7<O^^VM2X`LUVI=P"G\[=SM7NFH;1.NOP`IK.F;K18K=.F8<))J4VS
M;ZW3L-&\QJ:SP_8Z(`!397EC:&5L;&5S("BVZZGUNK@I`*?DI*.H[*9`J,DZ
M)7,`ID"HR:;FJ,:^Y`"ITJ:SID"HR:JZIN:HQK[D.@#!RJJK`,*RM76Z2ZUN
M`*Q/IU^LL*1JLZ&E]ZJZLW.ULJEWN'&GUK&VI5ROX,'D/P#%XZ7<`,7CI=RF
MYJC&ON0`Q>.EW*3`P_ZJNK7YL$^[H:GZ(#\`IF*FYJC&ON3`R[7XM66ML:2D
MQ>.EW*=2L*,LQ+6EW*5(I,ZMJ\+0MF>TP;G/I=RVW#\`Q>.EW+=SLJ.ES;M0
MK>S`>*9SLUVI=\#)JKJN=+*G+@"F8J;FJ,:^Y*2DQ>.EW*O=O^RHQK:U/P#%
MXZ7<JL6VHB^FH[A,JKJU^;!/NZ&I^B`_`*A#IKBU;J1*J^'%XZ7<I%>D0*:X
MJKJU;J1*KLFVH2`_`*5UQ>.EW*:SLUVI=\2UI=RG0*7.JKJHQJ7S/P#%XZ7<
MPDF_[[ZY`*C#ID/%XZ7<ID"HR:JZIN:HQK[D(#\`Q>.EW*KMKN:^WJ=`I5RO
MX*KM(#\`I4BDP,/^JKK#0Z;BQ>.EW*O=O^RHQK:U/P"I\Z6JP^3%XZ7<("5S
M(*5<K^"J[3\`Q>.EW,!XIG.NYJ2ZKF6Y[[C<I.BV]`#%XZ7<JNVNYJ2ZKF6Y
M[[C<I.BV]`#%XZ7<ID.DNJYEN>^XW*3HMO0`Q>.EW+QVN;.DNJYEN>^XW*3H
MMO0`IF*V9\#+M?BJNK5EK;&DI,7CI=RH0Z1`I-&JNJ[)MJ$@/P#%XZ7<I%>V
MQP"K^<3RL'VK0@"FK::SL'VK0@"QWZ:SL'VK0@"[MZ3HIK.P?:M"`*:LP5D`
M4VEE<G)A($QE;VYE("BWX*1LI'.PZBD`M?FE50##L;.Y`,.QL[FZ=+KB`%-I
M;F=A<&]R92`HMW.E6ZE9*0"D:J1P`+*DN4RZ^\5``%-L;W9A:VEA("BTM:RE
MI>^G2BD`4VQO=F5N:6$@*+2UK*6E[Z6GJ,@I`+.W`+!]L[<`L'VSMP"FK::S
ML'VSMP"QWZ:SL'VSMP"_;K.WLF"KUSH@`%-O;&]M;VX@27-L86YD<R`HK\'#
MN:KYN'.N<2D`4V]M86QI82`HK\&PJ*=1J,@I`+IQNU"XU@"QQJ9#I.BF5K_O
MOMP`J-.WO:9AIWT`4V]U=&@@069R:6-A("BK;JM$*0"K;KS:("A)4T\M.#@U
M.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<P"K;J5BLGD`JL6EU:;F`+:AMEH`MJ&V6KM0N=2E4@!3<&%I;B`HINBO
M6J3Z*0"I5:>CMFRE\P"O4Z[MIG*DN+_II$H`I,"SSL!XIG,`I,"SSL3FINP`
MI,"SSJ9#`+E"L,H`4W)I($QA;FMA("BTM:B]Q/6E9"D`MGVI;*GS7W(`O-"W
MQP"L4+O:JJ?%4;[4`+'2J6RDZ;3!`+9]J6RI\P"QTJELKLFVH0"QTJELIGZE
M]P"JK+I!7W4`K-D`JJRZ00#`>*9SKN:FH0"U\[E$`*=2L*.]=0"F<J;JID,`
MIMNV;*7SIF&G?:2DI6BPH[KTL.RF5[K9`+S+IJ$@6T-34UT`K%"TP:31`*?D
MI*.H[*:XI=B__2`B)7,B`*5$IJX`L&6E6`"\5Z5;("(E<R(@J.RH=++.JKJE
MT[W0I'>P9:58+B"G0:6RMK>UI:CLN-.ET[W0LU&NUJWCJ^&D?J_@M6ZD2BX`
MI%6\T`"FJ*5<`*:HI5RJNJ5;I$H@(B5S(B"H[*ATLLZDI"X`IJBE7*JZIMNH
M=++.I*2R3;"CJ,^ESJK,("(E<R(@JKJXZJ[&+@`B)7,BI'>G4K"CI[FFJ"X`
MIJBE7*JZIMNH=++.I*2ROK"C("(E<R(N`*1WIJBE7*JZIEZT7[-=J7<N(+W0
MK:NW<[C\I$K`R[7XKG2RIRX`I'>FJ*5<JKJSQJ7WLUVI=[CJKL8N`*1WIJBE
M7*JZL\:E][-=J7>XZJ[&("5S+@"FJ*5<JKJG\[=S("(E<R(`I'>FJ*5<JKK"
MT+QG("5S`%-U9&%N("C$K*2F*0"Z2ZUN`*3II5@`I.FXJ`"L4+3!I-$`M+@`
MI.FE6`"DZ:58+Z3IN*@`I.FE6#H@`*3IN*@`I.FXJ#H@`*17O-``I.2TJ0!3
M=7)I;F%M92`HQ*RG4:MN*0"Z[[BY`%-V86QB87)D(&%N9"!*86X@36%Y96X`
M4W=A>FEL86YD("BE=J7+P-G$]2D`4W=E9&5N("BWYZCE*0!3=VET>F5R;&%N
M9"`HM^>D:"D`IE"H0K!/O_VD=Z=2L*,`IE"H0J;FL,JXR[AM`+=JM$VVM:78
MI*2JNKMYJFN_^;M^`%-Y<FEA;B!!<F%B(%)E<'5B;&EC("BQU*=1J,@I`+EP
MJT(`N7"K0J:SK;<`N7"K0@"FK::SJ_G$\KEPJT(`5$%"(*3`N6JNYJ:AP,FN
MUP"J[;/F`*KMKN:DNJYE`*KMKN:DNJYE`*5XQE<`I7C&5P!486II:VES=&%N
M("BV\*9.M+6I6BD`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B`HJ5JI
M?*6GJ,@I`*78O-`Z`*O=O^RHQK:U`+EQN-RXN;U8`+/,JO&D0*1PKLFJNK?%
MJ]<Z(`"WQ:O7`+?%J]<Z(`"WQ:O7/&)R("\^*"5SL*HE<R\E<Z=#)7,I("9D
M96<[)7,`I^2DHZCLO,NJ3R`B)7,B+@"\RZI/NMZR>@"\R*[)`*2ZKF4`K\*D
MY:9R`+GON_2DY:9R`+GON_2DY:9RL[NZW0"L4+3!I7P`KO6DY2`H5$E3+38R
M,"D`5&AA:6QA;F0@**[UL.HI`+USO^C!W+W0JKJU9:VQI'>DHZ9SIF(N(,+W
MMGVDI"X`1E10(*FUIODH97AT96YS:6]N*;5,KL0N`$AO<F1E+TMO;&%B(+[C
MIEBD=;5[J,.EO*3DM*D@(B5S(@!)35-0(*SVO_VU3*IKLU&J[*EL+@!-86EN
M=&5N86YC92##_J=/J,.EO*:HI5RX_*1*`+_OMK6U^+6AI4C#]K.L+L+WMGVD
MI"X`IT&JNJATLLZZWK)ZK?NELK:WI?VS7:EWIFZD0*W3Q7:MK:OANMVD?J_@
MQ?VG0:C/I<[%=JVMJ'2RSBX`J;.NV+UU`*;FJ,:^Y"`B)7,B(+5,JFNS4:=2
ML*,N`*;FJ,:^Y"`B)7,B(*1WJ]BEWRX`IN:HQK[D("(E<R(@I'>G4K"C+@"F
MYJC&ON0@(B5S(B"D=Z?SIE>LL"`B)7,B+@"FYJC&ON0@(B5S(B"D=\!XIG,N
M`*:YIN:HQK[DM4RJ:[-1LDVJQ3H@)7,`P7"UN+BYO5BEO*O\J7<LJL6EU:G.
MIF*XZJ[&KG>DI*?DI*.H["X`I'>FJ*5<JKJQ3L%PM;BD2+=SO%>FW+-QL%2_
M_:2D+@#%Y\/2MFRE\\.QL[F[W:UNIK.D0*W3I'>XT;9]JKH@4$=0(+#/MO0N
M`+!TN&VX<[+5JKK#T:=/N+F]6"A)1"FDHZQ/I;RK_*EW++1.K$^JQ:75J<ZJ
MS*2CIF*XZJ[&KG>DI"X`L'2X;;ASLM6EO*O\J7<N`+O=K6ZD0*W3N&>Y3*5;
ML4NJNKKTN/2S<[6R+@"ULJ?TI.FTP:6RN]VD:JGSMGVI;*3IM,$N`*GSI.FT
MP2`E,R1S+*[)MJ$@)20T<R"JNJC&I?,@(B4Q)',B(*1WMW.\5ZCLIN:HQK[D
M("(E,B1S(B"DI"X`J?.DZ;3!("4S)',LKLFVH2`E)#1S(*JZJ,:E\R`B)3$D
M<R(@I'>FVZ;FJ,:^Y"`B)3(D<R(@I*2G4K"C+@"I\Z3IM,$@)3,D<RRNR;:A
M("4D-',@IN:HQK[D("(E,B1S(J2DJKJHQJ7S("(E,21S(B"D=[USO^BGN::H
M`+6Y)7.JNJC&I?.S<:J^I'>FJ*5<JKJP9:58+@#`R:[7("5S(,"SN-.E7:=T
MI$"MTR`E<R"S7:EW+@#`R:[7("5S(,"SN-.E7:=TI$"HQR`E<R"S7:EW+@"U
M3*IKO<:[<ZCLIMNHK<#)KM<N`*:YP,FNUZ2DJ%.FL[CJKL8N`*5(I%6L3R!R
M9F,X,C(@MFRE\ZJZJNW`62X`P_:I\Z:YJ,:E\Z5(I%6FLZ?SN-2RTZJZL=2M
M>CH`J*VE]\/1IT\@)7,@I'>S4:=2L*,N`*6JKMB]=0!';G501R"D1Z2XP,FJ
MNKCTKGRELK:WJ7>X<:9B($-R>7!T7W!G<#HZ(,/^IT^DI"X`IT&TOZGS("5S
M(+%(M;D@)7,@I$"KRJ5$IJZLL"`B)7,B(*JZJTBE\Z1WLU&V?;'2+@JF_;-O
MJ,.DHZ_@JT_#TKC3JTBE\ZJZI+JN9:1WI[FE_K-1IJRE\Z1(K-VGN:G.I$:X
MT2X`LW.ULJCLO7.\9[9LI?.MMJVQJ=*HSZ7.JKJF5[K9`*6RMK>L3Z1`K=.\
MQJ9R+@!(;W)D95]#<GEP=%]S;6EM93HZ(,/^IT\LI;*[W:UNIK,@;W!E;G-S
M;""\TK+5+@"FN;"^IFX@(B5S(B"XZJ[&IEVLL+97N4RSS*1JI+FS7*W(+*G2
MI4BU3*IKLU'`>*9S`*7.I4C`R[7XIKFXZJ[&P_ZKK"`H)7,I(*JZM7NFH:C#
MI*.F<Z9BJ?.H=++.I%<N`*3>K7JF<J6RMK>LL+/FI$"F<J2X+@"]T*A$J7RE
MO*>YIJ@N(+']L;6H_*G.L/NIVJC&I?.[W:UNI$"HQZ6RMK>PT;S&+@"EJJ5K
MKMB]=0"E:Z[8O74`Q.:F[*3`N6JF<J6RMK>LL+/FI$"F<J2X+@"FN:;XJD&^
MN2`B)7,B(*1WLU&G4K"C+@"FN:;XJD&^N2`B)7,B(*1WLU'`>*9S+@`E<R"J
MNK7YI56[W:A$I'>S4;*^L*,N`*O\J7>JNK!/O_VHPZ2CIG.F8BX`O,BF<\#)
MKM<B)7,BI*.F<Z9B+@"G0:G2O^FD2JJZN.JNQKM0M66ML;CJKL:DH[+%+@"D
M5Z15KMB]=0"D5Z[8O74`L7&D5Z1`K=.H0L9*I*>KX:17ML>JNKCJKL:_\J6B
M+@"D5[;'P,FNUZC#I;RS4<!XIG,N`'=E871H97(N8V]M(+#/MO2U3*IKJ,^E
MSBX`I^2DHZCLO,NFH;!TN&VEV+_]("(E<R(N`*A3IK.HQJ7SLL6F6+-OK=.W
M:K1-M\>K:"X`M4RE::7.JKJ_[[:U+@"U3*K^I?.E::J]L;6V?;'2+@"FN<3F
MINRDI*5=IW2DTZ9HJKJF<KS&+J=!I'>_Z:1*("5S(*W3IG*\QCNG0;_II$JJ
MNJ9RO,:ELK:WI'"I\R`E<RX`MW.\5R`B)7,B(*CLJ'2RSCH@)7,@KLFU;Z7-
MI$"MT[#=PT0N`*;;J'2RSK)-L*,@(B5S(B"JNKCJKL:NR;5OI<VD0*W3L-W#
M1#H`IMNH=++.LKZPHR`B)7,B(*[)M6^ES:1`K=.PW<-$.@"G\[=S("(E<R(Z
M("5S(*[)M6^ES:1`K=.PW<-$`*17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z("5S
M(*6\LU&D5[;'+@"D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E<R"D:J1PME>Y
M3*2YLURSS*1JK<@@*"5D(&)Y=&5S*2X`I%>VQ\#)KM>NR;5OI<VD0*W3L-W#
M1#H@MLBSH:3`JKH@)7,@P,FNU[-1I%>VQRX`IG.H^J;FJ,:^Y#H@)7,@KLFU
M;Z7-I$"MT[_YNWXN`+=SO%>HQJ7S.B`E<R"NR;5OI<VD0*W3O_F[?BX`P,NU
M^+9LI?.NR;5OI<VD0*W3O_F[?BX`O7._Z*C&I?,Z("5S(*[)M6^ES:1`K=._
M^;M^+@"VUZ1*IKFS<;!4O_VXZJ[&KLFU;Z7-O_F[?BX`MM>D2B!I0V%L96YD
M87(@N.JNQJ[)M6^ES:1`K=._^;M^+@"F8K-=J7>J[;/FI*2U;Z7-I$:D0*W3
MO_F[?BZFLZ5IK^"G0;_RNGRD1J6RMK>V\;QGJKK$YJ;L+@"W:+*^J,:E\SH@
M)7,@KLFU;Z7-I$"MT[_YNWX`L/6FYK-QL%2__:O\J7>E7*_@KLFU;Z7-I$"M
MT[_YNWXN(+W0M7FKX:9!N-6D0*:X+@"VQ[!EJ,:E\[-QJKZUN2`E<SH@)7,@
MKLFU;Z7-I$"MT[_YNWX`I_.W<\%PM;BD2+CJKL:NR;5OI<VD1J1`K=._^;M^
M+B"]T+5YJ^&F0;C5+@"G\[=SL'2X;;ASLM6NR;5OI<VD1J1`K=._^;M^+B"]
MT+5YJ^&F0;C5+@"H4Z:SJ,:E\Z5IMM>E6"X`IKD@24U!4""F^*I!OKFHPZ6\
MI.2TJ:M(I?.G6*3`J,FE7*_@+@"S;Z;\I4>DHZQ/I;^]5*JZ(')A<B#`H\%9
MP,FNURX`LV^F_*5'I*.L3Z6_O52JNB!Z:7`@P*/!6<#)KM<N`+-OIORE1Z2C
MK$^EO[U4JKJK2*7.I62XN;U8+@"FN<3FINRL3Z6RN]VM;JJZ+@"FN<3FINRD
MNJYEI76DN;-<ON.\QKS&IG(N`*:YQ.:F[*2ZKF6E=:2YLUR\QJ9RI,ZK7[BY
M+@"FN<3FINRDNJYEI76DN;-<I$NV::;LO,:MR"X`IKG$YJ;LI+JN9:6RMK>L
ML+-RN+FISJK%I=6DP+EJJKJ\QJ9R`*6RMK>L3Z1`K=.\QJ9R+@"FN<3FINRD
MNJYEI;*VMZ5=IW2D0++5I%&DN[9IINRJNB!21T(@PT.FXJ5.O5@LJ-*F<"`G
M(S$R,S1A9B<N`*:YP,FNUZ[FIJ&HPZ6\LU&DY+2I+@"S;ZW3JNVSYJ1WLU&S
M0K)ZN4PN`+-OK$\@)7,N`+-OK$\@2V]L86(@N'.RU:JZI$"MTZJKI?,N(+']
MP,NU^*:YJJNE\[O=K6ZOX*3DM*E+;VQA8B"X<[+5KN:FH:JZN7&D;+9LI?.S
M;L7I+KW0L-&FTB`E<R"E2*1&N-&S;ZC'MFRE\[-NQ>D`IOBJ0;ZYIE[`LSH@
M)7,`LV^KRK9LI?.HPZM$I4BG0;I$I<ZJNJ9RI+BVL*;3K$^HSZ7.("@E<RD@
MKM&\9Z;3IJ@N`*:YO,:MR+/,I-:ELK:WK$\@,2X`IKFF^*I!OKFU3*IKN>\@
M>FEP(*3.(&=Z:7`@KN:FH<#)KM>V::;FN-'`H\%9`*:YJ'2RSJ78JV6L3["Q
MI<ZJNJJLND$N`*6RMK>L3Z1`K=.\QJ9R+@"FN;7XM:&ELK:WK6ZET;_OMK6U
M^+6A*$]P=&EO;BFITJE)I7,`N7``K%"TP:5\`+#=PT2P;,+<`*[)MJ$`KLFV
MH;UDL_)?80"NR;:AJ_RK;@"NR;:AKN:FH0"NR;#/O^^^W`"NR;:AO62S\@!4
M:6UO<BU,97-T90"HQJ7SIE>ZV5]L`*C&I?.F5[K9`+S0PT0@*'1O;VQT:7`I
M.@"FK*7SI$@`IG"J1ZUNO<:_[RR]T*9BPDF_[[?&N:NJNJ90KLFK]B!#;VYT
M<F]LP>0HK=.D2+EQN*,I(*G.($-O;6UA;F3!Y"C$JZI'N7&XHRDN`*2UI-$`
M2%1-3""M[*ELP,D`5&]G;R`HIFBM]"D`5&]K96QA=0"I^J31`%1O;F=A("BJ
M1J5;*0"SN[.A`+/,I%>\:*[8K%L@*%]T;W`I`*1DJ+VY1J3.IJNHJ:WT`*]U
MJ<ZPL`"L4+3!I$<`K%"TP:1'`%1U;FES:6$@**SPI:>FZ*C(*0!4=7)K97D@
M**1GIM6HY"D`I&>FU:CDI.4@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4
M=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU("BD9Z7+OGPI`*NLIJ$`
MO^FD2J=!JKJ_[[[<.B``M;6E?KUUJ_R\QCH@`+KTIWT`NO2G?3H`56=A;F1A
M("BO4:1ZN48I`%5K<F%I;F4@**]1ITK$]2D`M4RJ:Z9SJ/H@5D93(*78O_TN
M`+7YI56NR;5,JFN\5Z5;PT*E?JJZJ,^ESJK,N.JP5"X`M4RJ:Z?OQ=P@5D93
M(,#)KM<@(B5S(B"JNL5VK:TN`+5,JFO%W*?S(%9&4R#`R:[7("5S+R5S(*JZ
MQ7:MK2X`M4RJ:\7<I_.LL"`E<RX`M4RJ:\#+K&3`R:[7I&JD<"`B)7,B+@"U
M3*IKP,NL9,#)KM>D:J1P("(E<R\E<R(N`+5,JFNS<[6RIMP@4U%,(*;XJD&^
MN2X`M4RJ:ZC/I<X@4U-,(+-SM;(N`+5,JFN]QKMS(%9&4R#`R:[7+@"U3*IK
MJ]BEWR!61E,@I=B__2`B)7,B+@"U3*IKJ]BEWR!61E,@I=B__2X`M4RJ:ZO8
MI=\@5D93(,#)KM<N`+5,JFNKV*7?(%9&4R"EV+_]("(E<R(N`+5,JFNKV*7?
MJL6EU:JZ(%9&4R#`R:[7+@"U3*IKL4ZXZJ[&N-'`H\%9+@"U3*IKIU*PHR`B
M)7,B+*:YI=B__:C#JT2JQ:75+@"U3*IKIU*PHR`B)7,B.B`E<P"U3*IKIU*P
MHR`B)7,B.B`E<P"U3*IKIU*PHR`E<RRFN:78O_VHPZM$JL6EU0"U3*IKIU*P
MHR`E<RX`M4RJ:[N\L&JG4K"CI=B__2X`M4RJ:Z=2L*,@5D93(*78O_TN`+5,
MJFNG4K"C(%9&4R"EV+_].B`E<RX`M4RJ:Z=2L*,@5D93(,#)KM<@(B5S(BX`
MM4RJ:Z=2L*,@5D93(,#)KM<N`+5,JFNG4K"C(%9&4R"EV+_]("(E<R(N`+5,
MJFN[O+!JIU*PHR!61E,Z("5S+@"U3*IKIU#"7Z78JV6JNJ78O_TN`+5,JFNX
MT;9]OLS#TK+3N&``M4RJ:[C\I$H@)7,@JKJI=[AQN.JNQBX`M4RJ:[=HLKX@
M5D93(,#)KM<N`+5,JFNV?;'2(%9&4R#`R:[7("(E<R(N`+5,JFN\9Z1*(%9&
M4R#`R:[7+@"U3*IKMGVQTB!61E,@P,FNURX`M4RJ:[9]L=+`H\%9P,DN`+5,
MJFO%JJCZ(%9&4R#`R:[7("AF:6QE<VEZ92@I(&9A:6QE9"DN`+5,JFO%JJCZ
M(%9&4R#`R:[7("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`+5,JFO%JJCZP,FN
MUSH@`+5,JFO%JJCZ('9F<W)O;W0@I=B__2X`M4RJ:Z?SIE<@(B5S(CH@)7,`
MM4RJ:Z?SIE<@)7,@K+`@)7,Z(*9=K+"EV+S0JTBE\Z=8I'>F<Z9B`+5,JFO%
MW*?S(%9&4R"EV+_]JKJF5[K9+@"U3*IKLKZPHR!61E,@I=B__3H@)7,N`+5,
MJFO%W*?S(%9&4R#`R:[7("(E<R(@JKJF5[K9+@"U3*IKQ=RG\R!61E,@P,FN
MUR`E<R\E<R"JNJ97NMDN`+5,JFO%W*?S(%9&4R#`R:[7JKJF5[K9+@"U3*IK
MQ:JH^B5SJKJJQ;:B+Z:CN$RXZK!4`+5,JFNP]:;F("=M:VES;V9S)RX`M4RJ
M:\+@M*L@5V]R9""DY:7S`+5,JFN\9Z1*(%9&4R`B)7,B(,#)KM<N`+5,JFN\
M9Z1*(%9&4R#`R:[7("AC;W!Y*"D@9F%I;&5D*2X`M4RJ:[QGI$H@5D93(,#)
MKM>XZJ[&+@"U3*IKO&>D2B!61E,@P,FNURP@NL^ZT+!TPT*D=[JA+@"IL[UU
M`*CZKOBG\Z?O`+1?K>P`IOBJ0;ZYLW.ULJ[)M6^ES:6\N7>TP:JZIE[`LSH@
M`+5OI<VEO+EWM,&JNJ9>P+,LI=&F^*I!OKDZ(`"EO*3`P_X`N%6PZKU8("A5
M5$8M."D`56YI=&5D($%R86(@16UI<F%T97,@**K\J=2G0L%PIEBD:J2]L.HI
M`%5N:71E9"!+:6YG9&]M("BM7K#J*0!5;FET960@4W1A=&5S("BL_+#J*0!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`L^:F[`"EO*J^
MJKH`I;RJOJJZ($%022"P5*ZGO7.XN2`H05!)($UE<W-A9V4@240I+@"EO*J^
MJKJKR*3AL%2NI[USN+D@*$%022!-97-S86=E($E$*2X`I;RJOJJZINRX;;CJ
ML%0N`*6\JKZJNJC/I<ZJS*97NMFISK%+O5@N`*2DPE^EV*MEI+BE\ZJZLW.U
ML@"EO*E2IE<`IEVF=Z7^Q56\>Z2CI+FS7*6\L<+%=JJZM7NFH;#UIN:PQ:15
M+[W&NW,OMDND5RX@PDF_[[U4J7>E2,#+M?@@;6]Z:6QL82YO<F<@J=*THZC1
MJKJLV\/VI]ZS3J3EI?,LQ?VG0:5II4BXT;"CIKFD0*VMJ.ZHPZ;;IN:V?:GQ
MM7NFH:9SJ/JPQ;9+PZ\N`*CZKOC#0Z;B`*6\I.2TJ:JZI+JN9:NLND$Z("5S
M+B`H56YS=7!P;W)T960@0V]N=&5N="U4>7!E+BD`I;RDY+2IJKJPQL#)IE<`
MQ=RG\P"G\[=S("5S`*?SMW.HSZ7.JLP`(B5S(J1WI_.W<RX`I'>G\[=S.B`E
M<RX`I_.W<[5[IJ&D=Z=2L*,N`*17ML<`I'>D5[;'J=*FL\"SI<ZU>Z:AJKJS
M7:EWP,FH[*;XJD&^N2X`I&J\9ZG4I$*\QJ9R`*1JO&?#N;"HO,:F<@!5<G5G
M=6%Y("BO4:G4IF,I`*C/I<ZEV*MEJKHZ("5S`*C/I<X@4U-,`*9PJD>G0:JZ
MJ,^ESJK,IE>ZV2^Q2[U8NU`@24U34""F^*I!OKFDHZ90+*5IIF*FN;-=J7<N
M`*C/I<ZJS`"HSZ7.JLP@)7,@I;RS<;E,("5S(*JZL<+%=L7GP](N`*C/I<ZJ
MS+K>LGH`J,^ESJK,I+:ML0"HSZ7.JLR_[[:U`*C/I<ZJS+7YI54`IKFON*5X
MJKJHSZ7.JLRU^:55J'2RSJ1WL+&ESBX`I^2DHZCLJ,^ESJK,L6*XN0"HSZ7.
MJLRF5[K9`*C/I<ZJS*97NMD@(B5S(B"D=Z9SIF(N`*C/I<ZJS*97NMDZ`*C/
MI<ZJS#H@`*ATLLZDI*JZJ,^ESJK,.@!5>F)E:VES=&%N("BO4:_WIT^G2BD`
M5D93(*78O_VHPZ2CIG.F8BX`L+*TP0"D=Z?DJ.RFLZ[$JKJF8<)).B``IK.N
MQ*G*`*5(I,#$P:RPL^:F["BQ<;)[IF*P7[KB*0"MR`"_[ZCZK<BFVP!686YU
M871U("BERZ6CJORYSRD`Q=RDQ@!696YE>G5E;&$@**EEI+JWYZG4*0#%Y\/2
MI:*QT2`M(*:YMFRE\Z5IK^"D=[Y$I$B^U:;;OWFG[RX`JJFENP"JJ:6[L;&H
M[@"KJZJ]N>^[]`"KJZJ]N=2E4@"KJZJ].@"K1+%@L*H`5FEE="!.86T@*+96
MJVXI`+96JVZDY2`H5DE30TE)*0#`R[7X("5S`*3IP,NU^`"F8K=SM?BUH;9]
ML=(`I4@@)7,@P,NU^`!6:7)G:6X@27-L86YD<RP@0G)I=&ES:"`HK5[$W;K[
MJ,JX<ZYQ*0!6:7)G:6X@27-L86YD<RP@52Y3+B`HK/S$W;K[J,JX<ZYQ*0"O
MX*BCJ]<`K^"HHZO7.B``N'&D:J=1I?&\=ZVWN7&K2*2]I7&S>KE,(%--5%``
MQ+6G:0#$M:=I(2$A(+%Q("5S(*3BL,JROK"CM7NFH2X`5TE.(+AGI=$@2%14
M4`!786QL:7,@86YD($9U='5N80#$M:=I`*Q0M,&D5`"DT:[PN7>T^@"N\+9(
MN.JNQK2CJ-$`=V5A=&AE<BYC;VT@NO2ON`"Z]*^X`+KTK[@`K%"TP:14`+9G
M`*E0("5D`+9G`*A#MF<`MF<Z(*A#`,5WJN\`Q7>J[ZCL("5S`,5WJN\L("5S
M`*;HO-H@*$E33RTX.#4Y+3$I`*;HO-H@*$E33RTX.#4Y+3$U*0!797-T97)N
M(%-A:&%R82`HINB\NZNBJ=0I`+5NI$JKX<"SN-.E_<7CI=P@)7,@K?ZD0*W3
MP+.ESK5[IJ$_`,3FINRJNJ3`N6JF<J2X/P"DWJUZJKJK9;AMIG*DN#\`I.F[
M4+9GJKJULJ3NQ>.EW*[)MJ&A2`"DZ;M0MF>JNK'2J6S%XZ7<KLFVH:%(`%=H
M97)E:7,@075S=')A;&EA(*9AN<\`K?ZMTZ3KK-L`NO2MMKUSO^B^N:JZM*&E
M\RAP;'5G:6YS*;'2L,JQL:CN+@"\9:O7`*5(($-34R"LL+/FINRJNKQEJ]<`
MI:K#Y"5SI5ROX*KMJKJ\9:O7**15IKBU;J1*J6RES:[$*3H`JNVNYKQEJ]<`
MO&6KU[/FINP`O&6KUSH`MK#%Z;/0IT``K;<`IJVFLZVW`*VWLW0HN&`I`*VW
MLW0Z`*VWLW0Z(`"TO+QZ`+3!J]W"IZJK`*1UIT``O^RDO:O'IF&G?0"_[*2]
MJ\>Y<;C<`*17KUJDZ0"RQ"5DIN:JNL3FINR\QJ78I*.EO[U4+B#`L[C3K6ZF
MLR5DK=/$YJ;L+*5UI^2H["5DK=/$YJ;L+@#$YJ;LO,:EV*2CI;^]5"X@P+.X
MTZUNIK,E9*W3Q.:F["RE=:?DJ.PE9*W3Q.:F["X`6#4P.78S(*FUIOFJ]\9?
MNWFJ:P!8-3`Y=C,@I42FKK3`I4ZF5[K9`%@U,#EV,R"E1*:NJO?&7\/1IT^J
MS`!8-3`Y=C,@L,;`R:97`*9^`*9^`%EA:&]O("$@IF&YSP"F?@"H0Z9^`*9^
M.B"H0P!996UE;B`HN*VJ^2D`K$\`K$^JNBRGVJ90MTX`IT&EV*MEJ,^ESJ_"
MI.6F<KUSO&>\TJ:A+B"HSZ7.(%L\/ET@J_:V<Z5II,&TJZRPNO2MMKUSO&>\
MTJ:A+@"DHZ2YLURG0:O8I=\E9*5(I%>JNK#/MO0N`*=!J%.FLZO8I=^V5[E,
M("5D(*W3J,:E\ZJZQ7:MK2X`IT&HPZ2CK$^K_*EWJ,:E\ZJZP=R]T*1(K?LN
M`*=!I;RS4;'"Q78N`+%QO7._Z,'<O="D2*W[M66ML:2DIT&E=:_@J,^ESK-O
MK=.J[;/F+@"G0:JZI?ZF5Z2DI*.E:::S("=<)R"S;[S+JKJF<J2X+B``IT&H
MPZ6\O^FD2J1`K=.FLZ[$JKJY<:1LMFRE\Z;LIWTN`*=!J,.EO*71MM>D2JJZ
MP,FNUZ2DN>^L3:7TIO/$YJ;LJ.P@)7,`IF*G0:JZJ*VDP,/1IT^_[[:UI*2H
MPZ6\LUVI=[EQI&RV;*7SINVG?2ZG0:6RMK>E_;9IIN8E<[-=J7<E<Z1^K^"V
MQ[!EJ,:E\[-QJKXN`*=!J,.H4Z:SMW.\5ZC&I?.H["`E<R"JNL5VK:TN`*=!
MJ,.H4Z:SQ7:MK2RF8JG2O^^^W*JZIN:HQK[DI%>W<[Q7J,:E\RX`IT&HPZA3
MIK/%=JVMIU*PHZ:YJ,:E\RX`IT&HPZA3IK.]<[_HIKFHQJ7SJKK%=JVM+@"G
M0:1WN&>U;J58+@"G0:1WN&>K_*EWI$"MTZ2CIEBJ:ZJZIN:HQK[D+@"G0:1W
MIJBE7+&UJ/RFJ*RPIKFHQJ7SJKJE6*YUI$BM^RX`IT&D=Z:HI5RP^ZG:IJBL
ML*:YJ,:E\ZJZI5BN=:1(K?LN`*=!I'>\R*[)L;6H_*:HK+"FN:C&I?.JNJ58
MKG6D2*W[+@"]T+_II$JD0*W3IK.NQ*JZN7&XW+BYO5@LL.J[VKEQN-RXN;U8
MMLBE=:2YLUR\QJ9RN+F]6"RHP[7XL:&J<*5IJ?.K9:VQID&E6Z1`K=,@)RLG
M+@"G0:6RMK>_Z:1*I$"MTZ:SKL2JNJW(+@"G0:6RMK>E_;-7N;JF;K[PJJRX
MZJ[&*$1A=&%4<F5E*:;XJD&ZW:1^K^#$?L3RJ,^ESK=SI<ZDX;7YI56J0;#(
M+@"G0:6RMK>E_;-7N;JD0*W3M>K`P,#)KM>H=++.*%9&4RFF^*I!NMTN`+W0
MM'FM>K#=PT2A0:9BIT&VQ[!EL-W#1+/XIVFDIZME+@"G0:6RMK>_Z:1*IKFS
M<[6RJ=*K_*96JKJZ]*=]`*=!I;*VMZ7]O^^^W*1`K=.M;J=2L*.JNJ;FJ,:^
MY"X`K;JE_:=!I;*VMZ7]O^^^W*1`K=.F8:=]+@"]T*O\J7>M;J=2L*.JNJ;X
MJD&^N2X`O="K_*EWK6ZR3;"CJKJHSZ7.JLPN`+W0J_RI=ZUNLKZPHZJZJ,^E
MSJK,+@"]T*O\J7>M;K=SO%>JNJC/I<ZJS"X`O="K_*EWK6ZG\[=SJKJHSZ7.
MJLPN`+W0J_RI=ZUNL/6FYJJZIT"ESBX`IT&ELK:WO^FD2K=SI,##_JJZIE>Z
MV2X`IT&ELK:WM*.HT:1`K=.X<:1JIU&YTJ2ZJKJY<;C<N+F]6`#`LZ=!JKJM
M;JA$+*A#M^VG0:JZIN:HQK[DLU&W<[Q7J,:E\Z[)M6^P9;-QJKXN`,"SIT&J
MNJUNJ$0LJ$.W[:=!JKJFYJC&ON2S4:=2L*.HQJ7SKLFU;[!ELW&JOBX`P+.G
M0:JZK6ZH1"RH0[?MIT&JNJ;FJ,:^Y+-1O7._Z*C&I?.NR;5OL&6S<:J^+@"T
MH[_TIT&F8J3IM,$Z)3(D<R"NR;:A.B4S)',@JKJNR:W4+*:SI$"MTZ;FJ,:^
MY*C&I?,@)3$D<R"UI:O=O^RR>BX`IT&JNB`E<R"W?+3!I'>Y3*[)+KW0K:NW
M<[5NI$HN`*=!JKJY<:1LMFRE\Z;MIWT`IT&JNK%(I?.D2+EQI&RV;*7SINVG
M?3H`IT&JNKCJL%0`IMNQ<:=!JKH@)7,@MWRTP;9]J6RE2*C3IT&JNKKTN]JZ
M]+CTINRG?:1WQ=RG\RX@K+"K3\5`IT&JNJ9WI?ZP7ZBCH4&G0:6RMK>MJ[=S
MM6ZD2BX`IT&JNJ97NMD`IT&JNL7GP]*F^*I!NMVHPZ2CI.2TJ;=SO%>HSZ7.
MJLPN(*9PJD>G0:?&L>:ZWK)ZJ,^ESJK,L6*XN2RG0:6RMK>E=+_OJ.2E3*JZ
MQ>?#TJ;XJD&ZW2X`IT&JNL7GP]*ZW:C#I;RDY+2IID.E6*C/I<ZJS*G.N-.E
M7*_@I'>S4</VLZPN`*;;L7&G0:JZ("5S(+=\M,&V?:ELI4BHTZ=!JKK"<\3]
MOKFF_*5'I'?%W*?S+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!I;*VMZVKMW.U
M;J1*+@"G0:JZPG/$_;ZYJ,.EO*3DM*FS;ZW3I5ROX"X`IT&JNL)SQ/V^N:C#
MI;RDY+2IID.F3+_OMK4NO="K]B!#5%),+T-O;6UA;F0@*R!0(*9#IDPN`*=!
MI=BK9:G2LUVI=ZJZKLFPSSH`IT&JNKEWLUVFYJC&ON0`N]6D5;EWLUVJNJBM
MI??#T:=/I'?%W*?S+@"[U:15N7>S7:JZJ*VE]\/1IT\Z`*=!JKJE_J97.@"G
M0:JZM6ZD2J1WJ.RTP2X`IT&F8B`E<R"DI*JZMW.Q2[U8K$\Z("5S`*=!IF*U
M;J1*M,&VH:JZO^^VM:1WLU&G\[=S+@"G0:JZO^^VM:1WI_.W<RX`IT&JNK%+
MO5BD=ZVKMW.S7:EW`+%+O5BD=[-1K:NW<[-=J7<LMW.JNK%+O5BD=[-ZN4RY
M<:1LMFRE\[%(M6^]T*5(N-.Q2[U8M6ZD2BX`IT&JNK%+O5BD=ZCLM,$N`*=!
MJKJ[M[K=IOBJ0;ZY.@!9=6=O<VQA=FEA("BK;K2UJ=2DTBD`6F%I<F4@*,+$
MI>PI`%IA;6)I82`HJ7RD\:C(*0!::6UB86)W92`HJ*^DVJO"*0!;P?3"PZ3>
MK7I=`%NPW<-$I,^L35T`6\7CI=RDWJUZ("T`6\7CI=RDWJUZ("T@)7,@IN9=
M`%NEO*E2IE>JNJC&I?-=`%NF[*GSIN8@)7,@ID`@)7,@IN9=`+K>LGI?00#$
MM:7<7T$`L/*EN[=JM$U?0@"I4J5/ID-?0P"^\*JLN.JNQE]$`*=2L*.F0U]$
M`+USO^A?10"ROJ;<7T<`N'.RU5]'`+NAJ?I?2`"\=KFSI+JN95])+BXN`+;7
MI$HOMM>E6%])`+5NI$I?3`"U;J587TP`K=>G[[-SM;)?32XN+@"GVJJZIN:H
MQK[D7TT`MW.HQJ7S7TX`O^^VM5]/`,5VK:U?4`"F0Z9,7U``LKZPH[GOLW.U
MLE]2+BXN`+=JM$U?4P"S7:EW7U,`JNVNYJ2ZKF5?5"XN+@"DM:317U0`J,^E
MSJK,7U4`LW&P5+_]`*GSJ,:E\[9]J6RK90"FYJC&ON0`M4RJ:ZO8I=^_Z:58
MP,FNUP"U3*IKMGVQTK_II$H`J_:FN0"Q2Z5/ID.[>:IKO_F[?@"S7:EWO_F[
M?@"_\J6BK:NM;JJZJ'2RSL#)KM<`N.JNQJ[FIJ&_^;M^`*3I`*3I`*3I`*?D
MI*.H[+!/O_T`IN:HQK[D+F-S=@"FYJC&ON0N:6-S`,#)KM<`L7$`L7$@)7,@
M*"5S*2"I\R`E<R`E<P"P?:VW`*[).@"NR0"EO*J^JKJV;*7SI42^]Z97NMD`
MI=^G60"JO;&UQ>.EW*GSI;NDY;#/`+_II$HOO^FE6+_YNWX`I+JSH;-NQ>F_
M^;M^`*;F70"DP`"DZP"F5[K9`*E\I;RYZJ=`+@"I?*6\N>JG0"X`L\:GT;_]
M`*GS)7.NR;:A)7,`IF*F4*1`I-$`IF*H0[9GJKJRQ*1`I-$`ILJDP*3Q`*9S
MJ/J^1*G:`+FSK\``LW&K2*CSJ7>[M[K=O_F[?@"D5Z3)`+5,I6FESJJZJD&P
MR`#%XZ7<KG2RIP!S;7,R96UA:6P@N&>ET2!(5%10`*SM`,.MJ7<`J'2RSK_Y
MNWX`J]V_[,.O`+S(KLFIRJJZI:*QT0"F0::XO^FD2J=!JKJQ2[U8I4B]5+M[
MM4R[?@"^XZ98`*6\J5*F5P"HSZ7.JLR_[[[<`'9#86QE;F1A<B]I0V%L96YD
M87(`=D-A<F0`I^2DHZCL('9%=F5N="X`K%"TP3H`=V5A=&AE<BYC;VT@NO2O
MN`"V9P"V9SH`MF<`IGX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O<&\O````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S4S`#`Q-S`U,P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]P;R]K;U]+4BYP;P``````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`Q,38U-#``,3`T,3<S-C(W-3(`,#(P-#(S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@2W)O;F]L
M:71H($MO<F5A;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@
M2BY)($MI;2X*(R!*+DD@2VEM(#QA<&]R:65`;F5T:6%N+F-O;3XL(#(P,#(N
M"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($MR
M;VYO;&ET:"`R+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,2TQ
M,2TP.2`Q-CHR.2LP.3`P7&XB"B),87-T+51R86YS;&%T;W(Z($HN22!+:6T@
M/&%P;W)I94!N971I86XN8V]M/EQN(@HB3&%N9W5A9V4M5&5A;3H@2V]R96%N
M(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U%54,M2U)<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!C86QE;F1A<G,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5D(&5V96YT<R(*;7-G<W1R("+`_,.\(,#/P:0B"@HC.B!T
M96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@1&%Y*',I("5S($AO=7(H<RD@)7,@36EN=71E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@W"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L
M;'D@:6UP;W)T960B"FUS9W-T<B`B)7,@QL3`S\#,(,#3QO?&KK7'OOJ]P+3/
MM-DN(@H*(SH@8V%L96YD87)S+G!H<#HQ,#4@;&EB+V)A<V4N<&AP.C$R.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G
M<W1R("+`S\&D(,#-O;K&]\:N(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S
M96%R8V@N:6YC.C$W"FUS9VED("(B"B(H0VQI8VL@;VX@8V%L96YD87(@;F%M
M92!T;R!S=VET8V@@=&AE(&-A;&5N9&%R)W,@=FES:6)I;&ET>2!I;B!T:&4@
M;6%I;B`B"B)W:6YD;W<I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,38T"FUS9VED("(J($%D9"!T:&5S92!B>2!C
M;&EC:VEN9R!!9&0@*B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$U,`IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D
M9')E<W,H97,I("HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X
M-@IM<V=I9"`B,2!A='1E;F1E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B,2!E=F5N="(*
M;7-G<W1R("+`_,.\(,#/P:0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,W"B,L(&9U>GIY"FUS9VED("(Q(&AO=7(B"FUS9W-T<B`B)60@O<,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED("(Q
M-2!M:6YU=&5S(@IM<V=S='(@(B5D(+K0(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-0HC+"!F=7IZ>0IM<V=I9"`B,C`@;6EN=71E<R(*;7-G<W1R
M("(E9""ZT"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*(RP@9G5Z
M>GD*;7-G:60@(C,P(&UI;G5T97,B"FUS9W-T<B`B)60@NM`B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ-S$*(RP@9G5Z>GD*;7-G:60@(CQS=')O
M;F<^071T96YD965S/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^
MQ;"_]K7E/"]B/B`HO+'%PRDB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHQ-#D*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^1&5S8W)I7W!T:6]N/"]S
M=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^L[N_ZSPO8CX@*+RQQ<,I
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C<W"B,L(&9U>GIY"FUS
M9VED("(\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS
M9W-T<B`B/&(^Q;"_]K7E/"]B/B`HO+'%PRDB"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ.30*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^4F5C=7)R
M96YC93PO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/L#/P:0@N=VZ
MN3PO8CX@*+RQQ<,I(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M,#$@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.#$*;7-G:60@(D%-(@IM
M<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4Y,0IM<V=I9"`B06-C
M97!T960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C$Q"FUS9VED(")!9%]V86YC960@4V5A<F-H(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38Q('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")!9&0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8*;7-G:60@(D%D
M9"!%=F5N="(*;7-G<W1R("+`S\&D(,/?L*$B"@HC.B!T96UP;&%T97,O<')E
M9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHS-0HC+"!F=7IZ>0IM<V=I
M9"`B061D(&$@;F5W(%)E;6]T92!#86QE;F1A<B(*;7-G<W1R("*[];?.O^X@
MP,_!I"##W["AQ\^QXB(*"B,Z(&%D9&5V96YT+G!H<#HV-`IM<V=I9"`B061D
M(&$@;F5W(&5V96YT(@IM<V=S='(@(KOUM\Z_[B#`S\&D(,/?L*''S['B(@H*
M(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C<T"FUS9VED
M(")!9&0@871T96YD965S(@IM<V=S='(@(B(*"B,Z(&-O;G1A8W1S+G!H<#HW
M-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$R,`HC.B!T96UP
M;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-S@*;7-G:60@(D%D9')E
M<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:%]A9'9A;F-E9"YI;F,Z."!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M,3$*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHU,PIM<V=I9"`B06QA<FTB"FUS9W-T<B`B
MOLNXLB(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B06QA<FT@)60@9&%Y<R!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E
M9"!H;W5R<R!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<W-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@;6EN
M=71E<R!B969O<F4B"FUS9W-T<B`BNM`@P/PB"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-S4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D('=E96MS(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8S"FUS9VED
M(")!;&%R;2`Q(&1A>2!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z,3<V.`IM<V=I9"`B06QA<FT@,2!H;W5R(&)E9F]R92(*;7-G<W1R
M("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<S"B,L(&9U>GIY"FUS9VED(")!
M;&%R;2`Q(&UI;G5T92!B969O<F4B"FUS9W-T<B`BNM`@P/PB"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ-S4X"FUS9VED(")!;&%R;2`Q('=E96L@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C8P"FUS9VED(")!;&%R;2!$871E(@IM
M<V=S='(@(K[+N+(@P,_`VB(*"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R
M;2!3<&%N("AM:6YU=&5S*2(*;7-G<W1R("*^R[BR(+"CL-T@*+K0*2(*"B,Z
M(&1A=&$N<&AP.C8Q"FUS9VED(")!;&%R;2!4:6UE(@IM<V=S='(@(K[+N+(@
MO<.PHR(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS,0IM<V=I
M9"`B06QL(@IM<V=S='(@(KCPM<XB"@HC.B!L:6(O1D)6:65W+G!H<#HQ,C8@
M;&EB+T9"5FEE=RYP:'`Z,3(Y(&QI8B]&0E9I97<N<&AP.C$S,@HC+"!F=7IZ
M>0IM<V=I9"`B06QL($%T=&5N9&5E<R(*;7-G<W1R("+`_,.\(,#/P:0B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3D*(RP@9G5Z>GD*;7-G
M:60@(D%L;"!&=71U<F4B"FUS9W-T<B`BOM7`N+?.(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C4S"B,L(&9U>GIY"FUS9VED(")!;&P@4&%S
M="(*;7-G<W1R("+'S[?G(+.[L[LB"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H
M;&ES="YP:'`Z,C<@;&EB+T)L;V-K+VUO;G1H+G!H<#HR-`HC.B!L:6(O0FQO
M8VLO;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*
M;7-G:60@(D%L;"!6:7-I8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,B!L:6(O1&%Y5FEE=RYP:'`Z.3`@
M;&EB+T1A>59I97<N<&AP.CDS"B,Z(&QI8B]7965K5FEE=RYP:'`Z,3(W(&QI
M8B]7965K5FEE=RYP:'`Z,3,T(&QI8B]$<FEV97(N<&AP.C$X,S(*;7-G:60@
M(D%L;"!D87DB"FUS9W-T<B`BQ\^WYR"SN[.[(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$V-`IM<V=I9"`B06QL(&1A>2!E=F5N="(*;7-G<W1R("+'
MS[?G(+.[L[L@P,_!I"(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,C$*;7-G:60@(D%L;"!E=F5N=',B"FUS9W-T<B`BP/S#O"#`S\&D(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O2W)O
M;F]L:71H+G!H<#HV.#,*;7-G:60@(D%N>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,0IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B-+_Y(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z,SD@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHW,"!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$U-@IM<V=I9"`B070B"FUS9W-T<B`BO<.PHR(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P,C8*;7-G:60@(B(*(D%T=&%C:&5D(&ES(&%N
M(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T
M:&4@979E;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I
M<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P
M9&%T92`B"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#(@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E;F1A;F-E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V,0IM
M<V=I9"`B071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B.+_Y
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHX"FUS9VED(")"87-I8R!3
M96%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T
M.C$W"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("*[_<#/(@H*(SH@;&EB+T9"
M5FEE=RYP:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$P"FUS9VED(")"=7-Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D
M+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S='(@(L#/
MP:0@P-/&]\:NQ\^QXB(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0Y
M"B,L(&9U>GIY"FUS9VED(")#86Q?96YD87(B"FUS9W-T<B`BP,_!I"#`T\;W
MQJ['S['B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$T-B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C$*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HR,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR,2!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(RP@9G5Z>GD*;7-G:60@(D-A;&5N
M9&%R(@IM<V=S='(@(L#/P:0@P-/&]\:NQ\^QXB(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HS"B,L(&9U>GIY"FUS9VED(")#86QE;F1A<B!3=6UM87)Y
M(@IM<V=S='(@(K_DON`B"@HC.B!D871A+G!H<#HR,C@*(RP@9G5Z>GD*;7-G
M:60@(D-A;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(FE#
M86QE;F1A<B#&Q,#/P,P@P-/&]\:NM<>^^KW`M,^TV2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3<*(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R<R(*;7-G<W1R("+`S\&D
M(,#3QO?&KL?/L>(B"@HC.B!C86QE;F1A<G,N<&AP.C(W"FUS9VED(")#86QE
M;F1A<G,@;75S="!H879E(&$@;F%M92XB"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z,C0S"B,L(&9U>GIY"FUS9VED(")#86XG="!C<F5A=&4@82!N97<@979E
M;G0N(@IM<V=S='(@(KOUM\Z_[B#`S\&D(+O]O+HB"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,2!T96UP;&%T97,O9&5L971E+V]N
M92YI;F,Z,S`*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,R('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C,P.0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(L/KO-(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HU-S`*(RP@9G5Z>GD*;7-G:60@(D-A;F-E;&QE
M9"(*;7-G<W1R("+#Z[S2(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`P,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N8V5L;&5D.B`E<R(*;7-G
M<W1R("+#Z[S2(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC
M960N:6YC.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C8Y"B,L(&9U>GIY
M"FUS9VED(")#871E9V]R7WDB"FUS9W-T<B`BN?S!UB(*"B,Z(&1A=&$N<&AP
M.C8S('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-"!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,PIM<V=I9"`B0V%T96=O<GDB"FUS9W-T
M<B`BN?S!UB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@
M(B(*(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L
M(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S(&)Y("(*(F5M86EL.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D-H
M;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E
M9"P@86YD(&1E;&5T960@979E;G1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V5A<F-H7V%B;V]K7W-E;&5C="YI;F,Z,3D@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Y.0IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O
M;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]F8E]C86QS7W-E;&5C="YI;F,Z,38*;7-G
M:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,3$*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S
M('1O(&EN8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!54DQS.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@
M(D-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHV-0IM<V=I9"`B
M0VQE87(@86QL(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR
M."!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S
M97!A<F%T960@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW,PIM<V=I9"`B0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_
M(@IM<V=S='(@(L#/P:0@N^C!IKW#(,BNP,X_(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-38W"FUS9VED(")#;VYF:7)M960B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(P.`IM<V=I9"`B0V]P
M>2!T:&4@55),(&)E;&]W(&9O<B!U<V4@=VAE<F5V97(@>6]U(&YE960@>6]U
M<B!&<F5E+T)U<WD@55),.B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ,C8*(RP@9G5Z>GD*;7-G:60@(D-R96%T92(*;7-G<W1R("+'
M]L#G(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q
M,@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($-A;&5N9&%R(@IM<V=S='(@(L#/
MP:0@P-/&]\:NQ\^QXB(*"B,Z(&UO;G1H+G!H<#HQ-C4@=&5M<&QA=&5S+W=E
M96LO:&5A9"YI;F,Z,C4@=&5M<&QA=&5S+V1A>2]R;W<N:6YC.C8*(SH@;&EB
M+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H<#HQ.30*;7-G:60@(D-R
M96%T92!A($YE=R!%=F5N="(*;7-G<W1R("*[];?.O^X@P,_!I""[_;RZ(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#`*;7-G:60@(D-R96%T960B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(Y
M"FUS9VED(")#=7)R96YT(@IM<V=S='(@(L?VP.<B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`Y
M"FUS9VED(")$86EL>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(KC%P,\Z(+G?
MN_W`SR`B"@HC.B!A='1E;F1E97,N<&AP.C$Q,"!L:6(O2W)O;F]L:71H+G!H
M<#HQ,C@X(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(Q"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,@IM<V=I9"`B1&%Y(@IM<V=S='(@(L#/(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,3,Y"FUS9VED(")$87DH<RDB"FUS9W-T<B`BP,\B"@HC.B!V:65W
M979E;G0N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92(*;7-G<W1R
M("*[Z,&F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-SD*
M;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(C$RO_DB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HU.30*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L
M="!#86QE;F1A<B(*;7-G<W1R("+`S\&D(,#3QO?&KL?/L>(B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DS('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@Q"B,Z('1E;7!L871E<R]D96QE=&4O
M;VYE+FEN8SHR.2!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M
M96YT+FEN8SHR,PHC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`BN^C!IB(*"B,Z(&1E;&5V96YT+G!H<#HT,"!T96UP;&%T
M97,O9&5L971E+V]N92YI;F,Z,3@@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N
M:6YC.C$X"B,Z(&QI8B]$<FEV97(N<&AP.C$X,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E("5S(@IM<V=S='(@(B5S(+OHP:8B"@HC.B!E9&ET979E
M;G0N<&AP.C<P"FUS9VED(")$96QE=&4@179E;G0B"FUS9W-T<B`BP,_!I""[
MZ,&F(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED
M("(B"B)$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U
M<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R("(*(F%L;"!O
M8V-U<F5N8V5S/R(*;7-G<W1R("(B"B+']L#G(,#/P:2XN""[Z,&F+"#`S""Y
MW[O]P,_!I+#Z(+CPM><@OM7`N+?.P,<@N=^[_<#/P:0L(+;'M,(@N/"UYR"Y
MW[O](,#/P:0@/R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHQ,#0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X"B,L
M(&9U>GIY"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`BO+.X[2(*"B,Z
M(&1A=&$N<&AP.C8R('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ-S4*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.38*;7-G:60@(D1E
M<V-R:7!T:6]N(@IM<V=S='(@(KRSN.TB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$W,PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2(*
M;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A
M;&5N9&%R<RYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@0V%L96YD
M87)S(@IM<V=S='(@(LBMN.D@O+/!I"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,"!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C@*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+(
MK;CI(+RSP:0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@
M(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U92!O;B!Y
M;W5R(&-A;&5N9&%R/R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU,S<*;7-G:60@(D1O97,@;F]T(')E8W5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")$=64Z
M("5S(@IM<V=S='(@(L?2P,\Z("5S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,3$U"FUS9VED(")$=7)A=&EO;B(*;7-G<W1R("*Q
MXK"C(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W
M,"!L:6(O1')I=F5R+G!H<#HQ.#`V"FUS9VED(")%9&ET(@IM<V=S='(@(KSV
MP:0B"@HC.B!E9&ET979E;G0N<&AP.C,S('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(V(&QI8B]$<FEV97(N<&AP.C$X,#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="`E<R(*;7-G<W1R("(E<R"\]L&D(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,3@W"FUS9VED(")%9&ET($%T=&5N9&5E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30P
M"B,L(&9U>GIY"FUS9VED(")%9&ET($-A;&5N9&%R<R(*;7-G<W1R("+`S\&D
M(,#-O;K&]\:N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,`HC+"!F
M=7IZ>0IM<V=I9"`B161I="!296UO=&4@0V%L96YD87)S(@IM<V=S='(@(L#/
MP:0@P-/&]\:NQ\^QXB(*"B,Z(&%T=&5N9&5E<RYP:'`Z,34P"FUS9VED(")%
M9&ET(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%T96=O
M<GE?;&5G96YD+FEN8SHR,`IM<V=I9"`B161I="!C871E9V]R:65S(&%N9"!C
M;VQO<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ-S8@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC
M.C0Q"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-`IM<V=I9"`B16UA
M:6P@061D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET
M7W1I;65S<&%N+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B16Y?9"(*;7-G<W1R
M("+!OK?A(,#/P-HB"@HC.B!D871A+G!H<#HU-PIM<V=I9"`B16YD($1A=&4B
M"FUS9W-T<B`BP;ZWX2#`S\#:(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N
M=%]H96%D97)S+FEN8SHX('1E;7!L871E<R]V:65W+W9I97<N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`X"FUS9VED(")%;F0@3VXB
M"FUS9W-T<B`BP;ZWX2#`S\#:(@H*(SH@9&%T82YP:'`Z-3@*;7-G:60@(D5N
M9"!4:6UE(@IM<V=S='(@(L&^M^$@O<.PHR(*"B,Z(&%T=&5N9&5E<RYP:'`Z
M,3(T(&%T=&5N9&5E<RYP:'`Z,3,U(&%T=&5N9&5E<RYP:'`Z,30R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N(&9O<B`E<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`Y,PIM<V=I9"`B179E;G0@861D960Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,#,*;7-G:60@(D5V96YT(&1E;&5T
M960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3@*;7-G
M:60@(D5V96YT(&5D:71E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3`V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%=F5N="!F<F]M("5S('1O
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V-`HC+"!F=7IZ
M>0IM<V=I9"`B179E;G1S(&UU<W0@:&%V92!A('-T87)T(&1A=&4N(@IM<V=S
M='(@(L&^M^'`S\"Z(+W#P-O`S+JXM-D@Q+^^WR#'U;3/M-DN(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z-S,P"FUS9VED(")%=F5N=',@;75S="!H879E(&$@=&ET
M;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V-PIM<V=I9"`B
M179E;G1S(&UU<W0@:&%V92!A;B!E;F0@9&%T92!O<B!A(&1U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI
M;F,Z-SD*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R("+!
MOK?A(+W#L*,B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X-PIM
M<V=I9"`B17AP;W)T(@IM<V=S='(@(L#-O;K&]\:N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@0V%L96YD87(B"FUS
M9W-T<B`BP,_!I"#`S;VZQO?&KB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C8Y"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(RO_DB"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$R.`HC+"!F=7IZ
M>0IM<V=I9"`B1FEN9"(*;7-G<W1R("*QW;_DP,\B"@HC.B!Y96%R+G!H<#HX
M-R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,R!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,C(*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*
M;7-G:60@(D9R(@IM<V=S='(@(K'=(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB
M"FUS9W-T<B`BP:2ZN+OGQ]<B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI
M;F,Z,C`@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$Y"B,Z('1E;7!L871E
M<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")&<FED87DB"FUS9W-T
M<B`BL=V_Y,#/(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,P
M"FUS9VED(")&=71U<F4B"FUS9W-T<B`BOM7`N+?.(@H*(SH@8V]N9FEG+VME
M>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")'86UE(@IM<V=S='(@(K#4P-,B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,C,*
M;7-G:60@(D=E;F5R86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$T,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1V]T;R`E
M<R(*;7-G<W1R("+`S+6_(@H*(SH@;6]N=&@N<&AP.C$S-2!T96UP;&%T97,O
M=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+V1A
M>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*;7-G:60@(DAI9&4B"FUS9W-T
M<B`B(@H*(SH@;6]N=&@N<&AP.C$S-2!T96UP;&%T97,O=V5E:R]H96%D7W-I
M9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?
M8GE?<VED92YI;F,Z,3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAI
M9&4@)7,B"FUS9W-T<B`B)7,@NKBQXB(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C8U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S.`IM<V=I9"`B
M2&]U<BAS*2(*;7-G<W1R("*]PR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S,*(RP@9G5Z>GD*;7-G:60@(DAO=R!L;VYG('-H;W5L9"!T:&4@=&EM
M92!S;&]T<R!O;B!T:&4@9&%Y(&%N9"!W965K('9I97=S(&)E/R(*;7-G<W1R
M("+`SR"YUR#!UKJP(+JXL>*_H;RM(#,PNM`@M-S`I[?.(+JXL>(_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`IM<V=I9"`B2&]W(&UA;GD@9&%Y
M<R!O9B!F<F5E+V)U<WD@:6YF;W)M871I;VX@<VAO=6QD('=E(&=E;F5R871E
M/R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#,P"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(DEF('EO=7(@96UA:6P@8VQI96YT(&1O97-N
M)W0@<W5P<&]R="!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T
M:&4@(@HB9F]L;&]W:6YG(&QI;FMS('1O(&%C8V5P="!O<B!D96-L:6YE('1H
M92!E=F5N="Y<;B(*(EQN(@HB5&\@86-C97!T('1H92!E=F5N=#I<;B(*(B5S
M7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0@=&5N=&%T:79E;'DZ7&XB
M"B(E<UQN(@HB7&XB"B)4;R!D96-L:6YE('1H92!E=F5N=#I<;B(*(B5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($-A;&5N9&%R+"!3=&5P
M("5D(@IM<V=S='(@(L#/P:0@P-/&]\:NQ\^QXB(*"B,Z(&1A=&$N<&AP.C,R
M,`IM<V=I9"`B26UP;W)T+T5X<&]R="!#86QE;F1A<B(*;7-G<W1R("+`S\&D
M(,#3QO?&KB_`S;VZQO?&KB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S='(@(C&_^2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<T"FUS9VED(")*=6QY(@IM
M<V=S='(@(C>_^2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C<S"FUS9VED(")*=6YE(@IM<V=S='(@(C:_^2(*"B,Z(&1A=&$N<&AP.C8U
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T,@IM<V=I9"`B2V5Y=V]R9',B
M"FUS9W-T<B`BQ;"_]K7E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C4U"FUS9VED("),87-T(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C@W"FUS9VED("),87-T($UO9&EF:65D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?
M<VED92YI;F,Z-`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I
M9&4N:6YC.C$P"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED
M92YI;F,Z,38@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C0*(RP@9G5Z>GD*
M;7-G:60@(DQA<W0@36]N=&@B"FUS9W-T<B`BN+;!]KBW(+3>(@H*(SH@=&5M
M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!9
M96%R(@IM<V=S='(@(KBVP?:XMR#!UB(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHU-"!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHS"FUS9VED
M("),87-T('=E96LB"FUS9W-T<B`BN+;!]KBW(,'6(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ-PIM<V=I9"`B3&EM:70@=&AE('1I;64@<W!A
M;B!T;R!E>'!O<G0Z(@IM<V=S='(@(L#-O;K&]\:N(+W#L*,@L*.PW2#!IL?1
M.B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX
M-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B
M3&]?8V%T:6]N(@IM<V=S='(@(L"GQ*$B"@HC.B!D871A+G!H<#HV-"!T96UP
M;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C4*(SH@=&5M<&QA=&5S
M+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,3@*(SH@=&5M<&QA
M=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-3(@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,C$*(SH@;&EB+T1R:79E<BYP:'`Z,3@T.0IM
M<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BP*?$H2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-0IM<V=I9"`B36%N86=E(')E;6]T92!C86QE;F1A<G,N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C<P"FUS9VED(")-87)C:"(*;7-G<W1R("(SO_DB"@HC.B!L:6(O87!I+G!H
M<#HQ,#`*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($5V96YT<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,@IM<V=I
M9"`B36%Y(@IM<V=S='(@(C6_^2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#8*
M;7-G:60@(DUE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N
M9&ES=#HQ-PIM<V=I9"`B365E=&EN9R(*;7-G<W1R("*YS,;#(@H*(SH@;&EB
M+T)L;V-K+W1R965?86QA<FUS+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-96YU
M($%L87)M<R(*;7-G<W1R("*^R[BR(@H*(SH@;&EB+T)L;V-K+W1R965?;65N
M=2YP:'`Z,PIM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C8X('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$S-PIM<V=I9"`B36EN=71E*',I(@IM<V=S='(@(KK0(@H*(SH@;&EB+T)L
M;V-K+W!R979M;VYT:&QI<W0N<&AP.C0R"FUS9VED(")-:7-S960@179E;G1S
M($QI<W0B"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#,@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C$X"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")-;R(*;7-G
M<W1R("*_^2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,34*(SH@=&5M<&QA=&5S+V5D:70O:F%V
M87-C<FEP="YI;F,Z-C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@IM<V=I
M9"`B36]N9&%Y(@IM<V=S='(@(K_YO^3`SR(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$R.3$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@U"FUS9VED(")-;VYT:"(*;7-G<W1R("*_^2(*"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B36]N=&@@
M5FEE=R(*;7-G<W1R("*_^2(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C,@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#,*;7-G:60@(DUO;G1H;'D@
M179E;G1S($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,CD@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C,U"FUS9VED(")-;VYT:&QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B
MO_FXMK39.B"YW[O]O_D@(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z
M,C0*;7-G:60@(DUO;G1H<R!!:&5A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO<')E=FUO;G1H;&ES="YP:'`Z,C0*(RP@9G5Z>GD*;7-G:60@(DUO;G1H
M<R!"969O<F4B"FUS9W-T<B`BNM`@P/PB"@HC.B!L:6(O87!I+G!H<#HV,3(*
M;7-G:60@(DUU;'1I<&QE(&E#86QE;F1A<B!C;VUP;VYE;G1S(&9O=6YD.R!O
M;FQY(&]N92!V179E;G0@:7,@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C
M86QE;F1A<G,N<&AP.C$R."!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(DUY($-A;&5N9&%R<R(*;7-G<W1R
M("+`S\&D(,#3QO?&KL?/L>(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S0@
M=&5M<&QA=&5S+VUE;G4N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")->2!#86QE
M;F1A<G,Z(@IM<V=S='(@(L#/P:0@P,V]NL;WQJXB"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C`T"FUS9VED(")->2!&<F5E+T)U
M<WD@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L
M96YD87)S+FEN8SHQ,3<@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$U.0HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W
M-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN
M8SHQ-PHC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT
M+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F%M92(*;7-G<W1R("*PU,#3(@H*
M(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HT,2!L:6(O0FQO8VLO;6]N=&AL:7-T
M+G!H<#HT-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*(SH@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,C`*;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R("*[
M];?.O^X@P,_!I"(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S0*
M(RP@9G5Z>GD*;7-G:60@(DYE>'0B"FUS9W-T<B`BM-G`O2#`SR(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-PIM<V=I9"`B3F5X="`R-"!H
M;W5R<R(*;7-G<W1R("(B"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z,CD*(RP@
M9G5Z>GD*;7-G:60@(DYE>'0@1&%Y(@IM<V=S='(@(K39P+T@P,\B"@HC.B!T
M96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C8*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP
M;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$X('1E;7!L871E
M<R]M;VYT:"]H96%D+FEN8SHV"FUS9VED(").97AT($UO;G1H(@IM<V=S='(@
M(K39P+T@M-XB"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C,R"B,L(&9U>GIY
M"FUS9VED(").97AT(%=E96LB"FUS9W-T<B`BM-G`O2#!UB(*"B,Z('1E;7!L
M871E<R]Y96%R+VAE860N:6YC.C8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@665A
M<B(*;7-G<W1R("*TV<"](,#/(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN
M8SHU"FUS9VED(").97AT(&1A>2(*;7-G<W1R("*TV<"](,#/(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4X('1E;7!L871E<R]W965K+VAE
M860N:6YC.C4*;7-G:60@(DYE>'0@=V5E:R(*;7-G<W1R("*TV<"](,'6(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-0HC+"!F=7IZ>0IM<V=I9"`B
M3F\B"FUS9W-T<B`BOOB]OR(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C<S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$R-@HC+"!F=7IZ>0IM<V=I
M9"`B3F\@86QA<FTB"FUS9W-T<B`BOLNXLB(*"B,Z('1E;7!L871E<R]A='1E
M;F1E97,O871T96YD965S+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B3F\@871T
M96YD965S(@IM<V=S='(@(L&^M^'`SR"^^+V_(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,Q,0IM<V=I9"`B3F\@8V%L96YD87)S(&%R92!A=F%I;&%B;&4@
M=&\@9W5E<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C4U"FUS9VED(").
M;R!E;F0@9&%T92(*;7-G<W1R("+!OK?AP,\@OOB]OR(*"B,Z(&QI8B]";&]C
M:R]P<F5V;6]N=&AL:7-T+G!H<#HQ-C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP
M:'`Z,38S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ.30*;7-G:60@(DYO
M(&5V96YT<R!T;R!D:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E
M+VMO;&%B+G!H<#HT,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE(&9O<B`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HS-#0@;&EB+V%P:2YP:'`Z-C`R"FUS9VED(").
M;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(P-`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M<F5C=7)R96YC92(*;7-G<W1R("*YW;JY(,#/(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z.#@V"FUS9VED(").;R!V86QI9"!E;6%I;"!A9&1R97-S(&9O=6YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8P,2!L:6(O2W)O
M;F]L:71H+G!H<#HV,C(*;7-G:60@(DYO;F4B"FUS9W-T<B`BOOB]OR(*"B,Z
M(&QI8B]3=&]R86=E+W-Q;"YP:'`Z,3,V"FUS9VED(").;W0@9F]U;F0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"B,L(&9U>GIY
M"FUS9VED(").;W1I9FEC871I;VYS(@IM<V=S='(@(L"GQ*$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.`IM<V=I9"`B3F]V96UB97(B
M"FUS9W-T<B`B,3&_^2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN
M8SHU-@IM<V=I9"`B3F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C<W"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(C$P
MO_DB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,R!T
M96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHV-0IM<V=I9"`B3VXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.`IM<V=I
M9"`B3VX@86QL(&-A;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-PIM<V=I9"`B
M3VX@86QL('-H;W=N(&-A;&5N9&%R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C<V"FUS9VED(")/;B!M>2!C86QE;F1A<G,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,3D*(RP@9G5Z
M>GD*;7-G:60@(D]P=&EO;F%L(@IM<V=S='(@(KRSP:0B"@HC.B!L:6(O1D)6
M:65W+G!H<#HQ,3@*;7-G:60@(D]P=&EO;F%L($%T=&5N9&5E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O1D)6:65W+G!H<#HQ-3(*;7-G:60@(D]V97)V:65W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C,T"FUS9VED
M(")/=VYE<B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")/=VYE<CH@)7,B"FUS9W-T<B`B
MQ]+`SSH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P,B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X,@IM<V=I9"`B4$TB"FUS9W-T
M<B`B(@H*(SH@9&%T82YP:'`Z,CD@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B4&%L;2!$871E0F]O:R(*;7-G<W1R("*^
MR[BR(,#/P-HB"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,PIM
M<V=I9"`B4&%S="!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,#D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,3DX"FUS9VED(")0871T97)N(@IM<V=S='(@(L"OQ_PB"@HC.B!T96UP;&%T
M97,O9&5L971E+V]N92YI;F,Z,C<*;7-G:60@(E!E<FUA;F5N=&QY(&1E;&5T
M92!T:&ES(&5V96YT/R(*;7-G<W1R("+`S"#`S\&DP+L@O\_`_,CW(+OHP:;'
MS[W#L-J]P+3/L>X_(@H*(SH@;&EB+V%P:2YP:'`Z,S(U(&QI8B]A<&DN<&AP
M.C0Q.2!L:6(O87!I+G!H<#HT.#$@;&EB+V%P:2YP:'`Z-34S"B,Z(&QI8B]A
M<&DN<&AP.C4X-"!L:6(O87!I+G!H<#HV-S`@;&EB+V%P:2YP:'`Z-S`V"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,38W"B,L(&9U>GIY"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R("*PL\#.(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Q"B,L(&9U>GIY"FUS9VED(")0;W)T86P@3W!T:6]N<R(*
M;7-G<W1R("*[Y[_KP-H@O+/!I"(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR
M-0HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@1&%Y(@IM<V=S='(@(L#,P/P@
MP,\B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C(V"B,L(&9U>GIY"FUS9VED
M(")0<F5V:6]U<R!7965K(@IM<V=S='(@(L#,P/P@P,\B"@HC.B!T96UP;&%T
M97,O9&%Y+VAE860N:6YC.C,*;7-G:60@(E!R979I;W5S(&1A>2(*;7-G<W1R
M("+`S,#\(,#/(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,U('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(U,@IM<V=I9"`B4F5C=7(@56YT:6PB
M"FUS9W-T<B`BP;ZWX2#`SR(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4F5C=7)R96YC92(*;7-G<W1R("*YW;JY
M(,#/(@H*(SH@9&%T82YP:'`Z-CD*;7-G:60@(E)E8W5R<F5N8V4@1&%T82(*
M;7-G<W1R("*YW;JY(,#/(@H*(SH@9&%T82YP:'`Z-C<*;7-G:60@(E)E8W5R
M<F5N8V4@16YD($1A=&4B"FUS9W-T<B`BN=VZN2#!OK?AP,\B"@HC.B!D871A
M+G!H<#HV.`IM<V=I9"`B4F5C=7)R96YC92!);G1E<G9A;"(*;7-G<W1R("*Y
MW;JY(+"CL-TB"@HC.B!D871A+G!H<#HV-@IM<V=I9"`B4F5C=7)R96YC92!4
M>7!E(@IM<V=S='(@(KG=NKD@P*_'_"(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C4T,`IM<V=I9"`B4F5C=7)S(&1A:6QY(@IM<V=S='(@(KC%P,\@N=VZN2(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T-PIM<V=I9"`B4F5C=7)S(&UO;G1H
M;'DB"FUS9W-T<B`BN,6_^2"YW;JY(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-30S"FUS9VED(")296-U<G,@=V5E:VQY(@IM<V=S='(@(KC%P=8@N=VZN2(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4U,`IM<V=I9"`B4F5C=7)S('EE87)L
M>2(*;7-G<W1R("*XQ;/B(+G=NKDB"@HC.B!L:6(O4V-H961U;&5R+VMR;VYO
M;&ET:"YP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6EN9&5R.B`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z.3$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T"B,L(&9U>GIY"FUS
M9VED(")296UO=&4@0V%L96YD87)S(@IM<V=S='(@(L#/P:0@P-/&]\:NQ\^Q
MXB(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHV,"!T96UP;&%T97,O;65N=2YI
M;F,Z-C(*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!#86QE;F1A<G,Z(@IM<V=S
M='(@(L#/P:0@P-/&]\:NQ\^QXB(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@
M)7,B"FUS9W-T<B`B(@H*(SH@871T96YD965S+G!H<#HQ,#0*;7-G:60@(E)E
M;6]V92!!='1E;F1E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C,R"FUS9VED("(B"B)297!L86-E(&5X:7-T:6YG(&-A;&5N
M9&%R('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4
M:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&-A
M;&5N9&%R+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HV,C8*;7-G:60@(E)E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M0E9I97<N<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S-R!L:6(O1D)6:65W+G!H
M<#HQ-#`@;&EB+T9"5FEE=RYP:'`Z,30S"FUS9VED(")297%U:7)E9"!!='1E
M;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S$P"FUS9VED(")297-E="!T
M;R!$969A=6QT<R(*;7-G<W1R("+#RK'BL*K`N+?.(@H*(SH@=&5M<&QA=&5S
M+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0S('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$V-@IM<V=I9"`B4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@>65A
M<BYP:'`Z.#@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C0@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C(S"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,3`U"FUS9VED(")382(*;7-G<W1R("+%Y"(*"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D+FEN8SHR,2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C`*
M(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S,*;7-G:60@(E-A
M='5R9&%Y(@IM<V=S='(@(L7DO^3`SR(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O8V%L96YD87)S+FEN8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS
M9W-T<B`BQ>0B"@HC.B!V:65W979E;G0N<&AP.C$Q."!E9&ET979E;G0N<&AP
M.C0X(&5D:71E=F5N="YP:'`Z-38*;7-G:60@(E-A=F4@07,@3F5W(@IM<V=S
M='(@(KOUM\X@P/K`Y2(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD
M965S+FEN8SHX-PIM<V=I9"`B4V%V92!!='1E;F1E97,B"FUS9W-T<B`B(@H*
M(SH@861D979E;G0N<&AP.C4U(&5D:71E=F5N="YP:'`Z-3$*;7-G:60@(E-A
M=F4@179E;G0B"FUS9W-T<B`BP,_!I"#`^L#E(@H*(SH@<V5A<F-H+G!H<#HY
M,2!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$U"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHV-R!T96UP;&%T97,O8V%L
M96YD87)S+W-E87)C:"YI;F,Z.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C$T,"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-@HC+"!F
M=7IZ>0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(C._^2(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ"B,L(&9U>GIY"FUS9VED(")396%R
M8V@@0V%L96YD87)S(@IM<V=S='(@(L#/P:0@P-/&]\:NQ\^QXB(*"B,Z('1E
M;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHV"FUS9VED(")396%R8V@@4F5S
M=6QT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C
M:"YI;F,Z-@IM<V=I9"`B4V5A<F-H(&9O<B!C86QE;F1A<G,@8V]N=&%I;FEN
M9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$U,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@8V%L96YD87(@
M=&\@961I="(*;7-G<W1R("+`T\;WQJ['TB#&Q,#/(+RQQ<,Z(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C@S"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S
M='(@(KW#P-L@P,_`VB(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.B(*;7-G
M<W1R("+`S\#:(,/BM\(@N>:]Q""\L<7#.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,0IM<V=I9"`B(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I
M;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C
M:&]O<V4@(@HB9&5F875L="!V:65W+B(*;7-G<W1R("+(KL#.(+_)O,?`NR"\
ML<7#Q\^_J2#(K;CI(,/BM\*_R;S'P+L@O*VWSB"TV;BCL-0@O+'%P\?5M,^T
MV2XB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Y"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@=&AE(&-A;&5N9&%R('1O(&EM<&]R="!T;SHB"FUS
M9W-T<B`BP-/&]\:NQ](@QL3`SR"\L<7#.B(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@97AP
M;W)T(&9O<FUA=#HB"FUS9W-T<B`BP-/&]\:NQ](@O-*]NB"\L<7#.B(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C@*;7-G:60@(E-E;&5C="!T
M:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(L#3QO?&KL?2(,;$P,\@O+'%
MPSHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED(")396QE
M8W0@=&AE(&9I<G-T('=E96MD87DZ(@IM<V=S='(@(L/6P\H@P=;!W\#/(+RQ
MQ<,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE
M.B(*;7-G<W1R("+`S;VZQO?&KL?2(,?\O<0@O+'%PSHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@T"FUS9VED(")396QE8W0@=&AE('1I;64@<W!A
M;B!T;R!S:&]W.B(*;7-G<W1R("+#XK?"O<.PHR"PH[#=(+RQQ<,Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O;B!S=&%R='5P.B(*;7-G<W1R("*W
MSK'7P,[(Q+^A(,/BM\+'TB#`S\&D(+RQQ<,Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=VAI8V@@979E
M;G1S('1O('-H;W<@:6X@=&AE('!O<G1A;"XB"FUS9W-T<B`B2&]R9&4@O^2^
MX+^AO*T@NKP@O/8@P-:QXL"GQ]$@P,_!I,"[(+RQQ</'TB"\]B#`UKW`M,^T
MV2XB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C0@=&5M<&QA=&5S
M+V1E;&5T92]D96QE=&4N:6YC.C(T"FUS9VED(")396YD(&$@8V%N8V5L(&YO
M=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@=&AI
M<R!E=F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5N9"!A;B!E;6%I;"!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#$*
M;7-G:60@(E-E;F0@=7!D871E<R]I;G9I=&%T:6]N<R!T;R!A;&P@871T96YD
M965S('=H96X@<V%V:6YG('1H:7,@979E;G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S8*;7-G:60@(E-E<'1E;6)E
M<B(*;7-G<W1R("(YO_DB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHX,PHC+"!F=7IZ>0IM<V=I9"`B4V5T(&5N9"!D871E(@IM<V=S
M='(@(L&^M^'`SR"^^+V_(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C8X"B,L(&9U>GIY"FUS9VED(")3970@<F5C=7)R96YC92!E;F0@9&%T92(*
M;7-G<W1R("*YW;JY(,&^M^'`SR(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")3970@<W1A<G0@9&%T
M92(*;7-G<W1R("*]P\#;(,#/P-HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3D*;7-G:60@(B(*(E-E="!Y;W5R(&9R964O8G5S>2!C86QE;F1A<G,@
M86YD('EO=7(@;W=N(&%N9"!O=&AE<B!U<V5R<R<@9G)E92]B=7-Y(&]P=&EO
M;G,N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4VAA<F4@;F]T(&9O=6YD.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-SD*(RP@9G5Z
M>GD*;7-G:60@(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T<B`BP,_!I"#`T\;W
MQJ['S['B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C0W('1E;7!L871E<R]M
M96YU+FEN8SHT.0HC+"!F=7IZ>0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R<SHB
M"FUS9W-T<B`BP,_!I"#`S;VZQO?&KB(*"B,Z(&-A;&5N9&%R7W-E87)C:"YP
M:'`Z,C4@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC+"!F
M=7IZ>0IM<V=I9"`B4VAO=R!#86QE;F1A<B(*;7-G<W1R("+`S\&D(,#-O;K&
M]\:N(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C(R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-H;W<@8V%L96YD87(@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-38*;7-G:60@(E-H
M;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30V"FUS9VED(")3:&]W(&1E;&5T92P@86QA<FTL(&%N
M9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS9VED(")3:&]W
M(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_(@IM<V=S='(@(L#/P:2_H;RM
M(,?2P,\@NKBQXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C8*;7-G
M:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N9#\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P,PIM<V=I9"`B4VAO=R!O;FQY(&5V96YT
M<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/R(*;7-G<W1R("*^R[BR(+RSP:2U
MR"#`S\&DN+@@NKBQXC\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<U
M"FUS9VED(")3:&]W('-H87)E9"!C86QE;F1A<G,@<VED92UB>2US:61E/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"B,L(&9U
M>GIY"FUS9VED(")3:&]W('1A<VMS('5S:6YG(&-A=&5G;W)Y(&-O;&]R<S\B
M"FUS9W-T<B`BP,_!I+^AO*T@Q]+`SR"ZN+'B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDU"B,L(&9U>GIY"FUS9VED(")3:&]W('1I;64@;V8@9&%Y
M(&)E='=E96X@96%C:"!D87D@:6X@=V5E:R!V:65W<S\B"FUS9W-T<B`BP,\@
MN=<@P=:ZL""ZN+'BOZ&\K2`S,+K0(+3<P*>WSB"ZN+'B/R(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q"B,L(&9U>GIY"FUS9VED
M(")3=&%?<G0B"FUS9W-T<B`BO</`VR#`S\#:(@H*(SH@9&%T82YP:'`Z-34*
M;7-G:60@(E-T87)T($1A=&4B"FUS9W-T<B`BO</`VR#`S\#:(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHW('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,C4*;7-G:60@(E-T87)T($]N(@IM<V=S='(@(KW#P-L@P,_`VB(*"B,Z(&1A
M=&$N<&AP.C4V"FUS9VED(")3=&%R="!4:6UE(@IM<V=S='(@(KW#P-L@O<.P
MHR(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHY
M-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHX-0IM<V=I9"`B4W1A=%]U<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N
M:6YC.C8@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T871U
M<R(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX,2!Y96%R+G!H<#HY,"!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-0HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,C0@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#<@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#D*;7-G:60@(E-U(@IM<V=S='(@(L#/(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H
M96%D+FEN8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M
M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(L#/O^3`SR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B5&%S:W,B"FUS
M9W-T<B`BQ]+`SR(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4W-"!L:6(O2W)O
M;F]L:71H+G!H<#HU.3<*;7-G:60@(E1E;G1A=&EV92(*;7-G<W1R("(B"@HC
M.B!Y96%R+G!H<#HX-B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV
M,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C$*(SH@;&EB+T)L;V-K+VUO
M;G1H+G!H<#HQ,#4*;7-G:60@(E1H(@IM<V=S='(@(KCQ(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW,`IM<V=I9"`B5&AE($5D:70@
M071T96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N="X@17AI=&EN
M9RXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&-A;FYO="!B92!D96QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C0P"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@8W)E
M871E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R
M96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H
M<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB
M(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,C8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B
M92!P=7)G960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+VIA
M=F%S8W)I<'0N:6YC.C$V,PIM<V=I9"`B5&AE(&5N9"!D871E(&UU<W0@8F4@
M;&%T97(@=&AA;B!T:&4@<W1A<G0@9&%T92XB"FUS9W-T<B`BP;ZWX<#/P+H@
MO</`V\#,NKBTV2#$O[[?(,?5M,^TV2XB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#DT"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!<(B5S7"(@
M:&%S(&)E96X@861D960L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3`T"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@9&5L971E9"P@=VAI
M8V@@=V%S(&]N("5S(&%T("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!<
M(B5S7"(@:&%S(&)E96X@961I=&5D+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@979E;G0@;F]T:69I8V%T:6]N('1O("5S('=A
M<R!S=6-C97-S9G5L;'D@<V5N="XB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`R-`IM<V=I9"`B5&AE(&9O;&QO=VEN9R!I<R!A(&UO<F4@
M9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V96YT.B(*;7-G<W1R("(B
M"@HC.B!A='1E;F0N<&AP.C0Q"FUS9VED("(B"B)4:&4@<F5Q=65S="!W87,@
M:6YC;VUP;&5T92X@4V]M92!P87)A;65T97)S('1H870@87)E(&YE8V5S<V%R
M>2!T;R!A8V-E<'0@;W(@(@HB9&5C;&EN92!A;B!E=F5N="!A<F4@;6ES<VEN
M9RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E;7!T>2YI;F,Z
M,PHC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&5V96YT<R!M871C:&EN
M9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`BP,V]NL;WQJ['TB#`
MS\&DP,P@OOB]P+3/M-DN(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C$X(&5D
M:71E=F5N=&%C=&EO;BYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R
M.B`E<R(*;7-G<W1R("+`VK?AN*8@P-/&]\:NQ\^TPB"UO[[((+_`M_FPH2"Y
MW[O]Q]^]P+3/M-DN(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C,T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@861D
M:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`BP-JWX;BF(,#3QO?&KL?/M,(@
MM;^^R""_P+?YL*$@N=^[_<??O<"TS[39+B(*"B,Z(&5D:71E=F5N=&%C=&EO
M;BYP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!E9&ET:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`BP-JW
MX;BF(,#3QO?&KL?/M,(@M;^^R""_P+?YL*$@N=^[_<??O<"TS[39+B(*"B,Z
M(&QI8B]A<&DN<&AP.C,S."!L:6(O87!I+G!H<#HU.38*(RP@9G5Z>GD*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R("+`VK?AN*8@P-/&]\:NQ\^TPB"UO[[((+_`M_FP
MH2"YW[O]Q]^]P+3/M-DN(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HV,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&UO=FEN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(L#:M^&XIB#`T\;WQJ['
MS[3"(+6_OL@@O\"W^;"A(+G?N_W'W[W`M,^TV2XB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<SH@
M)7,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3`U"FUS9VED(")4:&5R92!W
M97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N(@IM<V=S='(@(L#-O;K&]\:NQ](@
MP,_!I,#,(+[XO<"TS[39+B(*"B,Z(&1A=&$N<&AP.C$X-`IM<V=I9"`B5&AI
M<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!D871A+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q.`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,0IM<V=I
M9"`B5&AU<G-D87DB"FUS9W-T<B`BN/&_Y,#/(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C,W"B,L(&9U>GIY"FUS9VED(")4:6UE(%-P7V%N
M(@IM<V=S='(@(L'VOZH@O<.PHR(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C0*(RP@9G5Z>GD*;7-G:60@(E1I;64@<W!A;B(*;7-G
M<W1R("+!]K^J(+W#L*,B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A
M9'9A;F-E9"YI;F,Z,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z-#`*(RP@
M9G5Z>GD*;7-G:60@(E1I=%]L92(*;7-G<W1R("+!IKCQ(@H*(SH@9&%T82YP
M:'`Z-30@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"B,Z('1E;7!L
M871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z,PIM<V=I9"`B5&ET;&4B
M"FUS9W-T<B`BP::X\2(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H
M<#HQ,C(@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(Q"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ,C<*;7-G:60@(E1O9&%Y(@IM<V=S='(@(K_`M,,B
M"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(T(&QI8B]";&]C
M:R]M;VYT:&QI<W0N<&AP.C$R,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,3(Y"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX
M-"!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,"!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,3D*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*
M;7-G:60@(E1U(@IM<V=S='(@(LBM(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C$W('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-@HC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV.0IM<V=I9"`B5'5E<V1A>2(*
M;7-G<W1R("+(K;_DP,\B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z
M,3<*;7-G:60@(E1Y<&4B"FUS9W-T<B`BP*_'_"(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ.#,*;7-G:60@(E523"(*;7-G<W1R
M("(B"@HC.B!L:6(O4W1O<F%G92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!C86QE
M;F1A<G,N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VUC
M86PN<&AP.C$S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HS-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ-0HC.B!S8W)I<'1S+W5P9W)A9&5S+S(P,#0M,#4M
M,3E?8V]N=F5R=%]C871E9V]R:65S7W1O7W-T<FEN9W,N<&AP.C4S"FUS9VED
M(")5;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,W-B!L:6(O
M87!I+G!H<#HT-3`@;&EB+V%P:2YP:'`Z-3$V(&QI8B]A<&DN<&AP.C8R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B57-E<B!);G1E<F9A
M8V4B"FUS9W-T<B`BN^>_Z\#:(,#.Q<W&Y,#,O;HB"@HC.B!Y96%R+G!H<#HQ
M-C,@>65A<BYP:'`Z,38Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,38R"B,L(&9U>GIY"FUS9VED(")6:65W($1A>2(*
M;7-G<W1R("(E<R"ZN+'B(@H*(SH@>65A<BYP:'`Z.#4@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-C$@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C(P"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")792(*;7-G
M<W1R("*\]B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ."!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,3<*(SH@=&5M<&QA=&5S+V5D:70O:F%V
M87-C<FEP="YI;F,Z-S`*;7-G:60@(E=E9&YE<V1A>2(*;7-G<W1R("*\]K_D
MP,\B"@HC.B!A='1E;F1E97,N<&AP.C$Q,B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,CDP(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(S"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*;7-G<W1R("+!UB(*"B,Z(&UO
M;G1H+G!H<#HQ-SD@=V]R:W=E96LN<&AP.C,P('=E96LN<&AP.C,T"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E96L@)60B"FUS9W-T<B`B)60@P=8B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ-#`*;7-G:60@(E=E96LH<RDB"FUS9W-T<B`BN?C"L"#!UK^A("(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,34*;7-G:60@(E=E96ML>3H@4F5C=7)S(&5V97)Y(@IM
M<V=S='(@(L'6N+:TV2"YW[O].B"YW[O]P=8@(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-`IM<V=I9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@
M86YD('=E96L@=FEE=W,@96YD+"!W:&5N('1H97)E(&%R92!N;R!L871E<B!E
M=F5N=',_(@IM<V=S='(@(L#/(+G7(,'6NK`@NKBQXB#!OK?A(+W#L*,HP,_!
MI"#!OK?A(+W#L*,I/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*
M;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S
M('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V96YT<S\B"FUS
M9W-T<B`BP,\@N=<@P=:ZL""ZN+'B(+W#P-L@O<.PHRC`S\&D(+W#P-L@O<.P
MHRD_(@H*(SH@871T96YD965S+G!H<#HQ,3$@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3(X.2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E=O<FL@5V5E:R(*;7-G<W1R("+!UL'?
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,B!L:6(O0FQO8VLO=')E95]M
M96YU+G!H<#HR-0IM<V=I9"`B665A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C0Q"FUS9VED(")996%R;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R("*SXKBV
MM-DZ(+G?N_VSXB(*"B,Z(&1A=&$N<&AP.C0P(&1A=&$N<&AP.C(S-"!E9&ET
M979E;G1A8W1I;VXN<&AP.C0V(&%D9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@979E;G1S+B(*;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Y
M"FUS9VED(")9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF
M:65D(&5V96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C<V"FUS9VED(")9;W4@8V%N(&]N;'D@=7-E('1H:7,@
M9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.CDW,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W4@9&\@;F]T(&AA=F4@86X@96UA:6P@861D<F5S<R!C;VYF
M:6=U<F5D(&EN('EO=7(@4&5R<V]N86P@26YF;W)M871I;VX@(@HB3W!T:6]N
M<RX@66]U(&UU<W0@<V5T(&]N92`E<VAE<F4E<R!B969O<F4@979E;G0@;F]T
M:69I8V%T:6]N<R!C86X@8F4@<V5N="XB"FUS9W-T<B`B(@H*(SH@861D979E
M;G1A8W1I;VXN<&AP.C(P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C$Y-`IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L
M96YD87(N(@IM<V=S='(@(B(*"B,Z(&1E;&5V96YT86-T:6]N+G!H<#HR-@IM
M<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@9&5L971E('1H
M:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z
M-S@*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&5D:70@
M=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3@Y"FUS9VED
M(")9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BXB"FUS
M9W-T<B`B(@H*(SH@871T96YD+G!H<#HR,0IM<V=I9"`B66]U(&AA=F4@<W5C
M8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB
M"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HR-@IM<V=I9"`B66]U(&AA=F4@
M<W5C8V5S<V9U;&QY(&1E8VQI;F5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N
M="XB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HS,0IM<V=I9"`B66]U(&AA
M=F4@=&5N=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V
M96YT+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.CDQ"FUS9VED(")9
M;W4@;75S="!S96QE8W0@82!C86QE;F1A<B!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C4T
M"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y-`IM<V=I9"`B66]U
M(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@861D
M960@=&\@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$Q,#0*;7-G:60@(B(*(EEO=2!R97%U97-T960@=&\@8F4@
M;F]T:69I960@=VAE;B!E=F5N=',@87)E(&1E;&5T960@9G)O;2!Y;W5R(&-A
M;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y
M.0IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V
M96YT<R!A<F4@961I=&5D(&EN('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O4V-H961U;&5R+VMR;VYO;&ET:"YP:'`Z,C`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@<F5M:6YD960@86)O
M=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<VAA<F5S96QE8W0N:6YC.C$P"B,L(&9U>GIY"FUS
M9VED(")9;W5R(&1E9F%U;'0@8V%L96YD87(B"FUS9W-T<B`BP,_!I"#`S;VZ
MQO?&KB(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-3,@;&EB+T1R:79E<BYP:'`Z
M,3`V,PIM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.CDW"B,L(&9U>GIY"FUS9VED(")?06QA
M<FTB"FUS9W-T<B`BOLNXLB(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHQ,0IM<V=I9"`B7T)A<VEC(%-E87)C:"(*;7-G<W1R
M("(B"@HC.B!V:65W979E;G0N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B7T5D
M:70B"FUS9W-T<B`BO/;!I"(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S`*
M(RP@9G5Z>GD*;7-G:60@(E]';W1O(@IM<V=S='(@(L#,M;\B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,S,V"B,L(&9U>GIY"FUS9VED(")?26UP;W)T+T5X
M<&]R="(*;7-G<W1R("+`T\;WQJXOP,V]NL;WQJXB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,S$X"B,L(&9U>GIY"FUS9VED(")?37D@0V%L96YD87)S(@IM
M<V=S='(@(L#/P:0@P,V]NL;WQJXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,S(U"B,L(&9U>GIY"FUS9VED(")?3F5W($5V96YT(@IM<V=S='(@(KOUM\Z_
M[B#`S\&D(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,T,0IM<V=I9"`B7U!R
M:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S(*(RP@
M9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B,[_Y(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,R.`HC+"!F=7IZ>0IM<V=I9"`B7U1O9&%Y(@IM<V=S
M='(@(K_`M,,B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#(*;7-G
M:60@(F)E9F]R92!T:&4@979E;G0@<W1A<G1S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G<W1R("+`
MSR(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,3`*;7-G:60@(F1A>2AS*2(*;7-G<W1R("+`SR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$X-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y,`IM<V=I9"`B9&%Y<R(*;7-G<W1R("+`SR(*"B,Z(&1A=&$N<&AP.C$T
M-R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*(RP@9G5Z>GD*;7-G:60@
M(F5V96YT<RYC<W8B"FUS9W-T<B`BP/S#O"#`S\&D(@H*(SH@9&%T82YP:'`Z
M,38X"B,L(&9U>GIY"FUS9VED(")E=F5N=',N:6-S(@IM<V=S='(@(L#\P[P@
MP,_!I"(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3,Q
M"FUS9VED(")F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$R-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C8*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C,P('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(S-@IM<V=I9"`B;6]N=&@H<RDB"FUS9W-T<B`BO_DB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#(P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")O;B`E<R!A="`E<R(*;7-G<W1R("(E<["A("5S(+^AO*T@O</`V\?5M,^T
MV2XB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C,P"FUS9VED(")O;B!T:&4@<V%M92!D871E(@IM
M<V=S='(@(B"PL,"ZLZ^_H2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$R-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S8*;7-G:60@(F]N('1H
M92!S86UE('=E96MD87DB"FUS9W-T<B`B(+"PP+H@P=:_H2(*"B,Z(&1A=&$N
M<&AP.C,P('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*;7-G:60@(G9#
M86QE;F1A<B]I0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,S0Y(&QI8B]A<&DN<&AP.C8P-PIM<V=I9"`B=D5V96YT(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,0IM<V=I
M9"`B=V5E:R(*;7-G<W1R("+!UB(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3<*;7-G:60@(G=E
M96LH<RD@;VXZ(@IM<V=S='(@(KGXPK`@P=:_H3HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DR(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y-`IM<V=I9"`B=V5E:W,B"FUS9W-T
M<B`BP=8B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C0R"FUS9VED(")Y96%R*',I(@IM<V=S='(@
M(K/B(@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]K<F]N;VQI=&@O<&\O97-?15,N<&\`````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3,W,3$S`#$P-#$W,S8R-S4R`#`R
M,#0Q,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C(%-P86YI<V@@=')A;G-L871I;VYS(&9O<B!H;W)D92!P86-K86=E"B,@
M5')A9'5C8VEO;F5S(&%L(&5S<&'Q;VP@<&%R82!E;"!P87%U971E(&AO<F1E
M+@HC($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE(&AO<F1E('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L
M(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($MR;VYO;&ET:"`R+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#8M,#(M,30@,3,Z,S(K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-BTP,BTQ-"`Q,3HS-RLP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($UA
M;G5E;"!0+B!!>6%L82`\;6%Y86QA0'5N97@N97,^7&XB"B),86YG=6%G92U4
M96%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U697)S:6]N.B`Q
M+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M
M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB
M"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3M<
M;B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"!C86QE;F1A<G,@9F]U;F0B"FUS9W-T<B`B
M16YC;VYT<F%D87,@)60@86=E;F1A<R(*"B,Z('1E;7!L871E<R]S96%R8V@O
M:&5A9&5R+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&5V96YT<R(*
M;7-G<W1R("(E9"!A8V]N=&5C:6UI96YT;W,B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@1&%Y*',I("5S($AO=7(H<RD@)7,@36EN=71E<R(*;7-G<W1R("(E<R!D
M[6$H<RD@)7,@:&]R82AS*2`E<R!M:6YU=&]S(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3@P-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A='1E;F1E97,B"FUS
M9W-T<B`B)7,@87-I<W1E;G1E<R(*"B,Z(&1A=&$N<&AP.C(X,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*
M;7-G<W1R(")%;"!A<F-H:79O("5S('-E(&AA(&EM<&]R=&%D;R!S871I<V9A
M8W1O<FEA;65N=&4B"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O8F%S92YP
M:'`Z,3(X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS
M9W-T<B`B06=E;F1A(&1E("5S(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S
M96%R8V@N:6YC.C$W"FUS9VED("(B"B(H0VQI8VL@;VX@8V%L96YD87(@;F%M
M92!T;R!S=VET8V@@=&AE(&-A;&5N9&%R)W,@=FES:6)I;&ET>2!I;B!T:&4@
M;6%I;B`B"B)W:6YD;W<I(@IM<V=S='(@(B(*(BA0=6QS92!E;"!N;VUB<F4@
M9&5L(&-A;&5N9&%R:6\@<&%R82!C;VYM=71A<B!S=2!V:7-I8FEL:61A9"!E
M;B!L82!V96YT86X@(@HB<')I;F-I<&%L*2(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,38U"FUS9VED("(J($%D9"!T:&5S92!B>2!C
M;&EC:VEN9R!!9&0@*B(*;7-G<W1R("(J($%G<F5G87(@Z7-T;W,@:&%C:65N
M9&\@8VQI8R!E;B!!\6%D:7(@*B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,34Q"FUS9VED("(J(%!L96%S92!S96QE8W0@861D<F5S
M<RAE<RD@*B(*;7-G<W1R("(J(%!O<B!F879O<BP@<V5L96-C:6]N92!L82AS
M*2!D:7)E8V-I\VXH97,I("HB"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#`V"FUS
M9VED("(Q(&%T=&5N9&5E(@IM<V=S='(@(C$@87-I<W1E;G1E(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*;7-G:60@(C$@979E;G0B"FUS
M9W-T<B`B,2!A8V]N=&5C:6UI96YT;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C$S-PIM<V=I9"`B,2!H;W5R(@IM<V=S='(@(C$@:&]R82(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$S-`IM<V=I9"`B,34@
M;6EN=71E<R(*;7-G<W1R("(Q-2!M:6YU=&]S(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED("(R,"!M:6YU=&5S(@IM<V=S='(@
M(C(P(&UI;G5T;W,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ
M,S8*;7-G:60@(C,P(&UI;G5T97,B"FUS9W-T<B`B,S`@;6EN=71O<R(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$V.0IM<V=I9"`B/'-T<F]N9SY!
M='1E;F1E97,\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\<W1R;VYG
M/D%S:7-T96YT97,\+W-T<F]N9SX@*&]P8VEO;F%L*2(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$T-PIM<V=I9"`B/'-T<F]N9SY$97-C<FE?<'1I
M;VX\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\<W1R;VYG/D1E<V-R
M:5]P8VGS;CPO<W1R;VYG/B`H;W!C:6]N86PI(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C<T"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S=')O
M;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9SY086QA8G)A<R!C;&%V
M93PO<W1R;VYG/B`H;W!C:6]N86PI(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,3DR"FUS9VED("(\<W1R;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@
M*&]P=&EO;F%L*2(*;7-G<W1R("(\<W1R;VYG/E)E<&5T:6-I\VX\+W-T<F]N
M9SX@*&]P8VEO;F%L*2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3$S('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3DS"FUS9VED(")!32(*
M;7-G<W1R(")!32(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8P,@IM<V=I9"`B
M06-C97!T960B"FUS9W-T<B`B06-E<'1A9&$B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z,3$*;7-G:60@(D%D7W9A;F-E9"!396%R8V@B"FUS
M9W-T<B`B0OIS7W%U961A(&%V86YZ861A(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ-C`*;7-G:60@(D%D9"(*;7-G<W1R(")!\6%D
M:7(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,@IM<V=I9"`B061D
M($5V96YT(@IM<V=S='(@(D'Q861I<B!!8V]N=&5C:6UI96YT;R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C,U"FUS
M9VED(")!9&0@82!N97<@4F5M;W1E($-A;&5N9&%R(@IM<V=S='(@(D'Q861I
M<B!U;F$@86=E;F1A(')E;6]T82(*"B,Z(&%D9&5V96YT+G!H<#HV-`IM<V=I
M9"`B061D(&$@;F5W(&5V96YT(@IM<V=S='(@(D'Q861I<B!U;B!A8V]N=&5C
M:6UI96YT;R(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN
M8SHW,0IM<V=I9"`B061D(&%T=&5N9&5E<R(*;7-G<W1R(")!\6%D:7(@87-I
M<W1E;G1E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,3@U"FUS9VED(")!9&0@=&\@871T96YD965S(@IM<V=S='(@(D'Q861I<B!A
M(&%S:7-T96YT97,B"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,C@*(SH@=&5M<&QA=&5S+V%T=&5N9&5E
M<R]A='1E;F1E97,N:6YC.C<T"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`B3&EB<F5T82!D92!D:7)E8V-I;VYE<R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHQ,0IM<V=I9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(D+Z
M<W%U961A(&%V86YZ861A(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M-3,*;7-G:60@(D%L87)M(@IM<V=S='(@(D%L87)M82(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@9&%Y
M<R!B969O<F4B"FUS9W-T<B`B06QA<FUA("5D(&3M87,@86YT97,B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ-S@W"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M
M("5D(&AO=7)S(&)E9F]R92(*;7-G<W1R(")!;&%R;6$@)60@:&]R87,@86YT
M97,B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-SDR"B,L('!H<"UF;W)M870*;7-G
M:60@(D%L87)M("5D(&UI;G5T97,@8F5F;W)E(@IM<V=S='(@(D%L87)M82`E
M9"!M:6YU=&]S(&%N=&5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<W-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!W965K<R!B969O<F4B"FUS9W-T
M<B`B06QA<FUA("5D('-E;6%N87,@86YT97,B"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-S@Q"FUS9VED(")!;&%R;2`Q(&1A>2!B969O<F4B"FUS9W-T<B`B06QA
M<FUA(#$@9.UA(&%N=&5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-@IM<V=I
M9"`B06QA<FT@,2!H;W5R(&)E9F]R92(*;7-G<W1R(")!;&%R;6$@,2!H;W)A
M(&%N=&5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<Y,0IM<V=I9"`B06QA<FT@
M,2!M:6YU=&4@8F5F;W)E(@IM<V=S='(@(D%L87)M82`Q(&UI;G5T;R!A;G1E
M<RDB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<V"FUS9VED(")!;&%R;2`Q('=E
M96L@8F5F;W)E(@IM<V=S='(@(D%L87)M82`Q('-E;6%N82!A;G1E<R(*"B,Z
M(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!$871E(@IM<V=S='(@(D9E8VAA
M(&1E(&%L87)M82(*"B,Z(&1A=&$N<&AP.C4X"FUS9VED(")!;&%R;2!3<&%N
M("AM:6YU=&5S*2(*;7-G<W1R("));G1E<G9A;&\@9&4@;&$@86QA<FUA("AM
M:6YU=&]S*2(*"B,Z(&1A=&$N<&AP.C8P"FUS9VED(")!;&%R;2!4:6UE(@IM
M<V=S='(@(DAO<F$@9&4@;&$@86QA<FUA(@H*(SH@=&5M<&QA=&5S+V1E;&5T
M92]D96QE=&4N:6YC.C,T"FUS9VED(")!;&PB"FUS9W-T<B`B5&]D87,B"@HC
M.B!L:6(O1D)6:65W+G!H<#HQ,C@@;&EB+T9"5FEE=RYP:'`Z,3,Q(&QI8B]&
M0E9I97<N<&AP.C$S-`IM<V=I9"`B06QL($%T=&5N9&5E<R(*;7-G<W1R(")4
M;V1O<R!L;W,@87-I<W1E;G1E<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHU.0IM<V=I9"`B06QL($9U='5R92(*;7-G<W1R(")!8V]N=&5C
M:6UI96YT;W,@9G5T=7)O<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHU,PIM<V=I9"`B06QL(%!A<W0B"FUS9W-T<B`B06-O;G1E8VEM:65N
M=&]S('!A<V%D;W,B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z
M,C<@;&EB+T)L;V-K+VUO;G1H+G!H<#HR-`HC.B!L:6(O0FQO8VLO;6]N=&AL
M:7-T+G!H<#HR-R!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D%L
M;"!6:7-I8FQE(@IM<V=S='(@(E1O9&%S(&QA<R!V:7-I8FQE<R(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,B!L:6(O1&%Y5FEE
M=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.CDS"B,Z(&QI8B]7965K5FEE=RYP
M:'`Z,3(W(&QI8B]7965K5FEE=RYP:'`Z,3,T(&QI8B]$<FEV97(N<&AP.C$X
M-CD*;7-G:60@(D%L;"!D87DB"FUS9W-T<B`B5&]D;R!E;"!D[6$B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,38T"FUS9VED(")!;&P@9&%Y(&5V96YT
M(@IM<V=S='(@(D%C;VYT96-I;6EE;G1O('!O<B!T;V1O(&5L(&3M82(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S,*;7-G:60@(D%L;"!E=F5N
M=',B"FUS9W-T<B`B5&]D;W,@;&]S(&%C;VYT96-I;6EE;G1O<R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHT.`HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-S`@;&EB+TMR;VYO
M;&ET:"YP:'`Z-CDU"FUS9VED(")!;GDB"FUS9W-T<B`B0W5A;'%U:65R82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!
M<')I;"(*;7-G<W1R(")!8G)I;"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C,Y('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.CDS"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z.#(@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ-C@*;7-G:60@(D%T(@IM<V=S='(@(D$@
M;&%S(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`T-@IM<V=I9"`B(@HB071T
M86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@=VET:"!M;W)E(&EN9F]R;6%T
M:6]N(&%B;W5T('1H92!E=F5N="X@268@>6]U<B`B"B)M86EL(&-L:65N="!S
M=7!P;W)T<R!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E('1H:7,@9FEL92!T
M;R!E87-I;'D@=7!D871E("(*(GEO=7(@;&]C86P@8V]P>2!O9B!T:&4@979E
M;G0N(@IM<V=S='(@(B(*(E-E(&%D:G5N=&$@=6X@87)C:&EV;R!I0V%L96YD
M87(@8V]N(&WA<R!I;F9O<FUA8VGS;B!S;V)R92!E;"!A8V]N=&5C:6UI96YT
M;RX@(@HB4VD@<W4@8VQI96YT92!D92!C;W)R96\@<V]P;W)T82!S;VQI8VET
M=61E<R!I5&EP+"!P=65D92!U=&EL:7IA<B!E;"!A<F-H:79O("(*(G!A<F$@
M86-T=6%L:7IA<B!FX6-I;&UE;G1E('-U(&-O<&EA(&QO8V%L(&1E;"!A8V]N
M=&5C:6UI96YT;RXB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E
M<RYI;F,Z-#(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!
M='1E;F1A;F-E(@IM<V=S='(@(D%S:7-T96YC:6$B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ-C$*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")!
M<VES=&5N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z
M-S4*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!9V]S=&\B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C@*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R
M(")"^G-Q=65D82!S:6UP;&4B"@HC.B!C;VYF:6<O+F)A:R]K97EW;W)D<RYP
M:'`N9&ES=#HQ-PIM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B0W5M<&QE8?%O
M<R(*"B,Z(&QI8B]&0E9I97<N<&AP.CDP(&QI8B]&0E9I97<N<&AP.C$Q,0IM
M<V=I9"`B0G5S>2(*;7-G<W1R(")/8W5P861O(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C0R"FUS9VED(")#7V%L96YD87(B
M"FUS9W-T<B`B05]G96YD82(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C0W"FUS9VED(")#86Q?96YD87(B"FUS9W-T<B`B05]G96YD82(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#D@;&EB+T)L;V-K
M+W!R979M;VYT:&QI<W0N<&AP.C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,C$@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C$@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C(R"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PIM<V=I9"`B0V%L96YD87(@4W5M
M;6%R>2(*;7-G<W1R(")297-U;65N(&1E(&QA(&%G96YD82(*"B,Z(&1A=&$N
M<&AP.C(S,PIM<V=I9"`B0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB
M"FUS9W-T<B`B3&$@86=E;F1A('-E(&AA('-U<')I;6ED;R!S871I<V9A8W1O
M<FEA;65N=&4N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S8@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-#,*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z-3`@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M-3<*;7-G:60@(D-A;&5N9&%R<R(*;7-G<W1R(")!9V5N9&%S(@H*(SH@8V%L
M96YD87)S+G!H<#HR-PIM<V=I9"`B0V%L96YD87)S(&UU<W0@:&%V92!A(&YA
M;64N(@IM<V=S='(@(DQA<R!A9V5N9&%S('1I96YE;B!Q=64@=&5N97(@=6X@
M;F]M8G)E+B(*"B,Z(&1A=&$N<&AP.C(T.`IM<V=I9"`B0V%N)W0@8W)E871E
M(&$@;F5W(&5V96YT+B(*;7-G<W1R(").;R!S92!P=65D92!C<F5A<B!U;B!A
M8V]N=&5C:6UI96YT;R(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHS
M,R!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S4*(SH@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,S$@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S`W
M"FUS9VED(")#86YC96PB"FUS9W-T<B`B0V%N8V5L87(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU-S@*;7-G:60@(D-A;F-E;&QE9"(*;7-G<W1R(")#86YC
M96QA9&\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;F-E;&QE9#H@)7,B"FUS9W-T<B`B0V%N8V5L861O.B`E
M<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV
M,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHV-PIM<V=I9"`B0V%T96=O<E]Y
M(@IM<V=S='(@(E]#871E9V]R[6$B"@HC.B!D871A+G!H<#HV,B!T96UP;&%T
M97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C0@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3,*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(D-A=&5G;W+M
M82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(W.0IM<V=I9"`B
M(@HB0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@
M961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',@8GD@(@HB96UA:6PZ(@IM<V=S
M='(@(B(*(D5L:6IA('-I(&1E<V5A('%U92!S92!L92!N;W1I9FEQ=65N('!O
M<B!C;W)R96\@96QE8W1R\VYI8V\@;&]S("(*(F%C;VYT96-I;6EE;G1O<R!N
M=65V;W,L(&UO9&EF:6-A9&]S(&\@96QI;6EN861O<SHB"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W
M86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E
M9"!E=F5N=',N(@IM<V=S='(@(B(*(D5L:6IA('-I(&1E<V5A('%U92!S92!L
M92!N;W1I9FEQ=65N(&QO<R!A8V]N=&5C:6UI96YT;W,@;G5E=F]S+"!M;V1I
M9FEC861O<R`B"B)O(&5L:6UI;F%D;W,N(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z,CDR"FUS9VED(")#:&]O<V4@:68@>6]U('=A;G0@=&\@
M<F5C96EV92!E;6%I;"!R96UI;F1E<G,@9F]R(&5V96YT<R!W:71H(&%L87)M
M<SHB"FUS9W-T<B`B(@HB16QI:F$@<VD@<75I97)E(')E8VEB:7(@<F5C;W)D
M871O<FEO<R!P;W(@8V]R<F5O(&1E(&QO<R!A8V]N=&5C:6UI96YT;W,@8V]N
M("(*(F%L87)M87,Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E87)C:%]A8F]O
M:U]S96QE8W0N:6YC.C$Y(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,Q
M,@IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F
M;W(@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*(D5L:6IA(&QA<R!L:6)R
M971A<R!D92!D:7)E8V-I;VYE<R!E;B!L87,@<75E(&)U<V-A<B!54DQS(&1E
M(&EN9F]R;6%C:?-N(&1E("(*(G1I96UP;R!D:7-P;VYI8FQE+B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]F8E]C86QS7W-E;&5C="YI;F,Z,38*;7-G:60@(D-H
M;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U
M<WD@:6YF;W)M871I;VXZ(@IM<V=S='(@(B(*(D5L:6IA(&QA<R!A9V5N9&%S
M('%U92!Q=6EE<F4@<75E('-E(&EN8VQU>6%N(&5N(&QA(&EN9F]R;6%C:?-N
M(&1E(%1I96UP;R`B"B)$:7-P;VYI8FQE.B(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C,R-`IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@
M=&\@:6YC;'5D92!W:&5N(&=E;F5R871I;F<@9G)E92]B=7-Y(%523',Z(@IM
M<V=S='(@(B(*(D5L:6IA(&QA<R!A9V5N9&%S(&$@:6YC;'5I<B!A;"!G96YE
M<F%R(%523',@9&4@:6YF;W)M86-I\VX@9&4@=&EE;7!O("(*(F1I<W!O;FEB
M;&4Z(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@
M(D-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@(D5L:6IA
M(&QA(&%G96YD82!P;W(@;VUI<VGS;BXB"@HC.B!T96UP;&%T97,O871T96YD
M965S+V%T=&5N9&5E<RYI;F,Z.#0*;7-G:60@(D-L96%R(&%L;"!A='1E;F1E
M97,B"FUS9W-T<B`B0F]R<F%R('1O9&]S(&QO<R!A<VES=&5N=&5S(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*;7-G:60@(D-L
M;W-E('=I;F1O=R(*;7-G<W1R(")#97)R87(@=F5N=&%N82(*"B,Z(&1A=&$N
M<&AP.C(X('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3,*;7-G:60@(D-O
M;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B5F%L;W)E<R!S97!A<F%D
M;W,@<&]R(&-O;6%S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M-S,*;7-G:60@(D-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S/R(*;7-G<W1R
M("*_0V]N9FER;6%R(&5L:6UI;F%C:?-N(&1E(&%C;VYT96-I;6EE;G1O<S\B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S4*;7-G:60@(D-O;F9I<FUE9"(*
M;7-G<W1R(")#;VYF:7)M861O(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C(Q-PIM<V=I9"`B0V]P>2!T:&4@55),(&)E;&]W(&9O
M<B!U<V4@=VAE<F5V97(@>6]U(&YE960@>6]U<B!&<F5E+T)U<WD@55),.B(*
M;7-G<W1R("(B"B)#;W!I92!L82!S:6=U:65N=&4@55),('!A<F$@=7-A<FQA
M('-I96UP<F4@<75E(&YE8V5S:71E('-U(%523"!D92!T:65M<&\@(@HB9&ES
M<&]N:6)L93HB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(DYO('-E
M('!U961E(&%B<FER("5S+B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L
M96YD87)S+FEN8SHQ,CD*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<F5A<B(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,34*;7-G
M:60@(D-R96%T92!#86QE;F1A<B(*;7-G<W1R(")#<F5A<B!A9V5N9&$B"@HC
M.B!M;VYT:"YP:'`Z,38S('1E;7!L871E<R]W965K+VAE860N:6YC.C(U('1E
M;7!L871E<R]D87DO<F]W+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H<#HY,"!L
M:6(O1&%Y5FEE=RYP:'`Z,3DU"FUS9VED(")#<F5A=&4@82!.97<@179E;G0B
M"FUS9W-T<B`B0?%A9&ER(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M.#`*;7-G:60@(D-R96%T960B"FUS9W-T<B`B0W)E861O(@H*(SH@=&5M<&QA
M=&5S+V1E;&5T92]D96QE=&4N:6YC.C,R"FUS9VED(")#=7)R96YT(@IM<V=S
M='(@(D%C='5A;"(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,#8*;7-G:60@(D1A:6QY.B!296-U
M<G,@979E<GDB"FUS9W-T<B`B1&EA<FEA;65N=&4Z(%-E(')E<&ET92!C861A
M(@H*(SH@871T96YD965S+G!H<#HQ,#8@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q
M,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,0HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HX,@IM<V=I9"`B1&%Y(@IM<V=S='(@(D3M82(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C$S-PIM<V=I9"`B1&%Y*',I(@IM<V=S='(@(D3M82AS*2(*"B,Z
M('9I97=E=F5N="YP:'`Z,3$Q"FUS9VED(")$95]L971E(@IM<V=S='(@(E]%
M;&EM:6YA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Y
M"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$:6-I96UB<F4B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HV,#4*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(E)E
M8VAA>F%D82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,W"FUS
M9VED(")$969A=6QT($-A;&5N9&%R(@IM<V=S='(@(D%G96YD82!P;W(@;VUI
M<VGS;B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR
M,#0@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,R"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C(S(&QI8B]$<FEV97(N
M<&AP.C$X-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")%;&EM:6YA<B(*"B,Z
M(&1E;&5V96YT+G!H<#HT,"!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C$@
M=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(Q"B,Z(&QI8B]$<FEV97(N
M<&AP.C$X-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(@IM<V=S
M='(@(D5L:6UI;F%R("5S(@H*(SH@961I=&5V96YT+G!H<#HW,@IM<V=I9"`B
M1&5L971E($5V96YT(@IM<V=S='(@(D5L:6UI;F%R(@H*(SH@=&5M<&QA=&5S
M+V1E;&5T92]D96QE=&4N:6YC.C,P"FUS9VED("(B"B)$96QE=&4@=&AE(&-U
M<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T
M=7)E(&]C8W5R96YC97,L(&]R("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R
M("(B"B*_16QI;6EN87(@<_-L;R!E;"!A8V]N=&5C:6UI96YT;R!A8W1U86PL
M(.ES=&$@87!A<FEC:?-N('D@;&%S(&9U='5R87,L(&\@(@HB=&]D87,@;&%S
M(&%P87)I8VEO;F5S/R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHQ,#,@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X
M"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B7T1E<V-R:7!C:?-N(@H*
M(SH@9&%T82YP:'`Z-C$@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$W.`HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHY-@IM<V=I9"`B
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I<&-I\VXB"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W-`IM<V=I9"`B1&ES<&QA>2(*
M;7-G<W1R(")-;W-T<F%R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C8S"FUS9VED(")$:7-P;&%Y($-A;&5N9&%R<R(*;7-G<W1R
M(")-;W-T<F%R(&%G96YD87,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HY(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(P"B,Z(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.C(X"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`B3W!C:6]N97,@9&4@5FES=6%L:7IA8VGS;B(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$;R!Y;W4@=V%N
M="!T;R!S:&]W('1A<VMS('=H:6-H(&%R92!D=64@;VX@>6]U<B!C86QE;F1A
M<C\B"FUS9W-T<B`B4V5L96-C:6]N92!C\VUO(&UO<W1R87(@96X@;&$@86=E
M;F1A(&QA<R!T87)E87,@=F5N8VED87,B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU-#4*;7-G:60@(D1O97,@;F]T(')E8W5R(@IM<V=S='(@(DYO('-E(')E
M<&ET92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C,R-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$=64Z("5S(@IM<V=S='(@(E9E;F-I9&\Z("5S.B(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R
M871I;VXB"FUS9W-T<B`B1'5R86-I\VXB"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,3<S(&QI8B]$<FEV97(N<&AP.C$X,S8*;7-G
M:60@(D5D:70B"FUS9W-T<B`B36]D:69I8V%R(@H*(SH@961I=&5V96YT+G!H
M<#HS,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,B!L:6(O1')I=F5R+G!H
M<#HQ.#,U"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@)7,B"FUS9W-T<B`B
M36]D:69I8V%R("5S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@U
M"FUS9VED(")%9&ET($%T=&5N9&5E<R(*;7-G<W1R(")-;V1I9FEC87(@87-I
M<W1E;G1E<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ-#,*;7-G:60@(D5D:70@0V%L96YD87)S(@IM<V=S='(@(DUO9&EF:6-A
M<B!A9V5N9&%S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C4P
M"FUS9VED(")%9&ET(%)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B36]D:69I
M8V%R(&%G96YD87,@<F5M;W1A<R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,30V"FUS
M9VED(")%9&ET(&%T=&5N9&5E<R(*;7-G<W1R(")-;V1I9FEC87(@87-I<W1E
M;G1E<R(*"B,Z('1E;7!L871E<R]C871E9V]R>5]L96=E;F0N:6YC.C(P"FUS
M9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<R(*;7-G<W1R(")-;V1I
M9FEC87(@8V%T96=O<NUA<R!Y(&-O;&]R97,B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$W-R!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-#$*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38T
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D1I<F5C8VGS;B!D92!C
M;W)R96\B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHV
M,`IM<V=I9"`B16Y?9"(*;7-G<W1R(")?1FEN86PB"@HC.B!D871A+G!H<#HU
M-@IM<V=I9"`B16YD($1A=&4B"FUS9W-T<B`B1F5C:&$@9FEN86PB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C@@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ,C`*;7-G:60@(D5N9"!/;B(*;7-G<W1R(")497)M:6YA(&5L(@H*(SH@
M9&%T82YP:'`Z-3<*;7-G:60@(D5N9"!4:6UE(@IM<V=S='(@(DAO<F$@9FEN
M86PB"@HC.B!A='1E;F1E97,N<&AP.C$R,"!A='1E;F1E97,N<&AP.C$S,2!A
M='1E;F1E97,N<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R
M971R:65V:6YG(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,Z("5S(@IM
M<V=S='(@(D5R<F]R(&%L(')E8W5P97)A<B!L82!I;F9O<FUA8VGS;B!D92!T
M:65M<&\@9&ES<&]N:6)L92!D92`E<SH@)7,B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,3$S"FUS9VED(")%=F5N="!A9&1E9#HB"FUS9W-T<B`B06-O;G1E
M8VEM:65N=&\@8?%A9&ED;SHB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3(S
M"FUS9VED(")%=F5N="!D96QE=&5D.B(*;7-G<W1R(")!8V]N=&5C:6UI96YT
M;R!E;&EM:6YA9&\Z(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q.`IM<V=I
M9"`B179E;G0@961I=&5D.B(*;7-G<W1R(")!8V]N=&5C:6UI96YT;R!M;V1I
M9FEC861O.B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B179E;G0@9G)O;2`E<R!T;R`E<R(*;7-G<W1R(")!8V]N=&5C
M:6UI96YT;R!D92`E<R!P87)A("5S(@H*(SH@;&EB+T1R:79E<B]S<6PN<&AP
M.C,W,PIM<V=I9"`B179E;G0@;F]T(&9O=6YD(@IM<V=S='(@(DYO('-E(&5N
M8V]N='+S(&5L(&%C;VYT96-I;6EE;G1O(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M-S<P"FUS9VED(")%=F5N=',@;75S="!H879E(&$@<W1A<G0@9&%T92XB"FUS
M9W-T<B`B3&]S(&%C;VYT96-I;6EE;G1O<R!T:65N96X@<75E('1E;F5R('5N
M82!F96-H82!I;FEC:6%L+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<S-@IM<V=I
M9"`B179E;G1S(&UU<W0@:&%V92!A('1I=&QE+B(*;7-G<W1R("),;W,@86-O
M;G1E8VEM:65N=&]S('1I96YE;B!Q=64@=&5N97(@=6X@=.UT=6QO+B(*"B,Z
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHW-0IM<V=I9"`B
M17AP86YD($YA;65S(@IM<V=S='(@(D5X<&%N9&ER(&YO;6)R97,B"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y.0IM<V=I9"`B17AP;W)T(@IM
M<V=S='(@(D5X<&]R=&%R(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHX"FUS9VED(")%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`B17AP;W)T87(@
M86=E;F1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-CD*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)E<F\B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$S,PIM<V=I9"`B1FEN9"(*;7-G
M<W1R(")%;F-O;G1R87(B"@HC.B!Y96%R+G!H<#HX-"!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,3D*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(D9R(@IM<V=S
M='(@(E9I92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4X,0IM<V=I9"`B1G)E
M92(*;7-G<W1R("),:6)R92(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C4X"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B
M26YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4B"@HC.B!T96UP;&%T
M97,O;6]N=&@O:&5A9"YI;F,Z,C`@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3$Y"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED
M(")&<FED87DB"FUS9W-T<B`B5FEE<FYE<R(*"B,Z('1E;7!L871E<R]D96QE
M=&4O9&5L971E+FEN8SHS,PIM<V=I9"`B1G5T=7)E(@IM<V=S='(@(D9U='5R
M;R(*"B,Z(&-O;F9I9R\N8F%K+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")'86UE(@IM<V=S='(@(DIU96=O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C(S"FUS9VED(")'96YE<F%L(@IM<V=S='(@
M(D=E;F5R86PB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30P"B,L('!H
M<"UF;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`B27(@82`E<R(*"B,Z
M(&UO;G1H+G!H<#HQ,S,@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I
M9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N
M:6YC.C$P"FUS9VED(")(:61E(@IM<V=S='(@(D]C=6QT87(B"@HC.B!M;VYT
M:"YP:'`Z,3,S('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN
M8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHQ
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(:61E("5S(@IM<V=S='(@(D]C=6QT
M87(@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV-2!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHQ,S8*;7-G:60@(DAO=7(H<RDB"FUS9W-T<B`B
M2&]R82AS*2(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$S,PIM
M<V=I9"`B2&]W(&QO;F<@<VAO=6QD('1H92!T:6UE('-L;W1S(&]N('1H92!D
M87D@86YD('=E96L@=FEE=W,@8F4_(@IM<V=S='(@(K]486UA\6\@9&4@;&%S
M(&1I=FES:6]N97,@:&]R87)I87,@96X@;&%S('9I<W1A<R!D92!D[6$@>2!S
M96UA;F$_(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S`Q"FUS
M9VED(")(;W<@;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S
M:&]U;&0@=V4@9V5N97)A=&4_(@IM<V=S='(@(K]$92!C=6%N=&]S(&3M87,@
M<V4@9V5N97)A<N$@;&$@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB
M;&4_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`U,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B))9B!Y;W5R(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O
M<G0@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@;V8@=&AE("(*(F9O
M;&QO=VEN9R!L:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N
M7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB
M"B)4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*
M(EQN(@HB5&\@9&5C;&EN92!T:&4@979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B
M"B)3:2!S=2!C;&EE;G1E(&1E(&-O<G)E;R!N;R!S;W!O<G1A('!E=&EC:6]N
M97,@:51I<"P@<'5E9&4@=7-A<B!U;F\@9&4@;&]S("(*(G;M;F-U;&]S('-I
M9W5I96YT97,@<&%R82!A8V5P=&%R(&\@<F5C:&%Z87(@96P@86-O;G1E8VEM
M:65N=&\N7&XB"B)<;B(*(E!A<F$@86-E<'1A<FQO.EQN(@HB)7-<;B(*(EQN
M(@HB4&%R82!A8V5P=&%R;&\@8V]N9&EC:6]N86QM96YT93I<;B(*(B5S7&XB
M"B)<;B(*(E!A<F$@<F5C:&%Z87)L;SI<;B(*(B5S(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M="!#86QE;F1A<BP@4W1E<"`E9"(*;7-G<W1R("));7!O<G1A<B!A9V5N9&$N
M(%!A<V\@)60B"@HC.B!D871A+G!H<#HR.#@*;7-G:60@(DEM<&]R="]%>'!O
M<G0@0V%L96YD87(B"FUS9W-T<B`B26UP;W)T87(O17AP;W)T87(@86=E;F1A
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8X"FUS9VED
M(")*86YU87)Y(@IM<V=S='(@(D5N97)O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-S0*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L:6\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,PIM<V=I9"`B
M2G5N92(*;7-G<W1R(")*=6YI;R(*"B,Z(&1A=&$N<&AP.C8T('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$T,@IM<V=I9"`B2V5Y=V]R9',B"FUS9W-T<B`B
M4&%L86)R87,@8VQA=F4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z-34*;7-G:60@(DQA<W0@,C0@:&]U<G,B"FUS9W-T<B`BVFQT:6UA<R`R
M-"!H;W)A<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C@W"FUS9VED
M("),87-T($UO9&EF:65D(@IM<V=S='(@(MIL=&EM82!M;V1I9FEC86-I\VXB
M"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C0*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC
M.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$V('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHT"FUS9VED("),87-T($UO;G1H(@IM
M<V=S='(@(DUE<R!A;G1E<FEO<B(*"B,Z('1E;7!L871E<R]Y96%R+VAE860N
M:6YC.C0*;7-G:60@(DQA<W0@665A<B(*;7-G<W1R(")!\6\@86YT97)I;W(B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-30@=&5M<&QA=&5S
M+W=E96LO:&5A9"YI;F,Z,PIM<V=I9"`B3&%S="!W965K(@IM<V=S='(@(E-E
M;6%N82!A;G1E<FEO<B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,CD*;7-G:60@(DQI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.B(*;7-G
M<W1R("),:6UI=&%R(&EN=&5R=F%L;R!A(&5X<&]R=&%R.B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX-2!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHW-`IM<V=I9"`B3&]?8V%T:6]N(@IM<V=S='(@(E]5
M8FEC86-I\VXB"@HC.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V
M96YT7VAE861E<G,N:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C
M86Q?;6%N86=E;65N="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T
M95]C86Q?;6%N86=E;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,C$*(SH@;&EB+T1R:79E<BYP:'`Z,3@X-@IM<V=I9"`B3&]C871I;VXB
M"FUS9W-T<B`B56)I8V%C:?-N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z-#4*;7-G:60@(DUA;F%G92!R96UO=&4@8V%L96YD87)S+B(*;7-G
M<W1R(")'97-T:6]N92!L87,@86=E;F1A<R!R96UO=&%S+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<P"FUS9VED(")-87)C:"(*;7-G
M<W1R(")-87)Z;R(*"B,Z(&QI8B]A<&DN<&AP.C$P,`IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@179E;G1S(@IM<V=S='(@(D[Z;65R;R!MX7AI;6\@9&4@
M86-O;G1E8VEM:65N=&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R(")-87EO(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3@X,PIM<V=I9"`B364B"FUS9W-T<B`B66\B"@HC.B!C;VYF
M:6<O+F)A:R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B365E=&EN9R(*
M;7-G<W1R(")2975N:?-N(@H*(SH@;&EB+T)L;V-K+W1R965?86QA<FUS+G!H
M<#HS"FUS9VED(")-96YU($%L87)M<R(*;7-G<W1R(")!;&%R;6%S(@H*(SH@
M;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PIM<V=I9"`B365N=2!,:7-T(@IM
M<V=S='(@(DQI<W1A9&\@9&4@;65N^B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C8X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S-0IM<V=I9"`B
M36EN=71E*',I(@IM<V=S='(@(DUI;G5T;RAS*2(*"B,Z('EE87(N<&AP.C@P
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C4Y('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(Q-0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM
M<V=I9"`B36\B"FUS9W-T<B`B3'5N(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C$V('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-0HC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV."!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HQ,#8*;7-G:60@(DUO;F1A>2(*;7-G<W1R("),=6YE<R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,30@;&EB+T)L;V-K+W1R965?;65N
M=2YP:'`Z,C0*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#4*;7-G
M:60@(DUO;G1H(@IM<V=S='(@(DUE<R(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,PIM<V=I9"`B36]N=&@@5FEE=R(*;7-G<W1R(")6:7-T82!M96YS=6%L
M(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N
M=&AL:7-T+G!H<#HT,PIM<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G
M<W1R("),:7-T861O(&1E(&%C;VYT96-I;6EE;G1O<R!M96YS=6%L97,B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,S(*;7-G:60@(DUO;G1H;'DZ(%)E
M8W5R<R!E=F5R>2(*;7-G<W1R(")-96YS=6%L;65N=&4Z(%-E(')E<&ET92!C
M861A(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO
M;G1H<R!!:&5A9"(*;7-G<W1R(")0<O-X:6UO<R!M97-E<R(*"B,Z(&QI8B]"
M;&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS($)E9F]R
M92(*;7-G<W1R(")-:6YU=&]S(&%N=&5S(@H*(SH@;&EB+V%P:2YP:'`Z-C,T
M"FUS9VED(")-=6QT:7!L92!I0V%L96YD87(@8V]M<&]N96YT<R!F;W5N9#L@
M;VYL>2!O;F4@=D5V96YT(&ES('-U<'!O<G1E9"XB"FUS9W-T<B`B(@HB4V4@
M:&%N(&5N8V]N=')A9&\@=F%R:6]S(&-O;7!O;F5N=&5S(&E#86QE;F1A<CL@
M<_-L;R!S92!S;W!O<G1A('5N('9%=F5N="`B"B)C861A('9E>BXB"@HC.B!C
M86QE;F1A<G,N<&AP.C$R."!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z-S`*;7-G:60@(DUY($-A;&5N9&%R<R(*;7-G<W1R(")-:7,@86=E
M;F1A<R(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHS-"!T96UP;&%T97,O;65N
M=2YI;F,Z,S8*;7-G:60@(DUY($-A;&5N9&%R<SHB"FUS9W-T<B`B36ES(&%G
M96YD87,Z(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C(Q,PIM<V=I9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R(")-:2!54DP@
M9&4@=&EE;7!O(&1I<W!O;FEB;&4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z,3(P('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ-C(*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ-S8*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N
M="YI;F,Z,3<*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E
M;65N="YI;F,Z-#0*;7-G:60@(DYA;64B"FUS9W-T<B`B3F]M8G)E(@H*(SH@
M;&EB+T)L;V-K+VUO;G1H+G!H<#HT,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H
M<#HT-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*(SH@;&EB+T)L;V-K+W1R
M965?;65N=2YP:'`Z,C`*;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R(")!\6%D
M:7(B"@HC.B!L:6(O8F%S92YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(DYE=R!C86QE;F1A<B!C<F5A=&5D(&%N9"!A=71O;6%T:6-A;&QY('-H
M87)E9"!W:71H(&9O;&QO=VEN9R!G<F]U<"AS*3H@)7,N(@IM<V=S='(@(B(*
M(D%G96YD82!C<F5A9&$@>2!C;VUP87)T:61A(&1E(&9O<FUA(&%U=&]MX71I
M8V$@8V]N(&5L+VQO<R!S:6=U:65N=&4H<RD@9W)U<&\B"B(H<RDZ("5S+B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S,*;7-G:60@(DYE>'0B
M"FUS9W-T<B`B4VEG=6EE;G1E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(E!R\WAI
M;6%S(#(T(&AO<F%S(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(Y"FUS9VED
M(").97AT($1A>2(*;7-G<W1R(")0<O-X:6UO(&3M82(*"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-@HC.B!T96UP;&%T97,O
M;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3@@=&5M<&QA=&5S+VUO;G1H
M+VAE860N:6YC.C8*;7-G:60@(DYE>'0@36]N=&@B"FUS9W-T<B`B4'+S>&EM
M;R!M97,B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C,R"FUS9VED(").97AT
M(%=E96LB"FUS9W-T<B`B4'+S>&EM82!S96UA;F$B"@HC.B!T96UP;&%T97,O
M>65A<B]H96%D+FEN8SHV"FUS9VED(").97AT(%EE87(B"FUS9W-T<B`B4'+S
M>&EM;R!A\6\B"@HC.B!T96UP;&%T97,O9&%Y+VAE860N:6YC.C4*;7-G:60@
M(DYE>'0@9&%Y(@IM<V=S='(@(E!R\WAI;6\@9.UA(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C4X('1E;7!L871E<R]W965K+VAE860N:6YC
M.C4*;7-G:60@(DYE>'0@=V5E:R(*;7-G<W1R(")0<O-X:6UA('-E;6%N82(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(W-2!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HR.#@*;7-G:60@(DYO(@IM<V=S='(@(DYO(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,3(T"FUS9VED(").;R!A;&%R;2(*;7-G<W1R(")3:6X@86QA
M<FUA(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0X
M"FUS9VED(").;R!A='1E;F1E97,B"FUS9W-T<B`B4VEN(&%S:7-T96YT97,B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,P"FUS9VED(").;R!C86QE;F1A
M<G,@87)E(&%V86EL86)L92!T;R!G=65S=',N(@IM<V=S='(@(DYO('-E(&1I
M<W!O;F4@9&4@86=E;F1A<R!P87)A(&QO<R!I;G9I=&%D;W,N(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,V('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(U,@IM<V=I9"`B3F\@96YD(&1A=&4B"FUS9W-T<B`B4VEN(&9E8VAA
M(&9I;F%L(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$V-"!L
M:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ-C,*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$Y-`IM<V=I9"`B3F\@979E;G1S('1O(&1I<W!L87DB"FUS9W-T
M<B`B4VEN(&%C;VYT96-I;6EE;G1O<R!V:7-I8FQE<R(*"B,Z(&QI8B]3=&]R
M86=E+VMO;&%B+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!F<F5E
M+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE(&9O<B`E<R(*;7-G<W1R
M(").;R!S92!D:7-P;VYE(&1E(&EN9F]R;6%C:?-N(&1E('1I96UP;R!D:7-P
M;VYI8FQE(&1E("5S(@H*(SH@;&EB+V%P:2YP:'`Z,S0U(&QI8B]A<&DN<&AP
M.C8R-`IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G
M<W1R(").;R!S92!E;F-O;G1R87)O;B!D871O<R!I0V%L96YD87(N(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`Q"FUS9VED(").;R!R96-U<G)E
M;F-E(@IM<V=S='(@(E-I;B!R97!E=&EC:?-N(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z.3`R"FUS9VED(").;R!V86QI9"!E;6%I;"!A9&1R97-S(&9O=6YD
M(@IM<V=S='(@(DYO('-E(&5N8V]N=')A<F]N(&1I<F5C8VEO;F5S(&1E(&-O
M<G)E;R!VX6QI9&%S(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C$R(&QI8B]+
M<F]N;VQI=&@N<&AP.C8S,PIM<V=I9"`B3F]N92(*;7-G<W1R(").:6YG=6YA
M(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ-#4*;7-G:60@(DYO="!F;W5N
M9"(*;7-G<W1R(").;R!S92!H82!E;F-O;G1R861O(@H*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS
M9W-T<B`B079I<V]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-S@*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=FEE;6)R92(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-@IM<V=I9"`B3F]W(@IM
M<V=S='(@(D%H;W)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-S<*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3V-T=6)R92(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$S('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C8U"FUS9VED(")/;B(*;7-G<W1R(")%
M;"(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(W."!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HR.3$*;7-G:60@(D]N(&%L;"!C86QE;F1A
M<G,@22!H879E(')E860@86-C97-S('1O(@IM<V=S='(@(D1E('1O9&]S(&QO
M<R!C86QE;F1A<FEO<R!A(&QO<R!Q=64@=&5N9V\@86-C97-O(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C<W(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C(Y,`IM<V=I9"`B3VX@86QL('-H;W=N(&-A;&5N9&%R<R(*
M;7-G<W1R(")$92!T;V1A<R!L87,@86=E;F1A<R!V:7-I8FQE<R(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(W-B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HR.#D*;7-G:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY(@IM
M<V=S='(@(E/S;&\@9&4@;6ES(&%G96YD87,B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HV,S`*;7-G:60@(D]P=&EO;F%L(@IM<V=S='(@(D]P8VEO;F%L(@H*
M(SH@;&EB+T9"5FEE=RYP:'`Z,3$Y"FUS9VED(")/<'1I;VYA;"!!='1E;F1E
M97,B"FUS9W-T<B`B07-I<W1E;G1E<R!S:6X@8V]N9FER;6%R(@H*(SH@;&EB
M+T9"5FEE=RYP:'`Z,34T"FUS9VED(")/=F5R=FEE=R(*;7-G<W1R("));G1R
M;V1U8V-I\VXB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHS-`IM<V=I
M9"`B3W=N97(B"FUS9W-T<B`B4')O<&EE=&%R:6\B"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ.#@R"B,L('!H<"UF;W)M870*;7-G:60@(D]W;F5R.B`E<R(*;7-G
M<W1R(")0<F]P:65T87)I;SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$Q-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y-`IM<V=I
M9"`B4$TB"FUS9W-T<B`B4$TB"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES
M="YP:'`Z,R!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z-#(*;7-G:60@
M(E!A<W0@179E;G1S($QI<W0B"FUS9W-T<B`B3&ES=&%D;R!D92!A8V]N=&5C
M:6UI96YT;W,@<&%S861O<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$P.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.38*;7-G:60@(E!A='1E
M<FXB"FUS9W-T<B`B4&%T<O-N(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N
M:6YC.C,P"FUS9VED(")097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\B
M"FUS9W-T<B`BOT5L:6UI;F%R('!E<FUA;F5N=&5M96YT92!E<W1E(&%C;VYT
M96-I;6EE;G1O/R(*"B,Z(&QI8B]A<&DN<&AP.C,R-B!L:6(O87!I+G!H<#HT
M,C(@;&EB+V%P:2YP:'`Z-#DT(&QI8B]A<&DN<&AP.C4W-`HC.B!L:6(O87!I
M+G!H<#HV,#8@;&EB+V%P:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.C<R.`IM<V=I
M9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B4&5R;6ES;R!D96YE9V%D
M;R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S`*
M;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!R:79I;&5G:6]S(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C$*;7-G:60@(E!O<G1A;"!/
M<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S(&1E('!O<G1A;"(*"B,Z(&QI8B]&
M0E9I97<O9&%Y+G!H<#HR-0IM<V=I9"`B4')E=FEO=7,@1&%Y(@IM<V=S='(@
M(D3M82!A;G1E<FEO<B(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*;7-G
M:60@(E!R979I;W5S(%=E96LB"FUS9W-T<B`B4V5M86YA(&%N=&5R:6]R(@H*
M(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D
M87DB"FUS9W-T<B`B1.UA(&%N=&5R:6]R(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3,U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T.0IM<V=I
M9"`B4F5C=7(@56YT:6PB"FUS9W-T<B`B4F5P971I<B!H87-T82(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$P-@IM<V=I9"`B4F5C=7)R96YC92(*
M;7-G<W1R(")297!E=&EC:?-N(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@(E)E
M8W5R<F5N8V4@1&%T82(*;7-G<W1R(")$871O<R!A(')E<&5T:7(B"@HC.B!D
M871A+G!H<#HV-@IM<V=I9"`B4F5C=7)R96YC92!%;F0@1&%T92(*;7-G<W1R
M(")&96-H82!D92!F:6X@9&4@<F5P971I8VGS;B(*"B,Z(&1A=&$N<&AP.C8W
M"FUS9VED(")296-U<G)E;F-E($EN=&5R=F%L(@IM<V=S='(@(DEN=&5R=F%L
M;R!D92!R97!E=&EC:?-N(@H*(SH@9&%T82YP:'`Z-C4*;7-G:60@(E)E8W5R
M<F5N8V4@5'EP92(*;7-G<W1R(")4:7!O(&1E(')E<&5T:6-I\VXB"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HU-#@*;7-G:60@(E)E8W5R<R!D86EL>2(*;7-G
M<W1R(")297!E=&ER(&1I87)I86UE;G1E(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-34U"FUS9VED(")296-U<G,@;6]N=&AL>2(*;7-G<W1R(")297!E=&ER
M(&UE;G-U86QM96YT92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4U,0IM<V=I
M9"`B4F5C=7)S('=E96ML>2(*;7-G<W1R(")297!E=&ER('-E;6%N86QM96YT
M92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4U.`IM<V=I9"`B4F5C=7)S('EE
M87)L>2(*;7-G<W1R(")297!E=&ER(&%N=6%L;65N=&4B"@HC.B!L:6(O4V-H
M961U;&5R+VMR;VYO;&ET:"YP:'`Z,C`U"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E;6EN9&5R.B`E<R(*;7-G<W1R(")296-O<F1A=&]R:6\Z("5S(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.CDT(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.C0T"FUS9VED(")296UO=&4@0V%L96YD87)S
M(@IM<V=S='(@(D%G96YD87,@<F5M;W1A<R(*"B,Z('1E;7!L871E<R]M96YU
M+FEN8SHV,"!T96UP;&%T97,O;65N=2YI;F,Z-C(*;7-G:60@(E)E;6]T92!#
M86QE;F1A<G,Z(@IM<V=S='(@(D%G96YD87,@<F5M;W1A<SHB"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DT"FUS9VED(")296UO
M=&4@4W5B<V-R:7!T:6]N(%523"(*;7-G<W1R(")54DP@9&4@<W5S8W)I<&-I
M\VX@<F5M;W1A(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ-C$*;7-G:60@(E)E;6]V92(*;7-G<W1R(")1=6ET87(B"@HC.B!T96UP
M;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(E%U:71A<B`E<R(*"B,Z(&%T
M=&5N9&5E<RYP:'`Z,3`P"FUS9VED(")296UO=F4@071T96YD964B"FUS9W-T
M<B`B475I=&%R(&%S:7-T96YT92(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,S$*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@8V%L96YD87(@
M=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@
M(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@8V%L96YD
M87(N/"]S=')O;F<^(@IM<V=S='(@(B(*(K]3=7-T:71U:7(@;&$@86=E;F1A
M(&5X:7-T96YT92!C;VX@;&$@:6UP;W)T861A/R`\<W1R;VYG/D%V:7-O.B#)
M<W1O("(*(F5L:6UI;F%RX2!T;V1A<R!L87,@96YT<F%D87,@9&4@;&$@86=E
M;F1A(&%C='5A;"X\+W-T<F]N9SXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV
M,S<*;7-G:60@(E)E<75I<F5D(@IM<V=S='(@(E)E<75E<FED;R(*"B,Z(&QI
M8B]&0E9I97<N<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S.2!L:6(O1D)6:65W
M+G!H<#HQ-#(@;&EB+T9"5FEE=RYP:'`Z,30U"FUS9VED(")297%U:7)E9"!!
M='1E;F1E97,B"FUS9W-T<B`B07-I<W1E;G1E<R!R97%U97)I9&]S(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S(@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,S`X"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R(")2
M97-T875R87(@=F%L;W)E<R!P;W(@;VUI<VGS;B(*"B,Z('1E;7!L871E<R]A
M='1E;F1E97,O871T96YD965S+FEN8SHT,R!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ-C8*;7-G:60@(E)E<W!O;G-E(@IM<V=S='(@(E)E<W!U97-T82(*
M"B,Z('EE87(N<&AP.C@U('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,`HC.B!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$P-0IM<V=I9"`B4V$B"FUS9W-T<B`B4V%B(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(Q('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R,`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,PIM
M<V=I9"`B4V%T=7)D87DB"FUS9W-T<B`B4^%B861O(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(P,PIM<V=I9"`B4V%V92(*;7-G
M<W1R(")'=6%R9&%R(@H*(SH@=FEE=V5V96YT+G!H<#HQ,S,@961I=&5V96YT
M+G!H<#HT.2!E9&ET979E;G0N<&AP.C4W"FUS9VED(")3879E($%S($YE=R(*
M;7-G<W1R(")'=6%R9&%R(&-O;6\@;G5E=F\B"@HC.B!T96UP;&%T97,O871T
M96YD965S+V%T=&5N9&5E<RYI;F,Z.#,*;7-G:60@(E-A=F4@071T96YD965S
M(@IM<V=S='(@(D=U87)D87(@87-I<W1E;G1E<R(*"B,Z(&%D9&5V96YT+G!H
M<#HU-2!E9&ET979E;G0N<&AP.C4R"FUS9VED(")3879E($5V96YT(@IM<V=S
M='(@(D=U87)D87(B"@HC.B!S96%R8V@N<&AP.CDQ('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,30*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C8W('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN
M8SHX"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,30U(&QI
M8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(V"FUS9VED(")396%R8V@B"FUS9W-T
M<B`B0G5S8V%R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC
M.C$*;7-G:60@(E-E87)C:"!#86QE;F1A<G,B"FUS9W-T<B`B0G5S8V%R(&5N
M(&%G96YD87,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-@IM
M<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B4F5S=6QT861O<R!D92!L
M82!B^G-Q=65D82(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN
M8SHV"FUS9VED(")396%R8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN:6YG.B(*
M;7-G<W1R(")"=7-C87(@96X@86=E;F1A<R!Q=64@8V]N=&5N9V%N.B(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3,*;7-G:60@
M(E-E;&5C="!A(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`B4V5L96-C:6]N
M92!U;F$@86=E;F1A(&$@;6]D:69I8V%R(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C8U('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC
M.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"FUS
M9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C8VEO;F4@=6YA(&9E
M8VAA(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"FUS9VED(")396QE8W0@
M8V%L96YD87)S('1O(&1I<W!L87DZ(@IM<V=S='(@(E-E;&5C8VEO;F4@;&%S
M(&%G96YD87,@;6]S=')A9&%S.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C$Q"FUS9VED("(B"B)396QE8W0@8V]N9FER;6%T:6]N(&]P=&EO
M;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE=W,@86YD(&-H
M;V]S92`B"B)D969A=6QT('9I97<N(@IM<V=S='(@(B(*(E-E;&5C8VEO;F4@
M;W!C:6]N97,@9&4@8V]N9FER;6%C:?-N+"!C\VUO(&UO<W1R87(@;&%S(&1I
M9F5R96YT97,@=FES=&%S('D@(@HB97-C;VIE<B!L82!V:7-T82!P;W(@;VUI
M<VGS;BXB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$X"FUS9VED
M(")396QE8W0@=&AE(&-A;&5N9&%R('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B
M4V5L96-C:6]N92!L82!A9V5N9&$@82!L82!Q=64@:6UP;W)T87(Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.0IM<V=I9"`B4V5L96-T('1H
M92!C86QE;F1A<BAS*2!T;R!E>'!O<G0@9G)O;2(*;7-G<W1R(")396QE8V-I
M;VYE(&QA*',I(&%G96YD82AS*2!D97-D92!L82AS*2!Q=64@97AP;W)T87(B
M"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")396QE
M8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F4@96P@
M9F]R;6%T;R!D92!E>'!O<G1A8VGS;CHB"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C(W"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T
M.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&%R8VAI=F\@82!I;7!O<G1A<CHB
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@(E-E
M;&5C="!T:&4@9FER<W0@=V5E:V1A>3HB"FUS9W-T<B`B4V5L96-C:6]N92!E
M;"!P<FEM97(@9.UA(&QA8F]R86)L93HB"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@
M<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E-E;&5C8VEO;F4@96P@9F]R;6%T;R!D
M96P@87)C:&EV;R!O<FEG96XZ(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,3@T"FUS9VED(")396QE8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W
M.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&EN=&5R=F%L;R!M;W-T<F%D;SHB
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B4V5L
M96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A<G1U<#HB"FUS9W-T<B`B
M4V5L96-C:6]N92!L82!V:7-T82!M;W-T<F%D82!A;"!I;FEC:6\Z(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C(*;7-G:60@(E-E;&5C="!W
M:&EC:"!E=F5N=',@=&\@<VAO=R!I;B!T:&4@<&]R=&%L+B(*;7-G<W1R(")3
M96QE8V-I;VYE(&QO<R!A8V]N=&5C:6UI96YT;W,@;6]S=')A9&]S(&5N(&5L
M('!O<G1A;"XB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C<@=&5M
M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED(")396YD(&$@8V%N
M8V5L(&YO=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L971I
M;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"B)!;"!B;W)R87(@97-T92!A8V]N
M=&5C:6UI96YT;RP@96YV:6%R('5N(&%V:7-O(&1E(&%N=6QA8VGS;B!A('1O
M9&]S(&QO<R`B"B)A<VES=&5N=&5S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E-E;F0@86X@96UA:6P@
M=&\@)7,B"FUS9W-T<B`B16YV:6%R('5N(&-O<G)E;R!A("5S(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3<Y"FUS9VED(")396YD('5P9&%T97,O
M:6YV:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES
M(&5V96YT(@IM<V=S='(@(B(*(D%L(&=U87)D87(@97-T92!A8V]N=&5C:6UI
M96YT;RP@96YV:6%R(&%C='5A;&EZ86-I;VYE<R]I;G9I=&%C:6]N97,@82!T
M;V1O<R`B"B)L;W,@87-I<W1E;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<V"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P
M=&EE;6)R92(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC
M.C@S"FUS9VED(")3970@96YD(&1A=&4B"FUS9W-T<B`B17-T86)L96-E<B!F
M96-H82!F:6YA;"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V-0IM
M<V=I9"`B4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`B17-T86)L
M96-E<B!F96-H82!D92!F:6X@9&4@<F5P971I8VGS;B(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"FUS9VED(")3970@<W1A<G0@
M9&%T92(*;7-G<W1R(")%<W1A8FQE8V5R(&9E8VAA(&1E(&EN:6-I;R(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C4Y"FUS9VED("(B"B)3970@
M>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H
M97(@=7-E<G,G(&9R964O8G5S>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)$969I
M;F$@<W5S(&%G96YD87,@9&4@=&EE;7!O(&1I<W!O;FEB;&4@>2!S=2!P<F]P
M:65D860@>2!L87,@;W!C:6]N97,@9&4@(@HB=&EE;7!O(&1I<W!O;FEB;&4@
M<&%R82!O=')O<R!U<W5A<FEO<RXB"@HC.B!C86QE;F1A<G,N<&AP.C<W"B,L
M('!H<"UF;W)M870*;7-G:60@(E-H87)E(&YO="!F;W5N9#H@)7,B"FUS9W-T
M<B`B3F\@<V4@96YC;VYT<O,@96P@<F5C=7)S;R!C;VUP87)T:61O.B`E<RXB
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.#(*;7-G
M:60@(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T<B`B06=E;F1A<R!C;VUP87)T
M:61A<R(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHT-R!T96UP;&%T97,O;65N
M=2YI;F,Z-#D*;7-G:60@(E-H87)E9"!#86QE;F1A<G,Z(@IM<V=S='(@(D%G
M96YD87,@8V]M<&%R=&ED87,Z(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H<#HR
M-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC.B!T
M96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHS"FUS9VED(")3
M:&]W($-A;&5N9&%R(@IM<V=S='(@(DUO<W1R87(@86=E;F1A(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,34V"FUS9VED(")3:&]W(&-A=&5G
M;W)Y(&QE9V5N9#\B"FUS9W-T<B`BOTUO<W1R87(@8V]M96YT87)I;W,@9&4@
M;&%S(&-A=&5G;W+M87,_(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z,30V"FUS9VED(")3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E
M;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R("(B"B)%;B!L
M87,@=FES=&%S(&1E(&%G96YD82"_;6]S=')A<B!L;W,@:6-O;F]S(&5L:6UI
M;F%R+"!A;&%R;6$@>2!R97!E=&EC:?-N/R(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S:W,@:6X@=&AE
M(&-A;&5N9&%R/R(*;7-G<W1R("*_36]S=')A<B!L87,@=&%R96%S('9E;F-I
M9&%S(&5N(&QA(&%G96YD83\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HQ-C8*;7-G:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N9#\B"FUS9W-T
M<B`BOTUO<W1R87(@8V]M96YT87)I;W,@9&4@=&EE;7!O(&1I<W!O;FEB;&4_
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C`S"FUS9VED(")3
M:&]W(&]N;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S970_(@IM<V=S
M='(@(K]-;W-T<F%R('/S;&\@;&]S(&%C;VYT96-I;6EE;G1O<R!C;VX@86QA
M<FUA/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$W-0IM<V=I
M9"`B4VAO=R!S:&%R960@8V%L96YD87)S('-I9&4M8GDM<VED93\B"FUS9W-T
M<B`BOTUO<W1R87(@86=E;F1A<R!C;VUP87)T:61A<R!A;"!L861O/R(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B4VAO=R!T
M87-K<R!U<VEN9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(K]-;W-T<F%R
M(&QA<R!T87)E87,@8V]N(&QO<R!C;VQO<F5S(&1E(&QA<R!C871E9V]R[6%S
M/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDU"FUS9VED(")3
M:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C:"!D87D@:6X@=V5E:R!V:65W
M<S\B"FUS9W-T<B`BOTUO<W1R87(@;&%S(&AO<F%S(&5N=')E(&-A9&$@9.UA
M(&5N(&QA<R!V:7-T87,@<V5M86YA;&5S/R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C$Q"FUS9VED(")3=&%?<G0B"FUS9W-T<B`B
M16U?<&EE>F$@96PB"@HC.B!D871A+G!H<#HU-`IM<V=I9"`B4W1A<G0@1&%T
M92(*;7-G<W1R(")&96-H82!D92!I;FEC:6\B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+V5V96YT7VAE861E<G,N:6YC.C<@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS-PIM<V=I9"`B
M4W1A<G0@3VXB"FUS9W-T<B`B16UP:65Z82!E;"(*"B,Z(&1A=&$N<&AP.C4U
M"FUS9VED(")3=&%R="!4:6UE(@IM<V=S='(@(DAO<F$@9&4@:6YI8VEO(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.CDT('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C@S"FUS9VED(")3=&%T7W5S(@IM<V=S
M='(@(E]%<W1A9&\B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E
M<G,N:6YC.C8@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T
M871U<R(*;7-G<W1R(")%<W1A9&\B"@HC.B!Y96%R+G!H<#HW."!Y96%R+G!H
M<#HX-R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-0HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,C$@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ
M,#<@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#D*;7-G:60@(E-U(@IM<V=S='(@
M(D1O;2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-"!T96UP;&%T
M97,O;6]N=&@O:&5A9"YI;F,Z,C,*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(Q('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8W"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM
M<V=S='(@(D1O;6EN9V\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HR.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5&%R96%S(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z-3@U(&QI8B]+<F]N;VQI=&@N<&AP.C8P.`IM<V=I9"`B
M5&5N=&%T:79E(@IM<V=S='(@(E!R;W9I<VEO;F%L(@H*(SH@>65A<BYP:'`Z
M.#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C(@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C$X"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U
M"FUS9VED(")4:"(*;7-G<W1R(")*=64B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C<P"FUS9VED(")4:&4@161I="!!='1E;F1E97,@
M<V-R965N(&ES(&YO(&QO;F=E<B!P<F5S96YT+B!%>&ET:6YG+B(*;7-G<W1R
M("(B"B)982!N;R!E<W3A(&1I<W!O;FEB;&4@;&$@<&%N=&%L;&$@9&4@;6]D
M:69I8V%C:?-N(&1E(&%S:7-T96YT97,N(%-A;&EE;F1O+B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!C86YN;W0@8F4@9&5L971E9"XB"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@96QI;6EN87(@;&$@86=E;F1A(%PB)7-<(BXB"@HC.B!C86QE;F1A<G,N
M<&AP.C0P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S
M7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B4V4@:&$@8W)E861O(&QA
M(&%G96YD82!<(B5S7"(N(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!L82!A9V5N9&$@7"(E
M<UPB+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R96YA;65D('1O(%PB
M)7-<(BXB"FUS9W-T<B`B4V4@:&$@<F5N;VUB<F%D;R!L82!A9V5N9&$@7"(E
M<UPB(&-O;6\@7"(E<UPB+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!S
M879E9"XB"FUS9W-T<B`B4V4@:&$@9W5A<F1A9&\@;&$@86=E;F1A(%PB)7-<
M(BXB"@HC.B!D871A+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(DYO
M('-E('!U961E(&5L:6UI;F%R(&QA(&%G96YD83H@)7,B"@HC.B!T96UP;&%T
M97,O961I="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@(E1H92!E;F0@9&%T
M92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N(@IM<V=S='(@
M(DQA(&9E8VAA(&9I;F%L(&1E8F4@<V5R('!O<W1E<FEO<B!A(&QA(&9E8VAA
M(&EN:6-I86PN(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&%D
M9&5D('1O(%PB)7-<(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N
M(@IM<V=S='(@(B(*(E-E(&AA(&'Q861I9&\@96P@86-O;G1E8VEM:65N=&\@
M7"(E<UPB(&$@;&$@86=E;F1A(%PB)7-<(BP@96P@)7,@82!L87,@)7,N(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960@9G)O;2!<
M(B5S7"(@8V%L96YD87(L('=H:6-H('=A<R!O;B`E<R!A="`E(@HB<RXB"FUS
M9W-T<B`B(@HB4V4@:&$@96QI;6EN861O(&5L(&%C;VYT96-I;6EE;G1O(%PB
M)7-<(B!D92!L82!A9V5N9&$@7"(E<UPB+"!D96P@)7,@82!L87,@)2(*(G,N
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"!O;B!<
M(B5S7"(@8V%L96YD87(L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R
M("(B"B)392!H82!M;V1I9FEC861O(&5L(&%C;VYT96-I;6EE;G1O(%PB)7-<
M(B!D92!L82!A9V5N9&$@7"(E<UPB+"!E;"`E<R!A(&QA<R`E(@HB<RXB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#@W"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL
M>2!S96YT+B(*;7-G<W1R(")392!H82!E;G9I861O(&-O<G)E8W1A;65N=&4@
M82`E<R!E;"!A=FES;R!D96P@86-O;G1E8VEM:65N=&\N(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`T-`IM<V=I9"`B5&AE(&9O;&QO=VEN9R!I<R!A(&UO
M<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V96YT.B(*;7-G<W1R
M("),;R!Q=64@<VEG=64@97,@=6YA(&1E<V-R:7!C:?-N(&WA<R!D971A;&QA
M9&$@9&5L(&%C;VYT96-I;6EE;G1O.B(*"B,Z(&%T=&5N9"YP:'`Z-#$*;7-G
M:60@(B(*(E1H92!R97%U97-T('=A<R!I;F-O;7!L971E+B!3;VUE('!A<F%M
M971E<G,@=&AA="!A<F4@;F5C97-S87)Y('1O(&%C8V5P="!O<B`B"B)D96-L
M:6YE(&%N(&5V96YT(&%R92!M:7-S:6YG+B(*;7-G<W1R("(B"B),82!P971I
M8VGS;B!E<W1A8F$@:6YC;VUP;&5T82X@0V%R96-E(&1E('9A<FEO<R!D92!L
M;W,@<&%RX6UE=')O<R!N96-E<V%R:6]S("(*(G!A<F$@86-E<'1A<B!O(')E
M8VAA>F%R('5N(&%C;VYT96-I;6EE;G1O+B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O96UP='DN:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!E=F5N=',@;6%T
M8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(DYO(&AA>2!A
M8V]N=&5C:6UI96YT;W,@8V]I;F-I9&5N=&5S(&-O;B!L;W,@8W)I=&5R:6]S
M(&%C='5A;&5S+B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HQ."!E9&ET979E
M;G1A8W1I;VXN<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<R(*;7-G<W1R
M(")392!P<F]D=6IO('5N(&5R<F]R(&%L(&%C8V5D97(@82!L82!A9V5N9&$Z
M("5S(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C,T"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E
M<R(*;7-G<W1R(")392!P<F]D=6IO('5N(&5R<F]R(&%L(&'Q861I<B!E;"!A
M8V]N=&5C:6UI96YT;SH@)7,B"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!E9&ET
M:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O
M<B!A;"!M;V1I9FEC87(@96P@86-O;G1E8VEM:65N=&\Z("5S(@H*(SH@;&EB
M+V%P:2YP:'`Z,S,Y(&QI8B]A<&DN<&AP.C8Q.`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S
M='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S
M(&E#86QE;F1A<BXB"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C8S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@=&AE
M(&5V96YT.B`E<R(*;7-G<W1R(")392!P<F]D=6IO('5N(&5R<F]R(&%L('1R
M87-L861A<B!E;"!A8V]N=&5C:6UI96YT;SH@)7,B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#DR"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<SH@
M)7,B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!E;G9I87(@=6X@
M879I<V\@9&4@86-O;G1E8VEM:65N=&\@82`E<SH@)7,B"@HC.B!D871A+G!H
M<#HQ,#@*;7-G:60@(E1H97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R="XB
M"FUS9W-T<B`B3F\@:'5B;R!A8V]N=&5C:6UI96YT;W,@82!E>'!O<G1A<BXB
M"@HC.B!D871A+G!H<#HQ.#<*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B17-T92!F;W)M871O(&1E(&%R8VAI
M=F\@;F\@97-TX2!S;W!O<G1A9&\N(@H*(SH@9&%T82YP:'`Z,C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("5S(@IM<V=S='(@(LES=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(Z
M("5S(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$Q.`HC.B!T96UP;&%T97,O961I="]J879A<V-R
M:7!T+FEN8SHW,0IM<V=I9"`B5&AU<G-D87DB"FUS9W-T<B`B2G5E=F5S(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,W"FUS9VED(")4:6UE
M(%-P7V%N(@IM<V=S='(@(DEN=&5?<G9A;&\B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHT"FUS9VED(")4:6UE('-P86XB"FUS9W-T
M<B`B26YT97)V86QO(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C,T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,X"FUS9VED
M(")4:71?;&4B"FUS9W-T<B`B7U3M='5L;R(*"B,Z(&1A=&$N<&AP.C4S('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A
M<F-H+V5V96YT7VAE861E<G,N:6YC.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(E3M='5L;R(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C(@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ,C<*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DAO>2(*"B,Z(&QI
M8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C0@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z,3(S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,CD*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(DUA\6%N82(*"B,Z('EE87(N<&AP.C@Q
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8P('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(Q-@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM
M<V=I9"`B5'4B"FUS9W-T<B`B36%R(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C$W('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-@HC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV.0IM<V=I9"`B5'5E<V1A>2(*
M;7-G<W1R(")-87)T97,B"@HC.B!C;VYF:6<O+F)A:R]K97EW;W)D<RYP:'`N
M9&ES=#HQ-PIM<V=I9"`B5'EP92(*;7-G<W1R(")4:7!O(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$X-@IM<V=I9"`B55),(@IM
M<V=S='(@(E523"(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DEN
M8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!344PN(@H*(SH@8V%L
M96YD87)S+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B26YC87!A>B!D92!E;&EM:6YA
M<B!<(B5S7"(Z("5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R("));F-A<&%Z(&1E(&-A<F=A<B!L82!D969I;FEC:?-N
M(&1E("5S+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!<(B5S7"(Z("5S(@IM<V=S='(@(DEN
M8V%P87H@9&4@<F5N;VUB<F%R(%PB)7-<(CH@)7,B"@HC.B!L:6(O4W1O<F%G
M92]K;VQA8BYP:'`Z,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E=')I979E(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,B"FUS9W-T
M<B`B26YC87!A>B!D92!R96-U<&5R87(@;&$@:6YF;W)M86-I\VX@9&4@=&EE
M;7!O(&1I<W!O;FEB;&4@9&4@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ-0HC.B!S8W)I<'1S+W5P9W)A9&5S+S(P,#0M,#4M,3E?8V]N=F5R
M=%]C871E9V]R:65S7W1O7W-T<FEN9W,N<&AP.C4S"FUS9VED(")5;F9I;&5D
M(@IM<V=S='(@(E-I;B!C871E9V]R[6$B"@HC.B!L:6(O87!I+G!H<#HS-S<@
M;&EB+V%P:2YP:'`Z-#8Q(&QI8B]A<&DN<&AP.C4S-R!L:6(O87!I+G!H<#HV
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4
M>7!E.B`E<R(*;7-G<W1R(")4:7!O(&1E(&-O;G1E;FED;R!N;R!S;W!O<G1A
M9&\Z("5S(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`S-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<&1A=&5D.B`E<RXB"FUS9W-T<B`B06-T=6%L:7IA9&\Z
M("5S+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P"FUS9VED
M(")5<V5R($EN=&5R9F%C92(*;7-G<W1R("));G1E<F9A>B!D92!U<W5A<FEO
M(@H*(SH@>65A<BYP:'`Z,38P('EE87(N<&AP.C$V-B!L:6(O0FQO8VLO;6]N
M=&@N<&AP.C$U.2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$V,@IM<V=I9"`B5FEE
M=R!$87DB"FUS9W-T<B`B5F5R(&3M82(*"B,Z('EE87(N<&AP.C@R('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(Q-PHC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B
M5V4B"FUS9W-T<B`B36EE(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC
M.C$X('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-PHC.B!T96UP;&%T97,O
M961I="]J879A<V-R:7!T+FEN8SHW,`IM<V=I9"`B5V5D;F5S9&%Y(@IM<V=S
M='(@(DUIZ7)C;VQE<R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`X(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S,3,@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C,*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(E=E96LB"FUS
M9W-T<B`B4V5M86YA(@H*(SH@;6]N=&@N<&AP.C$W-R!W;W)K=V5E:RYP:'`Z
M,S`@=V5E:RYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5E:R`E9"(*
M;7-G<W1R(")396UA;F$@)60B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHU.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S@*;7-G:60@(E=E96LH
M<RDB"FUS9W-T<B`B4V5M86YA*',I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q,@IM<V=I9"`B
M5V5E:VQY.B!296-U<G,@979E<GDB"FUS9W-T<B`B4V5M86YA;&UE;G1E.B!3
M92!R97!I=&4@8V%D82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$R-`IM<V=I9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@
M=FEE=W,@96YD+"!W:&5N('1H97)E(&%R92!N;R!L871E<B!E=F5N=',_(@IM
M<V=S='(@(B(*(K]%;B!Q=>D@:&]R82!T97)M:6YA<N%N(&QA<R!V:7-T87,@
M9&4@9.UA('D@<V5M86YA+"!S:2!N;R!H87D@(@HB86-O;G1E8VEM:65N=&]S
M('!O<W1E<FEO<F5S/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$Q-0IM<V=I9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@
M=FEE=W,@<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S
M/R(*;7-G<W1R("(B"B*_16X@<77I(&AO<F$@96UP97IA<N%N(&QA<R!V:7-T
M87,@9&4@9.UA('D@<V5M86YA+"!S:2!N;R!H87D@86-O;G1E8VEM:65N=&]S
M("(*(F%N=&5R:6]R97,_(@H*(SH@871T96YD965S+G!H<#HQ,#<@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,Q,B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,@HC
M.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B5V]R:R!7
M965K(@IM<V=S='(@(E,N(&QA8F]R86PB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,S$U(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(U"FUS9VED(")996%R
M(@IM<V=S='(@(D'Q;R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R
M."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S@*;7-G:60@(EEE87)L>3H@
M4F5C=7)S(&5V97)Y(@IM<V=S='(@(D%N=6%L;65N=&4Z(%-E(')E<&ET92!C
M861A(@H*(SH@9&%T82YP:'`Z,SD@9&%T82YP:'`Z,C,Y(&5D:71E=F5N=&%C
M=&EO;BYP:'`Z-#8@861D979E;G0N<&AP.C$W"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!E=F5N=',N(@IM<V=S='(@(DYO(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@
M<&%R82!C<F5A<B!MX7,@9&4@)60@86-O;G1E8VEM:65N=&]S+B(*"B,Z(&%T
M=&5N9"YP:'`Z-#D*;7-G:60@(EEO=2!A<F4@;F]T(&%N(&%T=&5N9&5E(&]F
M('1H92!S<&5C:69I960@979E;G0N(@IM<V=S='(@(DYO(&5S('5N(&%S:7-T
M96YT92!D96P@86-O;G1E8VEM:65N=&\@:6YD:6-A9&\N(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW-@IM<V=I9"`B66]U(&-A;B!O
M;FQY('5S92!T:&ES(&9O<FT@9G)O;2!T:&4@161I="!!='1E;F1E97,@<V-R
M965N+B(*;7-G<W1R("(B"B)%<W1E(&9O<FUU;&%R:6\@<_-L;R!P=65D92!U
M<V%R;&\@9&5S9&4@;&$@<&%N=&%L;&$@9&4@;6]D:69I8V%C:?-N(&1E("(*
M(F%S:7-T96YT97,N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3@X"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A
M9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO
M;B`B"B)/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S:&5R925S(&)E9F]R
M92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B
M"B).;R!H82!C;VYF:6=U<F%D;R!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;R!E
M;B!L87,@<')E9F5R96YC:6%S(&1E('-U("(*(FED96YT:61A9"X@5&EE;F4@
M<75E(&EN9&EC87(@=6YA("5S87%U[25S('!A<F$@<&]D97(@96YV:6%R(&%V
M:7-O<R!D92`B"B)A8V]N=&5C:6UI96YT;W,N(@H*(SH@861D979E;G1A8W1I
M;VXN<&AP.C(P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S='(@(DYO
M(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!A\6%D:7(@86-O;G1E8VEM
M:65N=&]S(&$@)7,N(@H*(SH@9&%T82YP:'`Z,3DW"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE
M8W1E9"!C86QE;F1A<BXB"FUS9W-T<B`B(@HB3F\@9&ES<&]N92!D92!P<FEV
M:6QE9VEO<R!P87)A(&'Q861I<B!A8V]N=&5C:6UI96YT;W,@82!L82!A9V5N
M9&$@(@HB<V5L96-C:6]N861A+B(*"B,Z(&1E;&5V96YT86-T:6]N+G!H<#HR
M-@IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@9&5L971E
M('1H:7,@979E;G0N(@IM<V=S='(@(DYO(&1I<W!O;F4@9&4@<')I=FEL96=I
M;W,@<&%R82!E;&EM:6YA<B!E<W1E(&%C;VYT96-I;6EE;G1O+B(*"B,Z(&5D
M:71E=F5N=&%C=&EO;BYP:'`Z-S@*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="XB"FUS9W-T<B`B3F\@9&ES
M<&]N92!D92!P<FEV:6QE9VEO<R!P87)A(&UO9&EF:6-A<B!E<W1E(&%C;VYT
M96-I;6EE;G1O+B(*"B,Z(&1A=&$N<&AP.C$Y,@IM<V=I9"`B66]U(&AA=F4@
M<W!E8VEF:65D(&%N(&EN=F%L:60@8V%L96YD87(N(@IM<V=S='(@(DAA(&5S
M<&5C:69I8V%D;R!U;F$@86=E;F1A(&YO(';A;&ED82XB"@HC.B!A='1E;F0N
M<&AP.C(Q"FUS9VED(")9;W4@:&%V92!S=6-C97-S9G5L;'D@86-C97!T960@
M871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R(")(82!A8V5P=&%D
M;R!S871I<V9A8W1O<FEA;65N=&4@;&$@87-I<W1E;F-I82!A(&5S=&4@86-O
M;G1E8VEM:65N=&\N(@H*(SH@871T96YD+G!H<#HR-@IM<V=I9"`B66]U(&AA
M=F4@<W5C8V5S<V9U;&QY(&1E8VQI;F5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E
M=F5N="XB"FUS9W-T<B`B2&$@<F5C:&%Z861O('-A=&ES9F%C=&]R:6%M96YT
M92!L82!A<VES=&5N8VEA(&$@97-T92!A8V]N=&5C:6UI96YT;RXB"@HC.B!A
M='1E;F0N<&AP.C,Q"FUS9VED(")9;W4@:&%V92!T96YT871I=F5L>2!A8V-E
M<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(DAA(&%C
M97!T861O(&-O;F1I8VEO;F%L;65N=&4@;&$@87-I<W1E;F-I82!A(&5S=&4@
M86-O;G1E8VEM:65N=&\N(@H*(SH@8V%L96YD87)S+G!H<#HY,0IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B5&EE;F4@<75E('-E;&5C8VEO;F%R('5N82!A9V5N9&$@82!E;&EM
M:6YA<BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C4T
M"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS
M9W-T<B`B4')I;65R;R!T:65N92!Q=64@<V5L96-C:6]N87(@=6YA(&1I<F5C
M8VGS;BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$T"FUS9VED(")9;W4@
M<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A9&1E
M9"!T;R!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@HB2&%B[6$@<V]L:6-I
M=&%D;R!L82!N;W1I9FEC86-I\VX@9&4@;&$@861I8VGS;B!D92!A8V]N=&5C
M:6UI96YT;W,@82!S=7,@(@HB8V%L96YD87)I;W,N(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3$R-`IM<V=I9"`B(@HB66]U(')E<75E<W1E9"!T;R!B92!N
M;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L
M96YD87)S+B(*;7-G<W1R("(B"B)(86+M82!S;VQI8VET861O(&QA(&YO=&EF
M:6-A8VGS;B!D92!L82!E;&EM:6YA8VGS;B!D92!A8V]N=&5C:6UI96YT;W,@
M9&4@<W5S("(*(F-A;&5N9&%R:6]S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$Q,3D*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE
M;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T
M<B`B(@HB2&%B[6$@<V]L:6-I=&%D;R!L82!N;W1I9FEC86-I\VX@9&4@;&$@
M;6]D:69I8V%C:?-N(&1E(&%C;VYT96-I;6EE;G1O<R!D92`B"B)S=7,@8V%L
M96YD87)I;W,N(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(')E
M;6EN9&5D(&%B;W5T("5S+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T
M<B`B(@HB4V]L:6-I=/,@<75E('-E(&QE(&5N=FEA<F%N(')E8V]R9&%T;W)I
M;W,@9&4@)7,L('%U92!E<W1A<N$@96X@)7,@82!L87,@)7,N(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-H87)E<V5L96-T+FEN8SHQ,`IM<V=I9"`B66]U<B!D
M969A=6QT(&-A;&5N9&%R(@IM<V=S='(@(E-U(&%G96YD82!P;W(@;VUI<VGS
M;B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-C$@;&EB+T1R:79E<BYP:'`Z,3`W
M,0IM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(EM!8V]N=&5C:6UI
M96YT;R!S:6X@;F]M8G)E72(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.CDU"FUS9VED(")?06QA<FTB"FUS9W-T<B`B7T%L87)M82(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,0IM<V=I9"`B7T)A
M<VEC(%-E87)C:"(*;7-G<W1R(")"^G-?<75E9&$@<VEM<&QE(@H*(SH@=FEE
M=V5V96YT+G!H<#HQ,S4*;7-G:60@(E]%9&ET(@IM<V=S='(@(DUO7V1I9FEC
M87(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S4P"FUS9VED(")?1V]T;R(*
M;7-G<W1R("))7W(@82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-38*;7-G
M:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(E]);7!O<G1A<B]%>'!O<G1A
M<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S<*;7-G:60@(E]->2!#86QE
M;F1A<G,B"FUS9W-T<B`B7TUI<R!A9V5N9&%S(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,T-`IM<V=I9"`B7TYE=R!%=F5N="(*;7-G<W1R(")?0?%A9&ER
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,V,0IM<V=I9"`B7U!R:6YT(@IM
M<V=S='(@(DEM7W!R:6UI<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-3(*
M;7-G:60@(E]396%R8V@B"FUS9W-T<B`B7T)U<V-A<B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S-#<*;7-G:60@(E]4;V1A>2(*;7-G<W1R(")?2&]Y(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED(")B969O<F4@
M=&AE(&5V96YT('-T87)T<R(*;7-G<W1R(")A;G1E<R!D92!Q=64@96UP:65C
M92!E;"!A8V]N=&5C:6UI96YT;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C$X-0IM<V=I9"`B9&%Y(@IM<V=S='(@(F3M82(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR,#<*;7-G:60@(F1A>2AS*2(*;7-G<W1R(")D[6$H<RDB"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ.#8@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$X
M."!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ.#D*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(F3M
M87,B"@HC.B!D871A+G!H<#HQ-3`@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ"FUS9VED(")E=F5N=',N8W-V(@IM<V=S='(@(F%C;VYT96-I;6EE;G1O
M<RYC<W8B"@HC.B!D871A+G!H<#HQ-S$*;7-G:60@(F5V96YT<RYI8W,B"FUS
M9W-T<B`B86-O;G1E8VEM:65N=&]S+FEC<R(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,3,V"FUS9VED(")I;B(*;7-G<W1R(")E;B(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C8*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(W
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,PIM<V=I9"`B;6]N=&@H<RDB
M"FUS9W-T<B`B;65S*&5S*2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B;VX@)7,@870@)7,B"FUS9W-T<B`B96P@
M)7,@82!L87,@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(W"FUS9VED(")O;B!T:&4@<V%M
M92!D871E(@IM<V=S='(@(F5N(&QA(&UI<VUA(&9E8VAA(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3(V('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(S,PIM<V=I9"`B;VX@=&AE('-A;64@=V5E:V1A>2(*;7-G<W1R(")E;B!E
M;"!M:7-M;R!D[6$@;&%B;W)A8FQE(@H*(SH@9&%T82YP:'`Z,CD@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-`IM<V=I9"`B=D-A;&5N9&%R+VE#86QE
M;F1A<B(*;7-G<W1R(")V0V%L96YD87(O:4-A;&5N9&%R(@H*(SH@;&EB+V%P
M:2YP:'`Z,S4P(&QI8B]A<&DN<&AP.C8R.0IM<V=I9"`B=D5V96YT(&YO="!F
M;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@96P@=D5V96YT+B(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$Y,0IM<V=I9"`B=V5E:R(*
M;7-G<W1R(")S96UA;F$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$T"FUS9VED(")W965K*',I
M(&]N.B(*;7-G<W1R(")S96UA;F$H<RD@96XZ(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,3DR(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$Y,PHC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ.30*;7-G:60@
M(G=E96MS(@IM<V=S='(@(G-E;6%N87,B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,Y"FUS9VED
M(")Y96%R*',I(@IM<V=S='(@(F'Q;RAS*2(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]P;R]Z:%]#3BYP;P``````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`Q,34V,3(`,3`T,3<S-C(W-3(`,#(P-#$V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````",@2W)O;F]L:71H(%-I
M;7!L:69I960@0VAI;F5S92!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I
M(#(P,#(@5&AE($AO<F1E(%!R;VIE8W0N"B,@6FAA;F<@0F\@/&)O;WIH86YG
M0'-D8BYA8RYC;CXL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`R+C`M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,BTP-2TR-B`Q,#HU-2LP.#`P7&XB"B),87-T+51R
M86YS;&%T;W(Z(%IH86YG($)O(#QB;V]Z:&%N9T!S9&(N86,N8VX^7&XB"B),
M86YG=6%G92U496%M.B!::&%N9R!";R`\8F]O>FAA;F=`<V1B+F%C+F-N/EQN
M(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#U'0C(S,3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H
M+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!C86QE;F1A<G,@9F]U
M;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC
M.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&5V96YT<R(*;7-G
M<W1R("++^=/0RL*\_B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!$87DH<RD@)7,@
M2&]U<BAS*2`E<R!-:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$W.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@871T96YD965S(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R("+.Q+S^
M("5S(-+1M;S(Z\WJL\DB"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O8F%S
M92YP:'`Z,3(X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A
M;&5N9&%R(@IM<V=S='(@(K6\L_;0T+/,R-7`^B(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A
M;&5N9&%R(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI
M='D@:6X@=&AE(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V-`IM<V=I9"`B*B!!9&0@
M=&AE<V4@8GD@8VQI8VMI;F<@061D("HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-3`*;7-G:60@(BH@4&QE87-E
M('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W.#8*;7-G:60@(C$@871T96YD964B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*(RP@9G5Z>GD*;7-G:60@
M(C$@979E;G0B"FUS9W-T<B`BR_G3T,K"O/XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,W"B,L(&9U>GIY"FUS9VED("(Q(&AO=7(B"FUS9W-T<B`B
M)60@RK$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY
M"FUS9VED("(Q-2!M:6YU=&5S(@IM<V=S='(@(B5D(+?6(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM<V=I9"`B,C`@;6EN=71E
M<R(*;7-G<W1R("(E9""WUB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S8*(RP@9G5Z>GD*;7-G:60@(C,P(&UI;G5T97,B"FUS9W-T<B`B)60@M]8B
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-S$*(RP@9G5Z>GD*;7-G
M:60@(CQS=')O;F<^071T96YD965S/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS
M9W-T<B`B/&(^N=B\_+3*/"]B/B`HT:'/[BDB"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ-#D*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^1&5S8W)I
M7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^P^C*]CPO
M8CX@*-&AS^XI(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C<W"B,L
M(&9U>GIY"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO<'1I
M;VYA;"DB"FUS9W-T<B`B/&(^N=B\_+3*/"]B/B`HT:'/[BDB"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ.30*(RP@9G5Z>GD*;7-G:60@(CQS=')O
M;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB
M/M;8N+0\+V(^("C1H<_N*2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,3`Q('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@Q"FUS9VED(")!
M32(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.3$*;7-G:60@
M(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHQ,0IM<V=I9"`B061?=F%N8V5D(%-E87)C:"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V,2!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B061D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V"FUS9VED
M(")!9&0@179E;G0B"FUS9W-T<B`BT,+4]LK"O/XB"@HC.B!T96UP;&%T97,O
M<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHS-0HC+"!F=7IZ>0IM
M<V=I9"`B061D(&$@;F5W(%)E;6]T92!#86QE;F1A<B(*;7-G<W1R("+0PM3V
MTKO*PKS^(@H*(SH@861D979E;G0N<&AP.C8T"FUS9VED(")!9&0@82!N97<@
M979E;G0B"FUS9W-T<B`BT,+4]M*[RL*\_B(*"B,Z('1E;7!L871E<R]A='1E
M;F1E97,O871T96YD965S+FEN8SHW-`IM<V=I9"`B061D(&%T=&5N9&5E<R(*
M;7-G<W1R("(B"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C<X"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E
M9"!396%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z-3,*;7-G:60@(D%L87)M(@IM<V=S='(@(KZORKXB"@HC.B!L:6(O1')I
M=F5R+G!H<#HQ-S8T"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&1A
M>7,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@:&]U<G,@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%L87)M("5D(&UI;G5T97,@8F5F;W)E(@IM<V=S
M='(@(K?6UM/'L"(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06QA<FT@)60@=V5E:W,@8F5F;W)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C,*;7-G:60@(D%L87)M(#$@9&%Y(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8X"FUS9VED
M(")!;&%R;2`Q(&AO=7(@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W-S,*(RP@9G5Z>GD*;7-G:60@(D%L87)M(#$@;6EN=71E(&)E
M9F]R92(*;7-G<W1R("*WUM;3Q[`B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S4X
M"FUS9VED(")!;&%R;2`Q('=E96L@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C8P"FUS9VED(")!;&%R;2!$871E(@IM<V=S='(@(KZORK[(U<;:
M(@H*(SH@9&%T82YP:'`Z-3D*;7-G:60@(D%L87)M(%-P86X@*&UI;G5T97,I
M(@IM<V=S='(@(KZORKZ\Y+CT("BWUM;3*2(*"B,Z(&1A=&$N<&AP.C8Q"FUS
M9VED(")!;&%R;2!4:6UE(@IM<V=S='(@(KZORK[*L;SD(@H*(SH@=&5M<&QA
M=&5S+V1E;&5T92]D96QE=&4N:6YC.C,Q"FUS9VED(")!;&PB"FUS9W-T<B`B
MR_G3T"(*"B,Z(&QI8B]&0E9I97<N<&AP.C$R-B!L:6(O1D)6:65W+G!H<#HQ
M,CD@;&EB+T9"5FEE=RYP:'`Z,3,R"B,L(&9U>GIY"FUS9VED(")!;&P@071T
M96YD965S(@IM<V=S='(@(LOYT]#*PKS^(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C4Y"B,L(&9U>GIY"FUS9VED(")!;&P@1G5T=7)E(@IM
M<V=S='(@(L2_Q["\L-+4NO,B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z-3,*(RP@9G5Z>GD*;7-G:60@(D%L;"!087-T(@IM<V=S='(@(M7[
MR-4B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HR-`HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR
M-R!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D%L;"!6:7-I8FQE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C$R,B!L:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.CDS
M"B,Z(&QI8B]7965K5FEE=RYP:'`Z,3(W(&QI8B]7965K5FEE=RYP:'`Z,3,T
M(&QI8B]$<FEV97(N<&AP.C$X,S(*;7-G:60@(D%L;"!D87DB"FUS9W-T<B`B
MU?O(U2(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-C0*;7-G:60@(D%L
M;"!D87D@979E;G0B"FUS9W-T<B`BU?O(U=#4RL*\_B(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D%L;"!E=F5N=',B"FUS9W-T
M<B`BR_G3T,K"O/XB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z-#D*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC
M960N:6YC.C<Q(&QI8B]+<F]N;VQI=&@N<&AP.C8X,PIM<V=I9"`B06YY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q
M"FUS9VED(")!<')I;"(*;7-G<W1R("++Q-3"(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z,SD@=&5M<&QA=&5S+V5D:70O961I=%]T
M:6UE<W!A;BYI;F,Z.3,*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHW
M,"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U-@IM<V=I9"`B070B"FUS
M9W-T<B`BU-HB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(V"FUS9VED("(B
M"B)!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!W:71H(&UO<F4@:6YF
M;W)M871I;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y;W5R("(*(FUA:6P@8VQI
M96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@=&AI<R!F
M:6QE('1O(&5A<VEL>2!U<&1A=&4@(@HB>6]U<B!L;V-A;"!C;W!Y(&]F('1H
M92!E=F5N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C0R('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-0IM
M<V=I9"`B071T96YD86YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ-C$*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-0IM<V=I9"`B075G
M=7-T(@IM<V=S='(@(K#+U,(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:%]A9'9A;F-E9"YI;F,Z,3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C@*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@
M(LGZR-4B"@HC.B!L:6(O1D)6:65W+G!H<#HY,"!L:6(O1D)6:65W+G!H<#HQ
M,3`*;7-G:60@(D)U<WDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8VA?861V86YC960N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")#7V%L
M96YD87(B"FUS9W-T<B`BM;S(Z]#0L\S(U<#Z(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z-#D*(RP@9G5Z>GD*;7-G:60@(D-A;%]E;F1A<B(*;7-G
M<W1R("*UO,CKT-"SS,C5P/HB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A
M;&5N9&%R<RYI;F,Z,30V(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR
M,0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C(Q(&QI8B]";&]C:R]M;VYT:&QI
M<W0N<&AP.C(Q(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR,@HC+"!F=7IZ>0IM
M<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BM;S(Z]#0L\S(U<#Z(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R
M(%-U;6UA<GDB"FUS9W-T<B`BU:K2JB(*"B,Z(&1A=&$N<&AP.C(R.`HC+"!F
M=7IZ>0IM<V=I9"`B0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS
M9W-T<B`B:4-A;&5N9&%R(,[$O/[2T;6\R.O-ZK/)(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4W"B,L(&9U>GIY"FUS9VED(")#86QE;F1A<G,B"FUS9W-T<B`BM;S(Z]#0
ML\S(U<#Z(@H*(SH@8V%L96YD87)S+G!H<#HR-PIM<V=I9"`B0V%L96YD87)S
M(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(T
M,PHC+"!F=7IZ>0IM<V=I9"`B0V%N)W0@8W)E871E(&$@;F5W(&5V96YT+B(*
M;7-G<W1R("*]J,&BTKO0PLK"O/XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$Y,2!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S`*
M(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,R('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,P
M.0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(LBAS_LB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HU-S`*(RP@9G5Z>GD*;7-G:60@(D-A;F-E;&QE9"(*;7-G<W1R
M("+(H<_[(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`P,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N8V5L;&5D.B`E<R(*;7-G<W1R("+(H<_[
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C8T
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C8Y"B,L(&9U>GIY"FUS9VED(")#
M871E9V]R7WDB"FUS9W-T<B`BP."Q\"(*"B,Z(&1A=&$N<&AP.C8S('1E;7!L
M871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-"!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,PIM<V=I9"`B0V%T96=O<GDB"FUS9W-T<B`BP."Q\"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@(B(*(D-H;V]S
M92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@
M86YD(&1E;&5T960@979E;G1S(&)Y("(*(F5M86EL.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D-H;V]S92!I9B!Y
M;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E
M;&5T960@979E;G1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M<V5A<F-H7V%B;V]K7W-E;&5C="YI;F,Z,3D@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Y.0IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E
M87)C:"!F;W(@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]F8E]C86QS7W-E;&5C="YI;F,Z,38*;7-G:60@(D-H;V]S
M92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U<WD@
M:6YF;W)M871I;VXZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,3$*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU
M9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!54DQS.B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D-H;V]S92!Y
M;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHV-0IM<V=I9"`B0VQE87(@86QL
M(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR."!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@
M=F%L=65S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M,PIM<V=I9"`B0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_(@IM<V=S='(@
M(LBWMJC)OK/]RL*\_C\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-C<*;7-G
M:60@(D-O;F9I<FUE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,C`X"FUS9VED(")#;W!Y('1H92!54DP@8F5L
M;W<@9F]R('5S92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S>2!5
M4DPZ(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$R-@HC
M+"!F=7IZ>0IM<V=I9"`B0W)E871E(@IM<V=S='(@(L2_Q[`B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3$R"B,L(&9U>GIY"FUS
M9VED(")#<F5A=&4@0V%L96YD87(B"FUS9W-T<B`BM;S(Z]#0L\S(U<#Z(@H*
M(SH@;6]N=&@N<&AP.C$V-2!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHR-2!T
M96UP;&%T97,O9&%Y+W)O=RYI;F,Z-@HC.B!L:6(O1&%Y5FEE=RYP:'`Z.3`@
M;&EB+T1A>59I97<N<&AP.C$Y-`IM<V=I9"`B0W)E871E(&$@3F5W($5V96YT
M(@IM<V=S='(@(KVHP:+2N]#"RL*\_B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C@P"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D96QE=&4O9&5L971E+FEN8SHR.0IM<V=I9"`B0W5R<F5N="(*;7-G
M<W1R("+$O\>P(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(P.0IM<V=I9"`B1&%I;'DZ(%)E8W5R
M<R!E=F5R>2(*;7-G<W1R("+(U3H@P[\B"@HC.B!A='1E;F1E97,N<&AP.C$Q
M,"!L:6(O2W)O;F]L:71H+G!H<#HQ,C@X(&QI8B]";&]C:R]T<F5E7VUE;G4N
M<&AP.C(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@IM<V=I9"`B1&%Y
M(@IM<V=S='(@(LSL(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,Y"FUS9VED(")$87DH<RDB"FUS
M9W-T<B`BS.PB"@HC.B!V:65W979E;G0N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I
M9"`B1&5?;&5T92(*;7-G<W1R("+)OK/](@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-SD*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(LJN
MMO[4PB(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4Y-`IM<V=I9"`B1&5C;&EN
M960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W"B,L
M(&9U>GIY"FUS9VED(")$969A=6QT($-A;&5N9&%R(@IM<V=S='(@(K6\R.O0
MT+/,R-7`^B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ.3,@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#$*(SH@
M=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(Y('1E;7!L871E<R]P<F5F<R]R
M96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C(S"B,Z(&QI8B]$<FEV97(N<&AP
M.C$X,3,*;7-G:60@(D1E;&5T92(*;7-G<W1R("+)OK/](@H*(SH@9&5L979E
M;G0N<&AP.C0P('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHQ."!T96UP;&%T
M97,O9&5L971E+V1E;&5T92YI;F,Z,3@*(SH@;&EB+T1R:79E<BYP:'`Z,3@Q
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,B"FUS9W-T<B`BR;ZS
M_2`E<R(*"B,Z(&5D:71E=F5N="YP:'`Z-S`*;7-G:60@(D1E;&5T92!%=F5N
M="(*;7-G<W1R("+)OK/]RL*\_B(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L
M971E+FEN8SHR-PIM<V=I9"`B(@HB1&5L971E('1H92!C=7)R96YT(&5V96YT
M(&]N;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL(&9U='5R92!O8V-U<F5N
M8V5S+"!O<B`B"B)A;&P@;V-C=7)E;F-E<S\B"FUS9W-T<B`BM,O)OK/]MJ_7
M][VKS-?3P[6].KWVQ+_'L,K"O/XLQ+_'L+RPTM2Z\\K"O/XLN_++^=/0(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$P-"!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C@*(RP@9G5Z>GD*;7-G:60@
M(D1E<V-R:5]P=&EO;B(*;7-G<W1R("+#Z,KV(@H*(SH@9&%T82YP:'`Z-C(@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W-0HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHY-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`BP^C*]B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3<S"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(L_4RK[1
MH<_N(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8P
M"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y($-A;&5N9&%R<R(*;7-G<W1R("+/
MU,J^T:'/[B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+/U,J^T:'/[B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@
M<VAO=R!T87-K<R!W:&EC:"!A<F4@9'5E(&]N('EO=7(@8V%L96YD87(_(@IM
M<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4S-PIM<V=I9"`B1&]E
M<R!N;W0@<F5C=7(B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,S(U"B,L('!H<"UF;W)M870*;7-G:60@(D1U93H@)7,B"FUS9W-T<B`BRK'&
MVCH@)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ
M,34*;7-G:60@(D1U<F%T:6]N(@IM<V=S='(@(LJQQMHB"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<P(&QI8B]$<FEV97(N<&AP
M.C$X,#8*;7-G:60@(D5D:70B"FUS9W-T<B`BL>"\K2(*"B,Z(&5D:71E=F5N
M="YP:'`Z,S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8@;&EB+T1R:79E
M<BYP:'`Z,3@P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S
M='(@(K'@O*T@)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#<*
M;7-G:60@(D5D:70@071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#`*(RP@9G5Z>GD*;7-G:60@
M(D5D:70@0V%L96YD87)S(@IM<V=S='(@(K6\L_;0T+/,R-7`^B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3`*(RP@9G5Z>GD*;7-G:60@(D5D:70@
M4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R("*UO,CKT-"SS,C5P/HB"@HC.B!A
M='1E;F1E97,N<&AP.C$U,`IM<V=I9"`B161I="!A='1E;F1E97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N9"YI;F,Z,C`*;7-G
M:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-C`*(RP@
M9G5Z>GD*;7-G:60@(D5N7V0B"FUS9W-T<B`BO>'*^-/:(@H*(SH@9&%T82YP
M:'`Z-3<*;7-G:60@(D5N9"!$871E(@IM<V=S='(@(KWAROC(U<;:(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHX('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,3`X"FUS9VED(")%;F0@3VXB"FUS9W-T<B`BO>'*^-/:(@H*(SH@9&%T
M82YP:'`Z-3@*;7-G:60@(D5N9"!4:6UE(@IM<V=S='(@(KWAROC*L;SD(@H*
M(SH@871T96YD965S+G!H<#HQ,C0@871T96YD965S+G!H<#HQ,S4@871T96YD
M965S+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5T<FEE
M=FEN9R!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DS"FUS9VED(")%=F5N="!A
M9&1E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P,PIM
M<V=I9"`B179E;G0@9&5L971E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`Y.`IM<V=I9"`B179E;G0@961I=&5D.B(*;7-G<W1R("(B
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#8V"B,L('!H<"UF;W)M870*;7-G:60@
M(D5V96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z-S8T"B,L(&9U>GIY"FUS9VED(")%=F5N=',@;75S="!H879E(&$@
M<W1A<G0@9&%T92XB"FUS9W-T<B`BO>'*^,C5QMJQV-#HM//3VK^JRKS(U<;:
M+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<S,`IM<V=I9"`B179E;G1S(&UU<W0@
M:&%V92!A('1I=&QE+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HW
M-C<*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@86X@96YD(&1A=&4@;W(@82!D
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C<Y"B,L(&9U>GIY"FUS9VED(")%>'!A;F0@3F%M97,B
M"FUS9W-T<B`BO>'*^,JQO.0B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$X-PIM<V=I9"`B17AP;W)T(@IM<V=S='(@(K6\L_8B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R="!#86QE;F1A
M<B(*;7-G<W1R("*UO+/VT-"SS,C5P/HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHV.0IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`BMO[4
MPB(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(X"B,L
M(&9U>GIY"FUS9VED(")&:6YD(@IM<V=S='(@(M#'QMK.Y2(*"B,Z('EE87(N
M<&AP.C@W('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8S('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(R,@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP
M.C$P-0IM<V=I9"`B1G(B"FUS9W-T<B`BT,?&VL[E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U<WD@26YF
M;W)M871I;VXB"FUS9W-T<B`BQ..UQ+CVR,O0Q<^B.B(*"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D+FEN8SHR,"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@
M(D9R:61A>2(*;7-G<W1R("+0Q\;:SN4B"@HC.B!T96UP;&%T97,O9&5L971E
M+V1E;&5T92YI;F,Z,S`*;7-G:60@(D9U='5R92(*;7-G<W1R("+$O\>PO+#2
MU+KS(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")'
M86UE(@IM<V=S='(@(M/.S[<B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:%]A9'9A;F-E9"YI;F,Z,C,*;7-G:60@(D=E;F5R86PB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1V]T;R`E<R(*;7-G<W1R("+2QM;!(@H*(SH@;6]N=&@N
M<&AP.C$S-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*
M;7-G:60@(DAI9&4B"FUS9W-T<B`B(@H*(SH@;6]N=&@N<&AP.C$S-2!T96UP
M;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA
M=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DAI9&4@)7,B"FUS9W-T<B`BS]3*TR`E<R(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8U('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C$S.`IM<V=I9"`B2&]U<BAS*2(*;7-G<W1R("+*L2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*(RP@9G5Z>GD*;7-G:60@(DAO=R!L
M;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T:&4@9&%Y(&%N9"!W965K
M('9I97=S(&)E/R(*;7-G<W1R("+2U+#KT*'*L<ZJR-73Z];<M<37[M"AS]3*
MOK6ESKL_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`IM<V=I9"`B
M2&]W(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M871I;VX@<VAO=6QD
M('=E(&=E;F5R871E/R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#,P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DEF('EO=7(@96UA:6P@
M8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP(')E<75E<W1S('EO=2!C86X@
M=7-E(&]N92!O9B!T:&4@(@HB9F]L;&]W:6YG(&QI;FMS('1O(&%C8V5P="!O
M<B!D96-L:6YE('1H92!E=F5N="Y<;B(*(EQN(@HB5&\@86-C97!T('1H92!E
M=F5N=#I<;B(*(B5S7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0@=&5N
M=&%T:79E;'DZ7&XB"B(E<UQN(@HB7&XB"B)4;R!D96-L:6YE('1H92!E=F5N
M=#I<;B(*(B5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($-A
M;&5N9&%R+"!3=&5P("5D(@IM<V=S='(@(K6\R.O0T+/,R-7`^B(*"B,Z(&1A
M=&$N<&AP.C,R,`IM<V=I9"`B26UP;W)T+T5X<&]R="!#86QE;F1A<B(*;7-G
M<W1R("*UO,CK+[6\L_;0T+/,R-7`^B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S='(@(M*[U,(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-`IM<V=I9"`B
M2G5L>2(*;7-G<W1R("+&W]3"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-S,*;7-G:60@(DIU;F4B"FUS9W-T<B`BP?G4PB(*"B,Z(&1A
M=&$N<&AP.C8U('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T,@IM<V=I9"`B
M2V5Y=V]R9',B"FUS9W-T<B`BN=B\_+3*(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C4U"FUS9VED("),87-T(#(T(&AO=7)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C@W"FUS9VED("),87-T
M($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D
M7W-I9&5?8GE?<VED92YI;F,Z-`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$P"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I
M9&5?8GE?<VED92YI;F,Z,38@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C0*
M(RP@9G5Z>GD*;7-G:60@(DQA<W0@36]N=&@B"FUS9W-T<B`BR<_4PB(*"B,Z
M('1E;7!L871E<R]Y96%R+VAE860N:6YC.C0*(RP@9G5Z>GD*;7-G:60@(DQA
M<W0@665A<B(*;7-G<W1R("+)S];<(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:6YC.C4T('1E;7!L871E<R]W965K+VAE860N:6YC.C,*;7-G:60@
M(DQA<W0@=V5E:R(*;7-G<W1R("+)S];<(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ-PIM<V=I9"`B3&EM:70@=&AE('1I;64@<W!A;B!T;R!E
M>'!O<G0Z(@IM<V=S='(@(L_>UL:UO+/VRK&\Y+SDN/0Z(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@V('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C<V"B,L(&9U>GIY"FUS9VED("),;U]C871I;VXB"FUS
M9W-T<B`BM=BUXR(*"B,Z(&1A=&$N<&AP.C8T('1E;7!L871E<R]S96%R8V@O
M979E;G1?:&5A9&5R<RYI;F,Z-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E
M7V-A;%]M86YA9V5M96YT+FEN8SHQ.`HC.B!T96UP;&%T97,O<')E9G,O<F5M
M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHU,B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHR,0HC.B!L:6(O1')I=F5R+G!H<#HQ.#0Y"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R("*UV+7C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U
M"FUS9VED(")-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S`*;7-G:60@(DUA
M<F-H(@IM<V=S='(@(LC]U,(B"@HC.B!L:6(O87!I+G!H<#HQ,#`*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F($5V96YT<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,@IM<V=I9"`B36%Y(@IM<V=S
M='(@(LSL(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@T-@IM<V=I9"`B364B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")-965T:6YG(@IM<V=S='(@(KOATNDB"@HC.B!L:6(O0FQO8VLO=')E95]A
M;&%R;7,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@06QA<FUS(@IM<V=S
M='(@(KZORKXB"@HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HS"FUS9VED
M(")-96YU($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,W"FUS9VED(")-
M:6YU=&4H<RDB"FUS9W-T<B`BM];6TR(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N
M=&AL:7-T+G!H<#HT,@IM<V=I9"`B36ES<V5D($5V96YT<R!,:7-T(@IM<V=S
M='(@(B(*"B,Z('EE87(N<&AP.C@S('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C4Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.`HC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B36\B"FUS9W-T<B`BT,?&VM*[
M(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$V('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$Q-0HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T
M+FEN8SHV."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"FUS9VED(")-;VYD
M87DB"FUS9W-T<B`BT,?&VM*[(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y
M,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S='(@(M3"(@H*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-;VYT:"!6:65W(@IM
M<V=S='(@(M3"(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,R!L:6(O
M0FQO8VLO;6]N=&AL:7-T+G!H<#HT,PIM<V=I9"`B36]N=&AL>2!%=F5N=',@
M3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(R.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S4*
M;7-G:60@(DUO;G1H;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R("+4PCH@P[\B
M"@HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS
M($%H96%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T
M+G!H<#HR-`HC+"!F=7IZ>0IM<V=I9"`B36]N=&AS($)E9F]R92(*;7-G<W1R
M("*WUM;3Q[`B"@HC.B!L:6(O87!I+G!H<#HV,3(*;7-G:60@(DUU;'1I<&QE
M(&E#86QE;F1A<B!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!V179E;G0@
M:7,@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C$R
M."!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-C<*(RP@9G5Z
M>GD*;7-G:60@(DUY($-A;&5N9&%R<R(*;7-G<W1R("*UO,CKT-"SS,C5P/HB
M"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S0@=&5M<&QA=&5S+VUE;G4N:6YC
M.C,V"B,L(&9U>GIY"FUS9VED(")->2!#86QE;F1A<G,Z(@IM<V=S='(@(K6\
ML_;0T+/,R-7`^B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHR,#0*;7-G:60@(DUY($9R964O0G5S>2!54DPB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q-R!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34Y"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<U"B,Z('1E;7!L871E<R]P<F5F
M<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$W"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C0T"B,L(&9U>GIY"FUS
M9VED(").86UE(@IM<V=S='(@(M/.S[<B"@HC.B!L:6(O0FQO8VLO;6]N=&@N
M<&AP.C0Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0T(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HT,0HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,`IM
M<V=I9"`B3F5W($5V96YT(@IM<V=S='(@(M#"RL*\_B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(DYE>'0B"FUS
M9W-T<B`BS\+2N\SL(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M0E9I97<O9&%Y+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3F5X="!$87DB"FUS
M9W-T<B`BS\+2N\SL(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B
M>5]S:61E+FEN8SHV"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?
M<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S
M:61E+FEN8SHQ."!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z-@IM<V=I9"`B
M3F5X="!-;VYT:"(*;7-G<W1R("+/PKCVU,(B"@HC.B!L:6(O1D)6:65W+W=E
M96LN<&AP.C,R"B,L(&9U>GIY"FUS9VED(").97AT(%=E96LB"FUS9W-T<B`B
MS\+2N];<(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-@HC+"!F=7IZ
M>0IM<V=I9"`B3F5X="!996%R(@IM<V=S='(@(L_"TKO,["(*"B,Z('1E;7!L
M871E<R]D87DO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!D87DB"FUS9W-T<B`B
MS\+2N\SL(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4X('1E
M;7!L871E<R]W965K+VAE860N:6YC.C4*;7-G:60@(DYE>'0@=V5E:R(*;7-G
M<W1R("+/PM*[UMPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<U"B,L
M(&9U>GIY"FUS9VED(").;R(*;7-G<W1R("+.WB(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C<S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$R-@HC
M+"!F=7IZ>0IM<V=I9"`B3F\@86QA<FTB"FUS9W-T<B`BOJ_*OB(*"B,Z('1E
M;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT.`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@871T96YD965S(@IM<V=S='(@(M/`U+8B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,S$Q"FUS9VED(").;R!C86QE;F1A<G,@87)E(&%V86EL
M86)L92!T;R!G=65S=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-34*;7-G
M:60@(DYO(&5N9"!D871E(@IM<V=S='(@(M/`U+8B"@HC.B!L:6(O0FQO8VLO
M<')E=FUO;G1H;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C$V,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT"FUS9VED(").;R!E
M=F5N=',@=&\@9&ES<&QA>2(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92]K
M;VQA8BYP:'`Z-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,S0T(&QI8B]A<&DN<&AP.C8P,@IM<V=I9"`B3F\@
M:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,#0*(RP@9G5Z>GD*;7-G:60@(DYO(')E
M8W5R<F5N8V4B"FUS9W-T<B`BUMBXM,C5QMHB"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HX.#8*;7-G:60@(DYO('9A;&ED(&5M86EL(&%D9')E<W,@9F]U;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C`Q(&QI8B]+<F]N
M;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N92(*;7-G<W1R("+.WB(*"B,Z(&QI
M8B]3=&]R86=E+W-Q;"YP:'`Z,3,V"FUS9VED(").;W0@9F]U;F0B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"B,L(&9U>GIY"FUS
M9VED(").;W1I9FEC871I;VYS(@IM<V=S='(@(K78M>,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.`IM<V=I9"`B3F]V96UB97(B"FUS
M9W-T<B`BRJ[2N]3"(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C4V"FUS9VED(").;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-S<*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BRJ[4
MPB(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$S('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8U"FUS9VED(")/;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<X"FUS9VED
M(")/;B!A;&P@8V%L96YD87)S($D@:&%V92!R96%D(&%C8V5S<R!T;R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<W"FUS9VED(")/
M;B!A;&P@<VAO=VX@8V%L96YD87)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-S8*;7-G:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8Q.0HC+"!F=7IZ
M>0IM<V=I9"`B3W!T:6]N86PB"FUS9W-T<B`BT:'/[B(*"B,Z(&QI8B]&0E9I
M97<N<&AP.C$Q.`IM<V=I9"`B3W!T:6]N86P@071T96YD965S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&0E9I97<N<&AP.C$U,@IM<V=I9"`B3W9E<G9I97<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,S0*;7-G:60@
M(D]W;F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]W;F5R.B`E<R(*;7-G<W1R("+*
ML<;:.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`R('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@R"FUS9VED(")032(*;7-G<W1R
M("(B"@HC.B!D871A+G!H<#HR.2!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$T"B,L(&9U>GIY"FUS9VED(")086QM($1A=&5";V]K(@IM<V=S='(@(KZO
MRK[(U<;:(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C,*;7-G
M:60@(E!A<W0@179E;G1S($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3`Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y
M.`IM<V=I9"`B4&%T=&5R;B(*;7-G<W1R("+1^<J](@H*(SH@=&5M<&QA=&5S
M+V1E;&5T92]O;F4N:6YC.C(W"FUS9VED(")097)M86YE;G1L>2!D96QE=&4@
M=&AI<R!E=F5N=#\B"FUS9W-T<B`BT\"^P\F^L_VTR\K"O/X_(@H*(SH@;&EB
M+V%P:2YP:'`Z,S(U(&QI8B]A<&DN<&AP.C0Q.2!L:6(O87!I+G!H<#HT.#$@
M;&EB+V%P:2YP:'`Z-34S"B,Z(&QI8B]A<&DN<&AP.C4X-"!L:6(O87!I+G!H
M<#HV-S`@;&EB+V%P:2YP:'`Z-S`V"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,38W"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M("*X]LC+M<0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*(RP@9G5Z
M>GD*;7-G:60@(E!O<G1A;"!/<'1I;VYS(@IM<V=S='(@(LJYT\/5W]&AS^XB
M"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(E!R
M979I;W5S($1A>2(*;7-G<W1R("+'L-*[R-4B"@HC.B!L:6(O1D)6:65W+W=E
M96LN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!7965K(@IM<V=S
M='(@(L>PTKO(U2(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI;F,Z,PIM<V=I
M9"`B4')E=FEO=7,@9&%Y(@IM<V=S='(@(L>PTKO(U2(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M-3(*;7-G:60@(E)E8W5R(%5N=&EL(@IM<V=S='(@(M;8N+36L;6](@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`V"B,L(&9U>GIY"FUS9VED(")2
M96-U<G)E;F-E(@IM<V=S='(@(M;8N+3(U<;:(@H*(SH@9&%T82YP:'`Z-CD*
M;7-G:60@(E)E8W5R<F5N8V4@1&%T82(*;7-G<W1R("+6V+BTR-7&VB(*"B,Z
M(&1A=&$N<&AP.C8W"FUS9VED(")296-U<G)E;F-E($5N9"!$871E(@IM<V=S
M='(@(M;8N+2]V-:YR-4B"@HC.B!D871A+G!H<#HV.`IM<V=I9"`B4F5C=7)R
M96YC92!);G1E<G9A;"(*;7-G<W1R("+6V+BTO.2X]"(*"B,Z(&1A=&$N<&AP
M.C8V"FUS9VED(")296-U<G)E;F-E(%1Y<&4B"FUS9W-T<B`BUMBXM-#-S*PB
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#`*;7-G:60@(E)E8W5R<R!D86EL
M>2(*;7-G<W1R("+#O\C5UMBXM"(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T
M-PIM<V=I9"`B4F5C=7)S(&UO;G1H;'DB"FUS9W-T<B`BP[_4PM;8N+0B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HU-#,*;7-G:60@(E)E8W5R<R!W965K;'DB
M"FUS9W-T<B`BP[_6W-;8N+0B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3`*
M;7-G:60@(E)E8W5R<R!Y96%R;'DB"FUS9W-T<B`BP[_$ZM;8N+0B"@HC.B!L
M:6(O4V-H961U;&5R+VMR;VYO;&ET:"YP:'`Z,3DX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E;6EN9&5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.3$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T"B,L(&9U>GIY"FUS9VED(")296UO=&4@0V%L96YD87)S(@IM<V=S
M='(@(K6\R.O0T+/,R-7`^B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHV,"!T
M96UP;&%T97,O;65N=2YI;F,Z-C(*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!#
M86QE;F1A<G,Z(@IM<V=S='(@(K6\R.O0T+/,R-7`^B(*"B,Z('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHU,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296UO=F4@)7,B"FUS9W-T<B`B(@H*(SH@871T96YD965S+G!H<#HQ
M,#0*;7-G:60@(E)E;6]V92!!='1E;F1E92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C,R"FUS9VED("(B"B)297!L86-E(&5X
M:7-T:6YG(&-A;&5N9&%R('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N
M9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U
M<B!C=7)R96YT(&-A;&5N9&%R+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HV,C8*;7-G:60@(E)E<75I<F5D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&0E9I97<N<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S-R!L
M:6(O1D)6:65W+G!H<#HQ-#`@;&EB+T9"5FEE=RYP:'`Z,30S"FUS9VED(")2
M97%U:7)E9"!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S$P"FUS
M9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R("+6V,GHN]C$VK:HUK4B
M"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#,@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38V"FUS9VED(")297-P;VYS92(*;7-G
M<W1R("(B"@HC.B!Y96%R+G!H<#HX."!T96UP;&%T97,O:F%V87-C<FEP="]G
M;W1O+FEN8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C,*(SH@;&EB
M+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(M#'QMK!
M^2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,2!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z-S,*;7-G:60@(E-A='5R9&%Y(@IM<V=S='(@(M#'QMK!^2(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ.3(*(RP@9G5Z
M>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`BT,?&VL'Y(@H*(SH@=FEE=V5V96YT
M+G!H<#HQ,3@@961I=&5V96YT+G!H<#HT."!E9&ET979E;G0N<&AP.C4V"FUS
M9VED(")3879E($%S($YE=R(*;7-G<W1R("+![;3FT,*UM2(*"B,Z('1E;7!L
M871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHX-PIM<V=I9"`B4V%V92!!
M='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@861D979E;G0N<&AP.C4U(&5D:71E
M=F5N="YP:'`Z-3$*;7-G:60@(E-A=F4@179E;G0B"FUS9W-T<B`BM**TYLK"
MO/XB"@HC.B!S96%R8V@N<&AP.CDQ('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHQ,34*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C8W('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHX"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,30P(&QI8B]";&]C:R]T
M<F5E7VUE;G4N<&AP.C(V"B,L(&9U>GIY"FUS9VED(")396%R8V@B"FUS9W-T
M<B`BR/W4PB(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ
M"B,L(&9U>GIY"FUS9VED(")396%R8V@@0V%L96YD87)S(@IM<V=S='(@(K6\
MR.O0T+/,R-7`^B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHV
M"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+W-E87)C:"YI;F,Z-@IM<V=I9"`B4V5A<F-H(&9O<B!C
M86QE;F1A<G,@8V]N=&%I;FEN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U,`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&$@8V%L96YD87(@=&\@961I="(*;7-G<W1R("+1H=3QSL2\_M+4
MM;S(Z\K]OMTZ(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@82!D871E(@IM<V=S='(@(L;TRKS(U<;:(@H*(SH@=&5M<&QA=&5S
M+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")396QE8W0@8V%L96YD87)S
M('1O(&1I<W!L87DZ(@IM<V=S='(@(M&AU/'(Y[K.S]3*OLC5QMHZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED("(B"B)396QE8W0@8V]N
M9FER;6%T:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E
M;G0@=FEE=W,@86YD(&-H;V]S92`B"B)D969A=6QT('9I97<N(@IM<V=S='(@
M(M&AU/'(Y[K.S]3*OKCWUM:RN\VLM<3/U,J^M^>X\=+4O+#(L<JAM<3/U,J^
MM^>X\2(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3D*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.B(*
M;7-G<W1R("+1H=3QSL2\_M+4M;S(Z\K]OMTZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!E
M>'!O<G0@9F]R;6%T.B(*;7-G<W1R("+1H=3QP+34M,[$O/[2U+6\R.O*_;[=
M.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C@*;7-G:60@(E-E
M;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(M&AU/'.Q+S^TM2U
MO,CKROV^W3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED
M(")396QE8W0@=&AE(&9I<G-T('=E96MD87DZ(@IM<V=S='(@(M&AU/'#O];<
MM<2UVM*[S.PZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C
M92!F:6QE.B(*;7-G<W1R("+1H=3QM;RS]K7$N/'*O3HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@T"FUS9VED(")396QE8W0@=&AE('1I;64@<W!A
M;B!T;R!S:&]W.B(*;7-G<W1R("+'Z]&AU/'*L;SDM[;.I]+4S]3*OB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A<G1U<#HB"FUS9W-T<B`B
MT:'4\;6QM<?(Z[KSM<2UQ,_4RKZWO;>H.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('=H:6-H(&5V96YT
M<R!T;R!S:&]W(&EN('1H92!P;W)T86PN(@IM<V=S='(@(M&AU/'$Q-"IRL*\
M_M+4S]3*OM/:UO?$O\*\M<35JM*JUM`N(@H*(SH@=&5M<&QA=&5S+V1E;&5T
M92]O;F4N:6YC.C(T('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR-`IM
M<V=I9"`B4V5N9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL(&%T=&5N
M9&5E<R!W:&5N(&1E;&5T:6YG('1H:7,@979E;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3<P"B,L('!H<"UF;W)M870*;7-G
M:60@(E-E;F0@86X@96UA:6P@=&\@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3@Q"FUS9VED(")396YD('5P9&%T97,O:6YV
M:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V
M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C<V"FUS9VED(")397!T96UB97(B"FUS9W-T<B`BOL74PB(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS
M9VED(")3970@96YD(&1A=&4B"FUS9W-T<B`BT\#4MB(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(V.`HC+"!F=7IZ>0IM<V=I9"`B4V5T(')E8W5R
M<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`BUMBXM+W8UKG(U2(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,L(&9U>GIY"FUS9VED
M(")3970@<W1A<G0@9&%T92(*;7-G<W1R("+&],J\R-7&VB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU.0IM<V=I9"`B(@HB4V5T('EO=7(@9G)E92]B
M=7-Y(&-A;&5N9&%R<R!A;F0@>6]U<B!O=VX@86YD(&]T:&5R('5S97)S)R!F
M<F5E+V)U<WD@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H
M<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&%R92!N;W0@9F]U;F0Z("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHW.0HC+"!F=7IZ>0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R<R(*;7-G
M<W1R("*UO,CKT-"SS,C5P/HB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-#<@
M=&5M<&QA=&5S+VUE;G4N:6YC.C0Y"B,L(&9U>GIY"FUS9VED(")3:&%R960@
M0V%L96YD87)S.B(*;7-G<W1R("*UO+/VT-"SS,C5P/HB"@HC.B!C86QE;F1A
M<E]S96%R8V@N<&AP.C(U('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S
M:61E+FEN8SHS"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N
M:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@0V%L96YD87(B"FUS9W-T<B`B
MM;RS]M#0L\S(U<#Z(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N
M:6YC.C(R"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@8V%L96YD87(@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-38*
M;7-G:60@(E-H;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")3:&]W(&1E;&5T92P@
M86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS
M9VED(")3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_(@IM<V=S='(@
M(M3:T-"SS,C5P/K6T,_4RKZT^K#LRL+/[C\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,38V"FUS9VED(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@
M(E-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS
M9W-T<B`BUKO/U,J^T]#)Z+:HOJ_*OM?WT\.UQ,K"O/X_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$W-0IM<V=I9"`B4VAO=R!S:&%R960@8V%L96YD
M87)S('-I9&4M8GDM<VED93\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T87-K<R!U<VEN
M9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(M3:T-"SS,C5P/K6T,_4RKZT
M^K#LRL+/[C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@=&EM92!O9B!D87D@8F5T=V5E;B!E86-H(&1A>2!I
M;B!W965K('9I97=S/R(*;7-G<W1R("+2U+#KT*'*L<ZJR-73Z];<M<37[M"A
MS]3*OK6ESKL_(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E-T85]R="(*;7-G<W1R("*_JLJ\T]HB
M"@HC.B!D871A+G!H<#HU-0IM<V=I9"`B4W1A<G0@1&%T92(*;7-G<W1R("+&
M],J\R-7&VB(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI
M;F,Z-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT,0HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C(U"FUS9VED(")3=&%R="!/;B(*;7-G<W1R("*_
MJLJ\T]HB"@HC.B!D871A+G!H<#HU-@IM<V=I9"`B4W1A<G0@5&EM92(*;7-G
M<W1R("+&],J\RK&\Y"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHY-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHX-0IM<V=I
M9"`B4W1A=%]U<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V
M96YT7VAE861E<G,N:6YC.C8@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C<*
M;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX,2!Y96%R
M+G!H<#HY,"!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-0HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,C0@;&EB+T)L;V-K+VUO;G1H+G!H
M<#HQ,#<@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#D*;7-G:60@(E-U(@IM<V=S
M='(@(M#'QMK,["(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-"!T
M96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C,*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(Q('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8W
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4*;7-G:60@(E-U;F1A>2(*
M;7-G<W1R("+0Q\;:S.PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*
M;7-G:60@(E1A<VMS(@IM<V=S='(@(K3ZL.S*PL_N(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3<T(&QI8B]+<F]N;VQI=&@N<&AP.C4Y-PIM<V=I9"`B5&5N
M=&%T:79E(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP.C@V('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(R,0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS
M9W-T<B`BT,?&VLO$(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHW,`IM<V=I9"`B5&AE($5D:70@071T96YD965S('-C<F5E;B!I<R!N
M;R!L;VYG97(@<')E<V5N="X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@8V%L
M96YD87)S+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD
M87(@7"(E<UPB(&-A;FYO="!B92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!C
M86QE;F1A<G,N<&AP.C0P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE
M;F1A<B!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B(@H*(SH@
M8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L
M96YD87(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M(&-A;&5N9&%R<RYP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A
M;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R96YA;65D('1O(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C$V,PIM<V=I
M9"`B5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A<G0@
M9&%T92XB"FUS9W-T<B`BO>'*^,C5QMJQV-#HM//3VK^JRKS(U<;:+B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$P.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!A9&1E9"P@=VAI8V@@:7,@;VX@
M)7,@870@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q
M,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+"!W:&EC:"!W87,@;VX@)7,@870@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!E9&ET960L('=H:6-H
M(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!N;W1I
M9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(T"FUS9VED(")4:&4@9F]L
M;&]W:6YG(&ES(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@
M979E;G0Z(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z-#$*;7-G:60@(B(*
M(E1H92!R97%U97-T('=A<R!I;F-O;7!L971E+B!3;VUE('!A<F%M971E<G,@
M=&AA="!A<F4@;F5C97-S87)Y('1O(&%C8V5P="!O<B`B"B)D96-L:6YE(&%N
M(&5V96YT(&%R92!M:7-S:6YG+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V5M<'1Y+FEN8SHS"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@
M;F\@979E;G1S(&UA=&-H:6YG('1H92!C=7)R96YT(&-R:71E<FEA+B(*;7-G
M<W1R("+#N]/0RL*\_K_)M;RS]BXB"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z
M,3@@961I=&5V96YT86-T:6]N+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L
M96YD87(Z("5S(@IM<V=S='(@(K6\R.O*_;[=RK&WHLGZTKNX]K3MSO,N(@H*
M(SH@861D979E;G1A8W1I;VXN<&AP.C,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N=#H@
M)7,B"FUS9W-T<B`BM;S(Z\K]OMW*L;>BR?K2N[CVM.W.\RXB"@HC.B!E9&ET
M979E;G1A8W1I;VXN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S(@IM
M<V=S='(@(K6\R.O*_;[=RK&WHLGZTKNX]K3MSO,N(@H*(SH@;&EB+V%P:2YP
M:'`Z,S,X(&QI8B]A<&DN<&AP.C4Y-@HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM
M<V=S='(@(K6\R.O*_;[=RK&WHLGZTKNX]K3MSO,N(@H*(SH@961I=&5V96YT
M86-T:6]N+G!H<#HV,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@
M(K6\R.O*_;[=RK&WHLGZTKNX]K3MSO,N(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3`W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$P-0IM<V=I9"`B5&AE<F4@=V5R92!N
M;R!E=F5N=',@=&\@97AP;W)T+B(*;7-G<W1R("+#N]/0RL*\_K_)M;RS]BXB
M"@HC.B!D871A+G!H<#HQ.#0*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN
M8SHQ.2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3@*(SH@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-S$*;7-G:60@(E1H=7)S9&%Y(@IM<V=S
M='(@(M#'QMK+Q"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS
M-PHC+"!F=7IZ>0IM<V=I9"`B5&EM92!3<%]A;B(*;7-G<W1R("+*L<?X(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-`HC+"!F=7IZ
M>0IM<V=I9"`B5&EM92!S<&%N(@IM<V=S='(@(LJQQ_@B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,S8@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(E1I=%]L92(*;7-G<W1R
M("+*PKS^P_NSQB(*"B,Z(&1A=&$N<&AP.C4T('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E
M<G,N:6YC.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@(LK"O/[#^[/&(@H*(SH@
M;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R,B!L:6(O0FQO8VLO;6]N
M=&AL:7-T+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R-PIM
M<V=I9"`B5&]D87DB"FUS9W-T<B`BO?',["(*"B,Z(&QI8B]";&]C:R]P<F5V
M;6]N=&AL:7-T+G!H<#HQ,C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(S
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,CD*;7-G:60@(E1O;6]R<F]W
M(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP.C@T('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8P('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.0HC
M.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5'4B"FUS9W-T<B`B
MT,?&VK;^(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$W('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$Q-@HC.B!T96UP;&%T97,O961I="]J879A
M<V-R:7!T+FEN8SHV.0IM<V=I9"`B5'5E<V1A>2(*;7-G<W1R("+0Q\;:MOXB
M"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(E1Y<&4B
M"FUS9W-T<B`BT,W*O2(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ.#,*;7-G:60@(E523"(*;7-G<W1R("(B"@HC.B!L:6(O4W1O
M<F%G92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C@T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VUC86PN<&AP.C$S-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O
M<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M-0HC.B!S8W)I<'1S+W5P9W)A9&5S+S(P,#0M,#4M,3E?8V]N=F5R=%]C871E
M9V]R:65S7W1O7W-T<FEN9W,N<&AP.C4S"FUS9VED(")5;F9I;&5D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,W-B!L:6(O87!I+G!H<#HT-3`@;&EB
M+V%P:2YP:'`Z-3$V(&QI8B]A<&DN<&AP.C8R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,`IM<V=I9"`B57-E<B!);G1E<F9A8V4B"FUS9W-T<B`BRKG3
MP]7?O=._VB(*"B,Z('EE87(N<&AP.C$V,R!Y96%R+G!H<#HQ-CD@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ-3D@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ-C(*(RP@
M9G5Z>GD*;7-G:60@(E9I97<@1&%Y(@IM<V=S='(@(L_4RM,@)7,B"@HC.B!Y
M96%R+G!H<#HX-2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,2!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,C`*(SH@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HQ,#4*;7-G:60@(E=E(@IM<V=S='(@(M#'QMK(_2(*"B,Z('1E;7!L
M871E<R]M;VYT:"]H96%D+FEN8SHQ."!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,3<*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S`*;7-G
M:60@(E=E9&YE<V1A>2(*;7-G<W1R("+0Q\;:R/TB"@HC.B!A='1E;F1E97,N
M<&AP.C$Q,B!L:6(O2W)O;F]L:71H+G!H<#HQ,CDP(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C(S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I
M9"`B5V5E:R(*;7-G<W1R("+6W"(*"B,Z(&UO;G1H+G!H<#HQ-SD@=V]R:W=E
M96LN<&AP.C,P('=E96LN<&AP.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M96L@)60B"FUS9W-T<B`BUMP@)60B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#`*;7-G:60@(E=E
M96LH<RDB"FUS9W-T<B`BUMPB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"FUS9VED(")7965K
M;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R("+6W#H@P[\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED("(B"B)7:&%T('1I;64@<VAO=6QD
M(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA
M=&5R(&5V96YT<S\B"FUS9W-T<B`BR-73Z];<M<2]X=:YS]3*OLJQO.2COR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(B(*(E=H870@
M=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S('-T87)T+"!W:&5N('1H
M97)E(&%R92!N;R!E87)L:65R(&5V96YT<S\B"FUS9W-T<B`BR-73Z];<M<3&
M],J\S]3*OLJQO.2COR(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$Q(&QI8B]+<F]N
M;VQI=&@N<&AP.C$R.#D@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")7;W)K(%=E96LB"FUS
M9W-T<B`BR<^PX,C5(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,B!L:6(O
M0FQO8VLO=')E95]M96YU+G!H<#HR-0IM<V=I9"`B665A<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C0Q"FUS9VED(")996%R;'DZ(%)E8W5R<R!E=F5R>2(*
M;7-G<W1R("+$ZCH@P[\B"@HC.B!D871A+G!H<#HT,"!D871A+G!H<#HR,S0@
M961I=&5V96YT86-T:6]N+G!H<#HT-B!A9&1E=F5N="YP:'`Z,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&5V96YT<RXB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H
M<#HT.0IM<V=I9"`B66]U(&%R92!N;W0@86X@871T96YD964@;V8@=&AE('-P
M96-I9FEE9"!E=F5N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHW-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T
M:&ES(&9O<FT@9G)O;2!T:&4@161I="!!='1E;F1E97,@<V-R965N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HY-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&1O(&YO="!H879E(&%N(&5M86EL(&%D9')E<W,@
M8V]N9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T:6]N("(*(D]P
M=&EO;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F;W)E(&5V96YT
M(&YO=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N(@IM<V=S='(@(B(*"B,Z(&%D
M9&5V96YT86-T:6]N+G!H<#HR,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O("5S+B(*
M;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.30*;7-G:60@(EEO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@=&AE('-E;&5C=&5D
M(&-A;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!D96QE=F5N=&%C=&EO;BYP:'`Z
M,C8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T
M92!T:&ES(&5V96YT+B(*;7-G<W1R("(B"@HC.B!E9&ET979E;G1A8W1I;VXN
M<&AP.C<X"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E
M9&ET('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X.0IM
M<V=I9"`B66]U(&AA=F4@<W!E8VEF:65D(&%N(&EN=F%L:60@8V%L96YD87(N
M(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E
M('-U8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E
M;G0N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,C8*;7-G:60@(EEO=2!H
M879E('-U8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@
M979E;G0N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,S$*;7-G:60@(EEO
M=2!H879E('1E;G1A=&EV96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI
M<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HY,0IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHU-`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.30*;7-G:60@
M(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E
M(&%D9&5D('1O('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,3`T"FUS9VED("(B"B)9;W4@<F5Q=65S=&5D('1O
M(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U
M<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$P.3D*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE
M;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(')E;6EN9&5D
M(&%B;W5T("5S+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-H87)E<V5L96-T+FEN8SHQ,`HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!D969A=6QT(&-A;&5N9&%R(@IM<V=S='(@(K6\L_;0
MT+/,R-7`^B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-3,@;&EB+T1R:79E<BYP
M:'`Z,3`V,PIM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.CDW"B,L(&9U>GIY"FUS9VED(")?
M06QA<FTB"FUS9W-T<B`BOJ_*OB(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H7V%D=F%N8V5D+FEN8SHQ,0IM<V=I9"`B7T)A<VEC(%-E87)C:"(*;7-G
M<W1R("(B"@HC.B!V:65W979E;G0N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B
M7T5D:70B"FUS9W-T<B`BL>"\K2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M,S`*(RP@9G5Z>GD*;7-G:60@(E]';W1O(@IM<V=S='(@(M+&UL$B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,S,V"B,L(&9U>GIY"FUS9VED(")?26UP;W)T
M+T5X<&]R="(*;7-G<W1R("*UO,CK+[6\L_8B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,S$X"B,L(&9U>GIY"FUS9VED(")?37D@0V%L96YD87)S(@IM<V=S
M='(@(K6\L_;0T+/,R-7`^B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,C4*
M(RP@9G5Z>GD*;7-G:60@(E].97<@179E;G0B"FUS9W-T<B`BT,+*PKS^(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,T,0IM<V=I9"`B7U!R:6YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S(*(RP@9G5Z>GD*;7-G
M:60@(E]396%R8V@B"FUS9W-T<B`BR/W4PB(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$S,C@*(RP@9G5Z>GD*;7-G:60@(E]4;V1A>2(*;7-G<W1R("*]\<SL
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30R"FUS9VED(")B969O
M<F4@=&AE(&5V96YT('-T87)T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3@U"FUS9VED(")D87DB"FUS9W-T<B`BR-4B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C$P"FUS9VED(")D87DH<RDB"FUS9W-T<B`BR-4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3@V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.#<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X."!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(F1A>7,B"FUS9W-T<B`BR-4B"@HC.B!D871A+G!H<#HQ-#<@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ"B,L(&9U>GIY"FUS9VED(")E=F5N=',N
M8W-V(@IM<V=S='(@(LOYT]#*PKS^(@H*(SH@9&%T82YP:'`Z,38X"B,L(&9U
M>GIY"FUS9VED(")E=F5N=',N:6-S(@IM<V=S='(@(LOYT]#*PKS^(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,S$*;7-G:60@(F9R
M;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,S`@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,V"FUS
M9VED(")M;VYT:"AS*2(*;7-G<W1R("+4PB(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$P,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F]N("5S(&%T
M("5S(@IM<V=S='(@(B5S(+^JRKS3VB`E<R(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$R-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S`*;7-G
M:60@(F]N('1H92!S86UE(&1A=&4B"FUS9W-T<B`BU-K-K-*[S.PB"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C8@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C,V"FUS9VED(")O;B!T:&4@<V%M92!W965K9&%Y(@IM<V=S='(@
M(M3:P[_6W+7$M=K2N\SL(@H*(SH@9&%T82YP:'`Z,S`@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ-0IM<V=I9"`B=D-A;&5N9&%R+VE#86QE;F1A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HS-#D@;&EB+V%P:2YP:'`Z-C`W
M"FUS9VED(")V179E;G0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DQ"FUS9VED(")W965K(@IM<V=S='(@(M;<
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(Q-PIM<V=I9"`B=V5E:RAS*2!O;CHB"FUS9W-T<B`B
MUMPZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DS"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.30*
M;7-G:60@(G=E96MS(@IM<V=S='(@(M;<(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T,@IM<V=I
M9"`B>65A<BAS*2(*;7-G<W1R("+$ZB(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W!O
M+WIH7U17+G!O````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#$R,S,U,P`Q,#0Q-S,V,C<U,@`P,C`T-3$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!+4D].3TQ)5$@@5')A9&ET:6]N
M86P@0VAI;F5S92!4<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,2!$
M879I9"!#:&%N9RX@L6FH?:3E+*5XQE<*(R!$879I9"!#:&%N9R`\9&%V:61`
M=&UV+F=O=BYT=SXL(#(P,#$N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`R+C`M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#$M,#4@,34Z,#0K,#@P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,RTP,2TP."`Q,#HU,RLP,3`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($1A=FED($-H86YG(#QD879I9$!T;78N9V]V+G1W/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@5')A9&ET:6]N86P@0VAI;F5S92`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4))1S5<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+W-E87)C:"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M8V%L96YD87)S(&9O=6YD(@IM<V=S='(@(J?DJ.P@)60@K=.FYJC&ON0B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!E=F5N=',B"FUS9W-T<B`B)60@K=.HQJ7S(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3(S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($1A>2AS*2`E<R!(;W5R*',I("5S($UI;G5T97,B"FUS
M9W-T<B`B)7,@I-$@)7,@KLD@)7,@I,`B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M.#`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T=&5N9&5E<R(*;7-G<W1R
M("(E<R"E6*YUI$BM^R(*"B,Z(&1A=&$N<&AP.C(X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R
M("+`R:[7("5S(*1WMM>D2J>YIJ@B"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L
M:6(O8F%S92YP:'`Z,3(X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L
M96YD87(B"FUS9W-T<B`B)7.JNJ;FJ,:^Y"(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N
M9&%R(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@
M:6X@=&AE(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(HPDF_[Z;FJ,:^Y*97
MNMFE2*3!M*NFYJC&ON2F8J5$M?BUH:2DJKJE::BCJ<HI(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C0*;7-G:60@(BH@061D('1H
M97-E(&)Y(&-L:6-K:6YG($%D9"`J(@IM<V=S='(@(BH@PDF_[[=SO%>E2*>Y
MIJ@@*B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,34P
M"FUS9VED("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R
M("(J(+W0O^^^W*9AIWT@*B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X,#4*;7-G
M:60@(C$@871T96YD964B"FUS9W-T<B`B,2"F[*58KG6D2*W[(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*;7-G:60@(C$@979E;G0B"FUS
M9W-T<B`B,2"MTZC&I?,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,W
M"FUS9VED("(Q(&AO=7(B"FUS9W-T<B`B,2"D<*[)(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-`IM<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R("(Q
M-2"DP,3!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B
M,C`@;6EN=71E<R(*;7-G<W1R("(R,""DP,3!(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-@IM<V=I9"`B,S`@;6EN=71E<R(*;7-G<W1R("(S,""D
MP,3!(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,38Y"FUS9VED("(\
M<W1R;VYG/D%T=&5N9&5E<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@
M(CQS=')O;F<^I5BN=:1(K?L\+W-T<F]N9SX@**M$I;*VMRDB"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ-#<*;7-G:60@(CQS=')O;F<^1&5S8W)I
M7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9SZT
M>:UZ/"]S=')O;F<^("B_[[:U*5]P(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C<T"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO
M<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9S[#]L'DIG(\+W-T<F]N9SX@*+_O
MMK4I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DR"FUS9VED("(\
M<W1R;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R
M("(\<W1R;VYG/JVKO<8\+W-T<F]N9SX@*+_OMK4I(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ.3,*;7-G:60@(D%-(@IM<V=S='(@(J17I,@B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HV,#(*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(J1WL;6H_"(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I9"`B061?
M=F%N8V5D(%-E87)C:"(*;7-G<W1R("*V:;:EMVJT35]V(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C$@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(D%D9"(*;7-G<W1R("*W<[Q7
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(*;7-G:60@(D%D9"!%
M=F5N="(*;7-G<W1R("*W<[Q7J,:E\R(*"B,Z('1E;7!L871E<R]P<F5F<R]R
M96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C,U"FUS9VED(")!9&0@82!N97<@
M4F5M;W1E($-A;&5N9&%R(@IM<V=S='(@(K=SO%>D0*W3N[>ZW:;FJ,:^Y"(*
M"B,Z(&%D9&5V96YT+G!H<#HV-`IM<V=I9"`B061D(&$@;F5W(&5V96YT(@IM
M<V=S='(@(K=SO%>D0*C&I?,B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-S$*;7-G:60@(D%D9"!A='1E;F1E97,B"FUS9W-T<B`B
MMW.\5Z58KG6D2*W[(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(P"B,Z('1E;7!L871E<R]A='1E;F1E
M97,O871T96YD965S+FEN8SHW-0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S
M='(@(K-QL%2__2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHX('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I
M9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(K9IMJ6W:K1-(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3,*;7-G:60@(D%L87)M(@IM<V=S='(@
M(L2UI=PB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D%L87)M("5D(&1A>7,@8F5F;W)E(@IM<V=S='(@(B5D(*31JV7$
MM:7<(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!;&%R;2`E9"!H;W5R<R!B969O<F4B"FUS9W-T<B`B)60@I'"NR:ME
MQ+6EW"(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B06QA<FT@)60@;6EN=71E<R!B969O<F4B"FUS9W-T<B`B)60@I,#$
MP:MEQ+6EW"(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B06QA<FT@)60@=V5E:W,@8F5F;W)E(@IM<V=S='(@(B5D(+9G
MJV7$M:7<(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X,`IM<V=I9"`B06QA<FT@
M,2!D87D@8F5F;W)E(@IM<V=S='(@(C$@I-&K9<2UI=PB"@HC.B!L:6(O1')I
M=F5R+G!H<#HQ-S@U"FUS9VED(")!;&%R;2`Q(&AO=7(@8F5F;W)E(@IM<V=S
M='(@(C$@I'"NR:MEQ+6EW"(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.3`*;7-G
M:60@(D%L87)M(#$@;6EN=71E(&)E9F]R92(*;7-G<W1R("(Q(*3`Q,&K9<2U
MI=PB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<U"FUS9VED(")!;&%R;2`Q('=E
M96L@8F5F;W)E(@IM<V=S='(@(C$@MF>K9<2UI=PB"@HC.B!D871A+G!H<#HU
M.0IM<V=I9"`B06QA<FT@1&%T92(*;7-G<W1R("+$M:7<I.FTP2(*"B,Z(&1A
M=&$N<&AP.C4X"FUS9VED(")!;&%R;2!3<&%N("AM:6YU=&5S*2(*;7-G<W1R
M("+$M:7<MJ&Y:B`HI,#$P2DB"@HC.B!D871A+G!H<#HV,`IM<V=I9"`B06QA
M<FT@5&EM92(*;7-G<W1R("+$M:7<KLFVH2(*"B,Z('1E;7!L871E<R]D96QE
M=&4O9&5L971E+FEN8SHS-`IM<V=I9"`B06QL(@IM<V=S='(@(JG2IK,B"@HC
M.B!L:6(O1D)6:65W+G!H<#HQ,C@@;&EB+T9"5FEE=RYP:'`Z,3,Q(&QI8B]&
M0E9I97<N<&AP.C$S-`IM<V=I9"`B06QL($%T=&5N9&5E<R(*;7-G<W1R("*I
MTJ:SI5BN=:1(K?LB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M-3D*;7-G:60@(D%L;"!&=71U<F4B"FUS9W-T<B`BJ=*FLZ6\J-,B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*;7-G:60@(D%L;"!087-T
M(@IM<V=S='(@(JG2IK.Y3*5H(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI
M<W0N<&AP.C(W(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C0*(SH@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(U"FUS
M9VED(")!;&P@5FES:6)L92(*;7-G<W1R("*ITJ:SI6FHHZJZ(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3(R(&QI8B]$87E6:65W
M+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z.3,*(SH@;&EB+U=E96M6:65W+G!H
M<#HQ,C<@;&EB+U=E96M6:65W+G!H<#HQ,S0@;&EB+T1R:79E<BYP:'`Z,3@V
M.`IM<V=I9"`B06QL(&1A>2(*;7-G<W1R("*^XZ3I(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C$V-`IM<V=I9"`B06QL(&1A>2!E=F5N="(*;7-G<W1R
M("*^XZ3IJ<JHQJ7S(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS
M,PIM<V=I9"`B06QL(&5V96YT<R(*;7-G<W1R("*ITJ:SJ,:E\R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHT.`HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-S`@;&EB+TMR;VYO
M;&ET:"YP:'`Z-CDU"FUS9VED(")!;GDB"FUS9W-T<B`BI?2F6"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!<')I;"(*
M;7-G<W1R("*E?*3K(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z,SD@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX,B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C$V.`IM<V=I9"`B070B"FUS9W-T<B`BKLFVH2(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$P-#8*;7-G:60@(B(*(D%T=&%C:&5D(&ES
M(&%N(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U
M="!T:&4@979E;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@
M:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY
M('5P9&%T92`B"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G
M<W1R("(B"B+#]JGSLV^MTZC&I?.JNJ?SIFBP5*ZGI'>J_J5;IF(@:4-A;&5N
M9&%R(,#)KM>DI"X@IG"J1Z=!JKJV;*7SOES%JK-NQ>FDY+2I("(*(FE4:7`@
MIT&E::5(N[2I]JJZJ,^ESK-OK=.J_J7SP,FNUZ%!L4ZHQJ7SO<:[<ZCLIT&J
MNJ;FJ,:^Y*2D+B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S
M+FEN8SHT,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C4*;7-G:60@(D%T
M=&5N9&%N8V4B"FUS9W-T<B`BI5BN=:1(K?LB"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ-C$*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R("*E6*YU
MI$BM^R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<U"FUS
M9VED(")!=6=U<W0B"FUS9W-T<B`BI$NDZR(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,2!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z.`IM<V=I9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(K#RI;NW
M:K1-(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")"
M:7)T:&1A>2(*;7-G<W1R("*ES:3I(@H*(SH@;&EB+T9"5FEE=RYP:'`Z.3`@
M;&EB+T9"5FEE=RYP:'`Z,3$Q"FUS9VED(")"=7-Y(@IM<V=S='(@(J:CN$PB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#(*
M;7-G:60@(D-?86QE;F1A<B(*;7-G<W1R("*FYJC&ON1?82(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C0W"FUS9VED(")#86Q?96YD87(B"FUS9W-T
M<B`BIN:HQK[D7V4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,30V(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR,0HC.B!L
M:6(O0FQO8VLO;6]N=&@N<&AP.C(Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C(Q(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR,@IM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`BIN:HQK[D(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*
M;7-G:60@(D-A;&5N9&%R(%-U;6UA<GDB"FUS9W-T<B`BIN:HQK[DNDNM;B(*
M"B,Z(&1A=&$N<&AP.C(S,PIM<V=I9"`B0V%L96YD87(@<W5C8V5S<V9U;&QY
M('!U<F=E9"XB"FUS9W-T<B`BIN:HQK[DI'>GN::HLDVJQ2XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3<*;7-G:60@(D-A;&5N9&%R<R(*;7-G<W1R("*FYJC&ON0B"@HC
M.B!C86QE;F1A<G,N<&AP.C(W"FUS9VED(")#86QE;F1A<G,@;75S="!H879E
M(&$@;F%M92XB"FUS9W-T<B`BIN:HQK[DI;*VMZUNIK.D0*W3IE>ZV2XB"@HC
M.B!D871A+G!H<#HR-#@*;7-G:60@(D-A;B=T(&-R96%T92!A(&YE=R!E=F5N
M="XB"FUS9W-T<B`BM4RJ:ZO8I=^W<ZC&I?,B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$Y,2!T96UP;&%T97,O9&5L971E+V]N92YI
M;F,Z,S,*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,U('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C,P-PIM<V=I9"`B0V%N8V5L(@IM<V=S='(@(JCZKO@B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HU-S@*;7-G:60@(D-A;F-E;&QE9"(*;7-G<W1R("*D
M=ZCZKO@B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;F-E;&QE9#H@)7,B"FUS9W-T<B`BI'>H^J[X.B`E<R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV,R!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHV-PIM<V=I9"`B0V%T96=O<E]Y(@IM
M<V=S='(@(J3`P_Y?>2(*"B,Z(&1A=&$N<&AP.C8R('1E;7!L871E<R]S96%R
M8V@O979E;G1?:&5A9&5R<RYI;F,Z-"!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,PIM<V=I9"`B0V%T96=O<GDB"FUS9W-T<B`BI,##_B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@(B(*(D-H;V]S92!I9B!Y;W4@
M=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T
M960@979E;G1S(&)Y("(*(F5M86EL.B(*;7-G<W1R("*W[:C&I?.S4;=SO%<L
MO7._Z*G.IU*PHZ[)K$^G7Z5(MFRE\[-QJKXZ(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4R"FUS9VED(")#:&]O<V4@:68@>6]U('=A;G0@=&\@8F4@
M;F]T:69I960@;V8@;F5W+"!E9&ET960L(&%N9"!D96QE=&5D(&5V96YT<RXB
M"FUS9W-T<B`BM^VHQJ7SLU&W<[Q7++USO^BISJ=2L*.NR:Q/IU^S4;-QJKXN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y,@IM<V=I9"`B0VAO;W-E
M(&EF('EO=2!W86YT('1O(')E8V5I=F4@96UA:6P@<F5M:6YD97)S(&9O<B!E
M=F5N=',@=VET:"!A;&%R;7,Z(@IM<V=S='(@(JUNJ,^ESK9LI?.S<:J^JKJF
MYJC&ON0Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E87)C:%]A8F]O:U]S96QE
M8W0N:6YC.C$Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3(*;7-G:60@(D-H
M;V]S92!T:&4@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S
M>2!54DQS.B(*;7-G<W1R("*_[[[<LW&P5+_]I4BW:K1-JL6VHB^FH[A,NO2G
M?3HB"@HC.B!T96UP;&%T97,O<')E9G,O9F)?8V%L<U]S96QE8W0N:6YC.C$V
M"FUS9VED(")#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E(&EN('EO
M=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B(*;7-G<W1R("*_[[[<JL6VHB^F
MH[A,NO2G?:G2K6ZE7:=TJKJFYJC&ON0Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,R-`IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC
M;'5D92!W:&5N(&=E;F5R871I;F<@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@
M(K_OOMRS<;!4O_VE2*5;I$JJQ;:B+Z:CN$RZ]*=].B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!C
M86QE;F1A<BXB"FUS9W-T<B`BO^^^W*=!JKJY=[-=IN:HQK[D+B(*"B,Z('1E
M;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHX-0IM<V=I9"`B0VQE
M87(@86QL(&%T=&5N9&5E<R(*;7-G<W1R("*R3;"CJ=*FLZ58KG6D2*W[(@H*
M(SH@9&%T82YP:'`Z,C@@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,PIM
M<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("*S<L))I,"Y
M:JW((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S"FUS9VED(")#;VYF
M:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\B"FUS9W-T<B`BIU*PHZC&I?.NR:Q/
MIU^[W:UNO52[>R`_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<U"FUS9VED
M(")#;VYF:7)M960B"FUS9W-T<B`BI'>]5+M[(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(P-@IM<V=I9"`B0V]P>2!T:&4@55),
M(&)E;&]W(&9O<B!U<V4@=VAE<F5V97(@>6]U(&YE960@>6]U<B!&<F5E+T)U
M<WD@55),.B(*;7-G<W1R("*G0:JZJL6VHB^FH[A,NO2G?:9PI%4Z(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("*U3*IKMGVQTB`E<RXB"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3(V"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`BJ]BEWR(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHQ,3(*;7-G:60@(D-R96%T92!#86QE;F1A<B(*;7-G
M<W1R("*KV*7?IN:HQK[D(@H*(SH@;6]N=&@N<&AP.C$V,R!T96UP;&%T97,O
M=V5E:R]H96%D+FEN8SHR-2!T96UP;&%T97,O9&%Y+W)O=RYI;F,Z-@HC.B!L
M:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.C$Y-0IM<V=I9"`B
M0W)E871E(&$@3F5W($5V96YT(@IM<V=S='(@(JO8I=^D0+=SJ,:E\R(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C@P"FUS9VED(")#<F5A=&5D(@IM
M<V=S='(@(JO8I=\B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z
M,S(*;7-G:60@(D-U<G)E;G0B"FUS9W-T<B`BI=BK92(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,#8*;7-G:60@(D1A:6QY.B!296-U<G,@979E<GDB"FUS9W-T<B`BI.DZ(*A#
M(@H*(SH@871T96YD965S+G!H<#HQ,3`@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q
M,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#(*;7-G:60@(D1A>2(*;7-G<W1R("*DT2(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$S-PIM<V=I9"`B1&%Y*',I(@IM<V=S='(@(J31(@H*(SH@=FEE=V5V96YT
M+G!H<#HQ,3$*;7-G:60@(D1E7VQE=&4B"FUS9W-T<B`BIU*PHU]L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-SD*;7-G:60@(D1E8V5M
M8F5R(@IM<V=S='(@(J11I$>DZR(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8P
M-0IM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`BP<*UM"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-PIM<V=I9"`B1&5F875L="!#86QE;F1A<B(*;7-G
M<W1R("*Y=[-=IN:HQK[D(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$Y,R!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$X,0HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S(@=&5M<&QA=&5S
M+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,C,*(SH@;&EB+T1R
M:79E<BYP:'`Z,3@T.0IM<V=I9"`B1&5L971E(@IM<V=S='(@(J=2L*,B"@HC
M.B!D96QE=F5N="YP:'`Z-#`@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(Q
M('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR,0HC.B!L:6(O1')I=F5R
M+G!H<#HQ.#0X"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R(*;7-G
M<W1R("*G4K"C("5S(@H*(SH@961I=&5V96YT+G!H<#HW,@IM<V=I9"`B1&5L
M971E($5V96YT(@IM<V=S='(@(J=2L*.HQJ7S(@H*(SH@=&5M<&QA=&5S+V1E
M;&5T92]D96QE=&4N:6YC.C,P"FUS9VED("(B"B)$96QE=&4@=&AE(&-U<G)E
M;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E
M(&]C8W5R96YC97,L(&]R("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R("*F
MN:=2L*.PRJ=`L4ZN3:7.J.PZMLBEV*MEJ,:E\RREV*MEI,ZE2*OAJ,:E\RRI
MSJG2IK,B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI
M;F,Z,3`S('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR.`IM<V=I9"`B
M1&5S8W)I7W!T:6]N(@IM<V=S='(@(K1YK7I?<"(*"B,Z(&1A=&$N<&AP.C8Q
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S4*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.38*;7-G:60@(D1E<V-R:7!T:6]N(@IM
M<V=S='(@(K1YK7HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$W,PIM<V=I9"`B1&ES<&QA>2(*;7-G<W1R("+%XZ7<(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8P"FUS9VED(")$:7-P
M;&%Y($-A;&5N9&%R<R(*;7-G<W1R("+%XZ7<IN:HQK[D(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS
M(@IM<V=S='(@(L7CI=R_[[:U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P"FUS9VED(")$;R!Y;W4@=V%N="!T;R!S:&]W('1A<VMS('=H:6-H(&%R
M92!D=64@;VX@>6]U<B!C86QE;F1A<C\B"FUS9W-T<B`BIF*FYJC&ON2DI,7C
MI=RH[+3!JKJKW;_LJ,:VM2`_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30U
M"FUS9VED(")$;V5S(&YO="!R96-U<B(*;7-G<W1R("*DHZVKO<8B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1'5E
M.B`E<R(*;7-G<W1R("*H[+3!.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B
MM,&VH2(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ
M-S`@;&EB+T1R:79E<BYP:'`Z,3@S-0IM<V=I9"`B161I="(*;7-G<W1R("*]
M<[_H(@H*(SH@961I=&5V96YT+G!H<#HS,R!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,B!L:6(O1')I=F5R+G!H<#HQ.#,T"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@)7,B"FUS9W-T<B`BO7._Z"`E<R(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C$X-0IM<V=I9"`B161I="!!='1E;F1E97,B"FUS9W-T
M<B`BO7._Z*58KG6D2*W[(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$T,`IM<V=I9"`B161I="!#86QE;F1A<G,B"FUS9W-T<B`B
MO7._Z*;FJ,:^Y"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3`*;7-G
M:60@(D5D:70@4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R("*]<[_HN[>ZW:;F
MJ,:^Y"(*"B,Z(&%T=&5N9&5E<RYP:'`Z,34P"FUS9VED(")%9&ET(&%T=&5N
M9&5E<R(*;7-G<W1R("*]<[_HI5BN=:1(K?LB"@HC.B!T96UP;&%T97,O8V%T
M96=O<GE?;&5G96YD+FEN8SHR,`IM<V=I9"`B161I="!C871E9V]R:65S(&%N
M9"!C;VQO<G,B"FUS9W-T<B`BO7._Z*3`P_Z[4,-#IN(B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W-B!T96UP;&%T97,O871T96YD
M965S+V%T=&5N9&5E<RYI;F,Z-#$*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,38T"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(KEQI&RV;*7S
MIF&G?2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8P
M"FUS9VED(")%;E]D(@IM<V=S='(@(K6RI_1?9"(*"B,Z(&1A=&$N<&AP.C4V
M"FUS9VED(")%;F0@1&%T92(*;7-G<W1R("*ULJ?TI.FTP2(*"B,Z('1E;7!L
M871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z."!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R
M,`IM<V=I9"`B16YD($]N(@IM<V=S='(@(K6RI_2I\R(*"B,Z(&1A=&$N<&AP
M.C4W"FUS9VED(")%;F0@5&EM92(*;7-G<W1R("*ULJ?TKLFVH2(*"B,Z(&%T
M=&5N9&5E<RYP:'`Z,3(T(&%T=&5N9&5E<RYP:'`Z,3,U(&%T=&5N9&5E<RYP
M:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<SH@)7,B"FUS9W-T<B`BM4RJ
M:\6JJ/HE<SHE<ZJZJL6VHB^FH[A,N.JP5"(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$Q,3,*;7-G:60@(D5V96YT(&%D9&5D.B(*;7-G<W1R("*HQJ7SI'>W
M<[Q7.B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,C,*;7-G:60@(D5V96YT
M(&1E;&5T960Z(@IM<V=S='(@(JC&I?.D=Z=2L*,N(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3$Q.`IM<V=I9"`B179E;G0@961I=&5D.B(*;7-G<W1R("*H
MQJ7SI'>]<[_H.B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B179E;G0@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("*HQJ7S
ML7$@)7,@J.P@)7,B"@HC.B!L:6(O1')I=F5R+G!H<#HW-C<*;7-G:60@(D5V
M96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E+B(*;7-G<W1R("*HQJ7SI;*V
MMZUNIK.D0*W3L=*I;*3IM,$N(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S,S"FUS
M9VED(")%=F5N=',@;75S="!H879E(&$@=&ET;&4N(@IM<V=S='(@(JC&I?.E
MLK:WK6ZFLZ1`K=.F5[K9+B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T
M96YD965S+FEN8SHW-@IM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(JEM
MIE?!<K3Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.3D*;7-G
M:60@(D5X<&]R="(*;7-G<W1R("*VUZ58(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`B
MMM>E6*;FJ,:^Y"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C8Y"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("*D1Z3K(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,C@*;7-G:60@(D9I;F0B"FUS
M9W-T<B`BI^2T32(*"B,Z('EE87(N<&AP.C@T('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.0HC
M.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B1G(B"FUS9W-T<B`B
MK%"TP:2M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3@Q"FUS9VED(")&<F5E
M(@IM<V=S='(@(JK%MJ(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@*
M;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("*E::7.KLFV
MH;CJL%0B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C`@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3$Y"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S
M8W)I<'0N:6YC.C<R"FUS9VED(")&<FED87DB"FUS9W-T<B`BK%"TP:2M(@H*
M(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,S"FUS9VED(")&=71U
M<F4B"FUS9W-T<B`BI=BK9:3.I4BKX2(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP
M:'`N9&ES=#HQ-PIM<V=I9"`B1V%M92(*;7-G<W1R("*Y0\"X(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C(S"FUS9VED(")'
M96YE<F%L(@IM<V=S='(@(J1`K^LB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,30P"B,L('!H<"UF;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`B
MLKZFW"`E<R(*"B,Z(&UO;G1H+G!H<#HQ,S,@=&5M<&QA=&5S+W=E96LO:&5A
M9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$P"FUS9VED(")(:61E(@IM<V=S='(@(L'TPL,B
M"@HC.B!M;VYT:"YP:'`Z,3,S('1E;7!L871E<R]W965K+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S
M:61E+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(:61E("5S(@IM<V=S
M='(@(L'TPL,E<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8U('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C$S-@IM<V=I9"`B2&]U<BAS*2(*;7-G
M<W1R("*NR2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@
M(DAO=R!L;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T:&4@9&%Y(&%N
M9"!W965K('9I97=S(&)E/R(*;7-G<W1R("*DZ;M0MF?`R[7XJKJJNK/,I'#%
MXZ7<L^:F[#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`Q"FUS9VED
M(")(;W<@;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S:&]U
M;&0@=V4@9V5N97)A=&4_(@IM<V=S='(@(L"SN-.Y[Z6\J-.RHZ7-M%BDT:K%
MMJ(OIJ.X3+CJL%2I3S\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#4P"FUS
M9VED("(B"B))9B!Y;W5R(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O<G0@
M:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@;V8@=&AE("(*(F9O;&QO
M=VEN9R!L:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N7&XB
M"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB"B)4
M;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*(EQN
M(@HB5&\@9&5C;&EN92!T:&4@979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B"B*F
M<*I'IT&JNK9LI?.^7,6JLV[%Z:2CI.2TJ2!I5&EP(+W0J$0LIT&E::C/I<ZD
M5:9#I?2D0+-SM;*HT[&UJ/RISK#[J=JHQJ7S+EQN(@HB7&XB"B*QM:C\IKFH
MQJ7S.EQN(@HB)7-<;B(*(EQN(@HBO,BNR;&UJ/RFN:C&I?,Z7&XB"B(E<UQN
M(@HB7&XB"B*P^ZG:IKFHQJ7S.EQN(@HB)7,B"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($-A
M;&5N9&%R+"!3=&5P("5D(@IM<V=S='(@(K;7I$JFYJC&ON0LJ$+&2B`E9"(*
M"B,Z(&1A=&$N<&AP.C(X.`IM<V=I9"`B26UP;W)T+T5X<&]R="!#86QE;F1A
M<B(*;7-G<W1R("*VUZ1*+[;7I5BFYJC&ON0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV.`IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("*D
M0*3K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S0*;7-G
M:60@(DIU;'DB"FUS9W-T<B`BI$.DZR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<S"FUS9VED(")*=6YE(@IM<V=S='(@(J2[I.LB"@HC
M.B!D871A+G!H<#HV-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-#(*;7-G
M:60@(DME>7=O<F1S(@IM<V=S='(@(L/VP>2F<B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R-"!H;W5R<R(*;7-G
M<W1R("*SS*KQ(#(T(*1PKLDB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHX-PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("*SS*KQI$"FN*?S
MMW,B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC
M.C0*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ
M,`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$V
M('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHT"FUS9VED("),87-T($UO;G1H
M(@IM<V=S='(@(J17K=.DZR(*"B,Z('1E;7!L871E<R]Y96%R+VAE860N:6YC
M.C0*;7-G:60@(DQA<W0@665A<B(*;7-G<W1R("*D5Z1`IGXB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-30@=&5M<&QA=&5S+W=E96LO:&5A
M9"YI;F,Z,PIM<V=I9"`B3&%S="!W965K(@IM<V=S='(@(J17I$"V9R(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,CD*;7-G:60@(DQI;6ET('1H
M92!T:6UE('-P86X@=&\@97AP;W)T.B(*;7-G<W1R("*MK:CNMM>E6*[)MJ&V
MH;EJ.B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN
M8SHX-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHW-`IM<V=I9"`B3&]?8V%T
M:6]N(@IM<V=S='(@(J9APDE?8R(*"B,Z(&1A=&$N<&AP.C8S('1E;7!L871E
M<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-0HC.B!T96UP;&%T97,O<')E
M9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHQ.`HC.B!T96UP;&%T97,O
M<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHU,B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHR,0HC.B!L:6(O1')I=F5R+G!H<#HQ.#@U"FUS9VED
M("),;V-A=&EO;B(*;7-G<W1R("*F8<))(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U"FUS9VED(")-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RXB"FUS
M9W-T<B`BNMZR>J9HK=.[M[K=IN:HQK[D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C<P"FUS9VED(")-87)C:"(*;7-G<W1R("*D5*3K
M(@H*(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-87AI;75M($YU;6)E<B!O
M9B!%=F5N=',B"FUS9W-T<B`BJ,:E\Z17K:V\QJ78(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R("*D
MK:3K(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@X,@IM<V=I9"`B364B"FUS9W-T
M<B`BI]HB"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@
M(DUE971I;F<B"FUS9W-T<B`BMWS$LR(*"B,Z(&QI8B]";&]C:R]T<F5E7V%L
M87)M<RYP:'`Z,PIM<V=I9"`B365N=2!!;&%R;7,B"FUS9W-T<B`BI=B__<2U
MI=PB"@HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU
M($QI<W0B"FUS9W-T<B`BI5ROX*KM(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,U"FUS9VED(")-
M:6YU=&4H<RDB"FUS9W-T<B`BI,#$P2(*"B,Z('EE87(N<&AP.C@P('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C4Y('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(Q-0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B
M36\B"FUS9W-T<B`BK%"TP:1`(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N
M:6YC.C$V('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-0HC.B!T96UP;&%T
M97,O961I="]J879A<V-R:7!T+FEN8SHV."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`V"FUS9VED(")-;VYD87DB"FUS9W-T<B`BK%"TP:1`(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3,Q-"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S
M='(@(J3K(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS"FUS9VED(")-;VYT
M:"!6:65W(@IM<V=S='(@(J3KP,NU^"(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI
M<W0N<&AP.C,@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#,*;7-G:60@(DUO
M;G1H;'D@179E;G1S($QI<W0B"FUS9W-T<B`BJ$.DZZC&I?.F0ZKM(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$R-@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C8@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C,R"FUS9VED(")-;VYT:&QY.B!296-U
M<G,@979E<GDB"FUS9W-T<B`BI.LZ(*A#(@H*(SH@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!!:&5A9"(*;7-G<W1R("*EO*C3
MI.N\QB(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-`IM<V=I
M9"`B36]N=&AS($)E9F]R92(*;7-G<W1R("*E2*MEI.N\QB(*"B,Z(&QI8B]A
M<&DN<&AP.C8S-`IM<V=I9"`B375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O;F5N
M=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S=7!P;W)T960N(@IM<V=S
M='(@(K5OLGNF:*W3(&E#86QE;F1A<B"DN*7S.R"VR*5UI.2TJ2!V179E;G0N
M(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C8W"FUS9VED(")->2!#86QE;F1A<G,B"FUS9W-T<B`B
MI]JJNJ;FJ,:^Y"(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHS-"!T96UP;&%T
M97,O;65N=2YI;F,Z,S8*;7-G:60@(DUY($-A;&5N9&%R<SHB"FUS9W-T<B`B
MI]JJNJ;FJ,:^Y#HB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,C`R"FUS9VED(")->2!&<F5E+T)U<WD@55),(@IM<V=S='(@(J?:
MJKJJQ;:B+Z:CN$RZ]*=](@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$Q-R!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z,34Y"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<U
M"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC
M.C$W"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N
M:6YC.C0T"FUS9VED(").86UE(@IM<V=S='(@(J97NMDB"@HC.B!L:6(O0FQO
M8VLO;6]N=&@N<&AP.C0Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0T(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HT,0HC.B!L:6(O0FQO8VLO=')E95]M96YU
M+G!H<#HR,`IM<V=I9"`B3F5W($5V96YT(@IM<V=S='(@(K=SJ,:E\R(*"B,Z
M(&QI8B]B87-E+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB3F5W
M(&-A;&5N9&%R(&-R96%T960@86YD(&%U=&]M871I8V%L;'D@<VAA<F5D('=I
M=&@@9F]L;&]W:6YG(&=R;W5P*',I.B`E<RXB"FUS9W-T<B`BMW.JNJ;FJ,:^
MY*1WJ]BGM*C#I4*Q3J;;L,JDP*C)M;FX<[+5.B`E<RXB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C,S"FUS9VED(").97AT(@IM<V=S='(@(J15
MI$"H0B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-PIM<V=I
M9"`B3F5X="`R-"!H;W5R<R(*;7-G<W1R("*EO*C3(#(T(*1PKLDB"@HC.B!L
M:6(O1D)6:65W+V1A>2YP:'`Z,CD*;7-G:60@(DYE>'0@1&%Y(@IM<V=S='(@
M(J15I$"DT2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED
M92YI;F,Z-@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N
M:6YC.C$R"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3@@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C8*;7-G:60@(DYE>'0@
M36]N=&@B"FUS9W-T<B`BI%6MTZ3K(@H*(SH@;&EB+T9"5FEE=R]W965K+G!H
M<#HS,@IM<V=I9"`B3F5X="!7965K(@IM<V=S='(@(J15I$"V9R(*"B,Z('1E
M;7!L871E<R]Y96%R+VAE860N:6YC.C8*;7-G:60@(DYE>'0@665A<B(*;7-G
M<W1R("*D5:1`IGXB"@HC.B!T96UP;&%T97,O9&%Y+VAE860N:6YC.C4*;7-G
M:60@(DYE>'0@9&%Y(@IM<V=S='(@(J15I$"DT2(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHU."!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHU
M"FUS9VED(").97AT('=E96LB"FUS9W-T<B`BI%6D0+9G(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(W-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@X
M"FUS9VED(").;R(*;7-G<W1R("*G7R(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C<S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$R-`IM<V=I9"`B
M3F\@86QA<FTB"FUS9W-T<B`BM4PB"@HC.B!T96UP;&%T97,O871T96YD965S
M+V%T=&5N9&5E<RYI;F,Z-#@*;7-G:60@(DYO(&%T=&5N9&5E<R(*;7-G<W1R
M("*H4Z:SI5BN=:1(K?LB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,P"FUS
M9VED(").;R!C86QE;F1A<G,@87)E(&%V86EL86)L92!T;R!G=65S=',N(@IM
M<V=S='(@(JA3IK.E]*;SIN:HQK[DI6FHT:C3NZNHSZ7.+B(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR-3(*;7-G:60@(DYO(&5N9"!D871E(@IM<V=S='(@(J7#N[<B"@HC.B!L
M:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M;VYT
M:&QI<W0N<&AP.C$V,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT"FUS
M9VED(").;R!E=F5N=',@=&\@9&ES<&QA>2(*;7-G<W1R("*U3*C&I?.E::C1
MQ>.EW"(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HT,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!F<F5E+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA
M8FQE(&9O<B`E<R(*;7-G<W1R("*H4Z:SP_:I\R5SJKJJNJK%MJ(OIJ.X3+CJ
ML%0B"@HC.B!L:6(O87!I+G!H<#HS-#4@;&EB+V%P:2YP:'`Z-C(T"FUS9VED
M(").;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(J?DI*.H
M["!I0V%L96YD87(@N.JNQBXB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR,#$*;7-G:60@(DYO(')E8W5R<F5N8V4B"FUS9W-T<B`BM4PB"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HY,#(*;7-G:60@(DYO('9A;&ED(&5M86EL(&%D
M9')E<W,@9F]U;F0B"FUS9W-T<B`BI^2DHZCLIK.NQ*JZN7&D;*;MIWTB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HV,3(@;&EB+TMR;VYO;&ET:"YP:'`Z-C,S
M"FUS9VED(").;VYE(@IM<V=S='(@(K5,(@H*(SH@;&EB+U-T;W)A9V4O<W%L
M+G!H<#HQ,S8*;7-G:60@(DYO="!F;W5N9"(*;7-G<W1R("*GY*2CJ.PB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(DYO=&EF:6-A=&EO
M;G,B"FUS9W-T<B`BLW&JOK_OMK4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]G;W1O+FEN8SHW.`IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BI%&D0*3K
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4V"FUS9VED(").
M;W<B"FUS9W-T<B`BLGNF8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C<W"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(J11I.LB"@HC.B!T
M96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,R!T96UP;&%T97,O
M961I="]E9&ET7W1I;65S<&%N+FEN8SHV-0IM<V=I9"`B3VXB"FUS9W-T<B`B
MJ?,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<X(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.3$*;7-G:60@(D]N(&%L;"!C86QE;F1A<G,@22!H879E
M(')E860@86-C97-S('1O(@IM<V=S='(@(JG2IK.GVJ_@Q:JH^JJZJKJFYJC&
MON0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.3`*;7-G:60@(D]N(&%L;"!S:&]W;B!C86QE;F1A<G,B
M"FUS9W-T<B`BJ=*FL\7CI=RDI*JZIN:HQK[D.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.0IM<V=I
M9"`B3VX@;7D@8V%L96YD87)S(&]N;'DB"FUS9W-T<B`BI76MK:GSI]JJNJ;F
MJ,:^Y"(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8S,`IM<V=I9"`B3W!T:6]N
M86PB"FUS9W-T<B`BJT2ELK:W(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,3$Y"FUS
M9VED(")/<'1I;VYA;"!!='1E;F1E97,B"FUS9W-T<B`BJT2ELK:WI5BN=:1(
MK?LB"@HC.B!L:6(O1D)6:65W+G!H<#HQ-30*;7-G:60@(D]V97)V:65W(@IM
M<V=S='(@(K>GQELB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHS-`IM
M<V=I9"`B3W=N97(B"FUS9W-T<B`BOM:FLZK,(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3@X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")/=VYE<CH@)7,B"FUS9W-T
M<B`BOM:FLZK,.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3$T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3DT"FUS9VED(")032(*
M;7-G<W1R("*D5:3((@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP
M.C,@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C0R"FUS9VED(")087-T
M($5V96YT<R!,:7-T(@IM<V=S='(@(KE,I6BJNJC&I?.F0ZKM(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`Y('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C$Y-@IM<V=I9"`B4&%T=&5R;B(*;7-G<W1R("*\RZ:A(@H*(SH@=&5M
M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,P"FUS9VED(")097)M86YE;G1L>2!D
M96QE=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`BI<.D6Z=2L*.FN:C&I?,_(@H*
M(SH@;&EB+V%P:2YP:'`Z,S(V(&QI8B]A<&DN<&AP.C0R,B!L:6(O87!I+G!H
M<#HT.30@;&EB+V%P:2YP:'`Z-3<T"B,Z(&QI8B]A<&DN<&AP.C8P-B!L:6(O
M87!I+G!H<#HV.3(@;&EB+V%P:2YP:'`Z-S(X"FUS9VED(")097)M:7-S:6]N
M($1E;FEE9"(*;7-G<W1R("*F<ZCZOD2IVB(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ-C<*;7-G:60@(E!E<FUI<W-I;VYS(@IM
M<V=S='(@(L5VK:TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*;7-G
M:60@(E!O<G1A;"!/<'1I;VYS(@IM<V=S='(@(JW3I$BON*5XO^^VM2(*"B,Z
M(&QI8B]&0E9I97<O9&%Y+G!H<#HR-0IM<V=I9"`B4')E=FEO=7,@1&%Y(@IM
M<V=S='(@(JMEI$"DZ2(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*;7-G
M:60@(E!R979I;W5S(%=E96LB"FUS9W-T<B`BJV6D0+9G(@H*(SH@=&5M<&QA
M=&5S+V1A>2]H96%D+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D87DB"FUS9W-T
M<B`BJV6D0*3I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,U('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(T.0IM<V=I9"`B4F5C=7(@56YT:6PB
M"FUS9W-T<B`BK:N]QJJ]J.PB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,#8*;7-G:60@(E)E8W5R<F5N8V4B"FUS9W-T<B`BK:N]QB(*"B,Z(&1A
M=&$N<&AP.C8X"FUS9VED(")296-U<G)E;F-E($1A=&$B"FUS9W-T<B`BK:N]
MQJ3IM,$B"@HC.B!D871A+G!H<#HV-@IM<V=I9"`B4F5C=7)R96YC92!%;F0@
M1&%T92(*;7-G<W1R("*MJ[W&NDFD[J3I(@H*(SH@9&%T82YP:'`Z-C<*;7-G
M:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`BK:N]QK:AN6HB"@HC
M.B!D871A+G!H<#HV-0IM<V=I9"`B4F5C=7)R96YC92!4>7!E(@IM<V=S='(@
M(JVKO<:KK+I!(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30X"FUS9VED(")2
M96-U<G,@9&%I;'DB"FUS9W-T<B`BJ$.DZ:VKO<8B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HU-34*;7-G:60@(E)E8W5R<R!M;VYT:&QY(@IM<V=S='(@(JA#
MI.NMJ[W&(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34Q"FUS9VED(")296-U
M<G,@=V5E:VQY(@IM<V=S='(@(JA#MF>MJ[W&(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-34X"FUS9VED(")296-U<G,@>65A<FQY(@IM<V=S='(@(JA#IGZM
MJ[W&(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296UI;F1E<CH@)7,B"FUS9W-T<B`BM*._]#H@
M)7,B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.3$@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T"FUS9VED(")296UO=&4@0V%L96YD
M87)S(@IM<V=S='(@(KNWNMVFYJC&ON0B"@HC.B!T96UP;&%T97,O;65N=2YI
M;F,Z-C`@=&5M<&QA=&5S+VUE;G4N:6YC.C8R"FUS9VED(")296UO=&4@0V%L
M96YD87)S.B(*;7-G<W1R("*[M[K=IN:HQK[D.B(*"B,Z('1E;7!L871E<R]A
M='1E;F1E97,O871T96YD965S+FEN8SHU,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296UO=F4@)7,B"FUS9W-T<B`BLKZPHR`E<R(*"B,Z(&%T=&5N9&5E<RYP
M:'`Z,3`T"FUS9VED(")296UO=F4@071T96YD964B"FUS9W-T<B`BLKZPHZ58
MKG6D2*W[(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,0IM<V=I
M9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O
M<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L
M;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SXB
M"FUS9W-T<B`B(@HBI4BVUZ1*JKJFYJC&ON2X;;2KIG.F8JJZIN:HQK[D/R`\
M<W1R;VYG/L2UIVDZ(+-OL4ZW?*=2L*.EV*MEIN:HQK[DI*2JNJG2IK.L]B(*
M(K_]+CPO<W1R;VYG/B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8S-PIM<V=I
M9"`B4F5Q=6ER960B"FUS9W-T<B`BI;*VMZUN(@H*(SH@;&EB+T9"5FEE=RYP
M:'`Z.3@@;&EB+T9"5FEE=RYP:'`Z,3,Y(&QI8B]&0E9I97<N<&AP.C$T,B!L
M:6(O1D)6:65W+G!H<#HQ-#4*;7-G:60@(E)E<75I<F5D($%T=&5N9&5E<R(*
M;7-G<W1R("*ELK:WI5BN=:1(K?LB"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHS,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#@*;7-G:60@(E)E
M<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(JVKLUVF7J2ZJ7>MR"(*"B,Z('1E
M;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,R!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ-C8*;7-G:60@(E)E<W!O;G-E(@IM<V=S='(@(J9>
MPM`B"@HC.B!Y96%R+G!H<#HX-2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C`*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(JQ0M,&DNR(*
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,2!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI
M;F,Z-S,*;7-G:60@(E-A='5R9&%Y(@IM<V=S='(@(JQ0M,&DNR(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ.3(*;7-G:60@(E-A
M=F4B"FUS9W-T<B`BP'BF<R(*"B,Z('9I97=E=F5N="YP:'`Z,3,S(&5D:71E
M=F5N="YP:'`Z-#D@961I=&5V96YT+G!H<#HU-PIM<V=I9"`B4V%V92!!<R!.
M97<B"FUS9W-T<B`BI72F<[=SP,DB"@HC.B!T96UP;&%T97,O871T96YD965S
M+V%T=&5N9&5E<RYI;F,Z.#0*;7-G:60@(E-A=F4@071T96YD965S(@IM<V=S
M='(@(L!XIG.D2*W[(@H*(SH@861D979E;G0N<&AP.C4U(&5D:71E=F5N="YP
M:'`Z-3(*;7-G:60@(E-A=F4@179E;G0B"FUS9W-T<B`BP'BF<ZC&I?,B"@HC
M.B!S96%R8V@N<&AP.CDQ('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHQ,30*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C8W
M('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHX"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,30P(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C(V"FUS9VED(")396%R8V@B"FUS9W-T<B`BMVJT32(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ"FUS9VED(")396%R8V@@
M0V%L96YD87)S(@IM<V=S='(@(K=JM$VFYJC&ON0B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-@IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS
M9W-T<B`BMVJT3;6RJD<B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C
M:"YI;F,Z-@IM<V=I9"`B4V5A<F-H(&9O<B!C86QE;F1A<G,@8V]N=&%I;FEN
M9SHB"FUS9W-T<B`BMVJT3:;FJ,:^Y*5=IW0Z(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U,`IM<V=I9"`B4V5L96-T(&$@8V%L
M96YD87(@=&\@961I="(*;7-G<W1R("*_[[[<K6Z]<[_HJKJFYJC&ON0B"@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-C4@=&5M<&QA=&5S+V5D:70O
M961I=%]T:6UE<W!A;BYI;F,Z,S$*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T
M:6UE<W!A;BYI;F,Z.#,*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B
MO^^^W*1`K=.DZ;3!(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"FUS9VED
M(")396QE8W0@8V%L96YD87)S('1O(&1I<W!L87DZ(@IM<V=S='(@(K_OOMRM
M;L7CI=RJNJ;FJ,:^Y#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*
M;7-G:60@(B(*(E-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O
M(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E("(*(F1E
M9F%U;'0@=FEE=RXB"FUS9W-T<B`BO^^^W*9PIO/%XZ7<IE6ZV*2CIE"JNL#+
MM?BE2*3.I+JI=ZJZP,NU^"(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,3@*;7-G:60@(E-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O
M.B(*;7-G<W1R("*_[[[<IN:HQK[DI4BVUZ1*N.JNQJCL.B(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,3D*;7-G:60@(E-E;&5C="!T:&4@8V%L
M96YD87(H<RD@=&\@97AP;W)T(&9R;VTB"FUS9W-T<B`BO^^^W*UNMM>E6*JZ
MIN:HQK[D(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I
M9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R("*_[[[<MM>E
M6*[FIJ$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR-PIM<V=I
M9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`BO^^^W,#)
MKM>E2+;7I$JXZJ[&.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*
M;7-G:60@(E-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3HB"FUS9W-T<B`BO^^^
MW*A#MF>JNK+$I$"DT3HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z(@IM<V=S='(@(K_OOMRHT[>]P,FNUZJZJKJNYJ:A.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.#0*;7-G:60@(E-E;&5C="!T:&4@=&EM92!S
M<&%N('1O('-H;W<Z(@IM<V=S='(@(KW0O^^^W*[)MJ&]9+/RI4C%XZ7<(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED(")396QE8W0@=&AE
M('9I97<@=&\@9&ES<&QA>2!O;B!S=&%R='5P.B(*;7-G<W1R("*_[[[<M6ZD
M2JOAJKJJNL#+M?BDZ*IK.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,@IM<V=I9"`B4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H92!P
M;W)T86PN(@IM<V=S='(@(K_OOMRESJC3Q>.EW*GSK=.D2*^XI7BDI*JZJ,:E
M\RXB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C<@=&5M<&QA=&5S
M+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED(")396YD(&$@8V%N8V5L(&YO
M=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@=&AI
M<R!E=F5N="(*;7-G<W1R("*W[:C&I?.S4:=2L*.KX:%!ML>P9:1`K=.H^J[X
MLW&JOK6YJ=*FLZ58KG6D2*W[(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E-E;F0@86X@96UA:6P@=&\@
M)7,B"FUS9W-T<B`BML>P9:1`J\JV;*7SM;D@)7,B"@HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHQ-SD*;7-G:60@(E-E;F0@=7!D871E<R]I;G9I=&%T
M:6]N<R!T;R!A;&P@871T96YD965S('=H96X@<V%V:6YG('1H:7,@979E;G0B
M"FUS9W-T<B`BM^VHQJ7SLU'`>*9SJ^&A0;;'L&6D0*W3I_.W<R_!W+W0LW&J
MOK6YJ=*FLZ58KG6D2*W[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-S8*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("*D1:3K(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.#,*;7-G:60@(E-E
M="!E;F0@9&%T92(*;7-G<W1R("*S7:EWM;*G]*3IM,$B"@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR-C4*;7-G:60@(E-E="!R96-U<G)E;F-E(&5N
M9"!D871E(@IM<V=S='(@(K-=J7>MJ[W&NDFD[J3I(@H*(SH@=&5M<&QA=&5S
M+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,S$*;7-G:60@(E-E="!S=&%R="!D
M871E(@IM<V=S='(@(K-=J7>V?:ELI.FTP2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU.0IM<V=I9"`B(@HB4V5T('EO=7(@9G)E92]B=7-Y(&-A;&5N
M9&%R<R!A;F0@>6]U<B!O=VX@86YD(&]T:&5R('5S97)S)R!F<F5E+V)U<WD@
M;W!T:6]N<RXB"FUS9W-T<B`BLUVI=Z;;I':ISJ5,I$BJNJK%MJ(OIJ.X3+_O
MMK4N(@H*(SH@8V%L96YD87)S+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")3:&%R92!N;W0@9F]U;F0Z("5S(@IM<V=S='(@(J?DI*.H[*9`J,DZ)7,B
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-SD*;7-G
M:60@(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T<B`BID"HR:;FJ,:^Y"(*"B,Z
M('1E;7!L871E<R]M96YU+FEN8SHT-R!T96UP;&%T97,O;65N=2YI;F,Z-#D*
M;7-G:60@(E-H87)E9"!#86QE;F1A<G,Z(@IM<V=S='(@(JG2IK.F0*C)JKJF
MYJC&ON0Z(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H<#HR-2!T96UP;&%T97,O
M=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC.B!T96UP;&%T97,O9&%Y
M+VAE861?<VED95]B>5]S:61E+FEN8SHS"FUS9VED(")3:&]W($-A;&5N9&%R
M(@IM<V=S='(@(L7CI=RFYJC&ON0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34V"FUS9VED(")3:&]W(&-A=&5G;W)Y(&QE9V5N9#\B"FUS9W-T<B`B
MQ>.EW*3`P_ZJNK7YL$^[H:GZ(#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30V"FUS9VED(")3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E
M;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R("*F8J;FJ,:^
MY,#+M?BU9:VQI*3%XZ7<IU*PHRS$M:7<I4BDSJVKPM"V9[3!N<^EW+;</R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(E-H;W<@9'5E
M('1A<VMS(&EN('1H92!C86QE;F1A<C\B"FUS9W-T<B`BIF*FYJC&ON2DI,7C
MI=RKW;_LJ,:VM3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38V"FUS
M9VED(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S='(@(L7CI=RJQ;:B
M+Z:CN$RJNK7YL$^[H:GZ(#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C`S"FUS9VED(")3:&]W(&]N;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R
M;2!S970_(@IM<V=S='(@(J5UQ>.EW*:SLUVI=\2UI=RG0*7.JKJHQJ7S/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S4*;7-G:60@(E-H;W<@<VAA
M<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_(@IM<V=S='(@(JC#ID/%XZ7<
MID"HR:JZIN:HQK[D(#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q
M"FUS9VED(")3:&]W('1A<VMS('5S:6YG(&-A=&5G;W)Y(&-O;&]R<S\B"FUS
M9W-T<B`BI4BDP,/^JKK#0Z;BQ>.EW*O=O^RHQK:U/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B4VAO=R!T:6UE(&]F(&1A>2!B971W
M965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_(@IM<V=S='(@(J9BMF?`R[7X
MJKJU9:VQI*3%XZ7<J$.D0*31JKJNR;:A(#\B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHQ,0IM<V=I9"`B4W1A7W)T(@IM<V=S='(@
M(K9]J6RI\U]R(@H*(SH@9&%T82YP:'`Z-30*;7-G:60@(E-T87)T($1A=&4B
M"FUS9W-T<B`BL=*I;*3IM,$B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT
M7VAE861E<G,N:6YC.C<@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#$*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS-PIM<V=I9"`B4W1A<G0@3VXB
M"FUS9W-T<B`BMGVI;*GS(@H*(SH@9&%T82YP:'`Z-34*;7-G:60@(E-T87)T
M(%1I;64B"FUS9W-T<B`BL=*I;*[)MJ$B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z.30@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z.#,*;7-G:60@(E-T871?=7,B"FUS9W-T<B`BJJRZ05]U(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHV('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C(W"FUS9VED(")3=&%T=7,B"FUS9W-T<B`BJJRZ02(*
M"B,Z('EE87(N<&AP.C<X('EE87(N<&AP.C@W('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8U"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R
M,2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-R!L:6(O0FQO8VLO;6]N=&@N<&AP
M.C$P.0IM<V=I9"`B4W4B"FUS9W-T<B`BK%"TP:31(@H*(SH@=&5M<&QA=&5S
M+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR
M,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA=&5S+V5D
M:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(JQ0M,&DT2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`BJ]V_
M[*C&MK4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.#4@;&EB+TMR;VYO;&ET
M:"YP:'`Z-C`X"FUS9VED(")496YT871I=F4B"FUS9W-T<B`BO,BNR2(*"B,Z
M('EE87(N<&AP.C@S('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8R
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.`HC.B!L:6(O0FQO8VLO;6]N
M=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS9W-T<B`BK%"TP:5\(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW,`IM<V=I9"`B5&AE($5D
M:70@071T96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N="X@17AI
M=&EN9RXB"FUS9W-T<B`BO7._Z,'<O="JNK5EK;&D=Z2CIG.F8BX@PO>V?:2D
M+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&-A;&5N9&%R(%PB)7-<(B!C86YN;W0@8F4@9&5L971E9"XB"FUS9W-T
M<B`BIN:HQK[D(%PB)7-<(B"U3*IKLU&G4K"C+B(*"B,Z(&-A;&5N9&%R<RYP
M:'`Z-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<
M(B!H87,@8F5E;B!C<F5A=&5D+B(*;7-G<W1R("*FYJC&ON0@7"(E<UPB(*1W
MJ]BEWRXB"@HC.B!C86QE;F1A<G,N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`BIN:HQK[D(%PB)7-<(B"D=Z=2L*,N(@H*(SH@8V%L96YD87)S+G!H
M<#HU-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB
M(&AA<R!B965N(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("*FYJC&ON0@
M7"(E<UPB(*1WI_.F5ZRP(%PB)7-<(BXB"@HC.B!C86QE;F1A<G,N<&AP.C4V
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(J;FJ,:^Y"!<(B5S7"(@I'?`>*9S+B(*
M"B,Z(&1A=&$N<&AP.C(S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L
M96YD87(@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`BIKFFYJC&
MON2U3*IKLU&R3:K%.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I
M<'0N:6YC.C$V,PIM<V=I9"`B5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@
M=&AA;B!T:&4@<W1A<G0@9&%T92XB"FUS9W-T<B`BM;*G]*3IM,&ELKO=I&JI
M\[9]J6RDZ;3!+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,30*;7-G:60@
M(B(*(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@861D960@=&\@7"(E<UPB
M(&-A;&5N9&%R+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`BJ?.D
MZ;3!("4S)',LKLFVH2`E)#1S(*JZJ,:E\R!<(B4Q)'-<(B"D=[=SO%>H[*;F
MJ,:^Y"!<(B4R)'-<(B"DI"XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3(T
M"FUS9VED("(B"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960@
M9G)O;2!<(B5S7"(@8V%L96YD87(L('=H:6-H('=A<R!O;B`E<R!A="`E(@HB
M<RXB"FUS9W-T<B`BJ?.DZ;3!("4S)',LKLFVH2`E)#1S(*JZJ,:E\R!<(B4Q
M)'-<(B"D=Z;;IN:HQK[D(%PB)3(D<UPB(*2DIU*PHRXB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,3$Y"FUS9VED("(B"B)4:&4@979E;G0@7"(E<UPB(&AA
M<R!B965N(&5D:71E9"!O;B!<(B5S7"(@8V%L96YD87(L('=H:6-H(&ES(&]N
M("5S(&%T("5S+B(*;7-G<W1R("*I\Z3IM,$@)3,D<RRNR;:A("4D-',@IN:H
MQK[D(%PB)3(D<UPBI*2JNJC&I?,@7"(E,21S7"(@I'>]<[_HI[FFJ"(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$P.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@<W5C8V5S<V9U;&QY
M('-E;G0N(@IM<V=S='(@(K6Y)7.JNJC&I?.S<:J^I'>FJ*5<JKJP9:58+B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-#0*;7-G:60@(E1H92!F;VQL;W=I
M;F<@:7,@82!M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N
M=#HB"FUS9W-T<B`BP_:I\Z:YJ,:E\Z5(I%6FLZ?SN-2RTZJZL=2M>CHB"@HC
M.B!A='1E;F0N<&AP.C0Q"FUS9VED("(B"B)4:&4@<F5Q=65S="!W87,@:6YC
M;VUP;&5T92X@4V]M92!P87)A;65T97)S('1H870@87)E(&YE8V5S<V%R>2!T
M;R!A8V-E<'0@;W(@(@HB9&5C;&EN92!A;B!E=F5N="!A<F4@;6ES<VEN9RXB
M"FUS9W-T<B`BO="H1*E\I;RGN::H+B"Q_;&UJ/RISK#[J=JHQJ7SN]VM;J1`
MJ,>ELK:WL-&\QBXB"@HC.B!T96UP;&%T97,O<V5A<F-H+V5M<'1Y+FEN8SHS
M"FUS9VED(")4:&5R92!A<F4@;F\@979E;G1S(&UA=&-H:6YG('1H92!C=7)R
M96YT(&-R:71E<FEA+B(*;7-G<W1R("*H4Z:SJ,:E\[+%IEBS;ZW3MVJT3;?'
MJV@N(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C$X(&5D:71E=F5N=&%C=&EO
M;BYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S(@IM<V=S='(@(J9SJ/JF
MYJC&ON0Z("5S(*[)M6^ES:1`K=._^;M^+B(*"B,Z(&%D9&5V96YT86-T:6]N
M+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@861D:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`BMW.\5ZC&I?,Z("5S
M(*[)M6^ES:1`K=._^;M^+B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I
M;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R("*]<[_HJ,:E\SH@)7,@KLFU;Z7-
MI$"MT[_YNWXN(@H*(SH@;&EB+V%P:2YP:'`Z,S,Y(&QI8B]A<&DN<&AP.C8Q
M.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(K;7I$H@:4-A;&5N9&%R(+CJKL:NR;5O
MI<VD0*W3O_F[?BXB"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C8S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@=&AE
M(&5V96YT.B`E<R(*;7-G<W1R("*W:+*^J,:E\SH@)7,@KLFU;Z7-I$"MT[_Y
MNWXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DR"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO
M=&EF:6-A=&EO;B!T;R`E<SH@)7,B"FUS9W-T<B`BML>P9:C&I?.S<:J^M;D@
M)7,Z("5S(*[)M6^ES:1`K=._^;M^(@H*(SH@9&%T82YP:'`Z,3`X"FUS9VED
M(")4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N(@IM<V=S='(@(JA3
MIK.HQJ7SI6FVUZ58+B(*"B,Z(&1A=&$N<&AP.C$X-PIM<V=I9"`B5&AI<R!F
M:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("*FN<#)KM>N
MYJ:AJ,.EO+-1I.2TJ2XB"@HC.B!D871A+G!H<#HR-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS
M9W-T<B`BIOBJ0;ZYIE[`LSH@)7,B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A
M9"YI;F,Z,3D@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$X"B,Z('1E;7!L
M871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<Q"FUS9VED(")4:'5R<V1A>2(*
M;7-G<W1R("*L4+3!I7PB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z,S<*;7-G:60@(E1I;64@4W!?86XB"FUS9W-T<B`BKLFVH;UDL_)?82(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C0*;7-G:60@
M(E1I;64@<W!A;B(*;7-G<W1R("*NR;:AO62S\B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHS-"!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHS.`IM<V=I9"`B5&ET7VQE(@IM<V=S='(@(JC&I?.F5[K97VPB
M"@HC.B!D871A+G!H<#HU,R!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M,C`*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHS"FUS
M9VED(")4:71L92(*;7-G<W1R("*HQJ7SIE>ZV2(*"B,Z(&QI8B]";&]C:R]P
M<F5V;6]N=&AL:7-T+G!H<#HQ,C(@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z
M,3(Q"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,C<*;7-G:60@(E1O9&%Y
M(@IM<V=S='(@(J2UI-$B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP
M:'`Z,3(T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$R,PHC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3(Y"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("*I
M^J31(@H*(SH@>65A<BYP:'`Z.#$@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-C`@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$V"B,Z(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")4=2(*;7-G<W1R("*L4+3!I$<B
M"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3<@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3$V"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N
M:6YC.C8Y"FUS9VED(")4=65S9&%Y(@IM<V=S='(@(JQ0M,&D1R(*"B,Z(&-O
M;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B5'EP92(*;7-G<W1R
M("*KK*:A(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$X,PIM<V=I9"`B55),(@IM<V=S='(@(KKTIWTB"@HC.B!L:6(O4W1O<F%G
M92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+B(*;7-G<W1R("*U3*IKLW.ULJ;<(%-13""F^*I!OKDN(@H*(SH@
M8V%L96YD87)S+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`BM4RJ:Z=2L*,@7"(E<UPB
M.B`E<R(*"B,Z(&QI8B]$<FEV97(O;6-A;"YP:'`Z,3,T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E("5S+B(*;7-G<W1R("*U3*IKIU*PHR`E<RXB"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(K5,JFNX
M_*1*("5S(*JZJ7>X<;CJKL8N(@H*(SH@8V%L96YD87)S+G!H<#HU,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%PB)7-<(CH@)7,B
M"FUS9W-T<B`BM4RJ:Z?SIE<@7"(E<UPB.B`E<R(*"B,Z(&QI8B]3=&]R86=E
M+VMO;&%B+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G<W1R
M("*U3*IKQ:JH^B5SJKJJQ;:B+Z:CN$RXZK!4(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,34*(SH@<V-R:7!T<R]U<&=R861E<R\R,#`T+3`U+3$Y
M7V-O;G9E<G1?8V%T96=O<FEE<U]T;U]S=')I;F=S+G!H<#HU,PIM<V=I9"`B
M56YF:6QE9"(*;7-G<W1R("*EO*3`P_XB"@HC.B!L:6(O87!I+G!H<#HS-S<@
M;&EB+V%P:2YP:'`Z-#8Q(&QI8B]A<&DN<&AP.C4S-R!L:6(O87!I+G!H<#HV
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4
M>7!E.B`E<R(*;7-G<W1R("*EO*3DM*FJNJ2ZKF6KK+I!.B`E<RX@*%5N<W5P
M<&]R=&5D($-O;G1E;G0M5'EP92XI(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3`S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D.B`E<RXB"FUS9W-T
M<B`BI'>G\[=S.B`E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*
M;7-G:60@(E5S97(@26YT97)F86-E(@IM<V=S='(@(JC/I<ZJS*2VK;$B"@HC
M.B!Y96%R+G!H<#HQ-C`@>65A<BYP:'`Z,38V(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,34Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,38R"FUS9VED(")6:65W($1A
M>2(*;7-G<W1R("*DZ<#+M?@B"@HC.B!Y96%R+G!H<#HX,B!T96UP;&%T97,O
M:F%V87-C<FEP="]G;W1O+FEN8SHV,2!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR,3<*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E=E(@IM
M<V=S='(@(JQ0M,&D5"(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ
M."!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3<*(SH@=&5M<&QA=&5S+V5D
M:70O:F%V87-C<FEP="YI;F,Z-S`*;7-G:60@(E=E9&YE<V1A>2(*;7-G<W1R
M("*L4+3!I%0B"@HC.B!A='1E;F1E97,N<&AP.C$Q,B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,S$S(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(S"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*;7-G<W1R("*V9R(*
M"B,Z(&UO;G1H+G!H<#HQ-S<@=V]R:W=E96LN<&AP.C,P('=E96LN<&AP.C,T
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E96L@)60B"FUS9W-T<B`BJ5`@)60B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU.2!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ,S@*;7-G:60@(E=E96LH<RDB"FUS9W-T<B`BMF<B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C$R"FUS9VED(")7965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G
M<W1R("*V9SH@J$,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS
M9VED("(B"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E
M;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\B"FUS9W-T<B`B
MI.F[4+9GJKJULJ3NQ>.EW*[)MJ&A2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,34*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W
M965K('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V
M96YT<S\B"FUS9W-T<B`BI.F[4+9GJKJQTJELQ>.EW*[)MJ&A2"(*"B,Z(&%T
M=&5N9&5E<RYP:'`Z,3$Q(&QI8B]+<F]N;VQI=&@N<&AP.C$S,3(@;&EB+T)L
M;V-K+W1R965?;65N=2YP:'`Z,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@T"FUS9VED(")7;W)K(%=E96LB"FUS9W-T<B`BI%>O6J3I(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3,Q-2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR
M-0IM<V=I9"`B665A<B(*;7-G<W1R("*F?B(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S@*;7-G
M:60@(EEE87)L>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(J9^.B"H0R(*"B,Z
M(&1A=&$N<&AP.C,Y(&1A=&$N<&AP.C(S.2!E9&ET979E;G1A8W1I;VXN<&AP
M.C0V(&%D9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@979E;G1S
M+B(*;7-G<W1R("*G0:A3IK.KV*7?ME>Y3"`E9""MTZC&I?.JNL5VK:TN(@H*
M(SH@871T96YD+G!H<#HT.0IM<V=I9"`B66]U(&%R92!N;W0@86X@871T96YD
M964@;V8@=&AE('-P96-I9FEE9"!E=F5N="XB"FUS9W-T<B`BIT&HPZ2CK$^K
M_*EWJ,:E\ZJZP=R]T*1(K?LN(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHW-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T:&ES(&9O
M<FT@9G)O;2!T:&4@161I="!!='1E;F1E97,@<V-R965N+B(*;7-G<W1R("*Q
M<;USO^C!W+W0I$BM^[5EK;&DI*=!I76OX*C/I<ZS;ZW3JNVSYBXB"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HY.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1O(&YO="!H879E(&%N(&5M86EL(&%D9')E<W,@8V]N9FEG=7)E9"!I
M;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T:6]N("(*(D]P=&EO;G,N(%EO=2!M
M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F;W)E(&5V96YT(&YO=&EF:6-A=&EO
M;G,@8V%N(&)E('-E;G0N(@IM<V=S='(@(B(*(J9BIT&JNJBMI,##T:=/O^^V
MM:2DJ,.EO+-=J7>Y<:1LMFRE\Z;MIWTNIT&ELK:WI?VV::;F)7.S7:EW)7.D
M?J_@ML>P9:C&I?.S<2(*(JJ^+B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HR
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES
M<VEO;B!T;R!A9&0@979E;G1S('1O("5S+B(*;7-G<W1R("*G0:C#J%.FL[=S
MO%>HQJ7SJ.P@)7,@JKK%=JVM+B(*"B,Z(&1A=&$N<&AP.C$Y-PIM<V=I9"`B
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R!T
M:&4@<V5L96-T960@8V%L96YD87(N(@IM<V=S='(@(J=!J,.H4Z:SQ7:MK2RF
M8JG2O^^^W*JZIN:HQK[DI%>W<[Q7J,:E\RXB"@HC.B!D96QE=F5N=&%C=&EO
M;BYP:'`Z,C8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M(&1E;&5T92!T:&ES(&5V96YT+B(*;7-G<W1R("*G0:C#J%.FL\5VK:VG4K"C
MIKFHQJ7S+B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z-S@*;7-G:60@(EEO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="XB
M"FUS9W-T<B`BIT&HPZA3IK.]<[_HIKFHQJ7SJKK%=JVM+B(*"B,Z(&1A=&$N
M<&AP.C$Y,@IM<V=I9"`B66]U(&AA=F4@<W!E8VEF:65D(&%N(&EN=F%L:60@
M8V%L96YD87(N(@IM<V=S='(@(J=!I'>X9ZO\J7>D0*W3I*.F6*IKJKJFYJC&
MON0N(@H*(SH@871T96YD+G!H<#HR,0IM<V=I9"`B66]U(&AA=F4@<W5C8V5S
M<V9U;&QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS
M9W-T<B`BIT&D=Z:HI5RQM:C\IJBLL*:YJ,:E\ZJZI5BN=:1(K?LN(@H*(SH@
M871T96YD+G!H<#HR-@IM<V=I9"`B66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E
M8VQI;F5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`BIT&D
M=Z:HI5RP^ZG:IJBLL*:YJ,:E\ZJZI5BN=:1(K?LN(@H*(SH@871T96YD+G!H
M<#HS,0IM<V=I9"`B66]U(&AA=F4@=&5N=&%T:79E;'D@86-C97!T960@871T
M96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R("*G0:1WO,BNR;&UJ/RF
MJ*RPIKFHQJ7SJKJE6*YUI$BM^RXB"@HC.B!C86QE;F1A<G,N<&AP.CDQ"FUS
M9VED(")9;W4@;75S="!S96QE8W0@82!C86QE;F1A<B!T;R!B92!D96QE=&5D
M+B(*;7-G<W1R("*G0:6RMK>E_;_OOMRD0*W3K6ZG4K"CJKJFYJC&ON0N(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHU-`IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(JVZ
MI?VG0:6RMK>E_;_OOMRD0*W3IF&G?2XB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,3$T"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H
M96X@979E;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T
M<B`BP+.G0:JZK6ZH1"RH0[?MIT&JNJ;FJ,:^Y+-1MW.\5ZC&I?.NR;5OL&6S
M<:J^+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,C0*;7-G:60@(B(*(EEO
M=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&1E
M;&5T960@9G)O;2!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`BP+.G0:JZK6ZH
M1"RH0[?MIT&JNJ;FJ,:^Y+-1IU*PHZC&I?.NR;5OL&6S<:J^+B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$Q,3D*;7-G:60@(EEO=2!R97%U97-T960@=&\@
M8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R(&-A
M;&5N9&%R<RXB"FUS9W-T<B`BP+.G0:JZK6ZH1"RH0[?MIT&JNJ;FJ,:^Y+-1
MO7._Z*C&I?.NR;5OL&6S<:J^+B(*"B,Z(&QI8B]38VAE9'5L97(O:W)O;F]L
M:71H+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<75E<W1E
M9"!T;R!B92!R96UI;F1E9"!A8F]U="`E<RP@=VAI8V@@:7,@;VX@)7,@870@
M)7,N(@IM<V=S='(@(K2CO_2G0:9BI.FTP3HE,B1S(*[)MJ$Z)3,D<R"JNJ[)
MK=0LIK.D0*W3IN:HQK[DJ,:E\R`E,21S(+6EJ]V_[+)Z+B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*;7-G:60@(EEO=7(@9&5F
M875L="!C86QE;F1A<B(*;7-G<W1R("*G0:JZN7>S7:;FJ,:^Y"(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C$P-3@@;&EB+T1R:79E<BYP:'`Z,3`V.`IM<V=I9"`B
M6U5N;F%M960@979E;G1=(@IM<V=S='(@(ENEO*E2IE>JNJC&I?-=(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z.34*;7-G:60@(E]!;&%R;2(*;7-G
M<W1R("+$M:7<7T$B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z,3$*;7-G:60@(E]"87-I8R!396%R8V@B"FUS9W-T<B`BL/*E
MN[=JM$U?0B(*"B,Z('9I97=E=F5N="YP:'`Z,3,U"FUS9VED(")?161I="(*
M;7-G<W1R("*]<[_H7T4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S4P"FUS
M9VED(")?1V]T;R(*;7-G<W1R("*ROJ;<7T<B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,S4V"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R("*VUZ1*
M+[;7I5A?22(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S<*;7-G:60@(E]-
M>2!#86QE;F1A<G,B"FUS9W-T<B`BI]JJNJ;FJ,:^Y%]-(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,T-`IM<V=I9"`B7TYE=R!%=F5N="(*;7-G<W1R("*W
M<ZC&I?-?3B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-C$*;7-G:60@(E]0
M<FEN="(*;7-G<W1R("*F0Z9,7U`B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,S4R"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(K=JM$U?4R(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$S-#<*;7-G:60@(E]4;V1A>2(*;7-G<W1R("*DM:31
M7U0B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#`*;7-G:60@(F)E
M9F]R92!T:&4@979E;G0@<W1A<G1S(@IM<V=S='(@(JGSJ,:E\[9]J6RK92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G
M<W1R("*DZ2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,#<*;7-G:60@(F1A>2AS*2(*;7-G<W1R
M("*DZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#8@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$X-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@X
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y,`IM<V=I9"`B9&%Y<R(*;7-G<W1R("*DZ2(*"B,Z(&1A=&$N
M<&AP.C$U,"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(F5V
M96YT<RYC<W8B"FUS9W-T<B`BIN:HQK[D+F-S=B(*"B,Z(&1A=&$N<&AP.C$W
M,0IM<V=I9"`B979E;G1S+FEC<R(*;7-G<W1R("*FYJC&ON0N:6-S(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,S$*;7-G:60@(F9R
M;VTB"FUS9W-T<B`BL7$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(R-R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S,*
M;7-G:60@(FUO;G1H*',I(@IM<V=S='(@(J3K(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")O;B`E<R!A="`E<R(*
M;7-G<W1R("*I\R5SKLFVH25S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-PIM<V=I9"`B;VX@
M=&AE('-A;64@9&%T92(*;7-G<W1R("*F8J90I$"DT2(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,S,*;7-G:60@(F]N('1H92!S86UE('=E96MD87DB"FUS9W-T<B`BIF*H0[9G
MJKJRQ*1`I-$B"@HC.B!D871A+G!H<#HR.2!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$T"FUS9VED(")V0V%L96YD87(O:4-A;&5N9&%R(@IM<V=S='(@
M(G9#86QE;F1A<B]I0V%L96YD87(B"@HC.B!L:6(O87!I+G!H<#HS-3`@;&EB
M+V%P:2YP:'`Z-C(Y"FUS9VED(")V179E;G0@;F]T(&9O=6YD+B(*;7-G<W1R
M("*GY*2CJ.P@=D5V96YT+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3$*;7-G:60@(G=E96LB"FUS9W-T<B`BMF<B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$T"FUS
M9VED(")W965K*',I(&]N.B(*;7-G<W1R("*V9SHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DR(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y-`IM<V=I9"`B=V5E:W,B"FUS9W-T
M<B`BMF<B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C,Y"FUS9VED(")Y96%R*',I(@IM<V=S='(@
M(J9^(@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI
M=&@O<&\O:'5?2%4N<&\`````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,3,V,C0S`#$P-#$W,S8R-S4R`#`R,#0S,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C($MR;VYO;&ET:"!(=6YG
M87)I86X@=')A;G-L871I;VX@9FEL92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#(M
M,C`P-B!,87-Z;&\@3"X@5&]R;F]C:0HC(%1H:7,@9FEL92!I<R!D:7-T<FEB
M=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!+<F]N;VQI=&@@
M<&%C:V%G92X*(R!,871E<W0@=F5R<VEO;G,Z(&9T<#HO+WAE;FEA+G-O=&4N
M:'4O<'5B+VQI;G5X+VAO<F1E+PHC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!+<F]N;VQI=&@@,BXQ7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#8M,#(M,3<@,3`Z,#`K,#$P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-BTP,BTQ."`Q,#HT-"LP,3`P7&XB"B),87-T+51R86YS
M;&%T;W(Z($QA<WIL;R!,+B!4;W)N;V-I(#QT;W)L87-Z0'AE;FEA+G-O=&4N
M:'4^7&XB"B),86YG=6%G92U496%M.B!(=6YG87)I86X@/&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR7&XB"B)#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+W-E87)C:"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@8V%L96YD87)S(&9O=6YD(@IM<V=S='(@(B5D(&YA<'3A<G0@=&%LX6QT
M=6YK(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@979E;G1S(@IM<V=S='(@(B5D(&5L9F]G;&%L
M='/A9R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!$87DH<RD@)7,@2&]U<BAS*2`E
M<R!-:6YU=&5S(@IM<V=S='(@(B5S(&YA<"`E<R#S<F$@)7,@<&5R8R(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$X,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M871T96YD965S(@IM<V=S='(@(B5S('+I<WIT=F5V]2(*"B,Z(&1A=&$N<&AP
M.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL
M>2!I;7!O<G1E9"(*;7-G<W1R(")!("5S(&;A:FP@:6UP;W)TX6SA<V$@<VEK
M97)E<V5N(&UE9W3V<G3I;G0B"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O
M8F%S92YP:'`Z,3(X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD
M87(B"FUS9W-T<B`B)7,@;F%P=.%R82(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N9&%R
M(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@
M=&AE(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(B"B(H2V%T=&EN='-O;B!A
M(&YA<'3A<B!N97;I<F4L(&$@9O5A8FQA:V)A;B!V86SS(&UE9VIE;&5N[73I
M<R!B92T@:6QL+B`B"B)K:6MA<&-S;VSA<^%H;WHI+B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38U"FUS9VED("(J($%D9"!T:&5S
M92!B>2!C;&EC:VEN9R!!9&0@*B(*;7-G<W1R("(J($%Z($]+(&=O;6)R82!K
M871T:6YT=F$@861J=6L@:&]Z>N$@97IE:V5T("HB"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$U,0IM<V=I9"`B*B!0;&5A<V4@<V5L
M96-T(&%D9')E<W,H97,I("HB"FUS9W-T<B`B*B!+Z7)J_&L@=N%L87-S>F]N
M(&/M;2AE:REE="`J(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@P-@IM<V=I9"`B
M,2!A='1E;F1E92(*;7-G<W1R("(Q('+I<WIT=F5V]2(*"B,Z('1E;7!L871E
M<R]S96%R8V@O:&5A9&5R+FEN8SHT"FUS9VED("(Q(&5V96YT(@IM<V=S='(@
M(C$@96QF;V=L86QT<^%G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-PIM<V=I9"`B,2!H;W5R(@IM<V=S='(@(C$@\W)A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-`IM<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R("(Q
M-2!P97)C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B
M,C`@;6EN=71E<R(*;7-G<W1R("(R,"!P97)C(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-@IM<V=I9"`B,S`@;6EN=71E<R(*;7-G<W1R("(S,"!P
M97)C(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,38Y"FUS9VED("(\
M<W1R;VYG/D%T=&5N9&5E<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@
M(CQS=')O;F<^4NES>G1V97;U:SPO<W1R;VYG/B`H;W!C:6]NX6QI<RDB"@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#<*;7-G:60@(CQS=')O;F<^
M1&5S8W)I7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T
M<F]N9SY,9>URX7,\+W-T<F]N9SX@*&]P8VEO;N%L:7,I(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C<T"FUS9VED("(\<W1R;VYG/DME>7=O<F1S
M/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9SY+=6QC<W-Z
M879A:SPO<W1R;VYG/B`H;W!C:6]NX6QI<RDB"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ.3(*;7-G:60@(CQS=')O;F<^4F5C=7)R96YC93PO<W1R
M;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQS=')O;F<^27-MZ71L]63I<SPO
M<W1R;VYG/B`H;W!C:6]NX6QI<RDB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$Q,R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y,PIM<V=I
M9"`B04TB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C`R"FUS
M9VED(")!8V-E<'1E9"(*;7-G<W1R(")E;&9O9V%D=F$B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z,3$*;7-G:60@(D%D7W9A;F-E9"!396%R
M8V@B"FUS9W-T<B`B4NES>FQE=&5S(&ME<F5SZ7,B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V,`IM<V=I9"`B061D(@IM<V=S='(@
M(D)E=FET96PB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,@IM<V=I
M9"`B061D($5V96YT(@IM<V=S='(@(MIJ(&5L9F]G;&%L='/A9R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C,U"FUS
M9VED(")!9&0@82!N97<@4F5M;W1E($-A;&5N9&%R(@IM<V=S='(@(MIJ('3A
M=F]L:2!N87!TX7(@:&]Z>N%A9.%S82(*"B,Z(&%D9&5V96YT+G!H<#HV-`IM
M<V=I9"`B061D(&$@;F5W(&5V96YT(@IM<V=S='(@(MIJ(&5L9F]G;&%L='/A
M9R!B9>URX7-A(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C<Q"FUS9VED(")!9&0@871T96YD965S(@IM<V=S='(@(E+I<WIT=F5V
M]6L@:&]Z>N%A9.%S82(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3@U"FUS9VED(")!9&0@=&\@871T96YD965S(@IM<V=S='(@(D%D
M:G5K(&$@<NES>G1V97;U:VCV>B(*"B,Z(&-O;G1A8W1S+G!H<#HW-B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$R.`HC.B!T96UP;&%T97,O
M871T96YD965S+V%T=&5N9&5E<RYI;F,Z-S0*;7-G:60@(D%D9')E<W,@0F]O
M:R(*;7-G<W1R(")#[6UJ96=Y>NEK(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS9W-T<B`B4NES>FQE
M=&5S(&ME<F5SZ7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU,PIM
M<V=I9"`B06QA<FTB"FUS9W-T<B`B1FEG>65L;65Z=&5TZ7,B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ-S@R"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D
M(&1A>7,@8F5F;W)E(@IM<V=S='(@(D9I9WEE;&UE>G1E=.ES("5D(&YA<'!A
M;"!E;/5T=&4B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@W"B,L('!H<"UF;W)M
M870*;7-G:60@(D%L87)M("5D(&AO=7)S(&)E9F]R92(*;7-G<W1R(")&:6=Y
M96QM97IT973I<R`E9"#S<N%V86P@96SU='1E(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!M:6YU=&5S
M(&)E9F]R92(*;7-G<W1R(")&:6=Y96QM97IT973I<R`E9"!P97)C8V5L(&5L
M]71T92(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B06QA<FT@)60@=V5E:W,@8F5F;W)E(@IM<V=S='(@(D9I9WEE;&UE
M>G1E=.ES("5D(&CI='1E;"!E;/5T=&4B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M-S@Q"FUS9VED(")!;&%R;2`Q(&1A>2!B969O<F4B"FUS9W-T<B`B1FEG>65L
M;65Z=&5TZ7,@,2!N87!P86P@96SU='1E(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<X-@IM<V=I9"`B06QA<FT@,2!H;W5R(&)E9F]R92(*;7-G<W1R(")&:6=Y
M96QM97IT973I<R`Q(/-RX79A;"!E;/5T=&4B"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-SDQ"FUS9VED(")!;&%R;2`Q(&UI;G5T92!B969O<F4B"FUS9W-T<B`B
M1FEG>65L;65Z=&5TZ7,@,2!P97)C8V5L(&5L]71T92(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W-S8*;7-G:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T
M<B`B1FEG>65L;65Z=&5TZ7,@,2!HZ71T96P@96SU='1E(@H*(SH@9&%T82YP
M:'`Z-3D*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T<B`B02!F:6=Y96QM97IT
M973I<R!DX71U;6$B"@HC.B!D871A+G!H<#HU.`IM<V=I9"`B06QA<FT@4W!A
M;B`H;6EN=71E<RDB"FUS9W-T<B`B02!F:6=Y96QM97IT973I<R!I9/5T87)T
M86UA("AP97)C*2(*"B,Z(&1A=&$N<&AP.C8P"FUS9VED(")!;&%R;2!4:6UE
M(@IM<V=S='(@(D$@9FEG>65L;65Z=&5TZ7,@:61E:F4B"@HC.B!T96UP;&%T
M97,O9&5L971E+V1E;&5T92YI;F,Z,S0*;7-G:60@(D%L;"(*;7-G<W1R(")A
M>B#V<W-Z97-E="(*"B,Z(&QI8B]&0E9I97<N<&AP.C$R."!L:6(O1D)6:65W
M+G!H<#HQ,S$@;&EB+T9"5FEE=RYP:'`Z,3,T"FUS9VED(")!;&P@071T96YD
M965S(@IM<V=S='(@(D%Z(/9S<WIE<R!RZ7-Z='9E=O4B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z-3D*;7-G:60@(D%L;"!&=71U<F4B"FUS
M9W-T<B`B;6EN9&5N(&$@:O9V]6)E;B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHU,PIM<V=I9"`B06QL(%!A<W0B"FUS9W-T<B`B;6EN9&5N
M(&$@;?IL=&)A;B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR
M-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C(T"B,Z(&QI8B]";&]C:R]M;VYT:&QI
M<W0N<&AP.C(W(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B06QL
M(%9I<VEB;&4B"FUS9W-T<B`B07H@]G-S>F5S(&SA=&AA=/,B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,C(@;&EB+T1A>59I97<N
M<&AP.CDP(&QI8B]$87E6:65W+G!H<#HY,PHC.B!L:6(O5V5E:U9I97<N<&AP
M.C$R-R!L:6(O5V5E:U9I97<N<&AP.C$S-"!L:6(O1')I=F5R+G!H<#HQ.#8Y
M"FUS9VED(")!;&P@9&%Y(@IM<V=S='(@(F5GZ7-Z(&YA<"(*"B,Z(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@979E;G0B"FUS
M9W-T<B`B16?I<WIN87!O<R!E;&9O9VQA;'1SX6<B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C,S"FUS9VED(")!;&P@979E;G1S(@IM<V=S='(@
M(D%Z(/9S<WIE<R!E;&9O9VQA;'1SX6<B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#@*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C<P(&QI8B]+<F]N;VQI=&@N<&AP.C8Y-0IM
M<V=I9"`B06YY(@IM<V=S='(@(F+A<FUE;'EI:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!<')I;"(*;7-G<W1R("+A
M<')I;&ES(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M,SD@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX,B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$V.`IM<V=I9"`B070B"FUS9W-T<B`B("(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$P-#8*;7-G:60@(B(*(D%T=&%C:&5D(&ES(&%N(&E#86QE
M;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@979E
M;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I<"!R97%U
M97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P9&%T92`B
M"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G<W1R("(B"B)-
M96QLZ6ME;'1E;B!T86SA;&AA=/,@96=Y(&E#86QE;F1A<B#A;&QO;>%N>2P@
M;65L>2!T;W;A8F)I(&EN9F]R;>%C:?-V86P@(@HB<WIO;&?A;"!A>B!E<V5M
MZ6YY<O5L+B!!;65N;GEI8F5N(&%Z(-9N(&QE=F5L97KU<')O9W)A;6IA('3A
M;6]G871J82!A>B!I5&EP("(*(FOI<NES96ME="P@86MK;W(@82!M96QLZ6ML
M970@<V5G[71SZ6?I=F5L(&OV;FYY96X@9G)I<W/M=&AE=&D@82!E<V5MZ6YY
M("(*(G-A:N%T(&YA<'3A<N%B86X@;&5V]2!PZ6QDX6YYX6YA:R!A9&%T86ET
M+B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C4*;7-G:60@(D%T=&5N9&%N8V4B
M"FUS9W-T<B`B365G:F5L96[I<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$V,0IM<V=I9"`B071T96YD965S(@IM<V=S='(@(E+I<WIT=F5V]6LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-0IM<V=I9"`B
M075G=7-T(@IM<V=S='(@(F%U9W5S>G1U<R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,2!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z.`IM<V=I9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(DME<F5S
MZ7,B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D)I
M<G1H9&%Y(@IM<V=S='(@(E-Z_&QE=.ES;F%P(@H*(SH@;&EB+T9"5FEE=RYP
M:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$Q"FUS9VED(")"=7-Y(@IM<V=S='(@
M(D5L9F]G;&%L="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHT,@IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S='(@(DYA<'3A<B(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0W"FUS9VED(")#86Q?96YD
M87(B"FUS9W-T<B`B3F%P=.%R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C$T.2!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z
M,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HR,2!L:6(O0FQO8VLO;6]N=&AL
M:7-T+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(DYA<'3A<B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HS"FUS9VED(")#86QE;F1A<B!3=6UM87)Y(@IM<V=S='(@(DYA<'3A
M<B#V<W-Z969O9VQA;/,B"@HC.B!D871A+G!H<#HR,S,*;7-G:60@(D-A;&5N
M9&%R('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(D$@;F%P=.%R="!S
M:6ME<F5S96X@=/9R]FQT_&LN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W"FUS9VED(")#
M86QE;F1A<G,B"FUS9W-T<B`B3F%P=.%R86LB"@HC.B!C86QE;F1A<G,N<&AP
M.C(W"FUS9VED(")#86QE;F1A<G,@;75S="!H879E(&$@;F%M92XB"FUS9W-T
M<B`B02!N87!TX7)N86L@;F5V970@:V5L;"!A9&YI+B(*"B,Z(&1A=&$N<&AP
M.C(T.`IM<V=I9"`B0V%N)W0@8W)E871E(&$@;F5W(&5V96YT+B(*;7-G<W1R
M(").96T@;&5H971SZ6=E<R#Z:B!E;&9O9VQA;'1SX6<@8F5V:71E;&4N(@H*
M(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,S('1E;7!L871E<R]D96QE
M=&4O9&5L971E+FEN8SHS-0HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS
M,2!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#<*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R(")-Z6=S92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4W.`IM<V=I
M9"`B0V%N8V5L;&5D(@IM<V=S='(@(F5L;6%R860B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D-A;F-E;&QE9#H@
M)7,B"FUS9W-T<B`B16QM87)A9#H@)7,B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z-C,@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z-C<*;7-G:60@(D-A=&5G;W)?>2(*;7-G<W1R(")+871E9_-R:6$B"@HC
M.B!D871A+G!H<#HV,B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N
M:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*;7-G:60@(D-A=&5G
M;W)Y(@IM<V=S='(@(DMA=&5G\W)I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-SD*;7-G:60@(B(*(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N
M;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S(&)Y
M("(*(F5M86EL.B(*;7-G<W1R("(B"B)6X6QA<W-Z82!K:2P@:&]G>2!KZ7(M
M92!E;6%I;&)E;B!T]G)TZ6[U(.ER=&5S[73I<W0@87H@^FHL(&WS9&]S[71O
M='0L('9A9WD@(@HB=/9R]FQT(&5L9F]G;&%L='/A9V]K<O-L.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W
M86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E
M9"!E=F5N=',N(@IM<V=S='(@(B(*(DUE9V%D:&%T:F$L(&AO9WD@:^ER+64@
MZ7)T97/M=.ES="!A>B#Z:BP@;?-D;W/M=&]T="P@=F%G>2!T]G+V;'0@(@HB
M96QF;V=L86QT<^%G;VMR\VPN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Y,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O(')E8V5I=F4@96UA
M:6P@<F5M:6YD97)S(&9O<B!E=F5N=',@=VET:"!A;&%R;7,Z(@IM<V=S='(@
M(B(*(E;A;&%S<WIA(&MI+"!H;V=Y(&OI<BUE(&O\;/9N(&5M86EL8F5N('3V
M<G3I;O4@:F5L>NES="!A>F]K<O-L(&%Z("(*(F5L9F]G;&%L='/A9V]K<O-L
M+"!M96QY96MH97H@9FEG>65L;65Z=&5TZ7,@=F%N(')E;F1E;'9E.B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96%R8VA?86)O;VM?<V5L96-T+FEN8SHQ.2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$R"FUS9VED(")#:&]O<V4@=&AE(&%D
M9')E<W,@8F]O:W,@=&\@<V5A<F-H(&9O<B!F<F5E+V)U<WD@55),<SHB"FUS
M9W-T<B`B365L>6EK(&/M;6IE9WEZZ6ME:V)E;B!K97)E<W/\:R!A(&UE9VCM
M=F]T=&%K(&ED]6)E;W-Z=.%S:2!54DPM:NET.B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]F8E]C86QS7W-E;&5C="YI;F,Z,38*;7-G:60@(D-H;V]S92!T:&4@
M8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXZ(@IM<V=S='(@(DUE;'D@;F%P=.%R(&%D871A:2!J96QE;FIE;F5K
M(&UE9R!A>B#6;B!N>6EL=N%N;W,@:63U8F5O<WITX7/A8F%N.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C0*;7-G:60@(D-H;V]S92!T:&4@8V%L
M96YD87)S('1O(&EN8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!5
M4DQS.B(*;7-G<W1R(")-96QY:6L@8^UM:F5G>7KI:V5K8F5N(&ME<F5S<_QK
M(&$@;65G:.UV;W1T86L@:63U8F5O<WITX7-I(%523"UJZ70Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")#:&]O<V4@>6]U<B!D969A
M=6QT(&-A;&5N9&%R+B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A>B#6;B!A;&%P
MZ7)T96QM97KI<R!S>F5R:6YT:2!N87!TX7)JX70B"@HC.B!T96UP;&%T97,O
M871T96YD965S+V%T=&5N9&5E<RYI;F,Z.#0*;7-G:60@(D-L96%R(&%L;"!A
M='1E;F1E97,B"FUS9W-T<B`B5/9R]FQJ_&L@87H@]G-S>F5S(&UE9VCM=F]T
M=&%T(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*
M;7-G:60@(D-L;W-E('=I;F1O=R(*;7-G<W1R(")!>B!A8FQA:R!B97KA<N%S
M82(*"B,Z(&1A=&$N<&AP.C(X('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B5F5S
M<WKU=F5L(&5L=N%L87-Z=&]T="#I<G3I:V5K(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<S"FUS9VED(")#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT
M<S\B"FUS9W-T<B`B07H@96QF;V=L86QT<^%G;VL@=/9R;.ES96MO<B!K[7;A
M;B!K_&SV;B!M96=E<O5S[73I<W0_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-3<U"FUS9VED(")#;VYF:7)M960B"FUS9W-T<B`B8FEZ=&]S(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(Q-PIM<V=I9"`B0V]P
M>2!T:&4@55),(&)E;&]W(&9O<B!U<V4@=VAE<F5V97(@>6]U(&YE960@>6]U
M<B!&<F5E+T)U<WD@55),.B(*;7-G<W1R(")!;B#6;B!N>6EL=N%N;W,@:63U
M8F5O<WITX7-A(&%Z(&%LX6)B:2!54DPM96X@Z7)H973U(&5L.B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B)7,@;F5M(&YY:71H873S(&UE9RXB
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3(Y"FUS
M9VED(")#<F5A=&4B"FUS9W-T<B`B3.ET<F5H;WKA<R(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,34*;7-G:60@(D-R96%T92!#
M86QE;F1A<B(*;7-G<W1R("+::B!N87!TX7(@;.ET<F5H;WKA<V$B"@HC.B!M
M;VYT:"YP:'`Z,38S('1E;7!L871E<R]W965K+VAE860N:6YC.C(U('1E;7!L
M871E<R]D87DO<F]W+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O
M1&%Y5FEE=RYP:'`Z,3DU"FUS9VED(")#<F5A=&4@82!.97<@179E;G0B"FUS
M9W-T<B`BVFH@96QF;V=L86QT<^%G(&)E=FET96QE(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z.#`*;7-G:60@(D-R96%T960B"FUS9W-T<B`B3.ET
M<F5H;WIV82(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS,@IM
M<V=I9"`B0W5R<F5N="(*;7-G<W1R(")*96QE;FQE9VDB"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C`V"FUS9VED(")$86EL>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(FYA<&]N
M=&$Z(&UI;F1E;B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`V(&QI8B]+<F]N;VQI
M=&@N<&AP.C$S,3$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R"FUS9VED(")$87DB"FUS9W-T<B`B;F%P
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,3,W"FUS9VED(")$87DH<RDB"FUS9W-T<B`B;F%P(@H*
M(SH@=FEE=V5V96YT+G!H<#HQ,3$*;7-G:60@(D1E7VQE=&4B"FUS9W-T<B`B
M5/9R;.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-SD*
M;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E8V5M8F5R(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z-C`U"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")E;'5T
M87/M=&]T=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<*;7-G:60@
M(D1E9F%U;'0@0V%L96YD87(B"FUS9W-T<B`B07H@86QA<.ER=&5L;65ZZ7,@
M<WIE<FEN=&D@;F%P=.%R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C(P-"!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S(*(SH@
M=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,C,@
M;&EB+T1R:79E<BYP:'`Z,3@U,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E3V
M<FSI<R(*"B,Z(&1E;&5V96YT+G!H<#HT,"!T96UP;&%T97,O9&5L971E+V]N
M92YI;F,Z,C$@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(Q"B,Z(&QI
M8B]$<FEV97(N<&AP.C$X-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M("5S(@IM<V=S='(@(B5S('3V<FSI<V4B"@HC.B!E9&ET979E;G0N<&AP.C<R
M"FUS9VED(")$96QE=&4@179E;G0B"FUS9W-T<B`B07H@96QF;V=L86QT<^%G
M('3V<FSI<V4B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S`*
M;7-G:60@(B(*(D1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T:&ES
M(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@(@HB
M86QL(&]C8W5R96YC97,_(@IM<V=S='(@(B(*(D-S86L@97IT(&%Z(&5L9F]G
M;&%L='/A9V]T('3V<O9L:OQK+"!V86=Y(&5Z="#I<R!A>B#V<W-Z97,@:O9V
M]6)E;&ET+"!V86=Y("(*(G!E9&EG(&%Z(/9S<WIE<V5T+"!I9/5P;VYT=/-L
M(&;\9V=E=&QE;OQL/R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHQ,#,@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X
M"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B3&7M<N%S(@H*(SH@9&%T
M82YP:'`Z-C$@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W
M.`HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHY-@IM<V=I9"`B1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B3&7M<N%S(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ-S0*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B365G
M:F5L96[M=.ES(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C8S"FUS9VED(")$:7-P;&%Y($-A;&5N9&%R<R(*;7-G<W1R(").87!T
MX7)A:R!M96=J96QE;NUTZ7-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(DUE9VIE
M;&5N[73I<VD@8F7A;&SM=.%S;VLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`*;7-G:60@(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@
M87)E(&1U92!O;B!Y;W5R(&-A;&5N9&%R/R(*;7-G<W1R(")!(&AA=.%R:63U
M<R!F96QA9&%T;VL@:7,@:F5L96YJ96YE:R!M96<@82!N87!TX7)B86X_(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30U"FUS9VED(")$;V5S(&YO="!R96-U
M<B(*;7-G<W1R(")N96T@:7-MZ71L]61I:R(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$=64Z("5S(@IM<V=S='(@
M(DAA=.%R:63U.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B365D9&EG('1A
M<G0B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<S
M(&QI8B]$<FEV97(N<&AP.C$X,S8*;7-G:60@(D5D:70B"FUS9W-T<B`B3?-D
M;W/M=.%S(@H*(SH@961I=&5V96YT+G!H<#HS,R!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,B!L:6(O1')I=F5R+G!H<#HQ.#,U"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@)7,B"FUS9W-T<B`B)7,@;?-D;W/M=.%S82(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C$X-0IM<V=I9"`B161I="!!='1E;F1E
M97,B"FUS9W-T<B`B02!RZ7-Z='9E=O5K(&WS9&]S[73A<V$B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30S"FUS9VED(")%9&ET
M($-A;&5N9&%R<R(*;7-G<W1R(").87!TX7)A:R!M\V1O<^UTX7-A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,`IM<V=I9"`B161I="!296UO=&4@
M0V%L96YD87)S(@IM<V=S='(@(E3A=F]L:2!N87!TX7)A:R!B9>%L;.UTX7-A
M(@H*(SH@871T96YD965S+G!H<#HQ-#8*;7-G:60@(D5D:70@871T96YD965S
M(@IM<V=S='(@(D$@<NES>G1V97;U:R!M\V1O<^UTX7-A(@H*(SH@=&5M<&QA
M=&5S+V-A=&5G;W)Y7VQE9V5N9"YI;F,Z,C`*;7-G:60@(D5D:70@8V%T96=O
M<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(DMA=&5G\W)IX6L@Z7,@<WKM;F5I
M:R!VX6QT;WIT873A<V$B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$W-R!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z
M-#$*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38T"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D5M86EL(&/M;2(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C8P"FUS9VED(")%;E]D(@IM<V=S='(@
M(E;I9R(*"B,Z(&1A=&$N<&AP.C4V"FUS9VED(")%;F0@1&%T92(*;7-G<W1R
M(")!(&)E9F5J97KI<R!DX71U;6$B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V
M96YT7VAE861E<G,N:6YC.C@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#<*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,C`*;7-G:60@(D5N9"!/
M;B(*;7-G<W1R(")6Z6=Z]61I:R(*"B,Z(&1A=&$N<&AP.C4W"FUS9VED(")%
M;F0@5&EM92(*;7-G<W1R(")!(&)E9F5J97KI<R!I9&5J92(*"B,Z(&%T=&5N
M9&5E<RYP:'`Z,3(P(&%T=&5N9&5E<RYP:'`Z,3,Q(&%T=&5N9&5E<RYP:'`Z
M,3,X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<SH@)7,B"FUS9W-T<B`B3F5M('-I
M:V5R_&QT(&UE9W1U9&YI("5S(&ED]6)E;W-Z=.%SX70Z("5S(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3$Q,PIM<V=I9"`B179E;G0@861D960Z(@IM<V=S
M='(@(MIJ(&5L9F]G;&%L='/A9SHB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,3(S"FUS9VED(")%=F5N="!D96QE=&5D.B(*;7-G<W1R(")!>B!E;&9O9VQA
M;'1SX6<@=/9R;/5D]G1T.B`B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$X
M"FUS9VED(")%=F5N="!E9&ET960Z(@IM<V=S='(@(D%Z(&5L9F]G;&%L='/A
M9R!M\V1O<W5L=#HB"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5V96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B)7,@
MZ7,@)7,@:_9Z]G1T:2!E;&9O9VQA;'1SX6=O:R(*"B,Z(&QI8B]$<FEV97(O
M<W%L+G!H<#HS-S,*;7-G:60@(D5V96YT(&YO="!F;W5N9"(*;7-G<W1R(")!
M>B!E;&9O9VQA;'1SX6<@;F5M('1A;.%L:&%T\R(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C<W,`IM<V=I9"`B179E;G1S(&UU<W0@:&%V92!A('-T87)T(&1A=&4N
M(@IM<V=S='(@(D%Z(&5L9F]G;&%L='/A9VAO>B!DX71U;6]T(&ME;&P@<F5N
M9&5L;FDN(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S,V"FUS9VED(")%=F5N=',@
M;75S="!H879E(&$@=&ET;&4N(@IM<V=S='(@(D%Z(&5L9F]G;&%L='/A9VYA
M:R!E;&YE=F5ZZ7-T(&ME;&P@861N:2XB"@HC.B!T96UP;&%T97,O871T96YD
M965S+V%T=&5N9&5E<RYI;F,Z-S4*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G
M<W1R(")!(&/M;7+I<WIL970@=&5L:F5S<^D@96?I<WKM=.ES92(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3DY"FUS9VED(")%>'!O<G0B"FUS
M9W-T<B`B17AP;W)TX6SA<R(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z.`IM<V=I9"`B17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(DYA<'3A<B!E
M>'!O<G3A;.%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z
M-CD*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(F9E8G)UX7(B"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$S,PIM<V=I9"`B1FEN9"(*
M;7-G<W1R(")+97)E<W/\:R(*"B,Z('EE87(N<&AP.C@T('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(Q.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B1G(B"FUS
M9W-T<B`B4.DB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.#$*;7-G:60@(D9R
M964B"FUS9W-T<B`B4WIA8F%D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4X"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B16QF
M;V=L86QT<^%G:2!I;F9O<FWA8VGS(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C(P('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q.0HC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,@IM<V=I9"`B1G)I9&%Y(@IM
M<V=S='(@(G#I;G1E:R(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN
M8SHS,PIM<V=I9"`B1G5T=7)E(@IM<V=S='(@(DKV=O4B"@HC.B!C;VYF:6<O
M:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D=A;64B"FUS9W-T<B`B2N%T
MZ6LB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z
M,C,*;7-G:60@(D=E;F5R86PB"FUS9W-T<B`BP6QT86SA;F]S(&%D871O:R(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1V]T;R`E<R(*;7-G<W1R(")59W+A<R!I9&4Z("5S(@H*(SH@;6]N
M=&@N<&AP.C$S,R!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M,3`*;7-G:60@(DAI9&4B"FUS9W-T<B`B3F4@;75T87-S<W5K(@H*(SH@;6]N
M=&@N<&AP.C$S,R!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&ED92`E<R(*;7-G<W1R(").92!M
M=71A<W-U:R`E<RUT(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C4@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,V"FUS9VED(")(;W5R*',I(@IM
M<V=S='(@(O-R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G
M:60@(DAO=R!L;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T:&4@9&%Y
M(&%N9"!W965K('9I97=S(&)E/R(*;7-G<W1R(")!(&YA<&D@Z7,@:&5T:2!N
MZ7IE=&5K8F5N(&UI;'EE;B!H;W-S>OH@:63U96=Y<^EG96L@<WIE<F5P96QJ
M96YE:S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`Q"FUS9VED(")(
M;W<@;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S:&]U;&0@
M=V4@9V5N97)A=&4_(@IM<V=S='(@(DCA;GD@;F%P<F$@96SU<F4@:^ES>NUT
M<_QN:R!I9/5B96]S>G3A<VD@:6YF;W)MX6-I\W0_(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B))9B!Y;W5R
M(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O<G0@:51I<"!R97%U97-T<R!Y
M;W4@8V%N('5S92!O;F4@;V8@=&AE("(*(F9O;&QO=VEN9R!L:6YK<R!T;R!A
M8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N7&XB"B)<;B(*(E1O(&%C8V5P
M="!T:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V
M96YT('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*(EQN(@HB5&\@9&5C;&EN92!T
M:&4@979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B"B)(82!A(&+V;F?I<WKU<')O
M9W)A;6IA(&YE;2!TX6UO9V%T:F$@87H@:51I<"!KZ7+I<V5K970L(&%K:V]R
M(&%Z(&%LX6)B:2`B"B)S>O9V96=E:R!K]GK\;"!A(&UE9V9E;&5L]7)E(&MA
M='1I;G1V82!D]FYT:&5T(&$@;65G:.UVX7,@96QF;V=A9.%SX7+S;"Y<;B(*
M(EQN(@HB02!M96=H[7;A<R!E;&9O9V%DX7-A.EQN(@HB)7-<;B(*(EQN(@HB
M02!M96=H[7;A<R!F96QTZ71E;&5S(&5L9F]G863A<V$Z7&XB"B(E<UQN(@HB
M7&XB"B)!(&UE9VCM=N%S('9I<W-Z875T87/M=.%S83I<;B(*(B5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="!#86QE;F1A<BP@4W1E<"`E9"(*;7-G<W1R(").87!TX7(@
M:6UP;W)TX6SA<RP@)60N(&SI<.ES(@H*(SH@9&%T82YP:'`Z,C@X"FUS9VED
M("));7!O<G0O17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(DYA<'3A<B!I;7!O
M<G3A;.%S82]E>'!O<G3A;.%S82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S='(@(FIA;G7A<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<T"FUS9VED(")*
M=6QY(@IM<V=S='(@(FKZ;&EU<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C<S"FUS9VED(")*=6YE(@IM<V=S='(@(FKZ;FEU<R(*"B,Z
M(&1A=&$N<&AP.C8T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T,@IM<V=I
M9"`B2V5Y=V]R9',B"FUS9W-T<B`B2W5L8W-S>F%V86LB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z-34*;7-G:60@(DQA<W0@,C0@:&]U<G,B
M"FUS9W-T<B`B87H@96QM^FQT(#(T(/-R82(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C@W"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(E5T
M;VQS\R!M\V1O<^UTX7,B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C0*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ,`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y
M7W-I9&4N:6YC.C$V('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHT"FUS9VED
M("),87-T($UO;G1H(@IM<V=S='(@(DWZ;'0@:/-N87`B"@HC.B!T96UP;&%T
M97,O>65A<B]H96%D+FEN8SHT"FUS9VED("),87-T(%EE87(B"FUS9W-T<B`B
M;?IL="#I=B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-"!T
M96UP;&%T97,O=V5E:R]H96%D+FEN8SHS"FUS9VED("),87-T('=E96LB"FUS
M9W-T<B`B;?IL="!HZ70B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C(Y"FUS9VED("),:6UI="!T:&4@=&EM92!S<&%N('1O(&5X<&]R=#HB"FUS
M9W-T<B`B2V]R;.%T;WIZ=6L@87H@97AP;W)TX6QA;F3S(&%D871O:R!I9/5I
M;G1E<G9A;&QU;>%T.B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHX-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHW-`IM<V=I
M9"`B3&]?8V%T:6]N(@IM<V=S='(@(DAE;'DB"@HC.B!D871A+G!H<#HV,R!T
M96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C4*(SH@=&5M<&QA
M=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,3@*(SH@=&5M
M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-3(@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C$*(SH@;&EB+T1R:79E<BYP:'`Z,3@X
M-@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B2&5L>2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-0IM<V=I9"`B36%N86=E(')E;6]T92!C86QE;F1A
M<G,N(@IM<V=S='(@(E3A=F]L:2!N87!TX7)A:R!K97IE;.ES92XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,`IM<V=I9"`B36%R8V@B
M"FUS9W-T<B`B;>%R8VEU<R(*"B,Z(&QI8B]A<&DN<&AP.C$P,`IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@179E;G1S(@IM<V=S='(@(D%Z(&5L9F]G;&%L
M='/A9V]K(&UA>&EMX6QI<R!S>N%M82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<R"FUS9VED(")-87DB"FUS9W-T<B`B;>%J=7,B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ.#@S"FUS9VED(")-92(*;7-G<W1R("+);B(*
M"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B365E=&EN
M9R(*;7-G<W1R(")-96=B97-ZZ6SI<R(*"B,Z(&QI8B]";&]C:R]T<F5E7V%L
M87)M<RYP:'`Z,PIM<V=I9"`B365N=2!!;&%R;7,B"FUS9W-T<B`B1FEG>65L
M;65Z=&5TZ7-E:R(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C,*;7-G
M:60@(DUE;G4@3&ES="(*;7-G<W1R(")-96[\;&ES=&$B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHV."!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M,S4*;7-G:60@(DUI;G5T92AS*2(*;7-G<W1R(")P97)C(@H*(SH@>65A<BYP
M:'`Z.#`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-3D@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C$U"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,3`U"FUS9VED(")-;R(*;7-G<W1R(")(Z2(*"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D+FEN8SHQ-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,34*(SH@
M=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C@@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-@IM<V=I9"`B36]N9&%Y(@IM<V=S='(@(FCI=&;U(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q-"!L:6(O0FQO8VLO=')E95]M96YU
M+G!H<#HR-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO;G1H
M(@IM<V=S='(@(FCS;F%P(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS"FUS
M9VED(")-;VYT:"!6:65W(@IM<V=S='(@(DAA=FD@;65G:F5L96[M=.ES(@H*
M(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL
M:7-T+G!H<#HT,PIM<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R
M(")!>B!E;&9O9VQA;'1SX6=O:R!H879I(&QI<W3A:F$B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,S(*;7-G:60@(DUO;G1H;'DZ(%)E8W5R<R!E=F5R
M>2(*;7-G<W1R(")H879O;G1A.B!I<VWI=&SU9&EK(&UI;F1E;B(*"B,Z(&QI
M8B]";&]C:R]M;VYT:&QI<W0N<&AP.C(T"FUS9VED(")-;VYT:',@06AE860B
M"FUS9W-T<B`B:/-N87!O:VMA;"!E;/5R92(*"B,Z(&QI8B]";&]C:R]P<F5V
M;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS($)E9F]R92(*;7-G<W1R
M(")H\VYA<'!A;"!K;W+A8F)A;B(*"B,Z(&QI8B]A<&DN<&AP.C8S-`IM<V=I
M9"`B375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@
M;VYE('9%=F5N="!I<R!S=7!P;W)T960N(@IM<V=S='(@(B(*(E3V8F(@:4-A
M;&5N9&%R(&MO;7!O;F5N<R!V86X@:F5L96X[(&-S86L@96=Y('9%=F5N="!H
M87-Z;N%L871A('3A;6]G871O='0N(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C<P"FUS9VED(")-
M>2!#86QE;F1A<G,B"FUS9W-T<B`B07H@Z6X@;F%P=.%R86EM(@H*(SH@=&5M
M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M96YU+FEN8SHS-@IM<V=I
M9"`B37D@0V%L96YD87)S.B(*;7-G<W1R(")!>B#I;B!N87!TX7)A:6TZ(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(Q,PIM<V=I
M9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R("))9/5B96]S>G3A<VD@=V5B
M(&/M;65M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$R,"!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,38R"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V"B,Z('1E;7!L
M871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$W"B,Z('1E
M;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C0T"FUS
M9VED(").86UE(@IM<V=S='(@(D[I=B(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z-#$@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#0@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C0Q"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(P"FUS
M9VED(").97<@179E;G0B"FUS9W-T<B`BVFH@96QF;V=L86QT<^%G(@H*(SH@
M;&EB+V)A<V4N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B).97<@
M8V%L96YD87(@8W)E871E9"!A;F0@875T;VUA=&EC86QL>2!S:&%R960@=VET
M:"!F;VQL;W=I;F<@9W)O=7`H<RDZ("5S+B(*;7-G<W1R("(B"B+::B!N87!T
MX7)T(&AO>G1U;FL@;.ET<F4L(&UE;'D@875T;VUA=&EK=7-A;B!K]GKV<R!H
M87-Z;N%L871B82!K97+\;"!A("(*(FOV=F5T:V5Z]2!C<V]P;W)T;VMK86PZ
M("5S+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S,*;7-G:60@
M(DYE>'0B"FUS9W-T<B`B2_9V971K97KU(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@
M(F$@:_9V971K97KU(#(T(/-R82(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR
M.0IM<V=I9"`B3F5X="!$87DB"FUS9W-T<B`B;>%S;F%P(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHV"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S
M+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ."!T96UP;&%T97,O;6]N
M=&@O:&5A9"YI;F,Z-@IM<V=I9"`B3F5X="!-;VYT:"(*;7-G<W1R(")+]G9E
M=&ME>O4@:/-N87`B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C,R"FUS9VED
M(").97AT(%=E96LB"FUS9W-T<B`B:_9V971K97KU(&CI="(*"B,Z('1E;7!L
M871E<R]Y96%R+VAE860N:6YC.C8*;7-G:60@(DYE>'0@665A<B(*;7-G<W1R
M(")K]G9E=&ME>O4@Z78B"@HC.B!T96UP;&%T97,O9&%Y+VAE860N:6YC.C4*
M;7-G:60@(DYE>'0@9&%Y(@IM<V=S='(@(DWA<VYA<"(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHU."!T96UP;&%T97,O=V5E:R]H96%D+FEN
M8SHU"FUS9VED(").97AT('=E96LB"FUS9W-T<B`B:_9V971K97KU(&CI="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S4@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(X.`IM<V=I9"`B3F\B"FUS9W-T<B`B3F5M(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,3(T"FUS9VED(").;R!A;&%R;2(*;7-G<W1R(").:6YC<R!F:6=Y96QM97IT
M973I<R(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT
M.`IM<V=I9"`B3F\@871T96YD965S(@IM<V=S='(@(FYI;F-S96YE:R!RZ7-Z
M='9E=O5K(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,`IM<V=I9"`B3F\@
M8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R(")!
M('9E;F3I9R!F96QH87-Z;N%L\VL@<NES>NER92!N96T@X6QL(')E;F1E;&ME
M>NES<F4@;F%P=.%R+B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$S
M-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-3(*;7-G:60@(DYO(&5N9"!D
M871E(@IM<V=S='(@(FYI;F-S(';I9V4B"@HC.B!L:6(O0FQO8VLO<')E=FUO
M;G1H;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$V,PHC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT"FUS9VED(").;R!E=F5N=',@
M=&\@9&ES<&QA>2(*;7-G<W1R(").:6YC<R!M96=J96QE;NUT:&5T]2!E;&9O
M9VQA;'1SX6<B"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V
M86EL86)L92!F;W(@)7,B"FUS9W-T<B`B)7,@:63U8F5O<WITX7-I(&%D871A
M:2!N96T@Z7)H973U:R!E;"(*"B,Z(&QI8B]A<&DN<&AP.C,T-2!L:6(O87!I
M+G!H<#HV,C0*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB
M"FUS9W-T<B`B3F5M('1A;.%L:&%T\R!I0V%L96YD87(@861A="XB"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,#$*;7-G:60@(DYO(')E8W5R<F5N
M8V4B"FUS9W-T<B`B3FEN8W,@:7-MZ71L]63I<R(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.CDP,@IM<V=I9"`B3F\@=F%L:60@96UA:6P@861D<F5S<R!F;W5N
M9"(*;7-G<W1R(").96T@=&%LX6QH873S(.ER=NEN>65S(&5M86EL(&/M;2(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8Q,B!L:6(O2W)O;F]L:71H+G!H<#HV
M,S,*;7-G:60@(DYO;F4B"FUS9W-T<B`B;FEN8W,B"@HC.B!L:6(O4W1O<F%G
M92]S<6PN<&AP.C$T-0IM<V=I9"`B3F]T(&9O=6YD(@IM<V=S='(@(FYE;2!T
M86SA;&AA=/,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@
M(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`BR7)T97/M=.ES96LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.`IM<V=I9"`B3F]V96UB97(B
M"FUS9W-T<B`B;F]V96UB97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R(")M;W-T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S<*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B;VMT\V)E<B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C$S('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8U
M"FUS9VED(")/;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C<X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3$*;7-G:60@(D]N(&%L
M;"!C86QE;F1A<G,@22!H879E(')E860@86-C97-S('1O(@IM<V=S='(@(DUI
M;F1E;B!N87!TX7)B86XL(&%M:6AE>B!V86X@;VQV87/A<VD@:F]G;VTB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR.3`*;7-G:60@(D]N(&%L;"!S:&]W;B!C86QE;F1A<G,B"FUS9W-T
M<B`B07H@]G-S>F5S(&UE9VIE;&5N[71E='0@;F%P=.%R8F%N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(W-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C@Y"FUS9VED(")/;B!M>2!C86QE;F1A<G,@;VYL>2(*;7-G<W1R(")#<V%K
M(&$@<V%JX70@;F%P=.%R86EM8F%N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-C,P"FUS9VED(")/<'1I;VYA;"(*;7-G<W1R(")VX6QA<WIT:&%T\R(*"B,Z
M(&QI8B]&0E9I97<N<&AP.C$Q.0IM<V=I9"`B3W!T:6]N86P@071T96YD965S
M(@IM<V=S='(@(D]P8VEO;N%L:7,@<NES>G1V97;U:R(*"B,Z(&QI8B]&0E9I
M97<N<&AP.C$U-`IM<V=I9"`B3W9E<G9I97<B"FUS9W-T<B`BP71T96MI;G3I
M<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C,T"FUS9VED(")/=VYE
M<B(*;7-G<W1R(")4=6QA:F1O;F]S(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@X
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")/=VYE<CH@)7,B"FUS9W-T<B`B5'5L
M86ID;VYO<SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Q
M-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y-`IM<V=I9"`B4$TB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C,@;&EB
M+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C0R"FUS9VED(")087-T($5V96YT
M<R!,:7-T(@IM<V=S='(@(D%Z(&5L;?IL="!E;&9O9VQA;'1SX6=O:R!L:7-T
MX6IA(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`Y('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$Y-@IM<V=I9"`B4&%T=&5R;B(*;7-G<W1R(")-
M\V1J82(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHS,`IM<V=I9"`B
M4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_(@IM<V=S='(@(E;I9VQE
M9V5S96X@=/9R]FQJ_&L@:VD@97IT(&%Z(&5L9F]G;&%L='/A9V]T/R(*"B,Z
M(&QI8B]A<&DN<&AP.C,R-B!L:6(O87!I+G!H<#HT,C(@;&EB+V%P:2YP:'`Z
M-#DT(&QI8B]A<&DN<&AP.C4W-`HC.B!L:6(O87!I+G!H<#HV,#8@;&EB+V%P
M:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.C<R.`IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`BUFYN96L@;FEN8W,@96AH97H@96QE9V5N9/4@:F]G
M;W-U;'1SX6=A(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$W,`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B2F]G;W-U;'1S
MX6=O:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0IM<V=I9"`B4&]R
M=&%L($]P=&EO;G,B"FUS9W-T<B`B4WIE;>EL>65S(&ME>F3U;VQD86PB"@HC
M.B!L:6(O1D)6:65W+V1A>2YP:'`Z,C4*;7-G:60@(E!R979I;W5S($1A>2(*
M;7-G<W1R(")E;/5Z]2!N87`B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C(V
M"FUS9VED(")0<F5V:6]U<R!7965K(@IM<V=S='(@(F5L]7KU(&CI="(*"B,Z
M('1E;7!L871E<R]D87DO:&5A9"YI;F,Z,PIM<V=I9"`B4')E=FEO=7,@9&%Y
M(@IM<V=S='(@(D5L]7KU(&YA<"(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-#D*;7-G:60@(E)E
M8W5R(%5N=&EL(@IM<V=S='(@(DUE9&1I9R!I<VWI=&SU9&EK(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`V"FUS9VED(")296-U<G)E;F-E(@IM
M<V=S='(@(DES;>ET;/5DZ7-I(&%D871O:R(*"B,Z(&1A=&$N<&AP.C8X"FUS
M9VED(")296-U<G)E;F-E($1A=&$B"FUS9W-T<B`B27-MZ71L]63I<VD@861A
M=&]K(@H*(SH@9&%T82YP:'`Z-C8*;7-G:60@(E)E8W5R<F5N8V4@16YD($1A
M=&4B"FUS9W-T<B`B07H@:7-MZ71L]63I<R!VZ6=E(@H*(SH@9&%T82YP:'`Z
M-C<*;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`B07H@:7-M
MZ71L]63I<VD@:63U(@H*(SH@9&%T82YP:'`Z-C4*;7-G:60@(E)E8W5R<F5N
M8V4@5'EP92(*;7-G<W1R(")!>B!I<VWI=&SU9.ES(&9A:G3A:F$B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HU-#@*;7-G:60@(E)E8W5R<R!D86EL>2(*;7-G
M<W1R(").87!O;G1A(&ES;>ET;/5D:6LB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU-34*;7-G:60@(E)E8W5R<R!M;VYT:&QY(@IM<V=S='(@(DAA=F]N=&$@
M:7-MZ71L]61I:R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4U,0IM<V=I9"`B
M4F5C=7)S('=E96ML>2(*;7-G<W1R(")(971E;G1E(&ES;>ET;/5D:6LB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HU-3@*;7-G:60@(E)E8W5R<R!Y96%R;'DB
M"FUS9W-T<B`BR79E;G1E(&ES;>ET;/5D:6LB"@HC.B!L:6(O4V-H961U;&5R
M+VMR;VYO;&ET:"YP:'`Z,C`U"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6EN
M9&5R.B`E<R(*;7-G<W1R(")%;6SI:V5Z=&5T]3H@)7,B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.30@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T"FUS9VED(")296UO=&4@0V%L96YD87)S(@IM<V=S='(@(E3A
M=F]L:2!N87!TX7)A:R(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHV,"!T96UP
M;&%T97,O;65N=2YI;F,Z-C(*;7-G:60@(E)E;6]T92!#86QE;F1A<G,Z(@IM
M<V=S='(@(E3A=F]L:2!N87!TX7)A:SHB"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,3DT"FUS9VED(")296UO=&4@4W5B<V-R:7!T
M:6]N(%523"(*;7-G<W1R(")4X79O;&D@;F%P=.%R(&5L]69I>F5TZ7-I("AS
M=6)S8W)I<'1I;VXI(%523"(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,38Q"FUS9VED(")296UO=F4B"FUS9W-T<B`B5/9R;.ES(@H*
M(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C4Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E;6]V92`E<R(*;7-G<W1R("(E<R!T]G)LZ7-E
M(@H*(SH@871T96YD965S+G!H<#HQ,#`*;7-G:60@(E)E;6]V92!!='1E;F1E
M92(*;7-G<W1R(")!(&UE9VCM=F]T="!E;'3A=F]L[73A<V$B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C,Q"FUS9VED("(B"B)297!L86-E(&5X
M:7-T:6YG(&-A;&5N9&%R('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N
M9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U
M<B!C=7)R96YT(&-A;&5N9&%R+CPO<W1R;VYG/B(*;7-G<W1R("(B"B+-<FIU
M:R!F96S\;"!A(&MI=N%L87-Z=&]T="!C[6UJ96=Y>NEK970@87H@:6UP;W)T
MX6QT=&%L/R`B"B(\<W1R;VYG/D9I9WEE;&UE>G1E=.ES.B!E>B!K:73V<FQI
M(&%Z(/9S<WIE<R!A9&%T;W0@82!J96QE;FQE9VD@(@HB8^UM:F5G>7KI:V+U
M;"$\+W-T<F]N9SXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,S<*;7-G:60@
M(E)E<75I<F5D(@IM<V=S='(@(G-Z_&MSZ6=E<R(*"B,Z(&QI8B]&0E9I97<N
M<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S.2!L:6(O1D)6:65W+G!H<#HQ-#(@
M;&EB+T9"5FEE=RYP:'`Z,30U"FUS9VED(")297%U:7)E9"!!='1E;F1E97,B
M"FUS9W-T<B`B4WK\:W/I9V5S('+I<WIT=F5V]6LB"@HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHS,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#@*
M;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(DME>F1J_&L@^FIR
M82!A(&MI=/9L=.ES="(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD
M965S+FEN8SHT,R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C8*;7-G:60@
M(E)E<W!O;G-E(@IM<V=S='(@(E;A;&%S>B(*"B,Z('EE87(N<&AP.C@U('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8T('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(R,`HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I
M9"`B4V$B"FUS9W-T<B`B4WIO(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N
M:6YC.C(Q('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,`HC.B!T96UP;&%T
M97,O961I="]J879A<V-R:7!T+FEN8SHW,PIM<V=I9"`B4V%T=7)D87DB"FUS
M9W-T<B`B<WIO;6)A="(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHR,#,*;7-G:60@(E-A=F4B"FUS9W-T<B`B365N=.ES(@H*(SH@
M=FEE=V5V96YT+G!H<#HQ,S,@961I=&5V96YT+G!H<#HT.2!E9&ET979E;G0N
M<&AP.C4W"FUS9VED(")3879E($%S($YE=R(*;7-G<W1R("+::FOI;G0@;65N
M='/\:R!E;"(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN
M8SHX,PIM<V=I9"`B4V%V92!!='1E;F1E97,B"FUS9W-T<B`B02!RZ7-Z='9E
M=O5K(&5L;65N=.ES92(*"B,Z(&%D9&5V96YT+G!H<#HU-2!E9&ET979E;G0N
M<&AP.C4R"FUS9VED(")3879E($5V96YT(@IM<V=S='(@(D%Z(&5L9F]G;&%L
M='/A9R!M96YTZ7-E(@H*(SH@<V5A<F-H+G!H<#HY,2!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$T"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHV-R!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI
M;F,Z.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$T-2!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(DME<F5SZ7,B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI
M;F,Z,0IM<V=I9"`B4V5A<F-H($-A;&5N9&%R<R(*;7-G<W1R(")+97)E<^ES
M(&$@;F%P=.%R86MB86XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI
M;F,Z-@IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B02!K97)E<^ES
M(&5R961MZ6YY92(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN
M8SHV"FUS9VED(")396%R8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN:6YG.B(*
M;7-G<W1R(")+97)E<W/\:R!A(&YA<'3A<F%K8F%N.B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3,*;7-G:60@(E-E;&5C="!A
M(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`B5N%L87-S>F$@:VD@82!M\V1O
M<^UT86YI(&OM=N%N="!N87!TX7)T(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C8U('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q
M"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(E;A;&%S<WIO;B!K:2!E9WD@9.%T
M=6UO="(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHS,`IM<V=I9"`B4V5L96-T
M(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")6X6QA<W-Z82!K:2P@
M;65L>6EK(&YA<'3A<F%K870@:^UVX6YJ82!M96=J96QE;NUT96YI.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B(@HB4V5L96-T(&-O
M;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R
M96YT('9I97=S(&%N9"!C:&]O<V4@(@HB9&5F875L="!V:65W+B(*;7-G<W1R
M("(B"B)-96=E<O5S[73I<VD@;W!C:?-K+"!K_&SV;F+V>O4@;NEZ971E:R!M
M96=J96QE;NUTZ7-I(&9O<FWA:N%I+"!I;&PN(&%Z("(*(F%L87#I<G1E;&UE
M>F5T="!NZ7IE="#A;&SM=&AA=/,@8F4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ.`IM<V=I9"`B4V5L96-T('1H92!C86QE;F1A<B!T;R!I
M;7!O<G0@=&\Z(@IM<V=S='(@(E;A;&%S<WIA(&MI+"!M96QY:6L@;F%P=.%R
M8F$@:^UVX6YJ82!A>B!A9&%T;VMA="!I;7!O<G3A;&YI.B(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,3D*;7-G:60@(E-E;&5C="!T:&4@8V%L
M96YD87(H<RD@=&\@97AP;W)T(&9R;VTB"FUS9W-T<B`B5N%L87-S>F$@:VDL
M(&UE;'EI:R!N87!TX7(H86LI8O-L(&OM=N%N:F$@87H@861A=&]K870@97AP
M;W)TX6QN:3HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS
M9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E;A;&%S
M<WIA(&MI(&%Z(&5X<&]R=.%LX7,@9F]R;>%T=6WA=#HB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C(W"FUS9VED(")396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A>B!I;7!O<G3A;&%N
M9/,@9N%J;'0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I
M9"`B4V5L96-T('1H92!F:7)S="!W965K9&%Y.B(*;7-G<W1R(")6X6QA<W-Z
M82!K:2!A(&CI="!E;'/U(&YA<&KA=#HB"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@
M<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&%Z(&EM<&]R=.%L
M86YD\R!FX6IL(&9O<FWA='5MX70Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T:6UE('-P86X@=&\@<VAO=SHB
M"FUS9W-T<B`B5N%L87-S>F$@:VDL(&AO9WD@;6EL>65N(&ED]6EN=&5R=F%L
M;'5M;W0@:F5L96[M='/\;FL@;65G.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-@IM<V=I9"`B4V5L96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@
M<W1A<G1U<#HB"FUS9W-T<B`B5N%L87-S>F$@:VDL(&AO9WD@;6EL>65N(&[I
M>F5T(&IE;&5N:F5N(&UE9R!A(&)E:F5L96YT:V5ZZ7,@=73A;CHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(*;7-G:60@(E-E;&5C="!W:&EC:"!E
M=F5N=',@=&\@<VAO=R!I;B!T:&4@<&]R=&%L+B(*;7-G<W1R("(B"B)-96=A
M9&AA=/,L(&AO9WD@;6EL>65N(&5L9F]G;&%L='/A9V]K870@:F5L96[M='/\
M;FL@;65G(&%Z(/9S<WIE9F]G;&%L\R`B"B)NZ7IE=&)E;BXB"@HC.B!T96UP
M;&%T97,O9&5L971E+V]N92YI;F,Z,C<@=&5M<&QA=&5S+V1E;&5T92]D96QE
M=&4N:6YC.C(W"FUS9VED(")396YD(&$@8V%N8V5L(&YO=&EF:6-A=&EO;B!T
M;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@=&AI<R!E=F5N="(*;7-G
M<W1R("(B"B)!>B!E<V5MZ6YY('3V<FSI<V4@97-E=.EN(&O\;&1J_&YK('3A
M:NEK;WIT873A<W0@86YN86L@96QM87)A9.%SX7+S;"!A>B`B"B+V<W-Z97,@
M<NES>G1V97;U;F5K(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3<P
M"B,L('!H<"UF;W)M870*;7-G:60@(E-E;F0@86X@96UA:6P@=&\@)7,B"FUS
M9W-T<B`B3&5VZ6QK_&QDZ7,@)7,M;F5K(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,3<Y"FUS9VED(")396YD('5P9&%T97,O:6YV:71A=&EO;G,@
M=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V96YT(@IM<V=S
M='(@(B(*(DO\;&1J_&YK('!R;V=R86UVX6QT;WKA<VD@:6YF;W)MX6-I\W0O
M;65G:.UVX7-T(&%Z(/9S<WIE<R!RZ7-Z='9E=O5N96L@96YN96L@(@HB87H@
M96QF;V=L86QT<^%G;F%K(&$@;65N=.ES96MO<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C<V"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`B<WIE<'1E;6)E<B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C@S"FUS9VED(")3970@96YD(&1A=&4B"FUS9W-T<B`B02!B969E
M:F5ZZ7,@9.%T=6UA(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8U
M"FUS9VED(")3970@<F5C=7)R96YC92!E;F0@9&%T92(*;7-G<W1R(")!>B!I
M<VWI=&SU9.ES(';I9V4B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHS,0IM<V=I9"`B4V5T('-T87)T(&1A=&4B"FUS9W-T<B`B02!K
M97ID970@9.%T=6UA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y"FUS
M9VED("(B"B)3970@>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y;W5R
M(&]W;B!A;F0@;W1H97(@=7-E<G,G(&9R964O8G5S>2!O<'1I;VYS+B(*;7-G
M<W1R("(B"B)!>B#6;B!I;&PN(&WA<R!F96QH87-Z;N%L\VL@96QF;V=L86QT
M<^%G:2!A9&%T86EV86P@:V%P8W-O;&%T;W,@8F7A;&SM=.%S;VLN(@H*(SH@
M8V%L96YD87)S+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&%R92!N
M;W0@9F]U;F0Z("5S(@IM<V=S='(@(D$@:_9Z]G-E;B!H87-Z;N%L="!A9&%T
M9F]R<N%S(&YE;2!T86SA;&AA=/,Z("5S(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C@R"FUS9VED(")3:&%R960@0V%L96YD87)S
M(@IM<V=S='(@(DOV>O9S96X@:&%S>F[A;'0@;F%P=.%R86LB"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z-#<@=&5M<&QA=&5S+VUE;G4N:6YC.C0Y"FUS9VED
M(")3:&%R960@0V%L96YD87)S.B(*;7-G<W1R(")+]GKV<V5N(&AA<WINX6QT
M(&YA<'3A<F%K.B(*"B,Z(&-A;&5N9&%R7W-E87)C:"YP:'`Z,C4@=&5M<&QA
M=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*(SH@=&5M<&QA=&5S
M+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PIM<V=I9"`B4VAO=R!#86QE
M;F1A<B(*;7-G<W1R(")-=71A<W-U:R!A(&YA<'3A<G0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34V"FUS9VED(")3:&]W(&-A=&5G;W)Y(&QE9V5N
M9#\B"FUS9W-T<B`B2F5L97IZ_&L@:_QL]FX@82!M96=J96QE;NUT971T(&5S
M96WI;GEE:R!K871E9_-R:>%I=#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30V"FUS9VED(")3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E
M;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R("(B"B)!(&YA
M<'3A<B!M96=J96QE;NUTZ7-E:V]R(&QE9WEE;F5K+64@:6MO;F]K(&$@=/9R
M;.ES:2!F=6YK8VGS:&]Z+"!I;&PN(&$@(@HB9FEG>65L;65Z=&5TZ7-I+"!I
M<VWI=&SU9.ES:2!B9>%L;.UTX7-O:R!J96QZZ7/I<F4_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S:W,@:6X@
M=&AE(&-A;&5N9&%R/R(*;7-G<W1R(")-=71A<W-U:R!A(&AA=.%R:63U<R!F
M96QA9&%T;VMA="!A(&YA<'3A<F)A;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,38V"FUS9VED(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S
M='(@(DIE;/9L:OQK(&$@<WIA8F%D+V5L9F]G;&%L="!I9/5S>F%K;VMA=#\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`S"FUS9VED(")3:&]W(&]N
M;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S970_(@IM<V=S='(@(B(*
M(D-S86L@87IO:V%T(&%Z(&5L9F]G;&%L='/A9V]K870@;75T87-S=6LL(&%M
M:6MH97H@9FEG>65L;65Z=&5TZ7,@=F%N("(*(G)E;F1E;'9E/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S4*;7-G:60@(E-H;W<@<VAA<F5D(&-A
M;&5N9&%R<R!S:61E+6)Y+7-I9&4_(@IM<V=S='(@(D$@:_9Z]G-E;B!H87-Z
M;N%L="!N87!TX7)A:V%T(&5G>6WA<R!M96QL971T(.%B<N%Z;VQJ=6L_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B4VAO=R!T87-K
M<R!U<VEN9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(D$@9F5L861A=&]K
M870@82!K871E9_-R:>%J=6L@<WKM;F5I=F5L(&IE;&5N[71S_&L@;65G/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B4VAO=R!T:6UE
M(&]F(&1A>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_(@IM<V=S
M='(@(D$@:&5T:2!NZ7IE=&)E;B!M=71A<W-U:R!A>B#S<N%K870@82!N87!O
M:R!O<WIL;W!A:2!K]GKV='0@:7,_(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,3$*;7-G:60@(E-T85]R="(*;7-G<W1R(")+97ID
M970B"@HC.B!D871A+G!H<#HU-`IM<V=I9"`B4W1A<G0@1&%T92(*;7-G<W1R
M(")+97ID]2!DX71U;2(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A
M9&5R<RYI;F,Z-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT,0HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C,W"FUS9VED(")3=&%R="!/;B(*;7-G
M<W1R(")+97ID]61I:R(*"B,Z(&1A=&$N<&AP.C4U"FUS9VED(")3=&%R="!4
M:6UE(@IM<V=S='(@(DME>F3I<VD@:63U(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8VA?861V86YC960N:6YC.CDT('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C@S"FUS9VED(")3=&%T7W5S(@IM<V=S='(@(L%L;&%P;W0B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C8@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T871U<R(*;7-G<W1R("+!;&QA
M<&]T(@H*(SH@>65A<BYP:'`Z-S@@>65A<BYP:'`Z.#<@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-C4*(SH@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C(Q(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`W(&QI8B]";&]C:R]M;VYT
M:"YP:'`Z,3`Y"FUS9VED(")3=2(*;7-G<W1R(")682(*"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D+FEN8SHQ-"!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M,C,*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(Q('1E;7!L871E<R]E
M9&ET+VIA=F%S8W)I<'0N:6YC.C8W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#4*;7-G:60@(E-U;F1A>2(*;7-G<W1R(")V87/A<FYA<"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B
M1F5L861A=&]K(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3@U(&QI8B]+<F]N
M;VQI=&@N<&AP.C8P.`IM<V=I9"`B5&5N=&%T:79E(@IM<V=S='(@(G1E<G9E
M>F5T="(*"B,Z('EE87(N<&AP.C@S('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.`HC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS9W-T<B`B0W/\(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW,`IM<V=I9"`B
M5&AE($5D:70@071T96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N
M="X@17AI=&EN9RXB"FUS9W-T<B`B(@HB02!<(E+I<WIT=F5V]6L@;?-D;W/M
M=.%S85PB(&OI<&5R;GGU(&WA<B!ZX7)V82!V86XN($MI;.EPZ7,@:_9V971K
M97II:RXB"@HC.B!C86QE;F1A<G,N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!C86QE;F1A<B!<(B5S7"(@8V%N;F]T(&)E(&1E;&5T960N(@IM
M<V=S='(@(D$@7"(E<UPB(&YA<'3A<B!N96T@=/9R]FQH973U+B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N
M9&%R(%PB)7-<(B!H87,@8F5E;B!C<F5A=&5D+B(*;7-G<W1R(")!(%PB)7-<
M(B!N87!TX7)T(&SI=')E:&]Z='5K+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!(%PB)7-<(B!N87!TX7)T(&MI=/9R
M]FQT_&LN(@H*(SH@8V%L96YD87)S+G!H<#HU-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(')E;F%M960@=&\@
M7"(E<UPB+B(*;7-G<W1R(")!(%PB)7-<(B!N87!TX7)T(.%T;F5V97IZ_&L@
M7"(E<UPB+7)E+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB
M"FUS9W-T<B`B02!<(B5S7"(@;F%P=.%R="!E;&UE;G1E='3\:RXB"@HC.B!D
M871A+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(D$@;F%P=.%R(&YE
M;2!T]G+V;&AE=/4Z("5S(@H*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z,38S"FUS9VED(")4:&4@96YD(&1A=&4@;75S="!B92!L871E<B!T
M:&%N('1H92!S=&%R="!D871E+B(*;7-G<W1R(")!(&)E9F5J97KI<R!DX71U
M;6$@:^ES]6)B(&ME;&P@;&5G>65N+"!M:6YT(&$@:V5Z9&5TZ2XB"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,3$T"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@861D960@=&\@7"(E<UPB(&-A
M;&5N9&%R+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@HB02AZ
M*2!<(B5S7"(@^FH@96QF;V=L86QT<^%G(&UE9VIE;&5N="!A*'HI(%PB)7-<
M(B!N87!TX7)B86XL(&ED]7!O;G1J82`E<RP@)7,B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,3(T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!E=F5N
M="!<(B5S7"(@:&%S(&)E96X@9&5L971E9"!F<F]M(%PB)7-<(B!C86QE;F1A
M<BP@=VAI8V@@=V%S(&]N("5S(&%T("4B"B)S+B(*;7-G<W1R("(B"B)!*'HI
M(%PB)7-<(B!E;&9O9VQA;'1SX6<@=/9R;/5D]G1T(&$H>BD@7"(E<UPB(&YA
M<'3A<F+S;"P@:63U<&]N=&IA("5S+"`E<R`B"B)V;VQT+B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$Q,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&5V96YT(%PB)7-<(B!H87,@8F5E;B!E9&ET960@;VX@7"(E<UPB(&-A;&5N
M9&%R+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@HB02AZ*2!<
M(B5S7"(@96QF;V=L86QT<^%G(&WS9&]S=6QT(&$H>BD@7"(E<UPB(&YA<'3A
M<F)A;BP@:63U<&]N=&IA("5S+"`E<RXB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!N;W1I9FEC
M871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+B(*;7-G<W1R(")!
M>B!E<V5MZ6YY<O5L(&QE=F5L970@:_QL9'3\;FL@)7,@<NES>NER92XB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#0T"FUS9VED(")4:&4@9F]L;&]W:6YG
M(&ES(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z
M(@IM<V=S='(@(D%Z(&5S96WI;GD@<NES>FQE=&5S(&QE[7+A<V$Z(@H*(SH@
M871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E<W0@=V%S(&EN8V]M
M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N96-E<W-A<GD@=&\@
M86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E(&UI<W-I;F<N(@IM
M<V=S='(@(B(*(D$@;65G:.UVX7,@861A=&%I(&AIX6YY;W-A:RX@07H@97-E
M;>EN>65N('9A;/,@<NES>G;I=&5L(&5L9F]G863A<^%H;WH@=F%G>2`B"B)E
M;'5T87/M=.%SX6AO>B!S>OQK<^EG97,@861A=&]K(&OV>OQL(&5G>65S96L@
M;F5M(.%L;&YA:R!R96YD96QK97KI<W)E+B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O96UP='DN:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!E=F5N=',@;6%T
M8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(DYI;F-S(&$@
M:W)I=.ER:75M;VMN86L@;65G9F5L96SU(&5L9F]G;&%L='/A9RXB"@HC.B!A
M9&1E=F5N=&%C=&EO;BYP:'`Z,3@@961I=&5V96YT86-T:6]N+G!H<#HS-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@86-C97-S
M:6YG('1H92!C86QE;F1A<CH@)7,B"FUS9W-T<B`B2&EB82!T]G)TZ6YT(&$@
M;F%P=.%R(&5LZ7+I<V5K;W(Z("5S(@H*(SH@861D979E;G1A8W1I;VXN<&AP
M.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A
M9&1I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")!>B!E;&9O9VQA;'1SX6<@
M:&]Z>N%A9.%S82!S;W+A;B!H:6)A('3V<G3I;G0Z("5S(@H*(SH@961I=&5V
M96YT86-T:6]N+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(D%Z
M(&5L9F]G;&%L='/A9R!M\V1O<^UTX7-A('-O<N%N(&AI8F$@=/9R=.EN=#H@
M)7,B"@HC.B!L:6(O87!I+G!H<#HS,SD@;&EB+V%P:2YP:'`Z-C$X"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82XB"FUS9W-T<B`B07H@:4-A;&5N9&%R(&%D871O:R!I;7!O<G3A;.%S
M82!S;W+A;B!H:6)A('3V<G3I;G0N(@H*(SH@961I=&5V96YT86-T:6]N+G!H
M<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M;6]V:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B07H@96QF;V=L86QT<^%G
M(.%T:&5L>65ZZ7-E('-O<N%N(&AI8F$@=/9R=.EN=#H@)7,B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#DR"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T
M;R`E<SH@)7,B"FUS9W-T<B`B(@HB2&EB82!T]G)TZ6YT+"!A;6EK;W(@87H@
M97-E;>EN>7+U;"!TX6KI:V]Z=&%TX7-T(&%K87)T=6YK(&O\;&1E;FD@)7,@
M(@HB<NES>NER93H@)7,B"@HC.B!D871A+G!H<#HQ,#@*;7-G:60@(E1H97)E
M('=E<F4@;F\@979E;G1S('1O(&5X<&]R="XB"FUS9W-T<B`B3F5M('9O;'0@
M97AP;W)TX6QH873S(&5L9F]G;&%L='/A9RXB"@HC.B!D871A+G!H<#HQ.#<*
M;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B27-M97)E=&QE;B!FX6IL9F]R;>%T=6TN(@H*(SH@9&%T82YP:'`Z
M,C4P"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("5S(@IM<V=S='(@(D$@<WIE<G9E<B#\>F5N971E.B`E<R(*
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ.2!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,3@*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI
M;F,Z-S$*;7-G:60@(E1H=7)S9&%Y(@IM<V=S='(@(F-S_'3V<G3V:R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS-PIM<V=I9"`B5&EM92!3
M<%]A;B(*;7-G<W1R("))9/5T87)T86TB"@HC.B!T96UP;&%T97,O961I="]E
M9&ET7W1I;65S<&%N+FEN8SHT"FUS9VED(")4:6UE('-P86XB"FUS9W-T<B`B
M263U=&%R=&%M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC
M960N:6YC.C,T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,X"FUS9VED(")4
M:71?;&4B"FUS9W-T<B`B16QN979E>NES(@H*(SH@9&%T82YP:'`Z-3,@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"B,Z('1E;7!L871E<R]S96%R
M8V@O979E;G1?:&5A9&5R<RYI;F,Z,PIM<V=I9"`B5&ET;&4B"FUS9W-T<B`B
M16QN979E>NES(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R
M,B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$R-PIM<V=I9"`B5&]D87DB"FUS9W-T<B`B36$B"@HC.B!L
M:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(T(&QI8B]";&]C:R]M;VYT
M:&QI<W0N<&AP.C$R,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(Y"FUS
M9VED(")4;VUO<G)O=R(*;7-G<W1R(")(;VQN87`B"@HC.B!Y96%R+G!H<#HX
M,2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,"!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,38*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*
M;7-G:60@(E1U(@IM<V=S='(@(DME(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C$W('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-@HC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV.0IM<V=I9"`B5'5E<V1A>2(*
M;7-G<W1R(")K961D(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W
M"FUS9VED(")4>7!E(@IM<V=S='(@(E3M<'5S(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$X-@IM<V=I9"`B55),(@IM<V=S='(@
M(E523"(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(D%Z(%-13"!S
M>F5R=F5R(&YE;2#I<FAE=/4@96PN(@H*(SH@8V%L96YD87)S+G!H<#HX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B7"(E<UPB('3V<FSI<V4@;F5M('-I:V5R_&QT.B`E<R(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B
M3F5M('-I:V5R_&QT(&)E;VQV87-N:2`E<R!D969I;NUC:?-JX70N(@H*(SH@
M8V%L96YD87)S+G!H<#HU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%PB)7-<(CH@)7,B"FUS9W-T<B`B7"(E<UPB(.%T;F5V97KI
M<V4@;F5M('-I:V5R_&QT.B`E<R(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H
M<#HS.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G<W1R(").96T@<VEK
M97+\;'0@96SI<FYI("5S(&ED]6)E;W-Z=.%S:2!A9&%T86ET+B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$U"B,Z('-C<FEP=',O=7!G<F%D97,O
M,C`P-"TP-2TQ.5]C;VYV97)T7V-A=&5G;W)I97-?=&]?<W1R:6YG<RYP:'`Z
M-3,*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B8F5S;W)O;&%T;&%N(@H*(SH@
M;&EB+V%P:2YP:'`Z,S<W(&QI8B]A<&DN<&AP.C0V,2!L:6(O87!I+G!H<#HU
M,S<@;&EB+V%P:2YP:'`Z-C0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P
M<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B27-M97)E=&QE;B!T
M87)T86QO;73M<'5S.B`E<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9#H@)7,N(@IM<V=S='(@(B5S
M(';A;'1O>N%S86ET(&5L;65N=&5T=/QK+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,`IM<V=I9"`B57-E<B!);G1E<F9A8V4B"FUS9W-T<B`B02!P
M<F]G<F%M(&AA<WINX6QA=&$B"@HC.B!Y96%R+G!H<#HQ-C`@>65A<BYP:'`Z
M,38V(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,38R"FUS9VED(")6:65W($1A>2(*;7-G<W1R(").87!I(&UE9VIE;&5N
M[73I<R(*"B,Z('EE87(N<&AP.C@R('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q-PHC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5V4B"FUS9W-T<B`B4WIE(@H*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$X('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$Q-PHC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN
M8SHW,`IM<V=I9"`B5V5D;F5S9&%Y(@IM<V=S='(@(G-Z97)D82(*"B,Z(&%T
M=&5N9&5E<RYP:'`Z,3`X(&QI8B]+<F]N;VQI=&@N<&AP.C$S,3,@;&EB+T)L
M;V-K+W1R965?;65N=2YP:'`Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@S"FUS9VED(")7965K(@IM<V=S='(@(FCI="(*"B,Z(&UO;G1H+G!H<#HQ
M-S<@=V]R:W=E96LN<&AP.C,P('=E96LN<&AP.C,T"B,L('!H<"UF;W)M870*
M;7-G:60@(E=E96L@)60B"FUS9W-T<B`B)60N(&CI="(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C4Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S
M.`IM<V=I9"`B5V5E:RAS*2(*;7-G<W1R(")HZ70B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$R
M"FUS9VED(")7965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")H971E;G1E
M.B!I<VWI=&SU9&EK(&UI;F1E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K
M('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S/R(*
M;7-G<W1R("(B"B)(X6YY(/-RX6EG(&UU=&%S<W5K(&%Z(&ED]70@82!N87!I
M(&EL;"X@:&5T:2!NZ7IE=&)E;BP@:&$@;FEN8W,@:^ES]6)B:2`B"B)E;&9O
M9VQA;'1SX6<_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I
M9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@<W1A
M<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/R(*;7-G<W1R
M("(B"B)(X6YY(/-RX73U;"!K97ID=F4@;75T87-S=6L@87H@:63U="!A(&YA
M<&D@:6QL+B!H971I(&[I>F5T8F5N+"!H82!N:6YC<R`B"B)K;W+A8F)I(&5L
M9F]G;&%L='/A9S\B"@HC.B!A='1E;F1E97,N<&AP.C$P-R!L:6(O2W)O;F]L
M:71H+G!H<#HQ,S$R(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B5V]R:R!7965K(@IM<V=S
M='(@(FUU;FMA:.ET(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q-2!L:6(O
M0FQO8VLO=')E95]M96YU+G!H<#HR-0IM<V=I9"`B665A<B(*;7-G<W1R("+I
M=B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,S@*;7-G:60@(EEE87)L>3H@4F5C=7)S(&5V97)Y
M(@IM<V=S='(@(NEV96YT93H@:7-MZ71L]61I:R!M:6YD96XB"@HC.B!D871A
M+G!H<#HS.2!D871A+G!H<#HR,SD@961I=&5V96YT86-T:6]N+G!H<#HT-B!A
M9&1E=F5N="YP:'`Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&5V96YT<RXB"FUS
M9W-T<B`B3F5M(&AO>FAA="!LZ71R92!T]F)B+"!M:6YT("5D(&5L9F]G;&%L
M='/A9V]T+B(*"B,Z(&%T=&5N9"YP:'`Z-#D*;7-G:60@(EEO=2!A<F4@;F]T
M(&%N(&%T=&5N9&5E(&]F('1H92!S<&5C:69I960@979E;G0N(@IM<V=S='(@
M(M9N(&YE;2!RZ7-Z='9E=O5J92!A(&UE9VIE;/9L="!E<V5MZ6YY;F5K+B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z-S8*;7-G:60@
M(EEO=2!C86X@;VYL>2!U<V4@=&AI<R!F;W)M(&9R;VT@=&AE($5D:70@071T
M96YD965S('-C<F5E;BXB"FUS9W-T<B`B17H@87H@86)L86L@8W-A:R!A(%PB
M4NES>G1V97;U:R!M\V1O<^UTX7-A7"(@:^EP97)N>?5R]6P@:.UV:&%T\R!M
M96<N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3@X"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A9&1R97-S(&-O
M;F9I9W5R960@:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO;B`B"B)/<'1I
M;VYS+B!9;W4@;75S="!S970@;VYE("5S:&5R925S(&)E9F]R92!E=F5N="!N
M;W1I9FEC871I;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B"B).:6YC<R!M
M96=A9'9A(&%Z(&5M86EL(&/M;64@87H@UFX@<WIE;>EL>65S(&%Z;VYO<^UT
M\VKA8F%N(&$@;&5V96QE>NES("(*(F)EX6QL[73A<V%I(&OV>O9T="X@17IT
M(&UE9R!K96QL(&%D;FEA("5S:71T)7,@86AH;WHL(&AO9WD@97-E;>EN>65K
M<F4@<WKS;/,@(@HB;65G:.UV\VMA="!K_&QD:&5S<V5N(&$@<F5N9'-Z97(N
M(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C(P"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@
M=&\@)7,N(@IM<V=S='(@(M9N;F5K(&YI;F-S(&IO9V]S=6QT<^%G82!E;&9O
M9VQA;'1SX6=O:V%T(&)E[7)N:6$@)7,M8F4N(@H*(SH@9&%T82YP:'`Z,3DW
M"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E
M;G1S('1O('1H92!S96QE8W1E9"!C86QE;F1A<BXB"FUS9W-T<B`B(@HBUFYN
M96L@;FEN8W,@:F]G;W-U;'1SX6=A(&5L9F]G;&%L='/A9V]K870@8F7M<FYI
M82!A(&MI=N%L87-Z=&]T="!N87!TX7)B82XB"@HC.B!D96QE=F5N=&%C=&EO
M;BYP:'`Z,C8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M(&1E;&5T92!T:&ES(&5V96YT+B(*;7-G<W1R("+6;FYE:R!N:6YC<R!J;V=O
M<W5L='/A9V$@=/9R]FQN:2!E>G0@87H@96QF;V=L86QT<^%G;W0N(@H*(SH@
M961I=&5V96YT86-T:6]N+G!H<#HW.`IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@961I="!T:&ES(&5V96YT+B(*;7-G<W1R("+6;FYE
M:R!N:6YC<R!J;V=O<W5L='/A9V$@;?-D;W/M=&%N:2!E>G0@87H@96QF;V=L
M86QT<^%G;W0N(@H*(SH@9&%T82YP:'`Z,3DR"FUS9VED(")9;W4@:&%V92!S
M<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BXB"FUS9W-T<B`B2&EBX7,O
M96QF;V=A9&AA=&%T;&%N(&$@;65G861O='0@;F%P=.%R+B(*"B,Z(&%T=&5N
M9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E<'1E
M9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(M9N(&5L9F]G
M861T82!A(&UE9VCM=N%S="!E<G)E(&%Z(&5L9F]G;&%L='/A9W)A+B(*"B,Z
M(&%T=&5N9"YP:'`Z,C8*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!D
M96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(M9N
M('9I<W-Z875T87/M=&]T=&$@82!RZ7-Z=NET96QT(&5Z96X@87H@96QF;V=L
M86QT<^%G;VXN(@H*(SH@871T96YD+G!H<#HS,0IM<V=I9"`B66]U(&AA=F4@
M=&5N=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT
M+B(*;7-G<W1R("+6;B!F96QTZ71E;&5S96X@96QF;V=A9'1A(&$@;65G:.UV
MX7-T+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.3$*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(D5L]7-Z
M]G(@:VD@:V5L;"!VX6QA<WIT86YI82!A('3V<FQE;F3U(&YA<'3A<G0N(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHU-`IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(D5L
M]7-Z]G(@:VD@:V5L;"!VX6QA<WIT86YI82!E9WD@8^UM970N(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3$Q-`IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B
M92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@861D960@=&\@>6]U<B!C86QE
M;F1A<G,N(@IM<V=S='(@(LER=&5S[73I<W0@:^ER="!A(&YA<'3A<F%I8F%N
M(&UE9VIE;&5N]2#Z:B!E;&9O9VQA;'1SX6=O:W+S;"XB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,3(T"FUS9VED("(B"B)9;W4@<F5Q=65S=&5D('1O(&)E
M(&YO=&EF:65D('=H96X@979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U<B!C
M86QE;F1A<G,N(@IM<V=S='(@(LER=&5S[73I<W0@:^ER="!A(&YA<'3A<F%I
M8O-L('3V<O9L="!E;&9O9VQA;'1SX6=O:W+S;"XB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,3$Y"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF
M:65D('=H96X@979E;G1S(&%R92!E9&ET960@:6X@>6]U<B!C86QE;F1A<G,N
M(@IM<V=S='(@(LER=&5S[73I<W0@:^ER="!A(&YA<'3A<F%I8F%N(&WS9&]S
M[71O='0@96QF;V=L86QT<^%G;VMR\VPN(@H*(SH@;&EB+U-C:&5D=6QE<B]K
M<F]N;VQI=&@N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5Q
M=65S=&5D('1O(&)E(')E;6EN9&5D(&%B;W5T("5S+"!W:&EC:"!I<R!O;B`E
M<R!A="`E<RXB"FUS9W-T<B`B(@HBUFX@9FEG>65L;65Z=&5TZ7-T(&OI<G0@
M)7,@96QF;V=L86QT<^%G9V%L(&MA<&-S;VQA=&)A;BP@86UI;F5K(&ED]7!O
M;G1J82`E(@HB<RP@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O<VAA<F5S96QE
M8W0N:6YC.C$P"FUS9VED(")9;W5R(&1E9F%U;'0@8V%L96YD87(B"FUS9W-T
M<B`B07H@UFX@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@;F%P=.%R82(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$P-C$@;&EB+T1R:79E<BYP:'`Z,3`W,0IM<V=I
M9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(EME;&YE=F5ZZ7,@;NEL:_QL
M:2!E;&9O9VQA;'1SX6==(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M.34*;7-G:60@(E]!;&%R;2(*;7-G<W1R(")&:6=Y96QM97IT973I<R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,0IM<V=I
M9"`B7T)A<VEC(%-E87)C:"(*;7-G<W1R(")+97)E<^ES(@H*(SH@=FEE=V5V
M96YT+G!H<#HQ,S4*;7-G:60@(E]%9&ET(@IM<V=S='(@(DWS9&]S[73A<R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-3`*;7-G:60@(E]';W1O(@IM<V=S
M='(@(E]59W+A<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-38*;7-G:60@
M(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(DEM<&]R="]?17AP;W)T(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,S-PIM<V=I9"`B7TUY($-A;&5N9&%R<R(*
M;7-G<W1R(").87!TX7)A:5]M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,T
M-`IM<V=I9"`B7TYE=R!%=F5N="(*;7-G<W1R("+:7VH@96QF;V=L86QT<^%G
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,V,0IM<V=I9"`B7U!R:6YT(@IM
M<V=S='(@(E].>6]M=&%TX7,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S4R
M"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(DME<F5?<^ES(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,T-PIM<V=I9"`B7U1O9&%Y(@IM<V=S='(@(DU?82(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$T,`IM<V=I9"`B8F5F;W)E
M('1H92!E=F5N="!S=&%R=',B"FUS9W-T<B`B87H@97-E;>EN>2!E;/5T="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G
M<W1R(")N87`B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C`W"FUS9VED(")D87DH<RDB"FUS9W-T
M<B`B;F%P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(FYA<"(*"B,Z(&1A
M=&$N<&AP.C$U,"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@
M(F5V96YT<RYC<W8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3<Q"FUS9VED
M(")E=F5N=',N:6-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3,V"FUS9VED(")I;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-R!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,S,*;7-G:60@(FUO;G1H*',I(@IM<V=S
M='(@(BX@:/-N87`B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#0P"B,L('!H
M<"UF;W)M870*;7-G:60@(F]N("5S(&%T("5S(@IM<V=S='(@(B5S+"`E<R(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,C<*;7-G:60@(F]N('1H92!S86UE(&1A=&4B"FUS9W-T
M<B`B(&$@:/-N87`@=6=Y86YA>F]N(&YA<&KA;B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S,*
M;7-G:60@(F]N('1H92!S86UE('=E96MD87DB"FUS9W-T<B`B(&$@:.ET('5G
M>6%N87IO;B!N87!JX6XB"@HC.B!D871A+G!H<#HR.2!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$T"FUS9VED(")V0V%L96YD87(O:4-A;&5N9&%R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,U,"!L:6(O87!I+G!H<#HV,CD*
M;7-G:60@(G9%=F5N="!N;W0@9F]U;F0N(@IM<V=S='(@(D$@=D5V96YT(&YE
M;2!T86SA;&AA=/,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B=V5E:R(*;7-G<W1R(")HZ70B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$T"FUS9VED
M(")W965K*',I(&]N.B(*;7-G<W1R("(N(&CI=&5N(&$@:_9V971K97KU(&YA
M<"AO:REO;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DR(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.3,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y-`IM<V=I9"`B=V5E:W,B"FUS9W-T<B`B:.ET(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S
M.0IM<V=I9"`B>65A<BAS*2(*;7-G<W1R("(N(.EV8F5N(@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]K<F]N;VQI=&@O<&\O9FE?1DDN<&\`````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,3,T-34R`#$P-#$W,S8R-S4R`#`R,#,W-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C($9I
M;FYI<V@@=')A;G-L871I;VX@9F]R($MR;VYO;&ET:"X*(R!#;W!Y<FEG:'0@
M*$,I"B,@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3XL(#(P,#,M,C`P-BX*
M(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2W)O
M;F]L:71H(#(N,2UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP
M,BTR,"`Q,SHP,RLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R
M+3$X(#$R.C4Y*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@3&5E;F$@2&5I
M;F\@/&QI:6YU0'5T82YF:3Y<;B(*(DQA;F=U86=E+51E86TZ($9I;FYI<V@@
M/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U
M.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&-A;&5N9&%R<R!F;W5N9"(*;7-G<W1R(")L]GET
M>6D@)60@:V%L96YT97)I82(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&5V96YT<R(*;7-G<W1R
M("(E9"!T87!A:'1U;6%A(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE
M<W!A;BYI;F,Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S($1A>2AS*2`E
M<R!(;W5R*',I("5S($UI;G5T97,B"FUS9W-T<B`B)7,@4.1I=N3D("5S(%1U
M;G1I82`E<R!-:6YU=71T:6$B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#`X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T=&5N9&5E<R(*;7-G<W1R("(E<R!O
M<V%L;&ES='5J86$B"@HC.B!D871A+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B
M)7,@=&EE9&]S=&]N('1U;VYT:2!O;FYI<W1U:2(*"B,Z(&-A;&5N9&%R<RYP
M:'`Z,3`U(&QI8B]B87-E+G!H<#HQ,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<SIN(&MA;&5N=&5R:2(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L
M:6-K(&]N(&-A;&5N9&%R(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S
M('9I<VEB:6QI='D@:6X@=&AE(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(B
M"B(H3F%P<V%U=&$@:V%L96YT97)I;B!N:6UEY"!V86EH=&%A:W-E<VD@:V%L
M96YT97)I;B!NY&MY=GEY='3D('#DY&EK:W5N87-S82DB"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V-0IM<V=I9"`B*B!!9&0@=&AE
M<V4@8GD@8VQI8VMI;F<@061D("HB"FUS9W-T<B`B*B!,:7/DY"!NY&WD(&YA
M<&%U='1A;6%L;&$@3&ESY.0M<&%I;FEK971T82`J(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-3$*;7-G:60@(BH@4&QE87-E('-E
M;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@(BH@5F%L:71S92!O<V]I='1E
M970@*B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X,#<*;7-G:60@(C$@871T96YD
M964B"FUS9W-T<B`B,2!O<V%L;&ES='5J82(*"B,Z('1E;7!L871E<R]S96%R
M8V@O:&5A9&5R+FEN8SHT"FUS9VED("(Q(&5V96YT(@IM<V=S='(@(C$@=&%P
M86AT=6UA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B
M,2!H;W5R(@IM<V=S='(@(C$@='5N=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,T"FUS9VED("(Q-2!M:6YU=&5S(@IM<V=S='(@(C$U(&UI;G5U
M='1I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(C(P
M(&UI;G5T97,B"FUS9W-T<B`B,C`@;6EN=75T=&EA(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B,S`@;6EN=71E<R(*;7-G<W1R("(S
M,"!M:6YU=71T:6$B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-CD*
M;7-G:60@(CQS=')O;F<^071T96YD965S/"]S=')O;F<^("AO<'1I;VYA;"DB
M"FUS9W-T<B`B/'-T<F]N9SY/<V%L;&ES='5J870\+W-T<F]N9SX@*'9A<&%A
M96AT;VEN96XI(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30W"FUS
M9VED("(\<W1R;VYG/D1E<V-R:5]P=&EO;CPO<W1R;VYG/B`H;W!T:6]N86PI
M(@IM<V=S='(@(CQS=')O;F<^2W5V85]U<SPO<W1R;VYG/B`H=F%P86%E:'1O
M:6YE;BDB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-S0*;7-G:60@
M(CQS=')O;F<^2V5Y=V]R9',\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R
M("(\<W1R;VYG/D%V86EN<V%N870\+W-T<F]N9SX@*'9A<&%A96AT;VEN96XI
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DR"FUS9VED("(\<W1R
M;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\
M<W1R;VYG/E1O:7-T=79U=7,\+W-T<F]N9SX@*'9A<&%A96AT;VEN96XI(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,3,@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ.3,*;7-G:60@(D%-(@IM<V=S='(@(D%-(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-C`R"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R
M(")(>7;D:W-Y='1Y(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C$Q"FUS9VED(")!9%]V86YC960@4V5A<F-H(@IM<V=S='(@(E1A7W)K96UP
M:2!H86MU(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M-C`*;7-G:60@(D%D9"(*;7-G<W1R("),:7/DY"(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(R"FUS9VED(")!9&0@179E;G0B"FUS9W-T<B`B3&ES
MY.0@=&%P86AT=6UA(@H*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?
M;6%N86=E;65N="YI;F,Z,S4*;7-G:60@(D%D9"!A(&YE=R!296UO=&4@0V%L
M96YD87(B"FUS9W-T<B`B3&ESY.0@=75S:2!E=.1K86QE;G1E<FDB"@HC.B!A
M9&1E=F5N="YP:'`Z-C0*;7-G:60@(D%D9"!A(&YE=R!E=F5N="(*;7-G<W1R
M("),:7/DY"!U=7-I('1A<&%H='5M82(*"B,Z('1E;7!L871E<R]A='1E;F1E
M97,O871T96YD965S+FEN8SHW,0IM<V=I9"`B061D(&%T=&5N9&5E<R(*;7-G
M<W1R("),:7/DY"!O<V%L;&ES='5J870B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$X-0IM<V=I9"`B061D('1O(&%T=&5N9&5E<R(*
M;7-G<W1R("),:7/DY"!O<V%L;&ES='5J:6EN(@H*(SH@8V]N=&%C=',N<&AP
M.C<V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(X"B,Z('1E
M;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHW-`IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(D]S;VET96MI<FIA(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS9W-T
M<B`B5&%R:V5M<&D@:&%K=2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C4S"FUS9VED(")!;&%R;2(*;7-G<W1R(")(Y&QY='ES(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3<X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!D
M87ES(&)E9F]R92(*;7-G<W1R(")(Y&QY=.0@)60@<.1I=N3D(&%I:V%I<V5M
M;6EN(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!;&%R;2`E9"!H;W5R<R!B969O<F4B"FUS9W-T<B`B2.1L>73D("5D
M('1U;G1I82!A:6MA:7-E;6UI;B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@;6EN=71E<R!B969O<F4B
M"FUS9W-T<B`B2.1L>73D("5D(&UI;G5U='1A(&%I:V%I<V5M;6EN(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z,3<W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R
M;2`E9"!W965K<R!B969O<F4B"FUS9W-T<B`B2.1L>73D("5D('9I:6MK;V$@
M86EK86ES96UM:6XB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@R"FUS9VED(")!
M;&%R;2`Q(&1A>2!B969O<F4B"FUS9W-T<B`B2.1L>73D(#$@<.1I=N0@86EK
M86ES96UM:6XB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@W"FUS9VED(")!;&%R
M;2`Q(&AO=7(@8F5F;W)E(@IM<V=S='(@(DCD;'ETY"`Q('1U;G1I(&%I:V%I
M<V5M;6EN(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<Y,@IM<V=I9"`B06QA<FT@
M,2!M:6YU=&4@8F5F;W)E(@IM<V=S='(@(DCD;'ETY"`Q(&UI;G5U='1I82!A
M:6MA:7-E;6UI;B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S<*;7-G:60@(D%L
M87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B2.1L>73D(#$@=FEI:VMO(&%I
M:V%I<V5M;6EN(@H*(SH@9&%T82YP:'`Z-3D*;7-G:60@(D%L87)M($1A=&4B
M"FUS9W-T<B`B2.1L>71Y<W#D:7;D;>3D<N0B"@HC.B!D871A+G!H<#HU.`IM
M<V=I9"`B06QA<FT@4W!A;B`H;6EN=71E<RDB"FUS9W-T<B`B2.1L>71Y:W-E
M;B!P:71U=7,@*&UI;G5U='1E:6YA*2(*"B,Z(&1A=&$N<&AP.C8P"FUS9VED
M(")!;&%R;2!4:6UE(@IM<V=S='(@(DCD;'ET>7-A:6MA(@H*(SH@=&5M<&QA
M=&5S+V1E;&5T92]D96QE=&4N:6YC.C,T"FUS9VED(")!;&PB"FUS9W-T<B`B
M2V%I:VMI(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,3(X(&QI8B]&0E9I97<N<&AP
M.C$S,2!L:6(O1D)6:65W+G!H<#HQ,S0*;7-G:60@(D%L;"!!='1E;F1E97,B
M"FUS9W-T<B`B2V%I:VMI(&]S86QL:7-T=6IA="(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHU.0IM<V=I9"`B06QL($9U='5R92(*;7-G<W1R
M(")+86EK:VD@='5L979A="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHU,PIM<V=I9"`B06QL(%!A<W0B"FUS9W-T<B`B2V%I:VMI(&UE;FYE
M970B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4@;&EB+T)L;V-K+VUO
M;G1H+G!H<#HR-`HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C<@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C<*;7-G:60@(D%L;"!6:7-I8FQE
M(@IM<V=S='(@(DMA:6MK:2!NY&MY=N1T(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I=%]T:6UE<W!A;BYI;F,Z,3(R(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O
M1&%Y5FEE=RYP:'`Z.3,*(SH@;&EB+T1R:79E<BYP:'`Z,3@W,"!L:6(O5V5E
M:U9I97<N<&AP.C$R-R!L:6(O5V5E:U9I97<N<&AP.C$S-`IM<V=I9"`B06QL
M(&1A>2(*;7-G<W1R(")+;VMO('#D:7;D;B(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@979E;G0B"FUS9W-T<B`B2V]K
M;R!PY&EVY&X@=&%P86AT=6UA(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHS,PIM<V=I9"`B06QL(&5V96YT<R(*;7-G<W1R(")+86EK:VD@=&%P
M86AT=6UA="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D
M+FEN8SHT.`HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI
M;F,Z-S`@;&EB+TMR;VYO;&ET:"YP:'`Z-CDU"FUS9VED(")!;GDB"FUS9W-T
M<B`B36EKY"!T86AA;G-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-S$*;7-G:60@(D%P<FEL(@IM<V=S='(@(FAU:'1I:W5U(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,SD@=&5M<&QA=&5S
M+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHX,B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$V.`IM
M<V=I9"`B070B"FUS9W-T<B`B2V5L;&\B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#0V"FUS9VED("(B"B)!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL
M92!W:71H(&UO<F4@:6YF;W)M871I;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y
M;W5R("(*(FUA:6P@8VQI96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U
M(&-A;B!U<V4@=&AI<R!F:6QE('1O(&5A<VEL>2!U<&1A=&4@(@HB>6]U<B!L
M;V-A;"!C;W!Y(&]F('1H92!E=F5N="XB"FUS9W-T<B`B(@HB3&EI='1E96YA
M(&]N(&E#86QE;F1A<B!T:65D;W-T;RP@:F]S<V$@;VX@;&ESY'1I971O:F$@
M=&%P86AT=6UA<W1A+B!*;W,@(@HB<^1H:_9P;W-T:6]H:F5L;6%S=&D@='5K
M964@:51I<"!P>7EN=/9JY"P@;FEI;B!V;VET('3D;>1N('1I961O<W1O;B!A
M=G5L;&$@(@HB<.1I=FET=.3D('1I961O=&\@<&%I:V%L;&ES965N(&MO<&EO
M;VXN(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,@IM<V=I9"`B071T96YD86YC
M92(*;7-G<W1R(")/<V%L;&ES='5M:6YE;B(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$V,0IM<V=I9"`B071T96YD965S(@IM<V=S='(@(D]S86QL
M:7-T=6IA="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<U
M"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B96QO:W5U(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHX"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B
M66MS:6YK97)T86EN96X@:&%K=2(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N
M9&ES=#HQ-PIM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B4WEN='EMY'#D:7;D
M(@H*(SH@;&EB+T9"5FEE=RYP:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$Q"FUS
M9VED(")"=7-Y(@IM<V=S='(@(E9A<F%T='4B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#(*;7-G:60@(D-?86QE;F1A<B(*
M;7-G<W1R(")?2V%L96YT97)I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z-#<*;7-G:60@(D-A;%]E;F1A<B(*;7-G<W1R(")+7V%L96YT97)I(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$T.2!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HR
M,2!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C$*(SH@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,C$*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA
M;&5N=&5R:2(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(")#
M86QE;F1A<B!3=6UM87)Y(@IM<V=S='(@(DMA;&5N=&5R:6X@>6AT965N=F5T
M;R(*"B,Z(&1A=&$N<&AP.C(S,PIM<V=I9"`B0V%L96YD87(@<W5C8V5S<V9U
M;&QY('!U<F=E9"XB"FUS9W-T<B`B2V%L96YT97)I;B!P;VES=&\@;VYN:7-T
M=6DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4W"FUS9VED(")#86QE;F1A<G,B"FUS9W-T
M<B`B2V%L96YT97)I="(*"B,Z(&-A;&5N9&%R<RYP:'`Z,C<*;7-G:60@(D-A
M;&5N9&%R<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R(")+86QE;G1E<FEL
M;&$@<&ETY.0@;VQL82!N:6UI+B(*"B,Z(&1A=&$N<&AP.C(T.`IM<V=I9"`B
M0V%N)W0@8W)E871E(&$@;F5W(&5V96YT+B(*;7-G<W1R(")%:2!V;VED82!L
M=6]D82!U=71T82!T87!A:'1U;6%A;BXB"@HC.B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHS,2!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#<*(SH@=&5M
M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,U('1E;7!L871E<R]D96QE=&4O
M;VYE+FEN8SHS,PIM<V=I9"`B0V%N8V5L(@IM<V=S='(@(E!E<G4B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HU-S@*;7-G:60@(D-A;F-E;&QE9"(*;7-G<W1R
M(")097)U='1U(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YC96QL960Z("5S(@IM<V=S='(@(E!E<G5T='4Z
M("5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC
M.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C8W"FUS9VED(")#871E9V]R
M7WDB"FUS9W-T<B`B2V%T96=O<FE?82(*"B,Z(&1A=&$N<&AP.C8R('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$S('1E;7!L871E<R]S96%R8V@O979E;G1?
M:&5A9&5R<RYI;F,Z-`IM<V=I9"`B0V%T96=O<GDB"FUS9W-T<B`B2V%T96=O
M<FEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.0IM<V=I9"`B(@HB
M0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I
M=&5D+"!A;F0@9&5L971E9"!E=F5N=',@8GD@(@HB96UA:6PZ(@IM<V=S='(@
M(B(*(E9A;&ET<V4@:&%L=6%T:V\@<V%A9&$@:6QM;VET=6MS:6$@=75S:7-T
M82P@;75O:V%T=6ES=&$@=&%I('!O:7-T971U:7-T82`B"B)T87!A:'1U;6ES
M=&$@<^1H:_9P;W-T:71S93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(*;7-G:60@(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O
M9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S+B(*;7-G<W1R("(B
M"B)686QI='-E(&AA;'5A=&MO('-A861A(&EL;6]I='5K<VEA('5U<VES=&$L
M(&UU;VMA='5I<W1A('1A:2!P;VES=&5T=6ES=&$@(@HB=&%P86AT=6UI<W1A
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3(*;7-G:60@(D-H;V]S
M92!I9B!Y;W4@=V%N="!T;R!R96-E:79E(&5M86EL(')E;6EN9&5R<R!F;W(@
M979E;G1S('=I=&@@86QA<FUS.B(*;7-G<W1R("(B"B)686QI='-E(&AA;'5A
M=&MO('-A861A(&UU:7-T=71U:W-I82!SY&AK]G!O<W1I='-E('1A<&%H='5M
M:7-T82P@:F]I:&EN(&]N("(*(FQI:71E='1Y(&CD;'ET>7,Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-E87)C:%]A8F]O:U]S96QE8W0N:6YC.C$Y(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,3(*;7-G:60@(D-H;V]S92!T:&4@861D<F5S
M<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.B(*;7-G<W1R
M(")686QI='-E(&]S;VET96MI<FIA="P@:F]I<W1A(&5T<VETY.1N('9A<&%A
M+W9A<F%T='4@55),96IA.B(*"B,Z('1E;7!L871E<R]P<F5F<R]F8E]C86QS
M7W-E;&5C="YI;F,Z,38*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O
M(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXZ(@IM<V=S
M='(@(E9A;&ET<V4@:V%L96YT97)I="P@:F]T:V$@:&%L=6%T(&QI:71E='3D
M=N0@=F%P86$O=F%R871T=2!L:7-T875K<VEI;CHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S(T"FUS9VED(")#:&]O<V4@=&AE(&-A;&5N9&%R<R!T
M;R!I;F-L=61E('=H96X@9V5N97)A=&EN9R!F<F5E+V)U<WD@55),<SHB"FUS
M9W-T<B`B5F%L:71S92!K86QE;G1E<FET+"!J;VES=&$@=&5H9.3D;B!V87!A
M82]V87)A='1U(%523&5J83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@*;7-G:60@(D-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S
M='(@(E9O:70@=F%L:71A(&]L971U<VMA;&5N=&5R:7-I+B(*"B,Z('1E;7!L
M871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHX-`IM<V=I9"`B0VQE87(@
M86QL(&%T=&5N9&5E<R(*;7-G<W1R(")0;VES=&$@:V%I:VMI(&]S86QL:7-T
M=6IA="(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V
M"FUS9VED(")#;&]S92!W:6YD;W<B"FUS9W-T<B`B4W5L:F4@:6MK=6YA(@H*
M(SH@9&%T82YP:'`Z,C@@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,PIM
M<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")0:6QK=6EL
M;&$@97)O=&5T=70@87)V;W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S,*;7-G:60@(D-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S/R(*;7-G<W1R
M(")687)M:7-T82!T87!A:'1U;6EE;B!P;VES=&\N(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3<U"FUS9VED(")#;VYF:7)M960B"FUS9W-T<B`B5F%R;6ES
M=&5T='4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M,C$W"FUS9VED(")#;W!Y('1H92!54DP@8F5L;W<@9F]R('5S92!W:&5R979E
M<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ(@IM<V=S='(@(DMO<&EO
M:2!A;&QA(&]L979A(%523"!S:6YN92!M:6YN92!T87)V:71S970@=F%P86$O
M=F%R871T=2!54DPZY.0Z(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,38S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M(")%:2!V;VET=2!A=6MA:7-T82`E<RXB"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,3(Y"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B
M3'5O(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q
M-0IM<V=I9"`B0W)E871E($-A;&5N9&%R(@IM<V=S='(@(DQU;R!K86QE;G1E
M<FDB"@HC.B!M;VYT:"YP:'`Z,38S('1E;7!L871E<R]W965K+VAE860N:6YC
M.C(U('1E;7!L871E<R]D87DO<F]W+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H
M<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z,3DU"FUS9VED(")#<F5A=&4@82!.97<@
M179E;G0B"FUS9W-T<B`B3'5O('5U<VD@=&%P86AT=6UA(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z.#`*;7-G:60@(D-R96%T960B"FUS9W-T<B`B
M3'5O='4B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S(*;7-G
M:60@(D-U<G)E;G0B"FUS9W-T<B`B3GEK>6EN96XB"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`V
M"FUS9VED(")$86EL>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(E#D:79I='3D
M:6XZ(%1O:7-T=79U=61E;B!VY&QI(@H*(SH@871T96YD965S+G!H<#HQ,#8@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,R!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*;7-G:60@(D1A>2(*
M;7-G<W1R(")0Y&EVY"(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8R
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S-PIM<V=I9"`B1&%Y*',I(@IM
M<V=S='(@(E#D:7;DY"(*"B,Z('9I97=E=F5N="YP:'`Z,3$Q"FUS9VED(")$
M95]L971E(@IM<V=S='(@(E!O7VES=&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHW.0IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B:F]U
M;'5K=74B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,#4*;7-G:60@(D1E8VQI
M;F5D(@IM<V=S='(@(DMI96QTY'ET>6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<*;7-G:60@(D1E9F%U;'0@0V%L96YD87(B"FUS9W-T<B`B3VQE
M='5S:V%L96YT97)I(@H*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?
M;6%N86=E;65N="YI;F,Z,C,@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,R
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,#0@;&EB
M+T1R:79E<BYP:'`Z,3@U,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(E!O:7-T
M82(*"B,Z(&1E;&5V96YT+G!H<#HT,"!T96UP;&%T97,O9&5L971E+V1E;&5T
M92YI;F,Z,C$@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(Q"B,Z(&QI8B]$
M<FEV97(N<&AP.C$X-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S
M(@IM<V=S='(@(E!O:7-T82`E<R(*"B,Z(&5D:71E=F5N="YP:'`Z-S(*;7-G
M:60@(D1E;&5T92!%=F5N="(*;7-G<W1R(")0;VES=&$@=&%P86AT=6UA(@H*
M(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,P"FUS9VED("(B"B)$
M96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E
M(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R("(*(F%L;"!O8V-U<F5N
M8V5S/R(*;7-G<W1R("(B"B)0;VES=&$@=F%I;B!TY&WD('1A<&%H='5M82P@
M=.1MY"!T87!A:'1U;6$@:F$@:V%I:VMI('-E;B!T;VES:6YN;W0@=F%I("(*
M(FMA:6MK:2!TY&CD;B!T87!A:'1U;6%A;B!L:6ET='EVY'0N(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$P,R!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z,C@*;7-G:60@(D1E<V-R:5]P=&EO;B(*
M;7-G<W1R(")+=5]V875S(@H*(SH@9&%T82YP:'`Z-C$@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z.38*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$W.`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B2W5V875S
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S0*;7-G
M:60@(D1I<W!L87DB"FUS9W-T<B`B3N1Y=.0B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z-C,*;7-G:60@(D1I<W!L87D@0V%L96YD
M87)S(@IM<V=S='(@(D[D>73D(&MA;&5N=&5R:70B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(X"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS
M9W-T<B`B3N1K>6WD;B!A<V5T=6MS970B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S`*;7-G:60@(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI
M8V@@87)E(&1U92!O;B!Y;W5R(&-A;&5N9&%R/R(*;7-G<W1R(").Y'ETY"!K
M86QE;G1E<FES<V$@;F4@=&5H=.1VY'0L(&IO=&MA('!I=.1I<VD@;VQL82!V
M86QM:6EN82XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#4*;7-G:60@(D1O
M97,@;F]T(')E8W5R(@IM<V=S='(@(D5I('1O:7-T=2(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$=64Z("5S(@IM
M<V=S='(@(E9A;&UI<W1U=3H@)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET
M7W1I;65S<&%N+FEN8SHQ,34*;7-G:60@(D1U<F%T:6]N(@IM<V=S='(@(DME
M<W1O(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W
M,R!L:6(O1')I=F5R+G!H<#HQ.#,W"FUS9VED(")%9&ET(@IM<V=S='(@(DUU
M;VMK86$B"@HC.B!E9&ET979E;G0N<&AP.C,S('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(R(&QI8B]$<FEV97(N<&AP.C$X,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="`E<R(*;7-G<W1R(")-=6]K:V%A("5S(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3@U"FUS9VED(")%9&ET($%T=&5N9&5E<R(*
M;7-G<W1R(")-=6]K:V%A(&]S86QL:7-T=6II82(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#,*;7-G:60@(D5D:70@0V%L96YD
M87)S(@IM<V=S='(@(DUU;VMK86$@:V%L96YT97)E:71A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(U,`IM<V=I9"`B161I="!296UO=&4@0V%L96YD
M87)S(@IM<V=S='(@(DUU;VMK86$@973D:V%L96YT97)E:71A(@H*(SH@871T
M96YD965S+G!H<#HQ-#8*;7-G:60@(D5D:70@871T96YD965S(@IM<V=S='(@
M(DUU;VMK86$@;W-A;&QI<W1U:FEA(@H*(SH@=&5M<&QA=&5S+V-A=&5G;W)Y
M7VQE9V5N9"YI;F,Z,C`*;7-G:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L
M;W)S(@IM<V=S='(@(DUU;VMK86$@:V%T96=O<FEO:71A(&IA(';D<F5JY"(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-"!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$W-PHC.B!T96UP;&%T97,O871T96YD965S
M+V%T=&5N9&5E<RYI;F,Z-#$*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T
M<B`B4^1H:_9P;W-T:6]S;VET92(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C8P"FUS9VED(")%;E]D(@IM<V=S='(@(E#DY'1T>5]Y
M(@H*(SH@9&%T82YP:'`Z-38*;7-G:60@(D5N9"!$871E(@IM<V=S='(@(E#D
MY'1T>6UI<W#D:7;D;>3D<N0B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHT-R!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C@*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,C`*;7-G:60@(D5N9"!/;B(*
M;7-G<W1R(")0Y.1T='EY(@H*(SH@9&%T82YP:'`Z-3<*;7-G:60@(D5N9"!4
M:6UE(@IM<V=S='(@(E#DY'1T>6UI<V%I:V$B"@HC.B!A='1E;F1E97,N<&AP
M.C$R,"!A='1E;F1E97,N<&AP.C$S,2!A='1E;F1E97,N<&AP.C$S.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!F;W(@)7,Z("5S(@IM<V=S='(@(E1A<&%H='5I('9I<FAE
M('1U;W1A97-S82!V87!A82]V87)A='1U('1I971O:F$@)7,Z;&QE.B`E<R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,3,*;7-G:60@(D5V96YT(&%D9&5D
M.B(*;7-G<W1R(")487!A:'1U;6$@;&ESY'1T:6EN.B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$Q,C,*;7-G:60@(D5V96YT(&1E;&5T960Z(@IM<V=S='(@
M(E1A<&%H='5M82!P;VES=&5T=&EI;CHB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,3$X"FUS9VED(")%=F5N="!E9&ET960Z(@IM<V=S='(@(E1A<&%H='5M
M86$@;75O:V%T=&EI;CHB"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#<U"B,L('!H
M<"UF;W)M870*;7-G:60@(D5V96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
M5&%P86AT=6UA(&%L:V%E;B`E<R!L;W!P=65N("5S(@H*(SH@;&EB+T1R:79E
M<B]S<6PN<&AP.C,W,PIM<V=I9"`B179E;G0@;F]T(&9O=6YD(@IM<V=S='(@
M(E1A<&%H='5M86$@96D@;/9Y='EN>70B"@HC.B!L:6(O1')I=F5R+G!H<#HW
M-S$*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E+B(*;7-G
M<W1R(")487!A:'1U;6EL;&$@<&ETY.0@;VQL82!A;&MA;6ES86IA;FMO:'1A
M+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<S-PIM<V=I9"`B179E;G1S(&UU<W0@
M:&%V92!A('1I=&QE+B(*;7-G<W1R(")487!A:'1U;6EL;&$@<&ETY.0@;VQL
M82!O='-I:VMO(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C<U"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T<B`B3&%A:F5N;F$@
M;FEM970B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y.0IM<V=I
M9"`B17AP;W)T(@IM<V=S='(@(E9I92(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z.`IM<V=I9"`B17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(E9I
M92!K86QE;G1E<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV.0IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B:&5L;6EK=74B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$S,PIM<V=I9"`B1FEN
M9"(*;7-G<W1R(")(86MU(@H*(SH@>65A<BYP:'`Z.#0@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-C,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C$Y"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")&<B(*;7-G
M<W1R(")P92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4X,0IM<V=I9"`B1G)E
M92(*;7-G<W1R(")687!A82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.`IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(E9A<&%A
M+W9A<F%T='4@=&EE=&]J82(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q.2!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C`*(SH@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@(D9R:61A>2(*;7-G<W1R
M(")P97)J86YT86DB"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z
M,S,*;7-G:60@(D9U='5R92(*;7-G<W1R(")4=6QE=F%T(@H*(SH@8V]N9FEG
M+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")'86UE(@IM<V=S='(@(E!E
M;&DB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z
M,C,*;7-G:60@(D=E;F5R86PB"FUS9W-T<B`B66QE:6YE;B(*"B,Z(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V]T
M;R`E<R(*;7-G<W1R(")-96YE("5S(@H*(SH@;6]N=&@N<&AP.C$S,R!T96UP
M;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA
M=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*;7-G:60@(DAI9&4B
M"FUS9W-T<B`B4&EI;&]T82(*"B,Z(&UO;G1H+G!H<#HQ,S,@=&5M<&QA=&5S
M+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D
M87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G
M:60@(DAI9&4@)7,B"FUS9W-T<B`B4&EI;&]T82`E<R(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C8U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S
M-@IM<V=I9"`B2&]U<BAS*2(*;7-G<W1R(")4=6YT:6$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")(;W<@;&]N9R!S:&]U;&0@=&AE
M('1I;64@<VQO=',@;VX@=&AE(&1A>2!A;F0@=V5E:R!V:65W<R!B93\B"FUS
M9W-T<B`B2W5I;FMA('!I=&OD(&]N(&%I:V%L;VME<F\@<.1I=N0M(&IA('9I
M:6MK;V[D:WEM:7-SY#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`Q
M"FUS9VED(")(;W<@;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B!S:&]U;&0@=V4@9V5N97)A=&4_(@IM<V=S='(@(DUO;F5L;&5K;R!T=6QE
M=F%L;&4@<.1I=N1L;&4@;'5O9&%A;B!V87!A82]V87)A='1U("UT:65T;VIA
M/R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB268@>6]U<B!E;6%I;"!C;&EE;G0@9&]E<VXG="!S=7!P;W)T
M(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@;VYE(&]F('1H92`B"B)F;VQL
M;W=I;F<@;&EN:W,@=&\@86-C97!T(&]R(&1E8VQI;F4@=&AE(&5V96YT+EQN
M(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT.EQN(@HB)7-<;B(*(EQN(@HB
M5&\@86-C97!T('1H92!E=F5N="!T96YT871I=F5L>3I<;B(*(B5S7&XB"B)<
M;B(*(E1O(&1E8VQI;F4@=&AE(&5V96YT.EQN(@HB)7,B"FUS9W-T<B`B(@HB
M2F]S('/D:&OV<&]S=&EO:&IE;&UA<VD@96D@='5E(&E4:7`@<'EY;G3V:N0L
M(&YI:6X@=F]I(&OD>71TY.0@86QL82!O;&5V:6$@(@HB;&EN:VME:N0@;W-A
M;&QI<W1U86MS97-I('1A:2!K:65L=.1Y='GD(&]S86QL:7-T=6UA<W1A('1A
M<&%H='5M86%N+EQN(@HB7&XB"B)(>7;D:W-YY"!T87!A:'1U;6%N.EQN(@HB
M)7-<;B(*(EQN(@HB06QU<W1A=F%S=&D@:'EVY&MS>>0@=&%P86AT=6UA;CI<
M;B(*(B5S7&XB"B)<;B(*(DMI96QTY'ET>>1K<V5S:2!T87!A:'1U;6%S=&$Z
M7&XB"B(E<R(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G0@0V%L96YD87(L(%-T97`@)60B"FUS
M9W-T<B`B2V%L96YT97)I;B!T=6]N=&DL(&%S:V5L("5D(@H*(SH@9&%T82YP
M:'`Z,C@X"FUS9VED("));7!O<G0O17AP;W)T($-A;&5N9&%R(@IM<V=S='(@
M(E1U;R]6:64@:V%L96YT97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-C@*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B=&%M;6EK=74B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-`IM<V=I9"`B
M2G5L>2(*;7-G<W1R(")H96ENY&MU=2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<S"FUS9VED(")*=6YE(@IM<V=S='(@(FME<^1K=74B
M"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-#(*
M;7-G:60@(DME>7=O<F1S(@IM<V=S='(@(D%V86EN<V%N870B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-34*;7-G:60@(DQA<W0@,C0@:&]U
M<G,B"FUS9W-T<B`B161E;&QI<V5T(#(T('1U;G1I82(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C@W"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S
M='(@(DUU;VMA='1U('9I:6UE:W-I(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C0@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN
M8SHT"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M,3`*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ
M-@IM<V=I9"`B3&%S="!-;VYT:"(*;7-G<W1R(")%9&5L;&EN96X@:W5U:V%U
M<VDB"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHT"FUS9VED("),87-T
M(%EE87(B"FUS9W-T<B`B161E;&QI;F5N('9U;W-I(@H*(SH@=&5M<&QA=&5S
M+W=E96LO:&5A9"YI;F,Z,R!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M-30*;7-G:60@(DQA<W0@=V5E:R(*;7-G<W1R(")%9&5L;&EN96X@=FEI:VMO
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR.0IM<V=I9"`B3&EM
M:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z(@IM<V=S='(@(E)A:F]I=&$@
M=FEE;FYI;B!A:6MA:6MK=6YA83HB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:%]A9'9A;F-E9"YI;F,Z.#4@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M-S0*;7-G:60@(DQO7V-A=&EO;B(*;7-G<W1R(")086E?:VMA(@H*(SH@9&%T
M82YP:'`Z-C,@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C$@=&5M<&QA=&5S
M+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHU"B,Z('1E;7!L871E<R]P<F5F
M<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$X"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C4R(&QI8B]$<FEV97(N
M<&AP.C$X.#<*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E!A:6MK82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-0IM<V=I9"`B36%N86=E(')E;6]T
M92!C86QE;F1A<G,N(@IM<V=S='(@(E9O:70@:&%L;&ET82!E=.1K86QE;G1E
M<F5J82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,`IM
M<V=I9"`B36%R8V@B"FUS9W-T<B`B;6%A;&ES:W5U(@H*(SH@;&EB+V%P:2YP
M:'`Z,3`P"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!%=F5N=',B"FUS9W-T
M<B`B5&%P86AT=6UI96X@;6%K<VEM:6WDY'+D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R(")T;W5K
M;VMU=2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X.#0*;7-G:60@(DUE(@IM<V=S
M='(@(E1A(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")-965T:6YG(@IM<V=S='(@(E1A<&%A;6EN96XB"@HC.B!L:6(O0FQO8VLO
M=')E95]A;&%R;7,N<&AP.C,*;7-G:60@(DUE;G4@06QA<FUS(@IM<V=S='(@
M(E9A;&EK:V\@:.1L>71Y:W-E="(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N
M<&AP.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R(")686QI:VMO(&QI<W1A
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C@@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,3,U"FUS9VED(")-:6YU=&4H<RDB"FUS9W-T<B`B36EN
M=75T=&EA(@H*(SH@>65A<BYP:'`Z.#`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"B,Z(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")-;R(*;7-G<W1R(")M82(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-2!T96UP;&%T97,O;6]N
M=&@O:&5A9"YI;F,Z,38*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI
M;F,Z-C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@IM<V=I9"`B36]N9&%Y
M(@IM<V=S='(@(FUA86YA;G1A:2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M,38@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@U"FUS9VED(")-;VYT:"(*;7-G<W1R(")+=75K875S:2(*"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,PIM<V=I9"`B36]N=&@@5FEE=R(*;7-G
M<W1R(")+=75K875S:6[D:WEMY"(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N
M<&AP.C,@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#,*;7-G:60@(DUO;G1H
M;'D@179E;G1S($QI<W0B"FUS9W-T<B`B2W5U:V%U<VET=&%I;F5N('1A<&%H
M='5M86QI<W1A(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,C8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,R"FUS9VED
M(")-;VYT:&QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B2W5U:V%U<VET=&%I
M;CH@5&]I<W1U=G5U9&5N(';D;&DB"@HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T
M+G!H<#HR-`IM<V=I9"`B36]N=&AS($%H96%D(@IM<V=S='(@(E1U;&5V86$@
M:W5U:V%U='1A(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(T
M"FUS9VED(")-;VYT:',@0F5F;W)E(@IM<V=S='(@(DUE;FYY='3D(&MU=6MA
M=71T82(*"B,Z(&QI8B]A<&DN<&AP.C8S-`IM<V=I9"`B375L=&EP;&4@:4-A
M;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S
M=7!P;W)T960N(@IM<V=S='(@(DSV>71Y:2!U<V5I=&$@:4-A;&5N9&%R(&MO
M;7!O;F5N='1E:F$[(%9A:6X@>6MS:2!V179E;G0@;VX@='5E='1U+B(*"B,Z
M(&-A;&5N9&%R<RYP:'`Z,3(X('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHW,`IM<V=I9"`B37D@0V%L96YD87)S(@IM<V=S='(@(DMA;&5N
M=&5R:6YI(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M
M96YU+FEN8SHS-@IM<V=I9"`B37D@0V%L96YD87)S.B(*;7-G<W1R(")+86QE
M;G1E<FEN:3HB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z,C$S"FUS9VED(")->2!&<F5E+T)U<WD@55),(@IM<V=S='(@(E9A<&%A
M+W9A<F%T='4@55),.FEN:2(*"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?
M8V%L7VUA;F%G96UE;G0N:6YC.C$W"B,Z('1E;7!L871E<R]P<F5F<R]R96UO
M=&5?8V%L7VUA;F%G96UE;G0N:6YC.C0T"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$V,@IM<V=I9"`B3F%M92(*;7-G<W1R(").:6UI(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C0Q(&QI8B]";&]C:R]M;VYT:"YP:'`Z-#$@;&EB
M+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#0*(SH@;&EB+T)L;V-K+W1R965?;65N
M=2YP:'`Z,C`*;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R(")5=7-I('1A<&%H
M='5M82(*"B,Z(&QI8B]B87-E+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB3F5W(&-A;&5N9&%R(&-R96%T960@86YD(&%U=&]M871I8V%L;'D@
M<VAA<F5D('=I=&@@9F]L;&]W:6YG(&=R;W5P*',I.B`E<RXB"FUS9W-T<B`B
M(@HB575S:2!K86QE;G1E<FD@;VX@;'5O='4@:F$@875T;VUA871T:7-E<W1I
M(&IA971T=2!S975R86%V:65N(')Y:&UI96X@:V%N<W-A.B`B"B(E<RXB"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,S"FUS9VED(").97AT(@IM
M<V=S='(@(E-E=7)A879A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(E-E=7)A879A
M="`R-"!T=6YT:6$B"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z,CD*;7-G:60@
M(DYE>'0@1&%Y(@IM<V=S='(@(E-E=7)A879A('#D:7;D(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C8@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED
M95]B>5]S:61E+FEN8SHV"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?
M8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ.`IM<V=I9"`B3F5X="!-;VYT:"(*;7-G<W1R(")3975R
M86%V82!K=75K875S:2(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,S(*;7-G
M:60@(DYE>'0@5V5E:R(*;7-G<W1R(")3975R86%V82!V:6EK:V\B"@HC.B!T
M96UP;&%T97,O>65A<B]H96%D+FEN8SHV"FUS9VED(").97AT(%EE87(B"FUS
M9W-T<B`B4V5U<F%A=F$@=G5O<VDB"@HC.B!T96UP;&%T97,O9&%Y+VAE860N
M:6YC.C4*;7-G:60@(DYE>'0@9&%Y(@IM<V=S='(@(E-E=7)A879A('#D:7;D
M(@H*(SH@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-2!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-3@*;7-G:60@(DYE>'0@=V5E:R(*;7-G<W1R(")3
M975R86%V82!V:6EK:V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<U
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.#@*;7-G:60@(DYO(@IM<V=S='(@
M(D5I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S,@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,3(T"FUS9VED(").;R!A;&%R;2(*;7-G<W1R(")%
M:2!HY&QY='ES(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C0X"FUS9VED(").;R!A='1E;F1E97,B"FUS9W-T<B`B16D@;W-A;&QI
M<W1U:F%T(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,@IM<V=I9"`B3F\@
M8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R(")6
M:65R86EL:6IO:6QL92!E:2!O;&4@=&%R:F]L;&$@>6ATY.1N(&MA;&5N=&5R
M:6$N(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,V('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(U,@IM<V=I9"`B3F\@96YD(&1A=&4B"FUS9W-T
M<B`B16D@<.3D='1Y;6ES<.1I=N3D(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$Y-"!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,38T"B,Z(&QI
M8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$V,PIM<V=I9"`B3F\@979E;G1S('1O
M(&1I<W!L87DB"FUS9W-T<B`B16D@=&%P86AT=6UI82!NY'ET971TY';D:W-I
M(@H*(SH@;&EB+U-T;W)A9V4O:V]L86(N<&AP.C0X"B,L('!H<"UF;W)M870*
M;7-G:60@(DYO(&9R964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@
M9F]R("5S(@IM<V=S='(@(E9A<&%A+W9A<F%T='4@=&EE=&]J82`E<SIL;&4@
M96D@;VQE(&]L96UA<W-A(@H*(SH@;&EB+V%P:2YP:'`Z,S0U(&QI8B]A<&DN
M<&AP.C8R-`IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*
M;7-G<W1R(")%:2!L]GET>6YY="!I0V%L96YD87(@=&EE=&]J82XB"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,#$*;7-G:60@(DYO(')E8W5R<F5N
M8V4B"FUS9W-T<B`B16D@=&]I<W1U=G5U<R(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.CDP,@IM<V=I9"`B3F\@=F%L:60@96UA:6P@861D<F5S<R!F;W5N9"(*
M;7-G<W1R(")%:2!L]GET>6YY="!T;VEM:79A82!SY&AK]G!O<W1I;W-O:71E
M='1A+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8Q,B!L:6(O2W)O;F]L:71H
M+G!H<#HV,S,*;7-G:60@(DYO;F4B"FUS9W-T<B`B16D@;6ETY.1N(@H*(SH@
M;&EB+U-T;W)A9V4O<W%L+G!H<#HQ-#4*;7-G:60@(DYO="!F;W5N9"(*;7-G
M<W1R(")%:2!L]GET>6YY="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,0IM<V=I9"`B3F]T:69I8V%T:6]N<R(*;7-G<W1R("));&UO:71U:W-E="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<X"FUS9VED(").
M;W9E;6)E<B(*;7-G<W1R(")M87)R87-K=74B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R(").>70B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-PIM<V=I9"`B3V-T
M;V)E<B(*;7-G<W1R(")L;VMA:W5U(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(B`M("(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y,0IM
M<V=I9"`B3VX@86QL(&-A;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\B
M"FUS9W-T<B`B2V%I:VMI:6X@:V%L96YT97)E:6AI;BP@:F]I:&EN(&UI;G5L
M;&$@;VX@;'5K=6]I:V5U<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y,`IM<V=I9"`B3VX@86QL('-H
M;W=N(&-A;&5N9&%R<R(*;7-G<W1R(")+86EK:6QL82!NY&MY=FEL;.0@;VQE
M=FEI;B!K86QE;G1E<F5I:&EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(W-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@Y"FUS9VED(")/;B!M>2!C
M86QE;F1A<G,@;VYL>2(*;7-G<W1R(")686EN(&]M86QL82!K86QE;G1E<FEL
M;&%N:2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8S,`IM<V=I9"`B3W!T:6]N
M86PB"FUS9W-T<B`B5F%P86%E:'1O:6YE;B(*"B,Z(&QI8B]&0E9I97<N<&AP
M.C$Q.0IM<V=I9"`B3W!T:6]N86P@071T96YD965S(@IM<V=S='(@(DUA:&1O
M;&QI;F5N(&]S86QL:7-T=6IA(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,34T"FUS
M9VED(")/=F5R=FEE=R(*;7-G<W1R(")9;&5I<VMU=F$B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHS-`IM<V=I9"`B3W=N97(B"FUS9W-T<B`B3VUI
M<W1A:F$B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#@S"B,L('!H<"UF;W)M870*
M;7-G:60@(D]W;F5R.B`E<R(*;7-G<W1R(")/;6ES=&%J83H@)7,B"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Q-"!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$Y-`IM<V=I9"`B4$TB"FUS9W-T<B`B4$TB"@HC.B!L:6(O
M0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO<')E=FUO;G1H
M;&ES="YP:'`Z-#(*;7-G:60@(E!A<W0@179E;G1S($QI<W0B"FUS9W-T<B`B
M365N;F5I9&5N('1A<&%H='5M:65N(&QI<W1A(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3`Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y-@IM
M<V=I9"`B4&%T=&5R;B(*;7-G<W1R(")4;VES='5V=75S(@H*(SH@=&5M<&QA
M=&5S+V1E;&5T92]O;F4N:6YC.C,P"FUS9VED(")097)M86YE;G1L>2!D96QE
M=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`B4&]I<W1E=&%A;FMO('3D;>0@=&%P
M86AT=6UA('!Y<WEVY'-T:3\B"@HC.B!L:6(O87!I+G!H<#HS,C8@;&EB+V%P
M:2YP:'`Z-#(R(&QI8B]A<&DN<&AP.C0Y-"!L:6(O87!I+G!H<#HU-S0*(SH@
M;&EB+V%P:2YP:'`Z-C`V(&QI8B]A<&DN<&AP.C8Y,B!L:6(O87!I+G!H<#HW
M,C@*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(DOD>71T]B!K
M:65L;&5T='DB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z,3<P"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")/:6ME=61E="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0IM<V=I9"`B4&]R=&%L($]P
M=&EO;G,B"FUS9W-T<B`B4&]R=&%A;&EN(&%S971U:W-E="(*"B,Z(&QI8B]&
M0E9I97<O9&%Y+G!H<#HR-0IM<V=I9"`B4')E=FEO=7,@1&%Y(@IM<V=S='(@
M(D5D96QL:6YE;B!PY&EVY"(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*
M;7-G:60@(E!R979I;W5S(%=E96LB"FUS9W-T<B`B161E;&QI;F5N('9I:6MK
M;R(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI;F,Z,PIM<V=I9"`B4')E=FEO
M=7,@9&%Y(@IM<V=S='(@(D5D96QL:6YE;B!PY&EVY"(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M-#D*;7-G:60@(E)E8W5R(%5N=&EL(@IM<V=S='(@(E1O:7-T=79U=7,@<.3D
M='1Y>2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$P-@IM<V=I9"`B
M4F5C=7)R96YC92(*;7-G<W1R(")4;VES='5V=75S(@H*(SH@9&%T82YP:'`Z
M-C@*;7-G:60@(E)E8W5R<F5N8V4@1&%T82(*;7-G<W1R(")4;VES='5V=75D
M96X@=&EE9&]T(@H*(SH@9&%T82YP:'`Z-C8*;7-G:60@(E)E8W5R<F5N8V4@
M16YD($1A=&4B"FUS9W-T<B`B5&]I<W1U=G5U9&5N('#DY'1T>6UI<W#D:7;D
M;>3D<N0B"@HC.B!D871A+G!H<#HV-PIM<V=I9"`B4F5C=7)R96YC92!);G1E
M<G9A;"(*;7-G<W1R(")4;VES='5V=75D96X@=N1L:2(*"B,Z(&1A=&$N<&AP
M.C8U"FUS9VED(")296-U<G)E;F-E(%1Y<&4B"FUS9W-T<B`B5&]I<W1U=G5U
M9&5N('1Y>7!P:2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T.`IM<V=I9"`B
M4F5C=7)S(&1A:6QY(@IM<V=S='(@(E1O:7-T=74@<.1I=FET=.1I;B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C4U-0IM<V=I9"`B4F5C=7)S(&UO;G1H;'DB
M"FUS9W-T<B`B5&]I<W1U=2!K=75K875S:71T86EN(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-34Q"FUS9VED(")296-U<G,@=V5E:VQY(@IM<V=S='(@(E1O
M:7-T=74@=FEI:V]I='1A:6XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3@*
M;7-G:60@(E)E8W5R<R!Y96%R;'DB"FUS9W-T<B`B5&]I<W1U=2!V=6]S:71T
M86EN(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296UI;F1E<CH@)7,B"FUS9W-T<B`B375I<W1U
M='5S.B`E<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHY-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0*;7-G:60@(E)E;6]T92!#
M86QE;F1A<G,B"FUS9W-T<B`B173D:V%L96YT97)I="(*"B,Z('1E;7!L871E
M<R]M96YU+FEN8SHV,"!T96UP;&%T97,O;65N=2YI;F,Z-C(*;7-G:60@(E)E
M;6]T92!#86QE;F1A<G,Z(@IM<V=S='(@(D5TY&MA;&5N=&5R:70Z(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y-`IM<V=I9"`B
M4F5M;W1E(%-U8G-C<FEP=&EO;B!54DPB"FUS9W-T<B`B173D=&EL875K<V5N
M(%523"(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38Q
M"FUS9VED(")296UO=F4B"FUS9W-T<B`B4&]I<W1A(@H*(SH@=&5M<&QA=&5S
M+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92`E<R(*;7-G<W1R(")0;VES=&$@)7,B"@HC.B!A='1E;F1E
M97,N<&AP.C$P,`IM<V=I9"`B4F5M;W9E($%T=&5N9&5E(@IM<V=S='(@(E!O
M:7-T82!O<V%L;&ES='5J82(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,S$*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@8V%L96YD87(@=VET
M:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB
M9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@8V%L96YD87(N
M/"]S=')O;F<^(@IM<V=S='(@(B(*(DMO<G9A82!O;&5M87-S86]L979A="!K
M86QE;G1E<FET('1U;V1U;&QA(&MA;&5N=&5R:6QL83\@/'-T<F]N9SY687)O
M:71U<SH@(@HB5.1MY"!P;VES=&%A(&MA:6MK:2!T:65T=65E="!TY&WD;FAE
M=&MI<V5S=.0@:V%L96YT97)I<W1A<VDN/"]S=')O;F<^(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z-C,W"FUS9VED(")297%U:7)E9"(*;7-G<W1R(")086MO
M;&QI;F5N(@H*(SH@;&EB+T9"5FEE=RYP:'`Z.3@@;&EB+T9"5FEE=RYP:'`Z
M,3,Y(&QI8B]&0E9I97<N<&AP.C$T,B!L:6(O1D)6:65W+G!H<#HQ-#4*;7-G
M:60@(E)E<75I<F5D($%T=&5N9&5E<R(*;7-G<W1R(")086MO;&QI;F5N(&]S
M86QL:7-T=6IA(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S(@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,S`X"FUS9VED(")297-E="!T;R!$969A
M=6QT<R(*;7-G<W1R(")086QA=71A(&]L971U:W-E="(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$V-B!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z-#,*;7-G:60@(E)E<W!O;G-E(@IM<V=S='(@(E9A<W1A=7,B
M"@HC.B!Y96%R+G!H<#HX-2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C`*(SH@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(FQA(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(P('1E;7!L871E<R]M;VYT:"]H96%D
M+FEN8SHR,0HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,PIM
M<V=I9"`B4V%T=7)D87DB"FUS9W-T<B`B;&%U86YT86DB"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C`S"FUS9VED(")3879E(@IM
M<V=S='(@(E1A;&QE=&$B"@HC.B!E9&ET979E;G0N<&AP.C0Y(&5D:71E=F5N
M="YP:'`Z-3<@=FEE=V5V96YT+G!H<#HQ,S,*;7-G:60@(E-A=F4@07,@3F5W
M(@IM<V=S='(@(E1A;&QE=&$@=75T96YA(@H*(SH@=&5M<&QA=&5S+V%T=&5N
M9&5E<R]A='1E;F1E97,N:6YC.C@S"FUS9VED(")3879E($%T=&5N9&5E<R(*
M;7-G<W1R(")486QL971A(&]S86QL:7-T=6IA="(*"B,Z(&%D9&5V96YT+G!H
M<#HU-2!E9&ET979E;G0N<&AP.C4R"FUS9VED(")3879E($5V96YT(@IM<V=S
M='(@(E1A;&QE=&$@=&%P86AT=6UA(@H*(SH@<V5A<F-H+G!H<#HY,2!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$T"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHV-R!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$T-0HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C
M:"YI;F,Z."!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(DAA:W4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E
M87)C:"YI;F,Z,0IM<V=I9"`B4V5A<F-H($-A;&5N9&%R<R(*;7-G<W1R(")(
M86MU(&MA;&5N=&5R96ES=&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z-@IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B2&%U;B!T
M=6QO:W-E="(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHV
M"FUS9VED(")396%R8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN:6YG.B(*;7-G
M<W1R(")(864@:V%L96YT97)E:7-T82P@:F]T:V$@<VESY&QTY.0Z(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U,PIM<V=I9"`B
M4V5L96-T(&$@8V%L96YD87(@=&\@961I="(*;7-G<W1R(")686QI='-E(&MA
M;&5N=&5R:2!M=6]K871T879A:W-I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C8U('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q
M"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(E9A;&ET<V4@<.1I=N1MY.1RY"(*
M"B,Z('1E;7!L871E<R]M96YU+FEN8SHS,`IM<V=I9"`B4V5L96-T(&-A;&5N
M9&%R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")686QI='-E(&MA;&5N=&5R:2!N
MY'ET971TY';D:W-I.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM
M<V=I9"`B(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@
M9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@(@HB9&5F
M875L="!V:65W+B(*;7-G<W1R("(B"B)6;VET(&UU=71T86$@=F%R;6ES='5K
M<V5E;B!L:6ET='EV:>0@87-E='5K<VEA+"!M:71E;B!E<FEL86ES:6$@;N1K
M>6UIY"`B"B)NY'ET973DY&X@:F$@;6ETY"!KY'ET973DY&X@;VQE='5S;N1K
M>6WD;N0N(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ.`IM<V=I
M9"`B4V5L96-T('1H92!C86QE;F1A<B!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@
M(E9A;&ET<V4@:V%L96YT97)I+"!J;VAO;B!T=6]D86%N('1I971O:F$Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.0IM<V=I9"`B4V5L96-T
M('1H92!C86QE;F1A<BAS*2!T;R!E>'!O<G0@9G)O;2(*;7-G<W1R(")686QI
M='-E(&MA;&5N=&5R:70L(&IO:7-T82!V:65DY.1N('1I971O:F$B"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")396QE8W0@=&AE
M(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E9A;&ET<V4@=FEE;FYI<W/D(&OD
M>71E='3D=N0@;75O=&\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHR-PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T
M<B`B5F%L:71S92!T:65D;W-T;RP@:F]S=&$@='5O9&%A;B!T:65T;VIA.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@(E-E;&5C="!T
M:&4@9FER<W0@=V5E:V1A>3HB"FUS9W-T<B`B5F%L:71S92!E;G-I;6WD:6YE
M;B!V:6EK;VYPY&EVY#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z(@IM<V=S='(@(E9A;&ET<V4@;.1H9&5T:65D;W-T;VX@;75O=&\Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H
M92!T:6UE('-P86X@=&\@<VAO=SHB"FUS9W-T<B`B5F%L:71S92!NY'ET971T
MY';D(&%I:V%J86MS;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*
M;7-G:60@(E-E;&5C="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N('-T87)T=7`Z
M(@IM<V=S='(@(E9A;&ET<V4@<VESY.1N:VER:F%U='5M:7-E;B!JY&QK965N
M(&[D>71E='3D=N0@;N1K>6WD.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,@IM<V=I9"`B4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H
M92!P;W)T86PN(@IM<V=S='(@(E9O:70@=F%L:71A(&UI=.0@=&%P86AT=6UI
M82!NY'ET973DY&X@<&]R=&%A;&ES<V$N(@H*(SH@=&5M<&QA=&5S+V1E;&5T
M92]D96QE=&4N:6YC.C(W('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR-PIM
M<V=I9"`B4V5N9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL(&%T=&5N
M9&5E<R!W:&5N(&1E;&5T:6YG('1H:7,@979E;G0B"FUS9W-T<B`B3.1H973D
M('!E<G5U='5S=FEE<W1I(&MA:6MI;&QE(&]S86QL:7-T=6II;&QE(&MU;B!T
M87!A:'1U;6$@<&]I<W1E=&%A;B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")396YD(&%N(&5M86EL('1O
M("5S(@IM<V=S='(@(DSD:&5TY"!V:65S=&D@;W-O:71T965S965N("5S(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3<Y"FUS9VED(")396YD('5P
M9&%T97,O:6YV:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN
M9R!T:&ES(&5V96YT(@IM<V=S='(@(B(*(DSD:&5TY"!PY&EV:71Y:W-E="]K
M=71S=70@:V%I:VEL;&4@;W-A;&QI<W1U:FEL;&4@:W5N('1A<&%H='5M86X@
M;75U=&]K<VEA("(*(G1A;&QE=&5T86%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-S8*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")S
M>7ES:W5U(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M.#,*;7-G:60@(E-E="!E;F0@9&%T92(*;7-G<W1R(")!<V5T82!PY.1T='EM
M:7-PY&EVY"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V-0IM<V=I
M9"`B4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`B07-E=&$@=&]I
M<W1U=G5U9&5N('#DY'1T>6UI<W#D:7;D;>3D<N0B"@HC.B!T96UP;&%T97,O
M961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0IM<V=I9"`B4V5T('-T87)T(&1A
M=&4B"FUS9W-T<B`B07-E=&$@86QK86UI<W#D:7;D;>3D<N0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3D*;7-G:60@(B(*(E-E="!Y;W5R(&9R964O
M8G5S>2!C86QE;F1A<G,@86YD('EO=7(@;W=N(&%N9"!O=&AE<B!U<V5R<R<@
M9G)E92]B=7-Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D%S971A('9A<&%A+W9A
M<F%T='4@:V%L96YT97)I<VD@<V5KY"!S:6YU=6X@:F$@;75I:&EN(&QI:71T
M>79IY"!V87!A82\B"B)V87)A='1U(&%S971U:W-I82XB"@HC.B!C86QE;F1A
M<G,N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(E-H87)E(&YO="!F;W5N
M9#H@)7,B"FUS9W-T<B`B2F%K;V$@96D@;/9Y='EN>70Z("5S(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C@R"FUS9VED(")3:&%R
M960@0V%L96YD87)S(@IM<V=S='(@(DIA971U="!K86QE;G1E<FET(@H*(SH@
M=&5M<&QA=&5S+VUE;G4N:6YC.C0W('1E;7!L871E<R]M96YU+FEN8SHT.0IM
M<V=I9"`B4VAA<F5D($-A;&5N9&%R<SHB"FUS9W-T<B`B2F%E='5T(&MA;&5N
M=&5R:70Z(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H<#HR-2!T96UP;&%T97,O
M=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC.B!T96UP;&%T97,O9&%Y
M+VAE861?<VED95]B>5]S:61E+FEN8SHS"FUS9VED(")3:&]W($-A;&5N9&%R
M(@IM<V=S='(@(D[D>73D(&MA;&5N=&5R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-38*;7-G:60@(E-H;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G
M<W1R(").Y'ETY"!L=6]K:71U<W1E;B!S96QI='EK<V5T+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(E-H;W<@9&5L971E+"!A;&%R
M;2P@86YD(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_(@IM
M<V=S='(@(D[D>73D('!O:7-T82P@:.1L>71Y<R!J82!T;VES=&\@:6MO;FET
M(&MA;&5N=&5R:6[D:WEMY'-SY"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C$R"FUS9VED(")3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_
M(@IM<V=S='(@(D[D>73D('9A;&UI<W1U=F%T('1E:'3D=N1T(&MA;&5N=&5R
M:7-S82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38V"FUS9VED(")3
M:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S='(@(D[D>73D('9A<&%A+W9A
M<F%T='4@<V5L:71E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#,*
M;7-G:60@(E-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E
M=#\B"FUS9W-T<B`B3N1Y=.0@=F%I;B!N92!T87!A:'1U;6%T+"!J;VEH:6X@
M;&EI='1Y>2!HY&QY='ES+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-S4*;7-G:60@(E-H;W<@<VAA<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_
M(@IM<V=S='(@(D[D>73D(&IA971U="!K86QE;G1E<FET('9I97)E:VOD:6XN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B4VAO=R!T
M87-K<R!U<VEN9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(D[D>73D('1E
M:'3D=N1T(&OD>71TY&5N(&MA=&5G;W)I;VED96X@=N1R96KD+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B4VAO=R!T:6UE(&]F(&1A
M>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_(@IM<V=S='(@(D[D
M>73D(&ME;&QO;F%I:V$@:F]K86ES96X@<.1I=N1N(';D;&ES<^0@=FEI:VMO
M;N1K>6WD<W/D+B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C$Q"FUS9VED(")3=&%?<G0B"FUS9W-T<B`B7T%L:V%A(@H*(SH@9&%T
M82YP:'`Z-30*;7-G:60@(E-T87)T($1A=&4B"FUS9W-T<B`B06QK86UI<W#D
M:7;D;>3D<N0B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT,2!T96UP
M;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C<*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHS-PIM<V=I9"`B4W1A<G0@3VXB"FUS9W-T<B`B
M06QK86$B"@HC.B!D871A+G!H<#HU-0IM<V=I9"`B4W1A<G0@5&EM92(*;7-G
M<W1R(")!;&MA;6ES86EK82(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHY-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHX,PIM
M<V=I9"`B4W1A=%]U<R(*;7-G<W1R(")47VEL82(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C(W('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R
M<RYI;F,Z-@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E1I;&$B"@HC.B!Y96%R
M+G!H<#HW."!Y96%R+G!H<#HX-R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHV-0HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C$@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#<@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#D*;7-G
M:60@(E-U(@IM<V=S='(@(G-U(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(Q('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-`HC.B!T96UP;&%T
M97,O;6]N=&@O:&5A9"YI;F,Z,C,@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I9"`B
M4W5N9&%Y(@IM<V=S='(@(G-U;FYU;G1A:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5&5H=.1VY'0B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HU.#4@;&EB+TMR;VYO;&ET:"YP:'`Z-C`X
M"FUS9VED(")496YT871I=F4B"FUS9W-T<B`B16AD;W1E='1U(@H*(SH@>65A
M<BYP:'`Z.#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C(@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C$X"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,3`U"FUS9VED(")4:"(*;7-G<W1R(")T;R(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z-S`*;7-G:60@(E1H92!%9&ET($%T=&5N
M9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N($5X:71I;F<N(@IM
M<V=S='(@(DUU;VMK86$@;W-A;&QI<W1U:F$@+6[D:WEMY"!E:2!O;&4@96[D
MY"!NY&MY=FES<^0N(%!O:7-T=71A86XN(@H*(SH@8V%L96YD87)S+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&-A
M;FYO="!B92!D96QE=&5D+B(*;7-G<W1R(")+86QE;G1E<FEA(%PB)7-<(B!E
M:2!V;VD@<&]I<W1A82XB"@HC.B!C86QE;F1A<G,N<&AP.C0P"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@8W)E
M871E9"XB"FUS9W-T<B`B2V%L96YT97)I(%PB)7-<(B!O;B!L=6]T=2XB"@HC
M.B!C86QE;F1A<G,N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C
M86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B2V%L
M96YT97)I(%PB)7-<(B!O;B!P;VES=&5T='4B"@HC.B!C86QE;F1A<G,N<&AP
M.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@
M:&%S(&)E96X@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(DMA;&5N=&5R
M:2!<(B5S7"(@;VX@;FEM971T>2!U=61E;&QE96X@7"(E<UPB.FMS:2XB"@HC
M.B!C86QE;F1A<G,N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C
M86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(DMA;&5N
M=&5R:2!<(B5S7"(@;VX@=&%L;&5T971T=2XB"@HC.B!D871A+G!H<#HR,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B
M92!P=7)G960Z("5S(@IM<V=S='(@(DMA;&5N=&5R:6$@96D@=F]I='4@<&]I
M<W1A83H@)7,B"@HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHQ
M-C,*;7-G:60@(E1H92!E;F0@9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE
M('-T87)T(&1A=&4N(@IM<V=S='(@(E#DY'1T>6UI<W#D:7;D;>3D<N0@<&ET
MY.0@;VQL82!M>?9H96UP:2!K=6EN(&%L:V%M:7-PY&EVY&WDY'+D+B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!<(B5S7"(@
M8V%L96YD87(L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R(")487!A
M:'1U;6$@7"(E<UPB(&]N(&QI<^1T='D@:V%L96YT97)I:6X@7"(E<UPB+"!J
M;VMA(&]N("5S("5S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D(&9R;VT@7"(E<UPB(&-A;&5N9&%R+"!W:&EC:"!W87,@;VX@
M)7,@870@)2(*(G,N(@IM<V=S='(@(E1A<&%H='5M82!<(B5S7"(@;VX@<&]I
M<W1E='1U(&MA;&5N=&5R:7-T82!<(B5S7"(L(&IO:V$@;VX@)7,@)7,N(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"!O;B!<(B5S
M7"(@8V%L96YD87(L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R(")4
M87!A:'1U;6%A(%PB)7-<(B!O;B!M=6]K871T=2!K86QE;G1E<FES<V$@7"(E
M<UPB+"!J;VMA(&]N("5S("5S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P
M.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(&YO=&EF:6-A=&EO
M;B!T;R`E<R!W87,@<W5C8V5S<V9U;&QY('-E;G0N(@IM<V=S='(@(E1A<&%H
M='5M86EL;6]I='5K<V5N(&SD:&5T=.1M:6YE;B`E<R!O;FYI<W1U:2XB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#0T"FUS9VED(")4:&4@9F]L;&]W:6YG
M(&ES(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z
M(@IM<V=S='(@(E3D<W/D(&]V870@=&%R:V5M;6%T('1I961O="!T87!A:'1U
M;6%S=&$Z(@H*(SH@871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E
M<W0@=V%S(&EN8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N
M96-E<W-A<GD@=&\@86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E
M(&UI<W-I;F<N(@IM<V=S='(@(B(*(E!Y>6YT]B!O;&D@97#D=.1Y9&5L;&EN
M96XN($IO:71A:VEN('!A<F%M971R96IA('!U=71T=74L(&IO='1A('1A<&%H
M='5M82`B"B)O;&ES:2!V;VET=2!H>7;D:W-YY"!T86D@:'ELY'3D+B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O96UP='DN:6YC.C,*;7-G:60@(E1H97)E(&%R
M92!N;R!E=F5N=',@;6%T8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM
M<V=S='(@(D5I(&]L92!T87!A:'1U;6EA+"!J;W1K82!V87-T86ES:79A="!N
M>6MY:7-IY"!V86%T:6UU:W-I82XB"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z
M,3@@961I=&5V96YT86-T:6]N+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@86-C97-S:6YG('1H92!C86QE;F1A<CH@
M)7,B"FUS9W-T<B`B5&%P86AT=6D@=FER:&4@:^1Y=&5T=.1E<W/D(&MA;&5N
M=&5R:6$Z("5S(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C,T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V
M96YT.B`E<R(*;7-G<W1R(")487!A:'1U:2!V:7)H92!L:7/D='3D97-SY"!T
M87!A:'1U;6%A.B`E<R(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I;F<@
M=&AE(&5V96YT.B`E<R(*;7-G<W1R(")487!A:'1U:2!V:7)H92!M=6]K871T
M865S<V$@=&%P86AT=6UA83H@)7,B"@HC.B!L:6(O87!I+G!H<#HS,SD@;&EB
M+V%P:2YP:'`Z-C$X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B:4-A;&5N9&%R+71I
M971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92XB"@HC.B!E9&ET979E
M;G1A8W1I;VXN<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!M;W9I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")487!A
M:'1U;6EE;B!T=6]N;FES<V$@=&%P86AT=6D@=FER:&4Z("5S+B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@86X@979E;G0@;F]T:69I8V%T:6]N
M('1O("5S.B`E<R(*;7-G<W1R(")487!A:'1U:2!V:7)H92!LY&AE=&5T=.1E
M<W/D('1A<&%H='5M86EL;6]I='5S=&$@)7,Z;&QE.B`E<R(*"B,Z(&1A=&$N
M<&AP.C$P.`IM<V=I9"`B5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@97AP;W)T
M+B(*;7-G<W1R(")%:2!O;&4@=&%P86AT=6UI82X@5&%P86AT=6UI82!E:2!V
M;VD@=FEE9.0N(@H*(SH@9&%T82YP:'`Z,3@W"FUS9VED(")4:&ES(&9I;&4@
M9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(E3D;>0@=&EE9&]S
M=&]M=6]T;R!E:2!O;&4@='5E='1U+B(*"B,Z(&1A=&$N<&AP.C(U,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`E<R(*;7-G<W1R(")086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI.B`E
M<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q."!T96UP;&%T97,O
M;6]N=&@O:&5A9"YI;F,Z,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z-S$*;7-G:60@(E1H=7)S9&%Y(@IM<V=S='(@(G1O<G-T86DB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S<*;7-G:60@(E1I;64@
M4W!?86XB"FUS9W-T<B`B06EK86EK:U]U;F$B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHT"FUS9VED(")4:6UE('-P86XB"FUS9W-T
M<B`B06EK86EK:W5N82(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHS-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHS.`IM<V=I
M9"`B5&ET7VQE(@IM<V=S='(@(D]T<VE?:VMO(@H*(SH@9&%T82YP:'`Z-3,@
M=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHS"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,`IM<V=I9"`B5&ET;&4B"FUS9W-T
M<B`B3W1S:6MK;R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,C<@;&EB
M+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R,@HC.B!L:6(O0FQO8VLO;6]N
M=&AL:7-T+G!H<#HQ,C$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(E3D;N3D;B(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,CD@;&EB+T)L;V-K+W!R979M
M;VYT:&QI<W0N<&AP.C$R-`HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ
M,C,*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DAU;VUE;FYA(@H*(SH@>65A
M<BYP:'`Z.#$@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C`@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C$V"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,3`U"FUS9VED(")4=2(*;7-G<W1R(")T:2(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$Q-B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3<*
M(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-CD*;7-G:60@(E1U
M97-D87DB"FUS9W-T<B`B=&EI<W1A:2(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP
M:'`N9&ES=#HQ-PIM<V=I9"`B5'EP92(*;7-G<W1R(")4>7EP<&DB"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3@V"FUS9VED(")5
M4DPB"FUS9W-T<B`B55),(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HV-`IM
M<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T
M<B`B4U%,+7!A;'9E;&EM965N(&5I('-A861A('EH=&5Y='3D+B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(D5I('9O:61A('!O:7-T86$@
M7"(E<UPB.B`E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E
M<RXB"FUS9W-T<B`B3>3D<FET>6MS96X@)7,@;'5K96UI;F5N(&5PY&]N;FES
M='5I+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!<(B5S7"(Z("5S(@IM<V=S='(@(D5I('9O
M:61A(&YI;65TY"!U=61E;&QE96X@7"(E<UPB.B`E<R(*"B,Z(&QI8B]3=&]R
M86=E+VMO;&%B+G!H<#HS.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G
M<W1R(")%:2!V;VD@:&%K96$@=F%P86$O=F%R871T=2!T:65T;VIA("5S.FQL
M92(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$U"B,Z('-C<FEP=',O
M=7!G<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T7V-A=&5G;W)I97-?=&]?<W1R
M:6YG<RYP:'`Z-3,*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3'5O:VET=&5L
M96UA=&]N(@H*(SH@;&EB+V%P:2YP:'`Z,S<W(&QI8B]A<&DN<&AP.C0V,2!L
M:6(O87!I+G!H<#HU,S<@;&EB+V%P:2YP:'`Z-C0S"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B
M16D@='5E='1U($-O;G1E;G0M5'EP93H@)7,B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,#,T"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960Z("5S+B(*
M;7-G<W1R(")0Y&EV:71E='1I:6XZ("<E<R<N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P"FUS9VED(")5<V5R($EN=&5R9F%C92(*;7-G<W1R(")+
MY'ET=/9L:6ET='EMY"(*"B,Z('EE87(N<&AP.C$V,"!Y96%R+G!H<#HQ-C8@
M;&EB+T)L;V-K+VUO;G1H+G!H<#HQ-3D@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ
M-C(*;7-G:60@(E9I97<@1&%Y(@IM<V=S='(@(D[D>73D('#D:7;D(@H*(SH@
M>65A<BYP:'`Z.#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C$@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$W"B,Z(&QI8B]";&]C:R]M;VYT
M:"YP:'`Z,3`U"FUS9VED(")792(*;7-G<W1R(")K92(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$Q-R!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M,3@*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S`*;7-G:60@
M(E=E9&YE<V1A>2(*;7-G<W1R(")K97-K:79I:6MK;R(*"B,Z(&%T=&5N9&5E
M<RYP:'`Z,3`X(&QI8B]+<F]N;VQI=&@N<&AP.C$S,34@;&EB+T)L;V-K+W1R
M965?;65N=2YP:'`Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS
M9VED(")7965K(@IM<V=S='(@(E9I:6MK;R(*"B,Z(&UO;G1H+G!H<#HQ-S<@
M=V5E:RYP:'`Z,S0@=V]R:W=E96LN<&AP.C,P"B,L('!H<"UF;W)M870*;7-G
M:60@(E=E96L@)60B"FUS9W-T<B`B5FEI:VMO("5D(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,X
M"FUS9VED(")7965K*',I(@IM<V=S='(@(E9I:6MK;V$B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C$R"FUS9VED(")7965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")6:6EK
M;VET=&%I;CH@5&]I<W1U=G5U9&5N(';D;&DB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(T"FUS9VED("(B"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A
M;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V
M96YT<S\B"FUS9W-T<B`B(@HB36EH:6X@86EK86%N('#D:7;D(&IA('9I:6MK
M;V[D:WEMY'0@<&ETY&ES:2!PY.1T='GD+"!J;W,@96D@;VQE(&UY]FCD:7-E
M;7!IY"`B"B)T87!A:'1U;6EA/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,34*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K
M('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V96YT
M<S\B"FUS9W-T<B`B(@HB36EH:6X@86EK86%N('#D:7;D(&IA('9I:6MK;V[D
M:WEMY'0@<&ETY&ES:2!A;&MA82P@:F]S(&5I(&]L92!A:6MA:7-E;7!I82`B
M"B)T87!A:'1U;6EA/R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`W(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S,30@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")7;W)K(%=E96LB"FUS
M9W-T<B`B5'GV=FEI:VMO(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q-R!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-0IM<V=I9"`B665A<B(*;7-G<W1R
M(")6=6]S:2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,S@*;7-G:60@(EEE87)L>3H@4F5C=7)S
M(&5V97)Y(@IM<V=S='(@(E9U;W-I='1A:6XZ(%1O:7-T=79U=61E;B!VY&QI
M(@H*(SH@861D979E;G0N<&AP.C$W(&1A=&$N<&AP.C,Y(&1A=&$N<&AP.C(S
M.2!E9&ET979E;G1A8W1I;VXN<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!E
M=F5N=',N(@IM<V=S='(@(D5T('9O:2!T96ADY"!E;F5M<.3D(&MU:6X@)60@
M=&%P86AT=6UA82XB"@HC.B!A='1E;F0N<&AP.C0Y"FUS9VED(")9;W4@87)E
M(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF:65D(&5V96YT+B(*;7-G
M<W1R(")%="!O;&4@;65R:VET='D@;W-A;&QI<W1U:F%K<VD@86YN971T=75N
M('1A<&%H='5M86%N+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z-S8*;7-G:60@(EEO=2!C86X@;VYL>2!U<V4@=&AI<R!F;W)M(&9R
M;VT@=&AE($5D:70@071T96YD965S('-C<F5E;BXB"FUS9W-T<B`B5.1TY"!L
M;VUA:V5T=&$@=F]I(&OD>71TY.0@=F%I;B!-=6]K:V%A(&]S86QL:7-T=6IA
M("UNY&MY;>1S=.0N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3@X"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A
M9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO
M;B`B"B)/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S:&5R925S(&)E9F]R
M92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B
M"B)%="!O;&4@;>3D<FET96QL>70@<^1H:_9P;W-T:6]S;VET971T87-I('!R
M;V9I:6QI<VD@87-E='5K<VES<V$N(%-I;G5N('!I=.3D("(*(FWDY')I=&5L
M;.0@<^1H:_9P;W-T:6]S;VET92`E<W3DY&QLY"5S+"!E;FYE;FMU:6X@=&%P
M86AT=6UA('1I971O:F$@=F]I9&%A;B`B"B)LY&AE='3DY"XB"@HC.B!A9&1E
M=F5N=&%C=&EO;BYP:'`Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E<RXB"FUS
M9W-T<B`B4VEN=6QL82!E:2!O;&4@;VEK975K<VEA(&QI<^1TY"!T87!A:'1U
M;6EA("5S.N3D;BXB"@HC.B!D871A+G!H<#HQ.3<*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@=&AE('-E;&5C
M=&5D(&-A;&5N9&%R+B(*;7-G<W1R(")3:6YU;&QA(&5I(&]L92!O:6ME=6MS
M:6$@;&ESY'3D('1A<&%H='5M:6$@=F%L:71T=75N(&MA;&5N=&5R:6EN+B(*
M"B,Z(&1E;&5V96YT86-T:6]N+G!H<#HR-@IM<V=I9"`B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N(@IM<V=S='(@
M(E-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!P;VES=&%A('3D=.0@=&%P86AT
M=6UA82XB"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C<X"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N(@IM
M<V=S='(@(E-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!M=6]K871A('3D=.0@
M=&%P86AT=6UA82XB"@HC.B!D871A+G!H<#HQ.3(*;7-G:60@(EEO=2!H879E
M('-P96-I9FEE9"!A;B!I;G9A;&ED(&-A;&5N9&%R+B(*;7-G<W1R(")/;&5T
M(&WDY')I=&5L;'ET(&5PY&ME;'9O;B!K86QE;G1E<FEN+B(*"B,Z(&%T=&5N
M9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E<'1E
M9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(D]L970@;VYN
M:7-T=6YE97-T:2!H>7;D:W-Y;GET(&]S86QL:7-T=6UI<V5S:2!TY&CD;B!T
M87!A:'1U;6%A;BXB"@HC.B!A='1E;F0N<&AP.C(V"FUS9VED(")9;W4@:&%V
M92!S=6-C97-S9G5L;'D@9&5C;&EN960@871T96YD96YC92!T;R!T:&ES(&5V
M96YT+B(*;7-G<W1R(")/;&5T(&]N;FES='5N965S=&D@:VEE;'3D>71Y;GET
M(&]S86QL:7-T=6UA<W1A('3D:.1N('1A<&%H='5M86%N+B(*"B,Z(&%T=&5N
M9"YP:'`Z,S$*;7-G:60@(EEO=2!H879E('1E;G1A=&EV96QY(&%C8V5P=&5D
M(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`B(@HB3VQE="!O
M;FYI<W1U;F5E<W1I(&%L=7-T879A<W1I(&UY]FYT>6YY="!O<V%L;&ES='5M
M86%N('3D:.1N('1A<&%H='5M86%N+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.3$*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T
M960N(@IM<V=S='(@(E-I;G5N('!I=.3D('9A;&ET82!P;VES=&5T=&%V82!K
M86QE;G1E<FDN(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHU-`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N
M(@IM<V=S='(@(E-I;G5N('!I=.3D(&5N<VEN('9A;&ET82!O<V]I=&4N(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W,PIM<V=I
M9"`B66]U(&YE960@=&\@<V5L96-T(&$@8V%L96YD87(@9FER<W0B"FUS9W-T
M<B`B4VEN=6X@<&ETY.0@96YS:6X@=F%L:71A(&MA;&5N=&5R:2(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$Q,30*;7-G:60@(EEO=2!R97%U97-T960@=&\@
M8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&%D9&5D('1O('EO=7(@8V%L
M96YD87)S+B(*;7-G<W1R("(B"B)/;&5T('9A;&EN;G5T(&AA;'5A=F%S:2!I
M;&UO:71U:W-I82!K=6X@=&%P86AT=6UI82!L:6ET973DY&X@:V%L96YT97)E
M:6AI<VDN(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$R-`IM<V=I9"`B(@HB
M66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@
M9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"B)/;&5T
M('9A;&EN;G5T(&AA;'5A=F%S:2!I;&UO:71U:W-I82!K=6X@=&%P86AT=6UI
M82!P;VES=&5T86%N("(*(FMA;&5N=&5R96ES=&%S:2XB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,3$Y"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO
M=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET960@:6X@>6]U<B!C86QE;F1A
M<G,N(@IM<V=S='(@(B(*(D]L970@=F%L:6YN=70@:&%L=6%V87-I(&EL;6]I
M='5K<VEA(&MU;B!T87!A:'1U;6EA(&UU;VMA=&%A;B!K86QE;G1E<F5I<W-A
M<VDN(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(')E;6EN9&5D
M(&%B;W5T("5S+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B4'EY
M<VET(&UU:7-T=71T86UA86X@=&%P86AT=6UA<W1A("5S+"!J;VMA(&]N(&ME
M;&QO("5S("5S+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&%R97-E;&5C="YI
M;F,Z,3`*;7-G:60@(EEO=7(@9&5F875L="!C86QE;F1A<B(*;7-G<W1R(")/
M;&5T=7-K86QE;G1E<FES:3HB"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#8R(&QI
M8B]$<FEV97(N<&AP.C$P-S(*;7-G:60@(EM5;FYA;65D(&5V96YT72(*;7-G
M<W1R(");;FEM9>1MY'3V;B!T87!A:'1U;6%=(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z.34*;7-G:60@(E]!;&%R;2(*;7-G<W1R(")?2.1L>71Y
M<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ
M,0IM<V=I9"`B7T)A<VEC(%-E87)C:"(*;7-G<W1R(")?66MS:6YK97)T86EN
M96X@2&%K=2(*"B,Z('9I97=E=F5N="YP:'`Z,3,U"FUS9VED(")?161I="(*
M;7-G<W1R(")?375O:VMA82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-3(*
M;7-G:60@(E]';W1O(@IM<V=S='(@(E]-96YE(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,U.`IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7U1U
M;R]6:64B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,Y"FUS9VED(")?37D@
M0V%L96YD87)S(@IM<V=S='(@(E]+86QE;G1E<FEN:2(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S-#8*;7-G:60@(E].97<@179E;G0B"FUS9W-T<B`B7U5U
M<VD@=&%P86AT=6UA(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,V,PIM<V=I
M9"`B7U!R:6YT(@IM<V=S='(@(E]4=6QO<W1A(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,U-`IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?2&%K=2(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$S-#D*;7-G:60@(E]4;V1A>2(*;7-G<W1R
M(")?5.1NY.1N(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS
M9VED(")B969O<F4@=&AE(&5V96YT('-T87)T<R(*;7-G<W1R(")E;FYE;B!T
M87!A:'1U;6%N(&%L:W5A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M-0IM<V=I9"`B9&%Y(@IM<V=S='(@(G#D:7;D(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(P-PIM
M<V=I9"`B9&%Y*',I(@IM<V=S='(@(G#D:7;DY"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.#8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-PHC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@X(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B9&%Y
M<R(*;7-G<W1R(")PY&EVY.0B"@HC.B!D871A+G!H<#HQ-3`@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ"FUS9VED(")E=F5N=',N8W-V(@IM<V=S='(@
M(F5V96YT<RYC<W8B"@HC.B!D871A+G!H<#HQ-S$*;7-G:60@(F5V96YT<RYI
M8W,B"FUS9W-T<B`B979E;G1S+FEC<R(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3,V"FUS9VED(")I;B(*;7-G<W1R("(@(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$R-@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C<@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C,S"FUS9VED(")M;VYT:"AS*2(*;7-G
M<W1R(")K=75K875T=&$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#0P"B,L
M('!H<"UF;W)M870*;7-G:60@(F]N("5S(&%T("5S(@IM<V=S='(@(F%L:V%E
M;B`E<R`E<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,C<*;7-G:60@(F]N('1H92!S86UE(&1A
M=&4B"FUS9W-T<B`B<V%M86YA('#D:7;D;N0B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,S"FUS
M9VED(")O;B!T:&4@<V%M92!W965K9&%Y(@IM<V=S='(@(G-A;6%N82!V:6EK
M;VYPY&EVY&[D(@H*(SH@9&%T82YP:'`Z,CD@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHQ-`IM<V=I9"`B=D-A;&5N9&%R+VE#86QE;F1A<B(*;7-G<W1R
M(")V0V%L96YD87(O:4-A;&5N9&%R(@H*(SH@;&EB+V%P:2YP:'`Z,S4P(&QI
M8B]A<&DN<&AP.C8R.0IM<V=I9"`B=D5V96YT(&YO="!F;W5N9"XB"FUS9W-T
M<B`B96D@;/9Y='EN>70@=D5V96YT.N0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DQ"FUS9VED(")W965K(@IM<V=S='(@(G9I:6MK;R(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,30*;7-G:60@(G=E96LH<RD@;VXZ(@IM<V=S='(@(G9I:6MO:6QL
M83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DR(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.3,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y-`IM
M<V=I9"`B=V5E:W,B"FUS9W-T<B`B=FEI:VMO82(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,SD*
M;7-G:60@(GEE87(H<RDB"FUS9W-T<B`B=G5O='1A(@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]P;R]214%$
M344`````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,C,`,3`T,3<S-C(W-3(`,#$W-S(R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'-E92!H;W)D92]P;R]214%$344`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O<&\O<G5?4E4N<&\`````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3(Q,3<T`#$P-#$W,S8R
M-S4R`#`R,#0U,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````C($MR;VYO;&ET:"!2=7-S:6%N('1R86YS;&%T:6]N+@HC($-O
M<'ER:6=H="`H0RD*(R!!;G1O;B!.96MH;W)O<VAI:"`\86YT;VY`=F%L=65H
M;W-T+G)U/BP@,C`P,0HC($9E9&]R($$N($9E=&ES;W8@/&9A9D!S<V,N<G4^
M+"`R,#`R"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($MR;VYO;&ET:"!V,2XP7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,BTQ,2TQ,"`Q-SHT-2LP,S`P7&XB"B),87-T+51R86YS;&%T;W(Z($9E9&]R
M($$N($9E=&ES;W8@/&9A9D!S<V,N<G4^7&XB"B),86YG=6%G92U496%M.B!&
M961O<B!!+B!&971I<V]V(#QF869`<W-C+G)U/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#
M4#$R-3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!C86QE;F1A<G,@9F]U;F0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5D(&5V96YT<R(*;7-G<W1R("+"\>4@\>[A^_+H
M_R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!$87DH<RD@)7,@2&]U<BAS*2`E<R!-
M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@871T96YD965S(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U
M8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R("+4X.GK("5S(//Q[^7X[>X@
MZ.SO[O#RZ/#NXN#M(@H*(SH@8V%L96YD87)S+G!H<#HQ,#4@;&EB+V)A<V4N
M<&AP.C$R.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE
M;F1A<B(*;7-G<W1R("+=ZO'O[O#RZ/#NXN#R_"#JX.OE[>3@\/PB"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,3<*;7-G:60@(B(*(BA#
M;&EC:R!O;B!C86QE;F1A<B!N86UE('1O('-W:71C:"!T:&4@8V%L96YD87(G
M<R!V:7-I8FEL:71Y(&EN('1H92!M86EN("(*(G=I;F1O=RDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C0*;7-G
M:60@(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($%D9"`J(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,34P"FUS9VED
M("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ-S@V"FUS9VED("(Q(&%T=&5N9&5E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L(&9U
M>GIY"FUS9VED("(Q(&5V96YT(@IM<V=S='(@(L+QY2#Q[N'[\NC_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PHC+"!F=7IZ>0IM<V=I9"`B,2!H
M;W5R(@IM<V=S='(@(B5D(/<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,T"B,L(&9U>GIY"FUS9VED("(Q-2!M:6YU=&5S(@IM<V=S='(@(B5D(.SH
M[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*(RP@9G5Z>GD*;7-G
M:60@(C(P(&UI;G5T97,B"FUS9W-T<B`B)60@[.CM(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-@HC+"!F=7IZ>0IM<V=I9"`B,S`@;6EN=71E<R(*
M;7-G<W1R("(E9"#LZ.TB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M-S$*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^071T96YD965S/"]S=')O;F<^
M("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^RNO^]^7B^^4@\>ONXN`\+V(^(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30Y"B,L(&9U>GIY"FUS9VED
M("(\<W1R;VYG/D1E<V-R:5]P=&EO;CPO<W1R;VYG/B`H;W!T:6]N86PI(@IM
M<V=S='(@(CQB/L[OZ/'@[>CE/"]B/B`H[>4@[N'_Y^#RY>O\[>XI(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C<W"B,L(&9U>GIY"FUS9VED("(\
M<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B
M/&(^RNO^]^7B^^4@\>ONXN`\+V(^(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,3DT"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/E)E8W5R<F5N8V4\
M+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\8C[/[N+R[O#_Y>SN\?+\
M/"]B/B`H[>4@[N'_Y^#RY>O\[>XI(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ,#$@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.#$*;7-G
M:60@(D%-(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4Y,0IM
M<V=I9"`B06-C97!T960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9%]V86YC960@4V5A<F-H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38Q
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")!
M9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8*
M;7-G:60@(D%D9"!%=F5N="(*;7-G<W1R("+$[N'@XNCR_"#Q[N'[\NCE(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z
M,S4*(RP@9G5Z>GD*;7-G:60@(D%D9"!A(&YE=R!296UO=&4@0V%L96YD87(B
M"FUS9W-T<B`BQ.[AX.+H\OP@[>[B[N4@\>[A^_+HY2(*"B,Z(&%D9&5V96YT
M+G!H<#HV-`IM<V=I9"`B061D(&$@;F5W(&5V96YT(@IM<V=S='(@(L3NX>#B
MZ/+\(.WNXN[E(/'NX?ORZ.4B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-S0*;7-G:60@(D%D9"!A='1E;F1E97,B"FUS9W-T<B`B
M(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,3(P"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S
M+FEN8SHW.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I9"`B061V86YC960@4V5A<F-H
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C4S"FUS
M9VED(")!;&%R;2(*;7-G<W1R("+-X._N[.CMX.WHY2(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@9&%Y
M<R!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!H;W5R<R!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<W-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B06QA<FT@)60@;6EN=71E<R!B969O<F4B"FUS9W-T
M<B`BS.CM\_+[(.3N(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<U.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!W965K<R!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V,PIM<V=I9"`B06QA<FT@,2!D87D@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C@*;7-G
M:60@(D%L87)M(#$@:&]U<B!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3<W,PHC+"!F=7IZ>0IM<V=I9"`B06QA<FT@,2!M:6YU=&4@
M8F5F;W)E(@IM<V=S='(@(LSH[?/R^R#D[B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$W-3@*;7-G:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-C`*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T<B`BQ.#R
MX"#MX._N[.CMX.WH_R(*"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!3
M<&%N("AM:6YU=&5S*2(*;7-G<W1R("+$Z^CRY>O\[>[Q\OP@[>#O[NSH[>#M
MZ/\@*.SH[?/R^RDB"@HC.B!D871A+G!H<#HV,0IM<V=I9"`B06QA<FT@5&EM
M92(*;7-G<W1R("+"\.7L_R#MX._N[.CMX.WH_R(*"B,Z('1E;7!L871E<R]D
M96QE=&4O9&5L971E+FEN8SHS,0IM<V=I9"`B06QL(@IM<V=S='(@(L+QY2(*
M"B,Z(&QI8B]&0E9I97<N<&AP.C$R-B!L:6(O1D)6:65W+G!H<#HQ,CD@;&EB
M+T9"5FEE=RYP:'`Z,3,R"B,L(&9U>GIY"FUS9VED(")!;&P@071T96YD965S
M(@IM<V=S='(@(L+QY2#Q[N'[\NC_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:6YC.C4Y"B,L(&9U>GIY"FUS9VED(")!;&P@1G5T=7)E(@IM<V=S
M='(@(L'SY//YY>4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M-3,*(RP@9G5Z>GD*;7-G:60@(D%L;"!087-T(@IM<V=S='(@(LK@YN3[Z2#D
MY>W\(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(W(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,C0*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z
M,C<@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(U"FUS9VED(")!;&P@5FES:6)L
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N
M+FEN8SHQ,C(@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H<#HY
M,PHC.B!L:6(O5V5E:U9I97<N<&AP.C$R-R!L:6(O5V5E:U9I97<N<&AP.C$S
M-"!L:6(O1')I=F5R+G!H<#HQ.#,R"FUS9VED(")!;&P@9&%Y(@IM<V=S='(@
M(LK@YN3[Z2#DY>W\(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$V-`IM
M<V=I9"`B06QL(&1A>2!E=F5N="(*;7-G<W1R("+%YN7D[>7B[>[E(/'NX?OR
MZ.4B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")!
M;&P@979E;G1S(@IM<V=S='(@(L+QY2#Q[N'[\NC_(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O2W)O;F]L:71H+G!H
M<#HV.#,*;7-G:60@(D%N>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW,0IM<V=I9"`B07!R:6PB"FUS9W-T<B`BP._P
MY>O\(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,SD@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHW,"!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$U-@IM<V=I9"`B070B"FUS9W-T<B`BPB(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$P,C8*;7-G:60@(B(*(D%T=&%C:&5D(&ES(&%N(&E#86QE;F1A
M<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@979E;G0N
M($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I<"!R97%U97-T
M<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P9&%T92`B"B)Y
M;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#(@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E;F1A;F-E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V,0IM<V=I9"`B071T
M96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`BP.+C\_'R(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHX"FUS9VED(")"87-I8R!396%R8V@B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R("+$Y>W\(/#NYN3E[>C_(@H*(SH@;&EB
M+T9"5FEE=RYP:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$P"FUS9VED(")"=7-Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S='(@
M(LCL[^[P\NCP[N+@\OP@ZN#KY>WDX/#\(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z-#D*(RP@9G5Z>GD*;7-G:60@(D-A;%]E;F1A<B(*;7-G<W1R
M("+([._N\/+H\.[BX/+\(.K@Z^7MY.#P_"(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ-#8@;&EB+T)L;V-K+W!R979M;VYT:&QI
M<W0N<&AP.C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C$@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"B,L
M(&9U>GIY"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+([._N\/+H\.[BX/+\
M(.K@Z^7MY.#P_"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"B,L(&9U
M>GIY"FUS9VED(")#86QE;F1A<B!3=6UM87)Y(@IM<V=S='(@(L/KX.+MX/\B
M"@HC.B!D871A+G!H<#HR,C@*(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R('-U
M8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(M3@Z>L@].[P[.#RX"!I0V%L
M96YD87(@\_'OY?CM[B#H[._N\/+H\.[BX.TB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<*
M(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R<R(*;7-G<W1R("+([._N\/+H\.[B
MX/+\(.K@Z^7MY.#P_"(*"B,Z(&-A;&5N9&%R<RYP:'`Z,C<*;7-G:60@(D-A
M;&5N9&%R<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HR-#,*(RP@9G5Z>GD*;7-G:60@(D-A;B=T(&-R96%T92!A(&YE=R!E
M=F5N="XB"FUS9W-T<B`BT>[GY.#R_"#M[N+NY2#Q[N'[\NCE(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3$@=&5M<&QA=&5S+V1E
M;&5T92]O;F4N:6YC.C,P"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN
M8SHS,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHS,#D*;7-G:60@(D-A;F-E;"(*;7-G<W1R("+.\NSE
M[>`B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S`*(RP@9G5Z>GD*;7-G:60@
M(D-A;F-E;&QE9"(*;7-G<W1R("+.\NSE[>`B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,#`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YC96QL
M960Z("5S(@IM<V=S='(@(L[R[.7MX"(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H7V%D=F%N8V5D+FEN8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHV.0HC+"!F=7IZ>0IM<V=I9"`B0V%T96=O<E]Y(@IM<V=S='(@(LK@\N7C
M[O#H_R(*"B,Z(&1A=&$N<&AP.C8S('1E;7!L871E<R]S96%R8V@O979E;G1?
M:&5A9&5R<RYI;F,Z-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,PIM<V=I
M9"`B0V%T96=O<GDB"FUS9W-T<B`BRN#RY>/N\.C_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(W.0IM<V=I9"`B(@HB0VAO;W-E(&EF('EO=2!W86YT
M('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E
M=F5N=',@8GD@(@HB96UA:6PZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O(&)E
M(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96%R8VA?86)O;VM?
M<V5L96-T+FEN8SHQ.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDY"FUS9VED
M(")#:&]O<V4@=&AE(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H(&9O<B!F<F5E
M+V)U<WD@55),<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V9B
M7V-A;'-?<V5L96-T+FEN8SHQ-@IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A
M<G,@=&\@:6YC;'5D92!I;B!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;CHB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,0IM<V=I
M9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!W:&5N(&=E;F5R
M871I;F<@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!C
M86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C8U"FUS9VED(")#;&5A<B!A;&P@871T96YD965S(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(X('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S"FUS9VED(")#;VYF
M:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\B"FUS9W-T<B`BS^[D\N+E\.;DY>WH
MY2#SY.#KY>WH_R#Q[N'[\NCI(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-38W
M"FUS9VED(")#;VYF:7)M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(P.`IM<V=I9"`B0V]P>2!T:&4@55),
M(&)E;&]W(&9O<B!U<V4@=VAE<F5V97(@>6]U(&YE960@>6]U<B!&<F5E+T)U
M<WD@55),.B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ
M,C8*(RP@9G5Z>GD*;7-G:60@(D-R96%T92(*;7-G<W1R("+2Y>KS^>7E(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q,@HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E($-A;&5N9&%R(@IM<V=S='(@(LCL[^[P\NCP
M[N+@\OP@ZN#KY>WDX/#\(@H*(SH@;6]N=&@N<&AP.C$V-2!T96UP;&%T97,O
M=V5E:R]H96%D+FEN8SHR-2!T96UP;&%T97,O9&%Y+W)O=RYI;F,Z-@HC.B!L
M:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.C$Y-`IM<V=I9"`B
M0W)E871E(&$@3F5W($5V96YT(@IM<V=S='(@(M'NY^3@\OP@[>[B[N4@\>[A
M^_+HY2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C@P"FUS9VED(")#
M<F5A=&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E
M+FEN8SHR.0IM<V=I9"`B0W5R<F5N="(*;7-G<W1R("+2Y>KS^>7E(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(P.0IM<V=I9"`B1&%I;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R
M("+/[N+R[O#_Y?+Q_R#EYN7D[>7B[>XB"@HC.B!A='1E;F1E97,N<&AP.C$Q
M,"!L:6(O2W)O;F]L:71H+G!H<#HQ,C@X(&QI8B]";&]C:R]T<F5E7VUE;G4N
M<&AP.C(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@IM<V=I9"`B1&%Y
M(@IM<V=S='(@(L3E[?PB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV
M,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,SD*;7-G:60@(D1A>2AS*2(*
M;7-G<W1R("+$Y>W\*.3MZ"DB"@HC.B!V:65W979E;G0N<&AP.C$P-`HC+"!F
M=7IZ>0IM<V=I9"`B1&5?;&5T92(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-SD*;7-G:60@(D1E8V5M8F5R
M(@IM<V=S='(@(L3EZN#A\/PB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.30*
M;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#86QE;F1A<B(*
M;7-G<W1R("+([._N\/+H\.[BX/+\(.K@Z^7MY.#P_"(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ.3,@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ.#$*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N
M:6YC.C(Y('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N
M:6YC.C(S"B,Z(&QI8B]$<FEV97(N<&AP.C$X,3,*;7-G:60@(D1E;&5T92(*
M;7-G<W1R("+3Y.#KZ/+\(@H*(SH@9&5L979E;G0N<&AP.C0P('1E;7!L871E
M<R]D96QE=&4O;VYE+FEN8SHQ."!T96UP;&%T97,O9&5L971E+V1E;&5T92YI
M;F,Z,3@*(SH@;&EB+T1R:79E<BYP:'`Z,3@Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&4@)7,B"FUS9W-T<B`BT^3@Z^CR_"`E<R(*"B,Z(&5D:71E
M=F5N="YP:'`Z-S`*;7-G:60@(D1E;&5T92!%=F5N="(*;7-G<W1R("+3Y.#K
MZ/+\(/'NX?ORZ.4B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z
M,C<*;7-G:60@(B(*(D1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T
M:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@
M(@HB86QL(&]C8W5R96YC97,_(@IM<V=S='(@(B(*(M/DX.OH\OP@\N[K_.KN
M(.3@[>WNY2#Q[N'[\NCE+"#]\NX@\>[A^_+HY2#H(.+QY2#A\^3S^>CE(/'N
MX?ORZ/\L(.CKZ"#B\>4@(@HB\>[A^_+H_S\B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3`T('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I7W!T:6]N(@IM
M<V=S='(@(L[OZ/'@[>CE(@H*(SH@9&%T82YP:'`Z-C(@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W-0HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHY-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BSN_H\>#M
MZ.4B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W,PHC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R("+-X/'R\.[IZN@@[N'N
MZ^[WZN@B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M-C`*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@0V%L96YD87)S(@IM<V=S='(@
M(LW@\?+P[NGJZ"#NX>[K[O?JZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C@*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+-X/'R
M\.[IZN@@[N'NZ^[WZN@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*
M;7-G:60@(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U
M92!O;B!Y;W5R(&-A;&5N9&%R/R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HU,S<*;7-G:60@(D1O97,@;F]T(')E8W5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$=64Z("5S(@IM<V=S='(@(L3N.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T
M<B`BQ.OH\N7K_.WN\?+\(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$W,"!L:6(O1')I=F5R+G!H<#HQ.#`V"FUS9VED(")%9&ET
M(@IM<V=S='(@(M#EY.#J\NCP[N+@\OPB"@HC.B!E9&ET979E;G0N<&AP.C,S
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V(&QI8B]$<FEV97(N<&AP.C$X
M,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R("+0Y>3@
MZO+H\.[BX/+\("5S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@W
M"FUS9VED(")%9&ET($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30P"B,L(&9U>GIY"FUS9VED
M(")%9&ET($-A;&5N9&%R<R(*;7-G<W1R("+=ZO'O[O#RZ/#NXN#R_"#JX.OE
M[>3@\/PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4P"B,L(&9U>GIY
M"FUS9VED(")%9&ET(%)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`BR.SO[O#R
MZ/#NXN#R_"#JX.OE[>3@\/PB"@HC.B!A='1E;F1E97,N<&AP.C$U,`IM<V=I
M9"`B161I="!A='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A
M=&5G;W)Y7VQE9V5N9"YI;F,Z,C`*;7-G:60@(D5D:70@8V%T96=O<FEE<R!A
M;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3<V('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S
M+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C0*;7-G:60@
M(D5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I=%]T:6UE<W!A;BYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D5N7V0B"FUS
M9W-T<B`BQ^#JX.WWZ.+@Y?+Q_R(*"B,Z(&1A=&$N<&AP.C4W"FUS9VED(")%
M;F0@1&%T92(*;7-G<W1R("+$X/+@(.[J[NWWX.WH_R(*"B,Z('1E;7!L871E
M<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z."!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P.`IM
M<V=I9"`B16YD($]N(@IM<V=S='(@(L?@ZN#M]^CBX.7R\?\B"@HC.B!D871A
M+G!H<#HU.`IM<V=I9"`B16YD(%1I;64B"FUS9W-T<B`BPO#E[/\@[NKN[??@
M[>C_(@H*(SH@871T96YD965S+G!H<#HQ,C0@871T96YD965S+G!H<#HQ,S4@
M871T96YD965S+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M<F5T<FEE=FEN9R!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DS"FUS9VED(")%
M=F5N="!A9&1E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3$P,PIM<V=I9"`B179E;G0@9&5L971E9#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3`Y.`IM<V=I9"`B179E;G0@961I=&5D.B(*;7-G
M<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#8V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5V96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z-S8T"B,L(&9U>GIY"FUS9VED(")%=F5N=',@;75S="!H
M879E(&$@<W1A<G0@9&%T92XB"FUS9W-T<B`BQ.#RX"#NZN[M]^#MZ/\@Y.[K
MYNW@(.'[\OP@[^[GYN4@Y.#R^R#MX/?@Z^`N(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z-S,P"FUS9VED(")%=F5N=',@;75S="!H879E(&$@=&ET;&4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V-PIM<V=I9"`B179E;G1S(&UU
M<W0@:&%V92!A;B!E;F0@9&%T92!O<B!A(&1U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-SD*(RP@
M9G5Z>GD*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R("+"\.7L_R#NZN[M
M]^#MZ/\B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X-PIM<V=I
M9"`B17AP;W)T(@IM<V=S='(@(MWJ\>_N\/(B"@HC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R="!#86QE;F1A<B(*;7-G<W1R
M("+=ZO'O[O#RZ/#NXN#R_"#JX.OE[>3@\/PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV.0IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B
MU.7B\.#K_"(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,3(X"B,L(&9U>GIY"FUS9VED(")&:6YD(@IM<V=S='(@(L__\NWH]N`B"@HC
M.B!Y96%R+G!H<#HX-R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV
M,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C(*(SH@;&EB+T)L;V-K+VUO
M;G1H+G!H<#HQ,#4*;7-G:60@(D9R(@IM<V=S='(@(L_R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U<WD@
M26YF;W)M871I;VXB"FUS9W-T<B`BPN#XX"#H[?3N\.S@]NC_(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(P('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$Q.0HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,@IM
M<V=I9"`B1G)I9&%Y(@IM<V=S='(@(L__\NWH]N`B"@HC.B!T96UP;&%T97,O
M9&5L971E+V1E;&5T92YI;F,Z,S`*;7-G:60@(D9U='5R92(*;7-G<W1R("+!
M\^3S^>7E(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")'86UE(@IM<V=S='(@(LCC\.`B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:%]A9'9A;F-E9"YI;F,Z,C,*;7-G:60@(D=E;F5R86PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1V]T;R`E<R(*;7-G<W1R("+/Y?#EZ?+H(@H*(SH@
M;6]N=&@N<&AP.C$S-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED
M92YI;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3`*;7-G:60@(DAI9&4B"FUS9W-T<B`B(@H*(SH@;6]N=&@N<&AP.C$S
M-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DAI9&4@)7,B"FUS9W-T<B`BPNCD("5S
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C4@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,3,X"FUS9VED(")(;W5R*',I(@IM<V=S='(@(M?@\2CW
MX/'[*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*(RP@9G5Z>GD*
M;7-G:60@(DAO=R!L;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T:&4@
M9&%Y(&%N9"!W965K('9I97=S(&)E/R(*;7-G<W1R("+/[NK@Y_OBX/+\(._N
MZ_/WX/'NXOOE(/_WY>GJZ"#O\.@@[_#N\>SN\O#E(.3MY>D@Z"#MY>3EZ_P_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`IM<V=I9"`B2&]W(&UA
M;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M871I;VX@<VAO=6QD('=E(&=E
M;F5R871E/R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#,P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DEF('EO=7(@96UA:6P@8VQI96YT
M(&1O97-N)W0@<W5P<&]R="!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E(&]N
M92!O9B!T:&4@(@HB9F]L;&]W:6YG(&QI;FMS('1O(&%C8V5P="!O<B!D96-L
M:6YE('1H92!E=F5N="Y<;B(*(EQN(@HB5&\@86-C97!T('1H92!E=F5N=#I<
M;B(*(B5S7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0@=&5N=&%T:79E
M;'DZ7&XB"B(E<UQN(@HB7&XB"B)4;R!D96-L:6YE('1H92!E=F5N=#I<;B(*
M(B5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($-A;&5N9&%R
M+"!3=&5P("5D(@IM<V=S='(@(LCL[^[P\NCP[N+@\OP@ZN#KY>WDX/#\(@H*
M(SH@9&%T82YP:'`Z,S(P"FUS9VED("));7!O<G0O17AP;W)T($-A;&5N9&%R
M(@IM<V=S='(@(LCL[^[P\B_=ZO'O[O#R(.K@Z^7MY.#P_R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(M_MXN#P_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C<T"FUS9VED(")*=6QY(@IM<V=S='(@(LC^Z_PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,PIM<V=I9"`B2G5N92(*;7-G<W1R
M("+(_NW\(@H*(SH@9&%T82YP:'`Z-C4@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,30R"FUS9VED(")+97EW;W)D<R(*;7-G<W1R("+*Z_[WY>+[Y2#QZ^[B
MX"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-0IM<V=I9"`B
M3&%S="`R-"!H;W5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHX-PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C0*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC.B!T
M96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$V('1E;7!L
M871E<R]M;VYT:"]H96%D+FEN8SHT"B,L(&9U>GIY"FUS9VED("),87-T($UO
M;G1H(@IM<V=S='(@(L_P[OCK^^D@[.7Q__8B"@HC.B!T96UP;&%T97,O>65A
M<B]H96%D+FEN8SHT"B,L(&9U>GIY"FUS9VED("),87-T(%EE87(B"FUS9W-T
M<B`BS_#N^.O@_R#MY>3EZ_\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z-30@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,PIM<V=I9"`B3&%S
M="!W965K(@IM<V=S='(@(L_P[OCKX/\@[>7DY>O_(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ-PIM<V=I9"`B3&EM:70@=&AE('1I;64@<W!A
M;B!T;R!E>'!O<G0Z(@IM<V=S='(@(L[C\.#MZ/?E[>CE(/WJ\>_N\/+H\//E
M[.[C[B#B\.7LY>WM[N/N(._P[NSEYO/RZN`Z(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C@V('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C<V"B,L(&9U>GIY"FUS9VED("),;U]C871I;VXB"FUS9W-T<B`B
MT.#Q[^[K[N;E[>CE(@H*(SH@9&%T82YP:'`Z-C0@=&5M<&QA=&5S+W-E87)C
M:"]E=F5N=%]H96%D97)S+FEN8SHU"B,Z('1E;7!L871E<R]P<F5F<R]R96UO
M=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$X"B,Z('1E;7!L871E<R]P<F5F<R]R
M96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C4R('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C(Q"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#D*;7-G:60@(DQO8V%T
M:6]N(@IM<V=S='(@(M#@\>_NZ^[FY>WHY2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-0IM<V=I9"`B36%N86=E(')E;6]T92!C86QE;F1A<G,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<P
M"FUS9VED(")-87)C:"(*;7-G<W1R("+,X/#R(@H*(SH@;&EB+V%P:2YP:'`Z
M,3`P"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!%=F5N=',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S(*;7-G:60@
M(DUA>2(*;7-G<W1R("+,X.DB"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0V"FUS
M9VED(")-92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I
M<W0Z,3<*;7-G:60@(DUE971I;F<B"FUS9W-T<B`BPO'R\.7WX"(*"B,Z(&QI
M8B]";&]C:R]T<F5E7V%L87)M<RYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N
M=2!!;&%R;7,B"FUS9W-T<B`BS>#O[NSH[>#MZ.4B"@HC.B!L:6(O0FQO8VLO
M=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU($QI<W0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C@@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,3,W"FUS9VED(")-:6YU=&4H<RDB"FUS9W-T<B`BS.CM\_+@
M*/LI(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C0R"FUS9VED
M(")-:7-S960@179E;G1S($QI<W0B"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z
M.#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-3D@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C$X"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U
M"FUS9VED(")-;R(*;7-G<W1R("+/[2(*"B,Z('1E;7!L871E<R]M;VYT:"]H
M96%D+FEN8SHQ-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,34*(SH@=&5M
M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C@@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-@IM<V=I9"`B36]N9&%Y(@IM<V=S='(@(L_N[>7DY>O\[>CJ
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,2!L:6(O0FQO8VLO=')E95]M
M96YU+G!H<#HR-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO
M;G1H(@IM<V=S='(@(LSE\?_V(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS
M"B,L(&9U>GIY"FUS9VED(")-;VYT:"!6:65W(@IM<V=S='(@(LSE\?_V(@H*
M(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL
M:7-T+G!H<#HT,PIM<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(R.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(DUO;G1H
M;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R("+/[N+R[O#_Y?+Q_R#EYN7LY?'_
M]^WN(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO
M;G1H<R!!:&5A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H
M;&ES="YP:'`Z,C0*(RP@9G5Z>GD*;7-G:60@(DUO;G1H<R!"969O<F4B"FUS
M9W-T<B`BS.CM\_+[(.3N(@H*(SH@;&EB+V%P:2YP:'`Z-C$R"FUS9VED(")-
M=6QT:7!L92!I0V%L96YD87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@
M=D5V96YT(&ES('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S
M+G!H<#HQ,C@@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8W
M"B,L(&9U>GIY"FUS9VED(")->2!#86QE;F1A<G,B"FUS9W-T<B`BR.SO[O#R
MZ/#NXN#R_"#JX.OE[>3@\/PB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S0@
M=&5M<&QA=&5S+VUE;G4N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")->2!#86QE
M;F1A<G,Z(@IM<V=S='(@(MWJ\>_N\/+H\.[BX/+\(.K@Z^7MY.#P_"(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,#0*;7-G:60@
M(DUY($9R964O0G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q-R!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z,34Y"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,3<U"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA
M;F%G96UE;G0N:6YC.C$W"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L
M7VUA;F%G96UE;G0N:6YC.C0T"B,L(&9U>GIY"FUS9VED(").86UE(@IM<V=S
M='(@(LCC\.`B"@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C0Q(&QI8B]";&]C
M:R]M;VYT:&QI<W0N<&AP.C0T(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT,0HC
M.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,`IM<V=I9"`B3F5W($5V96YT
M(@IM<V=S='(@(LWNXN[E(/'NX?ORZ.4B"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C,T"B,L(&9U>GIY"FUS9VED(").97AT(@IM<V=S='(@(M'K
MY>3S_OGHZ2#DY>W\(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M0E9I97<O9&%Y+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3F5X="!$87DB"FUS
M9W-T<B`BT>OEY//^^>CI(.3E[?PB"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A
M9%]S:61E7V)Y7W-I9&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?
M<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$X('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHV
M"FUS9VED(").97AT($UO;G1H(@IM<V=S='(@(M'KY>3S_OGHZ2#LY?'_]B(*
M"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(DYE
M>'0@5V5E:R(*;7-G<W1R("+1Z^7D\_[YX/\@[>7DY>O_(@H*(SH@=&5M<&QA
M=&5S+WEE87(O:&5A9"YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!996%R
M(@IM<V=S='(@(M'KY>3S_OGHZ2#DY>W\(@H*(SH@=&5M<&QA=&5S+V1A>2]H
M96%D+FEN8SHU"FUS9VED(").97AT(&1A>2(*;7-G<W1R("+1Z^7D\_[YZ.D@
MY.7M_"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU."!T96UP
M;&%T97,O=V5E:R]H96%D+FEN8SHU"FUS9VED(").97AT('=E96LB"FUS9W-T
M<B`BT>OEY//^^>#_(.WEY.7K_R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-S4*(RP@9G5Z>GD*;7-G:60@(DYO(@IM<V=S='(@(LWE\B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C<S('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C$R-@HC+"!F=7IZ>0IM<V=I9"`B3F\@86QA<FTB"FUS9W-T<B`BS>#O
M[NSH[>#MZ.4B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI
M;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(DYO(&%T=&5N9&5E<R(*;7-G<W1R("+-
MY?(@Y.#R^R#NZN[M]^#MZ/\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S$Q
M"FUS9VED(").;R!C86QE;F1A<G,@87)E(&%V86EL86)L92!T;R!G=65S=',N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$S-B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR-34*;7-G:60@(DYO(&5N9"!D871E
M(@IM<V=S='(@(LWE\B#DX/+[(.[J[NWWX.WH_R(*"B,Z(&QI8B]";&]C:R]P
M<F5V;6]N=&AL:7-T+G!H<#HQ-C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z
M,38S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ.30*;7-G:60@(DYO(&5V
M96YT<R!T;R!D:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+VMO
M;&%B+G!H<#HT,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!F<F5E+V)U<WD@
M:6YF;W)M871I;VX@:7,@879A:6QA8FQE(&9O<B`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HS-#0@;&EB+V%P:2YP:'`Z-C`R"FUS9VED(").;R!I
M0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(P-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<F5C
M=7)R96YC92(*;7-G<W1R("+$X.WM^^4@[^[B\N[PX"(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C@X-@IM<V=I9"`B3F\@=F%L:60@96UA:6P@861D<F5S<R!F
M;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,#$@;&EB
M+TMR;VYO;&ET:"YP:'`Z-C(R"FUS9VED(").;VYE(@IM<V=S='(@(LWE\B(*
M"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z,3,V"FUS9VED(").;W0@9F]U;F0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"B,L(&9U
M>GIY"FUS9VED(").;W1I9FEC871I;VYS(@IM<V=S='(@(M#@\>_NZ^[FY>WH
MY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<X"FUS9VED
M(").;W9E;6)E<B(*;7-G<W1R("+-[O_A\/PB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-PIM<V=I9"`B3V-T;V)E
M<B(*;7-G<W1R("+.ZO+_X?#\(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T
M:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-S@*;7-G:60@(D]N(&%L;"!C86QE;F1A<G,@22!H879E(')E
M860@86-C97-S('1O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-S<*;7-G:60@(D]N(&%L;"!S:&]W;B!C86QE;F1A<G,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-@IM<V=I9"`B3VX@
M;7D@8V%L96YD87)S(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-C$Y"B,L(&9U>GIY"FUS9VED(")/<'1I;VYA;"(*;7-G<W1R("+-
MX/'R\.[IZN@B"@HC.B!L:6(O1D)6:65W+G!H<#HQ,3@*;7-G:60@(D]P=&EO
M;F%L($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!L:6(O1D)6:65W+G!H<#HQ
M-3(*;7-G:60@(D]V97)V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C,T"FUS9VED(")/=VYE<B(*;7-G<W1R("(B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ.#0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")/=VYE<CH@)7,B"FUS9W-T<B`BQ.XZ("5S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ,#(@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M.#(*;7-G:60@(E!-(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(Y('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(E!A;&T@
M1&%T94)O;VLB"FUS9W-T<B`BQ.#RX"#MX._N[.CMX.WH_R(*"B,Z(&QI8B]"
M;&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HS"FUS9VED(")087-T($5V96YT<R!,
M:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$P
M.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.3@*;7-G:60@(E!A='1E<FXB
M"FUS9W-T<B`BSN'PX.?E]B(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN
M8SHR-PIM<V=I9"`B4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_(@IM
M<V=S='(@(LW@XO'EX^3@(//DX.OH\OP@_?+N(/'NX?ORZ.4_(@H*(SH@;&EB
M+V%P:2YP:'`Z,S(U(&QI8B]A<&DN<&AP.C0Q.2!L:6(O87!I+G!H<#HT.#$@
M;&EB+V%P:2YP:'`Z-34S"B,Z(&QI8B]A<&DN<&AP.C4X-"!L:6(O87!I+G!H
M<#HV-S`@;&EB+V%P:2YP:'`Z-S`V"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,38W"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M("++Z/?M[N4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*(RP@9G5Z
M>GD*;7-G:60@(E!O<G1A;"!/<'1I;VYS(@IM<V=S='(@(LW@\?+P[NGJZ"#O
M[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z,C4*(RP@9G5Z
M>GD*;7-G:60@(E!R979I;W5S($1A>2(*;7-G<W1R("+/\.7D^^3S^>CI(.3E
M[?PB"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C(V"B,L(&9U>GIY"FUS9VED
M(")0<F5V:6]U<R!7965K(@IM<V=S='(@(L_PY>3[Y//YZ.D@Y.7M_"(*"B,Z
M('1E;7!L871E<R]D87DO:&5A9"YI;F,Z,PIM<V=I9"`B4')E=FEO=7,@9&%Y
M(@IM<V=S='(@(L_PY>3[Y//YZ.D@Y.7M_"(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-3(*;7-G
M:60@(E)E8W5R(%5N=&EL(@IM<V=S='(@(L_NXO+N\"#D[B(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4F5C=7)R
M96YC92(*;7-G<W1R("+$X.WM^^4@[^[B\N[PX"(*"B,Z(&1A=&$N<&AP.C8Y
M"FUS9VED(")296-U<G)E;F-E($1A=&$B"FUS9W-T<B`BQ.#M[?OE(._NXO+N
M\.`B"@HC.B!D871A+G!H<#HV-PIM<V=I9"`B4F5C=7)R96YC92!%;F0@1&%T
M92(*;7-G<W1R("+$X/+@(.[J[NWWX.WH_R#O[N+R[O#@(@H*(SH@9&%T82YP
M:'`Z-C@*;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`BR.WR
MY?#BX.L@[^[B\N[PX"(*"B,Z(&1A=&$N<&AP.C8V"FUS9VED(")296-U<G)E
M;F-E(%1Y<&4B"FUS9W-T<B`BTNCO(._NXO+N\.`B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HU-#`*;7-G:60@(E)E8W5R<R!D86EL>2(*;7-G<W1R("+%YN7D
M[>7B[>XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#<*;7-G:60@(E)E8W5R
M<R!M;VYT:&QY(@IM<V=S='(@(L7FY>SE\?_W[>XB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HU-#,*;7-G:60@(E)E8W5R<R!W965K;'DB"FUS9W-T<B`BQ>;E
M[>7DY>O\[>XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3`*;7-G:60@(E)E
M8W5R<R!Y96%R;'DB"FUS9W-T<B`BQ>;EX^[D[>XB"@HC.B!L:6(O4V-H961U
M;&5R+VMR;VYO;&ET:"YP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M;6EN9&5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z.3$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T"B,L
M(&9U>GIY"FUS9VED(")296UO=&4@0V%L96YD87)S(@IM<V=S='(@(LCL[^[P
M\NCP[N+@\OP@ZN#KY>WDX/#\(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C8P
M('1E;7!L871E<R]M96YU+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E
M($-A;&5N9&%R<SHB"FUS9W-T<B`BR.SO[O#RZ/#NXN#R_"#JX.OE[>3@\/PB
M"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(B(*"B,Z(&%T
M=&5N9&5E<RYP:'`Z,3`T"FUS9VED(")296UO=F4@071T96YD964B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,@IM<V=I9"`B
M(@HB4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O<G1E
M9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E
M;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C(V"FUS9VED(")297%U
M:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O1D)6:65W+G!H<#HY."!L:6(O1D)6
M:65W+G!H<#HQ,S<@;&EB+T9"5FEE=RYP:'`Z,30P(&QI8B]&0E9I97<N<&AP
M.C$T,PIM<V=I9"`B4F5Q=6ER960@071T96YD965S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,T('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C,Q,`IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B
MT>'P[O$@\_'RX.WNXN[J(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E
M;F1E97,N:6YC.C0S('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-@IM<V=I
M9"`B4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#@@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C0@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C(S"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")3
M82(*;7-G<W1R("+1X2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR
M,2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V5D
M:70O:F%V87-C<FEP="YI;F,Z-S,*;7-G:60@(E-A='5R9&%Y(@IM<V=S='(@
M(M'SX>'N\N`B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z,3DR"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S='(@(M'A(@H*(SH@
M=FEE=V5V96YT+G!H<#HQ,3@@961I=&5V96YT+G!H<#HT."!E9&ET979E;G0N
M<&AP.C4V"FUS9VED(")3879E($%S($YE=R(*;7-G<W1R("+1[O7PX.WH\OP@
MZN#J(.WNXN[E(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C@W"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!A
M9&1E=F5N="YP:'`Z-34@961I=&5V96YT+G!H<#HU,0IM<V=I9"`B4V%V92!%
M=F5N="(*;7-G<W1R("+1[O7PX.WH\OP@\>[A^_+HY2(*"B,Z('-E87)C:"YP
M:'`Z.3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q
M-0HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-C<@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]S96%R8V@N:6YC.C@*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ-#`@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C8*
M(RP@9G5Z>GD*;7-G:60@(E-E87)C:"(*;7-G<W1R("+,X/#R(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$*(RP@9G5Z>GD*;7-G:60@
M(E-E87)C:"!#86QE;F1A<G,B"FUS9W-T<B`BR.SO[O#RZ/#NXN#R_"#JX.OE
M[>3@\/PB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-@IM<V=I
M9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]S96%R8V@N:6YC.C8*;7-G:60@(E-E87)C:"!F;W(@8V%L96YD
M87)S(&-O;G1A:6YI;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ-3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`BPOOAY?#H\N4@].#IZR#D
MZ_\@Z.SO[O#RX"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V."!T
M96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0HC.B!T96UP;&%T
M97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHX,PHC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&$@9&%T92(*;7-G<W1R("+$X/+@(.W@]^#KX"(*"B,Z('1E;7!L
M871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&-A;&5N
M9&%R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@[O+N
MX?#@YN7MZ/\@Y.#R.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM
M<V=I9"`B(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@
M9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@(@HB9&5F
M875L="!V:65W+B(*;7-G<W1R("(B"B+"^^'N\"#S\?+@[>[B[NH@[^[D\N+E
M\.;DY>WH_RP@ZN#J(.[R[N'PX.;@\OP@\.#GZ^CW[?OE(.+HY/LL(.+[X>[P
M(.+HY.`@[^X@(@HB\^SNZ_?@[>C^+B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3D*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@8V%L96YD
M87(@=&\@:6UP;W)T('1O.B(*;7-G<W1R("+"^^'E\.CRY2#TX.GK(.3K_R#H
M[._N\/+@(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R
M("+"^^'E\.CRY2#H\?+N]^WHZB#H[._N\/+@.B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,C@*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I
M;7!O<G0Z(@IM<V=S='(@(L+[X>7PZ/+E(/3@Z>L@Y.O_(.CL[^[P\N`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED(")396QE8W0@=&AE
M(&9I<G-T('=E96MD87DZ(@IM<V=S='(@(LWEY.7K_R#MX/?H[>#E\O'_(/$Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*
M;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@_>KQ[^[P\N`Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T:6UE('-P
M86X@=&\@<VAO=SHB"FUS9W-T<B`BPOOAY?#H\N4@[O+NX?#@YN#E[/OI(._P
M[NSEYO/R[NH@XO#E[.7MZ#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=FEE=R!T;R!D:7-P;&%Y
M(&]N('-T87)T=7`Z(@IM<V=S='(@(L+[X>7PZ/+E(.+HY"#O[O'KY2#B]>[D
MX"#B(/'H\?+E[/,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@:6X@
M=&AE('!O<G1A;"XB"FUS9W-T<B`BPOOAY?#H\N4L(.K@ZNCE(/'NX?ORZ/\@
M[^[JX.?[XN#R_"#MX"#CZ^#B[>[I(/'R\.#MZ/;E($AO<F1E+B(*"B,Z('1E
M;7!L871E<R]D96QE=&4O;VYE+FEN8SHR-"!T96UP;&%T97,O9&5L971E+V1E
M;&5T92YI;F,Z,C0*;7-G:60@(E-E;F0@82!C86YC96P@;F]T:69I8V%T:6]N
M('1O(&%L;"!A='1E;F1E97,@=VAE;B!D96QE=&EN9R!T:&ES(&5V96YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")396YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$X,0IM<V=I9"`B4V5N
M9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S
M879I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW-@IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@
M(M'E[?+_X?#\(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z.#,*(RP@9G5Z>GD*;7-G:60@(E-E="!E;F0@9&%T92(*;7-G<W1R("+-
MY?(@Y.#R^R#NZN[M]^#MZ/\B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR-C@*(RP@9G5Z>GD*;7-G:60@(E-E="!R96-U<G)E;F-E(&5N9"!D871E
M(@IM<V=S='(@(L3@\N`@[NKN[??@[>C_(._NXO+N\.`B"@HC.B!T96UP;&%T
M97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B
M4V5T('-T87)T(&1A=&4B"FUS9W-T<B`BQ.#RX"#MX/?@Z^`B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3D*;7-G:60@(B(*(E-E="!Y;W5R(&9R964O
M8G5S>2!C86QE;F1A<G,@86YD('EO=7(@;W=N(&%N9"!O=&AE<B!U<V5R<R<@
M9G)E92]B=7-Y(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP
M:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAA<F4@;F]T(&9O=6YD.B`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z-SD*(RP@9G5Z>GD*;7-G:60@(E-H87)E9"!#86QE;F1A<G,B"FUS
M9W-T<B`BR.SO[O#RZ/#NXN#R_"#JX.OE[>3@\/PB"@HC.B!T96UP;&%T97,O
M;65N=2YI;F,Z-#<@=&5M<&QA=&5S+VUE;G4N:6YC.C0Y"B,L(&9U>GIY"FUS
M9VED(")3:&%R960@0V%L96YD87)S.B(*;7-G<W1R("+=ZO'O[O#RZ/#NXN#R
M_"#JX.OE[>3@\/PB"@HC.B!C86QE;F1A<E]S96%R8V@N<&AP.C(U('1E;7!L
M871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHS"B,Z('1E;7!L871E
M<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@0V%L96YD87(B"FUS9W-T<B`BW>KQ[^[P\NCP[N+@\OP@ZN#KY>WD
MX/#\(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C(R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-H;W<@8V%L96YD87(@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-38*;7-G:60@(E-H
M;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30V"FUS9VED(")3:&]W(&1E;&5T92P@86QA<FTL(&%N
M9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS9VED(")3:&]W
M(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_(@IM<V=S='(@(L_NZN#G^^+@
M\OP@XB#JX.OE[>3@\.4@\_'RX/#EXOCHY2#GX.3@]^@_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$V-@IM<V=I9"`B4VAO=R!F<F5E+V)U<WD@;&5G
M96YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`S
M"FUS9VED(")3:&]W(&]N;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S
M970_(@IM<V=S='(@(L_NZN#G^^+@\OP@\N[K_.KN(/'NX?ORZ/\@\2#N[^[B
MY?GE[>CE[#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<U"FUS9VED
M(")3:&]W('-H87)E9"!C86QE;F1A<G,@<VED92UB>2US:61E/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"B,L(&9U>GIY"FUS
M9VED(")3:&]W('1A<VMS('5S:6YG(&-A=&5G;W)Y(&-O;&]R<S\B"FUS9W-T
M<B`BS^[JX.?[XN#R_"#B(.K@Z^7MY.#PY2#S\?+@\.7B^.CE(.?@Y.#WZ#\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@=&EM92!O9B!D87D@8F5T=V5E;B!E86-H(&1A>2!I;B!W965K('9I
M97=S/R(*;7-G<W1R("+/[NK@Y_OBX/+\(._NZ_/WX/'NXOOE(/_WY>GJZ"#O
M\.@@[_#N\>SN\O#E(.3MY>D@Z"#MY>3EZ_P_(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E-T85]R
M="(*;7-G<W1R("+-X/?H[>#E\O'_(@H*(SH@9&%T82YP:'`Z-34*;7-G:60@
M(E-T87)T($1A=&4B"FUS9W-T<B`BQ.#RX"#MX/?@Z^`B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C<@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-0IM
M<V=I9"`B4W1A<G0@3VXB"FUS9W-T<B`BS>#WZ.W@Y?+Q_R(*"B,Z(&1A=&$N
M<&AP.C4V"FUS9VED(")3=&%R="!4:6UE(@IM<V=S='(@(L+PY>S_(.W@]^#K
MX"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHY
M-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHX-0IM<V=I9"`B4W1A=%]U<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N
M:6YC.C8@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T871U
M<R(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX,2!Y96%R+G!H<#HY,"!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-0HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,C0@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#<@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#D*;7-G:60@(E-U(@IM<V=S='(@(L+Q(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H
M96%D+FEN8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M
M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(L+N\>KPY?'E
M[?SE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS9VED(")487-K
M<R(*;7-G<W1R("+'X.3@]^@B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S0@
M;&EB+TMR;VYO;&ET:"YP:'`Z-3DW"FUS9VED(")496YT871I=F4B"FUS9W-T
M<B`B(@H*(SH@>65A<BYP:'`Z.#8@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(Q"B,Z(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")4:"(*;7-G<W1R("+7\B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z-S`*;7-G:60@(E1H
M92!%9&ET($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N
M($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!C86YN;W0@
M8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HT,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B
M965N(&-R96%T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C4T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S
M(&)E96X@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!C;W5L
M9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M961I="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@(E1H92!E;F0@9&%T92!M
M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N(@IM<V=S='(@(L3@
M\N`@[NKN[??@[>C_(.3NZ^;MX"#A^_+\(._NY^;E(.3@\OL@[>#WX.O@+B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!A9&1E9"P@=VAI8V@@:7,@
M;VX@)7,@870@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$Q,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+"!W:&EC:"!W87,@;VX@)7,@870@)7,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!E9&ET960L('=H
M:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!N
M;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(T"FUS9VED(")4:&4@
M9F]L;&]W:6YG(&ES(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T
M:&4@979E;G0Z(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z-#$*;7-G:60@
M(B(*(E1H92!R97%U97-T('=A<R!I;F-O;7!L971E+B!3;VUE('!A<F%M971E
M<G,@=&AA="!A<F4@;F5C97-S87)Y('1O(&%C8V5P="!O<B`B"B)D96-L:6YE
M(&%N(&5V96YT(&%R92!M:7-S:6YG+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+V5M<'1Y+FEN8SHS"B,L(&9U>GIY"FUS9VED(")4:&5R92!A
M<F4@;F\@979E;G1S(&UA=&-H:6YG('1H92!C=7)R96YT(&-R:71E<FEA+B(*
M;7-G<W1R("+1[N'[\NC_(.3K_R#]ZO'O[O#RX"#MY2#MX.GDY>W[+B(*"B,Z
M(&%D9&5V96YT86-T:6]N+G!H<#HQ."!E9&ET979E;G1A8W1I;VXN<&AP.C,U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@86-C97-S:6YG('1H92!C86QE;F1A<CH@)7,B"FUS9W-T<B`BSOCHX>K@
M(._PZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z
M,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R("+.^.CAZN`@[_#H
M(.CL[^[P\N4@Y.#M[?OU+B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z.#,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!E9&ET:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`BSOCHX>K@(._PZ"#H
M[._N\/+E(.3@[>W[]2XB"@HC.B!L:6(O87!I+G!H<#HS,S@@;&EB+V%P:2YP
M:'`Z-3DV"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`BSOCHX>K@(._P
MZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C8S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@;6]V:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`BSOCHX>K@(._PZ"#H
M[._N\/+E(.3@[>W[]2XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#<R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG
M(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z,3`U"FUS9VED(")4:&5R92!W97)E(&YO(&5V96YT<R!T
M;R!E>'!O<G0N(@IM<V=S='(@(M'NX?ORZ/\@Y.O_(/WJ\>_N\/+@(.WE(.W@
MZ>3E[?LN(@H*(SH@9&%T82YP:'`Z,3@T"FUS9VED(")4:&ES(&9I;&4@9F]R
M;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6]N=&@O
M:&5A9"YI;F,Z,3D@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$X"B,Z('1E
M;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<Q"FUS9VED(")4:'5R<V1A
M>2(*;7-G<W1R("+7Y?+BY?#C(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC.C,W"B,L(&9U>GIY"FUS9VED(")4:6UE(%-P7V%N(@IM<V=S='(@
M(L+PY>SE[>W@_R#G[NW@(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE
M<W!A;BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B5&EM92!S<&%N(@IM<V=S='(@
M(L+PY>SE[>W@_R#G[NW@(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.C,V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0P"B,L
M(&9U>GIY"FUS9VED(")4:71?;&4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@
M9&%T82YP:'`Z-30@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"B,Z
M('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z,PIM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@;&EB+T)L;V-K+W!R979M
M;VYT:&QI<W0N<&AP.C$R,B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ,C$*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R-PIM<V=I9"`B5&]D87DB"FUS
M9W-T<B`BT>7C[N3M_R(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H
M<#HQ,C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(S"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ,CD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*
M"B,Z('EE87(N<&AP.C@T('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C8P('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$P-0IM<V=I9"`B5'4B"FUS9W-T<B`BPO(B"@HC.B!T96UP
M;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3<@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3$V"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8Y"FUS
M9VED(")4=65S9&%Y(@IM<V=S='(@(L+R[O#MZ.HB"@HC.B!C;VYF:6<O:V5Y
M=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(E1Y<&4B"FUS9W-T<B`BTNCO(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$X,PIM<V=I
M9"`B55),(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z-C0*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]$<FEV97(O;6-A;"YP:'`Z,3,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@8V%L96YD
M87)S+G!H<#HU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4O:V]L
M86(N<&AP.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R971R
M:65V92!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$U"B,Z('-C<FEP=',O=7!G
M<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T7V-A=&5G;W)I97-?=&]?<W1R:6YG
M<RYP:'`Z-3,*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,S<V(&QI8B]A<&DN<&AP.C0U,"!L:6(O87!I+G!H<#HU,38@;&EB
M+V%P:2YP:'`Z-C(Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D
M($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"FUS9VED
M(")5<V5R($EN=&5R9F%C92(*;7-G<W1R("+/[NO\Y^[BX/+EZ_SQZNCI(.CM
M\N7P].7I\2(*"B,Z('EE87(N<&AP.C$V,R!Y96%R+G!H<#HQ-CD@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ-3D@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ-C(*(RP@
M9G5Z>GD*;7-G:60@(E9I97<@1&%Y(@IM<V=S='(@(L+HY"`E<R(*"B,Z('EE
M87(N<&AP.C@U('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8Q('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,`HC.B!L:6(O0FQO8VLO;6]N=&@N
M<&AP.C$P-0IM<V=I9"`B5V4B"FUS9W-T<B`BT?`B"@HC.B!T96UP;&%T97,O
M;6]N=&@O:&5A9"YI;F,Z,3@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$W
M"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<P"FUS9VED(")7
M961N97-D87DB"FUS9W-T<B`BT?#EY.`B"@HC.B!A='1E;F1E97,N<&AP.C$Q
M,B!L:6(O2W)O;F]L:71H+G!H<#HQ,CDP(&QI8B]";&]C:R]T<F5E7VUE;G4N
M<&AP.C(S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E
M:R(*;7-G<W1R("+-Y>3EZ_\B"@HC.B!M;VYT:"YP:'`Z,3<Y('=O<FMW965K
M+G!H<#HS,"!W965K+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7965K
M("5D(@IM<V=S='(@(LWEY.7K_R`E9"(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C4Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$T,`IM<V=I9"`B
M5V5E:RAS*2(*;7-G<W1R("+-Y>3EZ_\HZ"DB"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"FUS
M9VED(")7965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R("+/[N+R[O#_Y?+Q
M_R#EYN7MY>3EZ_SM[B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*
M;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S
M(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S/R(*;7-G<W1R
M("(B"B+*X.KH["#B\.7LY>WE["#GX.K@[??HXN#R_"#N\N[A\.#FX/+\(.3E
M[?P@Z.OH(.WEY.7K_BP@[_#H(.[R\?/R\?+BZ.@@X>[KY>4@(@HB[^[GY.WH
M]2#Q[N'[\NCI/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G
M:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S('-T
M87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V96YT<S\B"FUS9W-T
M<B`B(@HBT2#JX.KNX^X@XO#E[.7MZ"#MX/?H[>#R_"#N\N[A\.#FX/+\(.3E
M[?P@Z.OH(.WEY.7K_BP@[_#H(.[R\?+S\O'RXNCH(.'NZ^7E("(*(O#@[>WH
M]2#Q[N'[\NCI/R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$Q(&QI8B]+<F]N;VQI
M=&@N<&AP.C$R.#D@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C(*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")7;W)K(%=E96LB"FUS9W-T
M<B`BT.#A[O?@_R#MY>3EZ_\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,CDR
M(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(U"FUS9VED(")996%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR-#$*;7-G:60@(EEE87)L>3H@4F5C=7)S(&5V
M97)Y(@IM<V=S='(@(L_NXO+N\/_E\O'_(.7FY>/NY.WN(@H*(SH@9&%T82YP
M:'`Z-#`@9&%T82YP:'`Z,C,T(&5D:71E=F5N=&%C=&EO;BYP:'`Z-#8@861D
M979E;G0N<&AP.C$W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!E=F5N=',N(@IM<V=S
M='(@(B(*"B,Z(&%T=&5N9"YP:'`Z-#D*;7-G:60@(EEO=2!A<F4@;F]T(&%N
M(&%T=&5N9&5E(&]F('1H92!S<&5C:69I960@979E;G0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z-S8*;7-G:60@
M(EEO=2!C86X@;VYL>2!U<V4@=&AI<R!F;W)M(&9R;VT@=&AE($5D:70@071T
M96YD965S('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z.3<P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D;R!N;W0@:&%V
M92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S;VYA
M;"!);F9O<FUA=&EO;B`B"B)/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S
M:&5R925S(&)E9F]R92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT
M+B(*;7-G<W1R("(B"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z,C`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M861D(&5V96YT<R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3DT
M"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E
M;G1S('1O('1H92!S96QE8W1E9"!C86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@
M9&5L979E;G1A8W1I;VXN<&AP.C(V"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!D96QE=&4@=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*
M(SH@961I=&5V96YT86-T:6]N+G!H<#HW.`IM<V=I9"`B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@961I="!T:&ES(&5V96YT+B(*;7-G<W1R("(B
M"@HC.B!D871A+G!H<#HQ.#D*;7-G:60@(EEO=2!H879E('-P96-I9FEE9"!A
M;B!I;G9A;&ED(&-A;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP
M.C(Q"FUS9VED(")9;W4@:&%V92!S=6-C97-S9G5L;'D@86-C97!T960@871T
M96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R("(B"@HC.B!A='1E;F0N
M<&AP.C(V"FUS9VED(")9;W4@:&%V92!S=6-C97-S9G5L;'D@9&5C;&EN960@
M871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R("(B"@HC.B!A='1E
M;F0N<&AP.C,Q"FUS9VED(")9;W4@:&%V92!T96YT871I=F5L>2!A8V-E<'1E
M9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z.3$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A(&-A;&5N
M9&%R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z-30*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#DT"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF
M:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`IM<V=I9"`B
M(@HB66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A
M<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY"FUS9VED(")9;W4@<F5Q=65S=&5D
M('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET960@:6X@>6]U
M<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]38VAE9'5L97(O:W)O
M;F]L:71H+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<75E
M<W1E9"!T;R!B92!R96UI;F1E9"!A8F]U="`E<RP@=VAI8V@@:7,@;VX@)7,@
M870@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&%R97-E
M;&5C="YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!C86QE
M;F1A<B(*;7-G<W1R("+=ZO'O[O#RZ/#NXN#R_"#JX.OE[>3@\/PB"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ,#4S(&QI8B]$<FEV97(N<&AP.C$P-C,*;7-G:60@
M(EM5;FYA;65D(&5V96YT72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHY-PHC+"!F=7IZ>0IM<V=I9"`B7T%L87)M(@IM<V=S='(@
M(LW@[^[LZ.W@[>CE(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C$Q"FUS9VED(")?0F%S:6,@4V5A<F-H(@IM<V=S='(@(B(*
M"B,Z('9I97=E=F5N="YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")?161I="(*
M;7-G<W1R("+0Y>3@ZO+H\.[BX/+\(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3,S,`HC+"!F=7IZ>0IM<V=I9"`B7T=O=&\B"FUS9W-T<B`BS^7PY>GRZ"(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S8*(RP@9G5Z>GD*;7-G:60@(E])
M;7!O<G0O17AP;W)T(@IM<V=S='(@(LCL[^[P\B_=ZO'O[O#R(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3,Q.`HC+"!F=7IZ>0IM<V=I9"`B7TUY($-A;&5N
M9&%R<R(*;7-G<W1R("+=ZO'O[O#RZ/#NXN#R_"#JX.OE[>3@\/PB"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,S(U"B,L(&9U>GIY"FUS9VED(")?3F5W($5V
M96YT(@IM<V=S='(@(LWNXN[E(/'NX?ORZ.4B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,S0Q"FUS9VED(")?4')I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,S,@HC+"!F=7IZ>0IM<V=I9"`B7U-E87)C:"(*;7-G
M<W1R("+,X/#R(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,R.`HC+"!F=7IZ
M>0IM<V=I9"`B7U1O9&%Y(@IM<V=S='(@(M'EX^[D[?\B"@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHQ-#(*;7-G:60@(F)E9F]R92!T:&4@979E;G0@
M<W1A<G1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(F1A>2(*;7-G<W1R("+DY>W\(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q,`IM
M<V=I9"`B9&%Y*',I(@IM<V=S='(@(N3E[?PHY.WH*2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.#8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-PHC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@X(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M9&%Y<R(*;7-G<W1R("+D[>@B"@HC.B!D871A+G!H<#HQ-#<@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ"B,L(&9U>GIY"FUS9VED(")E=F5N=',N8W-V
M(@IM<V=S='(@(L+QY2#Q[N'[\NC_(@H*(SH@9&%T82YP:'`Z,38X"B,L(&9U
M>GIY"FUS9VED(")E=F5N=',N:6-S(@IM<V=S='(@(L+QY2#Q[N'[\NC_(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,S$*;7-G:60@
M(F9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,S`@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,V
M"FUS9VED(")M;VYT:"AS*2(*;7-G<W1R("+LY?'_]BC[*2(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(F]N("5S(&%T("5S(@IM<V=S='(@(B5S(.W@]^CMX.7R\?\@XB`E<R(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,S`*;7-G:60@(F]N('1H92!S86UE(&1A=&4B"FUS9W-T<B`B
MXB#R[O(@YN4@Y.7M_"(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R
M-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S8*;7-G:60@(F]N('1H92!S
M86UE('=E96MD87DB"FUS9W-T<B`BXB#R[O(@YN4@Y.7M_"#MY>3EZ^@B"@HC
M.B!D871A+G!H<#HS,"!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U"FUS
M9VED(")V0V%L96YD87(O:4-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C,T.2!L:6(O87!I+G!H<#HV,#<*;7-G:60@(G9%=F5N="!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3$*;7-G:60@(G=E96LB"FUS9W-T<B`B[>7DY>O_(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q
M-PIM<V=I9"`B=V5E:RAS*2!O;CHB"FUS9W-T<B`B[>7DY>O_*.@I.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3(@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DT"FUS9VED(")W
M965K<R(*;7-G<W1R("+MY>3EZ^@B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C0R"FUS9VED(")Y
M96%R*',I(@IM<V=S='(@(N/NY"C[*2(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W!O
M+W)O7U)/+G!O````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#$Q-C0S-P`Q,#0Q-S,V,C<U,@`P,C`T-#,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!+<F]N;VQI=&@@,2XP(%)O;6%N
M:6%N('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R($AO<F1E(%!R
M;VIE8W0N"B,@175G96X@2&]A;F-A(#QE=6=E;FA`=7)B86XM9W)A9G@N<F\^
M+"`R,#`S+B`@"B,@36%R:75S($1R86=U;&5S8W4\;6%R:75S9$!U<F)A;BUG
M<F%F>"YR;SXL(#(P,#,N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T
M+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`Q+C!<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`S+3`S+3`Q(#$R.C`P("LP,C`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($5U9V5N($AO86YC83QE=6=E;FA`=7)B86XM9W)A9G@N<F\^7&XB"B),
M86YG=6%G92U496%M.B!2;VUA;FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+W-E87)C:"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@8V%L96YD
M87)S(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A
M9&5R+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!E=F5N
M=',B"FUS9W-T<B`B061A=6=A(&5V96YI;65N="(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!$87DH<RD@)7,@2&]U<BAS*2`E<R!-:6YU=&5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$W.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@871T96YD965S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(W-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E
M9"(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O8F%S92YP
M:'`Z,3(X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]S96%R8V@N:6YC.C$W"FUS9VED("(B"B(H0VQI8VL@;VX@8V%L96YD87(@
M;F%M92!T;R!S=VET8V@@=&AE(&-A;&5N9&%R)W,@=FES:6)I;&ET>2!I;B!T
M:&4@;6%I;B`B"B)W:6YD;W<I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,38T"FUS9VED("(J($%D9"!T:&5S92!B
M>2!C;&EC:VEN9R!!9&0@*B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$U,`IM<V=I9"`B*B!0;&5A<V4@<V5L96-T
M(&%D9')E<W,H97,I("HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<X-@IM<V=I9"`B,2!A='1E;F1E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B,2!E=F5N
M="(*;7-G<W1R(")!9&%U9V$@979E;FEM96YT(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-PHC+"!F=7IZ>0IM<V=I9"`B,2!H;W5R(@IM<V=S='(@
M(F]R82`E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z
M>GD*;7-G:60@(C$U(&UI;G5T97,B"FUS9W-T<B`B)60@;6EN=71E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM<V=I9"`B,C`@
M;6EN=71E<R(*;7-G<W1R("(E9"!M:6YU=&4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,V"B,L(&9U>GIY"FUS9VED("(S,"!M:6YU=&5S(@IM<V=S
M='(@(B5D(&UI;G5T92(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$W
M,0HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY!='1E;F1E97,\+W-T<F]N9SX@
M*&]P=&EO;F%L*2(*;7-G<W1R("(\8CY#=79I;G1E(&-H96EE/"]B/B`H;W!T
M:6]N86PI(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30Y"B,L(&9U
M>GIY"FUS9VED("(\<W1R;VYG/D1E<V-R:5]P=&EO;CPO<W1R;VYG/B`H;W!T
M:6]N86PI(@IM<V=S='(@(CQB/D1E<V-R:65R93PO8CX@*&]P:71O;F$[*2(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(W-PHC+"!F=7IZ>0IM<V=I
M9"`B/'-T<F]N9SY+97EW;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S
M='(@(CQB/D-U=FEN=&4@8VAE:64\+V(^("AO<'1I;VYA;"DB"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ.30*(RP@9G5Z>GD*;7-G:60@(CQS=')O
M;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB
M/D9R96-V96YT83PO8CX@*&]P=&EO;F%L*2(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,3`Q('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@Q
M"FUS9VED(")!32(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU
M.3$*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I9"`B061?=F%N8V5D(%-E87)C:"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$V,2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I
M9"`B061D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(V"FUS9VED(")!9&0@179E;G0B"FUS9W-T<B`B061A=6=A(&5V96YI;65N
M="(*"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N
M:6YC.C,U"B,L(&9U>GIY"FUS9VED(")!9&0@82!N97<@4F5M;W1E($-A;&5N
M9&%R(@IM<V=S='(@(D%D875G82!E=F5N:6UE;G0@;F]U(@H*(SH@861D979E
M;G0N<&AP.C8T"FUS9VED(")!9&0@82!N97<@979E;G0B"FUS9W-T<B`B061A
M=6=A(&5V96YI;65N="!N;W4B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-S0*;7-G:60@(D%D9"!A='1E;F1E97,B"FUS9W-T<B`B
M(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,3(P"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S
M+FEN8SHW.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I9"`B061V86YC960@4V5A<F-H
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C4S"FUS
M9VED(")!;&%R;2(*;7-G<W1R(")!;&%R;6$B"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-S8T"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&1A>7,@8F5F
M;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B06QA<FT@)60@:&]U<G,@8F5F;W)E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D%L87)M("5D(&UI;G5T97,@8F5F;W)E(@IM<V=S='(@(DUI
M;G5T92!I;F%I;G1E(&1E(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!W965K<R!B969O<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V,PIM<V=I9"`B06QA<FT@,2!D
M87D@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C@*
M;7-G:60@(D%L87)M(#$@:&]U<B!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<W,PHC+"!F=7IZ>0IM<V=I9"`B06QA<FT@,2!M:6YU
M=&4@8F5F;W)E(@IM<V=S='(@(DUI;G5T92!I;F%I;G1E(&1E(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<U.`IM<V=I9"`B06QA<FT@,2!W965K(&)E9F]R92(*
M;7-G<W1R("(B"@HC.B!D871A+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B06QA
M<FT@1&%T92(*;7-G<W1R(")!;&%R;6$B"@HC.B!D871A+G!H<#HU.0IM<V=I
M9"`B06QA<FT@4W!A;B`H;6EN=71E<RDB"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D%L87)M(%1I;64B"FUS9W-T<B`B06QA
M<FUA(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,Q"B,L(&9U
M>GIY"FUS9VED(")!;&PB"FUS9W-T<B`B5&]A=&$@>FEU82(*"B,Z(&QI8B]&
M0E9I97<N<&AP.C$R-B!L:6(O1D)6:65W+G!H<#HQ,CD@;&EB+T9"5FEE=RYP
M:'`Z,3,R"FUS9VED(")!;&P@071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU.0IM<V=I9"`B06QL($9U='5R
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M-3,*(RP@9G5Z>GD*;7-G:60@(D%L;"!087-T(@IM<V=S='(@(E1O871A('II
M=6$B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HR-`HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR
M-R!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D%L;"!6:7-I8FQE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C$R,B!L:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.CDS
M"B,Z(&QI8B]7965K5FEE=RYP:'`Z,3(W(&QI8B]7965K5FEE=RYP:'`Z,3,T
M(&QI8B]$<FEV97(N<&AP.C$X,S(*;7-G:60@(D%L;"!D87DB"FUS9W-T<B`B
M5&]A=&$@>FEU82(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-C0*(RP@
M9G5Z>GD*;7-G:60@(D%L;"!D87D@979E;G0B"FUS9W-T<B`B5&]A=&$@>FEU
M82(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*(RP@9G5Z>GD*
M;7-G:60@(D%L;"!E=F5N=',B"FUS9W-T<B`B061A=6=A(&5V96YI;65N="(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHT.0HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-S$@;&EB
M+TMR;VYO;&ET:"YP:'`Z-C@S"FUS9VED(")!;GDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S$*;7-G:60@(D%P<FEL
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C,Y('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.CDS"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-S`@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ-38*;7-G:60@(D%T(@IM<V=S='(@(DQA(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3`R-@IM<V=I9"`B(@HB071T86-H960@:7,@86X@
M:4-A;&5N9&%R(&9I;&4@=VET:"!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('1H
M92!E=F5N="X@268@>6]U<B`B"B)M86EL(&-L:65N="!S=7!P;W)T<R!I5&EP
M(')E<75E<W1S('EO=2!C86X@=7-E('1H:7,@9FEL92!T;R!E87-I;'D@=7!D
M871E("(*(GEO=7(@;&]C86P@8V]P>2!O9B!T:&4@979E;G0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C4*;7-G:60@(D%T=&5N9&%N8V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38Q"FUS
M9VED(")!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-S4*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C@*;7-G:60@(D)A<VEC(%-E87)C
M:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*
M;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(EII(&1E(&YA<W1E<F4B"@HC.B!L
M:6(O1D)6:65W+G!H<#HY,"!L:6(O1D)6:65W+G!H<#HQ,3`*;7-G:60@(D)U
M<WDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")#7V%L96YD87(B"FUS9W-T
M<B`B0V%L96YD87(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHT.0HC
M+"!F=7IZ>0IM<V=I9"`B0V%L7V5N9&%R(@IM<V=S='(@(D-A;&5N9&%R(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$T-B!L:6(O
M0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C$*(SH@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HR,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR,2!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,C(*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(D-A;&5N
M9&%R(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G
M:60@(D-A;&5N9&%R(%-U;6UA<GDB"FUS9W-T<B`B0V%L96YD87(B"@HC.B!D
M871A+G!H<#HR,C@*;7-G:60@(D-A;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G
M960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-PHC+"!F=7IZ>0IM<V=I
M9"`B0V%L96YD87)S(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@8V%L96YD87)S
M+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87)S(&UU<W0@:&%V92!A
M(&YA;64N(@IM<V=S='(@(D%C96%S=&$@=F%L;V%R92!T<F5B=6EE('-A(&9I
M92!N=6UE<FEC82XB"@HC.B!D871A+G!H<#HR-#,*(RP@9G5Z>GD*;7-G:60@
M(D-A;B=T(&-R96%T92!A(&YE=R!E=F5N="XB"FUS9W-T<B`B0W)E87)E(&5V
M96YI;65N="!N;W4B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$Y,2!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S`*(SH@=&5M<&QA
M=&5S+V1E;&5T92]D96QE=&4N:6YC.C,R('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C,S"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,P.0IM<V=I9"`B
M0V%N8V5L(@IM<V=S='(@(E)E;G5N=&%R92(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C4W,`HC+"!F=7IZ>0IM<V=I9"`B0V%N8V5L;&5D(@IM<V=S='(@(E)E
M;G5N=&%R92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-A;F-E;&QE9#H@)7,B"FUS9W-T<B`B4F5N
M=6YT87)E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N
M:6YC.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C8Y"B,L(&9U>GIY"FUS
M9VED(")#871E9V]R7WDB"FUS9W-T<B`B0V%T96=O<FEE(@H*(SH@9&%T82YP
M:'`Z-C,@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHT('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$S"FUS9VED(")#871E9V]R>2(*;7-G
M<W1R(")#871E9V]R:64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<Y
M"FUS9VED("(B"B)#:&]O<V4@:68@>6]U('=A;G0@=&\@8F4@;F]T:69I960@
M;V8@;F5W+"!E9&ET960L(&%N9"!D96QE=&5D(&5V96YT<R!B>2`B"B)E;6%I
M;#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R"FUS
M9VED(")#:&]O<V4@:68@>6]U('=A;G0@=&\@8F4@;F]T:69I960@;V8@;F5W
M+"!E9&ET960L(&%N9"!D96QE=&5D(&5V96YT<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-E87)C:%]A8F]O:U]S96QE8W0N:6YC.C$Y(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3D*;7-G:60@(D-H;V]S92!T:&4@861D
M<F5S<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O9F)?8V%L<U]S96QE8W0N:6YC
M.C$V"FUS9VED(")#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E(&EN
M('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$Q"FUS9VED(")#:&]O<V4@=&AE(&-A
M;&5N9&%R<R!T;R!I;F-L=61E('=H96X@9V5N97)A=&EN9R!F<F5E+V)U<WD@
M55),<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M"FUS9VED(")#:&]O<V4@>6]U<B!D969A=6QT(&-A;&5N9&%R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-C4*
M;7-G:60@(D-L96%R(&%L;"!A='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z,C@@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,PIM<V=I9"`B
M0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S,*;7-G:60@(D-O;F9I<FT@9&5L971I;VX@;V8@
M979E;G1S/R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-C<*
M;7-G:60@(D-O;F9I<FUE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z,C`X"FUS9VED(")#;W!Y('1H92!54DP@
M8F5L;W<@9F]R('5S92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S
M>2!54DPZ(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$V,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$R
M-@IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ,3(*(RP@9G5Z>GD*;7-G:60@(D-R96%T
M92!#86QE;F1A<B(*;7-G<W1R(")#86QE;F1A<B(*"B,Z(&UO;G1H+G!H<#HQ
M-C4@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,C4@=&5M<&QA=&5S+V1A>2]R
M;W<N:6YC.C8*(SH@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H
M<#HQ.30*;7-G:60@(D-R96%T92!A($YE=R!%=F5N="(*;7-G<W1R(")#<F5A
M<F4@979E;FEM96YT(&YO=2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C@P"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M96QE=&4O9&5L971E+FEN8SHR.0IM<V=I9"`B0W5R<F5N="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C`Y"FUS9VED(")$86EL>3H@4F5C=7)S(&5V97)Y(@IM
M<V=S='(@(EII;&YI8SH@4F5P971A<F4@;&$@9FEE8V%R92(*"B,Z(&%T=&5N
M9&5E<RYP:'`Z,3$P(&QI8B]+<F]N;VQI=&@N<&AP.C$R.#@@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R
M"FUS9VED(")$87DB"FUS9W-T<B`B6FDB"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHV,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,SD*;7-G:60@
M(D1A>2AS*2(*;7-G<W1R(")::2AL92DB"@HC.B!V:65W979E;G0N<&AP.C$P
M-`HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92(*;7-G<W1R(")3=&5R9V4@)R5S
M)R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Y"FUS9VED
M(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU
M.30*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#86QE;F1A
M<B(*;7-G<W1R(")#86QE;F1A<B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHQ.3,@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ.#$*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(Y('1E;7!L
M871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C(S"B,Z(&QI
M8B]$<FEV97(N<&AP.C$X,3,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92(*;7-G
M<W1R(")3=&5R9V4@)R5S)R(*"B,Z(&1E;&5V96YT+G!H<#HT,"!T96UP;&%T
M97,O9&5L971E+V]N92YI;F,Z,3@@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N
M:6YC.C$X"B,Z(&QI8B]$<FEV97(N<&AP.C$X,3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R(")3=&5R9V4@)R5S)R(*
M"B,Z(&5D:71E=F5N="YP:'`Z-S`*;7-G:60@(D1E;&5T92!%=F5N="(*;7-G
M<W1R(")3=&5R9V4@979E;FEM96YT(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D
M96QE=&4N:6YC.C(W"FUS9VED("(B"B)$96QE=&4@=&AE(&-U<G)E;G0@979E
M;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R
M96YC97,L(&]R("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3`T('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B1&5S
M8W)I7W!T:6]N(@IM<V=S='(@(D1U<F%T82(*"B,Z(&1A=&$N<&AP.C8R('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S4*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T
M:6]N(@IM<V=S='(@(D1U<F%T82(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3<S"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(@IM<V=S
M='(@(D%F:7-E87IA(&]P=&EU;F4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@0V%L
M96YD87)S(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(D%F:7-E87IA(&]P=&EU;FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S`*;7-G:60@(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E
M(&1U92!O;B!Y;W5R(&-A;&5N9&%R/R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU,S<*;7-G:60@(D1O97,@;F]T(')E8W5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$=64Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B
M1'5R871A(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$W,"!L:6(O1')I=F5R+G!H<#HQ.#`V"B,L(&9U>GIY"FUS9VED(")%9&ET
M(@IM<V=S='(@(D5D:71E87IA("(*"B,Z(&5D:71E=F5N="YP:'`Z,S,@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C8@;&EB+T1R:79E<BYP:'`Z,3@P-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@(D5D:71E87IA
M("5S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@W"FUS9VED(")%
M9&ET($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,30P"B,L(&9U>GIY"FUS9VED(")%9&ET($-A
M;&5N9&%R<R(*;7-G<W1R(")#86QE;F1A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-3`*;7-G:60@(D5D:70@4F5M;W1E($-A;&5N9&%R<R(*;7-G
M<W1R("(B"@HC.B!A='1E;F1E97,N<&AP.C$U,`IM<V=I9"`B161I="!A='1E
M;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N
M9"YI;F,Z,C`*;7-G:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,3<V('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D5N7V0B"FUS9W-T<B`B4V9A<G-I
M="!D92(*"B,Z(&1A=&$N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")%;F0@1&%T
M92(*;7-G<W1R(")&87)A(&1A=&$@9&4@9FEN86PB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C@@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#@*;7-G
M:60@(D5N9"!/;B(*;7-G<W1R(")39F%R<VET(&1E(@H*(SH@9&%T82YP:'`Z
M-3@*(RP@9G5Z>GD*;7-G:60@(D5N9"!4:6UE(@IM<V=S='(@(FYI8VD@=6X@
M;W)A<B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3(T(&%T=&5N9&5E<RYP:'`Z,3,U
M(&%T=&5N9&5E<RYP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(')E=')I979I;F<@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<SH@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y,PIM<V=I9"`B
M179E;G0@861D960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$Q,#,*;7-G:60@(D5V96YT(&1E;&5T960Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P.3@*;7-G:60@(D5V96YT(&5D:71E9#HB"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`V-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%=F5N="!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C<V-`HC+"!F=7IZ>0IM<V=I9"`B179E;G1S(&UU<W0@
M:&%V92!A('-T87)T(&1A=&4N(@IM<V=S='(@(D1A=&$@9&4@<V9A<G-I="!T
M<F5B=6EE('-A(&9I92!M86D@;F]U82!D96-A="!D871A(&1E(&EN8V5P=70N
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S,P"FUS9VED(")%=F5N=',@;75S="!H
M879E(&$@=&ET;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V
M-PIM<V=I9"`B179E;G1S(&UU<W0@:&%V92!A;B!E;F0@9&%T92!O<B!A(&1U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-SD*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X-PIM<V=I9"`B17AP
M;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M.`HC+"!F=7IZ>0IM<V=I9"`B17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(D-A
M;&5N9&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-CD*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,3(X"B,L(&9U>GIY"FUS9VED(")&:6YD(@IM
M<V=S='(@(E9I;F5R:2(*"B,Z('EE87(N<&AP.C@W('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R
M,@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B1G(B"FUS9W-T
M<B`B5FEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY
M"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M871I:2!P97)S;VYA;&4B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M,C`@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$Y"B,Z('1E;7!L871E<R]E
M9&ET+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")&<FED87DB"FUS9W-T<B`B
M5FEN97)I(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,P"FUS
M9VED(")&=71U<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H
M<"YD:7-T.C$W"FUS9VED(")'86UE(@IM<V=S='(@(DIO8R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHR,PIM<V=I9"`B1V5N
M97)A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30P
M"B,L('!H<"UF;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`B(@H*(SH@
M;6]N=&@N<&AP.C$S-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED
M92YI;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3`*;7-G:60@(DAI9&4B"FUS9W-T<B`B(@H*(SH@;6]N=&@N<&AP.C$S
M-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&ED92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHV-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M,S@*;7-G:60@(DAO=7(H<RDB"FUS9W-T<B`B3W)A*&4I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S,PHC+"!F=7IZ>0IM<V=I9"`B2&]W(&QO;F<@
M<VAO=6QD('1H92!T:6UE('-L;W1S(&]N('1H92!D87D@86YD('=E96L@=FEE
M=W,@8F4_(@IM<V=S='(@(B(*(D%F:7-A<F4@<V5G;65N=&4@9&4@:G5M871A
M=&D@9&4@;W)A(&EN('9I>G5A;&EZ87)I;&4@>FEL96D@<VD@<V%P=&%M86YI
M:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@X"FUS9VED(")(;W<@
M;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S:&]U;&0@=V4@
M9V5N97)A=&4_(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB268@>6]U<B!E;6%I;"!C;&EE
M;G0@9&]E<VXG="!S=7!P;W)T(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@
M;VYE(&]F('1H92`B"B)F;VQL;W=I;F<@;&EN:W,@=&\@86-C97!T(&]R(&1E
M8VQI;F4@=&AE(&5V96YT+EQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT
M.EQN(@HB)7-<;B(*(EQN(@HB5&\@86-C97!T('1H92!E=F5N="!T96YT871I
M=F5L>3I<;B(*(B5S7&XB"B)<;B(*(E1O(&1E8VQI;F4@=&AE(&5V96YT.EQN
M(@HB)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!#86QE;F1A<BP@4W1E
M<"`E9"(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,C`*;7-G:60@(DEM<&]R
M="]%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-C@*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S0*;7-G:60@
M(DIU;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-S,*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M-C4@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,30R"FUS9VED(")+97EW;W)D
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M-34*;7-G:60@(DQA<W0@,C0@:&]U<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z.#<*;7-G:60@(DQA<W0@36]D:69I960B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E
M+FEN8SHT"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3`*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN
M8SHQ-B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z-`HC+"!F=7IZ>0IM<V=I
M9"`B3&%S="!-;VYT:"(*;7-G<W1R(")5;'1I;6$@;'5N82(*"B,Z('1E;7!L
M871E<R]Y96%R+VAE860N:6YC.C0*(RP@9G5Z>GD*;7-G:60@(DQA<W0@665A
M<B(*;7-G<W1R(")5;'1I;6$@<V%P=&%M86YA(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C4T('1E;7!L871E<R]W965K+VAE860N:6YC.C,*
M;7-G:60@(DQA<W0@=V5E:R(*;7-G<W1R(")5;'1I;6$@<V%P=&%M86YA(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I
M9"`B3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z(@IM<V=S='(@(E-E
M;&5C=&5A>F$@:6YT97)V86P@9&4@=&EM<#HB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z.#8@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(DQO7V-A=&EO;B(*;7-G<W1R("),
M;V-A=&EE(@H*(SH@9&%T82YP:'`Z-C0@=&5M<&QA=&5S+W-E87)C:"]E=F5N
M=%]H96%D97)S+FEN8SHU"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L
M7VUA;F%G96UE;G0N:6YC.C$X"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?
M8V%L7VUA;F%G96UE;G0N:6YC.C4R('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C(Q"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#D*;7-G:60@(DQO8V%T:6]N(@IM
M<V=S='(@(DQO8V%T:64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*
M;7-G:60@(DUA;F%G92!R96UO=&4@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,`IM<V=I9"`B36%R
M8V@B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-87AI
M;75M($YU;6)E<B!O9B!%=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S(*(RP@9G5Z>GD*;7-G:60@(DUA>2(*
M;7-G<W1R(")Z:2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#8*;7-G:60@(DUE
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM
M<V=I9"`B365E=&EN9R(*;7-G<W1R("));G1A;&YI<F4B"@HC.B!L:6(O0FQO
M8VLO=')E95]A;&%R;7,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@06QA
M<FUS(@IM<V=S='(@(D%L87)M82(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N
M<&AP.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHV."!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M,S<*(RP@9G5Z>GD*;7-G:60@(DUI;G5T92AS*2(*;7-G<W1R(")-:6YU=&4B
M"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z-#(*;7-G:60@(DUI
M<W-E9"!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX,R!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHU.2!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,3@*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G
M:60@(DUO(@IM<V=S='(@(DQU;B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D
M+FEN8SHQ-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,34*(SH@=&5M<&QA
M=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-@IM<V=I9"`B36]N9&%Y(@IM<V=S='(@(DQU;FDB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,CDQ(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(T
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0IM<V=I9"`B36]N=&@B"FUS9W-T
M<B`B3'5N82(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,PHC+"!F=7IZ>0IM
M<V=I9"`B36]N=&@@5FEE=R(*;7-G<W1R("),=6YA(@H*(SH@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT,PIM
M<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R.2!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(DUO;G1H;'DZ(%)E8W5R<R!E
M=F5R>2(*;7-G<W1R("),=6YA<CH@4V4@<F5P971A(&QA(&9I96-A<F4B"@HC
M.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS($%H
M96%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H
M<#HR-`HC+"!F=7IZ>0IM<V=I9"`B36]N=&AS($)E9F]R92(*;7-G<W1R(")-
M:6YU=&4@:6YA:6YT92!D92(*"B,Z(&QI8B]A<&DN<&AP.C8Q,@IM<V=I9"`B
M375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE
M('9%=F5N="!I<R!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R
M<RYP:'`Z,3(X('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHV
M-PHC+"!F=7IZ>0IM<V=I9"`B37D@0V%L96YD87)S(@IM<V=S='(@(D-A;&5N
M9&%R(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M96YU
M+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B37D@0V%L96YD87)S.B(*;7-G<W1R
M(")#86QE;F1A<B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHR,#0*;7-G:60@(DUY($9R964O0G5S>2!54DPB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q-R!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34Y"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<U"B,Z('1E;7!L871E<R]P<F5F
M<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$W"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C0T"B,L(&9U>GIY"FUS
M9VED(").86UE(@IM<V=S='(@(DIO8R(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z-#$@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#0@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C0Q"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(P"FUS
M9VED(").97<@179E;G0B"FUS9W-T<B`B179E;FEM96YT(&YO=2(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(DYE
M>'0B"FUS9W-T<B`B6FEU82!U<FUA=&]A<F4B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-3<*;7-G:60@(DYE>'0@,C0@:&]U<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(Y"B,L(&9U>GIY"FUS9VED
M(").97AT($1A>2(*;7-G<W1R(")::75A('5R;6%T;V%R92(*"B,Z('1E;7!L
M871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-@HC.B!T96UP;&%T
M97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3@@=&5M<&QA=&5S+VUO
M;G1H+VAE860N:6YC.C8*;7-G:60@(DYE>'0@36]N=&@B"FUS9W-T<B`B3'5N
M82!U<FUA=&]A<F4B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C,R"B,L(&9U
M>GIY"FUS9VED(").97AT(%=E96LB"FUS9W-T<B`B4V%P=&%M86YA('5R;6%T
M;V%R92(*"B,Z('1E;7!L871E<R]Y96%R+VAE860N:6YC.C8*(RP@9G5Z>GD*
M;7-G:60@(DYE>'0@665A<B(*;7-G<W1R(")::75A('5R;6%T;V%R92(*"B,Z
M('1E;7!L871E<R]D87DO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!D87DB"FUS
M9W-T<B`B6FEU82!U<FUA=&]A<F4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM<V=I9"`B
M3F5X="!W965K(@IM<V=S='(@(E-A<'1A;6%N82!U<FUA=&]A<F4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<U"B,L(&9U>GIY"FUS9VED(").;R(*
M;7-G<W1R(").:6-I('5N(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M-S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3(V"B,L(&9U>GIY"FUS9VED
M(").;R!A;&%R;2(*;7-G<W1R(")!;&%R;6$B"@HC.B!T96UP;&%T97,O871T
M96YD965S+V%T=&5N9&5E<RYI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(DYO(&%T
M=&5N9&5E<R(*;7-G<W1R(")&87)A(&1A=&$@9&4@9FEN86PB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,S$Q"FUS9VED(").;R!C86QE;F1A<G,@87)E(&%V
M86EL86)L92!T;R!G=65S=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-34*
M;7-G:60@(DYO(&5N9"!D871E(@IM<V=S='(@(D9A<F$@9&%T82!D92!F:6YA
M;"(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ-C0@;&EB+T)L
M;V-K+VUO;G1H;&ES="YP:'`Z,38S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ.30*;7-G:60@(DYO(&5V96YT<R!T;R!D:7-P;&%Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HT,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!F<F5E+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE(&9O
M<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HS-#0@;&EB+V%P:2YP
M:'`Z-C`R"FUS9VED(").;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(P-`IM<V=I
M9"`B3F\@<F5C=7)R96YC92(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HX.#8*;7-G:60@(DYO('9A;&ED(&5M86EL(&%D9')E<W,@9F]U;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C`Q(&QI8B]+<F]N
M;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N92(*;7-G<W1R(").:6-I('5N(@H*
M(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ,S8*;7-G:60@(DYO="!F;W5N9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*(RP@9G5Z
M>GD*;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`B3&]C871I92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<X"FUS9VED(").;W9E
M;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW-PIM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,R!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHV-0IM<V=I9"`B3VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.`IM<V=I9"`B
M3VX@86QL(&-A;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-PIM<V=I9"`B3VX@
M86QL('-H;W=N(&-A;&5N9&%R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C<V"FUS9VED(")/;B!M>2!C86QE;F1A<G,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,3D*(RP@9G5Z>GD*
M;7-G:60@(D]P=&EO;F%L(@IM<V=S='(@(D]P=&EU;FDB"@HC.B!L:6(O1D)6
M:65W+G!H<#HQ,3@*;7-G:60@(D]P=&EO;F%L($%T=&5N9&5E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O1D)6:65W+G!H<#HQ-3(*;7-G:60@(D]V97)V:65W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C,T"FUS9VED
M(")/=VYE<B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0U"B,L
M('!H<"UF;W)M870*;7-G:60@(D]W;F5R.B`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P,B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$X,@IM<V=I9"`B4$TB"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z,CD@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-`IM<V=I9"`B4&%L
M;2!$871E0F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H
M;&ES="YP:'`Z,PIM<V=I9"`B4&%S="!%=F5N=',@3&ES="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,#D@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,3DX"FUS9VED(")0871T97)N(@IM<V=S='(@(DUO9&5L
M(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(W"FUS9VED(")097)M
M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,S(U(&QI8B]A<&DN<&AP.C0Q.2!L:6(O87!I+G!H<#HT.#$@
M;&EB+V%P:2YP:'`Z-34S"B,Z(&QI8B]A<&DN<&AP.C4X-"!L:6(O87!I+G!H
M<#HV-S`@;&EB+V%P:2YP:'`Z-S`V"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,38W"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M(")097)S;VYA;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0HC+"!F
M=7IZ>0IM<V=I9"`B4&]R=&%L($]P=&EO;G,B"FUS9W-T<B`B3W!T:75N:2(*
M"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B4')E
M=FEO=7,@1&%Y(@IM<V=S='(@(EII=6$@<')E8V5D96YT82(*"B,Z(&QI8B]&
M0E9I97<O=V5E:RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(%=E
M96LB"FUS9W-T<B`B6FEU82!P<F5C961E;G1A(@H*(SH@=&5M<&QA=&5S+V1A
M>2]H96%D+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D87DB"FUS9W-T<B`B6FEU
M82!P<F5C961E;G1A(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,U
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(U,@IM<V=I9"`B4F5C=7(@56YT
M:6PB"FUS9W-T<B`B4F5P971A('!A;F$B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,#8*;7-G:60@(E)E8W5R<F5N8V4B"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(E)E8W5R<F5N8V4@1&%T82(*
M;7-G<W1R("(\8CY&<F5C=F5N=&$\+V(^("AO<'1I;VYA;"DB"@HC.B!D871A
M+G!H<#HV-PIM<V=I9"`B4F5C=7)R96YC92!%;F0@1&%T92(*;7-G<W1R("(B
M"@HC.B!D871A+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4F5C=7)R96YC92!)
M;G1E<G9A;"(*;7-G<W1R(")297!E=&$@<&%N82(*"B,Z(&1A=&$N<&AP.C8V
M"FUS9VED(")296-U<G)E;F-E(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z-30P"B,L(&9U>GIY"FUS9VED(")296-U<G,@9&%I;'DB
M"FUS9W-T<B`B4F5P971A('!A;F$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU
M-#<*(RP@9G5Z>GD*;7-G:60@(E)E8W5R<R!M;VYT:&QY(@IM<V=S='(@(E)E
M<&5T82!P86YA(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30S"B,L(&9U>GIY
M"FUS9VED(")296-U<G,@=V5E:VQY(@IM<V=S='(@(EII;&YI8SH@4F5P971A
M<F4@;&$@9FEE8V%R92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4U,`HC+"!F
M=7IZ>0IM<V=I9"`B4F5C=7)S('EE87)L>2(*;7-G<W1R(")::6QN:6,Z(%)E
M<&5T87)E(&QA(&9I96-A<F4B"@HC.B!L:6(O4V-H961U;&5R+VMR;VYO;&ET
M:"YP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6EN9&5R.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z.3$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T"B,L(&9U>GIY"FUS9VED
M(")296UO=&4@0V%L96YD87)S(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@=&5M
M<&QA=&5S+VUE;G4N:6YC.C8P('1E;7!L871E<R]M96YU+FEN8SHV,@HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<SHB"FUS9W-T<B`B0V%L96YD
M87(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(B(*"B,Z
M(&%T=&5N9&5E<RYP:'`Z,3`T"FUS9VED(")296UO=F4@071T96YD964B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,@IM<V=I
M9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O
M<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L
M;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C(V"FUS9VED(")2
M97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O1D)6:65W+G!H<#HY."!L:6(O
M1D)6:65W+G!H<#HQ,S<@;&EB+T9"5FEE=RYP:'`Z,30P(&QI8B]&0E9I97<N
M<&AP.C$T,PIM<V=I9"`B4F5Q=6ER960@071T96YD965S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,T('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C,Q,`IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T
M<B`B4F5S971E87IA(&QA('9A;&]R:2!I;7!L:6-I=&4B"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#,@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,38V"FUS9VED(")297-P;VYS92(*;7-G<W1R("(B"@HC.B!Y
M96%R+G!H<#HX."!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-"!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,C,*(SH@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(E-A;2(*"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D+FEN8SHR,2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C`*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S,*;7-G:60@
M(E-A='5R9&%Y(@IM<V=S='(@(E-A;6)A=&$B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DR"B,L(&9U>GIY"FUS9VED(")3879E
M(@IM<V=S='(@(E-A;2(*"B,Z('9I97=E=F5N="YP:'`Z,3$X(&5D:71E=F5N
M="YP:'`Z-#@@961I=&5V96YT+G!H<#HU-@IM<V=I9"`B4V%V92!!<R!.97<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C@W"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!A
M9&1E=F5N="YP:'`Z-34@961I=&5V96YT+G!H<#HU,0IM<V=I9"`B4V%V92!%
M=F5N="(*;7-G<W1R(")386QV96%Z82!E=F5N:6UE;G0B"@HC.B!S96%R8V@N
M<&AP.CDQ('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ
M,34*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C8W('1E;7!L871E
M<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHX"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,30P(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]S96%R8V@N:6YC.C$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!#86QE
M;F1A<G,B"FUS9W-T<B`B0V%L96YD87(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z-@IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C8*;7-G:60@
M(E-E87)C:"!F;W(@8V%L96YD87)S(&-O;G1A:6YI;F<Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3`*;7-G
M:60@(E-E;&5C="!A(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X('1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM
M97-P86XN:6YC.C@S"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")396QE8W1E87IA
M(&UO9"!D92!A9FES87)E($1A=&4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@8V]N9FER;6%T:6]N
M(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE=W,@
M86YD(&-H;V]S92`B"B)D969A=6QT('9I97<N(@IM<V=S='(@(B(*(E-E;&5C
M=&5A>F$@;6]D=6P@9&4@869I<V%R92!A;"!V:7IU86QI>F%R:6QO<B!S:2!A
M;&5G92!V:7IU86QI>F%R92!I;7!L:6-I=&$N(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ.0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C
M86QE;F1A<B!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(E-E;&5C=&5A>F$@:6YT
M97)V86P@9&4@=&EM<#HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z
M(@IM<V=S='(@(E-E;&5C=&5A>F$@<')I;6$@>FD@9&EN('-A<'1A;6%N83HB
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(X"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")396QE
M8W1E87IA(&EN=&5R=F%L(&1E('1I;7`Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-`IM<V=I9"`B4V5L96-T('1H92!F:7)S="!W965K9&%Y.B(*
M;7-G<W1R(")396QE8W1E87IA('!R:6UA('II(&1I;B!S87!T86UA;F$Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0IM<V=I9"`B4V5L96-T
M('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@T"FUS9VED(")396QE8W0@=&AE
M('1I;64@<W!A;B!T;R!S:&]W.B(*;7-G<W1R(")396QE8W1E87IA(&EN=&5R
M=F%L(&1E('1I;7`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O;B!S
M=&%R='5P.B(*;7-G<W1R(")396QE8W1E87IA('1I<"!D92!V:7IU86QI>F%R
M92!D=7!A(&EN=')A<F4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@
M:6X@=&AE('!O<G1A;"XB"FUS9W-T<B`B4V5L96-T96%Z82!C92!E=F5N:6UE
M;G1E('-A('-E(&%F:7-E>F4@:6X@8W5P<FEN<W5L($AO<F1E+B(*"B,Z('1E
M;7!L871E<R]D96QE=&4O;VYE+FEN8SHR-"!T96UP;&%T97,O9&5L971E+V1E
M;&5T92YI;F,Z,C0*;7-G:60@(E-E;F0@82!C86YC96P@;F]T:69I8V%T:6]N
M('1O(&%L;"!A='1E;F1E97,@=VAE;B!D96QE=&EN9R!T:&ES(&5V96YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")396YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$X,0IM<V=I9"`B4V5N
M9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S
M879I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW-@IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L
M(&9U>GIY"FUS9VED(")3970@96YD(&1A=&4B"FUS9W-T<B`B1F%R82!D871A
M(&1E(&9I;F%L(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X"FUS
M9VED(")3970@<F5C=7)R96YC92!E;F0@9&%T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0HC+"!F=7IZ>0IM
M<V=I9"`B4V5T('-T87)T(&1A=&4B"FUS9W-T<B`B:6X@86-E96%S:2!D871A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y"FUS9VED("(B"B)3970@
M>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H
M97(@=7-E<G,G(&9R964O8G5S>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C
M86QE;F1A<G,N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(E-H87)E(&YO
M="!F;W5N9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C<Y"B,L(&9U>GIY"FUS9VED(")3:&%R960@0V%L
M96YD87)S(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@=&5M<&QA=&5S+VUE;G4N
M:6YC.C0W('1E;7!L871E<R]M96YU+FEN8SHT.0HC+"!F=7IZ>0IM<V=I9"`B
M4VAA<F5D($-A;&5N9&%R<SHB"FUS9W-T<B`B0V%L96YD87(B"@HC.B!C86QE
M;F1A<E]S96%R8V@N<&AP.C(U('1E;7!L871E<R]W965K+VAE861?<VED95]B
M>5]S:61E+FEN8SHS"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I
M9&4N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@0V%L96YD87(B"FUS9W-T
M<B`B0V%L96YD87(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI
M;F,Z,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!C86QE;F1A<B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U-@IM
M<V=I9"`B4VAO=R!C871E9V]R>2!L96=E;F0_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(E-H;W<@9&5L971E+"!A
M;&%R;2P@86YD(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G
M:60@(E-H;W<@9'5E('1A<VMS(&EN('1H92!C86QE;F1A<C\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V-@IM<V=I9"`B4VAO=R!F
M<F5E+V)U<WD@;&5G96YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C`S"FUS9VED(")3:&]W(&]N;'D@979E;G1S('1H870@:&%V
M92!A;B!A;&%R;2!S970_(@IM<V=S='(@(D%F:7-A<F4@;G5M86D@82!E=F5N
M:6UE;G1E;&]R(&-A<F4@874@<V5T871A(&%L87)M83\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3<U"FUS9VED(")3:&]W('-H87)E9"!C86QE;F1A
M<G,@<VED92UB>2US:61E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(Q"FUS9VED(")3:&]W('1A<VMS('5S:6YG(&-A=&5G;W)Y
M(&-O;&]R<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDU"B,L(&9U>GIY"FUS9VED(")3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@
M96%C:"!D87D@:6X@=V5E:R!V:65W<S\B"FUS9W-T<B`B(@HB069I<V%R92!S
M96=M96YT92!D92!J=6UA=&%T:2!D92!O<F$@:6X@=FEZ=6%L:7IA<FEL92!Z
M:6QE:2!S:2!S87!T86UA;FEI/R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")3=&%?<G0B"FUS9W-T
M<B`B26YC97!E(&QA(@H*(SH@9&%T82YP:'`Z-34*(RP@9G5Z>GD*;7-G:60@
M(E-T87)T($1A=&4B"FUS9W-T<B`B26YC97!E(&QA(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHW('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C4*;7-G
M:60@(E-T87)T($]N(@IM<V=S='(@(DEN8V5P92!L82(*"B,Z(&1A=&$N<&AP
M.C4V"B,L(&9U>GIY"FUS9VED(")3=&%R="!4:6UE(@IM<V=S='(@(DEN8V5P
M92!L82(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN
M8SHY-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHX-0IM<V=I9"`B4W1A=%]U
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E
M<G,N:6YC.C8@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T
M871U<R(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX,2!Y96%R+G!H<#HY,"!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-0HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,C0@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#<@;&EB
M+T)L;V-K+VUO;G1H+G!H<#HQ,#D*;7-G:60@(E-U(@IM<V=S='(@(D1U;2(*
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-"!T96UP;&%T97,O;6]N
M=&@O:&5A9"YI;F,Z,C,*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(Q
M('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8W"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#4*;7-G:60@(E-U;F1A>2(*;7-G<W1R(")$=6UI
M;FEC82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0HC+"!F=7IZ>0IM
M<V=I9"`B5&%S:W,B"FUS9W-T<B`B56QT:6UI:2(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C4W-"!L:6(O2W)O;F]L:71H+G!H<#HU.3<*;7-G:60@(E1E;G1A
M=&EV92(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX-B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1H(@IM<V=S
M='(@(DIO:2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M-S`*;7-G:60@(E1H92!%9&ET($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@;&]N
M9V5R('!R97-E;G0N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R
M<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB
M)7-<(B!C86YN;W0@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD
M87)S+G!H<#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@
M7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE
M;F1A<G,N<&AP.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A
M<B!<(B5S7"(@:&%S(&)E96X@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C
M86QE;F1A<B!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@(E1H
M92!E;F0@9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N
M(@IM<V=S='(@(D1A=&$@9&4@<V9A<G-I="!T<F5B=6EE('-A(&9I92!M86D@
M;F]U82!D96-A="!D871A(&1E(&EN8V5P=70N(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E
M<UPB(&AA<R!B965N(&%D9&5D+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960L
M('=H:6-H('=A<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E
M;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"P@=VAI8V@@:7,@;VX@)7,@870@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E
M<R!W87,@<W5C8V5S<V9U;&QY('-E;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P,C0*;7-G:60@(E1H92!F;VQL;W=I;F<@:7,@82!M
M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#HB"FUS9W-T
M<B`B(@H*(SH@871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E<W0@
M=V%S(&EN8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N96-E
M<W-A<GD@=&\@86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E(&UI
M<W-I;F<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O96UP='DN
M:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!E=F5N=',@;6%T8VAI;F<@=&AE
M(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(B(*"B,Z(&%D9&5V96YT86-T
M:6]N+G!H<#HQ."!E9&ET979E;G1A8W1I;VXN<&AP.C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A
M;&5N9&%R.B`E<R(*;7-G<W1R("(B"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z
M,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%D
M9&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:71E=F5N=&%C
M=&EO;BYP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&5D:71I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HS,S@@;&EB+V%P:2YP:'`Z-3DV"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HV,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N
M=#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V5N9&EN
M9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S(@IM<V=S='(@(B(*
M"B,Z(&1A=&$N<&AP.C$P-0IM<V=I9"`B5&AE<F4@=V5R92!N;R!E=F5N=',@
M=&\@97AP;W)T+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.#0*;7-G:60@
M(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ.2!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,3@*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S$*
M;7-G:60@(E1H=7)S9&%Y(@IM<V=S='(@(DIO:2(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHS-PIM<V=I9"`B5&EM92!3<%]A;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHT"FUS
M9VED(")4:6UE('-P86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8VA?861V86YC960N:6YC.C,V('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C0P"B,L(&9U>GIY"FUS9VED(")4:71?;&4B"FUS9W-T<B`B5&ET;'4B
M"@HC.B!D871A+G!H<#HU-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M,C`*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHS"FUS
M9VED(")4:71L92(*;7-G<W1R(")4:71L=2(*"B,Z(&QI8B]";&]C:R]P<F5V
M;6]N=&AL:7-T+G!H<#HQ,C(@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(Q
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,C<*;7-G:60@(E1O9&%Y(@IM
M<V=S='(@(D%Z:2(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ
M,C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(S"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HQ,CD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z
M('EE87(N<&AP.C@T('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8P
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO;6]N
M=&@N<&AP.C$P-0IM<V=I9"`B5'4B"FUS9W-T<B`B36%R(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C$W('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q-@HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV.0IM<V=I
M9"`B5'5E<V1A>2(*;7-G<W1R(")-87)T:2(*"B,Z(&-O;F9I9R]K97EW;W)D
M<RYP:'`N9&ES=#HQ-PIM<V=I9"`B5'EP92(*;7-G<W1R(")4:7`B"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3@S"FUS9VED(")5
M4DPB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HV-`IM<V=I
M9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@8V%L96YD87)S+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<B]M8V%L+G!H<#HQ,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3@U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N
M<&AP.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP
M:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E=')I979E
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,34*(SH@<V-R:7!T<R]U<&=R861E
M<R\R,#`T+3`U+3$Y7V-O;G9E<G1?8V%T96=O<FEE<U]T;U]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HS-S8@;&EB+V%P:2YP:'`Z-#4P(&QI8B]A<&DN<&AP.C4Q-B!L:6(O87!I
M+G!H<#HV,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N
M=&5N="U4>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#$T"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960Z("5S+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*;7-G:60@(E5S
M97(@26YT97)F86-E(@IM<V=S='(@(DEN=&5R9F%T82!U=&EL:7IA=&]R(@H*
M(SH@>65A<BYP:'`Z,38S('EE87(N<&AP.C$V.2!L:6(O0FQO8VLO;6]N=&@N
M<&AP.C$U.2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$V,@IM<V=I9"`B5FEE=R!$
M87DB"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#4@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-C$@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(P
M"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")792(*;7-G<W1R
M(")-:64B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3@@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3$W"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S
M8W)I<'0N:6YC.C<P"FUS9VED(")7961N97-D87DB"FUS9W-T<B`B36EE<F-U
M<FDB"@HC.B!A='1E;F1E97,N<&AP.C$Q,B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,CDP(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(S"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*;7-G<W1R(")387!T86UA;F$B
M"@HC.B!M;VYT:"YP:'`Z,3<Y('=O<FMW965K+G!H<#HS,"!W965K+G!H<#HS
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7965K("5D(@IM<V=S='(@(E-A<'1A
M;6%N82`E9"(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C4Y('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C$T,`HC+"!F=7IZ>0IM<V=I9"`B5V5E:RAS
M*2(*;7-G<W1R(")387!T86UA;F$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"FUS9VED(")7
M965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")387!T86UA;F%L.B!392!R
M97!E=&$@;&$@9FEE8V%R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C0*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I
M97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED("(B
M"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@
M=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_(@IM<V=S='(@(B(*
M"B,Z(&%T=&5N9&5E<RYP:'`Z,3$Q(&QI8B]+<F]N;VQI=&@N<&AP.C$R.#D@
M;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@T"FUS9VED(")7;W)K(%=E96LB"FUS9W-T<B`B4V%P=&%M86YA
M(&QU8W)A=&]A<F4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,CDR(&QI8B]"
M;&]C:R]T<F5E7VUE;G4N<&AP.C(U"FUS9VED(")996%R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR-#$*;7-G:60@(EEE87)L>3H@4F5C=7)S(&5V97)Y(@IM
M<V=S='(@(D%N=6%L.B!392!R97!E=&$@;&$@9FEE8V%R92(*"B,Z(&1A=&$N
M<&AP.C0P(&1A=&$N<&AP.C(S-"!E9&ET979E;G1A8W1I;VXN<&AP.C0V(&%D
M9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@979E;G1S+B(*;7-G
M<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Y"FUS9VED(")9;W4@87)E(&YO="!A
M;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF:65D(&5V96YT+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C<V"FUS9VED
M(")9;W4@8V%N(&]N;'D@=7-E('1H:7,@9F]R;2!F<F]M('1H92!%9&ET($%T
M=&5N9&5E<R!S8W)E96XN(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.CDW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&\@;F]T(&AA
M=F4@86X@96UA:6P@861D<F5S<R!C;VYF:6=U<F5D(&EN('EO=7(@4&5R<V]N
M86P@26YF;W)M871I;VX@(@HB3W!T:6]N<RX@66]U(&UU<W0@<V5T(&]N92`E
M<VAE<F4E<R!B969O<F4@979E;G0@;F]T:69I8V%T:6]N<R!C86X@8F4@<V5N
M="XB"FUS9W-T<B`B(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C(P"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$Y
M-`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V
M96YT<R!T;R!T:&4@<V5L96-T960@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z
M(&1E;&5V96YT86-T:6]N+G!H<#HR-@IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N(@IM<V=S='(@(B(*
M"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z-S@*;7-G:60@(EEO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="XB"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z,3@Y"FUS9VED(")9;W4@:&%V92!S<&5C:69I960@
M86X@:6YV86QI9"!C86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H
M<#HR,0IM<V=I9"`B66]U(&AA=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D(&%T
M=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@871T96YD
M+G!H<#HR-@IM<V=I9"`B66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E8VQI;F5D
M(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@871T
M96YD+G!H<#HS,0IM<V=I9"`B66]U(&AA=F4@=&5N=&%T:79E;'D@86-C97!T
M960@871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R("(B"@HC.B!C
M86QE;F1A<G,N<&AP.CDQ"FUS9VED(")9;W4@;75S="!S96QE8W0@82!C86QE
M;F1A<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C4T"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`Y-`IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!N;W1I
M9FEE9"!W:&5N(&5V96YT<R!A<F4@861D960@=&\@>6]U<B!C86QE;F1A<G,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,#0*;7-G:60@
M(B(*(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@
M87)E(&1E;&5T960@9G)O;2!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y.0IM<V=I9"`B66]U(')E<75E<W1E
M9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@961I=&5D(&EN('EO
M=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-H961U;&5R+VMR
M;VYO;&ET:"YP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R97%U
M97-T960@=&\@8F4@<F5M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S
M(&%T("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<VAA<F5S
M96QE8W0N:6YC.C$P"FUS9VED(")9;W5R(&1E9F%U;'0@8V%L96YD87(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`U,R!L:6(O1')I=F5R+G!H
M<#HQ,#8S"FUS9VED(");56YN86UE9"!E=F5N=%TB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z.3<*(RP@9G5Z>GD*;7-G:60@(E]!
M;&%R;2(*;7-G<W1R(")!;&%R;6$B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:%]A9'9A;F-E9"YI;F,Z,3$*;7-G:60@(E]"87-I8R!396%R8V@B"FUS
M9W-T<B`B(@H*(SH@=FEE=V5V96YT+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@
M(E]%9&ET(@IM<V=S='(@(D5D:71E87IA("(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$S,S`*;7-G:60@(E]';W1O(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S,S8*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,3@*(RP@9G5Z>GD*;7-G:60@
M(E]->2!#86QE;F1A<G,B"FUS9W-T<B`B0V%L96YD87(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,S(U"B,L(&9U>GIY"FUS9VED(")?3F5W($5V96YT(@IM
M<V=S='(@(D5V96YI;65N="!N;W4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,S0Q"FUS9VED(")?4')I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,S,@IM<V=I9"`B7U-E87)C:"(*;7-G<W1R("(B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,S(X"B,L(&9U>GIY"FUS9VED(")?5&]D87DB"FUS
M9W-T<B`B07II(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30R"FUS
M9VED(")B969O<F4@=&AE(&5V96YT('-T87)T<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@U"FUS9VED(")D87DB"FUS9W-T<B`B
M>FDB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C$P"FUS9VED(")D87DH<RDB"FUS9W-T<B`B>FDH
M;&4I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(GII;&4B"@HC.B!D871A
M+G!H<#HQ-#<@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ"FUS9VED(")E
M=F5N=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$V.`IM<V=I9"`B
M979E;G1S+FEC<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$S,0IM<V=I9"`B9G)O;2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,"!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,S8*;7-G:60@(FUO;G1H*',I(@IM<V=S
M='(@(FQU;F$H:2DB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")O;B`E<R!A="`E<R(*;7-G<W1R("(E
M<R!I;F-E<&4@:6X@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,P"FUS9VED(")O;B!T:&4@
M<V%M92!D871E(@IM<V=S='(@(FEN(&%C965A<VD@9&%T82(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$R-B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR,S8*;7-G:60@(F]N('1H92!S86UE('=E96MD87DB"FUS9W-T<B`B:6X@
M86-E96%S:2!Z:2!A('-A<'1A;6%N:6DB"@HC.B!D871A+G!H<#HS,"!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U"FUS9VED(")V0V%L96YD87(O:4-A
M;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,T.2!L:6(O87!I
M+G!H<#HV,#<*;7-G:60@(G9%=F5N="!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3$*;7-G:60@(G=E96LB"FUS
M9W-T<B`B<V%P=&%M86YA(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3(R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q-PIM<V=I9"`B=V5E:RAS
M*2!O;CHB"FUS9W-T<B`B<V%P=&%M86YA*&DI(&QA.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.3(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PHC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DT"FUS9VED(")W965K<R(*;7-G
M<W1R(")S87!T86UA;FDB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C0R"FUS9VED(")Y96%R*',I
M(@IM<V=S='(@(F%N*&DI(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR
M;VYO;&ET:"]P;R]S:U]32RYP;P``````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`Q,S0P,C8`,3`T,3<S-C(W-3(`,#(P-#(W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@2W)O;F]L:71H
M(%-L;W9A:R!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@3&5O
M($UR869K;RP@/&QE;T!O96PN<VL^+"`R,#`R("AO<FEG:6YA;"!T<F%N<VQA
M=&]R*0HC("AC*2`R,#`T($EV86X@3F]R:7,@/'9I>$!V87IK82YS:SX*(PIM
M<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2W)O;F]L
M:71H(#(N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`Q+3,Q(#(S
M.C0Q*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,#(@,C,Z
M-3DK,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!)=F%N($YO<FES(#QV:7A`
M=F%Z:V$N<VL^7&XB"B),86YG=6%G92U496%M.B!3;&]V86L@/'9I>$!V87IK
M82YS:SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!C
M86QE;F1A<G,@9F]U;F0B"FUS9W-T<B`B)60@;N%J9&5N_6-H(&MA;&5N9.%R
M;W8B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!E=F5N=',B"FUS9W-T<B`B)60@=61A;&]S=.TB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@1&%Y*',I("5S($AO=7(H<RD@)7,@36EN
M=71E<R(*;7-G<W1R("(E<R!D+B`E<R!H;V0N("5S(&UI;BXB"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ.#`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T=&5N
M9&5E<R(*;7-G<W1R("(E<R#ZZ&%S=&[M:V]V(@H*(SH@9&%T82YP:'`Z,C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM
M<&]R=&5D(@IM<V=S='(@(G/Z8F]R("5S(/IS<&6Y;F4@:6UP;W)T;W9A;OTB
M"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O8F%S92YP:'`Z,3(X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD
MX7(@)7,B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,3<*
M;7-G:60@(B(*(BA#;&EC:R!O;B!C86QE;F1A<B!N86UE('1O('-W:71C:"!T
M:&4@8V%L96YD87(G<R!V:7-I8FEL:71Y(&EN('1H92!M86EN("(*(G=I;F1O
M=RDB"FUS9W-T<B`B(@HB*$ML:6MN:71E(&YA(&UE;F\@:V%L96YDX7)A+"!A
M8GD@<W1E('!R97!L:2!J96AO('9I9&ET9;5N;W.[('8@:&QA=FYO;2!O:VYE
M*2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38T"FUS
M9VED("(J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!!9&0@*B(*;7-G<W1R("(J
M(%!R:61A:G1E(&ML:6MN=73M;2!N82!0<FED8;L@*B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,34P"FUS9VED("(J(%!L96%S92!S
M96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(%!R;W/M;2!V>6)E<G1E
M(&%D<F5S=2AY*2`J(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@P.`IM<V=I9"`B
M,2!A='1E;F1E92(*;7-G<W1R("(Q(/KH87-T;NUK(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]H96%D97(N:6YC.C0*;7-G:60@(C$@979E;G0B"FUS9W-T<B`B
M,2!U9&%L;W.[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I
M9"`B,2!H;W5R(@IM<V=S='(@(C$@:&]D:6YA(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-`IM<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R("(Q-2!M
M:6[Z="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(C(P
M(&UI;G5T97,B"FUS9W-T<B`B,C`@;6EN^G1A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-@IM<V=I9"`B,S`@;6EN=71E<R(*;7-G<W1R("(S,"!M
M:6[Z=&$B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-CD*;7-G:60@
M(CQS=')O;F<^071T96YD965S/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T
M<B`B/'-T<F]N9S[:Z&%S=&[M8VD\+W-T<F]N9SX@*&YE<&]V:6YN[2DB"@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#<*;7-G:60@(CQS=')O;F<^
M1&5S8W)I7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T
M<F]N9SY0;U]P:7,\+W-T<F]N9SX@*&YE<&]V:6YN_2DB"@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR-S0*;7-G:60@(CQS=')O;F<^2V5Y=V]R9',\
M+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\<W1R;VYG/DNU^NAO=ND@
M<VQO=N$\+W-L;W;A/B`H;F5P;W9I;F[I*2(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C$Y,@IM<V=I9"`B/'-T<F]N9SY296-U<G)E;F-E/"]S=')O
M;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9SY/<&%K;W9A;FEE/"]S
M=')O;F<^("AN97!O=FEN;NDI(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.3,*;7-G:60@
M(D%-(@IM<V=S='(@(E!R961P;VQU9&[M;2(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C8P,@IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B06MC97!T;W9A;N$B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3$*;7-G:60@(D%D
M7W9A;F-E9"!396%R8V@B"FUS9W-T<B`B7U)O>KGM<F5NZ2!V>6BU863A=F%N
M:64B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V,2!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B061D
M(@IM<V=S='(@(E!R:61ANR(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(R"FUS9VED(")!9&0@179E;G0B"FUS9W-T<B`B4')I9&&[('5D86QO<[LB
M"@HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN
M8SHS-0IM<V=I9"`B061D(&$@;F5W(%)E;6]T92!#86QE;F1A<B(*;7-G<W1R
M(")0<FED8;L@;F]V_2!V>F1I86QE;OT@:V%L96YDX7(B"@HC.B!A9&1E=F5N
M="YP:'`Z-C0*;7-G:60@(D%D9"!A(&YE=R!E=F5N="(*;7-G<W1R(")0<FED
M8;L@;F]V^B!U9&%L;W.[(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E
M;F1E97,N:6YC.C<Q"FUS9VED(")!9&0@871T96YD965S(@IM<V=S='(@(E!R
M:61ANR#ZZ&%S=&[M:V]V(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(P"B,Z('1E;7!L871E<R]A='1E
M;F1E97,O871T96YD965S+FEN8SHW-0IM<V=I9"`B061D<F5S<R!";V]K(@IM
M<V=S='(@(D%D<F5SX7(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A
M9'9A;F-E9"YI;F,Z."!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3$*
M;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R(")2;WJY[7)E;ND@=GEH
MM6%DX79A;FEE(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3,*;7-G
M:60@(D%L87)M(@IM<V=S='(@(D%L87)M(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!D87ES(&)E9F]R
M92(*;7-G<W1R(")!;&%R;2`E9"!D;NT@<')E9"(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$W.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@:&]U<G,@
M8F5F;W)E(@IM<V=S='(@(D%L87)M("5D(&AO9.UN('!R960B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ-SDT"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D
M(&UI;G5T97,@8F5F;W)E(@IM<V=S='(@(D%L87)M("5D(&UI;BX@<')E9"(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$W-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M06QA<FT@)60@=V5E:W,@8F5F;W)E(@IM<V=S='(@(D%L87)M("5D('3]OF3R
M;W8@<')E9"(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.#,*;7-G:60@(D%L87)M
M(#$@9&%Y(&)E9F]R92(*;7-G<W1R(")!;&%R;2`Q(&1E\B!P<F5D(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z,3<X.`IM<V=I9"`B06QA<FT@,2!H;W5R(&)E9F]R
M92(*;7-G<W1R(")!;&%R;2`Q(&AO9&EN=2!P<F5D(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z,3<Y,PIM<V=I9"`B06QA<FT@,2!M:6YU=&4@8F5F;W)E(@IM<V=S
M='(@(D%L87)M(#$@;6EN^G1U('!R960B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M-S<X"FUS9VED(")!;&%R;2`Q('=E96L@8F5F;W)E(@IM<V=S='(@(D%L87)M
M(#$@=/V^9&7R('!R960B"@HC.B!D871A+G!H<#HU.0IM<V=I9"`B06QA<FT@
M1&%T92(*;7-G<W1R(")$X71U;2!A;&%R;74B"@HC.B!D871A+G!H<#HU.`IM
M<V=I9"`B06QA<FT@4W!A;B`H;6EN=71E<RDB"FUS9W-T<B`B4F]Z<.1T:64@
M86QA<FUU("AV(&UI;OIT86-H*2(*"B,Z(&1A=&$N<&AP.C8P"FUS9VED(")!
M;&%R;2!4:6UE(@IM<V=S='(@(LAA<R!A;&%R;74B"@HC.B!T96UP;&%T97,O
M9&5L971E+V1E;&5T92YI;F,Z,S0*;7-G:60@(D%L;"(*;7-G<W1R(")6N65T
M:WDB"@HC.B!L:6(O1D)6:65W+G!H<#HQ,C@@;&EB+T9"5FEE=RYP:'`Z,3,Q
M(&QI8B]&0E9I97<N<&AP.C$S-`IM<V=I9"`B06QL($%T=&5N9&5E<R(*;7-G
M<W1R(")6N65T8VD@^NAA<W1N[6-I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:6YC.C4Y"FUS9VED(")!;&P@1G5T=7)E(@IM<V=S='(@(E:Y971K
M>2!B=63Z8V4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*
M;7-G:60@(D%L;"!087-T(@IM<V=S='(@(E:Y971K>2!M:6YU;.DB"@HC.B!L
M:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HR-`HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D%L;"!6:7-I8FQE(@IM<V=S='(@
M(E:Y971K>2!V:61I=&6U;NDB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHQ,C(@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W
M+G!H<#HY,PHC.B!L:6(O5V5E:U9I97<N<&AP.C$R-R!L:6(O5V5E:U9I97<N
M<&AP.C$S-"!L:6(O1')I=F5R+G!H<#HQ.#<Q"FUS9VED(")!;&P@9&%Y(@IM
M<V=S='(@(DMAOF3](&1E\B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M-C0*;7-G:60@(D%L;"!D87D@979E;G0B"FUS9W-T<B`B2V&^9&]D96YNX2!U
M9&%L;W.[(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS,PIM<V=I
M9"`B06QL(&5V96YT<R(*;7-G<W1R(")6N65T:WD@=61A;&]S=&DB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#@*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C<P(&QI8B]+<F]N
M;VQI=&@N<&AP.C8Y-0IM<V=I9"`B06YY(@IM<V=S='(@(J5U8F]V;[5NX2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!
M<')I;"(*;7-G<W1R(")!<'+M;"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C,Y('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.CDS"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z.#(@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ-C@*;7-G:60@(D%T(@IM<V=S='(@(D\B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#0V"FUS9VED("(B"B)!='1A8VAE
M9"!I<R!A;B!I0V%L96YD87(@9FEL92!W:71H(&UO<F4@:6YF;W)M871I;VX@
M86)O=70@=&AE(&5V96YT+B!)9B!Y;W5R("(*(FUA:6P@8VQI96YT('-U<'!O
M<G1S(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@=&AI<R!F:6QE('1O(&5A
M<VEL>2!U<&1A=&4@(@HB>6]U<B!L;V-A;"!C;W!Y(&]F('1H92!E=F5N="XB
M"FUS9W-T<B`B(@HB5B!P<NUL;VAE(&IE('/Z8F]R(&E#86QE;F1A<B!S(&1E
M=&%I;&[];6D@:6YF;W)MX6-I86UI(&\@=61A;&]S=&DN($%K(%;AN2!E+2(*
M(FUA:6QO=OT@:VQI96YT('!O9'!O<G5J92!P;[YI861A=FMY(&E4:7`L(&WT
MOF5T92!T96YT;R!S^F)O<B!P;W6^:;L@;F$@(@HB:F5D;F]D=6-H^B!A:W1U
M86QI>N%C:74@5F&Y96H@;&]KX6QN96H@:_-P:64@=61A;&]S=&DN(@H*(SH@
M=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0R('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$V-0IM<V=I9"`B071T96YD86YC92(*;7-G<W1R
M("+:Z&%SNR(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V,0IM<V=I
M9"`B071T96YD965S(@IM<V=S='(@(MKH87-T;NUC:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T
M<B`B075G=7-T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC
M960N:6YC.C$Q('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHX"FUS9VED
M(")"87-I8R!396%R8V@B"FUS9W-T<B`B6N%K;&%D;ND@:+5A9&%N:64B"@HC
M.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D)I<G1H9&%Y
M(@IM<V=S='(@(DYA<F]D96YI;GDB"@HC.B!L:6(O1D)6:65W+G!H<#HY,"!L
M:6(O1D)6:65W+G!H<#HQ,3$*;7-G:60@(D)U<WDB"FUS9W-T<B`B6F%N97!R
MX7ID;F5N_2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D
M+FEN8SHT,@IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S='(@(DM?86QE;F3A<B(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0W"FUS9VED(")#86Q?96YD
M87(B"FUS9W-T<B`B2V%L7V5N9.%R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C$T.2!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP
M:'`Z,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HR,2!L:6(O0FQO8VLO;6]N
M=&AL:7-T+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9.%R(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C,*;7-G:60@(D-A;&5N9&%R(%-U;6UA<GDB"FUS9W-T<B`B
M2V%L96YDX7)O=OT@<_IH<FXB"@HC.B!D871A+G!H<#HR,S,*;7-G:60@(D-A
M;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(DMA;&5N9.%R
M(/IS<&6Y;F4@=GEM87IA;OTN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W"FUS9VED(")#
M86QE;F1A<G,B"FUS9W-T<B`B2V%L96YDX7)E(@H*(SH@8V%L96YD87)S+G!H
M<#HR-PIM<V=I9"`B0V%L96YD87)S(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S
M='(@(DMA;&5N9.%R92!M=7-I82!M8;L@;65NX2XB"@HC.B!D871A+G!H<#HR
M-#@*;7-G:60@(D-A;B=T(&-R96%T92!A(&YE=R!E=F5N="XB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!V>71V;W)INR!N;W;Z('5D86QO<[LN(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3$@=&5M<&QA=&5S+V1E
M;&5T92]O;F4N:6YC.C,S"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN
M8SHS-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,0HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHS,#<*;7-G:60@(D-A;F-E;"(*;7-G<W1R("):<G6Y
M:;LB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S@*;7-G:60@(D-A;F-E;&QE
M9"(*;7-G<W1R("):<G6Y96[I(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YC96QL960Z("5S(@IM<V=S='(@
M(EIR=;EE;NDZ("5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C8W"FUS9VED
M(")#871E9V]R7WDB"FUS9W-T<B`B2V%T96?S<E]I82(*"B,Z(&1A=&$N<&AP
M.C8R('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-"!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,PIM<V=I9"`B0V%T96=O<GDB"FUS9W-T
M<B`B2V%T96?S<FEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.0IM
M<V=I9"`B(@HB0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO=&EF:65D(&]F
M(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',@8GD@(@HB96UA:6PZ
M(@IM<V=S='(@(B(*(E9Y8F5R=&4@<VDL(.AI(&-H8V5T92!B>;L@=7!O>F]R
M;F5N_2!N82!N;W;I+"!U<')A=F5NZ2!A;&5B;R!V>6UA>F%NZ2`B"B)U9&%L
M;W-T:2!E;6%I;&]M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,@IM
M<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO=&EF:65D(&]F(&YE
M=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',N(@IM<V=S='(@(B(*(E9Y
M8F5R=&4@<VDL(.AI(&-H8V5T92!B>;L@=7!O>F]R;F5N_2!N82!N;W;I+"!U
M<')A=F5NZ2!A;&5B;R!V>6UA>F%NZ2`B"B)U9&%L;W-T:2XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,CDR"FUS9VED(")#:&]O<V4@:68@>6]U('=A
M;G0@=&\@<F5C96EV92!E;6%I;"!R96UI;F1E<G,@9F]R(&5V96YT<R!W:71H
M(&%L87)M<SHB"FUS9W-T<B`B(@HB5GEB97)T92!S:2P@Z&D@8VAC971E(&1O
M<W3A=F&[(&5M86EL;VT@<')I<&]M:65N:WD@<')E('5D86QO<W1I(',@86QA
M<FUO;3HB"@HC.B!T96UP;&%T97,O<')E9G,O<V5A<F-H7V%B;V]K7W-E;&5C
M="YI;F,Z,3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,@IM<V=I9"`B0VAO
M;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y
M(%523',Z(@IM<V=S='(@(B(*(E9Y8F5R=&4@861R97/A<BP@:W1O<OT@<V$@
M<&]UOFEJ92!N82!HM6%D86YI92!54DP@<R!I;F9O<FWA8VEA;6D@;R`B"B)Z
M86YE<'+A>F1N96YO<W1I.B(*"B,Z('1E;7!L871E<R]P<F5F<R]F8E]C86QS
M7W-E;&5C="YI;F,Z,38*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O
M(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXZ(@IM<V=S
M='(@(B(*(E9Y8F5R=&4@:V%L96YDX7)E+"!K=&]RZ2!S82!Z86AR;OH@9&\@
M:6YF;W)MX6-I86UI[2!O(%9AN65J('IA;F5P<N%Z9&YE;F]S=&DZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-`IM<V=I9"`B0VAO;W-E('1H92!C
M86QE;F1A<G,@=&\@:6YC;'5D92!W:&5N(&=E;F5R871I;F<@9G)E92]B=7-Y
M(%523',Z(@IM<V=S='(@(B(*(E9Y8F5R=&4@:V%L96YDX7)E+"!K=&]RZ2!S
M82!Z86AR;OH@<')I(&=E;F5R;W9A;NT@55),(',@:6YF;W)MX6-I86UI(&\@
M5F&Y96H@(@HB>F%N97!RX7ID;F5N;W-T:3HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@*;7-G:60@(D-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD
M87(N(@IM<V=S='(@(E9Y8F5R=&4@<VD@5N&Y('!R961N87-T879E;OT@:V%L
M96YDX7(N(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC
M.C@U"FUS9VED(")#;&5A<B!A;&P@871T96YD965S(@IM<V=S='(@(D]D<W1R
MX6YINR!VN65T:_UC:"#ZZ&%S=&[M:V]V(@H*(SH@9&%T82YP:'`Z,C@@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A
M=&5D('9A;'5E<R(*;7-G<W1R(")(;V1N;W1Y(&]D9&5L96[I(.AI87)K;W4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,*;7-G:60@(D-O;F9I<FT@
M9&5L971I;VX@;V8@979E;G1S/R(*;7-G<W1R(")0;W1V<F1Z;W9ANR!V>6UA
M>N%V86YI92!U9&%L;W-T[3\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S4*
M;7-G:60@(D-O;F9I<FUE9"(*;7-G<W1R(")0;W1V<F1E;NDB"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C$W"FUS9VED(")#;W!Y
M('1H92!54DP@8F5L;W<@9F]R('5S92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R
M($9R964O0G5S>2!54DPZ(@IM<V=S='(@(B(*(E-K;W#M<G5J=&4@55),('5V
M961E;OH@;FF^N6EE(&$@<&]UOFET92!J=2!A:V\@55),(',@:6YF;W)MX6-I
M86UI(&\@5F&Y96H@(@HB>F%N97!RX7ID;F5N;W-T:2XB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V;W)INR`E<RXB
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3(Y"FUS
M9VED(")#<F5A=&4B"FUS9W-T<B`B5GET=F]R:;LB"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3$U"FUS9VED(")#<F5A=&4@0V%L
M96YD87(B"FUS9W-T<B`B5GET=F]R:;L@:V%L96YDX7(B"@HC.B!M;VYT:"YP
M:'`Z,38S('1E;7!L871E<R]W965K+VAE860N:6YC.C(U('1E;7!L871E<R]D
M87DO<F]W+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE
M=RYP:'`Z,3DU"FUS9VED(")#<F5A=&4@82!.97<@179E;G0B"FUS9W-T<B`B
M5GET=F]R:;L@;F]V^B!U9&%L;W.[(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z.#`*;7-G:60@(D-R96%T960B"FUS9W-T<B`B5GET=F]R96[I(@H*
M(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,R"FUS9VED(")#=7)R
M96YT(@IM<V=S='(@(D%K='7A;&YE(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(P-@IM<V=I9"`B
M1&%I;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")$96YN93H@;W!A:V]V86YI
M92!K8;YD_6-H(@H*(SH@871T96YD965S+G!H<#HQ,3`@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,Q,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#(*;7-G:60@(D1A>2(*;7-G<W1R(")$9?(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV,B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ,S<*;7-G:60@(D1A>2AS*2(*;7-G<W1R(")$9?(H9&YI
M*2(*"B,Z('9I97=E=F5N="YP:'`Z,3$Q"FUS9VED(")$95]L971E(@IM<V=S
M='(@(E9Y7VUA>F&[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-SD*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E8V5M8F5R(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-C`U"FUS9VED(")$96-L:6YE9"(*;7-G<W1R
M(")/9&UI971N=73I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W"FUS
M9VED(")$969A=6QT($-A;&5N9&%R(@IM<V=S='(@(E;AN2!P<F5D;F%S=&%V
M96[](&MA;&5N9.%R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C(P-"!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X
M,0HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S(@=&5M<&QA=&5S+W!R
M969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,C,*(SH@;&EB+T1R:79E
M<BYP:'`Z,3@U,@IM<V=I9"`B1&5L971E(@IM<V=S='(@(E9Y;6%Z8;LB"@HC
M.B!D96QE=F5N="YP:'`Z-#`@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(Q
M('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR,0HC.B!L:6(O1')I=F5R
M+G!H<#HQ.#4Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R(*;7-G
M<W1R("):;6%Z8;L@)7,B"@HC.B!E9&ET979E;G0N<&AP.C<R"FUS9VED(")$
M96QE=&4@179E;G0B"FUS9W-T<B`B6FUA>F&[('5D86QO<[LB"@HC.B!T96UP
M;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S`*;7-G:60@(B(*(D1E;&5T92!T
M:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L
M;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@(@HB86QL(&]C8W5R96YC97,_(@IM
M<V=S='(@(B(*(E9Y;6%Z8;L@:6)A(&%K='7A;&YU('5D86QO<[LL('1E;G1O
M(';]<VMY="!A(':Y971K>2!B=63Z8V4@=OUS:WET>2!A;&5B;R`B"B)VN65T
M:WD@=OUS:WET>3\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z,3`S('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR.`IM
M<V=I9"`B1&5S8W)I7W!T:6]N(@IM<V=S='(@(E!O7W!I<R(*"B,Z(&1A=&$N
M<&AP.C8Q('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S@*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.38*;7-G:60@(D1E<V-R:7!T
M:6]N(@IM<V=S='(@(E!O<&ES(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ-S,*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B3F%S=&%V
M96YI92!Z;V)R87IE;FEA(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C8S"FUS9VED(")$:7-P;&%Y($-A;&5N9&%R<R(*;7-G<W1R
M("):;V)R87IINR!K86QE;F3A<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(X"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3F%S
M=&%V96YI92!Z;V)R87IE;FEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P"FUS9VED(")$;R!Y;W4@=V%N="!T;R!S:&]W('1A<VMS('=H:6-H(&%R
M92!D=64@;VX@>6]U<B!C86QE;F1A<C\B"FUS9W-T<B`B0VAC971E('IO8G)A
M>FF[(/IL;VAY('!O('1E<FWM;F4@=F\@5F&Y:6-H(&MA;&5N9.%R;V-H/R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T-0IM<V=I9"`B1&]E<R!N;W0@<F5C
M=7(B"FUS9W-T<B`B3F5O<&%K=6IE('-A(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G:60@(D1U93H@)7,B"FUS9W-T<B`B
M5&5R;>UN.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B5')V86YI92(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S,@;&EB+T1R
M:79E<BYP:'`Z,3@S.`IM<V=I9"`B161I="(*;7-G<W1R(")5<')A=FF[(@H*
M(SH@961I=&5V96YT+G!H<#HS,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,B!L:6(O1')I=F5R+G!H<#HQ.#,W"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@)7,B"FUS9W-T<B`B57!R879INR`E<R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C$X-0IM<V=I9"`B161I="!!='1E;F1E97,B"FUS9W-T<B`B
M57!R879INR#ZZ&%S=&[M:V]V(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C$T,PIM<V=I9"`B161I="!#86QE;F1A<G,B"FUS9W-T
M<B`B57!R879INR!K86QE;F3A<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4P"FUS9VED(")%9&ET(%)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B
M57!R879INR!V>F1I86QE;ND@:V%L96YDX7)E(@H*(SH@871T96YD965S+G!H
M<#HQ-3`*;7-G:60@(D5D:70@871T96YD965S(@IM<V=S='(@(E5P<F%V:;L@
M^NAA<W1N[6MO=B(*"B,Z('1E;7!L871E<R]C871E9V]R>5]L96=E;F0N:6YC
M.C(P"FUS9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<R(*;7-G<W1R
M(")5<')A=FF[(&MA=&5G\W)I92!A(&9A<F)Y(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S8@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C0Q"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V
M-`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%+6UA:6QO=N$@861R
M97-A(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-C`*
M;7-G:60@(D5N7V0B"FUS9W-T<B`B7TMO;FEE8R(*"B,Z(&1A=&$N<&AP.C4V
M"FUS9VED(")%;F0@1&%T92(*;7-G<W1R(")$X71U;2!U:V]NZ&5N:6$B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C@@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ,C`*;7-G:60@(D5N9"!/;B(*;7-G<W1R(")+;V[H[2(*"B,Z(&1A
M=&$N<&AP.C4W"FUS9VED(")%;F0@5&EM92(*;7-G<W1R("+(87,@=6MO;NAE
M;FEA(@H*(SH@871T96YD965S+G!H<#HQ,C0@871T96YD965S+G!H<#HQ,S4@
M871T96YD965S+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M<F5T<FEE=FEN9R!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<R(*
M;7-G<W1R("(B"B).87-T86QA(&-H>6)A('!R:2!I;7!O<G1E(&EN9F]R;>%C
M:>T@;R!Z86YE<'+A>F1N96YO<W1I('!O=;[M=F%T9;5A.B`E<SH@)7,N(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q,PIM<V=I9"`B179E;G0@861D960Z
M(@IM<V=S='(@(E!R:61A;N$@=61A;&]SNSHB"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,3(S"FUS9VED(")%=F5N="!D96QE=&5D.B(*;7-G<W1R(")6>6UA
M>F%NX2!U9&%L;W.[.B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,3@*;7-G
M:60@(D5V96YT(&5D:71E9#HB"FUS9W-T<B`B57!R879E;N$@=61A;&]SNSHB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#<T"B,L('!H<"UF;W)M870*;7-G:60@
M(D5V96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B561A;&]SNR!O9"`E<R!D
M;R`E<R(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H<#HS-S,*;7-G:60@(D5V96YT
M(&YO="!F;W5N9"(*;7-G<W1R(")59&%L;W.[(&YE8F]L82!NX6ID96[A(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z-S<P"FUS9VED(")%=F5N=',@;75S="!H879E
M(&$@<W1A<G0@9&%T92XB"FUS9W-T<B`B561A;&]S=&D@;75S:6$@;6&[(&3A
M='5M('IAZ&EA=&MU+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<S-@IM<V=I9"`B
M179E;G1S(&UU<W0@:&%V92!A('1I=&QE+B(*;7-G<W1R(")59&%L;W-T:2!M
M=7-I82!M8;L@=&ET=6PN(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E
M;F1E97,N:6YC.C<V"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T<B`B1&]P
M;&YINR!M96[A(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.3D*
M;7-G:60@(D5X<&]R="(*;7-G<W1R(")%>'!O<G0B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R="!#86QE;F1A<B(*;7-G
M<W1R(")%>'!O<G1O=F&[(&MA;&5N9.%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-CD*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E
M8G)UX7(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$R
M.`IM<V=I9"`B1FEN9"(*;7-G<W1R(").X6ISNR(*"B,Z('EE87(N<&AP.C@T
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8S('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM
M<V=I9"`B1G(B"FUS9W-T<B`B4&EA(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-3@Q"FUS9VED(")&<F5E(@IM<V=S='(@(E9OM6[](@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4X"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB
M"FUS9W-T<B`B26YF;W)MX6-I82!O('IA;F5P<N%Z9&YE;F]S=&DB"@HC.B!T
M96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C`@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3$Y"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<R
M"FUS9VED(")&<FED87DB"FUS9W-T<B`B4&EA=&]K(@H*(SH@=&5M<&QA=&5S
M+V1E;&5T92]D96QE=&4N:6YC.C,S"FUS9VED(")&=71U<F4B"FUS9W-T<B`B
M0G5D^F-N;W.[(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS
M9VED(")'86UE(@IM<V=S='(@(DAR82(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H7V%D=F%N8V5D+FEN8SHR,PIM<V=I9"`B1V5N97)A;"(*;7-G<W1R
M(")6N65O8F5C;NDB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30P"B,L
M('!H<"UF;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`B4')E:G.[(&YA
M("5S(@H*(SH@;6]N=&@N<&AP.C$S,R!T96UP;&%T97,O=V5E:R]H96%D7W-I
M9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?
M8GE?<VED92YI;F,Z,3`*;7-G:60@(DAI9&4B"FUS9W-T<B`B4VMR>;LB"@HC
M.B!M;VYT:"YP:'`Z,3,S('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S
M:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E
M+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(:61E("5S(@IM<V=S='(@
M(E-K<GF[("5S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C4@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3,V"FUS9VED(")(;W5R*',I(@IM<V=S
M='(@(DAO9&EN82AY*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*
M;7-G:60@(DAO=R!L;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T:&4@
M9&%Y(&%N9"!W965K('9I97=S(&)E/R(*;7-G<W1R(")!:^D@9&QHZ2!M86KZ
M(&)YNR#H87-O=ND@^G-E:WD@=B!D96YN;VT@82!T_;YD96YN;VT@;N%HM6%D
M93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`Q"FUS9VED(")(;W<@
M;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S:&]U;&0@=V4@
M9V5N97)A=&4_(@IM<V=S='(@(B(*(E!R92!A:_T@<&_H970@9&[M(&1O(&)U
M9/IC;F]S=&D@<V$@;>$@=GEG96YE<F]V8;L@:6YF;W)MX6-I82!O("(*(GIA
M;F5P<N%Z9&YE;F]S=&D_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B))9B!Y;W5R(&5M86EL(&-L:65N="!D
M;V5S;B=T('-U<'!O<G0@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@
M;V8@=&AE("(*(F9O;&QO=VEN9R!L:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN
M92!T:&4@979E;G0N7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0Z7&XB
M"B(E<UQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY
M.EQN(@HB)7-<;B(*(EQN(@HB5&\@9&5C;&EN92!T:&4@979E;G0Z7&XB"B(E
M<R(*;7-G<W1R("(B"B)!:R!6X;D@96UA:6QO=OT@:VQI96YT(&YE<&]D<&]R
M=6IE('!OOFEA9&%V:WD@:51I<"P@;?2^971E('!O=;YINR!J961N=2!Z("(*
M(FYA<VQE9'5J^F-I8V@@;&EN:65K;F$@86MC97!T;W9A;FEE(&%L96)O(&]D
M;6EE=&YU=&EE('5D86QO<W1I+EQN(@HB7&XB"B)0<F4@86MC97!T;W9A;FEE
M('5D86QO<W1I.EQN(@HB)7-<;B(*(EQN(@HB4')E('!R961B9;YNZ2!A:V-E
M<'1O=F%N:64Z7&XB"B(E<UQN(@HB7&XB"B)0<F4@;V1M:65T;G5T:64@=61A
M;&]S=&DZ7&XB"B(E<R(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@0V%L96YD87(L(%-T97`@
M)60B"FUS9W-T<B`B26UP;W)T;W9ANR!K86QE;F3A<BP@:W)O:R`E9"(*"B,Z
M(&1A=&$N<&AP.C(X.`IM<V=I9"`B26UP;W)T+T5X<&]R="!#86QE;F1A<B(*
M;7-G<W1R("));7!O<G0O17AP;W)T(&MA;&5N9.%R82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S
M='(@(DIA;G7A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C<T"FUS9VED(")*=6QY(@IM<V=S='(@(DKZ;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C<S"FUS9VED(")*=6YE(@IM<V=S='(@(DKZ
M;B(*"B,Z(&1A=&$N<&AP.C8T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T
M,@IM<V=I9"`B2V5Y=V]R9',B"FUS9W-T<B`B2[7ZZ&]VZ2!S;&]VX2(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R
M-"!H;W5R<R(*;7-G<W1R(")0;W-L961N_6-H(#(T(&AO9.UN(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#<*;7-G:60@(DQA<W0@36]D:69I960B
M"FUS9W-T<B`B4&]S;&5D;N$@86MT=6%L:7KA8VEA(@H*(SH@=&5M<&QA=&5S
M+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHT"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(SH@=&5M<&QA=&5S+VUO
M;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ-B!T96UP;&%T97,O;6]N=&@O
M:&5A9"YI;F,Z-`IM<V=I9"`B3&%S="!-;VYT:"(*;7-G<W1R(")0;W-L961N
M_2!M97-I86,B"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHT"FUS9VED
M("),87-T(%EE87(B"FUS9W-T<B`B4&]S;&5D;OT@<F]K(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C4T('1E;7!L871E<R]W965K+VAE860N
M:6YC.C,*;7-G:60@(DQA<W0@=V5E:R(*;7-G<W1R(")0;W-L961N_2!T_;YD
M9?(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Y"FUS9VED("),
M:6UI="!T:&4@=&EM92!S<&%N('1O(&5X<&]R=#HB"FUS9W-T<B`B3V)M961Z
M:;L@<F]Z<V%H(.AA<V]V('!R92!E>'!O<G0N(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C@U('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C<T"FUS9VED("),;U]C871I;VXB"FUS9W-T<B`B36EE7W-T;R(*
M"B,Z(&1A=&$N<&AP.C8S('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R
M<RYI;F,Z-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M
M96YT+FEN8SHQ.`HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA
M9V5M96YT+FEN8SHU,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR,0HC.B!L
M:6(O1')I=F5R+G!H<#HQ.#@X"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")-
M:65S=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*;7-G:60@(DUA
M;F%G92!R96UO=&4@8V%L96YD87)S+B(*;7-G<W1R(")3<')A=F]V8;L@=GID
M:6%L96[I(&MA;&5N9.%R92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G
M;W1O+FEN8SHW,`IM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%R96,B"@HC.B!L
M:6(O87!I+G!H<#HQ,#`*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($5V96YT
M<R(*;7-G<W1R(")-87AI;>%L;GD@<&_H970@=61A;&]S=.TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,@IM<V=I9"`B36%Y(@IM<V=S
M='(@(DWA:B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X.#4*;7-G:60@(DUE(@IM
M<V=S='(@(DIA(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS
M9VED(")-965T:6YG(@IM<V=S='(@(E-T<F5T;G5T:64B"@HC.B!L:6(O0FQO
M8VLO=')E95]A;&%R;7,N<&AP.C,*;7-G:60@(DUE;G4@06QA<FUS(@IM<V=S
M='(@(DUE;G4@86QA<FUY(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z
M,PIM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(EIO>FYA;2!M96YU(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C@@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,3,U"FUS9VED(")-:6YU=&4H<RDB"FUS9W-T<B`B36EN^G1A*'DI
M(@H*(SH@>65A<BYP:'`Z.#`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"B,Z(&QI8B]";&]C
M:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")-;R(*;7-G<W1R(")0;VXB"@HC.B!T
M96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,38@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3$U"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8X
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*;7-G:60@(DUO;F1A>2(*;7-G
M<W1R(")0;VYD96QO:R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,30@;&EB
M+T)L;V-K+W1R965?;65N=2YP:'`Z,C0@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@U"FUS9VED(")-;VYT:"(*;7-G<W1R(")-97-I86,B"@HC.B!L:6(O0FQO
M8VLO;6]N=&@N<&AP.C,*;7-G:60@(DUO;G1H(%9I97<B"FUS9W-T<B`B365S
M8>AN_2!NX6BU860B"@HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HS(&QI
M8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0S"FUS9VED(")-;VYT:&QY($5V96YT
M<R!,:7-T(@IM<V=S='(@(EIO>FYA;2!M97-AZ&[]8V@@=61A;&]S=.TB"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,S(*;7-G:60@(DUO;G1H;'DZ(%)E
M8W5R<R!E=F5R>2(*;7-G<W1R(")-97-AZ&YE.B!O<&%K;W9A;FEE(@H*(SH@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!!:&5A
M9"(*;7-G<W1R(")-97-I86-O=B!D;W!R961U(@H*(SH@;&EB+T)L;V-K+W!R
M979M;VYT:&QI<W0N<&AP.C(T"FUS9VED(")-;VYT:',@0F5F;W)E(@IM<V=S
M='(@(DUE<VEA8V]V('!R960B"@HC.B!L:6(O87!I+G!H<#HV,S0*;7-G:60@
M(DUU;'1I<&QE(&E#86QE;F1A<B!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N
M92!V179E;G0@:7,@<W5P<&]R=&5D+B(*;7-G<W1R("(B"B)";VQO(&[A:F1E
M;OUC:"!V:6%C97)O(&MO;7!O;F5N=&]V(&E#86QE;F1A<CL@<&]D<&]R;W9A
M;OT@:F4@:6)A(&IE9&5N("(*(G9%=F5N="XB"@HC.B!C86QE;F1A<G,N<&AP
M.C$R."!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-S`*;7-G
M:60@(DUY($-A;&5N9&%R<R(*;7-G<W1R(")-;VIE(&MA;&5N9.%R92(*"B,Z
M('1E;7!L871E<R]M96YU+FEN8SHS-"!T96UP;&%T97,O;65N=2YI;F,Z,S8*
M;7-G:60@(DUY($-A;&5N9&%R<SHB"FUS9W-T<B`B36]J92!K86QE;F3A<CHB
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C$S"FUS
M9VED(")->2!&<F5E+T)U<WD@55),(@IM<V=S='(@(DUO:F$@55),(',@:6YF
M;W)MX6-I86UI(&\@>F%N97!RX7ID;F5N;W-T:2(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,C`@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C$V,@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C$W-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M
M86YA9V5M96YT+FEN8SHQ-PHC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A
M;%]M86YA9V5M96YT+FEN8SHT-`IM<V=I9"`B3F%M92(*;7-G<W1R(")-96YO
M(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HT,2!L:6(O0FQO8VLO;6]N=&AL
M:7-T+G!H<#HT-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*(SH@;&EB+T)L
M;V-K+W1R965?;65N=2YP:'`Z,C`*;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R
M(").;W;A('5D86QO<[LB"@HC.B!L:6(O8F%S92YP:'`Z,34W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(DYE=R!C86QE;F1A<B!C<F5A=&5D(&%N9"!A=71O
M;6%T:6-A;&QY('-H87)E9"!W:71H(&9O;&QO=VEN9R!G<F]U<"AS*3H@)7,N
M(@IM<V=S='(@(B(*(DYO=OT@:V%L96YDX7(@8F]L('9Y='9O<F5N_2!A(&%U
M=&]M871I8VMY('-A('ID:66U82!S;R!S:W5P:6YO=2`H<VMU<&EN86UI*3H@
M(@HB)7,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,PIM<V=I
M9"`B3F5X="(*;7-G<W1R("+/86QE:B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHU-PIM<V=I9"`B3F5X="`R-"!H;W5R<R(*;7-G<W1R(").
M87-L961U:OIC:6-H(#(T(&AO9.UN(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP
M.C(Y"FUS9VED(").97AT($1A>2(*;7-G<W1R(").87-L961U:OIC:2!D9?(B
M"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C8*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC
M.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$X('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHV"FUS9VED(").97AT($UO;G1H(@IM
M<V=S='(@(DYA<VQE9'5J^F-I(&UE<VEA8R(*"B,Z(&QI8B]&0E9I97<O=V5E
M:RYP:'`Z,S(*;7-G:60@(DYE>'0@5V5E:R(*;7-G<W1R(").87-L961U:OIC
M:2!T_;YD9?(B"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHV"FUS9VED
M(").97AT(%EE87(B"FUS9W-T<B`B3F%S;&5D=6KZ8VD@<F]K(@H*(SH@=&5M
M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT(&1A>2(*;7-G<W1R
M(").87-L961U:OIC:2!D9?(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X
M="!W965K(@IM<V=S='(@(DYA<VQE9'5J^F-I('3]OF1E\B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-S4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X
M.`IM<V=I9"`B3F\B"FUS9W-T<B`B3FEE(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3(T"FUS9VED
M(").;R!A;&%R;2(*;7-G<W1R("*N:6%D96X@86QA<FTB"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#@*;7-G:60@(DYO(&%T=&5N
M9&5E<R(*;7-G<W1R("*N:6%D;FD@^NAA<W1N[6-I(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3,S,`IM<V=I9"`B3F\@8V%L96YD87)S(&%R92!A=F%I;&%B
M;&4@=&\@9W5E<W1S+B(*;7-G<W1R(")0<F4@;F5P<FEH;.%S96[]8V@@<&]U
MONUV871EM6]V(&YI92!S^B!K(&1I<W!O>NUC:6D@OFEA9&YE(&MA;&5N9.%R
M92XB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S8@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C4R"FUS9VED(").;R!E;F0@9&%T92(*;7-G<W1R
M("*N:6%D;GD@9.%T=6T@=6MO;NAE;FEA(@H*(SH@;&EB+T)L;V-K+W!R979M
M;VYT:&QI<W0N<&AP.C$V-"!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ-C,*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y-`IM<V=I9"`B3F\@979E;G1S
M('1O(&1I<W!L87DB"FUS9W-T<B`BKFEA9&YE('5D86QO<W1I(&YA('IO8G)A
M>F5N:64B"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z-#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F\@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL
M86)L92!F;W(@)7,B"FUS9W-T<B`B4')E("5S(&YI92!J92!K(&1I<W!O>NUC
M:6D@:6YF;W)MX6-I82!O('IA;F5P<N%Z9&YE;F]S=&DB"@HC.B!L:6(O87!I
M+G!H<#HS-#4@;&EB+V%P:2YP:'`Z-C(T"FUS9VED(").;R!I0V%L96YD87(@
M9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(DYE8F]L:2!NX6ID96[I(+YI861N
M92#Z9&%J92!I0V%L96YD87(N(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C`Q"FUS9VED(").;R!R96-U<G)E;F-E(@IM<V=S='(@(D)E>B!O<&%K
M;W9A;FEA(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3`R"FUS9VED(").;R!V
M86QI9"!E;6%I;"!A9&1R97-S(&9O=6YD(@IM<V=S='(@(DYE8F]L82!NX6ID
M96[A('!L871NX2!E+6UA:6QO=N$@861R97-A(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-C$R(&QI8B]+<F]N;VQI=&@N<&AP.C8S,PIM<V=I9"`B3F]N92(*
M;7-G<W1R("*N:6%D;F$B"@HC.B!L:6(O4W1O<F%G92]S<6PN<&AP.C$T-0IM
M<V=I9"`B3F]T(&9O=6YD(@IM<V=S='(@(DYE;N%J9&5NZ2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,0IM<V=I9"`B3F]T:69I8V%T:6]N<R(*;7-G
M<W1R(")5<&]Z;W)N96YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C<X"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-@IM<V=I9"`B3F]W
M(@IM<V=S='(@(E1E<F%Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-S<*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3VMT\V)E<B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$S('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8U"FUS9VED(")/;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<X(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.3$*;7-G:60@(D]N(&%L;"!C86QE;F1A<G,@22!H879E
M(')E860@86-C97-S('1O(@IM<V=S='(@(E!R92!VN65T:WD@:V%L96YDX7)E
M+"!K=2!K=&]R_6T@;>%M('!R[7-T=7`@;F$@Z.UT86YI92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y
M,`IM<V=I9"`B3VX@86QL('-H;W=N(&-A;&5N9&%R<R(*;7-G<W1R(")0<F4@
M=KEE=&MY('IO8G)A>F5NZ2!K86QE;F3A<F4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C<V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.#D*;7-G:60@
M(D]N(&UY(&-A;&5N9&%R<R!O;FQY(@IM<V=S='(@(DEB82!P<F4@;6]J92!K
M86QE;F3A<F4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,S`*;7-G:60@(D]P
M=&EO;F%L(@IM<V=S='(@(E9O;&ET9;5NZ2(*"B,Z(&QI8B]&0E9I97<N<&AP
M.C$Q.0IM<V=I9"`B3W!T:6]N86P@071T96YD965S(@IM<V=S='(@(DYE<&]V
M:6YN[2#ZZ&%S=&[M8VDB"@HC.B!L:6(O1D)6:65W+G!H<#HQ-30*;7-G:60@
M(D]V97)V:65W(@IM<V=S='(@(E!R96BU860B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHS-`IM<V=I9"`B3W=N97(B"FUS9W-T<B`B5FQA<W1N[6LB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D]W;F5R.B`E<R(*;7-G<W1R(")6;&%S=&[M:SH@)7,B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$Q-"!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$Y-`IM<V=I9"`B4$TB"FUS9W-T<B`B4&]P;VQU9&[M(@H*(SH@;&EB
M+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C,@;&EB+T)L;V-K+W!R979M;VYT
M:&QI<W0N<&AP.C0R"FUS9VED(")087-T($5V96YT<R!,:7-T(@IM<V=S='(@
M(EIO>FYA;2!M:6YU;/UC:"!U9&%L;W-T[2(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$P.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.38*;7-G
M:60@(E!A='1E<FXB"FUS9W-T<B`B5GIO<B(*"B,Z('1E;7!L871E<R]D96QE
M=&4O;VYE+FEN8SHS,`IM<V=I9"`B4&5R;6%N96YT;'D@9&5L971E('1H:7,@
M979E;G0_(@IM<V=S='(@(DYA=')V86QO('9Y;6%Z8;L@=/IT;R!U9&%L;W.[
M/R(*"B,Z(&QI8B]A<&DN<&AP.C,R-B!L:6(O87!I+G!H<#HT,C(@;&EB+V%P
M:2YP:'`Z-#DT(&QI8B]A<&DN<&AP.C4W-`HC.B!L:6(O87!I+G!H<#HV,#8@
M;&EB+V%P:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.C<R.`IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`B4'+M<W1U<"!Z86UI971N=73](@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W,`IM<V=I9"`B
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B4'+A=F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$*;7-G:60@(E!O<G1A;"!/<'1I;VYS(@IM<V=S='(@(DYA
M<W1A=F5N:6$@<&]R=.%L=2(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR-0IM
M<V=I9"`B4')E=FEO=7,@1&%Y(@IM<V=S='(@(E!R961C:.%D>F%J^F-I(&1E
M\B(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*;7-G:60@(E!R979I;W5S
M(%=E96LB"FUS9W-T<B`B4')E9&-HX61Z86KZ8VD@=/V^9&7R(@H*(SH@=&5M
M<&QA=&5S+V1A>2]H96%D+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D87DB"FUS
M9W-T<B`B4')E9&-HX61Z86KZ8VD@9&7R(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3,U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T.0IM<V=I
M9"`B4F5C=7(@56YT:6PB"FUS9W-T<B`B3W!A:W5J92!S82!K_6TB"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,#8*;7-G:60@(E)E8W5R<F5N8V4B
M"FUS9W-T<B`B3W!A:V]V86YI92(*"B,Z(&1A=&$N<&AP.C8X"FUS9VED(")2
M96-U<G)E;F-E($1A=&$B"FUS9W-T<B`BVF1A:F4@;W!A:V]V86YI82(*"B,Z
M(&1A=&$N<&AP.C8V"FUS9VED(")296-U<G)E;F-E($5N9"!$871E(@IM<V=S
M='(@(D3A='5M('5K;V[H96YI82!O<&%K;W9A;FEA(@H*(SH@9&%T82YP:'`Z
M-C<*;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`B26YT97)V
M86P@;W!A:V]V86YI82(*"B,Z(&1A=&$N<&AP.C8U"FUS9VED(")296-U<G)E
M;F-E(%1Y<&4B"FUS9W-T<B`B5'EP(&]P86MO=F%N:6$B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU-#@*;7-G:60@(E)E8W5R<R!D86EL>2(*;7-G<W1R(")O
M<&%K=6IE('-A(&MAOF1O9&5N;F4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU
M-34*;7-G:60@(E)E8W5R<R!M;VYT:&QY(@IM<V=S='(@(F]P86MU:F4@<V$@
M:V&^9/T@;65S:6%C(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34Q"FUS9VED
M(")296-U<G,@=V5E:VQY(@IM<V=S='(@(D]P86MU:F4@<V$@:V&^9/T@=/V^
M9&7R(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34X"FUS9VED(")296-U<G,@
M>65A<FQY(@IM<V=S='(@(F]P86MU:F4@<V$@<F%Z(')OZ&YE(@H*(SH@;&EB
M+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296UI;F1E<CH@)7,B"FUS9W-T<B`B4')I<&]M:65N:V$Z("5S(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.CDT(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-`IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<R(*
M;7-G<W1R(")6>F1I86QE;ND@:V%L96YDX7)E(@H*(SH@=&5M<&QA=&5S+VUE
M;G4N:6YC.C8P('1E;7!L871E<R]M96YU+FEN8SHV,@IM<V=I9"`B4F5M;W1E
M($-A;&5N9&%R<SHB"FUS9W-T<B`B5GID:6%L96[I(&MA;&5N9.%R93HB"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DT"FUS9VED
M(")296UO=&4@4W5B<V-R:7!T:6]N(%523"(*;7-G<W1R(")54DP@=GID:6%L
M96[I:&\@<')I:&SA<V5N:6$B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E("5S
M(@IM<V=S='(@(D]D<W1RX6YINR`E<R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`T
M"FUS9VED(")296UO=F4@071T96YD964B"FUS9W-T<B`B3V1S='+A;FF[(/KH
M87-T;NUK82(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S$*;7-G
M:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@8V%L96YD87(@=VET:"!T:&4@:6UP
M;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A
M;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@8V%L96YD87(N/"]S=')O;F<^
M(@IM<V=S='(@(B(*(E!R97#M<V&[(&5X:7-T=6KZ8VD@:V%L96YDX7(@:6UP
M;W)T;W9A;OUM(&MA;&5N9.%R;VT_(#QS=')O;F<^5F%R;W9A;FEE.B`B"B)T
M;W1O('9Y;6&^92!VN65T:WD@<&]L;[YK>2!V;R!68;EO;2!A:W1UX6QN;VT@
M:V%L96YDX7)I+CPO<W1R;VYG/B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8S
M-PIM<V=I9"`B4F5Q=6ER960B"FUS9W-T<B`B4&^^861O=F%N_2(*"B,Z(&QI
M8B]&0E9I97<N<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S.2!L:6(O1D)6:65W
M+G!H<#HQ-#(@;&EB+T9"5FEE=RYP:'`Z,30U"FUS9VED(")297%U:7)E9"!!
M='1E;F1E97,B"FUS9W-T<B`B4&^^861O=F%N[2#ZZ&%S=&[M8VDB"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHS,B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHS,#@*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(D]B
M;F]V:;L@;F$@<')E9&YA<W1A=F5NZ2!H;V1N;W1Y(@H*(SH@=&5M<&QA=&5S
M+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0S('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$V-@IM<V=I9"`B4F5S<&]N<V4B"FUS9W-T<B`B3V1P;W9E[R(*
M"B,Z('EE87(N<&AP.C@U('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,`HC.B!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$P-0IM<V=I9"`B4V$B"FUS9W-T<B`B4V\B"@HC.B!T96UP
M;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C$@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(P"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<S"FUS
M9VED(")3871U<F1A>2(*;7-G<W1R(")3;V)O=&$B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C`S"FUS9VED(")3879E(@IM<V=S
M='(@(E5L;[YINR(*"B,Z('9I97=E=F5N="YP:'`Z,3,S(&5D:71E=F5N="YP
M:'`Z-#D@961I=&5V96YT+G!H<#HU-PIM<V=I9"`B4V%V92!!<R!.97<B"FUS
M9W-T<B`B56QOOFF[(&%K;R!N;W;Z(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E
M<R]A='1E;F1E97,N:6YC.C@T"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G
M<W1R(")5;&^^:;L@^NAA<W1N[6MO=B(*"B,Z(&%D9&5V96YT+G!H<#HU-2!E
M9&ET979E;G0N<&AP.C4R"FUS9VED(")3879E($5V96YT(@IM<V=S='(@(E5L
M;[YINR!U9&%L;W.[(@H*(SH@<V5A<F-H+G!H<#HY,2!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$T"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHV-R!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI
M;F,Z.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$T,"!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(DBU861ANR(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN
M8SHQ"FUS9VED(")396%R8V@@0V%L96YD87)S(@IM<V=S='(@(E!R96BU861A
MNR!K86QE;F3A<F4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z
M-@IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B5OUS;&5D:WD@:+5A
M9&%N:6$B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z-@IM
M<V=I9"`B4V5A<F-H(&9O<B!C86QE;F1A<G,@8V]N=&%I;FEN9SHB"FUS9W-T
M<B`B2+5A9&&[(&MA;&5N9.%R92!O8G-A:'5J^F-E.B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3,*;7-G:60@(E-E;&5C="!A
M(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`B5GEB97)T92!K86QE;F3A<B!N
M82#Z<')A=G4B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-C4@=&5M
M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,S$*(SH@=&5M<&QA=&5S
M+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.#,*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`B5GEB97)T92!DX71U;2(*"B,Z('1E;7!L871E<R]M96YU
M+FEN8SHS,`IM<V=I9"`B4V5L96-T(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.B(*
M;7-G<W1R(")6>6)E<G1E(&MA;&5N9.%R92P@:W1O<ND@<V$@;6%J^B!Z;V)R
M87IO=F&[.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B
M(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA
M>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@(@HB9&5F875L="!V
M:65W+B(*;7-G<W1R("(B"B)6>6)E<G1E(&UOOFYO<W1I('!O='9R9&5N[2P@
M86MO('-A(&UA:OH@>F]B<F%Z;W9ANR!R]'IN92!NX6BU861Y(&$@=GEB97)T
M92`B"B)I;7!L:6-I=&[](&[A:+5A9"XB"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C$X"FUS9VED(")396QE8W0@=&AE(&-A;&5N9&%R('1O(&EM
M<&]R="!T;SHB"FUS9W-T<B`B5GEB97)T92!K86QE;F3A<BP@9&\@:W1O<NEH
M;R!S82!MX2!I;7!O<G1O=F&[.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,3D*;7-G:60@(E-E;&5C="!T:&4@8V%L96YD87(H<RD@=&\@97AP
M;W)T(&9R;VTB"FUS9W-T<B`B5GEB97)T92!K86QE;F3A<BAE*2P@:W1O<ND@
M<V$@;6%J^B!E>'!O<G1O=F&[(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ,@IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G
M<W1R(")6>6)E<G1E(&9O<FWA="!E>'!O<G1U.B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,C<*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I
M;7!O<G0Z(@IM<V=S='(@(E9Y8F5R=&4@<_IB;W(@<')E(&EM<&]R=#HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED(")396QE8W0@=&AE
M(&9I<G-T('=E96MD87DZ(@IM<V=S='(@(E9Y8F5R=&4@<')V_2!D9?(@=/V^
M9/)A.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G:60@
M(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T
M<B`B5GEB97)T92!F;W)MX70@>F1R;VIO=NEH;R!S^F)O<G4Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T:6UE
M('-P86X@=&\@<VAO=SHB"FUS9W-T<B`B5GEB97)T92#H87-O=OT@<F]Z<V%H
M('!R92!Z;V)R87IE;FEE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-@IM<V=I9"`B4V5L96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A<G1U
M<#HB"FUS9W-T<B`B5GEB97)T92!NX6BU860L(&MT;W+]('-A('IO8G)A>NT@
M<&\@<')I:&SA<V5N[3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(*
M;7-G:60@(E-E;&5C="!W:&EC:"!E=F5N=',@=&\@<VAO=R!I;B!T:&4@<&]R
M=&%L+B(*;7-G<W1R(")6>6)E<G1E+"!K=&]RZ2!U9&%L;W-T:2!S82!M86KZ
M('IO8G)A>FF[('8@<&]R=.%L:2XB"@HC.B!T96UP;&%T97,O9&5L971E+V]N
M92YI;F,Z,C<@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED
M(")396YD(&$@8V%N8V5L(&YO=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S
M('=H96X@9&5L971I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"B)0;W-L8;L@
M=7!O>F]R;F5N:64@;R!Z<G6Y96[M(':Y971K_6T@^NAA<W1N[6MO;2!P<FD@
M=GEM87IA;NT@=&5J=&\@=61A;&]S=&DB"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5N9"!A;B!E;6%I
M;"!T;R`E<R(*;7-G<W1R(")0;W-L8;L@92UM86EL("5S(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3<Y"FUS9VED(")396YD('5P9&%T97,O:6YV
M:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V
M96YT(@IM<V=S='(@(B(*(E!O<VQANR!A:W1U86QI>N%C:64O<&]Z=N%N:WD@
M=KEE=&O];2#ZZ&%S=&[M:V]M('!R:2!U;&^^96[M('1E:G1O('5D86QO<W1I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S8*;7-G:60@
M(E-E<'1E;6)E<B(*;7-G<W1R(")397!T96UB97(B"@HC.B!T96UP;&%T97,O
M961I="]E9&ET7W1I;65S<&%N+FEN8SHX,PIM<V=I9"`B4V5T(&5N9"!D871E
M(@IM<V=S='(@(DYA<W1A=FF[(&3A='5M('5K;V[H96YI82(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(V-0IM<V=I9"`B4V5T(')E8W5R<F5N8V4@
M96YD(&1A=&4B"FUS9W-T<B`B3F%S=&%V:;L@9.%T=6T@=6MO;NAE;FEA(&]P
M86MO=F%N:6$B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN
M8SHS,0IM<V=I9"`B4V5T('-T87)T(&1A=&4B"FUS9W-T<B`B3F%S=&%V:;L@
M9.%T=6T@>F'H:6%T:W4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3D*
M;7-G:60@(B(*(E-E="!Y;W5R(&9R964O8G5S>2!C86QE;F1A<G,@86YD('EO
M=7(@;W=N(&%N9"!O=&AE<B!U<V5R<R<@9G)E92]B=7-Y(&]P=&EO;G,N(@IM
M<V=S='(@(B(*(DYA<W1A=FF[(%9AN64@:V%L96YDX7)E(',@:6YF;W)MX6-I
M;W4@;R!Z86YE<'+A>F1N96YO<W1I(&$@;F%S=&%V96YI82`B"B)Z86YE<'+A
M>F1N96YO<W1I('!R92!6X7,@82!I;OUC:"!P;W6^[79A=&6U;W8N(@H*(SH@
M8V%L96YD87)S+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&%R92!N
M;W0@9F]U;F0Z("5S(@IM<V=S='(@(EID:66U86YI92!N96)O;&\@;N%J9&5N
MZ3H@)7,B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M.#(*;7-G:60@(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T<B`B6F1I9;5A;ND@
M:V%L96YDX7)E(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C0W('1E;7!L871E
M<R]M96YU+FEN8SHT.0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R<SHB"FUS9W-T
M<B`B6F1I9;5A;ND@:V%L96YDX7)E.B(*"B,Z(&-A;&5N9&%R7W-E87)C:"YP
M:'`Z,C4@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PIM<V=I
M9"`B4VAO=R!#86QE;F1A<B(*;7-G<W1R("):;V)R87IINR!K86QE;F3A<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-38*;7-G:60@(E-H;W<@8V%T
M96=O<GD@;&5G96YD/R(*;7-G<W1R("):;V)R87IINR!L96=E;F1U('!R92!K
M86QE;F3A<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED
M(")3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN
M(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R("(B"B):;V)R87IINR!I:V]N>2!P
M<F4@=GEM87IA;FEE+"!A;&%R;2!A(&]P86MO=F%N:64@=B!K86QE;F3A<F]V
M_6-H(&[A:+5A9&]C:#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R
M"FUS9VED(")3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_(@IM<V=S
M='(@(EIO8G)A>FF[(/IL;VAY('!O('1E<FWM;F4@=B!K86QE;F3A<FD_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V-@IM<V=I9"`B4VAO=R!F<F5E
M+V)U<WD@;&5G96YD/R(*;7-G<W1R("):;V)R87IINR!L96=E;F1U('!R92!I
M;F9O<FWA8VEE(&\@>F%N97!RX7ID;F5N;W-T:3\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C`S"FUS9VED(")3:&]W(&]N;'D@979E;G1S('1H870@
M:&%V92!A;B!A;&%R;2!S970_(@IM<V=S='(@(EIO8G)A>FF[(&QE;B!U9&%L
M;W-T:2P@:W1O<ND@;6%J^B!N87-T879E;OT@86QA<FT@/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-S4*;7-G:60@(E-H;W<@<VAA<F5D(&-A;&5N
M9&%R<R!S:61E+6)Y+7-I9&4_(@IM<V=S='(@(EIO8G)A>FF[('ID:66U86[I
M(&MA;&5N9.%R92!V962U82!S96)A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,C$*;7-G:60@(E-H;W<@=&%S:W,@=7-I;F<@8V%T96=O<GD@8V]L
M;W)S/R(*;7-G<W1R("):;V)R87IINR#Z;&]H>2!S('!O=;YI=.UM(&9A<FEE
M8B!P<F4@:V%T96?S<FEE/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-0IM<V=I9"`B4VAO=R!T:6UE(&]F(&1A>2!B971W965N(&5A8V@@9&%Y(&EN
M('=E96L@=FEE=W,_(@IM<V=S='(@(EIO8G)A>FF[(.AA<R!M961Z:2!K8;YD
M_6T@9/)O;2!V('3]OF1E;FYO;2!NX6BU861E/R(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q"FUS9VED(")3=&%?<G0B"FUS9W-T
M<B`B6F'H:6%?=&]K(@H*(SH@9&%T82YP:'`Z-30*;7-G:60@(E-T87)T($1A
M=&4B"FUS9W-T<B`B1.%T=6T@>F'H:6%T:W4B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+V5V96YT7VAE861E<G,N:6YC.C<@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS-PIM<V=I9"`B
M4W1A<G0@3VXB"FUS9W-T<B`B6F'H[6YA(@H*(SH@9&%T82YP:'`Z-34*;7-G
M:60@(E-T87)T(%1I;64B"FUS9W-T<B`BR&%S('IAZ&EA=&MU(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.CDT('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C@S"FUS9VED(")3=&%T7W5S(@IM<V=S='(@(E-T
M85]V(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHV
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C(W"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`B4W1A=B(*"B,Z('EE87(N<&AP.C<X('EE87(N<&AP.C@W('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8U"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(R,2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-R!L:6(O0FQO
M8VLO;6]N=&@N<&AP.C$P.0IM<V=I9"`B4W4B"FUS9W-T<B`B3F4B"@HC.B!T
M96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,30@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C(S"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,2!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV-PHC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`U"FUS9VED(")3=6YD87DB"FUS9W-T<B`B3F5D9;5A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS9VED(")487-K<R(*;7-G
M<W1R("+:;&]H>2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4X-2!L:6(O2W)O
M;F]L:71H+G!H<#HV,#@*;7-G:60@(E1E;G1A=&EV92(*;7-G<W1R(")0<F5D
M8F6^;OTB"@HC.B!Y96%R+G!H<#HX,R!T96UP;&%T97,O:F%V87-C<FEP="]G
M;W1O+FEN8SHV,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3@*(SH@;&EB
M+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1H(@IM<V=S='(@(JET(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW,`IM<V=I9"`B
M5&AE($5D:70@071T96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N
M="X@17AI=&EN9RXB"FUS9W-T<B`B3V)R87IO=FMA(%5P<F%V:;L@^NAA<W1N
M[6MO=B!UOB!N965X:7-T=6IE+B!+;VYI96,N(@H*(SH@8V%L96YD87)S+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB
M(&-A;FYO="!B92!D96QE=&5D+B(*;7-G<W1R(")+86QE;F3A<B!<(B5S7"(@
M<V$@;F5P;V1A<FEL;R!V>6UA>F&[+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@
M8F5E;B!C<F5A=&5D+B(*;7-G<W1R(")+86QE;F3A<B!<(B5S7"(@8F]L('9Y
M='9O<F5N_2XB"@HC.B!C86QE;F1A<G,N<&AP.C@X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B2V%L96YDX7(@7"(E<UPB(&)O;"!V>6UA>F%N_2XB"@HC.B!C
M86QE;F1A<G,N<&AP.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE
M;F1A<B!<(B5S7"(@:&%S(&)E96X@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S
M='(@(DMA;&5N9.%R(%PB)7-<(B!B;VP@<')E;65N;W9A;OT@;F$@7"(E<UPB
M+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B
M2V%L96YDX7(@7"(E<UPB(&)O;"!U;&^^96[]+B(*"B,Z(&1A=&$N<&AP.C(S
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@8V]U;&0@;F]T
M(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B2V%L96YDX7(@<V$@;F5P;V1A<FEL
M;R!V>6UA>F&[.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N
M:6YC.C$V,PIM<V=I9"`B5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA
M;B!T:&4@<W1A<G0@9&%T92XB"FUS9W-T<B`B1&7R('5K;V[H96YI82!M=7/M
M(&YA<VQE9&]V8;L@8;X@<&\@9&YI('IAZ&%T:6$N(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@979E
M;G0@7"(E<UPB(&AA<R!B965N(&%D9&5D('1O(%PB)7-<(B!C86QE;F1A<BP@
M=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S='(@(D1O(&MA;&5N9.%R82!<
M(B5S7"(@8F]L82!P<FED86[A('5D86QO<[L@7"(E<UPB+"!K=&]RX2!J92`E
M<R!O("5S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D(&9R;VT@7"(E<UPB(&-A;&5N9&%R+"!W:&EC:"!W87,@;VX@)7,@870@
M)2(*(G,N(@IM<V=S='(@(EH@:V%L96YDX7)A(%PB)7-<(B!B;VQA('9Y;6%Z
M86[A('5D86QO<[L@7"(E<UPB+"!K=&]RX2!B;VQA("5S(&\@)7,N(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"!O;B!<(B5S7"(@
M8V%L96YD87(L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R(")6(&MA
M;&5N9.%R:2!<(B5S7"(@8F]L82!U<')A=F5NX2!U9&%L;W.[(%PB)7-<(BP@
M:W1O<N$@:F4@)7,@;R`E<RXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#@W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!N;W1I9FEC871I;VX@
M=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+B(*;7-G<W1R(")5<&]Z;W)N
M96YI92!N82!U9&%L;W.[('!R92`E<R!B;VQO(/IS<&6Y;F4@;V1O<VQA;NDN
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`T-`IM<V=I9"`B5&AE(&9O;&QO
M=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V
M96YT.B(*;7-G<W1R(").87-L961U:F4@9&5T86EL;F5JN>T@<&]P:7,@=61A
M;&]S=&DZ(@H*(SH@871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E
M<W0@=V%S(&EN8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N
M96-E<W-A<GD@=&\@86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E
M(&UI<W-I;F<N(@IM<V=S='(@(B(*(E!OOFEA9&%V:V$@;F5B;VQA(/IP;&[A
M+B!#:/UB86KZ(&YI96MT;W+I('!A<F%M971R92P@:W1O<ND@<_H@;F5V>6AN
M=71NZ2!P<F4@(@HB86MC97!T;W9A;FEE(&%L96)O('IA;6EE=&YU=&EE('5D
M86QO<W1I+B(*"B,Z('1E;7!L871E<R]S96%R8V@O96UP='DN:6YC.C,*;7-G
M:60@(E1H97)E(&%R92!N;R!E=F5N=',@;6%T8VAI;F<@=&AE(&-U<G)E;G0@
M8W)I=&5R:6$N(@IM<V=S='(@(JYI861N92!U9&%L;W-T:2!N979Y:&]V=6KZ
M(&%K='7A;&YY;2!K<FETZ7)IX6TN(@H*(SH@861D979E;G1A8W1I;VXN<&AP
M.C$X(&5D:71E=F5N=&%C=&EO;BYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z
M("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('!R[7-T=7!E(&MU(&MA
M;&5N9.%R=3H@)7,B"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@
M979E;G0Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('!R:63A=F%N
M[2!U9&%L;W-T:3H@)7,B"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!E9&ET:6YG
M('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@^G!R
M879E('5D86QO<W1I.B`E<R(*"B,Z(&QI8B]A<&DN<&AP.C,S.2!L:6(O87!I
M+G!H<#HV,3@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(").87-T86QA(&-H>6)A('!R
M:2!I;7!O<G1E(/ID86IO=B!I0V%L96YD87(N(@H*(SH@961I=&5V96YT86-T
M:6]N+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P<FD@<')E<_IV86[M('5D86QO<W1I.B`E<R(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$P.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('-E;F1I;F<@86X@979E;G0@;F]T:69I8V%T:6]N('1O("5S
M.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!P;W-I96QA;NT@=7!O
M>F]R;F5N:6$@;F$@=61A;&]SNR`E<SH@)7,B"@HC.B!D871A+G!H<#HQ,#@*
M;7-G:60@(E1H97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R="XB"FUS9W-T
M<B`B3FEE('/Z(+YI861N92!U9&%L;W-T:2!P<F4@97AP;W)T+B(*"B,Z(&1A
M=&$N<&AP.C$X-PIM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(")496YT;R!F;W)MX70@<_IB;W)U(&YI92!J92!P
M;V1P;W)O=F%N_2XB"@HC.B!D871A+G!H<#HR-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B5&]T;R!O>F[A;6EL('-E<G9E<CH@)7,B"@HC.B!T96UP;&%T97,O;6]N
M=&@O:&5A9"YI;F,Z,3D@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$X"B,Z
M('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<Q"FUS9VED(")4:'5R
M<V1A>2(*;7-G<W1R("*I='9R=&]K(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:6YC.C,W"FUS9VED(")4:6UE(%-P7V%N(@IM<V=S='(@(LAA<V]V
M_2!R;WIS7V%H(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z-`IM<V=I9"`B5&EM92!S<&%N(@IM<V=S='(@(LAA<V]V_2!R;WIS86@B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,S0@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S@*;7-G:60@(E1I=%]L92(*;7-G
M<W1R(")4:71U7VPB"@HC.B!D871A+G!H<#HU,R!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z,C`*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D
M97)S+FEN8SHS"FUS9VED(")4:71L92(*;7-G<W1R(")4:71U;&]K(@H*(SH@
M;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R,B!L:6(O0FQO8VLO;6]N
M=&AL:7-T+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R-PIM
M<V=I9"`B5&]D87DB"FUS9W-T<B`B1&YE<R(*"B,Z(&QI8B]";&]C:R]P<F5V
M;6]N=&AL:7-T+G!H<#HQ,C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(S
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,CD*;7-G:60@(E1O;6]R<F]W
M(@IM<V=S='(@(EIA:G1R82(*"B,Z('EE87(N<&AP.C@Q('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C8P('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(Q-@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5'4B"FUS
M9W-T<B`B570B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3<@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$V"B,Z('1E;7!L871E<R]E9&ET+VIA
M=F%S8W)I<'0N:6YC.C8Y"FUS9VED(")4=65S9&%Y(@IM<V=S='(@(E5T;W)O
M:R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B5'EP
M92(*;7-G<W1R(")4>7`B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N
M9&%R<RYI;F,Z,3@V"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@;&EB
M+U-T;W)A9V4O<W%L+G!H<#HV-`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S<&]J:;L@
M<R!344P@<V5R=F5R;VTN(@H*(SH@8V%L96YD87)S+G!H<#HX-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%PB)7-<(CH@)7,B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DYE;6^^
M;ND@;F%H<F&[(&1E9FEN[6-I=2`E<RXB"@HC.B!C86QE;F1A<G,N<&AP.C4Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@7"(E<UPB
M.B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('!R96UE;F]V8;L@7"(E<UPB
M.B`E<R(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HS-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N(&9O<B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANR!I
M;F9O<FWA8VEU(&\@>F%N97!RX7ID;F5N;W-T:2`E<R(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$U"B,Z('-C<FEP=',O=7!G<F%D97,O,C`P-"TP
M-2TQ.5]C;VYV97)T7V-A=&5G;W)I97-?=&]?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E5N9FEL960B"FUS9W-T<B`B3F5N87-T879E;N$B"@HC.B!L:6(O87!I
M+G!H<#HS-S<@;&EB+V%P:2YP:'`Z-#8Q(&QI8B]A<&DN<&AP.C4S-R!L:6(O
M87!I+G!H<#HV-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@
M0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R(").97!O9'!O<F]V86[]('1Y<"!O
M8G-A:'4@*$-O;G1E;G0M5'EP92DZ("5S(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3`S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D.B`E<RXB"FUS
M9W-T<B`B06MT=6%L:7IO=F%NZ3H@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P"FUS9VED(")5<V5R($EN=&5R9F%C92(*;7-G<W1R(")0;W6^
M[79A=&6U<VOI(')O>FAR86YI92(*"B,Z('EE87(N<&AP.C$V,"!Y96%R+G!H
M<#HQ-C8@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ-3D@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HQ-C(*;7-G:60@(E9I97<@1&%Y(@IM<V=S='(@(EIO8G)A>FF[(&1E
M\B(*"B,Z('EE87(N<&AP.C@R('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q-PHC.B!L:6(O0FQO
M8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5V4B"FUS9W-T<B`B4W0B"@HC.B!T
M96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3@@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3$W"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<P
M"FUS9VED(")7961N97-D87DB"FUS9W-T<B`B4W1R961A(@H*(SH@871T96YD
M965S+G!H<#HQ,3(@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,R!L:6(O0FQO8VLO
M=')E95]M96YU+G!H<#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*
M;7-G:60@(E=E96LB"FUS9W-T<B`B5/V^9&7R(@H*(SH@;6]N=&@N<&AP.C$W
M-R!W;W)K=V5E:RYP:'`Z,S`@=V5E:RYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5E:R`E9"(*;7-G<W1R(")4_;YD9?(@)60B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M,S@*;7-G:60@(E=E96LH<RDB"FUS9W-T<B`B5/V^9&7R*'3]OF1N92DB"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C$R"FUS9VED(")7965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G
M<W1R(")4_;YD96YN93H@;W!A:W5J92!S82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C0*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N
M9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E
M;G1S/R(*;7-G<W1R("(B"B)+=&]R_6T@Z&%S;VT@;>$@:V]NZ&F[(&1E;F[]
M(&$@=/V^9&5N;OT@;N%HM6%D+"!A:R!N:64@<_H@;F5S:V]RN6EE('5D86QO
M<W1I/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(B(*
M(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S('-T87)T+"!W
M:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V96YT<S\B"FUS9W-T<B`B(@HB
M2W1O<OUM(.AA<V]M(&WA('IAZ.UN8;L@9&5N;OT@82!T_;YD96YN_2!NX6BU
M860L(&%K(&YI92!S^B!S:V]RN6EE('5D86QO<W1I/R(*"B,Z(&%T=&5N9&5E
M<RYP:'`Z,3$Q(&QI8B]+<F]N;VQI=&@N<&AP.C$S,3(@;&EB+T)L;V-K+W1R
M965?;65N=2YP:'`Z,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS
M9VED(")7;W)K(%=E96LB"FUS9W-T<B`B4')A8V]V;OT@=/V^9&7R(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q-2!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR-0IM<V=I9"`B665A<B(*;7-G<W1R(")2;VLB"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,X
M"FUS9VED(")996%R;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")2;^AN93H@
M;W!A:W5J92!S82(*"B,Z(&1A=&$N<&AP.C,Y(&1A=&$N<&AP.C(S.2!E9&ET
M979E;G1A8W1I;VXN<&AP.C0V(&%D9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@979E;G1S+B(*;7-G<W1R(").96WA=&4@;W!RX79N96YI92!V
M>71V;W)INR!V:6%C(&%K;R`E9"!U9&%L;W-T[2XB"@HC.B!A='1E;F0N<&AP
M.C0Y"FUS9VED(")9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E
M8VEF:65D(&5V96YT+B(*;7-G<W1R(").:64@<W1E(/KH87-T;NUK;VT@N7!E
M8VEF:6MO=F%N96H@=61A;&]S=&DN(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHW-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T:&ES
M(&9O<FT@9G)O;2!T:&4@161I="!!='1E;F1E97,@<V-R965N+B(*;7-G<W1R
M(")496YT;R!F;W)M=6SA<B!M]+YE=&4@<&]UOFF[(&EB82!Z(&]B<F%Z;W9K
M>2!5<')A=FF[(/KH87-T;NUK;W8N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M.3@X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D;R!N;W0@:&%V92!A
M;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S;VYA;"!)
M;F9O<FUA=&EO;B`B"B)/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S:&5R
M925S(&)E9F]R92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT+B(*
M;7-G<W1R("(B"B)6($]S;V)N_6-H(&EN9F]R;>%C:>%C:"!N96WA=&4@;F%S
M=&%V96[Z(&4M;6%I;&]V^B!A9')E<W4N($UU<^UT92!J=2`B"B)N87-T879I
MNR`E<W1U)7,@<VOT<BP@86MO('-A(&)U9/H@<&]S:65L8;L@=7!O>F]R;F5N
M:6$@;F$@=61A;&]S=&DN(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C(P"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N
M('1O(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S='(@(DYE;>%T92!P<N%V;R!N
M82!P<FED86YI92!U9&%L;W-T[2!D;R`E<RXB"@HC.B!D871A+G!H<#HQ.3<*
M;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N
M=',@=&\@=&AE('-E;&5C=&5D(&-A;&5N9&%R+B(*;7-G<W1R(").96WA=&4@
M<'+A=F\@;F$@<')I9&%N:64@=61A;&]S=.T@:R!V>6)R86[I;74@:V%L96YD
MX7)U+B(*"B,Z(&1E;&5V96YT86-T:6]N+G!H<#HR-@IM<V=I9"`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N(@IM
M<V=S='(@(DYE;>%T92!P<N%V;R!N82!V>6UA>F%N:64@=&5J=&\@=61A;&]S
M=&DN(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HW.`IM<V=I9"`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@961I="!T:&ES(&5V96YT+B(*;7-G
M<W1R(").96WA=&4@<'+A=F\@;F$@^G!R879U('1E:G1O('5D86QO<W1I+B(*
M"B,Z(&1A=&$N<&AP.C$Y,@IM<V=I9"`B66]U(&AA=F4@<W!E8VEF:65D(&%N
M(&EN=F%L:60@8V%L96YD87(N(@IM<V=S='(@(EIA9&%L:2!S=&4@;F5P;&%T
M;OT@:V%L96YDX7(N(@H*(SH@871T96YD+G!H<#HR,0IM<V=I9"`B66]U(&AA
M=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E
M=F5N="XB"FUS9W-T<B`BVG-P9;EN92!S=&4@86MC97!T;W9A;&D@^NAA<[L@
M;F$@=&5J=&\@=61A;&]S=&DN(@H*(SH@871T96YD+G!H<#HR-@IM<V=I9"`B
M66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E8VQI;F5D(&%T=&5N9&5N8V4@=&\@
M=&AI<R!E=F5N="XB"FUS9W-T<B`BVG-P9;EN92!S=&4@;V1M:65T;&D@^NAA
M<[L@;F$@=&5J=&\@=61A;&]S=&DN(@H*(SH@871T96YD+G!H<#HS,0IM<V=I
M9"`B66]U(&AA=F4@=&5N=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T
M;R!T:&ES(&5V96YT+B(*;7-G<W1R(")0<F5D8F6^;F4@<W1E(&%K8V5P=&]V
M86QI(/KH87.[(&YA('1E:G1O('5D86QO<W1I+B(*"B,Z(&-A;&5N9&%R<RYP
M:'`Z.3$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E
M(&1E;&5T960N(@IM<V=S='(@(DUU<^UT92!V>6)R8;L@:V%L96YDX7(L(&MT
M;W+](&WA(&)YNR!V>6UA>F%N_2XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C4T"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D
M<F5S<R!F:7)S="XB"FUS9W-T<B`B375S[71E('9Y8G)ANR!A<W!O\B!J961N
M=2!A9')E<W4N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q-`IM<V=I9"`B
M66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@
M861D960@=&\@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(E9YOF%D;W9A;&D@
M<W1E('5P;WIO<FYE;FEE(&YA('5D86QO<W1I('!R:61A;ND@9&\@5F&Y:6-H
M(&MA;&5N9.%R;W8N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$R-`IM<V=I
M9"`B(@HB66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT
M<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+B(*;7-G<W1R(")6
M>;YA9&]V86QI('-T92!U<&]Z;W)N96YI92!N82!U9&%L;W-T:2!V>6UA>F%N
MZ2!Z(%9AN6EC:"!K86QE;F3A<F]V+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$Q,3D*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE
M;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T
M<B`B(@HB5GF^861O=F%L:2!S=&4@=7!O>F]R;F5N:64@;F$@=7!R879E;FEE
M('5D86QO<W1I('9O(%9AN6EC:"!K86QE;F3A<F]C:"XB"@HC.B!L:6(O4V-H
M961U;&5R+VMR;VYO;&ET:"YP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!R97%U97-T960@=&\@8F4@<F5M:6YD960@86)O=70@)7,L('=H:6-H
M(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R(")0;[YA9&]V86QI('-T92!U<&]Z
M;W)N96YI92!N82!U9&%L;W.[("5S+"!K=&]RX2!J92`E<R!O("5S+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*;7-G:60@(EEO
M=7(@9&5F875L="!C86QE;F1A<B(*;7-G<W1R(")6X;D@<')E9&YA<W1A=F5N
M_2!K86QE;F3A<B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-C$@;&EB+T1R:79E
M<BYP:'`Z,3`W,0IM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(EM.
M97!O;65N;W9A;N$@=61A;&]SNUTB"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHY-0IM<V=I9"`B7T%L87)M(@IM<V=S='(@(E]!;&%R;2(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,0IM<V=I9"`B
M7T)A<VEC(%-E87)C:"(*;7-G<W1R(")?6N%K;&%D;ND@:+5A9&%N:64B"@HC
M.B!V:65W979E;G0N<&AP.C$S-0IM<V=I9"`B7T5D:70B"FUS9W-T<B`B7U5P
M<F%V:;LB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S4P"FUS9VED(")?1V]T
M;R(*;7-G<W1R(")?4')E:G.[(&YA(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3,U-@IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R="]%
M>'!O<G0B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,W"FUS9VED(")?37D@
M0V%L96YD87)S(@IM<V=S='(@(E]-;VIE(&MA;&5N9.%R92(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$S-#0*;7-G:60@(E].97<@179E;G0B"FUS9W-T<B`B
M7TYO=N$@=61A;&]SNR(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-C$*;7-G
M:60@(E]0<FEN="(*;7-G<W1R(")?5&QAZ&F[(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,U,@IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?2+5A9&&[(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,T-PIM<V=I9"`B7U1O9&%Y(@IM<V=S
M='(@(E]$;F5S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS
M9VED(")B969O<F4@=&AE(&5V96YT('-T87)T<R(*;7-G<W1R(")P<F5D('IA
MZ&EA=&MO;2!U9&%L;W-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(F1A>2(*;7-G<W1R(")D9?(B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`W"FUS
M9VED(")D87DH<RDB"FUS9W-T<B`B9&7R*&1N:2DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3@V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#<*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3@Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(F1A
M>7,B"FUS9W-T<B`B9&YI(@H*(SH@9&%T82YP:'`Z,34P('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B979E;G1S+F-S=B(*;7-G<W1R(")E
M=F5N=',N8W-V(@H*(SH@9&%T82YP:'`Z,3<Q"FUS9VED(")E=F5N=',N:6-S
M(@IM<V=S='(@(F5V96YT<RYI8W,B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$S,0IM<V=I9"`B9G)O;2(*;7-G<W1R(")O9"(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,C8*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(W('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,PIM<V=I9"`B;6]N=&@H<RDB"FUS
M9W-T<B`B;65S:6%C*&4I(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")O;B`E<R!A="`E<R(*;7-G<W1R(")59&%L
M;W.[("5S(&\@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(W"FUS9VED(")O;B!T:&4@<V%M
M92!D871E(@IM<V=S='(@(G1E;B!I<W3](&3A='5M(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S
M,PIM<V=I9"`B;VX@=&AE('-A;64@=V5E:V1A>2(*;7-G<W1R(")T96X@:7-T
M_2!D9?(@=B!T_;YD;FDB"@HC.B!D871A+G!H<#HR.2!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$T"FUS9VED(")V0V%L96YD87(O:4-A;&5N9&%R(@IM
M<V=S='(@(G9#86QE;F1A<B]I0V%L96YD87(B"@HC.B!L:6(O87!I+G!H<#HS
M-3`@;&EB+V%P:2YP:'`Z-C(Y"FUS9VED(")V179E;G0@;F]T(&9O=6YD+B(*
M;7-G<W1R(")V179E;G0@;F5B;VP@;N%J9&5N_2XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DQ"FUS9VED(")W965K(@IM<V=S='(@(G3]OF1E\B(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,30*;7-G:60@(G=E96LH<RD@;VXZ(@IM<V=S='(@(G3]
MOF1E\BAT_;YD;F4I(&YA.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PHC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DT"FUS9VED(")W965K<R(*;7-G<W1R(")T_;YD;F4B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C,Y"FUS9VED(")Y96%R*',I(@IM<V=S='(@(G)O:RAY*2(*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W!O+VQT7TQ4+G!O````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R-S<T,P`Q,#0Q
M-S,V,C<U,@`P,C`T-#,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!,:71H=6%N:6%N('1R86YS;&%T:6]N<R!F;W(@2W)O
M;F]L:71H('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R
M;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A
M;64@;&EC96YS92!A<R!T:&4@2W)O;F]L:71H('!A8VMA9V4N"B,@36%N=&%S
M(%-M96QE=FEC:75S(#QM86YT87-`;&YK+FQT/BP@,C`P,BX*(R!6:6QI=7,@
M4W5M:V%S(#QV:6QI=7-`;&YK+FQT/BP@,C`P,RP@,C`P-"X*(R`*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`R
M+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,2TS,"`Q,#HT
M,RLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%9I;&EU<R!3=6US:V%S(#QV
M:6QI=7-`;&YK+FQT/EQN(@HB3&%N9W5A9V4M5&5A;3H@3&ET:'5A;FEA;B`\
M=FEL:75S0&QN:RYL=#Y<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,3-<;B(*
M(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L
M871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)60@8V%L96YD87)S(&9O=6YD(@IM<V=S='(@(DYE<F%S
M=&$@:F]K:?@@:4-A;&5N9&%R(&1U;VUE;O@N(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@979E
M;G1S(@IM<V=S='(@(B5D(.%V>6MI86DB"@HC.B!T96UP;&%T97,O961I="]E
M9&ET7W1I;65S<&%N+FEN8SHQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M1&%Y*',I("5S($AO=7(H<RD@)7,@36EN=71E<R(*;7-G<W1R("(E<R!D:65N
M82AO<RP@^"D@)7,@=F%L86YD82AO<RP@^"D@)7,@;6EN=73K*.MS+"!I^"DB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A='1E;F1E97,B"FUS9W-T<B`B1&%L>79I^"!NZW)A(@H*
M(SH@9&%T82YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@
M<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(B5S(&9A:6QA<R!SZVMM
M:6YG86D@X6ME;'1A<R(*"B,Z(&-A;&5N9&%R<RYP:'`Z,3`U(&QI8B]B87-E
M+G!H<#HQ,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*
M;7-G<W1R("(E<R!K86QE;F1O<FEU<R(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N9&%R
M(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@
M=&AE(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V-`IM<V=I9"`B*B!!9&0@=&AE<V4@
M8GD@8VQI8VMI;F<@061D("HB"FUS9W-T<B`B*B!.;W+K9&%M:2!P<FEDZW3A
M('-P875S:VET92!0<FEDZW1I("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$U,`IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E
M<W,H97,I("HB"FUS9W-T<B`B*B!087-I<FEN:VET92!A9')E<^`H=7,I("HB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@V"B,L(&9U>GIY"FUS9VED("(Q(&%T
M=&5N9&5E(@IM<V=S='(@(D1A;'EV:?@@;NMR82(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:&5A9&5R+FEN8SHT"FUS9VED("(Q(&5V96YT(@IM<V=S='(@(C$@
MX79Y:VES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B
M,2!H;W5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S0*(RP@9G5Z>GD*;7-G:60@(C$U(&UI;G5T97,B"FUS9W-T<B`B36EN=73K
M*',I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM
M<V=I9"`B,C`@;6EN=71E<R(*;7-G<W1R(")-:6YU=.LH<RDB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,V"B,L(&9U>GIY"FUS9VED("(S,"!M:6YU
M=&5S(@IM<V=S='(@(DUI;G5TZRAS*2(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C$W,0HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY!='1E;F1E97,\
M+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\8CY$86QY=FEA:3PO8CX@
M*&YE8OMT:6YA*2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$T.0HC
M+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY$97-C<FE?<'1I;VX\+W-T<F]N9SX@
M*&]P=&EO;F%L*2(*;7-G<W1R("(\8CY?07!R8?!Y;6%S/"]B/B`H;F5B^W1I
M;F$I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C<W"B,L(&9U>GIY
M"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO<'1I;VYA;"DB
M"FUS9W-T<B`B/&(^4F%K=&EN:6%I(/YO9/YI86D\+V(^("AN96+[=&EN82DB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.30*(RP@9G5Z>GD*;7-G
M:60@(CQS=')O;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H;W!T:6]N86PI(@IM
M<V=S='(@(CQB/E!A<VEK87)T;VII;6%S/"]B/B`H;F5B^W1I;F$I(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#$@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ.#$*;7-G:60@(D%-(@IM<V=S='(@(D%-(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z-3DQ"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R(")0
M<FEI;71A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS
M9VED(")!9%]V86YC960@4V5A<F-H(@IM<V=S='(@(E]$971A;&D@<&%I9?!K
M82(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38Q('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")!9&0B
M"FUS9W-T<B`BP79E<W1I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C8*;7-G:60@(D%D9"!%=F5N="(*;7-G<W1R(").875J87,@X79Y:VES(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z
M,S4*;7-G:60@(D%D9"!A(&YE=R!296UO=&4@0V%L96YD87(B"FUS9W-T<B`B
M4W5K=7)T:2!N875JX"!N=71O;'5SX2!K86QE;F1O<FGX(@H*(SH@861D979E
M;G0N<&AP.C8T"FUS9VED(")!9&0@82!N97<@979E;G0B"FUS9W-T<B`B4W5K
M=7)T:2!N875JX"#A=GEKX2(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T
M96YD965S+FEN8SHW-`IM<V=I9"`B061D(&%T=&5N9&5E<R(*;7-G<W1R(")0
M<FEDZW1I(&1A;'EV:75S(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(P"B,Z('1E;7!L871E<R]A='1E
M;F1E97,O871T96YD965S+FEN8SHW.`IM<V=I9"`B061D<F5S<R!";V]K(@IM
M<V=S='(@(D%D<F5S^"!K;GEG96SK(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS9W-T<B`B1&5T86QI
M('!A:67P:V$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU,PIM<V=I
M9"`B06QA<FTB"FUS9W-T<B`B4&5R<W#K:FEM87,B"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ-S8T"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&1A>7,@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@:&]U<G,@8F5F;W)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%L87)M("5D(&UI;G5T97,@8F5F;W)E(@IM<V=S='(@
M(E!E<G-PZVII;6\@<&%S:6MA<G1O:FEM87,@*&UI;G5TZVUI<RDB"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ-S4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M
M("5D('=E96MS(&)E9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-S8S"FUS9VED(")!;&%R;2`Q(&1A>2!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z,3<V.`IM<V=I9"`B06QA<FT@,2!H;W5R(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<S"B,L(&9U
M>GIY"FUS9VED(")!;&%R;2`Q(&UI;G5T92!B969O<F4B"FUS9W-T<B`B4&5R
M<W#K:FEM;R!P87-I:V%R=&]J:6UA<R`H;6EN=73K;6ES*2(*"B,Z(&QI8B]$
M<FEV97(N<&AP.C$W-3@*;7-G:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@9&%T82YP:'`Z-C`*;7-G:60@(D%L87)M($1A=&4B"FUS
M9W-T<B`B4&5R<W#K:FEM;R!D871A(@H*(SH@9&%T82YP:'`Z-3D*;7-G:60@
M(D%L87)M(%-P86X@*&UI;G5T97,I(@IM<V=S='(@(E!E<G-PZVII;6\@<&%S
M:6MA<G1O:FEM87,@*&UI;G5TZVUI<RDB"@HC.B!D871A+G!H<#HV,0IM<V=I
M9"`B06QA<FT@5&EM92(*;7-G<W1R(")097)S<.MJ:6UO(&QA:6MA<R(*"B,Z
M('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS,0IM<V=I9"`B06QL(@IM
M<V=S='(@(E9I<VDB"@HC.B!L:6(O1D)6:65W+G!H<#HQ,C8@;&EB+T9"5FEE
M=RYP:'`Z,3(Y(&QI8B]&0E9I97<N<&AP.C$S,@IM<V=I9"`B06QL($%T=&5N
M9&5E<R(*;7-G<W1R(")6:7-I(&1A;'EV:6%I(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C4Y"FUS9VED(")!;&P@1G5T=7)E(@IM<V=S='(@
M(E9I<VD@8OMS:6UI(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C4S"B,L(&9U>GIY"FUS9VED(")!;&P@4&%S="(*;7-G<W1R(")6:7/@(&1I
M96[@(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(W(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,C0*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z
M,C<@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(U"FUS9VED(")!;&P@5FES:6)L
M92(*;7-G<W1R(")6:7-I(&UA=&]M:2(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC.C$R,B!L:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A
M>59I97<N<&AP.CDS"B,Z(&QI8B]7965K5FEE=RYP:'`Z,3(W(&QI8B]7965K
M5FEE=RYP:'`Z,3,T(&QI8B]$<FEV97(N<&AP.C$X,S(*;7-G:60@(D%L;"!D
M87DB"FUS9W-T<B`B5FESX"!D:65NX"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@979E;G0B"FUS9W-T<B`BP79Y:VES
M('9I<V%I(&1I96YA:2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,C$*;7-G:60@(D%L;"!E=F5N=',B"FUS9W-T<B`B5FES:2#A=GEK:6%I(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O
M2W)O;F]L:71H+G!H<#HV.#,*;7-G:60@(D%N>2(*;7-G<W1R(")"970@:W5R
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED
M(")!<')I;"(*;7-G<W1R(")"86QA;F1I<R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C,Y('1E;7!L871E<R]E9&ET+V5D:71?=&EM
M97-P86XN:6YC.CDS"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-S`@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-38*;7-G:60@(D%T(@IM<V=S
M='(@(B`B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(V"FUS9VED("(B"B)!
M='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!W:71H(&UO<F4@:6YF;W)M
M871I;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y;W5R("(*(FUA:6P@8VQI96YT
M('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@=&AI<R!F:6QE
M('1O(&5A<VEL>2!U<&1A=&4@(@HB>6]U<B!L;V-A;"!C;W!Y(&]F('1H92!E
M=F5N="XB"FUS9W-T<B`B(@HB4')I:V%B:6YT87,@9F%I;&%S('ER82!I0V%L
M96YD87(@:6YF;W)M86-I:F$@87!I92#A=GEKX2X@2F5I9W4@:OMS^"!P8?!T
M;R`B"B)K;&EE;G1A<R!P86QA:6MO(&E4:7`@=?YK;&%U<V%S+"!G86QI=&4@
M<&%N875D;W1I(/#A(&9A:6S@(&%T;F%U:FEN86YT("(*(FQO:V%L:6]S(.%V
M>6MI;R!K;W!I:F]S(&1U;VUE;FES+B(*"B,Z('1E;7!L871E<R]A='1E;F1E
M97,O871T96YD965S+FEN8SHT,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M-C4*;7-G:60@(D%T=&5N9&%N8V4B"FUS9W-T<B`B1&%L>79A=FEM87,B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C$*;7-G:60@(D%T=&5N9&5E
M<R(*;7-G<W1R(")$86QY=FEA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B4G5G<&K[=&ES
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHX"FUS9VED(")"87-I8R!3
M96%R8V@B"FUS9W-T<B`B4&%P<F%S=&]J:2!P86EE\&MA(@H*(SH@8V]N9FEG
M+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")":7)T:&1A>2(*;7-G<W1R
M(")':6UT861I96YI<R(*"B,Z(&QI8B]&0E9I97<N<&AP.CDP(&QI8B]&0E9I
M97<N<&AP.C$Q,`IM<V=I9"`B0G5S>2(*;7-G<W1R(")5_FEM=&$B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#0*;7-G:60@
M(D-?86QE;F1A<B(*;7-G<W1R(")+86Q?96YD;W)I=7,B"@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHT.0IM<V=I9"`B0V%L7V5N9&%R(@IM<V=S='(@
M(DMA;%]E;F1O<FEU<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ-#8@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(Q"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C$@;&EB+T)L;V-K+VUO;G1H;&ES="YP
M:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1O<FEU<R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HS"FUS9VED(")#86QE;F1A<B!3=6UM87)Y(@IM<V=S='(@(DMA;&5N
M9&]R:6%U<R!S86YT<G5M<&$B"@HC.B!D871A+G!H<#HR,C@*(RP@9G5Z>GD*
M;7-G:60@(D-A;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@
M(B5S(&9A:6QA<R!SZVMM:6YG86D@X6ME;'1A<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-PIM<V=I9"`B0V%L96YD87)S(@IM<V=S='(@(DMA;&5N9&]R:6%I(@H*(SH@
M8V%L96YD87)S+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87)S(&UU
M<W0@:&%V92!A(&YA;64N(@IM<V=S='(@(DMA;&5N9&]R:6%U<R!P879A9&EN
M:6UA<R(*"B,Z(&1A=&$N<&AP.C(T,PIM<V=I9"`B0V%N)W0@8W)E871E(&$@
M;F5W(&5V96YT+B(*;7-G<W1R(").97!A=GEK;R!S=6MU<G1I(&YA=6IO(.%V
M>6MI;RXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y
M,2!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S`*(SH@=&5M<&QA=&5S+V1E
M;&5T92]D96QE=&4N:6YC.C,R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,P.0IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(D%T\&%U:W1I(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<P
M"FUS9VED(")#86YC96QL960B"FUS9W-T<B`B073P875K=&%S(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3`P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YC
M96QL960Z("5S(@IM<V=S='(@(D%T\&%U:W1A.B`E<R(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV-"!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHV.0IM<V=I9"`B0V%T96=O<E]Y(@IM<V=S='(@(E]+871E
M9V]R:6IA(@H*(SH@9&%T82YP:'`Z-C,@=&5M<&QA=&5S+W-E87)C:"]E=F5N
M=%]H96%D97)S+FEN8SHT('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$S"FUS
M9VED(")#871E9V]R>2(*;7-G<W1R(")+871E9V]R:6IA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(W.0IM<V=I9"`B(@HB0VAO;W-E(&EF('EO=2!W
M86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E
M9"!E=F5N=',@8GD@(@HB96UA:6PZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O
M(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N
M=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96%R8VA?86)O
M;VM?<V5L96-T+FEN8SHQ.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDY"FUS
M9VED(")#:&]O<V4@=&AE(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H(&9O<B!F
M<F5E+V)U<WD@55),<SHB"FUS9W-T<B`B(@HB4&%S:7)I;FMI=&4@861R97/X
M(&MN>6=E;.8L(&MU<FEO:F4@:67P:V]S:71E('7^:6UT=6UO(&EN9F]R;6%C
M:6IO<R!54DPZ(@H*(SH@=&5M<&QA=&5S+W!R969S+V9B7V-A;'-?<V5L96-T
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@
M=&\@:6YC;'5D92!I;B!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;CHB"FUS
M9W-T<B`B(@HB4&%S:7)I;FMI=&4@861R97/X(&MN>6=E;.8L(&MU<FEO:F4@
M:67P:V]S:71E('7^:6UT=6UO(&EN9F]R;6%C:6IO<R!54DPZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E
M('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!W:&5N(&=E;F5R871I;F<@9G)E
M92]B=7-Y(%523',Z(@IM<V=S='(@(B(*(E!A<VER:6YK:71E(&%D<F5S^"!K
M;GEG96SF+"!K=7)I;VIE(&EE\&MO<VET92!U_FEM='5M;R!I;F9O<FUA8VEJ
M;W,@55),.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`HC+"!F=7IZ
M>0IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!C86QE;F1A<BXB"FUS9W-T
M<B`B2OMS^"!P86=R:6YD:6YI<R!K86QE;F1O<FEU<R(*"B,Z('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B
M0VQE87(@86QL(&%T=&5N9&5E<R(*;7-G<W1R("))\'1R:6YT:2!V:7-U<R!D
M86QY=FEU<R(*"B,Z(&1A=&$N<&AP.C(X('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T
M<B`B2V%B;&5L:6%I<R!A='-K:7)T;W,@<F5I:_!MZW,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S,*;7-G:60@(D-O;F9I<FT@9&5L971I;VX@;V8@
M979E;G1S/R(*;7-G<W1R(")0871V:7)T:6YT:2!V:7/X(.%V>6MI^"!I\'1R
M>6YI;>`_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-38W"FUS9VED(")#;VYF
M:7)M960B"FUS9W-T<B`B4&%T=FER=&EN=&%S(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(P.`IM<V=I9"`B0V]P>2!T:&4@55),
M(&)E;&]W(&9O<B!U<V4@=VAE<F5V97(@>6]U(&YE960@>6]U<B!&<F5E+T)U
M<WD@55),.B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S
M='(@(DYE9V%L:74@871I9&%R>71I("5S+B(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ,C8*;7-G:60@(D-R96%T92(*;7-G<W1R
M(")3=6MU<G1I(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($-A;&5N9&%R(@IM<V=S
M='(@(DYU=&]LYB!K86QE;F1O<FEA:2(*"B,Z(&UO;G1H+G!H<#HQ-C4@=&5M
M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,C4@=&5M<&QA=&5S+V1A>2]R;W<N:6YC
M.C8*(SH@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H<#HQ.30*
M;7-G:60@(D-R96%T92!A($YE=R!%=F5N="(*;7-G<W1R(")3=6MU<G1I(&YA
M=6K@(.%V>6OA(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#`*;7-G
M:60@(D-R96%T960B"FUS9W-T<B`B4W5K=7)T82(*"B,Z('1E;7!L871E<R]D
M96QE=&4O9&5L971E+FEN8SHR.0IM<V=I9"`B0W5R<F5N="(*;7-G<W1R(")%
M:6YA;6%S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(P.0IM<V=I9"`B1&%I;'DZ(%)E8W5R<R!E
M=F5R>2(*;7-G<W1R(")+87-D:65N:6YI<SH@4&%S:6MA<G1O:F$@:V%S(@H*
M(SH@871T96YD965S+G!H<#HQ,3`@;&EB+TMR;VYO;&ET:"YP:'`Z,3(X."!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#(*;7-G:60@(D1A>2(*;7-G<W1R(")$:65N82(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$S.0IM<V=I9"`B1&%Y*',I(@IM<V=S='(@(D1I96YA*&]S*2(*"B,Z('9I
M97=E=F5N="YP:'`Z,3`T"FUS9VED(")$95]L971E(@IM<V=S='(@(DGP=')I
M;G1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-SD*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(D=R=6]D:7,B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HU.30*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(E!A<VEB86EG
MYG,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0@0V%L96YD87(B"FUS9W-T<B`B2OMS^"!P86=R:6YD:6YI
M<R!K86QE;F1O<FEU<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ.3,@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M.#$*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(Y('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C(S"B,Z(&QI8B]$<FEV
M97(N<&AP.C$X,3,*;7-G:60@(D1E;&5T92(*;7-G<W1R("))\'1R:6YT:2(*
M"B,Z(&1E;&5V96YT+G!H<#HT,"!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z
M,3@@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C$X"B,Z(&QI8B]$<FEV
M97(N<&AP.C$X,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(@IM
M<V=S='(@(DGP=')I;G1I("5S(@H*(SH@961I=&5V96YT+G!H<#HW,`IM<V=I
M9"`B1&5L971E($5V96YT(@IM<V=S='(@(DGP=')I;G1I(.%V>6OA(@H*(SH@
M=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED("(B"B)$96QE
M=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E(&%N
M9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R("(*(F%L;"!O8V-U<F5N8V5S
M/R(*;7-G<W1R("))\'1R:6YT:2!T:6L@\.$@X79Y:^$L(.%V>6OA(&ER('9I
M<W5S(&+[<VEM=7,L(&%R8F$@=FES:V$_(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8VA?861V86YC960N:6YC.C$P-"!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z,C@*;7-G:60@(D1E<V-R:5]P=&EO;B(*;7-G<W1R(")?07!R
M8?!Y;6%S(@H*(SH@9&%T82YP:'`Z-C(@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C$W-0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHY
M-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B07!R8?!Y;6%S(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S,*;7-G:60@(D1I
M<W!L87DB"FUS9W-T<B`B4F]D>71I(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y($-A
M;&5N9&%R<R(*;7-G<W1R(")-86YO(&MA;&5N9&]R:6%I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS
M(@IM<V=S='(@(E9A:7ID879I;6\@;G5S=&%T>6UA:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@<VAO=R!T
M87-K<R!W:&EC:"!A<F4@9'5E(&]N('EO=7(@8V%L96YD87(_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4S-PIM<V=I9"`B1&]E<R!N;W0@
M<F5C=7(B"FUS9W-T<B`B3F5P87-I:V%R=&]J82(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")$=64Z("5S(@IM<V=S
M='(@(E1R=6MMZSH@)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHQ,34*;7-G:60@(D1U<F%T:6]N(@IM<V=S='(@(E1R=6MMZR(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S`@;&EB
M+T1R:79E<BYP:'`Z,3@P-@HC+"!F=7IZ>0IM<V=I9"`B161I="(*;7-G<W1R
M(")2961A9W5O=&DB"@HC.B!E9&ET979E;G0N<&AP.C,S('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(V(&QI8B]$<FEV97(N<&AP.C$X,#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R(")2961A9W5O=&D@)7,B"@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#<*;7-G:60@(D5D:70@071T
M96YD965S(@IM<V=S='(@(D1A;'EV:?@@<F5D86=A=FEM87,B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30P"B,L(&9U>GIY"FUS
M9VED(")%9&ET($-A;&5N9&%R<R(*;7-G<W1R(")2961A9W5O=&D@;G5T;VQU
M<VEU<R!K86QE;F1O<FEU<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-3`*;7-G:60@(D5D:70@4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R(")2961A
M9W5O=&D@;G5T;VQU<VEU<R!K86QE;F1O<FEU<R(*"B,Z(&%T=&5N9&5E<RYP
M:'`Z,34P"FUS9VED(")%9&ET(&%T=&5N9&5E<R(*;7-G<W1R(")2961A9W5O
M=&D@9&%L>79I=7,B"@HC.B!T96UP;&%T97,O8V%T96=O<GE?;&5G96YD+FEN
M8SHR,`IM<V=I9"`B161I="!C871E9V]R:65S(&%N9"!C;VQO<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S8@
M=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0Q"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$V-`IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R(")%;"X@<&'P=&\@861R97-A<R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C8P"B,L(&9U>GIY"FUS9VED(")%;E]D(@IM
M<V=S='(@(D)A:6=I87-I(@H*(SH@9&%T82YP:'`Z-3<*;7-G:60@(D5N9"!$
M871E(@IM<V=S='(@(E!A8F%I9V]S(&1A=&$B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+V5V96YT7VAE861E<G,N:6YC.C@@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#@*;7-G:60@
M(D5N9"!/;B(*;7-G<W1R(")"86EG:6%S:2(*"B,Z(&1A=&$N<&AP.C4X"FUS
M9VED(")%;F0@5&EM92(*;7-G<W1R(")086)A:6=O<R!L86EK87,B"@HC.B!A
M='1E;F1E97,N<&AP.C$R-"!A='1E;F1E97,N<&AP.C$S-2!A='1E;F1E97,N
M<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R971R:65V:6YG
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,Z("5S(@IM<V=S='(@(DYE
M9V%L:74@9V%U=&D@)7,@=F%R=&]T;VIO('7^:6UT=6UO(&EN9F]R;6%C:6IO
M<SH@)7,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DS"FUS9VED(")%=F5N
M="!A9&1E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P
M,PIM<V=I9"`B179E;G0@9&5L971E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`Y.`IM<V=I9"`B179E;G0@961I=&5D.B(*;7-G<W1R
M("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#8V"B,L('!H<"UF;W)M870*;7-G
M:60@(D5V96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`BP79Y:VES(&YU;R`E
M<R!I:VD@)7,B"@HC.B!L:6(O1')I=F5R+G!H<#HW-C0*(RP@9G5Z>GD*;7-G
M:60@(D5V96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E+B(*;7-G<W1R(")0
M86)A:6=O<R!D871A('1U<FD@8OMT:2!VZVQE<V[K(&YE9W4@<')A9/YI;W,@
M9&%T82XB"@HC.B!L:6(O1')I=F5R+G!H<#HW,S`*;7-G:60@(D5V96YT<R!M
M=7-T(&AA=F4@82!T:71L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z-S8W"FUS9VED(")%=F5N=',@;75S="!H879E(&%N(&5N9"!D871E(&]R
M(&$@9'5R871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A='1E;F1E
M97,O871T96YD965S+FEN8SHW.0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD($YA
M;65S(@IM<V=S='(@(DMA;&5N9&]R:6%U<R!P879A9&EN:6UA<R(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@W"FUS9VED(")%>'!O<G0B"FUS
M9W-T<B`B2?!K96QT:2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M.`IM<V=I9"`B17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(DGP:V5L=&D@:V%L
M96YD;W)I^"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8Y
M"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")687-A<FES(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,C@*;7-G:60@(D9I;F0B"FUS
M9W-T<B`B267P:V]T:2(*"B,Z('EE87(N<&AP.C@W('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R
M,@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B1G(B"FUS9W-T
M<B`B4&5N:RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@*(RP@9G5Z
M>GD*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O
M<FUA8VEJ;W,@;NMR82(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR
M,"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3D*(SH@=&5M<&QA=&5S+V5D
M:70O:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@(D9R:61A>2(*;7-G<W1R(")0
M96YK=&%D:65N:7,B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z
M,S`*;7-G:60@(D9U='5R92(*;7-G<W1R(")"^W-I;6%S(@H*(SH@8V]N9FEG
M+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")'86UE(@IM<V=S='(@(MYA
M:61I;6%S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N
M:6YC.C(S"FUS9VED(")'96YE<F%L(@IM<V=S='(@(E!A9W)I;F1I;FEA:2!L
M875K86DB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30P"B,L('!H<"UF
M;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`B4F]D>71I("5S(@H*(SH@
M;6]N=&@N<&AP.C$S-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED
M92YI;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3`*;7-G:60@(DAI9&4B"FUS9W-T<B`B(@H*(SH@;6]N=&@N<&AP.C$S
M-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DAI9&4@)7,B"FUS9W-T<B`B4')I;6EN
M:6UA<SH@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV-2!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ,S@*;7-G:60@(DAO=7(H<RDB"FUS9W-T
M<B`B5F%L86YD82AO<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S
M"B,L(&9U>GIY"FUS9VED(")(;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO
M=',@;VX@=&AE(&1A>2!A;F0@=V5E:R!V:65W<R!B93\B"FUS9W-T<B`B4F]D
M>71I('!U<W9A;&%N9&EN97,@_GEM97,@9&EE;F]S(&ER('-A=F%I=.MS('9A
M:7ID879I;64_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`HC+"!F
M=7IZ>0IM<V=I9"`B2&]W(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@<VAO=6QD('=E(&=E;F5R871E/R(*;7-G<W1R(")+:65K(&1I96[X
M(.$@<')I96OA(&=E;F5R=6]T:2!U_FEM='5M;R!I;F9O<FUA8VEJX#\B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#,P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(DEF('EO=7(@96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP
M(')E<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T:&4@(@HB9F]L;&]W:6YG
M(&QI;FMS('1O(&%C8V5P="!O<B!D96-L:6YE('1H92!E=F5N="Y<;B(*(EQN
M(@HB5&\@86-C97!T('1H92!E=F5N=#I<;B(*(B5S7&XB"B)<;B(*(E1O(&%C
M8V5P="!T:&4@979E;G0@=&5N=&%T:79E;'DZ7&XB"B(E<UQN(@HB7&XB"B)4
M;R!D96-L:6YE('1H92!E=F5N=#I<;B(*(B5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0@0V%L96YD87(L(%-T97`@)60B"FUS9W-T<B`B2V%L96YD;W)I
M875S(.%KZVQI;6%S+"`E9"UA<R#^:6YG<VYI<R(*"B,Z(&1A=&$N<&AP.C,R
M,`IM<V=I9"`B26UP;W)T+T5X<&]R="!#86QE;F1A<B(*;7-G<W1R("+!:V5L
M=&DO2?!K96QT:2!K86QE;F1O<FGX(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-C@*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B4V%U<VES
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S0*;7-G:60@
M(DIU;'DB"FUS9W-T<B`B3&EE<&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]G;W1O+FEN8SHW,PIM<V=I9"`B2G5N92(*;7-G<W1R(")":7+^96QI<R(*
M"B,Z(&1A=&$N<&AP.C8U('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T,@IM
M<V=I9"`B2V5Y=V]R9',B"FUS9W-T<B`BWF]D_FEA:2(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R-"!H;W5R<R(*
M;7-G<W1R(")087-K=71I;NMS(#(T('9A;&%N9&]S(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z.#<*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T
M<B`B4&%S:W5T:6[A(&MA<G3@(')E9&%G=6]T82(*"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-`HC.B!T96UP;&%T97,O;6]N
M=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,38@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C0*;7-G:60@(DQA<W0@36]N=&@B"FUS9W-T<B`B4&%S:W5T:6YI
M<R!MZVYU;R(*"B,Z('1E;7!L871E<R]Y96%R+VAE860N:6YC.C0*(RP@9G5Z
M>GD*;7-G:60@(DQA<W0@665A<B(*;7-G<W1R(")087-K=71I;NL@<V%V86ET
MZR(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-"!T96UP;&%T
M97,O=V5E:R]H96%D+FEN8SHS"FUS9VED("),87-T('=E96LB"FUS9W-T<B`B
M4&%S:W5T:6[K('-A=F%I=.LB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$W"FUS9VED("),:6UI="!T:&4@=&EM92!S<&%N('1O(&5X<&]R=#HB
M"FUS9W-T<B`B3G5S=&%T>71I(&QA:6MO('1A<G#@(&GP:V5L:6UU:3HB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z.#8@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z-S8*;7-G:60@(DQO7V-A=&EO;B(*;7-G
M<W1R(")?5FEE=&$B"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O<V5A<F-H
M+V5V96YT7VAE861E<G,N:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T
M95]C86Q?;6%N86=E;65N="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S+W)E
M;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,C$*(SH@;&EB+T1R:79E<BYP:'`Z,3@T.0IM<V=I9"`B3&]C871I
M;VXB"FUS9W-T<B`B5FEE=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#4*;7-G:60@(DUA;F%G92!R96UO=&4@8V%L96YD87)S+B(*;7-G<W1R(").
M=71O;'5S:?@@:V%L96YD;W)I^"!T=F%R:WEM87,N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S`*;7-G:60@(DUA<F-H(@IM<V=S='(@
M(DMO=F%S(@H*(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-87AI;75M($YU
M;6)E<B!O9B!%=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R(")'96=U_NLB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0V"FUS9VED(")-92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(DUE971I
M;F<B"FUS9W-T<B`B4W5S:7)I;FMI;6%S(@H*(SH@;&EB+T)L;V-K+W1R965?
M86QA<FUS+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-96YU($%L87)M<R(*;7-G
M<W1R(")097)S<.MJ:6UA<R(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP
M.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R(")-96YI=2!SX')A\&%S(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C@@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,3,W"FUS9VED(")-:6YU=&4H<RDB"FUS9W-T<B`B36EN=73K
M*',I(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C0R"FUS9VED
M(")-:7-S960@179E;G1S($QI<W0B"FUS9W-T<B`B4')A;&5I<W3X(.%V>6MI
M^"!SX')A\&%S(@H*(SH@>65A<BYP:'`Z.#,@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$X"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")-;R(*;7-G<W1R(")0
M:7)M+B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,34*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C
M<FEP="YI;F,Z-C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@IM<V=I9"`B
M36]N9&%Y(@IM<V=S='(@(E!I<FUA9&EE;FES(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3(Y,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S='(@(DWK;G5O
M(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS"FUS9VED(")-;VYT:"!6:65W
M(@IM<V=S='(@(DWK;G5O(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z
M,R!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT,PIM<V=I9"`B36]N=&AL>2!%
M=F5N=',@3&ES="(*;7-G<W1R(")-ZVYE<VEN:7,@X79Y:VGX('/@<F'P87,B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R
M.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(DUO;G1H;'DZ
M(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")+87-MZVYE<VEN:7,N($MA<G1O:F%S
M:2!K87,B"@HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B
M36]N=&AS($%H96%D(@IM<V=S='(@(DWK;F5S:6%I(.$@<')I96OA(@H*(SH@
M;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(T"FUS9VED(")-;VYT:',@
M0F5F;W)E(@IM<V=S='(@(DWK;F5S:6%I('!R:67P('1A:2(*"B,Z(&QI8B]A
M<&DN<&AP.C8Q,@IM<V=I9"`B375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O;F5N
M=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S=7!P;W)T960N(@IM<V=S
M='(@(E)A<W1I(&ME;&D@:4-A;&5N9&%R(&MO;7!O;F5N=&%I.R!P86QA:6MO
M;6%S('1I:R!V179E;G0@=&EP87,N(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8W"FUS9VED(")-
M>2!#86QE;F1A<G,B"FUS9W-T<B`B36%N;R!K86QE;F1O<FEA:2(*"B,Z('1E
M;7!L871E<R]M96YU+FEN8SHS-"!T96UP;&%T97,O;65N=2YI;F,Z,S8*;7-G
M:60@(DUY($-A;&5N9&%R<SHB"FUS9W-T<B`B36%N;R!K86QE;F1O<FEA:3HB
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C`T"B,L
M(&9U>GIY"FUS9VED(")->2!&<F5E+T)U<WD@55),(@IM<V=S='(@(E7^:6UT
M=6UA<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ
M,3<@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U.0HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W-0HC.B!T96UP;&%T
M97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHQ-PHC.B!T96UP
M;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHT-`IM<V=I
M9"`B3F%M92(*;7-G<W1R(")687)D87,B"@HC.B!L:6(O0FQO8VLO;6]N=&@N
M<&AP.C0Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0T(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HT,0HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,`IM
M<V=I9"`B3F5W($5V96YT(@IM<V=S='(@(DYA=6IA<R#A<F'P87,B"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,T"FUS9VED(").97AT(@IM<V=S
M='(@(E-E:V%N=&ES(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(E-E:V%NZ&EO<R`R
M-"!V86QA;F1O<R(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR.0IM<V=I9"`B
M3F5X="!$87DB"FUS9W-T<B`B4V5K86YT:2!D:65N82(*"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-@HC.B!T96UP;&%T97,O
M;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3@@=&5M<&QA=&5S+VUO;G1H
M+VAE860N:6YC.C8*;7-G:60@(DYE>'0@36]N=&@B"FUS9W-T<B`B4V5K86YT
M:7,@;>MN=6\B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C,R"FUS9VED(").
M97AT(%=E96LB"FUS9W-T<B`B4V5K86YT:2!S879A:73K(@H*(SH@=&5M<&QA
M=&5S+WEE87(O:&5A9"YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!996%R
M(@IM<V=S='(@(E-E:V%N=&D@9&EE;F$B"@HC.B!T96UP;&%T97,O9&%Y+VAE
M860N:6YC.C4*;7-G:60@(DYE>'0@9&%Y(@IM<V=S='(@(E-E:V%N=&D@9&EE
M;F$B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3@@=&5M<&QA
M=&5S+W=E96LO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!W965K(@IM<V=S='(@
M(E-E:V%N=&D@<V%V86ETZR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-S4*(RP@9G5Z>GD*;7-G:60@(DYO(@IM<V=S='(@(D1A8F%R(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,3(V"B,L(&9U>GIY"FUS9VED(").;R!A;&%R;2(*;7-G<W1R(")097)S
M<.MJ:6UA<R(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN
M8SHT.`IM<V=I9"`B3F\@871T96YD965S(@IM<V=S='(@(D1A;'EV:?@@;NMR
M82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,3$*;7-G:60@(DYO(&-A;&5N
M9&%R<R!A<F4@879A:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B2V%L96YD
M;W)I^"!S=F7H:6%M<R!NZW)A+B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-34*;7-G:60@(DYO
M(&5N9"!D871E(@IM<V=S='(@(D[K<F$@<&%B86EG;W,@9&%T;W,B"@HC.B!L
M:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M;VYT
M:&QI<W0N<&AP.C$V,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT"FUS
M9VED(").;R!E=F5N=',@=&\@9&ES<&QA>2(*;7-G<W1R("+!=GEK:?@@;NMR
M82(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HT,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!F<F5E+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE
M(&9O<B`E<R(*;7-G<W1R(").97!A=GEK;R!G875T:2`E<R!V87)T;W1O:F\@
M=?YI;71U;6\@:6YF;W)M86-I:F]S(@H*(SH@;&EB+V%P:2YP:'`Z,S0T(&QI
M8B]A<&DN<&AP.C8P,@IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O
M=6YD+B(*;7-G<W1R(").97)A<W1A(&IO:VGX(&E#86QE;F1A<B!D=6]M96[X
M+B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(P-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<F5C=7)R96YC92(*;7-G<W1R(")087-I:V%R=&]J:6UA<R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C@X-@IM<V=I9"`B3F\@=F%L:60@96UA
M:6P@861D<F5S<R!F;W5N9"(*;7-G<W1R(").97)A<W1A<R!T96ES:6YG87,@
M96PN('!A\'1O(&%D<F5S87,N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C`Q
M(&QI8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N92(*;7-G<W1R(").
MZW)A(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ,S8*;7-G:60@(DYO="!F
M;W5N9"(*;7-G<W1R(").97)A<W1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Q"B,L(&9U>GIY"FUS9VED(").;W1I9FEC871I;VYS(@IM<V=S='(@
M(E9I971A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S@*
M;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DQA<&MR:71I<R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-@IM<V=I9"`B3F]W(@IM<V=S='(@
M(D1A8F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S<*
M;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B4W!A;&ES(@H*(SH@=&5M<&QA=&5S
M+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S@*;7-G:60@(D]N(&%L;"!C86QE;F1A
M<G,@22!H879E(')E860@86-C97-S('1O(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-S<*(RP@9G5Z>GD*;7-G:60@(D]N(&%L;"!S
M:&]W;B!C86QE;F1A<G,B"FUS9W-T<B`B3G5T;VQU<VGX(&MA;&5N9&]R:?@@
M='9A<FMY;6%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S8*(RP@
M9G5Z>GD*;7-G:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY(@IM<V=S='(@(DUA
M;F\@:V%L96YD;W)I86DB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,3D*;7-G
M:60@(D]P=&EO;F%L(@IM<V=S='(@(DYE8OMT:6YA<R(*"B,Z(&QI8B]&0E9I
M97<N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B3W!T:6]N86P@071T96YD965S
M(@IM<V=S='(@(D1A;'EV875T:2!N96+[=&EN82(*"B,Z(&QI8B]&0E9I97<N
M<&AP.C$U,@IM<V=I9"`B3W9E<G9I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,S0*;7-G:60@(D]W;F5R(@IM<V=S='(@(E-A
M=FEN:6YK87,B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")/=VYE<CH@)7,B"FUS9W-T<B`B4V%V:6YI;FMA
M<R(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`R('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3@R"FUS9VED(")032(*;7-G<W1R(")032(*
M"B,Z(&1A=&$N<&AP.C(Y('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30*
M;7-G:60@(E!A;&T@1&%T94)O;VLB"FUS9W-T<B`B4&%L;2!K86QE;F1O<FEU
M<R`H1&%T94)O;VLI(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP
M.C,*;7-G:60@(E!A<W0@179E;G1S($QI<W0B"FUS9W-T<B`B4')AZVIU<VGX
M(.%V>6MI^"!SX')A\&%S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3`Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y.`IM<V=I9"`B4&%T=&5R
M;B(*;7-G<W1R(")087-I:V%R=&]J:6UA:2(*"B,Z('1E;7!L871E<R]D96QE
M=&4O;VYE+FEN8SHR-PIM<V=I9"`B4&5R;6%N96YT;'D@9&5L971E('1H:7,@
M979E;G0_(@IM<V=S='(@(DGP=')I;G1I(/#A(.%R8?#@/R(*"B,Z(&QI8B]A
M<&DN<&AP.C,R-2!L:6(O87!I+G!H<#HT,3D@;&EB+V%P:2YP:'`Z-#@Q(&QI
M8B]A<&DN<&AP.C4U,PHC.B!L:6(O87!I+G!H<#HU.#0@;&EB+V%P:2YP:'`Z
M-C<P(&QI8B]A<&DN<&AP.C<P-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`B3F5U_G1E;FMA('1E:7-I^"(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ-C<*;7-G:60@(E!E<FUI<W-I;VYS(@IM
M<V=S='(@(E1E:7/K<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0IM
M<V=I9"`B4&]R=&%L($]P=&EO;G,B"FUS9W-T<B`B4&]R=&%L;R!N=7-T871Y
M;6%I(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(U"FUS9VED(")0<F5V:6]U
M<R!$87DB"FUS9W-T<B`B06YK<W1E<V[K(&1I96YA(@H*(SH@;&EB+T9"5FEE
M=R]W965K+G!H<#HR-@IM<V=I9"`B4')E=FEO=7,@5V5E:R(*;7-G<W1R(")!
M;FMS=&5S;FES('!U<VQA<&ES(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN
M8SHS"FUS9VED(")0<F5V:6]U<R!D87DB"FUS9W-T<B`B5F%K87(@9&EE;F$B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S4@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C4R"FUS9VED(")296-U<B!5;G1I;"(*;7-G<W1R(")0
M87-I:V%R=&]J82!I:VDB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,#8*;7-G:60@(E)E8W5R<F5N8V4B"FUS9W-T<B`B4&%S:6MA<G1O:FEM87,B
M"@HC.B!D871A+G!H<#HV.0IM<V=I9"`B4F5C=7)R96YC92!$871A(@IM<V=S
M='(@(E!A<VEK87)T;VII;6\@9&%T82(*"B,Z(&1A=&$N<&AP.C8W"FUS9VED
M(")296-U<G)E;F-E($5N9"!$871E(@IM<V=S='(@(E!A<VEK87)T;VII;6\@
M<&%B86EG;W,@9&%T82(*"B,Z(&1A=&$N<&AP.C8X"FUS9VED(")296-U<G)E
M;F-E($EN=&5R=F%L(@IM<V=S='(@(E!A<VEK87)T;VII;6\@9&'^;G5M87,B
M"@HC.B!D871A+G!H<#HV-@IM<V=I9"`B4F5C=7)R96YC92!4>7!E(@IM<V=S
M='(@(E!A<VEK87)T;VII;6\@8OMD87,B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU-#`*;7-G:60@(E)E8W5R<R!D86EL>2(*;7-G<W1R(")086MA<G1O=&D@
M:V%S(&1I96[@(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30W"FUS9VED(")2
M96-U<G,@;6]N=&AL>2(*;7-G<W1R(")086MA<G1O=&D@:V%S(&WK;F5SX2(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T,PIM<V=I9"`B4F5C=7)S('=E96ML
M>2(*;7-G<W1R(")086MA<G1O=&D@:V%S('-A=F%I=.8B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU-3`*;7-G:60@(E)E8W5R<R!Y96%R;'DB"FUS9W-T<B`B
M4&%K87)T;W1I(&MA<R!M971U<R(*"B,Z(&QI8B]38VAE9'5L97(O:W)O;F]L
M:71H+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M:6YD97(Z("5S
M(@IM<V=S='(@(E!R:6UI;FEM87,Z("5S(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.CDQ(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-`IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R(").=71O;.8@:V%L
M96YD;W)I86DB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-C`@=&5M<&QA=&5S
M+VUE;G4N:6YC.C8R"FUS9VED(")296UO=&4@0V%L96YD87)S.B(*;7-G<W1R
M(").=71O;.8@:V%L96YD;W)I86DZ(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E
M<R]A='1E;F1E97,N:6YC.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V
M92`E<R(*;7-G<W1R("))\'1R:6YT:2`E<R(*"B,Z(&%T=&5N9&5E<RYP:'`Z
M,3`T"FUS9VED(")296UO=F4@071T96YD964B"FUS9W-T<B`B4&'P86QI;G1I
M(&1A;'EV:75S(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,@IM
M<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I
M;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S
M(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N
M9SXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C(V"FUS9VED
M(")297%U:7)E9"(*;7-G<W1R(")0<FEV86QO;6%S(@H*(SH@;&EB+T9"5FEE
M=RYP:'`Z.3@@;&EB+T9"5FEE=RYP:'`Z,3,W(&QI8B]&0E9I97<N<&AP.C$T
M,"!L:6(O1D)6:65W+G!H<#HQ-#,*;7-G:60@(E)E<75I<F5D($%T=&5N9&5E
M<R(*;7-G<W1R(")"^W1I;FD@9&%L>79I86DB"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHS-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,3`*;7-G
M:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(D%T<W1A='ET:2(*"B,Z
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,R!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ-C8*;7-G:60@(E)E<W!O;G-E(@IM<V=S='(@
M(D%T<V%K>6UA<R(*"B,Z('EE87(N<&AP.C@X('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,PHC
M.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B4V$B"FUS9W-T<B`B
MT&7P="XB"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C$@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3(P"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S
M8W)I<'0N:6YC.C<S"FUS9VED(")3871U<F1A>2(*;7-G<W1R("+09?!T861I
M96YI<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ
M.3(*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`BT&7P="XB"@HC.B!V
M:65W979E;G0N<&AP.C$Q."!E9&ET979E;G0N<&AP.C0X(&5D:71E=F5N="YP
M:'`Z-38*;7-G:60@(E-A=F4@07,@3F5W(@IM<V=S='(@(DGP<V%U9V]T:2!K
M86EP(&YA=6K@(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C@W"B,L(&9U>GIY"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G<W1R
M(")$86QY=FEA:2(*"B,Z(&%D9&5V96YT+G!H<#HU-2!E9&ET979E;G0N<&AP
M.C4Q"FUS9VED(")3879E($5V96YT(@IM<V=S='(@(DGP<V%U9V]T:2#A=GEK
MX2(*"B,Z('-E87)C:"YP:'`Z.3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.C$Q-0HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z-C<@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C@*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-#`@;&EB+T)L;V-K+W1R
M965?;65N=2YP:'`Z,C8*;7-G:60@(E-E87)C:"(*;7-G<W1R("))9?!K;W1I
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$*(RP@9G5Z
M>GD*;7-G:60@(E-E87)C:"!#86QE;F1A<G,B"FUS9W-T<B`B0F5N9')I(&MA
M;&5N9&]R:6%I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C8*
M(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(DEE\&MO
M=&DB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z-@IM<V=I
M9"`B4V5A<F-H(&9O<B!C86QE;F1A<G,@8V]N=&%I;FEN9SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U,`HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@8V%L96YD87(@=&\@961I="(*;7-G
M<W1R(")087-I<FEN:VET92!K86QE;F1O<FGX(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C8X('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S
M"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E!A<VER:6YK:71E(&1A
M=.`B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!C86QE;F1A<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B4&%S:7)I
M;FMI=&4@:V%L96YD;W)I^"#A:^ML:6UU:3HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$*;7-G:60@(B(*(E-E;&5C="!C;VYF:7)M871I;VX@;W!T
M:6]N<RP@:&]W('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@
M8VAO;W-E("(*(F1E9F%U;'0@=FEE=RXB"FUS9W-T<B`B(@HB4&%T=FER=&EN
M:6UO(&YU<W1A='EM^"P@=F%I>F1A=FEM;R!B^V3X(&ER('-T86YD87)T:6YI
M;R!V86EZ9&%V:6UO("(*(G!A<VER:6YK:6UA<RXB"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$Y"FUS9VED(")396QE8W0@=&AE(&-A;&5N9&%R
M('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B4&%S:7)I;FMI=&4@:V%L96YD;W)I
M^"#A:^ML:6UU:3HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R
M"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E!A
M<VER:6YK:71E(&GP:^ML:6UO(&9O<FUA=.`Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHR.`IM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM
M<&]R=#HB"FUS9W-T<B`B4&%S:7)I;FMI=&4@9F%I;.`@X6OK;&EM=6DZ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B4V5L96-T('1H
M92!F:7)S="!W965K9&%Y.B(*;7-G<W1R(")087-I<FEN:VET92!P:7)MX"#P
M:6]K:6%D:65NX3HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q
M"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z
M(@IM<V=S='(@(E!A<VER:6YK:71E(.%K96QI86UO(&9A:6QO(&9O<FUA=.`Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T
M('1H92!T:6UE('-P86X@=&\@<VAO=SHB"FUS9W-T<B`B4&%S:7)I;FMI=&4@
M;&%I:V\@=&%R<.`@<F]D>6UU:3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#8*;7-G:60@(E-E;&5C="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N('-T
M87)T=7`Z(@IM<V=S='(@(E!A<VER:6YK:71E('9A:7ID879I;6\@8OMDX"!P
M;R!P<FES:6IU;F=I;6\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M"FUS9VED(")396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@:6X@=&AE('!O
M<G1A;"XB"FUS9W-T<B`BP79Y:VGX(')O9'EM;R!P;W)T86QE('!A<VER:6YK
M:6UA<RXB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C0@=&5M<&QA
M=&5S+V1E;&5T92]D96QE=&4N:6YC.C(T"FUS9VED(")396YD(&$@8V%N8V5L
M(&YO=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@
M=&AI<R!E=F5N="(*;7-G<W1R(")4<FEN86YT+"!V:7-I96US(&1A;'EV:6%M
M<R!I\'-I^'-T:2!P<F%N9?!I;>`@87!I92#A=GEK:6\@;G5T<F%U:VEMX"(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")396YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@(DGP<VGX<W1I
M(&QA:?!KX"`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$X,0IM
M<V=I9"`B4V5N9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L;"!A='1E;F1E
M97,@=VAE;B!S879I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"B))\'-A=6=A
M;G0L('9I<VEE;7,@9&%L>79I86US(&GP<VGX<W1I('!R86YE\&EM82!A<&EE
M(.%V>6MI;R!A=&YA=6II;FEMX"\B"B)S=6O[<FEMX"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-@IM<V=I9"`B4V5P=&5M8F5R(@IM
M<V=S='(@(E)U9W/K:FES(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE
M<W!A;BYI;F,Z.#,*;7-G:60@(E-E="!E;F0@9&%T92(*;7-G<W1R(").=7)O
M9'EK:71E('!A8F%I9V]S(&1A=.`B"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR-C@*;7-G:60@(E-E="!R96-U<G)E;F-E(&5N9"!D871E(@IM<V=S
M='(@(DYU<F]D>6MI=&4@<&%S:6MA<G1O:FEM;R!P86)A:6=O<R!D873@(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,S$*;7-G:60@
M(E-E="!S=&%R="!D871E(@IM<V=S='(@(DYU<F]D>6MI=&4@<')A9/YI;W,@
M9&%TX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.0IM<V=I9"`B(@HB
M4V5T('EO=7(@9G)E92]B=7-Y(&-A;&5N9&%R<R!A;F0@>6]U<B!O=VX@86YD
M(&]T:&5R('5S97)S)R!F<F5E+V)U<WD@;W!T:6]N<RXB"FUS9W-T<B`B(@H*
M(SH@8V%L96YD87)S+G!H<#HW-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4VAA<F4@;F]T(&9O=6YD.B`E<R(*;7-G<W1R(")V179E;G0@;F5R87-T
M87,N(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C<Y
M"FUS9VED(")3:&%R960@0V%L96YD87)S(@IM<V=S='(@(D)E;F1R:2!K86QE
M;F1O<FEA:2(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHT-R!T96UP;&%T97,O
M;65N=2YI;F,Z-#D*;7-G:60@(E-H87)E9"!#86QE;F1A<G,Z(@IM<V=S='(@
M(D)E;F1R:2!K86QE;F1O<FEA:3HB"@HC.B!C86QE;F1A<E]S96%R8V@N<&AP
M.C(U('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHS"B,Z
M('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD;W)I=7,B
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,C(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-H;W<@8V%L96YD87(@7"(E<UPB(@IM
M<V=S='(@(D)E;F1R:2!K86QE;F1O<FEA:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-38*;7-G:60@(E-H;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G
M<W1R(")2;V1Y=&D@:V%T96=O<FEJ^"!S<&%L=O@@<F5I:_!M97,_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B4VAO=R!D96QE=&4L
M(&%L87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I;B!C86QE;F1A<B!V:65W
M<S\B"FUS9W-T<B`B4F]D>71I('1R>6YI;6\L('!E<G-PZVII;6\@:7(@<&%S
M:6MA<G1O:FEM;R!P:6MT;V=R86UA<R!K86QE;F1O<FEU:F4_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S:W,@
M:6X@=&AE(&-A;&5N9&%R/R(*;7-G<W1R(")2;V1Y=&D@96EN86UU<R!D87)B
M=7,@:V%L96YD;W)I=6IE/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C8*;7-G:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N9#\B"FUS9W-T<B`B4F]D
M>71I('7^:6UT=6UO(&EN9F]R;6%C:6IO<R!S<&%L=O@@<F5I:_!M97,_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,PIM<V=I9"`B4VAO=R!O;FQY
M(&5V96YT<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/R(*;7-G<W1R(")!<B!R
M;V1Y=&D@=&EK('1U;W,@=F5I:W-M=7,@:W5R:64@='5R:2!P97)S<.MJ:6UO
M(/YY;>8_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-0HC+"!F=7IZ
M>0IM<V=I9"`B4VAO=R!S:&%R960@8V%L96YD87)S('-I9&4M8GDM<VED93\B
M"FUS9W-T<B`B4F]D>71I(&)E;F1R=7,@:V%L96YD;W)I=7,@=FEE;N`@\&%L
M:6$@:VET;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@=&%S:W,@=7-I;F<@8V%T96=O<GD@8V]L;W)S/R(*
M;7-G<W1R(")2;V1Y=&D@96EN86UU<R!D87)B=7,@:V%L96YD;W)I=6IE/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B4VAO=R!T:6UE
M(&]F(&1A>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_(@IM<V=S
M='(@(E-A=F%I=.MS(')E_FEM92!R;V1Y=&D@=&%R<.`@=&%R<"!D:65N^#\B
M"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,0HC+"!F
M=7IZ>0IM<V=I9"`B4W1A7W)T(@IM<V=S='(@(E!R87-I9&5D82(*"B,Z(&1A
M=&$N<&AP.C4U"FUS9VED(")3=&%R="!$871E(@IM<V=S='(@(E!R863^:6]S
M(&1A=&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC
M.C<@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHR-0IM<V=I9"`B4W1A<G0@3VXB"FUS9W-T<B`B4')A
M<VED961A(@H*(SH@9&%T82YP:'`Z-38*;7-G:60@(E-T87)T(%1I;64B"FUS
M9W-T<B`B4')A9/YI;W,@;&%I:V%S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.CDU('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C@U"FUS9VED(")3=&%T7W5S(@IM<V=S='(@(E]"^W-E;F$B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C8@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T871U<R(*;7-G<W1R(")"^W-E;F$B
M"@HC.B!Y96%R+G!H<#HX,2!Y96%R+G!H<#HY,"!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHV-0HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,C0@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#<@;&EB+T)L;V-K+VUO;G1H+G!H
M<#HQ,#D*;7-G:60@(E-U(@IM<V=S='(@(E-E:VTN(@H*(SH@=&5M<&QA=&5S
M+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR
M,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA=&5S+V5D
M:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(E-E:VUA9&EE;FES(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS9VED(")487-K<R(*;7-G<W1R
M(")$87)B86DB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S0@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3DW"FUS9VED(")496YT871I=F4B"FUS9W-T<B`B0F%N9&]M
M87-I<R(*"B,Z('EE87(N<&AP.C@V('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,0HC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS9W-T<B`B2V5T=BXB
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C<P"FUS9VED
M(")4:&4@161I="!!='1E;F1E97,@<V-R965N(&ES(&YO(&QO;F=E<B!P<F5S
M96YT+B!%>&ET:6YG+B(*;7-G<W1R(")$86QY=FGX(')E9&%G879I;6\@;&%N
M9V%S('7^9&%R>71A<RX@2?!E:6YU+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!C86YN
M;W0@8F4@9&5L971E9"XB"FUS9W-T<B`B2V%L96YD;W)I875S(%PB)7-<(B!N
M96GP=')I;G1A<RXB"@HC.B!C86QE;F1A<G,N<&AP.C0P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N
M(&-R96%T960N(@IM<V=S='(@(DMA;&5N9&]R:75S(%PB)7-<(B!I\'1R:6YT
M87,N(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(DMA;&5N9&]R:75S(%PB)7-<(B!I\'1R:6YT87,N(@H*(SH@8V%L96YD
M87)S+G!H<#HU-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@
M7"(E<UPB(&AA<R!B965N(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")+
M86QE;F1O<FEU<R!<(B5S7"(@<&5R=F%D:6YT87,@X2!<(B5S7"(N(@H*(SH@
M8V%L96YD87)S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L
M96YD87(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")+86QE;F1O
M<FEU<R!<(B5S7"(@:?!S875G;W1A<RXB"@HC.B!D871A+G!H<#HR,C8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!C;W5L9"!N
M;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R(")+86QE;F1O<FEA=7,@7"(E<UPB
M(&YE:?!T<FEN=&%S+B(*"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N
M:6YC.C$V,PIM<V=I9"`B5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA
M;B!T:&4@<W1A<G0@9&%T92XB"FUS9W-T<B`B4&%B86EG;W,@9&%T82!T=7)I
M(&+[=&D@=NML97-NZR!N96=U('!R863^:6]S(&1A=&$N(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`Y-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!A9&1E9"P@=VAI8V@@:7,@;VX@
M)7,@870@)7,N(@IM<V=S='(@(DMA;&5N9&]R:75S(%PB)7-<(B!P97)V861I
M;G1A<R#A(%PB)7-<(BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3`T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960L('=H:6-H('=A<R!O;B`E<R!A="`E<RXB"FUS9W-T
M<B`B2V%L96YD;W)I=7,@7"(E<UPB(&GP=')I;G1A<RXB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,#DY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"P@=VAI8V@@:7,@;VX@
M)7,@870@)7,N(@IM<V=S='(@(DMA;&5N9&]R:75S(%PB)7-<(B!P97)V861I
M;G1A<R#A(%PB)7-<(BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#8W"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@
M)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+B(*;7-G<W1R(")0<F%N9?!I;6%S
M(&%P:64@X79Y:^$@<^MK;6EN9V%I(&GP<VGX<W1A<R`E<RXB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#(T"FUS9VED(")4:&4@9F]L;&]W:6YG(&ES(&$@
M;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z(@IM<V=S
M='(@(D1E=&%L97-N:7,@X79Y:VEO(&%P<F'P>6UA<SHB"@HC.B!A='1E;F0N
M<&AP.C0Q"FUS9VED("(B"B)4:&4@<F5Q=65S="!W87,@:6YC;VUP;&5T92X@
M4V]M92!P87)A;65T97)S('1H870@87)E(&YE8V5S<V%R>2!T;R!A8V-E<'0@
M;W(@(@HB9&5C;&EN92!A;B!E=F5N="!A<F4@;6ES<VEN9RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E;7!T>2YI;F,Z,PIM<V=I9"`B5&AE
M<F4@87)E(&YO(&5V96YT<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I
M82XB"FUS9W-T<B`BP79Y:VGX(&%T:71I;FMA;NAI^"!P86EE\&MO<R!K<FET
M97)I:G5S(&[K<F$N(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C$X(&5D:71E
M=F5N=&%C=&EO;BYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S(@IM<V=S
M='(@(DML86ED82!A=&ED87)A;G0@:V%L96YD;W)I^#H@)7,B"@HC.B!A9&1E
M=F5N=&%C=&EO;BYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(DML
M86ED82!P<FED961A;G0@X79Y:^$Z("5S(@H*(SH@961I=&5V96YT86-T:6]N
M+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@961I=&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(DML86ED82!R961A
M9W5O:F%N="#A=GEKX3H@)7,B"@HC.B!L:6(O87!I+G!H<#HS,S@@;&EB+V%P
M:2YP:'`Z-3DV"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B2VQA:61A(.%K96QI86YT
M(&E#86QE;F1A<B!D=6]M96YI<RXB"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP
M.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!M
M;W9I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")+;&%I9&$@<&5R:V5L:6%N
M="#A=GEKX3H@)7,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG(&%N
M(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<SH@)7,B"FUS9W-T<B`B2VQA:61A
M('-I=6[H:6%N="!P<F%N9?!I;>`@87!I92#A=GEKX2`E<SH@)7,B"@HC.B!D
M871A+G!H<#HQ,#4*;7-G:60@(E1H97)E('=E<F4@;F\@979E;G1S('1O(&5X
M<&]R="XB"FUS9W-T<B`BP79Y:VGX(&GP:^ML:6UU:2!NZW)A+B(*"B,Z(&1A
M=&$N<&AP.C$X-`IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(")&86EL;R!F;W)M871A<R!N97!A;&%I:V]M87,N
M(@H*(SH@9&%T82YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(E-E<G9E<FEO
M('!R86YE\&EM87,@=&]K<SH@)7,B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A
M9"YI;F,Z,3D@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$X"B,Z('1E;7!L
M871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<Q"FUS9VED(")4:'5R<V1A>2(*
M;7-G<W1R(")+971V:7)T861I96YI<R(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHS-PIM<V=I9"`B5&EM92!3<%]A;B(*;7-G<W1R("),86EK
M7V\@=&%R<&%S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z-`IM<V=I9"`B5&EM92!S<&%N(@IM<V=S='(@(DQA:6MO('1A<G!A<R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHS-B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHT,`IM<V=I9"`B5&ET7VQE(@IM<V=S
M='(@(E!A=F%D:6YI7VUA<R(*"B,Z(&1A=&$N<&AP.C4T('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT
M7VAE861E<G,N:6YC.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@(E!A=F%D:6YI
M;6%S(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R,B!L:6(O
M0FQO8VLO;6]N=&AL:7-T+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$R-PIM<V=I9"`B5&]D87DB"FUS9W-T<B`BT&EA;F1I96XB"@HC.B!L
M:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(T(&QI8B]";&]C:R]M;VYT
M:&QI<W0N<&AP.C$R,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(Y"FUS
M9VED(")4;VUO<G)O=R(*;7-G<W1R(")2>71O:B(*"B,Z('EE87(N<&AP.C@T
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8P('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM
M<V=I9"`B5'4B"FUS9W-T<B`B06YT<BXB"@HC.B!T96UP;&%T97,O;6]N=&@O
M:&5A9"YI;F,Z,3<@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$V"B,Z('1E
M;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8Y"FUS9VED(")4=65S9&%Y
M(@IM<V=S='(@(D%N=')A9&EE;FES(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H
M<"YD:7-T.C$W"FUS9VED(")4>7!E(@IM<V=S='(@(E1I<&%S(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$X,PIM<V=I9"`B55),
M(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYE
M<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4U%,('-E<G9E<FEO+B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I
M(%PB)7-<(CH@)7,B"@HC.B!L:6(O1')I=F5R+VUC86PN<&AP.C$S-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+B(*;7-G<W1R
M(").97!A=GEK;R!I\'1R:6YT:2`E<RXB"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E
M9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DYE<&%V>6MO('7^:W)A=71I("5S
M(&%P<F'P>6UO+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!<(B5S7"(Z("5S(@IM<V=S='(@
M(DYE<&%V>6MO('!E<G9A9&EN=&D@7"(E<UPB.B`E<R(*"B,Z(&QI8B]3=&]R
M86=E+VMO;&%B+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G
M<W1R(").97!A=GEK;R!G875T:2`E<R!V87)T;W1O:F\@=?YI;71U;6\@:6YF
M;W)M86-I:F]S('-E<G9E<GEJ92(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$U"B,Z('-C<FEP=',O=7!G<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T
M7V-A=&5G;W)I97-?=&]?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E5N9FEL960B
M"FUS9W-T<B`B3F5N=7)O9'ET82(*"B,Z(&QI8B]A<&DN<&AP.C,W-B!L:6(O
M87!I+G!H<#HT-3`@;&EB+V%P:2YP:'`Z-3$V(&QI8B]A<&DN<&AP.C8R,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N
M="U4>7!E.B`E<R(*;7-G<W1R(").96%T<&'^:6YT87,@9'5O;65N^"!T:7!A
M<RXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#$T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5P9&%T960Z("5S+B(*;7-G<W1R(")!=&YA=6II;G1A.B`E<RXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*;7-G:60@(E5S97(@26YT
M97)F86-E(@IM<V=S='(@(E9A<G1O=&]J;R!SX'-A:F$B"@HC.B!Y96%R+G!H
M<#HQ-C,@>65A<BYP:'`Z,38Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,38R"FUS9VED(")6:65W($1A>2(*;7-G<W1R
M(")2;V1Y=&D@9&EE;N`B"@HC.B!Y96%R+G!H<#HX-2!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV,2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,C`*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E=E(@IM<V=S
M='(@(E1R9>@N(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$X('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-PHC.B!T96UP;&%T97,O961I="]J
M879A<V-R:7!T+FEN8SHW,`IM<V=I9"`B5V5D;F5S9&%Y(@IM<V=S='(@(E1R
M9>AI861I96YI<R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$R(&QI8B]+<F]N;VQI
M=&@N<&AP.C$R.3`@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C,*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED(")7965K(@IM<V=S='(@(E-A
M=F%I=.LB"@HC.B!M;VYT:"YP:'`Z,3<Y('=O<FMW965K+G!H<#HS,"!W965K
M+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7965K("5D(@IM<V=S='(@
M(B5D('-A=F%I=.LB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU.2!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#`*;7-G:60@(E=E96LH<RDB"FUS
M9W-T<B`B4V%V86ETZRAS*2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$R,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,34*;7-G:60@(E=E96ML
M>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(DMA<W-A=F%I=&EN:7,N($MA<G1O
M:F%S:2!K87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED
M("(B"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L
M('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\B"FUS9W-T<B`B2W5R
M:2!V86QA;F1A(&1A<F)O(&1I96YO;6ES(&ER('-A=F%I=&=A;&EA:7,@>7)A
M('!A<VMU=&ENZS\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS
M9VED("(B"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S
M=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_(@IM<V=S
M='(@(DME;&EN=.`@=F%L86YD82!P<F%S:61E9&$@9&%R8F\@9&EE;F$@:7(@
M<V%V86ET9V%L:7,_(@H*(SH@871T96YD965S+G!H<#HQ,3$@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3(X.2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E=O<FL@5V5E:R(*;7-G
M<W1R(")$87)B;R!S879A:73K(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y
M,B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B
M665A<B(*;7-G<W1R("))9?!K;W1I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T,0IM<V=I9"`B
M665A<FQY.B!296-U<G,@979E<GDB"FUS9W-T<B`B2V%S;65T:6YI<RX@2V%R
M=&]J87-I(&MA<R(*"B,Z(&1A=&$N<&AP.C0P(&1A=&$N<&AP.C(S-"!E9&ET
M979E;G1A8W1I;VXN<&AP.C0V(&%D9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@979E;G1S+B(*;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Y
M"FUS9VED(")9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF
M:65D(&5V96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C<V"FUS9VED(")9;W4@8V%N(&]N;'D@=7-E('1H:7,@
M9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN(@IM<V=S='(@
M(M!IX"!F;W)MX"!G86QI=&4@;F%U9&]T:2!T:6L@:?`@9&%L>79I^"!R961A
M9V%V:6UO(&QA;F=O+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.CDW,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1O(&YO="!H879E(&%N
M(&5M86EL(&%D9')E<W,@8V]N9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN
M9F]R;6%T:6]N("(*(D]P=&EO;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H97)E
M)7,@8F5F;W)E(&5V96YT(&YO=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N(@IM
M<V=S='(@(B(*(E-A=F\@;G5S=&%T>6UU;W-E(&YE;G5R;V3K=&4@:F]K:6\@
M96PN('!A\'1O(&%D<F5S;RX@4')I9?`@<VGX<V1A;6D@(@HB<')A;F7P:6UU
M<RP@='5R:71E(.%R8?!Y=&D@8F5N="!V:65NX"XB"@HC.B!A9&1E=F5N=&%C
M=&EO;BYP:'`Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E<RXB"FUS9W-T<B`B
M2OMS(&YE='5R:71E('1E:7-I^"!P<FEDZW1I(.%V>6MI^"!P<FEE("5S+B(*
M"B,Z(&1A=&$N<&AP.C$Y-`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI
M<W-I;VX@=&\@861D(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L96YD87(N
M(@IM<V=S='(@(DK[<R!N971U<FET92!T96ES:?@@<')I9.MT:2#A=GEK:?@@
MX2!P87-I<FEN:W3@(&MA;&5N9&]R:?@N(@H*(SH@9&5L979E;G1A8W1I;VXN
M<&AP.C(V"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!D
M96QE=&4@=&AI<R!E=F5N="XB"FUS9W-T<B`B2OMS(&YE='5R:71E('1E:7-I
M^"!I\'1R:6YT:2#P:6\@X79Y:VEO+B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP
M:'`Z-S@*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&5D
M:70@=&AI<R!E=F5N="XB"FUS9W-T<B`B2OMS(&YE='5R:71E('1E:7-I^"!R
M961A9W5O=&D@\&EO(.%V>6MI;RXB"@HC.B!D871A+G!H<#HQ.#D*;7-G:60@
M(EEO=2!H879E('-P96-I9FEE9"!A;B!I;G9A;&ED(&-A;&5N9&%R+B(*;7-G
M<W1R(")*^W,@;G5R;V3K=&4@;F5T96ES:6YGX"!K86QE;F1O<FGX+B(*"B,Z
M(&%T=&5N9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!A
M8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(B(*
M"B,Z(&%T=&5N9"YP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E('-U
M8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N
M(@IM<V=S='(@(DK[<R!N971U<FET92!T96ES:?@@:?!T<FEN=&D@\&EO(.%V
M>6MI;RXB"@HC.B!A='1E;F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")9;W4@
M:&%V92!T96YT871I=F5L>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@
M979E;G0N(@IM<V=S='(@(DK[<R!N971U<FET92!T96ES:?@@:?!T<FEN=&D@
M\&EO(.%V>6MI;RXB"@HC.B!C86QE;F1A<G,N<&AP.CDQ"FUS9VED(")9;W4@
M;75S="!S96QE8W0@82!C86QE;F1A<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R
M(").=7)O9'EK:71E(&MA;&5N9&]R:?@L(&MU<FG@(&YO<FET92!I\'1R:6YT
M:2XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C4T"FUS
M9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T
M<B`B5FES^"!P:7)M82!R96EK:6$@;G5R;V1Y=&D@861R97/@+B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P.30*;7-G:60@(EEO=2!R97%U97-T960@=&\@
M8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&%D9&5D('1O('EO=7(@8V%L
M96YD87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3`T
M"FUS9VED("(B"B)9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@
M979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U<B!C86QE;F1A<G,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3D*;7-G:60@(EEO=2!R
M97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&5D:71E
M9"!I;B!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+U-C:&5D
M=6QE<B]K<F]N;VQI=&@N<&AP.C(P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!R96UI;F1E9"!A8F]U="`E<RP@
M=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S='(@(DK[<R!P<F'PZW1E('!R
M:6UI;G1I(&%P:64@)7,L(&MU<FES(&)U<R`E<RXB"@HC.B!T96UP;&%T97,O
M<')E9G,O<VAA<F5S96QE8W0N:6YC.C$P"FUS9VED(")9;W5R(&1E9F%U;'0@
M8V%L96YD87(B"FUS9W-T<B`B2OMS^"!P86=R:6YD:6YI<R!K86QE;F1O<FEU
M<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-3,@;&EB+T1R:79E<BYP:'`Z,3`V
M,PIM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(EM.9>%V87)D:6YT
M87,@X79Y:VES72(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.CDW"B,L
M(&9U>GIY"FUS9VED(")?06QA<FTB"FUS9W-T<B`B4&5R<W#K:FEM87,B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$*;7-G
M:60@(E]"87-I8R!396%R8V@B"FUS9W-T<B`B4&%P<F%?<W1O:FD@<&%I9?!K
M82(*"B,Z('9I97=E=F5N="YP:'`Z,3(P"FUS9VED(")?161I="(*;7-G<W1R
M(")2961A9W5O=&DB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,P"FUS9VED
M(")?1V]T;R(*;7-G<W1R(")2;V1?>71I(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3,S-@IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`BP6ME;'1I
M+U])\&ME;'1I(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q.`HC+"!F=7IZ
M>0IM<V=I9"`B7TUY($-A;&5N9&%R<R(*;7-G<W1R(")-86YO(&MA;&5N9&]R
M:6%I(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,R-0IM<V=I9"`B7TYE=R!%
M=F5N="(*;7-G<W1R(").85]U:F%S(.%R8?!A<R(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$S-#$*;7-G:60@(E]0<FEN="(*;7-G<W1R(")3<&%U<V1I;G1I
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,@IM<V=I9"`B7U-E87)C:"(*
M;7-G<W1R("))9?!K;W1I(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,R.`IM
M<V=I9"`B7U1O9&%Y(@IM<V=S='(@(E_0:6%N9&EE;B(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$T,@IM<V=I9"`B8F5F;W)E('1H92!E=F5N="!S
M=&%R=',B"FUS9W-T<B`B<')I9?`@<')A<VED961A;G0@X79Y:VEU:2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G<W1R
M(")D:65N82(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,3`*;7-G:60@(F1A>2AS*2(*;7-G<W1R
M(")D:65N82AO<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#<*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$X."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Y"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(F1A>7,B"FUS9W-T<B`B9&EE;F]S
M(@H*(SH@9&%T82YP:'`Z,30W('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,0IM<V=I9"`B979E;G1S+F-S=B(*;7-G<W1R(")I=GEK:6%I+F-S=B(*"B,Z
M(&1A=&$N<&AP.C$V.`IM<V=I9"`B979E;G1S+FEC<R(*;7-G<W1R(")I=GEK
M:6%I+FEC<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,3,Q"FUS9VED(")F<F]M(@IM<V=S='(@(FYU;R(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C8*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,P('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(S-@IM<V=I9"`B;6]N=&@H<RDB"FUS9W-T<B`B;>MN=6\H
M:6%I*2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,C`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(F]N("5S(&%T("5S(@IM<V=S='(@(L%V>6MI<R!N
M=6\@)7,@:6MI("5S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,`IM<V=I9"`B;VX@=&AE('-A
M;64@9&%T92(*;7-G<W1R(")T=6\@<&'H:74@;65T=2(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,S8*;7-G:60@(F]N('1H92!S86UE('=E96MD87DB"FUS9W-T<B`B=&$@<&'H
M:>`@<V%V86ETZW,@9&EE;N`B"@HC.B!D871A+G!H<#HS,"!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$U"FUS9VED(")V0V%L96YD87(O:4-A;&5N9&%R
M(@IM<V=S='(@(G9#86QE;F1A<B]I0V%L96YD87(B"@HC.B!L:6(O87!I+G!H
M<#HS-#D@;&EB+V%P:2YP:'`Z-C`W"FUS9VED(")V179E;G0@;F]T(&9O=6YD
M+B(*;7-G<W1R(")V179E;G0@;F5R87-T87,N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B=V5E:R(*;7-G<W1R(")S879A:73K(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(Q-PIM<V=I9"`B=V5E:RAS*2!O;CHB"FUS9W-T<B`B<V%V
M86ETZRCK<RDZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DS"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.30*;7-G:60@(G=E96MS(@IM<V=S='(@(G-A=F%I=.MS(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(T,@IM<V=I9"`B>65A<BAS*2(*;7-G<W1R(")M971A:2(*````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]P;R]D95]$12YP;P``````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`Q,S8T,C``,3`T,3<S-C(W-3(`,#(P,S4U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",@2W)O
M;F]L:71H($=E<FUA;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P
M,#$M,C`P-2!*86X@4V-H;F5I9&5R+@HC($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^+"`R,#`Q+3(P,#4N"B,*(R!F<F5E+V)U<WDZ($9R96DO1V5B
M=6-H=`IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@
M2W)O;F]L:71H(#(N,2UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P
M-BTP,RTP-B`Q,CHT-RLP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V
M+3`S+3`V(#$R.C4V*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SY<;B(*(DQA;F=U86=E+51E86TZ($=E
M<FUA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ
M(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES
M;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET
M7&XB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@8V%L96YD87)S(&9O=6YD(@IM<V=S='(@
M(B5D($MA;&5N9&5R(&=E9G5N9&5N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@979E;G1S(@IM
M<V=S='(@(B5D(%1E<FUI;F4B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1&%Y*',I
M("5S($AO=7(H<RD@)7,@36EN=71E<R(*;7-G<W1R("(E<R!486<H92D@)7,@
M4W1U;F1E*&XI("5S($UI;G5T96XB"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#`U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T=&5N9&5E<R(*;7-G<W1R("(E
M<R!496EL;F5H;65R(@H*(SH@9&%T82YP:'`Z,C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@
M(D1I92`E<RU$871E:2!W=7)D92!E<F9O;&=R96EC:"!I;7!O<G1I97)T(@H*
M(SH@8V%L96YD87)S+G!H<#HQ,#4@;&EB+V)A<V4N<&AP.C$R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S<R!+86QE
M;F1E<B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-PIM
M<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N9&%R(&YA;64@=&\@<W=I=&-H('1H
M92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE(&UA:6X@(@HB=VEN9&]W
M*2(*;7-G<W1R("(B"B(H2VQI8VME;B!3:64@875F(&1E;B!+86QE;F1E<FYA
M;65N+"!U;2!D96X@2V%L96YD97(@:6T@2&%U<'1F96YS=&5R(&5I;BT@(@HB
M;V1E<B!A=7-Z=6)L96YD96XI(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ-C4*;7-G:60@(BH@061D('1H97-E(&)Y(&-L:6-K:6YG
M($%D9"`J(@IM<V=S='(@(BH@1&EE<V4@:&EN>G5F_&=E;B!D=7)C:"!+;&EC
M:R!A=68@2&EN>G5F_&=E;B`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ-3$*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S
M*&5S*2`J(@IM<V=S='(@(BH@0FET=&4@061R97-S92AN*2!A=7-WY&AL96X@
M*B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X,#0*;7-G:60@(C$@871T96YD964B
M"FUS9W-T<B`B,2!496EL;F5H;65R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C0*;7-G:60@(C$@979E;G0B"FUS9W-T<B`B,2!497)M:6XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,W"FUS9VED("(Q(&AO=7(B
M"FUS9W-T<B`B,2!3='5N9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,T"FUS9VED("(Q-2!M:6YU=&5S(@IM<V=S='(@(C$U($UI;G5T96XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED("(R,"!M:6YU=&5S
M(@IM<V=S='(@(C(P($UI;G5T96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,V"FUS9VED("(S,"!M:6YU=&5S(@IM<V=S='(@(C,P($UI;G5T96XB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-CD*;7-G:60@(CQS=')O
M;F<^071T96YD965S/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T
M<F]N9SY496EL;F5H;65R/"]S=')O;F<^("AO<'1I;VYA;"DB"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ-#<*;7-G:60@(CQS=')O;F<^1&5S8W)I
M7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9SY?
M2V]M;65N=&%R/"]S=')O;F<^("AO<'1I;VYA;"DB"@HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR-S0*;7-G:60@(CQS=')O;F<^2V5Y=V]R9',\+W-T
M<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\<W1R;VYG/E-T:6-H=_9R=&5R
M/"]S=')O;F<^("AO<'1I;VYA;"DB"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ.3(*;7-G:60@(CQS=')O;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H
M;W!T:6]N86PI(@IM<V=S='(@(CQS=')O;F<^5VEE9&5R:&]L=6YG/"]S=')O
M;F<^("AO<'1I;VYA;"DB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$Q,R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y,PIM<V=I9"`B04TB
M"FUS9W-T<B`B04TB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,#(*;7-G:60@
M(D%C8V5P=&5D(@IM<V=S='(@(D%N9V5N;VUM96XB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z,3$*;7-G:60@(D%D7W9A;F-E9"!396%R8V@B
M"FUS9W-T<B`B15]R=V5I=&5R=&4@4W5C:&4B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$V,`IM<V=I9"`B061D(@IM<V=S='(@(DAI
M;GIU9OQG96XB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,@IM<V=I
M9"`B061D($5V96YT(@IM<V=S='(@(E1E<FUI;B!H:6YZ=6;\9V5N(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,S4*
M;7-G:60@(D%D9"!A(&YE=R!296UO=&4@0V%L96YD87(B"FUS9W-T<B`B16EN
M96X@;F5U96X@97AT97)N96X@2V%L96YD97(@:&EN>G5F_&=E;B(*"B,Z(&%D
M9&5V96YT+G!H<#HV-`IM<V=I9"`B061D(&$@;F5W(&5V96YT(@IM<V=S='(@
M(D5I;F5N(&YE=65N(%1E<FUI;B!H:6YZ=6;\9V5N(@H*(SH@=&5M<&QA=&5S
M+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C<Q"FUS9VED(")!9&0@871T96YD
M965S(@IM<V=S='(@(E1E:6QN96AM97(@:&EN>G5F_&=E;B(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@U"FUS9VED(")!9&0@=&\@
M871T96YD965S(@IM<V=S='(@(EIU(%1E:6QN96AM97)N(&AI;GIU9OQG96XB
M"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ,C@*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C<T"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S8G5C
M:"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I9"`B061V86YC
M960@4V5A<F-H(@IM<V=S='(@(D5R=V5I=&5R=&4@4W5C:&4B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHU,PIM<V=I9"`B06QA<FTB"FUS9W-T<B`B
M06QA<FTB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@P"B,L('!H<"UF;W)M870*
M;7-G:60@(D%L87)M("5D(&1A>7,@8F5F;W)E(@IM<V=S='(@(D%L87)M("5D
M(%1A9V4@=F]R:&5R(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!H;W5R<R!B969O<F4B"FUS9W-T<B`B
M06QA<FT@)60@4W1U;F1E;B!V;W)H97(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M-SDP"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&UI;G5T97,@8F5F
M;W)E(@IM<V=S='(@(D%L87)M("5D($UI;G5T96X@=F]R:&5R(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<W-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E
M9"!W965K<R!B969O<F4B"FUS9W-T<B`B06QA<FT@)60@5V]C:&5N('9O<FAE
M<B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-SD*;7-G:60@(D%L87)M(#$@9&%Y
M(&)E9F]R92(*;7-G<W1R(")!;&%R;2`Q(%1A9R!V;W)H97(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ-S@T"FUS9VED(")!;&%R;2`Q(&AO=7(@8F5F;W)E(@IM
M<V=S='(@(D%L87)M(#$@4W1U;F1E('9O<FAE<B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$W.#D*;7-G:60@(D%L87)M(#$@;6EN=71E(&)E9F]R92(*;7-G<W1R
M(")!;&%R;2`Q($UI;G5T92!V;W)H97(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M-S<T"FUS9VED(")!;&%R;2`Q('=E96L@8F5F;W)E(@IM<V=S='(@(D%L87)M
M(#$@5V]C:&4@=F]R:&5R(@H*(SH@9&%T82YP:'`Z-3D*;7-G:60@(D%L87)M
M($1A=&4B"FUS9W-T<B`B06QA<FUD871U;2(*"B,Z(&1A=&$N<&AP.C4X"FUS
M9VED(")!;&%R;2!3<&%N("AM:6YU=&5S*2(*;7-G<W1R(")!;&%R;2`H36EN
M=71E;BDB"@HC.B!D871A+G!H<#HV,`IM<V=I9"`B06QA<FT@5&EM92(*;7-G
M<W1R(")!;&%R;7IE:70B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI
M;F,Z,S0*;7-G:60@(D%L;"(*;7-G<W1R(")!;&QE(@H*(SH@;&EB+T9"5FEE
M=RYP:'`Z,3(X(&QI8B]&0E9I97<N<&AP.C$S,2!L:6(O1D)6:65W+G!H<#HQ
M,S0*;7-G:60@(D%L;"!!='1E;F1E97,B"FUS9W-T<B`B06QL92!496EL;F5H
M;65R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4Y"FUS9VED
M(")!;&P@1G5T=7)E(@IM<V=S='(@(D%L;&4@>G5K_&YF=&EG96XB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*;7-G:60@(D%L;"!087-T
M(@IM<V=S='(@(D%L;&4@=F5R9V%N9V5N96XB"@HC.B!L:6(O0FQO8VLO<')E
M=FUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L;V-K+VUO;G1H+G!H<#HR-`HC.B!L
M:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,C4*;7-G:60@(D%L;"!6:7-I8FQE(@IM<V=S='(@(D%L;&4@<VEC:'1B
M87)E;B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R
M,B!L:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.CDS"B,Z(&QI
M8B]7965K5FEE=RYP:'`Z,3(W(&QI8B]7965K5FEE=RYP:'`Z,3,T(&QI8B]$
M<FEV97(N<&AP.C$X-C<*;7-G:60@(D%L;"!D87DB"FUS9W-T<B`B1V%N>G3D
M9VEG(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$V-`IM<V=I9"`B06QL
M(&1A>2!E=F5N="(*;7-G<W1R(")'86YZ=.1G:6=E<B!497)M:6XB"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C,S"FUS9VED(")!;&P@979E;G1S
M(@IM<V=S='(@(D%L;&4@5&5R;6EN92(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H7V%D=F%N8V5D+FEN8SHT.`HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:%]A9'9A;F-E9"YI;F,Z-S`@;&EB+TMR;VYO;&ET:"YP:'`Z-CDU"FUS
M9VED(")!;GDB"FUS9W-T<B`B06QL92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I;"(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Y('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.CDS"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z.#(@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M-C@*;7-G:60@(D%T(@IM<V=S='(@(G5M(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3`T-@IM<V=I9"`B(@HB071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I
M;&4@=VET:"!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('1H92!E=F5N="X@268@
M>6]U<B`B"B)M86EL(&-L:65N="!S=7!P;W)T<R!I5&EP(')E<75E<W1S('EO
M=2!C86X@=7-E('1H:7,@9FEL92!T;R!E87-I;'D@=7!D871E("(*(GEO=7(@
M;&]C86P@8V]P>2!O9B!T:&4@979E;G0N(@IM<V=S='(@(B(*(DEM($%N:&%N
M9R!B969I;F1E="!S:6-H(&5I;F4@:4-A;&5N9&%R+41A=&5I(&UI="!M96AR
M($EN9F]R;6%T:6]N96X@>G4@(@HB9&EE<V5M(%1E<FUI;BX@5V5N;B!):'(@
M16UA:6PM4')O9W)A;6T@:51I<"U!;F9R86=E;B!B96AE<G)S8VAT+"!K]FYN
M96X@4VEE("(*(F1I97-E($1A=&5I(&1A>G4@8F5N=71Z96XL($EH<F4@;&]K
M86QE(%9E<G-I;VX@9&5S(%1E<FUI;G,@>G4@86MT=6%L:7-I97)E;BXB"@HC
M.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#(@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E;F1A;F-E(@IM<V=S
M='(@(D%N=V5S96YH96ET(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,38Q"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B5&5I;&YE:&UE<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U
M<W0B"FUS9W-T<B`B075G=7-T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8VA?861V86YC960N:6YC.C$Q('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN
M8SHX"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B16EN9F%C:&4@4W5C
M:&4B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D)I
M<G1H9&%Y(@IM<V=S='(@(D=E8G5R='-T86<B"@HC.B!L:6(O1D)6:65W+G!H
M<#HY,"!L:6(O1D)6:65W+G!H<#HQ,3$*;7-G:60@(D)U<WDB"FUS9W-T<B`B
M0F5S8VCD9G1I9W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z-#(*;7-G:60@(D-?86QE;F1A<B(*;7-G<W1R(")?2V%L96YD
M97(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHT-PIM<V=I9"`B0V%L
M7V5N9&%R(@IM<V=S='(@(E]+86QE;F1E<B(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ-#D@;&EB+T)L;V-K+W!R979M;VYT:&QI
M<W0N<&AP.C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C$@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS
M9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HS"FUS9VED(")#86QE;F1A<B!3=6UM87)Y(@IM<V=S
M='(@(DMA;&5N9&5R+=QB97)S:6-H="(*"B,Z(&1A=&$N<&AP.C(S,PIM<V=I
M9"`B0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS9W-T<B`B2V%L
M96YD97(@97)F;VQG<F5I8V@@9V5L965R="XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<*
M;7-G:60@(D-A;&5N9&%R<R(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z,C<*;7-G:60@(D-A;&5N9&%R<R!M=7-T(&AA=F4@82!N86UE
M+B(*;7-G<W1R(")+86QE;F1E<B!M_'-S96X@96EN96X@3F%M96X@:&%B96XN
M(@H*(SH@9&%T82YP:'`Z,C0X"FUS9VED(")#86XG="!C<F5A=&4@82!N97<@
M979E;G0N(@IM<V=S='(@(D5I;B!N975E<B!497)M:6X@:V]N;G1E(&YI8VAT
M(&5R<W1E;&QT('=E<F1E;BXB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI
M;F,Z,S,@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,U"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C,Q('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C,P-PIM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%B8G)E8VAE;B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C4W.`IM<V=I9"`B0V%N8V5L;&5D(@IM<V=S='(@
M(D%B9V5S86=T(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YC96QL960Z("5S(@IM<V=S='(@(D%B9V5S86=T
M.B`E<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN
M8SHV,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHV-PIM<V=I9"`B0V%T96=O
M<E]Y(@IM<V=S='(@(DMA=&5G;U]R:64B"@HC.B!D871A+G!H<#HV,B!T96UP
M;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C0@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3,*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G
M;W)I92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@(B(*
M(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D
M:71E9"P@86YD(&1E;&5T960@979E;G1S(&)Y("(*(F5M86EL.B(*;7-G<W1R
M("(B"B),96=E;B!3:64@9F5S="P@;V(@4VEE('!E<B!%;6%I;"#\8F5R(&YE
M=64L(&=EY&YD97)T92!O9&5R(&=E;/9S8VAT92!497)M:6YE("(*(F)E;F%C
M:')I8VAT:6=T('=E<F1E;B!M]F-H=&5N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO
M=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',N(@IM
M<V=S='(@(B(*(DQE9V5N(%-I92!F97-T+"!O8B!3:64@_&)E<B!N975E+"!G
M9>1N9&5R=&4@;V1E<B!G96SV<V-H=&4@5&5R;6EN92`B"B)B96YA8VAR:6-H
M=&EG="!W97)D96X@;?9C:'1E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,CDR"FUS9VED(")#:&]O<V4@:68@>6]U('=A;G0@=&\@<F5C96EV92!E
M;6%I;"!R96UI;F1E<G,@9F]R(&5V96YT<R!W:71H(&%L87)M<SHB"FUS9W-T
M<B`B(@HB3&5G96X@4VEE(&9E<W0L(&]B(%-I92!P97(@16UA:6P@_&)E<B!!
M;&%R;64@8F5N86-H<FEC:'1I9W0@=V5R9&5N(&WV8VAT96XZ(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-E87)C:%]A8F]O:U]S96QE8W0N:6YC.C$Y(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,3(*;7-G:60@(D-H;V]S92!T:&4@861D<F5S
M<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.B(*;7-G<W1R
M("(B"B)7Y&AL96X@4VEE(&1I92!!9')E<W-B_&-H97(@875S+"!I;B!D96YE
M;B!N86-H($9R96DO1V5B=6-H="U54DQS(&=E<W5C:'0@(@HB=V5R9&5N('-O
M;&PZ(@H*(SH@=&5M<&QA=&5S+W!R969S+V9B7V-A;'-?<V5L96-T+FEN8SHQ
M-@IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!I;B!Y
M;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;CHB"FUS9W-T<B`B(@HB5^1H;&5N
M(%-I92!D:64@2V%L96YD97(@875S+"!D:64@:6X@26AR92!&<F5I+T=E8G5C
M:'0M26YF;W)M871I;VYE;B`B"B)E:6YB97IO9V5N('=E<F1E;B!S;VQL96XZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-`IM<V=I9"`B0VAO;W-E
M('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!W:&5N(&=E;F5R871I;F<@9G)E
M92]B=7-Y(%523',Z(@IM<V=S='(@(B(*(E?D:&QE;B!3:64@9&EE($MA;&5N
M9&5R(&%U<RP@9&EE(&5I;F)E>F]G96X@=V5R9&5N('-O;&QE;BP@=V5N;B!)
M:')E($9R96DO(@HB1V5B=6-H="U54DQS(&5R>F5U9W0@=V5R9&5N.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B0VAO;W-E('EO=7(@
M9&5F875L="!C86QE;F1A<BXB"FUS9W-T<B`B5^1H;&5N(%-I92!):')E;B!3
M=&%N9&%R9"U+86QE;F1E<B!A=7,N(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E
M<R]A='1E;F1E97,N:6YC.C@T"FUS9VED(")#;&5A<B!A;&P@871T96YD965S
M(@IM<V=S='(@(D%L;&4@5&5I;&YE:&UE<B!E;G1F97)N96XB"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B0VQO<V4@
M=VEN9&]W(@IM<V=S='(@(D9E;G-T97(@<V-H;&EEWV5N(@H*(SH@9&%T82YP
M:'`Z,C@@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M
M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")+;VUM86=E=')E;FYT92!7
M97)T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,PIM<V=I9"`B0V]N
M9FER;2!D96QE=&EO;B!O9B!E=F5N=',_(@IM<V=S='(@(DSV<V-H96X@=F]N
M(%1E<FUI;F5N(&)E<W3D=&EG96X_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-3<U"FUS9VED(")#;VYF:7)M960B"FUS9W-T<B`B0F5S=.1T:6=T(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(Q-PIM<V=I9"`B
M0V]P>2!T:&4@55),(&)E;&]W(&9O<B!U<V4@=VAE<F5V97(@>6]U(&YE960@
M>6]U<B!&<F5E+T)U<WD@55),.B(*;7-G<W1R("(B"B)"96YU='IE;B!3:64@
M9&5N($QI;FL@875S(&1I97-E;2!&96QD+"!W;R!I;6UE<B!3:64@26AR92!&
M<F5I+T=E8G5C:'0M55),("(*(F)E;O9T:6=E;CHB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)7,N(@IM<V=S='(@(B5S(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E
M;BXB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3(Y
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B17)S=&5L;&5N(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q-0IM<V=I9"`B0W)E871E
M($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(&5R<W1E;&QE;B(*"B,Z(&UO
M;G1H+G!H<#HQ-C,@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,C4@=&5M<&QA
M=&5S+V1A>2]R;W<N:6YC.C8*(SH@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$
M87E6:65W+G!H<#HQ.34*;7-G:60@(D-R96%T92!A($YE=R!%=F5N="(*;7-G
M<W1R(").975E;B!497)M:6X@97)S=&5L;&5N(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z.#`*;7-G:60@(D-R96%T960B"FUS9W-T<B`B17)S=&5L
M;'0B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S(*;7-G:60@
M(D-U<G)E;G0B"FUS9W-T<B`B1&EE<V5N(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(P-@IM<V=I
M9"`B1&%I;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")4Y&=L:6-H.B!7:65D
M97)H;VQU;F<@86QL92(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`V(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S,3$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"FUS9VED(")$87DB"FUS9W-T<B`B
M5&%G(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,3,W"FUS9VED(")$87DH<RDB"FUS9W-T<B`B5&%G
M*&4I(@H*(SH@=FEE=V5V96YT+G!H<#HQ,3,*;7-G:60@(D1E7VQE=&4B"FUS
M9W-T<B`B7TSV<V-H96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHW.0IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5Z96UB97(B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HV,#4*;7-G:60@(D1E8VQI;F5D(@IM<V=S
M='(@(D%B9V5L96AN="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-PIM
M<V=I9"`B1&5F875L="!#86QE;F1A<B(*;7-G<W1R(")3=&%N9&%R9"U+86QE
M;F1E<B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR
M,#0@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,R"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C(S(&QI8B]$<FEV97(N
M<&AP.C$X-#@*;7-G:60@(D1E;&5T92(*;7-G<W1R("),]G-C:&5N(@H*(SH@
M9&5L979E;G0N<&AP.C0P('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR,2!T
M96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C$*(SH@;&EB+T1R:79E<BYP
M:'`Z,3@T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,B"FUS9W-T
M<B`B)7,@;/9S8VAE;B(*"B,Z(&5D:71E=F5N="YP:'`Z-S(*;7-G:60@(D1E
M;&5T92!%=F5N="(*;7-G<W1R(")497)M:6X@;/9S8VAE;B(*"B,Z('1E;7!L
M871E<R]D96QE=&4O9&5L971E+FEN8SHS,`IM<V=I9"`B(@HB1&5L971E('1H
M92!C=7)R96YT(&5V96YT(&]N;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL
M(&9U='5R92!O8V-U<F5N8V5S+"!O<B`B"B)A;&P@;V-C=7)E;F-E<S\B"FUS
M9W-T<B`B(@HB3G5R(&1E;B!A:W1U96QL96X@5&5R;6EN(&SV<V-H96XL(&%L
M;&4@>G5K_&YF=&EG96X@5&5R;6EN92!I;FML=7-I=F4@9&EE<V5M("(*(F]D
M97(@9&EE(&=A;GIE(%-E<FEE/R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H7V%D=F%N8V5D+FEN8SHQ,#,@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C(X"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B7T)E<V-H<F5I
M8G5N9R(*"B,Z(&1A=&$N<&AP.C8Q('1E;7!L871E<R]C86QE;F1A<G,O8V%L
M96YD87)S+FEN8SHQ-S@*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.38*
M;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)E<V-H<F5I8G5N9R(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<T"FUS9VED(")$
M:7-P;&%Y(@IM<V=S='(@(D%N>F5I9V4B"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z-C,*;7-G:60@(D1I<W!L87D@0V%L96YD87)S
M(@IM<V=S='(@(DMA;&5N9&5R(&%N>F5I9V5N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S
M='(@(D%N>F5I9V4M16EN<W1E;&QU;F=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@<VAO=R!T87-K<R!W
M:&EC:"!A<F4@9'5E(&]N('EO=7(@8V%L96YD87(_(@IM<V=S='(@(E-O;&QE
M;B#\8F5R9N1L;&EG92!!=69G86)E;B!I;B!):')E;2!+86QE;F1E<B!A;F=E
M>F5I9W0@=V5R9&5N/R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T-0IM<V=I
M9"`B1&]E<R!N;W0@<F5C=7(B"FUS9W-T<B`B2V5I;F4@5VEE9&5R:&]L=6YG
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G
M:60@(D1U93H@)7,B"FUS9W-T<B`B1N1L;&EG.B`E<R(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB
M"FUS9W-T<B`B7T1A=65R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$W,R!L:6(O1')I=F5R+G!H<#HQ.#,T"FUS9VED(")%9&ET
M(@IM<V=S='(@(D)E87)B96ET96XB"@HC.B!E9&ET979E;G0N<&AP.C,S('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(R(&QI8B]$<FEV97(N<&AP.C$X,S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R("(E<R!B96%R
M8F5I=&5N(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@U"FUS9VED
M(")%9&ET($%T=&5N9&5E<R(*;7-G<W1R(")496EL;F5H;65R(&)E87)B96ET
M96XB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30S
M"FUS9VED(")%9&ET($-A;&5N9&%R<R(*;7-G<W1R(")+86QE;F1E<B!B96%R
M8F5I=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,`IM<V=I9"`B
M161I="!296UO=&4@0V%L96YD87)S(@IM<V=S='(@(D5X=&5R;F4@2V%L96YD
M97(@8F5A<F)E:71E;B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,30V"FUS9VED(")%
M9&ET(&%T=&5N9&5E<R(*;7-G<W1R(")496EL;F5H;65R(&)E87)B96ET96XB
M"@HC.B!T96UP;&%T97,O8V%T96=O<GE?;&5G96YD+FEN8SHR,`IM<V=I9"`B
M161I="!C871E9V]R:65S(&%N9"!C;VQO<G,B"FUS9W-T<B`B2V%T96=O<FEE
M;B!U;F0@1F%R8F5N(&)E87)B96ET96XB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$W-R!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z-#$*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38T"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5M86EL861R97-S92(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8P"FUS9VED(")%
M;E]D(@IM<V=S='(@(D5N7V1E(@H*(SH@9&%T82YP:'`Z-38*;7-G:60@(D5N
M9"!$871E(@IM<V=S='(@(D5N9&1A='5M(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]E=F5N=%]H96%D97)S+FEN8SHX('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(P"FUS9VED(")%
M;F0@3VXB"FUS9W-T<B`B96YD970@86TB"@HC.B!D871A+G!H<#HU-PIM<V=I
M9"`B16YD(%1I;64B"FUS9W-T<B`B16YD>F5I="(*"B,Z(&%T=&5N9&5E<RYP
M:'`Z,3(P(&%T=&5N9&5E<RYP:'`Z,3,Q(&%T=&5N9&5E<RYP:'`Z,3,X"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(&9O<B`E<SH@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@
M075S;&5S96X@9&5R($9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N(&;\<B`E
M<SH@)7,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$S"FUS9VED(")%=F5N
M="!A9&1E9#HB"FUS9W-T<B`B5&5R;6EN(&AI;GIU9V5F_&=T.B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$Q,C,*;7-G:60@(D5V96YT(&1E;&5T960Z(@IM
M<V=S='(@(E1E<FUI;B!G96SV<V-H=#HB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,3$X"FUS9VED(")%=F5N="!E9&ET960Z(@IM<V=S='(@(E1E<FUI;B!B
M96%R8F5I=&5T.B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B179E;G0@9G)O;2`E<R!T;R`E<R(*;7-G<W1R(")497)M
M:6X@=F]N("5S(&)I<R`E<R(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H<#HS-S,*
M;7-G:60@(D5V96YT(&YO="!F;W5N9"(*;7-G<W1R(")497)M:6X@;FEC:'0@
M9V5F=6YD96XB"@HC.B!L:6(O1')I=F5R+G!H<#HW-C@*;7-G:60@(D5V96YT
M<R!M=7-T(&AA=F4@82!S=&%R="!D871E+B(*;7-G<W1R(")497)M:6YE(&W\
M<W-E;B!E:6X@4W1A<G1D871U;2!H86)E;BXB"@HC.B!L:6(O1')I=F5R+G!H
M<#HW,S0*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@82!T:71L92XB"FUS9W-T
M<B`B5&5R;6EN92!M_'-S96X@96EN96X@5&ET96P@:&%B96XN(@H*(SH@=&5M
M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C<U"FUS9VED(")%>'!A
M;F0@3F%M97,B"FUS9W-T<B`B3F%M96X@<W5C:&5N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ.3D*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%
M>'!O<G1I97)E;B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z.`IM
M<V=I9"`B17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(&5X<&]R
M=&EE<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-CD*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87(B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$S,PIM<V=I9"`B1FEN9"(*;7-G
M<W1R(")3=6-H92(*"B,Z('EE87(N<&AP.C@T('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.0HC
M.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B1G(B"FUS9W-T<B`B
M1G(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.#$*;7-G:60@(D9R964B"FUS
M9W-T<B`B1G)E:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.`IM<V=I
M9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(D9R96DO1V5B=6-H
M="U);F9O<FUA=&EO;F5N(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC
M.C(P('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q.0HC.B!T96UP;&%T97,O
M961I="]J879A<V-R:7!T+FEN8SHW,@IM<V=I9"`B1G)I9&%Y(@IM<V=S='(@
M(D9R96ET86<B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S,*
M;7-G:60@(D9U='5R92(*;7-G<W1R("):=6O\;F9T:6=E(@H*(SH@8V]N9FEG
M+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")'86UE(@IM<V=S='(@(E-P
M:65L(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC
M.C(S"FUS9VED(")'96YE<F%L(@IM<V=S='(@(D%L;&=E;65I;F5S(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")';W1O("5S(@IM<V=S='(@(D=E:&4@;F%C:"`E<R(*"B,Z(&UO;G1H+G!H
M<#HQ,S,@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R
M"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"FUS
M9VED(")(:61E(@IM<V=S='(@(D%U<V)L96YD96XB"@HC.B!M;VYT:"YP:'`Z
M,3,S('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC
M.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(:61E("5S(@IM<V=S='(@(B5S(&%U<V)L96YD
M96XB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV-2!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHQ,S8*;7-G:60@(DAO=7(H<RDB"FUS9W-T<B`B4W1U
M;F1E*&XI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B
M2&]W(&QO;F<@<VAO=6QD('1H92!T:6UE('-L;W1S(&]N('1H92!D87D@86YD
M('=E96L@=FEE=W,@8F4_(@IM<V=S='(@(B(*(E=I92!L86YG('-O;&QE;B!D
M:64@6F5I=&%B<V-H;FET=&4@:6X@9&5R(%1A9V5S+2!U;F0@5V]C:&5N86YS
M:6-H="!S96EN/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#$*;7-G
M:60@(DAO=R!M86YY(&1A>7,@;V8@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('-H
M;W5L9"!W92!G96YE<F%T93\B"FUS9W-T<B`B(@HB1OQR('=I979I96QE(%1A
M9V4@:6X@9&5R(%IU:W5N9G0@<V]L;&5N($9R96DO1V5B=6-H="U);F9O<FUA
M=&EO;F5N(&%N9V5Z96EG="`B"B)W97)D96X_(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B))9B!Y;W5R(&5M
M86EL(&-L:65N="!D;V5S;B=T('-U<'!O<G0@:51I<"!R97%U97-T<R!Y;W4@
M8V%N('5S92!O;F4@;V8@=&AE("(*(F9O;&QO=VEN9R!L:6YK<R!T;R!A8V-E
M<'0@;W(@9&5C;&EN92!T:&4@979E;G0N7&XB"B)<;B(*(E1O(&%C8V5P="!T
M:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT
M('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*(EQN(@HB5&\@9&5C;&EN92!T:&4@
M979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B"B)&86QL<R!):'(@16UA:6QP<F]G
M<F%M;2!K96EN92!I5&EP+4%N9G)A9V5N('5N=&5R<W3\='IT+"!K]FYN96X@
M4VEE(&5I;F5N("(*(F1E<B!F;VQG96YD96X@3&EN:W,@=F5R=V5N9&5N+"!U
M;2!D96X@5&5R;6EN('IU(&)E<W3D=&EG96X@;V1E<B!A8GIU;&5H;F5N+EQN
M(@HB7&XB"B)5;2!D96X@5&5R;6EN('IU(&)E<W3D=&EG96XZ7&XB"B(E<UQN
M(@HB7&XB"B)5;2!D96X@5&5R;6EN('5N=&5R(%9O<F)E:&%L="!Z=2!B97-T
MY'1I9V5N.EQN(@HB)7-<;B(*(EQN(@HB56T@9&5N(%1E<FUI;B!A8GIU;&5H
M;F5N.EQN(@HB)7,B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($-A;&5N9&%R+"!3=&5P("5D
M(@IM<V=S='(@(DMA;&5N9&5R(&EM<&]R=&EE<F5N+"!38VAR:71T("5D(@H*
M(SH@9&%T82YP:'`Z,C@X"FUS9VED("));7!O<G0O17AP;W)T($-A;&5N9&%R
M(@IM<V=S='(@(DMA;&5N9&5R+4EM<&]R="\M17AP;W)T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C@*;7-G:60@(DIA;G5A<GDB"FUS
M9W-T<B`B2F%N=6%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-S0*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C<S"FUS9VED(")*=6YE(@IM<V=S='(@
M(DIU;FDB"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ-#(*;7-G:60@(DME>7=O<F1S(@IM<V=S='(@(E-T:6-H=_9R=&5R(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4U"FUS9VED("),87-T
M(#(T(&AO=7)S(@IM<V=S='(@(DQE='IT92`R-"!3='5N9&5N(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#<*;7-G:60@(DQA<W0@36]D:69I960B
M"FUS9W-T<B`B3&5T>G1E(,1N9&5R=6YG(@H*(SH@=&5M<&QA=&5S+VUO;G1H
M+VAE861?<VED95]B>5]S:61E+FEN8SHT"B,Z('1E;7!L871E<R]M;VYT:"]H
M96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M861?<VED95]B>5]S:61E+FEN8SHQ-B!T96UP;&%T97,O;6]N=&@O:&5A9"YI
M;F,Z-`IM<V=I9"`B3&%S="!-;VYT:"(*;7-G<W1R("),971Z=&5R($UO;F%T
M(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-`IM<V=I9"`B3&%S="!9
M96%R(@IM<V=S='(@(DQE='IT97,@2F%H<B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHU-"!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHS"FUS
M9VED("),87-T('=E96LB"FUS9W-T<B`B3&5T>G1E(%=O8VAE(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR.0IM<V=I9"`B3&EM:70@=&AE('1I
M;64@<W!A;B!T;R!E>'!O<G0Z(@IM<V=S='(@(E?D:&QE;B!3:64@9&EE(%IE
M:71S<&%N;F4L(&1I92!E>'!O<G1I97)T('=E<F1E;B!S;VQL.B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX-2!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHW-`IM<V=I9"`B3&]?8V%T:6]N(@IM<V=S='(@
M(E]/<G0B"@HC.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V96YT
M7VAE861E<G,N:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?
M;6%N86=E;65N="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C
M86Q?;6%N86=E;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,C$*(SH@;&EB+T1R:79E<BYP:'`Z,3@X-`IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B3W)T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U"FUS9VED
M(")-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RXB"FUS9W-T<B`B5F5R=V%L=&5N
M(%-I92!E>'1E<FYE($MA;&5N9&5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<P"FUS9VED(")-87)C:"(*;7-G<W1R(")-Y')Z(@H*
M(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!%
M=F5N=',B"FUS9W-T<B`B36%X:6UA;&4@06YZ86AL(&%N(%1E<FUI;F5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA
M>2(*;7-G<W1R(")-86DB"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#@Q"FUS9VED
M(")-92(*;7-G<W1R("))8V@B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I
M<W0Z,3<*;7-G:60@(DUE971I;F<B"FUS9W-T<B`B0F5S<')E8VAU;F<B"@HC
M.B!L:6(O0FQO8VLO=')E95]A;&%R;7,N<&AP.C,*;7-G:60@(DUE;G4@06QA
M<FUS(@IM<V=S='(@(DUE;OQA;&%R;2(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R(")-96[\;&ES=&4B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV."!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ,S4*;7-G:60@(DUI;G5T92AS*2(*;7-G<W1R(")-:6YU
M=&4H;BDB"@HC.B!Y96%R+G!H<#HX,"!T96UP;&%T97,O:F%V87-C<FEP="]G
M;W1O+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,34*(SH@;&EB
M+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(DUO(@IM<V=S='(@(DUO(@H*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$V('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$Q-0HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN
M8SHV."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"FUS9VED(")-;VYD87DB
M"FUS9W-T<B`B36]N=&%G(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q-"!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S='(@(DUO;F%T(@H*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HS"FUS9VED(")-;VYT:"!6:65W(@IM<V=S='(@(DUO
M;F%T<V%N<VEC:'0B"@HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HS(&QI
M8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0S"FUS9VED(")-;VYT:&QY($5V96YT
M<R!,:7-T(@IM<V=S='(@(DUO;F%T;&EC:&4@5&5R;6EN;&ES=&4B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,S(*;7-G:60@(DUO;G1H;'DZ(%)E8W5R
M<R!E=F5R>2(*;7-G<W1R(")-;VYA=&QI8V@Z(%=I961E<FAO;'5N9R!A;&QE
M(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H
M<R!!:&5A9"(*;7-G<W1R(")-;VYA=&4@:6T@=F]R875S(@H*(SH@;&EB+T)L
M;V-K+W!R979M;VYT:&QI<W0N<&AP.C(T"FUS9VED(")-;VYT:',@0F5F;W)E
M(@IM<V=S='(@(DUO;F%T92!Z=79O<B(*"B,Z(&QI8B]A<&DN<&AP.C8S,PIM
M<V=I9"`B375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N
M;'D@;VYE('9%=F5N="!I<R!S=7!P;W)T960N(@IM<V=S='(@(B(*(DUE:')E
M<F4@:4-A;&5N9&%R+4MO;7!O;F5N=&5N(&=E9G5N9&5N.R!N=7(@96EN('9%
M=F5N="!W:7)D('5N=&5R<W3\='IT+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z,3(X
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHW,`IM<V=I9"`B
M37D@0V%L96YD87)S(@IM<V=S='(@(DUE:6YE($MA;&5N9&5R(@H*(SH@=&5M
M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M96YU+FEN8SHS-@IM<V=I
M9"`B37D@0V%L96YD87)S.B(*;7-G<W1R(")-96EN92!+86QE;F1E<CHB"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C$S"FUS9VED
M(")->2!&<F5E+T)U<WD@55),(@IM<V=S='(@(DUE:6YE($9R96DO1V5B=6-H
M="U54DPB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M,3(P('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-C(*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S8*(SH@=&5M<&QA
M=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,3<*(SH@=&5M
M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-#0*;7-G
M:60@(DYA;64B"FUS9W-T<B`B3F%M92(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z-#$@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#0@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C0Q"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(P"FUS
M9VED(").97<@179E;G0B"FUS9W-T<B`B3F5U97(@5&5R;6EN(@H*(SH@;&EB
M+V)A<V4N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B).97<@8V%L
M96YD87(@8W)E871E9"!A;F0@875T;VUA=&EC86QL>2!S:&%R960@=VET:"!T
M:&4@9F]L;&]W:6YG(&=R;W5P*',I.B`E(@HB<RXB"FUS9W-T<B`B(@HB3F5U
M97(@2V%L96YD97(@97)S=&5L;'0@=6YD(&%U=&]M871I<V-H(&9O;&=E;F1E
M;B!'<G5P<&5N(%IU9W)I9F8@9V5WY&AR=#H@)2(*(G,N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHS,PIM<V=I9"`B3F5X="(*;7-G<W1R(")7
M96ET97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3<*;7-G
M:60@(DYE>'0@,C0@:&]U<G,B"FUS9W-T<B`B3N1C:'-T92`R-"!3='5N9&5N
M(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(Y"FUS9VED(").97AT($1A>2(*
M;7-G<W1R(").Y&-H<W1E<B!486<B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A
M9%]S:61E7V)Y7W-I9&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?
M<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$X('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHV
M"FUS9VED(").97AT($UO;G1H(@IM<V=S='(@(D[D8VAS=&5R($UO;F%T(@H*
M(SH@;&EB+T9"5FEE=R]W965K+G!H<#HS,@IM<V=I9"`B3F5X="!7965K(@IM
M<V=S='(@(D[D8VAS=&4@5V]C:&4B"@HC.B!T96UP;&%T97,O>65A<B]H96%D
M+FEN8SHV"FUS9VED(").97AT(%EE87(B"FUS9W-T<B`B3N1C:'-T97,@2F%H
M<B(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!D
M87DB"FUS9W-T<B`B3N1C:'-T97(@5&%G(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C4X('1E;7!L871E<R]W965K+VAE860N:6YC.C4*;7-G
M:60@(DYE>'0@=V5E:R(*;7-G<W1R(").Y&-H<W1E(%=O8VAE(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(W-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C@X"FUS9VED(").;R(*;7-G<W1R(").96EN(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3(T"FUS
M9VED(").;R!A;&%R;2(*;7-G<W1R(")+96EN($%L87)M(@H*(SH@=&5M<&QA
M=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0X"FUS9VED(").;R!A='1E
M;F1E97,B"FUS9W-T<B`B2V5I;F4@5&5I;&YE:&UE<B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S,S`*;7-G:60@(DYO(&-A;&5N9&%R<R!A<F4@879A:6QA
M8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B17,@<VEN9"!K96EN92!+86QE;F1E
M<B!F_'(@1^1S=&4@=F5R9OQG8F%R+B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-3(*;7-G:60@
M(DYO(&5N9"!D871E(@IM<V=S='(@(DME:6X@16YD92(*"B,Z(&QI8B]";&]C
M:R]P<F5V;6]N=&AL:7-T+G!H<#HQ-C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP
M:'`Z,38S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ.30*;7-G:60@(DYO
M(&5V96YT<R!T;R!D:7-P;&%Y(@IM<V=S='(@(DME:6YE(%1E<FUI;F4B"@HC
M.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3F\@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@
M)7,B"FUS9W-T<B`B2V5I;F4@1G)E:2]'96)U8VAT+4EN9F]R;6%T:6]N96X@
M9OQR("5S('9E<F;\9V)A<B(*"B,Z(&QI8B]A<&DN<&AP.C,T-"!L:6(O87!I
M+G!H<#HV,C,*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB
M"FUS9W-T<B`B17,@=W5R9&5N(&ME:6YE(&E#86QE;F1A<BU$871E;B!G969U
M;F1E;BXB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#$*;7-G:60@
M(DYO(')E8W5R<F5N8V4B"FUS9W-T<B`B2V5I;F4@5VEE9&5R:&]L=6YG(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3`R"FUS9VED(").;R!V86QI9"!E;6%I
M;"!A9&1R97-S(&9O=6YD(@IM<V=S='(@(DME:6YE(&?\;'1I9V4@16UA:6QA
M9')E<W-E(&=E9G5N9&5N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C$R(&QI
M8B]+<F]N;VQI=&@N<&AP.C8S,PIM<V=I9"`B3F]N92(*;7-G<W1R(")+96EN
M92(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z,30U"FUS9VED(").;W0@9F]U
M;F0B"FUS9W-T<B`B3FEC:'0@9V5F=6YD96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$*;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`B0F5N
M86-H<FEC:'1I9W5N9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-S@*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4V"FUS9VED(").;W<B
M"FUS9W-T<B`B2F5T>G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHW-PIM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/:W1O8F5R(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S
M+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@
M(D%M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W."!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,CDQ"FUS9VED(")/;B!A;&P@8V%L96YD87)S($D@:&%V
M92!R96%D(&%C8V5S<R!T;R(*;7-G<W1R(")"96D@86QL96X@2V%L96YD97)N
M+"!F_'(@9&EE(&EC:"!,97-E<F5C:'1E(&AA8F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3`*;7-G
M:60@(D]N(&%L;"!S:&]W;B!C86QE;F1A<G,B"FUS9W-T<B`B0F5I(&%L;&5N
M(&%N9V5Z96EG=&5N($MA;&5N9&5R;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.0IM<V=I9"`B3VX@
M;7D@8V%L96YD87)S(&]N;'DB"FUS9W-T<B`B3G5R(&)E:2!M96EN96X@2V%L
M96YD97)N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C,P"FUS9VED(")/<'1I
M;VYA;"(*;7-G<W1R(")&<F5I=VEL;&EG(@H*(SH@;&EB+T9"5FEE=RYP:'`Z
M,3$Y"FUS9VED(")/<'1I;VYA;"!!='1E;F1E97,B"FUS9W-T<B`B1G)E:7=I
M;&QI9V4@5&5I;&YE:&UE<B(*"B,Z(&QI8B]&0E9I97<N<&AP.C$U-`IM<V=I
M9"`B3W9E<G9I97<B"FUS9W-T<B`BW&)E<G-I8VAT(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,S0*;7-G:60@(D]W;F5R(@IM<V=S='(@(D)E<VET
M>F5R(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")/=VYE<CH@)7,B"FUS9W-T<B`B0F5S:71Z97(Z("5S(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,30@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ.30*;7-G:60@(E!-(@IM<V=S='(@(E!-(@H*(SH@;&EB+T)L
M;V-K+W!R979M;VYT:&QI<W0N<&AP.C,@;&EB+T)L;V-K+W!R979M;VYT:&QI
M<W0N<&AP.C0R"FUS9VED(")087-T($5V96YT<R!,:7-T(@IM<V=S='(@(DQI
M<W1E('9E<F=A;F=E;F5R(%1E<FUI;F4B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,#D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DV"FUS9VED
M(")0871T97)N(@IM<V=S='(@(E)H>71H;75S(@H*(SH@=&5M<&QA=&5S+V1E
M;&5T92]O;F4N:6YC.C,P"FUS9VED(")097)M86YE;G1L>2!D96QE=&4@=&AI
M<R!E=F5N=#\B"FUS9W-T<B`B1&EE<V5N(%1E<FUI;B!U;G=I961E<F)R:6YG
M;&EC:"!L]G-C:&5N/R(*"B,Z(&QI8B]A<&DN<&AP.C,R-2!L:6(O87!I+G!H
M<#HT,C$@;&EB+V%P:2YP:'`Z-#DS(&QI8B]A<&DN<&AP.C4W,PHC.B!L:6(O
M87!I+G!H<#HV,#4@;&EB+V%P:2YP:'`Z-CDQ(&QI8B]A<&DN<&AP.C<R-PIM
M<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B6G5G<FEF9B!V97)W
M96EG97)T(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$W,`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5C:'1E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q"FUS9VED(")0;W)T86P@3W!T:6]N
M<R(*;7-G<W1R(")0;W)T86QE:6YS=&5L;'5N9V5N(@H*(SH@;&EB+T9"5FEE
M=R]D87DN<&AP.C(U"FUS9VED(")0<F5V:6]U<R!$87DB"FUS9W-T<B`B5F]R
M:6=E<B!486<B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C(V"FUS9VED(")0
M<F5V:6]U<R!7965K(@IM<V=S='(@(E9O<FEG92!7;V-H92(*"B,Z('1E;7!L
M871E<R]D87DO:&5A9"YI;F,Z,PIM<V=I9"`B4')E=FEO=7,@9&%Y(@IM<V=S
M='(@(E9O:&5R:6=E<B!486<B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,S4@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C0Y"FUS9VED(")296-U
M<B!5;G1I;"(*;7-G<W1R(")7:65D97)H;VQE;B!B:7,B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,#8*;7-G:60@(E)E8W5R<F5N8V4B"FUS9W-T
M<B`B5VEE9&5R:&]L=6YG(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@(E)E8W5R
M<F5N8V4@1&%T82(*;7-G<W1R(")7:65D97)H;VQU;F=S;75S=&5R(@H*(SH@
M9&%T82YP:'`Z-C8*;7-G:60@(E)E8W5R<F5N8V4@16YD($1A=&4B"FUS9W-T
M<B`B5VEE9&5R:&]L=6YG<V5N9&4B"@HC.B!D871A+G!H<#HV-PIM<V=I9"`B
M4F5C=7)R96YC92!);G1E<G9A;"(*;7-G<W1R(")7:65D97)H;VQU;F=S:6YT
M97)V86QL(@H*(SH@9&%T82YP:'`Z-C4*;7-G:60@(E)E8W5R<F5N8V4@5'EP
M92(*;7-G<W1R(")7:65D97)H;VQU;F=S='EP(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-30X"FUS9VED(")296-U<G,@9&%I;'DB"FUS9W-T<B`B5.1G;&EC
M:"(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4U-0IM<V=I9"`B4F5C=7)S(&UO
M;G1H;'DB"FUS9W-T<B`B36]N871L:6-H(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-34Q"FUS9VED(")296-U<G,@=V5E:VQY(@IM<V=S='(@(E?V8VAE;G1L
M:6-H(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34X"FUS9VED(")296-U<G,@
M>65A<FQY(@IM<V=S='(@(DKD:')L:6-H(@H*(SH@;&EB+U-C:&5D=6QE<B]K
M<F]N;VQI=&@N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296UI;F1E
M<CH@)7,B"FUS9W-T<B`B17)I;FYE<G5N9SH@)7,B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.30@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T"FUS9VED(")296UO=&4@0V%L96YD87)S(@IM<V=S='(@(D5X=&5R
M;F4@2V%L96YD97(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-C`@=&5M<&QA
M=&5S+VUE;G4N:6YC.C8R"FUS9VED(")296UO=&4@0V%L96YD87)S.B(*;7-G
M<W1R(")%>'1E<FYE($MA;&5N9&5R.B(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O8V%L96YD87)S+FEN8SHQ.30*;7-G:60@(E)E;6]T92!3=6)S8W)I<'1I
M;VX@55),(@IM<V=S='(@(D%B;VYN96UE;G0M55),(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C$*;7-G:60@(E)E;6]V92(*;7-G
M<W1R(")%;G1F97)N96XB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E("5S(@IM
M<V=S='(@(B5S(&5N=&9E<FYE;B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`P"FUS
M9VED(")296UO=F4@071T96YD964B"FUS9W-T<B`B5&5I;&YE:&UE<B!E;G1F
M97)N96XB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,Q"FUS9VED
M("(B"B)297!L86-E(&5X:7-T:6YG(&-A;&5N9&%R('=I=&@@=&AE(&EM<&]R
M=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL
M(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&-A;&5N9&%R+CPO<W1R;VYG/B(*
M;7-G<W1R("(B"B)%>&ES=&EE<F5N9&5N($MA;&5N9&5R(&UI="!D96T@:6UP
M;W)T:65R=&5N(&5R<V5T>F5N/R`\<W1R;VYG/E=A<FYU;F<Z($1A;6ET("(*
M(G=E<F1E;B!A;&QE(&%K='5E;&QE;B!%:6YT<N1G92!I;B!D96T@2V%L96YD
M97(@9V5L]G-C:'0N/"]S=')O;F<^(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-C,W"FUS9VED(")297%U:7)E9"(*;7-G<W1R(").;W1W96YD:6<B"@HC.B!L
M:6(O1D)6:65W+G!H<#HY."!L:6(O1D)6:65W+G!H<#HQ,SD@;&EB+T9"5FEE
M=RYP:'`Z,30R(&QI8B]&0E9I97<N<&AP.C$T-0IM<V=I9"`B4F5Q=6ER960@
M071T96YD965S(@IM<V=S='(@(DYO='=E;F1I9V4@5&5I;&YE:&UE<B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,R('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C,P.`IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B
M6G5R_&-K<V5T>F5N(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC.C0S('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-@IM<V=I9"`B
M4F5S<&]N<V4B"FUS9W-T<B`B06YW;W)T(@H*(SH@>65A<BYP:'`Z.#4@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C0@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C(P"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED
M(")382(*;7-G<W1R(")382(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN
M8SHR,2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C`*(SH@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-S,*;7-G:60@(E-A='5R9&%Y(@IM<V=S
M='(@(E-A;7-T86<B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,C`S"FUS9VED(")3879E(@IM<V=S='(@(E-P96EC:&5R;B(*"B,Z
M('9I97=E=F5N="YP:'`Z,3,U(&5D:71E=F5N="YP:'`Z-#D@961I=&5V96YT
M+G!H<#HU-PIM<V=I9"`B4V%V92!!<R!.97<B"FUS9W-T<B`B06QS($MO<&EE
M('-P96EC:&5R;B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S
M+FEN8SHX,PIM<V=I9"`B4V%V92!!='1E;F1E97,B"FUS9W-T<B`B5&5I;&YE
M:&UE<B!S<&5I8VAE<FXB"@HC.B!A9&1E=F5N="YP:'`Z-34@961I=&5V96YT
M+G!H<#HU,@IM<V=I9"`B4V%V92!%=F5N="(*;7-G<W1R(")497)M:6X@<W!E
M:6-H97)N(@H*(SH@<V5A<F-H+G!H<#HY,2!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:%]A9'9A;F-E9"YI;F,Z,3$T"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHV-R!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z.`HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$T-2!L:6(O0FQO
M8VLO=')E95]M96YU+G!H<#HR-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E-U
M8VAE(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$*;7-G
M:60@(E-E87)C:"!#86QE;F1A<G,B"FUS9W-T<B`B2V%L96YD97(@4W5C:&5N
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C8*;7-G:60@(E-E
M87)C:"!297-U;'1S(@IM<V=S='(@(E-U8VAE<F=E8FYI<W-E(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C8*;7-G:60@(E-E87)C:"!F
M;W(@8V%L96YD87)S(&-O;G1A:6YI;F<Z(@IM<V=S='(@(DYA8V@@2V%L96YD
M97)N('-U8VAE;CHB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,34S"FUS9VED(")396QE8W0@82!C86QE;F1A<B!T;R!E9&ET(@IM
M<V=S='(@(E?D:&QE;B!3:64@96EN96X@2V%L96YD97(@>G5M($)E87)B96ET
M96X@875S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8U('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"FUS9VED(")396QE8W0@82!D871E
M(@IM<V=S='(@(D1A='5M(&%U<W?D:&QE;B(*"B,Z('1E;7!L871E<R]M96YU
M+FEN8SHS,`IM<V=I9"`B4V5L96-T(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.B(*
M;7-G<W1R(")7Y&AL96X@4VEE($MA;&5N9&5R(&%U<SHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$*;7-G:60@(B(*(E-E;&5C="!C;VYF:7)M871I
M;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W
M<R!A;F0@8VAO;W-E("(*(F1E9F%U;'0@=FEE=RXB"FUS9W-T<B`B(@HB3&5G
M96X@4VEE($)E<W3D=&EG=6YG<RU%:6YS=&5L;'5N9V5N(&9E<W0L('=I92!D
M:64@=6YT97)S8VAI961L:6-H96X@(@HB06YS:6-H=&5N(&1A<F=E<W1E;&QT
M('=E<F1E;B!S;VQL96XL('5N9"!WY&AL96X@4VEE(&5I;F4@4W1A;F1A<F1A
M;G-I8VAT+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3@*;7-G
M:60@(E-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.B(*;7-G<W1R
M(")7Y&AL96X@4VEE(&1E;B!+86QE;F1E<BP@:6X@9&5N(&EM<&]R=&EE<G0@
M=V5R9&5N('-O;&PZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M.0IM<V=I9"`B4V5L96-T('1H92!C86QE;F1A<BAS*2!T;R!E>'!O<G0@9G)O
M;2(*;7-G<W1R(")7Y&AL96X@4VEE(&1E;B]D:64@2V%L96YD97(L(&1E<B]D
M:64@97AP;W)T:65R="!W97)D96X@<V]L;"AE;BDB"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F
M;W)M870Z(@IM<V=S='(@(E?D:&QE;B!3:64@9&%S($5X<&]R=&9O<FUA=#HB
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(W"FUS9VED(")396QE
M8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1I
M92!$871E:2P@9&EE(&EM<&]R=&EE<G0@=V5R9&5N('-O;&PZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B4V5L96-T('1H92!F:7)S
M="!W965K9&%Y.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1E;B!E<G-T96X@5V]C
M:&5N=&%G(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0IM<V=I
M9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G
M<W1R(")7Y&AL96X@4VEE(&1A<R!&;W)M870@9&5R(&EM<&]R=&EE<G1E;B!$
M871E:3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@T"FUS9VED(")3
M96QE8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W.B(*;7-G<W1R(")7Y&AL96X@
M4VEE(&1I92!:96ET<W!A;FYE+"!D:64@86YG97IE:6=T('=E<F1E;B!S;VQL
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B4V5L96-T
M('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A<G1U<#HB"FUS9W-T<B`B5^1H
M;&5N(%-I92!D:64@06YS:6-H="!A=7,L(&1I92!B96EM(%-T87)T(&%N9V5Z
M96EG="!W97)D96X@<V]L;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C(*;7-G:60@(E-E;&5C="!W:&EC:"!E=F5N=',@=&\@<VAO=R!I;B!T:&4@
M<&]R=&%L+B(*;7-G<W1R("(B"B),96=E;B!3:64@9F5S="P@=V5L8VAE(%1E
M<FUI;F4@875F(&1E<B!0;W)T86QS96ET92!A;F=E>F5I9W0@=V5R9&5N('-O
M;&QE;BXB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C<@=&5M<&QA
M=&5S+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED(")396YD(&$@8V%N8V5L
M(&YO=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@
M=&AI<R!E=F5N="(*;7-G<W1R("(B"B)%:6YE(%1E<FUI;F%B<V%G92!A;B!A
M;&QE(%1E:6QN96AM97(@<V-H:6-K96XL('=E;FX@9&EE<V5R(%1E<FUI;B!G
M96SV<V-H="`B"B)W:7)D(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E-E;F0@86X@96UA:6P@=&\@)7,B
M"FUS9W-T<B`B16UA:6P@86X@)7,@<V-H<F5I8F5N(@H*(SH@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,3<Y"FUS9VED(")396YD('5P9&%T97,O:6YV:71A
M=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V96YT
M(@IM<V=S='(@(B(*(D%K='5A;&ES:65R=6YG96XO16EN;&%D=6YG96X@86X@
M86QL92!496EL;F5H;65R/&)R("\^7&XB"B)S8VAI8VME;BP@=V5N;B!D:65S
M97(@5&5R;6EN(&=E<W!E:6-H97)T('=I<F0N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-S8*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R
M(")397!T96UB97(B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N
M+FEN8SHX,PIM<V=I9"`B4V5T(&5N9"!D871E(@IM<V=S='(@(D5N9&1A='5M
M(&9E<W1L96=E;B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V-0IM
M<V=I9"`B4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`B5VEE9&5R
M:&]L=6YG<V5N9&4@9F5S=&QE9V5N(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,S$*;7-G:60@(E-E="!S=&%R="!D871E(@IM<V=S
M='(@(E-T87)T9&%T=6T@9F5S=&QE9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4Y"FUS9VED("(B"B)3970@>6]U<B!F<F5E+V)U<WD@8V%L96YD
M87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H97(@=7-E<G,G(&9R964O8G5S>2!O
M<'1I;VYS+B(*;7-G<W1R("(B"B),96=E;B!3:64@26AR92!&<F5I+T=E8G5C
M:'0M2V%L96YD97(@=6YD("U%:6YS=&5L;'5N9V5N('5N9"!D:64@86YD97)E
M<B`B"B)"96YU='IE<B!F97-T+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4VAA<F4@;F]T(&9O=6YD.B`E<R(*;7-G<W1R
M(")'96UE:6YS86UE<B!+86QE;F1E<B!N:6-H="!G969U;F1E;CH@)7,B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.#(*;7-G:60@
M(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T<B`B1V5M96EN<V%M92!+86QE;F1E
M<B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHT-R!T96UP;&%T97,O;65N=2YI
M;F,Z-#D*;7-G:60@(E-H87)E9"!#86QE;F1A<G,Z(@IM<V=S='(@(D=E;65I
M;G-A;64@2V%L96YD97(Z(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H<#HR-2!T
M96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC.B!T96UP
M;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHS"FUS9VED(")3:&]W
M($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R($%N>F5I9V5N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$U-@IM<V=I9"`B4VAO=R!C871E9V]R>2!L
M96=E;F0_(@IM<V=S='(@(DMA=&5G;W)I96YL96=E;F1E(&%N>F5I9V5N/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(E-H;W<@9&5L
M971E+"!A;&%R;2P@86YD(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD87(@
M=FEE=W,_(@IM<V=S='(@(B(*(DSV<V-H96XM+"!!;&%R;2T@=6YD(%=I961E
M<FAO;'5N9W-S>6UB;VQE(&EN(&1E<B!+86QE;F1E<F%N<VEC:'0@86YZ96EG
M96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO
M=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R/R(*;7-G<W1R(")&Y&QL:6=E
M($%U9F=A8F5N(&EM($MA;&5N9&5R(&%N>F5I9V5N/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-C8*;7-G:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N
M9#\B"FUS9W-T<B`B1G)E:2]'96)U8VAT+4QE9V5N9&4@86YZ96EG96X_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,PIM<V=I9"`B4VAO=R!O;FQY
M(&5V96YT<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/R(*;7-G<W1R(").=7(@
M5&5R;6EN92!M:70@06QA<FT@86YZ96EG96X_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$W-0IM<V=I9"`B4VAO=R!S:&%R960@8V%L96YD87)S('-I
M9&4M8GDM<VED93\B"FUS9W-T<B`B1V5M96EN<V%M92!+86QE;F1E<B!N96)E
M;F5I;F%N9&5R(&%N>F5I9V5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C$*;7-G:60@(E-H;W<@=&%S:W,@=7-I;F<@8V%T96=O<GD@8V]L;W)S
M/R(*;7-G<W1R(")!=69G86)E;B!I;B!D96X@2V%T96=O<FEE9F%R8F5N(&%N
M>F5I9V5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B
M4VAO=R!T:6UE(&]F(&1A>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE
M=W,_(@IM<V=S='(@(E5H<GIE:71E;B!Z=VES8VAE;B!A;&QE;B!486=E;B!I
M;B!D96X@5V]C:&5N86YS:6-H=&5N(&%N>F5I9V5N/R(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q"FUS9VED(")3=&%?<G0B"FUS
M9W-T<B`B7T)E9VEN;B(*"B,Z(&1A=&$N<&AP.C4T"FUS9VED(")3=&%R="!$
M871E(@IM<V=S='(@(E-T87)T9&%T=6TB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+V5V96YT7VAE861E<G,N:6YC.C<@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M-#$*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS-PIM<V=I9"`B4W1A
M<G0@3VXB"FUS9W-T<B`B0F5G:6YN(@H*(SH@9&%T82YP:'`Z-34*;7-G:60@
M(E-T87)T(%1I;64B"FUS9W-T<B`B4W1A<G1Z96ET(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.CDT('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C@S"FUS9VED(")3=&%T7W5S(@IM<V=S='(@(E]3=&%T=7,B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C8@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T871U<R(*;7-G<W1R
M(")3=&%T=7,B"@HC.B!Y96%R+G!H<#HW."!Y96%R+G!H<#HX-R!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-0HC.B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,C$@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#<@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ,#D*;7-G:60@(E-U(@IM<V=S='(@(E-O(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H96%D
M+FEN8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA
M=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(E-O;FYT86<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*;7-G:60@(E1A<VMS(@IM<V=S
M='(@(D%U9F=A8F5N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3@U(&QI8B]+
M<F]N;VQI=&@N<&AP.C8P.`IM<V=I9"`B5&5N=&%T:79E(@IM<V=S='(@(E5N
M=&5R(%9O<F)E:&%L="(*"B,Z('EE87(N<&AP.C@S('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q
M.`HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS9W-T
M<B`B1&\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C<P
M"FUS9VED(")4:&4@161I="!!='1E;F1E97,@<V-R965N(&ES(&YO(&QO;F=E
M<B!P<F5S96YT+B!%>&ET:6YG+B(*;7-G<W1R(")$:64@5&5I;&YE:&UE<F%N
M<VEC:'0@:7-T(&YI8VAT(&UE:'(@9V5L861E;BX@06)B<G5C:"XB"@HC.B!C
M86QE;F1A<G,N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE
M;F1A<B!<(B5S7"(@8V%N;F]T(&)E(&1E;&5T960N(@IM<V=S='(@(D1E<B!+
M86QE;F1E<B!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BXB
M"@HC.B!C86QE;F1A<G,N<&AP.C0P"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B
M1&5R($MA;&5N9&5R(%PB)7-<(B!W=7)D92!E<GIE=6=T+B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")$97(@2V%L96YD
M97(@7"(E<UPB('=U<F1E(&=E;/9S8VAT+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z
M-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H
M87,@8F5E;B!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B1&5R($MA;&5N
M9&5R(%PB)7-<(B!W=7)D92!N86-H(%PB)7-<(B!U;6)E;F%N;G0N(@H*(SH@
M8V%L96YD87)S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L
M96YD87(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")$97(@2V%L
M96YD97(@7"(E<UPB('=U<F1E(&=E<W!E:6-H97)T+B(*"B,Z(&1A=&$N<&AP
M.C(S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@8V]U;&0@
M;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B1&5R($MA;&5N9&5R(&MO;FYT
M92!N:6-H="!G96QE97)T('=E<F1E;CH@)7,B"@HC.B!T96UP;&%T97,O961I
M="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@(E1H92!E;F0@9&%T92!M=7-T
M(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N(@IM<V=S='(@(D1A<R!%
M;F1D871U;2!M=7-S(&AI;G1E<B!D96T@4W1A<G1D871U;2!L:65G96XN(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&%D9&5D('1O(%PB)7-<
M(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S='(@(B(*
M(D1E<B!497)M:6X@7"(E<UPB+"!D97(@86T@)3,D<R!U;2`E-"1S(%5H<B!S
M=&%T=&9I;F1E="P@=W5R9&4@>G5M($MA;&5N9&5R("(*(EPB)3(D<UPB(&AI
M;GIU9V5F_&=T+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D(&9R;VT@7"(E<UPB(&-A;&5N9&%R+"!W:&EC:"!W87,@;VX@)7,@
M870@)2(*(G,N(@IM<V=S='(@(B(*(D1E<B!497)M:6X@7"(E<UPB+"!D97(@
M86T@)3,D<R!U;2`E-"1S(%5H<B!S=&%T=&9I;F1E;B!S;VQL=&4L('=U<F1E
M(&%U<R!D96T@(@HB2V%L96YD97(@7"(E,B1S7"(@9V5L]G-C:'0N(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"!O;B!<(B5S7"(@
M8V%L96YD87(L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R("(B"B)$
M97(@5&5R;6EN(%PB)7-<(BP@9&5R(&%M("4S)',@=6T@)30D<R!5:'(@<W1A
M='1F:6YD970L('=U<F1E(&EM($MA;&5N9&5R(%PB)2(*(C(D<UPB(&=EY&YD
M97)T+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@<W5C
M8V5S<V9U;&QY('-E;G0N(@IM<V=S='(@(DEH<F4@5&5R;6EN8F5N86-H<FEC
M:'1I9W5N9R!A;B`E<R!W=7)D92!E<F9O;&=R96EC:"!V97)S96YD970N(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`T-`IM<V=I9"`B5&AE(&9O;&QO=VEN
M9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V96YT
M.B(*;7-G<W1R(")(:65R(&ES="!E:6YE(&1E=&%I;&QI97)T97)E($)E<V-H
M<F5I8G5N9R!D97,@5&5R;6EN<SHB"@HC.B!A='1E;F0N<&AP.C0Q"FUS9VED
M("(B"B)4:&4@<F5Q=65S="!W87,@:6YC;VUP;&5T92X@4V]M92!P87)A;65T
M97)S('1H870@87)E(&YE8V5S<V%R>2!T;R!A8V-E<'0@;W(@(@HB9&5C;&EN
M92!A;B!E=F5N="!A<F4@;6ES<VEN9RXB"FUS9W-T<B`B(@HB1&EE($%N9G)A
M9V4@=V%R('5N=F]L;'-TY&YD:6<N($5I;FEG92!D97(@4&%R86UE=&5R+"!D
M:64@;F]T=V5N9&EG('-I;F0L('5M("(*(F5I;F5N(%1E<FUI;B!Z=2!B97-T
MY'1I9V5N(&]D97(@86)Z=7-A9V5N+"!F96AL96XN(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]E;7!T>2YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&5V96YT
M<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B17,@
M=W5R9&5N(&ME:6YE('!A<W-E;F1E;B!497)M:6YE(&=E9G5N9&5N+B(*"B,Z
M(&%D9&5V96YT86-T:6]N+G!H<#HQ."!E9&ET979E;G1A8W1I;VXN<&AP.C,U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8V-E
M<W-I;F<@=&AE(&-A;&5N9&%R.B`E<R(*;7-G<W1R(")"96EM(%IU9W)I9F8@
M875F(&1E;B!+86QE;F1E<B!I<W0@96EN($9E:&QE<B!A=69G971R971E;CH@
M)7,N(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C,T"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E
M<R(*;7-G<W1R(")"96EM($AI;GIU9OQG96X@9&5S(%1E<FUI;G,@:7-T(&5I
M;B!&96AL97(@875F9V5T<F5T96XZ("5S+B(*"B,Z(&5D:71E=F5N=&%C=&EO
M;BYP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&5D:71I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")"96EM($)E87)B
M96ET96X@9&5S(%1E<FUI;G,@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XZ
M("5S+B(*"B,Z(&QI8B]A<&DN<&AP.C,S."!L:6(O87!I+G!H<#HV,3<*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R(")"96EM($EM<&]R=&EE<F5N(&1E<B!I0V%L96YD
M87(@1&%T96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN(@H*(SH@961I
M=&5V96YT86-T:6]N+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B
M0F5I;2!697)S8VAI96)E;B!D97,@5&5R;6EN<R!I<W0@96EN($9E:&QE<B!A
M=69G971R971E;CH@)7,N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V5N9&EN
M9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S(@IM<V=S='(@(B(*
M(D)E:6T@5F5R<V-H:6-K96X@96EN97(@5&5R;6EN8F5N86-H<FEC:'1I9W5N
M9R!A;B`E<R!I<W0@96EN($9E:&QE<B`B"B)A=69G971R971E;CH@)7,B"@HC
M.B!D871A+G!H<#HQ,#@*;7-G:60@(E1H97)E('=E<F4@;F\@979E;G1S('1O
M(&5X<&]R="XB"FUS9W-T<B`B17,@:V]N;G1E;B!K96EN92!497)M:6YE('IU
M;2!%>'!O<G1I97)E;B!G969U;F1E;B!W97)D96XN(@H*(SH@9&%T82YP:'`Z
M,3@W"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(D1I97-E<R!$871E:69O<FUA="!W:7)D(&YI8VAT('5N=&5R
M<W3\='IT+B(*"B,Z(&1A=&$N<&AP.C(U,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R(")-
M96QD=6YG(&1E<R!397)V97)S.B`E<R(*"B,Z('1E;7!L871E<R]M;VYT:"]H
M96%D+FEN8SHQ.2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3@*(SH@=&5M
M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S$*;7-G:60@(E1H=7)S9&%Y
M(@IM<V=S='(@(D1O;FYE<G-T86<B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z,S<*;7-G:60@(E1I;64@4W!?86XB"FUS9W-T<B`B6F5I='-?
M<&%N;F4B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHT
M"FUS9VED(")4:6UE('-P86XB"FUS9W-T<B`B6F5I='-P86YN92(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHS-"!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHS.`IM<V=I9"`B5&ET7VQE(@IM<V=S='(@(E1I
M=&5?;"(*"B,Z(&1A=&$N<&AP.C4S('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC
M.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I=&5L(@H*(SH@;&EB+T)L;V-K
M+W!R979M;VYT:&QI<W0N<&AP.C$R,B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H
M<#HQ,C$*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R-PIM<V=I9"`B5&]D
M87DB"FUS9W-T<B`B2&5U=&4B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES
M="YP:'`Z,3(T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$R,PHC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,3(Y"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R
M(")-;W)G96XB"@HC.B!Y96%R+G!H<#HX,2!T96UP;&%T97,O:F%V87-C<FEP
M="]G;W1O+FEN8SHV,"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,38*(SH@
M;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1U(@IM<V=S='(@(D1I
M(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$W('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$Q-@HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T
M+FEN8SHV.0IM<V=I9"`B5'5E<V1A>2(*;7-G<W1R(")$:65N<W1A9R(*"B,Z
M(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B5'EP92(*;7-G
M<W1R(")4>7`B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z,3@V"FUS9VED(")54DPB"FUS9W-T<B`B2&]M97!A9V4B"@HC.B!L:6(O
M4W1O<F%G92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T
M;R!344P@<V5R=F5R+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2!344P@4V5R
M=F5R(&MA;FX@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N+B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(EPB)7-<(B!K86YN(&YI8VAT(&=E
M;/9S8VAT('=E<F1E;CH@)7,B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(D1E<B`E<RU4<F5I8F5R(&MO;FYT92!N:6-H
M="!G96QA9&5N('=E<F1E;BXB"@HC.B!C86QE;F1A<G,N<&AP.C4Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@7"(E<UPB.B`E<R(*
M;7-G<W1R(")<(B5S7"(@:V%N;B!N:6-H="!U;6)E;F%N;G0@=V5R9&5N.B`E
M<R(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HS.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N(&9O<B`E<R(*;7-G<W1R(")&96AL97(@8F5I;2!!=7-L97-E;B!D97(@
M1G)E:2]'96)U8VAT+4EN9F]R;6%T:6]N96X@9OQR("5S(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,34*(SH@<V-R:7!T<R]U<&=R861E<R\R,#`T
M+3`U+3$Y7V-O;G9E<G1?8V%T96=O<FEE<U]T;U]S=')I;F=S+G!H<#HU,PIM
M<V=I9"`B56YF:6QE9"(*;7-G<W1R(").:6-H="!Z=6=E;W)D;F5T(@H*(SH@
M;&EB+V%P:2YP:'`Z,S<V(&QI8B]A<&DN<&AP.C0V,"!L:6(O87!I+G!H<#HU
M,S8@;&EB+V%P:2YP:'`Z-C0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P
M<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B3FEC:'0@=6YT97)S
M=/QT>G1E<B!);FAA;'1S='EP.B`E<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$P,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9#H@)7,N(@IM<V=S
M='(@(D%K='5A;&ES:65R=#H@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P"FUS9VED(")5<V5R($EN=&5R9F%C92(*;7-G<W1R(")"96YU='IE
M<F]B97)F;.1C:&4B"@HC.B!Y96%R+G!H<#HQ-C`@>65A<BYP:'`Z,38V(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,38R
M"FUS9VED(")6:65W($1A>2(*;7-G<W1R(")486<@86YZ96EG96XB"@HC.B!Y
M96%R+G!H<#HX,B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,2!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,3<*(SH@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HQ,#4*;7-G:60@(E=E(@IM<V=S='(@(DUI(@H*(SH@=&5M<&QA=&5S
M+VUO;G1H+VAE860N:6YC.C$X('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q
M-PHC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,`IM<V=I9"`B
M5V5D;F5S9&%Y(@IM<V=S='(@(DUI='1W;V-H(@H*(SH@871T96YD965S+G!H
M<#HQ,#@@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,R!L:6(O0FQO8VLO=')E95]M
M96YU+G!H<#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@
M(E=E96LB"FUS9W-T<B`B5V]C:&4B"@HC.B!M;VYT:"YP:'`Z,3<W('=O<FMW
M965K+G!H<#HS,"!W965K+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M965K("5D(@IM<V=S='(@(B5D+B!7;V-H92(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C4Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S.`IM<V=I
M9"`B5V5E:RAS*2(*;7-G<W1R(")7;V-H92AN*2(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3(*
M;7-G:60@(E=E96ML>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(E?V8VAE;G1L
M:6-H.B!7:65D97)H;VQU;F<@86QL92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C0*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W
M965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S
M/R(*;7-G<W1R("(B"B)786YN('-O;&QE;B!D:64@5&%G97,M('5N9"!7;V-H
M96YA;G-I8VAT96X@96YD96XL('=E;FX@:V5I;F4@<W#D=&5R96X@(@HB5&5R
M;6EN92!V;W)L:65G96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-0IM<V=I9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE
M=W,@<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/R(*
M;7-G<W1R("(B"B)786YN('-O;&QE;B!D:64@5&%G97,M('5N9"!7;V-H96YA
M;G-I8VAT96X@96YD96XL('=E;FX@:V5I;F4@9G+\:&5R96X@(@HB5&5R;6EN
M92!V;W)L:65G96X_(@H*(SH@871T96YD965S+G!H<#HQ,#<@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3,Q,B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E=O<FL@5V5E:R(*;7-G
M<W1R(")!<F)E:71S=V]C:&4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S$U
M(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(U"FUS9VED(")996%R(@IM<V=S
M='(@(DIA:'(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C,X"FUS9VED(")996%R;'DZ(%)E8W5R
M<R!E=F5R>2(*;7-G<W1R(")*Y&AR;&EC:#H@5VEE9&5R:&]L=6YG(&%L;&4B
M"@HC.B!D871A+G!H<#HS.2!D871A+G!H<#HR,SD@961I=&5V96YT86-T:6]N
M+G!H<#HT-B!A9&1E=F5N="YP:'`Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&5V
M96YT<RXB"FUS9W-T<B`B4VEE(&3\<F9E;B!N:6-H="!M96AR(&%L<R`E9"!4
M97)M:6YE(&5R<W1E;&QE;BXB"@HC.B!A='1E;F0N<&AP.C0Y"FUS9VED(")9
M;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF:65D(&5V96YT
M+B(*;7-G<W1R(")3:64@<VEN9"!K96EN(%1E:6QN96AM97(@9&EE<V5S(%1E
M<FUI;G,N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW
M-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T:&ES(&9O<FT@9G)O;2!T:&4@
M161I="!!='1E;F1E97,@<V-R965N+B(*;7-G<W1R(")3:64@:_9N;F5N(&1I
M97-E<R!&;W)M=6QA<B!N=7(@=F]N(&1E<B!496EL;F5H;65R86YS:6-H="!A
M=7,@8F5N=71Z96XN(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3@X"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A
M9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO
M;B`B"B)/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S:&5R925S(&)E9F]R
M92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B
M"B)3:64@:&%B96X@:6X@26AR96X@16EN<W1E;&QU;F=E;B!U;G1E<B!097)S
M]FYL:6-H92!);F9O<FUA=&EO;F5N(&ME:6YE("(*(D5M86EL861R97-S92!A
M;F=E9V5B96XN(%-I92!M_'-S96X@)7-H:65R)7,@96EN92!!9')E<W-E(&5I
M;G1R86=E;BP@8F5V;W(@(@HB5&5R;6EN8F5N86-H<FEC:'1I9W5N9V5N('9E
M<G-C:&EC:W0@=V5R9&5N(&OV;FYE;BXB"@HC.B!A9&1E=F5N=&%C=&EO;BYP
M:'`Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E<RXB"FUS9W-T<B`B4VEE(&AA
M8F5N(&YI8VAT(&=E;OQG96YD(%)E8VAT92P@=6T@5&5R;6EN92!Z=2`E<R!H
M:6YZ=7IU9OQG96XN(@H*(SH@9&%T82YP:'`Z,3DW"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE
M8W1E9"!C86QE;F1A<BXB"FUS9W-T<B`B(@HB4VEE(&AA8F5N(&YI8VAT(&=E
M;OQG96YD(%)E8VAT92P@=6T@5&5R;6EN92!Z=2!D96T@875S9V5WY&AL=&5N
M($MA;&5N9&5R("(*(FAI;GIU>G5F_&=E;BXB"@HC.B!D96QE=F5N=&%C=&EO
M;BYP:'`Z,C8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M(&1E;&5T92!T:&ES(&5V96YT+B(*;7-G<W1R(")3:64@:&%B96X@;FEC:'0@
M9V5N_&=E;F0@4F5C:'1E+"!U;2!D:65S96X@5&5R;6EN('IU(&SV<V-H96XN
M(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HW.`IM<V=I9"`B66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@961I="!T:&ES(&5V96YT+B(*;7-G<W1R
M(")3:64@:&%B96X@;FEC:'0@9V5N_&=E;F0@4F5C:'1E+"!U;2!D:65S96X@
M5&5R;6EN('IU(&)E87)B96ET96XN(@H*(SH@9&%T82YP:'`Z,3DR"FUS9VED
M(")9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BXB"FUS
M9W-T<B`B4VEE(&AA8F5N(&5I;F5N('5N9_QL=&EG96X@2V%L96YD97(@86YG
M96=E8F5N+B(*"B,Z(&%T=&5N9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E('-U
M8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N
M(@IM<V=S='(@(E-I92!H86)E;B!E<F9O;&=R96EC:"!D:64@5&5I;&YA:&UE
M(&%N(&1I97-E;2!%=F5N="!Z=6=E<V%G="XB"@HC.B!A='1E;F0N<&AP.C(V
M"FUS9VED(")9;W4@:&%V92!S=6-C97-S9G5L;'D@9&5C;&EN960@871T96YD
M96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R(")3:64@:&%B96X@97)F;VQG
M<F5I8V@@9&EE(%1E:6QN86AM92!A;B!D:65S96T@179E;G0@86)G97-A9W0N
M(@H*(SH@871T96YD+G!H<#HS,0IM<V=I9"`B66]U(&AA=F4@=&5N=&%T:79E
M;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R
M(")3:64@:&%B96X@=6YT97(@5F]R8F5H86QT(&1I92!496EL;F%H;64@86X@
M9&EE<V5M($5V96YT('IU9V5S86=T+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.3$*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T
M960N(@IM<V=S='(@(E-I92!M_'-S96X@97)S="!D96X@>G4@;/9S8VAE;F1E
M;B!+86QE;F1E<B!A=7-WY&AL96XN(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHU-`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D
M9')E<W,@9FER<W0N(@IM<V=S='(@(E-I92!M_'-S96X@97)S="!E:6YE($%D
M<F5S<V4@875S=^1H;&5N+B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L
M96YD87)S+FEN8SHQ-S,*;7-G:60@(EEO=2!N965D('1O('-E;&5C="!A(&-A
M;&5N9&%R(&9I<G-T(@IM<V=S='(@(E-I92!M_'-S96X@97)S="!E:6YE;B!+
M86QE;F1E<B!A=7-WY&AL96XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$T
M"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E
M;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@HB
M4VEE('=O;&QT96X@8F5N86-H<FEC:'1I9W0@=V5R9&5N+"!W96YN(%1E<FUI
M;F4@>G4@26AR96X@2V%L96YD97)N("(*(FAI;GIU9V5F_&=T('=E<F1E;BXB
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3(T"FUS9VED("(B"B)9;W4@<F5Q
M=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!D96QE=&5D
M(&9R;VT@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*(E-I92!W;VQL=&5N
M(&)E;F%C:')I8VAT:6=T('=E<F1E;BP@=V5N;B!497)M:6YE(&%U<R!):')E
M;B!+86QE;F1E<FX@9V5L]G-C:'0@(@HB=V5R9&5N+B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$Q,3D*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@;F]T
M:69I960@=VAE;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R(&-A;&5N9&%R
M<RXB"FUS9W-T<B`B(@HB4VEE('=O;&QT96X@8F5N86-H<FEC:'1I9W0@=V5R
M9&5N+"!W96YN(%1E<FUI;F4@:6X@26AR96X@2V%L96YD97)N(&=EY&YD97)T
M("(*(G=E<F1E;BXB"@HC.B!L:6(O4V-H961U;&5R+VMR;VYO;&ET:"YP:'`Z
M,C$Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@
M<F5M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G
M<W1R("(B"B)3:64@=V]L;'1E;B#\8F5R("5S(&)E;F%C:')I8VAT:6=T('=E
M<F1E;BP@9&%S(&%M("5S('5M("5S('-T871T9FEN9&5T+B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*;7-G:60@(EEO=7(@9&5F
M875L="!C86QE;F1A<B(*;7-G<W1R(")):'(@4W1A;F1A<F0M2V%L96YD97(B
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#4Y(&QI8B]$<FEV97(N<&AP.C$P-CD*
M;7-G:60@(EM5;FYA;65D(&5V96YT72(*;7-G<W1R(");56YB96YA;FYT97(@
M5&5R;6EN72(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.CDU"FUS9VED
M(")?06QA<FTB"FUS9W-T<B`B7T%L87)M(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8VA?861V86YC960N:6YC.C$Q"FUS9VED(")?0F%S:6,@4V5A<F-H
M(@IM<V=S='(@(D5I;E]F86-H92!3=6-H92(*"B,Z('9I97=E=F5N="YP:'`Z
M,3,W"FUS9VED(")?161I="(*;7-G<W1R(")?0F5A<F)E:71E;B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$S-3`*;7-G:60@(E]';W1O(@IM<V=S='(@(E]'
M96AE('IU(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,U-@IM<V=I9"`B7TEM
M<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R="]%>'!O<G0B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,S,W"FUS9VED(")?37D@0V%L96YD87)S(@IM<V=S
M='(@(E]-96EN92!+86QE;F1E<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M-#0*;7-G:60@(E].97<@179E;G0B"FUS9W-T<B`B7TYE=65R(%1E<FUI;B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-C$*;7-G:60@(E]0<FEN="(*;7-G
M<W1R(")?1')U8VME;B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-3(*;7-G
M:60@(E]396%R8V@B"FUS9W-T<B`B7U-U8VAE(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,T-PIM<V=I9"`B7U1O9&%Y(@IM<V=S='(@(DAE7W5T92(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$T,`IM<V=I9"`B8F5F;W)E('1H
M92!E=F5N="!S=&%R=',B"FUS9W-T<B`B=F]R(&1E;2!497)M:6YB96=I;FXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@U"FUS9VED(")D87DB"FUS
M9W-T<B`B5&%G(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(P-PIM<V=I9"`B9&%Y*',I(@IM<V=S
M='(@(E1A9RAE*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#8@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$X-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3@X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B9&%Y<R(*;7-G<W1R(")486=E(@H*
M(SH@9&%T82YP:'`Z,34P('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM
M<V=I9"`B979E;G1S+F-S=B(*;7-G<W1R(")T97)M:6YE+F-S=B(*"B,Z(&1A
M=&$N<&AP.C$W,0IM<V=I9"`B979E;G1S+FEC<R(*;7-G<W1R(")T97)M:6YE
M+FEC<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3,V
M"FUS9VED(")I;B(*;7-G<W1R(")I;B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$R-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C8*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C(W('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(S,PIM<V=I9"`B;6]N=&@H<RDB"FUS9W-T<B`B36]N870H92DB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#0P"B,L('!H<"UF;W)M870*;7-G:60@
M(F]N("5S(&%T("5S(@IM<V=S='(@(F%M("5S('5M("5S(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(R-PIM<V=I9"`B;VX@=&AE('-A;64@9&%T92(*;7-G<W1R(")A;2!G;&5I
M8VAE;B!$871U;2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,S,*;7-G:60@(F]N('1H92!S86UE
M('=E96MD87DB"FUS9W-T<B`B86T@9VQE:6-H96X@5V]C:&5N=&%G(@H*(SH@
M9&%T82YP:'`Z,CD@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-`IM<V=I
M9"`B=D-A;&5N9&%R+VE#86QE;F1A<B(*;7-G<W1R(")V0V%L96YD87(O:4-A
M;&5N9&%R(@H*(SH@;&EB+V%P:2YP:'`Z,S0Y(&QI8B]A<&DN<&AP.C8R.`IM
M<V=I9"`B=D5V96YT(&YO="!F;W5N9"XB"FUS9W-T<B`B=D5V96YT(&YI8VAT
M(&=E9G5N9&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3$*;7-G
M:60@(G=E96LB"FUS9W-T<B`B5V]C:&4B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$T"FUS9VED
M(")W965K*',I(&]N.B(*;7-G<W1R(")7;V-H92AN*2!A;3HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DR(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y-`IM<V=I9"`B=V5E:W,B
M"FUS9W-T<B`B5V]C:&5N(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S.0IM<V=I9"`B>65A<BAS
M*2(*;7-G<W1R(")*86AR*&4I(@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]P;R]N;%].3"YP;P``````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S$P-3<`,3`T,3<S-C(W
M-3(`,#(P-#(P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",@2W)O;F]L:71H($1U=&-H('1R86YS;&%T:6]N+@HC($-O<'ER
M:6=H="`H0RD@,C`P,2!*86X@2W5I<&5R<RX*(R!*86X@2W5I<&5R<R`\:G)K
M=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL/BP@,C`P,2X*(PIM<V=I9"`B(@IM
M<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2W)O;F]L:71H(#(N,"UC
M=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`T+3$R+3$Y(#$V.C0S*S`Q
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2F%N($MU:7!E<G,@/&IR:W5I<&5R
M<T!L875W97)S8V]L;&5G92YN;#Y<;B(*(DQA;F=U86=E+51E86TZ($1U=&-H
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X
M-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!C86QE;F1A<G,@9F]U;F0B"FUS9W-T
M<B`B1V5E;B!I0V%L96YD87)D871A(&=E=F]N9&5N+B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&5V96YT<R(*;7-G<W1R("(E9"!G96)E=7)T96YI<W-E;B(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!$87DH<RD@)7,@2&]U<BAS*2`E<R!-:6YU=&5S(@IM<V=S
M='(@(B5S(&1A9RAE;BD@)7,@=7)E;B`E<R!M:6YU=&5N(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3<X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A='1E;F1E
M97,B"FUS9W-T<B`B)7,@86%N=V5Z:6=E;B(*"B,Z(&1A=&$N<&AP.C(W-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O
M<G1E9"(*;7-G<W1R("(E<R!B97-T86YD(&UE="!S=6-C97,@9V5I;7!O<G1E
M97)D(@H*(SH@8V%L96YD87)S+G!H<#HQ,#4@;&EB+V)A<V4N<&AP.C$R.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S
M)W,@86=E;F1A(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC
M.C$W"FUS9VED("(B"B(H0VQI8VL@;VX@8V%L96YD87(@;F%M92!T;R!S=VET
M8V@@=&AE(&-A;&5N9&%R)W,@=FES:6)I;&ET>2!I;B!T:&4@;6%I;B`B"B)W
M:6YD;W<I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,38T"FUS9VED("(J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!!
M9&0@*B(*;7-G<W1R("(J($1E>F4@=&]E=F]E9V5N+"!K;&EK(&]P(%1O979O
M96=E;B`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M-3`*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S
M='(@(BH@4V5L96-T965R(&%D<F5S*'-E;BDL(&$N=2YB+B`J(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<X-@IM<V=I9"`B,2!A='1E;F1E92(*;7-G<W1R("(Q
M(&%A;G=E>FEG92(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT
M"FUS9VED("(Q(&5V96YT(@IM<V=S='(@(C$@9V5B975R=&5N:7,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,W"FUS9VED("(Q(&AO=7(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`HC+"!F=7IZ>0IM
M<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R(")-:6YU=&5N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM<V=I9"`B,C`@;6EN=71E
M<R(*;7-G<W1R(")-:6YU=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-@HC+"!F=7IZ>0IM<V=I9"`B,S`@;6EN=71E<R(*;7-G<W1R(")-:6YU
M=&5N(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3<Q"B,L(&9U>GIY
M"FUS9VED("(\<W1R;VYG/D%T=&5N9&5E<SPO<W1R;VYG/B`H;W!T:6]N86PI
M(@IM<V=S='(@(CQB/D%A;G=E>FEG96X\+V(^("AO<'1I92DB"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ-#D*(RP@9G5Z>GD*;7-G:60@(CQS=')O
M;F<^1&5S8W)I7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B
M/&(^3VUS8VAR7VEJ=FEN9SPO8CX@*&]P=&EE*2(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(W-PHC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY+97EW
M;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/E1R969W;V]R
M9&5N/"]B/B`H;W!T:64I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,3DT"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/E)E8W5R<F5N8V4\+W-T<F]N
M9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\8CY(97)H86QI;F<\+V(^("AO<'1I
M92DB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P,2!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$X,0IM<V=I9"`B04TB"FUS9W-T<B`B04TB
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.3$*;7-G:60@(D%C8V5P=&5D(@IM
M<V=S='(@(D=E86-C97!T965R9"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHQ,0IM<V=I9"`B061?=F%N8V5D(%-E87)C:"(*;7-G<W1R(")?
M56ET9V5B<F5I9"!Z;V5K96XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C$V,2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$Y,`IM<V=I9"`B061D(@IM<V=S='(@(E1O979O96=E;B(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(V"FUS9VED(")!9&0@179E;G0B"FUS9W-T
M<B`B1V5B975R=&5N:7,@=&]E=F]E9V5N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,S4*;7-G:60@(D%D9"!A(&YE
M=R!296UO=&4@0V%L96YD87(B"FUS9W-T<B`B3FEE=7=E(&%G96YD82!O<"!A
M9G-T86YD+"!T;V5V;V5G96XB"@HC.B!A9&1E=F5N="YP:'`Z-C0*;7-G:60@
M(D%D9"!A(&YE=R!E=F5N="(*;7-G<W1R(").:65U=V4@9V5B975R=&5N:7,@
M=&]E=F]E9V5N(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C<T"FUS9VED(")!9&0@871T96YD965S(@IM<V=S='(@(D%A;G=E>FEG
M96X@=&]E=F]E9V5N(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(P"B,Z('1E;7!L871E<R]A='1E;F1E
M97,O871T96YD965S+FEN8SHW.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S
M='(@(D%D<F5S8F]E:R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHX('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM
M<V=I9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(E5I=&=E8G)E:60@>F]E
M:V5N(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3,*;7-G:60@(D%L
M87)M(@IM<V=S='(@(D%L87)M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!D87ES(&)E9F]R92(*;7-G
M<W1R(")!;&%R;2`E9"!D86=E;B!V;V]R(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!H;W5R<R!B969O
M<F4B"FUS9W-T<B`B06QA<FT@)60@=7)E;B!V;V]R(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z,3<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!M:6YU
M=&5S(&)E9F]R92(*;7-G<W1R(")!;&%R;2`E9"!M:6YU=&5N('9O;W(B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ-S4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L
M87)M("5D('=E96MS(&)E9F]R92(*;7-G<W1R(")!;&%R;2`E9"!W96ME;B!V
M;V]R(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V,PIM<V=I9"`B06QA<FT@,2!D
M87D@8F5F;W)E(@IM<V=S='(@(D%L87)M(#$@9&%G('9O;W(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ-S8X"FUS9VED(")!;&%R;2`Q(&AO=7(@8F5F;W)E(@IM
M<V=S='(@(D%L87)M(#$@=75R('9O;W(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M-S<S"FUS9VED(")!;&%R;2`Q(&UI;G5T92!B969O<F4B"FUS9W-T<B`B06QA
M<FT@,2!M:6YU=70@=F]O<B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3@*;7-G
M:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B06QA<FT@,2!W965K
M('9O;W(B"@HC.B!D871A+G!H<#HV,`IM<V=I9"`B06QA<FT@1&%T92(*;7-G
M<W1R(")!;&%R;61A='5M(@H*(SH@9&%T82YP:'`Z-3D*;7-G:60@(D%L87)M
M(%-P86X@*&UI;G5T97,I(@IM<V=S='(@(D%L87)M9'5U<B`H;6EN=71E;BDB
M"@HC.B!D871A+G!H<#HV,0IM<V=I9"`B06QA<FT@5&EM92(*;7-G<W1R(")!
M;&%R;71I:F0B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S$*
M;7-G:60@(D%L;"(*;7-G<W1R(")!;&QE(@H*(SH@;&EB+T9"5FEE=RYP:'`Z
M,3(V(&QI8B]&0E9I97<N<&AP.C$R.2!L:6(O1D)6:65W+G!H<#HQ,S(*;7-G
M:60@(D%L;"!!='1E;F1E97,B"FUS9W-T<B`B06QL92!A86YW97II9V5N(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4Y"FUS9VED(")!;&P@
M1G5T=7)E(@IM<V=S='(@(D%L;&4@=&]E:V]M<W1I9V4B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*;7-G:60@(D%L;"!087-T(@IM<V=S
M='(@(D%L;&4@869G96QO<&5N(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI
M<W0N<&AP.C(W(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C0*(SH@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(U"FUS
M9VED(")!;&P@5FES:6)L92(*;7-G<W1R(")!;&QE('II8VAT8F%A<B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,B!L:6(O1&%Y
M5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.CDS"B,Z(&QI8B]7965K5FEE
M=RYP:'`Z,3(W(&QI8B]7965K5FEE=RYP:'`Z,3,T(&QI8B]$<FEV97(N<&AP
M.C$X,S(*;7-G:60@(D%L;"!D87DB"FUS9W-T<B`B1&4@9V5H96QE(&1A9R(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@
M979E;G0B"FUS9W-T<B`B1V5H96QE(&1A9R!D=7)E;F1E(&=E8F5U<G1E;FES
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM<V=I9"`B06QL
M(&5V96YT<R(*;7-G<W1R(")!;&QE(&=E8F5U<G1E;FES<V5N(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O2W)O;F]L
M:71H+G!H<#HV.#,*;7-G:60@(D%N>2(*;7-G<W1R(")%;&LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,0IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B07!R:6PB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N
M+FEN8SHS.2!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHY,PHC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C<P('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,34V"FUS9VED(")!="(*;7-G<W1R(")/<"(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P,C8*;7-G:60@(B(*(D%T=&%C:&5D(&ES(&%N
M(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T
M:&4@979E;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I
M<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P
M9&%T92`B"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G<W1R
M("(B"B)":6IG979O96=D(&ES(&5E;B!I0V%L96YD87(@8F5S=&%N9"!M970@
M;65E<B!I;F9O<FUA=&EE(&]V97(@9&4@9V5B975R=&5N:7,N("(*(E=A;FYE
M97(@=7<@;6%I;&-L:65N="!I5&EP('9E<GIO96ME;B!O;F1E<G-T975N="P@
M:W5N="!U(&1I="!B97-T86YD("(*(F=E8G)U:6ME;B!O;2!E96YV;W5D:6<@
M=7<@;&]K86QE(&MO<&EE('9A;B!D92!G96)E=7)T96YI<R!B:6H@=&4@=V5R
M:V5N+B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT
M,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C4*;7-G:60@(D%T=&5N9&%N
M8V4B"FUS9W-T<B`B06%N=V5Z:6=H96ED(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,38Q"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B06%N=V5Z
M:6=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<U"FUS
M9VED(")!=6=U<W0B"FUS9W-T<B`B075G=7-T=7,B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C@*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R(")%
M96YV;W5D:6<@>F]E:V5N(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T
M.C$W"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")697)J86%R9&%G(@H*(SH@
M;&EB+T9"5FEE=RYP:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$P"FUS9VED(")"
M=7-Y(@IM<V=S='(@(D)E>F5T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8VA?861V86YC960N:6YC.C0T"FUS9VED(")#7V%L96YD87(B"FUS9W-T<B`B
M05]G96YD82(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0Y"FUS9VED
M(")#86Q?96YD87(B"FUS9W-T<B`B7T%G96YD82(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#8@;&EB+T)L;V-K+W!R979M;VYT
M:&QI<W0N<&AP.C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C$@;&EB+T)L
M;V-K+VUO;G1H;&ES="YP:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,PIM<V=I9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G
M<W1R(")!9V5N9&%S86UE;G9A='1I;F<B"@HC.B!D871A+G!H<#HR,C@*(RP@
M9G5Z>GD*;7-G:60@(D-A;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G960N(@IM
M<V=S='(@(B5S(&)E<W1A;F0@;65T('-U8V-E<R!G96EM<&]R=&5E<F0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3<*;7-G:60@(D-A;&5N9&%R<R(*;7-G<W1R(")!9V5N
M9&$G<R(*"B,Z(&-A;&5N9&%R<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(D-A
M;&5N9&%R<R!M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R(")!9V5N9&%N86%M
M(@H*(SH@9&%T82YP:'`Z,C0S"FUS9VED(")#86XG="!C<F5A=&4@82!N97<@
M979E;G0N(@IM<V=S='(@(DMA;B!G965N(&YI975W92!G96)E=7)T96YI<R!M
M86ME;BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y
M,2!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S`*(SH@=&5M<&QA=&5S+V1E
M;&5T92]D96QE=&4N:6YC.C,R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,P.0IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(D%F8G)E:V5N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<P
M"FUS9VED(")#86YC96QL960B"FUS9W-T<B`B069G96)R;VME;B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M8V5L;&5D.B`E<R(*;7-G<W1R(")!9F=E8G)O:V5N.B`E<R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV-"!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHV.0IM<V=I9"`B0V%T96=O<E]Y(@IM<V=S='(@(E]#
M871E9V]R:64B"@HC.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V
M96YT7VAE861E<G,N:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*
M;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(D-A=&5G;W)I92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@(B(*(D-H;V]S92!I9B!Y;W4@
M=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T
M960@979E;G1S(&)Y("(*(F5M86EL.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D-H;V]S92!I9B!Y;W4@=V%N="!T
M;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E
M;G1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V5A<F-H7V%B
M;V]K7W-E;&5C="YI;F,Z,3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.0IM
M<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F;W(@
M9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(DMI97,@:&5T(&%D<F5S8F]E:R!V
M;V]R(&AE="!Z;V5K96X@=F%N('9R:6HO8F5Z970@55),<SHB"@HC.B!T96UP
M;&%T97,O<')E9G,O9F)?8V%L<U]S96QE8W0N:6YC.C$V"B,L(&9U>GIY"FUS
M9VED(")#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E(&EN('EO=7(@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B(*;7-G<W1R(")+:65S(&1E(&%G96YD
M82=S(&1I92!U(&%A;B!U=R!6<FEJ+T)E>F5T(&QI:G-T96X@=VEL="!T;V5V
M;V5G96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,0HC+"!F=7IZ
M>0IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!W:&5N
M(&=E;F5R871I;F<@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(DMI97,@:&5T
M(&%D<F5S8F]E:R!V;V]R(&AE="!Z;V5K96X@=F%N('9R:6HO8F5Z970@55),
M<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D-H;V]S
M92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@(DMI97,@=7<@<W1A
M;F1A87)D(&%G96YD82XB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z-C4*(RP@9G5Z>GD*;7-G:60@(D-L96%R(&%L;"!A='1E;F1E
M97,B"FUS9W-T<B`B06QL92!A86YW97II9V5N('=I<W-E;B(*"B,Z(&1A=&$N
M<&AP.C(X('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3,*;7-G:60@(D-O
M;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B2V]M;6$@9V5S8VAE:61E
M;B!W86%R9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S"FUS9VED
M(")#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\B"FUS9W-T<B`B5F5R=VEJ
M9&5R:6YG('9A;B!G96)E=7)T96YI<W-E;B!B979E<W1I9V5N/R(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C4V-PIM<V=I9"`B0V]N9FER;65D(@IM<V=S='(@
M(D)E=F5S=&EG9"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHR,#@*;7-G:60@(D-O<'D@=&AE(%523"!B96QO=R!F;W(@=7-E('=H
M97)E=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y(%523#HB"FUS9W-T<B`B
M(@HB2V]P:65E<B!D92!O;F1E<G-T86%N9&4@55),('9O;W(@9V5B<G5I:RP@
M=V%N;F5E<B!U('5W(%9R:6HO0F5Z970@55),(&YO9&EG("(*(FAE969T.B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B2V]N("5S(&YI970@;W!E
M;F5N+B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ
M,C8*;7-G:60@(D-R96%T92(*;7-G<W1R(")-86ME;B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,3(*(RP@9G5Z>GD*;7-G:60@
M(D-R96%T92!#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$G<R!O<"!A9G-T86YD
M(@H*(SH@;6]N=&@N<&AP.C$V-2!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHR
M-2!T96UP;&%T97,O9&%Y+W)O=RYI;F,Z-@HC.B!L:6(O1&%Y5FEE=RYP:'`Z
M.3`@;&EB+T1A>59I97<N<&AP.C$Y-`IM<V=I9"`B0W)E871E(&$@3F5W($5V
M96YT(@IM<V=S='(@(DUA86L@965N(&YI975W92!G96)E=7)T96YI<R(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C@P"FUS9VED(")#<F5A=&5D(@IM
M<V=S='(@(D=E;6%A:W0B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI
M;F,Z,CD*;7-G:60@(D-U<G)E;G0B"FUS9W-T<B`B2'5I9&EG92(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,#D*;7-G:60@(D1A:6QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B
M1&%G96QI:FMS.B!H97)H86%L="!Z:6-H(&5L:V4B"@HC.B!A='1E;F1E97,N
M<&AP.C$Q,"!L:6(O2W)O;F]L:71H+G!H<#HQ,C@X(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@IM<V=I
M9"`B1&%Y(@IM<V=S='(@(D1A9R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S.0IM<V=I9"`B1&%Y
M*',I(@IM<V=S='(@(D1A9RAE;BDB"@HC.B!V:65W979E;G0N<&AP.C$P-`IM
M<V=I9"`B1&5?;&5T92(*;7-G<W1R(")697)W:5]J9&5R96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.0IM<V=I9"`B1&5C96UB97(B
M"FUS9W-T<B`B1&5C96UB97(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.30*
M;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(D%F9V5N;VUE;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-PIM<V=I9"`B1&5F875L="!#86QE;F1A<B(*
M;7-G<W1R(")3=&%N9&%A<F0@86=E;F1A(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C$Y,R!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C$X,0HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,CD@
M=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,C,*
M(SH@;&EB+T1R:79E<BYP:'`Z,3@Q,PIM<V=I9"`B1&5L971E(@IM<V=S='(@
M(E9E<G=I:F1E<F5N(@H*(SH@9&5L979E;G0N<&AP.C0P('1E;7!L871E<R]D
M96QE=&4O;VYE+FEN8SHQ."!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z
M,3@*(SH@;&EB+T1R:79E<BYP:'`Z,3@Q,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@)7,B"FUS9W-T<B`B5F5R=VEJ9&5R("5S(@H*(SH@961I=&5V
M96YT+G!H<#HW,`IM<V=I9"`B1&5L971E($5V96YT(@IM<V=S='(@(E9E<G=I
M:F1E<B!G96)E=7)T96YI<R(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E
M+FEN8SHR-PIM<V=I9"`B(@HB1&5L971E('1H92!C=7)R96YT(&5V96YT(&]N
M;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL(&9U='5R92!O8V-U<F5N8V5S
M+"!O<B`B"B)A;&P@;V-C=7)E;F-E<S\B"FUS9W-T<B`B(@HB5F5R=VEJ9&5R
M(&%L;&5E;B!D92!H=6ED:6=E(&=E8F5U<G1E;FES+"!D:70@=F]O<G9A;"!E
M;B!A;&QE('1O96MO;7-T:6=E("(*(G9O;W)V86QL96XL(&]F(&%L;&4@=F]O
M<G9A;&QE;C\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E
M9"YI;F,Z,3`T('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR.`IM<V=I
M9"`B1&5S8W)I7W!T:6]N(@IM<V=S='(@(D]M<V-H7W)I:G9I;F<B"@HC.B!D
M871A+G!H<#HV,B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M,3<U"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.CDV"FUS9VED(")$97-C
M<FEP=&EO;B(*;7-G<W1R(")"97-C:')I:G9I;F<B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W,PIM<V=I9"`B1&ES<&QA>2(*;7-G
M<W1R(")7965R9V5V96XB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N
M9&%R<RYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@0V%L96YD87)S
M(@IM<V=S='(@(DUI:FX@86=E;F1A)W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(X"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B
M5V5E<F=A=F5O<'1I97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*
M;7-G:60@(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U
M92!O;B!Y;W5R(&-A;&5N9&%R/R(*;7-G<W1R(")7:6QT('4@869G97)O;F1E
M('1A:V5N(&]P('5W(&%G96YD82!W965R9V5V96X_(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3,W"FUS9VED(")$;V5S(&YO="!R96-U<B(*;7-G<W1R(")(
M97)H86%L="!Z:6-H(&YI970B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HS,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1'5E.B`E<R(*;7-G<W1R(")697)V86QD
M871U;3H@)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN
M8SHQ,34*;7-G:60@(D1U<F%T:6]N(@IM<V=S='(@(E1I:F1S9'5U<B(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S`@;&EB+T1R
M:79E<BYP:'`Z,3@P-@IM<V=I9"`B161I="(*;7-G<W1R(")"97=E<FME;B(*
M"B,Z(&5D:71E=F5N="YP:'`Z,S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C8@;&EB+T1R:79E<BYP:'`Z,3@P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET("5S(@IM<V=S='(@(B5S(&)E=V5R:V5N(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,3@W"FUS9VED(")%9&ET($%T=&5N9&5E<R(*;7-G<W1R
M(")!86YW97II9V5N(&)E=V5R:V5N(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C$T,`HC+"!F=7IZ>0IM<V=I9"`B161I="!#86QE
M;F1A<G,B"FUS9W-T<B`B06=E;F1A)W,@;W`@869S=&%N9"P@8F5W97)K96XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4P"FUS9VED(")%9&ET(%)E
M;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B06=E;F1A)W,@;W`@869S=&%N9"P@
M8F5W97)K96XB"@HC.B!A='1E;F1E97,N<&AP.C$U,`IM<V=I9"`B161I="!A
M='1E;F1E97,B"FUS9W-T<B`B06%N=V5Z:6=E;B!B97=E<FME;B(*"B,Z('1E
M;7!L871E<R]C871E9V]R>5]L96=E;F0N:6YC.C(P"FUS9VED(")%9&ET(&-A
M=&5G;W)I97,@86YD(&-O;&]R<R(*;7-G<W1R(")#871E9V]R:67K;B!E;B!K
M;&5U<F5N(&)E=V5R:V5N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ-S8@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC
M.C0Q"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-`IM<V=I9"`B16UA
M:6P@061D<F5S<R(*;7-G<W1R(")%+6UA:6QA9')E<R(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8P"B,L(&9U>GIY"FUS9VED(")%
M;E]D(@IM<V=S='(@(D5I;F1I9W0@;W`B"@HC.B!D871A+G!H<#HU-PIM<V=I
M9"`B16YD($1A=&4B"FUS9W-T<B`B16EN9&1A='5M(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHX('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`X"FUS
M9VED(")%;F0@3VXB"FUS9W-T<B`B16EN9&EG="!O<"(*"B,Z(&1A=&$N<&AP
M.C4X"FUS9VED(")%;F0@5&EM92(*;7-G<W1R(")%:6YD=&EJ9"(*"B,Z(&%T
M=&5N9&5E<RYP:'`Z,3(T(&%T=&5N9&5E<RYP:'`Z,3,U(&%T=&5N9&5E<RYP
M:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<SH@)7,B"FUS9W-T<B`B1F]U
M="!B:6H@:&5T(&]P:&%L96X@=F%N('9R:6HO8F5Z970@:6YF;W)M871I92!V
M;V]R("5S.B`E<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3,*;7-G:60@
M(D5V96YT(&%D9&5D.B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,3`S"FUS9VED(")%=F5N="!D96QE=&5D.B(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,#DX"FUS9VED(")%=F5N="!E9&ET960Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B179E;G0@9G)O;2`E<R!T;R`E<R(*;7-G<W1R(")'96)E=7)T
M96YI<R!V86X@)7,@=&]T("5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S8T"B,L
M(&9U>GIY"FUS9VED(")%=F5N=',@;75S="!H879E(&$@<W1A<G0@9&%T92XB
M"FUS9W-T<B`B1&4@96EN9&1A='5M(&1I96YT(&QA=&5R('1E('II:FX@9&%N
M(&1E('-T87)T9&%T=6TN(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S,P"FUS9VED
M(")%=F5N=',@;75S="!H879E(&$@=&ET;&4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C<V-PIM<V=I9"`B179E;G1S(&UU<W0@:&%V92!A;B!E
M;F0@9&%T92!O<B!A(&1U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-SD*(RP@9G5Z>GD*;7-G:60@
M(D5X<&%N9"!.86UE<R(*;7-G<W1R(")!9V5N9&%N86%M(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ.#<*;7-G:60@(D5X<&]R="(*;7-G<W1R
M(")%>'!O<G1E<F5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX
M"FUS9VED(")%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`B06=E;F1A(&5X<&]R
M=&5R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV.0IM
M<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<FDB"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$R.`IM<V=I9"`B1FEN9"(*;7-G
M<W1R(")6:6YD96XB"@HC.B!Y96%R+G!H<#HX-R!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHV,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C(*
M(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(D9R(@IM<V=S='(@
M(E9R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS
M9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B1V5E;B!I;F9O
M<FUA=&EE(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(P('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$Q.0HC.B!T96UP;&%T97,O961I="]J879A
M<V-R:7!T+FEN8SHW,@IM<V=I9"`B1G)I9&%Y(@IM<V=S='(@(E9R:6ID86<B
M"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S`*;7-G:60@(D9U
M='5R92(*;7-G<W1R(")4;V5K;VUS="(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP
M:'`N9&ES=#HQ-PIM<V=I9"`B1V%M92(*;7-G<W1R(")3<&5L(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C(S"FUS9VED(")'
M96YE<F%L(@IM<V=S='(@(D%L9V5M965N(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")';W1O("5S(@IM<V=S
M='(@(D=A(&YA87(@)7,B"@HC.B!M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W
M965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y
M+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`IM<V=I9"`B2&ED92(*;7-G<W1R
M("(B"@HC.B!M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W965K+VAE861?<VED
M95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&ED
M92`E<R(*;7-G<W1R(")(97)I;FYE<FEN9SH@)7,B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHV-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S@*
M;7-G:60@(DAO=7(H<RDB"FUS9W-T<B`B575R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,PHC+"!F=7IZ>0IM<V=I9"`B2&]W(&QO;F<@<VAO=6QD
M('1H92!T:6UE('-L;W1S(&]N('1H92!D87D@86YD('=E96L@=FEE=W,@8F4_
M(@IM<V=S='(@(D=E8G)U:6L@:&%L9G5U<G,@:6YD96QI;F<@:6X@9&%G+2!E
M;B!W965K=V5E<F=A=F4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X
M.`HC+"!F=7IZ>0IM<V=I9"`B2&]W(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@
M:6YF;W)M871I;VX@<VAO=6QD('=E(&=E;F5R871E/R(*;7-G<W1R("(B"B)6
M;V]R(&AO979E96P@=&]E:V]M<W1I9V4@9&%G96X@9&EE;F5N('=E('9R:6HO
M8F5Z970@:6YF;W)M871I92!A86X@=&4@;6%K96X_(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`S,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B))9B!Y;W5R
M(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O<G0@:51I<"!R97%U97-T<R!Y
M;W4@8V%N('5S92!O;F4@;V8@=&AE("(*(F9O;&QO=VEN9R!L:6YK<R!T;R!A
M8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N7&XB"B)<;B(*(E1O(&%C8V5P
M="!T:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V
M96YT('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*(EQN(@HB5&\@9&5C;&EN92!T
M:&4@979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($-A
M;&5N9&%R+"!3=&5P("5D(@IM<V=S='(@(D%G96YD82!I;7!O<G1E<F5N+"!S
M=&%P("5D(@H*(SH@9&%T82YP:'`Z,S(P"FUS9VED("));7!O<G0O17AP;W)T
M($-A;&5N9&%R(@IM<V=S='(@(D%G96YD82!I;7!O<G1E<F5N+V5X<&]R=&5R
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV.`IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R(")*86YU87)I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-S0*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<S"FUS9VED
M(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC.B!D871A+G!H<#HV-2!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ-#(*;7-G:60@(DME>7=O<F1S(@IM<V=S='(@
M(E1R969W;V]R9&5N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C4U"FUS9VED("),87-T(#(T(&AO=7)S(@IM<V=S='(@(D%F9V5L;W!E;B`R
M-"!U=7(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHX-PIM<V=I9"`B
M3&%S="!-;V1I9FEE9"(*;7-G<W1R("),86%T<W0@9V5W:6IZ:6=D(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHT"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ-B!T96UP;&%T
M97,O;6]N=&@O:&5A9"YI;F,Z-`IM<V=I9"`B3&%S="!-;VYT:"(*;7-G<W1R
M(")!9F=E;&]P96X@;6%A;F0B"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN
M8SHT"B,L(&9U>GIY"FUS9VED("),87-T(%EE87(B"FUS9W-T<B`B069G96QO
M<&5N('=E96LB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-30@
M=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,PIM<V=I9"`B3&%S="!W965K(@IM
M<V=S='(@(D%F9V5L;W!E;B!W965K(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ-PIM<V=I9"`B3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O
M<G0Z(@IM<V=S='(@(D)E<&5R:R!D92P@=&4@97AP;W)T97)E;BP@=&EJ9'-D
M=75R.B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN
M8SHX-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHW-@IM<V=I9"`B3&]?8V%T
M:6]N(@IM<V=S='(@(E],;V-A=&EE(@H*(SH@9&%T82YP:'`Z-C0@=&5M<&QA
M=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHU"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$X"B,Z('1E;7!L871E
M<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C4R('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C(Q"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#D*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(DQO8V%T:64B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4*;7-G:60@(DUA;F%G92!R96UO=&4@8V%L96YD87)S
M+B(*;7-G<W1R(")!9V5N9&$G<R!O<"!A9G-T86YD+"!B96AE<F5N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<P"FUS9VED(")-87)C
M:"(*;7-G<W1R(")-86%R="(*"B,Z(&QI8B]A<&DN<&AP.C$P,`IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@179E;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<R"FUS9VED(")-87DB"FUS9W-T
M<B`B365I(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@T-@IM<V=I9"`B364B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")-965T:6YG(@IM<V=S='(@(E9E<F=A9&5R:6YG(@H*(SH@;&EB+T)L;V-K
M+W1R965?86QA<FUS+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-96YU($%L87)M
M<R(*;7-G<W1R(")!;&%R;2(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP
M.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R(")-96YU;&EJ<W0B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHV."!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ,S<*;7-G:60@(DUI;G5T92AS*2(*;7-G<W1R(")-:6YU=&5N(@H*
M(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C0R"FUS9VED(")-:7-S
M960@179E;G1S($QI<W0B"FUS9W-T<B`B1V5M:7-T92!G96)E=7)T96YI<W-E
M;FQI:G-T(@H*(SH@>65A<BYP:'`Z.#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$X"B,Z(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")-;R(*;7-G<W1R(")-82(*
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,34*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI
M;F,Z-C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@IM<V=I9"`B36]N9&%Y
M(@IM<V=S='(@(DUA86YD86<B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,CDQ
M(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-0IM<V=I9"`B36]N=&@B"FUS9W-T<B`B36%A;F0B"@HC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C,*;7-G:60@(DUO;G1H(%9I97<B"FUS9W-T<B`B
M36%A;F1W965R9V%V92(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C,@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#,*;7-G:60@(DUO;G1H;'D@179E
M;G1S($QI<W0B"FUS9W-T<B`B36%A;F1E;&EJ:V4@9V5B975R=&5N:7-S96X@
M;&EJ<W0B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(R.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(DUO
M;G1H;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")-86%N9&5L:6IK<SH@:&5R
M:&%A;'0@>FEC:"!E;&ME(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z
M,C0*;7-G:60@(DUO;G1H<R!!:&5A9"(*;7-G<W1R(")+;VUE;F1E(&UA86YD
M96XB"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C0*;7-G:60@
M(DUO;G1H<R!"969O<F4B"FUS9W-T<B`B36%A;F1E;B!V;V]R(@H*(SH@;&EB
M+V%P:2YP:'`Z-C$R"FUS9VED(")-=6QT:7!L92!I0V%L96YD87(@8V]M<&]N
M96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT(&ES('-U<'!O<G1E9"XB"FUS
M9W-T<B`B(@HB365E<F1E<F4@:4-A;&5N9&%R(&]N9&5R9&5L96X@9V5V;VYD
M96X[('-L96-H="#IZ6X@=D5V96YT('=O<F1T(&]N9&5R<W1E=6YD+B(*"B,Z
M(&-A;&5N9&%R<RYP:'`Z,3(X('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHV-PIM<V=I9"`B37D@0V%L96YD87)S(@IM<V=S='(@(DUI:FX@
M86=E;F1A)W,B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S0@=&5M<&QA=&5S
M+VUE;G4N:6YC.C,V"FUS9VED(")->2!#86QE;F1A<G,Z(@IM<V=S='(@(DUI
M:FX@86=E;F1A)W,Z(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C(P-`IM<V=I9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R(")-
M:6IN($9R965B=7-Y(%523"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L
M96YD87)S+FEN8SHQ,3<@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$U.0HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W
M-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN
M8SHQ-PHC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT
M+FEN8SHT-`IM<V=I9"`B3F%M92(*;7-G<W1R(").86%M(@H*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HT,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT-"!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*(SH@;&EB+T)L;V-K+W1R965?;65N
M=2YP:'`Z,C`*;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R(").:65U=V4@9V5B
M975R=&5N:7,B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,T"FUS
M9VED(").97AT(@IM<V=S='(@(E9O;&=E;F1E(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S
M='(@(E9O;&=E;F1E(#(T('5U<B(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR
M.0IM<V=I9"`B3F5X="!$87DB"FUS9W-T<B`B5F]L9V5N9&4@9&%G(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHV"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ."!T96UP;&%T
M97,O;6]N=&@O:&5A9"YI;F,Z-@IM<V=I9"`B3F5X="!-;VYT:"(*;7-G<W1R
M(")6;VQG96YD92!M86%N9"(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,S(*
M;7-G:60@(DYE>'0@5V5E:R(*;7-G<W1R(")6;VQG96YD92!W965K(@H*(SH@
M=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B3F5X
M="!996%R(@IM<V=S='(@(E9O;&=E;F1E(&1A9R(*"B,Z('1E;7!L871E<R]D
M87DO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!D87DB"FUS9W-T<B`B5F]L9V5N
M9&4@9&%G(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4X('1E
M;7!L871E<R]W965K+VAE860N:6YC.C4*;7-G:60@(DYE>'0@=V5E:R(*;7-G
M<W1R(")6;VQG96YD92!W965K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(W-0HC+"!F=7IZ>0IM<V=I9"`B3F\B"FUS9W-T<B`B3G4B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHW,R!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHQ,C8*(RP@9G5Z>GD*;7-G:60@(DYO(&%L87)M(@IM<V=S='(@(D%L87)M
M(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0X"FUS
M9VED(").;R!A='1E;F1E97,B"FUS9W-T<B`B1V5E;B!A86YW97II9V5N(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,0IM<V=I9"`B3F\@8V%L96YD87)S
M(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R(")'965N(&%G96YD
M82=S(&)E<V-H:6MB86%R('9O;W(@9V%S=&5N+B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-34*
M;7-G:60@(DYO(&5N9"!D871E(@IM<V=S='(@(D=E96X@96EN9&1A='5M(@H*
M(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$V-"!L:6(O0FQO8VLO
M;6]N=&AL:7-T+G!H<#HQ-C,*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y
M-`IM<V=I9"`B3F\@979E;G1S('1O(&1I<W!L87DB"FUS9W-T<B`B1V5E;B!G
M96)E=7)T96YI<W-E;B!W965R('1E(&=E=F5N(@H*(SH@;&EB+U-T;W)A9V4O
M:V]L86(N<&AP.C0S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S(@IM<V=S='(@(D=E
M96X@=G)I:B]B97IE="!I;F9O<FUA=&EE(&)E<V-H:6MB86%R('9O;W(@)7,B
M"@HC.B!L:6(O87!I+G!H<#HS-#0@;&EB+V%P:2YP:'`Z-C`R"FUS9VED(").
M;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(D=E96X@:4-A
M;&5N9&%R9&%T82!G979O;F1E;BXB"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,#0*(RP@9G5Z>GD*;7-G:60@(DYO(')E8W5R<F5N8V4B"FUS9W-T
M<B`B2&5R:&%L:6YG(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.#@V"FUS9VED
M(").;R!V86QI9"!E;6%I;"!A9&1R97-S(&9O=6YD(@IM<V=S='(@(D=E96X@
M9V5L9&EG(&4M;6%I;&%D<F5S(&=E=F]N9&5N(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-C`Q(&QI8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N92(*
M;7-G<W1R(")'965N(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ,S8*;7-G
M:60@(DYO="!F;W5N9"(*;7-G<W1R(").:65T(&=E=F]N9&5N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4Q"B,L(&9U>GIY"FUS9VED(").;W1I9FEC
M871I;VYS(@IM<V=S='(@(DQO8V%T:64B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHW.`IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V
M96UB97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-38*;7-G
M:60@(DYO=R(*;7-G<W1R(").=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C<W"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]K=&]B97(B
M"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,R!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHV-0IM<V=I9"`B3VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.`IM<V=I9"`B
M3VX@86QL(&-A;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-PHC+"!F=7IZ>0IM
M<V=I9"`B3VX@86QL('-H;W=N(&-A;&5N9&%R<R(*;7-G<W1R(")!9V5N9&$G
M<R!O<"!A9G-T86YD+"!B96AE<F5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-S8*(RP@9G5Z>GD*;7-G:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY
M(@IM<V=S='(@(DUI:FX@86=E;F1A)W,B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HV,3D*;7-G:60@(D]P=&EO;F%L(@IM<V=S='(@(D]P=&EO;F5E;"(*"B,Z
M(&QI8B]&0E9I97<N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B3W!T:6]N86P@
M071T96YD965S(@IM<V=S='(@(D]P=&EO;F5E;"!B:6H@=&4@=V]N96XB"@HC
M.B!L:6(O1D)6:65W+G!H<#HQ-3(*;7-G:60@(D]V97)V:65W(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C,T"FUS9VED(")/=VYE
M<B(*;7-G<W1R(")%:6=E;F%A<B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]W;F5R.B`E<R(*;7-G<W1R
M(")%:6=E;F%A<B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`R
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@R"FUS9VED(")032(*;7-G
M<W1R(")032(*"B,Z(&1A=&$N<&AP.C(Y('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,30*;7-G:60@(E!A;&T@1&%T94)O;VLB"FUS9W-T<B`B4&%L;2!$
M871E0F]O:R(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HS"FUS
M9VED(")087-T($5V96YT<R!,:7-T(@IM<V=S='(@(D%F9V5L;W!E;B!G96)E
M=7)T96YI<W-E;FQI:G-T(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3`Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y.`IM<V=I9"`B4&%T=&5R
M;B(*;7-G<W1R(")0871R;V]N(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N
M:6YC.C(W"FUS9VED(")097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\B
M"FUS9W-T<B`B1&5Z92!G96)E=7)T96YI<R!D969I;FET:65F('9E<G=I:F1E
M<F5N/R(*"B,Z(&QI8B]A<&DN<&AP.C,R-2!L:6(O87!I+G!H<#HT,3D@;&EB
M+V%P:2YP:'`Z-#@Q(&QI8B]A<&DN<&AP.C4U,PHC.B!L:6(O87!I+G!H<#HU
M.#0@;&EB+V%P:2YP:'`Z-C<P(&QI8B]A<&DN<&AP.C<P-@IM<V=I9"`B4&5R
M;6ES<VEO;B!$96YI960B"FUS9W-T<B`B5&]E9V%N9R!G97=E:6=E<F0B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,38W"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R(")296-H=&5N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Q"FUS9VED(")0;W)T86P@3W!T:6]N<R(*;7-G<W1R
M(")0;W)T86%L;W!T:65S(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(U"FUS
M9VED(")0<F5V:6]U<R!$87DB"FUS9W-T<B`B5F]R:6=E(&1A9R(*"B,Z(&QI
M8B]&0E9I97<O=V5E:RYP:'`Z,C8*;7-G:60@(E!R979I;W5S(%=E96LB"FUS
M9W-T<B`B5F]R:6=E('=E96LB"@HC.B!T96UP;&%T97,O9&%Y+VAE860N:6YC
M.C,*;7-G:60@(E!R979I;W5S(&1A>2(*;7-G<W1R(")6;W)I9V4@9&%G(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,U('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(U,@IM<V=I9"`B4F5C=7(@56YT:6PB"FUS9W-T<B`B2&5R
M:&%A;"!T;W0B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,#8*;7-G
M:60@(E)E8W5R<F5N8V4B"FUS9W-T<B`B2&5R:&%L:6YG(@H*(SH@9&%T82YP
M:'`Z-CD*;7-G:60@(E)E8W5R<F5N8V4@1&%T82(*;7-G<W1R(")(97)H86QI
M;F=S9&%T82(*"B,Z(&1A=&$N<&AP.C8W"FUS9VED(")296-U<G)E;F-E($5N
M9"!$871E(@IM<V=S='(@(DAE<FAA;&EN9W-E:6YD9&%T=6TB"@HC.B!D871A
M+G!H<#HV.`IM<V=I9"`B4F5C=7)R96YC92!);G1E<G9A;"(*;7-G<W1R(")(
M97)H86QI;F=S:6YT97)V86PB"@HC.B!D871A+G!H<#HV-@IM<V=I9"`B4F5C
M=7)R96YC92!4>7!E(@IM<V=S='(@(DAE<FAA;&EN9W-T>7!E(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z-30P"FUS9VED(")296-U<G,@9&%I;'DB"FUS9W-T
M<B`B2&5R:&%A;'0@9&%G96QI:FMS(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-30W"FUS9VED(")296-U<G,@;6]N=&AL>2(*;7-G<W1R(")(97)H86%L="!M
M86%N9&5L:6IK<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T,PIM<V=I9"`B
M4F5C=7)S('=E96ML>2(*;7-G<W1R(")(97)H86%L="!W96ME;&EJ:W,B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HU-3`*;7-G:60@(E)E8W5R<R!Y96%R;'DB
M"FUS9W-T<B`B2&5R:&%A;'0@:F%A<FQI:FMS(@H*(SH@;&EB+U-C:&5D=6QE
M<B]K<F]N;VQI=&@N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296UI
M;F1E<CH@)7,B"FUS9W-T<B`B2&5R:6YN97)I;F<Z("5S(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.CDQ(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-`IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R(")!
M9V5N9&$G<R!O<"!A9G-T86YD(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C8P
M('1E;7!L871E<R]M96YU+FEN8SHV,@IM<V=I9"`B4F5M;W1E($-A;&5N9&%R
M<SHB"FUS9W-T<B`B06=E;F1A)W,@;W`@869S=&%N9#HB"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(B5S('9E<G=I:F1E<F5N(@H*(SH@
M871T96YD965S+G!H<#HQ,#0*;7-G:60@(E)E;6]V92!!='1E;F1E92(*;7-G
M<W1R(")!86YW97II9V4@=F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C,R"FUS9VED("(B"B)297!L86-E(&5X:7-T:6YG(&-A
M;&5N9&%R('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG
M.B!4:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT
M(&-A;&5N9&%R+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HV,C8*;7-G:60@(E)E<75I<F5D(@IM<V=S='(@(E9E<F5I<W0B
M"@HC.B!L:6(O1D)6:65W+G!H<#HY."!L:6(O1D)6:65W+G!H<#HQ,S<@;&EB
M+T9"5FEE=RYP:'`Z,30P(&QI8B]&0E9I97<N<&AP.C$T,PIM<V=I9"`B4F5Q
M=6ER960@071T96YD965S(@IM<V=S='(@(E9E<F5I<W1E(&%A;G=E>FEG96XB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS-"!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHS,3`*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S
M='(@(DAE<G-T96P@<W1A;F1A87)D:6YS=&5L;&EN9V5N(@H*(SH@=&5M<&QA
M=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0S('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$V-@IM<V=I9"`B4F5S<&]N<V4B"FUS9W-T<B`B06YT=V]O
M<F0B"@HC.B!Y96%R+G!H<#HX."!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C,*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(EIA(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(Q('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$R,`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW
M,PIM<V=I9"`B4V%T=7)D87DB"FUS9W-T<B`B6F%T97)D86<B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DR"B,L(&9U>GIY"FUS
M9VED(")3879E(@IM<V=S='(@(EIA(@H*(SH@=FEE=V5V96YT+G!H<#HQ,3@@
M961I=&5V96YT+G!H<#HT."!E9&ET979E;G0N<&AP.C4V"FUS9VED(")3879E
M($%S($YE=R(*;7-G<W1R(")/<'-L86%N(&%L<R!N:65U=R(*"B,Z('1E;7!L
M871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHX-PHC+"!F=7IZ>0IM<V=I
M9"`B4V%V92!!='1E;F1E97,B"FUS9W-T<B`B06%N=V5Z:6=E;B(*"B,Z(&%D
M9&5V96YT+G!H<#HU-2!E9&ET979E;G0N<&AP.C4Q"FUS9VED(")3879E($5V
M96YT(@IM<V=S='(@(D=E8F5U<G1E;FES(&]P<VQA86XB"@HC.B!S96%R8V@N
M<&AP.CDQ('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ
M,34*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C8W('1E;7!L871E
M<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHX"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,30P(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B6F]E:V5N(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$*(RP@9G5Z>GD*;7-G:60@(E-E87)C
M:"!#86QE;F1A<G,B"FUS9W-T<B`B1V5D965L9&4@86=E;F1A)W,Z(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C8*(RP@9G5Z>GD*;7-G:60@
M(E-E87)C:"!297-U;'1S(@IM<V=S='(@(EIO96ME;B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHV"FUS9VED(")396%R8V@@9F]R(&-A
M;&5N9&%R<R!C;VYT86EN:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34P"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@82!C86QE;F1A<B!T;R!E9&ET(@IM<V=S='(@(E-E;&5C=&5E<B!E
M96X@86=E;F1A(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"FUS9VED(")396QE8W0@82!D
M871E(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@9&%T=6TB"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!C86QE;F1A
M<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B4V5L96-T965R(&1E(&%G96YD82!O
M;2!N86%R('1E(&EM<&]R=&5R96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q"FUS9VED("(B"B)396QE8W0@8V]N9FER;6%T:6]N(&]P=&EO;G,L
M(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE=W,@86YD(&-H;V]S
M92`B"B)D969A=6QT('9I97<N(@IM<V=S='(@(B(*(DMI97,@8F5V97-T:6=I
M;F=S;W!T:65S+"!H;V4@9&4@=F5R<V-H:6QL96YD92!W965R9V%V97,@=V]R
M9&5N(&%F9V5B965L9"!E;B`B"B)K:65S(&5E;B!S=&%N9&%A<F1W965R9V%V
M92XB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Y"FUS9VED(")3
M96QE8W0@=&AE(&-A;&5N9&%R('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B4V5L
M96-T965R(&1E(&%G96YD82!O;2!N86%R('1E(&EM<&]R=&5R96XZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I9"`B4V5L96-T('1H
M92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R(")396QE8W1E97(@:&5T(&5X<&]R
M=&9O<FUA870Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR.`IM
M<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B4V5L
M96-T965R(&AE="!I;7!O<G1B97-T86YD.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#0*;7-G:60@(E-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3HB
M"FUS9W-T<B`B4V5L96-T965R(&1E(&5E<G-T92!W965K9&%G.B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G:60@(E-E;&5C="!T:&4@
M9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B4V5L96-T965R
M(&AE="!F;W)M86%T('9A;B!H970@8G)O;F)E<W1A;F0Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T:6UE('-P
M86X@=&\@<VAO=SHB"FUS9W-T<B`B4V5L96-T965R(&5E;B!T:6ID<V1U=7)W
M965R9V%V93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@
M(E-E;&5C="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N('-T87)T=7`Z(@IM<V=S
M='(@(E-E;&5C=&5E<B!E96X@=V5E<F=A=F4@=V5L:V4@=V]R9'0@9V5B<G5I
M:W0@;F$@;W!S=&%R=&5N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,@IM<V=I9"`B4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H92!P
M;W)T86PN(@IM<V=S='(@(E-E;&5C=&5E<B!W96QK92!G96)E=7)T96YI<W-E
M;B!W;W)D96X@=V5E<F=E9V5V96X@:6X@:&5T('!O<G1A86PN(@H*(SH@=&5M
M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(T('1E;7!L871E<R]D96QE=&4O9&5L
M971E+FEN8SHR-`IM<V=I9"`B4V5N9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@
M=&\@86QL(&%T=&5N9&5E<R!W:&5N(&1E;&5T:6YG('1H:7,@979E;G0B"FUS
M9W-T<B`B(@HB4W1U=7(@965N(&%F>F5G9VEN9R!A86X@86QL92!A86YW97II
M9V5N(&)I:B!V97)W:6ID97)E;B!V86X@9&5Z92!G96)E=7)T96YI<R(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")396YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@(D5E;B!E+6UA:6P@
M=F5R<W1U<F5N(&%A;B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$X,0IM<V=I9"`B4V5N9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L;"!A
M='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"B)3
M='5U<B!U<&1A=&5S+W5I=&YO9&EG:6YG96X@86%N(&%L;&4@86%N=V5Z:6=E
M;B!B:6H@;W!S;&%A;B!V86X@9&5Z92`B"B)G96)E=7)T96YI<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<V"FUS9VED(")397!T96UB
M97(B"FUS9W-T<B`B4V5P=&5M8F5R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z.#,*;7-G:60@(E-E="!E;F0@9&%T92(*;7-G<W1R
M(")%:6YD9&%T=6T@:6YS=&5L;&5N(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C8X"FUS9VED(")3970@<F5C=7)R96YC92!E;F0@9&%T92(*;7-G
M<W1R(")(97)H86QI;F=S96EN9&1A='5M(&EN<W1E;&QE;B(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"FUS9VED(")3970@<W1A
M<G0@9&%T92(*;7-G<W1R(")"96=I;F1A='5M(&EN<W1E;&QE;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU.0IM<V=I9"`B(@HB4V5T('EO=7(@9G)E
M92]B=7-Y(&-A;&5N9&%R<R!A;F0@>6]U<B!O=VX@86YD(&]T:&5R('5S97)S
M)R!F<F5E+V)U<WD@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S
M+G!H<#HW-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4VAA<F4@;F]T
M(&9O=6YD.B`E<R(*;7-G<W1R(")V179E;G0@;FEE="!G979O;F1E;BXB"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-SD*(RP@9G5Z
M>GD*;7-G:60@(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T<B`B1V5D965L9&4@
M86=E;F1A)W,Z(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C0W('1E;7!L871E
M<R]M96YU+FEN8SHT.0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R<SHB"FUS9W-T
M<B`B1V5D965L9&4@86=E;F1A)W,Z(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H
M<#HR-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC
M.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHS"B,L(&9U
M>GIY"FUS9VED(")3:&]W($-A;&5N9&%R(@IM<V=S='(@(D%G96YD82(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHR,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!C86QE;F1A<B!<(B5S7"(B"FUS9W-T
M<B`B1V5D965L9&4@86=E;F1A)W,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$U-@IM<V=I9"`B4VAO=R!C871E9V]R>2!L96=E;F0_(@IM<V=S='(@
M(E1O;VX@8V%T96=O<FEE;&5G96YD83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30V"FUS9VED(")3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U
M<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R("(B"B)6
M97)W:6ID97)E;BP@86QA<FT@96X@:&5R:&%L:6YG<&EC=&]G<F%M;65N('=E
M97)G979E;B!I;B!A9V5N9&%W965R9V%V96X_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A
M;&5N9&%R/R(*;7-G<W1R(")486%K=F5R=F%L9&%T82!W965R9V5V96X@:6X@
M9&4@86=E;F1A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C8*;7-G
M:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N9#\B"FUS9W-T<B`B5&]O;B!6<FEJ
M+T)E>F5T(&QE9V5N9&$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P
M,PIM<V=I9"`B4VAO=R!O;FQY(&5V96YT<R!T:&%T(&AA=F4@86X@86QA<FT@
M<V5T/R(*;7-G<W1R(")!;&QE96X@9V5B975R=&5N:7-S96X@;65T(&5E;B!A
M;&%R;2!W965R9V5V96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W
M-0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!S:&%R960@8V%L96YD87)S('-I9&4M
M8GDM<VED93\B"FUS9W-T<B`B1V5D965L9&4@86=E;F1A)W,@;F%A<W0@96QK
M86%R('=E97)G979E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*
M(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&%S:W,@=7-I;F<@8V%T96=O<GD@8V]L
M;W)S/R(*;7-G<W1R(")486%K=F5R=F%L9&%T82!W965R9V5V96X@:6X@9&4@
M86=E;F1A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B
M4VAO=R!T:6UE(&]F(&1A>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE
M=W,_(@IM<V=S='(@(B!4:6ID('=E97)G979E;B!T=7-S96X@96QK92!D86<@
M:6X@=V5E:W=E97)G879E;C\B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4W1A7W)T(@IM<V=S='(@
M(D)E7V=I;G0@;W`B"@HC.B!D871A+G!H<#HU-0IM<V=I9"`B4W1A<G0@1&%T
M92(*;7-G<W1R(")"96=I;F1A='5M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E
M=F5N=%]H96%D97)S+FEN8SHW('1E;7!L871E<R]V:65W+W9I97<N:6YC.C0Q
M"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C4*;7-G:60@(E-T87)T
M($]N(@IM<V=S='(@(D)E9VEN="!O<"(*"B,Z(&1A=&$N<&AP.C4V"FUS9VED
M(")3=&%R="!4:6UE(@IM<V=S='(@(D)E9VEN=&EJ9"(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHY-2!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHX-0IM<V=I9"`B4W1A=%]U<R(*;7-G<W1R(")3=&%T7W5S
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHV('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C(W"FUS9VED(")3=&%T=7,B"FUS9W-T
M<B`B4W1A='5S(@H*(SH@>65A<BYP:'`Z.#$@>65A<BYP:'`Z.3`@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C4*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C(T(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`W(&QI8B]";&]C
M:R]M;VYT:"YP:'`Z,3`Y"FUS9VED(")3=2(*;7-G<W1R("):;R(*"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-"!T96UP;&%T97,O;6]N=&@O:&5A
M9"YI;F,Z,C,*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(Q('1E;7!L
M871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8W"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#4*;7-G:60@(E-U;F1A>2(*;7-G<W1R("):;VYD86<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*;7-G:60@(E1A<VMS(@IM<V=S
M='(@(E1A:V5N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<T(&QI8B]+<F]N
M;VQI=&@N<&AP.C4Y-PIM<V=I9"`B5&5N=&%T:79E(@IM<V=S='(@(E9O;W)L
M;W!I9R(*"B,Z('EE87(N<&AP.C@V('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,0HC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS9W-T<B`B1&\B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C<P"FUS9VED(")4
M:&4@161I="!!='1E;F1E97,@<V-R965N(&ES(&YO(&QO;F=E<B!P<F5S96YT
M+B!%>&ET:6YG+B(*;7-G<W1R(")(970@06%N=V5Z:6=E;B!B97=E<FME;B!S
M8VAE<FT@:7,@;FEE="!M965R(&%A;G=E>FEG+B!!9G-L=6ET96XN(@H*(SH@
M8V%L96YD87)S+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L
M96YD87(@7"(E<UPB(&-A;FYO="!B92!D96QE=&5D+B(*;7-G<W1R(")$92!A
M9V5N9&$@7"(E<UPB(&MA;B!N:65T('=O<F1E;B!V97)W:6ID97)D+B(*"B,Z
M(&-A;&5N9&%R<RYP:'`Z-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T
M<B`B1&4@86=E;F1A(%PB)7-<(B!I<R!V97)W:6ID97)D+B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")$92!A9V5N9&$@
M7"(E<UPB(&ES('9E<G=I:F1E<F0N(@H*(SH@8V%L96YD87)S+G!H<#HU-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B
M965N(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")$92!A9V5N9&$@7"(E
M<UPB(&ES(&AE<FYO96UD(&YA87(@7"(E<UPB+B(*"B,Z(&-A;&5N9&%R<RYP
M:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<
M(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B1&4@86=E;F1A(%PB)7-<(B!I
M<R!O<&=E<VQA9V5N+B(*"B,Z(&1A=&$N<&AP.C(R-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G
M960Z("5S(@IM<V=S='(@(D1E(&%G96YD82!<(B5S7"(@:V%N(&YI970@=V]R
M9&5N('9E<G=I:F1E<F0N(@H*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z,38S"FUS9VED(")4:&4@96YD(&1A=&4@;75S="!B92!L871E<B!T
M:&%N('1H92!S=&%R="!D871E+B(*;7-G<W1R(")$92!E:6YD9&%T=6T@9&EE
M;G0@;&%T97(@=&4@>FEJ;B!D86X@9&4@<W1A<G1D871U;2XB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#DT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&%D9&5D+"!W:&EC:"!I<R!O
M;B`E<R!A="`E<RXB"FUS9W-T<B`B1&4@86=E;F1A(%PB)7-<(B!I<R!H97)N
M;V5M9"!N86%R(%PB)7-<(BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3`T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960L('=H:6-H('=A<R!O;B`E<R!A="`E<RXB"FUS
M9W-T<B`B1&4@86=E;F1A(%PB)7-<(B!I<R!V97)W:6ID97)D+B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P.3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@961I=&5D+"!W:&EC:"!I
M<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B1&4@86=E;F1A(%PB)7-<(B!I<R!H
M97)N;V5M9"!N86%R(%PB)7-<(BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!N;W1I9FEC871I
M;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+B(*;7-G<W1R(")$92!G
M96)E=7)T96YI<VYO=&EF:6-A=&EE(&ES(&UE="!S=6-C97,@=F5R>F]N9&5N
M(&YA87(@)7,N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R-`IM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@
M;V8@=&AE(&5V96YT.B(*;7-G<W1R("(B"B)(970@=F]L9V5N9&4@:7,@965N
M(&UE97(@9V5D971A:6QL965R9&4@8F5S8VAR:6IV:6YG('9A;B!D92!G96)E
M=7)T96YI<SHB"@HC.B!A='1E;F0N<&AP.C0Q"FUS9VED("(B"B)4:&4@<F5Q
M=65S="!W87,@:6YC;VUP;&5T92X@4V]M92!P87)A;65T97)S('1H870@87)E
M(&YE8V5S<V%R>2!T;R!A8V-E<'0@;W(@(@HB9&5C;&EN92!A;B!E=F5N="!A
M<F4@;6ES<VEN9RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E
M;7!T>2YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&5V96YT<R!M871C:&EN
M9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B17(@>FEJ;B!G96)E
M=7)T96YI<W-E;B!D:64@;W9E<F5E;FMO;65N(&UE="!D92!H=6ED:6=E(&-R
M:71E<FEA+B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HQ."!E9&ET979E;G1A
M8W1I;VXN<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<R(*;7-G<W1R(")%
M96X@9F]U="!B:6H@9&4@=&]E9V%N9R!V86X@9&4@86=E;F1A.B`E<R(*"B,Z
M(&%D9&5V96YT86-T:6]N+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T
M<B`B165N(&9O=70@8FEJ(&AE="!T;V5V;V5G96X@=F%N(&1E(&=E8F5U<G1E
M;FES.B`E<R(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I;F<@=&AE(&5V
M96YT.B`E<R(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&)E=V5R:V5N('9A
M;B!D92!G96)E=7)T96YI<SH@)7,B"@HC.B!L:6(O87!I+G!H<#HS,S@@;&EB
M+V%P:2YP:'`Z-3DV"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B165N(&9O=70@8FEJ
M(&AE="!I;7!O<G1E<F5N('9A;B!D92!I0V%L96YD87)D871A+B(*"B,Z(&5D
M:71E=F5N=&%C=&EO;BYP:'`Z-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@
M(D5E;B!F;W5T(&)I:B!H970@=F5R<&QA871S96X@=F%N(&1E(&=E8F5U<G1E
M;FES.B`E<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@86X@979E
M;G0@;F]T:69I8V%T:6]N('1O("5S.B`E<R(*;7-G<W1R(")%96X@9F]U="!B
M:6H@:&5T('9E<GIE;F1E;B!V86X@965N(&=E8F5U<G1E;FES;F]T:69I8V%T
M:64@;F%A<B`E<SH@)7,B"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H97)E
M('=E<F4@;F\@979E;G1S('1O(&5X<&]R="XB"FUS9W-T<B`B17(@>FEJ;B!G
M965N(&=E8F5U<G1E;FES<V5N('1E(&5X<&]R=&5R96XN(@H*(SH@9&%T82YP
M:'`Z,3@T"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T
M960N(@IM<V=S='(@(D1I="!B97-T86YD<V9O<FUA870@=V]R9'0@;FEE="!O
M;F1E<G-T975N9"XB"@HC.B!D871A+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B1&ET(&ES('=A="!D92!S97)V97(@;65L9'0Z("5S(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q.`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,0IM<V=I
M9"`B5&AU<G-D87DB"FUS9W-T<B`B1&]N9&5R9&%G(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C,W"FUS9VED(")4:6UE(%-P7V%N(@IM<V=S
M='(@(E1I:F1S9%]U=7(B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHT"FUS9VED(")4:6UE('-P86XB"FUS9W-T<B`B5&EJ9'-D=75R
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C,V
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0P"FUS9VED(")4:71?;&4B"FUS
M9W-T<B`B7U1I=&5L(@H*(SH@9&%T82YP:'`Z-30@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C(P"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A
M9&5R<RYI;F,Z,PIM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET96PB"@HC.B!L
M:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(R(&QI8B]";&]C:R]M;VYT
M:&QI<W0N<&AP.C$R,0HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(W"FUS
M9VED(")4;V1A>2(*;7-G<W1R(")686YD86%G(@H*(SH@;&EB+T)L;V-K+W!R
M979M;VYT:&QI<W0N<&AP.C$R-"!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ
M,C,*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R.0IM<V=I9"`B5&]M;W)R
M;W<B"FUS9W-T<B`B36]R9V5N(@H*(SH@>65A<BYP:'`Z.#0@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C`@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C$Y"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")4=2(*
M;7-G<W1R(")$:2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-R!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,38*(SH@=&5M<&QA=&5S+V5D:70O
M:F%V87-C<FEP="YI;F,Z-CD*;7-G:60@(E1U97-D87DB"FUS9W-T<B`B1&EN
M<V1A9R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B
M5'EP92(*;7-G<W1R(")4>7!E(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C$X,PIM<V=I9"`B55),(@IM<V=S='(@(B(*"B,Z(&QI
M8B]3=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@(E5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYI970@:6X@<W1A870@;65T(&1E
M(%-13"!S97)V97(@=&4@=F5R8FEN9&5N+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S
M7"(Z("5S(@IM<V=S='(@(DYI970@:6X@<W1A870@;VT@7"(E<UPB.B`E<R!T
M92!V97)W:6ID97)E;B(*"B,Z(&QI8B]$<FEV97(O;6-A;"YP:'`Z,3,T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,N(@IM<V=S
M='(@(DYI970@:6X@<W1A870@;VT@)7,@=&4@=F5R=VEJ9&5R96XN(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z,3@U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(").:65T
M(&EN('-T86%T(&]M(&1E(&1E9FEN:71I92!V86X@)7,@=&4@;&%D96XN(@H*
M(SH@8V%L96YD87)S+G!H<#HU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%PB)7-<(CH@)7,B"FUS9W-T<B`B3FEE="!I;B!S=&%A
M="!<(B5S7"(@=&4@:&5R;F]E;65N.B`E<R(*"B,Z(&QI8B]3=&]R86=E+VMO
M;&%B+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5T
M<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G<W1R(").
M:65T(&EN('-T86%T('9R:6HO8F5Z970@:6YF;W)M871I92!O<"!T92!H86QE
M;B!V;V]R("5S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,34*(SH@
M<V-R:7!T<R]U<&=R861E<R\R,#`T+3`U+3$Y7V-O;G9E<G1?8V%T96=O<FEE
M<U]T;U]S=')I;F=S+G!H<#HU,PIM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")/
M;F)E;F]E;60B"@HC.B!L:6(O87!I+G!H<#HS-S8@;&EB+V%P:2YP:'`Z-#4P
M(&QI8B]A<&DN<&AP.C4Q-B!L:6(O87!I+G!H<#HV,C$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B
M"FUS9W-T<B`B3FEE="!O;F1E<G-T975N9"!#;VYT96YT+51Y<&4N(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3`Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&5D.B`E<RXB"FUS9W-T<B`B)7,@8FEJ9V5W97)K="XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`*;7-G:60@(E5S97(@26YT97)F86-E(@IM
M<V=S='(@(D=E8G)U:6ME<G-I;G1E<F9A8V4B"@HC.B!Y96%R+G!H<#HQ-C,@
M>65A<BYP:'`Z,38Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI8B]";&]C
M:R]M;VYT:"YP:'`Z,38R"FUS9VED(")6:65W($1A>2(*;7-G<W1R(")$86<@
M=V5E<F=E=F5N(@H*(SH@>65A<BYP:'`Z.#4@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-C$@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(P"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")792(*;7-G<W1R(")7
M;R(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ."!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,3<*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z-S`*;7-G:60@(E=E9&YE<V1A>2(*;7-G<W1R(")7;V5N<V1A9R(*
M"B,Z(&%T=&5N9&5E<RYP:'`Z,3$R(&QI8B]+<F]N;VQI=&@N<&AP.C$R.3`@
M;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C,*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@S"FUS9VED(")7965K(@IM<V=S='(@(E=E96LB"@HC.B!M;VYT
M:"YP:'`Z,3<Y('=O<FMW965K+G!H<#HS,"!W965K+G!H<#HS-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7965K("5D(@IM<V=S='(@(E=E96L@)60B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ-#`*;7-G:60@(E=E96LH<RDB"FUS9W-T<B`B5V5K96XB"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C$U"FUS9VED(")7965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R
M(")796ME;&EJ:W,Z(&AE<FAA86QT('II8V@@96QK92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@
M9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T
M97(@979E;G1S/R(*;7-G<W1R("(B"B)796QK92!T:6ID(&1I96YE;B!D86<M
M(&5N('=E96MW965R9V%V96X@=&4@96EN9&EG96XL('=A;FYE97(@97(@9V5E
M;B!L871E<F4@(@HB9V5B975R=&5N:7-S96X@>FEJ;C\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED("(B"B)7:&%T('1I;64@<VAO=6QD
M(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@
M96%R;&EE<B!E=F5N=',_(@IM<V=S='(@(B(*(E=E;&ME('1I:F0@9&EE;F5N
M(&1A9RT@96X@=V5E:W=E97)G879E;B!T92!B96=I;FYE;BP@=V%N;F5E<B!E
M<B!G965N(&5E<F1E<F4@(@HB9V5B975R=&5N:7-S96X@>FEJ;C\B"@HC.B!A
M='1E;F1E97,N<&AP.C$Q,2!L:6(O2W)O;F]L:71H+G!H<#HQ,C@Y(&QI8B]"
M;&]C:R]T<F5E7VUE;G4N<&AP.C(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-`IM<V=I9"`B5V]R:R!7965K(@IM<V=S='(@(E=E<FMW965K(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,B!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR-0HC+"!F=7IZ>0IM<V=I9"`B665A<B(*;7-G<W1R("):;V5K96XB"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C0Q"FUS9VED(")996%R;'DZ(%)E8W5R<R!E=F5R>2(*;7-G
M<W1R(")*86%R;&EJ:W,Z(&AE<FAA86QT('II8V@@96QK92(*"B,Z(&1A=&$N
M<&AP.C0P(&1A=&$N<&AP.C(S-"!E9&ET979E;G1A8W1I;VXN<&AP.C0V(&%D
M9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@979E;G1S+B(*;7-G
M<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Y"FUS9VED(")9;W4@87)E(&YO="!A
M;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF:65D(&5V96YT+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C<V"FUS9VED
M(")9;W4@8V%N(&]N;'D@=7-E('1H:7,@9F]R;2!F<F]M('1H92!%9&ET($%T
M=&5N9&5E<R!S8W)E96XN(@IM<V=S='(@(B(*(E4@:W5N="!D:70@9F]R;75L
M:65R(&%L;&5E;B!G96)R=6EK96X@=F%N=6ET(&AE="!!86YW97II9V5N(&)E
M=V5R:V5N('-C:&5R;2XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HY-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D;R!N;W0@:&%V92!A
M;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R960@:6X@>6]U<B!097)S;VYA;"!)
M;F9O<FUA=&EO;B`B"B)/<'1I;VYS+B!9;W4@;75S="!S970@;VYE("5S:&5R
M925S(&)E9F]R92!E=F5N="!N;W1I9FEC871I;VYS(&-A;B!B92!S96YT+B(*
M;7-G<W1R("(B"B)5(&AE969T(&=E96X@92UM86EL861R97,@9V5C;VYF:6=U
M<F5E<F0@:6X@=7<@(@HB:61E;G1I=&5I='-V;V]R:V5U<G-I;G-T96QL:6YG
M96XN(%4@9&EE;G0@97(@965N(&EN('1E('-T96QL96X@;VT@(@HB=6ET;F]D
M:6=I;F=E;B!T92!K=6YN96X@=F5R>F5N9&5N+B(*"B,Z(&%D9&5V96YT86-T
M:6]N+G!H<#HR,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O("5S+B(*;7-G<W1R(")5
M(&AE969T(&=E96X@<F5C:'0@;VT@9V5B975R=&5N:7-S96X@86%N("5S('1O
M92!T92!V;V5G96XN(@H*(SH@9&%T82YP:'`Z,3DT"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE
M8W1E9"!C86QE;F1A<BXB"FUS9W-T<B`B(@HB52!H965F="!G965N(')E8VAT
M(&]M(&=E8F5U<G1E;FES<V5N(&%A;B!D92!G97-E;&5C=&5E<F1E(&%G96YD
M82!T;V4@=&4@(@HB=F]E9V5N+B(*"B,Z(&1E;&5V96YT86-T:6]N+G!H<#HR
M-@IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@9&5L971E
M('1H:7,@979E;G0N(@IM<V=S='(@(E4@:&5E9G0@9V5E;B!R96-H="!O;2!D
M97IE(&=E8F5U<G1E;FES('1E('9E<G=I:F1E<F5N+B(*"B,Z(&5D:71E=F5N
M=&%C=&EO;BYP:'`Z-S@*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S
M:6]N('1O(&5D:70@=&AI<R!E=F5N="XB"FUS9W-T<B`B52!H965F="!G965N
M(')E8VAT(&]M(&1E>F4@9V5B975R=&5N:7,@=&4@8F5W97)K96XN(@H*(SH@
M9&%T82YP:'`Z,3@Y"FUS9VED(")9;W4@:&%V92!S<&5C:69I960@86X@:6YV
M86QI9"!C86QE;F1A<BXB"FUS9W-T<B`B52!H965F="!E96X@;VYG96QD:6=E
M(&%G96YD82!O<&=E9V5V96XN(@H*(SH@871T96YD+G!H<#HR,0IM<V=I9"`B
M66]U(&AA=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@
M=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HR-@HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E8VQI;F5D(&%T
M=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`B52!H965F="!G965N
M(')E8VAT(&]M(&1E>F4@9V5B975R=&5N:7,@=&4@=F5R=VEJ9&5R96XN(@H*
M(SH@871T96YD+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@=&5N
M=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*
M;7-G<W1R(")5(&AE969T(&=E96X@<F5C:'0@;VT@9&5Z92!G96)E=7)T96YI
M<R!T92!V97)W:6ID97)E;BXB"@HC.B!C86QE;F1A<G,N<&AP.CDQ"FUS9VED
M(")9;W4@;75S="!S96QE8W0@82!C86QE;F1A<B!T;R!B92!D96QE=&5D+B(*
M;7-G<W1R(")5(&1I96YT(&5E;B!A9V5N9&$@=&4@<V5L96-T97)E;B!O;2!T
M92!V97)W:6ID97)E;BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C4T"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F
M:7)S="XB"FUS9W-T<B`B52!D:65N="!E97)S="!E96X@861R97,@=&4@<V5L
M96-T97)E;BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DT"FUS9VED(")9
M;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A
M9&1E9"!T;R!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3$P-`IM<V=I9"`B(@HB66]U(')E<75E<W1E9"!T;R!B
M92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@
M8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,#DY"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@
M979E;G1S(&%R92!E9&ET960@:6X@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]38VAE9'5L97(O:W)O;F]L:71H+G!H<#HR,#$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@<F5M
M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R
M(")5('9E<GIO8VAT(&]M(&AE<FEN;F5R="!T92!W;W)D96X@86%N("5S+"!W
M870@:7,@;W`@)7,N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H87)E<V5L96-T
M+FEN8SHQ,`IM<V=I9"`B66]U<B!D969A=6QT(&-A;&5N9&%R(@IM<V=S='(@
M(E5W('-T86YD86%R9"!A9V5N9&$B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#4S
M(&QI8B]$<FEV97(N<&AP.C$P-C,*;7-G:60@(EM5;FYA;65D(&5V96YT72(*
M;7-G<W1R(");3VYB96YO96UD92!G96)E=7)T96YI<UTB"@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHY-PHC+"!F=7IZ>0IM<V=I9"`B7T%L87)M(@IM
M<V=S='(@(D%L87)M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C$Q"FUS9VED(")?0F%S:6,@4V5A<F-H(@IM<V=S='(@(D5E
M;E]V;W5D:6<@>F]E:V5N(@H*(SH@=FEE=V5V96YT+G!H<#HQ,C`*;7-G:60@
M(E]%9&ET(@IM<V=S='(@(E]"97=E<FME;B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$S,S`*;7-G:60@(E]';W1O(@IM<V=S='(@(D=A(%]N86%R(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,S-@IM<V=I9"`B7TEM<&]R="]%>'!O<G0B
M"FUS9W-T<B`B7TEM<&]R="]%>'!O<G0B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,S$X"FUS9VED(")?37D@0V%L96YD87)S(@IM<V=S='(@(E]-:6IN(&%G
M96YD82=S(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,R-0IM<V=I9"`B7TYE
M=R!%=F5N="(*;7-G<W1R(").:65U7W=E(&=E8F5U<G1E;FES(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3,T,0IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(D%?
M9F1R=6MK96XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,R"FUS9VED(")?
M4V5A<F-H(@IM<V=S='(@(E]:;V5K96XB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,S(X"FUS9VED(")?5&]D87DB"FUS9W-T<B`B7U9A;F1A86<B"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#(*;7-G:60@(F)E9F]R92!T:&4@
M979E;G0@<W1A<G1S(@IM<V=S='(@(G9O;W(@9&4@9V5B975R=&5N:7,@8F5G
M:6YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-0IM<V=I9"`B9&%Y
M(@IM<V=S='(@(F1A9R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q
M,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3`*;7-G:60@(F1A>2AS*2(*
M;7-G<W1R(")D86<H96XI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(F1A
M9V5N(@H*(SH@9&%T82YP:'`Z,30W('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,0IM<V=I9"`B979E;G1S+F-S=B(*;7-G<W1R(")E=F5N=',N8W-V(@H*
M(SH@9&%T82YP:'`Z,38X"FUS9VED(")E=F5N=',N:6-S(@IM<V=S='(@(F5V
M96YT<RYI8W,B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$S,0IM<V=I9"`B9G)O;2(*;7-G<W1R(")V86XB"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,"!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,S8*;7-G:60@(FUO;G1H*',I(@IM<V=S='(@(FUA86YD
M*&5N*2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,C`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(F]N("5S(&%T("5S(@IM<V=S='(@(D=E8F5U<G1E
M;FES('9A;B`E<R!T;W0@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,C0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,P"FUS9VED(")O;B!T
M:&4@<V%M92!D871E(@IM<V=S='(@(D]P(&1E>F5L9F1E(&1A='5M(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(S-@IM<V=I9"`B;VX@=&AE('-A;64@=V5E:V1A>2(*;7-G<W1R
M(")/<"!D97IE;&9D92!W965K9&%G(@H*(SH@9&%T82YP:'`Z,S`@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0IM<V=I9"`B=D-A;&5N9&%R+VE#86QE
M;F1A<B(*;7-G<W1R(")V0V%L96YD87(O:4-A;&5N9&%R(@H*(SH@;&EB+V%P
M:2YP:'`Z,S0Y(&QI8B]A<&DN<&AP.C8P-PIM<V=I9"`B=D5V96YT(&YO="!F
M;W5N9"XB"FUS9W-T<B`B=D5V96YT(&YI970@9V5V;VYD96XN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Y,0IM<V=I9"`B=V5E:R(*;7-G<W1R(")W
M965K(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(Q-PIM<V=I9"`B=V5E:RAS*2!O;CHB"FUS9W-T
M<B`B=V5E:R!O<#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DR(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y-`IM<V=I9"`B=V5E:W,B"FUS9W-T<B`B=V5K96XB"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C0R"FUS9VED(")Y96%R*',I(@IM<V=S='(@(FIA87(B"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W!O
M+VIA7TI0+G!O````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#$R,S<W-@`Q,#0Q-S,V,C<U,@`P,C`T,3(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!*87!A;F5S92!T<F%N<VQA=&EO
M;B!F;W(@:W)O;F]L:71H+@HC($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0
M<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S
M86UE(&QI8V5N<V4@87,@=&AE(&MR;VYO<FET:"!P86-K86=E+@HC($AI<F]M
M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U:W5B82YA8RYJ<#X*(PIM<V=I9"`B
M(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@:W)O;F]L:71H(#(N
M,"XQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP,2TQ,B`P.#HP,"LP
M.3`P7&XB"B),87-T+51R86YS;&%T;W(Z($AI<F]M:2!+:6UU<F$@/&AI<F]M
M:4!T86,N='-U:W5B82YA8RYJ<#Y<;B(*(DQA;F=U86=E+51E86TZ($IA<&%N
M97-E(#QU;FMN;W=N0'5N:VYO=VXN9&]M86EN/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U3
M2$E&5%]*25-<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<
M;B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@8V%L96YD87)S(&9O=6YD(@IM
M<V=S='(@(HZ$@LR77)+HE5PB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!E=F5N=',B"FUS9W-T
M<B`B)60@@T.#>(.3@V<B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1&%Y*',I("5S
M($AO=7(H<RD@)7,@36EN=71E<R(*;7-G<W1R("(E<R"3^B`E<R".GHK4("5S
M()6J(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A='1E;F1E97,B"FUS9W-T<B`B)7,@CE&)P8[2(@H*(SH@9&%T
M82YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S
M<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(B5S((-T@T"#0X.+@LV#0X.3@WR!
M6X-G@K."ZH+<@K6"O2(*"B,Z(&-A;&5N9&%R<RYP:'`Z,3`U(&QI8B]B87-E
M+G!H<#HQ,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*
M;7-G<W1R("(E<R""S)=<DNB57"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N9&%R(&YA
M;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE
M(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$V-`IM<V=I9"`B*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@061D("HB"FUS9W-T<B`B*H%UDL>)P8%V@O"#3H.*@V*#3H*U
M@L22QXG!("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$U,`IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS
M9W-T<B`B*B"#08-H@XR#6(+PD4F1\(*U@L2)NH*S@J(@*B(*"B,Z(&QI8B]$
M<FEV97(N<&AP.C$W.#8*;7-G:60@(C$@871T96YD964B"FUS9W-T<B`B@E".
M48G!CM(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`IM<V=I
M9"`B,2!E=F5N="(*;7-G<W1R("*"4(-#@WB#DX-G(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B,2!H;W5R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G:60@(C$U
M(&UI;G5T97,B"FUS9W-T<B`BE:HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,U"B,L(&9U>GIY"FUS9VED("(R,"!M:6YU=&5S(@IM<V=S='(@(I6J
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@HC+"!F=7IZ>0IM<V=I
M9"`B,S`@;6EN=71E<R(*;7-G<W1R("*5JB(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C$W,0HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY!='1E;F1E
M97,\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("*.48G!CM*!:8-)@W:#
M5H.'@Y.!:B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$T.0HC+"!F
M=7IZ>0IM<V=I9"`B/'-T<F]N9SY$97-C<FE?<'1I;VX\+W-T<F]N9SX@*&]P
M=&EO;F%L*2(*;7-G<W1R("*0X):^@6F#28-V@U:#AX.3@6HB"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR-S<*(RP@9G5Z>GD*;7-G:60@(CQS=')O
M;F<^2V5Y=V]R9',\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("*#3(-#
M@X^!6X-H@6F#28-V@U:#AX.3@6HB"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ.30*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^4F5C=7)R96YC93PO
M<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(HQ*@NB5U(*U@6F#28-V@U:#
MAX.3@6HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P,2!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X,0IM<V=I9"`B04TB"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3DQ"FUS9VED(")!8V-E<'1E9"(*
M;7-G<W1R("*.\Y>=(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C$Q"FUS9VED(")!9%]V86YC960@4V5A<F-H(@IM<V=S='(@(E]6C]J-UXR?
MC?4B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V,2!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B061D
M(@IM<V=S='(@(I+'B<$B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M-@IM<V=I9"`B061D($5V96YT(@IM<V=S='(@(H-#@WB#DX-GDL>)P2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C,U
M"FUS9VED(")!9&0@82!N97<@4F5M;W1E($-A;&5N9&%R(@IM<V=S='(@(I!6
M@K6"HH.*@X*!6X-G@TJ#C(.3@U^!6X+PDL>)P2(*"B,Z(&%D9&5V96YT+G!H
M<#HV-`IM<V=I9"`B061D(&$@;F5W(&5V96YT(@IM<V=S='(@(I!6@K6"HH-#
M@WB#DX-G@O"2QXG!(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC.C<T"FUS9VED(")!9&0@871T96YD965S(@IM<V=S='(@(HY1B<&.
MTH+PDL>)P2(*"B,Z(&-O;G1A8W1S+G!H<#HW-B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$R,`HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-S@*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("*#
M08-H@XR#6)*@(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC
M960N:6YC.C@@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED
M(")!9'9A;F-E9"!396%R8V@B"FUS9W-T<B`BC]J-UXR?C?4B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHU,PIM<V=I9"`B06QA<FTB"FUS9W-T<B`B
MC'B5\2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B06QA<FT@)60@9&%Y<R!B969O<F4B"FUS9W-T<B`B)60@D_J13X+)
MC'B5\2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B06QA<FT@)60@:&]U<G,@8F5F;W)E(@IM<V=S='(@(B5D((Z>BM21
M3X+)C'B5\2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B06QA<FT@)60@;6EN=71E<R!B969O<F4B"FUS9W-T<B`B)60@
ME:J13X+)C'B5\2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06QA<FT@)60@=V5E:W,@8F5F;W)E(@IM<V=S='(@(B5D
M((]4BM213X+)C'B5\2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C,*;7-G:60@
M(D%L87)M(#$@9&%Y(&)E9F]R92(*;7-G<W1R("*"4)/ZD4^"R8QXE?$B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ-S8X"FUS9VED(")!;&%R;2`Q(&AO=7(@8F5F
M;W)E(@IM<V=S='(@(H)0CIZ*U)%/@LF,>)7Q(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3<W,PIM<V=I9"`B06QA<FT@,2!M:6YU=&4@8F5F;W)E(@IM<V=S='(@
M(H)0E:J13X+)C'B5\2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3@*;7-G:60@
M(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B@E"/5(K4D4^"R8QXE?$B
M"@HC.B!D871A+G!H<#HV,`IM<V=I9"`B06QA<FT@1&%T92(*;7-G<W1R("*,
M>)7QD_J5="(*"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!3<&%N("AM
M:6YU=&5S*2(*;7-G<W1R("*,>)7QBM2*=8%IE:J!:B(*"B,Z(&1A=&$N<&AP
M.C8Q"FUS9VED(")!;&%R;2!4:6UE(@IM<V=S='(@(HQXE?&.GHK4(@H*(SH@
M=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,Q"FUS9VED(")!;&PB"FUS
M9W-T<B`BD5."Q"(*"B,Z(&QI8B]&0E9I97<N<&AP.C$R-B!L:6(O1D)6:65W
M+G!H<#HQ,CD@;&EB+T9"5FEE=RYP:'`Z,3,R"FUS9VED(")!;&P@071T96YD
M965S(@IM<V=S='(@(I%3@L2"S(Y1B<&.TB(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHU.0IM<V=I9"`B06QL($9U='5R92(*;7-G<W1R("*-
MH8SCD5."Q"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU,PIM
M<V=I9"`B06QL(%!A<W0B"FUS9W-T<B`BB=^+CI%3@L0B"@HC.B!L:6(O0FQO
M8VLO<')E=FUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L;V-K+VUO;G1H+G!H<#HR
M-`HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,C4*;7-G:60@(D%L;"!6:7-I8FQE(@IM<V=S='(@(HE[EY>)
MPI1<@LB"X(+,D5."Q"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C$R,B!L:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP
M.CDS"B,Z(&QI8B]7965K5FEE=RYP:'`Z,3(W(&QI8B]7965K5FEE=RYP:'`Z
M,3,T(&QI8B]$<FEV97(N<&AP.C$X,S(*;7-G:60@(D%L;"!D87DB"FUS9W-T
M<B`BBMN"4)/Z(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$V-`HC+"!F
M=7IZ>0IM<V=I9"`B06QL(&1A>2!E=F5N="(*;7-G<W1R("*14X-#@WB#DX-G
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM<V=I9"`B06QL
M(&5V96YT<R(*;7-G<W1R("*14X-#@WB#DX-G(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O2W)O;F]L:71H+G!H<#HV
M.#,*;7-G:60@(D%N>2(*;7-G<W1R("*"QX+J@L6"X"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!<')I;"(*;7-G<W1R
M("*"4XR.(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M,SD@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHW,"!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$U-@IM<V=I9"`B070B"FUS9W-T<B`BCIZ*U"(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P,C8*;7-G:60@(B(*(D%T=&%C:&5D(&ES(&%N(&E#
M86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@
M979E;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I<"!R
M97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P9&%T
M92`B"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G<W1R("(B
M"B*"L8+,@X&!6X.+@LF3695T@K."ZH+$@J*"Z8+,@LV!08-#@WB#DX-G@LR/
MVHW7@LF"PH*B@L2"S"!I0V%L96YD87(@@W2#0(-#@XN"Q2(*(H*W@4*"X(*U
M@4&#@8%;@XF"JB!I5&EP((+P@U2#?(%;@V>"M8+$@J*"ZH+.@4&3695T@W2#
M0(-#@XN"J8+GBLB24(+)EUR2Z)5<@O`B"B*-6)!6@L6"JX+<@K>!0B(*"B,Z
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ-C4*;7-G:60@(D%T=&5N9&%N8V4B"FUS9W-T
M<B`BCE&)P2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V,0IM<V=I
M9"`B071T96YD965S(@IM<V=S='(@(HY1B<&.TB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B
M@E>,CB(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN
M8SHQ,2!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z.`IM<V=I9"`B0F%S
M:6,@4V5A<F-H(@IM<V=S='(@(HK(B-6,GXWU(@H*(SH@8V]N9FEG+VME>7=O
M<F1S+G!H<"YD:7-T.C$W"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("*289"V
MD_HB"@HC.B!L:6(O1D)6:65W+G!H<#HY,"!L:6(O1D)6:65W+G!H<#HQ,3`*
M;7-G:60@(D)U<WDB"FUS9W-T<B`BD;V66B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHT-`IM<V=I9"`B0U]A;&5N9&%R(@IM
M<V=S='(@(E]!EUR2Z)5<(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M-#D*;7-G:60@(D-A;%]E;F1A<B(*;7-G<W1R("*77)+HE5PB"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30V(&QI8B]";&]C:R]P
M<F5V;6]N=&AL:7-T+G!H<#HR,0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C(Q
M(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C(Q(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HR,@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BEUR2Z)5<(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D-A;&5N9&%R(%-U;6UA
M<GDB"FUS9W-T<B`BEUR2Z)5<BE27=B(*"B,Z(&1A=&$N<&AP.C(R.`HC+"!F
M=7IZ>0IM<V=I9"`B0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS
M9W-T<B`B)7,@@W2#0(-#@XN"S8-#@Y.#?(%;@V>"LX+J@MR"M8*](@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4W"FUS9VED(")#86QE;F1A<G,B"FUS9W-T<B`BEUR2Z)5<
M(@H*(SH@8V%L96YD87)S+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B0V%L96YD
M87)S(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S='(@(I=<DNB57(+,EKR13R(*
M"B,Z(&1A=&$N<&AP.C(T,PIM<V=I9"`B0V%N)W0@8W)E871E(&$@;F5W(&5V
M96YT+B(*;7-G<W1R("*05H*U@J*#0X-X@Y.#9X+PC>R0K(+%@JN"W(*Y@O&!
M0B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DQ('1E
M;7!L871E<R]D96QE=&4O;VYE+FEN8SHS,`HC.B!T96UP;&%T97,O9&5L971E
M+V1E;&5T92YI;F,Z,S(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S,*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S`Y"FUS9VED(")#86YC96PB"FUS
M9W-T<B`B@TR#@X.3@UJ#BR(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4W,`IM
M<V=I9"`B0V%N8V5L;&5D(@IM<V=S='(@(H-,@X.#DX-:@XLB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-A;F-E
M;&QE9#H@)7,B"FUS9W-T<B`B@TR#@X.3@UJ#BXW/@MV!1B5S(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C8T('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C8Y"FUS9VED(")#871E9V]R7WDB"FUS9W-T<B`B
M7UF5JI?>(@H*(SH@9&%T82YP:'`Z-C,@=&5M<&QA=&5S+W-E87)C:"]E=F5N
M=%]H96%D97)S+FEN8SHT('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$S"FUS
M9VED(")#871E9V]R>2(*;7-G<W1R("*5JI?>(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(W.0IM<V=I9"`B(@HB0VAO;W-E(&EF('EO=2!W86YT('1O
M(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N
M=',@8GD@(@HB96UA:6PZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO
M=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96%R8VA?86)O;VM?<V5L
M96-T+FEN8SHQ.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDY"FUS9VED(")#
M:&]O<V4@=&AE(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H(&9O<B!F<F5E+V)U
M<WD@55),<SHB"FUS9W-T<B`BEUR2Z(_NE?&!:49R964O0G5S>2!54DR!:HR?
MC?67<(+,@T&#:(.,@UB2H(+PD4F1\(%&(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V9B7V-A;'-?<V5L96-T+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E
M('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!I;B!Y;W5R(&9R964O8G5S>2!I
M;F9O<FUA=&EO;CHB"FUS9W-T<B`B@J""R(*]@LR77)+HC^Z5\8+PCN:3OH*W
M@NF"O8+?@LR77)+HE5R"\)%)D?"!1B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,3$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S
M('1O(&EN8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!54DQS.B(*
M;7-G<W1R("*77)+HC^Z5\8%I1G)E92]"=7-Y(%523(%JC)^-]9=P@LR#08-H
M@XR#6)*@@O"129'P@48B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*
M;7-G:60@(D-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@
M(H-F@W2#2(.+@V>"S)=<DNB57(+PD4F1\(*U@L2"K8*^@K."HH%"(@H*(SH@
M=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C8U"B,L(&9U>GIY
M"FUS9VED(")#;&5A<B!A;&P@871T96YD965S(@IM<V=S='(@(I%3CE&)P8[2
M@O"/P8N.(@H*(SH@9&%T82YP:'`Z,C@@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R
M("*#4H.3@WV+YI#8@NB"S))L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<S"FUS9VED(")#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\B"FUS9W-T
M<B`B@T.#>(.3@V>"\(WMCYR"MX+IC=N"R8IME$:"M8+<@K>"J8%((@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-38W"FUS9VED(")#;VYF:7)M960B"FUS9W-T
M<B`BBFV2Z"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHR,#@*;7-G:60@(D-O<'D@=&AE(%523"!B96QO=R!F;W(@=7-E('=H97)E
M=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y(%523#HB"FUS9W-T<B`B@J""
MR(*]@LR77)+HC^Z5\2!54DR!:95+EW:"R(+&@K&"ZX+)@U*#<X%;@K6"Q(YG
MEW"!:H%&(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,38R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(E<R""\(I*
M@J^"W(*Y@O&"Q8*U@KV!0B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L
M96YD87)S+FEN8SHQ,C8*;7-G:60@(D-R96%T92(*;7-G<W1R("*-[)"L(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q,@HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E($-A;&5N9&%R(@IM<V=S='(@(H.*@X*!6X-G
M@TJ#C(.3@U^!6R(*"B,Z(&UO;G1H+G!H<#HQ-C4@=&5M<&QA=&5S+W=E96LO
M:&5A9"YI;F,Z,C4@=&5M<&QA=&5S+V1A>2]R;W<N:6YC.C8*(SH@;&EB+T1A
M>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H<#HQ.30*;7-G:60@(D-R96%T
M92!A($YE=R!%=F5N="(*;7-G<W1R("*05HM+@T.#>(.3@V>"\(WLD*PB"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHX,`IM<V=I9"`B0W)E871E9"(*
M;7-G<W1R("*-[)"LD_HB"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI
M;F,Z,CD*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0B"FUS9W-T<B`BC>R0K"(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,#D*;7-G:60@(D1A:6QY.B!296-U<G,@979E<GDB"FUS
M9W-T<B`BEHB3^H%&C$J"Z)74@K4B"@HC.B!A='1E;F1E97,N<&AP.C$Q,"!L
M:6(O2W)O;F]L:71H+G!H<#HQ,C@X(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP
M.C(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@IM<V=I9"`B1&%Y(@IM
M<V=S='(@(I/Z(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3,Y"FUS9VED(")$87DH<RDB"FUS9W-T
M<B`BD_J*U"(*"B,Z('9I97=E=F5N="YP:'`Z,3`T"FUS9VED(")$95]L971E
M(@IM<V=S='(@(E],C>V/G"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C<Y"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("*"4()1C(XB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HU.30*;7-G:60@(D1E8VQI;F5D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-PIM<V=I9"`B1&5F
M875L="!#86QE;F1A<B(*;7-G<W1R("*#9H-T@TB#BX-GEUR2Z)5<(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,R!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X,0HC.B!T96UP;&%T97,O9&5L
M971E+V]N92YI;F,Z,CD@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N
M86=E;65N="YI;F,Z,C,*(SH@;&EB+T1R:79E<BYP:'`Z,3@Q,PIM<V=I9"`B
M1&5L971E(@IM<V=S='(@(HWMCYPB"@HC.B!D96QE=F5N="YP:'`Z-#`@=&5M
M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C$X('1E;7!L871E<R]D96QE=&4O9&5L
M971E+FEN8SHQ.`HC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R("(E<R""\(WMCYPB"@HC.B!E
M9&ET979E;G0N<&AP.C<P"FUS9VED(")$96QE=&4@179E;G0B"FUS9W-T<B`B
M@T.#>(.3@V>"\(WMCYPB"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI
M;F,Z,C<*;7-G:60@(B(*(D1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY
M+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@
M;W(@(@HB86QL(&]C8W5R96YC97,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,#0@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C(X"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T
M<B`B7U"0X):^(@H*(SH@9&%T82YP:'`Z-C(@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C$W-0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHY-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BD."6OB(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<S"FUS9VED(")$:7-P
M;&%Y(@IM<V=S='(@(I5<CJ8B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A
M;&5N9&%R<RYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@0V%L96YD
M87)S(@IM<V=S='(@(HZ$@LR77)+HE5PB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(X"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B
ME5R.IH-)@W:#5H.'@Y,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*
M;7-G:60@(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U
M92!O;B!Y;W5R(&-A;&5N9&%R/R(*;7-G<W1R("**^I/Z@LR"H(+I@UZ#6(-.
M@O"77)+HE5R"R95<CJ:"M8+<@K>"J8%((@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-3,W"FUS9VED(")$;V5S(&YO="!R96-U<B(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HS,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1'5E
M.B`E<R(*;7-G<W1R("**^I/Z@48E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B
MC'"1L8KZBM0B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z,3<P(&QI8B]$<FEV97(N<&AP.C$X,#8*(RP@9G5Z>GD*;7-G:60@(D5D
M:70B"FUS9W-T<B`B7T65TH]7(@H*(SH@961I=&5V96YT+G!H<#HS,R!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR-B!L:6(O1')I=F5R+G!H<#HQ.#`V"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@)7,B"FUS9W-T<B`B)7,@@O"5TH]7
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@W"FUS9VED(")%9&ET
M($%T=&5N9&5E<R(*;7-G<W1R("*.48G!CM*"S)72CU<B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30P"B,L(&9U>GIY"FUS9VED
M(")%9&ET($-A;&5N9&%R<R(*;7-G<W1R("*#BH."@5N#9X-*@XR#DX-?@5N"
MS)72CU<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4P"FUS9VED(")%
M9&ET(%)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B@XJ#@H%;@V>#2H.,@Y.#
M7X%;@LR5TH]7(@H*(SH@871T96YD965S+G!H<#HQ-3`*;7-G:60@(D5D:70@
M871T96YD965S(@IM<V=S='(@(HY1B<&.TH+,E=*/5R(*"B,Z('1E;7!L871E
M<R]C871E9V]R>5]L96=E;F0N:6YC.C(P"FUS9VED(")%9&ET(&-A=&5G;W)I
M97,@86YD(&-O;&]R<R(*;7-G<W1R("*5JI?>@L:01H+,E=*/5R(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E<R]A
M='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B@X&!
M6X.+@T&#:(.,@U@B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N
M+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B16Y?9"(*;7-G<W1R("*/29>YD_HB
M"@HC.B!D871A+G!H<#HU-PIM<V=I9"`B16YD($1A=&4B"FUS9W-T<B`BCTF7
MN9/ZE70B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC
M.C@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ,#@*;7-G:60@(D5N9"!/;B(*;7-G<W1R("*/29>Y
MD_HB"@HC.B!D871A+G!H<#HU.`IM<V=I9"`B16YD(%1I;64B"FUS9W-T<B`B
MCTF7N8Z>BM0B"@HC.B!A='1E;F1E97,N<&AP.C$R-"!A='1E;F1E97,N<&AP
M.C$S-2!A='1E;F1E97,N<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,Z
M("5S(@IM<V=S='(@(B5S((*S@O&"S)=<DNB/[I7QCN:3OI*&@LF#1X.)@5N4
MK9"V@48E<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3,*;7-G:60@(D5V
M96YT(&%D9&5D.B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,3`S"FUS9VED(")%=F5N="!D96QE=&5D.B(*;7-G<W1R("(B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#DX"FUS9VED(")%=F5N="!E9&ET960Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B179E;G0@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HW-C0*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@82!S=&%R
M="!D871E+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HW,S`*;7-G
M:60@(D5V96YT<R!M=7-T(&AA=F4@82!T:71L92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z-S8W"FUS9VED(")%=F5N=',@;75S="!H879E(&%N
M(&5N9"!D871E(&]R(&$@9'5R871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHW.0HC+"!F=7IZ>0IM<V=I
M9"`B17AP86YD($YA;65S(@IM<V=S='(@(I=<DNB57(+,EKR13R(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@W"FUS9VED(")%>'!O<G0B"FUS
M9W-T<B`B@T>#3H-8@WR!6X-G(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHX"FUS9VED(")%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`BEUR2Z)5<
M@LR#1X-.@UB#?(%;@V<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHV.0IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B@E&,CB(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(X"FUS9VED(")&:6YD
M(@IM<V=S='(@(I%[@K<B"@HC.B!Y96%R+G!H<#HX-R!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,C(*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(D9R(@IM<V=S
M='(@(HO@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY
M"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`BE7.6OB(*
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,"!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI
M;F,Z-S(*;7-G:60@(D9R:61A>2(*;7-G<W1R("*+X)=J(@H*(SH@=&5M<&QA
M=&5S+V1E;&5T92]D96QE=&4N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")&=71U
M<F4B"FUS9W-T<B`BC:&,XY%3@L0B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP
M+F1I<W0Z,3<*(RP@9G5Z>GD*;7-G:60@(D=A;64B"FUS9W-T<B`BEKR13R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHR,PIM
M<V=I9"`B1V5N97)A;"(*;7-G<W1R("*14Y3*(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")';W1O("5S(@IM
M<V=S='(@(B5S((+)B-J3KB(*"B,Z(&UO;G1H+G!H<#HQ,S4@=&5M<&QA=&5S
M+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D
M87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"FUS9VED(")(:61E(@IM<V=S
M='(@(B(*"B,Z(&UO;G1H+G!H<#HQ,S4@=&5M<&QA=&5S+W=E96LO:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(DAI9&4@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C4@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3,X"FUS9VED(")(;W5R*',I(@IM<V=S
M='(@(HZ>BM0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,L(&9U
M>GIY"FUS9VED(")(;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@
M=&AE(&1A>2!A;F0@=V5E:R!V:65W<R!B93\B"FUS9W-T<B`BD_J"QH]4@LR5
M7(ZF@O`S,)6JDE"(RH+)@K6"W(*W@JF!2"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR.#@*;7-G:60@(DAO=R!M86YY(&1A>7,@;V8@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N('-H;W5L9"!W92!G96YE<F%T93\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`S,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B))9B!Y;W5R(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O<G0@:51I
M<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@;V8@=&AE("(*(F9O;&QO=VEN
M9R!L:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N7&XB"B)<
M;B(*(E1O(&%C8V5P="!T:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB"B)4;R!A
M8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*(EQN(@HB
M5&\@9&5C;&EN92!T:&4@979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T($-A;&5N9&%R+"!3=&5P("5D(@IM<V=S='(@(I=<DNB57(+,
M@T.#DX-\@5N#9X%!@UB#98-B@W8@)60B"@HC.B!D871A+G!H<#HS,C`*;7-G
M:60@(DEM<&]R="]%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`BEUR2Z)5<@LR#
M0X.3@WR!6X-G+X-'@TZ#6(-\@5N#9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S='(@(H)0C(XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-`IM<V=I9"`B
M2G5L>2(*;7-G<W1R("*"5HR.(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-S,*;7-G:60@(DIU;F4B"FUS9W-T<B`B@E6,CB(*"B,Z(&1A
M=&$N<&AP.C8U('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T,@IM<V=I9"`B
M2V5Y=V]R9',B"FUS9W-T<B`B@TR#0X./@5N#:"(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R-"!H;W5R<R(*;7-G
M<W1R("(R-(Z>BM213X+<@L4B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHX-PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("*-Q8])E<^-6)/Z
M(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHT
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ-B!T
M96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z-`IM<V=I9"`B3&%S="!-;VYT:"(*
M;7-G<W1R("(Q@Y:,CI%/@MR"Q2(*"B,Z('1E;7!L871E<R]Y96%R+VAE860N
M:6YC.C0*(RP@9G5Z>GD*;7-G:60@(DQA<W0@665A<B(*;7-G<W1R("*"4(]4
MBM213X+<@L4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-30@
M=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,PIM<V=I9"`B3&%S="!W965K(@IM
M<V=S='(@(H)0CU2*U)%/@MR"Q2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(DQI;6ET('1H92!T:6UE('-P86X@
M=&\@97AP;W)T.B(*;7-G<W1R("*57(ZF@K>"Z8KZBM2"\)%)D?"!1B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX-B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHW-@IM<V=I9"`B3&]?8V%T:6]N(@IM<V=S
M='(@(E]#C^J/BB(*"B,Z(&1A=&$N<&AP.C8T('1E;7!L871E<R]S96%R8V@O
M979E;G1?:&5A9&5R<RYI;F,Z-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E
M7V-A;%]M86YA9V5M96YT+FEN8SHQ.`HC.B!T96UP;&%T97,O<')E9G,O<F5M
M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHU,B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHR,0HC.B!L:6(O1')I=F5R+G!H<#HQ.#0Y"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R("*/ZH^*(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U
M"FUS9VED(")-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RXB"FUS9W-T<B`B@XJ#
M@H%;@V>#2H.,@Y.#7X%;@O"0W9+H@K6"W(*W@4(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]G;W1O+FEN8SHW,`IM<V=I9"`B36%R8V@B"FUS9W-T<B`B
M@E*,CB(*"B,Z(&QI8B]A<&DN<&AP.C$P,`IM<V=I9"`B36%X:6UU;2!.=6UB
M97(@;V8@179E;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<R"FUS9VED(")-87DB"FUS9W-T<B`B@E2,CB(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$X-#8*;7-G:60@(DUE(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B365E=&EN9R(*
M;7-G<W1R("*)[XMC(@H*(SH@;&EB+T)L;V-K+W1R965?86QA<FUS+G!H<#HS
M"B,L(&9U>GIY"FUS9VED(")-96YU($%L87)M<R(*;7-G<W1R("*,>)7Q(@H*
M(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PIM<V=I9"`B365N=2!,:7-T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8X('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C$S-PIM<V=I9"`B36EN=71E*',I(@IM
M<V=S='(@(I6J(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C0R
M"FUS9VED(")-:7-S960@179E;G1S($QI<W0B"FUS9W-T<B`B(@H*(SH@>65A
M<BYP:'`Z.#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-3D@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C$X"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,3`U"FUS9VED(")-;R(*;7-G<W1R("*,CB(*"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D+FEN8SHQ-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,34*
M(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C@@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@IM<V=I9"`B36]N9&%Y(@IM<V=S='(@(HR.EVHB
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,CDQ(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C(T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0IM<V=I9"`B36]N
M=&@B"FUS9W-T<B`BC(XB"@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C,*;7-G
M:60@(DUO;G1H(%9I97<B"FUS9W-T<B`BC(Z57(ZF(@H*(SH@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT,PIM
M<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R.2!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(DUO;G1H;'DZ(%)E8W5R<R!E
M=F5R>2(*;7-G<W1R("*6B(R.@4:,2H+HE=2"M2(*"B,Z(&QI8B]";&]C:R]M
M;VYT:&QI<W0N<&AP.C(T"B,L(&9U>GIY"FUS9VED(")-;VYT:',@06AE860B
M"FUS9W-T<B`BC(Z57(ZF(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N
M<&AP.C(T"B,L(&9U>GIY"FUS9VED(")-;VYT:',@0F5F;W)E(@IM<V=S='(@
M(HR.E5R.IB(*"B,Z(&QI8B]A<&DN<&AP.C8Q,@IM<V=I9"`B375L=&EP;&4@
M:4-A;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I
M<R!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z,3(X
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHV-PIM<V=I9"`B
M37D@0V%L96YD87)S(@IM<V=S='(@(HZ$@LR77)+HE5PB"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,S0@=&5M<&QA=&5S+VUE;G4N:6YC.C,V"FUS9VED(")-
M>2!#86QE;F1A<G,Z(@IM<V=S='(@(HZ$@LR77)+HE5R!1B(*"B,Z('1E;7!L
M871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,#0*;7-G:60@(DUY($9R
M964O0G5S>2!54DPB"FUS9W-T<B`BCH2"S)=<DNB/[I7Q(%523"(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,3<@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U.0HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$W-0HC.B!T96UP;&%T97,O<')E9G,O<F5M
M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHQ-PHC.B!T96UP;&%T97,O<')E9G,O
M<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHT-`IM<V=I9"`B3F%M92(*;7-G
M<W1R("*6O)%/(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HT,2!L:6(O0FQO
M8VLO;6]N=&AL:7-T+G!H<#HT-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*
M(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C`*;7-G:60@(DYE=R!%=F5N
M="(*;7-G<W1R("*05H-#@WB#DX-G(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHS-`IM<V=I9"`B3F5X="(*;7-G<W1R("*.GR(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-PIM<V=I9"`B3F5X="`R-"!H;W5R
M<R(*;7-G<W1R("*-H8SC,C2.GHK4(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP
M.C(Y"B,L(&9U>GIY"FUS9VED(").97AT($1A>2(*;7-G<W1R("*.GR(*"B,Z
M('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-@HC.B!T
M96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3@@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@36]N
M=&@B"FUS9W-T<B`B,8.6C(Z13X+<@L4B"@HC.B!L:6(O1D)6:65W+W=E96LN
M<&AP.C,R"FUS9VED(").97AT(%=E96LB"FUS9W-T<B`BEXB/5(+<@L4B"@HC
M.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHV"B,L(&9U>GIY"FUS9VED(").
M97AT(%EE87(B"FUS9W-T<B`BEXB/5(+<@L4B"@HC.B!T96UP;&%T97,O9&%Y
M+VAE860N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DYE>'0@9&%Y(@IM<V=S='(@
M(HZ?(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4X('1E;7!L
M871E<R]W965K+VAE860N:6YC.C4*;7-G:60@(DYE>'0@=V5E:R(*;7-G<W1R
M("*7B(]4@MR"Q2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S4*(RP@
M9G5Z>GD*;7-G:60@(DYO(@IM<V=S='(@(HVA(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3(V"B,L
M(&9U>GIY"FUS9VED(").;R!A;&%R;2(*;7-G<W1R("*,>)7Q(@H*(SH@=&5M
M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0X"FUS9VED(").;R!A
M='1E;F1E97,B"FUS9W-T<B`BCE&)P8[2@LB"M2(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$S,3$*;7-G:60@(DYO(&-A;&5N9&%R<R!A<F4@879A:6QA8FQE
M('1O(&=U97-T<RXB"FUS9W-T<B`B@U&#6(-GEW""S)=<DNB57(+-@J""Z(+<
M@KF"\8%"(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,V('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(U-0IM<V=I9"`B3F\@96YD(&1A=&4B"FUS
M9W-T<B`B@J*"PH+<@L6"X"(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T
M+G!H<#HQ-C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,38S"B,Z(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HQ.30*;7-G:60@(DYO(&5V96YT<R!T;R!D:7-P
M;&%Y(@IM<V=S='(@(I5<CJ:"MX+I@M>"JX-#@WB#DX-G@LV"H(+H@MR"N8+Q
M(@H*(SH@;&EB+U-T;W)A9V4O:V]L86(N<&AP.C0S"B,L('!H<"UF;W)M870*
M;7-G:60@(DYO(&9R964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@
M9F]R("5S(@IM<V=S='(@(B5S((*S@O&"S)=<DNB/[I7Q@LV"H(+H@MR"N8+Q
M(@H*(SH@;&EB+V%P:2YP:'`Z,S0T(&QI8B]A<&DN<&AP.C8P,@IM<V=I9"`B
M3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,#0*(RP@9G5Z>GD*;7-G:60@(DYO
M(')E8W5R<F5N8V4B"FUS9W-T<B`BC$J"Z)74@K6/29>YD_J"\)#=DN@B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HX.#8*;7-G:60@(DYO('9A;&ED(&5M86EL
M(&%D9')E<W,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-C`Q(&QI8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N92(*;7-G
M<W1R("*"R(*U(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ,S8*;7-G:60@
M(DYO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$*(RP@9G5Z>GD*;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`B
MC^J/BB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<X"FUS
M9VED(").;W9E;6)E<B(*;7-G<W1R("*"4()0C(XB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R("*-H2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<W"FUS9VED(")/
M8W1O8F5R(@IM<V=S='(@(H)0@D^,CB(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC.C$S('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C8U"FUS9VED(")/;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C<X"FUS9VED(")/;B!A;&P@8V%L96YD87)S($D@:&%V
M92!R96%D(&%C8V5S<R!T;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C<W"B,L(&9U>GIY"FUS9VED(")/;B!A;&P@<VAO=VX@8V%L
M96YD87)S(@IM<V=S='(@(H.*@X*!6X-G@TJ#C(.3@U^!6X+PD-V2Z(*U@MR"
MMX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-@HC+"!F=7IZ>0IM
M<V=I9"`B3VX@;7D@8V%L96YD87)S(&]N;'DB"FUS9W-T<B`BCH2"S)=<DNB5
M7"(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8Q.0IM<V=I9"`B3W!T:6]N86PB
M"FUS9W-T<B`BE$.(TR(*"B,@;7-G<W1R("*#28-V@U:#AX.3(@HC.B!L:6(O
M1D)6:65W+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(D]P=&EO;F%L($%T=&5N
M9&5E<R(*;7-G<W1R("*40XC3@LR.48G!(@H*(SH@;&EB+T9"5FEE=RYP:'`Z
M,34R"FUS9VED(")/=F5R=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHS-`IM<V=I9"`B3W=N97(B"FUS9W-T<B`BCXJ73([2
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@T-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B3W=N97(Z("5S(@IM<V=S='(@(H^*ETR.TB(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,3`R('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,3@R"FUS9VED(")032(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR
M.2!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T"B,L(&9U>GIY"FUS9VED
M(")086QM($1A=&5";V]K(@IM<V=S='(@(HQXE?&3^I5T(@H*(SH@;&EB+T)L
M;V-K+W!R979M;VYT:&QI<W0N<&AP.C,*;7-G:60@(E!A<W0@179E;G1S($QI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`Y
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y.`IM<V=I9"`B4&%T=&5R;B(*
M;7-G<W1R("*#<(->@5N#DR(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN
M8SHR-PIM<V=I9"`B4&5R;6%N96YT;'D@9&5L971E('1H:7,@979E;G0_(@IM
M<V=S='(@(H*Q@LR#0X-X@Y.#9X+PC>V/G(*U@MR"MX*I@4@B"@HC.B!L:6(O
M87!I+G!H<#HS,C4@;&EB+V%P:2YP:'`Z-#$Y(&QI8B]A<&DN<&AP.C0X,2!L
M:6(O87!I+G!H<#HU-3,*(SH@;&EB+V%P:2YP:'`Z-3@T(&QI8B]A<&DN<&AP
M.C8W,"!L:6(O87!I+G!H<#HW,#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D
M(@IM<V=S='(@(H-!@TZ#6H-8BY&4VR(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O8V%L96YD87)S+FEN8SHQ-C<*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S
M='(@(H-!@TZ#6H-8C*`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*
M;7-G:60@(E!O<G1A;"!/<'1I;VYS(@IM<V=S='(@(H-\@5N#7H.+@TF#=H-6
M@X>#DR(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR-0IM<V=I9"`B4')E=FEO
M=7,@1&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*
M;7-G:60@(E!R979I;W5S(%=E96LB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A>2]H96%D+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D87DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,U('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(U,@IM<V=I9"`B4F5C=7(@56YT:6PB"FUS9W-T<B`B
MCTF7N9/Z(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`V"B,L(&9U
M>GIY"FUS9VED(")296-U<G)E;F-E(@IM<V=S='(@(I:(CU2,2H+HE=2"M2(*
M"B,Z(&1A=&$N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")296-U<G)E;F-E($1A
M=&$B"FUS9W-T<B`BC$J"Z)74@K6/29>YD_J"\)#=DN@B"@HC.B!D871A+G!H
M<#HV-PHC+"!F=7IZ>0IM<V=I9"`B4F5C=7)R96YC92!%;F0@1&%T92(*;7-G
M<W1R("*,2H+HE=2"M8])E[F3^H+PD-V2Z"(*"B,Z(&1A=&$N<&AP.C8X"B,L
M(&9U>GIY"FUS9VED(")296-U<G)E;F-E($EN=&5R=F%L(@IM<V=S='(@(HQ*
M@NB5U(*UCTF7N9/Z@O"0W9+H(@H*(SH@9&%T82YP:'`Z-C8*;7-G:60@(E)E
M8W5R<F5N8V4@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU-#`*;7-G:60@(E)E8W5R<R!D86EL>2(*;7-G<W1R("*6B)/ZC$J"Z)74
M@K4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#<*;7-G:60@(E)E8W5R<R!M
M;VYT:&QY(@IM<V=S='(@(I:(C(Z,2H+HE=2"M2(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C4T,PIM<V=I9"`B4F5C=7)S('=E96ML>2(*;7-G<W1R("*6B(]4
MC$J"Z)74@K4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3`*;7-G:60@(E)E
M8W5R<R!Y96%R;'DB"FUS9W-T<B`BEHB43HQ*@NB5U(*U(@H*(SH@;&EB+U-C
M:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C$Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4F5M:6YD97(Z("5S(@IM<V=S='(@(B5S((+PC>V/G"(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHY,2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#0*;7-G:60@(E)E;6]T92!#86QE;F1A<G,B"FUS
M9W-T<B`B@XJ#@H%;@V>#2H.,@Y.#7X%;(@H*(SH@=&5M<&QA=&5S+VUE;G4N
M:6YC.C8P('1E;7!L871E<R]M96YU+FEN8SHV,@IM<V=I9"`B4F5M;W1E($-A
M;&5N9&%R<SHB"FUS9W-T<B`B@XJ#@H%;@V>#2H.,@Y.#7X%;@48B"@HC.B!T
M96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(B5S((+PC>V/G"(*"B,Z
M(&%T=&5N9&5E<RYP:'`Z,3`T"FUS9VED(")296UO=F4@071T96YD964B"FUS
M9W-T<B`BCE&)P8[F@NB.?H+?(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHS,@IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W
M:71H('1H92!I;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B
M"B)D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A
M<BX\+W-T<F]N9SXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-C(V"FUS9VED(")297%U:7)E9"(*;7-G<W1R("*52Y![(@H*(SH@;&EB+T9"
M5FEE=RYP:'`Z.3@@;&EB+T9"5FEE=RYP:'`Z,3,W(&QI8B]&0E9I97<N<&AP
M.C$T,"!L:6(O1D)6:65W+G!H<#HQ-#,*;7-G:60@(E)E<75I<F5D($%T=&5N
M9&5E<R(*;7-G<W1R("*52Y![CE&)P8[2(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S$P"FUS9VED
M(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R("*#9H-T@TB#BX-G@LF6WX*W
M(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0S('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$V-@IM<V=I9"`B4F5S<&]N<V4B"FUS
M9W-T<B`BB9Z3FB(*"B,Z('EE87(N<&AP.C@X('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,PHC
M.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B4V$B"FUS9W-T<B`B
MDWDB"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C$@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(P"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I
M<'0N:6YC.C<S"FUS9VED(")3871U<F1A>2(*;7-G<W1R("*3>9=J(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,@HC+"!F=7IZ
M>0IM<V=I9"`B4V%V92(*;7-G<W1R("*3>2(*"B,Z('9I97=E=F5N="YP:'`Z
M,3$X(&5D:71E=F5N="YP:'`Z-#@@961I=&5V96YT+G!H<#HU-@IM<V=I9"`B
M4V%V92!!<R!.97<B"FUS9W-T<B`BD%:+2X+&@K6"Q)7;D;8B"@HC.B!T96UP
M;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z.#<*(RP@9G5Z>GD*;7-G
M:60@(E-A=F4@071T96YD965S(@IM<V=S='(@(HY1B<&.TB(*"B,Z(&%D9&5V
M96YT+G!H<#HU-2!E9&ET979E;G0N<&AP.C4Q"FUS9VED(")3879E($5V96YT
M(@IM<V=S='(@(H-#@WB#DX-G@O"5VY&V(@H*(SH@<V5A<F-H+G!H<#HY,2!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$U"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHV-R!T96UP;&%T97,O8V%L96YD
M87)S+W-E87)C:"YI;F,Z.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$T,"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-@IM<V=I9"`B
M4V5A<F-H(@IM<V=S='(@(HR?C?4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+W-E87)C:"YI;F,Z,0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($-A;&5N9&%R
M<R(*;7-G<W1R("*+I)=,EUR2Z)5<@48B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(%)E<W5L=',B
M"FUS9W-T<B`BC)^-]2(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H
M+FEN8SHV"FUS9VED(")396%R8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN:6YG
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,34P"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!C86QE;F1A<B!T
M;R!E9&ET(@IM<V=S='(@(I=<DNB57(+PD4F1\"(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(V."!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N
M+FEN8SHS,0HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHX
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("**2HYN
MD_J"\)#=DN@B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!C86QE;F1A<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B
M@T.#DX-\@5N#9X*W@NF77)+HE5R"\)%)D?"!1B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,0IM<V=I9"`B(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O
M<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N
M9"!C:&]O<V4@(@HB9&5F875L="!V:65W+B(*;7-G<W1R("**;91&@LR#28-V
M@U:#AX.3@N*57(ZFC&".KH+(@L>"\)%)D?""M8+<@K>!0B(*"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,3D*;7-G:60@(E-E;&5C="!T:&4@8V%L
M96YD87(@=&\@:6UP;W)T('1O.B(*;7-G<W1R("*#0X.3@WR!6X-G@K>"Z9=<
MDNB57(+PD4F1\(%&(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M,@IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R("*#
M1X-.@UB#?(%;@V>"S(Q@CJZ"\)%)D?"!1B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,C@*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O
M<G0Z(@IM<V=S='(@(H-#@Y.#?(%;@V>"MX+I@W2#0(-#@XN"\)%)D?"!1B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@(E-E;&5C="!T
M:&4@9FER<W0@=V5E:V1A>3HB"FUS9W-T<B`BCU2"S(W%CXF"S)=JD_J"\)%)
MD?"!1B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G:60@
M(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T
M<B`BC+.#=(-`@T.#BX+,C&".KH+PD4F1\(%&(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T:6UE('-P86X@=&\@
M<VAO=SHB"FUS9W-T<B`BE5R.IH*W@NF*^HK4@O"129'P@48B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(E-E;&5C="!T:&4@=FEE=R!T
M;R!D:7-P;&%Y(&]N('-T87)T=7`Z(@IM<V=S='(@(HW%CXF"S)5<CJ:,8(ZN
M@O"129'P@48B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(*;7-G:60@
M(E-E;&5C="!W:&EC:"!E=F5N=',@=&\@<VAO=R!I;B!T:&4@<&]R=&%L+B(*
M;7-G<W1R("*#?(%;@UZ#BXGFELJ"R95<CJ:"MX+I@T.#>(.3@V>"\)%)D?""
MM8+<@K>!0B(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR-"!T96UP
M;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C0*;7-G:60@(E-E;F0@82!C86YC
M96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E;F1E97,@=VAE;B!D96QE=&EN
M9R!T:&ES(&5V96YT(@IM<V=S='(@(H*Q@LR#0X-X@Y.#9X+PC>V/G(*W@NF.
MGH+)CE&)P8[2@LF#3(.#@Y.#6H.+@LR2RI)M@O"/;X*W(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E-E
M;F0@86X@96UA:6P@=&\@)7,B"FUS9W-T<B`B)7,@@LF#@8%;@XN"\)&7@NDB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#$*;7-G:60@(E-E;F0@
M=7!D871E<R]I;G9I=&%T:6]N<R!T;R!A;&P@871T96YD965S('=H96X@<V%V
M:6YG('1H:7,@979E;G0B"FUS9W-T<B`B@T.#>(.3@V>"\)7;D;:"M8*]CIZ!
M08Y1B<&.TI%3B/6"R9+*DFV"\(]O@K<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHW-@IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(H)8
MC(XB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHX,PIM
M<V=I9"`B4V5T(&5N9"!D871E(@IM<V=S='(@(H])E[F3^H+PD-V2Z"(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V.`IM<V=I9"`B4V5T(')E8W5R
M<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`BC$J"Z)74@K6/29>YD_J"\)#=DN@B
M"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0IM<V=I
M9"`B4V5T('-T87)T(&1A=&4B"FUS9W-T<B`BBDJ.;I/Z@O"0W9+H(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y"FUS9VED("(B"B)3970@>6]U<B!F
M<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H97(@=7-E
M<G,G(&9R964O8G5S>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A
M<G,N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(E-H87)E(&YO="!F;W5N
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C<Y"B,L(&9U>GIY"FUS9VED(")3:&%R960@0V%L96YD87)S
M(@IM<V=S='(@(HNDETR77)+HE5R!1B(*"B,Z('1E;7!L871E<R]M96YU+FEN
M8SHT-R!T96UP;&%T97,O;65N=2YI;F,Z-#D*;7-G:60@(E-H87)E9"!#86QE
M;F1A<G,Z(@IM<V=S='(@(HNDETR77)+HE5R!1B(*"B,Z(&-A;&5N9&%R7W-E
M87)C:"YP:'`Z,C4@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N
M:6YC.C,*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M,PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!#86QE;F1A<B(*;7-G<W1R("*77)+H
ME5PB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,C(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-H;W<@8V%L96YD87(@7"(E<UPB
M(@IM<V=S='(@(HNDETR77)+HE5R!1B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-38*;7-G:60@(E-H;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G<W1R
M("*5JI?>@LR)\)#@@O"57(ZF@K6"W(*W@JF!2"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#8*;7-G:60@(E-H;W<@9&5L971E+"!A;&%R;2P@86YD
M(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_(@IM<V=S='(@
M(I=<DNB57(+,DH:"Q8WMCYR!08QXE?&!08Q*@NB5U(*U@LR#08-#@U*#DX+P
ME5R.IH*U@MR"MX*I@4@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R
M"FUS9VED(")3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD87(_(@IM<V=S
M='(@(H->@UB#3H+,BOJ3^H+PEUR2Z)5<@LF57(ZF@K6"W(*W@JF!2"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C8*;7-G:60@(E-H;W<@9G)E92]B
M=7-Y(&QE9V5N9#\B"FUS9W-T<B`BEUR2Z(_NE?&!:49R964O0G5D>8%J@LR)
M\)#@@O"57(ZF@K6"W(*W@JF!2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,#,*;7-G:60@(E-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L
M87)M('-E=#\B"FUS9W-T<B`BC'B5\8+,@J""Z8-#@WB#DX-G@KZ"KX+PE5R.
MIH*U@MR"MX*I@4@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<U"B,L
M(&9U>GIY"FUS9VED(")3:&]W('-H87)E9"!C86QE;F1A<G,@<VED92UB>2US
M:61E/R(*;7-G<W1R("*+I)=,EUR2Z)5<@O"5P(+7@L257(ZF@K6"W(*W@JF!
M2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*(RP@9G5Z>GD*;7-G
M:60@(E-H;W<@=&%S:W,@=7-I;F<@8V%T96=O<GD@8V]L;W)S/R(*;7-G<W1R
M("*#7H-8@TZ"S(KZD_J"\)=<DNB57(+)E5R.IH*U@MR"MX*I@4@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34*;7-G:60@(E-H;W<@=&EM92!O9B!D
M87D@8F5T=V5E;B!E86-H(&1A>2!I;B!W965K('9I97=S/R(*;7-G<W1R("*/
M5)5<CJ:"Q8+@EHB3^HZ>BM2"\)5<CJ:"M8+<@K>"J8%((@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@
M(E-T85]R="(*;7-G<W1R(")?4HI*CFZ3^B(*"B,Z(&1A=&$N<&AP.C4U"B,L
M(&9U>GIY"FUS9VED(")3=&%R="!$871E(@IM<V=S='(@(HI*CFZ3^H+PD-V2
MZ"(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-R!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C(U"FUS9VED(")3=&%R="!/;B(*;7-G<W1R("**2HYND_HB
M"@HC.B!D871A+G!H<#HU-@IM<V=I9"`B4W1A<G0@5&EM92(*;7-G<W1R("**
M2HYNCIZ*U"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D
M+FEN8SHY-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHX-0IM<V=I9"`B4W1A
M=%]U<R(*;7-G<W1R(")?58_SD=0B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V
M96YT7VAE861E<G,N:6YC.C8@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C<*
M;7-G:60@(E-T871U<R(*;7-G<W1R("*/\Y'4(@H*(SH@>65A<BYP:'`Z.#$@
M>65A<BYP:'`Z.3`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C4*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(T(&QI8B]";&]C:R]M;VYT
M:"YP:'`Z,3`W(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`Y"FUS9VED(")3=2(*
M;7-G<W1R("*3^B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-"!T
M96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C,*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(Q('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8W
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4*;7-G:60@(E-U;F1A>2(*
M;7-G<W1R("*3^I=J(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS
M9VED(")487-K<R(*;7-G<W1R("*#7H-8@TXB"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HU-S0@;&EB+TMR;VYO;&ET:"YP:'`Z-3DW"FUS9VED(")496YT871I
M=F4B"FUS9W-T<B`BE7.2Z"(*"B,Z('EE87(N<&AP.C@V('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(R,0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS
M9W-T<B`BEM@B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C<P"FUS9VED(")4:&4@161I="!!='1E;F1E97,@<V-R965N(&ES(&YO(&QO
M;F=E<B!P<F5S96YT+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A
M<G,N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<
M(B5S7"(@8V%N;F]T(&)E(&1E;&5T960N(@IM<V=S='(@(I=<DNB57"!<(B5S
M7"(@@LV-[8^<@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@8V%L96YD87)S+G!H
M<#HT,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!H87,@8F5E;B!C<F5A=&5D+B(*;7-G<W1R("*77)+HE5P@7"(E
M<UPB((+-C>V/G(*S@NJ"W(*U@KV!0B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("*77)+HE5P@7"(E<UPB((+-C>V/G(*S
M@NJ"W(*U@KV!0B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R96YA;65D
M('1O(%PB)7-<(BXB"FUS9W-T<B`BEUR2Z)5<(%PB)7-<(B""S2!<(B5S7"(@
M@LF6O)%/@JJ5SXU8@K."ZH+<@K6"O8%"(@H*(SH@8V%L96YD87)S+G!H<#HU
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R("*77)+HE5P@7"(E<UPB((+-E=N1MH*S
M@NJ"W(*U@KV!0B(*"B,Z(&1A=&$N<&AP.C(R-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z
M("5S(@IM<V=S='(@(I=<DNB57"!<(B5S7"(@@LV-[8^<@L6"JX+<@KF"\8+%
M@K6"O8%"(@H*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z,38S
M"FUS9VED(")4:&4@96YD(&1A=&4@;75S="!B92!L871E<B!T:&%N('1H92!S
M=&%R="!D871E+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,#DT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E
M<UPB(&AA<R!B965N(&%D9&5D+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS
M9W-T<B`BEUR2Z)5<(%PB)7-<(B""S2!<(B5S7"(@@LF6O)%/@JJ5SXU8@K."
MZH+<@K6"O8%"(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+"!W:&EC:"!W87,@;VX@)7,@870@)7,N(@IM<V=S='(@(I=<
MDNB57"!<(B5S7"(@@LV-[8^<@K."ZH+<@K6"O8%"(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`Y.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&5V96YT(%PB)7-<(B!H87,@8F5E;B!E9&ET960L('=H:6-H(&ES(&]N("5S
M(&%T("5S+B(*;7-G<W1R("*77)+HE5P@7"(E<UPB((+-(%PB)7-<(B""R9:\
MD4^"JI7/C5B"LX+J@MR"M8*]@4(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!N;W1I9FEC871I
M;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL>2!S96YT+B(*;7-G<W1R("*#0X-X
M@Y.#9Y+*DFV"S2`E<R""LX+Q@LF1EX+G@NJ"W(*U@KV!0B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P,C0*;7-G:60@(E1H92!F;VQL;W=I;F<@:7,@82!M
M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#HB"FUS9W-T
M<B`BB,B)NH+-@T.#>(.3@V>"S(_:C=>"Q8*W@48B"@HC.B!A='1E;F0N<&AP
M.C0Q"FUS9VED("(B"B)4:&4@<F5Q=65S="!W87,@:6YC;VUP;&5T92X@4V]M
M92!P87)A;65T97)S('1H870@87)E(&YE8V5S<V%R>2!T;R!A8V-E<'0@;W(@
M(@HB9&5C;&EN92!A;B!E=F5N="!A<F4@;6ES<VEN9RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]E;7!T>2YI;F,Z,PIM<V=I9"`B5&AE<F4@
M87)E(&YO(&5V96YT<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82XB
M"FUS9W-T<B`BC+N-W8+,BNZ/@(+)B.J2=H*W@NF#0X-X@Y.#9X+-@J""Z(+<
M@KF"\8%"(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C$X(&5D:71E=F5N=&%C
M=&EO;BYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S(@IM<V=S='(@(I=<
MDNB57(+,@T&#3H-:@UB2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!1B`E<R(*
M"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N=#H@)7,B"FUS
M9W-T<B`B@T.#>(.3@V>"S)+'B<&2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!
M1B`E<R(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I;F<@=&AE(&5V96YT
M.B`E<R(*;7-G<W1R("*#0X-X@Y.#9X+,E=*/5Y*&@LF#1X.)@5N"JI2MD+:"
MM8+<@K6"O8%&("5S(@H*(SH@;&EB+V%P:2YP:'`Z,S,X(&QI8B]A<&DN<&AP
M.C4Y-@IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<B"#9H%;@UZ"\(-#
M@Y.#?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0B(*"B,Z(&5D:71E
M=F5N=&%C=&EO;BYP:'`Z-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(H-#
M@WB#DX-G@LR(VI.NDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@48@)7,B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A
M=&EO;B!T;R`E<SH@)7,B"FUS9W-T<B`B@T.#>(.3@V>2RI)M@O`@)7,@@K."
M\8+)D9>039*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%&)7,B"@HC.B!D871A
M+G!H<#HQ,#4*;7-G:60@(E1H97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R
M="XB"FUS9W-T<B`B@T>#3H-8@WR!6X-G@K>"Z8-#@WB#DX-G@LV"H(+H@MR"
MN8+Q@4(B"@HC.B!D871A+G!H<#HQ.#0*;7-G:60@(E1H:7,@9FEL92!F;W)M
M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B@K&"S(-T@T"#0X.+C&".
MKH+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9&%T82YP:'`Z,C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("5S(@IM<V=S='(@(H-4@5N#;X*I@N>"S(F>DYJ!1B5S(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$Q.`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW
M,0IM<V=I9"`B5&AU<G-D87DB"FUS9W-T<B`BEMB7:B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHS-PIM<V=I9"`B5&EM92!3<%]A;B(*;7-G
M<W1R("**^HK4(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z-`IM<V=I9"`B5&EM92!S<&%N(@IM<V=S='(@(HKZBM0B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,S8@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z-#`*;7-G:60@(E1I=%]L92(*;7-G<W1R(")?3)5<
MD>@B"@HC.B!D871A+G!H<#HU-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z,C`*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHS
M"FUS9VED(")4:71L92(*;7-G<W1R("*57)'H(@H*(SH@;&EB+T)L;V-K+W!R
M979M;VYT:&QI<W0N<&AP.C$R,B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ
M,C$*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R-PIM<V=I9"`B5&]D87DB
M"FUS9W-T<B`BC:&3^B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H
M<#HQ,C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(S"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ,CD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(I:^
MD_HB"@HC.B!Y96%R+G!H<#HX-"!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHV,"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3D*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1U(@IM<V=S='(@(HG.(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$W('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$Q-@HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV
M.0IM<V=I9"`B5'5E<V1A>2(*;7-G<W1R("*)SI=J(@H*(SH@8V]N9FEG+VME
M>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")4>7!E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ.#,*;7-G:60@
M(E523"(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92]S<6PN<&AP.C8T"FUS
M9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!C86QE;F1A<G,N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<R(*;7-G<W1R(")<(B5S7"(@
M@O"-[8^<@L6"JX+<@KF"\8%&)7,B"@HC.B!L:6(O1')I=F5R+VUC86PN<&AP
M.C$S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S
M+B(*;7-G<W1R("(E<R""\(WMCYR"Q8*K@MR"N8+Q@4(B"@HC.B!L:6(O1')I
M=F5R+G!H<#HQ.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(E<R""
M\(WMCYR"Q8*K@MR"N8+Q@4(B"@HC.B!C86QE;F1A<G,N<&AP.C4Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B7"(E<UPB((+PC>V/G(+%@JN"W(*Y@O&!1B5S(@H*
M(SH@;&EB+U-T;W)A9V4O:V]L86(N<&AP.C,T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R971R:65V92!F<F5E+V)U<WD@:6YF;W)M871I;VX@
M9F]R("5S(@IM<V=S='(@(B5S((*S@O&"S)=<DNB/[I7Q@O"/BI.^@L6"JX+<
M@KF"\2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$U"B,Z('-C<FEP
M=',O=7!G<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T7V-A=&5G;W)I97-?=&]?
M<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BEJ*0KI>=
M(@H*(SH@;&EB+V%P:2YP:'`Z,S<V(&QI8B]A<&DN<&AP.C0U,"!L:6(O87!I
M+G!H<#HU,38@;&EB+V%P:2YP:'`Z-C(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3`Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P"FUS9VED(")5<V5R($EN=&5R9F%C92(*;7-G<W1R("*#AH%;@U6!
M6X-#@Y.#7H%;@W2#1H-#@U@B"@HC.B!Y96%R+G!H<#HQ-C,@>65A<BYP:'`Z
M,38Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,38R"FUS9VED(")6:65W($1A>2(*;7-G<W1R("(B"@HC.B!Y96%R+G!H
M<#HX-2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,2!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,C`*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ
M,#4*;7-G:60@(E=E(@IM<V=S='(@(I"%(@H*(SH@=&5M<&QA=&5S+VUO;G1H
M+VAE860N:6YC.C$X('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-PHC.B!T
M96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,`IM<V=I9"`B5V5D;F5S
M9&%Y(@IM<V=S='(@(I"%EVHB"@HC.B!A='1E;F1E97,N<&AP.C$Q,B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,CDP(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(S
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*;7-G
M<W1R("*/5"(*"B,Z(&UO;G1H+G!H<#HQ-SD@=V]R:W=E96LN<&AP.C,P('=E
M96LN<&AP.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E=E96L@)60B"FUS9W-T
M<B`BD>8E9(]4(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3D@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED(")7965K*',I(@IM<V=S
M='(@(H]4BM0B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"FUS9VED(")7965K;'DZ(%)E8W5R
M<R!E=F5R>2(*;7-G<W1R("*6B(]4@4:,2H+HE=2"M2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@
M9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T
M97(@979E;G1S/R(*;7-G<W1R("*3^I5<CJ:"QH]4E5R.IH+,CTF7N8Z>BM2"
MS8%((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B(@HB
M5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@<W1A<G0L('=H
M96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/R(*;7-G<W1R("*3^I5<
MCJ:"QH]4E5R.IH+,BDJ.;HZ>BM2"S8%((@H*(SH@871T96YD965S+G!H<#HQ
M,3$@;&EB+TMR;VYO;&ET:"YP:'`Z,3(X.2!L:6(O0FQO8VLO=')E95]M96YU
M+G!H<#HR,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E=O
M<FL@5V5E:R(*;7-G<W1R("*,CHO@(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3(Y,B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-0HC+"!F=7IZ>0IM<V=I
M9"`B665A<B(*;7-G<W1R("*,GXWU(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T,0IM<V=I9"`B
M665A<FQY.B!296-U<G,@979E<GDB"FUS9W-T<B`BEHB43H%&C$J"Z)74@K4B
M"@HC.B!D871A+G!H<#HT,"!D871A+G!H<#HR,S0@961I=&5V96YT86-T:6]N
M+G!H<#HT-B!A9&1E=F5N="YP:'`Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&5V
M96YT<RXB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HT.0IM<V=I9"`B66]U
M(&%R92!N;W0@86X@871T96YD964@;V8@=&AE('-P96-I9FEE9"!E=F5N="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHW-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T:&ES(&9O<FT@9G)O;2!T
M:&4@161I="!!='1E;F1E97,@<V-R965N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HY-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R
M960@:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO;B`B"B)/<'1I;VYS+B!9
M;W4@;75S="!S970@;VYE("5S:&5R925S(&)E9F]R92!E=F5N="!N;W1I9FEC
M871I;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B"B*"H(+(@KV"S8S"D&R/
M[I7Q@LR0W9+H@L6#@8%;@XN#08-H@XR#6(+PD-V2Z(*U@L2"HH+<@KF"\8%"
M@T.#>(.3@V>2RI)M@O""MX+I(@HB@KV"WX+)@LV"NX+,D-V2Z(*JE4N7=H+%
M@K>!0B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HR,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E
M;G1S('1O("5S+B(*;7-G<W1R("*"H(+(@KV"R8+-@T.#>(.3@V>"\"`E<R""
MR9+'B<&"MX+IC*",P(*J@J""Z(+<@KF"\8%"(@H*(SH@9&%T82YP:'`Z,3DT
M"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E
M;G1S('1O('1H92!S96QE8W1E9"!C86QE;F1A<BXB"FUS9W-T<B`B@J""R(*]
M@LF"S9%)D?""M8*]EUR2Z)5<@LF#0X-X@Y.#9X+PDL>)P8*W@NF,H(S`@JJ"
MH(+H@MR"N8+Q(@H*(SH@9&5L979E;G1A8W1I;VXN<&AP.C(V"FUS9VED(")9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!D96QE=&4@=&AI<R!E=F5N
M="XB"FUS9W-T<B`B@J""R(*]@LF"S8*Q@LR#0X-X@Y.#9X+PC>V/G(*W@NF,
MH(S`@JJ"H(+H@MR"N8+Q@4(B"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C<X
M"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H
M:7,@979E;G0N(@IM<V=S='(@(H*@@LB"O8+)@LV"L8+,@T.#>(.3@V>"\)72
MCU>"MX+IC*",P(*J@J""Z(+<@KF"\8%"(@H*(SH@9&%T82YP:'`Z,3@Y"FUS
M9VED(")9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BXB
M"FUS9W-T<B`BE7.0LX+(EUR2Z)5<@O".=Y+H@K6"W(*U@KV!0B(*"B,Z(&%T
M=&5N9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E
M<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z
M(&%T=&5N9"YP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E('-U8V-E
M<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM
M<V=S='(@(H*@@LB"O8+)@LV"L8+,@T.#>(.3@V>"\(WMCYR"MX+IC*",P(*J
M@J""Z(+<@KF"\8%"(@H*(SH@871T96YD+G!H<#HS,0HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&AA=F4@=&5N=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T
M;R!T:&ES(&5V96YT+B(*;7-G<W1R("*"H(+(@KV"R8+-@K&"S(-#@WB#DX-G
M@O"-[8^<@K>"Z8R@C,""JH*@@NB"W(*Y@O&!0B(*"B,Z(&-A;&5N9&%R<RYP
M:'`Z.3$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E
M(&1E;&5T960N(@IM<V=S='(@(HWMCYR"MX+I@M>"JY=<DNB57(+PD4F1\(*U
M@L2)NH*S@J*!0B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z-30*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T
M+B(*;7-G<W1R("*#08-H@XR#6(+PC<6/B8+)D4F1\(*U@L2)NH*S@J*!0B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.30*;7-G:60@(EEO=2!R97%U97-T
M960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&%D9&5D('1O('EO
M=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,3`T"FUS9VED("(B"B)9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D
M('=H96X@979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U<B!C86QE;F1A<G,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3D*;7-G:60@
M(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E
M(&5D:71E9"!I;B!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(')E;6EN9&5D(&%B;W5T("5S+"!W
M:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-H87)E<V5L96-T+FEN8SHQ,`IM<V=I9"`B66]U<B!D969A=6QT
M(&-A;&5N9&%R(@IM<V=S='(@(H-F@W2#2(.+@V>77)+HE5PB"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ,#4S(&QI8B]$<FEV97(N<&AP.C$P-C,*;7-G:60@(EM5
M;FYA;65D(&5V96YT72(*;7-G<W1R(");EK.6O(-#@WB#DX-G72(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.CDW"B,L(&9U>GIY"FUS9VED(")?06QA
M<FTB"FUS9W-T<B`BC'B5\2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHQ,0IM<V=I9"`B7T)A<VEC(%-E87)C:"(*;7-G<W1R
M(")?0HK(B-6,GXWU(@H*(SH@=FEE=V5V96YT+G!H<#HQ,C`*;7-G:60@(E]%
M9&ET(@IM<V=S='(@(E]%E=*/5R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M,S`*;7-G:60@(E]';W1O(@IM<V=S='(@(E]'B-J3KB(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S,S8*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@
M(E])@T.#DR^#08-%@V<B"@HC(&US9W-T<B`B7TF#0X.3@WR!6X-G+X-'@TZ#
M6(-\@5N#9R(*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q.`IM<V=I9"`B7TUY
M($-A;&5N9&%R<R(*;7-G<W1R(")?38Z$@LR77)+HE5PB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,S(U"FUS9VED(")?3F5W($5V96YT(@IM<V=S='(@(E].
MD%:#0X-X@Y.#9R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-#$*;7-G:60@
M(E]0<FEN="(*;7-G<W1R(")?4(CSC?PB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,S,R"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E]3C)^-]2(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$S,C@*;7-G:60@(E]4;V1A>2(*;7-G<W1R(")?
M5(VAD_HB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#(*;7-G:60@
M(F)E9F]R92!T:&4@979E;G0@<W1A<G1S(@IM<V=S='(@(H-#@WB#DX-GBDJ.
M;I%/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-0HC+"!F=7IZ>0IM
M<V=I9"`B9&%Y(@IM<V=S='(@(HVAD_HB"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$P"FUS9VED
M(")D87DH<RDB"FUS9W-T<B`BD_HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3@V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#<*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$X."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Y"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*(RP@9G5Z>GD*;7-G:60@(F1A
M>7,B"FUS9W-T<B`BD_HB"@HC.B!D871A+G!H<#HQ-#<@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ"B,L(&9U>GIY"FUS9VED(")E=F5N=',N8W-V(@IM
M<V=S='(@(B5D((-#@WB#DX-G(@H*(SH@9&%T82YP:'`Z,38X"B,L(&9U>GIY
M"FUS9VED(")E=F5N=',N:6-S(@IM<V=S='(@(B5D((-#@WB#DX-G(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,S$*;7-G:60@(F9R
M;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,S`@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,V"FUS
M9VED(")M;VYT:"AS*2(*;7-G<W1R("*#EHR.(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")O;B`E<R!A="`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C,P"FUS9VED(")O;B!T:&4@<V%M92!D
M871E(@IM<V=S='(@(I.O@K:3^H+)(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S-@IM<V=I9"`B
M;VX@=&AE('-A;64@=V5E:V1A>2(*;7-G<W1R("*3KX*VEVJ3^H+)(@H*(SH@
M9&%T82YP:'`Z,S`@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0HC+"!F
M=7IZ>0IM<V=I9"`B=D-A;&5N9&%R+VE#86QE;F1A<B(*;7-G<W1R("*77)+H
ME5R"S):\D4\B"@HC.B!L:6(O87!I+G!H<#HS-#D@;&EB+V%P:2YP:'`Z-C`W
M"FUS9VED(")V179E;G0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DQ"B,L(&9U>GIY"FUS9VED(")W965K(@IM
M<V=S='(@(H]4(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q-PIM<V=I9"`B=V5E:RAS*2!O;CHB
M"FUS9W-T<B`BCU2!09.O@K:3^H+)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.30*(RP@9G5Z>GD*;7-G:60@(G=E96MS(@IM<V=S
M='(@(H]4BM0B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C0R"FUS9VED(")Y96%R*',I(@IM<V=S
M='(@(I1.BM0B"@``+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI
M=&@O<&\O8F=?0D<N<&\`````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,3(T,#$S`#$P-#$W,S8R-S4R`#`R,#,U,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C($)U;&=A<FEA;B!T<F%N
M<VQA=&EO;G,@9F]R($MR;VYO;&ET:"!P86-K86=E+@HC($-O<'ER:6=H="`H
M0RD@,C`P,B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U
M=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($MR;VYO;&ET:"!P
M86-K86=E+@HC($UI<F]S;&%V(%!E;F1E=B`\;6ER;T!C>6)E<G-H861E+G5S
M/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R
M<VEO;CH@2W)O;F]L:71H(#(N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`R+3$Q+3$Y(#(P.C0T+3`U,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^7&XB"B),86YG
M=6%G92U496%M.B!"1R!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U#4#$R-3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:71<;B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@8V%L96YD87)S(&9O=6YD
M(@IM<V=S='(@(L+@^.CRY2#JX.OE[>3@\.@Z(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5D(&5V96YT<R(*;7-G<W1R("+"\>CWZN@@\?KAZ/+H_R(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!$87DH<RD@)7,@2&]U<BAS*2`E<R!-:6YU=&5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@871T96YD965S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(W
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I
M;7!O<G1E9"(*;7-G<W1R("(E<R#TX.GK(.'E^.4@Z.SO[O#RZ/#@[2#S\>_E
M^.WN(@H*(SH@8V%L96YD87)S+G!H<#HQ,#4@;&EB+V)A<V4N<&AP.C$R.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G
M<W1R("+*X.OE[>3@\"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H
M+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N9&%R(&YA;64@=&\@
M<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE(&UA:6X@
M(@HB=VEN9&]W*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$V-`HC+"!F=7IZ>0IM<V=I9"`B*B!!9&0@=&AE<V4@
M8GD@8VQI8VMI;F<@061D("HB"FUS9W-T<B`B*B#$[N'@XN7RY2#RY>?H(.K@
M\NX@ZNOHZNWE\N4@[>`@26YV:71E("HB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$U,`IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D
M9')E<W,H97,I("HB"FUS9W-T<B`B*B#,[NO_(.CGX>7PY?+E(.#D\.7Q*.@I
M("HB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@V"FUS9VED("(Q(&%T=&5N9&5E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT
M"B,L(&9U>GIY"FUS9VED("(Q(&5V96YT(@IM<V=S='(@(L+QZ/?JZ"#Q^N'H
M\NC_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PHC+"!F=7IZ>0IM
M<V=I9"`B,2!H;W5R(@IM<V=S='(@(B5D(/?@\2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G:60@(C$U(&UI;G5T97,B"FUS
M9W-T<B`B)60@[.CM\_+H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-0HC+"!F=7IZ>0IM<V=I9"`B,C`@;6EN=71E<R(*;7-G<W1R("(E9"#LZ.WS
M\N@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"B,L(&9U>GIY"FUS
M9VED("(S,"!M:6YU=&5S(@IM<V=S='(@(B5D(.SH[?/RZ"(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C$W,0HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N
M9SY!='1E;F1E97,\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\8C[*
MZ_[W[N+H(.3S[.@\+V(^("CN[_;H[NW@Z^WN*2(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C$T.0HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY$97-C
M<FE?<'1I;VX\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\8C[.[^CQ
MX.WHY3PO8CX@*.[O]NCN[>#K[>XI(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C<W"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S
M=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^RNO^]^[BZ"#D\^SH/"]B
M/B`H[N_VZ.[MX.OM[BDB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M.30*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^4F5C=7)R96YC93PO<W1R;VYG
M/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/L_NXO+N\/_E[.[Q\CPO8CX@*.[O
M]NCN[>#K[>XI(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#$@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.#$*;7-G:60@(D%-(@IM<V=S
M='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4Y,0IM<V=I9"`B06-C97!T
M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C$Q"FUS9VED(")!9%]V86YC960@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38Q('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")!9&0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8*;7-G:60@(D%D9"!%
M=F5N="(*;7-G<W1R("+$[N'@XN@@\?KAZ/+HY2(*"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C,U"B,L(&9U>GIY"FUS
M9VED(")!9&0@82!N97<@4F5M;W1E($-A;&5N9&%R(@IM<V=S='(@(L3NX>#B
M_^WE(.W@(.WNXB#N\N3@Z^7WY>T@*.WEZ^[JX.OE[2D@RN#KY>WDX/`Z(@H*
M(SH@861D979E;G0N<&AP.C8T"FUS9VED(")!9&0@82!N97<@979E;G0B"FUS
M9W-T<B`BQ.[AX.+H(.WNXNX@\?KAZ/+HY2(*"B,Z('1E;7!L871E<R]A='1E
M;F1E97,O871T96YD965S+FEN8SHW-`IM<V=I9"`B061D(&%T=&5N9&5E<R(*
M;7-G<W1R("(B"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C<X"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E
M9"!396%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z-3,*;7-G:60@(D%L87)M(@IM<V=S='(@(L#KX/#LX"(*"B,Z(&QI8B]$
M<FEV97(N<&AP.C$W-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@
M9&%Y<R!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!H;W5R<R!B969O<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<W-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@;6EN=71E<R!B969O<F4B"FUS
M9W-T<B`B)7,@S.CM\_+H(._PY>3H(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!W965K<R!B969O<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V,PIM<V=I9"`B06QA
M<FT@,2!D87D@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$W-C@*;7-G:60@(D%L87)M(#$@:&]U<B!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z,3<W,PHC+"!F=7IZ>0IM<V=I9"`B06QA<FT@
M,2!M:6YU=&4@8F5F;W)E(@IM<V=S='(@(B5S(,SH[?/RZ"#O\.7DZ"(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$W-3@*;7-G:60@(D%L87)M(#$@=V5E:R!B969O
M<F4B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-C`*;7-G:60@(D%L87)M($1A
M=&4B"FUS9W-T<B`BQ.#RX"#GX"#@Z^#P[.`B"@HC.B!D871A+G!H<#HU.0IM
M<V=I9"`B06QA<FT@4W!A;B`H;6EN=71E<RDB"FUS9W-T<B`BS_#NY/KKYNCR
MY>OM[O'R(.W@(.#KX/#LX/+@("CLZ.WS\N@I(@H*(SH@9&%T82YP:'`Z-C$*
M;7-G:60@(D%L87)M(%1I;64B"FUS9W-T<B`BU^#Q(.?@(.#KX/#LX"(*"B,Z
M('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS,0HC+"!F=7IZ>0IM<V=I
M9"`B06QL(@IM<V=S='(@(M;EZ^C_\B#DY>TB"@HC.B!L:6(O1D)6:65W+G!H
M<#HQ,C8@;&EB+T9"5FEE=RYP:'`Z,3(Y(&QI8B]&0E9I97<N<&AP.C$S,@HC
M+"!F=7IZ>0IM<V=I9"`B06QL($%T=&5N9&5E<R(*;7-G<W1R("+"\>CWZN@@
M\?KAZ/+H_R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU.0IM
M<V=I9"`B06QL($9U='5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-3,*(RP@9G5Z>GD*;7-G:60@(D%L;"!087-T(@IM
M<V=S='(@(M;EZ^C_\B#DY>TB"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES
M="YP:'`Z,C<@;&EB+T)L;V-K+VUO;G1H+G!H<#HR-`HC.B!L:6(O0FQO8VLO
M;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G
M:60@(D%L;"!6:7-I8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C$R,B!L:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB
M+T1A>59I97<N<&AP.CDS"B,Z(&QI8B]7965K5FEE=RYP:'`Z,3(W(&QI8B]7
M965K5FEE=RYP:'`Z,3,T(&QI8B]$<FEV97(N<&AP.C$X,S(*;7-G:60@(D%L
M;"!D87DB"FUS9W-T<B`BUN7KZ/_R(.3E[2(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@979E;G0B"FUS9W-T<B`BT?KA
MZ/+H_R#GX"#VY>OH_R#DY>TB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C(Q"FUS9VED(")!;&P@979E;G1S(@IM<V=S='(@(L+QZ/?JZ"#Q^N'H
M\NC_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC
M.C0Y"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW
M,2!L:6(O2W)O;F]L:71H+G!H<#HV.#,*;7-G:60@(D%N>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,0IM<V=I9"`B
M07!R:6PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE
M<W!A;BYI;F,Z,SD@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M.3,*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHW,"!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C$U-@IM<V=I9"`B070B"FUS9W-T<B`BXB(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$P,C8*;7-G:60@(B(*(D%T=&%C:&5D(&ES
M(&%N(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U
M="!T:&4@979E;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@
M:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY
M('5P9&%T92`B"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z
M-#(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E;F1A
M;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V
M,0IM<V=I9"`B071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHX"FUS9VED(")"87-I8R!3
M96%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T
M.C$W"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("+0[N;DY>T@Y.7M(@H*(SH@
M;&EB+T9"5FEE=RYP:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$P"FUS9VED(")"
M=7-Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S
M='(@(LK@Z^7MY.#P(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z-#D*
M(RP@9G5Z>GD*;7-G:60@(D-A;%]E;F1A<B(*;7-G<W1R("+*X.OE[>3@\"(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#8@;&EB
M+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(Q"B,Z(&QI8B]";&]C:R]M;VYT
M:"YP:'`Z,C$@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C$@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(R"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+*X.OE
M[>3@\"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"B,L(&9U>GIY"FUS
M9VED(")#86QE;F1A<B!3=6UM87)Y(@IM<V=S='(@(LK@Z^7MY.#P(@H*(SH@
M9&%T82YP:'`Z,C(X"B,L(&9U>GIY"FUS9VED(")#86QE;F1A<B!S=6-C97-S
M9G5L;'D@<'5R9V5D+B(*;7-G<W1R(")I0V%L96YD87(@].#IZ_KR(.'E^.4@
MZ.SO[O#RZ/#@[2#S\>_E^.WN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W"FUS9VED(")#
M86QE;F1A<G,B"FUS9W-T<B`BRN#KY>WDX/#H(@H*(SH@8V%L96YD87)S+G!H
M<#HR-PHC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87)S(&UU<W0@:&%V92!A(&YA
M;64N(@IM<V=S='(@(LCLY2#MX"#*X.OE[>3@\.`Z(@H*(SH@9&%T82YP:'`Z
M,C0S"B,L(&9U>GIY"FUS9VED(")#86XG="!C<F5A=&4@82!N97<@979E;G0N
M(@IM<V=S='(@(M'ZY^3@Z2#M[N+N(/'ZX>CRZ.4B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,2!T96UP;&%T97,O9&5L971E+V]N
M92YI;F,Z,S`*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,R('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C,P.0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C4W,`IM<V=I9"`B0V%N8V5L;&5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N8V5L;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-C0@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z-CD*(RP@9G5Z>GD*;7-G:60@(D-A=&5G;W)?>2(*;7-G<W1R("+*
MX/+EX^[PZ/\B"@HC.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V
M96YT7VAE861E<G,N:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*
M;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(LK@\N7C[O#H_R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@(B(*(D-H;V]S92!I9B!Y;W4@
M=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T
M960@979E;G1S(&)Y("(*(F5M86EL.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D-H;V]S92!I9B!Y;W4@=V%N="!T
M;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E
M;G1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V5A<F-H7V%B
M;V]K7W-E;&5C="YI;F,Z,3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.0IM
M<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F;W(@
M9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]F8E]C86QS7W-E;&5C="YI;F,Z,38*;7-G:60@(D-H;V]S92!T:&4@8V%L
M96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I
M;VXZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3$*
M;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@=VAE;B!G
M96YE<F%T:6YG(&9R964O8G5S>2!54DQS.B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!Y
M;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@(L+@^.C_\B#JX.OE[>3@
M\"#O[B#O[N3PX.?AZ/#@[>4Z(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C8U"FUS9VED(")#;&5A<B!A;&P@871T96YD965S(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(X('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S"FUS9VED(")#;VYF
M:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\B"FUS9W-T<B`BQ.`@\>4@Z.?H\>KB
MX"#KZ"#O[O+B^O#FY.7MZ.4@[_#H(.CG\O#HXN#MY?+N(.W@(/'ZX>CRZ/\_
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")#
M;VYF:7)M960B"FUS9W-T<B`BS>7O[N_ZZ^WE[2(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,#@*;7-G:60@(D-O<'D@=&AE(%52
M3"!B96QO=R!F;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO=7(@1G)E92]"
M=7-Y(%523#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,38R
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M,3(V"B,L(&9U>GIY"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BU^#Q\N7M(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q,@HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E($-A;&5N9&%R(@IM<V=S='(@(LWEZ^[JX.OM
MZ"#*X.OE[>3@\.@B"@HC.B!M;VYT:"YP:'`Z,38U('1E;7!L871E<R]W965K
M+VAE860N:6YC.C(U('1E;7!L871E<R]D87DO<F]W+FEN8SHV"B,Z(&QI8B]$
M87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z,3DT"FUS9VED(")#<F5A
M=&4@82!.97<@179E;G0B"FUS9W-T<B`BT?KGY.#I(.WNXNX@\?KAZ/+HY2(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C@P"FUS9VED(")#<F5A=&5D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR
M.0IM<V=I9"`B0W5R<F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`Y"FUS
M9VED(")$86EL>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(L3MY>+M[CH@[^[B
M\N#P_R#QY2#B\>7JZ"(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$P(&QI8B]+<F]N
M;VQI=&@N<&AP.C$R.#@@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"FUS9VED(")$87DB"FUS9W-T<B`B
MQ.7M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,3,Y"FUS9VED(")$87DH<RDB"FUS9W-T<B`BQ.7M
M*.3MZ"DB"@HC.B!V:65W979E;G0N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B
M1&5?;&5T92(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHW.0IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3DT"FUS9VED(")$96-L:6YE9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0@0V%L96YD87(B"FUS9W-T<B`BPN#XZ/_R(.K@Z^7M
MY.#P(._N(._NY/#@Y^'H\.#MY3HB"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z,3DS('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3@Q"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR.2!T96UP
M;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHR,PHC.B!L
M:6(O1')I=F5R+G!H<#HQ.#$S"FUS9VED(")$96QE=&4B"FUS9W-T<B`BR.?R
M\.CI(@H*(SH@9&5L979E;G0N<&AP.C0P('1E;7!L871E<R]D96QE=&4O;VYE
M+FEN8SHQ."!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,3@*(SH@;&EB
M+T1R:79E<BYP:'`Z,3@Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M)7,B"FUS9W-T<B`BR.?R\.CI("5S(@H*(SH@961I=&5V96YT+G!H<#HW,`IM
M<V=I9"`B1&5L971E($5V96YT(@IM<V=S='(@(LCG\O#HZ2#Q^N'H\NCE(@H*
M(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED("(B"B)$
M96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E
M(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R("(*(F%L;"!O8V-U<F5N
M8V5S/R(*;7-G<W1R("(B"B+(Y_+PZ.D@\>#L[B#RY>KS^>[R[B#Q^N'H\NCE
M+"#R[N+@(.@@XO'H]^KH(.'ZY.7YZ"#O[O_B_^+@[>C_+"#HZ^@@XO'H]^KH
M("(*(N_N_^+_XN#MZ/\_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.C$P-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M,C@*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:5]P=&EO;B(*;7-G<W1R("+.[^CQ
MX.WHY2(*"B,Z(&1A=&$N<&AP.C8R('1E;7!L871E<R]C86QE;F1A<G,O8V%L
M96YD87)S+FEN8SHQ-S4*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.38*
M;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(L[OZ/'@[>CE(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S,*;7-G:60@(D1I<W!L
M87DB"FUS9W-T<B`BS^[JX.;H(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y($-A;&5N
M9&%R<R(*;7-G<W1R("+,[O_R(,K@Z^7MY.#P(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S
M='(@(L3H\>_KY>D@SN_VZ.@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S`*;7-G:60@(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E
M(&1U92!O;B!Y;W5R(&-A;&5N9&%R/R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU,S<*;7-G:60@(D1O97,@;F]T(')E8W5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$=64Z("5S(@IM<V=S='(@(L?@Y/KKYN7MZ.4Z("5S(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3$U"FUS9VED(")$=7)A
M=&EO;B(*;7-G<W1R("+/\.[D^NOFZ/+EZ^WN\?(B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<P(&QI8B]$<FEV97(N<&AP.C$X
M,#8*;7-G:60@(D5D:70B"FUS9W-T<B`BT.7DX.KVZ/\B"@HC.B!E9&ET979E
M;G0N<&AP.C,S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V(&QI8B]$<FEV
M97(N<&AP.C$X,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="`E<R(*;7-G
M<W1R("+0Y>3@ZO;H_R#MX"`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C$X-PIM<V=I9"`B161I="!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$T,`HC+"!F=7IZ
M>0IM<V=I9"`B161I="!#86QE;F1A<G,B"FUS9W-T<B`BT.7DX.KVZ/\@[>`@
M[O+DX.OE]^7MZ"`H[>7K[NK@Z^WH*2#JX.OE[>3@\.@N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(U,`IM<V=I9"`B161I="!296UO=&4@0V%L96YD
M87)S(@IM<V=S='(@(M#EY.#J]NC_(.W@(.[RY.#KY??E[>@@*.WEZ^[JX.OM
MZ"D@ZN#KY>WDX/#H+B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,34P"FUS9VED(")%
M9&ET(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%T96=O
M<GE?;&5G96YD+FEN8SHR,`IM<V=I9"`B161I="!C871E9V]R:65S(&%N9"!C
M;VQO<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ-S8@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC
M.C0Q"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-`IM<V=I9"`B16UA
M:6P@061D<F5S<R(*;7-G<W1R("+%;6%I;"#@Y/#E\2(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8P"B,L(&9U>GIY"FUS9VED(")%
M;E]D(@IM<V=S='(@(LKPX.D@[>`B"@HC.B!D871A+G!H<#HU-PIM<V=I9"`B
M16YD($1A=&4B"FUS9W-T<B`BRO#@Z>W@(.3@\N`B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C@@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#@*;7-G
M:60@(D5N9"!/;B(*;7-G<W1R("+*\.#I(.W@(@H*(SH@9&%T82YP:'`Z-3@*
M;7-G:60@(D5N9"!4:6UE(@IM<V=S='(@(LKPX.7M(/?@\2(*"B,Z(&%T=&5N
M9&5E<RYP:'`Z,3(T(&%T=&5N9&5E<RYP:'`Z,3,U(&%T=&5N9&5E<RYP:'`Z
M,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E=')I979I;F<@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y,PIM<V=I9"`B179E;G0@861D960Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,#,*;7-G:60@(D5V
M96YT(&1E;&5T960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$P.3@*;7-G:60@(D5V96YT(&5D:71E9#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3`V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%=F5N="!F
M<F]M("5S('1O("5S(@IM<V=S='(@(M'ZX>CRZ.4@[O(@)7,@Y.X@)7,B"@HC
M.B!L:6(O1')I=F5R+G!H<#HW-C0*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@
M82!S=&%R="!D871E+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HW
M,S`*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@82!T:71L92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S8W"FUS9VED(")%=F5N=',@;75S="!H
M879E(&%N(&5N9"!D871E(&]R(&$@9'5R871I;VXN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHW.0HC+"!F=7IZ
M>0IM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(LKPX.7M(/?@\2(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@W"B,L(&9U>GIY"FUS9VED
M(")%>'!O<G0B"FUS9W-T<B`BR.SO[O#R+\7J\>_N\/(B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R="!#86QE;F1A<B(*
M;7-G<W1R("+%ZO'O[O#R(.W@(,K@Z^7MY.#P(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-CD*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(X"FUS
M9VED(")&:6YD(@IM<V=S='(@(M+Z\/'H(@H*(SH@>65A<BYP:'`Z.#<@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C,@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C(R"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED
M(")&<B(*;7-G<W1R("+/ZB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.`HC+"!F=7IZ>0IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S
M='(@(LCM].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C(P('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q.0HC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,@IM<V=I9"`B1G)I9&%Y(@IM
M<V=S='(@(L_E\OKJ(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC
M.C,P"FUS9VED(")&=71U<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O
M<F1S+G!H<"YD:7-T.C$W"FUS9VED(")'86UE(@IM<V=S='(@(LCC\.`B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,C,*;7-G
M:60@(D=E;F5R86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$T,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1V]T;R`E<R(*
M;7-G<W1R("+(Y.@@[>`B"@HC.B!M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W
M965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y
M+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`IM<V=I9"`B2&ED92(*;7-G<W1R
M("(B"@HC.B!M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W965K+VAE861?<VED
M95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&ED
M92`E<R(*;7-G<W1R("+(Y^/KY>0@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHV-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S@*;7-G:60@
M(DAO=7(H<RDB"FUS9W-T<B`BU^#Q*.`I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PHC+"!F=7IZ>0IM<V=I9"`B2&]W(&QO;F<@<VAO=6QD('1H
M92!T:6UE('-L;W1S(&]N('1H92!D87D@86YD('=E96L@=FEE=W,@8F4_(@IM
M<V=S='(@(B(*(L3@(/'E(._NZN#GXN#R(.OH(._NZ^[BZ.TM]^#Q[N+H(.CM
M\N7PXN#KZ"#B(.3MY>+MZ/_R(.@@\>7D[.CW[>C_\B#HY^/KY>0_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`HC+"!F=7IZ>0IM<V=I9"`B2&]W
M(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M871I;VX@<VAO=6QD('=E
M(&=E;F5R871E/R(*;7-G<W1R("+*[NOJ[B#D[>@@[>#O\.7D(/+P_^'BX"#D
MX"#QY2#CY>WE\.CPX"#QXN[A[N3E[2_GX.7R(.CM].[P[.#VZ/_RX#\B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#,P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(DEF('EO=7(@96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP
M(')E<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T:&4@(@HB9F]L;&]W:6YG
M(&QI;FMS('1O(&%C8V5P="!O<B!D96-L:6YE('1H92!E=F5N="Y<;B(*(EQN
M(@HB5&\@86-C97!T('1H92!E=F5N=#I<;B(*(B5S7&XB"B)<;B(*(E1O(&%C
M8V5P="!T:&4@979E;G0@=&5N=&%T:79E;'DZ7&XB"B(E<UQN(@HB7&XB"B)4
M;R!D96-L:6YE('1H92!E=F5N=#I<;B(*(B5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T($-A;&5N9&%R+"!3=&5P("5D(@IM<V=S='(@(LCL
M[^[P\B#MX"#*X.OE[>3@\"(*"B,Z(&1A=&$N<&AP.C,R,`IM<V=I9"`B26UP
M;W)T+T5X<&]R="!#86QE;F1A<B(*;7-G<W1R("+([._N\/(OQ>KQ[^[P\B#*
MX.OE[>3@\"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8X
M"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C<T"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<S"FUS9VED(")*=6YE
M(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C8U('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$T,@IM<V=I9"`B2V5Y=V]R9',B"FUS9W-T<B`BRNO^]^[BZ"#D
M\^SH(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4U"FUS9VED
M("),87-T(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C@W"B,L(&9U>GIY"FUS9VED("),87-T($UO9&EF:65D(@IM
M<V=S='(@(L_PY>3H^.7M(.SE\>7V(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M861?<VED95]B>5]S:61E+FEN8SHT"B,Z('1E;7!L871E<R]M;VYT:"]H96%D
M7W-I9&5?8GE?<VED92YI;F,Z,3`*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?
M<VED95]B>5]S:61E+FEN8SHQ-B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M-`IM<V=I9"`B3&%S="!-;VYT:"(*;7-G<W1R("+/\.7DZ/CE[2#LY?'E]B(*
M"B,Z('1E;7!L871E<R]Y96%R+VAE860N:6YC.C0*(RP@9G5Z>GD*;7-G:60@
M(DQA<W0@665A<B(*;7-G<W1R("+/\.7DZ/CMX"#QY>3LZ/;@(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4T('1E;7!L871E<R]W965K+VAE
M860N:6YC.C,*;7-G:60@(DQA<W0@=V5E:R(*;7-G<W1R("+/\.7DZ/CMX"#Q
MY>3LZ/;@(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-PIM<V=I
M9"`B3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z(@IM<V=S='(@(L[C
M\.#MZ/?H(._P[N3ZZ^;H\N7K[>[Q\O+@(.?@(.7J\>_N\/(Z(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@V('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C<V"B,L(&9U>GIY"FUS9VED("),;U]C871I;VXB
M"FUS9W-T<B`BS/_Q\NXB"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O<V5A
M<F-H+V5V96YT7VAE861E<G,N:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E
M;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S
M+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,C$*(SH@;&EB+T1R:79E<BYP:'`Z,3@T.0IM<V=I9"`B3&]C
M871I;VXB"FUS9W-T<B`BS/_Q\NXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#4*;7-G:60@(DUA;F%G92!R96UO=&4@8V%L96YD87)S+B(*;7-G<W1R
M("+3[_#@XNO_XN#MY2#MX"#MY>ONZN#K[>CRY2#JX.OE[>3@\.@N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S`*;7-G:60@(DUA<F-H
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$P,`IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@179E;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C<R"B,L(&9U>GIY"FUS9VED(")-87DB"FUS
M9W-T<B`BY.7M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@T-@IM<V=I9"`B364B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS
M9VED(")-965T:6YG(@IM<V=S='(@(M'PY?G@(@H*(SH@;&EB+T)L;V-K+W1R
M965?86QA<FUS+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-96YU($%L87)M<R(*
M;7-G<W1R("+`Z^#P[.`B"@HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HS
M"FUS9VED(")-96YU($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z-C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,W"FUS
M9VED(")-:6YU=&4H<RDB"FUS9W-T<B`BS.CM\_+@*.@I(@H*(SH@;&EB+T)L
M;V-K+W!R979M;VYT:&QI<W0N<&AP.C0R"FUS9VED(")-:7-S960@179E;G1S
M($QI<W0B"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#,@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C$X"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")-;R(*;7-G
M<W1R("+/[2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,34*(SH@=&5M<&QA=&5S+V5D:70O:F%V
M87-C<FEP="YI;F,Z-C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@IM<V=I
M9"`B36]N9&%Y(@IM<V=S='(@(L_N[>7DY>OMZ.HB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,CDQ(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(T(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-0IM<V=I9"`B36]N=&@B"FUS9W-T<B`BS.7Q
MY?8B"@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C,*(RP@9G5Z>GD*;7-G:60@
M(DUO;G1H(%9I97<B"FUS9W-T<B`BS.7QY?8B"@HC.B!L:6(O0FQO8VLO;6]N
M=&AL:7-T+G!H<#HS(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0S"FUS9VED
M(")-;VYT:&QY($5V96YT<R!,:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C8*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(Y('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(S-0IM<V=I9"`B36]N=&AL>3H@4F5C=7)S(&5V97)Y
M(@IM<V=S='(@(LSE\>7W[>XZ(._NXO+@\/\@\>4@XO'EZN@B"@HC.B!L:6(O
M0FQO8VLO;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS($%H96%D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-`HC
M+"!F=7IZ>0IM<V=I9"`B36]N=&AS($)E9F]R92(*;7-G<W1R("(E<R#,Z.WS
M\N@@[_#EY.@B"@HC.B!L:6(O87!I+G!H<#HV,3(*;7-G:60@(DUU;'1I<&QE
M(&E#86QE;F1A<B!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!V179E;G0@
M:7,@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C$R
M."!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-C<*(RP@9G5Z
M>GD*;7-G:60@(DUY($-A;&5N9&%R<R(*;7-G<W1R("+,[O_R(,K@Z^7MY.#P
M(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M96YU+FEN
M8SHS-@HC+"!F=7IZ>0IM<V=I9"`B37D@0V%L96YD87)S.B(*;7-G<W1R("+,
M[O_R(,K@Z^7MY.#P(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C(P-`IM<V=I9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3$W('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3D*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S4*(SH@=&5M<&QA=&5S+W!R
M969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,3<*(SH@=&5M<&QA=&5S
M+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-#0*;7-G:60@(DYA
M;64B"FUS9W-T<B`BR.SE(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HT,2!L
M:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT-"!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z-#$*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C`*;7-G:60@(DYE
M=R!%=F5N="(*;7-G<W1R("+-[N+N(/'ZX>CRZ.4B"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C,T"B,L(&9U>GIY"FUS9VED(").97AT(@IM<V=S
M='(@(M'KY>3BX/D@Y.7M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&0E9I97<O9&%Y+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3F5X="!$87DB
M"FUS9W-T<B`BT>OEY.+@^2#DY>TB"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A
M9%]S:61E7V)Y7W-I9&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?
M<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$X('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHV
M"FUS9VED(").97AT($UO;G1H(@IM<V=S='(@(M'KY>3BX/D@[.7QY?8B"@HC
M.B!L:6(O1D)6:65W+W=E96LN<&AP.C,R"B,L(&9U>GIY"FUS9VED(").97AT
M(%=E96LB"FUS9W-T<B`BT>OEY.+@^>`@\>7D[.CVX"(*"B,Z('1E;7!L871E
M<R]Y96%R+VAE860N:6YC.C8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@665A<B(*
M;7-G<W1R("+1Z^7DXN#Y(.3E[2(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI
M;F,Z-0IM<V=I9"`B3F5X="!D87DB"FUS9W-T<B`BT>OEY.+@^2#DY>TB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3@@=&5M<&QA=&5S+W=E
M96LO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!W965K(@IM<V=S='(@(M'KY>3B
MX/G@(/'EY.SH]N`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<U"B,L
M(&9U>GIY"FUS9VED(").;R(*;7-G<W1R("+-_^S@(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3(V
M"B,L(&9U>GIY"FUS9VED(").;R!A;&%R;2(*;7-G<W1R("+`Z^#P[.`B"@HC
M.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#@*(RP@9G5Z
M>GD*;7-G:60@(DYO(&%T=&5N9&5E<R(*;7-G<W1R("+-_^S@(.KPX.GMX"#D
MX/+@(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,0IM<V=I9"`B3F\@8V%L
M96YD87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R("+-_^S@
M(.K@Z^7MY.#PZ"#D[O'R^N_MZ"#GX"#C[O'RZ"XB"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C4U
M"FUS9VED(").;R!E;F0@9&%T92(*;7-G<W1R("+-_^S@(.KPX.GMX"#DX/+@
M(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$V-"!L:6(O0FQO
M8VLO;6]N=&AL:7-T+G!H<#HQ-C,*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$Y-`IM<V=I9"`B3F\@979E;G1S('1O(&1I<W!L87DB"FUS9W-T<B`B(@H*
M(SH@;&EB+U-T;W)A9V4O:V]L86(N<&AP.C0S"B,L('!H<"UF;W)M870*;7-G
M:60@(DYO(&9R964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,T-"!L:6(O87!I+G!H
M<#HV,#(*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`T"B,L(&9U
M>GIY"FUS9VED(").;R!R96-U<G)E;F-E(@IM<V=S='(@(L_NXO+N\/_E[.@@
MY.#M[>@B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HX.#8*;7-G:60@(DYO('9A
M;&ED(&5M86EL(&%D9')E<W,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z-C`Q(&QI8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B
M3F]N92(*;7-G<W1R("+-_^S@(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ
M,S8*;7-G:60@(DYO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3$*(RP@9G5Z>GD*;7-G:60@(DYO=&EF:6-A=&EO;G,B
M"FUS9W-T<B`BS/_Q\NXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHW.`IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C4V"FUS9VED(").;W<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S<*;7-G:60@
M(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T
M:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-S@*;7-G:60@(D]N(&%L;"!C86QE;F1A<G,@22!H879E(')E
M860@86-C97-S('1O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-S<*(RP@9G5Z>GD*;7-G:60@(D]N(&%L;"!S:&]W;B!C86QE;F1A
M<G,B"FUS9W-T<B`BT^_PX.+K_^+@[>4@[>`@[>7K[NK@Z^WH\N4@ZN#KY>WD
MX/#H+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S8*(RP@9G5Z>GD*
M;7-G:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY(@IM<V=S='(@(M#EY.#J\NCP
MX.D@ZN#KY>WDX/#H\N4@\>@N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C$Y
M"B,L(&9U>GIY"FUS9VED(")/<'1I;VYA;"(*;7-G<W1R("+.[_;HZ"(*"B,Z
M(&QI8B]&0E9I97<N<&AP.C$Q.`IM<V=I9"`B3W!T:6]N86P@071T96YD965S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&0E9I97<N<&AP.C$U,@IM<V=I9"`B3W9E
M<G9I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,S0*;7-G:60@(D]W;F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$X-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]W;F5R.B`E<R(*
M;7-G<W1R("+'X.3ZZ^;E[>CE.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,3`R('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@R"FUS
M9VED(")032(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR.2!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")086QM($1A=&5"
M;V]K(@IM<V=S='(@(L3@\N`@Y^`@X.O@\.S@(@H*(SH@;&EB+T)L;V-K+W!R
M979M;VYT:&QI<W0N<&AP.C,*;7-G:60@(E!A<W0@179E;G1S($QI<W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`Y('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C$Y.`IM<V=I9"`B4&%T=&5R;B(*;7-G<W1R
M("+/[N+R[O#_Y>SN\?(B"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z
M,C<*;7-G:60@(E!E<FUA;F5N=&QY(&1E;&5T92!T:&ES(&5V96YT/R(*;7-G
M<W1R("+$X"#QY2#GX.OH]^@@Z^@@\N[BX"#Q^N'H\NCE/R(*"B,Z(&QI8B]A
M<&DN<&AP.C,R-2!L:6(O87!I+G!H<#HT,3D@;&EB+V%P:2YP:'`Z-#@Q(&QI
M8B]A<&DN<&AP.C4U,PHC.B!L:6(O87!I+G!H<#HU.#0@;&EB+V%P:2YP:'`Z
M-C<P(&QI8B]A<&DN<&AP.C<P-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$V-PIM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q"B,L(&9U>GIY"FUS9VED(")0;W)T86P@
M3W!T:6]N<R(*;7-G<W1R("+/[O+PY>'H\N7K\>KH(.[O]NCH(@H*(SH@;&EB
M+T9"5FEE=R]D87DN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!$
M87DB"FUS9W-T<B`BS_#EY.CXY>T@Y.7M(@H*(SH@;&EB+T9"5FEE=R]W965K
M+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@5V5E:R(*;7-G<W1R
M("+/\.7DZ/CE[2#DY>TB"@HC.B!T96UP;&%T97,O9&%Y+VAE860N:6YC.C,*
M;7-G:60@(E!R979I;W5S(&1A>2(*;7-G<W1R("+/\.7DZ/CE[2#DY>TB"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S4@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C4R"FUS9VED(")296-U<B!5;G1I;"(*;7-G<W1R("+/[N+R
MX/#_Z2#D[NK@\NXB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,#8*
M(RP@9G5Z>GD*;7-G:60@(E)E8W5R<F5N8V4B"FUS9W-T<B`BS^[B\N[P_^7L
MZ"#DX.WMZ"(*"B,Z(&1A=&$N<&AP.C8Y"FUS9VED(")296-U<G)E;F-E($1A
M=&$B"FUS9W-T<B`BS^[B\N[P_^7LZ"#DX.WMZ"(*"B,Z(&1A=&$N<&AP.C8W
M"FUS9VED(")296-U<G)E;F-E($5N9"!$871E(@IM<V=S='(@(LKPX.GMX"#D
MX/+@(.?@(._NXO+N\/_E[.[Q\O+@(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@
M(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`BS^[B\N[P_^7L[O'R(.CM
M\N7PXN#K(@H*(SH@9&%T82YP:'`Z-C8*;7-G:60@(E)E8W5R<F5N8V4@5'EP
M92(*;7-G<W1R("+2Z.\@[>`@[^[B\N[P_^7L[O'R\N`B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU-#`*;7-G:60@(E)E8W5R<R!D86EL>2(*;7-G<W1R("+/
M[N+RX/#_Z2#B\>7JZ"#DY>TB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#<*
M;7-G:60@(E)E8W5R<R!M;VYT:&QY(@IM<V=S='(@(L_NXO+@\/_I(.SE\>7W
M[>XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#,*;7-G:60@(E)E8W5R<R!W
M965K;'DB"FUS9W-T<B`BS^[B\N#P_^D@\>7D[.CW[>XB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU-3`*;7-G:60@(E)E8W5R<R!Y96%R;'DB"FUS9W-T<B`B
MS^[B\N#P_^D@X^[DZ/CM[B(*"B,Z(&QI8B]38VAE9'5L97(O:W)O;F]L:71H
M+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M:6YD97(Z("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHY,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0*;7-G:60@(E)E;6]T92!#
M86QE;F1A<G,B"FUS9W-T<B`BS>7K[NK@Z^WH(,K@Z^7MY.#PZ"(*"B,Z('1E
M;7!L871E<R]M96YU+FEN8SHV,"!T96UP;&%T97,O;65N=2YI;F,Z-C(*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]T92!#86QE;F1A<G,Z(@IM<V=S='(@(LWEZ^[J
MX.OMZ"#*X.OE[>3@\.@B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E("5S(@IM
M<V=S='(@(B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`T"FUS9VED(")296UO=F4@
M071T96YD964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHS,@IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W
M:71H('1H92!I;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B
M"B)D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A
M<BX\+W-T<F]N9SXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-C(V"FUS9VED(")297%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O1D)6:65W
M+G!H<#HY."!L:6(O1D)6:65W+G!H<#HQ,S<@;&EB+T9"5FEE=RYP:'`Z,30P
M(&QI8B]&0E9I97<N<&AP.C$T,PIM<V=I9"`B4F5Q=6ER960@071T96YD965S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,T('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C,Q,`IM<V=I9"`B4F5S970@=&\@1&5F
M875L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E
M;F1E97,N:6YC.C0S('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-@IM<V=I
M9"`B4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#@@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C0@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C(S"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")3
M82(*;7-G<W1R("+1X2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR
M,2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V5D
M:70O:F%V87-C<FEP="YI;F,Z-S,*;7-G:60@(E-A='5R9&%Y(@IM<V=S='(@
M(M'ZX>[RX"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`BT>$B"@HC.B!V
M:65W979E;G0N<&AP.C$Q."!E9&ET979E;G0N<&AP.C0X(&5D:71E=F5N="YP
M:'`Z-38*;7-G:60@(E-A=F4@07,@3F5W(@IM<V=S='(@(L?@[^CXZ"#JX/+N
M(.WNXNXB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z
M.#<*;7-G:60@(E-A=F4@071T96YD965S(@IM<V=S='(@(B(*"B,Z(&%D9&5V
M96YT+G!H<#HU-2!E9&ET979E;G0N<&AP.C4Q"FUS9VED(")3879E($5V96YT
M(@IM<V=S='(@(L?@[^CXZ"#Q^N'H\NCE(@H*(SH@<V5A<F-H+G!H<#HY,2!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$U"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHV-R!T96UP;&%T97,O8V%L96YD
M87)S+W-E87)C:"YI;F,Z.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$T,"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-@IM<V=I9"`B
M4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A
M<F-H+FEN8SHQ"B,L(&9U>GIY"FUS9VED(")396%R8V@@0V%L96YD87)S(@IM
M<V=S='(@(LK@Z^7MY.#PZ"(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHV"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z-@IM<V=I9"`B4V5A<F-H
M(&9O<B!C86QE;F1A<G,@8V]N=&%I;FEN9SHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U,`HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@8V%L96YD87(@=&\@961I="(*;7-G<W1R("+(Y^'E
M\.@@ZN#KY>WDX/`B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-C@@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,S$*(SH@=&5M<&QA
M=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.#,*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BR.?AY?#H(.K@Z^7MY.#P(@H*(SH@
M=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M8V%L96YD87)S('1O(&1I<W!L87DZ(@IM<V=S='(@(LCGX>7PY?+E(.K@Z^7M
MY.#P(.?@(.CL[^[P\CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*
M;7-G:60@(B(*(E-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O
M(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E("(*(F1E
M9F%U;'0@=FEE=RXB"FUS9W-T<B`B(@HBR.?AY?#E\N4@[N_VZ.CRY2#GX"#O
M[O+B^O#FY.7MZ.4L(.K@ZB#DX"#QY2#O[NK@Y^+@\B#PX.?KZ/?MZ/+E(.CG
MX^OEY.@@Z"`B"B+HY^/KY>3@(._N(._NY/#@Y^'H\.#MY2XB"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Y"FUS9VED(")396QE8W0@=&AE(&-A
M;&5N9&%R('1O(&EM<&]R="!T;SHB"FUS9W-T<B`BR.?AY?#E\N4@ZN#KY>WD
MX/`@Y^`@Z.SO[O#R.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB
M"FUS9W-T<B`BR.?AY?#E\N4@Z.?R[O?MZ.K@(.?@(.CL[^[P\CHB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(X"FUS9VED(")396QE8W0@=&AE
M(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R("+(Y^'E\.7RY2#TX.GK(.?@(.CL
M[^[P\CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED(")3
M96QE8W0@=&AE(&9I<G-T('=E96MD87DZ(@IM<V=S='(@(LCGX>7PY?+E(.KN
MZ2#DX"#E(._Z\.+H__(@Y.7M(.W@(/'EY.SH]N#RX#HB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(LCGX>7P
MY?+E(/3N\.S@\BP@ZOKL(.KNZ?+N(.3@(/'E(.7J\>_N\/+H\.`Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T
M:6UE('-P86X@=&\@<VAO=SHB"FUS9W-T<B`BR.?AY?#E\N4@[_#NY/KKYNCR
MY>OM[O'R\N`L(.KN__+N(.3@(/'E(._NZN#GXN`Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('9I
M97<@=&\@9&ES<&QA>2!O;B!S=&%R='5P.B(*;7-G<W1R("+(Y^'E\.7RY2#H
MY^/KY>3@+"#J[NGR[B#DX"#QY2#BZ.;DX"#QZ^7D(.+U[N0Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M=VAI8V@@979E;G1S('1O('-H;W<@:6X@=&AE('!O<G1A;"XB"FUS9W-T<B`B
MR.?AY?#E\N4@\?KAZ/+H__+@+"#J[NCR[B#DX"#A^N3@\B#O[NK@Y^#MZ"#B
M(.[A[N'YY>WHY?+N(.W@($AO<F1E+B(*"B,Z('1E;7!L871E<R]D96QE=&4O
M;VYE+FEN8SHR-"!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C0*;7-G
M:60@(E-E;F0@82!C86YC96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E;F1E
M97,@=VAE;B!D96QE=&EN9R!T:&ES(&5V96YT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")396YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$X,0IM<V=I9"`B4V5N9"!U<&1A=&5S+VEN=FET
M871I;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHW-@IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS9VED(")3
M970@96YD(&1A=&4B"FUS9W-T<B`BS?_LX"#J\.#I[>`@Y.#RX"(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(V.`HC+"!F=7IZ>0IM<V=I9"`B4V5T
M(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`BRO#@Z>W@(.3@\N`@Y^`@
M[^[B\N[P_^7L[O'R\N`B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B4V5T('-T87)T(&1A=&4B"FUS
M9W-T<B`BS>#WX.OMX"#DX/+@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4Y"FUS9VED("(B"B)3970@>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S(&%N
M9"!Y;W5R(&]W;B!A;F0@;W1H97(@=7-E<G,G(&9R964O8G5S>2!O<'1I;VYS
M+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C<W"B,L('!H<"UF;W)M
M870*;7-G:60@(E-H87)E(&YO="!F;W5N9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C<Y"B,L(&9U>GIY
M"FUS9VED(")3:&%R960@0V%L96YD87)S(@IM<V=S='(@(LK@Z^7MY.#PZ"(*
M"B,Z('1E;7!L871E<R]M96YU+FEN8SHT-R!T96UP;&%T97,O;65N=2YI;F,Z
M-#D*(RP@9G5Z>GD*;7-G:60@(E-H87)E9"!#86QE;F1A<G,Z(@IM<V=S='(@
M(LK@Z^7MY.#PZ"(*"B,Z(&-A;&5N9&%R7W-E87)C:"YP:'`Z,C4@=&5M<&QA
M=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*(SH@=&5M<&QA=&5S
M+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B
M4VAO=R!#86QE;F1A<B(*;7-G<W1R("+*X.OE[>3@\"(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHR,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4VAO=R!C86QE;F1A<B!<(B5S7"(B"FUS9W-T<B`BPN#XZ/+E
M(.K@Z^7MY.#PZ#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34V"FUS
M9VED(")3:&]W(&-A=&5G;W)Y(&QE9V5N9#\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B4VAO=R!D96QE=&4L(&%L
M87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I;B!C86QE;F1A<B!V:65W<S\B
M"FUS9W-T<B`BS^[JX.;H(.CG\O#HZ2P@X.O@\.S@(.@@[^[B\N[P_^7L[O'R
M(.CJ[NWH(.(@Z.?CZ^7DZ/+E(.W@(.K@Z^7MY.#PZ/+E/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(E-H;W<@9'5E('1A<VMS(&EN
M('1H92!C86QE;F1A<C\B"FUS9W-T<B`BQ.`@\>4@[^[JX.?BX/(@Z^@@Y^#D
MX/?H(.(@ZN#KY>WDX/#@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C8*;7-G:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N9#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,PIM<V=I9"`B4VAO=R!O;FQY
M(&5V96YT<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/R(*;7-G<W1R("+$X"#Q
MY2#O[NK@Y^+@\B#KZ"#QX.SN(/'ZX>CRZ/_RX"P@ZN[H\NX@Z.S@\B#MX/'R
M\.[E[>`@X.O@\.S@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S4*
M;7-G:60@(E-H;W<@<VAA<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@=&%S:W,@=7-I;F<@8V%T96=O<GD@8V]L;W)S/R(*
M;7-G<W1R("+$X"#QY2#O[NK@Y^+@\B#KZ"#GX.3@]^@@XB#JX.OE[>3@\.`_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU"B,L(&9U>GIY"FUS9VED
M(")3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C:"!D87D@:6X@=V5E:R!V
M:65W<S\B"FUS9W-T<B`B(@HBQ.`@\>4@[^[JX.?BX/(@Z^@@[^[K[N+H[2WW
MX/'NXN@@Z.WRY?#BX.OH(.(@Y.WEXNWH__(@Z"#QY>3LZ/?MZ/_R(.CGX^OE
MY#\B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,0HC
M+"!F=7IZ>0IM<V=I9"`B4W1A7W)T(@IM<V=S='(@(L?@[^[WXN`@[>`B"@HC
M.B!D871A+G!H<#HU-0IM<V=I9"`B4W1A<G0@1&%T92(*;7-G<W1R("+-X/?@
MZ^W@(.3@\N`B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N
M:6YC.C<@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#$*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHR-0IM<V=I9"`B4W1A<G0@3VXB"FUS9W-T<B`B
MQ^#O[O?BX"#MX"(*"B,Z(&1A=&$N<&AP.C4V"FUS9VED(")3=&%R="!4:6UE
M(@IM<V=S='(@(LW@]^#KY>T@]^#Q(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.CDU('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C@U"FUS9VED(")3=&%T7W5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHR-PIM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP
M.C@Q('EE87(N<&AP.CDP('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C8U"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-"!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$P-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P.0IM<V=I9"`B
M4W4B"FUS9W-T<B`BS>0B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M,30@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(S"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R,2!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN
M8SHV-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")3=6YD
M87DB"FUS9W-T<B`BS>7DY>O_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Y"FUS9VED(")487-K<R(*;7-G<W1R("+'X.3@]^@B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU-S0@;&EB+TMR;VYO;&ET:"YP:'`Z-3DW"FUS9VED(")4
M96YT871I=F4B"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#8@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")4:"(*
M;7-G<W1R("+7\B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z-S`*;7-G:60@(E1H92!%9&ET($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@
M;&]N9V5R('!R97-E;G0N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!C86YN;W0@8F4@9&5L971E9"XB"FUS9W-T<B`BRN#KY>WDX/#Z
M\B!<(B5S7"(@[>4@[.[FY2#DX"#A^N3E(.CG\O#H\BXB"@HC.B!C86QE;F1A
M<G,N<&AP.C0P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L
M96YD87(@7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(LK@Z^7M
MY.#P^O(@7"(E<UPB(.'E^.4@Z.?R\.CR+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z
M.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+*X.OE[>3@\/KR(%PB)7-<(B#A
MY?CE(.CG\O#H\BXB"@HC.B!C86QE;F1A<G,N<&AP.C4T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N
M(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("+*X.OE[>3@\/KR(%PB)7-<
M(B#AY?CE(.?@[^CQX.TN(@H*(SH@8V%L96YD87)S+G!H<#HU-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N('-A
M=F5D+B(*;7-G<W1R("+*X.OE[>3@\/KR(%PB)7-<(B#AY?CE(.?@[^CQX.TN
M(@H*(SH@9&%T82YP:'`Z,C(V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@8V%L96YD87(@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T
M<B`BRN#KY>WDX/#Z\B!<(B5S7"(@[>4@[.[FY2#DX"#A^N3E(.CG\O#H\BXB
M"@HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@
M(E1H92!E;F0@9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A
M=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!A
M9&1E9"P@=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$Q,#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@9&5L971E9"P@=VAI8V@@
M=V%S(&]N("5S(&%T("5S+B(*;7-G<W1R("+*X.OE[>3@\/KR(%PB)7-<(B#A
MY?CE(.CG\O#H\BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@961I
M=&5D+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3`V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@<W5C8V5S<V9U
M;&QY('-E;G0N(@IM<V=S='(@(L+@^.#RX"#O[NK@[>`@X>7XY2#HY^_PX/+E
M[>`@\_'OY?CM[BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(T"FUS9VED
M(")4:&4@9F]L;&]W:6YG(&ES(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO
M;B!O9B!T:&4@979E;G0Z(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z-#$*
M;7-G:60@(B(*(E1H92!R97%U97-T('=A<R!I;F-O;7!L971E+B!3;VUE('!A
M<F%M971E<G,@=&AA="!A<F4@;F5C97-S87)Y('1O(&%C8V5P="!O<B`B"B)D
M96-L:6YE(&%N(&5V96YT(&%R92!M:7-S:6YG+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V5M<'1Y+FEN8SHS"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!A<F4@;F\@979E;G1S(&UA=&-H:6YG('1H92!C=7)R96YT(&-R:71E
M<FEA+B(*;7-G<W1R("+-_^S@(/'ZX>CRZ/\@Y^`@Y>KQ[^[P\BXB"@HC.B!A
M9&1E=F5N=&%C=&EO;BYP:'`Z,3@@961I=&5V96YT86-T:6]N+G!H<#HS-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S(@IM<V=S='(@(L/PY?CJX"#O
M\.@@Z.SO[O#RZ/#@[>4@[>`@:4-A;&5N9&%T(.3@[>WH+B(*"B,Z(&%D9&5V
M96YT86-T:6]N+G!H<#HS-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@979E;G0Z("5S(@IM<V=S
M='(@(L/PY?CJX"#O\.@@Z.SO[O#R(.W@(.CG[_#@\N7MZ/\@].#IZSH@)7,N
M(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I;F<@=&AE(&5V
M96YT.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ/+E
M+B(*"B,Z(&QI8B]A<&DN<&AP.C,S."!L:6(O87!I+G!H<#HU.38*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D
M871A+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\NCPX.WE(.W@(&E#86QE
M;F1A="#DX.WMZ"XB"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C8S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@;6]V
M:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#H[._N\/(@
M[>`@Y.#M[>CRY2XB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#<R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V5N
M9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Z.?O\.#YX.WE(.W@(._NZN#MX/+@.B`E<R(*"B,Z(&1A
M=&$N<&AP.C$P-0IM<V=I9"`B5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@97AP
M;W)T+B(*;7-G<W1R("+-_^S@(/'ZX>CRZ/\@Y^`@Y>KQ[^[P\BXB"@HC.B!D
M871A+G!H<#HQ.#0*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ.2!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3@*(SH@=&5M<&QA=&5S+V5D:70O
M:F%V87-C<FEP="YI;F,Z-S$*;7-G:60@(E1H=7)S9&%Y(@IM<V=S='(@(M?E
M\N+Z\/+ZZB(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS-PHC
M+"!F=7IZ>0IM<V=I9"`B5&EM92!3<%]A;B(*;7-G<W1R("+7X/'NXN`@Y^[M
MX"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C0*(RP@
M9G5Z>GD*;7-G:60@(E1I;64@<W!A;B(*;7-G<W1R("+7X/'NXN`@Y^[MX"(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHS-B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B5&ET
M7VQE(@IM<V=S='(@(L3K^N;M[O'R(@H*(SH@9&%T82YP:'`Z-30@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"B,Z('1E;7!L871E<R]S96%R8V@O
M979E;G1?:&5A9&5R<RYI;F,Z,PIM<V=I9"`B5&ET;&4B"FUS9W-T<B`BQ.OZ
MYNWN\?(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(R(&QI
M8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$R,0HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,3(W"FUS9VED(")4;V1A>2(*;7-G<W1R("+$[>7Q(@H*(SH@;&EB
M+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R-"!L:6(O0FQO8VLO;6]N=&AL
M:7-T+G!H<#HQ,C,*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R.0IM<V=I
M9"`B5&]M;W)R;W<B"FUS9W-T<B`BT_+PY2(*"B,Z('EE87(N<&AP.C@T('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8P('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I
M9"`B5'4B"FUS9W-T<B`BPO(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI
M;F,Z,3<@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$V"B,Z('1E;7!L871E
M<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8Y"FUS9VED(")4=65S9&%Y(@IM<V=S
M='(@(L+R[O#MZ.HB"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*
M;7-G:60@(E1Y<&4B"FUS9W-T<B`BTNCO(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C$X,PIM<V=I9"`B55),(@IM<V=S='(@(E52
M3"(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@(E5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE
M(%PB)7-<(CH@)7,N(@H*(SH@;&EB+T1R:79E<B]M8V%L+G!H<#HQ,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RXB"FUS9W-T
M<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@)7,N(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z,3@U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+#\.7XZN`@[_#H(.?@
M\.7FY.#MY2#MX"#DY?3H[>CVZ/_RX"#MX"`E<RXB"@HC.B!C86QE;F1A<G,N
M<&AP.C4Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%PB)7-<(CH@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@
M[>4@7"(E<UPB.B`E<RXB"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z,S0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R971R:65V
M92!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S(@IM<V=S='(@(LKNZ^KN
M(.3MZ"#MX._PY>0@\O#_X>+@(.3@(/'E(./E[>7PZ/#@(/'B[N'NY.7M+^?@
MY?(@Z.WT[O#LX/;H__+@/R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$U"B,Z('-C<FEP=',O=7!G<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T7V-A
M=&5G;W)I97-?=&]?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`BS>7O[N_ZZ^WE[2(*"B,Z(&QI8B]A<&DN<&AP.C,W-B!L:6(O87!I
M+G!H<#HT-3`@;&EB+V%P:2YP:'`Z-3$V(&QI8B]A<&DN<&AP.C8R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B57-E<B!);G1E<F9A8V4B
M"FUS9W-T<B`BS^[R\.7AZ/+EZ_'JZ"#H[?+E\/3EZ?$B"@HC.B!Y96%R+G!H
M<#HQ-C,@>65A<BYP:'`Z,38Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,38R"B,L(&9U>GIY"FUS9VED(")6:65W($1A
M>2(*;7-G<W1R("+(Y^/KY>0@)7,B"@HC.B!Y96%R+G!H<#HX-2!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,2!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,C`*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E=E
M(@IM<V=S='(@(M'P(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$X
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-PHC.B!T96UP;&%T97,O961I
M="]J879A<V-R:7!T+FEN8SHW,`IM<V=I9"`B5V5D;F5S9&%Y(@IM<V=S='(@
M(M'P_^3@(@H*(SH@871T96YD965S+G!H<#HQ,3(@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3(Y,"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,PHC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(E=E96LB"FUS9W-T<B`BT>7D[.CV
MX"(*"B,Z(&UO;G1H+G!H<#HQ-SD@=V]R:W=E96LN<&AP.C,P('=E96LN<&AP
M.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E=E96L@)60B"FUS9W-T<B`BT>7D
M[.CVX"`E9"(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C4Y('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C$T,`IM<V=I9"`B5V5E:RAS*2(*;7-G<W1R
M("+1Y>3LZ/;@*.@I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q-0IM<V=I9"`B5V5E:VQY.B!2
M96-U<G,@979E<GDB"FUS9W-T<B`BT>7D[.CW[>XZ(._NXO+@\/\@\>4@XO'_
MZN`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED("(B"B)7
M:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@
M=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\B"FUS9W-T<B`BRN[CX"#DX"#G
MX.+Z\/CBX/(@Y.WEXNWH__(@Z"#QY>3LZ/?MZ/_R(.CGX^OEY#\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED("(B"B)7:&%T('1I;64@
M<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A
M<F4@;F\@96%R;&EE<B!E=F5N=',_(@IM<V=S='(@(LKNX^`@Y.`@Y^#O[O?B
MX/(@Y.WEXNWH__(@Z"#QY>3LZ/?MZ/_R(.CGX^OEY#\B"@HC.B!A='1E;F1E
M97,N<&AP.C$Q,2!L:6(O2W)O;F]L:71H+G!H<#HQ,C@Y(&QI8B]";&]C:R]T
M<F5E7VUE;G4N<&AP.C(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM
M<V=I9"`B5V]R:R!7965K(@IM<V=S='(@(M#@X>[R[>`@\>7D[.CVX"(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$R.3(@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z,C4*;7-G:60@(EEE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T,0IM
M<V=I9"`B665A<FQY.B!296-U<G,@979E<GDB"FUS9W-T<B`BP^[DZ/CM[CH@
M[^[B\N#P_R#QY2#B\?_JX"(*"B,Z(&1A=&$N<&AP.C0P(&1A=&$N<&AP.C(S
M-"!E9&ET979E;G1A8W1I;VXN<&AP.C0V(&%D9&5V96YT+G!H<#HQ-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T
M92!M;W)E('1H86X@)60@979E;G1S+B(*;7-G<W1R("(B"@HC.B!A='1E;F0N
M<&AP.C0Y"FUS9VED(")9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@
M<W!E8VEF:65D(&5V96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C<V"FUS9VED(")9;W4@8V%N(&]N;'D@=7-E
M('1H:7,@9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.CDW,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1O(&YO="!H879E(&%N(&5M86EL
M(&%D9')E<W,@8V]N9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T
M:6]N("(*(D]P=&EO;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F
M;W)E(&5V96YT(&YO=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N(@IM<V=S='(@
M(B(*(LWE(/'RY2#B^N+EZ^@@96UA:6P@X.3PY?$@XOKB(.+@^.CRY2#MX/'R
M\.[IZN@N(-+P_^'BX"#DX"#GX.3@Y.7RY2#@Y/#E\2`B"B+O\.7DZ"#DX"#L
M[N;E\N4@Y.`@Z.?O\.#YX/+E(._NZN#MZ"XB"@HC.B!A9&1E=F5N=&%C=&EO
M;BYP:'`Z,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S
M='(@(LW_[.#RY2#O\.#BX"#GX"#D[N'@XO_MY2#MX"#Q^N'H\NC_(.KZ["#H
MY^'PX.WH_R#JX.OE[>3@\"XB"@HC.B!D871A+G!H<#HQ.30*;7-G:60@(EEO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@=&AE
M('-E;&5C=&5D(&-A;&5N9&%R+B(*;7-G<W1R("+-_^S@\N4@[_#@XN`@Y^`@
MY.[AX.+_[>4@[>`@\?KAZ/+H_R#J^NP@Z.?A\.#MZ/\@ZN#KY>WDX/`N(@H*
M(SH@9&5L979E;G1A8W1I;VXN<&AP.C(V"FUS9VED(")9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!D96QE=&4@=&AI<R!E=F5N="XB"FUS9W-T<B`B
MS?_LX/+E(._PX.+@(.3@(.CG\O#HY?+E(/+NXN`@\?KAZ/+HY2XB"@HC.B!E
M9&ET979E;G1A8W1I;VXN<&AP.C<X"B,L(&9U>GIY"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N(@IM<V=S
M='(@(LW_[.#RY2#O\.#BX"#DX"#HY_+PZ.7RY2#R[N+@(/'ZX>CRZ.4N(@H*
M(SH@9&%T82YP:'`Z,3@Y"FUS9VED(")9;W4@:&%V92!S<&5C:69I960@86X@
M:6YV86QI9"!C86QE;F1A<BXB"FUS9W-T<B`BQ^#DX.OH(/'RY2#MY>+@Z^CD
MY>T@ZN#KY>WDX/`N(@H*(SH@871T96YD+G!H<#HR,0IM<V=I9"`B66]U(&AA
M=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E
M=F5N="XB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HR-@HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E8VQI;F5D(&%T=&5N9&5N
M8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`BS?_LX/+E(._PX.+@(.3@(.CG
M\O#HY?+E(/+NXN`@\?KAZ/+HY2XB"@HC.B!A='1E;F0N<&AP.C,Q"B,L(&9U
M>GIY"FUS9VED(")9;W4@:&%V92!T96YT871I=F5L>2!A8V-E<'1E9"!A='1E
M;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(LW_[.#RY2#O\.#BX"#D
MX"#HY_+PZ.7RY2#R[N+@(/'ZX>CRZ.4N(@H*(SH@8V%L96YD87)S+G!H<#HY
M,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`BTO#_X>+@(.3@(.CGX>7PY?+E(.K@Z^7MY.#P+"#J
M[NGR[B#DX"#A^N3E(.CG\O#H\BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C4T"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`BTO#_X>+@(.3@(.CGX>7P
MY?+E(.K@Z^7MY.#P+"#J[NGR[B#DX"#A^N3E(.CG\O#H\BXB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#DT"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E
M(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N
M9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`IM
M<V=I9"`B(@HB66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V
M96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY"FUS9VED(")9;W4@<F5Q
M=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET960@
M:6X@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]38VAE9'5L
M97(O:W)O;F]L:71H+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(')E<75E<W1E9"!T;R!B92!R96UI;F1E9"!A8F]U="`E<RP@=VAI8V@@:7,@
M;VX@)7,@870@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M:&%R97-E;&5C="YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L
M="!C86QE;F1A<B(*;7-G<W1R("+"X/CH__(@ZN#KY>WDX/`@[^X@[^[D\.#G
MX>CPX.WE.B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-3,@;&EB+T1R:79E<BYP
M:'`Z,3`V,PIM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.CDW"B,L(&9U>GIY"FUS9VED(")?
M06QA<FTB"FUS9W-T<B`BP.O@\.S@(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C$Q"FUS9VED(")?0F%S:6,@4V5A<F-H(@IM
M<V=S='(@(B(*"B,Z('9I97=E=F5N="YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED
M(")?161I="(*;7-G<W1R("+0Y>3@ZO;H_R(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$S,S`*(RP@9G5Z>GD*;7-G:60@(E]';W1O(@IM<V=S='(@(LCDZ"#M
MX"(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S8*(RP@9G5Z>GD*;7-G:60@
M(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(LCL[^[P\B_%ZO'O[O#R(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q.`HC+"!F=7IZ>0IM<V=I9"`B7TUY($-A
M;&5N9&%R<R(*;7-G<W1R("+,[O_R(,K@Z^7MY.#P(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3,R-0HC+"!F=7IZ>0IM<V=I9"`B7TYE=R!%=F5N="(*;7-G
M<W1R("+-[N+N(/'ZX>CRZ.4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S0Q
M"B,L(&9U>GIY"FUS9VED(")?4')I;G0B"FUS9W-T<B`BSO+OY??@\N#I(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,@IM<V=I9"`B7U-E87)C:"(*;7-G
M<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S(X"B,L(&9U>GIY"FUS
M9VED(")?5&]D87DB"FUS9W-T<B`BQ.WE\2(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C$T,@IM<V=I9"`B8F5F;W)E('1H92!E=F5N="!S=&%R=',B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-0IM<V=I
M9"`B9&%Y(@IM<V=S='(@(N3E[2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$Q,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3`*;7-G:60@(F1A
M>2AS*2(*;7-G<W1R("+DY>THY.WH*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.#8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-PHC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B9&%Y<R(*;7-G
M<W1R("+D[>@B"@HC.B!D871A+G!H<#HQ-#<@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ"B,L(&9U>GIY"FUS9VED(")E=F5N=',N8W-V(@IM<V=S='(@
M(L+QZ/?JZ"#Q^N'H\NC_(@H*(SH@9&%T82YP:'`Z,38X"B,L(&9U>GIY"FUS
M9VED(")E=F5N=',N:6-S(@IM<V=S='(@(L+QZ/?JZ"#Q^N'H\NC_(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,S$*;7-G:60@(F9R
M;VTB"FUS9W-T<B`B[O(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(S,"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S8*
M;7-G:60@(FUO;G1H*',I(@IM<V=S='(@(NSE\>7V*.`I(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`R,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M;VX@)7,@870@)7,B"FUS9W-T<B`B)7,@Y^#O[O?BX"#QZ^7D("5S(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(S,`IM<V=I9"`B;VX@=&AE('-A;64@9&%T92(*;7-G<W1R("+M
MX"#Q^OG@\N`@Y.#RX"(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R
M-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S8*;7-G:60@(F]N('1H92!S
M86UE('=E96MD87DB"FUS9W-T<B`B[>`@\?KYZ/_R(/#@X>[RY>T@Y.7M(@H*
M(SH@9&%T82YP:'`Z,S`@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-0IM
M<V=I9"`B=D-A;&5N9&%R+VE#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HS-#D@;&EB+V%P:2YP:'`Z-C`W"FUS9VED(")V179E;G0@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")W965K(@IM<V=S='(@(O'EY.SH]N`B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C$W"FUS9VED(")W965K*',I(&]N.B(*;7-G<W1R("+QY>3LZ/;@*.@I.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3(@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DT"FUS9VED
M(")W965K<R(*;7-G<W1R("+QY>3LZ/;H(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T,@IM<V=I
M9"`B>65A<BAS*2(*;7-G<W1R("+C[N3H[>`B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W!O+V9R7T92+G!O````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$S-S(S-``Q,#0Q-S,V,C<U
M,P`P,C`T,C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(R!T<F%N<VQA=&EO;B!O9B!F<E]&4BYP;R!T;R!&<F5N8V@*(R!T
M<F%N<VQA=&EO;B!O9B!F<E]&4BYP;R!T;R!&<F%NYV%I<PHC($MR;VYO;&ET
M:"`R+C$@1G)E;F-H('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`Q
M($UI:VAAZVP@2F%N<V]N+@HC($-O<'ER:6=H="`H0RD@,C`P,BP@,C`P,RP@
M,C`P-2P@,C`P-B!4:&EE<G)Y(%1H;VUA<RX*(R!4:&ES(&9I;&4@:7,@9&ES
M=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@4$%#2T%'
M12!P86-K86=E+@HC($UI:VAAZVP@2F%N<V]N(#QM:6M`9V%L87AI92YN970^
M+"`R,#`Q+@HC(%1H:65R<GD@5&AO;6%S(#QT:&EE<G)Y0'!O;7!O+FYE=#XL
M(#(P,#(N"B,@4&EE<G)E($QA8VAA;F-E(#QP;$!P:65R<F5L86-H86YC92YN
M970^(&5T($)E;F]I="!3="U!;F1R92`\8F5N0&)E;F]I='-T+6%N9')E+FYE
M=#XL(#(P,#,L(#(P,#0N"B,@0F5N;VET(%-T+4%N9'+I(#QB96Y`8F5N;VET
M<W0M86YD<F4N;F5T/BP@,C`P-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@9G)?1E)<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-BTP,BTR,B`P-SHR-2LP,3`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`V+3`R+3(R(#(R.C`U*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M5&AI97)R>2!4:&]M87,@/'1H:65R<GE`<&]M<&\N;F5T/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@1G)E;F-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R
M86P]*&X@/B`Q*3M<;B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H
M+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!C86QE;F1A<G,@9F]U
M;F0B"FUS9W-T<B`B)60@8V%L96YD<FEE<G,@=')O=7;I<R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&5V96YT<R(*;7-G<W1R("(E9"#I=NEN96UE;G1S(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3(S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($1A>2AS*2`E<R!(;W5R*',I("5S($UI;G5T97,B"FUS9W-T
M<B`B)7,@2F]U<G,H<RD@)7,@2&5U<F4H<RD@)7,@36EN=71E<R(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C$X,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@871T
M96YD965S(@IM<V=S='(@(B5S('!A<G1I8VEP86YT<R(*"B,Z(&1A=&$N<&AP
M.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL
M>2!I;7!O<G1E9"(*;7-G<W1R("),92!F:6-H:65R("5S(&$@8FEE;B#I=.D@
M:6UP;W)TZ2(*"B,Z(&-A;&5N9&%R<RYP:'`Z,3`U(&QI8B]B87-E+G!H<#HQ
M,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M(")!9V5N9&$@9&4@)7,B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C
M:"YI;F,Z,3<*;7-G:60@(B(*(BA#;&EC:R!O;B!C86QE;F1A<B!N86UE('1O
M('-W:71C:"!T:&4@8V%L96YD87(G<R!V:7-I8FEL:71Y(&EN('1H92!M86EN
M("(*(G=I;F1O=RDB"FUS9W-T<B`B(@HB*$-L:7%U97(@<W5R(&QE(&YO;2!D
M=2!C86QE;F1R:65R('!O=7(@;"=A9F9I8VAE<B!D86YS(&QA(&9E;NIT<F4@
M<')I;F-I<&%L92DB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$V-0IM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@061D("HB
M"FUS9W-T<B`B*B!,97,@86IO=71E<B!E;B!C;&EQ=6%N="!S=7(@06IO=71E
M<B`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-3$*
M;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@
M(BH@5F5U:6QL97H@<^EL96-T:6]N;F5R('5N92AD97,I(&%D<F5S<V4H<RD@
M*B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X,#8*;7-G:60@(C$@871T96YD964B
M"FUS9W-T<B`B,2!P87)T:6-I<&%N="(*"B,Z('1E;7!L871E<R]S96%R8V@O
M:&5A9&5R+FEN8SHT"FUS9VED("(Q(&5V96YT(@IM<V=S='(@(C$@Z7;I;F5M
M96YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B,2!H
M;W5R(@IM<V=S='(@(C$@:&5U<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,T"FUS9VED("(Q-2!M:6YU=&5S(@IM<V=S='(@(C$U(&UI;G5T97,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED("(R,"!M:6YU
M=&5S(@IM<V=S='(@(C(P(&UI;G5T97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,V"FUS9VED("(S,"!M:6YU=&5S(@IM<V=S='(@(C,P(&UI;G5T
M97,B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-CD*;7-G:60@(CQS
M=')O;F<^071T96YD965S/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B
M/'-T<F]N9SY087)T:6-I<&%N=',\+W-T<F]N9SX@*&9A8W5L=&%T:68I(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30W"FUS9VED("(\<W1R;VYG
M/D1E<V-R:5]P=&EO;CPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQS
M=')O;F<^1&5S8W)I7W!T:6]N/"]S=')O;F<^("AF86-U;'1A=&EF*2(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(W-`IM<V=I9"`B/'-T<F]N9SY+
M97EW;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQS=')O;F<^
M36]T<RUC;.ES/"]S=')O;F<^("AF86-U;'1A=&EF*2(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$Y,@IM<V=I9"`B/'-T<F]N9SY296-U<G)E;F-E
M/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9SY2Z7#I=&ET
M:6]N/"]S=')O;F<^("AF86-U;'1A=&EF*2(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,3$S('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3DS
M"FUS9VED(")!32(*;7-G<W1R(")!32(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C8P,@IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B06-C97!TZ2(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I9"`B061?=F%N8V5D
M(%-E87)C:"(*;7-G<W1R(")?4F5C:&5R8VAE(&%V86YCZ64B"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V,`IM<V=I9"`B061D(@IM
M<V=S='(@(D%J;W5T97(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,@IM<V=I9"`B061D($5V96YT(@IM<V=S='(@(D%J;W5T(&0GZ7;I;F5M96YT
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI
M;F,Z,S4*;7-G:60@(D%D9"!A(&YE=R!296UO=&4@0V%L96YD87(B"FUS9W-T
M<B`B06IO=71E<B!U;B!N;W5V96P@86=E;F1A(&1I<W1A;G0B"@HC.B!A9&1E
M=F5N="YP:'`Z-C0*;7-G:60@(D%D9"!A(&YE=R!E=F5N="(*;7-G<W1R(")!
M:F]U=&5R('5N(&YO=79E;"#I=NEN96UE;G0B"@HC.B!T96UP;&%T97,O871T
M96YD965S+V%T=&5N9&5E<RYI;F,Z-S$*;7-G:60@(D%D9"!A='1E;F1E97,B
M"FUS9W-T<B`B06IO=71E<B!D97,@<&%R=&EC:7!A;G1S(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#4*;7-G:60@(D%D9"!T;R!A
M='1E;F1E97,B"FUS9W-T<B`B06IO=71E<B!A=7@@<&%R=&EC:7!A;G1S(@H*
M(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3(X"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN
M8SHW-`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D-A<FYE="!D)V%D
M<F5S<V5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N
M:6YC.C@@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!
M9'9A;F-E9"!396%R8V@B"FUS9W-T<B`B4F5C:&5R8VAE(&%V86YCZ64B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU,PIM<V=I9"`B06QA<FTB"FUS
M9W-T<B`B06QE<G1E(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!D87ES(&)E9F]R92(*;7-G<W1R(")!
M;&5R=&4@)60@:F]U<G,@879A;G0B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&AO=7)S(&)E9F]R92(*
M;7-G<W1R(")!;&5R=&4E9"!H975R97,@879A;G0B"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&UI;G5T
M97,@8F5F;W)E(@IM<V=S='(@(D%L97)T92`E9"!M:6YU=&5S(&%V86YT(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z,3<W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M;&%R;2`E9"!W965K<R!B969O<F4B"FUS9W-T<B`B06QE<G1E("5D('-E;6%I
M;F4@879A;G0B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@Q"FUS9VED(")!;&%R
M;2`Q(&1A>2!B969O<F4B"FUS9W-T<B`B06QE<G1E(#$@:F]U<F[I92!A=F%N
M="(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.#8*;7-G:60@(D%L87)M(#$@:&]U
M<B!B969O<F4B"FUS9W-T<B`B06QE<G1E(#$@:&5U<F4@879A;G0B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ-SDQ"FUS9VED(")!;&%R;2`Q(&UI;G5T92!B969O
M<F4B"FUS9W-T<B`B06QE<G1E(#$@;6EN=71E(&%V86YT(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3<W-@IM<V=I9"`B06QA<FT@,2!W965K(&)E9F]R92(*;7-G
M<W1R(")!;&5R=&4@,2!S96UA:6YE(&%V86YT(@H*(SH@9&%T82YP:'`Z-3D*
M;7-G:60@(D%L87)M($1A=&4B"FUS9W-T<B`B1&%T92!D92!L)V%L97)T92(*
M"B,Z(&1A=&$N<&AP.C4X"FUS9VED(")!;&%R;2!3<&%N("AM:6YU=&5S*2(*
M;7-G<W1R(")$=7+I92!D92!L)V%L97)T92`H;6EN=71E<RDB"@HC.B!D871A
M+G!H<#HV,`IM<V=I9"`B06QA<FT@5&EM92(*;7-G<W1R(")(975R92!D92!L
M)V%L97)T92(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS-`IM
M<V=I9"`B06QL(@IM<V=S='(@(E1O=70B"@HC.B!L:6(O1D)6:65W+G!H<#HQ
M,C@@;&EB+T9"5FEE=RYP:'`Z,3,Q(&QI8B]&0E9I97<N<&AP.C$S-`IM<V=I
M9"`B06QL($%T=&5N9&5E<R(*;7-G<W1R(")4;W5S(&QE<R!P87)T:6-I<&%N
M=',B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3D*;7-G:60@
M(D%L;"!&=71U<F4B"FUS9W-T<B`B5&]U<R#I=NEN96UE;G1S('5L=.ER:65U
M<G,B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*;7-G:60@
M(D%L;"!087-T(@IM<V=S='(@(E1O=7,@Z7;I;F5M96YT<R!A;G3I<FEE=7)S
M(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C
M:R]M;VYT:"YP:'`Z,C0*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C<@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(U"FUS9VED(")!;&P@5FES:6)L92(*
M;7-G<W1R(")4;W5T('9I<VEB;&4B"@HC.B!T96UP;&%T97,O961I="]E9&ET
M7W1I;65S<&%N+FEN8SHQ,C(@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6
M:65W+G!H<#HY,PHC.B!L:6(O5V5E:U9I97<N<&AP.C$R-R!L:6(O5V5E:U9I
M97<N<&AP.C$S-"!L:6(O1')I=F5R+G!H<#HQ.#8Y"FUS9VED(")!;&P@9&%Y
M(@IM<V=S='(@(E1O=71E(&QA(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,38T"FUS9VED(")!;&P@9&%Y(&5V96YT(@IM<V=S='(@(D1U
M<F4@=&]U=&4@;&$@:F]U<F[I92(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,S,*;7-G:60@(D%L;"!E=F5N=',B"FUS9W-T<B`B5&]U<R!L97,@
MZ7;I;F5M96YT<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHT.`HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E
M9"YI;F,Z-S`@;&EB+TMR;VYO;&ET:"YP:'`Z-CDU"FUS9VED(")!;GDB"FUS
M9W-T<B`B3B=I;7!O<G1E('%U96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]G;W1O+FEN8SHW,0IM<V=I9"`B07!R:6PB"FUS9W-T<B`B079R:6PB"@HC
M.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHS.2!T96UP;&%T
M97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHY,PHC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C@R('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,38X
M"FUS9VED(")!="(*;7-G<W1R("+`(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3`T-@IM<V=I9"`B(@HB071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@
M=VET:"!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('1H92!E=F5N="X@268@>6]U
M<B`B"B)M86EL(&-L:65N="!S=7!P;W)T<R!I5&EP(')E<75E<W1S('EO=2!C
M86X@=7-E('1H:7,@9FEL92!T;R!E87-I;'D@=7!D871E("(*(GEO=7(@;&]C
M86P@8V]P>2!O9B!T:&4@979E;G0N(@IM<V=S='(@(B(*(DQA('!IZ&-E(&IO
M:6YT92!E<W0@=6X@9FEC:&EE<B!I0V%L96YD87(@8V]N=&5N86YT('!L=7,@
M9"=I;F9O<FUA=&EO;G,@(@HB8V]N8V5R;F%N="!L)^EVZ6YE;65N="X@4VD@
M=F]T<F4@8VQI96YT(&1E(&-O=7)R:65R('-U<'!O<G1E(&QE<R!R97%UZG1E
M<R`B"B)I5&EP('9O=7,@<&]U=F5Z('5T:6QI<V5R(&-E(&9I8VAI97(@<&]U
M<B!M971T<F4@X"!J;W5R('9O=')E(&-O<&EE(&QO8V%L92`B"B)D92!L)^EV
MZ6YE;65N="XB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI
M;F,Z-#(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E
M;F1A;F-E(@IM<V=S='(@(E!RZ7-E;F-E(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,38Q"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B4'+I<V5N
M=',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-0IM<V=I
M9"`B075G=7-T(@IM<V=S='(@(D%O^W0B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC.C@*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R(")296-H97)C
M:&4@<VEM<&QE(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R(")!;FYI=F5R<V%I<F4B"@HC.B!L:6(O
M1D)6:65W+G!H<#HY,"!L:6(O1D)6:65W+G!H<#HQ,3$*;7-G:60@(D)U<WDB
M"FUS9W-T<B`B3V-C=7#I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.C0R"FUS9VED(")#7V%L96YD87(B"FUS9W-T<B`B7T%G
M96YD82(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0W"FUS9VED(")#
M86Q?96YD87(B"FUS9W-T<B`B05]G96YD82(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ-#D@;&EB+T)L;V-K+W!R979M;VYT:&QI
M<W0N<&AP.C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C$@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS
M9VED(")#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,PIM<V=I9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G<W1R
M(")3;VUM86ER92!D92!L)V%G96YD82(*"B,Z(&1A=&$N<&AP.C(S,PIM<V=I
M9"`B0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS9W-T<B`B3&4@
M8V%L96YD<FEE<B!A(.ETZ2!P=7)GZ2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<*;7-G
M:60@(D-A;&5N9&%R<R(*;7-G<W1R(")!9V5N9&%S(@H*(SH@8V%L96YD87)S
M+G!H<#HR-PIM<V=I9"`B0V%L96YD87)S(&UU<W0@:&%V92!A(&YA;64N(@IM
M<V=S='(@(DQE<R!A9V5N9&%S(&1O:79E;G0@879O:7(@=6X@;F]M+B(*"B,Z
M(&1A=&$N<&AP.C(T.`IM<V=I9"`B0V%N)W0@8W)E871E(&$@;F5W(&5V96YT
M+B(*;7-G<W1R(")#<NEA=&EO;B!I;7!O<W-I8FQE(&0G=6X@;F]U=F5L(.EV
MZ6YE;65N="XB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S,@=&5M
M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,U"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C,Q('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,P-PIM<V=I
M9"`B0V%N8V5L(@IM<V=S='(@(D%N;G5L97(B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HU-S@*;7-G:60@(D-A;F-E;&QE9"(*;7-G<W1R(")!;FYU;.EE(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YC96QL960Z("5S(@IM<V=S='(@(D%N;G5LZ66@.B`E<RXB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-C,@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z-C<*;7-G:60@(D-A=&5G;W)?>2(*;7-G<W1R
M(")#873I9V]R7VEE(@H*(SH@9&%T82YP:'`Z-C(@=&5M<&QA=&5S+W-E87)C
M:"]E=F5N=%]H96%D97)S+FEN8SHT('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$S"FUS9VED(")#871E9V]R>2(*;7-G<W1R(")#873I9V]R:64B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<Y"FUS9VED("(B"B)#:&]O<V4@:68@
M>6]U('=A;G0@=&\@8F4@;F]T:69I960@;V8@;F5W+"!E9&ET960L(&%N9"!D
M96QE=&5D(&5V96YT<R!B>2`B"B)E;6%I;#HB"FUS9W-T<B`B(@HB0VAO:7-I
M<W-E>B!S:2!V;W5S('9O=6QE>B#J=')E(&%V97)T:2!D97,@8W+I871I;VYS
M+"!M+B#@(&HN(&]U('-U<'!R97-S:6]N<R`B"B)D)^EVZ6YE;65N=',@<&%R
M(&-O=7)R:65RH#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(*;7-G
M:60@(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L
M(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S+B(*;7-G<W1R("(B"B)#:&]I
M<VES<V5Z('-I('9O=7,@=F]U;&5Z(.IT<F4@879E<G1I(&1E<R!C<NEA=&EO
M;G,L(&TN(.`@:BX@;W4@<W5P<')E<W-I;VYS("(*(F0GZ7;I;F5M96YT<RXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDR"FUS9VED(")#:&]O<V4@
M:68@>6]U('=A;G0@=&\@<F5C96EV92!E;6%I;"!R96UI;F1E<G,@9F]R(&5V
M96YT<R!W:71H(&%L87)M<SHB"FUS9W-T<B`B(@HB0VAO:7-I<W-E>B!S:2!V
M;W5S('9O=6QE>B!R96-E=F]I<B!D97,@8V]U<G)I97)S(&1E(')A<'!E;"!P
M;W5R(&QE<R`B"B+I=NEN96UE;G1S(&%V96,@9&5S(&%L87)M97.@.B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96%R8VA?86)O;VM?<V5L96-T+FEN8SHQ.2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$R"FUS9VED(")#:&]O<V4@=&AE(&%D
M9')E<W,@8F]O:W,@=&\@<V5A<F-H(&9O<B!F<F5E+V)U<WD@55),<SHB"FUS
M9W-T<B`B(@HB0VAO:7-I<W-E>B!L92!C87)N970@9"=A9')E<W-E<R!O^2!C
M:&5R8VAE<B!L97,@55),(&1E(&1I<W!O;FEB:6QI=.ESH#HB"@HC.B!T96UP
M;&%T97,O<')E9G,O9F)?8V%L<U]S96QE8W0N:6YC.C$V"FUS9VED(")#:&]O
M<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E(&EN('EO=7(@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N.B(*;7-G<W1R(")#:&]I<VES<V5Z(&QE<R!A9V5N9&%S
M(.`@:6YC;'5R92!D86YS('9O=')E(&QI<W1E(&1E(&1I<W!O;FEB:6QI=.ES
MH#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(T"FUS9VED(")#:&]O
M<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E('=H96X@9V5N97)A=&EN9R!F
M<F5E+V)U<WD@55),<SHB"FUS9W-T<B`B(@HB0VAO:7-I<W-E>B!L97,@86=E
M;F1A<R#@(&EN8VQU<F4@<&]U<B!GZ6[I<F5R(&QE<R!54DP@9&4@9&ES<&]N
M:6)I;&ETZ7.@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I
M9"`B0VAO;W-E('EO=7(@9&5F875L="!C86QE;F1A<BXB"FUS9W-T<B`B0VAO
M:7-I<W-E>B!V;W1R92!A9V5N9&$@<&%R(&3I9F%U="XB"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z.#0*;7-G:60@(D-L96%R(&%L
M;"!A='1E;F1E97,B"FUS9W-T<B`B3&EBZ7)E<B!T;W5S(&QE<R!P87)T:6-I
M<&%N=',B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X
M-@IM<V=I9"`B0VQO<V4@=VEN9&]W(@IM<V=S='(@(D9E<FUE<B!L82!F96[J
M=')E(@H*(SH@9&%T82YP:'`Z,C@@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")6
M86QE=7)S('/I<&%RZ65S('!A<B!D97,@=FER9W5L97,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S,*;7-G:60@(D-O;F9I<FT@9&5L971I;VX@;V8@
M979E;G1S/R(*;7-G<W1R(")#;VYF:7)M97(@;&$@<W5P<')E<W-I;VX@9&5S
M(.EVZ6YE;65N='.@/R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4W-0IM<V=I
M9"`B0V]N9FER;65D(@IM<V=S='(@(D-O;F9I<FWI92(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,3<*;7-G:60@(D-O<'D@=&AE
M(%523"!B96QO=R!F;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO=7(@1G)E
M92]"=7-Y(%523#HB"FUS9W-T<B`B(@HB0V]P:65R(&PG55),(&-I+61E<W-O
M=7,@<&]U<B!U=&EL:7-E<B!L;W)S<75E('9O=7,@879E>B!B97-O:6X@9&4@
M=F]T<F4@55),("(*(F1E(&1I<W!O;FEB:6QI=.ESH#HB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(D]U=F5R='5R92!D92`E<R!I;7!O<W-I8FQE
M+B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,CD*
M;7-G:60@(D-R96%T92(*;7-G<W1R(")#<NEE<B(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,34*;7-G:60@(D-R96%T92!#86QE
M;F1A<B(*;7-G<W1R(")#<NEE<B!U;B!A9V5N9&$B"@HC.B!M;VYT:"YP:'`Z
M,38S('1E;7!L871E<R]W965K+VAE860N:6YC.C(U('1E;7!L871E<R]D87DO
M<F]W+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP
M:'`Z,3DU"FUS9VED(")#<F5A=&4@82!.97<@179E;G0B"FUS9W-T<B`B0W+I
M97(@=6X@;F]U=F5L(.EVZ6YE;65N="(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C@P"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(D-RZ>DB"@HC.B!T
M96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S(*;7-G:60@(D-U<G)E;G0B
M"FUS9W-T<B`B0V]U<F%N="(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#8*;7-G:60@(D1A:6QY
M.B!296-U<G,@979E<GDB"FUS9W-T<B`B475O=&ED:65NH#H@<NEPZ71I=&EO
M;B!C:&%Q=64B"@HC.B!A='1E;F1E97,N<&AP.C$P-B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,S$Q(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(Q"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,@IM<V=I9"`B1&%Y(@IM<V=S='(@(DIO=7(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV,B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ,S<*;7-G:60@(D1A>2AS*2(*;7-G<W1R(")*;W5R*',I
M(@H*(SH@=FEE=V5V96YT+G!H<#HQ,3$*;7-G:60@(D1E7VQE=&4B"FUS9W-T
M<B`B7U-U<'!R:6UE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C<Y"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$Z6-E;6)R92(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C8P-0IM<V=I9"`B1&5C;&EN960B"FUS9W-T
M<B`B1.EC;&ENZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-PIM<V=I
M9"`B1&5F875L="!#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$@<&%R(&3I9F%U
M="(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,#0@
M=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,R"B,Z('1E;7!L871E<R]P<F5F
M<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C(S(&QI8B]$<FEV97(N<&AP
M.C$X-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")3=7!P<FEM97(B"@HC.B!D
M96QE=F5N="YP:'`Z-#`@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(Q('1E
M;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR,0HC.B!L:6(O1')I=F5R+G!H
M<#HQ.#0Y"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R
M(")3=7!P<FEM97(@)7,B"@HC.B!E9&ET979E;G0N<&AP.C<R"FUS9VED(")$
M96QE=&4@179E;G0B"FUS9W-T<B`B4W5P<')I;65R(&PGZ7;I;F5M96YT(@H*
M(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,P"FUS9VED("(B"B)$
M96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E
M(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R("(*(F%L;"!O8V-U<F5N
M8V5S/R(*;7-G<W1R("(B"B)3=7!P<FEM97(@;"?I=NEN96UE;G0@8V]U<F%N
M="!S975L96UE;G0L(&-E='1E(&]C8W5R<F5N8V4@970@=&]U=&5S(&QE<R`B
M"B)S=6EV86YT97,L(&]U('1O=71E<R!L97,@;V-C=7)R96YC97.@/R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,#,@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X"FUS9VED(")$97-C<FE?<'1I
M;VXB"FUS9W-T<B`B1&5S8W)I7W!T:6]N(@H*(SH@9&%T82YP:'`Z-C$@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W.`HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHY-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B1&5S8W)I<'1I;VXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$W-`IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")!9F9I8VAE<B(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHV,PIM<V=I
M9"`B1&ES<&QA>2!#86QE;F1A<G,B"FUS9W-T<B`B069F:6-H97(@;&5S(&%G
M96YD87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X"FUS9VED
M(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!T:6]N<R!D)V%F9FEC:&%G
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&\@>6]U
M('=A;G0@=&\@<VAO=R!T87-K<R!W:&EC:"!A<F4@9'5E(&]N('EO=7(@8V%L
M96YD87(_(@IM<V=S='(@(B(*(E9O=6QE>BUV;W5S(&%F9FEC:&5R(&QE<R!T
MXF-H97,@<75I('9I96YN96YT(.`@Z6-HZ6%N8V4@9&%N<R!V;W1R92!A9V5N
M9&&@/R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T-0IM<V=I9"`B1&]E<R!N
M;W0@<F5C=7(B"FUS9W-T<B`B3F]N('+I<.ET:71I9B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$=64Z("5S(@IM
M<V=S='(@(LEC:.EA;F-EH#H@)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET
M7W1I;65S<&%N+FEN8SHQ,34*;7-G:60@(D1U<F%T:6]N(@IM<V=S='(@(D1U
M<NEE(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W
M,R!L:6(O1')I=F5R+G!H<#HQ.#,V"FUS9VED(")%9&ET(@IM<V=S='(@(DUO
M9&EF:65R(@H*(SH@961I=&5V96YT+G!H<#HS,R!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,B!L:6(O1')I=F5R+G!H<#HQ.#,U"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@)7,B"FUS9W-T<B`BR61I=&5R("5S(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3@U"FUS9VED(")%9&ET($%T=&5N9&5E<R(*
M;7-G<W1R("+)9&ET97(@;&5S('!A<G1I8VEP86YT<R(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#,*;7-G:60@(D5D:70@0V%L
M96YD87)S(@IM<V=S='(@(LED:71E<B!L97,@86=E;F1A<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-3`*;7-G:60@(D5D:70@4F5M;W1E($-A;&5N
M9&%R<R(*;7-G<W1R("+)9&ET97(@9&5S(&%G96YD87,@9&ES=&%N=',B"@HC
M.B!A='1E;F1E97,N<&AP.C$T-@IM<V=I9"`B161I="!A='1E;F1E97,B"FUS
M9W-T<B`BR61I=&5Z(&QE<R!P87)T:6-I<&%N=',B"@HC.B!T96UP;&%T97,O
M8V%T96=O<GE?;&5G96YD+FEN8SHR,`IM<V=I9"`B161I="!C871E9V]R:65S
M(&%N9"!C;VQO<G,B"FUS9W-T<B`B36]D:69I97(@8V%TZ6=O<FEE<R!E="#I
M=&EQ=65T=&5S(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ-S<@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0Q"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-`IM<V=I9"`B16UA:6P@061D
M<F5S<R(*;7-G<W1R(")#;W5R<FEE;"(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC.C8P"FUS9VED(")%;E]D(@IM<V=S='(@(D9I7VXB
M"@HC.B!D871A+G!H<#HU-@IM<V=I9"`B16YD($1A=&4B"FUS9W-T<B`B1&%T
M92!D92!F:6XB"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N
M:6YC.C@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#<*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ,C`*;7-G:60@(D5N9"!/;B(*;7-G<W1R(")&
M:6X@;&4B"@HC.B!D871A+G!H<#HU-PIM<V=I9"`B16YD(%1I;64B"FUS9W-T
M<B`B1FEN(.`B"@HC.B!A='1E;F1E97,N<&AP.C$R,"!A='1E;F1E97,N<&AP
M.C$S,2!A='1E;F1E97,N<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,Z
M("5S(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@
M9&4@;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE<R!I0V%L96YD87*@9&4@("5S
MH#H@(@HB)7,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$S"FUS9VED(")%
M=F5N="!A9&1E9#HB"FUS9W-T<B`BR7;I;F5M96YT(&%J;W5TZ:`Z(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3$R,PIM<V=I9"`B179E;G0@9&5L971E9#HB
M"FUS9W-T<B`BR7;I;F5M96YT('-U<'!R:6WIH#HB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,3$X"FUS9VED(")%=F5N="!E9&ET960Z(@IM<V=S='(@(LEV
MZ6YE;65N="#I9&ETZ:`Z(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%=F5N="!F<F]M("5S('1O("5S(@IM<V=S='(@
M(LEVZ6YE;65N="!D=2`E<R!A=2`E<R(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H
M<#HS-S,*;7-G:60@(D5V96YT(&YO="!F;W5N9"(*;7-G<W1R("+)=NEN96UE
M;G0@;F]N('1R;W5VZ2(*"B,Z(&QI8B]$<FEV97(N<&AP.C<W,`IM<V=I9"`B
M179E;G1S(&UU<W0@:&%V92!A('-T87)T(&1A=&4N(@IM<V=S='(@(DQE<R#I
M=NEN96UE;G1S(&1O:79E;G0@879O:7(@=6YE(&1A=&4@9&4@9.EB=70N(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z-S,V"FUS9VED(")%=F5N=',@;75S="!H879E
M(&$@=&ET;&4N(@IM<V=S='(@(DQE<R#I=NEN96UE;G1S(&1O:79E;G0@879O
M:7(@=6X@=&ET<F4N(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC.C<U"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T<B`B1.EV96QO
M<'!E<B!L97,@;F]M<R(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3DY"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T97(B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R="!#86QE;F1A
M<B(*;7-G<W1R(")%>'!O<G1E<B!L)V%G96YD82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C8Y"FUS9VED(")&96)R=6%R>2(*;7-G<W1R
M(")&Z79R:65R(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ,S,*;7-G:60@(D9I;F0B"FUS9W-T<B`B5')O=79E<B(*"B,Z('EE87(N
M<&AP.C@T('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8S('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP
M.C$P-0IM<V=I9"`B1G(B"FUS9W-T<B`B5F5N(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-3@Q"FUS9VED(")&<F5E(@IM<V=S='(@(DQI8G)E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4X"FUS9VED(")&<F5E+T)U<WD@26YF;W)M
M871I;VXB"FUS9W-T<B`B1&ES<&]N:6)I;&ETZ7,B"@HC.B!T96UP;&%T97,O
M;6]N=&@O:&5A9"YI;F,Z,C`@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$Y
M"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")&
M<FED87DB"FUS9W-T<B`B5F5N9')E9&DB"@HC.B!T96UP;&%T97,O9&5L971E
M+V1E;&5T92YI;F,Z,S,*;7-G:60@(D9U='5R92(*;7-G<W1R("+`('9E;FER
M(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")'86UE
M(@IM<V=S='(@(DIE=2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHR,PIM<V=I9"`B1V5N97)A;"(*;7-G<W1R(")'Z6[I<F%L
M92(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V]T;R`E<R(*;7-G<W1R(")!;&QE<B#@("5S(@H*(SH@;6]N
M=&@N<&AP.C$S,R!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M,3`*;7-G:60@(DAI9&4B"FUS9W-T<B`B0V%C:&5R(@H*(SH@;6]N=&@N<&AP
M.C$S,R!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*
M(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&ED92`E<R(*;7-G<W1R(")#86-H97(@)7,B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV-2!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ,S8*;7-G:60@(DAO=7(H<RDB"FUS9W-T<B`B2&5U<F4H
M<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")(;W<@
M;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@=&AE(&1A>2!A;F0@=V5E
M:R!V:65W<R!B93\B"FUS9W-T<B`B(@HB1'5RZ64@9&5S('1R86YC:&5S(&AO
M<F%I<F5S(&1A;G,@;&5S('9U97,@X"!L82!J;W5R;NEE(&5T(.`@;&$@<V5M
M86EN9:`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,0IM<V=I9"`B
M2&]W(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M871I;VX@<VAO=6QD
M('=E(&=E;F5R871E/R(*;7-G<W1R("(B"B)0;W5R(&-O;6)I96X@9&4@:F]U
M<G,@X"!L82!F;VES(&1O:70M;VX@9^ENZ7)E<B!L97,@:6YF;W)M871I;VYS
M('-U<B!L82`B"B)D:7-P;VYI8FEL:73IH#\B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,#4P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DEF('EO=7(@96UA
M:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP(')E<75E<W1S('EO=2!C
M86X@=7-E(&]N92!O9B!T:&4@(@HB9F]L;&]W:6YG(&QI;FMS('1O(&%C8V5P
M="!O<B!D96-L:6YE('1H92!E=F5N="Y<;B(*(EQN(@HB5&\@86-C97!T('1H
M92!E=F5N=#I<;B(*(B5S7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0@
M=&5N=&%T:79E;'DZ7&XB"B(E<UQN(@HB7&XB"B)4;R!D96-L:6YE('1H92!E
M=F5N=#I<;B(*(B5S(@IM<V=S='(@(B(*(E-I('9O=')E(&QO9VEC:65L(&1E
M(&-O=7)R:65R(&YE('-U<'!O<G1E('!A<R!L97,@<F5Q=>IT97,@:51I<"!V
M;W5S('!O=79E>B`B"B)U=&EL:7-E<B!U;B!D97,@;&EE;G,@<W5I=F%N=',@
M<&]U<B!A8V-E<'1E<B!O=2!R969U<V5R(&PGZ7;I;F5M96YT+EQN(@HB7&XB
M"B)0;W5R(&%C8V5P=&5R(&PGZ7;I;F5M96YTH#I<;B(*(B5S7&XB"B)<;B(*
M(E!O=7(@86-C97!T97(@;"?I=NEN96UE;G0@<')O=FES;VER96UE;G2@.EQN
M(@HB)7-<;B(*(EQN(@HB4&]U<B!R969U<V5R(&PGZ7;I;F5M96YTH#I<;B(*
M(B5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="!#86QE;F1A<BP@4W1E<"`E9"(*;7-G<W1R
M("));7!O<G1E<B!U;B!A9V5N9&$L(.ET87!E("5D(@H*(SH@9&%T82YP:'`Z
M,C@X"FUS9VED("));7!O<G0O17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(DEM
M<&]R=&5R+T5X<&]R=&5R('5N(&%G96YD82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA
M;G9I97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-`IM
M<V=I9"`B2G5L>2(*;7-G<W1R(")*=6EL;&5T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-S,*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5I
M;B(*"B,Z(&1A=&$N<&AP.C8T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T
M,@IM<V=I9"`B2V5Y=V]R9',B"FUS9W-T<B`B36]T<RUC;.ES(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4U"FUS9VED("),87-T(#(T(&AO
M=7)S(@IM<V=S='(@(D1E<FYIZ')E<R`R-"!H975R97,B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHX-PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G
M<W1R(")$97)N:>AR92!M;V1I9FEC871I;VXB"@HC.B!T96UP;&%T97,O;6]N
M=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C0*(SH@=&5M<&QA=&5S+VUO;G1H
M+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC.B!T96UP;&%T97,O;6]N=&@O
M:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$V('1E;7!L871E<R]M;VYT:"]H96%D
M+FEN8SHT"FUS9VED("),87-T($UO;G1H(@IM<V=S='(@(DUO:7,@<'+I8^ED
M96YT(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-`IM<V=I9"`B3&%S
M="!996%R(@IM<V=S='(@(D%N;NEE('!RZ6/I9&5N=&4B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z-30@=&5M<&QA=&5S+W=E96LO:&5A9"YI
M;F,Z,PIM<V=I9"`B3&%S="!W965K(@IM<V=S='(@(E-E;6%I;F4@<'+I8^ED
M96YT92(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,CD*;7-G:60@
M(DQI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.B(*;7-G<W1R("),:6UI
M=&5R(&QA('#I<FEO9&4@X"!E>'!O<G1E<J`Z(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C@U('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C<T"FUS9VED("),;U]C871I;VXB"FUS9W-T<B`B3%]I974B"@HC
M.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N
M:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N
M="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E
M;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C$*(SH@;&EB
M+T1R:79E<BYP:'`Z,3@X-@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3&EE
M=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-0IM<V=I9"`B36%N86=E
M(')E;6]T92!C86QE;F1A<G,N(@IM<V=S='(@(D=E<W1I;VX@9&5S(&%G96YD
M87,@9&ES=&%N=',N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-S`*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<G,B"@HC.B!L:6(O87!I
M+G!H<#HQ,#`*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($5V96YT<R(*;7-G
M<W1R(").;VUB<F4@;6%X:6UA;"!D)^EVZ6YE;65N=',B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,@IM<V=I9"`B36%Y(@IM<V=S='(@
M(DUA:2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X.#,*;7-G:60@(DUE(@IM<V=S
M='(@(DUO:2(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I
M9"`B365E=&EN9R(*;7-G<W1R(")2Z75N:6]N(@H*(SH@;&EB+T)L;V-K+W1R
M965?86QA<FUS+G!H<#HS"FUS9VED(")-96YU($%L87)M<R(*;7-G<W1R(")-
M96YU(&1E<R!A;&5R=&5S(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z
M,PIM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(DUE;G4B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHV."!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M,S4*;7-G:60@(DUI;G5T92AS*2(*;7-G<W1R(")-:6YU=&4H<RDB"@HC.B!Y
M96%R+G!H<#HX,"!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHU.2!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,34*(SH@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HQ,#4*;7-G:60@(DUO(@IM<V=S='(@(DQU;B(*"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D+FEN8SHQ-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,34*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C@@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-@IM<V=I9"`B36]N9&%Y(@IM<V=S='(@(DQU
M;F1I(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q-"!L:6(O0FQO8VLO=')E
M95]M96YU+G!H<#HR-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*;7-G:60@
M(DUO;G1H(@IM<V=S='(@(DUO:7,B"@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP
M.C,*;7-G:60@(DUO;G1H(%9I97<B"FUS9W-T<B`B5G5E('!A<B!M;VES(@H*
M(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL
M:7-T+G!H<#HT,PIM<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R
M("),:7-T92!D97,@Z7;I;F5M96YT<R!M96YS=65L<R(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,C8*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(V('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(S,@IM<V=I9"`B36]N=&AL>3H@4F5C=7)S(&5V97)Y
M(@IM<V=S='(@(DUE;G-U96R@.B!RZ7#I=&ET:6]N('1O=7,@;&5S(@H*(SH@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!!:&5A
M9"(*;7-G<W1R(")-;VES(.`@=F5N:7(B"@HC.B!L:6(O0FQO8VLO<')E=FUO
M;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!"969O<F4B"FUS9W-T<B`B
M36]I<R!P<NECZ61E;G0B"@HC.B!L:6(O87!I+G!H<#HV,S0*;7-G:60@(DUU
M;'1I<&QE(&E#86QE;F1A<B!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!V
M179E;G0@:7,@<W5P<&]R=&5D+B(*;7-G<W1R("(B"B)0;'5S:65U<G,@8V]M
M<&]S86YT<R!I0V%L96YD87(@=')O=7;I<SL@<V5U;&5M96YT('5N(.EVZ6YE
M;65N="!E<W0@<W5P<&]R=.DN(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C<P"FUS9VED(")->2!#
M86QE;F1A<G,B"FUS9W-T<B`B365S(&%G96YD87,B"@HC.B!T96UP;&%T97,O
M;65N=2YI;F,Z,S0@=&5M<&QA=&5S+VUE;G4N:6YC.C,V"FUS9VED(")->2!#
M86QE;F1A<G,Z(@IM<V=S='(@(DUE<R!A9V5N9&%SH#HB"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C$S"FUS9VED(")->2!&<F5E
M+T)U<WD@55),(@IM<V=S='(@(DUO;B!54DP@9&4@9&ES<&]N:6)I;&ETZ7,B
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3(P('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-C(*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S8*(SH@=&5M<&QA=&5S+W!R
M969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,3<*(SH@=&5M<&QA=&5S
M+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-#0*;7-G:60@(DYA
M;64B"FUS9W-T<B`B3F]M(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HT,2!L
M:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT-"!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z-#$*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C`*;7-G:60@(DYE
M=R!%=F5N="(*;7-G<W1R(").;W5V96P@Z7;I;F5M96YT(@H*(SH@;&EB+V)A
M<V4N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B).97<@8V%L96YD
M87(@8W)E871E9"!A;F0@875T;VUA=&EC86QL>2!S:&%R960@=VET:"!F;VQL
M;W=I;F<@9W)O=7`H<RDZ("5S+B(*;7-G<W1R("(B"B).;W5V96P@86=E;F1A
M(&-RZ>D@970@<&%R=&%GZ2!A=71O;6%T:7%U96UE;G0@879E8R!L92AS*2!G
M<F]U<&4H<RD@<W5I=F%N="(*(BAS*:`Z("5S+B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,S,*;7-G:60@(DYE>'0B"FUS9W-T<B`B4W5I=F%N
M="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-PIM<V=I9"`B
M3F5X="`R-"!H;W5R<R(*;7-G<W1R(")0<F]C:&%I;F5S(#(T(&AE=7)E<R(*
M"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR.0IM<V=I9"`B3F5X="!$87DB"FUS
M9W-T<B`B2F]U<B!S=6EV86YT("(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D
M7W-I9&5?8GE?<VED92YI;F,Z-@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I
M9&5?8GE?<VED92YI;F,Z,3@@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C8*
M;7-G:60@(DYE>'0@36]N=&@B"FUS9W-T<B`B36]I<R!S=6EV86YT(@H*(SH@
M;&EB+T9"5FEE=R]W965K+G!H<#HS,@IM<V=I9"`B3F5X="!7965K(@IM<V=S
M='(@(E-E;6%I;F4@<W5I=F%N=&4@(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A
M9"YI;F,Z-@IM<V=I9"`B3F5X="!996%R(@IM<V=S='(@(D%N;NEE('-U:79A
M;G1E(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT
M(&1A>2(*;7-G<W1R(")*;W5R('-U:79A;G0B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM
M<V=I9"`B3F5X="!W965K(@IM<V=S='(@(E-E;6%I;F4@<W5I=F%N=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<U(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR.#@*;7-G:60@(DYO(@IM<V=S='(@(DYO;B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C<S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$R
M-`IM<V=I9"`B3F\@86QA<FTB"FUS9W-T<B`B075C=6YE(&%L97)T92(*"B,Z
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT.`IM<V=I9"`B
M3F\@871T96YD965S(@IM<V=S='(@(D%U8W5N('!A<G1I8VEP86YT(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,`IM<V=I9"`B3F\@8V%L96YD87)S(&%R
M92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R(")087,@9"=A9V5N9&$@
M9&ES<&]N:6)L92!P;W5R(&QE<R!I;G9I=.ES+B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-3(*
M;7-G:60@(DYO(&5N9"!D871E(@IM<V=S='(@(E!A<R!D92!D871E(&1E(&9I
M;B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ-C0@;&EB+T)L
M;V-K+VUO;G1H;&ES="YP:'`Z,38S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ.30*;7-G:60@(DYO(&5V96YT<R!T;R!D:7-P;&%Y(@IM<V=S='(@(D%U
M8W5N(.EVZ6YE;65N="#@(&%F9FEC:&5R(@H*(SH@;&EB+U-T;W)A9V4O:V]L
M86(N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S(@IM<V=S='(@(D%U8W5N
M92!I;F9O<FUA=&EO;B!S=7(@;&5S(&1I<W!O;FEB:6QI=.ES(&1E("5S(&XG
M97-T(&%C8V5S<VEB;&4B"@HC.B!L:6(O87!I+G!H<#HS-#4@;&EB+V%P:2YP
M:'`Z-C(T"FUS9VED(").;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM
M<V=S='(@(D%U8W5N92!D;VYNZ64@:4-A;&5N9&%R('1R;W5VZ64N(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`Q"FUS9VED(").;R!R96-U<G)E
M;F-E(@IM<V=S='(@(E-A;G,@<NEPZ71I=&EO;B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.CDP,@IM<V=I9"`B3F\@=F%L:60@96UA:6P@861D<F5S<R!F;W5N
M9"(*;7-G<W1R(")!=6-U;F4@861R97-S92!D92!C;W5R<FEE<B!T<F]U=NEE
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C$R(&QI8B]+<F]N;VQI=&@N<&AP
M.C8S,PIM<V=I9"`B3F]N92(*;7-G<W1R(")!=6-U;F4B"@HC.B!L:6(O4W1O
M<F%G92]S<6PN<&AP.C$T-0IM<V=I9"`B3F]T(&9O=6YD(@IM<V=S='(@(DYO
M;B!T<F]U=NDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@
M(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`B3F]T:69I8V%T:6]N<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<X"FUS9VED(").;W9E;6)E
M<B(*;7-G<W1R(").;W9E;6)R92(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHU-@IM<V=I9"`B3F]W(@IM<V=S='(@(DUA:6YT96YA;G0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-PIM<V=I9"`B3V-T
M;V)E<B(*;7-G<W1R(")/8W1O8G)E(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(DQE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(W."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDQ"FUS
M9VED(")/;B!A;&P@8V%L96YD87)S($D@:&%V92!R96%D(&%C8V5S<R!T;R(*
M;7-G<W1R(")3=7(@=&]U<R!L97,@86=E;F1A<R!A=7AQ=65L<R!J)V%I(&%C
M8^AS(&5N(&QE8W1U<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<W
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3`*;7-G:60@(D]N(&%L;"!S:&]W
M;B!C86QE;F1A<G,B"FUS9W-T<B`B4W5R('1O=7,@;&5S(&%G96YD87,@869F
M:6-HZ7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.#D*;7-G:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY
M(@IM<V=S='(@(E-E=6QE;65N="!S=7(@;65S(&%G96YD87,B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HV,S`*;7-G:60@(D]P=&EO;F%L(@IM<V=S='(@(D]P
M=&EO;FYE;"(*"B,Z(&QI8B]&0E9I97<N<&AP.C$Q.0IM<V=I9"`B3W!T:6]N
M86P@071T96YD965S(@IM<V=S='(@(E!A<G1I8VEP86YT<R!O<'1I;VYN96QS
M(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,34T"FUS9VED(")/=F5R=FEE=R(*;7-G
M<W1R(")3>6YT:.AS92(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C,T
M"FUS9VED(")/=VYE<B(*;7-G<W1R(")0<F]P<FGI=&%I<F4B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ.#@R"B,L('!H<"UF;W)M870*;7-G:60@(D]W;F5R.B`E
M<R(*;7-G<W1R(")0<F]P<FGI=&%I<F6@.B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,3$T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3DT"FUS9VED(")032(*;7-G<W1R(")032(*"B,Z(&QI8B]";&]C:R]P<F5V
M;6]N=&AL:7-T+G!H<#HS(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HT
M,@IM<V=I9"`B4&%S="!%=F5N=',@3&ES="(*;7-G<W1R("),:7-T92!D97,@
MZ7;I;F5M96YT<R!P87-SZ7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,#D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DV"FUS9VED(")0871T
M97)N(@IM<V=S='(@(DUO=&EF(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N
M:6YC.C,P"FUS9VED(")097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\B
M"FUS9W-T<B`B169F86-E<B!C970@Z7;I;F5M96YT(&3I9FEN:71I=F5M96YT
MH#\B"@HC.B!L:6(O87!I+G!H<#HS,C8@;&EB+V%P:2YP:'`Z-#(R(&QI8B]A
M<&DN<&AP.C0Y-"!L:6(O87!I+G!H<#HU-S0*(SH@;&EB+V%P:2YP:'`Z-C`V
M(&QI8B]A<&DN<&AP.C8Y,B!L:6(O87!I+G!H<#HW,C@*;7-G:60@(E!E<FUI
M<W-I;VX@1&5N:65D(@IM<V=S='(@(D%U=&]R:7-A=&EO;B!R96IE=.EE(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W,`IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B1')O:71S(&0G86-CZ',B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*;7-G:60@(E!O<G1A;"!/<'1I;VYS
M(@IM<V=S='(@(D]P=&EO;G,@9'4@<WES=.AM92(*"B,Z(&QI8B]&0E9I97<O
M9&%Y+G!H<#HR-0IM<V=I9"`B4')E=FEO=7,@1&%Y(@IM<V=S='(@(DIO=7(@
M<'+I8^ED96YT(@H*(SH@;&EB+T9"5FEE=R]W965K+G!H<#HR-@IM<V=I9"`B
M4')E=FEO=7,@5V5E:R(*;7-G<W1R(")396UA:6YE('!RZ6/I9&5N=&4B"@HC
M.B!T96UP;&%T97,O9&%Y+VAE860N:6YC.C,*;7-G:60@(E!R979I;W5S(&1A
M>2(*;7-G<W1R(")*;W5R('!RZ6/I9&5N="(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-#D*;7-G
M:60@(E)E8W5R(%5N=&EL(@IM<V=S='(@(E+I<.ET97(@:G5S<74GX"(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$P-@IM<V=I9"`B4F5C=7)R96YC
M92(*;7-G<W1R(")2Z7#I=&ET:6]N(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@
M(E)E8W5R<F5N8V4@1&%T82(*;7-G<W1R(")$;VYNZ65S(&1E('+I<.ET:71I
M;VXB"@HC.B!D871A+G!H<#HV-@IM<V=I9"`B4F5C=7)R96YC92!%;F0@1&%T
M92(*;7-G<W1R(")$871E(&1E(&9I;B!D92!RZ7#I=&ET:6]N(@H*(SH@9&%T
M82YP:'`Z-C<*;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`B
M26YT97)V86QL92!D92!RZ7#I=&ET:6]N(@H*(SH@9&%T82YP:'`Z-C4*;7-G
M:60@(E)E8W5R<F5N8V4@5'EP92(*;7-G<W1R(")4>7!E(&1E('+I<.ET:71I
M;VXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#@*;7-G:60@(E)E8W5R<R!D
M86EL>2(*;7-G<W1R(")2Z7#I=&ET:6]N('%U;W1I9&EE;FYE(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z-34U"FUS9VED(")296-U<G,@;6]N=&AL>2(*;7-G
M<W1R(")2Z7#I=&ET:6]N(&UE;G-U96QL92(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C4U,0IM<V=I9"`B4F5C=7)S('=E96ML>2(*;7-G<W1R(")2Z7#I=&ET
M:6]N(&AE8F1O;6%D86ER92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4U.`IM
M<V=I9"`B4F5C=7)S('EE87)L>2(*;7-G<W1R(")2Z7#I=&ET:6]N(&%N;G5E
M;&QE(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296UI;F1E<CH@)7,B"FUS9W-T<B`B4F%P<&5L
MH#H@)7,B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M.30@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T"FUS9VED(")296UO=&4@0V%L
M96YD87)S(@IM<V=S='(@(D%G96YD87,@9&ES=&%N=',B"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z-C`@=&5M<&QA=&5S+VUE;G4N:6YC.C8R"FUS9VED(")2
M96UO=&4@0V%L96YD87)S.B(*;7-G<W1R(")!9V5N9&%S(&1I<W1A;G1SH#HB
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DT"FUS
M9VED(")296UO=&4@4W5B<V-R:7!T:6]N(%523"(*;7-G<W1R(")54DP@9&4@
M<V]U<V-R:7!T:6]N(&1I<W1A;G1E(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ-C$*;7-G:60@(E)E;6]V92(*;7-G<W1R(")2971I
M<F5R(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C4Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92`E<R(*;7-G<W1R(")2971I
M<F5R("5S(@H*(SH@871T96YD965S+G!H<#HQ,#`*;7-G:60@(E)E;6]V92!!
M='1E;F1E92(*;7-G<W1R(")2971I<F5R(&QE('!A<G1I8VEP86YT(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,0IM<V=I9"`B(@HB4F5P;&%C
M92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O<G1E9"!O;F4_(#QS
M=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E;G1R:65S(&EN
M('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SXB"FUS9W-T<B`B(@HB
M4F5M<&QA8V5R(&QE(&-A;&5N9')I97(@97AI<W1A;G0@<&%R(&PG:6UP;W)T
MZ:`_(#QS=')O;F<^079E<G1I<W-E;65N=*`Z("(*(F-E;&$@<W5P<')I;65R
M82!T;W5T97,@;&5S(&5N='+I97,@9&4@=F]T<F4@86=E;F1A(&-O=7)A;G0N
M/"]S=')O;F<^(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C,W"FUS9VED(")2
M97%U:7)E9"(*;7-G<W1R(")297%U:7,B"@HC.B!L:6(O1D)6:65W+G!H<#HY
M."!L:6(O1D)6:65W+G!H<#HQ,SD@;&EB+T9"5FEE=RYP:'`Z,30R(&QI8B]&
M0E9I97<N<&AP.C$T-0IM<V=I9"`B4F5Q=6ER960@071T96YD965S(@IM<V=S
M='(@(E!A<G1I8VEP86YT<R!R97%U:7,B"@HC.B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHS,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#@*;7-G:60@
M(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(E+I:6YI=&EA;&ES97(@875X
M('9A;&5U<G,@<&%R(&3I9F%U="(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHT,R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C8*
M;7-G:60@(E)E<W!O;G-E(@IM<V=S='(@(E+I<&]N<V4B"@HC.B!Y96%R+G!H
M<#HX-2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-"!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,C`*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ
M,#4*;7-G:60@(E-A(@IM<V=S='(@(E-A;2(*"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D+FEN8SHR,2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C`*(SH@
M=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S,*;7-G:60@(E-A='5R
M9&%Y(@IM<V=S='(@(E-A;65D:2(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHR,#,*;7-G:60@(E-A=F4B"FUS9W-T<B`B16YR96=I
M<W1R97(B"@HC.B!V:65W979E;G0N<&AP.C$S,R!E9&ET979E;G0N<&AP.C0Y
M(&5D:71E=F5N="YP:'`Z-3<*;7-G:60@(E-A=F4@07,@3F5W(@IM<V=S='(@
M(D5N<F5G:7-T<F5R(&5N('1A;G0@<75E(&YO=79E874B"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z.#,*;7-G:60@(E-A=F4@071T
M96YD965S(@IM<V=S='(@(D5N<F5G:7-T<F5R(&QE<R!P87)T:6-I<&%N=',B
M"@HC.B!A9&1E=F5N="YP:'`Z-34@961I=&5V96YT+G!H<#HU,@IM<V=I9"`B
M4V%V92!%=F5N="(*;7-G<W1R(")%;G)E9VES=')E<B!L)^EVZ6YE;65N="(*
M"B,Z('-E87)C:"YP:'`Z.3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C$Q-`HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M-C<@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C@*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-#4@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,C8*;7-G:60@(E-E87)C:"(*;7-G<W1R(")296-H97)C:&5R
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$*;7-G:60@
M(E-E87)C:"!#86QE;F1A<G,B"FUS9W-T<B`B4F5C:&5R8VAE<B!D86YS(&QE
M<R!A9V5N9&%S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C8*
M;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(E+I<W5L=&%T<R!D92!L
M82!R96-H97)C:&4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI
M;F,Z-@IM<V=I9"`B4V5A<F-H(&9O<B!C86QE;F1A<G,@8V]N=&%I;FEN9SHB
M"FUS9W-T<B`B4F5C:&5R8VAE<B!L97,@86=E;F1A<R!C;VYT96YA;G2@.B(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3,*;7-G
M:60@(E-E;&5C="!A(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`B4^EL96-T
M:6]N;F5Z('5N(&%G96YD82#@(.ED:71E<B(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(V-2!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN
M8SHS,0HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHX,PIM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")3Z6QE8W1I;VYN97H@=6YE
M(&1A=&4B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S`*;7-G:60@(E-E;&5C
M="!C86QE;F1A<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B4^EL96-T:6]N;F5Z
M(&QE<R!A9V5N9&%S(.`@869F:6-H97*@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,0IM<V=I9"`B(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I
M;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C
M:&]O<V4@(@HB9&5F875L="!V:65W+B(*;7-G<W1R("(B"B)3Z6QE8W1I;VX@
M9&5S(&]P=&EO;G,@9&4@8V]N9FER;6%T:6]N+"!D92!L82!F8>=O;B!D)V%F
M9FEC:&5R(&QE<R!D:69FZ7)E;G1S("(*(NEC<F%N<R!E="!C:&]I>"!D92!L
M82!V=64@<&%R(&3I9F%U="XB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$X"FUS9VED(")396QE8W0@=&AE(&-A;&5N9&%R('1O(&EM<&]R="!T
M;SHB"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&PG86=E;F1A(&1A;G,@;&5Q=65L
M(&EM<&]R=&5RH#HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$Y
M"FUS9VED(")396QE8W0@=&AE(&-A;&5N9&%R*',I('1O(&5X<&]R="!F<F]M
M(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L97,@86=E;F1A<R#@('!A<G1I<B!D
M97-Q=65L<R!E>'!O<G1E<B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,3(*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T
M<B`B4^EL96-T:6]N;F5Z(&QE(&9O<FUA="!D92!L)V5X<&]R=&%T:6]NH#HB
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(W"FUS9VED(")396QE
M8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@
M;&4@9FEC:&EE<B#@(&EM<&]R=&5RH#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`T"FUS9VED(")396QE8W0@=&AE(&9I<G-T('=E96MD87DZ(@IM
M<V=S='(@(DQA('-E;6%I;F4@8V]M;65N8V4@;&6@.B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T
M(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&QE
M(&9O<FUA="!D=2!F:6-H:65R('-O=7)C9:`Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T:6UE('-P86X@=&\@
M<VAO=SHB"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&QA('#I<FEO9&4@X"!A9F9I
M8VAE<J`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED(")3
M96QE8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O;B!S=&%R='5P.B(*;7-G<W1R
M(")3Z6QE8W1I;VYN97H@;&$@=G5E(.`@869F:6-H97(@;&]R<R!D92!L)V5N
M='+I92!D86YS(&PG87!P;&EC871I;VZ@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,@IM<V=I9"`B4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W
M(&EN('1H92!P;W)T86PN(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!Q=65L<R#I
M=NEN96UE;G1S(&%F9FEC:&5R(&1A;G,@;&4@<&]R=&%I;"XB"@HC.B!T96UP
M;&%T97,O9&5L971E+V]N92YI;F,Z,C<@=&5M<&QA=&5S+V1E;&5T92]D96QE
M=&4N:6YC.C(W"FUS9VED(")396YD(&$@8V%N8V5L(&YO=&EF:6-A=&EO;B!T
M;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@=&AI<R!E=F5N="(*;7-G
M<W1R("(B"B)%;G9O>65R('5N(&UE<W-A9V4@9"=A;FYU;&%T:6]N(.`@=&]U
M<R!L97,@<&%R=&EC:7!A;G1S(&QO<G,@9&4@;&$@(@HB<W5P<')E<W-I;VX@
M9&4@;"?I=NEN96UE;G0B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5N9"!A;B!E;6%I;"!T;R`E<R(*
M;7-G<W1R(")%;G9O>65R('5N(&-O=7)R:65R(.`@)7,B"@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHQ-SD*;7-G:60@(E-E;F0@=7!D871E<R]I;G9I
M=&%T:6]N<R!T;R!A;&P@871T96YD965S('=H96X@<V%V:6YG('1H:7,@979E
M;G0B"FUS9W-T<B`B(@HB16YV;WEE<B!U;F4@;6ES92#@(&IO=7(O:6YV:71A
M=&EO;B#@('1O=7,@;&5S('!A<G1I8VEP86YT<R!L;W)S(&1E("(*(FPG96YR
M96=I<W1R96UE;G0@9&4@;"?I=NEN96UE;G0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW-@IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@
M(E-E<'1E;6)R92(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C@S"FUS9VED(")3970@96YD(&1A=&4B"FUS9W-T<B`B4^EL96-T:6]N
M;F5Z(&QA(&1A=&4@9&4@9FEN(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C8U"FUS9VED(")3970@<F5C=7)R96YC92!E;F0@9&%T92(*;7-G<W1R
M(")3Z6QE8W1I;VYN97H@;&$@9&%T92!D92!L82!F:6X@9&4@;&$@<NEC=7)R
M96YC92(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q
M"FUS9VED(")3970@<W1A<G0@9&%T92(*;7-G<W1R(")3Z6QE8W1I;VYN97H@
M;&$@9&%T92!D92!DZ6)U="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.0IM<V=I9"`B(@HB4V5T('EO=7(@9G)E92]B=7-Y(&-A;&5N9&%R<R!A;F0@
M>6]U<B!O=VX@86YD(&]T:&5R('5S97)S)R!F<F5E+V)U<WD@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HB069F96-T97(@=F]S(&%G96YD87,@9&4@9&ES<&]N:6)I
M;&ETZ7,@970@;&5S(&]P=&EO;G,@9&4@9&ES<&]N:6)I;&ETZ7,@<&]U<B`B
M"B)V;W5S(&5T(&QE<R!A=71R97,@=71I;&ES871E=7)S+B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAA<F4@;F]T(&9O
M=6YD.B`E<R(*;7-G<W1R(")087)T86=E(&YO;B!T<F]U=NF@.B`E<R(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHX,@IM<V=I9"`B
M4VAA<F5D($-A;&5N9&%R<R(*;7-G<W1R(")!9V5N9&%S('!A<G1A9^ES(@H*
M(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C0W('1E;7!L871E<R]M96YU+FEN8SHT
M.0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R<SHB"FUS9W-T<B`B06=E;F1A<R!P
M87)T86?I<Z`Z(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H<#HR-2!T96UP;&%T
M97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC.B!T96UP;&%T97,O
M9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHS"FUS9VED(")3:&]W($-A;&5N
M9&%R(@IM<V=S='(@(D%F9FEC:&5R(&PG86=E;F1A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U-@IM<V=I9"`B4VAO=R!C871E9V]R>2!L96=E;F0_
M(@IM<V=S='(@(DUO;G1R97(@;&$@;.EG96YD92!D92!L82!C873I9V]R:66@
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(E-H;W<@
M9&5L971E+"!A;&%R;2P@86YD(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD
M87(@=FEE=W,_(@IM<V=S='(@(B(*(DUO;G1R97(@;&5S(&EC]&YE<R!D92!S
M=7!P<F5S<VEO;BP@9"=A;&%R;64@970@9&4@<NEPZ71I=&EO;B!D86YS(&QE
M<R!V=65S("(*(F1E(&PG86=E;F1AH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$R"FUS9VED(")3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD
M87(_(@IM<V=S='(@(D%F9FEC:&5R(&QE<R!TXF-H97,@X"!RZ6%L:7-E<B!D
M86YS(&PG86=E;F1AH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38V
M"FUS9VED(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S='(@(DUO;G1R
M97(@;&$@;.EG96YD92!D97,@9&ES<&]N:6)I;&ETZ7.@/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@(E-H;W<@;VYL>2!E=F5N=',@
M=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS9W-T<B`B3B=A9F9I8VAE<B!Q
M=64@;&5S(.EVZ6YE;65N=',@86-C;VUP86=NZ7,@9"=U;F4@86QE<G1EH#\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<U"FUS9VED(")3:&]W('-H
M87)E9"!C86QE;F1A<G,@<VED92UB>2US:61E/R(*;7-G<W1R(")!9F9I8VAE
M<B!L97,@86=E;F1A<R!P87)T86?I<R!C]'1E(.`@8_1T9:`_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B4VAO=R!T87-K<R!U<VEN
M9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(E5T:6QI<V5R(&QE<R!C;W5L
M975R<R!D97,@8V%TZ6=O<FEE<R!P;W5R(&QE<R!TXF-H97.@/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B4VAO=R!T:6UE(&]F(&1A
M>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_(@IM<V=S='(@(DUO
M;G1R97(@;"=H975R92!E;G1R92!C:&%C=6YE(&1E<R!J;W5R;NEE<R!D86YS
M(&QA('9U92!P87(@<V5M86EN9:`_(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,3$*;7-G:60@(E-T85]R="(*;7-G<W1R(")$Z6)?
M=70B"@HC.B!D871A+G!H<#HU-`IM<V=I9"`B4W1A<G0@1&%T92(*;7-G<W1R
M(")$871E(&1E(&3I8G5T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H
M96%D97)S+FEN8SHW('1E;7!L871E<R]V:65W+W9I97<N:6YC.C0Q"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S<*;7-G:60@(E-T87)T($]N(@IM
M<V=S='(@(D3I8G5T(&QE(@H*(SH@9&%T82YP:'`Z-34*;7-G:60@(E-T87)T
M(%1I;64B"FUS9W-T<B`B2&5U<F4@9&4@9.EB=70B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z.30@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z.#,*;7-G:60@(E-T871?=7,B"FUS9W-T<B`B4W1A=%]U="(*
M"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHR-PIM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(E-T871U="(*"B,Z('EE87(N<&AP.C<X('EE87(N<&AP.C@W('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C8U"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(R,2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-R!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$P.0IM<V=I9"`B4W4B"FUS9W-T<B`B1&EM(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H96%D
M+FEN8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA
M=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(D1I;6%N8VAE(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS9VED(")487-K<R(*;7-G
M<W1R(")4XF-H97,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.#4@;&EB+TMR
M;VYO;&ET:"YP:'`Z-C`X"FUS9VED(")496YT871I=F4B"FUS9W-T<B`B5&5N
M=&%T:79E(@H*(SH@>65A<BYP:'`Z.#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$X"B,Z(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")4:"(*;7-G<W1R(")*974B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C<P"FUS9VED
M(")4:&4@161I="!!='1E;F1E97,@<V-R965N(&ES(&YO(&QO;F=E<B!P<F5S
M96YT+B!%>&ET:6YG+B(*;7-G<W1R("(B"B),)^EC<F%N(&0GZ61I=&EO;B!D
M97,@<&%R=&EC:7!A;G1S(&XG97-T('!L=7,@<'+I<V5N="X@4V]R=&EE(&5N
M(&-O=7)S+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!C86YN;W0@8F4@9&5L971E9"XB
M"FUS9W-T<B`B4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92!L)V%G96YD82"K
MH"5SH+LN(@H*(SH@8V%L96YD87)S+G!H<#HT,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM
M<V=S='(@(DPG86=E;F1A(*N@)7.@NR!A(.ETZ2!C<NGI+B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),)V%G96YD82"K
MH"5SH+L@82#I=.D@<W5P<')I;>DN(@H*(SH@8V%L96YD87)S+G!H<#HU-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B
M965N(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("),)V%G96YD82"KH"5S
MH+L@82#I=.D@<F5N;VUMZ2"K("5S(+LN(@H*(SH@8V%L96YD87)S+G!H<#HU
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R("),)V%G96YD82"KH"5SH+L@82#I=.D@
M96YR96=I<W1RZ2XB"@HC.B!D871A+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM
M<V=S='(@(E!U<F=E(&EM<&]S<VEB;&4@9&4@;"=A9V5N9&&@.B"KH"5SH+LB
M"@HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@
M(E1H92!E;F0@9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A
M=&4N(@IM<V=S='(@(DQA(&1A=&4@9&4@9FEN(&1O:70@ZG1R92!P;W-TZ7)I
M975R92#@(&QA(&1A=&4@9&4@9.EB=70N(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@979E;G0@7"(E
M<UPB(&AA<R!B965N(&%D9&5D('1O(%PB)7-<(B!C86QE;F1A<BP@=VAI8V@@
M:7,@;VX@)7,@870@)7,N(@IM<V=S='(@(DPGZ7;I;F5M96YT(*N@)7.@NR!A
M(.ETZ2!A:F]U=.D@X"!L)V%G96YD82"K("5S(+LL(&QE("5S(.`@)7,N(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960@9G)O;2!<
M(B5S7"(@8V%L96YD87(L('=H:6-H('=A<R!O;B`E<R!A="`E(@HB<RXB"FUS
M9W-T<B`B(@HB3"?I=NEN96UE;G0@JZ`E<Z"[(&$@Z73I(')E=&ERZ2!D92!L
M)V%G96YD82"K("5S(+N@.R!I;"#I=&%I="!L92`E<R#@("5S+B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$Q,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!E9&ET960@;VX@7"(E<UPB(&-A
M;&5N9&%R+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B3"?I=NEN
M96UE;G0@JZ`E<Z"[(&$@Z73I(&TN(.`@:BX@9&%N<R!L)V%G96YD82"K("5S
M(+LL(&QE("5S(.`@)7,N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`X-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@;F]T:69I8V%T:6]N('1O
M("5S('=A<R!S=6-C97-S9G5L;'D@<V5N="XB"FUS9W-T<B`B3&$@;F]T:69I
M8V%T:6]N(&1E(&PGZ7;I;F5M96YT(.`@)7,@82!B:65N(.ETZ2!E;G9O>>EE
M+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-#0*;7-G:60@(E1H92!F;VQL
M;W=I;F<@:7,@82!M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E
M=F5N=#HB"FUS9W-T<B`B5F]I8VD@=6YE(&1E<V-R:7!T:6]N('!L=7,@9.ET
M86EL;.EE(&1E(&PGZ7;I;F5M96YTH#HB"@HC.B!A='1E;F0N<&AP.C0Q"FUS
M9VED("(B"B)4:&4@<F5Q=65S="!W87,@:6YC;VUP;&5T92X@4V]M92!P87)A
M;65T97)S('1H870@87)E(&YE8V5S<V%R>2!T;R!A8V-E<'0@;W(@(@HB9&5C
M;&EN92!A;B!E=F5N="!A<F4@;6ES<VEN9RXB"FUS9W-T<B`B(@HB3&$@<F5Q
M=>IT92#I=&%I="!I;F-O;7!LZ'1E+B!);"!M86YQ=64@8V5R=&%I;G,@<&%R
M86WH=')E<R!NZ6-E<W-A:7)E<R!P;W5R("(*(FPG86-C97!T871I;VX@;W4@
M;&4@<F5F=7,@9"=U;B#I=NEN96UE;G0N(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]E;7!T>2YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&5V96YT<R!M871C
M:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B075C=6X@Z7;I
M;F5M96YT(&YE(&-O<G)E<W!O;F0@874@<'+I<V5N="!C<FETZ')E+B(*"B,Z
M(&%D9&5V96YT86-T:6]N+G!H<#HQ."!E9&ET979E;G1A8W1I;VXN<&AP.C,U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8V-E
M<W-I;F<@=&AE(&-A;&5N9&%R.B`E<R(*;7-G<W1R(")5;F4@97)R975R(',G
M97-T('!R;V1U:71E(&QO<G,@9&4@;"=A8V/H<R#@(&PG86=E;F1AH#H@)7,B
M"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@979E;G0Z("5S(@IM
M<V=S='(@(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L)V%J
M;W5T(&1E(&PGZ7;I;F5M96YTH#H@)7,B"@HC.B!E9&ET979E;G1A8W1I;VXN
M<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!E9&ET:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B56YE(&5R<F5U<B!S
M)V5S="!P<F]D=6ET92!L;W)S(&1E(&PGZ61I=&EO;B!D92!L)^EVZ6YE;65N
M=*`Z("5S(@H*(SH@;&EB+V%P:2YP:'`Z,S,Y(&QI8B]A<&DN<&AP.C8Q.`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N(@IM<V=S='(@(E5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO
M<G,@9&4@;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE<R!I0V%L96YD87(N(@H*
M(SH@961I=&5V96YT86-T:6]N+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,B"FUS
M9W-T<B`B56YE(&5R<F5U<B!E<W0@87!P87)U92!L;W)S(&1U(&3I<&QA8V5M
M96YT(&1E(&PGZ7;I;F5M96YTH#H@)7,B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#DR"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<SH@)7,B"FUS
M9W-T<B`B56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I
M(&1E('9O=')E(&EN=FET871I;VX@X"`E<Z`Z("5S(@H*(SH@9&%T82YP:'`Z
M,3`X"FUS9VED(")4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N(@IM
M<V=S='(@(D%U8W5N(.EVZ6YE;65N="#@(&5X<&]R=&5R(&XG82#I=.D@=')O
M=7;I+B(*"B,Z(&1A=&$N<&AP.C$X-PIM<V=I9"`B5&AI<R!F:6QE(&9O<FUA
M="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")#92!F;W)M870@9&4@9FEC
M:&EE<B!N)V5S="!P87,@<')I<R!E;B!C;VUP=&4N(@H*(SH@9&%T82YP:'`Z
M,C4P"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("5S(@IM<V=S='(@(DQE('-E<G9E=7(@:6YD:7%U9:`Z("5S
M(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$Q.`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T
M+FEN8SHW,0IM<V=I9"`B5&AU<G-D87DB"FUS9W-T<B`B2F5U9&DB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S<*;7-G:60@(E1I;64@4W!?
M86XB"FUS9W-T<B`B4.ER:6]D92(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C0*;7-G:60@(E1I;64@<W!A;B(*;7-G<W1R(")$=7+I
M92(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHS
M-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHS.`IM<V=I9"`B5&ET7VQE(@IM
M<V=S='(@(E1I=%]R92(*"B,Z(&1A=&$N<&AP.C4S('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE
M861E<G,N:6YC.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I=')E(@H*(SH@
M;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R,B!L:6(O0FQO8VLO;6]N
M=&AL:7-T+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R-PIM
M<V=I9"`B5&]D87DB"FUS9W-T<B`B075J;W5R9"=H=6DB"@HC.B!L:6(O0FQO
M8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(T(&QI8B]";&]C:R]M;VYT:&QI<W0N
M<&AP.C$R,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(Y"FUS9VED(")4
M;VUO<G)O=R(*;7-G<W1R(")$96UA:6XB"@HC.B!Y96%R+G!H<#HX,2!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,"!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,38*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@
M(E1U(@IM<V=S='(@(DUA<B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN
M8SHQ-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,38*(SH@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-CD*;7-G:60@(E1U97-D87DB"FUS9W-T
M<B`B36%R9&DB"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G
M:60@(E1Y<&4B"FUS9W-T<B`B5'EP92(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O8V%L96YD87)S+FEN8SHQ.#8*;7-G:60@(E523"(*;7-G<W1R(")54DPB
M"@HC.B!L:6(O4W1O<F%G92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")#;VYN97AI;VX@874@
M<V5R=F5U<B!344P@:6UP;W-S:6)L92XB"@HC.B!C86QE;F1A<G,N<&AP.C@T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB
M.B`E<R(*;7-G<W1R(")3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E(*N@)7.@
MNZ`Z("5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R(")#:&%R9V5M96YT(&EM<&]S<VEB;&4@9&4@;&$@9.EF:6YI=&EO
M;B!D92`E<RXB"@HC.B!C86QE;F1A<G,N<&AP.C4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@7"(E<UPB.B`E<R(*;7-G<W1R("))
M;7!O<W-I8FQE(&1E(')E;F]M;65R(*N@)7.@NZ`Z("5S(@H*(SH@;&EB+U-T
M;W)A9V4O:V]L86(N<&AP.C,Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R971R:65V92!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S(@IM
M<V=S='(@(DEM<&]S<VEB;&4@9&4@<NEC=7#I<F5R(&QE<R!I;F9O<FUA=&EO
M;G,@9&4@9&ES<&]N:6)I;&ETZ7,@9&4@)7,B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ-0HC.B!S8W)I<'1S+W5P9W)A9&5S+S(P,#0M,#4M,3E?
M8V]N=F5R=%]C871E9V]R:65S7W1O7W-T<FEN9W,N<&AP.C4S"FUS9VED(")5
M;F9I;&5D(@IM<V=S='(@(DAO<G,@8V%TZ6=O<FEE(@H*(SH@;&EB+V%P:2YP
M:'`Z,S<W(&QI8B]A<&DN<&AP.C0V,2!L:6(O87!I+G!H<#HU,S<@;&EB+V%P
M:2YP:'`Z-C0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O
M;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B5'EP92!D92!C;VYT96YU(&YO;BUS
M=7!P;W)TZ:`Z("5S(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`S-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D.B`E<RXB"FUS9W-T<B`B36ES92#@
M(&IO=7*@.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I
M9"`B57-E<B!);G1E<F9A8V4B"FUS9W-T<B`B26YT97)F86-E('5T:6QI<V%T
M975R(@H*(SH@>65A<BYP:'`Z,38P('EE87(N<&AP.C$V-B!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$U.2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$V,@IM<V=I9"`B
M5FEE=R!$87DB"FUS9W-T<B`B5F]I<B!L92!J;W5R(@H*(SH@>65A<BYP:'`Z
M.#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C$@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C$W"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U
M"FUS9VED(")792(*;7-G<W1R(")-97(B"@HC.B!T96UP;&%T97,O;6]N=&@O
M:&5A9"YI;F,Z,3@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$W"B,Z('1E
M;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<P"FUS9VED(")7961N97-D
M87DB"FUS9W-T<B`B365R8W)E9&DB"@HC.B!A='1E;F1E97,N<&AP.C$P."!L
M:6(O2W)O;F]L:71H+G!H<#HQ,S$S(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP
M.C(S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*
M;7-G<W1R(")396UA:6YE(@H*(SH@;6]N=&@N<&AP.C$W-R!W;W)K=V5E:RYP
M:'`Z,S`@=V5E:RYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5E:R`E
M9"(*;7-G<W1R(")396UA:6YE("5D(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,X"FUS9VED(")7
M965K*',I(@IM<V=S='(@(E-E;6%I;F4H<RDB"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$R"FUS
M9VED(")7965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")(96)D;VUA9&%I
M<F6@.B!RZ7#I=&ET:6]N(&-H87%U92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C0*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W
M965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A<F4@;F\@;&%T97(@979E;G1S
M/R(*;7-G<W1R("(B"B)$97)N:>AR92!H975R92!S=7(@;&5S(.EC<F%N<R!D
M97,@:F]U<G,@970@9&5S('-E;6%I;F5S+"!Q=6%N9"!I;"!N)WD@82!P87,@
M(@HB9"?I=NEN96UE;G0@=6QTZ7)I975RH#\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$U"FUS9VED("(B"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A
M;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE
M<B!E=F5N=',_(@IM<V=S='(@(B(*(E!R96UIZ')E(&AE=7)E('-U<B!L97,@
MZ6-R86YS(&1E<R!J;W5R<R!E="!D97,@<V5M86EN97,L('%U86YD(&EL(&XG
M>2!A('!A<R`B"B)D)^EVZ6YE;65N="!A;G3I<FEE=7*@/R(*"B,Z(&%T=&5N
M9&5E<RYP:'`Z,3`W(&QI8B]+<F]N;VQI=&@N<&AP.C$S,3(@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T
M"FUS9VED(")7;W)K(%=E96LB"FUS9W-T<B`B4V5M86EN92!O=79R86)L92(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,34@;&EB+T)L;V-K+W1R965?;65N
M=2YP:'`Z,C4*;7-G:60@(EEE87(B"FUS9W-T<B`B06YNZ64B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C,X"FUS9VED(")996%R;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")!
M;FYU96QL96UE;G2@.B!RZ7#I=&ET:6]N(&-H87%U92(*"B,Z(&1A=&$N<&AP
M.C,Y(&1A=&$N<&AP.C(S.2!E9&ET979E;G1A8W1I;VXN<&AP.C0V(&%D9&5V
M96YT+G!H<#HQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@979E;G1S+B(*;7-G<W1R
M(")6;W5S(&XGZG1E<R!P87,@875T;W)I<^D@X"!C<NEE<B!P;'5S(&1E("5D
M(.EVZ6YE;65N=',N(@H*(SH@871T96YD+G!H<#HT.0IM<V=I9"`B66]U(&%R
M92!N;W0@86X@871T96YD964@;V8@=&AE('-P96-I9FEE9"!E=F5N="XB"FUS
M9W-T<B`B5F]U<R!N)^IT97,@<&%S('5N(&1E<R!P87)T:6-I<&%N=',@X"!L
M)^EVZ6YE;65N="!S<.EC:69IZ2XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C<V"FUS9VED(")9;W4@8V%N(&]N;'D@=7-E('1H:7,@
M9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN(@IM<V=S='(@
M(B(*(D-E(&9O<FUU;&%I<F4@;F4@<&5U="#J=')E('5T:6QI<^D@<75E(&1E
M<'5I<R!L)^EC<F%N(&0GZ61I=&EO;B!D97,@(@HB<&%R=&EC:7!A;G1S+B`B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HY.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U(&1O(&YO="!H879E(&%N(&5M86EL(&%D9')E<W,@8V]N9FEG
M=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T:6]N("(*(D]P=&EO;G,N
M(%EO=2!M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F;W)E(&5V96YT(&YO=&EF
M:6-A=&EO;G,@8V%N(&)E('-E;G0N(@IM<V=S='(@(B(*(D%U8W5N92!A9')E
M<W-E(&1E(&-O=7)R:65L(&XG97-T(&-O;F9I9W5RZ64@9&%N<R!V;W1R92!P
M<F]F:6PN(%9O=7,@9&5V97H@96X@(@HB9.EF:6YI<B!U;F4@)7-I8VDE<R!A
M=F%N="!Q=64@9&5S(&YO=&EF:6-A=&EO;G,@9"?I=NEN96UE;G1S('!U:7-S
M96YT(.IT<F4@(@HB96YV;WGI97,N(@H*(SH@861D979E;G1A8W1I;VXN<&AP
M.C(P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M
M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S='(@(E9O=7,@;B=A
M=F5Z('!A<R!L)V%U=&]R:7-A=&EO;B!D)V%J;W5T97(@9&5S(.EVZ6YE;65N
M=',@X"`E<RXB"@HC.B!D871A+G!H<#HQ.3<*;7-G:60@(EEO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@=&AE('-E;&5C=&5D
M(&-A;&5N9&%R+B(*;7-G<W1R("(B"B)6;W5S(&XG879E>B!P87,@;"=A=71O
M<FES871I;VX@9"=A:F]U=&5R(&1E<R#I=NEN96UE;G1S(.`@;"=A9V5N9&$@
M(@HB<^EL96-T:6]N;NDN(@H*(SH@9&5L979E;G1A8W1I;VXN<&AP.C(V"FUS
M9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!D96QE=&4@=&AI
M<R!E=F5N="XB"FUS9W-T<B`B5F]U<R!N)V%V97H@<&%S(&PG875T;W)I<V%T
M:6]N(&1E('-U<'!R:6UE<B!C970@Z7;I;F5M96YT+B(*"B,Z(&5D:71E=F5N
M=&%C=&EO;BYP:'`Z-S@*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S
M:6]N('1O(&5D:70@=&AI<R!E=F5N="XB"FUS9W-T<B`B5F]U<R!N)V%V97H@
M<&%S(&PG875T;W)I<V%T:6]N(&1E(&UO9&EF:65R(&-E="#I=NEN96UE;G0N
M(@H*(SH@9&%T82YP:'`Z,3DR"FUS9VED(")9;W4@:&%V92!S<&5C:69I960@
M86X@:6YV86QI9"!C86QE;F1A<BXB"FUS9W-T<B`B5F]U<R!A=F5Z(&EN9&EQ
M=>D@=6X@86=E;F1A(&EN=F%L:61E+B(*"B,Z(&%T=&5N9"YP:'`Z,C$*;7-G
M:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E;F1E;F-E
M('1O('1H:7,@979E;G0N(@IM<V=S='(@(E9O=7,@879E>B!A8V-E<'3I(&1E
M('!A<G1I8VEP97(@X"!C970@Z7;I;F5M96YT+B(*"B,Z(&%T=&5N9"YP:'`Z
M,C8*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E
M;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(E9O=7,@879E>B!R969U
M<^D@9&4@<&%R=&EC:7!E<B#@(&-E="#I=NEN96UE;G0N(@H*(SH@871T96YD
M+G!H<#HS,0IM<V=I9"`B66]U(&AA=F4@=&5N=&%T:79E;'D@86-C97!T960@
M871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R(")6;W5S(&%V97H@
M86-C97!TZ2!D92!P87)T:6-I<&5R(.`@8V5T(.EVZ6YE;65N="!A=F5C(&1E
M<R!RZ7-E<G9E<RXB"@HC.B!C86QE;F1A<G,N<&AP.CDQ"FUS9VED(")9;W4@
M;75S="!S96QE8W0@82!C86QE;F1A<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R
M("));"!F875T(&0G86)O<F0@<^EL96-T:6]N;F5R(&PG86=E;F1A(.`@<W5P
M<')I;65R+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M-30*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*
M;7-G<W1R("));"!F875T(&0G86)O<F0@<^EL96-T:6]N;F5R('5N92!A9')E
M<W-E+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,30*;7-G:60@(EEO=2!R
M97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&%D9&5D
M('1O('EO=7(@8V%L96YD87)S+B(*;7-G<W1R(")6;W5S(&%V97H@9&5M86YD
MZ2#@(.IT<F4@879E<G1I(&1E<R#I=NEN96UE;G1S(&%J;W5TZ7,@X"!V;W,@
M86=E;F1A+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,C0*;7-G:60@(B(*
M(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E
M(&1E;&5T960@9G)O;2!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@HB5F]U
M<R!A=F5Z(&1E;6%N9.D@X"#J=')E(&%V97)T:2!D92!L82!S=7!P<F5S<VEO
M;B!D)^EVZ6YE;65N=',@9&%N<R!V;W,@(@HB86=E;F1A<RXB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,3$Y"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E
M(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET960@:6X@>6]U<B!C86QE
M;F1A<G,N(@IM<V=S='(@(B(*(E9O=7,@879E>B!D96UA;F3I(.`@ZG1R92!N
M;W1I9FGI(&1E(&QA(&TN(.`@:BX@9"?I=NEN96UE;G1S(&1A;G,@=F]S(&%G
M96YD87,N(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(')E;6EN
M9&5D(&%B;W5T("5S+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B
M5F]U<R!A=F5Z(&1E;6%N9.D@;&4@<F%P<&5L(&1E("5S+"!L92`E<R#@("5S
M+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*;7-G
M:60@(EEO=7(@9&5F875L="!C86QE;F1A<B(*;7-G<W1R(")6;W1R92!A9V5N
M9&$@<&%R(&3I9F%U="(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-C$@;&EB+T1R
M:79E<BYP:'`Z,3`W,0IM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@
M(EO)=NEN96UE;G0@<V%N<R!N;VU=(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z.34*;7-G:60@(E]!;&%R;2(*;7-G<W1R(")?06QE<G1E(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q"FUS9VED
M(")?0F%S:6,@4V5A<F-H(@IM<V=S='(@(E]296-H97)C:&4@<VEM<&QE(@H*
M(SH@=FEE=V5V96YT+G!H<#HQ,S4*;7-G:60@(E]%9&ET(@IM<V=S='(@(LED
M:71?97(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S4P"FUS9VED(")?1V]T
M;R(*;7-G<W1R(")!;&QE7W(@X"(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M-38*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(E]);7!O<G1E<B]%
M>'!O<G1E<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S<*;7-G:60@(E]-
M>2!#86QE;F1A<G,B"FUS9W-T<B`B7TUE<R!A9V5N9&%S(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,T-`IM<V=I9"`B7TYE=R!%=F5N="(*;7-G<W1R(")?
M3F]U=F5L(.EVZ6YE;65N="(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-C$*
M;7-G:60@(E]0<FEN="(*;7-G<W1R("));5]P<FEM97(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,S4R"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E]296-H
M97)C:&4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S0W"FUS9VED(")?5&]D
M87DB"FUS9W-T<B`B075?:F]U<F0G:'5I(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,30P"FUS9VED(")B969O<F4@=&AE(&5V96YT('-T87)T<R(*
M;7-G<W1R(")A=F%N="!L92!DZ6)U="!D92!L)^EVZ6YE;65N="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G<W1R(")J
M;W5R(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(P-PIM<V=I9"`B9&%Y*',I(@IM<V=S='(@(FIO
M=7(H<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.#<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Y"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(F1A>7,B"FUS9W-T<B`B:F]U<G,B"@HC.B!D
M871A+G!H<#HQ-3`@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ"FUS9VED
M(")E=F5N=',N8W-V(@IM<V=S='(@(F5V96YT<RYC<W8B"@HC.B!D871A+G!H
M<#HQ-S$*;7-G:60@(F5V96YT<RYI8W,B"FUS9W-T<B`B979E;G1S+FEC<R(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3,V"FUS9VED
M(")I;B(*;7-G<W1R(")D86YS(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,C<@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C,S"FUS9VED(")M;VYT:"AS*2(*;7-G<W1R(")M;VES(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")O;B`E<R!A
M="`E<R(*;7-G<W1R(")L92`E<R#@("5S(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-PIM<V=I
M9"`B;VX@=&AE('-A;64@9&%T92(*;7-G<W1R("+@(&QA(&WJ;64@9&%T92(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,S,*;7-G:60@(F]N('1H92!S86UE('=E96MD87DB"FUS
M9W-T<B`B;&4@;>IM92!J;W5R(&1E(&QA('-E;6%I;F4B"@HC.B!D871A+G!H
M<#HR.2!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T"FUS9VED(")V0V%L
M96YD87(O:4-A;&5N9&%R(@IM<V=S='(@(G9#86QE;F1A<B]I0V%L96YD87(B
M"@HC.B!L:6(O87!I+G!H<#HS-3`@;&EB+V%P:2YP:'`Z-C(Y"FUS9VED(")V
M179E;G0@;F]T(&9O=6YD+B(*;7-G<W1R(")VR7;I;F5M96YT(&YO;B!T<F]U
M=NDN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,0IM<V=I9"`B=V5E
M:R(*;7-G<W1R(")S96UA:6YE(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q-`IM<V=I9"`B=V5E
M:RAS*2!O;CHB"FUS9W-T<B`B<V5M86EN92AS*2P@;&6@.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.3(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DT"FUS9VED(")W965K<R(*
M;7-G<W1R(")S96UA:6YE<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,SD*;7-G:60@(GEE87(H
M<RDB"FUS9W-T<B`B86YNZ64H<RDB"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K
M<F]N;VQI=&@O<&\O87)?4UDN<&\`````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,3(Q,S`W`#$P-#$W,S8R-S4S`#`R,#0S,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C($MR;VYO;&ET
M:"`Q+C$@07)A8FEC('1R86YS;&%T:6]N"B,@5&AI<R!F:6QE(&ES(&1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($MR;VYO;&ET
M:"!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@,C`P,R!0;&%T:6YU;2!);F,N
M(#QP;$!T:6YU;2YI;F9O/@HC($-U<W1O;2!796(@07!P;&EC871I;VYS(#QH
M='1P.B\O<&QA=&EN=6TM<WDN8V]M/@HC(%!L871I;G5M($1E=F5L;W!M96YT
M(%1E86T@/&1E=G1E86U`<&QA=&EN=6TM<WDN8V]M/B`R,#`S"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`Q
M+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`S+3`T+3,P(#$R.C`P*S`R
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@(%!L871I;G5M($1E=F5L;W!M96YT
M(%1E86T@/&1E=G1E86U`<&QA=&EN=6TM<WDN8V]M/EQN(@HB3&%N9W5A9V4M
M5&5A;3H@07)A8FEC(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M
M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]0U`Q,C4V7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`^
M(#$I.UQN(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&-A;&5N9&%R<R!F;W5N9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@979E;G1S(@IM<V=S='(@(LSC
M[=H@Q^'#S<_'RR(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!$87DH<RD@)7,@2&]U
M<BAS*2`E<R!-:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$W.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@871T96YD965S(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R("(E<R#*XR#'
MT\KMT<?/(,?AX^'=(,CDS,?-(@H*(SH@8V%L96YD87)S+G!H<#HQ,#4@;&EB
M+V)A<V4N<&AP.C$R.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!#86QE;F1A<B(*;7-G<W1R("+*U<_MT2#'X</,Y,_)(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$W"FUS9VED("(B"B(H0VQI8VL@
M;VX@8V%L96YD87(@;F%M92!T;R!S=VET8V@@=&AE(&-A;&5N9&%R)W,@=FES
M:6)I;&ET>2!I;B!T:&4@;6%I;B`B"B)W:6YD;W<I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38T"FUS9VED("(J
M($%D9"!T:&5S92!B>2!C;&EC:VEN9R!!9&0@*B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$U,`IM<V=I9"`B*B!0
M;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<X-@IM<V=I9"`B,2!A='1E;F1E92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM
M<V=I9"`B,2!E=F5N="(*;7-G<W1R("+,X^W:(,?AP\W/Q\LB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,W"B,L(&9U>GIY"FUS9VED("(Q(&AO=7(B
M"FUS9W-T<B`B)60@T\?:R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S0*(RP@9G5Z>GD*;7-G:60@(C$U(&UI;G5T97,B"FUS9W-T<B`B)60@S]['
MQMXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"B,L(&9U>GIY"FUS
M9VED("(R,"!M:6YU=&5S(@IM<V=S='(@(B5D(,_>Q\;>(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-@HC+"!F=7IZ>0IM<V=I9"`B,S`@;6EN=71E
M<R(*;7-G<W1R("(E9"#/WL?&WB(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C$W,0HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY!='1E;F1E97,\+W-T
M<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\8C['X=_AX\?*(,?AX]W*Q\WM
MR3PO8CX@*,?.RNW'T>TI(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,30Y"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/D1E<V-R:5]P=&EO;CPO<W1R
M;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/L?AYM7=/"]B/B`HQ\[*[<?1
M[2DB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-S<*(RP@9G5Z>GD*
M;7-G:60@(CQS=')O;F<^2V5Y=V]R9',\+W-T<F]N9SX@*&]P=&EO;F%L*2(*
M;7-G<W1R("(\8C['X=_AX\?*(,?AX]W*Q\WMR3PO8CX@*,?.RNW'T>TI(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DT"B,L(&9U>GIY"FUS9VED
M("(\<W1R;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G
M<W1R("(\8C['X<K?T<?1/"]B/B`@*,?.RNW'T>TI(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ,#$@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ.#$*;7-G:60@(D%-(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C4Y,0IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9%]V86YC960@4V5A
M<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,38Q('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP
M"FUS9VED(")!9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C8*;7-G:60@(D%D9"!%=F5N="(*;7-G<W1R("+%UL?=R2#-S\LB
M"@HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN
M8SHS-0HC+"!F=7IZ>0IM<V=I9"`B061D(&$@;F5W(%)E;6]T92!#86QE;F1A
M<B(*;7-G<W1R("+%UL?=R2#-S\L@S,_MSR(*"B,Z(&%D9&5V96YT+G!H<#HV
M-`IM<V=I9"`B061D(&$@;F5W(&5V96YT(@IM<V=S='(@(L76Q]W)(,W/RR#,
MS^W/(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C<T
M"FUS9VED(")!9&0@871T96YD965S(@IM<V=S='(@(B(*"B,Z(&-O;G1A8W1S
M+G!H<#HW-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$R,`HC
M.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-S@*;7-G:60@
M(D%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z."!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z,3$*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU,PIM<V=I9"`B06QA<FTB"FUS
M9W-T<B`BRN3([>4B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8T"B,L('!H<"UF
M;W)M870*;7-G:60@(D%L87)M("5D(&1A>7,@8F5F;W)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$W-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M06QA<FT@)60@:&]U<G,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%L87)M
M("5D(&UI;G5T97,@8F5F;W)E(@IM<V=S='(@(B5S(,_>Q\;>(-[(X2(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$W-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA
M<FT@)60@=V5E:W,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$W-C,*;7-G:60@(D%L87)M(#$@9&%Y(&)E9F]R92(*;7-G<W1R("(B
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8X"FUS9VED(")!;&%R;2`Q(&AO=7(@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S,*(RP@
M9G5Z>GD*;7-G:60@(D%L87)M(#$@;6EN=71E(&)E9F]R92(*;7-G<W1R("(E
M<R#/WL?&WB#>R.$B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S4X"FUS9VED(")!
M;&%R;2`Q('=E96L@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C8P
M"FUS9VED(")!;&%R;2!$871E(@IM<V=S='(@(LK'T>W.(,?ARN3([>4B"@HC
M.B!D871A+G!H<#HU.0IM<V=I9"`B06QA<FT@4W!A;B`H;6EN=71E<RDB"FUS
M9W-T<B`BX\_)(,?ARN3([>4@*,C'X<_>Q\;>*2(*"B,Z(&1A=&$N<&AP.C8Q
M"FUS9VED(")!;&%R;2!4:6UE(@IM<V=S='(@(M+CY"#'X<KDR.WE(@H*(SH@
M=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,Q"FUS9VED(")!;&PB"FUS
M9W-T<B`BQ^',X^W:(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,3(V(&QI8B]&0E9I
M97<N<&AP.C$R.2!L:6(O1D)6:65W+G!H<#HQ,S(*(RP@9G5Z>GD*;7-G:60@
M(D%L;"!!='1E;F1E97,B"FUS9W-T<B`BS./MVB#'X</-S\?+(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4Y"B,L(&9U>GIY"FUS9VED(")!
M;&P@1G5T=7)E(@IM<V=S='(@(N/3RM[(X<?P(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C4S"B,L(&9U>GIY"FUS9VED(")!;&P@4&%S="(*
M;7-G<W1R("+?X2#'X>WFXR(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T
M+G!H<#HR-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C(T"B,Z(&QI8B]";&]C:R]M
M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I
M9"`B06QL(%9I<VEB;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I=%]T:6UE<W!A;BYI;F,Z,3(R(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O
M1&%Y5FEE=RYP:'`Z.3,*(SH@;&EB+U=E96M6:65W+G!H<#HQ,C<@;&EB+U=E
M96M6:65W+G!H<#HQ,S0@;&EB+T1R:79E<BYP:'`Z,3@S,@IM<V=I9"`B06QL
M(&1A>2(*;7-G<W1R("+?X2#'X>WFXR(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@979E;G0B"FUS9W-T<B`BS./MVB##
MS<_'RR#'X>WFXR(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*
M;7-G:60@(D%L;"!E=F5N=',B"FUS9W-T<B`BS./MVB#'X</-S\?+(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O2W)O
M;F]L:71H+G!H<#HV.#,*;7-G:60@(D%N>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,0IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`BY.W3Q^0B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N
M+FEN8SHS.2!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHY,PHC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C<P('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,34V"FUS9VED(")!="(*;7-G<W1R("+=[2(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P,C8*;7-G:60@(B(*(D%T=&%C:&5D(&ES(&%N
M(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T
M:&4@979E;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I
M<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P
M9&%T92`B"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#(@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E;F1A;F-E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V,0IM
M<V=I9"`B071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`BPL@B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C@*;7-G:60@(D)A<VEC(%-E
M87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z
M,3<*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(MKMSR#C[>''SR(*"B,Z(&QI
M8B]&0E9I97<N<&AP.CDP(&QI8B]&0E9I97<N<&AP.C$Q,`IM<V=I9"`B0G5S
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(D-?86QE;F1A<B(*;7-G<W1R
M("+'T\KMT<?/(,CMQ^3'RB#'X</,Y,_)(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z-#D*(RP@9G5Z>GD*;7-G:60@(D-A;%]E;F1A<B(*;7-G<W1R
M("+'T\KMT<?/(,CMQ^3'RB#'X</,Y,_)(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C$T-B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES
M="YP:'`Z,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HR,2!L:6(O0FQO8VLO
M;6]N=&AL:7-T+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(RP@
M9G5Z>GD*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(L?3RNW1Q\\@R.W'Y,?*
M(,?AP\SDS\DB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PHC+"!F=7IZ
M>0IM<V=I9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G<W1R("+'X<KASNW5(@H*
M(SH@9&%T82YP:'`Z,C(X"B,L(&9U>GIY"FUS9VED(")#86QE;F1A<B!S=6-C
M97-S9G5L;'D@<'5R9V5D+B(*;7-G<W1R("+*XR#'T\KMT<?/(,?AX^'=(,CD
MS,?-(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4W"B,L(&9U>GIY"FUS9VED(")#86QE;F1A
M<G,B"FUS9W-T<B`BQ]/*[=''SR#([<?DQ\H@Q^'#S.3/R2(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z,C<*;7-G:60@(D-A;&5N9&%R<R!M=7-T(&AA=F4@82!N86UE
M+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-#,*(RP@9G5Z>GD*;7-G:60@
M(D-A;B=T(&-R96%T92!A(&YE=R!E=F5N="XB"FUS9W-T<B`BQ>34Q\$@S<_+
M(,S/[<\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y
M,2!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,S`*(SH@=&5M<&QA=&5S+V1E
M;&5T92]D96QE=&4N:6YC.C,R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,P.0IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(L7AV\?!(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<P"B,L
M(&9U>GIY"FUS9VED(")#86YC96QL960B"FUS9W-T<B`BQ>';Q\$B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,#`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YC96QL960Z("5S(@IM<V=S='(@(L7AV\?!(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C8T('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C8Y"B,L(&9U>GIY"FUS9VED(")#871E9V]R7WDB"FUS
M9W-T<B`BRM7D[=TB"@HC.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H
M+V5V96YT7VAE861E<G,N:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3,*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(LK5Y.W=(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(W.0IM<V=I9"`B(@HB0VAO;W-E(&EF('EO=2!W
M86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E
M9"!E=F5N=',@8GD@(@HB96UA:6PZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O
M(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N
M=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96%R8VA?86)O
M;VM?<V5L96-T+FEN8SHQ.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDY"FUS
M9VED(")#:&]O<V4@=&AE(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H(&9O<B!F
M<F5E+V)U<WD@55),<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V9B7V-A;'-?<V5L96-T+FEN8SHQ-@IM<V=I9"`B0VAO;W-E('1H92!C86QE
M;F1A<G,@=&\@:6YC;'5D92!I;B!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO
M;CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,0IM
M<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!W:&5N(&=E
M;F5R871I;F<@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L
M="!C86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E
M<R]A='1E;F1E97,N:6YC.C8U"FUS9VED(")#;&5A<B!A;&P@871T96YD965S
M(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(X('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S"FUS9VED(")#
M;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\B"FUS9W-T<B`BRL/?[<\@S=#=
M(,?AP\W/Q\N_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-38W"B,L(&9U>GIY
M"FUS9VED(")#;VYF:7)M960B"FUS9W-T<B`BV^W1(./:T=TB"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C`X"FUS9VED(")#;W!Y
M('1H92!54DP@8F5L;W<@9F]R('5S92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R
M($9R964O0G5S>2!54DPZ(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$R-@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(@IM<V=S='(@(L?A
MS<?A[2(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ
M,3(*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!#86QE;F1A<B(*;7-G<W1R("+'
MT\KMT<?/(,CMQ^3'RB#'X</,Y,_)(@H*(SH@;6]N=&@N<&AP.C$V-2!T96UP
M;&%T97,O=V5E:R]H96%D+FEN8SHR-2!T96UP;&%T97,O9&%Y+W)O=RYI;F,Z
M-@HC.B!L:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.C$Y-`IM
M<V=I9"`B0W)E871E(&$@3F5W($5V96YT(@IM<V=S='(@(L7DU,?!(,W/RR#,
MS^W/(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#`*;7-G:60@(D-R
M96%T960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N
M:6YC.C(Y"FUS9VED(")#=7)R96YT(@IM<V=S='(@(L?AS<?A[2(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,#D*;7-G:60@(D1A:6QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B
M[>;C[<?P.B#*W]''T2#?X2(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$P(&QI8B]+
M<F]N;VQI=&@N<&AP.C$R.#@@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"FUS9VED(")$87DB"FUS9W-T
M<B`B[>;C(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3,Y"FUS9VED(")$87DH<RDB"FUS9W-T<B`B
M[>;C("C#[<?C*2(*"B,Z('9I97=E=F5N="YP:'`Z,3`T"B,L(&9U>GIY"FUS
M9VED(")$95]L971E(@IM<V=S='(@(LW0W2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C<Y"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("+?
MQ^3FY"#'X</FX2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4Y-`IM<V=I9"`B
M1&5C;&EN960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-A;&5N9&%R(@IM<V=S='(@
M(L?3RNW1Q\\@R.W'Y,?*(,?AP\SDS\DB"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,3DS('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,3@Q"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR.2!T
M96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHR,PHC
M.B!L:6(O1')I=F5R+G!H<#HQ.#$S"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
MS=#=(@H*(SH@9&5L979E;G0N<&AP.C0P('1E;7!L871E<R]D96QE=&4O;VYE
M+FEN8SHQ."!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,3@*(SH@;&EB
M+T1R:79E<BYP:'`Z,3@Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M)7,B"FUS9W-T<B`BS=#=("5S(@H*(SH@961I=&5V96YT+G!H<#HW,`IM<V=I
M9"`B1&5L971E($5V96YT(@IM<V=S='(@(LW0W2#'X<W/RR(*"B,Z('1E;7!L
M871E<R]D96QE=&4O9&5L971E+FEN8SHR-PIM<V=I9"`B(@HB1&5L971E('1H
M92!C=7)R96YT(&5V96YT(&]N;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL
M(&9U='5R92!O8V-U<F5N8V5S+"!O<B`B"B)A;&P@;V-C=7)E;F-E<S\B"FUS
M9W-T<B`B(@HBS=#=(,?AS<_+(,?AS<?A[2`@W=[8(*$@Y=#E(,?AX]')(.;'
MX>/1Q\H@Q^'>Q\_CR2##YL/F(,SC[=H@Q^'CT<?*(,?ARL?A[<F_(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$P-"!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C@*(RP@9G5Z>GD*;7-G:60@(D1E
M<V-R:5]P=&EO;B(*;7-G<W1R("+'X=31S2(*"B,Z(&1A=&$N<&AP.C8R('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S4*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z.38*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(L?AU-'-(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ-S,*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`BQ=GEQ]$@
MQ^'.[<?1Q\HB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@0V%L96YD87)S(@IM<V=S
M='(@(L79Y<?1(,?ASNW'T<?*(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(L79Y<?1
M(,?ASNW'T<?*(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED
M(")$;R!Y;W4@=V%N="!T;R!S:&]W('1A<VMS('=H:6-H(&%R92!D=64@;VX@
M>6]U<B!C86QE;F1A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-3,W"FUS9VED(")$;V5S(&YO="!R96-U<B(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HS,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1'5E
M.B`E<R(*;7-G<W1R("+'T\K-WL?>.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T
M<B`BQ^'=RM')(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$W,"!L:6(O1')I=F5R+G!H<#HQ.#`V"FUS9VED(")%9&ET(@IM<V=S
M='(@(LED:71E<B(*"B,Z(&5D:71E=F5N="YP:'`Z,S,@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C8@;&EB+T1R:79E<BYP:'`Z,3@P-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@(LK-T>W1("5S(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3@W"FUS9VED(")%9&ET($%T=&5N9&5E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,30P"B,L(&9U>GIY"FUS9VED(")%9&ET($-A;&5N9&%R<R(*;7-G
M<W1R("+*U<_MT2#'X</,Y,_)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U,`HC+"!F=7IZ>0IM<V=I9"`B161I="!296UO=&4@0V%L96YD87)S(@IM
M<V=S='(@(L?3RNW1Q\\@R.W'Y,?*(,?AP\SDS\DB"@HC.B!A='1E;F1E97,N
M<&AP.C$U,`IM<V=I9"`B161I="!A='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N9"YI;F,Z,C`*;7-G:60@(D5D:70@
M8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E<R]A='1E;F1E
M97,O871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-C`*(RP@9G5Z>GD*;7-G
M:60@(D5N7V0B"FUS9W-T<B`BRN3*Y>T@R,K'T>W-(@H*(SH@9&%T82YP:'`Z
M-3<*;7-G:60@(D5N9"!$871E(@IM<V=S='(@(LK'T>W.(,?AQ>3*Y<?!(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHX('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,3`X"FUS9VED(")%;F0@3VXB"FUS9W-T<B`BRN3*Y>T@R,K'T>W-
M(@H*(SH@9&%T82YP:'`Z-3@*;7-G:60@(D5N9"!4:6UE(@IM<V=S='(@(LKF
MWNW*(,?AQ>3*Y<?!(@H*(SH@871T96YD965S+G!H<#HQ,C0@871T96YD965S
M+G!H<#HQ,S4@871T96YD965S+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@<F5T<FEE=FEN9R!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R
M("5S.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DS
M"FUS9VED(")%=F5N="!A9&1E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3$P,PIM<V=I9"`B179E;G0@9&5L971E9#HB"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y.`IM<V=I9"`B179E;G0@961I
M=&5D.B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#8V"B,L('!H
M<"UF;W)M870*;7-G:60@(D5V96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S8T"B,L(&9U>GIY"FUS9VED(")%=F5N
M=',@;75S="!H879E(&$@<W1A<G0@9&%T92XB"FUS9W-T<B`B[<S((,/D(.W?
MYN0@RL?1[<X@Q^'DY<?MR2#CRL/.T<?P(-KD(,K'T>W.(,?AR,_'[<DB"@HC
M.B!L:6(O1')I=F5R+G!H<#HW,S`*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@
M82!T:71L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S8W"FUS
M9VED(")%=F5N=',@;75S="!H879E(&%N(&5N9"!D871E(&]R(&$@9'5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD
M965S+FEN8SHW.0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD($YA;65S(@IM<V=S
M='(@(LKFWNW*(,?AQ>3*Y<?!(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ.#<*;7-G:60@(D5X<&]R="(*;7-G<W1R("+*U<_MT2(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z.`IM<V=I9"`B17AP;W)T($-A;&5N
M9&%R(@IM<V=S='(@(LK5S^W1(,?AP\SDS\DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV.0IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B
MU,C'V"(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(X
M"B,L(&9U>GIY"FUS9VED(")&:6YD(@IM<V=S='(@(L?AS./:R2(*"B,Z('EE
M87(N<&AP.C@W('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8S('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,@HC.B!L:6(O0FQO8VLO;6]N=&@N
M<&AP.C$P-0IM<V=I9"`B1G(B"FUS9W-T<B`BQ^',X]K)(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U<WD@
M26YF;W)M871I;VXB"FUS9W-T<B`BQ^'([<?DQ\H@Q^'4SM7MR2(*"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,"!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S(*
M;7-G:60@(D9R:61A>2(*;7-G<W1R("+'X<SCVLDB"@HC.B!T96UP;&%T97,O
M9&5L971E+V1E;&5T92YI;F,Z,S`*;7-G:60@(D9U='5R92(*;7-G<W1R("+C
MT\K>R.''\"(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I
M9"`B1V%M92(*;7-G<W1R("+AVLC)(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C(S"FUS9VED(")'96YE<F%L(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`BQ=#ER"#%X>PB"@HC
M.B!M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S
M:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E
M+FEN8SHQ,`IM<V=I9"`B2&ED92(*;7-G<W1R("(B"@HC.B!M;VYT:"YP:'`Z
M,3,U('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC
M.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&ED92`E<R(*;7-G<W1R("+%V>7'
MT2`E<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8U('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$S.`IM<V=I9"`B2&]U<BAS*2(*;7-G<W1R("+3
MQ]K)("C3Q]HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,L(&9U
M>GIY"FUS9VED(")(;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@
M=&AE(&1A>2!A;F0@=V5E:R!V:65W<R!B93\B"FUS9W-T<B`BQ=GEQ]$@Q^'=
MT<?;Q\H@Q^'DU=TMT\?:[<D@W>T@Q^'MYN,@W>T@Q^''T\K:T<?6(,?AP]/(
MYMKMOR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.#@*;7-G:60@(DAO
M=R!M86YY(&1A>7,@;V8@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('-H;W5L9"!W
M92!G96YE<F%T93\B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3`S,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B))9B!Y;W5R(&5M86EL(&-L
M:65N="!D;V5S;B=T('-U<'!O<G0@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S
M92!O;F4@;V8@=&AE("(*(F9O;&QO=VEN9R!L:6YK<R!T;R!A8V-E<'0@;W(@
M9&5C;&EN92!T:&4@979E;G0N7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E
M;G0Z7&XB"B(E<UQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A
M=&EV96QY.EQN(@HB)7-<;B(*(EQN(@HB5&\@9&5C;&EN92!T:&4@979E;G0Z
M7&XB"B(E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!#86QE
M;F1A<BP@4W1E<"`E9"(*;7-G<W1R("+'T\KMT<?/(,CMQ^3'RB#'X</,Y,_)
M(@H*(SH@9&%T82YP:'`Z,S(P"FUS9VED("));7!O<G0O17AP;W)T($-A;&5N
M9&%R(@IM<V=S='(@(L?3RNW1Q\\ORM7/[=$@R.W'Y,?*(,?AP\SDS\DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV.`IM<V=I9"`B2F%N
M=6%R>2(*;7-G<W1R("+?Q^3FY"#'X<O'Y.TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW-`IM<V=I9"`B2G5L>2(*;7-G<W1R("+-TNW1
MQ^0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,PIM<V=I
M9"`B2G5N92(*;7-G<W1R("+*X^;2(@H*(SH@9&%T82YP:'`Z-C4@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,30R"FUS9VED(")+97EW;W)D<R(*;7-G<W1R
M("+'X=_AX\?*(,?AX]W*Q\WMR2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R-"!H;W5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHX-PIM<V=I9"`B3&%S="!-;V1I
M9FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C0*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ,`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y
M7W-I9&4N:6YC.C$V('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHT"B,L(&9U
M>GIY"FUS9VED("),87-T($UO;G1H(@IM<V=S='(@(L?AU.71(,?AP\[MT2(*
M"B,Z('1E;7!L871E<R]Y96%R+VAE860N:6YC.C0*(RP@9G5Z>GD*;7-G:60@
M(DQA<W0@665A<B(*;7-G<W1R("+'X</3R.;:(,?AP\[MT2(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-"!T96UP;&%T97,O=V5E:R]H96%D
M+FEN8SHS"FUS9VED("),87-T('=E96LB"FUS9W-T<B`BQ^'#T\CFVB#'X</.
M[=$B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$W"FUS9VED("),
M:6UI="!T:&4@=&EM92!S<&%N('1O(&5X<&]R=#HB"FUS9W-T<B`BRLW/[<\@
MQ^'=RM')(,?ATN/D[<D@X<K5S^W1Y<<B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z.#8@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(DQO7V-A=&EO;B(*;7-G<W1R("+'X>/?
MQ^0B"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE
M861E<G,N:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N
M86=E;65N="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?
M;6%N86=E;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C$*
M(SH@;&EB+T1R:79E<BYP:'`Z,3@T.0IM<V=I9"`B3&]C871I;VXB"FUS9W-T
M<B`BQ^'CW\?D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U"B,L(&9U
M>GIY"FUS9VED(")-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RXB"FUS9W-T<B`B
M26UP;W-S:6)L92!D92!C<NEE<B!U;F4@:6YS=&%N8V4@9'4@8V%L96YD<FEE
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,`IM<V=I
M9"`B36%R8V@B"FUS9W-T<B`BPM#'T2(*"B,Z(&QI8B]A<&DN<&AP.C$P,`IM
M<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@179E;G1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<R"FUS9VED(")-87DB
M"FUS9W-T<B`BP^W'T2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#8*;7-G:60@
M(DUE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ
M-PIM<V=I9"`B365E=&EN9R(*;7-G<W1R("+'S,KCQ]HB"@HC.B!L:6(O0FQO
M8VLO=')E95]A;&%R;7,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@06QA
M<FUS(@IM<V=S='(@(LKDR.WE(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z,PIM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C8X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S
M-PIM<V=I9"`B36EN=71E*',I(@IM<V=S='(@(L_>[=[)("C/WL?&WBDB"@HC
M.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z-#(*;7-G:60@(DUI<W-E
M9"!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX,R!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHU.2!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,3@*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@
M(DUO(@IM<V=S='(@(L?AQ<OD[>0B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A
M9"YI;F,Z,38@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$U"B,Z('1E;7!L
M871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8X(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#8*;7-G:60@(DUO;F1A>2(*;7-G<W1R("+'X<7+Y.WD(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,2!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO;G1H(@IM
M<V=S='(@(L?AU.71(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS"B,L(&9U
M>GIY"FUS9VED(")-;VYT:"!6:65W(@IM<V=S='(@(L?AU.71(@H*(SH@;&EB
M+T)L;V-K+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H
M<#HT,PIM<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R.2!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(DUO;G1H;'DZ(%)E
M8W5R<R!E=F5R>2(*;7-G<W1R("+4Y='MQ_`Z(,K?T<?1(-_A(@H*(SH@;&EB
M+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!!:&5A9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C0*
M(RP@9G5Z>GD*;7-G:60@(DUO;G1H<R!"969O<F4B"FUS9W-T<B`B)7,@S]['
MQMX@WLCA(@H*(SH@;&EB+V%P:2YP:'`Z-C$R"FUS9VED(")-=6QT:7!L92!I
M0V%L96YD87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT(&ES
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8W"B,L(&9U>GIY
M"FUS9VED(")->2!#86QE;F1A<G,B"FUS9W-T<B`BQ]/*[=''SR#([<?DQ\H@
MQ^'#S.3/R2(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHS-"!T96UP;&%T97,O
M;65N=2YI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(DUY($-A;&5N9&%R<SHB"FUS
M9W-T<B`BRM7/[=$@Q^'#S.3/R2(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHR,#0*;7-G:60@(DUY($9R964O0G5S>2!54DPB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$Q-R!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34Y"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<U"B,Z('1E;7!L
M871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$W"B,Z('1E
M;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C0T"B,L
M(&9U>GIY"FUS9VED(").86UE(@IM<V=S='(@(N':R,DB"@HC.B!L:6(O0FQO
M8VLO;6]N=&@N<&AP.C0Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0T(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HT,0HC.B!L:6(O0FQO8VLO=')E95]M96YU
M+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B3F5W($5V96YT(@IM<V=S='(@(LW=
MV2#'X<W/RR(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S0*(RP@
M9G5Z>GD*;7-G:60@(DYE>'0B"FUS9W-T<B`BQ^'MYN,@Q^'*Q^'M(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4W"FUS9VED(").97AT(#(T
M(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR.0HC
M+"!F=7IZ>0IM<V=I9"`B3F5X="!$87DB"FUS9W-T<B`BQ^'MYN,@Q^'*Q^'M
M(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHV
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ."!T
M96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z-@IM<V=I9"`B3F5X="!-;VYT:"(*
M;7-G<W1R("+'X=3ET2#'X<K'X>TB"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP
M.C,R"B,L(&9U>GIY"FUS9VED(").97AT(%=E96LB"FUS9W-T<B`BQ^'#T\CF
MVB#'X=['QN,B"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHV"B,L(&9U
M>GIY"FUS9VED(").97AT(%EE87(B"FUS9W-T<B`BQ^'MYN,@Q^'*Q^'M(@H*
M(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT(&1A>2(*
M;7-G<W1R("+'X>WFXR#'X<K'X>TB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM<V=I9"`B
M3F5X="!W965K(@IM<V=S='(@(L?AP]/(YMH@Q^'>Q\;C(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(W-0HC+"!F=7IZ>0IM<V=I9"`B3F\B"FUS9W-T
M<B`BX<?MYLS/(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S,@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3(V"B,L(&9U>GIY"FUS9VED(").;R!A
M;&%R;2(*;7-G<W1R("+*Y,CMY2(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B3F\@871T96YD965S
M(@IM<V=S='(@(N''[>;,SR#*Q]'MSB#'Y,KEQ\$B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,S$Q"FUS9VED(").;R!C86QE;F1A<G,@87)E(&%V86EL86)L
M92!T;R!G=65S=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-34*;7-G:60@
M(DYO(&5N9"!D871E(@IM<V=S='(@(N''[>;,SR#*Q]'MSB#'Y,KEQ\$B"@HC
M.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M
M;VYT:&QI<W0N<&AP.C$V,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT
M"FUS9VED(").;R!E=F5N=',@=&\@9&ES<&QA>2(*;7-G<W1R("(B"@HC.B!L
M:6(O4W1O<F%G92]K;VQA8BYP:'`Z-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,S0T(&QI8B]A<&DN<&AP.C8P
M,@IM<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#0*(RP@9G5Z>GD*
M;7-G:60@(DYO(')E8W5R<F5N8V4B"FUS9W-T<B`BR.W'Y,?*(,?ARM_1Q]$B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HX.#8*;7-G:60@(DYO('9A;&ED(&5M
M86EL(&%D9')E<W,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-C`Q(&QI8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N92(*
M;7-G<W1R("+AQ^WFS,\B"@HC.B!L:6(O4W1O<F%G92]S<6PN<&AP.C$S-@IM
M<V=I9"`B3F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B3F]T:69I8V%T:6]N<R(*;7-G
M<W1R("+'X>/?Q^0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHW.`IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BRM31[>0@Q^'+Q^3M(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4V"FUS9VED(").;W<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z
M-S<*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BRM31[>0@Q^'#YN$B"@HC.B!T
M96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,R!T96UP;&%T97,O
M961I="]E9&ET7W1I;65S<&%N+FEN8SHV-0IM<V=I9"`B3VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.`IM<V=I9"`B3VX@86QL
M(&-A;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-PIM<V=I9"`B3VX@86QL('-H
M;W=N(&-A;&5N9&%R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C<V"FUS9VED(")/;B!M>2!C86QE;F1A<G,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,3D*(RP@9G5Z>GD*;7-G:60@
M(D]P=&EO;F%L(@IM<V=S='(@(L?ASNW'T<?*(@H*(SH@;&EB+T9"5FEE=RYP
M:'`Z,3$X"FUS9VED(")/<'1I;VYA;"!!='1E;F1E97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T9"5FEE=RYP:'`Z,34R"FUS9VED(")/=F5R=FEE=R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHS-`IM<V=I9"`B3W=N
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@T-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B3W=N97(Z("5S(@IM<V=S='(@(L?3RLW>
MQ]XZ("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#(@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.#(*;7-G:60@(E!-(@IM<V=S='(@
M(B(*"B,Z(&1A=&$N<&AP.C(Y('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,30*(RP@9G5Z>GD*;7-G:60@(E!A;&T@1&%T94)O;VLB"FUS9W-T<B`BRL?1
M[<X@Q^'*Y,CMY2(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HS
M"FUS9VED(")087-T($5V96YT<R!,:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$P.2!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHQ.3@*;7-G:60@(E!A='1E<FXB"FUS9W-T<B`BY./FT,PB"@HC.B!T96UP
M;&%T97,O9&5L971E+V]N92YI;F,Z,C<*;7-G:60@(E!E<FUA;F5N=&QY(&1E
M;&5T92!T:&ES(&5V96YT/R(*;7-G<W1R("+-T-T@Y=#'(,?AS<_+(,C4W^$@
MY.7'QNV_(@H*(SH@;&EB+V%P:2YP:'`Z,S(U(&QI8B]A<&DN<&AP.C0Q.2!L
M:6(O87!I+G!H<#HT.#$@;&EB+V%P:2YP:'`Z-34S"B,Z(&QI8B]A<&DN<&AP
M.C4X-"!L:6(O87!I+G!H<#HV-S`@;&EB+V%P:2YP:'`Z-S`V"FUS9VED(")0
M97)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z,38W"FUS9VED(")097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*(RP@9G5Z
M>GD*;7-G:60@(E!O<G1A;"!/<'1I;VYS(@IM<V=S='(@(L[MQ]''RB#'X>/3
MRL[/XR(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR-0HC+"!F=7IZ>0IM<V=I
M9"`B4')E=FEO=7,@1&%Y(@IM<V=S='(@(L?A[>;C(,?AT\?(WB(*"B,Z(&QI
M8B]&0E9I97<O=V5E:RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S
M(%=E96LB"FUS9W-T<B`BQ^'MYN,@Q^'3Q\C>(@H*(SH@=&5M<&QA=&5S+V1A
M>2]H96%D+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D87DB"FUS9W-T<B`BQ^'M
MYN,@Q^'3Q\C>(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,U('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(U,@IM<V=I9"`B4F5C=7(@56YT:6PB
M"FUS9W-T<B`BRM_1Q]$@S<KL(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3`V"B,L(&9U>GIY"FUS9VED(")296-U<G)E;F-E(@IM<V=S='(@(LCM
MQ^3'RB#'X<K?T<?1(@H*(SH@9&%T82YP:'`Z-CD*;7-G:60@(E)E8W5R<F5N
M8V4@1&%T82(*;7-G<W1R("+([<?DQ\H@Q^'*W]''T2(*"B,Z(&1A=&$N<&AP
M.C8W"FUS9VED(")296-U<G)E;F-E($5N9"!$871E(@IM<V=S='(@(LK'T>W.
M(,?DRN7'P2#'X<K?T<?1(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@(E)E8W5R
M<F5N8V4@26YT97)V86PB"FUS9W-T<B`BQ^'=Q]7A(,?ATN/D[2(*"B,Z(&1A
M=&$N<&AP.C8V"FUS9VED(")296-U<G)E;F-E(%1Y<&4B"FUS9W-T<B`BY.;:
M(,?ARM_1Q]$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#`*;7-G:60@(E)E
M8W5R<R!D86EL>2(*;7-G<W1R("+*W]''T2#MYN/M(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-30W"FUS9VED(")296-U<G,@;6]N=&AL>2(*;7-G<W1R("+*
MW]''T2#4Y='M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30S"FUS9VED(")2
M96-U<G,@=V5E:VQY(@IM<V=S='(@(LK?T<?1(,?3R.;:[2(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C4U,`IM<V=I9"`B4F5C=7)S('EE87)L>2(*;7-G<W1R
M("+*W]''T2#3Y.;M(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP
M.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296UI;F1E<CH@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.CDQ
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-`HC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W1E($-A;&5N9&%R<R(*;7-G<W1R("+'T\KMT<?/(,CMQ^3'RB#'X</,Y,_)
M(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C8P('1E;7!L871E<R]M96YU+FEN
M8SHV,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<SHB"FUS9W-T
M<B`BQ]/*[=''SR#([<?DQ\H@Q^'#S.3/R2(*"B,Z('1E;7!L871E<R]A='1E
M;F1E97,O871T96YD965S+FEN8SHU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@)7,B"FUS9W-T<B`B(@H*(SH@871T96YD965S+G!H<#HQ,#0*;7-G
M:60@(E)E;6]V92!!='1E;F1E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C,R"FUS9VED("(B"B)297!L86-E(&5X:7-T:6YG
M(&-A;&5N9&%R('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N
M:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R
M96YT(&-A;&5N9&%R+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HV,C8*;7-G:60@(E)E<75I<F5D(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&0E9I97<N<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S-R!L:6(O1D)6
M:65W+G!H<#HQ-#`@;&EB+T9"5FEE=RYP:'`Z,30S"FUS9VED(")297%U:7)E
M9"!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S$P"FUS9VED(")2
M97-E="!T;R!$969A=6QT<R(*;7-G<W1R("+'X<7:S\?/Q\H@Q^''W<K1Q];M
MR2(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,R!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C8*;7-G:60@(E)E<W!O;G-E(@IM
M<V=S='(@(B(*"B,Z('EE87(N<&AP.C@X('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,PHC.B!L
M:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B4V$B"FUS9W-T<B`BQ^'#
MS<\B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C$@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(P"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I
M<'0N:6YC.C<S"FUS9VED(")3871U<F1A>2(*;7-G<W1R("+'X</-SR(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ.3(*(RP@9G5Z
M>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`BQ^'#S<\B"@HC.B!V:65W979E;G0N
M<&AP.C$Q."!E9&ET979E;G0N<&AP.C0X(&5D:71E=F5N="YP:'`Z-38*;7-G
M:60@(E-A=F4@07,@3F5W(@IM<V=S='(@(LW=V2#?S,_MSR(*"B,Z('1E;7!L
M871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHX-PIM<V=I9"`B4V%V92!!
M='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@861D979E;G0N<&AP.C4U(&5D:71E
M=F5N="YP:'`Z-3$*;7-G:60@(E-A=F4@179E;G0B"FUS9W-T<B`BS=W9(,?A
MS<_+(@H*(SH@<V5A<F-H+G!H<#HY,2!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:%]A9'9A;F-E9"YI;F,Z,3$U"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHV-R!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z.`HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$T,"!L:6(O0FQO8VLO
M=')E95]M96YU+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(L+0Q]$B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z
M,0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($-A;&5N9&%R<R(*;7-G<W1R("+'
MT\KMT<?/(,CMQ^3'RB#'X</,Y,_)(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C8*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHV"FUS9VED(")3
M96%R8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN:6YG.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34P"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@82!C86QE;F1A<B!T;R!E9&ET(@IM<V=S='(@
M(L?.RM$@X^'=(.'MRN,@Q]/*[=''S^4Z(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C8X('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC
M.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(LK'T>W.(,?A
MR,_'[<DB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!C86QE;F1A<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`BQ\[*
MT2#8T>W>R2#%V>7'T2#'X<KFQ]'MSB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,0IM<V=I9"`B(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS
M+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O
M<V4@(@HB9&5F875L="!V:65W+B(*;7-G<W1R("+'SLK1(,7:S\?/Q\H@Q^'*
MP]_MSR"A(-_MW2#MRN,@Q^'%V>7'T2#FQ\[*T2#'X<79Y<?1(,?AQ]W*T<?6
M[2(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3D*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.B(*;7-G
M<W1R("+'SLK1(./AW2#A[<KC(,?3RNW1Q\_E.B(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@
M97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`BQ\[*T2#'X>/5S]$@X>'%T\KMT<?/
M(./D.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C@*;7-G:60@
M(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(L?.RM$@X^'=
M(.'MRN,@Q]/*[=''S^4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-`IM<V=I9"`B4V5L96-T('1H92!F:7)S="!W965K9&%Y.B(*;7-G<W1R("+'
MSLK1(.WFXR#(S\?MR2#'X</3R.;:(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@
M;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("+'SLK1(,?ARN33[=X@X>W*
MXR#'X<K5S^W1(,7A[#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@T
M"FUS9VED(")396QE8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W.B(*;7-G<W1R
M("+'SLK1(,?AW<K1R2#'X=+CY.W)(.'%V>7'T>7'.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!V
M:65W('1O(&1I<W!L87D@;VX@<W1A<G1U<#HB"FUS9W-T<B`BQ\[*T2#4W^$@
MQ=GEQ]$@Q^'4Q]3)(,C:SR#'X<_.YN$Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=VAI8V@@979E;G1S
M('1O('-H;W<@:6X@=&AE('!O<G1A;"XB"FUS9W-T<B`BQ\[*T2##[<D@P\W/
MQ\L@X<K9Y=$@W>T@Q^'CX<[5+B(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE
M+FEN8SHR-"!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C0*;7-G:60@
M(E-E;F0@82!C86YC96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E;F1E97,@
M=VAE;B!D96QE=&EN9R!T:&ES(&5V96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M96YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C$X,0IM<V=I9"`B4V5N9"!U<&1A=&5S+VEN=FET871I
M;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW
M-@IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(L7MX>;A(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.#,*(RP@9G5Z>GD*;7-G:60@
M(E-E="!E;F0@9&%T92(*;7-G<W1R("+AQ^WFS,\@RL?1[<X@Q^3*Y<?!(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X"B,L(&9U>GIY"FUS9VED
M(")3970@<F5C=7)R96YC92!E;F0@9&%T92(*;7-G<W1R("+*Q]'MSB#'Y,KE
MQ\$@Q^'*W]''T2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")3970@<W1A<G0@9&%T92(*;7-G<W1R
M("+*Q]'MSB#'X<C/Q^W)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y
M"FUS9VED("(B"B)3970@>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y
M;W5R(&]W;B!A;F0@;W1H97(@=7-E<G,G(&9R964O8G5S>2!O<'1I;VYS+B(*
M;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C<W"B,L('!H<"UF;W)M870*
M;7-G:60@(E-H87)E(&YO="!F;W5N9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C<Y"B,L(&9U>GIY"FUS
M9VED(")3:&%R960@0V%L96YD87)S(@IM<V=S='(@(L?3RNW1Q\\@R.W'Y,?*
M(,?AP\SDS\DB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-#<@=&5M<&QA=&5S
M+VUE;G4N:6YC.C0Y"B,L(&9U>GIY"FUS9VED(")3:&%R960@0V%L96YD87)S
M.B(*;7-G<W1R("+*U<_MT2#'X</,Y,_)(@H*(SH@8V%L96YD87)?<V5A<F-H
M+G!H<#HR-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M,PHC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHS"B,L
M(&9U>GIY"FUS9VED(")3:&]W($-A;&5N9&%R(@IM<V=S='(@(LK5S^W1(,?A
MP\SDS\DB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!C86QE;F1A<B!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U-@IM<V=I9"`B
M4VAO=R!C871E9V]R>2!L96=E;F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(E-H;W<@9&5L971E+"!A;&%R;2P@
M86YD(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_(@IM<V=S
M='(@(L79Y<?1(,/MWN;DQ\H@Q^'-T-T@H2#'X<KDR.WE(.;'X<K?T<?1(-WM
M(,?AQ<SDS\F_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I
M9"`B4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N9&%R/R(*;7-G<W1R("+%
MV>7'T2#'X</-S\?+(,?AX]/*S=[)(-WM(,?AP\SDS\F_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$V-@IM<V=I9"`B4VAO=R!F<F5E+V)U<WD@;&5G
M96YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`S
M"FUS9VED(")3:&]W(&]N;'D@979E;G1S('1H870@:&%V92!A;B!A;&%R;2!S
M970_(@IM<V=S='(@(L79Y<?1(,?AP\W/Q\L@Q^'*[2#*XR#%VL_'S^7'(./:
M(,KDR.WE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-0IM<V=I9"`B
M4VAO=R!S:&%R960@8V%L96YD87)S('-I9&4M8GDM<VED93\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0HC+"!F=7IZ>0IM<V=I
M9"`B4VAO=R!T87-K<R!U<VEN9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@
M(L79Y<?1(,?AP\W/Q\L@Q^'CT\K-WLD@W>T@Q^'#S.3/R;\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.34*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&EM
M92!O9B!D87D@8F5T=V5E;B!E86-H(&1A>2!I;B!W965K('9I97=S/R(*;7-G
M<W1R("+%V>7'T2#'X=W1Q]O'RB#'X>35W2W3Q]KMR2#=[2#'X>WFXR#=[2#'
MX<?3RMK1Q]8@Q^'#T\CFVNV_(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T
M:6UE<W!A;BYI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E-T85]R="(*;7-G<W1R
M("+MR,_#(-WM(@H*(SH@9&%T82YP:'`Z-34*;7-G:60@(E-T87)T($1A=&4B
M"FUS9W-T<B`BRL?1[<X@Q^'(S\?MR2(*"B,Z('1E;7!L871E<R]S96%R8V@O
M979E;G1?:&5A9&5R<RYI;F,Z-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT
M,0HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(U"FUS9VED(")3=&%R
M="!/;B(*;7-G<W1R("+MR,_#(-WM(@H*(SH@9&%T82YP:'`Z-38*;7-G:60@
M(E-T87)T(%1I;64B"FUS9W-T<B`BTN/D(,?AR,_'[<DB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z.34@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z.#4*;7-G:60@(E-T871?=7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHV('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C(W"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*
M(SH@>65A<BYP:'`Z.#$@>65A<BYP:'`Z.3`@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-C4*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(T
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`W(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,3`Y"FUS9VED(")3=2(*;7-G<W1R("+'X</-SR(*"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D+FEN8SHQ-"!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C,*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(Q('1E;7!L871E<R]E9&ET
M+VIA=F%S8W)I<'0N:6YC.C8W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#4*;7-G:60@(E-U;F1A>2(*;7-G<W1R("+'X</-SR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`BQ^'CY>/'
MRB(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4W-"!L:6(O2W)O;F]L:71H+G!H
M<#HU.3<*;7-G:60@(E1E;G1A=&EV92(*;7-G<W1R("(B"@HC.B!Y96%R+G!H
M<#HX-B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ
M,#4*;7-G:60@(E1H(@IM<V=S='(@(L?ASN/MTR(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z-S`*;7-G:60@(E1H92!%9&ET($%T=&5N
M9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N($5X:71I;F<N(@IM
M<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@8V%N;F]T(&)E(&1E
M;&5T960N(@IM<V=S='(@(N70Y2#'X<K;[=''RB#;[=$@WL?(X<D@X>'*T<?,
MVB$B"@HC.B!C86QE;F1A<G,N<&AP.C0P"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T
M<B`B(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R96YA;65D('1O(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HU-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N('-A
M=F5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC
M.C$V,PIM<V=I9"`B5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T
M:&4@<W1A<G0@9&%T92XB"FUS9W-T<B`B[<S((,/D(.W?YN0@RL?1[<X@Q^'D
MY<?MR2#CRL/.T<?P(-KD(,K'T>W.(,?AR,_'[<DB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#DT"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!<
M(B5S7"(@:&%S(&)E96X@861D960L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3`T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"P@=VAI8V@@=V%S(&]N("5S(&%T("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E
M=F5N="!<(B5S7"(@:&%S(&)E96X@961I=&5D+"!W:&EC:"!I<R!O;B`E<R!A
M="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@;F]T:69I8V%T:6]N('1O
M("5S('=A<R!S=6-C97-S9G5L;'D@<V5N="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3`R-`IM<V=I9"`B5&AE(&9O;&QO=VEN9R!I<R!A
M(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V96YT.B(*;7-G
M<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Q"FUS9VED("(B"B)4:&4@<F5Q=65S
M="!W87,@:6YC;VUP;&5T92X@4V]M92!P87)A;65T97)S('1H870@87)E(&YE
M8V5S<V%R>2!T;R!A8V-E<'0@;W(@(@HB9&5C;&EN92!A;B!E=F5N="!A<F4@
M;6ES<VEN9RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E;7!T
M>2YI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&5V96YT<R!M
M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`BX<?*YLS/
M(./EX\?*(.'*U<_MT>7'+B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HQ."!E
M9&ET979E;G1A8W1I;VXN<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@86-C97-S:6YG('1H92!C86QE;F1A
M<CH@)7,B"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?3RNW1Q\\@Q^'([<?DQ\HN
M(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C,T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N
M=#H@)7,B"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?3RNW1Q\\@Q^'([<?DQ\HN
M(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I;F<@=&AE(&5V
M96YT.B`E<R(*;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q]/*[=''SR#'X<CMQ^3'
MRBXB"@HC.B!L:6(O87!I+G!H<#HS,S@@;&EB+V%P:2YP:'`Z-3DV"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?3RNW1Q\\@
MQ^'([<?DQ\HN(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HV,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN
M9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'T\KMT<?/
M(,?AR.W'Y,?*+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@86X@
M979E;G0@;F]T:69I8V%T:6]N('1O("5S.B`E<R(*;7-G<W1R("(B"@HC.B!D
M871A+G!H<#HQ,#4*;7-G:60@(E1H97)E('=E<F4@;F\@979E;G1S('1O(&5X
M<&]R="XB"FUS9W-T<B`BX<?*YLS/(./EX\?*(.'*U<_MT>7'+B(*"B,Z(&1A
M=&$N<&AP.C$X-`IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$Q.`HC.B!T96UP;&%T97,O961I="]J
M879A<V-R:7!T+FEN8SHW,0IM<V=I9"`B5&AU<G-D87DB"FUS9W-T<B`BQ^'.
MX^W3(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,W"B,L(&9U
M>GIY"FUS9VED(")4:6UE(%-P7V%N(@IM<V=S='(@(L?AX^38WLD@Q^'2X^3M
MR2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C0*(RP@
M9G5Z>GD*;7-G:60@(E1I;64@<W!A;B(*;7-G<W1R("+'X>/DV-[)(,?ATN/D
M[<DB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z
M,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@
M(E1I=%]L92(*;7-G<W1R("+'X=KDYL?D(@H*(SH@9&%T82YP:'`Z-30@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"B,Z('1E;7!L871E<R]S96%R
M8V@O979E;G1?:&5A9&5R<RYI;F,Z,PIM<V=I9"`B5&ET;&4B"FUS9W-T<B`B
MQ^':Y.;'Y"(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C(@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ,C<*;7-G:60@(E1O9&%Y(@IM<V=S='(@(L?A[>;C(,?AS<?A
M[2(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C0@;&EB+T)L
M;V-K+VUO;G1H;&ES="YP:'`Z,3(S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ,CD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(MO/Q_`B"@HC.B!Y96%R
M+G!H<#HX-"!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,"!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,3D*(SH@;&EB+T)L;V-K+VUO;G1H+G!H
M<#HQ,#4*;7-G:60@(E1U(@IM<V=S='(@(L?AR^''R\?!(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C$W('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q-@HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV.0HC+"!F
M=7IZ>0IM<V=I9"`B5'5E<V1A>2(*;7-G<W1R("+'X<[C[=,B"@HC.B!C;VYF
M:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(E1Y<&4B"FUS9W-T<B`B
MY.;:(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$X
M,PIM<V=I9"`B55),(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP
M:'`Z-C0*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<R(*
M;7-G<W1R("+AQ^WCW^0@S=#=("5S+B(*"B,Z(&QI8B]$<FEV97(O;6-A;"YP
M:'`Z,3,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M)7,N(@IM<V=S='(@(N''[>/?Y"#-T-T@)7,N(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3@U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+AQ^WCW^0@RLWC[>$@Q^'*
MVM'MW2#AW"`@)7,N(@H*(SH@8V%L96YD87)S+G!H<#HU,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!<(B5S7"(Z("5S
M(@IM<V=S='(@(N''[>/?Y"#-T-T@)7,N(@H*(SH@;&EB+U-T;W)A9V4O:V]L
M86(N<&AP.C,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G
M<W1R("+AQ^WCW^0@RLWC[>$@Q^'*VM'MW2#AW"`@)7,N(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,34*(SH@<V-R:7!T<R]U<&=R861E<R\R,#`T
M+3`U+3$Y7V-O;G9E<G1?8V%T96=O<FEE<U]T;U]S=')I;F=S+G!H<#HU,PIM
M<V=I9"`B56YF:6QE9"(*;7-G<W1R("+;[=$@X]K1W2(*"B,Z(&QI8B]A<&DN
M<&AP.C,W-B!L:6(O87!I+G!H<#HT-3`@;&EB+V%P:2YP:'`Z-3$V(&QI8B]A
M<&DN<&AP.C8R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#
M;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$P,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9#H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B
M57-E<B!);G1E<F9A8V4B"FUS9W-T<B`BYL?,Y<D@Q^'CT\K.S^,B"@HC.B!Y
M96%R+G!H<#HQ-C,@>65A<BYP:'`Z,38Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,34Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,38R"B,L(&9U>GIY"FUS9VED(")6
M:65W($1A>2(*;7-G<W1R("+%V>7'T2`E<R(*"B,Z('EE87(N<&AP.C@U('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8Q('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(R,`HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I
M9"`B5V4B"FUS9W-T<B`BQ^'#T<C:Q\$B"@HC.B!T96UP;&%T97,O;6]N=&@O
M:&5A9"YI;F,Z,3@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$W"B,Z('1E
M;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<P"FUS9VED(")7961N97-D
M87DB"FUS9W-T<B`BQ^'#T<C:Q\$B"@HC.B!A='1E;F1E97,N<&AP.C$Q,B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,CDP(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP
M.C(S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*
M;7-G<W1R("+'X<?3R.;:(@H*(SH@;6]N=&@N<&AP.C$W.2!W;W)K=V5E:RYP
M:'`Z,S`@=V5E:RYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5E:R`E
M9"(*;7-G<W1R("+'X<?3R.;:("5D(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED(")7
M965K*',I(@IM<V=S='(@(L?AP]/(YMH@*,/3Q\CMVBDB"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C$U"FUS9VED(")7965K;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R("+#T\CF
MVNW'\#H@RM_1Q]$@W^$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T
M"FUS9VED("(B"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W
M<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\B"FUS9W-T
M<B`B(@HBX\?EYB#"SM$@YM[*(.W*XR#%V>7'T>4@S>WD(.''(,KFS,\@P\W/
MQ\L@R-K/Y2#=[2#FUMH@Q=GEQ]$@Q^'MYN,@YL?AP]/(YMJ_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B(@HB5VAA="!T:6UE('-H
M;W5L9"!D87D@86YD('=E96L@=FEE=W,@<W1A<G0L('=H96X@=&AE<F4@87)E
M(&YO(&5A<FQI97(@979E;G1S/R(*;7-G<W1R("(B"B+CQ^7F(,/FX2#FWLH@
M[<KC(,79Y<?1Y2#-[>0@X<<@RN;,SR##S<_'RR#>R.'EW>T@YM;:(,79Y<?1
M(,?A[>;C(.;'X</3R.;:OR(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$Q(&QI8B]+
M<F]N;VQI=&@N<&AP.C$R.#D@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C(*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")7;W)K(%=E96LB
M"FUS9W-T<B`BQ]/(YMH@Q^':X^$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,CDR(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(U"FUS9VED(")996%R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR-#$*;7-G:60@(EEE87)L>3H@4F5C=7)S
M(&5V97)Y(@IM<V=S='(@(M/DYNW'\#H@RM_1Q]$@W^$B"@HC.B!D871A+G!H
M<#HT,"!D871A+G!H<#HR,S0@961I=&5V96YT86-T:6]N+G!H<#HT-B!A9&1E
M=F5N="YP:'`Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&5V96YT<RXB"FUS9W-T
M<B`B(@H*(SH@871T96YD+G!H<#HT.0IM<V=I9"`B66]U(&%R92!N;W0@86X@
M871T96YD964@;V8@=&AE('-P96-I9FEE9"!E=F5N="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW-@IM<V=I9"`B
M66]U(&-A;B!O;FQY('5S92!T:&ES(&9O<FT@9G)O;2!T:&4@161I="!!='1E
M;F1E97,@<V-R965N+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HY-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1O(&YO="!H879E
M(&%N(&5M86EL(&%D9')E<W,@8V]N9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L
M($EN9F]R;6%T:6]N("(*(D]P=&EO;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H
M97)E)7,@8F5F;W)E(&5V96YT(&YO=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N
M(@IM<V=S='(@(B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HR,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A
M9&0@979E;G1S('1O("5S+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.30*
M;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N
M=',@=&\@=&AE('-E;&5C=&5D(&-A;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!D
M96QE=F5N=&%C=&EO;BYP:'`Z,C8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O(&1E;&5T92!T:&ES(&5V96YT+B(*;7-G<W1R("(B"@HC
M.B!E9&ET979E;G1A8W1I;VXN<&AP.C<X"FUS9VED(")9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N(@IM<V=S='(@(B(*
M"B,Z(&1A=&$N<&AP.C$X.0IM<V=I9"`B66]U(&AA=F4@<W!E8VEF:65D(&%N
M(&EN=F%L:60@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z
M,C$*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E
M;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP
M:'`Z,C8*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!D96-L:6YE9"!A
M='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&%T=&5N
M9"YP:'`Z,S$*;7-G:60@(EEO=2!H879E('1E;G1A=&EV96QY(&%C8V5P=&5D
M(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@8V%L
M96YD87)S+G!H<#HY,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@8V%L96YD
M87(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHU-`IM<V=I9"`B66]U(&UU<W0@<V5L96-T
M(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$P.30*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I
M960@=VAE;B!E=F5N=',@87)E(&%D9&5D('1O('EO=7(@8V%L96YD87)S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3`T"FUS9VED("(B
M"B)9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R
M92!D96QE=&5D(&9R;VT@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3D*;7-G:60@(EEO=2!R97%U97-T960@
M=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R
M(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N
M;VQI=&@N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5Q=65S
M=&5D('1O(&)E(')E;6EN9&5D(&%B;W5T("5S+"!W:&EC:"!I<R!O;B`E<R!A
M="`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-H87)E<V5L
M96-T+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&-A;&5N
M9&%R(@IM<V=S='(@(LK5S^W1(,?AP\SDS\DB"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ,#4S(&QI8B]$<FEV97(N<&AP.C$P-C,*;7-G:60@(EM5;FYA;65D(&5V
M96YT72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHY
M-PHC+"!F=7IZ>0IM<V=I9"`B7T%L87)M(@IM<V=S='(@(LKDR.WE(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q"FUS9VED
M(")?0F%S:6,@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('9I97=E=F5N="YP:'`Z
M,3(P"B,L(&9U>GIY"FUS9VED(")?161I="(*;7-G<W1R("+)9&ET97(B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,P"B,L(&9U>GIY"FUS9VED(")?1V]T
M;R(*;7-G<W1R("+%T.7((,7A["(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M,S8*(RP@9G5Z>GD*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(L?3
MRNW1Q\\ORM7/[=$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S$X"B,L(&9U
M>GIY"FUS9VED(")?37D@0V%L96YD87)S(@IM<V=S='(@(LK5S^W1(,?AP\SD
MS\DB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S(U"B,L(&9U>GIY"FUS9VED
M(")?3F5W($5V96YT(@IM<V=S='(@(LW=V2#'X<W/RR(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S-#$*(RP@9G5Z>GD*;7-G:60@(E]0<FEN="(*;7-G<W1R
M("+'V,C:(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,@HC+"!F=7IZ>0IM
M<V=I9"`B7U-E87)C:"(*;7-G<W1R("+"T,?1(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,R.`HC+"!F=7IZ>0IM<V=I9"`B7U1O9&%Y(@IM<V=S='(@(L?A
M[>;C(,?AS<?A[2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$T,@IM
M<V=I9"`B8F5F;W)E('1H92!E=F5N="!S=&%R=',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-0IM<V=I9"`B9&%Y(@IM<V=S='(@
M(L?A[>;C(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(Q,`IM<V=I9"`B9&%Y*',I(@IM<V=S='(@
M(L?A[>;C("C'X</MQ^,I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(L?A
MP^W'XR(*"B,Z(&1A=&$N<&AP.C$T-R!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$*(RP@9G5Z>GD*;7-G:60@(F5V96YT<RYC<W8B"FUS9W-T<B`BS./M
MVB#'X</-S\?+(@H*(SH@9&%T82YP:'`Z,38X"B,L(&9U>GIY"FUS9VED(")E
M=F5N=',N:6-S(@IM<V=S='(@(LSC[=H@Q^'#S<_'RR(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3,Q"FUS9VED(")F<F]M(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,C8*(SH@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C,P('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S-@IM<V=I9"`B;6]N
M=&@H<RDB"FUS9W-T<B`BU.71("C#U.71*2(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$P,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F]N("5S(&%T
M("5S(@IM<V=S='(@(B5S(-/MR,_#(,?AVN/A(,[AQ^$@)7,B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C,P"FUS9VED(")O;B!T:&4@<V%M92!D871E(@IM<V=S='(@(N`@;&$@
M;>IM92!D871E(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(S-@IM<V=I9"`B;VX@=&AE('-A;64@
M=V5E:V1A>2(*;7-G<W1R("+DW=,@Q^'MYN,@W>T@Q^''T\CFVB(*"B,Z(&1A
M=&$N<&AP.C,P('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34*;7-G:60@
M(G9#86QE;F1A<B]I0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,S0Y(&QI8B]A<&DN<&AP.C8P-PIM<V=I9"`B=D5V96YT(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B=V5E:R(*;7-G<W1R("+'T\CFVB(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$R,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3<*;7-G
M:60@(G=E96LH<RD@;VXZ(@IM<V=S='(@(L?AP]/(YMH@*,/3Q\CMVBD@W>TZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DS"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.30*;7-G
M:60@(G=E96MS(@IM<V=S='(@(L?AP]/'R.W:(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T,@IM
M<V=I9"`B>65A<BAS*2(*;7-G<W1R("+3Y,D@*-/DYL?**2(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W!O+VET7TE4+G!O````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$S,#(U-0`Q,#0Q-S,V,C<U
M,P`P,C`T,C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(R!+<F]N;VQI=&@@,"XP+C,@271A;&EA;B!T<F%N<VQA=&EO;@HC
M(%!A;VQA($-A<G!E;G1E<B`\<&-A<G!E;G1E<D!I;F9V:6,N:70^.R!':6]V
M86YN:2!-96YE9VAE='1I(#QG;65N96=H971T:4!I;F9V:6,N:70^+"`R,#`Q
M+@HC($-O<'ER:6=H="`H8RD@,C`P,R!397)G:6\@1RX@0V%R961D82X*(R!3
M97)G:6\@1RX@0V%R961D82`\<V-A<F5D9&%`=&ES8V%L:2YI=#XL(#(P,#,N
M"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($MR
M;VYO;&ET:"!V,"XP+C-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`U+3`R
M+3(S(#$W.C(S+3`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@36%R8V\@4&ER
M;W9A;F\@/&UA<F-O+G!I<F]V86YO0'5N:6)O8V-O;FDN:70^7&XB"B),86YG
M=6%G92U496%M.B!)=&%L:6%N(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C
M:"YI;F,Z,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&-A;&5N
M9&%R<R!F;W5N9"(*;7-G<W1R(").97-S=6X@8V]M<&QE86YN;R!T<F]V871O
M+B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&5V96YT<R(*;7-G<W1R("(E9"!E=F5N=&DB"@HC
M.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1&%Y*',I("5S($AO=7(H<RD@)7,@36EN=71E
M<R(*;7-G<W1R("(E<R!':6]R;F\O:2`E<R!/<F$O92`E<R!-:6YU=&\O:2(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$W.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S(&%T=&5N9&5E<R(*;7-G<W1R(").97-S=6X@<&%R=&5C:7!A
M;G1E(@H*(SH@9&%T82YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(D9I;&4@)7,@
M:6UP;W)T871O(&-O;B!S=6-C97-S;R(*"B,Z(&-A;&5N9&%R<RYP:'`Z,3`U
M(&QI8B]B87-E+G!H<#HQ,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#
M86QE;F1A<B(*;7-G<W1R(")#86QE;F1A<FEO(&1I("5S(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$W"FUS9VED("(B"B(H0VQI8VL@
M;VX@8V%L96YD87(@;F%M92!T;R!S=VET8V@@=&AE(&-A;&5N9&%R)W,@=FES
M:6)I;&ET>2!I;B!T:&4@;6%I;B`B"B)W:6YD;W<I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38T"FUS9VED("(J
M($%D9"!T:&5S92!B>2!C;&EC:VEN9R!!9&0@*B(*;7-G<W1R("(J($%G9VEU
M;F=I('%U97-T:2!C;&EC8V%N9&\@<W4@06=G:75N9VD@*B(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,34P"FUS9VED("(J(%!L96%S
M92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(%-E;&5Z:6]N82!)
M;F1I<FEZ>F\O:2`J(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-@HC+"!F=7IZ
M>0IM<V=I9"`B,2!A='1E;F1E92(*;7-G<W1R(").97-S=6X@<&%R=&5C:7!A
M;G1E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*;7-G:60@
M(C$@979E;G0B"FUS9W-T<B`B,2!E=F5N=&\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,W"FUS9VED("(Q(&AO=7(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-`HC+"!F=7IZ>0IM<V=I9"`B,34@;6EN
M=71E<R(*;7-G<W1R(")-:6YU=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,U"B,L(&9U>GIY"FUS9VED("(R,"!M:6YU=&5S(@IM<V=S='(@(DUI
M;G5T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*(RP@9G5Z>GD*
M;7-G:60@(C,P(&UI;G5T97,B"FUS9W-T<B`B36EN=71I(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3<Q"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG
M/D%T=&5N9&5E<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/E!A
M<G1E8VEP86YT:3PO8CX@*&]P>FEO;F%L92DB"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ-#D*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^1&5S8W)I
M7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^1&5S8W)I
M>FEO;F4\+V(^("AO<'II;VYA;&4I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C<W"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S
M=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^4&%R;VQE(&-H:6%V93PO
M8CX@*&]P>FEO;F%L92DB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M.30*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^4F5C=7)R96YC93PO<W1R;VYG
M/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/D9R97%U96YZ83PO8CX@*&]P>FEO
M;F%L92DB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P,2!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X,0IM<V=I9"`B04TB"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3DQ"FUS9VED(")!8V-E<'1E9"(*
M;7-G<W1R(")!8V-E='1A=&\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z,3$*;7-G:60@(D%D7W9A;F-E9"!396%R8V@B"FUS9W-T<B`B4FEC
M97)C82!!7W9A;GIA=&$B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$V,2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y
M,`IM<V=I9"`B061D(@IM<V=S='(@(D%G9VEU;F=I(@H*(SH@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C8*;7-G:60@(D%D9"!%=F5N="(*;7-G<W1R(")!
M9V=I=6YG:2!%=F5N=&\B"@HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A
M;%]M86YA9V5M96YT+FEN8SHS-0IM<V=I9"`B061D(&$@;F5W(%)E;6]T92!#
M86QE;F1A<B(*;7-G<W1R(")!9V=I=6YG:2!U;B!N=6]V;R!#86QE;F1A<FEO
M(%)E;6]T;SHB"@HC.B!A9&1E=F5N="YP:'`Z-C0*;7-G:60@(D%D9"!A(&YE
M=R!E=F5N="(*;7-G<W1R(")!9V=I=6YG:2!U;B!N=6]V;R!E=F5N=&\B"@HC
M.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-S0*;7-G:60@
M(D%D9"!A='1E;F1E97,B"FUS9W-T<B`B06=G:75N9VD@<&%R=&5C:7!A;G1I
M(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,3(P"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S
M+FEN8SHW.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(E)U8G)I8V$B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z."!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3$*;7-G:60@(D%D=F%N8V5D
M(%-E87)C:"(*;7-G<W1R(")2:6-E<F-A($%V86YZ871A(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z-3,*;7-G:60@(D%L87)M(@IM<V=S='(@(D%L
M;&%R;64B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8T"B,L('!H<"UF;W)M870*
M;7-G:60@(D%L87)M("5D(&1A>7,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C$W-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@
M)60@:&]U<G,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$W-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&UI
M;G5T97,@8F5F;W)E(@IM<V=S='(@(E1E;7!O(&1I($%L;&%R;64@*&UI;G5T
M:2DB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D%L87)M("5D('=E96MS(&)E9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ-S8S"FUS9VED(")!;&%R;2`Q(&1A>2!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V.`IM<V=I9"`B06QA<FT@
M,2!H;W5R(&)E9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M-S<S"B,L(&9U>GIY"FUS9VED(")!;&%R;2`Q(&UI;G5T92!B969O<F4B"FUS
M9W-T<B`B5&5M<&\@9&D@06QL87)M92`H;6EN=71I*2(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W-3@*;7-G:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T
M<B`B(@H*(SH@9&%T82YP:'`Z-C`*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T
M<B`B1&%T82!D:2!!;&QA<FUE(@H*(SH@9&%T82YP:'`Z-3D*;7-G:60@(D%L
M87)M(%-P86X@*&UI;G5T97,I(@IM<V=S='(@(E1E;7!O(&1I($%L;&%R;64@
M*&UI;G5T:2DB"@HC.B!D871A+G!H<#HV,0IM<V=I9"`B06QA<FT@5&EM92(*
M;7-G<W1R(")!;&QA<FUE(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N
M:6YC.C,Q"FUS9VED(")!;&PB"FUS9W-T<B`B5'5T=&DB"@HC.B!L:6(O1D)6
M:65W+G!H<#HQ,C8@;&EB+T9"5FEE=RYP:'`Z,3(Y(&QI8B]&0E9I97<N<&AP
M.C$S,@IM<V=I9"`B06QL($%T=&5N9&5E<R(*;7-G<W1R(")4=71T:2!I('!A
M<G1E8VEP86YT:2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU
M.0IM<V=I9"`B06QL($9U='5R92(*;7-G<W1R(")4=71T;R!I;"!&=71U<F\B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*(RP@9G5Z>GD*
M;7-G:60@(D%L;"!087-T(@IM<V=S='(@(E1U='1O(&EL(&=I;W)N;R(*"B,Z
M(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO;6]N
M=&@N<&AP.C(T"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C(W(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B06QL(%9I<VEB;&4B"FUS9W-T
M<B`B5'5T=&D@5FES:6)I;&DB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHQ,C(@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W
M+G!H<#HY,PHC.B!L:6(O5V5E:U9I97<N<&AP.C$R-R!L:6(O5V5E:U9I97<N
M<&AP.C$S-"!L:6(O1')I=F5R+G!H<#HQ.#,R"FUS9VED(")!;&P@9&%Y(@IM
M<V=S='(@(E1U='1O(&EL(&=I;W)N;R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@979E;G0B"FUS9W-T<B`B5'5T=&\@
M:6P@9VEO<FYO(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM
M<V=I9"`B06QL(&5V96YT<R(*;7-G<W1R(")4=71T:2!G;&D@179E;G1I(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O
M2W)O;F]L:71H+G!H<#HV.#,*;7-G:60@(D%N>2(*;7-G<W1R(")1=6%L<VEA
M<VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,0IM<V=I
M9"`B07!R:6PB"FUS9W-T<B`B07!R:6QE(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I=%]T:6UE<W!A;BYI;F,Z,SD@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE
M<W!A;BYI;F,Z.3,*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHW,"!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U-@IM<V=I9"`B070B"FUS9W-T
M<B`B06QL92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,C8*;7-G:60@(B(*
M(D%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O
M<FUA=&EO;B!A8F]U="!T:&4@979E;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE
M;G0@<W5P<&]R=',@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I
M;&4@=&\@96%S:6QY('5P9&%T92`B"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE
M(&5V96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-#(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS
M9VED(")!='1E;F1A;F-E(@IM<V=S='(@(E!A<G1E8VEP86YT:2(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$V,0IM<V=I9"`B071T96YD965S(@IM
M<V=S='(@(E!A<G1E8VEP86YT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B06=O<W1O(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHX"FUS9VED(")"87-I8R!396%R
M8V@B"FUS9W-T<B`B4FEC97)C82!696QO8V4B"@HC.B!C;VYF:6<O:V5Y=V]R
M9',N<&AP+F1I<W0Z,3<*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D-O;7!L
M96%N;F\B"@HC.B!L:6(O1D)6:65W+G!H<#HY,"!L:6(O1D)6:65W+G!H<#HQ
M,3`*;7-G:60@(D)U<WDB"FUS9W-T<B`B26UP96=N871O(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0T"FUS9VED(")#7V%L
M96YD87(B"FUS9W-T<B`B0U]A;&5N9&%R:6\B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHT.0IM<V=I9"`B0V%L7V5N9&%R(@IM<V=S='(@(D-A;%]E
M;F1A<FEO(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$T-B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C$*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HR,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR,2!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*;7-G:60@(D-A;&5N9&%R(@IM<V=S
M='(@(D-A;&5N9&%R:6\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PIM
M<V=I9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G<W1R(")3;VUM87)I;R!D96P@
M0V%L96YD87)I;R(*"B,Z(&1A=&$N<&AP.C(R.`HC+"!F=7IZ>0IM<V=I9"`B
M0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS9W-T<B`B1FEL92`E
M<R!I;7!O<G1A=&\@8V]N('-U8V-E<W-O(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W"FUS
M9VED(")#86QE;F1A<G,B"FUS9W-T<B`B0V%L96YD87)I(@H*(SH@8V%L96YD
M87)S+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87)S(&UU<W0@:&%V
M92!A(&YA;64N(@IM<V=S='(@(DYO;64@9&5L($-A;&5N9&%R:6\B"@HC.B!D
M871A+G!H<#HR-#,*;7-G:60@(D-A;B=T(&-R96%T92!A(&YE=R!E=F5N="XB
M"FUS9W-T<B`B26UP;W-S:6)I;&4@8W)E87)E('5N(&YU;W9O(&5V96YT;R(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DQ('1E;7!L
M871E<R]D96QE=&4O;VYE+FEN8SHS,`HC.B!T96UP;&%T97,O9&5L971E+V1E
M;&5T92YI;F,Z,S(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S,*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,S`Y"FUS9VED(")#86YC96PB"FUS9W-T
M<B`B0V%N8V5L;&$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S`*;7-G:60@
M(D-A;F-E;&QE9"(*;7-G<W1R(")%;&EM:6YA=&\B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-A;F-E;&QE9#H@
M)7,B"FUS9W-T<B`B16QI;6EN871O.B`E<R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV-"!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHV.0IM<V=I9"`B0V%T96=O<E]Y(@IM<V=S='(@(D-A=&5G;W)I7V$B
M"@HC.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E
M<G,N:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*;7-G:60@(D-A
M=&5G;W)Y(@IM<V=S='(@(D-A=&5G;W)I82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-SD*;7-G:60@(B(*(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B
M92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S
M(&)Y("(*(F5M86EL.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3(*;7-G:60@(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I
M9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V5A<F-H7V%B;V]K7W-E;&5C
M="YI;F,Z,3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.0HC+"!F=7IZ>0IM
M<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F;W(@
M9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(E-E;&5Z:6]N82!U;F$@<G5B<FEC
M82!P97(@;&$@<FEC97)C82!D96=L:2!I;F1I<FEZ>FDN(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V9B7V-A;'-?<V5L96-T+FEN8SHQ-@IM<V=I9"`B0VAO;W-E
M('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!I;B!Y;W5R(&9R964O8G5S>2!I
M;F9O<FUA=&EO;CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Q,0IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC;'5D
M92!W:&5N(&=E;F5R871I;F<@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B0VAO;W-E('EO
M=7(@9&5F875L="!C86QE;F1A<BXB"FUS9W-T<B`B4V-E9VQI(&EL('1U;R!C
M86QE;F1A<FEO(&1I(&1E9F%U;'0B"@HC.B!T96UP;&%T97,O871T96YD965S
M+V%T=&5N9&5E<RYI;F,Z-C4*(RP@9G5Z>GD*;7-G:60@(D-L96%R(&%L;"!A
M='1E;F1E97,B"FUS9W-T<B`B07IZ97)A('1U='1I(&D@<&%R=&5C:7!A;G1I
M(@H*(SH@9&%T82YP:'`Z,C@@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ
M,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")686QO
M<FD@<V5P87)A=&D@9&$@=FER9V]L82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW,PIM<V=I9"`B0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_(@IM
M<V=S='(@(D-O;F9E<FUA(&-A;F-E;&QA>FEO;F4@9&5G;&D@979E;G1I/R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4V-PIM<V=I9"`B0V]N9FER;65D(@IM
M<V=S='(@(D-O;F9E<FUA=&\B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A
M;&5N9&%R<RYI;F,Z,C`X"FUS9VED(")#;W!Y('1H92!54DP@8F5L;W<@9F]R
M('5S92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ(@IM
M<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F]N(&5R
M82!P;W-S:6)I;&4@87!R:7)E("5S+B(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O8V%L96YD87)S+FEN8SHQ,C8*;7-G:60@(D-R96%T92(*;7-G<W1R(")#
M<F5A(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q
M,@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($-A;&5N9&%R(@IM<V=S='(@(D-A
M;&5N9&%R:2!296UO=&DB"@HC.B!M;VYT:"YP:'`Z,38U('1E;7!L871E<R]W
M965K+VAE860N:6YC.C(U('1E;7!L871E<R]D87DO<F]W+FEN8SHV"B,Z(&QI
M8B]$87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z,3DT"FUS9VED(")#
M<F5A=&4@82!.97<@179E;G0B"FUS9W-T<B`B0W)E82!U;B!N=6]V;R!E=F5N
M=&\B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHX,`IM<V=I9"`B0W)E
M871E9"(*;7-G<W1R(")#<F5A=&\B"@HC.B!T96UP;&%T97,O9&5L971E+V1E
M;&5T92YI;F,Z,CD*;7-G:60@(D-U<G)E;G0B"FUS9W-T<B`B0V]R<F5N=&4B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C`Y"FUS9VED(")$86EL>3H@4F5C=7)S(&5V97)Y(@IM
M<V=S='(@(D=I;W)N86QI97)O.B!3:2!R:7!E=&4@;V=N:2(*"B,Z(&%T=&5N
M9&5E<RYP:'`Z,3$P(&QI8B]+<F]N;VQI=&@N<&AP.C$R.#@@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R
M"FUS9VED(")$87DB"FUS9W-T<B`B1VEO<FYO(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,Y"FUS
M9VED(")$87DH<RDB"FUS9W-T<B`B1VEO<FYO*&DI(@H*(SH@=FEE=V5V96YT
M+G!H<#HQ,#0*;7-G:60@(D1E7VQE=&4B"FUS9W-T<B`B16Q?:6UI;F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.0IM<V=I9"`B1&5C
M96UB97(B"FUS9W-T<B`B1&EC96UB<F4B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU.30*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(E)I9FEU=&%T;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-PIM<V=I9"`B1&5F875L="!#86QE
M;F1A<B(*;7-G<W1R(")#86QE;F1A<FEO(&1I($1E9F%U;'0B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DS('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@Q"B,Z('1E;7!L871E<R]D96QE=&4O
M;VYE+FEN8SHR.2!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M
M96YT+FEN8SHR,PHC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`B16QI;6EN82(*"B,Z(&1E;&5V96YT+G!H<#HT,"!T96UP
M;&%T97,O9&5L971E+V]N92YI;F,Z,3@@=&5M<&QA=&5S+V1E;&5T92]D96QE
M=&4N:6YC.C$X"B,Z(&QI8B]$<FEV97(N<&AP.C$X,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E("5S(@IM<V=S='(@(D-A;F-E;&QA("5S(@H*(SH@
M961I=&5V96YT+G!H<#HW,`IM<V=I9"`B1&5L971E($5V96YT(@IM<V=S='(@
M(D5L:6UI;F$@179E;G1O(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N
M:6YC.C(W"FUS9VED("(B"B)$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL
M>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L
M(&]R("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R("(B"B)#86YC96QL82!S
M;VQO(&PG979E;G1O(&-O<G)E;G1E+"!Q=65S=&\@979E;G1O(&4@='5T=&4@
M;&4@<FEC;W)R96YZ92!F=71U<F4L("(*(F\@='5T=&4@;&4@<FEC;W)R96YZ
M93\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z
M,3`T('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR.`IM<V=I9"`B1&5S
M8W)I7W!T:6]N(@IM<V=S='(@(D1E<V-R:5]Z:6]N92(*"B,Z(&1A=&$N<&AP
M.C8R('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S4*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.38*;7-G:60@(D1E<V-R:7!T:6]N
M(@IM<V=S='(@(D1E<V-R:7II;VYE(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ-S,*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B5FES
M=6%L:7IZ82(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!#86QE;F1A<G,B"FUS9W-T
M<B`B36EE:2!#86QE;F1A<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(X"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!Z:6]N
M:2!6:7-U86QI>GIA>FEO;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S`*;7-G:60@(D1O('EO=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E
M(&1U92!O;B!Y;W5R(&-A;&5N9&%R/R(*;7-G<W1R(")6=6]I(&UO<W1R87)E
M(&QE(&%T=&EV:73@(&-H92!S;VYO(&1A('-V;VQG97)E(&YE;"!C86QE;F1A
M<FEO/R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4S-PIM<V=I9"`B1&]E<R!N
M;W0@<F5C=7(B"FUS9W-T<B`B3F]N('-I(')I<&5T92(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")$=64Z("5S(@IM
M<V=S='(@(D5N=')O.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM
M97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B1'5R871A
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W,"!L
M:6(O1')I=F5R+G!H<#HQ.#`V"B,L(&9U>GIY"FUS9VED(")%9&ET(@IM<V=S
M='(@(E]-;V1I9FEC82(*"B,Z(&5D:71E=F5N="YP:'`Z,S,@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C8@;&EB+T1R:79E<BYP:'`Z,3@P-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@(DUO9&EF:6-A("5S(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@W"FUS9VED(")%9&ET($%T
M=&5N9&5E<R(*;7-G<W1R(")-;V1I9FEC82!087)T96-I<&%N=&DB"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30P"B,L(&9U>GIY
M"FUS9VED(")%9&ET($-A;&5N9&%R<R(*;7-G<W1R(")-;V1I9FEC82!#86QE
M;F1A<FD@4F5M;W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,`IM
M<V=I9"`B161I="!296UO=&4@0V%L96YD87)S(@IM<V=S='(@(DUO9&EF:6-A
M($-A;&5N9&%R:2!296UO=&DB"@HC.B!A='1E;F1E97,N<&AP.C$U,`IM<V=I
M9"`B161I="!A='1E;F1E97,B"FUS9W-T<B`B36]D:69I8V$@<&%R=&5C:7!A
M;G1I(@H*(SH@=&5M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N9"YI;F,Z,C`*;7-G
M:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B
M26YD:7)I>GIO($5M86EL(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE
M<W!A;BYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D5N7V0B"FUS9W-T<B`B1FEN
M:7-C92!I;"(*"B,Z(&1A=&$N<&AP.C4W"FUS9VED(")%;F0@1&%T92(*;7-G
M<W1R(")$871A(&1I(&9I;F4B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT
M7VAE861E<G,N:6YC.C@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#<*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#@*;7-G:60@(D5N9"!/;B(*
M;7-G<W1R(")&:6YI<V-E(&EL(@H*(SH@9&%T82YP:'`Z-3@*;7-G:60@(D5N
M9"!4:6UE(@IM<V=S='(@(D]R87)I;R!D:2!&:6YE(@H*(SH@871T96YD965S
M+G!H<#HQ,C0@871T96YD965S+G!H<#HQ,S4@871T96YD965S+G!H<#HQ-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5T<FEE=FEN9R!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<R(*;7-G<W1R("(B"B)3:2!E)R!V
M97)I9FEC871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%Z:6]N92!D96QL92!I
M;F9O<FUA>FEO;FD@;&EB97)O+R(*(F]C8W5P871O(&1E;&PG=71E;G1E("5S
M.B`E<RXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DS"FUS9VED(")%=F5N
M="!A9&1E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P
M,PIM<V=I9"`B179E;G0@9&5L971E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`Y.`IM<V=I9"`B179E;G0@961I=&5D.B(*;7-G<W1R
M("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#8V"B,L('!H<"UF;W)M870*;7-G
M:60@(D5V96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B179E;G1I(&1A("5S
M(&$@)7,B"@HC.B!L:6(O1')I=F5R+G!H<#HW-C0*(RP@9G5Z>GD*;7-G:60@
M(D5V96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E+B(*;7-G<W1R("),82!D
M871A(&1I(&9I;F4@9&5V92!E<W-E<F4@9&]P;R!L82!D871A(&1I)VEN:7II
M;RXB"@HC.B!L:6(O1')I=F5R+G!H<#HW,S`*;7-G:60@(D5V96YT<R!M=7-T
M(&AA=F4@82!T:71L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M-S8W"FUS9VED(")%=F5N=',@;75S="!H879E(&%N(&5N9"!D871E(&]R(&$@
M9'5R871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHW.0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD($YA;65S
M(@IM<V=S='(@(DYO;64@9&5L($-A;&5N9&%R:6\B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C$X-PIM<V=I9"`B17AP;W)T(@IM<V=S='(@(D5S
M<&]R=&$B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C@*;7-G:60@
M(D5X<&]R="!#86QE;F1A<B(*;7-G<W1R(")%<W!O<G1A($-A;&5N9&%R:6\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV.0IM<V=I9"`B
M1F5B<G5A<GDB"FUS9W-T<B`B1F5B8G)A:6\B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$R.`IM<V=I9"`B1FEN9"(*;7-G<W1R(")4
M<F]V82(*"B,Z('EE87(N<&AP.C@W('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,@HC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B1G(B"FUS9W-T<B`B5F5N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&
M<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B3F5S<W5N82!);F9O<FUA
M>FEO;F4B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C`@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3$Y"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S
M8W)I<'0N:6YC.C<R"FUS9VED(")&<FED87DB"FUS9W-T<B`B5F5N97)D["(*
M"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS,`IM<V=I9"`B1G5T
M=7)E(@IM<V=S='(@(D9U='5R;R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N
M9&ES=#HQ-PIM<V=I9"`B1V%M92(*;7-G<W1R(")':6]C;R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHR,PIM<V=I9"`B1V5N
M97)A;"(*;7-G<W1R(")'96YE<F%L92(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V]T;R`E<R(*;7-G<W1R
M(")686D@82`E<R(*"B,Z(&UO;G1H+G!H<#HQ,S4@=&5M<&QA=&5S+W=E96LO
M:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO:&5A
M9%]S:61E7V)Y7W-I9&4N:6YC.C$P"FUS9VED(")(:61E(@IM<V=S='(@(B(*
M"B,Z(&UO;G1H+G!H<#HQ,S4@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y
M7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I
M9&4N:6YC.C$P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(:61E("5S
M(@IM<V=S='(@(E-O;&QE8VET;SH@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHV-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S@*;7-G:60@
M(DAO=7(H<RDB"FUS9W-T<B`B3W)A*&4I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PHC+"!F=7IZ>0IM<V=I9"`B2&]W(&QO;F<@<VAO=6QD('1H
M92!T:6UE('-L;W1S(&]N('1H92!D87D@86YD('=E96L@=FEE=W,@8F4_(@IM
M<V=S='(@(B(*(DUO<W1R82!L92!M97IZ92!O<F4@;F5L;&$@=FES=&$@9VEO
M<FYA;&EE<F$@92!S971T:6UA;F%L93]-;W-T<F$@:6YT97)V86QL:2`B"B)D
M:2!M97IZ82!O<F$@;F5L;&$@=FES=6%L:7IZ87II;VYE(&1I(&=I;W)N;R!E
M('-E='1I;6%N83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@X"B,L
M(&9U>GIY"FUS9VED(")(;W<@;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B!S:&]U;&0@=V4@9V5N97)A=&4_(@IM<V=S='(@(E!E<B!Q=6%N
M=&D@9VEO<FYI(&YE;"!F=71U<F\@9V5N97)I86UO(&EN9F]R;6%Z:6]N:2!L
M:6)E<F\O;V-C=7!A=&\_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`S,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B))9B!Y;W5R(&5M86EL(&-L:65N="!D
M;V5S;B=T('-U<'!O<G0@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@
M;V8@=&AE("(*(F9O;&QO=VEN9R!L:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN
M92!T:&4@979E;G0N7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0Z7&XB
M"B(E<UQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY
M.EQN(@HB)7-<;B(*(EQN(@HB5&\@9&5C;&EN92!T:&4@979E;G0Z7&XB"B(E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($-A;&5N9&%R+"!3=&5P("5D
M(@IM<V=S='(@(DEM<&]R=&$@0V%L96YD87)I;RP@4W1E<"`E9"(*"B,Z(&1A
M=&$N<&AP.C,R,`IM<V=I9"`B26UP;W)T+T5X<&]R="!#86QE;F1A<B(*;7-G
M<W1R("));7!O<G1A+T5S<&]R=&$@0V%L96YD87)I;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S
M='(@(D=E;FYA:6\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHW-`IM<V=I9"`B2G5L>2(*;7-G<W1R("),=6=L:6\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,PIM<V=I9"`B2G5N92(*;7-G<W1R
M(")':75G;F\B"@HC.B!D871A+G!H<#HV-2!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ-#(*;7-G:60@(DME>7=O<F1S(@IM<V=S='(@(E!A<F]L92!C:&EA
M=F4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-34*;7-G:60@
M(DQA<W0@,C0@:&]U<G,B"FUS9W-T<B`B56QT:6UE(#(T(&]R92(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C@W"FUS9VED("),87-T($UO9&EF:65D
M(@IM<V=S='(@(E5L=&EM82!-;V1I9FEC82(*"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-`HC.B!T96UP;&%T97,O;6]N=&@O
M:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"B,Z('1E;7!L871E<R]M;VYT:"]H
M96%D7W-I9&5?8GE?<VED92YI;F,Z,38@=&5M<&QA=&5S+VUO;G1H+VAE860N
M:6YC.C0*;7-G:60@(DQA<W0@36]N=&@B"FUS9W-T<B`B56QT:6UO(&UE<V4B
M"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHT"B,L(&9U>GIY"FUS9VED
M("),87-T(%EE87(B"FUS9W-T<B`B56QT:6UA('-E='1I;6%N82(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-"!T96UP;&%T97,O=V5E:R]H
M96%D+FEN8SHS"FUS9VED("),87-T('=E96LB"FUS9W-T<B`B56QT:6UA('-E
M='1I;6%N82(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3<*;7-G
M:60@(DQI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.B(*;7-G<W1R(")3
M96QE>FEO;F$@:6P@;&%S<V\@9&D@=&5M<&\@9&$@97-P;W)T87)E.B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX-B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHW-@IM<V=I9"`B3&]?8V%T:6]N(@IM<V=S
M='(@(DQU7V]G;R(*"B,Z(&1A=&$N<&AP.C8T('1E;7!L871E<R]S96%R8V@O
M979E;G1?:&5A9&5R<RYI;F,Z-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E
M7V-A;%]M86YA9V5M96YT+FEN8SHQ.`HC.B!T96UP;&%T97,O<')E9G,O<F5M
M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHU,B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHR,0HC.B!L:6(O1')I=F5R+G!H<#HQ.#0Y"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R("),=6]G;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-0IM<V=I9"`B36%N86=E(')E;6]T92!C86QE;F1A<G,N(@IM<V=S='(@(D=E
M<W1I<V-I(&-A;&5N9&%R:2!R96UO=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-S`*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<GIO
M(@H*(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-87AI;75M($YU;6)E<B!O
M9B!%=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R(")-86=G:6\B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ.#0V"FUS9VED(")-92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(DUE971I;F<B"FUS
M9W-T<B`B26YC;VYT<F\B"@HC.B!L:6(O0FQO8VLO=')E95]A;&%R;7,N<&AP
M.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@06QA<FUS(@IM<V=S='(@(D%L;&%R
M;64B"@HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU
M($QI<W0B"FUS9W-T<B`B07!R:2!#87)T96QL82(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C8X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S-PIM
M<V=I9"`B36EN=71E*',I(@IM<V=S='(@(DUI;G5T:2(*"B,Z(&QI8B]";&]C
M:R]P<F5V;6]N=&AL:7-T+G!H<#HT,@IM<V=I9"`B36ES<V5D($5V96YT<R!,
M:7-T(@IM<V=S='(@(D5L96YC;R!D:2!%=F5N=&D@4&5R<VDB"@HC.B!Y96%R
M+G!H<#HX,R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHU.2!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,3@*(SH@;&EB+T)L;V-K+VUO;G1H+G!H
M<#HQ,#4*;7-G:60@(DUO(@IM<V=S='(@(DQU;B(*"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D+FEN8SHQ-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,34*
M(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C@@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@IM<V=I9"`B36]N9&%Y(@IM<V=S='(@(DQU;F5D
M["(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$R.3$@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"FUS9VED(")-
M;VYT:"(*;7-G<W1R(")-97-E(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS
M"FUS9VED(")-;VYT:"!6:65W(@IM<V=S='(@(E9I<W5A;&EZ>F$@365S92(*
M"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C,@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z-#,*;7-G:60@(DUO;G1H;'D@179E;G1S($QI<W0B"FUS9W-T
M<B`B16QE;F-O($UE;G-I;&4@9&D@179E;G1I(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,CD@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C,U"FUS9VED(")-;VYT:&QY.B!296-U<G,@979E<GDB"FUS
M9W-T<B`B365N<VEL;65N=&4Z(%-I(')I<&5T92!O9VYI(@H*(SH@;&EB+T)L
M;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!!:&5A9"(*;7-G
M<W1R(")-97-I($%V86YT:2(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T
M+G!H<#HR-`IM<V=I9"`B36]N=&AS($)E9F]R92(*;7-G<W1R(")-97-I(%!R
M:6UA(@H*(SH@;&EB+V%P:2YP:'`Z-C$R"FUS9VED(")-=6QT:7!L92!I0V%L
M96YD87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT(&ES('-U
M<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8W"FUS9VED(")->2!#
M86QE;F1A<G,B"FUS9W-T<B`B36EE:2!#86QE;F1A<FDB"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,S0@=&5M<&QA=&5S+VUE;G4N:6YC.C,V"FUS9VED(")-
M>2!#86QE;F1A<G,Z(@IM<V=S='(@(DUI96D@0V%L96YD87)I.B(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,#0*(RP@9G5Z>GD*
M;7-G:60@(DUY($9R964O0G5S>2!54DPB"FUS9W-T<B`B4FES<&]S=&$@3&EB
M97)O+T]C8W5P871O(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$Q-R!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M,34Y"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<U"B,Z
M('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$W
M"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC
M.C0T"FUS9VED(").86UE(@IM<V=S='(@(DYO;64B"@HC.B!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C0Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0T(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HT,0HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR,`IM<V=I9"`B3F5W($5V96YT(@IM<V=S='(@(DYU;W9O($5V96YT;R(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S0*;7-G:60@(DYE>'0B
M"FUS9W-T<B`B4')O<W-I;6\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z-3<*;7-G:60@(DYE>'0@,C0@:&]U<G,B"FUS9W-T<B`B4')O<W-I
M;64@,C0@;W)E(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(Y"FUS9VED(").
M97AT($1A>2(*;7-G<W1R(")':6]R;F\@<W5C8V5S<VEV;R(*"B,Z('1E;7!L
M871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-@HC.B!T96UP;&%T
M97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3@@=&5M<&QA=&5S+VUO
M;G1H+VAE860N:6YC.C8*;7-G:60@(DYE>'0@36]N=&@B"FUS9W-T<B`B365S
M92!S=6-C97-S:79O(@H*(SH@;&EB+T9"5FEE=R]W965K+G!H<#HS,@IM<V=I
M9"`B3F5X="!7965K(@IM<V=S='(@(E-E='1I;6%N82!S=6-C97-S:79A(@H*
M(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B
M3F5X="!996%R(@IM<V=S='(@(D=I;W)N;R!S=6-C97-S:79O(@H*(SH@=&5M
M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT(&1A>2(*;7-G<W1R
M(")':6]R;F\@<W5C8V5S<VEV;R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHU."!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHU"FUS9VED(").
M97AT('=E96LB"FUS9W-T<B`B4V5T=&EM86YA('-U8V-E<W-I=F$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<U"B,L(&9U>GIY"FUS9VED(").;R(*
M;7-G<W1R(")/<F$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHW,R!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHQ,C8*(RP@9G5Z>GD*;7-G:60@(DYO
M(&%L87)M(@IM<V=S='(@(D%L;&%R;64B"@HC.B!T96UP;&%T97,O871T96YD
M965S+V%T=&5N9&5E<RYI;F,Z-#@*;7-G:60@(DYO(&%T=&5N9&5E<R(*;7-G
M<W1R(").97-S=6X@<&%R=&5C:7!A;G1E(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3,Q,0IM<V=I9"`B3F\@8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@
M9W5E<W1S+B(*;7-G<W1R(").97-S=6X@8V%L96YD87)I;R!D:7-P;VYI8FEL
M92!P97(@9VQI(&]S<&ET:2XB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C4U"FUS9VED(").;R!E
M;F0@9&%T92(*;7-G<W1R(").97-S=6YA(&1A=&$@9&D@9FEN92(*"B,Z(&QI
M8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ-C0@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z,38S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ.30*;7-G
M:60@(DYO(&5V96YT<R!T;R!D:7-P;&%Y(@IM<V=S='(@(DYE<W-U;B!E=F5N
M=&\@9&$@;6]S=')A<F4B"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z-#,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S(@IM<V=S='(@(B(*(E-I(&4G
M('9E<FEF:6-A=&\@=6X@97)R;W)E(&YE;&PG:6UP;W)T87II;VYE(&1E;&QE
M(&EN9F]R;6%Z:6]N:2!L:6)E<F\O(@HB;V-C=7!A=&\@9&5L;"=U=&5N=&4@
M)7,Z("5S+B(*"B,Z(&QI8B]A<&DN<&AP.C,T-"!L:6(O87!I+G!H<#HV,#(*
M;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B
M3F5S<W5N(&-O;7!L96%N;F\@=')O=F%T;RXB"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,#0*(RP@9G5Z>GD*;7-G:60@(DYO(')E8W5R<F5N8V4B
M"FUS9W-T<B`B4FEC;W)R96YZ82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C@X
M-@IM<V=I9"`B3F\@=F%L:60@96UA:6P@861D<F5S<R!F;W5N9"(*;7-G<W1R
M(").97-S=6X@:6YD:7)I>GIO(&4M;6%I;"!V86QI9&\@Z"!S=&%T;R!T<F]V
M871O+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8P,2!L:6(O2W)O;F]L:71H
M+G!H<#HV,C(*;7-G:60@(DYO;F4B"FUS9W-T<B`B3F5S<W5N;R(*"B,Z(&QI
M8B]3=&]R86=E+W-Q;"YP:'`Z,3,V"FUS9VED(").;W0@9F]U;F0B"FUS9W-T
M<B`B3F]N('1R;W9A=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*
M(RP@9G5Z>GD*;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`B3'5O9V\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.`IM<V=I9"`B
M3F]V96UB97(B"FUS9W-T<B`B3F]V96UB<F4B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R(")/<F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-PIM<V=I9"`B3V-T
M;V)E<B(*;7-G<W1R(")/='1O8G)E(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-S@*;7-G:60@(D]N(&%L;"!C86QE;F1A<G,@22!H879E
M(')E860@86-C97-S('1O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-S<*(RP@9G5Z>GD*;7-G:60@(D]N(&%L;"!S:&]W;B!C86QE
M;F1A<G,B"FUS9W-T<B`B1V5S=&ES8VD@8V%L96YD87)I(')E;6]T:2XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<V"B,L(&9U>GIY"FUS9VED(")/
M;B!M>2!C86QE;F1A<G,@;VYL>2(*;7-G<W1R(")-:65I($-A;&5N9&%R:2(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8Q.0IM<V=I9"`B3W!T:6]N86PB"FUS
M9W-T<B`B3W!Z:6]N86QE(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,3$X"B,L(&9U
M>GIY"FUS9VED(")/<'1I;VYA;"!!='1E;F1E97,B"FUS9W-T<B`B4&%R=&5C
M:7!A>FEO;F4@9F%C;VQT871I=F$B"@HC.B!L:6(O1D)6:65W+G!H<#HQ-3(*
M;7-G:60@(D]V97)V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C,T"FUS9VED(")/=VYE<B(*;7-G<W1R(")0<F]P<FEE=&%R
M:6\B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")/=VYE<CH@)7,B"FUS9W-T<B`B4')O<')I971A<FEO(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#(@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ.#(*;7-G:60@(E!-(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C(Y('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30*(RP@9G5Z
M>GD*;7-G:60@(E!A;&T@1&%T94)O;VLB"FUS9W-T<B`B1&%T82!D:2!!;&QA
M<FUE(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C,*;7-G:60@
M(E!A<W0@179E;G1S($QI<W0B"FUS9W-T<B`B16QE;F-O($5V96YT:2!087-S
M871I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`Y('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$Y.`IM<V=I9"`B4&%T=&5R;B(*;7-G<W1R(")-
M;V1E;&QO(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(W"FUS9VED
M(")097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`B0V%N
M8V5L;&$@<75E<W1O(&5V96YT;R!D969I;FET:79A;65N=&4_(@H*(SH@;&EB
M+V%P:2YP:'`Z,S(U(&QI8B]A<&DN<&AP.C0Q.2!L:6(O87!I+G!H<#HT.#$@
M;&EB+V%P:2YP:'`Z-34S"B,Z(&QI8B]A<&DN<&AP.C4X-"!L:6(O87!I+G!H
M<#HV-S`@;&EB+V%P:2YP:'`Z-S`V"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R(")097)M97-S;R!.96=A=&\B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z,38W"FUS9VED(")097)M:7-S:6]N<R(*
M;7-G<W1R(")097)M97-S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,0IM<V=I9"`B4&]R=&%L($]P=&EO;G,B"FUS9W-T<B`B3W!Z:6]N:2!0;W)T
M86QE(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(U"FUS9VED(")0<F5V:6]U
M<R!$87DB"FUS9W-T<B`B1VEO<FYO(%!R96-E9&5N=&4B"@HC.B!L:6(O1D)6
M:65W+W=E96LN<&AP.C(V"FUS9VED(")0<F5V:6]U<R!7965K(@IM<V=S='(@
M(E-E='1I;6%N82!0<F5C961E;G1E(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D
M+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D87DB"FUS9W-T<B`B1VEO<FYO('!R
M96-E9&5N=&4B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S4@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C4R"FUS9VED(")296-U<B!5;G1I;"(*
M;7-G<W1R(")2:7!E=&D@9FEN;R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$P-@IM<V=I9"`B4F5C=7)R96YC92(*;7-G<W1R(")2:6-O<G)E;GIA
M(@H*(SH@9&%T82YP:'`Z-CD*;7-G:60@(E)E8W5R<F5N8V4@1&%T82(*;7-G
M<W1R(")$871A(%)I8V]R<F5N>F$B"@HC.B!D871A+G!H<#HV-PIM<V=I9"`B
M4F5C=7)R96YC92!%;F0@1&%T92(*;7-G<W1R(")$871A(&1I($9I;F4@<FEC
M;W)R96YZ82(*"B,Z(&1A=&$N<&AP.C8X"FUS9VED(")296-U<G)E;F-E($EN
M=&5R=F%L(@IM<V=S='(@(DEN=&5R=F%L;&\@9&D@4FEC;W)R96YZ82(*"B,Z
M(&1A=&$N<&AP.C8V"FUS9VED(")296-U<G)E;F-E(%1Y<&4B"FUS9W-T<B`B
M5&EP;R!D:2!R:6-O<G)E;GIA(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30P
M"FUS9VED(")296-U<G,@9&%I;'DB"FUS9W-T<B`B4VD@<FEP971E(&]G;FD@
M9VEO<FYO(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30W"FUS9VED(")296-U
M<G,@;6]N=&AL>2(*;7-G<W1R(")3:2!R:7!E=&4@;V=N:2!M97-E(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-30S"FUS9VED(")296-U<G,@=V5E:VQY(@IM
M<V=S='(@(E-I(')I<&5T92!O9VYI('-E='1I;6%N82(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C4U,`IM<V=I9"`B4F5C=7)S('EE87)L>2(*;7-G<W1R(")3
M:2!R:7!E=&4@;V=N:2!A;FYO(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI
M=&@N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296UI;F1E<CH@)7,B
M"FUS9W-T<B`B4V]L;&5C:71O.B`E<R(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O8V%L96YD87)S+FEN8SHY,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0*
M;7-G:60@(E)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B0V%L96YD87)I(%)E
M;6]T:2(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHV,"!T96UP;&%T97,O;65N
M=2YI;F,Z-C(*;7-G:60@(E)E;6]T92!#86QE;F1A<G,Z(@IM<V=S='(@(D-A
M;&5N9&%R:2!296UO=&DZ(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E
M;F1E97,N:6YC.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92`E<R(*
M;7-G<W1R(")%;&EM:6YA("5S(@H*(SH@871T96YD965S+G!H<#HQ,#0*;7-G
M:60@(E)E;6]V92!!='1E;F1E92(*;7-G<W1R(")%;&EM:6YA(%!A<G1E8VEP
M86YT92(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S(*;7-G:60@
M(B(*(E)E<&QA8V4@97AI<W1I;F<@8V%L96YD87(@=VET:"!T:&4@:6UP;W)T
M960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@
M96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@8V%L96YD87(N/"]S=')O;F<^(@IM
M<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8R-@IM<V=I9"`B4F5Q
M=6ER960B"FUS9W-T<B`B3V)B;&EG871O<FEO(@H*(SH@;&EB+T9"5FEE=RYP
M:'`Z.3@@;&EB+T9"5FEE=RYP:'`Z,3,W(&QI8B]&0E9I97<N<&AP.C$T,"!L
M:6(O1D)6:65W+G!H<#HQ-#,*;7-G:60@(E)E<75I<F5D($%T=&5N9&5E<R(*
M;7-G<W1R(")087)T96-I<&%N=&D@4FEC:&EE<W1I(@H*(SH@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S$P
M"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#,@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,38V"FUS9VED(")297-P;VYS92(*;7-G<W1R(")2:7-P
M;W-T82(*"B,Z('EE87(N<&AP.C@X('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,PHC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B4V$B"FUS9W-T<B`B4V%B(@H*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(Q('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$R,`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN
M8SHW,PIM<V=I9"`B4V%T=7)D87DB"FUS9W-T<B`B4V%B871O(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,@HC+"!F=7IZ>0IM
M<V=I9"`B4V%V92(*;7-G<W1R(")386(B"@HC.B!V:65W979E;G0N<&AP.C$Q
M."!E9&ET979E;G0N<&AP.C0X(&5D:71E=F5N="YP:'`Z-38*;7-G:60@(E-A
M=F4@07,@3F5W(@IM<V=S='(@(E-A;'9A(&-O;64@3G5O=F\B"@HC.B!T96UP
M;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z.#<*(RP@9G5Z>GD*;7-G
M:60@(E-A=F4@071T96YD965S(@IM<V=S='(@(E!A<G1E8VEP86YT:2(*"B,Z
M(&%D9&5V96YT+G!H<#HU-2!E9&ET979E;G0N<&AP.C4Q"FUS9VED(")3879E
M($5V96YT(@IM<V=S='(@(E-A;'9A($5V96YT;R(*"B,Z('-E87)C:"YP:'`Z
M.3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q-0HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-C<@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]S96%R8V@N:6YC.C@*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ-#`@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C8*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")#97)C82(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O<V5A<F-H+FEN8SHQ"B,L(&9U>GIY"FUS9VED(")396%R8V@@0V%L
M96YD87)S(@IM<V=S='(@(D-A;&5N9&%R:2!#;VYD:79I<VDB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B4V5A
M<F-H(%)E<W5L=',B"FUS9W-T<B`B0V5R8V$B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+W-E87)C:"YI;F,Z-@IM<V=I9"`B4V5A<F-H(&9O<B!C86QE;F1A
M<G,@8V]N=&%I;FEN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C$U,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&$@8V%L96YD87(@=&\@961I="(*;7-G<W1R(")396QE>FEO;F$@=6X@8V%L
M96YD87)I;R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V."!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0HC.B!T96UP;&%T97,O
M961I="]E9&ET7W1I;65S<&%N+FEN8SHX,PIM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R(")396QE>FEO;F$@=6YA(&1A=&$B"@HC.B!T96UP;&%T97,O
M;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!C86QE;F1A<G,@
M=&\@9&ES<&QA>3HB"FUS9W-T<B`B4V5L97II;VYA(&EL(&-A;&5N9&%R:6\@
M=F5R<V\@8W5I(&EM<&]R=&%R93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$*;7-G:60@(B(*(E-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@
M:&]W('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E
M("(*(F1E9F%U;'0@=FEE=RXB"FUS9W-T<B`B(@HB4V-E9VQI(&QE(&]P>FEO
M;FD@9&D@8V]N9F5R;6$L(&QE("!V:7-U86QI>GIA>FEO;FD@92!S8V5G;&D@
M;&$@(@HB=FES=6%L:7IZ87II;VYE(&1I(&1E9F%U;'0N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ.0IM<V=I9"`B4V5L96-T('1H92!C86QE
M;F1A<B!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(E-E;&5Z:6]N82!I;"!C86QE
M;F1A<FEO('9E<G-O(&-U:2!I;7!O<G1A<F4Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ,@IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R
M;6%T.B(*;7-G<W1R(")396QE>FEO;F$@:6P@9F]R;6%T;R!P97(@97-P;W)T
M87)E.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C@*;7-G:60@
M(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(E-E;&5Z:6]N
M82!I;"!F:6QE(&1A(&EM<&]R=&%R93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`T"FUS9VED(")396QE8W0@=&AE(&9I<G-T('=E96MD87DZ(@IM
M<V=S='(@(E-E;&5Z:6]N82!I;"!P<FEM;R!G:6]R;F\@9F5R:6%L93HB"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q"FUS9VED(")396QE8W0@
M=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E-E;&5Z
M:6]N82!I;"!F;W)M871O(&1A(&-U:2!I;7!O<G1A<F4Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T:6UE('-P
M86X@=&\@<VAO=SHB"FUS9W-T<B`B4V5L97II;VYA(&EL(&QA<W-O(&1I('1E
M;7!O(&1A(&UO<W1R87)E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-@IM<V=I9"`B4V5L96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A<G1U
M<#HB"FUS9W-T<B`B4V-E9VQI(&QA('9I<W5A;&EZ>F%Z:6]N92!D82!M;W-T
M<F%R92!D;W!O(&PG86-C97-S;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C(*;7-G:60@(E-E;&5C="!W:&EC:"!E=F5N=',@=&\@<VAO=R!I;B!T
M:&4@<&]R=&%L+B(*;7-G<W1R(")396QE>FEO;F$@<75A;&D@979E;G1I(&UO
M<W1R87)E(&YE;"!P;W)T86QE+B(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE
M+FEN8SHR-"!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C0*;7-G:60@
M(E-E;F0@82!C86YC96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E;F1E97,@
M=VAE;B!D96QE=&EN9R!T:&ES(&5V96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M96YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@(DEN=FEA('5N(&5M86EL(&$@
M)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#$*;7-G:60@(E-E
M;F0@=7!D871E<R]I;G9I=&%T:6]N<R!T;R!A;&P@871T96YD965S('=H96X@
M<V%V:6YG('1H:7,@979E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-S8*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R
M(")3971T96UB<F4B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N
M+FEN8SHX,PIM<V=I9"`B4V5T(&5N9"!D871E(@IM<V=S='(@(DEM<&]S=&$@
M;&$@9&%T82!D:2!F:6YE(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C8X"FUS9VED(")3970@<F5C=7)R96YC92!E;F0@9&%T92(*;7-G<W1R("))
M;7!O<W1A(&QA(&1A=&$@9&D@9FEN92!D96QL82!R:6-O<G)E;GIA(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,S$*;7-G:60@(E-E
M="!S=&%R="!D871E(@IM<V=S='(@(DEM<&]S=&$@;&$@9&%T82!D)VEN:7II
M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.0IM<V=I9"`B(@HB4V5T
M('EO=7(@9G)E92]B=7-Y(&-A;&5N9&%R<R!A;F0@>6]U<B!O=VX@86YD(&]T
M:&5R('5S97)S)R!F<F5E+V)U<WD@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@
M8V%L96YD87)S+G!H<#HW-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4VAA<F4@;F]T(&9O=6YD.B`E<R(*;7-G<W1R(")V179E;G0@;F]N('1R;W9A
M=&\N(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C<Y
M"FUS9VED(")3:&%R960@0V%L96YD87)S(@IM<V=S='(@(D-A;&5N9&%R:2!#
M;VYD:79I<VDB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-#<@=&5M<&QA=&5S
M+VUE;G4N:6YC.C0Y"FUS9VED(")3:&%R960@0V%L96YD87)S.B(*;7-G<W1R
M(")#86QE;F1A<FD@0V]N9&EV:7-I.B(*"B,Z(&-A;&5N9&%R7W-E87)C:"YP
M:'`Z,C4@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC+"!F
M=7IZ>0IM<V=I9"`B4VAO=R!#86QE;F1A<B(*;7-G<W1R(")#86QE;F1A<FEO
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C(R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W(&-A;&5N9&%R(%PB)7-<(B(*
M;7-G<W1R(")#86QE;F1A<FD@0V]N9&EV:7-I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U-@IM<V=I9"`B4VAO=R!C871E9V]R>2!L96=E;F0_(@IM
M<V=S='(@(DUO<W1R82!L82!L96=E;F1A(&1I(&-A;&5N9&%R:3\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")3:&]W(&1E;&5T92P@
M86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S
M/R(*;7-G<W1R(")-;W-T<F$@:6-O;F4@8V%N8V5L;&$L(&%L;&%R;64@92!R
M:6-O<G)E;GIE(&YE;&QE('9I<W1E(&-A;&5N9&%R:6\_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S:W,@:6X@
M=&AE(&-A;&5N9&%R/R(*;7-G<W1R(")-;W-T<F$@;&4@871T:79I=.#@(&1A
M('-V;VQG97)E(&YE;"!C86QE;F1A<FEO/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E-H;W<@9G)E92]B=7-Y(&QE
M9V5N9#\B"FUS9W-T<B`B36]S=')A(&QA(&QE9V5N9&$@9&D@8V%L96YD87)I
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@(E-H;W<@
M;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS9W-T<B`B
M36]S=')O('-O;&\@9VQI(&5V96YT:2!C;VX@=6X@8V%M<&%N96QL;R!D:2!A
M;&QA<FUE/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S4*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@<VAA<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_
M(@IM<V=S='(@(DUO<W1R82!C86QE;F1A<FD@8V]N9&EV:7-I(&$@;&%T;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(E-H;W<@=&%S
M:W,@=7-I;F<@8V%T96=O<GD@8V]L;W)S/R(*;7-G<W1R(")-;W-T<F$@;&4@
M871T:79I=.`@=7-A;F1O(&D@8V]L;W)I(&1E;&QE(&-A=&5G;W)I93\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34*;7-G:60@(E-H;W<@=&EM92!O
M9B!D87D@8F5T=V5E;B!E86-H(&1A>2!I;B!W965K('9I97=S/R(*;7-G<W1R
M("(B"B)-;W-T<F$@:6YT97)V86QL:2!D:2!M97IZ82!O<F$@;F5L;&$@=FES
M=6%L:7IZ87II;VYE(&1I(&=I;W)N;R!E('-E='1I;6%N83\B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4W1A7W)T(@IM<V=S='(@(D-O;6EN8VEA(&EL(@H*(SH@9&%T82YP:'`Z
M-34*;7-G:60@(E-T87)T($1A=&4B"FUS9W-T<B`B1&%T82!D:2!);FEZ:6\B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C<@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHR-0IM<V=I9"`B4W1A<G0@3VXB"FUS9W-T<B`B0V]M:6YC:6$@
M:6PB"@HC.B!D871A+G!H<#HU-@IM<V=I9"`B4W1A<G0@5&EM92(*;7-G<W1R
M(")/<F$@9&D@26YI>FEO(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.CDU('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C@U"FUS
M9VED(")3=&%T7W5S(@IM<V=S='(@(E-T871I<R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHR-PIM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871I<R(*"B,Z('EE
M87(N<&AP.C@Q('EE87(N<&AP.CDP('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8U"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-"!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P.0IM
M<V=I9"`B4W4B"FUS9W-T<B`B1&]M(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,PHC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA=&5S+V5D:70O:F%V87-C
M<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I
M9"`B4W5N9&%Y(@IM<V=S='(@(D1O;65N:6-A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Y"FUS9VED(")487-K<R(*;7-G<W1R(")!='1I=FETX"(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4W-"!L:6(O2W)O;F]L:71H+G!H<#HU
M.3<*;7-G:60@(E1E;G1A=&EV92(*;7-G<W1R(")!;'1E<FYA=&EV:2(*"B,Z
M('EE87(N<&AP.C@V('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8R
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,0HC.B!L:6(O0FQO8VLO;6]N
M=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS9W-T<B`B1VEO(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW,`IM<V=I9"`B5&AE($5D:70@
M071T96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N="X@17AI=&EN
M9RXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&-A;FYO="!B92!D96QE
M=&5D+B(*;7-G<W1R("));"!C86QE;F1A<FEO(%PB)7-<(B!N;VX@<'7Y(&5S
M<V5R92!C86YC96QL871O+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-#`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S
M(&)E96X@8W)E871E9"XB"FUS9W-T<B`B26P@8V%L96YD87)I;R!<(B5S7"(@
MZ"!S=&%T;R!E;&EM:6YA=&\N(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(DEL(&-A;&5N9&%R:6\@7"(E<UPB(.@@<W1A
M=&\@96QI;6EN871O+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R96YA
M;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B26P@8V%L96YD87)I;R!<(B5S7"(@
MZ"!S=&%T;R!R:6YO;6EN871O(&$@7"(E<UPB+B(*"B,Z(&-A;&5N9&%R<RYP
M:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<
M(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B26P@8V%L96YD87)I;R!<(B5S
M7"(@Z"!S=&%T;R!S86QV871O+B(*"B,Z(&1A=&$N<&AP.C(R-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B
M92!P=7)G960Z("5S(@IM<V=S='(@(DEL(&-A;&5N9&%R:6\@7"(E<UPB(&YO
M;B!P=?D@97-S97)E(&-A;F-E;&QA=&\N(@H*(SH@=&5M<&QA=&5S+V5D:70O
M:F%V87-C<FEP="YI;F,Z,38S"FUS9VED(")4:&4@96YD(&1A=&4@;75S="!B
M92!L871E<B!T:&%N('1H92!S=&%R="!D871E+B(*;7-G<W1R("),82!D871A
M(&1I(&9I;F4@9&5V92!E<W-E<F4@9&]P;R!L82!D871A(&1I)VEN:7II;RXB
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DT"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&%D9&5D+"!W
M:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B26P@8V%L96YD87)I;R!<
M(B5S7"(@Z"!S=&%T;R!R:6YO;6EN871O(&$@7"(E<UPB+B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$Q,#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@9&5L971E9"P@=VAI8V@@=V%S
M(&]N("5S(&%T("5S+B(*;7-G<W1R("));"!C86QE;F1A<FEO(%PB)7-<(B#H
M('-T871O(&5L:6UI;F%T;RXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB
M(&AA<R!B965N(&5D:71E9"P@=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S
M='(@(DEL(&-A;&5N9&%R:6\@7"(E<UPB(.@@<W1A=&\@<FEN;VUI;F%T;R!A
M(%PB)7-<(BXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#8W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S
M('-U8V-E<W-F=6QL>2!S96YT+B(*;7-G<W1R("),82!N;W1I9FEC87II;VYE
M(&1E;"!E=F5N=&\@82`E<R#H('-T871A(&EN=FEA=&$@8V]N('-U8V-E<W-O
M+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,C0*;7-G:60@(E1H92!F;VQL
M;W=I;F<@:7,@82!M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E
M=F5N=#HB"FUS9W-T<B`B26P@<V5G=65N=&4@Z"!U;F$@9&5C<FEZ:6]N92!P
M:?D@9&5T=&%G;&EA=&$@9&5L(&5V96YT;SHB"@HC.B!A='1E;F0N<&AP.C0Q
M"FUS9VED("(B"B)4:&4@<F5Q=65S="!W87,@:6YC;VUP;&5T92X@4V]M92!P
M87)A;65T97)S('1H870@87)E(&YE8V5S<V%R>2!T;R!A8V-E<'0@;W(@(@HB
M9&5C;&EN92!A;B!E=F5N="!A<F4@;6ES<VEN9RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]E;7!T>2YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E
M(&YO(&5V96YT<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS
M9W-T<B`B3F]N(&-I('-O;F\@9FEL97,@:6X@<75E<W1A(&1I<F5C=&]R>2XB
M"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z,3@@961I=&5V96YT86-T:6]N+G!H
M<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M86-C97-S:6YG('1H92!C86QE;F1A<CH@)7,B"FUS9W-T<B`B17)R;W)E(&YE
M;&PG:6UP;W)T87II;VYE(&1E:2!D871I(&E#86QE;F1A<CH@)7,N(@H*(SH@
M861D979E;G1A8W1I;VXN<&AP.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R
M(")3:2!E)R!V97)I9FEC871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%Z:6]N
M92!D96QL)V5V96YT;SH@)7,N(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HX
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@961I
M=&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(E-I(&4G('9E<FEF:6-A=&\@
M=6X@97)R;W)E(&YE;&QA('9I<W5A;&EZ>F%Z:6]N92!D96QL)V5V96YT;SH@
M)7,N(@H*(SH@;&EB+V%P:2YP:'`Z,S,X(&QI8B]A<&DN<&AP.C4Y-@HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D5R<F]R92!N96QL)VEM<&]R=&%Z
M:6]N92!D96D@9&%T:2!I0V%L96YD87(Z("5S+B(*"B,Z(&5D:71E=F5N=&%C
M=&EO;BYP:'`Z-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(D5R<F]R92!N
M96QL)V5L:6UI;F%Z:6]N92!D96P@979E;G1O.B`E<RXB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E
M<SH@)7,B"FUS9W-T<B`B17)R;W)E(&YE;&PG:6YV:6\@9&5L('1U;R!I;G9I
M=&\@82`E<SH@)7,B"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H97)E('=E
M<F4@;F\@979E;G1S('1O(&5X<&]R="XB"FUS9W-T<B`B3F]N(&,G97)A;F\@
M979E;G1I(&1A(&5S<&]R=&%R92XB"@HC.B!D871A+G!H<#HQ.#0*;7-G:60@
M(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
M26P@9F]M871O(&1I('%U97-T;R!F:6QE(&YO;B#H('-U<'!O<G1A=&\N(@H*
M(SH@9&%T82YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(E%U97-T;R#H('%U
M96QL;R!C:&4@:6P@<V5V97(@:&$@:6YD:6-A=&\Z("5S(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q.`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,0IM<V=I
M9"`B5&AU<G-D87DB"FUS9W-T<B`B1VEO=F5D["(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHS-PIM<V=I9"`B5&EM92!3<%]A;B(*;7-G<W1R
M(")'97-T:6]N92!D96P@5&5M<&\B"@HC.B!T96UP;&%T97,O961I="]E9&ET
M7W1I;65S<&%N+FEN8SHT"FUS9VED(")4:6UE('-P86XB"FUS9W-T<B`B1V5S
M=&EO;F4@9&5L(%1E;7!O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.C,V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0P"FUS
M9VED(")4:71?;&4B"FUS9W-T<B`B5&ET;VQO(@H*(SH@9&%T82YP:'`Z-30@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"B,Z('1E;7!L871E<R]S
M96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z,PIM<V=I9"`B5&ET;&4B"FUS9W-T
M<B`B5&ET;VQO(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R
M,B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$R-PIM<V=I9"`B5&]D87DB"FUS9W-T<B`B3V=G:2(*"B,Z
M(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C0@;&EB+T)L;V-K+VUO
M;G1H;&ES="YP:'`Z,3(S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,CD*
M;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(D1O;6%N:2(*"B,Z('EE87(N<&AP
M.C@T('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8P('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P
M-0IM<V=I9"`B5'4B"FUS9W-T<B`B36%R(@H*(SH@=&5M<&QA=&5S+VUO;G1H
M+VAE860N:6YC.C$W('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-@HC.B!T
M96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV.0IM<V=I9"`B5'5E<V1A
M>2(*;7-G<W1R(")-87)T963L(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD
M:7-T.C$W"FUS9VED(")4>7!E(@IM<V=S='(@(E1I<&\B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3@S"FUS9VED(")54DPB"FUS
M9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HV-`IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@8V]N;F5T=&5R<VD@86P@<V5R=F5R(%-13"XB"@HC.B!C86QE;F1A
M<G,N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@7"(E<UPB.B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!E;&EM:6YA<F4@
M7"(E<UPB.B`E<R(*"B,Z(&QI8B]$<FEV97(O;6-A;"YP:'`Z,3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,N(@IM<V=S='(@
M(DEM<&]S<VEB:6QE(&5L:6UI;F%R92`E<RXB"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A<FEC
M87)E(&QE(&1E9FEN:7II;VYI(&1I("5S+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z
M-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!<(B5S
M7"(Z("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!<(B5S7"(Z
M("5S(@H*(SH@;&EB+U-T;W)A9V4O:V]L86(N<&AP.C,T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G<W1R("(B"B)3:2!E)R!V97)I9FEC
M871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%Z:6]N92!D96QL92!I;F9O<FUA
M>FEO;FD@;&EB97)O+R(*(F]C8W5P871O(&1E;&PG=71E;G1E("5S.B`E<RXB
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-0HC.B!S8W)I<'1S+W5P
M9W)A9&5S+S(P,#0M,#4M,3E?8V]N=F5R=%]C871E9V]R:65S7W1O7W-T<FEN
M9W,N<&AP.C4S"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DYO;B!!<F-H:79I
M871O(@H*(SH@;&EB+V%P:2YP:'`Z,S<V(&QI8B]A<&DN<&AP.C0U,"!L:6(O
M87!I+G!H<#HU,38@;&EB+V%P:2YP:'`Z-C(Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S
M='(@(D5S=&5N<VEO;F4@3F]N(%-U<'!O<G1A=&$B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#$T"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960Z("5S
M+B(*;7-G<W1R(")!9V=I;W)N871O.B`E<RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`*;7-G:60@(E5S97(@26YT97)F86-E(@IM<V=S='(@(DEN
M=&5R9F%C8VEA(%5T96YT92(*"B,Z('EE87(N<&AP.C$V,R!Y96%R+G!H<#HQ
M-CD@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ-3D@;&EB+T)L;V-K+VUO;G1H+G!H
M<#HQ-C(*;7-G:60@(E9I97<@1&%Y(@IM<V=S='(@(E9I<W5A;&EZ>F$@1VEO
M<FYO(@H*(SH@>65A<BYP:'`Z.#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-C$@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(P"B,Z(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")792(*;7-G<W1R(")-97(B"@HC
M.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3@@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3$W"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC
M.C<P"FUS9VED(")7961N97-D87DB"FUS9W-T<B`B365R8V]L963L(@H*(SH@
M871T96YD965S+G!H<#HQ,3(@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,"!L:6(O
M0FQO8VLO=')E95]M96YU+G!H<#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#,*;7-G:60@(E=E96LB"FUS9W-T<B`B4V5T=&EM86YA(@H*(SH@;6]N
M=&@N<&AP.C$W.2!W;W)K=V5E:RYP:'`Z,S`@=V5E:RYP:'`Z,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5E:R`E9"(*;7-G<W1R(")3971T:6UA;F$@)60B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU.2!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ-#`*;7-G:60@(E=E96LH<RDB"FUS9W-T<B`B4V5T=&EM
M86YA*&4I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(Q-0IM<V=I9"`B5V5E:VQY.B!296-U<G,@
M979E<GDB"FUS9W-T<B`B4V5T=&EM86YA;&UE;G1E.B!3:2!R:7!E=&4@;V=N
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(B(*(E=H
M870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T
M:&5R92!A<F4@;F\@;&%T97(@979E;G1S/R(*;7-G<W1R("(B"B)!(&-H92!O
M<F$@9&5V;VYO(&9I;FER92!I;"!G:6]R;F\@92!L82!S971T:6UA;F$L('%U
M86YD;R!N;VX@8VD@<V]N;R!E=F5N=&D@(@HB<W5C8V5S<VEV:3\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED("(B"B)7:&%T('1I;64@
M<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A
M<F4@;F\@96%R;&EE<B!E=F5N=',_(@IM<V=S='(@(B(*(D$@8VAE(&]R82!D
M979O;F\@:6YI>FEA<F4@:6P@9VEO<FYO(&4@;&$@<V5T=&EM86YA+"!Q=6%N
M9&\@;F]N(&-I('-O;F\@(@HB979E;G1I('!R96-E9&5N=&D_(@H*(SH@871T
M96YD965S+G!H<#HQ,3$@;&EB+TMR;VYO;&ET:"YP:'`Z,3(X.2!L:6(O0FQO
M8VLO=')E95]M96YU+G!H<#HR,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#0*;7-G:60@(E=O<FL@5V5E:R(*;7-G<W1R(")3971T:6UA;F$@;&%V;W)A
M=&EV82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$R.3(@;&EB+T)L;V-K+W1R
M965?;65N=2YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(EEE87(B"FUS9W-T<B`B
M0V5R8V$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C0Q"FUS9VED(")996%R;'DZ(%)E8W5R<R!E
M=F5R>2(*;7-G<W1R(")!;FYU86QM96YT93H@4VD@<FEP971E(&]G;FDB"@HC
M.B!D871A+G!H<#HT,"!D871A+G!H<#HR,S0@961I=&5V96YT86-T:6]N+G!H
M<#HT-B!A9&1E=F5N="YP:'`Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&5V96YT
M<RXB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HT.0IM<V=I9"`B66]U(&%R
M92!N;W0@86X@871T96YD964@;V8@=&AE('-P96-I9FEE9"!E=F5N="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW
M-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T:&ES(&9O<FT@9G)O;2!T:&4@
M161I="!!='1E;F1E97,@<V-R965N+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HY-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R960@
M:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO;B`B"B)/<'1I;VYS+B!9;W4@
M;75S="!S970@;VYE("5S:&5R925S(&)E9F]R92!E=F5N="!N;W1I9FEC871I
M;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B"B).;VX@:&%I(&YE<W-U;B!I
M;F1I<FEZ>F\@96UA:6P@<W!E8VEF:6-A=&\@;F5L;&4@='5E('!R969E<F5N
M>F4N($1E=FD@(@HB<V5T=&%R92!U;B!I;F1I<FEZ>F\@<')I;6$@8VAE(&QE
M(&YO=&EF:6-H92!D:2!E=F5N=&D@<VD@<&]S<V]N;R!I;G9I87)E+B(*"B,Z
M(&%D9&5V96YT86-T:6]N+G!H<#HR,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O("5S
M+B(*;7-G<W1R(").;VX@:&%I(&EL('!E<FUE<W-O(&1I(&%G9VEU;F=E<F4@
M979E;G1I(&$@)7,N(@H*(SH@9&%T82YP:'`Z,3DT"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE
M8W1E9"!C86QE;F1A<BXB"FUS9W-T<B`B3F]N(&AA:2!I;"!P97)M97-S;R!D
M:2!A9V=I=6YG97)E(&5V96YT:2!A;"!C86QE;F1A<FEO('-E;&5Z:6]N871O
M+B(*"B,Z(&1E;&5V96YT86-T:6]N+G!H<#HR-@IM<V=I9"`B66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N(@IM<V=S
M='(@(DYO;B!H86D@:6P@<&5R;65S<V\@9&D@8V%N8V5L;&%R92!L)V5V96YT
M;RXB"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C<X"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N(@IM<V=S
M='(@(DYO;B!H86D@:6P@<&5R;65S<V\@9&D@;6]D:69I8V%R92!Q=65S=&\@
M979E;G1O+B(*"B,Z(&1A=&$N<&AP.C$X.0IM<V=I9"`B66]U(&AA=F4@<W!E
M8VEF:65D(&%N(&EN=F%L:60@8V%L96YD87(N(@IM<V=S='(@(DAA:2!S<&5C
M:69I8V%T;R!U;B!C86QE;F1A<FEO(&YO;B!V86QI9&\N(@H*(SH@871T96YD
M+G!H<#HR,0IM<V=I9"`B66]U(&AA=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D
M(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@871T
M96YD+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@<W5C8V5S<V9U
M;&QY(&1E8VQI;F5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T
M<B`B3F]N(&AA:2!I;"!P97)M97-S;R!D:2!C86YC96QL87)E(&PG979E;G1O
M+B(*"B,Z(&%T=&5N9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E
M('1E;G1A=&EV96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N
M="XB"FUS9W-T<B`B3F]N(&AA:2!I;"!P97)M97-S;R!D:2!C86YC96QL87)E
M(&PG979E;G1O+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.3$*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(D1E=FD@<V5L97II;VYA<F4@=6X@8V%L96YD87)I;R!D82!E;&EM:6YA<F4B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C4T"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B
M1&5V:2!S96QE>FEO;F%R92!U;B!I;F1I<FEZ>F\@<')I;6$N(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3`Y-`IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B
M92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@861D960@=&\@>6]U<B!C86QE
M;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,#0*
M;7-G:60@(B(*(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E
M=F5N=',@87)E(&1E;&5T960@9G)O;2!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y.0IM<V=I9"`B66]U(')E
M<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@961I=&5D
M(&EN('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O4V-H961U
M;&5R+VMR;VYO;&ET:"YP:'`Z,C`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(')E;6EN9&5D(&%B;W5T("5S+"!W
M:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B2&%I(')I8VAI97-T;R!D
M:2!E<W-E<F4@<F%M;65N=&%T;R!D:2`E<RP@8VAE(.@@86QL92`E<RXB"@HC
M.B!T96UP;&%T97,O<')E9G,O<VAA<F5S96QE8W0N:6YC.C$P"FUS9VED(")9
M;W5R(&1E9F%U;'0@8V%L96YD87(B"FUS9W-T<B`B26P@='5O(&-A;&5N9&%R
M:6\@9&D@9&5F875L="(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-3,@;&EB+T1R
M:79E<BYP:'`Z,3`V,PIM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@
M(EM%=F5N=&\@<V5N>F$@;F]M95TB"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHY-PHC+"!F=7IZ>0IM<V=I9"`B7T%L87)M(@IM<V=S='(@(D%L;&%R
M;64B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z
M,3$*;7-G:60@(E]"87-I8R!396%R8V@B"FUS9W-T<B`B7U)I8V5R8V$@5F5L
M;V-E(@H*(SH@=FEE=V5V96YT+G!H<#HQ,C`*;7-G:60@(E]%9&ET(@IM<V=S
M='(@(E]-;V1I9FEC82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S`*;7-G
M:60@(E]';W1O(@IM<V=S='(@(E]686D@82(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$S,S8*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(E]);7!O
M<G1A+T5S<&]R=&$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S$X"B,L(&9U
M>GIY"FUS9VED(")?37D@0V%L96YD87)S(@IM<V=S='(@(DUI96D@0V%L96YD
M87)I(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,R-0IM<V=I9"`B7TYE=R!%
M=F5N="(*;7-G<W1R(")?3G5O=F\@179E;G1O(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,T,0IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(E]3=&%M<&$B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,R"FUS9VED(")?4V5A<F-H(@IM<V=S
M='(@(E]#97)C82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,C@*;7-G:60@
M(E]4;V1A>2(*;7-G<W1R(")?3V=G:2(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C$T,@IM<V=I9"`B8F5F;W)E('1H92!E=F5N="!S=&%R=',B"FUS
M9W-T<B`B<')I;6$@8VAE(&EN:7II82!L)V5V96YT;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G<W1R(")G:6]R;F\B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C$P"FUS9VED(")D87DH<RDB"FUS9W-T<B`B9VEO<FYO
M*&DI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(F=I;W)N:2(*"B,Z(&1A
M=&$N<&AP.C$T-R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@
M(F5V96YT<RYC<W8B"FUS9W-T<B`B979E;G1I+F-S=B(*"B,Z(&1A=&$N<&AP
M.C$V.`HC+"!F=7IZ>0IM<V=I9"`B979E;G1S+FEC<R(*;7-G<W1R(")E=F5N
M=&DN8W-V(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M,S$*;7-G:60@(F9R;VTB"FUS9W-T<B`B9&$B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,"!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,S8*;7-G:60@(FUO;G1H*',I(@IM<V=S='(@(FUE<V4H:2DB
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")O;B`E<R!A="`E<R(*;7-G<W1R(")%=F5N=&D@9&$@)7,@
M82`E<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,S`*;7-G:60@(F]N('1H92!S86UE(&1A=&4B
M"FUS9W-T<B`B86QL82!S=&5S<V$@9&%T82(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$R-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S8*;7-G
M:60@(F]N('1H92!S86UE('=E96MD87DB"FUS9W-T<B`B;&\@<W1E<W-O(&=I
M;W)N;R!F97)I86QE(@H*(SH@9&%T82YP:'`Z,S`@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B=D-A;&5N9&%R+VE#86QE
M;F1A<B(*;7-G<W1R(")#86QE;F1A<FD@0V]N9&EV:7-I(@H*(SH@;&EB+V%P
M:2YP:'`Z,S0Y(&QI8B]A<&DN<&AP.C8P-PIM<V=I9"`B=D5V96YT(&YO="!F
M;W5N9"XB"FUS9W-T<B`B=D5V96YT(&YO;B!T<F]V871O+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.3$*;7-G:60@(G=E96LB"FUS9W-T<B`B<V5T
M=&EM86YA(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(Q-PIM<V=I9"`B=V5E:RAS*2!O;CHB"FUS
M9W-T<B`B<V5T=&EM86YA*&4I('-U.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.3(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PHC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DT"FUS9VED(")W965K<R(*;7-G<W1R(")S971T
M:6UA;F4B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C0R"FUS9VED(")Y96%R*',I(@IM<V=S='(@
M(F%N;F\H:2DB"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W!O+VMR;VYO;&ET:"YP;W0`````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$Q,#0W-0`Q,#0Q-S,V,C<U
M,P`P,C$V,34`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(R!33TU%($1%4T-225!4259%(%1)5$Q%+@HC($-O<'ER:6=H="`H
M0RD@645!4B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U
M=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(%!!0TM!1T4@<&%C
M:V%G92X*(R!&25)35"!!551(3U(@/$5-04E,0$%$1%)%4U,^+"!914%2+@HC
M"B,L(&9U>GIY"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S
M:6]N.B!004-+04=%(%9%4E-)3TY<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-BTP,RTP-B`Q,CHT-RLP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B!9
M14%2+4U/+41!($A/.DU)*UI/3D5<;B(*(DQA<W0M5')A;G-L871O<CH@1E5,
M3"!.04U%(#Q%34%)3$!!1$1215-3/EQN(@HB3&%N9W5A9V4M5&5A;3H@3$%.
M1U5!1T4@/$Q,0&QI+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0TA!4E-%5%QN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D(&-A;&5N9&%R<R!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!E=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T
M:6UE<W!A;BYI;F,Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S($1A>2AS
M*2`E<R!(;W5R*',I("5S($UI;G5T97,B"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3@P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A='1E;F1E
M97,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@
M(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z,3`U(&QI8B]B87-E+G!H<#HQ,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,3<*;7-G:60@(B(*
M(BA#;&EC:R!O;B!C86QE;F1A<B!N86UE('1O('-W:71C:"!T:&4@8V%L96YD
M87(G<R!V:7-I8FEL:71Y(&EN('1H92!M86EN("(*(G=I;F1O=RDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C4*
M;7-G:60@(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($%D9"`J(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,34Q"FUS
M9VED("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(B
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#`T"FUS9VED("(Q(&%T=&5N9&5E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"FUS
M9VED("(Q(&5V96YT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S<*;7-G:60@(C$@:&]U<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,T"FUS9VED("(Q-2!M:6YU=&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(C(P(&UI
M;G5T97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-@IM<V=I9"`B,S`@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHQ-CD*;7-G:60@(CQS=')O;F<^071T96YD965S/"]S
M=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,30W"FUS9VED("(\<W1R;VYG/D1E<V-R:5]P=&EO;CPO
M<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(W-`IM<V=I9"`B/'-T<F]N9SY+97EW;W)D<SPO<W1R
M;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C$Y,@IM<V=I9"`B/'-T<F]N9SY296-U<G)E;F-E/"]S=')O
M;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.3,*
M;7-G:60@(D%-(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8P
M,@IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9%]V86YC960@4V5A<F-H(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,38P"FUS9VED(")!9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C(*;7-G:60@(D%D9"!%=F5N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHS-0IM
M<V=I9"`B061D(&$@;F5W(%)E;6]T92!#86QE;F1A<B(*;7-G<W1R("(B"@HC
M.B!A9&1E=F5N="YP:'`Z-C0*;7-G:60@(D%D9"!A(&YE=R!E=F5N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z
M-S$*;7-G:60@(D%D9"!A='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#4*;7-G:60@(D%D9"!T;R!A
M='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(X"B,Z('1E;7!L871E<R]A
M='1E;F1E97,O871T96YD965S+FEN8SHW-`IM<V=I9"`B061D<F5S<R!";V]K
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHX('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I
M9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C4S"FUS9VED(")!;&%R;2(*;7-G<W1R("(B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ-S@P"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M
M("5D(&1A>7,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$W.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@:&]U<G,@8F5F
M;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B06QA<FT@)60@;6EN=71E<R!B969O<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<W-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!;&%R;2`E9"!W965K<R!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<W.0IM<V=I9"`B06QA<FT@,2!D87D@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.#0*;7-G:60@(D%L87)M
M(#$@:&]U<B!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<X.0IM<V=I9"`B06QA<FT@,2!M:6YU=&4@8F5F;W)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S0*;7-G:60@(D%L87)M(#$@=V5E:R!B
M969O<F4B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-3D*;7-G:60@(D%L87)M
M($1A=&4B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-3@*;7-G:60@(D%L87)M
M(%-P86X@*&UI;G5T97,I(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C8P"FUS
M9VED(")!;&%R;2!4:6UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D96QE
M=&4O9&5L971E+FEN8SHS-`IM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&0E9I97<N<&AP.C$R."!L:6(O1D)6:65W+G!H<#HQ,S$@;&EB+T9"5FEE
M=RYP:'`Z,3,T"FUS9VED(")!;&P@071T96YD965S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU.0IM<V=I9"`B06QL($9U
M='5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z-3,*;7-G:60@(D%L;"!087-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]P<F5V;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C(T
M"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HR-0IM<V=I9"`B06QL(%9I<VEB;&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3(R(&QI8B]$87E6
M:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z.3,*(SH@;&EB+U=E96M6:65W
M+G!H<#HQ,C<@;&EB+U=E96M6:65W+G!H<#HQ,S0@;&EB+T1R:79E<BYP:'`Z
M,3@V-PIM<V=I9"`B06QL(&1A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,38T"FUS9VED(")!;&P@9&%Y(&5V96YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S,*;7-G:60@(D%L
M;"!E=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8VA?861V86YC960N:6YC.C0X"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHW,"!L:6(O2W)O;F]L:71H+G!H<#HV.34*;7-G:60@
M(D%N>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHW,0IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,SD@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHX,B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$V.`IM<V=I9"`B070B
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`T-@IM<V=I9"`B
M(@HB071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@=VET:"!M;W)E(&EN
M9F]R;6%T:6]N(&%B;W5T('1H92!E=F5N="X@268@>6]U<B`B"B)M86EL(&-L
M:65N="!S=7!P;W)T<R!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E('1H:7,@
M9FEL92!T;R!E87-I;'D@=7!D871E("(*(GEO=7(@;&]C86P@8V]P>2!O9B!T
M:&4@979E;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHT,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C4*
M;7-G:60@(D%T=&5N9&%N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,38Q"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S4*;7-G:60@(D%U
M9W5S="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A
M9'9A;F-E9"YI;F,Z,3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C@*
M;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:V5Y
M=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&0E9I97<N<&AP.CDP(&QI8B]&0E9I97<N<&AP.C$Q,0IM<V=I
M9"`B0G5S>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:%]A9'9A;F-E9"YI;F,Z-#(*;7-G:60@(D-?86QE;F1A<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHT-PIM<V=I9"`B0V%L7V5N
M9&%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ-#D@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(Q"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C$@;&EB+T)L;V-K+VUO;G1H;&ES="YP
M:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PIM<V=I
M9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR
M,S,*;7-G:60@(D-A;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-PIM<V=I9"`B0V%L96YD87)S(@IM<V=S
M='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z,C<*;7-G:60@(D-A;&5N9&%R<R!M
M=7-T(&AA=F4@82!N86UE+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-#@*
M;7-G:60@(D-A;B=T(&-R96%T92!A(&YE=R!E=F5N="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,S('1E;7!L871E<R]D96QE
M=&4O9&5L971E+FEN8SHS-0HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS
M,2!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#<*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S@*;7-G:60@(D-A
M;F-E;&QE9"(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;F-E;&QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C8S
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C8W"FUS9VED(")#871E9V]R7WDB
M"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-C(@=&5M<&QA=&5S+W-E87)C:"]E
M=F5N=%]H96%D97)S+FEN8SHT('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$S
M"FUS9VED(")#871E9V]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C<Y"FUS9VED("(B"B)#:&]O<V4@:68@>6]U('=A;G0@=&\@
M8F4@;F]T:69I960@;V8@;F5W+"!E9&ET960L(&%N9"!D96QE=&5D(&5V96YT
M<R!B>2`B"B)E;6%I;#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4R"FUS9VED(")#:&]O<V4@:68@>6]U('=A;G0@=&\@8F4@;F]T
M:69I960@;V8@;F5W+"!E9&ET960L(&%N9"!D96QE=&5D(&5V96YT<RXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y,@IM<V=I9"`B
M0VAO;W-E(&EF('EO=2!W86YT('1O(')E8V5I=F4@96UA:6P@<F5M:6YD97)S
M(&9O<B!E=F5N=',@=VET:"!A;&%R;7,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S96%R8VA?86)O;VM?<V5L96-T+FEN8SHQ.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$R"FUS9VED(")#:&]O<V4@=&AE(&%D9')E<W,@
M8F]O:W,@=&\@<V5A<F-H(&9O<B!F<F5E+V)U<WD@55),<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V9B7V-A;'-?<V5L96-T+FEN8SHQ-@IM
M<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!I;B!Y;W5R
M(&9R964O8G5S>2!I;F9O<FUA=&EO;CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,R-`IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A
M<G,@=&\@:6YC;'5D92!W:&5N(&=E;F5R871I;F<@9G)E92]B=7-Y(%523',Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I
M9"`B0VAO;W-E('EO=7(@9&5F875L="!C86QE;F1A<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C@T"FUS9VED
M(")#;&5A<B!A;&P@871T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS9VED(")#;&]S92!W:6YD
M;W<B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C@@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,*;7-G:60@
M(D-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S/R(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HU-S4*;7-G:60@(D-O;F9I<FUE9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C$W
M"FUS9VED(")#;W!Y('1H92!54DP@8F5L;W<@9F]R('5S92!W:&5R979E<B!Y
M;W4@;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ(@IM<V=S='(@(B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C$R.0IM<V=I9"`B0W)E871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,34*
M;7-G:60@(D-R96%T92!#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!M;VYT:"YP
M:'`Z,38S('1E;7!L871E<R]W965K+VAE860N:6YC.C(U('1E;7!L871E<R]D
M87DO<F]W+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE
M=RYP:'`Z,3DU"FUS9VED(")#<F5A=&4@82!.97<@179E;G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#`*;7-G:60@(D-R96%T
M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC
M.C,R"FUS9VED(")#=7)R96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#8*
M;7-G:60@(D1A:6QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B(@H*(SH@871T
M96YD965S+G!H<#HQ,#8@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,2!L:6(O0FQO
M8VLO=')E95]M96YU+G!H<#HR,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#(*;7-G:60@(D1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHV,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S<*;7-G:60@
M(D1A>2AS*2(*;7-G<W1R("(B"@HC.B!V:65W979E;G0N<&AP.C$Q,PIM<V=I
M9"`B1&5?;&5T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]G;W1O+FEN8SHW.0IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-C`U"FUS9VED(")$96-L:6YE9"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<*;7-G:60@(D1E9F%U
M;'0@0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C(P-"!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z
M,S(*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI
M;F,Z,C,@;&EB+T1R:79E<BYP:'`Z,3@T.`IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(B(*"B,Z(&1E;&5V96YT+G!H<#HT,"!T96UP;&%T97,O9&5L971E+V]N
M92YI;F,Z,C$@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(Q"B,Z(&QI
M8B]$<FEV97(N<&AP.C$X-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M("5S(@IM<V=S='(@(B(*"B,Z(&5D:71E=F5N="YP:'`Z-S(*;7-G:60@(D1E
M;&5T92!%=F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&5L971E+V1E
M;&5T92YI;F,Z,S`*;7-G:60@(B(*(D1E;&5T92!T:&4@8W5R<F5N="!E=F5N
M="!O;FQY+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E
M;F-E<RP@;W(@(@HB86QL(&]C8W5R96YC97,_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,#,@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X"FUS9VED(")$97-C<FE?<'1I;VXB
M"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-C$@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C$W.`HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHY-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S0*;7-G:60@(D1I<W!L87DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C8S"FUS9VED(")$:7-P;&%Y($-A;&5N9&%R<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X"FUS9VED(")$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P"FUS9VED(")$;R!Y;W4@=V%N="!T;R!S:&]W('1A<VMS('=H:6-H(&%R
M92!D=64@;VX@>6]U<B!C86QE;F1A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z-30U"FUS9VED(")$;V5S(&YO="!R96-U<B(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1'5E.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E
M9&ET7W1I;65S<&%N+FEN8SHQ,34*;7-G:60@(D1U<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S,@
M;&EB+T1R:79E<BYP:'`Z,3@S-`IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC
M.B!E9&ET979E;G0N<&AP.C,S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R
M(&QI8B]$<FEV97(N<&AP.C$X,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M.#4*;7-G:60@(D5D:70@071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#,*;7-G:60@(D5D:70@
M0V%L96YD87)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-3`*;7-G:60@(D5D:70@4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R("(B
M"@HC.B!A='1E;F1E97,N<&AP.C$T-@IM<V=I9"`B161I="!A='1E;F1E97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N9"YI;F,Z
M,C`*;7-G:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<W('1E
M;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M-C`*;7-G:60@(D5N7V0B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-38*;7-G
M:60@(D5N9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M979E;G1?:&5A9&5R<RYI;F,Z."!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R,`IM<V=I9"`B16YD
M($]N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4W"FUS9VED(")%;F0@5&EM
M92(*;7-G<W1R("(B"@HC.B!A='1E;F1E97,N<&AP.C$R,"!A='1E;F1E97,N
M<&AP.C$S,2!A='1E;F1E97,N<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@
M)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,3,*
M;7-G:60@(D5V96YT(&%D9&5D.B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,3(S"FUS9VED(")%=F5N="!D96QE=&5D.B(*;7-G<W1R("(B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$X"FUS9VED(")%=F5N="!E9&ET
M960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B179E;G0@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O1')I=F5R+W-Q;"YP:'`Z,S<S"FUS9VED(")%=F5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S8X"FUS9VED
M(")%=F5N=',@;75S="!H879E(&$@<W1A<G0@9&%T92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z-S,T"FUS9VED(")%=F5N=',@;75S="!H879E
M(&$@=&ET;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHW-0IM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3DY"FUS9VED(")%
M>'!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHX"FUS9VED(")%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-CD*;7-G:60@(D9E8G)U87)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3,S"FUS9VED(")&:6YD(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP.C@T
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8S('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM
M<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3@Q
M"FUS9VED(")&<F5E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU.`IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,"!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z-S(*;7-G:60@(D9R:61A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&5L971E+V1E;&5T92YI;F,Z,S,*;7-G:60@(D9U='5R92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D=A
M;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C(S"FUS9VED(")'96YE<F%L(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1V]T;R`E<R(*;7-G<W1R("(B"@HC.B!M;VYT:"YP:'`Z,3,S('1E;7!L871E
M<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O
M9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`IM<V=I9"`B2&ED92(*;7-G
M<W1R("(B"@HC.B!M;VYT:"YP:'`Z,3,S('1E;7!L871E<R]W965K+VAE861?
M<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED
M95]B>5]S:61E+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(:61E("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8U('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C$S-@IM<V=I9"`B2&]U<BAS*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")(
M;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@=&AE(&1A>2!A;F0@
M=V5E:R!V:65W<R!B93\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,P,0IM<V=I9"`B2&]W(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@
M:6YF;W)M871I;VX@<VAO=6QD('=E(&=E;F5R871E/R(*;7-G<W1R("(B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#4P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(DEF('EO=7(@96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP
M(')E<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T:&4@(@HB9F]L;&]W:6YG
M(&QI;FMS('1O(&%C8V5P="!O<B!D96-L:6YE('1H92!E=F5N="Y<;B(*(EQN
M(@HB5&\@86-C97!T('1H92!E=F5N=#I<;B(*(B5S7&XB"B)<;B(*(E1O(&%C
M8V5P="!T:&4@979E;G0@=&5N=&%T:79E;'DZ7&XB"B(E<UQN(@HB7&XB"B)4
M;R!D96-L:6YE('1H92!E=F5N=#I<;B(*(B5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0@0V%L96YD87(L(%-T97`@)60B"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z,C@X"FUS9VED("));7!O<G0O17AP;W)T($-A;&5N9&%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8X"FUS
M9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<T"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<S"FUS9VED(")*=6YE(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C8T('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$T,@IM<V=I9"`B2V5Y=V]R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C4U"FUS9VED("),87-T(#(T(&AO=7)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C@W"FUS
M9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-`HC.B!T96UP;&%T97,O;6]N
M=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,38@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C0*;7-G:60@(DQA<W0@36]N=&@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-`IM<V=I9"`B3&%S="!996%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-"!T96UP
M;&%T97,O=V5E:R]H96%D+FEN8SHS"FUS9VED("),87-T('=E96LB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR.0IM<V=I9"`B
M3&EM:70@=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHX-2!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHW-`IM<V=I9"`B3&]?8V%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C8S('1E;7!L871E<R]S96%R8V@O979E;G1?
M:&5A9&5R<RYI;F,Z-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M
M86YA9V5M96YT+FEN8SHQ.`HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A
M;%]M86YA9V5M96YT+FEN8SHU,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR
M,0HC.B!L:6(O1')I=F5R+G!H<#HQ.#@T"FUS9VED("),;V-A=&EO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*;7-G:60@(DUA
M;F%G92!R96UO=&4@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,`IM<V=I9"`B36%R8V@B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!%=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ.#@Q"FUS9VED(")-92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(DUE971I;F<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?86QA<FUS+G!H<#HS"FUS9VED(")-
M96YU($%L87)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=')E95]M96YU
M+G!H<#HS"FUS9VED(")-96YU($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z-C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,3,U"FUS9VED(")-:6YU=&4H<RDB"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z
M.#`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-3D@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C$U"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U
M"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A
M9"YI;F,Z,38@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$U"B,Z('1E;7!L
M871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8X(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#8*;7-G:60@(DUO;F1A>2(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,S$T(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(T(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0IM<V=I9"`B36]N=&@B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS"FUS9VED(")-;VYT:"!6:65W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C,@;&EB
M+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#,*;7-G:60@(DUO;G1H;'D@179E;G1S
M($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,C8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,R
M"FUS9VED(")-;VYT:&QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!!:&5A
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z
M,C0*;7-G:60@(DUO;G1H<R!"969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z-C,S"FUS9VED(")-=6QT:7!L92!I0V%L96YD87(@8V]M<&]N96YT
M<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT(&ES('-U<'!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C<P"FUS9VED(")->2!#86QE;F1A<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M96YU
M+FEN8SHS-@IM<V=I9"`B37D@0V%L96YD87)S.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C$S"FUS9VED(")-
M>2!&<F5E+T)U<WD@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ,C`@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C$V,@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$W-@HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA
M9V5M96YT+FEN8SHQ-PHC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M
M86YA9V5M96YT+FEN8SHT-`IM<V=I9"`B3F%M92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]N=&@N<&AP.C0Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C0T(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT,0HC.B!L:6(O0FQO8VLO=')E
M95]M96YU+G!H<#HR,`IM<V=I9"`B3F5W($5V96YT(@IM<V=S='(@(B(*"B,Z
M(&QI8B]B87-E+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB3F5W
M(&-A;&5N9&%R(&-R96%T960@86YD(&%U=&]M871I8V%L;'D@<VAA<F5D('=I
M=&@@=&AE(&9O;&QO=VEN9R!G<F]U<"AS*3H@)2(*(G,N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S,*;7-G:60@(DYE>'0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4W
M"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&QI8B]&0E9I
M97<O9&%Y+G!H<#HR.0IM<V=I9"`B3F5X="!$87DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHV"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ."!T96UP;&%T
M97,O;6]N=&@O:&5A9"YI;F,Z-@IM<V=I9"`B3F5X="!-;VYT:"(*;7-G<W1R
M("(B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C,R"FUS9VED(").97AT(%=E
M96LB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-@IM
M<V=I9"`B3F5X="!996%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D87DO
M:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!D87DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4X('1E;7!L871E<R]W965K+VAE
M860N:6YC.C4*;7-G:60@(DYE>'0@=V5E:R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C<U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M.#@*;7-G:60@(DYO(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C<S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$R-`IM<V=I9"`B
M3F\@86QA<FTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C0X"FUS9VED(").;R!A='1E;F1E97,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,`IM<V=I9"`B3F\@8V%L96YD
M87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S8@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C4R"FUS9VED(").;R!E;F0@9&%T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M;VYT
M:&QI<W0N<&AP.C$V,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT"FUS
M9VED(").;R!E=F5N=',@=&\@9&ES<&QA>2(*;7-G<W1R("(B"@HC.B!L:6(O
M4W1O<F%G92]K;VQA8BYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,S0T(&QI8B]A<&DN<&AP.C8R,PIM
M<V=I9"`B3F\@:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#$*;7-G:60@(DYO(')E
M8W5R<F5N8V4B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3`R
M"FUS9VED(").;R!V86QI9"!E;6%I;"!A9&1R97-S(&9O=6YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8Q,B!L:6(O2W)O;F]L:71H+G!H
M<#HV,S,*;7-G:60@(DYO;F4B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4O
M<W%L+G!H<#HQ-#4*;7-G:60@(DYO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(DYO=&EF:6-A=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z
M-S@*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHU-@IM<V=I9"`B3F]W(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<W"FUS9VED(")/8W1O
M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C$S('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8U
M"FUS9VED(")/;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C<X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3$*;7-G:60@(D]N(&%L
M;"!C86QE;F1A<G,@22!H879E(')E860@86-C97-S('1O(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Y,`IM<V=I9"`B3VX@86QL('-H;W=N(&-A;&5N9&%R<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.#D*;7-G:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8S,`IM<V=I9"`B
M3W!T:6]N86PB"FUS9W-T<B`B(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,3$Y"FUS
M9VED(")/<'1I;VYA;"!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@;&EB+T9"
M5FEE=RYP:'`Z,34T"FUS9VED(")/=F5R=FEE=R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHS-`IM<V=I9"`B3W=N97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")/=VYE<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.30*
M;7-G:60@(E!-(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL
M:7-T+G!H<#HS(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HT,@IM<V=I
M9"`B4&%S="!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,#D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DV
M"FUS9VED(")0871T97)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D96QE
M=&4O;VYE+FEN8SHS,`IM<V=I9"`B4&5R;6%N96YT;'D@9&5L971E('1H:7,@
M979E;G0_(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,R-2!L:6(O87!I
M+G!H<#HT,C$@;&EB+V%P:2YP:'`Z-#DS(&QI8B]A<&DN<&AP.C4W,PHC.B!L
M:6(O87!I+G!H<#HV,#4@;&EB+V%P:2YP:'`Z-CDQ(&QI8B]A<&DN<&AP.C<R
M-PIM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W,`IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q"FUS9VED(")0;W)T86P@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O
M1D)6:65W+V1A>2YP:'`Z,C4*;7-G:60@(E!R979I;W5S($1A>2(*;7-G<W1R
M("(B"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C(V"FUS9VED(")0<F5V:6]U
M<R!7965K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI;F,Z
M,PIM<V=I9"`B4')E=FEO=7,@9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M-#D*;7-G:60@(E)E8W5R(%5N=&EL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$P-@IM<V=I9"`B4F5C=7)R96YC92(*;7-G<W1R
M("(B"@HC.B!D871A+G!H<#HV.`IM<V=I9"`B4F5C=7)R96YC92!$871A(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C8V"FUS9VED(")296-U<G)E;F-E($5N
M9"!$871E(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C8W"FUS9VED(")296-U
M<G)E;F-E($EN=&5R=F%L(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C8U"FUS
M9VED(")296-U<G)E;F-E(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-30X"FUS9VED(")296-U<G,@9&%I;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34U"FUS9VED(")296-U<G,@;6]N=&AL
M>2(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3$*;7-G:60@
M(E)E8W5R<R!W965K;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-34X"FUS9VED(")296-U<G,@>65A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]38VAE9'5L97(O:W)O;F]L:71H+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M:6YD97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHY-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#0*;7-G:60@(E)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE;G4N:6YC.C8P('1E;7!L871E<R]M96YU+FEN8SHV,@IM
M<V=I9"`B4F5M;W1E($-A;&5N9&%R<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y-`IM<V=I9"`B4F5M;W1E
M(%-U8G-C<FEP=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C$*;7-G:60@(E)E;6]V92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(B(*"B,Z
M(&%T=&5N9&5E<RYP:'`Z,3`P"FUS9VED(")296UO=F4@071T96YD964B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,0IM<V=I
M9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O
M<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L
M;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C,W"FUS9VED(")2
M97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O1D)6:65W+G!H<#HY."!L:6(O
M1D)6:65W+G!H<#HQ,SD@;&EB+T9"5FEE=RYP:'`Z,30R(&QI8B]&0E9I97<N
M<&AP.C$T-0IM<V=I9"`B4F5Q=6ER960@071T96YD965S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,R('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C,P.`IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0S
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-@IM<V=I9"`B4F5S<&]N<V4B
M"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#4@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-C0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(P"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")382(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C$@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3(P"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N
M:6YC.C<S"FUS9VED(")3871U<F1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,C`S"FUS9VED(")3879E(@IM
M<V=S='(@(B(*"B,Z('9I97=E=F5N="YP:'`Z,3,U(&5D:71E=F5N="YP:'`Z
M-#D@961I=&5V96YT+G!H<#HU-PIM<V=I9"`B4V%V92!!<R!.97<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C@S
M"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!A9&1E=F5N
M="YP:'`Z-34@961I=&5V96YT+G!H<#HU,@IM<V=I9"`B4V%V92!%=F5N="(*
M;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.CDQ('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,30*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:6YC.C8W('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHX
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,30U(&QI8B]"
M;&]C:R]T<F5E7VUE;G4N<&AP.C(V"FUS9VED(")396%R8V@B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$*;7-G:60@
M(E-E87)C:"!#86QE;F1A<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C8*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHV"FUS
M9VED(")396%R8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN:6YG.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34S
M"FUS9VED(")396QE8W0@82!C86QE;F1A<B!T;R!E9&ET(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V-2!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHS,0HC.B!T96UP;&%T97,O961I="]E9&ET
M7W1I;65S<&%N+FEN8SHX,PIM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S`*;7-G:60@(E-E;&5C="!C
M86QE;F1A<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q"FUS9VED("(B"B)396QE8W0@8V]N9FER;6%T:6]N
M(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE=W,@
M86YD(&-H;V]S92`B"B)D969A=6QT('9I97<N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3@*;7-G:60@(E-E;&5C="!T:&4@
M8V%L96YD87(@=&\@:6UP;W)T('1O.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS9VED(")396QE8W0@=&AE(&-A;&5N
M9&%R*',I('1O(&5X<&]R="!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T
M(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHR-PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B
M4V5L96-T('1H92!F:7)S="!W965K9&%Y.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q"FUS9VED(")396QE8W0@=&AE(&9O
M<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.#0*;7-G:60@(E-E;&5C="!T:&4@=&EM92!S
M<&%N('1O('-H;W<Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-@IM<V=I9"`B4V5L96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@
M<W1A<G1U<#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(R"FUS9VED(")396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@:6X@=&AE
M('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N
M:6YC.C(W('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR-PIM<V=I9"`B
M4V5N9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL(&%T=&5N9&5E<R!W
M:&5N(&1E;&5T:6YG('1H:7,@979E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E-E
M;F0@86X@96UA:6P@=&\@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,3<Y"FUS9VED(")396YD('5P9&%T97,O:6YV:71A=&EO
M;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V96YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<V
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z.#,*;7-G:60@(E-E="!E;F0@9&%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-C4*;7-G
M:60@(E-E="!R96-U<G)E;F-E(&5N9"!D871E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"FUS9VED(")3970@
M<W1A<G0@9&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3D*;7-G:60@(B(*(E-E="!Y;W5R(&9R964O8G5S>2!C86QE;F1A<G,@
M86YD('EO=7(@;W=N(&%N9"!O=&AE<B!U<V5R<R<@9G)E92]B=7-Y(&]P=&EO
M;G,N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4VAA<F4@;F]T(&9O=6YD.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.#(*;7-G:60@
M(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M;G4N:6YC.C0W('1E;7!L871E<R]M96YU+FEN8SHT.0IM<V=I9"`B4VAA<F5D
M($-A;&5N9&%R<SHB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H
M<#HR-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC
M.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHS"FUS9VED
M(")3:&]W($-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-38*;7-G:60@(E-H;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")3
M:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A
M;&5N9&%R('9I97=S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$R"FUS9VED(")3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L96YD
M87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C8*
M;7-G:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N9#\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,PIM<V=I9"`B4VAO=R!O;FQY(&5V
M96YT<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<U"FUS9VED(")3:&]W('-H87)E9"!C
M86QE;F1A<G,@<VED92UB>2US:61E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED(")3:&]W('1A<VMS('5S:6YG(&-A
M=&5G;W)Y(&-O;&]R<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDU"FUS9VED(")3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C
M:"!D87D@:6X@=V5E:R!V:65W<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3$*;7-G:60@(E-T85]R="(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HU-`IM<V=I9"`B4W1A<G0@1&%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC
M.C<@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHS-PIM<V=I9"`B4W1A<G0@3VXB"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-34*;7-G:60@(E-T87)T(%1I;64B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.CDT('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C@S"FUS9VED(")3=&%T7W5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z
M-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR-PIM<V=I9"`B4W1A='5S(@IM
M<V=S='(@(B(*"B,Z('EE87(N<&AP.C<X('EE87(N<&AP.C@W('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C8U"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(R,2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-R!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$P.0IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H96%D+FEN
M8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-3@U(&QI8B]+<F]N;VQI=&@N<&AP.C8P.`IM
M<V=I9"`B5&5N=&%T:79E(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP.C@S('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8R('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(Q.`HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I
M9"`B5&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHW,`IM<V=I9"`B5&AE($5D:70@071T96YD965S('-C<F5E;B!I
M<R!N;R!L;VYG97(@<')E<V5N="X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M8V%L96YD87)S+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L
M96YD87(@7"(E<UPB(&-A;FYO="!B92!D96QE=&5D+B(*;7-G<W1R("(B"@HC
M.B!C86QE;F1A<G,N<&AP.C0P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C
M86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B(@H*
M(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&-A;&5N9&%R<RYP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R96YA;65D('1O(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HU-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*
M;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C$V,PIM
M<V=I9"`B5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A
M<G0@9&%T92XB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@979E;G0@7"(E<UPB(&AA
M<R!B965N(&%D9&5D('1O(%PB)7-<(B!C86QE;F1A<BP@=VAI8V@@:7,@;VX@
M)7,@870@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&5V96YT(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D(&9R;VT@7"(E<UPB(&-A;&5N9&%R+"!W:&EC:"!W
M87,@;VX@)7,@870@)2(*(G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$Q,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&5V96YT
M(%PB)7-<(B!H87,@8F5E;B!E9&ET960@;VX@7"(E<UPB(&-A;&5N9&%R+"!W
M:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@
M;F]T:69I8V%T:6]N('1O("5S('=A<R!S=6-C97-S9G5L;'D@<V5N="XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`T-`IM<V=I9"`B5&AE
M(&9O;&QO=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@
M=&AE(&5V96YT.B(*;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Q"FUS9VED
M("(B"B)4:&4@<F5Q=65S="!W87,@:6YC;VUP;&5T92X@4V]M92!P87)A;65T
M97)S('1H870@87)E(&YE8V5S<V%R>2!T;R!A8V-E<'0@;W(@(@HB9&5C;&EN
M92!A;B!E=F5N="!A<F4@;6ES<VEN9RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]E;7!T>2YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&5V
M96YT<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B
M(@H*(SH@861D979E;G1A8W1I;VXN<&AP.C$X(&5D:71E=F5N=&%C=&EO;BYP
M:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S(@IM<V=S='(@(B(*"B,Z(&%D
M9&5V96YT86-T:6]N+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B
M(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,S."!L:6(O87!I+G!H<#HV
M,3<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!E9&ET979E;G1A8W1I;VXN
M<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!M;W9I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,#DR"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E
M<SH@)7,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3`X"FUS9VED(")4:&5R
M92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C$X-PIM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$Q.`HC.B!T96UP;&%T97,O961I="]J
M879A<V-R:7!T+FEN8SHW,0IM<V=I9"`B5&AU<G-D87DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C,W"FUS9VED(")4:6UE
M(%-P7V%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM
M97-P86XN:6YC.C0*;7-G:60@(E1I;64@<W!A;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,S0@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,S@*;7-G:60@(E1I=%]L92(*;7-G<W1R("(B
M"@HC.B!D871A+G!H<#HU,R!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M,C`*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHS"FUS
M9VED(")4:71L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H
M;&ES="YP:'`Z,3(R(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$R,0HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(W"FUS9VED(")4;V1A>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(T(&QI8B]"
M;&]C:R]M;VYT:&QI<W0N<&AP.C$R,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,3(Y"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!Y96%R+G!H
M<#HX,2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,"!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,38*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ
M,#4*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M;VYT:"]H
M96%D+FEN8SHQ-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,38*(SH@=&5M
M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-CD*;7-G:60@(E1U97-D87DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS
M9VED(")4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHQ.#8*;7-G:60@(E523"(*;7-G<W1R("(B"@HC.B!L
M:6(O4W1O<F%G92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP
M.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HS.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ-0HC.B!S8W)I<'1S+W5P9W)A9&5S+S(P,#0M,#4M
M,3E?8V]N=F5R=%]C871E9V]R:65S7W1O7W-T<FEN9W,N<&AP.C4S"FUS9VED
M(")5;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,W-B!L:6(O
M87!I+G!H<#HT-C`@;&EB+V%P:2YP:'`Z-3,V(&QI8B]A<&DN<&AP.C8T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B57-E<B!);G1E<F9A
M8V4B"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z,38P('EE87(N<&AP.C$V-B!L
M:6(O0FQO8VLO;6]N=&@N<&AP.C$U.2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$V
M,@IM<V=I9"`B5FEE=R!$87DB"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#(@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C$@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C$W"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS
M9VED(")792(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI
M;F,Z,3@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$W"B,Z('1E;7!L871E
M<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<P"FUS9VED(")7961N97-D87DB"FUS
M9W-T<B`B(@H*(SH@871T96YD965S+G!H<#HQ,#@@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3,Q,R!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,PHC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(E=E96LB"FUS9W-T<B`B(@H*(SH@
M;6]N=&@N<&AP.C$W-R!W;W)K=V5E:RYP:'`Z,S`@=V5E:RYP:'`Z,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5E:R`E9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHQ,S@*;7-G:60@(E=E96LH<RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q
M,@IM<V=I9"`B5V5E:VQY.B!296-U<G,@979E<GDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B(@HB5VAA="!T:6UE
M('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD+"!W:&5N('1H97)E(&%R
M92!N;R!L871E<B!E=F5N=',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,34*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y
M(&%N9"!W965K('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L
M:65R(&5V96YT<S\B"FUS9W-T<B`B(@H*(SH@871T96YD965S+G!H<#HQ,#<@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,B!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E=O<FL@
M5V5E:R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S$U(&QI
M8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(U"FUS9VED(")996%R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,S@*;7-G:60@(EEE87)L>3H@4F5C=7)S(&5V97)Y
M(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,Y(&1A=&$N<&AP.C(S.2!E9&ET
M979E;G1A8W1I;VXN<&AP.C0V(&%D9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@979E;G1S+B(*;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Y
M"FUS9VED(")9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF
M:65D(&5V96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C<V"FUS9VED(")9;W4@8V%N(&]N;'D@=7-E('1H:7,@
M9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.CDX.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W4@9&\@;F]T(&AA=F4@86X@96UA:6P@861D<F5S<R!C;VYF
M:6=U<F5D(&EN('EO=7(@4&5R<V]N86P@26YF;W)M871I;VX@(@HB3W!T:6]N
M<RX@66]U(&UU<W0@<V5T(&]N92`E<VAE<F4E<R!B969O<F4@979E;G0@;F]T
M:69I8V%T:6]N<R!C86X@8F4@<V5N="XB"FUS9W-T<B`B(@H*(SH@861D979E
M;G1A8W1I;VXN<&AP.C(P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C$Y-PIM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L
M96YD87(N(@IM<V=S='(@(B(*"B,Z(&1E;&5V96YT86-T:6]N+G!H<#HR-@IM
M<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@9&5L971E('1H
M:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z
M-S@*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&5D:70@
M=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3DR"FUS9VED
M(")9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BXB"FUS
M9W-T<B`B(@H*(SH@871T96YD+G!H<#HR,0IM<V=I9"`B66]U(&AA=F4@<W5C
M8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB
M"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HR-@IM<V=I9"`B66]U(&AA=F4@
M<W5C8V5S<V9U;&QY(&1E8VQI;F5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N
M="XB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HS,0IM<V=I9"`B66]U(&AA
M=F4@=&5N=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V
M96YT+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.CDQ"FUS9VED(")9
M;W4@;75S="!S96QE8W0@82!C86QE;F1A<B!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C4T
M"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$W,PIM<V=I9"`B66]U(&YE960@=&\@<V5L96-T(&$@8V%L96YD87(@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q-`IM<V=I
M9"`B66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A
M<F4@861D960@=&\@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$Q,C0*;7-G:60@(B(*(EEO=2!R97%U97-T960@
M=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&1E;&5T960@9G)O;2!Y
M;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3$Q.0IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W
M:&5N(&5V96YT<R!A<F4@961I=&5D(&EN('EO=7(@8V%L96YD87)S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O4V-H961U;&5R+VMR;VYO;&ET:"YP:'`Z,C$Q"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@<F5M:6YD
M960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O<VAA<F5S96QE8W0N:6YC.C$P"FUS9VED
M(")9;W5R(&1E9F%U;'0@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3`U.2!L:6(O1')I=F5R+G!H<#HQ,#8Y"FUS9VED(");56YN
M86UE9"!E=F5N=%TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z.34*;7-G:60@(E]!;&%R;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$*;7-G:60@(E]"87-I
M8R!396%R8V@B"FUS9W-T<B`B(@H*(SH@=FEE=V5V96YT+G!H<#HQ,S<*;7-G
M:60@(E]%9&ET(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M-3`*;7-G:60@(E]';W1O(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$S-38*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S<*;7-G:60@(E]->2!#86QE;F1A<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,T-`IM<V=I9"`B
M7TYE=R!%=F5N="(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,S8Q"FUS9VED(")?4')I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,U,@IM<V=I9"`B7U-E87)C:"(*;7-G<W1R("(B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,S0W"FUS9VED(")?5&]D87DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED(")B969O<F4@
M=&AE(&5V96YT('-T87)T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@U"FUS9VED(")D87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(P-PIM<V=I9"`B9&%Y*',I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.#8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-PHC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@X(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B9&%Y
M<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ-3`@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ"FUS9VED(")E=F5N=',N8W-V(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C$W,0IM<V=I9"`B979E;G1S+FEC<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$S-@IM<V=I9"`B
M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,C<@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,S"FUS
M9VED(")M;VYT:"AS*2(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#0P"B,L('!H<"UF;W)M870*;7-G:60@(F]N("5S(&%T("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,C<*;7-G:60@(F]N('1H92!S86UE(&1A=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,PIM<V=I9"`B;VX@=&AE('-A;64@
M=V5E:V1A>2(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR.2!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$T"FUS9VED(")V0V%L96YD87(O:4-A;&5N9&%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,T.2!L:6(O87!I+G!H<#HV
M,C@*;7-G:60@(G9%=F5N="!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3$*;7-G:60@(G=E96LB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(Q-`IM<V=I9"`B=V5E:RAS*2!O;CHB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DS"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.30*;7-G
M:60@(G=E96MS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,SD*;7-G:60@(GEE
M87(H<RDB"FUS9W-T<B`B(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]P;R]L=E],5BYP;P``````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,C$V-#0`,3`T,3<S-C(W-3,`
M,#(P-#0R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",@3&%T=FEE\'4@=F%L;V1A<R!T=6QK;VIU;7,@2&]R9&4@1G)A;65W
M;W)K(&MO;7!O;F5N=&5I+@HC($MR;VYO;&ET:"`M($MA;&5N9.)R<PHC($-O
M<'ER:6=H="`H0RD@,C`P-"!&<F5E(%-O9G1W87)E($9O=6YD871I;VXL($EN
M8RX*(R!)=F%R<R!3=&EV<FGR\"`\:79A<G-`:W)A<VQA=F$N;'8^+"`R,#`T
M+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B`Q
M+C!<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`T+3`Y+3$U(#(P.C4R*S`R
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@279A<G,@4W1I=G)I;G,@/&EV87)S
M0&MR87-L879A+FQV/EQN(@HB3&%N9W5A9V4M5&5A;3H@3&%T=FEA;B`\:79A
M<G-`:W)A<VQA=F$N;'8^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U-UQN(@HB0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!C86QE;F1A<G,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]H96%D97(N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5D(&5V96YT<R(*;7-G<W1R(")6:7-I(&YO=&EK=6UI(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3(S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($1A>2AS*2`E<R!(;W5R*',I("5S($UI;G5T97,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY
M(&EM<&]R=&5D(@IM<V=S='(@(B5S(&1A=&YE('-E:VWN9VD@:65LXF3G=&$B
M"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O8F%S92YP:'`Z,3(X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@
M(D5K<W!O<G3G="!K86QE;F3B<G4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+W-E87)C:"YI;F,Z,3<*;7-G:60@(B(*(BA#;&EC:R!O;B!C86QE;F1A<B!N
M86UE('1O('-W:71C:"!T:&4@8V%L96YD87(G<R!V:7-I8FEL:71Y(&EN('1H
M92!M86EN("(*(G=I;F1O=RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C0*;7-G:60@(BH@061D('1H97-E(&)Y
M(&-L:6-K:6YG($%D9"`J(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,34P"FUS9VED("(J(%!L96%S92!S96QE8W0@
M861D<F5S<RAE<RD@*B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M-S@V"FUS9VED("(Q(&%T=&5N9&5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L(&9U>GIY"FUS9VED("(Q(&5V96YT
M(@IM<V=S='(@(E9I<VD@;F]T:6MU;6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,W"B,L(&9U>GIY"FUS9VED("(Q(&AO=7(B"FUS9W-T<B`B)60@
M<W1U;F1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`HC+"!F=7IZ
M>0IM<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R("(E9"!M:6[[=&5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM<V=I9"`B,C`@
M;6EN=71E<R(*;7-G<W1R("(E9"!M:6[[=&5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-@HC+"!F=7IZ>0IM<V=I9"`B,S`@;6EN=71E<R(*;7-G
M<W1R("(E9"!M:6[[=&5S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,3<Q"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/D%T=&5N9&5E<SPO<W1R;VYG
M/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/D%T<VSG9W;B<F1I/"]B/B`H;F5O
M8FQI9^)T:2DB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#D*(RP@
M9G5Z>GD*;7-G:60@(CQS=')O;F<^1&5S8W)I7W!T:6]N/"]S=')O;F<^("AO
M<'1I;VYA;"DB"FUS9W-T<B`B/&(^07!R86MS=',\+V(^("AN96]B;&EGXG1S
M*2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(W-PHC+"!F=7IZ>0IM
M<V=I9"`B/'-T<F]N9SY+97EW;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM
M<V=S='(@(CQB/D%T<VSG9W;B<F1I/"]B/B`H;F5O8FQI9^)T:2DB"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHQ.30*(RP@9G5Z>GD*;7-G:60@(CQS
M=')O;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@
M(CQB/D%T:^)R=&_P86[B<SPO8CX@*&YE;V)L:6?B=&DI(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#$@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ.#$*;7-G:60@(D%-(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C4Y,0IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9%]V86YC960@
M4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,38Q('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,3DP"FUS9VED(")!9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C8*;7-G:60@(D%D9"!%=F5N="(*;7-G<W1R(")0:65V:65N
M;W0@;F]T:6MU;74B"@HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M
M86YA9V5M96YT+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B061D(&$@;F5W(%)E
M;6]T92!#86QE;F1A<B(*;7-G<W1R(")0:65V:65N;W0@:F%U;G4@;F]T:6MU
M;74B"@HC.B!A9&1E=F5N="YP:'`Z-C0*;7-G:60@(D%D9"!A(&YE=R!E=F5N
M="(*;7-G<W1R(")0:65V:65N;W0@:F%U;G4@;F]T:6MU;74B"@HC.B!T96UP
M;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-S0*;7-G:60@(D%D9"!A
M='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@8V]N=&%C=',N<&AP.C<V('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(P"B,Z('1E;7!L871E<R]A
M='1E;F1E97,O871T96YD965S+FEN8SHW.`IM<V=I9"`B061D<F5S<R!";V]K
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHX('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I
M9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C4S"FUS9VED(")!;&%R;2(*;7-G<W1R(")!=&?B9&EN
MXFIU;7,B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8T"B,L('!H<"UF;W)M870*
M;7-G:60@(D%L87)M("5D(&1A>7,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C$W-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@
M)60@:&]U<G,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$W-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&UI
M;G5T97,@8F5F;W)E(@IM<V=S='(@(E!I<FUS("5S(&UI;OMTYVTB"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ-S4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M
M("5D('=E96MS(&)E9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-S8S"FUS9VED(")!;&%R;2`Q(&1A>2!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z,3<V.`IM<V=I9"`B06QA<FT@,2!H;W5R(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<S"B,L(&9U
M>GIY"FUS9VED(")!;&%R;2`Q(&UI;G5T92!B969O<F4B"FUS9W-T<B`B4&ER
M;7,@)7,@;6EN^W3G;2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3@*;7-G:60@
M(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M-C`*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T<B`B071GXF1I;N)J=6UA(&1A
M='5M<R(*"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!3<&%N("AM:6YU
M=&5S*2(*;7-G<W1R(")!=&?B9&ENXFIU;6$@;&%I:V$@<W!R[F1I<R`H;6EN
M^W3G<RDB"@HC.B!D871A+G!H<#HV,0IM<V=I9"`B06QA<FT@5&EM92(*;7-G
M<W1R(")!=&?B9&ENXFIU;6$@;&%I:W,B"@HC.B!T96UP;&%T97,O9&5L971E
M+V1E;&5T92YI;F,Z,S$*;7-G:60@(D%L;"(*;7-G<W1R(")6:7-S(@H*(SH@
M;&EB+T9"5FEE=RYP:'`Z,3(V(&QI8B]&0E9I97<N<&AP.C$R.2!L:6(O1D)6
M:65W+G!H<#HQ,S(*(RP@9G5Z>GD*;7-G:60@(D%L;"!!='1E;F1E97,B"FUS
M9W-T<B`B5FES:2!N;W1I:W5M:2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHU.0HC+"!F=7IZ>0IM<V=I9"`B06QL($9U='5R92(*;7-G<W1R
M(").XFMO=&[G(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4S
M"B,L(&9U>GIY"FUS9VED(")!;&P@4&%S="(*;7-G<W1R(")6:7-I(&1I96YA
M<R(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO
M8VLO;6]N=&@N<&AP.C(T"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C(W
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B06QL(%9I<VEB;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z,3(R(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z.3,*
M(SH@;&EB+U=E96M6:65W+G!H<#HQ,C<@;&EB+U=E96M6:65W+G!H<#HQ,S0@
M;&EB+T1R:79E<BYP:'`Z,3@S,@IM<V=I9"`B06QL(&1A>2(*;7-G<W1R(")6
M:7-I(&1I96YA<R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-C0*;7-G
M:60@(D%L;"!D87D@979E;G0B"FUS9W-T<B`B5FES:2!D:65N87,@;F]T:6MU
M;6DB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")!
M;&P@979E;G1S(@IM<V=S='(@(E9I<VD@;F]T:6MU;6DB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C<Q(&QI8B]+<F]N;VQI=&@N
M<&AP.C8X,PIM<V=I9"`B06YY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!<')I;"(*;7-G<W1R(")!
M<'+N;&ES(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M,SD@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHW,"!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$U-@IM<V=I9"`B070B"FUS9W-T<B`B+2(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$P,C8*;7-G:60@(B(*(D%T=&%C:&5D(&ES(&%N(&E#86QE
M;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@979E
M;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I<"!R97%U
M97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P9&%T92`B
M"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#(@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E;F1A;F-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V,0IM<V=I9"`B
M071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B075G=7-T<R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,2!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z.`IM<V=I9"`B0F%S:6,@4V5A
M<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ
M-PIM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B1'II;?!A;F%S(&1I96YA(@H*
M(SH@;&EB+T9"5FEE=RYP:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$P"FUS9VED
M(")"=7-Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0U]A;&5N9&%R(@IM
M<V=S='(@(DEE=FEL:W0@:V%L96YDXG)U(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z-#D*(RP@9G5Z>GD*;7-G:60@(D-A;%]E;F1A<B(*;7-G<W1R
M("))979I;&MT(&MA;&5N9.)R=2(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHQ-#8@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP
M.C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C$@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"B,L(&9U>GIY
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("))979I;&MT(&MA;&5N9.)R=2(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"B,L(&9U>GIY"FUS9VED(")#
M86QE;F1A<B!3=6UM87)Y(@IM<V=S='(@(DMO<'-A=FEL:W5M<R(*"B,Z(&1A
M=&$N<&AP.C(R.`HC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87(@<W5C8V5S<V9U
M;&QY('!U<F=E9"XB"FUS9W-T<B`B:2UK86QE;F3B<G,@<V5K;>YG:2!I97)A
M:W-T[G1S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W"B,L(&9U>GIY"FUS9VED(")#86QE
M;F1A<G,B"FUS9W-T<B`B265V:6QK="!K86QE;F3B<G4B"@HC.B!C86QE;F1A
M<G,N<&AP.C(W"FUS9VED(")#86QE;F1A<G,@;75S="!H879E(&$@;F%M92XB
M"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C0S"B,L(&9U>GIY"FUS9VED(")#
M86XG="!C<F5A=&4@82!N97<@979E;G0N(@IM<V=S='(@(DEZ=F5I9&]T(&IA
M=6YU(&YO=&EK=6UU(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ.3$@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,P"B,Z('1E;7!L
M871E<R]D96QE=&4O9&5L971E+FEN8SHS,B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHS,PHC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#D*;7-G:60@
M(D-A;F-E;"(*;7-G<W1R(")!=&-E;'0B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU-S`*(RP@9G5Z>GD*;7-G:60@(D-A;F-E;&QE9"(*;7-G<W1R(")!=&-E
M;'0B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#`Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YC96QL960Z("5S(@IM<V=S='(@(D%T8V5L="(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV-"!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHV.0HC+"!F=7IZ>0IM<V=I9"`B0V%T
M96=O<E]Y(@IM<V=S='(@(DMA=&5G;W)I:F$B"@HC.B!D871A+G!H<#HV,R!T
M96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C0@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3,*;7-G:60@(D-A=&5G;W)Y(@IM<V=S='(@(DMA
M=&5G;W)I:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<Y"FUS9VED
M("(B"B)#:&]O<V4@:68@>6]U('=A;G0@=&\@8F4@;F]T:69I960@;V8@;F5W
M+"!E9&ET960L(&%N9"!D96QE=&5D(&5V96YT<R!B>2`B"B)E;6%I;#HB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R"FUS9VED(")#
M:&]O<V4@:68@>6]U('=A;G0@=&\@8F4@;F]T:69I960@;V8@;F5W+"!E9&ET
M960L(&%N9"!D96QE=&5D(&5V96YT<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-E87)C:%]A8F]O:U]S96QE8W0N:6YC.C$Y(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.3D*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B
M;V]K<R!T;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O9F)?8V%L<U]S96QE8W0N:6YC.C$V"FUS
M9VED(")#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E(&EN('EO=7(@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$Q"FUS9VED(")#:&]O<V4@=&AE(&-A;&5N9&%R
M<R!T;R!I;F-L=61E('=H96X@9V5N97)A=&EN9R!F<F5E+V)U<WD@55),<SHB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED
M(")#:&]O<V4@>6]U<B!D969A=6QT(&-A;&5N9&%R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-C4*;7-G:60@
M(D-L96%R(&%L;"!A='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M,C@@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M;6$@
M<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S,*;7-G:60@(D-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S
M/R(*;7-G<W1R(")!<'-T:7!R:6[B="!N;W1I:W5M=2!D>N?P86YU(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M
M960B"FUS9W-T<B`B3F5A:7IP:6QD[G1S(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C(P.`IM<V=I9"`B0V]P>2!T:&4@55),(&)E
M;&]W(&9O<B!U<V4@=VAE<F5V97(@>6]U(&YE960@>6]U<B!&<F5E+T)U<WD@
M55),.B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,C8*
M(RP@9G5Z>GD*;7-G:60@(D-R96%T92(*;7-G<W1R(")087-R96EZYVIA:7,B
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3$R"B,L
M(&9U>GIY"FUS9VED(")#<F5A=&4@0V%L96YD87(B"FUS9W-T<B`B265V:6QK
M="!K86QE;F3B<G4B"@HC.B!M;VYT:"YP:'`Z,38U('1E;7!L871E<R]W965K
M+VAE860N:6YC.C(U('1E;7!L871E<R]D87DO<F]W+FEN8SHV"B,Z(&QI8B]$
M87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z,3DT"FUS9VED(")#<F5A
M=&4@82!.97<@179E;G0B"FUS9W-T<B`B27IV96ED;W0@:F%U;G4@;F]T:6MU
M;74B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHX,`IM<V=I9"`B0W)E
M871E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI
M;F,Z,CD*;7-G:60@(D-U<G)E;G0B"FUS9W-T<B`B4&%S<F5I>N=J86ES(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(P.0IM<V=I9"`B1&%I;'DZ(%)E8W5R<R!E=F5R>2(*;7-G
M<W1R(")$:65NXCH@071KXG)T;W1I97,@:V%T<G4B"@HC.B!A='1E;F1E97,N
M<&AP.C$Q,"!L:6(O2W)O;F]L:71H+G!H<#HQ,C@X(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@IM<V=I
M9"`B1&%Y(@IM<V=S='(@(D1I96YA(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,Y"FUS9VED(")$
M87DH<RDB"FUS9W-T<B`B1&EE;F%S(@H*(SH@=FEE=V5V96YT+G!H<#HQ,#0*
M(RP@9G5Z>GD*;7-G:60@(D1E7VQE=&4B"FUS9W-T<B`B1'KG<W0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.0IM<V=I9"`B1&5C96UB
M97(B"FUS9W-T<B`B1&5C96UB<FES(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-3DT"FUS9VED(")$96-L:6YE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V%L96YD
M87(B"FUS9W-T<B`B265V:6QK="!K86QE;F3B<G4B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DS('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3@Q"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN
M8SHR.2!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN
M8SHR,PHC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"FUS9VED(")$96QE=&4B"FUS
M9W-T<B`B1'KG<W0B"@HC.B!D96QE=F5N="YP:'`Z-#`@=&5M<&QA=&5S+V1E
M;&5T92]O;F4N:6YC.C$X('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHQ
M.`HC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92`E<R(*;7-G<W1R(")$871U;7,@)7,B"@HC.B!E9&ET979E;G0N
M<&AP.C<P"FUS9VED(")$96QE=&4@179E;G0B"FUS9W-T<B`B1'KG<W0@;F]T
M:6MU;74B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C<*;7-G
M:60@(B(*(D1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C
M8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@(@HB86QL
M(&]C8W5R96YC97,_(@IM<V=S='(@(B(*(D1ZYW-T('1I:V%I(&5S;_!O(&YO
M=&EK=6UU+"#P86KB('5N('9I<^)S(&[B:V%M86KB<R!R96EZYW,L('9A:79I
M96YMYW(_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N
M:6YC.C$P-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C@*(RP@9G5Z
M>GD*;7-G:60@(D1E<V-R:5]P=&EO;B(*;7-G<W1R(")087-K86ED<F]J=6US
M(@H*(SH@9&%T82YP:'`Z-C(@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$W-0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHY-@IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&%S:V%I9')O:G5M<R(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<S"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y(@IM<V=S='(@(D1I<W!L96IA('!A<F%M971R:2(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHV,`HC+"!F=7IZ
M>0IM<V=I9"`B1&ES<&QA>2!#86QE;F1A<G,B"FUS9W-T<B`B1&ES<&QE:F$@
M<&%R86UE=')I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.`IM
M<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D1I<W!L96IA('!A<F%M
M971R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&\@
M>6]U('=A;G0@=&\@<VAO=R!T87-K<R!W:&EC:"!A<F4@9'5E(&]N('EO=7(@
M8V%L96YD87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4S
M-PIM<V=I9"`B1&]E<R!N;W0@<F5C=7(B"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,S(U"B,L('!H<"UF;W)M870*;7-G:60@(D1U93H@)7,B
M"FUS9W-T<B`B4V%K87+B(&%R.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B
M26QG=6US(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$W,"!L:6(O1')I=F5R+G!H<#HQ.#`V"FUS9VED(")%9&ET(@IM<V=S='(@
M(DQA8F]T(@H*(SH@961I=&5V96YT+G!H<#HS,R!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR-B!L:6(O1')I=F5R+G!H<#HQ.#`V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@)7,B"FUS9W-T<B`B3&%B;W0@)7,B"@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHQ.#<*;7-G:60@(D5D:70@071T96YD965S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ-#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@0V%L96YD87)S(@IM<V=S='(@
M(D5K<W!O<G3G="!K86QE;F3B<G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4P"B,L(&9U>GIY"FUS9VED(")%9&ET(%)E;6]T92!#86QE;F1A<G,B
M"FUS9W-T<B`B265V:6QK="!K86QE;F3B<G4B"@HC.B!A='1E;F1E97,N<&AP
M.C$U,`IM<V=I9"`B161I="!A='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N9"YI;F,Z,C`*;7-G:60@(D5D:70@8V%T
M96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@
M(D5N7V0B"FUS9W-T<B`B0F5I9'IA<R(*"B,Z(&1A=&$N<&AP.C4W"FUS9VED
M(")%;F0@1&%T92(*;7-G<W1R(")"86EG=2!D871U;7,B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C@@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#@*
M;7-G:60@(D5N9"!/;B(*;7-G<W1R(")"96ED>F%S(@H*(SH@9&%T82YP:'`Z
M-3@*;7-G:60@(D5N9"!4:6UE(@IM<V=S='(@(D)E:6=U(&QA:6MS(@H*(SH@
M871T96YD965S+G!H<#HQ,C0@871T96YD965S+G!H<#HQ,S4@871T96YD965S
M+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5T<FEE=FEN
M9R!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DS"FUS9VED(")%=F5N="!A9&1E
M9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P,PIM<V=I
M9"`B179E;G0@9&5L971E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`Y.`IM<V=I9"`B179E;G0@961I=&5D.B(*;7-G<W1R("(B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ,#8V"B,L('!H<"UF;W)M870*;7-G:60@(D5V
M96YT(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z-S8T"B,L(&9U>GIY"FUS9VED(")%=F5N=',@;75S="!H879E(&$@<W1A
M<G0@9&%T92XB"FUS9W-T<B`B0F5I9W4@9&%T=6UA;2!I<B!JXF+[="!VYVSB
M:R!KXB!SXFMU;6$N(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S,P"FUS9VED(")%
M=F5N=',@;75S="!H879E(&$@=&ET;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]$
M<FEV97(N<&AP.C<V-PIM<V=I9"`B179E;G1S(&UU<W0@:&%V92!A;B!E;F0@
M9&%T92!O<B!A(&1U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M871T96YD965S+V%T=&5N9&5E<RYI;F,Z-SD*(RP@9G5Z>GD*;7-G:60@(D5X
M<&%N9"!.86UE<R(*;7-G<W1R(")"96EG=2!L86EK<R(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3@W"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B
M16MS<&]R=.=T(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS
M9VED(")%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`B16MS<&]R=.=T(&MA;&5N
M9.)R=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8Y"FUS
M9VED(")&96)R=6%R>2(*;7-G<W1R(")&96)R=>)R:7,B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$R.`HC+"!F=7IZ>0IM<V=I9"`B
M1FEN9"(*;7-G<W1R(")0:65K=&1I96YA(@H*(SH@>65A<BYP:'`Z.#<@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C,@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C(R"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED
M(")&<B(*;7-G<W1R(")0:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.`HC+"!F=7IZ>0IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S
M='(@(DK[<W4@:6YF;W)MXF-I:F$B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A
M9"YI;F,Z,C`@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$Y"B,Z('1E;7!L
M871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")&<FED87DB"FUS
M9W-T<B`B4&EE:W1D:65N82(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E
M+FEN8SHS,`IM<V=I9"`B1G5T=7)E(@IM<V=S='(@(D[B:V]T;N<B"@HC.B!C
M;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D=A;64B"FUS9W-T
M<B`B4W#G;&4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E
M9"YI;F,Z,C,*;7-G:60@(D=E;F5R86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C$T,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1V]T;R`E<R(*;7-G<W1R("))970@=7HB"@HC.B!M;VYT:"YP:'`Z,3,U
M('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T
M96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`IM<V=I9"`B
M2&ED92(*;7-G<W1R("(B"@HC.B!M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W
M965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y
M+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B2&ED92`E<R(*;7-G<W1R(")3:V%T<R`E<R(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C8U('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$S.`IM<V=I9"`B2&]U<BAS*2(*;7-G<W1R(")3='5N9&$H<RDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,L(&9U>GIY"FUS9VED(")(;W<@
M;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@=&AE(&1A>2!A;F0@=V5E
M:R!V:65W<R!B93\B"FUS9W-T<B`B4N)D[G0@8V5T=7)D8>]K=F%D<N)T:?)U
M<R!D:65N=2!U;B!N963G[W4@<VMA=&]S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR.#@*;7-G:60@(DAO=R!M86YY(&1A>7,@;V8@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N('-H;W5L9"!W92!G96YE<F%T93\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`S,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B))9B!Y;W5R(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O<G0@:51I
M<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@;V8@=&AE("(*(F9O;&QO=VEN
M9R!L:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N7&XB"B)<
M;B(*(E1O(&%C8V5P="!T:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB"B)4;R!A
M8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*(EQN(@HB
M5&\@9&5C;&EN92!T:&4@979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R="!#86QE;F1A<BP@4W1E<"`E9"(*;7-G<W1R("))
M979I;&MT(&MA;&5N9.)R=2(*"B,Z(&1A=&$N<&AP.C,R,`IM<V=I9"`B26UP
M;W)T+T5X<&]R="!#86QE;F1A<B(*;7-G<W1R("))979I;&MT+T5K<W!O<G3G
M="!K86QE;F3B<G4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV.`IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YVXG)I<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<T"FUS9VED(")*=6QY(@IM
M<V=S='(@(DK[;&EJ<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C<S"FUS9VED(")*=6YE(@IM<V=S='(@(DK[;FEJ82(*"B,Z(&1A=&$N
M<&AP.C8U('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T,@IM<V=I9"`B2V5Y
M=V]R9',B"FUS9W-T<B`B071S;.=G=N)R9&DB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-34*;7-G:60@(DQA<W0@,C0@:&]U<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#<*(RP@9G5Z>GD*
M;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B4.=DYVIA:7,@;>=N97-I
M<R(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M-`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,38@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C0*;7-G:60@(DQA<W0@36]N=&@B
M"FUS9W-T<B`B4.=DYVIA:7,@;>=N97-I<R(*"B,Z('1E;7!L871E<R]Y96%R
M+VAE860N:6YC.C0*(RP@9G5Z>GD*;7-G:60@(DQA<W0@665A<B(*;7-G<W1R
M(")0YV3G:N(@;F5DY^]A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C4T('1E;7!L871E<R]W965K+VAE860N:6YC.C,*;7-G:60@(DQA<W0@
M=V5E:R(*;7-G<W1R(")0YV3G:N(@;F5DY^]A(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ-PIM<V=I9"`B3&EM:70@=&AE('1I;64@<W!A;B!T
M;R!E>'!O<G0Z(@IM<V=S='(@(DEE<F]B9?YO="!L86EK82!G<F%F:6MU(&1A
M='4@96MS<&]R=&%M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C@V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C<V"B,L(&9U
M>GIY"FUS9VED("),;U]C871I;VXB"FUS9W-T<B`B071R8?!A;N)S(@H*(SH@
M9&%T82YP:'`Z-C0@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN
M8SHU"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N
M:6YC.C$X"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE
M;G0N:6YC.C4R('1E;7!L871E<R]V:65W+W9I97<N:6YC.C(Q"B,Z(&QI8B]$
M<FEV97(N<&AP.C$X-#D*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(D%T<F'P
M86[B<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-0HC+"!F=7IZ>0IM
M<V=I9"`B36%N86=E(')E;6]T92!C86QE;F1A<G,N(@IM<V=S='(@(DYA=F%R
M(&EZ=F5I9&]T(&MA;&5N9.)R82!I97)A:W-T=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C<P"FUS9VED(")-87)C:"(*;7-G<W1R(")-
M87)T<R(*"B,Z(&QI8B]A<&DN<&AP.C$P,`IM<V=I9"`B36%X:6UU;2!.=6UB
M97(@;V8@179E;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C<R"FUS9VED(")-87DB"FUS9W-T<B`B36%I:G,B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ.#0V"FUS9VED(")-92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(DUE971I;F<B
M"FUS9W-T<B`B5&EK\&%NXG,B"@HC.B!L:6(O0FQO8VLO=')E95]A;&%R;7,N
M<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@06QA<FUS(@IM<V=S='(@(D%T
M9^)D:6[B:G5M<R(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C,*;7-G
M:60@(DUE;G4@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHV."!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S<*;7-G:60@
M(DUI;G5T92AS*2(*;7-G<W1R(")-:6[[=&4H<RDB"@HC.B!L:6(O0FQO8VLO
M<')E=FUO;G1H;&ES="YP:'`Z-#(*;7-G:60@(DUI<W-E9"!%=F5N=',@3&ES
M="(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX,R!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3@*
M(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(DUO(@IM<V=S='(@
M(E!I(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$V('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$Q-0HC.B!T96UP;&%T97,O961I="]J879A<V-R
M:7!T+FEN8SHV."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"FUS9VED(")-
M;VYD87DB"FUS9W-T<B`B4&ER;61I96YA(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3(Y,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S='(@(DWG;F5S:7,B
M"@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUO
M;G1H(%9I97<B"FUS9W-T<B`B3>=N97-I<R(*"B,Z(&QI8B]";&]C:R]M;VYT
M:&QI<W0N<&AP.C,@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#,*;7-G:60@
M(DUO;G1H;'D@179E;G1S($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R
M-@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,CD@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C,U"FUS9VED(")-;VYT:&QY.B!296-U<G,@979E<GDB
M"FUS9W-T<B`B3>=N9?!O<SH@071KXG)T;W1I97,@:V%T<G4B"@HC.B!L:6(O
M0FQO8VLO;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS($%H96%D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-`HC
M+"!F=7IZ>0IM<V=I9"`B36]N=&AS($)E9F]R92(*;7-G<W1R(")0:7)M<R`E
M<R!M:6[[=.=M(@H*(SH@;&EB+V%P:2YP:'`Z-C$R"FUS9VED(")-=6QT:7!L
M92!I0V%L96YD87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT
M(&ES('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HQ
M,C@@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8W"B,L(&9U
M>GIY"FUS9VED(")->2!#86QE;F1A<G,B"FUS9W-T<B`B265V:6QK="!K86QE
M;F3B<G4B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S0@=&5M<&QA=&5S+VUE
M;G4N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")->2!#86QE;F1A<G,Z(@IM<V=S
M='(@(D5K<W!O<G3G="!K86QE;F3B<G4B"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,C`T"FUS9VED(")->2!&<F5E+T)U<WD@55),
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHQ,3<@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U
M.0HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W-0HC.B!T
M96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHQ-PHC
M.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHT
M-`HC+"!F=7IZ>0IM<V=I9"`B3F%M92(*;7-G<W1R(")3<.=L92(*"B,Z(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z-#$@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z
M-#0@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0Q"B,Z(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C(P"FUS9VED(").97<@179E;G0B"FUS9W-T<B`B2F%U;G,@
M;F]T:6MU;7,B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,T"B,L
M(&9U>GIY"FUS9VED(").97AT(@IM<V=S='(@(D[B:V_PXB!D:65N82(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-PIM<V=I9"`B3F5X="`R
M-"!H;W5R<R(*;7-G<W1R("(B"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z,CD*
M(RP@9G5Z>GD*;7-G:60@(DYE>'0@1&%Y(@IM<V=S='(@(D[B:V_PXB!D:65N
M82(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M-@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3@@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C8*;7-G:60@(DYE>'0@36]N=&@B
M"FUS9W-T<B`B3N)K;_!A:7,@;>=N97-I<R(*"B,Z(&QI8B]&0E9I97<O=V5E
M:RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(DYE>'0@5V5E:R(*;7-G<W1R(").
MXFMO\.(@;F5DY^]A(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-@HC
M+"!F=7IZ>0IM<V=I9"`B3F5X="!996%R(@IM<V=S='(@(D[B:V_PXB!D:65N
M82(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!D
M87DB"FUS9W-T<B`B3N)K;_#B(&1I96YA(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C4X('1E;7!L871E<R]W965K+VAE860N:6YC.C4*;7-G
M:60@(DYE>'0@=V5E:R(*;7-G<W1R(").XFMO\.(@;F5DY^]A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(W-0HC+"!F=7IZ>0IM<V=I9"`B3F\B"FUS
M9W-T<B`B3F%V(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S,@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3(V"B,L(&9U>GIY"FUS9VED(").;R!A
M;&%R;2(*;7-G<W1R(")!=&?B9&ENXFIU;7,B"@HC.B!T96UP;&%T97,O871T
M96YD965S+V%T=&5N9&5E<RYI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(DYO(&%T
M=&5N9&5E<R(*;7-G<W1R(").878@8F5I9W4@9&%T=6UA(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,Q,0IM<V=I9"`B3F\@8V%L96YD87)S(&%R92!A=F%I
M;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C4U"FUS
M9VED(").;R!E;F0@9&%T92(*;7-G<W1R(").878@8F5I9W4@9&%T=6UA(@H*
M(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$V-"!L:6(O0FQO8VLO
M;6]N=&AL:7-T+G!H<#HQ-C,*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y
M-`IM<V=I9"`B3F\@979E;G1S('1O(&1I<W!L87DB"FUS9W-T<B`B(@H*(SH@
M;&EB+U-T;W)A9V4O:V]L86(N<&AP.C0S"B,L('!H<"UF;W)M870*;7-G:60@
M(DYO(&9R964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,T-"!L:6(O87!I+G!H<#HV
M,#(*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`T"B,L(&9U>GIY
M"FUS9VED(").;R!R96-U<G)E;F-E(@IM<V=S='(@(D%T:^)R=&_P86[B<R!D
M871U;7,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HX.#8*;7-G:60@(DYO('9A
M;&ED(&5M86EL(&%D9')E<W,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z-C`Q(&QI8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B
M3F]N92(*;7-G<W1R(").878B"@HC.B!L:6(O4W1O<F%G92]S<6PN<&AP.C$S
M-@IM<V=I9"`B3F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B3F]T:69I8V%T:6]N<R(*
M;7-G<W1R(")!=')A\&%NXG,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G
M;W1O+FEN8SHW.`IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB<FES
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4V"FUS9VED(").
M;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-S<*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3VMT;V)R:7,B"@HC.B!T
M96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,R!T96UP;&%T97,O
M961I="]E9&ET7W1I;65S<&%N+FEN8SHV-0IM<V=I9"`B3VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.`IM<V=I9"`B3VX@86QL
M(&-A;&5N9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-PIM<V=I9"`B3VX@86QL('-H
M;W=N(&-A;&5N9&%R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C<V"FUS9VED(")/;B!M>2!C86QE;F1A<G,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,3D*(RP@9G5Z>GD*;7-G:60@
M(D]P=&EO;F%L(@IM<V=S='(@(E!A<F%M971R:2(*"B,Z(&QI8B]&0E9I97<N
M<&AP.C$Q.`IM<V=I9"`B3W!T:6]N86P@071T96YD965S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&0E9I97<N<&AP.C$U,@IM<V=I9"`B3W9E<G9I97<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,S0*;7-G:60@(D]W
M;F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D]W;F5R.B`E<R(*;7-G<W1R(")386MA
M<N(@87(Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#(@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.#(*;7-G:60@(E!-(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C(Y('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,30*(RP@9G5Z>GD*;7-G:60@(E!A;&T@1&%T94)O;VLB"FUS9W-T<B`B
M071GXF1I;N)J=6UA(&1A='5M<R(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL
M:7-T+G!H<#HS"FUS9VED(")087-T($5V96YT<R!,:7-T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$P.2!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ.3@*;7-G:60@(E!A='1E<FXB"FUS9W-T<B`B5F5I9',B
M"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C<*;7-G:60@(E!E<FUA
M;F5N=&QY(&1E;&5T92!T:&ES(&5V96YT/R(*;7-G<W1R(")$>N=S="#P;R!N
M;W1I:W5M=2!P:6QN[F+B(@H*(SH@;&EB+V%P:2YP:'`Z,S(U(&QI8B]A<&DN
M<&AP.C0Q.2!L:6(O87!I+G!H<#HT.#$@;&EB+V%P:2YP:'`Z-34S"B,Z(&QI
M8B]A<&DN<&AP.C4X-"!L:6(O87!I+G!H<#HV-S`@;&EB+V%P:2YP:'`Z-S`V
M"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,38W"FUS9VED(")097)M
M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C$*(RP@9G5Z>GD*;7-G:60@(E!O<G1A;"!/<'1I;VYS(@IM<V=S='(@(DQI
M971O=.)J82!P87)A;65T<FDB"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z,C4*
M(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S($1A>2(*;7-G<W1R("))97!R:65K
M\.=JXB!D:65N82(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*(RP@9G5Z
M>GD*;7-G:60@(E!R979I;W5S(%=E96LB"FUS9W-T<B`B265P<FEE:_#G:N(@
M9&EE;F$B"@HC.B!T96UP;&%T97,O9&%Y+VAE860N:6YC.C,*;7-G:60@(E!R
M979I;W5S(&1A>2(*;7-G<W1R("))97!R:65K\.=JXB!D:65N82(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR-3(*;7-G:60@(E)E8W5R(%5N=&EL(@IM<V=S='(@(D%T:^)R=&]J
M87,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,#8*(RP@9G5Z>GD*
M;7-G:60@(E)E8W5R<F5N8V4B"FUS9W-T<B`B071KXG)T;_!A;N)S(&1A='5M
M<R(*"B,Z(&1A=&$N<&AP.C8Y"FUS9VED(")296-U<G)E;F-E($1A=&$B"FUS
M9W-T<B`B071KXG)T;_!A;N)S(&1A='5M<R(*"B,Z(&1A=&$N<&AP.C8W"FUS
M9VED(")296-U<G)E;F-E($5N9"!$871E(@IM<V=S='(@(D%T:^)R=&_P86[B
M<R!I>G1E8^=J=6UA("AB96EG=2D@9&%T=6US(@H*(SH@9&%T82YP:'`Z-C@*
M;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`B071KXG)T;_!A
M;N)S(&EN=&5R=N)L<R(*"B,Z(&1A=&$N<&AP.C8V"FUS9VED(")296-U<G)E
M;F-E(%1Y<&4B"FUS9W-T<B`B071KXG)T;_!A;N)S(&QA:6MS(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z-30P"FUS9VED(")296-U<G,@9&%I;'DB"FUS9W-T
M<B`B071KXG)T;W1I97,@:V%T<G4@9&EE;G4B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HU-#<*;7-G:60@(E)E8W5R<R!M;VYT:&QY(@IM<V=S='(@(D%T:^)R
M=&]T:65S(&MA=')U(&WG;F5S:2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T
M,PIM<V=I9"`B4F5C=7)S('=E96ML>2(*;7-G<W1R(")!=&OB<G1O=&EE<R!I
M:R!N963G[W4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3`*;7-G:60@(E)E
M8W5R<R!Y96%R;'DB"FUS9W-T<B`B071KXG)T;W1I97,@:6L@9V%D=2(*"B,Z
M(&QI8B]38VAE9'5L97(O:W)O;F]L:71H+G!H<#HQ.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5M:6YD97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHY,2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#0*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!#86QE;F1A<G,B"FUS
M9W-T<B`B265V:6QK="!K86QE;F3B<G4B"@HC.B!T96UP;&%T97,O;65N=2YI
M;F,Z-C`@=&5M<&QA=&5S+VUE;G4N:6YC.C8R"B,L(&9U>GIY"FUS9VED(")2
M96UO=&4@0V%L96YD87)S.B(*;7-G<W1R("))979I;&MT(&MA;&5N9.)R=2(*
M"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHU,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296UO=F4@)7,B"FUS9W-T<B`B(@H*(SH@871T
M96YD965S+G!H<#HQ,#0*;7-G:60@(E)E;6]V92!!='1E;F1E92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,R"FUS9VED("(B
M"B)297!L86-E(&5X:7-T:6YG(&-A;&5N9&%R('=I=&@@=&AE(&EM<&]R=&5D
M(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N
M=')I97,@:6X@>6]U<B!C=7)R96YT(&-A;&5N9&%R+CPO<W1R;VYG/B(*;7-G
M<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,C8*;7-G:60@(E)E<75I
M<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]&0E9I97<N<&AP.CDX(&QI8B]&0E9I
M97<N<&AP.C$S-R!L:6(O1D)6:65W+G!H<#HQ-#`@;&EB+T9"5FEE=RYP:'`Z
M,30S"FUS9VED(")297%U:7)E9"!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,S$P"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R(")!
M=&EE<W1A=.YT(&YO:VQU<^=J=6UA('!A<F%M971R=7,B"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#,@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,38V"FUS9VED(")297-P;VYS92(*;7-G<W1R("(B"@HC.B!Y
M96%R+G!H<#HX."!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-"!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,C,*(SH@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(E-E(@H*(SH@=&5M<&QA=&5S
M+VUO;G1H+VAE860N:6YC.C(Q('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R
M,`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,PIM<V=I9"`B
M4V%T=7)D87DB"FUS9W-T<B`B4V5S=&1I96YA(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B4V%V
M92(*;7-G<W1R(")392(*"B,Z('9I97=E=F5N="YP:'`Z,3$X(&5D:71E=F5N
M="YP:'`Z-#@@961I=&5V96YT+G!H<#HU-@IM<V=I9"`B4V%V92!!<R!.97<B
M"FUS9W-T<B`B4V%G;&%BXG0@:^(@:F%U;G4B"@HC.B!T96UP;&%T97,O871T
M96YD965S+V%T=&5N9&5E<RYI;F,Z.#<*;7-G:60@(E-A=F4@071T96YD965S
M(@IM<V=S='(@(B(*"B,Z(&%D9&5V96YT+G!H<#HU-2!E9&ET979E;G0N<&AP
M.C4Q"FUS9VED(")3879E($5V96YT(@IM<V=S='(@(E-A9VQA8N)T(&YO=&EK
M=6UU(@H*(SH@<V5A<F-H+G!H<#HY,2!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:%]A9'9A;F-E9"YI;F,Z,3$U"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHV-R!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z.`HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$T,"!L:6(O0FQO8VLO
M=')E95]M96YU+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(DUA<G1S(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC
M.C$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!#86QE;F1A<G,B"FUS9W-T<B`B
M265V:6QK="!K86QE;F3B<G4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z-@IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C8*;7-G:60@(E-E87)C
M:"!F;W(@8V%L96YD87)S(&-O;G1A:6YI;F<Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3`*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`B27IV
MYVQI971I97,@9&%T;FD@:V\@:65L87/N=#HB"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR-C@@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z,S$*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.#,*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4^)K=6UA
M(&1A='5M<R(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("))
M>G;G;&EE=&EE<R!KXB!A='-P;V=U[V]T(&1A='5M=7,Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED("(B"B)396QE8W0@8V]N9FER;6%T
M:6]N(&]P=&EO;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE
M=W,@86YD(&-H;V]S92`B"B)D969A=6QT('9I97<N(@IM<V=S='(@(B(*(DEZ
M=N=L:65T:65S(&%P<W1I<')I;N)J=6UA('!A<F%M971R=7,L(&EZ=N=L[F5T
M:65S('9I96YU(&YO("(*(G9A:7+B:VEE;6%P<VMA=&5S("AA='3G;&]J=6UA
M*2!V96ED:65M+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3D*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T
M('1O.B(*;7-G<W1R("))>G;G;&EE=&EE<R!D871N:2!K;R!I96QA<^YT.B(*
M"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B27IVYVQI
M971I97,@;F\@:W5R:65N97,@:65L87/N=#HB"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C(X"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP
M;W)T.B(*;7-G<W1R("))>G;G;&EE=&EE<R!D871N:2!K;R!I96QA<^YT.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@(E-E;&5C="!T
M:&4@9FER<W0@=V5E:V1A>3HB"FUS9W-T<B`B27IVYVQI971I97,@;F5DY^]A
M<R!P:7)M;R!D:65N=2XB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@
M<V]U<F-E(&9I;&4Z(@IM<V=S='(@(DEZ=N=L:65T:65S(&9O<FWB='4@:^)D
MXB!E:W-P;W)TYW0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-`IM
M<V=I9"`B4V5L96-T('1H92!T:6UE('-P86X@=&\@<VAO=SHB"FUS9W-T<B`B
M27IVYVQI971I97,@;&%I:V$@<W!R[F1I(&-I:R!I;&=I('+B9.YT.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A<G1U<#HB"FUS9W-T<B`B
M27IVYVQI971I97,@<VMA='4@:V\@<N)D[G0@<.=C(&%U=&]R:7KB8VEJ87,@
M<VES=.=MXCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!W:&EC:"!E=F5N=',@=&\@<VAO=R!I;B!T:&4@
M<&]R=&%L+B(*;7-G<W1R("))>G;G;&EE=&EE<R!KXF1U<R!N;W1I:W5M=7,@
M<N)D[G0@:V]P<VMA=.(N(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC
M.C(T('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR-`IM<V=I9"`B4V5N
M9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL(&%T=&5N9&5E<R!W:&5N
M(&1E;&5T:6YG('1H:7,@979E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E-E;F0@
M86X@96UA:6P@=&\@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,3@Q"FUS9VED(")396YD('5P9&%T97,O:6YV:71A=&EO;G,@
M=&\@86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V96YT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<V"FUS
M9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P=&5M8G)I<R(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS9VED
M(")3970@96YD(&1A=&4B"FUS9W-T<B`B3F%V(&)E:6=U(&1A='5M82(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V.`HC+"!F=7IZ>0IM<V=I9"`B
M4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`B071KXG)T;_!A;N)S
M(&EZ=&5CYVIU;6$@*&)E:6=U*2!D871U;7,B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B4V5T('-T
M87)T(&1A=&4B"FUS9W-T<B`B4^)K=6UA(&1A='5M<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU.0IM<V=I9"`B(@HB4V5T('EO=7(@9G)E92]B=7-Y
M(&-A;&5N9&%R<R!A;F0@>6]U<B!O=VX@86YD(&]T:&5R('5S97)S)R!F<F5E
M+V)U<WD@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HW
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&%R92!N;W0@9F]U;F0Z("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHW.0HC+"!F=7IZ>0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R<R(*;7-G<W1R
M("))979I;&MT(&MA;&5N9.)R=2(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHT
M-R!T96UP;&%T97,O;65N=2YI;F,Z-#D*(RP@9G5Z>GD*;7-G:60@(E-H87)E
M9"!#86QE;F1A<G,Z(@IM<V=S='(@(D5K<W!O<G3G="!K86QE;F3B<G4B"@HC
M.B!C86QE;F1A<E]S96%R8V@N<&AP.C(U('1E;7!L871E<R]W965K+VAE861?
M<VED95]B>5]S:61E+FEN8SHS"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@0V%L96YD87(B
M"FUS9W-T<B`B16MS<&]R=.=T(&MA;&5N9.)R=2(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O<V5A<F-H+FEN8SHR,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M:&]W(&-A;&5N9&%R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34V"FUS9VED(")3:&]W(&-A=&5G;W)Y(&QE9V5N9#\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I
M9"`B4VAO=R!D96QE=&4L(&%L87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I
M;B!C86QE;F1A<B!V:65W<S\B"FUS9W-T<B`B4N)D[G0@(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S:W,@:6X@
M=&AE(&-A;&5N9&%R/R(*;7-G<W1R(")2XF3N="!A<B!N;W1I:W5M:65M(&MA
M;&5N9.)RXC\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38V"FUS9VED
M(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@(E-H;W<@;VYL>2!E=F5N=',@
M=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS9W-T<B`B4N)D[G0@=&EK86D@
M;F]T:6MU;75S(&%R(&%T9^)D:6[B:G5M=3\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3<U"FUS9VED(")3:&]W('-H87)E9"!C86QE;F1A<G,@<VED
M92UB>2US:61E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C(Q"B,L(&9U>GIY"FUS9VED(")3:&]W('1A<VMS('5S:6YG(&-A=&5G
M;W)Y(&-O;&]R<S\B"FUS9W-T<B`B4N)D[G0@87(@;F]T:6MU;6EE;2!K86QE
M;F3B<N(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU"B,L(&9U>GIY
M"FUS9VED(")3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C:"!D87D@:6X@
M=V5E:R!V:65W<S\B"FUS9W-T<B`B4N)D[G0@8V5T=7)D8>]K=F%D<N)T:?)U
M<R!D:65N=2!U;B!N963G[W4@<VMA=&]S/R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")3=&%?<G0B
M"FUS9W-T<B`B4^)K<VEE<R(*"B,Z(&1A=&$N<&AP.C4U"FUS9VED(")3=&%R
M="!$871E(@IM<V=S='(@(E/B:W5M82!D871U;7,B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C<@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-0IM<V=I
M9"`B4W1A<G0@3VXB"FUS9W-T<B`B4^)K<VEE<R(*"B,Z(&1A=&$N<&AP.C4V
M"FUS9VED(")3=&%R="!4:6UE(@IM<V=S='(@(E/B:W5M82!L86EK<R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHY-2!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHX-0IM<V=I9"`B4W1A=%]U<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C8@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T871U<R(*;7-G
M<W1R("(B"@HC.B!Y96%R+G!H<#HX,2!Y96%R+G!H<#HY,"!T96UP;&%T97,O
M:F%V87-C<FEP="]G;W1O+FEN8SHV-0HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,C0@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#<@;&EB+T)L;V-K+VUO
M;G1H+G!H<#HQ,#D*;7-G:60@(E-U(@IM<V=S='(@(E-V(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H96%D+FEN
M8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(E-VYW1D:65N82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B5&%S:W,B"FUS9W-T
M<B`B57ID979U;6DB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S0@;&EB+TMR
M;VYO;&ET:"YP:'`Z-3DW"FUS9VED(")496YT871I=F4B"FUS9W-T<B`B(@H*
M(SH@>65A<BYP:'`Z.#8@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z
M-C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(Q"B,Z(&QI8B]";&]C:R]M
M;VYT:"YP:'`Z,3`U"FUS9VED(")4:"(*;7-G<W1R(")#92(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z-S`*;7-G:60@(E1H92!%9&ET
M($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N($5X:71I
M;F<N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@8V%N;F]T
M(&)E(&1E;&5T960N(@IM<V=S='(@(DEZ;6%I\F%S(&YE=F%R(&%T8V5L="$B
M"@HC.B!C86QE;F1A<G,N<&AP.C0P"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B
M(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R96YA;65D('1O(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HU-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C$V
M,PIM<V=I9"`B5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@
M<W1A<G0@9&%T92XB"FUS9W-T<B`B0F5I9W4@9&%T=6UA;2!I<B!JXF+[="!V
MYVSB:R!KXB!SXFMU;6$N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB(&AA<R!B965N
M(&%D9&5D+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960L('=H:6-H('=A<R!O
M;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3`Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB(&AA
M<R!B965N(&5D:71E9"P@=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@<W5C8V5S
M<V9U;&QY('-E;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$P,C0*;7-G:60@(E1H92!F;VQL;W=I;F<@:7,@82!M;W)E(&1E=&%I;&5D
M(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#HB"FUS9W-T<B`B(@H*(SH@871T
M96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E<W0@=V%S(&EN8V]M<&QE
M=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N96-E<W-A<GD@=&\@86-C
M97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E(&UI<W-I;F<N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O96UP='DN:6YC.C,*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E(&%R92!N;R!E=F5N=',@;6%T8VAI;F<@=&AE(&-U
M<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(DYA=B!N;W1I:W5M=2!K;R!E:W-P
M;W)TYW0B"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z,3@@961I=&5V96YT86-T
M:6]N+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S(@IM<V=S
M='(@(DOO^V1A(&EE;&%S;W0@9&%T=7,B"@HC.B!A9&1E=F5N=&%C=&EO;BYP
M:'`Z,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")+[_MD82!I
M96QA<V]T(&1A='5S(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HX,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&5D
M:71I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")+[_MD82!I96QA<V]T(&1A
M='5S(@H*(SH@;&EB+V%P:2YP:'`Z,S,X(&QI8B]A<&DN<&AP.C4Y-@HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(DOO^V1A(&EE;&%S;W0@9&%T=7,B
M"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C8S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N
M=#H@)7,B"FUS9W-T<B`B2^_[9&$@:65L87-O="!D871U<R(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R('-E;F1I;F<@86X@979E;G0@;F]T:69I8V%T:6]N('1O
M("5S.B`E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H
M97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R="XB"FUS9W-T<B`B3F%V(&YO
M=&EK=6UU(&MO(&5K<W!O<G3G="(*"B,Z(&1A=&$N<&AP.C$X-`IM<V=I9"`B
M5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B
M"@HC.B!D871A+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$Q.`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,0IM
M<V=I9"`B5&AU<G-D87DB"FUS9W-T<B`B0V5T=7)D:65N82(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHS-PHC+"!F=7IZ>0IM<V=I9"`B5&EM
M92!3<%]A;B(*;7-G<W1R("),86EK82!Z:6YA(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B5&EM92!S
M<&%N(@IM<V=S='(@(DQA:6MA('II;F$B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z,S8@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(E1I=%]L92(*;7-G<W1R(").;W-A=6MU
M;7,B"@HC.B!D871A+G!H<#HU-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z,C`*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHS
M"FUS9VED(")4:71L92(*;7-G<W1R(").;W-A=6MU;7,B"@HC.B!L:6(O0FQO
M8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(R(&QI8B]";&]C:R]M;VYT:&QI<W0N
M<&AP.C$R,0HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(W"FUS9VED(")4
M;V1A>2(*;7-G<W1R("+0;V1I96YA(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT
M:&QI<W0N<&AP.C$R-"!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ,C,*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R.0IM<V=I9"`B5&]M;W)R;W<B"FUS
M9W-T<B`B4NYT9&EE;F$B"@HC.B!Y96%R+G!H<#HX-"!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV,"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,3D*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1U(@IM<V=S
M='(@(D]T(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$W('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$Q-@HC.B!T96UP;&%T97,O961I="]J879A
M<V-R:7!T+FEN8SHV.0IM<V=I9"`B5'5E<V1A>2(*;7-G<W1R(")/=')D:65N
M82(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B5'EP
M92(*;7-G<W1R(")4:7!S(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$X,PIM<V=I9"`B55),(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M7"(E<UPB.B`E<R(*;7-G<W1R(").979A<B!N96]D>N=S="`E<RXB"@HC.B!L
M:6(O1')I=F5R+VUC86PN<&AP.C$S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E("5S+B(*;7-G<W1R(").979A<B!N96]D>N=S="`E
M<RXB"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(DYE=F%R(&EE;.)DYW0@9&5F:6[N8VEJ=2!I96OP("5S+B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@7"(E<UPB.B`E<R(*;7-G<W1R(").979A<B!N96]D
M>N=S="`E<RXB"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z,S0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R971R:65V92!F<F5E
M+V)U<WD@:6YF;W)M871I;VX@9F]R("5S(@IM<V=S='(@(DYE=F%R(&EE;.)D
MYW0@9&5F:6[N8VEJ=2!I96OP("5S+B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$U"B,Z('-C<FEP=',O=7!G<F%D97,O,C`P-"TP-2TQ.5]C;VYV
M97)T7V-A=&5G;W)I97-?=&]?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E5N9FEL
M960B"FUS9W-T<B`B3F5A:7IP:6QD[G1S(@H*(SH@;&EB+V%P:2YP:'`Z,S<V
M(&QI8B]A<&DN<&AP.C0U,"!L:6(O87!I+G!H<#HU,38@;&EB+V%P:2YP:'`Z
M-C(Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M
M5'EP93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Q
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"FUS9VED(")5<V5R($EN
M=&5R9F%C92(*;7-G<W1R("),:65T;W3B:F$@<VMA=',B"@HC.B!Y96%R+G!H
M<#HQ-C,@>65A<BYP:'`Z,38Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,38R"B,L(&9U>GIY"FUS9VED(")6:65W($1A
M>2(*;7-G<W1R(")3:V%T<R`E<R(*"B,Z('EE87(N<&AP.C@U('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(R,`HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5V4B
M"FUS9W-T<B`B5'(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3@@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$W"B,Z('1E;7!L871E<R]E9&ET
M+VIA=F%S8W)I<'0N:6YC.C<P"FUS9VED(")7961N97-D87DB"FUS9W-T<B`B
M5')E\&1I96YA(@H*(SH@871T96YD965S+G!H<#HQ,3(@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3(Y,"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,PHC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(E=E96LB"FUS9W-T<B`B3F5D
MY^]A(@H*(SH@;6]N=&@N<&AP.C$W.2!W;W)K=V5E:RYP:'`Z,S`@=V5E:RYP
M:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5E:R`E9"(*;7-G<W1R(").
M963G[V%S("5D(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3D@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED(")7965K*',I(@IM<V=S
M='(@(DYE9.?O82AS*2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R
M,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,34*;7-G:60@(E=E96ML>3H@
M4F5C=7)S(&5V97)Y(@IM<V=S='(@(DYE9.?O83H@071KXG)T;W1I97,@:V%T
M<G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED("(B"B)7
M:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@
M=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\B"FUS9W-T<B`B2^)DXB!L86EK
MXB!D:65N86D@=6X@;F5DY^]A:2!JXF)E:61Z87,L(&IA(&YA=B!C:71U(&EE
M<F%K<W1U/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@
M(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S('-T87)T
M+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V96YT<S\B"FUS9W-T<B`B
M2^)DXB!L86EKXB!D:65N86D@=6X@;F5DY^]A:2!JXG/B:V%S+"!J82!N878@
M8VET=2!I97)A:W-T=3\B"@HC.B!A='1E;F1E97,N<&AP.C$Q,2!L:6(O2W)O
M;F]L:71H+G!H<#HQ,C@Y(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B5V]R:R!7965K(@IM
M<V=S='(@(D1A<F)A(&YE9.?O82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$R
M.3(@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C4*;7-G:60@(EEE87(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(X('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(T,0IM<V=I9"`B665A<FQY.B!296-U<G,@
M979E<GDB"FUS9W-T<B`B26MG861U<SH@071KXG)T;W1I97,@:V%T<G4B"@HC
M.B!D871A+G!H<#HT,"!D871A+G!H<#HR,S0@961I=&5V96YT86-T:6]N+G!H
M<#HT-B!A9&1E=F5N="YP:'`Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&5V96YT
M<RXB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HT.0IM<V=I9"`B66]U(&%R
M92!N;W0@86X@871T96YD964@;V8@=&AE('-P96-I9FEE9"!E=F5N="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW
M-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T:&ES(&9O<FT@9G)O;2!T:&4@
M161I="!!='1E;F1E97,@<V-R965N+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HY-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1O
M(&YO="!H879E(&%N(&5M86EL(&%D9')E<W,@8V]N9FEG=7)E9"!I;B!Y;W5R
M(%!E<G-O;F%L($EN9F]R;6%T:6]N("(*(D]P=&EO;G,N(%EO=2!M=7-T('-E
M="!O;F4@)7-H97)E)7,@8F5F;W)E(&5V96YT(&YO=&EF:6-A=&EO;G,@8V%N
M(&)E('-E;G0N(@IM<V=S='(@(B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HR
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES
M<VEO;B!T;R!A9&0@979E;G1S('1O("5S+B(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HQ.30*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M(&%D9"!E=F5N=',@=&\@=&AE('-E;&5C=&5D(&-A;&5N9&%R+B(*;7-G<W1R
M("(B"@HC.B!D96QE=F5N=&%C=&EO;BYP:'`Z,C8*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T92!T:&ES(&5V96YT+B(*;7-G
M<W1R("(B"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C<X"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X.0IM<V=I9"`B66]U(&AA=F4@<W!E
M8VEF:65D(&%N(&EN=F%L:60@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z(&%T
M=&5N9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!A8V-E
M<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z
M(&%T=&5N9"YP:'`Z,C8*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!D
M96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(B(*
M"B,Z(&%T=&5N9"YP:'`Z,S$*;7-G:60@(EEO=2!H879E('1E;G1A=&EV96QY
M(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`B
M(@H*(SH@8V%L96YD87)S+G!H<#HY,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T
M(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHU-`HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@
M(DIU;7,@:7(@:N)I>G;G;&%S(&MA=&5G;W)I:F$B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#DT"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF
M:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`IM<V=I9"`B
M(@HB66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A
M<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY"FUS9VED(")9;W4@<F5Q=65S=&5D
M('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET960@:6X@>6]U
M<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]38VAE9'5L97(O:W)O
M;F]L:71H+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<75E
M<W1E9"!T;R!B92!R96UI;F1E9"!A8F]U="`E<RP@=VAI8V@@:7,@;VX@)7,@
M870@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S:&%R97-E
M;&5C="YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!C86QE
M;F1A<B(*;7-G<W1R(")%:W-P;W)TYW0@:V%L96YDXG)U(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3`U,R!L:6(O1')I=F5R+G!H<#HQ,#8S"FUS9VED(");56YN
M86UE9"!E=F5N=%TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z.3<*(RP@9G5Z>GD*;7-G:60@(E]!;&%R;2(*;7-G<W1R(")!=&?B
M9&ENXFIU;7,B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E
M9"YI;F,Z,3$*;7-G:60@(E]"87-I8R!396%R8V@B"FUS9W-T<B`B(@H*(SH@
M=FEE=V5V96YT+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E]%9&ET(@IM<V=S
M='(@(DQA8F]T(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,`HC+"!F=7IZ
M>0IM<V=I9"`B7T=O=&\B"FUS9W-T<B`B265T('5Z(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3,S-@HC+"!F=7IZ>0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B
M"FUS9W-T<B`B265V:6QK="]%:W-P;W)TYW0B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,S$X"B,L(&9U>GIY"FUS9VED(")?37D@0V%L96YD87)S(@IM<V=S
M='(@(D5K<W!O<G3G="!K86QE;F3B<G4B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,S(U"B,L(&9U>GIY"FUS9VED(")?3F5W($5V96YT(@IM<V=S='(@(DIA
M=6YS(&YO=&EK=6US(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,T,0HC+"!F
M=7IZ>0IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(D1R=6OB="(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$S,S(*(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS
M9W-T<B`B36%R=',B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S(X"B,L(&9U
M>GIY"FUS9VED(")?5&]D87DB"FUS9W-T<B`BT&]D:65N82(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C$T,@IM<V=I9"`B8F5F;W)E('1H92!E=F5N
M="!S=&%R=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$X-0IM<V=I9"`B9&%Y(@IM<V=S='(@(F1I96YA(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q
M,`IM<V=I9"`B9&%Y*',I(@IM<V=S='(@(F1I96YA*',I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$X-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@W
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#@@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$X.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED
M(")D87ES(@IM<V=S='(@(F1I96YA<R(*"B,Z(&1A=&$N<&AP.C$T-R!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*(RP@9G5Z>GD*;7-G:60@(F5V96YT
M<RYC<W8B"FUS9W-T<B`B5FES:2!N;W1I:W5M:2(*"B,Z(&1A=&$N<&AP.C$V
M.`HC+"!F=7IZ>0IM<V=I9"`B979E;G1S+FEC<R(*;7-G<W1R(")6:7-I(&YO
M=&EK=6UI(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M,S$*;7-G:60@(F9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,S`@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C,V"FUS9VED(")M;VYT:"AS*2(*;7-G<W1R(")MYVYE<VES*"WP
M:2DB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")O;B`E<R!A="`E<R(*;7-G<W1R("(E<R!SXFMA<R!P
MYV,@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C,P"FUS9VED(")O;B!T:&4@<V%M92!D871E
M(@IM<V=S='(@(G1A:N(@<&'PXB!D871U;>(B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,V"FUS
M9VED(")O;B!T:&4@<V%M92!W965K9&%Y(@IM<V=S='(@(G1A:N(@<&'PXB!N
M963G[V%S(&1I96[B(@H*(SH@9&%T82YP:'`Z,S`@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ-0IM<V=I9"`B=D-A;&5N9&%R+VE#86QE;F1A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HS-#D@;&EB+V%P:2YP:'`Z-C`W"FUS
M9VED(")V179E;G0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DQ"FUS9VED(")W965K(@IM<V=S='(@(FYE9.?O
M82(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,3<*;7-G:60@(G=E96LH<RD@;VXZ(@IM<V=S='(@
M(FYE9.=LXB@MXG,I(#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DR
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y-`IM<V=I9"`B=V5E:W,B"FUS9W-T<B`B;F5DY^]A<R(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR-#(*;7-G:60@(GEE87(H<RDB"FUS9W-T<B`B9V%D<R@M:2DB
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O<&\O;FY?
M3D\N<&\`````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3(P
M-38T`#$P-#$W,S8R-S4S`#`R,#0R-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````C($MR;VYO;&ET:"!.;W)W96=I86X@3GEN
M;W)S:R!T<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,B!097(M4W1I
M86X@5F%T;F4*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2W)O;F]L:71H('!A8VMA9V4N"B,@4&5R
M+5-T:6%N(%9A=&YE(#QP<W9`;W)S=&$N;W)G/BP@,C`P,BX*(R`*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($MR;VYO;&ET:"`R
M+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP-BTP."`P,CHS
M.2LP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z(%!E<BU3=&EA;B!6871N92`\
M<'-V0&]R<W1A+F]R9SY<;B(*(DQA;F=U86=E+51E86TZ($YO<G=E9VEA;B!.
M>6YO<G-K(#QN>6YO<G-K0&]R<W1A+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@
M,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O
M+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&-A;&5N9&%R<R!F;W5N9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)60@979E;G1S(@IM<V=S='(@(D%L;&4@:&5N
M9&EN9V%R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S($1A>2AS*2`E<R!(;W5R*',I
M("5S($UI;G5T97,B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A='1E;F1E97,B"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I
M;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(D9I;&$@)7,@=F%R
M="!I;7!O<G1E<G0B"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O8F%S92YP
M:'`Z,3(X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(D5K<W!O<G1E<B!K86QE;F1E<B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N
M(&-A;&5N9&%R(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB
M:6QI='D@:6X@=&AE(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V-`IM<V=I9"`B*B!!
M9&0@=&AE<V4@8GD@8VQI8VMI;F<@061D("HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-3`*;7-G:60@(BH@4&QE
M87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@(B(*"B,Z(&QI8B]$
M<FEV97(N<&AP.C$W.#8*;7-G:60@(C$@871T96YD964B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*(RP@9G5Z>GD*;7-G
M:60@(C$@979E;G0B"FUS9W-T<B`B06QL92!H96YD:6YG87(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,W"B,L(&9U>GIY"FUS9VED("(Q(&AO=7(B
M"FUS9W-T<B`B)60@=&EM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S0*(RP@9G5Z>GD*;7-G:60@(C$U(&UI;G5T97,B"FUS9W-T<B`B)60@;6EN
M=71T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM
M<V=I9"`B,C`@;6EN=71E<R(*;7-G<W1R("(E9"!M:6YU='0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,V"B,L(&9U>GIY"FUS9VED("(S,"!M:6YU
M=&5S(@IM<V=S='(@(B5D(&UI;G5T="(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C$W,0HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY!='1E;F1E97,\
M+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\8CY.^&MK96QO<F0\+V(^
M("AV86QF<FET="DB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#D*
M(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^1&5S8W)I7W!T:6]N/"]S=')O;F<^
M("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^4VMI;&1R:6YG/"]B/B`H=F%L9G)I
M='0I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C<W"B,L(&9U>GIY
M"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO<'1I;VYA;"DB
M"FUS9W-T<B`B/&(^3OAK:V5L;W)D/"]B/B`H=F%L9G)I='0I(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3DT"B,L(&9U>GIY"FUS9VED("(\<W1R
M;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\
M8CY296=E;&9A<W0\+V(^("AV86QF<FET="DB"@HC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C$P,2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X
M,0IM<V=I9"`B04TB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M-3DQ"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z,3$*;7-G:60@(D%D7W9A;F-E9"!396%R8V@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ-C$@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G
M:60@(D%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR-@IM<V=I9"`B061D($5V96YT(@IM<V=S='(@(DQE9V<@=&EL(&AE;F1I
M;F<B"@HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT
M+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B061D(&$@;F5W(%)E;6]T92!#86QE
M;F1A<B(*;7-G<W1R("),96=G('1I;"!N>2!H96YD:6YG(@H*(SH@861D979E
M;G0N<&AP.C8T"FUS9VED(")!9&0@82!N97<@979E;G0B"FUS9W-T<B`B3&5G
M9R!T:6P@;GD@:&5N9&EN9R(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T
M96YD965S+FEN8SHW-`IM<V=I9"`B061D(&%T=&5N9&5E<R(*;7-G<W1R("(B
M"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C<X"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R8V@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3,*;7-G
M:60@(D%L87)M(@IM<V=S='(@(D%L87)M(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!D87ES(&)E9F]R
M92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D%L87)M("5D(&AO=7)S(&)E9F]R92(*;7-G<W1R("(B
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!;&%R;2`E9"!M:6YU=&5S(&)E9F]R92(*;7-G<W1R(")-:6YU
M='0@9OAR(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!;&%R;2`E9"!W965K<R!B969O<F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z,3<V,PIM<V=I9"`B06QA<FT@,2!D87D@8F5F;W)E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C@*;7-G:60@(D%L
M87)M(#$@:&]U<B!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3<W,PHC+"!F=7IZ>0IM<V=I9"`B06QA<FT@,2!M:6YU=&4@8F5F;W)E
M(@IM<V=S='(@(DUI;G5T="!F^'(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S4X
M"FUS9VED(")!;&%R;2`Q('=E96L@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C8P"FUS9VED(")!;&%R;2!$871E(@IM<V=S='(@(D%L87)M9&%T
M;R(*"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!3<&%N("AM:6YU=&5S
M*2(*;7-G<W1R(")!;&%R;6EN=&5R=F%L;"`H;6EN=71T*2(*"B,Z(&1A=&$N
M<&AP.C8Q"FUS9VED(")!;&%R;2!4:6UE(@IM<V=S='(@(D%L87)M=&ED<W!U
M;FMT(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,Q"FUS9VED
M(")!;&PB"FUS9W-T<B`B06QL92(*"B,Z(&QI8B]&0E9I97<N<&AP.C$R-B!L
M:6(O1D)6:65W+G!H<#HQ,CD@;&EB+T9"5FEE=RYP:'`Z,3,R"B,L(&9U>GIY
M"FUS9VED(")!;&P@071T96YD965S(@IM<V=S='(@(D%L;&4@:&5N9&EN9V%R
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4Y"B,L(&9U>GIY
M"FUS9VED(")!;&P@1G5T=7)E(@IM<V=S='(@(D9R86UT:60B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*(RP@9G5Z>GD*;7-G:60@(D%L
M;"!087-T(@IM<V=S='(@(DAE:6QE(&1A9V5N(@H*(SH@;&EB+T)L;V-K+W!R
M979M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C:R]M;VYT:"YP:'`Z,C0*(SH@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C(U"FUS9VED(")!;&P@5FES:6)L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,C(@;&EB+T1A>59I97<N
M<&AP.CDP(&QI8B]$87E6:65W+G!H<#HY,PHC.B!L:6(O5V5E:U9I97<N<&AP
M.C$R-R!L:6(O5V5E:U9I97<N<&AP.C$S-"!L:6(O1')I=F5R+G!H<#HQ.#,R
M"FUS9VED(")!;&P@9&%Y(@IM<V=S='(@(DAE:6QE(&1A9V5N(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C$V-`IM<V=I9"`B06QL(&1A>2!E=F5N="(*
M;7-G<W1R(")687)E<B!H96EL92!D86=E;B(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,C$*;7-G:60@(D%L;"!E=F5N=',B"FUS9W-T<B`B06QL
M92!H96YD:6YG87(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z-#D*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC
M960N:6YC.C<Q(&QI8B]+<F]N;VQI=&@N<&AP.C8X,PIM<V=I9"`B06YY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q
M"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I;"(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C,Y('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.CDS"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M-S`@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-38*;7-G:60@(D%T(@IM
M<V=S='(@(B`B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(V"FUS9VED("(B
M"B)!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!W:71H(&UO<F4@:6YF
M;W)M871I;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y;W5R("(*(FUA:6P@8VQI
M96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@=&AI<R!F
M:6QE('1O(&5A<VEL>2!U<&1A=&4@(@HB>6]U<B!L;V-A;"!C;W!Y(&]F('1H
M92!E=F5N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C0R('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-0IM
M<V=I9"`B071T96YD86YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ-C$*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-0IM<V=I9"`B075G
M=7-T(@IM<V=S='(@(D%U9W5S="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H7V%D=F%N8V5D+FEN8SHQ,2!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI
M;F,Z.`IM<V=I9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B0FER=&AD87DB"FUS9W-T
M<B`B0G5R<V1A9R(*"B,Z(&QI8B]&0E9I97<N<&AP.CDP(&QI8B]&0E9I97<N
M<&AP.C$Q,`IM<V=I9"`B0G5S>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@
M(D-?86QE;F1A<B(*;7-G<W1R("));7!O<G1E<B!K86QE;F1E<B(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C0Y"B,L(&9U>GIY"FUS9VED(")#86Q?
M96YD87(B"FUS9W-T<B`B26UP;W)T97(@:V%L96YD97(B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30V(&QI8B]";&]C:R]P<F5V
M;6]N=&AL:7-T+G!H<#HR,0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C(Q(&QI
M8B]";&]C:R]M;VYT:&QI<W0N<&AP.C(Q(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HR,@HC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B26UP;W)T
M97(@:V%L96YD97(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PHC+"!F
M=7IZ>0IM<V=I9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G<W1R(")386UA;F1R
M86<B"@HC.B!D871A+G!H<#HR,C@*(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R
M('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(FE#86QE;F1A<BUF:6P@
M=F%R="!I;7!O<G1E<G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<*(RP@9G5Z>GD*;7-G
M:60@(D-A;&5N9&%R<R(*;7-G<W1R("));7!O<G1E<B!K86QE;F1E<B(*"B,Z
M(&-A;&5N9&%R<RYP:'`Z,C<*;7-G:60@(D-A;&5N9&%R<R!M=7-T(&AA=F4@
M82!N86UE+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-#,*(RP@9G5Z>GD*
M;7-G:60@(D-A;B=T(&-R96%T92!A(&YE=R!E=F5N="XB"FUS9W-T<B`B3W!P
M<F5T="!N>2!H96YD:6YG(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ.3$@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,P"B,Z('1E
M;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS,B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#D*;7-G
M:60@(D-A;F-E;"(*;7-G<W1R(")!=F)R>70B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HU-S`*(RP@9G5Z>GD*;7-G:60@(D-A;F-E;&QE9"(*;7-G<W1R(")!
M=F)R>70B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#`Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YC96QL960Z("5S(@IM<V=S='(@(D%V8G)Y
M="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV
M-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHV.0HC+"!F=7IZ>0IM<V=I9"`B
M0V%T96=O<E]Y(@IM<V=S='(@(DMA=&5G;W)I(@H*(SH@9&%T82YP:'`Z-C,@
M=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHT('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$S"FUS9VED(")#871E9V]R>2(*;7-G<W1R(")+
M871E9V]R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@
M(B(*(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L
M(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S(&)Y("(*(F5M86EL.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D-H
M;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E
M9"P@86YD(&1E;&5T960@979E;G1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V5A<F-H7V%B;V]K7W-E;&5C="YI;F,Z,3D@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Y.0IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O
M;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]F8E]C86QS7W-E;&5C="YI;F,Z,38*;7-G
M:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,3$*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S
M('1O(&EN8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!54DQS.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@
M(D-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHV-0IM<V=I9"`B
M0VQE87(@86QL(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR
M."!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S
M97!A<F%T960@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW,PIM<V=I9"`B0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_
M(@IM<V=S='(@(E-T861F97-T('-L971T:6YG(&%V(&AE;F1I;F=A<C\B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HU-C<*;7-G:60@(D-O;F9I<FUE9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M,C`X"FUS9VED(")#;W!Y('1H92!54DP@8F5L;W<@9F]R('5S92!W:&5R979E
M<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ(@IM<V=S='(@(B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$R-@HC+"!F=7IZ>0IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(DYO=F5R86YD92(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O8V%L96YD87)S+FEN8SHQ,3(*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!#
M86QE;F1A<B(*;7-G<W1R("));7!O<G1E<B!K86QE;F1E<B(*"B,Z(&UO;G1H
M+G!H<#HQ-C4@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,C4@=&5M<&QA=&5S
M+V1A>2]R;W<N:6YC.C8*(SH@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6
M:65W+G!H<#HQ.30*;7-G:60@(D-R96%T92!A($YE=R!%=F5N="(*;7-G<W1R
M(")/<'!R971T(&YY(&AE;F1I;F<B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHX,`IM<V=I9"`B0W)E871E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&5L971E+V1E;&5T92YI;F,Z,CD*;7-G:60@(D-U<G)E;G0B"FUS9W-T
M<B`B3F]V97)A;F1E(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(P.0IM<V=I9"`B1&%I;'DZ(%)E
M8W5R<R!E=F5R>2(*;7-G<W1R(")+=F%R(&1A9SH@4VMJ97(@:W9A<B(*"B,Z
M(&%T=&5N9&5E<RYP:'`Z,3$P(&QI8B]+<F]N;VQI=&@N<&AP.C$R.#@@;&EB
M+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@R"FUS9VED(")$87DB"FUS9W-T<B`B1&%G(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,Y
M"FUS9VED(")$87DH<RDB"FUS9W-T<B`B9&%G*&%R*2(*"B,Z('9I97=E=F5N
M="YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")$95]L971E(@IM<V=S='(@(E-L
M971T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-SD*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E<V5M8F5R(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3DT"FUS9VED(")$96-L:6YE9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U
M;'0@0V%L96YD87(B"FUS9W-T<B`B26UP;W)T97(@:V%L96YD97(B"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DS('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@Q"B,Z('1E;7!L871E<R]D96QE
M=&4O;VYE+FEN8SHR.2!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA
M9V5M96YT+FEN8SHR,PHC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"FUS9VED(")$
M96QE=&4B"FUS9W-T<B`B4VQE='0B"@HC.B!D96QE=F5N="YP:'`Z-#`@=&5M
M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C$X('1E;7!L871E<R]D96QE=&4O9&5L
M971E+FEN8SHQ.`HC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R(")3;&5T="`E<R(*"B,Z(&5D
M:71E=F5N="YP:'`Z-S`*;7-G:60@(D1E;&5T92!%=F5N="(*;7-G<W1R(")3
M;&5T="!H96YD:6YG(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC
M.C(W"FUS9VED("(B"B)$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@
M=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R
M("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R("(B"B)3;&5T="!B97)R92!G
M:F5L9&%N9&4@:&5N9&EN9RP@9&5N;F4@9OAR96MO;7-T96X@;V<@86QL92!F
M<F%M=&ED:6=E("(*(F;X<F5K;VUS=&5R+"!E;&QE<B!A;&QE(&;X<F5K;VUS
M=&5R/R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN
M8SHQ,#0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X"B,L(&9U>GIY
M"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B4VMI;&1R:6YG(@H*(SH@
M9&%T82YP:'`Z-C(@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$W-0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHY-@IM<V=I9"`B1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B4VMI;&1R:6YG(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S,*(RP@9G5Z>GD*;7-G:60@(D1I<W!L
M87DB"FUS9W-T<B`B5FES:6YG<V%L=&5R;F%T:78B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D1I
M<W!L87D@0V%L96YD87)S(@IM<V=S='(@(E9I<VEN9W-A;'1E<FYA=&EV(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&ES<&QA
M>2!/<'1I;VYS(@IM<V=S='(@(E9I<VEN9W-A;'1E<FYA=&EV(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$;R!Y;W4@=V%N="!T;R!S
M:&]W('1A<VMS('=H:6-H(&%R92!D=64@;VX@>6]U<B!C86QE;F1A<C\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3,W"FUS9VED(")$;V5S
M(&YO="!R96-U<B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HS
M,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1'5E.B`E<R(*;7-G<W1R(")&;W)F
M96QL.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC
M.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B1'5R871I;VXB"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<P(&QI8B]$<FEV
M97(N<&AP.C$X,#8*;7-G:60@(D5D:70B"FUS9W-T<B`B16YD<F4B"@HC.B!E
M9&ET979E;G0N<&AP.C,S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V(&QI
M8B]$<FEV97(N<&AP.C$X,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="`E
M<R(*;7-G<W1R(")%;F1R92`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C$X-PIM<V=I9"`B161I="!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$T,`HC+"!F=7IZ
M>0IM<V=I9"`B161I="!#86QE;F1A<G,B"FUS9W-T<B`B16MS<&]R=&5R(&MA
M;&5N9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,`HC+"!F=7IZ
M>0IM<V=I9"`B161I="!296UO=&4@0V%L96YD87)S(@IM<V=S='(@(DEM<&]R
M=&5R(&MA;&5N9&5R(@H*(SH@871T96YD965S+G!H<#HQ-3`*;7-G:60@(D5D
M:70@871T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C871E9V]R
M>5]L96=E;F0N:6YC.C(P"FUS9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O
M;&]R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$W-B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z
M-#$*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38T"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C8P"B,L(&9U>GIY"FUS9VED(")%;E]D(@IM<V=S='(@
M(E-L=71T(@H*(SH@9&%T82YP:'`Z-3<*;7-G:60@(D5N9"!$871E(@IM<V=S
M='(@(E-L=71T9&%T;R(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A
M9&5R<RYI;F,Z."!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P.`IM<V=I9"`B16YD($]N(@IM<V=S
M='(@(E-L=71T(@H*(SH@9&%T82YP:'`Z-3@*;7-G:60@(D5N9"!4:6UE(@IM
M<V=S='(@(E-L=71T:61S<'5N:W0B"@HC.B!A='1E;F1E97,N<&AP.C$R-"!A
M='1E;F1E97,N<&AP.C$S-2!A='1E;F1E97,N<&AP.C$T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I;F9O<FUA
M=&EO;B!F;W(@)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$P.3,*;7-G:60@(D5V96YT(&%D9&5D.B(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,3`S"FUS9VED(")%=F5N="!D96QE=&5D.B(*
M;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DX"FUS9VED(")%
M=F5N="!E9&ET960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P
M-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B179E;G0@9G)O;2`E<R!T;R`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HW-C0*(RP@9G5Z>GD*;7-G
M:60@(D5V96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E+B(*;7-G<W1R(")3
M;'5T=&1A=&\@;>4@=F5R92!S96EN87)E(&5N;B!S=&%R=&1A=&\N(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z-S,P"FUS9VED(")%=F5N=',@;75S="!H879E(&$@
M=&ET;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V-PIM<V=I
M9"`B179E;G1S(&UU<W0@:&%V92!A;B!E;F0@9&%T92!O<B!A(&1U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E
M<RYI;F,Z-SD*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R
M(")3;'5T=&ED<W!U;FMT(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ.#<*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%:W-P;W)T(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@0V%L96YD
M87(B"FUS9W-T<B`B16MS<&]R=&5R(&MA;&5N9&5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-CD*;7-G:60@(D9E8G)U87)Y(@IM<V=S
M='(@(D9E8G)U87(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$R.`HC+"!F=7IZ>0IM<V=I9"`B1FEN9"(*;7-G<W1R(")&<F5D86<B
M"@HC.B!Y96%R+G!H<#HX-R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C(*(SH@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ,#4*;7-G:60@(D9R(@IM<V=S='(@(D9R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U
M<WD@26YF;W)M871I;VXB"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(P('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$Q.0HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW
M,@IM<V=I9"`B1G)I9&%Y(@IM<V=S='(@(D9R961A9R(*"B,Z('1E;7!L871E
M<R]D96QE=&4O9&5L971E+FEN8SHS,`IM<V=I9"`B1G5T=7)E(@IM<V=S='(@
M(D9R86UT:60B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G
M:60@(D=A;64B"FUS9W-T<B`B4W!E;"(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H7V%D=F%N8V5D+FEN8SHR,PIM<V=I9"`B1V5N97)A;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")';W1O("5S(@IM<V=S='(@(D?E('1I;"(*"B,Z
M(&UO;G1H+G!H<#HQ,S4@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I
M9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N
M:6YC.C$P"FUS9VED(")(:61E(@IM<V=S='(@(B(*"B,Z(&UO;G1H+G!H<#HQ
M,S4@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z
M('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(:61E("5S(@IM<V=S='(@(E9I<R`E
M<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8U('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C$S.`IM<V=I9"`B2&]U<BAS*2(*;7-G<W1R(")T:6UE
M+W1I;6%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC+"!F=7IZ
M>0IM<V=I9"`B2&]W(&QO;F<@<VAO=6QD('1H92!T:6UE('-L;W1S(&]N('1H
M92!D87D@86YD('=E96L@=FEE=W,@8F4_(@IM<V=S='(@(E9I<R!H86QV=&EM
M97-E9VUE;G0@:2!D86<M(&]G('9E:V5V:7-I;F<_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(X.`IM<V=I9"`B2&]W(&UA;GD@9&%Y<R!O9B!F<F5E
M+V)U<WD@:6YF;W)M871I;VX@<VAO=6QD('=E(&=E;F5R871E/R(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#,P"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(DEF('EO=7(@96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R
M="!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T:&4@(@HB9F]L
M;&]W:6YG(&QI;FMS('1O(&%C8V5P="!O<B!D96-L:6YE('1H92!E=F5N="Y<
M;B(*(EQN(@HB5&\@86-C97!T('1H92!E=F5N=#I<;B(*(B5S7&XB"B)<;B(*
M(E1O(&%C8V5P="!T:&4@979E;G0@=&5N=&%T:79E;'DZ7&XB"B(E<UQN(@HB
M7&XB"B)4;R!D96-L:6YE('1H92!E=F5N=#I<;B(*(B5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T($-A;&5N9&%R+"!3=&5P("5D(@IM<V=S
M='(@(DEM<&]R=&5R(&MA;&5N9&5R(@H*(SH@9&%T82YP:'`Z,S(P"FUS9VED
M("));7!O<G0O17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(DEM<&]R="]E:W-P
M;W)T(&MA;&5N9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-C@*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=6%R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S0*;7-G:60@(DIU;'DB"FUS
M9W-T<B`B2G5L:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C<S"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC.B!D871A+G!H<#HV
M-2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-#(*;7-G:60@(DME>7=O<F1S
M(@IM<V=S='(@(D[X:VME;&]R9"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R-"!H;W5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHX-PIM<V=I9"`B3&%S="!-;V1I
M9FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C0*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ,`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y
M7W-I9&4N:6YC.C$V('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHT"B,L(&9U
M>GIY"FUS9VED("),87-T($UO;G1H(@IM<V=S='(@(D;X<G)E(&WE;F%D(@H*
M(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B
M3&%S="!996%R(@IM<V=S='(@(D;X<G)E('9E:V4B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z-30@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z
M,PIM<V=I9"`B3&%S="!W965K(@IM<V=S='(@(D;X<G)E('9E:V4B"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$W"FUS9VED("),:6UI="!T:&4@
M=&EM92!S<&%N('1O(&5X<&]R=#HB"FUS9W-T<B`B079G<F5N<R!T:61S:6YT
M97)V86QL(&9O<B!E:W-P;W)T.B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H7V%D=F%N8V5D+FEN8SHX-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B3&]?8V%T:6]N(@IM<V=S='(@(E!L87-S97)I
M;F<B"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE
M861E<G,N:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N
M86=E;65N="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?
M;6%N86=E;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C$*
M(SH@;&EB+T1R:79E<BYP:'`Z,3@T.0IM<V=I9"`B3&]C871I;VXB"FUS9W-T
M<B`B4&QA<W-E<FEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-0IM
M<V=I9"`B36%N86=E(')E;6]T92!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<P"FUS9VED(")-87)C
M:"(*;7-G<W1R(")-87)S(@H*(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-
M87AI;75M($YU;6)E<B!O9B!%=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R
M(")-86DB"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0V"FUS9VED(")-92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@
M(DUE971I;F<B"FUS9W-T<B`B3?AT92(*"B,Z(&QI8B]";&]C:R]T<F5E7V%L
M87)M<RYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!!;&%R;7,B"FUS9W-T
M<B`B06QA<FTB"@HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HS"FUS9VED
M(")-96YU($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,W"FUS9VED(")-
M:6YU=&4H<RDB"FUS9W-T<B`B;6EN=71T(@H*(SH@;&EB+T)L;V-K+W!R979M
M;VYT:&QI<W0N<&AP.C0R"FUS9VED(")-:7-S960@179E;G1S($QI<W0B"FUS
M9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$X"B,Z(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")-;R(*;7-G<W1R(")-Y2(*
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,34*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI
M;F,Z-C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@IM<V=I9"`B36]N9&%Y
M(@IM<V=S='(@(DWE;F1A9R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$R.3$@
M;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C0@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@U"FUS9VED(")-;VYT:"(*;7-G<W1R(")-Y6YA9"(*"B,Z(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B36]N=&@@5FEE=R(*
M;7-G<W1R(")-Y6YA9"(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C,@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#,*;7-G:60@(DUO;G1H;'D@179E
M;G1S($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHR,CD@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C,U"FUS9VED(")-;VYT:&QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B2W9A
M<B!MY6YA9#H@4VMJ97(@:W9A<B(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N
M<&AP.C(T"FUS9VED(")-;VYT:',@06AE860B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(T"B,L(&9U>GIY"FUS9VED(")-
M;VYT:',@0F5F;W)E(@IM<V=S='(@(DUI;G5T="!F^'(B"@HC.B!L:6(O87!I
M+G!H<#HV,3(*;7-G:60@(DUU;'1I<&QE(&E#86QE;F1A<B!C;VUP;VYE;G1S
M(&9O=6YD.R!O;FQY(&]N92!V179E;G0@:7,@<W5P<&]R=&5D+B(*;7-G<W1R
M("(B"@HC.B!C86QE;F1A<G,N<&AP.C$R."!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(DUY($-A;&5N9&%R
M<R(*;7-G<W1R("));7!O<G1E<B!K86QE;F1E<B(*"B,Z('1E;7!L871E<R]M
M96YU+FEN8SHS-"!T96UP;&%T97,O;65N=2YI;F,Z,S8*(RP@9G5Z>GD*;7-G
M:60@(DUY($-A;&5N9&%R<SHB"FUS9W-T<B`B16MS<&]R=&5R(&MA;&5N9&5R
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(P-`IM
M<V=I9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3$W('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ-3D*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ-S4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C
M86Q?;6%N86=E;65N="YI;F,Z,3<*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T
M95]C86Q?;6%N86=E;65N="YI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYA;64B
M"FUS9W-T<B`B4W!E;"(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z-#$@;&EB
M+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#0@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C0Q"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(P"FUS9VED(").97<@
M179E;G0B"FUS9W-T<B`B3GD@:&5N9&EN9R(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(DYE>'0B"FUS9W-T<B`B
M3F5S=&4@9&%G(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4W
M"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&QI8B]&0E9I
M97<O9&%Y+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3F5X="!$87DB"FUS9W-T
M<B`B3F5S=&4@9&%G(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B
M>5]S:61E+FEN8SHV"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?
M<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S
M:61E+FEN8SHQ."!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z-@IM<V=I9"`B
M3F5X="!-;VYT:"(*;7-G<W1R(").97-T92!MY6YA9"(*"B,Z(&QI8B]&0E9I
M97<O=V5E:RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(DYE>'0@5V5E:R(*;7-G
M<W1R(").97-T92!V96ME(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z
M-@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!996%R(@IM<V=S='(@(DYE<W1E(&1A
M9R(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X="!D
M87DB"FUS9W-T<B`B3F5S=&4@9&%G(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:6YC.C4X('1E;7!L871E<R]W965K+VAE860N:6YC.C4*;7-G:60@
M(DYE>'0@=V5E:R(*;7-G<W1R(").97-T92!V96ME(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(W-0HC+"!F=7IZ>0IM<V=I9"`B3F\B"FUS9W-T<B`B
M26YG96XB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHW,R!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHQ,C8*(RP@9G5Z>GD*;7-G:60@(DYO(&%L87)M
M(@IM<V=S='(@(D%L87)M(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E
M;F1E97,N:6YC.C0X"B,L(&9U>GIY"FUS9VED(").;R!A='1E;F1E97,B"FUS
M9W-T<B`B26YG96X@<VQU='1D871O(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3,Q,0IM<V=I9"`B3F\@8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E
M<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C4U"FUS9VED(").;R!E;F0@
M9&%T92(*;7-G<W1R("));F=E;B!S;'5T=&1A=&\B"@HC.B!L:6(O0FQO8VLO
M<')E=FUO;G1H;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C$V,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT"FUS9VED(").;R!E
M=F5N=',@=&\@9&ES<&QA>2(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92]K
M;VQA8BYP:'`Z-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,S0T(&QI8B]A<&DN<&AP.C8P,@IM<V=I9"`B3F\@
M:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,#0*(RP@9G5Z>GD*;7-G:60@(DYO(')E
M8W5R<F5N8V4B"FUS9W-T<B`B4F5G96QF87-T(&1A=&$B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HX.#8*;7-G:60@(DYO('9A;&ED(&5M86EL(&%D9')E<W,@
M9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C`Q(&QI
M8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N92(*;7-G<W1R("));F=E
M;B(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z,3,V"FUS9VED(").;W0@9F]U
M;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"B,L
M(&9U>GIY"FUS9VED(").;W1I9FEC871I;VYS(@IM<V=S='(@(E!L87-S97)I
M;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.`IM<V=I
M9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB97(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-PIM<V=I9"`B3V-T
M;V)E<B(*;7-G<W1R(")/:W1O8F5R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-S@*;7-G:60@(D]N(&%L;"!C86QE;F1A<G,@22!H879E
M(')E860@86-C97-S('1O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-S<*;7-G:60@(D]N(&%L;"!S:&]W;B!C86QE;F1A<G,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-@IM<V=I9"`B
M3VX@;7D@8V%L96YD87)S(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-C$Y"B,L(&9U>GIY"FUS9VED(")/<'1I;VYA;"(*;7-G<W1R
M(")!;'1E<FYA=&EV(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,3$X"FUS9VED(")/
M<'1I;VYA;"!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@;&EB+T9"5FEE=RYP
M:'`Z,34R"FUS9VED(")/=F5R=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHS-`IM<V=I9"`B3W=N97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z,3@T-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3W=N97(Z("5S(@IM<V=S='(@(D9O<F9E;&PZ("5S(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#(@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ.#(*;7-G:60@(E!-(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C(Y('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30*(RP@9G5Z>GD*;7-G
M:60@(E!A;&T@1&%T94)O;VLB"FUS9W-T<B`B06QA<FUD871O(@H*(SH@;&EB
M+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C,*;7-G:60@(E!A<W0@179E;G1S
M($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3`Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y.`IM<V=I9"`B4&%T=&5R
M;B(*;7-G<W1R(")-^&YS=&5R(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N
M:6YC.C(W"FUS9VED(")097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\B
M"FUS9W-T<B`B4VQE='0@9&5N;F4@:&5N9&EN9V$@<&5R;6%N96YT/R(*"B,Z
M(&QI8B]A<&DN<&AP.C,R-2!L:6(O87!I+G!H<#HT,3D@;&EB+V%P:2YP:'`Z
M-#@Q(&QI8B]A<&DN<&AP.C4U,PHC.B!L:6(O87!I+G!H<#HU.#0@;&EB+V%P
M:2YP:'`Z-C<P(&QI8B]A<&DN<&AP.C<P-@IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$V-PHC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4&5R<V]N;&5G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q
M"B,L(&9U>GIY"FUS9VED(")0;W)T86P@3W!T:6]N<R(*;7-G<W1R(")"<G5K
M87)A;'1E<FYA=&EV(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(U"B,L(&9U
M>GIY"FUS9VED(")0<F5V:6]U<R!$87DB"FUS9W-T<B`B1OAR<F4@9&%G(@H*
M(SH@;&EB+T9"5FEE=R]W965K+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B4')E
M=FEO=7,@5V5E:R(*;7-G<W1R(")&^')R92!D86<B"@HC.B!T96UP;&%T97,O
M9&%Y+VAE860N:6YC.C,*;7-G:60@(E!R979I;W5S(&1A>2(*;7-G<W1R(")&
M^')R92!D86<B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S4@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C4R"FUS9VED(")296-U<B!5;G1I;"(*
M;7-G<W1R(")3:VIE<B!T:6PB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,#8*(RP@9G5Z>GD*;7-G:60@(E)E8W5R<F5N8V4B"FUS9W-T<B`B4F5G
M96QF87-T(&1A=&$B"@HC.B!D871A+G!H<#HV.0IM<V=I9"`B4F5C=7)R96YC
M92!$871A(@IM<V=S='(@(E)E9V5L9F%S="!D871A(@H*(SH@9&%T82YP:'`Z
M-C<*;7-G:60@(E)E8W5R<F5N8V4@16YD($1A=&4B"FUS9W-T<B`B4F5G96QF
M87-T('-L=71T9&%T;R(*"B,Z(&1A=&$N<&AP.C8X"FUS9VED(")296-U<G)E
M;F-E($EN=&5R=F%L(@IM<V=S='(@(E)E9V5L9F%S="!I;G1E<G9A;&PB"@HC
M.B!D871A+G!H<#HV-@IM<V=I9"`B4F5C=7)R96YC92!4>7!E(@IM<V=S='(@
M(E)E9V5L9F%S="!T>7!E(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30P"FUS
M9VED(")296-U<G,@9&%I;'DB"FUS9W-T<B`B4VMJ97(@9&%G;&5G(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-30W"FUS9VED(")296-U<G,@;6]N=&AL>2(*
M;7-G<W1R(")3:VIE<B!MY6YA9&QE9R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C4T,PIM<V=I9"`B4F5C=7)S('=E96ML>2(*;7-G<W1R(")3:VIE<B!K=F%R
M('9E:V4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3`*;7-G:60@(E)E8W5R
M<R!Y96%R;'DB"FUS9W-T<B`B4VMJ97(@Y7)L96<B"@HC.B!L:6(O4V-H961U
M;&5R+VMR;VYO;&ET:"YP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M;6EN9&5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z.3$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T"B,L
M(&9U>GIY"FUS9VED(")296UO=&4@0V%L96YD87)S(@IM<V=S='(@(DEM<&]R
M=&5R(&MA;&5N9&5R(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C8P('1E;7!L
M871E<R]M96YU+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E($-A;&5N
M9&%R<SHB"FUS9W-T<B`B26UP;W)T97(@:V%L96YD97(B"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(B(*"B,Z(&%T=&5N9&5E<RYP:'`Z
M,3`T"FUS9VED(")296UO=F4@071T96YD964B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,@IM<V=I9"`B(@HB4F5P;&%C92!E
M>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O<G1E9"!O;F4_(#QS=')O
M;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO
M=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-C(V"FUS9VED(")297%U:7)E9"(*;7-G<W1R
M("(B"@HC.B!L:6(O1D)6:65W+G!H<#HY."!L:6(O1D)6:65W+G!H<#HQ,S<@
M;&EB+T9"5FEE=RYP:'`Z,30P(&QI8B]&0E9I97<N<&AP.C$T,PIM<V=I9"`B
M4F5Q=6ER960@071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C,T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,Q,`IM
M<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B3G5L;'-T:6QL('1I
M;"!S=&%N9&%R9'9E<F1I87(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-#,@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38V"FUS
M9VED(")297-P;VYS92(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX."!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-"!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,C,*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@
M(E-A(@IM<V=S='(@(DQA(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC
M.C(Q('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,`HC.B!T96UP;&%T97,O
M961I="]J879A<V-R:7!T+FEN8SHW,PIM<V=I9"`B4V%T=7)D87DB"FUS9W-T
M<B`B3&%U<F1A9R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`B3&$B"@HC
M.B!V:65W979E;G0N<&AP.C$Q."!E9&ET979E;G0N<&AP.C0X(&5D:71E=F5N
M="YP:'`Z-38*;7-G:60@(E-A=F4@07,@3F5W(@IM<V=S='(@(DQA9W)E('-O
M;2!N>2(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHX
M-PIM<V=I9"`B4V%V92!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@861D979E
M;G0N<&AP.C4U(&5D:71E=F5N="YP:'`Z-3$*;7-G:60@(E-A=F4@179E;G0B
M"FUS9W-T<B`B3&%G<F4@:&5N9&EN9R(*"B,Z('-E87)C:"YP:'`Z.3$@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q-0HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-C<@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]S96%R8V@N:6YC.C@*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ-#`@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C8*(RP@9G5Z>GD*
M;7-G:60@(E-E87)C:"(*;7-G<W1R(")-87)S(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]S96%R8V@N:6YC.C$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!#
M86QE;F1A<G,B"FUS9W-T<B`B26UP;W)T97(@:V%L96YD97(B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-@IM<V=I9"`B4V5A<F-H(%)E<W5L
M=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N
M:6YC.C8*;7-G:60@(E-E87)C:"!F;W(@8V%L96YD87)S(&-O;G1A:6YI;F<Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHQ-3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&-A;&5N9&%R('1O
M(&5D:70B"FUS9W-T<B`B5F5L(&9I;"!S;VT@<VMA;"!I;7!O<G1E<F%S=#HB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-C@@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z,S$*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z.#,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`B4W1A<G1D871O(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC
M.C,P"B,L(&9U>GIY"FUS9VED(")396QE8W0@8V%L96YD87)S('1O(&1I<W!L
M87DZ(@IM<V=S='(@(E9E;"!K;W)L96ES(&1A=&]A<B!S:V%L('9I<V%S=#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*;7-G:60@(B(*(E-E;&5C
M="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L87D@=&AE(&1I
M9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E("(*(F1E9F%U;'0@=FEE=RXB"FUS
M9W-T<B`B(@HB5F5L(&%L=&5R;F%T:78@9F]R('-T861F97-T:6YG+"!K;W)L
M96ES(&1E:2!U;&EK92!V:7-I;F=A;F4@<VMA;"`B"B)P<F5S96YT97)A<W0@
M;V<@=F5L(&5I('-T86YD87)D=FES:6YG+B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3D*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@8V%L
M96YD87(@=&\@:6UP;W)T('1O.B(*;7-G<W1R(")696P@9FEL('-O;2!S:V%L
M(&EM<&]R=&5R87-T.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB
M"FUS9W-T<B`B5F5L(&MJ96QD92#E(&EM<&]R=&5R92!F<N4Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR.`IM<V=I9"`B4V5L96-T('1H92!F
M:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B5F5L(&9I;"!S;VT@<VMA;"!I;7!O
M<G1E<F%S=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED
M(")396QE8W0@=&AE(&9I<G-T('=E96MD87DZ(@IM<V=S='(@(E9E;"!F^')S
M=&4@=F5K961A9SHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U
M<F-E(&9I;&4Z(@IM<V=S='(@(E9E;"!F;W)M870@Y2!E:W-P;W)T97)E('1I
M;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@T"FUS9VED(")396QE
M8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W.B(*;7-G<W1R(")696P@=&ED<VEN
M=&5R=F%L;"#E('9I<V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O
M;B!S=&%R='5P.B(*;7-G<W1R(")696P@=FES:6YG82!S;VT@<VMA;"!B<G5K
M87-T(&5T=&5R(&EN;FQO9V=I;F<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=VAI8V@@979E;G1S('1O
M('-H;W<@:6X@=&AE('!O<G1A;"XB"FUS9W-T<B`B5F5L(&MV82!H96YD:6YG
M87(@<V]M('-K86P@=FES87-T(&D@<V%M86YD<F%G(&9O<B!(;W)D92XB"@HC
M.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C0@=&5M<&QA=&5S+V1E;&5T
M92]D96QE=&4N:6YC.C(T"FUS9VED(")396YD(&$@8V%N8V5L(&YO=&EF:6-A
M=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L971I;F<@=&AI<R!E=F5N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5N9"!A;B!E;6%I;"!T;R`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#$*;7-G:60@
M(E-E;F0@=7!D871E<R]I;G9I=&%T:6]N<R!T;R!A;&P@871T96YD965S('=H
M96X@<V%V:6YG('1H:7,@979E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S8*;7-G:60@(E-E<'1E;6)E<B(*;7-G
M<W1R(")397!T96UB97(B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHX,PHC+"!F=7IZ>0IM<V=I9"`B4V5T(&5N9"!D871E(@IM<V=S
M='(@(DEN9V5N('-L=71T9&%T;R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(V.`HC+"!F=7IZ>0IM<V=I9"`B4V5T(')E8W5R<F5N8V4@96YD(&1A
M=&4B"FUS9W-T<B`B4F5G96QF87-T('-L=71T9&%T;R(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")3
M970@<W1A<G0@9&%T92(*;7-G<W1R(")3=&%R=&1A=&\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3D*;7-G:60@(B(*(E-E="!Y;W5R(&9R964O8G5S
M>2!C86QE;F1A<G,@86YD('EO=7(@;W=N(&%N9"!O=&AE<B!U<V5R<R<@9G)E
M92]B=7-Y(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAA<F4@;F]T(&9O=6YD.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z-SD*(RP@9G5Z>GD*;7-G:60@(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T
M<B`B26UP;W)T97(@:V%L96YD97(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z
M-#<@=&5M<&QA=&5S+VUE;G4N:6YC.C0Y"B,L(&9U>GIY"FUS9VED(")3:&%R
M960@0V%L96YD87)S.B(*;7-G<W1R(")%:W-P;W)T97(@:V%L96YD97(B"@HC
M.B!C86QE;F1A<E]S96%R8V@N<&AP.C(U('1E;7!L871E<R]W965K+VAE861?
M<VED95]B>5]S:61E+FEN8SHS"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@0V%L96YD87(B
M"FUS9W-T<B`B16MS<&]R=&5R(&MA;&5N9&5R(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]S96%R8V@N:6YC.C(R"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@8V%L96YD87(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-38*;7-G:60@(E-H;W<@8V%T96=O<GD@;&5G96YD/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED
M(")3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN
M(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$R"FUS9VED(")3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L
M96YD87(_(@IM<V=S='(@(E9I<R!O<'!GY79E<B!T:6P@9F]R9F%L;"!I(&MA
M;&5N9&5R96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V-@IM<V=I
M9"`B4VAO=R!F<F5E+V)U<WD@;&5G96YD/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C`S"FUS9VED(")3:&]W(&]N;'D@979E;G1S
M('1H870@:&%V92!A;B!A;&%R;2!S970_(@IM<V=S='(@(E9I<R!B97)R92!H
M96YD:6YG87(@<V]M(&AA<B!E:6X@86QA<FT@86MT:79E<G0_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$W-0IM<V=I9"`B4VAO=R!S:&%R960@8V%L
M96YD87)S('-I9&4M8GDM<VED93\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(R,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T87-K<R!U
M<VEN9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(E9I<R!O<'!GY79E<B!T
M:6P@9F]R9F%L;"!I(&MA;&5N9&5R96X_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDU"B,L(&9U>GIY"FUS9VED(")3:&]W('1I;64@;V8@9&%Y(&)E
M='=E96X@96%C:"!D87D@:6X@=V5E:R!V:65W<S\B"FUS9W-T<B`B5FES(&AA
M;'9T:6UE<V5G;65N="!I(&1A9RT@;V<@=F5K979I<VEN9S\B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4W1A7W)T(@IM<V=S='(@(E-T87)T(@H*(SH@9&%T82YP:'`Z-34*;7-G
M:60@(E-T87)T($1A=&4B"FUS9W-T<B`B4W1A<G1D871O(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHW('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C4*
M;7-G:60@(E-T87)T($]N(@IM<V=S='(@(E-T87)T(@H*(SH@9&%T82YP:'`Z
M-38*;7-G:60@(E-T87)T(%1I;64B"FUS9W-T<B`B4W1A<G1T:61S<'5N:W0B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z.34@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z.#4*;7-G:60@(E-T871?=7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN
M8SHV('1E;7!L871E<R]V:65W+W9I97<N:6YC.C(W"FUS9VED(")3=&%T=7,B
M"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#$@>65A<BYP:'`Z.3`@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C4*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C(T(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`W(&QI8B]";&]C
M:R]M;VYT:"YP:'`Z,3`Y"FUS9VED(")3=2(*;7-G<W1R(")3^"(*"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-"!T96UP;&%T97,O;6]N=&@O:&5A
M9"YI;F,Z,C,*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(Q('1E;7!L
M871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8W"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#4*;7-G:60@(E-U;F1A>2(*;7-G<W1R(")3^&YD86<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*;7-G:60@(E1A<VMS(@IM<V=S
M='(@(D]P<&?E=F5R(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<T(&QI8B]+
M<F]N;VQI=&@N<&AP.C4Y-PIM<V=I9"`B5&5N=&%T:79E(@IM<V=S='(@(B(*
M"B,Z('EE87(N<&AP.C@V('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,0HC.B!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS9W-T<B`B5&\B"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C<P"FUS9VED(")4:&4@161I
M="!!='1E;F1E97,@<V-R965N(&ES(&YO(&QO;F=E<B!P<F5S96YT+B!%>&ET
M:6YG+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@8V%N;F]T(&)E(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!C
M<F5A=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C@X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HU-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N
M(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N
M<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S
M7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(R
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@8V]U;&0@;F]T
M(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O
M:F%V87-C<FEP="YI;F,Z,38S"FUS9VED(")4:&4@96YD(&1A=&4@;75S="!B
M92!L871E<B!T:&%N('1H92!S=&%R="!D871E+B(*;7-G<W1R(")3;'5T=&1A
M=&\@;>4@=F5R92!S96EN87)E(&5N;B!S=&%R=&1A=&\N(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E
M;G0@7"(E<UPB(&AA<R!B965N(&%D9&5D+"!W:&EC:"!I<R!O;B`E<R!A="`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960L('=H:6-H('=A<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"P@=VAI8V@@:7,@;VX@
M)7,@870@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(&YO=&EF:6-A=&EO
M;B!T;R`E<R!W87,@<W5C8V5S<V9U;&QY('-E;G0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$P,C0*;7-G:60@(E1H92!F;VQL;W=I;F<@
M:7,@82!M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#HB
M"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E
M<75E<W0@=V%S(&EN8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R
M92!N96-E<W-A<GD@=&\@86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@
M87)E(&UI<W-I;F<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M96UP='DN:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!E=F5N
M=',@;6%T8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(D1E
M="!V87(@:6YG96X@:&5N9&EN9V%R(.4@96MS<&]R=&5R92XB"@HC.B!A9&1E
M=F5N=&%C=&EO;BYP:'`Z,3@@961I=&5V96YT86-T:6]N+G!H<#HS-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%C
M8V5S<VEN9R!T:&4@8V%L96YD87(Z("5S(@IM<V=S='(@(D1E="!S:VIE9&1E
M(&5I;B!F96EL('9E9"!I;7!O<G0@878@9&%T82XB"@HC.B!A9&1E=F5N=&%C
M=&EO;BYP:'`Z,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")$
M970@<VMJ961D92!E:6X@9F5I;"!V960@:6UP;W)T(&%V(&1A=&$N(@H*(SH@
M961I=&5V96YT86-T:6]N+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&5D:71I;F<@=&AE(&5V96YT.B`E
M<R(*;7-G<W1R(")$970@<VMJ961D92!E:6X@9F5I;"!V960@:6UP;W)T(&%V
M(&1A=&$N(@H*(SH@;&EB+V%P:2YP:'`Z,S,X(&QI8B]A<&DN<&AP.C4Y-@HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D1E="!S:VIE9&1E(&5I;B!F
M96EL('9E9"!I;7!O<G0@878@9&%T82XB"@HC.B!E9&ET979E;G1A8W1I;VXN
M<&AP.C8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B1&5T('-K
M:F5D9&4@96EN(&9E:6P@=F5D(&EM<&]R="!A=B!D871A+B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R('-E;F1I;F<@86X@979E;G0@;F]T:69I8V%T:6]N('1O
M("5S.B`E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ,#4*;7-G:60@(E1H
M97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R="XB"FUS9W-T<B`B1&5T('9A
M<B!I;F=E;B!H96YD:6YG87(@Y2!E:W-P;W)T97)E+B(*"B,Z(&1A=&$N<&AP
M.C$X-`IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D
M+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$Y('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$Q.`HC.B!T96UP;&%T97,O961I="]J879A<V-R
M:7!T+FEN8SHW,0IM<V=I9"`B5&AU<G-D87DB"FUS9W-T<B`B5&]R<V1A9R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHS-PHC+"!F=7IZ>0IM
M<V=I9"`B5&EM92!3<%]A;B(*;7-G<W1R(")4:61S<V]N92(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C0*(RP@9G5Z>GD*;7-G:60@
M(E1I;64@<W!A;B(*;7-G<W1R(")4:61S<V]N92(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHS-B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B5&ET7VQE(@IM<V=S='(@(E1I
M='1E;"(*"B,Z(&1A=&$N<&AP.C4T('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC
M.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I='1E;"(*"B,Z(&QI8B]";&]C
M:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C(@;&EB+T)L;V-K+VUO;G1H;&ES="YP
M:'`Z,3(Q"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,C<*;7-G:60@(E1O
M9&%Y(@IM<V=S='(@(DD@9&%G(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI
M<W0N<&AP.C$R-"!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ,C,*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C$R.0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T
M<B`B(@H*(SH@>65A<BYP:'`Z.#0@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-C`@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$Y"B,Z(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")4=2(*;7-G<W1R(")4>2(*"B,Z
M('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-R!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,38*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z
M-CD*;7-G:60@(E1U97-D87DB"FUS9W-T<B`B5'ES9&%G(@H*(SH@8V]N9FEG
M+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")4>7!E(@IM<V=S='(@(E1Y
M<&4B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3@S
M"FUS9VED(")54DPB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H
M<#HV-`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HX-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T1R:79E<B]M8V%L+G!H<#HQ,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3@U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!C
M86QE;F1A<G,N<&AP.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G
M92]K;VQA8BYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E=')I979E(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,34*(SH@<V-R:7!T
M<R]U<&=R861E<R\R,#`T+3`U+3$Y7V-O;G9E<G1?8V%T96=O<FEE<U]T;U]S
M=')I;F=S+G!H<#HU,PIM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HS-S8@;&EB+V%P:2YP:'`Z-#4P(&QI8B]A<&DN<&AP.C4Q
M-B!L:6(O87!I+G!H<#HV,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P
M;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,#$T"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960Z
M("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*
M;7-G:60@(E5S97(@26YT97)F86-E(@IM<V=S='(@(D)R=6MA<F=R96YS97-N
M:71T(@H*(SH@>65A<BYP:'`Z,38S('EE87(N<&AP.C$V.2!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$U.2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$V,@HC+"!F=7IZ
M>0IM<V=I9"`B5FEE=R!$87DB"FUS9W-T<B`B5FES("5S(@H*(SH@>65A<BYP
M:'`Z.#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C$@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C(P"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,3`U"FUS9VED(")792(*;7-G<W1R(")/;B(*"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D+FEN8SHQ."!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3<*(SH@
M=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S`*;7-G:60@(E=E9&YE
M<V1A>2(*;7-G<W1R(")/;G-D86<B"@HC.B!A='1E;F1E97,N<&AP.C$Q,B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,CDP(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP
M.C(S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*
M;7-G<W1R(")696ME(@H*(SH@;6]N=&@N<&AP.C$W.2!W;W)K=V5E:RYP:'`Z
M,S`@=V5E:RYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5E:R`E9"(*
M;7-G<W1R(")696ME("5D(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED(")7965K*',I
M(@IM<V=S='(@(E9E:V4H<BDB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"FUS9VED(")7965K
M;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")+=F%R('9E:V4Z(%-K:F5R(&MV
M87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED("(B"B)7
M:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@
M=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\B"FUS9W-T<B`B(@HB4.4@:W9A
M('1I9'-P=6YK="!S:V%L(&1A9RT@;V<@=F5K979I<VEN9V%R('-L=71T92P@
M;N5R(&1E="!E<B!I;F=E;B!S96EN87)E("(*(FAE;F1I;F=A<C\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED("(B"B)7:&%T('1I;64@
M<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A
M<F4@;F\@96%R;&EE<B!E=F5N=',_(@IM<V=S='(@(B(*(E#E(&MV82!T:61S
M<'5N:W0@<VMA;"!D86<M(&]G('9E:V5V:7-I;F=A<B!S=&%R=&4L(&[E<B!D
M970@97(@:6YG96X@(@HB=&ED;&5G87)E(&AE;F1I;F=A<C\B"@HC.B!A='1E
M;F1E97,N<&AP.C$Q,2!L:6(O2W)O;F]L:71H+G!H<#HQ,C@Y(&QI8B]";&]C
M:R]T<F5E7VUE;G4N<&AP.C(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-`IM<V=I9"`B5V]R:R!7965K(@IM<V=S='(@(D%R8F5I9'-V96ME(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,B!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR-0IM<V=I9"`B665A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C0Q"FUS
M9VED(")996%R;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")+=F%R="#E<CH@
M4VMJ97(@:W9A<G0B"@HC.B!D871A+G!H<#HT,"!D871A+G!H<#HR,S0@961I
M=&5V96YT86-T:6]N+G!H<#HT-B!A9&1E=F5N="YP:'`Z,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&5V96YT<RXB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HT
M.0IM<V=I9"`B66]U(&%R92!N;W0@86X@871T96YD964@;V8@=&AE('-P96-I
M9FEE9"!E=F5N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHW-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T:&ES
M(&9O<FT@9G)O;2!T:&4@161I="!!='1E;F1E97,@<V-R965N+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HY-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U(&1O(&YO="!H879E(&%N(&5M86EL(&%D9')E<W,@8V]N
M9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T:6]N("(*(D]P=&EO
M;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F;W)E(&5V96YT(&YO
M=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N(@IM<V=S='(@(B(*"B,Z(&%D9&5V
M96YT86-T:6]N+G!H<#HR,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O("5S+B(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HQ.30*;7-G:60@(EEO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@=&AE('-E;&5C=&5D(&-A
M;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!D96QE=F5N=&%C=&EO;BYP:'`Z,C8*
M;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T92!T
M:&ES(&5V96YT+B(*;7-G<W1R("(B"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP
M.C<X"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E9&ET
M('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X.0IM<V=I
M9"`B66]U(&AA=F4@<W!E8VEF:65D(&%N(&EN=F%L:60@8V%L96YD87(N(@IM
M<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E('-U
M8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N
M(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,C8*;7-G:60@(EEO=2!H879E
M('-U8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E
M;G0N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,S$*;7-G:60@(EEO=2!H
M879E('1E;G1A=&EV96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E
M=F5N="XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HY,0IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHU
M-`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.30*;7-G:60@(EEO
M=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&%D
M9&5D('1O('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,3`T"FUS9VED("(B"B)9;W4@<F5Q=65S=&5D('1O(&)E
M(&YO=&EF:65D('=H96X@979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U<B!C
M86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P
M.3D*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E
M=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(')E;6EN9&5D(&%B
M;W5T("5S+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-H87)E<V5L96-T+FEN8SHQ,`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!D969A=6QT(&-A;&5N9&%R(@IM<V=S='(@(D5K<W!O<G1E
M<B!K86QE;F1E<B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-3,@;&EB+T1R:79E
M<BYP:'`Z,3`V,PIM<V=I9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.CDW"B,L(&9U>GIY"FUS9VED
M(")?06QA<FTB"FUS9W-T<B`B06QA<FTB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$*;7-G:60@(E]"87-I8R!396%R8V@B
M"FUS9W-T<B`B(@H*(SH@=FEE=V5V96YT+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G
M:60@(E]%9&ET(@IM<V=S='(@(D5N9')E(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3,S,`HC+"!F=7IZ>0IM<V=I9"`B7T=O=&\B"FUS9W-T<B`B1^4@=&EL
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S-@HC+"!F=7IZ>0IM<V=I9"`B
M7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B26UP;W)T+V5K<W!O<G0B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,S$X"B,L(&9U>GIY"FUS9VED(")?37D@0V%L
M96YD87)S(@IM<V=S='(@(D5K<W!O<G1E<B!K86QE;F1E<B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$S,C4*(RP@9G5Z>GD*;7-G:60@(E].97<@179E;G0B
M"FUS9W-T<B`B3GD@:&5N9&EN9R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M-#$*;7-G:60@(E]0<FEN="(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,S,R"B,L(&9U>GIY"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(DUA
M<G,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S(X"B,L(&9U>GIY"FUS9VED
M(")?5&]D87DB"FUS9W-T<B`B22!D86<B"@HC.B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHQ-#(*;7-G:60@(F)E9F]R92!T:&4@979E;G0@<W1A<G1S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@
M(F1A>2(*;7-G<W1R(")D86<B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$P"FUS9VED(")D87DH
M<RDB"FUS9W-T<B`B9&%G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(F1A
M9V%R(@H*(SH@9&%T82YP:'`Z,30W('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,0HC+"!F=7IZ>0IM<V=I9"`B979E;G1S+F-S=B(*;7-G<W1R(")!;&QE
M(&AE;F1I;F=A<B(*"B,Z(&1A=&$N<&AP.C$V.`HC+"!F=7IZ>0IM<V=I9"`B
M979E;G1S+FEC<R(*;7-G<W1R(")!;&QE(&AE;F1I;F=A<B(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3,Q"FUS9VED(")F<F]M(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,C8*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C,P('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S-@IM<V=I9"`B
M;6]N=&@H<RDB"FUS9W-T<B`B;>5N860@(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3`R,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B;VX@)7,@870@
M)7,B"FUS9W-T<B`B)7,@<W1A<G1A<B!O;2`E<R(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S`*
M;7-G:60@(F]N('1H92!S86UE(&1A=&4B"FUS9W-T<B`B<.4@<V%M92!D871O
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(S-@IM<V=I9"`B;VX@=&AE('-A;64@=V5E:V1A>2(*
M;7-G<W1R(")PY2!S86UE('9E:V5D86<B"@HC.B!D871A+G!H<#HS,"!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U"FUS9VED(")V0V%L96YD87(O:4-A
M;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,T.2!L:6(O87!I
M+G!H<#HV,#<*;7-G:60@(G9%=F5N="!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3$*;7-G:60@(G=E96LB"FUS
M9W-T<B`B=F5K92(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,3<*;7-G:60@(G=E96LH<RD@;VXZ
M(@IM<V=S='(@(G9E:V4@<.4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.30*;7-G:60@(G=E96MS(@IM<V=S='(@(G9E:V5R(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(T,@IM<V=I9"`B>65A<BAS*2(*;7-G<W1R("+E<B(*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]P;R]P;%]0
M3"YP;P``````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,C`V
M-#<`,3`T,3<S-C(W-3,`,#(P-#,P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@2U)/3D],251((%!O;&ES:"!T<F%N<VQA
M=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,B!-86-I96L@56AL:6<@/&UU:&QI
M9T!U<RYE9'4N<&P^"B,@1DE24U0@05542$]2("!-86-I96L@56AL:6<@/&UU
M:&QI9T!U<RYE9'4N<&P^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B`P+C`N-%QN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#(M,#$M,C(@,C(Z,#`K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!-86-I96L@56AL:6<@/&UU:&QI9T!U<RYE9'4N<&P^7&XB"B),86YG=6%G
M92U496%M.B!-52`\;75H;&EG0'5S+F5D=2YP;#Y<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&-A;&5N9&%R<R!F;W5N9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@979E;G1S(@IM<V=S='(@(E=S>GES
M=&MI92!Z9&%R>F5N:6$B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1&%Y*',I("5S
M($AO=7(H<RD@)7,@36EN=71E<R(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ-S@W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T=&5N9&5E<R(*
M;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B:6UP
M;W)T('!L:6MU("5S('=Y:V]N86YY('!O<')A=VYI92(*"B,Z(&-A;&5N9&%R
M<RYP:'`Z,3`U(&QI8B]B87-E+G!H<#HQ,C@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B16MS<&]R='5J(&MA
M;&5N9&%R>B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ
M-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N9&%R(&YA;64@=&\@<W=I=&-H
M('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE(&UA:6X@(@HB=VEN
M9&]W*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$V-`IM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@061D
M("HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ-3`*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.#8*;7-G:60@(C$@
M871T96YD964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D
M97(N:6YC.C0*(RP@9G5Z>GD*;7-G:60@(C$@979E;G0B"FUS9W-T<B`B5W-Z
M>7-T:VEE('ID87)Z96YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S<*(RP@9G5Z>GD*;7-G:60@(C$@:&]U<B(*;7-G<W1R("(E9"!G;V1Z:6YA
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`HC+"!F=7IZ>0IM<V=I
M9"`B,34@;6EN=71E<R(*;7-G<W1R("(E9"!M:6YU='DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,U"B,L(&9U>GIY"FUS9VED("(R,"!M:6YU=&5S
M(@IM<V=S='(@(B5D(&UI;G5T>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S8*(RP@9G5Z>GD*;7-G:60@(C,P(&UI;G5T97,B"FUS9W-T<B`B)60@
M;6EN=71Y(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3<Q"B,L(&9U
M>GIY"FUS9VED("(\<W1R;VYG/D%T=&5N9&5E<SPO<W1R;VYG/B`H;W!T:6]N
M86PI(@IM<V=S='(@(CQB/E.S;W=A(&ML=6-Z;W=E/"]B/B`H;W!C:F]N86QN
M:64I(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30Y"B,L(&9U>GIY
M"FUS9VED("(\<W1R;VYG/D1E<V-R:5]P=&EO;CPO<W1R;VYG/B`H;W!T:6]N
M86PI(@IM<V=S='(@(CQB/D]P:7,\+V(^("AO<&-J;VYA;&YI92DB"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR-S<*(RP@9G5Z>GD*;7-G:60@(CQS
M=')O;F<^2V5Y=V]R9',\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G<W1R("(\
M8CY3LV]W82!K;'5C>F]W93PO8CX@*&]P8VIO;F%L;FEE*2(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N
M9SY296-U<G)E;F-E/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^
M4F5K=7)E;F-J83PO8CX@*&]P8VIO;F%L;FEE*2(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,3`Q('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3@Q"FUS9VED(")!32(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU.3$*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I9"`B061?=F%N8V5D(%-E87)C
M:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$V,2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM
M<V=I9"`B061D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(V"FUS9VED(")!9&0@179E;G0B"FUS9W-T<B`B1&]D86H@>F1A<GIE
M;FEE(@H*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N
M="YI;F,Z,S4*(RP@9G5Z>GD*;7-G:60@(D%D9"!A(&YE=R!296UO=&4@0V%L
M96YD87(B"FUS9W-T<B`B1&]D86H@;F]W92!Z9&%R>F5N:64B"@HC.B!A9&1E
M=F5N="YP:'`Z-C0*;7-G:60@(D%D9"!A(&YE=R!E=F5N="(*;7-G<W1R(")$
M;V1A:B!N;W=E('ID87)Z96YI92(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHW-`IM<V=I9"`B061D(&%T=&5N9&5E<R(*;7-G<W1R
M("(B"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC.C<X"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R
M8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3,*
M;7-G:60@(D%L87)M(@IM<V=S='(@(D%L87)M(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z,3<V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!D87ES(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D%L87)M("5D(&AO=7)S(&)E9F]R92(*;7-G<W1R
M("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!;&%R;2`E9"!M:6YU=&5S(&)E9F]R92(*;7-G<W1R(")M
M:6YU="!P<GIE9"(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06QA<FT@)60@=V5E:W,@8F5F;W)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C,*;7-G:60@(D%L87)M(#$@9&%Y(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8X"FUS9VED
M(")!;&%R;2`Q(&AO=7(@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W-S,*(RP@9G5Z>GD*;7-G:60@(D%L87)M(#$@;6EN=71E(&)E
M9F]R92(*;7-G<W1R(")M:6YU="!P<GIE9"(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$W-3@*;7-G:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-C`*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T<B`B1&%T
M82!A;&%R;74B"@HC.B!D871A+G!H<#HU.0IM<V=I9"`B06QA<FT@4W!A;B`H
M;6EN=71E<RDB"FUS9W-T<B`B0WIA<R!T<G=A;FEA(&%L87)M=2`H;6EN=71Y
M*2(*"B,Z(&1A=&$N<&AP.C8Q"FUS9VED(")!;&%R;2!4:6UE(@IM<V=S='(@
M(D-Z87,@86QA<FUU(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC
M.C,Q"B,L(&9U>GIY"FUS9VED(")!;&PB"FUS9W-T<B`B0V&S>2!D>FEE\2(*
M"B,Z(&QI8B]&0E9I97<N<&AP.C$R-B!L:6(O1D)6:65W+G!H<#HQ,CD@;&EB
M+T9"5FEE=RYP:'`Z,3,R"B,L(&9U>GIY"FUS9VED(")!;&P@071T96YD965S
M(@IM<V=S='(@(E=S>GES=&MI92!Z9&%R>F5N:6$B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z-3D*;7-G:60@(D%L;"!&=71U<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4S"B,L(&9U
M>GIY"FUS9VED(")!;&P@4&%S="(*;7-G<W1R(")#8;-Y(&1Z:67Q(@H*(SH@
M;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C:R]M;VYT
M:"YP:'`Z,C0*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C(U"FUS9VED(")!;&P@5FES:6)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,C(@
M;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H<#HY,PHC.B!L:6(O
M5V5E:U9I97<N<&AP.C$R-R!L:6(O5V5E:U9I97<N<&AP.C$S-"!L:6(O1')I
M=F5R+G!H<#HQ.#,R"FUS9VED(")!;&P@9&%Y(@IM<V=S='(@(D-ALWD@9'II
M9?$B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,38T"FUS9VED(")!;&P@
M9&%Y(&5V96YT(@IM<V=S='(@(EID87)Z96YI92!C8;-O9'II96YN92(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D%L;"!E=F5N
M=',B"FUS9W-T<B`B5W-Z>7-T:VEE('ID87)Z96YI82(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHT.0HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-S$@;&EB+TMR;VYO;&ET:"YP
M:'`Z-C@S"FUS9VED(")!;GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-S$*;7-G:60@(D%P<FEL(@IM<V=S='(@(FMW
M:65C:67Q(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M,SD@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHW,"!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$U-@IM<V=I9"`B070B"FUS9W-T<B`B;R(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$P,C8*;7-G:60@(B(*(D%T=&%C:&5D(&ES(&%N(&E#86QE
M;F1A<B!F:6QE('=I=&@@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@979E
M;G0N($EF('EO=7(@(@HB;6%I;"!C;&EE;G0@<W5P<&]R=',@:51I<"!R97%U
M97-T<R!Y;W4@8V%N('5S92!T:&ES(&9I;&4@=&\@96%S:6QY('5P9&%T92`B
M"B)Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE(&5V96YT+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#(@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E;F1A;F-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V,0IM<V=I9"`B
M071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C<U"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B<VEE<G!I9?$B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C@*;7-G:60@(D)A<VEC(%-E
M87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z
M,3<*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(G5R;V1Z:6YY(@H*(SH@;&EB
M+T9"5FEE=RYP:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$P"FUS9VED(")"=7-Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S='(@
M(DEM<&]R='5J(&MA;&5N9&%R>B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C0Y"B,L(&9U>GIY"FUS9VED(")#86Q?96YD87(B"FUS9W-T<B`B26UP
M;W)T=6H@:V%L96YD87)Z(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$T-B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C$*
M(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HR,2!L:6(O0FQO8VLO;6]N=&AL:7-T
M+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(RP@9G5Z>GD*;7-G
M:60@(D-A;&5N9&%R(@IM<V=S='(@(DEM<&]R='5J(&MA;&5N9&%R>B(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"B,L(&9U>GIY"FUS9VED(")#86QE
M;F1A<B!3=6UM87)Y(@IM<V=S='(@(E!O9'-U;6]W86YI92(*"B,Z(&1A=&$N
M<&AP.C(R.`HC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87(@<W5C8V5S<V9U;&QY
M('!U<F=E9"XB"FUS9W-T<B`B:6UP;W)T('!L:6MU(&E#86QE;F1A<B!W>6MO
M;F%N;R!P;VUYMFQN:64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<*(RP@9G5Z>GD*;7-G
M:60@(D-A;&5N9&%R<R(*;7-G<W1R("));7!O<G1U:B!K86QE;F1A<GHB"@HC
M.B!C86QE;F1A<G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")#86QE;F1A<G,@
M;75S="!H879E(&$@;F%M92XB"FUS9W-T<B`B5&$@=V%R=&^VYB!M=7-I(&)Y
MYB!L:6-Z8K$N(@H*(SH@9&%T82YP:'`Z,C0S"B,L(&9U>GIY"FUS9VED(")#
M86XG="!C<F5A=&4@82!N97<@979E;G0N(@IM<V=S='(@(E5T=_-R>B!N;W=E
M('ID87)Z96YI92(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3DQ('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHS,`HC.B!T96UP;&%T
M97,O9&5L971E+V1E;&5T92YI;F,Z,S(@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,S,*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S`Y"FUS9VED(")#
M86YC96PB"FUS9W-T<B`B6F%N:65C:&%J(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-3<P"B,L(&9U>GIY"FUS9VED(")#86YC96QL960B"FUS9W-T<B`B6F%N
M:65C:&%J(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`P,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N8V5L;&5D.B`E<R(*;7-G<W1R("):86YI
M96-H86HB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI
M;F,Z-C0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z-CD*(RP@9G5Z>GD*;7-G
M:60@(D-A=&5G;W)?>2(*;7-G<W1R(")+871E9V]R:6$B"@HC.B!D871A+G!H
M<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C0@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*;7-G:60@(D-A=&5G;W)Y(@IM<V=S
M='(@(DMA=&5G;W)I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-SD*
M;7-G:60@(B(*(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O
M9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S(&)Y("(*(F5M86EL
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(*;7-G
M:60@(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L
M(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<V5A<F-H7V%B;V]K7W-E;&5C="YI;F,Z,3D@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Y.0IM<V=I9"`B0VAO;W-E('1H92!A9&1R
M97-S(&)O;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]F8E]C86QS7W-E;&5C="YI;F,Z
M,38*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@:6X@
M>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXZ(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3$*;7-G:60@(D-H;V]S92!T:&4@8V%L
M96YD87)S('1O(&EN8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!5
M4DQS.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*
M;7-G:60@(D-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHV-0IM
M<V=I9"`B0VQE87(@86QL(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HR."!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S"FUS9VED(")#
M;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW,PIM<V=I9"`B0V]N9FER;2!D96QE=&EO;B!O9B!E
M=F5N=',_(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4V-PIM
M<V=I9"`B0V]N9FER;65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHR,#@*;7-G:60@(D-O<'D@=&AE(%523"!B
M96QO=R!F;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y
M(%523#HB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,38R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3(V
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E
M($-A;&5N9&%R(@IM<V=S='(@(DEM<&]R='5J(&MA;&5N9&%R>B(*"B,Z(&UO
M;G1H+G!H<#HQ-C4@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,C4@=&5M<&QA
M=&5S+V1A>2]R;W<N:6YC.C8*(SH@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$
M87E6:65W+G!H<#HQ.30*;7-G:60@(D-R96%T92!A($YE=R!%=F5N="(*;7-G
M<W1R(")5='?S<GH@;F]W92!Z9&%R>F5N:64B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHX,`IM<V=I9"`B0W)E871E9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,CD*;7-G:60@(D-U<G)E;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(P.0IM<V=I9"`B1&%I;'DZ(%)E8W5R
M<R!E=F5R>2(*;7-G<W1R(")C;V1Z:65N;FEE.B!P;W=T87)Z82!S:>H@8V\B
M"@HC.B!A='1E;F1E97,N<&AP.C$Q,"!L:6(O2W)O;F]L:71H+G!H<#HQ,C@X
M(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(Q"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,@IM<V=I9"`B1&%Y(@IM<V=S='(@(D1Z:67Q(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,3,Y"FUS9VED(")$87DH<RDB"FUS9W-T<B`B9&YI(@H*(SH@=FEE=V5V
M96YT+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D1E7VQE=&4B"FUS9W-T<B`B
M=7-U\2`G)7,G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z
M-SD*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F=R=61Z:67Q(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z-3DT"FUS9VED(")$96-L:6YE9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<*(RP@9G5Z>GD*;7-G:60@
M(D1E9F%U;'0@0V%L96YD87(B"FUS9W-T<B`B26UP;W)T=6H@:V%L96YD87)Z
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,R!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X,0HC.B!T96UP;&%T
M97,O9&5L971E+V]N92YI;F,Z,CD@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C
M86Q?;6%N86=E;65N="YI;F,Z,C,*(SH@;&EB+T1R:79E<BYP:'`Z,3@Q,PHC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(@IM<V=S='(@(G5S=?$@)R5S)R(*"B,Z
M(&1E;&5V96YT+G!H<#HT,"!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,3@@
M=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C$X"B,Z(&QI8B]$<FEV97(N
M<&AP.C$X,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E
M<R(*;7-G<W1R(")U<W7Q("<E<R<B"@HC.B!E9&ET979E;G0N<&AP.C<P"FUS
M9VED(")$96QE=&4@179E;G0B"FUS9W-T<B`B=7-U\2!Z9&%R>F5N:64B"@HC
M.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C<*;7-G:60@(B(*(D1E
M;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R<F5N8V4@
M86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@(@HB86QL(&]C8W5R96YC
M97,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHQ,#0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X
M"B,L(&9U>GIY"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B;W!I<R(*
M"B,Z(&1A=&$N<&AP.C8R('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHQ-S4*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.38*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(F]P:7,B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$W,PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA
M>2(*;7-G<W1R(")/<&-J92!W>;9W:65T;&%N:6$B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D1I
M<W!L87D@0V%L96YD87)S(@IM<V=S='(@(D]P8VIE('=YMG=I971L86YI82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@*;7-G:60@(D1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R(")/<&-J92!W>;9W:65T;&%N:6$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1O('EO=2!W86YT('1O
M('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U92!O;B!Y;W5R(&-A;&5N9&%R/R(*
M;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU,S<*;7-G:60@(D1O
M97,@;F]T(')E8W5R(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C,R-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1'5E.B`E<R(*;7-G
M<W1R(")497)M:6XZ(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z,3$U"FUS9VED(")$=7)A=&EO;B(*;7-G<W1R(")#>F%S('1R=V%N
M:6$B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<P
M(&QI8B]$<FEV97(N<&AP.C$X,#8*(RP@9G5Z>GD*;7-G:60@(D5D:70B"FUS
M9W-T<B`B961Y='5J("(*"B,Z(&5D:71E=F5N="YP:'`Z,S,@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C8@;&EB+T1R:79E<BYP:'`Z,3@P-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@(F5D>71U:B`E<R(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$X-PIM<V=I9"`B161I="!!='1E
M;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$T,`HC+"!F=7IZ>0IM<V=I9"`B161I="!#86QE;F1A<G,B
M"FUS9W-T<B`B16MS<&]R='5J(&MA;&5N9&%R>B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-3`*(RP@9G5Z>GD*;7-G:60@(D5D:70@4F5M;W1E($-A
M;&5N9&%R<R(*;7-G<W1R("));7!O<G1U:B!K86QE;F1A<GHB"@HC.B!A='1E
M;F1E97,N<&AP.C$U,`IM<V=I9"`B161I="!A='1E;F1E97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N9"YI;F,Z,C`*;7-G:60@
M(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E<R]A
M='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-C`*(RP@9G5Z
M>GD*;7-G:60@(D5N7V0B"FUS9W-T<B`B:V_Q8WJQ8R!W(@H*(SH@9&%T82YP
M:'`Z-3<*;7-G:60@(D5N9"!$871E(@IM<V=S='(@(F1A=&$@>F%K;_%C>F5N
M:6$B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C@@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ,#@*;7-G:60@(D5N9"!/;B(*;7-G<W1R(")K;_%C>K%C
M('<B"@HC.B!D871A+G!H<#HU.`IM<V=I9"`B16YD(%1I;64B"FUS9W-T<B`B
M8WIA<R!Z86MO\6-Z96YI82(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3(T(&%T=&5N
M9&5E<RYP:'`Z,3,U(&%T=&5N9&5E<RYP:'`Z,30R"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M(&9O<B`E<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3`Y,PIM<V=I9"`B179E;G0@861D960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$Q,#,*;7-G:60@(D5V96YT(&1E;&5T960Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3@*;7-G:60@(D5V96YT
M(&5D:71E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`V-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%=F5N="!F<F]M("5S('1O("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V-`HC+"!F=7IZ>0IM<V=I9"`B
M179E;G1S(&UU<W0@:&%V92!A('-T87)T(&1A=&4N(@IM<V=S='(@(D1A=&$@
M:V_Q8V$@;75S:2!B>>8@</.\;FEE:G-Z82!N:;\@9&%T82!P;V-ZL71K=2XB
M"@HC.B!L:6(O1')I=F5R+G!H<#HW,S`*;7-G:60@(D5V96YT<R!M=7-T(&AA
M=F4@82!T:71L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S8W
M"FUS9VED(")%=F5N=',@;75S="!H879E(&%N(&5N9"!D871E(&]R(&$@9'5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T
M96YD965S+FEN8SHW.0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD($YA;65S(@IM
M<V=S='(@(F-Z87,@>F%K;_%C>F5N:6$B"@HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$X-PIM<V=I9"`B17AP;W)T(@IM<V=S='(@(D5K<W!O<G0B
M"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R
M="!#86QE;F1A<B(*;7-G<W1R(")%:W-P;W)T=6H@:V%L96YD87)Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-CD*;7-G:60@(D9E8G)U
M87)Y(@IM<V=S='(@(FQU='DB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C$R.`HC+"!F=7IZ>0IM<V=I9"`B1FEN9"(*;7-G<W1R(")0
M:;%T96LB"@HC.B!Y96%R+G!H<#HX-R!T96UP;&%T97,O:F%V87-C<FEP="]G
M;W1O+FEN8SHV,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C(*(SH@;&EB
M+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(D9R(@IM<V=S='(@(E!I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&
M<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B5'=O:F$@:6YF;W)M86-J
M82(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,"!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z-S(*;7-G:60@(D9R:61A>2(*;7-G<W1R(")0:;%T96LB"@HC.B!T
M96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S`*;7-G:60@(D9U='5R92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G
M:60@(D=A;64B"FUS9W-T<B`B1W)A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C(S"FUS9VED(")'96YE<F%L(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`B5WEB\W(B"@HC.B!M
M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E
M+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN
M8SHQ,`IM<V=I9"`B2&ED92(*;7-G<W1R("(B"@HC.B!M;VYT:"YP:'`Z,3,U
M('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T
M96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(:61E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C8U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S
M.`IM<V=I9"`B2&]U<BAS*2(*;7-G<W1R(")G;V1Z:6YA*'DI(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC+"!F=7IZ>0IM<V=I9"`B2&]W(&QO
M;F<@<VAO=6QD('1H92!T:6UE('-L;W1S(&]N('1H92!D87D@86YD('=E96L@
M=FEE=W,@8F4_(@IM<V=S='(@(D-Z>2!P;VMA>GEW8>8@<')Z961Z:6&S>2!P
M\[-G;V1Z:6YN92!W('=I9&]K86-H(&1N:6$@:2!T>6=O9&YI83\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@X"FUS9VED(")(;W<@;6%N>2!D87ES
M(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S:&]U;&0@=V4@9V5N97)A=&4_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB268@>6]U<B!E;6%I;"!C;&EE;G0@9&]E<VXG
M="!S=7!P;W)T(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@;VYE(&]F('1H
M92`B"B)F;VQL;W=I;F<@;&EN:W,@=&\@86-C97!T(&]R(&1E8VQI;F4@=&AE
M(&5V96YT+EQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT.EQN(@HB)7-<
M;B(*(EQN(@HB5&\@86-C97!T('1H92!E=F5N="!T96YT871I=F5L>3I<;B(*
M(B5S7&XB"B)<;B(*(E1O(&1E8VQI;F4@=&AE(&5V96YT.EQN(@HB)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@0V%L96YD87(L(%-T97`@
M)60B"FUS9W-T<B`B26UP;W)T=6H@:V%L96YD87)Z(@H*(SH@9&%T82YP:'`Z
M,S(P"FUS9VED("));7!O<G0O17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(FEM
M<&]R="]E:W-P;W)T(&MA;&5N9&%R>F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHV.`IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")S='EC
M>F7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S0*;7-G
M:60@(DIU;'DB"FUS9W-T<B`B;&EP:65C(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9V]T;RYI;F,Z-S,*;7-G:60@(DIU;F4B"FUS9W-T<B`B8WIE<G=I
M96,B"@HC.B!D871A+G!H<#HV-2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M-#(*;7-G:60@(DME>7=O<F1S(@IM<V=S='(@(G.S;W=A(&ML=6-Z;W=E(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4U"FUS9VED("),87-T
M(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C@W"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-`HC.B!T96UP
M;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"B,Z('1E;7!L
M871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,38@=&5M<&QA=&5S
M+VUO;G1H+VAE860N:6YC.C0*(RP@9G5Z>GD*;7-G:60@(DQA<W0@36]N=&@B
M"FUS9W-T<B`B4&]P<GIE9&YI(&UI97-IL6,B"@HC.B!T96UP;&%T97,O>65A
M<B]H96%D+FEN8SHT"B,L(&9U>GIY"FUS9VED("),87-T(%EE87(B"FUS9W-T
M<B`B4&]P<GIE9&YI('1Y9'II9?$B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z-30@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,PIM<V=I9"`B
M3&%S="!W965K(@IM<V=S='(@(E!O<')Z961N:2!T>61Z:67Q(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-PIM<V=I9"`B3&EM:70@=&AE('1I
M;64@<W!A;B!T;R!E>'!O<G0Z(@IM<V=S='(@(D]G<F%N:6-Z(&]K<F5S(&1L
M82!E:W-P;W)T=3HB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z.#8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z-S8*(RP@9G5Z
M>GD*;7-G:60@(DQO7V-A=&EO;B(*;7-G<W1R(")-:65J<V-E(@H*(SH@9&%T
M82YP:'`Z-C0@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHU
M"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC
M.C$X"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N
M:6YC.C4R('1E;7!L871E<R]V:65W+W9I97<N:6YC.C(Q"B,Z(&QI8B]$<FEV
M97(N<&AP.C$X-#D*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DUI96IS8V4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*;7-G:60@(DUA;F%G92!R
M96UO=&4@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW,`IM<V=I9"`B36%R8V@B"FUS9W-T<B`B;6%R
M>F5C(@H*(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!%=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R(")M86HB"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ.#0V"FUS9VED(")-92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(DUE971I;F<B"FUS
M9W-T<B`B<W!O=&MA;FEE(@H*(SH@;&EB+T)L;V-K+W1R965?86QA<FUS+G!H
M<#HS"B,L(&9U>GIY"FUS9VED(")-96YU($%L87)M<R(*;7-G<W1R(")!;&%R
M;2(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C,*;7-G:60@(DUE;G4@
M3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV
M."!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S<*;7-G:60@(DUI;G5T92AS
M*2(*;7-G<W1R(")M:6YU=&$H>2DB"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H
M;&ES="YP:'`Z-#(*;7-G:60@(DUI<W-E9"!%=F5N=',@3&ES="(*;7-G<W1R
M("(B"@HC.B!Y96%R+G!H<#HX,R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3@*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(DUO(@IM<V=S='(@(E!O(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$V('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$Q-0HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV
M."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"FUS9VED(")-;VYD87DB"FUS
M9W-T<B`B<&]N:65D>FEALV5K(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y
M,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S='(@(DUI97-IL6,B"@HC.B!L
M:6(O0FQO8VLO;6]N=&@N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUO;G1H(%9I
M97<B"FUS9W-T<B`B36EE<VFQ8R(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N
M<&AP.C,@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#,*;7-G:60@(DUO;G1H
M;'D@179E;G1S($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,CD@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C,U"FUS9VED(")-;VYT:&QY.B!296-U<G,@979E<GDB"FUS9W-T
M<B`B;6EE<VGJ8WIN:64Z('!O=W1A<GIA('-IZB!C;R(*"B,Z(&QI8B]";&]C
M:R]M;VYT:&QI<W0N<&AP.C(T"FUS9VED(")-;VYT:',@06AE860B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(T"B,L(&9U
M>GIY"FUS9VED(")-;VYT:',@0F5F;W)E(@IM<V=S='(@(FUI;G5T('!R>F5D
M(@H*(SH@;&EB+V%P:2YP:'`Z-C$R"FUS9VED(")-=6QT:7!L92!I0V%L96YD
M87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT(&ES('-U<'!O
M<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8W"B,L(&9U>GIY"FUS9VED
M(")->2!#86QE;F1A<G,B"FUS9W-T<B`B26UP;W)T=6H@:V%L96YD87)Z(@H*
M(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M96YU+FEN8SHS
M-@HC+"!F=7IZ>0IM<V=I9"`B37D@0V%L96YD87)S.B(*;7-G<W1R(")%:W-P
M;W)T=6H@:V%L96YD87)Z(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C(P-`IM<V=I9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3$W
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3D*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S4*(SH@=&5M<&QA=&5S
M+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,3<*(SH@=&5M<&QA
M=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-#0*(RP@9G5Z
M>GD*;7-G:60@(DYA;64B"FUS9W-T<B`B1W)A(@H*(SH@;&EB+T)L;V-K+VUO
M;G1H+G!H<#HT,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT-"!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z-#$*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z
M,C`*;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R(").;W=E('ID87)Z96YI92(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S0*(RP@9G5Z>GD*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B3F%S=.IP;GD@9'II9?$B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z-3<*;7-G:60@(DYE>'0@,C0@:&]U<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(Y"B,L(&9U>GIY
M"FUS9VED(").97AT($1A>2(*;7-G<W1R(").87-TZG!N>2!D>FEE\2(*"B,Z
M('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-@HC.B!T
M96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3@@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C8*;7-G:60@(DYE>'0@36]N=&@B"FUS9W-T
M<B`B3F%S=.IP;GD@;6EE<VFQ8R(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z
M,S(*(RP@9G5Z>GD*;7-G:60@(DYE>'0@5V5E:R(*;7-G<W1R(").87-TZG!N
M>2!T>61Z:67Q(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A9"YI;F,Z-@HC+"!F
M=7IZ>0IM<V=I9"`B3F5X="!996%R(@IM<V=S='(@(DYA<W3J<&YY(&1Z:67Q
M(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT(&1A
M>2(*;7-G<W1R(").87-TZG!N>2!D>FEE\2(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHU."!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHU"FUS
M9VED(").97AT('=E96LB"FUS9W-T<B`B3F%S=.IP;GD@='ED>FEE\2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S4*(RP@9G5Z>GD*;7-G:60@(DYO
M(@IM<V=S='(@(F)R86LB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHW
M,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,C8*(RP@9G5Z>GD*;7-G:60@
M(DYO(&%L87)M(@IM<V=S='(@(D%L87)M(@H*(SH@=&5M<&QA=&5S+V%T=&5N
M9&5E<R]A='1E;F1E97,N:6YC.C0X"B,L(&9U>GIY"FUS9VED(").;R!A='1E
M;F1E97,B"FUS9W-T<B`B;FEE(&UA(&1A='D@:V_Q8V$B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,S$Q"FUS9VED(").;R!C86QE;F1A<G,@87)E(&%V86EL
M86)L92!T;R!G=65S=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-34*;7-G
M:60@(DYO(&5N9"!D871E(@IM<V=S='(@(FYI92!M82!D871Y(&MO\6-A(@H*
M(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$V-"!L:6(O0FQO8VLO
M;6]N=&AL:7-T+G!H<#HQ-C,*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y
M-`IM<V=I9"`B3F\@979E;G1S('1O(&1I<W!L87DB"FUS9W-T<B`B(@H*(SH@
M;&EB+U-T;W)A9V4O:V]L86(N<&AP.C0S"B,L('!H<"UF;W)M870*;7-G:60@
M(DYO(&9R964O8G5S>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,T-"!L:6(O87!I+G!H<#HV
M,#(*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`T"B,L(&9U>GIY
M"FUS9VED(").;R!R96-U<G)E;F-E(@IM<V=S='(@(F1A=&$@<&]W=&%R>F%N
M:6$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HX.#8*;7-G:60@(DYO('9A;&ED
M(&5M86EL(&%D9')E<W,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-C`Q(&QI8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N
M92(*;7-G<W1R(")B<F%K(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ,S8*
M;7-G:60@(DYO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$*(RP@9G5Z>GD*;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS
M9W-T<B`B36EE:G-C92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C<X"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(")L:7-T;W!A9"(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-@IM<V=I9"`B3F]W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<W
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(G!AO&1Z:65R;FEK(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S@*;7-G:60@(D]N(&%L;"!C
M86QE;F1A<G,@22!H879E(')E860@86-C97-S('1O(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S<*;7-G:60@(D]N(&%L;"!S:&]W
M;B!C86QE;F1A<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(W-@IM<V=I9"`B3VX@;7D@8V%L96YD87)S(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C$Y"B,L(&9U>GIY"FUS9VED(")/
M<'1I;VYA;"(*;7-G<W1R(")/<&-J92(*"B,Z(&QI8B]&0E9I97<N<&AP.C$Q
M.`IM<V=I9"`B3W!T:6]N86P@071T96YD965S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&0E9I97<N<&AP.C$U,@IM<V=I9"`B3W9E<G9I97<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,S0*;7-G:60@(D]W;F5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3W=N97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,3`R('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3@R"FUS9VED(")032(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR.2!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")086QM
M($1A=&5";V]K(@IM<V=S='(@(D1A=&$@86QA<FUU(@H*(SH@;&EB+T)L;V-K
M+W!R979M;VYT:&QI<W0N<&AP.C,*;7-G:60@(E!A<W0@179E;G1S($QI<W0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`Y('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y.`IM<V=I9"`B4&%T=&5R;B(*;7-G
M<W1R(")7>F]R>F5C(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(W
M"FUS9VED(")097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,S(U(&QI8B]A<&DN<&AP.C0Q.2!L:6(O
M87!I+G!H<#HT.#$@;&EB+V%P:2YP:'`Z-34S"B,Z(&QI8B]A<&DN<&AP.C4X
M-"!L:6(O87!I+G!H<#HV-S`@;&EB+V%P:2YP:'`Z-S`V"FUS9VED(")097)M
M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,38W"B,L(&9U>GIY"FUS9VED(")097)M:7-S
M:6]N<R(*;7-G<W1R(")O<V]B:7-T>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,0HC+"!F=7IZ>0IM<V=I9"`B4&]R=&%L($]P=&EO;G,B"FUS9W-T
M<B`B3W!C:F4B"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z,C4*(RP@9G5Z>GD*
M;7-G:60@(E!R979I;W5S($1A>2(*;7-G<W1R(")0;W!R>F5D;FD@9'II9?$B
M"@HC.B!L:6(O1D)6:65W+W=E96LN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")0
M<F5V:6]U<R!7965K(@IM<V=S='(@(E!O<')Z961N:2!D>FEE\2(*"B,Z('1E
M;7!L871E<R]D87DO:&5A9"YI;F,Z,PIM<V=I9"`B4')E=FEO=7,@9&%Y(@IM
M<V=S='(@(E!O<')Z961N:2!D>FEE\2(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-3(*;7-G:60@
M(E)E8W5R(%5N=&EL(@IM<V=S='(@(E!O=W1A<GIA;FEE(&1O(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`V"B,L(&9U>GIY"FUS9VED(")296-U
M<G)E;F-E(@IM<V=S='(@(F1A=&$@<&]W=&%R>F%N:6$B"@HC.B!D871A+G!H
M<#HV.0IM<V=I9"`B4F5C=7)R96YC92!$871A(@IM<V=S='(@(F1A=&$@<&]W
M=&%R>F%N:6$B"@HC.B!D871A+G!H<#HV-PIM<V=I9"`B4F5C=7)R96YC92!%
M;F0@1&%T92(*;7-G<W1R(")D871A(&MO\6-A('!O=W1A<GIA;FEA(@H*(SH@
M9&%T82YP:'`Z-C@*;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T
M<B`B<')Z961Z:6&S('!O=W1A<GIA;FEA(@H*(SH@9&%T82YP:'`Z-C8*;7-G
M:60@(E)E8W5R<F5N8V4@5'EP92(*;7-G<W1R(")T>7`@<&]W=&%R>F%N:6$B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#`*;7-G:60@(E)E8W5R<R!D86EL
M>2(*;7-G<W1R(")P;W=T87)Z82!S:>H@8V]D>FEE;FYI92(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C4T-PIM<V=I9"`B4F5C=7)S(&UO;G1H;'DB"FUS9W-T
M<B`B<&]W=&%R>F$@<VGJ(&-O(&UI97-IL6,B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HU-#,*;7-G:60@(E)E8W5R<R!W965K;'DB"FUS9W-T<B`B<&]W=&%R
M>F$@<VGJ(&-O('1Y9'II9?$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3`*
M;7-G:60@(E)E8W5R<R!Y96%R;'DB"FUS9W-T<B`B<&]W=&%R>F$@<VGJ(&-O
M(')O:R(*"B,Z(&QI8B]38VAE9'5L97(O:W)O;F]L:71H+G!H<#HQ.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5M:6YD97(Z("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHY,2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#0*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!#86QE
M;F1A<G,B"FUS9W-T<B`B26UP;W)T=6H@:V%L96YD87)Z(@H*(SH@=&5M<&QA
M=&5S+VUE;G4N:6YC.C8P('1E;7!L871E<R]M96YU+FEN8SHV,@HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<SHB"FUS9W-T<B`B26UP;W)T=6H@
M:V%L96YD87)Z(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92`E<R(*;7-G<W1R
M("(B"@HC.B!A='1E;F1E97,N<&AP.C$P-`IM<V=I9"`B4F5M;W9E($%T=&5N
M9&5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,S(*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@8V%L96YD87(@=VET:"!T
M:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L
M971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@8V%L96YD87(N/"]S
M=')O;F<^(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8R-@IM
M<V=I9"`B4F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB+T9"5FEE=RYP:'`Z
M.3@@;&EB+T9"5FEE=RYP:'`Z,3,W(&QI8B]&0E9I97<N<&AP.C$T,"!L:6(O
M1D)6:65W+G!H<#HQ-#,*;7-G:60@(E)E<75I<F5D($%T=&5N9&5E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS-"!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHS,3`*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S
M(@IM<V=S='(@(E!R>GEW<O/F('5S=&%W:65N:6$@9&]M>;9L;F4B"@HC.B!T
M96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#,@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,38V"FUS9VED(")297-P;VYS92(*;7-G<W1R("(B
M"@HC.B!Y96%R+G!H<#HX."!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C,*(SH@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(E-O(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(Q('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R,`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,PIM
M<V=I9"`B4V%T=7)D87DB"FUS9W-T<B`B<V]B;W1A(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B
M4V%V92(*;7-G<W1R(")3;R(*"B,Z('9I97=E=F5N="YP:'`Z,3$X(&5D:71E
M=F5N="YP:'`Z-#@@961I=&5V96YT+G!H<#HU-@IM<V=I9"`B4V%V92!!<R!.
M97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC.C@W"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC
M.B!A9&1E=F5N="YP:'`Z-34@961I=&5V96YT+G!H<#HU,0IM<V=I9"`B4V%V
M92!%=F5N="(*;7-G<W1R("):87!A;6GJ=&%J('ID87)Z96YI92(*"B,Z('-E
M87)C:"YP:'`Z.3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N
M:6YC.C$Q-0HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-C<@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C@*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-#`@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"(*;7-G<W1R(")M87)Z96,B
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,0HC+"!F=7IZ
M>0IM<V=I9"`B4V5A<F-H($-A;&5N9&%R<R(*;7-G<W1R("));7!O<G1U:B!K
M86QE;F1A<GHB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-@IM
M<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]S96%R8V@N:6YC.C8*;7-G:60@(E-E87)C:"!F;W(@8V%L
M96YD87)S(&-O;G1A:6YI;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3`*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`B5WEB:65R>B!P;&EK
M(&1O(&EM<&]R='4Z(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(F1A=&$@<&]C>K%T:W4B"@HC.B!T
M96UP;&%T97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!C
M86QE;F1A<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B5WEB:65R>BP@=R!J86MI
M('-P;W/S8B!P;VMA>GEW8>8@9&%T>3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C="!C;VYF:7)M871I
M;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!V:65W
M<R!A;F0@8VAO;W-E("(*(F1E9F%U;'0@=FEE=RXB"FUS9W-T<B`B5WEB:65R
M>BP@=R!J86MI('-P;W/S8B!P;VMA>GEW8>8@<O._;F4@=VED;VMI+B!7>6)I
M97)Z('=I9&]K(&1O;7FV;&YY+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,3D*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@8V%L96YD87(@
M=&\@:6UP;W)T('1O.B(*;7-G<W1R(")7>6)I97)Z('!L:6L@9&\@:6UP;W)T
M=3HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E=Y
M8FEE<GH@OW+S9+-O(&1O(&EM<&]R='4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHR.`IM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R
M=#HB"FUS9W-T<B`B5WEB:65R>B!P;&EK(&1O(&EM<&]R='4Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B4V5L96-T('1H92!F:7)S
M="!W965K9&%Y.B(*;7-G<W1R(")7>6)I97)Z('!I97)W<WIY(&1Z:67Q('1Y
M9V]D;FEA.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@
M9FEL93HB"FUS9W-T<B`B5WEB:65R>B!F;W)M870@9&\@96MS<&]R='4Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H
M92!T:6UE('-P86X@=&\@<VAO=SHB"FUS9W-T<B`B5WEB:65R>B!P;VMA>GEW
M86YY(&]K<F5S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A
M<G1U<#HB"FUS9W-T<B`B5WEB:65R>B!W:61O:R!P;VMA>GEW86YY(&YA('!O
M8WJQ=&MU('!R86-Y.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN
M('1H92!P;W)T86PN(@IM<V=S='(@(E=Y8FEE<GHL(&IA:VEE('ID87)Z96YI
M82!P;VMA>F'F('<@<&]D<W5M;W=A;FEU($AO<F1E+B(*"B,Z('1E;7!L871E
M<R]D96QE=&4O;VYE+FEN8SHR-"!T96UP;&%T97,O9&5L971E+V1E;&5T92YI
M;F,Z,C0*;7-G:60@(E-E;F0@82!C86YC96P@;F]T:69I8V%T:6]N('1O(&%L
M;"!A='1E;F1E97,@=VAE;B!D96QE=&EN9R!T:&ES(&5V96YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")396YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$X,0IM<V=I9"`B4V5N9"!U<&1A
M=&5S+VEN=FET871I;VYS('1O(&%L;"!A='1E;F1E97,@=VAE;B!S879I;F<@
M=&AI<R!E=F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]G;W1O+FEN8SHW-@IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(G=R>F5S
M:67Q(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.#,*
M(RP@9G5Z>GD*;7-G:60@(E-E="!E;F0@9&%T92(*;7-G<W1R(")N:64@;6$@
M9&%T>2!K;_%C82(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V.`HC
M+"!F=7IZ>0IM<V=I9"`B4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T
M<B`B9&%T82!K;_%C82!P;W=T87)Z86YI82(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")3970@<W1A
M<G0@9&%T92(*;7-G<W1R(")D871A('!O8WJQ=&MU(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4Y"FUS9VED("(B"B)3970@>6]U<B!F<F5E+V)U<WD@
M8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H97(@=7-E<G,G(&9R964O
M8G5S>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H87)E(&YO="!F;W5N9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C<Y"B,L(&9U>GIY"FUS9VED(")3:&%R960@0V%L96YD87)S(@IM<V=S='(@
M(DEM<&]R='5J(&MA;&5N9&%R>B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHT
M-R!T96UP;&%T97,O;65N=2YI;F,Z-#D*(RP@9G5Z>GD*;7-G:60@(E-H87)E
M9"!#86QE;F1A<G,Z(@IM<V=S='(@(D5K<W!O<G1U:B!K86QE;F1A<GHB"@HC
M.B!C86QE;F1A<E]S96%R8V@N<&AP.C(U('1E;7!L871E<R]W965K+VAE861?
M<VED95]B>5]S:61E+FEN8SHS"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@0V%L96YD87(B
M"FUS9W-T<B`B16MS<&]R='5J(&MA;&5N9&%R>B(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O<V5A<F-H+FEN8SHR,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M:&]W(&-A;&5N9&%R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34V"FUS9VED(")3:&]W(&-A=&5G;W)Y(&QE9V5N9#\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I
M9"`B4VAO=R!D96QE=&4L(&%L87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I
M;B!C86QE;F1A<B!V:65W<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A
M;&5N9&%R/R(*;7-G<W1R(")#>GD@<&]K87IY=V'F('IA9&%N:6$@=&5R;6EN
M;W=E('<@:V%L96YD87)Z=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,38V"FUS9VED(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@(E-H;W<@;VYL
M>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS9W-T<B`B0WIY
M('!O:V%Z>7=AYB!T>6QK;R!T92!W>61A<GIE;FEA+"!K=/-R>6T@<')Z>7!I
M<V%N;R!A;&%R;3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<U"FUS
M9VED(")3:&]W('-H87)E9"!C86QE;F1A<G,@<VED92UB>2US:61E/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"B,L(&9U>GIY
M"FUS9VED(")3:&]W('1A<VMS('5S:6YG(&-A=&5G;W)Y(&-O;&]R<S\B"FUS
M9W-T<B`B0WIY('!O:V%Z>7=AYB!Z861A;FEA('1E<FUI;F]W92!W(&MA;&5N
M9&%R>G4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU"B,L(&9U>GIY
M"FUS9VED(")3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C:"!D87D@:6X@
M=V5E:R!V:65W<S\B"FUS9W-T<B`B0WIY('!O:V%Z>7=AYB!P<GIE9'II8;-Y
M('#SLV=O9'II;FYE('<@=VED;VMA8V@@9&YI82!I('1Y9V]D;FEA/R(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q"B,L(&9U>GIY
M"FUS9VED(")3=&%?<G0B"FUS9W-T<B`B4&]C>K%W<WIY(&]D(@H*(SH@9&%T
M82YP:'`Z-34*;7-G:60@(E-T87)T($1A=&4B"FUS9W-T<B`B9&%T82!P;V-Z
ML71K=2(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z
M-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C(U"FUS9VED(")3=&%R="!/;B(*;7-G<W1R(")0;V-Z
ML7=S>GD@;V0B"@HC.B!D871A+G!H<#HU-@IM<V=I9"`B4W1A<G0@5&EM92(*
M;7-G<W1R(")C>F%S('!O8WJQ=&MU(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.CDU('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C@U"FUS9VED(")3=&%T7W5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHR-PIM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP
M.C@Q('EE87(N<&AP.CDP('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C8U"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-"!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C$P-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P.0IM<V=I9"`B
M4W4B"FUS9W-T<B`B3FDB"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M,30@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(S"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R,2!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN
M8SHV-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")3=6YD
M87DB"FUS9W-T<B`B;FEE9'II96QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Y"FUS9VED(")487-K<R(*;7-G<W1R(")Z861A;FEA(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z-3<T(&QI8B]+<F]N;VQI=&@N<&AP.C4Y-PIM<V=I
M9"`B5&5N=&%T:79E(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP.C@V('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(R,0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B
M5&@B"FUS9W-T<B`B0WHB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C<P"FUS9VED(")4:&4@161I="!!='1E;F1E97,@<V-R965N(&ES
M(&YO(&QO;F=E<B!P<F5S96YT+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!C
M86QE;F1A<G,N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE
M;F1A<B!<(B5S7"(@8V%N;F]T(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M(&-A;&5N9&%R<RYP:'`Z-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A
M;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!C<F5A=&5D+B(*;7-G<W1R("(B"@HC
M.B!C86QE;F1A<G,N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C
M86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*
M(SH@8V%L96YD87)S+G!H<#HU-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M8V%L96YD87(@7"(E<UPB(&AA<R!B965N(')E;F%M960@=&\@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C4V"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@8V%L96YD87(@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z,38S"FUS
M9VED(")4:&4@96YD(&1A=&4@;75S="!B92!L871E<B!T:&%N('1H92!S=&%R
M="!D871E+B(*;7-G<W1R(")$871A(&MO\6-A(&UU<VD@8GGF('#SO&YI96IS
M>F$@;FF_(&1A=&$@<&]C>K%T:W4N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3`Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB(&AA
M<R!B965N(&%D9&5D+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960L('=H:6-H
M('=A<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E
M<UPB(&AA<R!B965N(&5D:71E9"P@=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E<R!W87,@
M<W5C8V5S<V9U;&QY('-E;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$P,C0*;7-G:60@(E1H92!F;VQL;W=I;F<@:7,@82!M;W)E(&1E
M=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#HB"FUS9W-T<B`B(@H*
M(SH@871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E<W0@=V%S(&EN
M8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N96-E<W-A<GD@
M=&\@86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E(&UI<W-I;F<N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O96UP='DN:6YC.C,*
M(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!E=F5N=',@;6%T8VAI;F<@
M=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(DYI92!B>;-O('ID87)Z
M9?$L(&MT\W)E(&UOOVYA(&5K<W!O<G1O=V'F+B(*"B,Z(&%D9&5V96YT86-T
M:6]N+G!H<#HQ."!E9&ET979E;G1A8W1I;VXN<&AP.C,U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@86-C97-S:6YG
M('1H92!C86QE;F1A<CH@)7,B"FUS9W-T<B`B4&]D8WIA<R!I;7!O<G1U(&1A
M;GEC:"!W>7-TL7!ILR!BL[%D+B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HS
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&%D9&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(E!O9&-Z87,@:6UP
M;W)T=2!D86YY8V@@=WES=+%P:;,@8K.Q9"XB"@HC.B!E9&ET979E;G1A8W1I
M;VXN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(E!O
M9&-Z87,@:6UP;W)T=2!D86YY8V@@=WES=+%P:;,@8K.Q9"XB"@HC.B!L:6(O
M87!I+G!H<#HS,S@@;&EB+V%P:2YP:'`Z-3DV"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`B4&]D8WIA<R!I;7!O<G1U(&1A;GEC:"!W>7-TL7!ILR!B
ML[%D+B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z-C,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@=&AE
M(&5V96YT.B`E<R(*;7-G<W1R(")0;V1C>F%S(&EM<&]R='4@9&%N>6-H('=Y
M<W2Q<&FS(&*SL60N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!A
M;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C$P-0IM<V=I9"`B5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@
M97AP;W)T+B(*;7-G<W1R(").:64@8GFS;R!Z9&%R>F7Q+"!K=/-R92!M;[]N
M82!E:W-P;W)T;W=AYBXB"@HC.B!D871A+G!H<#HQ.#0*;7-G:60@(E1H:7,@
M9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D+FEN8SHQ.2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,3@*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S$*;7-G:60@
M(E1H=7)S9&%Y(@IM<V=S='(@(F-Z=V%R=&5K(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C,W"B,L(&9U>GIY"FUS9VED(")4:6UE(%-P7V%N
M(@IM<V=S='(@(E-T<F5F82!C>F%S;W=A(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I=%]T:6UE<W!A;BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B5&EM92!S<&%N
M(@IM<V=S='(@(E-T<F5F82!C>F%S;W=A(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8VA?861V86YC960N:6YC.C,V('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C0P"B,L(&9U>GIY"FUS9VED(")4:71?;&4B"FUS9W-T<B`B6F1A<GIE
M;FEE(@H*(SH@9&%T82YP:'`Z-30@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C(P"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z
M,PIM<V=I9"`B5&ET;&4B"FUS9W-T<B`B6F1A<GIE;FEE(@H*(SH@;&EB+T)L
M;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R,B!L:6(O0FQO8VLO;6]N=&AL:7-T
M+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R-PIM<V=I9"`B
M5&]D87DB"FUS9W-T<B`B3?-J('=I9&]K(@H*(SH@;&EB+T)L;V-K+W!R979M
M;VYT:&QI<W0N<&AP.C$R-"!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ,C,*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R.0IM<V=I9"`B5&]M;W)R;W<B
M"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#0@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-C`@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$Y"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")4=2(*;7-G<W1R(")7
M="(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-R!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,38*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP
M="YI;F,Z-CD*;7-G:60@(E1U97-D87DB"FUS9W-T<B`B=W1O<F5K(@H*(SH@
M8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")4>7!E(@IM<V=S
M='(@(G1Y<"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ.#,*;7-G:60@(E523"(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92]S
M<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O1')I=F5R+VUC86PN<&AP.C$S-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*
M"B,Z(&-A;&5N9&%R<RYP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M=&]R86=E+VMO;&%B+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-0HC.B!S
M8W)I<'1S+W5P9W)A9&5S+S(P,#0M,#4M,3E?8V]N=F5R=%]C871E9V]R:65S
M7W1O7W-T<FEN9W,N<&AP.C4S"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C,W-B!L:6(O87!I+G!H<#HT-3`@;&EB+V%P:2YP
M:'`Z-3$V(&QI8B]A<&DN<&AP.C8R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C$P,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D
M871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,`IM<V=I9"`B57-E<B!);G1E<F9A8V4B"FUS9W-T<B`B5VED;VL@;VMI
M96YK82(*"B,Z('EE87(N<&AP.C$V,R!Y96%R+G!H<#HQ-CD@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ-3D@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ-C(*;7-G:60@
M(E9I97<@1&%Y(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP.C@U('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(R,`HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5V4B
M"FUS9W-T<B`BIG(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3@@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$W"B,Z('1E;7!L871E<R]E9&ET
M+VIA=F%S8W)I<'0N:6YC.C<P"FUS9VED(")7961N97-D87DB"FUS9W-T<B`B
MMG)O9&$B"@HC.B!A='1E;F1E97,N<&AP.C$Q,B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,CDP(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(S"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*;7-G<W1R(")4>61Z:67Q
M(@H*(SH@;6]N=&@N<&AP.C$W.2!W;W)K=V5E:RYP:'`Z,S`@=V5E:RYP:'`Z
M,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5E:R`E9"(*;7-G<W1R(")T>61Z
M:67Q("5D(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3D@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED(")7965K*',I(@IM<V=S='(@
M(G1Y9'II9?$H='EG;V1N:64I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q-0IM<V=I9"`B5V5E
M:VQY.B!296-U<G,@979E<GDB"FUS9W-T<B`B='EG;V1N:6]W;SH@<&]W=&%R
M>F$@<VGJ(&-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I
M9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD
M+"!W:&5N('1H97)E(&%R92!N;R!L871E<B!E=F5N=',_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(B(*(E=H870@
M=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S('-T87)T+"!W:&5N('1H
M97)E(&%R92!N;R!E87)L:65R(&5V96YT<S\B"FUS9W-T<B`B(@H*(SH@871T
M96YD965S+G!H<#HQ,3$@;&EB+TMR;VYO;&ET:"YP:'`Z,3(X.2!L:6(O0FQO
M8VLO=')E95]M96YU+G!H<#HR,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#0*;7-G:60@(E=O<FL@5V5E:R(*;7-G<W1R(")4>61Z:67Q(')O8F]C>GDB
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,CDR(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C(U"FUS9VED(")996%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M-#$*;7-G:60@(EEE87)L>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(G)O8WIN
M:64Z('!O=W1A<GIA('-IZB!C;R(*"B,Z(&1A=&$N<&AP.C0P(&1A=&$N<&AP
M.C(S-"!E9&ET979E;G1A8W1I;VXN<&AP.C0V(&%D9&5V96YT+G!H<#HQ-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@979E;G1S+B(*;7-G<W1R("(B"@HC.B!A='1E
M;F0N<&AP.C0Y"FUS9VED(")9;W4@87)E(&YO="!A;B!A='1E;F1E92!O9B!T
M:&4@<W!E8VEF:65D(&5V96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C<V"FUS9VED(")9;W4@8V%N(&]N;'D@
M=7-E('1H:7,@9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.CDW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W4@9&\@;F]T(&AA=F4@86X@96UA:6P@861D
M<F5S<R!C;VYF:6=U<F5D(&EN('EO=7(@4&5R<V]N86P@26YF;W)M871I;VX@
M(@HB3W!T:6]N<RX@66]U(&UU<W0@<V5T(&]N92`E<VAE<F4E<R!B969O<F4@
M979E;G0@;F]T:69I8V%T:6]N<R!C86X@8F4@<V5N="XB"FUS9W-T<B`B(@H*
M(SH@861D979E;G1A8W1I;VXN<&AP.C(P"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@
M)7,N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$Y-`IM<V=I9"`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R!T:&4@<V5L
M96-T960@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z(&1E;&5V96YT86-T:6]N
M+G!H<#HR-@IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M9&5L971E('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&5D:71E=F5N=&%C
M=&EO;BYP:'`Z-S@*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N
M('1O(&5D:70@=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M,3@Y"FUS9VED(")9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE
M;F1A<BXB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HR,0IM<V=I9"`B66]U
M(&AA=F4@<W5C8V5S<V9U;&QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI
M<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HR-@IM<V=I9"`B
M66]U(&AA=F4@<W5C8V5S<V9U;&QY(&1E8VQI;F5D(&%T=&5N9&5N8V4@=&\@
M=&AI<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H<#HS,0IM<V=I
M9"`B66]U(&AA=F4@=&5N=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T
M;R!T:&ES(&5V96YT+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.CDQ
M"FUS9VED(")9;W4@;75S="!S96QE8W0@82!C86QE;F1A<B!T;R!B92!D96QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C4T"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F
M:7)S="XB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y-`IM
M<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT
M<R!A<F4@861D960@=&\@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,#0*;7-G:60@(B(*(EEO=2!R97%U97-T
M960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&1E;&5T960@9G)O
M;2!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`Y.0IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE
M9"!W:&5N(&5V96YT<R!A<F4@961I=&5D(&EN('EO=7(@8V%L96YD87)S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O4V-H961U;&5R+VMR;VYO;&ET:"YP:'`Z,C`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@<F5M
M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O<VAA<F5S96QE8W0N:6YC.C$P"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@8V%L96YD87(B"FUS9W-T<B`B
M16MS<&]R='5J(&MA;&5N9&%R>B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-3,@
M;&EB+T1R:79E<BYP:'`Z,3`V,PIM<V=I9"`B6U5N;F%M960@979E;G1=(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.CDW"B,L(&9U
M>GIY"FUS9VED(")?06QA<FTB"FUS9W-T<B`B06QA<FTB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$*;7-G:60@(E]"87-I
M8R!396%R8V@B"FUS9W-T<B`B(@H*(SH@=FEE=V5V96YT+G!H<#HQ,C`*(RP@
M9G5Z>GD*;7-G:60@(E]%9&ET(@IM<V=S='(@(F5D>71U:B`B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,S,P"B,L(&9U>GIY"FUS9VED(")?1V]T;R(*;7-G
M<W1R(")7>6+S<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S8*(RP@9G5Z
M>GD*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(DEM<&]R="]%:W-P
M;W)T(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q.`HC+"!F=7IZ>0IM<V=I
M9"`B7TUY($-A;&5N9&%R<R(*;7-G<W1R(")%:W-P;W)T=6H@:V%L96YD87)Z
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,R-0HC+"!F=7IZ>0IM<V=I9"`B
M7TYE=R!%=F5N="(*;7-G<W1R(").;W=E('ID87)Z96YI92(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$S-#$*;7-G:60@(E]0<FEN="(*;7-G<W1R("(B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,R"B,L(&9U>GIY"FUS9VED(")?4V5A
M<F-H(@IM<V=S='(@(FUA<GIE8R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M,C@*(RP@9G5Z>GD*;7-G:60@(E]4;V1A>2(*;7-G<W1R(")-\VH@=VED;VLB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#(*;7-G:60@(F)E9F]R
M92!T:&4@979E;G0@<W1A<G1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G<W1R(")D>FEE\2(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR,3`*;7-G:60@(F1A>2AS*2(*;7-G<W1R(")D>FEE\2AD;FDI
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(F1N:2(*"B,Z(&1A=&$N<&AP
M.C$T-R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*(RP@9G5Z>GD*;7-G
M:60@(F5V96YT<RYC<W8B"FUS9W-T<B`B5W-Z>7-T:VEE('ID87)Z96YI82(*
M"B,Z(&1A=&$N<&AP.C$V.`HC+"!F=7IZ>0IM<V=I9"`B979E;G1S+FEC<R(*
M;7-G<W1R(")7<WIY<W1K:64@>F1A<GIE;FEA(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,S$*;7-G:60@(F9R;VTB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,S`@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,V"FUS9VED(")M;VYT:"AS
M*2(*;7-G<W1R(")M:65S:;%C*&UI97-IL6-E*2(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$P,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F]N("5S
M(&%T("5S(@IM<V=S='(@(B5S(')O>G!O8WIY;F$@<VGJ('IA("5S(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(S,`IM<V=I9"`B;VX@=&AE('-A;64@9&%T92(*;7-G<W1R(")W
M('1Y;2!S86UY;2!D;FEU(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3(V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S-@IM<V=I9"`B;VX@=&AE
M('-A;64@=V5E:V1A>2(*;7-G<W1R(")W('1Y;2!S86UY;2!D;FEU('1Y9V]D
M;FEA(@H*(SH@9&%T82YP:'`Z,S`@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ-0IM<V=I9"`B=D-A;&5N9&%R+VE#86QE;F1A<B(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HS-#D@;&EB+V%P:2YP:'`Z-C`W"FUS9VED(")V179E
M;G0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DQ"FUS9VED(")W965K(@IM<V=S='(@(G1Y9'II9?$B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C$W"FUS9VED(")W965K*',I(&]N.B(*;7-G<W1R(")T>61Z:67Q
M*'1Y9V]D;FEE*2!W.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3(@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PHC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DT"FUS9VED(")W965K<R(*;7-G<W1R(")T>6=O9&YI92(*"B,Z
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHR-#(*;7-G:60@(GEE87(H<RDB"FUS9W-T<B`B<F]K*&QA=&$I
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W!O+V1A7T1+
M+G!O````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R,#8T
M,``Q,#0Q-S,V,C<U,P`P,C`S-34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!+<F]N;VQI=&@@1&%N:7-H(%1R86YS;&%T
M:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R($%R;F4@36]R=&5N<V5N+"!":6QL
M($5D9VEN9W1O;BX*(R!":6QL($5D9VEN9W1O;B`\8D`P>#(P+F-O;3XL(#(P
M,#(N"B,@07)N92!-;W)T96YS96X@/&%R;F4M;6]R=&5N<V5N0')E9&-R;W-S
M+F1K/BP@,C`P,BX*(PHC(%5P9&%T960@8GD@36%R=&EN($QI<W0M4&5T97)S
M96X@/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K/@IM<V=I9"`B(@IM<V=S='(@
M(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2W)O;F]L:71H(#(N,"UC=G-<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`R+3`U+3(R(#$T.C$R*S`R,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@36%R=&EN($QI<W0M4&5T97)S96X@/&UA<G1I
M;D!L:7-T+7!E=&5R<V5N+F1K/EQN(@HB3&%N9W5A9V4M5&5A;3H@1&%N:7-H
M(#QD:RUH;W)D94!H=6QP<WES=&5M<RYN970^7&XB"B)-24U%+59E<G-I;VXZ
M(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES
M;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET
M7&XB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@8V%L96YD87)S(&9O=6YD(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!E=F5N=',B"FUS9W-T<B`B06QL92!A
M9G1A;&5R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z
M,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S($1A>2AS*2`E<R!(;W5R*',I
M("5S($UI;G5T97,B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A='1E;F1E97,B"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I
M;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(B5S(&9I;"!S=6-C
M97-F=6QD="!I;7!O<G1E<F5T(@H*(SH@8V%L96YD87)S+G!H<#HQ,#4@;&EB
M+V)A<V4N<&AP.C$R.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!#86QE;F1A<B(*;7-G<W1R(")%:W-P;W)TZ7(@2V%L96YD97(B"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,3<*;7-G:60@(B(*(BA#
M;&EC:R!O;B!C86QE;F1A<B!N86UE('1O('-W:71C:"!T:&4@8V%L96YD87(G
M<R!V:7-I8FEL:71Y(&EN('1H92!M86EN("(*(G=I;F1O=RDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C0*;7-G
M:60@(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($%D9"`J(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,34P"FUS9VED
M("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ-S@V"FUS9VED("(Q(&%T=&5N9&5E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L(&9U
M>GIY"FUS9VED("(Q(&5V96YT(@IM<V=S='(@(D%L;&4@869T86QE<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*(RP@9G5Z>GD*;7-G:60@(C$@
M:&]U<B(*;7-G<W1R("(E9"!T:6UE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-`HC+"!F=7IZ>0IM<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R("(E
M9"!M:6YU='1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*(RP@
M9G5Z>GD*;7-G:60@(C(P(&UI;G5T97,B"FUS9W-T<B`B)60@;6EN=71T97(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"B,L(&9U>GIY"FUS9VED
M("(S,"!M:6YU=&5S(@IM<V=S='(@(B5D(&UI;G5T=&5R(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3<Q"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG
M/D%T=&5N9&5E<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/D[X
M9VQE;W)D/"]B/B`H=F%L9V9R:2DB"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ-#D*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^1&5S8W)I7W!T:6]N
M/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^0F5S:W)I=F5L<V4\
M+V(^("AV86QG9G)I*2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(W
M-PHC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY+97EW;W)D<SPO<W1R;VYG/B`H
M;W!T:6]N86PI(@IM<V=S='(@(CQB/D[X9VQE;W)D/"]B/B`H=F%L9V9R:2DB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.30*(RP@9G5Z>GD*;7-G
M:60@(CQS=')O;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H;W!T:6]N86PI(@IM
M<V=S='(@(CQB/D=E;G1A9V5L<V4\+V(^("AO<'1I;VYA;"DB"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P,2!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$X,0IM<V=I9"`B04TB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3DQ"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,3$*;7-G:60@(D%D7W9A;F-E
M9"!396%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ-C$@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ.3`*;7-G:60@(D%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR-@IM<V=I9"`B061D($5V96YT(@IM<V=S='(@(E1I;&;X
M:B!!9G1A;&4B"@HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA
M9V5M96YT+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B061D(&$@;F5W(%)E;6]T
M92!#86QE;F1A<B(*;7-G<W1R(")4:6QF^&H@;GD@869T86QE(@H*(SH@861D
M979E;G0N<&AP.C8T"FUS9VED(")!9&0@82!N97<@979E;G0B"FUS9W-T<B`B
M5&EL9OAJ(&YY(&%F=&%L92(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T
M96YD965S+FEN8SHW-`IM<V=I9"`B061D(&%T=&5N9&5E<R(*;7-G<W1R("(B
M"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ,C`*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C<X"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R8V@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3,*;7-G
M:60@(D%L87)M(@IM<V=S='(@(D%L87)M(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!D87ES(&)E9F]R
M92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D%L87)M("5D(&AO=7)S(&)E9F]R92(*;7-G<W1R("(B
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!;&%R;2`E9"!M:6YU=&5S(&)E9F]R92(*;7-G<W1R(")-:6YU
M='1E<B!I;F1E;B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06QA<FT@)60@=V5E:W,@8F5F;W)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C,*;7-G:60@(D%L87)M(#$@9&%Y(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8X"FUS9VED
M(")!;&%R;2`Q(&AO=7(@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$W-S,*(RP@9G5Z>GD*;7-G:60@(D%L87)M(#$@;6EN=71E(&)E
M9F]R92(*;7-G<W1R(")-:6YU='1E<B!I;F1E;B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$W-3@*;7-G:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z-C`*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T<B`B
M06QA<FT@1&%T;R(*"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!3<&%N
M("AM:6YU=&5S*2(*;7-G<W1R(")!;&%R;2!687)I9VAE9"`H;6EN=71T97(I
M(@H*(SH@9&%T82YP:'`Z-C$*;7-G:60@(D%L87)M(%1I;64B"FUS9W-T<B`B
M06QA<FT@5&ED(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,Q
M"FUS9VED(")!;&PB"FUS9W-T<B`B06QL92(*"B,Z(&QI8B]&0E9I97<N<&AP
M.C$R-B!L:6(O1D)6:65W+G!H<#HQ,CD@;&EB+T9"5FEE=RYP:'`Z,3,R"B,L
M(&9U>GIY"FUS9VED(")!;&P@071T96YD965S(@IM<V=S='(@(D%L;&4@869T
M86QE<B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU.0HC+"!F
M=7IZ>0IM<V=I9"`B06QL($9U='5R92(*;7-G<W1R(")&<F5M=&ED:6<B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*(RP@9G5Z>GD*;7-G
M:60@(D%L;"!087-T(@IM<V=S='(@(DAE;&4@9&%G96XB"@HC.B!L:6(O0FQO
M8VLO<')E=FUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L;V-K+VUO;G1H+G!H<#HR
M-`HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,C4*;7-G:60@(D%L;"!6:7-I8FQE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,B!L:6(O1&%Y
M5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.CDS"B,Z(&QI8B]7965K5FEE
M=RYP:'`Z,3(W(&QI8B]7965K5FEE=RYP:'`Z,3,T(&QI8B]$<FEV97(N<&AP
M.C$X,S(*;7-G:60@(D%L;"!D87DB"FUS9W-T<B`B2&5L92!D86=E;B(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@979E
M;G0B"FUS9W-T<B`B2&5L961A9W-A9G1A;&4B"@HC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C(Q"FUS9VED(")!;&P@979E;G1S(@IM<V=S='(@(D%L
M;&4@869T86QE<B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHT.0HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E
M9"YI;F,Z-S$@;&EB+TMR;VYO;&ET:"YP:'`Z-C@S"FUS9VED(")!;GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S$*
M;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z,SD@=&5M<&QA=&5S+V5D:70O961I=%]T
M:6UE<W!A;BYI;F,Z.3,*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHW
M,"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U-@IM<V=I9"`B070B"FUS
M9W-T<B`B2VPN(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R-@IM<V=I9"`B
M(@HB071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@=VET:"!M;W)E(&EN
M9F]R;6%T:6]N(&%B;W5T('1H92!E=F5N="X@268@>6]U<B`B"B)M86EL(&-L
M:65N="!S=7!P;W)T<R!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E('1H:7,@
M9FEL92!T;R!E87-I;'D@=7!D871E("(*(GEO=7(@;&]C86P@8V]P>2!O9B!T
M:&4@979E;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHT,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C4*
M;7-G:60@(D%T=&5N9&%N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,38Q"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S4*;7-G:60@(D%U
M9W5S="(*;7-G<W1R(")!=6=U<W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:%]A9'9A;F-E9"YI;F,Z,3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C@*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D)I<G1H9&%Y(@IM<V=S
M='(@(D;X9'-E;'-D86<B"@HC.B!L:6(O1D)6:65W+G!H<#HY,"!L:6(O1D)6
M:65W+G!H<#HQ,3`*;7-G:60@(D)U<WDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0T"B,L(&9U>GIY"FUS
M9VED(")#7V%L96YD87(B"FUS9W-T<B`B26UP;W)TZ7(@2V%L96YD97(B"@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHT.0HC+"!F=7IZ>0IM<V=I9"`B
M0V%L7V5N9&%R(@IM<V=S='(@(DEM<&]R=.ER($MA;&5N9&5R(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$T-B!L:6(O0FQO8VLO
M<')E=FUO;G1H;&ES="YP:'`Z,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HR
M,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,C(*(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DEM
M<&]R=.ER($MA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*
M(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R(%-U;6UA<GDB"FUS9W-T<B`B26YD
M:&]L9"(*"B,Z(&1A=&$N<&AP.C(R.`HC+"!F=7IZ>0IM<V=I9"`B0V%L96YD
M87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS9W-T<B`B:4-A;&5N9&%R(&9I
M;"!S=6-C97-S9G5L9'0@:6UP;W)T97)E="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-PHC
M+"!F=7IZ>0IM<V=I9"`B0V%L96YD87)S(@IM<V=S='(@(DEM<&]R=.ER($MA
M;&5N9&5R(@H*(SH@8V%L96YD87)S+G!H<#HR-PIM<V=I9"`B0V%L96YD87)S
M(&UU<W0@:&%V92!A(&YA;64N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(T
M,PHC+"!F=7IZ>0IM<V=I9"`B0V%N)W0@8W)E871E(&$@;F5W(&5V96YT+B(*
M;7-G<W1R(")/<')E="!.>2!!9G1A;&4B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$Y,2!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z
M,S`*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,R('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C,P.0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%N;G5L;&5R(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z-3<P"B,L(&9U>GIY"FUS9VED(")#86YC96QL960B
M"FUS9W-T<B`B06YN=6QL97(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#`Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YC96QL960Z("5S(@IM
M<V=S='(@(D%N;G5L;&5R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.C8T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C8Y"B,L
M(&9U>GIY"FUS9VED(")#871E9V]R7WDB"FUS9W-T<B`B2V%T96=O<FDB"@HC
M.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N
M:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*;7-G:60@(D-A=&5G
M;W)Y(@IM<V=S='(@(DMA=&5G;W)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(W.0IM<V=I9"`B(@HB0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO
M=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',@8GD@
M(@HB96UA:6PZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO=&EF:65D
M(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96%R8VA?86)O;VM?<V5L96-T+FEN
M8SHQ.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDY"FUS9VED(")#:&]O<V4@
M=&AE(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H(&9O<B!F<F5E+V)U<WD@55),
M<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V9B7V-A;'-?<V5L
M96-T+FEN8SHQ-@IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC
M;'5D92!I;B!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;CHB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,0IM<V=I9"`B0VAO;W-E
M('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!W:&5N(&=E;F5R871I;F<@9G)E
M92]B=7-Y(%523',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.`IM<V=I9"`B0VAO;W-E('EO=7(@9&5F875L="!C86QE;F1A<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C8U"FUS9VED(")#;&5A<B!A;&P@871T96YD965S(@IM<V=S='(@(B(*
M"B,Z(&1A=&$N<&AP.C(X('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3,*
M;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S"FUS9VED(")#;VYF:7)M(&1E;&5T
M:6]N(&]F(&5V96YT<S\B"FUS9W-T<B`B0F5K<N9F="!A;FYU;&QE<FEN9R!A
M9B!A9G1A;&5R/R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4V-PIM<V=I9"`B
M0V]N9FER;65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHR,#@*;7-G:60@(D-O<'D@=&AE(%523"!B96QO=R!F
M;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y(%523#HB
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,38R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3(V"B,L(&9U
M>GIY"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B06MT=65L(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q,@HC+"!F=7IZ>0IM<V=I
M9"`B0W)E871E($-A;&5N9&%R(@IM<V=S='(@(DEM<&]R=.ER($MA;&5N9&5R
M(@H*(SH@;6]N=&@N<&AP.C$V-2!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHR
M-2!T96UP;&%T97,O9&%Y+W)O=RYI;F,Z-@HC.B!L:6(O1&%Y5FEE=RYP:'`Z
M.3`@;&EB+T1A>59I97<N<&AP.C$Y-`IM<V=I9"`B0W)E871E(&$@3F5W($5V
M96YT(@IM<V=S='(@(D]P<F5T($YY($%F=&%L92(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C@P"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR.0IM<V=I9"`B0W5R<F5N
M="(*;7-G<W1R(")!:W1U96PB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`Y"FUS9VED(")$86EL
M>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(D1A9VQI9SH@1V5N=&%G97,@:'9E
M<B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$P(&QI8B]+<F]N;VQI=&@N<&AP.C$R
M.#@@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@R"FUS9VED(")$87DB"FUS9W-T<B`B1&%G(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,3,Y"FUS9VED(")$87DH<RDB"FUS9W-T<B`B1&%G*&4I(@H*(SH@=FEE
M=V5V96YT+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D1E7VQE=&4B"FUS9W-T
M<B`B4VQE="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Y
M"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$96-E;6)E<B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C4Y-`IM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W"B,L(&9U>GIY"FUS9VED(")$
M969A=6QT($-A;&5N9&%R(@IM<V=S='(@(DEM<&]R=.ER($MA;&5N9&5R(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,R!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X,0HC.B!T96UP;&%T97,O
M9&5L971E+V]N92YI;F,Z,CD@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?
M;6%N86=E;65N="YI;F,Z,C,*(SH@;&EB+T1R:79E<BYP:'`Z,3@Q,PIM<V=I
M9"`B1&5L971E(@IM<V=S='(@(E-L970B"@HC.B!D96QE=F5N="YP:'`Z-#`@
M=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C$X('1E;7!L871E<R]D96QE=&4O
M9&5L971E+FEN8SHQ.`HC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R(")3;&5T("5S(@H*(SH@
M961I=&5V96YT+G!H<#HW,`IM<V=I9"`B1&5L971E($5V96YT(@IM<V=S='(@
M(E-L970@069T86QE(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC
M.C(W"FUS9VED("(B"B)$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL>2P@
M=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L(&]R
M("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R("(B"B)3;&5T(&MU;B!D96YN
M92!A9G1A;&4L(&1E;FYE(&]G(&%L;&4@=&EL:/AR96YD92!F<F5M=&ED:6=E
M(&%F=&%L97(L(&5L;&5R("(*(F%L;&4@=&EL:/AR96YD92!A9G1A;&5R/R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,#0@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X"B,L(&9U>GIY"FUS9VED
M(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B0F5S:W)I=F5L<V4B"@HC.B!D871A
M+G!H<#HV,B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<U
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.CDV"FUS9VED(")$97-C<FEP
M=&EO;B(*;7-G<W1R(")"97-K<FEV96QS92(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,3<S"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y
M(@IM<V=S='(@(DEN9'-T:6QL:6YG97)N92!F;W(@=FES;FEN9R(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHV,`HC+"!F=7IZ>0IM
M<V=I9"`B1&ES<&QA>2!#86QE;F1A<G,B"FUS9W-T<B`B26YD<W1I;&QI;F=E
M<FYE(&9O<B!V:7-N:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(DEN9'-T:6QL
M:6YG97)N92!F;W(@=FES;FEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@<VAO=R!T87-K<R!W:&EC:"!A
M<F4@9'5E(&]N('EO=7(@8V%L96YD87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C4S-PIM<V=I9"`B1&]E<R!N;W0@<F5C=7(B"FUS9W-T
M<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,S(U"B,L('!H<"UF;W)M870*
M;7-G:60@(D1U93H@)7,B"FUS9W-T<B`B1F]R9F%L9&5N.B`E<R(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R
M871I;VXB"FUS9W-T<B`B5F%R:6=H960B"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,3<P(&QI8B]$<FEV97(N<&AP.C$X,#8*;7-G
M:60@(D5D:70B"FUS9W-T<B`B4F5T(@H*(SH@961I=&5V96YT+G!H<#HS,R!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR-B!L:6(O1')I=F5R+G!H<#HQ.#`V
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@)7,B"FUS9W-T<B`B4F5T("5S
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@W"FUS9VED(")%9&ET
M($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z,30P"B,L(&9U>GIY"FUS9VED(")%9&ET($-A;&5N
M9&%R<R(*;7-G<W1R(")%:W-P;W)TZ7(@2V%L96YD97(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C4P"B,L(&9U>GIY"FUS9VED(")%9&ET(%)E;6]T
M92!#86QE;F1A<G,B"FUS9W-T<B`B26UP;W)TZ7(@2V%L96YD97(B"@HC.B!A
M='1E;F1E97,N<&AP.C$U,`IM<V=I9"`B161I="!A='1E;F1E97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N9"YI;F,Z,C`*;7-G
M:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-C`*(RP@
M9G5Z>GD*;7-G:60@(D5N7V0B"FUS9W-T<B`B4VQU='1E<B!D96XB"@HC.B!D
M871A+G!H<#HU-PIM<V=I9"`B16YD($1A=&4B"FUS9W-T<B`B4VQU='1E<B!D
M96XB"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C@@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ,#@*;7-G:60@(D5N9"!/;B(*;7-G<W1R(")3;'5T=&5R
M(&1E;B(*"B,Z(&1A=&$N<&AP.C4X"FUS9VED(")%;F0@5&EM92(*;7-G<W1R
M(")3;'5T=&5R($ML+B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3(T(&%T=&5N9&5E
M<RYP:'`Z,3,U(&%T=&5N9&5E<RYP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O
M<B`E<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y
M,PIM<V=I9"`B179E;G0@861D960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$Q,#,*;7-G:60@(D5V96YT(&1E;&5T960Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3@*;7-G:60@(D5V96YT(&5D
M:71E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`V-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%=F5N="!F<F]M("5S('1O("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V-`HC+"!F=7IZ>0IM<V=I9"`B179E
M;G1S(&UU<W0@:&%V92!A('-T87)T(&1A=&4N(@IM<V=S='(@(E-L=71D871O
M('-K86P@=N9R92!S96YE<F4@96YD('-T87)T9&%T;RXB"@HC.B!L:6(O1')I
M=F5R+G!H<#HW,S`*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@82!T:71L92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S8W"FUS9VED(")%=F5N
M=',@;75S="!H879E(&%N(&5N9"!D871E(&]R(&$@9'5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHW
M.0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(E-L=71T
M97(@2VPN(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ.#<*;7-G
M:60@(D5X<&]R="(*;7-G<W1R(")%:W-P;W)TZ7(B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R="!#86QE;F1A<B(*;7-G
M<W1R(")%:W-P;W)TZ7(@2V%L96YD97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]G;W1O+FEN8SHV.0IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B
M<G5A<B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(X
M"B,L(&9U>GIY"FUS9VED(")&:6YD(@IM<V=S='(@(D9R961A9R(*"B,Z('EE
M87(N<&AP.C@W('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8S('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,@HC.B!L:6(O0FQO8VLO;6]N=&@N
M<&AP.C$P-0IM<V=I9"`B1G(B"FUS9W-T<B`B1G)E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U<WD@26YF
M;W)M871I;VXB"FUS9W-T<B`B1&EN($EN9F]R;6%T:6]N(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C(P('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q.0HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,@IM<V=I
M9"`B1G)I9&%Y(@IM<V=S='(@(D9R961A9R(*"B,Z('1E;7!L871E<R]D96QE
M=&4O9&5L971E+FEN8SHS,`IM<V=I9"`B1G5T=7)E(@IM<V=S='(@(D9R96UT
M:61I9R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B
M1V%M92(*;7-G<W1R(")3<&EL(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8VA?861V86YC960N:6YC.C(S"FUS9VED(")'96YE<F%L(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`B1^4@5&EL(@H*(SH@;6]N
M=&@N<&AP.C$S-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z
M,3`*;7-G:60@(DAI9&4B"FUS9W-T<B`B(@H*(SH@;6]N=&@N<&AP.C$S-2!T
M96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M
M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DAI9&4@)7,B"FUS9W-T<B`B5FES("5S(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C4@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,3,X"FUS9VED(")(;W5R*',I(@IM<V=S='(@(E1I;64H<BDB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,L(&9U>GIY"FUS9VED
M(")(;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO=',@;VX@=&AE(&1A>2!A
M;F0@=V5E:R!V:65W<R!B93\B"FUS9W-T<B`B5FES(&AA;'8@=&EM97,@<N9K
M:V5R(&D@9&%G(&]G('5G92!O=F5R<VEG=&5R/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.#@*;7-G:60@(DAO=R!M86YY(&1A>7,@;V8@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N('-H;W5L9"!W92!G96YE<F%T93\B"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B))9B!Y;W5R(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O<G0@
M:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@;V8@=&AE("(*(F9O;&QO
M=VEN9R!L:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N7&XB
M"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB"B)4
M;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*(EQN
M(@HB5&\@9&5C;&EN92!T:&4@979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="!#86QE;F1A<BP@4W1E<"`E9"(*;7-G<W1R
M("));7!O<G3I<B!+86QE;F1E<B(*"B,Z(&1A=&$N<&AP.C,R,`IM<V=I9"`B
M26UP;W)T+T5X<&]R="!#86QE;F1A<B(*;7-G<W1R("));7!O<G3I<B]%:W-P
M;W)TZ7(@2V%L96YD97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHV.`IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YU87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-`IM<V=I9"`B2G5L>2(*
M;7-G<W1R(")*=6QI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-S,*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z(&1A=&$N<&AP
M.C8U('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$T,@IM<V=I9"`B2V5Y=V]R
M9',B"FUS9W-T<B`B3OAG;&5O<F1E<B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R-"!H;W5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHX-PIM<V=I9"`B3&%S="!-
M;V1I9FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C0*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED
M95]B>5]S:61E+FEN8SHQ,`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C$V('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHT"B,L
M(&9U>GIY"FUS9VED("),87-T($UO;G1H(@IM<V=S='(@(E-I9'-T92!MY6YE
M9"(*"B,Z('1E;7!L871E<R]Y96%R+VAE860N:6YC.C0*(RP@9G5Z>GD*;7-G
M:60@(DQA<W0@665A<B(*;7-G<W1R(")3:61S=&4@=6=E(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C4T('1E;7!L871E<R]W965K+VAE860N
M:6YC.C,*;7-G:60@(DQA<W0@=V5E:R(*;7-G<W1R(")3:61S=&4@=6=E(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-PIM<V=I9"`B3&EM:70@
M=&AE('1I;64@<W!A;B!T;R!E>'!O<G0Z(@IM<V=S='(@(D)E9W+F;G,@=&ED
M<W)U;6UE="!F;W(@9&EN(&5K<W!O<G0Z(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8VA?861V86YC960N:6YC.C@V('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C<V"B,L(&9U>GIY"FUS9VED("),;U]C871I;VXB"FUS9W-T<B`B4W1E
M9"(*"B,Z(&1A=&$N<&AP.C8T('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A
M9&5R<RYI;F,Z-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA
M9V5M96YT+FEN8SHQ.`HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M
M86YA9V5M96YT+FEN8SHU,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR,0HC
M.B!L:6(O1')I=F5R+G!H<#HQ.#0Y"FUS9VED("),;V-A=&EO;B(*;7-G<W1R
M(")3=&5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U"FUS9VED(")-
M86YA9V4@<F5M;W1E(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S`*;7-G:60@(DUA<F-H(@IM<V=S
M='(@(DUA<G1S(@H*(SH@;&EB+V%P:2YP:'`Z,3`P"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!%=F5N=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R(")-86HB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0V"FUS9VED(")-92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(DUE971I
M;F<B"FUS9W-T<B`B3?AD92(*"B,Z(&QI8B]";&]C:R]T<F5E7V%L87)M<RYP
M:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!!;&%R;7,B"FUS9W-T<B`B06QA
M<FTB"@HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU
M($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M-C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3,W"FUS9VED(")-:6YU=&4H
M<RDB"FUS9W-T<B`B36EN=70H=&5R*2(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N
M=&AL:7-T+G!H<#HT,@IM<V=I9"`B36ES<V5D($5V96YT<R!,:7-T(@IM<V=S
M='(@(B(*"B,Z('EE87(N<&AP.C@S('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C4Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.`HC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B36\B"FUS9W-T<B`B36%N(@H*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$V('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$Q-0HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN
M8SHV."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"FUS9VED(")-;VYD87DB
M"FUS9W-T<B`B36%N9&%G(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,2!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S='(@(DWE;F5D(@H*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-;VYT:"!6:65W(@IM
M<V=S='(@(DWE;F5D(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,R!L
M:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT,PIM<V=I9"`B36]N=&AL>2!%=F5N
M=',@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(R.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,S4*;7-G:60@(DUO;G1H;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")-Y6YE
M9&QI9SH@1V5N=&%G97,@:'9E<B(*"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N
M<&AP.C(T"FUS9VED(")-;VYT:',@06AE860B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(T"B,L(&9U>GIY"FUS9VED(")-
M;VYT:',@0F5F;W)E(@IM<V=S='(@(DUI;G5T=&5R(&EN9&5N(@H*(SH@;&EB
M+V%P:2YP:'`Z-C$R"FUS9VED(")-=6QT:7!L92!I0V%L96YD87(@8V]M<&]N
M96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT(&ES('-U<'!O<G1E9"XB"FUS
M9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HQ,C@@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]C86QE;F1A<G,N:6YC.C8W"B,L(&9U>GIY"FUS9VED(")->2!#86QE
M;F1A<G,B"FUS9W-T<B`B26UP;W)TZ7(@2V%L96YD97(B"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,S0@=&5M<&QA=&5S+VUE;G4N:6YC.C,V"B,L(&9U>GIY
M"FUS9VED(")->2!#86QE;F1A<G,Z(@IM<V=S='(@(D5K<W!O<G3I<B!+86QE
M;F1E<B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR
M,#0*;7-G:60@(DUY($9R964O0G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Q-R!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34Y"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,3<U"B,Z('1E;7!L871E<R]P<F5F<R]R96UO
M=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$W"B,Z('1E;7!L871E<R]P<F5F<R]R
M96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C0T"B,L(&9U>GIY"FUS9VED(").
M86UE(@IM<V=S='(@(E-P:6PB"@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C0Q
M(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0T(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HT,0HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,`IM<V=I9"`B
M3F5W($5V96YT(@IM<V=S='(@(DYY($%F=&%L92(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B3N9S=&4@9&%G(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M0E9I97<O9&%Y+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3F5X="!$87DB"FUS
M9W-T<B`B3N9S=&4@9&%G(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED
M95]B>5]S:61E+FEN8SHV"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?
M8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ."!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z-@IM<V=I
M9"`B3F5X="!-;VYT:"(*;7-G<W1R(").YG-T92!-Y6YE9"(*"B,Z(&QI8B]&
M0E9I97<O=V5E:RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(DYE>'0@5V5E:R(*
M;7-G<W1R(").YG-T92!U9V4B"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN
M8SHV"B,L(&9U>GIY"FUS9VED(").97AT(%EE87(B"FUS9W-T<B`B3N9S=&4@
M9&%G(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT
M(&1A>2(*;7-G<W1R(").YG-T92!D86<B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM<V=I
M9"`B3F5X="!W965K(@IM<V=S='(@(D[F<W1E('5G92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-S4*(RP@9G5Z>GD*;7-G:60@(DYO(@IM<V=S='(@
M(DEN9V5N(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S,@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3(V"B,L(&9U>GIY"FUS9VED(").;R!A;&%R
M;2(*;7-G<W1R(")!;&%R;2(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T
M96YD965S+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B3F\@871T96YD965S(@IM
M<V=S='(@(DEN9V5N('-L=70@9&%T;R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$S,3$*;7-G:60@(DYO(&-A;&5N9&%R<R!A<F4@879A:6QA8FQE('1O(&=U
M97-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3,V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(U-0IM<V=I9"`B3F\@96YD
M(&1A=&4B"FUS9W-T<B`B26YG96X@<VQU="!D871O(@H*(SH@;&EB+T)L;V-K
M+W!R979M;VYT:&QI<W0N<&AP.C$V-"!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H
M<#HQ-C,*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y-`IM<V=I9"`B3F\@
M979E;G1S('1O(&1I<W!L87DB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4O
M:V]L86(N<&AP.C0S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C,T-"!L:6(O87!I+G!H<#HV,#(*;7-G:60@(DYO
M(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C`T"B,L(&9U>GIY"FUS9VED(").;R!R
M96-U<G)E;F-E(@IM<V=S='(@(D=E;G1A9V5L<V4@1&%T82(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C@X-@IM<V=I9"`B3F\@=F%L:60@96UA:6P@861D<F5S
M<R!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,#$@
M;&EB+TMR;VYO;&ET:"YP:'`Z-C(R"FUS9VED(").;VYE(@IM<V=S='(@(DEN
M9V5N(@H*(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ,S8*;7-G:60@(DYO="!F
M;W5N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*
M(RP@9G5Z>GD*;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`B4W1E9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<X"FUS9VED(").
M;W9E;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHU-@IM<V=I9"`B3F]W(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<W"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(D]K=&]B97(B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHQ,R!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN
M8SHV-0IM<V=I9"`B3VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(W.`IM<V=I9"`B3VX@86QL(&-A;&5N9&%R<R!)(&AA=F4@<F5A
M9"!A8V-E<W,@=&\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(W-PIM<V=I9"`B3VX@86QL('-H;W=N(&-A;&5N9&%R<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<V"FUS9VED(")/;B!M
M>2!C86QE;F1A<G,@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HV,3D*(RP@9G5Z>GD*;7-G:60@(D]P=&EO;F%L(@IM<V=S='(@(DEN
M9'-T:6QL:6YG97(B"@HC.B!L:6(O1D)6:65W+G!H<#HQ,3@*;7-G:60@(D]P
M=&EO;F%L($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!L:6(O1D)6:65W+G!H
M<#HQ-3(*;7-G:60@(D]V97)V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C,T"FUS9VED(")/=VYE<B(*;7-G<W1R("(B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ.#0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")/=VYE<CH@)7,B"FUS9W-T<B`B1F]R9F%L9&5N.B`E<R(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`R('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,3@R"FUS9VED(")032(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HR.2!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T"B,L(&9U>GIY"FUS
M9VED(")086QM($1A=&5";V]K(@IM<V=S='(@(D%L87)M($1A=&\B"@HC.B!L
M:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,PIM<V=I9"`B4&%S="!%=F5N
M=',@3&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,#D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DX"FUS9VED(")0871T
M97)N(@IM<V=S='(@(D9R96MV96YS(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O
M;F4N:6YC.C(W"FUS9VED(")097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N
M=#\B"FUS9W-T<B`B4VQE="!D96YN92!A9G1A;&4@=6EG96YK86QD96QI9W0_
M(@H*(SH@;&EB+V%P:2YP:'`Z,S(U(&QI8B]A<&DN<&AP.C0Q.2!L:6(O87!I
M+G!H<#HT.#$@;&EB+V%P:2YP:'`Z-34S"B,Z(&QI8B]A<&DN<&AP.C4X-"!L
M:6(O87!I+G!H<#HV-S`@;&EB+V%P:2YP:'`Z-S`V"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z,38W"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N
M<R(*;7-G<W1R(")097)S;VYL:6<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C$*(RP@9G5Z>GD*;7-G:60@(E!O<G1A;"!/<'1I;VYS(@IM<V=S='(@
M(D)R=6=E<FEN9'-T:6QL:6YG97(B"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z
M,C4*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S($1A>2(*;7-G<W1R(")&;W)E
M9^5E;F1E(&1A9R(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*(RP@9G5Z
M>GD*;7-G:60@(E!R979I;W5S(%=E96LB"FUS9W-T<B`B1F]R96?E96YD92!D
M86<B"@HC.B!T96UP;&%T97,O9&%Y+VAE860N:6YC.C,*;7-G:60@(E!R979I
M;W5S(&1A>2(*;7-G<W1R(")&;W)E9^5E;F1E(&1A9R(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M-3(*;7-G:60@(E)E8W5R(%5N=&EL(@IM<V=S='(@(D=E;G1A9V5S('1I;"(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$P-@HC+"!F=7IZ>0IM<V=I
M9"`B4F5C=7)R96YC92(*;7-G<W1R(")'96YT86=E;'-E($1A=&$B"@HC.B!D
M871A+G!H<#HV.0IM<V=I9"`B4F5C=7)R96YC92!$871A(@IM<V=S='(@(D=E
M;G1A9V5L<V4@1&%T82(*"B,Z(&1A=&$N<&AP.C8W"FUS9VED(")296-U<G)E
M;F-E($5N9"!$871E(@IM<V=S='(@(D=E;G1A9V5L<V4@4VQU="!$871O(@H*
M(SH@9&%T82YP:'`Z-C@*;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS
M9W-T<B`B1V5N=&%G96QS92!);G1E<G9A;"(*"B,Z(&1A=&$N<&AP.C8V"FUS
M9VED(")296-U<G)E;F-E(%1Y<&4B"FUS9W-T<B`B1V5N=&%G96QS92!4>7!E
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30P"FUS9VED(")296-U<G,@9&%I
M;'DB"FUS9W-T<B`B1V5N=&%G97,@9&%G;&EG="(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C4T-PIM<V=I9"`B4F5C=7)S(&UO;G1H;'DB"FUS9W-T<B`B1V5N
M=&%G97,@;>5N961L:6=T(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30S"FUS
M9VED(")296-U<G,@=V5E:VQY(@IM<V=S='(@(D=E;G1A9V5S('5G96YT;&EG
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34P"FUS9VED(")296-U<G,@>65A
M<FQY(@IM<V=S='(@(D=E;G1A9V5S(.5R;&EG="(*"B,Z(&QI8B]38VAE9'5L
M97(O:W)O;F]L:71H+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M
M:6YD97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHY,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B26UP;W)T
MZ7(@2V%L96YD97(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-C`@=&5M<&QA
M=&5S+VUE;G4N:6YC.C8R"B,L(&9U>GIY"FUS9VED(")296UO=&4@0V%L96YD
M87)S.B(*;7-G<W1R("));7!O<G3I<B!+86QE;F1E<B(*"B,Z('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHU,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296UO=F4@)7,B"FUS9W-T<B`B(@H*(SH@871T96YD965S+G!H<#HQ
M,#0*;7-G:60@(E)E;6]V92!!='1E;F1E92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C,R"FUS9VED("(B"B)297!L86-E(&5X
M:7-T:6YG(&-A;&5N9&%R('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N
M9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U
M<B!C=7)R96YT(&-A;&5N9&%R+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HV,C8*;7-G:60@(E)E<75I<F5D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&0E9I97<N<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S-R!L
M:6(O1D)6:65W+G!H<#HQ-#`@;&EB+T9"5FEE=RYP:'`Z,30S"FUS9VED(")2
M97%U:7)E9"!!='1E;F1E97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S$P"FUS
M9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R(")4:6QB86=E('1I;"!S
M=&%N9&%R9&EN9'-T:6QL:6YG97(B"@HC.B!T96UP;&%T97,O871T96YD965S
M+V%T=&5N9&5E<RYI;F,Z-#,@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38V
M"FUS9VED(")297-P;VYS92(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX."!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV-"!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,C,*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G
M:60@(E-A(@IM<V=S='(@(DSX<B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D
M+FEN8SHR,2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C`*(SH@=&5M<&QA
M=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S,*;7-G:60@(E-A='5R9&%Y(@IM
M<V=S='(@(DSX<F1A9R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`B3/AR
M(@H*(SH@=FEE=V5V96YT+G!H<#HQ,3@@961I=&5V96YT+G!H<#HT."!E9&ET
M979E;G0N<&AP.C4V"FUS9VED(")3879E($%S($YE=R(*;7-G<W1R(")'96T@
M<V]M(&YY(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC
M.C@W"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!A9&1E
M=F5N="YP:'`Z-34@961I=&5V96YT+G!H<#HU,0IM<V=I9"`B4V%V92!%=F5N
M="(*;7-G<W1R(")'96T@869T86QE(@H*(SH@<V5A<F-H+G!H<#HY,2!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$U"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHV-R!T96UP;&%T97,O8V%L96YD87)S
M+W-E87)C:"YI;F,Z.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$T,"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-@HC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H(@IM<V=S='(@(DUA<G1S(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]S96%R8V@N:6YC.C$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!#
M86QE;F1A<G,B"FUS9W-T<B`B26UP;W)TZ7(@2V%L96YD97(B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-@IM<V=I9"`B4V5A<F-H(%)E<W5L
M=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N
M:6YC.C8*;7-G:60@(E-E87)C:"!F;W(@8V%L96YD87)S(&-O;G1A:6YI;F<Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHQ-3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&-A;&5N9&%R('1O
M(&5D:70B"FUS9W-T<B`B5N9L9R!F:6P@=&EL(&EM<&]R=&5R:6YG.B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V."!T96UP;&%T97,O961I="]E
M9&ET7W1I;65S<&%N+FEN8SHS,0HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHX,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*
M;7-G<W1R(")3=&%R="!D871O(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,P
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@8V%L96YD87)S('1O(&1I<W!L87DZ
M(@IM<V=S='(@(E;F;&<@:'9O<F1A;B!M86X@=FES97(@9&%T;V5R.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B(@HB4V5L96-T(&-O
M;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R
M96YT('9I97=S(&%N9"!C:&]O<V4@(@HB9&5F875L="!V:65W+B(*;7-G<W1R
M("(B"B)6YFQG(&)E:W+F9G1E;'-E<BP@:'9O<F1A;B!M86X@=FES97(@9F]R
M<VME;&QI9V4@;W9E<G-I9W1E<BP@;V<@=N9L9R`B"B)S=&%N9&%R9&]V97)S
M:6=T96XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ.0HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C86QE;F1A<B!T;R!I;7!O<G0@=&\Z
M(@IM<V=S='(@(E;F;&<@9FEL('1I;"!I;7!O<G1E<FEN9SHB"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E;F;&<@:VEL9&4@870@
M:6UP;W)T97)E(&9R83HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C(X"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R
M(")6YFQG(&9I;"!T:6P@:6UP;W)T97)I;F<Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-`IM<V=I9"`B4V5L96-T('1H92!F:7)S="!W965K9&%Y
M.B(*;7-G<W1R(")6YFQG(&;X<G-T92!U9V5D86<Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H
M92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")6YFQG(&9O
M<FUA="!A="!E:W-P;W)T97)E('1I;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3@T"FUS9VED(")396QE8W0@=&AE('1I;64@<W!A;B!T;R!S:&]W
M.B(*;7-G<W1R(")6YFQG('1I9'-V87)I9VAE9"!D97(@<VMA;"!V:7-E<SHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N('-T87)T=7`Z(@IM<V=S
M='(@(E;F;&<@;W9E<G-I9W0@9&5R('9I<V5S(&5F=&5R(&QO9VEN.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H92!P;W)T86PN(@IM<V=S
M='(@(E;F;&<@:'9I;&ME(&%F=&%L97(@9&5R('-K86P@=FES97,@:2!O=F5R
M<VEG=&5N+B(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR-"!T96UP
M;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C0*;7-G:60@(E-E;F0@82!C86YC
M96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E;F1E97,@=VAE;B!D96QE=&EN
M9R!T:&ES(&5V96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")396YD(&%N(&5M86EL
M('1O("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$X,0IM<V=I9"`B4V5N9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L;"!A
M='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-@IM<V=I9"`B4V5P
M=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)E<B(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS9VED(")3970@96YD
M(&1A=&4B"FUS9W-T<B`B26YG96X@<VQU="!D871O(@H*(SH@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C8X"B,L(&9U>GIY"FUS9VED(")3970@<F5C=7)R
M96YC92!E;F0@9&%T92(*;7-G<W1R(")'96YT86=E;'-E(%-L=70@1&%T;R(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,L(&9U
M>GIY"FUS9VED(")3970@<W1A<G0@9&%T92(*;7-G<W1R(")3=&%R="!D871O
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y"FUS9VED("(B"B)3970@
M>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H
M97(@=7-E<G,G(&9R964O8G5S>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C
M86QE;F1A<G,N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(E-H87)E(&YO
M="!F;W5N9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C<Y"B,L(&9U>GIY"FUS9VED(")3:&%R960@0V%L
M96YD87)S(@IM<V=S='(@(DEM<&]R=.ER($MA;&5N9&5R(@H*(SH@=&5M<&QA
M=&5S+VUE;G4N:6YC.C0W('1E;7!L871E<R]M96YU+FEN8SHT.0HC+"!F=7IZ
M>0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R<SHB"FUS9W-T<B`B16MS<&]R=.ER
M($MA;&5N9&5R(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H<#HR-2!T96UP;&%T
M97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC.B!T96UP;&%T97,O
M9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHS"B,L(&9U>GIY"FUS9VED(")3
M:&]W($-A;&5N9&%R(@IM<V=S='(@(D5K<W!O<G3I<B!+86QE;F1E<B(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHR,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3:&]W(&-A;&5N9&%R(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34V"FUS9VED(")3:&]W(&-A=&5G
M;W)Y(&QE9V5N9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T-@IM<V=I9"`B4VAO=R!D96QE=&4L(&%L87)M+"!A;F0@<F5C=7)R
M96YC92!I8V]N<R!I;B!C86QE;F1A<B!V:65W<S\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S
M:W,@:6X@=&AE(&-A;&5N9&%R/R(*;7-G<W1R(")6:7,@9F]R969A;&1E;F1E
M(&]P9V%V97(@:2!K86QE;F1E<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,38V"FUS9VED(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@(E-H;W<@
M;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS9W-T<B`B
M5FES(&MU;B!A9G1A;&5R('-O;2!E<B!M960@86QA<FT_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$W-0IM<V=I9"`B4VAO=R!S:&%R960@8V%L96YD
M87)S('-I9&4M8GDM<VED93\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T87-K<R!U<VEN
M9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(E9I<R!F;W)E9F%L9&5N9&4@
M;W!G879E<B!I(&MA;&5N9&5R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:6UE(&]F(&1A>2!B971W965N
M(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_(@IM<V=S='(@(E9I<R!H86QV('1I
M;65S('+F:VME<B!I(&1A9R!O9R!U9V4@;W9E<G-I9W1E<C\B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4W1A7W)T(@IM<V=S='(@(E-T87)T(&1E;B(*"B,Z(&1A=&$N<&AP.C4U
M"FUS9VED(")3=&%R="!$871E(@IM<V=S='(@(E-T87)T(&1A=&\B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C<@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHR-0IM<V=I9"`B4W1A<G0@3VXB"FUS9W-T<B`B4W1A<G0@9&5N(@H*(SH@
M9&%T82YP:'`Z-38*;7-G:60@(E-T87)T(%1I;64B"FUS9W-T<B`B4W1A<G0@
M=&ED(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC
M.CDU('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C@U"FUS9VED(")3=&%T7W5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R
M<RYI;F,Z-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR-PIM<V=I9"`B4W1A
M='5S(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP.C@Q('EE87(N<&AP.CDP('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8U"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(R-"!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-R!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P.0IM<V=I9"`B4W4B"FUS9W-T<B`B4_AN(@H*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT
M:"]H96%D+FEN8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@
M=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(E/X;F1A
M9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B5&%S:W,B
M"FUS9W-T<B`B3W!G879E<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4W-"!L
M:6(O2W)O;F]L:71H+G!H<#HU.3<*;7-G:60@(E1E;G1A=&EV92(*;7-G<W1R
M("(B"@HC.B!Y96%R+G!H<#HX-B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHV,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C$*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1H(@IM<V=S='(@(E1O<B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z-S`*;7-G:60@(E1H
M92!%9&ET($%T=&5N9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N
M($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!C86YN;W0@
M8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HT,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B
M965N(&-R96%T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C4T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S
M(&)E96X@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R
M(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!C;W5L
M9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M961I="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@(E1H92!E;F0@9&%T92!M
M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N(@IM<V=S='(@(E-L
M=71D871O('-K86P@=N9R92!S96YE<F4@96YD('-T87)T9&%T;RXB"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,#DT"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!E=F5N="!<(B5S7"(@:&%S(&)E96X@861D960L('=H:6-H(&ES(&]N("5S
M(&%T("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3`T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"P@=VAI8V@@=V%S(&]N("5S(&%T("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@961I=&5D+"!W:&EC:"!I
M<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3`V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@;F]T:69I
M8V%T:6]N('1O("5S('=A<R!S=6-C97-S9G5L;'D@<V5N="XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R-`IM<V=I9"`B5&AE(&9O;&QO
M=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V
M96YT.B(*;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Q"FUS9VED("(B"B)4
M:&4@<F5Q=65S="!W87,@:6YC;VUP;&5T92X@4V]M92!P87)A;65T97)S('1H
M870@87)E(&YE8V5S<V%R>2!T;R!A8V-E<'0@;W(@(@HB9&5C;&EN92!A;B!E
M=F5N="!A<F4@;6ES<VEN9RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]E;7!T>2YI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO
M(&5V96YT<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T
M<B`B1&5R('9A<B!I;F=E;B!A9G1A;&5R(&%T(&5K<W!O<G1E<F4N(@H*(SH@
M861D979E;G1A8W1I;VXN<&AP.C$X(&5D:71E=F5N=&%C=&EO;BYP:'`Z,S4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<R(*;7-G<W1R(")$97(@=F%R
M(&5N(&9E:FP@:2!I;7!O<G0@868@9&%T82XB"@HC.B!A9&1E=F5N=&%C=&EO
M;BYP:'`Z,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")$97(@
M=F%R(&5N(&9E:FP@:2!I;7!O<G0@868@9&%T82XB"@HC.B!E9&ET979E;G1A
M8W1I;VXN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@
M(D1E<B!V87(@96X@9F5J;"!I(&EM<&]R="!A9B!D871A+B(*"B,Z(&QI8B]A
M<&DN<&AP.C,S."!L:6(O87!I+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R(")$97(@=F%R(&5N(&9E:FP@:2!I;7!O<G0@868@9&%T82XB
M"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C8S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N
M=#H@)7,B"FUS9W-T<B`B1&5R('9A<B!E;B!F96IL(&D@:6UP;W)T(&%F(&1A
M=&$N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!A;B!E=F5N="!N
M;W1I9FEC871I;VX@=&\@)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C$P-0IM<V=I9"`B5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@97AP;W)T+B(*
M;7-G<W1R(")$97(@=F%R(&EN9V5N(&%F=&%L97(@870@96MS<&]R=&5R92XB
M"@HC.B!D871A+G!H<#HQ.#0*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN
M8SHQ.2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3@*(SH@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-S$*;7-G:60@(E1H=7)S9&%Y(@IM<V=S
M='(@(E1O<G-D86<B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M,S<*(RP@9G5Z>GD*;7-G:60@(E1I;64@4W!?86XB"FUS9W-T<B`B5&ED<WIO
M;F4B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHT"B,L
M(&9U>GIY"FUS9VED(")4:6UE('-P86XB"FUS9W-T<B`B5&ED<WIO;F4B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,S8@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(E1I=%]L
M92(*;7-G<W1R(")4:71E;"(*"B,Z(&1A=&$N<&AP.C4T('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT
M7VAE861E<G,N:6YC.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I=&5L(@H*
M(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R,B!L:6(O0FQO8VLO
M;6]N=&AL:7-T+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$R
M-PIM<V=I9"`B5&]D87DB"FUS9W-T<B`B22!$86<B"@HC.B!L:6(O0FQO8VLO
M<')E=FUO;G1H;&ES="YP:'`Z,3(T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C$R,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(Y"FUS9VED(")4;VUO
M<G)O=R(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX-"!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV,"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,3D*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1U(@IM<V=S
M='(@(E1I<B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-R!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,38*(SH@=&5M<&QA=&5S+V5D:70O:F%V
M87-C<FEP="YI;F,Z-CD*;7-G:60@(E1U97-D87DB"FUS9W-T<B`B5&ER<V1A
M9R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B5'EP
M92(*;7-G<W1R(")4>7!E(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$X,PIM<V=I9"`B55),(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;6-A;"YP:'`Z,3,T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS
M9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HU,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+U-T;W)A9V4O:V]L86(N<&AP.C,T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R971R:65V92!F<F5E+V)U<WD@:6YF;W)M871I;VX@
M9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$U"B,Z('-C<FEP=',O=7!G<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T7V-A
M=&5G;W)I97-?=&]?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,S<V(&QI8B]A<&DN<&AP.C0U,"!L
M:6(O87!I+G!H<#HU,38@;&EB+V%P:2YP:'`Z-C(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Q-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P"FUS9VED(")5<V5R($EN=&5R9F%C92(*;7-G<W1R(")"
M<G5G97)G<N9N<V5F;&%D92(*"B,Z('EE87(N<&AP.C$V,R!Y96%R+G!H<#HQ
M-CD@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ-3D@;&EB+T)L;V-K+VUO;G1H+G!H
M<#HQ-C(*(RP@9G5Z>GD*;7-G:60@(E9I97<@1&%Y(@IM<V=S='(@(E9I<R`E
M<R(*"B,Z('EE87(N<&AP.C@U('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R,`HC.B!L:6(O0FQO
M8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5V4B"FUS9W-T<B`B3VYS(@H*(SH@
M=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$X('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$Q-PHC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW
M,`IM<V=I9"`B5V5D;F5S9&%Y(@IM<V=S='(@(D]N<V1A9R(*"B,Z(&%T=&5N
M9&5E<RYP:'`Z,3$R(&QI8B]+<F]N;VQI=&@N<&AP.C$R.3`@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S
M"FUS9VED(")7965K(@IM<V=S='(@(E5G92(*"B,Z(&UO;G1H+G!H<#HQ-SD@
M=V]R:W=E96LN<&AP.C,P('=E96LN<&AP.C,T"B,L('!H<"UF;W)M870*;7-G
M:60@(E=E96L@)60B"FUS9W-T<B`B56=E("5D(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS
M9VED(")7965K*',I(@IM<V=S='(@(E5G92AR*2(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,34*
M;7-G:60@(E=E96ML>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(E5G96YL:6<Z
M($=E;G1A9V5S(&AV97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T
M"FUS9VED("(B"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W
M<R!E;F0L('=H96X@=&AE<F4@87)E(&YO(&QA=&5R(&5V96YT<S\B"FUS9W-T
M<B`B(@HB2'9A9"!T:60@<VMA;"!D86<@;V<@=6=E(&]V97)S:6=T97(@96YD
M92!M960L(&[E<B!D97(@:6MK92!E<B!S96YE<F4@869T86QE<C\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED("(B"B)7:&%T('1I;64@
M<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R92!A
M<F4@;F\@96%R;&EE<B!E=F5N=',_(@IM<V=S='(@(B(*(DAV860@=&ED('-K
M86P@9&%G(&]G('5G92!O=F5R<VEG=&5R('-T87)T92!M960L(&[E<B!D97(@
M:6MK92!E<B!T:61L:6=E<F4@(@HB869T86QE<C\B"@HC.B!A='1E;F1E97,N
M<&AP.C$Q,2!L:6(O2W)O;F]L:71H+G!H<#HQ,C@Y(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I
M9"`B5V]R:R!7965K(@IM<V=S='(@(D%R8F5J9'-U9V4B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,CDR(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(U"FUS
M9VED(")996%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-#$*;7-G:60@(EEE
M87)L>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(L5R;&EG.B!'96YT86=E<R!H
M=F5R(@H*(SH@9&%T82YP:'`Z-#`@9&%T82YP:'`Z,C,T(&5D:71E=F5N=&%C
M=&EO;BYP:'`Z-#8@861D979E;G0N<&AP.C$W"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!E=F5N=',N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z-#D*;7-G:60@
M(EEO=2!A<F4@;F]T(&%N(&%T=&5N9&5E(&]F('1H92!S<&5C:69I960@979E
M;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z-S8*;7-G:60@(EEO=2!C86X@;VYL>2!U<V4@=&AI<R!F;W)M(&9R
M;VT@=&AE($5D:70@071T96YD965S('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z.3<P"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R960@
M:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO;B`B"B)/<'1I;VYS+B!9;W4@
M;75S="!S970@;VYE("5S:&5R925S(&)E9F]R92!E=F5N="!N;W1I9FEC871I
M;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B"@HC.B!A9&1E=F5N=&%C=&EO
M;BYP:'`Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E<RXB"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z,3DT"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES
M<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE8W1E9"!C86QE;F1A<BXB
M"FUS9W-T<B`B(@H*(SH@9&5L979E;G1A8W1I;VXN<&AP.C(V"FUS9VED(")9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!D96QE=&4@=&AI<R!E=F5N
M="XB"FUS9W-T<B`B(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HW.`IM<V=I
M9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@961I="!T:&ES(&5V
M96YT+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.#D*;7-G:60@(EEO=2!H
M879E('-P96-I9FEE9"!A;B!I;G9A;&ED(&-A;&5N9&%R+B(*;7-G<W1R("(B
M"@HC.B!A='1E;F0N<&AP.C(Q"FUS9VED(")9;W4@:&%V92!S=6-C97-S9G5L
M;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R
M("(B"@HC.B!A='1E;F0N<&AP.C(V"FUS9VED(")9;W4@:&%V92!S=6-C97-S
M9G5L;'D@9&5C;&EN960@871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G
M<W1R("(B"@HC.B!A='1E;F0N<&AP.C,Q"FUS9VED(")9;W4@:&%V92!T96YT
M871I=F5L>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM
M<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.3$*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z-30*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DT"FUS9VED(")9;W4@<F5Q=65S
M=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T;R!Y
M;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3$P-`IM<V=I9"`B(@HB66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE
M9"!W:&5N(&5V96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY"FUS9VED
M(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R
M92!E9&ET960@:6X@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]38VAE9'5L97(O:W)O;F]L:71H+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!R96UI;F1E9"!A8F]U="`E<RP@
M=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@9&5F875L="!C86QE;F1A<B(*;7-G<W1R(")%:W-P;W)TZ7(@2V%L96YD
M97(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#4S(&QI8B]$<FEV97(N<&AP.C$P
M-C,*;7-G:60@(EM5;FYA;65D(&5V96YT72(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHY-PHC+"!F=7IZ>0IM<V=I9"`B7T%L87)M
M(@IM<V=S='(@(D%L87)M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.C$Q"FUS9VED(")?0F%S:6,@4V5A<F-H(@IM<V=S='(@
M(B(*"B,Z('9I97=E=F5N="YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")?161I
M="(*;7-G<W1R(")2970B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,P"B,L
M(&9U>GIY"FUS9VED(")?1V]T;R(*;7-G<W1R(")'Y2!4:6PB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,S,V"B,L(&9U>GIY"FUS9VED(")?26UP;W)T+T5X
M<&]R="(*;7-G<W1R("));7!O<G3I<B]%:W-P;W)TZ7(B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,S$X"B,L(&9U>GIY"FUS9VED(")?37D@0V%L96YD87)S
M(@IM<V=S='(@(D5K<W!O<G3I<B!+86QE;F1E<B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$S,C4*(RP@9G5Z>GD*;7-G:60@(E].97<@179E;G0B"FUS9W-T
M<B`B3GD@069T86QE(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,T,0IM<V=I
M9"`B7U!R:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M,S(*(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B36%R=',B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S(X"B,L(&9U>GIY"FUS9VED(")?5&]D
M87DB"FUS9W-T<B`B22!$86<B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHQ-#(*;7-G:60@(F)E9F]R92!T:&4@979E;G0@<W1A<G1S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*
M;7-G<W1R(")D86<B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$P"FUS9VED(")D87DH<RDB"FUS
M9W-T<B`B9&%G*&4I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(F1A9V4B
M"@HC.B!D871A+G!H<#HQ-#<@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M"B,L(&9U>GIY"FUS9VED(")E=F5N=',N8W-V(@IM<V=S='(@(D%L;&4@869T
M86QE<B(*"B,Z(&1A=&$N<&AP.C$V.`HC+"!F=7IZ>0IM<V=I9"`B979E;G1S
M+FEC<R(*;7-G<W1R(")!;&QE(&%F=&%L97(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$S,0IM<V=I9"`B9G)O;2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S
M,"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S8*;7-G:60@(FUO;G1H*',I
M(@IM<V=S='(@(FWE;F5D*&5R*2`B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,#(P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")O;B`E<R!A="`E<R(*
M;7-G<W1R("(E<R!S=&%R=&5R(&]M("5S(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,`IM<V=I
M9"`B;VX@=&AE('-A;64@9&%T92(*;7-G<W1R(")PY2!S86UM92!D871O(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(S-@IM<V=I9"`B;VX@=&AE('-A;64@=V5E:V1A>2(*;7-G
M<W1R(")PY2!S86UM92!U9V5D86<B"@HC.B!D871A+G!H<#HS,"!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$U"FUS9VED(")V0V%L96YD87(O:4-A;&5N
M9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,T.2!L:6(O87!I+G!H
M<#HV,#<*;7-G:60@(G9%=F5N="!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3$*;7-G:60@(G=E96LB"FUS9W-T
M<B`B=6=E(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(Q-PIM<V=I9"`B=V5E:RAS*2!O;CHB"FUS
M9W-T<B`B=6=E*'(I('#E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PHC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DT"FUS9VED(")W965K<R(*;7-G<W1R(")U9V5R(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(T,@IM<V=I9"`B>65A<BAS*2(*;7-G<W1R("+E<B(*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O<&\O8W-?0UHN
M<&\`````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3(W-3$U
M`#$P-#$W,S8R-S4S`#`R,#0R-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C($MR;VYO;&ET:"!#>F5C:"!4<F%N<VQA=&EO
M;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@
M9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S
M('1H92!(;W)D92!P86-K86=E+@HC(%!A=F5L($-H>71I;"`\<&%V96Q`8VAY
M=&EL+G1K/BP@,C`P,2TR,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!+<F]N;VQI=&@@,BXP+6-V<UQN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z("`R,#`Q+3`W+3(V(#$T.C4V+3`Y,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@4&%V96P@0VAY=&EL(#QP879E;$!C:'ET:6PN=&L^7&XB
M"B),86YG=6%G92U496%M.B!#>F5C:"`\9&5V0&QI<W1S+FAO<F1E+F]R9SY<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@."UB:71<;B(*(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',]
M,SL@<&QU<F%L/2AN)3$P/3TQ("8F(&XE,3`P(3TQ,2`_(#`@.B!N)3$P/CTR
M("8F(&XE(@HB,3`\/30@)B8@*&XE,3`P/#$P('Q\(&XE,3`P/CTR,"D@/R`Q
M(#H@,BD[7&XB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z
M,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&-A;&5N9&%R<R!F
M;W5N9"(*;7-G<W1R(").96)Y;&$@;F%L97IE;F$@ON%D;N$@9&%T82!P<F\@
M:4-A;&5N9&%R+B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&5V96YT<R(*;7-G<W1R("(E9"!U
M9.%L;W-T[2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC
M.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!$87DH<RD@)7,@2&]U<BAS
M*2`E<R!-:6YU=&5S(@IM<V=S='(@(B5S($1N^2A$96XI("5S($AO9&EN*&$I
M("5S($UI;G5T(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A='1E;F1E97,B"FUS9W-T<B`B)7,@^NAA<W1N[6OY
M(@H*(SH@9&%T82YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I
M;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(B5S('-O=6)O<B#Z
M<W#LN6[L(&EM<&]R=&]VX6XB"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O
M8F%S92YP:'`Z,3(X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD
M87(B"FUS9W-T<B`B)7,@+2!+86QE;F3A^"(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N
M9&%R(&YA;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@
M:6X@=&AE(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V-`IM<V=I9"`B*B!!9&0@=&AE
M<V4@8GD@8VQI8VMI;F<@061D("HB"FUS9W-T<B`B*B!0^&ED870@='ET;R!K
M;&EK;G5T[6T@;F$@4/AI9&%T("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$U,`IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E
M<W,H97,I("HB"FUS9W-T<B`B*B!0<F]S[6T@=GEB97)T92!E;6%I;&]V;W4H
MZ2D@861R97-U*'DI("HB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@V"FUS9VED
M("(Q(&%T=&5N9&5E(@IM<V=S='(@(C$@^NAA<W1N[6LB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VAE861E<BYI;F,Z-`IM<V=I9"`B,2!E=F5N="(*;7-G<W1R
M("(Q('5DX6QO<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,W"FUS
M9VED("(Q(&AO=7(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-`HC+"!F=7IZ>0IM<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R(")-
M:6YU="AA*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*(RP@9G5Z
M>GD*;7-G:60@(C(P(&UI;G5T97,B"FUS9W-T<B`B36EN=70H82DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"B,L(&9U>GIY"FUS9VED("(S,"!M
M:6YU=&5S(@IM<V=S='(@(DUI;G5T*&$I(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,3<Q"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/D%T=&5N9&5E
M<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/MKH87-T;NUC:3PO
M8CX@*&YE<&]V:6YNZ2DB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ
M-#D*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^1&5S8W)I7W!T:6]N/"]S=')O
M;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^4&]P:5]S/"]B/B`H;F5P;W9I
M;F[I*2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(W-PHC+"!F=7IZ
M>0IM<V=I9"`B/'-T<F]N9SY+97EW;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI
M(@IM<V=S='(@(CQB/DML[>AO=N$@<VQO=F$\+V(^("AN97!O=FEN;NDI(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DT"B,L(&9U>GIY"FUS9VED
M("(\<W1R;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G
M<W1R("(\8CY/<&%K;W;A;NT\+V(^("AN97!O=FEN;NDI(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#$@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ.#$*;7-G:60@(D%-(@IM<V=S='(@(D%-(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3DQ"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R(")0^&EJ871O
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!
M9%]V86YC960@4V5A<F-H(@IM<V=S='(@(DAL7V5D870@1/EK;&%D;NQJ:2(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38Q('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")!9&0B"FUS
M9W-T<B`B4/AI9&%T(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8*
M;7-G:60@(D%D9"!%=F5N="(*;7-G<W1R(")0^&ED870@563A;&]S="(*"B,Z
M('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C,U
M"FUS9VED(")!9&0@82!N97<@4F5M;W1E($-A;&5N9&%R(@IM<V=S='(@(E#X
M:61A="!N;W;](%9Z9.%L96[]($MA;&5N9.'X(@H*(SH@861D979E;G0N<&AP
M.C8T"FUS9VED(")!9&0@82!N97<@979E;G0B"FUS9W-T<B`B4/AI9&%T(&YO
M=F]U('5DX6QO<W0B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E
M<RYI;F,Z-S0*;7-G:60@(D%D9"!A='1E;F1E97,B"FUS9W-T<B`B4/AI9&%T
M(/KH87-T;NUK>2(*"B,Z(&-O;G1A8W1S+G!H<#HW-B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$R,`HC.B!T96UP;&%T97,O871T96YD965S
M+V%T=&5N9&5E<RYI;F,Z-S@*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R
M(")+;VYT86MT>2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHX('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM<V=I
M9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(DAL961A="!$^6ML861N[&II
M(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3,*;7-G:60@(D%L87)M
M(@IM<V=S='(@(D%L87)M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!D87ES(&)E9F]R92(*;7-G<W1R
M(")!;&%R;2`E9"!D;OD@</AE9"(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@:&]U<G,@8F5F;W)E(@IM
M<V=S='(@(D%L87)M("5D(&AO9&EN('#X960B"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-S<T"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&UI;G5T97,@
M8F5F;W)E(@IM<V=S='(@(D%L87)M("5D(&UI;G5T('#X960B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ-S4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D
M('=E96MS(&)E9F]R92(*;7-G<W1R(")!;&%R;B`E9"!T_61N^2!P^&5D(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z,3<V,PIM<V=I9"`B06QA<FT@,2!D87D@8F5F
M;W)E(@IM<V=S='(@(D%L87)M(#$@9&5N('#X960B"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ-S8X"FUS9VED(")!;&%R;2`Q(&AO=7(@8F5F;W)E(@IM<V=S='(@
M(D%L87)M(#$@:&]D:6YU('#X960B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<S
M"FUS9VED(")!;&%R;2`Q(&UI;G5T92!B969O<F4B"FUS9W-T<B`B06QA<FT@
M,2!M:6YU='4@</AE9"(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3@*;7-G:60@
M(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B06QA<FT@,2!T_61E;B!P
M^&5D(@H*(SH@9&%T82YP:'`Z-C`*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T
M<B`B1&%T=6T@06QA<FUU(@H*(SH@9&%T82YP:'`Z-3D*;7-G:60@(D%L87)M
M(%-P86X@*&UI;G5T97,I(@IM<V=S='(@(E9Y;>SX96[M($%L87)M=2`H=B!M
M:6YU=.%C:"DB"@HC.B!D871A+G!H<#HV,0IM<V=I9"`B06QA<FT@5&EM92(*
M;7-G<W1R("+(87,@06QA<FUU(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE
M=&4N:6YC.C,Q"FUS9VED(")!;&PB"FUS9W-T<B`B5KEE(@H*(SH@;&EB+T9"
M5FEE=RYP:'`Z,3(V(&QI8B]&0E9I97<N<&AP.C$R.2!L:6(O1D)6:65W+G!H
M<#HQ,S(*;7-G:60@(D%L;"!!='1E;F1E97,B"FUS9W-T<B`B5KEI8VAN:2#:
MZ&%S=&[M8VDB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3D*
M;7-G:60@(D%L;"!&=71U<F4B"FUS9W-T<B`B5KEE8VAN>2!V($)U9&]U8VYO
M<W1I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4S"FUS9VED
M(")!;&P@4&%S="(*;7-G<W1R(")6N65C:&YY($UI;G5LZ2(*"B,Z(&QI8B]"
M;&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO;6]N=&@N<&AP
M.C(T"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HR-0IM<V=I9"`B06QL(%9I<VEB;&4B"FUS9W-T<B`B5KEE
M8VAN>2!6:61I=&5L;NDB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHQ,C(@;&EB+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H
M<#HY,PHC.B!L:6(O5V5E:U9I97<N<&AP.C$R-R!L:6(O5V5E:U9I97<N<&AP
M.C$S-"!L:6(O1')I=F5R+G!H<#HQ.#,R"FUS9VED(")!;&P@9&%Y(@IM<V=S
M='(@(D-E;/T@9&5N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$V-`IM
M<V=I9"`B06QL(&1A>2!E=F5N="(*;7-G<W1R(")59.%L;W-T(&YA(&-E;/T@
M9&5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM<V=I9"`B
M06QL(&5V96YT<R(*;7-G<W1R(")6N65C:&YY(%5DX6QO<W1I(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O2W)O;F]L
M:71H+G!H<#HV.#,*;7-G:60@(D%N>2(*;7-G<W1R(")*86OA:V]L:78B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,0IM<V=I9"`B07!R
M:6PB"FUS9W-T<B`B1'5B96XB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHS.2!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN
M8SHY,PHC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C<P('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,34V"FUS9VED(")!="(*;7-G<W1R(")6(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R-@IM<V=I9"`B(@HB071T86-H960@
M:7,@86X@:4-A;&5N9&%R(&9I;&4@=VET:"!M;W)E(&EN9F]R;6%T:6]N(&%B
M;W5T('1H92!E=F5N="X@268@>6]U<B`B"B)M86EL(&-L:65N="!S=7!P;W)T
M<R!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E('1H:7,@9FEL92!T;R!E87-I
M;'D@=7!D871E("(*(GEO=7(@;&]C86P@8V]P>2!O9B!T:&4@979E;G0N(@IM
M<V=S='(@(B(*(E-O=6)O<B!I0V%L96YD87(@:F4@</AI;&^^96X@<R!I;F9O
M<FUA8V5M:2!O('5DX6QO<W1I+B!0;VMU9"!6X;D@96UA:6QO=OT@(@HB:VQI
M96YT('!O9'!O<G5J92!I5&EP(+[A9&]S=&DL(&WYOF5T92!P;W6^[70@=&5N
M=&\@<V]U8F]R('!R;R!J961N;V1UN>T@(@HB86MT=6%L:7IA8VD@;&]KX6QN
M[6AO(&MA;&5N9.'X92XB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z-#(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED
M(")!='1E;F1A;F-E(@IM<V=S='(@(MKH87-T(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,38Q"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`BVNAA
M<W1N[6-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S4*
M;7-G:60@(D%U9W5S="(*;7-G<W1R(")3<G!E;B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,2!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z.`IM<V=I9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(E9Y
M:&QE9&%T(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")":7)T:&1A>2(*;7-G<W1R(").87)O>F5N:6YY(@H*(SH@;&EB+T9"5FEE
M=RYP:'`Z.3`@;&EB+T9"5FEE=RYP:'`Z,3$P"FUS9VED(")"=7-Y(@IM<V=S
M='(@(EIA;F5P<N%Z;NQN_2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHT-`IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S='(@(DM?
M86QE;F3A^"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0Y"FUS9VED
M(")#86Q?96YD87(B"FUS9W-T<B`B2V%L7V5N9.'X(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$T-B!L:6(O0FQO8VLO<')E=FUO
M;G1H;&ES="YP:'`Z,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HR,2!L:6(O
M0FQO8VLO;6]N=&AL:7-T+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,C(*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9.'X(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D-A;&5N9&%R(%-U;6UA<GDB
M"FUS9W-T<B`B4VAR;G5T[2!+86QE;F3A^&4B"@HC.B!D871A+G!H<#HR,C@*
M(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G960N
M(@IM<V=S='(@(B5S('-O=6)O<B#Z<W#LN6[L(&EM<&]R=&]VX6XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3<*;7-G:60@(D-A;&5N9&%R<R(*;7-G<W1R(")+86QE;F3A
M^&4B"@HC.B!C86QE;F1A<G,N<&AP.C(W"FUS9VED(")#86QE;F1A<G,@;75S
M="!H879E(&$@;F%M92XB"FUS9W-T<B`B2V%L96YDX?AE(&UU<^T@;>UT(&IM
MZ6YO+B(*"B,Z(&1A=&$N<&AP.C(T,PIM<V=I9"`B0V%N)W0@8W)E871E(&$@
M;F5W(&5V96YT+B(*;7-G<W1R(").96QZ92!V>71V;_AI="!N;W9O=2!U9.%L
M;W-T+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DQ
M('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHS,`HC.B!T96UP;&%T97,O9&5L
M971E+V1E;&5T92YI;F,Z,S(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S,*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S`Y"FUS9VED(")#86YC96PB
M"FUS9W-T<B`B4W1O<FYO(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<P"FUS
M9VED(")#86YC96QL960B"FUS9W-T<B`B4W1O<FYO=N%N;R(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N8V5L
M;&5D.B`E<R(*;7-G<W1R(")3=&]R;F]VX6YO.B`E<R(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV-"!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHV.0IM<V=I9"`B0V%T96=O<E]Y(@IM<V=S='(@(DMA=&5G
M;W)?:64B"@HC.B!D871A+G!H<#HV,R!T96UP;&%T97,O<V5A<F-H+V5V96YT
M7VAE861E<G,N:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*;7-G
M:60@(D-A=&5G;W)Y(@IM<V=S='(@(DMA=&5G;W)I92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@(B(*(D-H;V]S92!I9B!Y;W4@=V%N
M="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@
M979E;G1S(&)Y("(*(F5M86EL.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B
M92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V5A<F-H7V%B;V]K
M7W-E;&5C="YI;F,Z,3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.0IM<V=I
M9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F;W(@9G)E
M92]B=7-Y(%523',Z(@IM<V=S='(@(E9Y8G)A="!+;VYT86MT>2!P<F\@:&QE
M9.%N[2!F<F5E+V)U<WD@55),.B(*"B,Z('1E;7!L871E<R]P<F5F<R]F8E]C
M86QS7W-E;&5C="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@
M8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXZ(@IM<V=S='(@(EIV;VQI="!K86QE;F3A^&4L(&MT97+I('-I('#X
M96IE=&4@<&]UONUT('!R;R!V_7!I<R!S97IN86UU($9R964O0G5S>3HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$Q"B,L(&9U>GIY"FUS9VED(")#
M:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E('=H96X@9V5N97)A=&EN
M9R!F<F5E+V)U<WD@55),<SHB"FUS9W-T<B`B5GEB<F%T($MO;G1A:W1Y('!R
M;R!H;&5DX6[M(&9R964O8G5S>2!54DPZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X"FUS9VED(")#:&]O<V4@>6]U<B!D969A=6QT(&-A;&5N9&%R
M+B(*;7-G<W1R("):=F]L:70@:6UP;&EC:71N[2!K86QE;F3A^"(*"B,Z('1E
M;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHV-0HC+"!F=7IZ>0IM
M<V=I9"`B0VQE87(@86QL(&%T=&5N9&5E<R(*;7-G<W1R(")3;6%Z870@=KEE
M8VAN>2#ZZ&%S=&[M:WDB"@HC.B!D871A+G!H<#HR."!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S
M(@IM<V=S='(@(LCA<FMO=2!O9&3L;&5NZ2!H;V1N;W1Y(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<S"FUS9VED(")#;VYF:7)M(&1E;&5T:6]N(&]F
M(&5V96YT<S\B"FUS9W-T<B`B4&]T=G)D:70@<VUA>N%N[2!U9.%L;W-T[3\B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-C<*;7-G:60@(D-O;F9I<FUE9"(*
M;7-G<W1R(")0;W1V<GIE;F\B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A
M;&5N9&%R<RYI;F,Z,C`X"FUS9VED(")#;W!Y('1H92!54DP@8F5L;W<@9F]R
M('5S92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ(@IM
M<V=S='(@(EIK;W#M<F]V870@;NV^92!U=F5D96YO=2!54DP@<')O('!O=;YI
M=.T@<R!68;GM($9R964O0G5S>2!54DPZ(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,38R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S
M+B(*;7-G<W1R(").96QZ92!O=&5V^.UT("5S+B(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,C8*;7-G:60@(D-R96%T92(*;7-G
M<W1R(")6>71V;_AI="(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ,3(*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!#86QE;F1A<B(*
M;7-G<W1R(")6>F3A;&5NZ2!+86QE;F3A^&4B"@HC.B!M;VYT:"YP:'`Z,38U
M('1E;7!L871E<R]W965K+VAE860N:6YC.C(U('1E;7!L871E<R]D87DO<F]W
M+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z
M,3DT"FUS9VED(")#<F5A=&4@82!.97<@179E;G0B"FUS9W-T<B`B5GET=F_X
M:70@3F]V;W4@563A;&]S="(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C@P"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(E9Y='9O^&5N;R(*"B,Z('1E
M;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR.0IM<V=I9"`B0W5R<F5N="(*
M;7-G<W1R(")3;W7H87-N_2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$Q,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#D*;7-G:60@(D1A:6QY
M.B!296-U<G,@979E<GDB"FUS9W-T<B`B1&5N;NPZ(%)E:W5R>NUV;NP@:V&^
M9/TB"@HC.B!A='1E;F1E97,N<&AP.C$Q,"!L:6(O2W)O;F]L:71H+G!H<#HQ
M,C@X(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(Q"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,@IM<V=I9"`B1&%Y(@IM<V=S='(@(D1E;B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C$S.0IM<V=I9"`B1&%Y*',I(@IM<V=S='(@(D1E;BA$;GDI(@H*(SH@
M=FEE=V5V96YT+G!H<#HQ,#0*;7-G:60@(D1E7VQE=&4B"FUS9W-T<B`B4VU?
M>F%T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-SD*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(E!R;W-I;F5C(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3DT"FUS9VED(")$96-L:6YE9"(*;7-G<W1R("):86WM=&YU
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-PIM<V=I9"`B1&5F875L
M="!#86QE;F1A<B(*;7-G<W1R("));7!L:6-I=&[M($MA;&5N9.'X(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,R!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X,0HC.B!T96UP;&%T97,O9&5L
M971E+V]N92YI;F,Z,CD@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N
M86=E;65N="YI;F,Z,C,*(SH@;&EB+T1R:79E<BYP:'`Z,3@Q,PIM<V=I9"`B
M1&5L971E(@IM<V=S='(@(E-M87IA="(*"B,Z(&1E;&5V96YT+G!H<#HT,"!T
M96UP;&%T97,O9&5L971E+V]N92YI;F,Z,3@@=&5M<&QA=&5S+V1E;&5T92]D
M96QE=&4N:6YC.C$X"B,Z(&QI8B]$<FEV97(N<&AP.C$X,3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E("5S(@IM<V=S='(@(E-M87IA="`E<R(*"B,Z
M(&5D:71E=F5N="YP:'`Z-S`*;7-G:60@(D1E;&5T92!%=F5N="(*;7-G<W1R
M(")3;6%Z870@563A;&]S="(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E
M+FEN8SHR-PIM<V=I9"`B(@HB1&5L971E('1H92!C=7)R96YT(&5V96YT(&]N
M;'DL('1H:7,@;V-C=7)R96YC92!A;F0@86QL(&9U='5R92!O8V-U<F5N8V5S
M+"!O<B`B"B)A;&P@;V-C=7)E;F-E<S\B"FUS9W-T<B`B(@HB4VUA>F%T('!O
M=7IE('-O=>AA<VYO=2!U9.%L;W-T+"!T96YT;R!V_7-K>70@82!VN65C:&YY
M(';]<VMY='D@=B!B=61O=6-N=2P@(@HB;F5B;R!VN65C:&YY(';]<VMY='D_
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$P
M-"!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C@*;7-G:60@(D1E<V-R
M:5]P=&EO;B(*;7-G<W1R(")0;W!I7W,B"@HC.B!D871A+G!H<#HV,B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<U"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.CDV"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R
M(")0;W!I<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,3<S"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(EIO8G)A>FET(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8P"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y($-A;&5N9&%R<R(*;7-G<W1R(")+86QE;F3A^&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X"FUS9VED(")$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`B36^^;F]S=&D@6F]B<F%Z96[M(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$;R!Y;W4@=V%N="!T;R!S
M:&]W('1A<VMS('=H:6-H(&%R92!D=64@;VX@>6]U<B!C86QE;F1A<C\B"FUS
M9W-T<B`B4/AE:F5T92!S:2!Z;V)R87II="#Z:V]L>2P@:W1E<ND@:G-O=2!P
M;[YA9&]VX6YY+"!N82!68;EE;2!K86QE;F3A^&D_(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3,W"FUS9VED(")$;V5S(&YO="!R96-U<B(*;7-G<W1R(")"
M97H@;W!A:V]VX6[M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,S(U"B,L('!H
M<"UF;W)M870*;7-G:60@(D1U93H@)7,B"FUS9W-T<B`B4&^^861O=F%N_3H@
M)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,34*
M;7-G:60@(D1U<F%T:6]N(@IM<V=S='(@(D3I;&MA(%1R=N%N[2(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-S`@;&EB+T1R:79E
M<BYP:'`Z,3@P-@IM<V=I9"`B161I="(*;7-G<W1R(")5<')A=FET(@H*(SH@
M961I=&5V96YT+G!H<#HS,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-B!L
M:6(O1')I=F5R+G!H<#HQ.#`V"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M)7,B"FUS9W-T<B`B57!R879I="`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C$X-PIM<V=I9"`B161I="!!='1E;F1E97,B"FUS9W-T<B`B57!R
M879I="#:Z&%S=&[M:WDB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N
M9&%R<RYI;F,Z,30P"B,L(&9U>GIY"FUS9VED(")%9&ET($-A;&5N9&%R<R(*
M;7-G<W1R(")5<')A=FET(%9Z9.%L96[I($MA;&5N9.'X92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-3`*;7-G:60@(D5D:70@4F5M;W1E($-A;&5N
M9&%R<R(*;7-G<W1R(")5<')A=FET(%9Z9.%L96[I($MA;&5N9.'X92(*"B,Z
M(&%T=&5N9&5E<RYP:'`Z,34P"FUS9VED(")%9&ET(&%T=&5N9&5E<R(*;7-G
M<W1R(")5<')A=FET(/GH87-T;NUK>2(*"B,Z('1E;7!L871E<R]C871E9V]R
M>5]L96=E;F0N:6YC.C(P"FUS9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O
M;&]R<R(*;7-G<W1R(")5<')A=FET(&MA=&5G;W)I92!A(&)A<G9Y(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S8@=&5M<&QA=&5S
M+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0Q"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$V-`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%
M;6%I;&]VX2!!9')E<V$B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B16Y?9"(*;7-G<W1R(")+;VYE
M8R!V(@H*(SH@9&%T82YP:'`Z-3<*;7-G:60@(D5N9"!$871E(@IM<V=S='(@
M(D1A='5M(%5K;V[H96[M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H
M96%D97)S+FEN8SHX('1E;7!L871E<R]V:65W+W9I97<N:6YC.C0W"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`X"FUS9VED(")%;F0@3VXB"FUS
M9W-T<B`B2V]N96,@=B(*"B,Z(&1A=&$N<&AP.C4X"FUS9VED(")%;F0@5&EM
M92(*;7-G<W1R("+(87,@56MO;NAE;NTB"@HC.B!A='1E;F1E97,N<&AP.C$R
M-"!A='1E;F1E97,N<&AP.C$S-2!A='1E;F1E97,N<&AP.C$T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B!F;W(@)7,Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI
M(';]8NQR=2`E<R!I;F9O<FUA8V4@;R!F<F5E+V)U<WDZ("5S(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3`Y,PIM<V=I9"`B179E;G0@861D960Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,#,*;7-G:60@(D5V96YT
M(&1E;&5T960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P
M.3@*;7-G:60@(D5V96YT(&5D:71E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3`V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%=F5N="!F<F]M
M("5S('1O("5S(@IM<V=S='(@(E5DX6QO<W0@;V0@)7,@9&\@)7,B"@HC.B!L
M:6(O1')I=F5R+G!H<#HW-C0*(RP@9G5Z>GD*;7-G:60@(D5V96YT<R!M=7-T
M(&AA=F4@82!S=&%R="!D871E+B(*;7-G<W1R(")+86QE;F3A^&4@;75S[2!M
M[70@:FWI;F\N(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S,P"B,L(&9U>GIY"FUS
M9VED(")%=F5N=',@;75S="!H879E(&$@=&ET;&4N(@IM<V=S='(@(DMA;&5N
M9.'X92!M=7/M(&WM="!J;>EN;RXB"@HC.B!L:6(O1')I=F5R+G!H<#HW-C<*
M;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@86X@96YD(&1A=&4@;W(@82!D=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E
M;F1E97,N:6YC.C<Y"B,L(&9U>GIY"FUS9VED(")%>'!A;F0@3F%M97,B"FUS
M9W-T<B`B3N%Z978@2V%L96YDX?AE(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ.#<*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%>'!O<G1O=F%T
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O
M<G0@0V%L96YD87(B"FUS9W-T<B`B17AP;W)T;W9A="!+86QE;F3A^"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8Y"FUS9VED(")&96)R
M=6%R>2(*;7-G<W1R("+:;F]R(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ,C@*;7-G:60@(D9I;F0B"FUS9W-T<B`B5GEH;&5D870B
M"@HC.B!Y96%R+G!H<#HX-R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C(*(SH@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ,#4*;7-G:60@(D9R(@IM<V=S='(@(E#A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4X"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U
M<WD@26YF;W)M871I;VXB"FUS9W-T<B`B0F5Z($EN9F]R;6%C92(*"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,"!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S(*
M;7-G:60@(D9R:61A>2(*;7-G<W1R(")0X71E:R(*"B,Z('1E;7!L871E<R]D
M96QE=&4O9&5L971E+FEN8SHS,`IM<V=I9"`B1G5T=7)E(@IM<V=S='(@(D)U
M9&]U8VYO<W0B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G
M:60@(D=A;64B"FUS9W-T<B`B2')A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C(S"FUS9VED(")'96YE<F%L(@IM<V=S='(@
M(E:Y96]B96-N["(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1V]T;R`E<R(*;7-G<W1R(")*[70@;F$@)7,B
M"@HC.B!M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W965K+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S
M:61E+FEN8SHQ,`IM<V=I9"`B2&ED92(*;7-G<W1R("(B"@HC.B!M;VYT:"YP
M:'`Z,3,U('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHQ
M,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&ED92`E<R(*;7-G<W1R(")5
M<&]M[6YK83H@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV-2!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S@*;7-G:60@(DAO=7(H<RDB"FUS
M9W-T<B`B2&]D:6XH82DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S
M"B,L(&9U>GIY"FUS9VED(")(;W<@;&]N9R!S:&]U;&0@=&AE('1I;64@<VQO
M=',@;VX@=&AE(&1A>2!A;F0@=V5E:R!V:65W<R!B93\B"FUS9W-T<B`B6F]B
M<F%Z:70@</EL:&]D:6YO=ND@^G-E:WD@=B!D96YN[6T@82!T_61E;F[M;2!Z
M;V)R87IE;NT_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`HC+"!F
M=7IZ>0IM<V=I9"`B2&]W(&UA;GD@9&%Y<R!O9B!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@<VAO=6QD('=E(&=E;F5R871E/R(*;7-G<W1R(")+;VQI:R!D;NT@
M9&]P^&5D=2!MX6UE(&=E;F5R;W9A="!I;F9O<FUA8VD@9G)E92]B=7-Y/R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB268@>6]U<B!E;6%I;"!C;&EE;G0@9&]E<VXG="!S=7!P;W)T(&E4
M:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@;VYE(&]F('1H92`B"B)F;VQL;W=I
M;F<@;&EN:W,@=&\@86-C97!T(&]R(&1E8VQI;F4@=&AE(&5V96YT+EQN(@HB
M7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT.EQN(@HB)7-<;B(*(EQN(@HB5&\@
M86-C97!T('1H92!E=F5N="!T96YT871I=F5L>3I<;B(*(B5S7&XB"B)<;B(*
M(E1O(&1E8VQI;F4@=&AE(&5V96YT.EQN(@HB)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="!#86QE;F1A<BP@4W1E<"`E9"(*;7-G<W1R("));7!O<G1O
M=F%T($MA;&5N9.'X+"!+<F]K("5D(@H*(SH@9&%T82YP:'`Z,S(P"FUS9VED
M("));7!O<G0O17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(DEM<&]R=&]V870O
M17AP;W)T;W9A="!+86QE;F3A^"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V=O=&\N:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DQE9&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S0*;7-G:60@(DIU
M;'DB"FUS9W-T<B`BR&5R=F5N96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]G;W1O+FEN8SHW,PIM<V=I9"`B2G5N92(*;7-G<W1R("+(97)V96XB"@HC
M.B!D871A+G!H<#HV-2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-#(*;7-G
M:60@(DME>7=O<F1S(@IM<V=S='(@(DML[>AO=N$@<VQO=F$B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-34*;7-G:60@(DQA<W0@,C0@:&]U
M<G,B"FUS9W-T<B`B4&]S;&5D;NUC:"`R-"!H;V1I;B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C@W"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S
M='(@(DYA<&]S;&5D>2!:;>QN[&YO(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M861?<VED95]B>5]S:61E+FEN8SHT"B,Z('1E;7!L871E<R]M;VYT:"]H96%D
M7W-I9&5?8GE?<VED92YI;F,Z,3`*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?
M<VED95]B>5]S:61E+FEN8SHQ-B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M-`IM<V=I9"`B3&%S="!-;VYT:"(*;7-G<W1R(")-:6YU;/T@3>QS[6,B"@HC
M.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHT"B,L(&9U>GIY"FUS9VED("),
M87-T(%EE87(B"FUS9W-T<B`B36EN=6S]('3]9&5N(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8V@N:6YC.C4T('1E;7!L871E<R]W965K+VAE860N:6YC
M.C,*;7-G:60@(DQA<W0@=V5E:R(*;7-G<W1R(")-:6YU;/T@=/UD96XB"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$W"FUS9VED("),:6UI="!T
M:&4@=&EM92!S<&%N('1O(&5X<&]R=#HB"FUS9W-T<B`B3&EM:71O=F%T(.AA
M<V]VZ2!R;WIP['3M('!R;R!E>'!O<G1O=N%N[3HB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z.#8@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z-S8*;7-G:60@(DQO7V-A=&EO;B(*;7-G<W1R(")-[5]S=&\B
M"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E
M<G,N:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E
M;65N="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N
M86=E;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,C$*(SH@
M;&EB+T1R:79E<BYP:'`Z,3@T.0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B
M3>US=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*;7-G:60@(DUA
M;F%G92!R96UO=&4@8V%L96YD87)S+B(*;7-G<W1R(")/=FSA9.%N[2!P<F\@
M=GIDX6QE;ND@:V%L96YDX?AE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-S`*;7-G:60@(DUA<F-H(@IM<V=S='(@(D+X97IE;B(*"B,Z
M(&QI8B]A<&DN<&AP.C$P,`IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@179E
M;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C<R"FUS9VED(")-87DB"FUS9W-T<B`B2W;L=&5N(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3@T-@IM<V=I9"`B364B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED(")-965T:6YG(@IM<V=S='(@
M(E-C:/EZ92(*"B,Z(&QI8B]";&]C:R]T<F5E7V%L87)M<RYP:'`Z,PHC+"!F
M=7IZ>0IM<V=I9"`B365N=2!!;&%R;7,B"FUS9W-T<B`B06QA<FTB"@HC.B!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU($QI<W0B"FUS
M9W-T<B`B365N=2!397IN86TB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHV."!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S<*;7-G:60@(DUI;G5T
M92AS*2(*;7-G<W1R(")-:6YU="AA*2(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N
M=&AL:7-T+G!H<#HT,@IM<V=I9"`B36ES<V5D($5V96YT<R!,:7-T(@IM<V=S
M='(@(E;]<&ES(%IM9;EK86[]8V@@563A;&]S=.TB"@HC.B!Y96%R+G!H<#HX
M,R!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHU.2!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,3@*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*
M;7-G:60@(DUO(@IM<V=S='(@(E!O(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C$V('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-0HC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV."!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`V"FUS9VED(")-;VYD87DB"FUS9W-T<B`B4&]N9.QL[2(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C$R.3$@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z,C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"FUS9VED(")-;VYT:"(*
M;7-G<W1R(")-['/M8R(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,PIM<V=I
M9"`B36]N=&@@5FEE=R(*;7-G<W1R("):;V)R87II="!-['/M8R(*"B,Z(&QI
M8B]";&]C:R]M;VYT:&QI<W0N<&AP.C,@;&EB+T)L;V-K+VUO;G1H;&ES="YP
M:'`Z-#,*;7-G:60@(DUO;G1H;'D@179E;G1S($QI<W0B"FUS9W-T<B`B3>QS
M[>AN[2!6_7!I<R!59.%L;W-T[2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C8*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C(Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(S-0IM<V=I9"`B36]N=&AL>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(DWL
M<^WH;NPZ(%)E:W5R>NUV;NP@:V&^9/TB"@HC.B!L:6(O0FQO8VLO;6]N=&AL
M:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS($%H96%D(@IM<V=S='(@(DWL<^UC
M92!$;W#X961U(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(T
M"FUS9VED(")-;VYT:',@0F5F;W)E(@IM<V=S='(@(E#X960@3>QS[6-I(@H*
M(SH@;&EB+V%P:2YP:'`Z-C$R"FUS9VED(")-=6QT:7!L92!I0V%L96YD87(@
M8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT(&ES('-U<'!O<G1E
M9"XB"FUS9W-T<B`B(@HB0GEL;R!N86QE>F5N;R!N[&MO;&EK(.CA<W3M(&E#
M86QE;F1A<BX@2F4@;6^^;F\@<&]UONUT(&IE;B!J961E;B!V179E;G0N(@H*
M(SH@8V%L96YD87)S+G!H<#HQ,C@@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C8W"FUS9VED(")->2!#86QE;F1A<G,B"FUS9W-T<B`B2V%L
M96YDX?AE(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M
M96YU+FEN8SHS-@IM<V=I9"`B37D@0V%L96YD87)S.B(*;7-G<W1R(")+86QE
M;F3A^&4Z(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C(P-`IM<V=I9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R(")&<F5E+T)U
M<WD@55),(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$Q-R!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34Y"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<U"B,Z('1E;7!L
M871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$W"B,Z('1E
M;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C0T"FUS
M9VED(").86UE(@IM<V=S='(@(D[A>F5V(@H*(SH@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HT,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT-"!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z-#$*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C`*
M;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R(").;W;A(%5DX6QO<W0B"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,T"FUS9VED(").97AT(@IM<V=S
M='(@(D1A;+GM(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4W
M"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(D1A;+GM8V@@,C0@:&]D
M:6XB"@HC.B!L:6(O1D)6:65W+V1A>2YP:'`Z,CD*;7-G:60@(DYE>'0@1&%Y
M(@IM<V=S='(@(D1A;+GM($1E;B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D
M7W-I9&5?8GE?<VED92YI;F,Z-@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I
M9&5?8GE?<VED92YI;F,Z,3@@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C8*
M;7-G:60@(DYE>'0@36]N=&@B"FUS9W-T<B`B1&%LN>T@3>QS[6,B"@HC.B!L
M:6(O1D)6:65W+W=E96LN<&AP.C,R"FUS9VED(").97AT(%=E96LB"FUS9W-T
M<B`B1&%LN>T@5/UD96XB"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHV
M"B,L(&9U>GIY"FUS9VED(").97AT(%EE87(B"FUS9W-T<B`B1&%LN>T@1&5N
M(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT(&1A
M>2(*;7-G<W1R(")$86RY[2!D96XB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM<V=I9"`B
M3F5X="!W965K(@IM<V=S='(@(D1A;+GM('3]9&5N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(W-0HC+"!F=7IZ>0IM<V=I9"`B3F\B"FUS9W-T<B`B
M3GEN[2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C<S('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$R-@HC+"!F=7IZ>0IM<V=I9"`B3F\@86QA<FTB
M"FUS9W-T<B`B06QA<FTB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z-#@*;7-G:60@(DYO(&%T=&5N9&5E<R(*;7-G<W1R(")"97H@
M^NAA<W1N[6OY(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,0IM<V=I9"`B
M3F\@8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R
M("*NX61N_2!Z($MA;&5N9.'X^2!N96[M(&1O<W1U<&[]('!R;R!H;W-T>2XB
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S8@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C4U"FUS9VED(").;R!E;F0@9&%T92(*;7-G<W1R(")"
M97H@9&YE('5K;V[H96[M(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N
M<&AP.C$V-"!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ-C,*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C$Y-`IM<V=I9"`B3F\@979E;G1S('1O(&1I<W!L
M87DB"FUS9W-T<B`BKN%D;ND@=63A;&]S=&D@:R!Z;V)R87IE;NTB"@HC.B!L
M:6(O4W1O<F%G92]K;VQA8BYP:'`Z-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@)7,B
M"FUS9W-T<B`BKN%D;N$@9G)E92]B=7-Y(&EN9F]R;6%C92!N96[M(&1O<W1U
M<&[A('!R;R`E<R(*"B,Z(&QI8B]A<&DN<&AP.C,T-"!L:6(O87!I+G!H<#HV
M,#(*;7-G:60@(DYO(&E#86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T
M<B`B3F5B>6QA(&YA;&5Z96YA(+[A9&[A(&1A=&$@<')O(&E#86QE;F1A<BXB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#0*(RP@9G5Z>GD*;7-G
M:60@(DYO(')E8W5R<F5N8V4B"FUS9W-T<B`B3W!A:V]VX6[M(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z.#@V"FUS9VED(").;R!V86QI9"!E;6%I;"!A9&1R
M97-S(&9O=6YD(@IM<V=S='(@(DYE8GEL82!N86QE>F5N82"^X61NX2!P;&%T
M;N$@92UM86EL;W;A(&%D<F5S82(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8P
M,2!L:6(O2W)O;F]L:71H+G!H<#HV,C(*;7-G:60@(DYO;F4B"FUS9W-T<B`B
MKN%D;N$B"@HC.B!L:6(O4W1O<F%G92]S<6PN<&AP.C$S-@IM<V=I9"`B3F]T
M(&9O=6YD(@IM<V=S='(@(DYE;F%L97IE;F\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$*(RP@9G5Z>GD*;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS
M9W-T<B`B3>US=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHW.`IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3&ES=&]P860B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G
M<W1R(").>6[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z
M-S<*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BV.UJ96XB"@HC.B!T96UP;&%T
M97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,R!T96UP;&%T97,O961I="]E
M9&ET7W1I;65S<&%N+FEN8SHV-0IM<V=I9"`B3VXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.`IM<V=I9"`B3VX@86QL(&-A;&5N
M9&%R<R!)(&AA=F4@<F5A9"!A8V-E<W,@=&\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(W-PHC+"!F=7IZ>0IM<V=I9"`B3VX@86QL
M('-H;W=N(&-A;&5N9&%R<R(*;7-G<W1R(")/=FSA9.%N[2!P<F\@=GIDX6QE
M;ND@:V%L96YDX?AE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-@HC
M+"!F=7IZ>0IM<V=I9"`B3VX@;7D@8V%L96YD87)S(&]N;'DB"FUS9W-T<B`B
M2V%L96YDX?AE(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C$Y"FUS9VED(")/
M<'1I;VYA;"(*;7-G<W1R(").97!O=FEN;OTB"@HC.B!L:6(O1D)6:65W+G!H
M<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(D]P=&EO;F%L($%T=&5N9&5E<R(*;7-G
M<W1R("+:Z&%S="!N97!O=FEN;N$B"@HC.B!L:6(O1D)6:65W+G!H<#HQ-3(*
M;7-G:60@(D]V97)V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C,T"FUS9VED(")/=VYE<B(*;7-G<W1R(")6;&%S=&[M:R(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D]W;F5R.B`E<R(*;7-G<W1R(")6;&%S=&[M:R(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,3`R('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,3@R"FUS9VED(")032(*;7-G<W1R(")032(*"B,Z(&1A=&$N<&AP
M.C(Y('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30*;7-G:60@(E!A;&T@
M1&%T94)O;VLB"FUS9W-T<B`B4&%L;2!$871E0F]O:R(*"B,Z(&QI8B]";&]C
M:R]P<F5V;6]N=&AL:7-T+G!H<#HS"FUS9VED(")087-T($5V96YT<R!,:7-T
M(@IM<V=S='(@(E;]<&ES('!R;[EL[6-H('5DX6QO<W3M(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3`Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$Y.`IM<V=I9"`B4&%T=&5R;B(*;7-G<W1R(")6>F]R(@H*(SH@=&5M<&QA
M=&5S+V1E;&5T92]O;F4N:6YC.C(W"FUS9VED(")097)M86YE;G1L>2!D96QE
M=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`B4&5R;6%N96YT;NP@<VUA>F%T('1U
M=&\@=63A;&]S=#\B"@HC.B!L:6(O87!I+G!H<#HS,C4@;&EB+V%P:2YP:'`Z
M-#$Y(&QI8B]A<&DN<&AP.C0X,2!L:6(O87!I+G!H<#HU-3,*(SH@;&EB+V%P
M:2YP:'`Z-3@T(&QI8B]A<&DN<&AP.C8W,"!L:6(O87!I+G!H<#HW,#8*;7-G
M:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(DYE<&]V;VQE;OT@</CM
M<W1U<"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ
M-C<*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!RX79A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q"FUS9VED(")0;W)T86P@3W!T:6]N<R(*
M;7-G<W1R(")-;[YN;W-T:2!0;W)TX6QU(@H*(SH@;&EB+T9"5FEE=R]D87DN
M<&AP.C(U"FUS9VED(")0<F5V:6]U<R!$87DB"FUS9W-T<B`B4/AE9&-H;WKM
M($1E;B(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*;7-G:60@(E!R979I
M;W5S(%=E96LB"FUS9W-T<B`B4/AE9&-H;WKM(%3]9&5N(@H*(SH@=&5M<&QA
M=&5S+V1A>2]H96%D+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D87DB"FUS9W-T
M<B`B4/AE9&-H;WKM(&1E;B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$S-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-3(*;7-G:60@(E)E8W5R
M(%5N=&EL(@IM<V=S='(@(E)E:W5R>NUV;NP@8;X@9&\B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,#8*;7-G:60@(E)E8W5R<F5N8V4B"FUS9W-T
M<B`B3W!A:V]VX6[M(@H*(SH@9&%T82YP:'`Z-CD*;7-G:60@(E)E8W5R<F5N
M8V4@1&%T82(*;7-G<W1R(")/<&%K;W;A;NT@1&%T(@H*(SH@9&%T82YP:'`Z
M-C<*;7-G:60@(E)E8W5R<F5N8V4@16YD($1A=&4B"FUS9W-T<B`B1&%T=6T@
M3W!A:V]V86[M(&1O(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@(E)E8W5R<F5N
M8V4@26YT97)V86PB"FUS9W-T<B`B3W!A:V]V86/M($EN=&5R=F%L(@H*(SH@
M9&%T82YP:'`Z-C8*;7-G:60@(E)E8W5R<F5N8V4@5'EP92(*;7-G<W1R(")/
M<&%K;W9A8^T@5'EP(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30P"FUS9VED
M(")296-U<G,@9&%I;'DB"FUS9W-T<B`B3W!A:V]V870@9&5N;NPB"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HU-#<*;7-G:60@(E)E8W5R<R!M;VYT:&QY(@IM
M<V=S='(@(D]P86MO=F%T(&UE<^WH;NPB"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU-#,*;7-G:60@(E)E8W5R<R!W965K;'DB"FUS9W-T<B`B3W!A:V]V870@
M=/UD;NPB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3`*;7-G:60@(E)E8W5R
M<R!Y96%R;'DB"FUS9W-T<B`B3W!A:V]V870@<F_H;NPB"@HC.B!L:6(O4V-H
M961U;&5R+VMR;VYO;&ET:"YP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E;6EN9&5R.B`E<R(*;7-G<W1R(")5<&]M[6YK83H@)7,B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.3$@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0T"FUS9VED(")296UO=&4@0V%L96YD87)S(@IM<V=S='(@
M(E9Z9.%L96[I($MA;&5N9.'X92(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHV
M,"!T96UP;&%T97,O;65N=2YI;F,Z-C(*;7-G:60@(E)E;6]T92!#86QE;F1A
M<G,Z(@IM<V=S='(@(E9Z9.%L96[I($MA;&5N9.'X93HB"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(D]D<W1R86YI="`E<R(*"B,Z(&%T
M=&5N9&5E<RYP:'`Z,3`T"FUS9VED(")296UO=F4@071T96YD964B"FUS9W-T
M<B`B3V1S=')A;FET(-KH87-T;NUK82(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,S(*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@8V%L96YD
M87(@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H
M:7,@(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@8V%L
M96YD87(N/"]S=')O;F<^(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C8R-@IM<V=I9"`B4F5Q=6ER960B"FUS9W-T<B`B4&]V:6YNZ2(*"B,Z
M(&QI8B]&0E9I97<N<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S-R!L:6(O1D)6
M:65W+G!H<#HQ-#`@;&EB+T9"5FEE=RYP:'`Z,30S"FUS9VED(")297%U:7)E
M9"!!='1E;F1E97,B"FUS9W-T<B`B4&]V:6YN[2#:Z&%S=&[M8VDB"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHS-"!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHS,3`*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(E)E
M<V5T;W9A="!N82!);7!L:6-I=&[M($YA<W1A=F5N[2(*"B,Z('1E;7!L871E
M<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,R!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ-C8*;7-G:60@(E)E<W!O;G-E(@IM<V=S='(@(D]D<&]V[.\B
M"@HC.B!Y96%R+G!H<#HX."!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C,*(SH@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(E-O(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(Q('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R,`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,PIM
M<V=I9"`B4V%T=7)D87DB"FUS9W-T<B`B4V]B;W1A(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B
M4V%V92(*;7-G<W1R(")3;R(*"B,Z('9I97=E=F5N="YP:'`Z,3$X(&5D:71E
M=F5N="YP:'`Z-#@@961I=&5V96YT+G!H<#HU-@IM<V=I9"`B4V%V92!!<R!.
M97<B"FUS9W-T<B`B56QOOFET($IA:V\@3F]V;W4B"@HC.B!T96UP;&%T97,O
M871T96YD965S+V%T=&5N9&5E<RYI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E-A
M=F4@071T96YD965S(@IM<V=S='(@(MKH87-T;NUC:2(*"B,Z(&%D9&5V96YT
M+G!H<#HU-2!E9&ET979E;G0N<&AP.C4Q"FUS9VED(")3879E($5V96YT(@IM
M<V=S='(@(E5L;[YI="!59.%L;W-T(@H*(SH@<V5A<F-H+G!H<#HY,2!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$U"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHV-R!T96UP;&%T97,O8V%L96YD87)S
M+W-E87)C:"YI;F,Z.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$T,"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(E9Y:&QE9&%T(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]S96%R8V@N:6YC.C$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!#86QE;F1A
M<G,B"FUS9W-T<B`B4V3M;&5NZ2!+86QE;F3A^&4Z(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]H96%D97(N:6YC.C8*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!2
M97-U;'1S(@IM<V=S='(@(E9Y:&QE9&%T(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]S96%R8V@N:6YC.C8*;7-G:60@(E-E87)C:"!F;W(@8V%L96YD87)S
M(&-O;G1A:6YI;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A
M<G,O8V%L96YD87)S+FEN8SHQ-3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A
M(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T<B`B5GEB<F%T(&MA;&5N9.'X(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C@S"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(E9Y8G)A="!D871U;2(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&-A;&5N9&%R<R!T;R!D:7-P;&%Y.B(*;7-G
M<W1R(")6>6)R870@:V%L96YDX?@@<')O(&EM<&]R=&]VX6[M.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B(@HB4V5L96-T(&-O;F9I
M<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT
M('9I97=S(&%N9"!C:&]O<V4@(@HB9&5F875L="!V:65W+B(*;7-G<W1R("(B
M"B)6>6)R870@;6^^;F]S=&D@<&]T=G)Z96[M+"!R^7INZ2!Z;V)R87IE;NT@
M82!V>6)E<F%T(&EM<&QI8VET;NT@>F]B<F%Z96[M+B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,3D*;7-G:60@(E-E;&5C="!T:&4@8V%L96YD
M87(@=&\@:6UP;W)T('1O.B(*;7-G<W1R(")6>6)R870@:V%L96YDX?@@<')O
M(&EM<&]R=&]VX6[M.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3(*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B
M5GEB<F%T(&9O<FWA="!E>'!O<G1U.B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,C@*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z
M(@IM<V=S='(@(E9Y8G)A="!S;W5B;W(@:R!I;7!O<G1O=N%N[3HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED(")396QE8W0@=&AE(&9I
M<G-T('=E96MD87DZ(@IM<V=S='(@(E9Y8G)A="!P<G9N[2!D96X@=/UD;F4Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0IM<V=I9"`B4V5L
M96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")6
M>6)R870@9F]R;>%T('ID<F]J;W;I:&\@<V]U8F]R=3HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@T"FUS9VED(")396QE8W0@=&AE('1I;64@<W!A
M;B!T;R!S:&]W.B(*;7-G<W1R(")6>6)R870@Z&%S;W;I(')O>G#L=.T@:R!Z
M;V)R87IE;NTZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED
M(")396QE8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O;B!S=&%R='5P.B(*;7-G
M<W1R(")6>6)R870@>F]B<F%Z96[M('!O('#X:6AL8;EE;NT@<V4Z("(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@IM<V=I9"`B4V5L96-T('=H:6-H
M(&5V96YT<R!T;R!S:&]W(&EN('1H92!P;W)T86PN(@IM<V=S='(@(E9Y8G)A
M="!J86OI('5DX6QO<W1I('-E(&UA:NT@>F]B<F%Z:70@=B!P;W)TX6QU+B(*
M"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR-"!T96UP;&%T97,O9&5L
M971E+V1E;&5T92YI;F,Z,C0*;7-G:60@(E-E;F0@82!C86YC96P@;F]T:69I
M8V%T:6]N('1O(&%L;"!A='1E;F1E97,@=VAE;B!D96QE=&EN9R!T:&ES(&5V
M96YT(@IM<V=S='(@(B(*(EIA<VQA="!Z<'+A=G4@;R!Z<G6Y96[M('5DX6QO
M<W1I(':Y96T@^NAA<W1N[6OY;2P@:V1YOB!S92!U9.%L;W-T('-M87KA=N$B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V5N9"!A;B!E;6%I;"!T;R`E<R(*;7-G<W1R("):87-L870@
M96UA:6P@)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#$*;7-G
M:60@(E-E;F0@=7!D871E<R]I;G9I=&%T:6]N<R!T;R!A;&P@871T96YD965S
M('=H96X@<V%V:6YG('1H:7,@979E;G0B"FUS9W-T<B`B6F%S;&%T(&%K='5A
M;&EZ86-I+W!O>G;A;FMU(':Y96T@^NAA<W1N[6OY;2P@:V1YOB!S92!U9.%L
M;W-T('5K;.%DX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C<V"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B6N'X[2(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"FUS9VED(")3970@96YD
M(&1A=&4B"FUS9W-T<B`B3F%S=&%V:70@:V]N9>AN_2!D871U;2(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(V.`IM<V=I9"`B4V5T(')E8W5R<F5N
M8V4@96YD(&1A=&4B"FUS9W-T<B`B2V]N9>AN_2!D871U;2!O<&%K;W9A;NTB
M"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0IM<V=I
M9"`B4V5T('-T87)T(&1A=&4B"FUS9W-T<B`B3F%S=&%V:70@9&%T=6T@>F'H
MX71K=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.0IM<V=I9"`B(@HB
M4V5T('EO=7(@9G)E92]B=7-Y(&-A;&5N9&%R<R!A;F0@>6]U<B!O=VX@86YD
M(&]T:&5R('5S97)S)R!F<F5E+V)U<WD@;W!T:6]N<RXB"FUS9W-T<B`B(@H*
M(SH@8V%L96YD87)S+G!H<#HW-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4VAA<F4@;F]T(&9O=6YD.B`E<R(*;7-G<W1R(")V179E;G0@;F5B>6P@
M;F%L97IE;BXB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z-SD*(RP@9G5Z>GD*;7-G:60@(E-H87)E9"!#86QE;F1A<G,B"FUS9W-T
M<B`B4V3M;&5NZ2!+86QE;F3A^&4Z(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC
M.C0W('1E;7!L871E<R]M96YU+FEN8SHT.0IM<V=I9"`B4VAA<F5D($-A;&5N
M9&%R<SHB"FUS9W-T<B`B4V3M;&5NZ2!+86QE;F3A^&4Z(@H*(SH@8V%L96YD
M87)?<V5A<F-H+G!H<#HR-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?
M<VED92YI;F,Z,PHC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E
M+FEN8SHS"B,L(&9U>GIY"FUS9VED(")3:&]W($-A;&5N9&%R(@IM<V=S='(@
M(DMA;&5N9.'X(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC
M.C(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W(&-A;&5N9&%R
M(%PB)7-<(B(*;7-G<W1R(")39.UL96[I($MA;&5N9.'X93HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34V"FUS9VED(")3:&]W(&-A=&5G;W)Y(&QE
M9V5N9#\B"FUS9W-T<B`B6F]B<F%Z:70@;&5G96YD=2!K871E9V]R:>T_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B4VAO=R!D96QE
M=&4L(&%L87)M+"!A;F0@<F5C=7)R96YC92!I8V]N<R!I;B!C86QE;F1A<B!V
M:65W<S\B"FUS9W-T<B`B(@HB6F]B<F%Z:70@:6MO;FMY('!R;R!S;6%ZX6[M
M+"!A;&%R;2!A(&]P86MO=N%N[2!P^&D@>F]B<F%Z;W;A;NT@:V%L96YDX?AE
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(E-H;W<@
M9'5E('1A<VMS(&EN('1H92!C86QE;F1A<C\B"FUS9W-T<B`B6F]B<F%Z:70@
M;^AE:^%V86[I('5D86QO<W1I('8@:V%L96YDX?AI/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-C8*;7-G:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N
M9#\B"FUS9W-T<B`B6F]B<F%Z:70@;&5G96YD=2!P<F\@9G)E92]B=7-Y/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@(E-H;W<@;VYL
M>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS9W-T<B`B36%J
M[2!S92!U:^%Z870@<&]U>F4@=63A;&]S=&D@<R!A;&%R;65M/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E-H;W<@
M<VAA<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_(@IM<V=S='(@(EIO8G)A
M>FET('-D[6QE;ND@:V%L96YDX?AE('9E9&QE('-E8F4_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(R,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T87-K
M<R!U<VEN9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(EIO8G)A>FET(&_H
M96OA=F%NZ2!U9&%L;W-T:2!V(&MA;&5N9.'X:3\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.34*;7-G:60@(E-H;W<@=&EM92!O9B!D87D@8F5T=V5E
M;B!E86-H(&1A>2!I;B!W965K('9I97=S/R(*;7-G<W1R("):;V)R87II="#H
M87,@;65Z:2!K8;YD_6T@9&YE;2!V('3]9&5N;NUM('IO8G)A>F5N[3\B"@HC
M.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B4W1A7W)T(@IM<V=S='(@(EIAZ%_M;N$@5B(*"B,Z(&1A=&$N
M<&AP.C4U"FUS9VED(")3=&%R="!$871E(@IM<V=S='(@(D1A='5M(%IAZ.%T
M:W4B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C<@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHR-0IM<V=I9"`B4W1A<G0@3VXB"FUS9W-T<B`B6F'H[6[A
M(%8B"@HC.B!D871A+G!H<#HU-@IM<V=I9"`B4W1A<G0@5&EM92(*;7-G<W1R
M("+(87,@6F'HX71K=2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHY-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHX-0IM<V=I
M9"`B4W1A=%]U<R(*;7-G<W1R(")3=&%?=B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O979E;G1?:&5A9&5R<RYI;F,Z-B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHR-PIM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T878B"@HC.B!Y96%R+G!H
M<#HX,2!Y96%R+G!H<#HY,"!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV-0HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C0@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ,#<@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#D*;7-G:60@
M(E-U(@IM<V=S='(@(DYE(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC
M.C$T('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,PHC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI
M;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I9"`B4W5N
M9&%Y(@IM<V=S='(@(DYE9.QL92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B563A;&]S=&DB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HU-S0@;&EB+TMR;VYO;&ET:"YP:'`Z-3DW"FUS9VED
M(")496YT871I=F4B"FUS9W-T<B`B4/AE9&+LOF[](@H*(SH@>65A<BYP:'`Z
M.#8@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C(@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U
M"FUS9VED(")4:"(*;7-G<W1R("+(="(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z-S`*;7-G:60@(E1H92!%9&ET($%T=&5N9&5E<R!S
M8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N($5X:71I;F<N(@IM<V=S='(@
M(E-T<N%N:V$@<R!5<')A=F]U(-KH87-T;NUK^2!J:;X@;F5N[2X@2V]NZ.UM
M+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&-A;&5N9&%R(%PB)7-<(B!C86YN;W0@8F4@9&5L971E9"XB"FUS9W-T
M<B`B3F5L>F4@<VUA>F%T(&MA;&5N9.'X(%PB)7-<(BXB"@HC.B!C86QE;F1A
M<G,N<&AP.C0P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L
M96YD87(@7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(DMA;&5N
M9.'X(%PB)7-<(B!B>6P@<VUA>N%N+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")+86QE;F3A^"!<(B5S7"(@8GEL('-M
M87KA;BXB"@HC.B!C86QE;F1A<G,N<&AP.C4T"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@<F5N86UE9"!T;R!<
M(B5S7"(N(@IM<V=S='(@(DMA;&5N9.'X(%PB)7-<(B!B>6P@</AE:FUE;F]V
MX6X@;F$@7"(E<UPB+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`B2V%L96YDX?@@7"(E<UPB(&)Y;"!U;&^^96XN(@H*(SH@
M9&%T82YP:'`Z,C(V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M8V%L96YD87(@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B3F5L
M>F4@<VUA>F%T(&MA;&5N9.'X(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O961I
M="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@(E1H92!E;F0@9&%T92!M=7-T
M(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N(@IM<V=S='(@(D1A='5M
M(&MO;F-E(&UU<^T@8OUT('!O(&1A='4@>F'HX71K=2XB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,#DT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&%D9&5D+"!W:&EC:"!I<R!O;B`E
M<R!A="`E<RXB"FUS9W-T<B`B2V%L96YDX?@@7"(E<UPB(&)Y;"!P^&5J;65N
M;W;A;B!N82!<(B5S7"(N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+"!W:&EC:"!W87,@;VX@)7,@870@)7,N(@IM<V=S
M='(@(DMA;&5N9.'X(%PB)7-<(B!B>6P@<VUA>N%N+B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$P.3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!E=F5N="!<(B5S7"(@:&%S(&)E96X@961I=&5D+"!W:&EC:"!I<R!O;B`E
M<R!A="`E<RXB"FUS9W-T<B`B2V%L96YDX?@@7"(E<UPB(&)Y;"!P^&5J;65N
M;W;A;B!N82!<(B5S7"(N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@;F]T:69I8V%T:6]N('1O
M("5S('=A<R!S=6-C97-S9G5L;'D@<V5N="XB"FUS9W-T<B`B57!O>F]R;NQN
M[2!O('5DX6QO<W1I(&)Y;&\@^G-P[+EN["!Z87-LX6YO('!R;R`E<RXB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(T"FUS9VED(")4:&4@9F]L;&]W:6YG
M(&ES(&$@;6]R92!D971A:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z
M(@IM<V=S='(@(D[A<VQE9'5J92!P;V1R;V)N[&JY[2!P;W!I<R!U9.%L;W-T
M:3HB"@HC.B!A='1E;F0N<&AP.C0Q"FUS9VED("(B"B)4:&4@<F5Q=65S="!W
M87,@:6YC;VUP;&5T92X@4V]M92!P87)A;65T97)S('1H870@87)E(&YE8V5S
M<V%R>2!T;R!A8V-E<'0@;W(@(@HB9&5C;&EN92!A;B!E=F5N="!A<F4@;6ES
M<VEN9RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E;7!T>2YI
M;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&5V96YT<R!M871C:&EN9R!T:&4@
M8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`BKN%D;ND@=63A;&]S=&D@<V4@
M;F5S:&]D=6KM('-E('-O=>AA<V[];2!K<FETZ7)I96TN(@H*(SH@861D979E
M;G1A8W1I;VXN<&AP.C$X(&5D:71E=F5N=&%C=&EO;BYP:'`Z,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%C8V5S<VEN9R!T
M:&4@8V%L96YD87(Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI('#X
M[7-T=7!U(&ME(&MA;&5N9.'X:3H@)7,B"@HC.B!A9&1E=F5N=&%C=&EO;BYP
M:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&%D9&EN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@
M</AI('#X:63A=N%N[2!U9.%L;W-T:3H@)7,B"@HC.B!E9&ET979E;G1A8W1I
M;VXN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!E9&ET:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P^&D@^G!R87;L('5DX6QO<W1I.B`E<R(*"B,Z(&QI8B]A<&DN<&AP
M.C,S."!L:6(O87!I+G!H<#HU.38*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")0^&D@
M:6UP;W)T;W;A;NT@:4-A;&5N9&%R(&1A="!D;[EL;R!K(&-H>6+L+B(*"B,Z
M(&5D:71E=F5N=&%C=&EO;BYP:'`Z-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S(@IM<V=S
M='(@(DYA<W1A;&$@8VAY8F$@</AI('!O<W5N=2!U9.%L;W-T:3H@)7,B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A
M=&EO;B!T;R`E<SH@)7,B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P^&D@>F%S
M[6SM;NT@;WINX6UE;NT@;R!U9.%L;W-T:2!P<F\@)7,Z("5S(@H*(SH@9&%T
M82YP:'`Z,3`U"FUS9VED(")4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O
M<G0N(@IM<V=S='(@(J[A9&[I('5DX6QO<W1I(&L@97AP;W)T;W;A;NTN(@H*
M(SH@9&%T82YP:'`Z,3@T"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(E1E;G1O(&9O<FWA="!S;W5B;W)U(&YE
M;'IE('!O=;[M="XB"@HC.B!D871A+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B5&]T;R!J92!Z<'+A=F$@>F4@<V5R=F5R=3H@)7,B"@HC.B!T96UP;&%T
M97,O;6]N=&@O:&5A9"YI;F,Z,3D@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,3$X"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<Q"FUS9VED
M(")4:'5R<V1A>2(*;7-G<W1R("+(='9R=&5K(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C,W"FUS9VED(")4:6UE(%-P7V%N(@IM<V=S='(@
M(LAA<V]VZ2!2;WI?<.QT[2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM
M97-P86XN:6YC.C0*;7-G:60@(E1I;64@<W!A;B(*;7-G<W1R("+(87-O=ND@
M4F]Z<.QT[2`B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E
M9"YI;F,Z,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z-#`*;7-G:60@(E1I
M=%]L92(*;7-G<W1R(")4:71?=6PB"@HC.B!D871A+G!H<#HU-"!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z,C`*(SH@=&5M<&QA=&5S+W-E87)C:"]E
M=F5N=%]H96%D97)S+FEN8SHS"FUS9VED(")4:71L92(*;7-G<W1R(")4:71U
M;"(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C(@;&EB+T)L
M;V-K+VUO;G1H;&ES="YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ,C<*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D1N97,B"@HC.B!L:6(O0FQO
M8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(T(&QI8B]";&]C:R]M;VYT:&QI<W0N
M<&AP.C$R,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(Y"FUS9VED(")4
M;VUO<G)O=R(*;7-G<W1R("):[71R82(*"B,Z('EE87(N<&AP.C@T('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8P('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(Q.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B
M5'4B"FUS9W-T<B`BVG0B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M,3<@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$V"B,Z('1E;7!L871E<R]E
M9&ET+VIA=F%S8W)I<'0N:6YC.C8Y"FUS9VED(")4=65S9&%Y(@IM<V=S='(@
M(MIT97+](@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")4>7!E(@IM<V=S='(@(E1Y<"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHQ.#,*;7-G:60@(E523"(*;7-G<W1R("(B"@HC.B!L
M:6(O4W1O<F%G92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(").96QZ92!S92!P^&EP;VII="!N
M82!344P@<V5R=F5R+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S
M='(@(DYE;'IE('-M87IA="!<(B5S7"(Z("5S+B(*"B,Z(&QI8B]$<FEV97(O
M;6-A;"YP:'`Z,3,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)7,N(@IM<V=S='(@(DYE;'IE('-M87IA="`E<RXB"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(D1E9FEN:6-E
M("5S(&YE;NT@9&]S='5P;N$N(@H*(SH@8V%L96YD87)S+G!H<#HU,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B3F5L>F4@</AE:FWL;F]V870@7"(E<UPB.B`E<R(*"B,Z(&QI
M8B]3=&]R86=E+VMO;&%B+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O<B`E
M<R(*;7-G<W1R(").96QZ92!Z:FES=&ET(&EN9F]R;6%C[2!F<F5E+V)U<WD@
M<'(@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-0HC.B!S8W)I
M<'1S+W5P9W)A9&5S+S(P,#0M,#4M,3E?8V]N=F5R=%]C871E9V]R:65S7W1O
M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DYE=GEP
M;&[L;F\B"@HC.B!L:6(O87!I+G!H<#HS-S8@;&EB+V%P:2YP:'`Z-#4P(&QI
M8B]A<&DN<&AP.C4Q-B!L:6(O87!I+G!H<#HV,C$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS
M9W-T<B`B3F5P;V1P;W)O=F%N_2!4>7`@3V)S86AU("A#;VYT96YT+51Y<&4I
M+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E9#H@)7,N(@IM<V=S='(@(D%K='5A;&EZ;W;A;FEO.B`E
M<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*;7-G:60@(E5S97(@
M26YT97)F86-E(@IM<V=S='(@(E6^:79A=&5L<VOI(%)O>FAR86[M(@H*(SH@
M>65A<BYP:'`Z,38S('EE87(N<&AP.C$V.2!L:6(O0FQO8VLO;6]N=&@N<&AP
M.C$U.2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$V,@IM<V=I9"`B5FEE=R!$87DB
M"FUS9W-T<B`B6F]B<F%Z:70@1&5N(@H*(SH@>65A<BYP:'`Z.#4@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C$@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C(P"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")7
M92(*;7-G<W1R(")3="(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ
M."!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3<*(SH@=&5M<&QA=&5S+V5D
M:70O:F%V87-C<FEP="YI;F,Z-S`*;7-G:60@(E=E9&YE<V1A>2(*;7-G<W1R
M(")3=/AE9&$B"@HC.B!A='1E;F1E97,N<&AP.C$Q,B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,CDP(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(S"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E:R(*;7-G<W1R(")4_61E
M;B(*"B,Z(&UO;G1H+G!H<#HQ-SD@=V]R:W=E96LN<&AP.C,P('=E96LN<&AP
M.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E=E96L@)60B"FUS9W-T<B`B5/UD
M96X@)60B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU.2!T96UP;&%T
M97,O961I="]E9&ET+FEN8SHQ-#`*;7-G:60@(E=E96LH<RDB"FUS9W-T<B`B
M5/UD96XH>2DB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C(@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"FUS9VED(")7965K;'DZ(%)E8W5R
M<R!E=F5R>2(*;7-G<W1R(")4_61N[#H@4F5K=7)Z[79N["!K8;YD_2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(B(*(E=H870@=&EM
M92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A
M<F4@;F\@;&%T97(@979E;G1S/R(*;7-G<W1R("(B"B)+9'D@;>$@Z&%S;W;I
M('IO8G)A>F5N:2!D;F4@82!T_61N92!K;V[H:70L('!O:W5D(&YE;V)S86AU
M:NT@<&]Z9&YI('5DX6QO<W1I/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,34*;7-G:60@(B(*(E=H870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K
M('9I97=S('-T87)T+"!W:&5N('1H97)E(&%R92!N;R!E87)L:65R(&5V96YT
M<S\B"FUS9W-T<B`B(@HB2V1Y(&WA(.AA<V]VZ2!Z;V)R87IE;FD@9&YE(&$@
M=/UD;F4@>F'H[70L('!O:W5D(&YE;V)S86AU:NT@Z&%S;ND@=63A;&]S=&D_
M(@H*(SH@871T96YD965S+G!H<#HQ,3$@;&EB+TMR;VYO;&ET:"YP:'`Z,3(X
M.2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#0*;7-G:60@(E=O<FL@5V5E:R(*;7-G<W1R(")0<F%C;W9N
M[2!4_61E;B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$R.3(@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(EEE87(B"FUS9W-T
M<B`B5GEH;&5D870B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C0Q"FUS9VED(")996%R;'DZ(%)E
M8W5R<R!E=F5R>2(*;7-G<W1R(")2;^AN[#H@4F5K=7)Z[79N["!K8;YD_2(*
M"B,Z(&1A=&$N<&AP.C0P(&1A=&$N<&AP.C(S-"!E9&ET979E;G1A8W1I;VXN
M<&AP.C0V(&%D9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@979E
M;G1S+B(*;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Y"FUS9VED(")9;W4@
M87)E(&YO="!A;B!A='1E;F1E92!O9B!T:&4@<W!E8VEF:65D(&5V96YT+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C<V"FUS9VED(")9;W4@8V%N(&]N;'D@=7-E('1H:7,@9F]R;2!F<F]M('1H
M92!%9&ET($%T=&5N9&5E<R!S8W)E96XN(@IM<V=S='(@(E1E;G1O(&9O<FUU
M;.'X(&QZ92!P;W5Z92!P;W6^[70@>F4@<W1RX6YK>2#:<')A=GD@VNAA<W1N
M[6OY+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.CDW,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U(&1O(&YO="!H879E(&%N(&5M86EL(&%D
M9')E<W,@8V]N9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T:6]N
M("(*(D]P=&EO;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F;W)E
M(&5V96YT(&YO=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N(@IM<V=S='(@(B(*
M(DYE=61A;&D@:G-T92!E;6%I;&]V;W4@861R97-U('8@;F%S=&%V96[M(&ED
M96YT:71Y+B!!;&5S<&_R(&IE9&YA(&UU<^T@8OUT("(*(GIA9.%N82XB"@HC
M.B!A9&1E=F5N=&%C=&EO;BYP:'`Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E
M<RXB"FUS9W-T<B`B3F5D;W-T871EZ&[A('!RX79A('!R;R!P^&EDX6[M('5D
MX6QO<W3M(&1O("5S+B(*"B,Z(&1A=&$N<&AP.C$Y-`IM<V=I9"`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R!T:&4@<V5L
M96-T960@8V%L96YD87(N(@IM<V=S='(@(DYE9&]S=&%T9>ANX2!P<N%V82!P
M<F\@</AI9.%N[2!U9.%L;W-T[2!D;R!V>6)R86[I:&\@:V%L96YDX?AE+B(*
M"B,Z(&1E;&5V96YT86-T:6]N+G!H<#HR-@IM<V=I9"`B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N(@IM<V=S='(@
M(DYE9&]S=&%T9>ANX2!P<N%V82!P<F\@<VUA>N%N[2!TZ71O('5DX6QO<W1I
M+B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z-S@*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="XB"FUS9W-T
M<B`B3F5D;W-T871EZ&[A('!RX79A('!R;R#Z<')A=G4@=.ET;R!U9.%L;W-T
M:2XB"@HC.B!D871A+G!H<#HQ.#D*;7-G:60@(EEO=2!H879E('-P96-I9FEE
M9"!A;B!I;G9A;&ED(&-A;&5N9&%R+B(*;7-G<W1R(")">6P@>F%DX6X@;F5I
M<&QA=&[](&MA;&5N9.'X+B(*"B,Z(&%T=&5N9"YP:'`Z,C$*;7-G:60@(EEO
M=2!H879E('-U8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H
M:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,C8*(RP@9G5Z
M>GD*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E
M;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(DYE9&]S=&%T9>ANX2!P
M<N%V82!P<F\@<VUA>N%N[2!TZ71O('5DX6QO<W1I+B(*"B,Z(&%T=&5N9"YP
M:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E('1E;G1A=&EV96QY(&%C
M8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB"FUS9W-T<B`B3F5D
M;W-T871EZ&[A('!RX79A('!R;R!S;6%ZX6[M('3I=&\@=63A;&]S=&DN(@H*
M(SH@8V%L96YD87)S+G!H<#HY,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@
M8V%L96YD87(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B375S[71E('9Y8G)A
M="!K86QE;F3A^"P@:W1E<OT@8G5D92!S;6%ZX6XN(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHU-`IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(DUU<^UT92!N96ID^.UV
M92!V>6)R870@96UA:6QO=F]U(&%D<F5S=2XB"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,#DT"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D
M('=H96X@979E;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`IM<V=I9"`B(@HB
M66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@
M9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,#DY"FUS9VED(")9;W4@<F5Q=65S=&5D('1O
M(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E9&ET960@:6X@>6]U<B!C
M86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]38VAE9'5L97(O:W)O;F]L
M:71H+G!H<#HR,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!R
M97%U97-T960@=&\@8F4@<F5M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N
M("5S(&%T("5S+B(*;7-G<W1R("*NX61A;&D@:G-T92!O('#X:7!O;65N=73M
M('5DX6QO<W1I("5S+"!K=&5RX2!J92!V("5S+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*;7-G:60@(EEO=7(@9&5F875L="!C
M86QE;F1A<B(*;7-G<W1R(")6X;D@:6UP;&EC:71N[2!K86QE;F3A^"(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$P-3,@;&EB+T1R:79E<BYP:'`Z,3`V,PIM<V=I
M9"`B6U5N;F%M960@979E;G1=(@IM<V=S='(@(EM59.%L;W-T(&)E>B!NX7IV
M=5TB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHY-PHC+"!F=7IZ>0IM
M<V=I9"`B7T%L87)M(@IM<V=S='(@(D%L87)M(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q"FUS9VED(")?0F%S:6,@4V5A
M<F-H(@IM<V=S='(@(E]6>6AL961A="(*"B,Z('9I97=E=F5N="YP:'`Z,3(P
M"FUS9VED(")?161I="(*;7-G<W1R(")?57!R879I="(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$S,S`*;7-G:60@(E]';W1O(@IM<V=S='(@(E]*[70@;F$B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,V"FUS9VED(")?26UP;W)T+T5X
M<&]R="(*;7-G<W1R(")?26UP;W)T;W9A="]%>'!O<G1O=F%T(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3,Q.`IM<V=I9"`B7TUY($-A;&5N9&%R<R(*;7-G
M<W1R(")?2V%L96YDX?AE(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,R-0IM
M<V=I9"`B7TYE=R!%=F5N="(*;7-G<W1R(")?3F]VX2!59.%L;W-T(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,T,0IM<V=I9"`B7U!R:6YT(@IM<V=S='(@
M(E]4:7-K(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,@IM<V=I9"`B7U-E
M87)C:"(*;7-G<W1R(")?5GEH;&5D870B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,S(X"FUS9VED(")?5&]D87DB"FUS9W-T<B`B7T1N97,B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ-#(*;7-G:60@(F)E9F]R92!T:&4@979E
M;G0@<W1A<G1S(@IM<V=S='(@(G#X960@>F'HX71K96T@=63A;&]S=&DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@U"FUS9VED(")D87DB"FUS9W-T
M<B`B9&5N(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(Q,`IM<V=I9"`B9&%Y*',I(@IM<V=S='(@
M(F1E;BAD;GDI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(F1N>2(*"B,Z
M(&1A=&$N<&AP.C$T-R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G
M:60@(F5V96YT<RYC<W8B"FUS9W-T<B`B=63A;&]S=&DN8W9S(@H*(SH@9&%T
M82YP:'`Z,38X"FUS9VED(")E=F5N=',N:6-S(@IM<V=S='(@(G5D[6QO<W1I
M+FEC<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3,Q
M"FUS9VED(")F<F]M(@IM<V=S='(@(F]D(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(T('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,S`@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C,V"FUS9VED(")M;VYT:"AS*2(*;7-G<W1R(")M['/M8RAE*2(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,C`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(F]N("5S(&%T("5S(@IM<V=S='(@(E5DX6QO<W0@;V0@)7,@
M9&\@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C,P"FUS9VED(")O;B!T:&4@<V%M92!D871E
M(@IM<V=S='(@(G9E('-T96INZ6T@9&YU(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S-@IM<V=I
M9"`B;VX@=&AE('-A;64@=V5E:V1A>2(*;7-G<W1R(")V92!S=&5J;NEM('3]
M9&YU(@H*(SH@9&%T82YP:'`Z,S`@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ-0IM<V=I9"`B=D-A;&5N9&%R+VE#86QE;F1A<B(*;7-G<W1R(")V0V%L
M96YD87(O:4-A;&5N9&%R(@H*(SH@;&EB+V%P:2YP:'`Z,S0Y(&QI8B]A<&DN
M<&AP.C8P-PIM<V=I9"`B=D5V96YT(&YO="!F;W5N9"XB"FUS9W-T<B`B=D5V
M96YT(&YE8GEL(&YA;&5Z96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y,0IM<V=I9"`B=V5E:R(*;7-G<W1R(")T_61E;B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,3<*;7-G:60@(G=E96LH<RD@;VXZ(@IM<V=S='(@(G3]9&5N*'3]9&YY*2!V
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3(@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DT"FUS
M9VED(")W965K<R(*;7-G<W1R(")T_61N>2(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-#(*;7-G
M:60@(GEE87(H<RDB"FUS9W-T<B`B<F]K*'DI(@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:W)O;F]L:71H+W!O+W!T7T)2+G!O````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$S-#$U-@`Q,#0Q-S,V,C<U,P`P,C`T
M,S``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R!T<F%N<VQA=&EO;B!O9B!K<F]N;VQI=&@N<&\@=&\@0G)A>FEL:6%N(%!O
M<G1U9W5E<V4*(R!#;W!Y<FEG:'0@*$,I(%E%05(@2&]R9&4@4')O:F5C=`HC
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!+<F]N;VQI=&@@<&%C:V%G92X*(PHC($9A8FEO($=O;65S
M(#QF;&=O;7-`=6]L+F-O;2YB<CXL(#(P,#8N"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!+<F]N;VQI=&A<;B(*(E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E
M871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I
M<VEO;BU$871E.B`R,#`V+3`R+3$V(#$V.C0P+3`R,#!<;B(*(DQA<W0M5')A
M;G-L871O<CH@1F%B:6\@1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@0G)A>FEL:6%N(%!O<G1U9W5E<V4@/&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)8+4=E;F5R871O
M<CH@2T)A8F5L(#$N,RXQ7&XB"B)0;'5R86PM1F]R;7,Z("!N<&QU<F%L<STR
M.R!P;'5R86P]*&X@/B`Q*3M<;B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M<V5A<F-H+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!C86QE;F1A
M<G,@9F]U;F0B"FUS9W-T<B`B)60@86=E;F1A<R!NXV\@96YC;VYT<F%D87,B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!E=F5N=',B"FUS9W-T<B`B)60@979E;G1O<R(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$R,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!$87DH<RD@)7,@2&]U<BAS*2`E<R!-:6YU=&5S
M(@IM<V=S='(@(B5S($1I82AS*2`E<R!(;W)A*',I("5S($UI;G5T;W,B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ.#`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&%T=&5N9&5E<R(*;7-G<W1R("(E<R!P87)T:6-I<&%N=&5S(@H*(SH@9&%T
M82YP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S
M<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(D%R<75I=F\@)7,@:6UP;W)T861O
M(&-O;2!S=6-E<W-O(@H*(SH@8V%L96YD87)S+G!H<#HQ,#4@;&EB+V)A<V4N
M<&AP.C$R.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM
M<V=S='(@(D%G96YD82!D92`E<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M<V5A<F-H+FEN8SHQ-PIM<V=I9"`B(@HB*$-L:6-K(&]N(&-A;&5N9&%R(&YA
M;64@=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE
M(&UA:6X@(@HB=VEN9&]W*2(*;7-G<W1R("(B"B(H0VQI<75E(&YO(&YO;64@
M9&$@86=E;F1A('!A<F$@86QT97)A<B!A('9I<W5A;&EZ8>?C;R!D82!A9V5N
M9&$@;F$@:F%N96QA("(*(G!R:6YC:7!A;"DB"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$V-`IM<V=I9"`B*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@061D("HB"FUS9W-T<B`B*B!!9&EC:6]N92!E<W1E<R!C;&EC
M86YD;R!E;2!!9&EC:6]N87(@*B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,34P"FUS9VED("(J(%!L96%S92!S96QE8W0@861D<F5S
M<RAE<RD@*B(*;7-G<W1R("(J(%!O<B!F879O<B!S96QE8VEO;F4@;RAS*2!E
M;F1E<F7G;RAS*2`J(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@P-0IM<V=I9"`B
M,2!A='1E;F1E92(*;7-G<W1R("(Q('!A<G1I8VEP86YT92(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"FUS9VED("(Q(&5V96YT(@IM<V=S
M='(@(C$@979E;G1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM
M<V=I9"`B,2!H;W5R(@IM<V=S='(@(C$@:&]R82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S0*;7-G:60@(C$U(&UI;G5T97,B"FUS9W-T<B`B,34@
M;6EN=71O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@
M(C(P(&UI;G5T97,B"FUS9W-T<B`B,C`@;6EN=71O<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(C,P(&UI;G5T97,B"FUS9W-T<B`B
M,S`@;6EN=71O<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$V.0IM
M<V=I9"`B/'-T<F]N9SY!='1E;F1E97,\+W-T<F]N9SX@*&]P=&EO;F%L*2(*
M;7-G<W1R("(\<W1R;VYG/E!A<G1I8VEP86YT97,\+W-T<F]N9SX@*&]P8VEO
M;F%L*2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$T-PIM<V=I9"`B
M/'-T<F]N9SY$97-C<FE?<'1I;VX\+W-T<F]N9SX@*&]P=&EO;F%L*2(*;7-G
M<W1R("(\<W1R;VYG/D1?97-C<FGGXV\\+W-T<F]N9SX@*&]P8VEO;F%L*2(*
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(W-`IM<V=I9"`B/'-T<F]N
M9SY+97EW;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQS=')O
M;F<^4&%L879R87,M8VAA=F4\+W-T<F]N9SX@*&]P8VEO;F%L*2(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y,@IM<V=I9"`B/'-T<F]N9SY296-U
M<G)E;F-E/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9SY2
M97!E=&GGXV\\+W-T<F]N9SX@*&]P8VEO;F%L*2(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,3`Q('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3@Q"FUS9VED(")!32(*;7-G<W1R(")!32(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C8P,@IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B06-E:71A(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9%]V86YC
M960@4V5A<F-H(@IM<V=S='(@(E!E<W%U:7-A($%?=F%NYV%D82(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,38Q('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")!9&0B"FUS9W-T<B`B
M061I8VEO;F%R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(*;7-G
M:60@(D%D9"!%=F5N="(*;7-G<W1R(")!9&EC:6]N87(@179E;G1O(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,S4*
M;7-G:60@(D%D9"!A(&YE=R!296UO=&4@0V%L96YD87(B"FUS9W-T<B`B061I
M8VEO;F%R('5M82!N;W9A($%G96YD82!296UO=&$B"@HC.B!A9&1E=F5N="YP
M:'`Z-C0*;7-G:60@(D%D9"!A(&YE=R!E=F5N="(*;7-G<W1R(")!9&EC:6]N
M87(@;F]V;R!E=F5N=&\B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z-S$*;7-G:60@(D%D9"!A='1E;F1E97,B"FUS9W-T<B`B061I
M8VEO;F%R('!A<G1I8VEP86YT97,B"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,C`*(SH@=&5M<&QA=&5S
M+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C<U"FUS9VED(")!9&1R97-S($)O
M;VLB"FUS9W-T<B`B0V%TX6QO9V\@9&4@16YD97)EYV]S(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS
M9W-T<B`B4&5S<75I<V$@079A;N=A9&$B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHU,PIM<V=I9"`B06QA<FTB"FUS9W-T<B`B079I<V\B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ-S@Q"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M
M("5D(&1A>7,@8F5F;W)E(@IM<V=S='(@(D%V:7-A<B`E9"!D:6%S(&%N=&5S
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!;&%R;2`E9"!H;W5R<R!B969O<F4B"FUS9W-T<B`B079I<V%R("5D(&AO
M<F%S(&%N=&5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<Y,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!;&%R;2`E9"!M:6YU=&5S(&)E9F]R92(*;7-G<W1R(")!
M=FES87(@)60@;6EN=71O<R!A;G1E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@=V5E:W,@8F5F;W)E
M(@IM<V=S='(@(D%V:7-A<B`E9"!S96UA;F%S(&%N=&5S(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3<X,`IM<V=I9"`B06QA<FT@,2!D87D@8F5F;W)E(@IM<V=S
M='(@(D%V:7-A<B`Q(&1I82!A;G1E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W
M.#4*;7-G:60@(D%L87)M(#$@:&]U<B!B969O<F4B"FUS9W-T<B`B079I<V%R
M(#$@:&]R82!A;G1E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W.3`*;7-G:60@
M(D%L87)M(#$@;6EN=71E(&)E9F]R92(*;7-G<W1R(")!=FES87(@,2!M:6YU
M=&\@86YT97,B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<U"FUS9VED(")!;&%R
M;2`Q('=E96L@8F5F;W)E(@IM<V=S='(@(D%V:7-A<B`Q('-E;6%N82!A;G1E
M<R(*"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!$871E(@IM<V=S='(@
M(D1A=&$@9&\@879I<V\B"@HC.B!D871A+G!H<#HU.`IM<V=I9"`B06QA<FT@
M4W!A;B`H;6EN=71E<RDB"FUS9W-T<B`B1'5R8>?C;R!D;R!!=FES;R`H;6EN
M=71O<RDB"@HC.B!D871A+G!H<#HV,`IM<V=I9"`B06QA<FT@5&EM92(*;7-G
M<W1R(")(;W+A<FEO(&1O($%V:7-O(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D
M96QE=&4N:6YC.C,T"FUS9VED(")!;&PB"FUS9W-T<B`B5&]D;W,B"@HC.B!L
M:6(O1D)6:65W+G!H<#HQ,C@@;&EB+T9"5FEE=RYP:'`Z,3,Q(&QI8B]&0E9I
M97<N<&AP.C$S-`IM<V=I9"`B06QL($%T=&5N9&5E<R(*;7-G<W1R(")4;V1O
M<R!087)T:6-I<&%N=&5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C4Y"FUS9VED(")!;&P@1G5T=7)E(@IM<V=S='(@(E1O9&]S($9U='5R
M;W,B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3,*;7-G:60@
M(D%L;"!087-T(@IM<V=S='(@(E1O9&]S(%!A<W-A9&]S(@H*(SH@;&EB+T)L
M;V-K+W!R979M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,C0*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C(U"FUS9VED(")!;&P@5FES:6)L92(*;7-G<W1R(")4;V1O
M<R!6:7/M=F5I<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C$R,B!L:6(O1&%Y5FEE=RYP:'`Z.3`@;&EB+T1A>59I97<N<&AP.CDS
M"B,Z(&QI8B]7965K5FEE=RYP:'`Z,3(W(&QI8B]7965K5FEE=RYP:'`Z,3,T
M(&QI8B]$<FEV97(N<&AP.C$X-C@*;7-G:60@(D%L;"!D87DB"FUS9W-T<B`B
M1&EA('1O9&\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,38T"FUS9VED
M(")!;&P@9&%Y(&5V96YT(@IM<V=S='(@(D5V96YT;R!O(&1I82!T;V1O(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM<V=I9"`B06QL(&5V
M96YT<R(*;7-G<W1R(")4;V1O<R!E=F5N=&]S(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C0X"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,"!L:6(O2W)O;F]L:71H+G!H<#HV
M.34*;7-G:60@(D%N>2(*;7-G<W1R(")1=6%L<75E<B!U;2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!<')I;"(*;7-G
M<W1R(")!8G)I;"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C,Y('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.CDS"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-S`@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ-38*;7-G:60@(D%T(@IM<V=S='(@(L!S(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3`T-@IM<V=I9"`B(@HB071T86-H960@:7,@86X@
M:4-A;&5N9&%R(&9I;&4@=VET:"!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('1H
M92!E=F5N="X@268@>6]U<B`B"B)M86EL(&-L:65N="!S=7!P;W)T<R!I5&EP
M(')E<75E<W1S('EO=2!C86X@=7-E('1H:7,@9FEL92!T;R!E87-I;'D@=7!D
M871E("(*(GEO=7(@;&]C86P@8V]P>2!O9B!T:&4@979E;G0N(@IM<V=S='(@
M(B(*(E-E(&5N8V]N=')A(&%N97AA9&\@=6T@87)Q=6EV;R!I0V%L96YD87(@
M8V]M(&UA:7,@:6YF;W)M8>?U97,@<V]B<F4@;R`B"B)E=F5N=&\N(%-E('-E
M=2!C;&EE;G1E(&1E(&-O<G)E:6\@<W5P;W)T82!R97%U:7-IY_5E<R!I5&EP
M+"!V;V/J('!O9&4@(@HB=71I;&EZ87(@97-T92!A<G%U:79O('!A<F$@871U
M86QI>F%R(&9A8VEL;65N=&4@<W5A(&/S<&EA(&QO8V%L(&1O(&5V96YT;RXB
M"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#(@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38U"FUS9VED(")!='1E;F1A;F-E(@IM
M<V=S='(@(E!R97-E;N=A(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,38Q"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B4&%R=&EC:7!A;G1E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<U"FUS9VED(")!
M=6=U<W0B"FUS9W-T<B`B06=O<W1O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C$Q('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHX"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B4&5S<75I<V$@
M4VEM<&QE<R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I
M9"`B0FER=&AD87DB"FUS9W-T<B`B06YI=F5R<^%R:6\B"@HC.B!L:6(O1D)6
M:65W+G!H<#HY,"!L:6(O1D)6:65W+G!H<#HQ,3$*;7-G:60@(D)U<WDB"FUS
M9W-T<B`B3V-U<&%D;R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHT,@IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S='(@(E]!9V5N
M9&$B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHT-PIM<V=I9"`B0V%L
M7V5N9&%R(@IM<V=S='(@(D%G7V5N9&$B"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z,30V(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T
M+G!H<#HR,0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C(Q(&QI8B]";&]C:R]M
M;VYT:&QI<W0N<&AP.C(Q(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR,@IM<V=I
M9"`B0V%L96YD87(B"FUS9W-T<B`B06=E;F1A(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C,*;7-G:60@(D-A;&5N9&%R(%-U;6UA<GDB"FUS9W-T<B`B
M4F5S=6UO(&1A($%G96YD82(*"B,Z(&1A=&$N<&AP.C(R.0IM<V=I9"`B0V%L
M96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS9W-T<B`B02!A9V5N9&$@
M9F]I(')E;6]V:61A(&-O;2!S=6-E<W-O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-PIM
M<V=I9"`B0V%L96YD87)S(@IM<V=S='(@(D%G96YD87,B"@HC.B!C86QE;F1A
M<G,N<&AP.C(W"FUS9VED(")#86QE;F1A<G,@;75S="!H879E(&$@;F%M92XB
M"FUS9W-T<B`B06=E;F1A<R!D979E;2!P;W-S=6ER('5M(&YO;64N(@H*(SH@
M9&%T82YP:'`Z,C0T"FUS9VED(")#86XG="!C<F5A=&4@82!N97<@979E;G0N
M(@IM<V=S='(@(D[C;R!C;VYS:6=O(&-R:6%R('5M(&YO=F\@979E;G1O+B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DQ('1E;7!L
M871E<R]D96QE=&4O;VYE+FEN8SHS,PHC.B!T96UP;&%T97,O9&5L971E+V1E
M;&5T92YI;F,Z,S4@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S$*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,S`W"FUS9VED(")#86YC96PB"FUS9W-T
M<B`B0V%N8V5L87(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S@*;7-G:60@
M(D-A;F-E;&QE9"(*;7-G<W1R(")#86YC96QA9&\B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D-A;F-E;&QE9#H@
M)7,B"FUS9W-T<B`B0V%N8V5L861O.B`E<R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV,R!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHV-PIM<V=I9"`B0V%T96=O<E]Y(@IM<V=S='(@(D-?871E9V]R:6$B
M"@HC.B!D871A+G!H<#HV,B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E
M<G,N:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*;7-G:60@(D-A
M=&5G;W)Y(@IM<V=S='(@(D-A=&5G;W)I82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-SD*;7-G:60@(B(*(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B
M92!N;W1I9FEE9"!O9B!N97<L(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S
M(&)Y("(*(F5M86EL.B(*;7-G<W1R("(B"B)%<V-O;&AA('-E('9O8^H@<75E
M<B!S97(@;F]T:69I8V%D;R!P;W(@92UM86EL('-O8G)E(&5V96YT;W,@;F]V
M;W,L(&5D:71A9&]S("(*(F4@97AC;'7M9&]S.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E(&EF('EO=2!W86YT('1O(&)E
M(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',N
M(@IM<V=S='(@(B(*(D5S8V]L:&$@<V4@=F]CZB!Q=65R('-E<B!N;W1I9FEC
M861O('-O8G)E(&5V96YT;W,@;F]V;W,L(&5D:71A9&]S(&4@(@HB97AC;'7M
M9&]S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3(*;7-G:60@(D-H
M;V]S92!I9B!Y;W4@=V%N="!T;R!R96-E:79E(&5M86EL(')E;6EN9&5R<R!F
M;W(@979E;G1S('=I=&@@86QA<FUS.B(*;7-G<W1R("(B"B)%<V-O;&AA('-E
M('9O8^H@<75E<B!R96-E8F5R('!O<B!E+6UA:6P@;&5M8G)E=&5S(&1E(&5V
M96YT;W,@8V]M(&%V:7-O<SHB"@HC.B!T96UP;&%T97,O<')E9G,O<V5A<F-H
M7V%B;V]K7W-E;&5C="YI;F,Z,3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q
M,@IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C:"!F
M;W(@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(D5S8V]L:&$@;R!C873A;&]G
M;R!D92!E;F1E<F7G;W,@<&%R82!P97-Q=6ES87(@<&]R(%523',@;&EV<F4O
M;V-U<&%D;SHB"@HC.B!T96UP;&%T97,O<')E9G,O9F)?8V%L<U]S96QE8W0N
M:6YC.C$V"FUS9VED(")#:&]O<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E
M(&EN('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B(*;7-G<W1R("(B"B)%
M<V-O;&AA(&$@86=E;F1A('%U92!V;V/J('%U97(@:6YC;'5I<B!E;2!S=6%S
M(&QI<W1A9V5N<R!,:79R92]/8W5P861O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,C0*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN
M8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!54DQS.B(*;7-G<W1R
M(")%<V-O;&AA(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S('!A<F$@<&5S<75I
M<V%R('!O<B!54DQS(&QI=G)E+V]C=7!A9&\Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X"FUS9VED(")#:&]O<V4@>6]U<B!D969A=6QT(&-A;&5N
M9&%R+B(*;7-G<W1R(")%<V-O;&AA(&$@86=E;F1A('!A9'+C;RXB"@HC.B!T
M96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z.#4*;7-G:60@(D-L
M96%R(&%L;"!A='1E;F1E97,B"FUS9W-T<B`B4F5M;W9E<B!T;V1O<R!P87)T
M:6-I<&%N=&5S(@H*(SH@9&%T82YP:'`Z,C@@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G
M<W1R(")686QO<F5S('-E<&%R861O<R!P;W(@=NUR9W5L82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW,PIM<V=I9"`B0V]N9FER;2!D96QE=&EO;B!O
M9B!E=F5N=',_(@IM<V=S='(@(D-O;F9I<FUA<B!A(&5X8VQU<^-O(&1E(&5V
M96YT;W,_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<U"FUS9VED(")#;VYF
M:7)M960B"FUS9W-T<B`B0V]N9FER;6%D;R(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHR,#8*;7-G:60@(D-O<'D@=&AE(%523"!B
M96QO=R!F;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO=7(@1G)E92]"=7-Y
M(%523#HB"FUS9W-T<B`B(@HB0V]P:64@82!54DP@86)A:7AO('!A<F$@=71I
M;&EZ87(@;VYD92!V;V/J(&YE8V5S<VET92!D92!S=6$@55),($QI=G)E+R(*
M(D]C=7!A9&\Z(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,38S"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("));7!O
M<W/M=F5L(&%B<FER("5S+B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L
M96YD87)S+FEN8SHQ,C8*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<FEA<B(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,3(*;7-G
M:60@(D-R96%T92!#86QE;F1A<B(*;7-G<W1R(")#<FEA<B!!9V5N9&$B"@HC
M.B!M;VYT:"YP:'`Z,38S('1E;7!L871E<R]W965K+VAE860N:6YC.C(U('1E
M;7!L871E<R]D87DO<F]W+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H<#HY,"!L
M:6(O1&%Y5FEE=RYP:'`Z,3DU"FUS9VED(")#<F5A=&4@82!.97<@179E;G0B
M"FUS9W-T<B`B0W)I87(@3F]V;R!%=F5N=&\B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHX,`IM<V=I9"`B0W)E871E9"(*;7-G<W1R(")#<FEA9&\B
M"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S(*;7-G:60@(D-U
M<G)E;G0B"FUS9W-T<B`B071U86PB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`V"FUS9VED(")$
M86EL>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(D1IX7)I;SH@4F5P971E(&$@
M8V%D82(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$P(&QI8B]+<F]N;VQI=&@N<&AP
M.C$S,3$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R"FUS9VED(")$87DB"FUS9W-T<B`B1&EA(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,3,W"FUS9VED(")$87DH<RDB"FUS9W-T<B`B1&EA*',I(@H*(SH@
M=FEE=V5V96YT+G!H<#HQ,3$*;7-G:60@(D1E7VQE=&4B"FUS9W-T<B`B17AC
M7VQU:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.0IM
M<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5Z96UB<F\B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HV,#4*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(E)E8W5S
M861O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W"FUS9VED(")$969A
M=6QT($-A;&5N9&%R(@IM<V=S='(@(D%G96YD82!0861RXV\B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DS('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@Q"B,Z('1E;7!L871E<R]D96QE=&4O
M;VYE+FEN8SHS,B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M
M96YT+FEN8SHR,PHC.B!L:6(O1')I=F5R+G!H<#HQ.#0Y"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`B17AC;'5I<B(*"B,Z(&1E;&5V96YT+G!H<#HT,"!T96UP
M;&%T97,O9&5L971E+V]N92YI;F,Z,C$@=&5M<&QA=&5S+V1E;&5T92]D96QE
M=&4N:6YC.C(Q"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E("5S(@IM<V=S='(@(D5X8VQU:7(@)7,B"@HC.B!E
M9&ET979E;G0N<&AP.C<R"FUS9VED(")$96QE=&4@179E;G0B"FUS9W-T<B`B
M17AC;'5I<B!%=F5N=&\B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI
M;F,Z,S`*;7-G:60@(B(*(D1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY
M+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@
M;W(@(@HB86QL(&]C8W5R96YC97,_(@IM<V=S='(@(B(*(D5X8VQU:7(@<V]M
M96YT92!O(&5V96YT;R!A='5A;"P@97-T82!O8V]R<NIN8VEA(&4@=&]D87,@
M9G5T=7)A<R!O8V]R<NIN8VEA<R`B"B)O=2!T;V1A<R!O8V]R<NIN8VEA<S\B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3`S
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHR.`IM<V=I9"`B1&5S8W)I
M7W!T:6]N(@IM<V=S='(@(D1E7W-C<FGGXV\B"@HC.B!D871A+G!H<#HV,2!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<U"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.CDV"FUS9VED(")$97-C<FEP=&EO;B(*;7-G
M<W1R(")$97-C<FGGXV\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$W,PIM<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")%>&EB:7(B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z-C`*;7-G:60@
M(D1I<W!L87D@0V%L96YD87)S(@IM<V=S='(@(D5X:6)I<B!!9V5N9&%S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&ES<&QA
M>2!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!%>&EB:>?C;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&\@>6]U('=A;G0@=&\@
M<VAO=R!T87-K<R!W:&EC:"!A<F4@9'5E(&]N('EO=7(@8V%L96YD87(_(@IM
M<V=S='(@(E9O8^H@<75E<B!E>&EB:7(@=&%R969A<R!E;F-E<G)A9&%S(&5M
M('-U82!A9V5N9&$_(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30U"FUS9VED
M(")$;V5S(&YO="!R96-U<B(*;7-G<W1R(").XV\@<F5P971E(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G:60@(D1U93H@
M)7,B"FUS9W-T<B`B5F5N8VEM96YT;SH@)7,B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHQ,34*;7-G:60@(D1U<F%T:6]N(@IM<V=S
M='(@(D1U<F'GXV\B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,3<P(&QI8B]$<FEV97(N<&AP.C$X,S4*;7-G:60@(D5D:70B"FUS
M9W-T<B`B161I=&%R(@H*(SH@961I=&5V96YT+G!H<#HS,R!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,B!L:6(O1')I=F5R+G!H<#HQ.#,T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@)7,B"FUS9W-T<B`B161I=&%R("5S(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@U"FUS9VED(")%9&ET($%T=&5N
M9&5E<R(*;7-G<W1R(")%9&ET87(@4&%R=&EC:7!A;G1E<R(*"B,Z('1E;7!L
M871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#`*;7-G:60@(D5D:70@
M0V%L96YD87)S(@IM<V=S='(@(D5D:71A<B!!9V5N9&%S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(U,`IM<V=I9"`B161I="!296UO=&4@0V%L96YD
M87)S(@IM<V=S='(@(D5D:71A<B!!9V5N9&%S(%)E;6]T87,B"@HC.B!A='1E
M;F1E97,N<&AP.C$U,`IM<V=I9"`B161I="!A='1E;F1E97,B"FUS9W-T<B`B
M161I=&%R('!A<G1I8VEP86YT97,B"@HC.B!T96UP;&%T97,O8V%T96=O<GE?
M;&5G96YD+FEN8SHR,`IM<V=I9"`B161I="!C871E9V]R:65S(&%N9"!C;VQO
M<G,B"FUS9W-T<B`B161I=&%R(&-A=&5G;W)I87,@92!C;W)E<R(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V('1E;7!L871E<R]A
M='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B16YD
M97)EYV\@9&4@12U-86EL(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE
M<W!A;BYI;F,Z-C`*;7-G:60@(D5N7V0B"FUS9W-T<B`B06-A8F$@16TB"@HC
M.B!D871A+G!H<#HU-@IM<V=I9"`B16YD($1A=&4B"FUS9W-T<B`B1&%T82!&
M:6YA;"(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z
M."!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C$P.`IM<V=I9"`B16YD($]N(@IM<V=S='(@(D%C86)A
M($5M(@H*(SH@9&%T82YP:'`Z-3<*;7-G:60@(D5N9"!4:6UE(@IM<V=S='(@
M(DAO<N%R:6\@1FEN86PB"@HC.B!A='1E;F1E97,N<&AP.C$R-"!A='1E;F1E
M97,N<&AP.C$S-2!A='1E;F1E97,N<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F
M;W(@)7,Z("5S(@IM<V=S='(@(D5R<F\@86\@;V)T97(@:6YF;W)M8>?C;R!L
M:79R92]O8W5P861O(&1E("5S.B`E<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$Q,3,*;7-G:60@(D5V96YT(&%D9&5D.B(*;7-G<W1R(")%=F5N=&\@861I
M8VEO;F%D;SHB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3(S"FUS9VED(")%
M=F5N="!D96QE=&5D.B(*;7-G<W1R(")%=F5N=&\@97AC;'7M9&\Z(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q.`IM<V=I9"`B179E;G0@961I=&5D.B(*
M;7-G<W1R(")%=F5N=&\@961I=&%D;SHB"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M,#<Q"B,L('!H<"UF;W)M870*;7-G:60@(D5V96YT(&9R;VT@)7,@=&\@)7,B
M"FUS9W-T<B`B179E;G1O(&1E("5S('!A<F$@)7,B"@HC.B!L:6(O1')I=F5R
M+G!H<#HW-C<*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E
M+B(*;7-G<W1R(")%=F5N=&]S(&1E=F5M('!O<W-U:7(@=6UA(&1A=&$@9&4@
M:6[M8VEO+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<S,PIM<V=I9"`B179E;G1S
M(&UU<W0@:&%V92!A('1I=&QE+B(*;7-G<W1R(")%=F5N=&]S(&1E=F5M('!O
M<W-U:7(@=6T@=.UT=6QO+B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T
M96YD965S+FEN8SHW-@IM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(D5X
M<&%N9&ER($YO;65S(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M.#<*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%>'!O<G1A<B(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z.`IM<V=I9"`B17AP;W)T($-A;&5N9&%R
M(@IM<V=S='(@(D5X<&]R=&%R($%G96YD82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C8Y"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")&
M979E<F5I<F\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$R.`IM<V=I9"`B1FEN9"(*;7-G<W1R(")%;F-O;G1R87(B"@HC.B!Y96%R
M+G!H<#HX-"!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,R!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,3D*(SH@;&EB+T)L;V-K+VUO;G1H+G!H
M<#HQ,#4*;7-G:60@(D9R(@IM<V=S='(@(E-E>"(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C4X,0IM<V=I9"`B1G)E92(*;7-G<W1R("),:79R92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU.`IM<V=I9"`B1G)E92]"=7-Y($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DEN9F]R;6'GXV\@3&EV<F4O3V-U<&%D;R(*"B,Z
M('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,"!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z
M-S(*;7-G:60@(D9R:61A>2(*;7-G<W1R(")397AT82U&96ER82(*"B,Z('1E
M;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS,PIM<V=I9"`B1G5T=7)E(@IM
M<V=S='(@(D9U='5R;R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ
M-PIM<V=I9"`B1V%M92(*;7-G<W1R(")*;V=O(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C(S"FUS9VED(")'96YE<F%L(@IM
M<V=S='(@(D=E<F%L(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")';W1O("5S(@IM<V=S='(@(DER(%!A<F$@
M)7,B"@HC.B!M;VYT:"YP:'`Z,3,S('1E;7!L871E<R]W965K+VAE861?<VED
M95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B
M>5]S:61E+FEN8SHQ,`IM<V=I9"`B2&ED92(*;7-G<W1R(")/8W5L=&%R(@H*
M(SH@;6]N=&@N<&AP.C$S,R!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?
M<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED
M92YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&ED92`E<R(*;7-G<W1R
M("),96UB<F5T93H@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV
M-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S8*;7-G:60@(DAO=7(H<RDB
M"FUS9W-T<B`B2&]R82AS*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S,*;7-G:60@(DAO=R!L;VYG('-H;W5L9"!T:&4@=&EM92!S;&]T<R!O;B!T
M:&4@9&%Y(&%N9"!W965K('9I97=S(&)E/R(*;7-G<W1R("(B"B)1=6%L(&1E
M=F4@<V5R(&\@:6YT97)V86QO(&1E('1E;7!O(&$@<V5R(&5X:6)I9&\@;F%S
M('9I<W5A;&EZ8>?U97,@9&4@9&EA(&4@(@HB<V5M86YA/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,#$*;7-G:60@(DAO=R!M86YY(&1A>7,@;V8@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N('-H;W5L9"!W92!G96YE<F%T93\B"FUS
M9W-T<B`B07,@:6YF;W)M8>?U97,@;&EV<F4O;V-U<&%D;R!D979E('-E<B!G
M97)A9&$@8V]M('%U86YT;W,@9&EA<S\B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#4P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DEF('EO=7(@96UA:6P@
M8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP(')E<75E<W1S('EO=2!C86X@
M=7-E(&]N92!O9B!T:&4@(@HB9F]L;&]W:6YG(&QI;FMS('1O(&%C8V5P="!O
M<B!D96-L:6YE('1H92!E=F5N="Y<;B(*(EQN(@HB5&\@86-C97!T('1H92!E
M=F5N=#I<;B(*(B5S7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0@=&5N
M=&%T:79E;'DZ7&XB"B(E<UQN(@HB7&XB"B)4;R!D96-L:6YE('1H92!E=F5N
M=#I<;B(*(B5S(@IM<V=S='(@(B(*(E-E('-E=2!C;&EE;G1E(&1E(&4M;6%I
M;"!NXV\@<W5P;W)T82!S;VQI8VET8>?U97,@:51I<"!V;V/J('!O9&4@=7-A
M<B!U;2!D;W,@(@HB<V5G=6EN=&5S(&QI;FMS('!A<F$@86-E:71A<B!O=2!R
M96-U<V%R(&\@979E;G1O+EQN(@HB7&XB"B)087)A(&%C96ET87(@;R!E=F5N
M=&\Z7&XB"B(E<UQN(@HB7&XB"B)087)A(&%C96ET87(@=&5M<&]R87)I86UE
M;G1E(&\@979E;G1O.EQN(@HB)7-<;B(*(EQN(@HB4&%R82!R96-U<V%R(&\@
M979E;G1O.EQN(@HB)7,B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($-A;&5N9&%R+"!3=&5P
M("5D(@IM<V=S='(@(DEM<&]R=&%R($%G96YD82P@4&%S<V\@)60B"@HC.B!D
M871A+G!H<#HR.#0*;7-G:60@(DEM<&]R="]%>'!O<G0@0V%L96YD87(B"FUS
M9W-T<B`B26UP;W)T87(O17AP;W)T87(@06=E;F1A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C@*;7-G:60@(DIA;G5A<GDB"FUS9W-T
M<B`B2F%N96ER;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC
M.C<T"FUS9VED(")*=6QY(@IM<V=S='(@(DIU;&AO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S,*;7-G:60@(DIU;F4B"FUS9W-T<B`B
M2G5N:&\B"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ-#(*;7-G:60@(DME>7=O<F1S(@IM<V=S='(@(E!A;&%V<F%S+6-H879E
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4U"FUS9VED("),
M87-T(#(T(&AO=7)S(@IM<V=S='(@(MIL=&EM87,@,C0@:&]R87,B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHX-PIM<V=I9"`B3&%S="!-;V1I9FEE
M9"(*;7-G<W1R("+:;'1I;6$@36]D:69I8V'GXV\B"@HC.B!T96UP;&%T97,O
M;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C0*(SH@=&5M<&QA=&5S+VUO
M;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC.B!T96UP;&%T97,O;6]N
M=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$V('1E;7!L871E<R]M;VYT:"]H
M96%D+FEN8SHT"FUS9VED("),87-T($UO;G1H(@IM<V=S='(@(MIL=&EM;R!-
MZG,B"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHT"FUS9VED("),87-T
M(%EE87(B"FUS9W-T<B`BVFQT:6UO($%N;R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHU-"!T96UP;&%T97,O=V5E:R]H96%D+FEN8SHS"FUS
M9VED("),87-T('=E96LB"FUS9W-T<B`BVFQT:6UA('-E;6%N82(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3<*;7-G:60@(DQI;6ET('1H92!T
M:6UE('-P86X@=&\@97AP;W)T.B(*;7-G<W1R("),:6UI=&%R(&\@:6YT97)V
M86QO(&1E('1E;7!O('!A<F$@97AP;W)T87(Z(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C@U('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C<T"FUS9VED("),;U]C871I;VXB"FUS9W-T<B`B4F5?9VGC;R(*
M"B,Z(&1A=&$N<&AP.C8S('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R
M<RYI;F,Z-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M
M96YT+FEN8SHQ.`HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA
M9V5M96YT+FEN8SHU,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR,0HC.B!L
M:6(O1')I=F5R+G!H<#HQ.#@U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")2
M96=IXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4*;7-G:60@(DUA
M;F%G92!R96UO=&4@8V%L96YD87)S+B(*;7-G<W1R(")'97)E;F-I87(@86=E
M;F1A<R!R96UO=&%S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C<P"FUS9VED(")-87)C:"(*;7-G<W1R(")-87+G;R(*"B,Z(&QI8B]A
M<&DN<&AP.C$P,`IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@179E;G1S(@IM
M<V=S='(@(D[Z;65R;R!-X7AI;6\@9&4@179E;G1O<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C<R"FUS9VED(")-87DB"FUS9W-T<B`B
M36%I;R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X.#(*;7-G:60@(DUE(@IM<V=S
M='(@(D5U(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")-965T:6YG(@IM<V=S='(@(E)E=6YIXV\B"@HC.B!L:6(O0FQO8VLO=')E
M95]A;&%R;7,N<&AP.C,*;7-G:60@(DUE;G4@06QA<FUS(@IM<V=S='(@(D%V
M:7-O<R!D92!-96YU(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PIM
M<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(DQI<W1A(&1E($UE;G4B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHV."!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ,S4*;7-G:60@(DUI;G5T92AS*2(*;7-G<W1R(")-:6YU=&\H<RDB
M"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z-#(*;7-G:60@(DUI
M<W-E9"!%=F5N=',@3&ES="(*;7-G<W1R("),:7-T82!D92!%=F5N=&]S(%!E
M<F1I9&]S(@H*(SH@>65A<BYP:'`Z.#`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"B,Z(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")-;R(*;7-G<W1R(")396<B
M"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,38@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3$U"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N
M:6YC.C8X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*;7-G:60@(DUO;F1A
M>2(*;7-G<W1R(")396=U;F1A+49E:7)A(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3,Q-"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S='(@(DWJ<R(*"B,Z
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,PIM<V=I9"`B36]N=&@@5FEE=R(*;7-G
M<W1R(")6:7-U86QI>F'GXV\@365N<V%L(@H*(SH@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT,PIM<V=I9"`B
M36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R("),:7-T82!D92!%=F5N=&]S
M($UE;G-A:7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(R-B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S(*;7-G:60@
M(DUO;G1H;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")-96YS86PZ(%)E<&5T
M92!A(&-A9&$B"@HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-`IM<V=I
M9"`B36]N=&AS($%H96%D(@IM<V=S='(@(E!R\WAI;6]S($UE<V5S(@H*(SH@
M;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C(T"FUS9VED(")-;VYT:',@
M0F5F;W)E(@IM<V=S='(@(DUE<V5S($%N=&5R:6]R97,B"@HC.B!L:6(O87!I
M+G!H<#HV,S0*;7-G:60@(DUU;'1I<&QE(&E#86QE;F1A<B!C;VUP;VYE;G1S
M(&9O=6YD.R!O;FQY(&]N92!V179E;G0@:7,@<W5P<&]R=&5D+B(*;7-G<W1R
M("(B"B)-^FQT:7!L;W,@8V]M<&]N96YT97,@:4-A;&5N9&%R(&5N8V]N=')A
M9&]S.R!S;VUE;G1E('5M('9%=F5N="#I('-U<&]R=&%D;RXB"@HC.B!C86QE
M;F1A<G,N<&AP.C$R."!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z-C<*;7-G:60@(DUY($-A;&5N9&%R<R(*;7-G<W1R(")-:6YH87,@06=E
M;F1A<R(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHS-"!T96UP;&%T97,O;65N
M=2YI;F,Z,S8*;7-G:60@(DUY($-A;&5N9&%R<SHB"FUS9W-T<B`B36EN:&%S
M($%G96YD87,Z(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C(P,@IM<V=I9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R(")-:6YH
M82!54DP@3&EV<F4O3V-U<&%D;R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHQ,3<@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$U.0HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$W-0HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT
M+FEN8SHQ-PHC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M
M96YT+FEN8SHT-`IM<V=I9"`B3F%M92(*;7-G<W1R(").;VUE(@H*(SH@;&EB
M+T)L;V-K+VUO;G1H+G!H<#HT,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT
M-"!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-#$*(SH@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,C`*;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R(").;W9O($5V
M96YT;R(*"B,Z(&QI8B]B87-E+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB3F5W(&-A;&5N9&%R(&-R96%T960@86YD(&%U=&]M871I8V%L;'D@
M<VAA<F5D('=I=&@@9F]L;&]W:6YG(&=R;W5P*',I.B`E<RXB"FUS9W-T<B`B
M(@HB3F]V82!A9V5N9&$@8W)I861A(&4@875T;VUA=&EC86UE;G1E(&-O;7!A
M<G1I;&AA9&$@8V]M(&\H<RD@<V5G=6EN=&4H<RD@9W)U<&\B"B(H<RDZ("5S
M+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S,*;7-G:60@(DYE
M>'0B"FUS9W-T<B`B4'+S>&EM82(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FEN8SHU-PIM<V=I9"`B3F5X="`R-"!H;W5R<R(*;7-G<W1R(")0<O-X
M:6UA<R`R-"!H;W)A<R(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR.0IM<V=I
M9"`B3F5X="!$87DB"FUS9W-T<B`B4'+S>&EM;R!$:6$B"@HC.B!T96UP;&%T
M97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C8*(SH@=&5M<&QA=&5S
M+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O
M;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$X('1E;7!L871E<R]M;VYT
M:"]H96%D+FEN8SHV"FUS9VED(").97AT($UO;G1H(@IM<V=S='(@(E!R\WAI
M;6\@3>IS(@H*(SH@;&EB+T9"5FEE=R]W965K+G!H<#HS,@IM<V=I9"`B3F5X
M="!7965K(@IM<V=S='(@(E!R\WAI;6$@4V5M86YA(@H*(SH@=&5M<&QA=&5S
M+WEE87(O:&5A9"YI;F,Z-@IM<V=I9"`B3F5X="!996%R(@IM<V=S='(@(E!R
M\WAI;6\@06YO(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED
M(").97AT(&1A>2(*;7-G<W1R(")0<O-X:6UO(&1I82(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHU."!T96UP;&%T97,O=V5E:R]H96%D+FEN
M8SHU"FUS9VED(").97AT('=E96LB"FUS9W-T<B`B4'+S>&EM82!396UA;F$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<U(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR.#@*;7-G:60@(DYO(@IM<V=S='(@(D[C;R(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C<S('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$R-`IM<V=I9"`B3F\@86QA<FTB"FUS9W-T<B`B3F5N:'5M($%V:7-O(@H*
M(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0X"FUS9VED
M(").;R!A='1E;F1E97,B"FUS9W-T<B`B3F5N:'5M(%!A<G1I8VEP86YT92(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,S`*;7-G:60@(DYO(&-A;&5N9&%R
M<R!A<F4@879A:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B3F5N:'5M82!A
M9V5N9&$@97-TX2!D:7-P;V[M=F5L('!A<F$@8V]N=FED861O<RXB"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S8@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C4R"FUS9VED(").;R!E;F0@9&%T92(*;7-G<W1R(")396T@9&%T
M82!F:6YA;"(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ-C0@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,38S"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ.30*;7-G:60@(DYO(&5V96YT<R!T;R!D:7-P;&%Y(@IM<V=S
M='(@(DYE;FAU;2!E=F5N=&\@<&%R82!E>&EB:7(B"@HC.B!L:6(O4W1O<F%G
M92]K;VQA8BYP:'`Z-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92!F;W(@)7,B"FUS9W-T<B`B
M3F5N:'5M82!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\@97-TX2!D:7-P;V[M
M=F5L('!A<F$@)7,B"@HC.B!L:6(O87!I+G!H<#HS-#4@;&EB+V%P:2YP:'`Z
M-C(T"FUS9VED(").;R!I0V%L96YD87(@9&%T82!W87,@9F]U;F0N(@IM<V=S
M='(@(DYE;FAU;2!D861O(&E#86QE;F1A<B!F;VD@96YC;VYT<F%D;RXB"@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#$*;7-G:60@(DYO(')E8W5R
M<F5N8V4B"FUS9W-T<B`B4F5P971IY^-O(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z.3`R"FUS9VED(").;R!V86QI9"!E;6%I;"!A9&1R97-S(&9O=6YD(@IM
M<V=S='(@(DYE;FAU;2!E;F1E<F7G;R!D92!E+6UA:6P@=N%L:61O(&9O:2!E
M;F-O;G1R861O(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C$R(&QI8B]+<F]N
M;VQI=&@N<&AP.C8S,PIM<V=I9"`B3F]N92(*;7-G<W1R(").96YH=6UA(@H*
M(SH@;&EB+U-T;W)A9V4O<W%L+G!H<#HQ,S8*;7-G:60@(DYO="!F;W5N9"(*
M;7-G<W1R(").XV\@96YC;VYT<F%D;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,0IM<V=I9"`B3F]T:69I8V%T:6]N<R(*;7-G<W1R(").;W1I9FEC
M8>?U97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.`IM
M<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB<F\B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R(")!
M9V]R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<W"FUS
M9VED(")/8W1O8F5R(@IM<V=S='(@(D]U='5B<F\B"@HC.B!T96UP;&%T97,O
M961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,R!T96UP;&%T97,O961I="]E9&ET
M7W1I;65S<&%N+FEN8SHV-0IM<V=I9"`B3VXB"FUS9W-T<B`B16TB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<X(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR.3$*;7-G:60@(D]N(&%L;"!C86QE;F1A<G,@22!H879E(')E860@86-C
M97-S('1O(@IM<V=S='(@(D5M('1O9&%S(&%S(&%G96YD87,@<75E(&5U('1E
M;FAO(&%C97-S;R!D92!L96ET=7)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(W-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDP"FUS9VED(")/;B!A
M;&P@<VAO=VX@8V%L96YD87)S(@IM<V=S='(@(D5M('1O9&%S(&%S(&%G96YD
M87,@97AI8FED87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.#D*;7-G:60@(D]N(&UY(&-A;&5N9&%R
M<R!O;FQY(@IM<V=S='(@(E-O;65N=&4@96T@;6EN:&%S(&%G96YD87,B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HV,S`*;7-G:60@(D]P=&EO;F%L(@IM<V=S
M='(@(D]P8VEO;F%L(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,3$Y"FUS9VED(")/
M<'1I;VYA;"!!='1E;F1E97,B"FUS9W-T<B`B4&%R=&EC:7!AY^-O(&]P8VEO
M;F%L(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,34T"FUS9VED(")/=F5R=FEE=R(*
M;7-G<W1R(")6:7/C;R!'97)A;"(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C,T"FUS9VED(")/=VYE<B(*;7-G<W1R(")0<F]P<FEE=.%R:6\B"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ.#@Q"B,L('!H<"UF;W)M870*;7-G:60@(D]W
M;F5R.B`E<R(*;7-G<W1R(")0<F]P<FEE=.%R:6\Z("5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#(@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ.#(*;7-G:60@(E!-(@IM<V=S='(@(E!-(@H*(SH@;&EB+T)L;V-K
M+W!R979M;VYT:&QI<W0N<&AP.C,*;7-G:60@(E!A<W0@179E;G1S($QI<W0B
M"FUS9W-T<B`B3&ES=&$@9&4@179E;G1O<R!087-S861O<R(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$P.2!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHQ.38*;7-G:60@(E!A='1E<FXB"FUS9W-T<B`B36]D96QO(@H*(SH@=&5M
M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,P"FUS9VED(")097)M86YE;G1L>2!D
M96QE=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`B17AC;'5I<B!E<W1E(&5V96YT
M;R!P97)M86YE;G1E;65N=&4_(@H*(SH@;&EB+V%P:2YP:'`Z,S(V(&QI8B]A
M<&DN<&AP.C0R,B!L:6(O87!I+G!H<#HT.30@;&EB+V%P:2YP:'`Z-3<T"B,Z
M(&QI8B]A<&DN<&AP.C8P-B!L:6(O87!I+G!H<#HV.3(@;&EB+V%P:2YP:'`Z
M-S(X"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")097)M:7-S
MXV\@3F5G861A(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$V-PIM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0IM<V=I9"`B4&]R=&%L
M($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1O(%!O<G1A;"(*"B,Z(&QI8B]&
M0E9I97<O9&%Y+G!H<#HR-0IM<V=I9"`B4')E=FEO=7,@1&%Y(@IM<V=S='(@
M(D1I82!!;G1E<FEO<B(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*;7-G
M:60@(E!R979I;W5S(%=E96LB"FUS9W-T<B`B4V5M86YA($%N=&5R:6]R(@H*
M(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHS"FUS9VED(")0<F5V:6]U<R!D
M87DB"FUS9W-T<B`B1&EA(&%N=&5R:6]R(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3,U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T.0IM<V=I
M9"`B4F5C=7(@56YT:6PB"FUS9W-T<B`B4F5P971I<B!!=.DB"@HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,#8*;7-G:60@(E)E8W5R<F5N8V4B"FUS
M9W-T<B`B4F5P971IY^-O(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@(E)E8W5R
M<F5N8V4@1&%T82(*;7-G<W1R(")$861O<R!D82!297!E=&GGXV\B"@HC.B!D
M871A+G!H<#HV-@IM<V=I9"`B4F5C=7)R96YC92!%;F0@1&%T92(*;7-G<W1R
M(")$871A($9I;F%L(&1A(%)E<&5T:>?C;R(*"B,Z(&1A=&$N<&AP.C8W"FUS
M9VED(")296-U<G)E;F-E($EN=&5R=F%L(@IM<V=S='(@(DEN=&5R=F%L;R!D
M92!297!E=&GGXV\B"@HC.B!D871A+G!H<#HV-0IM<V=I9"`B4F5C=7)R96YC
M92!4>7!E(@IM<V=S='(@(E1I<&\@9&4@4F5P971IY^-O(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z-30X"FUS9VED(")296-U<G,@9&%I;'DB"FUS9W-T<B`B
M4F5P971E(&1I87)I86UE;G1E(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34U
M"FUS9VED(")296-U<G,@;6]N=&AL>2(*;7-G<W1R(")297!E=&4@;65N<V%L
M;65N=&4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3$*;7-G:60@(E)E8W5R
M<R!W965K;'DB"FUS9W-T<B`B4F5P971E('-E;6%N86QM96YT92(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C4U.`IM<V=I9"`B4F5C=7)S('EE87)L>2(*;7-G
M<W1R(")297!E=&4@86YU86QM96YT92(*"B,Z(&QI8B]38VAE9'5L97(O:W)O
M;F]L:71H+G!H<#HR,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M:6YD97(Z
M("5S(@IM<V=S='(@(DQE;6)R971E.B`E<R(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHY,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#0*;7-G:60@(E)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B06=E;F1A<R!2
M96UO=&%S(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C8P('1E;7!L871E<R]M
M96YU+FEN8SHV,@IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<SHB"FUS9W-T<B`B
M06=E;F1A<R!296UO=&%S.B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T
M96YD965S+FEN8SHU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@)7,B
M"FUS9W-T<B`B4F5M;W9E<B`E<R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`T"FUS
M9VED(")296UO=F4@071T96YD964B"FUS9W-T<B`B4F5M;W9E<B!087)T:6-I
M<&%N=&4B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,Q"FUS9VED
M("(B"B)297!L86-E(&5X:7-T:6YG(&-A;&5N9&%R('=I=&@@=&AE(&EM<&]R
M=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL
M(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&-A;&5N9&%R+CPO<W1R;VYG/B(*
M;7-G<W1R("(B"B)3=6)S=&ET=6ER(&$@86=E;F1A(&5X:7-T96YT92!P96QA
M(&%G96YD82!I;7!O<G1A9&$_/'-T<F]N9SY!=&5NY^-O.B!)<W-O("(*(F5X
M8VQU:7+A('1O9&]S(&]S(')E9VES=')O<R!D92!S=6$@86=E;F1A(&%T=6%L
M+CPO<W1R;VYG/B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8S-PIM<V=I9"`B
M4F5Q=6ER960B"FUS9W-T<B`B3V)R:6=A=/-R:6\B"@HC.B!L:6(O1D)6:65W
M+G!H<#HY."!L:6(O1D)6:65W+G!H<#HQ,SD@;&EB+T9"5FEE=RYP:'`Z,30R
M(&QI8B]&0E9I97<N<&AP.C$T-0IM<V=I9"`B4F5Q=6ER960@071T96YD965S
M(@IM<V=S='(@(E!A<G1I8VEP86YT97,@3V)R:6=A=/-R:6]S(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,S(@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,S`X"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R(")2971O
M<FYA<B!P87)A(&]S('!A9'+U97,B"@HC.B!T96UP;&%T97,O871T96YD965S
M+V%T=&5N9&5E<RYI;F,Z-#,@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38V
M"FUS9VED(")297-P;VYS92(*;7-G<W1R(")297-P;W-T82(*"B,Z('EE87(N
M<&AP.C@U('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8T('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(R,`HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP
M.C$P-0IM<V=I9"`B4V$B"FUS9W-T<B`B4V%B(@H*(SH@=&5M<&QA=&5S+VUO
M;G1H+VAE860N:6YC.C(Q('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,`HC
M.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,PIM<V=I9"`B4V%T
M=7)D87DB"FUS9W-T<B`B4^%B861O(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C$Y,@IM<V=I9"`B4V%V92(*;7-G<W1R(")386QV
M87(B"@HC.B!V:65W979E;G0N<&AP.C$S,R!E9&ET979E;G0N<&AP.C0Y(&5D
M:71E=F5N="YP:'`Z-3<*;7-G:60@(E-A=F4@07,@3F5W(@IM<V=S='(@(E-A
M;'9A<B!#;VUO($YO=F\B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N
M9&5E<RYI;F,Z.#0*;7-G:60@(E-A=F4@071T96YD965S(@IM<V=S='(@(E-A
M;'9A<B!087)T:6-I<&%N=&5S(@H*(SH@861D979E;G0N<&AP.C4U(&5D:71E
M=F5N="YP:'`Z-3(*;7-G:60@(E-A=F4@179E;G0B"FUS9W-T<B`B4V%L=F%R
M($5V96YT;R(*"B,Z('-E87)C:"YP:'`Z.3$@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C$Q-`HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YI;F,Z-C<@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C@*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-#`@;&EB+T)L
M;V-K+W1R965?;65N=2YP:'`Z,C8*;7-G:60@(E-E87)C:"(*;7-G<W1R(")0
M97-Q=6ES87(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z
M,0IM<V=I9"`B4V5A<F-H($-A;&5N9&%R<R(*;7-G<W1R(")097-Q=6ES87(@
M06=E;F1A<R(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHV"FUS
M9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R(")297-U;'1A9&]S(&1A(%!E
M<W%U:7-A(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C8*
M;7-G:60@(E-E87)C:"!F;W(@8V%L96YD87)S(&-O;G1A:6YI;F<Z(@IM<V=S
M='(@(E!E<W%U:7-A<B!P;W(@86=E;F1A<R!C;VYT96YD;SHB"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34P"FUS9VED(")396QE
M8W0@82!C86QE;F1A<B!T;R!E9&ET(@IM<V=S='(@(E-E;&5C:6]N92!U;6$@
M86=E;F1A('!A<F$@961I=&%R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,C8U('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,Z
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"FUS9VED(")3
M96QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C:6]N92!U;6$@9&%T82(*"B,Z
M('1E;7!L871E<R]M96YU+FEN8SHS,`IM<V=I9"`B4V5L96-T(&-A;&5N9&%R
M<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")396QE8VEO;F4@87,@86=E;F1A<R!A
M(&5X:6)I<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*;7-G:60@
M(B(*(E-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O(&1I<W!L
M87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E("(*(F1E9F%U;'0@
M=FEE=RXB"FUS9W-T<B`B(@HB4V5L96-I;VYE(&]PY_5E<R!D92!C;VYF:7)M
M8>?C;RP@8V]M;R!E>&EB:7(@9&EF97)E;G1E<R!V:7-U86QI>F'G]65S(&4@
M(@HB97-C;VQH82!U;6$@=FES=6%L:7IAY^-O('!A9'+C;RXB"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$X"FUS9VED(")396QE8W0@=&AE(&-A
M;&5N9&%R('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B4V5L96-I;VYE(&$@86=E
M;F1A('!A<F$@;VYD92!I;7!O<G1A<CHB"@HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$R"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z
M(@IM<V=S='(@(E-E;&5C:6]N92!O(&9O<FUA=&\@<&%R82!E>'!O<G1A<CHB
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(W"FUS9VED(")396QE
M8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")396QE8VEO;F4@;R!A
M<G%U:79O('!A<F$@:6UP;W)T87(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-`IM<V=I9"`B4V5L96-T('1H92!F:7)S="!W965K9&%Y.B(*;7-G
M<W1R(")396QE8VEO;F4@;R!P<FEM96ER;R!D:6$@9&$@<V5M86YA.B(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G:60@(E-E;&5C="!T
M:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B4V5L96-I
M;VYE(&\@9F]R;6%T;R!D;R!A<G%U:79O(&1E(&]R:6=E;3HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3@T"FUS9VED(")396QE8W0@=&AE('1I;64@
M<W!A;B!T;R!S:&]W.B(*;7-G<W1R(")396QE8VEO;F4@;R!T96UP;R!D92!D
M=7)AY^-O('!A<F$@97AI8FER.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-@IM<V=I9"`B4V5L96-T('1H92!V:65W('1O(&1I<W!L87D@;VX@<W1A
M<G1U<#HB"FUS9W-T<B`B4V5L96-I;VYE(&$@=FES=6%L:7IAY^-O('!A<F$@
M97AI8FER(&YA(&EN:6-I86QI>F'GXV\Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R"FUS9VED(")396QE8W0@=VAI8V@@979E;G1S('1O('-H;W<@
M:6X@=&AE('!O<G1A;"XB"FUS9W-T<B`B4V5L96-I;VYE('%U86ES(&5V96YT
M;W,@97AI8FER(&YO('!O<G1A;"XB"@HC.B!T96UP;&%T97,O9&5L971E+V]N
M92YI;F,Z,C<@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED
M(")396YD(&$@8V%N8V5L(&YO=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S
M('=H96X@9&5L971I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"B)%;G9I87(@
M=6UA(&YO=&EF:6-AY^-O(&1E(&-A;F-E;&%M96YT;R!P87)A('1O9&]S('!A
M<G1I8VEP86YT97,@86\@97AC;'5I<B`B"B)E<W1E(&5V96YT;R(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")396YD(&%N(&5M86EL('1O("5S(@IM<V=S='(@(D5N=FEA<B!U;2!E+6UA
M:6P@<&%R82`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$W.0IM
M<V=I9"`B4V5N9"!U<&1A=&5S+VEN=FET871I;VYS('1O(&%L;"!A='1E;F1E
M97,@=VAE;B!S879I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"B)%;G9I87(@
M871U86QI>F'G]65S+V-O;G9I=&5S('!A<F$@=&]D;W,@;W,@<&%R=&EC:7!A
M;G1E<R!A;R!S86QV87(@97-T92`B"B)E=F5N=&\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]G;W1O+FEN8SHW-@IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S
M='(@(E-E=&5M8G)O(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z.#,*;7-G:60@(E-E="!E;F0@9&%T92(*;7-G<W1R(")$969I;FER
M(&1A=&$@9FEN86PB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-C4*
M;7-G:60@(E-E="!R96-U<G)E;F-E(&5N9"!D871E(@IM<V=S='(@(D1E9FEN
M:7(@9&%T82!F:6YA;"!D82!R97!E=&GGXV\B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHS,0IM<V=I9"`B4V5T('-T87)T(&1A=&4B
M"FUS9W-T<B`B1&5F:6YI<B!D871A(&1E(&EN[6-I;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU.0IM<V=I9"`B(@HB4V5T('EO=7(@9G)E92]B=7-Y
M(&-A;&5N9&%R<R!A;F0@>6]U<B!O=VX@86YD(&]T:&5R('5S97)S)R!F<F5E
M+V)U<WD@;W!T:6]N<RXB"FUS9W-T<B`B1&5F:6YE(&%S(&]PY_5E<R!L:79R
M92]O8W5P861O+"!S=6%S(&4@9&4@;W5T<F]S('5S=>%R:6]S+B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAA<F4@;F]T
M(&9O=6YD.B`E<R(*;7-G<W1R(")#;VUP87)T:6QH86UE;G1O(&[C;R!E;F-O
M;G1R861O.B`E<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHW.0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R<R(*;7-G<W1R(")!9V5N
M9&%S($-O;7!A<G1I;&AA9&%S(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C0W
M('1E;7!L871E<R]M96YU+FEN8SHT.0IM<V=I9"`B4VAA<F5D($-A;&5N9&%R
M<SHB"FUS9W-T<B`B06=E;F1A<R!#;VUP87)T:6QH861A<SHB"@HC.B!C86QE
M;F1A<E]S96%R8V@N<&AP.C(U('1E;7!L871E<R]W965K+VAE861?<VED95]B
M>5]S:61E+FEN8SHS"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I
M9&4N:6YC.C,*;7-G:60@(E-H;W<@0V%L96YD87(B"FUS9W-T<B`B17AI8FER
M($%G96YD82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-38*;7-G:60@
M(E-H;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G<W1R(")%>&EB:7(@;&5G96YD
M82!D87,@8V%T96=O<FEA<S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30V"FUS9VED(")3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E
M(&EC;VYS(&EN(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R("(B"B)%>&EB:7(@
M;W,@[6-O;F5S(&1E(&5X8VQU<^-O+"!A=FES;R!E(')E<&5T:>?C;R!N87,@
M=FES=6%L:7IAY_5E<R!D82!A9V5N9&$_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S:W,@:6X@=&AE(&-A;&5N
M9&%R/R(*;7-G<W1R(")%>&EB:7(@=&%R969A<R!V96YC:61A<R!N82!A9V5N
M9&$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V-@IM<V=I9"`B4VAO
M=R!F<F5E+V)U<WD@;&5G96YD/R(*;7-G<W1R(")%>&EB:7(@;&5G96YD82!D
M92!L:79R92]O8W5P861O/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#,*;7-G:60@(E-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M
M('-E=#\B"FUS9W-T<B`B17AI8FER('-O;65N=&4@979E;G1O<R!C;VT@879I
M<V\@9&5F:6YI9&\_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-0IM
M<V=I9"`B4VAO=R!S:&%R960@8V%L96YD87)S('-I9&4M8GDM<VED93\B"FUS
M9W-T<B`B17AI8FER(&%G96YD87,@8V]M<&%R=&EL:&%D87,@;&%D;RUA+6QA
M9&\_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B4VAO
M=R!T87-K<R!U<VEN9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(D5X:6)I
M<B!T87)E9F%S('5T:6QI>F%N9&\@8V]R97,@9&4@8V%T96=O<FEA/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B4VAO=R!T:6UE(&]F
M(&1A>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_(@IM<V=S='(@
M(D5X:6)I<B!A<R!H;W)A<R!E;G1R92!C861A(&1I82!N87,@=FES=6%L:7IA
MY_5E<R!S96UA;F%I<S\B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHQ,0IM<V=I9"`B4W1A7W)T(@IM<V=S='(@(DE?;FEC:6%R(@H*
M(SH@9&%T82YP:'`Z-30*;7-G:60@(E-T87)T($1A=&4B"FUS9W-T<B`B1&%T
M82!);FEC:6%L(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S
M+FEN8SHW('1E;7!L871E<R]V:65W+W9I97<N:6YC.C0Q"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,C4*;7-G:60@(E-T87)T($]N(@IM<V=S='(@
M(DEN:6-I82!%;2(*"B,Z(&1A=&$N<&AP.C4U"FUS9VED(")3=&%R="!4:6UE
M(@IM<V=S='(@(DAO<F$@26YI8VEA;"(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H7V%D=F%N8V5D+FEN8SHY-"!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHX,PIM<V=I9"`B4W1A=%]U<R(*;7-G<W1R(")3:71?=6'GXV\B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C8@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,C<*;7-G:60@(E-T871U<R(*;7-G<W1R(")3:71U
M8>?C;R(*"B,Z('EE87(N<&AP.C<X('EE87(N<&AP.C@W('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C8U"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(R,2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-R!L:6(O0FQO8VLO;6]N
M=&@N<&AP.C$P.0IM<V=I9"`B4W4B"FUS9W-T<B`B1&]M(@H*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E<R]M;VYT:"]H96%D+FEN
M8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C$@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-0IM<V=I9"`B4W5N9&%Y(@IM<V=S='(@(D1O;6EN9V\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*;7-G:60@(E1A<VMS(@IM<V=S='(@
M(E1A<F5F87,B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.#4@;&EB+TMR;VYO
M;&ET:"YP:'`Z-C`X"FUS9VED(")496YT871I=F4B"FUS9W-T<B`B4')O=FES
M\W)I;R(*"B,Z('EE87(N<&AP.C@S('1E;7!L871E<R]J879A<V-R:7!T+V=O
M=&\N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.`HC.B!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5&@B"FUS9W-T<B`B475I(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW,`IM<V=I9"`B
M5&AE($5D:70@071T96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N
M="X@17AI=&EN9RXB"FUS9W-T<B`B02!T96QA($5D:71A<B!087)T:6-I<&%N
M=&5S(&[C;R!E<W3A(&UA:7,@9&ES<&]N[79E;"X@4V%I;F1O+B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N
M9&%R(%PB)7-<(B!C86YN;W0@8F4@9&5L971E9"XB"FUS9W-T<B`B02!A9V5N
M9&$@7"(E<UPB(&[C;R!P;V1E('-E<B!E>&-L=>UD82XB"@HC.B!C86QE;F1A
M<G,N<&AP.C0P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<
M(B5S7"(@:&%S(&)E96X@8W)E871E9"XB"FUS9W-T<B`B02!A9V5N9&$@7"(E
M<UPB(&9O:2!C<FEA9&$N(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(D$@86=E;F1A(%PB)7-<(B!F;VD@97AC;'7M9&$N
M(@H*(SH@8V%L96YD87)S+G!H<#HU-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(')E;F%M960@=&\@7"(E<UPB
M+B(*;7-G<W1R(")!(&%G96YD82!<(B5S7"(@9F]I(')E;F]M96%D82!P87)A
M(%PB)7-<(BXB"@HC.B!C86QE;F1A<G,N<&AP.C4V"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(D$@86=E;F1A(%PB)7-<(B!F;VD@<V%L=F$N(@H*(SH@9&%T82YP
M:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!C;W5L
M9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R(")!(&%G96YD82!NXV\@</1D
M92!S97(@<F5M;W9I9&$Z("5S(@H*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C
M<FEP="YI;F,Z,38S"FUS9VED(")4:&4@96YD(&1A=&4@;75S="!B92!L871E
M<B!T:&%N('1H92!S=&%R="!D871E+B(*;7-G<W1R(")!(&1A=&$@9FEN86P@
M9&5V92!S97(@;6%I;W(@<75E(&$@9&%T82!I;FEC:6%L+B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$Q,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&5V96YT(%PB)7-<(B!H87,@8F5E;B!A9&1E9"!T;R!<(B5S7"(@8V%L96YD
M87(L('=H:6-H(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R("(B"B)/(&5V96YT
M;R!<(B5S7"(@9F]I(&%D:6-I;VYA9&\@;F$@86=E;F1A(%PB)7-<(BP@;R!Q
M=6%L('-E<N$@96T@)7,@X',@)7,N(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3$R-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@979E;G0@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960@9G)O;2!<(B5S7"(@8V%L96YD87(L('=H:6-H
M('=A<R!O;B`E<R!A="`E(@HB<RXB"FUS9W-T<B`B3R!E=F5N=&\@7"(E<UPB
M(&9O:2!E>&-L=>UD;R!D82!A9V5N9&$@7"(E<UPB+"!O('%U86P@97)A(&5M
M("5S(.!S("5S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE(&5V96YT(%PB)7-<(B!H87,@8F5E;B!E
M9&ET960@;VX@7"(E<UPB(&-A;&5N9&%R+"!W:&EC:"!I<R!O;B`E<R!A="`E
M<RXB"FUS9W-T<B`B(@HB3R!E=F5N=&\@7"(E<UPB(&9O:2!A;'1E<F%D;R!N
M82!A9V5N9&$@7"(E<UPB+"!O('%U86P@<V5RX2!E;2`E<R#@<R`E<RXB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#@W"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E<W-F=6QL
M>2!S96YT+B(*;7-G<W1R(")!(&YO=&EF:6-AY^-O(&1E(&5V96YT;R!P87)A
M("5S(&9O:2!E;G9I861A(&-O;2!S=6-E<W-O+B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$P-#0*;7-G:60@(E1H92!F;VQL;W=I;F<@:7,@82!M;W)E(&1E
M=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#HB"FUS9W-T<B`B4V5G
M=64@=6UA(&1E<V-R:>?C;R!M86ES(&1E=&%L:&%D82!D;R!E=F5N=&\Z(@H*
M(SH@871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E<W0@=V%S(&EN
M8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N96-E<W-A<GD@
M=&\@86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E(&UI<W-I;F<N
M(@IM<V=S='(@(B(*(D$@<V]L:6-I=&'GXV\@;N-O(&9O:2!C;VUP;&5T861A
M+B!!;&=U;G,@<&%RXFUE=')O<R!Q=64@<^-O(&YE8V5S<^%R:6]S('!A<F$@
M(@HB86-E:71A<B!O=2!R96-U<V%R('5M(&5V96YT;R!E<W3C;R!F86QT86YD
M;RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+V5M<'1Y+FEN8SHS"FUS9VED(")4
M:&5R92!A<F4@;F\@979E;G1S(&UA=&-H:6YG('1H92!C=7)R96YT(&-R:71E
M<FEA+B(*;7-G<W1R(").XV\@97AI<W1E;2!E=F5N=&]S(&-O<G)E<W!O;F1E
M;G1E<R!A;R!C<FETZ7)I;R!A='5A;"XB"@HC.B!A9&1E=F5N=&%C=&EO;BYP
M:'`Z,3@@961I=&5V96YT86-T:6]N+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@86-C97-S:6YG('1H92!C86QE;F1A
M<CH@)7,B"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!A8V5S<V%R(&$@86=E
M;F1A.B`E<R(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HS-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N
M=#H@)7,B"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!A9&EC:6]N87(@;R!E
M=F5N=&\Z("5S(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HX,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@
M979E;G0Z("5S(@IM<V=S='(@(DAO=79E('5M(&5R<F\@86\@961I=&%R(&\@
M979E;G1O.B`E<R(*"B,Z(&QI8B]A<&DN<&AP.C,S.2!L:6(O87!I+G!H<#HV
M,3@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R(")(;W5V92!U;2!E<G)O(&%O(&EM<&]R
M=&%R(&]S(&1A9&]S(&1O(&E#86QE;F1A<BXB"@HC.B!E9&ET979E;G1A8W1I
M;VXN<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!M;W9I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")(;W5V92!U;2!E
M<G)O(&%O(&UO=F5R(&\@979E;G1O.B`E<R(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$P.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('-E;F1I;F<@86X@979E;G0@;F]T:69I8V%T:6]N('1O("5S.B`E<R(*
M;7-G<W1R(")(;W5V92!U;2!E<G)O(&%O(&5N=FEA<B!U;6$@;F]T:69I8V'G
MXV\@9&4@979E;G1O('!A<F$@)7,Z("5S(@H*(SH@9&%T82YP:'`Z,3`T"FUS
M9VED(")4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N(@IM<V=S='(@
M(D[C;R!E>&ES=&EA;2!E=F5N=&]S('!A<F$@97AP;W)T87(N(@H*(SH@9&%T
M82YP:'`Z,3@S"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(D5S=&4@9F]R;6%T;R!D92!A<G%U:79O(&[C;R#I
M('-U<&]R=&%D;RXB"@HC.B!D871A+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B27-T;R!F;VD@;R!Q=64@;R!S97)V:61O<B!R971O<FYO=3H@)7,B"@HC
M.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3D@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3$X"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC
M.C<Q"FUS9VED(")4:'5R<V1A>2(*;7-G<W1R(")1=6EN=&$M1F5I<F$B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S<*;7-G:60@(E1I;64@
M4W!?86XB"FUS9W-T<B`B26YT97)V7V%L;R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C0*;7-G:60@(E1I;64@<W!A;B(*;7-G<W1R
M("));G1E<G9A;&\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S@*;7-G:60@
M(E1I=%]L92(*;7-G<W1R(")?5.UT=6QO(@H*(SH@9&%T82YP:'`Z-3,@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(P"B,Z('1E;7!L871E<R]S96%R
M8V@O979E;G1?:&5A9&5R<RYI;F,Z,PIM<V=I9"`B5&ET;&4B"FUS9W-T<B`B
M5.UT=6QO(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N<&AP.C$R,B!L
M:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$R-PIM<V=I9"`B5&]D87DB"FUS9W-T<B`B2&]J92(*"B,Z(&QI
M8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C0@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z,3(S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,CD*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(D%M86YHXR(*"B,Z('EE87(N<&AP.C@Q
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8P('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(Q-@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM
M<V=I9"`B5'4B"FUS9W-T<B`B5&5R(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C$W('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-@HC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV.0IM<V=I9"`B5'5E<V1A>2(*
M;7-G<W1R(")497+G82U&96ER82(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N
M9&ES=#HQ-PIM<V=I9"`B5'EP92(*;7-G<W1R(")4:7!O(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$X,PIM<V=I9"`B55),(@IM
M<V=S='(@(E523"(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DEM
M<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@4U%,+B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(DEM<&]S<^UV96P@97AC;'5I<B!<
M(B5S7"(Z("5S(@H*(SH@;&EB+T1R:79E<B]M8V%L+G!H<#HQ,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RXB"FUS9W-T<B`B
M26UP;W-S[79E;"!E>&-L=6ER("5S+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B26UP;W-S[79E;"!C87)R96=A<B!A
M(&1E9FEN:>?C;R!D92`E<RXB"@HC.B!C86QE;F1A<G,N<&AP.C4Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@7"(E<UPB.B`E<R(*
M;7-G<W1R("));7!O<W/M=F5L(')E;F]M96%R(%PB)7-<(CH@)7,B"@HC.B!L
M:6(O4W1O<F%G92]K;VQA8BYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E=')I979E(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@
M)7,B"FUS9W-T<B`B26UP;W-S[79E;"!O8G1E<B!A(&EN9F]R;6'GXV\@;&EV
M<F4O;V-U<&%D;R!D92`E<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$U"B,Z('-C<FEP=',O=7!G<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T7V-A
M=&5G;W)I97-?=&]?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`B4V5M(&-A=&5G;W)I82(*"B,Z(&QI8B]A<&DN<&AP.C,W-R!L:6(O
M87!I+G!H<#HT-C$@;&EB+V%P:2YP:'`Z-3,W(&QI8B]A<&DN<&AP.C8T,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z
M("5S(@IM<V=S='(@(D-O;G1E;G0M5'EP92!NXV\@<W5P;W)T861O.B`E<R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9#H@)7,N(@IM<V=S='(@(D%T=6%L:7IA9&\Z("5S+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B57-E<B!);G1E<F9A
M8V4B"FUS9W-T<B`B26YT97)F86-E(&1O(%5S=>%R:6\B"@HC.B!Y96%R+G!H
M<#HQ-C`@>65A<BYP:'`Z,38V(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,38R"FUS9VED(")6:65W($1A>2(*;7-G<W1R
M(")6:7-U86QI>F'GXV\@1&GA<FEA(@H*(SH@>65A<BYP:'`Z.#(@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C$@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C$W"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")7
M92(*;7-G<W1R(")1=6$B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z
M,3@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$W"B,Z('1E;7!L871E<R]E
M9&ET+VIA=F%S8W)I<'0N:6YC.C<P"FUS9VED(")7961N97-D87DB"FUS9W-T
M<B`B475A<G1A+49E:7)A(@H*(SH@871T96YD965S+G!H<#HQ,3(@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,Q,R!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,PHC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(E=E96LB"FUS9W-T
M<B`B4V5M86YA(@H*(SH@;6]N=&@N<&AP.C$W-R!W;W)K=V5E:RYP:'`Z,S`@
M=V5E:RYP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5E:R`E9"(*;7-G
M<W1R(")396UA;F$@)60B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHU
M.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S@*;7-G:60@(E=E96LH<RDB
M"FUS9W-T<B`B4V5M86YA*',I(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,3(R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q,@IM<V=I9"`B5V5E
M:VQY.B!296-U<G,@979E<GDB"FUS9W-T<B`B4V5M86YA;&UE;G1E.B!297!E
M=&4@82!C861A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I
M9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD
M+"!W:&5N('1H97)E(&%R92!N;R!L871E<B!E=F5N=',_(@IM<V=S='(@(B(*
M(D$@<75E(&AO<F%S(&1E=F5RXV\@9FEN86QI>F%R(&%S('9I<W5A;&EZ8>?U
M97,@9&4@9&EA(&4@<V5M86YA+"!Q=6%N9&\@;N-O("(*(FAO=79E<B!E=F5N
M=&]S(&UA:7,@=&%R9&4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-0IM<V=I9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE
M=W,@<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A<FQI97(@979E;G1S/R(*
M;7-G<W1R("(B"B)!('%U92!H;W)A<R!D979E<N-O(&EN:6-I87(@87,@=FES
M=6%L:7IAY_5E<R!D92!D:6$@92!S96UA;F$L('%U86YD;R!NXV\@(@HB:&]U
M=F5R(&5V96YT;W,@;6%I<R!C961O/R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$Q
M(&QI8B]+<F]N;VQI=&@N<&AP.C$S,3(@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")7;W)K
M(%=E96LB"FUS9W-T<B`B1&EA<R!#;VUE<F-I86ES(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3,Q-2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-0IM<V=I
M9"`B665A<B(*;7-G<W1R(")!;F\B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,X"FUS9VED(")9
M96%R;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")!;G5A;#H@<F5P971E(&$@
M8V%D82(*"B,Z(&1A=&$N<&AP.C,Y(&1A=&$N<&AP.C(S-2!E9&ET979E;G1A
M8W1I;VXN<&AP.C0V(&%D9&5V96YT+G!H<#HQ-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@979E;G1S+B(*;7-G<W1R(")6;V/J(&[C;R!E<W3A(&%U=&]R:7IA9&\@
M82!C<FEA<B!M86ES('%U92`E9"!E=F5N=&]S+B(*"B,Z(&%T=&5N9"YP:'`Z
M-#D*;7-G:60@(EEO=2!A<F4@;F]T(&%N(&%T=&5N9&5E(&]F('1H92!S<&5C
M:69I960@979E;G0N(@IM<V=S='(@(E9O8^H@;N-O(.D@=6T@<&%R=&EC:7!A
M;G1E(&1O(&5V96YT;R!E<W!E8VEF:6-A9&\N(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHW-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S
M92!T:&ES(&9O<FT@9G)O;2!T:&4@161I="!!='1E;F1E97,@<V-R965N+B(*
M;7-G<W1R("(B"B)6;V/J('!O9&4@=71I;&EZ87(@97-T92!F;W)M=6SA<FEO
M('-O;65N=&4@82!P87)T:7(@9&$@=&5L82!%9&ET87(@(@HB4&%R=&EC:7!A
M;G1E<RXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HY.#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&1O(&YO="!H879E(&%N(&5M86EL(&%D9')E<W,@
M8V]N9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T:6]N("(*(D]P
M=&EO;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F;W)E(&5V96YT
M(&YO=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N(@IM<V=S='(@(B(*(E9O8^H@
M;N-O('1E;2!U;2!E;F1E<F7G;R!D92!E+6UA:6P@8V]N9FEG=7)A9&\@;F%S
M('-U87,@3W#G]65S(&1E("(*(DEN9F]R;6'G]65S(%!E<W-O86ES+B!6;V/J
M(&1E=F4@9&5F:6YI<B!U;2`E<V%Q=6DE<R!A;G1E<R!D92!E;G9I87(@87,@
M(@HB;F]T:69I8V'G]65S(&1E(&5V96YT;W,N(@H*(SH@861D979E;G1A8W1I
M;VXN<&AP.C(P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S='(@(E9O
M8^H@;N-O('1E;2!P97)M:7-SXV\@9&4@861I8VEO;F%R(&5V96YT;W,@96T@
M)7,N(@H*(SH@9&%T82YP:'`Z,3DS"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE8W1E9"!C86QE
M;F1A<BXB"FUS9W-T<B`B5F]CZB!NXV\@=&5M('!E<FUI<W/U97,@9&4@861I
M8VEO;F%R(&5V96YT;W,@;F$@86=E;F1A('-E;&5C:6]N861A+B(*"B,Z(&1E
M;&5V96YT86-T:6]N+G!H<#HR-@IM<V=I9"`B66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N(@IM<V=S='(@(E9O8^H@
M;N-O('1E;2!P97)M:7-SXV\@9&4@97AC;'5I<B!E<W1E(&5V96YT;RXB"@HC
M.B!E9&ET979E;G1A8W1I;VXN<&AP.C<X"FUS9VED(")9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!E9&ET('1H:7,@979E;G0N(@IM<V=S='(@(E9O
M8^H@;N-O('1E;2!P97)M:7-SXV\@9&4@961I=&%R(&5S=&4@979E;G1O+B(*
M"B,Z(&1A=&$N<&AP.C$X.`IM<V=I9"`B66]U(&AA=F4@<W!E8VEF:65D(&%N
M(&EN=F%L:60@8V%L96YD87(N(@IM<V=S='(@(E9O8^H@97-P96-I9FEC;W4@
M=6UA(&%G96YD82!I;G;A;&ED82XB"@HC.B!A='1E;F0N<&AP.C(Q"FUS9VED
M(")9;W4@:&%V92!S=6-C97-S9G5L;'D@86-C97!T960@871T96YD96YC92!T
M;R!T:&ES(&5V96YT+B(*;7-G<W1R(")6;V/J(&%C96ET;W4@82!P87)T:6-I
M<&'GXV\@;F5S=&4@979E;G1O+B(*"B,Z(&%T=&5N9"YP:'`Z,C8*;7-G:60@
M(EEO=2!H879E('-U8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O
M('1H:7,@979E;G0N(@IM<V=S='(@(E9O8^H@<F5C=7-O=2!A('!A<G1I8VEP
M8>?C;R!N97-T92!E=F5N=&\N(@H*(SH@871T96YD+G!H<#HS,0IM<V=I9"`B
M66]U(&AA=F4@=&5N=&%T:79E;'D@86-C97!T960@871T96YD96YC92!T;R!T
M:&ES(&5V96YT+B(*;7-G<W1R(")6;V/J(&%C96ET;W4@<')O=FES;W)I86UE
M;G1E('!A<G1I8VEP87(@9&5S=&4@979E;G1O+B(*"B,Z(&-A;&5N9&%R<RYP
M:'`Z.3$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E
M(&1E;&5T960N(@IM<V=S='(@(E9O8^H@9&5V92!S96QE8VEO;F%R('5M82!A
M9V5N9&$@<&%R82!E>&-L=6ER+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z-30*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R
M97-S(&9I<G-T+B(*;7-G<W1R(")6;V/J(&1E=F4@<V5L96-I;VYA<B!U;2!E
M;F1E<F7G;R!P<FEM96ER;RXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$T
M"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E
M;G1S(&%R92!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@HB
M5F]CZB!S;VQI8VET;W4@<V5R(&YO=&EF:6-A9&\@<75A;F1O(&5V96YT;W,@
M<^-O(&%D:6-I;VYA9&]S(&5M('-U87,@86=E;F1A<RXB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,3(T"FUS9VED("(B"B)9;W4@<F5Q=65S=&5D('1O(&)E
M(&YO=&EF:65D('=H96X@979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U<B!C
M86QE;F1A<G,N(@IM<V=S='(@(B(*(E9O8^H@<V]L:6-I=&]U('-E<B!N;W1I
M9FEC861O('%U86YD;R!E=F5N=&]S('/C;R!E>&-L=>UD;W,@9&4@<W5A<R!A
M9V5N9&%S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q,3D*;7-G:60@(EEO
M=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&5D
M:71E9"!I;B!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@HB5F]CZB!S;VQI
M8VET;W4@<V5R(&YO=&EF:6-A9&\@<75A;F1O(&5V96YT;W,@<^-O(&5D:71A
M9&]S(&5M('-U87,@86=E;F1A<RXB"@HC.B!L:6(O4V-H961U;&5R+VMR;VYO
M;&ET:"YP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R97%U97-T
M960@=&\@8F4@<F5M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N("5S(&%T
M("5S+B(*;7-G<W1R(")6;V/J('-O;&EC:71O=2!S97(@879I<V%D;R!S;V)R
M92`E<RP@<75E('-E<N$@96T@)7,@(.!S("5S+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*;7-G:60@(EEO=7(@9&5F875L="!C
M86QE;F1A<B(*;7-G<W1R(")3=6$@86=E;F1A('!A9'+C;R(*"B,Z(&QI8B]$
M<FEV97(N<&AP.C$P-3@@;&EB+T1R:79E<BYP:'`Z,3`V.`IM<V=I9"`B6U5N
M;F%M960@979E;G1=(@IM<V=S='(@(EM%=F5N=&\@<V5M(&YO;65=(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z.34*;7-G:60@(E]!;&%R;2(*;7-G
M<W1R(")!=FES;R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHQ,0IM<V=I9"`B7T)A<VEC(%-E87)C:"(*;7-G<W1R(")097-Q
M=6ES82!?4VEM<&QE<R(*"B,Z('9I97=E=F5N="YP:'`Z,3,U"FUS9VED(")?
M161I="(*;7-G<W1R(")?161I=&%R(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3,U,`IM<V=I9"`B7T=O=&\B"FUS9W-T<B`B7TER(%!A<F$B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,S4V"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G
M<W1R("));7!O<G1A<B]%7WAP;W)T87(B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,S,W"FUS9VED(")?37D@0V%L96YD87)S(@IM<V=S='(@(DUI;FAA<R!?
M06=E;F1A<R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-#0*;7-G:60@(E].
M97<@179E;G0B"FUS9W-T<B`B7TYO=F\@179E;G1O(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3,V,0IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(DE?;7!R:6UI
M<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-3(*;7-G:60@(E]396%R8V@B
M"FUS9W-T<B`B7U!E<W%U:7-A<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S
M-#<*;7-G:60@(E]4;V1A>2(*;7-G<W1R(")?2&]J92(*"B,Z('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C$T,`IM<V=I9"`B8F5F;W)E('1H92!E=F5N="!S
M=&%R=',B"FUS9W-T<B`B86YT97,@9&4@:6YI8VEA<B!O(&5V96YT;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G<W1R
M(")D:6$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C`W"FUS9VED(")D87DH<RDB"FUS9W-T<B`B
M9&EA*',I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(F1I87,B"@HC.B!D
M871A+G!H<#HQ-#8@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ"FUS9VED
M(")E=F5N=',N8W-V(@IM<V=S='(@(F5V96YT;W,N8W-V(@H*(SH@9&%T82YP
M:'`Z,38W"FUS9VED(")E=F5N=',N:6-S(@IM<V=S='(@(F5V96YT;W,N:6-S
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,S$*;7-G
M:60@(F9R;VTB"FUS9W-T<B`B9&4B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C(R-R!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR,S,*;7-G:60@(FUO;G1H*',I(@IM<V=S='(@(FWJ<RAE<RDB"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HQ,#0P"B,L('!H<"UF;W)M870*;7-G:60@(F]N
M("5S(&%T("5S(@IM<V=S='(@(F5M("5S(.!S("5S(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z,3(T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R
M-PIM<V=I9"`B;VX@=&AE('-A;64@9&%T92(*;7-G<W1R(")N82!M97-M82!D
M871A(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(S,PIM<V=I9"`B;VX@=&AE('-A;64@=V5E:V1A
M>2(*;7-G<W1R(")N82!M97-M82!S96UA;F$B"@HC.B!D871A+G!H<#HR.2!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T"FUS9VED(")V0V%L96YD87(O
M:4-A;&5N9&%R(@IM<V=S='(@(G9#86QE;F1A<B]I0V%L96YD87(B"@HC.B!L
M:6(O87!I+G!H<#HS-3`@;&EB+V%P:2YP:'`Z-C(Y"FUS9VED(")V179E;G0@
M;F]T(&9O=6YD+B(*;7-G<W1R(")V179E;G0@;N-O(&5N8V]N=')A9&\N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,0IM<V=I9"`B=V5E:R(*;7-G
M<W1R(")S96UA;F$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C(@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$T"FUS9VED(")W965K*',I(&]N
M.B(*;7-G<W1R(")S96UA;F$H<RD@96TZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.30*;7-G:60@(G=E96MS(@IM<V=S='(@(G-E
M;6%N87,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C@@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C,Y"FUS9VED(")Y96%R*',I(@IM<V=S='(@
M(F%N;RAS*2(*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O<&\O
M<'1?4%0N<&\`````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,3(P-#`Q`#$P-#$W,S8R-S4S`#`R,#0S-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($M23TY/3$E42"!0;W)T=6=A;"!0
M;W)T=6=U97-E('1R86YS;&%T:6]N+@HC($UA;G5E;"!-96YE>F5S(&1E(%-E
M<75E:7)A(#Q-86YU96PN4V5Q=65I<F$^+"`R,#`U+@HC($)A<V5D(&]N(&$@
M<')E=FEO=7,*(R!+4D].3TQ)5$@@0E)!6DE,24%.(%!/4E151U5%4T4@3$%.
M1U5!1T4@1DE,12X*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@4V%M=65L($UO=&$N
M"B,@4T%-545,($U/5$$@/'-A;75E;$!B=6UE<F%N9W5E+F-O;3XL(#(P,#$N
M"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($MR
M;VYO;&ET:"TP+C`N,RUC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P
M-2TQ,"TQ,R`Q-SHQ,RLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`Q
M+3$R+3`V(#$V.C(P+3`S,#!<;B(*(DQA<W0M5')A;G-L871O<CH@4V%M=65L
M($UO=&$@/'-A;75E;$!B=6UE<F%N9W5E+F-O;3Y<;B(*(DQA;F=U86=E+51E
M86TZ($)R87II;&EA;B!0;W)T=6=U97-E(#QD979`;&ES=',N:&]R9&4N;W)G
M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@979E;G1S(@IM
M<V=S='(@(B5D(&5V96YT;W,B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1&%Y*',I
M("5S($AO=7(H<RD@)7,@36EN=71E<R(*;7-G<W1R("(E<R!$:6$H<RD@)7,@
M2&]R82AS*2`E<R!-:6YU=&\H<RDB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-SDT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T=&5N9&5E<R(*;7-G<W1R("(E
M<R!P87)T:6-I<&%N=&5S(@H*(SH@9&%T82YP:'`Z,C0Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S
M='(@(F%R<75I=F\@)7,@:6UP;W)T861O(&-O;2!S=6-E<W-O(@H*(SH@8V%L
M96YD87)S+G!H<#HQ,#4@;&EB+V)A<V4N<&AP.C$R-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9.%R:6\@9&4@
M)7,B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V-`IM
M<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@061D("HB"FUS9W-T<B`B
M*B!!9&EC:6]N92UO<R!C;&EC86YD;R!E;2!!9&EC:6]N87(@*B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,34P"FUS9VED("(J(%!L
M96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(%!O<B!F879O
M<B!S96QE8V-I;VYE(&5N9&5R9>=O*',I("HB"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-SDT"FUS9VED("(Q(&%T=&5N9&5E(@IM<V=S='(@(C$@<&%R=&EC:7!A
M;G1E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0*;7-G:60@
M(C$@979E;G0B"FUS9W-T<B`B,2!E=F5N=&\B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ-S`*;7-G:60@(CQB/D%T=&5N9&5E<SPO8CX@*&]P=&EO
M;F%L*2(*;7-G<W1R("(\8CY087)T:6-I<&%N=&5S/"]B/B`H;W!C:6]N86PI
M(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30X"FUS9VED("(\8CY$
M97-C<FE?<'1I;VX\+V(^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^1&5S7V-R
M:>?C;SPO8CX@*&]P8VEO;F%L*2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(W-@IM<V=I9"`B/&(^2V5Y=V]R9',\+V(^("AO<'1I;VYA;"DB"FUS
M9W-T<B`B/&(^4&%L85]V<F%S+4-H879E/"]B/B`H;W!C:6]N86PI(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3DS"FUS9VED("(\8CY296-U<G)E
M;F-E/"]B/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/E)E<&5T:>?C;SPO8CX@
M*&]P8VEO;F%L*2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`Q
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@Q"FUS9VED(")!32(*;7-G
M<W1R(")!32(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T-0IM<V=I9"`B06-C
M97!T960B"FUS9W-T<B`B06-E:71E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:6YC.C$Q"FUS9VED(")!9%]V86YC960@4V5A<F-H(@IM<V=S='(@
M(E!R;V-U<F$@7T%V86[G861A(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ-C$@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ.3`*;7-G:60@(D%D9"(*;7-G<W1R(")!9&EC:6]N87(B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR-0IM<V=I9"`B061D($5V96YT(@IM<V=S
M='(@(D%D:6-I;VYA<B!%=F5N=&\B"@HC.B!T96UP;&%T97,O<')E9G,O<F5M
M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHS-0IM<V=I9"`B061D(&$@;F5W(%)E
M;6]T92!#86QE;F1A<B(*;7-G<W1R(")!9&EC:6]N87(@=6T@;F]V;R!#86QE
M;F3A<FEO(%)E;6]T;R(*"B,Z(&%D9&5V96YT+G!H<#HU,`IM<V=I9"`B061D
M(&$@;F5W(&5V96YT(@IM<V=S='(@(D%D:6-I;VYA<B!U;2!N;W9O(&5V96YT
M;R(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHX,0IM
M<V=I9"`B061D(&%T=&5N9&5E<R(*;7-G<W1R(")!9&EC:6]N87(@<&%R=&EC
M:7!A;G1E<R(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN
M8SHY,0IM<V=I9"`B061D('!E;W!L92!F<F]M(&UY($%D9')E<W,@0F]O:R(*
M;7-G<W1R(")!9&EC:6]N87(@<&5S<V]A<R!D;R!M974@3&EV<F\@9&4@16YD
M97)EYV]S(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC
M.C@V"FUS9VED(")!9&0@=&AE<V4@<&5O<&QE(@IM<V=S='(@(D%D:6-I;VYA
M<B!E<W1A<R!P97-S;V%S(@H*(SH@8V]N=&%C=',N<&AP.C@R('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(P"FUS9VED(")!9&1R97-S($)O
M;VLB"FUS9W-T<B`B3&EV<F\@9&4@16YD97)EYV]S(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS9W-T
M<B`B4')O8W5R82!!=F%NYV%D82(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D:70N:6YC.CDV"FUS9VED(")!;&%R
M;2(*;7-G<W1R(")!=FES;R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@9&%Y<R!B969O<F4B"FUS9W-T
M<B`B079I<V\@)60@9&EA<R!A;G1E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@:&]U<G,@8F5F;W)E
M(@IM<V=S='(@(D%V:7-O("5D(&AO<F%S(&%N=&5S(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z,3<X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!M:6YU
M=&5S(&)E9F]R92(*;7-G<W1R(")!=FES;R`E9"!M:6YU=&]S(&%N=&5S(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z,3<V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M;&%R;2`E9"!W965K<R!B969O<F4B"FUS9W-T<B`B079I<V\@)60@<V5M86YA
M<R!A;G1E<R(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-S,*;7-G:60@(D%L87)M
M(#$@9&%Y(&)E9F]R92(*;7-G<W1R(")!=FES;R`Q(&1I82!A;G1E<R(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$W-S@*;7-G:60@(D%L87)M(#$@:&]U<B!B969O
M<F4B"FUS9W-T<B`B079I<V\@,2!H;W)A(&%N=&5S(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z,3<X,PIM<V=I9"`B06QA<FT@,2!M:6YU=&4@8F5F;W)E(@IM<V=S
M='(@(D%V:7-O(#$@;6EN=71O(&%N=&5S(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<V.`IM<V=I9"`B06QA<FT@,2!W965K(&)E9F]R92(*;7-G<W1R(")!=FES
M;R`Q('-E;6%N82!A;G1E<R(*"B,Z(&1A=&$N<&AP.C4P"FUS9VED(")!;&%R
M;2!$871E(@IM<V=S='(@(D1A=&$@9&\@079I<V\B"@HC.B!D871A+G!H<#HT
M.0IM<V=I9"`B06QA<FT@4W!A;B`H;6EN=71E<RDB"FUS9W-T<B`B1'5R8>?C
M;R!D;R!!=FES;R`H;6EN=71O<RDB"@HC.B!D871A+G!H<#HU,0IM<V=I9"`B
M06QA<FT@5&EM92(*;7-G<W1R(")(;W)A(&1O($%V:7-O(@H*(SH@=&5M<&QA
M=&5S+V1E;&5T92]D96QE=&4N:6YC.C,Q"FUS9VED(")!;&PB"FUS9W-T<B`B
M5'5D;R(*"B,Z(&QI8B]&0E9I97<N<&AP.C$R-"!L:6(O1D)6:65W+G!H<#HQ
M,C<@;&EB+T9"5FEE=RYP:'`Z,3,P"FUS9VED(")!;&P@071T96YD965S(@IM
M<V=S='(@(E1O9&]S(&]S(%!A<G1I8VEP86YT97,B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z-3D*;7-G:60@(D%L;"!&=71U<F4B"FUS9W-T
M<B`B5&]D;R!O($9U='5R;R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M+FEN8SHU,PIM<V=I9"`B06QL(%!A<W0B"FUS9W-T<B`B5&]D;R!O(%!A<W-A
M9&\B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C<@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HR-`HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR
M-R!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D%L;"!6:7-I8FQE
M(@IM<V=S='(@(E1U9&\@;R!6:7/M=F5L(@H*(SH@=&5M<&QA=&5S+V5D:70O
M961I=%]T:6UE<W!A;BYI;F,Z,3(V(&QI8B]$87E6:65W+G!H<#HX-B!L:6(O
M1&%Y5FEE=RYP:'`Z.#@*(SH@;&EB+U=E96M6:65W+G!H<#HQ,#@@;&EB+U=E
M96M6:65W+G!H<#HQ,3@@;&EB+T1R:79E<BYP:'`Z,38Y.`HC.B!L:6(O1')I
M=F5R+G!H<#HQ-S(T"FUS9VED(")!;&P@9&%Y(@IM<V=S='(@(E1O9&\@;R!D
M:6$B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,38X"FUS9VED(")!;&P@
M9&%Y(&5V96YT(@IM<V=S='(@(D5V96YT;R!D92!T;V1O(&\@9&EA(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM<V=I9"`B06QL(&5V96YT
M<R(*;7-G<W1R(")4;V1O<R!O<R!E=F5N=&]S(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8VA?861V86YC960N:6YC.C0Y"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHW,2!L:6(O2W)O;F]L:71H+G!H<#HV
M,S<*;7-G:60@(D%N>2(*;7-G<W1R(")1=6%L<75E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Q"FUS9VED(")!<')I;"(*;7-G<W1R
M(")!8G)I;"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC
M.CDU('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-S`*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ-38*;7-G:60@(D%T(@IM<V=S='(@(L!S(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`P,@IM<V=I9"`B(@HB071T86-H960@
M:7,@86X@:4-A;&5N9&%R(&9I;&4@=VET:"!M;W)E(&EN9F]R;6%T:6]N(&%B
M;W5T('1H92!E=F5N="X@268@>6]U<B`B"B)M86EL(&-L:65N="!S=7!P;W)T
M<R!I5&EP(')E<75E<W1S('EO=2!C86X@=7-E('1H:7,@9FEL92!T;R!E87-I
M;'D@=7!D871E("(*(GEO=7(@;&]C86P@8V]P>2!O9B!T:&4@979E;G0N(@IM
M<V=S='(@(B(*(D5M(&%N97AO(&5S=.$@=6T@87)Q=6EV;R!I0V%L96YD87(@
M8V]M(&UA:7,@:6YF;W)M8>?C;R!S;V)R92!O(&5V96YT;RX@4V4@;R`B"B)S
M974@8VQI96YT92!D92!C;W)R96EO(&5L96-T<O-N:6-O('-U<&]R=&%R('!E
M9&ED;W,@:51I<"P@<&]D92!U<V%R(&5S=&4@(@HB9FEC:&5I<F\@<&%R82!A
M8W1U86QI>F%R(&-O;2!F86-I;&ED861E(&$@<W5A(&/S<&EA(&QO8V%L(&1O
M(&5V96YT;RXB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI
M;F,Z-#8@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3@Q"FUS9VED(")!='1E
M;F1A;F-E(@IM<V=S='(@(E!A<G1I8VEP8>?C;R(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$W-PIM<V=I9"`B071T96YD965S(@IM<V=S='(@(E!A
M<G1I8VEP86YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHW-0IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%G;W-T;R(*"B,Z('1E;7!L
M871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,C8*;7-G:60@(D)A8VL@
M=&\@0V%L96YD87(@3W!T:6]N<R(*;7-G<W1R(")6;VQT87(@X',@3W#G]65S
M(&1E($-A;&5N9.%R:6\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A
M9'9A;F-E9"YI;F,Z,3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C@*
M;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R(")0<F]C=7)A($+A<VEC82(*
M"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B1&%T82!D92!N87-C:6UE;G1O(@H*(SH@=&5M<&QA=&5S
M+V9B=FEE=R]L96=E;F0N:6YC.C,@;&EB+T9"5FEE=RYP:'`Z.3`@;&EB+T9"
M5FEE=RYP:'`Z,3`Y"FUS9VED(")"=7-Y(@IM<V=S='(@(D]C=7!A9&\B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#0*;7-G
M:60@(D-?86QE;F1A<B(*;7-G<W1R(")#7V%L96YDX7)I;R(*"B,Z('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C0X"FUS9VED(")#86Q?96YD87(B"FUS9W-T
M<B`B0V%L7V5N9.%R:6\B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP
M:'`Z,C$@;&EB+T)L;V-K+VUO;G1H+G!H<#HR,0HC.B!L:6(O0FQO8VLO;6]N
M=&AL:7-T+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9.%R:6\B"@HC.B!T96UP;&%T97,O
M8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3$S"FUS9VED(")#86QE;F1A<B!$
M97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGGXV\@9&\@0V%L96YDX7)I;R(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHY-PIM<V=I
M9"`B0V%L96YD87(@3F%M92(*;7-G<W1R(").;VUE(&1O($-A;&5N9.%R:6\B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PIM<V=I9"`B0V%L96YD87(@
M4W5M;6%R>2(*;7-G<W1R(")3=6WA<FEO(&1O($-A;&5N9.%R:6\B"@HC.B!C
M86QE;F1A<G,N<&AP.C$Q.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,`IM<V=I9"`B0V%L96YD87)S(@IM<V=S='(@(D-A;&5N9.%R:6]S(@H*
M(SH@8V%L96YD87)S+G!H<#HR-PIM<V=I9"`B0V%L96YD87)S(&UU<W0@:&%V
M92!A(&YA;64N(@IM<V=S='(@(D]S(&-A;&5N9.%R:6]S('3J;2!D92!T97(@
M=6T@;F]M92(*"B,Z(&1A=&$N<&AP.C(Q,0IM<V=I9"`B0V%N)W0@8W)E871E
M(&$@;F5W(&5V96YT+B(*;7-G<W1R("));7!O<W/M=F5L(&-R:6%R(&YO=F\@
M979E;G1O+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,3DQ('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHS,`HC.B!T96UP;&%T97,O
M9&5L971E+V1E;&5T92YI;F,Z,S(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,S(*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S`X"FUS9VED(")#86YC
M96PB"FUS9W-T<B`B0V%N8V5L87(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU
M,C0*;7-G:60@(D-A;F-E;&QE9"(*;7-G<W1R(")#86YC96QA9&\B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M8V5L;&5D.B`E<R(*;7-G<W1R(")#86YC96QA9&\Z("5S(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C8T('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C8X"FUS9VED(")#871E9V]R7WDB"FUS9W-T<B`B0V%T
M96=O<E]I82(*"B,Z(&1A=&$N<&AP.C4S('1E;7!L871E<R]S96%R8V@O979E
M;G1?:&5A9&5R<RYI;F,Z-"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR,0IM
M<V=I9"`B0V%T96=O<GDB"FUS9W-T<B`B0V%T96=O<FEA(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(R('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ,C,*;7-G:60@(D-H86YG92(*;7-G<W1R
M(")!;'1E<F%R(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E87)C:%]A8F]O:U]S
M96QE8W0N:6YC.C$W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S4*;7-G:60@
M(D-H;V]S92!T:&4@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@9F]R(&9R964O
M8G5S>2!54DQS.B(*;7-G<W1R("(B"B)%<V-O;&AA(&]S(&QI=G)O<R!D92!E
M;F1E<F7G;W,@;F]S('%U86ES('!R;V-U<F%R('!O<B!54DP@3&EV<F4O3V-U
M<&%D;SHB"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z
M,3,X"FUS9VED("(B"B)#:&]O<V4@=&AE(&-A;&5N9&%R<R!T:&%T('EO=2!W
M86YT('1O(&)E(&EN8VQU9&5D(&EN('EO=7(@1G)E92]"=7-Y(&QI<W1I;F=S
M.B(*;7-G<W1R("(B"B)%<V-O;&AA(&]S(&-A;&5N9.%R:6\@<75E('!R971E
M;F1E(&EN8VQU:7(@;F%S(&QI<W1A<R!D92!,:79R92]/8W5P861O.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B0VAO;W-E('EO=7(@
M9&5F875L="!C86QE;F1A<BXB"FUS9W-T<B`B17-C;VQH82!O('-E=2!C86QE
M;F3A<FEO('!O<B!O;6ES<^-O+B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHW,@IM<V=I9"`B0VQE87(@86QL(&%T=&%N9&5E<R(*
M;7-G<W1R(")296UO=F5R('1O9&]S(&]S('!E<G1I8VEP86YT97,B"@HC.B!D
M871A+G!H<#HR."!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$V"FUS9VED
M(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(E9A;&]R97,@<V5P
M87)A9&]S('!O<B!V[7)G=6QA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-@IM<V=I9"`B0V]N9FER;2!D96QE=&EO;B!O9B!E=F5N=',_(@IM<V=S
M='(@(D-O;F9I<FUA(')E;6_GXV\@9&4@979E;G1O<S\B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU,C$*;7-G:60@(D-O;F9I<FUE9"(*;7-G<W1R(")#;VYF
M:7)M861O(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC
M.C$U,0IM<V=I9"`B0V]P>2!T:&4@55),(&)E;&]W(&9O<B!U<V4@=VAE<F5V
M97(@>6]U(&YE960@>6]U<B!&<F5E+T)U<WD@55),.B(*;7-G<W1R(")#;W!I
M92!O(%523"!A8F%I>&\@<&%R82!U<V%R(&]N9&4@9F]R(&YE8V5S<^%R:6\@
M=6T@55),($QI=G)E+T]C=7!A9&\Z(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,38R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*
M;7-G<W1R(").XV\@<'5D92!A8G)I<B`E<RXB"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z,3<@=&5M<&QA=&5S+V-A;&5N9&%R<R]C
M86QE;F1A<G,N:6YC.C$R,PHC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N
M9&%R<RYI;F,Z,3(U"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0W)I87(B"@HC
M.B!M;VYT:"YP:'`Z,34V(&UO;G1H+G!H<#HQ-3<@=&5M<&QA=&5S+W=E96LO
M:&5A9"YI;F,Z,C(*(SH@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z,C,@=&5M
M<&QA=&5S+V1A>2]R;W<N:6YC.C8@;&EB+T1A>59I97<N<&AP.C@V"B,Z(&QI
M8B]$87E6:65W+G!H<#HQ.#4*;7-G:60@(D-R96%T92!A($YE=R!%=F5N="(*
M;7-G<W1R(")#<FEA<B!.;W9O($5V96YT;R(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C@X"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(D-R:6%D;R(*
M"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHR.0IM<V=I9"`B0W5R
M<F5N="(*;7-G<W1R(")#;W)R96YT92(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$R,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#@*;7-G:60@
M(D1A:6QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B1&GA<FEO.B!297!E=&4@
M8V%D82(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`V(&QI8B]+<F]N;VQI=&@N<&AP
M.C$P-S<@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<U"FUS9VED(")$87DB"FUS9W-T<B`B1&EA(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S`@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,3,X"FUS9VED(")$87DH<RDB"FUS9W-T<B`B1&EA*',I(@H*(SH@
M=FEE=V5V96YT+G!H<#HQ,#,*;7-G:60@(D1E7VQE=&4B"FUS9W-T<B`B4F5?
M;6]V97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.0IM
M<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5Z96UB<F\B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU-#@*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(D1E8VQI
M;F]U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W"FUS9VED(")$969A
M=6QT($-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9.%R:6\@<&]R($]M:7-SXV\B
M"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,3(T('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@Q"B,Z('1E;7!L871E
M<R]D96QE=&4O;VYE+FEN8SHR.2!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A
M;%]M86YA9V5M96YT+FEN8SHR,PHC.B!L:6(O1')I=F5R+G!H<#HQ.#$Y"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B4F5M;W9E<B(*"B,Z('9I97=E=F5N="YP
M:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!<(B5S7"(B"FUS
M9W-T<B`B4F5M;W9E<B!<(B5S7"(B"@HC.B!D96QE=F5N="YP:'`Z-#`@=&5M
M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C$X('1E;7!L871E<R]D96QE=&4O9&5L
M971E+FEN8SHQ.`HC.B!L:6(O1')I=F5R+G!H<#HQ.#$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R(")296UO=F5R("5S(@H*(SH@
M961I=&5V96YT+G!H<#HV,0IM<V=I9"`B1&5L971E($5V96YT(@IM<V=S='(@
M(E)E;6]V97(@979E;G1O(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N
M:6YC.C(W"FUS9VED("(B"B)$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@;VYL
M>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC97,L
M(&]R("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R("(B"B)296UO=F5R(&\@
M87!E;F%S(&\@979E;G1O(&-O<G)E;G1E+"!O(&5V96YT;R!C;W)R96YT92!E
M('1O9&%S(&%S(&]C;W)RZFYC:6%S("(*(F9U='5R87,L(&]U('1O9&%S(&%S
M(&]C;W)RZFYC:6%S/R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHQ,#0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X
M"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B1&5S8W)?:>?C;R(*"B,Z
M(&1A=&$N<&AP.C4R('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$P-0IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)IY^-O(@H*(SH@=&5M<&QA
M=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C$P-0IM<V=I9"`B1&ES;6ES
M<R(*;7-G<W1R(")$97-C87)T87(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$W,PIM<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")-;W-T
M<F%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.`IM<V=I9"`B
M1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!6:7-U86QI>F'G
MXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1O('EO
M=2!W86YT('1O('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U92!O;B!Y;W5R(&-A
M;&5N9&%R/R(*;7-G<W1R(")$97-E:F$@;6]S=')A<B!P<F%Z;R!F:6YA;"!D
M87,@=&%R969A<R!N;R!S974@8V%L96YDX7)I;S\B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HT.3$*;7-G:60@(D1O97,@;F]T(')E8W5R(@IM<V=S='(@(D[C
M;R!S92!R97!E=&4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HS,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1'5E.B`E<R(*;7-G<W1R(")0<F%Z;R!F:6YA;#H@
M)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHV,@IM
M<V=I9"`B1'5R871I;VXB"FUS9W-T<B`B1'5R8>?C;R(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$X,3(*;7-G:60@(D5D:70B"FUS9W-T<B`B161I=&%R(@H*(SH@
M=FEE=V5V96YT+G!H<#HQ,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!<
M(B5S7"(B"FUS9W-T<B`B161I=&%R(%PB)7-<(B(*"B,Z(&5D:71E=F5N="YP
M:'`Z,S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C4@;&EB+T1R:79E<BYP
M:'`Z,3@Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@
M(D5D:71A<B`E<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$X-@IM
M<V=I9"`B161I="!!='1E;F1E97,B"FUS9W-T<B`B161I=&%R(%!A<G1I8VEP
M86YT97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED(")%
M9&ET(%)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`B161I=&%R($-A;&5N9.%R
M:6]S(%)E;6]T;W,B"@HC.B!A='1E;F1E97,N<&AP.C$T-@IM<V=I9"`B161I
M="!A='1E;F1E97,B"FUS9W-T<B`B161I=&%R('!A<G1I8VEP86YT97,B"@HC
M.B!T96UP;&%T97,O8V%T96=O<GE?;&5G96YD+FEN8SHR-0IM<V=I9"`B161I
M="!C871E9V]R:65S(&%N9"!C;VQO<G,B"FUS9W-T<B`B161I=&%R(&-A=&5G
M;W)I87,@92!C;W)E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3<V('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT
M-0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ.#`*;7-G:60@(D5M86EL
M($%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@9&4@0V]R<F5I;R!%;&5C='+S
M;FEC;R(*"B,Z(&1A=&$N<&AP.C0W"FUS9VED(")%;F0@1&%T92(*;7-G<W1R
M(")$871A(&9I;F%L(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D
M97)S+FEN8SHX('1E;7!L871E<R]V:65W+W9I97<N:6YC.C4U"B,Z('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8W('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,3`X"FUS9VED(")%;F0@3VXB"FUS9W-T<B`B06-A8F$@
M96TB"@HC.B!D871A+G!H<#HT.`IM<V=I9"`B16YD(%1I;64B"FUS9W-T<B`B
M2&]RX7)I;R!F:6YA;"(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3(P(&%T=&5N9&5E
M<RYP:'`Z,3,Q(&%T=&5N9&5E<RYP:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O
M<B`E<SH@)7,B"FUS9W-T<B`B17)R;R!D97-C87)R96=A;F1O(&EN9F]R;6'G
MXV\@;&EV<F4O;V-U<&%D;R!D92`E<SH@)7,B"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ,#(X"B,L('!H<"UF;W)M870*;7-G:60@(D5V96YT(&9R;VT@)7,@=&\@
M)7,B"FUS9W-T<B`B179E;G1O(&1E("5S(&$@)7,B"@HC.B!L:6(O1')I=F5R
M+G!H<#HW-#<*;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@82!S=&%R="!D871E
M+B(*;7-G<W1R(")/<R!E=F5N=&]S('3J;2!D92!T97(@=6UA(&1A=&$@9&4@
M:6[M8VEO+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<Q,PIM<V=I9"`B179E;G1S
M(&UU<W0@:&%V92!A('1I=&QE+B(*;7-G<W1R(")/<R!E=F5N=&]S('3J;2!D
M92!T97(@=6T@=.UT=6QO+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<U,`IM<V=I
M9"`B179E;G1S(&UU<W0@:&%V92!A;B!E;F0@9&%T92!O<B!A(&1U<F%T:6]N
M+B(*;7-G<W1R(")/<R!E=F5N=&]S('3J;2!D92!T97(@=6UA(&1A=&$@9FEN
M86P@;W4@=6UA(&1U<F'GXV\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ.#<*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%>'!O<G1A<B(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z.`IM<V=I9"`B17AP;W)T($-A
M;&5N9&%R(@IM<V=S='(@(D5X<&]R=&%R(&-A;&5N9.%R:6\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV.0IM<V=I9"`B1F5B<G5A<GDB
M"FUS9W-T<B`B1F5V97)E:7)O(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ,C@*;7-G:60@(D9I;F0B"FUS9W-T<B`B4&5S<75I<V%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C,@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C(Q"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,3`Y"FUS9VED(")&<B(*;7-G<W1R("(V+JHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G
M<W1R("));F9O<FUAY^-O($QI=G)E+T]C=7!A9&\B"@HC.B!T96UP;&%T97,O
M;6]N=&@O:&5A9"YI;F,Z,C`@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,P
M"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")&
M<FED87DB"FUS9W-T<B`B<V5X=&$M9F5I<F$B"@HC.B!T96UP;&%T97,O9&5L
M971E+V1E;&5T92YI;F,Z,S`*;7-G:60@(D9U='5R92(*;7-G<W1R(")&=71U
M<F\B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(D=A
M;64B"FUS9W-T<B`B2F]G;R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHR,PIM<V=I9"`B1V5N97)A;"(*;7-G<W1R(")'97)A
M;"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V]T;R`E<R(*;7-G<W1R("))<B!P87)A("5S(@H*(SH@=&5M
M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L
M871E<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"FUS9VED(")(:61E
M(@IM<V=S='(@(D5S8V]N9&5R(@H*(SH@=&5M<&QA=&5S+W=E96LO:&5A9%]S
M:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(DAI9&4@)7,B
M"FUS9W-T<B`B3V-U;'1A<B`E<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C<S('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S-PIM<V=I9"`B2&]U
M<BAS*2(*;7-G<W1R(")(;W)A*',I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(V-`IM<V=I9"`B(@HB2&]W(&UA;GD@9&%Y<R!I;G1O('1H92!F=71U
M<F4@<VAO=6QD('=E(&=E;F5R871E(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F
M;W(_(@IM<V=S='(@(D%TZ2!Q=6%N=&]S(&1I87,@;F\@9G5T=7)O(&1E=F5M
M;W,@9V5R87(@:6YF;W)M8>?C;R!L:79R92]O8W5P861O/R(*"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0@0V%L96YD87(L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T87(@0V%L
M96YDX7)I;RP@4&%S<V\@)60B"@HC.B!D871A+G!H<#HR.#8*;7-G:60@(DEM
M<&]R="]%>'!O<G0@0V%L96YD87(B"FUS9W-T<B`B26UP;W)T87(O17AP;W)T
M87(@0V%L96YDX7)I;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C8X"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA;F5I<F\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-`IM<V=I9"`B2G5L>2(*
M;7-G<W1R(")*=6QH;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C<S"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FAO(@H*(SH@9&%T82YP
M:'`Z-34@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,34U"FUS9VED(")+97EW
M;W)D<R(*;7-G<W1R(")086QA=G)A<RUC:&%V92(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R-"!H;W5R<R(*;7-G
M<W1R("+:;'1I;6%S(#(T(&AO<F%S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z.34*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`BVFQT:6UO
M($UO9&EF:6-A9&\B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y
M7W-I9&4N:6YC.C0*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S
M:61E+FEN8SHQ,`HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I
M9&4N:6YC.C$V('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHT"FUS9VED("),
M87-T($UO;G1H(@IM<V=S='(@(MIL=&EM;R!-ZG,B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z-30@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z
M,PIM<V=I9"`B3&%S="!W965K(@IM<V=S='(@(MIL=&EM82!S96UA;F$B"@HC
M.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,C(*;7-G:60@
M(DQA<W1S(@IM<V=S='(@(D1U<F'GXV\B"@HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$W"FUS9VED("),:6UI="!T:&4@=&EM92!S<&%N('1O(&5X
M<&]R=#HB"FUS9W-T<B`B3&EM:71A<B!A(&=A;6$@=&5M<&]R86P@82!E>'!O
M<G1A<CH@(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N
M:6YC.C@V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C<U"FUS9VED("),;U]C
M871I;VXB"FUS9W-T<B`B3&]?8V%L(@H*(SH@9&%T82YP:'`Z-30@=&5M<&QA
M=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHU"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$X"B,Z('1E;7!L871E
M<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C4R('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C(Y"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),
M;V-A;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-0IM<V=I9"`B36%N
M86=E(')E;6]T92!C86QE;F1A<G,N(@IM<V=S='(@(D=E<FER(&-A;&5N9.%R
M:6]S(')E;6]T;W,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-S`*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<N=O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R
M(")-86EO(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")-965T:6YG(@IM<V=S='(@(D5N8V]N=')O(@H*(SH@;&EB+T)L;V-K+W1R
M965?;65N=2YP:'`Z,PIM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(DQI<W1A
M(&1E($UE;G5S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S8@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,3,V"FUS9VED(")-:6YU=&4H<RDB"FUS
M9W-T<B`B36EN=71O*',I(@H*(SH@;&EB+T)L;V-K+W!R979M;VYT:&QI<W0N
M<&AP.C0T"FUS9VED(")-:7-S960@179E;G1S($QI<W0B"FUS9W-T<B`B3&ES
M=&$@9&4@179E;G1O<R!&86QH861O<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C4Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q-PHC
M.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P.0IM<V=I9"`B36\B"FUS9W-T<B`B
M,BZJ(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$V('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R-@HC.B!T96UP;&%T97,O961I="]J879A<V-R
M:7!T+FEN8SHV."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"FUS9VED(")-
M;VYD87DB"FUS9W-T<B`B<V5G=6YD82UF96ER82(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$P.#`@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C0@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")-;VYT:"(*;7-G<W1R(")-ZG,B
M"@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C,*;7-G:60@(DUO;G1H(%9I97<B
M"FUS9W-T<B`B5FES=&$@9&4@3>IS(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES
M="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT-`IM<V=I9"`B36]N
M=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R("),:7-T82!D92!%=F5N=&]S($UE
M;G-A:7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S8@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3,X"B,Z('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S0*;7-G:60@(DUO
M;G1H;'DZ(%)E8W5R<R!E=F5R>2(*;7-G<W1R(")-96YS86PZ(%)E<&5T92!C
M861A(@H*(SH@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO
M;G1H<R!!:&5A9"(*;7-G<W1R(")-97-E<R#@($9R96YT92(*"B,Z(&QI8B]"
M;&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS($)E9F]R
M92(*;7-G<W1R(")-97-E<R!!='+A<R(*"B,Z(&QI8B]A<&DN<&AP.C$W-PIM
M<V=I9"`B375L=&EP;&4@:4-A;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N
M;'D@;VYE('9%=F5N="!I<R!S=7!P;W)T960N(@IM<V=S='(@(B(*(DWZ;'1I
M<&QO<R!C;VUP;VYE;F5T92!I0V%L96YD87(@96YC;VYT<F%D;W,[(&%P96YA
M<R!S92!S=7!O<G1A('5M('9%=F5N="XB"@HC.B!T96UP;&%T97,O8V%L96YD
M87)S+V-A;&5N9&%R<RYI;F,Z.#0*;7-G:60@(DUY($-A;&5N9&%R<R(*;7-G
M<W1R(")/<R!-975S($-A;&5N9.%R:6]S(@H*(SH@=&5M<&QA=&5S+VUE;G4N
M:6YC.C,P"FUS9VED(")->2!#86QE;F1A<G,Z(@IM<V=S='(@(D]S($UE=7,@
M0V%L96YDX7)I;W,Z(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$S,@IM<V=I9"`B37D@1G)E92]"=7-Y(%523"(*;7-G<W1R(")/
M<R!-975S(%523"!,:79R92]/8W5P861O(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ-S4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T
M95]C86Q?;6%N86=E;65N="YI;F,Z,3<*(SH@=&5M<&QA=&5S+W!R969S+W)E
M;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-#0*;7-G:60@(DYA;64B"FUS9W-T
M<B`B3F]M92(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z-#,@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z-#4@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C0R"B,Z
M(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(P"FUS9VED(").97<@179E;G0B
M"FUS9W-T<B`B3F]V;R!%=F5N=&\B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C,T"FUS9VED(").97AT(@IM<V=S='(@(E!R\WAI;6\B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3<*;7-G:60@(DYE>'0@,C0@
M:&]U<G,B"FUS9W-T<B`B4'+S>&EM87,@,C0@:&]R87,B"@HC.B!L:6(O1D)6
M:65W+V1A>2YP:'`Z-S@*;7-G:60@(DYE>'0@1&%Y(@IM<V=S='(@(E!R\WAI
M;6\@1&EA(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E
M+FEN8SHV"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI
M;F,Z,3(*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN
M8SHQ."!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z-@IM<V=I9"`B3F5X="!-
M;VYT:"(*;7-G<W1R(")0<O-X:6UO($WJ<R(*"B,Z(&QI8B]&0E9I97<O=V5E
M:RYP:'`Z,S(*;7-G:60@(DYE>'0@5V5E:R(*;7-G<W1R(")0<O-X:6UA(%-E
M;6%N82(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X
M="!D87DB"FUS9W-T<B`B4'+S>&EM;R!D:6$B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM
M<V=I9"`B3F5X="!W965K(@IM<V=S='(@(E!R\WAI;6$@<V5M86YA(@H*(SH@
M=&5M<&QA=&5S+V9B=FEE=R]L96=E;F0N:6YC.C<*;7-G:60@(DYO($EN9F]R
M;6%T:6]N(@IM<V=S='(@(E-E;2!);F9O<FUAY^-O(@H*(SH@=&5M<&QA=&5S
M+W9I97<O=FEE=RYI;F,Z.#$@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3(U
M"FUS9VED(").;R!A;&%R;2(*;7-G<W1R(")396T@879I<V\B"@HC.B!T96UP
M;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-3,*;7-G:60@(DYO(&%T
M=&5N9&5E<R(*;7-G<W1R(")396T@<&%R=&EC:7!A;G1E<R(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P.3D*;7-G:60@(DYO(&-A;&5N9&%R<R!A<F4@879A
M:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B3N-O(&CA(&-A;&5N9.%R:6]S
M(&1I<W!O;NUV96ES('!A<F$@8V]N=FED861O<RXB"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ-#@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C4T
M"FUS9VED(").;R!E;F0@9&%T92(*;7-G<W1R(")396T@9&%T82!F:6YA;"(*
M"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ.#`@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,3<V"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR
M,#8*;7-G:60@(DYO(&5V96YT<R!T;R!D:7-P;&%Y(@IM<V=S='(@(E-E;2!E
M=F5N=&]S('!A<F$@;6]S=')A<B(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H
M<#HT,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@:7,@879A:6QA8FQE(&9O<B`E<R(*;7-G<W1R("));F9O<FUAY^-O
M(&QI=G)E+V]C=7!A9&\@<&%R82`E<R!E<W3A(&EN9&ES<&]N[79E;"(*"B,Z
M(&QI8B]A<&DN<&AP.C$V-R!L:6(O87!I+G!H<#HS-#<*;7-G:60@(DYO(&E#
M86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B3N-O('-E(&5N8V]N
M=')O=2!D861O<R!I0V%L96YD87(N(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C`S"FUS9VED(").;R!R96-U<G)E;F-E(@IM<V=S='(@(E-E;2!R
M97!E=&GGXV\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HX-C0*;7-G:60@(DYO
M('9A;&ED(&5M86EL(&%D9')E<W,@9F]U;F0B"FUS9W-T<B`B3N-O('-E(&5N
M8V]N=')O=2!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(';A;&ED
M;R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4U-2!L:6(O2W)O;F]L:71H+G!H
M<#HU-S8*;7-G:60@(DYO;F4B"FUS9W-T<B`B3F5N:'5M(@H*(SH@;&EB+U-T
M;W)A9V4O<W%L+G!H<#HQ,S8*;7-G:60@(DYO="!F;W5N9"(*;7-G<W1R(").
MXV\@96YC;VYT<F%D;R(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,3(*;7-G:60@(B(*(DYO=&EC93H@26UP;W)T:6YG(&ES(&YO="!P;W-S:6)L
M92!W:71H('1H:7,@8V]N9FEG=7)A=&EO;B!D=64@=&\@82!B=6<@:6X@(@HB
M=&AE('5N9&5R;'EI;F<@8V%L96YD87(@9')I=F5R+B(*;7-G<W1R("(B"B).
M;W1A.B!);7!O<G1A<B!NXV\@Z2!P;W-S[79E;"!C;VT@97-T82!C;VYF:6=U
M<F'GXV\@9&5V:61O(&$@=6T@97)R;R!N;R`B"B)M96-A;FES;6\@9&4@8V%L
M96YDX7)I;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW
M.`IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB<F\B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-38*;7-G:60@(DYO=R(*;7-G<W1R
M(")!9V]R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<W
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]U='5B<F\B"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HU-S,*;7-G:60@(D]P=&EO;F%L(@IM<V=S='(@(D]P8VEO
M;F%L(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,3$W"FUS9VED(")/<'1I;VYA;"!T
M;R!A='1E;F0B"FUS9W-T<B`B4&%R=&EC:7!AY^-O(&]P8VEO;F%L(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#(*;7-G:60@(D]W;F5R(@IM<V=S
M='(@(D1O;F\B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P,B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X,@IM<V=I9"`B4$TB"FUS9W-T
M<B`B4$TB"@HC.B!D871A+G!H<#HR.2!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$W"FUS9VED(")086QM($1A=&5";V]K(@IM<V=S='(@(D1A=&5";V]K
M(&1O(%!A;&TB"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,PIM
M<V=I9"`B4&%S="!%=F5N=',@3&ES="(*;7-G<W1R("),:7-T82!D92!%=F5N
M=&]S(%!A<W-A9&]S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$Y
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$Y-PIM<V=I9"`B4&%T=&5R;B(*
M;7-G<W1R(")0861RXV\B"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z
M,C<*;7-G:60@(E!E<FUA;F5N=&QY(&1E;&5T92!T:&ES(&5V96YT/R(*;7-G
M<W1R(")296UO=F5R(&5V96YT;R!P97)M86YE;G1E;65N=&4_(@H*(SH@;&EB
M+V%P:2YP:'`Z,30X(&QI8B]A<&DN<&AP.C(S,"!L:6(O87!I+G!H<#HR.3@@
M;&EB+V%P:2YP:'`Z,S(Y"B,Z(&QI8B]A<&DN<&AP.C0R-R!L:6(O87!I+G!H
M<#HT-C,*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<FUI
M<W/C;R!.96=A9&$B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,3`W"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S
M]65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q"FUS9VED(")0;W)T
M86P@3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&\@4&]R=&%L(@H*(SH@=&5M
M<&QA=&5S+V9B=FEE=R]L96=E;F0N:6YC.C4*;7-G:60@(E!O<W-I8FQE($UE
M971I;F<@5&EM92(*;7-G<W1R(")0;W-S[79E;"!(;W)A(&1O($5N8V]N=')O
M(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,30Y"FUS9VED(")0;W-S:6)L92!-965T
M:6YG(%1I;65S(@IM<V=S='(@(E!O<W/M=F5I<R!(;W)A<R!D92!%;F-O;G1R
M;R(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HW-`IM<V=I9"`B4')E=FEO=7,@
M1&%Y(@IM<V=S='(@(D1I82!!;G1E<FEO<B(*"B,Z(&QI8B]&0E9I97<O=V5E
M:RYP:'`Z,C8*;7-G:60@(E!R979I;W5S(%=E96LB"FUS9W-T<B`B4V5M86YA
M($%N=&5R:6]R(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHS"FUS9VED
M(")0<F5V:6]U<R!D87DB"FUS9W-T<B`B1&EA(&%N=&5R:6]R(@H*(SH@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,30W('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C(U,0IM<V=I9"`B4F5C=7(@56YT:6PB"FUS9W-T<B`B4F5P971I<B!!
M=.DB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,38*;7-G:60@(E)E
M8W5R<F5N8V4B"FUS9W-T<B`B4F5P971IY^-O(@H*(SH@9&%T82YP:'`Z-3D*
M;7-G:60@(E)E8W5R<F5N8V4@1&%T82(*;7-G<W1R(")$861O<R!D92!297!E
M=&GGXV\B"@HC.B!D871A+G!H<#HU-PIM<V=I9"`B4F5C=7)R96YC92!%;F0@
M1&%T92(*;7-G<W1R(")$871A($9I;F%L(&1A(%)E<&5T:>?C;R(*"B,Z(&1A
M=&$N<&AP.C4X"FUS9VED(")296-U<G)E;F-E($EN=&5R=F%L(@IM<V=S='(@
M(DEN=&5R=F%L;R!D92!297!E=&GGXV\B"@HC.B!D871A+G!H<#HU-@IM<V=I
M9"`B4F5C=7)R96YC92!4>7!E(@IM<V=S='(@(E1I<&\@9&4@4F5P971IY^-O
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-#DT"FUS9VED(")296-U<G,@9&%I
M;'DB"FUS9W-T<B`B4F5P971E(&1I87)I86UE;G1E(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-3`Q"FUS9VED(")296-U<G,@;6]N=&AL>2(*;7-G<W1R(")2
M97!E=&4@;65N<V%L;65N=&4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HT.3<*
M;7-G:60@(E)E8W5R<R!W965K;'DB"FUS9W-T<B`B4F5P971E('-E;6%N86QM
M96YT92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4P-`IM<V=I9"`B4F5C=7)S
M('EE87)L>2(*;7-G<W1R(")297!E=&4@86YU86QM96YT92(*"B,Z(&QI8B]3
M8VAE9'5L97(O:W)O;F]L:71H+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5M:6YD97(Z("5S(@IM<V=S='(@(DQE;6)R971E.B`E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-`IM<V=I9"`B4F5M;W1E($-A;&5N9&%R
M<R(*;7-G<W1R(")#86QE;F3A<FEO<R!296UO=&]S(@H*(SH@=&5M<&QA=&5S
M+VUE;G4N:6YC.C0R"FUS9VED(")296UO=&4@0V%L96YD87)S.B(*;7-G<W1R
M(")#86QE;F3A<FEO<R!296UO=&]S.B(*"B,Z('1E;7!L871E<R]A='1E;F1E
M97,O871T96YD965S+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")296UO
M=F4@)7,B"FUS9W-T<B`B4F5M;W9E<B`E<R(*"B,Z(&%T=&5N9&5E<RYP:'`Z
M,S<*;7-G:60@(E)E;6]V92!!='1E;F1E92(*;7-G<W1R(")296UO=F5R(%!A
M<G1I8VEP86YT92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4X,`IM<V=I9"`B
M4F5Q=6ER960B"FUS9W-T<B`B26YD:7-P96YSX79E;"(*"B,Z(&QI8B]&0E9I
M97<N<&AP.C$S-2!L:6(O1D)6:65W+G!H<#HQ,S@@;&EB+T9"5FEE=RYP:'`Z
M,30Q"FUS9VED(")297%U:7)E9"!!='1E;F1E97,B"FUS9W-T<B`B4&%R=&EC
M:7!A;G1E<R!);F1I<W!E;G/A=F5I<R(*"B,Z(&QI8B]&0E9I97<N<&AP.CDX
M"FUS9VED(")297%U:7)E9"!T;R!A='1E;F0B"FUS9W-T<B`B26YD:7-P96YS
MX79E;"!P87)T:6-I<&%R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C$R-0IM<V=I9"`B4F5S970B"FUS9W-T<B`B3&EM<&%R(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S,@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,S`Y"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R
M(")297!O<B!686QO<F5S('!O<B!/;6ES<^-O(@H*(SH@=&5M<&QA=&5S+V%T
M=&5N9&5E<R]A='1E;F1E97,N:6YC.C0W('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$X,@IM<V=I9"`B4F5S<&]N<V4B"FUS9W-T<B`B4F5S<&]S=&$B"@HC
M.B!V:65W979E;G0N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")37V%V
M92!<(B5S7"(@07,@3F5W(@IM<V=S='(@(D=R879A<B!<(B5S7"(@0V]M;R!.
M;W9O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C0@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C(R"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,3`Y"FUS9VED(")382(*;7-G<W1R(")SX6(B"@HC.B!T96UP;&%T97,O
M;6]N=&@O:&5A9"YI;F,Z,C$@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,Q
M"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C<S"FUS9VED(")3
M871U<F1A>2(*;7-G<W1R(")SX6)A9&\B"@HC.B!V:65W979E;G0N<&AP.C$Q
M-R!E9&ET979E;G0N<&AP.C0T(&5D:71E=F5N="YP:'`Z-#@*;7-G:60@(E-A
M=F4@07,@3F5W(@IM<V=S='(@(D=R879A<B!#;VUO($YO=F\B"@HC.B!A9&1E
M=F5N="YP:'`Z-#$@961I=&5V96YT+G!H<#HT-@IM<V=I9"`B4V%V92!%=F5N
M="(*;7-G<W1R(")'=6%R9&%R($5V96YT;R(*"B,Z('-E87)C:"YP:'`Z.3,@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q-0HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-C<@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ-#`*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z,C4*;7-G:60@(E-E87)C:"(*;7-G<W1R(")0<F]C=7)A<B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHV"FUS9VED(")396%R8V@@4F5S
M=6QT<R(*;7-G<W1R(")297-U;'1A9&]S(&1A(%!R;V-U<F$B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.#8*;7-G:60@(E-E;&5C
M="!A(&-A;&5N9&%R(@IM<V=S='(@(E-E;&5C8VEO;F4@=6T@8V%L96YDX7)I
M;R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V-R!T96UP;&%T97,O
M961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0HC.B!T96UP;&%T97,O961I="]E
M9&ET7W1I;65S<&%N+FEN8SHX-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G
M<W1R(")396QE8V-I;VYE('5M82!D871A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q"FUS9VED("(B"B)396QE8W0@8V]N9FER;6%T:6]N(&]P=&EO
M;G,L(&AO=R!T;R!D:7-P;&%Y('1H92!D:69F97)E;G0@=FEE=W,@86YD(&-H
M;V]S92`B"B)D969A=6QT('9I97<N(@IM<V=S='(@(B(*(E-E;&5C8VEO;F4@
M;W#G]65S(&1E(&-O;F9I<FUAY^-O+"!C;VUO(&UO<W1R87(@87,@9&EF97)E
M;G1A<R!V:7-T87,@92!Q=6%L(&$@(@HB=FES=&$@<&]R(&]M:7-SXV\N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,@IM<V=I9"`B4V5L96-T
M('1H92!C86QE;F1A<B!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(E-E;&5C:6]N
M92!O(&-A;&5N9.%R:6\@<&%R82!O('%U86P@:6UP;W)T87(Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I9"`B4V5L96-T('1H92!E
M>'!O<G0@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D
M92!E>'!O<G1AY^-O.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,S$*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@
M(E-E;&5C:6]N92!O(&%R<75I=F\@82!I;7!O<G1A<CHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`V"FUS9VED(")396QE8W0@=&AE(&9I<G-T('=E
M96MD87DZ(@IM<V=S='(@(E-E;&5C:6]N92!O('!R:6UE:7)O(&1I82!D82!S
M96UA;F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-`IM<V=I
M9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G
M<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D;R!F:6-H96ER;R!F;VYT93HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<S"FUS9VED(")396QE8W0@
M=&AE('1I;64@<W!A;B!T;R!S:&]W.B(*;7-G<W1R(")396QE8VEO;F4@82!G
M86UA('1E;7!O<F%L(&$@;6]S=')A<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-SD*;7-G:60@(E-E;&5C="!T:&4@=FEE=R!T;R!D:7-P;&%Y(&]N
M('-T87)T=7`Z(@IM<V=S='(@(E-E;&5C:6]N92!A('9I<W1A(&$@;6]S=&%R
M(&%P\W,@82!E;G1R861A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,@IM<V=I9"`B4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H92!P
M;W)T86PN(@IM<V=S='(@(E-E;&5C:6]N92!Q=64@979E;G1O<R!M;W-T<F%R
M(&YO('!O<G1A;"XB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,C0@
M=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(T"FUS9VED(")396YD(&$@
M8V%N8V5L(&YO=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H96X@9&5L
M971I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"B)%;G9I87(@=6UA(&YO=&EF
M:6-AY^-O(&1E(&-A;F-E;&%M96YT;R!A('1O9&]S(&]S('!A<G1I8VEP86YT
M97,@<75A;F1O('-E("(*(G)E;6]V97(@97-T92!E=F5N=&\B"@HC.B!T96UP
M;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-C`@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3@V"B,L('!H<"UF;W)M870*;7-G:60@(E-E;F0@86X@
M96UA:6P@=&\@)7,B"FUS9W-T<B`B16YV:6%R('5M82!M96YS86=E;2!P87)A
M("5S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3@P"FUS9VED(")3
M96YD('5P9&%T97,O:6YV:71A=&EO;G,@=&\@86QL(&%T=&5N9&5E<R!W:&5N
M('-A=FEN9R!T:&ES(&5V96YT(@IM<V=S='(@(B(*(D5N=FEA<B!A8W1U86QI
M>F'G]65S+V-O;G9I=&5S(&$@=&]D;W,@;W,@<&%R=&EC:7!A;G1E<R!Q=6%N
M9&\@97-T92!E=F5N=&\@(@HB9F]R(&=U87)D861O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S8*;7-G:60@(E-E<'1E;6)E<B(*;7-G
M<W1R(")3971E;6)R;R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C@U"FUS9VED(")3970@96YD(&1A=&4B"FUS9W-T<B`B071R:6)U
M:7(@9&%T82!F:6YA;"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V
M-PIM<V=I9"`B4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`B17-P
M96-I9FEC87(@9&%T82!F:6YA;"!D82!R97!E=&GGXV\B"@HC.B!T96UP;&%T
M97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHS,0IM<V=I9"`B4V5T('-T87)T
M(&1A=&4B"FUS9W-T<B`B17-P96-I9FEC87(@9&%T82!I;FEC:6%L(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R"FUS9VED(")3970@>6]U<B!O=VX@
M86YD(&]T:&5R('5S97(G<R!F<F5E+V)U<WD@;W!T:6]N<RXB"FUS9W-T<B`B
M1&5F:6YA(&%S(&]PY_5E<R!D92!L:79R92]O8W5P861O('!A<F$@<VD@92!P
M87)A(&]S(&]U=')O<RXB"@HC.B!C86QE;F1A<G,N<&AP.C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E-H87)E(&YO="!F;W5N9#H@)7,B"FUS9W-T<B`B4&%R
M=&EL:&$@;N-O(&5N8V]N=')A9&$Z("5S(@H*(SH@=&5M<&QA=&5S+VUE;G4N
M:6YC.C,V"FUS9VED(")3:&%R960@0V%L96YD87)S.B(*;7-G<W1R(")#86QE
M;F3A<FEO(%!A<G1I;&AA9&]S.B(*"B,Z('1E;7!L871E<R]W965K+VAE861?
M<VED95]B>5]S:61E+FEN8SHS"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C,*;7-G:60@(E-H;W<@0V%L96YD87(B"FUS9W-T<B`B
M36]S=')A<B!#86QE;F3A<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T-0IM<V=I9"`B4VAO=R!C871E9V]R>2!L96=E;F0_(@IM<V=S='(@(DUO
M<W1R87(@;&5G96YD82!D92!C871E9V]R:6%S/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-H;W<@9&5L971E+"!A;&%R;2P@86YD
M(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L96YD87(@=FEE=W,_(@IM<V=S='(@
M(DUO<W1R87(@[6-O;F5S(&1E(')E;6_GXV\L(&%V:7-O(&4@<F5P971IY^-O
M(&YA<R!V:7-T87,@9&\@8V%L96YDX7)I;S\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C`Q"FUS9VED(")3:&]W(&1U92!T87-K<R!I;B!T:&4@8V%L
M96YD87(_(@IM<V=S='(@(DUO<W1R87(@=&%R969A<R!C;VT@<')A>F\@97AC
M961I9&\@;F\@8V%L96YDX7)I;S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34U"FUS9VED(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S='(@
M(DUO<W1R87(@;&5G96YD82!L:79R92]O8W5P861O/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B4VAO=R!H86QF(&AO=7(@<VQO=',@
M:6X@9&%Y(&%N9"!W965K('9I97=S/R(*;7-G<W1R(")-;W-T<F%R(&EN=&5R
M=F%L;W,@9&4@;65I82!H;W)A(&YA<R!V:7-T87,@9&4@9&EA(&4@<V5M86YA
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E-H;W<@
M;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS9W-T<B`B
M36]S=')A<B!S;VUE;G1E(&5V96YT;W,@8V]M(&%V:7-O(&-O;F9I9W5R861O
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C0*;7-G:60@(E-H;W<@
M<VAA<F5D(&-A;&5N9&%R<R!S:61E+6)Y+7-I9&4_(@IM<V=S='(@(DUO<W1R
M87(@8V%L96YDX7)I;W,@<&%R=&EL:&%D;W,@;&%D;R!A(&QA9&\_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,`IM<V=I9"`B4VAO=R!T87-K<R!U
M<VEN9R!C871E9V]R>2!C;VQO<G,_(@IM<V=S='(@(DUO<W1R87(@=&%R969A
M<R!U<V%N9&\@8V]R97,@9&4@8V%T96=O<FEA<S\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3<*;7-G:60@(E-H;W<@=&EM92!O9B!D87D@8F5T=V5E
M;B!E86-H(&1A>2!I;B!W965K('9I97=S/R(*;7-G<W1R(")-;W-T<F%R(&AO
M<F$@9&\@9&EA(&5N=')E(&-A9&$@9&EA(&YA<R!V:7-T87,@9&4@<V5M86YA
M/R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q"FUS
M9VED(")3=&%?<G0@3VXB"FUS9W-T<B`B26YI7V-I82US92!%;2(*"B,Z(&1A
M=&$N<&AP.C0U"FUS9VED(")3=&%R="!$871E(@IM<V=S='(@(D1A=&$@26YI
M8VEA;"(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z
M-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C(U"FUS9VED(")3=&%R="!/;B(*;7-G<W1R("));FEC
M:6$M<V4@16TB"@HC.B!D871A+G!H<#HT-@IM<V=I9"`B4W1A<G0@5&EM92(*
M;7-G<W1R(")(;W)A($EN:6-I86PB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:%]A9'9A;F-E9"YI;F,Z.34@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M.#0*;7-G:60@(E-T871?=7,B"FUS9W-T<B`B17-T85]D;R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHS-0IM<V=I9"`B4W1A='5S(@IM<V=S='(@(D5S=&%D;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8U('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(R,PHC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$Q
M,2!L:6(O0FQO8VLO;6]N=&@N<&AP.C$Q,PIM<V=I9"`B4W4B"FUS9W-T<B`B
M9&]M(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$T('1E;7!L871E
M<R]M;VYT:"]H96%D+FEN8SHR,PHC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,S(@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-C<*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B4W5N9&%Y(@IM<V=S='(@
M(F1O;6EN9V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CD*;7-G:60@
M(E1A<VMS(@IM<V=S='(@(E1A<F5F87,B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HU,C@@;&EB+TMR;VYO;&ET:"YP:'`Z-34Q"FUS9VED(")496YT871I=F4B
M"FUS9W-T<B`B5&5N=&%T:79A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-C(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(P"B,Z(&QI
M8B]";&]C:R]M;VYT:"YP:'`Z,3`Y"FUS9VED(")4:"(*;7-G<W1R("(U+JHB
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C<P"FUS9VED
M(")4:&4@161I="!!='1E;F1E97,@<V-R965N(&ES(&YO(&QO;F=E<B!P<F5S
M96YT+B!%>&ET:6YG+B(*;7-G<W1R(")/(&5C<N,@161IY^-O(&1E(%!A<G1I
M8VEP86YT97,@:N$@;N-O(&5S=.$@<')E<V5N=&4N(%-A:6YD;RXB"@HC.B!C
M86QE;F1A<G,N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE
M;F1A<B!<(B5S7"(@8V%N;F]T(&)E(&1E;&5T960N(@IM<V=S='(@(D\@8V%L
M96YDX7)I;R!<(B5S7"(@;N-O('#T9&4@<V5R(')E;6]V:61O+B(*"B,@8RUF
M;W)M870*(SH@8V%L96YD87)S+G!H<#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S
M='(@(D\@8V%L96YDX7)I;R!<(B5S7"(@9F]I(&-R:6%D;RXB"@HC.B!C86QE
M;F1A<G,N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A
M<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B3R!C86QE;F3A
M<FEO(%PB)7-<(B!F;VD@<F5M;W9I9&\N(@H*(SH@8V%L96YD87)S+G!H<#HU
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA
M<R!B965N(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")/(&-A;&5N9.%R
M:6\@7"(E<UPB(&9O:2!R96YO;65A9&\@8V]M;R!<(B5S7"(N(@H*(SH@8V%L
M96YD87)S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD
M87(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")/(&-A;&5N9.%R
M:6\@7"(E<UPB(&9O:2!G=6%R9&%D;RXB"@HC.B!T96UP;&%T97,O961I="]J
M879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@(E1H92!E;F0@9&%T92!M=7-T(&)E
M(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N(@IM<V=S='(@(D$@9&%T82!F
M:6YA;"!D979E('-E<B!M86EO<B!Q=64@82!D871A(&EN:6-I86PN(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3`S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@979E;G0@;F]T:69I8V%T:6]N('1O("5S('=A<R!S=6-C97-S9G5L;'D@
M<V5N="XB"FUS9W-T<B`B02!N;W1I9FEC8>?C;R!D92!E=F5N=&\@<&%R82`E
M<R!F;VD@96YV:6%D82!C;VT@<W5C97-S;RXB"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,#`P"FUS9VED(")4:&4@9F]L;&]W:6YG(&ES(&$@;6]R92!D971A
M:6QE9"!D97-C<FEP=&EO;B!O9B!T:&4@979E;G0Z(@IM<V=S='(@(E-E9W5E
M+7-E('5M82!D97-C<FGGXV\@;6%I<R!P;W)M96YO<FEZ861A(&1O(&5V96YT
M;SHB"@HC.B!T96UP;&%T97,O<V5A<F-H+V5M<'1Y+FEN8SHS"FUS9VED(")4
M:&5R92!A<F4@;F\@979E;G1S(&UA=&-H:6YG('1H92!C=7)R96YT(&-R:71E
M<FEA+B(*;7-G<W1R(").96YH=6T@979E;G1O(&1E(&%C;W)D;R!C;VT@;R!C
M<FETZ7)I;R!C;W)R96YT92XB"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z,3@@
M961I=&5V96YT86-T:6]N+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@86-C97-S:6YG('1H92!C86QE;F1A<CH@)7,B
M"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O(&%C961E<B!A;R!C86QE;F3A
M<FEO.B`E<R(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HS,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N
M=#H@)7,B"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O(&%D:6-I;VYA<B!O
M(&5V96YT;SH@)7,B"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!E9&ET:6YG('1H
M92!E=F5N=#H@)7,B"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O(&5D:71A
M<B!O(&5V96YT;SH@)7,B"@HC.B!L:6(O87!I+G!H<#HQ-C$@;&EB+V%P:2YP
M:'`Z,S0Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O
M(&EM<&]R=&%R(&1A9&]S(&E#86QE;F1A<BXB"@HC.B!E9&ET979E;G1A8W1I
M;VXN<&AP.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!M;W9I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")/8V]R<F5U('5M
M(&5R<F\@86\@;6]V97(@;R!E=F5N=&\Z("5S(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S
M(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!A;R!E;G9I87(@=6UA(&YO=&EF
M:6-AY^-O(&1O(&5V96YT;R!P87)A("5S.B`E<R(*"B,Z(&1A=&$N<&AP.CDU
M"FUS9VED(")4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N(@IM<V=S
M='(@(D[C;R!HX2!E=F5N=&]S('!A<F$@97AP;W)T87(N(@H*(SH@9&%T82YP
M:'`Z,3<S"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T
M960N(@IM<V=S='(@(D5S=&4@9F]R;6%T;R!D92!F:6-H96ER;R!NXV\@Z2!S
M=7!O<G1A9&\N(@H*(SH@9&%T82YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@
M(D5I<R!O('%U92!O('-E<G9I9&]R(&1I<W-E.B`E<R(*"B,Z('1E;7!L871E
M<R]M;VYT:"]H96%D+FEN8SHQ.2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ
M,CD*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S$*;7-G:60@
M(E1H=7)S9&%Y(@IM<V=S='(@(G%U:6YT82UF96ER82(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHS-PIM<V=I9"`B5&EM92!3<%]A;B(*;7-G
M<W1R(")'7V%M82!496UP;W)A;"(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C0*;7-G:60@(E1I;64@<W!A;B(*;7-G<W1R(")'86UA
M('1E;7!O<F%L(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC
M960N:6YC.C,V('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C,Y"FUS9VED(")4
M:71?;&4B"FUS9W-T<B`B5.UT=5]L;R(*"B,Z(&1A=&$N<&AP.C0T('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A<F-H
M+V5V96YT7VAE861E<G,N:6YC.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@(E3M
M='5L;R(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,S$@;&EB
M+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(W"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ,S$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DAO:F4B"@HC.B!L:6(O
M0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,3,S(&QI8B]";&]C:R]M;VYT:&QI
M<W0N<&AP.C$R.0HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3,S"FUS9VED
M(")4;VUO<G)O=R(*;7-G<W1R(")!;6%N:.,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHV,"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,3@*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#D*;7-G:60@(E1U(@IM<V=S
M='(@(C,NJB(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-R!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ,C<*(SH@=&5M<&QA=&5S+V5D:70O:F%V
M87-C<FEP="YI;F,Z-CD*;7-G:60@(E1U97-D87DB"FUS9W-T<B`B=&5RYV$M
M9F5I<F$B"@HC.B!C;VYF:6<O:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@
M(E1Y<&4B"FUS9W-T<B`B5&EP;R(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z
M-C0*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;&EG87(@86\@<V5R=FED;W(@4U%,
M+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(D[C;R!C;VYS
M:6=O(')E;6]V97(@7"(E<UPB.B`E<RXB"@HC.B!L:6(O1')I=F5R+VUC86PN
M<&AP.C$S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M("5S+B(*;7-G<W1R(").XV\@8V]N<VEG;R!R96UO=F5R("5S+B(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C$X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B26UP;W-S
M[79E;"!L97(@82!D969I;FGGXV\@9&4@)7,N(@H*(SH@8V%L96YD87)S+G!H
M<#HU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B3N-O(&-O;G-I9V\@<F5N;VUE87(@7"(E<UPB
M.B`E<RXB"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E=')I979E(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B!F;W(@)7,B"FUS9W-T<B`B3N-O(&-O;G-I9V\@;V)T97(@:6YF
M;W)M8>?C;R!L:79R92]O8W5P861O(&1E("5S(@H*(SH@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,C,*(SH@<V-R:7!T<R]U<&=R861E<R\R,#`T+3`U+3$Y
M7V-O;G9E<G1?8V%T96=O<FEE<U]T;U]S=')I;F=S+G!H<#HU,PIM<V=I9"`B
M56YF:6QE9"(*;7-G<W1R(")396T@8V%T96=O<FEA(@H*(SH@;&EB+T9"5FEE
M=R]D87DN<&AP.C0X(&QI8B]&0E9I97<O9&%Y+G!H<#HU.`IM<V=I9"`B56YK
M;F]W;B(*;7-G<W1R(")$97-C;VYH96-I9&\B"@HC.B!L:6(O87!I+G!H<#HQ
M.#<@;&EB+V%P:2YP:'`Z,C8Q(&QI8B]A<&DN<&AP.C,W.`IM<V=I9"`B56YS
M=7!P;W)T960@0V]N=&5N="U4>7!E+B(*;7-G<W1R(")4:7!O(&1E(&-O;G1E
M^F1O("A#;VYT96YT+51Y<&4I(&[C;R!S=7!O<G1A9&\N(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z.3DR"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960Z
M("5S+B(*;7-G<W1R(")!8W1U86QI>F%D;SH@)7,N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P"FUS9VED(")5<V5R($EN=&5R9F%C92(*;7-G<W1R
M("));G1E<F9A8V4@9&\@=71I;&EZ861O<B(*"B,Z(&QI8B]";&]C:R]M;VYT
M:"YP:'`Z,38S(&QI8B]";&]C:R]M;VYT:"YP:'`Z,38V"FUS9VED(")6:65W
M($1A>2(*;7-G<W1R(")-;W-T<F%R($1I82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q
M.0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P.0IM<V=I9"`B5V4B"FUS9W-T
M<B`B-"ZJ(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$X('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$R.`HC.B!T96UP;&%T97,O961I="]J879A
M<V-R:7!T+FEN8SHW,`IM<V=I9"`B5V5D;F5S9&%Y(@IM<V=S='(@(G%U87)T
M82UF96ER82(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3`X(&QI8B]+<F]N;VQI=&@N
M<&AP.C$P-SD@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C,*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")7965K(@IM<V=S='(@(E-E;6%N
M82(*"B,Z(&UO;G1H+G!H<#HQ-S`@=V]R:W=E96LN<&AP.C,P('=E96LN<&AP
M.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E=E96L@)60B"FUS9W-T<B`B4V5M
M86YA("5D(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-C<@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,3,Y"FUS9VED(")7965K*',I(@IM<V=S='(@
M(E-E;6%N82AS*2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$S-"!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,30*;7-G:60@(E=E96ML>3H@4F5C
M=7)S(&5V97)Y(@IM<V=S='(@(E-E;6%N86QM96YT93H@<F5P971E(&-A9&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED("(B"B)7:&%T
M('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!E;F0L('=H96X@=&AE
M<F4@87)E(&YO(&QA=&5R(&5V96YT<S\B"FUS9W-T<B`B(@HB02!Q=64@:&]R
M87,@9&5V96T@=&5R;6EN87(@87,@=FES=&%S(&1E(&1I82!E('-E;6%N82P@
M<75A;F1O(&[C;R!H;W5V97(@(@HB979E;G1O<R!P;W-T97)I;W)E<S\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED("(B"B)7:&%T('1I
M;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@=VAE;B!T:&5R
M92!A<F4@;F\@96%R;&EE<B!E=F5N=',_(@IM<V=S='(@(B(*(D$@<75E(&AO
M<F%S(&1E=F5M(&-O;67G87(@87,@=FES=&%S(&1E(&1I82!E('-E;6%N82P@
M<75A;F1O(&[C;R!H;W5V97(@(@HB979E;G1O<R!A;G1E<FEO<F5S/R(*"B,Z
M(&%T=&5N9&5E<RYP:'`Z,3`W(&QI8B]+<F]N;VQI=&@N<&AP.C$P-S@@;&EB
M+T)L;V-K+W1R965?;65N=2YP:'`Z,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<W"FUS9VED(")7;W)K(%=E96LB"FUS9W-T<B`B0V]M97)C:6%L(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,30P('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(T,`IM<V=I9"`B665A<FQY.B!296-U<G,@979E<GDB"FUS
M9W-T<B`B06YU86PZ(')E<&5T92!P;W(B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C<V"FUS9VED(")9;W4@8V%N(&]N;'D@=7-E('1H
M:7,@9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN(@IM<V=S
M='(@(E/S('!O9&4@=7-A<B!E<W1E(&9O<FUU;.%R:6\@82!P87)T:7(@9&\@
M96-RXR!%9&GGXV\@9&4@4&%R=&EC:7!AY_5E<R(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.CDT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&\@;F]T
M(&AA=F4@86X@96UA:6P@861D<F5S<R!C;VYF:6=U<F5D(&EN('EO=7(@4&5R
M<V]N86P@26YF;W)M871I;VX@(@HB3W!T:6]N<RX@66]U(&UU<W0@<V5T(&]N
M92`E<VAE<F4E<R!B969O<F4@979E;G0@;F]T:69I8V%T:6]N<R!C86X@8F4@
M<V5N="XB"FUS9W-T<B`B(@HB3N-O('1E;2!U;2!E;F1E<F7G;R!D92!C;W)R
M96EO(&5L96-T<O-N:6-O(&-O;F9I9W5R861O(&YA<R!S=6%S($]PY_5E<R!D
M92`B"B));F9O<FUAY^-O(%!E<W-O86PN(%1E;2!D92!C;VYF:6=U<F%R('5M
M("5S87%U:25S('!A<F$@<75E(&QH92!P;W-S86T@<V5R("(*(F5N=FEA9&%S
M(&YO=&EF:6-AY_5E<RXB"@HC.B!A9&1E=F5N=&%C=&EO;BYP:'`Z,C`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@
M=&\@861D(&5V96YT<R!T;R`E<RXB"FUS9W-T<B`B3N-O('1E;2!P97)M:7-S
MXV\@<&%R82!A9&EC:6]N87(@979E;G1O<R!A("5S+B(*"B,Z(&1A=&$N<&AP
M.C$X,PIM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@861D
M(&5V96YT<R!T;R!T:&4@<V5L96-T960@8V%L96YD87(N(@IM<V=S='(@(D[C
M;R!T96T@<&5R;6ES<^-O('!A<F$@861I8VEO;F%R(&5V96YT;W,@86\@8V%L
M96YDX7)I;R!S96QE8V-I;VYA9&\N(@H*(SH@9&5L979E;G1A8W1I;VXN<&AP
M.C(V"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!D96QE
M=&4@=&AI<R!E=F5N="XB"FUS9W-T<B`B3N-O('1E;2!P97)M:7-SXV\@<&%R
M82!R96UO=F5R(&5S=&4@979E;G1O+B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP
M:'`Z-C@*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&5D
M:70@=&AI<R!E=F5N="XB"FUS9W-T<B`B3N-O('1E;2!P97)M:7-SXV\@<&%R
M82!E9&ET87(@97-T92!E=F5N=&\N(@H*(SH@9&%T82YP:'`Z,3<X"FUS9VED
M(")9;W4@:&%V92!S<&5C:69I960@86X@:6YV86QI9"!C86QE;F1A<BXB"FUS
M9W-T<B`B17-P96-I9FEC;W4@=6T@8V%L96YDX7)I;R!I;G;A;&ED;RXB"@HC
M.B!C86QE;F1A<G,N<&AP.CDQ"FUS9VED(")9;W4@;75S="!S96QE8W0@82!C
M86QE;F1A<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")496T@9&4@<V5L96-C
M:6]N87(@=6T@8V%L96YDX7)I;R!A(')E;6]V97(N(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHU-`IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(E1E;2!D92!S96QE8V-I
M;VYA<B!P<FEM96ER;R!U;2!E;F1E<F7G;RXB"@HC.B!L:6(O4V-H961U;&5R
M+VMR;VYO;&ET:"YP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R
M97%U97-T960@=&\@8F4@<F5M:6YD960@86)O=70@)7,L('=H:6-H(&ES(&]N
M("5S(&%T("5S+B(*;7-G<W1R(")0961I=2!P87)A('-E<B!R96-O<F1A9&\@
M86-E<F-A(&1E("5S+"!Q=64@=&5M(&QU9V%R(&$@)7,@96T@)7,N(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-H87)E<V5L96-T+FEN8SHQ,`IM<V=I9"`B66]U
M<B!D969A=6QT(&-A;&5N9&%R(@IM<V=S='(@(D\@<V5U(&-A;&5N9.%R:6\@
M<&]R(&]M:7-SXV\B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#$U(&QI8B]$<FEV
M97(N<&AP.C$P,C4*;7-G:60@(EM5;FYA;65D(&5V96YT72(*;7-G<W1R(");
M179E;G1O('-E;2!N;VUE72(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM
M97-P86XN:6YC.C,Y"FUS9VED(")?070B"FUS9W-T<B`BP%]S(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q"FUS9VED(")?
M0F%S:6,@4V5A<F-H(@IM<V=S='(@(E!R;V-U<F$@7T+A<VEC82(*"B,Z('9I
M97=E=F5N="YP:'`Z,3$Y"FUS9VED(")?161I="(*;7-G<W1R(")%9&E?=&%R
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q,@IM<V=I9"`B7T=O=&\B"FUS
M9W-T<B`B7TER('!A<F$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3(R"FUS
M9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R("));7!O<G1A<B]%7WAP;W)T
M87(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$W"FUS9VED(")?37D@0V%L
M96YD87)S(@IM<V=S='(@(D]S(%]-975S($-A;&5N9.%R:6]S(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3$P.`IM<V=I9"`B7TYE=R!%=F5N="(*;7-G<W1R
M(")?3F]V;R!%=F5N=&\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3(W"FUS
M9VED(")?4')I;G0B"FUS9W-T<B`B26U?<')I;6ER(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3$Q-`IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?4')O8W5R
M87(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-3,*;7-G:60@(E]3:&]W(@IM
M<V=S='(@(DUO<W1R85]R(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-0IM
M<V=I9"`B7U1O9&%Y(@IM<V=S='(@(E](;VIE(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,30Q"FUS9VED(")B969O<F4@=&AE(&5V96YT('-T87)T
M<R(*;7-G<W1R(")A;G1E<R!D92!O(&5V96YT;R!C;VUEYV%R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$W-`IM<V=I9"`B9&%Y(@IM<V=S='(@(F1I
M82(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,#D*;7-G:60@(F1A>2AS*2(*;7-G<W1R(")D:6$H
M<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<U(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-S8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(F1A>7,B"FUS9W-T<B`B9&EA<R(*"B,Z(&1A=&$N
M<&AP.C$S-R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(F5V
M96YT<RYC<W8B"FUS9W-T<B`B979E;G1O<RYC<W8B"@HC.B!D871A+G!H<#HQ
M-3@*;7-G:60@(F5V96YT<RYI8W,B"FUS9W-T<B`B979A;G1O<RYI8W,B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$S,0IM<V=I9"`B
M9G)O;2(*;7-G<W1R(")D92(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$S-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S@*(SH@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C(Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S
M-0IM<V=I9"`B;6]N=&@H<RDB"FUS9W-T<B`B;65S*&5S*2(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$S-B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR,CD*;7-G:60@(F]N('1H92!S86UE(&1A=&4B"FUS9W-T<B`B;F$@;65S
M;6$@9&%T82(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$S."!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(F]N('1H92!S86UE('=E
M96MD87DB"FUS9W-T<B`B;F\@;65S;6\@9&EA(&1A('-E;6%N82(*"B,Z(&1A
M=&$N<&AP.C,P('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3@*;7-G:60@
M(G9#86QE;F1A<B]I0V%L96YD87(B"FUS9W-T<B`B=D-A;&5N9&%R+VE#86QE
M;F1A<B(*"B,Z(&QI8B]A<&DN<&AP.C$W,B!L:6(O87!I+G!H<#HS-3(*;7-G
M:60@(G9%=F5N="!N;W0@9F]U;F0N(@IM<V=S='(@(G9%=F5N="!NXV\@96YC
M;VYT<F%D;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@P"FUS9VED
M(")W965K(@IM<V=S='(@(G-E;6%N82(*"B,Z('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C$S-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,38*;7-G:60@
M(G=E96LH<RD@;VXZ(@IM<V=S='(@(G-E;6%N82AS*2!E;3HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3@Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,PIM<V=I9"`B=V5E:W,B
M"FUS9W-T<B`B<V5M86YA<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$T,"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-#$*;7-G:60@(GEE87(H
M<RDB"FUS9W-T<B`B86YO*',I(@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]P;R]N
M8E].3RYP;P``````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q
M,C(Q,#,`,3`T,3<S-C(W-3,`,#(P-#`R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````",@3F]R=V5G:6%N($MR;VYO;&ET:"!4
M<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@2&]R9&4@4')O:F5C
M="X*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@
M;&EC96YS92!A<R!T:&4@2W)O;F]L:71H('!A8VMA9V4N"B,@5&]R<W1E:6X@
M4RX@2&%N<V5N(#QH=6QE8F]E<D!T96-H8F5E+FYO/BP@,C`P,BX*(R!!;F1R
M96%S($=U;FQE:6MS:V%A<R`\86YD<F5A<T!G=6YL96EK<VMA87,N;F\^+"`R
M,#`S+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!+<F]N;VQI=&@@,2XQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TP
M-2TQ."`R,SHS-RLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($%N9')E87,@
M1W5N;&5I:W-K86%S(#QA;F1R96%S0&=U;FQE:6MS:V%A<RYN;SY<;B(*(DQA
M;F=U86=E+51E86TZ($YO<G=E9VEA;B`H0F]K;6%L*2`\:3$X;D!L:7-T<RYH
M;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)60@8V%L96YD87)S(&9O=6YD(@IM<V=S='(@(DUI;F4@:V%L96YD
M97)E<B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!E=F5N=',B"FUS9W-T<B`B06QL
M92!H96YD96QS97(B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N
M+FEN8SHQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1&%Y*',I("5S($AO
M=7(H<RD@)7,@36EN=71E<R(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H
M<#HQ-S@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A='1E;F1E
M97,B"FUS9W-T<B`B26YG96X@9&5L=&%K97)E(@H*(SH@9&%T82YP:'`Z,C<U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM
M<&]R=&5D(@IM<V=S='(@(B5S(&9I;&5N(&)L92!I;7!O<G1E<G0B"@HC.B!C
M86QE;F1A<G,N<&AP.C$P-2!L:6(O8F%S92YP:'`Z,3(X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N
M9&5R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C$W"FUS
M9VED("(B"B(H0VQI8VL@;VX@8V%L96YD87(@;F%M92!T;R!S=VET8V@@=&AE
M(&-A;&5N9&%R)W,@=FES:6)I;&ET>2!I;B!T:&4@;6%I;B`B"B)W:6YD;W<I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,38T"FUS9VED("(J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!!9&0@*B(*
M;7-G<W1R("(J($QE9V<@=&EL(&1I<W-E('9E9"#E(&ML:6MK92`G3&5G9R!T
M:6PG("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$U
M,`IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-@HC+"!F=7IZ>0IM<V=I9"`B
M,2!A='1E;F1E92(*;7-G<W1R("));F=E;B!D96QT86ME<F4B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B,2!E
M=F5N="(*;7-G<W1R(")!;&QE(&AE;F1E;'-E<B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S<*(RP@9G5Z>GD*;7-G:60@(C$@:&]U<B(*;7-G<W1R
M("(E9"!T:6UE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`HC+"!F
M=7IZ>0IM<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R("(E9"!M:6YU='1E<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*(RP@9G5Z>GD*;7-G:60@
M(C(P(&UI;G5T97,B"FUS9W-T<B`B)60@;6EN=71T97(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,V"B,L(&9U>GIY"FUS9VED("(S,"!M:6YU=&5S
M(@IM<V=S='(@(B5D(&UI;G5T=&5R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,3<Q"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/D%T=&5N9&5E<SPO
M<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(D1E;'1A:V5R97(B"@HC.B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHQ-#D*(RP@9G5Z>GD*;7-G:60@(CQS
M=')O;F<^1&5S8W)I7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T
M<B`B0F5S:W)I=F5L<V4@*"!V86QG9G)I='0@*2(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:70N:6YC.C(W-PHC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY+97EW
M;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQB/E-T:6MK;W)D
M/"]B/B`H=F%L9V9R:71T*2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B/'-T<F]N9SY296-U<G)E;F-E/"]S=')O
M;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^1VIE;G1A:V5L<V4@/"]B/B`H
M=F%L9V9R:71T*2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`Q
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@Q"FUS9VED(")!32(*;7-G
M<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.3$*;7-G:60@(D%C8V5P
M=&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN
M8SHQ,0IM<V=I9"`B061?=F%N8V5D(%-E87)C:"(*;7-G<W1R(")!=F%N<V5R
M="!3^&LB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V
M,2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B
M061D(@IM<V=S='(@(DQE9V<@=&EL(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C8*;7-G:60@(D%D9"!%=F5N="(*;7-G<W1R("),96=G('1I;"!H
M96YD96QS92(*"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L7VUA;F%G
M96UE;G0N:6YC.C,U"B,L(&9U>GIY"FUS9VED(")!9&0@82!N97<@4F5M;W1E
M($-A;&5N9&%R(@IM<V=S='(@(DQE9V<@=&EL(&YY(&AE;F1E;'-E(@H*(SH@
M861D979E;G0N<&AP.C8T"FUS9VED(")!9&0@82!N97<@979E;G0B"FUS9W-T
M<B`B3&5G9R!T:6P@;GD@:&5N9&5L<V4B"@HC.B!T96UP;&%T97,O871T96YD
M965S+V%T=&5N9&5E<RYI;F,Z-S0*;7-G:60@(D%D9"!A='1E;F1E97,B"FUS
M9W-T<B`B3&5G9R!T:6P@9&5L=&%K97)E(@H*(SH@8V]N=&%C=',N<&AP.C<V
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3(P"B,Z('1E;7!L
M871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHW.`IM<V=I9"`B061D<F5S
M<R!";V]K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHX('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ
M,0IM<V=I9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(D%V86YS97)T(%/X
M:R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C4S"FUS9VED(")!;&%R
M;2(*;7-G<W1R(")!;&%R;2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06QA<FT@)60@9&%Y<R!B969O<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!;&%R;2`E9"!H;W5R<R!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<W-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M06QA<FT@)60@;6EN=71E<R!B969O<F4B"FUS9W-T<B`B36EN=71T97(@9OAR
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<U.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!;&%R;2`E9"!W965K<R!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3<V,PIM<V=I9"`B06QA<FT@,2!D87D@8F5F;W)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-C@*;7-G:60@(D%L87)M(#$@
M:&]U<B!B969O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<W
M,PHC+"!F=7IZ>0IM<V=I9"`B06QA<FT@,2!M:6YU=&4@8F5F;W)E(@IM<V=S
M='(@(DUI;G5T=&5R(&;X<B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3@*;7-G
M:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z-C`*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T<B`B06QA<FT@1&%T;R(*
M"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!3<&%N("AM:6YU=&5S*2(*
M;7-G<W1R(")!;&%R;2!);G1E<G9A;&P@*&UI;G5T=&5R*2(*"B,Z(&1A=&$N
M<&AP.C8Q"FUS9VED(")!;&%R;2!4:6UE(@IM<V=S='(@(D%L87)M(%1I9'-P
M=6YK="(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHS,0IM<V=I
M9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC.B!L:6(O1D)6:65W+G!H<#HQ,C8@
M;&EB+T9"5FEE=RYP:'`Z,3(Y(&QI8B]&0E9I97<N<&AP.C$S,@IM<V=I9"`B
M06QL($%T=&5N9&5E<R(*;7-G<W1R(")!;&QE(&1E;'1A:V5R92(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU.0IM<V=I9"`B06QL($9U='5R
M92(*;7-G<W1R(")!;&P@9G)A;71I9"(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHU,PIM<V=I9"`B06QL(%!A<W0B"FUS9W-T<B`B06QL(&9O
M<G1I9"(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR-R!L:6(O
M0FQO8VLO;6]N=&@N<&AP.C(T"B,Z(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C(W(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B06QL(%9I<VEB
M;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z,3(R(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z
M.3,*(SH@;&EB+U=E96M6:65W+G!H<#HQ,C<@;&EB+U=E96M6:65W+G!H<#HQ
M,S0@;&EB+T1R:79E<BYP:'`Z,3@S,@IM<V=I9"`B06QL(&1A>2(*;7-G<W1R
M(")(96QE(&1A9V5N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$V-`IM
M<V=I9"`B06QL(&1A>2!E=F5N="(*;7-G<W1R(")(96YD96QS96X@=F%R97(@
M:&5L92!D86=E;B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*
M;7-G:60@(D%L;"!E=F5N=',B"FUS9W-T<B`B06QL92!H96YD96QS97(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C<Q(&QI8B]+
M<F]N;VQI=&@N<&AP.C8X,PIM<V=I9"`B06YY(@IM<V=S='(@(D%L;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,0IM<V=I9"`B07!R
M:6PB"FUS9W-T<B`B87!R:6PB"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I
M;65S<&%N+FEN8SHS.2!T96UP;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN
M8SHY,PHC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C<P('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,34V"FUS9VED(")!="(*;7-G<W1R(")+;&]K
M:V$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#(V"FUS9VED("(B"B)!='1A
M8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!W:71H(&UO<F4@:6YF;W)M871I
M;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y;W5R("(*(FUA:6P@8VQI96YT('-U
M<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@=&AI<R!F:6QE('1O
M(&5A<VEL>2!U<&1A=&4@(@HB>6]U<B!L;V-A;"!C;W!Y(&]F('1H92!E=F5N
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC.C0R('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-0IM<V=I9"`B
M071T96YD86YC92(*;7-G<W1R(")$96QT86ME<F4B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ-C$*(RP@9G5Z>GD*;7-G:60@(D%T=&5N9&5E<R(*
M;7-G<W1R("),96=G('1I;"!D96QT86ME<F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW-0IM<V=I9"`B075G=7-T(@IM<V=S='(@(F%U
M9W5S="(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN
M8SHQ,2!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z.`IM<V=I9"`B0F%S
M:6,@4V5A<F-H(@IM<V=S='(@(E-T86YD87)D('/X:R(*"B,Z(&-O;F9I9R]K
M97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B
M0G5R<V1A9R(*"B,Z(&QI8B]&0E9I97<N<&AP.CDP(&QI8B]&0E9I97<N<&AP
M.C$Q,`IM<V=I9"`B0G5S>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z-#0*;7-G:60@(D-?86QE;F1A<B(*
M;7-G<W1R(")+86QE;F1E<B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C0Y"B,L(&9U>GIY"FUS9VED(")#86Q?96YD87(B"FUS9W-T<B`B2V%L96YD
M97(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,30V
M(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HR,0HC.B!L:6(O0FQO8VLO
M;6]N=&@N<&AP.C(Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C(Q(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HR,@HC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,PIM<V=I9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G<W1R(")+86QE;F1E<B!S
M86UM96YD<F%G(@H*(SH@9&%T82YP:'`Z,C(X"B,L(&9U>GIY"FUS9VED(")#
M86QE;F1A<B!S=6-C97-S9G5L;'D@<'5R9V5D+B(*;7-G<W1R(")I0V%L96YD
M87(@9FEL(&)L92!I;7!O<G1E<G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<*(RP@9G5Z
M>GD*;7-G:60@(D-A;&5N9&%R<R(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R<R!M=7-T
M(&AA=F4@82!N86UE+B(*;7-G<W1R(")+86QE;F1E<B!N879N(@H*(SH@9&%T
M82YP:'`Z,C0S"B,L(&9U>GIY"FUS9VED(")#86XG="!C<F5A=&4@82!N97<@
M979E;G0N(@IM<V=S='(@(DQA9R!E="!N>2!H96YD96QS92(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DQ('1E;7!L871E<R]D96QE
M=&4O;VYE+FEN8SHS,`HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z
M,S(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,S`Y"FUS9VED(")#86YC96PB"FUS9W-T<B`B079B<GET
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<P"FUS9VED(")#86YC96QL960B
M"FUS9W-T<B`B079B<G5T="(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N8V5L;&5D.B`E<R(*;7-G<W1R(")!
M=F)R=71T.B`E<R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N
M8V5D+FEN8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHV.0IM<V=I9"`B
M0V%T96=O<E]Y(@IM<V=S='(@(DMA=&5G;W)I(@H*(SH@9&%T82YP:'`Z-C,@
M=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHT('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$S"FUS9VED(")#871E9V]R>2(*;7-G<W1R(")+
M871E9V]R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-SD*;7-G:60@
M(B(*(D-H;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L
M(&5D:71E9"P@86YD(&1E;&5T960@979E;G1S(&)Y("(*(F5M86EL.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(*;7-G:60@(D-H
M;V]S92!I9B!Y;W4@=V%N="!T;R!B92!N;W1I9FEE9"!O9B!N97<L(&5D:71E
M9"P@86YD(&1E;&5T960@979E;G1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V5A<F-H7V%B;V]K7W-E;&5C="YI;F,Z,3D@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Y.0IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O
M;VMS('1O('-E87)C:"!F;W(@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]F8E]C86QS7W-E;&5C="YI;F,Z,38*;7-G
M:60@(D-H;V]S92!T:&4@8V%L96YD87)S('1O(&EN8VQU9&4@:6X@>6]U<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,3$*;7-G:60@(D-H;V]S92!T:&4@8V%L96YD87)S
M('1O(&EN8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R964O8G5S>2!54DQS.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@
M(D-H;V]S92!Y;W5R(&1E9F%U;'0@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHV-0HC+"!F=7IZ
M>0IM<V=I9"`B0VQE87(@86QL(&%T=&5N9&5E<R(*;7-G<W1R(")&:F5R;B!A
M;&QE(&1E;'1A:V5R92(*"B,Z(&1A=&$N<&AP.C(X('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B
M"FUS9W-T<B`B2V]M;6$@<V5P87)E<G1E('9E<F1I97(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S,*;7-G:60@(D-O;F9I<FT@9&5L971I;VX@;V8@
M979E;G1S/R(*;7-G<W1R(")"96MR969T('-L971T:6YG(&%V(&AE;F1E;'-E
M<C\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-C<*;7-G:60@(D-O;F9I<FUE
M9"(*;7-G<W1R(")"96MR969T970B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z,C`X"FUS9VED(")#;W!Y('1H92!54DP@8F5L;W<@
M9F]R('5S92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S>2!54DPZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$R-@IM<V=I
M9"`B0W)E871E(@IM<V=S='(@(D]P<')E='0B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z,3$R"B,L(&9U>GIY"FUS9VED(")#<F5A
M=&4@0V%L96YD87(B"FUS9W-T<B`B26UP;W)T97(@2V%L96YD97(B"@HC.B!M
M;VYT:"YP:'`Z,38U('1E;7!L871E<R]W965K+VAE860N:6YC.C(U('1E;7!L
M871E<R]D87DO<F]W+FEN8SHV"B,Z(&QI8B]$87E6:65W+G!H<#HY,"!L:6(O
M1&%Y5FEE=RYP:'`Z,3DT"FUS9VED(")#<F5A=&4@82!.97<@179E;G0B"FUS
M9W-T<B`B3&%G(&5T(&YY(&AE;F1E;'-E(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z.#`*;7-G:60@(D-R96%T960B"FUS9W-T<B`B3W!P<F5T=&5T
M(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(Y"FUS9VED(")#
M=7)R96YT(@IM<V=S='(@(D[E=N9R96YD92(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,#D*;7-G
M:60@(D1A:6QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B2'9E<B!D86<Z(%-K
M:F5R(&AV97(@9&%G(@H*(SH@871T96YD965S+G!H<#HQ,3`@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3(X."!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*;7-G:60@(D1A>2(*;7-G<W1R(")$
M86<B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV,B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHQ,SD*;7-G:60@(D1A>2AS*2(*;7-G<W1R(")$86<H
M97(I(@H*(SH@=FEE=V5V96YT+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D1E
M7VQE=&4B"FUS9W-T<B`B4VQE='0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]G;W1O+FEN8SHW.0IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B9&5S96UB
M97(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.30*;7-G:60@(D1E8VQI;F5D
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="!#86QE;F1A<B(*;7-G<W1R(")696QG(&5N
M(&MA;&5N9&5R(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C$Y,R!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X,0HC
M.B!T96UP;&%T97,O9&5L971E+V]N92YI;F,Z,CD@=&5M<&QA=&5S+W!R969S
M+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,C,*(SH@;&EB+T1R:79E<BYP
M:'`Z,3@Q,PIM<V=I9"`B1&5L971E(@IM<V=S='(@(E-L971T(@H*(SH@9&5L
M979E;G0N<&AP.C0P('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHQ."!T96UP
M;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,3@*(SH@;&EB+T1R:79E<BYP:'`Z
M,3@Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,B"FUS9W-T<B`B
M4VQE='0@)7,B"@HC.B!E9&ET979E;G0N<&AP.C<P"FUS9VED(")$96QE=&4@
M179E;G0B"FUS9W-T<B`B4VQE='1E(&AE;F1E;'-E(@H*(SH@=&5M<&QA=&5S
M+V1E;&5T92]D96QE=&4N:6YC.C(W"FUS9VED("(B"B)$96QE=&4@=&AE(&-U
M<G)E;G0@979E;G0@;VYL>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T
M=7)E(&]C8W5R96YC97,L(&]R("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R
M("(B"B)3;&5T="!B87)E(&=J96QD96YD92!H96YD96QS92P@9&5N;F4@:&5N
M9&5L<V5N(&]G(&%L;&4@9G)E;71I9&EG92!H96YD96QS97(L("(*(F5L;&5R
M(&%L;&4@:&5N9&5L<V5R/R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHQ,#0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C(X"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B0F5S:W)I=F5L<V4B
M"@HC.B!D871A+G!H<#HV,B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R
M<RYI;F,Z,3<U"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.CDV"FUS9VED
M(")$97-C<FEP=&EO;B(*;7-G<W1R(")"97-K<FEV96QS92(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<S"FUS9VED(")$:7-P;&%Y
M(@IM<V=S='(@(E9I<R(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!#86QE;F1A<G,B
M"FUS9W-T<B`B36EN92!K86QE;F1E<F5R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(E9I<VEN9W-V86QG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS
M9VED(")$;R!Y;W4@=V%N="!T;R!S:&]W('1A<VMS('=H:6-H(&%R92!D=64@
M;VX@>6]U<B!C86QE;F1A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-3,W"FUS9VED(")$;V5S(&YO="!R96-U<B(*;7-G<W1R("(B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HS,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1'5E.B`E<R(*;7-G<W1R(")&;W)F86QL.B`E<R(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS
M9W-T<B`B5F%R:6=H970B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N
M9&%R<RYI;F,Z,3<P(&QI8B]$<FEV97(N<&AP.C$X,#8*;7-G:60@(D5D:70B
M"FUS9W-T<B`B4F5D:6=E<B(*"B,Z(&5D:71E=F5N="YP:'`Z,S,@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C8@;&EB+T1R:79E<BYP:'`Z,3@P-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET("5S(@IM<V=S='(@(E)E9&EG97(@)7,B
M"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#<*;7-G:60@(D5D:70@
M071T96YD965S(@IM<V=S='(@(D5N9')E(&1E;'1A:V5R92(*"B,Z('1E;7!L
M871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-#`*(RP@9G5Z>GD*;7-G
M:60@(D5D:70@0V%L96YD87)S(@IM<V=S='(@(DUI;F4@:V%L96YD97)E<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3`*(RP@9G5Z>GD*;7-G:60@
M(D5D:70@4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R("));7!O<G1E<B!+86QE
M;F1E<B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,34P"FUS9VED(")%9&ET(&%T=&5N
M9&5E<R(*;7-G<W1R(")%;F1R92!D96QT86ME<F4B"@HC.B!T96UP;&%T97,O
M8V%T96=O<GE?;&5G96YD+FEN8SHR,`IM<V=I9"`B161I="!C871E9V]R:65S
M(&%N9"!C;VQO<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ-S8@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC.C0Q"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$V-`IM<V=I
M9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%+7!O<W0@861R97-S92(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8P"B,L(&9U>GIY
M"FUS9VED(")%;E]D(@IM<V=S='(@(D%V<VQU='1E<R(*"B,Z(&1A=&$N<&AP
M.C4W"FUS9VED(")%;F0@1&%T92(*;7-G<W1R(")!=G-L=71T97,@9&%T;R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z."!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$P.`IM<V=I9"`B16YD($]N(@IM<V=S='(@(D%V<VQU='1E<R(*
M"B,Z(&1A=&$N<&AP.C4X"FUS9VED(")%;F0@5&EM92(*;7-G<W1R(")!=G-L
M=71T97,@:VQO:VME;B(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3(T(&%T=&5N9&5E
M<RYP:'`Z,3,U(&%T=&5N9&5E<RYP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(')E=')I979I;F<@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(&9O
M<B`E<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y
M,PIM<V=I9"`B179E;G0@861D960Z(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$Q,#,*;7-G:60@(D5V96YT(&1E;&5T960Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.3@*;7-G:60@(D5V96YT(&5D
M:71E9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`V-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%=F5N="!F<F]M("5S('1O("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V-`HC+"!F=7IZ>0IM<V=I9"`B179E
M;G1S(&UU<W0@:&%V92!A('-T87)T(&1A=&4N(@IM<V=S='(@(DMA;B!I:VME
M(&%V<VQU='1E(&;X<B!S=&%R="XB"@HC.B!L:6(O1')I=F5R+G!H<#HW,S`*
M;7-G:60@(D5V96YT<R!M=7-T(&AA=F4@82!T:71L92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z-S8W"FUS9VED(")%=F5N=',@;75S="!H879E
M(&%N(&5N9"!D871E(&]R(&$@9'5R871I;VXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHW.0HC+"!F=7IZ>0IM
M<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(DMA;&5N9&5R(&YA=FXB"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X-PIM<V=I9"`B17AP;W)T
M(@IM<V=S='(@(D5K<W!O<G1E<B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z.`IM<V=I9"`B17AP;W)T($-A;&5N9&%R(@IM<V=S='(@(D5K<W!O
M<G1E<B!K86QE;F1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N
M:6YC.C8Y"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")F96)R=6%R(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,C@*;7-G:60@(D9I
M;F0B"FUS9W-T<B`B1FEN;B(*"B,Z('EE87(N<&AP.C@W('1E;7!L871E<R]J
M879A<V-R:7!T+V=O=&\N:6YC.C8S('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C(R,@HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B1G(B"FUS
M9W-T<B`B1G(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@*(RP@9G5Z
M>GD*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R(")$:6X@
M:6YF;W)M87-J;VXB"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C`@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$Y"B,Z('1E;7!L871E<R]E9&ET
M+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")&<FED87DB"FUS9W-T<B`B1G)E
M9&%G(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C,P"FUS9VED
M(")&=71U<F4B"FUS9W-T<B`B1G)E;71I9"(*"B,Z(&-O;F9I9R]K97EW;W)D
M<RYP:'`N9&ES=#HQ-PIM<V=I9"`B1V%M92(*;7-G<W1R(")3<&EL;"(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHR,PIM<V=I
M9"`B1V5N97)A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,30P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")';W1O("5S(@IM
M<V=S='(@(D?E('1I;"(*"B,Z(&UO;G1H+G!H<#HQ,S4@=&5M<&QA=&5S+W=E
M96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO
M:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"FUS9VED(")(:61E(@IM<V=S='(@
M(B(*"B,Z(&UO;G1H+G!H<#HQ,S4@=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E
M7V)Y7W-I9&4N:6YC.C$R"B,Z('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y
M7W-I9&4N:6YC.C$P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(:61E
M("5S(@IM<V=S='(@(E9I<R`E<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C8U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S.`IM<V=I9"`B2&]U
M<BAS*2(*;7-G<W1R(")4:6UE*'(I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,PHC+"!F=7IZ>0IM<V=I9"`B2&]W(&QO;F<@<VAO=6QD('1H92!T
M:6UE('-L;W1S(&]N('1H92!D87D@86YD('=E96L@=FEE=W,@8F4_(@IM<V=S
M='(@(E9I<R!H86QV=&EM97-S96=M96YT97(@:2!D86<M(&]G('5K979I<VEN
M9S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@X"FUS9VED(")(;W<@
M;6%N>2!D87ES(&]F(&9R964O8G5S>2!I;F9O<FUA=&EO;B!S:&]U;&0@=V4@
M9V5N97)A=&4_(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB268@>6]U<B!E;6%I;"!C;&EE
M;G0@9&]E<VXG="!S=7!P;W)T(&E4:7`@<F5Q=65S=',@>6]U(&-A;B!U<V4@
M;VYE(&]F('1H92`B"B)F;VQL;W=I;F<@;&EN:W,@=&\@86-C97!T(&]R(&1E
M8VQI;F4@=&AE(&5V96YT+EQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT
M.EQN(@HB)7-<;B(*(EQN(@HB5&\@86-C97!T('1H92!E=F5N="!T96YT871I
M=F5L>3I<;B(*(B5S7&XB"B)<;B(*(E1O(&1E8VQI;F4@=&AE(&5V96YT.EQN
M(@HB)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!#86QE;F1A<BP@4W1E
M<"`E9"(*;7-G<W1R("));7!O<G1E<B!K86QE;F1E<BP@<W1E9R`E9"(*"B,Z
M(&1A=&$N<&AP.C,R,`IM<V=I9"`B26UP;W)T+T5X<&]R="!#86QE;F1A<B(*
M;7-G<W1R("));7!O<G1E<B]%:W-P;W)T97(@2V%L96YD97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV.`IM<V=I9"`B2F%N=6%R>2(*
M;7-G<W1R(")J86YU87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHW-`IM<V=I9"`B2G5L>2(*;7-G<W1R(")J=6QI(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S,*;7-G:60@(DIU;F4B"FUS9W-T
M<B`B:G5N:2(*"B,Z(&1A=&$N<&AP.C8U('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$T,@IM<V=I9"`B2V5Y=V]R9',B"FUS9W-T<B`B4W1I:VMO<F0B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-34*;7-G:60@(DQA<W0@
M,C0@:&]U<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z.#<*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHT"B,Z('1E;7!L
M871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ-B!T96UP;&%T97,O
M;6]N=&@O:&5A9"YI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!-;VYT:"(*
M;7-G<W1R(")&;W)R:6=E(&WE;F5D(@H*(SH@=&5M<&QA=&5S+WEE87(O:&5A
M9"YI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!996%R(@IM<V=S='(@(D9O
M<G)I9V4@=6ME(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4T
M('1E;7!L871E<R]W965K+VAE860N:6YC.C,*;7-G:60@(DQA<W0@=V5E:R(*
M;7-G<W1R(")&;W)R:6=E('5K92(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,3<*;7-G:60@(DQI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T
M.B(*;7-G<W1R(")!=F=R96YS('1I9'-I;G1E<G9A;&P@9F]R(&5K<W!O<G1E
M<FEN9SHB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI
M;F,Z.#8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z-S8*;7-G:60@(DQO7V-A
M=&EO;B(*;7-G<W1R(")3=&5D(@H*(SH@9&%T82YP:'`Z-C0@=&5M<&QA=&5S
M+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHU"B,Z('1E;7!L871E<R]P<F5F
M<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C$X"B,Z('1E;7!L871E<R]P
M<F5F<R]R96UO=&5?8V%L7VUA;F%G96UE;G0N:6YC.C4R('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C(Q"B,Z(&QI8B]$<FEV97(N<&AP.C$X-#D*;7-G:60@
M(DQO8V%T:6]N(@IM<V=S='(@(E!L87-S97)I;F<B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4*;7-G:60@(DUA;F%G92!R96UO=&4@8V%L96YD87)S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHW,`IM<V=I9"`B36%R8V@B"FUS9W-T<B`B;6%R<R(*"B,Z(&QI8B]A<&DN
M<&AP.C$P,`IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@179E;G1S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<R"FUS
M9VED(")-87DB"FUS9W-T<B`B;6%I(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@T
M-@IM<V=I9"`B364B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H
M<"YD:7-T.C$W"FUS9VED(")-965T:6YG(@IM<V=S='(@(DWX=&4B"@HC.B!L
M:6(O0FQO8VLO=')E95]A;&%R;7,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE
M;G4@06QA<FUS(@IM<V=S='(@(D%L87)M(@H*(SH@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,PIM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C8X('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C$S-PIM<V=I9"`B36EN=71E*',I(@IM<V=S='(@(DUI;G5T="AE<BDB
M"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z-#(*;7-G:60@(DUI
M<W-E9"!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC.B!Y96%R+G!H<#HX,R!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHU.2!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,3@*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G
M:60@(DUO(@IM<V=S='(@(DUA(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N
M:6YC.C$V('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-0HC.B!T96UP;&%T
M97,O961I="]J879A<V-R:7!T+FEN8SHV."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`V"FUS9VED(")-;VYD87DB"FUS9W-T<B`B36%N9&%G(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z,3(Y,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO;G1H(@IM<V=S
M='(@(DWE;F5D(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS"B,L(&9U>GIY
M"FUS9VED(")-;VYT:"!6:65W(@IM<V=S='(@(DWE;F5D(@H*(SH@;&EB+T)L
M;V-K+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT
M,PIM<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R.2!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(DUO;G1H;'DZ(%)E8W5R
M<R!E=F5R>2(*;7-G<W1R(")(=F5R(&WE;F5D.B!3:VIE<B!H=F5R(@H*(SH@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!!:&5A
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z
M,C0*(RP@9G5Z>GD*;7-G:60@(DUO;G1H<R!"969O<F4B"FUS9W-T<B`B36EN
M=71T97(@9OAR(@H*(SH@;&EB+V%P:2YP:'`Z-C$R"FUS9VED(")-=6QT:7!L
M92!I0V%L96YD87(@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@=D5V96YT
M(&ES('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HQ
M,C@@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8W"FUS9VED
M(")->2!#86QE;F1A<G,B"FUS9W-T<B`B36EN92!K86QE;F1E<F5R(@H*(SH@
M=&5M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M96YU+FEN8SHS-@HC
M+"!F=7IZ>0IM<V=I9"`B37D@0V%L96YD87)S.B(*;7-G<W1R(")-:6YE(&MA
M;&5N9&5R97(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z,C`T"FUS9VED(")->2!&<F5E+T)U<WD@55),(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,3<@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U.0HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W-0HC.B!T96UP;&%T97,O<')E9G,O
M<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHQ-PHC.B!T96UP;&%T97,O<')E
M9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHT-`HC+"!F=7IZ>0IM<V=I
M9"`B3F%M92(*;7-G<W1R(")3<&EL;"(*"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z-#$@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z-#0@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C0Q"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(P"FUS
M9VED(").97<@179E;G0B"FUS9W-T<B`B3GD@:&5N9&5L<V4B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C,T"FUS9VED(").97AT(@IM<V=S='(@
M(DYE<W1E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C4W"FUS
M9VED(").97AT(#(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&QI8B]&0E9I97<O
M9&%Y+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3F5X="!$87DB"FUS9W-T<B`B
M3F5S=&4@9&%G(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S
M:61E+FEN8SHV"B,Z('1E;7!L871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED
M92YI;F,Z,3(*(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E
M+FEN8SHQ."!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z-@IM<V=I9"`B3F5X
M="!-;VYT:"(*;7-G<W1R(").97-T92!MY6YE9"(*"B,Z(&QI8B]&0E9I97<O
M=V5E:RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(DYE>'0@5V5E:R(*;7-G<W1R
M(").97-T92!U:V4B"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHV"B,L
M(&9U>GIY"FUS9VED(").97AT(%EE87(B"FUS9W-T<B`B3F5S=&4@9&%G(@H*
M(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT(&1A>2(*
M;7-G<W1R(").97-T92!D86<B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C
M:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM<V=I9"`B3F5X
M="!W965K(@IM<V=S='(@(DYE<W1E('5K92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-S4*(RP@9G5Z>GD*;7-G:60@(DYO(@IM<V=S='(@(D[E(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,3(V"B,L(&9U>GIY"FUS9VED(").;R!A;&%R;2(*;7-G<W1R
M(")!;&%R;2(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN
M8SHT.`IM<V=I9"`B3F\@871T96YD965S(@IM<V=S='(@(DEN9V5N(&1E;'1A
M:V5R92(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S,3$*;7-G:60@(DYO(&-A
M;&5N9&%R<R!A<F4@879A:6QA8FQE('1O(&=U97-T<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,V('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(U-0IM<V=I9"`B3F\@96YD(&1A=&4B"FUS9W-T<B`B26YG
M96X@879S;'5T=&YI;F=S(&1A=&\B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H
M;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$V,PHC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT"FUS9VED(").;R!E=F5N=',@=&\@
M9&ES<&QA>2(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N(&ES(&%V86EL86)L92!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,S0T(&QI8B]A<&DN<&AP.C8P,@IM<V=I9"`B3F\@:4-A;&5N9&%R
M(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,#0*(RP@9G5Z>GD*;7-G:60@(DYO(')E8W5R<F5N8V4B
M"FUS9W-T<B`B1VIE;G1A9V5N9&4@9&%T;R(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C@X-@IM<V=I9"`B3F\@=F%L:60@96UA:6P@861D<F5S<R!F;W5N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HV,#$@;&EB+TMR;VYO
M;&ET:"YP:'`Z-C(R"FUS9VED(").;VYE(@IM<V=S='(@(DEN9V5N(@H*(SH@
M;&EB+U-T;W)A9V4O<W%L+G!H<#HQ,S8*;7-G:60@(DYO="!F;W5N9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*(RP@9G5Z>GD*
M;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`B4&QA<W-E<FEN9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<X"FUS9VED(").;W9E
M;6)E<B(*;7-G<W1R(")N;W9E;6)E<B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHU-@IM<V=I9"`B3F]W(@IM<V=S='(@(D[E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S<*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B;VMT;V)E<B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM
M97-P86XN:6YC.C$S('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC
M.C8U"FUS9VED(")/;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C<X"FUS9VED(")/;B!A;&P@8V%L96YD87)S($D@:&%V92!R96%D
M(&%C8V5S<R!T;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C<W"FUS9VED(")/;B!A;&P@<VAO=VX@8V%L96YD87)S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S8*(RP@9G5Z>GD*;7-G
M:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY(@IM<V=S='(@(DUI;F4@:V%L96YD
M97)E<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8Q.0HC+"!F=7IZ>0IM<V=I
M9"`B3W!T:6]N86PB"FUS9W-T<B`B5F%L9R(*"B,Z(&QI8B]&0E9I97<N<&AP
M.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B3W!T:6]N86P@071T96YD965S(@IM<V=S
M='(@(D%L;&4@9&5L=&%K97)E(@H*(SH@;&EB+T9"5FEE=RYP:'`Z,34R"FUS
M9VED(")/=F5R=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHS-`IM<V=I9"`B3W=N97(B"FUS9W-T<B`B16EG97(B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ.#0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")/=VYE<CH@)7,B"FUS9W-T<B`B16EG97(B"@HC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C$P,B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X
M,@IM<V=I9"`B4$TB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,CD@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B4&%L;2!$
M871E0F]O:R(*;7-G<W1R(")!;&%R;2!$871O(@H*(SH@;&EB+T)L;V-K+W!R
M979M;VYT:&QI<W0N<&AP.C,*;7-G:60@(E!A<W0@179E;G1S($QI<W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`Y('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C$Y.`IM<V=I9"`B4&%T=&5R;B(*;7-G<W1R
M(")-^&YS=&5R(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(W"FUS
M9VED(")097)M86YE;G1L>2!D96QE=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`B
M4VQE='0@9&5N;F4@:&5N9&5L<V5N('!E<FUA;F5N=#\B"@HC.B!L:6(O87!I
M+G!H<#HS,C4@;&EB+V%P:2YP:'`Z-#$Y(&QI8B]A<&DN<&AP.C0X,2!L:6(O
M87!I+G!H<#HU-3,*(SH@;&EB+V%P:2YP:'`Z-3@T(&QI8B]A<&DN<&AP.C8W
M,"!L:6(O87!I+G!H<#HW,#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ-C<*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!E
M<G-O;FQI9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,0HC+"!F=7IZ
M>0IM<V=I9"`B4&]R=&%L($]P=&EO;G,B"FUS9W-T<B`B0G)U:V5R=F%L9R(*
M"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B4')E
M=FEO=7,@1&%Y(@IM<V=S='(@(DYE<W1E(&1A9R(*"B,Z(&QI8B]&0E9I97<O
M=V5E:RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(%=E96LB"FUS
M9W-T<B`B3F5S=&4@9&%G(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHS
M"FUS9VED(")0<F5V:6]U<R!D87DB"FUS9W-T<B`B3F5S=&4@9&%G(@H*(SH@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,U('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C(U,@IM<V=I9"`B4F5C=7(@56YT:6PB"FUS9W-T<B`B079S;'5T
M=&5S(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3`V"B,L(&9U>GIY
M"FUS9VED(")296-U<G)E;F-E(@IM<V=S='(@(D=J96YT86=E;F1E(&1A=&\B
M"@HC.B!D871A+G!H<#HV.0IM<V=I9"`B4F5C=7)R96YC92!$871A(@IM<V=S
M='(@(D=J96YT86=E;F1E(&1A=&\B"@HC.B!D871A+G!H<#HV-PIM<V=I9"`B
M4F5C=7)R96YC92!%;F0@1&%T92(*;7-G<W1R(")3;'5T="!D871O(&9O<B!G
M:F5N=&%G:6YG(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@(E)E8W5R<F5N8V4@
M26YT97)V86PB"FUS9W-T<B`B1VIE;G1A9V5L<V5S(&EN=&5R=F%L;"(*"B,Z
M(&1A=&$N<&AP.C8V"FUS9VED(")296-U<G)E;F-E(%1Y<&4B"FUS9W-T<B`B
M1VIE;G1A9V5L<V5S('1Y<&4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#`*
M;7-G:60@(E)E8W5R<R!D86EL>2(*;7-G<W1R(")3:VIE<B!D86=L:6<B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HU-#<*;7-G:60@(E)E8W5R<R!M;VYT:&QY
M(@IM<V=S='(@(E-K:F5R(&WE;F5D;&EG(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-30S"FUS9VED(")296-U<G,@=V5E:VQY(@IM<V=S='(@(E-K:F5R('5K
M96YT;&EG(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34P"FUS9VED(")296-U
M<G,@>65A<FQY(@IM<V=S='(@(E-K:F5R(.5R;&EG(@H*(SH@;&EB+U-C:&5D
M=6QE<B]K<F]N;VQI=&@N<&AP.C$Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M:6YD97(Z("5S(@IM<V=S='(@(E1A(&)O<G0@)7,B"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z.3$@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0T"B,L(&9U>GIY"FUS9VED(")296UO=&4@0V%L96YD
M87)S(@IM<V=S='(@(DEM<&]R=&5R($MA;&5N9&5R(@H*(SH@=&5M<&QA=&5S
M+VUE;G4N:6YC.C8P('1E;7!L871E<R]M96YU+FEN8SHV,@HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W1E($-A;&5N9&%R<SHB"FUS9W-T<B`B26UP;W)T97(@2V%L
M96YD97(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z
M-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E("5S(@IM<V=S='(@(E1A
M(&)O<G0@)7,B"@HC.B!A='1E;F1E97,N<&AP.C$P-`IM<V=I9"`B4F5M;W9E
M($%T=&5N9&5E(@IM<V=S='(@(E1A(&)O<G0@9&5L=&%K97)E(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS,@IM<V=I9"`B(@HB4F5P;&%C92!E
M>&ES=&EN9R!C86QE;F1A<B!W:71H('1H92!I;7!O<G1E9"!O;F4_(#QS=')O
M;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO
M=7(@8W5R<F5N="!C86QE;F1A<BX\+W-T<F]N9SXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z-C(V"FUS9VED(")297%U:7)E9"(*;7-G<W1R
M(")/8FQI9V%T;W)I<VLB"@HC.B!L:6(O1D)6:65W+G!H<#HY."!L:6(O1D)6
M:65W+G!H<#HQ,S<@;&EB+T9"5FEE=RYP:'`Z,30P(&QI8B]&0E9I97<N<&AP
M.C$T,PIM<V=I9"`B4F5Q=6ER960@071T96YD965S(@IM<V=S='(@(D]B;&EG
M871O<FES:V4@9&5L=&%K97)E(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S$P"FUS9VED(")297-E
M="!T;R!$969A=6QT<R(*;7-G<W1R(").=6QL<W1I;&P@=&EL('-T86YD87)D
M=F5R9&EE<B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN
M8SHT,R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C8*;7-G:60@(E)E<W!O
M;G-E(@IM<V=S='(@(E-V87(B"@HC.B!Y96%R+G!H<#HX."!T96UP;&%T97,O
M:F%V87-C<FEP="]G;W1O+FEN8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHR,C,*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E-A(@IM
M<V=S='(@(DSX(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(Q('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$R,`HC.B!T96UP;&%T97,O961I="]J
M879A<V-R:7!T+FEN8SHW,PIM<V=I9"`B4V%T=7)D87DB"FUS9W-T<B`B3/AR
M9&%G(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$Y
M,@HC+"!F=7IZ>0IM<V=I9"`B4V%V92(*;7-G<W1R("),^"(*"B,Z('9I97=E
M=F5N="YP:'`Z,3$X(&5D:71E=F5N="YP:'`Z-#@@961I=&5V96YT+G!H<#HU
M-@IM<V=I9"`B4V%V92!!<R!.97<B"FUS9W-T<B`B3&%G<F4@<V]M(&YY(@H*
M(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C@W"B,L(&9U
M>GIY"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G<W1R(")482!B;W)T(&1E
M;'1A:V5R92(*"B,Z(&%D9&5V96YT+G!H<#HU-2!E9&ET979E;G0N<&AP.C4Q
M"FUS9VED(")3879E($5V96YT(@IM<V=S='(@(DQA9W)E(&AE;F1E;'-E(@H*
M(SH@<V5A<F-H+G!H<#HY,2!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z,3$U"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHV
M-R!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z.`HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$T,"!L:6(O0FQO8VLO=')E95]M
M96YU+G!H<#HR-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E/X:R(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ"B,L(&9U>GIY"FUS9VED
M(")396%R8V@@0V%L96YD87)S(@IM<V=S='(@(DUI;F4@:V%L96YD97)E<B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHV"B,L(&9U>GIY"FUS
M9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R(")3^&LB"@HC.B!T96UP;&%T
M97,O8V%L96YD87)S+W-E87)C:"YI;F,Z-@IM<V=I9"`B4V5A<F-H(&9O<B!C
M86QE;F1A<G,@8V]N=&%I;FEN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$U,`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&$@8V%L96YD87(@=&\@961I="(*;7-G<W1R(")696QG(&5N(&MA
M;&5N9&5R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C8X('1E;7!L
M871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!D871E(@IM<V=S='(@(E9E;&<@96X@:V%L96YD97(B"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!C86QE
M;F1A<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B5F5L9R!H=F]R9&%N(&1A=&\@
M<VMA;"!V:7-E<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*;7-G
M:60@(B(*(E-E;&5C="!C;VYF:7)M871I;VX@;W!T:6]N<RP@:&]W('1O(&1I
M<W!L87D@=&AE(&1I9F9E<F5N="!V:65W<R!A;F0@8VAO;W-E("(*(F1E9F%U
M;'0@=FEE=RXB"FUS9W-T<B`B(@HB5F5L9R!V86QG(&9O<B!B96MR969T96QS
M92P@:'9O<F1A;B!D92!U;&EK92!V:7-I;F=E;F4@<VMA;"!P<F5S96YT97)E
M<R!O9R`B"B)V96QG(&5N('-T86YD87)D=FES:6YG+B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,3D*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T
M:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.B(*;7-G<W1R(")696QG(&9I;"!S
M;VT@<VMA;"!I;7!O<G1E<F5S.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,3(*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS
M9W-T<B`B5F5L9R!E:W-P;W)T(&9O<FUA=#HB"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C(X"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP
M;W)T.B(*;7-G<W1R(")696QG(&9I;"!S;VT@<VMA;"!I;7!O<G1E<F5S.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@(E-E;&5C="!T
M:&4@9FER<W0@=V5E:V1A>3HB"FUS9W-T<B`B5F5L9R!F^')S=&4@=6ME9&%G
M.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G:60@(E-E
M;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B
M5F5L9R!F;W)M871E="!PY2!F:6QE;B!S;VT@<VMA;"!I;7!O<G1E<F5S.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#0*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!S<&%N('1O('-H;W<Z(@IM<V=S='(@(E9E;&<@=&ED<VEN=&5R
M=F%L;"!S;VT@<VMA;"!V:7-E<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=FEE=R!T;R!D:7-P
M;&%Y(&]N('-T87)T=7`Z(@IM<V=S='(@(E9E;&<@=FES;FEN9R!S;VT@<VMA
M;"!B<G5K97,@971T97(@:6YN;&]G9VEN9SHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!W:&EC:"!E=F5N
M=',@=&\@<VAO=R!I;B!T:&4@<&]R=&%L+B(*;7-G<W1R(")696QG(&AV:6QK
M92!H96YD96QS97(@<V]M('-K86P@=FES97,@:2!O<'!S=6UM97)I;F=S=FES
M;FEN9V5N+B(*"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR-"!T96UP
M;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E-E
M;F0@82!C86YC96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E;F1E97,@=VAE
M;B!D96QE=&EN9R!T:&ES(&5V96YT(@IM<V=S='(@(B(*(E-E;F0@;W!P9&%T
M97)I;F=E<B]I;G9I=&%S:F]N97(@=&EL(&%L;&4@9&5L=&%K97)E('9E9"!L
M86=R:6YG(&%V(&1E;FYE("(*(FAE;F1E;'-E;B(*"B,Z('1E;7!L871E<R]V
M:65W+W9I97<N:6YC.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")396YD(&%N
M(&5M86EL('1O("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C$X,0IM<V=I9"`B4V5N9"!U<&1A=&5S+VEN=FET871I;VYS('1O
M(&%L;"!A='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N="(*;7-G<W1R
M("(B"B)396YD(&]P<&1A=&5R:6YG97(O:6YV:71A<VIO;F5R('1I;"!A;&QE
M(&1E;'1A:V5R92!V960@;&%G<FEN9R!A=B!D96YN92`B"B)H96YD96QS96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW-@IM<V=I9"`B
M4V5P=&5M8F5R(@IM<V=S='(@(G-E<'1E;6)E<B(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS9VED(")3970@
M96YD(&1A=&4B"FUS9W-T<B`B26YG96X@879S;'5T=&YI;F=S(&1A=&\B"@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR-C@*(RP@9G5Z>GD*;7-G:60@
M(E-E="!R96-U<G)E;F-E(&5N9"!D871E(@IM<V=S='(@(E-L=71T(&1A=&\@
M9F]R(&=J96YT86=I;F<B"@HC.B!T96UP;&%T97,O961I="]E9&ET7W1I;65S
M<&%N+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B4V5T('-T87)T(&1A=&4B"FUS
M9W-T<B`B4W1A<G0@9&%T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.0IM<V=I9"`B(@HB4V5T('EO=7(@9G)E92]B=7-Y(&-A;&5N9&%R<R!A;F0@
M>6]U<B!O=VX@86YD(&]T:&5R('5S97)S)R!F<F5E+V)U<WD@;W!T:6]N<RXB
M"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HW-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3:&%R92!N;W0@9F]U;F0Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHW.0HC+"!F=7IZ>0IM
M<V=I9"`B4VAA<F5D($-A;&5N9&%R<R(*;7-G<W1R(")-:6YE(&MA;&5N9&5R
M97(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-#<@=&5M<&QA=&5S+VUE;G4N
M:6YC.C0Y"B,L(&9U>GIY"FUS9VED(")3:&%R960@0V%L96YD87)S.B(*;7-G
M<W1R(")-:6YE(&MA;&5N9&5R97(B"@HC.B!C86QE;F1A<E]S96%R8V@N<&AP
M.C(U('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E+FEN8SHS"B,Z
M('1E;7!L871E<R]D87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,C(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-H;W<@8V%L96YD87(@7"(E<UPB(@IM<V=S
M='(@(DUI;F4@:V%L96YD97)E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-38*;7-G:60@(E-H;W<@8V%T96=O<GD@;&5G96YD/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")3:&]W(&1E
M;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC;VYS(&EN(&-A;&5N9&%R
M('9I97=S/R(*;7-G<W1R(")6:7,@<VQE='0M+"!A;&%R;2T@;V<@9VIE;G1A
M9V5L<V5S:6MO;F5R(&D@:V%L96YD97)V:7-N:6YG/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(E-H;W<@9'5E('1A<VMS(&EN('1H
M92!C86QE;F1A<C\B"FUS9W-T<B`B5FES(&]P<&=A=F5R('1I;"!F;W)F86QL
M(&D@:V%L96YD97)E;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38V
M"FUS9VED(")3:&]W(&9R964O8G5S>2!L96=E;F0_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@(E-H;W<@;VYL>2!E
M=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS9W-T<B`B5FES(&)A
M<F4@:&5N9&5L<V5R('-O;2!H87(@86QA<FT_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$W-0IM<V=I9"`B4VAO=R!S:&%R960@8V%L96YD87)S('-I
M9&4M8GDM<VED93\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T87-K<R!U<VEN9R!C871E
M9V]R>2!C;VQO<G,_(@IM<V=S='(@(E9I<R!O<'!G879E<B!T:6P@9F]R9F%L
M;"!I(&MA;&5N9&5R96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU
M"B,L(&9U>GIY"FUS9VED(")3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C
M:"!D87D@:6X@=V5E:R!V:65W<S\B"FUS9W-T<B`B5FES(&AA;'9T:6UE<W-E
M9VUE;G1E<B!I(&1A9RT@;V<@=6ME=FES:6YG/R(*"B,Z('1E;7!L871E<R]E
M9&ET+V5D:71?=&EM97-P86XN:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")3=&%?
M<G0B"FUS9W-T<B`B4W1A<G0@<.4B"@HC.B!D871A+G!H<#HU-0IM<V=I9"`B
M4W1A<G0@1&%T92(*;7-G<W1R(")3=&%R="!D871O(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHW('1E;7!L871E<R]V:65W+W9I
M97<N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C4*;7-G
M:60@(E-T87)T($]N(@IM<V=S='(@(E-T87)T(@H*(SH@9&%T82YP:'`Z-38*
M;7-G:60@(E-T87)T(%1I;64B"FUS9W-T<B`B4W1A<G0@=&ED(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.CDU('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C@U"FUS9VED(")3=&%T7W5S(@IM<V=S='(@(E-T
M871U<R(*"B,Z('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z
M-B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B
M4W1A='5S(@IM<V=S='(@(E-T871U<R(*"B,Z('EE87(N<&AP.C@Q('EE87(N
M<&AP.CDP('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C8U"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-"!L:6(O0FQO8VLO;6]N=&@N<&AP
M.C$P-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P.0IM<V=I9"`B4W4B"FUS9W-T
M<B`B4_@B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,30@=&5M<&QA
M=&5S+VUO;G1H+VAE860N:6YC.C(S"B,Z('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R,2!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHV-PHC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")3=6YD87DB"FUS9W-T
M<B`B4_AN9&%G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS9VED
M(")487-K<R(*;7-G<W1R(")/<'!G879E<B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C4W-"!L:6(O2W)O;F]L:71H+G!H<#HU.3<*;7-G:60@(E1E;G1A=&EV
M92(*;7-G<W1R(")&;W)E;/AP:6<B"@HC.B!Y96%R+G!H<#HX-B!T96UP;&%T
M97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1H
M(@IM<V=S='(@(E1O(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHW,`IM<V=I9"`B5&AE($5D:70@071T96YD965S('-C<F5E;B!I<R!N
M;R!L;VYG97(@<')E<V5N="X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@8V%L
M96YD87)S+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&-A;&5N9&%R(%PB)7-<(B!C86YN;W0@8F4@9&5L971E9"XB"FUS9W-T<B`B
M16YD<FEN9V5R(&AE<B!K86X@:6MK92!A;F=R97,A(@H*(SH@8V%L96YD87)S
M+G!H<#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E
M<UPB(&AA<R!B965N(&-R96%T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R
M<RYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A
M<G,N<&AP.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<
M(B5S7"(@:&%S(&)E96X@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&-A;&5N9&%R<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE
M;F1A<B!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHQ-C,*;7-G:60@(E1H92!E
M;F0@9&%T92!M=7-T(&)E(&QA=&5R('1H86X@=&AE('-T87)T(&1A=&4N(@IM
M<V=S='(@(DMA;B!I:VME(&%V<VQU='1E(&;X<B!S=&%R="XB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,#DT"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!E
M=F5N="!<(B5S7"(@:&%S(&)E96X@861D960L('=H:6-H(&ES(&]N("5S(&%T
M("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3`T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"P@=VAI8V@@=V%S(&]N("5S(&%T("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@961I=&5D+"!W:&EC:"!I<R!O
M;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3`V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@;F]T:69I8V%T
M:6]N('1O("5S('=A<R!S=6-C97-S9G5L;'D@<V5N="XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`R-`IM<V=I9"`B5&AE(&9O;&QO=VEN
M9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE(&5V96YT
M.B(*;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP.C0Q"FUS9VED("(B"B)4:&4@
M<F5Q=65S="!W87,@:6YC;VUP;&5T92X@4V]M92!P87)A;65T97)S('1H870@
M87)E(&YE8V5S<V%R>2!T;R!A8V-E<'0@;W(@(@HB9&5C;&EN92!A;B!E=F5N
M="!A<F4@;6ES<VEN9RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]E;7!T>2YI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&5V
M96YT<R!M871C:&EN9R!T:&4@8W5R<F5N="!C<FET97)I82XB"FUS9W-T<B`B
M1&5T(&5R(&EN9V5N(&AE;F1E;'-E<B#E(&5K<W!O<G1E<F4N(@H*(SH@861D
M979E;G1A8W1I;VXN<&AP.C$X(&5D:71E=F5N=&%C=&EO;BYP:'`Z,S4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A
M8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<R(*;7-G<W1R(")$970@<VMJ961D
M92!E;B!F96EL('9E9"!I;7!O<G0@878@9&%T82XB"@HC.B!A9&1E=F5N=&%C
M=&EO;BYP:'`Z,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&5V96YT.B`E<R(*;7-G<W1R(")$
M970@<VMJ961D92!E;B!F96EL('9E9"!I;7!O<G0@878@9&%T82XB"@HC.B!E
M9&ET979E;G1A8W1I;VXN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S
M(@IM<V=S='(@(D1E="!S:VIE9&1E(&5N(&9E:6P@=F5D(&EM<&]R="!A=B!D
M871A+B(*"B,Z(&QI8B]A<&DN<&AP.C,S."!L:6(O87!I+G!H<#HU.38*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")$970@<VMJ961D92!E;B!F96EL
M('9E9"!I;7!O<G0@878@9&%T82XB"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP
M.C8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B1&5T('-K:F5D
M9&4@96X@9F5I;"!V960@:6UP;W)T(&%V(&1A=&$N(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z,3`W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z
M("5S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$P-0IM<V=I9"`B5&AE<F4@
M=V5R92!N;R!E=F5N=',@=&\@97AP;W)T+B(*;7-G<W1R(")$970@97(@:6YG
M96X@:&5N9&5L<V5R(.4@96MS<&]R=&5R92XB"@HC.B!D871A+G!H<#HQ.#0*
M;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ.2!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,3@*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI
M;F,Z-S$*;7-G:60@(E1H=7)S9&%Y(@IM<V=S='(@(E1O<G-D86<B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S<*;7-G:60@(E1I;64@4W!?
M86XB"FUS9W-T<B`B5&ED<W!E<FEO9&4B"@HC.B!T96UP;&%T97,O961I="]E
M9&ET7W1I;65S<&%N+FEN8SHT"FUS9VED(")4:6UE('-P86XB"FUS9W-T<B`B
M5&ED<W!E<FEO9&4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A
M;F-E9"YI;F,Z,S8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z-#`*;7-G:60@
M(E1I=%]L92(*;7-G<W1R(")4:71T96PB"@HC.B!D871A+G!H<#HU-"!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,C`*(SH@=&5M<&QA=&5S+W-E87)C
M:"]E=F5N=%]H96%D97)S+FEN8SHS"FUS9VED(")4:71L92(*;7-G<W1R(")4
M:71T96PB"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,3(R(&QI
M8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$R,0HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,3(W"FUS9VED(")4;V1A>2(*;7-G<W1R("))(&1A9R(*"B,Z(&QI
M8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C0@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z,3(S"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,CD*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(DD@;6]R9V5N(@H*(SH@>65A<BYP:'`Z
M.#0@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C`@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C$Y"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U
M"FUS9VED(")4=2(*;7-G<W1R(")4:2(*"B,Z('1E;7!L871E<R]M;VYT:"]H
M96%D+FEN8SHQ-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,38*(SH@=&5M
M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-CD*;7-G:60@(E1U97-D87DB
M"FUS9W-T<B`B5&ER<V1A9R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES
M=#HQ-PIM<V=I9"`B5'EP92(*;7-G<W1R(")4>7!E(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$X,PIM<V=I9"`B55),(@IM<V=S
M='(@(B(*"B,Z(&QI8B]3=&]R86=E+W-Q;"YP:'`Z-C0*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O
M;6-A;"YP:'`Z,3,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HU,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4O:V]L86(N<&AP.C,T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R971R:65V92!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$U"B,Z('-C<FEP=',O=7!G<F%D97,O,C`P-"TP
M-2TQ.5]C;VYV97)T7V-A=&5G;W)I97-?=&]?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E5N9FEL960B"FUS9W-T<B`B56ML87-S:69I<V5R="(*"B,Z(&QI8B]A
M<&DN<&AP.C,W-B!L:6(O87!I+G!H<#HT-3`@;&EB+V%P:2YP:'`Z-3$V(&QI
M8B]A<&DN<&AP.C8R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E
M9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$P,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9#H@)7,N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I
M9"`B57-E<B!);G1E<F9A8V4B"FUS9W-T<B`B0G)U:V5R9W)E;G-E<VYI='0B
M"@HC.B!Y96%R+G!H<#HQ-C,@>65A<BYP:'`Z,38Y(&QI8B]";&]C:R]M;VYT
M:"YP:'`Z,34Y(&QI8B]";&]C:R]M;VYT:"YP:'`Z,38R"B,L(&9U>GIY"FUS
M9VED(")6:65W($1A>2(*;7-G<W1R(")6:7,@)7,B"@HC.B!Y96%R+G!H<#HX
M-2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV,2!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHR,C`*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ,#4*
M;7-G:60@(E=E(@IM<V=S='(@(D]N(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C$X('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$Q-PHC.B!T96UP
M;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,`IM<V=I9"`B5V5D;F5S9&%Y
M(@IM<V=S='(@(D]N<V1A9R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$R(&QI8B]+
M<F]N;VQI=&@N<&AP.C$R.3`@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C,*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED(")7965K(@IM<V=S
M='(@(E5K92(*"B,Z(&UO;G1H+G!H<#HQ-SD@=V]R:W=E96LN<&AP.C,P('=E
M96LN<&AP.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E=E96L@)60B"FUS9W-T
M<B`B56ME("5D(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3D@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED(")7965K*',I(@IM<V=S
M='(@(E5K92AE<BDB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C(@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C$U"FUS9VED(")7965K;'DZ(%)E
M8W5R<R!E=F5R>2(*;7-G<W1R(")5:V5N=&QI9SH@4VMJ97(@:'9E<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(B(*(E=H870@=&EM
M92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S(&5N9"P@=VAE;B!T:&5R92!A
M<F4@;F\@;&%T97(@979E;G1S/R(*;7-G<W1R("(B"B)+;&]K:V5S;&5T="!D
M86<M(&]G('5K979I<VEN9V5R('9I<V5S(&9R96T@=&EL+"!O;2!D970@:6MK
M92!E<B!N;V5N('-E;F5R92`B"B)H96YD96QS97(_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D
M87D@86YD('=E96L@=FEE=W,@<W1A<G0L('=H96X@=&AE<F4@87)E(&YO(&5A
M<FQI97(@979E;G1S/R(*;7-G<W1R("(B"B)+;&]K:V5S;&5T="!D86<M(&]G
M('5K979I<VEN9V5R('9I<V5S(&9R82P@;VT@9&5T(&EK:V4@97(@;F]E;B!T
M:61L:6=E<F4@(@HB:&5N9&5L<V5R/R(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$Q
M(&QI8B]+<F]N;VQI=&@N<&AP.C$R.#D@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")7;W)K
M(%=E96LB"FUS9W-T<B`B07)B96ED<W5K92(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C$R.3(@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C4*(RP@9G5Z>GD*
M;7-G:60@(EEE87(B"FUS9W-T<B`B4_AK(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(X('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T,0IM<V=I
M9"`B665A<FQY.B!296-U<G,@979E<GDB"FUS9W-T<B`BQ7)L:6<Z(%-K:F5R
M(&AV97)T(@H*(SH@9&%T82YP:'`Z-#`@9&%T82YP:'`Z,C,T(&5D:71E=F5N
M=&%C=&EO;BYP:'`Z-#8@861D979E;G0N<&AP.C$W"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!E=F5N=',N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z-#D*;7-G
M:60@(EEO=2!A<F4@;F]T(&%N(&%T=&5N9&5E(&]F('1H92!S<&5C:69I960@
M979E;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z-S8*;7-G:60@(EEO=2!C86X@;VYL>2!U<V4@=&AI<R!F;W)M
M(&9R;VT@=&AE($5D:70@071T96YD965S('-C<F5E;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I9W5R
M960@:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO;B`B"B)/<'1I;VYS+B!9
M;W4@;75S="!S970@;VYE("5S:&5R925S(&)E9F]R92!E=F5N="!N;W1I9FEC
M871I;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B"@HC.B!A9&1E=F5N=&%C
M=&EO;BYP:'`Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@861D(&5V96YT<R!T;R`E<RXB"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z,3DT"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R
M;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE8W1E9"!C86QE;F1A
M<BXB"FUS9W-T<B`B(@H*(SH@9&5L979E;G1A8W1I;VXN<&AP.C(V"FUS9VED
M(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!D96QE=&4@=&AI<R!E
M=F5N="XB"FUS9W-T<B`B(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HW.`IM
M<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@961I="!T:&ES
M(&5V96YT+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.#D*;7-G:60@(EEO
M=2!H879E('-P96-I9FEE9"!A;B!I;G9A;&ED(&-A;&5N9&%R+B(*;7-G<W1R
M("(B"@HC.B!A='1E;F0N<&AP.C(Q"FUS9VED(")9;W4@:&%V92!S=6-C97-S
M9G5L;'D@86-C97!T960@871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G
M<W1R("(B"@HC.B!A='1E;F0N<&AP.C(V"FUS9VED(")9;W4@:&%V92!S=6-C
M97-S9G5L;'D@9&5C;&EN960@871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*
M;7-G<W1R("(B"@HC.B!A='1E;F0N<&AP.C,Q"FUS9VED(")9;W4@:&%V92!T
M96YT871I=F5L>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N
M(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.3$*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A(&-A;&5N9&%R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z-30*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DT"FUS9VED(")9;W4@<F5Q
M=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!A9&1E9"!T
M;R!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3$P-`IM<V=I9"`B(@HB66]U(')E<75E<W1E9"!T;R!B92!N;W1I
M9FEE9"!W:&5N(&5V96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD
M87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#DY"FUS
M9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S
M(&%R92!E9&ET960@:6X@>6]U<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]38VAE9'5L97(O:W)O;F]L:71H+G!H<#HR,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!R96UI;F1E9"!A8F]U="`E
M<RP@=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@9&5F875L="!C86QE;F1A<B(*;7-G<W1R(")696QG(&5N(&MA;&5N
M9&5R(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`U,R!L:6(O1')I=F5R+G!H<#HQ
M,#8S"FUS9VED(");56YN86UE9"!E=F5N=%TB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z.3<*(RP@9G5Z>GD*;7-G:60@(E]!;&%R
M;2(*;7-G<W1R(")!;&%R;2(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H
M7V%D=F%N8V5D+FEN8SHQ,0IM<V=I9"`B7T)A<VEC(%-E87)C:"(*;7-G<W1R
M(")3=&%N9&%R9"!S^&LB"@HC.B!V:65W979E;G0N<&AP.C$R,`IM<V=I9"`B
M7T5D:70B"FUS9W-T<B`B4F5D:6=E<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$S,S`*;7-G:60@(E]';W1O(@IM<V=S='(@(D?E('1I;"(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$S,S8*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S
M='(@(DEM<&]R=&5R+T5K<W!O<G1E<B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$S,3@*;7-G:60@(E]->2!#86QE;F1A<G,B"FUS9W-T<B`B36EN92!K86QE
M;F1E<F4B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S(U"FUS9VED(")?3F5W
M($5V96YT(@IM<V=S='(@(DYY(&AE;F1E;'-E(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,T,0IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(E!R:6YT(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,@IM<V=I9"`B7U-E87)C:"(*;7-G<W1R
M(")3^&LB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S(X"FUS9VED(")?5&]D
M87DB"FUS9W-T<B`B22!D86<B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN
M8SHQ-#(*;7-G:60@(F)E9F]R92!T:&4@979E;G0@<W1A<G1S(@IM<V=S='(@
M(F;X<B!H96YD96QS96X@<W1A<G1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G<W1R(")D86<B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C$P"FUS9VED(")D87DH<RDB"FUS9W-T<B`B9&%G*&5R*2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.#8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@X(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B9&%Y<R(*;7-G<W1R(")D86=E<B(*"B,Z(&1A=&$N<&AP.C$T-R!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*(RP@9G5Z>GD*;7-G:60@(F5V96YT
M<RYC<W8B"FUS9W-T<B`B06QL92!H96YD96QS97(B"@HC.B!D871A+G!H<#HQ
M-C@*(RP@9G5Z>GD*;7-G:60@(F5V96YT<RYI8W,B"FUS9W-T<B`B06QL92!H
M96YD96QS97(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$S,0IM<V=I9"`B9G)O;2(*;7-G<W1R(")F<F$B"@HC.B!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V
M"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S,"!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR,S8*;7-G:60@(FUO;G1H*',I(@IM<V=S='(@(FWE;F5D
M*&5R*2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P,C`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(F]N("5S(&%T("5S(@IM<V=S='(@(B5S('-T87)T
M97(@;VT@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C,P"FUS9VED(")O;B!T:&4@<V%M92!D
M871E(@IM<V=S='(@(G#E('-A;6UE(&1A=&\B"@HC.B!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,C8@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,V"FUS
M9VED(")O;B!T:&4@<V%M92!W965K9&%Y(@IM<V=S='(@(G#E('-A;6UE('5K
M92!D86<B"@HC.B!D871A+G!H<#HS,"!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$U"FUS9VED(")V0V%L96YD87(O:4-A;&5N9&%R(@IM<V=S='(@(G9#
M86QE;F1E<B]I0V%L96YD97(B"@HC.B!L:6(O87!I+G!H<#HS-#D@;&EB+V%P
M:2YP:'`Z-C`W"FUS9VED(")V179E;G0@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DQ"FUS9VED(")W965K(@IM
M<V=S='(@(G5K92(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R,B!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHR,3<*;7-G:60@(G=E96LH<RD@;VXZ
M(@IM<V=S='(@(G5K92AR*2!PY3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3DR(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Y-`IM<V=I9"`B=V5E:W,B"FUS9W-T<B`B=6ME<B(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHR-#(*;7-G:60@(GEE87(H<RDB"FUS9W-T<B`BY7(B"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]P;R]S=E]312YP;P``````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S0R-#<`,3`T,3<S
M-C(W-3,`,#(P-#0R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@2W)O;F]L:71H(%-W961I<V@@=')A;G-L871I;VX*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#(M,C`P-B!(;W)D92!0<F]J96-T"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE($MR;VYO;&ET:"!P86-K86=E+@HC($IO87%U:6T@2&]M<FEG:&%U<V5N
M(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/BP@,C`P-BX*(R!!;F1R96%S($1A:&SI
M;B`\86YD<F5A<T!D86AL96XN=W,^+"`R,#`U+@HC"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!+<F]N;VQI=&@@,BXQ7&XB"B)2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,30@,3`Z,#8K,#$P,%QN(@HB
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-"`Q-3HP,"LP,3`P7&XB"B),
M87-T+51R86YS;&%T;W(Z($IO87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E
M8F)P;&%T<V5N+G-E/EQN(@HB3&%N9W5A9V4M5&5A;3H@4W=E9&ES:"`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E
M;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!C86QE;F1A<G,@9F]U;F0B"FUS9W-T<B`B)60@:V%L96YD
M<F%R(&AI='1A9&5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC
M.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@979E;G1S(@IM<V=S='(@(B5D
M(&CD;F1E;'-E<B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!$87DH<RD@)7,@2&]U
M<BAS*2`E<R!-:6YU=&5S(@IM<V=S='(@(B5S(&1A9RAA<BD@)7,@=&EM;2AA
M<BD@)7,@;6EN=70H97(I(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@P-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A='1E;F1E97,B"FUS9W-T<B`B)7,@9&5L
M=&%G87)E(@H*(SH@9&%T82YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(B5S+69I
M;&5N(.1R(&EM<&]R=&5R860B"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O
M8F%S92YP:'`Z,3(X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD
M87(B"FUS9W-T<B`B)7-S(&MA;&5N9&5R(@H*(SH@=&5M<&QA=&5S+V-A;&5N
M9&%R<R]S96%R8V@N:6YC.C$W"FUS9VED("(B"B(H0VQI8VL@;VX@8V%L96YD
M87(@;F%M92!T;R!S=VET8V@@=&AE(&-A;&5N9&%R)W,@=FES:6)I;&ET>2!I
M;B!T:&4@;6%I;B`B"B)W:6YD;W<I(@IM<V=S='(@(B(*(BA+;&EC:V$@<.4@
M:V%L96YD97)N86UN970@9O9R(&%T="#D;F1R82!K86QE;F1E<FYS('-Y;FQI
M9VAE="!I(&AU=G5D9O9N<W1R970I(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ-C4*;7-G:60@(BH@061D('1H97-E(&)Y(&-L:6-K
M:6YG($%D9"`J(@IM<V=S='(@(BH@3.1G9R!T:6QL(&1E;2!HY'(@9V5N;VT@
M871T(&ML:6-K82`G3.1G9R!T:6QL)R`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ-3$*;7-G:60@(BH@4&QE87-E('-E;&5C="!A
M9&1R97-S*&5S*2`J(@IM<V=S='(@(BH@5N1L:B!A9')E<W,H97(I("HB"@HC
M.B!L:6(O1')I=F5R+G!H<#HQ.#`V"FUS9VED("(Q(&%T=&5N9&5E(@IM<V=S
M='(@(C$@9&5L=&%G87)E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N
M:6YC.C0*;7-G:60@(C$@979E;G0B"FUS9W-T<B`B,2!HY&YD96QS92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@(C$@:&]U<B(*;7-G
M<W1R("(Q('1I;6UE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`IM
M<V=I9"`B,34@;6EN=71E<R(*;7-G<W1R("(Q-2!M:6YU=&5R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B,C`@;6EN=71E<R(*;7-G
M<W1R("(R,"!M:6YU=&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-@IM<V=I9"`B,S`@;6EN=71E<R(*;7-G<W1R("(S,"!M:6YU=&5R(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,38Y"FUS9VED("(\<W1R;VYG/D%T
M=&5N9&5E<SPO<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQS=')O;F<^
M1&5L=&%G87)E/"]S=')O;F<^("AV86QF<FDI(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,30W"FUS9VED("(\<W1R;VYG/D1E<V-R:5]P=&EO;CPO
M<W1R;VYG/B`H;W!T:6]N86PI(@IM<V=S='(@(CQS=')O;F<^0F5S:W)I7W9N
M:6YG/"]S=')O;F<^("AV86QF<FDI(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C<T"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^("AO
M<'1I;VYA;"DB"FUS9W-T<B`B/'-T<F]N9SY.>6-K96QO<F0\+W-T<F]N9SX@
M*'9A;&9R:2DB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.3(*;7-G
M:60@(CQS=')O;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H;W!T:6]N86PI(@IM
M<V=S='(@(CQS=')O;F<^57!P<F5P;FEN9SPO<W1R;VYG/B`H=F%L9G)I*2(*
M"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3$S('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,3DS"FUS9VED(")!32(*;7-G<W1R(")!32(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C8P,@IM<V=I9"`B06-C97!T960B"FUS9W-T
M<B`B06-C97!T97)A9"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN
M8SHQ,0IM<V=I9"`B061?=F%N8V5D(%-E87)C:"(*;7-G<W1R(")!7W9A;F-E
M<F%D('/V:VYI;F<B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$V,`IM<V=I9"`B061D(@IM<V=S='(@(DSD9V<@=&EL;"(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:70N:6YC.C(R"FUS9VED(")!9&0@179E;G0B"FUS
M9W-T<B`B3.1G9R!T:6QL(&CD;F1E;'-E(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,S4*;7-G:60@(D%D9"!A(&YE
M=R!296UO=&4@0V%L96YD87(B"FUS9W-T<B`B3.1G9R!T:6QL(&YY(&9JY')R
M:V%L96YD97(B"@HC.B!A9&1E=F5N="YP:'`Z-C0*;7-G:60@(D%D9"!A(&YE
M=R!E=F5N="(*;7-G<W1R("),Y&=G('1I;&P@96X@;GD@:.1N9&5L<V4B"@HC
M.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-S$*;7-G:60@
M(D%D9"!A='1E;F1E97,B"FUS9W-T<B`B3.1G9R!T:6QL(&1E;'1A9V%R92(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@U"FUS9VED
M(")!9&0@=&\@871T96YD965S(@IM<V=S='(@(DSD9V<@=&EL;"!D96QT86=A
M<F4B"@HC.B!C;VYT86-T<RYP:'`Z-S8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ,C@*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC.C<T"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S
M8F]K(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC
M.C@@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C$Q"FUS9VED(")!9'9A
M;F-E9"!396%R8V@B"FUS9W-T<B`B079A;F-E<F%D('/V:VYI;F<B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHU,PIM<V=I9"`B06QA<FTB"FUS9W-T
M<B`B06QA<FTB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@R"B,L('!H<"UF;W)M
M870*;7-G:60@(D%L87)M("5D(&1A>7,@8F5F;W)E(@IM<V=S='(@(D%L87)M
M("5D(&1A9V%R(&EN;F%N(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!H;W5R<R!B969O<F4B"FUS9W-T
M<B`B06QA<FT@)60@=&EM;6%R(&EN;F%N(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E9"!M:6YU=&5S(&)E
M9F]R92(*;7-G<W1R(")!;&%R;2`E9"!M:6YU=&5R(&EN;F%N(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3<W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&%R;2`E
M9"!W965K<R!B969O<F4B"FUS9W-T<B`B06QA<FT@)60@=F5C:V]R(&EN;F%N
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<X,0IM<V=I9"`B06QA<FT@,2!D87D@
M8F5F;W)E(@IM<V=S='(@(D%L87)M(#$@9&%G(&EN;F%N(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3<X-@IM<V=I9"`B06QA<FT@,2!H;W5R(&)E9F]R92(*;7-G
M<W1R(")!;&%R;2`Q('1I;6UA(&EN;F%N(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3<Y,0IM<V=I9"`B06QA<FT@,2!M:6YU=&4@8F5F;W)E(@IM<V=S='(@(D%L
M87)M(#$@;6EN=70@:6YN86XB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S<V"FUS
M9VED(")!;&%R;2`Q('=E96L@8F5F;W)E(@IM<V=S='(@(D%L87)M(#$@=F5C
M:V$@:6YN86XB"@HC.B!D871A+G!H<#HU.0IM<V=I9"`B06QA<FT@1&%T92(*
M;7-G<W1R(")!;&%R;61A='5M(@H*(SH@9&%T82YP:'`Z-3@*;7-G:60@(D%L
M87)M(%-P86X@*&UI;G5T97,I(@IM<V=S='(@(E1I9"!M96QL86X@86QA<FT@
M*&UI;G5T97(I(@H*(SH@9&%T82YP:'`Z-C`*;7-G:60@(D%L87)M(%1I;64B
M"FUS9W-T<B`B06QA<FUT:60B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T
M92YI;F,Z,S0*;7-G:60@(D%L;"(*;7-G<W1R(")!;&QA(@H*(SH@;&EB+T9"
M5FEE=RYP:'`Z,3(X(&QI8B]&0E9I97<N<&AP.C$S,2!L:6(O1D)6:65W+G!H
M<#HQ,S0*;7-G:60@(D%L;"!!='1E;F1E97,B"FUS9W-T<B`B06QL82!D96QT
M86=A<F4B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3D*;7-G
M:60@(D%L;"!&=71U<F4B"FUS9W-T<B`B06QL82!F<F%M=&ED82(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU,PIM<V=I9"`B06QL(%!A<W0B
M"FUS9W-T<B`B06QL82!T:61I9V%R92(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N
M=&AL:7-T+G!H<#HR-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C(T"B,Z(&QI8B]"
M;&]C:R]M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR
M-0IM<V=I9"`B06QL(%9I<VEB;&4B"FUS9W-T<B`B06QL82!S>6YL:6=A(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,3(R(&QI8B]$
M87E6:65W+G!H<#HY,"!L:6(O1&%Y5FEE=RYP:'`Z.3,*(SH@;&EB+U=E96M6
M:65W+G!H<#HQ,C<@;&EB+U=E96M6:65W+G!H<#HQ,S0@;&EB+T1R:79E<BYP
M:'`Z,3@V.0IM<V=I9"`B06QL(&1A>2(*;7-G<W1R(")(96QA(&1A9V5N(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$V-`IM<V=I9"`B06QL(&1A>2!E
M=F5N="(*;7-G<W1R(")(96QD86=S:.1N9&5L<V4B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C,S"FUS9VED(")!;&P@979E;G1S(@IM<V=S='(@
M(D%L;&$@:.1N9&5L<V5R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?
M861V86YC960N:6YC.C0X"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHW,"!L:6(O2W)O;F]L:71H+G!H<#HV.34*;7-G:60@(D%N
M>2(*;7-G<W1R(")V:6QK96X@<V]M(&AE;'-T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9V]T;RYI;F,Z-S$*;7-G:60@(D%P<FEL(@IM<V=S='(@(F%P
M<FEL(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,SD@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHX,B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$V.`IM<V=I9"`B070B"FUS9W-T<B`B2VPB"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,#0V"FUS9VED("(B"B)!='1A8VAE9"!I<R!A;B!I0V%L96YD
M87(@9FEL92!W:71H(&UO<F4@:6YF;W)M871I;VX@86)O=70@=&AE(&5V96YT
M+B!)9B!Y;W5R("(*(FUA:6P@8VQI96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S
M=',@>6]U(&-A;B!U<V4@=&AI<R!F:6QE('1O(&5A<VEL>2!U<&1A=&4@(@HB
M>6]U<B!L;V-A;"!C;W!Y(&]F('1H92!E=F5N="XB"FUS9W-T<B`B(@HB16X@
M:4-A;&5N9&%R+69I;"!M960@;65R(&EN9F]R;6%T:6]N(&]M(&CD;F1E;'-E
M;B!H87(@8FEF;V=A=',N($]M(&1I;B!E+2(*(G!O<W1K;&EE;G0@<W3V9&5R
M(&E4:7`M9O9R9G+E9VYI;F=A<B!SY2!K86X@9'4@86YVY&YD82!D96X@8FEF
M;V=A9&5F:6QE;B!F]G(@(@HB871T(&5N:V5L="!U<'!D871E<F$@9&EN(&QO
M:V%L82!K;W!I82!A=B!HY&YD96QS96XN(@H*(SH@=&5M<&QA=&5S+V%T=&5N
M9&5E<R]A='1E;F1E97,N:6YC.C0R('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$V-0IM<V=I9"`B071T96YD86YC92(*;7-G<W1R(")$96QT86=A;F1E(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,38Q"FUS9VED(")!='1E;F1E
M97,B"FUS9W-T<B`B1&5L=&%G87)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-S4*;7-G:60@(D%U9W5S="(*;7-G<W1R(")A=6=U<W1I
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C$Q
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHX"FUS9VED(")"87-I8R!3
M96%R8V@B"FUS9W-T<B`B4_9K;FEN9R(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP
M:'`N9&ES=#HQ-PIM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B1O9D96QS961A
M9R(*"B,Z('1E;7!L871E<R]F8G9I97<O;&5G96YD+FEN8SHS(&QI8B]&0E9I
M97<N<&AP.CDP(&QI8B]&0E9I97<N<&AP.C$Q,0IM<V=I9"`B0G5S>2(*;7-G
M<W1R(")5<'!T86=E;B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHT,@IM<V=I9"`B0U]A;&5N9&%R(@IM<V=S='(@(DM?86QE
M;F1E<B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C0W"FUS9VED(")#
M86Q?96YD87(B"FUS9W-T<B`B2U]A;&5N9&5R(@H*(SH@=&5M<&QA=&5S+V-A
M;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$T.2!L:6(O0FQO8VLO<')E=FUO;G1H
M;&ES="YP:'`Z,C$*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HR,2!L:6(O0FQO
M8VLO;6]N=&AL:7-T+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*
M;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D-A;&5N9&%R(%-U;6UA<GDB"FUS
M9W-T<B`B2V%L96YD97)S86UM86YF871T;FEN9R(*"B,Z(&1A=&$N<&AP.C(S
M,PIM<V=I9"`B0V%L96YD87(@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS9W-T
M<B`B2V%L96YD97)N(&AA<B!R96YS871S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-PIM
M<V=I9"`B0V%L96YD87)S(@IM<V=S='(@(DMA;&5N9')A<B(*"B,Z(&-A;&5N
M9&%R<RYP:'`Z,C<*;7-G:60@(D-A;&5N9&%R<R!M=7-T(&AA=F4@82!N86UE
M+B(*;7-G<W1R(")+86QE;F1R87(@;>5S=&4@:&$@971T(&YA;6XN(@H*(SH@
M9&%T82YP:'`Z,C0X"FUS9VED(")#86XG="!C<F5A=&4@82!N97<@979E;G0N
M(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(&5N(&YY(&CD;F1E;'-E(@H*(SH@
M=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,S('1E;7!L871E<R]D96QE=&4O
M9&5L971E+FEN8SHS-0HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,2!T
M96UP;&%T97,O961I="]E9&ET+FEN8SHS,#<*;7-G:60@(D-A;F-E;"(*;7-G
M<W1R(")!=F)R>70B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-S@*;7-G:60@
M(D-A;F-E;&QE9"(*;7-G<W1R(")!=F)R=71E;B(*"B,Z(&QI8B]+<F]N;VQI
M=&@N<&AP.C$P,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N8V5L;&5D.B`E
M<R(*;7-G<W1R(")!=F)R=71E;CH@)7,B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:%]A9'9A;F-E9"YI;F,Z-C,@=&5M<&QA=&5S+V5D:70O961I="YI
M;F,Z-C<*;7-G:60@(D-A=&5G;W)?>2(*;7-G<W1R(")+871E9V]R7VDB"@HC
M.B!D871A+G!H<#HV,B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E<G,N
M:6YC.C0@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,*;7-G:60@(D-A=&5G
M;W)Y(@IM<V=S='(@(DMA=&5G;W)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(W.0IM<V=I9"`B(@HB0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO
M=&EF:65D(&]F(&YE=RP@961I=&5D+"!A;F0@9&5L971E9"!E=F5N=',@8GD@
M(@HB96UA:6PZ(@IM<V=S='(@(B(*(E;D;&H@;VT@9'4@=FEL;"!B;&D@:6YF
M;W)M97)A9"!O;2!N>6$L(.1N9')A9&4@96QL97(@<F%D97)A9&4@:.1N9&5L
M<V5R('9I82`B"B)E+7!O<W0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4R"FUS9VED(")#:&]O<V4@:68@>6]U('=A;G0@=&\@8F4@;F]T:69I960@
M;V8@;F5W+"!E9&ET960L(&%N9"!D96QE=&5D(&5V96YT<RXB"FUS9W-T<B`B
M(@HB5N1L:B!O;2!D=2!V:6QL(&)L:2!I;F9O<FUE<F%D(&]M(&YY82P@Y&YD
M<F%D92!E;&QE<B!R861E<F%D92!HY&YD96QS97(@=FEA("(*(F4M<&]S="XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDR"FUS9VED(")#:&]O<V4@
M:68@>6]U('=A;G0@=&\@<F5C96EV92!E;6%I;"!R96UI;F1E<G,@9F]R(&5V
M96YT<R!W:71H(&%L87)M<SHB"FUS9W-T<B`B(@HB5N1L:B!O;2!D=2!V:6QL
M(&)L:2!N;W1I9FEE<F%D(&]M(&YY82P@Y&YD<F%D92!E;&QE<B!R861E<F%D
M92!HY&YD96QS97(@=FEA("(*(F4M<&]S=#HB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V5A<F-H7V%B;V]K7W-E;&5C="YI;F,Z,3D*(SH@=&5M<&QA=&5S+W!R
M969S+W-E87)C:%]A8F]O:RYI;F,Z,3<@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Q,@IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VMS('1O('-E87)C
M:"!F;W(@9G)E92]B=7-Y(%523',Z(@IM<V=S='(@(E;D;&H@861R97-S8F]K
M(&;V<B!S]FMN:6YG(&%V(&QE9&EG+W5P<'1A9V5N(%523#HB"@HC.B!T96UP
M;&%T97,O<')E9G,O9F)?8V%L<U]S96QE8W0N:6YC.C$V"FUS9VED(")#:&]O
M<V4@=&AE(&-A;&5N9&%R<R!T;R!I;F-L=61E(&EN('EO=7(@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N.B(*;7-G<W1R(")6Y&QJ(&1E(&MA;&5N9')A<B!D=2!V
M:6QL(&EN:VQU9&5R82!I(&QI<W1N:6YG(&%V(&QE9&EG+W5P<'1A9V5N.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C0*;7-G:60@(D-H;V]S92!T
M:&4@8V%L96YD87)S('1O(&EN8VQU9&4@=VAE;B!G96YE<F%T:6YG(&9R964O
M8G5S>2!54DQS.B(*;7-G<W1R(")6Y&QJ(&MA;&5N9')A<B!A='0@:6YK;'5D
M97)A(&[D<B!L961I9R]U<'!T86=E;BU54DQE<B!S:V%P87,Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")#:&]O<V4@>6]U<B!D969A
M=6QT(&-A;&5N9&%R+B(*;7-G<W1R(")6Y&QJ(&1I;B!F]G)V86QD82!K86QE
M;F1E<BXB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z
M.#0*;7-G:60@(D-L96%R(&%L;"!A='1E;F1E97,B"FUS9W-T<B`B4F5N<V$@
M86QL82!D96QT86=A<F4B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$X-@IM<V=I9"`B0VQO<V4@=VEN9&]W(@IM<V=S='(@(E-TY&YG
M(&;V;G-T97(B"@HC.B!D871A+G!H<#HR."!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S
M='(@(DMO;6UA<V5P87)E<F%D92!VY')D96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S,*;7-G:60@(D-O;F9I<FT@9&5L971I;VX@;V8@979E;G1S
M/R(*;7-G<W1R(")"96MRY&9T82!R861E<FEN9R!A=B!HY&YD96QS97(_(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3<U"FUS9VED(")#;VYF:7)M960B"FUS
M9W-T<B`B0F5K<N1F=&%D(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C(Q-PIM<V=I9"`B0V]P>2!T:&4@55),(&)E;&]W(&9O<B!U
M<V4@=VAE<F5V97(@>6]U(&YE960@>6]U<B!&<F5E+T)U<WD@55),.B(*;7-G
M<W1R(")+;W!I97)A(&SD;FME;B!N961A;B!NY'(@9'4@8F5H]G9E<B!I;F9R
M;VUA=&EO;B!O;2!L961I9R]U<'!T86=E;CHB"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(DMA;B!I;G1E(/9P<&YA("5S+B(*"B,Z('1E;7!L871E
M<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,CD*;7-G:60@(D-R96%T92(*
M;7-G<W1R(")3:V%P82(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD
M87)S+FEN8SHQ,34*;7-G:60@(D-R96%T92!#86QE;F1A<B(*;7-G<W1R(")3
M:V%P82!K86QE;F1E<B(*"B,Z(&UO;G1H+G!H<#HQ-C,@=&5M<&QA=&5S+W=E
M96LO:&5A9"YI;F,Z,C4@=&5M<&QA=&5S+V1A>2]R;W<N:6YC.C8*(SH@;&EB
M+T1A>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H<#HQ.34*;7-G:60@(D-R
M96%T92!A($YE=R!%=F5N="(*;7-G<W1R(")3:V%P82!E;B!N>2!HY&YD96QS
M92(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C@P"FUS9VED(")#<F5A
M=&5D(@IM<V=S='(@(E-K87!A9"(*"B,Z('1E;7!L871E<R]D96QE=&4O9&5L
M971E+FEN8SHS,@IM<V=I9"`B0W5R<F5N="(*;7-G<W1R(")!:W1U96QL(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$R('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(P-@IM<V=I9"`B1&%I;'DZ(%)E8W5R<R!E=F5R>2(*;7-G
M<W1R(")$86=L:6<Z(%5P<')E<&$@=F%R(@H*(SH@871T96YD965S8V]M;6]N
M+G!H<#HR,"!A='1E;F1E97,N<&AP.C$P-B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,S$Q"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(Q(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,@IM<V=I9"`B1&%Y(@IM<V=S='(@(D1A9R(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C8R('1E;7!L871E<R]E9&ET+V5D:70N
M:6YC.C$S-PIM<V=I9"`B1&%Y*',I(@IM<V=S='(@(D1A9RAA<BDB"@HC.B!V
M:65W979E;G0N<&AP.C$Q,0IM<V=I9"`B1&5?;&5T92(*;7-G<W1R(")?4F%D
M97)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-SD*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E8V5M8F5R(@H*(SH@;&EB+TMR;VYO
M;&ET:"YP:'`Z-C`U"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")!=F+V:G0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<*;7-G:60@(D1E9F%U;'0@
M0V%L96YD87(B"FUS9W-T<B`B1O9R=F%L9"!K86QE;F1E<B(*"B,Z('1E;7!L
M871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,#0@=&5M<&QA=&5S+V1E
M;&5T92]O;F4N:6YC.C,R"B,Z('1E;7!L871E<R]P<F5F<R]R96UO=&5?8V%L
M7VUA;F%G96UE;G0N:6YC.C(S(&QI8B]$<FEV97(N<&AP.C$X-3`*;7-G:60@
M(D1E;&5T92(*;7-G<W1R(")2861E<F$B"@HC.B!D96QE=F5N="YP:'`Z-#`@
M=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(Q('1E;7!L871E<R]D96QE=&4O
M9&5L971E+FEN8SHR,0HC.B!L:6(O1')I=F5R+G!H<#HQ.#0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92`E<R(*;7-G<W1R(")2861E<F$@)7,B"@HC
M.B!E9&ET979E;G0N<&AP.C<R"FUS9VED(")$96QE=&4@179E;G0B"FUS9W-T
M<B`B4F%D97)A(&CD;F1E;'-E(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE
M=&4N:6YC.C,P"FUS9VED("(B"B)$96QE=&4@=&AE(&-U<G)E;G0@979E;G0@
M;VYL>2P@=&AI<R!O8V-U<G)E;F-E(&%N9"!A;&P@9G5T=7)E(&]C8W5R96YC
M97,L(&]R("(*(F%L;"!O8V-U<F5N8V5S/R(*;7-G<W1R("(B"B)2861E<F$@
M96YB87)T(&%K='5E;&P@:.1N9&5L<V4L(&%K='5E;&P@<V%M="!F<F%M=&ED
M82!F]G)E:V]M<W1E<B!E;&QE<B!A;&QA("(*(F;V<F5K;VUS=&5R/R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,#,@=&5M
M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC.C(X"FUS9VED(")$97-C<FE?<'1I
M;VXB"FUS9W-T<B`B7T)E<VMR:79N:6YG(@H*(SH@9&%T82YP:'`Z-C$@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W.`HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHY-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B0F5S:W)I=FYI;F<B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$W-`IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")6:7-A(@H*(SH@
M=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8S"FUS9VED(")$
M:7-P;&%Y($-A;&5N9&%R<R(*;7-G<W1R(")6:7-A(&MA;&5N9')A<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@*;7-G:60@(D1I<W!L87D@
M3W!T:6]N<R(*;7-G<W1R(")6:7-N:6YG<VEN<W3D;&QN:6YG87(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1O('EO=2!W86YT('1O
M('-H;W<@=&%S:W,@=VAI8V@@87)E(&1U92!O;B!Y;W5R(&-A;&5N9&%R/R(*
M;7-G<W1R(")6:6QL(&1U('9I<V$@=7!P9VEF=&5R('-O;2#D<B!K;&%R82!I
M(&1I;B!K86QE;F1E<C\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#4*;7-G
M:60@(D1O97,@;F]T(')E8W5R(@IM<V=S='(@(E5P<')E<&%S(&EN=&4B"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1'5E.B`E<R(*;7-G<W1R(")+;&%R.B`E<R(*"B,Z('1E;7!L871E<R]E9&ET
M+V5D:71?=&EM97-P86XN:6YC.C$Q-0IM<V=I9"`B1'5R871I;VXB"FUS9W-T
M<B`B5F%R86MT:6=H970B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N
M9&%R<RYI;F,Z,3<S(&QI8B]$<FEV97(N<&AP.C$X,S8*;7-G:60@(D5D:70B
M"FUS9W-T<B`BQ&YD<F$B"@HC.B!E9&ET979E;G0N<&AP.C,S('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(R(&QI8B]$<FEV97(N<&AP.C$X,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="`E<R(*;7-G<W1R("+$;F1R82`E<R(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$X-0IM<V=I9"`B161I="!!='1E
M;F1E97,B"FUS9W-T<B`BQ&YD<F$@9&5L=&%G87)E(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$T,PIM<V=I9"`B161I="!#86QE
M;F1A<G,B"FUS9W-T<B`B4F5D:6=E<F$@:V%L96YD<F%R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(U,`IM<V=I9"`B161I="!296UO=&4@0V%L96YD
M87)S(@IM<V=S='(@(L1N9')A(&9JY')R:V%L96YD<F%R(@H*(SH@871T96YD
M965S+G!H<#HQ-#8*;7-G:60@(D5D:70@871T96YD965S(@IM<V=S='(@(L1N
M9')A(&1E;'1A9V%R92(*"B,Z('1E;7!L871E<R]C871E9V]R>5]L96=E;F0N
M:6YC.C(P"FUS9VED(")%9&ET(&-A=&5G;W)I97,@86YD(&-O;&]R<R(*;7-G
M<W1R("+$;F1R82!K871E9V]R:65R(&]C:"!FY')G97(B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W-R!T96UP;&%T97,O871T96YD
M965S+V%T=&5N9&5E<RYI;F,Z-#$*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,38T"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D4M<&]S=&%D
M<F5S<R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C8P
M"FUS9VED(")%;E]D(@IM<V=S='(@(E-L=70B"@HC.B!D871A+G!H<#HU-@IM
M<V=I9"`B16YD($1A=&4B"FUS9W-T<B`B4VQU=&1A='5M(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHX('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(P
M"FUS9VED(")%;F0@3VXB"FUS9W-T<B`B4VQU=&$@9&5N(@H*(SH@9&%T82YP
M:'`Z-3<*;7-G:60@(D5N9"!4:6UE(@IM<V=S='(@(E-L=71T:60B"@HC.B!A
M='1E;F1E97-C;VUM;VXN<&AP.C,T(&%T=&5N9&5E<V-O;6UO;BYP:'`Z-#4@
M871T96YD965S8V]M;6]N+G!H<#HU,@HC.B!A='1E;F1E97,N<&AP.C$R,"!A
M='1E;F1E97,N<&AP.C$S,2!A='1E;F1E97,N<&AP.C$S.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!R971R:65V:6YG(&9R964O8G5S>2!I;F9O<FUA
M=&EO;B!F;W(@)7,Z("5S(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A(&EN9F]R
M;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N(&;V<B`E<SH@)7,B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,3$S"FUS9VED(")%=F5N="!A9&1E9#HB"FUS9W-T
M<B`B2.1N9&5L<V4@<VMA<&%D.B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q
M,C,*;7-G:60@(D5V96YT(&1E;&5T960Z(@IM<V=S='(@(DCD;F1E;'-E(')A
M9&5R860Z(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$Q.`IM<V=I9"`B179E
M;G0@961I=&5D.B(*;7-G<W1R(")(Y&YD96QS92#D;F1R860Z(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3`W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%=F5N="!F
M<F]M("5S('1O("5S(@IM<V=S='(@(DCD;F1E;'-E(&9RY6X@)7,@=&EL;"`E
M<R(*"B,Z(&QI8B]$<FEV97(O<W%L+G!H<#HS-S,*;7-G:60@(D5V96YT(&YO
M="!F;W5N9"(*;7-G<W1R(")(Y&YD96QS96X@:&ET=&%D97,@:6YT92(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C<W,`IM<V=I9"`B179E;G1S(&UU<W0@:&%V92!A
M('-T87)T(&1A=&4N(@IM<V=S='(@(DCD;F1E;'-E<B!MY7-T92!H82!E='0@
M<W1A<G1D871U;2XB"@HC.B!L:6(O1')I=F5R+G!H<#HW,S8*;7-G:60@(D5V
M96YT<R!M=7-T(&AA=F4@82!T:71L92XB"FUS9W-T<B`B2.1N9&5L<V5R(&WE
M<W1E(&AA(&5N(')U8G)I:RXB"@HC.B!T96UP;&%T97,O871T96YD965S+V%T
M=&5N9&5E<RYI;F,Z-S4*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R(")%
M>'!A;F1E<F$@;F%M;B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3DY"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T97)A(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHX"FUS9VED(")%>'!O<G0@0V%L96YD
M87(B"FUS9W-T<B`B17AP;W)T97)A(&MA;&5N9&5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-CD*;7-G:60@(D9E8G)U87)Y(@IM<V=S
M='(@(F9E8G)U87)I(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ,S,*;7-G:60@(D9I;F0B"FUS9W-T<B`B4_9K(@H*(SH@>65A<BYP
M:'`Z.#0@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C,@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C$Y"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,3`U"FUS9VED(")&<B(*;7-G<W1R(")&<B(*"B,Z(&QI8B]+<F]N;VQI=&@N
M<&AP.C4X,0IM<V=I9"`B1G)E92(*;7-G<W1R("),961I9R(*"B,Z(&%T=&5N
M9&5E<W9I97<N<&AP.C$Y"FUS9VED(")&<F5E+T)U<WDB"FUS9W-T<B`B3&5D
M:6<O57!P=&%G96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@*;7-G
M:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("),961I9R]5<'!T
M86=E;BUI;F9O<FUA=&EO;B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN
M8SHR,"!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3D*(SH@=&5M<&QA=&5S
M+V5D:70O:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@(D9R:61A>2(*;7-G<W1R
M(")&<F5D86<B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z,S,*
M;7-G:60@(D9U='5R92(*;7-G<W1R(")&<F%M=&ED82(*"B,Z(&-O;F9I9R]K
M97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B1V%M92(*;7-G<W1R(")3<&5L
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C(S
M"FUS9VED(")'96YE<F%L(@IM<V=S='(@(D%L;&WD;B(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V]T;R`E
M<R(*;7-G<W1R(")'Y2!T:6QL("5S(@H*(SH@;6]N=&@N<&AP.C$S,R!T96UP
M;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA
M=&5S+V1A>2]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*;7-G:60@(DAI9&4B
M"FUS9W-T<B`B1_9M(@H*(SH@;6]N=&@N<&AP.C$S,R!T96UP;&%T97,O=V5E
M:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA=&5S+V1A>2]H
M96%D7W-I9&5?8GE?<VED92YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&ED92`E<R(*;7-G<W1R(")']FT@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHV-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S8*;7-G:60@
M(DAO=7(H<RDB"FUS9W-T<B`B5&EM;2]E+V%R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,PIM<V=I9"`B2&]W(&QO;F<@<VAO=6QD('1H92!T:6UE
M('-L;W1S(&]N('1H92!D87D@86YD('=E96L@=FEE=W,@8F4_(@IM<V=S='(@
M(DAU<B!LY6YG82!S:V%L;"!T:61P;W-T97)N82!V87)A(&D@9&4@9&%G;&EG
M82!O8V@@=F5C:V]V:7-A('9Y97)N83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S`Q"FUS9VED(")(;W<@;6%N>2!D87ES(&]F(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!S:&]U;&0@=V4@9V5N97)A=&4_(@IM<V=S='(@(B(*(D;V
M<B!H=7(@;>5N9V$@9&%G87(@9G)A;>5T('9I;&P@9'4@9V5N97)E<F$@;&5D
M:6<M+W5P<'1A9V5N:6YF;W)M871I;VX_(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3`U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B))9B!Y;W5R(&5M86EL
M(&-L:65N="!D;V5S;B=T('-U<'!O<G0@:51I<"!R97%U97-T<R!Y;W4@8V%N
M('5S92!O;F4@;V8@=&AE("(*(F9O;&QO=VEN9R!L:6YK<R!T;R!A8V-E<'0@
M;W(@9&5C;&EN92!T:&4@979E;G0N7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@
M979E;G0Z7&XB"B(E<UQN(@HB7&XB"B)4;R!A8V-E<'0@=&AE(&5V96YT('1E
M;G1A=&EV96QY.EQN(@HB)7-<;B(*(EQN(@HB5&\@9&5C;&EN92!T:&4@979E
M;G0Z7&XB"B(E<R(*;7-G<W1R("(B"B)/;2!D:6X@92UP;W-T:VQI96YT(&EN
M=&4@<W3V9&5R(&E4:7`L('/E(&MA;B!D=2!A;G;D;F1A(&5N(&%V(&;V;&IA
M;F1E("(*(FSD;FMA<B!A='0@86-C97!E=&5R82!E;&QE<B!A=F+V:F$@:.1N
M9&5L<V5N+EQN(@HB1O9R(&%T="!A8V-E<'1E<F$Z7&XB"B(E<UQN(@HB1O9R
M(&%T="!P<F5L:6UI;N1R="!A8V-E<'1E<F$Z7&XB"B(E<UQN(@HB1O9R(&%T
M="!A=F+V:F$Z7&XB"B(E<R(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@0V%L96YD87(L(%-T
M97`@)60B"FUS9W-T<B`B26UP;W)T97)A(&MA;&5N9&5R+"!S=&5G("5D(@H*
M(SH@9&%T82YP:'`Z,C@X"FUS9VED("));7!O<G0O17AP;W)T($-A;&5N9&%R
M(@IM<V=S='(@(DEM<&]R=&5R82]%>'!O<G1E<F$@:V%L96YD97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHV.`IM<V=I9"`B2F%N=6%R
M>2(*;7-G<W1R(")J86YU87)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-S0*;7-G:60@(DIU;'DB"FUS9W-T<B`B:G5L:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<S"FUS9VED(")*=6YE(@IM
M<V=S='(@(FIU;FDB"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ-#(*;7-G:60@(DME>7=O<F1S(@IM<V=S='(@(DYY8VME;&]R
M9"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-0IM<V=I9"`B
M3&%S="`R-"!H;W5R<R(*;7-G<W1R(")396YA<W1E(#(T('1I;6UA<FYA(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#<*;7-G:60@(DQA<W0@36]D
M:69I960B"FUS9W-T<B`B4V5N87-T(.1N9')A9"(*"B,Z('1E;7!L871E<R]M
M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z-`HC.B!T96UP;&%T97,O;6]N
M=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$P"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,38@=&5M<&QA=&5S+VUO;G1H+VAE
M860N:6YC.C0*;7-G:60@(DQA<W0@36]N=&@B"FUS9W-T<B`B1O9R<F$@;>5N
M861E;B(*"B,Z('1E;7!L871E<R]Y96%R+VAE860N:6YC.C0*;7-G:60@(DQA
M<W0@665A<B(*;7-G<W1R(")&]G)R82#E<F5T(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C4T('1E;7!L871E<R]W965K+VAE860N:6YC.C,*
M;7-G:60@(DQA<W0@=V5E:R(*;7-G<W1R(")&]G)R82!V96-K86XB"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Y"FUS9VED("),:6UI="!T:&4@
M=&EM92!S<&%N('1O(&5X<&]R=#HB"FUS9W-T<B`B0F5G<N1N<V$@=&ED<W-P
M86YN970@9O9R(&5X<&]R=&5N.B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H7V%D=F%N8V5D+FEN8SHX-2!T96UP;&%T97,O961I="]E9&ET+FEN8SHW
M-`IM<V=I9"`B3&]?8V%T:6]N(@IM<V=S='(@(E]0;&%T<R(*"B,Z(&1A=&$N
M<&AP.C8S('1E;7!L871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-0HC
M.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHQ
M.`HC.B!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN
M8SHU,B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHR,0HC.B!L:6(O1')I=F5R
M+G!H<#HQ.#@V"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")0;&%T<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-0IM<V=I9"`B36%N86=E(')E;6]T
M92!C86QE;F1A<G,N(@IM<V=S='(@(DAA;G1E<F$@9FKD<G)K86QE;F1R87(N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S`*;7-G:60@
M(DUA<F-H(@IM<V=S='(@(FUA<G,B"@HC.B!L:6(O87!I+G!H<#HQ,#`*;7-G
M:60@(DUA>&EM=6T@3G5M8F5R(&]F($5V96YT<R(*;7-G<W1R(")-87@@86YT
M86P@:.1N9&5L<V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI
M;F,Z-S(*;7-G:60@(DUA>2(*;7-G<W1R(")M86HB"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ.#@S"FUS9VED(")-92(*;7-G<W1R(")*86<B"@HC.B!C;VYF:6<O
M:V5Y=V]R9',N<&AP+F1I<W0Z,3<*;7-G:60@(DUE971I;F<B"FUS9W-T<B`B
M3?9T92(*"B,Z(&QI8B]";&]C:R]T<F5E7V%L87)M<RYP:'`Z,PIM<V=I9"`B
M365N=2!!;&%R;7,B"FUS9W-T<B`B365N>6%L87)M(@H*(SH@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,PIM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(DUE
M;GEL:7-T82(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C8X('1E;7!L
M871E<R]E9&ET+V5D:70N:6YC.C$S-0IM<V=I9"`B36EN=71E*',I(@IM<V=S
M='(@(DUI;G5T*&5R*2(*"B,Z('EE87(N<&AP.C@P('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C4Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q
M-0HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B36\B"FUS9W-T
M<B`B3>4B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,38@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3$U"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S
M8W)I<'0N:6YC.C8X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*;7-G:60@
M(DUO;F1A>2(*;7-G<W1R(")-Y6YD86<B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,S$T(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-0IM<V=I9"`B36]N=&@B"FUS9W-T<B`B3>5N860B"@HC
M.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C,*;7-G:60@(DUO;G1H(%9I97<B"FUS
M9W-T<B`B3>5N861S=GDB"@HC.B!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HS
M(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C0S"FUS9VED(")-;VYT:&QY($5V
M96YT<R!,:7-T(@IM<V=S='(@(DWE;F%T;&EG82!HY&YD96QS97(B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR,S(*;7-G:60@(DUO;G1H;'DZ(%)E8W5R
M<R!E=F5R>2(*;7-G<W1R(")-;VYA=&QI9SH@57!P<F5P82!V87(B"@HC.B!L
M:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HR-`IM<V=I9"`B36]N=&AS($%H96%D
M(@IM<V=S='(@(DWE;F%D97(@9G)A;>5T(@H*(SH@;&EB+T)L;V-K+W!R979M
M;VYT:&QI<W0N<&AP.C(T"FUS9VED(")-;VYT:',@0F5F;W)E(@IM<V=S='(@
M(DWE;F%D97(@=&ED:6=A<F4B"@HC.B!L:6(O87!I+G!H<#HV,S0*;7-G:60@
M(DUU;'1I<&QE(&E#86QE;F1A<B!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N
M92!V179E;G0@:7,@<W5P<&]R=&5D+B(*;7-G<W1R(")&;&5R82!I0V%L9&5N
M97(M9&5L87(@:&ET=&%D97,[(&5N8F%R="!E;B!V179E;G0@<W3V9',N(@H*
M(SH@8V%L96YD87)S+G!H<#HQ,C@@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.C<P"FUS9VED(")->2!#86QE;F1A<G,B"FUS9W-T<B`B36EN
M82!K86QE;F1R87(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,S0@=&5M<&QA
M=&5S+VUE;G4N:6YC.C,V('1E;7!L871E<R]M96YU+VUE;G4N:6YC.C8R"FUS
M9VED(")->2!#86QE;F1A<G,Z(@IM<V=S='(@(DUI;F$@:V%L96YD<F%R.B(*
M"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHR,3,*;7-G
M:60@(DUY($9R964O0G5S>2!54DPB"FUS9W-T<B`B36EN(&QE9&EG+W5P<'1A
M9V5N+5523"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ,C`@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$V,@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$W-@HC.B!T96UP
M;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHQ-PHC.B!T
M96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHT-`IM
M<V=I9"`B3F%M92(*;7-G<W1R(").86UN(@H*(SH@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HT,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HT-"!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z-#$*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C`*
M;7-G:60@(DYE=R!%=F5N="(*;7-G<W1R(").>2!HY&YD96QS92(*"B,Z(&QI
M8B]B87-E+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB3F5W(&-A
M;&5N9&%R(&-R96%T960@86YD(&%U=&]M871I8V%L;'D@<VAA<F5D('=I=&@@
M9F]L;&]W:6YG(&=R;W5P*',I.B`E<RXB"FUS9W-T<B`B3GD@:V%L96YD97(@
M<VMA<&%D(&]C:"!A=71O;6%T:7-K="!D96QA9"!M960@9O9L:F%N9&4@9W)U
M<'`H97(I.B`E<RXB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,S
M"FUS9VED(").97AT(@IM<V=S='(@(D[D<W1A(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C4W"FUS9VED(").97AT(#(T(&AO=7)S(@IM<V=S
M='(@(D[D<W1A(#(T('1I;6UA<B(*"B,Z(&QI8B]&0E9I97<O9&%Y+G!H<#HR
M.0IM<V=I9"`B3F5X="!$87DB"FUS9W-T<B`B3N1S=&$@9&%G(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHV"B,Z('1E;7!L
M871E<R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,Z,3(*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ."!T96UP;&%T97,O
M;6]N=&@O:&5A9"YI;F,Z-@IM<V=I9"`B3F5X="!-;VYT:"(*;7-G<W1R(").
MY'-T82!MY6YA9"(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,S(*;7-G:60@
M(DYE>'0@5V5E:R(*;7-G<W1R(").Y'-T82!V96-K82(*"B,Z('1E;7!L871E
M<R]Y96%R+VAE860N:6YC.C8*;7-G:60@(DYE>'0@665A<B(*;7-G<W1R(").
MY'-T82#E<B(*"B,Z('1E;7!L871E<R]D87DO:&5A9"YI;F,Z-0IM<V=I9"`B
M3F5X="!D87DB"FUS9W-T<B`B3N1S=&$@9&%G(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:6YC.C4X('1E;7!L871E<R]W965K+VAE860N:6YC.C4*
M;7-G:60@(DYE>'0@=V5E:R(*;7-G<W1R(").Y'-T82!V96-K82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S4@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(X.`IM<V=I9"`B3F\B"FUS9W-T<B`B3F5J(@H*(SH@=&5M<&QA=&5S+V9B
M=FEE=R]L96=E;F0N:6YC.C<*;7-G:60@(DYO($EN9F]R;6%T:6]N(@IM<V=S
M='(@(DEN9V5N(&EN9F]R;6%T:6]N(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-S,@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,3(T"FUS9VED(").
M;R!A;&%R;2(*;7-G<W1R("));F=E="!A;&%R;2(*"B,Z('1E;7!L871E<R]A
M='1E;F1E97,O871T96YD965S+FEN8SHT.`IM<V=I9"`B3F\@871T96YD965S
M(@IM<V=S='(@(DEN9V$@9&5L=&%G87)E(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3,S,`IM<V=I9"`B3F\@8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@
M9W5E<W1S+B(*;7-G<W1R("));F=A(&MA;&5N9')A<B!T:6QL9^1N9VQI9V$@
M9O9R(&?D<W1E<BXB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S8@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C4R"FUS9VED(").;R!E;F0@9&%T
M92(*;7-G<W1R("));F=E="!S;'5T9&%T=6TB"@HC.B!L:6(O0FQO8VLO<')E
M=FUO;G1H;&ES="YP:'`Z,38T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP.C$V
M,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3DT"FUS9VED(").;R!E=F5N
M=',@=&\@9&ES<&QA>2(*;7-G<W1R("));F=A(&CD;F1E;'-E<B!A='0@=FES
M82(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!F<F5E+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE
M(&9O<B`E<R(*;7-G<W1R("));F=E;B!I;F9O<FUA=&EO;B!O;2!L961I9R]U
M<'!T86=E;B!T:6QL9^1N9VQI9R!F]G(@)7,B"@HC.B!L:6(O87!I+G!H<#HS
M-#4@;&EB+V%P:2YP:'`Z-C(T"FUS9VED(").;R!I0V%L96YD87(@9&%T82!W
M87,@9F]U;F0N(@IM<V=S='(@(FE#86QE;F1A<B!I;F9O<FUA=&EO;B!S86MN
M87,N(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C`Q"FUS9VED(").
M;R!R96-U<G)E;F-E(@IM<V=S='(@(DEN9V5N('5P<')E<&YI;F<B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HY,#(*;7-G:60@(DYO('9A;&ED(&5M86EL(&%D
M9')E<W,@9F]U;F0B"FUS9W-T<B`B1V]D:^1N9"!E+7!O<W1A9')E<W,@<V%K
M;F%S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8Q,B!L:6(O2W)O;F]L:71H
M+G!H<#HV,S,*;7-G:60@(DYO;F4B"FUS9W-T<B`B26YG96XB"@HC.B!L:6(O
M4W1O<F%G92]S<6PN<&AP.C$T-0IM<V=I9"`B3F]T(&9O=6YD(@IM<V=S='(@
M(DAI='1A9&5S(&EN=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*
M;7-G:60@(DYO=&EF:6-A=&EO;G,B"FUS9W-T<B`B3F]T:69I97)I;F=A<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<X"FUS9VED(").
M;W9E;6)E<B(*;7-G<W1R(")N;W9E;6)E<B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FEN8SHU-@IM<V=I9"`B3F]W(@IM<V=S='(@(DYU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S<*;7-G:60@(D]C=&]B
M97(B"FUS9W-T<B`B;VMT;V)E<B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C$S('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C8U"FUS9VED(")/;B(*;7-G<W1R(")$96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C<X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3$*;7-G
M:60@(D]N(&%L;"!C86QE;F1A<G,@22!H879E(')E860@86-C97-S('1O(@IM
M<V=S='(@(D;V<B!A;&QA(&MA;&5N9&5R87(@<V]M(&IA9R!H87(@;.1S8F5H
M]G)I9VAE="!T:6QL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDP"FUS9VED(")/;B!A;&P@<VAO=VX@
M8V%L96YD87)S(@IM<V=S='(@(D;V<B!A;&QA('9I<V%D92!K86QE;F1R87(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR.#D*;7-G:60@(D]N(&UY(&-A;&5N9&%R<R!O;FQY(@IM<V=S
M='(@(D5N8F%R="!F]G(@;6EN82!K86QE;F1R87(B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HV,S`*;7-G:60@(D]P=&EO;F%L(@IM<V=S='(@(E9A;&9R:2(*
M"B,Z(&QI8B]&0E9I97<N<&AP.C$Q.0IM<V=I9"`B3W!T:6]N86P@071T96YD
M965S(@IM<V=S='(@(D5J(&]B;&EG871O<FES:V$@9&5L=&%G87)E(@H*(SH@
M;&EB+T9"5FEE=RYP:'`Z,34T"FUS9VED(")/=F5R=FEE=R(*;7-G<W1R("+6
M=F5R<VEK="(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C,T"FUS9VED
M(")/=VYE<B(*;7-G<W1R("+$9V%R92(*"B,Z(&QI8B]$<FEV97(N<&AP.C$X
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W=N97(Z("5S(@IM<V=S='(@(L1G
M87)E.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3$T('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3DT"FUS9VED(")032(*;7-G<W1R
M(")032(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HS(&QI8B]"
M;&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HT,@IM<V=I9"`B4&%S="!%=F5N=',@
M3&ES="(*;7-G<W1R(")&]G)F;'5T;F$@:.1N9&5L<V5R(@H*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3`Y('1E;7!L871E<R]E9&ET+V5D:70N:6YC
M.C$Y-@IM<V=I9"`B4&%T=&5R;B(*;7-G<W1R(")-]FYS=&5R(@H*(SH@=&5M
M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,P"FUS9VED(")097)M86YE;G1L>2!D
M96QE=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`B4F%D97)A(&CD;F1E;'-E;B!P
M97)M86YE;G0_(@H*(SH@;&EB+V%P:2YP:'`Z,S(V(&QI8B]A<&DN<&AP.C0R
M,B!L:6(O87!I+G!H<#HT.30@;&EB+V%P:2YP:'`Z-3<T"B,Z(&QI8B]A<&DN
M<&AP.C8P-B!L:6(O87!I+G!H<#HV.3(@;&EB+V%P:2YP:'`Z-S(X"FUS9VED
M(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("+%=&MO;7-T(&YE:V%D(@H*
M(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$W,`IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B0F5H]G)I9VAE=&5R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q"FUS9VED(")0;W)T86P@3W!T:6]N<R(*
M;7-G<W1R(")0;W)T86QI;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+V9B
M=FEE=R]L96=E;F0N:6YC.C4*;7-G:60@(E!O<W-I8FQE($UE971I;F<@5&EM
M92(*;7-G<W1R(")-]FIL:6<@;?9T97-T:60B"@HC.B!L:6(O1D)6:65W+V1A
M>2YP:'`Z,C4*;7-G:60@(E!R979I;W5S($1A>2(*;7-G<W1R(")&]G)E9^5E
M;F1E(&1A9R(*"B,Z(&QI8B]&0E9I97<O=V5E:RYP:'`Z,C8*;7-G:60@(E!R
M979I;W5S(%=E96LB"FUS9W-T<B`B1O9R96?E96YD92!V96-K82(*"B,Z('1E
M;7!L871E<R]D87DO:&5A9"YI;F,Z,PIM<V=I9"`B4')E=FEO=7,@9&%Y(@IM
M<V=S='(@(D;V<F5GY65N9&4@9&%G(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z,3,U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(T.0IM<V=I9"`B
M4F5C=7(@56YT:6PB"FUS9W-T<B`B57!P<F5P82!T:6QL<R(*"B,Z('1E;7!L
M871E<R]V:65W+W9I97<N:6YC.C$P-@IM<V=I9"`B4F5C=7)R96YC92(*;7-G
M<W1R(")5<'!R97!N:6YG(@H*(SH@9&%T82YP:'`Z-C@*;7-G:60@(E)E8W5R
M<F5N8V4@1&%T82(*;7-G<W1R("));F9O<FUA=&EO;B!O;2!U<'!R97!N:6YG
M(@H*(SH@9&%T82YP:'`Z-C8*;7-G:60@(E)E8W5R<F5N8V4@16YD($1A=&4B
M"FUS9W-T<B`B4VQU=&1A='5M(&;V<B!U<'!R97!N:6YG(@H*(SH@9&%T82YP
M:'`Z-C<*;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`B26YT
M97)V86QL(&;V<B!U<'!R97!N:6YG(@H*(SH@9&%T82YP:'`Z-C4*;7-G:60@
M(E)E8W5R<F5N8V4@5'EP92(*;7-G<W1R(")4>7`@878@=7!P<F5P;FEN9R(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4T.`IM<V=I9"`B4F5C=7)S(&1A:6QY
M(@IM<V=S='(@(D1A9VQI9R!U<'!R97!N:6YG(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z-34U"FUS9VED(")296-U<G,@;6]N=&AL>2(*;7-G<W1R(")-Y6YA
M=&QI9R!U<'!R97!N:6YG(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-34Q"FUS
M9VED(")296-U<G,@=V5E:VQY(@IM<V=S='(@(E9E8VMO=FES('5P<')E<&YI
M;F<B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-3@*;7-G:60@(E)E8W5R<R!Y
M96%R;'DB"FUS9W-T<B`BQ7)L:6<@=7!P<F5P;FEN9R(*"B,Z(&QI8B]38VAE
M9'5L97(O:W)O;F]L:71H+G!H<#HR,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M:6YD97(Z("5S(@IM<V=S='(@(E#E;6EN;F5L<V4Z("5S(@H*(SH@=&5M
M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.CDT(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-`IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R
M(")&:N1R<FMA;&5N9')A<B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHV,"!T
M96UP;&%T97,O;65N=2YI;F,Z-C(@=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z
M-S0*;7-G:60@(E)E;6]T92!#86QE;F1A<G,Z(@IM<V=S='(@(D9JY')R:V%L
M96YD<F%R.B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ.30*;7-G:60@(E)E;6]T92!3=6)S8W)I<'1I;VX@55),(@IM<V=S='(@
M(E!R96YU;65R871I;VYS861R97-S("A54DPI(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C$*;7-G:60@(E)E;6]V92(*;7-G<W1R
M(")482!B;W)T(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N
M:6YC.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92`E<R(*;7-G<W1R
M(")482!B;W)T("5S(@H*(SH@871T96YD965S:&%N9&QE<BYP:'`Z,S0@871T
M96YD965S+G!H<#HQ,#`*;7-G:60@(E)E;6]V92!!='1E;F1E92(*;7-G<W1R
M(")482!B;W)T(&1E;'1A9V%R92(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,S$*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@8V%L96YD87(@
M=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@
M(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@8V%L96YD
M87(N/"]S=')O;F<^(@IM<V=S='(@(B(*(D5R<^1T="!B969I;G1L:6<@:V%L
M96YD97(@;65D(&1E;B!I;7!O<G1E<F%D93\@/'-T<F]N9SY687)N:6YG.B!!
M;&QA('!O<W1E<B`B"B)I(&%K='5E;&P@:V%L96YD97(@:V]M;65R(&%T="!R
M861E<F%S+CPO<W1R;VYG/B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C8S-PIM
M<V=I9"`B4F5Q=6ER960B"FUS9W-T<B`B3V)L:6=A=&]R:7-K="(*"B,Z(&QI
M8B]&0E9I97<N<&AP.CDX(&QI8B]&0E9I97<N<&AP.C$S.2!L:6(O1D)6:65W
M+G!H<#HQ-#(@;&EB+T9"5FEE=RYP:'`Z,30U"FUS9VED(")297%U:7)E9"!!
M='1E;F1E97,B"FUS9W-T<B`B3V)L:6=A=&]R:7-K82!D96QT86=A<F4B"@HC
M.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHS,#@*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@
M(L5T97)S=.1L;"!T:6QL(&=R=6YD:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L
M871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,R!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ-C8*;7-G:60@(E)E<W!O;G-E(@IM<V=S='(@(E-V87(B
M"@HC.B!Y96%R+G!H<#HX-2!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHV-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C`*(SH@;&EB+T)L;V-K
M+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E-A(@IM<V=S='(@(DSV(@H*(SH@=&5M
M<&QA=&5S+VUO;G1H+VAE860N:6YC.C(Q('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$R,`HC.B!T96UP;&%T97,O961I="]J879A<V-R:7!T+FEN8SHW,PIM
M<V=I9"`B4V%T=7)D87DB"FUS9W-T<B`B3/9R9&%G(@H*(SH@=&5M<&QA=&5S
M+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C(P,PIM<V=I9"`B4V%V92(*;7-G
M<W1R(")3<&%R82(*"B,Z('9I97=E=F5N="YP:'`Z,3,S(&5D:71E=F5N="YP
M:'`Z-#D@961I=&5V96YT+G!H<#HU-PIM<V=I9"`B4V%V92!!<R!.97<B"FUS
M9W-T<B`B4W!A<F$@<V]M(&YY(@H*(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A
M='1E;F1E97,N:6YC.C@S"FUS9VED(")3879E($%T=&5N9&5E<R(*;7-G<W1R
M(")3<&%R82!D96QT86=A<F4B"@HC.B!A9&1E=F5N="YP:'`Z-34@961I=&5V
M96YT+G!H<#HU,@IM<V=I9"`B4V%V92!%=F5N="(*;7-G<W1R(")3<&%R82(*
M"B,Z('-E87)C:"YP:'`Z.3$@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V
M86YC960N:6YC.C$Q-`HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z
M-C<@=&5M<&QA=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C@*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-#4@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,C8*;7-G:60@(E-E87)C:"(*;7-G<W1R(")3]FLB"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,0IM<V=I9"`B4V5A<F-H
M($-A;&5N9&%R<R(*;7-G<W1R(")3]FL@:V%L96YD<F%R(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C8*;7-G:60@(E-E87)C:"!297-U;'1S
M(@IM<V=S='(@(E/V:W)E<W5L=&%T(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]S96%R8V@N:6YC.C8*;7-G:60@(E-E87)C:"!F;W(@8V%L96YD87)S(&-O
M;G1A:6YI;F<Z(@IM<V=S='(@(E/V:R!F]G(@:V%L96YD<F%R('-O;2!I;FYE
M:.5L;&5R.B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN
M8SHQ-3,*;7-G:60@(E-E;&5C="!A(&-A;&5N9&%R('1O(&5D:70B"FUS9W-T
M<B`B5N1L:B!K86QE;F1E<B!S;VT@<VMA;&P@<F5D:6=E<F%S(@H*(SH@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C8U('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P
M86XN:6YC.C@S"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E;D;&H@
M971T(&1A='5M(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"FUS9VED(")3
M96QE8W0@8V%L96YD87)S('1O(&1I<W!L87DZ(@IM<V=S='(@(E9I<V$@:V%L
M96YD<F%R.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B
M(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@9&ES<&QA
M>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@(@HB9&5F875L="!V
M:65W+B(*;7-G<W1R("(B"B)6Y&QJ(&EN<W3D;&QN:6YG87(@9O9R(&)E:W+D
M9G1E;'-E<B!O8V@@:'5R('9Y97(@<VMA;&P@=FES87,@<V%M="!F]G)V86QD
M('9Y+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3@*;7-G:60@
M(E-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.B(*;7-G<W1R(")6
MY&QJ(&MA;&5N9&5R(&%T="!I;7!O<G1E<F$@=&EL;#HB"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$Y"FUS9VED(")396QE8W0@=&AE(&-A;&5N
M9&%R*',I('1O(&5X<&]R="!F<F]M(@IM<V=S='(@(E;D;&H@:V%L96YD97(O
M:V%L96YD<F%R(&%T="!E>'!O<G1E<F$@9G+E;CHB"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F
M;W)M870Z(@IM<V=S='(@(E;D;&H@97AP;W)T9F]R;6%T.B(*"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,C<*;7-G:60@(E-E;&5C="!T:&4@9FEL
M92!T;R!I;7!O<G0Z(@IM<V=S='(@(E;D;&H@9FEL('-O;2!S:V%L;"!I;7!O
M<G1E<F%S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@
M(E-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3HB"FUS9W-T<B`B5N1L:B!F]G)S
M=&$@=F5C:V]D86=E;CHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z(@IM<V=S='(@(E;D;&H@9F]R;6%T('#E(&EM<&]R=&9I;&5N.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#0*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!S<&%N('1O('-H;W<Z(@IM<V=S='(@(E;D;&H@=&ED<VEN=&5R=F%L
M;"!S;VT@<VMA;&P@=FES87,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@V"FUS9VED(")396QE8W0@=&AE('9I97<@=&\@9&ES<&QA>2!O;B!S=&%R
M='5P.B(*;7-G<W1R(")6Y&QJ('9Y('-O;2!V:7-A<R!V:60@<W1A<G0Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R"FUS9VED(")396QE8W0@=VAI
M8V@@979E;G1S('1O('-H;W<@:6X@=&AE('!O<G1A;"XB"FUS9W-T<B`B5N1L
M:B!V:6QK82!HY&YD96QS97(@<V]M('-K86QL('9I<V%S(&D@<&]R=&%L96XN
M(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(W('1E;7!L871E<R]D
M96QE=&4O9&5L971E+FEN8SHR-PIM<V=I9"`B4V5N9"!A(&-A;F-E;"!N;W1I
M9FEC871I;VX@=&\@86QL(&%T=&5N9&5E<R!W:&5N(&1E;&5T:6YG('1H:7,@
M979E;G0B"FUS9W-T<B`B(@HB4VMI8VMA(&5N(&%N;G5L97)I;F=S;F]T:69I
M97)I;F<@=&EL;"!A;&QA(&1E;'1A9V%R92!NY'(@:.1N9&5L<V5N(')A9&5R
M87,B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V5N9"!A;B!E;6%I;"!T;R`E<R(*;7-G<W1R(")3:VEC
M:V$@;65D9&5L86YD92!T:6QL("5S(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,3<Y"FUS9VED(")396YD('5P9&%T97,O:6YV:71A=&EO;G,@=&\@
M86QL(&%T=&5N9&5E<R!W:&5N('-A=FEN9R!T:&ES(&5V96YT(@IM<V=S='(@
M(B(*(E-K:6-K82!U<'!D871E<FEN9R]I;F)J=61N:6YG87(@=&EL;"!A;&QA
M(&1E;'1A9V%R92!NY'(@:.1N9&5L<V5N('-P87)A<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C<V"FUS9VED(")397!T96UB97(B"FUS
M9W-T<B`B<V5P=&5M8F5R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE
M<W!A;BYI;F,Z.#,*;7-G:60@(E-E="!E;F0@9&%T92(*;7-G<W1R(")!;F=E
M('-L=71D871U;2(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V-0IM
M<V=I9"`B4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T<B`B06YG92!S
M;'5T9&%T=6T@9O9R('5P<')E<&YI;F<B"@HC.B!T96UP;&%T97,O961I="]E
M9&ET7W1I;65S<&%N+FEN8SHS,0IM<V=I9"`B4V5T('-T87)T(&1A=&4B"FUS
M9W-T<B`B06YG92!S=&%R=&1A='5M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Y"FUS9VED("(B"B)3970@>6]U<B!F<F5E+V)U<WD@8V%L96YD87)S
M(&%N9"!Y;W5R(&]W;B!A;F0@;W1H97(@=7-E<G,G(&9R964O8G5S>2!O<'1I
M;VYS+B(*;7-G<W1R(")!;F=E(&1I;F$@;V-H(&%N9')A<R!I;G-TY&QL;FEN
M9V%R(&;V<B!L961I9R]U<'!T86=E;BXB"@HC.B!C86QE;F1A<G,N<&AP.C<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H87)E(&YO="!F;W5N9#H@)7,B"FUS
M9W-T<B`B571D96QN:6YG('-A:VYA<SH@)7,B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z.#(*;7-G:60@(E-H87)E9"!#86QE;F1A
M<G,B"FUS9W-T<B`B1&5L861E(&MA;&5N9')A<B(*"B,Z('1E;7!L871E<R]M
M96YU+FEN8SHT-R!T96UP;&%T97,O;65N=2YI;F,Z-#D@=&5M<&QA=&5S+VUE
M;G4O;65N=2YI;F,Z-C@*;7-G:60@(E-H87)E9"!#86QE;F1A<G,Z(@IM<V=S
M='(@(D1E;&%D92!K86QE;F1R87(Z(@H*(SH@8V%L96YD87)?<V5A<F-H+G!H
M<#HR-2!T96UP;&%T97,O=V5E:R]H96%D7W-I9&5?8GE?<VED92YI;F,Z,PHC
M.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN8SHS"FUS9VED
M(")3:&]W($-A;&5N9&%R(@IM<V=S='(@(E9I<V$@:V%L96YD97(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34V"FUS9VED(")3:&]W(&-A=&5G;W)Y
M(&QE9V5N9#\B"FUS9W-T<B`B5FES82!F]G)K;&%R:6YG(&;V<B!K871E9V]R
M:65R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(E-H
M;W<@9&5L971E+"!A;&%R;2P@86YD(')E8W5R<F5N8V4@:6-O;G,@:6X@8V%L
M96YD87(@=FEE=W,_(@IM<V=S='(@(E9I<V$@:6MO;F5R(&;V<B!R861E<F$L
M(&%L87)M(&]C:"#E=&5R:V]M;6%N9&4@:2!K86QE;F1E<G9Y97(_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B4VAO=R!D=64@=&%S
M:W,@:6X@=&AE(&-A;&5N9&%R/R(*;7-G<W1R(")6:7-A(&;V<F9A;&QN82!U
M<'!G:69T97(@:2!K86QE;F1E<FX_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$V-@IM<V=I9"`B4VAO=R!F<F5E+V)U<WD@;&5G96YD/R(*;7-G<W1R
M(")6:7-A(&;V<FML87)I;F<@9O9R(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P
M<'1A9V5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#,*;7-G:60@
M(E-H;W<@;VYL>2!E=F5N=',@=&AA="!H879E(&%N(&%L87)M('-E=#\B"FUS
M9W-T<B`B5FES82!E;F)A<G0@:.1N9&5L<V5R(&UE9"!A;&%R;3\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<U"FUS9VED(")3:&]W('-H87)E9"!C
M86QE;F1A<G,@<VED92UB>2US:61E/R(*;7-G<W1R(")6:7-A(&1E;&%D92!K
M86QE;F1R87(@<VED82!V:60@<VED83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C(Q"FUS9VED(")3:&]W('1A<VMS('5S:6YG(&-A=&5G;W)Y(&-O
M;&]R<S\B"FUS9W-T<B`B5FES82!U<'!G:69T97(@;65D(&MA=&5G;W)I9N1R
M9V5R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-0IM<V=I9"`B4VAO
M=R!T:6UE(&]F(&1A>2!B971W965N(&5A8V@@9&%Y(&EN('=E96L@=FEE=W,_
M(@IM<V=S='(@(E9I<V$@:VQO8VMS;&%G(&UE;&QA;B!V87)J92!D86<@:2!V
M96-K;W9Y/R(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC
M.C$Q"FUS9VED(")3=&%?<G0B"FUS9W-T<B`B4W1A7W)T82!D96XB"@HC.B!D
M871A+G!H<#HU-`IM<V=I9"`B4W1A<G0@1&%T92(*;7-G<W1R(")3=&%R=&1A
M='5M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8SHW
M('1E;7!L871E<R]V:65W+W9I97<N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,S<*;7-G:60@(E-T87)T($]N(@IM<V=S='(@(E-T87)T
M82!D96XB"@HC.B!D871A+G!H<#HU-0IM<V=I9"`B4W1A<G0@5&EM92(*;7-G
M<W1R(")3=&%R='1I9"(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHY-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHX,PIM<V=I
M9"`B4W1A=%]U<R(*;7-G<W1R(")3=&%T7W5S(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]E=F5N=%]H96%D97)S+FEN8SHV('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C(W"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A='5S(@H*(SH@>65A
M<BYP:'`Z-S@@>65A<BYP:'`Z.#<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T
M;RYI;F,Z-C4*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(Q(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,3`W(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`Y"FUS
M9VED(")3=2(*;7-G<W1R(")3]B(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D
M+FEN8SHQ-"!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,C,*(SH@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3(Q('1E;7!L871E<R]E9&ET+VIA=F%S8W)I
M<'0N:6YC.C8W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4*;7-G:60@
M(E-U;F1A>2(*;7-G<W1R(")3]FYD86<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,CD*;7-G:60@(E1A<VMS(@IM<V=S='(@(E5P<&=I9G1E<B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C4X-2!L:6(O2W)O;F]L:71H+G!H<#HV,#@*
M;7-G:60@(E1E;G1A=&EV92(*;7-G<W1R(")0<F5L:6UI;N1R(@H*(SH@>65A
M<BYP:'`Z.#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C(@=&5M
M<&QA=&5S+V5D:70O961I="YI;F,Z,C$X"B,Z(&QI8B]";&]C:R]M;VYT:"YP
M:'`Z,3`U"FUS9VED(")4:"(*;7-G<W1R(")4;R(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z-S`*;7-G:60@(E1H92!%9&ET($%T=&5N
M9&5E<R!S8W)E96X@:7,@;F\@;&]N9V5R('!R97-E;G0N($5X:71I;F<N(@IM
M<V=S='(@(E9Y;B!F]G(@<F5D:6=E<FEN9R!A=B!D96QT86=A<F4@Y'(@:6YT
M92!T:6QL9^1N9VQI9R!LY&YG<F4N($%V<VQU=&%R+B(*"B,Z(&-A;&5N9&%R
M<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB
M)7-<(B!C86YN;W0@8F4@9&5L971E9"XB"FUS9W-T<B`B2V%L96YD97(@)R5S
M)R!K=6YD92!I;G1E(')A9&5R87,N(@H*(SH@8V%L96YD87)S+G!H<#HT,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B
M965N(&-R96%T960N(@IM<V=S='(@(DMA;&5N9&5R("<E<R<@<VMA<&%D97,N
M(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(DMA;&5N9&5R("<E<R<@<F%D97)A9&5S+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z
M-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H
M87,@8F5E;B!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B3F%M;F5T('#E
M(&MA;&5N9&5R("<E<R<@:&%R(.1N9')A=',@=&EL;"`G)7,G+B(*"B,Z(&-A
M;&5N9&%R<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N
M9&%R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B2V%L96YD97)N
M("<E<R<@<W!A<F%D97,N(@H*(SH@9&%T82YP:'`Z,C,Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!C86QE;F1A<B!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E
M<R(*;7-G<W1R(")+86QE;F1E<B`G)7,G(&MU;F1E(&EN=&4@<F5N<V%S+B(*
M"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C$V,PIM<V=I9"`B
M5&AE(&5N9"!D871E(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A<G0@9&%T
M92XB"FUS9W-T<B`B4VQU=&1A='5M(&WE<W1E('9A<F$@<V5N87)E(.1N('-T
M87)T9&%T=6TB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,3$T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!E=F5N="!<(B5S7"(@:&%S(&)E96X@861D
M960@=&\@7"(E<UPB(&-A;&5N9&%R+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB
M"FUS9W-T<B`B2.1N9&5L<V4@)R5S)R!H87(@<VMA<&%T<R!I(&MA;&5N9&5R
M;B`E<RP@9&5N("5S(&ML("5S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$Q
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&5V96YT(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D(&9R;VT@7"(E<UPB(&-A;&5N9&%R+"!W:&EC:"!W
M87,@;VX@)7,@870@)2(*(G,N(@IM<V=S='(@(DCD;F1E;'-E("<E<R<@:&%R
M(')A9&5R871S(&9RY6X@)7,L(&1E;B`E<R!K;"`E<RXB"@HC.B!L:6(O2W)O
M;F]L:71H+G!H<#HQ,3$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!E
M=F5N="!<(B5S7"(@:&%S(&)E96X@961I=&5D(&]N(%PB)7-<(B!C86QE;F1A
M<BP@=VAI8V@@:7,@;VX@)7,@870@)7,N(@IM<V=S='(@(DCD;F1E;'-E("<E
M<R<@*"5S*2!H87(@Y&YD<F%T<SL@:.1N9&5L<V5N(.1R(&1E;B`E<R!K;"`E
M<RXB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#@W"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S('-U8V-E
M<W-F=6QL>2!S96YT+B(*;7-G<W1R(")(Y&YD96QS96YO=&EF:65R:6YG('1I
M;&P@)7,@:&%R('-K:6-K871S+B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P
M-#0*;7-G:60@(E1H92!F;VQL;W=I;F<@:7,@82!M;W)E(&1E=&%I;&5D(&1E
M<V-R:7!T:6]N(&]F('1H92!E=F5N=#HB"FUS9W-T<B`B1O9L:F%N9&4@Y'(@
M96X@;65R(&1E=&%L:F5R860@8F5S:W)I=FEN9R!A=B!HY&YD96QS96XZ(@H*
M(SH@871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E<W0@=V%S(&EN
M8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N96-E<W-A<GD@
M=&\@86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E(&UI<W-I;F<N
M(@IM<V=S='(@(B(*(D)E9^1R86X@Y'(@:6YT92!K;VUP;&5T="X@3N5G<F$@
M<&%R86UE=')A<B!S;VT@:W+D=G,@9O9R(&%T="!A8V-E<'1E<F$@96QL97(@
M(@HB879B]FIA('-A:VYA<RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+V5M<'1Y
M+FEN8SHS"FUS9VED(")4:&5R92!A<F4@;F\@979E;G1S(&UA=&-H:6YG('1H
M92!C=7)R96YT(&-R:71E<FEA+B(*;7-G<W1R("));F=A(&CD;F1E;'-E<B!M
M871C:&%R(&%K='5E;&QT('5R=F%L+B(*"B,Z(&%D9&5V96YT86-T:6]N+G!H
M<#HQ."!E9&ET979E;G1A8W1I;VXN<&AP.C,U"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R
M.B`E<R(*;7-G<W1R(")&96P@=FED(.5T:V]M<W0@878@:V%L96YD97)N.B`E
M<R(*"B,Z(&%D9&5V96YT86-T:6]N+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N=#H@)7,B
M"FUS9W-T<B`B1&5T('5P<'-T;V0@9F5L('9I9"!T:6QLY&=G(&%V(&CD;F1E
M;'-E;CH@)7,B"@HC.B!E9&ET979E;G1A8W1I;VXN<&AP.C@S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!E9&ET:6YG('1H92!E
M=F5N=#H@)7,B"FUS9W-T<B`B1&5T('5P<'-T;V0@9F5L('9I9"!R961I9V5R
M:6YG(&%V(&CD;F1E;'-E;CH@)7,B"@HC.B!L:6(O87!I+G!H<#HS,SD@;&EB
M+V%P:2YP:'`Z-C$X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B1F5L('9I9"!I;7!O
M<G0@878@:4-A;&5N9&%R(&1A=&$N(@H*(SH@961I=&5V96YT86-T:6]N+G!H
M<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M;6]V:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`B1&5T('5P<'-T;V0@9F5L
M('9I9"!F;'ET="!A=B!HY&YD96QS93H@)7,N(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,Z("5S
M(@IM<V=S='(@(D1E="!U<'!S=&]D(&9E;"!V:60@<^1N9&YI;F<@878@;F]T
M:69I97)I;F<@=&EL;"`E<SH@)7,B"@HC.B!D871A+G!H<#HQ,#@*;7-G:60@
M(E1H97)E('=E<F4@;F\@979E;G1S('1O(&5X<&]R="XB"FUS9W-T<B`B26YG
M82!HY&YD96QS97(@871T(&5X<&]R=&5R82XB"@HC.B!D871A+G!H<#HQ.#<*
M;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B1FEL9F]R;6%T970@<W3V9',@:6YT92XB"@HC.B!D871A+G!H<#HR
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@)7,B"FUS9W-T<B`B4V5R=F5R;B!S=F%R861E.B`E<R(*"B,Z
M('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ.2!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,3@*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z
M-S$*;7-G:60@(E1H=7)S9&%Y(@IM<V=S='(@(E1O<G-D86<B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S<*;7-G:60@(E1I;64@4W!?86XB
M"FUS9W-T<B`B5&ED<W-P7V%N;B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:71?
M=&EM97-P86XN:6YC.C0*;7-G:60@(E1I;64@<W!A;B(*;7-G<W1R(")4:61S
M<W!A;FXB"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI
M;F,Z,S0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,S@*;7-G:60@(E1I=%]L
M92(*;7-G<W1R(")4:71E7VPB"@HC.B!D871A+G!H<#HU,R!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YI;F,Z,C`*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N
M=%]H96%D97)S+FEN8SHS"FUS9VED(")4:71L92(*;7-G<W1R(")4:71E;"(*
M"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C(@;&EB+T)L;V-K
M+VUO;G1H;&ES="YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M,C<*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DED86<B"@HC.B!L:6(O0FQO8VLO
M<')E=FUO;G1H;&ES="YP:'`Z,3(T(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C$R,PHC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3(Y"FUS9VED(")4;VUO
M<G)O=R(*;7-G<W1R("));6]R9V]N(@H*(SH@>65A<BYP:'`Z.#$@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C`@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C$V"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`U"FUS9VED(")4
M=2(*;7-G<W1R(")4:2(*"B,Z('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ
M-R!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,38*(SH@=&5M<&QA=&5S+V5D
M:70O:F%V87-C<FEP="YI;F,Z-CD*;7-G:60@(E1U97-D87DB"FUS9W-T<B`B
M5&ES9&%G(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W"FUS9VED
M(")4>7!E(@IM<V=S='(@(E1Y<"(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8SHQ.#8*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC
M.B!L:6(O4W1O<F%G92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT
M82!344PM<V5R=F5R+B(*"B,Z(&-A;&5N9&%R<RYP:'`Z.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S(@IM<V=S
M='(@(DMA;B!I;G1E(')A9&5R82`G)7,G.B`E<R(*"B,Z(&QI8B]$<FEV97(O
M;6-A;"YP:'`Z,3,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)7,N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82`G)7,G+B(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B2V%N
M(&EN=&4@;&%D9&$@9&5F:6YI=&EO;F5N(&%V("5S+B(*"B,Z(&-A;&5N9&%R
M<RYP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!<(B5S7"(Z("5S(@IM<V=S='(@(DMA;B!I;G1E(&)Y=&$@;F%M;B!PY2`G
M)7,G.B`E<R(*"B,Z(&QI8B]3=&]R86=E+VMO;&%B+G!H<#HS.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N(&9O<B`E<R(*;7-G<W1R(")+86X@:6YT92!HY&UT82!I;F9O
M<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;B!F]G(@)7,B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ-2!S8W)I<'1S+V-O;G9E<G1?8V%T96=O<FEE
M<RYP:'`Z-3,*(SH@<V-R:7!T<R]U<&=R861E<R\R,#`T+3`U+3$Y7V-O;G9E
M<G1?8V%T96=O<FEE<U]T;U]S=')I;F=S+G!H<#HU,PIM<V=I9"`B56YF:6QE
M9"(*;7-G<W1R(")%:B!K871E9V]R:7-E<F%D(@H*(SH@;&EB+V%P:2YP:'`Z
M,S<W(&QI8B]A<&DN<&AP.C0V,2!L:6(O87!I+G!H<#HU,S<@;&EB+V%P:2YP
M:'`Z-C0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E
M;G0M5'EP93H@)7,B"FUS9W-T<B`B0V]N=&5N="U4>7!E('-T]F1S(&EN=&4Z
M("5S(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`S-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&5D.B`E<RXB"FUS9W-T<B`B57!P9&%T97)A9#H@)7,N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"FUS9VED(")5<V5R($EN
M=&5R9F%C92(*;7-G<W1R(")!;G;D;F1A<F=RY&YS<VYI='0B"@HC.B!Y96%R
M+G!H<#HQ-C`@>65A<BYP:'`Z,38V(&QI8B]";&]C:R]M;VYT:"YP:'`Z,34Y
M(&QI8B]";&]C:R]M;VYT:"YP:'`Z,38R"FUS9VED(")6:65W($1A>2(*;7-G
M<W1R(")6:7-A(&1A9R(*"B,Z('EE87(N<&AP.C@R('1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC.C8Q('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q
M-PHC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5V4B"FUS9W-T
M<B`B3VXB"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3@@=&5M<&QA
M=&5S+W9I97<O=FEE=RYI;F,Z,3$W"B,Z('1E;7!L871E<R]E9&ET+VIA=F%S
M8W)I<'0N:6YC.C<P"FUS9VED(")7961N97-D87DB"FUS9W-T<B`B3VYS9&%G
M(@H*(SH@871T96YD965S8V]M;6]N+G!H<#HR,B!A='1E;F1E97,N<&AP.C$P
M."!L:6(O2W)O;F]L:71H+G!H<#HQ,S$S"B,Z(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C(S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B5V5E
M:R(*;7-G<W1R(")696-K82(*"B,Z(&UO;G1H+G!H<#HQ-S<@=V]R:W=E96LN
M<&AP.C,P('=E96LN<&AP.C,T"B,L('!H<"UF;W)M870*;7-G:60@(E=E96L@
M)60B"FUS9W-T<B`B5F5C:V$@)60B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHU.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,S@*;7-G:60@(E=E
M96LH<RDB"FUS9W-T<B`B5F5C:R]A+V]R(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(R('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q,@IM<V=I
M9"`B5V5E:VQY.B!296-U<G,@979E<GDB"FUS9W-T<B`B5F5C:V]V:7,Z(%5P
M<')E<&$@=F%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I
M9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@96YD
M+"!W:&5N('1H97)E(&%R92!N;R!L871E<B!E=F5N=',_(@IM<V=S='(@(B(*
M(E#E('9I;&ME;B!T:60@<VMA;&P@9&%G+2!O8V@@=F5C:V]V>65R('-L=71A
M(&[D<B!D970@:6YT92!F:6YN<R!NY6=R82!S96YA<F4@(@HB:.1N9&5L<V5R
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(B(*(E=H
M870@=&EM92!S:&]U;&0@9&%Y(&%N9"!W965K('9I97=S('-T87)T+"!W:&5N
M('1H97)E(&%R92!N;R!E87)L:65R(&5V96YT<S\B"FUS9W-T<B`B(@HB4.4@
M=FEL:V5N('1I9"!S:V%L;"!D86<M(&]C:"!V96-K;W9Y97(@<W1A<G1A(&[D
M<B!D970@:6YT92!F:6YN<R!NY6=R82`B"B)T:61I9V%R92!HY&YD96QS97(_
M(@H*(SH@871T96YD965S8V]M;6]N+G!H<#HR,2!A='1E;F1E97,N<&AP.C$P
M-R!L:6(O2W)O;F]L:71H+G!H<#HQ,S$R"B,Z(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C(R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B5V]R
M:R!7965K(@IM<V=S='(@(D%R8F5T<W9E8VMA(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3,Q-2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-0IM<V=I9"`B
M665A<B(*;7-G<W1R("+%<B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S@*;7-G:60@(EEE87)L
M>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(L5R;&EG.B!5<'!R97!A('9A<FIE
M(@H*(SH@9&%T82YP:'`Z,SD@9&%T82YP:'`Z,C,Y(&5D:71E=F5N=&%C=&EO
M;BYP:'`Z-#8@861D979E;G0N<&AP.C$W"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!E
M=F5N=',N(@IM<V=S='(@(D1U(&;E<B!I;G1E('-K87!A(&9L97(@Y&X@)60@
M:.1N9&5L<V5R+B(*"B,Z(&%T=&5N9"YP:'`Z-#D*;7-G:60@(EEO=2!A<F4@
M;F]T(&%N(&%T=&5N9&5E(&]F('1H92!S<&5C:69I960@979E;G0N(@IM<V=S
M='(@(D1U(.1R(&EN=&4@96X@9&5L=&%G87)E('1I;&P@:.1N9&5L<V5N+B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z-S8*;7-G:60@
M(EEO=2!C86X@;VYL>2!U<V4@=&AI<R!F;W)M(&9R;VT@=&AE($5D:70@071T
M96YD965S('-C<F5E;BXB"FUS9W-T<B`B1'4@:V%N(&5N9&%S="!A;G;D;F1A
M(&1E="!HY'(@9F]R;75LY')E="!F<N5N('9Y;B#D;F1R82!D96QT86=A<F4N
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z.3@X"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=2!D;R!N;W0@:&%V92!A;B!E;6%I;"!A9&1R97-S(&-O;F9I
M9W5R960@:6X@>6]U<B!097)S;VYA;"!);F9O<FUA=&EO;B`B"B)/<'1I;VYS
M+B!9;W4@;75S="!S970@;VYE("5S:&5R925S(&)E9F]R92!E=F5N="!N;W1I
M9FEC871I;VYS(&-A;B!B92!S96YT+B(*;7-G<W1R("(B"B)$=2!H87(@:6YG
M96X@92UP;W-T861R97-S(&MO;F9I9W5R97)A9"!I(&1I;F$@:6YS=.1L;&YI
M;F=A<BX@1'4@;>5S=&4@86YG92`B"B)E;B`E<VCD<B5S(&EN;F%N(&YO=&EF
M:65R:6YG87(@:V%N('-K:6-K87,N(@H*(SH@861D979E;G1A8W1I;VXN<&AP
M.C(P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M
M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N(@IM<V=S='(@(D1U(&AA<B!I
M;G1E(&)E:/9R:6=H970@871T(&SD9V=A('1I;&P@:.1N9&5L<V5R('1I;&P@
M)7,N(@H*(SH@9&%T82YP:'`Z,3DW"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H92!S96QE8W1E9"!C86QE
M;F1A<BXB"FUS9W-T<B`B1'4@:&%R(&EN=&4@8F5H]G)I9VAE="!A='0@;.1G
M9V$@=&EL;"!HY&YD96QS97(@=&EL;"!A:W1U96QL(&MA;&5N9&5R+B(*"B,Z
M(&1E;&5V96YT86-T:6]N+G!H<#HR-@IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@9&5L971E('1H:7,@979E;G0N(@IM<V=S='(@(D1U
M(&AA<B!I;G1E(&)E:/9R:6=H970@871T(')A9&5R82!A:W1U96QL(&CD;F1E
M;'-E+B(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z-S@*;7-G:60@(EEO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="XB"FUS
M9W-T<B`B1'4@:&%R(&EN=&4@8F5H]G)I9VAE="!A='0@<F5D:6=E<F$@86MT
M=65L;"!HY&YD96QS92XB"@HC.B!D871A+G!H<#HQ.3(*;7-G:60@(EEO=2!H
M879E('-P96-I9FEE9"!A;B!I;G9A;&ED(&-A;&5N9&%R+B(*;7-G<W1R(")$
M=2!H87(@86YG:79I="!E;B!F96QA:W1I9R!K86QE;F1E<BXB"@HC.B!A='1E
M;F0N<&AP.C(Q"FUS9VED(")9;W4@:&%V92!S=6-C97-S9G5L;'D@86-C97!T
M960@871T96YD96YC92!T;R!T:&ES(&5V96YT+B(*;7-G<W1R(")$=2!H87(@
M86-C97!T97)A="!D96QT86=A;F1E('1I;&P@:.1N9&5L<V5N+B(*"B,Z(&%T
M=&5N9"YP:'`Z,C8*;7-G:60@(EEO=2!H879E('-U8V-E<W-F=6QL>2!D96-L
M:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(D1U(&AA
M<B!A=F+V:G0@9&5L=&%G86YD92!T:6QL(&CD;F1E;'-E;BXB"@HC.B!A='1E
M;F0N<&AP.C,Q"FUS9VED(")9;W4@:&%V92!T96YT871I=F5L>2!A8V-E<'1E
M9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N(@IM<V=S='(@(D1U(&AA<B!P
M<F5L:6UI;N1R="!A8V-E<'1E<F%T(&1E;'1A9V%N9&4@=&EL;"!HY&YD96QS
M96XN(@H*(SH@8V%L96YD87)S+G!H<#HY,0IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B1'4@;>5S
M=&4@86YG92!E;B!K86QE;F1E<B!S;VT@<VMA;&P@<F%D97)A<RXB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C4T"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B1'4@;>5S
M=&4@86YG92!E;B!A9')E<W,@9O9R<W0N(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3$Q-`IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE9"!W
M:&5N(&5V96YT<R!A<F4@861D960@=&\@>6]U<B!C86QE;F1A<G,N(@IM<V=S
M='(@(D1U(&)E9^1R9&4@;F]T:69I97)I;F<@;N1R(&CD;F1E;'-E<B!L861E
M<R!T:6QL(&D@9&EN82!K86QE;F1R87(N(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z,3$R-`IM<V=I9"`B(@HB66]U(')E<75E<W1E9"!T;R!B92!N;W1I9FEE
M9"!W:&5N(&5V96YT<R!A<F4@9&5L971E9"!F<F]M('EO=7(@8V%L96YD87)S
M+B(*;7-G<W1R(")$=2!B96?D<F1E(&YO=&EF:65R:6YG(&[D<B!HY&YD96QS
M97(@<F%D97)A9&5S(&9RY6X@9&EN82!K86QE;F1R87(N(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3$Q.0IM<V=I9"`B66]U(')E<75E<W1E9"!T;R!B92!N
M;W1I9FEE9"!W:&5N(&5V96YT<R!A<F4@961I=&5D(&EN('EO=7(@8V%L96YD
M87)S+B(*;7-G<W1R(")$=2!B96?D<F1E(&YO=&EF:65R:6YG(&[D<B!HY&YD
M96QS97(@Y&YD<F%D97,@:2!D:6YA(&MA;&5N9')A<BXB"@HC.B!L:6(O4V-H
M961U;&5R+VMR;VYO;&ET:"YP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!R97%U97-T960@=&\@8F4@<F5M:6YD960@86)O=70@)7,L('=H:6-H
M(&ES(&]N("5S(&%T("5S+B(*;7-G<W1R(")$=2!B96?D<F1E(&%T="!B;&D@
M<.5M:6YD(&]M("5S+"!S;VT@Y'(@9&5N("5S(&ML("5S+B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S:&%R97-E;&5C="YI;F,Z,3`*;7-G:60@(EEO=7(@9&5F
M875L="!C86QE;F1A<B(*;7-G<W1R(")$:6X@9O9R=F%L9&$@:V%L96YD97(B
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#8Q(&QI8B]$<FEV97(N<&AP.C$P-S$*
M;7-G:60@(EM5;FYA;65D(&5V96YT72(*;7-G<W1R(");3F%M;FSV<R!HY&YD
M96QS95TB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHY-0IM<V=I9"`B
M7T%L87)M(@IM<V=S='(@(D%L87)M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8VA?861V86YC960N:6YC.C$Q"FUS9VED(")?0F%S:6,@4V5A<F-H(@IM
M<V=S='(@(D5N:V5L('/V:VYI;F<B"@HC.B!V:65W979E;G0N<&AP.C$S-0IM
M<V=I9"`B7T5D:70B"FUS9W-T<B`BQ&YD<F$B"@HC.B!T96UP;&%T97,O;65N
M=2]M96YU+FEN8SHQ-B!L:6(O2W)O;F]L:71H+G!H<#HQ,S4P"FUS9VED(")?
M1V]T;R(*;7-G<W1R(")?1^4@=&EL;"(*"B,Z('1E;7!L871E<R]M96YU+VUE
M;G4N:6YC.C(W(&QI8B]+<F]N;VQI=&@N<&AP.C$S-38*;7-G:60@(E]);7!O
M<G0O17AP;W)T(@IM<V=S='(@(E]);7!O<G0O17AP;W)T(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3,S-PIM<V=I9"`B7TUY($-A;&5N9&%R<R(*;7-G<W1R
M(")?36EN82!K86QE;F1R87(B"@HC.B!T96UP;&%T97,O;65N=2]M96YU+FEN
M8SHR,"!L:6(O2W)O;F]L:71H+G!H<#HQ,S0T"FUS9VED(")?3F5W($5V96YT
M(@IM<V=S='(@(E].>2!HY&YD96QS92(*"B,Z('1E;7!L871E<R]M96YU+VUE
M;G4N:6YC.C,R(&QI8B]+<F]N;VQI=&@N<&AP.C$S-C$*;7-G:60@(E]0<FEN
M="(*;7-G<W1R(")5='-K<FEF="(*"B,Z('1E;7!L871E<R]M96YU+VUE;G4N
M:6YC.C(S(&QI8B]+<F]N;VQI=&@N<&AP.C$S-3(*;7-G:60@(E]396%R8V@B
M"FUS9W-T<B`B7U/V:R(*"B,Z('1E;7!L871E<R]M96YU+VUE;G4N:6YC.C0X
M"FUS9VED(")?4VAO=R(*;7-G<W1R(")?5FES82(*"B,Z('1E;7!L871E<R]M
M96YU+VUE;G4N:6YC.C$T(&QI8B]+<F]N;VQI=&@N<&AP.C$S-#<*;7-G:60@
M(E]4;V1A>2(*;7-G<W1R(")?261A9R(*"B,Z('1E;7!L871E<R]E9&ET+V5D
M:70N:6YC.C$T,`IM<V=I9"`B8F5F;W)E('1H92!E=F5N="!S=&%R=',B"FUS
M9W-T<B`B:6YN86X@:.1N9&5L<V5N(&+V<FIA<B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.#4*;7-G:60@(F1A>2(*;7-G<W1R(")D86<B"@HC.B!T
M96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z,C`W"FUS9VED(")D87DH<RDB"FUS9W-T<B`B9&%G*&%R*2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#8@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$X-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@X(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B9&%Y<R(*;7-G<W1R(")D86=A<B(*"B,Z(&1A=&$N<&AP.C$U
M,"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(F5V96YT<RYC
M<W8B"FUS9W-T<B`B:.1N9&5L<V5R+F-S=B(*"B,Z(&1A=&$N<&AP.C$W,0IM
M<V=I9"`B979E;G1S+FEC<R(*;7-G<W1R(")HY&YD96QS97(N:6-S(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,S8*;7-G:60@(FEN
M(@IM<V=S='(@(FDB"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@
M=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(R-R!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S,*;7-G
M:60@(FUO;G1H*',I(@IM<V=S='(@(FWE;F%D*&5R*2(*"B,Z(&QI8B]+<F]N
M;VQI=&@N<&AP.C$P-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B;VX@)7,@870@
M)7,B"FUS9W-T<B`B9&5N("5S(&ML("5S(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z,3(T('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R-PIM<V=I
M9"`B;VX@=&AE('-A;64@9&%T92(*;7-G<W1R(")PY2!S86UM82!D86<B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C8@=&5M<&QA=&5S+V5D:70O
M961I="YI;F,Z,C,S"FUS9VED(")O;B!T:&4@<V%M92!W965K9&%Y(@IM<V=S
M='(@(G#E('-A;6UA('9E8VMO9&%G(@H*(SH@9&%T82YP:'`Z,CD@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-`IM<V=I9"`B=D-A;&5N9&%R+VE#86QE
M;F1A<B(*;7-G<W1R(")V0V%L96YD87(O:4-A;&5N9&%R(@H*(SH@;&EB+V%P
M:2YP:'`Z,S4P(&QI8B]A<&DN<&AP.C8R.0IM<V=I9"`B=D5V96YT(&YO="!F
M;W5N9"XB"FUS9W-T<B`B=D5V96YT('-A:VYA<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DQ"FUS9VED(")W965K(@IM<V=S='(@(G9E8VMA(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(R('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(Q-`IM<V=I9"`B=V5E:RAS*2!O;CHB"FUS9W-T<B`B=F5C
M:V$@<.4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DS"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.30*;7-G:60@(G=E96MS(@IM<V=S='(@(G9E8VMO<B(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,SD*;7-G:60@(GEE87(H<RDB"FUS9W-T<B`BY7(B"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O
M;F]L:71H+W!O+V5L7T=2+G!O````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$R,S(S,0`Q,#0Q-S,V,C<U,P`P,C`T,#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!+<F]N;VQI=&@@
M1W)E96L@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`R(%-T969A
M;F]S($DN($1I;6ET<FEO=2X*(R!3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-U
M<'!O<G1?=V5B;6%I;$!T96EA=&@N9W(^+"`R,#`R+@HC(%-I;&QI9V%R9&]S
M(%AR:7-T;V9O<F]S+"`R,#`R+@HC($%N86=N;W-T;W!O=6QO<R!!<&]S=&]L
M:7,L(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($MR;VYO;&ET:#H@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#$M,#<M,C8@,3$Z,S8K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-U<'!O<G1?=V5B;6%I;$!T96EA
M=&@N9W(^7&XB"B),86YG=6%G92U496%M.B!'<F5E:R`\9&5V0&QI<W1S+FAO
M<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM-UQN(@HB0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z('1E;7!L871E<R]C
M86QE;F1A<G,O<V5A<F-H+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!C86QE;F1A<G,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5D(&5V96YT<R(*;7-G<W1R("*\Z^$@].$@X^7C[^W\].$B"@HC.B!T96UP
M;&%T97,O961I="]E9&ET7W1I;65S<&%N+FEN8SHQ,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@1&%Y*',I("5S($AO=7(H<RD@)7,@36EN=71E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S@W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@
M:6UP;W)T960B"FUS9W-T<B`B)7,L(-WCZ>WE(.7PZ?3U]_[R(.<@Y>GSX>/Y
MX]X@]._U(.'Q]^7?[_4B"@HC.B!C86QE;F1A<G,N<&AP.C$P-2!L:6(O8F%S
M92YP:'`Z,3(X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A
M;&5N9&%R(@IM<V=S='(@(L7NX>/YX]X@Q^SE\>_K[^/?[_4B"@HC.B!T96UP
M;&%T97,O8V%L96YD87)S+W-E87)C:"YI;F,Z,3<*;7-G:60@(B(*(BA#;&EC
M:R!O;B!C86QE;F1A<B!N86UE('1O('-W:71C:"!T:&4@8V%L96YD87(G<R!V
M:7-I8FEL:71Y(&EN('1H92!M86EN("(*(G=I;F1O=RDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-C0*;7-G:60@
M(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($%D9"`J(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,34P"FUS9VED("(J
M(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(B"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ-S@V"FUS9VED("(Q(&%T=&5N9&5E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT"B,L(&9U>GIY
M"FUS9VED("(Q(&5V96YT(@IM<V=S='(@(KSKX2#TX2#CY>/O[?STX2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*(RP@9G5Z>GD*;7-G:60@(C$@
M:&]U<B(*;7-G<W1R("(E9"#^\>$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,T"B,L(&9U>GIY"FUS9VED("(Q-2!M:6YU=&5S(@IM<V=S='(@(B5D
M(.OE\/3<(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ
M>0IM<V=I9"`B,C`@;6EN=71E<R(*;7-G<W1R("(E9"#KY?#TW"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*(RP@9G5Z>GD*;7-G:60@(C,P(&UI
M;G5T97,B"FUS9W-T<B`B)60@Z^7P]-PB"@HC.B!T96UP;&%T97,O961I="]E
M9&ET+FEN8SHQ-S$*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^071T96YD965S
M/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^R]WNY>GR(.KKY>GD
MZ=P\+V(^("CP\>_AZ?'E].GJ_"DB"@HC.B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ-#D*(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^1&5S8W)I7W!T:6]N
M/"]S=')O;F<^("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^T.7QZ>/QX?;>/"]B
M/B`H\/'OX>GQY?3IZOPI(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C<W"B,L(&9U>GIY"FUS9VED("(\<W1R;VYG/DME>7=O<F1S/"]S=')O;F<^
M("AO<'1I;VYA;"DB"FUS9W-T<B`B/&(^R]WNY>GR(.KKY>GDZ=P\+V(^("CP
M\>_AZ?'E].GJ_"DB"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.30*
M(RP@9G5Z>GD*;7-G:60@(CQS=')O;F<^4F5C=7)R96YC93PO<W1R;VYG/B`H
M;W!T:6]N86PI(@IM<V=S='(@(CQB/L7PX>W<Z^?XYSPO8CX@*/#Q[^'I\>7T
MZ>K\*2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`Q('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,3@Q"FUS9VED(")!32(*;7-G<W1R("(B
M"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU.3$*;7-G:60@(D%C8V5P=&5D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHQ,0IM
M<V=I9"`B061?=F%N8V5D(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$V,2!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B061D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V"FUS9VED(")!9&0@179E;G0B
M"FUS9W-T<B`BT/'O\^C>ZN<@P^7C[^W\]._R(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,S4*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!A(&YE=R!296UO=&4@0V%L96YD87(B"FUS9W-T<B`BT/'O\^C>
MZN<@[=WO]2##Y>/O[?ST[_(B"@HC.B!A9&1E=F5N="YP:'`Z-C0*;7-G:60@
M(D%D9"!A(&YE=R!E=F5N="(*;7-G<W1R("+0\>_SZ-[JYR#MW>_U(,/EX^_M
M_/3O\B(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHW
M-`IM<V=I9"`B061D(&%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!C;VYT86-T
M<RYP:'`Z-S8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,C`*
M(SH@=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C<X"FUS9VED
M(")!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8VA?861V86YC960N:6YC.C@@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC.C$Q"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-3,*;7-G:60@(D%L87)M(@IM
M<V=S='(@(M#Q[^7IY._P[]_G\^<B"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S8T
M"B,L('!H<"UF;W)M870*;7-G:60@(D%L87)M("5D(&1A>7,@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B06QA<FT@)60@:&]U<G,@8F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C$W-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%L87)M("5D(&UI;G5T97,@8F5F;W)E(@IM<V=S='(@(LOE\/3<(/#Q
MZ>TB"@HC.B!L:6(O1')I=F5R+G!H<#HQ-S4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D%L87)M("5D('=E96MS(&)E9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ-S8S"FUS9VED(")!;&%R;2`Q(&1A>2!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3<V.`IM<V=I9"`B06QA<FT@
M,2!H;W5R(&)E9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M-S<S"B,L(&9U>GIY"FUS9VED(")!;&%R;2`Q(&UI;G5T92!B969O<F4B"FUS
M9W-T<B`BR^7P]-P@\/'I[2(*"B,Z(&QI8B]$<FEV97(N<&AP.C$W-3@*;7-G
M:60@(D%L87)M(#$@=V5E:R!B969O<F4B"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z-C`*;7-G:60@(D%L87)M($1A=&4B"FUS9W-T<B`BQ^SE\>_LY^W?X2#0
M\>_EZ>3O\._?Y_/G\B(*"B,Z(&1A=&$N<&AP.C4Y"FUS9VED(")!;&%R;2!3
M<&%N("AM:6YU=&5S*2(*;7-G<W1R("+$Z=SQZN7IX2#0\>_EZ>3O\._?Y_/G
M\B`HZ^7P]-PI(@H*(SH@9&%T82YP:'`Z-C$*;7-G:60@(D%L87)M(%1I;64B
M"FUS9W-T<B`BQ^SE\>_LY^W?X2#0\>_EZ>3O\._?Y_/G\B(*"B,Z('1E;7!L
M871E<R]D96QE=&4O9&5L971E+FEN8SHS,0IM<V=I9"`B06QL(@IM<V=S='(@
M(KSKX2(*"B,Z(&QI8B]&0E9I97<N<&AP.C$R-B!L:6(O1D)6:65W+G!H<#HQ
M,CD@;&EB+T9"5FEE=RYP:'`Z,3,R"B,L(&9U>GIY"FUS9VED(")!;&P@071T
M96YD965S(@IM<V=S='(@(KSKX2#TX2#CY>/O[?STX2(*"B,Z('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FEN8SHU.0HC+"!F=7IZ>0IM<V=I9"`B06QL($9U
M='5R92(*;7-G<W1R("+,Y>OK[^WTZ>K<(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:6YC.C4S"B,L(&9U>GIY"FUS9VED(")!;&P@4&%S="(*;7-G
M<W1R("*\Z^7R(/3I\B#LW?'E\B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL
M:7-T+G!H<#HR-R!L:6(O0FQO8VLO;6]N=&@N<&AP.C(T"B,Z(&QI8B]";&]C
M:R]M;VYT:&QI<W0N<&AP.C(W(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-0IM
M<V=I9"`B06QL(%9I<VEB;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z,3(R(&QI8B]$87E6:65W+G!H<#HY,"!L
M:6(O1&%Y5FEE=RYP:'`Z.3,*(SH@;&EB+U=E96M6:65W+G!H<#HQ,C<@;&EB
M+U=E96M6:65W+G!H<#HQ,S0@;&EB+T1R:79E<BYP:'`Z,3@S,@IM<V=I9"`B
M06QL(&1A>2(*;7-G<W1R("*\Z^7R(/3I\B#LW?'E\B(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ-C0*;7-G:60@(D%L;"!D87D@979E;G0B"FUS9W-T
M<B`BP^7C[^W\\B#P[_4@Y.GA\>KEWR#\Z^<@].?M(.S=\>$B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")!;&P@979E;G1S(@IM
M<V=S='(@(KSKX2#TX2#CY>/O[?STX2(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H7V%D=F%N8V5D+FEN8SHT.0HC.B!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:%]A9'9A;F-E9"YI;F,Z-S$@;&EB+TMR;VYO;&ET:"YP:'`Z-C@S"FUS
M9VED(")!;GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-S$*;7-G:60@(D%P<FEL(@IM<V=S='(@(L'P\=_KZ>_R(@H*
M(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z,SD@=&5M<&QA
M=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z.3,*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHW,"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U
M-@IM<V=I9"`B070B"FUS9W-T<B`BT^4B"@HC.B!L:6(O2W)O;F]L:71H+G!H
M<#HQ,#(V"FUS9VED("(B"B)!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL
M92!W:71H(&UO<F4@:6YF;W)M871I;VX@86)O=70@=&AE(&5V96YT+B!)9B!Y
M;W5R("(*(FUA:6P@8VQI96YT('-U<'!O<G1S(&E4:7`@<F5Q=65S=',@>6]U
M(&-A;B!U<V4@=&AI<R!F:6QE('1O(&5A<VEL>2!U<&1A=&4@(@HB>6]U<B!L
M;V-A;"!C;W!Y(&]F('1H92!E=F5N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C0R('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$V-0IM<V=I9"`B071T96YD86YC92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ-C$*;7-G:60@(D%T=&5N9&5E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN
M8SHW-0IM<V=I9"`B075G=7-T(@IM<V=S='(@(L']X^_U\_3O\B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHQ,2!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YI;F,Z.`IM<V=I9"`B0F%S:6,@4V5A<F-H(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I
M9"`B0FER=&AD87DB"FUS9W-T<B`BP^7MW>CKZ>$B"@HC.B!L:6(O1D)6:65W
M+G!H<#HY,"!L:6(O1D)6:65W+G!H<#HQ,3`*;7-G:60@(D)U<WDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8VA?861V86YC960N:6YC
M.C0T"B,L(&9U>GIY"FUS9VED(")#7V%L96YD87(B"FUS9W-T<B`BQ>GSX>/Y
MX]X@Q^SE\>_K[^/?[_4B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHT
M.0HC+"!F=7IZ>0IM<V=I9"`B0V%L7V5N9&%R(@IM<V=S='(@(L7I\^'C^>/>
M(,?LY?'OZ^_CW^_U(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$T-B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C$*(SH@
M;&EB+T)L;V-K+VUO;G1H+G!H<#HR,2!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H
M<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(RP@9G5Z>GD*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(L7I\^'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D-A;&5N
M9&%R(%-U;6UA<GDB"FUS9W-T<B`BT.7QW^OG^.<B"@HC.B!D871A+G!H<#HR
M,C@*(RP@9G5Z>GD*;7-G:60@(D-A;&5N9&%R('-U8V-E<W-F=6QL>2!P=7)G
M960N(@IM<V=S='(@(L7PZ?3U]][R(.7I\^'C^>/>(/3O]2#'[.7Q[^OOX]_O
M]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-PHC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87)S
M(@IM<V=S='(@(L7I\^'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@8V%L96YD87)S
M+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B0V%L96YD87)S(&UU<W0@:&%V92!A
M(&YA;64N(@IM<V=S='(@(L'U]-X@YR#TZ>S>(/#QW?#EZ2#MX2#EW^WAZ2#A
M\>GH[/SR+B(*"B,Z(&1A=&$N<&AP.C(T,PHC+"!F=7IZ>0IM<V=I9"`B0V%N
M)W0@8W)E871E(&$@;F5W(&5V96YT+B(*;7-G<W1R("+$Y^SI[_7QX]_A(.W=
M[_4@X^7C[^W\]._R(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ.3$@=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C,P"B,Z('1E;7!L
M871E<R]D96QE=&4O9&5L971E+FEN8SHS,B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHS,PHC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,#D*;7-G:60@
M(D-A;F-E;"(*;7-G<W1R("+!ZO7Q[R(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C4W,`HC+"!F=7IZ>0IM<V=I9"`B0V%N8V5L;&5D(@IM<V=S='(@(L'J]?'O
M(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`P,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N8V5L;&5D.B`E<R(*;7-G<W1R("+!ZO7Q[R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHV-"!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHV.0HC+"!F=7IZ>0IM<V=I9"`B0V%T96=O
M<E]Y(@IM<V=S='(@(LKA].?C[_'?X2(*"B,Z(&1A=&$N<&AP.C8S('1E;7!L
M871E<R]S96%R8V@O979E;G1?:&5A9&5R<RYI;F,Z-"!T96UP;&%T97,O=FEE
M=R]V:65W+FEN8SHQ,PIM<V=I9"`B0V%T96=O<GDB"FUS9W-T<B`BRN'TY^/O
M\=_A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W.0IM<V=I9"`B(@HB
M0VAO;W-E(&EF('EO=2!W86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I
M=&5D+"!A;F0@9&5L971E9"!E=F5N=',@8GD@(@HB96UA:6PZ(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,@IM<V=I9"`B0VAO;W-E
M(&EF('EO=2!W86YT('1O(&)E(&YO=&EF:65D(&]F(&YE=RP@961I=&5D+"!A
M;F0@9&5L971E9"!E=F5N=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S96%R8VA?86)O;VM?<V5L96-T+FEN8SHQ.2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,CDY"FUS9VED(")#:&]O<V4@=&AE(&%D9')E<W,@8F]O:W,@
M=&\@<V5A<F-H(&9O<B!F<F5E+V)U<WD@55),<SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V9B7V-A;'-?<V5L96-T+FEN8SHQ-@IM<V=I9"`B
M0VAO;W-E('1H92!C86QE;F1A<G,@=&\@:6YC;'5D92!I;B!Y;W5R(&9R964O
M8G5S>2!I;F9O<FUA=&EO;CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Q,0IM<V=I9"`B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@
M:6YC;'5D92!W:&5N(&=E;F5R871I;F<@9G)E92]B=7-Y(%523',Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B0VAO
M;W-E('EO=7(@9&5F875L="!C86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C8U"FUS9VED(")#;&5A
M<B!A;&P@871T96YD965S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(X('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R
M871E9"!V86QU97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<S"FUS9VED(")#;VYF:7)M(&1E;&5T:6]N(&]F(&5V96YT<S\B"FUS
M9W-T<B`B*LWA(.;G].7?].'I(.7PZ>+EXN'?^?/G(.KA]-P@].<@Y.GAX_'A
M]MX@]/GM(./EX^_M_/3Y[3LB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-C<*
M;7-G:60@(D-O;F9I<FUE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z,C`X"FUS9VED(")#;W!Y('1H92!54DP@
M8F5L;W<@9F]R('5S92!W:&5R979E<B!Y;W4@;F5E9"!Y;W5R($9R964O0G5S
M>2!54DPZ(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$V,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C$R
M-@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(@IM<V=S='(@(M3QW??Y[2(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ,3(*(RP@9G5Z
M>GD*;7-G:60@(D-R96%T92!#86QE;F1A<B(*;7-G<W1R("+%Z?/AX_GCWB#'
M[.7Q[^OOX]_O]2(*"B,Z(&UO;G1H+G!H<#HQ-C4@=&5M<&QA=&5S+W=E96LO
M:&5A9"YI;F,Z,C4@=&5M<&QA=&5S+V1A>2]R;W<N:6YC.C8*(SH@;&EB+T1A
M>59I97<N<&AP.CDP(&QI8B]$87E6:65W+G!H<#HQ.30*;7-G:60@(D-R96%T
M92!A($YE=R!%=F5N="(*;7-G<W1R("+$Y^SI[_7QX]_A(.W=[_4@X^7C[^W\
M]._R(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z.#`*;7-G:60@(D-R
M96%T960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N
M:6YC.C(Y"FUS9VED(")#=7)R96YT(@IM<V=S='(@(M3QW??Y[2(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$Q,B!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR,#D*;7-G:60@(D1A:6QY.B!296-U<G,@979E<GDB"FUS9W-T<B`B
MRN'HY^SE\>GMW#H@RMSHY2(*"B,Z(&%T=&5N9&5E<RYP:'`Z,3$P(&QI8B]+
M<F]N;VQI=&@N<&AP.C$R.#@@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C$*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"FUS9VED(")$87DB"FUS9W-T
M<B`BQ^S=\>$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV,B!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHQ,SD*;7-G:60@(D1A>2AS*2(*;7-G<W1R
M("+'[-WQX2CE\BDB"@HC.B!V:65W979E;G0N<&AP.C$P-`HC+"!F=7IZ>0IM
M<V=I9"`B1&5?;&5T92(*;7-G<W1R("+$Z>'C\>'VWB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V=O=&\N:6YC.C<Y"FUS9VED(")$96-E;6)E<B(*;7-G
M<W1R("+$Y>K=[.+QZ>_R(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-3DT"FUS
M9VED(")$96-L:6YE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V%L96YD87(B"FUS
M9W-T<B`BQ>GSX>/YX]X@Q^SE\>_K[^/?[_4B"@HC.B!T96UP;&%T97,O8V%L
M96YD87)S+V-A;&5N9&%R<RYI;F,Z,3DS('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3@Q"B,Z('1E;7!L871E<R]D96QE=&4O;VYE+FEN8SHR
M.2!T96UP;&%T97,O<')E9G,O<F5M;W1E7V-A;%]M86YA9V5M96YT+FEN8SHR
M,PHC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"FUS9VED(")$96QE=&4B"FUS9W-T
M<B`BQ.GAX_'A]MXB"@HC.B!D96QE=F5N="YP:'`Z-#`@=&5M<&QA=&5S+V1E
M;&5T92]O;F4N:6YC.C$X('1E;7!L871E<R]D96QE=&4O9&5L971E+FEN8SHQ
M.`HC.B!L:6(O1')I=F5R+G!H<#HQ.#$S"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92`E<R(*;7-G<W1R("+$Z>'C\>'VWB`E<R(*"B,Z(&5D:71E=F5N
M="YP:'`Z-S`*;7-G:60@(D1E;&5T92!%=F5N="(*;7-G<W1R("+$Z>'C\>'V
MWB##Y>/O[?ST[_(B"@HC.B!T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,Z
M,C<*;7-G:60@(B(*(D1E;&5T92!T:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T
M:&ES(&]C8W5R<F5N8V4@86YD(&%L;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@
M(@HB86QL(&]C8W5R96YC97,_(@IM<V=S='(@(B(*(L3IX>/QW/CTY2#T[R#T
M\=WW^>T@X^7C[^W\\B#L_.WO+"#A]?3\(/3O(/#E\>GS].'TZ>K\(.KAZ2#\
MZ^7R(/3I\B`B"B+LY>OK[^WTZ>K=\B#E[/;A[=_SY>GR(/3O]2P@WOSKY?(@
M].GR(.7L]N'MW_/EZ?(@]._U.R(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H7V%D=F%N8V5D+FEN8SHQ,#0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:6YC.C(X"B,L(&9U>GIY"FUS9VED(")$97-C<FE?<'1I;VXB"FUS9W-T<B`B
MT.7QZ>/QX?;>(@H*(SH@9&%T82YP:'`Z-C(@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C$W-0HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHY-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BT.7QZ>/QX?;>(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S,*(RP@9G5Z
M>GD*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`BQ>SVW.WI\^<@T?7H[-_SY?GM
M(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N:6YC.C8P"B,L
M(&9U>GIY"FUS9VED(")$:7-P;&%Y($-A;&5N9&%R<R(*;7-G<W1R("+%[/;<
M[>GSYR#1]>CLW_/E^>TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(X"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BQ>SVW.WI\^<@
MT?7H[-_SY?GM(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED
M(")$;R!Y;W4@=V%N="!T;R!S:&]W('1A<VMS('=H:6-H(&%R92!D=64@;VX@
M>6]U<B!C86QE;F1A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP
M:'`Z-3,W"FUS9VED(")$;V5S(&YO="!R96-U<B(*;7-G<W1R("(B"@HC.B!L
M:6(O2W)O;F]L:71H+G!H<#HS,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1'5E
M.B`E<R(*;7-G<W1R("+$Z=SQZN7IX3H@)7,B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET7W1I;65S<&%N+FEN8SHQ,34*;7-G:60@(D1U<F%T:6]N(@IM<V=S
M='(@(L3IW/'JY>GA(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A
M<G,N:6YC.C$W,"!L:6(O1')I=F5R+G!H<#HQ.#`V"FUS9VED(")%9&ET(@IM
M<V=S='(@(L7PY>[E\>/A\]_A(@H*(SH@961I=&5V96YT+G!H<#HS,R!T96UP
M;&%T97,O961I="]E9&ET+FEN8SHR-B!L:6(O1')I=F5R+G!H<#HQ.#`V"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@)7,B"FUS9W-T<B`BQ?#E[N7QX^'S
MW^$@)7,B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ.#<*;7-G:60@
M(D5D:70@071T96YD965S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C86QE
M;F1A<G,O8V%L96YD87)S+FEN8SHQ-#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@
M0V%L96YD87)S(@IM<V=S='(@(L7NX>/YX]X@Q^SE\>_K[^/?[_4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4P"B,L(&9U>GIY"FUS9VED(")%9&ET
M(%)E;6]T92!#86QE;F1A<G,B"FUS9W-T<B`BQ>GSX>/YX]X@Q^SE\>_K[^/?
M[_4B"@HC.B!A='1E;F1E97,N<&AP.C$U,`IM<V=I9"`B161I="!A='1E;F1E
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A=&5G;W)Y7VQE9V5N9"YI
M;F,Z,C`*;7-G:60@(D5D:70@8V%T96=O<FEE<R!A;F0@8V]L;W)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3<V
M('1E;7!L871E<R]A='1E;F1E97,O871T96YD965S+FEN8SHT,0HC.B!T96UP
M;&%T97,O=FEE=R]V:65W+FEN8SHQ-C0*;7-G:60@(D5M86EL($%D9')E<W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI
M;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D5N7V0B"FUS9W-T<B`BR][NYR#3].GR
M(@H*(SH@9&%T82YP:'`Z-3<*;7-G:60@(D5N9"!$871E(@IM<V=S='(@(L?L
MY?'O[.?MW^$@R][NY_(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE
M861E<G,N:6YC.C@@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#@*;7-G:60@(D5N9"!/;B(*;7-G
M<W1R("++WN[G(-/TZ?(B"@HC.B!D871A+G!H<#HU.`IM<V=I9"`B16YD(%1I
M;64B"FUS9W-T<B`BO_'A(,O>[N?R(@H*(SH@871T96YD965S+G!H<#HQ,C0@
M871T96YD965S+G!H<#HQ,S4@871T96YD965S+G!H<#HQ-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@<F5T<FEE=FEN9R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@9F]R("5S.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H
M+G!H<#HQ,#DS"FUS9VED(")%=F5N="!A9&1E9#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3$P,PIM<V=I9"`B179E;G0@9&5L971E9#HB
M"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`Y.`IM<V=I9"`B
M179E;G0@961I=&5D.B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M,#8V"B,L('!H<"UF;W)M870*;7-G:60@(D5V96YT(&9R;VT@)7,@=&\@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z-S8T"B,L(&9U>GIY"FUS
M9VED(")%=F5N=',@;75S="!H879E(&$@<W1A<G0@9&%T92XB"FUS9W-T<B`B
M(@HBQR#G[.7Q[^SG[=_A(/3=Z^_U\B#P\=WPY>D@[>$@Y=_MX>D@[.7TX>/E
M[=WS].7QYR#TY_(@Y^SE\>_LY^W?X?(@X?'WWO(N(@H*(SH@;&EB+T1R:79E
M<BYP:'`Z-S,P"FUS9VED(")%=F5N=',@;75S="!H879E(&$@=&ET;&4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C<V-PIM<V=I9"`B179E;G1S
M(&UU<W0@:&%V92!A;B!E;F0@9&%T92!O<B!A(&1U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-SD*
M(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R("*_\>$@R][N
MY_(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X-PIM<V=I9"`B
M17AP;W)T(@IM<V=S='(@(L7NX>/YX]XB"@HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C@*;7-G:60@(D5X<&]R="!#86QE;F1A<B(*;7-G<W1R("+%
M[N'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9V]T;RYI;F,Z-CD*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(M;EXO'O]=SQ
MZ>_R(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,C@*
M(RP@9G5Z>GD*;7-G:60@(D9I;F0B"FUS9W-T<B`BT.'QX?/JY?7>(@H*(SH@
M>65A<BYP:'`Z.#<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C,@
M=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C(R"B,Z(&QI8B]";&]C:R]M;VYT
M:"YP:'`Z,3`U"FUS9VED(")&<B(*;7-G<W1R("+0X2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU.`HC+"!F=7IZ>0IM<V=I9"`B1G)E92]"=7-Y($EN
M9F]R;6%T:6]N(@IM<V=S='(@(L_I(-#KY_'O]N_QW^7R(//A\B(*"B,Z('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHR,"!T96UP;&%T97,O=FEE=R]V:65W
M+FEN8SHQ,3D*(SH@=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S(*
M;7-G:60@(D9R:61A>2(*;7-G<W1R("+0X?'A\^KE]=XB"@HC.B!T96UP;&%T
M97,O9&5L971E+V1E;&5T92YI;F,Z,S`*;7-G:60@(D9U='5R92(*;7-G<W1R
M("+,Y>OK[^WTZ>K<(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T.C$W
M"FUS9VED(")'86UE(@IM<V=S='(@(M#AZ??MW^3I(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]S96%R8VA?861V86YC960N:6YC.C(S"FUS9VED(")'96YE<F%L
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=O=&\@)7,B"FUS9W-T<B`BS.7T
MX?;O\=PB"@HC.B!M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W965K+VAE861?
M<VED95]B>5]S:61E+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED
M95]B>5]S:61E+FEN8SHQ,`IM<V=I9"`B2&ED92(*;7-G<W1R("(B"@HC.B!M
M;VYT:"YP:'`Z,3,U('1E;7!L871E<R]W965K+VAE861?<VED95]B>5]S:61E
M+FEN8SHQ,@HC.B!T96UP;&%T97,O9&%Y+VAE861?<VED95]B>5]S:61E+FEN
M8SHQ,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&ED92`E<R(*;7-G
M<W1R("+%[/;<[>GSYR`E<R(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC
M.C8U('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C$S.`IM<V=I9"`B2&]U<BAS
M*2(*;7-G<W1R("*_\>$HY?(I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,PHC+"!F=7IZ>0IM<V=I9"`B2&]W(&QO;F<@<VAO=6QD('1H92!T:6UE
M('-L;W1S(&]N('1H92!D87D@86YD('=E96L@=FEE=W,@8F4_(@IM<V=S='(@
M(B(*(LWA(./?[>7TX>D@]_GQZ?/L_/(@X>W<(.SI\]X@_O'A(//TYR#KW_/T
MX2#TY_(@Y^S=\>'R(.KAZ2#TY_(@Y>+D[^S<Y.'R.R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.#@*;7-G:60@(DAO=R!M86YY(&1A>7,@;V8@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N('-H;W5L9"!W92!G96YE<F%T93\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3`S,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B))9B!Y;W5R(&5M86EL(&-L:65N="!D;V5S;B=T('-U<'!O
M<G0@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!O;F4@;V8@=&AE("(*(F9O
M;&QO=VEN9R!L:6YK<R!T;R!A8V-E<'0@;W(@9&5C;&EN92!T:&4@979E;G0N
M7&XB"B)<;B(*(E1O(&%C8V5P="!T:&4@979E;G0Z7&XB"B(E<UQN(@HB7&XB
M"B)4;R!A8V-E<'0@=&AE(&5V96YT('1E;G1A=&EV96QY.EQN(@HB)7-<;B(*
M(EQN(@HB5&\@9&5C;&EN92!T:&4@979E;G0Z7&XB"B(E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="!#86QE;F1A<BP@4W1E<"`E9"(*;7-G
M<W1R("+%Z?/AX_GCWB#'[.7Q[^OOX]_O]2(*"B,Z(&1A=&$N<&AP.C,R,`IM
M<V=I9"`B26UP;W)T+T5X<&]R="!#86QE;F1A<B(*;7-G<W1R("+%Z?/AX_GC
MWB_%[N'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9V]T;RYI;F,Z-C@*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`BR>'M[_7<
M\>GO\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C<T"FUS
M9VED(")*=6QY(@IM<V=S='(@(LGO_>OI[_(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]G;W1O+FEN8SHW,PIM<V=I9"`B2G5N92(*;7-G<W1R("+)[_WM
MZ>_R(@H*(SH@9&%T82YP:'`Z-C4@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z
M,30R"FUS9VED(")+97EW;W)D<R(*;7-G<W1R("++W>[G(.KKY>GDWR(*"B,Z
M('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FEN8SHU-0IM<V=I9"`B3&%S="`R
M-"!H;W5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHX-PIM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C0*(SH@=&5M<&QA
M=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ,`HC.B!T96UP;&%T
M97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$V('1E;7!L871E<R]M
M;VYT:"]H96%D+FEN8SHT"B,L(&9U>GIY"FUS9VED("),87-T($UO;G1H(@IM
M<V=S='(@(M3EZ^7U].'?[_(@[-[MX?(B"@HC.B!T96UP;&%T97,O>65A<B]H
M96%D+FEN8SHT"B,L(&9U>GIY"FUS9VED("),87-T(%EE87(B"FUS9W-T<B`B
MU.7KY?7TX=_A(,7BY._LW.3A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:6YC.C4T('1E;7!L871E<R]W965K+VAE860N:6YC.C,*;7-G:60@(DQA
M<W0@=V5E:R(*;7-G<W1R("+4Y>OE]?3AW^$@Q>+D[^S<Y.$B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$W"FUS9VED("),:6UI="!T:&4@=&EM
M92!S<&%N('1O(&5X<&]R=#HB"FUS9W-T<B`BQ?#IZ]WN].4@].\@Y?WQ[_(@
M]._U(/?Q_.WO]2#P[_4@Z.$@Y>[<X^7TY3HB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z.#8@=&5M<&QA=&5S+V5D:70O961I
M="YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(DQO7V-A=&EO;B(*;7-G<W1R("+4
M[_#OZ.7SW^$B"@HC.B!D871A+G!H<#HV-"!T96UP;&%T97,O<V5A<F-H+V5V
M96YT7VAE861E<G,N:6YC.C4*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T95]C
M86Q?;6%N86=E;65N="YI;F,Z,3@*(SH@=&5M<&QA=&5S+W!R969S+W)E;6]T
M95]C86Q?;6%N86=E;65N="YI;F,Z-3(@=&5M<&QA=&5S+W9I97<O=FEE=RYI
M;F,Z,C$*(SH@;&EB+T1R:79E<BYP:'`Z,3@T.0IM<V=I9"`B3&]C871I;VXB
M"FUS9W-T<B`BU._P[^CE\]_A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0U"FUS9VED(")-86YA9V4@<F5M;W1E(&-A;&5N9&%R<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S`*;7-G:60@
M(DUA<F-H(@IM<V=S='(@(LS<\?3I[_(B"@HC.B!L:6(O87!I+G!H<#HQ,#`*
M;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($5V96YT<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW,@IM<V=I9"`B36%Y
M(@IM<V=S='(@(LS<Z>_R(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@T-@IM<V=I
M9"`B364B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VME>7=O<F1S+G!H<"YD:7-T
M.C$W"FUS9VED(")-965T:6YG(@IM<V=S='(@(M/U[=SM].?SYR(*"B,Z(&QI
M8B]";&]C:R]T<F5E7V%L87)M<RYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N
M=2!!;&%R;7,B"FUS9W-T<B`BT/'OY>GD[_#OW^?SYR(*"B,Z(&QI8B]";&]C
M:R]T<F5E7VUE;G4N<&AP.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHV."!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ,S<*;7-G:60@(DUI;G5T92AS*2(*;7-G<W1R("++Y?#T
M_"C<*2(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HT,@IM<V=I
M9"`B36ES<V5D($5V96YT<R!,:7-T(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP
M.C@S('1E;7!L871E<R]J879A<V-R:7!T+V=O=&\N:6YC.C4Y('1E;7!L871E
M<R]E9&ET+V5D:70N:6YC.C(Q.`HC.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P
M-0IM<V=I9"`B36\B"FUS9W-T<B`BQ.4B"@HC.B!T96UP;&%T97,O;6]N=&@O
M:&5A9"YI;F,Z,38@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$U"B,Z('1E
M;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8X(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#8*;7-G:60@(DUO;F1A>2(*;7-G<W1R("+$Y?7TW?'A(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,2!L:6(O0FQO8VLO=')E95]M96YU
M+G!H<#HR-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*;7-G:60@(DUO;G1H
M(@IM<V=S='(@(LS>[>'R(@H*(SH@;&EB+T)L;V-K+VUO;G1H+G!H<#HS"B,L
M(&9U>GIY"FUS9VED(")-;VYT:"!6:65W(@IM<V=S='(@(LS>[>'R(@H*(SH@
M;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,R!L:6(O0FQO8VLO;6]N=&AL:7-T
M+G!H<#HT,PIM<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C0@=&5M<&QA=&5S+W9I
M97<O=FEE=RYI;F,Z,3(V"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(R
M.2!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,S4*;7-G:60@(DUO;G1H;'DZ
M(%)E8W5R<R!E=F5R>2(*;7-G<W1R("+,Y^WIX=_A.B#*W.CE(@H*(SH@;&EB
M+T)L;V-K+VUO;G1H;&ES="YP:'`Z,C0*;7-G:60@(DUO;G1H<R!!:&5A9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<')E=FUO;G1H;&ES="YP:'`Z,C0*
M(RP@9G5Z>GD*;7-G:60@(DUO;G1H<R!"969O<F4B"FUS9W-T<B`BR^7P]-P@
M\/'I[2(*"B,Z(&QI8B]A<&DN<&AP.C8Q,@IM<V=I9"`B375L=&EP;&4@:4-A
M;&5N9&%R(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE('9%=F5N="!I<R!S
M=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z,3(X('1E
M;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHV-PHC+"!F=7IZ>0IM
M<V=I9"`B37D@0V%L96YD87)S(@IM<V=S='(@(L7I\^'C^>/>(,?LY?'OZ^_C
MW^_U(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C,T('1E;7!L871E<R]M96YU
M+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B37D@0V%L96YD87)S.B(*;7-G<W1R
M("+%[N'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R
M<R]C86QE;F1A<G,N:6YC.C(P-`IM<V=I9"`B37D@1G)E92]"=7-Y(%523"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI
M;F,Z,3$W('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S+FEN8SHQ-3D*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ-S4*(SH@=&5M
M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z,3<*(SH@
M=&5M<&QA=&5S+W!R969S+W)E;6]T95]C86Q?;6%N86=E;65N="YI;F,Z-#0*
M(RP@9G5Z>GD*;7-G:60@(DYA;64B"FUS9W-T<B`BT.'I]^W?Y.DB"@HC.B!L
M:6(O0FQO8VLO;6]N=&@N<&AP.C0Q(&QI8B]";&]C:R]M;VYT:&QI<W0N<&AP
M.C0T(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HT,0HC.B!L:6(O0FQO8VLO=')E
M95]M96YU+G!H<#HR,`IM<V=I9"`B3F5W($5V96YT(@IM<V=S='(@(LW=[R##
MY>/O[?SR(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-`HC+"!F
M=7IZ>0IM<V=I9"`B3F5X="(*;7-G<W1R("+%\/SLY>WG(,S=\>$B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z-3<*;7-G:60@(DYE>'0@,C0@
M:&]U<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T9"5FEE=R]D87DN<&AP.C(Y"B,L
M(&9U>GIY"FUS9VED(").97AT($1A>2(*;7-G<W1R("+%\/SLY>WG(,S=\>$B
M"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C8*
M(SH@=&5M<&QA=&5S+VUO;G1H+VAE861?<VED95]B>5]S:61E+FEN8SHQ,@HC
M.B!T96UP;&%T97,O;6]N=&@O:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C$X('1E
M;7!L871E<R]M;VYT:"]H96%D+FEN8SHV"FUS9VED(").97AT($UO;G1H(@IM
M<V=S='(@(L7P_.SE[>_R(,S>[>'R(@H*(SH@;&EB+T9"5FEE=R]W965K+G!H
M<#HS,@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!7965K(@IM<V=S='(@(L7P_.SE
M[><@Q>+D[^S<Y.$B"@HC.B!T96UP;&%T97,O>65A<B]H96%D+FEN8SHV"B,L
M(&9U>GIY"FUS9VED(").97AT(%EE87(B"FUS9W-T<B`BQ?#\[.7MYR#,W?'A
M(@H*(SH@=&5M<&QA=&5S+V1A>2]H96%D+FEN8SHU"FUS9VED(").97AT(&1A
M>2(*;7-G<W1R("+%\/SLY>WG(,S=\>$B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YI;F,Z-3@@=&5M<&QA=&5S+W=E96LO:&5A9"YI;F,Z-0IM<V=I
M9"`B3F5X="!W965K(@IM<V=S='(@(L7P_.SE[><@Q>+D[^S<Y.$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<U"B,L(&9U>GIY"FUS9VED(").;R(*
M;7-G<W1R("+*X>W=[>$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHW
M,R!T96UP;&%T97,O961I="]E9&ET+FEN8SHQ,C8*(RP@9G5Z>GD*;7-G:60@
M(DYO(&%L87)M(@IM<V=S='(@(M#Q[^7IY._P[]_G\^<B"@HC.B!T96UP;&%T
M97,O871T96YD965S+V%T=&5N9&5E<RYI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@
M(DYO(&%T=&5N9&5E<R(*;7-G<W1R("+$Y>T@]?#<\??EZ2#G[.7Q[^SG[=_A
M(.O>[N?R(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q,0IM<V=I9"`B3F\@
M8V%L96YD87)S(&%R92!A=F%I;&%B;&4@=&\@9W5E<W1S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,S8@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C4U"FUS9VED(").;R!E;F0@9&%T92(*;7-G<W1R("+$
MY>T@]?#<\??EZ2#G[.7Q[^SG[=_A(.O>[N?R(@H*(SH@;&EB+T)L;V-K+W!R
M979M;VYT:&QI<W0N<&AP.C$V-"!L:6(O0FQO8VLO;6]N=&AL:7-T+G!H<#HQ
M-C,*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y-`IM<V=I9"`B3F\@979E
M;G1S('1O(&1I<W!L87DB"FUS9W-T<B`B(@H*(SH@;&EB+U-T;W)A9V4O:V]L
M86(N<&AP.C0S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!I<R!A=F%I;&%B;&4@9F]R("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C,T-"!L:6(O87!I+G!H<#HV,#(*;7-G:60@(DYO(&E#
M86QE;F1A<B!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C`T"B,L(&9U>GIY"FUS9VED(").;R!R96-U
M<G)E;F-E(@IM<V=S='(@(L7PX>W<Z^?XYR#DY>3O[-WM^>TB"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HX.#8*;7-G:60@(DYO('9A;&ED(&5M86EL(&%D9')E
M<W,@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-C`Q
M(&QI8B]+<F]N;VQI=&@N<&AP.C8R,@IM<V=I9"`B3F]N92(*;7-G<W1R("+*
MX>W=[>$B"@HC.B!L:6(O4W1O<F%G92]S<6PN<&AP.C$S-@IM<V=I9"`B3F]T
M(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,0HC+"!F=7IZ>0IM<V=I9"`B3F]T:69I8V%T:6]N<R(*;7-G<W1R("+4[_#O
MZ.7SW^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O+FEN8SHW.`IM
M<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BS>_=[.+QZ>_R(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:6YC.C4V"FUS9VED(").;W<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S<*;7-G:60@
M(D]C=&]B97(B"FUS9W-T<B`BS^KT_N+QZ>_R(@H*(SH@=&5M<&QA=&5S+V5D
M:70O961I=%]T:6UE<W!A;BYI;F,Z,3,@=&5M<&QA=&5S+V5D:70O961I=%]T
M:6UE<W!A;BYI;F,Z-C4*;7-G:60@(D]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-S@*;7-G:60@(D]N(&%L;"!C86QE;F1A<G,@
M22!H879E(')E860@86-C97-S('1O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-S<*;7-G:60@(D]N(&%L;"!S:&]W;B!C86QE;F1A
M<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W-@IM
M<V=I9"`B3VX@;7D@8V%L96YD87)S(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TMR;VYO;&ET:"YP:'`Z-C$Y"B,L(&9U>GIY"FUS9VED(")/<'1I;VYA;"(*
M;7-G<W1R("+1]>CLW_/EZ?(B"@HC.B!L:6(O1D)6:65W+G!H<#HQ,3@*;7-G
M:60@(D]P=&EO;F%L($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!L:6(O1D)6
M:65W+G!H<#HQ-3(*;7-G:60@(D]V97)V:65W(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C,T"FUS9VED(")/=VYE<B(*;7-G<W1R
M("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ.#0U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")/=VYE<CH@)7,B"FUS9W-T<B`BQ.G<\>KEZ>$Z("5S(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,#(@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ.#(*;7-G:60@(E!-(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C(Y('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30*(RP@9G5Z
M>GD*;7-G:60@(E!A;&T@1&%T94)O;VLB"FUS9W-T<B`BQ^SE\>_LY^W?X2#0
M\>_EZ>3O\._?Y_/G\B(*"B,Z(&QI8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H
M<#HS"FUS9VED(")087-T($5V96YT<R!,:7-T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$P.2!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHQ.3@*;7-G:60@(E!A='1E<FXB"FUS9W-T<B`BS._TW^+O(@H*(SH@
M=&5M<&QA=&5S+V1E;&5T92]O;F4N:6YC.C(W"FUS9VED(")097)M86YE;G1L
M>2!D96QE=&4@=&AI<R!E=F5N=#\B"FUS9W-T<B`BS>$@Y.GAX_'A]N7?(,S/
MS<G,P2#A]?3\(/3O(./EX^_M_/([(@H*(SH@;&EB+V%P:2YP:'`Z,S(U(&QI
M8B]A<&DN<&AP.C0Q.2!L:6(O87!I+G!H<#HT.#$@;&EB+V%P:2YP:'`Z-34S
M"B,Z(&QI8B]A<&DN<&AP.C4X-"!L:6(O87!I+G!H<#HV-S`@;&EB+V%P:2YP
M:'`Z-S`V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,38W"B,L(&9U
M>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("+0\>_S^?#IZOPB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$*(RP@9G5Z>GD*;7-G:60@(E!O
M<G1A;"!/<'1I;VYS(@IM<V=S='(@(L7PZ>OOX]WR(-?QWO/TYR(*"B,Z(&QI
M8B]&0E9I97<O9&%Y+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@
M1&%Y(@IM<V=S='(@(M#Q[^?C[_WLY>WG(.?LW?'A(@H*(SH@;&EB+T9"5FEE
M=R]W965K+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@5V5E:R(*
M;7-G<W1R("+0\>_GX^_][.7MYR#G[-WQX2(*"B,Z('1E;7!L871E<R]D87DO
M:&5A9"YI;F,Z,PIM<V=I9"`B4')E=FEO=7,@9&%Y(@IM<V=S='(@(M#Q[^?C
M[_WLY>WG(.?LW?'A(@H*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3,U
M('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(U,@IM<V=I9"`B4F5C=7(@56YT
M:6PB"FUS9W-T<B`BQ?#A[=SKY_CG(-WY\B(*"B,Z('1E;7!L871E<R]V:65W
M+W9I97<N:6YC.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4F5C=7)R96YC92(*;7-G
M<W1R("+%\.'MW.OG^.<@Y.7D[^S=[?GM(@H*(SH@9&%T82YP:'`Z-CD*;7-G
M:60@(E)E8W5R<F5N8V4@1&%T82(*;7-G<W1R("+%\.'MW.OG^.<@Y.7D[^S=
M[?GM(@H*(SH@9&%T82YP:'`Z-C<*;7-G:60@(E)E8W5R<F5N8V4@16YD($1A
M=&4B"FUS9W-T<B`B*L?LY?'O[.?MW^$@U-WK[_7R(@H*(SH@9&%T82YP:'`Z
M-C@*;7-G:60@(E)E8W5R<F5N8V4@26YT97)V86PB"FUS9W-T<B`B*L7PX>W<
MZ^?XYR#=^?(B"@HC.B!D871A+G!H<#HV-@IM<V=I9"`B4F5C=7)R96YC92!4
M>7!E(@IM<V=S='(@(BK%\.'MX>OA[.+A[?SLY>WO\B#4_?#O\B(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C4T,`IM<V=I9"`B4F5C=7)S(&1A:6QY(@IM<V=S
M='(@(LKAZ.?LY?'I[?[R(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z-30W"FUS
M9VED(")296-U<G,@;6]N=&AL>2(*;7-G<W1R("+%\.'MW.OG^.<@X>W<(.S>
M[>$B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HU-#,*;7-G:60@(E)E8W5R<R!W
M965K;'DB"FUS9W-T<B`BQ?#A[=SKY_CG(.'MW"#EXN3O[-SDX2(*"B,Z(&QI
M8B]+<F]N;VQI=&@N<&AP.C4U,`IM<V=I9"`B4F5C=7)S('EE87)L>2(*;7-G
M<W1R("+%\.'MW.OG^.<@X>W<(/?Q_.WO(@H*(SH@;&EB+U-C:&5D=6QE<B]K
M<F]N;VQI=&@N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296UI;F1E
M<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE
M;F1A<G,N:6YC.CDQ(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-`HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W1E($-A;&5N9&%R<R(*;7-G<W1R("+%Z?/AX_GCWB#'
M[.7Q[^OOX]_O]2(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHV,"!T96UP;&%T
M97,O;65N=2YI;F,Z-C(*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!#86QE;F1A
M<G,Z(@IM<V=S='(@(L7I\^'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@=&5M<&QA
M=&5S+V%T=&5N9&5E<R]A='1E;F1E97,N:6YC.C4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E;6]V92`E<R(*;7-G<W1R("(B"@HC.B!A='1E;F1E97,N<&AP
M.C$P-`IM<V=I9"`B4F5M;W9E($%T=&5N9&5E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S(*;7-G:60@(B(*(E)E<&QA8V4@
M97AI<W1I;F<@8V%L96YD87(@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R
M;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y
M;W5R(&-U<G)E;G0@8V%L96YD87(N/"]S=')O;F<^(@IM<V=S='(@(B(*"B,Z
M(&QI8B]+<F]N;VQI=&@N<&AP.C8R-@IM<V=I9"`B4F5Q=6ER960B"FUS9W-T
M<B`B(@H*(SH@;&EB+T9"5FEE=RYP:'`Z.3@@;&EB+T9"5FEE=RYP:'`Z,3,W
M(&QI8B]&0E9I97<N<&AP.C$T,"!L:6(O1D)6:65W+G!H<#HQ-#,*;7-G:60@
M(E)E<75I<F5D($%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHS-"!T96UP;&%T97,O961I="]E9&ET+FEN8SHS,3`*
M;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(L7PX>WA]N_QW"#T
M^>T@\/'OY?#IZ^7C[-WM^>T@\?7H[-_SY?GM(@H*(SH@=&5M<&QA=&5S+V%T
M=&5N9&5E<R]A='1E;F1E97,N:6YC.C0S('1E;7!L871E<R]V:65W+W9I97<N
M:6YC.C$V-@IM<V=I9"`B4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@>65A<BYP
M:'`Z.#@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C0@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C(S"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,3`U"FUS9VED(")382(*;7-G<W1R("+3X2(*"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D+FEN8SHR,2!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,C`*(SH@
M=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S,*;7-G:60@(E-A='5R
M9&%Y(@IM<V=S='(@(M/<XN+A].\B"@HC.B!T96UP;&%T97,O8V%L96YD87)S
M+V-A;&5N9&%R<RYI;F,Z,3DR"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S
M='(@(M/A(@H*(SH@=FEE=V5V96YT+G!H<#HQ,3@@961I=&5V96YT+G!H<#HT
M."!E9&ET979E;G0N<&AP.C4V"FUS9VED(")3879E($%S($YE=R(*;7-G<W1R
M("+!\._HWNKE]?/G(/GR(.W=[R(*"B,Z('1E;7!L871E<R]A='1E;F1E97,O
M871T96YD965S+FEN8SHX-PIM<V=I9"`B4V%V92!!='1E;F1E97,B"FUS9W-T
M<B`B(@H*(SH@861D979E;G0N<&AP.C4U(&5D:71E=F5N="YP:'`Z-3$*;7-G
M:60@(E-A=F4@179E;G0B"FUS9W-T<B`BP?#OZ-[JY?7SYR##Y>/O[?ST[_(B
M"@HC.B!S96%R8V@N<&AP.CDQ('1E;7!L871E<R]S96%R8V@O<V5A<F-H7V%D
M=F%N8V5D+FEN8SHQ,34*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC
M.C8W('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHX"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,30P(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C(V"B,L(&9U>GIY"FUS9VED(")396%R8V@B"FUS9W-T<B`B
MS-SQ].GO\B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHQ
M"B,L(&9U>GIY"FUS9VED(")396%R8V@@0V%L96YD87)S(@IM<V=S='(@(L7I
M\^'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D
M97(N:6YC.C8*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C86QE;F1A<G,O<V5A<F-H+FEN8SHV"FUS9VED(")396%R
M8V@@9F]R(&-A;&5N9&%R<R!C;VYT86EN:6YG.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,Z,34P"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@82!C86QE;F1A<B!T;R!E9&ET(@IM<V=S='(@(L7P
MZ>O=[O3E(/3O(.'Q]^7?[R#P[_4@Z.$@Y>GSW./E].4Z(@H*(SH@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C8X('1E;7!L871E<R]E9&ET+V5D:71?=&EM
M97-P86XN:6YC.C,Q"B,Z('1E;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN
M:6YC.C@S"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(L?LY?'O[.?MW^$@Q>KJW^WG\^?R(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC
M.C,P"B,L(&9U>GIY"FUS9VED(")396QE8W0@8V%L96YD87)S('1O(&1I<W!L
M87DZ(@IM<V=S='(@(L7PZ>O=[O3E(/3O[2#T\?SP[R#E[/;<[>GSY_(@]/GM
M(,?LY?'O[.?MZ?[M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM
M<V=I9"`B(@HB4V5L96-T(&-O;F9I<FUA=&EO;B!O<'1I;VYS+"!H;W<@=&\@
M9&ES<&QA>2!T:&4@9&EF9F5R96YT('9I97=S(&%N9"!C:&]O<V4@(@HB9&5F
M875L="!V:65W+B(*;7-G<W1R("(B"B+%\.GKW>[TY2#T[^T@]/'\\.\@Y>SV
MW.WI\^?R+"#JX>D@]._M(/3Q_/#O(.7PZ>+EXN'?^?/G\B#T^>T@Y>WE\>/E
MZ?[M+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3D*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.B(*
M;7-G<W1R("+%\.GKW>[TY2#T[R#A\??EW^\@\._U(.CA(.7I\]SCY?3E.B(*
M"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`BQ?#IZ]WN
M].4@X?#\(/#O]2#HX2#EZ?/<X^7TY2#TX2#DY>3O[-WMX3HB"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C(X"FUS9VED(")396QE8W0@=&AE(&9I
M;&4@=&\@:6UP;W)T.B(*;7-G<W1R("+%\.GKW>[TY2#T[R#A\??EW^\@\._U
M(.CA(.7I\]SCY?3E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*
M;7-G:60@(E-E;&5C="!T:&4@9FER<W0@=V5E:V1A>3HB"FUS9W-T<B`BQ?#I
MZ]WN].4@].?M(/#Q_O3G(.?LW?'A(/3G\B#EXN3O[-SD[_(Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("+%
M\.GKW>[TY2#TY^T@[._Q]MX@]/GM(.3EY._LW>WY[2#E[OSD[_4Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-`IM<V=I9"`B4V5L96-T('1H92!T
M:6UE('-P86X@=&\@<VAO=SHB"FUS9W-T<B`BQ?#IZ]WN].4@].\@Y?WQ[_(@
M]._U(/?Q_.WO]2#P[_4@Z.$@Y>SVX>W?YN7TX>DZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('9I
M97<@=&\@9&ES<&QA>2!O;B!S=&%R='5P.B(*;7-G<W1R("+%\.GKW>[TY2#T
MY^T@Y>SVW.WI\^<@\._U(.CA(/?QY_/I[._P[^GEW_3AZ2#LY?3<(/3G[2#E
MW_/OY.\@\^'R.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('=H:6-H(&5V96YT<R!T;R!S:&]W(&EN('1H
M92!P;W)T86PN(@IM<V=S='(@(B(*(L7PZ>O=[O3E(/#OZ>$@X^7C[^W\].$@
MZ.$@Y>SVX>W?YN_M].'I(//TY^T@\/'^].<@\^7KW^3A("CPY?'?Z^?XYRD@
M].?R("(*(O7PY_'E\]_A\BXB"@HC.B!T96UP;&%T97,O9&5L971E+V]N92YI
M;F,Z,C0@=&5M<&QA=&5S+V1E;&5T92]D96QE=&4N:6YC.C(T"FUS9VED(")3
M96YD(&$@8V%N8V5L(&YO=&EF:6-A=&EO;B!T;R!A;&P@871T96YD965S('=H
M96X@9&5L971I;F<@=&AI<R!E=F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O=FEE=R]V:65W+FEN8SHQ-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5N
M9"!A;B!E;6%I;"!T;R`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O961I
M="]E9&ET+FEN8SHQ.#$*;7-G:60@(E-E;F0@=7!D871E<R]I;G9I=&%T:6]N
M<R!T;R!A;&P@871T96YD965S('=H96X@<V%V:6YG('1H:7,@979E;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-S8*
M;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("+3Y?#TW>SB\>GO\B(*"B,Z('1E
M;7!L871E<R]E9&ET+V5D:71?=&EM97-P86XN:6YC.C@S"B,L(&9U>GIY"FUS
M9VED(")3970@96YD(&1A=&4B"FUS9W-T<B`BQ.7M(/7PW/'WY>D@Y^SE\>_L
MY^W?X2#KWN[G\B(*"B,Z('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(V.`HC
M+"!F=7IZ>0IM<V=I9"`B4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B"FUS9W-T
M<B`B*L?LY?'O[.?MW^$@U-WK[_7R(@H*(SH@=&5M<&QA=&5S+V5D:70O961I
M=%]T:6UE<W!A;BYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(E-E="!S=&%R="!D
M871E(@IM<V=S='(@(L?LY?'O[.?MW^$@Q>KJW^WG\^?R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Y"FUS9VED("(B"B)3970@>6]U<B!F<F5E+V)U
M<WD@8V%L96YD87)S(&%N9"!Y;W5R(&]W;B!A;F0@;W1H97(@=7-E<G,G(&9R
M964O8G5S>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP
M.C<W"B,L('!H<"UF;W)M870*;7-G:60@(E-H87)E(&YO="!F;W5N9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-A;&5N9&%R<R]C86QE;F1A<G,N
M:6YC.C<Y"B,L(&9U>GIY"FUS9VED(")3:&%R960@0V%L96YD87)S(@IM<V=S
M='(@(L7I\^'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@=&5M<&QA=&5S+VUE;G4N
M:6YC.C0W('1E;7!L871E<R]M96YU+FEN8SHT.0HC+"!F=7IZ>0IM<V=I9"`B
M4VAA<F5D($-A;&5N9&%R<SHB"FUS9W-T<B`BQ>[AX_GCWB#'[.7Q[^OOX]_O
M]2(*"B,Z(&-A;&5N9&%R7W-E87)C:"YP:'`Z,C4@=&5M<&QA=&5S+W=E96LO
M:&5A9%]S:61E7V)Y7W-I9&4N:6YC.C,*(SH@=&5M<&QA=&5S+V1A>2]H96%D
M7W-I9&5?8GE?<VED92YI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!#86QE
M;F1A<B(*;7-G<W1R("+%[N'C^>/>(,?LY?'OZ^_CW^_U(@H*(SH@=&5M<&QA
M=&5S+V-A;&5N9&%R<R]S96%R8V@N:6YC.C(R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-H;W<@8V%L96YD87(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-38*;7-G:60@(E-H;W<@8V%T96=O<GD@;&5G
M96YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V
M"FUS9VED(")3:&]W(&1E;&5T92P@86QA<FTL(&%N9"!R96-U<G)E;F-E(&EC
M;VYS(&EN(&-A;&5N9&%R('9I97=S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C$R"FUS9VED(")3:&]W(&1U92!T87-K<R!I;B!T
M:&4@8V%L96YD87(_(@IM<V=S='(@(LWA(.7L]N'MW^;O[?3AZ2#TX2#CY>/O
M[?STX2#S].\@Q^SE\>_K_./I[R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-C8*;7-G:60@(E-H;W<@9G)E92]B=7-Y(&QE9V5N9#\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,PIM<V=I9"`B4VAO=R!O
M;FQY(&5V96YT<R!T:&%T(&AA=F4@86X@86QA<FT@<V5T/R(*;7-G<W1R("+-
MX2#E[/;A[>GS]._][2#L_.WO(/3A(./EX^_M_/3A(//TX2#O\._?X2#=]^7I
M(._QZ?/TY=\@]?#E[>C][.GSYSLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3<U"FUS9VED(")3:&]W('-H87)E9"!C86QE;F1A<G,@<VED92UB>2US
M:61E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q
M"B,L(&9U>GIY"FUS9VED(")3:&]W('1A<VMS('5S:6YG(&-A=&5G;W)Y(&-O
M;&]R<S\B"FUS9W-T<B`BS>$@Y>SVX>W?YN_M].'I(/3A(./EX^_M_/3A(//T
M[R#'[.7Q[^O\X^GO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU"B,L
M(&9U>GIY"FUS9VED(")3:&]W('1I;64@;V8@9&%Y(&)E='=E96X@96%C:"!D
M87D@:6X@=V5E:R!V:65W<S\B"FUS9W-T<B`B(@HBS>$@X]_MY?3AZ2#W^?'I
M\^S\\B#A[=P@[.GSWB#^\>$@\_3G(.O?\_3A(/3G\B#G[-WQX?(@ZN'I(/3G
M\B#EXN3O[-SDX?([(@H*(SH@=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A
M;BYI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E-T85]R="(*;7-G<W1R("+%ZNK?
M[>?SYR#S].GR(@H*(SH@9&%T82YP:'`Z-34*;7-G:60@(E-T87)T($1A=&4B
M"FUS9W-T<B`BQ^SE\>_LY^W?X2#%ZNK?[>?SY_(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V5V96YT7VAE861E<G,N:6YC.C<@=&5M<&QA=&5S+W9I97<O=FEE
M=RYI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-0IM<V=I
M9"`B4W1A<G0@3VXB"FUS9W-T<B`BQ>KJW^WG\^<@\_3I\B(*"B,Z(&1A=&$N
M<&AP.C4V"FUS9VED(")3=&%R="!4:6UE(@IM<V=S='(@(K_QX2#%ZNK?[>?S
MY_(B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z
M.34@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z.#4*;7-G:60@(E-T871?=7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S
M+FEN8SHV('1E;7!L871E<R]V:65W+W9I97<N:6YC.C(W"FUS9VED(")3=&%T
M=7,B"FUS9W-T<B`B(@H*(SH@>65A<BYP:'`Z.#$@>65A<BYP:'`Z.3`@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C4*(SH@=&5M<&QA=&5S+V5D
M:70O961I="YI;F,Z,C(T(&QI8B]";&]C:R]M;VYT:"YP:'`Z,3`W(&QI8B]"
M;&]C:R]M;VYT:"YP:'`Z,3`Y"FUS9VED(")3=2(*;7-G<W1R("+*]2(*"B,Z
M('1E;7!L871E<R]M;VYT:"]H96%D+FEN8SHQ-"!T96UP;&%T97,O;6]N=&@O
M:&5A9"YI;F,Z,C,*(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(Q('1E
M;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC.C8W"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#4*;7-G:60@(E-U;F1A>2(*;7-G<W1R("+*]?'IX>K>
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS9VED(")487-K<R(*
M;7-G<W1R("+#Y>/O[?STX2(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C4W-"!L
M:6(O2W)O;F]L:71H+G!H<#HU.3<*;7-G:60@(E1E;G1A=&EV92(*;7-G<W1R
M("(B"@HC.B!Y96%R+G!H<#HX-B!T96UP;&%T97,O:F%V87-C<FEP="]G;W1O
M+FEN8SHV,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,C$*(SH@;&EB+T)L
M;V-K+VUO;G1H+G!H<#HQ,#4*;7-G:60@(E1H(@IM<V=S='(@(M#=(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHW,`IM<V=I9"`B5&AE
M($5D:70@071T96YD965S('-C<F5E;B!I<R!N;R!L;VYG97(@<')E<V5N="X@
M17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HW,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&-A;FYO="!B
M92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C0P"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!C86QE;F1A<B!<(B5S7"(@:&%S(&)E
M96X@8W)E871E9"XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HX.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&-A;&5N9&%R<RYP:'`Z-30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@
M8F5E;B!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@8V%L96YD
M87)S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8V%L96YD87(@
M7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-A;&5N9&%R(&-O=6QD
M(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]E
M9&ET+VIA=F%S8W)I<'0N:6YC.C$V,PIM<V=I9"`B5&AE(&5N9"!D871E(&UU
M<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A<G0@9&%T92XB"FUS9W-T<B`B(@HB
MQR#G[.7Q[^SG[=_A(/3=Z^_U\B#P\=WPY>D@[>$@Y=_MX>D@[.7TX>/E[=WS
M].7QYR#TY_(@Y^SE\>_LY^W?X?(@X?'WWO(N(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E;G0@7"(E
M<UPB(&AA<R!B965N(&%D9&5D+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3$P-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@979E;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960L
M('=H:6-H('=A<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TMR
M;VYO;&ET:"YP:'`Z,3`Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@979E
M;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"P@=VAI8V@@:7,@;VX@)7,@870@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&5V96YT(&YO=&EF:6-A=&EO;B!T;R`E
M<R!W87,@<W5C8V5S<V9U;&QY('-E;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]+
M<F]N;VQI=&@N<&AP.C$P,C0*;7-G:60@(E1H92!F;VQL;W=I;F<@:7,@82!M
M;W)E(&1E=&%I;&5D(&1E<V-R:7!T:6]N(&]F('1H92!E=F5N=#HB"FUS9W-T
M<B`B(@H*(SH@871T96YD+G!H<#HT,0IM<V=I9"`B(@HB5&AE(')E<75E<W0@
M=V%S(&EN8V]M<&QE=&4N(%-O;64@<&%R86UE=&5R<R!T:&%T(&%R92!N96-E
M<W-A<GD@=&\@86-C97!T(&]R("(*(F1E8VQI;F4@86X@979E;G0@87)E(&UI
M<W-I;F<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O96UP='DN
M:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!E=F5N=',@;6%T
M8VAI;F<@=&AE(&-U<G)E;G0@8W)I=&5R:6$N(@IM<V=S='(@(L3E[2#U\-SQ
M]^_U[2#CY>/O[?STX2#P\>_R(.7NX>/YX]XN(@H*(SH@861D979E;G1A8W1I
M;VXN<&AP.C$X(&5D:71E=F5N=&%C=&EO;BYP:'`Z,S4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A8V-E<W-I;F<@
M=&AE(&-A;&5N9&%R.B`E<R(*;7-G<W1R("+0X?'O]?/IW//TY^KE(//VW.OL
MX2#JX?3<(/3G[2#EZ?/AX_GCWB#T^>T@Y.7D[^S=[?GM(@H*(SH@861D979E
M;G1A8W1I;VXN<&AP.C,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T
M<B`BT.'Q[_7SZ=SS].?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@]/GM
M(.3EY._LW>WY[2(*"B,Z(&5D:71E=F5N=&%C=&EO;BYP:'`Z.#,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!E9&ET
M:6YG('1H92!E=F5N=#H@)7,B"FUS9W-T<B`BT.'Q[_7SZ=SS].?JY2#S]MSK
M[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@]/GM(.3EY._LW>WY[2(*"B,Z(&QI8B]A
M<&DN<&AP.C,S."!L:6(O87!I+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R("+0X?'O]?/IW//TY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/A
MX_GCWB#T^>T@Y.7D[^S=[?GM(@H*(SH@961I=&5V96YT86-T:6]N+G!H<#HV
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&UO=FEN9R!T:&4@979E;G0Z("5S(@IM<V=S='(@(M#A\>_U\^G<\_3G
MZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(/3Y[2#DY>3O[-WM^>TB"@HC
M.B!L:6(O2W)O;F]L:71H+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG(&%N(&5V96YT(&YO=&EF:6-A
M=&EO;B!T;R`E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3`U"FUS
M9VED(")4:&5R92!W97)E(&YO(&5V96YT<R!T;R!E>'!O<G0N(@IM<V=S='(@
M(L3E[2#U\-SQ]^_U[2#CY>/O[?STX2#P\>_R(.7NX>/YX]XN(@H*(SH@9&%T
M82YP:'`Z,3@T"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(T-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6]N=&@O:&5A9"YI;F,Z,3D@=&5M
M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3$X"B,Z('1E;7!L871E<R]E9&ET+VIA
M=F%S8W)I<'0N:6YC.C<Q"FUS9VED(")4:'5R<V1A>2(*;7-G<W1R("+0W>SP
M].<B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YI;F,Z,S<*(RP@9G5Z
M>GD*;7-G:60@(E1I;64@4W!?86XB"FUS9W-T<B`BQO[MYR"_\>'R(@H*(SH@
M=&5M<&QA=&5S+V5D:70O961I=%]T:6UE<W!A;BYI;F,Z-`HC+"!F=7IZ>0IM
M<V=I9"`B5&EM92!S<&%N(@IM<V=S='(@(L;^[><@O_'A\B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O<V5A<F-H7V%D=F%N8V5D+FEN8SHS-B!T96UP;&%T97,O
M961I="]E9&ET+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B5&ET7VQE(@IM<V=S
M='(@(M3?].OO\B(*"B,Z(&1A=&$N<&AP.C4T('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FEN8SHR,`HC.B!T96UP;&%T97,O<V5A<F-H+V5V96YT7VAE861E
M<G,N:6YC.C,*;7-G:60@(E1I=&QE(@IM<V=S='(@(M3?].OO\B(*"B,Z(&QI
M8B]";&]C:R]P<F5V;6]N=&AL:7-T+G!H<#HQ,C(@;&EB+T)L;V-K+VUO;G1H
M;&ES="YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,C<*;7-G
M:60@(E1O9&%Y(@IM<V=S='(@(M/>[.7QX2(*"B,Z(&QI8B]";&]C:R]P<F5V
M;6]N=&AL:7-T+G!H<#HQ,C0@;&EB+T)L;V-K+VUO;G1H;&ES="YP:'`Z,3(S
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,CD*;7-G:60@(E1O;6]R<F]W
M(@IM<V=S='(@(B(*"B,Z('EE87(N<&AP.C@T('1E;7!L871E<R]J879A<V-R
M:7!T+V=O=&\N:6YC.C8P('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(Q.0HC
M.B!L:6(O0FQO8VLO;6]N=&@N<&AP.C$P-0IM<V=I9"`B5'4B"FUS9W-T<B`B
MU/'?(@H*(SH@=&5M<&QA=&5S+VUO;G1H+VAE860N:6YC.C$W('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$Q-@HC.B!T96UP;&%T97,O961I="]J879A<V-R
M:7!T+FEN8SHV.0IM<V=I9"`B5'5E<V1A>2(*;7-G<W1R("+4\=_TYR(*"B,Z
M(&-O;F9I9R]K97EW;W)D<RYP:'`N9&ES=#HQ-PIM<V=I9"`B5'EP92(*;7-G
M<W1R("+4_?#O\B(*"B,Z('1E;7!L871E<R]C86QE;F1A<G,O8V%L96YD87)S
M+FEN8SHQ.#,*;7-G:60@(E523"(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G
M92]S<6PN<&AP.C8T"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!C86QE;F1A<G,N<&AP.C@T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VUC86PN<&AP.C$S-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RXB"FUS
M9W-T<B`BQ.7M(.7?[>'I(.3U[>'T_.T@[>$@]N_Q]/GH[_WM(._I(/'UZ.S?
M\^7I\B#T[_4@)7,N(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R("+$Y>T@Y=_MX>D@Y/7MX?3\[2#MX2#V[_'T^>CO_>T@
M[^D@\?7H[-_SY>GR(/3O]2`E<RXB"@HC.B!C86QE;F1A<G,N<&AP.C4Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O4W1O<F%G92]K;VQA8BYP:'`Z,S0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R971R:65V92!F
M<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S(@IM<V=S='(@(L3E[2#EW^WA
MZ2#D]>WA]/SM(.WA(/;O\?3YZ._][2#OZ2#Q]>CLW_/EZ?(@]._U("5S+B(*
M"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$U"B,Z('-C<FEP=',O=7!G
M<F%D97,O,C`P-"TP-2TQ.5]C;VYV97)T7V-A=&5G;W)I97-?=&]?<W1R:6YG
M<RYP:'`Z-3,*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,S<V(&QI8B]A<&DN<&AP.C0U,"!L:6(O87!I+G!H<#HU,38@;&EB
M+V%P:2YP:'`Z-C(Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D
M($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TMR;VYO;&ET
M:"YP:'`Z,3`Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"FUS9VED
M(")5<V5R($EN=&5R9F%C92(*;7-G<W1R("+0Y?'IXMSKZ^_M(-?QWO/TYR(*
M"B,Z('EE87(N<&AP.C$V,R!Y96%R+G!H<#HQ-CD@;&EB+T)L;V-K+VUO;G1H
M+G!H<#HQ-3D@;&EB+T)L;V-K+VUO;G1H+G!H<#HQ-C(*(RP@9G5Z>GD*;7-G
M:60@(E9I97<@1&%Y(@IM<V=S='(@(L7L]MSMZ?/G("5S(@H*(SH@>65A<BYP
M:'`Z.#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9V]T;RYI;F,Z-C$@=&5M<&QA
M=&5S+V5D:70O961I="YI;F,Z,C(P"B,Z(&QI8B]";&]C:R]M;VYT:"YP:'`Z
M,3`U"FUS9VED(")792(*;7-G<W1R("+4Y2(*"B,Z('1E;7!L871E<R]M;VYT
M:"]H96%D+FEN8SHQ."!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3<*(SH@
M=&5M<&QA=&5S+V5D:70O:F%V87-C<FEP="YI;F,Z-S`*;7-G:60@(E=E9&YE
M<V1A>2(*;7-G<W1R("+4Y?3<\?3G(@H*(SH@871T96YD965S+G!H<#HQ,3(@
M;&EB+TMR;VYO;&ET:"YP:'`Z,3(Y,"!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(E=E96LB
M"FUS9W-T<B`BQ>+D[^S<Y.$B"@HC.B!M;VYT:"YP:'`Z,3<Y('=O<FMW965K
M+G!H<#HS,"!W965K+G!H<#HS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7965K
M("5D(@IM<V=S='(@(L7BY._LW.3A("5D(@H*(SH@=&5M<&QA=&5S+W9I97<O
M=FEE=RYI;F,Z-3D@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30P"FUS9VED
M(")7965K*',I(@IM<V=S='(@(L7BY._LW.3A*.7R*2(*"B,Z('1E;7!L871E
M<R]V:65W+W9I97<N:6YC.C$R,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR
M,34*;7-G:60@(E=E96ML>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@(L7BY._L
MX>3IX=_A.B#*W.CE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM
M<V=I9"`B(@HB5VAA="!T:6UE('-H;W5L9"!D87D@86YD('=E96L@=FEE=W,@
M96YD+"!W:&5N('1H97)E(&%R92!N;R!L871E<B!E=F5N=',_(@IM<V=S='(@
M(B(*(M#OZ>$@Z.$@Y=_MX>D@YR#TY>OIZMX@_O'A(//TY^T@Y>SVW.WI\^<@
MX>W<(.?LW?'A(.KAZ2#A[=P@Y>+D[^S<Y.$L(/STX>T@(@HBY.7M]?#<\??O
M]>T@W.OKX2#CY>/O[?STX2#P\>_SY.GO\>GS[-WMX2#A\>/\].7QX2#A\/P@
MX?7TWCLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED("(B
M"B)7:&%T('1I;64@<VAO=6QD(&1A>2!A;F0@=V5E:R!V:65W<R!S=&%R="P@
M=VAE;B!T:&5R92!A<F4@;F\@96%R;&EE<B!E=F5N=',_(@IM<V=S='(@(B(*
M(M#OZ>$@Z.$@Y=_MX>D@YR#^\>$@W>WA\>[G\B#S].?M(.7L]MSMZ?/G(.'M
MW"#G[-WQX2#JX>D@X>W<(.7BY._LW.3A+"#\].'M("(*(N3E[?7PW/'W[_7M
M(-SKZ^$@X^7C[^W\].$@\/'O\^3I[_'I\^S=[>$@[?GQW_3E\>$@X?#\(.'U
M]-X[(@H*(SH@871T96YD965S+G!H<#HQ,3$@;&EB+TMR;VYO;&ET:"YP:'`Z
M,3(X.2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR,@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E=O<FL@5V5E:R(*;7-G<W1R("+0Y>WH
MWNSE\>\B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,CDR(&QI8B]";&]C:R]T
M<F5E7VUE;G4N<&AP.C(U"FUS9VED(")996%R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]V:65W+W9I97<N:6YC.C$R."!T96UP;&%T97,O961I="]E9&ET
M+FEN8SHR-#$*;7-G:60@(EEE87)L>3H@4F5C=7)S(&5V97)Y(@IM<V=S='(@
M(L7TY_/?^?(Z(,K<Z.4B"@HC.B!D871A+G!H<#HT,"!D871A+G!H<#HR,S0@
M961I=&5V96YT86-T:6]N+G!H<#HT-B!A9&1E=F5N="YP:'`Z,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&5V96YT<RXB"FUS9W-T<B`B(@H*(SH@871T96YD+G!H
M<#HT.0IM<V=I9"`B66]U(&%R92!N;W0@86X@871T96YD964@;V8@=&AE('-P
M96-I9FEE9"!E=F5N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHW-@IM<V=I9"`B66]U(&-A;B!O;FQY('5S92!T
M:&ES(&9O<FT@9G)O;2!T:&4@161I="!!='1E;F1E97,@<V-R965N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HY-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&1O(&YO="!H879E(&%N(&5M86EL(&%D9')E<W,@
M8V]N9FEG=7)E9"!I;B!Y;W5R(%!E<G-O;F%L($EN9F]R;6%T:6]N("(*(D]P
M=&EO;G,N(%EO=2!M=7-T('-E="!O;F4@)7-H97)E)7,@8F5F;W)E(&5V96YT
M(&YO=&EF:6-A=&EO;G,@8V%N(&)E('-E;G0N(@IM<V=S='(@(B(*"B,Z(&%D
M9&5V96YT86-T:6]N+G!H<#HR,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O("5S+B(*
M;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.30*;7-G:60@(EEO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@=&AE('-E;&5C=&5D
M(&-A;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!D96QE=F5N=&%C=&EO;BYP:'`Z
M,C8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&1E;&5T
M92!T:&ES(&5V96YT+B(*;7-G<W1R("(B"@HC.B!E9&ET979E;G1A8W1I;VXN
M<&AP.C<X"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!E
M9&ET('1H:7,@979E;G0N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$X.0IM
M<V=I9"`B66]U(&AA=F4@<W!E8VEF:65D(&%N(&EN=F%L:60@8V%L96YD87(N
M(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,C$*;7-G:60@(EEO=2!H879E
M('-U8V-E<W-F=6QL>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O('1H:7,@979E
M;G0N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,C8*;7-G:60@(EEO=2!H
M879E('-U8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@
M979E;G0N(@IM<V=S='(@(B(*"B,Z(&%T=&5N9"YP:'`Z,S$*;7-G:60@(EEO
M=2!H879E('1E;G1A=&EV96QY(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI
M<R!E=F5N="XB"FUS9W-T<B`B(@H*(SH@8V%L96YD87)S+G!H<#HY,0IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L971E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHU-`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$P.30*;7-G:60@
M(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E
M(&%D9&5D('1O('EO=7(@8V%L96YD87)S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2W)O;F]L:71H+G!H<#HQ,3`T"FUS9VED("(B"B)9;W4@<F5Q=65S=&5D('1O
M(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U
M<B!C86QE;F1A<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]+<F]N;VQI=&@N<&AP
M.C$P.3D*;7-G:60@(EEO=2!R97%U97-T960@=&\@8F4@;F]T:69I960@=VAE
M;B!E=F5N=',@87)E(&5D:71E9"!I;B!Y;W5R(&-A;&5N9&%R<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP.C(P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@<F5Q=65S=&5D('1O(&)E(')E;6EN9&5D
M(&%B;W5T("5S+"!W:&EC:"!I<R!O;B`E<R!A="`E<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-H87)E<V5L96-T+FEN8SHQ,`HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!D969A=6QT(&-A;&5N9&%R(@IM<V=S='(@(L7NX>/Y
MX]X@Q^SE\>_K[^/?[_4B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#4S(&QI8B]$
M<FEV97(N<&AP.C$P-C,*;7-G:60@(EM5;FYA;65D(&5V96YT72(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O961I="]E9&ET+FEN8SHY-PHC+"!F=7IZ>0IM
M<V=I9"`B7T%L87)M(@IM<V=S='(@(M#Q[^7IY._P[]_G\^<B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,Z,3$*;7-G:60@(E]"
M87-I8R!396%R8V@B"FUS9W-T<B`B(@H*(SH@=FEE=V5V96YT+G!H<#HQ,C`*
M(RP@9G5Z>GD*;7-G:60@(E]%9&ET(@IM<V=S='(@(L7PY>[E\>/A\]_A(@H*
M(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,S,`HC+"!F=7IZ>0IM<V=I9"`B7T=O
M=&\B"FUS9W-T<B`BS.7TX?;O\=PB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,S,V"B,L(&9U>GIY"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R("+%
MZ?/AX_GCWB_%[N'C^>/>(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,Q.`HC
M+"!F=7IZ>0IM<V=I9"`B7TUY($-A;&5N9&%R<R(*;7-G<W1R("+%[N'C^>/>
M(,?LY?'OZ^_CW^_U(@H*(SH@;&EB+TMR;VYO;&ET:"YP:'`Z,3,R-0HC+"!F
M=7IZ>0IM<V=I9"`B7TYE=R!%=F5N="(*;7-G<W1R("+-W>\@P^7C[^W\\B(*
M"B,Z(&QI8B]+<F]N;VQI=&@N<&AP.C$S-#$*;7-G:60@(E]0<FEN="(*;7-G
M<W1R("(B"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ,S,R"B,L(&9U>GIY"FUS
M9VED(")?4V5A<F-H(@IM<V=S='(@(LS<\?3I[_(B"@HC.B!L:6(O2W)O;F]L
M:71H+G!H<#HQ,S(X"B,L(&9U>GIY"FUS9VED(")?5&]D87DB"FUS9W-T<B`B
MT][LY?'A(@H*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,30R"FUS9VED
M(")B969O<F4@=&AE(&5V96YT('-T87)T<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3@U"FUS9VED(")D87DB"FUS9W-T<B`BY^S=
M\>$B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN8SHQ,3(@=&5M<&QA=&5S
M+V5D:70O961I="YI;F,Z,C$P"FUS9VED(")D87DH<RDB"FUS9W-T<B`BY^S=
M\>$HY?(I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@W"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DP"FUS9VED(")D87ES(@IM<V=S='(@(N?LW?'E\B(*"B,Z
M(&1A=&$N<&AP.C$T-R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*(RP@
M9G5Z>GD*;7-G:60@(F5V96YT<RYC<W8B"FUS9W-T<B`BO.OA(/3A(./EX^_M
M_/3A(@H*(SH@9&%T82YP:'`Z,38X"B,L(&9U>GIY"FUS9VED(")E=F5N=',N
M:6-S(@IM<V=S='(@(KSKX2#TX2#CY>/O[?STX2(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3,Q"FUS9VED(")F<F]M(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R-"!T96UP;&%T97,O
M=FEE=R]V:65W+FEN8SHQ,C8*(SH@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z
M,C,P('1E;7!L871E<R]E9&ET+V5D:70N:6YC.C(S-@IM<V=I9"`B;6]N=&@H
M<RDB"FUS9W-T<B`B[-[MX2CE\BDB"@HC.B!L:6(O2W)O;F]L:71H+G!H<#HQ
M,#(P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")O;B`E<R!A="`E<R(*
M;7-G<W1R("(E<R#NY>KI[=P@\^4@)7,B"@HC.B!T96UP;&%T97,O=FEE=R]V
M:65W+FEN8SHQ,C0@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C,P"FUS9VED
M(")O;B!T:&4@<V%M92!D871E(@IM<V=S='(@(O3G[2#?Y.GA(.?LW?'A(@H*
M(SH@=&5M<&QA=&5S+W9I97<O=FEE=RYI;F,Z,3(V('1E;7!L871E<R]E9&ET
M+V5D:70N:6YC.C(S-@IM<V=I9"`B;VX@=&AE('-A;64@=V5E:V1A>2(*;7-G
M<W1R("+TY^T@W^3IX2#EXN3O[-SDX2(*"B,Z(&1A=&$N<&AP.C,P('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,34*;7-G:60@(G9#86QE;F1A<B]I0V%L
M96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,S0Y(&QI8B]A<&DN
M<&AP.C8P-PIM<V=I9"`B=D5V96YT(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,0IM<V=I9"`B=V5E:R(*;7-G
M<W1R("+EXN3O[-SDX2(*"B,Z('1E;7!L871E<R]V:65W+W9I97<N:6YC.C$R
M,B!T96UP;&%T97,O961I="]E9&ET+FEN8SHR,3<*;7-G:60@(G=E96LH<RD@
M;VXZ(@IM<V=S='(@(N7BY._LW.3A*.7R*2#TY^TH].\I.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.3(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DT"FUS9VED(")W965K<R(*
M;7-G<W1R("+EXN3O[-SDY?(B"@HC.B!T96UP;&%T97,O=FEE=R]V:65W+FEN
M8SHQ,C@@=&5M<&QA=&5S+V5D:70O961I="YI;F,Z,C0R"FUS9VED(")Y96%R
M*',I(@IM<V=S='(@(MWT[_(HYRDB"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]K<F]N;VQI=&@O;&EB+P``````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`Q-S(P,P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L:6(O1D)6:65W+P``````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-3,`,#(P,S(U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+VQI8B]&0E9I97<O9&%Y+G!H<```````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-#,P,0`Q,#0Q-S,V,C<U,P`P,C$V,#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@
M8VQA<W,@<F5P<F5S96YT(&$@<VEN9VQE(&1A>2!F8G9I97<@;V8@;75L:71P
M;&4@9G)E92!B=7-Y(&EN9F]R;6%T:6]N+@H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VXN"B`J"B`J("1(;W)D93H@:W)O;F]L
M:71H+VQI8B]&0E9I97<O9&%Y+G!H<"QV(#$N,3,N-"XW(#(P,#8O,#$O,#$@
M,C$Z,CDZ,#,@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!A=71H;W(@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!P86-K86=E($MR;VYO;&ET
M:`H@*B\*8VQA<W,@2W)O;F]L:71H7T9R965"=7-Y7U9I97=?9&%Y(&5X=&5N
M9',@2W)O;F]L:71H7T9R965"=7-Y7U9I97<@>PH*("`@('9A<B`D=FEE=R`]
M("=D87DG.PH@("`@=F%R("1?=&EM94)L;V-K<R`](&%R<F%Y*"D["@H@("`@
M9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES
M=')Y+"`D<')E9G,["@H@("`@("`@(')E='5R;B!(;W)D93HZ;&EN:R@G(R<L
M(%\H(E!R979I;W5S($1A>2(I+"`G)RP@)R<L("=R971U<FX@<W=I=&-H5&EM
M97-T86UP*"<@+B`H)'1H:7,M/E]S=&%R=%-T86UP("T@.#8T,#`I("X@)RD[
M)RD@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=N878O;&5F="YP;F<G+"`G
M/"<L(&YU;&PL("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X*
M("`@("`@("`@("`@)SPO83XG("X*("`@("`@("`@("`@<W1R9G1I;64H)'!R
M969S+3YG971686QU92@G9&%T95]F;W)M870G*2P@)'1H:7,M/E]S=&%R=%-T
M86UP*2`N"B`@("`@("`@("`@($AO<F1E.CIL:6YK*"<C)RP@7R@B3F5X="!$
M87DB*2P@)R<L("<G+"`G<F5T=7)N('-W:71C:%1I;65S=&%M<"@G("X@*"1T
M:&ES+3Y?<W1A<G13=&%M<"`K(#@V-#`P*2`N("<I.R<I("X*("`@("`@("`@
M("`@2&]R9&4Z.FEM9R@G;F%V+W)I9VAT+G!N9R<L("<^)RP@;G5L;"P@)')E
M9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+@H@("`@("`@("`@("`G
M/"]A/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7VAO=7)S*"D*("`@('L*("`@
M("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("`D:&]U<G-?:'1M;"`]("<G
M.PH@("`@("`@("1W:61T:"`](')O=6YD*#$P,"`O("@D=&AI<RT^7V5N9$AO
M=7(@+2`D=&AI<RT^7W-T87)T2&]U<B`K(#$I*3L*("`@("`@("!F;W(@*"1I
M(#T@)'1H:7,M/E]S=&%R=$AO=7([("1I(#P@)'1H:7,M/E]E;F1(;W5R.R`D
M:2LK*2!["B`@("`@("`@("`@("1T(#T@;6MT:6UE*"1I+"`P+"`P+"!D871E
M*"=N)RP@)'1H:7,M/E]S=&%R=%-T86UP*2P@9&%T92@G:B<L("1T:&ES+3Y?
M<W1A<G13=&%M<"DL(&1A=&4H)UDG+"`D=&AI<RT^7W-T87)T4W1A;7`I*3L*
M("`@("`@("`@("`@)'1H:7,M/E]T:6UE0FQO8VMS6R1T72`](&UK=&EM92@D
M:2`K(#$L(#`L(#`L(&1A=&4H)VXG+"`D=&AI<RT^7W-T87)T4W1A;7`I+"!D
M871E*"=J)RP@)'1H:7,M/E]S=&%R=%-T86UP*2P@9&%T92@G62<L("1T:&ES
M+3Y?<W1A<G13=&%M<"DI("T@,3L*("`@("`@("`@("`@)&AO=7)S7VAT;6P@
M+CT@)SQT:"!W:61T:#TB)R`N("1W:61T:"`N("<E(CXG("X@9&%T92@D<')E
M9G,M/F=E=%9A;'5E*"=T=V5N='E&;W5R)RD@/R`G1SHP,"<@.B`G9SHP,"<L
M("1T*2`N("<\+W1H/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AO
M=7)S7VAT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<B@D9&%Y(#T@
M;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("!I
M9B`H:7-?;G5L;"@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@=&EM92@I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W-T87)T4W1A;7`@/2!M:W1I
M;64H)'1H:7,M/E]S=&%R=$AO=7(L(#`L(#`L(&1A=&4H)VXG+"`D9&%Y*2P@
M9&%T92@G:B<L("1D87DI+"!D871E*"=9)RP@)&1A>2DI.PH@("`@("`@("1T
M:&ES+3Y?96YD4W1A;7`@/2!M:W1I;64H)'1H:7,M/E]E;F1(;W5R+"`P+"`P
M+"!D871E*"=N)RP@)&1A>2DL(&1A=&4H)VHG+"`D9&%Y*2P@9&%T92@G62<L
M("1D87DI*3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:W)O;F]L:71H+VQI8B]&0E9I97<O=V]R:W=E96LN<&AP````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3(Q-P`Q,#0Q-S,V,C<U,P`P,C(V-S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O=V5E:RYP:'`G
M.PH*+RHJ"B`J(%1H:7,@8VQA<W,@<F5P<F5S96YT(&$@=V]R:W=E96L@9F)V
M:65W(&]F(&UU;&ET<&QE(&9R964@8G5S>2!I;F9O<FUA=&EO;BX*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N+@H@*@H@*B`D
M2&]R9&4Z(&MR;VYO;&ET:"]L:6(O1D)6:65W+W=O<FMW965K+G!H<"QV(#$N
M-RXQ,"XT(#(P,#8O,#$O,#$@,C$Z,CDZ,#,@:F%N($5X<"`D"B`J"B`J($!A
M=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M($!P86-K86=E($MR;VYO;&ET:`H@*B\*8VQA<W,@2W)O;F]L:71H7T9R965"
M=7-Y7U9I97=?=V]R:W=E96L@97AT96YD<R!+<F]N;VQI=&A?1G)E94)U<WE?
M5FEE=U]W965K('L*"B`@("!V87(@)'9I97<@/2`G=V]R:W=E96LG.PH@("`@
M=F%R("1?9&%Y<R`](#4["@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]&0E9I97<O=V5E:RYP:'``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S,P,0`Q,#0Q-S,V,C<U,P`P,C$W
M-C<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H:7,@8VQA<W,@<F5P<F5S96YT(&$@=V5E:R!F8G9I
M97<@;V8@;75L:71P;&4@9G)E92!B=7-Y(&EN9F]R;6%T:6]N+@H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VXN"B`J"B`J("1(
M;W)D93H@:W)O;F]L:71H+VQI8B]&0E9I97<O=V5E:RYP:'`L=B`Q+C$Q+C0N
M.2`R,#`V+S`Q+S`Q(#(Q.C(Y.C`S(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R
M("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`
M875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<&%C
M:V%G92!+<F]N;VQI=&@*("HO"F-L87-S($MR;VYO;&ET:%]&<F5E0G5S>5]6
M:65W7W=E96L@97AT96YD<R!+<F]N;VQI=&A?1G)E94)U<WE?5FEE=R!["@H@
M("`@=F%R("1V:65W(#T@)W=E96LG.PH@("`@=F%R("1?9&%Y<R`](#<["B`@
M("!V87(@)%]T:6UE0FQO8VMS(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!?
M=&ET;&4H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1P<F5F
M<SL*"B`@("`@("`@<F5T=7)N($AO<F1E.CIL:6YK*"<C)RP@7R@B4')E=FEO
M=7,@5V5E:R(I+"`G)RP@)R<L("=R971U<FX@<W=I=&-H5&EM97-T86UP*"<@
M+B`H)'1H:7,M/E]S=&%R=%-T86UP("T@-R`J(#@V-#`P*2`N("<I.R<I("X*
M("`@("`@("`@("`@2&]R9&4Z.FEM9R@G;F%V+VQE9G0N<&YG)RP@)SPG+"!N
M=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N"B`@("`@
M("`@("`@("<\+V$^)R`N"B`@("`@("`@("`@('-T<F9T:6UE*"1P<F5F<RT^
M9V5T5F%L=64H)V1A=&5?9F]R;6%T)RDL("1T:&ES+3Y?<W1A<G13=&%M<"D@
M+@H@("`@("`@("`@("`G("T@)R`N"B`@("`@("`@("`@('-T<F9T:6UE*"1P
M<F5F<RT^9V5T5F%L=64H)V1A=&5?9F]R;6%T)RDL("1T:&ES+3Y?<W1A<G13
M=&%M<"`K("@H)'1H:7,M/E]D87ES("T@,2D@*B`X-C0P,"DI("X*("`@("`@
M("`@("`@2&]R9&4Z.FQI;FLH)R,G+"!?*").97AT(%=E96LB*2P@)R<L("<G
M+"`G<F5T=7)N('-W:71C:%1I;65S=&%M<"@G("X@*"1T:&ES+3Y?<W1A<G13
M=&%M<"`K(#<@*B`X-C0P,"D@+B`G*3LG*2`N"B`@("`@("`@("`@($AO<F1E
M.CII;6<H)VYA=B]R:6=H="YP;F<G+"`G/B<L(&YU;&PL("1R96=I<W1R>2T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI("X*("`@("`@("`@("`@)SPO83XG.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]H;W5R<R@I"B`@("!["B`@("`@("`@9VQO
M8F%L("1P<F5F<SL*"B`@("`@("`@)&AO=7)S7VAT;6P@/2`G)SL*("`@("`@
M("`D9&%Y5VED=&@@/2!R;W5N9"@Q,#`@+R`D=&AI<RT^7V1A>7,I.PH@("`@
M("`@("1S<&%N(#T@9FQO;W(H*"1T:&ES+3Y?96YD2&]U<B`M("1T:&ES+3Y?
M<W1A<G1(;W5R*2`O(#,I.PH@("`@("`@(&EF("@H)'1H:7,M/E]E;F1(;W5R
M("T@)'1H:7,M/E]S=&%R=$AO=7(I("4@,RD@>PH@("`@("`@("`@("`D<W!A
M;BLK.PH@("`@("`@('T*("`@("`@("`D9&%T95]F;W)M870@/2`D<')E9G,M
M/F=E=%9A;'5E*"=D871E7V9O<FUA="<I.PH@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1T:&ES+3Y?9&%Y<SL@)&DK*RD@>PH@("`@("`@("`@("`D="`]
M(&UK=&EM92@P+"`P+"`P+"!D871E*"=N)RP@)'1H:7,M/E]S=&%R=%-T86UP
M*2P@9&%T92@G:B<L("1T:&ES+3Y?<W1A<G13=&%M<"D@*R`D:2P@9&%T92@G
M62<L("1T:&ES+3Y?<W1A<G13=&%M<"DI.PH@("`@("`@("`@("`D9&%Y7VQA
M8F5L(#T@<W1R9G1I;64H)&1A=&5?9F]R;6%T+"`D="D["B`@("`@("`@("`@
M("1H;W5R<U]H=&UL("X]('-P<FEN=&8H)SQT:"!C;VQS<&%N/2(E9"(@=VED
M=&@](B5S)24B/B5S/"]T:#XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S<&%N+"`D9&%Y5VED=&@L("1D87E?;&%B96PI.PH@("`@
M("`@('T*("`@("`@("`D:&]U<G-?:'1M;"`N/2`G/"]T<CX\='(^/'1D('=I
M9'1H/2(Q,#`B(&-L87-S/2)L86)E;"(^)FYB<W`[/"]T9#XG.PH*("`@("`@
M("`D=VED=&@@/2!R;W5N9"@Q,#`@+R`H)'-P86X@*B`D=&AI<RT^7V1A>7,I
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^7V1A>7,[("1I
M*RLI('L*("`@("`@("`@("`@9F]R("@D:"`]("1T:&ES+3Y?<W1A<G1(;W5R
M.R`D:"`\("1T:&ES+3Y?96YD2&]U<CL@)&@@*ST@,RD@>PH@("`@("`@("`@
M("`@("`@)'0@/2!M:W1I;64H)&@L(#`L(#`L(&1A=&4H)VXG+"`D=&AI<RT^
M7W-T87)T4W1A;7`I+"!D871E*"=J)RP@)'1H:7,M/E]S=&%R=%-T86UP*2`K
M("1I+"!D871E*"=9)RP@)'1H:7,M/E]S=&%R=%-T86UP*2D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W1I;65";&]C:W-;)'1=(#T@;6MT:6UE*"1H("L@
M,RP@,"P@,"P@9&%T92@G;B<L("1T:&ES+3Y?<W1A<G13=&%M<"DL(&1A=&4H
M)VHG+"`D=&AI<RT^7W-T87)T4W1A;7`I("L@)&DL(&1A=&4H)UDG+"`D=&AI
M<RT^7W-T87)T4W1A;7`I*2`M(#$["@H@("`@("`@("`@("`@("`@)&AO=7(@
M/2!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G*2`_("='.C`P
M)R`Z("=G.C`P)RP@)'0I.PH@("`@("`@("`@("`@("`@)&AO=7)S7VAT;6P@
M+CT@<W!R:6YT9B@G/'1H('=I9'1H/2(E9"4E(CXE<SPO=&@^)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=I9'1H+"`D:&]U
M<BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:&]U<G-?:'1M;"`N("<\+W1R/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<B@D9&%Y(#T@;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S
M.PH*("`@("`@("!I9B`H:7-?;G5L;"@D9&%Y*2D@>PH@("`@("`@("`@("!L
M:7-T*"1S=&%R=$1A=&5;)WEE87(G72P@)'-T87)T1&%T95LG;6]N=&@G72P@
M)'-T87)T1&%T95LG;61A>2==*2`](&5X<&QO9&4H)RTG+"!$871E7T-A;&,Z
M.F)E9VEN3V97965K*&YU;&PL(&YU;&PL(&YU;&PL("(E62TE;2TE9"(I*3L*
M("`@("`@("`@("`@)&1A>2`](&UK=&EM92@P+"`P+"`P+"`D<W1A<G1$871E
M6R=M;VYT:"==+"`D<W1A<G1$871E6R=M9&%Y)UTL("1S=&%R=$1A=&5;)WEE
M87(G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D<W1A
M<G1$871E6R=Y96%R)UTL("1S=&%R=$1A=&5;)VUO;G1H)UTL("1S=&%R=$1A
M=&5;)VUD87DG72D@/2!E>'!L;V1E*"<M)RP@1&%T95]#86QC.CIB96=I;D]F
M5V5E:RAD871E*"=J)RP@)&1A>2DL(&1A=&4H)VXG+"`D9&%Y*2P@9&%T92@G
M62<L("1D87DI+"`B)5DM)6TM)60B*2D["B`@("`@("`@("`@("1D87D@/2!M
M:W1I;64H,"P@,"P@,"P@)'-T87)T1&%T95LG;6]N=&@G72P@)'-T87)T1&%T
M95LG;61A>2==+"`D<W1A<G1$871E6R=Y96%R)UTI.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^7W-T87)T4W1A;7`@/2!M:W1I;64H,"P@,"P@,"P@9&%T
M92@G;B<L("1D87DI+"!D871E*"=J)RP@)&1A>2DL(&1A=&4H)UDG+"`D9&%Y
M*2D["B`@("`@("`@)'1H:7,M/E]E;F13=&%M<"`@(#T@;6MT:6UE*#(S+"`U
M.2P@-3DL(&1A=&4H)VXG+"`D9&%Y*2`K("1T:&ES+3Y?9&%Y<R`M(#$L(&1A
M=&4H)VHG+"`D9&%Y*2P@9&%T92@G62<L("1D87DI*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]38VAE
M9'5L97(O````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<U,P`P,C$Q,C$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K
M<F]N;VQI=&@O;&EB+U-C:&5D=6QE<B]K<F]N;VQI=&@N<&AP````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(P-S8W`#$P-#$W,S8R-S4S`#`R,S8U-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@2&]R9&5?4V-H961U;&5R7VMR;VYO;&ET:#HZ"B`J"B`J($%C="!O;B!A
M;&%R;7,@:6X@979E;G1S(&%N9"!S96YD(&5M86EL<R]P86=E<R]E=&,N('1O
M('5S97)S+@H@*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]L:6(O4V-H961U;&5R
M+VMR;VYO;&ET:"YP:'`L=B`Q+C(U+C8N,3`@,C`P-B\P,B\Q.2`R,SHU-CHT
M."!C:'5C:R!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]38VAE9'5L97(*
M("HO"F-L87-S($AO<F1E7U-C:&5D=6QE<E]K<F]N;VQI=&@@97AT96YD<R!(
M;W)D95]38VAE9'5L97(@>PH*("`@("\J*@H@("`@("H@0V%C:&4@;V8@979E
M;G0@:61S('1H870@:&%V92!A;')E861Y(&)E96X@<V5E;B]H860@<F5M:6YD
M97)S('-E;G0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]S965N(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!L
M:7-T(&]F(&-A;&5N9&%R<RX@5V4@<W1O<F4@=&AI<R!S;R!W92=R92!N;W0@
M9F5T8VAI;F<@:70@86QL('1H90H@("`@("H@=&EM92P@8G5T('5P9&%T92!T
M:&4@8V%C:&4@;V-C87-I;VYA;&QY('1O(&9I;F0@;F5W(&-A;&5N9&%R<RX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-A
M;&5N9&%R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@;&%S="!T
M:6UE<W1A;7`@=&AA="!W92!R86XN"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D7W)U;G1I;64["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;&%S="!T:6UE('=E(&9E=&-H960@=&AE(&9U;&P@8V%L96YD87(@
M;&ES="X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?;&ES='1I;64["@H@("`@9G5N8W1I;VX@2&]R9&5?4V-H961U;&5R
M7VMR;VYO;&ET:"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!P
M87)E;G0Z.DAO<F1E7U-C:&5D=6QE<B@D<&%R86US*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!R=6XH*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@
M("`@("`@)'1H:7,M/E]R=6YT:6UE(#T@=&EM92@I.PH*("`@("`@("`O+R!)
M9B!W92!H879E;B=T(&9E=&-H960@=&AE(&QI<W0@;V8@8V%L96YD87)S(&EN
M(&]V97(@86X*("`@("`@("`O+R!H;W5R+"!R92UL:7-T('1O('!I8VL@=7`@
M86YY(&YE=R!O;F5S+@H@("`@("`@(&EF("@D=&AI<RT^7W)U;G1I;64@+2`D
M=&AI<RT^7VQI<W1T:6UE(#X@,S8P,"D@>PH@("`@("`@("`@("!G;&]B86P@
M)'-H87)E<SL*"B`@("`@("`@("`@("1T:&ES+3Y?;&ES='1I;64@/2`D=&AI
M<RT^7W)U;G1I;64["B`@("`@("`@("`@("1T:&ES+3Y?8V%L96YD87)S(#T@
M)'-H87)E<RT^;&ES=$%L;%-H87)E<R@I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@268@=&AE<F4@87)E(&YO(&-A;&5N9&%R<R!T;R!M;VYI=&]R+"!J=7-T
M(')E='5R;BX*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?8V%L96YD87)S
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1C;VYF6R=R96UI;F1E<B==6R=S97)V97)?;F%M92==*2D@
M>PH@("`@("`@("`@("`D8V]N9ELG<V5R=F5R)UU;)VYA;64G72`]("1C;VYF
M6R=R96UI;F1E<B==6R=S97)V97)?;F%M92==.PH@("`@("`@('T*"B`@("`@
M("`@+R\@0VAE8VL@9F]R(&%L87)M<R!A;F0@86-T(&]N('1H96TN"B`@("`@
M("`@)&MR;VYO;&ET:"`]("9+<F]N;VQI=&A?1')I=F5R.CIF86-T;W)Y*"D[
M"B`@("`@("`@)&%L87)M<R`]($MR;VYO;&ET:#HZ;&ES=$%L87)M<RAN97<@
M2&]R9&5?1&%T92@D=&AI<RT^7W)U;G1I;64I+"!A<G)A>5]K97ES*"1T:&ES
M+3Y?8V%L96YD87)S*2D["B`@("`@("`@9F]R96%C:"`H)&%L87)M<R!A<R`D
M8V%L260@/3X@)&-A;&%R;7,I('L*("`@("`@("`@("`@)&MR;VYO;&ET:"T^
M;W!E;B@D8V%L260I.PH@("`@("`@("`@("!F;W)E86-H("@D8V%L87)M<R!A
M<R`D979E;G1)9"D@>PH@("`@("`@("`@("`@("`@)&5V96YT(#T@)B1K<F]N
M;VQI=&@M/F=E=$5V96YT*"1E=F5N=$ED*3L*("`@("`@("`@("`@("`@(&EF
M("AI<U]A*"1E=F5N="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("\J(%-E="!T:&4@979E;G0G<R!S=&%R="!D871E('1O('1H92!N
M97AT(')E8W5R<F5N8V4*("`@("`@("`@("`@("`@("`J(&1A=&4N(%1H:7,@
M<VAO=6QD(&%V;VED('!R;V)L96US('=H96X@86X@86QA<FT*("`@("`@("`@
M("`@("`@("`J('1R:6=G97)S(&]N(&$@9&EF9F5R96YT(&1A>2!F<F]M('1H
M92!A8W1U86P@979E;G0L"B`@("`@("`@("`@("`@("`@*B!A;F0@;6%K92`D
M<V5E;FED('5N:7%U92!F;W(@96%C:"!O8V-U<G)E;F-E(&]F(&$*("`@("`@
M("`@("`@("`@("`J(')E8W5R<FEN9R!E=F5N="X@*B\*("`@("`@("`@("`@
M("`@("1E=F5N="T^<W1A<G0@/2`D979E;G0M/FYE>'1296-U<G)E;F-E*"1T
M:&ES+3Y?<G5N=&EM92D["@H@("`@("`@("`@("`@("`@+RH@0VAE8VL@9F]R
M(&5X8V5P=&EO;G,[(&1O(&YO=&AI;F<@:68@;VYE(&ES(&9O=6YD+B`J+PH@
M("`@("`@("`@("`@("`@:68@*"1E=F5N="T^:&%S17AC97!T:6]N*"1E=F5N
M="T^<W1A<G0M/GEE87(L("1E=F5N="T^<W1A<G0M/FUO;G1H+"`D979E;G0M
M/G-T87)T+3YM9&%Y*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S965N:60@
M/2`D979E;G1)9"`N("1E=F5N="T^<W1A<G0M/G1I;65S=&%M<"@I("X@)&5V
M96YT+3YG971!;&%R;2@I.PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W-E96Y;)'-E96YI9%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S965N6R1S965N:61=(#T@=')U93L*("`@("`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/G)E;6EN9"@D8V%L260L("1E=F5N="D[
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(')E;6EN9"@D8V%L260L("8D979E;G0I"B`@("!["B`@("`@("`@9VQO8F%L
M("1K<F]N;VQI=&@L("1C;VYF+"`D<VAA<F5S.PH*("`@("`@("!I9B`H)&MR
M;VYO;&ET:"T^9V5T0V%L96YD87(H*2`A/2`D8V%L260I('L*("`@("`@("`@
M("`@)&MR;VYO;&ET:"T^;W!E;B@D8V%L260I.PH@("`@("`@('T*"B`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+TU)344N<&AP)SL*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TU)344O2&5A9&5R<RYP:'`G.PH@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O34E-12]-97-S86=E+G!H<"<["@H@("`@("`@("\J($1E
M<VER960@;&]G:6,Z(&QI<W0@=7-E<G,@86YD(&=R;W5P<R!T:&%T(&-A;B!V
M:65W("1C86Q)9"P@86YD('-E;F0*("`@("`@("`@*B!E;6%I;"!T;R!A;GD@
M;V8@=&AE;2!T:&%T('=E(&-A;B!F:6YD(&%N(&5M86EL(&%D9')E<W,@9F]R
M+B!4:&ES"B`@("`@("`@("H@=VEL;"!H;W!E9G5L;'D@8F4@:6UP<F]V960@
M870@<V]M92!P;VEN="!S;R!T:&%T('!E;W!L92!D;VXG="!G970*("`@("`@
M("`@*B!M=6QT:7!L92!E;6%I;',L(&%N9"!C86X@<V5T(&UO<F4@<')E9F5R
M96YC97,@;VX@:&]W('1H97D@=V%N="!T;PH@("`@("`@("`J(&)E(&YO=&EF
M:65D+B`J+PH@("`@("`@("1S:&%R92`]("1S:&%R97,M/F=E=%-H87)E*"1C
M86Q)9"D["B`@("`@("`@:68@*&ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1R
M96-I<&EE;G1S(#T@87)R87DH*3L*("`@("`@("`D96UA:6QS(#T@87)R87DH
M*3L*"B`@("`@("`@)'5S97)S(#T@)'-H87)E+3YL:7-T57-E<G,H4$5235-?
M4D5!1"D["B`@("`@("`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*2!["B`@
M("`@("`@("`@(&EF("AE;7!T>2@D96UA:6QS6R1U<V5R72DI('L*("`@("`@
M("`@("`@("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"=N
M;VYE)RP@)'5S97(I.PH@("`@("`@("`@("`@("`@)&5M86EL(#T@)&ED96YT
M:71Y+3YG971686QU92@G9G)O;5]A9&1R)RD["B`@("`@("`@("`@("`@("!I
M9B`H<W1R<W1R*"1E;6%I;"P@)T`G*2D@>PH@("`@("`@("`@("`@("`@("`@
M(&QI<W0H)&UA:6QB;W@L("1H;W-T*2`](&5X<&QO9&4H)T`G+"`D96UA:6PI
M.PH@("`@("`@("`@("`@("`@("`@("1E;6%I;'-;)'5S97)=(#T@34E-13HZ
M<F9C.#(R5W)I=&5!9&1R97-S*"1M86EL8F]X+"`D:&]S="P@)&ED96YT:71Y
M+3YG971686QU92@G9G5L;&YA;64G*2D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A96UP='DH)&5M86EL<ULD
M=7-E<ETI*2!["B`@("`@("`@("`@("`@("`D<')E9G,@/2`F4')E9G,Z.G-I
M;F=L971O;B@D8V]N9ELG<')E9G,G75LG9')I=F5R)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K<F]N;VQI=&@G+"`D=7-E
M<BD["B`@("`@("`@("`@("`@("`D<')E9G,M/G)E=')I979E*"D["B`@("`@
M("`@("`@("`@("`D<VAO=VY?8V%L96YD87)S(#T@=6YS97)I86QI>F4H)'!R
M969S+3YG971686QU92@G9&ES<&QA>5]C86QS)RDI.PH@("`@("`@("`@("`@
M("`@)')E;6EN9&5R(#T@)'!R969S+3YG971686QU92@G979E;G1?<F5M:6YD
M97(G*3L*("`@("`@("`@("`@("`@(&EF("@H)')E;6EN9&5R(#T]("=O=VYE
M<B<@)B8@)'5S97(@/3T@)'-H87)E+3YG970H)V]W;F5R)RDI('Q\"B`@("`@
M("`@("`@("`@("`@("`@*"1R96UI;F1E<B`]/2`G<VAO=R<@)B8@:6Y?87)R
M87DH)&-A;$ED+"`D<VAO=VY?8V%L96YD87)S*2D@?'P*("`@("`@("`@("`@
M("`@("`@("`D<F5M:6YD97(@/3T@)W)E860G*2!["B`@("`@("`@("`@("`@
M("`@("`@)&QA;F<@/2`D<')E9G,M/F=E=%9A;'5E*"=L86YG=6%G92<I.PH@
M("`@("`@("`@("`@("`@("`@("1T=V5N='E&;W5R(#T@)'!R969S+3YG9716
M86QU92@G='=E;G1Y1F]U<B<I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)')E8VEP:65N='-;)&QA;F==6R1T=V5N='E&;W5R72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)')E8VEP:65N='-;)&QA;F==6R1T=V5N
M='E&;W5R72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1R96-I<&EE;G1S6R1L86YG75LD='=E;G1Y1F]U
M<EU;72`]("1E;6%I;'-;)'5S97)=.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D9W)O=7!S(#T@)'-H87)E
M+3YL:7-T1W)O=7!S*%!%4DU37U)%040I.PH@("`@("`@("1G<F]U<$UA;F%G
M97(@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH@("`@("`@(&9O<F5A8V@@*"1G
M<F]U<',@87,@)&=I9"D@>PH@("`@("`@("`@("!I9B`H96UP='DH)&5M86EL
M<ULD9VED72DI('L*("`@("`@("`@("`@("`@("1G<F]U<"`]("1G<F]U<$UA
M;F%G97(M/F=E=$=R;W5P0GE)9"@D9VED*3L*("`@("`@("`@("`@("`@(&EF
M("@D96UA:6P@/2`D9W)O=7`M/F=E="@G96UA:6PG*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1E;6%I;'-;)&=I9%T@/2`D9W)O=7`M/F=E="@G96UA:6PG
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D96UA:6QS6R1G:61=*2D@>PH@("`@("`@("`@("`@
M("`@)'!R969S(#T@)E!R969S.CIS:6YG;&5T;VXH)&-O;F9;)W!R969S)UU;
M)V1R:79E<B==+"`G:&]R9&4G+"`D9VED*3L*("`@("`@("`@("`@("`@("1P
M<F5F<RT^<F5T<FEE=F4H*3L*("`@("`@("`@("`@("`@("1L86YG(#T@)'!R
M969S+3YG971686QU92@G;&%N9W5A9V4G*3L*("`@("`@("`@("`@("`@("1T
M=V5N='E&;W5R(#T@)'!R969S+3YG971686QU92@G='=E;G1Y1F]U<B<I.PH@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<F5C:7!I96YT<ULD;&%N9UU;
M)'1W96YT>49O=7)=*2D@>PH@("`@("`@("`@("`@("`@("`@("1R96-I<&EE
M;G1S6R1L86YG75LD='=E;G1Y1F]U<ET@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)')E8VEP:65N='-;)&QA;F==6R1T
M=V5N='E&;W5R75M=(#T@)&5M86EL<ULD9VED73L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"$D<F5C:7!I96YT<RD@>PH@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=.;R!E;6%I;"!A9&1R
M97-S97,@879A:6QA8FQE('1O('-E;F0@<F5M:6YD97(@9F]R("5S('1O(')E
M8VEP:65N="AS*3H@)7,@)7,G+"`D979E;G0M/G1I=&QE+"!I;7!L;V1E*"<L
M("<L("1U<V5R<RDL(&EM<&QO9&4H)RP@)RP@)&=R;W5P<RDI+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D;7-G7VAE861E<G,@/2`F
M;F5W($U)345?2&5A9&5R<R@I.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D
M365S<V%G94ED2&5A9&5R*"D["B`@("`@("`@)&US9U]H96%D97)S+3YA9&1!
M9V5N=$AE861E<B@I.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R
M*"=$871E)RP@9&%T92@G<B<I*3L*("`@("`@("`D;7-G7VAE861E<G,M/F%D
M9$AE861E<B@G5&\G+"`G0V%L96YD87)296UI;F1E<G,Z.R<I.PH@("`@("`@
M("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=&<F]M)RP@)&-O;F9;)W)E;6EN
M9&5R)UU;)V9R;VU?861D<B==*3L*"B`@("`@("`@)&UA:6Q?9')I=F5R(#T@
M)&-O;F9;)VUA:6QE<B==6R=T>7!E)UT["B`@("`@("`@)&UA:6Q?<&%R86US
M(#T@)&-O;F9;)VUA:6QE<B==6R=P87)A;7,G73L*("`@("`@("!I9B`H)&UA
M:6Q?9')I=F5R(#T]("=S;71P)R`F)B`D;6%I;%]P87)A;7-;)V%U=&@G72`F
M)@H@("`@("`@("`@("!E;7!T>2@D;6%I;%]P87)A;7-;)W5S97)N86UE)UTI
M*2!["B`@("`@("`@("`@("1M86EL7W!A<F%M<ULG=7-E<FYA;64G72`]($%U
M=&@Z.F=E=$%U=&@H*3L*("`@("`@("`@("`@)&UA:6Q?<&%R86US6R=P87-S
M=V]R9"==(#T@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G*3L*("`@
M("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1R96-I<&EE;G1S(&%S("1L86YG
M(#T^("1L86YG7W)E8VEP:65N=',I('L*("`@("`@("`@("`@3DQ3.CIS971,
M86YG*"1L86YG*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YR96UO=F5(
M96%D97(H)U-U8FIE8W0G*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA
M9&1(96%D97(H)U-U8FIE8W0G+"!S<')I;G1F*%\H(E)E;6EN9&5R.B`E<R(I
M+"`D979E;G0M/G1I=&QE*2D["@H@("`@("`@("`@("!F;W)E86-H("@D;&%N
M9U]R96-I<&EE;G1S(&%S("1T=V5N='E&;W5R(#T^("1T9E]R96-I<&EE;G1S
M*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](")<;B(@+B!S<')I;G1F
M*%\H(EEO=2!R97%U97-T960@=&\@8F4@<F5M:6YD960@86)O=70@)7,L('=H
M:6-H(&ES(&]N("5S(&%T("5S+B(I+"`D979E;G0M/G1I=&QE+"!S=')F=&EM
M92@G)7@G+"`D979E;G0M/G-T87)T+3YT:6UE<W1A;7`H*2DL(&1A=&4H)'1W
M96YT>49O=7(@/R`G2#II)R`Z("=H.FEA)RP@)&5V96YT+3YS=&%R="T^=&EM
M97-T86UP*"DI*2`N(")<;EQN(B`N("1E=F5N="T^9V5T1&5S8W)I<'1I;VXH
M*3L*"B`@("`@("`@("`@("`@("`D;6EM92`]("9N97<@34E-15]-97-S86=E
M*"D["B`@("`@("`@("`@("`@("`D8F]D>2`]("9N97<@34E-15]087)T*"=T
M97AT+W!L86EN)RP@4W1R:6YG.CIW<F%P*"1M97-S86=E+"`W-BP@(EQN(BDL
M($Y,4SHZ9V5T0VAA<G-E="@I*3L*"B`@("`@("`@("`@("`@("`D;6EM92T^
M861D4&%R="@D8F]D>2D["B`@("`@("`@("`@("`@("`D;7-G7VAE861E<G,M
M/F%D9$U)345(96%D97)S*"1M:6UE*3L*"B`@("`@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92AS<')I;G1F*"=396YD:6YG(')E;6EN9&5R(&9O<B`E
M<R!T;R`E<R<L("1E=F5N="T^=&ET;&4L(&EM<&QO9&4H)RP@)RP@)'1F7W)E
M8VEP:65N=',I*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@("`@("`@("`D<V5N="`]("1M:6UE+3YS96YD*&EM<&QO
M9&4H)RP@)RP@)'1F7W)E8VEP:65N=',I+"`D;7-G7VAE861E<G,L("1M86EL
M7V1R:79E<BP@)&UA:6Q?<&%R86US*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1S96YT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1S96YT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O
M;&EB+T1R:79E<B\`````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`R,#0S-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VMR;VYO;&ET:"]L:6(O1')I=F5R+VEC86PN<&AP````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<R-34`,3`T,3<S-C(W-3,`,#(R,#8U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@2W)O;F]L:71H7T1R:79E<E]I8V%L.CH@8VQA<W,@
M:6UP;&5M96YT<R!T:&4@2W)O;F]L:71H7T1R:79E<@H@*B!!4$D@9F]R(&E#
M86QE;F1A<B!D871A+@H@*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]L:6(O1')I
M=F5R+VEC86PN<&AP+'8@,2XS+C(N-"`R,#`U+S$P+S$X(#$R.C(W.C,Q(&IA
M;B!%>'`@)`H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2W)O;F]L:71H(#(N,`H@*B!`<&%C
M:V%G92!+<F]N;VQI=&@*("HO"F-L87-S($MR;VYO;&ET:%]$<FEV97)?:6-A
M;"!E>'1E;F1S($MR;VYO;&ET:%]$<FEV97(@>PH*("`@("\J*@H@("`@("H@
M0V%C:&4@979E;G1S(&%S('=E(&9E=&-H('1H96T@=&\@879O:60@9F5T8VAI
M;F<@;W(@<&%R<VEN9R!T:&4@<V%M90H@("`@("H@979E;G0@='=I8V4N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C86-H
M92`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@;W!E;B@D8V%L96YD87(I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]C86QE;F1A<B`]("1C86QE;F1A<CL*("`@
M('T*"B`@("!F=6YC=&EO;B!L:7-T06QA<FUS*"1D871E*0H@("`@>PH@("`@
M("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&QI<W1%
M=F5N=',H)'-T87)T1&%T92`](&YU;&PL("1E;F1$871E(#T@;G5L;"P@)&AA
M<T%L87)M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&1A=&$@/2!+<F]N;VQI
M=&@Z.F=E=%)E;6]T94-A;&5N9&%R*"1U<FPI.PH@("`@("`@(&EF("AI<U]A
M*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M9&%T83L*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M:4-A;&5N9&%R+G!H<"<["B`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#
M86QE;F1A<B@I.PH@("`@("`@(&EF("@A)&E#86PM/G!A<G-E=D-A;&5N9&%R
M*"1D871A*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@
M("!]"@H@("`@("`@("1C;VUP;VYE;G1S(#T@)&E#86PM/F=E=$-O;7!O;F5N
M=',H*3L*("`@("`@("`D979E;G1S(#T@87)R87DH*3L*("`@("`@("`D8V]U
M;G0@/2!C;W5N="@D8V]M<&]N96YT<RD["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1C;VUP;VYE;G0@
M/2`D8V]M<&]N96YT<ULD:5T["B`@("`@("`@("`@(&EF("@D8V]M<&]N96YT
M+3YG9714>7!E*"D@/3T@)W9%=F5N="<I('L*("`@("`@("`@("`@("`@("1E
M=F5N="`]("9N97<@2W)O;F]L:71H7T5V96YT7VEC86PH)'1H:7,I.PH@("`@
M("`@("`@("`@("`@)&5V96YT+3YF<F]M:4-A;&5N9&%R*"1C;VUP;VYE;G0I
M.PH@("`@("`@("`@("`@("`@)&5V96YT+3YR96UO=&5#86P@/2`D=7)L.PH@
M("`@("`@("`@("`@("`@)&5V96YT+3YE=F5N=$E$(#T@)&D["B`@("`@("`@
M("`@("`@("`D979E;G1S6UT@/2`D979E;G0["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D979E;G1S.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9G971%=F5N="@D979E;G1)9"`](&YU;&PI"B`@("!["B`@("`@
M("`@)&1A=&$@/2!+<F]N;VQI=&@Z.F=E=%)E;6]T94-A;&5N9&%R*"1U<FPI
M.PH@("`@("`@(&EF("AI<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("!]"@H@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H<"<["B`@("`@("`@)&E#
M86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@(&EF("@A)&E#
M86PM/G!A<G-E=D-A;&5N9&%R*"1D871A*2D@>PH@("`@("`@("`@("!R971U
M<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1C;VUP;VYE;G1S(#T@
M)&E#86PM/F=E=$-O;7!O;F5N=',H*3L*("`@("`@("!I9B`H:7-S970H)&-O
M;7!O;F5N='-;)&5V96YT261=*2`F)B`D8V]M<&]N96YT<ULD979E;G1)9%TM
M/F=E=%1Y<&4H*2`]/2`G=D5V96YT)RD@>PH@("`@("`@("`@("`D979E;G0@
M/2`F;F5W($MR;VYO;&ET:%]%=F5N=%]I8V%L*"1T:&ES*3L*("`@("`@("`@
M("`@)&5V96YT+3YF<F]M:4-A;&5N9&%R*"1C;VUP;VYE;G1S6R1E=F5N=$ED
M72D["B`@("`@("`@("`@("1E=F5N="T^<F5M;W1E0V%L(#T@)'5R;#L*("`@
M("`@("`@("`@)&5V96YT+3YE=F5N=$E$(#T@)&5V96YT260["@H@("`@("`@
M("`@("!R971U<FX@)&5V96YT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971">55)1"@D=6ED*0H@
M("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;W0@<W5P
M<&]R=&5D)RD["B`@("!]"@H@("`@9G5N8W1I;VX@97AI<W1S*"D*("`@('L*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F]T('-U<'!O<G1E
M9"<I.PH@("`@?0H*("`@(&9U;F-T:6]N('-A=F5%=F5N="@D979E;G0I"B`@
M("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO="!S=7!P
M;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J($UO=F4@86X@979E;G0@
M=&\@82!N97<@8V%L96YD87(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D979E;G1)9"`@("`@(%1H92!E=F5N="!T;R!M;W9E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F5W0V%L96YD87(@(%1H92!N97<@8V%L96YD87(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&UO=F4H)&5V96YT260L("1N97=#86QE;F1A
M<BD*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F]T
M('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@
M8V%L96YD87(@86YD(&%L;"!I=',@979E;G1S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&-A;&5N9&%R("!4:&4@;F%M92!O9B!T:&4@8V%L96YD
M87(@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E;&5T92@D8V%L96YD87(I"B`@("!["B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)TYO="!S=7!P;W)T960G*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E;&5T92!A;B!E=F5N="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1E=F5N=$ED("!4:&4@240@;V8@=&AE(&5V96YT('1O
M(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]R
M(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D96QE=&5%=F5N="@D979E;G1)9"D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G3F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"GT*"F-L87-S($MR;VYO;&ET:%]%=F5N=%]I8V%L(&5X=&5N9',@
M2W)O;F]L:71H7T5V96YT('L*"B`@("!F=6YC=&EO;B!F<F]M1')I=F5R*"1V
M179E;G0I"B`@("!["B`@("`@("`@)'1H:7,M/F9R;VUI0V%L96YD87(H)'9%
M=F5N="D["B`@("`@("`@)'1H:7,M/FEN:71I86QI>F5D(#T@=')U93L*("`@
M("`@("`D=&AI<RT^<W1O<F5D(#T@=')U93L*("`@('T*"B`@("!F=6YC=&EO
M;B!T;T1R:79E<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT;VE#
M86QE;F1A<B@I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L:6(O1')I=F5R
M+VMO;&%B+G!H<```````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#,S-#$`
M,3`T,3<S-C(W-3,`,#(R,C0Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TMO
M;&%B+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*
M"B\J*@H@*B!(;W)D92!+<F]N;VQI=&@@9')I=F5R(&9O<B!T:&4@2V]L86(@
M24U!4"!397)V97(N"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2&]R9&4@4')O
M:F5C="`H:'1T<#HO+VAO<F1E+F]R9R\I"B`J"B`J("1(;W)D93H@:W)O;F]L
M:71H+VQI8B]$<FEV97(O:V]L86(N<&AP+'8@,2XQ-BXR+C@@,C`P-B\P,B\P
M,B`Q,SHT.3HR,R!S96QS:WD@17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@(%-T=6%R="!":6YG92`\;VUI8W)O;D!M:6=H='DN8V\N>F$^"B`J
M($!S:6YC92`@($MR;VYO;&ET:"`R+C`*("H@0'!A8VMA9V4@2W)O;F]L:71H
M"B`J+PIC;&%S<R!+<F]N;VQI=&A?1')I=F5R7VMO;&%B(&5X=&5N9',@2W)O
M;F]L:71H7T1R:79E<B!["@H@("`@+RHJ"B`@("`@*B!/=7(@2V]L86(@<V5R
M=F5R(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!+;VQA8@H@("`@
M("HO"B`@("!V87(@)%]K;VQA8B`](&YU;&P["@H@("`@9G5N8W1I;VX@;W!E
M;B@D8V%L96YD87(I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M8V%L96YD87(I('Q\("1T:&ES+3Y?8V%L96YD87(@(3T@)&-A;&5N9&%R*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?8V%L96YD87(@/2`D8V%L96YD87(["B`@
M("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T*"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1I<V-O;FYE8W0H*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7VMO;&%B*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VMO
M;&%B(#T@)FYE=R!+;VQA8B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]K;VQA8BT^;W!E;B@D=&AI<RT^7V-A;&5N9&%R*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?:V]L86(I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]K;VQA8BT^8VQO<V4H
M*3L*("`@("`@("`D=&AI<RT^7VMO;&%B(#T@;G5L;#L*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@;&ES=$%L87)M<R@D9&%T
M92D*("`@('L*("`@("`@("`D86QL979E;G1S(#T@)'1H:7,M/FQI<W1%=F5N
M=',H)&1A=&4L("1D871E+"!T<G5E*3L*("`@("`@("`D979E;G1S(#T@87)R
M87DH*3L*"B`@("`@("`@9F]R96%C:"`H)&%L;&5V96YT<R!A<R`D979E;G1)
M9"D@>PH@("`@("`@("`@("`D979E;G0@/2`F)'1H:7,M/F=E=$5V96YT*"1E
M=F5N=$ED*3L*"B`@("`@("`@("`@(&EF("@D979E;G0M/F=E=%)E8W5R5'EP
M92@I(#T]($M23TY/3$E42%]214-54E].3TY%*2!["B`@("`@("`@("`@("`@
M("`D<W1A<G0@/2`F;F5W($AO<F1E7T1A=&4H)&5V96YT+3YS=&%R="D["B`@
M("`@("`@("`@("`@("`D<W1A<G0M/FUI;B`M/2`D979E;G0M/F=E=$%L87)M
M*"D["B`@("`@("`@("`@("`@("`D<W1A<G0M/F-O<G)E8W0H*3L*("`@("`@
M("`@("`@("`@(&EF("@D<W1A<G0M/F-O;7!A<F5$871E5&EM92@D9&%T92D@
M/#T@,"`F)@H@("`@("`@("`@("`@("`@("`@("1D871E+3YC;VUP87)E1&%T
M951I;64H)&5V96YT+3YE;F0I(#P]("TQ*2!["B`@("`@("`@("`@("`@("`@
M("`@)&5V96YT<UM=(#T@)&5V96YT260["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H)&YE>'0@
M/2`D=&AI<RT^;F5X=%)E8W5R<F5N8V4H)&5V96YT260L("1D871E*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1S=&%R="`]("9N97<@2&]R9&5?1&%T92@D
M;F5X="D["B`@("`@("`@("`@("`@("`@("`@)'-T87)T+3YM:6X@+3T@)&5V
M96YT+3YG971!;&%R;2@I.PH@("`@("`@("`@("`@("`@("`@("1S=&%R="T^
M8V]R<F5C="@I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<W1A<G0M/F-O
M;7!A<F5$871E5&EM92@D9&%T92D@/#T@,"`F)@H@("`@("`@("`@("`@("`@
M("`@("`@("`D9&%T92T^8V]M<&%R941A=&54:6UE*&YE=R!(;W)D95]$871E
M*&%R<F%Y*"=Y96%R)R`]/B`D;F5X="T^>65A<BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;6]N=&@G(#T^("1N97AT+3YM;VYT:"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;61A>2<@/3X@)&YE>'0M/FUD87DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VAO=7(G(#T^("1E=F5N="T^96YD+3YH;W5R+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=M:6XG(#T^("1E=F5N="T^96YD+3YM:6XL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W-E8R<@/3X@)&5V96YT+3YE;F0M
M/G-E8RDI(#P]("TQ*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D979E
M;G1S6UT@/2`D979E;G1)9#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!I<U]A<G)A>2@D979E;G1S*2`_("1E=F5N=',@.B!A<G)A>2@I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF('1H92!E=F5N="=S
M(%5)1"!A;')E861Y(&5X:7-T<R!A;F0@<F5T=7)N<R!A;&P@979E;G0*("`@
M("`J(&ED<R!W:71H('1H870@54E$+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5I9"`@("`@("`@("!4:&4@979E;G0G<R!U:60N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C86QE;F1A<E]I9"`@0V%L96YD87(@=&\@<V5A<F-H
M(&EN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%)E='5R;G,@82!S
M=')I;F<@=VET:"!E=F5N=%]I9"!O<B!F86QS92!I9B!N;W0@9F]U;F0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D=6ED+"`D8V%L96YD87)?:60@
M/2!N=6QL*0H@("`@>PH@("`@("`@("\O($1O;B=T('5S92!C86QE;F1A<B!I
M9"!H97)E+@H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:V]L86(M/FQO861/
M8FIE8W0H)'5I9"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U:60["B`@
M("!]"@H@("`@9G5N8W1I;VX@;&ES=$5V96YT<R@D<W1A<G1$871E(#T@;G5L
M;"P@)&5N9$1A=&4@/2!N=6QL*0H@("`@>PH@("`@("`@("\O(%=E(&1O;B=T
M('!E<F9O<FT@86YY(&-H96-K:6YG(&]N("1S=&%R=$1A=&4@86YD("1E;F1$
M871E+`H@("`@("`@("\O(&%S('1H870@:&%S('1H92!P;W1E;G1I86P@=&\@
M;&5A=F4@;W5T(')E8W5R<FEN9R!E=F5N=`H@("`@("`@("\O(&EN<W1A;F-E
M<RX*("`@("`@("`D979E;G1S(#T@87)R87DH*3L*"B`@("`@("`@)&US9U]L
M:7-T(#T@)'1H:7,M/E]K;VQA8BT^;&ES=$]B:F5C=',H*3L*("`@("`@("!I
M9B`H:7-?82@D;7-G7VQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1M<V=?;&ES=#L*("`@("`@("!]"@H@("`@("`@(&EF("AE
M;7!T>2@D;7-G7VQI<W0I*2!["B`@("`@("`@("`@(')E='5R;B`D979E;G1S
M.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&US9U]L:7-T(&%S("1M
M<V<I('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:V]L86(M/FQO
M861/8FIE8W0H)&US9RP@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D979E;G1S
M6R1T:&ES+3Y?:V]L86(M/F=E=%5)1"@I72`]("1T:&ES+3Y?:V]L86(M/F=E
M=%5)1"@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E=F5N=',["B`@
M("!]"@H@("`@9G5N8W1I;VX@)F=E=$5V96YT*"1E=F5N=$E$(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D979E;G1)1"DI('L*("`@("`@
M("`@("`@)&5V96YT(#T@)FYE=R!+<F]N;VQI=&A?179E;G1?:V]L86(H)'1H
M:7,I.PH@("`@("`@("`@("!R971U<FX@)&5V96YT.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?:V]L86(M/FQO861/8FIE8W0H)&5V
M96YT240I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("`D979E;G0@/2`F;F5W($MR;VYO;&ET:%]%=F5N=%]K;VQA8B@D
M=&AI<RD["B`@("`@("`@)&5V96YT+3YF<F]M1')I=F5R*"1T:&ES*3L*"B`@
M("`@("`@<F5T=7)N("1E=F5N=#L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T
M0GE5240H)'5I9"D*("`@('L*("`@("`@("`D=&AI<RT^;W!E;BA!=71H.CIG
M971!=71H*"DI.PH*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5V96YT*"1U
M:60I.PH@("`@?0H*("`@(&9U;F-T:6]N('-A=F5%=F5N="@D979E;G0I"B`@
M("!["B`@("`@("`@)&L@/2`F)'1H:7,M/E]K;VQA8CL*"B`@("`@("`@)&5D
M:70@/2!F86QS93L*("`@("`@("!I9B`H)&5V96YT+3YI<U-T;W)E9"@I('Q\
M("1E=F5N="T^97AI<W1S*"DI('L*("`@("`@("`@("`@)'5I9"`]("1E=F5N
M="T^9V5T240H*3L*"B`@("`@("`@("`@("1R97-U;'0@/2`D:RT^;&]A9$]B
M:F5C="@D=6ED*3L*("`@("`@("`@("`@+R].;R!E<G)O<B!C:&5C:R!H97)E
M+"!A;')E861Y(&1O;F4@:6X@97AI<W1S*"D*"B`@("`@("`@("`@("1E9&ET
M(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)&5V
M96YT+3YG971)1"@I*2!["B`@("`@("`@("`@("`@("`D=6ED(#T@)&5V96YT
M+3YG971)1"@I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'5I9"`](&UD-2AU;FEQ:60H;71?<F%N9"@I+"!T<G5E*2D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1K+3YN97=/8FIE8W0H)'5I9"D["B`@
M("`@("`@?0H*("`@("`@("`D>&UL7VAA<V@@/2`F)'1H:7,M/E]K;VQA8BT^
M9V5T0W5R<F5N=$]B:F5C="@I.PH*("`@("`@("`D:RT^<V5T4W1R*"=S=6UM
M87)Y)RP@)&5V96YT+3YG9714:71L92@I*3L*("`@("`@("`D:RT^<V5T4W1R
M*"=B;V1Y)RP@)&5V96YT+3YG971$97-C<FEP=&EO;B@I*3L*("`@("`@("`D
M:RT^<V5T4W1R*"=C871E9V]R:65S)RP@)&5V96YT+3YG971#871E9V]R>2@I
M*3L*("`@("`@("`D:RT^<V5T4W1R*"=L;V-A=&EO;B<L("1E=F5N="T^9V5T
M3&]C871I;VXH*2D["@H@("`@("`@("1O<F=A;FEZ97(@/2`F)&LM/FEN:712
M;V]T16QE;2@G;W)G86YI>F5R)RD["B`@("`@("`@)&LM/G-E=$5L96U3='(H
M)&]R9V%N:7IE<BP@)W-M='`M861D<F5S<R<L("1E=F5N="T^9V5T0W)E871O
M<DE$*"DI.PH*("`@("`@("`D:RT^<V5T5F%L*"=A;&%R;2<L("1E=F5N="T^
M9V5T06QA<FTH*2D["B`@("`@("`@:68@*"1E=F5N="T^:7-!;&Q$87DH*2D@
M>PH@("`@("`@("`@("`D:RT^<V5T5F%L*"=S=&%R="UD871E)RP@2V]L86(Z
M.F5N8V]D941A=&4H)&5V96YT+3YS=&%R="T^=&EM97-T86UP*"DI*3L*("`@
M("`@("`@("`@)&LM/G-E=%9A;"@G96YD+61A=&4G+"!+;VQA8CHZ96YC;V1E
M1&%T92@D979E;G0M/F5N9"T^=&EM97-T86UP*"DM,C0J-C`J-C`I*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:RT^<V5T5F%L*"=S=&%R="UD
M871E)RP@2V]L86(Z.F5N8V]D941A=&54:6UE*"1E=F5N="T^<W1A<G0M/G1I
M;65S=&%M<"@I*2D["B`@("`@("`@("`@("1K+3YS971686PH)V5N9"UD871E
M)RP@2V]L86(Z.F5N8V]D941A=&54:6UE*"1E=F5N="T^96YD+3YT:6UE<W1A
M;7`H*2DI.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D979E;G0M/G-T
M871U<RD@>PH@("`@("`@(&-A<V4@2U)/3D],251(7U-405154U]#04Y#14Q,
M140Z"B`@("`@("`@("`@("1K+3YS971686PH)W-H;W<M=&EM92UA<R<L("=F
M<F5E)RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($M23TY/
M3$E42%]35$%455-?5$5.5$%4259%.@H@("`@("`@("`@("`D:RT^<V5T5F%L
M*"=S:&]W+71I;64M87,G+"`G=&5N=&%T:79E)RD["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E($M23TY/3$E42%]35$%455-?0T].1DE2345$
M.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1K+3YS971686PH)W-H
M;W<M=&EM92UA<R<L("=B=7-Y)RD["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@)&LM/F1E;$%L;%)O;W1%;&5M<R@G871T96YD964G
M*3L*("`@("`@("!F;W)E86-H("@D979E;G0M/F%T=&5N9&5E<R!A<R`D96UA
M:6P@/3X@)'-T871U<RD@>PH@("`@("`@("`@("`D871T96YD964@/2`F)&LM
M/F%P<&5N9%)O;W1%;&5M*"=A='1E;F1E92<I.PH@("`@("`@("`@("`D:RT^
M<V5T16QE;59A;"@D871T96YD964L("=S;71P+6%D9')E<W,G+"`D96UA:6PI
M.PH*("`@("`@("`@("`@<W=I=&-H("@D<W1A='5S6R=R97-P;VYS92==*2![
M"B`@("`@("`@("`@(&-A<V4@2U)/3D],251(7U)%4U!/3E-%7T%#0T505$5$
M.@H@("`@("`@("`@("`@("`@)&LM/G-E=$5L96U686PH)&%T=&5N9&5E+"`G
M<W1A='5S)RP@)V%C8V5P=&5D)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@2U)/3D],251(7U)%4U!/3E-%7T1%0TQ)3D5$
M.@H@("`@("`@("`@("`@("`@)&LM/G-E=$5L96U686PH)&%T=&5N9&5E+"`G
M<W1A='5S)RP@)V1E8VQI;F5D)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@2U)/3D],251(7U)%4U!/3E-%7U1%3E1!5$E6
M13H*("`@("`@("`@("`@("`@("1K+3YS971%;&5M5F%L*"1A='1E;F1E92P@
M)W-T871U<R<L("=T96YT871I=F4G*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92!+4D].3TQ)5$A?4D534$].4T5?3D].13H*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1K+3YS971%
M;&5M5F%L*"1A='1E;F1E92P@)W-T871U<R<L("=N;VYE)RD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@('-W:71C:"`H)'-T871U<ULG871T96YD86YC
M92==*2!["B`@("`@("`@("`@(&-A<V4@2U)/3D],251(7U!!4E1?3U!424].
M04PZ"B`@("`@("`@("`@("`@("`D:RT^<V5T16QE;59A;"@D871T96YD964L
M("=R;VQE)RP@)V]P=&EO;F%L)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@2U)/3D],251(7U!!4E1?3D].13H*("`@("`@
M("`@("`@("`@("1K+3YS971%;&5M5F%L*"1A='1E;F1E92P@)W)O;&4G+"`G
M<F5S;W5R8V4G*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92!+4D].3TQ)5$A?4$%25%]215%525)%1#H*("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("1K+3YS971%;&5M5F%L*"1A='1E
M;F1E92P@)W)O;&4G+"`G<F5Q=6ER960G*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&LM/F1E;$%L;%)O;W1%;&5M<R@G<F5C=7)R96YC
M92<I.PH*("`@("`@("`D<F%N9V5?='EP92`]("=N;VYE)SL*("`@("`@("`D
M<F%N9V4@/2`P.PH@("`@("`@(&EF("@A96UP='DH)&5V96YT+3YR96-U<D5N
M9"DI('L*("`@("`@("`@("`@)')A;F=E7W1Y<&4@/2`G9&%T92<["B`@("`@
M("`@("`@("1R86YG92`]($MO;&%B.CIE;F-O9&5$871E*"1E=F5N="T^<F5C
M=7)%;F0M/G1I;65S=&%M<"@I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M979E;G0M/G)E8W5R5'EP92`A/2!+4D].3TQ)5$A?4D5#55)?3D].12D@>PH@
M("`@("`@("`@("`D<F5C=7)R96YC92`]("8D:RT^:6YI=%)O;W1%;&5M*"=R
M96-U<G)E;F-E)RD["B`@("`@("`@("`@("1K+3YS971%;&5M5F%L*"1R96-U
M<G)E;F-E+"`G:6YT97)V86PG+"`D979E;G0M/G)E8W5R26YT97)V86PI.PH@
M("`@("`@("`@("`D<F%N9V4@/2`F)&LM/G-E=$5L96U686PH)')E8W5R<F5N
M8V4L("=R86YG92<L("1R86YG92D["B`@("`@("`@("`@("1R86YG92T^<V5T
M7V%T=')I8G5T92@G='EP92<L("1R86YG95]T>7!E*3L*"B`@("`@("`@("`@
M('-W:71C:"`H)&5V96YT+3YR96-U<E1Y<&4I('L*("`@("`@("`@("`@("`@
M(&-A<V4@2U)/3D],251(7U)%0U527T1!24Q9.@H@("`@("`@("`@("`@("`@
M("`@("1R96-U<G)E;F-E+3YS971?871T<FEB=71E*"=C>6-L92<L("=D86EL
M>2<I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@(&-A<V4@2U)/3D],251(7U)%0U527U=%14M,63H*("`@("`@("`@("`@
M("`@("`@("`D<F5C=7)R96YC92T^<V5T7V%T=')I8G5T92@G8WEC;&4G+"`G
M=V5E:VQY)RD["@H@("`@("`@("`@("`@("`@("`@("1D87ES(#T@87)R87DH
M)W-U;F1A>2<L("=M;VYD87DG+"`G='5E<V1A>2<L("=W961N97-D87DG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1H=7)S9&%Y)RP@
M)V9R:61A>2<L("=S871U<F1A>2<I.PH*("`@("`@("`@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/#T@-R`[("1I*RLI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1E=F5N="T^<F5C=7)/;D1A>2AP;W<H,BP@)&DI*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A>2`]("8D:RT^87!P
M96YD16QE;2@G9&%Y)RP@)')E8W5R<F5N8V4I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1A>2T^<V5T7V-O;G1E;G0H)&1A>7-;)&E=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E($M23TY/3$E42%]214-54E]$05E?3T9?34].5$@Z"B`@("`@("`@("`@
M("`@("`@("`@)')E8W5R<F5N8V4M/G-E=%]A='1R:6)U=&4H)V-Y8VQE)RP@
M)VUO;G1H;'DG*3L*("`@("`@("`@("`@("`@("`@("`D<F5C=7)R96YC92T^
M<V5T7V%T=')I8G5T92@G='EP92<L("=D87EN=6UB97(G*3L*("`@("`@("`@
M("`@("`@("`@("`D:RT^<V5T16QE;59A;"@D<F5C=7)R96YC92P@)V1A=&4G
M+"`D979E;G0M/G-T87)T+3YM9&%Y*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E($M23TY/3$E42%]214-54E]7
M145+7T]&7TU/3E1(.@H@("`@("`@("`@("`@("`@("`@("1R96-U<G)E;F-E
M+3YS971?871T<FEB=71E*"=C>6-L92<L("=M;VYT:&QY)RD["B`@("`@("`@
M("`@("`@("`@("`@)')E8W5R<F5N8V4M/G-E=%]A='1R:6)U=&4H)W1Y<&4G
M+"`G=V5E:V1A>2<I.PH@("`@("`@("`@("`@("`@("`@("1K+3YS971%;&5M
M5F%L*"1R96-U<G)E;F-E+"`G9&%Y;G5M8F5R)RP@,2D["B`@("`@("`@("`@
M("`@("`@("`@)'-T87)T(#T@)FYE=R!(;W)D95]$871E*"1E=F5N="T^<W1A
M<G0I.PH@("`@("`@("`@("`@("`@("`@("1D87ES(#T@87)R87DH)W-U;F1A
M>2<L("=M;VYD87DG+"`G='5E<V1A>2<L("=W961N97-D87DG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1H=7)S9&%Y)RP@)V9R:61A
M>2<L("=S871U<F1A>2<I.PH@("`@("`@("`@("`@("`@("`@("1K+3YS971%
M;&5M5F%L*"1R96-U<G)E;F-E+"`G9&%Y)RP@)&1A>7-;)'-T87)T+3YD87E/
M9E=E96LH*5TI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&-A<V4@2U)/3D],251(7U)%0U527UE%05),63H*("`@("`@
M("`@("`@("`@("`@("`D<F5C=7)R96YC92T^<V5T7V%T=')I8G5T92@G8WEC
M;&4G+"`G>65A<FQY)RD["B`@("`@("`@("`@("`@("`@("`@)')E8W5R<F5N
M8V4M/G-E=%]A='1R:6)U=&4H)W1Y<&4G+"`G;6]N=&AD87DG*3L*"B`@("`@
M("`@("`@("`@("`@("`@)&UO;G1H<R`](&%R<F%Y*"=J86YU87)Y)RP@)V9E
M8G)U87)Y)RP@)VUA<F-H)RP@)V%P<FEL)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VUA>2<L("=J=6YE)RP@)VIU;'DG+"`G875G
M=7-T)RP@)W-E<'1E;6)E<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=O8W1O8F5R)RP@)VYO=F5M8F5R)RP@)V1E8V5M8F5R)RD[
M"@H@("`@("`@("`@("`@("`@("`@("1K+3YS971%;&5M5F%L*"1R96-U<G)E
M;F-E+"`G;6]N=&@G+"`D;6]N=&AS6R1E=F5N="T^<W1A<G0M/FUO;G1H72D[
M"B`@("`@("`@("`@("`@("`@("`@)&LM/G-E=$5L96U686PH)')E8W5R<F5N
M8V4L("=D871E)RP@)&5V96YT+3YS=&%R="T^;61A>2D["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2`D:RT^<V%V94]B:F5C="@I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!.;W1I9GD@86)O
M=70@=&AE(&-H86YG960@979E;G0N("HO"B`@("`@("`@)')E<W5L="`]($MR
M;VYO;&ET:#HZ<V5N9$YO=&EF:6-A=&EO;B@D979E;G0L("1E9&ET(#\@)V5D
M:70G(#H@)V%D9"<I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E
M<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1U:60["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!-;W9E(&%N(&5V96YT('1O(&$@;F5W(&-A;&5N9&%R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&5V96YT260@("`@("!4:&4@979E;G0@
M=&\@;6]V92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=T-A;&5N9&%R("!4
M:&4@;F5W(&-A;&5N9&%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E*"1E
M=F5N=$E$+"`D;F5W0V%L96YD87(I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:V]L86(M/FUO=F5/8FIE8W0H)&5V96YT240L("1N97=#86QE;F1A
M<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!C86QE;F1A<B!A
M;F0@86QL(&ET<R!E=F5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V%L96YD87(@(%1H92!N86UE(&]F('1H92!C86QE;F1A<B!T;R!D96QE
M=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O<B!A(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L
M971E*"1C86QE;F1A<BD*("`@('L*("`@("`@("`O+R!4:&ES(&ES(&AA;F1L
M960@8GD@=&AE('-H87)E(&AO;VMS+@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE(&$@8V%L96YD87(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9G)O;2`@5&AE(&-U<G)E;G0@;F%M
M92!O9B!T:&4@8V%L96YD87(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;R`@
M("!4:&4@;F5W(&YA;64@;V8@=&AE(&-A;&5N9&%R+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;W(@82!014%27T5R<F]R(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D9G)O;2P@)'1O*0H@
M("`@>PH@("`@("`@("\O(%1H:7,@:7,@:&%N9&QE9"!B>2!T:&4@<VAA<F4@
M:&]O:W,N"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&4@86X@979E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D979E;G1)9"`@5&AE($E$(&]F('1H92!E=F5N="!T;R!D96QE=&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O<B!A(%!%05)?
M17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E
M179E;G0H)&5V96YT240I"B`@("!["B`@("`@("`@+RH@1F5T8V@@=&AE(&5V
M96YT(&9O<B!L871E<B!U<V4N("HO"B`@("`@("`@)&5V96YT(#T@)B1T:&ES
M+3YG971%=F5N="@D979E;G1)1"D["@H@("`@("`@("\J($1E;&5T92!T:&4@
M979E;G0N("HO"B`@("`@("`@)&1E;&5T960@/2`D=&AI<RT^7VMO;&%B+3YR
M96UO=F5/8FIE8W1S*"1E=F5N=$E$*3L*("`@("`@("!I9B`H(21D96QE=&5D
M('Q\(&ES7V$H)&1E;&5T960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1D96QE=&5D.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]T
M:69Y(&%B;W5T('1H92!D96QE=&5D(&5V96YT+B`J+PH@("`@("`@("1R97-U
M;'0@/2!+<F]N;VQI=&@Z.G-E;F1.;W1I9FEC871I;VXH)&5V96YT+"`G9&5L
M971E)RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@?0H@
M("`@?0H*?0H*8VQA<W,@2W)O;F]L:71H7T5V96YT7VMO;&%B(&5X=&5N9',@
M2W)O;F]L:71H7T5V96YT('L*"B`@("!F=6YC=&EO;B!F<F]M1')I=F5R*"1D
M=6UM>2D*("`@('L*("`@("`@("`D9')I=F5R(#T@)B1T:&ES+3YG971$<FEV
M97(H*3L*("`@("`@("`D:R`]("8D9')I=F5R+3Y?:V]L86(["@H@("`@("`@
M("1T:&ES+3YE=F5N=$E$(#T@)&LM/F=E=%5)1"@I.PH@("`@("`@("1T:&ES
M+3YS9715240H)&LM/F=E=%5)1"@I*3L*("`@("`@("`D=&AI<RT^=&ET;&4@
M/2`D:RT^9V5T4W1R*"=S=6UM87)Y)RD["B`@("`@("`@)'1H:7,M/F1E<V-R
M:7!T:6]N(#T@)&LM/F=E=%-T<B@G8F]D>2<I.PH@("`@("`@("1T:&ES+3YL
M;V-A=&EO;B`]("1K+3YG9713='(H)VQO8V%T:6]N)RD["B`@("`@("`@)'1H
M:7,M/F-A=&5G;W)Y(#T@)&LM/F=E=%-T<B@G8V%T96=O<FEE<R<I.PH*("`@
M("`@("`D;W)G86YI>F5R(#T@)B1K+3YG9712;V]T16QE;2@G;W)G86YI>F5R
M)RD["B`@("`@("`@)'1H:7,M/F-R96%T;W))1"`]("1K+3YG971%;&5M4W1R
M*"1O<F=A;FEZ97(L("=S;71P+6%D9')E<W,G*3L*"B`@("`@("`@)'1H:7,M
M/F%L87)M(#T@)&LM/F=E=%9A;"@G86QA<FTG*3L*("`@("`@("`D=&AI<RT^
M<W1A<G0@/2`F;F5W($AO<F1E7T1A=&4H2V]L86(Z.F1E8V]D941A=&5/<D1A
M=&54:6UE*"1K+3YG971686PH)W-T87)T+61A=&4G*2DI.PH@("`@("`@("1T
M:&ES+3YE;F0@/2`F;F5W($AO<F1E7T1A=&4H2V]L86(Z.F1E8V]D949U;&Q$
M87E$871E*"1K+3YG971686PH)V5N9"UD871E)RDI*3L*("`@("`@("`D=&AI
M<RT^9'5R36EN(#T@*"1T:&ES+3YE;F0M/G1I;65S=&%M<"@I("T@)'1H:7,M
M/G-T87)T+3YT:6UE<W1A;7`H*2D@+R`V,#L*"B`@("`@("`@)'-T871U<R`]
M("1K+3YG971686PH)W-H;W<M=&EM92UA<R<I.PH@("`@("`@('-W:71C:"`H
M)'-T871U<RD@>PH@("`@("`@(&-A<V4@)V9R964G.@H@("`@("`@("`@("`D
M=&AI<RT^<W1A='5S(#T@2U)/3D],251(7U-405154U]#04Y#14Q,140["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=T96YT871I=F4G.@H@
M("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@2U)/3D],251(7U-405154U]4
M14Y4051)5D4["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=B
M=7-Y)SH*("`@("`@("!C87-E("=O=71O9F]F9FEC92<Z"B`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]($M23TY/3$E42%]3
M5$%455-?0T].1DE2345$.PH@("`@("`@('T*"B`@("`@("`@)&%T=&5N9&5E
M<R`]("8D:RT^9V5T06QL4F]O=$5L96US*"=A='1E;F1E92<I.PH@("`@("`@
M(&9O<B`H)&D@/2`P+"`D:B`](&-O=6YT*"1A='1E;F1E97,I.R`D:2`\("1J
M.R`D:2LK*2!["B`@("`@("`@("`@("1A='1E;F1E92`]("8D871T96YD965S
M6R1I73L*"B`@("`@("`@("`@("1E;6%I;"`]("1K+3YG971%;&5M4W1R*"1A
M='1E;F1E92P@)W-M='`M861D<F5S<R<I.PH@("`@("`@("`@("!I9B`H96UP
M='DH)&5M86EL*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1R;VQE(#T@)&LM/F=E=$5L96U686PH
M)&%T=&5N9&5E+"`G<F]L92<I.PH@("`@("`@("`@("!S=VET8V@@*"1R;VQE
M*2!["B`@("`@("`@("`@(&-A<V4@)V]P=&EO;F%L)SH*("`@("`@("`@("`@
M("`@("1R;VQE(#T@2U)/3D],251(7U!!4E1?3U!424].04P["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W)E<V]U<F-E)SH*
M("`@("`@("`@("`@("`@("1R;VQE(#T@2U)/3D],251(7U!!4E1?3D].13L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G<F5Q
M=6ER960G.@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M)')O;&4@/2!+4D].3TQ)5$A?4$%25%]215%525)%1#L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<W1A='5S
M(#T@)&LM/F=E=$5L96U686PH)&%T=&5N9&5E+"`G<W1A='5S)RD["B`@("`@
M("`@("`@('-W:71C:"`H)'-T871U<RD@>PH@("`@("`@("`@("!C87-E("=A
M8V-E<'1E9"<Z"B`@("`@("`@("`@("`@("`D<W1A='5S(#T@2U)/3D],251(
M7U)%4U!/3E-%7T%#0T505$5$.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("=D96-L:6YE9"<Z"B`@("`@("`@("`@("`@("`D
M<W1A='5S(#T@2U)/3D],251(7U)%4U!/3E-%7T1%0TQ)3D5$.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=T96YT871I=F4G
M.@H@("`@("`@("`@("`@("`@)'-T871U<R`]($M23TY/3$E42%]215-03TY3
M15]414Y4051)5D4["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)VYO;F4G.@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@)'-T871U<R`]($M23TY/3$E42%]215-03TY315].3TY%.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&ES+3YA9&1!='1E;F1E92@D96UA:6PL("1R;VQE+"`D<W1A='5S
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YR96-U<D5N9"`](&YU;&P[
M"B`@("`@("`@)'1H:7,M/G)E8W5R5'EP92`]($M23TY/3$E42%]214-54E].
M3TY%.PH*("`@("`@("`D<F5C=7)R96YC92`]("8D:RT^9V5T4F]O=$5L96TH
M)W)E8W5R<F5N8V4G*3L*("`@("`@("!I9B`H)')E8W5R<F5N8V4@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("1C>6-L92`]("1R96-U<G)E;F-E+3YG971?
M871T<FEB=71E*"=C>6-L92<I.PH@("`@("`@("`@("`D=&AI<RT^<F5C=7))
M;G1E<G9A;"`]("1K+3YG971%;&5M5F%L*"1R96-U<G)E;F-E+"`G:6YT97)V
M86PG*3L*"B`@("`@("`@("`@('-W:71C:"`H)&-Y8VQE*2!["B`@("`@("`@
M("`@(&-A<V4@)V1A:6QY)SH*("`@("`@("`@("`@("`@("1T:&ES+3YR96-U
M<E1Y<&4@/2!+4D].3TQ)5$A?4D5#55)?1$%)3%D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W=E96ML>2<Z"B`@("`@("`@
M("`@("`@("`D=&AI<RT^<F5C=7)4>7!E(#T@2U)/3D],251(7U)%0U527U=%
M14M,63L*"B`@("`@("`@("`@("`@("`D;6%S:R`](#`["B`@("`@("`@("`@
M("`@("`D8FET<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=M;VYD
M87DG(#T^($A/4D1%7T1!5$5?34%32U]-3TY$05DL"B`@("`@("`@("`@("`@
M("`@("`@)W1U97-D87DG(#T^($A/4D1%7T1!5$5?34%32U]454531$%9+`H@
M("`@("`@("`@("`@("`@("`@("=W961N97-D87DG(#T^($A/4D1%7T1!5$5?
M34%32U]7141.15-$05DL"B`@("`@("`@("`@("`@("`@("`@)W1H=7)S9&%Y
M)R`]/B!(3U)$15]$051%7TU!4TM?5$A54E-$05DL"B`@("`@("`@("`@("`@
M("`@("`@)V9R:61A>2<@/3X@2$]21$5?1$%415]-05-+7T92241!62P*("`@
M("`@("`@("`@("`@("`@("`G<V%T=7)D87DG(#T^($A/4D1%7T1!5$5?34%3
M2U]305154D1!62P*("`@("`@("`@("`@("`@("`@("`G<W5N9&%Y)R`]/B!(
M3U)$15]$051%7TU!4TM?4U5.1$%9+`H@("`@("`@("`@("`@("`@*3L*"B`@
M("`@("`@("`@("`@("`D9&%Y<R`]("1K+3YG971!;&Q%;&5M<R@G9&%Y)RP@
M)')E8W5R<F5N8V4I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A>7,@
M87,@)&1A>2D@>PH@("`@("`@("`@("`@("`@("`@("1D87E?<W1R(#T@)&1A
M>2T^9V5T7V-O;G1E;G0H*3L*"B`@("`@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1D87E?<W1R*2!\?"`A:7-S970H)&)I='-;)&1A>5]S=')=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("1M87-K('P]("1B:71S
M6R1D87E?<W1R73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T4F5C=7)/;D1A>2@D;6%S:RD["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VUO;G1H;'DG.@H@("`@("`@
M("`@("`@("`@)'1Y<&4@/2`D<F5C=7)R96YC92T^9V5T7V%T=')I8G5T92@G
M='EP92<I.PH@("`@("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@
M("`@("`@("`@("`@8V%S92`G9&%Y;G5M8F5R)SH*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<F5C=7)4>7!E(#T@2U)/3D],251(7U)%0U527T1!65]/
M1E]-3TY42#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=W965K9&%Y)SH*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<F5C=7)4>7!E(#T@2U)/3D],251(7U)%0U527T1!65]/1E]-3TY4
M2#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M>65A<FQY)SH*("`@("`@("`@("`@("`@("1T:&ES+3YR96-U<E1Y<&4@/2!+
M4D].3TQ)5$A?4D5#55)?645!4DQ9.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R86YG92`]("8D:RT^9V5T
M16QE;2@G<F%N9V4G+"`D<F5C=7)R96YC92D["B`@("`@("`@("`@("1R86YG
M95]T>7!E(#T@)')A;F=E+3YG971?871T<FEB=71E*"=T>7!E)RD["B`@("`@
M("`@("`@("1R86YG95]V86P@/2`D:RT^9V5T16QE;59A;"@D<F5C=7)R96YC
M92P@)W)A;F=E)RD["@H@("`@("`@("`@("!S=VET8V@@*"1R86YG95]T>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@)VYU;6)E<B<Z"B`@("`@("`@("`@("`@
M("`O+R!+<F]N;VQI=&@@8V%N)W0@:&%N9&QE(')E8W5R<F5N8V4@:6YT97)V
M86QS(&)Y"B`@("`@("`@("`@("`@("`O+R!N=6UB97(@;V8@:6YS=&%N8V5S
M('EE="X*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G9&%T92<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5C=7)%;F0@/2`F
M;F5W($AO<F1E7T1A=&4H2V]L86(Z.F1E8V]D941A=&4H)')A;F=E7W9A;"DI
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YI;FET:6%L:7IE9"`]('1R=64["B`@("`@
M("`@)'1H:7,M/G-T;W)E9"`]('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&]$<FEV97(H*0H@("`@>PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]$<FEV97(O
M<W%L+G!H<```````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W-#,S,0`Q
M,#0Q-S,V,C<U,P`P,C$W-3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!+<F]N;VQI=&A?1')I
M=F5R7W-Q;#HZ(&-L87-S(&EM<&QE;65N=',@=&AE($MR;VYO;&ET:%]$<FEV
M97(*("H@05!)(&9O<B!A(%-13"!B86-K96YD+@H@*@H@*B`D2&]R9&4Z(&MR
M;VYO;&ET:"]L:6(O1')I=F5R+W-Q;"YP:'`L=B`Q+C$S-BXR+C$Y(#(P,#8O
M,#$O,C0@,#`Z,3`Z-3,@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($QU8R!3
M86EL;&%R9"`\;'5C+G-A:6QL87)D0&9R+F%L8V]V92YC;VT^"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!+<F]N;VQI=&@@,"XS"B`J($!P86-K86=E($MR;VYO;&ET:`H@*B\*
M8VQA<W,@2W)O;F]L:71H7T1R:79E<E]S<6P@97AT96YD<R!+<F]N;VQI=&A?
M1')I=F5R('L*"B`@("`O*BH*("`@("`J(%1H92!O8FIE8W0@:&%N9&QE(&9O
M<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T:6]N+@H@("`@("H*("`@
M("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R("1?9&(["@H@("`@+RHJ"B`@
M("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!O<B!N;W0@=V4G<F4@
M8W5R<F5N=&QY(&-O;FYE8W1E9"!T;R!T:&4@4U%,"B`@("`@*B!S97)V97(N
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V%C:&4@979E
M;G1S(&%S('=E(&9E=&-H('1H96T@=&\@879O:60@9F5T8VAI;F<@=&AE('-A
M;64@979E;G0@9G)O;2!T:&4*("`@("`J($1"('1W:6-E+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V%C:&4@/2!A<G)A
M>2@I.PH*("`@(&9U;F-T:6]N(&]P96XH)&-A;&5N9&%R*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?8V%L96YD87(@/2`D8V%L96YD87(["B`@("`@("`@)'1H
M:7,M/E]C;VYN96-T*"D["B`@("!]"@H@("`@9G5N8W1I;VX@;&ES=$%L87)M
M<R@D9&%T92D*("`@('L*("`@("`@("`D86QL979E;G1S(#T@)'1H:7,M/FQI
M<W1%=F5N=',H)&1A=&4L(&YU;&PL('1R=64I.PH@("`@("`@("1E=F5N=',@
M/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D86QL979E;G1S(&%S("1E
M=F5N=$ED*2!["B`@("`@("`@("`@("1E=F5N="`]("8D=&AI<RT^9V5T179E
M;G0H)&5V96YT260I.PH*("`@("`@("`@("`@:68@*"1E=F5N="T^9V5T4F5C
M=7)4>7!E*"D@/3T@2U)/3D],251(7U)%0U527TY/3D4I('L*("`@("`@("`@
M("`@("`@("1S=&%R="`]("9N97<@2&]R9&5?1&%T92@D979E;G0M/G-T87)T
M*3L*("`@("`@("`@("`@("`@("1S=&%R="T^;6EN("T]("1E=F5N="T^9V5T
M06QA<FTH*3L*("`@("`@("`@("`@("`@("1S=&%R="T^8V]R<F5C="@I.PH@
M("`@("`@("`@("`@("`@:68@*"1S=&%R="T^8V]M<&%R941A=&54:6UE*"1D
M871E*2`\/2`P("8F"B`@("`@("`@("`@("`@("`@("`@)&1A=&4M/F-O;7!A
M<F5$871E5&EM92@D979E;G0M/F5N9"D@/#T@+3$I('L*("`@("`@("`@("`@
M("`@("`@("`D979E;G1S6UT@/2`D979E;G1)9#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@D
M;F5X="`]("1T:&ES+3YN97AT4F5C=7)R96YC92@D979E;G1)9"P@)&1A=&4I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'-T87)T(#T@)FYE=R!(;W)D95]$
M871E*"1N97AT*3L*("`@("`@("`@("`@("`@("`@("`D<W1A<G0M/FUI;B`M
M/2`D979E;G0M/F=E=$%L87)M*"D["B`@("`@("`@("`@("`@("`@("`@)'-T
M87)T+3YC;W)R96-T*"D["B`@("`@("`@("`@("`@("`@("`@)&5N9"`]("9N
M97<@2&]R9&5?1&%T92AA<G)A>2@G>65A<B<@/3X@)&YE>'0M/GEE87(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;6]N=&@G(#T^("1N97AT+3YM;VYT:"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B`D;F5X
M="T^;61A>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=H;W5R)R`]/B`D979E;G0M/F5N9"T^:&]U<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=M:6XG(#T^("1E=F5N="T^96YD+3YM:6XL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V5C)R`]/B`D979E
M;G0M/F5N9"T^<V5C*2D["B`@("`@("`@("`@("`@("`@("`@:68@*"1S=&%R
M="T^8V]M<&%R941A=&54:6UE*"1D871E*2`\/2`P("8F"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D871E+3YC;VUP87)E1&%T951I;64H)&5N9"D@/#T@
M+3$I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5V96YT<UM=(#T@)&5V
M96YT260["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-?
M87)R87DH)&5V96YT<RD@/R`D979E;G1S(#H@87)R87DH*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!S96%R8V@H)'%U97)Y*0H@("`@>PH@("`@("`@("\O($)U
M:6QD(%-13"!C;VYD:71I;VYS(&)A<V5D(&]N('1H92!Q=65R>2!S=')I;F<N
M"B`@("`@("`@)&-O;F0@/2`G*"@G.PH@("`@("`@("1V86QU97,@/2!A<G)A
M>2@I.PH*("`@("`@("!I9B`H(65M<'1Y*"1Q=65R>2T^=&ET;&4I*2!["B`@
M("`@("`@("`@("1B:6YD<R`]($AO<F1E7U-13#HZ8G5I;&1#;&%U<V4H)'1H
M:7,M/E]D8BP@)V5V96YT7W1I=&QE)RP@)TQ)2T4G+"`D<75E<GDM/G1I=&QE
M+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1B:6YD<RDI('L*
M("`@("`@("`@("`@("`@("1C;VYD("X]("1B:6YD<ULP72`N("<@04Y$("<[
M"B`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87E?;65R9V4H)'9A;'5E
M<RP@)&)I;F1S6S%=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1C;VYD("X]("1B:6YD<SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H(65M<'1Y*"1Q=65R>2T^;&]C871I;VXI*2!["B`@
M("`@("`@("`@("1B:6YD<R`]($AO<F1E7U-13#HZ8G5I;&1#;&%U<V4H)'1H
M:7,M/E]D8BP@)V5V96YT7VQO8V%T:6]N)RP@)TQ)2T4G+"`D<75E<GDM/FQO
M8V%T:6]N+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1B:6YD
M<RDI('L*("`@("`@("`@("`@("`@("1C;VYD("X]("1B:6YD<ULP72`N("<@
M04Y$("<["B`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87E?;65R9V4H
M)'9A;'5E<RP@)&)I;F1S6S%=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1C;VYD("X]("1B:6YD<SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1Q=65R>2T^9&5S8W)I<'1I
M;VXI*2!["B`@("`@("`@("`@("1B:6YD<R`]($AO<F1E7U-13#HZ8G5I;&1#
M;&%U<V4H)'1H:7,M/E]D8BP@)V5V96YT7V1E<V-R:7!T:6]N)RP@)TQ)2T4G
M+"`D<75E<GDM/F1E<V-R:7!T:6]N+"!T<G5E*3L*("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1B:6YD<RDI('L*("`@("`@("`@("`@("`@("1C;VYD("X]
M("1B:6YD<ULP72`N("<@04Y$("<["B`@("`@("`@("`@("`@("`D=F%L=65S
M(#T@87)R87E?;65R9V4H)'9A;'5E<RP@)&)I;F1S6S%=*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;VYD("X]("1B:6YD<SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'%U
M97)Y+3YC871E9V]R>2DI('L*("`@("`@("`@("`@)&)I;F1S(#T@2&]R9&5?
M4U%,.CIB=6EL9$-L875S92@D=&AI<RT^7V1B+"`G979E;G1?8V%T96=O<GDG
M+"`G/2<L("1Q=65R>2T^8V%T96=O<GDL('1R=64I.PH@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)&)I;F1S*2D@>PH@("`@("`@("`@("`@("`@)&-O;F0@
M+CT@)&)I;F1S6S!=("X@)R!!3D0@)SL*("`@("`@("`@("`@("`@("1V86QU
M97,@/2!A<G)A>5]M97)G92@D=F%L=65S+"`D8FEN9'-;,5TI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-O;F0@+CT@)&)I;F1S
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D
M<75E<GDM/G-T871U<RDI('L*("`@("`@("`@("`@)&)I;F1S(#T@2&]R9&5?
M4U%,.CIB=6EL9$-L875S92@D=&AI<RT^7V1B+"`G979E;G1?<W1A='5S)RP@
M)STG+"`D<75E<GDM/G-T871U<RP@=')U92D["B`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D8FEN9',I*2!["B`@("`@("`@("`@("`@("`D8V]N9"`N/2`D
M8FEN9'-;,%T@+B`G($%.1"`G.PH@("`@("`@("`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y7VUE<F=E*"1V86QU97,L("1B:6YD<ULQ72D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D8V]N9"`N/2`D8FEN9',["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D8V]N9"`]/2`G
M*"@G*2!["B`@("`@("`@("`@("1C;VYD(#T@)R<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&-O;F0@/2!S=6)S='(H)&-O;F0L(#`L('-T<FQE
M;B@D8V]N9"D@+2`U*2`N("<I*2<["B`@("`@("`@?0H*("`@("`@("`D979E
M;G1)9',@/2`D=&AI<RT^;&ES=$5V96YT<T-O;F1I=&EO;F%L*"1Q=65R>2T^
M<W1A<G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!E;7!T>2@D<75E<GDM/F5N9"D@/PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YE=R!(
M;W)D95]$871E*&%R<F%Y*"=M9&%Y)R`]/B`S,2P@)VUO;G1H)R`]/B`Q,BP@
M)WEE87(G(#T^(#DY.3DI*2`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'%U97)Y+3YE;F0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1E=F5N=$ED
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&5V96YT
M261S.PH@("`@("`@('T*"B`@("`@("`@)&5V96YT<R`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H)&5V96YT261S(&%S("1E=F5N=$ED*2!["B`@("`@
M("`@("`@("1E=F5N="`]("8D=&AI<RT^9V5T179E;G0H)&5V96YT260I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D979E;G0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D979E;G0["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&5V96YT<UM=(#T@)&5V96YT.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1E=F5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&5C:W,@:68@=&AE(&5V96YT)W,@54E$(&%L<F5A9'D@97AI<W1S(&%N9"!R
M971U<FYS(&%L;"!E=F5N=`H@("`@("H@:61S('=I=&@@=&AA="!5240N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=6ED("`@("`@("`@(%1H92!E
M=F5N="=S('5I9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-A;&5N9&%R7VED
M("!#86QE;F1A<B!T;R!S96%R8V@@:6XN"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F=\8F]O;&5A;B`@4F5T=7)N<R!A('-T<FEN9R!W:71H(&5V96YT
M7VED(&]R(&9A;'-E(&EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!N;W0@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D=6ED
M+"`D8V%L96YD87)?:60@/2!N=6QL*0H@("`@>PH@("`@("`@("1Q=65R>2`]
M("=314Q%0U0@979E;G1?:60@($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T
M86)L92==("X@)R!72$5212!E=F5N=%]U:60@/2`_)SL*("`@("`@("`D=F%L
M=65S(#T@87)R87DH)'5I9"D["@H@("`@("`@(&EF("@A:7-?;G5L;"@D8V%L
M96YD87)?:60I*2!["B`@("`@("`@("`@("1Q=65R>2`N/2`G($%.1"!C86QE
M;F1A<E]I9"`](#\G.PH@("`@("`@("`@("`D=F%L=65S6UT@/2`D8V%L96YD
M87)?:60["B`@("`@("`@?0H*("`@("`@("`O+R!,;V<@=&AE('%U97)Y(&%T
M(&$@1$5"54<@;&]G(&QE=F5L+@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*'-P<FEN=&8H)U-13"!E=F5N="!F971C:"!B>2`E<SH@<75E<GD@/2`B)7,B
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($%U=&@Z.F=E
M=$%U=&@H*2P@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@
M)&5V96YT(#T@)B1T:&ES+3Y?9&(M/F=E=%)O=R@D<75E<GDL("1V86QU97,L
M($1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@:68@*&ES7V$H)&5V96YT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@<F5T=7)N("1E=F5N=#L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D979E;G0I('L*("`@("`@("`@("`@<F5T=7)N("1E=F5N=%LG
M979E;G1?:60G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&ES
M=',@86QL(&5V96YT<R!I;B!T:&4@=&EM92!R86YG92P@;W!T:6]N86QL>2!R
M97-T<FEC=&EN9PH@("`@("H@<F5S=6QT<R!T;R!O;FQY(&5V96YT<R!W:71H
M(&%L87)M<RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?1&%T92`D<W1A
M<G1);G1E<G9A;"`@4W1A<G0@;V8@<F%N9V4@9&%T92!O8FIE8W0N"B`@("`@
M*B!`<&%R86T@2&]R9&5?1&%T92`D96YD26YT97)V86P@("`@16YD(&]F(')A
M;F=E(&1A=&$@;V)J96-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&AA<T%L
M87)M("`@("`@("`@($]N;'D@<F5T=7)N(&5V96YT<R!W:71H(&%L87)M<S\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A
M=6QT<R!T;R!A;&P@979E;G1S+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($5V96YT<R!I;B!T:&4@9VEV96X@=&EM92!R86YG92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&ES=$5V96YT<R@D<W1A<G1$871E(#T@;G5L;"P@)&5N
M9$1A=&4@/2!N=6QL+"`D:&%S06QA<FT@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H(6ES<V5T*"1E;F1$871E*2D@>PH@("`@("`@("`@("`D96YD26YT
M97)V86P@/2`F;F5W($AO<F1E7T1A=&4H87)R87DH)VUD87DG(#T^(#,Q+"`G
M;6]N=&@G(#T^(#$R+"`G>65A<B<@/3X@.3DY.2DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&QI<W0H)&5N9$EN=&5R=F%L+3YM9&%Y+"`D96YD
M26YT97)V86PM/FUO;G1H+"`D96YD26YT97)V86PM/GEE87(I(#T@97AP;&]D
M92@G+R<L($1A=&5?0V%L8SHZ;F5X=$1A>2@D96YD1&%T92T^;61A>2P@)&5N
M9$1A=&4M/FUO;G1H+"`D96YD1&%T92T^>65A<BP@)R5D+R5M+R59)RDI.PH@
M("`@("`@('T*"B`@("`@("`@)'-T87)T26YT97)V86P@/2!N=6QL.PH@("`@
M("`@(&EF("AI<W-E="@D<W1A<G1$871E*2D@>PH@("`@("`@("`@("!I9B`H
M)'-T87)T1&%T92`]/3T@,"D@>PH@("`@("`@("`@("`@("`@)'-T87)T26YT
M97)V86P@/2`F;F5W($AO<F1E7T1A=&4H87)R87DH)VUD87DG(#T^(#$L("=M
M;VYT:"<@/3X@,2P@)WEE87(G(#T^(#`P,#`I*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1S=&%R=$EN=&5R=F%L(#T@)FYE=R!(
M;W)D95]$871E*"1S=&%R=$1A=&4I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@D<W1A<G1);G1E<G9A;"T^;6]N=&@@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@)'-T87)T26YT97)V86PM/FUO;G1H(#T@,3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H)'-T87)T26YT97)V86PM/FUD87D@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@)'-T87)T26YT97)V86PM/FUD87D@/2`Q
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H
M:7,M/FQI<W1%=F5N='-#;VYD:71I;VYA;"@D<W1A<G1);G1E<G9A;"P@)&5N
M9$EN=&5R=F%L+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1H87-!;&%R;2`_("=E=F5N=%]A;&%R;2`^(#\G(#H@)R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&AA<T%L87)M(#\@87)R87DH,"D@.B!A<G)A>2@I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($QI<W1S(&%L;"!E=F5N=',@=&AA="!S871I<V9Y('1H92!G
M:79E;B!C;VYD:71I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]$
M871E("1S=&%R=$EN=&5R=F%L("!3=&%R="!O9B!R86YG92!D871E(&]B:F5C
M="X*("`@("`J($!P87)A;2!(;W)D95]$871E("1E;F1);G1E<G9A;"`@("!%
M;F0@;V8@<F%N9V4@9&%T82!O8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;VYD:71I;VYS("`@("`@("`@0V]N9&ET:6]N<RP@9VEV96X@87,@4U%,
M(&-L875S97,N"B`@("`@*B!`<&%R86T@87)R87D@)'9A;',@("`@("`@("`@
M("`@("`@4U%,(&)I;F0@=F%R:6%B;&5S(&9O<B!U<V4@=VET:`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYD:71I;VYS
M(&-L875S97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@179E;G1S
M(&EN('1H92!G:79E;B!T:6UE(')A;F=E('-A=&ES9GEI;F<@=&AE(&=I=F5N
M"B`@("`@*B`@("`@("`@("`@("`@("!C;VYD:71I;VYS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L:7-T179E;G1S0V]N9&ET:6]N86PH)'-T87)T26YT97)V
M86PL("1E;F1);G1E<G9A;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8V]N9&ET:6]N<R`]("<G+"`D=F%L<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'$@/2`G4T5,14-4(&5V96YT7VED+"!E=F5N=%]U:60L
M(&5V96YT7V1E<V-R:7!T:6]N+"!E=F5N=%]L;V-A=&EO;BPG("X*("`@("`@
M("`@("`@)R!E=F5N=%]S=&%T=7,L(&5V96YT7V%T=&5N9&5E<RPG("X*("`@
M("`@("`@("`@)R!E=F5N=%]K97EW;W)D<RP@979E;G1?=&ET;&4L(&5V96YT
M7V-A=&5G;W)Y+"<@+@H@("`@("`@("`@("`G(&5V96YT7W)E8W5R='EP92P@
M979E;G1?<F5C=7)E;F1D871E+"!E=F5N=%]R96-U<FEN=&5R=F%L+"<@+@H@
M("`@("`@("`@("`G(&5V96YT7W)E8W5R9&%Y<RP@979E;G1?<W1A<G0L(&5V
M96YT7V5N9"P@979E;G1?86QA<FTL)R`N"B`@("`@("`@("`@("<@979E;G1?
M;6]D:69I960L(&5V96YT7V5X8V5P=&EO;G,L(&5V96YT7V-R96%T;W)?:60G
M("X*("`@("`@("`@("`@)R!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N"B`@("`@("`@("`@("<@5TA%4D4@8V%L96YD87)?:60@/2`_($%.
M1"`H*"<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?8V%L96YD
M87(I.PH*("`@("`@("!I9B`H)&-O;F1I=&EO;G,I('L*("`@("`@("`@("`@
M)'$@+CT@)&-O;F1I=&EO;G,@+B`G*2D@04Y$("@H)SL*("`@("`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y7VUE<F=E*"1V86QU97,L("1V86QS*3L*("`@("`@
M("!]"@H@("`@("`@("1E=&EM92`]('-P<FEN=&8H)R4P-&0M)3`R9"TE,#)D
M(#`P.C`P.C`P)RP@)&5N9$EN=&5R=F%L+3YY96%R+"`D96YD26YT97)V86PM
M/FUO;G1H+"`D96YD26YT97)V86PM/FUD87DI.PH@("`@("`@(&EF("AI<W-E
M="@D<W1A<G1);G1E<G9A;"DI('L*("`@("`@("`@("`@)'-T:6UE(#T@<W!R
M:6YT9B@G)3`T9"TE,#)D+24P,F0@,#`Z,#`Z,#`G+"`D<W1A<G1);G1E<G9A
M;"T^>65A<BP@)'-T87)T26YT97)V86PM/FUO;G1H+"`D<W1A<G1);G1E<G9A
M;"T^;61A>2D["B`@("`@("`@("`@("1Q("X]("=E=F5N=%]E;F0@/B`_($%.
M1"`G.PH@("`@("`@("`@("`D=F%L=65S6UT@/2`D<W1I;64["B`@("`@("`@
M?0H@("`@("`@("1Q("X]("=E=F5N=%]S=&%R="`\(#\I($]2("@G.PH@("`@
M("`@("1V86QU97-;72`]("1E=&EM93L*("`@("`@("!I9B`H:7-S970H)'-T
M:6UE*2D@>PH@("`@("`@("`@("`D<2`N/2`G979E;G1?<F5C=7)E;F1D871E
M(#X](#\@04Y$("<["B`@("`@("`@("`@("1V86QU97-;72`]("1S=&EM93L*
M("`@("`@("!]"B`@("`@("`@)'$@+CT@)V5V96YT7W-T87)T(#P](#\G("X*
M("`@("`@("`@("`@)R!!3D0@979E;G1?<F5C=7)T>7!E(#P^(#\I*2<["B`@
M("`@("`@87)R87E?<'5S:"@D=F%L=65S+"`D971I;64L($M23TY/3$E42%]2
M14-54E].3TY%*3L*"B`@("`@("`@+R\@3&]G('1H92!Q=65R>2!A="!A($1%
M0E5'(&QO9R!L979E;"X*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I
M;G1F*"=344P@979E;G0@;&ES="!B>2`E<SH@<75E<GD@/2`B)7,B)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($%U=&@Z.F=E=$%U=&@H
M*2P@)'$I+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O+R!2=6X@=&AE
M('%U97)Y+@H@("`@("`@("1Q<B`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q+"`D
M=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<7(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)'%R+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)&5V96YT<R`](&%R<F%Y
M*"D["B`@("`@("`@)')O=R`]("1Q<BT^9F5T8VA2;W<H1$)?1D540TA-3T1%
M7T%34T]#*3L*("`@("`@("!W:&EL92`H)')O=R`F)B`A:7-?82@D<F]W+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("\O($EF('1H92!E=F5N="!D
M:60@;F]T(&AA=F4@82!5240@8F5F;W)E+"!W92!N965D('1O(&=I=F4*("`@
M("`@("`@("`@+R\@:70@;VYE+@H@("`@("`@("`@("!I9B`H96UP='DH)')O
M=ULG979E;G1?=6ED)UTI*2!["B`@("`@("`@("`@("`@("`D<F]W6R=E=F5N
M=%]U:60G72`]("1T:&ES+3YG96YE<F%T955)1"@I.PH*("`@("`@("`@("`@
M("`@("\O(%-A=F4@=&AE(&YE=R!5240@9F]R(&1A=&$@:6YT96=R:71Y+@H@
M("`@("`@("`@("`@("`@)'%U97)Y(#T@)U501$%412`G("X@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UT@+B`G(%-%5"!E=F5N=%]U:60@/2`_(%=(15)%(&5V
M96YT7VED(#T@/R<["B`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH
M)')O=ULG979E;G1?=6ED)UTL("1R;W=;)V5V96YT7VED)UTI.PH*("`@("`@
M("`@("`@("`@("\O($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V
M96PN"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F
M*"=344P@979E;G0@=6ED(&%U=&]C<F5A=&EO;B!F;W(@)7,Z('%U97)Y(#T@
M(B5S(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($%U=&@Z.F=E=$%U=&@H*2P@)'%U97)Y*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@5V4@:&%V92!A;&P@=&AE
M(&EN9F]R;6%T:6]N('=E(&YE960@=&\@8W)E871E(&%N(&5V96YT"B`@("`@
M("`@("`@("\O(&]B:F5C="!F;W(@=&AI<R!E=F5N="P@<V\@9V\@86AE860@
M86YD(&-A8VAE(&ET+@H@("`@("`@("`@("`D=&AI<RT^7V-A8VAE6R1T:&ES
M+3Y?8V%L96YD87)=6R1R;W=;)V5V96YT7VED)UU=(#T@)FYE=R!+<F]N;VQI
M=&A?179E;G1?<W%L*"1T:&ES+"`D<F]W*3L*("`@("`@("`@("`@:68@*"1R
M;W=;)V5V96YT7W)E8W5R='EP92==(#T]($M23TY/3$E42%]214-54E].3TY%
M*2!["B`@("`@("`@("`@("`@("`D979E;G1S6R1R;W=;)V5V96YT7W5I9"==
M72`]("1R;W=;)V5V96YT7VED)UT["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;F5X="`]("1T:&ES+3YN97AT4F5C=7)R96YC92@D
M<F]W6R=E=F5N=%]I9"==+"`D<W1A<G1);G1E<G9A;"D["B`@("`@("`@("`@
M("`@("!I9B`H)&YE>'0@)B8@)&YE>'0M/F-O;7!A<F5$871E*"1E;F1);G1E
M<G9A;"D@/"`P*2!["B`@("`@("`@("`@("`@("`@("`@)&5V96YT<ULD<F]W
M6R=E=F5N=%]U:60G75T@/2`D<F]W6R=E=F5N=%]I9"==.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F]W(#T@)'%R
M+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1E=F5N=',["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E
M=$5V96YT*"1E=F5N=$ED(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?
M;G5L;"@D979E;G1)9"DI('L*("`@("`@("`@("`@)&5V96YT(#T@)FYE=R!+
M<F]N;VQI=&A?179E;G1?<W%L*"1T:&ES*3L*("`@("`@("`@("`@<F5T=7)N
M("1E=F5N=#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V-A8VAE6R1T:&ES+3Y?8V%L96YD87)=6R1E=F5N=$ED72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?8V%C:&5;)'1H:7,M/E]C86QE;F1A<EU;
M)&5V96YT261=.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@)U-%3$5#
M5"!E=F5N=%]I9"P@979E;G1?=6ED+"!E=F5N=%]D97-C<FEP=&EO;BP@979E
M;G1?;&]C871I;VXL)R`N"B`@("`@("`@("`@("<@979E;G1?<W1A='5S+"!E
M=F5N=%]A='1E;F1E97,L)R`N"B`@("`@("`@("`@("<@979E;G1?:V5Y=V]R
M9',L(&5V96YT7W1I=&QE+"!E=F5N=%]C871E9V]R>2PG("X*("`@("`@("`@
M("`@)R!E=F5N=%]R96-U<G1Y<&4L(&5V96YT7W)E8W5R96YD9&%T92P@979E
M;G1?<F5C=7)I;G1E<G9A;"PG("X*("`@("`@("`@("`@)R!E=F5N=%]R96-U
M<F1A>7,L(&5V96YT7W-T87)T+"!E=F5N=%]E;F0L(&5V96YT7V%L87)M+"<@
M+@H@("`@("`@("`@("`G(&5V96YT7VUO9&EF:65D+"!E=F5N=%]E>&-E<'1I
M;VYS+"!E=F5N=%]C<F5A=&]R7VED)R`N"B`@("`@("`@("`@("<@1E)/32`G
M("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+B`G(%=(15)%(&5V96YT7VED
M(#T@/R!!3D0@8V%L96YD87)?:60@/2`_)SL*("`@("`@("`D=F%L=65S(#T@
M87)R87DH)&5V96YT260L("1T:&ES+3Y?8V%L96YD87(I.PH*("`@("`@("`O
M+R!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+@H@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!E=F5N="!F971C:"!B
M>2`E<SH@<75E<GD@/2`B)7,B)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($%U=&@Z.F=E=$%U=&@H*2P@)'%U97)Y*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@)&5V96YT(#T@)B1T:&ES+3Y?9&(M/F=E=%)O
M=R@D<75E<GDL("1V86QU97,L($1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@
M("`@:68@*&ES7V$H)&5V96YT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1E=F5N
M=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D979E;G0I('L*("`@("`@("`@
M("`@)'1H:7,M/E]C86-H95LD=&AI<RT^7V-A;&5N9&%R75LD979E;G1)9%T@
M/2`F;F5W($MR;VYO;&ET:%]%=F5N=%]S<6PH)'1H:7,L("1E=F5N="D["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-A8VAE6R1T:&ES+3Y?8V%L96YD
M87)=6R1E=F5N=$ED73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")%=F5N="!N;W0@9F]U;F0B*2D[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N("9G971">55)1"@D=6ED
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D
M<75E<GD@/2`G4T5,14-4(&5V96YT7VED+"!E=F5N=%]U:60L(&-A;&5N9&%R
M7VED+"!E=F5N=%]D97-C<FEP=&EO;BP@979E;G1?;&]C871I;VXL)R`N"B`@
M("`@("`@("`@("<@979E;G1?<W1A='5S+"!E=F5N=%]A='1E;F1E97,L)R`N
M"B`@("`@("`@("`@("<@979E;G1?:V5Y=V]R9',L(&5V96YT7W1I=&QE+"!E
M=F5N=%]C871E9V]R>2PG("X*("`@("`@("`@("`@)R!E=F5N=%]R96-U<G1Y
M<&4L(&5V96YT7W)E8W5R96YD9&%T92P@979E;G1?<F5C=7)I;G1E<G9A;"PG
M("X*("`@("`@("`@("`@)R!E=F5N=%]R96-U<F1A>7,L(&5V96YT7W-T87)T
M+"!E=F5N=%]E;F0L(&5V96YT7V%L87)M+"<@+@H@("`@("`@("`@("`G(&5V
M96YT7VUO9&EF:65D+"!E=F5N=%]E>&-E<'1I;VYS+"!E=F5N=%]C<F5A=&]R
M7VED)R`N"B`@("`@("`@("`@("<@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT@+B`G(%=(15)%(&5V96YT7W5I9"`](#\G.PH@("`@("`@("1V
M86QU97,@/2!A<G)A>2@D=6ED*3L*"B`@("`@("`@+R\@3&]G('1H92!Q=65R
M>2!A="!A($1%0E5'(&QO9R!L979E;"X*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92AS<')I;G1F*"=344P@979E;G0@9F5T8V@@8GD@)7,Z('%U97)Y(#T@
M(B5S(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!!=71H
M.CIG971!=71H*"DL("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("1E=F5N="`]("8D=&AI<RT^7V1B+3YG9712;W<H)'%U97)Y+"`D=F%L
M=65S+"!$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@(&EF("AI<U]A*"1E
M=F5N="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@(')E='5R;B`D979E;G0["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&5V96YT*2!["B`@("`@("`@("`@("1T:&ES+3YO<&5N
M*"1E=F5N=%LG8V%L96YD87)?:60G72D["B`@("`@("`@("`@("1T:&ES+3Y?
M8V%C:&5;)'1H:7,M/E]C86QE;F1A<EU;)&5V96YT6R=E=F5N=%]I9"==72`]
M("9N97<@2W)O;F]L:71H7T5V96YT7W-Q;"@D=&AI<RP@)&5V96YT*3L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%C:&5;)'1H:7,M/E]C86QE;F1A
M<EU;)&5V96YT6R=E=F5N=%]I9"==73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D=6ED("X@)R!N;W0@
M9F]U;F0G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E
M<R!A;B!E=F5N="!I;B!T:&4@8F%C:V5N9"X*("`@("`J($EF(&ET(&ES(&$@
M;F5W(&5V96YT+"!I="!I<R!A9&1E9"P@;W1H97)W:7-E('1H92!E=F5N="!I
M<R!U<&1A=&5D+@H@("`@("H*("`@("`J($!P87)A;2!+<F]N;VQI=&A?179E
M;G0@)&5V96YT("!4:&4@979E;G0@=&\@<V%V92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V%V945V96YT*"1E=F5N="D*("`@('L*("`@("`@("!I9B`H)&5V
M96YT+3YI<U-T;W)E9"@I('Q\("1E=F5N="T^97AI<W1S*"DI('L*("`@("`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["@H@("`@("`@("`@("`D<75E<GD@
M/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N("<@4T54
M("<["@H@("`@("`@("`@("!F;W)E86-H("@D979E;G0M/F=E=%!R;W!E<G1I
M97,H*2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("1Q=65R
M>2`N/2`B("1K97D@/2`_+"(["B`@("`@("`@("`@("`@("`D=F%L=65S6UT@
M/2`D=F%L.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1Q=65R>2`]('-U
M8G-T<B@D<75E<GDL(#`L("TQ*3L*("`@("`@("`@("`@)'%U97)Y("X]("<@
M5TA%4D4@979E;G1?:60@/2`_)SL*("`@("`@("`@("`@)'9A;'5E<UM=(#T@
M)&5V96YT+3YG971)9"@I.PH*("`@("`@("`@("`@+R\@3&]G('1H92!Q=65R
M>2!A="!A($1%0E5'(&QO9R!L979E;"X*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H<W!R:6YT9B@G4U%,(&5V96YT('5P9&%T92!B>2`E<SH@<75E
M<GD@/2`B)7,B)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!!=71H.CIG971!=71H*"DL("1Q=65R>2DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!,;V<@=&AE(&UO9&EF:6-A
M=&EO;B!O9B!T:&ES(&ET96T@:6X@=&AE(&AI<W1O<GD@;&]G+@H@("`@("`@
M("`@("!I9B`H)&5V96YT+3YG9715240H*2D@>PH@("`@("`@("`@("`@("`@
M)&AI<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@("`@
M("`@("`@("`@("`D:&ES=&]R>2T^;&]G*"=K<F]N;VQI=&@Z)R`N("1T:&ES
M+3Y?8V%L96YD87(@+B`G.B<@+B`D979E;G0M/F=E=%5)1"@I+"!A<G)A>2@G
M86-T:6]N)R`]/B`G;6]D:69Y)RDL('1R=64I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O+R!.;W1I9GD@=7-E<G,@86)O=70@=&AE(&-H86YG960@
M979E;G0N"B`@("`@("`@("`@("1R97-U;'0@/2!+<F]N;VQI=&@Z.G-E;F1.
M;W1I9FEC871I;VXH)&5V96YT+"`G961I="<I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(')E='5R;B`D979E;G0M/F=E=$ED*"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@:68@*"1E=F5N="T^9V5T260H*2D@>PH@("`@("`@("`@("`@
M("`@)&ED(#T@)&5V96YT+3YG971)9"@I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&ED(#T@;60U*'5N:7%I9"AM=%]R86YD*"DL
M('1R=64I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1E=F5N
M="T^9V5T54E$*"DI('L*("`@("`@("`@("`@("`@("1U:60@/2`D979E;G0M
M/F=E=%5)1"@I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'5I9"`]("1T:&ES+3YG96YE<F%T955)1"@I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D<75E<GD@/2`G24Y315)4($E.5$\@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==.PH@("`@("`@("`@("`D8V]L<U]N86UE(#T@
M)R`H979E;G1?:60L(&5V96YT7W5I9"PG.PH@("`@("`@("`@("`D8V]L<U]V
M86QU97,@/2`G(%9!3%5%4R`H/RP@/RPG.PH@("`@("`@("`@("`D=F%L=65S
M(#T@87)R87DH)&ED+"`D=6ED*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1E
M=F5N="T^9V5T4')O<&5R=&EE<R@I(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@)&-O;'-?;F%M92`N/2`B("1K97DL(CL*("`@("`@("`@
M("`@("`@("1C;VQS7W9A;'5E<R`N/2`G(#\L)SL*("`@("`@("`@("`@("`@
M("1V86QU97-;72`]("1V86P["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1C;VQS7VYA;64@+CT@)R!C86QE;F1A<E]I9"DG.PH@("`@("`@("`@("`D
M8V]L<U]V86QU97,@+CT@)R`_*2<["B`@("`@("`@("`@("1V86QU97-;72`]
M("1T:&ES+3Y?8V%L96YD87(["@H@("`@("`@("`@("`D<75E<GD@+CT@)&-O
M;'-?;F%M92`N("1C;VQS7W9A;'5E<SL*"B`@("`@("`@("`@("\O($QO9R!T
M:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN"B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!E=F5N="!S=&]R92!B>2`E
M<SH@<75E<GD@/2`B)7,B)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!!=71H.CIG971!=71H*"DL("1Q=65R>2DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^
M<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($QO9R!T:&4@8W)E871I
M;VX@;V8@=&AI<R!I=&5M(&EN('1H92!H:7-T;W)Y(&QO9RX*("`@("`@("`@
M("`@)&AI<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@
M("`@("`@("`@("1H:7-T;W)Y+3YL;V<H)VMR;VYO;&ET:#HG("X@)'1H:7,M
M/E]C86QE;F1A<B`N("<Z)R`N("1U:60L(&%R<F%Y*"=A8W1I;VXG(#T^("=A
M9&0G*2P@=')U92D["@H@("`@("`@("`@("`O+R!.;W1I9GD@=7-E<G,@86)O
M=70@=&AE(&YE=R!E=F5N="X*("`@("`@("`@("`@)')E<W5L="`]($MR;VYO
M;&ET:#HZ<V5N9$YO=&EF:6-A=&EO;B@D979E;G0L("=A9&0G*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($UO=F4@86X@979E;G0@=&\@82!N97<@8V%L96YD87(N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D979E;G1)9"`@("`@(%1H92!E
M=F5N="!T;R!M;W9E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W0V%L96YD
M87(@(%1H92!N97<@8V%L96YD87(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO
M=F4H)&5V96YT260L("1N97=#86QE;F1A<BD*("`@('L*("`@("`@("`O+R!-
M86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN
M"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("1Q=65R>2`]
M("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@)R!3150@
M8V%L96YD87)?:60@/2`_(%=(15)%(&-A;&5N9&%R7VED(#T@/R!!3D0@979E
M;G1?:60@/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH)&YE=T-A;&5N
M9&%R+"`D=&AI<RT^7V-A;&5N9&%R+"`D979E;G1)9"D["@H@("`@("`@("\O
M($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN"B`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G2W)O;F]L:71H7T1R:79E<E]S
M<6PZ.FUO=F4H*3H@)7,G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("`O+R!!='1E;7!T('1H92!M;W9E('%U97)Y+@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@8V%L96YD87(@86YD(&%L;"!I
M=',@979E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A;&5N
M9&%R("!4:&4@;F%M92!O9B!T:&4@8V%L96YD87(@=&\@9&5L971E+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;W(@82!014%27T5R<F]R
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T92@D8V%L
M96YD87(I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@
M("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT@+B`G(%=(15)%(&-A;&5N9&%R7VED(#T@/R<["B`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*"1C86QE;F1A<BD["@H@("`@("`@("\O($QO9R!T
M:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN"B`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,($-A;&5N9&5R($1E;&5T92!B>2`E
M<SH@<75E<GD@/2`B)7,B)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($%U=&@Z.F=E=$%U=&@H*2P@)'%U97)Y*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@86X@
M979E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D979E;G1)9"`@
M5&AE($E$(&]F('1H92!E=F5N="!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E179E;G0H)&5V96YT260I
M"B`@("!["B`@("`@("`@+R\@1F5T8V@@=&AE(&5V96YT(&9O<B!L871E<B!U
M<V4N"B`@("`@("`@)&5V96YT(#T@)B1T:&ES+3YG971%=F5N="@D979E;G1)
M9"D["@H@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UT@+B`G(%=(15)%(&5V96YT7VED(#T@/R!!3D0@
M8V%L96YD87)?:60@/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH)&5V
M96YT260L("1T:&ES+3Y?8V%L96YD87(I.PH*("`@("`@("`O+R!,;V<@=&AE
M('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+@H@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*'-P<FEN=&8H)U-13"!%=F5N="!$96QE=&4@8GD@)7,Z('%U
M97)Y(#T@(B5S(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!!=71H.CIG971!=71H*"DL("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL
M("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L
M="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\O($QO
M9R!T:&4@9&5L971I;VX@;V8@=&AI<R!I=&5M(&EN('1H92!H:7-T;W)Y(&QO
M9RX*("`@("`@("!I9B`H)&5V96YT+3YG9715240H*2D@>PH@("`@("`@("`@
M("`D:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@
M("`@("`@("`@)&AI<W1O<GDM/FQO9R@G:W)O;F]L:71H.B<@+B`D=&AI<RT^
M7V-A;&5N9&%R("X@)SHG("X@)&5V96YT+3YG9715240H*2P@87)R87DH)V%C
M=&EO;B<@/3X@)V1E;&5T92<I+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@
M("\O($YO=&EF>2!A8F]U="!T:&4@9&5L971E9"!E=F5N="X*("`@("`@("`D
M<F5S=6QT(#T@2W)O;F]L:71H.CIS96YD3F]T:69I8V%T:6]N*"1E=F5N="P@
M)V1E;&5T92<I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L
M="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!O<&5N(&$@<&5R<VES=&5N="!C;VYN96-T:6]N('1O
M('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B!4<G5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("![
M"B`@("`@("`@:68@*"$D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US+"`G
M8V%L96YD87(G+`H@("`@("`@("`@("`@("`@87)R87DH)W!H<'1Y<&4G*2D[
M"@H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=D871A
M8F%S92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1A
M=&%B87-E)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@/2`G)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T86)L92==*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G:W)O
M;F]L:71H7V5V96YT<R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O
M($-O;FYE8W0@=&\@=&AE(%-13"!S97)V97(@=7-I;F<@=&AE('-U<'!L:65D
M('!A<F%M971E<G,N"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G1$(N<&AP
M)SL*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D=&AI
M<RT^7W!A<F%M<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1T
M:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO
M<F1E.CIF871A;"@D=&AI<RT^7V1B+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3970@1$(@<&]R=&%B:6QI
M='D@;W!T:6]N<RX*("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YP
M:'!T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/E]S971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)2
M3U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"
M24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!T
M<G5E.PH*("`@("`@("`@("`@+R\@2&%N9&QE(&%N>2!D871A8F%S92!S<&5C
M:69I8R!I;FET:6%L:7IA=&EO;B!C;V1E('1O"B`@("`@("`@("`@("\O(')U
M;BX*("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YD8G-Y;G1A>"D@
M>PH@("`@("`@("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@("`@("1Q
M=65R>2`](")!3%1%4B!315-324].(%-%5"!.3%-?1$%415]&3U)-050@/2`G
M65E962U-32U$1"!(2#(T.DU).E-3)R(["@H@("`@("`@("`@("`@("`@+R\@
M3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X*("`@("`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!S97-S:6]N
M('-E='5P(&)Y("5S.B!Q=65R>2`]("(E<R(G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!!=71H.CIG971!=71H*"DL("1Q
M=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=P9W-Q;"<Z"B`@("`@("`@
M("`@("`@("`D<75E<GD@/2`B4T54(&1A=&5S='EL92!43R`G:7-O)R(["@H@
M("`@("`@("`@("`@("`@+R\@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO
M9R!L979E;"X*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P
M<FEN=&8H)U-13"!S97-S:6]N('-E='5P(&)Y("5S.B!Q=65R>2`]("(E<R(G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!!
M=71H.CIG971!=71H*"DL("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=65R>2@D<75E
M<GDI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@=F%L=64@9G)O;2!T:&4@9')I
M=F5R)W,@8VAA<G-E="!T;R!T:&4@9&5F875L=`H@("`@("H@8VAA<G-E="X*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E("!!('9A;'5E('1O
M(&-O;G9E<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-O
M;G9E<G1E9"!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=$9R
M;VU$<FEV97(H)'9A;'5E*0H@("`@>PH@("`@("`@(')E='5R;B!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1V86QU92P@)'1H:7,M/E]P87)A;7-;)V-H87)S
M970G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A('9A;'5E
M(&9R;VT@=&AE(&1E9F%U;'0@8VAA<G-E="!T;R!T:&4@9')I=F5R)W,*("`@
M("`J(&-H87)S970N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1V86QU
M92`@02!V86QU92!T;R!C;VYV97)T+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!C;VYV97)T960@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O;G9E<G14;T1R:79E<B@D=F%L=64I"B`@("!["B`@("`@("`@<F5T
M=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"!.3%,Z.F=E=$-H
M87)S970H*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("!]"@I]
M"@HO*BH*("H@0'!A8VMA9V4@2W)O;F]L:71H"B`J+PIC;&%S<R!+<F]N;VQI
M=&A?179E;G1?<W%L(&5X=&5N9',@2W)O;F]L:71H7T5V96YT('L*"B`@("`O
M*BH*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<')O<&5R
M=&EE<R`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@9G)O;41R:79E<B@D4U%,
M179E;G0I"B`@("!["B`@("`@("`@)&1R:79E<B`]("8D=&AI<RT^9V5T1')I
M=F5R*"D["@H@("`@("`@("1T:&ES+3YS=&%R="`]("9N97<@2&]R9&5?1&%T
M92@I.PH@("`@("`@("1T:&ES+3YE;F0@/2`F;F5W($AO<F1E7T1A=&4H*3L*
M("`@("`@("!L:7-T*"1T:&ES+3YS=&%R="T^>65A<BP@)'1H:7,M/G-T87)T
M+3YM;VYT:"P@)'1H:7,M/G-T87)T+3YM9&%Y+"`D=&AI<RT^<W1A<G0M/FAO
M=7(L("1T:&ES+3YS=&%R="T^;6EN+"`D=&AI<RT^<W1A<G0M/G-E8RD@/2!S
M<V-A;F8H)%-13$5V96YT6R=E=F5N=%]S=&%R="==+"`G)3`T9"TE,#)D+24P
M,F0@)3`R9#HE,#)D.B4P,F0G*3L*("`@("`@("!L:7-T*"1T:&ES+3YE;F0M
M/GEE87(L("1T:&ES+3YE;F0M/FUO;G1H+"`D=&AI<RT^96YD+3YM9&%Y+"`D
M=&AI<RT^96YD+3YH;W5R+"`D=&AI<RT^96YD+3YM:6XL("1T:&ES+3YE;F0M
M/G-E8RD@/2!S<V-A;F8H)%-13$5V96YT6R=E=F5N=%]E;F0G72P@)R4P-&0M
M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RD["@H@("`@("`@("1T:&ES+3YD
M=7)-:6X@/2`H)'1H:7,M/F5N9"T^=&EM97-T86UP*"D@+2`D=&AI<RT^<W1A
M<G0M/G1I;65S=&%M<"@I*2`O(#8P.PH*("`@("`@("!I9B`H:7-S970H)%-1
M3$5V96YT6R=E=F5N=%]R96-U<F5N9&1A=&4G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/G)E8W5R16YD(#T@)FYE=R!(;W)D95]$871E*"D["B`@("`@("`@
M("`@(&QI<W0H)'1H:7,M/G)E8W5R16YD+3YY96%R+"`D=&AI<RT^<F5C=7)%
M;F0M/FUO;G1H+"`D=&AI<RT^<F5C=7)%;F0M/FUD87DL("1T:&ES+3YR96-U
M<D5N9"T^:&]U<BP@)'1H:7,M/G)E8W5R16YD+3YM:6XL("1T:&ES+3YR96-U
M<D5N9"T^<V5C*2`]('-S8V%N9B@D4U%,179E;G1;)V5V96YT7W)E8W5R96YD
M9&%T92==+"`G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YT:71L92`]("1D<FEV97(M/F-O;G9E
M<G1&<F]M1')I=F5R*"1344Q%=F5N=%LG979E;G1?=&ET;&4G72D["B`@("`@
M("`@)'1H:7,M/F5V96YT240@/2`D4U%,179E;G1;)V5V96YT7VED)UT["B`@
M("`@("`@)'1H:7,M/G-E=%5)1"@D4U%,179E;G1;)V5V96YT7W5I9"==*3L*
M("`@("`@("`D=&AI<RT^8W)E871O<DE$(#T@)%-13$5V96YT6R=E=F5N=%]C
M<F5A=&]R7VED)UT["B`@("`@("`@)'1H:7,M/G)E8W5R5'EP92`]("AI;G0I
M)%-13$5V96YT6R=E=F5N=%]R96-U<G1Y<&4G73L*("`@("`@("`D=&AI<RT^
M<F5C=7));G1E<G9A;"`]("AI;G0I)%-13$5V96YT6R=E=F5N=%]R96-U<FEN
M=&5R=F%L)UT["@H@("`@("`@(&EF("AI<W-E="@D4U%,179E;G1;)V5V96YT
M7V-A=&5G;W)Y)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YC871E9V]R>2`]
M("1D<FEV97(M/F-O;G9E<G1&<F]M1')I=F5R*"1344Q%=F5N=%LG979E;G1?
M8V%T96=O<GDG72D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D4U%,
M179E;G1;)V5V96YT7VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3YL;V-A=&EO;B`]("1D<FEV97(M/F-O;G9E<G1&<F]M1')I=F5R*"1344Q%
M=F5N=%LG979E;G1?;&]C871I;VXG72D["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<W-E="@D4U%,179E;G1;)V5V96YT7W-T871U<R==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^<W1A='5S(#T@)%-13$5V96YT6R=E=F5N=%]S=&%T=7,G
M73L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1344Q%=F5N=%LG979E
M;G1?871T96YD965S)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YA='1E;F1E
M97,@/2!U;G-E<FEA;&EZ92@D9')I=F5R+3YC;VYV97)T1G)O;41R:79E<B@D
M4U%,179E;G1;)V5V96YT7V%T=&5N9&5E<R==*2D["B`@("`@("`@?0H@("`@
M("`@(&EF("AI<W-E="@D4U%,179E;G1;)V5V96YT7VME>7=O<F1S)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3YK97EW;W)D<R`](&5X<&QO9&4H)RPG+"`D
M9')I=F5R+3YC;VYV97)T1G)O;41R:79E<B@D4U%,179E;G1;)V5V96YT7VME
M>7=O<F1S)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D4U%,
M179E;G1;)V5V96YT7V5X8V5P=&EO;G,G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/F5X8V5P=&EO;G,@/2!E>'!L;V1E*"<L)RP@)%-13$5V96YT6R=E=F5N
M=%]E>&-E<'1I;VYS)UTI.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)%-13$5V96YT6R=E=F5N=%]D97-C<FEP=&EO;B==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^9&5S8W)I<'1I;VX@/2`D9')I=F5R+3YC;VYV97)T1G)O;41R
M:79E<B@D4U%,179E;G1;)V5V96YT7V1E<V-R:7!T:6]N)UTI.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-S970H)%-13$5V96YT6R=E=F5N=%]A;&%R;2==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^86QA<FT@/2`H:6YT*21344Q%=F5N
M=%LG979E;G1?86QA<FTG73L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T
M*"1344Q%=F5N=%LG979E;G1?<F5C=7)D87ES)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3YR96-U<D1A=&$@/2`H:6YT*21344Q%=F5N=%LG979E;G1?<F5C
M=7)D87ES)UT["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^:6YI=&EA;&EZ
M960@/2!T<G5E.PH@("`@("`@("1T:&ES+3YS=&]R960@/2!T<G5E.PH@("`@
M?0H*("`@(&9U;F-T:6]N('1O1')I=F5R*"D*("`@('L*("`@("`@("`D9')I
M=F5R(#T@)B1T:&ES+3YG971$<FEV97(H*3L*"B`@("`@("`@+R\@0F%S:6,@
M9FEE;&1S+@H@("`@("`@("1T:&ES+3Y?<')O<&5R=&EE<ULG979E;G1?8W)E
M871O<E]I9"==(#T@)&1R:79E<BT^8V]N=F5R=%1O1')I=F5R*"1T:&ES+3YG
M971#<F5A=&]R260H*2D["B`@("`@("`@)'1H:7,M/E]P<F]P97)T:65S6R=E
M=F5N=%]T:71L92==(#T@)&1R:79E<BT^8V]N=F5R=%1O1')I=F5R*"1T:&ES
M+3YT:71L92D["B`@("`@("`@)'1H:7,M/E]P<F]P97)T:65S6R=E=F5N=%]D
M97-C<FEP=&EO;B==(#T@)&1R:79E<BT^8V]N=F5R=%1O1')I=F5R*"1T:&ES
M+3YG971$97-C<FEP=&EO;B@I*3L*("`@("`@("`D=&AI<RT^7W!R;W!E<G1I
M97-;)V5V96YT7V-A=&5G;W)Y)UT@/2`D9')I=F5R+3YC;VYV97)T5&]$<FEV
M97(H)'1H:7,M/F=E=$-A=&5G;W)Y*"DI.PH@("`@("`@("1T:&ES+3Y?<')O
M<&5R=&EE<ULG979E;G1?;&]C871I;VXG72`]("1D<FEV97(M/F-O;G9E<G14
M;T1R:79E<B@D=&AI<RT^9V5T3&]C871I;VXH*2D["B`@("`@("`@)'1H:7,M
M/E]P<F]P97)T:65S6R=E=F5N=%]S=&%T=7,G72`]("1T:&ES+3YG9713=&%T
M=7,H*3L*("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97-;)V5V96YT7V%T=&5N
M9&5E<R==(#T@)&1R:79E<BT^8V]N=F5R=%1O1')I=F5R*'-E<FEA;&EZ92@D
M=&AI<RT^9V5T071T96YD965S*"DI*3L*("`@("`@("`D=&AI<RT^7W!R;W!E
M<G1I97-;)V5V96YT7VME>7=O<F1S)UT@/2`D9')I=F5R+3YC;VYV97)T5&]$
M<FEV97(H:6UP;&]D92@G+"<L("1T:&ES+3YG971+97EW;W)D<R@I*2D["B`@
M("`@("`@)'1H:7,M/E]P<F]P97)T:65S6R=E=F5N=%]E>&-E<'1I;VYS)UT@
M/2!I;7!L;V1E*"<L)RP@)'1H:7,M/F=E=$5X8V5P=&EO;G,H*2D["B`@("`@
M("`@)'1H:7,M/E]P<F]P97)T:65S6R=E=F5N=%]M;V1I9FEE9"==(#T@=&EM
M92@I.PH*("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97-;)V5V96YT7W-T87)T
M)UT@/2!D871E*"=9+6TM9"!(.FDZ<R<L("1T:&ES+3YS=&%R="T^=&EM97-T
M86UP*"DI.PH*("`@("`@("`O+R!%=F5N="!E;F0N"B`@("`@("`@)'1H:7,M
M/E]P<F]P97)T:65S6R=E=F5N=%]E;F0G72`](&1A=&4H)UDM;2UD($@Z:3IS
M)RP@)'1H:7,M/F5N9"T^=&EM97-T86UP*"DI.PH*("`@("`@("`O+R!!;&%R
M;2X*("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97-;)V5V96YT7V%L87)M)UT@
M/2`D=&AI<RT^9V5T06QA<FTH*3L*"B`@("`@("`@+R\@4F5C=7)R96YC92X*
M("`@("`@("`D<F5C=7)?96YD(#T@:7-S970H)'1H:7,M/G)E8W5R16YD*2`_
M(&5X<&QO9&4H)SHG+"!`9&%T92@G63IN.FHG+"`D=&AI<RT^<F5C=7)%;F0M
M/G1I;65S=&%M<"@I*2D@.B!N=6QL.PH@("`@("`@(&EF("AE;7!T>2@D<F5C
M=7)?96YD6S!=*2!\?"`D<F5C=7)?96YD6S!=(#P](#$Y-S`I('L*("`@("`@
M("`@("`@)')E8W5R7V5N9%LP72`](#DY.3D["B`@("`@("`@("`@("1R96-U
M<E]E;F1;,5T@/2`Q,CL*("`@("`@("`@("`@)')E8W5R7V5N9%LR72`](#,Q
M.PH@("`@("`@('T*"B`@("`@("`@)')E8W5R(#T@)'1H:7,M/F=E=%)E8W5R
M5'EP92@I.PH@("`@("`@("1T:&ES+3Y?<')O<&5R=&EE<ULG979E;G1?<F5C
M=7)T>7!E)UT@/2`D<F5C=7(["B`@("`@("`@:68@*"1R96-U<B`A/2!+4D].
M3TQ)5$A?4D5#55)?3D].12D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R;W!E
M<G1I97-;)V5V96YT7W)E8W5R:6YT97)V86PG72`]("1T:&ES+3YG971296-U
M<DEN=&5R=F%L*"D["B`@("`@("`@("`@("1T:&ES+3Y?<')O<&5R=&EE<ULG
M979E;G1?<F5C=7)E;F1D871E)UT@/2!S<')I;G1F*"<E,#1D)3`R9"4P,F0G
M+"`D<F5C=7)?96YD6S!=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5C=7)?96YD
M6S%=+"`D<F5C=7)?96YD6S)=*3L*"B`@("`@("`@("`@('-W:71C:"`H)')E
M8W5R*2!["B`@("`@("`@("`@(&-A<V4@2U)/3D],251(7U)%0U527U=%14M,
M63H*("`@("`@("`@("`@("`@("1T:&ES+3Y?<')O<&5R=&EE<ULG979E;G1?
M<F5C=7)D87ES)UT@/2`D=&AI<RT^9V5T4F5C=7)/;D1A>7,H*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=%!R;W!E<G1I97,H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!R;W!E<G1I97,["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR
M;VYO;&ET:"]L:6(O0FQO8VLO````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(P,C,U`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]";&]C:R]P<F5V;6]N=&AL
M:7-T+G!H<``````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-34T,``Q,#0Q-S,V,C<U
M,P`P,C,V-C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B4&%S="!%=F5N=',@3&ES
M="(I.PH*+RHJ"B`J($AO<F1E7T)L;V-K7TMR;VYO;&ET:%]M;VYT:&QI<W0Z
M.B!);7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&5?0FQO8VL*("H@05!)('1O
M(&1I<W!L87D@82!L:7-T(&]F('!R979I;W5S(&-A;&5N9&%R(&ET96US(&=R
M;W5P960@8GD@;6]N=&@N"B`J"B`J("1(;W)D93H@:W)O;F]L:71H+VQI8B]"
M;&]C:R]P<F5V;6]N=&AL:7-T+G!H<"QV(#$N,34N,BXV(#(P,#8O,#$O,#,@
M,C`Z-3`Z,3<@8VAU8VL@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO
M8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TMR;VYO;&ET:%]P<F5V;6]N=&AL
M:7-T(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=K
M<F]N;VQI=&@G.PH*("`@(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@>PH@("`@
M("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO8F%S
M92YP:'`G.PH*("`@("`@("`D<&%R86US(#T@87)R87DH)V-A;&5N9&%R)R`]
M/B!A<G)A>2@G;F%M92<@/3X@7R@B0V%L96YD87(B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)V5N
M=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=D969A=6QT)R`]/B`G7U]A;&PG*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@)VUO;G1H<R<@("`]/B!A<G)A>2@G;F%M92<@/3X@7R@B36]N=&AS
M($)E9F]R92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@,BDI.PH@
M("`@("`@("1P87)A;7-;)V-A;&5N9&%R)UU;)W9A;'5E<R==6R=?7V%L;"==
M(#T@7R@B06QL(%9I<VEB;&4B*3L*("`@("`@("!F;W)E86-H("A+<F]N;VQI
M=&@Z.FQI<W1#86QE;F1A<G,H*2!A<R`D:60@/3X@)&-A;"D@>PH@("`@("`@
M("`@("`D<&%R86US6R=C86QE;F1A<B==6R=V86QU97,G75LD:61=(#T@)&-A
M;"T^9V5T*"=N86UE)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A
M<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@
M5&AE('1I=&QE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I
M"B`@("!["B`@("`@("`@<F5T=7)N($AO<F1E.CIL:6YK*$AO<F1E.CIU<FPH
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EN:71I86Q086=E*"DL('1R=64I
M*2`N(%\H(E!A<W0@179E;G1S($QI<W0B*2`N("<\+V$^)SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN('1H:7,@8FQO8VLN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]B87-E+G!H
M<"<["B`@("`@("`@<F5Q=6ER95]O;F-E($M23TY/3$E42%]"05-%("X@)R]L
M:6(O1&%Y+G!H<"<["@H@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1P<F5F
M<SL*"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W1O;VQT:7`N:G,G
M+"`G:&]R9&4G+"!T<G5E*3L*"B`@("`@("`@)'-T87)T1&%T92`]("9N97<@
M2&]R9&5?1&%T92AA<G)A>2@G>65A<B<@/3X@9&%T92@G62<I+"`G;6]N=&@G
M(#T^(&1A=&4H)VXG*2`M("1T:&ES+3Y?<&%R86US6R=M;VYT:',G72P@)VUD
M87DG(#T^(&1A=&4H)VHG*2DI.PH@("`@("`@("1S=&%R=$1A=&4M/F-O<G)E
M8W0H*3L*("`@("`@("`D96YD1&%T92`]("9N97<@2&]R9&5?1&%T92AA<G)A
M>2@G>65A<B<@/3X@9&%T92@G62<I+"`G;6]N=&@G(#T^(&1A=&4H)VXG*2P@
M)VUD87DG(#T^(&1A=&4H)VHG*2`M(#$I*3L*("`@("`@("`D96YD1&%T92T^
M8V]R<F5C="@I.PH*("`@("`@("`D;F]W(#T@)'-T87)T1&%T92T^=&EM97-T
M86UP*"D["B`@("`@("`@)&-U<G)E;G1?;6]N=&@@/2`G)SL*"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=C86QE;F1A<B==*2`F)B`D=&AI
M<RT^7W!A<F%M<ULG8V%L96YD87(G72`A/2`G7U]A;&PG*2!["B`@("`@("`@
M("`@("1A;&QE=F5N=',@/2!+<F]N;VQI=&@Z.FQI<W1%=F5N=',H)'-T87)T
M1&%T92P@)&5N9$1A=&4L(&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=C86QE;F1A
M<B==*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%L;&5V96YT
M<R`]($MR;VYO;&ET:#HZ;&ES=$5V96YT<R@D<W1A<G1$871E+"`D96YD1&%T
M92P@)$=,3T)!3%-;)V1I<W!L87E?8V%L96YD87)S)UTI.PH@("`@("`@('T*
M"B`@("`@("`@)&AT;6P@/2`G/&QI;FL@:')E9CTB)R`N($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G=&AE;65S+V-A=&5G;W)Y0U-3+G!H<"<I("X@)R(@<F5L
M/2)S='EL97-H965T(B!T>7!E/2)T97AT+V-S<R(@+SXG.PH*("`@("`@("`O
M*B!(;W<@;6%N>2!D87ES(&1O('=E(&YE960@=&\@8VAE8VLN("HO"B`@("`@
M("`@)&1A>7,@/2!$871E7T-A;&,Z.F1A=&5$:69F*"1S=&%R=$1A=&4M/FUD
M87DL("1S=&%R=$1A=&4M/FUO;G1H+"`D<W1A<G1$871E+3YY96%R+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YD1&%T92T^;61A
M>2P@)&5N9$1A=&4M/FUO;G1H+"`D96YD1&%T92T^>65A<BD["@H@("`@("`@
M("\J($QO;W`@=&AR;W5G:"!T:&4@9&%Y<RX@*B\*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D9&%Y<SL@)&DK*RD@>PH@("`@("`@("`@("`D9&%Y(#T@
M)FYE=R!+<F]N;VQI=&A?1&%Y*"1S=&%R=$1A=&4M/FUO;G1H+"`D<W1A<G1$
M871E+3YM9&%Y("L@)&DL("1S=&%R=$1A=&4M/GEE87(I.PH@("`@("`@("`@
M("`D=&]D87E?<W1A;7`@/2`D9&%Y+3YG9713=&%M<"@I.PH@("`@("`@("`@
M("!I9B`H96UP='DH)&%L;&5V96YT<ULD=&]D87E?<W1A;7!=*2D@>PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1E=F5N=',@/2`F)&%L;&5V96YT<ULD=&]D87E?<W1A;7!=.PH@("`@
M("`@("`@("`D9FER<W1E=F5N="`]('1R=64["@H@("`@("`@("`@("`O*B!/
M=71P=70@;6]N=&@@:&5A9&5R+B`J+PH@("`@("`@("`@("!I9B`H)&-U<G)E
M;G1?;6]N=&@@(3T@)&1A>2T^;6]N=&@I('L*("`@("`@("`@("`@("`@("1C
M=7)R96YT7VUO;G1H(#T@<W1R9G1I;64H)R5M)RP@)'1O9&%Y7W-T86UP*3L*
M("`@("`@("`@("`@("`@("1H=&UL("X]("<\='(^/'1D(&-O;'-P86X](C0B
M(&-L87-S/2)C;VYT<F]L(CX\<W1R;VYG/B<@+B!S=')F=&EM92@G)4(G+"`D
M=&]D87E?<W1A;7`I("X@)SPO<W1R;VYG/CPO=&0^/"]T<CXG.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D=&]D87DQ,F%M(#T@;6MT:6UE*#`L(#`L
M(#`L("1D87DM/FUO;G1H+"`D9&%Y+3YM9&%Y+"`D9&%Y+3YY96%R*3L*("`@
M("`@("`@("`@)'1O;6]R<F]W,3)A;2`](&UK=&EM92@P+"`P+"`P+"`D9&%Y
M+3YM;VYT:"P@)&1A>2T^;61A>2`K(#$L("1D87DM/GEE87(I.PH@("`@("`@
M("`@("!F;W)E86-H("@D979E;G1S(&%S("1E=F5N="D@>PH@("`@("`@("`@
M("`@("`@:68@*"$D979E;G0M/FAA<U)E8W5R5'EP92A+4D].3TQ)5$A?4D5#
M55)?3D].12DI('L*("`@("`@("`@("`@("`@("`@("`D979E;G0M/G-T87)T
M(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=H;W5R)R`]/B`D979E;G0M/G-T
M87)T+3YH;W5R+"`G;6EN)R`]/B`D979E;G0M/G-T87)T+3YM:6XL("=S96,G
M(#T^("1E=F5N="T^<W1A<G0M/G-E8RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@
M/3X@)&1A>2T^;6]N=&@L("=M9&%Y)R`]/B`D9&%Y+3YM9&%Y+"`G>65A<B<@
M/3X@)&1A>2T^>65A<BDI.PH@("`@("`@("`@("`@("`@("`@("1E=F5N="T^
M96YD(#T@)FYE=R!(;W)D95]$871E*"1E=F5N="T^<W1A<G0M/G1I;65S=&%M
M<"@I("L@)&5V96YT+3YD=7)-:6X@*B`V,"D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D979E;G0M/G-T87)T
M+3YT:6UE<W1A;7`H*2`\("1T;V1A>3$R86TI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5V96YT+3YS=&%R="`]("9N97<@2&]R9&5?1&%T92@D=&]D
M87DQ,F%M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1E=F5N="T^96YD+3YT:6UE<W1A;7`H*2`^/2`D=&]M;W)R
M;W<Q,F%M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1E=F5N="T^96YD
M(#T@)FYE=R!(;W)D95]$871E*"1T;VUO<G)O=S$R86TI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("!I9B`H)&5V96YT+3YE;F0M/G1I;65S=&%M<"@I(#P@)&YO=RD@>PH@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=S=6UM87)Y
M7V%L87)M<R<I("8F("$D979E;G0M/F%L87)M*2!["B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H)&9I<G-T979E;G0I('L*("`@("`@("`@("`@("`@("`@("`D
M:'1M;"`N/2`G/'1R/CQT9"!C;&%S<STB=&5X="(@=F%L:6=N/2)T;W`B(&%L
M:6=N/2)R:6=H="(^/'-T<F]N9SXG.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D9&%Y+3YI<U1O9&%Y*"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@7R@B5&]D87DB*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)&1A>2T^:7-4;VUO<G)O=R@I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X](%\H(E1O;6]R<F]W(BD["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@
M+CT@9&%T92@G:B<L("1T;V1A>5]S=&%M<"D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W-T<F]N9SXF
M;F)S<#L\+W1D/B<["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T979E;G0@
M/2!F86QS93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0@8VQA<W,](G1E>'0B/B9N8G-P
M.SPO=&0^)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M:'1M;"`N/2`G/'1D(&-L87-S/2)T97AT(B!N;W=R87`](FYO=W)A<"(@=F%L
M:6=N/2)T;W`B/B<["B`@("`@("`@("`@("`@("!I9B`H)&5V96YT+3YS=&%R
M="T^=&EM97-T86UP*"D@/"`D;F]W("8F("1E=F5N="T^96YD+3YT:6UE<W1A
M;7`H*2`^("1N;W<I('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G
M/'-T<F]N9SXG("X@)&5V96YT+3YG971,;V-A=&EO;B@I("X@)SPO<W1R;VYG
M/B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1H=&UL("X]("1E=F5N="T^9V5T3&]C871I;VXH*3L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/"]T9#X\=&0@
M8VQA<W,](G1E>'0B/B9N8G-P.R9N8G-P.R9N8G-P.SPO=&0^)R`N"B`@("`@
M("`@("`@("`@("`@("`@)SQT9"!C;&%S<STB8FQO8VLM979E;G1B;W@@8V%T
M96=O<GDG("X@;60U*"1E=F5N="T^9V5T0V%T96=O<GDH*2D@+B`G(B!V86QI
M9VX](G1O<"(^)SL*"B`@("`@("`@("`@("`@("!I9B`H)&5V96YT+3YS=&%R
M="T^=&EM97-T86UP*"D@/"`D;F]W("8F("1E=F5N="T^96YD+3YT:6UE<W1A
M;7`H*2`^("1N;W<I('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G
M/'-T<F]N9SXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1E=F5N="T^979E;G1)1"DI('L*("`@("`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`D979E;G0M/F=E=$QI;FLH;G5L;"P@=')U92D["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&5V96YT+3YT87-K240I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH
M2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/FQI;FLH)W1A<VMS+W-H;W<G+"!A<G)A
M>2@G=&%S:R<@/3X@)&5V96YT+3YT87-K240L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=&%S:VQI<W0G(#T^("1E=F5N
M="T^=&%S:VQI<W1)1"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=')U92DL("1E=F5N="T^9V5T5&ET
M;&4H*2D@+B`D979E;G0M/F=E=%1I=&QE*"D@+B`G/"]A/B<["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]
M("1E=F5N="T^9V5T5&ET;&4H*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("@D979E;G0M/G-T87)T+3YT:6UE<W1A;7`H*2`\("1N
M;W<@)B8@)&5V96YT+3YE;F0M/G1I;65S=&%M<"@I(#X@)&YO=RD@>PH@("`@
M("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W-T<F]N9SXG.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SPO=&0^/"]T
M<CXG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H96UP
M='DH)&AT;6PI*2!["B`@("`@("`@("`@(')E='5R;B`G/&5M/B<@+B!?*").
M;R!E=F5N=',@=&\@9&ES<&QA>2(I("X@)SPO96T^)SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`G/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB
M,3`P)2(^)R`N("1H=&UL("X@)SPO=&%B;&4^)SL*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:W)O;F]L:71H+VQI8B]";&]C:R]M;VYT:"YP:'``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q-3`R-P`Q,#0Q-S,V,C<U,P`P,C(P-S4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"B1B
M;&]C:U]N86UE(#T@7R@B36]N=&@@5FEE=R(I.PH*+RHJ"B`J($AO<F1E7T)L
M;V-K7TMR;VYO;&ET:%]M;VYT:#HZ($EM<&QE;65N=&%T:6]N(&]F('1H92!(
M;W)D95]";&]C:R!!4$D*("H@=&\@9&ES<&QA>2!A(&UI;FD@;6]N=&@@=FEE
M=R!O9B!C86QE;F1A<B!I=&5M<RX*("H*("H@)$AO<F1E.B!K<F]N;VQI=&@O
M;&EB+T)L;V-K+VUO;G1H+G!H<"QV(#$N,C$N,BXW(#(P,#8O,#$O,#,@,C`Z
M-3`Z,3<@8VAU8VL@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*
M("HO"F-L87-S($AO<F1E7T)L;V-K7TMR;VYO;&ET:%]M;VYT:"!E>'1E;F1S
M($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:W)O;F]L:71H)SL*
M"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+V)A<V4N<&AP)SL*"B`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*"=C86QE;F1A<B<@/3X@87)R87DH)VYA
M;64G(#T^(%\H(D-A;&5N9&%R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@/3X@)U]?86QL)RDI.PH@("`@("`@("1P87)A;7-;)V-A;&5N9&%R)UU;
M)W9A;'5E<R==6R=?7V%L;"==(#T@7R@B06QL(%9I<VEB;&4B*3L*("`@("`@
M("!F;W)E86-H("A+<F]N;VQI=&@Z.FQI<W1#86QE;F1A<G,H*2!A<R`D:60@
M/3X@)&-A;"D@>PH@("`@("`@("`@("`D<&%R86US6R=C86QE;F1A<B==6R=V
M86QU97,G75LD:61=(#T@)&-A;"T^9V5T*"=N86UE)RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%1H92!T:71L92!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("`@5&AE('1I=&QE('1E>'0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*("`@("`@("!R971U<FX@2&]R9&4Z.FQI;FLH2&]R9&4Z.G5R;"@D
M<F5G:7-T<GDM/F=E=$EN:71I86Q086=E*"DL('1R=64I*2`N('-T<F9T:6UE
M*"<E0BP@)5DG*2`N("<\+V$^(#QS;6%L;#XG("X*("`@("`@("`@("`@2&]R
M9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&1E=F5N="YP:'`G
M+"!T<G5E*2D@+B!(;W)D93HZ:6UG*"=N97<N<&YG)RP@7R@B3F5W($5V96YT
M(BDI("X@)R`G("X@7R@B3F5W($5V96YT(BD@+B`G/"]A/CPO<VUA;&P^)SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN('1H
M:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@
M8V]N=&5N=`H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("![
M"B`@("`@("`@9VQO8F%L("1P<F5F<SL*("`@("`@("!R97%U:7)E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+V)A<V4N<&AP)SL*("`@("`@("!R
M97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]$87DN<&AP)SL*
M"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W1O;VQT:7`N:G,G+"`G
M:&]R9&4G+"!T<G5E*3L*"B`@("`@("`@)'EE87(@/2!D871E*"=9)RD["B`@
M("`@("`@)&UO;G1H(#T@9&%T92@G;2<I.PH@("`@("`@("1T;V1A>2`](&UK
M=&EM92@P+"`P+"`P+"!D871E*"=N)RDL(&1A=&4H)VHG*2P@9&%T92@G62<I
M*3L*"B`@("`@("`@)'-T87)T9&%Y(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y
M*"=M9&%Y)R`]/B`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;6]N=&@G(#T^("1M;VYT:"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)WEE87(G(#T^("1Y96%R*2D[
M"B`@("`@("`@)'-T87)T9&%Y(#T@)'-T87)T9&%Y+3YD87E/9E=E96LH*3L*
M("`@("`@("`D9&%Y<TEN5FEE=R`]($1A=&5?0V%L8SHZ=V5E:W-);DUO;G1H
M*"1M;VYT:"P@)'EE87(I("H@-SL*("`@("`@("!I9B`H(21P<F5F<RT^9V5T
M5F%L=64H)W=E96M?<W1A<G1?;6]N9&%Y)RDI('L*("`@("`@("`@("`@)'-T
M87)T3V96:65W(#T@,2`M("1S=&%R=&1A>3L*"B`@("`@("`@("`@("\O(%=E
M(&UA>2!N965D('1O(&%D:G5S="!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M('9I97<@:68*("`@("`@("`@("`@+R\@=V4G<F4@<W1A<G1I;F<@=V5E:W,@
M;VX@4W5N9&%Y+@H@("`@("`@("`@("!I9B`H)'-T87)T9&%Y(#T]($A/4D1%
M7T1!5$5?4U5.1$%9*2!["B`@("`@("`@("`@("`@("`D9&%Y<TEN5FEE=R`M
M/2`W.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1E;F1D87D@/2`F;F5W
M($AO<F1E7T1A=&4H87)R87DH)VUD87DG(#T^($AO<F1E7T1A=&4Z.F1A>7-)
M;DUO;G1H*"1M;VYT:"P@)'EE87(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@/3X@)&UO;G1H+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y96%R
M)R`]/B`D>65A<BDI.PH@("`@("`@("`@("`D96YD9&%Y(#T@)&5N9&1A>2T^
M9&%Y3V97965K*"D["B`@("`@("`@("`@(&EF("@D96YD9&%Y(#T]($A/4D1%
M7T1!5$5?4U5.1$%9*2!["B`@("`@("`@("`@("`@("`D9&%Y<TEN5FEE=R`K
M/2`W.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"1S=&%R=&1A>2`]/2!(3U)$15]$051%7U-53D1!62D@>PH@("`@
M("`@("`@("`@("`@)'-T87)T3V96:65W(#T@+34["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<W1A<G1/9E9I97<@/2`R("T@)'-T
M87)T9&%Y.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W1A
M<G1$871E(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=Y96%R)R`]/B`D>65A
M<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=M;VYT:"<@/3X@)&UO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VUD87DG(#T^("1S=&%R=$]F5FEE=RDI.PH@
M("`@("`@("1E;F1$871E(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=Y96%R
M)R`]/B`D>65A<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;6]N=&@G(#T^("1M;VYT:"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;61A>2<@/3X@)'-T87)T3V96:65W
M("L@)&1A>7-);E9I97<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VAO=7(G(#T^(#(S+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=M:6XG(#T^(#4Y+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S96,G(#T^(#4Y*2D[
M"B`@("`@("`@)'-T87)T1&%T92T^8V]R<F5C="@I.PH@("`@("`@("1E;F1$
M871E+3YC;W)R96-T*"D["@H@("`@("`@("\J(%1A8FQE('-T87)T+B!A;F0@
M8W5R<F5N="!M;VYT:"!I;F1I8V%T;W(N("HO"B`@("`@("`@)&AT;6P@/2`G
M/'1A8FQE(&-E;&QS<&%C:6YG/2(Q(B!C;&%S<STB8FQO8VLM;6]N=&AG<FED
M(B!W:61T:#TB,3`P)2(^/'1R/B<["@H@("`@("`@("\J(%-E="!U<"!T:&4@
M=V5E:V1A>7,N("HO"B`@("`@("`@)'=E96MD87ES(#T@87)R87DH7R@B36\B
M*2P@7R@B5'4B*2P@7R@B5V4B*2P@7R@B5&@B*2P@7R@B1G(B*2P@7R@B4V$B
M*2D["B`@("`@("`@:68@*"$D<')E9G,M/F=E=%9A;'5E*"=W965K7W-T87)T
M7VUO;F1A>2<I*2!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)'=E96MD
M87ES+"!?*")3=2(I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=V5E:V1A>7-;72`](%\H(E-U(BD["B`@("`@("`@?0H@("`@("`@(&9O<F5A
M8V@@*"1W965K9&%Y<R!A<R`D=V5E:V1A>2D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`G/'1H(&-L87-S/2)I=&5M(CXG("X@)'=E96MD87D@+B`G/"]T:#XG
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=C86QE;F1A<B==*2`F)B`D=&AI<RT^7W!A<F%M<ULG8V%L96YD87(G72`A
M/2`G7U]A;&PG*2!["B`@("`@("`@("`@("1A;&Q?979E;G1S(#T@2W)O;F]L
M:71H.CIL:7-T179E;G1S*"1S=&%R=$1A=&4L("1E;F1$871E+"!A<G)A>2@D
M=&AI<RT^7W!A<F%M<ULG8V%L96YD87(G72DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1A;&Q?979E;G1S(#T@2W)O;F]L:71H.CIL:7-T179E
M;G1S*"1S=&%R=$1A=&4L("1E;F1$871E+"`D1TQ/0D%,4ULG9&ES<&QA>5]C
M86QE;F1A<G,G72D["B`@("`@("`@?0H*("`@("`@("`D=V5E:W,@/2!A<G)A
M>2@I.PH@("`@("`@("1W965K9&%Y(#T@,#L*("`@("`@("`D=V5E:R`]("TQ
M.PH@("`@("`@(&9O<B`H)&1A>2`]("1S=&%R=$]F5FEE=SL@)&1A>2`\("1S
M=&%R=$]F5FEE=R`K("1D87ES26Y6:65W.R`D9&%Y*RLI('L*("`@("`@("`@
M("`@)&1A>5-T86UP(#T@;6MT:6UE*#`L(#`L(#`L("1M;VYT:"P@)&1A>2P@
M)'EE87(I.PH*("`@("`@("`@("`@:68@*"1W965K9&%Y(#T](#<I('L*("`@
M("`@("`@("`@("`@("1W965K9&%Y(#T@,#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H)'=E96MD87D@/3T@,"D@>PH@("`@("`@("`@("`@("`@
M)'=E96LK*SL*("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W1R/CQT<CXG
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H;6MT:6UE*#`L(#`L
M(#`I(#T]("1D87E3=&%M<"D@>PH@("`@("`@("`@("`@("`@)'1D7V-L87-S
M(#T@)W1O9&%Y)SL*("`@("`@("`@("`@?2!E;'-E:68@*&1A=&4H)VXG+"`D
M9&%Y4W1A;7`I("$]("1M;VYT:"D@>PH@("`@("`@("`@("`@("`@)'1D7V-L
M87-S(#T@)V]T:&5R;6]N=&@G.PH@("`@("`@("`@("!](&5L<V5I9B`H9&%T
M92@G=R<L("1D87E3=&%M<"D@/3T@,"!\?"!D871E*"=W)RP@)&1A>5-T86UP
M*2`]/2`V*2!["B`@("`@("`@("`@("`@("`D=&1?8VQA<W,@/2`G=V5E:V5N
M9"<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&1?
M8VQA<W,@/2`G=&5X="<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT
M;6P@+CT@)SQT9"!A;&EG;CTB8V5N=&5R(B!C;&%S<STB)R`N("1T9%]C;&%S
M<R`N("<B/B<["@H@("`@("`@("`@("`O*B!3970@=7`@=&AE(&QI;FL@=&\@
M=&AE(&1A>2!V:65W+B`J+PH@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=D87DN<&AP)RP@=')U92D["B`@("`@("`@("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@87)R87DH)W1I;65S=&%M
M<"<@/3X@)&1A>5-T86UP*2D["@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A
M;&Q?979E;G1S6R1D87E3=&%M<%TI*2!["B`@("`@("`@("`@("`@("`O*B!4
M:&5R92!A<F4@979E;G1S.R!C<F5A=&4@82!C96QL('=I=&@@=&]O;'1I<"!T
M;PH@("`@("`@("`@("`@("`@("H@;&ES="!T:&5M+B`J+PH@("`@("`@("`@
M("`@("`@)&1A>5]E=F5N=',@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1A;&Q?979E;G1S6R1D87E3=&%M<%T@87,@)&5V96YT*2!["B`@("`@
M("`@("`@("`@("`@("`@)&1A>5]E=F5N=',@+CT@9&%T92@D<')E9G,M/F=E
M=%9A;'5E*"=T=V5N='E&;W5R)RD@/R`G1SII)R`Z("=G.FEA)RP@)&5V96YT
M+3YS=&%R="T^=&EM97-T86UP*"DI("X@)R`M("<@+B!D871E*"1P<F5F<RT^
M9V5T5F%L=64H)W1W96YT>49O=7(G*2`_("='.FDG(#H@)V<Z:6$G+"`D979E
M;G0M/F5N9"T^=&EM97-T86UP*"DI.PH@("`@("`@("`@("`@("`@("`@("1D
M87E?979E;G1S("X]("@D979E;G0M/F=E=$QO8V%T:6]N*"DI(#\@)R`H)R`N
M("1E=F5N="T^9V5T3&]C871I;VXH*2`N("<I)R`Z("<G.PH@("`@("`@("`@
M("`@("`@("`@("1D87E?979E;G1S("X]("<@)R`N("1E=F5N="T^9V5T5&ET
M;&4H*2`N(")<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D8V5L;"`]($AO<F1E.CIL:6YK5&]O;'1I<"@D=7)L+"!?*")6:65W($1A
M>2(I+"`G)RP@)R<L("<G+"`D9&%Y7V5V96YT<RD@+B!D871E*"=J)RP@)&1A
M>5-T86UP*2`N("<\+V$^)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("\J($YO(&5V96YT<RP@<&QA:6X@;&EN:R!T;R!T:&4@9&%Y
M+B`J+PH@("`@("`@("`@("`@("`@)&-E;&P@/2!(;W)D93HZ;&EN:U1O;VQT
M:7`H)'5R;"P@7R@B5FEE=R!$87DB*2D@+B!D871E*"=J)RP@)&1A>5-T86UP
M*2`N("<\+V$^)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0F]L
M9"!T:&4@8V5L;"!I9B!T:&5R92!A<F4@979E;G1S+B`J+PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1A;&Q?979E;G1S6R1D87E3=&%M<%TI*2!["B`@("`@
M("`@("`@("`@("`D8V5L;"`]("<\<W1R;VYG/B<@+B`D8V5L;"`N("<\+W-T
M<F]N9SXG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D:'1M;"`N/2`D
M8V5L;"`N("<\+W1D/B<["B`@("`@("`@("`@("1W965K9&%Y*RL["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&AT;6P@+B`G/"]T<CX\+W1A8FQE/B<[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]"
M;&]C:R]M;VYT:&QI<W0N<&AP````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-38P-``Q,#0Q-S,V,C<U,P`P,C(W-S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B
M36]N=&AL>2!%=F5N=',@3&ES="(I.PH*+RHJ"B`J($AO<F1E7T)L;V-K7TMR
M;VYO;&ET:%]M;VYT:&QI<W0Z.B!);7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R
M9&5?0FQO8VL@05!)"B`J('1O(&1I<W!L87D@82!L:7-T(&]F(&-A;&5N9&%R
M(&ET96US(&=R;W5P960@8GD@;6]N=&@N"B`J"B`J("1(;W)D93H@:W)O;F]L
M:71H+VQI8B]";&]C:R]M;VYT:&QI<W0N<&AP+'8@,2XR-RXR+C8@,C`P-B\P
M,2\P,R`R,#HU,#HQ-R!C:'5C:R!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D
M95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2W)O;F]L:71H7VUO;G1H
M;&ES="!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@/2`G
M:W)O;F]L:71H)SL*"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@
M("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+V)A
M<V4N<&AP)SL*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=C86QE;F1A<B<@
M/3X@87)R87DH)VYA;64G(#T^(%\H(D-A;&5N9&%R(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E
M;G5M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)U]?86QL)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("=M;VYT:',G("`@/3X@87)R87DH)VYA;64G(#T^(%\H(DUO;G1H
M<R!!:&5A9"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@,BDI.PH@
M("`@("`@("1P87)A;7-;)V-A;&5N9&%R)UU;)W9A;'5E<R==6R=?7V%L;"==
M(#T@7R@B06QL(%9I<VEB;&4B*3L*("`@("`@("!F;W)E86-H("A+<F]N;VQI
M=&@Z.FQI<W1#86QE;F1A<G,H*2!A<R`D:60@/3X@)&-A;"D@>PH@("`@("`@
M("`@("`D<&%R86US6R=C86QE;F1A<B==6R=V86QU97,G75LD:61=(#T@)&-A
M;"T^9V5T*"=N86UE)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A
M<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@
M5&AE('1I=&QE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I
M"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("!R971U
M<FX@2&]R9&4Z.FQI;FLH2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E=$EN:71I
M86Q086=E*"DL('1R=64I*2`N(%\H(DUO;G1H;'D@179E;G1S($QI<W0B*2`N
M("<\+V$^(#QS;6%L;#XG("X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&1E=F5N="YP:'`G+"!T<G5E*2D@+B!(
M;W)D93HZ:6UG*"=N97<N<&YG)RP@7R@B3F5W($5V96YT(BDI("X@)R`G("X@
M7R@B3F5W($5V96YT(BD@+B`G/"]A/CPO<VUA;&P^)SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@<F5Q
M=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]B87-E+G!H<"<[
M"B`@("`@("`@<F5Q=6ER95]O;F-E($M23TY/3$E42%]"05-%("X@)R]L:6(O
M1&%Y+G!H<"<["@H@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1P<F5F<SL*
M"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W1O;VQT:7`N:G,G+"`G
M:&]R9&4G+"!T<G5E*3L*"B`@("`@("`@)&YO=R`]('1I;64H*3L*("`@("`@
M("`D=&]D87D@/2!D871E*"=J)RD["B`@("`@("`@)&-U<G)E;G1?;6]N=&@@
M/2`G)SL*"B`@("`@("`@)'-T87)T1&%T92`]("9N97<@2&]R9&5?1&%T92AA
M<G)A>2@G>65A<B<@/3X@9&%T92@G62<I+"`G;6]N=&@G(#T^(&1A=&4H)VXG
M*2P@)VUD87DG(#T^(&1A=&4H)VHG*2DI.PH@("`@("`@("1E;F1$871E(#T@
M)FYE=R!(;W)D95]$871E*&%R<F%Y*"=Y96%R)R`]/B!D871E*"=9)RDL("=M
M;VYT:"<@/3X@9&%T92@G;B<I("L@)'1H:7,M/E]P87)A;7-;)VUO;G1H<R==
M+"`G;61A>2<@/3X@9&%T92@G:B<I("T@,2DI.PH@("`@("`@("1E;F1$871E
M+3YC;W)R96-T*"D["@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M
M<ULG8V%L96YD87(G72D@)B8@)'1H:7,M/E]P87)A;7-;)V-A;&5N9&%R)UT@
M(3T@)U]?86QL)RD@>PH@("`@("`@("`@("`D86QL979E;G1S(#T@2W)O;F]L
M:71H.CIL:7-T179E;G1S*"1S=&%R=$1A=&4L("1E;F1$871E+"!A<G)A>2@D
M=&AI<RT^7W!A<F%M<ULG8V%L96YD87(G72DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1A;&QE=F5N=',@/2!+<F]N;VQI=&@Z.FQI<W1%=F5N
M=',H)'-T87)T1&%T92P@)&5N9$1A=&4L("1'3$]"04Q36R=D:7-P;&%Y7V-A
M;&5N9&%R<R==*3L*("`@("`@("!]"@H@("`@("`@("1H=&UL(#T@)SQL:6YK
M(&AR968](B<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)W1H96UE<R]C871E
M9V]R>4-34RYP:'`G*2`N("<B(')E;#TB<W1Y;&5S:&5E="(@='EP93TB=&5X
M="]C<W,B("\^)SL*"B`@("`@("`@+RH@2&]W(&UA;GD@9&%Y<R!D;R!W92!N
M965D('1O(&-H96-K+B`J+PH@("`@("`@("1D87ES(#T@1&%T95]#86QC.CID
M871E1&EF9B@D<W1A<G1$871E+3YM9&%Y+"`D<W1A<G1$871E+3YM;VYT:"P@
M)'-T87)T1&%T92T^>65A<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N9$1A=&4M/FUD87DL("1E;F1$871E+3YM;VYT:"P@)&5N
M9$1A=&4M/GEE87(I.PH*("`@("`@("`O*B!,;V]P('1H<F]U9V@@=&AE(&1A
M>7,N("HO"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&1A>7,[("1I*RLI
M('L*("`@("`@("`@("`@)&1A>2`]("9N97<@2W)O;F]L:71H7T1A>2@D<W1A
M<G1$871E+3YM;VYT:"P@)'1O9&%Y("L@)&DI.PH@("`@("`@("`@("`D=&]D
M87E?<W1A;7`@/2`D9&%Y+3YG9713=&%M<"@I.PH@("`@("`@("`@("!I9B`H
M96UP='DH)&%L;&5V96YT<ULD=&]D87E?<W1A;7!=*2D@>PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F
M:7)S=&5V96YT(#T@=')U93L*"B`@("`@("`@("`@("\J($]U='!U="!M;VYT
M:"!H96%D97(N("HO"B`@("`@("`@("`@(&EF("@D8W5R<F5N=%]M;VYT:"`A
M/2`D9&%Y+3YM;VYT:"D@>PH@("`@("`@("`@("`@("`@)&-U<G)E;G1?;6]N
M=&@@/2!S=')F=&EM92@G)6TG+"`D=&]D87E?<W1A;7`I.PH@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@)SQT<CX\=&0@8V]L<W!A;CTB-"(@8VQA<W,](F-O
M;G1R;VPB/CQS=')O;F<^)R`N('-T<F9T:6UE*"<E0B<L("1T;V1A>5]S=&%M
M<"D@+B`G/"]S=')O;F<^/"]T9#X\+W1R/B<["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1T;V1A>3$R86T@/2!M:W1I;64H,"P@,"P@,"P@)&1A>2T^
M;6]N=&@L("1D87DM/FUD87DL("1D87DM/GEE87(I.PH@("`@("`@("`@("`D
M=&]M;W)R;W<Q,F%M(#T@;6MT:6UE*#`L(#`L(#`L("1D87DM/FUO;G1H+"`D
M9&%Y+3YM9&%Y("L@,2P@)&1A>2T^>65A<BD["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1A;&QE=F5N='-;)'1O9&%Y7W-T86UP72!A<R`D979E;G0I('L*("`@
M("`@("`@("`@("`@(&EF("@A)&5V96YT+3YH87-296-U<E1Y<&4H2U)/3D],
M251(7U)%0U527TY/3D4I*2!["B`@("`@("`@("`@("`@("`@("`@)&5V96YT
M+3YS=&%R="`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G:&]U<B<@/3X@)&5V
M96YT+3YS=&%R="T^:&]U<BP@)VUI;B<@/3X@)&5V96YT+3YS=&%R="T^;6EN
M+"`G<V5C)R`]/B`D979E;G0M/G-T87)T+3YS96,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;6]N=&@G(#T^("1D87DM/FUO;G1H+"`G;61A>2<@/3X@)&1A>2T^;61A>2P@
M)WEE87(G(#T^("1D87DM/GEE87(I*3L*("`@("`@("`@("`@("`@("`@("`D
M979E;G0M/F5N9"`]("9N97<@2&]R9&5?1&%T92@D979E;G0M/G-T87)T+3YT
M:6UE<W1A;7`H*2`K("1E=F5N="T^9'5R36EN("H@-C`I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&5V96YT
M+3YS=&%R="T^=&EM97-T86UP*"D@/"`D=&]D87DQ,F%M*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1E=F5N="T^<W1A<G0@/2`F;F5W($AO<F1E7T1A
M=&4H)'1O9&%Y,3)A;2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D979E;G0M/F5N9"T^=&EM97-T86UP*"D@/CT@
M)'1O;6]R<F]W,3)A;2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D979E
M;G0M/F5N9"`]("9N97<@2&]R9&5?1&%T92@D=&]M;W)R;W<Q,F%M*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@:68@*"1E=F5N="T^96YD+3YT:6UE<W1A;7`H*2`\("1N;W<@
M?'P*("`@("`@("`@("`@("`@("`@("`H)'!R969S+3YG971686QU92@G<W5M
M;6%R>5]A;&%R;7,G*2`F)B`A)&5V96YT+3YA;&%R;2DI('L*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("!I9B`H)&9I<G-T979E;G0I('L*("`@("`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`G/'1R/CQT9"!C;&%S<STB=&5X="(@=F%L:6=N/2)T
M;W`B(&%L:6=N/2)R:6=H="(^/'-T<F]N9SXG.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D9&%Y+3YI<U1O9&%Y*"DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@7R@B5&]D87DB*3L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)&1A>2T^:7-4;VUO<G)O=R@I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X](%\H(E1O;6]R<F]W(BD["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@9&%T92@G:B<L("1T;V1A>5]S=&%M<"D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W-T
M<F]N9SXF;F)S<#L\+W1D/B<["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T
M979E;G0@/2!F86QS93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0@8VQA<W,](G1E>'0B
M/B9N8G-P.SPO=&0^)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`G/'1D(&-L87-S/2)T97AT(B!N;W=R87`](FYO=W)A
M<"(@=F%L:6=N/2)T;W`B/B<["B`@("`@("`@("`@("`@("!I9B`H)&5V96YT
M+3YS=&%R="T^=&EM97-T86UP*"D@/"`D;F]W("8F("1E=F5N="T^96YD+3YT
M:6UE<W1A;7`H*2`^("1N;W<I('L*("`@("`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`G/'-T<F]N9SXG("X@)&5V96YT+3YG971,;V-A=&EO;B@I("X@)SPO
M<W1R;VYG/B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1H=&UL("X]("1E=F5N="T^9V5T3&]C871I;VXH*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/"]T
M9#X\=&0@8VQA<W,](G1E>'0B/B9N8G-P.R9N8G-P.R9N8G-P.SPO=&0^)R`N
M"B`@("`@("`@("`@("`@("`@("`@)SQT9"!C;&%S<STB8FQO8VLM979E;G1B
M;W@@8V%T96=O<GDG("X@;60U*"1E=F5N="T^9V5T0V%T96=O<GDH*2D@+B`G
M(B!V86QI9VX](G1O<"(^)SL*"B`@("`@("`@("`@("`@("!I9B`H)&5V96YT
M+3YS=&%R="T^=&EM97-T86UP*"D@/"`D;F]W("8F("1E=F5N="T^96YD+3YT
M:6UE<W1A;7`H*2`^("1N;W<I('L*("`@("`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`G/'-T<F]N9SXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1E=F5N="T^979E;G1)1"DI('L*("`@("`@("`@
M("`@("`@("`@("`D:'1M;"`N/2`D979E;G0M/F=E=$QI;FLH;G5L;"P@=')U
M92D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&5V96YT+3YT
M87-K240I*2!["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z
M.FQI;FLH2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/FQI;FLH)W1A<VMS+W-H;W<G
M+"!A<G)A>2@G=&%S:R<@/3X@)&5V96YT+3YT87-K240L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&%S:VQI<W0G(#T^
M("1E=F5N="T^=&%S:VQI<W1)1"DI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92DL("1E=F5N="T^
M9V5T5&ET;&4H*2D@+B`D979E;G0M/F=E=%1I=&QE*"D@+B`G/"]A/B<["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1H
M=&UL("X]("1E=F5N="T^9V5T5&ET;&4H*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@D979E;G0M/G-T87)T+3YT:6UE<W1A;7`H
M*2`\("1N;W<@)B8@)&5V96YT+3YE;F0M/G1I;65S=&%M<"@I(#X@)&YO=RD@
M>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W-T<F]N9SXG.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SPO
M=&0^/"]T<CXG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H96UP='DH)&AT;6PI*2!["B`@("`@("`@("`@(')E='5R;B`G/&5M/B<@
M+B!?*").;R!E=F5N=',@=&\@9&ES<&QA>2(I("X@)SPO96T^)SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`G/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W
M:61T:#TB,3`P)2(^)R`N("1H=&UL("X@)SPO=&%B;&4^)SL*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]";&]C:R]T<F5E7V%L87)M
M<RYP:'`````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3,S-P`Q,#0Q-S,V,C<U
M,P`P,C,R-3$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B365N=2!!;&%R;7,B*3L*
M)&)L;V-K7W1Y<&4@/2`G=')E92<["@HO*BH*("H@)$AO<F1E.B!K<F]N;VQI
M=&@O;&EB+T)L;V-K+W1R965?86QA<FUS+G!H<"QV(#$N,2XR+C,@,C`P-B\P
M,2\Q,2`Q,SHP,#HR,R!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?
M0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7VMR;VYO;&ET:%]T<F5E7V%L
M87)M<R!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@/2`G
M:W)O;F]L:71H)SL*"B`@("!F=6YC=&EO;B!?8G5I;&14<F5E*"8D=')E92P@
M)&EN9&5N="`](#`L("1P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@($!D
M969I;F4H)TM23TY/3$E42%]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN+RXN)RD["B`@("`@("`@<F5Q=6ER95]O;F-E($M23TY/3$E42%]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PH*("`@("`@("`D;F]W(#T@=&EM92@I.PH@
M("`@("`@("1A;&%R;4-O=6YT(#T@,#L*("`@("`@("`D86QA<FUS(#T@2W)O
M;F]L:71H.CIL:7-T06QA<FUS*&YE=R!(;W)D95]$871E*"1N;W<I+"`D1TQ/
M0D%,4ULG9&ES<&QA>5]C86QE;F1A<G,G72D["B`@("`@("`@9F]R96%C:"`H
M)&%L87)M<R!A<R`D8V%L260@/3X@)&-A;$%L87)M<RD@>PH@("`@("`@("`@
M("`D1TQ/0D%,4ULG:W)O;F]L:71H)UTM/F]P96XH)&-A;$ED*3L*("`@("`@
M("`@("`@9F]R96%C:"`H)&-A;$%L87)M<R!A<R`D979E;G1)9"D@>PH@("`@
M("`@("`@("`@("`@)&5V96YT(#T@)B1'3$]"04Q36R=K<F]N;VQI=&@G72T^
M9V5T179E;G0H)&5V96YT260I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H
M)&5V96YT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@
M)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*"1E=F5N="D["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&5V96YT1&%T92`]("1E=F5N="T^;F5X=%)E8W5R<F5N
M8V4H)&YO=RD["B`@("`@("`@("`@("`@("!I9B`H)&5V96YT+3YH87-%>&-E
M<'1I;VXH)&5V96YT1&%T92T^>65A<BP@)&5V96YT1&%T92T^;6]N=&@L("1E
M=F5N=$1A=&4M/FUD87DI*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&%L87)M
M0V]U;G0K*SL*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A
M;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=V:65W979E;G0N<&AP)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=E=F5N=$E$)R`]/B`D979E;G1)9"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-A;&5N9&%R)R`]/B`D
M8V%L260I*3L*"B`@("`@("`@("`@("`@("`D=')E92T^861D3F]D92@D<&%R
M96YT("X@)&-A;$ED("X@)&5V96YT260L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5V96YT+3YG9714:71L92@I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN9&5N="`K(#$L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=I8V]N)R`]/B`G86QA<FTN<&YG)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N9&ER)R`]/B`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T:71L92<@/3X@)&5V96YT+3YG9714
M;V]L=&EP*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=7)L)R`]/B`D=7)L*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("@D<F5G:7-T<GDM/F=E="@G=7)L)RP@)'!A<F5N="DI('L*
M("`@("`@("`@("`@)'!U<FP@/2`D<F5G:7-T<GDM/F=E="@G=7)L)RP@)'!A
M<F5N="D["B`@("`@("`@?2!E;'-E:68@*"1R96=I<W1R>2T^9V5T*"=S=&%T
M=7,G+"`D<&%R96YT*2`]/2`G:&5A9&EN9R<@?'P*("`@("`@("`@("`@("`@
M("`@(21R96=I<W1R>2T^9V5T*"=W96)R;V]T)RDI('L*("`@("`@("`@("`@
M)'!U<FP@/2!N=6QL.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E=$EN:71I86Q086=E*"1P
M87)E;G0I*3L*("`@("`@("!]"B`@("`@("`@)'!N;V1E7W!A<F%M<R`](&%R
M<F%Y*"=U<FPG(#T^("1P=7)L+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:6-O;B<@/3X@)')E9VES=')Y+3YG970H)VEC;VXG+"`D<&%R96YT
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEC;VYD:7(G(#T^
M("<G*3L*("`@("`@("`D<&YO9&5?;F%M92`]("1R96=I<W1R>2T^9V5T*"=N
M86UE)RP@)'!A<F5N="D["B`@("`@("`@:68@*"1A;&%R;4-O=6YT*2!["B`@
M("`@("`@("`@("1P;F]D95]N86UE(#T@)SQS=')O;F<^)R`N("1P;F]D95]N
M86UE("X@)SPO<W1R;VYG/B<["B`@("`@("`@?0H*("`@("`@("`D=')E92T^
M861D3F]D92@D<&%R96YT+"`D<F5G:7-T<GDM/F=E="@G;65N=5]P87)E;G0G
M+"`D<&%R96YT*2P*("`@("`@("`@("`@("`@("`@("`@("`D<&YO9&5?;F%M
M92P@)&EN9&5N="P@9F%L<V4L("1P;F]D95]P87)A;7,I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K
M<F]N;VQI=&@O;&EB+T)L;V-K+W-U;6UA<GDN<&AP````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(P,C(T`#$P-#$W,S8R-S4S`#`R,C0T,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*)&)L
M;V-K7VYA;64@/2!?*")#86QE;F1A<B!3=6UM87)Y(BD["@HO*BH*("H@2&]R
M9&5?0FQO8VM?2W)O;F]L:71H7W-U;6UA<GDZ.B!);7!L96UE;G1A=&EO;B!O
M9B!T:&4@2&]R9&5?0FQO8VL@05!)('1O"B`J(&1I<W!L87D@82!S=6UM87)Y
M(&]F(&-A;&5N9&%R(&ET96US+@H@*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`L=B`Q+C0Q+C(N-B`R,#`V+S`Q+S`S(#(P
M.C4P.C$W(&-H=6-K($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L;V-K
M"B`J+PIC;&%S<R!(;W)D95]";&]C:U]+<F]N;VQI=&A?<W5M;6%R>2!E>'1E
M;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:W)O;F]L:71H
M)SL*"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("!`9&5F
M:6YE*"=+4D].3TQ)5$A?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B\N+B<I.PH@("`@("`@(')E<75I<F5?;VYC92!+4D].3TQ)5$A?0D%312`N
M("<O;&EB+V)A<V4N<&AP)SL*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=C
M86QE;F1A<B<@/3X@87)R87DH)VYA;64G(#T^(%\H(D-A;&5N9&%R(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&5F875L="<@/3X@)U]?86QL)RDI.PH@("`@("`@
M("1P87)A;7-;)V-A;&5N9&%R)UU;)W9A;'5E<R==6R=?7V%L;"==(#T@7R@B
M06QL(%9I<VEB;&4B*3L*("`@("`@("!F;W)E86-H("A+<F]N;VQI=&@Z.FQI
M<W1#86QE;F1A<G,H*2!A<R`D:60@/3X@)&-A;"D@>PH@("`@("`@("`@("`D
M<&%R86US6R=C86QE;F1A<B==6R=V86QU97,G75LD:61=(#T@)&-A;"T^9V5T
M*"=N86UE)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<F%M<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I;B!T:&ES
M(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE('1I
M=&QE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("!R971U<FX@2&]R
M9&4Z.FQI;FLH2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E=$EN:71I86Q086=E
M*"DL('1R=64I*2`N("1R96=I<W1R>2T^9V5T*"=N86UE)RD@+B`G/"]A/B`\
M<VUA;&P^)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G
M861D979E;G0N<&AP)RP@=')U92DI("X@2&]R9&4Z.FEM9R@G;F5W+G!N9R<L
M(%\H(DYE=R!%=F5N="(I*2`N("<@)R`N(%\H(DYE=R!%=F5N="(I("X@)SPO
M83X\+W-M86QL/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N
M="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O
M;G1E;G0H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1P<F5F
M<SL*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN+V)A<V4N<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@2U)/3D],251(
M7T)!4T4@+B`G+VQI8B]$87DN<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`G.PH*("`@("`@("!(
M;W)D93HZ861D4V-R:7!T1FEL92@G=&]O;'1I<"YJ<R<L("=H;W)D92<L('1R
M=64I.PH*("`@("`@("`D;F]W(#T@=&EM92@I.PH@("`@("`@("1T;V1A>2`]
M(&1A=&4H)VHG*3L*"B`@("`@("`@)'-T87)T1&%T92`]("9N97<@2&]R9&5?
M1&%T92AA<G)A>2@G>65A<B<@/3X@9&%T92@G62<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUO;G1H)R`]/B!D871E
M*"=N)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;61A>2<@/3X@9&%T92@G:B<I*2D["B`@("`@("`@)&5N9$1A=&4@
M/2`F;F5W($AO<F1E7T1A=&4H87)R87DH)WEE87(G(#T^(&1A=&4H)UDG*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6]N
M=&@G(#T^(&1A=&4H)VXG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;61A>2<@/3X@9&%T92@G:B<I("L@)'!R969S+3YG
M971686QU92@G<W5M;6%R>5]D87ES)RDI*3L*("`@("`@("`D96YD1&%T92T^
M8V]R<F5C="@I.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;
M)V-A;&5N9&%R)UTI("8F"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=C
M86QE;F1A<B==("$]("=?7V%L;"<I('L*("`@("`@("`@("`@)&%L;&5V96YT
M<R`]($MR;VYO;&ET:#HZ;&ES=$5V96YT<R@D<W1A<G1$871E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;F1$
M871E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=C86QE;F1A<B==*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%L;&5V96YT<R`]($MR;VYO
M;&ET:#HZ;&ES=$5V96YT<R@D<W1A<G1$871E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;F1$871E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1'
M3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R<R==*3L*("`@("`@("!]"@H@("`@
M("`@("1H=&UL(#T@)R<["B`@("`@("`@)&E-87@@/2`D=&]D87D@*R`D<')E
M9G,M/F=E=%9A;'5E*"=S=6UM87)Y7V1A>7,G*3L*("`@("`@("`D9FER<W1D
M87D@/2!T<G5E.PH@("`@("`@(&9O<B`H)&D@/2`D=&]D87D[("1I(#P@)'1O
M9&%Y("L@)&E-87@[("1I*RLI('L*("`@("`@("`@("`@)&1A>2`]("9N97<@
M2W)O;F]L:71H7T1A>2AD871E*"=N)RDL("1I*3L*("`@("`@("`@("`@:68@
M*&5M<'1Y*"1A;&QE=F5N='-;)&1A>2T^9V5T4W1A;7`H*5TI*2!["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&5V96YT<R`]("8D86QL979E;G1S6R1D87DM/F=E=%-T86UP*"E=.PH@
M("`@("`@("`@("`D9FER<W1E=F5N="`]('1R=64["@H@("`@("`@("`@("`D
M=&]D87DQ,F%M(#T@;6MT:6UE*#`L(#`L(#`L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A>2T^;6]N=&@L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A>2T^;61A>2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%Y+3YY96%R*3L*("`@("`@("`@("`@)'1O;6]R
M<F]W,3)A;2`](&UK=&EM92@P+"`P+"`P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D87DM/FUO;G1H+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D87DM/FUD87D@*R`Q+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D87DM/GEE87(I.PH@("`@("`@
M("`@("!F;W)E86-H("@D979E;G1S(&%S("1E=F5N="D@>PH@("`@("`@("`@
M("`@("`@:68@*"$D979E;G0M/FAA<U)E8W5R5'EP92A+4D].3TQ)5$A?4D5#
M55)?3D].12DI('L*("`@("`@("`@("`@("`@("`@("`D979E;G0M/G-T87)T
M(#T@)FYE=R!(;W)D95]$871E*`H@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G:&]U<B<@/3X@)&5V96YT+3YS=&%R="T^:&]U<BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VUI;B<@/3X@)&5V96YT+3YS=&%R="T^
M;6EN+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V5C)R`]/B`D
M979E;G0M/G-T87)T+3YS96,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=M;VYT:"<@/3X@)&1A>2T^;6]N=&@L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=M9&%Y)R`]/B`D9&%Y+3YM9&%Y+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G>65A<B<@/3X@)&1A>2T^>65A<BDI.PH@
M("`@("`@("`@("`@("`@("`@("1E=F5N="T^96YD(#T@)FYE=R!(;W)D95]$
M871E*"1E=F5N="T^<W1A<G0M/G1I;65S=&%M<"@I("L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H)&5V96YT
M+3YD=7)-:6X@*B`V,"DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&5V96YT+3YS=&%R="T^=&EM97-T86UP
M*"D@/"`D=&]D87DQ,F%M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1E
M=F5N="T^<W1A<G0@/2`F;F5W($AO<F1E7T1A=&4H)'1O9&%Y,3)A;2D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M979E;G0M/F5N9"T^=&EM97-T86UP*"D@/CT@)'1O;6]R<F]W,3)A;2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D979E;G0M/F5N9"`]("9N97<@2&]R
M9&5?1&%T92@D=&]M;W)R;W<Q,F%M*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&5V96YT
M+3YE;F0M/G1I;65S=&%M<"@I(#P@)&YO=RD@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("!I9B`H)'!R969S+3YG971686QU92@G<W5M;6%R>5]A;&%R;7,G
M*2`F)B`A)&5V96YT+3YA;&%R;2D@8V]N=&EN=64["B`@("`@("`@("`@("`@
M("!I9B`H)&9I<G-T979E;G0I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M(21F:7)S=&1A>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`G/'1R/CQT9"!C;VQS<&%N/2(S(B!S='EL93TB9F]N="US:7IE.C)P>#LB
M/B9N8G-P.SPO=&0^/"]T<CXG.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1R/CQT9"!C;VQS<&%N/2(S
M(B!C;&%S<STB8V]N=')O;"(^/'-T<F]N9SXG.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D9&%Y+3YI<U1O9&%Y*"DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A>6YA;64@/2!?*")4;V1A>2(I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("@D9&%Y+3YI<U1O;6]R<F]W*"DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A>6YA;64@/2!?*")4;VUO<G)O=R(I.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D9&%Y+3YD:69F*"D@/"`W*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D87EN86UE(#T@<W1R9G1I;64H
M)R5!)RP@)&1A>2T^9V5T4W1A;7`H*2D["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A>6YA;64@/2!S
M=')F=&EM92@D<')E9G,M/F=E=%9A;'5E*"=D871E7V9O<FUA="<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D87DM
M/F=E=%-T86UP*"DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D9&%Y;&EN:R`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G
M9&%Y+G!H<"<I.PH@("`@("`@("`@("`@("`@("`@("1D87EL:6YK(#T@571I
M;#HZ861D4&%R86UE=&5R*"1D87EL:6YK+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T:6UE<W1A;7`G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D87DM/F=E=%-T86UP*"DI.PH@("`@("`@("`@("`@("`@("`@("1H
M=&UL("X]($AO<F1E.CIL:6YK*"1D87EL:6YK+"!S<')I;G1F*%\H(D=O=&\@
M)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&%Y;F%M92DI.PH@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("1D87EN86UE("X@)SPO83X\+W-T<F]N9SX\+W1D
M/CPO='(^)SL*("`@("`@("`@("`@("`@("`@("`D9FER<W1E=F5N="`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@("`@("1F:7)S=&1A>2`](&9A;'-E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT
M<CX\=&0@8VQA<W,](G1E>'0B(&YO=W)A<#TB;F]W<F%P(B!V86QI9VX](G1O
M<"(^)SL*("`@("`@("`@("`@("`@(&EF("@D979E;G0M/G-T87)T+3YT:6UE
M<W1A;7`H*2`\("1N;W<@)B8*("`@("`@("`@("`@("`@("`@("`D979E;G0M
M/F5N9"T^=&EM97-T86UP*"D@/B`D;F]W*2!["B`@("`@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@)SQS=')O;F<^)SL*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("!I9B`H)&5V96YT+3YS=&%R="T^:&]U<B`A/2`P('Q\
M"B`@("`@("`@("`@("`@("`@("`@)&5V96YT+3YS=&%R="T^;6EN("$](#`@
M?'P*("`@("`@("`@("`@("`@("`@("`H*"1E=F5N="T^96YD+3YT:6UE<W1A
M;7`H*2`M("1E=F5N="T^<W1A<G0M/G1I;65S=&%M<"@I*2`E"B`@("`@("`@
M("`@("`@("`@("`@("@R-"`J(#8P("H@-C`I*2`A/2`P*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&EM92`](&1A=&4H)T<Z
M:2<L("1E=F5N="T^<W1A<G0M/G1I;65S=&%M<"@I*2`N("<M)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!D871E*"='.FDG+"`D979E;G0M/F5N
M9"T^=&EM97-T86UP*"DI.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:6UE(#T@9&%T92@G9SII($$G
M+"`D979E;G0M/G-T87)T+3YT:6UE<W1A;7`H*2D@+B`G+2<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9&%T92@G9SII($$G+"`D979E;G0M/F5N
M9"T^=&EM97-T86UP*"DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1I;64@
M/2!?*")!;&P@9&%Y(&5V96YT(BD["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@)'1E>'0@/2`D979E;G0M/F=E=%1I=&QE*"D["B`@("`@
M("`@("`@("`@("!I9B`H)&QO8V%T:6]N(#T@)&5V96YT+3YG971,;V-A=&EO
M;B@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@)R`H)R`N("1L
M;V-A=&EO;B`N("<I)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1H=&UL("X]("1T:6UE.PH@("`@("`@("`@("`@("`@:68@*"1E=F5N
M="T^<W1A<G0M/G1I;65S=&%M<"@I(#P@)&YO=R`F)@H@("`@("`@("`@("`@
M("`@("`@("1E=F5N="T^96YD+3YT:6UE<W1A;7`H*2`^("1N;W<I('L*("`@
M("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/"]S=')O;F<^)SL*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/"]T9#X\
M=&0@8VQA<W,](G1E>'0B/B9N8G-P.R9N8G-P.R9N8G-P.SPO=&0^)R`N"B`@
M("`@("`@("`@("`@("`@("`@)SQT9"!C;&%S<STB8FQO8VLM979E;G1B;W@@
M8V%T96=O<GDG("X@;60U*"1E=F5N="T^9V5T0V%T96=O<GDH*2D@+B`G(B!V
M86QI9VX](G1O<"(^)SL*"B`@("`@("`@("`@("`@("!I9B`H)&5V96YT+3YS
M=&%R="T^=&EM97-T86UP*"D@/"`D;F]W("8F"B`@("`@("`@("`@("`@("`@
M("`@)&5V96YT+3YE;F0M/G1I;65S=&%M<"@I(#X@)&YO=RD@>PH@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\<W1R;VYG/B<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D979E;G0M/F=E=$QI
M;FLH;G5L;"P@=')U92D["B`@("`@("`@("`@("`@("!I9B`H)&5V96YT+3YS
M=&%R="T^=&EM97-T86UP*"D@/"`D;F]W("8F"B`@("`@("`@("`@("`@("`@
M("`@)&5V96YT+3YE;F0M/G1I;65S=&%M<"@I(#X@)&YO=RD@>PH@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\+W-T<F]N9SXG.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SPO=&0^/"]T<CXG
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH
M)&AT;6PI*2!["B`@("`@("`@("`@(')E='5R;B`G/&5M/B<@+B!?*").;R!E
M=F5N=',@=&\@9&ES<&QA>2(I("X@)SPO96T^)SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`G/&QI;FL@:')E9CTB)R`N($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G=&AE;65S+V-A=&5G;W)Y0U-3+G!H<"<I("X@)R(@<F5L/2)S='EL
M97-H965T(B!T>7!E/2)T97AT+V-S<R(@+SX\=&%B;&4@8V5L;'-P86-I;F<]
M(C`B('=I9'1H/2(Q,#`E(CXG("X@)&AT;6P@+B`G/"]T86)L93XG.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O
M;&EB+T)L;V-K+W1R965?;65N=2YP:'``````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-S<W`#$P-#$W,S8R-S4S`#`R,C<T,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*)&)L;V-K7VYA;64@
M/2!?*")-96YU($QI<W0B*3L*)&)L;V-K7W1Y<&4@/2`G=')E92<["@HO*BH*
M("H@)$AO<F1E.B!K<F]N;VQI=&@O;&EB+T)L;V-K+W1R965?;65N=2YP:'`L
M=B`Q+C$P+C@N,2`R,#`U+S$P+S$X(#$R.C(W.C,Q(&IA;B!%>'`@)`H@*@H@
M*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?
M:W)O;F]L:71H7W1R965?;65N=2!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@
M("!V87(@)%]A<'`@/2`G:W)O;F]L:71H)SL*"B`@("!F=6YC=&EO;B!?8G5I
M;&14<F5E*"8D=')E92P@)&EN9&5N="`](#`L("1P87)E;G0@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1M96YU
M<R`](&%R<F%Y*`H@("`@("`@("`@("!A<G)A>2@G;F5W)RP@7R@B3F5W($5V
M96YT(BDL("=N97<N<&YG)RP@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&1E
M=F5N="YP:'`G*2DL"B`@("`@("`@("`@(&%R<F%Y*"=D87DG+"!?*")$87DB
M*2P@)V1A>79I97<N<&YG)RP@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=D87DN
M<&AP)RDI+`H@("`@("`@("`@("!A<G)A>2@G=V]R:R<L(%\H(E=O<FL@5V5E
M:R(I+"`G=V]R:W=E96MV:65W+G!N9R<L($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G=V]R:W=E96LN<&AP)RDI+`H@("`@("`@("`@("!A<G)A>2@G=V5E:R<L
M(%\H(E=E96LB*2P@)W=E96MV:65W+G!N9R<L($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G=V5E:RYP:'`G*2DL"B`@("`@("`@("`@(&%R<F%Y*"=M;VYT:"<L
M(%\H(DUO;G1H(BDL("=M;VYT:'9I97<N<&YG)RP@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=M;VYT:"YP:'`G*2DL"B`@("`@("`@("`@(&%R<F%Y*"=Y96%R
M)RP@7R@B665A<B(I+"`G>65A<G9I97<N<&YG)RP@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=Y96%R+G!H<"<I*2P*("`@("`@("`@("`@87)R87DH)W-E87)C
M:"<L(%\H(E-E87)C:"(I+"`G<V5A<F-H+G!N9R<L($AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@G<V5A<F-H+G!H<"<I+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*2P*("`@("`@("`I.PH*("`@("`@("!F;W)E86-H("@D;65N
M=7,@87,@)&UE;G4I('L*("`@("`@("`@("`@)'1R964M/F%D9$YO9&4H)'!A
M<F5N="`N("1M96YU6S!=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%R96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D;65N=5LQ72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9&5N="`K(#$L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G:6-O;B<@/3X@)&UE;G5;,ETL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N9&ER)R`]/B!I<W-E="@D
M;65N=5LT72D@/R`D;65N=5LT72`Z("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@
M)&UE;G5;,UTI*3L*("`@("`@("!]"B`@("!]"@I]"@`N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L:6(O4W1O<F%G92\`````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`
M,#(P-C`W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]3
M=&]R86=E+VMO;&%B+G!H<```````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,S8R-@`Q,#0Q-S,V,C<U,P`P,C(T,30`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R
M9&4O:4-A;&5N9&%R+G!H<"<["@HO*BH*("H@2&]R9&4@2W)O;F]L:71H(&9R
M964O8G5S>2!D<FEV97(@9F]R('1H92!+;VQA8B!)34%0(%-E<G9E<BX*("H@
M0V]P>7)I9VAT(#(P,#0M,C`P-B!(;W)D92!0<F]J96-T("AH='1P.B\O:&]R
M9&4N;W)G+RD*("H*("H@)$AO<F1E.B!K<F]N;VQI=&@O;&EB+U-T;W)A9V4O
M:V]L86(N<&AP+'8@,2XT+C$P+C4@,C`P-B\P,B\P."`Q,CHR-SHU.2!J86X@
M17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=2!D:60*("H@;F]T
M(')E8V5I=F4@<W5C:"!A(&9I;&4L('-E92!A;'-O(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4W1U87)T
M($)I;F=E(#QO;6EC<F]N0&UI9VAT>2YC;RYZ83X*("H@0'!A8VMA9V4@2W)O
M;F]L:71H"B`J+PIC;&%S<R!+<F]N;VQI=&A?4W1O<F%G95]K;VQA8B!E>'1E
M;F1S($MR;VYO;&ET:%]3=&]R86=E('L*"B`@("!V87(@)%]P87)A;7,@/2!A
M<G)A>2@I.PH*("`@(&9U;F-T:6]N($MR;VYO;&ET:%]3=&]R86=E7VMO;&%B
M*"1U<V5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI
M<RT^7W5S97(@/2`D=7-E<CL*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P
M87)A;7,["B`@("!]"@H@("`@9G5N8W1I;VX@<V5A<F-H*"1E;6%I;"P@)'!R
M:79A=&5?;VYL>2`](&9A;'-E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@)&9B7W5R;"`]('-P<FEN=&8H)R5S.B\O)7,Z)60O9G)E
M96)U<WDO)7,N=F9B)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N
M9ELG<W1O<F%G92==6R=F<F5E8G5S>2==6R=P<F]T;V-O;"==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W-E
M<G9E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF6R=S=&]R
M86=E)UU;)V9R965B=7-Y)UU;)W!O<G0G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`D96UA:6PI.PH*("`@("`@("`D=F9B7W1E>'0@/2!F:6QE7V=E
M=%]C;VYT96YT<R@D9F)?=7)L*3L*("`@("`@("!I9B`H)'9F8E]T97AT(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E5N86)L92!T;R!R971R:65V92!F<F5E+V)U<WD@:6YF
M;W)M871I;VX@9F]R("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E;6%I;"DL($M23TY/3$E42%]%4E)/4E]&0E].3U1?1D]5
M3D0I.PH@("`@("`@('T*"B`@("`@("`@)&E#86P@/2!N97<@2&]R9&5?:4-A
M;&5N9&%R.PH@("`@("`@("1I0V%L+3YP87)S979#86QE;F1A<B@D=F9B7W1E
M>'0I.PH*("`@("`@("`D=F9B(#T@)B1I0V%L+3YF:6YD0V]M<&]N96YT*"=6
M1E)%14)54UDG*3L*("`@("`@("!I9B`H)'9F8B`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*").
M;R!F<F5E+V)U<WD@:6YF;W)M871I;VX@:7,@879A:6QA8FQE(&9O<B`E<R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96UA:6PI
M+"!+4D].3TQ)5$A?15)23U)?1D)?3D]47T9/54Y$*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=F9B.PH@("`@?0H*("`@(&9U;F-T:6]N('-T;W)E
M*"1E;6%I;"P@)'9F8BP@)'!U8FQI8R`](&9A;'-E*0H@("`@>PH@("`@("`@
M("\O(%=E(&1O;B=T(&-A<F4@86)O=70@<W1O<FEN9R!&0B!I;F9O(&%T('1H
M92!M;VUE;G0[('=E(')A=&AE<B!L970*("`@("`@("`O+R!+;VQA8B=S(&9R
M965B=7-Y+G!H<"!S8W)I<'0@875T;RUG96YE<F%T92!I="!F;W(@=7,N"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L:6(O4W1O<F%G
M92]S<6PN<&AP````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,W,3$`
M,3`T,3<S-C(W-3,`,#(R,3$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!+<F]N;VQI=&A?4W1O<F%G
M93HZ(&1E9FEN97,@86X@05!)(&9O<B!S=&]R:6YG(&9R964O8G5S>0H@*B!I
M;F9O<FUA=&EO;BX*("H*("H@)$AO<F1E.B!K<F]N;VQI=&@O;&EB+U-T;W)A
M9V4O<W%L+G!H<"QV(#$N-RXQ,"XU(#(P,#8O,#$O,3@@,3DZ-#8Z-3,@8F5N
M($5X<"`D"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($!P86-K86=E($MR;VYO;&ET:`H@*B\*8VQA
M<W,@2W)O;F]L:71H7U-T;W)A9V5?<W%L(&5X=&5N9',@2W)O;F]L:71H7U-T
M;W)A9V4@>PH*("`@("\J*B!0;VEN=&5R('1O('1H92!S<6P@8V]N;F5C=&EO
M;BX@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*B!";V]L96%N('=H:6-H(&-O
M;G1A:6YS('-T871E(&]F('-Q;"!C;VYN96-T:6]N("HO"B`@("!V87(@)%]C
M;VYN96-T960@/2!F86QS93L*"B`@("`O*BH@2&%S:"!C;VYT86EN:6YG(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W('-Q;"!0
M87-S=V1?1')I=F5R(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@("1P87)A;7,@("`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P
M87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!+<F]N;VQI=&A?4W1O
M<F%G95]S<6PH)'5S97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?=7-E<B`]("1U<V5R.PH*("`@("`@("`O*B!5<V4@9&5F
M875L=',@=VAE<F4@;F5E9&5D+B`J+PH@("`@("`@("1T:&ES+3Y?<&%R86US
M(#T@)'!A<F%M<SL*("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`]
M(&ES<V5T*"1P87)A;7-;)W1A8FQE)UTI(#\@)'!A<F%M<ULG=&%B;&4G72`Z
M("=K<F]N;VQI=&A?<W1O<F%G92<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYN96-T('1O('1H92!D871A8F%S90H@("`@("H*("`@("`J($!R971U<FX@
M("!B;V]L96%N("`@5')U92!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@(&EF("@A)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@
M("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@
M)W-T;W)A9V4G+`H@("`@("`@("`@("`@("`@87)R87DH)W!H<'1Y<&4G*2P*
M("`@("`@("`@("`@("`@("=K<F]N;VQI=&@@<W1O<F%G92!344PG*3L*"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E
M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&%T86)A
M<V4G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;
M)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG:&]S='-P96,G72`]("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S=7!P
M;&EE9`H@("`@("`@("`@("`O+R!P87)A;65T97)S+@H@("`@("`@("`@("!I
M;F-L=61E7V]N8V4@)T1"+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?9&(@
M/2`F1$(Z.F-O;FYE8W0H)'1H:7,M/E]P87)A;7,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!E<G-I<W1E;G0G(#T^
M("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==*2DI.PH@("`@
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5
M;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(I*3L*("`@("`@("`@
M("`@?0H*"B`@("`@("`@("`@("\O(%-E="!$0B!P;W)T86)I;&ET>2!O<'1I
M;VYS+@H@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/G!H<'1Y<&4I
M('L*("`@("`@("`@("`@8V%S92`G;7-S<6PG.@H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!
M0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24R!\($1"
M7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/
M5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24RD["B`@("`@("`@("`@
M('T*"@H@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@4U%,('-E<G9E<B!A;F0@8VQE
M86X@=7`@=&AE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E87)C:"!F;W(@82!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("1E;6%I;"`@("`@("`@5&AE(&5M86EL(&%D9')E<W,@=&\@
M;&]O:W5P"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<')I=F%T95]O;FQY("AO
M<'1I;VYA;"D@3VYL>2!R971U<FX@9G)E92]B=7-Y"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N(&]W;F5D(&)Y('1H
M:7,@=7-E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@("`@("`@
M("`@("`@($AO<F1E7VE#86QE;F1A<E]V1G)E96)U<WD@;VX@<W5C8V5S<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T5R<F]R
M(&]N(&5R<F]R(&]R(&YO="!F;W5N9`H@("`@("HO"B`@("!F=6YC=&EO;B!S
M96%R8V@H)&5M86EL+"`D<')I=F%T95]O;FQY(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@+R\@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`@("`@("`@)')E
M<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@
M("`@("`@?0H*("`@("`@("`O+R!"=6EL9"!T:&4@4U%,('%U97)Y+@H@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!V9F)?<V5R:6%L:7IE9"!&
M4D]-("5S(%=(15)%('9F8E]E;6%I;#T_($%.1"`H=F9B7V]W;F5R/3\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTI.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D96UA:6PL("1T:&ES+3Y?
M=7-E<BD["@H@("`@("`@(&EF("@D<')I=F%T95]O;FQY*2!["B`@("`@("`@
M("`@("1Q=65R>2`N/2`G*2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'%U97)Y("X]("(@3U(@=F9B7V]W;F5R/2<G*2(["B`@("`@("`@?0H*
M("`@("`@("`O+R!,;V<@=&AE('%U97)Y(&%T(&1E8G5G(&QE=F5L+@H@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!S96%R8V@@8GD@
M)7,Z('%U97)Y(#T@(B5S(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!!=71H.CIG971!=71H*"DL("1Q=65R>2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["@H@("`@("`@("\O($5X96-U=&4@=&AE('%U97)Y+@H@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I
M.PH@("`@("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]'151-
M3T1%7T%34T]#*3L*("`@("`@("`@("`@)')E<W5L="T^9G)E92@I.PH@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)')O=RDI('L*("`@("`@("`@("`@("`@
M("\O(%)E=')I979E($9R965B=7-Y(&]B:F5C="X@(%1/1$\Z(&-H96-K(&9O
M<B!M=6QT:7!L90H@("`@("`@("`@("`@("`@+R\@<F5S=6QT<R!A;F0@;65R
M9V4@=&AE;2!I;G1O(&]N92!A;F0@<F5T=7)N+@H@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]397)I86QI>F4N<&AP)SL*("`@("`@("`@
M("`@("`@("1V9F(@/2!(;W)D95]397)I86QI>F4Z.G5N<V5R:6%L:7IE*"1R
M;W=;)W9F8E]S97)I86QI>F5D)UTL(%-%4DE!3$E:15]"05-)0RD["B`@("`@
M("`@("`@("`@("!R971U<FX@)'9F8CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@9F]U
M;F0B*2P@2U)/3D],251(7T524D]27T9"7TY/5%]&3U5.1"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3=&]R92!T:&4@9G)E96)U<WD@:6YF;W)M871I;VX@
M9F]R(&$@9VEV96X@96UA:6P@861D<F5S<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@)&5M86EL("`@("`@("!4
M:&4@96UA:6P@861D<F5S<R!T;R!S=&]R92!F8B!I;F9O(&9O<BX*("`@("`J
M($!P87)A;2!(;W)D95]I0V%L96YD87)?=D9R965B=7-Y("`D=F9B("`@("`@
M("`@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("`@("`@("`@("`@("`@
M("`@("`D<')I=F%T95]O;FQY("AO<'1I;VYA;"D@5$]$3PH@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@("`@("`@("`@("`@5')U92!O;B!S=6-C
M97-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?
M17)R;W(@;VX@97)R;W(@;W(@;F]T(&9O=6YD"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-T;W)E*"1E;6%I;"P@)'9F8BP@)'!U8FQI8R`](&9A;'-E*0H@("`@
M>PH@("`@("`@("\O($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@("`@("`@
M("1R97,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@("`@('T*"B`@("`@("`@)&]W;F5R(#T@*"$D<'5B;&EC*2`_("1T
M:&ES+3Y?=7-E<B`Z("<G.PH*("`@("`@("`O+R!"=6EL9"!T:&4@4U%,('%U
M97)Y+@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5R:6%L:7IE+G!H
M<"<["B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G24Y315)4($E.5$\@)7,@
M*'9F8E]O=VYE<BP@=F9B7V5M86EL+"!V9F)?<V5R:6%L:7IE9"D@5D%,5453
M("@_+"`_+"`_*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1O
M=VYE<BP@)&5M86EL+"!(;W)D95]397)I86QI>F4Z.G-E<FEA;&EZ92@D=F9B
M+"!315))04Q)6D5?0D%324,I*3L*"B`@("`@("`@+R\@3&]G('1H92!Q=65R
M>2!A="!D96)U9R!L979E;"X*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS
M<')I;G1F*"=344P@:6YS97)T(&)Y("5S.B!Q=65R>2`]("(E<R(G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@075T:#HZ9V5T075T:"@I
M+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O+R!%>&5C
M=71E('1H92!Q=65R>2X*("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^<75E
M<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@('T*"GT*````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]$<FEV97(N<&AP
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(Q-S0U,0`Q,#0Q
M-S,V,C<U,P`P,C$Q-38`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($MR;VYO;&ET:%]$<FEV97(Z.B!D
M969I;F5S(&%N($%022!F;W(@:6UP;&5M96YT:6YG('-T;W)A9V4@8F%C:V5N
M9',*("H@9F]R($MR;VYO;&ET:"X*("H*("H@)$AO<F1E.B!K<F]N;VQI=&@O
M;&EB+T1R:79E<BYP:'`L=B`Q+C$Q-BXR+C,X(#(P,#8O,#,O,#$@,3DZ,S$Z
M-#(@8VAU8VL@17AP("0*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($MR;VYO;&ET:"`P+C$*
M("H@0'!A8VMA9V4@2W)O;F]L:71H"B`J+PIC;&%S<R!+<F]N;VQI=&A?1')I
M=F5R('L*"B`@("`O*BH*("`@("`J($$@:&%S:"!C;VYT86EN:6YG(&%N>2!P
M87)A;65T97)S(&9O<B!T:&4@8W5R<F5N="!D<FEV97(N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@8V%L96YD87(N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8V%L
M96YD87(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<B`M(&IU<W0@<W1O
M<F4@=&AE("1P87)A;7,@:6X@;W5R(&YE=VQY+6-R96%T960*("`@("`J(&]B
M:F5C="X@06QL(&]T:&5R('=O<FL@:7,@9&]N92!B>2!O<&5N*"DN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S
M(&YE961E9"!F;W(@=&AI<R!D<FEV97(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($MR;VYO;&ET:%]$<FEV97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H92!C=7)R96YT;'D@;W!E;B!C86QE;F1A<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-U<G)E;G0@8V%L96YD
M87(@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V%L96YD87(H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-A;&5N9&%R.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5N97)A=&4@82!U;FEV97)S86P@+R!U;FEQ=64@
M:61E;G1I9FEE<B!F;W(@82!T87-K+B!4:&ES(&ES"B`@("`@*B!.3U0@<V]M
M971H:6YG('1H870@=V4@97AP96-T('1O(&)E(&%B;&4@=&\@<&%R<V4@:6YT
M;R!A"B`@("`@*B!T87-K;&ES="!A;F0@82!T87-K260N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@($$@;FEC92!U;FEQ=64@<W1R:6YG("AS:&]U
M;&0@8F4@,C4U(&-H87)S(&]R(&QE<W,I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G96YE<F%T955)1"@I"B`@("!["B`@("`@("`@<F5T=7)N(&1A=&4H)UEM
M9$AI<R<I("X@)RXG("X*("`@("`@("`@("`@<W5B<W1R*&)A<V5?8V]N=F5R
M="AM:6-R;W1I;64H*2P@,3`L(#,V*2P@+3$V*2`N"B`@("`@("`@("`@("=`
M)R`N("1'3$]"04Q36R=C;VYF)UU;)W-E<G9E<B==6R=N86UE)UT["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296YA;64@82!C86QE;F1A<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F<F]M("!4:&4@8W5R<F5N="!N86UE(&]F
M('1H92!C86QE;F1A<BX*("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@(%1H
M92!N97<@;F%M92!O9B!T:&4@8V%L96YD87(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE*"1F<F]M+"`D=&\I"B`@("![
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M96%R8V@@82!C86QE;F1A<BX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T
M($MR;VYO;&ET:%]%=F5N="`D<75E<GD@($$@2W)O;F]L:71H7T5V96YT(&]B
M:F5C="!W:71H('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C<FET97)I82!T;R!S96%R8V@@9F]R+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($%N(&%R<F%Y(&]F($MR;VYO;&ET:%]%
M=F5N=',@;W(@82!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M96%R8V@H)'%U97)Y*0H@("`@>PH@("`@("`@("\J($]U<B!D969A=6QT(&EM
M<&QE;65N=&%T:6]N(&9I<G-T(&=E=',@/&5M/F%L;#PO96T^(&5V96YT<R!I
M;@H@("`@("`@("`J(&$@<W!E8VEF:6,@<&5R:6]D+"!A;F0@=&AE;B!F:6QT
M97)S(&)A<V5D(&]N('1H92!A8W1U86P*("`@("`@("`@*B!V86QU97,@=&AA
M="!A<F4@9FEL;&5D(&EN+B!$<FEV97)S(&-A;B!O<'1I;6EZ92!T:&ES"B`@
M("`@("`@("H@8F5H879I;W(@:68@=&AE>2!H879E('1H92!A8FEL:71Y+B`J
M+PH@("`@("`@("1R97-U;'1S(#T@87)R87DH*3L*"B`@("`@("`@)&5V96YT
M<R`]("8D=&AI<RT^;&ES=$5V96YT<R@D<75E<GDM/G-T87)T+"`D<75E<GDM
M/F5N9"D["B`@("`@("`@:68@*&ES7V$H)&5V96YT<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5V96YT<SL*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<W-E="@D<75E<GDM/G-T87)T*2D@>PH@("`@("`@("`@
M("`D<W1A<G14:6UE(#T@)'%U97)Y+3YS=&%R="T^=&EM97-T86UP*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T87)T5&EM92`](&YU;&P[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'%U97)Y+3YE;F0I*2![
M"B`@("`@("`@("`@("1E;F14:6UE(#T@)'%U97)Y+3YE;F0M/G1I;65S=&%M
M<"@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E;F14:6UE(#T@
M;G5L;#L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1E=F5N=',@87,@
M)&5V96YT:60I('L*("`@("`@("`@("`@)&5V96YT(#T@)B1T:&ES+3YG971%
M=F5N="@D979E;G1I9"D["B`@("`@("`@("`@(&EF("AI<U]A*"1E=F5N="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1E=F5N
M=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&5V4W1A<G14:6UE(#T@
M)&5V96YT+3YS=&%R="T^=&EM97-T86UP*"D["B`@("`@("`@("`@("1E=D5N
M9%1I;64@/2`D979E;G0M/F5N9"T^=&EM97-T86UP*"D["@H@("`@("`@("`@
M("!I9B`H*"@H)&5V16YD5&EM92`^("1S=&%R=%1I;64@?'P@(6ES<V5T*"1S
M=&%R=%1I;64I*2`F)@H@("`@("`@("`@("`@("`@("`H)&5V4W1A<G14:6UE
M(#P@)&5N9%1I;64@?'P@(6ES<V5T*"1E;F14:6UE*2DI('Q\"B`@("`@("`@
M("`@("`@("`@*"1E=F5N="T^9V5T4F5C=7)4>7!E*"D@(3T@2U)/3D],251(
M7U)%0U527TY/3D4@)B8@)&5V16YD5&EM92`^/2`D<W1A<G14:6UE("8F("1E
M=E-T87)T5&EM92`\/2`D96YD5&EM92DI("8F"B`@("`@("`@("`@("`@("`H
M96UP='DH)'%U97)Y+3YT:71L92D@?'P@<W1R:7-T<B@D979E;G0M/F=E=%1I
M=&QE*"DL("1Q=65R>2T^=&ET;&4I*2`F)@H@("`@("`@("`@("`@("`@*&5M
M<'1Y*"1Q=65R>2T^;&]C871I;VXI('Q\('-T<FES='(H)&5V96YT+3YG971,
M;V-A=&EO;B@I+"`D<75E<GDM/FQO8V%T:6]N*2D@)B8*("`@("`@("`@("`@
M("`@("AE;7!T>2@D<75E<GDM/F1E<V-R:7!T:6]N*2!\?"!S=')I<W1R*"1E
M=F5N="T^9V5T1&5S8W)I<'1I;VXH*2P@)'%U97)Y+3YD97-C<FEP=&EO;BDI
M("8F"B`@("`@("`@("`@("`@("`H(6ES<V5T*"1Q=65R>2T^8V%T96=O<GDI
M('Q\("1E=F5N="T^9V5T0V%T96=O<GDH*2`]/2`D<75E<GDM/F-A=&5G;W)Y
M*2`F)@H@("`@("`@("`@("`@("`@*"%I<W-E="@D<75E<GDM/G-T871U<RD@
M?'P@)&5V96YT+3YG9713=&%T=7,H*2`]/2`D<75E<GDM/G-T871U<RDI('L*
M("`@("`@("`@("`@("`@("1R97-U;'1S6UT@/2`D979E;G0["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@
M('T*"B`@("`O*BH*("`@("`J($9I;F0@=&AE(&YE>'0@<F5C=7)R96YC92!O
M9B`D979E;G1)9"!T:&%T)W,@869T97(@)&%F=&5R1&%T92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`@("`D979E;G1)9"`@("!4:&4@240@;V8@
M=&AE(&5V96YT('1O(&9E=&-H+@H@("`@("H@0'!A<F%M($AO<F1E7T1A=&4@
M)&%F=&5R1&%T92`@4F5T=7)N(&5V96YT<R!A9G1E<B!T:&ES(&1A=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!(;W)D95]$871E('P@8F]O;&5A;B`@5&AE
M(&1A=&4@;V8@=&AE(&YE>'0@<F5C=7)R96YC92!O<B!F86QS90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@=&AE(&5V96YT(&1O
M97,@;F]T(')E8W5R(&%F=&5R("1A9G1E<D1A=&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YE>'1296-U<G)E;F-E*"1E=F5N=$ED+"`D869T97)$871E*0H@
M("`@>PH@("`@("`@("1E=F5N="`]("8D=&AI<RT^9V5T179E;G0H)&5V96YT
M260I.PH@("`@("`@(&EF("AI<U]A*"1E=F5N="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&5V96YT.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1E=F5N="T^;F5X=%)E8W5R<F5N8V4H)&%F=&5R1&%T92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C
M;VYC<F5T92!+<F]N;VQI=&A?1')I=F5R(&EN<W1A;F-E(&)A<V5D"B`@("`@
M*B!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R
M:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2W)O;F]L:71H7T1R:79E<B!S
M=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!T;R!R971U
M<FXN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA
M<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!+<F]N;VQI=&A?1')I=F5R("!4:&4@;F5W;'D@8W)E871E9"!C
M;VYC<F5T92!+<F]N;VQI=&A?1')I=F5R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EN<W1A;F-E+"!O<B!A(%!%05)?17)R;W(@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(@/2!N
M=6QL+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L
M;"@D9')I=F5R*2D@>PH@("`@("`@("`@("`D9')I=F5R(#T@)$=,3T)!3%-;
M)V-O;F8G75LG8V%L96YD87(G75LG9')I=F5R)UT["B`@("`@("`@?0H*("`@
M("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF
M("AI<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@/2!(
M;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=C86QE;F1A<B<L("1D<FEV97(I.PH@
M("`@("`@('T*"B`@("`@("`@:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]$<FEV97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M)&-L87-S(#T@)TMR;VYO;&ET:%]$<FEV97)?)R`N("1D<FEV97(["B`@("`@
M("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1D
M<FEV97(@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D9')I=F5R(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(I
M+"`D8VQA<W,I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9')I=F5R
M.PH@("`@?0H*?0H*+RHJ"B`J($MR;VYO;&ET:%]%=F5N=#HZ(&1E9FEN97,@
M82!G96YE<FEC($%022!F;W(@979E;G1S+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2W)O
M;F]L:71H(#`N,0H@*B!`<&%C:V%G92!+<F]N;VQI=&@*("HO"F-L87-S($MR
M;VYO;&ET:%]%=F5N="!["@H@("`@+RHJ"B`@("`@*B!&;&%G('1H870@:7,@
M<V5T('1O('1R=64@:68@=&AI<R!E=F5N="!H87,@9&%T82!F<F]M(&5I=&AE
M<B!A"B`@("`@*B!S=&]R86=E(&)A8VME;F0@;W(@82!F;W)M(&]R(&]T:&5R
M(&EM<&]R="!M971H;V0N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D:6YI=&EA;&EZ960@/2!F86QS93L*"B`@("`O*BH*
M("`@("`J($9L86<@=&AA="!I<R!S970@=&\@=')U92!I9B!T:&ES(&5V96YT
M(&5X:7-T<R!I;B!A('-T;W)A9V4@9')I=F5R+@H@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)'-T;W)E9"`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@5&AE(&1R:79E<B!U;FEQ=64@:61E;G1I9FEE<B!F
M;W(@=&AI<R!E=F5N="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)&5V96YT240@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE(%5)1"!F;W(@=&AI<R!E=F5N="X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]U:60@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@5&AE('5S97(@:60@;V8@=&AE(&-R96%T;W(@;V8@=&AE(&5V96YT
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M8W)E871O<DE$(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!O
M9B!T:&ES(&5V96YT+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D=&ET;&4@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!I
M9&5N=&EF:65R(&]F('1H92!C871E9V]R>2!T:&ES(&5V96YT(&)E;&]N9W,@
M=&\N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D8V%T96=O<GD@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&QO8V%T:6]N
M('1H:7,@979E;G0@;V-C=7)S(&%T+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D;&]C871I;VX@/2`G)SL*"B`@("`O*BH*
M("`@("`J(%1H92!S=&%T=7,@;V8@=&AI<R!E=F5N="X*("`@("`J"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1S=&%T=7,@/2!+4D].
M3TQ)5$A?4U1!5%537T-/3D9)4DU%1#L*"B`@("`O*BH*("`@("`J(%1H92!D
M97-C<FEP=&EO;B!F;W(@=&AI<R!E=F5N=`H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&5S8W)I<'1I;VX@/2`G)SL*"B`@
M("`O*BH*("`@("`J($%L;"!T:&4@871T96YD965S(&]F('1H:7,@979E;G0N
M"B`@("`@*@H@("`@("H@5&AI<R!I<R!A;B!A<W-O8VEA=&EV92!A<G)A>2!W
M:&5R92!T:&4@:V5Y<R!A<F4@=&AE(&5M86EL(&%D9')E<W-E<PH@("`@("H@
M;V8@=&AE(&%T=&5N9&5E<RP@86YD('1H92!V86QU97,@87)E(&%L<V\@87-S
M;V-I871I=F4@87)R87ES('=I=&@*("`@("`J(&ME>7,@)V%T=&5N9&%N8V4G
M(&%N9"`G<F5S<&]N<V4G('!O:6YT:6YG('1O('1H92!A='1E;F1E97,G(&%T
M=&5N9&%N8V4*("`@("`J(&%N9"!R97-P;VYS92!V86QU97,L(')E<W!E8W1I
M=F5L>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D871T96YD965S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($%L;"!T
M:&4@:V5Y('=O<F1S(&%S<V]C:71A=&5D('=I=&@@=&AI<R!E=F5N="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D:V5Y=V]R
M9',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06QL('1H92!E>&-E<'1I
M;VYS(&9R;VT@<F5C=7)R96YC92!F;W(@=&AI<R!E=F5N="X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97AC97!T:6]N<R`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@<W1A<G0@=&EM92!O9B!T
M:&4@979E;G0N"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]$871E"B`@("`@
M*B\*("`@('9A<B`D<W1A<G0["@H@("`@+RHJ"B`@("`@*B!4:&4@96YD('1I
M;64@;V8@=&AE(&5V96YT+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?1&%T
M90H@("`@("HO"B`@("!V87(@)&5N9#L*"B`@("`O*BH*("`@("`J(%1H92!E
M;F0@=&EM92!O9B!T:&4@<F5C=7)R96YC92!I;G1E<G9A;"X*("`@("`J"B`@
M("`@*B!`=F%R($AO<F1E7T1A=&4*("`@("`J+PH@("`@=F%R("1R96-U<D5N
M9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@9'5R871I;VX@;V8@=&AI
M<R!E=F5N="!I;B!M:6YU=&5S"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D9'5R36EN(#T@,#L*"B`@("`O*BH*("`@("`J
M($YU;6)E<B!O9B!M:6YU=&5S(&)E9F]R92!T:&4@979E;G0@<W1A<G1S('1O
M('1R:6=G97(@86X@86QA<FTN"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D86QA<FT@/2`P.PH*("`@("\J*@H@("`@("H@
M5&AE('1Y<&4@;V8@<F5C=7)R96YC92!T:&ES(&5V96YT(&9O;&QO=W,N($M2
M3TY/3$E42%]214-54E\J(&-O;G-T86YT+@H@("`@("H*("`@("`J($!V87(@
M:6YT96=E<@H@("`@("HO"B`@("!V87(@)')E8W5R5'EP92`]($M23TY/3$E4
M2%]214-54E].3TY%.PH*("`@("\J*@H@("`@("H@5$]$3R!4:&4@;&5N9W1H
M(&]F('1I;64@8F5T=V5E;B!R96-U<G)E;F-E<R!I;B!S96-O;F1S/PH@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)')E8W5R
M26YT97)V86P@/2!N=6QL.PH*("`@("\J*@H@("`@("H@06YY(&%D9&ET:6]N
M86P@<F5C=7)R96YC92!D871A+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)')E8W5R1&%T82`](&YU;&P["@H@("`@+RHJ
M"B`@("`@*B!4:&4@:61E;G1I9FEE<B!O9B!T:&4@8V%L96YD97(@=&AI<R!E
M=F5N="!E>&ES=',@;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?8V%L96YD87(["@H@("`@+RHJ"B`@("`@*B!4:&4@
M5F%R4F5N9&5R97(@8VQA<W,@=&\@=7-E(&9O<B!P<FEN=&EN9R!S96QE8W0@
M96QE;65N=',N"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]525]687)296YD
M97)E<@H@("`@("HO"B`@("!V87(@)%]V87)296YD97)E<CL*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M($MR;VYO
M;&ET:%]$<FEV97(@)&1R:79E<B`@("`@("`@5&AE(&)A8VME;F0@9')I=F5R
M('1H870@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@979E;G0@:7,@<W1O<F5D(&EN+@H@("`@("H@0'!A<F%M
M($MR;VYO;&ET:%]%=F5N="`@)&5V96YT3V)J96-T("`@0F%C:V5N9"!S<&5C
M:69I8R!E=F5N="!O8FIE8W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H870@=&AI<R!W:6QL(')E<')E<V5N="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@2W)O;F]L:71H7T5V96YT*"8D9')I=F5R
M+"`D979E;G1/8FIE8W0@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M8V%L96YD87(@/2`D9')I=F5R+3YG971#86QE;F1A<B@I.PH*("`@("`@("!I
M9B`H:7-S970H)&5V96YT3V)J96-T*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M9G)O;41R:79E<B@D979E;G1/8FIE8W0I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!A(')E9F5R96YC92!T;R!A(&1R:79E<B!T
M:&%T)W,@=F%L:60@9F]R('1H:7,@979E;G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!+<F]N;VQI=&A?1')I=F5R("!!(&1R:79E<B!T:&%T('1H:7,@979E
M;G0@8V%N('5S92!T;R!S879E(&ET<V5L9BP@971C+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9V5T1')I=F5R*"D*("`@('L*("`@("`@("!G;&]B86P@)&MR
M;VYO;&ET:#L*("`@("`@("!I9B`H)&MR;VYO;&ET:"T^9V5T0V%L96YD87(H
M*2`A/2`D=&AI<RT^7V-A;&5N9&%R*2!["B`@("`@("`@("`@("1K<F]N;VQI
M=&@M/F-L;W-E*"D["B`@("`@("`@("`@("1K<F]N;VQI=&@M/F]P96XH)'1H
M:7,M/E]C86QE;F1A<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&MR
M;VYO;&ET:#L*("`@('T*"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@=&AI<R!E
M=F5N="!I;B!I0V%L96YD87(@9F]R;6%T+@H@("`@("H*("`@("`J($!P87)A
M;2!(;W)D95]I0V%L96YD87(@)B1C86QE;F1A<B`@02!(;W)D95]I0V%L96YD
M87(@;V)J96-T('1H870@86-T<R!A<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A(&-O;G1A:6YE<BX*("`@("`J($!P87)A
M;2!)9&5N=&ET>2`D:61E;G1I='D@("`@("`@("`@5&AE($ED96YT:71Y(&]B
M:F5C="!O9B!T:&4@;W)G86YI>F5R+@H@("`@("H*("`@("`J($!R971U<FX@
M2&]R9&5?:4-A;&5N9&%R7W9E=F5N="`@5&AE('9%=F5N="!O8FIE8W0@9F]R
M('1H:7,@979E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9T;VE#86QE;F1A
M<B@F)&-A;&5N9&%R+"`D:61E;G1I='DI"B`@("!["B`@("`@("`@9VQO8F%L
M("1P<F5F<SL*"B`@("`@("`@+R\@1V5T(&$@<F5F97)E;F-E('1O('1H92!C
M86QE;F1A<B!D<FEV97(N"B`@("`@("`@)&MR;VYO;&ET:"`]("8D=&AI<RT^
M9V5T1')I=F5R*"D["@H@("`@("`@("1V179E;G0@/2`F2&]R9&5?:4-A;&5N
M9&%R.CIN97=#;VUP;VYE;G0H)W9E=F5N="<L("1C86QE;F1A<BD["@H@("`@
M("`@(&EF("@D=&AI<RT^:7-!;&Q$87DH*2D@>PH@("`@("`@("`@("`D=D5V
M96YT+3YS971!='1R:6)U=&4H)T144U1!4E0G+"`D=&AI<RT^<W1A<G0L(&%R
M<F%Y*"=604Q512<@/3X@)T1!5$4G*2D["B`@("`@("`@("`@("1V179E;G0M
M/G-E=$%T=')I8G5T92@G1%1%3D0G+"`D=&AI<RT^96YD+"!A<G)A>2@G5D%,
M544G(#T^("=$051%)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1V179E;G0M/G-E=$%T=')I8G5T92@G1%135$%25"<L("1T:&ES+3YS=&%R
M="D["B`@("`@("`@("`@("1V179E;G0M/G-E=$%T=')I8G5T92@G1%1%3D0G
M+"`D=&AI<RT^96YD*3L*("`@("`@("!]"@H@("`@("`@("1V179E;G0M/G-E
M=$%T=')I8G5T92@G1%135$%-4"<L('1I;64H*2D["B`@("`@("`@)'9%=F5N
M="T^<V5T071T<FEB=71E*"=5240G+"`D=&AI<RT^7W5I9"D["B`@("`@("`@
M)'9%=F5N="T^<V5T071T<FEB=71E*"=354U-05)9)RP@)'1H:7,M/G1I=&QE
M*3L*("`@("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)U1204Y34"<L("=/
M4$%1544G*3L*("`@("`@("`D;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L=64H
M)V9U;&QN86UE)RD["B`@("`@("`@)'9%=F5N="T^<V5T071T<FEB=71E*"=/
M4D=!3DE:15(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G34%)
M3%1/.B<@+B`D:61E;G1I='DM/F=E=%9A;'5E*"=F<F]M7V%D9'(G*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@96UP='DH)&YA;64I(#\@;G5L
M;"`Z(&%R<F%Y*"=#3B<@/3X@)&YA;64I*3L*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3YD97-C<FEP=&EO;BDI('L*("`@("`@("`@("`@)'9%=F5N="T^
M<V5T071T<FEB=71E*"=$15-#4DE05$E/3B<L("1T:&ES+3YD97-C<FEP=&EO
M;BD["B`@("`@("`@?0H@("`@("`@("1C871E9V]R:65S(#T@)'1H:7,M/F=E
M=$-A=&5G;W)Y*"D["B`@("`@("`@:68@*"%E;7!T>2@D8V%T96=O<FEE<RDI
M('L*("`@("`@("`@("`@)'9%=F5N="T^<V5T071T<FEB=71E*"=#051%1T]2
M2453)RP@)&-A=&5G;W)I97,I.PH@("`@("`@('T*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3YL;V-A=&EO;BDI('L*("`@("`@("`@("`@)'9%=F5N="T^
M<V5T071T<FEB=71E*"=,3T-!5$E/3B<L("1T:&ES+3YL;V-A=&EO;BD["B`@
M("`@("`@?0H*("`@("`@("`O+R!!='1E;F1E97,N"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/F=E=$%T=&5N9&5E<R@I(&%S("1E;6%I;"`]/B`D<W1A='5S
M*2!["B`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("`@
M("!S=VET8V@@*"1S=&%T=7-;)V%T=&5N9&%N8V4G72D@>PH@("`@("`@("`@
M("!C87-E($M23TY/3$E42%]005)47U)%455)4D5$.@H@("`@("`@("`@("`@
M("`@)'!A<F%M<ULG4D],12==(#T@)U)%42U005)424-)4$%.5"<["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@2U)/3D],251(
M7U!!4E1?3U!424].04PZ"B`@("`@("`@("`@("`@("`D<&%R86US6R=23TQ%
M)UT@/2`G3U!4+5!!4E1)0TE004Y4)SL*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92!+4D].3TQ)5$A?4$%25%].3TY%.@H@("`@
M("`@("`@("`@("`@)'!A<F%M<ULG4D],12==(#T@)TY/3BU005)424-)4$%.
M5"<["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@<W=I=&-H("@D<W1A='5S6R=R97-P;VYS92==*2!["B`@("`@
M("`@("`@(&-A<V4@2U)/3D],251(7U)%4U!/3E-%7TY/3D4Z"B`@("`@("`@
M("`@("`@("`D<&%R86US6R=005)44U1!5"==(#T@)TY%1413+4%#5$E/3B<[
M"B`@("`@("`@("`@("`@("`D<&%R86US6R=24U90)UT@/2`G5%)512<["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@2U)/3D],
M251(7U)%4U!/3E-%7T%#0T505$5$.@H@("`@("`@("`@("`@("`@)'!A<F%M
M<ULG4$%25%-4050G72`]("=!0T-%4%1%1"<["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@2U)/3D],251(7U)%4U!/3E-%7T1%
M0TQ)3D5$.@H@("`@("`@("`@("`@("`@)'!A<F%M<ULG4$%25%-4050G72`]
M("=$14-,24Y%1"<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@2U)/3D],251(7U)%4U!/3E-%7U1%3E1!5$E613H*("`@("`@
M("`@("`@("`@("1P87)A;7-;)U!!4E135$%4)UT@/2`G5$5.5$%4259%)SL*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)T%45$5.1$5%)RP@)TU!24Q4
M3SHG("X@)&5M86EL+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@("\O
M($%L87)M+@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/F%L87)M*2D@>PH@
M("`@("`@("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)T%!3$%232<L("1T
M:&ES+3YS=&%R="T^=&EM97-T86UP*"D@+2`D=&AI<RT^86QA<FT@*B`V,"D[
M"B`@("`@("`@?0H*("`@("`@("`O+R!296-U<G)E;F-E+@H@("`@("`@(&EF
M("@D=&AI<RT^<F5C=7)4>7!E*2!["B`@("`@("`@("`@("1R<G5L92`]("<G
M.PH@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3YR96-U<E1Y<&4I('L*("`@
M("`@("`@("`@8V%S92!+4D].3TQ)5$A?4D5#55)?3D].13H*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!+4D].3TQ)5$A?4D5#
M55)?1$%)3%DZ"B`@("`@("`@("`@("`@("`D<G)U;&4@/2`G1E)%43U$04E,
M63M)3E1%4E9!3#TG("`N("1T:&ES+3YR96-U<DEN=&5R=F%L.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E($M23TY/3$E42%]2
M14-54E]7145+3%DZ"B`@("`@("`@("`@("`@("`D<G)U;&4@/2`G1E)%43U7
M145+3%D[24Y415)604P])R`N("1T:&ES+3YR96-U<DEN=&5R=F%L("X@)SM"
M641!63TG.PH@("`@("`@("`@("`@("`@)'9C86QD87ES(#T@87)R87DH)U-5
M)RP@)TU/)RP@)U15)RP@)U=%)RP@)U1()RP@)T92)RP@)U-!)RD["@H@("`@
M("`@("`@("`@("`@9F]R("@D:2`]("1F;&%G(#T@,#L@)&D@/#T@-R`[("LK
M)&DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/G)E8W5R3VY$
M87DH<&]W*#(L("1I*2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1F;&%G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<G)U;&4@
M+CT@)RPG.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("1R<G5L92`N/2`D=F-A;&1A>7-;)&E=.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D9FQA9R`]('1R=64["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E($M23TY/3$E42%]214-54E]$05E?3T9?
M34].5$@Z"B`@("`@("`@("`@("`@("`D<G)U;&4@/2`G1E)%43U-3TY42$Q9
M.TE.5$525D%,/2<@+B`D=&AI<RT^<F5C=7));G1E<G9A;#L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!+4D].3TQ)5$A?4D5#
M55)?5T5%2U]/1E]-3TY42#H*("`@("`@("`@("`@("`@("1V8V%L9&%Y<R`]
M(&%R<F%Y*"=352<L("=-3R<L("=452<L("=712<L("=42"<L("=&4B<L("=3
M02<I.PH@("`@("`@("`@("`@("`@)')R=6QE(#T@)T9215$]34].5$A,63M)
M3E1%4E9!3#TG("X@)'1H:7,M/G)E8W5R26YT97)V86P@+B`G.T)91$%9/2<@
M+@H@("`@("`@("`@("`@("`@("`@("@D=&AI<RT^<W1A<G0M/G=E96M/9EEE
M87(H*2`M(&1A=&4H)U<G+"!M:W1I;64H,"P@,"P@,"P@)'1H:7,M/G-T87)T
M+3YM;VYT:"P@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS=&%R
M="T^>65A<BDI("L@,2D@+@H@("`@("`@("`@("`@("`@("`@("1V8V%L9&%Y
M<ULD=&AI<RT^<W1A<G0M/F1A>4]F5V5E:R@I73L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92!+4D].3TQ)5$A?4D5#55)?645!
M4DQ9.@H@("`@("`@("`@("`@("`@)')R=6QE(#T@)T9215$]645!4DQ9.TE.
M5$525D%,/2<@+B`D=&AI<RT^<F5C=7));G1E<G9A;#L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1R<G5L92D@)B8@(65M<'1Y*"1T:&ES+3YR96-U<D5N9"DI('L*("`@
M("`@("`@("`@("`@("1R<G5L92`N/2`G.U5.5$E,/2<@+B`D8V%L96YD87(M
M/E]E>'!O<G1$871E*"1T:&ES+3YR96-U<D5N9"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D<G)U;&4I*2!["B`@("`@("`@("`@
M("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)U)254Q%)RP@)')R=6QE*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@17AC97!T:6]N
M<RX*("`@("`@("`D97AC97!T:6]N<R`]("1T:&ES+3YG971%>&-E<'1I;VYS
M*"D["B`@("`@("`@)&5X9&%T97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A
M8V@@*"1E>&-E<'1I;VYS(&%S("1E>&-E<'1I;VXI('L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D97AC97!T:6]N*2D@>PH@("`@("`@("`@("`@("`@;&ES
M="@D>65A<BP@)&UO;G1H+"`D;61A>2D@/2!S<V-A;F8H)&5X8V5P=&EO;BP@
M)R4P-&0E,#)D)3`R9"<I.PH@("`@("`@("`@("`@("`@)&5X9&%T97-;72`]
M("9N97<@2&]R9&5?1&%T92AA<G)A>2@G>65A<B<@/3X@)'EE87(L("=M;VYT
M:"<@/3X@)&UO;G1H+"`G;61A>2<@/3X@)&UD87DI*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H8V]U;G0H)&5X9&%T97,I*2!["B`@
M("`@("`@("`@("1V179E;G0M/G-E=$%T=')I8G5T92@G15A$051%)RP@)&5X
M9&%T97,L(&%R<F%Y*"=604Q512<@/3X@)T1!5$4G*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'9%=F5N=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%5P9&%T92!T:&4@<')O<&5R=&EE<R!O9B!T:&ES(&5V96YT(&9R;VT@80H@
M("`@("H@2&]R9&5?:4-A;&5N9&%R7W9E=F5N="!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M($AO<F1E7VE#86QE;F1A<E]V979E;G0@)'9%=F5N="`@
M5&AE(&E#86QE;F1A<B!D871A('1O('5P9&%T90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O;2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9G)O;6E#86QE;F1A<B@D=D5V96YT*0H@("`@>PH@("`@
M("`@("\O(%5N:7%U92!)1"X*("`@("`@("`D=6ED(#T@)'9%=F5N="T^9V5T
M071T<FEB=71E*"=5240G*3L*("`@("`@("!I9B`H(65M<'1Y*"1U:60I("8F
M("%I<U]A*"1U:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H
M:7,M/G-E=%5)1"@D=6ED*3L*("`@("`@("!]"@H@("`@("`@("\O(%1I=&QE
M+"!C871E9V]R>2!A;F0@9&5S8W)I<'1I;VXN"B`@("`@("`@)'1I=&QE(#T@
M)'9%=F5N="T^9V5T071T<FEB=71E*"=354U-05)9)RD["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D=&ET;&4I("8F("%I<U]A*"1T:71L92P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T5&ET;&4H)'1I=&QE*3L*
M("`@("`@("!]"B`@("`@("`@)&-A=&5G;W)I97,@/2`D=D5V96YT+3YG971!
M='1R:6)U=&4H)T-!5$5'3U))15,G*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1C871E9V]R:65S*2`F)B`A:7-?82@D8V%T96=O<FEE<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`O+R!4:&4@0T%414=/4ED@871T<FEB=71E
M(&ES(&1E;&EM:71E9"!B>2!C;VUM87,L('-O('-P;&ET"B`@("`@("`@("`@
M("\O(&ET('5P+@H@("`@("`@("`@("`D8V%T96=O<FEE<R`](&5X<&QO9&4H
M)RPG+"`D8V%T96=O<FEE<RD["@H@("`@("`@("`@("`O+R!792!O;FQY('-U
M<'!O<G0@;VYE(&-A=&5G;W)Y('!E<B!E=F5N="!R:6=H="!N;W<L('-O"B`@
M("`@("`@("`@("\O(&%R8FET<F%R:6QY('1A:V4@=&AE(&QA<W0@;VYE+@H@
M("`@("`@("`@("!F;W)E86-H("@D8V%T96=O<FEE<R!A<R`D8V%T96=O<GDI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971#871E9V]R>2@D8V%T96=O
M<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1D97-C(#T@
M)'9%=F5N="T^9V5T071T<FEB=71E*"=$15-#4DE05$E/3B<I.PH@("`@("`@
M(&EF("@A:7-?87)R87DH)&1E<V,I("8F("%I<U]A*"1D97-C+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YS971$97-C<FEP=&EO;B@D
M9&5S8RD["B`@("`@("`@?0H*("`@("`@("`O+R!,;V-A=&EO;BX*("`@("`@
M("`D;&]C871I;VX@/2`D=D5V96YT+3YG971!='1R:6)U=&4H)TQ/0T%424].
M)RD["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;&]C871I;VXI("8F("%I<U]A
M*"1L;V-A=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^<V5T3&]C871I;VXH)&QO8V%T:6]N*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%-T87)T(&%N9"!E;F0@9&%T92X*("`@("`@("`D<W1A<G0@/2`D=D5V
M96YT+3YG971!='1R:6)U=&4H)T144U1!4E0G*3L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1S=&%R="D@)B8@(6ES7V$H)'-T87)T+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1T:&ES+3YS=&%R="`]("9N97<@2&]R9&5?1&%T
M92@D<W1A<G0I.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D<W1A<G0I
M("8F("%I<U]A*"1S=&%R="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^<W1A<G0@/2`F;F5W($AO<F1E7T1A=&4H87)R87DH)WEE87(G
M(#T^("AI;G0I)'-T87)T6R=Y96%R)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6]N=&@G(#T^("AI;G0I
M)'-T87)T6R=M;VYT:"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VUD87DG(#T^("AI;G0I)'-T87)T6R=M
M9&%Y)UTI*3L*("`@("`@("!]"B`@("`@("`@)&5N9"`]("1V179E;G0M/F=E
M=$%T=')I8G5T92@G1%1%3D0G*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1E
M;F0I("8F("%I<U]A*"1E;F0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)'1H:7,M/F5N9"`]("9N97<@2&]R9&5?1&%T92@D96YD*3L*("`@("`@
M("!](&5L<V5I9B`H:7-?87)R87DH)&5N9"D@)B8@(6ES7V$H)&5N9"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^96YD(#T@)FYE=R!(
M;W)D95]$871E*&%R<F%Y*"=Y96%R)R`]/B`H:6YT*21E;F1;)WEE87(G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;6]N=&@G(#T^("AI;G0I)&5N9%LG;6]N=&@G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;61A>2<@/3X@
M*&EN="DD96YD6R=M9&%Y)UTI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D9'5R871I;VX@/2`D=D5V96YT+3YG971!='1R:6)U=&4H)T154D%4
M24].)RD["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&1U<F%T:6]N*2`F
M)B`A:7-?82@D9'5R871I;VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YE;F0@/2`F;F5W($AO<F1E7T1A=&4H)'1H:7,M/G-T
M87)T+3YT:6UE<W1A;7`H*2`K("1D=7)A=&EO;BD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O+R!%;F0@9&%T92!E<75A;"!T;R!S
M=&%R="!D871E(&%S('!E<B!21D,@,C0T-2X*("`@("`@("`@("`@("`@("1T
M:&ES+3YE;F0@/2!5=&EL.CIC;&]N94]B:F5C="@D=&AI<RT^<W1A<G0I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D86QA<FT@/2`D=D5V
M96YT+3YG971!='1R:6)U=&4H)T%!3$%232<I.PH@("`@("`@(&EF("@A:7-?
M87)R87DH)&%L87)M*2`F)B`A:7-?82@D86QA<FTL("=014%27T5R<F]R)RD@
M)B8@:6YT=F%L*"1A;&%R;2DI('L*("`@("`@("`@("`@)'1H:7,M/F%L87)M
M(#T@:6YT=F%L*"@D=&AI<RT^<W1A<G0M/G1I;65S=&%M<"@I("T@)&%L87)M
M*2`O(#8P*3L*("`@("`@("!]"@H@("`@("`@("\O(%)E8W5R<F5N8V4N"B`@
M("`@("`@)')R=6QE(#T@)'9%=F5N="T^9V5T071T<FEB=71E*"=24E5,12<I
M.PH@("`@("`@(&EF("@A:7-?87)R87DH)')R=6QE*2`F)B`A:7-?82@D<G)U
M;&4L("=014%27T5R<F]R)RD@)B8@<W1R<&]S*"1R<G5L92P@)STG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@+R\@4&%R<V4@=&AE(')E8W5R<F5N8V4@
M<G5L92!I;G1O(&ME>7,@86YD('9A;'5E<RX*("`@("`@("`@("`@)'!A<G1S
M(#T@97AP;&]D92@G.R<L("1R<G5L92D["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1P87)T<R!A<R`D<&%R="D@>PH@("`@("`@("`@("`@("`@;&ES="@D:V5Y
M+"`D=F%L=64I(#T@97AP;&]D92@G/2<L("1P87)T+"`R*3L*("`@("`@("`@
M("`@("`@("1R9&%T85LD:V5Y72`]("1V86QU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*&ES<V5T*"1R9&%T85LG1E)%42==*2D@>PH@("`@
M("`@("`@("`@("`@+R\@06QW87ES(&1E9F%U;'0@=&AE(')E8W5R26YT97)V
M86P@=&\@,2X*("`@("`@("`@("`@("`@("1T:&ES+3YS971296-U<DEN=&5R
M=F%L*&ES<V5T*"1R9&%T85LG24Y415)604PG72D@/R`D<F1A=&%;)TE.5$52
M5D%,)UT@.B`Q*3L*"B`@("`@("`@("`@("`@("`D9G)E<75E;F-Y(#T@4W1R
M:6YG.CIU<'!E<B@D<F1A=&%;)T9215$G72D["B`@("`@("`@("`@("`@("!S
M=VET8V@@*"1F<F5Q=65N8WDI('L*("`@("`@("`@("`@("`@(&-A<V4@)T1!
M24Q9)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4F5C=7)4>7!E
M*$M23TY/3$E42%]214-54E]$04E,62D["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G5T5%2TQ9)SH*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T4F5C=7)4>7!E*$M23TY/3$E42%]2
M14-54E]7145+3%DI.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M<F1A=&%;)T)91$%9)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M
M87-K9&%Y<R`](&%R<F%Y*"=352<@/3X@2$]21$5?1$%415]-05-+7U-53D1!
M62P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)TU/)R`]/B!(3U)$15]$051%7TU!4TM?34].1$%9+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5%4G(#T^($A/4D1%7T1!
M5$5?34%32U]454531$%9+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G5T4G(#T^($A/4D1%7T1!5$5?34%32U]7141.15-$
M05DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=42"<@/3X@2$]21$5?1$%415]-05-+7U1(55)31$%9+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1E(G(#T^($A/4D1%
M7T1!5$5?34%32U]&4DE$05DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=302<@/3X@2$]21$5?1$%415]-05-+7U-!5%52
M1$%9*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A>7,@/2!E>'!L;V1E
M*"<L)RP@)')D871A6R="641!62==*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&UA<VL@/2`P.PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D9&%Y<R!A<R`D9&%Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;6%S:R!\/2`D;6%S:V1A>7-;)&1A>5T["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%)E
M8W5R3VY$87DH)&UA<VLI.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O(%)E8W5R(&]N('1H92!D87D@
M;V8@=&AE('=E96L@;V8@=&AE"B`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&]R:6=I;F%L(')E8W5R<F5N8V4N"B`@("`@("`@("`@("`@("`@("`@("`@
M("1M87-K9&%Y<R`](&%R<F%Y*$A/4D1%7T1!5$5?4U5.1$%9(#T^($A/4D1%
M7T1!5$5?34%32U]354Y$05DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($A/4D1%7T1!5$5?34].1$%9(#T^($A/4D1%7T1!
M5$5?34%32U]-3TY$05DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($A/4D1%7T1!5$5?5%5%4T1!62`]/B!(3U)$15]$051%
M7TU!4TM?5%5%4T1!62P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@2$]21$5?1$%415]7141.15-$05D@/3X@2$]21$5?1$%4
M15]-05-+7U=%1$Y%4T1!62P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@2$]21$5?1$%415]42%524T1!62`]/B!(3U)$15]$
M051%7TU!4TM?5$A54E-$05DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($A/4D1%7T1!5$5?1E))1$%9(#T^($A/4D1%7T1!
M5$5?34%32U]&4DE$05DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($A/4D1%7T1!5$5?4T%455)$05D@/3X@2$]21$5?1$%4
M15]-05-+7U-!5%521$%9*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=%)E8W5R3VY$87DH)&UA<VMD87ES6R1T:&ES+3YS=&%R="T^9&%Y
M3V97965K*"E=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G34].5$A,
M62<Z"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R9&%T85LG0EE$
M05DG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%)E
M8W5R5'EP92A+4D].3TQ)5$A?4D5#55)?5T5%2U]/1E]-3TY42"D["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=%)E8W5R5'EP92A+4D].3TQ)5$A?4D5#55)?1$%97T]&
M7TU/3E1(*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G645!4DQ9)SH*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4F5C=7)4>7!E*$M23TY/
M3$E42%]214-54E]914%23%DI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<F1A=&%;)U5.5$E,)UTI*2!["B`@("`@("`@("`@("`@("`@("`@;&ES
M="@D>65A<BP@)&UO;G1H+"`D;61A>2D@/2!S<V-A;F8H)')D871A6R=53E1)
M3"==+"`G)3`T9"4P,F0E,#)D)RD["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G)E8W5R16YD(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=Y96%R)R`]
M/B`D>65A<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VUO;G1H)R`]/B`D;6]N=&@L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=M9&%Y)R`]/B`D;61A>2DI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@
M3F\@<F5C=7)R96YC92!D871A("T@979E;G0@9&]E<R!N;W0@<F5C=7(N"B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T4F5C=7)4>7!E*$M23TY/3$E42%]2
M14-54E].3TY%*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@17AC97!T:6]N<RX*("`@("`@("`D97AD871E<R`]("1V179E;G0M/F=E
M=$%T=')I8G5T92@G15A$051%)RD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1E
M>&1A=&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D97AD871E<R!A<R`D
M97AD871E*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&5X9&%T
M92DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D17AC97!T:6]N
M*"AI;G0I)&5X9&%T95LG>65A<B==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*&EN="DD97AD871E6R=M;VYT:"==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD97AD
M871E6R=M9&%Y)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^:6YI=&EA;&EZ960@/2!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP;W)T('1H92!V86QU97,@9F]R
M('1H:7,@979E;G0@9G)O;2!A;B!A<G)A>2!O9B!V86QU97,N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1H87-H("!!<G)A>2!C;VYT86EN:6YG(&%L
M;"!T:&4@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!F<F]M2&%S:"@D
M:&%S:"D*("`@('L*("`@("`@("`O+R!3964@:68@:70G<R!A(&YE=R!E=F5N
M="X*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^9V5T260H*2DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$-R96%T;W))9"A!=71H.CIG971!=71H*"DI
M.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1H87-H6R=T:71L92==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T5&ET;&4H)&AA<VA;)W1I=&QE
M)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D5V96YT<R!M=7-T(&AA=F4@82!T:71L92XB*2D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&AA<VA;)V1E<V-R:7!T
M:6]N)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971$97-C<FEP=&EO;B@D
M:&%S:%LG9&5S8W)I<'1I;VXG72D["B`@("`@("`@?0H@("`@("`@(&EF("@A
M96UP='DH)&AA<VA;)V-A=&5G;W)Y)UTI*2!["B`@("`@("`@("`@(&=L;V)A
M;"`D8TUA;F%G97(["B`@("`@("`@("`@("1C871E9V]R:65S(#T@)&--86YA
M9V5R+3YG970H*3L*("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D:&%S:%LG
M8V%T96=O<GDG72P@)&-A=&5G;W)I97,I*2!["B`@("`@("`@("`@("`@("`D
M8TUA;F%G97(M/F%D9"@D:&%S:%LG8V%T96=O<GDG72D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/G-E=$-A=&5G;W)Y*"1H87-H6R=C871E
M9V]R>2==*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D:&%S:%LG
M;&]C871I;VXG72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$QO8V%T:6]N
M*"1H87-H6R=L;V-A=&EO;B==*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E
M;7!T>2@D:&%S:%LG:V5Y=V]R9',G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=$ME>7=O<F1S*&5X<&QO9&4H)RPG+"`D:&%S:%LG:V5Y=V]R9',G72DI
M.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1H87-H6R=S=&%R=%]D
M871E)UTI*2!["B`@("`@("`@("`@("1D871E(#T@97AP;&]D92@G+2<L("1H
M87-H6R=S=&%R=%]D871E)UTI.PH@("`@("`@("`@("!I9B`H96UP='DH)&AA
M<VA;)W-T87)T7W1I;64G72DI('L*("`@("`@("`@("`@("`@("1T:6UE(#T@
M87)R87DH,"P@,"P@,"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&EM92`](&5X<&QO9&4H)SHG+"`D:&%S:%LG<W1A<G1?=&EM
M92==*3L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D=&EM92D@/3T@,BD@
M>PH@("`@("`@("`@("`@("`@("`@("1T:6UE6S)=(#T@,#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H8V]U;G0H
M)'1I;64I(#T](#,@)B8@8V]U;G0H)&1A=&4I(#T](#,I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS=&%R="`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G
M>65A<B<@/3X@)&1A=&5;,%TL("=M;VYT:"<@/3X@)&1A=&5;,5TL("=M9&%Y
M)R`]/B`D9&%T95LR72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:&]U<B<@/3X@)'1I;65;,%TL("=M
M:6XG(#T^("1T:6UE6S%=+"`G<V5C)R`]/B`D=&EM95LR72DI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B179E;G1S(&UU<W0@:&%V92!A('-T87)T(&1A
M=&4N(BDI.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&AA<VA;)V1U
M<F%T:6]N)UTI("8F(&5M<'1Y*"1H87-H6R=E;F1?9&%T92==*2D@>PH@("`@
M("`@("`@("`D:&%S:%LG96YD7V1A=&4G72`]("1H87-H6R=S=&%R=%]D871E
M)UT["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&AA<VA;)V1U<F%T
M:6]N)UTI*2!["B`@("`@("`@("`@("1W965K<R`]('-T<E]R97!L86-E*"=7
M)RP@)R<L("1H87-H6R=D=7)A=&EO;B==6S%=*3L*("`@("`@("`@("`@)&1A
M>7,@/2!S=')?<F5P;&%C92@G1"<L("<G+"`D:&%S:%LG9'5R871I;VXG75LR
M72D["B`@("`@("`@("`@("1H;W5R<R`]('-T<E]R97!L86-E*"=()RP@)R<L
M("1H87-H6R=D=7)A=&EO;B==6S1=*3L*("`@("`@("`@("`@)&UI;G5T97,@
M/2!I<W-E="@D:&%S:%LG9'5R871I;VXG75LU72D@/R!S=')?<F5P;&%C92@G
M32<L("<G+"`D:&%S:%LG9'5R871I;VXG75LU72D@.B`P.PH@("`@("`@("`@
M("`D<V5C;VYD<R`](&ES<V5T*"1H87-H6R=D=7)A=&EO;B==6S9=*2`_('-T
M<E]R97!L86-E*"=3)RP@)R<L("1H87-H6R=D=7)A=&EO;B==6S9=*2`Z(#`[
M"B`@("`@("`@("`@("1H87-H6R=D=7)A=&EO;B==(#T@*"1W965K<R`J(#8P
M("H@-C`@*B`R-"`J(#<I("L@*"1D87ES("H@-C`@*B`V,"`J(#(T*2`K("@D
M:&]U<G,@*B`V,"`J(#8P*2`K("@D;6EN=71E<R`J(#8P*2`K("1S96-O;F1S
M.PH@("`@("`@("`@("`D=&AI<RT^96YD(#T@)FYE=R!(;W)D95]$871E*"1T
M:&ES+3YS=&%R="T^=&EM97-T86UP*"D@*R`D:&%S:%LG9'5R871I;VXG72D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&AA<VA;)V5N9%]D871E
M)UTI*2!["B`@("`@("`@("`@("1D871E(#T@97AP;&]D92@G+2<L("1H87-H
M6R=E;F1?9&%T92==*3L*("`@("`@("`@("`@:68@*&5M<'1Y*"1H87-H6R=E
M;F1?=&EM92==*2D@>PH@("`@("`@("`@("`@("`@)'1I;64@/2!A<G)A>2@P
M+"`P+"`P*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1T:6UE(#T@97AP;&]D92@G.B<L("1H87-H6R=E;F1?=&EM92==*3L*("`@
M("`@("`@("`@("`@(&EF("AC;W5N="@D=&EM92D@/3T@,BD@>PH@("`@("`@
M("`@("`@("`@("`@("1T:6UE6S)=(#T@,#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H8V]U;G0H)'1I;64I(#T]
M(#,@)B8@8V]U;G0H)&1A=&4I(#T](#,I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YE;F0@/2`F;F5W($AO<F1E7T1A=&4H87)R87DH)WEE87(G(#T^("1D
M871E6S!=+"`G;6]N=&@G(#T^("1D871E6S%=+"`G;61A>2<@/3X@)&1A=&5;
M,ETL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H;W5R)R`]/B`D=&EM95LP72P@)VUI;B<@/3X@)'1I;65;
M,5TL("=S96,G(#T^("1T:6UE6S)=*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*"%E;7!T>2@D:&%S:%LG86QA<FTG72DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$%L87)M*"1H87-H6R=A;&%R;2==*3L*("`@
M("`@("!](&5L<V5I9B`H(65M<'1Y*"1H87-H6R=A;&%R;5]D871E)UTI("8F
M"B`@("`@("`@("`@("`@("`@("%E;7!T>2@D:&%S:%LG86QA<FU?=&EM92==
M*2D@>PH@("`@("`@("`@("`D9&%T92`](&5X<&QO9&4H)RTG+"`D:&%S:%LG
M86QA<FU?9&%T92==*3L*("`@("`@("`@("`@)'1I;64@/2!E>'!L;V1E*"<Z
M)RP@)&AA<VA;)V%L87)M7W1I;64G72D["B`@("`@("`@("`@(&EF("AC;W5N
M="@D=&EM92D@/3T@,BD@>PH@("`@("`@("`@("`@("`@)'1I;65;,ET@/2`P
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AC;W5N="@D=&EM92D@
M/3T@,R`F)B!C;W5N="@D9&%T92D@/3T@,RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$%L87)M*"@D=&AI<RT^<W1A<G0M/G1I;65S=&%M<"@I("T@
M;6MT:6UE*"1T:6UE6S!=+"`D=&EM95LQ72P@)'1I;65;,ETL("1D871E6S%=
M+"`D9&%T95LR72P@)&1A=&5;,%TI*2`O(#8P*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1H87-H6R=R96-U<E]T>7!E
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971296-U<E1Y<&4H)&AA<VA;
M)W)E8W5R7W1Y<&4G72D["B`@("`@("`@("`@(&EF("@A96UP='DH)&AA<VA;
M)W)E8W5R7V5N9%]D871E)UTI*2!["B`@("`@("`@("`@("`@("`D9&%T92`]
M(&5X<&QO9&4H)RTG+"`D:&%S:%LG<F5C=7)?96YD7V1A=&4G72D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<F5C=7)%;F0@/2`F;F5W($AO<F1E7T1A=&4H
M87)R87DH)WEE87(G(#T^("1D871E6S!=+"`G;6]N=&@G(#T^("1D871E6S%=
M+"`G;61A>2<@/3X@)&1A=&5;,ETI*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1H87-H6R=R96-U<E]I;G1E<G9A;"==*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%)E8W5R26YT97)V86PH)&AA<VA;
M)W)E8W5R7VEN=&5R=F%L)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A96UP='DH)&AA<VA;)W)E8W5R7V1A=&$G72DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971296-U<D]N1&%Y*"1H87-H6R=R96-U<E]D871A
M)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M:6YI=&EA;&EZ960@/2!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V%V
M92!C:&%N9V5S('1O('1H:7,@979E;G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V%V92@I"B`@("!["B`@("`@("`@:68@*"$D
M=&AI<RT^:7-);FET:6%L:7IE9"@I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=%=F5N="!N;W0@>65T(&EN:71I86QI>F5D)RD[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^=&]$<FEV97(H*3L*("`@("`@
M("`D9')I=F5R(#T@)B1T:&ES+3YG971$<FEV97(H*3L*("`@("`@("!R971U
M<FX@)&1R:79E<BT^<V%V945V96YT*"1T:&ES*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9"!A;B!E>&-E<'1I;VX@=&\@82!R96-U<G)I;F<@979E;G0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'EE87(@("!4:&4@>65A
M<B!O9B!T:&4@97AE8W!T:6]N+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UO
M;G1H("!4:&4@;6]N=&@@;V8@=&AE(&5X96-P=&EO;BX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1M9&%Y("`@5&AE(&1A>2!O9B!T:&4@;6]N=&@@;V8@=&AE
M(&5X8V5P=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@861D17AC97!T:6]N
M*"1Y96%R+"`D;6]N=&@L("1M9&%Y*0H@("`@>PH@("`@("`@("1T:&ES+3YE
M>&-E<'1I;VYS6UT@/2!S<')I;G1F*"<E,#1D)3`R9"4P,F0G+"`D>65A<BP@
M)&UO;G1H+"`D;61A>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!I
M9B!A;B!E>&-E<'1I;VX@97AI<W1S(&9O<B!A(&=I=F5N(')E8V-U<F5N8V4@
M;V8@86X@979E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'EE
M87(@("!4:&4@>65A<B!O9B!T:&4@<F5U8W)A;F-E+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&UO;G1H("!4:&4@;6]N=&@@;V8@=&AE(')E=6-R86YC92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1M9&%Y("`@5&AE(&1A>2!O9B!T:&4@
M;6]N=&@@;V8@=&AE(')E=6-R86YC92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@86X@97AC97!T:6]N(&5X:7-T<R!F;W(@=&AE
M(&=I=F5N(&1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T5X8V5P=&EO
M;B@D>65A<BP@)&UO;G1H+"`D;61A>2D*("`@('L*("`@("`@("!R971U<FX@
M:6Y?87)R87DH<W!R:6YT9B@G)3`T9"4P,F0E,#)D)RP@)'EE87(L("1M;VYT
M:"P@)&UD87DI+"`D=&AI<RT^9V5T17AC97!T:6]N<R@I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E=')I979E(&%L;"!T:&4@97AC97!T:6]N<R!F;W(@
M=&AI<R!E=F5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A
M>2!C;VYT86EN:6YG('1H92!D871E<R!O9B!A;&P@=&AE(&5X8V5P=&EO;G,@
M:6X*("`@("`J("`@("`@("`@("`@("`@(%E965E-341$(&9O<FTN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$5X8V5P=&EO;G,H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^97AC97!T:6]N<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@:7-);FET:6%L:7IE9"@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YI;FET:6%L:7IE9#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@
M:7-3=&]R960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<W1O<F5D
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@=&AE(&-U<G)E;G0@
M979E;G0@:7,@86QR96%D>2!P<F5S96YT(&EN('1H92!C86QE;F1A<BX*("`@
M("`J($1O('1H92!C:&5C:R!B87-E9"!O;B!T:&4@=6ED+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!E=F5N="!E>&ES=',L(&9A
M;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"D*
M("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=6ED*2!\?"`A:7-S
M970H)'1H:7,M/E]C86QE;F1A<BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@)&5V96YT240@/2`D1TQ/0D%,4ULG
M:W)O;F]L:71H)UTM/F5X:7-T<R@D=&AI<RT^7W5I9"P@)'1H:7,M/E]C86QE
M;F1A<BD["B`@("`@("`@:68@*&ES7V$H)&5V96YT240L("=014%27T5R<F]R
M)RD@?'P@(21E=F5N=$E$*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^979E;G1)1"`]
M("1E=F5N=$E$.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!I9B!T:&ES(&5V96YT(')E
M8W5R<R!O;B!A(&=I=F5N(&1A>2!O9B!T:&4@=V5E:RX*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D9&%Y36%S:R`@02!M87-K('-P96-I9GEI;F<@
M=&AE(&1A>2AS*2!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=&AI<R!E=F5N="!R96-U<G,@;VX@=&AE(&=I=F5N
M(&1A>2AS*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5C=7)/;D1A>2@D9&%Y
M36%S:RD*("`@('L*("`@("`@("!R971U<FX@*"1T:&ES+3YR96-U<D1A=&$@
M)B`D9&%Y36%S:RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3<&5C:69Y('1H
M92!D87ES('1H:7,@979E;G0@<F5C=7)S(&]N+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1D87E-87-K("!!(&UA<VL@<W!E8VEF>6EN9R!T:&4@
M9&%Y*',I('1O(')E8W5R(&]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9712
M96-U<D]N1&%Y*"1D87E-87-K*0H@("`@>PH@("`@("`@("1T:&ES+3YR96-U
M<D1A=&$@/2`D9&%Y36%S:SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@9&%Y<R!T:&ES(&5V96YT(')E8W5R<R!O;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@($$@;6%S:R!S<&5C:69Y:6YG('1H92!D87DH
M<RD@=&AI<R!E=F5N="!R96-U<G,@;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%)E8W5R3VY$87ES*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G)E8W5R1&%T83L*("`@('T*"B`@("!F=6YC=&EO;B!G971296-U<E1Y<&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5C=7)4>7!E.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&AA<U)E8W5R5'EP92@D<F5C=7)R96YC92D*("`@
M('L*("`@("`@("!R971U<FX@*"1R96-U<G)E;F-E(#T]/2`D=&AI<RT^<F5C
M=7)4>7!E*3L*("`@('T*"B`@("!F=6YC=&EO;B!S971296-U<E1Y<&4H)')E
M8W5R<F5N8V4I"B`@("!["B`@("`@("`@)'1H:7,M/G)E8W5R5'EP92`]("1R
M96-U<G)E;F-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!L96YG
M=&@@;V8@=&EM92!B971W965N(')E8W5R<F5N8V5S(&]F('1H:7,@979E;G0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN=&5R=F%L("!4:&4@
M;G5M8F5R(&]F('-E8V]N9',@8F5T=V5E;B!R96-U<G)E;F-E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T4F5C=7));G1E<G9A;"@D:6YT97)V86PI"B`@
M("!["B`@("`@("`@:68@*"1I;G1E<G9A;"`^(#`I('L*("`@("`@("`@("`@
M)'1H:7,M/G)E8W5R26YT97)V86P@/2`D:6YT97)V86P["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&QE;F=T:"!O9B!T
M:6UE(&)E='=E96X@<F5C=7)R96YC97,@9F\@=&AI<R!E=F5N="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@<V5C;VYD
M<R!B971W965N(')E8W5R<F5N8V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971296-U<DEN=&5R=F%L*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G)E8W5R26YT97)V86P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M92!T:&4@;&]C86QL>2!U;FEQ=64@:61E;G1I9FEE<B!F;W(@=&AI<R!E=F5N
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&QO8V%L(&ED
M96YT:69I97(@9F]R('1H:7,@979E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$ED*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F5V96YT240[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&QO8V%L;'D@=6YI<75E
M(&ED96YT:69I97(@9F]R('1H:7,@979E;G0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D979E;G1)9"`@5&AE(&QO8V%L(&ED96YT:69I97(@9F]R
M('1H:7,@979E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ED*"1E=F5N
M=$ED*0H@("`@>PH@("`@("`@(&EF("AS=6)S='(H)&5V96YT260L(#`L(#$P
M*2`]/2`G:W)O;F]L:71H.B<I('L*("`@("`@("`@("`@)&5V96YT260@/2!S
M=6)S='(H)&5V96YT260L(#$P*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/F5V96YT240@/2`D979E;G1)9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E('1H92!G;&]B86P@54E$(&9O<B!T:&ES(&5V96YT+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9VQO8F%L(%5)1"!F;W(@=&AI
M<R!E=F5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T54E$*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]U:60["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE(&=L;V)A;"!5240@9F]R('1H:7,@979E;G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=6ED("!4:&4@9VQO8F%L(%5)1"!F
M;W(@=&AI<R!E=F5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T54E$*"1U
M:60I"B`@("!["B`@("`@("`@)'1H:7,M/E]U:60@/2`D=6ED.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&ED(&]F('1H92!U<V5R('=H
M;R!C<F5A=&5D('1H92!E=F5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&-R96%T;W(@:60*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M0W)E871O<DED*"D*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES
M+3YC<F5A=&]R240I(#\@)'1H:7,M/F-R96%T;W))1"`Z($%U=&@Z.F=E=$%U
M=&@H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:60@;V8@=&AE
M(&-R96%T;W(@;V8@=&AE(&5V96YT+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-R96%T;W))1"`@5&AE('5S97(@:60@9F]R('1H92!U<V5R('=H
M;R!C<F5A=&5D('1H92!E=F5N=`H@("`@("HO"B`@("!F=6YC=&EO;B!S971#
M<F5A=&]R260H)&-R96%T;W))1"D*("`@('L*("`@("`@("`D=&AI<RT^8W)E
M871O<DE$(#T@)&-R96%T;W))1#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E('1H92!T:71L92!O9B!T:&ES(&5V96YT+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@=&ET;&4@;V8@=&AI<R!E=F5N="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T5&ET;&4H*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^=&%S:TE$*2!\?`H@("`@("`@("`@("!I<W-E="@D
M=&AI<RT^8V]N=&%C=$E$*2!\?`H@("`@("`@("`@("!I<W-E="@D=&AI<RT^
M<F5M;W1E0V%L*2D@>PH@("`@("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES
M+3YT:71L92D@/R`D=&AI<RT^=&ET;&4@.B!?*");56YN86UE9"!E=F5N=%TB
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/FES26YI=&EA;&EZ
M960H*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@
M("`@("!I9B`H:7-S970H)$=,3T)!3%-;)V%L;%]C86QE;F1A<G,G75LD=&AI
M<RT^9V5T0V%L96YD87(H*5TI("8F"B`@("`@("`@("`@("%I<U]A*"1S:&%R
M92`]("1'3$]"04Q36R=A;&Q?8V%L96YD87)S)UU;)'1H:7,M/F=E=$-A;&5N
M9&%R*"E=+"`G4$5!4E]%<G)O<B<I("8F"B`@("`@("`@("`@("1S:&%R92T^
M:&%S4&5R;6ES<VEO;BA!=71H.CIG971!=71H*"DL(%!%4DU37U)%040L("1T
M:&ES+3YG971#<F5A=&]R260H*2DI('L*("`@("`@("`@("`@<F5T=7)N("%E
M;7!T>2@D=&AI<RT^=&ET;&4I(#\@)'1H:7,M/G1I=&QE(#H@7R@B6U5N;F%M
M960@979E;G1=(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9VQO
M8F%L("1P<F5F<SL*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H7R@B179E
M;G0@9G)O;2`E<R!T;R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G*2`_("='.FDG
M(#H@)V<Z:6$G+"`D=&AI<RT^<W1A<G0M/G1I;65S=&%M<"@I*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9&%T92@D<')E9G,M/F=E=%9A;'5E*"=T
M=V5N='E&;W5R)RD@/R`G1SII)R`Z("=G.FEA)RP@)'1H:7,M/F5N9"T^=&EM
M97-T86UP*"DI*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M970@=&AE('1I=&QE(&]F('1H:7,@979E;G0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@5&AE(&YE=R!T:71L92!F;W(@=&AI<R!E=F5N="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T5&ET;&4H)'1I=&QE*0H@("`@>PH@("`@
M("`@("1T:&ES+3YT:71L92`]("1T:71L93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=&EE=F4@=&AE(&1E<V-R:7!T:6]N(&]F('1H:7,@979E;G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D97-C<FEP=&EO;B!O
M9B!T:&ES(&5V96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$97-C<FEP
M=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD97-C<FEP=&EO
M;CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@9&5S8W)I<'1I;VX@
M;V8@=&AI<R!E=F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M97-C<FEP=&EO;B`@5&AE(&YE=R!D97-C<FEP=&EO;B!F;W(@=&AI<R!E=F5N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5S8W)I<'1I;VXH)&1E<V-R
M:7!T:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3YD97-C<FEP=&EO;B`]("1D
M97-C<FEP=&EO;CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@8V%T
M96=O<GD@=&AI<R!E=F5N="!B96QO;F=S('1O+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1C871E9V]R>2`@5&AE(&ED96YT:69I97(@;V8@=&AE
M(&-A=&5G;W)Y('1H:7,@979E;G0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8F5L;VYG<R!T;RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M0V%T96=O<GDH)&-A=&5G;W)Y*0H@("`@>PH@("`@("`@("1T:&ES+3YC871E
M9V]R>2`]("1C871E9V]R>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I
M979E('1H92!C871E9V]R>2!T:&ES(&5V96YT(&)E;&]N9W,@=&\N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@:61E;G1I9FEE<B!O9B!T
M:&4@8V%T96=O<GD@=&AI<R!E=F5N="!B96QO;F=S('1O+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971#871E9V]R>2@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YC871E9V]R>3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@;&]C871I;VX@=&AI<R!E=F5N="!O8V-U<G,@870N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;&]C871I;VX@(%1H92!N97<@;&]C871I;VX@
M9F]R('1H:7,@979E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$QO8V%T
M:6]N*"1L;V-A=&EO;BD*("`@('L*("`@("`@("`D=&AI<RT^;&]C871I;VX@
M/2`D;&]C871I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!T
M:&4@;&]C871I;VX@=&AI<R!E=F5N="!O8V-U<G,@870N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!L;V-A=&EO;B!O9B!T:&ES(&5V96YT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,;V-A=&EO;B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YL;V-A=&EO;CL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E=')I979E('1H92!E=F5N="!S=&%T=7,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!4:&4@<W1A='5S(&]F('1H:7,@979E;G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-T871U<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YS=&%T=7,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@=VAE=&AE<B!T:&4@979E;G1S('-T871U<R!I<R!T:&4@<V%M
M92!A<R!T:&4@<W!E8VEF:65D('9A;'5E+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1S=&%T=7,@(%1H92!S=&%T=7,@=F%L=64@=&\@8VAE8VL@
M86=A:6YS="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=&AE(&5V96YT<R!S=&%T=7,@:7,@=&AE('-A;64@87,@)'-T871U<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@:&%S4W1A='5S*"1S=&%T=7,I"B`@("![
M"B`@("`@("`@<F5T=7)N("@D<W1A='5S(#T]/2`D=&AI<RT^<W1A='5S*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@<W1A='5S(&]F('1H:7,@
M979E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T871U<R`@
M5&AE(&YE=R!E=F5N="!S=&%T=7,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=%-T871U<R@D<W1A='5S*0H@("`@>PH@("`@("`@("1T:&ES+3YS=&%T=7,@
M/2`D<W1A='5S.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@96YT
M:7)E(&%T=&5N9&5E(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D871T96YD965S("!4:&4@;F5W(&%T=&5N9&5E<R!A<G)A>2X@5&AI<R!S
M:&]U;&0@8F4@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@8V]R<F5C="!F;W)M870@=&\@879O:60@9')I=F5R('!R;V)L96US+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971!='1E;F1E97,H)&%T=&5N9&5E<RD*
M("`@('L*("`@("`@("`D=&AI<RT^871T96YD965S(#T@)&%T=&5N9&5E<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!N97<@871T96YD964@=&\@
M=&AE(&-U<G)E;G0@979E;G0N(%1H:7,@=VEL;"!O=F5R=W)I=&4@86X*("`@
M("`J(&5X:7-T:6YG(&%T=&5N9&5E(&EF(&]N92!E>&ES=',@=VET:"!T:&4@
M<V%M92!E;6%I;"!A9&1R97-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&5M86EL("`@("`@("!4:&4@96UA:6P@861D<F5S<R!O9B!T:&4@871T
M96YD964N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D871T96YD86YC92`@5&AE
M(&%T=&5N9&%N8V4@8V]D92!O9B!T:&4@871T96YD964N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<F5S<&]N<V4@("`@5&AE(')E<W!O;G-E(&-O9&4@;V8@
M=&AE(&%T=&5N9&5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1!='1E;F1E
M92@D96UA:6PL("1A='1E;F1A;F-E+"`D<F5S<&]N<V4I"B`@("!["B`@("`@
M("`@:68@*"1A='1E;F1A;F-E(#T]($M23TY/3$E42%]005)47TE'3D]212D@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%T=&5N9&5E<ULD96UA
M:6Q=*2D@>PH@("`@("`@("`@("`@("`@)&%T=&5N9&%N8V4@/2`D=&AI<RT^
M871T96YD965S6R1E;6%I;%U;)V%T=&5N9&%N8V4G73L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1A='1E;F1A;F-E(#T@2U)/3D],
M251(7U!!4E1?4D5154E2140["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YA='1E;F1E97-;)&5M86EL72`](&%R<F%Y*`H@("`@
M("`@("`@("`G871T96YD86YC92<@/3X@)&%T=&5N9&%N8V4L"B`@("`@("`@
M("`@("=R97-P;VYS92<@/3X@)')E<W!O;G-E"B`@("`@("`@*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;6]V97,@=&AE('-P96-I9FEE9"!A='1E;F1E
M92!F<F]M('1H92!C=7)R96YT(&5V96YT+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&5M86EL("!4:&4@96UA:6P@861D<F5S<R!O9B!T:&4@871T
M96YD964N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94%T=&5N9&5E*"1E
M;6%I;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%T=&5N9&5E
M<ULD96UA:6Q=*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^871T96YD
M965S6R1E;6%I;%TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&5N=&ER92!A='1E;F1E97,@87)R87DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@02!C;W!Y(&]F('1H92!A='1E;F1E97,@
M87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%T=&5N9&5E<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YA='1E;F1E97,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@=&\@<V5E('=H971H97(@=&AE('-P96-I
M9FEE9"!A='1E;F1E92!I<R!A<W-O8VEA=&5D('=I=&@@=&AE"B`@("`@*B!C
M=7)R96YT(&5V96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5M
M86EL("!4:&4@96UA:6P@861D<F5S<R!O9B!T:&4@871T96YD964N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I
M960@871T96YD964@:7,@<')E<V5N="!F;W(@=&AI<PH@("`@("H@("`@("`@
M("`@("`@("`@("!E=F5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S071T
M96YD964H)&5M86EL*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI
M<RT^871T96YD965S6R1E;6%I;%TI.PH@("`@?0H*("`@(&9U;F-T:6]N('-E
M=$ME>7=O<F1S*"1K97EW;W)D<RD*("`@('L*("`@("`@("`D=&AI<RT^:V5Y
M=V]R9',@/2`D:V5Y=V]R9',["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T2V5Y
M=V]R9',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^:V5Y=V]R9',[
M"B`@("!]"@H@("`@9G5N8W1I;VX@:&%S2V5Y=V]R9"@D:V5Y=V]R9"D*("`@
M('L*("`@("`@("!R971U<FX@:6Y?87)R87DH)&ME>7=O<F0L("1T:&ES+3YK
M97EW;W)D<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:&%S4F5C=7)%;F0H*0H@
M("`@>PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/G)E8W5R16YD*2`F
M)B!I<W-E="@D=&AI<RT^<F5C=7)%;F0M/GEE87(I("8F("1T:&ES+3YR96-U
M<D5N9"T^>65A<B`A/2`Y.3DY*3L*("`@('T*"B`@("!F=6YC=&EO;B!I<T%L
M;$1A>2@I"B`@("!["B`@("`@("`@<F5T=7)N("@D=&AI<RT^<W1A<G0M/FAO
M=7(@/3T@,"`F)B`D=&AI<RT^<W1A<G0M/FUI;B`]/2`P("8F("1T:&ES+3YS
M=&%R="T^<V5C(#T](#`@)B8*("`@("`@("`@("`@("`@("1T:&ES+3YE;F0M
M/FAO=7(@/3T@,"`F)B`D=&AI<RT^96YD+3YM:6X@/3T@,"`F)B`D=&AI<RT^
M<W1A<G0M/G-E8R`]/2`P("8F"B`@("`@("`@("`@("`@("`H)'1H:7,M/F5N
M9"T^;61A>2`^("1T:&ES+3YS=&%R="T^;61A>2!\?`H@("`@("`@("`@("`@
M("`@("1T:&ES+3YE;F0M/FUO;G1H(#X@)'1H:7,M/G-T87)T+3YM;VYT:"!\
M?`H@("`@("`@("`@("`@("`@("1T:&ES+3YE;F0M/GEE87(@/B`D=&AI<RT^
M<W1A<G0M/GEE87(I*3L*("`@('T*"B`@("!F=6YC=&EO;B!S971!;&%R;2@D
M86QA<FTI"B`@("!["B`@("`@("`@)'1H:7,M/F%L87)M(#T@)&%L87)M.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$%L87)M*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/F%L87)M.PH@("`@?0H*("`@(&9U;F-T:6]N(')E861&
M;W)M*"D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S+"`D8TUA;F%G97([
M"@H@("`@("`@("\O(%-E92!I9B!I="=S(&$@;F5W(&5V96YT+@H@("`@("`@
M(&EF("@A)'1H:7,M/FES26YI=&EA;&EZ960H*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V5T0W)E871O<DED*$%U=&@Z.F=E=$%U=&@H*2D["B`@("`@("`@
M?0H*("`@("`@("`O+R!"87-I8R!F:65L9',N"B`@("`@("`@)'1H:7,M/G-E
M=%1I=&QE*%5T:6PZ.F=E=$9O<FU$871A*"=T:71L92<L("1T:&ES+3YT:71L
M92DI.PH@("`@("`@("1T:&ES+3YS971$97-C<FEP=&EO;BA5=&EL.CIG971&
M;W)M1&%T82@G9&5S8W)I<'1I;VXG+"`D=&AI<RT^9&5S8W)I<'1I;VXI*3L*
M("`@("`@("`D=&AI<RT^<V5T3&]C871I;VXH571I;#HZ9V5T1F]R;41A=&$H
M)VQO8V%T:6]N)RP@)'1H:7,M/FQO8V%T:6]N*2D["B`@("`@("`@)'1H:7,M
M/G-E=$ME>7=O<F1S*%5T:6PZ.F=E=$9O<FU$871A*"=K97EW;W)D<R<L("1T
M:&ES+3YK97EW;W)D<RDI.PH*("`@("`@("`O+R!#871E9V]R>2X*("`@("`@
M("!I9B`H)&YE=U]C871E9V]R>2`](%5T:6PZ.F=E=$9O<FU$871A*"=N97=?
M8V%T96=O<GDG*2D@>PH@("`@("`@("`@("`D;F5W7V-A=&5G;W)Y(#T@)&--
M86YA9V5R+3YA9&0H)&YE=U]C871E9V]R>2D["B`@("`@("`@("`@(&EF("@D
M;F5W7V-A=&5G;W)Y*2!["B`@("`@("`@("`@("`@("`D8V%T96=O<GD@/2`D
M;F5W7V-A=&5G;W)Y.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&-A=&5G;W)Y(#T@571I;#HZ9V5T1F]R;41A=&$H)V-A
M=&5G;W)Y)RP@)'1H:7,M/F-A=&5G;W)Y*3L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/G-E=$-A=&5G;W)Y*"1C871E9V]R>2D["@H@("`@("`@("\O(%-T
M871U<RX*("`@("`@("`D=&AI<RT^<V5T4W1A='5S*%5T:6PZ.F=E=$9O<FU$
M871A*"=S=&%T=7,G+"`D=&AI<RT^<W1A='5S*2D["@H@("`@("`@("\O($%T
M=&5N9&5E<RX*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=A='1E;F1E
M97,G72D@)B8@:7-?87)R87DH)%]315-324].6R=A='1E;F1E97,G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/G-E=$%T=&5N9&5E<R@D7U-%4U-)3TY;)V%T
M=&5N9&5E<R==*3L*("`@("`@("!]"@H@("`@("`@("\O($5V96YT('-T87)T
M+@H@("`@("`@("1S=&%R="`](%5T:6PZ.F=E=$9O<FU$871A*"=S=&%R="<I
M.PH@("`@("`@("1S=&%R=%]Y96%R(#T@)'-T87)T6R=Y96%R)UT["B`@("`@
M("`@)'-T87)T7VUO;G1H(#T@)'-T87)T6R=M;VYT:"==.PH@("`@("`@("1S
M=&%R=%]D87D@/2`D<W1A<G1;)V1A>2==.PH@("`@("`@("1S=&%R=%]H;W5R
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W-T87)T7VAO=7(G*3L*("`@("`@("`D
M<W1A<G1?;6EN(#T@571I;#HZ9V5T1F]R;41A=&$H)W-T87)T7VUI;B<I.PH@
M("`@("`@("1A;5]P;2`](%5T:6PZ.F=E=$9O<FU$871A*"=A;5]P;2<I.PH*
M("`@("`@("!I9B`H(21P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G*2D@
M>PH@("`@("`@("`@("!I9B`H)&%M7W!M(#T]("=032<I('L*("`@("`@("`@
M("`@("`@(&EF("@D<W1A<G1?:&]U<B`A/2`Q,BD@>PH@("`@("`@("`@("`@
M("`@("`@("1S=&%R=%]H;W5R("L](#$R.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V5I9B`H)'-T87)T7VAO=7(@/3T@,3(I('L*("`@
M("`@("`@("`@("`@("1S=&%R=%]H;W5R(#T@,#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=E;F1?
M;W)?9'5R)RD@/3T@,2D@>PH@("`@("`@("`@("!I9B`H571I;#HZ9V5T1F]R
M;41A=&$H)W=H;VQE7V1A>2<I(#T](#$I('L*("`@("`@("`@("`@("`@("1S
M=&%R=%]H;W5R(#T@,#L*("`@("`@("`@("`@("`@("1S=&%R=%]M:6X@/2`P
M.PH@("`@("`@("`@("`@("`@)&1U<E]D87D@/2`P.PH@("`@("`@("`@("`@
M("`@)&1U<E]H;W5R(#T@,C0["B`@("`@("`@("`@("`@("`D9'5R7VUI;B`]
M(#`["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9'5R
M7V1A>2`]("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)V1U<E]D87DG*3L*("`@
M("`@("`@("`@("`@("1D=7)?:&]U<B`]("AI;G0I571I;#HZ9V5T1F]R;41A
M=&$H)V1U<E]H;W5R)RD["B`@("`@("`@("`@("`@("`D9'5R7VUI;B`]("AI
M;G0I571I;#HZ9V5T1F]R;41A=&$H)V1U<E]M:6XG*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G-T87)T(#T@)FYE=R!(;W)D
M95]$871E*&%R<F%Y*"=H;W5R)R`]/B`D<W1A<G1?:&]U<BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUI;B<@/3X@
M)'-T87)T7VUI;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VUO;G1H)R`]/B`D<W1A<G1?;6]N=&@L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]
M/B`D<W1A<G1?9&%Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G>65A<B<@/3X@)'-T87)T7WEE87(I*3L*("`@("`@
M("`D=&AI<RT^<W1A<G0M/F-O<G)E8W0H*3L*"B`@("`@("`@:68@*%5T:6PZ
M.F=E=$9O<FU$871A*"=E;F1?;W)?9'5R)RD@/3T@,2D@>PH@("`@("`@("`@
M("`O+R!%=F5N="!D=7)A=&EO;BX*("`@("`@("`@("`@)'1H:7,M/F5N9"`]
M("9N97<@2&]R9&5?1&%T92AA<G)A>2@G:&]U<B<@/3X@)'-T87)T7VAO=7(@
M*R`D9'5R7VAO=7(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VUI;B<@/3X@)'-T87)T7VUI;B`K("1D=7)?;6EN
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=M;VYT:"<@/3X@)'-T87)T7VUO;G1H+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B`D<W1A
M<G1?9&%Y("L@)&1U<E]D87DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)WEE87(G(#T^("1S=&%R=%]Y96%R*2D[
M"B`@("`@("`@("`@("1T:&ES+3YE;F0M/F-O<G)E8W0H*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!%=F5N="!E;F0N"B`@("`@("`@("`@
M("1E;F0@/2!5=&EL.CIG971&;W)M1&%T82@G96YD)RD["B`@("`@("`@("`@
M("1E;F1?>65A<B`]("1E;F1;)WEE87(G73L*("`@("`@("`@("`@)&5N9%]M
M;VYT:"`]("1E;F1;)VUO;G1H)UT["B`@("`@("`@("`@("1E;F1?9&%Y(#T@
M)&5N9%LG9&%Y)UT["B`@("`@("`@("`@("1E;F1?:&]U<B`](%5T:6PZ.F=E
M=$9O<FU$871A*"=E;F1?:&]U<B<I.PH@("`@("`@("`@("`D96YD7VUI;B`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=E;F1?;6EN)RD["B`@("`@("`@("`@("1E
M;F1?86U?<&T@/2!5=&EL.CIG971&;W)M1&%T82@G96YD7V%M7W!M)RD["@H@
M("`@("`@("`@("!I9B`H(21P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G
M*2D@>PH@("`@("`@("`@("`@("`@:68@*"1E;F1?86U?<&T@/3T@)U!-)RD@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D96YD7VAO=7(@(3T@,3(I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&5N9%]H;W5R("L](#$R.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M96YD7VAO=7(@/3T@,3(I('L*("`@("`@("`@("`@("`@("`@("`D96YD7VAO
M=7(@/2`P.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D=&AI<RT^96YD(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=H
M;W5R)R`]/B`D96YD7VAO=7(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VUI;B<@/3X@)&5N9%]M:6XL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUO
M;G1H)R`]/B`D96YD7VUO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B`D96YD7V1A>2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M>65A<B<@/3X@)&5N9%]Y96%R*2D["B`@("`@("`@("`@("1T:&ES+3YE;F0M
M/F-O<G)E8W0H*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YE;F0M/G1I;65S
M=&%M<"@I(#P@)'1H:7,M/G-T87)T+3YT:6UE<W1A;7`H*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F5N9"`](%5T:6PZ.F-L;VYE3V)J96-T*"1T:&ES
M+3YS=&%R="D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M($%L87)M+@H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G86QA<FTG
M*2`]/2`Q*2!["B`@("`@("`@("`@("1T:&ES+3YS971!;&%R;2A5=&EL.CIG
M971&;W)M1&%T82@G86QA<FU?=F%L=64G*2`J(%5T:6PZ.F=E=$9O<FU$871A
M*"=A;&%R;5]U;FET)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3YS971!;&%R;2@P*3L*("`@("`@("!]"@H@("`@("`@("\O(%)E
M8W5R<F5N8V4N"B`@("`@("`@)')E8W5R(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W)E8W5R)RD["B`@("`@("`@:68@*"%I<U]N=6QL*"1R96-U<BD@)B8@)')E
M8W5R("$]/2`G)RD@>PH@("`@("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A
M=&$H)W)E8W5R7V5N9&1A=&5?='EP92<I(#T]("=N;VYE)RD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G)E8W5R16YD(#T@;G5L;#L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R96-U<E]E;F1D871E(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W)E8W5R7V5N9&1A=&4G*3L*("`@("`@("`@("`@
M("`@("1R96-U<E]E;F1D871E7WEE87(@/2`D<F5C=7)?96YD9&%T95LG>65A
M<B==.PH@("`@("`@("`@("`@("`@)')E8W5R7V5N9&1A=&5?;6]N=&@@/2`D
M<F5C=7)?96YD9&%T95LG;6]N=&@G73L*("`@("`@("`@("`@("`@("1R96-U
M<E]E;F1D871E7V1A>2`]("1R96-U<E]E;F1D871E6R=D87DG73L*"B`@("`@
M("`@("`@("`@("`D=&AI<RT^<F5C=7)%;F0@/2`F;F5W($AO<F1E7T1A=&4H
M87)R87DH)VAO=7(G(#T^(#$L("=M:6XG(#T^(#$L("=S96,G(#T^(#$L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VUO;G1H)R`]/B`D<F5C=7)?96YD9&%T95]M;VYT:"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;61A>2<@/3X@)')E8W5R7V5N9&1A=&5?9&%Y+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=Y96%R)R`]/B`D<F5C=7)?96YD9&%T95]Y96%R*2D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<F5C=7)%;F0M/F-O<G)E8W0H*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'1H:7,M/G-E=%)E8W5R5'EP92@D<F5C=7(I
M.PH@("`@("`@("`@("!S=VET8V@@*"1R96-U<BD@>PH@("`@("`@("`@("!C
M87-E($M23TY/3$E42%]214-54E]$04E,63H*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971296-U<DEN=&5R=F%L*%5T:6PZ.F=E=$9O<FU$871A*"=R96-U
M<E]D86EL>5]I;G1E<G9A;"<L(#$I*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92!+4D].3TQ)5$A?4D5#55)?5T5%2TQ9.@H@
M("`@("`@("`@("`@("`@)'=E96ML>2`](%5T:6PZ.F=E=$9O<FU$871A*"=W
M965K;'DG*3L*("`@("`@("`@("`@("`@("1W965K9&%Y<R`](#`["B`@("`@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)'=E96ML>2DI('L*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=V5E:VQY(&%S("1D87DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'=E96MD87ES('P]("1D87D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("@D=V5E:V1A>7,@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@
M("\O(%-U;F1A>2!S=&%R=',@870@,"X*("`@("`@("`@("`@("`@("`@("!S
M=VET8V@@*"1T:&ES+3YS=&%R="T^9&%Y3V97965K*"DI('L*("`@("`@("`@
M("`@("`@("`@("!C87-E(#`Z("1W965K9&%Y<R!\/2!(3U)$15]$051%7TU!
M4TM?4U5.1$%9.R!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E(#$Z
M("1W965K9&%Y<R!\/2!(3U)$15]$051%7TU!4TM?34].1$%9.R!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!C87-E(#(Z("1W965K9&%Y<R!\/2!(3U)$
M15]$051%7TU!4TM?5%5%4T1!63L@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@8V%S92`S.B`D=V5E:V1A>7,@?#T@2$]21$5?1$%415]-05-+7U=%1$Y%
M4T1!63L@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`T.B`D=V5E
M:V1A>7,@?#T@2$]21$5?1$%415]-05-+7U1(55)31$%9.R!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!C87-E(#4Z("1W965K9&%Y<R!\/2!(3U)$15]$
M051%7TU!4TM?1E))1$%9.R!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C
M87-E(#8Z("1W965K9&%Y<R!\/2!(3U)$15]$051%7TU!4TM?4T%455)$05D[
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4F5C=7));G1E<G9A;"A5
M=&EL.CIG971&;W)M1&%T82@G<F5C=7)?=V5E:VQY7VEN=&5R=F%L)RP@,2DI
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%)E8W5R3VY$87DH)'=E96MD
M87ES*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92!+4D].3TQ)5$A?4D5#55)?1$%97T]&7TU/3E1(.@H@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=%)E8W5R26YT97)V86PH571I;#HZ9V5T1F]R;41A=&$H
M)W)E8W5R7V1A>5]O9E]M;VYT:%]I;G1E<G9A;"<L(#$I*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!+4D].3TQ)5$A?4D5#
M55)?5T5%2U]/1E]-3TY42#H*("`@("`@("`@("`@("`@("1T:&ES+3YS9712
M96-U<DEN=&5R=F%L*%5T:6PZ.F=E=$9O<FU$871A*"=R96-U<E]W965K7V]F
M7VUO;G1H7VEN=&5R=F%L)RP@,2DI.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E($M23TY/3$E42%]214-54E]914%23%DZ"B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T4F5C=7));G1E<G9A;"A5=&EL.CIG
M971&;W)M1&%T82@G<F5C=7)?>65A<FQY7VEN=&5R=F%L)RP@,2DI.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YI;FET:6%L:7IE9"`]('1R=64["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T1'5R871I;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D
M9'5R871I;VX@/2!N=6QL.PH@("`@("`@(&EF("AI<W-E="@D9'5R871I;VXI
M*2!["B`@("`@("`@("`@(')E='5R;B`D9'5R871I;VX["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1H:7,M/FES26YI=&EA;&EZ960H*2D@>PH@("`@("`@
M("`@("`D9'5R7V1A>5]M871C:"`]("1T:&ES+3YE;F0M/FUD87D@+2`D=&AI
M<RT^<W1A<G0M/FUD87D["B`@("`@("`@("`@("1D=7)?:&]U<E]M871C:"`]
M("1T:&ES+3YE;F0M/FAO=7(@+2`D=&AI<RT^<W1A<G0M/FAO=7(["B`@("`@
M("`@("`@("1D=7)?;6EN7VUA=&-H(#T@)'1H:7,M/F5N9"T^;6EN("T@)'1H
M:7,M/G-T87)T+3YM:6X["B`@("`@("`@("`@('=H:6QE("@D9'5R7VUI;E]M
M871C:"`\(#`I('L*("`@("`@("`@("`@("`@("1D=7)?;6EN7VUA=&-H("L]
M(#8P.PH@("`@("`@("`@("`@("`@+2TD9'5R7VAO=7)?;6%T8V@["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@=VAI;&4@*"1D=7)?:&]U<E]M871C:"`\
M(#`I('L*("`@("`@("`@("`@("`@("1D=7)?:&]U<E]M871C:"`K/2`R-#L*
M("`@("`@("`@("`@("`@("TM)&1U<E]D87E?;6%T8V@["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1D=7)?:&]U<E]M871C:"`]/2`P("8F("1D
M=7)?;6EN7VUA=&-H(#T](#`*("`@("`@("`@("`@("`@("8F("1T:&ES+3YE
M;F0M/FUD87D@+2`D=&AI<RT^<W1A<G0M/FUD87D@/3T@,2D@>PH@("`@("`@
M("`@("`@("`@)&1U<E]D87E?;6%T8V@@/2`P.PH@("`@("`@("`@("`@("`@
M)&1U<E]H;W5R7VUA=&-H(#T@,C,["B`@("`@("`@("`@("`@("`D9'5R7VUI
M;E]M871C:"`](#8P.PH@("`@("`@("`@("`@("`@)'=H;VQE7V1A>5]M871C
M:"`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=VAO;&5?9&%Y7VUA=&-H(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9'5R7V1A>5]M871C:"`](#`[
M"B`@("`@("`@("`@("1D=7)?:&]U<E]M871C:"`](#$["B`@("`@("`@("`@
M("1D=7)?;6EN7VUA=&-H(#T@,#L*("`@("`@("`@("`@)'=H;VQE7V1A>5]M
M871C:"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&1U<F%T:6]N(#T@
M;F5W('-T9$-L87-S.PH@("`@("`@("1D=7)A=&EO;BT^9&%Y(#T@)&1U<E]D
M87E?;6%T8V@["B`@("`@("`@)&1U<F%T:6]N+3YH;W5R(#T@)&1U<E]H;W5R
M7VUA=&-H.PH@("`@("`@("1D=7)A=&EO;BT^;6EN(#T@)&1U<E]M:6Y?;6%T
M8V@["B`@("`@("`@)&1U<F%T:6]N+3YW:&]L941A>2`]("1W:&]L95]D87E?
M;6%T8V@["@H@("`@("`@(')E='5R;B`D9'5R871I;VX["B`@("!]"@H@("`@
M9G5N8W1I;VX@:'1M;"@D<')O<&5R='DI"B`@("!["B`@("`@("`@9VQO8F%L
M("1P<F5F<SL*"B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@I.PH@("`@("`@
M("1A='1R:6)U=&5S(#T@)R<["B`@("`@("`@)'-E;"`](&9A;'-E.PH*("`@
M("`@("!S=VET8V@@*"1P<F]P97)T>2D@>PH@("`@("`@(&-A<V4@)W-T87)T
M6WEE87)=)SH*("`@("`@("`@("`@<F5T=7)N("`G/&EN<'5T(&YA;64](B<@
M+B`D<')O<&5R='D@+B`G(B!V86QU93TB)R`N("1T:&ES+3YS=&%R="T^>65A
M<B`N"B`@("`@("`@("`@("`@("`G(B!T>7!E/2)T97AT(B!O;F-H86YG93TB
M)R`N("1T:&ES+3YJ<R@D<')O<&5R='DI("X*("`@("`@("`@("`@("`@("<B
M(&ED/2(G("X@)'!R;W!E<G1Y("X@)R(@<VEZ93TB-"(@;6%X;&5N9W1H/2(T
M(B`O/B<["@H@("`@("`@(&-A<V4@)W-T87)T6VUO;G1H72<Z"B`@("`@("`@
M("`@("1S96P@/2`D=&AI<RT^<W1A<G0M/FUO;G1H.PH@("`@("`@("`@("!F
M;W(@*"1I(#T@,3L@)&D@/"`Q,SL@*RLD:2D@>PH@("`@("`@("`@("`@("`@
M)&]P=&EO;G-;)&E=(#T@<W1R9G1I;64H)R5B)RP@;6MT:6UE*#$L(#$L(#$L
M("1I+"`Q*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&%T=')I8G5T
M97,@/2`G(&]N8VAA;F=E/2(G("X@)'1H:7,M/FIS*"1P<F]P97)T>2D@+B`G
M(B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=S=&%R=%MD
M87E=)SH*("`@("`@("`@("`@)'-E;"`]("1T:&ES+3YS=&%R="T^;61A>3L*
M("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P@,S([("LK)&DI('L*("`@
M("`@("`@("`@("`@("1O<'1I;VYS6R1I72`]("1I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1A='1R:6)U=&5S(#T@)R!O;F-H86YG93TB)R`N("1T
M:&ES+3YJ<R@D<')O<&5R='DI("X@)R(G.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G<W1A<G1?:&]U<B<Z"B`@("`@("`@("`@("1S96P@
M/2`H:6YT*61A=&4H)'!R969S+3YG971686QU92@G='=E;G1Y1F]U<B<I(#\@
M)T<G(#H@)V<G+"`D=&AI<RT^<W1A<G0M/G1I;65S=&%M<"@I*3L*("`@("`@
M("`@("`@)&AO=7)?;6EN(#T@)'!R969S+3YG971686QU92@G='=E;G1Y1F]U
M<B<I(#\@,"`Z(#$["B`@("`@("`@("`@("1H;W5R7VUA>"`]("1P<F5F<RT^
M9V5T5F%L=64H)W1W96YT>49O=7(G*2`_(#(T(#H@,3,["B`@("`@("`@("`@
M(&9O<B`H)&D@/2`D:&]U<E]M:6X[("1I(#P@)&AO=7)?;6%X.R`K*R1I*2![
M"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULD:5T@/2`D:3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D871T<FEB=71E<R`]("<@;VYC:&%N9V4](F1O
M8W5M96YT+F5V96YT+G=H;VQE7V1A>2YC:&5C:V5D(#T@9F%L<V4[('5P9&%T
M945N9$1A=&4H*3LB)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)W-T87)T7VUI;B<Z"B`@("`@("`@("`@("1S96P@/2!S<')I;G1F*"<E
M,#)D)RP@)'1H:7,M/G-T87)T+3YM:6XI.PH@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`Q,CL@*RLD:2D@>PH@("`@("`@("`@("`@("`@)&UI;B`]
M('-P<FEN=&8H)R4P,F0G+"`D:2`J(#4I.PH@("`@("`@("`@("`@("`@)&]P
M=&EO;G-;)&UI;ET@/2`D;6EN.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1A='1R:6)U=&5S(#T@)R!O;F-H86YG93TB9&]C=6UE;G0N979E;G0N=VAO
M;&5?9&%Y+F-H96-K960@/2!F86QS93L@=7!D871E16YD1&%T92@I.R(G.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G96YD6WEE87)=)SH*
M("`@("`@("`@("`@<F5T=7)N("`G/&EN<'5T(&YA;64](B<@+B`D<')O<&5R
M='D@+B`G(B!V86QU93TB)R`N("1T:&ES+3YE;F0M/GEE87(@+@H@("`@("`@
M("`@("`@("`@)R(@='EP93TB=&5X="(@;VYC:&%N9V4](B<@+B`D=&AI<RT^
M:G,H)'!R;W!E<G1Y*2`N"B`@("`@("`@("`@("`@("`G(B!I9#TB)R`N("1P
M<F]P97)T>2`N("<B('-I>F4](C0B(&UA>&QE;F=T:#TB-"(@+SXG.PH*("`@
M("`@("!C87-E("=E;F1;;6]N=&A=)SH*("`@("`@("`@("`@)'-E;"`]("1T
M:&ES+3YI<TEN:71I86QI>F5D*"D@/R`D=&AI<RT^96YD+3YM;VYT:"`Z("1T
M:&ES+3YS=&%R="T^;6]N=&@["B`@("`@("`@("`@(&9O<B`H)&D@/2`Q.R`D
M:2`\(#$S.R`K*R1I*2!["B`@("`@("`@("`@("`@("`D;W!T:6]N<ULD:5T@
M/2!S=')F=&EM92@G)6(G+"!M:W1I;64H,2P@,2P@,2P@)&DL(#$I*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D871T<FEB=71E<R`]("<@;VYC:&%N
M9V4](B<@+B`D=&AI<RT^:G,H)'!R;W!E<G1Y*2`N("<B)SL*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)V5N9%MD87E=)SH*("`@("`@("`@
M("`@)'-E;"`]("1T:&ES+3YI<TEN:71I86QI>F5D*"D@/R`D=&AI<RT^96YD
M+3YM9&%Y(#H@)'1H:7,M/G-T87)T+3YM9&%Y.PH@("`@("`@("`@("!F;W(@
M*"1I(#T@,3L@)&D@/"`S,CL@*RLD:2D@>PH@("`@("`@("`@("`@("`@)&]P
M=&EO;G-;)&E=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&%T
M=')I8G5T97,@/2`G(&]N8VAA;F=E/2(G("X@)'1H:7,M/FIS*"1P<F]P97)T
M>2D@+B`G(B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=E
M;F1?:&]U<B<Z"B`@("`@("`@("`@("1S96P@/2`D=&AI<RT^:7-);FET:6%L
M:7IE9"@I(#\*("`@("`@("`@("`@("`@("AI;G0I9&%T92@D<')E9G,M/F=E
M=%9A;'5E*"=T=V5N='E&;W5R)RD@/R`G1R<@.B`G9R<L("1T:&ES+3YE;F0M
M/G1I;65S=&%M<"@I*2`Z"B`@("`@("`@("`@("`@("`H:6YT*61A=&4H)'!R
M969S+3YG971686QU92@G='=E;G1Y1F]U<B<I(#\@)T<G(#H@)V<G+"`D=&AI
M<RT^<W1A<G0M/G1I;65S=&%M<"@I*2`K(#$["B`@("`@("`@("`@("1H;W5R
M7VUI;B`]("1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G*2`_(#`@.B`Q
M.PH@("`@("`@("`@("`D:&]U<E]M87@@/2`D<')E9G,M/F=E=%9A;'5E*"=T
M=V5N='E&;W5R)RD@/R`R-"`Z(#$S.PH@("`@("`@("`@("!F;W(@*"1I(#T@
M)&AO=7)?;6EN.R`D:2`\("1H;W5R7VUA>#L@*RLD:2D@>PH@("`@("`@("`@
M("`@("`@)&]P=&EO;G-;)&E=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&%T=')I8G5T97,@/2`G(&]N8VAA;F=E/2)U<&1A=&5$=7)A=&EO
M;B@I.R!D;V-U;65N="YE=F5N="YE;F1?;W)?9'5R6S!=+F-H96-K960@/2!T
M<G5E(B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=E;F1?
M;6EN)SH*("`@("`@("`@("`@)'-E;"`]("1T:&ES+3YI<TEN:71I86QI>F5D
M*"D@/R`D=&AI<RT^96YD+3YM:6X@.B`D=&AI<RT^<W1A<G0M/FUI;CL*("`@
M("`@("`@("`@)'-E;"`]('-P<FEN=&8H)R4P,F0G+"`D<V5L*3L*("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@,3([("LK)&DI('L*("`@("`@("`@
M("`@("`@("1M:6X@/2!S<')I;G1F*"<E,#)D)RP@)&D@*B`U*3L*("`@("`@
M("`@("`@("`@("1O<'1I;VYS6R1M:6Y=(#T@)&UI;CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D871T<FEB=71E<R`]("<@;VYC:&%N9V4](G5P9&%T
M941U<F%T:6]N*"D[(&1O8W5M96YT+F5V96YT+F5N9%]O<E]D=7);,%TN8VAE
M8VME9"`]('1R=64B)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)V1U<E]D87DG.@H@("`@("`@("`@("`D9'5R(#T@)'1H:7,M/F=E=$1U
M<F%T:6]N*"D["B`@("`@("`@("`@("1S96P@/2`D9'5R+3YD87D["B`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#,V-CL@*RLD:2D@>PH@("`@("`@
M("`@("`@("`@)&]P=&EO;G-;)&E=(#T@)&D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&%T=')I8G5T97,@/2`G(&]N8VAA;F=E/2)D;V-U;65N="YE
M=F5N="YW:&]L95]D87DN8VAE8VME9"`](&9A;'-E.R!U<&1A=&5%;F1$871E
M*"D[(&1O8W5M96YT+F5V96YT+F5N9%]O<E]D=7);,5TN8VAE8VME9"`]('1R
M=64[(B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=D=7)?
M:&]U<B<Z"B`@("`@("`@("`@("1D=7(@/2`D=&AI<RT^9V5T1'5R871I;VXH
M*3L*("`@("`@("`@("`@)'-E;"`]("1D=7(M/FAO=7(["B`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(#(T.R`K*R1I*2!["B`@("`@("`@("`@("`@
M("`D;W!T:6]N<ULD:5T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D871T<FEB=71E<R`]("<@;VYC:&%N9V4](F1O8W5M96YT+F5V96YT+G=H
M;VQE7V1A>2YC:&5C:V5D(#T@9F%L<V4[('5P9&%T945N9$1A=&4H*3L@9&]C
M=6UE;G0N979E;G0N96YD7V]R7V1U<ELQ72YC:&5C:V5D(#T@=')U93LB)SL*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V1U<E]M:6XG.@H@
M("`@("`@("`@("`D9'5R(#T@)'1H:7,M/F=E=$1U<F%T:6]N*"D["B`@("`@
M("`@("`@("1S96P@/2`D9'5R+3YM:6X["B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(#$S.R`K*R1I*2!["B`@("`@("`@("`@("`@("`D;6EN(#T@
M<W!R:6YT9B@G)3`R9"<L("1I("H@-2D["B`@("`@("`@("`@("`@("`D;W!T
M:6]N<ULD;6EN72`]("1M:6X["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&%T=')I8G5T97,@/2`G(&]N8VAA;F=E/2)D;V-U;65N="YE=F5N="YW:&]L
M95]D87DN8VAE8VME9"`](&9A;'-E.W5P9&%T945N9$1A=&4H*3MD;V-U;65N
M="YE=F5N="YE;F1?;W)?9'5R6S%=+F-H96-K960]=')U92(G.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G<F5C=7)?96YD9&%T95MY96%R
M72<Z"B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-);FET:6%L:7IE9"@I*2![
M"B`@("`@("`@("`@("`@("`D96YD(#T@)'1H:7,M/FAA<U)E8W5R16YD*"D@
M/R`D=&AI<RT^<F5C=7)%;F0M/GEE87(@.B`D=&AI<RT^96YD+3YY96%R.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&5N9"`]("1T
M:&ES+3YS=&%R="T^>65A<CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@("<\:6YP=70@;F%M93TB)R`N("1P<F]P97)T>2`N("<B('9A;'5E
M/2(G("X@)&5N9"`N"B`@("`@("`@("`@("`@("`G(B!T>7!E/2)T97AT(B!O
M;F-H86YG93TB)R`N("1T:&ES+3YJ<R@D<')O<&5R='DI("X*("`@("`@("`@
M("`@("`@("<B(&ED/2(G("X@)'!R;W!E<G1Y("X@)R(@<VEZ93TB-"(@;6%X
M;&5N9W1H/2(T(B`O/B<["@H@("`@("`@(&-A<V4@)W)E8W5R7V5N9&1A=&5;
M;6]N=&A=)SH*("`@("`@("`@("`@:68@*"1T:&ES+3YI<TEN:71I86QI>F5D
M*"DI('L*("`@("`@("`@("`@("`@("1S96P@/2`D=&AI<RT^:&%S4F5C=7)%
M;F0H*2`_("1T:&ES+3YR96-U<D5N9"T^;6]N=&@@.B`D=&AI<RT^96YD+3YM
M;VYT:#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S
M96P@/2`D=&AI<RT^<W1A<G0M/FUO;G1H.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\(#$S.R`K*R1I*2!["B`@("`@("`@
M("`@("`@("`D;W!T:6]N<ULD:5T@/2!S=')F=&EM92@G)6(G+"!M:W1I;64H
M,2P@,2P@,2P@)&DL(#$I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M871T<FEB=71E<R`]("<@;VYC:&%N9V4](B<@+B`D=&AI<RT^:G,H)'!R;W!E
M<G1Y*2`N("<B)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)W)E8W5R7V5N9&1A=&5;9&%Y72<Z"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M:7-);FET:6%L:7IE9"@I*2!["B`@("`@("`@("`@("`@("`D<V5L(#T@)'1H
M:7,M/FAA<U)E8W5R16YD*"D@/R`D=&AI<RT^<F5C=7)%;F0M/FUD87D@.B`D
M=&AI<RT^96YD+3YM9&%Y.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'-E;"`]("1T:&ES+3YS=&%R="T^;61A>3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"`S,CL@*RLD:2D@
M>PH@("`@("`@("`@("`@("`@)&]P=&EO;G-;)&E=(#T@)&D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&%T=')I8G5T97,@/2`G(&]N8VAA;F=E/2(G
M("X@)'1H:7,M/FIS*"1P<F]P97)T>2D@+B`G(B<["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^7W9A<E)E;F1E
M<F5R*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O54DO5F%R
M4F5N9&5R97(N<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]V87)296YD97)E
M<B`]("9(;W)D95]525]687)296YD97)E<CHZ9F%C=&]R>2@G:'1M;"<I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("<\<V5L96-T(&YA;64](B<@+B`D
M<')O<&5R='D@+B`G(B<@+B`D871T<FEB=71E<R`N("<@:60](B<@+B`D<')O
M<&5R='D@+B`G(CXG("X*("`@("`@("`@("`@)'1H:7,M/E]V87)296YD97)E
M<BT^7W-E;&5C=$]P=&EO;G,H)&]P=&EO;G,L("1S96PI("X*("`@("`@("`@
M("`@)SPO<V5L96-T/B<["B`@("!]"@H@("`@9G5N8W1I;VX@:G,H)'!R;W!E
M<G1Y*0H@("`@>PH@("`@("`@('-W:71C:"`H)'!R;W!E<G1Y*2!["B`@("`@
M("`@8V%S92`G<W1A<G1;;6]N=&A=)SH*("`@("`@("!C87-E("=S=&%R=%MY
M96%R72<Z"B`@("`@("`@8V%S92`G<W1A<G1;9&%Y72<Z"B`@("`@("`@8V%S
M92`G<W1A<G0G.@H@("`@("`@("`@("!R971U<FX@)W5P9&%T95=D87DH7"=S
M=&%R=%]W9&%Y7"<I.R!D;V-U;65N="YE=F5N="YW:&]L95]D87DN8VAE8VME
M9"`](&9A;'-E.R!U<&1A=&5%;F1$871E*"D[)SL*"B`@("`@("`@8V%S92`G
M96YD6VUO;G1H72<Z"B`@("`@("`@8V%S92`G96YD6WEE87)=)SH*("`@("`@
M("!C87-E("=E;F1;9&%Y72<Z"B`@("`@("`@8V%S92`G96YD)SH*("`@("`@
M("`@("`@<F5T=7)N("=U<&1A=&579&%Y*%PG96YD7W=D87E<)RD[('5P9&%T
M941U<F%T:6]N*"D[(&1O8W5M96YT+F5V96YT+F5N9%]O<E]D=7);,%TN8VAE
M8VME9"`]('1R=64[)SL*"B`@("`@("`@8V%S92`G<F5C=7)?96YD9&%T95MM
M;VYT:%TG.@H@("`@("`@(&-A<V4@)W)E8W5R7V5N9&1A=&5;>65A<ETG.@H@
M("`@("`@(&-A<V4@)W)E8W5R7V5N9&1A=&5;9&%Y72<Z"B`@("`@("`@8V%S
M92`G<F5C=7)?96YD9&%T92<Z"B`@("`@("`@("`@(')E='5R;B`G=7!D871E
M5V1A>2A<)W)E8W5R7V5N9%]W9&%Y7"<I.R!D;V-U;65N="YE=F5N="YR96-U
M<E]E;F1D871E7W1Y<&5;,5TN8VAE8VME9"`]('1R=64[)SL*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T3&EN:R@D=&EM97-T86UP(#T@,"P@
M)&EC;VYS(#T@=')U92P@)&9R;VU?=7)L(#T@;G5L;"D*("`@('L*("`@("`@
M("!G;&]B86P@)'!R:6YT7W9I97<L("1P<F5F<RP@)')E9VES=')Y+"`D8TUA
M;F%G97(["@H@("`@("`@(&EF("@D9G)O;5]U<FP@/3T](&YU;&PI('L*("`@
M("`@("`@("`@)&9R;VU?=7)L(#T@2&]R9&4Z.G-E;&95<FPH=')U92P@9F%L
M<V4L('1R=64I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YR96UO=&5#86PI*2!["B`@("`@("`@("`@("1S:&%R92`](&9A;'-E.PH@
M("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=V:65W979E
M;G0N<&AP)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G979E;G1)1"<@/3X@)'1H:7,M/F5V96YT240L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-A;&5N9&%R
M)R`]/B`G*BIR96UO=&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=R96UO=&5#86PG(#T^("1T:&ES+3YR96UO=&5#
M86PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1I;65S=&%M<"<@/3X@)'1I;65S=&%M<"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7)L)R`]/B`D9G)O;5]U
M<FPI*3L*("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@D=7)L*3L*("`@("`@("`@("`@)&QI;FL@/2!(;W)D93HZ;&EN:U1O;VQT
M:7`H)'5R;"P@)'1H:7,M/F=E=%1I=&QE*"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG9713=&%T=7-#;&%S<R@I
M+"`G)RP@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YG9714;V]L=&EP*"DI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S:&%R92`])B`D1TQ/0D%,4ULG86QL7V-A;&5N9&%R<R==
M6R1T:&ES+3YG971#86QE;F1A<B@I73L*("`@("`@("`@("`@:68@*&ES7V$H
M)'-H87)E+"`G4$5!4E]%<G)O<B<I('Q\"B`@("`@("`@("`@("`@("`A)'-H
M87)E+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H*2P@4$5235-?4D5!
M1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F=E=$-R96%T;W))9"@I*2D@>PH@("`@("`@("`@("`@("`@)&QI;FL@
M/2`G)SL*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YE=F5N
M=$E$*2D@>PH@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<B@G=FEE=V5V96YT+G!H<"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=E=F5N=$E$)R`]/B`D=&AI<RT^
M979E;G1)1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-A;&5N9&%R)R`]/B`D=&AI<RT^9V5T0V%L96YD87(H
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1I;65S=&%M<"<@/3X@)'1I;65S=&%M<"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@
M)&9R;VU?=7)L*2D["B`@("`@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"1U<FPI.PH@("`@("`@("`@("`@("`@)&QI;FL@/2!(
M;W)D93HZ;&EN:U1O;VQT:7`H)'5R;"P@)'1H:7,M/G1I=&QE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E
M=%-T871U<T-L87-S*"DL("<G+"`G)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG9714;V]L=&EP*"DI.PH@
M("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/G1A<VM)1"DI('L*
M("`@("`@("`@("`@("`@("1L:6YK(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/FQI;FLH)W1A<VMS+W-H;W<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=&%S:R<@/3X@)'1H
M:7,M/G1A<VM)1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1A<VML:7-T)R`]/B`D=&AI<RT^
M=&%S:VQI<W1)1"DI.PH@("`@("`@("`@("`@("`@)&QI;FL@/2!(;W)D93HZ
M;&EN:RA(;W)D93HZ=7)L*"1L:6YK*2P@)R<L("=E=F5N="<I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QI;FL@/2`G)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&QI;FL@+CT@0&AT;6QS
M<&5C:6%L8VAA<G,H)'1H:7,M/F=E=%1I=&QE*"DL($5.5%]154]415,L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3DQ3.CIG971#:&%R
M<V5T*"DI.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/G)E;6]T94-A;"D@
M?'P*("`@("`@("`@("`@*"%I<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2`F
M)@H@("`@("`@("`@("`@)'-H87)E+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E
M=$%U=&@H*2P@4$5235-?4D5!1"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9V5T0W)E871O<DED*"DI("8F"B`@("`@("`@
M("`@("`H:7-S970H)'1H:7,M/F5V96YT240I('Q\"B`@("`@("`@("`@("`@
M:7-S970H)'1H:7,M/G1A<VM)1"DI*2D@>PH@("`@("`@("`@("`D;&EN:R`N
M/2`G/"]A/B<["B`@("`@("`@?0H*("`@("`@("!I9B`H)&EC;VYS("8F("1P
M<F5F<RT^9V5T5F%L=64H)W-H;W=?:6-O;G,G*2D@>PH@("`@("`@("`@("`D
M<W1A='5S(#T@)R<["B`@("`@("`@("`@(&EF("@D=&AI<RT^86QA<FTI('L*
M("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^86QA<FT@)2`Q,#`X,"`]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)&%L87)M7W9A;'5E(#T@)'1H:7,M
M/F%L87)M("\@,3`P.#`["B`@("`@("`@("`@("`@("`@("`@)'1I=&QE(#T@
M)&%L87)M7W9A;'5E(#T](#$@/PH@("`@("`@("`@("`@("`@("`@("`@("!?
M*")!;&%R;2`Q('=E96L@8F5F;W)E(BD@.@H@("`@("`@("`@("`@("`@("`@
M("`@("!S<')I;G1F*%\H(D%L87)M("5D('=E96MS(&)E9F]R92(I+"`D86QA
M<FU?=F%L=64I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YA
M;&%R;2`E(#$T-#`@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("1A;&%R
M;5]V86QU92`]("1T:&ES+3YA;&%R;2`O(#$T-#`["B`@("`@("`@("`@("`@
M("`@("`@)'1I=&QE(#T@)&%L87)M7W9A;'5E(#T](#$@/PH@("`@("`@("`@
M("`@("`@("`@("`@("!?*")!;&%R;2`Q(&1A>2!B969O<F4B*2`Z"B`@("`@
M("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B06QA<FT@)60@9&%Y<R!B
M969O<F4B*2P@)&%L87)M7W9A;'5E*3L*("`@("`@("`@("`@("`@('T@96QS
M96EF("@D=&AI<RT^86QA<FT@)2`V,"`]/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@)&%L87)M7W9A;'5E(#T@)'1H:7,M/F%L87)M("\@-C`["B`@("`@
M("`@("`@("`@("`@("`@)'1I=&QE(#T@)&%L87)M7W9A;'5E(#T](#$@/PH@
M("`@("`@("`@("`@("`@("`@("`@("!?*")!;&%R;2`Q(&AO=7(@8F5F;W)E
M(BD@.@H@("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F*%\H(D%L87)M
M("5D(&AO=7)S(&)E9F]R92(I+"`D86QA<FU?=F%L=64I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D86QA<FU?=F%L
M=64@/2`D=&AI<RT^86QA<FT["B`@("`@("`@("`@("`@("`@("`@)'1I=&QE
M(#T@)&%L87)M7W9A;'5E(#T](#$@/PH@("`@("`@("`@("`@("`@("`@("`@
M("!?*")!;&%R;2`Q(&UI;G5T92!B969O<F4B*2`Z"B`@("`@("`@("`@("`@
M("`@("`@("`@('-P<FEN=&8H7R@B06QA<FT@)60@;6EN=71E<R!B969O<F4B
M*2P@)&%L87)M7W9A;'5E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1S=&%T=7,@+CT@2&]R9&4Z.FEM9R@G86QA<FU?<VUA;&PN<&YG
M)RP@)'1I=&QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=T:71L92<@/3X@)'1I=&QE*2D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@A)'1H:7,M/FAA<U)E8W5R5'EP92A+4D].3TQ)
M5$A?4D5#55)?3D].12DI('L*("`@("`@("`@("`@("`@("1T:71L92`]($MR
M;VYO;&ET:#HZ<F5C=7)4;U-T<FEN9R@D=&AI<RT^<F5C=7)4>7!E*3L*("`@
M("`@("`@("`@("`@("1S=&%T=7,@+CT@2&]R9&4Z.FEM9R@G<F5C=7(N<&YG
M)RP@)'1I=&QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=T:71L92<@/3X@)'1I=&QE*2D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/F%T=&5N9&5E<RDI('L*
M("`@("`@("`@("`@("`@("1T:71L92`](&-O=6YT*"1T:&ES+3YA='1E;F1E
M97,I(#T](#$*("`@("`@("`@("`@("`@("`@("`_(%\H(C$@871T96YD964B
M*0H@("`@("`@("`@("`@("`@("`@(#H@<W!R:6YT9BA?*"(E<R!A='1E;F1E
M97,B*2P@8V]U;G0H)'1H:7,M/F%T=&5N9&5E<RDI.PH@("`@("`@("`@("`@
M("`@)'-T871U<R`N/2!(;W)D93HZ:6UG*"=A='1E;F1E97,N<&YG)RP@)'1I
M=&QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=T:71L92<@/3X@)'1I=&QE*2D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@A96UP='DH)'-T871U<RDI('L*("`@("`@("`@("`@("`@
M("1L:6YK("X]("<@)R`N("1S=&%T=7,["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@D<')I;G1?=FEE=R!\?`H@("`@("`@("`@("`@("`@:7-?
M82@D<VAA<F4L("=014%27T5R<F]R)RD@?'P*("`@("`@("`@("`@("`@("%I
M<W-E="@D=&AI<RT^979E;G1)1"DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D;&EN:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YR96UO=&5#86PI('Q\"B`@("`@("`@("`@("`@("`D<VAA<F4M
M/FAA<U!E<FUI<W-I;VXH075T:#HZ9V5T075T:"@I+"!015)-4U]%1$E4+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG
M971#<F5A=&]R260H*2DI('L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H)V5D:71E=F5N="YP:'`G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G979E;G1)1"<@
M/3X@)'1H:7,M/F5V96YT240L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=C86QE;F1A<B<@/3X@:7-S970H)'1H
M:7,M/G)E;6]T94-A;"D@/R`G*BIR96UO=&4G(#H@)'1H:7,M/F=E=$-A;&5N
M9&%R*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T:6UE<W1A;7`G(#T^("1T:6UE<W1A;7`L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<FPG
M(#T^("1F<F]M7W5R;"DI.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3YR96UO=&5#86PI*2!["B`@("`@("`@("`@("`@("`@("`@)'5R;"`]
M(%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G<F5M;W1E0V%L)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YR96UO=&5#86PI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&QI;FL@+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"1U<FPI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W!R:6YT9BA?*")%9&ET("5S(BDL("1T:&ES+3YT:71L
M92DI("X*("`@("`@("`@("`@("`@("`@("!(;W)D93HZ:6UG*"=E9&ET+7-M
M86QL+G!N9R<L(%\H(D5D:70B*2P@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N
M"B`@("`@("`@("`@("`@("`@("`@)SPO83XG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G)E;6]T94-A;"D@)B8*("`@
M("`@("`@("`@("`@("1S:&%R92T^:&%S4&5R;6ES<VEO;BA!=71H.CIG971!
M=71H*"DL(%!%4DU37T1%3$5412P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^9V5T0W)E871O<DED*"DI*2!["B`@("`@
M("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=D96QE=F5N
M="YP:'`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G979E;G1)1"<@/3X@)'1H:7,M/F5V96YT240L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C
M86QE;F1A<B<@/3X@)'1H:7,M/F=E=$-A;&5N9&%R*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T:6UE<W1A
M;7`G(#T^("1T:6UE<W1A;7`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=U<FPG(#T^("1F<F]M7W5R;"DI.PH@
M("`@("`@("`@("`@("`@)&QI;FL@+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"1U<FPI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")$96QE=&4@)7,B
M*2P@)'1H:7,M/G1I=&QE*2D@+@H@("`@("`@("`@("`@("`@("`@($AO<F1E
M.CII;6<H)V1E;&5T92US;6%L;"YP;F<G+"!?*")$96QE=&4B*2P@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*2`N"B`@("`@("`@("`@("`@("`@("`@)SPO83XG
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QI
M;FL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!T
M;V]L=&EP(&9O<B!Q=6EC:R!D97-C<FEP=&EO;G,@;V8@=&AI<R!E=F5N="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&]O;'1I<"@I"B`@("!["B`@("`@
M("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)'1O;VQT:7`@/2`G)SL*"B`@
M("`@("`@:68@*"1T:&ES+3YI<T%L;$1A>2@I*2!["B`@("`@("`@("`@("1T
M;V]L=&EP("X](%\H(D%L;"!D87DB*3L*("`@("`@("!](&5L<V5I9B`H)'1H
M:7,M/G-T87)T+3YC;VUP87)E1&%T92@D=&AI<RT^96YD*2`A/2`P*2!["B`@
M("`@("`@("`@("1T;V]L=&EP("X]('-T<F9T:6UE*"1P<F5F<RT^9V5T5F%L
M=64H)V1A=&5?9F]R;6%T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS=&%R="T^=&EM97-T86UP*"DI("X@)RTG("X*("`@
M("`@("`@("`@("`@('-T<F9T:6UE*"1P<F5F<RT^9V5T5F%L=64H)V1A=&5?
M9F]R;6%T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^96YD
M+3YT:6UE<W1A;7`H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1O;VQT:7`@+CT@9&%T92@D<')E9G,M/F=E=%9A;'5E*"=T=V5N='E&;W5R
M)RD@/R`G1SII)R`Z("=G.FEA)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<W1A<G0M/G1I;65S=&%M<"@I*2`N("<M)R`N"B`@("`@
M("`@("`@("`@("!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G
M*2`_("='.FDG(#H@)V<Z:6$G+`H@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^96YD+3YT:6UE<W1A;7`H*2D["B`@("`@("`@?0H*("`@("`@("`D=&]O
M;'1I<"`N/2`B7&XB("X@<W!R:6YT9BA?*")/=VYE<CH@)7,B*2P@*"1T:&ES
M+3YG971#<F5A=&]R260H*2`]/2!!=71H.CIG971!=71H*"D@/PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7R@B364B*2`Z($MR;VYO;&ET:#HZ9V5T57-E<DYA;64H)'1H:7,M/F=E=$-R
M96%T;W))9"@I*2DI.PH*("`@("`@("!I9B`H)'1H:7,M/FQO8V%T:6]N*2![
M"B`@("`@("`@("`@("1T;V]L=&EP("X](")<;B(@+B!?*"),;V-A=&EO;B(I
M("X@)SH@)R`N("1T:&ES+3YL;V-A=&EO;CL*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=&AI<RT^9&5S8W)I<'1I;VXI('L*("`@("`@("`@("`@)'1O;VQT
M:7`@+CT@(EQN7&XB("X@)'1H:7,M/F1E<V-R:7!T:6]N.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T;V]L=&EP.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!#4U,@8VQA<W,@9F]R('1H92!E=F5N
M="!B87-E9"!O;B!I=',@<W1A='5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713=&%T=7-#;&%S<R@I"B`@("!["B`@("`@("`@<W=I=&-H("@D=&AI<RT^
M<W1A='5S*2!["B`@("`@("`@8V%S92!+4D].3TQ)5$A?4U1!5%537T-!3D-%
M3$Q%1#H*("`@("`@("`@("`@<F5T=7)N("=E=F5N="UC86YC96QL960G.PH*
M("`@("`@("!C87-E($M23TY/3$E42%]35$%455-?5$5.5$%4259%.@H@("`@
M("`@(&-A<V4@2U)/3D],251(7U-405154U]&4D5%.@H@("`@("`@("`@("!R
M971U<FX@)V5V96YT+71E;G1A=&EV92<["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)V5V96YT)SL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@=&AE
M(&YE>'0@<F5C=7)R96YC92!O9B!T:&ES(&5V96YT('1H870G<R!A9G1E<B`D
M869T97)$871E+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]$871E("1A
M9G1E<D1A=&4@(%)E='5R;B!E=F5N=',@869T97(@=&AI<R!D871E+@H@("`@
M("H*("`@("`J($!R971U<FX@2&]R9&5?1&%T97QB;V]L96%N("!4:&4@9&%T
M92!O9B!T:&4@;F5X="!R96-U<G)E;F-E(&]R(&9A;'-E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@=&AE(&5V96YT(&1O97,@;F]T
M(')E8W5R(&%F=&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%F=&5R1&%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E8W5R
M<F5N8V4H)&%F=&5R1&%T92D*("`@('L*("`@("`@("`D869T97(@/2`F;F5W
M($AO<F1E7T1A=&4H)&%F=&5R1&%T92D["B`@("`@("`@)&%F=&5R+3YC;W)R
M96-T*"D["@H@("`@("`@(&EF("@D=&AI<RT^<W1A<G0M/F-O;7!A<F5$871E
M*"1A9G1E<BD@/CT@,"D@>PH@("`@("`@("`@("!R971U<FX@;F5W($AO<F1E
M7T1A=&4H)'1H:7,M/G-T87)T*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=&AI<RT^<F5C=7));G1E<G9A;"`]/2`P*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^:&%S4F5C
M=7)%;F0H*2D@>PH@("`@("`@("`@("`D=&AI<RT^<F5C=7)%;F0M/FAO=7(@
M/2`R,SL*("`@("`@("`@("`@)'1H:7,M/G)E8W5R16YD+3YM:6X@/2`U.3L*
M("`@("`@("`@("`@)'1H:7,M/G)E8W5R16YD+3YS96,@/2`U.3L*("`@("`@
M("!]"@H@("`@("`@('-W:71C:"`H)'1H:7,M/F=E=%)E8W5R5'EP92@I*2![
M"B`@("`@("`@8V%S92!+4D].3TQ)5$A?4D5#55)?1$%)3%DZ"B`@("`@("`@
M("`@("1D:69F(#T@1&%T95]#86QC.CID871E1&EF9B@D=&AI<RT^<W1A<G0M
M/FUD87DL("1T:&ES+3YS=&%R="T^;6]N=&@L("1T:&ES+3YS=&%R="T^>65A
M<BP@)&%F=&5R+3YM9&%Y+"`D869T97(M/FUO;G1H+"`D869T97(M/GEE87(I
M.PH@("`@("`@("`@("`D<F5C=7(@/2!C96EL*"1D:69F("\@)'1H:7,M/G)E
M8W5R26YT97)V86PI("H@)'1H:7,M/G)E8W5R26YT97)V86P["B`@("`@("`@
M("`@("1N97AT(#T@)'1H:7,M/G-T87)T.PH@("`@("`@("`@("!L:7-T*"1N
M97AT+3YM9&%Y+"`D;F5X="T^;6]N=&@L("1N97AT+3YY96%R*2`](&5X<&QO
M9&4H)R\G+"!$871E7T-A;&,Z.F1A>7-4;T1A=&4H1&%T95]#86QC.CID871E
M5&]$87ES*"1N97AT+3YM9&%Y+"`D;F5X="T^;6]N=&@L("1N97AT+3YY96%R
M*2`K("1R96-U<BP@)R5E+R5M+R59)RDI.PH@("`@("`@("`@("!I9B`H*"$D
M=&AI<RT^:&%S4F5C=7)%;F0H*2!\?`H@("`@("`@("`@("`@("`@("1N97AT
M+3YC;VUP87)E1&%T92@D=&AI<RT^<F5C=7)%;F0I(#P](#`I("8F"B`@("`@
M("`@("`@("`@("`D;F5X="T^8V]M<&%R941A=&4H)&%F=&5R*2`^/2`P*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@;F5W($AO<F1E7T1A=&4H)&YE>'0I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E($M23TY/3$E42%]214-54E]7145+3%DZ"B`@("`@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^<F5C=7)$871A*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!L:7-T*"1S
M=&%R=%]W965K+3YM9&%Y+"`D<W1A<G1?=V5E:RT^;6]N=&@L("1S=&%R=%]W
M965K+3YY96%R*2`](&5X<&QO9&4H)R\G+"!$871E7T-A;&,Z.F)E9VEN3V97
M965K*"1T:&ES+3YS=&%R="T^;61A>2P@)'1H:7,M/G-T87)T+3YM;VYT:"P@
M)'1H:7,M/G-T87)T+3YY96%R+"`G)64O)6TO)5DG*2D["B`@("`@("`@("`@
M("1S=&%R=%]W965K+3YH;W5R(#T@)'1H:7,M/G-T87)T+3YH;W5R.PH@("`@
M("`@("`@("`D<W1A<G1?=V5E:RT^;6EN(#T@)'1H:7,M/G-T87)T+3YM:6X[
M"B`@("`@("`@("`@("1S=&%R=%]W965K+3YS96,@/2`D=&AI<RT^<W1A<G0M
M/G-E8SL*("`@("`@("`@("`@;&ES="@D869T97)?=V5E:RT^;61A>2P@)&%F
M=&5R7W=E96LM/FUO;G1H+"`D869T97)?=V5E:RT^>65A<BD@/2!E>'!L;V1E
M*"<O)RP@1&%T95]#86QC.CIB96=I;D]F5V5E:R@D869T97(M/FUD87DL("1A
M9G1E<BT^;6]N=&@L("1A9G1E<BT^>65A<BP@)R5E+R5M+R59)RDI.PH@("`@
M("`@("`@("`D869T97)?=V5E:U]E;F0@/2`F;F5W($AO<F1E7T1A=&4H)&%F
M=&5R7W=E96LI.PH@("`@("`@("`@("`D869T97)?=V5E:U]E;F0M/FUD87D@
M*ST@-SL*("`@("`@("`@("`@)&%F=&5R7W=E96M?96YD+3YC;W)R96-T*"D[
M"@H@("`@("`@("`@("`D9&EF9B`]($1A=&5?0V%L8SHZ9&%T941I9F8H)'-T
M87)T7W=E96LM/FUD87DL("1S=&%R=%]W965K+3YM;VYT:"P@)'-T87)T7W=E
M96LM/GEE87(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D869T97)?=V5E:RT^;61A>2P@)&%F=&5R7W=E96LM/FUO;G1H+"`D
M869T97)?=V5E:RT^>65A<BD["B`@("`@("`@("`@("1R96-U<B`]("1D:69F
M("L@*"1D:69F("4@*"1T:&ES+3YR96-U<DEN=&5R=F%L("H@-RDI.PH@("`@
M("`@("`@("`D;F5X="`]("1S=&%R=%]W965K.PH@("`@("`@("`@("!L:7-T
M*"1N97AT+3YM9&%Y+"`D;F5X="T^;6]N=&@L("1N97AT+3YY96%R*2`](&5X
M<&QO9&4H)R\G+"!$871E7T-A;&,Z.F1A>7-4;T1A=&4H1&%T95]#86QC.CID
M871E5&]$87ES*"1N97AT+3YM9&%Y+"`D;F5X="T^;6]N=&@L("1N97AT+3YY
M96%R*2`K("1R96-U<BP@)R5E+R5M+R59)RDI.PH@("`@("`@("`@("`D;F5X
M="`]("9N97<@2&]R9&5?1&%T92@D;F5X="D["B`@("`@("`@("`@('=H:6QE
M("@D;F5X="T^8V]M<&%R941A=&4H)&%F=&5R*2`\(#`@)B8@)&YE>'0M/F-O
M;7!A<F5$871E*"1A9G1E<E]W965K7V5N9"D@/"`P*2!["B`@("`@("`@("`@
M("`@("`K*R1N97AT+3YM9&%Y.PH@("`@("`@("`@("`@("`@)&YE>'0M/F-O
M<G)E8W0H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21T:&ES
M+3YH87-296-U<D5N9"@I('Q\"B`@("`@("`@("`@("`@("`D;F5X="T^8V]M
M<&%R941A=&4H)'1H:7,M/G)E8W5R16YD*2`\/2`P*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&YE>'0M/F-O;7!A<F5$871E*"1A9G1E<E]W965K7V5N9"D@
M/CT@,"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;F5X
M=%)E8W5R<F5N8V4H)&%F=&5R7W=E96M?96YD*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('=H:6QE("@A)'1H:7,M/G)E8W5R3VY$87DH
M*&EN="EP;W<H,BP@)&YE>'0M/F1A>4]F5V5E:R@I*2D@)B8@)&YE>'0M/F-O
M;7!A<F5$871E*"1A9G1E<E]W965K7V5N9"D@/"`P*2!["B`@("`@("`@("`@
M("`@("`@("`@*RLD;F5X="T^;61A>3L*("`@("`@("`@("`@("`@("`@("`D
M;F5X="T^8V]R<F5C="@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"$D=&AI<RT^:&%S4F5C=7)%;F0H*2!\?`H@("`@("`@("`@
M("`@("`@("`@("1N97AT+3YC;VUP87)E1&%T92@D=&AI<RT^<F5C=7)%;F0I
M(#P](#`I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&YE>'0M/F-O;7!A
M<F5$871E*"1A9G1E<E]W965K7V5N9"D@/CT@,"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FYE>'1296-U<G)E;F-E*"1A9G1E
M<E]W965K7V5N9"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1N97AT.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!+4D].3TQ)5$A?4D5#
M55)?1$%97T]&7TU/3E1(.@H@("`@("`@("`@("`D<W1A<G0@/2!5=&EL.CIC
M;&]N94]B:F5C="AN97<@2&]R9&5?1&%T92@D=&AI<RT^<W1A<G0I*3L*("`@
M("`@("`@("`@:68@*"1A9G1E<BT^8V]M<&%R941A=&4H)'-T87)T*2`\(#`I
M('L*("`@("`@("`@("`@("`@("1A9G1E<B`]("1S=&%R=#L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R\@268@=V4G<F4@<W1A<G1I;F<@<&%S="!T
M:&ES(&UO;G1H)W,@<F5C=7)R96YC92!O9B!T:&4*("`@("`@("`@("`@+R\@
M979E;G0L(&QO;VL@:6X@=&AE(&YE>'0@;6]N=&@@;VX@=&AE(&1A>2!T:&4@
M979E;G0*("`@("`@("`@("`@+R\@<F5C=7)S+@H@("`@("`@("`@("!I9B`H
M)&%F=&5R+3YM9&%Y(#X@)'-T87)T+3YM9&%Y*2!["B`@("`@("`@("`@("`@
M("`K*R1A9G1E<BT^;6]N=&@["B`@("`@("`@("`@("`@("`D869T97(M/FUD
M87D@/2`D<W1A<G0M/FUD87D["B`@("`@("`@("`@("`@("`D869T97(M/F-O
M<G)E8W0H*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@061J=7-T
M("1S=&%R="!T;R!B92!T:&4@9FER<W0@;6%T8V@N"B`@("`@("`@("`@("1O
M9F9S970@/2`H)&%F=&5R+3YM;VYT:"`M("1S=&%R="T^;6]N=&@I("L@*"1A
M9G1E<BT^>65A<B`M("1S=&%R="T^>65A<BD@*B`Q,CL*("`@("`@("`@("`@
M)&]F9G-E="`](&9L;V]R*"@D;V9F<V5T("L@)'1H:7,M/G)E8W5R26YT97)V
M86P@+2`Q*2`O("1T:&ES+3YR96-U<DEN=&5R=F%L*2`J("1T:&ES+3YR96-U
M<DEN=&5R=F%L.PH*("`@("`@("`@("`@)'-T87)T+3YM;VYT:"`K/2`D;V9F
M<V5T.PH*("`@("`@("`@("`@9&\@>PH@("`@("`@("`@("`@("`@+R\@1&]N
M)W0@8V]R<F5C="!F;W(@9&%Y(&]V97)F;&]W.R!W92!J=7-T('-K:7`*("`@
M("`@("`@("`@("`@("\O($9E8G)U87)Y(#,P=&@L(&9O<B!E>&%M<&QE+@H@
M("`@("`@("`@("`@("`@)'-T87)T+3YC;W)R96-T*$A/4D1%7T1!5$5?34%3
M2U]-3TY42"D["B`@("`@("`@("`@("`@("!I9B`H)'-T87)T+3YI<U9A;&ED
M*"DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'-T87)T.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($EF('1H92!I;G1E
M<G9A;"!I<R`Q,BP@86YD('1H92!D871E(&ES;B=T('9A;&ED+`H@("`@("`@
M("`@("`@("`@+R\@=&AE;B!W92!N965D('1O('-E92!I9B!&96)R=6%R>2`R
M.71H(&ES(&%N"B`@("`@("`@("`@("`@("`O+R!O<'1I;VXN($EF(&YO="P@
M=&AE;B!T:&4@979E;G0@=VEL;"!?;F5V97)?(')E8W5R+`H@("`@("`@("`@
M("`@("`@+R\@86YD('=E(&YE960@=&\@<W1O<"!C:&5C:VEN9R!T;R!A=F]I
M9"!A;B!I;F9I;FET90H@("`@("`@("`@("`@("`@+R\@;&]O<"X*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^<F5C=7));G1E<G9A;"`]/2`Q,B`F)B`H
M)'-T87)T+3YM;VYT:"`A/2`R('Q\("1S=&%R="T^;61A>2`^(#(Y*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`O+R!!9&0@=&AE(')E8W5R<F5N8V4@
M:6YT97)V86PN"B`@("`@("`@("`@("`@("`D<W1A<G0M/FUO;G1H("L]("1T
M:&ES+3YR96-U<DEN=&5R=F%L.PH*("`@("`@("`@("`@("`@("\O($)A:6P@
M:68@=V4G=F4@9V]N92!P87-T('1H92!E;F0@;V8@<F5C=7)R96YC92X*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^:&%S4F5C=7)%;F0H*2`F)@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YR96-U<D5N9"T^8V]M<&%R941A=&4H
M)'-T87)T*2`\(#`I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@=VAI;&4@*'1R
M=64I.PH*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@2U)/3D],
M251(7U)%0U527U=%14M?3T9?34].5$@Z"B`@("`@("`@("`@("\O(%-T87)T
M('=I=&@@=&AE('-T87)T(&1A=&4@;V8@=&AE(&5V96YT+@H@("`@("`@("`@
M("`D97-T87)T(#T@571I;#HZ8VQO;F5/8FIE8W0H;F5W($AO<F1E7T1A=&4H
M)'1H:7,M/G-T87)T*2D["@H@("`@("`@("`@("`O+R!7:&%T(&1A>2!O9B!T
M:&4@=V5E:RP@86YD('=E96L@;V8@=&AE(&UO;G1H+"!D;R!W90H@("`@("`@
M("`@("`O+R!R96-U<B!O;C\*("`@("`@("`@("`@)&YT:"`](&-E:6PH)'1H
M:7,M/G-T87)T+3YM9&%Y("\@-RD["B`@("`@("`@("`@("1W965K9&%Y(#T@
M)&5S=&%R="T^9&%Y3V97965K*"D["@H@("`@("`@("`@("`O+R!!9&IU<W0@
M)&5S=&%R="!T;R!B92!T:&4@9FER<W0@8V%N9&ED871E+@H@("`@("`@("`@
M("`D;V9F<V5T(#T@*"1A9G1E<BT^;6]N=&@@+2`D97-T87)T+3YM;VYT:"D@
M*R`H)&%F=&5R+3YY96%R("T@)&5S=&%R="T^>65A<BD@*B`Q,CL*("`@("`@
M("`@("`@)&]F9G-E="`](&9L;V]R*"@D;V9F<V5T("L@)'1H:7,M/G)E8W5R
M26YT97)V86P@+2`Q*2`O("1T:&ES+3YR96-U<DEN=&5R=F%L*2`J("1T:&ES
M+3YR96-U<DEN=&5R=F%L.PH*("`@("`@("`@("`@+R\@061J=7-T(&]U<B!W
M;W)K:6YG(&1A=&4@=6YT:6P@:70G<R!A9G1E<B`D869T97(N"B`@("`@("`@
M("`@("1E<W1A<G0M/FUO;G1H("L]("1O9F9S970@+2`D=&AI<RT^<F5C=7))
M;G1E<G9A;#L*("`@("`@("`@("`@9&\@>PH@("`@("`@("`@("`@("`@)&5S
M=&%R="T^;6]N=&@@*ST@)'1H:7,M/G)E8W5R26YT97)V86P["B`@("`@("`@
M("`@("`@("`D97-T87)T+3YC;W)R96-T*"D["@H@("`@("`@("`@("`@("`@
M)&YE>'0@/2`F571I;#HZ8VQO;F5/8FIE8W0H)&5S=&%R="D["B`@("`@("`@
M("`@("`@("`D;F5X="T^<V5T3G1H5V5E:V1A>2@D=V5E:V1A>2P@)&YT:"D[
M"@H@("`@("`@("`@("`@("`@:68@*"1N97AT+3YC;VUP87)E1&%T92@D869T
M97(I(#P@,"D@>PH@("`@("`@("`@("`@("`@("`@("\O(%=E(&AA=F5N)W0@
M;6%D92!I="!P87-T("1A9G1E<B!Y970L('1R>0H@("`@("`@("`@("`@("`@
M("`@("\O(&%G86EN+@H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YH
M87-296-U<D5N9"@I("8F"B`@("`@("`@("`@("`@("`@("`@)&YE>'0M/F-O
M;7!A<F5$871E*"1T:&ES+3YR96-U<D5N9"D@/B`P*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@5V4G=F4@9V]N92!P87-T('1H92!E;F0@;V8@<F5C=7)R
M96YC93L@=V4@8V%N"B`@("`@("`@("`@("`@("`@("`@+R\@9VEV92!U<"!N
M;W<N"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O(%=E(&AA=F4@82!C86YD
M:61A=&4@=&\@<F5T=7)N+@H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T@=VAI;&4@*'1R=64I.PH*("`@("`@("`@("`@<F5T=7)N("1N
M97AT.PH*("`@("`@("!C87-E($M23TY/3$E42%]214-54E]914%23%DZ"B`@
M("`@("`@("`@("\O(%-T87)T('=I=&@@=&AE('-T87)T(&1A=&4@;V8@=&AE
M(&5V96YT+@H@("`@("`@("`@("`D97-T87)T(#T@571I;#HZ8VQO;F5/8FIE
M8W0H;F5W($AO<F1E7T1A=&4H)'1H:7,M/G-T87)T*2D["@H@("`@("`@("`@
M("`O+R!792!P<F]B86)L>2!N965D(&$@<V5P97)A=&4@8V%S92!H97)E(&9O
M<B!&96)R=6%R>2`R.71H"B`@("`@("`@("`@("\O(&%N9"!L96%P('EE87)S
M+"!B=70@=6YT:6P@=V4G<F4@86)S;VQU=&5L>2!S=7)E(&ET)W,@80H@("`@
M("`@("`@("`O+R!B=6<L('=E)VQL(&QE879E(&ET(&]U="X*("`@("`@("`@
M("`@:68@*"1A9G1E<BT^;6]N=&@@/B`D97-T87)T+3YM;VYT:"!\?`H@("`@
M("`@("`@("`@("`@*"1A9G1E<BT^;6]N=&@@/3T@)&5S=&%R="T^;6]N=&@@
M)B8@)&%F=&5R+3YM9&%Y(#X@)&5S=&%R="T^;61A>2DI('L*("`@("`@("`@
M("`@("`@("LK)&%F=&5R+3YY96%R.PH@("`@("`@("`@("`@("`@)&%F=&5R
M+3YM;VYT:"`]("1E<W1A<G0M/FUO;G1H.PH@("`@("`@("`@("`@("`@)&%F
M=&5R+3YM9&%Y(#T@)&5S=&%R="T^;61A>3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+R\@061J=7-T("1E<W1A<G0@=&\@8F4@=&AE(&9I<G-T(&-A
M;F1I9&%T92X*("`@("`@("`@("`@)&]F9G-E="`]("1A9G1E<BT^>65A<B`M
M("1E<W1A<G0M/GEE87(["B`@("`@("`@("`@(&EF("@D;V9F<V5T(#X@,"D@
M>PH@("`@("`@("`@("`@("`@)&]F9G-E="`]("@H)&]F9G-E="`K("1T:&ES
M+3YR96-U<DEN=&5R=F%L("T@,2D@+R`D=&AI<RT^<F5C=7));G1E<G9A;"D@
M*B`D=&AI<RT^<F5C=7));G1E<G9A;#L*("`@("`@("`@("`@("`@("1E<W1A
M<G0M/GEE87(@*ST@)&]F9G-E=#L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@5V4G=F4@9V]N92!P87-T('1H92!E;F0@;V8@<F5C=7)R96YC93L@
M9VEV92!U<"X*("`@("`@("`@("`@:68@*"1T:&ES+3YH87-296-U<D5N9"@I
M("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5C=7)%;F0M/F-O;7!A<F5$
M871E*"1E<W1A<G0I(#P@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@)&5S=&%R
M=#L*("`@("`@("!]"@H@("`@("`@("\O(%=E(&1I9&XG="!F:6YD(&%N>71H
M:6YG+"!T:&4@<F5C=7)4>7!E('=A<R!B860L(&]R"B`@("`@("`@+R\@<V]M
M971H:6YG(&5L<V4@=V5N="!W<F]N9R`M(')E='5R;B!F86QS92X*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@:&%S06-T:79E
M4F5C=7)R96YC92@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^:&%S4F5C
M=7)%;F0H*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1N97AT(#T@)'1H:7,M/FYE>'1296-U<G)E;F-E*%5T:6PZ
M.F-L;VYE3V)J96-T*"1T:&ES+3YS=&%R="DI.PH@("`@("`@('=H:6QE("AI
M<U]O8FIE8W0H)&YE>'0I*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/FAA
M<T5X8V5P=&EO;B@D;F5X="T^>65A<BP@)&YE>'0M/FUO;G1H+"`D;F5X="T^
M;61A>2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D;F5X="`]("1T:&ES+3YN97AT4F5C=7)R
M96YC92AA<G)A>2@G>65A<B<@/3X@)&YE>'0M/GEE87(L("=M;VYT:"<@/3X@
M)&YE>'0M/FUO;G1H+"`G;61A>2<@/3X@)&YE>'0M/FUD87D@*R`Q+"`G:&]U
M<B<@/3X@)&YE>'0M/FAO=7(L("=M:6XG(#T^("1N97AT+3YM:6XL("=S96,G
M(#T^("1N97AT+3YS96,I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971#86QE;F1A<B@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%L96YD87(["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5T0V%L96YD87(H)&-A;&5N9&%R*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?8V%L96YD87(@/2`D8V%L96YD87(["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]K<F]N;VQI=&@O;&EB+V%P:2YP:'``````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8R-S,R`#$P-#$W,S8R-S4S`#`R
M,#0W-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@2W)O;F]L:71H(&5X=&5R;F%L($%022!I;G1E<F9A
M8V4N"B`J"B`J("1(;W)D93H@:W)O;F]L:71H+VQI8B]A<&DN<&AP+'8@,2XQ
M,C8N,BXQ,R`R,#`V+S`S+S`V(#$S.C4T.C`T(&IA;B!%>'`@)`H@*@H@*B!4
M:&ES(&9I;&4@9&5F:6YE<R!+<F]N;VQI=&@G<R!E>'1E<FYA;"!!4$D@:6YT
M97)F86-E+B!/=&AE<B!A<'!L:6-A=&EO;G,*("H@8V%N(&EN=&5R86-T('=I
M=&@@2W)O;F]L:71H('1H<F]U9V@@=&AI<R!!4$DN"B`J"B`J($!P86-K86=E
M($MR;VYO;&ET:`H@*B\*"B1?<V5R=FEC97-;)W!E<FUS)UT@/2!A<G)A>2@*
M("`@("=A<F=S)R`]/B!A<G)A>2@I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO
M<F1E?7-T<FEN9T%R<F%Y)RD["@HD7W-E<G9I8V5S6R=S:&]W)UT@/2!A<G)A
M>2@*("`@("=L:6YK)R`]/B`G)6%P<&QI8V%T:6]N)2]V:65W979E;G0N<&AP
M/V-A;&5N9&%R/7QC86QE;F1A<GPG("X*("`@("`@("`@("`@("`G)F5V96YT
M240]?&5V96YT?"9U:60]?'5I9'PG"BD["@HD7W-E<G9I8V5S6R=B<F]W<V4G
M72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=P871H)R`]/B`G<W1R
M:6YG)RDL"B`@("`G='EP92<@/3X@)WMU<FXZ:&%S:'UH87-H2&%S:"<L"BD[
M"@HD7W-E<G9I8V5S6R=G971&<F5E0G5S>2==(#T@87)R87DH"B`@("`G87)G
M<R<@/3X@87)R87DH)W-T87)T<W1A;7`G(#T^("=I;G0G+"`G96YD<W1A;7`G
M(#T^("=I;G0G+"`G8V%L96YD87(G(#T^("=S=')I;F<G*2P*("`@("=T>7!E
M)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<**3L*"B1?<V5R=FEC97-;
M)VQI<W1#86QE;F1A<G,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y
M*"=O=VYE<F]N;'DG(#T^("=B;V]L96%N)RP@)W!E<FUI<W-I;VXG(#T^("=I
M;G0G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<*
M*3L*"B1?<V5R=FEC97-;)VQI<W1%=F5N=',G72`](&%R<F%Y*`H@("`@)V%R
M9W,G(#T^(&%R<F%Y*"=S=&%R='-T86UP)R`]/B`G:6YT)RP@)V5N9'-T86UP
M)R`]/B`G:6YT)RP@)V-A;&5N9&%R)R`]/B`G<W1R:6YG)RP@)W-H;W=296-U
M<G)E;F-E)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V%R<F%Y)PHI
M.PH*)%]S97)V:6-E<ULG;&ES="==(#T@87)R87DH"B`@("`G87)G<R<@/3X@
M87)R87DH*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<**3L*"B1?<V5R=FEC97-;)VQI<W1">2==(#T@87)R87DH"B`@("`G87)G
M<R<@/3X@87)R87DH)V%C=&EO;B<@/3X@)W-T<FEN9R<L("=T:6UE<W1A;7`G
M(#T^("=I;G0G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!
M<G)A>2<**3L*"B1?<V5R=FEC97-;)V=E=$%C=&EO;E1I;65S=&%M<"==(#T@
M87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W5I9"<@/3X@)W-T<FEN9R<L
M("=T:6UE<W1A;7`G(#T^("=I;G0G*2P*("`@("=T>7!E)R`]/B`G:6YT)RP*
M*3L*"B1?<V5R=FEC97-;)VEM<&]R="==(#T@87)R87DH"B`@("`G87)G<R<@
M/3X@87)R87DH)V-O;G1E;G0G(#T^("=S=')I;F<G+"`G8V]N=&5N=%1Y<&4G
M(#T^("=S=')I;F<G+"`G8V%L96YD87(G(#T^("=S=')I;F<G*2P*("`@("=T
M>7!E)R`]/B`G:6YT)PHI.PH*)%]S97)V:6-E<ULG97AP;W)T)UT@/2!A<G)A
M>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G=6ED)R`]/B`G<W1R:6YG)RP@)V-O
M;G1E;G14>7!E)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)W-T<FEN
M9R<**3L*"B1?<V5R=FEC97-;)V5X<&]R=$-A;&5N9&%R)UT@/2!A<G)A>2@*
M("`@("=A<F=S)R`]/B!A<G)A>2@G8V%L96YD87(G(#T^("=S=')I;F<G+"`G
M8V]N=&5N=%1Y<&4G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G<W1R
M:6YG)PHI.PH*"B1?<V5R=FEC97-;)V1E;&5T92==(#T@87)R87DH"B`@("`G
M87)G<R<@/3X@87)R87DH)W5I9"<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G
M(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5P;&%C92==(#T@87)R
M87DH"B`@("`G87)G<R<@/3X@87)R87DH)W5I9"<@/3X@)W-T<FEN9R<L("=C
M;VYT96YT)R`]/B`G<W1R:6YG)RP@)V-O;G1E;G14>7!E)R`]/B`G<W1R:6YG
M)RDL"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HO+R!&25A-13H@8W)E
M871E(&-O;7!L97@@='EP92!D969I;FET:6]N(&9O<B!33T%0(&-A;&QS+@HD
M7W-E<G9I8V5S6R=E=F5N=$9R;VU5240G72`](&%R<F%Y*`H@("`@)V%R9W,G
M(#T^(&%R<F%Y*"=U:60G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G
M;V)J96-T)PHI.PH*+R\@1DE8344Z(&-R96%T92!C;VUP;&5X('1Y<&4@9&5F
M:6YI=&EO;B!F;W(@4T]!4"!C86QL<RX*)%]S97)V:6-E<ULG=7!D871E071T
M96YD964G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=R97-P;VYS
M92<@/3X@)V]B:F5C="<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*
M"F9U;F-T:6]N(%]K<F]N;VQI=&A?<&5R;7,H*0I["B`@("`D<&5R;7,@/2!A
M<G)A>2@I.PH@("`@)'!E<FUS6R=T<F5E)UU;)VMR;VYO;&ET:"==6R=M87A?
M979E;G1S)UT@/2!F86QS93L*("`@("1P97)M<ULG=&ET;&4G75LG:W)O;F]L
M:71H.FUA>%]E=F5N=',G72`](%\H(DUA>&EM=6T@3G5M8F5R(&]F($5V96YT
M<R(I.PH@("`@)'!E<FUS6R=T>7!E)UU;)VMR;VYO;&ET:#IM87A?979E;G1S
M)UT@/2`G:6YT)SL*"B`@("!R971U<FX@)'!E<FUS.PI]"@IF=6YC=&EO;B!?
M7VMR;VYO;&ET:%]M;V1I9FEE9"@D=6ED*0I["B`@("`D;6]D:69I960@/2!?
M:W)O;F]L:71H7V=E=$%C=&EO;E1I;65S=&%M<"@D=6ED+"`G;6]D:69Y)RD[
M"B`@("!I9B`H96UP='DH)&UO9&EF:65D*2D@>PH@("`@("`@("1M;V1I9FEE
M9"`](%]K<F]N;VQI=&A?9V5T06-T:6]N5&EM97-T86UP*"1U:60L("=A9&0G
M*3L*("`@('T*("`@(')E='5R;B`D;6]D:69I960["GT*"B\J*@H@*B!"<F]W
M<V4@=&AR;W5G:"!+<F]N;VQI=&@G<R!O8FIE8W0@=')E92X*("H*("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@;&5V96P@;V8@=&AE('1R964@
M=&\@8G)O=W-E+@H@*B!`<&%R86T@87)R87D@)'!R;W!E<G1I97,@(%1H92!I
M=&5M('!R;W!E<G1I97,@=&\@<F5T=7)N+B!$969A=6QT<R!T;R`G;F%M92<L
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEC;VXG+"!A;F0@)V)R
M;W=S96%B;&4G+@H@*@H@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]N=&5N=',@
M;V8@)'!A=&@*("HO"F9U;F-T:6]N(%]K<F]N;VQI=&A?8G)O=W-E*"1P871H
M(#T@)R<L("1P<F]P97)T:65S(#T@87)R87DH*2D*>PH@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<["B`@("!G;&]B
M86P@)')E9VES=')Y.PH*("`@("\O($1E9F%U;'0@<')O<&5R=&EE<RX*("`@
M(&EF("@A)'!R;W!E<G1I97,I('L*("`@("`@("`D<')O<&5R=&EE<R`](&%R
M<F%Y*"=N86UE)RP@)VEC;VXG+"`G8G)O=W-E86)L92<I.PH@("`@?0H*("`@
M(&EF("AS=6)S='(H)'!A=&@L(#`L(#DI(#T]("=K<F]N;VQI=&@G*2!["B`@
M("`@("`@)'!A=&@@/2!S=6)S='(H)'!A=&@L(#DI.PH@("`@?0H@("`@:68@
M*'-U8G-T<B@D<&%T:"P@,"P@,2D@/3T@)R\G*2!["B`@("`@("`@)'!A=&@@
M/2!S=6)S='(H)'!A=&@L(#$I.PH@("`@?0H@("`@:68@*'-U8G-T<B@D<&%T
M:"P@+3$I(#T]("<O)RD@>PH@("`@("`@("1P871H(#T@<W5B<W1R*"1P871H
M+"`P+"`M,2D["B`@("!]"@H@("`@:68@*&5M<'1Y*"1P871H*2D@>PH@("`@
M("`@("1C86QE;F1A<G,@/2!+<F]N;VQI=&@Z.FQI<W1#86QE;F1A<G,H9F%L
M<V4L(%!%4DU37U-(3U<I.PH@("`@("`@("1R97-U;'1S(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D8V%L96YD87)S(&%S("1C86QE;F1A<DED(#T^
M("1C86QE;F1A<BD@>PH@("`@("`@("`@("!I9B`H:6Y?87)R87DH)VYA;64G
M+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@("`@("1R97-U;'1S6R=K
M<F]N;VQI=&@O)R`N("1C86QE;F1A<DED75LG;F%M92==(#T@)&-A;&5N9&%R
M+3YG970H)VYA;64G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M:6Y?87)R87DH)VEC;VXG+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@
M("`@("1R97-U;'1S6R=K<F]N;VQI=&@O)R`N("1C86QE;F1A<DED75LG:6-O
M;B==(#T@)')E9VES=')Y+3YG971);6%G941I<B@I("X@)R]K<F]N;VQI=&@N
M<&YG)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH
M)V)R;W=S96%B;&4G+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@("`@
M("1R97-U;'1S6R=K<F]N;VQI=&@O)R`N("1C86QE;F1A<DED75LG8G)O=W-E
M86)L92==(#T@)&-A;&5N9&%R+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E=$%U
M=&@H*2P@4$5235-?4D5!1"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*&EN7V%R<F%Y*"=C;VYT96YT='EP92<L("1P<F]P97)T:65S*2D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L='-;)VMR;VYO;&ET:"\G("X@)&-A;&5N
M9&%R261=6R=C;VYT96YT='EP92==(#T@)VAT='!D+W5N:7@M9&ER96-T;W)Y
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH)V-O
M;G1E;G1L96YG=&@G+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@("`@
M("1R97-U;'1S6R=K<F]N;VQI=&@O)R`N("1C86QE;F1A<DED75LG8V]N=&5N
M=&QE;F=T:"==(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M:6Y?87)R87DH)VUO9&EF:65D)RP@)'!R;W!E<G1I97,I*2!["B`@("`@("`@
M("`@("`@("`D<F5S=6QT<ULG:W)O;F]L:71H+R<@+B`D8V%L96YD87))9%U;
M)VUO9&EF:65D)UT@/2!T:6UE*"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&EN7V%R<F%Y*"=C<F5A=&5D)RP@)'!R;W!E<G1I97,I*2!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT<ULG:W)O;F]L:71H+R<@+B`D8V%L96YD
M87))9%U;)V-R96%T960G72`](#`["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1R97-U;'1S.PH@("`@?2!E;'-E:68@*&%R<F%Y
M7VME>5]E>&ES=',H)'!A=&@L($MR;VYO;&ET:#HZ;&ES=$-A;&5N9&%R<RAF
M86QS92P@4$5235-?4D5!1"DI*2!["B`@("`@("`@)&5V96YT<R`]($MR;VYO
M;&ET:#HZ;&ES=$5V96YT<R@P+"!N97<@2&]R9&5?1&%T92AA<G)A>2@G>65A
M<B<@/3X@.3DY.2P@)VUO;G1H)R`]/B`Q,BP@)V1A>2<@/3X@,S$I*2P@87)R
M87DH)'!A=&@I+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)&5V96YT<RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&5V96YT<SL*
M("`@("`@("!]"@H@("`@("`@("1R97-U;'1S(#T@87)R87DH*3L*("`@("`@
M("!F;W)E86-H("@D979E;G1S(&%S("1T:6UE<W1A;7`@/3X@)'1I;65E=F5N
M=',I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1I;65E=F5N=',@87,@)&5V
M96YT260@/3X@)&5V96YT*2!["B`@("`@("`@("`@("`@("`D:V5Y(#T@)VMR
M;VYO;&ET:"\G("X@)'!A=&@@+B`G+R<@+B`D979E;G1)9#L*("`@("`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2@G;F%M92<L("1P<F]P97)T:65S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K97E=6R=N86UE)UT@/2`D
M979E;G0M/F=E=%1I=&QE*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H:6Y?87)R87DH)VEC;VXG+"`D<')O<&5R=&EE<RDI('L*
M("`@("`@("`@("`@("`@("`@("`D<F5S=6QT<ULD:V5Y75LG:6-O;B==(#T@
M)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2`N("<O;6EM92]I8V%L
M96YD87(N<&YG)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AI;E]A<G)A>2@G8G)O=W-E86)L92<L("1P<F]P97)T:65S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K97E=6R=B<F]W<V5A8FQE
M)UT@/2!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AI;E]A<G)A>2@G8V]N=&5N='1Y<&4G+"`D<')O<&5R=&EE<RDI('L*
M("`@("`@("`@("`@("`@("`@("`D<F5S=6QT<ULD:V5Y75LG8V]N=&5N='1Y
M<&4G72`]("=T97AT+V-A;&5N9&%R)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@G8V]N=&5N=&QE;F=T:"<L("1P
M<F]P97)T:65S*2D@>PH@("`@("`@("`@("`@("`@("`@("1D871A(#T@7VMR
M;VYO;&ET:%]E>'!O<G0H)&5V96YT+3YG9715240H*2P@)W1E>'0O8V%L96YD
M87(G*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D9&%T82P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T82`]
M("<G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT<ULD:V5Y75LG8V]N=&5N=&QE;F=T:"==(#T@<W1R;&5N*"1D
M871A*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI
M;E]A<G)A>2@G;6]D:69I960G+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@
M("`@("`@("`@("`D<F5S=6QT<ULD:V5Y75LG;6]D:69I960G72`](%]?:W)O
M;F]L:71H7VUO9&EF:65D*"1E=F5N="T^9V5T54E$*"DI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"=C<F5A=&5D
M)RP@)'!R;W!E<G1I97,I*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L
M='-;)&ME>5U;)V-R96%T960G72`](%]K<F]N;VQI=&A?9V5T06-T:6]N5&EM
M97-T86UP*"1E=F5N="T^9V5T54E$*"DL("=A9&0G*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E<W5L=',["B`@("!](&5L<V4@>PH@("`@("`@("1P87)T<R`](&5X<&QO
M9&4H)R\G+"`D<&%T:"D["B`@("`@("`@:68@*&-O=6YT*"1P87)T<RD@/3T@
M,B`F)@H@("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S*"1P87)T<ULP72P@
M2W)O;F]L:71H.CIL:7-T0V%L96YD87)S*&9A;'-E+"!015)-4U]214%$*2DI
M('L*("`@("`@("`@("`@9VQO8F%L("1K<F]N;VQI=&@["B`@("`@("`@("`@
M(&EF("@D:W)O;F]L:71H+3YG971#86QE;F1A<B@I("$]("1P87)T<ULP72D@
M>PH@("`@("`@("`@("`@("`@)&MR;VYO;&ET:"T^8VQO<V4H*3L*("`@("`@
M("`@("`@("`@("1K<F]N;VQI=&@M/F]P96XH)'!A<G1S6S!=*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D979E;G0@/2`F)&MR;VYO;&ET:"T^9V5T
M179E;G0H)'!A<G1S6S%=*3L*("`@("`@("`@("`@:68@*&ES7V$H)&5V96YT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&5V
M96YT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@87)R
M87DH)V1A=&$G(#T^(%]K<F]N;VQI=&A?97AP;W)T*"1E=F5N="T^9V5T54E$
M*"DL("=T97AT+V-A;&5N9&%R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;6EM971Y<&4G(#T^("=T97AT+V-A;&5N9&%R)RD["B`@("`@("`@
M("`@("1M;V1I9FEE9"`](%]?:W)O;F]L:71H7VUO9&EF:65D*"1E=F5N="T^
M9V5T54E$*"DI.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1M;V1I9FEE9"DI
M('L*("`@("`@("`@("`@("`@("1R97-U;'1;)VUT:6UE)UT@/2`D;6]D:69I
M960["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H@("`@?0H*("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"1P871H("X@)R!D;V5S(&YO="!E>&ES="!O<B!P97)M:7-S:6]N(&1E;FEE
M9"<I.PI]"@IF=6YC=&EO;B!?:W)O;F]L:71H7VQI<W1#86QE;F1A<G,H)&]W
M;F5R;VYL>2`](&9A;'-E+"`D<&5R;6ES<VEO;B`](&YU;&PI"GL*("`@(')E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH@
M("`@:68@*"%I<W-E="@D<&5R;6ES<VEO;BDI('L*("`@("`@("`D<&5R;6ES
M<VEO;B`](%!%4DU37U-(3U<["B`@("!]"B`@("!R971U<FX@87)R87E?:V5Y
M<RA+<F]N;VQI=&@Z.FQI<W1#86QE;F1A<G,H)&]W;F5R;VYL>2P@)'!E<FUI
M<W-I;VXI*3L*?0H*9G5N8W1I;VX@7VMR;VYO;&ET:%]L:7-T*"D*>PH@("`@
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<[
M"B`@("`D:61S(#T@2W)O;F]L:71H.CIL:7-T179E;G1)9',H,"P@;F5W($AO
M<F1E7T1A=&4H87)R87DH)WEE87(G(#T^(#DY.3DL("=M;VYT:"<@/3X@,3(L
M("=D87DG(#T^(#,Q*2DI.PH@("`@:68@*&ES7V$H)&ED<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@(')E='5R;B`D:61S.PH@("`@?0H*("`@("1U:61S
M(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1I9',@87,@)&-A;"D@>PH@("`@
M("`@("1U:61S(#T@87)R87E?;65R9V4H)'5I9',L(&%R<F%Y7VME>7,H)&-A
M;"DI.PH@("`@?0H*("`@(')E='5R;B`D=6ED<SL*?0H*+RHJ"B`J(%)E='5R
M;G,@86X@87)R87D@;V8@54E$<R!F;W(@979E;G1S('1H870@:&%V92!H860@
M)&%C=&EO;B!H87!P96X@<VEN8V4*("H@)'1I;65S=&%M<"X*("H*("H@0'!A
M<F%M('-T<FEN9R`@)&%C=&EO;B`@("`@5&AE(&%C=&EO;B!T;R!C:&5C:R!F
M;W(@+2!A9&0L(&UO9&EF>2P@;W(@9&5L971E+@H@*B!`<&%R86T@:6YT96=E
M<B`D=&EM97-T86UP("!4:&4@=&EM92!T;R!S=&%R="!T:&4@<V5A<F-H+@H@
M*B!`<&%R86T@<W1R:6YG("`D8V%L96YD87(@("!4:&4@8V%L96YD87(@=&\@
M<V5A<F-H(&EN+@H@*@H@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!5
M241S(&UA=&-H:6YG('1H92!A8W1I;VX@86YD('1I;64@8W)I=&5R:6$N"B`J
M+PIF=6YC=&EO;B!?:W)O;F]L:71H7VQI<W1">2@D86-T:6]N+"`D=&EM97-T
M86UP+"`D8V%L96YD87(@/2`G)RD*>PH@("`@<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<["@H@("`@:68@*&5M<'1Y*"1C
M86QE;F1A<BDI('L*("`@("`@("`D8V%L96YD87(@/2!+<F]N;VQI=&@Z.F=E
M=$1E9F%U;'1#86QE;F1A<B@I.PH@("`@?0H*("`@("1H:7-T;W)Y(#T@)DAO
M<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@)&AI<W1O<FEE<R`]("1H
M:7-T;W)Y+3YG971">51I;65S=&%M<"@G/B<L("1T:6UE<W1A;7`L(&%R<F%Y
M*&%R<F%Y*"=O<"<@/3X@)STG+"`G9FEE;&0G(#T^("=A8W1I;VXG+"`G=F%L
M=64G(#T^("1A8W1I;VXI*2P@)VMR;VYO;&ET:#HG("X@)&-A;&5N9&%R*3L*
M("`@(&EF("AI<U]A*"1H:7-T;W)I97,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("!R971U<FX@)&AI<W1O<FEE<SL*("`@('T*"B`@("`O+R!3=')I<"!L
M96%D:6YG(&MR;VYO;&ET:#IU<V5R;F%M93HN"B`@("!R971U<FX@<')E9U]R
M97!L86-E*"<O7BA;7CI=*CHI>S)]+R<L("<G+"!A<G)A>5]K97ES*"1H:7-T
M;W)I97,I*3L*?0H*+RHJ"B`J(%)E='5R;G,@=&AE('1I;65S=&%M<"!O9B!A
M;B!O<&5R871I;VX@9F]R(&$@9VEV96X@=6ED(&%N(&%C=&EO;@H@*@H@*B!`
M<&%R86T@<W1R:6YG("1U:60@("`@("!4:&4@=6ED('1O(&QO;VL@9F]R+@H@
M*B!`<&%R86T@<W1R:6YG("1A8W1I;VX@("!4:&4@86-T:6]N('1O(&-H96-K
M(&9O<B`M(&%D9"P@;6]D:69Y+"!O<B!D96QE=&4N"B`J($!P87)A;2!S=')I
M;F<@)&-A;&5N9&%R(%1H92!C86QE;F1A<B!T;R!S96%R8V@@:6XN"B`J"B`J
M($!R971U<FX@:6YT96=E<B`@5&AE('1I;65S=&%M<"!F;W(@=&AI<R!A8W1I
M;VXN"B`J+PIF=6YC=&EO;B!?:W)O;F]L:71H7V=E=$%C=&EO;E1I;65S=&%M
M<"@D=6ED+"`D86-T:6]N+"`D8V%L96YD87(@/2`G)RD*>PH@("`@<F5Q=6ER
M95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<["@H@("`@
M:68@*&5M<'1Y*"1C86QE;F1A<BDI('L*("`@("`@("`D8V%L96YD87(@/2!+
M<F]N;VQI=&@Z.F=E=$1E9F%U;'1#86QE;F1A<B@I.PH@("`@?0H*("`@("1H
M:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@<F5T
M=7)N("1H:7-T;W)Y+3YG971!8W1I;VY4:6UE<W1A;7`H)VMR;VYO;&ET:#HG
M("X@)&-A;&5N9&%R("X@)SHG("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1U:60L("1A8W1I;VXI.PI]"@HO*BH*("H@26UP
M;W)T<R!A;B!E=F5N="!R97!R97-E;G1E9"!I;B!T:&4@<W!E8VEF:65D(&-O
M;G1E;G0@='EP92X*("H*("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@
M(%1H92!C;VYT96YT(&]F('1H92!E=F5N="X*("H@0'!A<F%M('-T<FEN9R`D
M8V]N=&5N=%1Y<&4@(%=H870@9F]R;6%T(&ES('1H92!D871A(&EN/R!#=7)R
M96YT;'D@<W5P<&]R=',Z"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\<')E/@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&5X="]C
M86QE;F1A<@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&5X="]X
M+6EC86QE;F1A<@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&5X
M="]X+79C86QE;F1A<@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&5X="]X+79E=F5N=`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]P<F4^"B`J($!P87)A;2!S=')I;F<@)&-A;&5N9&%R("`@("!7:&%T(&-A
M;&5N9&%R('-H;W5L9"!T:&4@979E;G0@8F4@861D960@=&\_"B`J"B`J($!R
M971U<FX@;6EX960@(%1H92!E=F5N="=S(%5)1"P@;W(@82!014%27T5R<F]R
M(&]N(&9A:6QU<F4N"B`J+PIF=6YC=&EO;B!?:W)O;F]L:71H7VEM<&]R="@D
M8V]N=&5N="P@)&-O;G1E;G14>7!E+"`D8V%L96YD87(@/2!N=6QL*0I["B`@
M("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A<V4N<&AP
M)SL*("`@(&=L;V)A;"`D:W)O;F]L:71H.PH*("`@(&EF("@A:7-S970H)&-A
M;&5N9&%R*2D@>PH@("`@("`@("1C86QE;F1A<B`]($MR;VYO;&ET:#HZ9V5T
M1&5F875L=$-A;&5N9&%R*%!%4DU37T5$250I.PH@("`@?0H@("`@:68@*"%A
M<G)A>5]K97E?97AI<W1S*"1C86QE;F1A<BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("!+<F]N;VQI=&@Z.FQI<W1#86QE;F1A<G,H9F%L<V4L(%!%4DU3
M7T5$250I*2D@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E!E<FUI<W-I;VX@1&5N:65D(BDI.PH@("`@?0H@("`@)&MR;VYO;&ET:"T^
M;W!E;B@D8V%L96YD87(I.PH*("`@('-W:71C:"`H)&-O;G1E;G14>7!E*2![
M"B`@("!C87-E("=T97AT+V-A;&5N9&%R)SH*("`@(&-A<V4@)W1E>'0O>"UI
M8V%L96YD87(G.@H@("`@8V%S92`G=&5X="]X+79C86QE;F1A<B<Z"B`@("!C
M87-E("=T97AT+W@M=F5V96YT)SH*("`@("`@("!I9B`H(6ES7V$H)&-O;G1E
M;G0L("=(;W)D95]I0V%L96YD87)?=F5V96YT)RDI('L*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L96YD87(N<&AP)SL*("`@("`@("`@
M("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@("`@
M("!I9B`H(21I0V%L+3YP87)S979#86QE;F1A<B@D8V]N=&5N="DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(I
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-O;7!O;F5N=',@/2`D
M:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH@("`@("`@("`@("!S=VET8V@@*&-O
M=6YT*"1C;VUP;VYE;G1S*2D@>PH@("`@("`@("`@("!C87-E(#`Z"B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!I0V%L
M96YD87(@9&%T82!W87,@9F]U;F0N(BDI.PH*("`@("`@("`@("`@8V%S92`Q
M.@H@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D8V]M<&]N96YT<ULP73L*
M("`@("`@("`@("`@("`@(&EF("@A:7-?82@D8V]N=&5N="P@)TAO<F1E7VE#
M86QE;F1A<E]V979E;G0G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(G9%=F5N="!N;W0@9F]U;F0N(BDI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@)&ED<R`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D8V]M<&]N96YT<R!A<R`D
M8V]N=&5N="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1C;VYT
M96YT+"`G2&]R9&5?:4-A;&5N9&%R7W9E=F5N="<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1E=F5N="`]("8D:W)O;F]L:71H+3YG971%=F5N="@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D979E;G0M/F9R;VUI0V%L96YD
M87(H)&-O;G1E;G0I.PH@("`@("`@("`@("`@("`@("`@("`@("`D979E;G1)
M9"`]("1E=F5N="T^<V%V92@I.PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D979E;G1)9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1E=F5N=$ED.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1I9'-;
M72`]("1E=F5N=$ED.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D:61S.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D979E;G0@/2`F)&MR;VYO;&ET
M:"T^9V5T179E;G0H*3L*("`@("`@("`D979E;G0M/F9R;VUI0V%L96YD87(H
M)&-O;G1E;G0I.PH@("`@("`@("1E=F5N=$ED(#T@)&5V96YT+3YS879E*"D[
M"B`@("`@("`@8G)E86L["@H@("`@9&5F875L=#H*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N<W5P<&]R=&5D($-O;G1E
M;G0M5'EP93H@)7,B*2P@)&-O;G1E;G14>7!E*2D["B`@("!]"@H@("`@:68@
M*&ES7V$H)&5V96YT260L("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U
M<FX@)&5V96YT260["B`@("!]"@H@("`@)&5V96YT(#T@)B1K<F]N;VQI=&@M
M/F=E=$5V96YT*"1E=F5N=$ED*3L*("`@(')E='5R;B`D979E;G0M/F=E=%5)
M1"@I.PI]"@HO*BH*("H@17AP;W)T<R!A;B!E=F5N="P@:61E;G1I9FEE9"!B
M>2!5240L(&EN('1H92!R97%U97-T960@8V]N=&5N="!T>7!E+@H@*@H@*B!`
M<&%R86T@<W1R:6YG("1U:60@("`@("`@("!)9&5N=&EF>2!T:&4@979E;G0@
M=&\@97AP;W)T+@H@*B!`<&%R86T@;6EX960@)&-O;G1E;G14>7!E("!7:&%T
M(&9O<FUA="!S:&]U;&0@=&AE(&1A=&$@8F4@:6X_"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($5I=&AE<B!A('-T<FEN9R!W:71H(&]N92!O9CH*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'!R93X*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1E>'0O8V%L96YD87(*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1E>'0O>"UI8V%L96YD87(*("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1E>'0O>"UV8V%L96YD87(*("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]P<F4^"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]R(&%N(&%R<F%Y('=I=&@@;W!T:6]N<SH*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'!R93X*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=#;VYT96YT5'EP92<Z(&%S(&%B;W9E
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G14Y#3T1)3D<G.B`H
M;W!T:6]N86PI(&-H87)A8W1E<B!E;F-O9&EN9PH@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R('-T<FEN9W,@9FEE;&1S
M+@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T-(05)3150G.B`@
M*&]P=&EO;F%L*2!C:&%R<V5T("AE>"X@551&+3@I+@H@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)U9%4E-)3TXG.B`@*&]P=&EO;F%L*2!&;W)M
M870@=F5R<VEO;B`H97@N(&E#86QE;F1A<B`R+C`L('9#86QE;F1A<B`Q+C`I
M+@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+W!R93X*("H*("H@
M0')E='5R;B!S=')I;F<@(%1H92!R97%U97-T960@9&%T82X*("HO"F9U;F-T
M:6]N(%]K<F]N;VQI=&A?97AP;W)T*"1U:60L("1C;VYT96YT5'EP92D*>PH@
M("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H
M<"<["B`@("!G;&]B86P@)&MR;VYO;&ET:"P@)&MR;VYO;&ET:%]S:&%R97,[
M"@H@("`@)&5V96YT(#T@)&MR;VYO;&ET:"T^9V5T0GE5240H)'5I9"D["B`@
M("!I9B`H:7-?82@D979E;G0L("=014%27T5R<F]R)RDI('L*("`@("`@("!R
M971U<FX@)&5V96YT.PH@("`@?0H*("`@(&EF("@A87)R87E?:V5Y7V5X:7-T
M<R@D979E;G0M/F=E=$-A;&5N9&%R*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@2W)O;F]L:71H.CIL:7-T0V%L96YD87)S*&9A;'-E+"!015)-4U]2
M14%$*2DI('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")0
M97)M:7-S:6]N($1E;FEE9"(I*3L*("`@('T*"B`@("`D=F5R<VEO;B`]("<R
M+C`G.PH@("`@:68@*&ES7V%R<F%Y*"1C;VYT96YT5'EP92DI('L*("`@("`@
M("`D;W!T:6]N<R`]("1C;VYT96YT5'EP93L*("`@("`@("`D8V]N=&5N=%1Y
M<&4@/2`D;W!T:6]N<ULG0V]N=&5N=%1Y<&4G73L*("`@("`@("!U;G-E="@D
M;W!T:6]N<ULG0V]N=&5N=%1Y<&4G72D["B`@("`@("`@:68@*&ES<V5T*"1O
M<'1I;VYS6R=615)324].)UTI*2!["B`@("`@("`@("`@("1V97)S:6]N(#T@
M)&]P=&EO;G-;)U9%4E-)3TXG73L*("`@("`@("`@("`@=6YS970H)&]P=&EO
M;G-;)U9%4E-)3TXG72D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@
M("`D;W!T:6]N<R`](&%R<F%Y*"D["B`@("!]"@H@("`@<W=I=&-H("@D8V]N
M=&5N=%1Y<&4I('L*("`@(&-A<V4@)W1E>'0O>"UV8V%L96YD87(G.@H@("`@
M("`@("\O($1O=VYG<F%D92!V97)S:6]N(&%N9"!F86QL('1H<F]U9V@N"B`@
M("`@("`@)'9E<G-I;VX@/2`G,2XP)SL*"B`@("!C87-E("=T97AT+V-A;&5N
M9&%R)SH*("`@(&-A<V4@)W1E>'0O>"UI8V%L96YD87(G.@H@("`@("`@("1I
M9&5N=&ET>2`]("8D:W)O;F]L:71H7W-H87)E<RT^9V5T261E;G1I='E">5-H
M87)E*"1K<F]N;VQI=&A?<VAA<F5S+3YG9713:&%R92@D979E;G0M/F=E=$-A
M;&5N9&%R*"DI*3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L
M96YD87(N<&AP)SL*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N
M9&%R*"1V97)S:6]N*3L*"B`@("`@("`@+R\@0W)E871E(&$@;F5W('9%=F5N
M="X*("`@("`@("`D=D5V96YT(#T@)B1E=F5N="T^=&]I0V%L96YD87(H)&E#
M86PL("1I9&5N=&ET>2D["B`@("`@("`@)'9%=F5N="T^<V5T4&%R86UE=&5R
M*"=354U-05)9)RP@)&]P=&EO;G,I.PH@("`@("`@("1V179E;G0M/G-E=%!A
M<F%M971E<B@G1$530U))4%1)3TXG+"`D;W!T:6]N<RD["B`@("`@("`@)'9%
M=F5N="T^<V5T4&%R86UE=&5R*"=,3T-!5$E/3B<L("1O<'1I;VYS*3L*"B`@
M("`@("`@)&E#86PM/F%D9$-O;7!O;F5N="@D=D5V96YT*3L*"B`@("`@("`@
M<F5T=7)N("1I0V%L+3YE>'!O<G1V0V%L96YD87(H*3L*"B`@("!D969A=6QT
M.@H@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<R(I+"`D8V]N=&5N=%1Y<&4I
M*3L["B`@("!]"GT*"B\J*@H@*B!%>'!O<G1S(&$@8V%L96YD87(@:6X@=&AE
M(')E<75E<W1E9"!C;VYT96YT('1Y<&4N"B`J"B`J($!P87)A;2!S=')I;F<@
M)&-A;&5N9&%R("`@(%1H92!C86QE;F1A<B!T;R!E>'!O<G0N"B`J($!P87)A
M;2!M:7AE9"`D8V]N=&5N=%1Y<&4@(%=H870@9F]R;6%T('-H;W5L9"!T:&4@
M9&%T82!B92!I;C\*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@16ET
M:&5R(&$@<W1R:6YG('=I=&@@;VYE(&]F.@H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\<')E/@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T97AT+V-A;&5N9&%R"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1E>'0O>"UI8V%L96YD87(*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&5X="]X+79C86QE;F1A<@H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+W!R93X*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@
M86X@87)R87D@=VET:"!O<'1I;VYS.@H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\<')E/@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M0V]N=&5N=%1Y<&4G.B!A<R!A8F]V90H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G14Y#3T1)3D<G.B`H;W!T:6]N86PI(&-H87)A8W1E<B!E;F-O
M9&EN9R!F;W(*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R:6YG<R!F:65L9',N"B`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=#2$%24T54)SH@("AO<'1I;VYA;"D@8VAA<G-E="`H97@N(%54
M1BTX*2X*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U9%4E-)3TXG
M.B`@*&]P=&EO;F%L*2!&;W)M870@=F5R<VEO;B`H97@N(&E#86QE;F1A<B`R
M+C`L('9#86QE;F1A<B`Q+C`I+@H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+W!R93X*("H*("H@0')E='5R;B!S=')I;F<@(%1H92!I0V%L96YD
M87(@<F5P<F5S96YT871I;VX@;V8@=&AE(&-A;&5N9&%R+@H@*B\*9G5N8W1I
M;VX@7VMR;VYO;&ET:%]E>'!O<G1#86QE;F1A<B@D8V%L96YD87(L("1C;VYT
M96YT5'EP92D*>PH@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]B87-E+G!H<"<["B`@("!G;&]B86P@)&MR;VYO;&ET:"P@)&MR;VYO
M;&ET:%]S:&%R97,["@H@("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1C86QE
M;F1A<BP*("`@("`@("`@("`@("`@("`@("`@("`@("!+<F]N;VQI=&@Z.FQI
M<W1#86QE;F1A<G,H9F%L<V4L(%!%4DU37U)%040I*2D@>PH@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E!E<FUI<W-I;VX@1&5N:65D(BDI
M.PH@("`@?0H*("`@("1V97)S:6]N(#T@)S(N,"<["B`@("!I9B`H:7-?87)R
M87DH)&-O;G1E;G14>7!E*2D@>PH@("`@("`@("1O<'1I;VYS(#T@)&-O;G1E
M;G14>7!E.PH@("`@("`@("1C;VYT96YT5'EP92`]("1O<'1I;VYS6R=#;VYT
M96YT5'EP92==.PH@("`@("`@('5N<V5T*"1O<'1I;VYS6R=#;VYT96YT5'EP
M92==*3L*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)U9%4E-)3TXG72DI
M('L*("`@("`@("`@("`@)'9E<G-I;VX@/2`D;W!T:6]N<ULG5D524TE/3B==
M.PH@("`@("`@("`@("!U;G-E="@D;W!T:6]N<ULG5D524TE/3B==*3L*("`@
M("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("1O<'1I;VYS(#T@87)R87DH
M*3L*("`@('T*"B`@("`D:W)O;F]L:71H+3YO<&5N*"1C86QE;F1A<BD["B`@
M("`D979E;G1S(#T@)&MR;VYO;&ET:"T^;&ES=$5V96YT<RAN=6QL+"!N=6QL
M*3L*"B`@("!S=VET8V@@*"1C;VYT96YT5'EP92D@>PH@("`@8V%S92`G=&5X
M="]X+79C86QE;F1A<B<Z"B`@("`@("`@+R\@1&]W;F=R861E('9E<G-I;VX@
M86YD(&9A;&P@=&AR;W5G:"X*("`@("`@("`D=F5R<VEO;B`]("<Q+C`G.PH*
M("`@(&-A<V4@)W1E>'0O8V%L96YD87(G.@H@("`@8V%S92`G=&5X="]X+6EC
M86QE;F1A<B<Z"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L96YD
M87(N<&AP)SL*"B`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A
M<B@D=F5R<VEO;BD["B`@("`@("`@)&ED96YT:71Y(#T@)B1K<F]N;VQI=&A?
M<VAA<F5S+3YG971)9&5N=&ET>4)Y4VAA<F4H)&MR;VYO;&ET:%]S:&%R97,M
M/F=E=%-H87)E*"1C86QE;F1A<BDI.PH*("`@("`@("!F;W)E86-H("@D979E
M;G1S(&%S("1I9"D@>PH@("`@("`@("`@("`D979E;G0@/2`F)&MR;VYO;&ET
M:"T^9V5T179E;G0H)&ED*3L*("`@("`@("`@("`@)'9%=F5N="`]("8D979E
M;G0M/G1O:4-A;&5N9&%R*"1I0V%L+"`D:61E;G1I='DI.PH@("`@("`@("`@
M("`D=D5V96YT+3YS971087)A;65T97(H)U-534U!4EDG+"`D;W!T:6]N<RD[
M"B`@("`@("`@("`@("1V179E;G0M/G-E=%!A<F%M971E<B@G1$530U))4%1)
M3TXG+"`D;W!T:6]N<RD["B`@("`@("`@("`@("1V179E;G0M/G-E=%!A<F%M
M971E<B@G3$]#051)3TXG+"`D;W!T:6]N<RD["B`@("`@("`@("`@("1I0V%L
M+3YA9&1#;VUP;VYE;G0H)'9%=F5N="D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&E#86PM/F5X<&]R='9#86QE;F1A<B@I.PH*("`@(&1E9F%U;'0Z
M"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5
M;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(BDL("1C;VYT96YT5'EP92DI
M.PH@("`@?0I]"@HO*BH*("H@1&5L971E<R!A;B!E=F5N="!I9&5N=&EF:65D
M(&)Y(%5)1"X*("H*("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D=6ED("!!('-I
M;F=L92!5240@;W(@86X@87)R87D@:61E;G1I9GEI;F<@=&AE(&5V96YT*',I
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@9&5L971E+@H@*@H@
M*B!`<F5T=7)N(&)O;VQE86X@(%-U8V-E<W,@;W(@9F%I;'5R92X*("HO"F9U
M;F-T:6]N(%]K<F]N;VQI=&A?9&5L971E*"1U:60I"GL*("`@("\J($AA;F1L
M92!A;B!A<G)R87D@;V8@54E$<R!F;W(@8V]N=F5N:65N8V4@;V8@9&5L971I
M;F<@;75L=&EP;&4@979E;G1S(&%T"B`@("`@*B!O;F-E+B`J+PH@("`@:68@
M*&ES7V%R<F%Y*"1U:60I*2!["B`@("`@("`@9F]R96%C:"`H)'5I9"!A<R`D
M9RD@>PH@("`@("`@("`@("`D<F5S=6QT(#T@7VMR;VYO;&ET:%]D96QE=&4H
M)&<I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E
M+G!H<"<["B`@("!G;&]B86P@)&MR;VYO;&ET:#L*"B`@("`D979E;G0@/2`D
M:W)O;F]L:71H+3YG971">55)1"@D=6ED*3L*("`@(&EF("AI<U]A*"1E=F5N
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D979E;G0["B`@
M("!]"@H@("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1E=F5N="T^9V5T0V%L
M96YD87(H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!+<F]N;VQI=&@Z
M.FQI<W1#86QE;F1A<G,H9F%L<V4L(%!%4DU37T1%3$5412DI*2!["B`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&5R;6ES<VEO;B!$96YI
M960B*2D["B`@("!]"@H@("`@<F5T=7)N("1K<F]N;VQI=&@M/F1E;&5T945V
M96YT*"1E=F5N="T^9V5T240H*2D["GT*"B\J*@H@*B!297!L86-E<R!T:&4@
M979E;G0@:61E;G1I9FEE9"!B>2!5240@=VET:"!T:&4@8V]N=&5N="!R97!R
M97-E;G1E9"!I;B!T:&4*("H@<W!E8VEF:65D(&-O;G1E;G14>7!E+@H@*@H@
M*B!`<&%R86T@<W1R:6YG("1U:60@("`@("`@("`@261E;F9I='D@=&AE(&5V
M96YT('1O(')E<&QA8V4N"B`J($!P87)A;2!S=')I;F<@)&-O;G1E;G0@("`@
M("!4:&4@8V]N=&5N="!O9B!T:&4@979E;G0N"B`J($!P87)A;2!S=')I;F<@
M)&-O;G1E;G14>7!E("!7:&%T(&9O<FUA="!I<R!T:&4@9&%T82!I;C\@0W5R
M<F5N=&QY('-U<'!O<G1S.@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&5X="]C86QE;F1A<@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&5X="]X+6EC86QE;F1A<@H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&5X="]X+79C86QE;F1A<@H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=&5X="]X+79E=F5N=`H@*@H@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;W1H97)W:7-E+@H@*B\*9G5N
M8W1I;VX@7VMR;VYO;&ET:%]R97!L86-E*"1U:60L("1C;VYT96YT+"`D8V]N
M=&5N=%1Y<&4I"GL*("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O8F%S92YP:'`G.PH@("`@9VQO8F%L("1K<F]N;VQI=&@["@H@("`@
M)&5V96YT(#T@)&MR;VYO;&ET:"T^9V5T0GE5240H)'5I9"D["B`@("!I9B`H
M:7-?82@D979E;G0L("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@
M)&5V96YT.PH@("`@?0H*("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D979E
M;G0M/F=E=$-A;&5N9&%R*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M2W)O;F]L:71H.CIL:7-T0V%L96YD87)S*&9A;'-E+"!015)-4U]%1$E4*2DI
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")097)M:7-S
M:6]N($1E;FEE9"(I*3L*("`@('T*"B`@("!S=VET8V@@*"1C;VYT96YT5'EP
M92D@>PH@("`@8V%S92`G=&5X="]C86QE;F1A<B<Z"B`@("!C87-E("=T97AT
M+W@M:6-A;&5N9&%R)SH*("`@(&-A<V4@)W1E>'0O>"UV8V%L96YD87(G.@H@
M("`@8V%S92`G=&5X="]X+79E=F5N="<Z"B`@("`@("`@:68@*"%I<U]A*"1C
M;VYT96YT+"`G2&]R9&5?:4-A;&5N9&%R7W9E=F5N="<I*2!["B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H<"<["B`@("`@
M("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@
M("`@("`@:68@*"$D:4-A;"T^<&%R<V5V0V%L96YD87(H)&-O;G1E;G0I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C;VUP;VYE;G1S
M(#T@)&E#86PM/F=E=$-O;7!O;F5N=',H*3L*("`@("`@("`@("`@<W=I=&-H
M("AC;W5N="@D8V]M<&]N96YT<RDI('L*("`@("`@("`@("`@8V%S92`P.@H@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@
M:4-A;&5N9&%R(&1A=&$@=V%S(&9O=6YD+B(I*3L*"B`@("`@("`@("`@(&-A
M<V4@,3H*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&-O;7!O;F5N='-;
M,%T["B`@("`@("`@("`@("`@("!I9B`H(6ES7V$H)&-O;G1E;G0L("=(;W)D
M95]I0V%L96YD87)?=F5V96YT)RDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")V179E;G0@;F]T(&9O=6YD+B(I
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(DUU;'1I<&QE(&E#86QE;F1A<B!C;VUP;VYE
M;G1S(&9O=6YD.R!O;FQY(&]N92!V179E;G0@:7,@<W5P<&]R=&5D+B(I*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&5V96YT+3YF<F]M
M:4-A;&5N9&%R*"1C;VYT96YT*3L*("`@("`@("`D979E;G1)9"`]("1E=F5N
M="T^<V%V92@I.PH@("`@("`@(&)R96%K.PH*("`@(&1E9F%U;'0Z"B`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;G-U<'!O
M<G1E9"!#;VYT96YT+51Y<&4Z("5S(BDL("1C;VYT96YT5'EP92DI.PH@("`@
M?0H*("`@(')E='5R;B!I<U]A*"1E=F5N=$ED+"`G4$5!4E]%<G)O<B<I(#\@
M)&5V96YT260@.B!T<G5E.PI]"@HO*BH*("H@1V5N97)A=&5S(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B!F;W(@82!G:79E;B!T:6UE('!E<FEO9"X*("H*("H@
M0'!A<F%M(&EN=&5G97(@)'-T87)T<W1A;7`@(%1H92!S=&%R="!O9B!T:&4@
M=&EM92!P97)I;V0@=&\@<F5T<FEE=F4N"B`J($!P87)A;2!I;G1E9V5R("1E
M;F1S=&%M<"`@("!4:&4@96YD(&]F('1H92!T:6UE('!E<FEO9"!T;R!R971R
M:65V92X*("H@0'!A<F%M('-T<FEN9R`D8V%L96YD87(@("`@(%1H92!C86QE
M;F1A<B!T;R!V:65W(&9R964O8G5S>2!S;&]T<R!F;W(N"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!T:&4@=7-E<B=S(&1E
M9F%U;'0@8V%L96YD87(N"B`J"B`J($!R971U<FX@2&]R9&5?:4-A;&5N9&%R
M7W9F<F5E8G5S>2`@02!F<F5E8G5S>2!O8FIE8W0@=&AA="!C;W9E<G,@=&AE
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!E8VEF
M:65D('1I;64@<&5R:6]D+@H@*B\*9G5N8W1I;VX@7VMR;VYO;&ET:%]G971&
M<F5E0G5S>2@D<W1A<G1S=&%M<"`](&YU;&PL("1E;F1S=&%M<"`](&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&5N9&%R(#T@
M;G5L;"D*>PH@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]B87-E+G!H<"<["@H@("`@:68@*&ES7VYU;&PH)&-A;&5N9&%R*2D@>PH@
M("`@("`@("1C86QE;F1A<B`]($MR;VYO;&ET:#HZ9V5T1&5F875L=$-A;&5N
M9&%R*"D["B`@("!]"@H@("`@<F5T=7)N($MR;VYO;&ET:#HZ9V5N97)A=&5&
M<F5E0G5S>2@D8V%L96YD87(L("1S=&%R='-T86UP+"`D96YD<W1A;7`L('1R
M=64I.PI]"@HO*BH*("H@4F5T<FEE=F5S(&$@2W)O;F]L:71H7T5V96YT(&]B
M:F5C="P@9VEV96X@86X@979E;G0@54E$+@H@*@H@*B!`<&%R86T@<W1R:6YG
M("1U:60@(%1H92!E=F5N="=S(%5)1"X*("H*("H@0')E='5R;B!+<F]N;VQI
M=&A?179E;G0@($$@=F%L:60@2W)O;F]L:71H7T5V96YT(&]N('-U8V-E<W,L
M(&]R(&$@4$5!4E]%<G)O<@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M;VX@9F%I;'5R92X*("HO"F9U;F-T:6]N("9?:W)O;F]L:71H7V5V96YT1G)O
M;55)1"@D=6ED*0I["B`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+V)A<V4N<&AP)SL*("`@(&=L;V)A;"`D:W)O;F]L:71H.PH*("`@
M("1E=F5N="`]("1K<F]N;VQI=&@M/F=E=$)Y54E$*"1U:60I.PH@("`@:68@
M*&ES7V$H)&5V96YT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N
M("1E=F5N=#L*("`@('T*"B`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&5V
M96YT+3YG971#86QE;F1A<B@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M($MR;VYO;&ET:#HZ;&ES=$-A;&5N9&%R<RAF86QS92P@4$5235-?4TA/5RDI
M*2!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&5R;6ES
M<VEO;B!$96YI960B*2D["B`@("!]"@H@("`@<F5T=7)N("1E=F5N=#L*?0H*
M+RHJ"B`J(%5P9&%T97,@86X@871T96YD964G<R!R97-P;VYS92!S=&%T=7,@
M9F]R(&$@<W!E8VEF:65D(&5V96YT+@H@*@H@*B!`<&%R86T@2&]R9&5?:4-A
M;&5N9&5R7W9E=F5N="`D<F5S<&]N<V4@($$@2&]R9&5?:4-A;&5N9&5R7W9E
M=F5N="!O8FIE8W0L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=VET:"!A('9A;&ED(%5)1"!A='1R:6)U=&4@=&AA=`H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!O
M:6YT<R!T;R!A;B!E>&ES=&EN9R!E=F5N="X*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!4:&ES(&ES('1Y<&EC86QL>2!T
M:&4@=D5V96YT"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<&]R=&EO;B!O9B!A;B!I5&EP(&UE971I;F<M<F5Q=65S=`H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M<W!O;G-E+"!W:71H('1H92!A='1E;F1E92=S"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5S<&]N<V4@:6X@86X@0514
M14Y$144@<&%R86UE=&5R+@H@*@H@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,L(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("HO"F9U;F-T:6]N
M(%]K<F]N;VQI=&A?=7!D871E071T96YD964H)')E<W!O;G-E*0I["B`@("!R
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A<V4N<&AP)SL*
M("`@(&=L;V)A;"`D:W)O;F]L:71H.PH*("`@("1U:60@/2`D<F5S<&]N<V4M
M/F=E=$%T=')I8G5T92@G54E$)RD["B`@("!I9B`H:7-?82@D=6ED+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1U:60["B`@("!]"@H@("`@
M)&5V96YT(#T@)&MR;VYO;&ET:"T^9V5T0GE5240H)'5I9"D["B`@("!I9B`H
M:7-?82@D979E;G0L("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@
M)&5V96YT.PH@("`@?0H*("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D979E
M;G0M/F=E=$-A;&5N9&%R*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M2W)O;F]L:71H.CIL:7-T0V%L96YD87)S*&9A;'-E+"!015)-4U]%1$E4*2DI
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")097)M:7-S
M:6]N($1E;FEE9"(I*3L*("`@('T*"B`@("`D871N86UE<R`]("1R97-P;VYS
M92T^9V5T071T<FEB=71E*"=!5%1%3D1%12<I.PH@("`@)&%T<&%R;7,@/2`D
M<F5S<&]N<V4M/F=E=$%T=')I8G5T92@G051414Y$144G+"!T<G5E*3L*"B`@
M("!I9B`H(6ES7V%R<F%Y*"1A=&YA;65S*2D@>PH@("`@("`@("1A=&YA;65S
M(#T@87)R87DH)&%T;F%M97,I.PH@("`@?0H@("`@9F]R96%C:"`H)&%T;F%M
M97,@87,@)&EN9&5X(#T^("1A='1E;F1E92D@>PH@("`@("`@("1A='1E;F1E
M92`]('-T<E]R97!L86-E*"=-04E,5$\Z)RP@)R<L("1A='1E;F1E92D["B`@
M("`@("`@:68@*"1E=F5N="T^:&%S071T96YD964H)&%T=&5N9&5E*2D@>PH@
M("`@("`@("`@("`D979E;G0M/F%D9$%T=&5N9&5E*"1A='1E;F1E92P@2U)/
M3D],251(7U!!4E1?24=.3U)%+"!+<F]N;VQI=&@Z.G)E<W!O;G-E1G)O;4E#
M86PH)&%T<&%R;7-;)&EN9&5X75LG4$%25%-4050G72DI.PH@("`@("`@('T*
M("`@('T*"B`@("`D<F5S=6QT(#T@)&5V96YT+3YS879E*"D["B`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("!]"@H@("`@<F5T=7)N('1R=64["GT*"B\J*@H@*B!,
M:7-T<R!E=F5N=',@9F]R(&$@9VEV96X@=&EM92!P97)I;V0N"B`J"B`J($!P
M87)A;2!I;G1E9V5R("1S=&%R='-T86UP("`@("`@5&AE('-T87)T(&]F('1H
M92!T:6UE('!E<FEO9"!T;R!R971R:65V92X*("H@0'!A<F%M(&EN=&5G97(@
M)&5N9'-T86UP("`@("`@("!4:&4@96YD(&]F('1H92!T:6UE('!E<FEO9"!T
M;R!R971R:65V92X*("H@0'!A<F%M('-T<FEN9R`D8V%L96YD87(@("`@("`@
M("!4:&4@8V%L96YD87(@=&\@=FEE=R!F<F5E+V)U<WD@<VQO=',@9F]R+@H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O
M('1H92!U<V5R)W,@9&5F875L="!C86QE;F1A<BX*("H@0'!A<F%M(&)O;VQE
M86X@)'-H;W=296-U<G)E;F-E("!2971U<FX@979E<GD@:6YS=&%N8V4@;V8@
M82!R96-U<G)I;F<@979E;G0_"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@268@9F%L<V4L('=I;&P@;VYL>2!R971U<FX@<F5C=7)R:6YG
M(&5V96YT<PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]N
M8V4@:6YS:61E('1H92`D<W1A<G1$871E("T@)&5N9$1A=&4@<F%N9V4N"B`J
M"B`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(%5)1',*("HO"F9U;F-T
M:6]N(%]K<F]N;VQI=&A?;&ES=$5V96YT<R@D<W1A<G1S=&%M<"`](&YU;&PL
M("1E;F1S=&%M<"`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V%L96YD87(@/2!N=6QL+"`D<VAO=U)E8W5R<F5N8V4@/2!T<G5E
M*0I["B`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A
M<V4N<&AP)SL*"B`@("!I9B`H:7-?;G5L;"@D8V%L96YD87(I*2!["B`@("`@
M("`@)&-A;&5N9&%R(#T@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=D
M969A=6QT7W-H87)E)RD["B`@("!]"@H@("`@<F5T=7)N($MR;VYO;&ET:#HZ
M;&ES=$5V96YT<R@D<W1A<G1S=&%M<"P@)&5N9'-T86UP+"`D8V%L96YD87(L
M("1S:&]W4F5C=7)R96YC92D["GT*````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]L:6(O1&%Y5FEE=RYP:'``````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P-#`Q-#<`,3`T,3<S-C(W-3,`,#(Q,C8W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]$87DN<&AP)SL*"B\J*@H@
M*B!4:&4@2W)O;F]L:71H7T1A>59I97<Z.B!C;&%S<R!P<F]V:61E<R!A;B!!
M4$D@9F]R('9I97=I;F<@9&%Y<RX*("H*("H@)$AO<F1E.B!K<F]N;VQI=&@O
M;&EB+T1A>59I97<N<&AP+'8@,2XQ,SDN,BXX(#(P,#4O,3`O,C`@,#DZ,3<Z
M-#D@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!+<F]N;VQI=&@@,"XQ"B`J($!P
M86-K86=E($MR;VYO;&ET:`H@*B\*8VQA<W,@2W)O;F]L:71H7T1A>59I97<@
M97AT96YD<R!+<F]N;VQI=&A?1&%Y('L*"B`@("!V87(@)%]E=F5N=',@/2!A
M<G)A>2@I.PH@("`@=F%R("1?86QL7V1A>5]E=F5N=',@/2!A<G)A>2@I.PH@
M("`@=F%R("1?979E;G1?;6%T<FEX(#T@87)R87DH*3L*("`@('9A<B`D7W!A
M<G-E9"`](&9A;'-E.PH@("`@=F%R("1?<W!A;B`](&%R<F%Y*"D["B`@("!V
M87(@)%]T;W1A;'-P86X@/2`P.PH@("`@=F%R("1?<VED96)Y<VED92`](&9A
M;'-E.PH@("`@=F%R("1?8W5R<F5N=$-A;&5N9&%R<R`](&%R<F%Y*"D["@H@
M("`@9G5N8W1I;VX@2W)O;F]L:71H7T1A>59I97<H)&UO;G1H(#T@;G5L;"P@
M)&1A>2`](&YU;&PL("1Y96%R(#T@;G5L;"P@)&5V96YT<R`](&YU;&PI"B`@
M("!["B`@("`@("`@<&%R96YT.CI+<F]N;VQI=&A?1&%Y*"1M;VYT:"P@)&1A
M>2P@)'EE87(I.PH*("`@("`@("!G;&]B86P@)'!R969S.PH@("`@("`@("1T
M:&ES+3Y?<VED96)Y<VED92`]("1P<F5F<RT^9V5T5F%L=64H)W-H;W=?<VAA
M<F5D7W-I9&5?8GE?<VED92<I.PH@("`@("`@(&EF("@D=&AI<RT^7W-I9&5B
M>7-I9&4I('L*("`@("`@("`@("`@)&%L;$-A;&5N9&%R<R`]($MR;VYO;&ET
M:#HZ;&ES=$-A;&5N9&%R<R@I.PH@("`@("`@("`@("!F;W)E86-H("@D1TQ/
M0D%,4ULG9&ES<&QA>5]C86QE;F1A<G,G72!A<R`D8VED*2!["B`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C=7)R96YT0V%L96YD87)S6R1C:61=(#T@)B1A
M;&Q#86QE;F1A<G-;)&-I9%T["B`@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M;&Q?9&%Y7V5V96YT<ULD8VED72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1#
M86QE;F1A<G,@/2!A<G)A>2@P*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<U]N=6QL*"1E=F5N=',I*2!["B`@("`@("`@("`@("1E=F5N=',@/2!+<F]N
M;VQI=&@Z.FQI<W1%=F5N=',H)'1H:7,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;F5W($AO<F1E7T1A=&4H87)R87DH
M)WEE87(G(#T^("1T:&ES+3YY96%R+"`G;6]N=&@G(#T^("1T:&ES+3YM;VYT
M:"P@)VUD87DG(#T^("1T:&ES+3YM9&%Y+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=H;W5R)R`]/B`R,RP@)VUI;B<@/3X@-3DL("=S96,G(#T^(#4Y*2DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)$=,
M3T)!3%-;)V1I<W!L87E?8V%L96YD87)S)UTI.PH@("`@("`@("`@("`D=&AI
M<RT^7V5V96YT<R`](&%R<F%Y7W!O<"@D979E;G1S*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V5V96YT<R`]("1E=F5N=',["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?979E;G1S
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5V96YT<R`](&%R<F%Y*"D["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=$5V96YT<R@D979E;G1S
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?979E;G1S(#T@)&5V96YT<SL*("`@
M('T*"B`@("!F=6YC=&EO;B!H=&UL*"1T96UP;&%T95]P871H(#T@2U)/3D],
M251(7U1%35!,051%4RD*("`@('L*("`@("`@("!G;&]B86P@)'!R969S+"`D
M<')I;G1?=FEE=SL*"B`@("`@("`@:68@*"$D=&AI<RT^7W!A<G-E9"D@>PH@
M("`@("`@("`@("`D=&AI<RT^<&%R<V4H*3L*("`@("`@("!]"@H@("`@("`@
M("1S=&%R=&5D(#T@9F%L<V4["B`@("`@("`@)&9I<G-T7W)O=R`]('1R=64[
M"@H@("`@("`@(')E<75I<F4@)'1E;7!L871E7W!A=&@@+B`G+V1A>2]H96%D
M+FEN8R<["B`@("`@("`@:68@*"1T:&ES+3Y?<VED96)Y<VED92D@>PH@("`@
M("`@("`@("!R97%U:7)E("1T96UP;&%T95]P871H("X@)R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87)?<V5A<F-H+FIS)SL*("`@("`@("`@("`@<F5Q=6ER
M92`D=&5M<&QA=&5?<&%T:"`N("<O9&%Y+VAE861?<VED95]B>5]S:61E+FEN
M8R<["B`@("`@("`@?0H*("`@("`@("`D979E;G1#871E9V]R:65S(#T@87)R
M87DH*3L*"B`@("`@("`@)')O=R`]("<G.PH@("`@("`@(&EF("@A)'!R:6YT
M7W9I97<@)B8*("`@("`@("`@("`@2W)O;F]L:71H.CIG971$969A=6QT0V%L
M96YD87(H4$5235-?141)5"D@)B8*("`@("`@("`@("`@*"%E;7!T>2@D8V]N
M9ELG:&]O:W,G75LG<&5R;7-D96YI960G72D@?'P*("`@("`@("`@("`@($MR
M;VYO;&ET:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I(#T]/2!T<G5E
M('Q\"B`@("`@("`@("`@("!+<F]N;VQI=&@Z.FAA<U!E<FUI<W-I;VXH)VUA
M>%]E=F5N=',G*2`^($MR;VYO;&ET:#HZ8V]U;G1%=F5N=',H*2DI('L*("`@
M("`@("`@("`@)&%D9&5V96YT=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=A
M9&1E=F5N="YP:'`G+"!A<G)A>2@G=&EM97-T86UP)R`]/B`D=&AI<RT^<VQO
M='-;,%U;)W1I;65S=&%M<"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A
M;&QD87DG(#T^(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@
M2&]R9&4Z.G-E;&95<FPH=')U92DI*3L*("`@("`@("`@("`@)&%D9&5V96YT
M=7)L(#T@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1A9&1E
M=F5N='5R;"DL(%\H(D-R96%T92!A($YE=R!%=F5N="(I+"`G:&]U<B<I("X@
M7R@B06QL(&1A>2(I("X*("`@("`@("`@("`@("`@($AO<F1E.CII;6<H)VYE
M=U]S;6%L;"YP;F<G+"`G*R<I("X@)SPO83XG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1A9&1E=F5N='5R;"`]("<\<W!A;B!C;&%S<STB:&]U
M<B(^)R`N(%\H(D%L;"!D87DB*2`N("<\+W-P86X^)SL*("`@("`@("!]"@H@
M("`@("`@("\J(%1H92!A;&P@9&%Y(&5V96YT<R!A<F4@;F]T(&QI<W1E9"!I
M;B!D:69F97)E;G0@8V]L=6UN<RP@8G5T(&EN"B`@("`@("`@("H@9&EF9F5R
M96YT(')O=W,N("!);B!S:61E(&)Y('-I9&4@=FEE=R!W92!D;R!N;W0@<W!R
M96%D(&%N(&5V96YT"B`@("`@("`@("H@;W9E<B!M=6QT:7!L92!R;W=S(&EF
M('1H97)E(&%R92!D:69F97)E;G0@;G5M8F5R<R!O9B!A;&P@9&%Y(&5V96YT
M<PH@("`@("`@("`J(&9O<B!D:69F97)E;G0@8V%L96YD87)S+B`@5V4@:G5S
M="!P=70@;VYE(&5V96YT(&EN(&$@<VEN9VQE(')O=PH@("`@("`@("`J('=I
M=&@@;F\@<F]W<W!A;BX@(%=E('!U="!I;B!A(')O=W-P86X@:6X@=&AE(')O
M=R!A9G1E<B!T:&4@;&%S=`H@("`@("`@("`J(&5V96YT('1O(&9I;&P@86QL
M(')E;6%I;FEN9R!R;W=S+B`J+PH@("`@("`@("1R;W=S<&%N(#T@*"1T:&ES
M+3Y?86QL7V1A>5]M87AR;W=S<&%N*2`_("<@<F]W<W!A;CTB)R`N("1T:&ES
M+3Y?86QL7V1A>5]M87AR;W=S<&%N("X@)R(@)R`Z("<G.PH@("`@("`@(&9O
M<B`H)&L@/2`P.R`D:R`\("1T:&ES+3Y?86QL7V1A>5]M87AR;W=S<&%N.R`D
M:RLK*2!["B`@("`@("`@("`@("1R;W<@/2`G)SL*("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]C=7)R96YT0V%L96YD87)S(&%S("1C:60@/3X@)&-A
M;"D@>PH@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?86QL7V1A
M>5]E=F5N='-;)&-I9%TI(#T]/2`D:RD@>PH@("`@("`@("`@("`@("`@("`@
M("\O(%1H97)E(&%R92!N;R!E=F5N=',@;W(@86QL(&5V96YT<R!F;W(@=&AI
M<R!C86QE;F1A<@H@("`@("`@("`@("`@("`@("`@("\O(&AA=F4@86QR96%D
M>2!B965N('!R:6YT960N"B`@("`@("`@("`@("`@("`@("`@)')O=R`N/2`G
M/'1D(&-L87-S/2)A;&QD87DB('=I9'1H/2(Q)2(@<F]W<W!A;CTB)R`N("@D
M=&AI<RT^7V%L;%]D87E?;6%X<F]W<W!A;B`M("1K*2`N("<B(&-O;'-P86X]
M(B<N("`D=&AI<RT^7W-P86Y;)&-I9%T@+B`G(CXF;F)S<#L\+W1D/B<["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H8V]U;G0H)'1H:7,M/E]A;&Q?9&%Y
M7V5V96YT<ULD8VED72D@/B`D:RD@>PH@("`@("`@("`@("`@("`@("`@("\O
M(%=E(&AA=F4@;F]T('!R:6YT960@979E<GD@86QL(&1A>2!E=F5N="!Y970N
M(%!U="!O;F4*("`@("`@("`@("`@("`@("`@("`O+R!I;G1O('1H:7,@<F]W
M+@H@("`@("`@("`@("`@("`@("`@("1E=F5N="`]("1T:&ES+3Y?86QL7V1A
M>5]E=F5N='-;)&-I9%U;)&M=.PH@("`@("`@("`@("`@("`@("`@("1E=F5N
M=$-A=&5G;W)I97-;)&5V96YT+3YG971#871E9V]R>2@I72`]('1R=64["@H@
M("`@("`@("`@("`@("`@("`@("1R;W<@+CT@)SQT9"!C;&%S<STB9&%Y+65V
M96YT8F]X(&-A=&5G;W)Y)R`N(&UD-2@D979E;G0M/F=E=$-A=&5G;W)Y*"DI
M("X@)R(@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("=V86QI9VX](G1O
M<"(@8V]L<W!A;CTB)R`N("1T:&ES+3Y?<W!A;ELD8VED72`N("<B/B<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`D979E;G0M/F=E=$QI;FLH)'1H:7,M
M/F=E=%-T86UP*"DI("X@)SPO=&0^)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R97%U:7)E("1T96UP;&%T95]P871H
M("X@)R]D87DO86QL7V1A>2YI;F,G.PH@("`@("`@("`@("`D9FER<W1?<F]W
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H)&9I<G-T7W)O=RD@
M>PH@("`@("`@("`@("`D<F]W("X]("<\=&0@8V]L<W!A;CTB)R`N("1T:&ES
M+3Y?=&]T86QS<&%N("X@)R(^)FYB<W`[/"]T9#XG.PH@("`@("`@("`@("!R
M97%U:7)E("1T96UP;&%T95]P871H("X@)R]D87DO86QL7V1A>2YI;F,G.PH@
M("`@("`@('T*"B`@("`@("`@)'1W96YT>5]F;W5R(#T@)'!R969S+3YG9716
M86QU92@G='=E;G1Y1F]U<B<I.PH@("`@("`@("1D87E?:&]U<E]S=&%R="`]
M("1P<F5F<RT^9V5T5F%L=64H)V1A>5]H;W5R7W-T87)T)RD@+R`R("H@)'1H
M:7,M/E]S;&]T<U!E<DAO=7(["B`@("`@("`@)&1A>5]H;W5R7V5N9"`]("1P
M<F5F<RT^9V5T5F%L=64H)V1A>5]H;W5R7V5N9"<I("\@,B`J("1T:&ES+3Y?
M<VQO='-097)(;W5R.PH@("`@("`@("1R;W=S(#T@87)R87DH*3L*"B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)'1H:7,M/E]S;&]T<U!E<D1A>3L@)&DK
M*RD@>PH@("`@("`@("`@("!I9B`H)&D@/CT@)&1A>5]H;W5R7V5N9"`F)B`D
M:2`^("1T:&ES+3YL87-T*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&D@/"`D=&AI<RT^9FER<W0@
M)B8@)&D@/"`D9&%Y7VAO=7)?<W1A<G0I('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F]W(#T@)R<[
M"B`@("`@("`@("`@(&EF("@H)&T@/2`D:2`E("1T:&ES+3Y?<VQO='-097)(
M;W5R*2`A/2`P*2!["B`@("`@("`@("`@("`@("`D=&EM92`]("<Z)R`N("1M
M("H@)'1H:7,M/E]S;&]T3&5N9W1H.PH@("`@("`@("`@("`@("`@)&AO=7)C
M;&%S<R`]("=H86QF:&]U<B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=&EM92`](&1A=&4H)'1W96YT>5]F;W5R(#\@)T<G(#H@
M)V=A)RP@)'1H:7,M/G-L;W1S6R1I75LG=&EM97-T86UP)UTI.PH@("`@("`@
M("`@("`@("`@)&AO=7)C;&%S<R`]("=H;W5R)SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7V-U<G)E;G1#86QE;F1A
M<G,I*2!["B`@("`@("`@("`@("`@("`D<F]W("X]("<\=&0^)FYB<W`[/"]T
M9#XG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7V-U<G)E;G1#86QE;F1A<G,@87,@)&-I9"`]/B`D8V%L*2!["B`@("`@
M("`@("`@("`@("`D:'-P86X@/2`P.PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]E=F5N=%]M871R:7A;)&-I9%U;)&E=(&%S("1K97DI('L*
M("`@("`@("`@("`@("`@("`@("`D979E;G0@/2`F)'1H:7,M/E]E=F5N='-;
M)&ME>5T["@H@("`@("`@("`@("`@("`@("`@("\O(%-I;F-E('=E)W9E(&UA
M9&4@<W5R92!T:&%T('1H:7,@979E;G0G<R!O=F5R;&%P(&ES(&$*("`@("`@
M("`@("`@("`@("`@("`O+R!F86-T;W(@;V8@=&AE('1O=&%L('-P86XL('=E
M(&=E="!T:&ES(&5V96YT)W,*("`@("`@("`@("`@("`@("`@("`O+R!I;F1I
M=FED=6%L('-P86X@8GD@9&EV:61I;F<@=&AE('1O=&%L('-P86X@8GD@=&AI
M<PH@("`@("`@("`@("`@("`@("`@("\O(&5V96YT)W,@;W9E<FQA<"X*("`@
M("`@("`@("`@("`@("`@("`D<W!A;B`]("1T:&ES+3Y?<W!A;ELD8VED72`O
M("1E=F5N="T^;W9E<FQA<#L*("`@("`@("`@("`@("`@("`@("`D:'-P86X@
M*ST@)'-P86X["@H@("`@("`@("`@("`@("`@("`@("1S=&%R="`](&UK=&EM
M92AF;&]O<B@D:2`O("1T:&ES+3Y?<VQO='-097)(;W5R*2P@*"1I("4@)'1H
M:7,M/E]S;&]T<U!E<DAO=7(I("H@)'1H:7,M/E]S;&]T3&5N9W1H+"`P+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;6]N
M=&@L("1T:&ES+3YM9&%Y+"`D=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1E=F5N="T^<W1A<G0M/G1I;65S=&%M<"@I(#X]("1S=&%R
M="`F)B`D979E;G0M/G-T87)T+3YT:6UE<W1A;7`H*2`\("1S=&%R="`K(#8P
M("H@)'1H:7,M/E]S;&]T3&5N9W1H('Q\("1S=&%R="`]/2`D=&AI<RT^9V5T
M4W1A;7`H*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D979E;G1#871E
M9V]R:65S6R1E=F5N="T^9V5T0V%T96=O<GDH*5T@/2!T<G5E.PH*("`@("`@
M("`@("`@("`@("`@("`@("`@)')O=R`N/2`G/'1D(&-L87-S/2)D87DM979E
M;G1B;W@@8V%T96=O<GDG("X@;60U*"1E=F5N="T^9V5T0V%T96=O<GDH*2D@
M+B`G(B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB
M)R`N(')O=6YD*"@Y,"`O(&-O=6YT*"1T:&ES+3Y?8W5R<F5N=$-A;&5N9&%R
M<RDI("H@*"1S<&%N("\@)'1H:7,M/E]S<&%N6R1C:61=*2D@("X@)R4B("<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;&EG;CTB=&]P(B!C
M;VQS<&%N/2(G("X@)'-P86X@+B`G(B!R;W=S<&%N/2(G("X@)&5V96YT+3YR
M;W=S<&%N("X@)R(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M979E;G0M/F=E=$QI;FLH)'1H:7,M/F=E=%-T86UP*"DI("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<F;F)S<#L\+W1D/B<["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("1D:69F(#T@)'1H:7,M/E]S<&%N6R1C:61=("T@)&AS<&%N.PH@("`@("`@
M("`@("`@("`@:68@*"1D:69F(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1R;W<@+CT@<W1R7W)E<&5A="@G/'1D/B9N8G-P.SPO=&0^)RP@)&1I9F8I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H(21P<FEN=%]V:65W("8F"B`@("`@("`@("`@("`@("!+<F]N;VQI
M=&@Z.F=E=$1E9F%U;'1#86QE;F1A<BA015)-4U]%1$E4*2`F)@H@("`@("`@
M("`@("`@("`@*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG<&5R;7-D96YI960G
M72D@?'P*("`@("`@("`@("`@("`@("!+<F]N;VQI=&@Z.FAA<U!E<FUI<W-I
M;VXH)VUA>%]E=F5N=',G*2`]/3T@=')U92!\?`H@("`@("`@("`@("`@("`@
M($MR;VYO;&ET:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I(#X@2W)O
M;F]L:71H.CIC;W5N=$5V96YT<R@I*2D@>PH@("`@("`@("`@("`@("`@)&%D
M9&5V96YT=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=A9&1E=F5N="YP:'`G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=T:6UE<W1A;7`G(#T^("1T:&ES+3YS;&]T<ULD:5U;
M)W1I;65S=&%M<"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=U<FPG(#T^($AO<F1E.CIS96QF
M57)L*'1R=64I*2D["B`@("`@("`@("`@("`@("`D861D979E;G1U<FP@/2!(
M;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC871I;VY5<FPH)&%D9&5V96YT=7)L
M*2P@7R@B0W)E871E(&$@3F5W($5V96YT(BDL("1H;W5R8VQA<W,I("X*("`@
M("`@("`@("`@("`@("`@("`D=&EM92`N($AO<F1E.CII;6<H)VYE=U]S;6%L
M;"YP;F<G+"`G*R<I("X@)SPO83XG.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&%D9&5V96YT=7)L(#T@)SQS<&%N(&-L87-S/2(G
M("X@)&AO=7)C;&%S<R`N("<B/B<@+B`D=&EM92`N("<\+W-P86X^)SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)')O=W-;72`](&%R<F%Y*"=R;W<G
M(#T^("1R;W<L("=S;&]T)R`]/B`D861D979E;G1U<FPI.PH@("`@("`@('T*
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]496UP;&%T92YP:'`G.PH@
M("`@("`@("1T96UP;&%T92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*("`@
M("`@("`D=&5M<&QA=&4M/G-E="@G<F]W7VAE:6=H="<L(')O=6YD*#(P("\@
M)'1H:7,M/E]S;&]T<U!E<DAO=7(I*3L*("`@("`@("`D=&5M<&QA=&4M/G-E
M="@G<F]W<R<L("1R;W=S*3L*("`@("`@("`D=&5M<&QA=&4M/G-E="@G<VAO
M=U]S;&]T<R<L('1R=64L('1R=64I.PH@("`@("`@(&5C:&\@)'1E;7!L871E
M+3YF971C:"@D=&5M<&QA=&5?<&%T:"`N("<O9&%Y+W)O=W,N:'1M;"<I.PH*
M("`@("`@("!R97%U:7)E("1T96UP;&%T95]P871H("X@)R]C871E9V]R>5]L
M96=E;F0N:6YC)SL*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I
M;VX@<G5N<R!T:')O=6=H('1H92!E=F5N=',@86YD('1R:65S('1O(&9I9W5R
M92!O=70*("`@("`J('=H870@<VAO=6QD(&)E(&]N(&5A8V@@;&EN92!O9B!T
M:&4@;W5T<'5T('1A8FQE+B!4:&ES(&ES(&$*("`@("`J(&QI='1L92!T<FEC
M:WDN"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E*"D*("`@('L*("`@("`@
M("!G;&]B86P@)'!R969S.PH*("`@("`@("`D=&UP(#T@87)R87DH*3L*("`@
M("`@("`D=&AI<RT^7V%L;%]D87E?;6%X<F]W<W!A;B`](#`["@H@("`@("`@
M("\O(%-E<&%R871E(&]U="!A;&P@9&%Y(&5V96YT<R!A;F0@9&\@<V]M92!I
M;FET:6%L:7IA=&EO;B]P<F5P"B`@("`@("`@+R\@9F]R('!A<G-I;F<N"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]C=7)R96YT0V%L96YD87)S(&%S("1C
M:60@/3X@)&-A;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V%L;%]D87E?979E
M;G1S6R1C:61=(#T@87)R87DH*3L*("`@("`@("`@("`@)'1H:7,M/E]A;&Q?
M9&%Y7W)O=W-P86Y;)&-I9%T@/2`P.PH@("`@("`@('T*"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]E=F5N=',@87,@)&ME>2`]/B`D979E;G0I('L*("`@
M("`@("`@("`@+R\@268@=V4@:&%V92!S:61E7V)Y7W-I9&4@=V4@;VYL>2!W
M86YT('1O(&EN8VQU9&4@=&AE"B`@("`@("`@("`@("\O(&5V96YT(&EN('1H
M92!P<F]P97(@8V%L96YD87(N"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W-I
M9&5B>7-I9&4I('L*("`@("`@("`@("`@("`@("1C:60@/2`D979E;G0M/F=E
M=$-A;&5N9&%R*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D8VED(#T@,#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@
M06QL(&1A>2!E=F5N=',@87)E(&5A<WD[('-T;W)E('1H96T@<V5P97)A=&5L
M>2X*("`@("`@("`@("`@:68@*"1E=F5N="T^:7-!;&Q$87DH*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A;&Q?9&%Y7V5V96YT<ULD8VED75M=(#T@
M)E5T:6PZ.F-L;VYE3V)J96-T*"1E=F5N="D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%L;%]D87E?<F]W<W!A;ELD8VED72LK.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A;&Q?9&%Y7VUA>')O=W-P86X@/2!M87@H)'1H:7,M/E]A
M;&Q?9&%Y7VUA>')O=W-P86XL("1T:&ES+3Y?86QL7V1A>5]R;W=S<&%N6R1C
M:61=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O
M($EN:71I86QI>F4@=&AE(&YU;6)E<B!O9B!E=F5N=',@=&AA="!T:&ES(&5V
M96YT"B`@("`@("`@("`@("`@("`O+R!O=F5R;&%P<R!W:71H+@H@("`@("`@
M("`@("`@("`@)&5V96YT+3YO=F5R;&%P(#T@,#L*"B`@("`@("`@("`@("`@
M("`O+R!);FET:6%L:7IE('1H:7,@979E;G0G<R!V97)T:6-A;"!S<&%N+@H@
M("`@("`@("`@("`@("`@)&5V96YT+3YR;W=S<&%N(#T@,#L*"B`@("`@("`@
M("`@("`@("`O+R!-86ME('-U<F4@=&AA="!W92=R92!U<VEN9R!T:&4@8W5R
M<F5N="!D871E(&9O<@H@("`@("`@("`@("`@("`@+R\@<F5C=7)R:6YG(&5V
M96YT<RX*("`@("`@("`@("`@("`@(&EF("@A)&5V96YT+3YH87-296-U<E1Y
M<&4H2U)/3D],251(7U)%0U527TY/3D4I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&5V96YT+3YS=&%R="`]("95=&EL.CIC;&]N94]B:F5C="@D979E;G0M
M/G-T87)T*3L*("`@("`@("`@("`@("`@("`@("`D979E;G0M/G-T87)T+3YM
M9&%Y(#T@)'1H:7,M/FUD87D["B`@("`@("`@("`@("`@("`@("`@)&5V96YT
M+3YS=&%R="T^;6]N=&@@/2`D=&AI<RT^;6]N=&@["B`@("`@("`@("`@("`@
M("`@("`@)&5V96YT+3YS=&%R="T^>65A<B`]("1T:&ES+3YY96%R.PH@("`@
M("`@("`@("`@("`@("`@("1E=F5N="T^96YD(#T@)FYE=R!(;W)D95]$871E
M*"1E=F5N="T^<W1A<G0M/G1I;65S=&%M<"@I("L@)&5V96YT+3YD=7)-:6X@
M*B`V,"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&UP
M6UT@/2`F571I;#HZ8VQO;F5/8FIE8W0H)&5V96YT*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^7V5V96YT<R`]("1T;7`["@H@
M("`@("`@("\O($EN:71I86QI>F4@=&AE('-E="!O9B!D:69F97)E;G0@<F]W
M<W!A;G,@;F5E9&5D+@H@("`@("`@("1S<&%N<R`](&%R<F%Y*#$@/3X@=')U
M92D["@H@("`@("`@("\O(%1R86-K('1H92!L87-T('-L;W0@:6X@=VAI8V@@
M=V4@:&%V92!A;B!E=F5N="X*("`@("`@("`D=&AI<RT^;&%S="`](#`["B`@
M("`@("`@)'1H:7,M/F9I<G-T(#T@)'1H:7,M/E]S;&]T<U!E<D1A>3L*"B`@
M("`@("`@+R\@4G5N('1H<F]U9V@@979E<GD@<VQO="P@861D:6YG(&EN(&5N
M=')I97,@9F]R(&5V97)Y(&5V96YT"B`@("`@("`@+R\@=&AA="!W92!H879E
M(&AE<F4N"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'1H:7,M/E]S;&]T
M<U!E<D1A>3L@)&DK*RD@>PH@("`@("`@("`@("`O+R!);FET:6%L:7IE('1H
M:7,@<VQO="!I;B!T:&4@979E;G0@;6%T<FEX+@H@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V-U<G)E;G1#86QE;F1A<G,@87,@)&-I9"`]/B`D8V%L
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V5V96YT7VUA=')I>%LD8VED
M75LD:5T@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M+R!#86QC=6QA=&4@=&AE('-T87)T(&%N9"!E;F0@=&EM97-T86UP<R!F;W(@
M=&AI<R!S;&]T+@H@("`@("`@("`@("`D<W1A<G0@/2!M:W1I;64H9FQO;W(H
M)&D@+R`D=&AI<RT^7W-L;W1S4&5R2&]U<BDL("@D:2`E("1T:&ES+3Y?<VQO
M='-097)(;W5R*2`J("1T:&ES+3Y?<VQO=$QE;F=T:"P@,"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YM;VYT:"P@)'1H:7,M/FUD87DL
M("1T:&ES+3YY96%R*3L*("`@("`@("`@("`@)&5N9"`]("1S=&%R="`K("@V
M,"`J("1T:&ES+3Y?<VQO=$QE;F=T:"D["@H@("`@("`@("`@("`O+R!396%R
M8V@@=&AR;W5G:"!O=7(@979E;G1S+@H@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7V5V96YT<R!A<R`D:V5Y(#T^("1E=F5N="D@>PH@("`@("`@("`@
M("`@("`@+R\@268@=V4@:&%V92!S:61E7V)Y7W-I9&4@=V4@;VYL>2!W86YT
M('1O(&EN8VQU9&4@=&AE"B`@("`@("`@("`@("`@("`O+R!E=F5N="!I;B!T
M:&4@<')O<&5R(&-A;&5N9&%R+@H@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?<VED96)Y<VED92D@>PH@("`@("`@("`@("`@("`@("`@("1C:60@/2`D
M979E;G0M/F=E=$-A;&5N9&%R*"D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1C:60@/2`P.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("\O($EF('1H92!E=F5N="!F86QL<R!A
M;GEW:&5R92!I;G-I9&4@=&AI<R!S;&]T+"!A9&0*("`@("`@("`@("`@("`@
M("\O(&ET+"!M86ME('-U<F4@;W1H97(@979E;G1S(&MN;W<@=&AA="!T:&5Y
M(&]V97)L87`*("`@("`@("`@("`@("`@("\O(&ET+"!A;F0@:6YC<F5M96YT
M('1H92!E=F5N="=S('9E<G1I8V%L('-P86XN"B`@("`@("`@("`@("`@("!I
M9B`H*"1E=F5N="T^96YD+3YT:6UE<W1A;7`H*2`^("1S=&%R="`F)B`D979E
M;G0M/G-T87)T+3YT:6UE<W1A;7`H*2`\("1E;F0@*2!\?`H@("`@("`@("`@
M("`@("`@("`@("@D979E;G0M/F5N9"T^=&EM97-T86UP*"D@/3T@)&5V96YT
M+3YS=&%R="T^=&EM97-T86UP*"D@)B8@)&5V96YT+3YS=&%R="T^=&EM97-T
M86UP*"D@/3T@)'-T87)T*2D@>PH*("`@("`@("`@("`@("`@("`@("`O+R!-
M86ME('-U<F4@=V4@:V5E<"!T:&4@;&%T97-T(&AO=7(@=&AA;B!A;B!E=F5N
M=`H@("`@("`@("`@("`@("`@("`@("\O(')E86-H97,@=7`M=&\M9&%T92X*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&D@/B`D=&AI<RT^;&%S="D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&%S="`]("1I.PH@("`@
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@+R\@36%K
M92!S=7)E('=E(&ME97`@=&AE(&9I<G-T(&AO=7(@=&AA;B!A;B!E=F5N=`H@
M("`@("`@("`@("`@("`@("`@("\O(')E86-H97,@=7`M=&\M9&%T92X*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&D@/"`D=&AI<RT^9FER<W0I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I<G-T(#T@)&D["B`@("`@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O+R!!9&0@
M=&AI<R!E=F5N="!T;R!T:&4@979E;G1S('=H:6-H(&%R92!I;B!T:&ES"B`@
M("`@("`@("`@("`@("`@("`@+R\@<F]W+@H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?979E;G1?;6%T<FEX6R1C:61=6R1I75M=(#T@)&ME>3L*"B`@
M("`@("`@("`@("`@("`@("`@+R\@26YC<F5M96YT('1H92!E=F5N="=S('9E
M<G1I8V%L('-P86XN"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E=F5N
M='-;)&ME>5TM/G)O=W-P86XK*SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C=7)R96YT
M0V%L96YD87)S(&%S("1C:60@/3X@)&-A;"D@>PH@("`@("`@("`@("`@("`@
M+R\@57!D871E('1H92!N=6UB97(@;V8@979E;G1S('1H870@979E;G1S(&EN
M('1H:7,@<F]W"B`@("`@("`@("`@("`@("`O+R!O=F5R;&%P('=I=&@N"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5V96YT7VUA=')I>%LD
M8VED75LD:5T@87,@)&5V*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]E=F5N='-;)&5V72T^;W9E<FQA<"`](&UA>"@D=&AI<RT^7V5V96YT<ULD
M979=+3YO=F5R;&%P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]U;G0H)'1H:7,M/E]E=F5N=%]M
M871R:7A;)&-I9%U;)&E=*2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@+R\@57!D871E('1H92!S970@;V8@<F]W<W!A;G,@=&\@:6YC
M;'5D92!T:&4@=F%L=64@9F]R"B`@("`@("`@("`@("`@("`O+R!T:&ES(')O
M=RX*("`@("`@("`@("`@("`@("1S<&%N<ULD8VED75MC;W5N="@D=&AI<RT^
M7V5V96YT7VUA=')I>%LD8VED75LD:5TI72`]('1R=64["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8W5R<F5N
M=$-A;&5N9&%R<R!A<R`D8VED(#T^("1C86PI('L*("`@("`@("`@("`@+R\@
M4V]R="!E=F5R>2!R;W<@8GD@979E;G0@9'5R871I;VXL('-O('1H870@;&]N
M9V5R(&5V96YT<R!A<F4*("`@("`@("`@("`@+R\@9F%R=&AE<B!T;R!T:&4@
M;&5F="X*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P]("1T:&ES+3YL
M87-T.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M
M/E]E=F5N=%]M871R:7A;)&-I9%U;)&E=*2D@>PH@("`@("`@("`@("`@("`@
M("`@('5S;W)T*"1T:&ES+3Y?979E;G1?;6%T<FEX6R1C:61=6R1I72P@87)R
M87DH)'1H:7,L("=?<V]R=$)Y1'5R871I;VXG*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($YO=R!T:&%T('=E
M(&AA=F4@=&AE(&YU;6)E<B!O9B!E=F5N=',@:6X@96%C:"!R;W<L('=E"B`@
M("`@("`@("`@("\O(&-A;B!C86QC=6QA=&4@=&AE('1O=&%L('-P86X@;F5E
M9&5D+@H@("`@("`@("`@("`D<W!A;ELD8VED72`](#$["@H@("`@("`@("`@
M("`O+R!4=7)N(&ME>7,@:6YT;R!A<G)A>2!V86QU97,N"B`@("`@("`@("`@
M("1S<&%N<ULD8VED72`](&%R<F%Y7VME>7,H)'-P86YS6R1C:61=*3L*"B`@
M("`@("`@("`@("\O(%-T87)T('=I=&@@=&AE(&)I9V=E<W0@;VYE(&9I<G-T
M+@H@("`@("`@("`@("!R<V]R="@D<W!A;G-;)&-I9%TI.PH@("`@("`@("`@
M("!F;W)E86-H("@D<W!A;G-;)&-I9%T@87,@)',I('L*("`@("`@("`@("`@
M("`@("\O($EF('1H92!N=6UB97(@;V8@979E;G1S(&EN('1H:7,@<F]W(&1O
M97-N)W0@9&EV:61E"B`@("`@("`@("`@("`@("`O+R!C;&5A;FQY(&EN=&\@
M=&AE(&-U<G)E;G0@=&]T86P@<W!A;BP@=V4@;F5E9"!T;PH@("`@("`@("`@
M("`@("`@+R\@;75L=&EP;'D@=&AE('1O=&%L('-P86X@8GD@=&AE(&YU;6)E
M<B!O9B!E=F5N=',@:6X*("`@("`@("`@("`@("`@("\O('1H:7,@<F]W+@H@
M("`@("`@("`@("`@("`@:68@*"1S<&%N6R1C:61=("4@)',@(3T@,"D@>PH@
M("`@("`@("`@("`@("`@("`@("1S<&%N6R1C:61=("H]("1S.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M=&]T86QS<&%N("L]("1S<&%N6R1C:61=.PH@("`@("`@('T*("`@("`@("`O
M+R!3970@=&AE(&9I;F%L('-P86XN"B`@("`@("`@:68@*&ES<V5T*"1S<&%N
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-P86X@/2`D<W!A;CL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W1O=&%L<W!A;B`](#$[
M"B`@("`@("`@?0H*("`@("`@("`O+R!792=R92!N;W<@<&%R<V5D(&%N9"!R
M96%D>2!T;R!G;RX*("`@("`@("`D=&AI<RT^7W!A<G-E9"`]('1R=64["B`@
M("!]"@H@("`@9G5N8W1I;VX@;&EN:R@D;V9F<V5T(#T@,"D*("`@('L*("`@
M("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=D87DN<&AP)RD[
M"B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;6]N
M=&@G+"`D=&AI<RT^9V5T5&EM92@G)6TG+"`D;V9F<V5T*2D["B`@("`@("`@
M)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;61A>2<L(&QT<FEM
M*"1T:&ES+3YG9714:6UE*"<E9"<L("1O9F9S970I*2D["B`@("`@("`@)'5R
M;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G>65A<B<L("1T:&ES+3YG
M9714:6UE*"<E62<L("1O9F9S970I*3L*"B`@("`@("`@<F5T=7)N("1U<FP[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W-O<G1">41U<F%T:6]N*"1E=D$L("1E
M=D(I"B`@("!["B`@("`@("`@)&1U<D$@/2`D=&AI<RT^7V5V96YT<ULD979!
M72T^<F]W<W!A;CL*("`@("`@("`D9'5R0B`]("1T:&ES+3Y?979E;G1S6R1E
M=D)=+3YR;W=S<&%N.PH*("`@("`@("!I9B`H)&1U<D$@/B`D9'5R0BD@>PH@
M("`@("`@("`@("!R971U<FX@+3$["B`@("`@("`@?2!E;'-E:68@*"1D=7)!
M(#T]("1D=7)"*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@('T*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI
M8B]+<F]N;VQI=&@N<&AP````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#$T-#$U-``Q,#0Q-S,V,C<U,P`P,C$V-S,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92!+
M4D].3TQ)5$A?0D%312`N("<O;&EB+T1R:79E<BYP:'`G.PH*9&5F:6YE*"=+
M4D].3TQ)5$A?4D5#55)?3D].12<L("`@("`@("`@(#`I.PID969I;F4H)TM2
M3TY/3$E42%]214-54E]$04E,62<L("`@("`@("`@,2D["F1E9FEN92@G2U)/
M3D],251(7U)%0U527U=%14M,62<L("`@("`@("`R*3L*9&5F:6YE*"=+4D].
M3TQ)5$A?4D5#55)?1$%97T]&7TU/3E1()RP@(#,I.PID969I;F4H)TM23TY/
M3$E42%]214-54E]7145+7T]&7TU/3E1()RP@-"D["F1E9FEN92@G2U)/3D],
M251(7U)%0U527UE%05),62<L("`@("`@("`U*3L*"F1E9FEN92@G2U)/3D],
M251(7U-405154U].3TY%)RP@,"D["F1E9FEN92@G2U)/3D],251(7U-40515
M4U]414Y4051)5D4G+"`Q*3L*9&5F:6YE*"=+4D].3TQ)5$A?4U1!5%537T-/
M3D9)4DU%1"<L(#(I.PID969I;F4H)TM23TY/3$E42%]35$%455-?0T%.0T5,
M3$5$)RP@,RD["F1E9FEN92@G2U)/3D],251(7U-405154U]&4D5%)RP@-"D[
M"@ID969I;F4H)TM23TY/3$E42%]215-03TY315].3TY%)RP@("`@("`Q*3L*
M9&5F:6YE*"=+4D].3TQ)5$A?4D534$].4T5?04-#15!4140G+"`@,BD["F1E
M9FEN92@G2U)/3D],251(7U)%4U!/3E-%7T1%0TQ)3D5$)RP@(#,I.PID969I
M;F4H)TM23TY/3$E42%]215-03TY315]414Y4051)5D4G+"`T*3L*"F1E9FEN
M92@G2U)/3D],251(7U!!4E1?4D5154E2140G+"`Q*3L*9&5F:6YE*"=+4D].
M3TQ)5$A?4$%25%]/4%1)3TY!3"<L(#(I.PID969I;F4H)TM23TY/3$E42%]0
M05)47TY/3D4G+"`@("`@,RD["F1E9FEN92@G2U)/3D],251(7U!!4E1?24=.
M3U)%)RP@("`T*3L*"F1E9FEN92@G2U)/3D],251(7TE425!?4D5154535"<L
M(#$I.PID969I;F4H)TM23TY/3$E42%])5$E07T-!3D-%3"<L("`R*3L*"F1E
M9FEN92@G2U)/3D],251(7T524D]27T9"7TY/5%]&3U5.1"<L(#$I.PH*+RHJ
M"B`J(%1H92!+<F]N;VQI=&@Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L
M:71Y(&-O;6UO;B!T;R!A;&P@;V8@2W)O;F]L:71H+@H@*@H@*B`D2&]R9&4Z
M(&MR;VYO;&ET:"]L:6(O2W)O;F]L:71H+G!H<"QV(#$N,C8S+C(N,S,@,C`P
M-B\P,B\R,"`R,CHQ-CHQ,R!J86X@17AP("0*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($MR
M;VYO;&ET:"`P+C$*("H@0'!A8VMA9V4@2W)O;F]L:71H"B`J+PIC;&%S<R!+
M<F]N;VQI=&@@>PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@=&AE(&5V
M96YT<R!T:&%T(&AA<'!E;B!E86-H(&1A>2!W:71H:6X@82!T:6UE('!E<FEO
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1S=&%R=$1A=&4@(%1H
M92!S=&%R="!O9B!T:&4@=&EM92!R86YG92X*("`@("`J($!P87)A;2!O8FIE
M8W0@)&5N9$1A=&4@("`@5&AE(&5N9"!O9B!T:&4@=&EM92!R86YG92X*("`@
M("`J($!P87)A;2!A<G)A>2`@)&-A;&5N9&%R<R`@5&AE(&-A;&5N9&%R<R!T
M;R!C:&5C:R!F;W(@979E;G1S+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!E=F5N=',@:&%P<&5N:6YG(&EN('1H:7,@=&EM92!P97)I;V0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1%=F5N=$ED<R@D<W1A<G1$871E
M(#T@;G5L;"P@)&5N9$1A=&4@/2!N=6QL+"`D8V%L96YD87)S(#T@;G5L;"D*
M("`@('L*("`@("`@("!G;&]B86P@)&MR;VYO;&ET:#L*"B`@("`@("`@:68@
M*"%I<W-E="@D<W1A<G1$871E*2D@>PH@("`@("`@("`@("`D<W1A<G1$871E
M(#T@)FYE=R!(;W)D95]$871E*'1I;64H*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'-T87)T1&%T92`](%5T:6PZ.F-L;VYE3V)J96-T*&YE
M=R!(;W)D95]$871E*"1S=&%R=$1A=&4I*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<W-E="@D96YD1&%T92DI('L*("`@("`@("`@("`@)&5N9$1A=&4@
M/2`F;F5W($AO<F1E7T1A=&4H=&EM92@I*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D96YD1&%T92`](%5T:6PZ.F-L;VYE3V)J96-T*&YE=R!(
M;W)D95]$871E*"1E;F1$871E*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)&-A;&5N9&%R<RDI('L*("`@("`@("`@("`@)&-A;&5N9&%R<R`]
M("1'3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R<R==.PH@("`@("`@('T*"B`@
M("`@("`@)&5V96YT261S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D
M8V%L96YD87)S(&%S("1C86PI('L*("`@("`@("`@("`@:68@*"1K<F]N;VQI
M=&@M/F=E=$-A;&5N9&%R*"D@(3T@)&-A;"D@>PH@("`@("`@("`@("`@("`@
M)&MR;VYO;&ET:"T^8VQO<V4H*3L*("`@("`@("`@("`@("`@("1K<F]N;VQI
M=&@M/F]P96XH)&-A;"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5V
M96YT261S6R1C86Q=(#T@)&MR;VYO;&ET:"T^;&ES=$5V96YT<R@D<W1A<G1$
M871E+"`D96YD1&%T92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5V
M96YT261S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@=&AE
M(&%L87)M<R!A8W1I=F4@<FEG:'0@;VX@)&1A=&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&]B:F5C="`D9&%T92`@("`@("`@(%1H92!S=&%R="!O9B!T:&4@
M=&EM92!R86YG92X*("`@("`J($!P87)A;2!A<G)A>2`@)&-A;&5N9&%R<R`@
M("!4:&4@8V%L96YD87)S('1O(&-H96-K(&9O<B!E=F5N=',N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&%L87)M<R!A8W1I=F4@;VX@)&1A
M=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1!;&%R;7,H)&1A=&4L("1C
M86QE;F1A<G,I"B`@("!["B`@("`@("`@9VQO8F%L("1K<F]N;VQI=&@["@H@
M("`@("`@("1A;&%R;7,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C
M86QE;F1A<G,@87,@)&-A;"D@>PH@("`@("`@("`@("!I9B`H)&MR;VYO;&ET
M:"T^9V5T0V%L96YD87(H*2`A/2`D8V%L*2!["B`@("`@("`@("`@("`@("`D
M:W)O;F]L:71H+3YC;&]S92@I.PH@("`@("`@("`@("`@("`@)&MR;VYO;&ET
M:"T^;W!E;B@D8V%L*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D86QA
M<FUS6R1C86Q=(#T@)&MR;VYO;&ET:"T^;&ES=$%L87)M<R@D9&%T92D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&%L87)M<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E87)C:"!F;W(@979E;G1S('=I=&@@=&AE(&=I=F5N('!R
M;W!E<G1I97,*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1Q=65R>2`@
M5&AE('-E87)C:"!Q=65R>0H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!E=F5N=',*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H*"1Q=65R
M>2D*("`@('L*("`@("`@("!G;&]B86P@)&MR;VYO;&ET:#L*"B`@("`@("`@
M:68@*"%I<W-E="@D<75E<GDM/F-A;&5N9&%R<RDI('L*("`@("`@("`@("`@
M)&-A;&5N9&%R<R`]("1'3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R<R==.PH@
M("`@("`@('T*"B`@("`@("`@)&5V96YT<R`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"`H)&-A;&5N9&%R<R!A<R`D8V%L*2!["B`@("`@("`@("`@(&EF
M("@D:W)O;F]L:71H+3YG971#86QE;F1A<B@I("$]("1C86PI('L*("`@("`@
M("`@("`@("`@("1K<F]N;VQI=&@M/F-L;W-E*"D["B`@("`@("`@("`@("`@
M("`D:W)O;F]L:71H+3YO<&5N*"1C86PI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1R971E=F5N=',@/2`D:W)O;F]L:71H+3YS96%R8V@H)'%U97)Y
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)')E=&5V96YT<R!A<R`D979E;G0I
M('L*("`@("`@("`@("`@("`@("1E=F5N='-;72`]("1E=F5N=#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E=F5N=',["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&971C:&5S(&$@<F5M;W1E(&-A;&5N9&%R
M(&EN=&\@=&AE('-E<W-I;VX@86YD(')E='5R;B!T:&4@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H92!L;V-A=&EO;B!O9B!T
M:&4@<F5M;W1E(&-A;&5N9&%R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($5I=&AE<B!T:&4@8V%L96YD87(@9&%T82P@;W(@86X@97)R;W(@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5M;W1E0V%L96YD
M87(H)'5R;"D*("`@('L*("`@("`@("`O+R!4<F5A="!W96)C86PZ+R\@55),
M<R!A<R!H='1P.B\O+@H@("`@("`@(&EF("AS=6)S='(H)'5R;"P@,"P@.2D@
M/3T@)W=E8F-A;#HO+R<I('L*("`@("`@("`@("`@)'5R;"`]('-T<E]R97!L
M86-E*"=W96)C86PZ+R\G+"`G:'1T<#HO+R<L("1U<FPI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&5M<'1Y*"1?4T534TE/3ELG:W)O;F]L:71H)UU;)W)E
M;6]T92==6R1U<FQ=*2D@>PH@("`@("`@("`@("`D;W!T:6]N<ULG;65T:&]D
M)UT@/2`G1T54)SL*("`@("`@("`@("`@)&]P=&EO;G-;)W1I;65O=70G72`]
M(#4["B`@("`@("`@("`@("1O<'1I;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@
M=')U93L*"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2%144"]297%U97-T
M+G!H<"<["B`@("`@("`@("`@("1H='1P(#T@)FYE=R!(5%107U)E<75E<W0H
M)'5R;"P@)&]P=&EO;G,I.PH@("`@("`@("`@("!`)&AT='`M/G-E;F1297%U
M97-T*"D["B`@("`@("`@("`@(&EF("@D:'1T<"T^9V5T4F5S<&]N<V5#;V1E
M*"D@(3T@,C`P*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92AS<')I;G1F*"=&86EL960@=&\@<F5T<FEE=F4@<F5M;W1E(&-A;&5N9&%R
M.B!U<FP@/2`B)7,B+"!S=&%T=7,@/2`E<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1U<FPL("1H='1P+3YG971297-P
M;VYS94-O9&4H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O
M=6QD(&YO="!O<&5N("5S+B(I+"`D=7)L*2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)%]315-324].6R=K<F]N;VQI=&@G75LG<F5M;W1E)UU;)'5R
M;%T@/2`D:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"D["@H@("`@("`@("`@("`O
M+R!,;V<@9F5T8V@@870@1$5"54<@;&5V96PN"B`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*'-P<FEN=&8H)U)E=')I979E9"!R96UO=&4@8V%L96YD
M87(@9F]R("5S.B!U<FP@/2`B)7,B)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!!=71H.CIG971!=71H*"DL("1U<FPI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M7U-%4U-)3TY;)VMR;VYO;&ET:"==6R=R96UO=&4G75LD=7)L73L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL('1H92!E=F5N=',@9G)O;2!A
M(')E;6]T92!C86QE;F1A<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<FP@(%1H92!U<FP@;V8@=&AE(')E;6]T92!C86QE;F1A<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&ES=%)E;6]T945V96YT<R@D=7)L*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D:W)O;F]L:71H.PH*("`@("`@("`D9&%T82`]($MR
M;VYO;&ET:#HZ9V5T4F5M;W1E0V%L96YD87(H)'5R;"D["B`@("`@("`@:68@
M*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1D871A.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]I0V%L96YD87(N<&AP)SL*("`@("`@("`D:4-A;"`]("9N97<@2&]R
M9&5?:4-A;&5N9&%R*"D["B`@("`@("`@:68@*"$D:4-A;"T^<&%R<V5V0V%L
M96YD87(H)&1A=&$I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@
M("`@("`@('T*"B`@("`@("`@)&-O;7!O;F5N=',@/2`D:4-A;"T^9V5T0V]M
M<&]N96YT<R@I.PH@("`@("`@("1E=F5N=',@/2!A<G)A>2@I.PH@("`@("`@
M("1C;W5N="`](&-O=6YT*"1C;VUP;VYE;G1S*3L*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)&-O;7!O
M;F5N="`]("1C;VUP;VYE;G1S6R1I73L*("`@("`@("`@("`@:68@*"1C;VUP
M;VYE;G0M/F=E=%1Y<&4H*2`]/2`G=D5V96YT)RD@>PH@("`@("`@("`@("`@
M("`@)&5V96YT(#T@)B1K<F]N;VQI=&@M/F=E=$5V96YT*"D["B`@("`@("`@
M("`@("`@("`D979E;G0M/F9R;VUI0V%L96YD87(H)&-O;7!O;F5N="D["B`@
M("`@("`@("`@("`@("`D979E;G0M/G)E;6]T94-A;"`]("1U<FP["B`@("`@
M("`@("`@("`@("`D979E;G0M/F5V96YT240@/2`D:3L*("`@("`@("`@("`@
M("`@("1E=F5N='-;72`]("1E=F5N=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1E=F5N=',["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&%N(&5V96YT(&]B:F5C="!F;W(@86X@979E;G0@;VX@
M82!R96UO=&4@8V%L96YD87(N"B`@("`@*@H@("`@("H@5&AI<R!I<R!K:6YD
M(&]F(&$@=&5M;W)A<GD@<V]L=71I;VX@=6YT:6P@=V4@8V%N(&AA=F4@;75L
M=&EP;&4@9')I=F5R<PH@("`@("H@:6X@=7-E(&%T('1H92!S86UE('1I;64N
M"B`@("`@*@H@("`@("H@0'!A<F%M("1U<FP@("`@("!4:&4@=7)L(&]F('1H
M92!R96UO=&4@8V%L96YD87(N"B`@("`@*B!`<&%R86T@)&5V96YT260@(%1H
M92!I;F1E>"!O9B!T:&4@979E;G0@;VX@=&AE(')E;6]T92!C86QE;F1A<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N($MR;VYO;&ET:%]%=F5N="`@5&AE(&5V
M96YT(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5M;W1E179E
M;G1/8FIE8W0H)'5R;"P@)&5V96YT260I"B`@("!["B`@("`@("`@9VQO8F%L
M("1K<F]N;VQI=&@["@H@("`@("`@("1D871A(#T@2W)O;F]L:71H.CIG9712
M96UO=&5#86QE;F1A<B@D=7)L*3L*("`@("`@("!I9B`H:7-?82@D9&%T82P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@
M("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+VE#86QE;F1A
M<BYP:'`G.PH@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H
M*3L*("`@("`@("!I9B`H(21I0V%L+3YP87)S979#86QE;F1A<B@D9&%T82DI
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("`D8V]M<&]N96YT<R`]("1I0V%L+3YG971#;VUP;VYE;G1S*"D["B`@
M("`@("`@:68@*&ES<V5T*"1C;VUP;VYE;G1S6R1E=F5N=$ED72D@)B8*("`@
M("`@("`@("`@)&-O;7!O;F5N='-;)&5V96YT261=+3YG9714>7!E*"D@/3T@
M)W9%=F5N="<I('L*("`@("`@("`@("`@)&5V96YT(#T@)B1K<F]N;VQI=&@M
M/F=E=$5V96YT*"D["B`@("`@("`@("`@("1E=F5N="T^9G)O;6E#86QE;F1A
M<B@D8V]M<&]N96YT<ULD979E;G1)9%TI.PH@("`@("`@("`@("`D979E;G0M
M/G)E;6]T94-A;"`]("1U<FP["B`@("`@("`@("`@("1E=F5N="T^979E;G1)
M1"`]("1E=F5N=$ED.PH*("`@("`@("`@("`@<F5T=7)N("1E=F5N=#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@86QL('1H92!E=F5N=',@=&AA="!H87!P96X@96%C
M:"!D87D@=VET:&EN(&$@=&EM92!P97)I;V0*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT?$AO<F1E7T1A=&4@)'-T87)T1&%T92`@5&AE('-T87)T(&]F('1H
M92!T:6UE(')A;F=E+@H@("`@("H@0'!A<F%M(&EN='Q(;W)D95]$871E("1E
M;F1$871E("`@(%1H92!E;F0@;V8@=&AE('1I;64@<F%N9V4N"B`@("`@*B!`
M<&%R86T@87)R87D@)&-A;&5N9&%R<R`@("`@("`@("`@5&AE(&-A;&5N9&%R
M<R!T;R!C:&5C:R!F;W(@979E;G1S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)'-H;W=296-U<G)E;F-E("`@(%)E='5R;B!E=F5R>2!I;G-T86YC92!O9B!A
M(')E8W5R<FEN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5V96YT/R!)9B!F86QS92P@=VEL;"!O;FQY(')E='5R;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E8W5R<FEN
M9R!E=F5N=',@;VYC92!I;G-I9&4@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-T87)T1&%T92`M("1E;F1$871E(')A
M;F=E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!E=F5N=',@
M:&%P<&5N:6YG(&EN('1H:7,@=&EM92!P97)I;V0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI<W1%=F5N=',H)'-T87)T1&%T92`](&YU;&PL("1E;F1$871E
M(#T@;G5L;"P@)&-A;&5N9&%R<R`](&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S:&]W4F5C=7)R96YC92`]('1R=64I"B`@("!["B`@("`@("`@
M9VQO8F%L("1K<F]N;VQI=&@L("1P<F5F<RP@)')E9VES=')Y.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1S=&%R=$1A=&4I*2!["B`@("`@("`@("`@("1S=&%R
M=$1A=&4@/2`F;F5W($AO<F1E7T1A=&4H=&EM92@I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<W1A<G1$871E(#T@571I;#HZ8VQO;F5/8FIE
M8W0H;F5W($AO<F1E7T1A=&4H)'-T87)T1&%T92DI.PH@("`@("`@('T*("`@
M("`@("!I9B`H(6ES<V5T*"1E;F1$871E*2D@>PH@("`@("`@("`@("`D96YD
M1&%T92`]("9N97<@2&]R9&5?1&%T92AT:6UE*"DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1E;F1$871E(#T@571I;#HZ8VQO;F5/8FIE8W0H
M;F5W($AO<F1E7T1A=&4H)&5N9$1A=&4I*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<W-E="@D8V%L96YD87)S*2D@>PH@("`@("`@("`@("`D8V%L96YD
M87)S(#T@)$=,3T)!3%-;)V1I<W!L87E?8V%L96YD87)S)UT["B`@("`@("`@
M?0H*("`@("`@("`D979E;G1)9',@/2!+<F]N;VQI=&@Z.FQI<W1%=F5N=$ED
M<R@D<W1A<G1$871E+"`D96YD1&%T92P@)&-A;&5N9&%R<RD["@H@("`@("`@
M("1S=&%R=$]F4&5R:6]D(#T@571I;#HZ8VQO;F5/8FIE8W0H)'-T87)T1&%T
M92D["B`@("`@("`@)'-T87)T3V9097)I;V0M/FAO=7(@/2`D<W1A<G1/9E!E
M<FEO9"T^;6EN(#T@)'-T87)T3V9097)I;V0M/G-E8R`](#`["B`@("`@("`@
M)&5N9$]F4&5R:6]D(#T@571I;#HZ8VQO;F5/8FIE8W0H)&5N9$1A=&4I.PH@
M("`@("`@("1E;F1/9E!E<FEO9"T^:&]U<B`](#(S.PH@("`@("`@("1E;F1/
M9E!E<FEO9"T^;6EN(#T@)&5N9$]F4&5R:6]D+3YS96,@/2`U.3L*"B`@("`@
M("`@)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1E=F5N
M=$ED<R!A<R`D8V%L(#T^("1E=F5N=',I('L*("`@("`@("`@("`@:68@*"1K
M<F]N;VQI=&@M/F=E=$-A;&5N9&%R*"D@(3T@)&-A;"D@>PH@("`@("`@("`@
M("`@("`@)&MR;VYO;&ET:"T^8VQO<V4H*3L*("`@("`@("`@("`@("`@("1K
M<F]N;VQI=&@M/F]P96XH)&-A;"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@9F]R96%C:"`H)&5V96YT<R!A<R`D:60I('L*("`@("`@("`@("`@("`@
M("\O($9)6$U%.B!N;R!L;VYG97(@;F5E9"!T;R!F971C:"!E=F5N=',@8F5F
M;W)E"B`@("`@("`@("`@("`@("`O+R!G971T:6YG(')E8W5R<F5N8V5S+@H@
M("`@("`@("`@("`@("`@)&5V96YT(#T@)B1K<F]N;VQI=&@M/F=E=$5V96YT
M*"1I9"D["@H@("`@("`@("`@("`@("`@2W)O;F]L:71H.CI?9V5T179E;G1S
M*"1R97-U;'1S+"`D979E;G0L("1S=&%R=$1A=&4L("1E;F1$871E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=&%R=$]F4&5R
M:6]D+"`D96YD3V9097)I;V0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-H;W=296-U<G)E;F-E*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+R\@3F%G(%1A<VMS+@H@("`@("`@(&EF("@D
M<')E9G,M/F=E=%9A;'5E*"=S:&]W7W1A<VMS)RD@)B8*("`@("`@("`@("`@
M)')E9VES=')Y+3YH87--971H;V0H)W1A<VMS+VQI<W1487-K<R<I*2!["B`@
M("`@("`@("`@("1T87-K3&ES="`]("1R96=I<W1R>2T^8V%L;"@G=&%S:W,O
M;&ES=%1A<VMS)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D=&%S:TQI<W0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1K<F]N;VQI=&@M
M/F]P96XH2W)O;F]L:71H.CIG971$969A=6QT0V%L96YD87(H4$5235-?4TA/
M5RDI.PH@("`@("`@("`@("`@("`@)&1U945N9%-T86UP(#T@;6MT:6UE*#`L
M(#`L(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5N9$1A=&4M/FUO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E;F1$871E+3YM9&%Y("L@,2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D96YD1&%T92T^>65A<BD["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&%S:TQI<W0@87,@)'1A<VLI('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T87-K6R=D=64G72D@)B8*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1A<VM;)V1U92==(#X]("1S=&%R
M=$]F4&5R:6]D+3YT:6UE<W1A;7`H*2`F)@H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&%S:ULG9'5E)UT@/"`D9'5E16YD4W1A;7`@)B8*("`@("`@("`@
M("`@("`@("`@("`@("`@96UP='DH)'1A<VM;)V-O;7!L971E9"==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D979E;G0@/2`F)&MR;VYO;&ET:"T^
M9V5T179E;G0H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&5V96YT+3YS
M9714:71L92AS<')I;G1F*%\H(D1U93H@)7,B*2P@)'1A<VM;)VYA;64G72DI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D979E;G0M/G1A<VM)1"`]("1T
M87-K6R=T87-K7VED)UT["B`@("`@("`@("`@("`@("`@("`@("`@("1E=F5N
M="T^=&%S:VQI<W1)1"`]("1T87-K6R=T87-K;&ES=%]I9"==.PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)'!R969S+3YG971686QU92@G<VAO=U]T
M87-K7V-O;&]R<R<I("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M<W-E="@D=&%S:ULG8V%T96=O<GDG72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E=F5N="T^8V%T96=O<GD@/2!I<W-E="@D=&%S:ULG8V%T
M96=O<GDG72D@/R`D=&%S:ULG8V%T96=O<GDG72`Z(&YU;&P["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&5V
M96YT+3YS=&%R="`]("9N97<@2&]R9&5?1&%T92@D=&%S:ULG9'5E)UTI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D979E;G0M/F5N9"`]("9N97<@2&]R
M9&5?1&%T92@D=&%S:ULG9'5E)UT@*R`Q*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A>5-T86UP(#T@;6MT:6UE*#`L(#`L(#`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D871E*"=N)RP@)'1A
M<VM;)V1U92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&1A=&4H)VHG+"`D=&%S:ULG9'5E)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&%T92@G62<L("1T
M87-K6R=D=64G72DI.PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT
M<ULD9&%Y4W1A;7!=6R=?=&%S:R<@+B`D=&%S:ULG=&%S:U]I9"==72`]("1E
M=F5N=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%)E;6]T92!#
M86QE;F1A<G,N"B`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)V1I<W!L87E?
M<F5M;W1E7V-A;&5N9&%R<R==(&%S("1U<FPI('L*("`@("`@("`@("`@)&5V
M96YT<R`]($MR;VYO;&ET:#HZ;&ES=%)E;6]T945V96YT<R@D=7)L*3L*("`@
M("`@("`@("`@:68@*"%I<U]A*"1E=F5N=',L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("1K<F]N;VQI=&@M/F]P96XH2W)O;F]L:71H.CIG
M971$969A=6QT0V%L96YD87(H4$5235-?4TA/5RDI.PH@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&5V96YT<R!A<R`D979E;G0I('L*("`@("`@("`@("`@
M("`@("`@("!+<F]N;VQI=&@Z.E]G971%=F5N=',H)')E<W5L=',L("1E=F5N
M="P@)'-T87)T1&%T92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5N9$1A=&4L("1S=&%R=$]F4&5R:6]D+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YD3V9097)I
M;V0L("1S:&]W4F5C=7)R96YC92D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1R97-U;'1S
M(&%S("1D87D@/3X@)&1E=F5N=',I('L*("`@("`@("`@("`@:68@*&-O=6YT
M*"1D979E;G1S*2D@>PH@("`@("`@("`@("`@("`@=6%S;W)T*"1D979E;G1S
M+"!A<G)A>2@G2W)O;F]L:71H)RP@)U]S;W)T179E;G13=&%R=%1I;64G*2D[
M"B`@("`@("`@("`@("`@("`D<F5S=6QT<ULD9&%Y72`]("1D979E;G1S.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L
M=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86QC=6QA=&5S(')E8W5R<F5N
M8V5S(&]F(&%N(&5V96YT(&1U<FEN9R!A(&-E<G1A:6X@<&5R:6]D+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5T179E;G1S*"8D<F5S=6QT<RP@)B1E=F5N="P@)'-T87)T1&%T92P@
M)&5N9$1A=&4L"B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%R=$]F4&5R
M:6]D+"`D96YD3V9097)I;V0L"B`@("`@("`@("`@("`@("`@("`@("`@("1S
M:&]W4F5C=7)R96YC92D*("`@('L*("`@("`@("!G;&]B86P@)&MR;VYO;&ET
M:#L*"B`@("`@("`@:68@*"$D979E;G0M/FAA<U)E8W5R5'EP92A+4D].3TQ)
M5$A?4D5#55)?3D].12D@)B8@)'-H;W=296-U<G)E;F-E*2!["B`@("`@("`@
M("`@("\O(%)E8W5R<FEN9R!%=F5N="X*"B`@("`@("`@("`@(&EF("@D979E
M;G0M/G-T87)T+3YC;VUP87)E1&%T951I;64H)'-T87)T3V9097)I;V0I(#P@
M,"D@>PH@("`@("`@("`@("`@("`@+R\@5&AE(&9I<G-T('1I;64@=&AE(&5V
M96YT(&AA<'!E;G,@=V%S(&)E9F]R92!T:&4@<&5R:6]D"B`@("`@("`@("`@
M("`@("`O+R!S=&%R=&5D+B!3=&%R="!S96%R8VAI;F<@9F]R(')E8W5R<F5N
M8V5S(&9R;VT@=&AE('-T87)T(&]F"B`@("`@("`@("`@("`@("`O+R!T:&4@
M<&5R:6]D+@H@("`@("`@("`@("`@("`@)&YE>'0@/2!A<G)A>2@G>65A<B<@
M/3X@)'-T87)T1&%T92T^>65A<BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VUO;G1H)R`]/B`D<W1A<G1$871E+3YM;VYT:"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VUD87DG(#T^("1S=&%R=$1A=&4M/FUD
M87DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@
M5&AE(&9I<G-T('1I;64@=&AE(&5V96YT(&AA<'!E;G,@:7,@:6X@=&AE(')A
M;F=E.R!U;FQE<W,*("`@("`@("`@("`@("`@("\O('1H97)E(&ES(&%N(&5X
M8V5P=&EO;B!F;W(@=&AI<R!O8W5R<F5N8V4L(&%D9"!I="X*("`@("`@("`@
M("`@("`@(&EF("@A)&5V96YT+3YH87-%>&-E<'1I;VXH)&5V96YT+3YS=&%R
M="T^>65A<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5V96YT+3YS=&%R="T^;6]N=&@L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E=F5N="T^<W1A<G0M/FUD87DI
M*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;;6MT:6UE*#`L(#`L
M(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E=F5N
M="T^<W1A<G0M/FUO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D979E;G0M/G-T87)T+3YM9&%Y+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D979E;G0M/G-T87)T+3YY96%R*5U;)&5V
M96YT+3YG971)1"@I72`]("1E=F5N=#L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`O+R!3=&%R="!S96%R8VAI;F<@9F]R(')E8W5R<F5N
M8V5S(&9R;VT@=&AE(&1A>2!A9G1E<B!I=`H@("`@("`@("`@("`@("`@+R\@
M<W1A<G1S+@H@("`@("`@("`@("`@("`@)&YE>'0@/2!5=&EL.CIC;&]N94]B
M:F5C="@D979E;G0M/G-T87)T*3L*("`@("`@("`@("`@("`@("1N97AT+3YM
M9&%Y*RL["B`@("`@("`@("`@("`@("`D;F5X="T^8V]R<F5C="@I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!!9&0@86QL(')E8W5R<F5N8V5S
M(&]F('1H92!E=F5N="X*("`@("`@("`@("`@)&YE>'0@/2`D979E;G0M/FYE
M>'1296-U<G)E;F-E*"1N97AT*3L*("`@("`@("`@("`@=VAI;&4@*"1N97AT
M("$]/2!F86QS92`F)B`D;F5X="T^8V]M<&%R941A=&4H)&5N9$1A=&4I(#P]
M(#`I('L*("`@("`@("`@("`@("`@(&EF("@A)&5V96YT+3YH87-%>&-E<'1I
M;VXH)&YE>'0M/GEE87(L("1N97AT+3YM;VYT:"P@)&YE>'0M/FUD87DI*2![
M"B`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;)&YE>'0M/F1A=&5S=&%M
M<"@I75LD979E;G0M/F=E=$E$*"E=(#T@)&5V96YT.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&YE>'0@/2`D979E;G0M/FYE>'1296-U
M<G)E;F-E*&%R<F%Y*"=Y96%R)R`]/B`D;F5X="T^>65A<BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;6]N=&@G(#T^("1N97AT+3YM;VYT:"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;61A>2<@/3X@)&YE
M>'0M/FUD87D@*R`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H;W5R)R`]/B`D;F5X="T^:&]U<BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;6EN)R`]/B`D;F5X="T^;6EN+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S96,G(#T^
M("1N97AT+3YS96,I*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O($5V96YT(&]N;'D@;V-C=7)S(&]N8V4N"@H@("`@
M("`@("`@("`O+R!7;W)K(&]U="!W:&%T(&1A>2!I="!S=&%R=',@;VXN"B`@
M("`@("`@("`@(&EF("@D979E;G0M/G-T87)T+3YC;VUP87)E1&%T951I;64H
M)'-T87)T3V9097)I;V0I(#P@,"D@>PH@("`@("`@("`@("`@("`@+R\@270@
M<W1A<G1E9"!B969O<F4@=&AE(&)E9VEN;FEN9R!O9B!T:&4@<&5R:6]D+@H@
M("`@("`@("`@("`@("`@)&5V96YT4W1A<G0@/2!5=&EL.CIC;&]N94]B:F5C
M="@D<W1A<G1/9E!E<FEO9"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D979E;G13=&%R="`](%5T:6PZ.F-L;VYE3V)J96-T*"1E
M=F5N="T^<W1A<G0I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!7
M;W)K(&]U="!W:&%T(&1A>2!I="!E;F1S(&]N+@H@("`@("`@("`@("!I9B`H
M)&5V96YT+3YE;F0M/F-O;7!A<F5$871E5&EM92@D96YD3V9097)I;V0I(#X@
M,"D@>PH@("`@("`@("`@("`@("`@+R\@16YD<R!A9G1E<B!T:&4@96YD(&]F
M('1H92!P97)I;V0N"B`@("`@("`@("`@("`@("`D979E;G1%;F0@/2!5=&EL
M.CIC;&]N94]B:F5C="@D96YD3V9097)I;V0I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+R\@268@=&AE(&5V96YT(&1O97-N)W0@
M96YD(&%T(#$R86T@<V5T('1H92!E;F0@9&%T92!T;R!T:&4*("`@("`@("`@
M("`@("`@("\O(&-U<G)E;G0@96YD(&1A=&4N($EF(&ET(&5N9',@870@,3)A
M;2!A;F0@9&]E<R!N;W0@96YD(&%T"B`@("`@("`@("`@("`@("`O+R!T:&4@
M<V%M92!T:6UE('1H870@:70@<W1A<G1S("@P(&1U<F%T:6]N*2P@<V5T('1H
M92!E;F0@9&%T90H@("`@("`@("`@("`@("`@+R\@=&\@=&AE('!R979I;W5S
M(&1A>2=S(&5N9"!D871E+@H@("`@("`@("`@("`@("`@:68@*"1E=F5N="T^
M96YD+3YH;W5R("$](#`@?'P*("`@("`@("`@("`@("`@("`@("`D979E;G0M
M/F5N9"T^;6EN("$](#`@?'P*("`@("`@("`@("`@("`@("`@("`D979E;G0M
M/G-T87)T+3YC;VUP87)E1&%T951I;64H)&5V96YT+3YE;F0I(#T](#`I('L*
M("`@("`@("`@("`@("`@("`@("`D979E;G1%;F0@/2!5=&EL.CIC;&]N94]B
M:F5C="@D979E;G0M/F5N9"D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1E=F5N=$5N9"`]("9N97<@2&]R9&5?1&%T
M92@*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VAO=7(G(#T^(#(S
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6EN)R`]/B`U.2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-E8R<@/3X@-3DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@/3XD979E;G0M
M/F5N9"T^;6]N=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M9&%Y)R`]/B`D979E;G0M/F5N9"T^;61A>2`M(#$L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=Y96%R)R`]/B`D979E;G0M/F5N9"T^>65A<BDI
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!!9&0@=&AE(&5V96YT('1O(&%L;"!T:&4@9&%Y<R!I="!C;W9E<G,N
M"B`@("`@("`@("`@("1I(#T@)&5V96YT4W1A<G0M/FUD87D["B`@("`@("`@
M("`@("1L;V]P1&%T92`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G;6]N=&@G
M(#T^("1E=F5N=%-T87)T+3YM;VYT:"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B`D:2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y96%R
M)R`]/B`D979E;G13=&%R="T^>65A<BDI.PH@("`@("`@("`@("!W:&EL92`H
M)&QO;W!$871E+3YC;VUP87)E1&%T951I;64H)&5V96YT16YD*2`\/2`P*2![
M"B`@("`@("`@("`@("`@("!I9B`H(2@D979E;G0M/FES06QL1&%Y*"D@)B8*
M("`@("`@("`@("`@("`@("`@("`@("1L;V]P1&%T92T^8V]M<&%R941A=&54
M:6UE*"1E=F5N=$5N9"D@/3T@,"DI('L*("`@("`@("`@("`@("`@("`@("`D
M<F5S=6QT<ULD;&]O<$1A=&4M/G1I;65S=&%M<"@I75LD979E;G0M/F=E=$E$
M*"E=(#T@)&5V96YT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&QO;W!$871E(#T@)FYE=R!(;W)D95]$871E*`H@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=M;VYT:"<@/3X@)&5V96YT4W1A<G0M/FUO;G1H+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B`K*R1I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("=Y96%R)R`]/B`D979E;G13=&%R="T^
M>65A<BDI.PH@("`@("`@("`@("`@("`@)&QO;W!$871E+3YC;W)R96-T*"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!N=6UB97(@;V8@979E;G1S(&EN(&-A;&5N9&%R<R!T
M:&%T('1H92!C=7)R96YT('5S97(@;W=N<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@979E;G1S('1H870@=&AE('5S
M97(@;W=N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1%=F5N=',H*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D:W)O;F]L:71H.PH*("`@("`@("!S=&%T
M:6,@)&-O=6YT.PH@("`@("`@(&EF("AI<W-E="@D8V]U;G0I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8V]U;G0["B`@("`@("`@?0H*("`@("`@("`D8V%L
M96YD87)S(#T@2W)O;F]L:71H.CIL:7-T0V%L96YD87)S*'1R=64L(%!%4DU3
M7T%,3"D["B`@("`@("`@)&-U<G)E;G1?8V%L96YD87(@/2`D:W)O;F]L:71H
M+3YG971#86QE;F1A<B@I.PH*("`@("`@("`D8V]U;G0@/2`P.PH@("`@("`@
M(&9O<F5A8V@@*&%R<F%Y7VME>7,H)&-A;&5N9&%R<RD@87,@)&-A;&5N9&%R
M*2!["B`@("`@("`@("`@(&EF("@D:W)O;F]L:71H+3YG971#86QE;F1A<B@I
M("$]("1C86QE;F1A<BD@>PH@("`@("`@("`@("`@("`@)&MR;VYO;&ET:"T^
M8VQO<V4H*3L*("`@("`@("`@("`@("`@("1K<F]N;VQI=&@M/F]P96XH)&-A
M;&5N9&%R*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4F5T<FEE
M=F4@=&AE(&5V96YT(&QI<W0@9G)O;2!S=&]R86=E+@H@("`@("`@("`@("`D
M8V]U;G0@*ST@8V]U;G0H)&MR;VYO;&ET:"T^;&ES=$5V96YT<R@I*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%)E;W!E;B!L87-T(&-A;&5N9&%R+@H@("`@
M("`@(&EF("@D:W)O;F]L:71H+3YG971#86QE;F1A<B@I("$]("1C=7)R96YT
M7V-A;&5N9&%R*2!["B`@("`@("`@("`@("1K<F]N;VQI=&@M/F-L;W-E*"D[
M"B`@("`@("`@("`@("1K<F]N;VQI=&@M/F]P96XH)&-U<G)E;G1?8V%L96YD
M87(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;W5N=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E86P@;F%M92P@:68@879A
M:6QA8FQE+"!O9B!A;B!E=F5N="=S+V-A;&5N9&%R)W,@;W=N97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%5S97).86UE*"1U:60I"B`@("!["B`@("`@
M("`@<W1A=&EC("1N86UE<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("@A:7-S
M970H)&YA;65S6R1U:61=*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`@("`@("`@("1I9&5N="`]("9)
M9&5N=&ET>3HZ<VEN9VQE=&]N*"=N;VYE)RP@)'5I9"D["B`@("`@("`@("`@
M("1I9&5N="T^<V5T1&5F875L="@D:61E;G0M/F=E=$1E9F%U;'0H*2D["B`@
M("`@("`@("`@("1N86UE<ULD=6ED72`]("1I9&5N="T^9V5T5F%L=64H)V9U
M;&QN86UE)RD["B`@("`@("`@("`@(&EF("AE;7!T>2@D;F%M97-;)'5I9%TI
M*2!["B`@("`@("`@("`@("`@("`D;F%M97-;)'5I9%T@/2`D=6ED.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&YA;65S6R1U
M:61=.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P<R!A($MR;VYO;&ET:"!R
M96-U<G)E;F-E('9A;'5E('1O(&$@=')A;G-L871E9"!S=')I;F<@<W5I=&%B
M;&4@9F]R"B`@("`@*B!D:7-P;&%Y+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1T>7!E("!4:&4@<F5C=7)R96YC92!V86QU93L@;VYE(&]F('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($M23TY/3$E42%]214-5
M4E]86%@@8V]N<W1A;G1S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=')A;G-L871E9"!D:7-P;&%Y86)L92!R96-U<G)E;F-E('9A;'5E
M('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5C=7)4;U-T<FEN9R@D
M='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@
M8V%S92!+4D].3TQ)5$A?4D5#55)?3D].13H*("`@("`@("`@("`@<F5T=7)N
M(%\H(D1O97,@;F]T(')E8W5R(BD["@H@("`@("`@(&-A<V4@2U)/3D],251(
M7U)%0U527T1!24Q9.@H@("`@("`@("`@("!R971U<FX@7R@B4F5C=7)S(&1A
M:6QY(BD["@H@("`@("`@(&-A<V4@2U)/3D],251(7U)%0U527U=%14M,63H*
M("`@("`@("`@("`@<F5T=7)N(%\H(E)E8W5R<R!W965K;'DB*3L*"B`@("`@
M("`@8V%S92!+4D].3TQ)5$A?4D5#55)?1$%97T]&7TU/3E1(.@H@("`@("`@
M(&-A<V4@2U)/3D],251(7U)%0U527U=%14M?3T9?34].5$@Z"B`@("`@("`@
M("`@(')E='5R;B!?*")296-U<G,@;6]N=&AL>2(I.PH*("`@("`@("!C87-E
M($M23TY/3$E42%]214-54E]914%23%DZ"B`@("`@("`@("`@(')E='5R;B!?
M*")296-U<G,@>65A<FQY(BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@36%P<R!A($MR;VYO;&ET:"!M965T:6YG('-T871U<R!S=')I;F<@
M=&\@82!T<F%N<VQA=&5D('-T<FEN9R!S=6ET86)L90H@("`@("H@9F]R(&1I
M<W!L87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T871U<R`@
M5&AE(&UE971I;F<@<W1A='5S.R!O;F4@;V8@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!+4D].3TQ)5$A?4U1!5%537UA86"!C;VYS=&%N
M=',N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T<F%N<VQA
M=&5D(&1I<W!L87EA8FQE(&UE971I;F<@<W1A='5S('-T<FEN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<W1A='5S5&]3=')I;F<H)'-T871U<RD*("`@('L*
M("`@("`@("!S=VET8V@@*"1S=&%T=7,I('L*("`@("`@("!C87-E($M23TY/
M3$E42%]35$%455-?0T].1DE2345$.@H@("`@("`@("`@("!R971U<FX@7R@B
M0V]N9FER;65D(BD["@H@("`@("`@(&-A<V4@2U)/3D],251(7U-405154U]#
M04Y#14Q,140Z"B`@("`@("`@("`@(')E='5R;B!?*")#86YC96QL960B*3L*
M"B`@("`@("`@8V%S92!+4D].3TQ)5$A?4U1!5%537T92144Z"B`@("`@("`@
M("`@(')E='5R;B!?*")&<F5E(BD["@H@("`@("`@(&-A<V4@2U)/3D],251(
M7U-405154U]414Y4051)5D4Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@
M("`@<F5T=7)N(%\H(E1E;G1A=&EV92(I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($UA<',@82!+<F]N;VQI=&@@871T96YD964@<F5S<&]N
M<V4@<W1R:6YG('1O(&$@=')A;G-L871E9"!S=')I;F<*("`@("`J('-U:71A
M8FQE(&9O<B!D:7-P;&%Y+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1R97-P;VYS92`@5&AE(&%T=&5N9&5E(')E<W!O;G-E.R!O;F4@;V8@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@($M23TY/3$E42%]2
M15-03TY315]86%@@8V]N<W1A;G1S+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=')A;G-L871E9"!D:7-P;&%Y86)L92!A='1E;F1E92!R
M97-P;VYS92!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<W!O;G-E
M5&]3=')I;F<H)')E<W!O;G-E*0H@("`@>PH@("`@("`@('-W:71C:"`H)')E
M<W!O;G-E*2!["B`@("`@("`@8V%S92!+4D].3TQ)5$A?4D534$].4T5?04-#
M15!4140Z"B`@("`@("`@("`@(')E='5R;B!?*")!8V-E<'1E9"(I.PH*("`@
M("`@("!C87-E($M23TY/3$E42%]215-03TY315]$14-,24Y%1#H*("`@("`@
M("`@("`@<F5T=7)N(%\H(D1E8VQI;F5D(BD["@H@("`@("`@(&-A<V4@2U)/
M3D],251(7U)%4U!/3E-%7U1%3E1!5$E613H*("`@("`@("`@("`@<F5T=7)N
M(%\H(E1E;G1A=&EV92(I.PH*("`@("`@("!C87-E($M23TY/3$E42%]215-0
M3TY315].3TY%.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R
M;B!?*").;VYE(BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M36%P<R!A($MR;VYO;&ET:"!A='1E;F1E92!P87)T:6-I<&%T:6]N('-T<FEN
M9R!T;R!A('1R86YS;&%T960@<W1R:6YG"B`@("`@*B!S=6ET86)L92!F;W(@
M9&ES<&QA>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&%R="`@
M5&AE(&%T=&5N9&5E('!A<G1I8VEP871I;VX[(&]N92!O9B!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!+4D].3TQ)5$A?4$%25%]86%@@8V]N
M<W1A;G1S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=')A
M;G-L871E9"!D:7-P;&%Y86)L92!A='1E;F1E92!P87)T:6-I<&%T:6]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P87)T5&]3=')I;F<H)'!A<G0I"B`@("!["B`@("`@("`@<W=I=&-H
M("@D<&%R="D@>PH@("`@("`@(&-A<V4@2U)/3D],251(7U!!4E1?3U!424].
M04PZ"B`@("`@("`@("`@(')E='5R;B!?*")/<'1I;VYA;"(I.PH*("`@("`@
M("!C87-E($M23TY/3$E42%]005)47TY/3D4Z"B`@("`@("`@("`@(')E='5R
M;B!?*").;VYE(BD["@H@("`@("`@(&-A<V4@2U)/3D],251(7U!!4E1?4D51
M54E2140Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(%\H
M(E)E<75I<F5D(BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M36%P<R!A;B!I0V%L96YD87(@871T96YD964@<F5S<&]N<V4@<W1R:6YG('1O
M('1H92!C;W)R97-P;VYD:6YG"B`@("`@*B!+<F]N;VQI=&@@=F%L=64N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5S<&]N<V4@(%1H92!A='1E
M;F1E92!R97-P;VYS92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE($MR;VYO;&ET:"!R97-P;VYS92!V86QU92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5S<&]N<V5&<F]M24-A;"@D<F5S<&]N<V4I"B`@("!["B`@("`@
M("`@<W=I=&-H("A3=')I;F<Z.G5P<&5R*"1R97-P;VYS92DI('L*("`@("`@
M("!C87-E("=!0T-%4%1%1"<Z"B`@("`@("`@("`@(')E='5R;B!+4D].3TQ)
M5$A?4D534$].4T5?04-#15!4140["@H@("`@("`@(&-A<V4@)T1%0TQ)3D5$
M)SH*("`@("`@("`@("`@<F5T=7)N($M23TY/3$E42%]215-03TY315]$14-,
M24Y%1#L*"B`@("`@("`@8V%S92`G5$5.5$%4259%)SH*("`@("`@("`@("`@
M<F5T=7)N($M23TY/3$E42%]215-03TY315]414Y4051)5D4["@H@("`@("`@
M(&-A<V4@)TY%1413+4%#5$E/3B<Z"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N($M23TY/3$E42%]215-03TY315].3TY%.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!T:&4@2%1-3"!F;W(@
M86X@979E;G0@<W1A='5S('=I9&=E="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@("!4:&4@;F%M92!O9B!T:&4@=VED9V5T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8W5R<F5N="`@5&AE('-E;&5C=&5D('-T871U
M<R!V86QU92X*("`@("`J($!P87)A;2!S=')I;F<@)&%N>2`@("`@(%=H971H
M97(@86X@)V%N>2<@:71E;2!S:&]U;&0@8F4@861D960*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@/'-E;&5C=#X@=VED9V5T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9%-T871U<U=I9&=E="@D;F%M92P@
M)&-U<G)E;G0@/2!+4D].3TQ)5$A?4U1!5%537T-/3D9)4DU%1"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A;GD@/2!F86QS92D*("`@('L*
M("`@("`@("`D:'1M;"`]("(\<V5L96-T(&ED/5PB)&YA;65<(B!N86UE/5PB
M)&YA;65<(CXB.PH*("`@("`@("`D<W1A=&EI(#T@87)R87DH"B`@("`@("`@
M("`@($M23TY/3$E42%]35$%455-?1E)%12P*("`@("`@("`@("`@2U)/3D],
M251(7U-405154U]414Y4051)5D4L"B`@("`@("`@("`@($M23TY/3$E42%]3
M5$%455-?0T].1DE2345$+`H@("`@("`@("`@("!+4D].3TQ)5$A?4U1!5%53
M7T-!3D-%3$Q%1`H@("`@("`@("D["@H@("`@("`@(&EF("@A:7-S970H)&-U
M<G)E;G0I*2!["B`@("`@("`@("`@("1C=7)R96YT(#T@2U)/3D],251(7U-4
M05154U].3TY%.PH@("`@("`@('T*"B`@("`@("`@:68@*"1A;GDI('L*("`@
M("`@("`@("`@)&AT;6P@+CT@(CQO<'1I;VX@=F%L=64]7"(B("X@2U)/3D],
M251(7U-405154U].3TY%("X@(EPB(CL*("`@("`@("`@("`@)&AT;6P@+CT@
M*"1C=7)R96YT(#T]($M23TY/3$E42%]35$%455-?3D].12D@/R`G('-E;&5C
M=&5D/2)S96QE8W1E9"(^)R`Z("<^)SL*("`@("`@("`@("`@)&AT;6P@+CT@
M7R@B06YY(BD@+B`B/"]O<'1I;VX^(CL*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1S=&%T:6D@87,@)'-T871U<RD@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`B/&]P=&EO;B!V86QU93U<(B1S=&%T=7-<(B(["B`@("`@("`@("`@
M("1H=&UL("X]("@D<W1A='5S(#T]("1C=7)R96YT*2`_("<@<V5L96-T960]
M(G-E;&5C=&5D(CXG(#H@)SXG.PH@("`@("`@("`@("`D:'1M;"`N/2!+<F]N
M;VQI=&@Z.G-T871U<U1O4W1R:6YG*"1S=&%T=7,I("X@(CPO;W!T:6]N/B([
M"B`@("`@("`@?0H@("`@("`@("1H=&UL("X]("<\+W-E;&5C=#XG.PH*("`@
M("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&%L;"!C86QE;F1A<G,@82!U<V5R(&AA<R!A8V-E<W,@=&\L(&%C8V]R
M9&EN9R!T;R!S979E<F%L"B`@("`@*B!P87)A;65T97)S+W!E<FUI<W-I;VX@
M;&5V96QS+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1O=VYE<F]N
M;'D@("!/;FQY(')E='5R;B!C86QE;F1E<G,@=&AA="!T:&ES('5S97(@;W=N
M<S\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT
M<R!T;R!F86QS92X*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N
M("!4:&4@<&5R;6ES<VEO;B!T;R!F:6QT97(@8V%L96YD87)S(&)Y+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!C86QE;F1A<B!L:7-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T0V%L96YD87)S*"1O=VYE<F]N;'D@
M/2!F86QS92P@)'!E<FUI<W-I;VX@/2!015)-4U]32$]7*0H@("`@>PH@("`@
M("`@("1C86QE;F1A<G,@/2`D1TQ/0D%,4ULG:W)O;F]L:71H7W-H87)E<R==
M+3YL:7-T4VAA<F5S*$%U=&@Z.F=E=$%U=&@H*2P@)'!E<FUI<W-I;VXL("1O
M=VYE<F]N;'D@/R!!=71H.CIG971!=71H*"D@.B!N=6QL*3L*("`@("`@("!I
M9B`H:7-?82@D8V%L96YD87)S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1C86QE;F1A<G,L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A;&5N9&%R<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1E9F%U;'0@8V%L
M96YD87(@9F]R('1H92!C=7)R96YT('5S97(@870@=&AE('-P96-I9FEE9`H@
M("`@("H@<&5R;6ES<VEO;G,@;&5V96PN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$1E9F%U;'1#86QE;F1A<B@D<&5R;6ES<VEO;B`](%!%4DU37U-(3U<I
M"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)&1E9F%U
M;'1?<VAA<F4@/2`D<')E9G,M/F=E=%9A;'5E*"=D969A=6QT7W-H87)E)RD[
M"B`@("`@("`@)&-A;&5N9&%R<R`]($MR;VYO;&ET:#HZ;&ES=$-A;&5N9&%R
M<RAF86QS92P@)'!E<FUI<W-I;VXI.PH*("`@("`@("!I9B`H:7-S970H)&-A
M;&5N9&%R<ULD9&5F875L=%]S:&%R95TI*2!["B`@("`@("`@("`@(')E='5R
M;B`D9&5F875L=%]S:&%R93L*("`@("`@("!](&5L<V5I9B`H)'!R969S+3YI
M<TQO8VME9"@G9&5F875L=%]S:&%R92<I*2!["B`@("`@("`@("`@(')E='5R
M;B`G)SL*("`@("`@("!](&5L<V5I9B`H8V]U;G0H)&-A;&5N9&%R<RDI('L*
M("`@("`@("`@("`@<F5T=7)N(&ME>2@D8V%L96YD87)S*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E<R!T:&4@9G)E92]B=7-Y('1E>'0@9F]R("1C86QE;F1A<BX@
M0V%C:&4@:70@9F]R(&%T(&QE87-T(&%N"B`@("`@*B!H;W5R+"!A<R!W96QL
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F=\87)R87D@)&-A;&5N9&%R
M("!4:&4@8V%L96YD87(@=&\@=FEE=R!F<F5E+V)U<WD@<VQO=',@9F]R+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T<W1A;7`@("`@(%1H92!S=&%R
M="!O9B!T:&4@=&EM92!P97)I;V0@=&\@<F5T<FEE=F4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D96YD<W1A;7`@("`@("`@5&AE(&5N9"!O9B!T:&4@=&EM
M92!P97)I;V0@=&\@<F5T<FEE=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<F5T=7)N3V)J("`@("`@1&5F875L="!F86QS92X@4F5T=7)N(&$@=D9R965B
M=7-Y(&]B:F5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EN<W1E860@;V8@=&5X="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&9R964O8G5S>2!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G96YE<F%T949R965"=7-Y*"1C86QE;F1A<BP@)'-T87)T<W1A;7`@/2!N
M=6QL+"`D96YD<W1A;7`@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5T=7)N3V)J(#T@9F%L<V4I"B`@("!["B`@("`@("`@9VQO
M8F%L("1K<F]N;VQI=&A?<VAA<F5S+"`D<')E9G,["@H@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH@("`@("`@(')E<75I<F5?
M;VYC92!+4D].3TQ)5$A?0D%312`N("<O;&EB+W9E<G-I;VXN<&AP)SL*"B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D8V%L96YD87(I*2!["B`@("`@("`@("`@
M("1C86QE;F1A<B`](&%R<F%Y*"1C86QE;F1A<BD["B`@("`@("`@?0H*("`@
M("`@("`O+R!&971C:"!T:&4@87!P<F]P<FEA=&4@<VAA<F4@86YD(&-H96-K
M('!E<FUI<W-I;VYS+@H@("`@("`@("1S:&%R92`]("8D:W)O;F]L:71H7W-H
M87)E<RT^9V5T4VAA<F4H)&-A;&5N9&%R6S!=*3L*("`@("`@("!I9B`H:7-?
M82@D<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@('T*"B`@("`@("`@+R\@1&5F875L="!T:&4@<W1A<G0@
M9&%T92!T;R!T;V1A>2X*("`@("`@("!I9B`H:7-?;G5L;"@D<W1A<G1S=&%M
M<"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@9&%T92@G;B<I.PH@("`@("`@
M("`@("`D>65A<B`](&1A=&4H)UDG*3L*("`@("`@("`@("`@)&1A>2`](&1A
M=&4H)VHG*3L*"B`@("`@("`@("`@("1S=&%R='-T86UP(#T@;6MT:6UE*#`L
M(#`L(#`L("1M;VYT:"P@)&1A>2P@)'EE87(I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@1&5F875L="!T:&4@96YD(&1A=&4@=&\@=&AE('-T87)T(&1A=&4@
M*R!F<F5E8G5S>5]D87ES+@H@("`@("`@(&EF("AI<U]N=6QL*"1E;F1S=&%M
M<"D@?'P@)&5N9'-T86UP(#P@)'-T87)T<W1A;7`I('L*("`@("`@("`@("`@
M)&UO;G1H(#T@9&%T92@G;B<L("1S=&%R='-T86UP*3L*("`@("`@("`@("`@
M)'EE87(@/2!D871E*"=9)RP@)'-T87)T<W1A;7`I.PH@("`@("`@("`@("`D
M9&%Y(#T@9&%T92@G:B<L("1S=&%R='-T86UP*3L*"B`@("`@("`@("`@("1E
M;F1S=&%M<"`](&UK=&EM92@P+"`P+"`P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&UO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A>2`K("1P<F5F<RT^9V5T5F%L=64H)V9R965B=7-Y7V1A>7,G
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Y96%R*3L*("`@
M("`@("!]"@H@("`@("`@("\O($=E="!T:&4@261E;G1I='D@9F]R('1H92!O
M=VYE<B!O9B!T:&4@<VAA<F4N"B`@("`@("`@)&ED96YT:71Y(#T@)DED96YT
M:71Y.CIS:6YG;&5T;VXH)VYO;F4G+"`D<VAA<F4M/F=E="@G;W=N97(G*2D[
M"B`@("`@("`@)&5M86EL(#T@)&ED96YT:71Y+3YG971686QU92@G9G)O;5]A
M9&1R)RD["B`@("`@("`@)&-N(#T@)&ED96YT:71Y+3YG971686QU92@G9G5L
M;&YA;64G*3L*"B`@("`@("`@+R\@1F5T8V@@979E;G1S+@H@("`@("`@("1S
M=&%R=$1A=&4@/2`F;F5W($AO<F1E7T1A=&4H)'-T87)T<W1A;7`I.PH@("`@
M("`@("1E;F1$871E(#T@)FYE=R!(;W)D95]$871E*"1E;F1S=&%M<"D["B`@
M("`@("`@)&)U<WD@/2!+<F]N;VQI=&@Z.FQI<W1%=F5N=',H)'-T87)T1&%T
M92P@)&5N9$1A=&4L("1C86QE;F1A<BD["@H@("`@("`@("\O($-R96%T92!T
M:&4@;F5W(&E#86QE;F1A<BX*("`@("`@("`D=D-A;"`]("9N97<@2&]R9&5?
M:4-A;&5N9&%R*"D["B`@("`@("`@)'9#86PM/G-E=$%T=')I8G5T92@G4%)/
M1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J96-T+R]+<F]N;VQI=&@@)R`N($M2
M3TY/3$E42%]615)324].("X@)R\O14XG*3L*("`@("`@("`D=D-A;"T^<V5T
M071T<FEB=71E*"=-151(3T0G+"`G4%5"3$E32"<I.PH*("`@("`@("`O+R!#
M<F5A=&4@;F5W('9&<F5E8G5S>2X*("`@("`@("`D=D9B(#T@)DAO<F1E7VE#
M86QE;F1A<CHZ;F5W0V]M<&]N96YT*"=V9G)E96)U<WDG+"`D=D-A;"D["B`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"%E;7!T>2@D
M8VXI*2!["B`@("`@("`@("`@("1P87)A;7-;)T-.)UT@/2`D8VX["B`@("`@
M("`@?0H@("`@("`@(&EF("@A96UP='DH)&5M86EL*2D@>PH@("`@("`@("`@
M("`D=D9B+3YS971!='1R:6)U=&4H)T]21T%.25I%4B<L("=-04E,5$\Z)R`N
M("1E;6%I;"P@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'9&8BT^<V5T071T<FEB=71E*"=/4D=!3DE:15(G+"`G)RP@)'!A<F%M
M<RD["B`@("`@("`@?0H*("`@("`@("`D=D9B+3YS971!='1R:6)U=&4H)T14
M4U1!35`G+"!T:6UE*"DI.PH@("`@("`@("1V1F(M/G-E=$%T=')I8G5T92@G
M1%135$%25"<L("1S=&%R='-T86UP*3L*("`@("`@("`D=D9B+3YS971!='1R
M:6)U=&4H)T1414Y$)RP@)&5N9'-T86UP*3L*("`@("`@("`D=D9B+3YS971!
M='1R:6)U=&4H)U523"<L($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9F(N<&AP
M/W4])R`N("1S:&%R92T^9V5T*"=O=VYE<B<I+"!T<G5E+"`M,2DI.PH*("`@
M("`@("`O+R!!9&0@86QL('1H92!B=7-Y('!E<FEO9',N"B`@("`@("`@9F]R
M96%C:"`H)&)U<WD@87,@)&1A>2`]/B`D979E;G1S*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1E=F5N=',@87,@)&5V96YT*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&5V96YT+3YH87-3=&%T=7,H2U)/3D],251(7U-405154U]&4D5%
M*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1D=7)A=&EO;B`]("1E=F5N="T^
M96YD+3YT:6UE<W1A;7`H*2`M("1E=F5N="T^<W1A<G0M/G1I;65S=&%M<"@I
M.PH*("`@("`@("`@("`@("`@("\O($UA:V4@<W5R92!T:&%T('=E)W)E('5S
M:6YG('1H92!C=7)R96YT(&1A=&4@9F]R(')E8W5R<FEN9PH@("`@("`@("`@
M("`@("`@+R\@979E;G1S+@H@("`@("`@("`@("`@("`@:68@*"$D979E;G0M
M/FAA<U)E8W5R5'EP92A+4D].3TQ)5$A?4D5#55)?3D].12DI('L*("`@("`@
M("`@("`@("`@("`@("`D<W1A<G14:&ES1&%Y(#T@;6MT:6UE*"1E=F5N="T^
M<W1A<G0M/FAO=7(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D979E;G0M/G-T87)T+3YM:6XL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D979E;G0M/G-T87)T+3YS
M96,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D871E*"=N)RP@)&1A>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!D871E*"=J)RP@)&1A>2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D871E*"=9)RP@)&1A
M>2DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D<W1A<G14:&ES1&%Y(#T@)&5V96YT+3YS=&%R="T^=&EM97-T86UP
M*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=D9B+3YA
M9&1"=7-Y4&5R:6]D*"="55-9)RP@)'-T87)T5&AI<T1A>2P@;G5L;"P@)&1U
M<F%T:6]N*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@
M4F5M;W9E('1H92!O=F5R;&%P<RX*("`@("`@("`D=D9B+3YS:6UP;&EF>2@I
M.PH@("`@("`@("1V0V%L+3YA9&1#;VUP;VYE;G0H)'9&8BD["@H@("`@("`@
M("\O(%)E='5R;B!T:&4@=D9R965B=7-Y(&]B:F5C="!I9B!R97%U97-T960N
M"B`@("`@("`@:68@*"1R971U<FY/8FHI('L*("`@("`@("`@("`@<F5T=7)N
M("1V1F(["B`@("`@("`@?0H*("`@("`@("`O+R!'96YE<F%T92!T:&4@=D-A
M;"!F:6QE+@H@("`@("`@(')E='5R;B`D=D-A;"T^97AP;W)T=D-A;&5N9&%R
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B!F;W(@82!G:79E;B!E;6%I;"!A9&1R97-S+"!I
M9B!A;GD*("`@("`J(&EN9F]R;6%T:6]N(&ES(&%V86EL86)L92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;6%I;"`@5&AE(&5M86EL(&%D9')E
M<W,@=&\@;&]O:R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]I
M0V%L96YD87)?=F9R965B=7-Y("!&<F5E+V)U<WD@8V]M<&]N96YT(&]N('-U
M8V-E<W,L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%!%05)?17)R;W(@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971&<F5E0G5S>2@D96UA:6PI"B`@("!["B`@("`@("`@9VQO8F%L("1C
M;VYF+"`D<')E9G,["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O:4-A
M;&5N9&%R+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+U)&0S@R
M,BYP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G
M.PH*("`@("`@("`O+R!0<F]P97)L>2!H86YD;&4@4D9#.#(R+6-O;7!L:6%N
M="!E;6%I;"!A9&1R97-S97,N"B`@("`@("`@<W1A=&EC("1R9F,X,C(["B`@
M("`@("`@:68@*&ES7VYU;&PH)')F8S@R,BDI('L*("`@("`@("`@("`@)')F
M8S@R,B`]("9N97<@36%I;%]21D,X,C(H*3L*("`@("`@("!]"@H@("`@("`@
M("1D969A=6QT7V1O;6%I;B`](&5M<'1Y*"1C;VYF6R=S=&]R86=E)UU;)V1E
M9F%U;'1?9&]M86EN)UTI(#\@;G5L;"`Z("1C;VYF6R=S=&]R86=E)UU;)V1E
M9F%U;'1?9&]M86EN)UT["B`@("`@("`@)')E<R`]("1R9F,X,C(M/G!A<G-E
M061D<F5S<TQI<W0H)&5M86EL+"`D9&5F875L=%]D;VUA:6XI.PH@("`@("`@
M(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@("`@(&EF("@A8V]U;G0H)')E
M<RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F\@=F%L:60@96UA:6P@861D<F5S<R!F;W5N9"(I*3L*("`@("`@("!]"@H@
M("`@("`@("1E;6%I;"`]($U)344Z.G)F8S@R,E=R:71E061D<F5S<R@D<F5S
M6S!=+3YM86EL8F]X+"`D<F5S6S!=+3YH;W-T*3L*"B`@("`@("`@+R\@0VAE
M8VL@:68@=V4@8V%N(')E=')I979E(&$@5D9"(&9R;VT@=&AE($9R964O0G5S
M>2!54DPL(&EF(&]N92!I<PH@("`@("`@("\O('-E="X*("`@("`@("`D=7)L
M(#T@2W)O;F]L:71H.CIG971&<F5E0G5S>55R;"@D96UA:6PI.PH@("`@("`@
M(&EF("AI<U]A*"1U<FPL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M=6YS970H)'5R;"D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'5R
M;"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(5%10+U)E<75E<W0N
M<&AP)SL*("`@("`@("`@("`@)&AT='`@/2`F;F5W($A45%!?4F5Q=65S="@D
M=7)L+"!A<G)A>2@G;65T:&]D)R`]/B`G1T54)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&EM96]U="<@
M/3X@-2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G86QL;W=2961I<F5C=',G(#T^('1R=64I*3L*("`@("`@
M("`@("`@0"1H='1P+3YS96YD4F5Q=65S="@I.PH@("`@("`@("`@("!I9B`H
M)&AT='`M/F=E=%)E<W!O;G-E0V]D92@I(#T](#(P,"`F)@H@("`@("`@("`@
M("`@("`@)&1A=&$@/2`D:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"DI('L*("`@
M("`@("`@("`@("`@("1V0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*
M("`@("`@("`@("`@("`@("1V0V%L+3YP87)S979#86QE;F1A<B@D9&%T82D[
M"@H@("`@("`@("`@("`@("`@)'9&8B`]("8D=D-A;"T^9FEN9$-O;7!O;F5N
M="@G5D92145"55-9)RD["B`@("`@("`@("`@("`@("!I9B`H)'9&8B`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'9&8CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+R\@0VAE8VL@<W1O<F%G92!D<FEV97(N"B`@("`@("`@9VQO8F%L("1C
M;VYF.PH@("`@("`@(')E<75I<F5?;VYC92!+4D].3TQ)5$A?0D%312`N("<O
M;&EB+U-T;W)A9V4N<&AP)SL*("`@("`@("`D<W1O<F%G92`]("9+<F]N;VQI
M=&A?4W1O<F%G93HZ<VEN9VQE=&]N*"D["@H@("`@("`@("1F8B`]("1S=&]R
M86=E+3YS96%R8V@H)&5M86EL*3L*("`@("`@("!I9B`H(6ES7V$H)&9B+"`G
M4$5!4E]%<G)O<B<I('Q\("1F8BT^9V5T0V]D92@I(#T]($M23TY/3$E42%]%
M4E)/4E]&0E].3U1?1D]53D0I('L*("`@("`@("`@("`@<F5T=7)N("1F8CL*
M("`@("`@("!]"@H@("`@("`@("\O($]R(&5L<V4@<F5T=7)N(&%N(&5M<'1Y
M(%9&0B!O8FIE8W0*("`@("`@("`D=D-A;"`]("9N97<@2&]R9&5?:4-A;&5N
M9&%R*"D["B`@("`@("`@)'9&8B`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O
M;7!O;F5N="@G=F9R965B=7-Y)RP@)'9#86PI.PH@("`@("`@("1V1F(M/G-E
M=$%T=')I8G5T92@G3U)'04Y)6D52)RP@)&5M86EL*3L*"B`@("`@("`@<F5T
M=7)N("1V1F(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396%R8VAE<R!A9&1R
M97-S(&)O;VMS(&9O<B!T:&4@9G)E96)U<WD@55),(&9O<B!A(&=I=F5N(&5M
M86EL(&%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D96UA
M:6P@(%1H92!E;6%I;"!A9&1R97-S('1O(&QO;VL@9F]R+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!U<FP@;VX@<W5C8V5S<R!O<B!F86QS
M92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&<F5E0G5S
M>55R;"@D96UA:6PI"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>2P@
M)'!R969S.PH*("`@("`@("!R971U<FX@)')E9VES=')Y+3YC86QL*"=C;VYT
M86-T<R]G971&:65L9"<L(&%R<F%Y*"1E;6%I;"P@)V9R965B=7-Y57)L)RP@
M0'5N<V5R:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H)W-E87)C:%]A8F]O:R<I
M*2P@=')U92DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@;W5T(&E4
M:7`@979E;G0@;F]T:69I8V%T:6]N<R!T;R!A;&P@871T96YD965S(&]F(&$@
M<W!E8VEF:6,*("`@("`J(&5V96YT+B!#86X@8F4@=7-E9"!T;R!S96YD(&5V
M96YT(&EN=FET871I;VYS+"!E=F5N="!U<&1A=&5S(&%S('=E;&P@87,*("`@
M("`J(&5V96YT(&-A;F-E;&QA=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M($MR;VYO;&ET:%]%=F5N="`D979E;G0@("`@("!4:&4@979E;G0@:6X@<75E
M<W1I;VXN"B`@("`@*B!`<&%R86T@3F]T:69I8V%T:6]N("1N;W1I9FEC871I
M;VX@($$@;F]T:69I8V%T:6]N(&]B:F5C="!U<V5D('1O('-H;W<*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5S=6QT('-T
M871U<RX*("`@("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VX@("`@("`@("`@
M("`@5&AE('1Y<&4@;V8@;F]T:69I8V%T:6]N('1O('-E;F0N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($]N92!O9B!T:&4@
M2U)/3D],251(7TE425!?*B!V86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E;F1)5&EP3F]T:69I8V%T:6]N<R@F)&5V96YT+"`F)&YO=&EF:6-A=&EO
M;BP@)&%C=&EO;BD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@("1A='1E;F1E97,@/2`D979E;G0M/F=E=$%T=&5N9&5E<R@I.PH@("`@
M("`@(&EF("@A)&%T=&5N9&5E<RD@>PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y
M+G!H<"<["B`@("`@("`@)&ED96YT(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH
M*3L*"B`@("`@("`@)&UY96UA:6P@/2`D:61E;G0M/F=E=%9A;'5E*"=F<F]M
M7V%D9'(G*3L*("`@("`@("!I9B`H(21M>65M86EL*2!["B`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")9;W4@9&\@;F]T(&AA
M=F4@86X@96UA:6P@861D<F5S<R!C;VYF:6=U<F5D(&EN('EO=7(@4&5R<V]N
M86P@26YF;W)M871I;VX@3W!T:6]N<RX@66]U(&UU<W0@<V5T(&]N92`E<VAE
M<F4E<R!B969O<F4@979E;G0@;F]T:69I8V%T:6]N<R!C86X@8F4@<V5N="XB
M*2P@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU<FPH
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I
M("X@)R]S97)V:6-E<R]P<F5F<RYP:'`G*2P@87)R87DH)V%P<"<@/3X@)VAO
M<F1E)RP@)V=R;W5P)R`]/B`G:61E;G1I=&EE<R<I*2DL("<\+V$^)RDL("=H
M;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]-24U%+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-
M24U%+TAE861E<G,N<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+TU)344O365S<V%G92YP:'`G.PH*("`@("`@("`D;7EE;6%I;"`](&5X<&QO
M9&4H)T`G+"`D;7EE;6%I;"D["B`@("`@("`@)&9R;VT@/2!-24U%.CIR9F,X
M,C)7<FET94%D9')E<W,H)&UY96UA:6Q;,%TL(&ES<V5T*"1M>65M86EL6S%=
M*2`_("1M>65M86EL6S%=(#H@)R<L("1I9&5N="T^9V5T5F%L=64H)V9U;&QN
M86UE)RDI.PH*("`@("`@("`D;6%I;%]D<FEV97(@/2`D8V]N9ELG;6%I;&5R
M)UU;)W1Y<&4G73L*("`@("`@("`D;6%I;%]P87)A;7,@/2`D8V]N9ELG;6%I
M;&5R)UU;)W!A<F%M<R==.PH@("`@("`@(&EF("@D;6%I;%]D<FEV97(@/3T@
M)W-M='`G("8F("1M86EL7W!A<F%M<ULG875T:"==("8F"B`@("`@("`@("`@
M(&5M<'1Y*"1M86EL7W!A<F%M<ULG=7-E<FYA;64G72DI('L*("`@("`@("`@
M("`@)&UA:6Q?<&%R86US6R=U<V5R;F%M92==(#T@075T:#HZ9V5T075T:"@I
M.PH@("`@("`@("`@("`D;6%I;%]P87)A;7-;)W!A<W-W;W)D)UT@/2!!=71H
M.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I.PH@("`@("`@('T*"B`@("`@
M("`@9F]R96%C:"`H)&%T=&5N9&5E<R!A<R`D96UA:6P@/3X@)'-T871U<RD@
M>PH@("`@("`@("`@("`O+R!$;VXG="!B;W1H97(@<V5N9&EN9R!A;B!I;G9I
M=&%T:6]N+W5P9&%T92!I9B!T:&4@<F5C:7!I96YT(&1O97,*("`@("`@("`@
M("`@+R\@;F]T(&YE960@=&\@<&%R=&EC:7!A=&4L(&]R(&AA<R!D96-L:6YE
M9"!P87)T:6-I<&%T:6YG"B`@("`@("`@("`@(&EF("@D<W1A='5S6R=A='1E
M;F1A;F-E)UT@/3T@2U)/3D],251(7U!!4E1?3D].12!\?`H@("`@("`@("`@
M("`@("`@)'-T871U<ULG<F5S<&]N<V4G72`]/2!+4D].3TQ)5$A?4D534$].
M4T5?1$5#3$E.140I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!$971E<FUI;F4@86QL(&YO=&EF
M:6-A=&EO;BUS<&5C:69I8R!S=')I;F=S+@H@("`@("`@("`@("!S=VET8V@@
M*"1A8W1I;VXI('L*("`@("`@("`@("`@8V%S92!+4D].3TQ)5$A?251)4%]#
M04Y#14PZ"B`@("`@("`@("`@("`@("`O+R!#86YC96QL871I;VX*("`@("`@
M("`@("`@("`@("1M971H;V0@/2`G0T%.0T5,)SL*("`@("`@("`@("`@("`@
M("1F:6QE;F%M92`]("=E=F5N="UC86YC96QL871I;VXN:6-S)SL*("`@("`@
M("`@("`@("`@("1S=6)J96-T(#T@<W!R:6YT9BA?*")#86YC96QL960Z("5S
M(BDL("1E=F5N="T^9V5T5&ET;&4H*2D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@2U)/3D],251(7TE425!?4D5154535#H*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1M971H;V0@
M/2`G4D5154535"<["B`@("`@("`@("`@("`@("!I9B`H)'-T871U<ULG<F5S
M<&]N<V4G72`]/2!+4D].3TQ)5$A?4D534$].4T5?3D].12D@>PH@("`@("`@
M("`@("`@("`@("`@("\O($EN=FET871I;VXN"B`@("`@("`@("`@("`@("`@
M("`@)&9I;&5N86UE(#T@)V5V96YT+6EN=FET871I;VXN:6-S)SL*("`@("`@
M("`@("`@("`@("`@("`D<W5B:F5C="`]("1E=F5N="T^9V5T5&ET;&4H*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M+R\@57!D871E+@H@("`@("`@("`@("`@("`@("`@("1F:6QE;F%M92`]("=E
M=F5N="UU<&1A=&4N:6-S)SL*("`@("`@("`@("`@("`@("`@("`D<W5B:F5C
M="`]('-P<FEN=&8H7R@B57!D871E9#H@)7,N(BDL("1E=F5N="T^9V5T5&ET
M;&4H*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&UE<W-A9V4@/2`D<W5B
M:F5C="`N("<@*"<["B`@("`@("`@("`@("1M97-S86=E("X]('-P<FEN=&8H
M7R@B;VX@)7,@870@)7,B*2P@<W1R9G1I;64H)R5X)RP@)&5V96YT+3YS=&%R
M="T^=&EM97-T86UP*"DI+"!D871E*"=(.FDG+"`D979E;G0M/G-T87)T+3YT
M:6UE<W1A;7`H*2DI.PH@("`@("`@("`@("`D;65S<V%G92`N/2`B*5QN7&XB
M.PH*("`@("`@("`@("`@:68@*"1E=F5N="T^9V5T1&5S8W)I<'1I;VXH*2`A
M/2`G)RD@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@+CT@7R@B5&AE(&9O
M;&QO=VEN9R!I<R!A(&UO<F4@9&5T86EL960@9&5S8W)I<'1I;VX@;V8@=&AE
M(&5V96YT.B(I("X@(EQN7&XB("X@)&5V96YT+3YG971$97-C<FEP=&EO;B@I
M("X@(EQN7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1M97-S86=E
M("X](%\H(D%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE('=I=&@@;6]R
M92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@979E;G0N($EF('EO=7(@;6%I;"!C
M;&EE;G0@<W5P<&]R=',@:51I<"!R97%U97-T<R!Y;W4@8V%N('5S92!T:&ES
M(&9I;&4@=&\@96%S:6QY('5P9&%T92!Y;W5R(&QO8V%L(&-O<'D@;V8@=&AE
M(&5V96YT+B(I.PH*("`@("`@("`@("`@:68@*"1A8W1I;VX@/3T@2U)/3D],
M251(7TE425!?4D5154535"D@>PH@("`@("`@("`@("`@("`@)&%T=&5N9%]L
M:6YK(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G871T96YD+G!H<"<L('1R=64L("TQ*2P@87)R87DH)VDG(#T^("1E=F5N
M="T^9V5T54E$*"DL("=U)R`]/B`D96UA:6PI+"!N=6QL+"!F86QS92D["B`@
M("`@("`@("`@("`@("`D;65S<V%G92`N/2`B7&Y<;B(@+B!S<')I;G1F*%\H
M(DEF('EO=7(@96UA:6P@8VQI96YT(&1O97-N)W0@<W5P<&]R="!I5&EP(')E
M<75E<W1S('EO=2!C86X@=7-E(&]N92!O9B!T:&4@9F]L;&]W:6YG(&QI;FMS
M('1O(&%C8V5P="!O<B!D96-L:6YE('1H92!E=F5N="Y<;EQN5&\@86-C97!T
M('1H92!E=F5N=#I<;B5S7&Y<;E1O(&%C8V5P="!T:&4@979E;G0@=&5N=&%T
M:79E;'DZ7&XE<UQN7&Y4;R!D96-L:6YE('1H92!E=F5N=#I<;B5S(BDL(%5T
M:6PZ.F%D9%!A<F%M971E<B@D871T96YD7VQI;FLL("=A)RP@)V%C8V5P="<L
M(&9A;'-E*2P@571I;#HZ861D4&%R86UE=&5R*"1A='1E;F1?;&EN:RP@)V$G
M+"`G=&5N=&%T:79E)RP@9F%L<V4I+"!5=&EL.CIA9&1087)A;65T97(H)&%T
M=&5N9%]L:6YK+"`G82<L("=D96-L:6YE)RP@9F%L<V4I*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&UI;64@/2`F;F5W($U)345?4&%R="@G;75L
M=&EP87)T+V%L=&5R;F%T:79E)RD["B`@("`@("`@("`@("1B;V1Y(#T@)FYE
M=R!-24U%7U!A<G0H)W1E>'0O<&QA:6XG+"!3=')I;F<Z.G=R87`H)&UE<W-A
M9V4L(#@P+"`B7&XB*2D["B`@("`@("`@("`@("1B;V1Y+3YS971#:&%R<V5T
M*$Y,4SHZ9V5T0VAA<G-E="@I*3L*"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O1&%T82YP:'`G.PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH*("`@("`@("`@("`@)&E#86P@/2`F
M;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@("`@("`D:4-A;"T^<V5T
M071T<FEB=71E*"=-151(3T0G+"`D;65T:&]D*3L*("`@("`@("`@("`@)&E#
M86PM/F%D9$-O;7!O;F5N="@D979E;G0M/G1O:4-A;&5N9&%R*"1I0V%L+"`D
M:61E;G0I*3L*("`@("`@("`@("`@)&EC<R`]("9N97<@34E-15]087)T*"=T
M97AT+V-A;&5N9&%R)RP@)&E#86PM/F5X<&]R='9#86QE;F1A<B@I*3L*("`@
M("`@("`@("`@)&EC<RT^<V5T3F%M92@D9FEL96YA;64I.PH@("`@("`@("`@
M("`D:6-S+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G34542$]$)RP@)&UE
M=&AO9"D["B`@("`@("`@("`@("1I8W,M/G-E=$-H87)S970H3DQ3.CIG971#
M:&%R<V5T*"DI.PH*("`@("`@("`@("`@)&UI;64M/F%D9%!A<G0H)&)O9'DI
M.PH@("`@("`@("`@("`D;6EM92T^861D4&%R="@D:6-S*3L*("`@("`@("`@
M("`@)&UI;64@/2`F34E-15]-97-S86=E.CIC;VYV97)T36EM95!A<G0H)&UI
M;64I.PH*("`@("`@("`@("`@+R\@0G5I;&0@=&AE(&YO=&EF:6-A=&EO;B!H
M96%D97)S+@H@("`@("`@("`@("`D;7-G7VAE861E<G,@/2`F;F5W($U)345?
M2&5A9&5R<R@I.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9%)E8V5I
M=F5D2&5A9&5R*"D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D365S
M<V%G94ED2&5A9&5R*"D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D
M2&5A9&5R*"=$871E)RP@9&%T92@G<B<I*3L*("`@("`@("`@("`@)&US9U]H
M96%D97)S+3YA9&1(96%D97(H)T9R;VTG+"!-24U%.CIE;F-O9&4H)&9R;VTL
M($Y,4SHZ9V5T0VAA<G-E="@I*2D["B`@("`@("`@("`@("1M<V=?:&5A9&5R
M<RT^861D2&5A9&5R*"=4;R<L($U)344Z.F5N8V]D92@D96UA:6PL($Y,4SHZ
M9V5T0VAA<G-E="@I*2D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D
M2&5A9&5R*"=3=6)J96-T)RP@34E-13HZ96YC;V1E*"1S=6)J96-T+"!.3%,Z
M.F=E=$-H87)S970H*2DI.PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@2U)/
M3D],251(7T)!4T4@+B`G+VQI8B]V97)S:6]N+G!H<"<["B`@("`@("`@("`@
M("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=5<V5R+4%G96YT)RP@)TMR;VYO
M;&ET:"`G("X@2U)/3D],251(7U9%4E-)3TXI.PH@("`@("`@("`@("`D;7-G
M7VAE861E<G,M/F%D9$U)345(96%D97)S*"1M:6UE*3L*"B`@("`@("`@("`@
M("1S=&%T=7,@/2`D;6EM92T^<V5N9"@D96UA:6PL("1M<V=?:&5A9&5R<RP@
M)&UA:6Q?9')I=F5R+"`D;6%I;%]P87)A;7,I.PH@("`@("`@("`@("!I9B`H
M(6ES7V$H)'-T871U<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@*("`@("`@("`@("`@("`@("`@("!S
M<')I;G1F*%\H(E1H92!E=F5N="!N;W1I9FEC871I;VX@=&\@)7,@=V%S('-U
M8V-E<W-F=6QL>2!S96YT+B(I+"`D96UA:6PI+`H@("`@("`@("`@("`@("`@
M("`@("=H;W)D92YS=6-C97-S)PH@("`@("`@("`@("`@("`@*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")4:&5R92!W
M87,@86X@97)R;W(@<V5N9&EN9R!A;B!E=F5N="!N;W1I9FEC871I;VX@=&\@
M)7,Z("5S(BDL("1E;6%I;"P@)'-T871U<RT^9V5T365S<V%G92@I*2P*("`@
M("`@("`@("`@("`@("`@("`G:&]R9&4N97)R;W(G"B`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4V5N9',@96UA:6P@;F]T:69I8V%T:6]N<R!T:&%T(&$@979E;G0@
M:&%S(&)E96X@861D960L(&5D:71E9"P@;W(*("`@("`J(&1E;&5T960@=&\@
M=7-E<G,@=&AA="!W86YT('-U8V@@;F]T:69I8V%T:6]N<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@2W)O;F]L:71H7T5V96YT("1E=F5N="`@06X@979E;G0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8W1I;VX@("`@("`@("`@5&AE(&5V
M96YT(&%C=&EO;BX@3VYE(&]F(")A9&0B+"`B961I="(L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@(F1E;&5T92(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E;F1.;W1I9FEC871I;VXH)B1E=F5N="P@)&%C
M=&EO;BD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@('-W
M:71C:"`H)&%C=&EO;BD@>PH@("`@("`@(&-A<V4@)V%D9"<Z"B`@("`@("`@
M("`@("1S=6)J96-T(#T@7R@B179E;G0@861D960Z(BD["B`@("`@("`@("`@
M("1N;W1I9FEC871I;VY?;65S<V%G92`](%\H(EEO=2!R97%U97-T960@=&\@
M8F4@;F]T:69I960@=VAE;B!E=F5N=',@87)E(&%D9&5D('1O('EO=7(@8V%L
M96YD87)S+B(I("X@(EQN7&XB("X@7R@B5&AE(&5V96YT(%PB)7-<(B!H87,@
M8F5E;B!A9&1E9"!T;R!<(B5S7"(@8V%L96YD87(L('=H:6-H(&ES(&]N("5S
M(&%T("5S+B(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M961I="<Z"B`@("`@("`@("`@("1S=6)J96-T(#T@7R@B179E;G0@961I=&5D
M.B(I.PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N7VUE<W-A9V4@/2!?*")9
M;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF:65D('=H96X@979E;G1S(&%R92!E
M9&ET960@:6X@>6]U<B!C86QE;F1A<G,N(BD@+B`B7&Y<;B(@+B!?*")4:&4@
M979E;G0@7"(E<UPB(&AA<R!B965N(&5D:71E9"!O;B!<(B5S7"(@8V%L96YD
M87(L('=H:6-H(&ES(&]N("5S(&%T("5S+B(I.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`G9&5L971E)SH*("`@("`@("`@("`@)'-U8FIE
M8W0@/2!?*")%=F5N="!D96QE=&5D.B(I.PH@("`@("`@("`@("`D;F]T:69I
M8V%T:6]N7VUE<W-A9V4@/2!?*")9;W4@<F5Q=65S=&5D('1O(&)E(&YO=&EF
M:65D('=H96X@979E;G1S(&%R92!D96QE=&5D(&9R;VT@>6]U<B!C86QE;F1A
M<G,N(BD@+B`B7&Y<;B(@+B!?*")4:&4@979E;G0@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960@9G)O;2!<(B5S7"(@8V%L96YD87(L('=H:6-H('=A<R!O;B`E
M<R!A="`E<RXB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;FMN
M;W=N(&5V96YT(&%C=&EO;CH@)R`N("1A8W1I;VXI.PH@("`@("`@('T*"B`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344N<&AP)SL*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344O2&5A9&5R<RYP:'`G.PH@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O34E-12]-97-S86=E+G!H<"<["@H@("`@("`@("1G
M<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH@("`@("`@("1C86QE;F1A
M<B`]("1E=F5N="T^9V5T0V%L96YD87(H*3L*("`@("`@("`D<VAA<F4@/2`F
M)$=,3T)!3%-;)VMR;VYO;&ET:%]S:&%R97,G72T^9V5T4VAA<F4H)&-A;&5N
M9&%R*3L*("`@("`@("`D<F5C:7!I96YT<R`](&%R<F%Y*"D["@H@("`@("`@
M("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@
M)&9R;VT@/2`D:61E;G1I='DM/F=E=$1E9F%U;'1&<F]M061D<F5S<RAT<G5E
M*3L*"B`@("`@("`@)&]W;F5R(#T@)'-H87)E+3YG970H)V]W;F5R)RD["B`@
M("`@("`@:68@*$MR;VYO;&ET:#HZ7VYO=&EF:6-A=&EO;E!R968H)&]W;F5R
M+"`G;W=N97(G*2D@>PH@("`@("`@("`@("`D<F5C:7!I96YT<ULD;W=N97)=
M(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1S:&%R92T^
M;&ES=%5S97)S*%!%4DU37U)%040I(&%S("1U<V5R*2!["B`@("`@("`@("`@
M(&EF("@A:7-S970H)')E8VEP:65N='-;)'5S97)=*2D@>PH@("`@("`@("`@
M("`@("`@)')E8VEP:65N='-;)'5S97)=(#T@2W)O;F]L:71H.CI?;F]T:69I
M8V%T:6]N4')E9B@D=7-E<BP@)W)E860G+"`D8V%L96YD87(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1S:&%R92T^;&ES
M=$=R;W5P<RA015)-4U]214%$*2!A<R`D9W)O=7`I('L*("`@("`@("`@("`@
M)&=R;W5P(#T@)&=R;W5P<RT^9V5T1W)O=7!">4ED*"1G<F]U<"D["B`@("`@
M("`@("`@("1G<F]U<%]U<V5R<R`]("1G<F]U<"T^;&ES=$%L;%5S97)S*"D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1G<F]U<%]U<V5R<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&=R
M;W5P7W5S97)S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!F;W)E86-H("@D9W)O=7!?=7-E<G,@87,@)'5S97(I('L*("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)')E8VEP:65N='-;)'5S97)=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1R96-I<&EE;G1S6R1U<V5R72`]($MR
M;VYO;&ET:#HZ7VYO=&EF:6-A=&EO;E!R968H)'5S97(L("=R96%D)RP@)&-A
M;&5N9&%R*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&%D9')E<W-E<R`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"`H)')E8VEP:65N=',@87,@)'5S97(@/3X@)'-E;F0I('L*("`@
M("`@("`@("`@:68@*"1S96YD*2!["B`@("`@("`@("`@("`@("`D:61E;G1I
M='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@G;F]N92<L("1U<V5R*3L*("`@
M("`@("`@("`@("`@("1E;6%I;"`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9R
M;VU?861D<B<I.PH@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D96UA:6PL
M("=`)RDI('L*("`@("`@("`@("`@("`@("`@("!L:7-T*"1M86EL8F]X+"`D
M:&]S="D@/2!E>'!L;V1E*"=`)RP@)&5M86EL*3L*("`@("`@("`@("`@("`@
M("`@("`D861D<F5S<V5S6UT@/2!-24U%.CIR9F,X,C)7<FET94%D9')E<W,H
M)&UA:6QB;W@L("1H;W-T+"`D:61E;G1I='DM/F=E=%9A;'5E*"=F=6QL;F%M
M92<I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*"%C;W5N="@D861D<F5S<V5S*2D@>PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D;7-G7VAE861E<G,@
M/2`F;F5W($U)345?2&5A9&5R<R@I.PH@("`@("`@("1M<V=?:&5A9&5R<RT^
M861D365S<V%G94ED2&5A9&5R*"D["B`@("`@("`@)&US9U]H96%D97)S+3YA
M9&1!9V5N=$AE861E<B@I.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A
M9&5R*"=$871E)RP@9&%T92@G<B<I*3L*("`@("`@("`D;7-G7VAE861E<G,M
M/F%D9$AE861E<B@G1G)O;2<L("1F<F]M*3L*("`@("`@("`D;7-G7VAE861E
M<G,M/F%D9$AE861E<B@G4W5B:F5C="<L("1S=6)J96-T("X@)R`G("X@)&5V
M96YT+3YT:71L92D["@H@("`@("`@("1M97-S86=E(#T@(EQN(B`N('-P<FEN
M=&8H)&YO=&EF:6-A=&EO;E]M97-S86=E+"`D979E;G0M/G1I=&QE+"`D<VAA
M<F4M/F=E="@G;F%M92<I+"!S=')F=&EM92@G)7@G+"`D979E;G0M/G-T87)T
M+3YT:6UE<W1A;7`H*2DL(&1A=&4H)T@Z:2<L("1E=F5N="T^<W1A<G0M/G1I
M;65S=&%M<"@I*2D@+B`B7&Y<;B(@+B`D979E;G0M/F=E=$1E<V-R:7!T:6]N
M*"D["@H@("`@("`@("1M:6UE(#T@)FYE=R!-24U%7TUE<W-A9V4H*3L*("`@
M("`@("`D8F]D>2`]("9N97<@34E-15]087)T*"=T97AT+W!L86EN)RP@4W1R
M:6YG.CIW<F%P*"1M97-S86=E+"`W-BP@(EQN(BDL($Y,4SHZ9V5T0VAA<G-E
M="@I*3L*"B`@("`@("`@)&UI;64M/F%D9%!A<G0H)&)O9'DI.PH@("`@("`@
M("1M<V=?:&5A9&5R<RT^861D34E-14AE861E<G,H)&UI;64I.PH*("`@("`@
M("`D;6%I;%]D<FEV97(@/2`D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G73L*("`@
M("`@("`D;6%I;%]P87)A;7,@/2`D8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==
M.PH@("`@("`@(&EF("@D;6%I;%]D<FEV97(@/3T@)W-M='`G("8F("1M86EL
M7W!A<F%M<ULG875T:"==("8F"B`@("`@("`@("`@(&5M<'1Y*"1M86EL7W!A
M<F%M<ULG=7-E<FYA;64G72DI('L*("`@("`@("`@("`@)&UA:6Q?<&%R86US
M6R=U<V5R;F%M92==(#T@075T:#HZ9V5T075T:"@I.PH@("`@("`@("`@("`D
M;6%I;%]P87)A;7-;)W!A<W-W;W)D)UT@/2!!=71H.CIG971#<F5D96YT:6%L
M*"=P87-S=V]R9"<I.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H<W!R:6YT9B@G4V5N9&EN9R!E=F5N="!N;W1I9FEC871I;VYS(&9O
M<B`E<R!T;R`E<R<L("1E=F5N="T^=&ET;&4L(&EM<&QO9&4H)RP@)RP@)&%D
M9')E<W-E<RDI+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("!R971U<FX@)&UI;64M/G-E;F0H:6UP;&]D92@G+"`G+"`D
M861D<F5S<V5S*2P@)&US9U]H96%D97)S+"`D;6%I;%]D<FEV97(L("1M86EL
M7W!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H
M97(@82!U<V5R('=A;G1S(&5M86EL(&YO=&EF:6-A=&EO;G,@9F]R(&$@8V%L
M96YD87(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'1O9&\@5&AI<R!M971H;V0@:7,@8V%U<VEN9R!A(&UE;6]R>2!L
M96%K('-O;65W:&5R92P@;F]T:6-E86)L92!I9@H@("`@("H@("`@("`@:6UP
M;W)T:6YG(&$@;&%R9V4@86UO=6YT(&]F(&5V96YT<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@02!U<V5R(&YA;64N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1M;V1E("`@("`@5&AE(&-H96-K(")M;V1E(BX@
M268@(F]W;F5R(BP@=&AE(&UE=&AO9"!C:&5C:W,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B!T:&4@=7-E<B!W86YT<R!N;W1I9FEC871I
M;VYS(&]N;'D@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V%L96YD87)S(&AE(&]W;G,N($EF(")R96%D(BP@=&AE(&UE=&AO9"!C:&5C
M:W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I9B!T:&4@=7-E
M<B!W86YT<R!N;W1I9FEC871I;VYS(&9O<B!A;&P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!C86QE;F1A<G,@:&4@:&%S(')E860@86-C97-S
M('1O+"!O<B!O;FQY(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@('-H;W=N(&-A;&5N9&%R<R!A;F0@=&AE('-P96-I9FEE9"!C86QE;F1A
M<B!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-U<G)E;G1L
M>2!S:&]W;BX*("`@("`J($!P87)A;2!S=')I;F<@)&-A;&5N9&%R("!4:&4@
M;F%M92!O9B!T:&4@8V%L96YD87(@:68@;6]D92!I<R`B<F5A9"(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!U<V5R('=A
M;G1S(&YO=&EF:6-A=&EO;G,@9F]R('1H92!C86QE;F1A<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VYO=&EF:6-A=&EO;E!R968H)'5S97(L("1M;V1E+"`D
M8V%L96YD87(@/2!N=6QL*0H@("`@>PH@("`@("`@("1P<F5F<R`]("90<F5F
M<SHZ<VEN9VQE=&]N*"1'3$]"04Q36R=C;VYF)UU;)W!R969S)UU;)V1R:79E
M<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K<F]N
M;VQI=&@G+"`D=7-E<BP@)R<L(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F%L<V4I.PH@("`@("`@("1P<F5F<RT^<F5T<FEE
M=F4H*3L*"B`@("`@("`@)&YO=&EF:6-A=&EO;B`]("1P<F5F<RT^9V5T5F%L
M=64H)V5V96YT7VYO=&EF:6-A=&EO;B<I.PH@("`@("`@('-W:71C:"`H)&YO
M=&EF:6-A=&EO;BD@>PH@("`@("`@(&-A<V4@)V]W;F5R)SH*("`@("`@("`@
M("`@<F5T=7)N("1M;V1E(#T]("=O=VYE<B<["B`@("`@("`@8V%S92`G<F5A
M9"<Z"B`@("`@("`@("`@(')E='5R;B`D;6]D92`]/2`G<F5A9"<["B`@("`@
M("`@8V%S92`G<VAO=R<Z"B`@("`@("`@("`@(&EF("@D;6]D92`]/2`G<F5A
M9"<I('L*("`@("`@("`@("`@("`@("1D:7-P;&%Y7V-A;&5N9&%R<R`]('5N
M<V5R:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H)V1I<W!L87E?8V%L<R<I*3L*
M("`@("`@("`@("`@("`@(')E='5R;B!I;E]A<G)A>2@D8V%L96YD87(L("1D
M:7-P;&%Y7V-A;&5N9&%R<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!C=7)R
M96YT5&EM97-T86UP*"D*("`@('L*("`@("`@("`D=&EM97-T86UP(#T@*&EN
M="E5=&EL.CIG971&;W)M1&%T82@G=&EM97-T86UP)RD["B`@("`@("`@:68@
M*"$D=&EM97-T86UP*2!["B`@("`@("`@("`@("1Y96%R(#T@*&EN="E5=&EL
M.CIG971&;W)M1&%T82@G>65A<B<L(&1A=&4H)UDG*2D["B`@("`@("`@("`@
M("1M;VYT:"`]("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)VUO;G1H)RP@9&%T
M92@G;B<I*3L*("`@("`@("`@("`@)&1A>2`]("AI;G0I571I;#HZ9V5T1F]R
M;41A=&$H)VUD87DG+"!D871E*"=D)RDI.PH@("`@("`@("`@("!I9B`H)'=E
M96L@/2`H:6YT*55T:6PZ.F=E=$9O<FU$871A*"=W965K)RDI('L*("`@("`@
M("`@("`@("`@("1M;VYT:"`](#$["B`@("`@("`@("`@("`@("`D9&%Y(#T@
M2&]R9&5?1&%T93HZ9FER<W1$87E/9E=E96LH)'=E96LL("1Y96%R*3L*("`@
M("`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H
M)W=E96M?<W1A<G1?;6]N9&%Y)RDI('L*("`@("`@("`@("`@("`@("`@("`D
M9&%Y*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1I;65S=&%M<"`](&UK=&EM92@P+"`P+"`P+"`D;6]N=&@L("1D
M87DL("1Y96%R*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&EM97-T
M86UP.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<W!E8VEF
M:65D('!E<FUI<W-I;VX@9F]R('1H92!C=7)R96YT('5S97(N"B`@("`@*@H@
M("`@("H@0'-I;F-E($MR;VYO;&ET:"`R+C$*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P97)M:7-S:6]N("!!('!E<FUI<W-I;VXL(&-U<G)E;G1L
M>2!O;FQY("=M87A?979E;G1S)RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@=F%L=64@;V8@=&AE('-P96-I9FEE9"!P97)M:7-S:6]N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1P97)M:7-S:6]N
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<&5R;7,["@H@("`@("`@(&EF("@A
M)'!E<FUS+3YE>&ES=',H)VMR;VYO;&ET:#HG("X@)'!E<FUI<W-I;VXI*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M)&%L;&]W960@/2`D<&5R;7,M/F=E=%!E<FUI<W-I;VYS*"=K<F]N;VQI=&@Z
M)R`N("1P97)M:7-S:6]N*3L*("`@("`@("!I9B`H:7-?87)R87DH)&%L;&]W
M960I*2!["B`@("`@("`@("`@('-W:71C:"`H)'!E<FUI<W-I;VXI('L*("`@
M("`@("`@("`@8V%S92`G;6%X7V5V96YT<R<Z"B`@("`@("`@("`@("`@("`D
M86QL;W=E9"`](&%R<F%Y7W)E9'5C92@D86QL;W=E9"P@8W)E871E7V9U;F-T
M:6]N*"<D82P@)&(G+"`G<F5T=7)N(&UA>"@D82P@)&(I.R<I+"`P*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&%L;&]W960["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&%B<R@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]522]4
M86)S+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L
M97,N<&AP)SL*("`@("`@("`D=&%B<R`]("9N97<@2&]R9&5?54E?5&%B<R@G
M=FEE=R<L(%9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I*3L*("`@
M("`@("`D=&%B<RT^<')E<V5R=F4H)W1I;65S=&%M<"<L($MR;VYO;&ET:#HZ
M8W5R<F5N=%1I;65S=&%M<"@I*3L*"B`@("`@("`@)'1A8G,M/F%D9%1A8BA?
M*")$87DB*2P@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=D87DN<&AP)RDL("=D
M87DG*3L*("`@("`@("`D=&%B<RT^861D5&%B*%\H(E=O<FL@5V5E:R(I+"!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)W=O<FMW965K+G!H<"<I+"`G=V]R:W=E
M96LG*3L*("`@("`@("`D=&%B<RT^861D5&%B*%\H(E=E96LB*2P@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=W965K+G!H<"<I+"`G=V5E:R<I.PH@("`@("`@
M("1T86)S+3YA9&1486(H7R@B36]N=&@B*2P@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=M;VYT:"YP:'`G*2P@)VUO;G1H)RD["B`@("`@("`@)'1A8G,M/F%D
M9%1A8BA?*")996%R(BDL($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G>65A<BYP
M:'`G*2P@)WEE87(G*3L*"B`@("`@("`@96-H;R`D=&%B<RT^<F5N9&5R*&)A
M<V5N86UE*"1?4T525D526R=02%!?4T5,1B==*2`]/2`G:6YD97@N<&AP)R`_
M("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G9&5F875L='9I97<G*2`Z
M('-T<E]R97!L86-E*"<N<&AP)RP@)R<L(&)A<V5N86UE*"1?4T525D526R=0
M2%!?4T5,1B==*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S($MR
M;VYO;&ET:"=S(&QI<W0@;V8@;65N=2!I=&5M<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T365N=2@D<F5T=7)N5'EP92`]("=O8FIE8W0G*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D8V]N9BP@)')E9VES=')Y+"`D8G)O=W-E<BP@)'!R
M969S+"`D<')I;G1?;&EN:SL*"B`@("`@("`@+R\@0VAE8VL@:&5R92!F;W(@
M9W5E<W0@8V%L96YD87)S('-O('1H870@=V4@9&]N)W0@9V5T(&UU;'1I<&QE
M"B`@("`@("`@+R\@;65S<V%G97,@869T97(@<F5D:7)E8W1S+"!E=&,N"B`@
M("`@("`@:68@*"%!=71H.CIG971!=71H*"D@)B8@(6-O=6YT*"1'3$]"04Q3
M6R=A;&Q?8V%L96YD87)S)UTI*2!["B`@("`@("`@("`@("1'3$]"04Q36R=N
M;W1I9FEC871I;VXG72T^<'5S:"A?*").;R!C86QE;F1A<G,@87)E(&%V86EL
M86)L92!T;R!G=65S=',N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]-96YU+G!H<"<["B`@("`@("`@)&UE;G4@/2`F;F5W
M($UE;G4H*3L*"B`@("`@("`@:68@*$%U=&@Z.F=E=$%U=&@H*2D@>PH@("`@
M("`@("`@("`D;65N=2T^861D*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G8V%L
M96YD87)S+G!H<"<I+"!?*")?37D@0V%L96YD87)S(BDL("=C86QE;F1A<G,N
M<&YG)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H2W)O;F]L:71H.CIG971$
M969A=6QT0V%L96YD87(H4$5235-?141)5"D@)B8*("`@("`@("`@("`@*"%E
M;7!T>2@D8V]N9ELG:&]O:W,G75LG<&5R;7-D96YI960G72D@?'P*("`@("`@
M("`@("`@($MR;VYO;&ET:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I
M(#T]/2!T<G5E('Q\"B`@("`@("`@("`@("!+<F]N;VQI=&@Z.FAA<U!E<FUI
M<W-I;VXH)VUA>%]E=F5N=',G*2`^($MR;VYO;&ET:#HZ8V]U;G1%=F5N=',H
M*2DI('L*("`@("`@("`@("`@)&UE;G4M/F%D9"A5=&EL.CIA9&1087)A;65T
M97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&1E=F5N="YP:'`G*2P@)W5R
M;"<L($AO<F1E.CIS96QF57)L*'1R=64L(&9A;'-E+"!T<G5E*2DL(%\H(E].
M97<@179E;G0B*2P@)VYE=RYP;F<G*3L*("`@("`@("!]"@H@("`@("`@("1M
M96YU+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1P<F5F<RT^9V5T5F%L
M=64H)V1E9F%U;'1V:65W)RD@+B`G+G!H<"<I+"!?*")?5&]D87DB*2P@)W1O
M9&%Y+G!N9R<L(&YU;&PL(&YU;&PL(&YU;&PL("=?7VYO<V5L96-T:6]N)RD[
M"B`@("`@("`@:68@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=D;VTG*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G9V]T;RYI;F,G+"`G
M:W)O;F]L:71H)RD["B`@("`@("`@("`@("1M96YU+3YA9&0H)R,G+"!?*")?
M1V]T;R(I+"`G9V]T;RYP;F<G+"!N=6QL+"`G)RP@)V]P96Y+1V]T;RA<)R<@
M+B!+<F]N;VQI=&@Z.F-U<G)E;G14:6UE<W1A;7`H*2`N("=<)RD[(')E='5R
M;B!F86QS93LG*3L*("`@("`@("!]"B`@("`@("`@)&UE;G4M/F%D9"A(;W)D
M93HZ87!P;&EC871I;VY5<FPH)W-E87)C:"YP:'`G*2P@7R@B7U-E87)C:"(I
M+"`G<V5A<F-H+G!N9R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI.PH*("`@("`@("`O+R!);7!O<G0O17AP;W)T+@H@("`@("`@(&EF("@D
M8V]N9ELG;65N=2==6R=I;7!O<G1?97AP;W)T)UTI('L*("`@("`@("`@("`@
M)&UE;G4M/F%D9"A(;W)D93HZ87!P;&EC871I;VY5<FPH)V1A=&$N<&AP)RDL
M(%\H(E]);7!O<G0O17AP;W)T(BDL("=D871A+G!N9R<L("1R96=I<W1R>2T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4')I;G0N"B`@("`@("`@:68@*"1C;VYF6R=M96YU)UU;)W!R:6YT)UT@)B8@
M:7-S970H)'!R:6YT7VQI;FLI*2!["B`@("`@("`@("`@("1M96YU+3YA9&0H
M)'!R:6YT7VQI;FLL(%\H(E]0<FEN="(I+"`G<')I;G0N<&YG)RP@)')E9VES
M=')Y+3YG971);6%G941I<B@G:&]R9&4G*2P@)U]B;&%N:R<L("=P;W!U<"AT
M:&ES+FAR968I.R!R971U<FX@9F%L<V4[)RD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)')E='5R;E1Y<&4@/3T@)V]B:F5C="<I('L*("`@("`@("`@("`@
M<F5T=7)N("1M96YU.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D;65N=2T^<F5N9&5R*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@57-E9"!W:71H('5S;W)T*"D@=&\@<V]R="!E=F5N=',@8F%S
M960@;VX@=&AE:7(@<W1A<G0@=&EM97,N"B`@("`@*B!4:&ES(&9U;F-T:6]N
M(&EG;F]R97,@=&AE(&1A=&4@8V]M<&]N96YT('-O(')E8W5R:6YG(&5V96YT
M<R!C86X*("`@("`J(&)E('-O<G1E9"!C;W)R96-T;'D@;VX@82!P97(@9&%Y
M(&)A<VES+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V]R=$5V96YT4W1A<G14
M:6UE*"1A+"`D8BD*("`@('L*("`@("`@("`D9&EF9B`]("AI;G0I9&%T92@G
M1VES)RP@)&$M/G-T87)T+3YT:6UE<W1A;7`H*2D@+2`H:6YT*61A=&4H)T=I
M<R<L("1B+3YS=&%R="T^=&EM97-T86UP*"DI.PH@("`@("`@(&EF("@D9&EF
M9B`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!S=')C;VQL*"1A+3YT:71L
M92P@)&(M/G1I=&QE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)&1I9F8["B`@("`@("`@?0H@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]B87-E+G!H<```````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-3`P,@`Q,#0Q-S,V,C<U,P`P
M,C`V,C$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($MR;VYO;&ET:"!B87-E(&EN8VQU<VEO;B!F:6QE
M+@H@*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]L:6(O8F%S92YP:'`L=B`Q+C$Q
M-RXX+C4@,C`P-B\P,R\P,B`Q.#HU-SHS,"!C:'5C:R!%>'`@)`H@*@H@*B!4
M:&ES(&9I;&4@8G)I;F=S(&EN(&%L;"!O9B!T:&4@9&5P96YD96YC:65S('1H
M870@979E<GD@2W)O;F]L:71H"B`J('-C<FEP="!W:6QL(&YE960L(&%N9"!S
M971S('5P(&]B:F5C=',@=&AA="!A;&P@<V-R:7!T<R!U<V4N"B`J+PH*+RH@
M0VAE8VL@9F]R(&$@<')I;W(@9&5F:6YI=&EO;B!O9B!(3U)$15]"05-%("AP
M97)H87!S(&)Y(&%N"B`J(&%U=&]?<')E<&5N9%]F:6QE(&1E9FEN:71I;VX@
M9F]R('-I=&4@8W5S=&]M:7IA=&EO;BDN("HO"FEF("@A9&5F:6YE9"@G2$]2
M1$5?0D%312<I*2!["B`@("!`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["GT*"B\J($QO860@=&AE($AO<F1E
M($9R86UE=V]R:R!C;W)E+"!A;F0@<V5T('5P(&EN8VQU<VEO;B!P871H<RX@
M*B\*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<[
M"@HO*B!296=I<W1R>2X@*B\*)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG
M;&5T;VXH*3L*:68@*&ES7V$H*"1P=7-H960@/2`D<F5G:7-T<GDM/G!U<VA!
M<'`H)VMR;VYO;&ET:"<L("%D969I;F5D*"=!551(7TA!3D1,15(G*2DI+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("!I9B`H)'!U<VAE9"T^9V5T0V]D92@I(#T]
M("=P97)M:7-S:6]N7V1E;FEE9"<I('L*("`@("`@("!(;W)D93HZ875T:&5N
M=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*("`@('T*("`@($AO<F1E.CIF
M871A;"@D<'5S:&5D+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*?0HD
M8V]N9B`]("8D1TQ/0D%,4ULG8V]N9B==.PI`9&5F:6YE*"=+4D].3TQ)5$A?
M5$5-4$Q!5$53)RP@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<I*3L*"B\J
M($9I;F0@=&AE(&)A<V4@9FEL92!P871H(&]F($MR;VYO;&ET:"X@*B\*0&1E
M9FEN92@G2U)/3D],251(7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXG*3L*"B\J($AO<F1E(&9R86UE=V]R:R!L:6)R87)I97,N("HO"G)E<75I
M<F5?;VYC92`G2&]R9&4O1&%T92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+TAE;'`N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92](:7-T;W)Y+G!H<"<[
M"@HO*B!.;W1I9FEC871I;VX@<WES=&5M+B`J+PHD;F]T:69I8V%T:6]N(#T@
M)DYO=&EF:6-A=&EO;CHZ<VEN9VQE=&]N*"D["B1N;W1I9FEC871I;VXM/F%T
M=&%C:"@G<W1A='5S)RD["@HO*B!+<F]N;VQI=&@@8F%S92!L:6)R87)Y+B`J
M+PIR97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]+<F]N;VQI
M=&@N<&AP)SL*"B\J($-A=&5G;W)I97,N("HO"G)E<75I<F5?;VYC92`G2&]R
M9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<"<["B1'3$]"04Q36R=C36%N
M86=E<B==(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G97(H*3L*"B\J(%!%
M05(@1&%T95]#86QC+B`J+PIR97%U:7)E7V]N8V4@)T1A=&4O0V%L8RYP:'`G
M.PH*+RH@4W1A<G0@8V]M<')E<W-I;VXL(&EF(')E<75E<W1E9"X@*B\*2&]R
M9&4Z.F-O;7!R97-S3W5T<'5T*"D["@HO*B!3970@=&AE('1I;65Z;VYE('9A
M<FEA8FQE+"!I9B!A=F%I;&%B;&4N("HO"DY,4SHZ<V5T5&EM95IO;F4H*3L*
M"B\J($-R96%T92!A(&-A;&5N9&%R(&)A8VME;F0@;V)J96-T+B`J+PHD1TQ/
M0D%,4ULG:W)O;F]L:71H)UT@/2`F2W)O;F]L:71H7T1R:79E<CHZ9F%C=&]R
M>2@I.PH*+RH@0W)E871E(&$@<VAA<F4@:6YS=&%N8V4N("HO"G)E<75I<F5?
M;VYC92`G2&]R9&4O4VAA<F4N<&AP)SL*)$=,3T)!3%-;)VMR;VYO;&ET:%]S
M:&%R97,G72`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1R96=I<W1R>2T^
M9V5T07!P*"DI.PH*+RH@57!D871E('!R969E<F5N8V5S(&9O<B!W:&EC:"!C
M86QE;F1A<G,@=&\@9&ES<&QA>2X@268@=&AE('5S97(*("H@9&]E<VXG="!H
M879E(&%N>2!S96QE8W1E9"!C86QE;F1A<G,@=&\@=FEE=R!T:&5N(&9A;&P@
M8F%C:R!T;R!A;@H@*B!A=F%I;&%B;&4@8V%L96YD87(N("HO"B1'3$]"04Q3
M6R=D:7-P;&%Y7V-A;&5N9&%R<R==(#T@=6YS97)I86QI>F4H)$=,3T)!3%-;
M)W!R969S)UTM/F=E=%9A;'5E*"=D:7-P;&%Y7V-A;',G*2D["B1'3$]"04Q3
M6R=D:7-P;&%Y7W)E;6]T95]C86QE;F1A<G,G72`]('5N<V5R:6%L:7IE*"1'
M3$]"04Q36R=P<F5F<R==+3YG971686QU92@G9&ES<&QA>5]R96UO=&5?8V%L
M<R<I*3L*:68@*"@D9%]C86P@/2!5=&EL.CIG971&;W)M1&%T82@G9&ES<&QA
M>5]C86PG*2D@(3T](&YU;&PI('L*("`@(&EF("AS=6)S='(H)&1?8V%L+"`P
M+"`W*2`]/2`G<F5M;W1E7R<I('L*("`@("`@("`D9%]C86P@/2!S=6)S='(H
M)&1?8V%L+"`W*3L*("`@("`@("!I9B`H:6Y?87)R87DH)&1?8V%L+"`D1TQ/
M0D%,4ULG9&ES<&QA>5]R96UO=&5?8V%L96YD87)S)UTI*2!["B`@("`@("`@
M("`@("1K97D@/2!A<G)A>5]S96%R8V@H)&1?8V%L+"`D1TQ/0D%,4ULG9&ES
M<&QA>5]R96UO=&5?8V%L96YD87)S)UTI.PH@("`@("`@("`@("!U;G-E="@D
M1TQ/0D%,4ULG9&ES<&QA>5]R96UO=&5?8V%L96YD87)S)UU;)&ME>5TI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1'3$]"04Q36R=D:7-P;&%Y
M7W)E;6]T95]C86QE;F1A<G,G75M=(#T@)&1?8V%L.PH@("`@("`@('T*("`@
M('T@96QS92!["B`@("`@("`@:68@*&EN7V%R<F%Y*"1D7V-A;"P@)$=,3T)!
M3%-;)V1I<W!L87E?8V%L96YD87)S)UTI*2!["B`@("`@("`@("`@("1K97D@
M/2!A<G)A>5]S96%R8V@H)&1?8V%L+"`D1TQ/0D%,4ULG9&ES<&QA>5]C86QE
M;F1A<G,G72D["B`@("`@("`@("`@('5N<V5T*"1'3$]"04Q36R=D:7-P;&%Y
M7V-A;&5N9&%R<R==6R1K97E=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D1TQ/0D%,4ULG9&ES<&QA>5]C86QE;F1A<G,G75M=(#T@)&1?8V%L
M.PH@("`@("`@('T*("`@('T*?0H*+RH@36%K92!S=7)E(&%L;"!S:&%R97,@
M97AI<W1S(&YO=R!T;R!S879E(&]N(&-H96-K:6YG(&QA=&5R+B`J+PHD1TQ/
M0D%,4ULG86QL7V-A;&5N9&%R<R==(#T@2W)O;F]L:71H.CIL:7-T0V%L96YD
M87)S*"D["B1C86QE;F1A<E]K97ES(#T@87)R87E?=F%L=65S*"1'3$]"04Q3
M6R=D:7-P;&%Y7V-A;&5N9&%R<R==*3L*)$=,3T)!3%-;)V1I<W!L87E?8V%L
M96YD87)S)UT@/2!A<G)A>2@I.PIF;W)E86-H("@D8V%L96YD87)?:V5Y<R!A
M<R`D:60I('L*("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG86QL7V-A;&5N9&%R
M<R==6R1I9%TI*2!["B`@("`@("`@)$=,3T)!3%-;)V1I<W!L87E?8V%L96YD
M87)S)UU;72`]("1I9#L*("`@('T*?0H*+RH@36%K92!S=7)E(&%L;"!T:&4@
M<F5M;W1E(&-A;&5N9&%R<R!S=&EL;"!E>&ES="X@*B\*)%]T96UP(#T@)$=,
M3T)!3%-;)V1I<W!L87E?<F5M;W1E7V-A;&5N9&%R<R==.PHD7V%L;"`]('5N
M<V5R:6%L:7IE*"1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G<F5M;W1E
M7V-A;',G*2D["B1'3$]"04Q36R=D:7-P;&%Y7W)E;6]T95]C86QE;F1A<G,G
M72`](&%R<F%Y*"D["F9O<F5A8V@@*"1?86QL(&%S("1I9"D@>PH@("`@:68@
M*&EN7V%R<F%Y*"1I9%LG=7)L)UTL("1?=&5M<"DI('L*("`@("`@("`D1TQ/
M0D%,4ULG9&ES<&QA>5]R96UO=&5?8V%L96YD87)S)UU;72`]("1I9%LG=7)L
M)UT["B`@("!]"GT*)$=,3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=D:7-P
M;&%Y7W)E;6]T95]C86QS)RP@<V5R:6%L:7IE*"1'3$]"04Q36R=D:7-P;&%Y
M7W)E;6]T95]C86QE;F1A<G,G72DI.PH*:68@*&-O=6YT*"1'3$]"04Q36R=D
M:7-P;&%Y7V-A;&5N9&%R<R==*2`]/2`P*2!["B`@("`D8V%L<R`]($MR;VYO
M;&ET:#HZ;&ES=$-A;&5N9&%R<RAT<G5E*3L*("`@(&EF("@A075T:#HZ9V5T
M075T:"@I*2!["B`@("`@("`@+RH@06QL(&-A;&5N9&%R<R!F;W(@9W5E<W1S
M+B`J+PH@("`@("`@("1'3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R<R==(#T@
M87)R87E?:V5Y<R@D8V%L<RD["B`@("!](&5L<V4@>PH@("`@("`@("\J($UA
M:V4@<W5R92!A="!L96%S="!T:&4@9&5F875L="!C86QE;F1A<B!I<R!V:7-I
M8FQE+B`J+PH@("`@("`@("1'3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R<R==
M(#T@87)R87DH2W)O;F]L:71H.CIG971$969A=6QT0V%L96YD87(H4$5235-?
M4D5!1"DI.PH*("`@("`@("`O*B!)9B!T:&4@=7-E<B=S('!E<G-O;F%L(&-A
M;&5N9&%R(&1O97-N)W0@97AI<W0L('1H96X@8W)E871E(&ET+B`J+PH@("`@
M("`@(&EF("@A)$=,3T)!3%-;)VMR;VYO;&ET:%]S:&%R97,G72T^97AI<W1S
M*$%U=&@Z.F=E=$%U=&@H*2DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@("`@("`D:61E;G1I='D@
M/2`F261E;G1I='DZ.G-I;F=L971O;B@I.PH@("`@("`@("`@("`D;F%M92`]
M("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN86UE)RD["B`@("`@("`@("`@
M(&EF("AT<FEM*"1N86UE*2`]/2`G)RD@>PH@("`@("`@("`@("`@("`@)&YA
M;64@/2!!=71H.CIR96UO=F5(;V]K*$%U=&@Z.F=E=$%U=&@H*2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'-H87)E(#T@)B1'3$]"04Q36R=K<F]N
M;VQI=&A?<VAA<F5S)UTM/FYE=U-H87)E*$%U=&@Z.F=E=$%U=&@H*2D["B`@
M("`@("`@("`@("1S:&%R92T^<V5T*"=N86UE)RP@<W!R:6YT9BA?*"(E<R=S
M($-A;&5N9&%R(BDL("1N86UE*2D["B`@("`@("`@("`@("1'3$]"04Q36R=K
M<F]N;VQI=&A?<VAA<F5S)UTM/F%D9%-H87)E*"1S:&%R92D["B`@("`@("`@
M("`@("1'3$]"04Q36R=A;&Q?8V%L96YD87)S)UU;075T:#HZ9V5T075T:"@I
M72`]("8D<VAA<F4["@H@("`@("`@("`@("`O*B!-86ME('-U<F4@=&AE('!E
M<G-O;F%L(&-A;&5N9&%R(&ES(&1I<W!L87EE9"!B>2!D969A=6QT+B`J+PH@
M("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1'3$]"04Q36R=D:7-P;&%Y7V-A
M;&5N9&%R<R==+"!!=71H.CIG971!=71H*"DI*2!["B`@("`@("`@("`@("`@
M("`D1TQ/0D%,4ULG9&ES<&QA>5]C86QE;F1A<G,G75M=(#T@075T:#HZ9V5T
M075T:"@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#86QE;F1A
M<B!A=71O+7-H87)I;F<@=VET:"!T:&4@=7-E<B=S(&=R;W5P<R`J+PH@("`@
M("`@("`@("!I9B`H)&-O;F9;)V%U=&]S:&%R92==6R=S:&%R97!E<FUS)UT@
M(3T@)VYO;F4G*2!["B`@("`@("`@("`@("`@("`D<&5R;5]V86QU92`](#`[
M"B`@("`@("`@("`@("`@("!S=VET8V@@*"1C;VYF6R=A=71O<VAA<F4G75LG
M<VAA<F5P97)M<R==*2!["B`@("`@("`@("`@("`@("!C87-E("=R96%D)SH*
M("`@("`@("`@("`@("`@("`@("`D<&5R;5]V86QU92`](%!%4DU37U)%040@
M?"!015)-4U]32$]7.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`G961I="<Z"B`@("`@("`@("`@("`@("`@("`@
M)'!E<FU?=F%L=64@/2!015)-4U]214%$('P@4$5235-?4TA/5R!\(%!%4DU3
M7T5$250["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!C87-E("=F=6QL)SH*("`@("`@("`@("`@("`@("`@("`D<&5R;5]V
M86QU92`](%!%4DU37U)%040@?"!015)-4U]32$]7('P@4$5235-?141)5"!\
M(%!%4DU37T1%3$5413L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P97)M(#T@)'-H87)E
M+3YG971097)M:7-S:6]N*"D["B`@("`@("`@("`@("`@("`O+R!!9&0@=&AE
M(&1E9F%U;'0@<&5R;2P@;F]T(&%D9&5D(&]T:&5R=VES90H@("`@("`@("`@
M("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H
M*2P@4$5235-?04Q,+"!F86QS92D["B`@("`@("`@("`@("`@("`D9W)O=7!?
M;&ES="`]($=R;W5P.CIG971'<F]U<$UE;6)E<G-H:7!S*$%U=&@Z.F=E=$%U
M=&@H*2D["B`@("`@("`@("`@("`@("!I9B`H(6ES7V$H)&=R;W5P7VQI<W0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D9W)O=7!?;&ES="!A<R`D9W)O=7!?:60@/3X@)&=R;W5P7VYA;64I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FTM/F%D9$=R;W5P4&5R;6ES
M<VEO;B@D9W)O=7!?:60L("1P97)M7W9A;'5E+"!F86QS92D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'-H87)E+3YS971097)M:7-S:6]N*"1P97)M*3L*("`@("`@("`@("`@
M("`@("1S:&%R92T^<V%V92@I.PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"AS<')I;G1F*%\H(DYE=R!C86QE;F1A<B!C<F5A=&5D(&%N
M9"!A=71O;6%T:6-A;&QY('-H87)E9"!W:71H('1H92!F;VQL;W=I;F<@9W)O
M=7`H<RDZ("5S+B(I+"!I;7!L;V1E*"<L("<L("1G<F]U<%]L:7-T*2DL("=H
M;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"GT*"B1'3$]"04Q36R=P<F5F<R==+3YS971686QU92@G9&ES<&QA>5]C86QS
M)RP@<V5R:6%L:7IE*"1'3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R<R==*2D[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O
M;F]L:71H+VQI8B]3=&]R86=E+G!H<```````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-S(U-P`Q,#0Q-S,V,C<U,P`P,C$S,S``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!+<F]N;VQI=&A?4W1O<F%G93HZ(&1E9FEN97,@86X@05!)(&9O<B!S=&]R
M:6YG(&9R964O8G5S>2!I;F9O<FUA=&EO;@H@*@H@*B!`875T:&]R("!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<&%C:V%G
M92!+<F]N;VQI=&@*("HO"F-L87-S($MR;VYO;&ET:%]3=&]R86=E('L*"B`@
M("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!C=7)R96YT('5S
M97)N86UE+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7W5S97(@/2`G)SL*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E='5R;B!A(&-O;F-R971E($MR;VYO;&ET:%]3=&]R86=E(&EN<W1A;F-E
M(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@("`D9')I=F5R("`@("!4:&4@='EP92!O9B!C;VYC<F5T92!+<F]N;VQI
M=&A?4W1O<F%G92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T;R!R971U<FXN("!4:&4@:7,@8F%S960@;VX@=&AE('-T
M;W)A9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9')I
M=F5R("@D9')I=F5R*2X@(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&5D+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)'5S97(@("`@("`@5&AE(&YA
M;64@;V8@=&AE('5S97(@=VAO(&]W;G,@=&AE(&9R964O8G5S>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`@("`@)'!A<F%M<R`@("`@*&]P=&EO
M;F%L*2!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYF:6=U<F%T:6]N(&]R
M(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@("!4:&4@;F5W;'D@8W)E871E9"!C;VYC
M<F5T92!+<F]N;VQI=&A?4W1O<F%G92!I;G-T86YC92P@;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9F86-T;W)Y*"1U<V5R(#T@;G5L;"P@)&1R:79E<B`](&YU
M;&PL("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL
M*"1U<V5R*2D@>PH@("`@("`@("`@("`D=7-E<B`]($%U=&@Z.F=E=$%U=&@H
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N=6QL*"1D<FEV97(I*2![
M"B`@("`@("`@("`@("1D<FEV97(@/2`D1TQ/0D%,4ULG8V]N9B==6R=S=&]R
M86=E)UU;)V1R:79E<B==.PH@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`]
M(&)A<V5N86UE*"1D<FEV97(I.PH*("`@("`@("!I9B`H:7-?;G5L;"@D<&%R
M86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E
M<D-O;F9I9R@G<W1O<F%G92<L("1D<FEV97(I.PH@("`@("`@('T*"B`@("`@
M("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]3=&]R86=E
M+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=+<F]N
M;VQI=&A?4W1O<F%G95\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?
M97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R970@/2`F
M;F5W("1C;&%S<R@D=7-E<BP@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T
M;R!A(&-O;F-R971E($MR;VYO;&ET:%]3=&]R86=E(&EN<W1A;F-E"B`@("`@
M*B!B87-E9"!O;B`D9')I=F5R+B`@270@=VEL;"!O;FQY(&-R96%T92!A(&YE
M=R!I;G-T86YC92!I9B!N;PH@("`@("H@2W)O;F]L:71H7U-T;W)A9V4@:6YS
M=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES
M=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT
M:7!L92!S=&]R86=E('-O=7)C97,@87)E(')E<75I<F5D+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9+
M<F]N;VQI=&A?4W1O<F%G93HZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`@("1D<FEV97(@("`@(%1H92!T>7!E(&]F(&-O;F-R
M971E($MR;VYO;&ET:%]3=&]R86=E('-U8F-L87-S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1O(')E='5R;BX@(%1H92!I<R!B87-E
M9"!O;B!T:&4@<W1O<F%G90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!D<FEV97(@*"1D<FEV97(I+B`@5&AE(&-O9&4@:7,@9'EN86UI
M8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YC
M;'5D960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@("`D=7-E<B`@
M("`@("!4:&4@;F%M92!O9B!T:&4@=7-E<B!W:&\@;W=N<R!T:&4@9G)E92]B
M=7-Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN9F]R
M;6%T:6]N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@("`D<&%R86US
M("`@("`H;W!T:6]N86PI($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;F9I
M9W5R871I;VX@;W(@8V]N;F5C=&EO;B!P87)A;65T97)S(&$*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@;6EG:'0@;F5E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@(%1H92!C<F5A=&5D
M(&-O;F-R971E($MR;VYO;&ET:%]3=&]R86=E(&EN<W1A;F-E+"!O<B!F86QS
M90H@("`@("H@("`@("`@("`@("`@("`@("!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)G-I;F=L971O;B@D=7-E<B`](&YU;&PL("1D<FEV97(@
M/2!N=6QL+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@
M)&EN<W1A;F-E<SL*"B`@("`@("`@:68@*&ES7VYU;&PH)'5S97(I*2!["B`@
M("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T:"@I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES7VYU;&PH)&1R:79E<BDI('L*("`@("`@("`@("`@
M)&1R:79E<B`]("1'3$]"04Q36R=C;VYF)UU;)W-T;W)A9V4G75LG9')I=F5R
M)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D<&%R86US*2D@
M>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I
M9R@G<W1O<F%G92<L("1D<FEV97(I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S
M(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S
M97)I86QI>F4H87)R87DH)'5S97(L("1D<FEV97(L("1P87)A;7,I*3L*("`@
M("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@
M("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2W)O;F]L:71H
M7U-T;W)A9V4Z.F9A8W1O<GDH)'5S97(L("1D<FEV97(L("1P87)A;7,I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R
M95T["B`@("!]"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+VQI8B]P<F5F<RYP:'``````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-38V-P`Q,#0Q-S,V,C<U
M,P`P,C$P-#8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+VQI8B]P<F5F
M<RYP:'`L=B`Q+C4N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(Y.C`S(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B`@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J+PH*9G5N8W1I;VX@:&%N9&QE7W)E
M;6]T95]C86Q?;6%N86=E;65N="@D=7!D871E9"D*>PH@("`@9VQO8F%L("1P
M<F5F<SL*"B`@("`D8V%L3F%M92`](%5T:6PZ.F=E=$9O<FU$871A*"=R96UO
M=&5?;F%M92<I.PH@("`@)&-A;%5R;"`@/2!T<FEM*%5T:6PZ.F=E=$9O<FU$
M871A*"=R96UO=&5?=7)L)RDI.PH@("`@)&-A;$%C=&EO;DE$(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W)E;6]T95]A8W1I;VXG+"`G861D)RD["@H@("`@:68@
M*"1C86Q!8W1I;VY)1"`]/2`G861D)RD@>PH@("`@("`@(&EF("@A96UP='DH
M)&-A;$YA;64I("8F("%E;7!T>2@D8V%L57)L*2D@>PH@("`@("`@("`@("`D
M8V%L<R`]('5N<V5R:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H)W)E;6]T95]C
M86QS)RDI.PH@("`@("`@("`@("`D8V%L<UM=(#T@87)R87DH)VYA;64G(#T^
M("1C86Q.86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@
M(#T^("1C86Q5<FPI.PH@("`@("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=R
M96UO=&5?8V%L<R<L('-E<FEA;&EZ92@D8V%L<RDI.PH@("`@("`@("`@("`D
M=7!D871E9"`]('1R=64["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"B`@("!](&5L<V5I9B`H)&-A;$%C=&EO;DE$(#T]("=D96QE=&4G
M*2!["B`@("`@("`@)&-A;',@/2!U;G-E<FEA;&EZ92@D<')E9G,M/F=E=%9A
M;'5E*"=R96UO=&5?8V%L<R<I*3L*("`@("`@("!F;W)E86-H("@D8V%L<R!A
M<R`D:V5Y(#T^("1C86PI('L*("`@("`@("`@("`@:68@*"1C86Q;)W5R;"==
M(#T]("1C86Q5<FPI('L*("`@("`@("`@("`@("`@('5N<V5T*"1C86QS6R1K
M97E=*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)W)E;6]T95]C86QS
M)RP@<V5R:6%L:7IE*"1C86QS*2D["B`@("`@("`@)'5P9&%T960@/2!T<G5E
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@(')E='5R;B!T<G5E
M.PI]"@IF=6YC=&EO;B!H86YD;&5?<VAA<F5S96QE8W0H)'5P9&%T960I"GL*
M("`@("1D969A=6QT7W-H87)E(#T@571I;#HZ9V5T1F]R;41A=&$H)V1E9F%U
M;'1?<VAA<F4G*3L*("`@(&EF("@A:7-?;G5L;"@D9&5F875L=%]S:&%R92DI
M('L*("`@("`@("`D<VAA<F5L:7-T(#T@2W)O;F]L:71H.CIL:7-T0V%L96YD
M87)S*"D["B`@("`@("`@:68@*"AI<U]A<G)A>2@D<VAA<F5L:7-T*2D@/B`P
M("8F(&ES<V5T*"1S:&%R96QI<W1;)&1E9F%U;'1?<VAA<F5=*2D@>PH@("`@
M("`@("`@("`D1TQ/0D%,4ULG<')E9G,G72T^<V5T5F%L=64H)V1E9F%U;'1?
M<VAA<F4G+"`D9&5F875L=%]S:&%R92D["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*("`@('T*"B`@("!R971U<FX@9F%L<V4["GT*"F9U
M;F-T:6]N(&AA;F1L95]S96%R8VA?86)O;VM?<V5L96-T*"1U<&1A=&5D*0I[
M"B`@("`D861D<F5S<U]B;V]K4V5L96-T960@/2!5=&EL.CIG971&;W)M1&%T
M82@G<V5A<F-H7V%B;V]K)RD["B`@("`D861D<F5S<U]B;V]K<R`]("1'3$]"
M04Q36R=R96=I<W1R>2==+3YC86QL*"=C;VYT86-T<R]S;W5R8V5S)RD["B`@
M("`D861D<F5S<U]B;V]K1FEL=&5R960@/2!A<G)A>2@I.PH*("`@(&EF("AI
M<W-E="@D861D<F5S<U]B;V]K4V5L96-T960I("8F(&ES7V%R<F%Y*"1A9&1R
M97-S7V)O;VM396QE8W1E9"DI('L*("`@("`@("!F;W)E86-H("@D861D<F5S
M<U]B;V]K4V5L96-T960@87,@)&%D9')E<W-?8F]O:RD@>PH@("`@("`@("`@
M("`D861D<F5S<U]B;V]K1FEL=&5R961;72`]("1A9&1R97-S7V)O;VL["B`@
M("`@("`@?0H@("`@?0H*("`@("1'3$]"04Q36R=P<F5F<R==+3YS971686QU
M92@G<V5A<F-H7V%B;V]K)RP@<V5R:6%L:7IE*"1A9&1R97-S7V)O;VM&:6QT
M97)E9"DI.PH*("`@(')E='5R;B!T<G5E.PI]"@II9B`H(21P<F5F<RT^:7-,
M;V-K960H)V1A>5]H;W5R7W-T87)T)RD@?'P@(21P<F5F<RT^:7-,;V-K960H
M)V1A>5]H;W5R7V5N9"<I*2!["B`@("`D9&%Y7VAO=7)?<W1A<G1?;W!T:6]N
M<R`](&%R<F%Y*"D["B`@("!F;W(@*"1I(#T@,#L@)&D@/#T@-#@[("1I*RLI
M('L*("`@("`@("`D9&%Y7VAO=7)?<W1A<G1?;W!T:6]N<ULD:5T@/2!D871E
M*"@D<')E9G,M/F=E=%9A;'5E*"=T=V5N='E&;W5R)RDI(#\@)T<Z:2<@.B`G
M9SII82<L(&UK=&EM92@P+"`D:2`J(#,P+"`P*2D["B`@("!]"B`@("`D9&%Y
M7VAO=7)?96YD7V]P=&EO;G,@/2`D9&%Y7VAO=7)?<W1A<G1?;W!T:6]N<SL*
M?0H*9G5N8W1I;VX@:&%N9&QE7V9B7V-A;'-?<V5L96-T*"1U<&1A=&5D*0I[
M"B`@("`D9F)?8V%L<U-E;&5C=&5D(#T@571I;#HZ9V5T1F]R;41A=&$H)V9B
M7V-A;',G*3L*("`@("1F8E]C86QS(#T@2W)O;F]L:71H.CIL:7-T0V%L96YD
M87)S*"D["B`@("`D9F)?8V%L<T9I;'1E<F5D(#T@87)R87DH*3L*"B`@("!I
M9B`H:7-S970H)&9B7V-A;'-396QE8W1E9"D@)B8@:7-?87)R87DH)&9B7V-A
M;'-396QE8W1E9"DI('L*("`@("`@("!F;W)E86-H("@D9F)?8V%L<U-E;&5C
M=&5D(&%S("1F8E]C86PI('L*("`@("`@("`@("`@)&9B7V-A;'-&:6QT97)E
M9%M=(#T@)&9B7V-A;#L*("`@("`@("!]"B`@("!]"@H@("`@)$=,3T)!3%-;
M)W!R969S)UTM/G-E=%9A;'5E*"=F8E]C86QS)RP@<V5R:6%L:7IE*"1F8E]C
M86QS1FEL=&5R960I*3L*"B`@("!R971U<FX@=')U93L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K
M<F]N;VQI=&@O;&EB+T9"5FEE=RYP:'``````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(Q,C<P`#$P-#$W,S8R-S4S`#`R,3`S-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E("=(;W)D92]496UP;&%T92YP:'`G.PH*+RHJ"B`J(%1H:7,@
M8VQA<W,@<F5P<F5S96YT(&$@=FEE=R!O9B!M=6QT:7!L92!F<F5E(&)U<WD@
M:6YF;W)M871I;VX@<V5T<RX*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N+@H@*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]L:6(O
M1D)6:65W+G!H<"QV(#$N,3`N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(Y.C`S(&IA
M;B!%>'`@)`H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!+<F]N;VQI=&@*("HO"F-L87-S
M($MR;VYO;&ET:%]&<F5E0G5S>5]6:65W('L*"B`@("!V87(@)%]R97%U:7)E
M9$UE;6)E<G,@/2!A<G)A>2@I.PH@("`@=F%R("1?;W!T:6]N86Q-96UB97)S
M(#T@87)R87DH*3L*"B`@("!V87(@)%]S=&%R=$AO=7(["B`@("!V87(@)%]E
M;F1(;W5R.PH*("`@('9A<B`D7W-T87)T4W1A;7`["B`@("!V87(@)%]E;F13
M=&%M<#L*"B`@("!F=6YC=&EO;B!A9&1297%U:7)E9$UE;6)E<B@D=D9R965B
M=7-Y*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5Q=6ER961-96UB97)S6UT@
M/2!5=&EL.CIC;&]N94]B:F5C="@D=D9R965B=7-Y*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!A9&1/<'1I;VYA;$UE;6)E<B@D=D9R965B=7-Y*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;W!T:6]N86Q-96UB97)S6UT@/2!5=&EL.CIC;&]N
M94]B:F5C="@D=D9R965B=7-Y*3L*("`@('T*"B`@("!F=6YC=&EO;B!R96YD
M97(H)&1A>2`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*
M"B`@("`@("`@)'1H:7,M/E]S=&%R=$AO=7(@/2!F;&]O<B@D<')E9G,M/F=E
M=%9A;'5E*"=D87E?:&]U<E]S=&%R="<I("\@,BD["B`@("`@("`@)'1H:7,M
M/E]E;F1(;W5R(#T@9FQO;W(H*"1P<F5F<RT^9V5T5F%L=64H)V1A>5]H;W5R
M7V5N9"<I("L@,2D@+R`R*3L*"B`@("`@("`@)'1H:7,M/E]R96YD97(H)&1A
M>2D["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H
M<"<["B`@("`@("`@)'9#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@
M("`@("`@("1R97%U:7)E9"`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O;7!O
M;F5N="@G=F9R965B=7-Y)RP@)'9#86PI.PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?<F5Q=6ER961-96UB97)S(&%S("1M96UB97(I('L*("`@("`@("`@
M("`@)')E<75I<F5D+3YM97)G92@D;65M8F5R+"!F86QS92D["B`@("`@("`@
M?0H@("`@("`@("1R97%U:7)E9"T^<VEM<&QI9GDH*3L*"B`@("`@("`@)&]P
M=&EO;F%L(#T@)DAO<F1E7VE#86QE;F1A<CHZ;F5W0V]M<&]N96YT*"=V9G)E
M96)U<WDG+"`D=D-A;"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]O<'1I
M;VYA;$UE;6)E<G,@87,@)&UE;6)E<BD@>PH@("`@("`@("`@("`D;W!T:6]N
M86PM/FUE<F=E*"1M96UB97(L(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@
M)&]P=&EO;F%L+3YS:6UP;&EF>2@I.PH*("`@("`@("`D;W!T:6UA;"`]("9(
M;W)D95]I0V%L96YD87(Z.FYE=T-O;7!O;F5N="@G=F9R965B=7-Y)RP@)'9#
M86PI.PH@("`@("`@("1O<'1I;6%L+3YM97)G92@D<F5Q=6ER960L(&9A;'-E
M*3L*("`@("`@("`D;W!T:6UA;"T^;65R9V4H)&]P=&EO;F%L*3L*"B`@("`@
M("`@)&)A<V5?=7)L(#T@2&]R9&4Z.G-E;&95<FPH*3L*("`@("`@("`D8F%S
M95]U<FP@/2!5=&EL.CIR96UO=F5087)A;65T97(H)&)A<V5?=7)L+"`G9&%T
M92<I.PH@("`@("`@("1B87-E7W5R;"`](%5T:6PZ.G)E;6]V95!A<F%M971E
M<B@D8F%S95]U<FPL("=F8G9I97<G*3L*("`@("`@("`D8F%S95]U<FP@/2!5
M=&EL.CIA9&1087)A;65T97(H)&)A<V5?=7)L+"`G9F)V:65W)RP@)'1H:7,M
M/G9I97<I.PH*("`@("`@("`D=&5M<&QA=&4@/2`F;F5W($AO<F1E7U1E;7!L
M871E*"D["B`@("`@("`@)'1E;7!L871E+3YS970H)W1I=&QE)RP@)'1H:7,M
M/E]T:71L92@I*3L*"B`@("`@("`@)&AT;6P@/2`D=&5M<&QA=&4M/F9E=&-H
M*$M23TY/3$E42%]414U03$%415,@+B`G+V9B=FEE=R]H96%D97(N='!L)RD@
M+@H@("`@("`@("`@("`G/&1I=B!C;&%S<STB9F)G<FED(CXG.PH*("`@("`@
M("`D:&]U<G-?:'1M;"`]("1T:&ES+3Y?:&]U<G,H*3L*"B`@("`@("`@+R\@
M<V5T($,@;&]C86QE('1O(&%V;VED(&QO8V%L:7IE9"!D96-I;6%L('-E<&%R
M871O<G,@9'5R:6YG($-34R!W:61T:`H@("`@("`@("\O(&-A;&-U;&%T:6]N
M+@H@("`@("`@("1L8R`]('-E=&QO8V%L92A,0U].54U%4DE#+"`P*3L*("`@
M("`@("!S971L;V-A;&4H3$-?3E5-15))0RP@)T,G*3L*"B`@("`@("`@+R\@
M4F5Q=6ER960@=&\@871T96YD+@H@("`@("`@(&EF("AC;W5N="@D=&AI<RT^
M7W)E<75I<F5D365M8F5R<RD@/B`P*2!["B`@("`@("`@("`@("1T96UP;&%T
M92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*("`@("`@("`@("`@)')O=W,@
M/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]R97%U:7)E9$UE
M;6)E<G,@87,@)&UE;6)E<BD@>PH@("`@("`@("`@("`@("`@)&)L;V-K<R`]
M("1T:&ES+3Y?9V5T0FQO8VMS*"1M96UB97(L("1M96UB97(M/F=E=$)U<WE0
M97)I;V1S*"DL("=B=7-Y8FQO8VLN='!L)RP@7R@B0G5S>2(I*3L*("`@("`@
M("`@("`@("`@("1T96UP;&%T92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*
M("`@("`@("`@("`@("`@("1T96UP;&%T92T^<V5T*"=B;&]C:W,G+"`D8FQO
M8VMS*3L*("`@("`@("`@("`@("`@("1T96UP;&%T92T^<V5T*"=N86UE)RP@
M)&UE;6)E<BT^9V5T3F%M92@I*3L*("`@("`@("`@("`@("`@("1R;W=S("X]
M("1T96UP;&%T92T^9F5T8V@H2U)/3D],251(7U1%35!,051%4R`N("<O9F)V
M:65W+W)O=RYT<&PG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1E
M;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T92@I.PH@("`@("`@("`@("`D
M=&5M<&QA=&4M/G-E="@G=&ET;&4G+"!?*")297%U:7)E9"!!='1E;F1E97,B
M*2D["B`@("`@("`@("`@("1T96UP;&%T92T^<V5T*"=R;W=S)RP@)')O=W,I
M.PH@("`@("`@("`@("`D=&5M<&QA=&4M/G-E="@G<W!A;B<L(&-O=6YT*"1T
M:&ES+3Y?=&EM94)L;V-K<RDI.PH@("`@("`@("`@("`D=&5M<&QA=&4M/G-E
M="@G:&]U<G,G+"`D:&]U<G-?:'1M;"D["B`@("`@("`@("`@("1T96UP;&%T
M92T^<V5T*"=L96=E;F0G+"`G)RD["B`@("`@("`@("`@("1H=&UL("X]("1T
M96UP;&%T92T^9F5T8V@H2U)/3D],251(7U1%35!,051%4R`N("<O9F)V:65W
M+W-E8W1I;VXN='!L)RD["B`@("`@("`@?0H*("`@("`@("`O+R!/<'1I;VYA
M;"!T;R!A='1E;F0N"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?;W!T:6]N
M86Q-96UB97)S*2`^(#`I('L*("`@("`@("`@("`@)'1E;7!L871E(#T@)FYE
M=R!(;W)D95]496UP;&%T92@I.PH@("`@("`@("`@("`D<F]W<R`]("<G.PH@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V]P=&EO;F%L365M8F5R<R!A
M<R`D;65M8F5R*2!["B`@("`@("`@("`@("`@("`D8FQO8VMS(#T@)'1H:7,M
M/E]G971";&]C:W,H)&UE;6)E<BP@)&UE;6)E<BT^9V5T0G5S>5!E<FEO9',H
M*2P@)V)U<WEB;&]C:RYT<&PG+"!?*")"=7-Y(BDI.PH@("`@("`@("`@("`@
M("`@)'1E;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T92@I.PH@("`@("`@
M("`@("`@("`@)'1E;7!L871E+3YS970H)V)L;V-K<R<L("1B;&]C:W,I.PH@
M("`@("`@("`@("`@("`@)'1E;7!L871E+3YS970H)VYA;64G+"`D;65M8F5R
M+3YG971.86UE*"DI.PH@("`@("`@("`@("`@("`@)')O=W,@+CT@)'1E;7!L
M871E+3YF971C:"A+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]F8G9I97<O<F]W
M+G1P;"<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&5M<&QA=&4@
M/2`F;F5W($AO<F1E7U1E;7!L871E*"D["B`@("`@("`@("`@("1T96UP;&%T
M92T^<V5T*"=T:71L92<L(%\H(D]P=&EO;F%L($%T=&5N9&5E<R(I*3L*("`@
M("`@("`@("`@)'1E;7!L871E+3YS970H)W)O=W,G+"`D<F]W<RD["B`@("`@
M("`@("`@("1T96UP;&%T92T^<V5T*"=S<&%N)RP@8V]U;G0H)'1H:7,M/E]T
M:6UE0FQO8VMS*2D["B`@("`@("`@("`@("1T96UP;&%T92T^<V5T*"=H;W5R
M<R<L("1H;W5R<U]H=&UL*3L*("`@("`@("`@("`@)'1E;7!L871E+3YS970H
M)VQE9V5N9"<L("<G*3L*("`@("`@("`@("`@)&AT;6P@+CT@)'1E;7!L871E
M+3YF971C:"A+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]F8G9I97<O<V5C=&EO
M;BYT<&PG*3L*("`@("`@("!]"@H@("`@("`@("\O(%!O<W-I8FQE(&UE971I
M;F<@=&EM97,N"B`@("`@("`@)&]P=&EM86PM/G-E=$%T=')I8G5T92@G3U)'
M04Y)6D52)RP@7R@B06QL($%T=&5N9&5E<R(I*3L*("`@("`@("`D8FQO8VMS
M(#T@)'1H:7,M/E]G971";&]C:W,H)&]P=&EM86PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1O<'1I;6%L+3YG971&<F5E4&5R:6]D
M<R@D=&AI<RT^7W-T87)T4W1A;7`L("1T:&ES+3Y?96YD4W1A;7`I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;65E=&EN9V)L;V-K
M+G1P;"<L(%\H(D%L;"!!='1E;F1E97,B*2D["@H@("`@("`@("1T96UP;&%T
M92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*("`@("`@("`D=&5M<&QA=&4M
M/G-E="@G;F%M92<L(%\H(D%L;"!!='1E;F1E97,B*2D["B`@("`@("`@)'1E
M;7!L871E+3YS970H)V)L;V-K<R<L("1B;&]C:W,I.PH@("`@("`@("1R;W=S
M(#T@)'1E;7!L871E+3YF971C:"A+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]F
M8G9I97<O<F]W+G1P;"<I.PH*("`@("`@("`O+R!0;W-S:6)L92!M965T:6YG
M('1I;65S+@H@("`@("`@("1R97%U:7)E9"T^<V5T071T<FEB=71E*"=/4D=!
M3DE:15(G+"!?*")297%U:7)E9"!!='1E;F1E97,B*2D["B`@("`@("`@)&)L
M;V-K<R`]("1T:&ES+3Y?9V5T0FQO8VMS*"1R97%U:7)E9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D+3YG971&<F5E
M4&5R:6]D<R@D=&AI<RT^7W-T87)T4W1A;7`L("1T:&ES+3Y?96YD4W1A;7`I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;65E=&EN
M9V)L;V-K+G1P;"<L(%\H(E)E<75I<F5D($%T=&5N9&5E<R(I*3L*"B`@("`@
M("`@)'1E;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T92@I.PH@("`@("`@
M("1T96UP;&%T92T^<V5T*"=N86UE)RP@7R@B4F5Q=6ER960@071T96YD965S
M(BDI.PH@("`@("`@("1T96UP;&%T92T^<V5T*"=B;&]C:W,G+"`D8FQO8VMS
M*3L*("`@("`@("`D<F]W<R`N/2`D=&5M<&QA=&4M/F9E=&-H*$M23TY/3$E4
M2%]414U03$%415,@+B`G+V9B=FEE=R]R;W<N='!L)RD["@H@("`@("`@("\O
M(%)E<V5T(&QO8V%L92X*("`@("`@("!S971L;V-A;&4H3$-?3E5-15))0RP@
M)&QC*3L*"B`@("`@("`@)'1E;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T
M92@I.PH@("`@("`@("1T96UP;&%T92T^<V5T*"=R;W=S)RP@)')O=W,I.PH@
M("`@("`@("1T96UP;&%T92T^<V5T*"=T:71L92<L(%\H(D]V97)V:65W(BDI
M.PH@("`@("`@("1T96UP;&%T92T^<V5T*"=S<&%N)RP@8V]U;G0H)'1H:7,M
M/E]T:6UE0FQO8VMS*2D["B`@("`@("`@)'1E;7!L871E+3YS970H)VAO=7)S
M)RP@)&AO=7)S7VAT;6PI.PH@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E
M*"=S:&]W7V9B7VQE9V5N9"<I*2!["B`@("`@("`@("`@("1T96UP;&%T92T^
M<V5T3W!T:6]N*"=G971T97AT)RP@=')U92D["B`@("`@("`@("`@("1T96UP
M;&%T92T^<V5T*"=L96=E;F0G+"`D=&5M<&QA=&4M/F9E=&-H*$M23TY/3$E4
M2%]414U03$%415,@+B`G+V9B=FEE=R]L96=E;F0N='!L)RDI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T96UP;&%T92T^<V5T*"=L96=E;F0G
M+"`G)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P@+B`D=&5M
M<&QA=&4M/F9E=&-H*$M23TY/3$E42%]414U03$%415,@+B`G+V9B=FEE=R]S
M96-T:6]N+G1P;"<I("X@)SPO9&EV/B<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!+<F]N;VQI=&A?1G)E
M94)U<WE?5FEE=R!I;G-T86YC92!B87-E9"!O;@H@("`@("H@)'9I97<N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=FEE=R`@5&AE('1Y<&4@;V8@
M8V]N8W)E=&4@2W)O;F]L:71H7T9R965"=7-Y7U9I97<*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@('-U8F-L87-S('1O(')E='5R;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T
M92!+<F]N;VQI=&A?1G)E94)U<WE?5FEE=PH@("`@("H@("`@("`@("`@("`@
M("`@:6YS=&%N8V4L(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F9F%C=&]R>2@D=FEE=RD*("`@('L*("`@("`@("`D9')I
M=F5R(#T@8F%S96YA;64H)'9I97<I.PH@("`@("`@(')E<75I<F5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O1D)6:65W+R<@+B`D=FEE=R`N("<N<&AP
M)SL*("`@("`@("`D8VQA<W,@/2`G2W)O;F]L:71H7T9R965"=7-Y7U9I97=?
M)R`N("1V:65W.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`D=FEE=R`]("9N97<@)&-L87-S*"1U<V5R+"`D<&%R
M86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=FEE=R`](&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V:65W.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E
M('1O(&$@8V]N8W)E=&4@2W)O;F]L:71H7T9R965"=7-Y7U9I97<*("`@("`J
M(&EN<W1A;F-E(&)A<V5D(&]N("1V:65W+B`@270@=VEL;"!O;FQY(&-R96%T
M92!A(&YE=R!I;G-T86YC92!I9B!N;PH@("`@("H@2W)O;F]L:71H7T9R965"
M=7-Y7U9I97<@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U
M<G)E;G1L>0H@("`@("H@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T
M:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*("`@("`J("1V87(@/2`F2W)O;F]L
M:71H7T9R965"=7-Y7U9I97<Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=FEE=R`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2W)O
M;F]L:71H7T9R965"=7-Y7U9I97<*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@('-U8F-L87-S('1O(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@8W)E871E9"!C;VYC<F5T92!+<F]N;VQI=&A?1G)E94)U
M<WE?5FEE=R!I;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@(&9A
M;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1V:65W*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH*
M("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@
M("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<W-E="@D:6YS=&%N8V5S6R1V:65W72DI('L*("`@("`@("`@("`@)&EN
M<W1A;F-E<ULD=FEE=UT@/2`F2W)O;F]L:71H7T9R965"=7-Y7U9I97<Z.F9A
M8W1O<GDH)'9I97<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T
M86YC97-;)'9I97==.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G971";&]C:W,H
M)&UE;6)E<BP@)'!E<FEO9',L("1B;&]C:V9I;&4L("1L86)E;"D*("`@('L*
M("`@("`@("`D=&5M<&QA=&4@/2`F;F5W($AO<F1E7U1E;7!L871E*"D["B`@
M("`@("`@)'1E;7!L871E+3YS970H)VQA8F5L)RP@)&QA8F5L*3L*"B`@("`@
M("`@<F5S970H)'!E<FEO9',I.PH@("`@("`@(&QI<W0H)'!E<FEO9%-T87)T
M+"`D<&5R:6]D16YD*2`](&5A8V@H)'!E<FEO9',I.PH*("`@("`@("`D8FQO
M8VMS(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]T:6UE0FQO8VMS
M(&%S("1S=&%R="`]/B`D96YD*2!["B`@("`@("`@("`@(&EF("@D;65M8F5R
M+3YG9713=&%R="@I(#X@)'-T87)T('Q\"B`@("`@("`@("`@("`@("`D;65M
M8F5R+3YG971%;F0H*2`\("1E;F0I('L*("`@("`@("`@("`@("`@("1B;&]C
M:W,@+CT@)'1E;7!L871E+3YF971C:"A+4D].3TQ)5$A?5$5-4$Q!5$53("X@
M)R]F8G9I97<O=6YK;F]W;F)L;V-K+G1P;"<I.PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('=H:6QE("@D
M96YD(#X@)'!E<FEO9$5N9"`F)@H@("`@("`@("`@("`@("`@("`@;&ES="@D
M<&5R:6]D4W1A<G0L("1P97)I;V1%;F0I(#T@96%C:"@D<&5R:6]D<RDI.PH*
M("`@("`@("`@("`@:68@*"1S=&%R="`\/2`D<&5R:6]D16YD("8F("1E;F0@
M/CT@)'!E<FEO9%-T87)T*2!["B`@("`@("`@("`@("`@("`D8FQO8VMS("X]
M("1T96UP;&%T92T^9F5T8V@H2U)/3D],251(7U1%35!,051%4R`N("<O9F)V
M:65W+R<@+B`D8FQO8VMF:6QE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1B;&]C:W,@+CT@)'1E;7!L871E+3YF971C:"A+4D].
M3TQ)5$A?5$5-4$Q!5$53("X@)R]F8G9I97<O96UP='EB;&]C:RYT<&PG*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1B;&]C
M:W,["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VMR;VYO;&ET:"]L:6(O1&%Y+G!H<```````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4R-S0`,3`T,3<S-C(W-3,`,#(P-#,V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@2W)O;F]L:71H7T1A>3HZ(&-L87-S('!R;W9I9&5S
M(&%N($%022!F;W(@9&5A;&EN9R!W:71H(&1A>7,N"B`J"B`J("1(;W)D93H@
M:W)O;F]L:71H+VQI8B]$87DN<&AP+'8@,2XR-BXQ,"XR(#(P,#4O,3`O,3@@
M,3(Z,C<Z,S`@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!+<F]N;VQI=&@@
M,"XQ"B`J($!P86-K86=E($MR;VYO;&ET:`H@*B\*8VQA<W,@2W)O;F]L:71H
M7T1A>2!E>'1E;F1S($AO<F1E7T1A=&4@>PH*("`@("\J*@H@("`@("H@2&]W
M(&UA;GD@=&EM92!S;&]T<R!A<F4@=V4@9&EV:61I;F<@96%C:"!H;W5R(&EN
M=&\_(%-E="!F<F]M('5S97(*("`@("`J('!R969E<F5N8V5S+@H@("`@("H*
M("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]S;&]T<U!E
M<DAO=7(["@H@("`@+RHJ"B`@("`@*B!(;W<@;6%N>2!S;&]T<R!D;R!W92!H
M879E('!E<B!D87D_($-A;&-U;&%T960@9G)O;2`D7W-L;W1S4&5R2&]U<BX*
M("`@("`J"B`@("`@*B!`<V5E("1?<VQO='-097)(;W5R"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<VQO='-097)$87D["@H@("`@
M+RHJ"B`@("`@*B!(;W<@;6%N>2!M:6YU=&5S(&%R92!I;B!E86-H('-L;W0_
M($-A;&-U;&%T960@9G)O;2`D7W-L;W1S4&5R2&]U<BX*("`@("`J"B`@("`@
M*B!`<V5E("1?<VQO='-097)(;W5R"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?<VQO=$QE;F=T:#L*"B`@("`O*BH*("`@("`J($%R
M<F%Y(&]F('-L;W1S(&AO;&1I;F<@=&EM97-T86UP<R!F;W(@96%C:"!P:65C
M92!O9B!T:&ES(&1A>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D<VQO=',@/2!A<G)A>2@I.PH*("`@(&9U;F-T:6]N($MR
M;VYO;&ET:%]$87DH)&UO;G1H(#T@;G5L;"P@)&1A>2`](&YU;&PL("1Y96%R
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@
M("`@("`@("`@("`D;6]N=&@@/2!D871E*"=N)RD["B`@("`@("`@?0H@("`@
M("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!D
M871E*"=9)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@
M>PH@("`@("`@("`@("`D9&%Y(#T@9&%T92@G:B<I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/DAO<F1E7T1A=&4H87)R87DH)WEE87(G(#T^("1Y96%R
M+"`G;6]N=&@G(#T^("1M;VYT:"P@)VUD87DG(#T^("1D87DI*3L*("`@("`@
M("`D=&AI<RT^8V]R<F5C="@I.PH*("`@("`@("`D=&AI<RT^7W-L;W1S4&5R
M2&]U<B`]("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G<VQO='-?<&5R
M7VAO=7(G*3L*("`@("`@("!I9B`H(21T:&ES+3Y?<VQO='-097)(;W5R*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<VQO='-097)(;W5R(#T@,3L*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/E]S;&]T<U!E<D1A>2`]("1T:&ES+3Y?<VQO
M='-097)(;W5R("H@,C0["B`@("`@("`@)'1H:7,M/E]S;&]T3&5N9W1H(#T@
M-C`@+R`D=&AI<RT^7W-L;W1S4&5R2&]U<CL*"B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)'1H:7,M/E]S;&]T<U!E<D1A>3L@)&DK*RD@>PH@("`@("`@
M("`@("`D=&AI<RT^<VQO='-;)&E=6R=T:6UE<W1A;7`G72`](&UK=&EM92@P
M+"`D:2`J("1T:&ES+3Y?<VQO=$QE;F=T:"P@,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUO
M;G1H+"`D=&AI<RT^;61A>2P@)'1H:7,M/GEE87(I.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!G9714:6UE*"1F;W)M870L("1O9F9S970@/2`P
M*0H@("`@>PH@("`@("`@(')E='5R;B!S=')F=&EM92@D9F]R;6%T+`H@("`@
M("`@("`@("`@("`@("`@("`@("!M:W1I;64H,"P@,"P@,"P@)'1H:7,M/FUO
M;G1H+"`H)'1H:7,M/FUD87D@*R`D;V9F<V5T*2P@)'1H:7,M/GEE87(I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!G9714;VUO<G)O=R@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&UK=&EM92@P+"`P+"`P+"`D=&AI<RT^;6]N=&@L("1T:&ES
M+3YM9&%Y("L@,2P@)'1H:7,M/GEE87(I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%-T86UP*"D*("`@('L*("`@("`@("!R971U<FX@;6MT:6UE*#`L(#`L
M(#`L("1T:&ES+3YM;VYT:"P@)'1H:7,M/FUD87DL("1T:&ES+3YY96%R*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!I<U1O9&%Y*"D*("`@('L*("`@("`@("!R
M971U<FX@*&UK=&EM92@P+"`P+"`P+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YM
M9&%Y+"`D=&AI<RT^>65A<BD@/3T@;6MT:6UE*#`L(#`L(#`I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!I<U1O;6]R<F]W*"D*("`@('L*("`@("`@("!R971U
M<FX@*&UK=&EM92@P+"`P+"`P+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YM9&%Y
M("T@,2P@)'1H:7,M/GEE87(I(#T](&UK=&EM92@P+"`P+"`P*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@9&EF9B@I"B`@("!["B`@("`@("`@)&1A>3(@/2`F
M;F5W($MR;VYO;&ET:%]$87DH*3L*("`@("`@("!R971U<FX@1&%T95]#86QC
M.CID871E1&EF9B@D=&AI<RT^;61A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^
M>65A<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%Y
M,BT^;61A>2P@)&1A>3(M/FUO;G1H+"`D9&%Y,BT^>65A<BD["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+VQI8B]7965K5FEE=RYP:'``````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`S,#`U,@`Q,#0Q-S,V,C<U,P`P,C$T,S<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!+
M<F]N;VQI=&A?5V5E:U9I97<Z.B!C;&%S<R!P<F]V:61E<R!A;B!!4$D@9F]R
M('9I97=I;F<@=V5E:W,N"B`J"B`J("1(;W)D93H@:W)O;F]L:71H+VQI8B]7
M965K5FEE=RYP:'`L=B`Q+C@X+C(N-"`R,#`U+S$P+S$X(#$R.C(W.C,P(&IA
M;B!%>'`@)`H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2W)O;F]L:71H(#`N,0H@*B!`<&%C:V%G
M92!+<F]N;VQI=&@*("HO"F-L87-S($MR;VYO;&ET:%]7965K5FEE=R!["@H@
M("`@=F%R("1P87)S960@/2!F86QS93L*("`@('9A<B`D9&%Y<R`](&%R<F%Y
M*"D["B`@("!V87(@)'=E96L@/2!N=6QL.PH@("`@=F%R("1Y96%R(#T@;G5L
M;#L*("`@('9A<B`D<W1A<G1$87D@/2!(3U)$15]$051%7U-53D1!63L*("`@
M('9A<B`D96YD1&%Y(#T@2$]21$5?1$%415]305154D1!63L*("`@('9A<B`D
M7W-I9&5B>7-I9&4@/2!F86QS93L*("`@('9A<B`D7V-U<G)E;G1#86QE;F1A
M<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@2&]W(&UA;GD@=&EM92!S
M;&]T<R!A<F4@=V4@9&EV:61I;F<@96%C:"!H;W5R(&EN=&\_"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W-L;W1S4&5R
M2&]U<B`](#(["@H@("`@+RHJ"B`@("`@*B!(;W<@;6%N>2!S;&]T<R!D;R!W
M92!H879E('!E<B!D87D_($-A;&-U;&%T960@9G)O;2`D7W-L;W1S4&5R2&]U
M<BX*("`@("`J"B`@("`@*B!`<V5E("1?<VQO='-097)(;W5R"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<VQO='-097)$87D["@H@
M("`@9G5N8W1I;VX@2W)O;F]L:71H7U=E96M6:65W*"1W965K(#T@;G5L;"P@
M)'EE87(@/2!N=6QL+"`D<W1A<G1$87D@/2!N=6QL+"`D96YD1&%Y(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@
M("`@("1Y96%R(#T@9&%T92@G62<I.PH@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)'=E96LI*2!["B`@("`@("`@("`@("1D871E(#T@)FYE=R!(;W)D
M95]$871E*&%R<F%Y*"=Y96%R)R`]/B`D>65A<BP@)VUO;G1H)R`]/B!D871E
M*"=N)RDL("=M9&%Y)R`]/B!D871E*"=J)RDI*3L*("`@("`@("`@("`@)'=E
M96L@/2`D9&%T92T^=V5E:T]F665A<B@I.PH@("`@("`@("`@("!I9B`H)'=E
M96L@/3T@,2`F)B!D871E*"=N)RD@/3T@,3(I('L*("`@("`@("`@("`@("`@
M("1Y96%R*RL["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=V5E:W-);EEE87(@/2!(;W)D95]$871E.CIW965K<TEN665A
M<B@D>65A<BD["B`@("`@("`@("`@(&EF("@D=V5E:R`\(#$I('L*("`@("`@
M("`@("`@("`@("1Y96%R+2T["B`@("`@("`@("`@("`@("`D=V5E:R`K/2`D
M=V5E:W-);EEE87(["B`@("`@("`@("`@('T@96QS96EF("@D=V5E:R`^("1W
M965K<TEN665A<BD@>PH@("`@("`@("`@("`@("`@)'=E96L@+3T@)'=E96MS
M26Y996%R.PH@("`@("`@("`@("`@("`@)'EE87(K*SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/GEE87(@/2`D>65A<CL*("`@
M("`@("`D=&AI<RT^=V5E:R`]("1W965K.PH*("`@("`@("!I9B`H:7-S970H
M)'-T87)T1&%Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^<W1A<G1$87D@/2`D
M<W1A<G1$87D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D96YD1&%Y
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^96YD1&%Y(#T@)&5N9$1A>3L*("`@
M("`@("!]"@H@("`@("`@("1F:7)S=$1A>2`]($AO<F1E7T1A=&4Z.F9I<G-T
M1&%Y3V97965K*"1W965K+"`D>65A<BD@*R!$871E7T-A;&,Z.F1A=&54;T1A
M>7,H,2P@,2P@)'EE87(I("T@,3L*"B`@("`@("`@<F5Q=6ER95]O;F-E($M2
M3TY/3$E42%]"05-%("X@)R]L:6(O1&%Y5FEE=RYP:'`G.PH@("`@("`@(&9O
M<B`H)&D@/2`D=&AI<RT^<W1A<G1$87D[("1I(#P]("1T:&ES+3YE;F1$87D[
M("1I*RLI('L*("`@("`@("`@("`@;&ES="@D9&%Y+"`D;6]N=&@L("1Y96%R
M*2`](&5X<&QO9&4H)R\G+"!$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&9I<G-T
M1&%Y("L@)&DL("<E9"\E;2\E62<I*3L*("`@("`@("`@("`@)'1H:7,M/F1A
M>7-;)&E=(#T@)FYE=R!+<F]N;VQI=&A?1&%Y5FEE=R@D;6]N=&@L("1D87DL
M("1Y96%R+"!N=6QL+"!A<G)A>2@I*3L*("`@("`@("!]"@H@("`@("`@(&QI
M<W0H)'-D87DL("1S;6]N=&@L("1S>65A<BD@/2!E>'!L;V1E*"<O)RP@1&%T
M95]#86QC.CID87ES5&]$871E*"1F:7)S=$1A>2`K("1T:&ES+3YS=&%R=$1A
M>2P@)R5D+R5M+R59)RDI.PH@("`@("`@(&QI<W0H)&5D87DL("1E;6]N=&@L
M("1E>65A<BD@/2!E>'!L;V1E*"<O)RP@1&%T95]#86QC.CID87ES5&]$871E
M*"1F:7)S=$1A>2`K("1T:&ES+3YE;F1$87DL("<E9"\E;2\E62<I*3L*("`@
M("`@("`D<W1A<G1$871E(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=Y96%R
M)R`]/B`D<WEE87(L("=M;VYT:"<@/3X@)'-M;VYT:"P@)VUD87DG(#T^("1S
M9&%Y*2D["B`@("`@("`@)&5N9$1A=&4@/2`F;F5W($AO<F1E7T1A=&4H87)R
M87DH)WEE87(G(#T^("1E>65A<BP@)VUO;G1H)R`]/B`D96UO;G1H+"`G;61A
M>2<@/3X@)&5D87DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VAO=7(G(#T^(#(S+"`G;6EN)R`]/B`U.2P@)W-E8R<@/3X@
M-3DI*3L*("`@("`@("`D96YD1&%T92T^8V]R<F5C="@I.PH@("`@("`@("1A
M;&QE=F5N=',@/2!+<F]N;VQI=&@Z.FQI<W1%=F5N=',H)'-T87)T1&%T92P@
M)&5N9$1A=&4L("1'3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R<R==*3L*("`@
M("`@("!F;W(@*"1I(#T@)'1H:7,M/G-T87)T1&%Y.R`D:2`\/2`D=&AI<RT^
M96YD1&%Y.R`D:2LK*2!["B`@("`@("`@("`@("1T:&ES+3YD87ES6R1I72T^
M<V5T179E;G1S*&ES<V5T*"1A;&QE=F5N='-;)'1H:7,M/F1A>7-;)&E=+3YG
M9713=&%M<"@I72D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D86QL979E;G1S6R1T:&ES+3YD87ES6R1I72T^9V5T4W1A;7`H
M*5T@.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@I*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]S:61E8GES:61E
M(#T@)'1H:7,M/F1A>7-;)'1H:7,M/G-T87)T1&%Y72T^7W-I9&5B>7-I9&4[
M"B`@("`@("`@)'1H:7,M/E]C=7)R96YT0V%L96YD87)S(#T@)'1H:7,M/F1A
M>7-;)'1H:7,M/G-T87)T1&%Y72T^7V-U<G)E;G1#86QE;F1A<G,["B`@("`@
M("`@)'1H:7,M/E]S;&]T<U!E<DAO=7(@/2`D=&AI<RT^9&%Y<ULD=&AI<RT^
M<W1A<G1$87E=+3Y?<VQO='-097)(;W5R.PH@("`@("`@("1T:&ES+3Y?<VQO
M='-097)$87D@/2`D=&AI<RT^9&%Y<ULD=&AI<RT^<W1A<G1$87E=+3Y?<VQO
M='-097)$87D["B`@("`@("`@)'1H:7,M/E]S;&]T3&5N9W1H(#T@)'1H:7,M
M/F1A>7-;)'1H:7,M/G-T87)T1&%Y72T^7W-L;W1,96YG=&@["B`@("!]"@H@
M("`@9G5N8W1I;VX@:'1M;"@D=&5M<&QA=&5?<&%T:"`]($M23TY/3$E42%]4
M14U03$%415,I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<RP@)'!R:6YT
M7W9I97<["@H@("`@("`@("1M;W)E7W1I;65S;&]T<R`]("1P<F5F<RT^9V5T
M5F%L=64H)W1I;65?8F5T=V5E;E]D87ES)RD["B`@("`@("`@)&EN8VQU9&5?
M86QL7V5V96YT<R`]("$D<')E9G,M/F=E=%9A;'5E*"=S:&]W7W-H87)E9%]S
M:61E7V)Y7W-I9&4G*3L*"B`@("`@("`@:68@*"$D=&AI<RT^<&%R<V5D*2![
M"B`@("`@("`@("`@("1T:&ES+3YP87)S92@I.PH@("`@("`@('T*"B`@("`@
M("`@)'-L;W1S(#T@)'1H:7,M/F1A>7-;)'1H:7,M/G-T87)T1&%Y72T^<VQO
M=',["B`@("`@("`@)&-I9"`](#`["B`@("`@("`@<F5Q=6ER92`D=&5M<&QA
M=&5?<&%T:"`N("<O=V5E:R]H96%D+FEN8R<["B`@("`@("`@:68@*"1T:&ES
M+3Y?<VED96)Y<VED92D@>PH@("`@("`@("`@("!R97%U:7)E("1T96UP;&%T
M95]P871H("X@)R]J879A<V-R:7!T+V]P96Y?8V%L96YD87)?<V5A<F-H+FIS
M)SL*("`@("`@("`@("`@<F5Q=6ER92`D=&5M<&QA=&5?<&%T:"`N("<O=V5E
M:R]H96%D7W-I9&5?8GE?<VED92YI;F,G.PH@("`@("`@('T*"B`@("`@("`@
M)&5V96YT7V-O=6YT(#T@,#L*("`@("`@("!F;W(@*"1J(#T@)'1H:7,M/G-T
M87)T1&%Y.R`D:B`\/2`D=&AI<RT^96YD1&%Y.R`D:BLK*2!["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?8W5R<F5N=$-A;&5N9&%R<R!A<R`D8VED
M(#T^("1C86PI('L*("`@("`@("`@("`@("`@("1E=F5N=%]C;W5N="`](&UA
M>"@D979E;G1?8V]U;G0L(&-O=6YT*"1T:&ES+3YD87ES6R1J72T^7V%L;%]D
M87E?979E;G1S6R1C:61=*2D["B`@("`@("`@("`@("`@("!R97-E="@D=&AI
M<RT^9&%Y<ULD:ETM/E]A;&Q?9&%Y7V5V96YT<ULD8VED72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D;6]R95]T:6UE<VQO=',I
M('L*("`@("`@("`@("`@)&%D9&5V96YT=7)L(#T@;G5L;#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D861D979E;G1U<FP@/2!?*")!;&P@9&%Y
M(BD["B`@("`@("`@?0H*("`@("`@("`D979E;G1#871E9V]R:65S(#T@87)R
M87DH*3L*"B`@("`@("`@)')O=R`]("<G.PH@("`@("`@(&9O<B`H)&H@/2`D
M=&AI<RT^<W1A<G1$87D[("1J(#P]("1T:&ES+3YE;F1$87D[("1J*RLI('L*
M("`@("`@("`@("`@)')O=R`N/2`G/'1D(&-L87-S/2)H;W5R(B!A;&EG;CTB
M<FEG:'0B/B<@+B`H)&UO<F5?=&EM97-L;W1S(#\@7R@B06QL(&1A>2(I(#H@
M)R9N8G-P.R<I("X@)SPO=&0^)SL*("`@("`@("`@("`@)')O=R`N/2`G/'1D
M(&-O;'-P86X](B<@+B`D=&AI<RT^9&%Y<ULD:ETM/E]T;W1A;'-P86X@+B`G
M(B!V86QI9VX](G1O<"(^/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN
M9STB,"(^)SL*("`@("`@("`@("`@:68@*"1T:&ES+3YD87ES6R1J72T^7V%L
M;%]D87E?;6%X<F]W<W!A;B`^(#`I('L*("`@("`@("`@("`@("`@(&9O<B`H
M)&L@/2`P.R`D:R`\("1T:&ES+3YD87ES6R1J72T^7V%L;%]D87E?;6%X<F]W
M<W!A;CL@)&LK*RD@>PH@("`@("`@("`@("`@("`@("`@("1R;W<@+CT@)SQT
M<CXG.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD87ES
M6R1J72T^7V-U<G)E;G1#86QE;F1A<G,@87,@)&-I9"`]/B`D8V%L*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^9&%Y<ULD
M:ETM/E]A;&Q?9&%Y7V5V96YT<ULD8VED72D@/3T]("1K*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<F]W("X]("<\=&0@<F]W<W!A;CTB)R`N
M("@D=&AI<RT^9&%Y<ULD:ETM/E]A;&Q?9&%Y7VUA>')O=W-P86X@+2`D:RD@
M+B`G(B!W:61T:#TB)RX@<F]U;F0H.3D@+R!C;W5N="@D=&AI<RT^9&%Y<ULD
M:ETM/E]C=7)R96YT0V%L96YD87)S*2D@+B`G)2(^)FYB<W`[/"]T9#XG.PH@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H8V]U;G0H)'1H:7,M
M/F1A>7-;)&I=+3Y?86QL7V1A>5]E=F5N='-;)&-I9%TI(#X@)&LI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E=F5N="`]("1T:&ES+3YD87ES
M6R1J72T^7V%L;%]D87E?979E;G1S6R1C:61=6R1K73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E=F5N=$-A=&5G;W)I97-;)&5V96YT+3YG971#
M871E9V]R>2@I72`]('1R=64["@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')O=R`N/2`G/'1D(&-L87-S/2)W965K+65V96YT8F]X(&-A=&5G;W)Y
M)R`N(&UD-2@D979E;G0M/F=E=$-A=&5G;W)Y*"DI("X@)R(@)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=I9'1H/2(G("X@<F]U;F0H
M.3D@+R!C;W5N="@D=&AI<RT^9&%Y<ULD:ETM/E]C=7)R96YT0V%L96YD87)S
M*2D@+B`G)2(@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W9A;&EG;CTB=&]P(CXG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D979E;G0M/F=E=$QI;FLH)'1H:7,M/F1A>7-;)&I=+3YG9713=&%M
M<"@I*2`N("<\+W1D/B<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)')O=R`N
M/2`G/"]T<CXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)')O=R`N/2`G/'1R/CQT9"!C;VQS<&%N
M/2(G("X@8V]U;G0H)'1H:7,M/E]C=7)R96YT0V%L96YD87)S*2`N("<B/B9N
M8G-P.SPO=&0^/"]T<CXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R
M;W<@+CT@)SPO=&%B;&4^/"]T9#XG.PH@("`@("`@('T*"B`@("`@("`@)')O
M=W-P86X@/2`G)SL*("`@("`@("`D9FER<W1?<F]W(#T@=')U93L*("`@("`@
M("!R97%U:7)E("1T96UP;&%T95]P871H("X@)R]D87DO86QL7V1A>2YI;F,G
M.PH*("`@("`@("`D='=E;G1Y7V9O=7(@/2`D<')E9G,M/F=E=%9A;'5E*"=T
M=V5N='E&;W5R)RD["B`@("`@("`@)&1A>5]H;W5R7W-T87)T(#T@)'!R969S
M+3YG971686QU92@G9&%Y7VAO=7)?<W1A<G0G*2`O(#(@*B`D=&AI<RT^7W-L
M;W1S4&5R2&]U<CL*("`@("`@("`D9&%Y7VAO=7)?96YD(#T@)'!R969S+3YG
M971686QU92@G9&%Y7VAO=7)?96YD)RD@+R`R("H@)'1H:7,M/E]S;&]T<U!E
M<DAO=7(["B`@("`@("`@)')O=W,@/2!A<G)A>2@I.PH*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D=&AI<RT^7W-L;W1S4&5R1&%Y.R`D:2LK*2!["B`@
M("`@("`@("`@(&EF("@D:2`^/2`D9&%Y7VAO=7)?96YD("8F("1I(#X@)'1H
M:7,M/FQA<W0I('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D:2`\("1T:&ES+3YF:7)S="`F)B`D:2`\
M("1D87E?:&]U<E]S=&%R="D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@H)&T@/2`D:2`E("1T
M:&ES+3Y?<VQO='-097)(;W5R*2`A/2`P*2!["B`@("`@("`@("`@("`@("`D
M=&EM92`]("<Z)R`N("1M("H@)'1H:7,M/E]S;&]T3&5N9W1H.PH@("`@("`@
M("`@("`@("`@)&AO=7)C;&%S<R`]("=H86QF:&]U<B<["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&EM92`](&1A=&4H)'1W96YT
M>5]F;W5R(#\@)T<G(#H@)V=A)RP@)'-L;W1S6R1I75LG=&EM97-T86UP)UTI
M.PH@("`@("`@("`@("`@("`@)&AO=7)C;&%S<R`]("=H;W5R)SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)')O=R`]("<G.PH@("`@("`@("`@("!F
M;W(@*"1J(#T@)'1H:7,M/G-T87)T1&%Y.R`D:B`\/2`D=&AI<RT^96YD1&%Y
M.R`D:BLK*2!["B`@("`@("`@("`@("`@("`O+R!!9&0@<W!A8V5R(&)E='=E
M96X@9&%Y<RP@;W(@=&EM97-L;W1S+@H@("`@("`@("`@("`@("`@:68@*"1M
M;W)E7W1I;65S;&]T<RD@>PH@("`@("`@("`@("`@("`@("`@("1R;W<@+CT@
M)SQT9"!A;&EG;CTB<FEG:'0B(&-L87-S/2(G("X@)&AO=7)C;&%S<R`N("<B
M/B<@+B`D=&EM92`N("<\+W1D/B<["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1R;W<@+CT@)SQT9"!W:61T:#TB,24B
M/B9N8G-P.SPO=&0^)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?8W5R<F5N=$-A;&5N9&%R<RDI('L*
M("`@("`@("`@("`@("`@("`@("`D<F]W("X]("<\=&0^)FYB<W`[/"]T9#XG
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]C=7)R96YT0V%L96YD87)S(&%S("1C:60@/3X@)&-A;"D@>PH@
M("`@("`@("`@("`@("`@("`@("1H<W!A;B`](#`["B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/F1A>7-;)&I=+3Y?979E;G1?;6%T<FEX
M6R1C:61=6R1I72!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1E=F5N="`]("8D=&AI<RT^9&%Y<ULD:ETM/E]E=F5N='-;)&ME>5T["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D:6YC;'5D95]A;&Q?979E;G1S
M('Q\("1E=F5N="T^9V5T0V%L96YD87(H*2`]/2`D8VED*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!3:6YC92!W92=V92!M861E('-U<F4@
M=&AA="!T:&ES(&5V96YT)W,*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(&]V97)L87`@:7,@82!F86-T;W(@;V8@=&AE('1O=&%L('-P86XL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!W92!G970@=&AI<R!E=F5N
M="=S(&EN9&EV:61U86P@<W!A;B!B>0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@9&EV:61I;F<@=&AE('1O=&%L('-P86X@8GD@=&AI<R!E=F5N
M="=S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!O=F5R;&%P+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-P86X@/2`D=&AI<RT^9&%Y
M<ULD:ETM/E]S<&%N6R1C:61=("\@)&5V96YT+3YO=F5R;&%P.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&AS<&%N("L]("1S<&%N.PH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S=&%R="`](&UK=&EM92AF;&]O<B@D
M:2`O("1T:&ES+3Y?<VQO='-097)(;W5R*2P@*"1I("4@)'1H:7,M/E]S;&]T
M<U!E<DAO=7(I("H@)'1H:7,M/E]S;&]T3&5N9W1H+"`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD87ES
M6R1J72T^;6]N=&@L("1T:&ES+3YD87ES6R1J72T^;61A>2P@)'1H:7,M/F1A
M>7-;)&I=+3YY96%R*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D979E;G0M/G-T87)T+3YT:6UE<W1A;7`H*2`^/2`D<W1A<G0@)B8@)&5V
M96YT+3YS=&%R="T^=&EM97-T86UP*"D@/"`D<W1A<G0@*R`V,"`J("1T:&ES
M+3Y?<VQO=$QE;F=T:"!\?"`D<W1A<G0@/3T@)'1H:7,M/F1A>7-;)&I=+3YG
M9713=&%M<"@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5V96YT0V%T96=O<FEE<ULD979E;G0M/F=E=$-A=&5G;W)Y*"E=(#T@=')U
M93L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O=R`N/2`G
M/'1D(&-L87-S/2)W965K+65V96YT8F]X(&-A=&5G;W)Y)R`N(&UD-2@D979E
M;G0M/F=E=$-A=&5G;W)Y*"DI("X@)R(@)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=V86QI9VX](G1O<"(@)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB)R`N(&9L;V]R
M*"@H.3`@+R!C;W5N="@D=&AI<RT^9&%Y<RDI("\@8V]U;G0H)'1H:7,M/E]C
M=7)R96YT0V%L96YD87)S*2D@*B`H)'-P86X@+R`D=&AI<RT^9&%Y<ULD:ETM
M/E]S<&%N6R1C:61=*2D@+B`G)2(@)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=C;VQS<&%N/2(G("X@)'-P86X@+B`G(B!R;W=S
M<&%N/2(G("X@)&5V96YT+3YR;W=S<&%N("X@)R(^)R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E=F5N="T^9V5T3&EN:R@D=&AI
M<RT^9&%Y<ULD:ETM/F=E=%-T86UP*"DI("X@)SPO=&0^)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@
M)&1I9F8@/2`D=&AI<RT^9&%Y<ULD:ETM/E]S<&%N6R1C:61=("T@)&AS<&%N
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@D9&EF9B`^(#`I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)')O=R`N/2!S=')?<F5P96%T*"<\=&0^)FYB
M<W`[/"]T9#XG+"`D9&EF9BD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F]W
M<UM=(#T@87)R87DH)W)O=R<@/3X@)')O=RP@)W-L;W0G(#T^("<\<W!A;B!C
M;&%S<STB)R`N("1H;W5R8VQA<W,@+B`G(CXG("X@)'1I;64@+B`G/"]S<&%N
M/B<I.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]4
M96UP;&%T92YP:'`G.PH@("`@("`@("1T96UP;&%T92`]("9N97<@2&]R9&5?
M5&5M<&QA=&4H*3L*("`@("`@("`D=&5M<&QA=&4M/G-E="@G<F]W7VAE:6=H
M="<L(')O=6YD*#(P("\@)'1H:7,M/E]S;&]T<U!E<DAO=7(I*3L*("`@("`@
M("`D=&5M<&QA=&4M/G-E="@G<F]W<R<L("1R;W=S*3L*("`@("`@("`D=&5M
M<&QA=&4M/G-E="@G<VAO=U]S;&]T<R<L("$D;6]R95]T:6UE<VQO=',L('1R
M=64I.PH@("`@("`@(&5C:&\@)'1E;7!L871E+3YF971C:"@D=&5M<&QA=&5?
M<&%T:"`N("<O9&%Y+W)O=W,N:'1M;"<I.PH*("`@("`@("!R97%U:7)E("1T
M96UP;&%T95]P871H("X@)R]C871E9V]R>5]L96=E;F0N:6YC)SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%!A<G-E(&%L;"!E=F5N=',@9F]R(&%L;"!O9B!T
M:&4@9&%Y<R!T:&%T('=E)W)E(&AA;F1L:6YG.R!T:&5N"B`@("`@*B!R=6X@
M=&AR;W5G:"!T:&4@<F5S=6QT<R!T;R!G970@=&AE('1O=&%L(&AO<FEZ;VYT
M86P@<W!A;B!F;W(*("`@("`J('1H92!W965K+"!A;F0@=&AE(&QA=&5S="!E
M=F5N="!O9B!T:&4@=V5E:RX*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V4H
M*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`D=&AI<RT^<W1A<G1$87D[("1I
M(#P]("1T:&ES+3YE;F1$87D[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M
M/F1A>7-;)&E=+3YP87)S92@I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/G1O=&%L<W!A;B`](#`["B`@("`@("`@)'1H:7,M/G-P86X@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<B`H)&D@/2`D=&AI<RT^<W1A<G1$87D[("1I(#P]("1T
M:&ES+3YE;F1$87D[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M/G1O=&%L
M<W!A;B`K/2`D=&AI<RT^9&%Y<ULD:5TM/E]T;W1A;'-P86X["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?8W5R<F5N=$-A;&5N9&%R<R!A<R`D8VED
M(#T^("1K97DI('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M<W!A;ELD8VED72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<W!A
M;ELD8VED72`K/2`D=&AI<RT^9&%Y<ULD:5TM/E]S<&%N6R1C:61=.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<W!A;ELD8VED72`]("1T:&ES+3YD87ES6R1I72T^7W-P86Y;)&-I9%T[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YL87-T(#T@,#L*("`@("`@("`D=&AI<RT^9FER<W0@
M/2`D=&AI<RT^7W-L;W1S4&5R1&%Y.PH@("`@("`@(&9O<B`H)&D@/2`D=&AI
M<RT^<W1A<G1$87D[("1I(#P]("1T:&ES+3YE;F1$87D[("1I*RLI('L*("`@
M("`@("`@("`@:68@*"1T:&ES+3YD87ES6R1I72T^;&%S="`^("1T:&ES+3YL
M87-T*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;&%S="`]("1T:&ES+3YD
M87ES6R1I72T^;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)'1H:7,M/F1A>7-;)&E=+3YF:7)S="`\("1T:&ES+3YF:7)S="D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F9I<G-T(#T@)'1H:7,M/F1A>7-;)&E=+3YF
M:7)S=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!L:6YK*"1O9F9S970@/2`P*0H@("`@>PH@("`@("`@("1S8W)I<'1.
M86UE(#T@8F%S96YA;64H)%]315)615);)U!(4%]314Q&)UTI.PH@("`@("`@
M("1W965K(#T@)'1H:7,M/G=E96L@*R`D;V9F<V5T.PH@("`@("`@("1Y96%R
M(#T@)'1H:7,M/GEE87(["B`@("`@("`@)'=E96MS26Y996%R(#T@2&]R9&5?
M1&%T93HZ=V5E:W-);EEE87(H)'EE87(I.PH@("`@("`@(&EF("@D=V5E:R`\
M(#$I('L*("`@("`@("`@("`@)'EE87(M+3L*("`@("`@("`@("`@)'=E96L@
M*ST@)'=E96MS26Y996%R.PH@("`@("`@('T@96QS96EF("@D=V5E:R`^("1W
M965K<TEN665A<BD@>PH@("`@("`@("`@("`D=V5E:R`M/2`D=V5E:W-);EEE
M87(["B`@("`@("`@("`@("1Y96%R*RL["B`@("`@("`@?0H@("`@("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'-C<FEP=$YA;64L("=W965K)RP@
M)'=E96LI.PH@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R
M;"P@)WEE87(G+"`D>65A<BD["B`@("`@("`@<F5T=7)N($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@D=7)L*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]L:6(O=F5R
M<VEO;BYP:'``````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M-C$`,3`T,3<S-C(W-3,`,#(Q,S<S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP(&1E9FEN92@G2U)/3D],251(7U9%
M4E-)3TXG+"`G2#,@*#(N,2DG*2`_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S+P``````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S4S`#`R,#0S,P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T
M96UP;&%T97,O9&%Y+P``````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(Q,C$P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]D87DO<F]W7VAA;&8N:6YC````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,S-P`Q,#0Q-S,V,C<U,P`P,C,U,#0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(#QT
M<B!C;&%S<STB/#]P:'`@96-H;R`D<W1Y;&4@/SXB/@H\/W!H<"!I9B`H)&9I
M<G-T7W)O=RDZ(#\^"B`@/'1D('=I9'1H/2(Q)2(^)FYB<W`[/"]T9#X*/#]P
M:'`@96YD:68[(#\^"B`@/'1D('=I9'1H/2(Q)2(@<W1Y;&4](G=I9'1H.C5P
M>#L@:&5I9VAT.C$P<'@B/B9N8G-P.SPO=&0^"B`@/'1D('=I9'1H/2(Q)2(^
M)FYB<W`[/"]T9#X*("`\/W!H<"!E8VAO("1R;W<@/SX*(#PO='(^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]T96UP;&%T97,O9&%Y+V%L;%]D87DN:6YC````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`U-C(`,3`T,3<S-C(W-3,`,#(S,S$P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"`\='(^"CP_<&AP(&EF
M("@D9FER<W1?<F]W*3H@/SX*("`\=&0@=VED=&@](C$E(B!C;&%S<STB;F]W
M<F%P(B!A;&EG;CTB<FEG:'0B/#]P:'`@96-H;R`D<F]W<W!A;B`_/CX\<W1R
M;VYG/CP_<&AP(&5C:&\@)&%D9&5V96YT=7)L(#\^/"]S=')O;F<^/"]T9#X*
M("`\=&0@=VED=&@](C$E(CP_<&AP(&5C:&\@)')O=W-P86X@/SX@<W1Y;&4]
M(G=I9'1H.C5P>#L@:&5I9VAT.CP_<&AP(&5C:&\@<F]U;F0H,C`@+R`D=&AI
M<RT^7W-L;W1S4&5R2&]U<BD@/SYP>"(^)FYB<W`[/"]T9#X*("`\=&0@=VED
M=&@](C$E(CP_<&AP(&5C:&\@)')O=W-P86X@/SX^)FYB<W`[/"]T9#X*/#]P
M:'`@96YD:68[(#\^"B`@/#]P:'`@96-H;R`D<F]W(#\^"B`\+W1R/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&5M<&QA
M=&5S+V1A>2]R;W<N:6YC````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,#,P`#$P-#$W,S8R-S4S`#`R,C4P,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````@/'1R(&-L87-S/2(\/W!H<"!E8VAO("1S
M='EL92`_/B(^"B`@/'1D('=I9'1H/2(Q)2(@8VQA<W,](FYO=W)A<"(\/W!H
M<"!I9B`H)')O=W-P86XI(&5C:&\@)R!R;W=S<&%N/2(R(B`G(#\^(&%L:6=N
M/2)R:6=H="(^"B`@(#P_<&AP"FEF("AE;7!T>2@D;6]R95]T:6UE<VQO=',I
M*2!["B`@("!I9B`H:7-S970H)&%D9&5V96YT=7)L*2D@>PH@("`@("`@(&5C
M:&\@)&%D9&5V96YT=7)L("X@)'1I;64@+B!(;W)D93HZ:6UG*"=N97=?<VUA
M;&PN<&YG)RP@)RLG+"!A<G)A>2@G=&ET;&4G(#T^(%\H(D-R96%T92!A($YE
M=R!%=F5N="(I*2D@+B`G/"]A/B<["B`@("!](&5L<V4@>PH@("`@("`@(&5C
M:&\@)SQS<&%N(&-L87-S/2(G("X@)&AO=7)C;&%S<R`N("<B/B<@+B`D=&EM
M92`N("<\+W-P86X^)SL*("`@('T*?0H_/@H@(#PO=&0^"B`@/'1D('=I9'1H
M/2(Q)2(@<W1Y;&4](G=I9'1H.C5P>#L@:&5I9VAT.C$P<'@B/B9N8G-P.SPO
M=&0^"B`@/'1D('=I9'1H/2(Q)2(^)FYB<W`[/"]T9#X*("`\/W!H<"!E8VAO
M("1R;W<@/SX*(#PO='(^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O
M=&5M<&QA=&5S+V1A>2]R;W=S+FAT;6P`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P-#,W`#$P-#$W,S8R-S4S`#`R,S`W,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\;&]O<#IR;W=S/@H@/'1R/@H@
M(#QT9"!W:61T:#TB,24B(&-L87-S/2)N;W=R87`B(&%L:6=N/2)R:6=H="(^
M"B`@(#QI9CIS:&]W7W-L;W1S/@H@("`@/'1A9SIR;W=S+G-L;W0@+SX*("`@
M/"]I9CIS:&]W7W-L;W1S/@H@(#PO=&0^"B`@/'1D('=I9'1H/2(Q)2(@<W1Y
M;&4](G=I9'1H.C5P>#L@:&5I9VAT.CQT86<Z<F]W7VAE:6=H="`O/G!X(CXF
M;F)S<#L\+W1D/@H@(#QT9"!W:61T:#TB,24B/B9N8G-P.SPO=&0^"B`@/'1A
M9SIR;W=S+G)O=R`O/@H@/"]T<CX*/"]L;V]P.G)O=W,^"CPO=&%B;&4^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]D
M87DO:&5A9%]S:61E7V)Y7W-I9&4N:6YC````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38R-0`Q
M,#0Q-S,V,C<U,P`P,C4S,#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(#QT<CX*("`\=&@@8VQA<W,](F-O;G1R;VPB('=I
M9'1H/2(Q,"4B(&-O;'-P86X](C,B(&%L:6=N/2)L969T(CX*("`@(#P_<&AP
M(&EF("@A)'!R:6YT7W9I97<I(&5C:&\@2&]R9&4Z.FQI;FLH)R,G+"!?*")3
M:&]W($-A;&5N9&%R(BDL("<G+"`G)RP@)V]P96Y?8V%L96YD87)?<V5A<F-H
M*"D[)RD@+B!(;W)D93HZ:6UG*"=N97=?8FEG+G!N9R<L(%\H(E-H;W<@0V%L
M96YD87(B*2D@+B`G/"]A/B<@/SX*("`\+W1H/@H\/W!H<"!I9B`H(6-O=6YT
M*"1T:&ES+3Y?8W5R<F5N=$-A;&5N9&%R<RDI.B`_/@H@(#QT:"!C;&%S<STB
M8V]N=')O;"(@=VED=&@](CDP)2(^)FYB<W`[/"]T:#X*/#]P:'`@96YD:68[
M(#\^"CP_<&AP("1I(#T@,#L@9F]R96%C:"`H)'1H:7,M/E]C=7)R96YT0V%L
M96YD87)S(&%S("1C:60@/3X@)&-A;"DZ(#\^"B`@/'1H(&-L87-S/2)C;VYT
M<F]L(B!W:61T:#TB/#]P:'`@96-H;R!R;W5N9"@Y,"`O(&-O=6YT*"1T:&ES
M+3Y?8W5R<F5N=$-A;&5N9&%R<RDI(#\^)2(@8V]L<W!A;CTB/#]P:'`@96-H
M;R`D=&AI<RT^7W-P86Y;)&-I9%T@/SXB/@H@("`\<W1R;VYG/CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D8V%L+3YG970H)VYA;64G*2D[(&EF("@A
M)'!R:6YT7W9I97<I(&5C:&\@)R`G("X@2&]R9&4Z.FQI;FLH571I;#HZ861D
M4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*"DL("=D:7-P;&%Y7V-A;"<L("1C
M86PM/F=E=%-H;W)T3F%M92@I*2P@<W!R:6YT9BA?*")(:61E("5S(BDL("1C
M86PM/F=E="@G;F%M92<I*2D@+B!(;W)D93HZ:6UG*"=D96QE=&4M<VUA;&PN
M<&YG)RP@7R@B2&ED92(I+"`G)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)R`_/CPO<W1R;VYG/@H@(#PO
M=&@^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`\+W1R/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L
M871E<R]D87DO:&5A9"YI;F,`````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#<U-0`Q,#0Q-S,V,C<U,P`P,C(V,3``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&1I=B!C;&%S<STB:&5A9&5R(B!S='EL
M93TB=&5X="UA;&EG;CIC96YT97(B/@H\/W!H<`II9B`H(21P<FEN=%]V:65W
M*2!E8VAO($AO<F1E.CIL:6YK*"1T:&ES+3YL:6YK*"TQ*2P@7R@B4')E=FEO
M=7,@9&%Y(BDI("X@2&]R9&4Z.FEM9R@G;F%V+VQE9G0N<&YG)RP@)SPG+"`G
M)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`N("<\+V$^)SL*96-H;R`D=&AI<RT^9V5T5&EM92@D<')E9G,M/F=E=%9A
M;'5E*"=D871E7V9O<FUA="<I*3L*:68@*"$D<')I;G1?=FEE=RD@96-H;R!(
M;W)D93HZ;&EN:R@D=&AI<RT^;&EN:R@Q*2P@7R@B3F5X="!D87DB*2D@+B!(
M;W)D93HZ:6UG*"=N878O<FEG:'0N<&YG)RP@)SXG+"`G)RP@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)SL*
M/SX*/"]D:78^"@H\=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E
M(B!C;&%S<STB<W1R:7!E9"(^"@`````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O<V5A<F-H
M+P``````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-3,`,#(Q-S`P`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+W1E;7!L871E<R]S96%R8V@O979E;G1?9F]O=&5R<RYI;F,`````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`Q,0`Q,#0Q-S,V,C<U,P`P,C4R-#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/"]T86)L93X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O
M<V5A<F-H+W-E87)C:%]A9'9A;F-E9"YI;F,`````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<R,34`
M,3`T,3<S-C(W-3,`,#(U-#8W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB979E
M;G0B(&%C=&EO;CTB<V5A<F-H+G!H<"(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP
M=70H*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@
M=F%L=64](G-E87)C:%]C86QE;F1A<B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB<V5A<F-H7VUO9&4B('9A;'5E/2)A9'9A;F-E9"(@+SX*/'1A
M8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`\='(^"B`@/'1D
M(&%L:6=N/2)L969T(B!C;&%S<STB:&5A9&5R(CX*("`@("`@/'-T<F]N9SX\
M/W!H<"!E8VAO(%\H(D%D=F%N8V5D(%-E87)C:"(I(#\^/"]S=')O;F<^"B`@
M/"]T9#X*("`\=&0@86QI9VX](G)I9VAT(B!C;&%S<STB:&5A9&5R(CX*("`@
M(#P_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="A5=&EL.CIA9&1087)A;65T97(H
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S96%R8V@N<&AP)RDL("=S96%R8VA?
M;6]D92<L("=B87-I8R<I+"!?*")"87-I8R!396%R8V@B*2P@)W-M86QL:&5A
M9&5R)RP@)R<L("<G+"!?*")?0F%S:6,@4V5A<F-H(BDI(#\^"B`@/"]T9#X*
M(#PO='(^"CPO=&%B;&4^"@H\8G(@+SX*"CQT86)L92!C96QL<W!A8VEN9STB
M,"(@8VQA<W,](G-T<FEP960B/@H*/"$M+2!G96YE<F%L(&AE861E<B`M+3X*
M/'1R/@H@/'1D(&%L:6=N/2)L969T(B!C;VQS<&%N/2(U(B!C;&%S<STB:&5A
M9&5R(CX*("`\<W!A;B!C;&%S<STB<VUA;&QH96%D97(B/CQS=')O;F<^/#]P
M:'`@96-H;R!?*")'96YE<F%L(BD@/SX\+W-T<F]N9SX\+W-P86X^"B`\+W1D
M/@H\+W1R/@H*/#\*)&-A;&5N9&%R<R`]($MR;VYO;&ET:#HZ;&ES=$-A;&5N
M9&%R<RAF86QS92P@4$5235-?141)5"D["B1I<W-E87)C:"`]('1R=64["G)E
M<75I<F4@2U)/3D],251(7U1%35!,051%4R`N("<O961I="]J879A<V-R:7!T
M+FEN8R<["C\^"CPA+2T@=&ET;&4@+2T^"CQT<CX*(#QT9"!A;&EG;CTB<FEG
M:'0B(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO($AO<F1E.CIL
M86)E;"@G=&ET;&4G+"!?*")4:71?;&4B*2D@/SXF;F)S<#LF;F)S<#L\+W-T
M<F]N9SX\+W1D/@H@/'1D(&%L:6=N/2)L969T(B!C;VQS<&%N/2(T(CX*("`\
M:6YP=70@='EP93TB=&5X="(@;F%M93TB=&ET;&4B(&ED/2)T:71L92(@=F%L
M=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D979E;G0M/G1I=&QE
M*2`_/B(@<VEZ93TB-#`B(&UA>&QE;F=T:#TB,C4U(B`O/@H@/"]T9#X*/"]T
M<CX*"CPA+2T@8V%L96YD87(@+2T^"CQT<CX*(#QT9"!A;&EG;CTB<FEG:'0B
M(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO($AO<F1E.CIL86)E
M;"@G=&%R9V5T8V%L96YD87(G+"!?*")#7V%L96YD87(B*2D@/SXF;F)S<#LF
M;F)S<#L\+W-T<F]N9SX\+W1D/@H@/'1D(&%L:6=N/2)L969T(B!C;VQS<&%N
M/2(T(CX*("`@(#QS96QE8W0@:60](F-A;&5N9&%R(B!N86UE/2)C86QE;F1A
M<B(^"B`@("`\/W!H<`H@("`@)&5#86QE;F1A<B`]("1E=F5N="T^9V5T0V%L
M96YD87(H*3L*("`@(&5C:&\@)SQO<'1I;VX@=F%L=64](E]?86YY(B<@+@H@
M("`@("`@("`H(21E0V%L96YD87(@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G
M(#H@)R<I("X@)SXG("X@7R@B06YY(BD@+@H@("`@("`@("`G/"]O<'1I;VX^
M)SL*("`@(&9O<F5A8V@@*"1C86QE;F1A<G,@87,@)&ED(#T^("1C86PI('L*
M("`@("`@("`D<V5L(#T@*"1I9"`]/2`D94-A;&5N9&%R*2`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)SL*("`@("`@("!P<FEN=&8H)SQO<'1I;VX@
M=F%L=64](B5S(B5S/B5S/"]O<'1I;VX^)RP*("`@("`@("`@("`@("`@:'1M
M;'-P96-I86QC:&%R<R@D:60I+"`D<V5L+"!H=&UL<W!E8VEA;&-H87)S*"1C
M86PM/F=E="@G;F%M92<I*2D@+B`B7&XB.PH@("`@?2`_/@H@("`@/"]S96QE
M8W0^"@H@/"]T9#X*/"]T<CX*"CPA+2T@8V%T96=O<GD@+2T^"CQT<CX*(#QT
M9"!A;&EG;CTB<FEG:'0B(&-L87-S/2)L:6=H="(^"B`@("`\<W1R;VYG/CP_
M<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=C871E9V]R>2<L(%\H(D-A=&5G;W)?
M>2(I*2`_/B9N8G-P.R9N8G-P.SPO<W1R;VYG/@H@/"]T9#X*(#QT9"!A;&EG
M;CTB;&5F="(@8V]L<W!A;CTB-"(^"B`@(#QS96QE8W0@:60](F-A=&5G;W)Y
M(B!N86UE/2)C871E9V]R>2(^"B`@(#P_<&AP"B`@("!E8VAO("<\;W!T:6]N
M('9A;'5E/2)?7V%N>2(G.PH@("`@96-H;R`H(6ES<V5T*"1E=F5N="T^8V%T
M96=O<GDI*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)SL*("`@(&5C
M:&\@)SXG("X@7R@B06YY(BD@+B`G/"]O<'1I;VX^)SL*("`@("1C871E9V]R
M:65S(#T@)&--86YA9V5R+3YG970H*3L*"B`@("!F;W)E86-H("@D8V%T96=O
M<FEE<R!A<R`D;F%M92D@>PH@("`@("`@(&5C:&\@)SQO<'1I;VX@=F%L=64]
M(B<@+B!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2`N("<B)R`N"B`@("`@("`@
M("`@("@H)&5V96YT+3YC871E9V]R>2`]/2`D;F%M92D@/R`G('-E;&5C=&5D
M/2)S96QE8W1E9"(^)R`Z("<^)RD@+@H@("`@("`@("`@("!H=&UL<W!E8VEA
M;&-H87)S*"1N86UE*2`N("<\+V]P=&EO;CXG.PH@("`@('T*("`@(#\^"B`@
M("`\+W-E;&5C=#X*(#PO=&0^"CPO='(^"@H\(2TM(&QO8V%T:6]N("TM/@H\
M='(^"B`\=&0@86QI9VX](G)I9VAT(B!C;&%S<STB;&EG:'0B/CQS=')O;F<^
M/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)VQO8V%T:6]N)RP@7R@B3&]?8V%T
M:6]N(BDI(#\^)FYB<W`[)FYB<W`[/"]S=')O;F<^/"]T9#X*(#QT9"!A;&EG
M;CTB;&5F="(@8V]L<W!A;CTB-"(^"B`@/&EN<'5T('1Y<&4](G1E>'0B(&YA
M;64](FQO8V%T:6]N(B!I9#TB;&]C871I;VXB('9A;'5E/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&5V96YT+3YL;V-A=&EO;BD@/SXB('-I>F4]
M(C0P(B!M87AL96YG=&@](C(U-2(@+SX*(#PO=&0^"CPO='(^"@H\(2TM('-T
M871U<R`M+3X*/'1R/@H@/'1D(&%L:6=N/2)R:6=H="(@8VQA<W,](FQI9VAT
M(CX*("`@(#QS=')O;F<^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)W-T871U
M<R<L(%\H(E-T871?=7,B*2D@/SXF;F)S<#LF;F)S<#L\+W-T<F]N9SX*(#PO
M=&0^"B`\=&0@86QI9VX](FQE9G0B(&-O;'-P86X](C0B/@H@(#P_<&AP(&5C
M:&\@2W)O;F]L:71H.CIB=6EL9%-T871U<U=I9&=E="@G<W1A='5S)RP@)&5V
M96YT+3YS=&%T=7,L('1R=64I(#\^"B`\+W1D/@H\+W1R/@H*/"$M+2!D97-C
M<FEP=&EO;B`M+3X*/'1R/@H@/'1D(&%L:6=N/2)R:6=H="(@8VQA<W,](FQI
M9VAT(CX\<W1R;VYG/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=D97-C<FEP
M=&EO;B<L(%\H(D1E<V-R:5]P=&EO;B(I*2`_/B9N8G-P.R9N8G-P.SPO<W1R
M;VYG/CPO=&0^"B`\=&0@86QI9VX](FQE9G0B(&-O;'-P86X](C0B/@H@(#QI
M;G!U="!T>7!E/2)T97AT(B!N86UE/2)D97-C<FEP=&EO;B(@:60](F1E<V-R
M:7!T:6]N(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1E
M=F5N="T^9&5S8W)I<'1I;VXI(#\^(B!S:7IE/2(T,"(@;6%X;&5N9W1H/2(R
M-34B("\^"B`\+W1D/@H\+W1R/@H*/#]P:'`@<F5Q=6ER92!+4D].3TQ)5$A?
M5$5-4$Q!5$53("X@)R]E9&ET+V5D:71?=&EM97-P86XN:6YC)SL@/SX*"CPO
M=&%B;&4^"@H\8G(@+SX*/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U
M='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4V5A<F-H(BD@/SXB("\^"CPO
M9F]R;3X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR
M;VYO;&ET:"]T96UP;&%T97,O<V5A<F-H+V5V96YT7W-U;6UA<FEE<RYI;F,`
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$S-30`,3`T,3<S-C(W-3,`,#(U-C`Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#QT<B!C;&%S<STB
M=&5X="(^"B`\=&0@;F]W<F%P/2)N;W=R87`B(&-L87-S/2)C871E9V]R>3P_
M<&AP(&5C:&\@;60U*"1F;W5N9"T^9V5T0V%T96=O<GDH*2D@/SXB/@H@(#P_
M<&AP(&5C:&\@)&9O=6YD+3YG971,:6YK*"D@/SX*(#PO=&0^"B`\=&0@8VQA
M<W,](FYO=W)A<"(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1F;W5N
M9"T^9V5T0V%T96=O<GDH*2D@/SX\+W1D/@H@/'1D(&-L87-S/2)N;W=R87`B
M/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9F]U;F0M/F=E=$QO8V%T
M:6]N*"DI(#\^/"]T9#X*(#QT9"!C;&%S<STB;F]W<F%P(CX\/W!H<"!E8VAO
M($MR;VYO;&ET:#HZ<W1A='5S5&]3=')I;F<H)&9O=6YD+3YG9713=&%T=7,H
M*2D@/SX\+W1D/@H@/'1D(&-L87-S/2)N;W=R87`B/CP_<&AP(&5C:&\@<W1R
M9G1I;64H)'!R969S+3YG971686QU92@G9&%T95]F;W)M870G*2P@)'-T87)T
M+3YT:6UE<W1A;7`H*2D@+B!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT
M>49O=7(G*2`_("<@1SII)R`Z("<@9SII(&$G+"`D<W1A<G0M/G1I;65S=&%M
M<"@I*2`_/CPO=&0^"B`\=&0@8VQA<W,](FYO=W)A<"(^/#]P:'`@96-H;R!S
M=')F=&EM92@D<')E9G,M/F=E=%9A;'5E*"=D871E7V9O<FUA="<I+"`D96YD
M+3YT:6UE<W1A;7`H*2D@+B!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT
M>49O=7(G*2`_("<@1SII)R`Z("<@9SII(&$G+"`D96YD+3YT:6UE<W1A;7`H
M*2D@/SX\+W1D/@H\+W1R/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O<V5A<F-H+V5M<'1Y+FEN8P``````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`R,#``,3`T,3<S-C(W-3,`,#(S-3$V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QB<B!C
M;&%S<STB<W!A8V5R(B`O/@H\9&EV(&-L87-S/2)T97AT(CX*(#QE;3X\/W!H
M<"!E8VAO(%\H(E1H97)E(&%R92!N;R!E=F5N=',@;6%T8VAI;F<@=&AE(&-U
M<G)E;G0@8W)I=&5R:6$N(BD@/SX\+V5M/@H\+V1I=CX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI
M=&@O=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:6YC````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`T-#8R`#$P-#$W,S8R-S4S`#`R,S8T,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\9F]R;2!M971H;V0](G!O
M<W0B(&YA;64](F5V96YT(B!A8W1I;VX](G-E87)C:"YP:'`B/@H\/W!H<"!5
M=&EL.CIP9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB86-T:6]N240B('9A;'5E/2)S96%R8VA?8V%L96YD87(B("\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](G-E87)C:%]M;V1E(B!V86QU93TB8F%S
M:6,B("\^"CQT86)L92!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B/@H@
M/'1R/@H@(#QT9"!A;&EG;CTB;&5F="(@8VQA<W,](FAE861E<B(^"B`@("`@
M(#P_<&AP(&5C:&\@7R@B0F%S:6,@4V5A<F-H(BD@/SX*("`\+W1D/@H@(#QT
M9"!A;&EG;CTB<FEG:'0B(&-L87-S/2)H96%D97(B/@H@("`@/#]P:'`@96-H
M;R!(;W)D93HZ=VED9V5T*%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ87!P
M;&EC871I;VY5<FPH)W-E87)C:"YP:'`G*2P@)W-E87)C:%]M;V1E)RP@)V%D
M=F%N8V5D)RDL(%\H(D%D=F%N8V5D(%-E87)C:"(I+"`G<VUA;&QH96%D97(G
M+"`G)RP@)R<L(%\H(D%D7W9A;F-E9"!396%R8V@B*2D@/SX*("`\+W1D/@H@
M/"]T<CX*/"]T86)L93X*"CQT86)L92!C96QL<W!A8VEN9STB,"(@=VED=&@]
M(C$P,"4B/@H\(2TM('-E87)C:"!P871T97)N("TM/@H\='(^"B`@/'1D(&-L
M87-S/2)I=&5M(B!A;&EG;CTB<FEG:'0B('9A;&EG;CTB=&]P(B!N;W=R87`]
M(FYO=W)A<"(^"B`@("`\<W1R;VYG/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L
M*"=P871T97)N7W1I=&QE)RP@7R@B5&ET;&4B*2D@/SXZ/"]S=')O;F<^)FYB
M<W`["B`@/"]T9#X*("`\=&0@8VQA<W,](FET96TB('=I9'1H/2(Q,#`E(CX*
M("`@(#QI;G!U="!N86UE/2)P871T97)N7W1I=&QE(B!I9#TB<&%T=&5R;E]T
M:71L92(@='EP93TB=&5X="(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<RA5=&EL.CIG971&;W)M1&%T82@G<&%T=&5R;E]T:71L92<I*2`_
M/B(@<VEZ93TB-3`B(&UA>&QE;F=T:#TB,3`P(B`O/@H@(#PO=&0^"CPO='(^
M"CQT<CX*("`\=&0@8VQA<W,](FET96TB(&%L:6=N/2)R:6=H="(@=F%L:6=N
M/2)T;W`B(&YO=W)A<#TB;F]W<F%P(CX*("`@(#QS=')O;F<^/#]P:'`@96-H
M;R!(;W)D93HZ;&%B96PH)W!A='1E<FY?9&5S8R<L(%\H(D1E<V-R:5]P=&EO
M;B(I*2`_/CH\+W-T<F]N9SXF;F)S<#L*("`\+W1D/@H@(#QT9"!C;&%S<STB
M:71E;2(@=VED=&@](C$P,"4B/@H@("`@/&EN<'5T(&YA;64](G!A='1E<FY?
M9&5S8R(@:60](G!A='1E<FY?9&5S8R(@='EP93TB=&5X="(@=F%L=64](CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG971&;W)M1&%T82@G
M<&%T=&5R;E]D97-C)RDI(#\^(B!S:7IE/2(U,"(@;6%X;&5N9W1H/2(Q,#`B
M("\^"B`@/"]T9#X*/"]T<CX*/"$M+2!R86YG92`M+3X*/'1R/@H@(#QT9"!C
M;&%S<STB:71E;2(@86QI9VX](G)I9VAT(B!V86QI9VX](G1O<"(@;F]W<F%P
M/2)N;W=R87`B/@H@("`@/'-T<F]N9SX\/W!H<"!E8VAO($AO<F1E.CIL86)E
M;"@G<V5A<F-H7W!A='1E<FXG+"!?*")4:6UE(%-P7V%N(BDI(#\^.CPO<W1R
M;VYG/B9N8G-P.PH@(#PO=&0^"B`@/'1D(&-L87-S/2)I=&5M(B!W:61T:#TB
M,3`P)2(^"B`@("`\<V5L96-T(&YA;64](G)A;F=E(CX*/#]P:'`*9G5N8W1I
M;VX@<F%N9V5?;W!T:6]N7W-T<FEN9R@D=&AI<W)A;F=E+"`D9&5S8W(I"GL*
M("`@(&5C:&\@)SQO<'1I;VX@)SL*("`@(&EF("A5=&EL.CIG971&;W)M1&%T
M82@G<F%N9V4G*2`]/2`D=&AI<W)A;F=E*2!["B`@("`@("`@96-H;R`B=F%L
M=64]7"(D=&AI<W)A;F=E7"(@<V5L96-T960]7")S96QE8W1E9%PB(CL*("`@
M('T@96QS92!["B`@("`@("`@96-H;R`B=F%L=64]7"(D=&AI<W)A;F=E7"(B
M.PH@("`@?0H@("`@96-H;R`G/B<@+B`D9&5S8W(@+B`G/"]O<'1I;VX^)SL*
M?0H*<F%N9V5?;W!T:6]N7W-T<FEN9R@G+2<L(%\H(D%L;"!087-T(BDI.PIR
M86YG95]O<'1I;VY?<W1R:6YG*"<M-C`T.#`P)RP@7R@B3&%S="!W965K(BDI
M.PIR86YG95]O<'1I;VY?<W1R:6YG*"<M.#8T,#`G+"!?*"),87-T(#(T(&AO
M=7)S(BDI.PIR86YG95]O<'1I;VY?<W1R:6YG*"<P)RP@7R@B3F]W(BDI.PIR
M86YG95]O<'1I;VY?<W1R:6YG*"<X-C0P,"<L(%\H(DYE>'0@,C0@:&]U<G,B
M*2D["G)A;F=E7V]P=&EO;E]S=')I;F<H)S8P-#@P,"<L(%\H(DYE>'0@=V5E
M:R(I*3L*<F%N9V5?;W!T:6]N7W-T<FEN9R@G*R<L(%\H(D%L;"!&=71U<F4B
M*2D["C\^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H\+W1A8FQE/@H*
M/&)R("\^"CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A
M;'5E/2(\/W!H<"!E8VAO(%\H(E-E87)C:"(I(#\^(B`O/@H\+V9O<FT^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S+W-E87)C:"]E=F5N=%]H96%D97)S
M+FEN8P```````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S$S`#$P-#$W,S8R-S4S`#`R-3(P-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\=&%B
M;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(Q(B!C;&%S<STB:71E;2(^
M"B`\='(@8VQA<W,](FET96TB/@H@(#QT:"!C;&%S<STB:71E;2(@86QI9VX]
M(FQE9G0B/CP_<&AP(&5C:&\@7R@B5&ET;&4B*2`_/CPO=&@^"B`@/'1H(&-L
M87-S/2)I=&5M(B!A;&EG;CTB;&5F="(^/#]P:'`@96-H;R!?*")#871E9V]R
M>2(I(#\^/"]T:#X*("`\=&@@8VQA<W,](FET96TB(&%L:6=N/2)L969T(CX\
M/W!H<"!E8VAO(%\H(DQO8V%T:6]N(BD@/SX\+W1H/@H@(#QT:"!C;&%S<STB
M:71E;2(@86QI9VX](FQE9G0B/CP_<&AP(&5C:&\@7R@B4W1A='5S(BD@/SX\
M+W1H/@H@(#QT:"!C;&%S<STB:71E;2(@86QI9VX](FQE9G0B/CP_<&AP(&5C
M:&\@7R@B4W1A<G0@3VXB*2`_/CPO=&@^"B`@/'1H(&-L87-S/2)I=&5M(B!A
M;&EG;CTB;&5F="(^/#]P:'`@96-H;R!?*")%;F0@3VXB*2`_/CPO=&@^"B`\
M+W1R/@H`````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L
M:71H+W1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8P``````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#,R-@`Q,#0Q-S,V,C<U,P`P,C,V,C$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/&)R(&-L87-S/2)S<&%C
M97(B("\^"CQD:78@8VQA<W,](FAE861E<B(^"B`\<W!A;B!C;&%S<STB<FEG
M:'1&;&]A="(^"B`@/#]P:'`@96-H;R!C;W5N="@D979E;G1S*2`]/2`Q(#\@
M7R@B,2!E=F5N="(I(#H@<W!R:6YT9BA?*"(E9"!E=F5N=',B*2P@8V]U;G0H
M)&5V96YT<RDI(#\^"B`\+W-P86X^"B`\/W!H<"!E8VAO(%\H(E-E87)C:"!2
M97-U;'1S(BD@/SX*/"]D:78^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T
M97,O9&%T82\`````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-3,`,#(Q,S0T`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:W)O;F]L:71H+W1E;7!L871E<R]D871A+VEM<&]R="YI;F,`````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,S,V,0`Q,#0Q-S,V,C<U,P`P,C,S-3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/&9O<FT@;65T
M:&]D/2)P;W-T(B!N86UE/2)I;7!O<G1?9F]R;2(@96YC='EP93TB;75L=&EP
M87)T+V9O<FTM9&%T82(@86-T:6]N/2)D871A+G!H<"(^"CP_<&AP(%5T:6PZ
M.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A
M8W1I;VY)1"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M;F5X=%]S=&5P*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M:6UP;W)T7W-T97`B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&EM<&]R=%]S
M=&5P(#\^(B`O/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F
M*%\H(DEM<&]R="!#86QE;F1A<BP@4W1E<"`E9"(I+"`H:6YT*21I;7!O<G1?
M<W1E<"D@/SX*/"]H,3X*"CQD:78@8VQA<W,](FET96TB/@H@("`@/#]P:'`@
M96-H;R!?*")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z
M(BD@/SX\8G(@+SX*("`@(#QS96QE8W0@;F%M93TB:6UP;W)T7V9O<FUA="(^
M"B`@("`@(#QO<'1I;VX@=F%L=64](F-S=B(^/#]P:'`@96-H;R!?*")#;VUM
M82!S97!A<F%T960@=F%L=65S(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO
M;B!V86QU93TB:6-A;&5N9&%R(CX\/W!H<"!E8VAO(%\H(G9#86QE;F1A<B]I
M0V%L96YD87(B*2`_/CPO;W!T:6]N/@H@("`@/"]S96QE8W0^/&)R("\^"@H@
M("`@/#]P:'`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=D969A=6QT7W-H87)E
M)RD@)B8@8V]U;G0H)&-A;&5N9&%R<R`]($MR;VYO;&ET:#HZ;&ES=$-A;&5N
M9&%R<RAF86QS92P@4$5235-?141)5"DI(#X@,2DZ(#\^"B`@("`\/W!H<"!E
M8VAO(%\H(E-E;&5C="!T:&4@8V%L96YD87(@=&\@:6UP;W)T('1O.B(I(#\^
M/&)R("\^"B`@("`\<V5L96-T(&YA;64](FEM<&]R=$-A;"(^"B`@("`@(#P_
M<&AP(&9O<F5A8V@@*"1C86QE;F1A<G,@87,@)&ED(#T^("1C86PI('L*("`@
M("`@("`@('!R:6YT9B@G/&]P=&EO;B!V86QU93TB)7,B/B5S/"]O<'1I;VX^
M)RP@:'1M;'-P96-I86QC:&%R<R@D:60I+"!H=&UL<W!E8VEA;&-H87)S*"1C
M86PM/F=E="@G;F%M92<I*2D@+B`B7&XB.PH@("`@("!](#\^"B`@("`\+W-E
M;&5C=#X\8G(@+SX\8G(@+SX*("`@(#P_<&AP(&5L<V4Z(#\^"B`@("`\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)I;7!O<G1#86PB('9A;'5E/2(\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H2W)O;F]L:71H.CIG971$969A=6QT
M0V%L96YD87(H4$5235-?141)5"DI(#\^(B`O/@H@("`@/#]P:'`@96YD:68[
M(#\^"B`@("`\/W!H<"!E8VAO(%\H(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O
M<G0Z(BD@/SX\8G(@+SX*("`@(#QI;G!U="!T>7!E/2)F:6QE(B!N86UE/2)I
M;7!O<G1?9FEL92(@8VQA<W,](F9I>&5D(B!S:7IE/2(T,"(@+SX*("`@(#QB
M<B`O/CQB<B`O/@H@("`@/&EN<'5T('1Y<&4](F-H96-K8F]X(B!A;&EG;CTB
M;6ED9&QE(B!N86UE/2)P=7)G92(@:60](G!U<F=E(B!V86QU93TB,2(@+SX*
M("`@(#QL86)E;"!F;W(](G!U<F=E(CX\/W!H<"!E8VAO(%\H(E)E<&QA8V4@
M97AI<W1I;F<@8V%L96YD87(@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R
M;VYG/E=A<FYI;F<Z(%1H:7,@9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R
M(&-U<G)E;G0@8V%L96YD87(N/"]S=')O;F<^(BD@/SX\+VQA8F5L/@H@("`@
M/&)R("\^/&)R("\^"B`@("`\:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB
M/#]P:'`@96-H;R!?*").97AT(BD@/SXB(&-L87-S/2)B=71T;VXB("\^"CPO
M9&EV/@H\+V9O<FT^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,34T-#,`,3`T,3<S-C(W-3,`,#(S,S8T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QF;W)M(&UE=&AO9#TB
M<&]S="(@;F%M93TB97AP;W)T(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z
M.F1O=VYL;V%D57)L*%\H(F5V96YT<RYC<W8B*2P@;G5L;"P@)V1A=&$N<&AP
M)RD@/SXB/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)E>'!O<G0B("\^
M"@H\8G(@8VQA<W,](G-P86-E<B(@+SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*
M(#P_<&AP(&5C:&\@7R@B17AP;W)T($-A;&5N9&%R(BD@/SX*/"]H,3X*"CQD
M:78@8VQA<W,](FET96TB/@H@("`@/#]P:'`@96-H;R!?*")396QE8W0@=&AE
M(&5X<&]R="!F;W)M870Z(BD@/SX\8G(@+SX*("`@(#QS96QE8W0@;F%M93TB
M97AP;W)T240B/@H@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO($58
M4$]25%]#4U8@/SXB/D-35CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E
M/2(\/W!H<"!E8VAO($584$]25%])0T%,14Y$05(@/SXB/FE#86QE;F1A<CPO
M;W!T:6]N/@H@("`@/"]S96QE8W0^/&)R("\^/&)R("\^"@H@("`@/#]P:'`@
M:68@*&-O=6YT*"1C86QE;F1A<G,@/2!+<F]N;VQI=&@Z.FQI<W1#86QE;F1A
M<G,H9F%L<V4L(%!%4DU37U)%040I*2`^(#$I.B`_/@H@("`@/#]P:'`@96-H
M;R!?*")396QE8W0@=&AE(&-A;&5N9&%R*',I('1O(&5X<&]R="!F<F]M(BD@
M/SX\8G(@+SX*("`@(#QS96QE8W0@;F%M93TB97AP;W)T0V%L6UTB(&UU;'1I
M<&QE/2)M=6QT:7!L92(^"B`@("`@(#P_<&AP(&9O<F5A8V@@*"1C86QE;F1A
M<G,@87,@)&ED(#T^("1C86PI('L*("`@("`@("`@('!R:6YT9B@G/&]P=&EO
M;B!V86QU93TB)7,B/B5S/"]O<'1I;VX^)RP@:'1M;'-P96-I86QC:&%R<R@D
M:60I+"!H=&UL<W!E8VEA;&-H87)S*"1C86PM/F=E="@G;F%M92<I*2D@+B`B
M7&XB.PH@("`@("!](#\^"B`@("`\+W-E;&5C=#X\8G(@+SX\8G(@+SX*("`@
M(#P_<&AP(&5L<V4Z(#\^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)E>'!O<G1#86Q;72(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<RA+<F]N;VQI=&@Z.F=E=$1E9F%U;'1#86QE;F1A<BA015)-4U]214%$
M*2D@/SXB("\^"B`@("`\/W!H<"!E;F1I9CL@/SX*"B`@("`\/W!H<"!E8VAO
M(%\H(DQI;6ET('1H92!T:6UE('-P86X@=&\@97AP;W)T.B(I(#\^/&)R("\^
M"B`@("`\=&%B;&4^"B`@("`\='(^"B`@("`@(#QT9#X\:6YP=70@='EP93TB
M<F%D:6\B(&YA;64](F%L;%]E=F5N=',B(&ED/2)A;&PB('9A;'5E/2(Q(B!C
M:&5C:V5D/2)C:&5C:V5D(B`O/CPO=&0^"B`@("`@(#QT9"!C;VQS<&%N/2(R
M(CX\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G86QL)RP@7R@B06QL(&5V96YT
M<R(I*2`_/CPO=&0^"B`@("`\+W1R/@H@("`@/'1R/@H@("`@("`\=&0@<F]W
M<W!A;CTB-"(@=F%L:6=N/2)T;W`B/CQI;G!U="!T>7!E/2)R861I;R(@;F%M
M93TB86QL7V5V96YT<R(@:60](G-O;64B('9A;'5E/2(P(B`O/CPO=&0^"B`@
M("`@(#QT9"!A;&EG;CTB<FEG:'0B/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L
M*"=S;VUE)RP@7R@B4W1A<G0@3VXB*2D@/SX\+W1D/@H@("`@("`\=&0@8V]L
M<W!A;CTB,R(^"B`@("`@("`@/'-E;&5C="!N86UE/2)S=&%R=%]Y96%R(B!O
M;F-H86YG93TB9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)W-O;64G*2YC:&5C
M:V5D(#T@=')U93LB/@H\/W!H<`HD<W1A<G1?>65A<E]M871C:"`](&1A=&4H
M)UDG*3L*9F]R("@D:2`]("TQ.R`D:2`\(#8[("1I*RLI.@H@("`@)'ER(#T@
M9&%T92@G62<I("L@)&D["B`@("`D<V5L(#T@)R<["B`@("!I9B`H)'ER(#T]
M("1S=&%R=%]Y96%R7VUA=&-H*2!["B`@("`@("`@)'-E;"`]("<@<V5L96-T
M960](G-E;&5C=&5D(B<["B`@("!]"C\^"B`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(\/W!H<"!E8VAO("1Y<B`_/B(\/W!H<"!E8VAO("1S96P@/SX^/#]P
M:'`@96-H;R`D>7(@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R.R`_/@H@("`@
M("`@(#PO<V5L96-T/@H@("`@("`@("T*("`@("`@("`\<V5L96-T(&YA;64]
M(G-T87)T7VUO;G1H(B!O;F-H86YG93TB9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)W-O;64G*2YC:&5C:V5D(#T@=')U93LB/@H\/W!H<`HD<W1A<G1?;6]N
M=&A?;6%T8V@@/2!D871E*"=N)RD@+2`Q.PIF;W(@*"1I(#T@,3L@)&D@/"`Q
M,SL@)&DK*RDZ"B`@("`D<V5L(#T@)R<["B`@("!I9B`H)&D@/3T@)'-T87)T
M7VUO;G1H7VUA=&-H*2!["B`@("`@("`@)'-E;"`]("<@<V5L96-T960](G-E
M;&5C=&5D(B<["B`@("!]"C\^"B`@("`@("`@("`\;W!T:6]N('9A;'5E/2(\
M/W!H<"!E8VAO("1I(#\^(CP_<&AP(&5C:&\@)'-E;"`_/CX\/W!H<"!E8VAO
M('-T<F9T:6UE*"<E8B<L(&UK=&EM92@Q+"`Q+"`Q+"`D:2P@,2DI(#\^/"]O
M<'1I;VX^"CP_<&AP(&5N9&9O<CL@/SX*("`@("`@("`\+W-E;&5C=#X*("`@
M("`@("`M"B`@("`@("`@/'-E;&5C="!N86UE/2)S=&%R=%]D87DB(&]N8VAA
M;F=E/2)D;V-U;65N="YG971%;&5M96YT0GE)9"@G<V]M92<I+F-H96-K960@
M/2!T<G5E.R(^"CP_<&AP"B1S=&%R=%]D87E?;6%T8V@@/2!D871E*"=J)RD[
M"F9O<B`H)&D@/2`Q.R`D:2`\(#,R.R`D:2LK*3H*("`@("1S96P@/2`G)SL*
M("`@(&EF("@D:2`]/2`D<W1A<G1?9&%Y7VUA=&-H*2!["B`@("`@("`@)'-E
M;"`]("<@<V5L96-T960](G-E;&5C=&5D(B<["B`@("!]"C\^"B`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO("1I(#\^(CP_<&AP(&5C:&\@
M)'-E;"`_/CX\/W!H<"!E8VAO("1I(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O
M<CL@/SX*("`@("`@("`\+W-E;&5C=#X*("`@("`@/"]T9#X*("`@(#PO='(^
M"B`@("`\(2TM('-T87)T('1I;64@+2T^"B`@("`\='(^"B`@("`@(#QT9"!A
M;&EG;CTB<FEG:'0B/CP_<&AP(&5C:&\@7R@B070B*2`_/CPO=&0^"B`@("`@
M(#QT9"!A;&EG;CTB;&5F="(@8V]L<W!A;CTB,R(^"B`@("`@("`@/'-E;&5C
M="!N86UE/2)S=&%R=%]H;W5R(B!O;F-H86YG93TB9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)W-O;64G*2YC:&5C:V5D(#T@=')U93LB/@H\/W!H<`HD<W1A
M<G1?:&]U<E]M871C:"`]("1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G
M*2`_(#`@.B`Q,#L*)&AO=7)?;6EN(#T@*"1P<F5F<RT^9V5T5F%L=64H)W1W
M96YT>49O=7(G*2D@/R`P(#H@,3L*)&AO=7)?;6%X(#T@*"1P<F5F<RT^9V5T
M5F%L=64H)W1W96YT>49O=7(G*2D@/R`R-"`Z(#$S.PIF;W(@*"1I(#T@)&AO
M=7)?;6EN.R`D:2`\("1H;W5R7VUA>#L@)&DK*RDZ"B`@("`D<V5L(#T@)R<[
M"B`@("!I9B`H)&D@/3T@)'-T87)T7VAO=7)?;6%T8V@I"B`@("`@("`@)'-E
M;"`]("<@<V5L96-T960](G-E;&5C=&5D(B<["C\^"B`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2(\/W!H<"!E8VAO("1I(#\^(CP_<&AP(&5C:&\@)'-E;"`_
M/CX\/W!H<"!E8VAO("1I(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<CL@/SX*
M("`@("`@("`\+W-E;&5C=#X*("`@("`@("`F;F)S<#LZ)FYB<W`["B`@("`@
M("`@/'-E;&5C="!N86UE/2)S=&%R=%]M:6XB(&]N8VAA;F=E/2)D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G<V]M92<I+F-H96-K960@/2!T<G5E.R(^"CP_
M<&AP"B1S=&%R=%]M:6Y?;6%T8V@@/2`P.PIF;W(@*"1I(#T@,#L@)&D@/"`Q
M,CL@)&DK*RDZ"B`@("`D<V5L(#T@)R<["B`@("`D;6EN(#T@<W!R:6YT9B@G
M)3`R9"<L("1I("H@-2D["B`@("!I9B`H)&UI;B`]/2`D<W1A<G1?;6EN7VUA
M=&-H*0H@("`@("`@("1S96P@/2`G('-E;&5C=&5D/2)S96QE8W1E9"(G.PH_
M/@H@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D;6EN(#\^
M(CP_<&AP(&5C:&\@)'-E;"`_/CX\/W!H<"!E8VAO("1M:6X@/SX\+V]P=&EO
M;CX*/#]P:'`@96YD9F]R.R`_/@H@("`@("`@(#PO<V5L96-T/@H\/W!H<`II
M9B`H(21P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G*2D@>PH_/@H@("`@
M("`@(#QI;G!U="!T>7!E/2)R861I;R(@;F%M93TB86U?<&TB(&ED/2)S86TB
M('9A;'5E/2)!32(@8VAE8VME9#TB8VAE8VME9"(@+SX\/W!H<"!E8VAO($AO
M<F1E.CIL86)E;"@G<V%M)RP@7R@B04TB*2D@/SX*("`@("`@("`\:6YP=70@
M='EP93TB<F%D:6\B(&YA;64](F%M7W!M(B!I9#TB<W!M(B!V86QU93TB4$TB
M("\^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)W-P;2<L(%\H(E!-(BDI(#\^
M"CP_<&AP('T@/SX*("`@("`@/"]T9#X*("`@(#PO='(^"B`@("`\(2TM(&5N
M9"!D871E("TM/@H@("`@/'1R/@H@("`@("`\=&0@86QI9VX](G)I9VAT(CX\
M/W!H<"!E8VAO(%\H(D5N9"!/;B(I(#\^/"]T9#X*("`@("`@/'1D/@H\/W!H
M<`HD96YD7WEE87)?;6%T8V@@/2`D<W1A<G1?>65A<E]M871C:#L*)&5N9%]M
M;VYT:%]M871C:"`]("1S=&%R=%]M;VYT:%]M871C:"`K(#$["B1E;F1?9&%Y
M7VUA=&-H(#T@)'-T87)T7V1A>5]M871C:#L*)&5N9%]H;W5R7VUA=&-H(#T@
M)'-T87)T7VAO=7)?;6%T8V@["B1E;F1?;6EN7VUA=&-H(#T@)'-T87)T7VUI
M;E]M871C:#L*/SX*("`@("`@("`\<V5L96-T(&YA;64](F5N9%]Y96%R(B!O
M;F-H86YG93TB9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)W-O;64G*2YC:&5C
M:V5D(#T@=')U93LB/@H\/W!H<`IF;W(@*"1I(#T@+3$[("1I(#P@-CL@)&DK
M*RDZ"B`@("`D>7(@/2!D871E*"=9)RD@*R`D:3L*("`@("1S96P@/2`G)SL*
M("`@(&EF("@D>7(@/3T@)&5N9%]Y96%R7VUA=&-H*2!["B`@("`@("`@)'-E
M;"`]("<@<V5L96-T960](G-E;&5C=&5D(B<["B`@("!]"C\^"B`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO("1Y<B`_/B(\/W!H<"!E8VAO
M("1S96P@/SX^/#]P:'`@96-H;R`D>7(@/SX\+V]P=&EO;CX*/#]P:'`@96YD
M9F]R.R`_/@H@("`@("`@(#PO<V5L96-T/@H@("`@("`@("T*("`@("`@("`\
M<V5L96-T(&YA;64](F5N9%]M;VYT:"(@;VYC:&%N9V4](F1O8W5M96YT+F=E
M=$5L96UE;G1">4ED*"=S;VUE)RDN8VAE8VME9"`]('1R=64[(CX*/#]P:'`*
M9F]R("@D:2`](#$[("1I(#P@,3,[("1I*RLI.@H@("`@)'-E;"`]("<G.PH@
M("`@:68@*"1I(#T]("1E;F1?;6]N=&A?;6%T8V@I('L*("`@("`@("`D<V5L
M(#T@)R!S96QE8W1E9#TB<V5L96-T960B)SL*("`@('T*/SX*("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@)&D@/SXB/#]P:'`@96-H;R`D
M<V5L(#\^/CP_<&AP(&5C:&\@<W1R9G1I;64H)R5B)RP@;6MT:6UE*#$L,2PQ
M+"1I+#$I*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W([(#\^"B`@("`@("`@
M/"]S96QE8W0^"B`@("`@("`@+0H@("`@("`@(#QS96QE8W0@;F%M93TB96YD
M7V1A>2(@;VYC:&%N9V4](F1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=S;VUE
M)RDN8VAE8VME9"`]('1R=64[(CX*/#]P:'`*9F]R("@D:2`](#$[("1I(#P@
M,S([("1I*RLI.@H@("`@)'-E;"`]("<G.PH@("`@:68@*"1I(#T]("1E;F1?
M9&%Y7VUA=&-H*0H@("`@("`@("1S96P@/2`G('-E;&5C=&5D/2)S96QE8W1E
M9"(G.PH_/@H@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D
M:2`_/B(\/W!H<"!E8VAO("1S96P@/SX^/#]P:'`@96-H;R`D:2`_/CPO;W!T
M:6]N/@H\/W!H<"!E;F1F;W([(#\^"B`@("`@("`@/"]S96QE8W0^"B`@("`@
M(#PO=&0^"B`@("`\+W1R/@H@("`@/"$M+2!E;F0@=&EM92`M+3X*("`@(#QT
M<CX*("`@("`@/'1D(&%L:6=N/2)R:6=H="(^/#]P:'`@96-H;R!?*")!="(I
M(#\^/"]T9#X*("`@("`@/'1D(&%L:6=N/2)L969T(CX*("`@("`@("`\<V5L
M96-T(&YA;64](F5N9%]H;W5R(B!O;F-H86YG93TB9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)W-O;64G*2YC:&5C:V5D(#T@=')U93LB/@H\/W!H<`IF;W(@
M*"1I(#T@)&AO=7)?;6EN.R`D:2`\("1H;W5R7VUA>#L@)&DK*RDZ"B`@("`D
M<V5L(#T@)R<["B`@("!I9B`H)&D@/3T@)&5N9%]H;W5R7VUA=&-H*0H@("`@
M("`@("1S96P@/2`G('-E;&5C=&5D/2)S96QE8W1E9"(G.PH_/@H@("`@("`@
M("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D:2`_/B(\/W!H<"!E8VAO
M("1S96P@/SX^/#]P:'`@96-H;R`D:2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F
M;W([(#\^"B`@("`@("`@/"]S96QE8W0^"B`@("`@("`@)FYB<W`[.B9N8G-P
M.PH@("`@("`@(#QS96QE8W0@;F%M93TB96YD7VUI;B(@;VYC:&%N9V4](F1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*"=S;VUE)RDN8VAE8VME9"`]('1R=64[
M(CX*/#]P:'`*9F]R("@D:2`](#`[("1I(#P@,3([("1I*RLI.@H@("`@)'-E
M;"`]("<G.PH@("`@)&UI;B`]('-P<FEN=&8H)R4P,F0G+"`D:2`J(#4I.PH@
M("`@:68@*"1M:6X@/3T@)&5N9%]M:6Y?;6%T8V@I"B`@("`@("`@)'-E;"`]
M("<@<V5L96-T960](G-E;&5C=&5D(B<["C\^"B`@("`@("`@("`\;W!T:6]N
M('9A;'5E/2(\/W!H<"!E8VAO("1M:6X@/SXB/#]P:'`@96-H;R`D<V5L(#\^
M/CP_<&AP(&5C:&\@)&UI;B`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W([(#\^
M"B`@("`@("`@/"]S96QE8W0^"CP_<&AP(&EF("@A)'!R969S+3YG971686QU
M92@G='=E;G1Y1F]U<B<I*3H@/SX*("`@("`@("`\:6YP=70@='EP93TB<F%D
M:6\B(&YA;64](F5N9%]A;5]P;2(@:60](F5A;2(@=F%L=64](D%-(B!C:&5C
M:V5D/2)C:&5C:V5D(B`O/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=E86TG
M+"!?*")!32(I*2`_/@H@("`@("`@(#QI;G!U="!T>7!E/2)R861I;R(@;F%M
M93TB96YD7V%M7W!M(B!I9#TB97!M(B!V86QU93TB4$TB("\^/#]P:'`@96-H
M;R!(;W)D93HZ;&%B96PH)V5P;2<L(%\H(E!-(BDI(#\^"CP_<&AP(&5N9&EF
M.R`_/@H@("`@("`\+W1D/@H@("`@/"]T<CX*("`@(#PO=&%B;&4^/&)R("\^
M"B`@("`\:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?
M*")%>'!O<G0B*2`_/B(@8VQA<W,](F)U='1O;B(@+SX*/"]D:78^"CPO9F]R
M;3X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O
M961I="\`````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-3,`,#(Q,S8P`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O
M;F]L:71H+W1E;7!L871E<R]E9&ET+V5D:70N:6YC````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`S-S8U-@`Q,#0Q-S,V,C<U,P`P,C,P,38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&1I=B!I9#TB<&%G
M92(^"CQF;W)M(&%C=&EO;CTB/#]P:'`@96-H;R`H)&5V96YT+3YI<TEN:71I
M86QI>F5D*"D@/R`G961I=&5V96YT86-T:6]N+G!H<"<@.B`G861D979E;G1A
M8W1I;VXN<&AP)RD@/SXB(&UE=&AO9#TB<&]S="(@;F%M93TB979E;G0B/@H\
M/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB>65A<B(@=F%L=64](CP_<&AP(&EF("AI<W-E="@D>65A<BDI
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D>65A<BD@/SXB("\^"CQI;G!U="!T
M>7!E/2)H:61D96XB(&YA;64](FUO;G1H(B!V86QU93TB/#]P:'`@:68@*&ES
M<V5T*"1M;VYT:"DI(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;6]N=&@I(#\^
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)M9&%Y(B!V86QU93TB
M/#]P:'`@:68@*&ES<V5T*"1D87DI*2!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&1A>2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G1I;65S
M=&%M<"(@=F%L=64](CP_<&AP(&EF("AI<W-E="@D=&EM97-T86UP*2D@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1T:6UE<W1A;7`I(#\^(B`O/@H\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)N97=?8V%T96=O<GDB('9A;'5E/2(B("\^
M"CP_<&AP(&EF("AI<W-E="@D=7)L*2DZ(#\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](G5R;"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D=7)L*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("@D
M979E;G0M/FES26YI=&EA;&EZ960H*2DZ(#\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F5V96YT240B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&5V96YT+3YG971)1"@I*2`_/B(@+SX*/#]P:'`@96YD:68[
M(#\^"CP_<&AP(&EF("@D979E;G0M/FES26YI=&EA;&EZ960H*2DZ(#\^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F5X:7-T:6YG8V%L96YD87(B('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&5V96YT+3YG971#
M86QE;F1A<B@I*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^"@H*/"$M+2!H96%D
M97(@+2T^"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@)&5V96YT
M+3YI<TEN:71I86QI>F5D*"D@/R!S<')I;G1F*%\H(D5D:70@)7,B*2P@:'1M
M;'-P96-I86QC:&%R<R@D979E;G0M/F=E=%1I=&QE*"DI*2`Z(%\H(D%D9"!%
M=F5N="(I(#\^"CPO:#$^"@H\=&%B;&4@8VQA<W,](G-T<FEP960B(&-E;&QS
M<&%C:6YG/2(P(CX*/"$M+2!B=71T;VYS("TM/@H\='(^"B`\=&0^/"]T9#X*
M(#QT9"!C;VQS<&%N/2(T(CX*("`\/W!H<"!E8VAO(&EM<&QO9&4H(EQN(BP@
M)&)U='1O;G,I(#\^"B`@/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB8V%N
M8V5L(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")#86YC
M96PB*2`_/B(@;VYC;&EC:STB<V5L9BYL;V-A=&EO;B`]("<\/W!H<"!E8VAO
M("1C86YC96QU<FP@/SXG.R!R971U<FX@9F%L<V4[(B`O/@H@(#QI;G!U="!T
M>7!E/2)B=71T;VXB(&YA;64](G)E<V5T0G5T=&]N(B!C;&%S<STB8G5T=&]N
M(B!V86QU93TB/#]P:'`@96-H;R!?*")297-E="!T;R!$969A=6QT<R(I(#\^
M(B!O;F-L:6-K/2)D;V-U;65N="YE=F5N="YR97-E="@I.R!U<&1A=&579&%Y
M*"=S=&%R=%]W9&%Y)RD[('5P9&%T95=D87DH)V5N9%]W9&%Y)RD[(B`O/@H@
M/"]T9#X*/"]T<CX*"CPA+2T@=&ET;&4@+2T^"CQT<CX*(#QT9"!A;&EG;CTB
M<FEG:'0B(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO($AO<F1E
M.CIL86)E;"@G=&ET;&4G+"!?*")4:71?;&4B*2D@/SXF;F)S<#LF;F)S<#L\
M+W-T<F]N9SX\+W1D/@H@/'1D(&-O;'-P86X](C0B/@H@(#QI;G!U="!T>7!E
M/2)T97AT(B!N86UE/2)T:71L92(@:60](G1I=&QE(B!V86QU93TB/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1E=F5N="T^9V5T5&ET;&4H*2D@/SXB
M('-I>F4](C0P(B!M87AL96YG=&@](C(U-2(@+SX*(#PO=&0^"CPO='(^"@H\
M(2TM(&-A;&5N9&%R("TM/@H\/W!H<"!I9B`H(21P<F5F<RT^:7-,;V-K960H
M)V1E9F%U;'1?<VAA<F4G*2`F)B!C;W5N="@D8V%L96YD87)S*2`^(#$I.B`_
M/@H\='(^"B`\=&0@86QI9VX](G)I9VAT(B!C;&%S<STB;&EG:'0B/CQS=')O
M;F<^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)W1A<F=E=&-A;&5N9&%R)RP@
M7R@B0V%L7V5N9&%R(BDI(#\^)FYB<W`[)FYB<W`[/"]S=')O;F<^/"]T9#X*
M(#QT9"!C;VQS<&%N/2(T(CX*("`@(#QS96QE8W0@:60](G1A<F=E=&-A;&5N
M9&%R(B!N86UE/2)T87)G971C86QE;F1A<B(^"B`@("`\/W!H<`H@("`@9F]R
M96%C:"`H)&-A;&5N9&%R<R!A<R`D:60@/3X@)&-A;"D@>PH@("`@("`@("1S
M96P@/2`H)&ED(#T]("1C86QE;F1A<E]I9"D@/R`G('-E;&5C=&5D/2)S96QE
M8W1E9"(G(#H@)R<["B`@("`@("`@<')I;G1F*"<\;W!T:6]N('9A;'5E/2(E
M<R(E<SXE<SPO;W!T:6]N/B<L"B`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L
M8VAA<G,H)&ED*2P@)'-E;"P@:'1M;'-P96-I86QC:&%R<R@D8V%L+3YG970H
M)VYA;64G*2DI("X@(EQN(CL*("`@('T@/SX*("`@(#PO<V5L96-T/@H*(#PO
M=&0^"CPO='(^"CP_<&AP(&5L<V4Z(#\^"CQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](G1A<F=E=&-A;&5N9&%R(B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1C86QE;F1A<E]I9"D@/SXB("\^"CP_<&AP(&5N9&EF
M.R`_/@H*/"$M+2!C871E9V]R>2`M+3X*/'1R/@H@/'1D(&%L:6=N/2)R:6=H
M="(@8VQA<W,](FQI9VAT(CX*("`@(#QS=')O;F<^/#]P:'`@96-H;R!(;W)D
M93HZ;&%B96PH)V-A=&5G;W)Y)RP@7R@B0V%T96=O<E]Y(BDI(#\^)FYB<W`[
M)FYB<W`[/"]S=')O;F<^"B`\+W1D/@H@/'1D(&-O;'-P86X](C0B/CP_<&AP
M(&5C:&\@)&--86YA9V5R+3YG971396QE8W0H)V-A=&5G;W)Y)RP@)&5V96YT
M+3YG971#871E9V]R>2@I*2`_/CPO=&0^"CPO='(^"@H\(2TM(&QO8V%T:6]N
M("TM/@H\='(^"B`\=&0@86QI9VX](G)I9VAT(B!C;&%S<STB;&EG:'0B/CQS
M=')O;F<^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)VQO8V%T:6]N)RP@7R@B
M3&]?8V%T:6]N(BDI(#\^)FYB<W`[)FYB<W`[/"]S=')O;F<^/"]T9#X*(#QT
M9"!C;VQS<&%N/2(T(CX*("`\:6YP=70@='EP93TB=&5X="(@;F%M93TB;&]C
M871I;VXB(&ED/2)L;V-A=&EO;B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D979E;G0M/F=E=$QO8V%T:6]N*"DI(#\^(B!S:7IE/2(T
M,"(@;6%X;&5N9W1H/2(R-34B("\^"B`\+W1D/@H\+W1R/@H*/"$M+2!S=&%T
M=7,@+2T^"CQT<CX*(#QT9"!A;&EG;CTB<FEG:'0B(&-L87-S/2)L:6=H="(^
M"B`@("`\<W1R;VYG/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=S=&%T=7,G
M+"!?*")3=&%T7W5S(BDI(#\^)FYB<W`[)FYB<W`[/"]S=')O;F<^"B`\+W1D
M/@H@/'1D(&-O;'-P86X](C0B/@H@(#P_<&AP(&5C:&\@2W)O;F]L:71H.CIB
M=6EL9%-T871U<U=I9&=E="@G<W1A='5S)RP@)&5V96YT+3YG9713=&%T=7,H
M*2D@/SX*(#PO=&0^"CPO='(^"@H\/W!H<"!R97%U:7)E($M23TY/3$E42%]4
M14U03$%415,@+B`G+V5D:70O961I=%]T:6UE<W!A;BYI;F,G(#\^"@H\(2TM
M(&%L87)M("TM/@H\='(^"B`\=&0@86QI9VX](G)I9VAT(B!C;&%S<STB;&EG
M:'0B(')O=W-P86X](C(B('9A;&EG;CTB=&]P(CX*("`@(#QS=')O;F<^/#]P
M:'`@)&%K(#T@2&]R9&4Z.F=E=$%C8V5S<TME>2A?*")?06QA<FTB*2D[(&5C
M:&\@2&]R9&4Z.FAI9VAL:6=H=$%C8V5S<TME>2A?*")?06QA<FTB*2P@)&%K
M*2`_/B9N8G-P.R9N8G-P.SPO<W1R;VYG/@H@/"]T9#X*(#QT9"!V86QI9VX]
M(G1O<"(^"B`@/#]P:'`*("!I9B`H)&5V96YT+3YI<TEN:71I86QI>F5D*"D@
M)B8@)&5V96YT+3YA;&%R;2`^(#`I('L*("`@("`@)&%L87)M7W-E="`]('1R
M=64["B`@("`@(&EF("@D979E;G0M/F%L87)M("4@,3`P.#`@/3T@,"D@>PH@
M("`@("`@("`@)&%L87)M7W9A;'5E(#T@)&5V96YT+3YA;&%R;2`O(#$P,#@P
M.PH@("`@("`@("`@)&%L87)M7W5N:70@/2`G=V5E:R<["B`@("`@('T@96QS
M96EF("@D979E;G0M/F%L87)M("4@,30T,"`]/2`P*2!["B`@("`@("`@("`D
M86QA<FU?=F%L=64@/2`D979E;G0M/F%L87)M("\@,30T,#L*("`@("`@("`@
M("1A;&%R;5]U;FET(#T@)V1A>2<["B`@("`@('T@96QS96EF("@D979E;G0M
M/F%L87)M("4@-C`@/3T@,"D@>PH@("`@("`@("`@)&%L87)M7W9A;'5E(#T@
M)&5V96YT+3YA;&%R;2`O(#8P.PH@("`@("`@("`@)&%L87)M7W5N:70@/2`G
M:&]U<B<["B`@("`@('T@96QS92!["B`@("`@("`@("`D86QA<FU?=F%L=64@
M/2`D979E;G0M/F%L87)M.PH@("`@("`@("`@)&%L87)M7W5N:70@/2`G;6EN
M)SL*("`@("`@?0H@('T@96QS92!["B`@("`@("1A;&%R;5]V86QU92`](#$U
M.PH@("`@("`D86QA<FU?=6YI="`]("=M:6XG.PH@("`@("`D86QA<FU?<V5T
M(#T@9F%L<V4["B`@?0H@(#\^"B`@/&EN<'5T(&ED/2)N;V%L87)M(B!N86UE
M/2)A;&%R;2(@='EP93TB<F%D:6\B('9A;'5E/2(P(CP_<&AP(&EF("@A)&%L
M87)M7W-E="D@96-H;R`G(&-H96-K960](F-H96-K960B)R`_/B`O/@H@/"]T
M9#X*(#QT9#XF;F)S<#L\+W1D/@H@/'1D('9A;&EG;CTB=&]P(B!C;VQS<&%N
M/2(R(CX*("`\;&%B96P@9F]R/2)N;V%L87)M(B!A8V-E<W-K97D](CP_<&AP
M(&5C:&\@)&%K(#\^(CX@/#]P:'`@96-H;R!?*").;R!A;&%R;2(I(#\^/"]L
M86)E;#X*(#PO=&0^"CPO='(^"CQT<CX*(#QT9"!V86QI9VX](G1O<"(^"B`@
M/&EN<'5T(&YA;64](F%L87)M(B!T>7!E/2)R861I;R(@=F%L=64](C$B/#]P
M:'`@:68@*"1A;&%R;5]S970I(&5C:&\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M/SX@+SX*(#PO=&0^"B`\=&0^)FYB<W`[/"]T9#X*(#QT9"!V86QI9VX](G1O
M<"(@8V]L<W!A;CTB,B(^"B`@/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C(B
M(&YA;64](F%L87)M7W9A;'5E(B!V86QU93TB/#]P:'`@96-H;R`D86QA<FU?
M=F%L=64@/SXB(&]N8VAA;F=E/2)D;V-U;65N="YE=F5N="YA;&%R;5LQ72YC
M:&5C:V5D/71R=64B("\^)FYB<W`["B`@/'-E;&5C="!N86UE/2)A;&%R;5]U
M;FET(B!O;F-H86YG93TB9&]C=6UE;G0N979E;G0N86QA<FU;,5TN8VAE8VME
M9#UT<G5E(CX*("`@/&]P=&EO;B!V86QU93TB,2(\/W!H<"!E8VAO("@D86QA
M<FU?=6YI="`]/2`G;6EN)RD@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@
M)R<@/SX^/#]P:'`@96-H;R!?*")-:6YU=&4H<RDB*2`_/CPO;W!T:6]N/@H@
M("`\;W!T:6]N('9A;'5E/2(V,"(\/W!H<"!E8VAO("@D86QA<FU?=6YI="`]
M/2`G:&]U<B<I(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_
M<&AP(&5C:&\@7R@B2&]U<BAS*2(I(#\^/"]O<'1I;VX^"B`@(#QO<'1I;VX@
M=F%L=64](C$T-#`B/#]P:'`@96-H;R`H)&%L87)M7W5N:70@/3T@)V1A>2<I
M(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@
M7R@B1&%Y*',I(BD@/SX\+V]P=&EO;CX*("`@/&]P=&EO;B!V86QU93TB,3`P
M.#`B/#]P:'`@96-H;R`H)&%L87)M7W5N:70@/3T@)W=E96LG*2`_("<@<V5L
M96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(E=E96LH
M<RDB*2`_/CPO;W!T:6]N/@H@(#PO<V5L96-T/@H@(#P_<&AP(&5C:&\@7R@B
M8F5F;W)E('1H92!E=F5N="!S=&%R=',B*2`_/@H@/"]T9#X*/"]T<CX*"CPA
M+2T@9&5S8W)I<'1I;VX@+2T^"CQT<CX*(#QT9"!C;VQS<&%N/2(U(B!C;&%S
M<STB:&5A9&5R(CX*("`\<W!A;B!C;&%S<STB<VUA;&QH96%D97(B/CP_<&AP
M(&5C:&\@2&]R9&4Z.FQA8F5L*"=D97-C<FEP=&EO;B<L(%\H(CQS=')O;F<^
M1&5S8W)I7W!T:6]N/"]S=')O;F<^("AO<'1I;VYA;"DB*2D@/SX\+W-P86X^
M"CPO=&0^"CPO='(^"CQT<CX*(#QT9#XF;F)S<#L\+W1D/@H@/'1D(&-O;'-P
M86X](C0B/@H@(#QT97AT87)E82!I9#TB9&5S8W)I<'1I;VXB(&YA;64](F1E
M<V-R:7!T:6]N(B!C;VQS/2(T,"(@<F]W<STB-"(^/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1E=F5N="T^9V5T1&5S8W)I<'1I;VXH*2D@/SX\+W1E
M>'1A<F5A/@H@/"]T9#X*/"]T<CX*"CPA+2T@871T96YD965S("TM/@H\/W!H
M<`HD871T96YD965S7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@G)RP@)W1I
M;65S=&%M<"<L("1T:6UE<W1A;7`I.PII9B`H)&)R;W=S97(M/FAA<T9E871U
M<F4H)VIA=F%S8W)I<'0G*2D@>PH@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)V]P96Y?871T96YD965S7W=I;BYJ<R<I.PH@("`@)&%T=&5N9&5E<U]L:6YK
M(#T@)VIA=F%S8W)I<'0Z;W!E;E]A='1E;F1E97-?=VEN*%PG)R`N("1B<F]W
M<V5R+3YE<V-A<&5*4T-O9&4H<W5B<W1R*"1A='1E;F1E97-?=7)L+"`Q*2D@
M+B`G7"<I.R<["GT@96QS92!["B`@("`D871T96YD965S7VQI;FL@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)V%T=&5N9&5E<RYP:'`G("X@)&%T=&5N9&5E
M<U]U<FPI.PI]"C\^"CQT<CX*(#QT9"!C;VQS<&%N/2(U(B!C;&%S<STB:&5A
M9&5R(CX*("`\<W!A;B!C;&%S<STB<VUA;&QH96%D97(B/CP_<&AP(&5C:&\@
M2&]R9&4Z.FQA8F5L*"=A='1E;F1E97,G+"!?*"(\<W1R;VYG/D%T=&5N9&5E
M<SPO<W1R;VYG/B`H;W!T:6]N86PI(BDI(#\^/"]S<&%N/@H@/"]T9#X*/"]T
M<CX*"CQT<CX*(#QT9#X\+W1D/@H@/'1D/@H@(#QI;G!U="!I9#TB<V5N9'5P
M9&%T97,B('1Y<&4](F-H96-K8F]X(B!N86UE/2)S96YD=7!D871E<R(@+SX*
M(#PO=&0^"B`\=&0@8V]L<W!A;CTB,R(^"B`@/&QA8F5L(&9O<CTB<V5N9'5P
M9&%T97,B/CP_<&AP(&5C:&\@7R@B4V5N9"!U<&1A=&5S+VEN=FET871I;VYS
M('1O(&%L;"!A='1E;F1E97,@=VAE;B!S879I;F<@=&AI<R!E=F5N="(I(#\^
M/"]L86)E;#X*(#PO=&0^"CPO='(^"CQT<CX*(#QT9#X\+W1D/@H@/'1D(&-O
M;'-P86X](C0B/@H@(#QI;G!U="!T>7!E/2)B=71T;VXB(&YA;64](F5D:71A
M='1E;F1E97,B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H
M(D5D:70@071T96YD965S(BD@/SXB(&]N8VQI8VL](CP_<&AP(&5C:&\@)&%T
M=&5N9&5E<U]L:6YK(#\^(B`O/@H@/"]T9#X*/"]T<CX*"CPA+2T@<F5C=7)R
M96YC92`M+3X*/'1R/@H@/'1D(&-O;'-P86X](C4B(&-L87-S/2)H96%D97(B
M/@H@(#QS<&%N(&-L87-S/2)S;6%L;&AE861E<B(^/#]P:'`@96-H;R!?*"(\
M<W1R;VYG/E)E8W5R<F5N8V4\+W-T<F]N9SX@*&]P=&EO;F%L*2(I(#\^/"]S
M<&%N/@H@/"]T9#X*/"]T<CX*/'1R/@H@/'1D(&-L87-S/2)L:6=H="(@86QI
M9VX](G)I9VAT(B!V86QI9VX](G1O<"(^/'-T<F]N9SX\/W!H<"!E8VAO($AO
M<F1E.CIL86)E;"@G<F5C=7)N;VYE)RP@7R@B4&%T=&5R;B(I*2`_/B9N8G-P
M.R9N8G-P.SPO<W1R;VYG/CPO=&0^"B`\=&0@=F%L:6=N/2)T;W`B(&-O;'-P
M86X](C0B/@H@(#QT86)L92!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B
M/@H@("`\='(^"B`@("`\=&0@8VQA<W,](FYO=W)A<"(^"B`@("`@/&EN<'5T
M(&ED/2)R96-U<FYO;F4B('1Y<&4](G)A9&EO(B!N86UE/2)R96-U<B(@;VYC
M;&EC:STB8VQE87)&:65L9',H,"D[(B!V86QU93TB/#]P:'`@96-H;R!+4D].
M3TQ)5$A?4D5#55)?3D].12`_/B(\/W!H<"!I9B`H)&5V96YT+3YH87-296-U
M<E1Y<&4H2U)/3D],251(7U)%0U527TY/3D4I*2!E8VAO("<@8VAE8VME9#TB
M8VAE8VME9"(G(#\^("\^/&QA8F5L(&9O<CTB<F5C=7)N;VYE(CX@/#]P:'`@
M96-H;R!?*").;R!R96-U<G)E;F-E(BD@/SX\+VQA8F5L/@H@("`@/"]T9#X*
M("`@/"]T<CX*("`@/'1R/@H@("`@/'1D(&-L87-S/2)N;W=R87`B/@H@("`@
M(#QI;G!U="!I9#TB<F5C=7)D86EL>2(@='EP93TB<F%D:6\B(&YA;64](G)E
M8W5R(B!O;F-L:6-K/2)S971);G1E<G9A;"@G<F5C=7)?9&%I;'E?:6YT97)V
M86PG*3LB('9A;'5E/2(\/W!H<"!E8VAO($M23TY/3$E42%]214-54E]$04E,
M62`_/B(\/W!H<"!I9B`H)&5V96YT+3YH87-296-U<E1Y<&4H2U)/3D],251(
M7U)%0U527T1!24Q9*2D@96-H;R`G(&-H96-K960](F-H96-K960B)R`_/B`O
M/CQL86)E;"!F;W(](G)E8W5R9&%I;'DB/B`\/W!H<"!E8VAO(%\H(D1A:6QY
M.B!296-U<G,@979E<GDB*2`_/B9N8G-P.SPO;&%B96P^"B`@("`@/&EN<'5T
M('1Y<&4](G1E>'0B(&YA;64](G)E8W5R7V1A:6QY7VEN=&5R=F%L(B!S:7IE
M/2(R(B!O;FME>7!R97-S/2)S971296-U<B@Q*3LB(&]N8VAA;F=E/2)S9712
M96-U<B@Q*3LB('9A;'5E/2(\/W!H<"!E8VAO("1E=F5N="T^:&%S4F5C=7)4
M>7!E*$M23TY/3$E42%]214-54E]$04E,62D@/R`D979E;G0M/F=E=%)E8W5R
M26YT97)V86PH*2`Z("<G(#\^(B`O/B9N8G-P.SP_<&AP(&5C:&\@7R@B9&%Y
M*',I(BD@/SX*("`@(#PO=&0^"B`@(#PO='(^"B`@(#QT<CX*("`@(#QT9"!C
M;&%S<STB;F]W<F%P(CX*("`@("`\:6YP=70@:60](G)E8W5R=V5E:VQY(B!T
M>7!E/2)R861I;R(@;F%M93TB<F5C=7(B(&]N8VQI8VL](G-E=$EN=&5R=F%L
M*"=R96-U<E]W965K;'E?:6YT97)V86PG*3LB('9A;'5E/2(\/W!H<"!E8VAO
M($M23TY/3$E42%]214-54E]7145+3%D@/SXB/#]P:'`@:68@*"1E=F5N="T^
M:&%S4F5C=7)4>7!E*$M23TY/3$E42%]214-54E]7145+3%DI*2!E8VAO("<@
M8VAE8VME9#TB8VAE8VME9"(G(#\^("\^/&QA8F5L(&9O<CTB<F5C=7)W965K
M;'DB/B`\/W!H<"!E8VAO(%\H(E=E96ML>3H@4F5C=7)S(&5V97)Y(BD@/SXF
M;F)S<#L\+VQA8F5L/@H@("`@(#QI;G!U="!T>7!E/2)T97AT(B!N86UE/2)R
M96-U<E]W965K;'E?:6YT97)V86PB('-I>F4](C(B(&]N:V5Y<')E<W,](G-E
M=%)E8W5R*#(I.R(@;VYC:&%N9V4](G-E=%)E8W5R*#(I.R(@=F%L=64](CP_
M<&AP(&5C:&\@)&5V96YT+3YH87-296-U<E1Y<&4H2U)/3D],251(7U)%0U52
M7U=%14M,62D@/R`D979E;G0M/F=E=%)E8W5R26YT97)V86PH*2`Z("<G(#\^
M(B`O/B9N8G-P.PH@("`@(#P_<&AP(&5C:&\@7R@B=V5E:RAS*2!O;CHB*2`_
M/CQB<B`O/B9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.PH@
M("`@(#QL86)E;"!F;W(](FUO(CX\/W!H<"!E8VAO(%\H(DUO(BD@/SX\+VQA
M8F5L/CQI;G!U="!I9#TB;6\B('1Y<&4](F-H96-K8F]X(B!N86UE/2)W965K
M;'E;72(@;VYC;&EC:STB<V5T26YT97)V86PH)W)E8W5R7W=E96ML>5]I;G1E
M<G9A;"<I.W-E=%)E8W5R*#(I.R(@=F%L=64](CP_<&AP(&5C:&\@2$]21$5?
M1$%415]-05-+7TU/3D1!62`_/B(\/W!H<"!I9B`H)&5V96YT+3YR96-U<D]N
M1&%Y*$A/4D1%7T1!5$5?34%32U]-3TY$05DI*2!E8VAO("<@8VAE8VME9#TB
M8VAE8VME9"(G(#\^("\^)FYB<W`["B`@("`@/&QA8F5L(&9O<CTB='4B/CP_
M<&AP(&5C:&\@7R@B5'4B*2`_/CPO;&%B96P^/&EN<'5T(&ED/2)T=2(@='EP
M93TB8VAE8VMB;W@B(&YA;64](G=E96ML>5M=(B!O;F-L:6-K/2)S971);G1E
M<G9A;"@G<F5C=7)?=V5E:VQY7VEN=&5R=F%L)RD[<V5T4F5C=7(H,BD[(B!V
M86QU93TB/#]P:'`@96-H;R!(3U)$15]$051%7TU!4TM?5%5%4T1!62`_/B(\
M/W!H<"!I9B`H)&5V96YT+3YR96-U<D]N1&%Y*$A/4D1%7T1!5$5?34%32U]4
M54531$%9*2D@96-H;R`G(&-H96-K960](F-H96-K960B)R`_/B`O/B9N8G-P
M.PH@("`@(#QL86)E;"!F;W(](G=E(CX\/W!H<"!E8VAO(%\H(E=E(BD@/SX\
M+VQA8F5L/CQI;G!U="!I9#TB=V4B('1Y<&4](F-H96-K8F]X(B!N86UE/2)W
M965K;'E;72(@;VYC;&EC:STB<V5T26YT97)V86PH)W)E8W5R7W=E96ML>5]I
M;G1E<G9A;"<I.W-E=%)E8W5R*#(I.R(@=F%L=64](CP_<&AP(&5C:&\@2$]2
M1$5?1$%415]-05-+7U=%1$Y%4T1!62`_/B(\/W!H<"!I9B`H)&5V96YT+3YR
M96-U<D]N1&%Y*$A/4D1%7T1!5$5?34%32U]7141.15-$05DI*2!E8VAO("<@
M8VAE8VME9#TB8VAE8VME9"(G(#\^("\^)FYB<W`["B`@("`@/&QA8F5L(&9O
M<CTB=&@B/CP_<&AP(&5C:&\@7R@B5&@B*2`_/CPO;&%B96P^/&EN<'5T(&ED
M/2)T:"(@='EP93TB8VAE8VMB;W@B(&YA;64](G=E96ML>5M=(B!O;F-L:6-K
M/2)S971);G1E<G9A;"@G<F5C=7)?=V5E:VQY7VEN=&5R=F%L)RD[<V5T4F5C
M=7(H,BD[(B!V86QU93TB/#]P:'`@96-H;R!(3U)$15]$051%7TU!4TM?5$A5
M4E-$05D@/SXB/#]P:'`@:68@*"1E=F5N="T^<F5C=7)/;D1A>2A(3U)$15]$
M051%7TU!4TM?5$A54E-$05DI*2!E8VAO("<@8VAE8VME9#TB8VAE8VME9"(G
M(#\^("\^)FYB<W`["B`@("`@/&QA8F5L(&9O<CTB9G(B/CP_<&AP(&5C:&\@
M7R@B1G(B*2`_/CPO;&%B96P^/&EN<'5T(&ED/2)F<B(@='EP93TB8VAE8VMB
M;W@B(&YA;64](G=E96ML>5M=(B!O;F-L:6-K/2)S971);G1E<G9A;"@G<F5C
M=7)?=V5E:VQY7VEN=&5R=F%L)RD[<V5T4F5C=7(H,BD[(B!V86QU93TB/#]P
M:'`@96-H;R!(3U)$15]$051%7TU!4TM?1E))1$%9(#\^(CP_<&AP(&EF("@D
M979E;G0M/G)E8W5R3VY$87DH2$]21$5?1$%415]-05-+7T92241!62DI(&5C
M:&\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@/SX@+SXF;F)S<#L*("`@("`\;&%B
M96P@9F]R/2)S82(^/#]P:'`@96-H;R!?*")382(I(#\^/"]L86)E;#X\:6YP
M=70@:60](G-A(B!T>7!E/2)C:&5C:V)O>"(@;F%M93TB=V5E:VQY6UTB(&]N
M8VQI8VL](G-E=$EN=&5R=F%L*"=R96-U<E]W965K;'E?:6YT97)V86PG*3MS
M971296-U<B@R*3LB('9A;'5E/2(\/W!H<"!E8VAO($A/4D1%7T1!5$5?34%3
M2U]305154D1!62`_/B(\/W!H<"!I9B`H)&5V96YT+3YR96-U<D]N1&%Y*$A/
M4D1%7T1!5$5?34%32U]305154D1!62DI(&5C:&\@)R!C:&5C:V5D/2)C:&5C
M:V5D(B<@/SX@+SXF;F)S<#L*("`@("`\;&%B96P@9F]R/2)S=2(^/#]P:'`@
M96-H;R!?*")3=2(I(#\^/"]L86)E;#X\:6YP=70@:60](G-U(B!T>7!E/2)C
M:&5C:V)O>"(@;F%M93TB=V5E:VQY6UTB(&]N8VQI8VL](G-E=$EN=&5R=F%L
M*"=R96-U<E]W965K;'E?:6YT97)V86PG*3MS971296-U<B@R*3LB('9A;'5E
M/2(\/W!H<"!E8VAO($A/4D1%7T1!5$5?34%32U]354Y$05D@/SXB/#]P:'`@
M:68@*"1E=F5N="T^<F5C=7)/;D1A>2A(3U)$15]$051%7TU!4TM?4U5.1$%9
M*2D@96-H;R`G(&-H96-K960](F-H96-K960B)R`_/B`O/B9N8G-P.PH@("`@
M/"]T9#X*("`@/"]T<CX*("`@/'1R/@H@("`@/'1D(&-L87-S/2)N;W=R87`B
M/@H@("`@(#QI;G!U="!I9#TB<F5C=7)M;VYT:&1A>2(@='EP93TB<F%D:6\B
M(&YA;64](G)E8W5R(B!O;F-L:6-K/2)S971);G1E<G9A;"@G<F5C=7)?9&%Y
M7V]F7VUO;G1H7VEN=&5R=F%L)RD[(B!V86QU93TB/#]P:'`@96-H;R!+4D].
M3TQ)5$A?4D5#55)?1$%97T]&7TU/3E1((#\^(CP_<&AP(&EF("@D979E;G0M
M/FAA<U)E8W5R5'EP92A+4D].3TQ)5$A?4D5#55)?1$%97T]&7TU/3E1(*2D@
M96-H;R`G(&-H96-K960](F-H96-K960B)R`_/B`O/CQL86)E;"!F;W(](G)E
M8W5R;6]N=&AD87DB/B`\/W!H<"!E8VAO(%\H(DUO;G1H;'DZ(%)E8W5R<R!E
M=F5R>2(I(#\^)FYB<W`[/"]L86)E;#X*("`@("`\:6YP=70@='EP93TB=&5X
M="(@;F%M93TB<F5C=7)?9&%Y7V]F7VUO;G1H7VEN=&5R=F%L(B!S:7IE/2(R
M(B!O;FME>7!R97-S/2)S971296-U<B@S*3LB(&]N8VAA;F=E/2)S971296-U
M<B@S*3LB('9A;'5E/2(\/W!H<"!E8VAO("1E=F5N="T^:&%S4F5C=7)4>7!E
M*$M23TY/3$E42%]214-54E]$05E?3T9?34].5$@I(#\@)&5V96YT+3YG9712
M96-U<DEN=&5R=F%L*"D@.B`G)R`_/B(@+SXF;F)S<#L\/W!H<"!E8VAO(%\H
M(FUO;G1H*',I(BD@+B`G("<@+B!?*")O;B!T:&4@<V%M92!D871E(BD@/SX*
M("`@(#PO=&0^"B`@(#PO='(^"B`@(#QT<CX*("`@(#QT9"!C;&%S<STB;F]W
M<F%P(CX*("`@("`\:6YP=70@:60](G)E8W5R;6]N=&AW965K(B!T>7!E/2)R
M861I;R(@;F%M93TB<F5C=7(B(&]N8VQI8VL](G-E=$EN=&5R=F%L*"=R96-U
M<E]W965K7V]F7VUO;G1H7VEN=&5R=F%L)RD[(B!V86QU93TB/#]P:'`@96-H
M;R!+4D].3TQ)5$A?4D5#55)?5T5%2U]/1E]-3TY42"`_/B(\/W!H<"!I9B`H
M)&5V96YT+3YH87-296-U<E1Y<&4H2U)/3D],251(7U)%0U527U=%14M?3T9?
M34].5$@I*2!E8VAO("<@8VAE8VME9#TB8VAE8VME9"(G(#\^("\^/&QA8F5L
M(&9O<CTB<F5C=7)M;VYT:'=E96LB/B`\/W!H<"!E8VAO(%\H(DUO;G1H;'DZ
M(%)E8W5R<R!E=F5R>2(I(#\^)FYB<W`[/"]L86)E;#X*("`@("`\:6YP=70@
M='EP93TB=&5X="(@;F%M93TB<F5C=7)?=V5E:U]O9E]M;VYT:%]I;G1E<G9A
M;"(@<VEZ93TB,B(@;VYK97EP<F5S<STB<V5T4F5C=7(H-"D[(B!O;F-H86YG
M93TB<V5T4F5C=7(H-"D[(B!V86QU93TB/#]P:'`@96-H;R`D979E;G0M/FAA
M<U)E8W5R5'EP92A+4D].3TQ)5$A?4D5#55)?5T5%2U]/1E]-3TY42"D@/R`D
M979E;G0M/F=E=%)E8W5R26YT97)V86PH*2`Z("<G(#\^(B`O/B9N8G-P.SP_
M<&AP(&5C:&\@7R@B;6]N=&@H<RDB*2`N("<@)R`N(%\H(F]N('1H92!S86UE
M('=E96MD87DB*2`_/@H@("`@/"]T9#X*("`@/"]T<CX*("`@/'1R/@H@("`@
M/'1D(&-L87-S/2)N;W=R87`B/@H@("`@(#QI;G!U="!I9#TB<F5C=7)Y96%R
M(B!T>7!E/2)R861I;R(@;F%M93TB<F5C=7(B(&]N8VQI8VL](G-E=$EN=&5R
M=F%L*"=R96-U<E]Y96%R;'E?:6YT97)V86PG*3LB('9A;'5E/2(\/W!H<"!E
M8VAO($M23TY/3$E42%]214-54E]914%23%D@/SXB/#]P:'`@:68@*"1E=F5N
M="T^:&%S4F5C=7)4>7!E*$M23TY/3$E42%]214-54E]914%23%DI*2!E8VAO
M("<@8VAE8VME9#TB8VAE8VME9"(G(#\^("\^/&QA8F5L(&9O<CTB<F5C=7)Y
M96%R(CX@/#]P:'`@96-H;R!?*")996%R;'DZ(%)E8W5R<R!E=F5R>2(I(#\^
M)FYB<W`[/"]L86)E;#X*("`@("`\:6YP=70@='EP93TB=&5X="(@;F%M93TB
M<F5C=7)?>65A<FQY7VEN=&5R=F%L(B!S:7IE/2(R(B!O;FME>7!R97-S/2)S
M971296-U<B@U*3LB(&]N8VAA;F=E/2)S971296-U<B@U*3LB('9A;'5E/2(\
M/W!H<"!E8VAO("1E=F5N="T^:&%S4F5C=7)4>7!E*$M23TY/3$E42%]214-5
M4E]914%23%DI(#\@)&5V96YT+3YG971296-U<DEN=&5R=F%L*"D@.B`G)R`_
M/B(@+SXF;F)S<#L\/W!H<"!E8VAO(%\H(GEE87(H<RDB*2`_/@H@("`@/"]T
M9#X*("`@/"]T<CX*("`\+W1A8FQE/@H@/"]T9#X*/"]T<CX*"CPA+2T@<F5C
M=7(@96YD(&1A=&4@+2T^"CQT<CX*(#QT9"!A;&EG;CTB<FEG:'0B(&-L87-S
M/2)L:6=H="(@=F%L:6=N/2)T;W`B/@H@("`@/'-T<F]N9SX\/W!H<"!E8VAO
M($AO<F1E.CIL86)E;"@G<F5C=7)?96YD9&%T95MY96%R72<L(%\H(E)E8W5R
M(%5N=&EL(BDI(#\^)FYB<W`[)FYB<W`[/"]S=')O;F<^"B`\+W1D/@H@/'1D
M(&-O;'-P86X](C,B/@H@(#QI;G!U="!I9#TB<F5C=7)N;V5N9"(@='EP93TB
M<F%D:6\B(&YA;64](G)E8W5R7V5N9&1A=&5?='EP92(@=F%L=64](FYO;F4B
M/#]P:'`@96-H;R`H)&5V96YT+3YH87-296-U<D5N9"@I(#\@)R<@.B`G(&-H
M96-K960](F-H96-K960B)RD@/SX@+SX\;&%B96P@9F]R/2)R96-U<FYO96YD
M(CX@/#]P:'`@96-H;R!?*").;R!E;F0@9&%T92(I(#\^/"]L86)E;#X\8G(@
M+SX*("`\:6YP=70@='EP93TB<F%D:6\B(&YA;64](G)E8W5R7V5N9&1A=&5?
M='EP92(@=F%L=64](F1A=&4B/#]P:'`@96-H;R`H)&5V96YT+3YH87-296-U
M<D5N9"@I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)RD@/SX@+SX*("`\
M/W!H<"!E8VAO("1E=F5N="T^:'1M;"@G<F5C=7)?96YD9&%T95MY96%R72<I
M(#\^("T@/#]P:'`@96-H;R`D979E;G0M/FAT;6PH)W)E8W5R7V5N9&1A=&5;
M;6]N=&A=)RD@/SX@+2`\/W!H<"!E8VAO("1E=F5N="T^:'1M;"@G<F5C=7)?
M96YD9&%T95MD87E=)RD@/SX*/#]P:'`@:68@*"@D8G)O=W-E<BT^:7-"<F]W
M<V5R*"=M<VEE)RD@)B8@)&)R;W=S97(M/F=E=$UA:F]R*"D@/CT@-"D@?'P*
M("`@("`@("`@("@D8G)O=W-E<BT^:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8@
M)&)R;W=S97(M/F=E=$UA:F]R*"D@/CT@-2DI.B`_/@H@("`\<W!A;B!I9#TB
M<F5C=7)?96YD7W=D87DB/CPO<W!A;CX*("`@/'-C<FEP="!T>7!E/2)T97AT
M+VIA=F%S8W)I<'0B/@H@("`@=7!D871E5V1A>2@B<F5C=7)?96YD7W=D87DB
M*3L*("`@/"]S8W)I<'0^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H)$=,
M3T)!3%-;)V)R;W=S97(G72T^:&%S1F5A='5R92@G9&]M)RDI('L*("`@(&5C
M:&\@)SPO=&0^/'1D/B<["B`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G;W!E
M;E]C86QE;F1A<BYJ<R<L("=H;W)D92<I.PH@("`@96-H;R!(;W)D93HZ;&EN
M:R@G(R<L(%\H(E-E;&5C="!A(&1A=&4B*2P@)R<L("<G+"`G;W!E;D-A;&5N
M9&%R*%PG<F5C=7)?96YD9&%T96EM9UPG+"!<)W)E8W5R7V5N9&1A=&5<)RP@
M7"<G("X@861D<VQA<VAE<R@D979E;G0M/FIS*"=R96-U<E]E;F1D871E)RDI
M("X@)UPG*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G8V%L96YD
M87(N<&YG)RP@7R@B4V5T(')E8W5R<F5N8V4@96YD(&1A=&4B*2P@)V%L:6=N
M/2)T;W`B(&ED/2)R96-U<E]E;F1D871E:6UG(B<L("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<["GT@/SX*
M(#PO=&0^"CPO='(^"@H\/W!H<"!I9B`H)&-O;F9;)VUE=&%D871A)UU;)VME
M>7=O<F1S)UTI.B`_/@H\(2TM(&ME>7=O<F1S("TM/@H\='(@8VQA<W,](G-M
M86QL:&5A9&5R(CX*(#QT9"!C;VQS<&%N/2(U(B!C;&%S<STB:&5A9&5R(CX*
M("`\<W!A;B!C;&%S<STB<VUA;&QH96%D97(B/CP_<&AP(&5C:&\@7R@B/'-T
M<F]N9SY+97EW;W)D<SPO<W1R;VYG/B`H;W!T:6]N86PI(BD@/SX\+W-P86X^
M"B`\+W1D/@H\+W1R/@H\='(^"B`\=&0^/"]T9#X*(#QT9"!C;VQS<&%N/2(T
M(CX*("`\=&%B;&4@8V5L;'-P86-I;F<](C(B/@H@("`\/W!H<"!I;F-L=61E
M7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+V-O;F9I9R]K97EW;W)D<RYP:'`G
M.R`D8V]U;G0@/2`P(#\^"B`@(#P_<&AP(&9O<F5A8V@@*"1K97EW;W)D<R!A
M<R`D8V%T(#T^("1L:7-T*3H*("`@("`@(&EF("@D8V]U;G0@)2`S(#T](#`I
M.B`_/@H@("`\='(^"B`@(#P_<&AP(&5N9&EF.R`_/@H@("`@/'1D('9A;&EG
M;CTB=&]P(CX*("`@("`\<W1R;VYG/CP_<&AP(&5C:&\@)&-A="`_/CPO<W1R
M;VYG/CQB<B`O/@H@("`@/#]P:'`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H
M)&QI<W0I.R`K*R1K*3H@/SX*("`@("`\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&ED/2)K97EW;W)D/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K*2`_
M/B(@;F%M93TB:V5Y=V]R9'-;72(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D;&ES=%LD:UTI(#\^(CP_<&AP(&EF("@D979E;G0M/FAA
M<TME>7=O<F0H)&QI<W1;)&M=*2D@96-H;R`G(&-H96-K960](F-H96-K960B
M)R`_/B`O/@H@("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=K97EW;W)D
M)R`N("1K+"!H=&UL<W!E8VEA;&-H87)S*"1L:7-T6R1K72DI(#\^/&)R("\^
M"B`@("`\/W!H<"!E;F1F;W([(#\^"B`@("`\+W1D/@H@("`\/W!H<"!I9B`H
M*"1C;W5N="`E(#,@/3T@,BD@?'P@*"1C;W5N="`]/2!C;W5N="@D:V5Y=V]R
M9',I("T@,2DI.B`_/@H@("`\+W1R/@H@("`\/W!H<"!E;F1I9CL@*RLD8V]U
M;G0@/SX*("`@/#]P:'`@96YD9F]R96%C:#L@/SX*("`\+W1A8FQE/@H@/"]T
M9#X*/"]T<CX*/#]P:'`@96YD:68[(#\^"@H\(2TM(&)U='1O;G,@+2T^"CQT
M<CX*(#QT9#X\+W1D/@H@/'1D(&-O;'-P86X](C0B/@H@(#P_<&AP(&5C:&\@
M:6UP;&]D92@B7&XB+"`D8G5T=&]N<RD@/SX*("`\:6YP=70@='EP93TB<W5B
M;6ET(B!N86UE/2)C86YC96PB(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(D-A;F-E;"(I(#\^(B!O;F-L:6-K/2)S96QF+FQO8V%T:6]N
M(#T@)SP_<&AP(&5C:&\@)&-A;F-E;'5R;"`_/B<[(')E='5R;B!F86QS93LB
M("\^"B`@/&EN<'5T('1Y<&4](F)U='1O;B(@;F%M93TB<F5S971"=71T;VXB
M(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E<V5T('1O
M($1E9F%U;'1S(BD@/SXB(&]N8VQI8VL](F1O8W5M96YT+F5V96YT+G)E<V5T
M*"D[('5P9&%T95=D87DH)W-T87)T7W=D87DG*3L@=7!D871E5V1A>2@G96YD
M7W=D87DG*3LB("\^"B`@/"]T9#X*(#PO='(^"CPO=&%B;&4^"CPO9F]R;3X*
M/"]D:78^"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0ID
M;V-U;65N="YE=F5N="YT:71L92YF;V-U<R@I.PHO+RTM/@H\+W-C<FEP=#X*
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]E9&ET+V5D
M:71?=&EM97-P86XN:6YC````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C0U-0`Q,#0Q-S,V
M,C<U,P`P,C0W,#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/"$M+2!T:6UE<W!A;B!H96%D97(@+2T^"CQT<CX*(#QT9"!A
M;&EG;CTB;&5F="(@8V]L<W!A;CTB-2(@8VQA<W,](FAE861E<B(^"B`@/'-P
M86X@8VQA<W,](G-M86QL:&5A9&5R(CX\<W1R;VYG/CP_<&AP(&5C:&\@7R@B
M5&EM92!S<&%N(BD@/SX\+W-T<F]N9SX\+W-P86X^"B`\+W1D/@H\+W1R/@H*
M/"$M+2!S=&%R="!D871E("TM/@H\='(^"B`\=&0@86QI9VX](G)I9VAT(B!C
M;&%S<STB;&EG:'0B/@H@("`@/'-T<F]N9SX\/W!H<"!E8VAO($AO<F1E.CIL
M86)E;"@G<W1A<G1;>65A<ETG+"!?*")3=&%?<G0B*2D@/SXF;F)S<#LF;F)S
M<#L\+W-T<F]N9SX*(#PO=&0^"B`\=&0@8V]L<W!A;CTB,B(@86QI9VX](G)I
M9VAT(CX\/W!H<"!E8VAO(%\H(D]N(BD@/SXF;F)S<#L\+W1D/@H@/'1D(&%L
M:6=N/2)L969T(CX*("`\/W!H<"!E8VAO("1E=F5N="T^:'1M;"@G<W1A<G1;
M>65A<ETG*2`_/@H@("T*("`\/W!H<"!E8VAO("1E=F5N="T^:'1M;"@G<W1A
M<G1;;6]N=&A=)RD@/SX*("`M"B`@/#]P:'`@96-H;R`D979E;G0M/FAT;6PH
M)W-T87)T6V1A>5TG*2`_/@H\/W!H<"!I9B`H*"1B<F]W<V5R+3YI<T)R;W=S
M97(H)VUS:64G*2`F)B`D8G)O=W-E<BT^9V5T36%J;W(H*2`^/2`T*2!\?`H@
M("`@("`@("`@*"1B<F]W<V5R+3YI<T)R;W=S97(H)VUO>FEL;&$G*2`F)B`D
M8G)O=W-E<BT^9V5T36%J;W(H*2`^/2`U*2DZ(#\^"B`@/'-P86X@:60](G-T
M87)T7W=D87DB/CPO<W!A;CX*("`\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C
M<FEP="(^"B`@('5P9&%T95=D87DH)W-T87)T7W=D87DG*3L*("`\+W-C<FEP
M=#X*/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("@D1TQ/0D%,4ULG8G)O=W-E
M<B==+3YH87-&96%T=7)E*"=D;VTG*2D@>PH@("`@96-H;R`G/"]T9#X\=&0^
M)SL*("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=O<&5N7V-A;&5N9&%R+FIS
M)RP@)VAO<F1E)RD["B`@("!E8VAO("<\9&EV(&ED/2)G;W1O(B!C;&%S<STB
M8V]N=')O;"(@<W1Y;&4](G!O<VET:6]N.F%B<V]L=71E.W9I<VEB:6QI='DZ
M:&ED9&5N.W!A9&1I;F<Z,7!X(CX\+V1I=CXG.PH@("`@96-H;R!(;W)D93HZ
M;&EN:R@G(R<L(%\H(E-E;&5C="!A(&1A=&4B*2P@)R<L("<G+"`G;W!E;D-A
M;&5N9&%R*%PG<W1A<G1I;6=<)RP@7"=S=&%R=%PG+"!<)R<@+B!A9&1S;&%S
M:&5S*"1E=F5N="T^:G,H)W-T87)T)RDI("X@)UPG*3L@<F5T=7)N(&9A;'-E
M.R<I("X@2&]R9&4Z.FEM9R@G8V%L96YD87(N<&YG)RP@7R@B4V5T('-T87)T
M(&1A=&4B*2P@)V%L:6=N/2)T;W`B(&ED/2)S=&%R=&EM9R(G+"`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG
M.PI](#\^"B`\+W1D/@H\+W1R/@H*/"$M+2!S=&%R="!T:6UE("TM/@H\='(^
M"B`\=&0^)FYB<W`[/"]T9#X*(#QT9"!C;VQS<&%N/2(R(B!A;&EG;CTB<FEG
M:'0B/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=S=&%R=%]H;W5R)RP@7R@B
M070B*2D@/SXF;F)S<#L\+W1D/@H@/'1D(&%L:6=N/2)L969T(B!C;VQS<&%N
M/2(R(CX*("`\/W!H<"!E8VAO("1E=F5N="T^:'1M;"@G<W1A<G1?:&]U<B<I
M(#\^)FYB<W`[.B9N8G-P.SP_<&AP(&5C:&\@)&5V96YT+3YH=&UL*"=S=&%R
M=%]M:6XG*2`_/@H@(#P_<&AP"B`@:68@*"$D<')E9G,M/F=E=%9A;'5E*"=T
M=V5N='E&;W5R)RDI('L*("`@("`@:68@*"1E=F5N="T^<W1A<G0M/FAO=7(@
M/"`Q,BD@>PH@("`@("`@("`@)&%M(#T@)R!C:&5C:V5D/2)C:&5C:V5D(B<[
M"B`@("`@("`@("`D<&T@/2`G)SL*("`@("`@?2!E;'-E('L*("`@("`@("`@
M("1A;2`]("<G.PH@("`@("`@("`@)'!M(#T@)R!C:&5C:V5D/2)C:&5C:V5D
M(B<["B`@("`@('T*("`_/@H@(#QI;G!U="!I9#TB86TB('1Y<&4](G)A9&EO
M(B!N86UE/2)A;5]P;2(@=F%L=64](D%-(CP_<&AP(&5C:&\@)&%M(#\^(&]N
M8VQI8VL](F1O8W5M96YT+F5V96YT+G=H;VQE7V1A>2YC:&5C:V5D/69A;'-E
M.W5P9&%T945N9$1A=&4H*3LB("\^/&QA8F5L(&9O<CTB86TB(&]N8VQI8VL]
M(F1O8W5M96YT+F5V96YT+G=H;VQE7V1A>2YC:&5C:V5D/69A;'-E.W5P9&%T
M945N9$1A=&4H*3LB/D%-/"]L86)E;#X*("`\:6YP=70@:60](G!M(B!T>7!E
M/2)R861I;R(@;F%M93TB86U?<&TB('9A;'5E/2)032(\/W!H<"!E8VAO("1P
M;2`_/B!O;F-L:6-K/2)D;V-U;65N="YE=F5N="YW:&]L95]D87DN8VAE8VME
M9#UF86QS93MU<&1A=&5%;F1$871E*"D[(B`O/CQL86)E;"!F;W(](G!M(B!O
M;F-L:6-K/2)D;V-U;65N="YE=F5N="YW:&]L95]D87DN8VAE8VME9#UF86QS
M93MU<&1A=&5%;F1$871E*"D[(CY033PO;&%B96P^"B`@/#]P:'`@?2`_/@H@
M/"]T9#X*/"]T<CX*"CPA+2T@96YD(&1A=&4@+2T^"CQT<CX*(#QT9"!A;&EG
M;CTB<FEG:'0B(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO($AO
M<F1E.CIL86)E;"@G9'5R871I;VXG+"!?*")%;E]D(BDI(#\^)FYB<W`[)FYB
M<W`[/"]S=')O;F<^/"]T9#X*(#QT9"!A;&EG;CTB;&5F="(^"B`@/&EN<'5T
M('1Y<&4](G)A9&EO(B!N86UE/2)E;F1?;W)?9'5R(B!I9#TB9'5R871I;VXB
M('9A;'5E/2(P(B!C:&5C:V5D/2)C:&5C:V5D(B`O/@H@/"]T9#X*(#QT9"!A
M;&EG;CTB<FEG:'0B/@H@(#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=E;F1;
M>65A<ETG+"!?*")/;B(I*2`_/B9N8G-P.PH@/"]T9#X*(#QT9"!A;&EG;CTB
M;&5F="(^"B`@/#]P:'`@96-H;R`D979E;G0M/FAT;6PH)V5N9%MY96%R72<I
M(#\^"B`@+0H@(#P_<&AP(&5C:&\@)&5V96YT+3YH=&UL*"=E;F1;;6]N=&A=
M)RD@/SX*("`M"B`@/#]P:'`@96-H;R`D979E;G0M/FAT;6PH)V5N9%MD87E=
M)RD@/SX*/#]P:'`@:68@*"@D8G)O=W-E<BT^:7-"<F]W<V5R*"=M<VEE)RD@
M)B8@)&)R;W=S97(M/F=E=$UA:F]R*"D@/CT@-"D@?'P*("`@("`@("`@("@D
M8G)O=W-E<BT^:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8@)&)R;W=S97(M/F=E
M=$UA:F]R*"D@/CT@-2DI.B`_/@H@(#QS<&%N(&ED/2)E;F1?=V1A>2(^/"]S
M<&%N/@H@(#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*("`@=7!D
M871E5V1A>2@G96YD7W=D87DG*3L*("`\+W-C<FEP=#X*/#]P:'`@96YD:68[
M(#\^"CP_<&AP(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E
M*"=D;VTG*2D@>PH@("`@96-H;R`G/"]T9#X\=&0@<F]W<W!A;CTB,B(@=F%L
M:6=N/2)T;W`B/B<["B`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G;W!E;E]C
M86QE;F1A<BYJ<R<L("=H;W)D92<I.PH@("`@96-H;R!(;W)D93HZ;&EN:R@G
M(R<L(%\H(E-E;&5C="!A(&1A=&4B*2P@)R<L("<G+"`G;W!E;D-A;&5N9&%R
M*%PG96YD:6UG7"<L(%PG96YD7"<L(%PG)R`N(&%D9'-L87-H97,H)&5V96YT
M+3YJ<R@G96YD)RDI("X@)UPG*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z
M.FEM9R@G8V%L96YD87(N<&YG)RP@7R@B4V5T(&5N9"!D871E(BDL("=A;&EG
M;CTB=&]P(B!I9#TB96YD:6UG(B<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG
M971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<["GT@/SX*(#PO=&0^"CPO
M='(^"@H\(2TM(&5N9"!T:6UE("TM/@H\='(^"B`\=&0^)FYB<W`[/"]T9#X*
M(#QT9"!A;&EG;CTB;&5F="(^)FYB<W`[/"]T9#X*(#QT9"!A;&EG;CTB<FEG
M:'0B/@H@(#P_<&AP(&5C:&\@7R@B070B*2`_/B9N8G-P.PH@/"]T9#X*(#QT
M9"!C;VQS<&%N/2(R(B!A;&EG;CTB;&5F="(^"B`@/#]P:'`@96-H;R`D979E
M;G0M/FAT;6PH)V5N9%]H;W5R)RD@/SXF;F)S<#LZ)FYB<W`[/#]P:'`@96-H
M;R`D979E;G0M/FAT;6PH)V5N9%]M:6XG*2`_/@H@(#P_<&AP"B`@:68@*"$D
M<')E9G,M/F=E=%9A;'5E*"=T=V5N='E&;W5R)RDI('L*("`@("`@:68@*"1E
M=F5N="T^96YD+3YH;W5R(#P@,3(I('L*("`@("`@("`@("1A;2`]("<@8VAE
M8VME9#TB8VAE8VME9"(G.PH@("`@("`@("`@)'!M(#T@)R<["B`@("`@('T@
M96QS92!["B`@("`@("`@("`D86T@/2`G)SL*("`@("`@("`@("1P;2`]("<@
M8VAE8VME9#TB8VAE8VME9"(G.PH@("`@("!]"B`@/SX*("`\:6YP=70@:60]
M(F5A;2(@='EP93TB<F%D:6\B(&YA;64](F5N9%]A;5]P;2(@=F%L=64](D%-
M(CP_<&AP(&5C:&\@)&%M(#\^(&]N8VQI8VL](F1O8W5M96YT+F5V96YT+F5N
M9%]O<E]D=7);,%TN8VAE8VME9#UT<G5E.W5P9&%T941U<F%T:6]N*"DB("\^
M/&QA8F5L(&9O<CTB96%M(B!O;F-L:6-K/2)D;V-U;65N="YE=F5N="YE;F1?
M;W)?9'5R6S!=+F-H96-K960]=')U93MU<&1A=&5$=7)A=&EO;B@I(CY!33PO
M;&%B96P^"B`@/&EN<'5T(&ED/2)E<&TB('1Y<&4](G)A9&EO(B!N86UE/2)E
M;F1?86U?<&TB('9A;'5E/2)032(\/W!H<"!E8VAO("1P;2`_/B!O;F-L:6-K
M/2)D;V-U;65N="YE=F5N="YE;F1?;W)?9'5R6S!=+F-H96-K960]=')U93MU
M<&1A=&5$=7)A=&EO;B@I(B`O/CQL86)E;"!F;W(](F5P;2(@;VYC;&EC:STB
M9&]C=6UE;G0N979E;G0N96YD7V]R7V1U<ELP72YC:&5C:V5D/71R=64[=7!D
M871E1'5R871I;VXH*2(^4$T\+VQA8F5L/@H@(#P_<&AP('T@/SX*(#PO=&0^
M"CPO='(^"@H\(2TM(&1U<F%T:6]N("TM/@H\='(^"B`\=&0@86QI9VX](G)I
M9VAT(B!V86QI9VX](G1O<"(@8VQA<W,](FQI9VAT(CX\<W1R;VYG/CP_<&AP
M(&5C:&\@2&]R9&4Z.FQA8F5L*"=D=7)A=&EO;B<L(%\H(D1U<F%T:6]N(BDI
M(#\^)FYB<W`[)FYB<W`[/"]S=')O;F<^/"]T9#X*(#QT9"!A;&EG;CTB;&5F
M="(@=F%L:6=N/2)T;W`B/@H@(#QI;G!U="!T>7!E/2)R861I;R(@;F%M93TB
M96YD7V]R7V1U<B(@=F%L=64](C$B("\^"B`\+W1D/@H@/'1D/B9N8G-P.SPO
M=&0^"B`\=&0@86QI9VX](FQE9G0B('9A;&EG;CTB=&]P(CX*("`\:6YP=70@
M:60](F%L;&1A>2(@;F%M93TB=VAO;&5?9&%Y(B!T>7!E/2)C:&5C:V)O>"(@
M=F%L=64](C$B(&]N8VQI8VL](G-E=%=H;VQE1&%Y*'1H:7,N=F%L=64I.R!U
M<&1A=&5%;F1$871E*"D[(&1O8W5M96YT+F5V96YT+F5N9%]O<E]D=7);,5TN
M8VAE8VME9"`]('1R=64B/#]P:'`@)&1U<B`]("1E=F5N="T^9V5T1'5R871I
M;VXH*3L@:68@*"1D=7(M/G=H;VQE1&%Y*2!E8VAO("<@8VAE8VME9#TB8VAE
M8VME9"(G(#\^("\^"B`@/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)V%L;&1A
M>2<L(%\H(D%L;"!D87DB*2D@/SX\8G(@+SX*("`\/W!H<"!P<FEN=&8H7R@B
M)7,@1&%Y*',I("5S($AO=7(H<RD@)7,@36EN=71E<R(I+"`D979E;G0M/FAT
M;6PH)V1U<E]D87DG*2P@)&5V96YT+3YH=&UL*"=D=7)?:&]U<B<I+"`D979E
M;G0M/FAT;6PH)V1U<E]M:6XG*2D@/SX*/#]P:'`@:68@*"1'3$]"04Q36R=B
M<F]W<V5R)UTM/FAA<T9E871U<F4H)V1O;2<I*3H@/SX*(#PO=&0^"B`\=&0@
M<F]W<W!A;CTB,B(@=F%L:6=N/2)T;W`B(&%L:6=N/2)R:6=H="(^)FYB<W`[
M"CP_<&AP(&5N9&EF.R`_/@H@/"]T9#X*/"]T<CX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O
M;F]L:71H+W1E;7!L871E<R]E9&ET+VIA=F%S8W)I<'0N:6YC````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`R,3,W-0`Q,#0Q-S,V,C<U,P`P,C0R,C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`@96-H;R`D
M8TUA;F%G97(M/F=E=$IA=F%38W)I<'0H)V5V96YT)RP@)V-A=&5G;W)Y)RD@
M/SX*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H*/#]P
M:'`@:68@*"%5=&EL.CIN;VY);G!U=%9A<B@G:7-S96%R8V@G*2DZ(#\^"@IF
M=6YC=&EO;B!S971);G1E<G9A;"AF:65L9"D*>PH@("`@96QT(#T@979A;"@B
M9&]C=6UE;G0N979E;G0N(B`K(&9I96QD*3L*("`@(&EF("AE;'0N=F%L=64@
M/3T@(B(I('L*("`@("`@("!E;'0N=F%L=64@/2`Q.PH@("`@?0H*("`@(&EF
M("AF:65L9"`]/2`G<F5C=7)?9&%I;'E?:6YT97)V86PG*2!C;&5A<D9I96QD
M<R@Q*3L*("`@(&5L<V4@:68@*&9I96QD(#T]("=R96-U<E]W965K;'E?:6YT
M97)V86PG*2!C;&5A<D9I96QD<R@R*3L*("`@(&5L<V4@:68@*&9I96QD(#T]
M("=R96-U<E]D87E?;V9?;6]N=&A?:6YT97)V86PG*2!C;&5A<D9I96QD<R@S
M*3L*("`@(&5L<V4@:68@*&9I96QD(#T]("=R96-U<E]W965K7V]F7VUO;G1H
M7VEN=&5R=F%L)RD@8VQE87)&:65L9',H-"D["B`@("!E;'-E(&EF("AF:65L
M9"`]/2`G<F5C=7)?>65A<FQY7VEN=&5R=F%L)RD@8VQE87)&:65L9',H-2D[
M"GT*"F9U;F-T:6]N('-E=%)E8W5R*&EN9&5X*0I["B`@("!D;V-U;65N="YE
M=F5N="YR96-U<EMI;F1E>%TN8VAE8VME9"`]('1R=64["B`@("!C;&5A<D9I
M96QD<RAI;F1E>"D["GT*"F9U;F-T:6]N(&-L96%R1FEE;&1S*&EN9&5X*0I[
M"B`@("!I9B`H:6YD97@@(3T@,2D@9&]C=6UE;G0N979E;G0N<F5C=7)?9&%I
M;'E?:6YT97)V86PN=F%L=64@/2`G)SL*("`@(&EF("AI;F1E>"`A/2`R*2![
M"B`@("`@("`@9&]C=6UE;G0N979E;G0N<F5C=7)?=V5E:VQY7VEN=&5R=F%L
M+G9A;'5E(#T@)R<["B`@("`@("`@9F]R("AV87(@:2`](#`[(&D@/"!D;V-U
M;65N="YE=F5N="YE;&5M96YT<RYL96YG=&@[(&DK*RD@>PH@("`@("`@("`@
M("!I9B`H9&]C=6UE;G0N979E;G0N96QE;65N='-;:5TN;F%M92`]/2`G=V5E
M:VQY6UTG*2!["B`@("`@("`@("`@("`@("!D;V-U;65N="YE=F5N="YE;&5M
M96YT<UMI72YC:&5C:V5D(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"B`@("!I9B`H:6YD97@@(3T@,RD@9&]C=6UE;G0N979E;G0N
M<F5C=7)?9&%Y7V]F7VUO;G1H7VEN=&5R=F%L+G9A;'5E(#T@)R<["B`@("!I
M9B`H:6YD97@@(3T@-"D@9&]C=6UE;G0N979E;G0N<F5C=7)?=V5E:U]O9E]M
M;VYT:%]I;G1E<G9A;"YV86QU92`]("<G.PH@("`@:68@*&EN9&5X("$](#4I
M(&1O8W5M96YT+F5V96YT+G)E8W5R7WEE87)L>5]I;G1E<G9A;"YV86QU92`]
M("<G.PI]"@H\/W!H<"!E;F1I9CL@/SX*"F9U;F-T:6]N('-E=%=H;VQE1&%Y
M*'=H;VQE1&%Y*0I["B`@("!I9B`H=VAO;&5$87D@/3T@,2D@>PH\/W!H<"!I
M9B`H)'!R969S+3YG971686QU92@G='=E;G1Y1F]U<B<I*3H@/SX*("`@("`@
M("!D;V-U;65N="YE=F5N="YS=&%R=%]H;W5R+G-E;&5C=&5D26YD97@@/2`P
M.PH\/W!H<"!E;'-E.B`_/@H@("`@("`@(&1O8W5M96YT+F5V96YT+G-T87)T
M7VAO=7(N<V5L96-T961);F1E>"`](#$Q.PH@("`@("`@(&1O8W5M96YT+F5V
M96YT+F%M7W!M6S!=+F-H96-K960@/2!T<G5E.PH\/W!H<"!E;F1I9CL@/SX*
M("`@("`@("!D;V-U;65N="YE=F5N="YS=&%R=%]M:6XN<V5L96-T961);F1E
M>"`](#`["B`@("`@("`@9&]C=6UE;G0N979E;G0N9'5R7V1A>2YS96QE8W1E
M9$EN9&5X(#T@,#L*("`@("`@("!D;V-U;65N="YE=F5N="YD=7)?:&]U<BYS
M96QE8W1E9$EN9&5X(#T@,C,["B`@("`@("`@9&]C=6UE;G0N979E;G0N9'5R
M7VUI;BYS96QE8W1E9$EN9&5X(#T@,3(["B`@("!]"GT*"F9U;F-T:6]N('5P
M9&%T95=D87DH<W!A;BD*>PH\/W!H<"!I9B`H*"1'3$]"04Q36R=B<F]W<V5R
M)UTM/FES0G)O=W-E<B@G;7-I92<I("8F("1'3$]"04Q36R=B<F]W<V5R)UTM
M/F=E=$UA:F]R*"D@/CT@-"D@?'P*("`@("`@("`@("@D1TQ/0D%,4ULG8G)O
M=W-E<B==+3YI<T)R;W=S97(H)VUO>FEL;&$G*2`F)B`D1TQ/0D%,4ULG8G)O
M=W-E<B==+3YG971-86IO<B@I(#X](#4I*3H@/SX*("`@('=D87ES(#T@;F5W
M($%R<F%Y*`H@("`@("`@("<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W5N
M9&%Y(BDI(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(DUO;F1A>2(I*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")4=65S9&%Y(BDI(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(E=E9&YE<V1A>2(I*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")4:'5R<V1A>2(I*2`_/B<L"B`@("`@("`@)SP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")&<FED87DB*2D@/SXG+`H@("`@("`@
M("<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4V%T=7)D87DB*2D@/SXG"B`@
M("`I.PH@("`@:68@*'-P86X@/3T@)W-T87)T7W=D87DG*2!["B`@("`@("`@
M<W!A;D]B:B`](%]G970H)W-T87)T7W=D87DG*3L*("`@("`@("!D87D@/2!?
M9V5T*"=S=&%R=%MD87E=)RDN=F%L=64["B`@("`@("`@;6]N=&@@/2!?9V5T
M*"=S=&%R=%MM;VYT:%TG*2YV86QU92`M(#$["B`@("`@("`@>65A<B`](%]G
M970H)W-T87)T6WEE87)=)RDN=F%L=64["B`@("!](&5L<V4@:68@*'-P86X@
M/3T@)V5N9%]W9&%Y)RD@>PH@("`@("`@('-P86Y/8FH@/2!?9V5T*"=E;F1?
M=V1A>2<I.PH@("`@("`@(&1A>2`](%]G970H)V5N9%MD87E=)RDN=F%L=64[
M"B`@("`@("`@;6]N=&@@/2!?9V5T*"=E;F1;;6]N=&A=)RDN=F%L=64@+2`Q
M.PH@("`@("`@('EE87(@/2!?9V5T*"=E;F1;>65A<ETG*2YV86QU93L*/#]P
M:'`@:68@*"%5=&EL.CIN;VY);G!U=%9A<B@G:7-S96%R8V@G*2DZ(#\^"B`@
M("!](&5L<V4@:68@*'-P86X@/3T@)W)E8W5R7V5N9%]W9&%Y)RD@>PH@("`@
M("`@('-P86Y/8FH@/2!?9V5T*"=R96-U<E]E;F1?=V1A>2<I.PH@("`@("`@
M(&1A>2`](%]G970H)W)E8W5R7V5N9&1A=&5;9&%Y72<I+G9A;'5E.PH@("`@
M("`@(&UO;G1H(#T@7V=E="@G<F5C=7)?96YD9&%T95MM;VYT:%TG*2YV86QU
M92`M(#$["B`@("`@("`@>65A<B`](%]G970H)W)E8W5R7V5N9&1A=&5;>65A
M<ETG*2YV86QU93L*/#]P:'`@96YD:68[(#\^"B`@("!]"B`@("!D871E(#T@
M;F5W($1A=&4H>65A<BP@;6]N=&@L(&1A>2D*("`@('-P86Y/8FHN:6YN97)(
M5$U,(#T@)R@G("L@=V1A>7-;9&%T92YG971$87DH*5T@*R`G*2<["CP_<&AP
M(&5N9&EF.R`_/@I]"CP_<&AP(&EF("@A)'!R969S+3YG971686QU92@G='=E
M;G1Y1F]U<B<I*3H@/SX*"B\O($-O;G9E<G1S(&$@,3(@:&]U<B!B87-E9"!N
M=6UB97(@=&\@:71S(#(T(&AO=7(@9F]R;6%T"F9U;F-T:6]N(&-O;G9E<G14
M;S(T2&]U<BAI;E]H;W5R+"!I;E]E;&5M96YT3F%M92D*>PH@("`@=F%R(&9O
M<FT@/2!D;V-U;65N="YE=F5N=#L*("`@(&EF("AF;W)M6VEN7V5L96UE;G1.
M86UE75LQ72YC:&5C:V5D*2!["B`@("`@("`@:68@*&EN7VAO=7(@(3T@,3(I
M('L*("`@("`@("`@("`@:6Y?:&]U<B`K/2`Q,CL*("`@("`@("!]"B`@("!]
M(&5L<V4@:68@*&EN7VAO=7(@/3T@,3(I('L*("`@("`@("!I;E]H;W5R(#T@
M,#L*("`@('T*"B`@("!R971U<FX@:6Y?:&]U<CL*?0H\/W!H<"!E;F1I9CL@
M/SX*"F9U;F-T:6]N('5P9&%T941U<F%T:6]N*"D*>PH@("`@=F%R(&9O<FT@
M/2!D;V-U;65N="YE=F5N=#L*/#]P:'`@:68@*"1P<F5F<RT^9V5T5F%L=64H
M)W1W96YT>49O=7(G*2DZ(#\^"B`@("!V87(@<W1A<G1(;W5R(#T@9F]R;2YS
M=&%R=%]H;W5R6V9O<FTN<W1A<G1?:&]U<BYS96QE8W1E9$EN9&5X72YV86QU
M93L*("`@('9A<B!E;F1(;W5R(#T@9F]R;2YE;F1?:&]U<EMF;W)M+F5N9%]H
M;W5R+G-E;&5C=&5D26YD97A=+G9A;'5E"CP_<&AP(&5L<V4Z(#\^"B`@("!V
M87(@<W1A<G1(;W5R(#T@<&%R<V5);G0H9F]R;2YS=&%R=%]H;W5R6V9O<FTN
M<W1A<G1?:&]U<BYS96QE8W1E9$EN9&5X72YV86QU92D["B`@("!S=&%R=$AO
M=7(@/2!C;VYV97)T5&\R-$AO=7(H<W1A<G1(;W5R+"`G86U?<&TG*3L*("`@
M('9A<B!E;F1(;W5R(#T@<&%R<V5);G0H9F]R;2YE;F1?:&]U<EMF;W)M+F5N
M9%]H;W5R+G-E;&5C=&5D26YD97A=+G9A;'5E*3L*("`@(&5N9$AO=7(@/2!C
M;VYV97)T5&\R-$AO=7(H96YD2&]U<BP@)V5N9%]A;5]P;2<I.PH\/W!H<"!E
M;F1I9CL@/SX*("`@('9A<B!S=&%R=$1A=&4@/2!$871E+E540RA?9V5T*"=S
M=&%R=%MY96%R72<I+G9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]G970H)W-T87)T6VUO;G1H72<I+G9A;'5E("T@,2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?9V5T*"=S=&%R=%MD87E=)RDN=F%L=64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A<G1(;W5R+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&9O<FTN<W1A<G1?;6EN6V9O<FTN
M<W1A<G1?;6EN+G-E;&5C=&5D26YD97A=+G9A;'5E*3L*("`@('9A<B!E;F1$
M871E(#T@1&%T92Y55$,H7V=E="@G96YD6WEE87)=)RDN=F%L=64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]G970H)V5N9%MM;VYT:%TG*2YV86QU
M92`M(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(%]G970H)V5N9%MD
M87E=)RDN=F%L=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&5N9$AO
M=7(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<FTN96YD7VUI;EMF
M;W)M+F5N9%]M:6XN<V5L96-T961);F1E>%TN=F%L=64I.PH@("`@=F%R(&9A
M:6QE9"`](&9A;'-E.PH@("`@:68@*&5N9$1A=&4@/"!S=&%R=$1A=&4I('L*
M/#]P:'`@:68@*"$D<')E9G,M/F=E=%9A;'5E*"=T=V5N='E&;W5R)RDI.B`_
M/@H@("`@("`@("\O($EF('1H92!E;F0@:&]U<B!I<R!M87)K960@87,@=&AE
M("AD969A=6QT*2!!32P@86YD('1H90H@("`@("`@("\O('-T87)T(&AO=7(@
M:7,@86QS;R!!32P@875T;VUA=&EC86QL>2!D969A=6QT('1H92!E;F0@:&]U
M<@H@("`@("`@("\O('1O(%!-(&EF('1H92!D871E(&ES(&]T:&5R=VES92!T
M:&4@<V%M92`M(&%S<W5M92!T:&%T('1H90H@("`@("`@("\O('5S97(@=V%N
M=',@82`Y86TM,G!M(&5V96YT("AF;W(@97AA;7!L92DL(&EN<W1E860@;V8*
M("`@("`@("`O+R!T:')O=VEN9R!A;B!E<G)O<BX*("`@("`@("!I9B`H7V=E
M="@G<W1A<G1;>65A<ETG*2YV86QU92`]/2!?9V5T*"=E;F1;>65A<ETG*2YV
M86QU92`F)@H@("`@("`@("`@("!?9V5T*"=S=&%R=%MM;VYT:%TG*2YV86QU
M92`]/2!?9V5T*"=E;F1;;6]N=&A=)RDN=F%L=64@)B8*("`@("`@("`@("`@
M7V=E="@G<W1A<G1;9&%Y72<I+G9A;'5E(#T](%]G970H)V5N9%MD87E=)RDN
M=F%L=64@)B8*("`@("`@("`@("`@(61O8W5M96YT+F5V96YT6R=A;5]P;2==
M6S%=+F-H96-K960@)B8*("`@("`@("`@("`@(61O8W5M96YT+F5V96YT6R=E
M;F1?86U?<&TG75LQ72YC:&5C:V5D*2!["B`@("`@("`@("`@("\O(%1O9V=L
M92!T:&4@96YD(&1A=&4@=&\@4$TN"B`@("`@("`@("`@(&9O<FTN96YD7V%M
M7W!M6S%=+F-H96-K960@/2!T<G5E.PH*("`@("`@("`@("`@+R\@4F5C86QC
M=6QA=&4@96YD('1I;64N"B`@("`@("`@("`@('9A<B!E;F1(;W5R(#T@<&%R
M<V5);G0H9F]R;2YE;F1?:&]U<EMF;W)M+F5N9%]H;W5R+G-E;&5C=&5D26YD
M97A=+G9A;'5E*3L*("`@("`@("`@("`@96YD2&]U<B`](&-O;G9E<G14;S(T
M2&]U<BAE;F1(;W5R+"`G96YD7V%M7W!M)RD["B`@("`@("`@("`@(&5N9$1A
M=&4@/2!$871E+E540RA?9V5T*"=E;F1;>65A<ETG*2YV86QU92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]G970H)V5N9%MM;VYT:%TG*2YV
M86QU92`M(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?9V5T
M*"=E;F1;9&%Y72<I+G9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@96YD2&]U<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<FTN96YD7VUI;EMF;W)M+F5N9%]M:6XN<V5L96-T961);F1E>%TN=F%L
M=64I.PH@("`@("`@('T@96QS92!["CP_<&AP(&5N9&EF.R`_/@H@("`@("`@
M(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE(&5N9"!D871E
M(&UU<W0@8F4@;&%T97(@=&AA;B!T:&4@<W1A<G0@9&%T92XB*2D@/SXG*3L*
M("`@("`@("!E;F1$871E(#T@<W1A<G1$871E.PH@("`@("`@(&9A:6QE9"`]
M('1R=64["CP_<&AP(&EF("@A)'!R969S+3YG971686QU92@G='=E;G1Y1F]U
M<B<I*3H@/SX*("`@("`@("!]"CP_<&AP(&5N9&EF.R`_/@H@("`@?0H@("`@
M=F%R(&1U<F%T:6]N(#T@*&5N9$1A=&4@+2!S=&%R=$1A=&4I("\@,3`P,#L*
M("`@('9A<B!D=7)$87D@/2!-871H+F9L;V]R*&1U<F%T:6]N("\@.#8T,#`I
M.PH@("`@9'5R871I;VX@)3T@.#8T,#`["B`@("!V87(@9'5R2&]U<B`]($UA
M=&@N9FQO;W(H9'5R871I;VX@+R`S-C`P*3L*("`@(&1U<F%T:6]N("4](#,V
M,#`["B`@("!V87(@9'5R36EN(#T@36%T:"YF;&]O<BAD=7)A=&EO;B`O(#8P
M("\@-2D["B`@("!I9B`H9'5R1&%Y(#P@9F]R;2YD=7)?9&%Y+F]P=&EO;G,N
M;&5N9W1H*2!["B`@("`@("`@9F]R;2YD=7)?9&%Y+G-E;&5C=&5D26YD97@@
M/2!D=7)$87D["B`@("!]"B`@("!E;'-E('L*("`@("`@("!F;W)M+F1U<E]D
M87DN<V5L96-T961);F1E>"`](&9O<FTN9'5R7V1A>2YO<'1I;VYS+FQE;F=T
M:"`M(#$["B`@("!]"B`@("!F;W)M+F1U<E]H;W5R+G-E;&5C=&5D26YD97@@
M/2!D=7)(;W5R.PH@("`@9F]R;2YD=7)?;6EN+G-E;&5C=&5D26YD97@@/2!D
M=7)-:6X["B`@("!F;W)M+G=H;VQE7V1A>2YC:&5C:V5D(#T@9F%L<V4["B`@
M("!I9B`H9F%I;&5D*2!["B`@("`@("`@=7!D871E16YD1&%T92@I.PH@("`@
M?0I]"@IF=6YC=&EO;B!U<&1A=&5%;F1$871E*"D*>PH@("`@=F%R(&9O<FT@
M/2!D;V-U;65N="YE=F5N=#L*("`@('9A<B!Y96%R1&EF9B`](#P_<&AP(&5C
M:&\@9&%T92@G62<I("T@,2`_/CL*/#]P:'`@:68@*"1P<F5F<RT^9V5T5F%L
M=64H)W1W96YT>49O=7(G*2DZ(#\^"B`@("!V87(@<W1A<G1(;W5R(#T@9F]R
M;2YS=&%R=%]H;W5R6V9O<FTN<W1A<G1?:&]U<BYS96QE8W1E9$EN9&5X72YV
M86QU93L*/#]P:'`@96QS93H@/SX*("`@('9A<B!S=&%R=$AO=7(@/2!P87)S
M94EN="AF;W)M+G-T87)T7VAO=7);9F]R;2YS=&%R=%]H;W5R+G-E;&5C=&5D
M26YD97A=+G9A;'5E*3L*("`@('-T87)T2&]U<B`](&-O;G9E<G14;S(T2&]U
M<BAS=&%R=$AO=7(L("=A;5]P;2<I.PH\/W!H<"!E;F1I9CL@/SX*("`@('9A
M<B!S=&%R=$1A=&4@/2!N97<@1&%T92A?9V5T*"=S=&%R=%MY96%R72<I+G9A
M;'5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]G970H)W-T87)T
M6VUO;G1H72<I+G9A;'5E("T@,2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?9V5T*"=S=&%R=%MD87E=)RDN=F%L=64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1A<G1(;W5R+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<FTN<W1A<G1?;6EN6V9O<FTN<W1A<G1?;6EN+G-E;&5C
M=&5D26YD97A=+G9A;'5E*3L*("`@('9A<B!E;F1$871E(#T@;F5W($1A=&4H
M*3L*("`@('9A<B!M:6YU=&5S(#T@9F]R;2YD=7)?9&%Y6V9O<FTN9'5R7V1A
M>2YS96QE8W1E9$EN9&5X72YV86QU92`J(#$T-#`["B`@("!M:6YU=&5S("L]
M(&9O<FTN9'5R7VAO=7);9F]R;2YD=7)?:&]U<BYS96QE8W1E9$EN9&5X72YV
M86QU92`J(#8P.PH@("`@;6EN=71E<R`K/2!F;W)M+F1U<E]M:6Y;9F]R;2YD
M=7)?;6EN+G-E;&5C=&5D26YD97A=+G9A;'5E("H@,3L*("`@('9A<B!M<V5C
M<R`](&UI;G5T97,@*B`V,#`P,#L*("`@(&5N9$1A=&4N<V5T5&EM92AS=&%R
M=$1A=&4N9V5T5&EM92@I("L@;7-E8W,I.PH@("`@=F%R(&5N9%EE87(@/2!E
M;F1$871E+F=E=%EE87(H*3L*("`@(&EF("AE;F1996%R(#P@,3DP,"D@>PH@
M("`@("`@(&5N9%EE87(@*ST@,3DP,#L*("`@('T*("`@(%]G970H)V5N9%MY
M96%R72<I+G9A;'5E(#T@96YD665A<CL*("`@(%]G970H)V5N9%MM;VYT:%TG
M*2YS96QE8W1E9$EN9&5X(#T@96YD1&%T92YG971-;VYT:"@I.PH@("`@7V=E
M="@G96YD6V1A>5TG*2YS96QE8W1E9$EN9&5X(#T@96YD1&%T92YG971$871E
M*"D@+2`Q.PH@("`@=F%R(&5N9$AO=7(@/2!E;F1$871E+F=E=$AO=7)S*"D*
M/#]P:'`@:68@*"$D<')E9G,M/F=E=%9A;'5E*"=T=V5N='E&;W5R)RDI.B`_
M/@H@("`@:68@*&5N9$AO=7(@/"`Q,BD@>PH@("`@("`@(&EF("AE;F1(;W5R
M(#T](#`I('L*("`@("`@("`@("`@96YD2&]U<B`](#$R.PH@("`@("`@('T*
M("`@("`@("!F;W)M+F5N9%]A;5]P;5LP72YC:&5C:V5D(#T@=')U93L*("`@
M('T@96QS92!["B`@("`@("`@:68@*&5N9$AO=7(@/B`Q,BD@>PH@("`@("`@
M("`@("!E;F1(;W5R("T](#$R.PH@("`@("`@('T*("`@("`@("!F;W)M+F5N
M9%]A;5]P;5LQ72YC:&5C:V5D(#T@=')U93L*("`@('T*("`@(&5N9$AO=7(@
M+3T@,3L*/#]P:'`@96YD:68[(#\^"B`@("!F;W)M+F5N9%]H;W5R+G-E;&5C
M=&5D26YD97@@/2!E;F1(;W5R.PH@("`@9F]R;2YE;F1?;6EN+G-E;&5C=&5D
M26YD97@@/2!E;F1$871E+F=E=$UI;G5T97,H*2`O(#4["B`@("!U<&1A=&57
M9&%Y*"=E;F1?=V1A>2<I.PI]"@H\/W!H<"!I9B`H571I;#HZ9V5T1F]R;41A
M=&$H)V%L;&1A>2<I(#T](#$I.B`_/@IW:6YD;W<N;VYL;V%D(#T@9G5N8W1I
M;VXH*0I["B`@("!D;V-U;65N="YE=F5N="YW:&]L95]D87DN8VQI8VLH*0I]
M.PH\/W!H<"!E;F1I9CL@/SX*"F9U;F-T:6]N(%]G970H:60I"GL*("`@(')E
M='5R;B!D;V-U;65N="YG971%;&5M96YT0GE)9"`_"B`@("`@("`@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H:60I(#H*("`@("`@("!E=F%L*"=D;V-U;65N
M="YA;&PN)R`K(&ED*3L*?0H*+R\@+2T^"CPO<V-R:7!T/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S+W9I97<O````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`R,30P-0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O=FEE
M=R]V:65W+FEN8P``````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38Q,3,`,3`T
M,3<S-C(W-3,`,#(S,#4Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#QD:78@:60](G!A9V4B/@H*/"$M+2!H96%D97(@+2T^
M"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@0&AT;6QS<&5C:6%L
M8VAA<G,H)&5V96YT+3YG9714:71L92@I+"!%3E1?0T]-4$%4+"!.3%,Z.F=E
M=$-H87)S970H*2D@/SX*(#P_<&AP(&EF("@A)'!R:6YT7W9I97<I.B`_/B`\
M<VUA;&P^6R`\/W!H<"!E8VAO(&EM<&QO9&4H)R!\("<L("1M>6QI;FMS*2`_
M/B!=/"]S;6%L;#X\/W!H<"!E;F1I9CL@/SX*/"]H,3X*"CQT86)L92!C96QL
M<W!A8VEN9STB,"(@=VED=&@](C$P,"4B(&-L87-S/2)S=')I<&5D(CX*"CPA
M+2T@8V%T96=O<GD@+2T^"CQT<CX*(#QT9"!W:61T:#TB,3`E(B!C;&%S<STB
M<FEG:'1!;&EG;B(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D-A=&5G;W)Y(BD@
M/SXF;F)S<#LF;F)S<#L\+W-T<F]N9SX\+W1D/@H@/'1D('=I9'1H/2(Y,"4B
M/@H@(#P_<&AP(&5C:&\@0&AT;6QS<&5C:6%L8VAA<G,H)&-A=&5G;W)Y(#\@
M)&-A=&5G;W)Y(#H@7R@B56YF:6QE9"(I+"!%3E1?0T]-4$%4+"!.3%,Z.F=E
M=$-H87)S970H*2D@/SX*(#PO=&0^"CPO='(^"@H\(2TM(&QO8V%T:6]N("TM
M/@H\='(^"B`\=&0@8VQA<W,](G)I9VAT06QI9VXB/CQS=')O;F<^/#]P:'`@
M96-H;R!?*"),;V-A=&EO;B(I(#\^)FYB<W`[)FYB<W`[/"]S=')O;F<^/"]T
M9#X*(#QT9#X\/W!H<"!E8VAO(&5M<'1Y*"1L;V-A=&EO;BD@/R`G)FYB<W`[
M)R`Z($!H=&UL<W!E8VEA;&-H87)S*"1L;V-A=&EO;BP@14Y47T-/35!!5"P@
M3DQ3.CIG971#:&%R<V5T*"DI(#\^(#PO=&0^"CPO='(^"@H\(2TM('-T871U
M<R`M+3X*/'1R/@H@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX\<W1R;VYG/CP_
M<&AP(&5C:&\@7R@B4W1A='5S(BD@/SXF;F)S<#LF;F)S<#L\+W-T<F]N9SX\
M+W1D/@H@/'1D/CP_<&AP(&5C:&\@96UP='DH)'-T871U<RD@/R`G)FYB<W`[
M)R`Z(&AT;6QS<&5C:6%L8VAA<G,H)'-T871U<RD@/SX@/"]T9#X*/"]T<CX*
M"CP_<&AP(&EF("@A96UP='DH)&]W;F5R*2DZ(#\^"CPA+2T@;W=N97(@+2T^
M"CQT<CX*(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(^/'-T<F]N9SX\/W!H<"!E
M8VAO(%\H(D]W;F5R(BD@/SXF;F)S<#LF;F)S<#L\+W-T<F]N9SX\+W1D/@H@
M/'1D/CP_<&AP(&5C:&\@0&AT;6QS<&5C:6%L8VAA<G,H)&]W;F5R+"!%3E1?
M0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H*2D@/SX@/"]T9#X*/"]T<CX*/#]P
M:'`@96YD:68[(#\^"@H\(2TM('-T87)T(&1A=&4@+2T^"CQT<CX*(#QT9"!C
M;&%S<STB<FEG:'1!;&EG;B(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E-T87)T
M($]N(BD@/SXF;F)S<#LF;F)S<#L\+W-T<F]N9SX\+W1D/@H@/'1D/CP_<&AP
M(&5C:&\@<W1R9G1I;64H)'!R969S+3YG971686QU92@G9&%T95]F;W)M870G
M*2P@)&5V96YT+3YS=&%R="T^=&EM97-T86UP*"DI("X@9&%T92@D<')E9G,M
M/F=E=%9A;'5E*"=T=V5N='E&;W5R)RD@/R`G($<Z:2<@.B`G(&<Z:2!A)RP@
M)&5V96YT+3YS=&%R="T^=&EM97-T86UP*"DI(#\^/"]T9#X*/"]T<CX*"CPA
M+2T@96YD(&1A=&4@+2T^"CQT<CX*(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(^
M/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D5N9"!/;B(I(#\^)FYB<W`[)FYB<W`[
M/"]S=')O;F<^/"]T9#X*(#QT9#X\/W!H<"!E8VAO('-T<F9T:6UE*"1P<F5F
M<RT^9V5T5F%L=64H)V1A=&5?9F]R;6%T)RDL("1E=F5N="T^96YD+3YT:6UE
M<W1A;7`H*2D@+B!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G
M*2`_("<@1SII)R`Z("<@9SII(&$G+"`D979E;G0M/F5N9"T^=&EM97-T86UP
M*"DI(#\^/"]T9#X*/"]T<CX*"CPA+2T@86QA<FT@+2T^"CQT<CX*(#QT9"!C
M;&%S<STB<FEG:'1!;&EG;B(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D%L87)M
M(BD@/SXF;F)S<#LF;F)S<#L\+W-T<F]N9SX\+W1D/@H@/'1D/@H\/W!H<`II
M9B`H)&5V96YT+3YI<TEN:71I86QI>F5D*"D@)B8@)&5V96YT+3YA;&%R;2`^
M(#`I.@H@("`@:68@*"1E=F5N="T^86QA<FT@)2`Q,#`X,"`]/2`P*2!["B`@
M("`@("`@)&%L87)M7W9A;'5E(#T@)&5V96YT+3YA;&%R;2`O(#$P,#@P.PH@
M("`@("`@("1A;&%R;5]U;FET(#T@7R@B5V5E:RAS*2(I.PH@("`@?2!E;'-E
M:68@*"1E=F5N="T^86QA<FT@)2`Q-#0P(#T](#`I('L*("`@("`@("`D86QA
M<FU?=F%L=64@/2`D979E;G0M/F%L87)M("\@,30T,#L*("`@("`@("`D86QA
M<FU?=6YI="`](%\H(D1A>2AS*2(I.PH@("`@?2!E;'-E:68@*"1E=F5N="T^
M86QA<FT@)2`V,"`]/2`P*2!["B`@("`@("`@)&%L87)M7W9A;'5E(#T@)&5V
M96YT+3YA;&%R;2`O(#8P.PH@("`@("`@("1A;&%R;5]U;FET(#T@7R@B2&]U
M<BAS*2(I.PH@("`@?2!E;'-E('L*("`@("`@("`D86QA<FU?=F%L=64@/2`D
M979E;G0M/F%L87)M.PH@("`@("`@("1A;&%R;5]U;FET(#T@7R@B36EN=71E
M*',I(BD["B`@("!]"C\^"B`@/#]P:'`@96-H;R`D86QA<FU?=F%L=64@+B`G
M("<@+B`D86QA<FU?=6YI="`_/@H\/W!H<"!E;'-E.B`_/@H@(#P_<&AP(&5C
M:&\@7R@B3F\@86QA<FTB*2`_/@H\/W!H<"!E;F1I9CL@/SX*(#PO=&0^"CPO
M='(^"@H\/W!H<"!I9B`H:7-S970H)&-R96%T960I*3H@/SX*/'1R/@H@(#QT
M9"!C;&%S<STB;F]W<F%P(')I9VAT06QI9VXB/CQS=')O;F<^/#]P:'`@96-H
M;R!?*")#<F5A=&5D(BD@/SX\+W-T<F]N9SXF;F)S<#LF;F)S<#L\+W1D/@H@
M(#QT9"!C;&%S<STB;F]W<F%P(CX\/W!H<"!E8VAO('-T<F9T:6UE*"1P<F5F
M<RT^9V5T5F%L=64H)V1A=&5?9F]R;6%T)RDL("1C<F5A=&5D*2`N("<@)R`N
M(&1A=&4H)'!R969S+3YG971686QU92@G='=E;G1Y1F]U<B<I(#\@)T<Z:2<@
M.B`G9SII(&$G+"`D8W)E871E9"D@/SX\+W1D/@H\+W1R/@H\/W!H<"!E;F1I
M9CL@/SX*"CP_<&AP(&EF("AI<W-E="@D;6]D:69I960I*3H@/SX*/'1R/@H@
M(#QT9"!C;&%S<STB;F]W<F%P(')I9VAT06QI9VXB/CQS=')O;F<^/#]P:'`@
M96-H;R!?*"),87-T($UO9&EF:65D(BD@/SX\+W-T<F]N9SXF;F)S<#LF;F)S
M<#L\+W1D/@H@(#QT9"!C;&%S<STB;F]W<F%P(CX\/W!H<"!E8VAO('-T<F9T
M:6UE*"1P<F5F<RT^9V5T5F%L=64H)V1A=&5?9F]R;6%T)RDL("1M;V1I9FEE
M9"D@+B`G("<@+B!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O=7(G
M*2`_("='.FDG(#H@)V<Z:2!A)RP@)&UO9&EF:65D*2`_/CPO=&0^"CPO='(^
M"CP_<&AP(&5N9&EF.R`_/@H*"CP_<&AP(&EF("@A96UP='DH)&1E<V-R:7!T
M:6]N*2DZ(#\^"CPA+2T@9&5S8W)I<'1I;VX@+2T^"CQT<CX*(#QT9"!C;VQS
M<&%N/2(R(B!C;&%S<STB:&5A9&5R(CX\<W!A;B!C;&%S<STB<VUA;&QH96%D
M97(B/CP_<&AP(&5C:&\@7R@B1&5S8W)I<'1I;VXB*2`_/CPO<W!A;CX\+W1D
M/@H\+W1R/@H\='(^"B`\=&0@8V]L<W!A;CTB,B(^/#]P:'`@<F5Q=6ER95]O
M;F-E("=(;W)D92]497AT+T9I;'1E<BYP:'`G.R!E8VAO(%1E>'1?1FEL=&5R
M.CIF:6QT97(H)&1E<V-R:7!T:6]N+"`G=&5X=#)H=&UL)RP@87)R87DH)W!A
M<G-E;&5V96PG(#T^(%1%6%1?2%1-3%]-24-23RP@)V-L87-S)R`]/B`G=&5X
M="<I*2`_/CPO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H*/#]P:'`@:68@
M*"$D979E;G0M/FAA<U)E8W5R5'EP92A+4D].3TQ)5$A?4D5#55)?3D].12DI
M.B`_/@H\(2TM(')E8W5R<F5N8V4@+2T^"CQT<CX*(#QT9"!C;VQS<&%N/2(R
M(B!C;&%S<STB:&5A9&5R(CX\<W!A;B!C;&%S<STB<VUA;&QH96%D97(B/CP_
M<&AP(&5C:&\@7R@B4F5C=7)R96YC92(I(#\^/"]S<&%N/CPO=&0^"CPO='(^
M"CQT<CX*(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(@=F%L:6=N/2)T;W`B/CQS
M=')O;F<^/#]P:'`@96-H;R!?*")0871T97)N(BD@/SXF;F)S<#LF;F)S<#L\
M+W-T<F]N9SX\+W1D/@H@/'1D('9A;&EG;CTB=&]P(CX*/#]P:'`@:68@*"1E
M=F5N="T^:&%S4F5C=7)4>7!E*$M23TY/3$E42%]214-54E]$04E,62DI.B`_
M/@H@("`\/W!H<"!E8VAO(%\H(D1A:6QY.B!296-U<G,@979E<GDB*2`N("<@
M)R`N("1E=F5N="T^9V5T4F5C=7));G1E<G9A;"@I("X@)R`G("X@7R@B9&%Y
M*',I(BD@/SX*/#]P:'`@96QS96EF("@D979E;G0M/FAA<U)E8W5R5'EP92A+
M4D].3TQ)5$A?4D5#55)?5T5%2TQ9*2DZ"B`@("`D=V5E:V1A>7,@/2!A<G)A
M>2@I.PH@("`@:68@*"1E=F5N="T^<F5C=7)/;D1A>2A(3U)$15]$051%7TU!
M4TM?34].1$%9*2D@("`@)'=E96MD87ES6UT@/2!?*")-;VYD87DB*3L*("`@
M(&EF("@D979E;G0M/G)E8W5R3VY$87DH2$]21$5?1$%415]-05-+7U1515-$
M05DI*2`@("1W965K9&%Y<UM=(#T@7R@B5'5E<V1A>2(I.PH@("`@:68@*"1E
M=F5N="T^<F5C=7)/;D1A>2A(3U)$15]$051%7TU!4TM?5T5$3D531$%9*2D@
M)'=E96MD87ES6UT@/2!?*")7961N97-D87DB*3L*("`@(&EF("@D979E;G0M
M/G)E8W5R3VY$87DH2$]21$5?1$%415]-05-+7U1(55)31$%9*2D@("1W965K
M9&%Y<UM=(#T@7R@B5&AU<G-D87DB*3L*("`@(&EF("@D979E;G0M/G)E8W5R
M3VY$87DH2$]21$5?1$%415]-05-+7T92241!62DI("`@("1W965K9&%Y<UM=
M(#T@7R@B1G)I9&%Y(BD["B`@("!I9B`H)&5V96YT+3YR96-U<D]N1&%Y*$A/
M4D1%7T1!5$5?34%32U]305154D1!62DI("`D=V5E:V1A>7-;72`](%\H(E-A
M='5R9&%Y(BD["B`@("!I9B`H)&5V96YT+3YR96-U<D]N1&%Y*$A/4D1%7T1!
M5$5?34%32U]354Y$05DI*2`@("`D=V5E:V1A>7-;72`](%\H(E-U;F1A>2(I
M.PH@("`@96-H;R!?*")7965K;'DZ(%)E8W5R<R!E=F5R>2(I("X@)R`G("X@
M)&5V96YT+3YG971296-U<DEN=&5R=F%L*"D@+B`G("<@+B!?*")W965K*',I
M(&]N.B(I("X@)R`G("X@:6UP;&]D92@G+"`G+"`D=V5E:V1A>7,I(#\^"CP_
M<&AP(&5L<V5I9B`H)&5V96YT+3YH87-296-U<E1Y<&4H2U)/3D],251(7U)%
M0U527T1!65]/1E]-3TY42"DI.B`_/@H@("`\/W!H<"!E8VAO(%\H(DUO;G1H
M;'DZ(%)E8W5R<R!E=F5R>2(I("X@)R`G("X@)&5V96YT+3YG971296-U<DEN
M=&5R=F%L*"D@+B`G("<@+B!?*")M;VYT:"AS*2(I("X@)R`G("X@7R@B;VX@
M=&AE('-A;64@9&%T92(I(#\^"CP_<&AP(&5L<V5I9B`H)&5V96YT+3YH87-2
M96-U<E1Y<&4H2U)/3D],251(7U)%0U527U=%14M?3T9?34].5$@I*3H@/SX*
M("`@/#]P:'`@96-H;R!?*")-;VYT:&QY.B!296-U<G,@979E<GDB*2`N("<@
M)R`N("1E=F5N="T^9V5T4F5C=7));G1E<G9A;"@I("X@)R`G("X@7R@B;6]N
M=&@H<RDB*2`N("<@)R`N(%\H(F]N('1H92!S86UE('=E96MD87DB*2`_/@H\
M/W!H<"!E;'-E:68@*"1E=F5N="T^:&%S4F5C=7)4>7!E*$M23TY/3$E42%]2
M14-54E]914%23%DI*3H@/SX*("`@/#]P:'`@96-H;R!?*")996%R;'DZ(%)E
M8W5R<R!E=F5R>2(I("X@)R`G("X@)&5V96YT+3YG971296-U<DEN=&5R=F%L
M*"D@+B`G("<@+B!?*")Y96%R*',I(BD@/SX*/#]P:'`@96YD:68[(#\^"B`\
M+W1D/@H\+W1R/@H*/"$M+2!R96-U<B!E;F0@9&%T92`M+3X*/'1R/@H@/'1D
M(&-L87-S/2)R:6=H=$%L:6=N(CX\<W1R;VYG/CP_<&AP(&5C:&\@7R@B4F5C
M=7(@56YT:6PB*2`_/B9N8G-P.R9N8G-P.SPO<W1R;VYG/CPO=&0^"B`\=&0^
M/#]P:'`@96-H;R`D979E;G0M/FAA<U)E8W5R16YD*"D@/R!S=')F=&EM92@D
M<')E9G,M/F=E=%9A;'5E*"=D871E7V9O<FUA="<I+"`D979E;G0M/G)E8W5R
M16YD+3YT:6UE<W1A;7`H*2D@+B!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W
M96YT>49O=7(G*2`_("<@1SII)R`Z("<@9SII(&$G+"`D979E;G0M/G)E8W5R
M16YD+3YT:6UE<W1A;7`H*2D@.B!?*").;R!E;F0@9&%T92(I(#\^/"]T9#X*
M/"]T<CX*/#]P:'`@96YD:68[(#\^"@H\/W!H<"!I9B`H)&-O;F9;)VUE=&%D
M871A)UU;)VME>7=O<F1S)UT@)B8@8V]U;G0H)&ME>7=O<F1?;&ES="DI.B`_
M/@H\='(^"B`\=&0@8V]L<W!A;CTB,B(@8VQA<W,](FAE861E<B(^/'-P86X@
M8VQA<W,](G-M86QL:&5A9&5R(CX\/W!H<"!E8VAO(%\H(DME>7=O<F1S(BD@
M/SX\+W-P86X^/"]T9#X*/"]T<CX*/#]P:'`@9F]R96%C:"`H)&ME>7=O<F1?
M;&ES="!A<R`D8V%T(#T^("1L:7-T*3H@/SX*/'1R/@H@/'1D(&-L87-S/2)R
M:6=H=$%L:6=N(B!V86QI9VX](G1O<"(^/'-T<F]N9SX\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)&-A="D@/SXF;F)S<#LF;F)S<#L\+W-T<F]N9SX\
M+W1D/@H@/'1D/@H\/W!H<"!F;W)E86-H("@D;&ES="!A<R`D96YT<GDI.B`_
M/@H@(#P_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D96YT<GDI(#\^/&)R
M("\^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`\+W1D/@H\+W1R/@H\/W!H<"!E
M;F1F;W)E86-H.R`_/@H\/W!H<"!E;F1I9CL@/SX*/"]T86)L93X*"CP_<&AP
M(&EF("@A96UP='DH)&%T=&5N9&5E<RDI.B`_/@H\=&%B;&4@8V5L;'-P86-I
M;F<](C`B/@H\(2TM(&%T=&5N9&5E<R`M+3X*/'1R/@H@/'1D(&-O;'-P86X]
M(C,B(&-L87-S/2)H96%D97(B/CQS<&%N(&-L87-S/2)S;6%L;&AE861E<B(^
M/#]P:'`@96-H;R!?*")!='1E;F1E97,B*2`_/CPO<W!A;CX\+W1D/@H\+W1R
M/@H@/'1R(&-L87-S/2)I=&5M(CX*("`\=&0@=VED=&@](C4P)2(^/'-T<F]N
M9SX\/W!H<"!E8VAO(%\H(D5M86EL($%D9')E<W,B*2`_/B9N8G-P.R9N8G-P
M.SPO<W1R;VYG/CPO=&0^"B`@/'1D('=I9'1H/2(R-24B/CQS=')O;F<^/#]P
M:'`@96-H;R!?*")!='1E;F1A;F-E(BD@/SXF;F)S<#LF;F)S<#L\+W-T<F]N
M9SX\+W1D/@H@(#QT9"!W:61T:#TB,C4E(CX\<W1R;VYG/CP_<&AP(&5C:&\@
M7R@B4F5S<&]N<V4B*2`_/B9N8G-P.R9N8G-P.SPO<W1R;VYG/CPO=&0^"B`\
M+W1R/@H@/#]P:'`@9F]R96%C:"`H)&%T=&5N9&5E<R!A<R`D96UA:6P@/3X@
M)'-T871U<RDZ(#\^"B`@/'1R/@H@("`\=&0^/#]P:'`@96-H;R!(;W)D93HZ
M;&EN:R@D<F5G:7-T<GDM/F-A;&PH)VUA:6PO8V]M<&]S92<L(&%R<F%Y*&%R
M<F%Y*"=T;R<@/3X@)&5M86EL*2DI+"!S<')I;G1F*%\H(E-E;F0@86X@96UA
M:6P@=&\@)7,B*2P@)&5M86EL*2DL(&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL
M*2`N("<\+V$^)R`_/CPO=&0^"B`@(#QT9#X\/W!H<"!E8VAO($MR;VYO;&ET
M:#HZ<&%R=%1O4W1R:6YG*"1S=&%T=7-;)V%T=&5N9&%N8V4G72D@/SX\+W1D
M/@H@("`\=&0^/#]P:'`@96-H;R!+<F]N;VQI=&@Z.G)E<W!O;G-E5&]3=')I
M;F<H)'-T871U<ULG<F5S<&]N<V4G72D@/SX\+W1D/@H@(#PO='(^"B`\/W!H
M<"!E;F1F;W)E86-H.R`_/@H\+W1R/@H\+W1A8FQE/@H\/W!H<"!E;F1I9CL@
M/SX*"CPO9&EV/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]W
M965K+P``````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<U,P`P,C$S-C8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N
M;VQI=&@O=&5M<&QA=&5S+W=E96LO:&5A9%]S:61E7V)Y7W-I9&4N:6YC````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,C$T`#$P-#$W,S8R-S4S`#`R-30V,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````@/'1R/@H@(#QT9"!W
M:61T:#TB,24B(&%L:6=N/2)L969T(B!C;VQS<&%N/2(S(CX*("`@/#]P:'`@
M:68@*"$D<')I;G1?=FEE=RD@96-H;R!(;W)D93HZ;&EN:R@G(R<L(%\H(E-H
M;W<@0V%L96YD87(B*2P@)R<L("<G+"`G;W!E;E]C86QE;F1A<E]S96%R8V@H
M*3LG*2`N($AO<F1E.CII;6<H)VYE=U]B:6<N<&YG)RP@7R@B4VAO=R!#86QE
M;F1A<B(I*2`N("<\+V$^)R`_/@H@(#PO=&0^"CP_<&AP(&9O<F5A8V@@*"1T
M:&ES+3YD87ES(&%S("1D87DI.B`_/@H@(#QT9"!C;&%S<STB8V]N=')O;"(@
M=VED=&@](C$E(CXF;F)S<#L\+W1D/@H\/W!H<"!I9B`H(6-O=6YT*"1T:&ES
M+3Y?8W5R<F5N=$-A;&5N9&%R<RDI.B`_/@H@(#QT9"!W:61T:#TB/#]P:'`@
M96-H;R!F;&]O<B@Y,"`O(&-O=6YT*"1T:&ES+3YD87ES*2D@/SXE(B!C;&%S
M<STB/#]P:'`@96-H;R`H)&1A>2T^:7-4;V1A>2@I(#\@)W-E;&5C=&5D+6-O
M;G1R;VPG(#H@)V-O;G1R;VPG*2`_/B(^)FYB<W`[/"]T9#X*/#]P:'`@96YD
M:68[(#\^"CP_<&AP(&9O<F5A8V@@*"1T:&ES+3Y?8W5R<F5N=$-A;&5N9&%R
M<R!A<R`D8VED(#T^("1C86PI.B`_/@H@(#QT9"!C;&%S<STB/#]P:'`@96-H
M;R`H)&1A>2T^:7-4;V1A>2@I(#\@)W-E;&5C=&5D+6-O;G1R;VPG(#H@)V-O
M;G1R;VPG*2`_/B(@=VED=&@](CP_<&AP(&5C:&\@9FQO;W(H*#DP+V-O=6YT
M*"1T:&ES+3YD87ES*2D@+R!C;W5N="@D=&AI<RT^7V-U<G)E;G1#86QE;F1A
M<G,I*2`_/B4B(&-O;'-P86X](CP_<&AP(&5C:&\@)&1A>2T^7W-P86Y;)&-I
M9%T@/SXB/@H@("`\<W1R;VYG/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D8V%L+3YG970H)VYA;64G*2D[(&EF("@A)'!R:6YT7W9I97<I(&5C:&\@
M)R`G("X@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS
M96QF57)L*"DL("=D:7-P;&%Y7V-A;"<L("1C86PM/F=E=%-H;W)T3F%M92@I
M*2P@<W!R:6YT9BA?*")(:61E("5S(BDL("1C86PM/F=E="@G;F%M92<I*2D@
M+B!(;W)D93HZ:6UG*"=D96QE=&4M<VUA;&PN<&YG)RP@7R@B2&ED92(I+"`G
M)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`N("<\+V$^)R`_/CPO<W1R;VYG/@H@(#PO=&0^"CP_<&AP(&5N9&9O<F5A
M8V@[(&5N9&9O<F5A8V@[(#\^"B`\+W1R/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O=V5E:R]H
M96%D+FEN8P``````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S-C<`,3`T,3<S
M-C(W-3,`,#(R-S<P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QD:78@8VQA<W,](FAE861E<B(@<W1Y;&4](G1E>'0M86QI
M9VXZ8V5N=&5R(CX*/#]P:'`*:68@*"$D<')I;G1?=FEE=RD@96-H;R!(;W)D
M93HZ;&EN:R@D=&AI<RT^;&EN:R@M,2DL(%\H(DQA<W0@=V5E:R(I*2`N($AO
M<F1E.CII;6<H)VYA=B]L969T+G!N9R<L("<\)RP@)R<L("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<["F5C
M:&\@)'1H:7,M/F1A>7-;)'1H:7,M/G-T87)T1&%Y72T^9V5T5&EM92@D<')E
M9G,M/F=E=%9A;'5E*"=D871E7V9O<FUA="<I*2`N("<@+2`G("X@)'1H:7,M
M/F1A>7-;)'1H:7,M/F5N9$1A>5TM/F=E=%1I;64H)'!R969S+3YG971686QU
M92@G9&%T95]F;W)M870G*2D["FEF("@A)'!R:6YT7W9I97<I(&5C:&\@2&]R
M9&4Z.FQI;FLH)'1H:7,M/FQI;FLH,2DL(%\H(DYE>'0@=V5E:R(I*2`N($AO
M<F1E.CII;6<H)VYA=B]R:6=H="YP;F<G+"`G/B<L("<G+"`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PH_
M/@H\+V1I=CX*"CQT86)L92!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B
M(&-L87-S/2)S=')I<&5D(CX*(#QT<CX*("`\=&@@8VQA<W,](F-O;G1R;VPB
M('=I9'1H/2(Q)2(@8V]L<W!A;CTB,R(^)FYB<W`[/"]T:#X*"CP_<&AP(&9O
M<F5A8V@@*"1T:&ES+3YD87ES(&%S("1D87DI.B`_/@H@(#QT:"!C;&%S<STB
M8V]N=')O;"(@=VED=&@](C$E(CXF;F)S<#L\+W1H/@H@(#QT:"!C;&%S<STB
M;F]W<F%P(#P_<&AP(&5C:&\@*"1D87DM/FES5&]D87DH*2`_("=S96QE8W1E
M9"UC;VYT<F]L)R`Z("=C;VYT<F]L)RD@/SXB('=I9'1H/2(\/W!H<"!E8VAO
M(')O=6YD*#@P("\@8V]U;G0H)'1H:7,M/F1A>7,I*2`_/B4B(&-O;'-P86X]
M(CP_<&AP(&5C:&\@)&1A>2T^7W1O=&%L<W!A;B`_/B(^"CP_<&AP"FEF("A+
M<F]N;VQI=&@Z.F=E=$1E9F%U;'1#86QE;F1A<BA015)-4U]%1$E4*2`F)B`A
M)'!R:6YT7W9I97<@)B8*("`@("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W!E
M<FUS9&5N:65D)UTI('Q\"B`@("`@2W)O;F]L:71H.CIH87-097)M:7-S:6]N
M*"=M87A?979E;G1S)RD@/3T]('1R=64@?'P*("`@("!+<F]N;VQI=&@Z.FAA
M<U!E<FUI<W-I;VXH)VUA>%]E=F5N=',G*2`^($MR;VYO;&ET:#HZ8V]U;G1%
M=F5N=',H*2DI('L*("`@("1A9&1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M)V%D9&5V96YT+G!H<"<L(&%R<F%Y*"=M;VYT:"<@/3X@)&1A>2T^;6]N=&@L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G>65A<B<@/3X@)&1A>2T^>65A<BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M9&%Y)R`]/B`D9&%Y+3YM9&%Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z
M.G-E;&95<FPH=')U92P@9F%L<V4L('1R=64I*2D["B`@("!E8VAO($AO<F1E
M.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D861D=7)L*2P@7R@B0W)E
M871E(&$@3F5W($5V96YT(BDI"B`@("`N($AO<F1E.CII;6<H)VYE=U]S;6%L
M;"YP;F<G+"`G*R<I"B`@("`N("<\+V$^)SL*?0H_/@H@("`\<W1R;VYG/CP_
M<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)&1A>2T^;&EN:R@I+"`G)RP@)W=I9&=E
M="<I("X@)&1A>2T^9V5T5&EM92@G)4$L("5D+B<I(#\^/"]A/CPO<W1R;VYG
M/@H@(#PO=&@^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`\+W1R/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S+WEE87(O````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S
M`#`R,3,W,P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP
M;&%T97,O>65A<B]H96%D+FEN8P``````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$P,3(`,3`T,3<S-C(W-3,`,#(R-S4V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QT86)L92!C;&%S<STB;F]P861D:6YG
M(B!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B/@H\='(^"B`@/'1H(&-L
M87-S/2)H96%D97(B/@H@(#P_<&AP(&5C:&\@*"$D<')I;G1?=FEE=RD@/R!(
M;W)D93HZ;&EN:R@D<')E=G5R;"P@7R@B3&%S="!996%R(BDI("X@2&]R9&4Z
M.FEM9R@G;F%V+VQE9G0N<&YG)RP@)SPG+"`G)RP@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)R`Z("<G(#\^
M"B`@/#]P:'`@96-H;R`D=&ET;&4@/SX*("`\/W!H<"!E8VAO("@A)'!R:6YT
M7W9I97<I(#\@2&]R9&4Z.FQI;FLH)&YE>'1U<FPL(%\H(DYE>'0@665A<B(I
M*2`N($AO<F1E.CII;6<H)VYA=B]R:6=H="YP;F<G+"`G/B<L("<G+"`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO
M83XG(#H@)R<@/SX*("`\+W1H/@H\+W1R/@H\+W1A8FQE/@H\=&%B;&4@8VQA
M<W,](FYO<&%D9&EN9R(@8V5L;'-P86-I;F<](C4B('=I9'1H/2(Q,#`E(CX\
M='(^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET
M:"]T96UP;&%T97,O:F%V87-C<FEP="\`````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(R-C`Q`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87)?<V5A<F-H+FIS```````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<U,P`Q,#0Q-S,V,C<U,P`P,C<R
M-C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IV87(@<V5L
M9E5R;"`]("<\/W!H<"!E8VAO(%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ
M<V5L9E5R;"AF86QS92P@=')U92DL("=D:7-P;&%Y7V-A;"<L("<G+"!F86QS
M92D[(#\^)SL*"F9U;F-T:6]N(&]P96Y?8V%L96YD87)?<V5A<F-H*"D*>PH@
M("`@=F%R(&YA;64@/2`G8V%L96YD87)?<V5A<F-H7W=I;F1O=R<["B`@("!N
M86UE(#T@=VEN9&]W+F]P96XH)SP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=C86QE;F1A<E]S96%R8V@N<&AP)RP@=')U92D@/SXG+"!N86UE
M+"`G=&]O;&)A<CUN;RQL;V-A=&EO;CUN;RQS=&%T=7,]>65S+'-C<F]L;&)A
M<G,]>65S+')E<VEZ86)L93UY97,L=VED=&@],S`P+&AE:6=H=#TR,#`G*3L*
M("`@(&EF("@A979A;"@G;F%M92YO<&5N97(G*2D@>PH@("`@("`@(&YA;64N
M;W!E;F5R(#T@<V5L9CL*("`@('T*?0H*+R\@+2T^"CPO<V-R:7!T/@H`````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR
M;VYO;&ET:"]T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V%T=&5N9&5E<U]W
M:6XN:G,`````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(R,S8`,3`T,3<S-C(W-3,`,#(W,#$Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP(&EF("@A
M<W1R<W1R*"1?4T525D526R=02%!?4T5,1B==+"`G:F%V87-C<FEP="YP:'`G
M*2DZ(#\^/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"CP_
M<&AP(&5N9&EF.R`_/@IF=6YC=&EO;B!O<&5N7V%T=&5N9&5E<U]W:6XH87)G
M<RD*>PH@("`@=F%R('5R;"`]("(\/W!H<"!E8VAO($AO<F1E.CIU<FPH)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F%P<&QI8V%T:6]N5V5B4&%T:"@G)6%P<&QI
M8V%T:6]N)2]A='1E;F1E97,N<&AP)RP@)VMR;VYO;&ET:"<I*2`_/B(["B`@
M("!I9B`H=7)L+FEN9&5X3V8H)S\G*2`]/2`M,2D@>PH@("`@("`@('9A<B!G
M;'5E(#T@)S\G.PH@("`@?2!E;'-E('L*("`@("`@("!V87(@9VQU92`]("<F
M)SL*("`@('T*("`@('9A<B!N;W<@/2!N97<@1&%T92@I.PH@("`@=F%R(&YA
M;64@/2`B871T96YD965S7W=I;F1O=U\B("L@;F]W+F=E=%1I;64H*3L*("`@
M(&EF("AA<F=S("$]("(B*2!["B`@("`@("`@=7)L(#T@=7)L("L@9VQU92`K
M(&%R9W,@*R`B)G5N:7$](B`K(&YO=RYG9714:6UE*"D["B`@("!](&5L<V4@
M>PH@("`@("`@('5R;"`]('5R;"`K(&=L=64@*R`B=6YI<3TB("L@;F]W+F=E
M=%1I;64H*3L*("`@('T*("`@('9A<B!7:61T:"`]('-C<F5E;BYW:61T:#L*
M("`@(&EF("A7:61T:"`^(#<W-2D@>PH@("`@("`@(%=I9'1H(#T@-S`P.PH@
M("`@?2!E;'-E('L*("`@("`@("!7:61T:"`M/2`W-3L*("`@('T*("`@('9A
M<B!(96EG:'0@/2!S8W)E96XN:&5I9VAT.PH@("`@:68@*$AE:6=H="`^(#<R
M-2D@>PH@("`@("`@($AE:6=H="`](#8U,#L*("`@('T@96QS92!["B`@("`@
M("`@2&5I9VAT("T](#<U.PH@("`@?0H@("`@<&%R86T@/2`B=&]O;&)A<CUN
M;RQL;V-A=&EO;CUN;RQS=&%T=7,]>65S+'-C<F]L;&)A<G,]>65S+')E<VEZ
M86)L93UY97,L=VED=&@](B`K(%=I9'1H("L@(BQH96EG:'0](B`K($AE:6=H
M="`K("(L;&5F=#TP+'1O<#TP(CL*("`@(&YA;64@/2!W:6YD;W<N;W!E;BAU
M<FPL(&YA;64L('!A<F%M*3L*("`@(&EF("@A979A;"@B;F%M92YO<&5N97(B
M*2D@>PH@("`@("`@(&YA;64N;W!E;F5R(#T@<V5L9CL*("`@('T*?0H\/W!H
M<"!I9B`H(7-T<G-T<B@D7U-%4E9%4ELG4$A07U-%3$8G72P@)VIA=F%S8W)I
M<'0N<&AP)RDI.B`_/B\O("TM/@H\+W-C<FEP=#X*/#]P:'`@96YD:68[(#\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]J879A
M<V-R:7!T+V=O=&\N:6YC````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C0S-P`Q,#0Q
M-S,V,C<U,P`P,C0R-3$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=F%R(&-U<G)E;G1$871E+"!C=7)R96YT665A<CL*"F9U
M;F-T:6]N('=E96M/9EEE87(H9"D*>PH@("`@+R\@061A<'1E9"!F<F]M(&AT
M='`Z+R]W=W<N;65R;'EN+F1E;6]N+F-O+G5K+VIS+61A=&4W+FAT;2-7:T-O
M;G8N"B`@("!V87(@;7,Q9"`](#@V-#`P,#`P+"!M<S-D(#T@,R`J(&US,60L
M(&US-V0@/2`W("H@;7,Q9#L*"B`@("!V87(@>65A<B`](&0N9V5T665A<B@I
M.PH@("`@:68@*'EE87(@/"`Q.3`P*2!["B`@("`@("`@>65A<B`K/2`Q.3`P
M.PH@("`@?0H@("`@=F%R($0S(#T@1&%T92Y55$,H>65A<BP@9"YG971-;VYT
M:"@I+"!D+F=E=$1A=&4H*2D@*R!M<S-D.PH@("`@=F%R('=K(#T@36%T:"YF
M;&]O<BA$,R`O(&US-V0I.PH@("`@=VET:"`H;F5W($1A=&4H=VL@*B!M<S=D
M*2D@>PH@("`@("`@('9A<B!Y>2`](&=E=%540T9U;&Q996%R*"D["B`@("!]
M"B`@("!R971U<FX@6WEY+"`Q("L@=VL@+2!-871H+F9L;V]R*"A$871E+E54
M0RAY>2P@,"P@-"D@*R!M<S-D*2`O(&US-V0I70I]"@IF=6YC=&EO;B!O<&5N
M2T=O=&\H=&EM97-T86UP*0I["B`@("!V87(@<F]W+"!C96QL+"!I;6<L(&QI
M;FLL(&1A>7,["@H@("`@=F%R(&0@/2!N97<@1&%T92AT:6UE<W1A;7`@*B`Q
M,#`P*3L*("`@(&-U<G)E;G1$871E(#T@9#L*("`@('9A<B!M;VYT:"`](&0N
M9V5T36]N=&@H*3L*("`@('9A<B!Y96%R(#T@9"YG971996%R*"D["B`@("!I
M9B`H>65A<B`\(#$Y,#`I('L*("`@("`@("!Y96%R("L](#$Y,#`["B`@("!]
M"B`@("!C=7)R96YT665A<B`]('EE87(["B`@("!V87(@9FER<W1/9DUO;G1H
M(#T@;F5W($1A=&4H>65A<BP@;6]N=&@L(#$I.PH@("`@=F%R(&1I9F8@/2!F
M:7)S=$]F36]N=&@N9V5T1&%Y*"D@+2`Q.PH@("`@:68@*&1I9F8@/3T@+3$I
M('L*("`@("`@("!D:69F(#T@-CL*("`@('T*("`@('-W:71C:"`H;6]N=&@I
M('L*("`@(&-A<V4@,SH*("`@(&-A<V4@-3H*("`@(&-A<V4@.#H*("`@(&-A
M<V4@,3`Z"B`@("`@("`@9&%Y<R`](#,P.PH@("`@("`@(&)R96%K.PH*("`@
M(&-A<V4@,3H*("`@("`@("!I9B`H>65A<B`E(#0@/3T@,"`F)B`H>65A<B`E
M(#$P,"`A/2`P('Q\('EE87(@)2`T,#`@/3T@,"DI('L*("`@("`@("`@("`@
M9&%Y<R`](#(Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&1A>7,@
M/2`R.#L*("`@("`@("!]"B`@("`@("`@8G)E86L["@H@("`@9&5F875L=#H*
M("`@("`@("!D87ES(#T@,S$["B`@("`@("`@8G)E86L["B`@("!]"@H@("`@
M=F%R('=D87ES(#T@6PH@("`@("`@("<\/W!H<"!E8VAO(%\H(DUO(BD@/SXG
M+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(E1U(BD@/SXG+`H@("`@("`@("<\
M/W!H<"!E8VAO(%\H(E=E(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H
M(E1H(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(D9R(BD@/SXG+`H@
M("`@("`@("<\/W!H<"!E8VAO(%\H(E-A(BD@/SXG+`H@("`@("`@("<\/W!H
M<"!E8VAO(%\H(E-U(BD@/SXG"B`@("!=.PH@("`@=F%R(&UO;G1H<R`](%L*
M("`@("`@("`G/#]P:'`@96-H;R!?*")*86YU87)Y(BD@/SXG+`H@("`@("`@
M("<\/W!H<"!E8VAO(%\H(D9E8G)U87)Y(BD@/SXG+`H@("`@("`@("<\/W!H
M<"!E8VAO(%\H(DUA<F-H(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H
M(D%P<FEL(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(DUA>2(I(#\^
M)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")*=6YE(BD@/SXG+`H@("`@("`@
M("<\/W!H<"!E8VAO(%\H(DIU;'DB*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C
M:&\@7R@B075G=7-T(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(E-E
M<'1E;6)E<B(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")/8W1O8F5R
M(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(DYO=F5M8F5R(BD@/SXG
M+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(D1E8V5M8F5R(BD@/SXG"B`@("!=
M.PH*("`@('9A<B!T86)L92`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1!
M0DQ%)RD["B`@("!V87(@=&)O9'D@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*"=40D]$62<I.PH@("`@=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH@("`@
M=&%B;&4N8VQA<W-.86UE(#T@)VET96TG.PH@("`@=&%B;&4N8V5L;%-P86-I
M;F<@/2`P.PH*("`@("\O(%1I=&QE+@H@("`@<F]W(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@G5%(G*3L*("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%
M;&5M96YT*"=41"<I.PH@("`@8V5L;"YC;VQ3<&%N(#T@.#L*("`@(&-E;&PN
M86QI9VX@/2`G<FEG:'0G.PH@("`@8V5L;"YC;&%S<TYA;64@/2`G8V]N=')O
M;"<["B`@("!L:6YK(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@
M("`@;&EN:RYH<F5F(#T@)R,G.PH@("`@;&EN:RYO;F-L:6-K(#T@9G5N8W1I
M;VXH*2!["B`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)VMG;W1O
M)RDN<W1Y;&4N9&ES<&QA>2`]("=N;VYE)SL*("`@("`@("!I9B`H8F%C:VEN
M9R`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=K9V]T;T)A8VMI;F<G*2D@
M>PH@("`@("`@("`@("!B86-K:6YG+G-T>6QE+F1I<W!L87D@/2`G;F]N92<[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@(&EM
M9R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I.PH@("`@:6UG+G-R
M8R`]("<\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G
M941I<B@G:&]R9&4G*2`_/B]C;&]S92YP;F<G.PH@("`@;&EN:RYA<'!E;F1#
M:&EL9"AI;6<I.PH@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*("`@(')O
M=RYA<'!E;F1#:&EL9"AC96QL*3L*("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O
M=RD["@H@("`@+R\@665A<BX*("`@(')O=R`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H)U12)RD["B`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N
M="@G5$0G*3L*("`@(&-E;&PN86QI9VX@/2`G;&5F="<["B`@("!L:6YK(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@;&EN:RYH<F5F(#T@
M)R,G.PH@("`@;&EN:RYO;F-L:6-K(#T@9G5N8W1I;VXH*2!["B`@("`@("`@
M;F5W1&%T92`](&YE=R!$871E*&-U<G)E;G1996%R("T@,2P@8W5R<F5N=$1A
M=&4N9V5T36]N=&@H*2P@,2D["B`@("`@("`@;W!E;DM';W1O*&YE=T1A=&4N
M9V5T5&EM92@I("\@,3`P,"D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*("`@(&EM9R`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@("!I;6<N<W)C(#T@)SP_<&AP
M(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D
M92<I(#\^+VYA=B]L969T+G!N9R<["B`@("!L:6YK+F%P<&5N9$-H:6QD*&EM
M9RD["B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["@H@("`@8V5L;"`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("!C96QL+F-O;%-P86X@
M/2`V.PH@("`@8V5L;"YA;&EG;B`]("=C96YT97(G.PH@("`@=F%R('D@/2!D
M;V-U;65N="YC<F5A=&5497AT3F]D92AY96%R*3L*("`@(&-E;&PN87!P96YD
M0VAI;&0H>2D["B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["@H@("`@8V5L
M;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("!C96QL+F%L
M:6=N(#T@)W)I9VAT)SL*("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G(R<["B`@("!L:6YK+F]N8VQI
M8VL@/2!F=6YC=&EO;B@I('L*("`@("`@("!N97=$871E(#T@;F5W($1A=&4H
M8W5R<F5N=%EE87(@*R`Q+"!C=7)R96YT1&%T92YG971-;VYT:"@I+"`Q*3L*
M("`@("`@("!O<&5N2T=O=&\H;F5W1&%T92YG9714:6UE*"D@+R`Q,#`P*3L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@("!C96QL+F%P<&5N9$-H
M:6QD*&QI;FLI.PH@("`@:6UG(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G
M24U')RD*("`@(&EM9RYS<F,@/2`G/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RD@/SXO;F%V+W)I9VAT+G!N
M9R<["B`@("!L:6YK+F%P<&5N9$-H:6QD*&EM9RD["B`@("!R;W<N87!P96YD
M0VAI;&0H8V5L;"D["B`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH*("`@
M("\O($UO;G1H(&YA;64N"B`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=44B<I.PH@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M)U1$)RD["B`@("!C96QL+F%L:6=N(#T@)VQE9G0G.PH@("`@;&EN:R`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@(&QI;FLN:')E9B`]("<C
M)SL*("`@(&QI;FLN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH@("`@("`@('9A
M<B!N97=-;VYT:"`](&-U<G)E;G1$871E+F=E=$UO;G1H*"D@+2`Q.PH@("`@
M("`@('9A<B!N97=996%R(#T@8W5R<F5N=%EE87(["B`@("`@("`@:68@*&YE
M=TUO;G1H(#T]("TQ*2!["B`@("`@("`@("`@(&YE=TUO;G1H(#T@,3$["B`@
M("`@("`@("`@(&YE=UEE87(@+3T@,3L*("`@("`@("!]"B`@("`@("`@;F5W
M1&%T92`](&YE=R!$871E*&YE=UEE87(L(&YE=TUO;G1H+"!C=7)R96YT1&%T
M92YG971$871E*"DI.PH@("`@("`@(&]P96Y+1V]T;RAN97=$871E+F=E=%1I
M;64H*2`O(#$P,#`I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@
M(&-E;&PN87!P96YD0VAI;&0H;&EN:RD["B`@("!I;6<@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*"=)34<G*0H@("`@:6UG+G-R8R`]("<\/W!H<"!E8VAO
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2`_
M/B]N878O;&5F="YP;F<G.PH@("`@;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@
M("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH*("`@(&-E;&P@/2!D;V-U;65N
M="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@8V5L;"YC;VQ3<&%N(#T@-CL*
M("`@(&-E;&PN86QI9VX@/2`G8V5N=&5R)SL*("`@(&QI;FL@/2!D;V-U;65N
M="YC<F5A=&5%;&5M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G/#]P:'`@
M96-H;R!(;W)D93HZ87!P;&EC871I;VY5<FPH)VUO;G1H+G!H<"<I(#\^)SL*
M("`@(&EF("AL:6YK+FAR968N:6YD97A/9B@G/R<I("$]("TQ*2!["B`@("`@
M("`@;&EN:RYH<F5F("L]("<F)SL*("`@('T@96QS92!["B`@("`@("`@;&EN
M:RYH<F5F("L]("<_)SL*("`@('T*("`@(&QI;FLN:')E9B`K/2`G>65A<CTG
M("L@>65A<B`K("<F;6]N=&@])R`K("AM;VYT:"`K(#$I.PH@("`@8V5L;"YA
M<'!E;F1#:&EL9"AL:6YK*3L*("`@('9A<B!M(#T@9&]C=6UE;G0N8W)E871E
M5&5X=$YO9&4H;6]N=&AS6VUO;G1H72D["B`@("!L:6YK+F%P<&5N9$-H:6QD
M*&TI.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH*("`@(&-E;&P@/2!D
M;V-U;65N="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@8V5L;"YA;&EG;B`]
M("=R:6=H="<["B`@("!L:6YK(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G
M02<I.PH@("`@;&EN:RYH<F5F(#T@)R,G.PH@("`@;&EN:RYO;F-L:6-K(#T@
M9G5N8W1I;VXH*2!["B`@("`@("`@;F5W1&%T92`](&YE=R!$871E*&-U<G)E
M;G1996%R+"!C=7)R96YT1&%T92YG971-;VYT:"@I("L@,2P@,2D["B`@("`@
M("`@;W!E;DM';W1O*&YE=T1A=&4N9V5T5&EM92@I("\@,3`P,"D["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@8V5L;"YA<'!E;F1#:&EL9"AL
M:6YK*3L*("`@(&EM9R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I
M"B`@("!I;6<N<W)C(#T@)SP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I(#\^+VYA=B]R:6=H="YP;F<G.PH@
M("`@;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@("`@<F]W+F%P<&5N9$-H:6QD
M*&-E;&PI.PH@("`@=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*"B`@("`O+R!W
M965K9&%Y<PH@("`@<F]W(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5%(G
M*3L*("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=41"<I.PH@
M("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@9F]R("AV87(@:2`](#`[
M(&D@/"`W.R!I*RLI('L*("`@("`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@G5$0G*3L*("`@("`@("!W965K9&%Y(#T@9&]C=6UE;G0N8W)E
M871E5&5X=$YO9&4H=V1A>7-;:5TI.PH@("`@("`@(&-E;&PN87!P96YD0VAI
M;&0H=V5E:V1A>2D["B`@("`@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@
M("`@?0H@("`@=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*"B`@("`O+R!R;W=S
M"B`@("!V87(@=V5E:TEN9F\L(&ET86QI8SL*("`@('9A<B!C;W5N="`](#$[
M"B`@("!V87(@=&]D87D@/2!N97<@1&%T92@I.PH@("`@=F%R('1H:7-996%R
M(#T@=&]D87DN9V5T665A<B@I.PH@("`@:68@*'1H:7-996%R(#P@,3DP,"D@
M>PH@("`@("`@('1H:7-996%R("L](#$Y,#`["B`@("!]"B`@("!V87(@;V1D
M(#T@=')U93L*("`@(&9O<B`H=F%R(&D@/2`Q.R!I(#P](&1A>7,[(&DK*RD@
M>PH@("`@("`@(&EF("AC;W5N="`]/2`Q*2!["B`@("`@("`@("`@(')O=R`]
M(&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@("`@("`@("`@(')O
M=RYA;&EG;B`]("=R:6=H="<["B`@("`@("`@("`@(&EF("AO9&0I('L*("`@
M("`@("`@("`@("`@(')O=RYC;&%S<TYA;64@/2`G:71E;3`G.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F]W+F-L87-S3F%M92`]
M("=I=&5M,2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@;V1D(#T@(6]D
M9#L*("`@("`@("`@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M)U1$)RD["B`@("`@("`@("`@('=E96M);F9O(#T@=V5E:T]F665A<BAN97<@
M1&%T92AY96%R+"!M;VYT:"P@:2DI.PH@("`@("`@("`@("!I=&%L:6,@/2!D
M;V-U;65N="YC<F5A=&5%;&5M96YT*"=))RD["B`@("`@("`@("`@(&-E;&PN
M87!P96YD0VAI;&0H:71A;&EC*3L*("`@("`@("`@("`@;&EN:R`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@("`@("`@("`@;&EN:RYH<F5F
M(#T@)SP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=W965K+G!H
M<"<I(#\^)SL*("`@("`@("`@("`@:68@*&QI;FLN:')E9BYI;F1E>$]F*"<_
M)RD@(3T@+3$I('L*("`@("`@("`@("`@("`@(&QI;FLN:')E9B`K/2`G)B<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!L:6YK+FAR
M968@*ST@)S\G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&QI;FLN:')E
M9B`K/2`G>65A<CTG("L@=V5E:TEN9F];,%T@*R`G)G=E96L])R`K('=E96M)
M;F9O6S%=.PH@("`@("`@("`@("!I=&%L:6,N87!P96YD0VAI;&0H;&EN:RD[
M"B`@("`@("`@("`@(&QI;FLN87!P96YD0VAI;&0H9&]C=6UE;G0N8W)E871E
M5&5X=$YO9&4H=V5E:TEN9F];,5TI*3L*("`@("`@("`@("`@<F]W+F%P<&5N
M9$-H:6QD*&-E;&PI.PH@("`@("`@('T*("`@("`@("!I9B`H:2`]/2`Q*2![
M"B`@("`@("`@("`@(&9O<B`H=F%R(&H@/2`P.R!J(#P@9&EF9CL@:BLK*2![
M"B`@("`@("`@("`@("`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N
M="@G5$0G*3L*("`@("`@("`@("`@("`@(')O=RYA<'!E;F1#:&EL9"AC96QL
M*3L*("`@("`@("`@("`@("`@(&-O=6YT*RL["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M)U1$)RD["B`@("`@("`@:68@*'1H:7-996%R(#T]('EE87(@)B8*("`@("`@
M("`@("`@=&]D87DN9V5T36]N=&@H*2`]/2!M;VYT:"`F)@H@("`@("`@("`@
M("!T;V1A>2YG971$871E*"D@/3T@:2D@>PH@("`@("`@("`@("!C96QL+G-T
M>6QE+F)O<F1E<B`]("<Q<'@@<V]L:60@<F5D)SL*("`@("`@("!]"B`@("`@
M("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@("`@
M("!L:6YK+FAR968@/2`G/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC871I;VY5
M<FPH)V1A>2YP:'`G*2`_/B<["B`@("`@("`@:68@*&QI;FLN:')E9BYI;F1E
M>$]F*"<_)RD@(3T@+3$I('L*("`@("`@("`@("`@;&EN:RYH<F5F("L]("<F
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!L:6YK+FAR968@*ST@
M)S\G.PH@("`@("`@('T*("`@("`@("!L:6YK+FAR968@*ST@)WEE87(])R`K
M('EE87(@*R`G)FUO;G1H/2<@*R`H;6]N=&@@*R`Q*2`K("<F;61A>3TG("L@
M:3L*("`@("`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@("`@(&1A
M>2`](&1O8W5M96YT+F-R96%T951E>'1.;V1E*&DI.PH@("`@("`@(&QI;FLN
M87!P96YD0VAI;&0H9&%Y*3L*("`@("`@("!R;W<N87!P96YD0VAI;&0H8V5L
M;"D["B`@("`@("`@:68@*&-O=6YT(#T](#<I('L*("`@("`@("`@("`@=&)O
M9'DN87!P96YD0VAI;&0H<F]W*3L*("`@("`@("`@("`@8V]U;G0@/2`P.PH@
M("`@("`@('T*("`@("`@("!C;W5N="LK.PH@("`@?0H@("`@:68@*&-O=6YT
M(#X@,2D@>PH@("`@("`@(&9O<B`H:2`](&-O=6YT.R!I(#P](#<[(&DK*RD@
M>PH@("`@("`@("`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G
M5$0G*3L*("`@("`@("`@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@
M("`@('T*("`@("`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH@("`@?0H*
M("`@("\O(%-H;W<@<&]P=7`@9&EV+@H@("`@=F%R(&1I=B`](&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*"=K9V]T;R<I.PH@("`@:68@*&1I=BYF:7)S=$-H
M:6QD*2!["B`@("`@("`@9&EV+G)E;6]V94-H:6QD*&1I=BYF:7)S=$-H:6QD
M*3L*("`@('T*("`@(&1I=BYA<'!E;F1#:&EL9"AT86)L92D["B`@("!D:78N
M<W1Y;&4N9&ES<&QA>2`]("=B;&]C:R<["@H@("`@+R\@0F%C:R!T:&4@<&]P
M=7`@=VET:"!A;B!I9G)A;64@:68@;F5C97-S87)Y('1O(&AI9&4@/'-E;&5C
M=#X*("`@("\O(&)O>&5S(&EN($U3244N"B`@("!I9B`H8F%C:VEN9R`](&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*"=K9V]T;T)A8VMI;F<G*2D@>PH@("`@
M("`@(&)A8VMI;F<N<W1Y;&4N=VED=&@@/2!D:78N;V9F<V5T5VED=&@["B`@
M("`@("`@8F%C:VEN9RYS='EL92YH96EG:'0@/2!D:78N;V9F<V5T2&5I9VAT
M.PH@("`@("`@(&)A8VMI;F<N<W1Y;&4N=&]P(#T@9&EV+G-T>6QE+G1O<#L*
M("`@("`@("!B86-K:6YG+G-T>6QE+FQE9G0@/2!D:78N<W1Y;&4N;&5F=#L*
M"B`@("`@("`@:68@*&1I=BYS='EL92YZ26YD97@@/3T@)R<I('L*("`@("`@
M("`@("`@9&EV+G-T>6QE+GI);F1E>"`](#(["B`@("`@("`@("`@(&)A8VMI
M;F<N<W1Y;&4N>DEN9&5X(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!B86-K:6YG+G-T>6QE+GI);F1E>"`](&1I=BYS='EL92YZ26YD97@@
M+2`Q.PH@("`@("`@('T*"B`@("`@("`@8F%C:VEN9RYS='EL92YD:7-P;&%Y
M(#T@)V)L;V-K)SL*("`@('T*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]T96UP;&%T97,O;6]N=&@O````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(Q-38P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]M;VYT:"]H
M96%D7W-I9&5?8GE?<VED92YI;F,`````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0P,0`Q,#0Q-S,V
M,C<U,P`P,C4V-3$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^
M"CQT<CX*("`\=&@@8VQA<W,](FAE861E<B(@=VED=&@](C(P)2(^"B`@/#]P
M:'`@96-H;R`H(21P<FEN=%]V:65W*2`_($AO<F1E.CIL:6YK*"1P<F5V=7)L
M+"!?*"),87-T($UO;G1H(BDI("X@2&]R9&4Z.FEM9R@G;F%V+VQE9G0N<&YG
M)RP@)SPG+"`G)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*2`N("<\+V$^)R`Z("<G(#\^"B`@/#]P:'`@96-H;R`D=&ET
M;&4@/SX*("`\/W!H<"!E8VAO("@A)'!R:6YT7W9I97<I(#\@2&]R9&4Z.FQI
M;FLH)&YE>'1U<FPL(%\H(DYE>'0@36]N=&@B*2D@+B!(;W)D93HZ:6UG*"=N
M878O<FEG:'0N<&YG)RP@)SXG+"`G)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)R`Z("<G(#\^"B`@/"]T
M:#X*("`\=&0@8VQA<W,](FAE861E<B(@=VED=&@](C(P)2(^/"]T9#X*("`\
M=&@@8VQA<W,](FAE861E<B(@=VED=&@](C(P)2(^"B`@/#]P:'`@96-H;R`H
M(21P<FEN=%]V:65W*2`_($AO<F1E.CIL:6YK*"1P<F5V=7)L+"!?*"),87-T
M($UO;G1H(BDI("X@2&]R9&4Z.FEM9R@G;F%V+VQE9G0N<&YG)RP@)SPG+"`G
M)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`N("<\+V$^)R`Z("<G(#\^"B`@/#]P:'`@96-H;R`D=&ET;&4@/SX*("`\
M/W!H<"!E8VAO("@A)'!R:6YT7W9I97<I(#\@2&]R9&4Z.FQI;FLH)&YE>'1U
M<FPL(%\H(DYE>'0@36]N=&@B*2D@+B!(;W)D93HZ:6UG*"=N878O<FEG:'0N
M<&YG)RP@)SXG+"`G)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E
M1&ER*"=H;W)D92<I*2`N("<\+V$^)R`Z("<G(#\^"B`@/"]T:#X*("`\=&0@
M8VQA<W,](FAE861E<B(@=VED=&@](C(P)2(^/"]T9#X*("`\=&@@8VQA<W,]
M(FAE861E<B(@=VED=&@](C(P)2(^"B`@/#]P:'`@96-H;R`H(21P<FEN=%]V
M:65W*2`_($AO<F1E.CIL:6YK*"1P<F5V=7)L+"!?*"),87-T($UO;G1H(BDI
M("X@2&]R9&4Z.FEM9R@G;F%V+VQE9G0N<&YG)RP@)SPG+"`G)RP@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^
M)R`Z("<G(#\^"B`@/#]P:'`@96-H;R`D=&ET;&4@/SX*("`\/W!H<"!E8VAO
M("@A)'!R:6YT7W9I97<I(#\@2&]R9&4Z.FQI;FLH)&YE>'1U<FPL(%\H(DYE
M>'0@36]N=&@B*2D@+B!(;W)D93HZ:6UG*"=N878O<FEG:'0N<&YG)RP@)SXG
M+"`G)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D
M92<I*2`N("<\+V$^)R`Z("<G(#\^"B`@/"]T:#X*/"]T<CX*"CQT<CX\=&0@
M8V]L<W!A;CTB-2(^/'1A8FQE(&-L87-S/2)M;VYT:&=R:60B(&-E;&QS<&%C
M:6YG/2(Q(B!W:61T:#TB,3`P)2(^"@H\='(^"CP_<&AP"B1D87EO9G=E96L@
M/2`P.PHD;V9F<V5T(#T@)'!R969S+3YG971686QU92@G=V5E:U]S=&%R=%]M
M;VYD87DG*2`_(#$@.B`P.PIF;W(@*"1D87D@/2`H,2`M("1S=&%R=&1A>2D[
M("1D87D@/"`H,2`M("1S=&%R=&1A>2D@*R`D9&%Y<TEN5FEE=SL@)&1A>2LK
M*3H*/SX*("`\=&@@8VQA<W,](FET96TB/CP_<&AP(&5C:&\@<W1R9G1I;64H
M)R5!)RP@;6MT:6UE*#`L(#`L(#`L("1M;VYT:"P@)&1A>2`K("1O9F9S970L
M("1Y96%R*2D@/SX\+W1H/@H\/W!H<"`D9&%Y;V9W965K*RL[(&EF("@H)&1A
M>6]F=V5E:R`E(#<@/3T@,"D@)B8@*"1D87EO9G=E96L@(3T@,"DI.B`_/@H@
M(#QT:#XF;F)S<#L\+W1H/@H\/W!H<"!E;F1I9CL@96YD9F]R.R`_/@H\+W1R
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O;6]N=&@O:&5A9"YI
M;F,`````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-C$`,3`T,3<S-C(W-3,`
M,#(S,34P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QT86)L92!C;&%S<STB;F]P861D:6YG(B!C96QL<W!A8VEN9STB,"(@
M=VED=&@](C$P,"4B/@H\='(^"B`@/'1H(&-L87-S/2)H96%D97(B/@H@(#P_
M<&AP(&5C:&\@*"$D<')I;G1?=FEE=RD@/R!(;W)D93HZ;&EN:R@D<')E=G5R
M;"P@7R@B3&%S="!-;VYT:"(I*2`N($AO<F1E.CII;6<H)VYA=B]L969T+G!N
M9R<L("<\)RP@)R<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I
M<B@G:&]R9&4G*2D@+B`G/"]A/B<@.B`G)R`_/@H@(#P_<&AP(&5C:&\@)'1I
M=&QE(#\^"B`@/#]P:'`@96-H;R`H(21P<FEN=%]V:65W*2`_($AO<F1E.CIL
M:6YK*"1N97AT=7)L+"!?*").97AT($UO;G1H(BDI("X@2&]R9&4Z.FEM9R@G
M;F%V+W)I9VAT+G!N9R<L("<^)RP@)R<L("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<@.B`G)R`_/@H@(#PO
M=&@^"CPO='(^"@H\='(^/'1D/CQT86)L92!C;&%S<STB;6]N=&AG<FED(&YO
M<&%D9&EN9R(@8V5L;'-P86-I;F<](C$B('=I9'1H/2(Q,#`E(CX*"CQT<CX*
M/#]P:'`@:68@*"$D<')E9G,M/F=E=%9A;'5E*"=W965K7W-T87)T7VUO;F1A
M>2<I*3H@/SX*/'1H(&-L87-S/2)I=&5M(CX\/W!H<"!E8VAO(%\H(E-U;F1A
M>2(I(#\^/"]T:#X*/#]P:'`@96YD:68[(#\^"CQT:"!C;&%S<STB:71E;2(^
M/#]P:'`@96-H;R!?*")-;VYD87DB*2`_/CPO=&@^"CQT:"!C;&%S<STB:71E
M;2(^/#]P:'`@96-H;R!?*")4=65S9&%Y(BD@/SX\+W1H/@H\=&@@8VQA<W,]
M(FET96TB/CP_<&AP(&5C:&\@7R@B5V5D;F5S9&%Y(BD@/SX\+W1H/@H\=&@@
M8VQA<W,](FET96TB/CP_<&AP(&5C:&\@7R@B5&AU<G-D87DB*2`_/CPO=&@^
M"CQT:"!C;&%S<STB:71E;2(^/#]P:'`@96-H;R!?*")&<FED87DB*2`_/CPO
M=&@^"CQT:"!C;&%S<STB:71E;2(^/#]P:'`@96-H;R!?*")3871U<F1A>2(I
M(#\^/"]T:#X*/#]P:'`@:68@*"1P<F5F<RT^9V5T5F%L=64H)W=E96M?<W1A
M<G1?;6]N9&%Y)RDI.B`_/@H\=&@@8VQA<W,](FET96TB/CP_<&AP(&5C:&\@
M7R@B4W5N9&%Y(BD@/SX\+W1H/@H\/W!H<"!E;F1I9CL@/SX*/"]T<CX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+W1E;7!L871E<R]A='1E;F1E97,O````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,P`P,C(T,#<`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S+V%T=&5N9&5E<R]A='1E;F1E
M97,N:6YC`````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,C<W`#$P-#$W,S8R-S4S`#`R-3`V
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*9G5N8W1I;VX@
M<&5R9F]R;4%C=&EO;BAI9"P@=F%L=64I"GL*("`@(&1O8W5M96YT+F%T=&5N
M9&5E<T9O<FTN86-T:6]N240N=F%L=64@/2!I9#L*("`@(&1O8W5M96YT+F%T
M=&5N9&5E<T9O<FTN86-T:6]N5F%L=64N=F%L=64@/2!V86QU93L*("`@(&1O
M8W5M96YT+F%T=&5N9&5E<T9O<FTN<W5B;6ET*"D["B`@("!R971U<FX@9F%L
M<V4["GT*"F9U;F-T:6]N('-W:71C:%1I;65S=&%M<"AT:6UE<W1A;7`I"GL*
M("`@(&1O8W5M96YT+F%T=&5N9&5E<T9O<FTN=&EM97-T86UP+G9A;'5E(#T@
M=&EM97-T86UP.PH@("`@9&]C=6UE;G0N871T96YD965S1F]R;2YS=6)M:70H
M*3L*("`@(')E='5R;B!F86QS93L*?0H*9G5N8W1I;VX@<W=I=&-H5FEE=RAV
M:65W*0I["B`@("!D;V-U;65N="YA='1E;F1E97-&;W)M+G9I97<N=F%L=64@
M/2!V:65W.PH@("`@9&]C=6UE;G0N871T96YD965S1F]R;2YS=6)M:70H*3L*
M("`@(')E='5R;B!F86QS93L*?0HO+R`M+3X*/"]S8W)I<'0^"@H\9F]R;2!M
M971H;V0](G!O<W0B(&%C=&EO;CTB871T96YD965S+G!H<"(@;F%M93TB871T
M96YD965S1F]R;2(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](F%D9"(@
M+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N5F%L=64B('9A
M;'5E/2(B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G9I97<B('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9I97<I(#\^(B`O
M/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)T:6UE<W1A;7`B('9A;'5E
M/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'1I;65S=&%M<"D@/SXB
M("\^"@H\:#$@8VQA<W,](FAE861E<B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1T:71L92D@/SX\+V@Q/@H*/'1A8FQE('=I9'1H/2(Q,#`E(B!C
M96QL<W!A8VEN9STB,"(@8VQA<W,](FQI;F5D4F]W(CX*"CPA+2T@871T96YD
M964@;&ES="!H96%D97(@+2T^"CQT<B!C;&%S<STB:71E;2!N;W=R87`@;&5F
M=$%L:6=N(CX*(#QT:"!W:61T:#TB,B4B/CP_<&AP(&5C:&\@)&1E;&EM9R`_
M/CPO=&@^"B`\=&@@=VED=&@](C0X)2(^/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*%\H(D5M86EL($%D9')E<W,B*2D@/SX\+W1H/@H@/'1H('=I9'1H
M/2(R-24B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA?*")!='1E;F1A
M;F-E(BDI(#\^/"]T:#X*(#QT:"!W:61T:#TB,C4E(CX\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H7R@B4F5S<&]N<V4B*2D@/SX\+W1H/@H\+W1R/@H*
M/"$M+2!A='1E;F1E97,@+2T^"CP_<&AP("1I(#T@,#L@:68@*&5M<'1Y*"1A
M='1E;F1E97,I*3H@/SX*(#QT<CX\=&0@8V]L<W!A;CTB-"(^/&5M/CP_<&AP
M(&5C:&\@7R@B3F\@871T96YD965S(BD@/SX\+V5M/CPO=&0^/"]T<CX*/#]P
M:'`@96QS93H@9F]R96%C:"`H)&%T=&5N9&5E<R!A<R`D96UA:6P@/3X@)'-T
M871U<RDZ(#\^"B`\='(^"B`@/'1D/CP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH
M)R,G+"!S<')I;G1F*%\H(E)E;6]V92`E<R(I+"`D96UA:6PI+"`G)RP@)R<L
M(")P97)F;W)M06-T:6]N*"=R96UO=F4G+"!D96-O9&554DE#;VUP;VYE;G0H
M)R(@+B!R87=U<FQE;F-O9&4H)&5M86EL*2`N("(G*2D[(')E='5R;B!F86QS
M93LB*2`N($AO<F1E.CII;6<H)V1E;&5T92YP;F<G+"`G)RP@;G5L;"P@)')E
M9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<@/SX\+W1D
M/@H@(#QT9#X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL*2`_
M/CPO=&0^"B`@/'1D/@H@("`\<V5L96-T(&YA;64](CP_<&AP(&5C:&\@(F%T
M=&5N9&%N8V5?)&DB(#\^(B!O;F-H86YG93TB<&5R9F]R;4%C=&EO;B@G8VAA
M;F=E871T)RP@9&]C=6UE;G0N871T96YD965S1F]R;2X\/W!H<"!E8VAO(")A
M='1E;F1A;F-E7R1I(B`_/BYV86QU92`K("<@)R`K(&1E8V]D955224-O;7!O
M;F5N="@G/#]P:'`@96-H;R!R87=U<FQE;F-O9&4H)&5M86EL*2`_/B<I*3LB
M/@H@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!+4D].3TQ)5$A?4$%2
M5%]215%525)%1"`_/B(\/W!H<"!I9B`H)'-T871U<ULG871T96YD86YC92==
M(#T]($M23TY/3$E42%]005)47U)%455)4D5$*2`@96-H;R`G('-E;&5C=&5D
M/2)S96QE8W1E9"(G(#\^/CP_<&AP(&5C:&\@2W)O;F]L:71H.CIP87)T5&]3
M=')I;F<H2U)/3D],251(7U!!4E1?4D5154E2140I(#\^/"]O<'1I;VX^"B`@
M("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO($M23TY/3$E42%]005)47T]0
M5$E/3D%,(#\^(CP_<&AP(&EF("@D<W1A='5S6R=A='1E;F1A;F-E)UT@/3T@
M2U)/3D],251(7U!!4E1?3U!424].04PI("!E8VAO("<@<V5L96-T960](G-E
M;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!+<F]N;VQI=&@Z.G!A<G14;U-T<FEN
M9RA+4D].3TQ)5$A?4$%25%]/4%1)3TY!3"D@/SX\+V]P=&EO;CX*("`@(#QO
M<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@2U)/3D],251(7U!!4E1?3D].12`_
M/B(\/W!H<"!I9B`H)'-T871U<ULG871T96YD86YC92==(#T]($M23TY/3$E4
M2%]005)47TY/3D4I("!E8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^
M/#]P:'`@96-H;R!+<F]N;VQI=&@Z.G!A<G14;U-T<FEN9RA+4D].3TQ)5$A?
M4$%25%].3TY%*2`_/CPO;W!T:6]N/@H@("`\+W-E;&5C=#X*("`\+W1D/@H@
M(#QT9#X\/W!H<"!E8VAO($MR;VYO;&ET:#HZ<F5S<&]N<V54;U-T<FEN9R@D
M<W1A='5S6R=R97-P;VYS92==*2`_/CPO=&0^"B`\+W1R/@H@/#]P:'`@)&DK
M*SL@/SX*/#]P:'`@96YD9F]R96%C:#L@/SX*/#]P:'`@96YD:68[(#\^"CPO
M=&%B;&4^"@H\8G(@+SX*"CQT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I
M;F<](C(B(&-L87-S/2)N;W=R87`@8V]N=')O;"(^"B`\='(^"B`@/'1D(&-L
M87-S/2)R:6=H=$%L:6=N(CXF;F)S<#L\<W1R;VYG/CP_<&AP(&5C:&\@2&]R
M9&4Z.FAI9VAL:6=H=$%C8V5S<TME>2A?*")!9&0@871T96YD965S(BDL("1A
M:R`]($AO<F1E.CIG971!8V-E<W-+97DH7R@B061D(&%T=&5N9&5E<R(I*2D@
M/SX\+W-T<F]N9SX\+W1D/@H@(#QT9#X\:6YP=70@='EP93TB=&5X="(@;F%M
M93TB;F5W071T96YD965S(B!S:7IE/2(U,"(@;6%X;&5N9W1H/2(R-34B(#P_
M<&AP(&5C:&\@*"%E;7!T>2@D86LI*2`_("=A8V-E<W-K97D](B<@+B`D86L@
M+B`G(B`G(#H@)R<@/SXO/CPO=&0^"CP_<&AP(&EF("@D<F5G:7-T<GDM/FAA
M<TUE=&AO9"@G8V]N=&%C=',O<V5A<F-H)RDI.B`_/@H@(#QT9"!A;&EG;CTB
M8V5N=&5R(CX\/W!H<"!E8VAO($AO<F1E.CIL:6YK*"<C)RP@)R<L("=W:61G
M970G+"!N=6QL+"`G=VEN9&]W+F]P96XH7"<G("X@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=C;VYT86-T<RYP:'`G*2`N("=<)RP@7"=C;VYT86-T<UPG+"!<
M)W1O;VQB87(];F\L;&]C871I;VX];F\L<W1A='5S/6YO+'-C<F]L;&)A<G,]
M>65S+')E<VEZ86)L93UY97,L=VED=&@]-34P+&AE:6=H=#TR-S`L;&5F=#TQ
M,#`L=&]P/3$P,%PG*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G
M861D<F5S<V)O;VM?8G)O=W-E+G!N9R<I("X@)SQB<B`O/B<@+B!?*")!9&1R
M97-S($)O;VLB*2`N("<\+V$^)R`_/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)R,G+"`G)RP@)W=I9&=E="<L
M(&YU;&PL(")R971U<FX@<&5R9F]R;4%C=&EO;B@G97AP86YD)RP@)R<I.R(I
M("X@2&]R9&4Z.FEM9R@G97AP86YD+G!N9R<I("X@)SQB<B`O/B<@+B!?*")%
M>'!A;F0@3F%M97,B*2`N("<\+V$^)R`_/CPO=&0^"B`@/'1D('=I9'1H/2(Q
M,#`E(CXF;F)S<#L\+W1D/@H\/W!H<"!E;F1I9CL@/SX*(#PO='(^"CPO=&%B
M;&4^"@H\8G(@+SX*/&1I=CX*(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S
M/2)B=71T;VXB(&YA;64](F%D9$YE=R(@=F%L=64](CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<RA?*")3879E($%T=&5N9&5E<R(I*2`_/B(@+SX*(#P_
M<&AP(&EF("@A96UP='DH)&%T=&5N9&5E<RDI.B`_/CQI;G!U="!T>7!E/2)S
M=6)M:70B(&-L87-S/2)B=71T;VXB(&YA;64](F-L96%R06QL(B!V86QU93TB
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*%\H(D-L96%R(&%L;"!A='1E
M;F1E97,B*2D@/SXB("\^/#]P:'`@96YD:68[(#\^"CPO9&EV/@H*/&)R("\^
M"CP_<&AP(&5C:&\@)'1A8G,M/G)E;F1E<B@D=FEE=RD@+B`D=F9B7VAT;6P@
M/SX*/"]F;W)M/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR
M;VYO;&ET:"]T96UP;&%T97,O8V%L96YD87)S+P``````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(R,S8W`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]C86QE;F1A<G,O
M8V%L96YD87)S+FEN8P`````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C4Q,``Q,#0Q-S,V,C<U
M,P`P,C4P,38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&1I=B!I9#TB<&%G92(^"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V
M87-C<FEP="(^"CPA+2T*"G9A<B!E9&ET55),(#T@9&5C;V1E55))0V]M<&]N
M96YT*"<\/W!H<"!E8VAO(')A=W5R;&5N8V]D92A5=&EL.CIA9&1087)A;65T
M97(H2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D
M92<I("X@)R]S97)V:6-E<R]S:&%R97,O961I="YP:'`_87!P/6MR;VYO;&ET
M:"<L('1R=64I+"`G<VAA<F4G+"`G0$E$0"<L(&9A;'-E*2D@/SXG*3L*=F%R
M(&-A;F-E;%-U8FUI="`](&9A;'-E.PIV87(@9FEE;&1S(#T@;F5W($%R<F%Y
M*"D["CP_<&AP(&9O<F5A8V@@*"1M>5]C86QE;F1A<G,@87,@)&ED(#T^("1C
M86PI.B`_/@IF:65L9'-;)SP_<&AP(&5C:&\@<F%W=7)L96YC;V1E*"1I9"D@
M/SXG72`](&YE=R!!<G)A>2@*("`@("`@("`B/#]P:'`@96-H;R!R87=U<FQE
M;F-O9&4H)&-A;"T^9V5T*"=N86UE)RDI(#\^(BP*("`@("`@("`B/#]P:'`@
M96-H;R!R87=U<FQE;F-O9&4H)&-A;"T^9V5T*"=D97-C)RDI(#\^(BD["CP_
M<&AP(&5N9&9O<F5A8V@[(#\^"@IF=6YC=&EO;B!N97=#:&]I8V4H*0I["B`@
M("!V87(@=7)L3V)J(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260@/R!D;V-U
M;65N="YG971%;&5M96YT0GE)9"@G8V%L96YD87)?=7)L)RD@.B!E=F%L*"=D
M;V-U;65N="YA;&PN8V%L96YD87)?=7)L)RD["B`@("!V87(@<W5B<V-R:7!T
M:6]N57)L3V)J(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260@/R!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G8V%L96YD87)?<W5B<V-R:7!T:6]N7W5R;"<I
M(#H@979A;"@G9&]C=6UE;G0N86QL+F-A;&5N9&%R7W-U8G-C<FEP=&EO;E]U
M<FPG*3L*("`@('9A<B!S:&%R92`](&1O8W5M96YT+G-H87)E<RYS:&%R92YO
M<'1I;VYS6V1O8W5M96YT+G-H87)E<RYS:&%R92YS96QE8W1E9$EN9&5X72YV
M86QU93L*("`@(&EF("AS:&%R92`]/2`M,2D@>PH@("`@("`@(&1O8W5M96YT
M+G-H87)E<RYE9&ET7W-H87)E+G9A;'5E(#T@)R<["B`@("`@("`@9&]C=6UE
M;G0N<VAA<F5S+G)E<V5T*"D["B`@("`@("`@=7)L3V)J+FEN;F5R2%1-3"`]
M("<G.PH@("`@("`@('-U8G-C<FEP=&EO;E5R;$]B:B`]("<G.PH@("`@?2!E
M;'-E('L*("`@("`@("!D;V-U;65N="YS:&%R97,N961I=%]S:&%R92YV86QU
M92`](&1E8V]D955224-O;7!O;F5N="AS:&%R92D["B`@("`@("`@9&]C=6UE
M;G0N<VAA<F5S+FED+G9A;'5E(#T@9&5C;V1E55))0V]M<&]N96YT*&9I96QD
M<UMS:&%R95U;,%TI.PH@("`@("`@(&1O8W5M96YT+G-H87)E<RYD97-C<FEP
M=&EO;BYV86QU92`](&1E8V]D955224-O;7!O;F5N="AF:65L9'-;<VAA<F5=
M6S%=*3L*("`@("`@("!U<FQ/8FHN:6YN97)(5$U,(#T@(CP_<&AP(&5C:&\@
M571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G;6]N
M=&@N<&AP)RP@=')U92P@+3$I+"`G9&ES<&QA>5]C86PG+"`G)RD@/SXB("L@
M<VAA<F4["B`@("`@("`@<W5B<V-R:7!T:6]N57)L3V)J+FEN;F5R2%1-3"`]
M("(\/W!H<"!E8VAO(%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ87!P;&EC
M871I;VY5<FPH)VEC<RYP:'`G+"!T<G5E+"`M,2DL("=C)RP@)R<I(#\^(B`K
M('-H87)E.PH@("`@?0I]"@IF=6YC=&EO;B!C:&5C:U-U8FUI="@I"GL*("`@
M(&EF("@A9&]C=6UE;G0N<VAA<F5S+F5D:71?<VAA<F4N=F%L=64I('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@8V%N8V5L(#T@8V%N8V5L
M4W5B;6ET.PH@("`@8V%N8V5L4W5B;6ET(#T@9F%L<V4["CP_<&AP(&EF("@D
M8G)O=W-E<BT^9V5T0G)O=W-E<B@I(#T]("=M<VEE)R`F)B`D8G)O=W-E<BT^
M9V5T36%J;W(H*2`^/2`T*3H@/SX*("`@('=I;F1O=RYE=F5N="YR971U<FY6
M86QU92`]("%C86YC96P["CP_<&AP(&5N9&EF.R`_/@H@("`@<F5T=7)N("%C
M86YC96P["GT*"F9U;F-T:6]N('-H;W=(:61E*&-A;&5N9&%R*0I["B`@("!D
M;V-U;65N="YS:&]W:&ED92YD:7-P;&%Y7V-A;"YV86QU92`](&-A;&5N9&%R
M+FED.PH@("`@9&]C=6UE;G0N<VAO=VAI9&4N<W5B;6ET*"D["GT*"B\O+2T^
M"CPO<V-R:7!T/@H*/#]P:'`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=D:7-P
M;&%Y7V-A;',G*2`F)B`H*&-O=6YT*"1R96UO=&5?8V%L96YD87)S*2!\?"!C
M;W5N="@D1TQ/0D%,4ULG86QL7V-A;&5N9&%R<R==*2`^(#$I*2DZ(#\^"CQF
M;W)M(&%C=&EO;CTB8V%L96YD87)S+G!H<"(@;65T:&]D/2)P;W-T(B!N86UE
M/2)S:&]W:&ED92(^"CP_<&AP(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB9&ES<&QA>5]C86PB("\^"@H\
M:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(%\H(D1I<W!L87D@0V%L
M96YD87)S(BD@/SX*/"]H,3X*"CQD:78@8VQA<W,](FAE861E<F)O>"(^"@H\
M/W!H<"!I9B`H8V]U;G0H)&UY7V-A;&5N9&%R<RDI.B`_/@H\9&EV(&-L87-S
M/2)C;VYT<F]L(CX*(#QS=')O;F<^/#]P:'`@96-H;R!?*")->2!#86QE;F1A
M<G,B*2`_/CPO<W1R;VYG/@H\+V1I=CX*/#]P:'`@9F]R96%C:"`H)&UY7V-A
M;&5N9&%R<R!A<R`D:60@/3X@)&-A;"DZ(#\^"CQD:78^"B`\:6YP=70@;VYC
M:&%N9V4](G-H;W=(:61E*'1H:7,I(B!T>7!E/2)C:&5C:V)O>"(@;F%M93TB
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1I9"D@/SXB(&ED/2(\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ED*2`_/B(\/W!H<"!E8VAO("AI
M;E]A<G)A>2@D:60L("1D:7-P;&%Y7V-A;&5N9&%R<RD@/R`G(&-H96-K960]
M(F-H96-K960B)R`Z("<G*2`_/B`O/B`\;&%B96P@9F]R/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&ED*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1C86PM/F=E="@G;F%M92<I*2`_/CPO;&%B96P^"CPO9&EV
M/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\/W!H<"!E;F1I9CL@/SX*"CP_<&AP
M(&EF("AC;W5N="@D<VAA<F5D7V-A;&5N9&%R<RDI.B`_/@H\8G(@8VQA<W,]
M(G-P86-E<B(@+SX*/&1I=B!C;&%S<STB8V]N=')O;"(^"B`\<W1R;VYG/CP_
M<&AP(&5C:&\@7R@B4VAA<F5D($-A;&5N9&%R<R(I(#\^/"]S=')O;F<^"CPO
M9&EV/@H\/W!H<"!F;W)E86-H("@D<VAA<F5D7V-A;&5N9&%R<R!A<R`D:60@
M/3X@)&-A;"DZ(#\^"CQD:78^"B`\:6YP=70@;VYC:&%N9V4](G-H;W=(:61E
M*'1H:7,I(B!T>7!E/2)C:&5C:V)O>"(@;F%M93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1I9"D@/SXB(&ED/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&ED*2`_/B(\/W!H<"!E8VAO("AI;E]A<G)A>2@D:60L("1D
M:7-P;&%Y7V-A;&5N9&%R<RD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G
M*2`_/B`O/B`\;&%B96P@9F]R/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&ED*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C86PM
M/F=E="@G;F%M92<I*2`_/CPO;&%B96P^"CPO9&EV/@H\/W!H<"!E;F1F;W)E
M86-H.R`_/@H\/W!H<"!E;F1I9CL@/SX*"CP_<&AP(&EF("AC;W5N="@D<F5M
M;W1E7V-A;&5N9&%R<RDI.B`_/@H\8G(@8VQA<W,](G-P86-E<B(@+SX*/&1I
M=B!C;&%S<STB8V]N=')O;"(^"B`\<W1R;VYG/CP_<&AP(&5C:&\@7R@B4F5M
M;W1E($-A;&5N9&%R<R(I(#\^/"]S=')O;F<^"CPO9&EV/@H\/W!H<"!F;W)E
M86-H("@D<F5M;W1E7V-A;&5N9&%R<R!A<R`D:60@/3X@)&-A;"DZ(#\^"CQD
M:78^"B`\:6YP=70@;VYC:&%N9V4](G-H;W=(:61E*'1H:7,I(B!T>7!E/2)C
M:&5C:V)O>"(@;F%M93TB<F5M;W1E7SP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D8V%L6R=U<FPG72D@/SXB(&ED/2)R96UO=&5?/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1C86Q;)W5R;"==*2`_/B(\/W!H<"!E8VAO("AI
M;E]A<G)A>2@D8V%L6R=U<FPG72P@)&1I<W!L87E?<F5M;W1E7V-A;&5N9&%R
M<RD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G*2`_/B`O/B`\;&%B96P@
M9F]R/2)R96UO=&5?/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C86Q;
M)W5R;"==*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C86Q;
M)VYA;64G72D@/SX\+VQA8F5L/@H\+V1I=CX*/#]P:'`@96YD9F]R96%C:#L@
M/SX*/#]P:'`@96YD:68[(#\^"@H\+V1I=CX*"CPO9F]R;3X*"CQB<B`O/@H\
M/W!H<"!E;F1I9CL@/SX*"CQF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB8W)E
M871E(B!A8W1I;VX](F-A;&5N9&%R<RYP:'`B(&]N<W5B;6ET/2)R971U<FX@
M9&]C=6UE;G0N8W)E871E+FED+G9A;'5E("$]("<G.R(^"CP_<&AP(&5C:&\@
M571I;#HZ9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB86-T:6]N240B('9A;'5E/2)S879E(B`O/@H*/&@Q(&-L87-S/2)H96%D
M97(B/@H@/#]P:'`@96-H;R!?*")#<F5A=&4@0V%L96YD87(B*2`_/@H\+V@Q
M/@H\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(B!C;&%S<STB
M:&5A9&5R8F]X(CX*(#QT<CX*("`\=&0@=VED=&@](C$U)2(@8VQA<W,](FYO
M=W)A<"(@86QI9VX](G)I9VAT(CX*("`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H
M(DYA;64B*2`_/CPO<W1R;VYG/B9N8G-P.PH@(#PO=&0^"B`@/'1D('=I9'1H
M/2(X-24B/@H@("`\:6YP=70@='EP93TB=&5X="(@;F%M93TB:60B('-I>F4]
M(C,P(B!M87AL96YG=&@](C8P(B`O/@H@(#PO=&0^"B`\+W1R/@H@/'1R/@H@
M(#QT9#X\+W1D/@H@(#QT9#X*("`@/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M
M93TB<V%V92(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M0W)E871E(BD@/SXB("\^"B`@/"]T9#X*(#PO='(^"CPO=&%B;&4^"CPO9F]R
M;3X*"CQB<B`O/@H*/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)S:&%R97,B
M(&%C=&EO;CTB8V%L96YD87)S+G!H<"(@;VYS=6)M:70](G)E='5R;B!C:&5C
M:U-U8FUI="@I.R(^"CP_<&AP(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)S
M879E(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)E9&ET7W-H87)E
M(B!V86QU93TB(B`O/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H
M;R!?*")%9&ET($-A;&5N9&%R<R(I(#\^"CPO:#$^"@H\=&%B;&4@=VED=&@]
M(C$P,"4B(&-E;&QS<&%C:6YG/2(P(B!C;&%S<STB:&5A9&5R8F]X(CX*(#QT
M<CX*("`\=&0@=VED=&@](C$U)2(@8VQA<W,](FYO=W)A<"(@86QI9VX](G)I
M9VAT(CX*("`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D-A;&5N9&%R(BD@/SX\
M+W-T<F]N9SXF;F)S<#L*("`\+W1D/@H@(#QT9"!W:61T:#TB.#4E(CX*("`@
M/'-E;&5C="!N86UE/2)S:&%R92(@;VYC:&%N9V4](FYE=T-H;VEC92@I(CX*
M("`@(#QO<'1I;VX@=F%L=64](BTQ(CX\/W!H<"!E8VAO(%\H(E-E;&5C="!A
M(&-A;&5N9&%R('1O(&5D:70B*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@9F]R
M96%C:"`H)&UY7V-A;&5N9&%R<R!A<R`D:60@/3X@)&-A;"DZ(#\^"B`@("`\
M;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ED
M*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C86PM/F=E="@G
M;F%M92<I*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@96YD9F]R96%C:#L@/SX*
M("`@/"]S96QE8W0^"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S
M/2)N;W=R87`B(&%L:6=N/2)R:6=H="(^"B`@(#QS=')O;F<^/#]P:'`@96-H
M;R!?*").86UE(BD@/SX\+W-T<F]N9SXF;F)S<#L*("`\+W1D/@H@(#QT9#X*
M("`@/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](FED(B!S:7IE/2(S,"(@;6%X
M;&5N9W1H/2(V,"(@+SX*("`\+W1D/@H@/"]T<CX*(#QT<CX*("`\=&0@8VQA
M<W,](FYO=W)A<"(@86QI9VX](G)I9VAT(CX*("`@/'-T<F]N9SX\/W!H<"!E
M8VAO(%\H(E!E<FUI<W-I;VYS(BD@/SX\+W-T<F]N9SX*("`\+W1D/@H@(#QT
M9#X*("`@/&EN<'5T('1Y<&4](F)U='1O;B(@;F%M93TB<&5R;7,B(&-L87-S
M/2)B=71T;VXB(&]N8VQI8VL](FEF("AD;V-U;65N="YS:&%R97,N961I=%]S
M:&%R92YV86QU92D@<&]P=7`H961I=%523"YR97!L86-E*"\E-#!)1"4T,"\L
M(&1O8W5M96YT+G-H87)E<RYE9&ET7W-H87)E+G9A;'5E*2D[(&5L<V4@86QE
M<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")9;W4@;F5E9"!T;R!S96QE
M8W0@82!C86QE;F1A<B!F:7)S="(I*2`_/B<I(B!V86QU93TB/#]P:'`@96-H
M;R!?*")%9&ET(BD@/SXB("\^"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D
M(&%L:6=N/2)R:6=H="(@=F%L:6=N/2)T;W`B(&-L87-S/2)N;W=R87`B/@H@
M("`\<W1R;VYG/CP_<&AP(&5C:&\@7R@B1&5S8W)I<'1I;VXB*2`_/CPO<W1R
M;VYG/B9N8G-P.PH@(#PO=&0^"B`@/'1D/@H@("`\=&5X=&%R96$@;F%M93TB
M9&5S8W)I<'1I;VXB(')O=W,](C0B(&-O;',](C8P(CX\+W1E>'1A<F5A/@H@
M(#PO=&0^"B`\+W1R/@H@/'1R/@H@(#QT9"!A;&EG;CTB<FEG:'0B('9A;&EG
M;CTB=&]P(B!C;&%S<STB;F]W<F%P(CX*("`@/'-T<F]N9SX\/W!H<"!E8VAO
M(%\H(E523"(I(#\^/"]S=')O;F<^)FYB<W`["B`@/"]T9#X*("`\=&0^"B`@
M(#QS<&%N(&ED/2)C86QE;F1A<E]U<FPB/CPO<W!A;CX*("`\+W1D/@H@/"]T
M<CX*(#QT<CX*("`\=&0@86QI9VX](G)I9VAT(B!V86QI9VX](G1O<"(@8VQA
M<W,](FYO=W)A<"(^"B`@(#QS=')O;F<^/#]P:'`@96-H;R!?*")296UO=&4@
M4W5B<V-R:7!T:6]N(%523"(I(#\^/"]S=')O;F<^)FYB<W`["B`@/"]T9#X*
M("`\=&0^"B`@(#QS<&%N(&ED/2)C86QE;F1A<E]S=6)S8W)I<'1I;VY?=7)L
M(CX\+W-P86X^"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D/CPO=&0^"B`@
M/'1D/@H@("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)S879E(B!C;&%S
M<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")3879E(BD@/SXB("\^
M"B`@(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](F1E;&5T92(@8VQA<W,]
M(F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N<VAA<F5S+F%C=&EO;DE$+G9A
M;'5E(#T@)V1E;&5T92<B('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1E;&5T92(I
M(#\^(B`O/@H@(#PO=&0^"B`\+W1R/@H\+W1A8FQE/@H*/"]F;W)M/@H*/&)R
M("\^"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@7R@B37D@1G)E
M92]"=7-Y(%523"(I(#\^"CPO:#$^"CQD:78@8VQA<W,](FAE861E<F)O>"(^
M"B`\9&EV(&-L87-S/2)C;VYT<F]L(CX*("`\/W!H<"!E8VAO(%\H(D-O<'D@
M=&AE(%523"!B96QO=R!F;W(@=7-E('=H97)E=F5R('EO=2!N965D('EO=7(@
M1G)E92]"=7-Y(%523#HB*2`_/@H@/"]D:78^"B`\<"!C;&%S<STB=&5X="(^
M"B`@/#]P:'`@96-H;R!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=F8BYP:'`G+"!T<G5E+"`M,2DL("=U)RP@075T:#HZ9V5T
M075T:"@I*2`_/@H@/"]P/@H\+V1I=CX*"CPO9&EV/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S+V-A;&5N9&%R
M<R]S96%R8V@N:6YC````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,38P`#$P-#$W,S8R
M-S4S`#`R-#,R,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\:#$@8VQA<W,](FAE861E<B(^/#]P:'`@96-H;R!?*")396%R
M8V@@0V%L96YD87)S(BD@/SX\+V@Q/@H*/&1I=B!C;&%S<STB:71E;2(^"CQF
M;W)M(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"@I(#\^(CX*
M/#]P:'`@96-H;R!5=&EL.CIF;W)M26YP=70H*2`_/@H\/W!H<"!E8VAO($AO
M<F1E.CIL86)E;"@G<V5A<F-H)RP@7R@B4V5A<F-H(&9O<B!C86QE;F1A<G,@
M8V]N=&%I;FEN9SHB*2D@/SX\8G(@+SX*/&EN<'5T('1Y<&4](G1E>'0B(&YA
M;64](G-E87)C:"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D<V5A<F-H*2`_/B(@+SX*/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB
M<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")3
M96%R8V@B*2`_/B(@+SX*/"]F;W)M/@H\+V1I=CX*"CP_<&AP(&EF("@D<F5S
M=6QT<RDZ(#\^"CQB<B!C;&%S<STB<W!A8V5R(B`O/@H*/&1I=B!C;&%S<STB
M:&5A9&5R(CX*("`\/W!H<"!P<FEN=&8H7R@B)60@8V%L96YD87)S(&9O=6YD
M(BDL(&-O=6YT*"1R97-U;'1S*2D@/SX*("`\<W!A;B!C;&%S<STB<VUA;&QH
M96%D97(B/CP_<&AP(&5C:&\@7R@B*$-L:6-K(&]N(&-A;&5N9&%R(&YA;64@
M=&\@<W=I=&-H('1H92!C86QE;F1A<B=S('9I<VEB:6QI='D@:6X@=&AE(&UA
M:6X@=VEN9&]W*2(I(#\^/"]S<&%N/@H\+V1I=CX*/'1A8FQE(&-E;&QS<&%C
M:6YG/2(P(B!C;&%S<STB<W1R:7!E9"(@=VED=&@](C$P,"4B/@H\/W!H<"`D
M:2`](#`[(&9O<F5A8V@@*"1R97-U;'1S(&%S("1C86QE;F1A<B`]/B`D<VAA
M<F4I.B`_/@H@(#QT<B!I9#TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1C86QE;F1A<BD@/SXB/@H@("`@/'1D/CP_<&AP(&5C:&\@2&]R9&4Z.FQI
M;FLH)R,G+"`G)RP@)R<L("<G+"`G:68@*'=I;F1O=RYO<&5N97(I('L@=VEN
M9&]W+F]P96YE<BYL;V-A=&EO;BYH<F5F(#T@=VEN9&]W+F]P96YE<BYS96QF
M57)L*UPG)R`N("1C86QE;F1A<B`N("=<)SL@?2!R971U<FX@9F%L<V4G*2`N
M(&AT;6QS<&5C:6%L8VAA<G,H)'-H87)E+3YG970H)VYA;64G*2D@+B`G/"]A
M/B<@/SX\+W1D/@H@(#QT<CX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]T86)L
M93X*/#]P:'`@96YD:68[(#\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]T96UP;&%T97,O9&5L971E+P``````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(Q-C<U`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]D96QE=&4O;VYE+FEN
M8P`````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$P,``Q,#0Q-S,V,C<U,P`P
M,C,Q-#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*:68@*&5M<'1Y*"1U<FPI*2!["B`@("`D=7)L(#T@571I;#HZ
M861D4&%R86UE=&5R*"=M;VYT:"YP:'`G+"!A<G)A>2@G;6]N=&@G(#T^("1M
M;VYT:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=Y96%R)R`]/B`D>65A<BDI.PH@("`@)'5R;"`]($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@D=7)L+"!T<G5E*3L*?2!E;'-E('L*("`@("\O
M($5S8V%P92!54DQS('1H870@8V%M92!F<F]M(&-L:65N="US:61E(&EN<'5T
M+@H@("`@)'5R;"`](&AT;6QS<&5C:6%L8VAA<G,H)'5R;"D["GT*/SX*/&9O
M<FT@86-T:6]N/2)D96QE=F5N=&%C=&EO;BYP:'`B(&UE=&AO9#TB<&]S="(@
M;F%M93TB9&5L971E(CX*/#]P:'`@96-H;R!5=&EL.CIF;W)M26YP=70H*2`_
M/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)Y96%R(B!V86QU93TB/#]P
M:'`@:68@*&ES<V5T*"1Y96%R*2D@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1Y
M96%R*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB;6]N=&@B
M('9A;'5E/2(\/W!H<"!I9B`H:7-S970H)&UO;G1H*2D@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1M;VYT:"D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](FUD87DB('9A;'5E/2(\/W!H<"!I9B`H:7-S970H)&1A>2DI(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D9&%Y*2`_/B(@+SX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB=7)L(B!V86QU93TB/#]P:'`@96-H;R`D=7)L(#\^
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)E=F5N=$E$(B!V86QU
M93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1E=F5N="T^9V5T240H
M*2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F-A;&5N9&%R
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F=E
M=$9O<FU$871A*"=C86QE;F1A<B<I*2`_/B(@+SX*"CQH,2!C;&%S<STB:&5A
M9&5R(CX*(#P_<&AP('!R:6YT9BA?*")$96QE=&4@)7,B*2P@:'1M;'-P96-I
M86QC:&%R<R@D979E;G0M/F=E=%1I=&QE*"DI*2`_/@H\+V@Q/@H\8G(@+SX*
M"CQD:78@8VQA<W,](F)O>"(^"CP_<&AP(&EF("@A96UP='DH)&5V96YT+3YA
M='1E;F1E97,I*3H@/SX*(#QP/CQI;G!U="!I9#TB<V5N9'5P9&%T97,B('1Y
M<&4](F-H96-K8F]X(B!N86UE/2)S96YD=7!D871E<R(@8VAE8VME9#TB8VAE
M8VME9"(@+SX\;&%B96P@9F]R/2)S96YD=7!D871E<R(^(#P_<&AP(&5C:&\@
M7R@B4V5N9"!A(&-A;F-E;"!N;W1I9FEC871I;VX@=&\@86QL(&%T=&5N9&5E
M<R!W:&5N(&1E;&5T:6YG('1H:7,@979E;G0B*2`_/CPO;&%B96P^/"]P/@H\
M/W!H<"!E;F1I9B`_/@H*(#QP/CP_<&AP(&5C:&\@7R@B4&5R;6%N96YT;'D@
M9&5L971E('1H:7,@979E;G0_(BD@/SX\+W`^"@H@/&EN<'5T('1Y<&4](G-U
M8FUI="(@8VQA<W,](F)U='1O;B(@;F%M93TB9&5L971E(B!V86QU93TB/#]P
M:'`@96-H;R!?*")$96QE=&4B*2`_/B(@+SX*(#QA(&-L87-S/2)B=71T;VXB
M(&AR968](CP_<&AP(&5C:&\@)'5R;"`_/B(^/#]P:'`@96-H;R!?*")#86YC
M96PB*2`_/CPO83X*/"]D:78^"@H\+V9O<FT^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O9&5L971E+V1E;&5T92YI;F,`
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,T-C,`,3`T,3<S-C(W-3,`,#(S-C,U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"FEF("AE;7!T>2@D=7)L*2D@>PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A
M<F%M971E<B@G;6]N=&@N<&AP)RP@87)R87DH)VUO;G1H)R`]/B`D;6]N=&@L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G>65A<B<@/3X@)'EE87(I*3L*("`@("1U<FP@/2!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)'5R;"P@=')U92D["GT@96QS92!["B`@("`O+R!%<V-A
M<&4@55),<R!T:&%T(&-A;64@9G)O;2!C;&EE;G0M<VED92!I;G!U="X*("`@
M("1U<FP@/2!H=&UL<W!E8VEA;&-H87)S*"1U<FPI.PI]"C\^"CQF;W)M(&%C
M=&EO;CTB9&5L979E;G1A8W1I;VXN<&AP(B!M971H;V0](G!O<W0B(&YA;64]
M(F1E;&5T92(^"CP_<&AP(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB>65A<B(@=F%L=64](CP_<&AP(&EF
M("AI<W-E="@D>65A<BDI(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D>65A<BD@
M/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FUO;G1H(B!V86QU
M93TB/#]P:'`@:68@*&ES<V5T*"1M;VYT:"DI(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D;6]N=&@I(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)M9&%Y(B!V86QU93TB/#]P:'`@:68@*&ES<V5T*"1D87DI*2!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)&1A>2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](G5R;"(@=F%L=64](CP_<&AP(&5C:&\@)'5R;"`_/B(@+SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB979E;G1)1"(@=F%L=64](CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D979E;G0M/F=E=$ED*"DI(#\^
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)C86QE;F1A<B(@=F%L
M=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D979E;G0M/F=E=$-A
M;&5N9&%R*"DI(#\^(B`O/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@
M<')I;G1F*%\H(D1E;&5T92`E<R(I+"!H=&UL<W!E8VEA;&-H87)S*"1E=F5N
M="T^9V5T5&ET;&4H*2DI(#\^"CPO:#$^"CQB<B`O/@H*/&1I=B!C;&%S<STB
M8F]X(CX*/#]P:'`@:68@*"%E;7!T>2@D979E;G0M/F%T=&5N9&5E<RDI.B`_
M/@H@/'`^/&EN<'5T(&ED/2)S96YD=7!D871E<R(@='EP93TB8VAE8VMB;W@B
M(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB<V5N9'5P9&%T97,B(&-H96-K960]
M(F-H96-K960B("\^/&QA8F5L(&9O<CTB<V5N9'5P9&%T97,B/B`\/W!H<"!E
M8VAO(%\H(E-E;F0@82!C86YC96P@;F]T:69I8V%T:6]N('1O(&%L;"!A='1E
M;F1E97,@=VAE;B!D96QE=&EN9R!T:&ES(&5V96YT(BD@/SX\+VQA8F5L/CPO
M<#X*/#]P:'`@96YD:68@/SX*"B`\<#X\/W!H<"!E8VAO(%\H(D1E;&5T92!T
M:&4@8W5R<F5N="!E=F5N="!O;FQY+"!T:&ES(&]C8W5R<F5N8V4@86YD(&%L
M;"!F=71U<F4@;V-C=7)E;F-E<RP@;W(@86QL(&]C8W5R96YC97,_(BD@/SX\
M+W`^"@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@;F%M
M93TB8W5R<F5N="(@=F%L=64](CP_<&AP(&5C:&\@7R@B0W5R<F5N="(I(#\^
M(B`O/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@;F%M
M93TB9G5T=7)E(B!V86QU93TB/#]P:'`@96-H;R!?*")&=71U<F4B*2`_/B(@
M+SX*(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&YA;64]
M(F%L;"(@=F%L=64](CP_<&AP(&5C:&\@7R@B06QL(BD@/SXB("\^"B`\82!C
M;&%S<STB8G5T=&]N(B!H<F5F/2(\/W!H<"!E8VAO("1U<FP@/SXB/CP_<&AP
M(&5C:&\@7R@B0V%N8V5L(BD@/SX\+V$^"CPO9&EV/@H*/"]F;W)M/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]K<F]N;VQI=&@O=&5M<&QA=&5S+V9B=FEE=R\`````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`R,3<Q-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O9F)V:65W
M+W-E8W1I;VXN='!L````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T,S,`,3`T,3<S
M-C(W-3,`,#(T,#<W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QB<B`O/@H\=&%B;&4@8VQA<W,](FYO=W)A<"(@8V5L;'-P
M86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*(#QT<CX*("`\=&0@8VQA<W,](FQA
M8F5L(CXF;F)S<#L\+W1D/@H@(#QT9"!C;&%S<STB;&%B96PB(&-O;'-P86X]
M(CQT86<Z<W!A;B`O/B(^/'-T<F]N9SX\=&%G.G1I=&QE("\^/"]S=')O;F<^
M/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)L86)E;"(^)FYB<W`[
M/"]T9#X*("`\=&%G.FAO=7)S("\^"B`\+W1R/@H@/'1A9SIR;W=S("\^"B`\
M=&%G.FQE9V5N9"`O/@H\+W1A8FQE/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S+V9B=FEE=R]R;W<N='!L````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`T`#$P-#$W,S8R-S4S`#`R,S(S
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````@
M/'1R/@H@(#QT9"!C;&%S<STB;&%B96PB/CQT86<Z;F%M92`O/CPO=&0^"B`@
M/'1A9SIB;&]C:W,@+SX*(#PO='(^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O
M;F]L:71H+W1E;7!L871E<R]F8G9I97<O96UP='EB;&]C:RYT<&P`````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`R,``Q,#0Q-S,V,C<U,P`P,C0U-S0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/'1D/B9N8G-P.SPO
M=&0^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP
M;&%T97,O9F)V:65W+V)U<WEB;&]C:RYT<&P`````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,S4`,3`T,3<S-C(W-3,`,#(T-#(V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QT9"!C;&%S<STB8G5S>2(^)FYB<W`[
M/"]T9#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S+V9B=FEE
M=R]L96=E;F0N='!L````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,3`U`#$P-#$W
M,S8R-S4S`#`R,S8V-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````@/'1R/@H@(#QT9"!C;&%S<STB;&%B96PB/B9N8G-P.SPO
M=&0^"B`@/'1D(&-L87-S/2)L86)E;"(@8V]L<W!A;CTB/'1A9SIS<&%N("\^
M(CXF;F)S<#L\+W1D/@H@/"]T<CX*(#QT<CX*("`\=&0@8VQA<W,](FQA8F5L
M(CXF;F)S<#L\+W1D/@H@(#QT9"!C;&%S<STB;&%B96PB(&-O;'-P86X](CQT
M86<Z<W!A;B`O/B(^"B`@(#QS<&%N('-T>6QE/2)P861D:6YG+6QE9G0Z,35P
M>#LB(&-L87-S/2)B=7-Y(CXF;F)S<#L\+W-P86X^"B`@(#QS<&%N(&-L87-S
M/2)L96=E;F0B/CQG971T97AT/D)U<WD\+V=E='1E>'0^/"]S<&%N/@H@("`\
M<W!A;B!S='EL93TB<&%D9&EN9RUL969T.C$U<'@[(B!C;&%S<STB9G)E92(^
M)FYB<W`[/"]S<&%N/@H@("`\<W!A;B!C;&%S<STB;&5G96YD(CX\9V5T=&5X
M=#Y0;W-S:6)L92!-965T:6YG(%1I;64\+V=E='1E>'0^/"]S<&%N/@H@("`\
M<W!A;B!S='EL93TB<&%D9&EN9RUL969T.C$U<'@[(B!C;&%S<STB=6YK;F]W
M;B(^)FYB<W`[/"]S<&%N/@H@("`\<W!A;B!C;&%S<STB;&5G96YD(CX\9V5T
M=&5X=#Y.;R!);F9O<FUA=&EO;CPO9V5T=&5X=#X\+W-P86X^"B`@/"]T9#X*
M(#PO='(^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&5M<&QA=&5S
M+V9B=FEE=R]U;FMN;W=N8FQO8VLN='!L````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#0P
M`#$P-#$W,S8R-S4S`#`R-3$S-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\=&0@8VQA<W,](G5N:VYO=VXB/B9N8G-P.SPO
M=&0^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]F8G9I97<O:&5A
M9&5R+G1P;``````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$P-0`Q,#0Q-S,V,C<U
M,P`P,C,V-3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&1I=B!C;&%S<STB:&5A9&5R(B!S='EL93TB=&5X="UA;&EG;CIC
M96YT97(B/@H@/'1A9SIT:71L92`O/@H\+V1I=CX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O9F)V:65W+VUE971I;F=B;&]C:RYT
M<&P`````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,S4`,3`T,3<S-C(W-3,`,#(U,#<T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QT9"!C
M;&%S<STB9G)E92(^)FYB<W`[/"]T9#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI
M=&@O=&5M<&QA=&5S+V-O;G1A8W1S+P``````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`R,C(U,0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34P-C<`,3`T,3<S-C(W-3,`,#(T
M-3<P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H*=F%R(&1I
M<W!L87D@/2!D96-O9&554DE#;VUP;VYE;G0H(CP_<&AP(&5C:&\@*"%E;7!T
M>2@D9&ES<&QA>2D@/R!R87=U<FQE;F-O9&4H)&1I<W!L87DI(#H@)VYA;64G
M*2`_/B(I.PH*9G5N8W1I;VX@8VAA;F=E1&ES<&QA>2@I"GL*("`@('9A<B!L
M:7-T1&ES<&QA>2`](&1O8W5M96YT+F-O;G1A8W1S+F1I<W!L87D["@H@("`@
M:68@*&QI<W1$:7-P;&%Y+F]P=&EO;G-;;&ES=$1I<W!L87DN<V5L96-T961)
M;F1E>%TN=F%L=64@(3T@9&ES<&QA>2D@>PH@("`@("`@(&1I<W!L87D@/2!L
M:7-T1&ES<&QA>2YO<'1I;VYS6VQI<W1$:7-P;&%Y+G-E;&5C=&5D26YD97A=
M+G9A;'5E.PH*("`@("`@("!S(#T@9&]C=6UE;G0N8V]N=&%C=',N<V5A<F-H
M7W)E<W5L=',["B`@("`@("`@9F]R*'9A<B!I(#T@,#L@:2`\(',N;&5N9W1H
M.R!I*RLI('L*("`@("`@("`@("`@=F%R('1E;7`@/2!S+F]P=&EO;G-;:5TN
M=F%L=64["B`@("`@("`@("`@(&EF("AT96UP(#T]("(B*2![(&-O;G1I;G5E
M.R!]"@H@("`@("`@("`@("!S+F]P=&EO;G-;:5TN=F%L=64@/2!E<V-A<&4H
M<RYO<'1I;VYS6VE=+G1E>'0I.PH@("`@("`@("`@("!S+F]P=&EO;G-;:5TN
M=&5X="`]('5N97-C87!E*'1E;7`I.PH@("`@("`@('T*"B`@("`@("`@9"`]
M(&1O8W5M96YT+F-O;G1A8W1S+G-E;&5C=&5D7V%D9')E<W-E<SL*("`@("`@
M("!F;W(H=F%R(&D@/2`P.R!I(#P@9"YL96YG=&@[(&DK*RD@>PH@("`@("`@
M("`@("!V87(@=&5M<"`](&0N;W!T:6]N<UMI72YV86QU93L*("`@("`@("`@
M("`@:68@*'1E;7`@/3T@(B(I('L@8V]N=&EN=64[('T*"B`@("`@("`@("`@
M(&0N;W!T:6]N<UMI72YV86QU92`](&5S8V%P92AD+F]P=&EO;G-;:5TN=&5X
M="D["B`@("`@("`@("`@(&0N;W!T:6]N<UMI72YT97AT(#T@=6YE<V-A<&4H
M=&5M<"D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO;B!P87-S061D<F5S
M<V5S*"D*>PH@("`@=F%R(&QI<W0@/2!D;V-U;65N="YC;VYT86-T<RYS96QE
M8W1E9%]A9&1R97-S97,["B`@("!V87(@<V$@/2`G)SL*"B`@("!F;W(@*'9A
M<B!I(#T@,#L@:2`\(&QI<W0N;&5N9W1H.R!I*RLI('L*("`@("`@("!V87(@
M:71E;2`](&QI<W0N;W!T:6]N<UMI73L*("`@("`@("!I9B`H:71E;2YV86QU
M92`]/2`G)RD@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@
M("`@("`@<V$@*ST@:71E;2YV86QU92`K("=\)R`K(&ET96TN=&5X="`K("=\
M)SL*("`@('T*("`@(&1O8W5M96YT+F-O;G1A8W1S+G-A+G9A;'5E(#T@<V$[
M"GT*"F9U;F-T:6]N(&%D9$%D9')E<W,H*0I["B`@("!V87(@<R`](&1O8W5M
M96YT+F-O;G1A8W1S+G-E87)C:%]R97-U;'1S.PH@("`@=F%R(&0@/2!D;V-U
M;65N="YC;VYT86-T<RYS96QE8W1E9%]A9&1R97-S97,["@H@("`@:68@*',N
M<V5L96-T961);F1E>"`\(#`I('L*("`@("`@("!A;&5R="@G/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I
M<G-T+B(I*2`_/B<I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T@96QS
M92!["B`@("`@("`@9F]R("AV87(@:2`](#`[(&D@/"!S+FQE;F=T:#L@:2LK
M*2!["B`@("`@("`@("`@('9A<B!I=&5M(#T@<RYO<'1I;VYS6VE=.PH@("`@
M("`@("`@("!I9B`H:71E;2YV86QU92`]/2`B(BD@>R!C;VYT:6YU93L@?0H@
M("`@("`@("`@("!I9B`H:71E;2YS96QE8W1E9"D@>PH@("`@("`@("`@("`@
M("`@9"YO<'1I;VYS6V0N;&5N9W1H72`](&YE=R!/<'1I;VXH:71E;2YT97AT
M+"!I=&5M+G9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M?0H*9G5N8W1I;VX@=7!D871E365S<V%G92@I"GL*("`@(&EF("AP87)E;G0N
M;W!E;F5R+F-L;W-E9"D@>PH@("`@("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B5&AE($5D:70@071T96YD965S('-C<F5E;B!I<R!N;R!L
M;VYG97(@<')E<V5N="X@17AI=&EN9RXB*2D@/SXG*3L*("`@("`@("!T:&ES
M+F-L;W-E*"D["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&EF("@A<&%R
M96YT+F]P96YE<BYD;V-U;65N="YA='1E;F1E97-&;W)M*2!["B`@("`@("`@
M86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")9;W4@8V%N(&]N;'D@
M=7-E('1H:7,@9F]R;2!F<F]M('1H92!%9&ET($%T=&5N9&5E<R!S8W)E96XN
M(BDI(#\^)RD["B`@("`@("`@=&AI<RYC;&]S92@I.PH@("`@("`@(')E='5R
M;CL*("`@('T*"B`@("!V87(@;&ES="`](&1O8W5M96YT+F-O;G1A8W1S+G-E
M;&5C=&5D7V%D9')E<W-E<SL*("`@('9A<B!F:65L9"`]('!A<F5N="YO<&5N
M97(N9&]C=6UE;G0N871T96YD965S1F]R;2YN97=!='1E;F1E97,["B`@("!F
M;W(@*'9A<B!I(#T@,#L@:2`\(&QI<W0N;&5N9W1H.R!I*RLI('L*("`@("`@
M("!I9B`H;&ES="YO<'1I;VYS6VE=+G9A;'5E(#T]("<G*2!["B`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("!I9B`H9&ES<&QA>2`]
M/2`G;F%M92<I('L*("`@("`@("`@("`@=F%R(&%D9')E<W,@/2!U;F5S8V%P
M92AL:7-T+F]P=&EO;G-;:5TN=F%L=64I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@('9A<B!A9&1R97-S(#T@;&ES="YO<'1I;VYS6VE=+G1E>'0[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H9FEE;&0N=F%L=64I('L*("`@("`@
M("`@("`@9FEE;&0N=F%L=64@/2!F:65L9"YV86QU92`K("<L("<@*R!A9&1R
M97-S.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9I96QD+G9A;'5E
M(#T@861D<F5S<SL*("`@("`@("!]"B`@("!]"B`@("!P87)E;G0N;W!E;F5R
M+F1O8W5M96YT+F%T=&5N9&5E<T9O<FTN<W5B;6ET*"D["B`@("!T:&ES+F-L
M;W-E*"D["GT*"F9U;F-T:6]N(')E;6]V94%D9')E<W,H*0I["B`@("!V87(@
M;&ES="`](&1O8W5M96YT+F-O;G1A8W1S+G-E;&5C=&5D7V%D9')E<W-E<SL*
M("`@(&9O<B`H=F%R(&D@/2!L:7-T+FQE;F=T:"`M(#$[(&D@/B`P.R!I+2TI
M('L*("`@("`@("!I9B`H;&ES="YO<'1I;VYS6VE=+G-E;&5C=&5D*2!["B`@
M("`@("`@("`@(&QI<W0N;W!T:6]N<UMI72`](&YU;&P["B`@("`@("`@?0H@
M("`@?0I]"@IW:6YD;W<N;VYL;V%D(#T@9G5N8W1I;VXH*2!["B`@("!I9B`H
M='EP96]F(&1O8W5M96YT+F=E=$5L96UE;G1">4ED("$]("=U;F1E9FEN960G
M*2!["B`@("`@("`@=F%R('-E87)C:'1A8FQE(#T@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)W-E87)C:'1A8FQE)RD["B`@("`@("`@:68@*'-E87)C:'1A
M8FQE("8F('1Y<&5O9B!S96%R8VAT86)L92YO9F9S9717:61T:"`A/2`G=6YD
M969I;F5D)RD@>PH@("`@("`@("`@("!W:6YD;W<N:6YN97)7:61T:"`]('-E
M87)C:'1A8FQE+F]F9G-E=%=I9'1H.PH@("`@("`@('T*("`@('T*?0H*+R\M
M+3X*/"]S8W)I<'0^"CQF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB8V]N=&%C
M=',B(&]N<W5B;6ET/2)P87-S061D<F5S<V5S*"D[(B!A8W1I;VX](F-O;G1A
M8W1S+G!H<#]N;V-A8VAE/3P_<&AP(&5C:&\@;60U*&UT7W)A;F0H*2D@/SXB
M/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)S82(@+SX*/#]P:'`@571I
M;#HZ<&9O<FU);G!U="@I(#\^"@H\9&EV(&-L87-S/2)H96%D97(B/CP_<&AP
M(&5C:&\@7R@B061D<F5S<R!";V]K(BD@/SX\+V1I=CX*"CQT86)L92!I9#TB
M<V5A<F-H=&%B;&4B('=I9'1H/2(Q,#`E(CX*/'1R/@H@(#QT9"!C;VQS<&%N
M/2(S(B!C;&%S<STB;&EG:'0@;F]W<F%P(CX*("`@(#QS=')O;F<^/#]P:'`@
M96-H;R!?*")&:6YD(BD@/SX\+W-T<F]N9SX*("`@(#QI;G!U="!V86QU93TB
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S96%R8V@I(#\^(B!N86UE
M/2)S96%R8V@B('-T>6QE/2)W:61T:#HQ-3!P>"(@+SX*/#]P:'`@:68@*&-O
M=6YT*"1S;W5R8V5?;&ES="D@/B`Q*3H@/SX*("`@(#QS=')O;F<^/#]P:'`@
M96-H;R!?*")I;B(I(#\^/"]S=')O;F<^"B`@("`\<V5L96-T(&YA;64](G-O
M=7)C92(^"B`@("`\/W!H<"!F;W)E86-H("@D<V]U<F-E7VQI<W0@87,@)&ME
M>2`]/B`D<V5L96-T*3H@/SX*("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(\/W!H<"!I9B`H)&ME>2`]
M/2`D<V]U<F-E*2!E8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P
M:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S96QE8W0I(#\^/"]O<'1I;VX^
M"B`@("`\/W!H<"!E;F1F;W)E86-H.R`_/@H@("`@/"]S96QE8W0^"CP_<&AP
M(&5L<V4Z(#\^"B`@("`\:6YP=70@;F%M93TB<V]U<F-E(B!T>7!E/2)H:61D
M96XB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H:V5Y*"1S
M;W5R8V5?;&ES="DI(#\^(B`O/@H\/W!H<"!E;F1I9CL@/SX*("`@(#QI;G!U
M="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E
M8VAO(%\H(E-E87)C:"(I(#\^(B`O/@H@(#PO=&0^"CPO='(^"CQT<CX*("`\
M=&0@=VED=&@](C0U)2(^"B`@("`\<V5L96-T(&YA;64](G-E87)C:%]R97-U
M;'1S(B!M=6QT:7!L93TB;75L=&EP;&4B('-I>F4](C$P(B!S='EL93TB=VED
M=&@Z,3`P)2(@;VYC:&%N9V4](F1O8W5M96YT+F-O;G1A8W1S+G-E87)C:%]R
M97-U;'1S6S!=+G-E;&5C=&5D/69A;'-E(B!O;F1B;&-L:6-K/2)A9&1!9&1R
M97-S*"DB/@H@("`@("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B
M*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("HB*2`_/CPO;W!T:6]N/@H@
M("`@("`\/W!H<"!F;W)E86-H("@D861D<F5S<V5S(&%S("1A9&1R*3H@:68@
M*"1D:7-P;&%Y(#T]("=E;6%I;"<I.B`_/@H@("`@("`\;W!T:6]N('9A;'5E
M/2(\/W!H<"!E8VAO(')A=W5R;&5N8V]D92@D861D<ELG;F%M92==*2`_/B(^
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1A9&1R6R=E;6%I;"==*2`_
M/CPO;W!T:6]N/@H@("`@("`\/W!H<"!E;'-E.B`_/@H@("`@("`\;W!T:6]N
M('9A;'5E/2(\/W!H<"!E8VAO(')A=W5R;&5N8V]D92@D861D<ELG96UA:6PG
M72D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D861D<ELG;F%M
M92==*2`_/CPO;W!T:6]N/@H@("`@("`\/W!H<"!E;F1I9CL@96YD9F]R96%C
M:#L@/SX*("`@(#PO<V5L96-T/@H@(#PO=&0^"B`@/'1D('=I9'1H/2(Q,"4B
M(&%L:6=N/2)C96YT97(B/@H@("`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA
M<W,](F)U='1O;B(@;VYC;&EC:STB861D061D<F5S<R@I.R(@=F%L=64](CP_
M<&AP(&5C:&\@7R@B061D(BD@/SX@)F=T.R9G=#LB("\^/&)R("\^/&)R("\^
M"B`@("`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!O;F-L
M:6-K/2)R96UO=F5!9&1R97-S*"DB('9A;'5E/2(F;'0[)FQT.R`\/W!H<"!E
M8VAO(%\H(E)E;6]V92(I(#\^(B`O/@H@(#PO=&0^"B`@/'1D('=I9'1H/2(T
M-24B/@H@("`@/'-E;&5C="!N86UE/2)S96QE8W1E9%]A9&1R97-S97,B(&UU
M;'1I<&QE/2)M=6QT:7!L92(@<VEZ93TB,3`B('-T>6QE/2)W:61T:#HQ,#`E
M(B!O;F-H86YG93TB9&]C=6UE;G0N8V]N=&%C=',N<V5L96-T961?861D<F5S
M<V5S6S!=+G-E;&5C=&5D/69A;'-E(CX*("`@("`@/&]P=&EO;B!V86QU93TB
M(CX\/W!H<"!E8VAO(%\H(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($%D9"`J
M(BD@/SX\+V]P=&EO;CX*("`@("`@/#]P:'`@9F]R96%C:"`H)'-E;&5C=&5D
M7V%D9')E<W-E<R!A<R`D=F%L=64@/3X@)'1E>'0I.B`_/@H@("`@("`\;W!T
M:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E
M*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1T97AT*2`_/CPO
M;W!T:6]N/@H@("`@("`\/W!H<"!E;F1F;W)E86-H.R`_/@H@("`@/"]S96QE
M8W0^"B`@/"]T9#X*/"]T<CX*/'1R/@H@(#QT9"!C;VQS<&%N/2(S(B!C;&%S
M<STB;&EG:'0@;F]W<F%P(CX*("`@(#QS=')O;F<^/#]P:'`@96-H;R!?*")$
M:7-P;&%Y(BD@/SX\+W-T<F]N9SX*("`@(#QS96QE8W0@;F%M93TB9&ES<&QA
M>2(@;VYC:&%N9V4](F-H86YG941I<W!L87DH*3LB/@H@("`@("`\;W!T:6]N
M('9A;'5E/2)N86UE(CP_<&AP(&5C:&\@)&1I<W!L87D@/3T@)VYA;64G(#\@
M)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B
M3F%M92(I(#\^/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](F5M86EL
M(CP_<&AP(&5C:&\@)&1I<W!L87D@/3T@)V5M86EL)R`_("<@<V5L96-T960]
M(G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(D5M86EL($%D9')E
M<W,B*2`_/CPO;W!T:6]N/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*("`\=&0@
M8V]L<W!A;CTB,B(^)FYB<W`[/"]T9#X*/"]T<CX*/"]T86)L93X*"CQD:78@
M8VQA<W,](FAE861E<B!R:6=H=$%L:6=N(CX*("`\:6YP=70@='EP93TB8G5T
M=&]N(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)U<&1A=&5-97-S86=E*"D[
M(B!V86QU93TB/#]P:'`@96-H;R!?*")!9&0@=&\@871T96YD965S(BD@/SXB
M("\^"B`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@;VYC
M;&EC:STB=VEN9&]W+F-L;W-E*"D[(B!V86QU93TB/#]P:'`@96-H;R!?*")#
M;&]S92!W:6YD;W<B*2`_/B(@+SX*("`\/W!H<"!E8VAO($AE;'`Z.FQI;FLH
M)VMR;VYO;&ET:"<L("=I;G9I=&4M861D<F5S<V)O;VLG*2`_/@H\+V1I=CX*
M/"]F;W)M/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]T96UP;&%T97,O<')E9G,O````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(Q-34R`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+W1E;7!L871E<R]P<F5F<R]R96UO=&5?
M8V%L7VUA;F%G96UE;G0N:6YC```````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<S,@`Q,#0Q-S,V,C<U,P`P
M,C8U-30`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB<F5M;W1E7V%C=&EO;B(@
M=F%L=64](F%D9"(^"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^
M"CPA+2T*9G5N8W1I;VX@9&5L971E0V%L*&ED*0I["B`@("!D;V-U;65N="YP
M<F5F<RYR96UO=&5?86-T:6]N+G9A;'5E(#T@)V1E;&5T92<["B`@("!D;V-U
M;65N="YP<F5F<RYR96UO=&5?=7)L+G9A;'5E(#T@:60["B`@("!D;V-U;65N
M="YP<F5F<RYS=6)M:70H*3L*?0HM+3X*/"]S8W)I<'0^"@H\=&%B;&4@8V5L
M;'-P86-I;F<](C(B/@H\='(^"B`@/'1D/B9N8G-P.SPO=&0^"B`@/'1D/CQS
M=')O;F<^/#]P:'`@96-H;R!?*").86UE(BD@/SX\+W-T<F]N9SX\+W1D/@H@
M(#QT9#X\<W1R;VYG/CP_<&AP(&5C:&\@7R@B3&]C871I;VXB*2`_/CPO<W1R
M;VYG/CPO=&0^"CPO='(^"@H\/W!H<"`D8V%L<R`]('5N<V5R:6%L:7IE*"1P
M<F5F<RT^9V5T5F%L=64H)W)E;6]T95]C86QS)RDI.R!F;W)E86-H("@D8V%L
M<R!A<R`D:V5Y(#T^("1C86PI.B`_/@H\='(^"B`@/'1D(&-L87-S/2)T97AT
M(CX\82!H<F5F/2(C(B!O;F-L:6-K/2)D96QE=&5#86PH9&5C;V1E55))0V]M
M<&]N96YT*"<\/W!H<"!E8VAO(')A=W5R;&5N8V]D92@D8V%L6R=U<FPG72D@
M/SXG*2D[(')E='5R;B!F86QS93LB/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G
M9&5L971E+G!N9R<L(%\H(D1E;&5T92(I+"`G)RP@)')E9VES=')Y+3YG971)
M;6%G941I<B@G:&]R9&4G*2D@/SX\+V$^/"]T9#X*("`\=&0@8VQA<W,](G1E
M>'0B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V%L6R=N86UE)UTI
M(#\^/"]T9#X*("`\=&0@8VQA<W,](G1E>'0B/CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D8V%L6R=U<FPG72D@/SX\+W1D/@H\+W1R/@H\/W!H<"!E
M;F1F;W)E86-H.R`_/@H*/'1R/@H@/'1D/B9N8G-P.SPO=&0^"CPO='(^"@H\
M='(^"B`\=&0@8V]L<W!A;CTB,R(^"B`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H
M(D%D9"!A(&YE=R!296UO=&4@0V%L96YD87(B*2`_/CPO<W1R;VYG/@H@/"]T
M9#X*/"]T<CX*"CQT<CX*(#QT9"!C;VQS<&%N/2(S(CX*("`\=&%B;&4@8V5L
M;'-P86-I;F<](C$B/@H@("`\='(^"B`@("`\=&0@86QI9VX](G)I9VAT(CX*
M("`@("`\<W1R;VYG/CP_<&AP(&5C:&\@7R@B3F%M92(I(#\^/"]S=')O;F<^
M)FYB<W`[)FYB<W`["B`@("`\+W1D/@H@("`@/'1D/@H@("`@(#QI;G!U="!T
M>7!E/2)T97AT(B!N86UE/2)R96UO=&5?;F%M92(@=F%L=64](B(^"B`@("`\
M+W1D/@H@("`\+W1R/@H@("`\='(^"B`@("`\=&0@86QI9VX](G)I9VAT(CX*
M("`@("`\<W1R;VYG/CP_<&AP(&5C:&\@7R@B3&]C871I;VXB*2`_/CPO<W1R
M;VYG/B9N8G-P.R9N8G-P.PH@("`@/"]T9#X*("`@(#QT9#X*("`@("`\:6YP
M=70@<VEZ93TB-3`B('1Y<&4](G1E>'0B(&YA;64](G)E;6]T95]U<FPB('9A
M;'5E/2(B/@H@("`@/"]T9#X*("`@/"]T<CX*("`\+W1A8FQE/@H@/"]T9#X*
M/"]T<CX*"CPO=&%B;&4^"@``````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O
M=&5M<&QA=&5S+W!R969S+W-H87)E<V5L96-T+FEN8P``````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q,C$T`#$P-#$W,S8R-S4S`#`R-#4T,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`II9B`H(21P<F5F<RT^
M:7-,;V-K960H)V1E9F%U;'1?<VAA<F4G*2DZ"B`@("`D<VAA<F5L:7-T(#T@
M2W)O;F]L:71H.CIL:7-T0V%L96YD87)S*"D["B`@("!I9B`H*"1D969A=6QT
M7W-H87)E(#T@)'!R969S+3YG971686QU92@G9&5F875L=%]S:&%R92<I*2`]
M/2!N=6QL('Q\"B`@("`@("`@(6ES<V5T*"1S:&%R96QI<W1;)&1E9F%U;'1?
M<VAA<F5=*2D@>PH@("`@("`@("1D969A=6QT7W-H87)E(#T@075T:#HZ9V5T
M075T:"@I.PH@("`@?0H_/@H*("`@(#QS=')O;F<^/#]P:'`@96-H;R!?*")9
M;W5R(&1E9F%U;'0@8V%L96YD87(B*2`_/CPO<W1R;VYG/B9N8G-P.PH@("`@
M/'-E;&5C="!N86UE/2)D969A=6QT7W-H87)E(CX*("`@(#P_<&AP(&9O<F5A
M8V@@*"1S:&%R96QI<W0@87,@)&ED(#T^("1S:&%R92DZ(#\^"B`@("`@/&]P
M=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1I9"D@
M/SXB/#]P:'`@:68@*"1I9"`]/2`D9&5F875L=%]S:&%R92D@96-H;R`G('-E
M;&5C=&5D/2)S96QE8W1E9"(G(#\^/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D<VAA<F4M/F=E="@G;F%M92<I*2`_/CPO;W!T:6]N/@H@("`@/#]P
M:'`@96YD9F]R96%C:#L@/SX*("`@(#PO<V5L96-T/@H\/W!H<"!E;F1I9CL@
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N
M;VQI=&@O=&5M<&QA=&5S+W!R969S+V9B7V-A;'-?<V5L96-T+FEN8P``````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q-30T`#$P-#$W,S8R-S4S`#`R-3$W-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\8G(@8VQA<W,](G-P
M86-E<B(@+SX*/#]P:'`*:68@*"$D<')E9G,M/FES3&]C:V5D*"=F8E]C86QS
M)RDI('L*("`@("1F8E]C86QS(#T@2W)O;F]L:71H.CI,:7-T0V%L96YD87)S
M*"D["B`@("`D9F)?8V%L<U-A=F5D(#T@=6YS97)I86QI>F4H)'!R969S+3YG
M971686QU92@G9F)?8V%L<R<I*3L*("`@("1F8E]C86Q396QE8W0@/2`G)SL*
M("`@(&9O<F5A8V@@*"1F8E]C86QS(&%S("1F8E]C86P@/3X@)&-A;"D@>PH@
M("`@("`@(&EF("@A:7-?8F]O;"AA<G)A>5]S96%R8V@H)&9B7V-A;"P@)&9B
M7V-A;'-3879E9"DI*2!["B`@("`@("`@("`@("1F8E]C86Q396QE8W0@+CT@
M)SQO<'1I;VX@=F%L=64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1F8E]C86PI
M("X@)R(@<V5L96-T960](G-E;&5C=&5D(CXG("X@:'1M;'-P96-I86QC:&%R
M<R@D8V%L+3YG970H)VYA;64G*2D@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9F)?8V%L4V5L96-T("X]("<\;W!T:6]N
M('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D9F)?8V%L*2`N("<B/B<@
M+B!H=&UL<W!E8VEA;&-H87)S*"1C86PM/F=E="@G;F%M92<I*2`N("<\+V]P
M=&EO;CXG.PH@("`@("`@('T*("`@('T*"B`@("!I9B`H)&9B7V-A;%-E;&5C
M="D@>PH@("`@("`@(&5C:&\@7R@B0VAO;W-E('1H92!C86QE;F1A<G,@=&\@
M:6YC;'5D92!I;B!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;CHB*2`N("<\
M8G(@+SXG("X*("`@("`@("`@("`@)SQS96QE8W0@;75L=&EP;&4](FUU;'1I
M<&QE(B!N86UE/2)F8E]C86QS6UTB/B<@+B`D9F)?8V%L4V5L96-T("X@)SPO
M<V5L96-T/CQB<B`O/CQB<B!C;&%S<STB<W!A8V5R(B`O/B<["B`@("!]"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]K<F]N;VQI=&@O=&5M<&QA=&5S+W!R969S+W-E87)C:%]A8F]O:U]S96QE
M8W0N:6YC`````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,3`P`#$P-#$W,S8R-S4S`#`R-C(Q,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\8G(@8VQA
M<W,](G-P86-E<B(@+SX*/#]P:'`*:68@*"$D<')E9G,M/FES3&]C:V5D*"=S
M96%R8VA?86)O;VLG*2`F)B`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G8V]N=&%C
M=',O<V]U<F-E<R<I*2!["B`@("`D861D<F5S<U]B;V]K<R`]("1R96=I<W1R
M>2T^8V%L;"@G8V]N=&%C=',O<V]U<F-E<R<I.PH@("`@:68@*"%I<U]A*"1A
M9&1R97-S7V)O;VMS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&%D9')E
M<W-?8F]O:U-A=F5D(#T@=6YS97)I86QI>F4H)'!R969S+3YG971686QU92@G
M<V5A<F-H7V%B;V]K)RDI.PH@("`@("`@("1A9&1R97-S7V)O;VM396QE8W0@
M/2`G)SL*"B`@("`@("`@9F]R96%C:"`H)&%D9')E<W-?8F]O:W,@87,@)&%D
M9')E<W-?8F]O:R`]/B`D9&5S8W)I<'1I;VXI('L*("`@("`@("`@("`@:68@
M*"%I<U]B;V]L*&%R<F%Y7W-E87)C:"@D861D<F5S<U]B;V]K+"`D861D<F5S
M<U]B;V]K4V%V960I*2D@>PH@("`@("`@("`@("`@("`@)&%D9')E<W-?8F]O
M:U-E;&5C="`N/2`G/&]P=&EO;B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA
M<G,H)&%D9')E<W-?8F]O:RD@+B`G(B!S96QE8W1E9#XG("X@:'1M;'-P96-I
M86QC:&%R<R@D9&5S8W)I<'1I;VXI("X@)SPO;W!T:6]N/B<["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D861D<F5S<U]B;V]K4V5L
M96-T("X]("<\;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D
M861D<F5S<U]B;V]K*2`N("<B/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1D97-C
M<FEP=&EO;BD@+B`G/"]O<'1I;VX^)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("!I9B`H:7-S970H)&%D9')E<W-?8F]O:U-E;&5C="DI
M('L*("`@("`@("!E8VAO(%\H(D-H;V]S92!T:&4@861D<F5S<R!B;V]K<R!T
M;R!S96%R8V@@9F]R(&9R964O8G5S>2!54DQS.B(I("X@)SQB<B`O/B<["B`@
M("`@("`@96-H;R`G/'-E;&5C="!M=6QT:7!L93TB;75L=&EP;&4B(&YA;64]
M(G-E87)C:%]A8F]O:UM=(CXG("X@)&%D9')E<W-?8F]O:U-E;&5C="`N("<\
M+W-E;&5C=#X\8G(@+SX\8G(@8VQA<W,](G-P86-E<B(@+SXG.PH@("`@?0I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O
M8V%T96=O<GE?;&5G96YD+FEN8P``````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,3``
M,3`T,3<S-C(W-3,`,#(T,C0W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QD:78@:60](F9O;W1E<B(^"CP_<&AP"G)E<75I
M<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PII9B`H)$=,3T)!3%-;)W!R969S
M)UTM/F=E=%9A;'5E*"=S:&]W7VQE9V5N9"<I("8F(&-O=6YT*"1E=F5N=$-A
M=&5G;W)I97,I*2!["B`@("`D:'1M;"`]("<G.PH*("`@(&MS;W)T*"1E=F5N
M=$-A=&5G;W)I97,I.PH@("`@9F]R96%C:"`H)&5V96YT0V%T96=O<FEE<R!A
M<R`D8V%T96=O<GD@/3X@)'8I('L*("`@("`@("!I9B`H96UP='DH)&-A=&5G
M;W)Y*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@
M("`@("1H=&UL("X]("<@/'-P86X@8VQA<W,](FQE9V5N9"UE=F5N=&)O>"!E
M=F5N="!C871E9V]R>2<@+B!M9#4H)&-A=&5G;W)Y*2`N("<B/B<@+@H@("`@
M("`@("`@("!497AT.CIH=&UL06QL4W!A8V5S*"1C871E9V]R>2D@+B`G/"]S
M<&%N/B<["B`@("!]"@H@("`@:68@*$%U=&@Z.F=E=$%U=&@H*2`F)B`H(21'
M3$]"04Q36R=P<F5F<R==+3YI<TQO8VME9"@G8V%T96=O<FEE<R<I('Q\"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`A)$=,3T)!3%-;)W!R969S)UTM
M/FES3&]C:V5D*"=C871E9V]R>5]C;VQO<G,G*2DI('L*("`@("`@("`D8V%T
M96=O<GE5<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G5R;"@D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G
M+W-E<G9I8V5S+W!R969S+G!H<"<I+"!A<G)A>2@G87!P)R`]/B`G:&]R9&4G
M+"`G9W)O=7`G(#T^("=C871E9V]R:65S)RDI.PH@("`@("`@("1H=&UL("X]
M("<@)R`N($AO<F1E.CIL:6YK*"1C871E9V]R>55R;"P@7R@B161I="!C871E
M9V]R:65S(&%N9"!C;VQO<G,B*2P@)R<L("=?8FQA;FLG*2`N($AO<F1E.CII
M;6<H)V-O;&]R<&EC:V5R+G!N9R<L(%\H(D5D:70@8V%T96=O<FEE<R!A;F0@
M8V]L;W)S(BDL("<G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI("X@)SPO83XG.PH@("`@?0H*("`@(&5C:&\@)&AT;6P[
M"GT*/SX*/"]D:78^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:W)O;F]L:71H+W1E;7!L871E<R]M96YU+FEN8P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-C<P-``Q,#0Q-S,V,C<U,P`P,C(P-S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M)')E;6]T95]C86QE;F1A<G,@/2!U;G-E<FEA;&EZ92@D<')E9G,M/F=E=%9A
M;'5E*"=R96UO=&5?8V%L<R<I*3L*)&-U<G)E;G1?=7-E<B`]($%U=&@Z.F=E
M=$%U=&@H*3L*)&UY7V-A;&5N9&%R<R`](&%R<F%Y*"D["B1S:&%R961?8V%L
M96YD87)S(#T@87)R87DH*3L*9F]R96%C:"`H2W)O;F]L:71H.CIL:7-T0V%L
M96YD87)S*"D@87,@)&ED(#T^("1C86PI('L*("`@(&EF("@D8V%L+3YG970H
M)V]W;F5R)RD@/3T@)&-U<G)E;G1?=7-E<BD@>PH@("`@("`@("1M>5]C86QE
M;F1A<G-;)&ED72`]("1C86P["B`@("!](&5L<V4@>PH@("`@("`@("1S:&%R
M961?8V%L96YD87)S6R1I9%T@/2`D8V%L.PH@("`@?0I]"@II9B`H<W1R<W1R
M*"1?4T525D526R=02%!?4T5,1B==+"`G;6]N=&@N<&AP)RD@(3T](&9A;'-E
M('Q\"B`@("!S=')S='(H)%]315)615);)U!(4%]314Q&)UTL("=W965K+G!H
M<"<I("$]/2!F86QS92!\?`H@("`@<W1R<W1R*"1?4T525D526R=02%!?4T5,
M1B==+"`G=V]R:W=E96LN<&AP)RD@(3T](&9A;'-E('Q\"B`@("!S=')S='(H
M)%]315)615);)U!(4%]314Q&)UTL("=D87DN<&AP)RD@(3T](&9A;'-E*3H@
M/SX*/&9O<FT@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIS96QF57)L*"D@
M/SXB(&UE=&AO9#TB<&]S="(@;F%M93TB8V%L96YD87)396QE8W1O<B(^"CP_
M<&AP(&5L<V4Z(#\^"CQF;W)M(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)'!R969S+3YG971686QU92@G9&5F875L='9I97<G
M*2`N("<N<&AP)RD@/SXB(&UE=&AO9#TB<&]S="(@;F%M93TB8V%L96YD87)3
M96QE8W1O<B(^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!E8VAO(%5T:6PZ.F9O
M<FU);G!U="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G1I;65S
M=&%M<"(@=F%L=64](CP_<&AP(&5C:&\@2W)O;F]L:71H.CIC=7)R96YT5&EM
M97-T86UP*"D@/SXB("\^"@H\9&EV(&ED/2)M96YU(CX*/#]P:'`@:68@*"$D
M<')E9G,M/FES3&]C:V5D*"=D:7-P;&%Y7V-A;',G*2`F)B`H*&-O=6YT*"1R
M96UO=&5?8V%L96YD87)S*2!\?"!C;W5N="@D1TQ/0D%,4ULG86QL7V-A;&5N
M9&%R<R==*2`^(#$I('Q\("%C;W5N="@D9&ES<&QA>5]C86QE;F1A<G,I*2DZ
M(#\^"B`\<W!A;B!S='EL93TB9FQO870Z<FEG:'0B/@H\<V5L96-T(&YA;64]
M(F1I<W!L87E?8V%L(B!O;F-H86YG93TB8V%L96YD87)3=6)M:70H*2(^"CP_
M<&AP(&EF("@D8G)O=W-E<BT^:&%S1F5A='5R92@G;W!T9W)O=7`G*2DZ(#\^
M"B`@/&]P=&EO;B!V86QU93TB(CX\/W!H<"!E8VAO(%\H(E-E;&5C="!C86QE
M;F1A<G,@=&\@9&ES<&QA>3HB*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1I9CL@
M/SX*/#]P:'`@:68@*&-O=6YT*"1M>5]C86QE;F1A<G,I*3H@/SX*/#]P:'`@
M:68@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=O<'1G<F]U<"<I*3H@/SX*("`\
M;W!T9W)O=7`@;&%B96P](CP_<&AP(&5C:&\@7R@B37D@0V%L96YD87)S.B(I
M(#\^(CX*/#]P:'`@96QS93H@/SX*("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP
M(&5C:&\@7R@B37D@0V%L96YD87)S.B(I(#\^/"]O<'1I;VX^"CP_<&AP(&5N
M9&EF.R`_/@H\/W!H<"!F;W)E86-H("@D;7E?8V%L96YD87)S(&%S("1I9"`]
M/B`D8V%L*3H@/SX*("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&ED*2`_/B(\/W!H<"!E8VAO("AI;E]A<G)A>2@D:60L
M("1D:7-P;&%Y7V-A;&5N9&%R<RD@/R`G(&-L87-S/2)S96QE8W1E9"(G(#H@
M)R<I("X@)SXG("X@:'1M;'-P96-I86QC:&%R<R@D8V%L+3YG970H)VYA;64G
M*2D@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R96%C:#L@/SX*/#]P:'`@:68@
M*"1B<F]W<V5R+3YH87-&96%T=7)E*"=O<'1G<F]U<"<I*3H@/SX*("`\+V]P
M=&=R;W5P/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@96YD:68[(#\^"CP_<&AP
M(&EF("AC;W5N="@D<VAA<F5D7V-A;&5N9&%R<RDI.B`_/@H\/W!H<"!I9B`H
M)&)R;W=S97(M/FAA<T9E871U<F4H)V]P=&=R;W5P)RDI.B`_/@H@(#QO<'1G
M<F]U<"!L86)E;#TB/#]P:'`@96-H;R!?*")3:&%R960@0V%L96YD87)S.B(I
M(#\^(CX*/#]P:'`@96QS93H@/SX*("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP
M(&5C:&\@7R@B4VAA<F5D($-A;&5N9&%R<SHB*2`_/CPO;W!T:6]N/@H\/W!H
M<"!E;F1I9CL@/SX*/#]P:'`@9F]R96%C:"`H)'-H87)E9%]C86QE;F1A<G,@
M87,@)&ED(#T^("1C86PI.B`_/@H@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D:60I(#\^(CP_<&AP(&5C:&\@*&EN7V%R
M<F%Y*"1I9"P@)&1I<W!L87E?8V%L96YD87)S*2`_("<@8VQA<W,](G-E;&5C
M=&5D(B<@.B`G)RD@+B`G/ELG("X@)&-A;"T^9V5T*"=O=VYE<B<I("X@)UT@
M)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&-A;"T^9V5T*"=N86UE)RDI(#\^/"]O
M<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"CP_<&AP(&EF("@D8G)O=W-E
M<BT^:&%S1F5A='5R92@G;W!T9W)O=7`G*2DZ(#\^"B`@/"]O<'1G<F]U<#X*
M/#]P:'`@96YD:68[(#\^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H8V]U
M;G0H)')E;6]T95]C86QE;F1A<G,I*3H@/SX*/#]P:'`@:68@*"1B<F]W<V5R
M+3YH87-&96%T=7)E*"=O<'1G<F]U<"<I*3H@/SX*("`\;W!T9W)O=7`@;&%B
M96P](CP_<&AP(&5C:&\@7R@B4F5M;W1E($-A;&5N9&%R<SHB*2`_/B(^"CP_
M<&AP(&5L<V4Z(#\^"B`@/&]P=&EO;B!V86QU93TB(CX\/W!H<"!E8VAO(%\H
M(E)E;6]T92!#86QE;F1A<G,Z(BD@/SX\+V]P=&EO;CX*/#]P:'`@96YD:68[
M(#\^"CP_<&AP(&9O<F5A8V@@*"1R96UO=&5?8V%L96YD87)S(&%S("1I9"`]
M/B`D8V%L*3H@/SX*("`\;W!T:6]N('9A;'5E/2)R96UO=&5?/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1C86Q;)W5R;"==*2`_/B(\/W!H<"!E8VAO
M("AI;E]A<G)A>2@D8V%L6R=U<FPG72P@)&1I<W!L87E?<F5M;W1E7V-A;&5N
M9&%R<RD@/R`G(&-L87-S/2)S96QE8W1E9"(G(#H@)R<I("X@)SXG("X@:'1M
M;'-P96-I86QC:&%R<R@D8V%L6R=N86UE)UTI(#\^/"]O<'1I;VX^"CP_<&AP
M(&5N9&9O<F5A8V@[(#\^"CP_<&AP(&EF("@D8G)O=W-E<BT^:&%S1F5A='5R
M92@G;W!T9W)O=7`G*2DZ(#\^"B`@/"]O<'1G<F]U<#X*/#]P:'`@96YD:68[
M(#\^"CP_<&AP(&5N9&EF.R`_/@H\+W-E;&5C=#X*(#PO<W!A;CX*/#]P:'`@
M96YD:68[(#\^"@H@/#]P:'`@96-H;R!+<F]N;VQI=&@Z.F=E=$UE;G4H)W-T
M<FEN9R<I(#\^"B`\8G(@8VQA<W,](F-L96%R(B`O/@H\+V1I=CX*/"]F;W)M
M/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"G9A<B!L
M;V%D:6YG.PIF=6YC=&EO;B!C86QE;F1A<E-U8FUI="@I"GL*("`@(&1O8W5M
M96YT+F-A;&5N9&%R4V5L96-T;W(N<W5B;6ET*"D["B`@("!R971U<FX@9F%L
M<V4["GT*+R\@+2T^"CPO<V-R:7!T/@H*/#]P:'`@)$=,3T)!3%-;)VYO=&EF
M:6-A=&EO;B==+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U
M<R<I*2`_/@H`````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]T96UP;&%T97,O8V]M;6]N+6AE861E<BYI;F,`````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,T-S4`,3`T,3<S-C(W-3,`,#(S-C4R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"FEF("AI<W-E="@D;&%N9W5A9V4I*2!["B`@("!H96%D97(H)T-O;G1E;G0M
M='EP93H@=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H
M*2D["B`@("!H96%D97(H)U9A<GDZ($%C8V5P="U,86YG=6%G92<I.PI]"C\^
M"CPA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP
M(%1R86YS:71I;VYA;"\O14XB(")$5$0O>&AT;6PQ+71R86YS:71I;VYA;"YD
M=&0B/@H\(2TM($MR;VYO;&ET:#H@0V]P>7)I9VAT(#(P,#`M,C`P-BP@5&AE
M($AO<F1E(%!R;VIE8W0N($MR;VYO;&ET:"!I<R!U;F1E<B!T:&4@1U!,+B`M
M+3X*/"$M+2`@($AO<F1E(%!R;VIE8W0Z(&AT='`Z+R]H;W)D92YO<F<O('P@
M2W)O;F]L:71H.B!H='1P.B\O:&]R9&4N;W)G+VMR;VYO;&ET:"\@("`@+2T^
M"CPA+2T@("`@("`@("`@("!'3E4@4'5B;&EC($QI8V5N<V4Z(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"`@("`@("`@("`@("TM/@H\
M/W!H<"!E8VAO("%E;7!T>2@D;&%N9W5A9V4I(#\@)SQH=&UL(&QA;F<](B<@
M+B!S=')T<B@D;&%N9W5A9V4L("=?)RP@)RTG*2`N("<B/B<@.B`G/&AT;6P^
M)R`_/@H\:&5A9#X*/#]P:'`*"B1P86=E7W1I=&QE(#T@)')E9VES=')Y+3YG
M970H)VYA;64G*3L*:68@*"%E;7!T>2@D=&ET;&4I*2`D<&%G95]T:71L92`N
M/2`G(#HZ("<@+B`D=&ET;&4["FEF("@A96UP='DH)')E9G)E<VA?=&EM92D@
M)B8@*"1R969R97-H7W1I;64@/B`P*2`F)B`A96UP='DH)')E9G)E<VA?=7)L
M*2D@>PH@("`@96-H;R`B/&UE=&$@:'1T<"UE<75I=CU<(G)E9G)E<VA<(B!C
M;VYT96YT/5PB)')E9G)E<VA?=&EM93MU<FP])')E9G)E<VA?=7)L7"(^7&XB
M.PI]"@II9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:7-"<F]W<V5R*"=K;VYQ
M=65R;W(G*2D@>PH@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V9I>%5N<W1Y
M;&5D3W!T:6]N<RYJ<R<L("=K<F]N;VQI=&@G+"!T<G5E*3L*?0I(;W)D93HZ
M:6YC;'5D95-C<FEP=$9I;&5S*"D["@H_/@H\=&ET;&4^/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1P86=E7W1I=&QE*2`_/CPO=&ET;&4^"CQL:6YK
M(&AR968](CP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM
M86=E1&ER*"D_/B]F879I8V]N+FEC;R(@<F5L/2)32$]25$-55"!)0T].(B`O
M/@H\/W!H<"!E8VAO($AO<F1E.CIS='EL97-H965T3&EN:R@G:W)O;F]L:71H
M)RP@96UP='DH)'!R:6YT7W9I97<I(#\@)R<@.B`G<')I;G0G*2`_/@H\;&EN
M:R!H<F5F/2(\/W!H<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G=&AE
M;65S+V-A=&5G;W)Y0U-3+G!H<"<I(#\^(B!R96P](G-T>6QE<VAE970B('1Y
M<&4](G1E>'0O8W-S(B`O/@H\+VAE860^"@H\8F]D>3P_<&AP(&EF("A5=&EL
M.CIN;VY);G!U=%9A<B@G8F]D>4-L87-S)RDI(&5C:&\@)R!C;&%S<STB)R`N
M("1B;V1Y0VQA<W,@+B`G(B<@/SX^"@H\9&EV(&ED/2)K9V]T;R(@8VQA<W,]
M(FAE861E<F)O>"(@<W1Y;&4](G!O<VET:6]N.F%B<V]L=71E.V1I<W!L87DZ
M;F]N93ML969T.C4P<'@[=&]P.C4P<'@[<&%D9&EN9SHP.WHM:6YD97@Z,2(^
M/"]D:78^"CP_<&AP(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YI<T)R;W=S
M97(H)VUS:64G*2`F)B!V97)S:6]N7V-O;7!A<F4H)$=,3T)!3%-;)V)R;W=S
M97(G72T^9V5T5F5R<VEO;B@I+"`G-2XU)RD@/CT@,"DZ(#\^"CQI9G)A;64@
M:60](FMG;W1O0F%C:VEN9R(@<W)C/2)J879A<V-R:7!T.F9A;'-E.R(@<V-R
M;VQL:6YG/2)N;R(@9G)A;65B;W)D97(](C`B('-T>6QE/2)P;W-I=&EO;CIA
M8G-O;'5T93MD:7-P;&%Y.FYO;F4B/CPO:69R86UE/@H\/W!H<"!E;F1I9CL@
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K
M<F]N;VQI=&@O=&AE;65S+P``````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`Q-S<R,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T:&5M97,O9W)A<&AI8W,O````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-3,`,#(Q-3(R`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1H
M96UE<R]G<F%P:&EC<R]W;W)K=V5E:W9I97<N<&YG````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#4V,0`Q,#0Q-S,V,C<U,P`P,C0W-C``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`(```"0D6@V```!.$E$050HSYU2+<["0!!].S.%!D%(,82`([6XWH43
M($AJ>P($!&P=MR!<`<D!,!A$10_0I-M%#-]20/$]L9F_MV]F=H$?80`<#H>F
M:0#HZ?[0MM5-TU0`#`:#Z_7Z4?%MCT8C``)@.IWV^WUCS$O7F`]71.[W^Y,P
MG\^+HM!$N[I-"\-0I>3[UK:A*68FHC`,`9"OUB@1Y7F>)$D<QZO5RF>MM6J+
M#WFI]7J]W^\7BX4N#4"GTU&=-P5/.)U.V^UV/!YO-AL`UEHB8N8HBEZ$-F:S
MV>5RV>UV>9Y;:T7$.1<$@8B\#>V19=GY?*ZJ:KE<,K-SKJ[K;K?[>NFJJLJR
M%!$BTI4W3</,VB<SBX@QIBB*R63R5!@.ASJB;D,?V!CCG+/6^A4]6SH>C[?;
M[6/T;_1ZO?]\C9_Q`![HG>RM7BW<`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T:&5M97,O9W)A<&AI
M8W,O9F%V:6-O;BYI8V\`````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-S8`,3`T
M,3<S-C(W-3,`,#(S-C4R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````0`!`!`0````````:`4``!8````H````$````"``
M```!``@````````!```````````````!`````````````+^_OP"AH:$`^?GY
M`)*2D@#JZNH`@X.#`!P<'`"]O;T`]_?W`.CHZ`"!@8$`&AH:`,K*R@"[N[L`
MG9V=`(Z.C@#FYN8`&!@8``D)"0!24E(`FYN;`//S\P",C(P`Y.3D`*BHJ`"9
MF9D`\?'Q`.+BX@![>WL`M;6U`)>7EP#O[^\`B(B(`&IJ:@#"PL(``P,#`+.S
MLP"5E94`[>WM`(:&A@#Z^OH`DY.3`.OKZP"$A(0`S<W-``X.#@"^OKX`@H*"
M`-K:V@`,#`P`O+R\`*VMK0#V]O8`Y^?G`("`@`#T]/0`C8V-`.7EY0`7%Q<`
M45%1`/+R\@#CX^,`;6UM`+:VM@"8F)@`\/#P`,/#PP"6EI8`[N[N`(>'AP#?
MW]\`$1$1`/O[^P`\/#P`E)24`.SL[`"%A84`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````#0XS,S,S""\O
M+R\!0QD``#0Y.1`0$!`0$!`0$!!!```#`PD).#A"&Q8]%A86&````Q$%3"<;
M(#T6%C4I21@```,Z/!)((DP;+DH"10,^```#.C$1%R08!1X`"CT#/@```SI`
M.P`_-C8E`!@6.$<```,81SHY$Q@V-``^&QLM```#/AT',A01-@P`1RM%#0``
M`QP^&!@Z$1$V-C8%&PT```,<'#X^&#HZ$38V-B`C```-#C,S,S,(+R\O+P%#
M&0``-"%&1BA-+"P&,`L+-T$```\5%1H:01]$1"9+*@0$````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:W)O;F]L:71H+W1H96UE<R]G<F%P:&EC<R]M;VYT:'9I97<N<&YG````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#8T,``Q,#0Q-S,V,C<U,P`P,C0R-#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`(```"0D6@V```!9TE$050HSYU2NX[",!"<C1<4
M*"(>39"@HZ"CH*'@)_@$6J3P)=`B&@H^@([?0)04%"`E%K($2.YPX>0*<Y<(
MKKF;PMKU[GI&LP;^"`*P7J_3-`7@SNP;Q=BEL]F,`=1JM=/I]-;Q&8=A"(`!
M=#J=(`B(*.<E>DN964KY&NCW^THI5RAV%\=\WW=4_/EJ,7`E(83G>;[O`_!^
MNE>KU7`X[/5Z412YF\%@T&JUGL\G$5EK<Z>,,4F2G,]G*>5BL:A4*DF27*_7
M[78+((YCK;76>K_?YY*(Z'@\3B83I50414((`.5RV94\SR.B1J.12P+0[78/
MA\-\/E\NE]9:IQL`,V=95BJ5F#F7)*4<C\=A&-;K]>ET>KO=M-9!$(Q&H\UF
M\W@\C#%Q'+\V;8RYW^_,[*B9.4U3(81S20C!S$2DE&JWVR^69K/I_H5SPRV8
MB+(LL]86+6(`N]WN<KD4C?\5U6KU/U_CS_@"B'K#9FXW,QT`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T
M:&5M97,O9W)A<&AI8W,O;F5W7W-M86QL+G!N9P``````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`T,S,`,3`T,3<S-C(W-3,`,#(T,C`V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````(
M````"`@#````\]%.N0```%103%1%`````P,#!04%"@H*#0T-#0\4$Q,3'Q\?
M("`?)R<G+BXN,#`P,C(R-34Q-C8V.#DS.SLY86!>8V=N9V=G8VAP:VMK@X5]
MAX>"\J@5_]1R__#6````864.90````%T4DY3`$#FV&8````!8DM'1`"(!1U(
M````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$R,*'^Q:!@```$!)
M1$%4>-H=B\<!@$`,PPP<[>@]=O;?DX`?TD<&\$S+C6^5N(7&M12].9`DD1S0
M!<ULAKO3BGQ%==+Z_[77W@(O@%,#D"2PMN4`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&AE;65S+V=R87!H
M:6-S+W5N:VYO=VXM8F%C:V=R;W5N9"YP;F<`````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,38T`#$P
M-#$W,S8R-S4S`#`R-C`T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````!P````X(`````,8V
M6<<````)<$A9<P```$@```!(`$;):SX````F241!5!C3G<LQ`0`P#(`P_!NJ
MC3IB!U6P*U=8U8%80D)"0KCP^1[BD$TKP9'OK@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+W1H96UE<R]G<F%P:&EC<R]W965K=FEE
M=RYP;F<````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4R,0`Q,#0Q-S,V,C<U,P`P
M,C0P-3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`(```"0D6@V```!&$E$050H
MSYU2,:Y&0!">W9V(2(C0:)Q!*:ZBT2A%XP1Z5W`+E^`""HEH%`J)`V!?,9Y?
M\(K_?<5F9G:^G9EO%N!+,``HRW+?=P"@4_[B:I.;IBD"@&F:7=?=,IZVXS@`
M@`#@NJYA&(RQ3UW&;BXBCN-X$#S/FZ:)+J[95YJJJE0*R4<\C'5=GX,B(N=<
M5=4/X5H]"`(`6);%-,VF:2BX;1LE\"<ABJ*ZKO,\G^>9@HJB""&$$.^$)$DX
MYUF6Q7%\O,JY$,*RK)>6:!N^[Q=%$88A1:24BJ+0G/QUG>NZ]GVOZ_I3";Q)
M09*W;4L=Z[HNA$#$4^*#8-LV_0M2@Q;,&)-2;MMV2G00JJH:AN%<W%_0-.T_
M7^-K_`"I8XU"]9_A"@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]T:&5M97,O9W)A<&AI8W,O;F5W7V)I9RYP;F<`````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`T-S,`,3`T,3<S-C(W-3,`,#(S-C0S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P```%103%1%````!04%"@H*#0T-
M#0\4$Q,3'Q\?("`?)R<G+BXN,#`P,C(R-34Q-C8V.#DS.SLY86!>8V=N9V=G
M8VAP:VMK@X5]AX>"\J@5_]1R__#6`````P,#W$2#R0````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U00/
M$10VWS0:(0```&!)1$%4"-=MSCD2@"`01%$06414-A&&^]]3P=)D^%'7BYJ0
MIY2,V??S)%\(IJF4G*T=P[H>!Z4-`#CW'@-CI9=[6F.0\IU7;]LP0*]!K<L2
M(X96"`V4^I\B<&Z>`808P@U,"0WILGV@RP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O
M=&AE;65S+V=R87!H:6-S+V%D9')E<W-B;V]K7V)R;W=S92YP;F<`````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P-#<V`#$P-#$W,S8R-S4S`#`R-C$Q-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(`P```"@M#U,```!44$Q410```!43$S$Q,9@L$TI*2DI+2X1?5VEJ
M:M]"'G5U=7Y^?H^/CYZ>GJVEIJVMK:ZNKK^_O]/3T^7EY>?GY^CHZ.GIZ>SL
M[/7U]?;V]OCX^/___P```*V\%Q\````!=%).4P!`YMAF`````6)+1T0`B`4=
M2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,"!(H!`"M+-H```!C
M241!5'C:;8]9#H`@#`5QWP7<=>Y_3R,%(XGSU\E[3:O4#WC>^=P=2S`<L\,0
MY3&SU!B%#D-5/2&Z8"A"*142OS6?K$,SB.DO0=,XP2JS;?UM;-*P.91$EP2A
MR#PU\7.?_S[<_B$-+.K['10`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1H96UE<R]G<F%P
M:&EC<R]C86QE;F1A<G,N<&YG````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8T,``Q
M,#0Q-S,V,C<U,P`P,C0Q-C$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`(```"0
MD6@V```!9TE$050HSYU2NX[",!"<C1<4*"(>39"@HZ"CH*'@)_@$6J3P)=`B
M&@H^@([?0)04%"`E%K($2.YPX>0*<Y<(KKF;PMKU[GI&LP;^"`*P7J_3-`7@
MSNP;Q=BEL]F,`=1JM=/I]-;Q&8=A"(`!=#J=(`B(*.<E>DN964KY&NCW^THI
M5RAV%\=\WW=4_/EJ,7`E(83G>;[O`_!^NE>KU7`X[/5Z412YF\%@T&JUGL\G
M$5EK<Z>,,4F2G,]G*>5BL:A4*DF27*_7[78+((YCK;76>K_?YY*(Z'@\3B83
MI50414((`.5RV94\SR.B1J.12P+0[78/A\-\/E\NE]9:IQL`,V=95BJ5F#F7
M)*4<C\=A&-;K]>ET>KO=M-9!$(Q&H\UF\W@\C#%Q'+\V;8RYW^_,[*B9.4U3
M(81S20C!S$2DE&JWVR^69K/I_H5SPRV8B+(LL]86+6(`N]WN<KD4C?\5U6KU
M/U_CS_@"B'K#9FXW,QT`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T:&5M97,O9W)A<&AI8W,O=&]D87DN
M<&YG````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W,S(`,3`T,3<S-C(W-3,`
M,#(S,S0W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```,!03%1%
M````"PX)$1$1%!04&1D9/1L40QT5)S$B+BXN4",:4R4;,C(R5R8=-#0T,STO
M.3DY82L@-4`Q-D4P/S\_0DI`2DI*=CXO1E5!255%6UM;5F)26&158&!@6V97
MI4DW965E9F9FJ5A)A86%BXN+EY>7FYN;M+2TM;6UMK:VN[N[O+R\Q,3$R<G)
MRLK*S,S,SL[.S\_/TM+2T]/3V]O;W-S<W]_?X.#@XN+BY.3DZ.CHZ>GIZNKJ
M[>WM[^_O____````]>R[4P````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L1```+$0%_9%^1````!W1)344'U`P($B@T)G0<=@```)-)1$%4
M>-IMS`<.PC`,!="P2QEA%`A[%B@-LY21`O_^MR*A2J@$W[(E/UDFY$\`R$["
M%!AW$X(V!@LQ^0K2=,Z%[QI!RQ6^X&(&O2^Y4+6/;Y!%M(T.=ZM902:^05@L
MYY[T5=)/<+%']L.BEH%0PFUS]@Q<)02KX]I`4+/S.^^DP7'ZPTZCD.JQ>I6I
M'6`JY#-^\P:;1A6"!=,E9`````!)14Y$KD)@@@``````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]K<F]N;VQI=&@O=&AE;65S+V=R87!H:6-S+W)E8W5R+G!N9P``````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,C0U`#$P-#$W,S8R-S4S`#`R,S,T-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````#`````P!`P```&R[SJ0````&4$Q410``,____T='R)(`
M```"=%).4_\`Y;<P2@````%B2T=$`?\"+=X````)<$A9<P```$@```!(`$;)
M:SX````J241!5`C78_C_@>'!!X;_!0SW-S#T;V!@8V"X+P!BW__`\/X#PP>@
MU`<`.K81_G=X_VH`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H
M+W1H96UE<R]G<F%P:&EC<R]A;&%R;5]S;6%L;"YP;F<`````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#<S,P`Q,#0Q-S,V,C<U,P`P,C0U,30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M``X````-"`,```"N`J]-````VU!,5$4O`!P/#P\B'@Q`.!9)0!A;/`!83AY9
M3A^$7`".80"@<`"I>@*O@@ZQAA*=D5.WCR.YE"?)E0>]G3>_GSS!HT+$H4[8
MIQ?$J4S%JDK'JE/&L67-LVG0N'#FOBC2NGC2OFO8PXKQT47NT&#KSWSPTF+_
MW0#TUU#SUE[VWEORVXCYX6'TWXSXXWGTX8_ZYWS]ZWKZZ8WWYJ;[ZYSVZK3_
M[XS^[Y?_\)+Z\*S]\:C\\;+\\;3\\K[Z\L3_]*[_]+/_];;Z\\__];O_];S_
M^,S^^-/_^MK^^N?___\```"JOZIQ`````7123E,`0.;89@````%B2T=$`(@%
M'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#`@2+`43QME(````
M>4E$051XVF-@``,/#P8DX*$LC,1GTS36%F>&RTDY6%OI"L'DV0S=W%V-)-BA
MDB(V+J[.%DH\$&DV>4M'>UM3=5X6L"2?@9V3F8F^FA@[2)I)1<=<3TM#45:0
M`\CU$)664Y"1%.#GYN)D]0"ZA]$#`:"&FZBBNA+*`P!ZNQ+Y&Q3&?P````!)
M14Y$KD)@@@`````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T:&5M97,O9W)A
M<&AI8W,O>65A<G9I97<N<&YG````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-C``
M,3`T,3<S-C(W-3,`,#(T,#8S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P````1G04U!``#6V-1/6#(```#/4$Q410```(Z.CO___^;FYKZ^OKR\
MO.3DY.?GY_/S\_GY^8V-C>7EY0P,#!P<'./CXQ$1$9B8F&IJ:A<7%XR,C.+B
MXO'Q\1@8&,K*RFUM;0,#`WM[>U%145)24L/#P^KJZK^_OYN;F]K:VO?W]ZVM
MK9*2DH>'A^_O[[N[N[:VMI:6EO+R\KV]O8&!@?3T]*BHJ)F9F82$A).3D]_?
MW_;V]H.#@\+"POKZ^H:&AOO[^_#P\(B(B)V=G924E)>7EX*"@I65E>WM[0D)
M"8"`@.SL[(6%A8`6B2X````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A
M9'EQR64\````ITE$050HSVW.QQ:",!`%T)AH"(DB*HA=I"D*@KUW__^;G+!@
MH;[%.Y.[F`E"/SG9=I+HES"\G1>>!^`>?7_W3M/U-8J>.H`U+D%F1<BP/P=0
M#4/3J!!$491@DX%&J2#R/3`M@$ZEW,-Y`2P%?V#$"<T*8%)'+8QDR0E@1!IM
MC&3)":#;K-9P7O(*&;SN9C!E;+7=RQVJZCAQ?#`9$)/@<E[(\_?K7_D`K\@0
M(P6Z2CP`````245.1*Y"8((`````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&AE;65S+V=R87!H:6-S+VYE=RYP
M;F<``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#<R`#$P-#$W,S8R-S4S
M`#`R,S`Q-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```$(4$Q4
M10````,#`P4%!0H*"@T-#0T/%!,3$Q\?'R`@'R<G)RXN+C`P,#(R,C4U,38V
M-C@Y,SL[.6%@7F-G;F=G9V-H<&MK:X"`@(&!@8*"@H.#@X.%?82$A(6%A8:&
MAH>'@H>'AXB(B(V-C8Z.CI*2DI.3DY24E)65E9:6EI>7EYB8F)F9F9N;FYV=
MG:BHJ*VMK?*H%;N[N[R\O+V]O;Z^OK^_O\+"PL/#P\K*RLW-S<_/S__4<MG9
MV=O;V]W=W=[>WM_?WM_?W^'AX>+BXN/CX^3DY.;FYN?GY^CHZ.KJZNOKZ^SL
M[.WM[>[N[N_O[_'Q\?_PUO+R\O/S\_3T]/;V]O?W]_GY^?KZ^OO[^S?W%B<`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4
M$R,2#(#"4````+A)1$%4>-IMSM4.PD`00-'B[N[NLK@L5LI0O,L"A?__$[9M
MP@-P'R:9DTPR'/=3L]&HUVO52J5<*A8*#-K93":53"1BT4@D7&,P[G19O3YK
M,&HQD`4!(.WRQ$51O`Q5`%@;"/:M%GMIK`!,G5X]P9PY<#AK`$9"",;8(4D3
M%>96MB&$W/3&JS!C$R.=/725-]K)#H(8V0#.&FSWQY/?Q%GH_?D"!>3'XR8L
M^?654JI`.Y?+?_K[^E=O"`\G-P=:(KX`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=&AE;65S+V=R87!H:6-S
M+V%L87)M+G!N9P``````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S,S`#$P-#$W
M,S8R-S4S`#`R,S,R-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,`
M``#;4$Q4104`'`\/#R(>#$`X%DE`&%L\`%A.'EE.'X1<`(YA`*!P`*EZ`J^"
M#K&&$IV14[>/([F4)\F5![V=-[^?/,&C0L2A3MBG%\2I3,6J2L>J4\:Q9<VS
M:="X<.:^*-*Z>-*^:]C#BO'11>[08.O/?/#28O_=`/374//67O;>6_+;B/GA
M8?3?C/CC>?3AC_KG?/WK>OKIC??FIOOKG/;JM/_OC/[OE__PDOKPK/WQJ/SQ
MLOSQM/SROOKRQ/_TKO_TL__UMOKSS__UN__UO/_XS/[XT__ZVO[ZY____P``
M`(OS[60````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``
M"Q,!`)J<&`````=T24U%!]0,"!(K![*)+J,```!Y241!5'C:8V#``3P\T/C*
MPB@B;)K&VN+,2/)2#M96ND((-6R&;NZN1A+L<`4B-BZNSA9*/#`E;/*6CO:V
MINJ\+%`%?`9V3F8F^FIB[!`E3"HZYGI:&HJR@AQ@`0]1:3D%&4D!?FXN3E8/
ML!L9/1``;I&)J@=^O^`!`-S=$OG0M11>`````$E%3D2N0F""````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:W)O;F]L:71H+W1H96UE<R]G<F%P:&EC<R]A='1E;F1E97,N
M<&YG```````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,R,``Q,#0Q-S,V,C<U,P`P,C0Q
M-S4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3```!<5!,5$4```4#
M`0`$`0`"`@($!`(%!04("`D%"P<2"@$:#@$-$QD.$QH.%!H.%!L.%1L4%!8<
M$PL1%Q04%1<0%AT5%A@6%A@1&"`D%@DC&`X;&QPK&`09*Q`?*@T?)2LH)R0C
M*"TE*"H^/#9*039I.@HU2DTG629(1D1Q/PHP8B!33$:$2@TG=2@X;CA$77E*
M76^,3@U:6EHI?BHI?RDN@"XM@2U)9(%.9'DMA2U/<D(QAS%3:'U9:GQG9V<U
MBC9=:WA3;8E4;8=/?D]M:VM:<(>J7PHYDCE:<HNL8`R6:1I$C41<=(QS<&==
M>9:Z9A.@<QYR>7]L?(MZ>7EH?I:];!.^;1.\;1N_;1.^;A-K@9>`?7;$<!-J
MAJ'-=AK.>1QRCJG/>1R`D*)HIVF!D9^"DZ2`EJO1C2>)FZN)G*S6D"F*GK32
MESO:EB_4FC[=F#&II9BMJ9S#Q\W(R\W+TMS-T]G,U-S;UL?=X>3FX=#<XN?P
MZMD```"-7NS2`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q(```L2`=+=?OP````'=$E-10?4#!03(C-9\N-/````'71%6'1#;VUM96YT
M`$-R96%T960@=VET:"!4:&4@1TE-4.]D)6X```"O241!5'C:8V"`@:HJ!A20
M7UZ9AQ#B%V4KK:RLA`E(LAK8,$?F9,$%6)P"&9GD<K/A`IRAX2'!BAFIE=Y0
M`8[XV)@H)3\/N"%2OOI:83(:%I[&.A`1`7=U91=IU41;8Q.P@)"_IKB$F@J[
MHZNY$4A`)"#.KK`@P<U,T-)0&R2@D!EM75:1'N0@7`5QO7R*CU5Q45J)EQC4
M4MD(>[VD9&=373Z81WAX>'EY>;BY&+`#`+60)Z]ES0&.`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1H96UE<R]G<F%P:&EC<R]K<F]N
M;VQI=&@N<&YG```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8T,``Q,#0Q-S,V,C<U
M,P`P,C0R,S8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!`````0"`(```"0D6@V```!9TE$
M050HSYU2NX[",!"<C1<4*"(>39"@HZ"CH*'@)_@$6J3P)=`B&@H^@([?0)04
M%"`E%K($2.YPX>0*<Y<(KKF;PMKU[GI&LP;^"`*P7J_3-`7@SNP;Q=BEL]F,
M`=1JM=/I]-;Q&8=A"(`!=#J=(`B(*.<E>DN964KY&NCW^THI5RAV%\=\WW=4
M_/EJ,7`E(83G>;[O`_!^NE>KU7`X[/5Z412YF\%@T&JUGL\G$5EK<Z>,,4F2
MG,]G*>5BL:A4*DF27*_7[78+((YCK;76>K_?YY*(Z'@\3B83I50414((`.5R
MV94\SR.B1J.12P+0[78/A\-\/E\NE]9:IQL`,V=95BJ5F#F7)*4<C\=A&-;K
M]>ET>KO=M-9!$(Q&H\UF\W@\C#%Q'+\V;8RYW^_,[*B9.4U3(81S20C!S$2D
ME&JWVR^69K/I_H5SPRV8B+(LL]86+6(`N]WN<KD4C?\5U6KU/U_CS_@"B'K#
M9FXW,QT`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VMR;VYO;&ET:"]T:&5M97,O9W)A<&AI8W,O97AP86YD+G!N9P``````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`T,S,`,3`T,3<S-C(W-3,`,#(S-3`T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`0#````[=WB4@```"I03%1%``,`8&!@AFP`
M2W>X>)5?LY``FK"'GK;9L\2ET<*"Y]ZTTN#U____````3C<R#0````%T4DY3
M`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)
M344'U`P4$QD/2B]P\````&I)1$%4>-IC8$"`NQ<@-.^LN0QW[X(8*V-YS8N!
MHKQ3=2_7;+<%J;EXO7I[+5#D[MWKVZN!C&L=*9?+RVT9>&^DI=P%*>:=F^8;
M"]+.>]?E9BS$P+NS($;SWEP*9<R*A=H9>A4B<O<NV'H`"3(L:.BPORH`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI
M=&@O=&AE;65S+V=R87!H:6-S+V1A>79I97<N<&YG````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-3`P`#$P-#$W,S8R-S4S`#`R,S8W,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`(`@```)"1:#8```$'241!5"C/G5(QDH,P#%Q;PO&DR##0,,SD
M#324?"2?X#/4_((F;TD#18K\@`+C*\3Y#$F3V\(CV2OO6C+P)12`ON_7=04@
MJ_]%'$O:MBT#2-/T\7@<&.]Q410`&,#U>KU<+DJI/UVE#BDS/Y_/K:"JJM?K
M!4!K'=O56H<R:ZU(<7Q\B`.;B+36UEH`^IU-1'5=EV4YS[-SSCFGE'+.;<R/
MO>NZ#@#SIF^,(2(BVEF*88R)+<ECLBP[*H@Q<1PK>.^3))%T5R"#.YU.M]NM
M:9K[_2[[R[($#H>[F3GT<9HF(I*8B)@Y3&8KR/-<KI=NR("54MY[:=1.81B&
M<1SC5W[$^7S^S]?X&C_.PG]1-W[D^P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1H96UE<R]G
M<F%P:&EC<R]G;W1O+G!N9P``````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4W
M,0`Q,#0Q-S,V,C<U,P`P,C,R,#``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3````A%!,5$4```!):#5R721T7B-[9"=4=SU@@4B4=3.CAC.FACNF
MB#]]EVJDC$>TDC>VE$*[F3R\GDB^GD.]GTC$HC[%H$;&H$3&HS_+I3[/K$+1
MK4+/K$[4KT/7L$/3L%#8L4/=M$39M%+=M4?=MTFIR9/@OV*PSYJXU*3&W+?)
MW;O)WKO2X\8````'_@]_`````7123E,`0.;89@````%B2T=$`(@%'4@````)
M<$A9<P``"X@```N(`>6.*4D````'=$E-10?4#`@2*"U"'[2V````;DE$051X
MVIW.V0Z",!!`T:(B(H+@!LA2M5B7^___1QL"A/!BO)F7.2\S0OP6,\`,](M)
ML[U5UX[X?MY::7;-H^S@]30I12+ER0K!VN802GD9P669]F!S6.WO=18QG%UL
M\N)X9OP#/SYX,/D-Q'^UB@`-,.(KJCD`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T:&5M97,O<')I;G0O````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-3,`,#(Q,#4V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1H
M96UE<R]P<FEN="]S8W)E96XN8W-S````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#,Q-@`Q,#0Q-S,V,C<U,P`P,C,P-#0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J("1(;W)D93H@:W)O;F]L
M:71H+W1H96UE<R]P<FEN="]S8W)E96XN8W-S+'8@,2XR+C(N,B`R,#`U+S$P
M+S$X(#$R.C(W.C0V(&IA;B!%>'`@)`H@*B\*"BYD87DL("YO=&AE<FUO;G1H
M+"`N=V5E:V5N9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.PH@("`@
M8V]L;W(Z(",P,#`["GT*+G1O9&%Y('L*("`@(&)O<F1E<BUC;VQO<CH@(S`P
M,#L*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T:&5M97,O<VEM<&QE
M>"\`````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-3,`,#(Q-#`S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L
M:71H+W1H96UE<R]S:6UP;&5X+W-C<F5E;BYC<W,`````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#8P-@`Q,#0Q-S,V,C<U,P`P,C,S-S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RHJ"B`J("1(;W)D93H@
M:W)O;F]L:71H+W1H96UE<R]S:6UP;&5X+W-C<F5E;BYC<W,L=B`Q+C$@,C`P
M-"\Q,"\Q-R`R,#HS-SHT.2!M9&IU:VEC($5X<"`D"B`J+PH*+F1A>2!["B`@
M("!C;VQO<CH@(T9&1D9&1CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",W,SDP
M0CD["GT*+F1A>3IH;W9E<B!["B`@("!C;VQO<CH@(S,S,S,S,SL*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z(",W,SDP0CD["GT*+G-E;&5C=&5D('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z(",X-D(T1$8["GT*+F1A>2UE=F5N=&)O>"!A('L*
M("`@(&-O;&]R.B`C,#`P,#`P.PI]"BYW965K+65V96YT8F]X(&$@>PH@("`@
M8V]L;W(Z(",P,#`P,#`["GT*+FUO;G1H+65V96YT8F]X(&$@>PH@("`@8V]L
M;W(Z(",P,#`P,#`["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T:&5M97,O
M8G5R;G1O<F%N9V4O````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-3,`,#(R,C4P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:W)O;F]L:71H+W1H96UE<R]B=7)N=&]R86YG92]S8W)E96XN8W-S````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#0Q,@`Q,#0Q-S,V,C<U,P`P,C0R,S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+RHJ"B`J(%1H
M96UE(&)Y.B!%<FEC($IO;B!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H
M>7-I8W,N=71E>&%S+F5D=3X*("H@4&QE87-E(&-O;G1A8W0@=&AE('1H96UE
M)W,@875T:&]R(&9O<B!A;GD@;6ES<VEN9R!S='EL92X*("H*("H@)$AO<F1E
M.B!K<F]N;VQI=&@O=&AE;65S+V)U<FYT;W)A;F=E+W-C<F5E;BYC<W,L=B`Q
M+C$N,BXR(#(P,#4O,3`O,3@@,3(Z,C<Z-#4@:F%N($5X<"`D"B`J+PH*+G1O
M9&%Y('L*("`@(&)O<F1E<BUC;VQO<CH@(V,V,#L*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]T
M:&5M97,O;6]Z:6QL82\`````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(Q,S<Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:W)O;F]L:71H+W1H96UE<R]M;WII;&QA+W-C<F5E;BYC<W,`````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$W,P`Q,#0Q-S,V,C<U,P`P,C,S-C``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+RHJ
M"B`J("1(;W)D93H@:W)O;F]L:71H+W1H96UE<R]M;WII;&QA+W-C<F5E;BYC
M<W,L=B`Q+C$@,C`P-"\Q,2\P,R`Q-CHQ-#HT.2!C:'5C:R!%>'`@)`H@*B\*
M"BYL96=E;F0@>PH@("`@8V]L;W(Z(",P,#`["GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO
M;&ET:"]T:&5M97,O8FQU97=H:71E+P``````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(Q-S$R`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+W1H96UE<R]B;'5E=VAI=&4O<V-R965N
M+F-S<P`````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8U-P`Q,#0Q-S,V,C<U,P`P
M,C,W,3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+W1H96UE<R]B;'5E=VAI=&4O
M<V-R965N+F-S<RQV(#$N-"XQ,"XU(#(P,#4O,3$O,3$@,C,Z,S0Z,3(@:F%N
M($5X<"`D"B`J+PH*+RH@06QT97)N871I;F<@<W1Y;&5S+B!I=&5M,"P@:71E
M;3$@87)E(&1E<')E8V%T960N("HO"BYR;W=%=F5N('L*("`@(&)A8VMG<F]U
M;F0Z("-E964["GT*+G)O=T]D9"!["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]
M"@HN;&5G96YD('L*("`@(&-O;&]R.B`C,#`P.PI]"BYD87D@>PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V4Y93EE.3L*?0HN9&%Y.FAO=F5R('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-F9F8["GT*82YN97=%=F5N="!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C93EE.64Y.PI]"F$N;F5W179E;G0Z:&]V97(@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9CL*?0H`````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]T:&5M97,O8V%T96=O<GE#4U,N<&AP````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(U-S8`,3`T,3<S-C(W-3,`,#(R-C,P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]T:&5M97,O8V%T96=O<GE#4U,N<&AP
M+'8@,2XT+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(Y.C`T(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*B\*"D!D969I;F4H)T%55$A?2$%.
M1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=+4D].3TQ)5$A?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2U)/3D],251(
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M26UA9V4N<&AP)SL*"FAE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+V-S<R<I
M.PH*)&-O;&]R<R`]("1C36%N86=E<BT^8V]L;W)S*"D["B1F9T-O;&]R<R`]
M("1C36%N86=E<BT^9F=#;VQO<G,H*3L*9F]R96%C:"`H)&-O;&]R<R!A<R`D
M8V%T96=O<GD@/3X@)&-O;&]R*2!["B`@("!I9B`H)&-A=&5G;W)Y(#T]("=?
M=6YF:6QE9%\G*2!["B`@("`@("`@8V]N=&EN=64["B`@("!](&5L<V5I9B`H
M)&-A=&5G;W)Y(#T]("=?9&5F875L=%\G*2!["B`@("`@("`@96-H;R`G+FUO
M;G1H+65V96YT0F]X+"`N=V5E:RUE=F5N=$)O>"P@+F1A>2UE=F5N=$)O>"P@
M+F)L;V-K+65V96YT0F]X+"`N;&5G96YD+65V96YT0F]X+"`G+`H@("`@("`@
M("`@("`G+FUO;G1H+65V96YT0F]X(&$L("YW965K+65V96YT0F]X(&$L("YD
M87DM979E;G1";W@@82P@+F)L;V-K+65V96YT0F]X(&$L("YL96=E;F0M979E
M;G1";W@@82P@)RP*("`@("`@("`@("`@)RYM;VYT:"UE=F5N=$)O>"!A.FAO
M=F5R+"`N=V5E:RUE=F5N=$)O>"!A.FAO=F5R+"`N9&%Y+65V96YT0F]X(&$Z
M:&]V97(L("YB;&]C:RUE=F5N=$)O>"!A.FAO=F5R+"`N;&5G96YD+65V96YT
M0F]X(&$Z:&]V97(@>R`G.PH@("`@?2!E;'-E('L*("`@("`@("`D8VQA<W,@
M/2`G+F-A=&5G;W)Y)R`N(&UD-2@D8V%T96=O<GDI.PH@("`@("`@(&5C:&\@
M(B1C;&%S<RP@)&-L87-S(&$L("1C;&%S<R!A.FAO=F5R('L@(CL*("`@('T*
M"B`@("!E8VAO("=B;W)D97(M8V]L;W(Z("<@+B!(;W)D95]);6%G93HZ;6]D
M:69Y0V]L;W(H)&-O;&]R+"`M,'@T-"D@+B`G.R`G+`H@("`@("`@("=C;VQO
M<CH@)R`N("AI<W-E="@D9F=#;VQO<G-;)&-A=&5G;W)Y72D@/R`D9F=#;VQO
M<G-;)&-A=&5G;W)Y72`Z("1F9T-O;&]R<ULG7V1E9F%U;'1?)UTI("X@)SL@
M)RP*("`@("`@("`G8F%C:V=R;W5N9#H@)R`N("1C;VQO<B`N("([('U<;B([
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W1H96UE<R]S8W)E
M96XN8W-S````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(Q,@`Q
M,#0Q-S,V,C<U,P`P,C$W,3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+W1H96UE
M<R]S8W)E96XN8W-S+'8@,2XR+C0N,3`@,C`P-2\Q,B\Q-R`Q-SHP.3HP,2!C
M:'5C:R!%>'`@)`H@*B\*"B-M96YU('L*("`@("\J($UE;G4@8F]T=&]M(&UA
M<F=I;BP@861D960@9F]R($)#+B`J+PH@("`@;6%R9VEN+6)O='1O;3H@.'!X
M.PI]"@HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A<F4@
M9&5P<F5C871E9"X@*B\*+G)O=T5V96X@>PH@("`@8F%C:V=R;W5N9#H@(V5E
M93L*?0HN<F]W3V1D('L*("`@(&)A8VMG<F]U;F0Z("-D9&0["GT*"B\J($EM
M86=E(&%L:6=N;65N="P@861D960@9F]R($)#+B`J+PII;6<@>PH@("`@=F5R
M=&EC86PM86QI9VXZ(&UI9&1L93L*?0H*+FAO=7(@>PH@("`@9F]N="US:7IE
M.B`Q,7!X.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["GT*+FAA;&9H;W5R('L*
M("`@(&9O;G0M<VEZ93H@.'!X.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["B`@
M("!V97)T:6-A;"UA;&EG;CH@<W5P97(["GT*+F5V96YT('L*("`@(&9O;G0M
M<VEZ93H@,3%P>#L*?0HN979E;G0M=&5N=&%T:79E('L*("`@(&9O;G0M<VEZ
M93H@,3%P>#L*("`@(&9O;G0M<W1Y;&4Z(&ET86QI8SL*?0HN979E;G0M8V%N
M8V5L;&5D('L*("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@('1E>'0M9&5C;W)A
M=&EO;CH@;&EN92UT:')O=6=H.PI]"BYL96=E;F0@>PH@("`@9F]N="US:7IE
M.B`Q,7!X.PH@("`@<&%D9&EN9RUR:6=H=#H@,3!P>#L*?0HN=&]D87D@>PH@
M("`@8F]R9&5R.B`R<'@@<V]L:60@(S0T-CL*("`@(&)A8VMG<F]U;F0Z("-F
M9F8["GT*+FUO;G1H9W)I9"!["B`@("!B86-K9W)O=6YD.B`C.3DY.PI]"BYO
M=&AE<FUO;G1H('L*("`@(&)A8VMG<F]U;F0Z("-E-V5E96,["GT*+G=E96ME
M;F0@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CEE9CL*?0H*+RH@0FQO8VLM<W!E
M8VEF:6,@<W1Y;&5S+B`J+PHN8FQO8VLM;6]N=&AG<FED('L*("`@(&)A8VMG
M<F]U;F0Z("-F9F8["GT*+F)L;V-K+6UO;G1H9W)I9"`N=&]D87D@>PH@("`@
M8F]R9&5R.B`Q<'@@<V]L:60@(S0T-CL*?0H*+RH@8F]R9&5R+6-O;&]R(&%N
M9"!B86-K9W)O=6YD+6-O;&]R('=I;&P@86QW87ES(&)E(&]V97)R:61D96X@
M9F]R('1H90H@*B`J+65V96YT8F]X(&-L87-S97,@*B\*+F)L;V-K+65V96YT
M8F]X('L*("`@(&)O<F1E<BUW:61T:#H@,7!X.PH@("`@8F]R9&5R+7-T>6QE
M.B!S;VQI9#L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PH@("`@<&%D
M9&EN9RUL969T.B`Q<'@["GT*+FUO;G1H+65V96YT8F]X('L*("`@(&)O<F1E
M<BUW:61T:#H@,7!X.PH@("`@8F]R9&5R+7-T>6QE.B!S;VQI9#L*("`@("UM
M;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PH@("`@<&%D9&EN9RUL969T.B`Q<'@[
M"B`@("!M87)G:6XZ(#%P>#L*?0HN=V5E:RUE=F5N=&)O>"!["B`@("!B;W)D
M97(M=VED=&@Z(#%P>#L*("`@(&)O<F1E<BUS='EL93H@<V]L:60["B`@("`M
M;6]Z+6)O<F1E<BUR861I=7,Z(#$U<'@["B`@("!P861D:6YG+6QE9G0Z(#5P
M>#L*?0HN9&%Y+65V96YT8F]X('L*("`@(&)O<F1E<BUW:61T:#H@,7!X.PH@
M("`@8F]R9&5R+7-T>6QE.B!S;VQI9#L*("`@("UM;WHM8F]R9&5R+7)A9&EU
M<SH@,35P>#L*("`@('!A9&1I;F<M;&5F=#H@-7!X.PI]"BYL96=E;F0M979E
M;G1B;W@@>PH@("`@8F]R9&5R+7=I9'1H.B`Q<'@["B`@("!B;W)D97(M<W1Y
M;&4Z('-O;&ED.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["B`@("!P
M861D:6YG.B`Q<'@@-7!X(#%P>"`U<'@["GT*"BYS96QE8W1E9"UC;VYT<F]L
M('L*("`@(&)A8VMG<F]U;F0Z("-B8F-B9F8["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(SDY.3L*?0H*+F1A>2!["B`@("!D:7-P;&%Y.B!B;&]C
M:SL*("`@(&9L;V%T.B!L969T.PH@("`@=VED=&@Z(#$T<'@["B`@("!H96EG
M:'0Z(#$T<'@["B`@("!P861D:6YG.B`Q<'@["B`@("!B86-K9W)O=6YD.B`C
M9&1D.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(SDY.3L*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C.3DY.PH@("`@9F]N="US:7IE.B`Q
M,7!X.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["B`@("!T97AT+6%L:6=N.B!C
M96YT97(["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*+F1A>3IH;W9E
M<B!["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["B`@("!B86-K9W)O=6YD
M.B`C93EE.64Y.PI]"BYW965K('L*("`@(&9L;V%T.B!L969T.PH@("`@9F]N
M="US:7IE.B`Q,'!X.PH@("`@<&%D9&EN9RUL969T.B`R<'@["GT*82YN97=%
M=F5N="!["B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@(&9L;V%T.B!L969T.PH@
M("`@:&5I9VAT.B`Q,G!X.PH@("`@=VED=&@Z(#$R<'@["B`@("!P861D:6YG
M.B`T<'@@,"`P.PH@("`@9F]N="US:7IE.B`V<'@["B`@("!T97AT+6%L:6=N
M.B!C96YT97(["B`@("!B86-K9W)O=6YD.B`C9&1D.PH@("`@8F]R9&5R+7)I
M9VAT.B`Q<'@@<V]L:60@(SDY.3L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"`C.3DY.PI]"F$N;F5W179E;G0Z:&]V97(@>PH@("`@8F%C:V=R;W5N
M9#H@(V4Y93EE.3L*?0IA+FYE=T5V96YT(&EM9R!["B`@("!V97)T:6-A;"UA
M;&EG;CH@=&]P.PI]"@HN>65A<BUE=F5N="!["B`@("!B86-K9W)O=6YD.B`C
M9F9F,39B.PI]"@HC:V=O=&\@82!["B`@("!C;VQO<CH@(S`P,#L*?0HC:V=O
M=&\@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z
M("-A86$["B`@("!B;W)D97(M8V]L;W(Z('1R86YS<&%R96YT.PI]"@HO*B!&
M<F5E+V)U<WD@9W)I9"X@*B\*+F)U<WD@>PH@("`@8F%C:V=R;W5N9#H@(V8P
M,#L*?0HN=6YK;F]W;B!["B`@("!B86-K9W)O=6YD.B`C9#1D,&,X('5R;"@B
M9W)A<&AI8W,O=6YK;F]W;BUB86-K9W)O=6YD+G!N9R(I(')E<&5A="!T;W`@
M;&5F=#L*?0HN9G)E92!["B`@("!B86-K9W)O=6YD.B`C,CAB,C)B.PH@("`@
M8V]L;W(Z("-F9F8["GT*"F1I=BYF8F=R:60@>PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(V9F9CL*("`@(&]V97)F;&]W.B!A=71O.PI]"BYF8F=R:60@=&%B
M;&4@>PH@("`@=VED=&@Z(#$P,"4["B`@("!B;W)D97(M8V]L;&%P<V4Z(&-O
M;&QA<'-E.PI]"BYF8F=R:60@=&%B;&4@=&0L("YF8F=R:60@=&%B;&4@=&@@
M>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*?0HN9F)G<FED('1A8FQE
M("YL86)E;"!["B`@("!B;W)D97(Z(&YO;F4["GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]D;V-S+P``````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-3,`,#$W,S8U`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O
M;F]L:71H+V1O8W,O55!'4D%$24Y'````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`R,P`Q,#0Q-S,V,C<U,P`P,C`V,C(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H@57!G<F%D:6YG('1O($MR;VYO;&ET:"`R+C`*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@
M("1$871E.B`R,#`T+S$Q+S$V(#(R.C4X.C0R("0*.E)E=FES:6]N.B`@("`@
M("12979I<VEO;CH@,2XQ("0*.D-O;G1A8W0Z("`@("`@(&MR;VYO;&ET:$!L
M:7-T<RYH;W)D92YO<F<*"@I4:&5S92!A<F4@:6YS=')U8W1I;VYS('1O('5P
M9W)A9&4@9G)O;2!+<F]N;VQI=&@@,2XQ+G@@=&\@2W)O;F]L:71H(#(N,"X*
M4&QE87-E(&)A8VMU<"!Y;W5R(&5X:7-T:6YG(&1A=&$@8F5F;W)E(')U;FYI
M;F<@86YY(&]F('1H92!S=&5P<R!D97-C<FEB960*8F5L;W<N("!9;W4@8V%N
M)W0@=7-E('1H92!U<&1A=&5D(&1A=&$@=VET:"!Y;W5R(&]L9"!+<F]N;VQI
M=&@@=F5R<VEO;@IA;GEM;W)E+@H*"E-13"!"86-K96YD<PH]/3T]/3T]/3T]
M/3T*"E1H<F5E(&YE=R!F:65L9',@86YD(&$@;F5W('1A8FQE(&AA=F4@8F5E
M;B!A9&1E9"!T;R!T:&4@9&5F875L="!344P@=&%B;&4*;&%Y;W5T('1O('!R
M;W9I9&4@=&AE('-C:&5D=6QI;F<@9F5A='5R97,@=&\@2W)O;F]L:71H+@H*
M17AE8W5T92!T:&4@<')O=FED960@4U%,('-C<FEP="!T;R!U<&1A=&4@>6]U
M<B!D871A('1O('1H92!N97<@2W)O;F]L:71H"G9E<G-I;VXZ.@H*("`@;7ES
M<6P@+2UU<V5R/7)O;W0@+2UP87-S=V]R9#T\37E344PM<F]O="UP87-S=V]R
M9#X@/&1B(&YA;64^(#P@<V-R:7!T<R]U<&=R861E<R\Q+C%?=&]?,BXP+FUY
M<W%L+G-Q;`H*"D-A=&5G;W)I97,*/3T]/3T]/3T]/0H*0V%T96=O<FEE<R!A
M<F4@;F]W(&)E:6YG(&UA:6YT86EN960@8V5N=')A;&QY(&9O<B!A;&P@2&]R
M9&4@87!P;&EC871I;VYS('1H870*<W5P<&]R="!T:&5M+B`@5&\@8V]N=F5R
M="!T:&4@;VQD(&5V96YT(&-A=&5G;W)I97,@97AE8W5T92!T:&4@<')O=FED
M960@4$A0"G-C<FEP=#HZ"@H@("!P:'`@<V-R:7!T<R]U<&=R861E<R\R,#`T
M+3`U+3$Y7V-O;G9E<G1?8V%T96=O<FEE<U]T;U]S=')I;F=S+G!H<`H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O9&]C<R]214%$344`````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,S`W`#$P-#$W
M,S8R-S4S`#`R,#(T-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!7:&%T(&ES($MR;VYO;&ET:#\*/3T]/3T]/3T]/3T]/3T]
M/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#4O,3`O,3@@,3(Z,C<Z
M,C@@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+CDN."XQ("0*.D-O
M;G1A8W0Z("`@("`@(&MR;VYO;&ET:$!L:7-T<RYH;W)D92YO<F<*"BXN(&-O
M;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*2W)O
M;F]L:71H(&ES(&$@=V5B+6)A<V5D(&-A;&5N9&%R('-Y<W1E;2!W<FET=&5N
M(&EN(%!(4"!A;F0@=71I;&EZ:6YG('1H90I(;W)D92!!<'!L:6-A=&EO;B!&
M<F%M97=O<FLN"@I4:&ES('-O9G1W87)E(&ES($]322!#97)T:69I960@3W!E
M;B!3;W5R8V4@4V]F='=A<F4N("!/4TD@0V5R=&EF:65D(&ES(&$*8V5R=&EF
M:6-A=&EO;B!M87)K(&]F('1H92!@3W!E;B!3;W5R8V4@26YI=&EA=&EV96!?
M+@H*+BX@7V!/<&5N(%-O=7)C92!);FET:6%T:79E8#H@:'1T<#HO+W=W=RYO
M<&5N<V]U<F-E+F]R9R\*"@I/8G1A:6YI;F<@2W)O;F]L:71H"BTM+2TM+2TM
M+2TM+2TM+2TM+2T*"D9U<G1H97(@:6YF;W)M871I;VX@;VX@2W)O;F]L:71H
M(&%N9"!T:&4@;&%T97-T('9E<G-I;VX@8V%N(&)E(&]B=&%I;F5D(&%T"@H@
M(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VMR;VYO;&ET:"\*"@I$;V-U;65N=&%T
M:6]N"BTM+2TM+2TM+2TM+2T*"E1H92!F;VQL;W=I;F<@9&]C=6UE;G1A=&EO
M;B!I<R!A=F%I;&%B;&4@:6X@=&AE($MR;VYO;&ET:"!D:7-T<FEB=71I;VXZ
M"@HZ4D5!1$U%7SH@("`@("`@("`@("!4:&ES(&9I;&4*.D-/4%E)3D=?.B`@
M("`@("`@("`@0V]P>7)I9VAT(&%N9"!L:6-E;G-E(&EN9F]R;6%T:6]N"CI@
M9&]C<R]#2$%.1T538%\Z("`@($-H86YG97,@8GD@<F5L96%S90HZ8&1O8W,O
M0U)%1$E44V!?.B`@("!0<F]J96-T(&1E=F5L;W!E<G,*.F!D;V-S+TE.4U1!
M3$Q@7SH@("`@26YS=&%L;&%T:6]N(&EN<W1R=6-T:6]N<R!A;F0@;F]T97,*
M.F!D;V-S+U1/1$]@7SH@("`@("`@1&5V96QO<&UE;G0@5$]$3R!L:7-T"CI@
M9&]C<R]54$=2041)3D=@7SH@(%!O:6YT97)S(&]N('5P9W)A9&EN9R!F<F]M
M('!R979I;W5S($MR;VYO;&ET:"!V97)S:6]N<PH*"DEN<W1A;&QA=&EO;@HM
M+2TM+2TM+2TM+2T*"DEN<W1R=6-T:6]N<R!F;W(@:6YS=&%L;&EN9R!+<F]N
M;VQI=&@@8V%N(&)E(&9O=6YD(&EN('1H92!F:6QE($E.4U1!3$Q?(&EN('1H
M90I@8&1O8W,O8&`@9&ER96-T;W)Y(&]F('1H92!+<F]N;VQI=&@@9&ES=')I
M8G5T:6]N+@H*"D%S<VES=&%N8V4*+2TM+2TM+2TM+0H*268@>6]U(&5N8V]U
M;G1E<B!P<F]B;&5M<R!W:71H(%-K96QE=&]N+"!H96QP(&ES(&%V86EL86)L
M92$@"@I4:&4@2&]R9&4@1G)E<75E;G1L>2!!<VME9"!1=65S=&EO;G,@3&ES
M="`H1D%1*2P@879A:6QA8FQE(&]N('1H92!796(@870*(`H@(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+V9A<2\*"E1H92!(;W)D92!0<F]J96-T(')U;G,@82!N
M=6UB97(@;V8@;6%I;&EN9R!L:7-T<RP@9F]R(&EN9&EV:61U86P@87!P;&EC
M871I;VYS"F%N9"!F;W(@:7-S=65S(')E;&%T:6YG('1O('1H92!P<F]J96-T
M(&%S(&$@=VAO;&4N("!);F9O<FUA=&EO;BP@87)C:&EV97,L(&%N9`IS=6)S
M8W)I<'1I;VX@:6YF;W)M871I;VX@8V%N(&)E(&9O=6YD(&%T"@H@(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VUA:6PO"@I,87-T;'DL($AO<F1E(&1E=F5L;W!E
M<G,L(&-O;G1R:6)U=&]R<R!A;F0@=7-E<G,@86QS;R!M86ME(&]C8V%S:6]N
M86P*87!P96%R86YC97,@;VX@25)#+"!O;B!T:&4@8VAA;FYE;"`C:&]R9&4@
M;VX@=&AE(&9R965N;V1E($YE='=O<FL**&ER8RYF<F5E;F]D92YN970I+@H*
M"DQI8V5N<VEN9PHM+2TM+2TM+2T*"D9O<B!L:6-E;G-I;F<@86YD(&-O<'ER
M:6=H="!I;F9O<FUA=&EO;BP@<&QE87-E('-E92!T:&4@9FEL92!#3U!924Y'
M7R!I;B!T:&4*2W)O;F]L:71H(&1I<W1R:6)U=&EO;BX*"E1H86YK<RP*"E1H
M92!+<F]N;VQI=&@@5&5A;0H*"BXN(%]214%$344Z(#]F/5)%041-12YH=&UL
M"BXN(%]#3U!924Y'.B!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]G
M<&PN<&AP"BXN(%]D;V-S+T-(04Y'15,Z(#]F/4-(04Y'15,N:'1M;`HN+B!?
M9&]C<R]#4D5$2513.B`_9CU#4D5$2513+FAT;6P*+BX@7TE.4U1!3$PZ"BXN
M(%]D;V-S+TE.4U1!3$PZ(#]F/4E.4U1!3$PN:'1M;`HN+B!?9&]C<R]43T1/
M.B`_9CU43T1/+FAT;6P*+BX@7V1O8W,O55!'4D%$24Y'.B`_9CU54$=2041)
M3D<N:'1M;`H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O9&]C
M<R]#2$%.1T53````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#4W,3(P`#$P-#$W,S8R-S4S`#`R,#,V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+2TM"G8R+C$*+2TM+0H*6V-J:%T@
M5&AE<F4@87)E(&YO=R!S979E<F%L(&=U87)D<R!A9V%I;G-T('5S97)S(&)E
M:6YG('-T=6-K('=I=&@@;F\@<V5L96-T960*("`@("`@8V%L96YD87)S(&%N
M9"!N;R!W87D@=&\@<V5L96-T(&]N92`H0G5G(",S-3,X*2X*"@HM+2TM+2TM
M+0IV,BXQ+5)#,PHM+2TM+2TM+0H*6VIA;ET@1FEX(')E=')I979I;F<@;V8@
M9G)E92]B=7-Y(%523',@9G)O;2!+;VQA8B!S97)V97)S("AT;VMO94!K9&4N
M;W)G+`H@("`@("!"=6<@(S,T-3`I+@I;:F%N72!&:7@@<F5C=7)R:6YG(&5V
M96YT<R!W:71H;W5T(&5N9"!D871E<R!U<VEN9R!T:&4@2V]L86(@9')I=F5R
M"B`@("`@("AT;VMO94!K9&4N;W)G+"!"=6<@(S(W,S0I+@I;:F%N72!!;&QO
M=R!T;R!S<&5C:69Y('!O<G0@86YD('!R;W1O8V]L(&]F($MO;&%B('-E<G9E
M<B!F;W(@9G)E92]B=7-Y(')E<75E<W0*("`@("`@*&%S96EG;T!K9&4N;W)G
M+"!T;VMO94!K9&4N;W)G+"!297%U97-T(",R,3<X*2X*6VIA;ET@26UP<F]V
M92!A='1E;F1E97,@86YD(&-O;G1A8W1S(&9O<FUS+@H*"BTM+2TM+2TM"G8R
M+C$M4D,R"BTM+2TM+2TM"@I;:F%N72!3:&]W('-U8G-C<FEP=&EO;B!54DP@
M9F]R(&-A;&5N9&%R<R!I;B`B37D@0V%L96YD87)S(B!O=F5R=FEE=PH@("`@
M("`H:V5V:6Y?;7EE<D!I=3$S+F]R9RP@4F5Q=65S="`C,S(U-BDN"EMJ86Y=
M($9I>"!B<F]W<V5R(')E9&ER96-T:6]N(&%F=&5R('-A=FEN9R!E=F5N=',N
M"@H*+2TM+2TM+2T*=C(N,2U20S$*+2TM+2TM+2T*"EMC:FA=(%1H92!C86QE
M;F1A<BAS*2!T;R!E>'!O<G0@9&%T82!F<F]M(&%R92!N;W<@8V]N9FEG=7)A
M8FQE("A297%U97-T(",R,S,P*2X*6VIA;ET@061D(%!O<G1U9W5E<V4@=')A
M;G-L871I;VX@*$UA;G5E;"!-96YE>F5S(&1E(%-E<75E:7)A"B`@("`@(#Q-
M86YU96PN4V5Q=65I<F$^*2X*6V-J:%T@57-E($A45%!?4F5Q=65S="!T;R!R
M971R:65V92!&<F5E+T)U<WD@:6YF;W)M871I;VX@<V\@=V4@9&]N)W0*("`@
M("`@<F5L>2!O;B!A;&QO=U]U<FQ?9F]P96XN"EMC:FA=(%)E;6]V92!D:7-A
M8FQE9"!01$(@:6UP;W)T(&-O9&4N"EMC:FA=($9I>"!D:7-P;&%Y('=H96X@
M;VYL>2!R96UO=&4@8V%L96YD87)S(&%R92!A8W1I=F4@*$)U9R`C,C<W-RDN
M"EMC:FA=($9I>"!A;&%R;7,@9F]R(')E8W5R<FEN9R!E=F5N=',N"EMB96Y=
M($%D9"!24U90('1O(&E4:7`@<V\@3W5T;&]O:R!W:6QL('-E;F0@82!R97!L
M>2!M97-S86=E('=H96X@=&AE"B`@("`@(&EN=FET871I;VX@:7,@86-C97!T
M960O9&5C;&EN960O971C+@I;:F%N72!!;&QO=R!A=71O;6%T:6,@<VAA<FEN
M9R!O9B!N97<@8V%L96YD87)S('=I=&@@=7-E<G,G(&=R;W5P<PH@("`@("`H
M9V%U<F5T0&9R964N9G(L(%)E<75E<W0@(S$S-C8I+@I;:F%N72!!9&0@<')E
M9F5R96YC92!T;R!O;FQY(')E=')I979E(&5V96YT(')E;6EN9&5R<R!F;W(@
M8V5R=&%I;B!C86QE;F1A<G,*("`@("`@*&ME=FEN7VUY97)`:74Q,RYO<F<L
M(%)E<75E<W0@(S8T.2DN"EMJ86Y=($%L=V%Y<R!R971U<FX@=&\@;&%S="!S
M8W)E96X@869T97(@961I=&EN9R!O<B!D96QE=&EN9R!E=F5N=',N"EMJ86Y=
M($%L;&]W('1O(&9R965L>2!S970@979E;G0@>65A<G,N"EMJ86Y=($%D9"!E
M=F5N="!S=&%T=7,@;V8@(D9R964B+@I;:F%N72!!9&0@0TQ)('-C<FEP="!T
M;R!I;7!O<G0@:4-A;&5N9&%R+W9#86QE;F1A<B!D871A+@I;8VIH72!$97!R
M96-A=&4@=&AE($U#04P@9')I=F5R+@I;;6%S72!!;&QO=R!R97!L86-I;F<@
M82!C86QE;F1A<B!W:71H(&%N(&EM<&]R=&5D(&]N92X@*$)U9R`C,3,V-"D*
M6VUA<UT@0VAA;F=E(&%N>2!O=71P=70@;V8@/&(^(&%N9"`\:3X@=&%G<R!T
M;R`\<W1R;VYG/B!A;F0@/&5M/B!F;W(@8F5T=&5R"B`@("`@(&%C8V5S<VEB
M:6QI='D@<W5P<&]R="X*6V-J:%T@57-E($-34R!F;W(@86QL(&-A=&5G;W)Y
M(&-O;&]R<R!I;G-T96%D(&]F(&=E;F5R871I;F<@=&AE;2!I;FQI;F4N"EMC
M:FA=(%5S92!(;W)D95]496UP;&%T92!F;W(@9&%Y(&%N9"!W965K('9I97<@
M<F]W<RX*6V-J:%T@5&AE(&QE;F=T:"!O9B!T:6UE('-L;W1S(&EN('1H92!D
M87D@86YD('=E96L@=FEE=W,@:7,@;F]W(&-O;F9I9W5R86)L90H@("`@("`H
M0G5G(",Q.34R*2X*6V-J:%T@061D(&$@=')E92!B;&]C:R!F;W(@<VAO=VEN
M9R!C=7)R96YT(&%L87)M<RX*6VIA;ET@061D('!E<FUI<W-I;VYS('1O(')E
M<W1R:6-T(&YU;6)E<B!O9B!E=F5N=',N"EMC:FA=(%-H;W<@979E;G0@;W=N
M97)S(&EN('1O;VQT:7!S+@I;8VIH72!&:7@@87-S=6UP=&EO;G,@86)O=70@
M=7-E<G,@8F5I;F<@;&]G9V5D(&EN('=H96X@9F5T8VAI;F<@9G)E92]B=7-Y
M"B`@("`@(&EN9F]R;6%T:6]N("AT87-I;B`H870I(&9H;2`H9&]T*2!E9'4L
M($)U9R`C,3@U,"DN"EMJ86Y=($%D9"!C86QE;F1A<B!P;W!U<"!W:6YD;W<@
M=&\@<VED92UB>2US:61E('9I97<@=&\@<V5A<F-H(&9O<B!C86QE;F1A<G,*
M("`@("`@86YD('1O9V=L92!T:&5I<B!V:7-I8FEL:71Y+@I;:F%N72!!9&0@
M:6-O;B!T;R!C86QE;F1A<B!N86UE<R!T;R!R96UO=F4@8V%L96YD87)S(&9R
M;VT@<VED92UB>2US:61E('9I97<N"EMC:FA=(&9B+G!H<"!N;W<@86-C97!T
M<R`_=3T@87)G=6UE;G1S(&%S('=E;&P@87,@/V,]+"!F;W(@9&ES<&QA>6EN
M9R!A('5S97(G<PH@("`@("!C:&]S96X@9G)E92]B=7-Y(&-A;&5N9&%R<RP@
M86QL;W=I;F<@=7-E<G,@8V]N=')O;"!O9B!W:&EC:"!C86QE;F1A<G,*("`@
M("`@8FQO8VL@;W5T(&9R964O8G5S>2!T:6UE('=I=&AO=70@8VAA;F=I;F<@
M=&AE(&9R964O8G5S>2!54DP*("`@("`@*&ME=FEN7VUY97)`:74Q,RYO<F<L
M($)U9R`C,38X,RDN"EMC:FA=($%D9"!E>&ES=',H*2!M971H;V0@=&\@8V%L
M96YD87(@9')I=F5R<R!F;W(@8VAE8VMI;F<@:68@979E;G1S(&5X:7-T(&)Y
M"B`@("`@(%5)1"`H4F]E;"!';&]U9&5M86YS(#QR;V5L0&=L;W5D96UA;G,N
M:6YF;SXI+@I;:F%N72!396YD(&QI;FMS(&EN(&E4:7`@<F5Q=65S=',@=&\@
M;&5T('5S97)S('%U:6-K;'D@<F5P;'D@=&\@86X@:6YV:71A=&EO;BX*6V-J
M:%T@061D(&EC<RYP:'`@*&%L<V\@;6ER<F]R960@8GD@86X@97AP;W)T0V%L
M96YD87(H*2!!4$D@;65T:&]D*2P@=VAI8V@@8V%N"B`@("`@(&)E('5S960@
M9F]R(&EN=&5G<F%T:6]N('=I=&@@4W5N8FER9"P@:4-A;"P@970N(&%L+B`H
M<W)R869A0'5S8RYE<RP*("`@("`@0G5G(",Y,3<I+@I;:F%N72!!9&0@<')E
M9F5R96YC92!T;R!S96YD(&5M86EL(&YO=&EF:6-A=&EO;G,@=&\@=7-E<G,@
M=VAE;B!E=F5N=',@:&%V90H@("`@("!B965N(&%D9&5D+"!E9&ET960L(&]R
M(&1E;&5T960@:6X@=&AE:7(@8V%L96YD87)S+@I;8VIH72!!9&0@82!996%R
M('9I97<@*&UB>61A;&5K0&UO8FEL96UI;FDN8V]M*2`H0G5G(",Q,C,X*2X*
M6VIA;ET@57-E($]05$=23U50<R!I;B!C86QE;F1A<B!D<F]P(&1O=VX@;&ES
M="X*"@HM+2TM+2T*=C(N,"XV"BTM+2TM+0H*6V-J:%T@0VQO<V4@<V5V97)A
M;"!84U,@<')O8FQE;7,@=VET:"!C86QE;F1A<B!A;F0@979E;G0@9FEE;&1S
M+@H*"BTM+2TM+0IV,BXP+C4*+2TM+2TM"@I;:F%N72!&:7@@=V%R;FEN9W,@
M=VET:"!);G1E<FYE="!%>'!L;W)E<B!O;B!(5%104R!C;VYN96-T:6]N<RX*
M6VIA;ET@1FEX(')E;6EN9&5R(&5M86EL<RX*"@HM+2TM+2T*=C(N,"XT"BTM
M+2TM+0H*6VIA;ET@06QL;W<@=&\@:6UP;W)T(&UO<F4@=&AA;B!O;F4@979E
M;G0@9G)O;2!I0V%L96YD87(@9&%T82!A="!O;F-E+@I;8VIH72!!=F]I9"!L
M;V]P<R!A;F0@;W1H97(@97)R;W)S(&)Y(&EM;65D:6%T96QY(&9A:6QI;F<@
M;F5X=%)E8W5R<F5N8V4H*0H@("`@("!C:&5C:VEN9R!F;W(@86YY(&5V96YT
M('=I=&@@82!R96-U<DEN=&5R=F%L(&]F(#`@*$)U9R`C,C<P.2DN"@H*+2TM
M+2TM+2TM+0IV,BXP+C0M4D,Q"BTM+2TM+2TM+2T*"EMJ86Y=($9I>"!N879I
M9V%T:6]N('!O<'5P('=I=&@@4V%F87)I(&)R;W=S97)S("AT+GIE;&Q`9VUX
M+F1E+"!"=6<@(S(T-#<I+@I;8VIH72!&:7@@:6YF:6YI=&4@;&]O<"!W:71H
M('-O;64@<F5C=7)R:6YG(&5V96YT<R`H0G5G(",R,S0V*2X*6V-J:%T@1FEX
M($%L;"!087-T(&%N9"!!;&P@1G5T=7)E('-E87)C:&5S("A"=6<@(S(R-3<I
M+@I;8VIH72!"92!S;6%R=&5R(&%B;W5T(&5N9F]R8VEN9R`B96YD(&)E9F]R
M92!B96=I;FYI;F<B(&-H96-K(&9O<@H@("`@("!A;2]P;2!U<V5R<R!W:&5N
M(&-R96%T:6YG(&%N(&5V96YT('1H86X@<W!A;G,@;F]O;B`H0G5G(",Q-S,Q
M*2X*6VIA;ET@4V]R="!S96%R8V@@<F5S=6QT<R!B>2!S=&%R="!D871E(&%N
M9"!S:&]W(&-A=&5G;W)Y(&-O;&]R<RX*6V-J:%T@4F5S<&5C="!T=V5N='E?
M9F]U<B!P<F5F97)E;F-E(&EN(')E;6EN9&5R<R!S8W)I<'0@*$)U9R`C,3@Y
M-BDN"@H*+2TM+2TM"G8R+C`N,PHM+2TM+2T*"EMJ86Y=(%)E<W!E8W0@4TU4
M4"!A=71H96YT:6-A=&EO;B!S971T:6YG<R!W:&5N('-E;F1I;F<@<F5M:6YD
M97)S(&%N9`H@("`@("!N;W1I9FEC871I;VYS("AR97%U:7)E<R!(;W)D92`S
M+C`N-"DN"EMJ86Y=($EN8VQU9&4@9&%T92!I;B!R96UI;F1E<B!M97-S86=E
M("A"=6<@(S$X-34I+@I;:F%N72!&:7@@=&EM92!G<FED<R!I;B!F<F5E+V)U
M<WD@=FEE=R`H0G5G<R`C,34U-RP@(S$X-C@L('1A<VEN0&9H;2YE9'4I+@H*
M"BTM+2TM+2TM+2T*=C(N,"XS+5)#,0HM+2TM+2TM+2TM"@I;:F%N72!&:7@@
M8G)O=W-I;F<@=&AR;W5G:"!W;W)K('=E96MS(&EN(&%T=&5N9&5E<R!V:65W
M("A"=6<@(S$X-3(L"B`@("`@('1A<VEN0&9H;2YE9'4I+@I;:F%N72!&:7@@
M=7!D871I;F<@;V8@871T96YD964@<W1A='5S(&EN(&%T=&5N9&5E<R!V:65W
M("A"=6<@(S$Q.#@I+@I;:F%N72!$;VXG="!S:&]W('1A<VMS('=I=&AO=70@
M9'5E(&1A=&5S(&EN(&%L;"!T:6UE>F]N97,@*$)U9R`C-3$T*2X*6VIA;ET@
M26YC;'5D92!A='1E;F1E97,@:6X@:51I<"!E=F5N="!I;G9I=&%T:6]N<R`H
M0G5G(",Q-C<V*2X*6VIA;ET@1FEX(&=E;F5R871E9"!(5$U,(&EF(&YO(&-A
M;&5N9&%R(&AA<R!B965N('-E;&5C=&5D+@I;8VIH72!!9&0@82!0;W-T9W)E
M4U%,('5P9W)A9&4@<V-R:7!T("A"=6<@(S$W-S@I+@I;8VIH72!3:&]W('1H
M92!C86QE;F1A<B!S96QE8W1I;VX@9')O<&1O=VX@:68@=&AE<F4@87)E(')E
M;6]T92!C86QE;F1A<G,*("`@("`@<F5G87)D;&5S<R!O9B!N=6UB97(@;V8@
M<VAA<F5S("A"=6<@(S$V-#`I+@I;8VIH72!397!A<F%T92!B=71T;VYS(&]N
M(&%T=&5N9&5E<R!S8W)E96X@*&ME=FEN7VUY97)`:74Q,RYO<F<L($)U9R`C
M,38S-2DN"EMC:FA=(%5S92!B:6YD('9A<FEA8FQE<R!I;B!T:&4@4U%,(&1R
M:79E<G,@*'-E;'-K>4!C;VQU;6)I82YE9'4L($)U9W,@(S$V-CDL"B`@("`@
M(",Q-C<P*2X*6VIA;ET@4V5N9"!R96UI;F1E<G,@:6X@=7-E<G,G(&QA;F=U
M86=E<R`H0G5G(",Q-C4T*2X*6V-J:%T@1&]N)W0@;&5A=F4@979E;G1S(&EN
M('1H92!D871A8F%S92!W:71H(&YO(')E8W5R<F5N8V5S(&QE9G0@*$)U9R`C
M,34P,RDN"EMC:FA=($UA:V4@<W5R92!T:&%T(')E;6]T92!E=F5N=',@8V%N
M(&)E(&5D:71E9"!F;W(@<V%V:6YG(&%S(&YE=RP@86YD(&YE=F5R"B`@("`@
M('-H;W<@82!D96QE=&4@8G5T=&]N(&9O<B!T:&5M("A"=6<@(S$V,SDI+@I;
M8VIH72!!;'=A>7,@=7-E(&5V96YT240L(&YO="!E=F5N=$EN9&5X+B!&:7AE
M<R!P<F]B;&5M<R!W:71H(&]N;'D@;VYE(')E;6]T90H@("`@("!E=F5N="!S
M:&]W:6YG('5P('!E<B!D87D@*$)U9R`C,38S,"DN"EMJ86Y=($9I>"!F<F5E
M+V)U<WD@9V5N97)A=&EO;B!O;B!B<F]K96X@4$A0($-'22!305!)<R`H0G5G
M(",Q-3DY*2X*6V-J:%T@4V5T(')E8W5R<F5N8V4@96YD(&1A=&4@:68@<')E
M<V5N="!I;B!I0V%L(&1A=&$@*$)U9R`C,3,V-2P@(S$U.#(I+@I;8VIH72!!
M;&%R;7,@=&AA="!A<F4@82!C86QE;F1A<B!D87D@;W(@;6]R92!I;B!T:&4@
M9G5T=7)E(&%R92!N;W<@<V5N="!O;@H@("`@("!T:6UE("A"=6<@(S$S-38I
M"EMJ86Y=($-A=&-H(&5R<F]R<R!I9B!I;7!O<G1I;F<@:6YC;VUP;&5T92!E
M=F5N=',@*$)U9R`C,30R.2DN"EMC:FA=($9I>"!D:7-P;&%Y(&5R<F]R<R!W
M:71H(&]V97)L87!P:6YG(')E<&5A=&EN9R!E=F5N=',@86YD(%!(4#0*("`@
M("`@*$)U9R`C,3(P,"DN"EMB96Y=($%L;&]W('-E='1I;F<@=&AE(&1E9F%U
M;'0@9&]M86EN(&]N(&%T=&5N9&5E(&5M86EL(&%D9')E<W-E<R!W:&5N"B`@
M("`@(&-H96-K:6YG(&9O<B!F<F5E8G5S>2!U<FQS+@I;8VIH72!4<F5A="!W
M96)C86PZ+R\@55),<R!A<R!H='1P.B\O(&9O<B!R96UO=&4@8V%L96YD87)S
M("A"=6<@(S$T.#`I+@I;8VIH72!&:7@@<')O8FQE;7,@=VET:"!0;W-T9W)E
M4U%,(&%N9"!N;VXM25-/(&1A=&4@9F]R;6%T<R`H0G5G(",Q-#@R*2X*6VIA
M;ET@5V]R:V%R;W5N9"!)12!W87)N:6YG('=H96X@96YT97)I;F<@2W)O;F]L
M:71H(&]V97(@2%144%,@*$)U9R`C.3$P*2X*6VIA;ET@061D('-H;W)T8W5T
M(&EC;VX@*&9A=FEC;VXN:6-O*2X*6VIA;ET@4V]R="!W:&]L92!D87D@979E
M;G1S(&%L<&AA8F5T:6-A;&QY("A"=6<@(S(R,BDN"@H*+2TM+2TM"G8R+C`N
M,@HM+2TM+2T*"EMJ86Y=($9I>"!P;W)T86P@8FQO8VL@9F]R(&UI<W-I;F<@
M979E;G1S(&%T('1H92!T=7)N(&]F('1H92!Y96%R("A"=6<@(S$S,S<I+@H*
M"BTM+2TM+2TM+2T*=C(N,"XR+5)#,0HM+2TM+2TM+2TM"@I;:F%N72!&:7@@
M9G)E92]B=7-Y('9I97=S('=I=&@@<V]M92!L86YG=6%G97,@*$)U9R`C,3`S
M-BDN"EMC:FA=(%!R979E;G0@:6YF:6YI=&4@;&]O<',@:68@979E;G1S(&%R
M92!S970@=&\@<F5C=7(@=V5E:VQY(&]N(&YO"B`@("`@('=E96MD87ES("A"
M=6<@(S$P-S0I+@I;8VIH72!3970@:4-A;&5N9&%R(&5V96YT<R!W:71H('=E
M96ML>2!R96-U<G)E;F-E('1O(')E8W5R(&]N('1H92!D87D*("`@("`@;V8@
M=&AE('=E96L@;V8@=&AE(&9I<G-T(')E8W5R<F5N8V4@:68@;F\@0EE$05D@
M9&%T82!I<R!P<F5S96YT"B`@("`@("A"=6<@(S$P-S0I+@I;8VIH72!-86ME
M('-U<F4@=&AA="!E=F5N="!5241S(&%R92!P<F]P97)L>2!S970@:6X@:51I
M<"!N;W1I9FEC871I;VYS"B`@("`@("A"=6<@(S$Q-3,I+@I;:F%N72!!9&0@
M2F%P86YE<V4@=')A;G-L871I;VX@*$AI<F]M:2!+:6UU<F$@/&AI<F]M:4!T
M86,N='-U:W5B82YA8RYJ<#XI+@I;8VIH72!#:&5C:R!T:&4@8V]M<&QE=&EO
M;B!S=&%T=7,@;V8@=&%S:W,L(&YO="!J=7-T('1H96ER(&1U92!D871E+`H@
M("`@("!B969O<F4@<VAO=VEN9R!T:&5M(&]N('1H92!C86QE;F1A<B`H0G5G
M(",Y-#<I+@H*"BTM+2TM+0IV,BXP+C$*+2TM+2TM"@I;8VIH72!&:7@@;VYE
M('!A9V4@;&]A9"!D96QA>2!I;B!S:&]W:6YG(&YE=R]R96UO=FEN9R!D96QE
M=&5D('-H87)E<PH@("`@("!O;B!T:&4@37D@0V%L96YD87)S('-C<F5E;B`H
M0G5G(",Q,#0X*2X*6V-J:%T@1FEX(&QA8F5L:6YG(&]F('=E96MD87D@8V]L
M=6UN<R!I;B!T:&4@36]N=&@@=FEE=R!W:&5N('1H90H@("`@("!W965K('-T
M87)T<R!O;B!-;VYD87D@86YD('-H;W=?<VAA<F5D7W-I9&5?8GE?<VED92!P
M<F5F97)E;F-E"B`@("`@(&ES(&]N("A"=6<@(S$P-#DI+@I;8VIH72!&:7@@
M9F%T86P@97)R;W(@=VAE;B!I;B!C86QE;F1A<B]I;7!O<G0@05!)(&-A;&P*
M("`@("`@*%-E8F%S=&GA;B!#86QE<F\@/'-C86QE<F]`9&%T861E8RYE<SXI
M+@I;8VIH72!&:7@@82!W965K(&)O=6YD87)Y('!R;V)L96T@=&AA="!T;V]K
M('EO=2!T;R!T:&4@<')E=FEO=7,*("`@("`@=V5E:R!W:&5N('-W:71C:&EN
M9R!B971W965N('1H92!W965K(&%N9"!W;W)K('=E96L@=FEE=W,N"EMC:FA=
M($9I>"!S979E<F%L(&5R<F]R<R!I;B!C86QC=6QA=&EN9R!T:&4@=V5E:R!N
M=6UB97(@870@=&AE"B`@("`@(')O;&QO=F5R(&)E='=E96X@>65A<G,N"EMC
M:FA=($9I>"!A;B!O9F8M8GDM;VYE(&5R<F]R(&EN('1H92!W;W)K('=E96L@
M=FEE=R!W:&5N('1H92!U<V5R"B`@("`@('9I97=S('=E96MS('-T87)T<R!O
M;B!3=6YD87D@*$)U9R`C,3`T-BDN"EMC:FA=($%D9"!0;W-T9W)E4U%,('9E
M<G-I;VX@;V8@,C`P-"TQ,BTR,5]A9&1?979E;G1?=6ED("A"=6<@(S$P,C@I
M+@I;8VIH72!&:7@@='EP;R!T:&%T('!R979E;G1E9"!A='1E;F1E97,@9G)O
M;2!B96EN9R!S879E9"`H0G5G(",Q,#$Y*2X*"@HM+2TM"G8R+C`*+2TM+0H*
M6V-J:%T@54E$<R!N965D('1O(&)E('-T;W)E9"!I;B!T:&4@2&ES=&]R>2!S
M>7-T96T@=VET:"!A(&MR;VYO;&ET:#H*("`@("`@<')E9FEX(&%N9"!W:71H
M('1H92!C86QE;F1A<B!S;R!A<R!N;W0@=&\@8V]N9G5S92!D:69F97)E;G0*
M("`@("`@:6YS=&%N8V5S(&]F('1H92!S86UE(&5V96YT("AI9B!T=V\@=7-E
M<G,@8F]T:"!H879E(&$@979E;G0@;VX*("`@("`@=&AE:7(@<V5P97)A=&4@
M8V%L96YD87)S+"!T:&5Y('-H;W5L9"!H879E('5N:7%U92!H:7-T;W)I97,@
M9F]R"B`@("`@('1H870@979E;G0I+@I;8VIH72!4:&4@37D@0V%L96YD87)S
M('!A9V4@;F]W(&AA<R!A('1O;VP@9F]R(&=E;F5R871I;F<@1G)E92]"=7-Y
M(%523',*("`@("`@*$)U9R`C-3<Q*2X*6V-J:%T@4&%S<R!(;W)D95]$871E
M(&]B:F5C=',@:6YS=&5A9"!O9B!T:6UE<W1A;7!S('=H96X@97AP;W)T:6YG
M('1O"B`@("`@(&E#86QE;F1A<B`H0G5G(",Y-3`I+@I;8VIH72!#;&]N92!E
M=F5N=',@8F5F;W)E(&-H86YG:6YG('1H96ER('-T87)T(&1A=&5S('1O('1H
M92!C=7)R96YT(&1A>0H@("`@("!I;B!T:&4@9&%Y('9I97<@<V\@=&AA="!T
M:&4@=V5E:R!V:65W(&ES;B=T('=R;VYG+@I;8VIH72!&:7@@86X@;V9F+6)Y
M+6]N92!E<G)O<B!I;B!T:&4@=V5E:R!V:65W('=H96X@=&AE('5S97(@=FEE
M=W,@=V5E:W,*("`@("`@<W1A<G1I;F<@;VX@4W5N9&%Y+@I;8VIH72!!9&0@
M82!P<F5F97)E;F-E(&9O<B!W:&5T:&5R(&]R(&YO="!T;R!S:&]W('1H92!B
M86-K9W)O=6YD(&-O;&]R"B`@("`@(&9O<B!T87-K<R!S:&]W;B!O;B!T:&4@
M8V%L96YD87(N"EMC:FA=($1O;B=T('!R;V1U8V4@:6YV86QI9"!E>&-E<'1I
M;VX@9&%T97,@=VAE;B!E>'!O<G1I;F<@:4-A;"!F:6QE<R!O<@H@("`@("!W
M:&5N(&QO861I;F<@4U%,(&5V96YT<RX*6V-J:%T@57-E<G,@8V%N(&YO=R!G
M970@=&\@=&AE(&-A=&5G;W)Y+V-O;&]R(&5D:70@<V-R965N(&1I<F5C=&QY
M"B`@("`@(&9R;VT@=&AE(&-A=&5G;W)Y(&QE9V5N9"P@:6YS=&5A9"!O9B!H
M879I;F<@=&\@9FEN9"!T:&5M(&EN"B`@("`@($AO<F1E)W,@<')E9G,N"@H*
M+2TM+2TM+2T*=C(N,"U20S,*+2TM+2TM+2T*"EMC:FA=($%D9"!!;&P@4&%S
M="!A<R!A;B!O<'1I;VX@;VX@<VEM<&QE('-E87)C:&5S+@I;8VIH72!!9&0@
M37D@0V%L96YD87)S(&UE;G4@96YT<GDN"EMC:FA=($5V96YT(&5X8V5P=&EO
M;G,@87)E(&YO=R!C;W)R96-T;'D@97AP;W)T960@:6X@:4-A;&5N9&%R(&9I
M;&5S+@I;8VIH72!&:7@@<F5C=7)R:6YG(&5V96YT<R!T:&%T(')E8W5R(&]N
M('1H92!S86UE(&1A>2!O9B!T:&4@;6]N=&@@979E<GD@;@H@("`@("!M;VYT
M:',@=VAE<F4@;B`^(#$@*$)U9R`C.3`W*2X*6V-J:%T@1FEX(&UO;G1H('9I
M97<@9F]R(&UO;G1H<R!S=&%R=&EN9R!O;B!3=6YD87D@=VET:"!T:&4@9FER
M<W0@9&ES<&QA>65D"B`@("`@(&1A>2!S970@=&\@36]N9&%Y("A"=6<@(SDP
M-RDN"EMC:FA=(%-H;W<@979E;G0@<W1A=&4@8GD@0U-3('-T>6QI;F<@*$1E
M<F5K(%`N($UO;W)E(#QD97)E:VU`:&%C:W5N:7@N;W)G/BDN"EMJ86Y=($-O
M<G)E8W1L>2!H:6=H;&EG:'0@=&AE(&-U<G)E;G0@=FEE=R=S('1A8B`H0G5G
M(",X.38I+@H*"BTM+2TM+2TM"G8R+C`M4D,R"BTM+2TM+2TM"@I;:F%N72!&
M:7@@<F5C=7)R:6YG(&5V96YT<R!F<F]M(')E;6]T92!C86QE;F1A<G,@*$)U
M9R`C-34Y*2X*6V-J:%T@5&AE(&UE;G5B87(@1V]T;R!P;W!U<"!I<R!N;W<@
M86QW87ES(&]N('1O<"!O9B`\<V5L96-T/B!B;WAE<RP*("`@("`@979E;B!I
M;B!);G1E<FYE="!%>'!L;W)E<B`H0G5G(",X,C(I+@I;8VIH72!-96YU8F%R
M($=O=&\@;&EN:R!W;W)K<R!O;B!T:&4@3W!T:6]N<R!S8W)E96X@86=A:6XN
M"@H*+2TM+2TM+2T*=C(N,"U20S$*+2TM+2TM+2T*"EMC:FA=($9I>"!T:&4@
M;65N=6)A<B!P;W!U<"!D871E(&YA=FEG871O<B!O;B!T:&4@3F5W($5V96YT
M('-C<F5E;BX*6V-J:%T@4F5M;W9E('5N=7-E9"!S<&5C:6%L:7IE9"!N;W1I
M9FEC871I;VX@;&ES=&5N97(N"EMC:FA=(%5P9&%T92!I8V]N<RX*6VIA;ET@
M1FEX(&EM<&]R=&EN9R!O9B!N;VXM<F5C=7)R:6YG(&5V96YT<RX*6VIA;ET@
M4V%V92!C871E9V]R:65S(&]F(&EM<&]R=&5D(&5V96YT<RX*6V-J:%T@4VAO
M=R!D:69F97)E;G0@8V%L96YD87(@=FEE=W,@:6X@=&%B<RP@;F]T(&EN('1H
M92!M96YU+@I;8VIH72!3:&]W(&9R964O8G5S>2!V:65W(&]N;'D@:6X@=&AE
M(&5V96YT('-C<F5E;BX*"@HM+2TM+2TM+2T*=C(N,"U"151!"BTM+2TM+2TM
M+0H*6V-J:%T@5&AE(&=U=',@;V8@2W)O;F]L:71H7T5V96YT(&]B:F5C=',@
M87)E(&YO=R!B87-E9"!O;B!(;W)D95]$871E"B`@("`@(&]B:F5C=',@:6YS
M=&5A9"!O9B!T:6UE<W1A;7!S+@I;8VIH72!,;W1S(&]F(&1A=&4M<F5L871E
M9"!F=6YC=&EO;G,@;6]V960@=&\@=&AE($AO<F1E7T1A=&4@8VQA<W,N"EMJ
M86Y=($%D9"!P<F5F97)E;F-E(&9O<B!A9&1R97-S(&)O;VMS('1O('-E87)C
M:"!F;W(@9G)E92]B=7-Y('5R;',N"EMJ86Y=($%D9"!S<&5C:6%L(&)L86-K
M+6]N+7=H:71E('-T>6QE<R!F;W(@;65S<V%G92!P<FEN=&EN9RX*6V-J:%T@
M061D('1I=&QE(&9I96QD('1O('1H92!B87-I8R!S96%R8V@N"EMC:FA=($%L
M;&]W('-E87)C:&5S(&9O<B`B06QL($9U='5R92(@979E;G1S+@I;8VIH72!!
M9&0@<V5A<F-H(&9U;F-T:6]N86QI='D@*$UE:6QO9B`\;65I;&]F0'=A;F%D
M;V\N;FP^*2X*6VIA;ET@061D(&%C8V5S<R!K97ES+@I;8VIH72!!9&0@2V]L
M86(@9')I=F5R<R`H4W1U87)T($)I;F?K(#QS+F)I;F=E0&-O9&5F=7-I;VXN
M8V\N>F$^*2X*"@HM+2TM+2TM+2TM"G8R+C`M04Q02$$*+2TM+2TM+2TM+0H*
M6V-J:%T@4F5M;W1E(&-A;&5N9&%R<R!A<F4@;F]W('!A<G-E9"!W:71H('1H
M92!(;W)D95]I0V%L96YD87(@;&EB<F%R>2P*("`@("`@=VAI8V@@86QL;W=S
M(&9O<B!M=6-H(&)E='1E<B!I0V%L96YD87(@<W5P<&]R="P@8F5T=&5R(&AA
M;F1L:6YG(&]F"B`@("`@('1I;65Z;VYE<RP@971C+@I;8VIH72!4:&4@;6]N
M=&@@=FEE=R!N;R!L;VYG97(@<VAO=W,@8FQA;FL@8F]X97,@9F]R(&1A>7,@
M:6X@=&AE(&=R:60@=&AA="!A<F4*("`@("`@;W5T<VED92!O9B!T:&4@8W5R
M<F5N="!M;VYT:"`M(&EN<W1E860L(&ET(&=O97,@8F%C:R!I;G1O('1H92!P
M<F5V:6]U<PH@("`@("!M;VYT:"!A;F0@9F]R=V%R9"!I;G1O('1H92!N97AT
M(&UO;G1H(&AO=V5V97(@;6%N>2!D87ES(&%R92!S:&]W86)L92X*6V-J:%T@
M2W)O;F]L:71H(&YO=R!I;F-L=61E<R!T:&4@9G5N8W1I;VYA;&ET>2P@<')E
M=FEO=7-L>2!I;B!-;VUE;G0L"B`@("`@('1O('1R86-K(&%T=&5N9&5E<R!F
M;W(@979E;G1S+"!S96YD(&EN=FET871I;VYS+"!U<&1A=&5S+"!A;F0*("`@
M("`@8V%N8V5L;&%T:6]N<RP@86YD(&1O('-C:&5D=6QI;F<@8F%S960@;VX@
M9G)E96)U<WD@:6YF;W)M871I;VX*("`@("`@*%-T=6%R="!":6YG92`\<RYB
M:6YG94!C;V1E9G5S:6]N+F-O+GIA/BDN"EMC:FA=($MR;VYO;&ET:%]$<FEV
M97(Z.FUO=F4H*2!A9&1E9"!T;R!P<F5V96YT(&5V96YT($E$<R!C:&%N9VEN
M9R!W:&5N(&UO=FEN9PH@("`@("!B971W965N(&-A;&5N9&%R<RP@:68@<&]S
M<VEB;&4N"EMC:FA=($=5241S(&YO=R!O;FQY(&-O;G1A:6X@:W)O;F]L:71H
M.B!A;F0@=&AE(&5V96YT($E$("T@<VAA<F5N86UE(&ES(&YO=`H@("`@("!N
M965D960N"EMC:FA=($5V96YT($E$<R!A<F4@;F]W(#,R+6-H87)A8W1E<B!U
M;FEQ=64@<W1R:6YG<RP@=&\@8F4@=7-E86)L92!A<R!'54E$<RX*("`@("`@
M5&AE(%-13"!T86)L92!D969I;FET:6]N(&AA<R!C:&%N9V5D.R!C;VYV97)S
M:6]N('-C<FEP=',@87)E(&EN('-C<FEP=',O+@I;8VIH72!E=F5N=&0@;F]W
M('5S97,@=&AE($AO<F1E7U-C:&5D=6QE<B!!4$DG<R!A8FEL:71Y('1O('-E
M<FEA;&EZ92!A;F0*("`@("`@<V%V92!S=&%T93L@:70G<R!N;W<@;65A;G0@
M=&\@8F4@<G5N(&]U="!O9B!C<F]N(&5V97)Y(&UI;G5T92`H;F\*("`@("`@
M;6]R92!S;&]W(&UE;6]R>2!M=6YC:&EN9RDN"EMC:FA=(%-H;W<@<W1A<G0@
M86YD(&5N9"!T:6UE<R!I;B!E=F5N="!T;V]L=&EP<PH@("`@("`H4&%Y=&]N
M(#QP87ET;VY`<F5P;&EG96XN8V]M/BDN"EMC:FA=($9I>"!E=F5N=',@=&AA
M="!R96-U<B!E=F5R>2!N(&UO;G1H<R`H=VAE<F4@;B`A/2`Q*2!O;B!T:&4@
M<V%M90H@("`@("!W965K9&%Y('=H96X@=7-I;F<@=&AE(%-13"!D<FEV97(N
M"EMC:FA=(%1R86-K(&%D9&ET:6]N+"!M;V1I9FEC871I;VXL(&%N9"!D96QE
M=&EO;B!O9B!E=F5N=',*("`@("`@=VET:"!T:&4@2&]R9&4@2&ES=&]R>3HZ
M($%022X*6V-J:%T@5&AE(&5V96YT(&5D:71O<B!N;W<@<W=I=&-H97,@=&AE
M(&QI<W0@;V8@8V%T96=O<FEE<R!T;R!M871C:"!T:&4*("`@("`@8V%L96YD
M87(@=&AA="!Y;W4@87)E(&%D9&EN9R!T:&4@979E;G0@=&\N"EMC:FA=(%-H
M;W<@=&]O;'1I<',@=VET:"!E=F5N="!D97-C<FEP=&EO;G,N"EMC:FA=(%-H
M;W<@82!L96=E;F0@;6%P<&EN9R!C871E9V]R:65S('1O(&-O;&]R<PH@("`@
M("`H2F%S;VX@4G5S="`\:G)U<W1`<G5S='EP87)T<RYC;VT^*2X*6VUI<ET@
M;&ES=$5V96YT<R!N;W<@<W5P<&]R=',@86X@;W!T:6]N('1O($Y/5"!D;R!R
M96-U<G)E;F-E("AU<V5F=6P@9F]R"B`@("`@('-Y;F-H<F]N:7II;F<@=VET
M:"!O=&AE<B!S>7-T96US*2X*6V-J:%T@1FER<W0@<VAO="!A="!A(')E;6EN
M9&5R(&1A96UO;BP@=W)I='1E;B!I;B!02%`@86YD('5S:6YG('1H90H@("`@
M("!(;W)D95]38VAE9'5L97(@9G)A;65W;W)K+@I;8VIH72!#86-H92!F<F5E
M+V)U<WD@:6YF;W)M871I;VX@9F]R(&%N(&AO=7(N"EMC:FA=($%D9"!V:65W
M:6YG(&]F('-H87)E9"!C86QE;F1A<G,@<VED92UB>2US:61E(&EN('1H92!M
M;VYT:"!V:65W"B`@("`@("AJ+FAU:6YI;FM`=V%N861O;RYN;"DN"EMC:FA=
M($MR;VYO;&ET:"!N;W<@9V5N97)A=&5S(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B!F;W(@86YY(&-A;&5N9&%R('1H870@=&AE"B`@("`@('9I97=E<B!H87,@
M4$5235-?4TA/5R!P97)M:7-S:6]N('1O+B!4:&ES(&-A;B!B92!U<V5D(&EN
M+"!E+F<N+"!/=71L;V]K"B`@("`@(&9O<B!S8VAE9'5L:6YG(&UE971I;F=S
M+"!E=&,N"EMC:FA=(%-U<'!O<G0@9F]R(&=U97-T(&-A;&5N9&%R<RX*6V-J
M:%T@57-E('1H92!G;&]B86P@<VAA<F5S(&5D:71I;F<@<&%G92!F;W(@8VAA
M;F=I;F<O87-S:6=N:6YG('-H87)E"B`@("`@('!E<FUI<W-I;VYS+@I;;6%C
M72!!9&0@<W5P<&]R="!F;W(@<W5B<V-R:6)I;F<@=&\@<F5M;W1E(&E#86QE
M;F1A<B!F:6QE<RX*6V-J:%T@4F5M;W9E('1H92!3:&%R92!H96%D97(@9F]R
M(&YO=SL@=&%K97,@=7`@9F%R('1O;R!M=6-H('-P86-E"B`@("`@('1O(&-O
M;6UU;FEC871E(&QI;6ET960@:6YF;W)M871I;VXN"EMM86-=($%D9"!A8FEL
M:71Y('1O(&1I<W!L87D@;75L=&EP;&4@8V%L96YD87)S(&%T(&$@=&EM92X*
M6V-J:%T@4&%L;2!$871E0F]O:R`H4$1"*2!I;7!O<G0@<W5P<&]R="X*6VUA
M8UT@061D('-H87)E9"!C86QE;F1A<G,@<W5P<&]R="`H2F]E;"!686YD86P@
M/&IV86YD86Q`:6YF;W1E8VLN<6,N8V$^*2X*6V-J:%T@2W)O;F]L:71H(&-A
M;B!N;W<@<V5N9"!I0V%L96YD87(@:6YV:71A=&EO;G,@=&\@86X@979E;G0N
M"EMC:FA=($EM<&]R="]%>'!O<G0@;V8@:4-A;&5N9&%R(&1A=&$@=V]R:W,@
M9F]R(&)A<VEC(&%T=')I8G5T97,@;F]W+@I;8VIH72!5<V4@2&]R9&4Z.F-O
M;7!R97-S3W5T<'5T*"D@9F]R(&]U='!U="!C;VUP<F5S<VEO;BX*"@HM+2TM
M+2T*=C$N,2XT"BTM+2TM+0H*6VIA;ET@0VQO<V4@6%-3('=H96X@<V5T=&EN
M9R!T:&4@<&%R96YT(&9R86UE)W,@<&%G92!T:71L92!B>2!J879A<V-R:7!T
M("AC:F@I+@H*"BTM+2TM+0IV,2XQ+C,*+2TM+2TM"@I;:F%N72!&:7@@9&ES
M<&QA>2!O9B!C871E9V]R>2!C;VQO<G,@:6X@=V5E:R!A;F0@9&%Y('9I97=S
M("A":O9R;B!486-K;6%N;@H@("`@("`\8FIO97)N+G1A8VMM86YN0&-O;G-U
M;'1I8V\N9&4^*2X*6VIA;ET@061D($QA='9I86X@=')A;G-L871I;VX@*$EV
M87)S(%-T:79R:6YS(#QI=F%R<T!K<F%S;&%V82YL=CXI+@I;:F%N72!&:7@@
M97)R;VYE;W5S(&IA=F%S8W)I<'0@:6X@<F5C=7)R96YC92!I;G!U="!F:65L
M9',@;V8@=&AE(&5V96YT(&9O<FT*("`@("`@*$)U9W,@-#`S+"`T,#@I+@H*
M"BTM+2TM+0IV,2XQ+C(*+2TM+2TM"@I;8VIH72!&:7@@82!B=6<@:6X@=&AE
M(%-13"!D<FEV97(@<')E=F5N=&EN9R!E=F5N=',@9G)O;2!B96EN9R!D:7-P
M;&%Y960N"@H*+2TM+2TM"G8Q+C$N,0HM+2TM+2T*"EMJ86Y=($9I>"!S;VUE
M(&1I<W!L87D@8G5G<R!W:71H(')E8W5R<FEN9R!E=F5N=',@:6X@=&AE('-Q
M;"!D<FEV97(@*&-J:"DN"@H*+2TM+2TM+2TM+0IV,2XQ+C$M4D,Q"BTM+2TM
M+2TM+2T*"EMJ86Y=($9I>"!B<F]K96X@:6UA9V4@=&%G(&EN(&1A>2!A;F0@
M=V5E:R!V:65W<RX*6VIA;ET@1FEX(").97<@0V%T96=O<GDB('-E;&5C=&EO
M;B!I;B!E=F5N="!E9&ET('9I97<N"EMJ86Y=($%D9"!!<F%B:6,@*%-Y<FEA
M*2!T<F%N<VQA=&EO;B`H4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;0H@("`@
M("`\9&5V=&5A;4!P;&%T:6YU;2US>2YN970^*2X*"@HM+2TM"G8Q+C$*+2TM
M+0H*6V-J:%T@2W)O;F]L:71H7T5V96YT(&]B:F5C=',@;F]W(&MN;W<@:&]W
M('1O(&]B=&%I;B!T:&5I<B!D<FEV97(L"B`@("`@(')A=&AE<B!T:&%N('-T
M;W)I;F<@82!R969E<F5N8V4N($UA:V5S(&9O<B!M=6-H('-M86QL97(O8F5T
M=&5R"B`@("`@(')E='5R;B!V86QU97,@;W9E<B!834PM4E!#+"!A="!L96%S
M="X*6V-J:%T@1FEX(&$@8G5G(&EN('1H92!S<&%N;FEN9R!A;&=O<FET:&T@
M=VAE;B!T:&5R92!W97)E('1W;PH@("`@("!I;F1E<&5N9&%N="!S971S(&]F
M(&]V97)L87!P:6YG(&5V96YT<R!T:&%T('=E<F4@;F]T(&-O;6UO;@H@("`@
M("!F86-T;W)S("AI+F4L(&$@<V5T(&]F(#(@979E;G1S(&%N9"!A('-E="!O
M9B`S(&5V96YT<RDN($%L<V\*("`@("`@<W1A<G0@=&\@9&]C=6UE;G0@=&AE
M(')O=R!S<&%N;FEN9R!C;V1E+@I;;6ER72!);7!L96UE;G0@=V5E:R!O9B!M
M;VYT:"!R96-U<G)E;F-E(&9O<B!344P@9')I=F5R+@I;8VIH72!5<V4@2W)O
M;F]L:71H.CIL:7-T179E;G1S*"D@979E<GEW:&5R92P@<V\@=&AE<F4@:7,@
M;VYL>2!O;F4@8F]D>0H@("`@("!O9B!C;V1E('1O(&1E8G5G+V%D9"!T;R!F
M;W(@;&ES=&EN9R!O9B!E=F5N=',N"EMC:FA=(%-H;W<@3F%G('1A<VMS+"!I
M9B!R97%U97-T960L(&]N(&%L;"!V:65W<RX*6V-J:%T@57-E($MR;VYO;&ET
M:#HZ;&ES=$5V96YT<R@I(&EN('1H92!W965K('9I97=S.R!S:&]U;&0@8F4@
M;75C:`H@("`@("!M;W)E(&5F9FEC:65N="`H9F5W97(@4U%,('%U97)I97,O
M34-!3"!C86QL<RDN"EMC:FA=($9I>"!S=6UM87)Y(&1I<W!L87D@;V8@979E
M;G1S(&%F=&5R(&%N(&5M<'1Y(&1A>2X*6V-J:%T@1FEX(&QI;FMS('1O(&5V
M96YT<R!O;B!O=&AE<B!C86QE;F1A<G,@:6X@=&AE('-U;6UA<GDN"EMC:FA=
M(%-H;W<@8V%T96=O<GD@8V]L;W)S(&EN('1H92!+<F]N;VQI=&@@<W5M;6%R
M>2X*6V-J:%T@4VAO=R!C=7)R96YT(&-A=&5G;W)Y(&-O;&]R(&EN(&-A=&5G
M;W)Y(&-O;&]R(&]P=&EO;G,@<V-R965N"B`@("`@("A*86X@2W5I<&5R<R`\
M:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL/BDN"EMJ86Y=($%D9"!2;VUA
M;FEA;B!T<F%N<VQA=&EO;B`H175G96X@2&]A;F-A(#QE=6=E;FA`=7)B86XM
M9W)A9G@N<F\^+`H@("`@("!-87)I=7,@1')A9W5L97-C=2`\;6%R:75S9$!U
M<F)A;BUG<F%F>"YR;SXI+@I;:F%N72!!9&0@4')I;G0@8G5T=&]N(&9O<B!D
M87DL('=E96LL(&UO;G1H('9I97=S("AM86,I+@I;:F%N72!#;&5A;B!U<"!U
M<FP@8W)E871I;VX@86YD(%A(5$U,("AM86,I+@I;:F%N72!!9&0@3F]R=V5G
M:6%N($)O:VUA86P@=')A;G-L871I;VX@*%1O<G-T96EN(%,N($AA;G-E;B`\
M:'5L96)O97)`=&5C:&)E92YN;SXI+@I;:F%N72!!9&0@2W)O;F]L:71H.CIA
M9&1087)A;65T97(H*2X*6VIA;ET@061D($QI=&AU86YI86X@=')A;G-L871I
M;VX@*$1A<FEU<R!-871U;&EA=7-K87,@/&1A<FEU<T!L;FLN;'0^*2X*6VUA
M8UT@0VQE86X@=7`@=7)L(&-R96%T:6]N(&%N9"!82%1-3"X*6VIA;ET@061D
M(%-I;7!L:69I960@0VAI;F5S92!T<F%N<VQA=&EO;B`H6FAA;F<@0F\@/&)O
M;WIH86YG0'-D8BYA8RYC;CXI+@I;:F%N72!!9&0@0G5L9V%R:6%N('1R86YS
M;&%T:6]N("A-:7)O<VQA=B!096YD978@/&UI<F]`8WEB97)S:&%D92YU<SXI
M+@I;:F%N72!297!L86-E(#P_/2!W:71H(#P_<&AP(&5C:&\L(&%N9"!R96UO
M=F4@=&AE('-H;W)T7V]P96Y?=&%G<R!R97%U:7)E;65N="X*6VIA;ET@061D
M(&1E;&5T92!L:6YK('1O(&5V96YT('9I97<N"EMJ86Y=(%)E;6]V92!D97!R
M96-A=&5D($1".CII<U=A<FYI;F<H*2!C86QL<RX*"@HM+2TM"G8Q+C`*+2TM
M+0H*6VIA;ET@061D($AU;F=A<FEA;B!T<F%N<VQA=&EO;B`H3&%S>FQO($PN
M(%1O<FYO8VD@/'1O<FQA<WI`>&5N:6$N<V]T92YH=3XI+@I;:F%N72!!9&0@
M2V]R96%N('1R86YS;&%T:6]N("A*+DD@2VEM(#QA<&]R:65`;F5T:6%N+F-O
M;3XI+@I;:F%N72!!9&0@1&%N:7-H('1R86YS;&%T:6]N("A":6QL($5D9VEN
M9W1O;B`\:&]R9&5`,'@R,"YC;VT^*2X*6VIA;ET@061D($YO<G=E9VEA;B!.
M>6YO<G-K('1R86YS;&%T:6]N("A097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T
M82YO<F<^*2X*6VIA;ET@061D(&5V96YT('9I97<@<&%G92!A;F0@;6%K92!I
M="!T:&4@<W1A;F1A<F0@:68@8VQI8VMI;F<@;VX@86X@979E;G0*("`@("`@
M;&EN:R`H0G)A;F1O;B!+;FET=&5R(#QK;FET=&5R8D!B;&%N9'-I=&4N;W)G
M/BDN"EMJ86Y=(%-H;W<@979E;G0@9&5S8W)I<'1I;VX@:6X@;&EN:R!T;V]L
M=&EP+@I;:F%N72!!9&0@179E;G0Z.F=E=$QI;FLH*2X*6V-J:%T@5')A8VL@
M=VAE;B!E=F5N=',@87)E(&UO9&EF:65D+@I;8VIH72!!9&0@97AC97!T:6]N
M<R!T;R!R96-U<G)I;F<@979E;G1S+@I;8VIH72!!;&QO=R!S86UE(&1E;&5T
M:6]N(&]P=&EO;G,@87,@4&%L;2!F;W(@<F5C=7)R:6YG(&5V96YT<RX*6V-J
M:%T@061D(&$@<')E9F5R96YC92!F;W(@8V]N9FER;6EN9R!E=F5N="!D96QE
M=&EO;BX*6VIA;ET@061D(%-L;W9A:R!T<F%N<VQA=&EO;B`H3&5O($UR869K
M;R`\;&5O0&]E;"YS:SXI+@I;:F%N72!!9&0@(E-A=F4@87,@;F5W(B!B=71T
M;VX@*$UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M*2X*6V-J:%T@0VQO<V4@82!P;W1E;G1I86P@<')O8FQE;2!W:71H(')E9VES
M=&5R7V=L;V)A;',@3VX@86YD("1J<U]O;DQO860N"EMJ86Y=($%D9"!&:6YN
M:7-H('1R86YS;&%T:6]N("A,965N82!(96EN;R`\;&EI;G5`=71A+F9I/BDN
M"EMC:FA=($%D9"!N97<@979E;G0@;&EN:R!T;R!T:&4@<W5M;6%R>2`H475I
M;FX@5VEL<V]N(#QQ=VEL<V]N0&UI9'=O<FQD+F]R9SXI+@I;8VIH72!5<V4@
M=&AE(&YE=R!0<F5F<U5)(&-L87-S+@I;8VIH72!3:&]W(&5V96YT<R!T:&%T
M(&5X=&5N9"!P87-T('1H92!E;F0@:&]U<B!O9B!T:&4@9&%Y('9I97<N"EMJ
M;VY=($%D87!T('1O('1H92!N97<@2&]R9&4Z.FEM9R@I('-Y;G1A>"X*6V-J
M:%T@4W=I=&-H(&]U='!U="!C;VUP<F5S<VEO;B!T;R!O8E]G>FAA;F1L97(H
M*2X*6V-J:%T@1FEX(&-O;'5M;B!W:61T:',@:6X@=V5E:R!V:65W('1O(&)E
M(&-O;G-I<W1E;G0*("`@("`@*$IE9F8@1W)A=F5S(#QJ969F0&EM86=E+7-R
M8RYC;VT^*2X*6VIA;ET@061D(%!O;&ES:"!T<F%N<VQA=&EO;B`H36%C:65K
M(%5H;&EG(#QM=6AL:6=`=7,N961U+G!L/BDN"EMC:FA=($%D9"!P<F5F97)E
M;F-E<R!F;W(@=&AE(&AO=7(@<F%N9V4@<VAO=VX@:6X@=&AE(&1A>2]W965K
M('9I97=S+@I;8VIH72!5<V4@2U)/3D],251(7U1%35!,051%4R!C;VYS=&%N
M="!F;W(@86QL('1E;7!L871E('!A=&AS+@I;8VIH72!5<V4@)')E9VES=')Y
M+3YG970H*2!F;W(@86QL(%)E9VES=')Y(&EN9F]R;6%T:6]N+@I;8VIH72!5
M<V4@=&AE(&YE=R!.;W1I9FEC871I;VX@<WES=&5M+@I;:F%N72!!9&0@4W=E
M9&ES:"!T<F%N<VQA=&EO;B`H06YD<F5A<R!$86ALZ6X@/&%N9')E87-`9&%H
M;&5N+G=S/BDN"EMJ;VY=($5N86)L92!T:&4@(G!O<G1A8FEL:71Y(B!O<'1I
M;VX@:6X@=&AE(%-13"!D<FEV97(N"EMJ86Y=(%5S92!T:&4@;F5W(&YO=&EF
M:6-A=&EO;B!F<F%M97=O<FLN(%1H:7,@8G)E86MS(&-O;7!A=&EB:6QI='D@
M=VET:`H@("`@("!(;W)D92`R+C`N"EMJ86Y=(%)E;6]V92!T:&4@<W1A;F1A
M<F0@=F%L=64@9F]R('1H92!L86YG=6%G92!P<F5F97)E;F-E+B!4:&4@;&%N
M9W5A9V4@=&\*("`@("`@9F%L;"!B86-K('1O('-H;W5L9"!B92!S970@2&]R
M9&4@=VED92!I;B!L86YG+G!H<"!I;G-T96%D+@I;:F%N72!#:&%N9V4@)S(T
M:'(G('!R969E<F5N8V4@=&\@)W1W96YT>49O=7(G('1O(&)E(&QD87`@8V]M
M<&QI86YT+@H*"BTM+2TM+0IV,"XP+C,*+2TM+2TM"@I;8FIN72!#:&%N9V4@
M)V5N)R!A;F0@)V5N7T5.)R!L;V-A;&5S('1O("=E;E]54R<@*&1E9F%U;'0I
M+@I;:F%N72!!9&0@0G)A>FEL:6%N(%!O<G1U9W5E<V4@=')A;G-L871I;VX@
M*%-A;75E;"!-;W1A"B`@("`@(#QS86UU96Q`8G5M97)A;F=U92YC;VT^*2X*
M6VIA;ET@061D($1(5$U,(&1A=&4@;F%V:6=A=&]R+@I;:F%N72!!9&0@1W)E
M96L@=')A;G-L871I;VX@*%-T969A;F]S($DN($1I;6ET<FEO=2`\<V1I;6ET
M<FE`=&5I871H+F=R/BDN"EMJ86Y=($%D9"!2=7-S:6%N('1R86YS;&%T:6]N
M("A!;G1O;B!.96MH;W)O<VAI:"`\86YT;VY`=F%L=65H;W-T+G)U/BDN"EMJ
M86Y=(%)E8V]D92!T:&4@:'1M;"!D:7-P;&%Y(&9U;F-T:6]N<R!A;F0@861D
M(&5X=')A(')O=R!F;W(@86QL(&1A>2!E=F5N=',N"EMC:FA=($QE="!T:&4@
M4F5G:7-T<GD@:&%N9&QE(')E=')I979I;F<@<')E9F5R96YC97,N"EMJ86Y=
M($%D9"!I8V]N(&9O<B!R96-U<G)I;F<@979E;G1S+@I;:F%N72!!9&0@<')E
M9F5R96YC92!T;R!S:&]W(&1U92!T87-K<R!F<F]M($YA9R!I;B!T:&4@8V%L
M96YD87(N"EMJ86Y=($%D9"!I;7!O<G0O97AP;W)T(&-A<&%B:6QI='DN"EMJ
M86Y=($%D9"!)=&%L:6%N('1R86YS;&%T:6]N("A':6]V86YN:2!-96YE9VAE
M='1I(#QG;65N96=H971T:4!I;F9V:6,N:70^*2X*6V-J:%T@061D(%1R861I
M=&EO;F%L($-H:6YE<V4@=')A;G-L871I;VX@*$1A=FED($-H86YG(#QD879I
M9$!T:&)U;RYG;W8N='<^*2X*6VIA;ET@061D('-U<'!O<G0@9F]R('1I;65Z
M;VYE<PI;:F%N72!0=70@;F5W+65V96YT+6QI;FL@:6YT;R!W965K(&AE861E
M<B!I;G-T96%D(&%R;W5N9"!T:6UE<R!I;B!W965K('9I97<N"EMJ86Y=($%D
M9"!D87D@;V8@;6]N=&@@:6YT;R!W965K(&AE861E<G,*6V-J:%T@061D($-Z
M96-H('1R86YS;&%T:6]N("AP8VAY=&EL0&%S<"YO9VDN961U*2X*6VIA;ET@
M5&AE(&UE;G4@8G5T=&]N<R!N;W<@;W!E;B!T:&4@9&%Y+W=E96LO;6]N=&@@
M=FEE=R!C;W)R97-P;VYD:6YG('1O('1H90H@("`@("!A8W1U86P@=FEE=RX@
M3F5W("=4;V1A>2<@8G5T=&]N+@I;:F%N72!-86ME('-U<F4@=&AA="!E=F5N
M=',@8F5F;W)E(#AA;2!A<F4@<VAO=VX@8V]R<F5C=&QY+@I;8VIH72!!9&0@
M86X@:6YI=&EA;"!->5-13"!D<FEV97(@*$QU8R!386EL;&%R9"`\;'5C*VMR
M;VYO;&ET:$!A;&-O=F4N9G(^*2X*6V%V<VU=(%)E<&QA8V4@)&-O;F9;)W!A
M=&AS)UT@=VET:"!T:&4@)')E9VES=')Y(&5Q=6EV86QE;G1S+@I;:F%N72!,
M970@=&AE('=E96L@86QT97)N871I=F5L>2!S=&%R="!W:71H(%-U;F1A>2X@
M25-/(&-O;F9O<FT@=V5E:R!N=6UB97(*("`@("`@8V%L8W5L871I;VXN"EMC
M:FA=(%!R979E;G0@86QL(&1A>2!E=F5N=',@9G)O;2!C875S:6YG('1H92!D
M87D@=&\@<W1A<G0@9&ES<&QA>6EN9R!A="`Q,F%M+@I;8VIH72!!9&0@)&-O
M;F9;)VUE;G4G75LG87!P<R==('-U<'!O<G0@86YD(&$@:&5L<"!L:6YK+@I;
M:F%N72!,970@=&AE('5S97)S(&%L=&5R;F%T:79E;'D@<V5L96-T(&5N9"!T
M:6UE(&]R(&1U<F%T:6]N(&]F(&%N(&5V96YT+@I;:F%N72!!9&0@<W5P<&]R
M="!F;W(@86QA<FUS+@I;8VIH72!!9&0@82!P<F5F97)E;F-E('1O('5S92!H
M;W5R(&EN8W)E;65N=',@:6YS=&5A9"!O9B!H86QF+6AO=7(@*$IA;@H@("`@
M("!38VAN96ED97(@/&IA;FUA:6QI;F=`9VUX+F1E/BDN"EMC:FA=($)O;&0@
M:6X@<')O9W)E<W,@979E;G1S(&EN('1H92!S=6UM87)Y(&%N9"!D;VXG="!S
M:&]W(&5V96YT<R!T:&%T(&%R90H@("`@("!O=F5R("A*86X@4V-H;F5I9&5R
M(#QJ86YM86EL:6YG0&=M>"YD93XI+@I;8VIH72!!9&0@9&5L971E(&QI;FMS
M(&]N(&5V96YT(&5D:70@<&%G97,L(&%N9"!M86ME('-U<F4@9&5L971E(&%N
M9"!C86YC96P*("`@("`@=V]R:R!W:71H;W5T(&IA=F%S8W)I<'0@*$IA;B!3
M8VAN96ED97(@/&IA;FUA:6QI;F=`9VUX+F1E/BDN"EMC:FA=($%D9"!T<F%N
M<VQA=&EO;B!F<F%M97=O<FLN"EMC:FA=($UA:V4@<W5R92!E=F5N=',@87)E
M('-O<G1E9"!B>2!T:6UE(&EN('1H92!S=6UM87)Y+@I;8VIH72!5<V4@=&AE
M("IU<FPH*2!F=6YC=&EO;G,@;6]R92!C;VYS:7-T96YT;'D@=&\@;6%K92!S
M=7)E('1H870*("`@("`@8V]O:VEE+6QE<W,@<V5S<VEO;G,@=V]R:RX*"@HM
M+2TM+2T*=C`N,"XR"BTM+2TM+0H*6V-J:%T@06QL;W<@86QL+61A>2!E=F5N
M=',@86YD(&UO;G1L>2UO;BUW965K9&%Y(')E8W5R<F5N8V4N"EMC:FA=($%D
M9"!A($AO<F1E('-U;6UA<GD@05!)(&9U;F-T:6]N+@I;8VIH72!5<V4@,C1H
M<B!T:6UE('!R969E<F5N8V4@*$IA;B!38VAN96ED97(@/&IA;FUA:6QI;F=`
M9VUX+F1E/BDN"EMC:FA=($%D9&5D(%!R969E<F5N8V5S(&9R86UE=V]R:R!I
M;G1O($MR;VYO;&ET:"X*6VIO;ET@365R9V4@9&]C='EP92YI;F,@:6YT;R!C
M;VUM;VXM:&5A9&5R+FEN8RX*6VIO;ET@06QL;W<@=&AE(')E9VES=')Y('1O
M(&AA;F1L92!+<F]N;VQI=&@G<R!C;VYF:6=U<F%T:6]N('9A;'5E<RX*6VIO
M;ET@2$]21$5?0D%312!I<R!N;W<@9&5F:6YE9"!I;B!L:6(O8F%S92YP:'`@
M:6YS=&5A9"!O9B!C;VYF:6<O8V]N9BYP:'`N"EMC:FA=($1E9FEN92!T:&4@
M2$]21$5?0D%312!C;VYS=&%N="!I;B!C;VYF:6<O8V]N9BYP:'`L(&%N9"!U
M<V4@:70@=VAE;@H@("`@("!R969E<G)I;F<@=&\@86YY(&]F($AO<F1E)W,@
M9FEL97,N"EMJ;VY=(%)E=&ER960@8V]N9FEG+VUE;G4N='AT(&EN(&9A=F]R
M(&]F(&-O;F9I9R]M96YU+G!H<"X@(%1H:7,@9FEL92!F;VQL;W=S"B`@("`@
M(&$@;F5W(&9O<FUA="!B87-E9"!O;B!N871I=F4@4$A0(&1A=&$@<W1R=6-T
M=7)E<RX*6V-J:%T@061D(&%N(&]P=&EO;F%L(&ME>7=O<F1S('-E8W1I;VXL
M(&%N9"!A(&ME>7=O<F1S(&1E9FEN:71I;VX@9FEL92X*6V-J:%T@061D(&$@
M;&]C871I;VX@9FEE;&0@=&\@979E;G1S+@I;8VIH72!!9&0@=&AE(&%B:6QI
M='D@=&\@<F4M;&%B96P@=&AE(&-A=&5G;W)Y(&9I96QD+"!A;F0@=&\@;6%K
M92!I="!A"B`@("`@('-Y<W1E;2UD969I;F5D(&QI<W0@;V8@;W!T:6]N<RX*
M6V-J:%T@061D960@2W)O;F]L:71H.CIW965K<TEN665A<B@D>65A<BD@86YD
M($MR;VYO;&ET:%]$87DZ.FES5&]D87DH*2X*6V-J:%T@061D('=E96L@86YD
M('=O<FMW965K("AM;VXM9G)I*2!V:65W<RX*6V-J:%T@06QL;W<@979E;G1S
M('1O(')E8W5R(&5V97)Y(&]T:&5R('=E96LL(&5V97)Y(#,@9&%Y<RP@971C
M+@I;8VIH72!296]R9V%N:7IE('1H92!E=F5N="!A9&1I;F<O961I=&EN9R!S
M8W)E96X@86YD(&%D9"!J879A<V-R:7!T('1O(&=I=F4*("`@("`@=&AE('5S
M97(@<V%N92!D969A=6QT<RX*6V-J:%T@4F5M;W9E('EE87(N<&AP.R!I="=S
M('5G;'D@86YD(&YO="!R96%L;'D@=7-E9G5L+@I;8VIH72!/<&5N('1H92!C
M86QE;F1E<B!I;B!B87-E+G!H<"X*6V-J:%T@4F5M;W9E(&UO<W0@;V8@=&AE
M(')E;6%I;FEN9R!M8V%L+61E<&5N9&5N="!C;V1E+@I;8VIH72!+<F]N;VQI
M=&@@;F]W('5S97,@2&]R9&4@875T:&5N=&EC871I;VX@:6YS=&5A9"!O9B!I
M=',@;W=N+B!4:&ES(&UE86YS"B`@("`@('1H870@=VAA=&5V97(@875T:"!M
M971H;V0@>6]U(&%R92!U<VEN9R!F;W(@2&]R9&4@=VEL;"!B92!U<V5D('1O
M"B`@("`@(&%U=&AE;G1I8V%T92!T;R!+<F]N;VQI=&@L(&%N9"!I;B!R971U
M<FX@>6]U(&=E="!S:6YG;&4@<VEG;BUO;B!W:71H(&%N>0H@("`@("!O=&AE
M<B!A<'!S('5S:6YG($AO<F1E(&%U=&AE;G1I8V%T:6]N+B!4:&ES(&%L<V\@
M;65A;G,@=&AA="!+<F]N;VQI=&@*("`@("`@:7,@8V]M<&QE=&5L>2!I;F1E
M<&5N9&5N="!O9B!-0T%,(&9O<B!A=71H96YT:6-A=&EO;B!N;W<[(&EF('EO
M=2!H879E"B`@("`@(&]N92!-0T%,('5S97(L('1H870G<R!E;F]U9V@@=&\@
M<')O=FED92!C86QE;F1A<G,@9F]R(&%L;"!(;W)D92!U<V5R<RX*6V-J:%T@
M061D(&QI8B]B87-E+G!H<"!T;R!I;F-L=61E(&%L;"!G;&]B86QL>2!N965D
M960@8V]N9B!F:6QE<R!A;F0*("`@("`@;&EB<F%R:65S+"!S970@=7`@=&AE
M(&QA;F=U86=E+"!E=&,N"EMC:FA=($%B<W1R86-T('1H92!E=F5N="!C<F5A
M=&EO;B]E9&ET(&-O9&4@:6YT;R!T:&4*("`@("`@2W)O;F]L:71H7T1R:79E
M<B]+<F]N;VQI=&A?179E;G0@8VQA<W-E<RX*6V-J:%T@0VAA;F=E<R!T;R!W
M;W)K('=I=&@@<F5G:7-T97)?9VQO8F%L<R`]($]F9BX@*$E.(%!23T=215-3
M*0I;8VIH72!!9&0@86X@;W!T:6]N86P@(F=E="!T:&4@=&EM92!T:&ES(&5V
M96YT('=O=6QD('-T87)T(&]N(&1A>2!X(B!F96%T=7)E"B`@("`@('1O('1H
M92!+<F]N;VQI=&A?179E;G0Z.B!C;&%S<RP@86QL;W=I;F<@<W1A='5S+G!H
M<"!T;R!W;W)K('=I=&@*("`@("`@<F5C=7)R:6YG(&5V96YT<RX*6V-J:%T@
M5V4@;F]W(&AA=F4@=&AE($MR;VYO;&ET:%]%=F5N="!A8G-T<F%C=&EO;B!C
M;&%S<R!T:&%T(&%B<W1R86-T<R!A=V%Y"B`@("`@(&1E=&%I;',@;V8@979E
M;G1S+"!S;R!T:&%T('1H92!F<F]N=&5N9"!S8W)I<'1S(&%R96XG="!D97!E
M;F1A;G0@;VX*("`@("`@;6-A;"X*6V-J:%T@1&ES<&QA>2!E=F5N=',@=VAI
M8V@@87)E(&EN('!R;V=R97-S+"!J=7-T('-T87)T:6YG+"!O<B!S=&%R="!I
M;B!U;F1E<@H@("`@("!T=V\@:&]U<G,@86QO;F<@=VET:"!O=&AE<B!M97-S
M86=E<R!J=7-T('5N9&5R('1H92!M96YU+@I;8VIH72!-=6-H('-L:6-K97(@
M54DN"EMC:FA=(%5S92!M8V%L7W!O<&5N(&EN<W1E860@;V8@;6-A;%]O<&5N
M("T@;6EG:'0@9VEV92!U<R!A('!E<F9O<FUA;F-E(&=A:6XN"@H*+2TM+2TM
M"G8P+C`N,0HM+2TM+2T*"EMC:FA=($1O;B=T(&1I<W!L87D@9&5L971E(&QI
M;FMS(&EN(&UO;G1H('9I97<[('-L:6UM97(@54DN"EMJ;VY=(%-I;&5N8V4@
M<V5S<VEO;E]S=&%R="!W87)N:6YG<RX*6VIO;ET@57-E($AO<F1E.CIU<FPH
M*2!I;B!P;&%C92!O9B!T:&4@9&5P<F5C871E9"!B=6EL9%523"@I(&9U;F-T
M:6]N+@I;8VIH72!5<&1A=&4@=&\@=V]R:R!W:71H(&YE=R!S;&EM;65D(&1O
M=VXO2&]R9&4Z.B!I;G1E9W)A=&5D('-E<W-I;VX@8V]D92X*6V-J:%T@57-E
M('1H92!N97<@8W-S+G!H<"!S8W)I<'0@=&\@9V5N97)A=&4@;W5R('-T>6QE
M<VAE971S+@I;8VIH72!2979I<VEN9R!T:&4@;&]O:R!A;F0@9F5E;"!T;R!U
M<V4@=&AE(&YE=R!S='EL97-H965T<R!A;F0@8V]N=F5N=&EO;G,N"EMC:FA=
M($%D9&5D(&EN:71I86P@0TA!3D=%4R!F:6QE(&%N9"!D;V-U;65N=&%T:6]N
M+@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VMR;VYO;&ET:"]D;V-S+T-2141)5%,`````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V,C0`,3`T,3<S-C(W-3,`,#(P
M-#$R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*($MR;VYO;&ET:"!$979E
M;&]P;65N="!496%M"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,
M87-T('5P9&%T93H@("`D1&%T93H@,C`P-B\P,R\P-B`P.3HT-#HP-R`D"CI2
M979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N,S<N."XQ,2`D"CI#;VYT86-T
M.B`@("`@("!H;W)D94!L:7-T<RYH;W)D92YO<F<*"@I#;W)E($1E=F5L;W!E
M<G,*/3T]/3T]/3T]/3T]/3T]"@HM($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@HM($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"@H*
M1')I=F5R<PH]/3T]/3T]"@H]/3T]/3T]/3T]/3T]/3T]/2`@(#T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"E!%05(@1$(@("`@("`@
M("`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"CT]/3T]
M/3T]/3T]/3T]/3T]("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"@I,;V-A;&EZ871I;VX*/3T]/3T]/3T]/3T]"@H]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*07)A8FEC("A3>7)I82D@("`@
M("`@("`@4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;2`\9&5V=&5A;4!P;&%T
M:6YU;2US>2YN970^"D)R87II;&EA;B!0;W)T=6=U97-E("`@(%-A;75E;"!-
M;W1A(#QS86UU96Q`8G5M97)A;F=U92YC;VT^"B`@("`@("`@("`@("`@("`@
M("`@("`@($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB<CX*0G5L9V%R
M:6%N("`@("`@("`@("`@("`@36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R
M<VAA9&4N=7,^"D-H:6YE<V4@*%-I;7!L:69I960I("`@(%IH86YG($)O(#QB
M;V]Z:&%N9T!S9&(N86,N8VX^"D-H:6YE<V4@*%1R861I=&EO;F%L*2`@($1A
M=FED($-H86YG(#QD879I9$!T;78N9V]V+G1W/@I#>F5C:"`@("`@("`@("`@
M("`@("`@("!0879E;"!#:'ET:6P@/'!C:'ET:6Q`87-P+F]G:2YE9'4^"D1A
M;FES:"`@("`@("`@("`@("`@("`@($)I;&P@161G:6YG=&]N(#QH;W)D94`P
M>#(P+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@36%R=&EN($QI<W0M
M4&5T97)S96X@/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K/@I$=71C:"`@("`@
M("`@("`@("`@("`@("!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C
M;VQL96=E+FYL/@H@("`@("`@("`@("`@("`@("`@("`@("!(86X@4W!R=7ET
M(#QH86XN<W!R=7ET0&EJ<W-E;&=R;V5P+FYL/@I&:6YN:7-H("`@("`@("`@
M("`@("`@("!,965N82!(96EN;R`\;&EI;G5`=71A+F9I/@I&<F5N8V@@("`@
M("`@("`@("`@("`@("!-:6MH8>ML($IA;G-O;B`\;6EK0&=A;&%X:64N;F5T
M/@H@("`@("`@("`@("`@("`@("`@("`@("!"96YO:70@4W0M06YD<ND@/&)E
M;D!B96YO:71S="UA;F1R92YN970^"B`@("`@("`@("`@("`@("`@("`@("`@
M(%!I97)R92!,86-H86YC92`\<&Q`<&EE<G)E;&%C:&%N8V4N;F5T/@I'97)M
M86X@("`@("`@("`@("`@("`@("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@I'<F5E:R`@("`@("`@("`@("`@("`@("!3=&5F86YO<R!)+B!$:6UI
M=')I;W4@/'-U<'!O<G1`=&5I871H+F=R/@H@("`@("`@("`@("`@("`@("`@
M("`@("!3:6QL:6=A<F1O<R!8<FES=&]F;W)O<PH@("`@("`@("`@("`@("`@
M("`@("`@("!!;F%G;F]S=&]P;W5L;W,@07!O<W1O;&ES"DAU;F=A<FEA;B`@
M("`@("`@("`@("`@($QA<WIL;R!,+B!4;W)N;V-I(#QT;W)L87-Z0'AE;FEA
M+G-O=&4N:'4^"DET86QI86X@("`@("`@("`@("`@("`@($=I;W9A;FYI($UE
M;F5G:&5T=&D@/&=M96YE9VAE='1I0&EN9G9I8RYI=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@36%R8V\@4&ER;W9A;F\@/&UA<F-O+G!I<F]V86YO0'5N
M:6)O8V-O;FDN:70^"B`@("`@("`@("`@("`@("`@("`@("`@($-R:7-T:6%N
M($UA;F]N:2`\8W)I<W1I86XN;6%N;VYI0&YE=&AE<VES+FET/@I*87!A;F5S
M92`@("`@("`@("`@("`@("!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S
M=6MU8F$N86,N:G`^"DMO<F5A;B`@("`@("`@("`@("`@("`@($HN22!+:6T@
M/&%P;W)I94!N971I86XN8V]M/@I,871V:6%N("`@("`@("`@("`@("`@("!)
M=F%R<R!3=&EV<FEN<R`\:79A<G-`:W)A<VQA=F$N;'8^"DQI=&AU86YI86X@
M("`@("`@("`@("`@($1A<FEU<R!-871U;&EA=7-K87,@/&1A<FEU<T!L;FLN
M;'0^"B`@("`@("`@("`@("`@("`@("`@("`@(%9I;&EU<R!3=6US:V%S(#QV
M:6QI=7-`;&YK+FQT/@I.;W)W96=I86X@0F]K;6%A;"`@("`@("!4;W)S=&5I
M;B!3+B!(86YS96X@/&AU;&5B;V5R0'1E8VAB964N;F\^"B`@("`@("`@("`@
M("`@("`@("`@("`@(%1O<F)J;W)N($=R:6YD:&%U9R`\9W)I;F1H875G0&=M
M86EL+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@06YD<F5A<R!'=6YL
M96EK<VMA87,@/&%N9')E87-`9W5N;&5I:W-K86%S+FYO/@H@("`@("`@("`@
M("`@("`@("`@("`@("!4<F]N9"!":OAR<W1A9"`\=')B0&YD;BYN;SX*("`@
M("`@("`@("`@("`@("`@("`@("`@5&AO;6%S($-H<BX@1&%H;"`\=&-D0&YD
M;BYN;SX*3F]R=V5G:6%N($YY;F]R<VL@("`@("`@4&5R+5-T:6%N(%9A=&YE
M(#QP<W9`;W)S=&$N;W)G/@I0;VQI<V@@("`@("`@("`@("`@("`@("!-86-I
M96L@56AL:6<@/&UU:&QI9T!U<RYE9'4N<&P^"E!O<G1U9W5E<V4@("`@("`@
M("`@("`@($UA;G5E;"!-96YE>F5S(&1E(%-E<75E:7)A(#Q-86YU96PN4V5Q
M=65I<F$^"E)O;6%N:6%N("`@("`@("`@("`@("`@($5U9V5N($AO86YC82`\
M975G96YH0'5R8F%N+6=R869X+G)O/@H@("`@("`@("`@("`@("`@("`@("`@
M("!-87)I=7,@1')A9W5L97-C=2`\;6%R:75S9$!U<F)A;BUG<F%F>"YR;SX*
M4G5S<VEA;B`@("`@("`@("`@("`@("`@06YT;VX@3F5K:&]R;W-H:6@@/&%N
M=&]N0'9A;'5E:&]S="YR=3X*("`@("`@("`@("`@("`@("`@("`@("`@1F5D
M;W(@02X@1F5T:7-O=B`\9F%F0'-S8RYR=3X*4VQO=F%K("`@("`@("`@("`@
M("`@("`@3&5O($UR869K;R`\;&5O0&]E;"YS:SX*4W!A;FES:"`@("`@("`@
M("`@("`@("`@36%N=65L(%!E<F5Z($%Y86QA(#QM<&5R87EA0&%L8V%Z86)A
M+G5N97@N97,^"E-W961I<V@@("`@("`@("`@("`@("`@($%N9')E87,@1&%H
M;.EN(#QA;F1R96%S0&1A:&QE;BYW<SX*("`@("`@("`@("`@("`@("`@("`@
M("`@2F]A<75I;2!(;VUR:6=H875S96X@/&IO:&]`=V5B8G!L871S96XN<V4^
M"E1U<FMI<V@@("`@("`@("`@("`@("`@($ES=&%N8G5L(%1E8VAN:6-A;"!5
M;FEV97)S:71Y($E4($1E<&%R=&UE;G0*("`@("`@("`@("`@("`@("`@("`@
M("`@/&ET=6)I;4!I='4N961U+G1R/@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T@
M("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]K<F]N;VQI=&@O9&]C<R])3E-404Q,````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P,3`W`#$P-#$W,S8R-S4S`#`R
M,#0Q,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@26YS=&%L;&EN9R!+<F]N
M;VQI=&@@,BXQ"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S="!U
M<&1A=&4Z("`@)$1A=&4Z(#(P,#4O,3$O,30@,38Z,3<Z-#D@)`HZ4F5V:7-I
M;VXZ("`@("`@)%)E=FES:6]N.B`Q+C$V+C$P+C8@)`HZ0V]N=&%C=#H@("`@
M("`@:W)O;F]L:71H0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z.B!#
M;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I4:&ES(&1O8W5M96YT
M(&-O;G1A:6YS(&EN<W1R=6-T:6]N<R!F;W(@:6YS=&%L;&EN9R!T:&4@2W)O
M;F]L:71H('=E8BUB87-E9`IC86QE;F1A<B!A<'!L:6-A=&EO;B!O;B!Y;W5R
M('-Y<W1E;2X*"D9O<B!I;F9O<FUA=&EO;B!O;B!T:&4@8V%P86)I;&ET:65S
M(&%N9"!F96%T=7)E<R!O9B!+<F]N;VQI=&@L('-E92!T:&4@9FEL90I214%$
M345?(&EN('1H92!T;W`M;&5V96P@9&ER96-T;W)Y(&]F('1H92!+<F]N;VQI
M=&@@9&ES=')I8G5T:6]N+@H*"D]B=&%I;FEN9R!+<F]N;VQI=&@*/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*2W)O;F]L:71H(&-A;B!B92!O8G1A:6YE9"!F<F]M
M('1H92!(;W)D92!W96)S:71E(&%N9"!&5%`@<V5R=F5R+"!A=`H*("`@:'1T
M<#HO+W=W=RYH;W)D92YO<F<O:W)O;F]L:71H+PH*("`@9G1P.B\O9G1P+FAO
M<F1E+F]R9R]P=6(O:W)O;F]L:71H+PH*0FQE961I;F<M961G92!D979E;&]P
M;65N="!V97)S:6]N<R!O9B!+<F]N;VQI=&@@87)E(&%V86EL86)L92!V:6$@
M0U93.R!S964@=&AE"F9I;&4@8&AO<F1E+V1O8W,O2$%#2TE.1V!?(&EN('1H
M92!(;W)D92!D:7-T<FEB=71I;VX@9F]R(&EN9F]R;6%T:6]N(&]N"F%C8V5S
M<VEN9R!T:&4@2&]R9&4@0U93(')E<&]S:71O<GDN"@H*4')E<F5Q=6ES:71E
M<PH]/3T]/3T]/3T]/3T]"@I4;R!F=6YC=&EO;B!P<F]P97)L>2P@2W)O;F]L
M:71H(')E<75I<F5S('1H92!F;VQL;W=I;F<Z"@HQ+B!!('=O<FMI;F<@2&]R
M9&4@:6YS=&%L;&%T:6]N+@H*("`@2W)O;F]L:71H(')U;G,@=VET:&EN('1H
M92!@2&]R9&4@07!P;&EC871I;VX@1G)A;65W;W)K8%\L(&$@<V5T(&]F(&-O
M;6UO;@H@("!T;V]L<R!F;W(@5V5B(&%P<&QI8V%T:6]N<R!W<FET=&5N(&EN
M(%!(4"X@(%EO=2!M=7-T(&EN<W1A;&P@2&]R9&4@8F5F;W)E"B`@(&EN<W1A
M;&QI;F<@2W)O;F]L:71H+B`@66]U(&UU<W0@=7-E(&$@=F5R<VEO;B!O9B!(
M;W)D92`S+C`@;W(@9W)E871E<BX*"B`@("XN(%]@2&]R9&4@07!P;&EC871I
M;VX@1G)A;65W;W)K8#H@:'1T<#HO+W=W=RYH;W)D92YO<F<O:&]R9&4O"@H@
M("!4:&4@2&]R9&4@1G)A;65W;W)K(&-A;B!B92!O8G1A:6YE9"!F<F]M('1H
M92!(;W)D92!W96)S:71E(&%N9"!&5%`@<V5R=F5R+`H@("!A=`H*("`@("`@
M:'1T<#HO+W=W=RYH;W)D92YO<F<O:&]R9&4O"@H@("`@("!F='`Z+R]F='`N
M:&]R9&4N;W)G+W!U8B]H;W)D92\*"B`@($UA;GD@;V8@2W)O;F]L:71H)W,@
M<')E<F5Q=6ES:71E<R!A<F4@86QS;R!(;W)D92!P<F5R97%U:7-I=&5S+@H*
M("`@+BX@26UP;W)T86YT.CH@0F4@<W5R92!T;R!H879E(&-O;7!L971E9"!A
M;&P@;V8@=&AE('-T97!S(&EN('1H90H@("`@("`@("`@("`@("`@("!@:&]R
M9&4O9&]C<R])3E-404Q,8%\@9FEL92!F;W(@=&AE($AO<F1E($9R86UE=V]R
M:R!B969O<F4*("`@("`@("`@("`@("`@("`@:6YS=&%L;&EN9R!+<F]N;VQI
M=&@N"@HR+B!344P@<W5P<&]R="!I;B!02%`L(&]R($MO;&%B('-U<'!O<G0@
M:6X@2&]R9&4*"B`@($MR;VYO;&ET:"!S=&]R92!I=',@9&%T82!I;B!A(&)A
M8VME;F0@+2!E:71H97(@86X@4U%,(&1A=&%B87-E(&]R(&$*("`@2V]L86(@
M<V5R=F5R+B!"=6EL9"!02%`@=VET:"!W:&EC:&5V97(@4U%,(&1R:79E<B!Y
M;W4@<F5Q=6ER93L@<V5E"B`@('1H92!(;W)D92!@:&]R9&4O9&]C<R])3E-4
M04Q,8%\@9FEL92!F;W(@;6]R92!D971A:6QS(&]N('5S:6YG(&1A=&%B87-E
M<PH@("!W:71H($AO<F1E+"!O<B!T:&4@2V]L86(@=V5B8VQI96YT(&1O8W5M
M96YT871I;VX@9F]R(&AO=R!T;R!S970@=7`*("`@2W)O;F]L:71H(&9O<B!+
M;VQA8BX*"C,N($]P97)A=&EN9R!3>7-T96T@=VET:"!S=7!P;W)T(&9O<B!D
M871E<R!B969O<F4@,3DW,"TP,2TP,2!;3U!424].04Q="@H@("!)9B!Y;W4@
M=V%N="!T;R!U<V4@9&%T97,@96%R;&EE<B!T:&4@2F%N=6%R>2`Q<W0@,3DW
M,"P@9F]R(&5X86UP;&4*("`@8FER=&AD87ES+"!Y;W4@;F5E9"!A;B!/<&5R
M871I;F<@4WES=&5M<R!T:&%T('-U<'!O<G1S(&YE9V%T:79E"B`@('1I;65S
M=&%M<',N($UI8W)O<V]F="!7:6YD;W=S(&1O97,@*BIN;W0J*B!S=7!P;W)T
M('-U8V@@9&%T97,N"@H*26YS=&%L;&EN9R!+<F]N;VQI=&@*/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*"DMR;VYO;&ET:"!I<R!W<FET=&5N(&EN(%!(4"P@86YD
M(&UU<W0@8F4@:6YS=&%L;&5D(&EN(&$@=V5B+6%C8V5S<VEB;&4*9&ER96-T
M;W)Y+B`@5&AE('!R96-I<V4@;&]C871I;VX@;V8@=&AI<R!D:7)E8W1O<GD@
M=VEL;"!D:69F97(@9G)O;2!S>7-T96T@=&\*<WES=&5M+B`@0V]N=F5N=&EO
M;F%L;'DL($MR;VYO;&ET:"!I<R!I;G-T86QL960@9&ER96-T;'D@=6YD97)N
M96%T:"!(;W)D92!I;@IT:&4@=V5B<V5R=F5R)W,@9&]C=6UE;G0@=')E92X*
M"E-I;F-E($MR;VYO;&ET:"!I<R!W<FET=&5N(&EN(%!(4"P@=&AE<F4@:7,@
M;F\@8V]M<&EL871I;VX@;F5C97-S87)Y.R!S:6UP;'D*97AP86YD('1H92!D
M:7-T<FEB=71I;VX@=VAE<F4@>6]U('=A;G0@:70@=&\@<F5S:61E(&%N9"!R
M96YA;64@=&AE(')O;W0*9&ER96-T;W)Y(&]F('1H92!D:7-T<FEB=71I;VX@
M=&\@=VAA=&5V97(@>6]U('=I<V@@=&\@87!P96%R(&EN('1H92!54DPN("!&
M;W(*97AA;7!L92P@=VET:"!T:&4@07!A8VAE('=E8G-E<G9E<B=S(&1E9F%U
M;'0@9&]C=6UE;G0@<F]O="!O9@I@8"]U<W(O;&]C86PO87!A8VAE+VAT9&]C
M<V!@+"!Y;W4@=V]U;&0@='EP93HZ"@H@("!C9"`O=7-R+VQO8V%L+V%P86-H
M92]H=&1O8W,O:&]R9&4*("`@=&%R('IX=F8@+W!A=&@O=&\O:W)O;F]L:71H
M+7@N>2YZ+G1A<BYG>@H@("!M=B!K<F]N;VQI=&@M>"YY+GH@:W)O;F]L:71H
M"@IA;F0@=V]U;&0@=&AE;B!F:6YD($MR;VYO;&ET:"!A="!T:&4@55),"@H@
M("!H='1P.B\O>6]U<BUS97)V97(O:&]R9&4O:W)O;F]L:71H+PH*"D-O;F9I
M9W5R:6YG($MR;VYO;&ET:`H]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"C$N($-O
M;F9I9W5R:6YG($AO<F1E(&9O<B!+<F]N;VQI=&@*"B`@(&$N(%)E9VES=&5R
M('1H92!A<'!L:6-A=&EO;@H*("`@("`@26X@8&!H;W)D92]C;VYF:6<O<F5G
M:7-T<GDN<&AP8&`L(&9I;F0@=&AE(&!@87!P;&EC871I;VYS6R=K<F]N;VQI
M=&@G76!@"B`@("`@('-T86YZ82X@(%1H92!@8'-H;W=@8"!P87)A;65T97(@
M<VAO=6QD(&%L<F5A9'D@8F4@;6%R:V5D(&!@/3X@=')U96!@+@H@("`@("!)
M9B!Y;W4@:&%V92!C:&%N9V5D('1H92!L;V-A=&EO;B!O9B!+<F]N;VQI=&@@
M<F5L871I=F4@=&\@2&]R9&4L(&5I=&AE<@H@("`@("!I;B!T:&4@55),(&]R
M(&EN('1H92!F:6QE<WES=&5M(&]R(&)O=&@L('EO=2!M=7-T('5P9&%T92!T
M:&4*("`@("`@8&!F:6QE<F]O=&!@(&%N9"!@8'=E8G)O;W1@8"!S971T:6YG
M<R!T;R!T:&5I<B!C;W)R96-T('9A;'5E<RX*"B`@(&(N($-O;F9I9W5R:6YG
M(&$@1&%T851R964@8F%C:V5N9`H*("`@("`@2W)O;F]L:71H(')E<75I<F5S
M(&$@<&5R;6%N96YT(&!@1&%T851R965@8"!B86-K96YD(&EN($AO<F1E('1O
M(&UA;F%G90H@("`@("!C86QE;F1A<G,@86YD('1O(&%D9"!E=F5N=',@=&\@
M8V%L96YD87)S+B`@268@>6]U(&1I9&XG="!S971U<"!A"B`@("`@($1A=&%4
M<F5E(&)A8VME;F0@>65T+"!G;R!T;R!T:&4@8V]N9FEG=7)A=&EO;B!I;G1E
M<F9A8V4L('-E;&5C="!(;W)D90H@("`@("!F<F]M('1H92!L:7-T(&]F(&%P
M<&QI8V%T:6]N<R!A;F0@<V5L96-T(&$@9')I=F5R(&1I9F9E<F5N="!T:&%N
M"B`@("`@(&!@3F]N96!@(&]N('1H92!@8$1A=&%4<F5E(%-Y<W1E;6!@('1A
M8BX@($UA:V4@<W5R92!T:&%T('EO=2!R86X@=&AE"B`@("`@(&YE8V5S<V%R
M>2!S8W)I<'1S('1O(&-R96%T92!A('-T;W)A9V4@8F%C:V5N9"!F;W(@=&AE
M($1A=&%4<F5E('-Y<W1E;2P*("`@("`@92YG+B!O;F4@;V8@=&AE(&!@8W)E
M871E+BHN<W%L8&`@;W(@8&!H;W)D95]D871A=')E92XJ+G-Q;&!@(%-13"!S
M8W)I<'1S"B`@("`@(&EN(&!@:&]R9&4O<V-R:7!T<R]S<6PO8&`N("!9;W4@
M<VAO=6QD(&AA=F4@9&]N92!T:&ES(&%L<F5A9'D@9'5R:6YG('1H90H@("`@
M("!I;G-T86QL871I;VX@;V8@2&]R9&4N"@HR+B!#<F5A=&EN9R!T:&4@9&%T
M86)A<V4@=&%B;&4*"B`@(%1H92!S<&5C:69I8R!S=&5P<R!T;R!C<F5A=&4@
M=&AE($MR;VYO;&ET:"!D871A8F%S92!T86)L92!D97!E;F0@;VX@=VAI8V@*
M("`@9&%T86)A<V4@>6]U)W9E(&-H;W-E;B!T;R!U<V4N"@H@("!&:7)S="P@
M;&]O:R!I;B!@8'-C<FEP=',O9')I=F5R<R]S<6PO8&`@=&\@<V5E(&EF(&$@
M<V-R:7!T(&%L<F5A9'D@97AI<W1S"B`@(&9O<B!Y;W5R(&1A=&%B87-E('1Y
M<&4N("!)9B!S;RP@>6]U('-H;W5L9"!B92!A8FQE('1O('-I;7!L>2!E>&5C
M=71E('1H870*("`@<V-R:7!T(&%S('-U<&5R=7-E<B!I;B!Y;W5R(&1A=&%B
M87-E+B`@*$YO=&4@=&AA="!E>&5C=71I;F<@=&AE('-C<FEP="!A<PH@("!T
M:&4@(FAO<F1E(B!U<V5R('=I;&P@<')O8F%B;'D@9F%I;"!W:&5N(&=R86YT
M:6YG('!R:79I;&5G97,N*0H*("`@268@<W5C:"!A('-C<FEP="!D;V5S(&YO
M="!E>&ES="P@>6]U)VQL(&YE960@=&\@8G5I;&0@>6]U<B!O=VXL('5S:6YG
M('1H90H@("!F:6QE(&MR;VYO;&ET:"YS<6P@87,@82!S=&%R=&EN9R!P;VEN
M="X@($EF('EO=2!N965D(&%S<VES=&%N8V4@:6X@8W)E871I;F<*("`@9&%T
M86)A<V5S+"!Y;W4@;6%Y('=I<V@@=&\@;&5T('5S(&MN;W<@;VX@=&AE($MR
M;VYO;&ET:"!M86EL:6YG(&QI<W0N"@H@("!9;W4@=VEL;"!A;'-O(&YE960@
M=&\@;6%K92!S=7)E('1H870@=&AE(")H;W)D92(@=7-E<B!I;B!Y;W5R(&1A
M=&%B87-E(&AA<PH@("!T86)L92UC<F5A=&EO;B!P<FEV:6QE9V5S+"!S;R!T
M:&%T('1H92!T86)L97,@=&AA="!@4$5!4B!$0F!?('5S97,@=&\*("`@<')O
M=FED92!P;W)T86)L92!S97%U96YC97,@8V%N(&)E(&-R96%T960N"@H@("`N
M+B!?8%!%05(@1$)@.B!H='1P.B\O<&5A<BYP:'`N;F5T+T1""@HS+B!#;VYF
M:6=U<FEN9R!+<F]N;VQI=&@N"@H@("!4;R!C;VYF:6=U<F4@2W)O;F]L:71H
M+"!C:&%N9V4@=&\@=&AE(&!@8V]N9FEG+V!@(&1I<F5C=&]R>2!O9B!T:&4*
M("`@:6YS=&%L;&5D(&1I<W1R:6)U=&EO;BP@86YD(&UA:V4@8V]P:65S(&]F
M(&%L;"!O9B!T:&4@8V]N9FEG=7)A=&EO;@H@("!@8&1I<W1@8"!F:6QE<R!W
M:71H;W5T('1H92!@8&1I<W1@8"!S=69F:7@Z.@H*("`@("`@8V0@8V]N9FEG
M+PH@("`@("!F;W(@9F]O(&EN("HN9&ES=#L@9&\@8W`@)&9O;R!@8F%S96YA
M;64@)&9O;R`N9&ES=&`[(&1O;F4*"B`@($1O8W5M96YT871I;VX@;VX@=&AE
M(&9O<FUA="!O9B!T:&]S92!F:6QE<R!C86X@8F4@9F]U;F0@:6X@96%C:"!F
M:6QE.R!O<&5N"B`@(&5A8V@@:6X@86X@961I=&]R(&%N9"!M86ME(&-H86YG
M97,@87,@<W5G9V5S=&5D('=I=&AI;BX@(%1H92!D969A=6QT('9A;'5E<PH@
M("!A<F4@<F5A<V]N86)L92P@8G5T(&UA>2!N;W0@8F4@87!P<F]P<FEA=&4@
M9F]R('EO=7(@<VET92P@<V\@:70@:7,@8F5S="!T;PH@("!C:&5C:R!T:&5M
M(&)E9F]R92!P<F5C965D:6YG+@H*("`@66]U(&UU<W0@;&]G:6X@=&\@2&]R
M9&4@87,@82!(;W)D92!!9&UI;FES=')A=&]R('1O(&9I;FES:"!T:&4*("`@
M8V]N9FEG=7)A=&EO;B!O9B!+<F]N;VQI=&@N("!5<V4@=&AE($AO<F1E(&!@
M061M:6YI<W1R871I;VY@8"!M96YU(&ET96T@=&\*("`@9V5T('1O('1H92!A
M9&UI;FES=')A=&EO;B!P86=E+"!A;F0@=&AE;B!C;&EC:R!O;B!T:&4@8&!#
M;VYF:6=U<F%T:6]N8&`*("`@:6-O;B!T;R!G970@=&AE(&-O;F9I9W5R871I
M;VX@<&%G92X@(%-E;&5C="!@8$-A;&5N9&%R8&`@9G)O;2!T:&4@<V5L96-T
M:6]N"B`@(&QI<W0@;V8@87!P;&EC871I;VYS+B`@1FEL;"!I;B!O<B!C:&%N
M9V4@86YY(&-O;F9I9W5R871I;VX@=F%L=65S(&%S"B`@(&YE961E9"X@(%=H
M96X@9&]N92!C;&EC:R!O;B!@8$=E;F5R871E($-A;&5N9&%R($-O;F9I9W5R
M871I;VY@8"!T;R!G96YE<F%T90H@("!T:&4@8&!C;VYF+G!H<&!@(&9I;&4N
M("!)9B!Y;W5R('=E8B!S97)V97(@9&]E<VXG="!H879E('=R:71E('!E<FUI
M<W-I;VYS"B`@('1O('1H92!+<F]N;VQI=&@@8V]N9FEG=7)A=&EO;B!D:7)E
M8W1O<GD@;W(@9FEL92P@:70@=VEL;"!N;W0@8F4@86)L92!T;PH@("!W<FET
M92!T:&4@9FEL92X@($EN('1H:7,@8V%S92P@9V\@8F%C:R!T;R!@8$-O;F9I
M9W5R871I;VY@8"!A;F0@8VAO;W-E(&]N90H@("!O9B!T:&4@;W1H97(@;65T
M:&]D<R!T;R!C<F5A=&4@=&AE(&-O;F9I9W5R871I;VX@9FEL90H@("!@8&MR
M;VYO;&ET:"]C;VYF:6<O8V]N9BYP:'!@8"X*"B`@($YO=&4@9F]R(&EN=&5R
M;F%T:6]N86P@=7-E<G,Z($YA9R!U<V5S($=.52!G971T97AT('1O('!R;W9I
M9&4@;&]C86P*("`@=')A;G-L871I;VYS(&]F('1E>'0@9&ES<&QA>65D(&)Y
M(&%P<&QI8V%T:6]N<SL@=&AE('1R86YS;&%T:6]N<R!A<F4@9F]U;F0*("`@
M:6X@=&AE('!O+R!D:7)E8W1O<GDN("!)9B!A('1R86YS;&%T:6]N(&ES(&YO
M="!Y970@879A:6QA8FQE(&9O<B!Y;W5R"B`@(&QO8V%L92`H86YD('EO=2!W
M:7-H('1O(&-R96%T92!O;F4I+"!S964@=&AE(&!@:&]R9&4O<&\O4D5!1$U%
M8&`@9FEL92P@;W(*("`@:68@>6]U)W)E(&AA=FEN9R!T<F]U8FQE('5S:6YG
M(&$@<')O=FED960@=')A;G-L871I;VXL('!L96%S92!S964@=&AE"B`@(&!H
M;W)D92]D;V-S+U1204Y33$%424].4V!?(&9I;&4@9F]R(&EN<W1R=6-T:6]N
M<RX*"C0N(%1E<W1I;F<@2W)O;F]L:71H"@H@("!5<V4@2W)O;F]L:71H('1O
M(&-R96%T92P@;6]D:69Y+"!A;F0@9&5L971E(&5V96YT<RX@5&5S="!A="!L
M96%S="!T:&4*("`@9F]L;&]W:6YG.@H*("`@+2!#<F5A=&EN9R!A(&YE=R!E
M=F5N=`H@("`M($-R96%T:6YG(&$@<F5C=7)R:6YG(&5V96YT"B`@("T@36]D
M:69Y:6YG(&%N(&5V96YT"B`@("T@1&5L971I;F<@86X@979E;G0*"@I/8G1A
M:6YI;F<@4W5P<&]R=`H]/3T]/3T]/3T]/3T]/3T]/0H*268@>6]U(&5N8V]U
M;G1E<B!P<F]B;&5M<R!W:71H($MR;VYO;&ET:"P@:&5L<"!I<R!A=F%I;&%B
M;&4A"@I4:&4@2&]R9&4@1G)E<75E;G1L>2!!<VME9"!1=65S=&EO;G,@3&ES
M="`H1D%1*2P@879A:6QA8FQE(&]N('1H92!796(@870*"B`@:'1T<#HO+W=W
M=RYH;W)D92YO<F<O9F%Q+PH*5&AE($AO<F1E(%!R;VIE8W0@<G5N<R!A(&YU
M;6)E<B!O9B!M86EL:6YG(&QI<W1S+"!F;W(@:6YD:79I9'5A;"!A<'!L:6-A
M=&EO;G,*86YD(&9O<B!I<W-U97,@<F5L871I;F<@=&\@=&AE('!R;VIE8W0@
M87,@82!W:&]L92X@($EN9F]R;6%T:6]N+"!A<F-H:79E<RP@86YD"G-U8G-C
M<FEP=&EO;B!I;F9O<FUA=&EO;B!C86X@8F4@9F]U;F0@870*"B`@:'1T<#HO
M+W=W=RYH;W)D92YO<F<O;6%I;"\*"DQA<W1L>2P@2&]R9&4@9&5V96QO<&5R
M<RP@8V]N=')I8G5T;W)S(&%N9"!U<V5R<R!A;'-O(&UA:V4@;V-C87-I;VYA
M;`IA<'!E87)A;F-E<R!O;B!)4D,L(&]N('1H92!C:&%N;F5L("-H;W)D92!O
M;B!T:&4@9G)E96YO9&4@3F5T=V]R:PHH:7)C+F9R965N;V1E+FYE="DN"@I0
M;&5A<V4@:V5E<"!I;B!M:6YD('1H870@2W)O;F]L:71H(&ES(&9R964@<V]F
M='=A<F4@=W)I='1E;B!B>2!V;VQU;G1E97)S+@I&;W(@:6YF;W)M871I;VX@
M;VX@<F5A<V]N86)L92!S=7!P;W)T(&5X<&5C=&%T:6]N<RP@<&QE87-E(')E
M860*"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O<W5P<&]R="YP:'`*"E1H86YK
M<R!F;W(@=7-I;F<@2W)O;F]L:71H(0H*5&AE($AO<F1E('1E86T*"@HN+B!?
M4D5!1$U%.B`_9CU214%$344N:'1M;`HN+B!?8&AO<F1E+V1O8W,O24Y35$%,
M3&`Z("XN+RXN+VAO<F1E+V1O8W,O/V8]24Y35$%,3"YH=&UL"BXN(%]@:&]R
M9&4O9&]C<R](04-+24Y'8#H@+BXO+BXO:&]R9&4O9&]C<R\_9CU(04-+24Y'
M+FAT;6P*+BX@7V!H;W)D92]D;V-S+U1204Y33$%424].4V`Z("XN+RXN+VAO
M<F1E+V1O8W,O/V8]5%)!3E-,051)3TY3+FAT;6P*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]K<F]N;VQI=&@O9&]C<R]214Q%05-%7TY/5$53````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`U,#4U`#$P-#$W,S8R-S4S`#`R,3,T,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@4F5L96%S92!F;V-U<RX@4&]S<VEB;&4@=F%L=65S.@H@*B`P("T@
M3B]!"B`J(#$@+2!);FET:6%L(&9R97-H;65A="!A;FYO=6YC96UE;G0*("H@
M,B`M($1O8W5M96YT871I;VX*("H@,R`M($-O9&4@8VQE86YU<`H@*B`T("T@
M36EN;W(@9F5A='5R92!E;FAA;F-E;65N=',*("H@-2`M($UA:F]R(&9E871U
M<F4@96YH86YC96UE;G1S"B`J(#8@+2!-:6YO<B!B=6=F:7AE<PH@*B`W("T@
M36%J;W(@8G5G9FEX97,*("H@."`M($UI;F]R('-E8W5R:71Y(&9I>&5S"B`J
M(#D@+2!-86IO<B!S96-U<FET>2!F:7AE<PH@*B\*)'1H:7,M/FYO=&5S6R=F
M;2==6R=F;V-U<R==(#T@-3L*"B\J($UA:6QI;F<@;&ES="!R96QE87-E(&YO
M=&5S+B`J+PHD=&AI<RT^;F]T97-;)VUL)UU;)V-H86YG97,G72`](#P\/$U,
M"E1H92!(;W)D92!496%M(&ES('!L96%S960@=&\@86YN;W5N8V4@=&AE(&9I
M;F%L(')E;&5A<V4@;V8@=&AE($MR;VYO;&ET:`I#86QE;F1A<B!!<'!L:6-A
M=&EO;B!V97)S:6]N($@S("@R+C$I+@H*2W)O;F]L:71H(&ES('1H92!(;W)D
M92!C86QE;F1A<B!A<'!L:6-A=&EO;BX@($ET('!R;W9I9&5S('=E8BUB87-E
M9`IC86QE;F1A<G,@8F%C:V5D(&)Y(&$@4U%,(&1A=&%B87-E(&]R(&$@2V]L
M86(@<V5R=F5R+B`@4W5P<&]R=&5D"F9E871U<F5S(&EN8VQU9&4@<VAA<F5D
M(&-A;&5N9&%R<RP@<F5M;W1E(&-A;&5N9&%R<RP@;65E=&EN9PIM86YA9V5M
M96YT+"!A;&%R;7,L(')E8W5R<FEN9R!E=F5N=',L(&%N9"!A('-O<&AI<W1I
M8V%T960@9&%Y+W=E96L*=FEE=R!W:&EC:"!H86YD;&5S(&%R8FET<F%R>2!N
M=6UB97)S(&]F(&]V97)L87!P:6YG(&5V96YT<RX*"DUA:F]R(&-H86YG97,@
M8V]M<&%R960@=&\@=&AE($MR;VYO;&ET:"!(,R`H,BXQ+5)#,RD@=F5R<VEO
M;B!A<F4Z"B`@("`J($%D9&5D(&=U87)D<R!A9V%I;G-T(&YO="!B96EN9R!A
M8FQE('1O('-E;&5C="!D:7-P;&%Y960@8V%L96YD87)S+@H*36%J;W(@8VAA
M;F=E<R!C;VUP87)E9"!T;R!T:&4@2W)O;F]L:71H($@S("@R+C`I('9E<G-I
M;VYS(&%R93H*("`@("H@665A<B!V:65W+@H@("`@*B!%;6%I;"!N;W1I9FEC
M871I;VYS('=H96X@979E;G1S(&AA=F4@8F5E;B!A9&1E9"!O<B!C:&%N9V5D
M+@H@("`@*B!3:&]W(&-U<G)E;G0@86QA<FUS(&EN('-I9&5B87(@;65N=2X*
M("`@("H@179E;G0@<W1A='5S(&]F(")&<F5E(BX*("`@("H@4W5B<V-R:7!T
M:6]N('-U<'!O<G0@9F]R(&-A;&5N9&%R(&-L:65N=',@;&EK92!I0V%L(&]R
M(%-U;F)I<F0N"B`@("`J($%L;&]W('1O(&9R965L>2!S970@979E;G0@>65A
M<G,N"B`@("`J(%-U<'!O<G0@;65E=&EN9R!P;&%N;FEN9R!W:71H(&-L:65N
M=',@=VET:&]U="!I5&EP+VE#86QE;F1A<B!S=7!P;W)T+@H@("`@*B!);7!R
M;W9E9"!S:61E+6)Y+7-I9&4@=FEE=W,@9F]R(&UU;'1I<&QE(&-A;&5N9&%R
M<RX*("`@("H@26UP<F]V960@86-C97-S:6)I;&ET>2X*("`@("H@26UP<F]V
M960@871T96YD965S(&EN=&5R9F%C92X*("`@("H@3F5W('1R86YS;&%T:6]N
M.B!0;W)T=6=U97-E+@H@("`@*B!#;VUP871I8FQE('=I=&@@4$A0(#4N,2X*
M("`@("H@4V5V97)A;"!+;VQA8B!R96QA=&5D(&9I>&5S+@H@("`@*B!$97!R
M96-A=&5D($U#04P@9')I=F5R+@H@("`@*B!097)M:7-S:6]N<R!T;R!R97-T
M<FEC="!N=6UB97(@;V8@979E;G1S+@H@("`@*B!3:6UP;&EF:65D(&9R964O
M8G5S>2!54DQS+@H@("`@*B!#;VUM86YD(&QI;F4@<V-R:7!T('1O(&)A=&-H
M(&EM<&]R="!I0V%L96YD87(@9&%T82X*34P["@HO*B!&<F5S:&UE870@<F5L
M96%S92!N;W1E<RP@;F]T(&UO<F4@=&AA;B`V,#`@8VAA<F%C=&5R<RX@*B\*
M)'1H:7,M/FYO=&5S6R=F;2==6R=C:&%N9V5S)UT@/2`\/#Q&30I!(%EE87(@
M=FEE=RP@96UA:6P@;F]T:69I8V%T:6]N<R!F;W(@8VAA;F=E9"!E=F5N=',L
M(&%N(&5V96YT('-T871U<R!O9B!&<F5E+"!S=6)S8W)I<'1I;VX@<W5P<&]R
M="!F;W(@9&5S:W1O<"!C86QE;F1A<B!C;&EE;G1S(&%N9"!S=7!P;W)T(&9O
M<B!M965T:6YG('!L86YN:6YG('=I=&@@8VQI96YT<R!W:71H;W5T(&E4:7`O
M:4-A;&5N9&%R('-U<'!O<G0@:&%V92!B965N(&%D9&5D+B!#=7)R96YT(&%L
M87)M<R!A<F4@9&ES<&QA>65D(&EN('1H92!S:61E8F%R(&UE;G4N(%1H92!S
M:61E+6)Y+7-I9&4@=FEE=W,@9F]R(&UU;'1I<&QE(&-A;&5N9&%R<RP@86-C
M97-S:6)I;&ET>2!A;F0@=&AE(&%T=&5N9&5E<R!I;G1E<F9A8V4@:&%V92!B
M965N(&EM<')O=F5D+B!+;VQA8B!R96QA=&5D(&)U9W,@:&%V92!B965N(&9I
M>&5D+B!4:&4@34-!3"!D<FEV97(@:&%S(&)E96X@9&5P<F5C871E9"X@1G)E
M92]B=7-Y(%523',@:&%V92!B965N('-I;7!L:69I960N(%!E<FUI<W-I;VYS
M('1O(')E<W1R:6-T(&YU;6)E<B!O9B!E=F5N=',@86YD(&$@<V-R:7!T('1O
M(&EM<&]R="!I0V%L96YD87(@9&%T82!H879E(&)E96X@861D960N"D9-.PH*
M)'1H:7,M/FYO=&5S6R=N86UE)UT@/2`G2W)O;F]L:71H)SL*)'1H:7,M/FYO
M=&5S6R=F;2==6R=P<F]J96-T)UT@/2`G:W)O;F]L:71H)SL*)'1H:7,M/FYO
M=&5S6R=F;2==6R=B<F%N8V@G72`]("=(;W)D92`S)SL*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]D;V-S
M+U1/1$\`````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#,U-S8`,3`T,3<S-C(W-3,`,#(P,#8U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H@2W)O;F]L:71H($1E=F5L;W!M96YT(%1/1$\@3&ES=`H]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T
M93H@("`D1&%T93H@,C`P-2\Q,"\Q."`Q,CHR-SHR.2`D"CI2979I<VEO;CH@
M("`@("`D4F5V:7-I;VXZ(#$N,34N-"XR("0*.D-O;G1A8W0Z("`@("`@(&MR
M;VYO;&ET:$!L:7-T<RYH;W)D92YO<F<*"BT@1FEN:7-H('-C<FEP=',O<F5M
M:6YD97)S+G!H<"!T;R!F;&5X:6)L>2!S96YD(')E;6EN9&5R<RX*"BT@3F5E
M9"!A(%5)(&9O<B!D96QE=&EN9R!E>&-E<'1I;VYS('1O(&$@<F5C=7)R:6YG
M(&5V96YT+@H*+2!!('-E<&%R871E(&QO8V%T:6]N('1O('-E;&5C="!T:&4@
M8V%L96YD87)S('1O(&1I<W!L87D@:6X@=&AE('-U;6UA<GDN"B`@0W5R<F5N
M=&QY('1H92!S=6UM87)Y(&1I<W!L87ES('=H870@979E<B!Y;W4@:&%D('-E
M;&5C=&5D('1H92!L87-T('1I;64@>6]U"B`@=V5R92!I;B!+<F]N;VQI=&@N
M"@HM($1R;W`@9&]W;B!L:7-T('1O('-E;&5C="!F<F]M(&QO8V%L('5S97)S
M(&]R(&-A;&5N9&%R<R!I;B!T:&4@871T96YD965S('9I97<N"@HM(%1H92!O
M<'1I;VX@=&\@;F]T(&AA=F4@86YY('!E<G-O;F%L(&-A;&5N9&%R<R!D:7-P
M;&%Y960L(&YO=R!W:71H(')E;6]T90H@(&-A;&5N9&%R<R!T:&ES('=O=6QD
M(&)E(&$@9&5S:7)A8FQE(&]P=&EO;BX*"BT@4F5M;W9E('1H92!A<W-U;7!T
M:6]N('1H870@96%C:"!C86QE;F1A<B!I<R!U<VEN9R!T:&4@<V%M92!B86-K
M96YD+B!)9&5A;&QY"B`@:70@<VAO=6QD(&)E('!O<W-I8FQE('1O(&AA=F4@
M82!L;V-A;"!C86QE;F1A<B!U<VEN9R!S<6P@;W(@:V]L86(@86YD(&$*("!R
M96UO=&4@8V%L96YD87(@=7-I;F<@86YO=&AE<B!D<FEV97(@*&5G('=C87`@
M;W(@=VAA=&5V97(@;6]Z:6QL82!U<V5S*2X*"BT@1')I=F5R<R!S:&]U;&0@
M:&%N9&QE('1H92!P97)M:7-S:6]N<R!C:&5C:W,@:6YS=&5A9"!O9B!A8V-E
M<W-I;F<@<VAA<F5S"B`@9&ER96-T;'D@*&]U='-I9&4@9')I=F5R<RD@=&\@
M9V5T('1H92!P97)M:7-S:6]N<R!F;W(@86X@979E;G0@;W(@8V%L96YD87(N
M"B`@3VYE(&1A>2!W92!M:6=H="!H879E(&$@8V%L96YD87(@8F%C:V5N9"!T
M:&%T(&MN;W=S(&%B;W5T('!E<FUI<W-I;VYS+@H*+2!!;&QO=R!P=6)L:7-H
M:6YG(&-A;&5N9&%R<R!T;R!A(')E;6]T92!S:71E(&%S(&E#86QE;F1A<B!F
M:6QE<RX*"BT@4V%V:6YG(&]F(&EN9&EV:61U86P@979E;G1S(&%S("YI8W,@
M9FEL97,N"@HM(%-U<'!O<G0@9F]R('-E87)C:&EN9R!A(&QO8V%L(&9I;&4@
M<WES=&5M(&9O<B!F<F5E8G5S>2!I;F9O+@H*+2!3=7!P;W)T(&9O<B!S96%R
M8VAI;F<@9G)E96)U<WDN;V9F:6-E+FUI8W)O<V]F="YC;VT@9F]R(&9R965B
M=7-Y(&EN9F\N"@HM($%U=&]M871I8V%L;'D@;&]C871E(&$@;65E=&EN9R!T
M:6UE+@H*+2!!9&0@82!Q=6EC:R!T;V]L(&9O<B!P;&%N;FEN9R!M965T:6YG
M(&%G96YD87,N"@HM($AA;F1L92!R97-O=7)C92!S8VAE9'5L:6YG+VUA;F%G
M96UE;G0@<V]M96AO=RP@96ET:&5R('!E<BUC86QE;F1A<B!O<B!B>0H@(&MI
M;F1S(&]F(&-A;&5N9&%R<RP@:6YC;'5D:6YG(')U;&5S(&9O<B!W:&5N(&]V
M97)L87!P:6YG(&%P<&]I;G1M96YT<R!A<F4*("!A;&QO=V5D+"!E=&,N"@HM
M(&QI8B]$<FEV97(O:6-A;"YP:'`@<VAO=6QD(&)E('1H92!C96YT<F%L(&QO
M8V%T:6]N(&9O<B!R96UO=&4@8V%L96YD87(*("!S=7!P;W)T+B!.965D<R!T
M;R!B92!F:6YI<VAE9"X*"BT@5VAE;B!E9&ET:6YG(&$@<F5C=7)R:6YG(&5V
M96YT+"!T:&4@9&%T92!F<F]M('=H:6-H('1H92!E9&ET(&)U='1O;B!W87,*
M("!C;&EC:V5D('-H;W5L9"!B92!R969L96-T960@:6X@=&AE(&5D:70@<V-R
M965N+@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O9&]C<R]#3U!9
M24Y'````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0S,3`U
M`#$P-#$W,S8R-S4S`#`R,#0R,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````)"2`@("!'3E4@1T5.15)!3"!054),24,@3$E#
M14Y310H)"2`@("`@("!697)S:6]N(#(L($IU;F4@,3DY,0H*($-O<'ER:6=H
M="`H0RD@,3DX.2P@,3DY,2!&<F5E(%-O9G1W87)E($9O=6YD871I;VXL($EN
M8RX*("`@("`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+"!-
M02`@,#(Q,3$M,3,P-R`@55-!"B!%=F5R>6]N92!I<R!P97)M:71T960@=&\@
M8V]P>2!A;F0@9&ES=')I8G5T92!V97)B871I;2!C;W!I97,*(&]F('1H:7,@
M;&EC96YS92!D;V-U;65N="P@8G5T(&-H86YG:6YG(&ET(&ES(&YO="!A;&QO
M=V5D+@H*"0D)("`@(%!R96%M8FQE"@H@(%1H92!L:6-E;G-E<R!F;W(@;6]S
M="!S;V9T=V%R92!A<F4@9&5S:6=N960@=&\@=&%K92!A=V%Y('EO=7(*9G)E
M961O;2!T;R!S:&%R92!A;F0@8VAA;F=E(&ET+B`@0GD@8V]N=')A<W0L('1H
M92!'3E4@1V5N97)A;"!0=6)L:6,*3&EC96YS92!I<R!I;G1E;F1E9"!T;R!G
M=6%R86YT964@>6]U<B!F<F5E9&]M('1O('-H87)E(&%N9"!C:&%N9V4@9G)E
M90IS;V9T=V%R92TM=&\@;6%K92!S=7)E('1H92!S;V9T=V%R92!I<R!F<F5E
M(&9O<B!A;&P@:71S('5S97)S+B`@5&AI<PI'96YE<F%L(%!U8FQI8R!,:6-E
M;G-E(&%P<&QI97,@=&\@;6]S="!O9B!T:&4@1G)E92!3;V9T=V%R90I&;W5N
M9&%T:6]N)W,@<V]F='=A<F4@86YD('1O(&%N>2!O=&AE<B!P<F]G<F%M('=H
M;W-E(&%U=&AO<G,@8V]M;6ET('1O"G5S:6YG(&ET+B`@*%-O;64@;W1H97(@
M1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N('-O9G1W87)E(&ES(&-O=F5R960@
M8GD*=&AE($=.52!,:6)R87)Y($=E;F5R86P@4'5B;&EC($QI8V5N<V4@:6YS
M=&5A9"XI("!9;W4@8V%N(&%P<&QY(&ET('1O"GEO=7(@<')O9W)A;7,L('1O
M;RX*"B`@5VAE;B!W92!S<&5A:R!O9B!F<F5E('-O9G1W87)E+"!W92!A<F4@
M<F5F97)R:6YG('1O(&9R965D;VTL(&YO=`IP<FEC92X@($]U<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E<R!A<F4@9&5S:6=N960@=&\@;6%K92!S=7)E('1H
M870@>6]U"FAA=F4@=&AE(&9R965D;VT@=&\@9&ES=')I8G5T92!C;W!I97,@
M;V8@9G)E92!S;V9T=V%R92`H86YD(&-H87)G92!F;W(*=&AI<R!S97)V:6-E
M(&EF('EO=2!W:7-H*2P@=&AA="!Y;W4@<F5C96EV92!S;W5R8V4@8V]D92!O
M<B!C86X@9V5T(&ET"FEF('EO=2!W86YT(&ET+"!T:&%T('EO=2!C86X@8VAA
M;F=E('1H92!S;V9T=V%R92!O<B!U<V4@<&EE8V5S(&]F(&ET"FEN(&YE=R!F
M<F5E('!R;V=R86US.R!A;F0@=&AA="!Y;W4@:VYO=R!Y;W4@8V%N(&1O('1H
M97-E('1H:6YG<RX*"B`@5&\@<')O=&5C="!Y;W5R(')I9VAT<RP@=V4@;F5E
M9"!T;R!M86ME(')E<W1R:6-T:6]N<R!T:&%T(&9O<F)I9`IA;GEO;F4@=&\@
M9&5N>2!Y;W4@=&AE<V4@<FEG:'1S(&]R('1O(&%S:R!Y;W4@=&\@<W5R<F5N
M9&5R('1H92!R:6=H=',N"E1H97-E(')E<W1R:6-T:6]N<R!T<F%N<VQA=&4@
M=&\@8V5R=&%I;B!R97-P;VYS:6)I;&ET:65S(&9O<B!Y;W4@:68@>6]U"F1I
M<W1R:6)U=&4@8V]P:65S(&]F('1H92!S;V9T=V%R92P@;W(@:68@>6]U(&UO
M9&EF>2!I="X*"B`@1F]R(&5X86UP;&4L(&EF('EO=2!D:7-T<FEB=71E(&-O
M<&EE<R!O9B!S=6-H(&$@<')O9W)A;2P@=VAE=&AE<@IG<F%T:7,@;W(@9F]R
M(&$@9F5E+"!Y;W4@;75S="!G:79E('1H92!R96-I<&EE;G1S(&%L;"!T:&4@
M<FEG:'1S('1H870*>6]U(&AA=F4N("!9;W4@;75S="!M86ME('-U<F4@=&AA
M="!T:&5Y+"!T;V\L(')E8V5I=F4@;W(@8V%N(&=E="!T:&4*<V]U<F-E(&-O
M9&4N("!!;F0@>6]U(&UU<W0@<VAO=R!T:&5M('1H97-E('1E<FUS('-O('1H
M97D@:VYO=R!T:&5I<@IR:6=H=',N"@H@(%=E('!R;W1E8W0@>6]U<B!R:6=H
M=',@=VET:"!T=V\@<W1E<',Z("@Q*2!C;W!Y<FEG:'0@=&AE('-O9G1W87)E
M+"!A;F0**#(I(&]F9F5R('EO=2!T:&ES(&QI8V5N<V4@=VAI8V@@9VEV97,@
M>6]U(&QE9V%L('!E<FUI<W-I;VX@=&\@8V]P>2P*9&ES=')I8G5T92!A;F0O
M;W(@;6]D:69Y('1H92!S;V9T=V%R92X*"B`@06QS;RP@9F]R(&5A8V@@875T
M:&]R)W,@<')O=&5C=&EO;B!A;F0@;W5R<RP@=V4@=V%N="!T;R!M86ME(&-E
M<G1A:6X*=&AA="!E=F5R>6]N92!U;F1E<G-T86YD<R!T:&%T('1H97)E(&ES
M(&YO('=A<G)A;G1Y(&9O<B!T:&ES(&9R964*<V]F='=A<F4N("!)9B!T:&4@
M<V]F='=A<F4@:7,@;6]D:69I960@8GD@<V]M96]N92!E;'-E(&%N9"!P87-S
M960@;VXL('=E"G=A;G0@:71S(')E8VEP:65N=',@=&\@:VYO=R!T:&%T('=H
M870@=&AE>2!H879E(&ES(&YO="!T:&4@;W)I9VEN86PL('-O"G1H870@86YY
M('!R;V)L96US(&EN=')O9'5C960@8GD@;W1H97)S('=I;&P@;F]T(')E9FQE
M8W0@;VX@=&AE(&]R:6=I;F%L"F%U=&AO<G,G(')E<'5T871I;VYS+@H*("!&
M:6YA;&QY+"!A;GD@9G)E92!P<F]G<F%M(&ES('1H<F5A=&5N960@8V]N<W1A
M;G1L>2!B>2!S;V9T=V%R90IP871E;G1S+B`@5V4@=VES:"!T;R!A=F]I9"!T
M:&4@9&%N9V5R('1H870@<F5D:7-T<FEB=71O<G,@;V8@82!F<F5E"G!R;V=R
M86T@=VEL;"!I;F1I=FED=6%L;'D@;V)T86EN('!A=&5N="!L:6-E;G-E<RP@
M:6X@969F96-T(&UA:VEN9R!T:&4*<')O9W)A;2!P<F]P<FEE=&%R>2X@(%1O
M('!R979E;G0@=&AI<RP@=V4@:&%V92!M861E(&ET(&-L96%R('1H870@86YY
M"G!A=&5N="!M=7-T(&)E(&QI8V5N<V5D(&9O<B!E=F5R>6]N92=S(&9R964@
M=7-E(&]R(&YO="!L:6-E;G-E9"!A="!A;&PN"@H@(%1H92!P<F5C:7-E('1E
M<FUS(&%N9"!C;VYD:71I;VYS(&9O<B!C;W!Y:6YG+"!D:7-T<FEB=71I;VX@
M86YD"FUO9&EF:6-A=&EO;B!F;VQL;W<N"@P*"0D@("`@1TY5($=%3D5204P@
M4%5"3$E#($Q)0T5.4T4*("`@5$5235,@04Y$($-/3D1)5$E/3E,@1D]2($-/
M4%E)3D<L($1)4U1224)55$E/3B!!3D0@34]$249)0T%424]."@H@(#`N(%1H
M:7,@3&EC96YS92!A<'!L:65S('1O(&%N>2!P<F]G<F%M(&]R(&]T:&5R('=O
M<FL@=VAI8V@@8V]N=&%I;G,*82!N;W1I8V4@<&QA8V5D(&)Y('1H92!C;W!Y
M<FEG:'0@:&]L9&5R('-A>6EN9R!I="!M87D@8F4@9&ES=')I8G5T960*=6YD
M97(@=&AE('1E<FUS(&]F('1H:7,@1V5N97)A;"!0=6)L:6,@3&EC96YS92X@
M(%1H92`B4')O9W)A;2(L(&)E;&]W+`IR969E<G,@=&\@86YY('-U8V@@<')O
M9W)A;2!O<B!W;W)K+"!A;F0@82`B=V]R:R!B87-E9"!O;B!T:&4@4')O9W)A
M;2(*;65A;G,@96ET:&5R('1H92!0<F]G<F%M(&]R(&%N>2!D97)I=F%T:79E
M('=O<FL@=6YD97(@8V]P>7)I9VAT(&QA=SH*=&AA="!I<R!T;R!S87DL(&$@
M=V]R:R!C;VYT86EN:6YG('1H92!0<F]G<F%M(&]R(&$@<&]R=&EO;B!O9B!I
M="P*96ET:&5R('9E<F)A=&EM(&]R('=I=&@@;6]D:69I8V%T:6]N<R!A;F0O
M;W(@=')A;G-L871E9"!I;G1O(&%N;W1H97(*;&%N9W5A9V4N("`H2&5R96EN
M869T97(L('1R86YS;&%T:6]N(&ES(&EN8VQU9&5D('=I=&AO=70@;&EM:71A
M=&EO;B!I;@IT:&4@=&5R;2`B;6]D:69I8V%T:6]N(BXI("!%86-H(&QI8V5N
M<V5E(&ES(&%D9')E<W-E9"!A<R`B>6]U(BX*"D%C=&EV:71I97,@;W1H97(@
M=&AA;B!C;W!Y:6YG+"!D:7-T<FEB=71I;VX@86YD(&UO9&EF:6-A=&EO;B!A
M<F4@;F]T"F-O=F5R960@8GD@=&AI<R!,:6-E;G-E.R!T:&5Y(&%R92!O=71S
M:61E(&ET<R!S8V]P92X@(%1H92!A8W0@;V8*<G5N;FEN9R!T:&4@4')O9W)A
M;2!I<R!N;W0@<F5S=')I8W1E9"P@86YD('1H92!O=71P=70@9G)O;2!T:&4@
M4')O9W)A;0II<R!C;W9E<F5D(&]N;'D@:68@:71S(&-O;G1E;G1S(&-O;G-T
M:71U=&4@82!W;W)K(&)A<V5D(&]N('1H90I0<F]G<F%M("AI;F1E<&5N9&5N
M="!O9B!H879I;F<@8F5E;B!M861E(&)Y(')U;FYI;F<@=&AE(%!R;V=R86TI
M+@I7:&5T:&5R('1H870@:7,@=')U92!D97!E;F1S(&]N('=H870@=&AE(%!R
M;V=R86T@9&]E<RX*"B`@,2X@66]U(&UA>2!C;W!Y(&%N9"!D:7-T<FEB=71E
M('9E<F)A=&EM(&-O<&EE<R!O9B!T:&4@4')O9W)A;2=S"G-O=7)C92!C;V1E
M(&%S('EO=2!R96-E:79E(&ET+"!I;B!A;GD@;65D:75M+"!P<F]V:61E9"!T
M:&%T('EO=0IC;VYS<&EC=6]U<VQY(&%N9"!A<'!R;W!R:6%T96QY('!U8FQI
M<V@@;VX@96%C:"!C;W!Y(&%N(&%P<')O<')I871E"F-O<'ER:6=H="!N;W1I
M8V4@86YD(&1I<V-L86EM97(@;V8@=V%R<F%N='D[(&ME97`@:6YT86-T(&%L
M;"!T:&4*;F]T:6-E<R!T:&%T(')E9F5R('1O('1H:7,@3&EC96YS92!A;F0@
M=&\@=&AE(&%B<V5N8V4@;V8@86YY('=A<G)A;G1Y.PIA;F0@9VEV92!A;GD@
M;W1H97(@<F5C:7!I96YT<R!O9B!T:&4@4')O9W)A;2!A(&-O<'D@;V8@=&AI
M<R!,:6-E;G-E"F%L;VYG('=I=&@@=&AE(%!R;V=R86TN"@I9;W4@;6%Y(&-H
M87)G92!A(&9E92!F;W(@=&AE('!H>7-I8V%L(&%C="!O9B!T<F%N<V9E<G)I
M;F<@82!C;W!Y+"!A;F0*>6]U(&UA>2!A="!Y;W5R(&]P=&EO;B!O9F9E<B!W
M87)R86YT>2!P<F]T96-T:6]N(&EN(&5X8VAA;F=E(&9O<B!A(&9E92X*"B`@
M,BX@66]U(&UA>2!M;V1I9GD@>6]U<B!C;W!Y(&]R(&-O<&EE<R!O9B!T:&4@
M4')O9W)A;2!O<B!A;GD@<&]R=&EO;@IO9B!I="P@=&AU<R!F;W)M:6YG(&$@
M=V]R:R!B87-E9"!O;B!T:&4@4')O9W)A;2P@86YD(&-O<'D@86YD"F1I<W1R
M:6)U=&4@<W5C:"!M;V1I9FEC871I;VYS(&]R('=O<FL@=6YD97(@=&AE('1E
M<FUS(&]F(%-E8W1I;VX@,0IA8F]V92P@<')O=FED960@=&AA="!Y;W4@86QS
M;R!M965T(&%L;"!O9B!T:&5S92!C;VYD:71I;VYS.@H*("`@(&$I(%EO=2!M
M=7-T(&-A=7-E('1H92!M;V1I9FEE9"!F:6QE<R!T;R!C87)R>2!P<F]M:6YE
M;G0@;F]T:6-E<PH@("`@<W1A=&EN9R!T:&%T('EO=2!C:&%N9V5D('1H92!F
M:6QE<R!A;F0@=&AE(&1A=&4@;V8@86YY(&-H86YG92X*"B`@("!B*2!9;W4@
M;75S="!C875S92!A;GD@=V]R:R!T:&%T('EO=2!D:7-T<FEB=71E(&]R('!U
M8FQI<V@L('1H870@:6X*("`@('=H;VQE(&]R(&EN('!A<G0@8V]N=&%I;G,@
M;W(@:7,@9&5R:79E9"!F<F]M('1H92!0<F]G<F%M(&]R(&%N>0H@("`@<&%R
M="!T:&5R96]F+"!T;R!B92!L:6-E;G-E9"!A<R!A('=H;VQE(&%T(&YO(&-H
M87)G92!T;R!A;&P@=&AI<F0*("`@('!A<G1I97,@=6YD97(@=&AE('1E<FUS
M(&]F('1H:7,@3&EC96YS92X*"B`@("!C*2!)9B!T:&4@;6]D:69I960@<')O
M9W)A;2!N;W)M86QL>2!R96%D<R!C;VUM86YD<R!I;G1E<F%C=&EV96QY"B`@
M("!W:&5N(')U;BP@>6]U(&UU<W0@8V%U<V4@:70L('=H96X@<W1A<G1E9"!R
M=6YN:6YG(&9O<B!S=6-H"B`@("!I;G1E<F%C=&EV92!U<V4@:6X@=&AE(&UO
M<W0@;W)D:6YA<GD@=V%Y+"!T;R!P<FEN="!O<B!D:7-P;&%Y(&%N"B`@("!A
M;FYO=6YC96UE;G0@:6YC;'5D:6YG(&%N(&%P<')O<')I871E(&-O<'ER:6=H
M="!N;W1I8V4@86YD(&$*("`@(&YO=&EC92!T:&%T('1H97)E(&ES(&YO('=A
M<G)A;G1Y("AO<B!E;'-E+"!S87EI;F<@=&AA="!Y;W4@<')O=FED90H@("`@
M82!W87)R86YT>2D@86YD('1H870@=7-E<G,@;6%Y(')E9&ES=')I8G5T92!T
M:&4@<')O9W)A;2!U;F1E<@H@("`@=&AE<V4@8V]N9&ET:6]N<RP@86YD('1E
M;&QI;F<@=&AE('5S97(@:&]W('1O('9I97<@82!C;W!Y(&]F('1H:7,*("`@
M($QI8V5N<V4N("`H17AC97!T:6]N.B!I9B!T:&4@4')O9W)A;2!I='-E;&8@
M:7,@:6YT97)A8W1I=F4@8G5T"B`@("!D;V5S(&YO="!N;W)M86QL>2!P<FEN
M="!S=6-H(&%N(&%N;F]U;F-E;65N="P@>6]U<B!W;W)K(&)A<V5D(&]N"B`@
M("!T:&4@4')O9W)A;2!I<R!N;W0@<F5Q=6ER960@=&\@<')I;G0@86X@86YN
M;W5N8V5M96YT+BD*#`I4:&5S92!R97%U:7)E;65N=',@87!P;'D@=&\@=&AE
M(&UO9&EF:65D('=O<FL@87,@82!W:&]L92X@($EF"FED96YT:69I86)L92!S
M96-T:6]N<R!O9B!T:&%T('=O<FL@87)E(&YO="!D97)I=F5D(&9R;VT@=&AE
M(%!R;V=R86TL"F%N9"!C86X@8F4@<F5A<V]N86)L>2!C;VYS:61E<F5D(&EN
M9&5P96YD96YT(&%N9"!S97!A<F%T92!W;W)K<R!I;@IT:&5M<V5L=F5S+"!T
M:&5N('1H:7,@3&EC96YS92P@86YD(&ET<R!T97)M<RP@9&\@;F]T(&%P<&QY
M('1O('1H;W-E"G-E8W1I;VYS('=H96X@>6]U(&1I<W1R:6)U=&4@=&AE;2!A
M<R!S97!A<F%T92!W;W)K<RX@($)U="!W:&5N('EO=0ID:7-T<FEB=71E('1H
M92!S86UE('-E8W1I;VYS(&%S('!A<G0@;V8@82!W:&]L92!W:&EC:"!I<R!A
M('=O<FL@8F%S960*;VX@=&AE(%!R;V=R86TL('1H92!D:7-T<FEB=71I;VX@
M;V8@=&AE('=H;VQE(&UU<W0@8F4@;VX@=&AE('1E<FUS(&]F"G1H:7,@3&EC
M96YS92P@=VAO<V4@<&5R;6ES<VEO;G,@9F]R(&]T:&5R(&QI8V5N<V5E<R!E
M>'1E;F0@=&\@=&AE"F5N=&ER92!W:&]L92P@86YD('1H=7,@=&\@96%C:"!A
M;F0@979E<GD@<&%R="!R96=A<F1L97-S(&]F('=H;R!W<F]T92!I="X*"E1H
M=7,L(&ET(&ES(&YO="!T:&4@:6YT96YT(&]F('1H:7,@<V5C=&EO;B!T;R!C
M;&%I;2!R:6=H=',@;W(@8V]N=&5S=`IY;W5R(')I9VAT<R!T;R!W;W)K('=R
M:71T96X@96YT:7)E;'D@8GD@>6]U.R!R871H97(L('1H92!I;G1E;G0@:7,@
M=&\*97AE<F-I<V4@=&AE(')I9VAT('1O(&-O;G1R;VP@=&AE(&1I<W1R:6)U
M=&EO;B!O9B!D97)I=F%T:79E(&]R"F-O;&QE8W1I=F4@=V]R:W,@8F%S960@
M;VX@=&AE(%!R;V=R86TN"@I);B!A9&1I=&EO;BP@;65R92!A9V=R96=A=&EO
M;B!O9B!A;F]T:&5R('=O<FL@;F]T(&)A<V5D(&]N('1H92!0<F]G<F%M"G=I
M=&@@=&AE(%!R;V=R86T@*&]R('=I=&@@82!W;W)K(&)A<V5D(&]N('1H92!0
M<F]G<F%M*2!O;B!A('9O;'5M92!O9@IA('-T;W)A9V4@;W(@9&ES=')I8G5T
M:6]N(&UE9&EU;2!D;V5S(&YO="!B<FEN9R!T:&4@;W1H97(@=V]R:R!U;F1E
M<@IT:&4@<V-O<&4@;V8@=&AI<R!,:6-E;G-E+@H*("`S+B!9;W4@;6%Y(&-O
M<'D@86YD(&1I<W1R:6)U=&4@=&AE(%!R;V=R86T@*&]R(&$@=V]R:R!B87-E
M9"!O;B!I="P*=6YD97(@4V5C=&EO;B`R*2!I;B!O8FIE8W0@8V]D92!O<B!E
M>&5C=71A8FQE(&9O<FT@=6YD97(@=&AE('1E<FUS(&]F"E-E8W1I;VYS(#$@
M86YD(#(@86)O=F4@<')O=FED960@=&AA="!Y;W4@86QS;R!D;R!O;F4@;V8@
M=&AE(&9O;&QO=VEN9SH*"B`@("!A*2!!8V-O;7!A;GD@:70@=VET:"!T:&4@
M8V]M<&QE=&4@8V]R<F5S<&]N9&EN9R!M86-H:6YE+7)E861A8FQE"B`@("!S
M;W5R8V4@8V]D92P@=VAI8V@@;75S="!B92!D:7-T<FEB=71E9"!U;F1E<B!T
M:&4@=&5R;7,@;V8@4V5C=&EO;G,*("`@(#$@86YD(#(@86)O=F4@;VX@82!M
M961I=6T@8W5S=&]M87)I;'D@=7-E9"!F;W(@<V]F='=A<F4@:6YT97)C:&%N
M9V4[(&]R+`H*("`@(&(I($%C8V]M<&%N>2!I="!W:71H(&$@=W)I='1E;B!O
M9F9E<BP@=F%L:60@9F]R(&%T(&QE87-T('1H<F5E"B`@("!Y96%R<RP@=&\@
M9VEV92!A;GD@=&AI<F0@<&%R='DL(&9O<B!A(&-H87)G92!N;R!M;W)E('1H
M86X@>6]U<@H@("`@8V]S="!O9B!P:'ES:6-A;&QY('!E<F9O<FUI;F<@<V]U
M<F-E(&1I<W1R:6)U=&EO;BP@82!C;VUP;&5T90H@("`@;6%C:&EN92UR96%D
M86)L92!C;W!Y(&]F('1H92!C;W)R97-P;VYD:6YG('-O=7)C92!C;V1E+"!T
M;R!B90H@("`@9&ES=')I8G5T960@=6YD97(@=&AE('1E<FUS(&]F(%-E8W1I
M;VYS(#$@86YD(#(@86)O=F4@;VX@82!M961I=6T*("`@(&-U<W1O;6%R:6QY
M('5S960@9F]R('-O9G1W87)E(&EN=&5R8VAA;F=E.R!O<BP*"B`@("!C*2!!
M8V-O;7!A;GD@:70@=VET:"!T:&4@:6YF;W)M871I;VX@>6]U(')E8V5I=F5D
M(&%S('1O('1H92!O9F9E<@H@("`@=&\@9&ES=')I8G5T92!C;W)R97-P;VYD
M:6YG('-O=7)C92!C;V1E+B`@*%1H:7,@86QT97)N871I=F4@:7,*("`@(&%L
M;&]W960@;VYL>2!F;W(@;F]N8V]M;65R8VEA;"!D:7-T<FEB=71I;VX@86YD
M(&]N;'D@:68@>6]U"B`@("!R96-E:79E9"!T:&4@<')O9W)A;2!I;B!O8FIE
M8W0@8V]D92!O<B!E>&5C=71A8FQE(&9O<FT@=VET:"!S=6-H"B`@("!A;B!O
M9F9E<BP@:6X@86-C;W)D('=I=&@@4W5B<V5C=&EO;B!B(&%B;W9E+BD*"E1H
M92!S;W5R8V4@8V]D92!F;W(@82!W;W)K(&UE86YS('1H92!P<F5F97)R960@
M9F]R;2!O9B!T:&4@=V]R:R!F;W(*;6%K:6YG(&UO9&EF:6-A=&EO;G,@=&\@
M:70N("!&;W(@86X@97AE8W5T86)L92!W;W)K+"!C;VUP;&5T92!S;W5R8V4*
M8V]D92!M96%N<R!A;&P@=&AE('-O=7)C92!C;V1E(&9O<B!A;&P@;6]D=6QE
M<R!I="!C;VYT86EN<RP@<&QU<R!A;GD*87-S;V-I871E9"!I;G1E<F9A8V4@
M9&5F:6YI=&EO;B!F:6QE<RP@<&QU<R!T:&4@<V-R:7!T<R!U<V5D('1O"F-O
M;G1R;VP@8V]M<&EL871I;VX@86YD(&EN<W1A;&QA=&EO;B!O9B!T:&4@97AE
M8W5T86)L92X@($AO=V5V97(L(&%S(&$*<W!E8VEA;"!E>&-E<'1I;VXL('1H
M92!S;W5R8V4@8V]D92!D:7-T<FEB=71E9"!N965D(&YO="!I;F-L=61E"F%N
M>71H:6YG('1H870@:7,@;F]R;6%L;'D@9&ES=')I8G5T960@*&EN(&5I=&AE
M<B!S;W5R8V4@;W(@8FEN87)Y"F9O<FTI('=I=&@@=&AE(&UA:F]R(&-O;7!O
M;F5N=',@*&-O;7!I;&5R+"!K97)N96PL(&%N9"!S;R!O;BD@;V8@=&AE"F]P
M97)A=&EN9R!S>7-T96T@;VX@=VAI8V@@=&AE(&5X96-U=&%B;&4@<G5N<RP@
M=6YL97-S('1H870@8V]M<&]N96YT"FET<V5L9B!A8V-O;7!A;FEE<R!T:&4@
M97AE8W5T86)L92X*"DEF(&1I<W1R:6)U=&EO;B!O9B!E>&5C=71A8FQE(&]R
M(&]B:F5C="!C;V1E(&ES(&UA9&4@8GD@;V9F97)I;F<*86-C97-S('1O(&-O
M<'D@9G)O;2!A(&1E<VEG;F%T960@<&QA8V4L('1H96X@;V9F97)I;F<@97%U
M:79A;&5N=`IA8V-E<W,@=&\@8V]P>2!T:&4@<V]U<F-E(&-O9&4@9G)O;2!T
M:&4@<V%M92!P;&%C92!C;W5N=',@87,*9&ES=')I8G5T:6]N(&]F('1H92!S
M;W5R8V4@8V]D92P@979E;B!T:&]U9V@@=&AI<F0@<&%R=&EE<R!A<F4@;F]T
M"F-O;7!E;&QE9"!T;R!C;W!Y('1H92!S;W5R8V4@86QO;F<@=VET:"!T:&4@
M;V)J96-T(&-O9&4N"@P*("`T+B!9;W4@;6%Y(&YO="!C;W!Y+"!M;V1I9GDL
M('-U8FQI8V5N<V4L(&]R(&1I<W1R:6)U=&4@=&AE(%!R;V=R86T*97AC97!T
M(&%S(&5X<')E<W-L>2!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4N("!!
M;GD@871T96UP=`IO=&AE<G=I<V4@=&\@8V]P>2P@;6]D:69Y+"!S=6)L:6-E
M;G-E(&]R(&1I<W1R:6)U=&4@=&AE(%!R;V=R86T@:7,*=F]I9"P@86YD('=I
M;&P@875T;VUA=&EC86QL>2!T97)M:6YA=&4@>6]U<B!R:6=H=',@=6YD97(@
M=&AI<R!,:6-E;G-E+@I(;W=E=F5R+"!P87)T:65S('=H;R!H879E(')E8V5I
M=F5D(&-O<&EE<RP@;W(@<FEG:'1S+"!F<F]M('EO=2!U;F1E<@IT:&ES($QI
M8V5N<V4@=VEL;"!N;W0@:&%V92!T:&5I<B!L:6-E;G-E<R!T97)M:6YA=&5D
M('-O(&QO;F<@87,@<W5C:`IP87)T:65S(')E;6%I;B!I;B!F=6QL(&-O;7!L
M:6%N8V4N"@H@(#4N(%EO=2!A<F4@;F]T(')E<75I<F5D('1O(&%C8V5P="!T
M:&ES($QI8V5N<V4L('-I;F-E('EO=2!H879E(&YO=`IS:6=N960@:70N("!(
M;W=E=F5R+"!N;W1H:6YG(&5L<V4@9W)A;G1S('EO=2!P97)M:7-S:6]N('1O
M(&UO9&EF>2!O<@ID:7-T<FEB=71E('1H92!0<F]G<F%M(&]R(&ET<R!D97)I
M=F%T:79E('=O<FMS+B`@5&AE<V4@86-T:6]N<R!A<F4*<')O:&EB:71E9"!B
M>2!L87<@:68@>6]U(&1O(&YO="!A8V-E<'0@=&AI<R!,:6-E;G-E+B`@5&AE
M<F5F;W)E+"!B>0IM;V1I9GEI;F<@;W(@9&ES=')I8G5T:6YG('1H92!0<F]G
M<F%M("AO<B!A;GD@=V]R:R!B87-E9"!O;B!T:&4*4')O9W)A;2DL('EO=2!I
M;F1I8V%T92!Y;W5R(&%C8V5P=&%N8V4@;V8@=&AI<R!,:6-E;G-E('1O(&1O
M('-O+"!A;F0*86QL(&ET<R!T97)M<R!A;F0@8V]N9&ET:6]N<R!F;W(@8V]P
M>6EN9RP@9&ES=')I8G5T:6YG(&]R(&UO9&EF>6EN9PIT:&4@4')O9W)A;2!O
M<B!W;W)K<R!B87-E9"!O;B!I="X*"B`@-BX@16%C:"!T:6UE('EO=2!R961I
M<W1R:6)U=&4@=&AE(%!R;V=R86T@*&]R(&%N>2!W;W)K(&)A<V5D(&]N('1H
M90I0<F]G<F%M*2P@=&AE(')E8VEP:65N="!A=71O;6%T:6-A;&QY(')E8V5I
M=F5S(&$@;&EC96YS92!F<F]M('1H90IO<FEG:6YA;"!L:6-E;G-O<B!T;R!C
M;W!Y+"!D:7-T<FEB=71E(&]R(&UO9&EF>2!T:&4@4')O9W)A;2!S=6)J96-T
M('1O"G1H97-E('1E<FUS(&%N9"!C;VYD:71I;VYS+B`@66]U(&UA>2!N;W0@
M:6UP;W-E(&%N>2!F=7)T:&5R"G)E<W1R:6-T:6]N<R!O;B!T:&4@<F5C:7!I
M96YT<R<@97AE<F-I<V4@;V8@=&AE(')I9VAT<R!G<F%N=&5D(&AE<F5I;BX*
M66]U(&%R92!N;W0@<F5S<&]N<VEB;&4@9F]R(&5N9F]R8VEN9R!C;VUP;&EA
M;F-E(&)Y('1H:7)D('!A<G1I97,@=&\*=&AI<R!,:6-E;G-E+@H*("`W+B!)
M9BP@87,@82!C;VYS97%U96YC92!O9B!A(&-O=7)T(&IU9&=M96YT(&]R(&%L
M;&5G871I;VX@;V8@<&%T96YT"FEN9G)I;F=E;65N="!O<B!F;W(@86YY(&]T
M:&5R(')E87-O;B`H;F]T(&QI;6ET960@=&\@<&%T96YT(&ES<W5E<RDL"F-O
M;F1I=&EO;G,@87)E(&EM<&]S960@;VX@>6]U("AW:&5T:&5R(&)Y(&-O=7)T
M(&]R9&5R+"!A9W)E96UE;G0@;W(*;W1H97)W:7-E*2!T:&%T(&-O;G1R861I
M8W0@=&AE(&-O;F1I=&EO;G,@;V8@=&AI<R!,:6-E;G-E+"!T:&5Y(&1O(&YO
M=`IE>&-U<V4@>6]U(&9R;VT@=&AE(&-O;F1I=&EO;G,@;V8@=&AI<R!,:6-E
M;G-E+B`@268@>6]U(&-A;FYO=`ID:7-T<FEB=71E('-O(&%S('1O('-A=&ES
M9GD@<VEM=6QT86YE;W5S;'D@>6]U<B!O8FQI9V%T:6]N<R!U;F1E<B!T:&ES
M"DQI8V5N<V4@86YD(&%N>2!O=&AE<B!P97)T:6YE;G0@;V)L:6=A=&EO;G,L
M('1H96X@87,@82!C;VYS97%U96YC92!Y;W4*;6%Y(&YO="!D:7-T<FEB=71E
M('1H92!0<F]G<F%M(&%T(&%L;"X@($9O<B!E>&%M<&QE+"!I9B!A('!A=&5N
M=`IL:6-E;G-E('=O=6QD(&YO="!P97)M:70@<F]Y86QT>2UF<F5E(')E9&ES
M=')I8G5T:6]N(&]F('1H92!0<F]G<F%M(&)Y"F%L;"!T:&]S92!W:&\@<F5C
M96EV92!C;W!I97,@9&ER96-T;'D@;W(@:6YD:7)E8W1L>2!T:')O=6=H('EO
M=2P@=&AE;@IT:&4@;VYL>2!W87D@>6]U(&-O=6QD('-A=&ES9GD@8F]T:"!I
M="!A;F0@=&AI<R!,:6-E;G-E('=O=6QD(&)E('1O"G)E9G)A:6X@96YT:7)E
M;'D@9G)O;2!D:7-T<FEB=71I;VX@;V8@=&AE(%!R;V=R86TN"@I)9B!A;GD@
M<&]R=&EO;B!O9B!T:&ES('-E8W1I;VX@:7,@:&5L9"!I;G9A;&ED(&]R('5N
M96YF;W)C96%B;&4@=6YD97(*86YY('!A<G1I8W5L87(@8VER8W5M<W1A;F-E
M+"!T:&4@8F%L86YC92!O9B!T:&4@<V5C=&EO;B!I<R!I;G1E;F1E9"!T;PIA
M<'!L>2!A;F0@=&AE('-E8W1I;VX@87,@82!W:&]L92!I<R!I;G1E;F1E9"!T
M;R!A<'!L>2!I;B!O=&AE<@IC:7)C=6US=&%N8V5S+@H*270@:7,@;F]T('1H
M92!P=7)P;W-E(&]F('1H:7,@<V5C=&EO;B!T;R!I;F1U8V4@>6]U('1O(&EN
M9G)I;F=E(&%N>0IP871E;G1S(&]R(&]T:&5R('!R;W!E<G1Y(')I9VAT(&-L
M86EM<R!O<B!T;R!C;VYT97-T('9A;&ED:71Y(&]F(&%N>0IS=6-H(&-L86EM
M<SL@=&AI<R!S96-T:6]N(&AA<R!T:&4@<V]L92!P=7)P;W-E(&]F('!R;W1E
M8W1I;F<@=&AE"FEN=&5G<FET>2!O9B!T:&4@9G)E92!S;V9T=V%R92!D:7-T
M<FEB=71I;VX@<WES=&5M+"!W:&EC:"!I<PII;7!L96UE;G1E9"!B>2!P=6)L
M:6,@;&EC96YS92!P<F%C=&EC97,N("!-86YY('!E;W!L92!H879E(&UA9&4*
M9V5N97)O=7,@8V]N=')I8G5T:6]N<R!T;R!T:&4@=VED92!R86YG92!O9B!S
M;V9T=V%R92!D:7-T<FEB=71E9`IT:')O=6=H('1H870@<WES=&5M(&EN(')E
M;&EA;F-E(&]N(&-O;G-I<W1E;G0@87!P;&EC871I;VX@;V8@=&AA=`IS>7-T
M96T[(&ET(&ES('5P('1O('1H92!A=71H;W(O9&]N;W(@=&\@9&5C:61E(&EF
M(&AE(&]R('-H92!I<R!W:6QL:6YG"G1O(&1I<W1R:6)U=&4@<V]F='=A<F4@
M=&AR;W5G:"!A;GD@;W1H97(@<WES=&5M(&%N9"!A(&QI8V5N<V5E(&-A;FYO
M=`II;7!O<V4@=&AA="!C:&]I8V4N"@I4:&ES('-E8W1I;VX@:7,@:6YT96YD
M960@=&\@;6%K92!T:&]R;W5G:&QY(&-L96%R('=H870@:7,@8F5L:65V960@
M=&\*8F4@82!C;VYS97%U96YC92!O9B!T:&4@<F5S="!O9B!T:&ES($QI8V5N
M<V4N"@P*("`X+B!)9B!T:&4@9&ES=')I8G5T:6]N(&%N9"]O<B!U<V4@;V8@
M=&AE(%!R;V=R86T@:7,@<F5S=')I8W1E9"!I;@IC97)T86EN(&-O=6YT<FEE
M<R!E:71H97(@8GD@<&%T96YT<R!O<B!B>2!C;W!Y<FEG:'1E9"!I;G1E<F9A
M8V5S+"!T:&4*;W)I9VEN86P@8V]P>7)I9VAT(&AO;&1E<B!W:&\@<&QA8V5S
M('1H92!0<F]G<F%M('5N9&5R('1H:7,@3&EC96YS90IM87D@861D(&%N(&5X
M<&QI8VET(&=E;V=R87!H:6-A;"!D:7-T<FEB=71I;VX@;&EM:71A=&EO;B!E
M>&-L=61I;F<*=&AO<V4@8V]U;G1R:65S+"!S;R!T:&%T(&1I<W1R:6)U=&EO
M;B!I<R!P97)M:71T960@;VYL>2!I;B!O<B!A;6]N9PIC;W5N=')I97,@;F]T
M('1H=7,@97AC;'5D960N("!);B!S=6-H(&-A<V4L('1H:7,@3&EC96YS92!I
M;F-O<G!O<F%T97,*=&AE(&QI;6ET871I;VX@87,@:68@=W)I='1E;B!I;B!T
M:&4@8F]D>2!O9B!T:&ES($QI8V5N<V4N"@H@(#DN(%1H92!&<F5E(%-O9G1W
M87)E($9O=6YD871I;VX@;6%Y('!U8FQI<V@@<F5V:7-E9"!A;F0O;W(@;F5W
M('9E<G-I;VYS"F]F('1H92!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9R;VT@
M=&EM92!T;R!T:6UE+B`@4W5C:"!N97<@=F5R<VEO;G,@=VEL;`IB92!S:6UI
M;&%R(&EN('-P:7)I="!T;R!T:&4@<')E<V5N="!V97)S:6]N+"!B=70@;6%Y
M(&1I9F9E<B!I;B!D971A:6P@=&\*861D<F5S<R!N97<@<')O8FQE;7,@;W(@
M8V]N8V5R;G,N"@I%86-H('9E<G-I;VX@:7,@9VEV96X@82!D:7-T:6YG=6ES
M:&EN9R!V97)S:6]N(&YU;6)E<BX@($EF('1H92!0<F]G<F%M"G-P96-I9FEE
M<R!A('9E<G-I;VX@;G5M8F5R(&]F('1H:7,@3&EC96YS92!W:&EC:"!A<'!L
M:65S('1O(&ET(&%N9"`B86YY"FQA=&5R('9E<G-I;VXB+"!Y;W4@:&%V92!T
M:&4@;W!T:6]N(&]F(&9O;&QO=VEN9R!T:&4@=&5R;7,@86YD(&-O;F1I=&EO
M;G,*96ET:&5R(&]F('1H870@=F5R<VEO;B!O<B!O9B!A;GD@;&%T97(@=F5R
M<VEO;B!P=6)L:7-H960@8GD@=&AE($9R964*4V]F='=A<F4@1F]U;F1A=&EO
M;BX@($EF('1H92!0<F]G<F%M(&1O97,@;F]T('-P96-I9GD@82!V97)S:6]N
M(&YU;6)E<B!O9@IT:&ES($QI8V5N<V4L('EO=2!M87D@8VAO;W-E(&%N>2!V
M97)S:6]N(&5V97(@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E"D9O
M=6YD871I;VXN"@H@(#$P+B!)9B!Y;W4@=VES:"!T;R!I;F-O<G!O<F%T92!P
M87)T<R!O9B!T:&4@4')O9W)A;2!I;G1O(&]T:&5R(&9R964*<')O9W)A;7,@
M=VAO<V4@9&ES=')I8G5T:6]N(&-O;F1I=&EO;G,@87)E(&1I9F9E<F5N="P@
M=W)I=&4@=&\@=&AE(&%U=&AO<@IT;R!A<VL@9F]R('!E<FUI<W-I;VXN("!&
M;W(@<V]F='=A<F4@=VAI8V@@:7,@8V]P>7)I9VAT960@8GD@=&AE($9R964*
M4V]F='=A<F4@1F]U;F1A=&EO;BP@=W)I=&4@=&\@=&AE($9R964@4V]F='=A
M<F4@1F]U;F1A=&EO;CL@=V4@<V]M971I;65S"FUA:V4@97AC97!T:6]N<R!F
M;W(@=&AI<RX@($]U<B!D96-I<VEO;B!W:6QL(&)E(&=U:61E9"!B>2!T:&4@
M='=O(&=O86QS"F]F('!R97-E<G9I;F<@=&AE(&9R964@<W1A='5S(&]F(&%L
M;"!D97)I=F%T:79E<R!O9B!O=7(@9G)E92!S;V9T=V%R92!A;F0*;V8@<')O
M;6]T:6YG('1H92!S:&%R:6YG(&%N9"!R975S92!O9B!S;V9T=V%R92!G96YE
M<F%L;'DN"@H)"0D@("`@3D\@5T%24D%.5%D*"B`@,3$N($)%0T%54T4@5$A%
M(%!23T=204T@25,@3$E#14Y3140@1E)%12!/1B!#2$%21T4L(%1(15)%($E3
M($Y/(%=!4E)!3E19"D9/4B!42$4@4%)/1U)!32P@5$\@5$A%($585$5.5"!0
M15)-2514140@0ED@05!03$E#04),12!,05<N("!%6$-%4%0@5TA%3@I/5$A%
M4E=)4T4@4U1!5$5$($E.(%=2251)3D<@5$A%($-/4%E224=(5"!(3TQ$15)3
M($%.1"]/4B!/5$A%4B!005)42453"E!23U9)1$4@5$A%(%!23T=204T@(D%3
M($E3(B!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%251(15(@15A0
M4D534T5$"D]2($E-4$Q)140L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$
M(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&"DU%4D-(04Y404))3$E4
M62!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4N("!42$4@
M14Y425)%(%))4TL@05,*5$\@5$A%(%%504Q)5%D@04Y$(%!%4D9/4DU!3D-%
M($]&(%1(12!04D]'4D%-($E3(%=)5$@@64]5+B`@4TA/54Q$(%1(10I04D]'
M4D%-(%!23U9%($1%1D5#5$E612P@64]5($%34U5-12!42$4@0T]35"!/1B!!
M3$P@3D5#15-305)9(%-%4E9)0TE.1RP*4D5004E2($]2($-/4E)%0U1)3TXN
M"@H@(#$R+B!)3B!.3R!%5D5.5"!53DQ%4U,@4D5154E2140@0ED@05!03$E#
M04),12!,05<@3U(@04=2145$(%1/($E.(%=2251)3D<*5TE,3"!!3ED@0T]0
M65))1TA4($A/3$1%4BP@3U(@04Y9($]42$52(%!!4E19(%=(3R!-05D@34]$
M2499($%.1"]/4@I2141)4U1224)55$4@5$A%(%!23T=204T@05,@4$5234E4
M5$5$($%"3U9%+"!"12!,24%"3$4@5$\@64]5($9/4B!$04U!1T53+`I)3D-,
M541)3D<@04Y9($=%3D5204PL(%-014-)04PL($E.0TE$14Y404P@3U(@0T].
M4T51545.5$E!3"!$04U!1T53($%225-)3D<*3U54($]&(%1(12!54T4@3U(@
M24Y!0DE,2519(%1/(%5312!42$4@4%)/1U)!32`H24Y#3%5$24Y'($)55"!.
M3U0@3$E-251%1`I43R!,3U-3($]&($1!5$$@3U(@1$%402!"14E.1R!214Y$
M15)%1"!)3D%#0U52051%($]2($Q/4U-%4R!355-404E.140@0ED*64]5($]2
M(%1(25)$(%!!4E1)15,@3U(@02!&04E,55)%($]&(%1(12!04D]'4D%-(%1/
M($]015)!5$4@5TE42"!!3ED@3U1(15(*4%)/1U)!35,I+"!%5D5.($E&(%-5
M0T@@2$],1$52($]2($]42$52(%!!4E19($A!4R!"145.($%$5DE3140@3T8@
M5$A%"E!/4U-)0DE,2519($]&(%-50T@@1$%-04=%4RX*"@D)("`@("!%3D0@
M3T8@5$5235,@04Y$($-/3D1)5$E/3E,*#`H)("`@($AO=R!T;R!!<'!L>2!4
M:&5S92!497)M<R!T;R!9;W5R($YE=R!0<F]G<F%M<PH*("!)9B!Y;W4@9&5V
M96QO<"!A(&YE=R!P<F]G<F%M+"!A;F0@>6]U('=A;G0@:70@=&\@8F4@;V8@
M=&AE(&=R96%T97-T"G!O<W-I8FQE('5S92!T;R!T:&4@<'5B;&EC+"!T:&4@
M8F5S="!W87D@=&\@86-H:65V92!T:&ES(&ES('1O(&UA:V4@:70*9G)E92!S
M;V9T=V%R92!W:&EC:"!E=F5R>6]N92!C86X@<F5D:7-T<FEB=71E(&%N9"!C
M:&%N9V4@=6YD97(@=&AE<V4@=&5R;7,N"@H@(%1O(&1O('-O+"!A='1A8V@@
M=&AE(&9O;&QO=VEN9R!N;W1I8V5S('1O('1H92!P<F]G<F%M+B`@270@:7,@
M<V%F97-T"G1O(&%T=&%C:"!T:&5M('1O('1H92!S=&%R="!O9B!E86-H('-O
M=7)C92!F:6QE('1O(&UO<W0@969F96-T:79E;'D*8V]N=F5Y('1H92!E>&-L
M=7-I;VX@;V8@=V%R<F%N='D[(&%N9"!E86-H(&9I;&4@<VAO=6QD(&AA=F4@
M870@;&5A<W0*=&AE(")C;W!Y<FEG:'0B(&QI;F4@86YD(&$@<&]I;G1E<B!T
M;R!W:&5R92!T:&4@9G5L;"!N;W1I8V4@:7,@9F]U;F0N"@H@("`@/&]N92!L
M:6YE('1O(&=I=F4@=&AE('!R;V=R86TG<R!N86UE(&%N9"!A(&)R:65F(&ED
M96$@;V8@=VAA="!I="!D;V5S+CX*("`@($-O<'ER:6=H="`H0RD@,3EY>2`@
M/&YA;64@;V8@875T:&]R/@H*("`@(%1H:7,@<')O9W)A;2!I<R!F<F5E('-O
M9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(@;6]D:69Y
M"B`@("!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!'96YE<F%L(%!U
M8FQI8R!,:6-E;G-E(&%S('!U8FQI<VAE9"!B>0H@("`@=&AE($9R964@4V]F
M='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R('9E<G-I;VX@,B!O9B!T:&4@3&EC
M96YS92P@;W(*("`@("AA="!Y;W5R(&]P=&EO;BD@86YY(&QA=&5R('9E<G-I
M;VXN"@H@("`@5&AI<R!P<F]G<F%M(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H
M;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@("!B=70@5TE42$]55"!!
M3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT
M>2!O9@H@("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%2
M5$E#54Q!4B!055)03U-%+B`@4V5E('1H90H@("`@1TY5($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@("!9;W4@<VAO=6QD
M(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@1V5N97)A;"!0=6)L
M:6,@3&EC96YS90H@("`@86QO;F<@=VET:"!T:&ES('!R;V=R86T[(&EF(&YO
M="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@($9O=6YD871I;VXL
M($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL($U!
M("`P,C$Q,2TQ,S`W("!54T$*"@I!;'-O(&%D9"!I;F9O<FUA=&EO;B!O;B!H
M;W<@=&\@8V]N=&%C="!Y;W4@8GD@96QE8W1R;VYI8R!A;F0@<&%P97(@;6%I
M;"X*"DEF('1H92!P<F]G<F%M(&ES(&EN=&5R86-T:79E+"!M86ME(&ET(&]U
M='!U="!A('-H;W)T(&YO=&EC92!L:6ME('1H:7,*=VAE;B!I="!S=&%R=',@
M:6X@86X@:6YT97)A8W1I=F4@;6]D93H*"B`@("!';F]M;W9I<VEO;B!V97)S
M:6]N(#8Y+"!#;W!Y<FEG:'0@*$,I(#$Y>7D@;F%M92!O9B!A=71H;W(*("`@
M($=N;VUO=FES:6]N(&-O;65S('=I=&@@04)33TQ55$5,62!.3R!705)204Y4
M63L@9F]R(&1E=&%I;',@='EP92!@<VAO=R!W)RX*("`@(%1H:7,@:7,@9G)E
M92!S;V9T=V%R92P@86YD('EO=2!A<F4@=V5L8V]M92!T;R!R961I<W1R:6)U
M=&4@:70*("`@('5N9&5R(&-E<G1A:6X@8V]N9&ET:6]N<SL@='EP92!@<VAO
M=R!C)R!F;W(@9&5T86EL<RX*"E1H92!H>7!O=&AE=&EC86P@8V]M;6%N9',@
M8'-H;W<@=R<@86YD(&!S:&]W(&,G('-H;W5L9"!S:&]W('1H92!A<'!R;W!R
M:6%T90IP87)T<R!O9B!T:&4@1V5N97)A;"!0=6)L:6,@3&EC96YS92X@($]F
M(&-O=7)S92P@=&AE(&-O;6UA;F1S('EO=2!U<V4@;6%Y"F)E(&-A;&QE9"!S
M;VUE=&AI;F<@;W1H97(@=&AA;B!@<VAO=R!W)R!A;F0@8'-H;W<@8R<[('1H
M97D@8V]U;&0@979E;B!B90IM;W5S92UC;&EC:W,@;W(@;65N=2!I=&5M<RTM
M=VAA=&5V97(@<W5I=',@>6]U<B!P<F]G<F%M+@H*66]U('-H;W5L9"!A;'-O
M(&=E="!Y;W5R(&5M<&QO>65R("AI9B!Y;W4@=V]R:R!A<R!A('!R;V=R86UM
M97(I(&]R('EO=7(*<V-H;V]L+"!I9B!A;GDL('1O('-I9VX@82`B8V]P>7)I
M9VAT(&1I<V-L86EM97(B(&9O<B!T:&4@<')O9W)A;2P@:68*;F5C97-S87)Y
M+B`@2&5R92!I<R!A('-A;7!L93L@86QT97(@=&AE(&YA;65S.@H*("!9;WEO
M9'EN92P@26YC+BP@:&5R96)Y(&1I<V-L86EM<R!A;&P@8V]P>7)I9VAT(&EN
M=&5R97-T(&EN('1H92!P<F]G<F%M"B`@8$=N;VUO=FES:6]N)R`H=VAI8V@@
M;6%K97,@<&%S<V5S(&%T(&-O;7!I;&5R<RD@=W)I='1E;B!B>2!*86UE<R!(
M86-K97(N"@H@(#QS:6=N871U<F4@;V8@5'D@0V]O;CXL(#$@07!R:6P@,3DX
M.0H@(%1Y($-O;VXL(%!R97-I9&5N="!O9B!6:6-E"@I4:&ES($=E;F5R86P@
M4'5B;&EC($QI8V5N<V4@9&]E<R!N;W0@<&5R;6ET(&EN8V]R<&]R871I;F<@
M>6]U<B!P<F]G<F%M(&EN=&\*<')O<')I971A<GD@<')O9W)A;7,N("!)9B!Y
M;W5R('!R;V=R86T@:7,@82!S=6)R;W5T:6YE(&QI8G)A<GDL('EO=2!M87D*
M8V]N<VED97(@:70@;6]R92!U<V5F=6P@=&\@<&5R;6ET(&QI;FMI;F<@<')O
M<')I971A<GD@87!P;&EC871I;VYS('=I=&@@=&AE"FQI8G)A<GDN("!)9B!T
M:&ES(&ES('=H870@>6]U('=A;G0@=&\@9&\L('5S92!T:&4@1TY5($QI8G)A
M<GD@1V5N97)A;`I0=6)L:6,@3&EC96YS92!I;G-T96%D(&]F('1H:7,@3&EC
M96YS92X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]I;F1E>"YP:'``
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$T-C<`
M,3`T,3<S-C(W-3,`,#(P,C8R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR;VYO;&ET
M:"]I;F1E>"YP:'`L=B`Q+C(X(#(P,#0O,3`O,3D@,3`Z,#DZ,3$@:F%N($5X
M<"`D"B`J"B`J($MR;VYO;&ET:#H@0V]P>7)I9VAT(#$Y.3DL(#(P,#`@0VAA
M<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@<W5C:"!A
M(&9I;&4L('-E92!A;'-O(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G
M<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=+4D].3TQ)5$A?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I*3L*)&MR;VYO;&ET:%]C;VYF:6=U<F5D(#T@*$!I<U]R
M96%D86)L92A+4D].3TQ)5$A?0D%312`N("<O8V]N9FEG+V-O;F8N<&AP)RD@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@($!I<U]R96%D86)L92A+4D].
M3TQ)5$A?0D%312`N("<O8V]N9FEG+W!R969S+G!H<"<I*3L*"FEF("@A)&MR
M;VYO;&ET:%]C;VYF:6=U<F5D*2!["B`@("!R97%U:7)E($M23TY/3$E42%]"
M05-%("X@)R\N+B]L:6(O5&5S="YP:'`G.PH@("`@2&]R9&5?5&5S=#HZ8V]N
M9FEG1FEL97--:7-S:6YG*"=+<F]N;VQI=&@G+"!+4D].3TQ)5$A?0D%312P*
M("`@("`@("!A<G)A>2@G8V]N9BYP:'`G+"`G<')E9G,N<&AP)RDI.PI]"@IR
M97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<[
M"G)E<75I<F4@2U)/3D],251(7T)!4T4@+B`G+R<@+B`D<')E9G,M/F=E=%9A
M;'5E*"=D969A=6QT=FEE=R<I("X@)RYP:'`G.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]I8W,N
M<&AP````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#0R-34`,3`T,3<S-C(W-3,`,#$W-S(W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR
M;VYO;&ET:"]I8W,N<&AP+'8@,2XU+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(Y.C`R
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@
M2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TM2
M3TY/3$E42%]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N
M8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O0V%C:&4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]I
M0V%L96YD87(N<&AP)SL*"B\O($1E=&5R;6EN92!W:&EC:"!C86QE;F1A<B!T
M;R!E>'!O<G0N"B1C86QE;F1A<B`](%5T:6PZ.F=E=$9O<FU$871A*"=C)RD[
M"FEF("AE;7!T>2@D8V%L96YD87(I("8F("%E;7!T>2@D7U-%4E9%4ELG4$%4
M2%])3D9/)UTI*2!["B`@("`D8V%L96YD87(@/2!B87-E;F%M92@D7U-%4E9%
M4ELG4$%42%])3D9/)UTI.PI]"@HD<VAA<F4@/2`D:W)O;F]L:71H7W-H87)E
M<RT^9V5T4VAA<F4H)&-A;&5N9&%R*3L*:68@*&ES7V$H)'-H87)E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("!H96%D97(H)TA45%`O,2XP(#0P,"!"860@4F5Q
M=65S="<I.PH@("`@96-H;R`G-#`P($)A9"!297%U97-T)SL*("`@(&5X:70[
M"GT*"B\O($9I<G-T('1R>2!G=65S="!P97)M:7-S:6]N<RX*:68@*"$D<VAA
M<F4M/FAA<U!E<FUI<W-I;VXH)R<L(%!%4DU37U)%040I*2!["B`@("`O+R!!
M=71H96YT:6-A=&4N"B`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O
M;F9;)V%U=&@G75LG9')I=F5R)UTI.PH@("`@:68@*"%I<W-E="@D7U-%4E9%
M4ELG4$A07T%55$A?55-%4B==*0H@("`@("`@('Q\("$D875T:"T^875T:&5N
M=&EC871E*"1?4T525D526R=02%!?05542%]54T52)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A<W-W;W)D)R`]/B!I<W-E
M="@D7U-%4E9%4ELG4$A07T%55$A?4%<G72D@/R`D7U-%4E9%4ELG4$A07T%5
M5$A?4%<G72`Z(&YU;&PI*0H@("`@("`@('Q\("$D<VAA<F4M/FAA<U!E<FUI
M<W-I;VXH075T:#HZ9V5T075T:"@I+"!015)-4U]214%$*2D@>PH@("`@("`@
M(&AE861E<B@G5U=7+4%U=&AE;G1I8V%T93H@0F%S:6,@<F5A;&T](DMR;VYO
M;&ET:"!I0V%L96YD87(@26YT97)F86-E(B<I.PH@("`@("`@(&AE861E<B@G
M2%144"\Q+C`@-#`Q(%5N875T:&]R:7IE9"<I.PH@("`@("`@(&5C:&\@)S0P
M,2!5;F%U=&AO<FEZ960G.PH@("`@("`@(&5X:70["B`@("!]"GT*"B1C86-H
M92`]("9(;W)D95]#86-H93HZ<VEN9VQE=&]N*"1C;VYF6R=C86-H92==6R=D
M<FEV97(G72P@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G8V%C:&4G+"`D8V]N
M9ELG8V%C:&4G75LG9')I=F5R)UTI*3L*)&ME>2`]("=K<F]N;VQI=&@N:6-S
M+B<@+B`D8V%L96YD87(["@HD:6-S(#T@)&-A8VAE+3YG970H)&ME>2P@,S8P
M*3L*:68@*"$D:6-S*2!["B`@("`D:W)O;F]L:71H+3YO<&5N*"1C86QE;F1A
M<BD["B`@("`D979E;G1S(#T@)&MR;VYO;&ET:"T^;&ES=$5V96YT<RAN=6QL
M+"!N=6QL*3L*"B`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D[
M"B`@("`D:4-A;"T^<V5T071T<FEB=71E*"=8+5=2+4-!3$Y!344G+"`D<VAA
M<F4M/F=E="@G;F%M92<I*3L*("`@("1I9&5N=&ET>2`]("8D:W)O;F]L:71H
M7W-H87)E<RT^9V5T261E;G1I='E">5-H87)E*"1S:&%R92D["@H@("`@9F]R
M96%C:"`H)&5V96YT<R!A<R`D:60I('L*("`@("`@("`D979E;G0@/2`F)&MR
M;VYO;&ET:"T^9V5T179E;G0H)&ED*3L*("`@("`@("`D:4-A;"T^861D0V]M
M<&]N96YT*"1E=F5N="T^=&]I0V%L96YD87(H)&E#86PL("1I9&5N=&ET>2DI
M.PH@("`@?0H*("`@("1I8W,@/2`D:4-A;"T^97AP;W)T=D-A;&5N9&%R*"D[
M"B`@("`D8V%C:&4M/G-E="@D:V5Y+"`D:6-S*3L*?0H*)&)R;W=S97(M/F1O
M=VYL;V%D2&5A9&5R<R@D8V%L96YD87(@+B`G+FEC<R<L("=T97AT+V-A;&5N
M9&%R)RP@=')U92P@<W1R;&5N*"1I8W,I*3L*96-H;R`D:6-S.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR
M;VYO;&ET:"]F8BYP:'``````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,U-38`,3`T,3<S-C(W-3,`,#$W-30S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&MR;VYO;&ET:"]F8BYP:'`L=B`Q+C(U+C$P+C0@,C`P-B\P
M,2\P,2`R,3HR.3HP,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+V=P;"YH=&UL+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I
M.PI`9&5F:6YE*"=+4D].3TQ)5$A?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M*3L*<F5Q=6ER95]O;F-E($M23TY/3$E42%]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-A8VAE+G!H<"<["@HO+R!$971E
M<FUI;F4@=&AE('5S97)N86UE('1O('-H;W<@9G)E92]B=7-Y('1I;64@9F]R
M+@HD8V%L(#T@571I;#HZ9V5T1F]R;41A=&$H)V,G*3L*)'5S97(@/2!5=&EL
M.CIG971&;W)M1&%T82@G=2<I.PII9B`H(65M<'1Y*"1C86PI*2!["B`@("!I
M9B`H:7-?87)R87DH)&-A;"DI('L*("`@("`@("`D8V%L(#T@:6UP;&]D92@G
M?"<L("1C86PI.PH@("`@?0I](&5L<V5I9B`H(65M<'1Y*"1?4T525D526R=0
M051(7TE.1D\G72DI('L*("`@("1U<V5R(#T@8F%S96YA;64H)%]315)615);
M)U!!5$A?24Y&3R==*3L*?0H*)&-A8VAE(#T@)DAO<F1E7T-A8VAE.CIS:6YG
M;&5T;VXH)&-O;F9;)V-A8VAE)UU;)V1R:79E<B==+"!(;W)D93HZ9V5T1')I
M=F5R0V]N9FEG*"=C86-H92<L("1C;VYF6R=C86-H92==6R=D<FEV97(G72DI
M.PHD:V5Y(#T@)VMR;VYO;&ET:"YF8BXG("X@*"1U<V5R(#\@)W4N)R`N("1U
M<V5R(#H@)V,N)R`N("1C86PI.PHD9F(@/2`D8V%C:&4M/F=E="@D:V5Y+"`S
M-C`I.PII9B`H(21F8BD@>PH@("`@:68@*"1U<V5R*2!["B`@("`@("`@)'!R
M969S(#T@)E!R969S.CIS:6YG;&5T;VXH)&-O;F9;)W!R969S)UU;)V1R:79E
M<B==+"`G:W)O;F]L:71H)RP@)'5S97(L("<G+"!N=6QL+"!F86QS92D["B`@
M("`@("`@)'!R969S+3YR971R:65V92@I.PH@("`@("`@("1C86P@/2!`=6YS
M97)I86QI>F4H)'!R969S+3YG971686QU92@G9F)?8V%L<R<I*3L*("`@("`@
M("!I9B`H:7-?87)R87DH)&-A;"DI('L*("`@("`@("`@("`@)&-A;"`](&EM
M<&QO9&4H)WPG+"`D8V%L*3L*("`@("`@("!]"@H@("`@("`@("\O($EF('1H
M92!F<F5E+V)U<WD@8V%L96YD87)S('!R969E<F5N8V4@:7,@96UP='DL(&1E
M9F%U;'0@=&\*("`@("`@("`O+R!T:&4@=7-E<B=S(&1E9F%U;'1?<VAA<F4@
M<')E9F5R96YC92P@86YD(&EF('1H870G<R!E;7!T>2P*("`@("`@("`O+R!T
M;R!T:&5I<B!U<V5R;F%M92X*("`@("`@("!I9B`H(21C86PI('L*("`@("`@
M("`@("`@)&-A;"`]("1P<F5F<RT^9V5T5F%L=64H)V1E9F%U;'1?<VAA<F4G
M*3L*("`@("`@("`@("`@:68@*"$D8V%L*2!["B`@("`@("`@("`@("`@("`D
M8V%L(#T@)'5S97(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@)&9B(#T@2W)O;F]L:71H.CIG96YE<F%T949R965"=7-Y*&5X<&QO9&4H
M)WPG+"`D8V%L*2D["B`@("!I9B`H:7-?82@D9F(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D9F(L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("!E>&ET.PH@("`@?0H@
M("`@)&-A8VAE+3YS970H)&ME>2P@)&9B*3L*?0H*)&)R;W=S97(M/F1O=VYL
M;V%D2&5A9&5R<R@H)'5S97(@/R`D=7-E<B`Z("1C86PI("X@)RYV9F(G+"`G
M=&5X="]C86QE;F1A<B<L('1R=64L('-T<FQE;B@D9F(I*3L*96-H;R`D9F([
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI
M=&@O961I=&5V96YT86-T:6]N+G!H<```````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$Q-#4V`#$P-#$W,S8R-S4S`#`R,C,S-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!K<F]N;VQI=&@O961I=&5V96YT86-T:6]N+G!H<"QV(#$N-3,N,3(N
M-B`R,#`V+S`Q+S`Y(#$U.C0S.C(S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2U)/3D],251(7T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!+4D].3TQ)
M5$A?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B1U<FP@/2!5=&EL.CIG971&
M;W)M1&%T82@G=7)L)RD["@II9B`H(55T:6PZ.F=E=$9O<FU$871A*"=C86YC
M96PG*2D@>PH@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=D96QE=&4G*2D@
M>PH@("`@("`@("1D96QU<FP@/2`G9&5L979E;G0N<&AP)SL*("`@("`@("!5
M=&EL.CIA9&1087)A;65T97(H)&1E;'5R;"P@)V5V96YT240G+"!5=&EL.CIG
M971&;W)M1&%T82@G979E;G1)1"<I*3L*("`@("`@("!5=&EL.CIA9&1087)A
M;65T97(H)&1E;'5R;"P@)V-A;&5N9&%R)RP@571I;#HZ9V5T1F]R;41A=&$H
M)V5X:7-T:6YG8V%L96YD87(G*2D["B`@("`@("`@)&QO8V%T:6]N(#T@2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"1D96Q5<FPL('1R=64I.PH@("`@("`@(&EF
M("@A96UP='DH)'5R;"DI('L*("`@("`@("`@("`@)&QO8V%T:6]N(#T@571I
M;#HZ861D4&%R86UE=&5R*"1L;V-A=&EO;BP@)W5R;"<L("1U<FPL(&9A;'-E
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:6UE<W1A;7`@/2!5=&EL.CIG
M971&;W)M1&%T82@G=&EM97-T86UP)RDI('L*("`@("`@("`@("`@)&QO8V%T
M:6]N(#T@571I;#HZ861D4&%R86UE=&5R*"1L;V-A=&EO;BP@)W1I;65S=&%M
M<"<L("1T:6UE<W1A;7`L(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@:&5A
M9&5R*"=,;V-A=&EO;CH@)R`N("1L;V-A=&EO;BD["B`@("!](&5L<V4@>PH@
M("`@("`@("1S;W5R8V4@/2!5=&EL.CIG971&;W)M1&%T82@G97AI<W1I;F=C
M86QE;F1A<B<I.PH@("`@("`@("1T87)G970@/2!5=&EL.CIG971&;W)M1&%T
M82@G=&%R9V5T8V%L96YD87(G*3L*("`@("`@("`D<VAA<F4@/2`F)&MR;VYO
M;&ET:%]S:&%R97,M/F=E=%-H87)E*"1T87)G970I.PH*("`@("`@("!I9B`H
M:7-?82@D<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H97)E('=A<R!A;B!E<G)O
M<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<R(I+"`D<VAA<F4M/F=E=$UE
M<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G<V%V94%S3F5W)RDI
M('L*("`@("`@("`@("`@("`@(&EF("A+<F]N;VQI=&@Z.FAA<U!E<FUI<W-I
M;VXH)VUA>%]E=F5N=',G*2`]/3T@=')U92!\?`H@("`@("`@("`@("`@("`@
M("`@($MR;VYO;&ET:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I(#X@
M2W)O;F]L:71H.CIC;W5N=$5V96YT<R@I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&MR;VYO;&ET:"T^;W!E;B@D=&%R9V5T*3L*("`@("`@("`@("`@("`@
M("`@("`D979E;G0@/2`F)&MR;VYO;&ET:"T^9V5T179E;G0H*3L*"B`@("`@
M("`@("`@("`@("`@("`@+R\@1&]N)W0@9V\@8F%C:R!T;R!T:&4@;VQD(&5V
M96YT+@H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1U<FPI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G
M92`]($!H=&UL<W!E8VEA;&-H87)S*'-P<FEN=&8H7R@B66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&5V96YT<RXB*2P@2W)O
M;F]L:71H.CIH87-097)M:7-S:6]N*"=M87A?979E;G1S)RDI+"!%3E1?0T]-
M4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG<&5R;7-D96YI960G72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!(;W)D93HZ8V%L
M;$AO;VLH)U]P97)M<U]H;V]K7V1E;FEE9"<L(&%R<F%Y*"=K<F]N;VQI=&@Z
M;6%X7V5V96YT<R<I+"`G:&]R9&4G+"`D;65S<V%G92D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H)&UE<W-A9V4L("=H;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT
M+G)A=R<I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&EF("@D=&%R9V5T("$]("1S;W5R8V4I('L*
M("`@("`@("`@("`@("`@("`@("`O+R!/;FQY(&1E;&5T92!T:&4@979E;G0@
M9G)O;2!T:&4@<V]U<F-E(&-A;&5N9&%R(&EF('1H:7,*("`@("`@("`@("`@
M("`@("`@("`O+R!U<V5R(&AA<R!P97)M:7-S:6]N<R!T;R!D;R!S;RX*("`@
M("`@("`@("`@("`@("`@("`D<V]U<F-E4VAA<F4@/2`F)&MR;VYO;&ET:%]S
M:&%R97,M/F=E=%-H87)E*"1S;W5R8V4I.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-?82@D<VAA<F4L("=014%27T5R<F]R)RD@)B8@(6ES7V$H)'-O
M=7)C95-H87)E+"`G4$5!4E]%<G)O<B<I("8F"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S;W5R8V53:&%R92T^:&%S4&5R;6ES<VEO;BA!=71H.CIG971!
M=71H*"DL(%!%4DU37T1%3$5412D@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-H87)E+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H*2P@4$52
M35-?141)5"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&MR;VYO;&ET
M:"T^;W!E;B@D<V]U<F-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M<R`]("1K<F]N;VQI=&@M/FUO=F4H571I;#HZ9V5T1F]R;41A=&$H)V5V96YT
M240G*2P@)'1A<F=E="D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R
M92!W87,@86X@97)R;W(@;6]V:6YG('1H92!E=F5N=#H@)7,B*2P@)')E<RT^
M9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&MR;VYO;&ET
M:"T^8VQO<V4H*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@("`@("1K<F]N;VQI=&@M/F]P96XH)'1A<F=E="D["B`@("`@("`@
M("`@("`@("`@("`@)&5V96YT(#T@)B1K<F]N;VQI=&@M/F=E=$5V96YT*%5T
M:6PZ.F=E=$9O<FU$871A*"=E=F5N=$E$)RDI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:W)O;F]L:71H+3YO<&5N
M*"1S;W5R8V4I.PH@("`@("`@("`@("`@("`@("`@("1E=F5N="`]("8D:W)O
M;F]L:71H+3YG971%=F5N="A5=&EL.CIG971&;W)M1&%T82@G979E;G1)1"<I
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*&ES<V5T*"1E=F5N="DI('L*("`@("`@("`@("`@("`@(&EF("@A
M)'-H87)E+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H*2P@4$5235-?
M141)5"P@)&5V96YT+3YG971#<F5A=&]R240H*2DI('L*("`@("`@("`@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O(&5D:70@=&AI<R!E=F5N="XB*2P@)VAO<F1E+G=A
M<FYI;F<G*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&5V96YT+3YR96%D1F]R;2@I.PH@("`@("`@("`@("`@("`@
M("`@("1R97,@/2`D979E;G0M/G-A=F4H*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4
M:&5R92!W87,@86X@97)R;W(@961I=&EN9R!T:&4@979E;G0Z("5S(BDL("1R
M97,M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G<V5N9'5P
M9&%T97,G+"!F86QS92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@2W)O
M;F]L:71H.CIS96YD251I<$YO=&EF:6-A=&EO;G,H)&5V96YT+"`D;F]T:69I
M8V%T:6]N+"!+4D].3TQ)5$A?251)4%]215%515-4*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"GT*"FEF("@A96UP='DH)'5R;"DI('L*("`@("1L;V-A
M=&EO;B`]("1U<FP["GT@96QS92!["B`@("`D=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1P<F5F<RT^9V5T5F%L=64H)V1E9F%U;'1V:65W)RD@+B`G+G!H
M<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=M;VYT
M:"<@/3X@571I;#HZ9V5T1F]R;41A=&$H)VUO;G1H)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=Y96%R)R`]/B!5=&EL.CIG971&
M;W)M1&%T82@G>65A<B<I*2D["B`@("`D;&]C871I;VX@/2!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)'5R;"P@=')U92D["GT*"B\O($UA:V4@<W5R92!54DP@
M:7,@=6YI<75E+@HD;&]C871I;VX@/2!5=&EL.CIA9&1087)A;65T97(H)&QO
M8V%T:6]N+"`G=6YI<75E)RP@;60U*&UI8W)O=&EM92@I*2P@9F%L<V4I.PH*
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1L;V-A=&EO;BD["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:W)O;F]L:71H+V5D:71E=F5N="YP:'``````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-S0U-@`Q,#0Q-S,V,C<U,P`P,C$Q-#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:W)O;F]L:71H+V5D:71E=F5N="YP:'`L=B`Q+C4R+C@N
M,R`R,#`U+S$R+S$U(#`U.C`V.C,X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+"`R,#`P($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B`@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2U)/3D],251(
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!+4D].
M3TQ)5$A?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"FEF("A5=&EL.CIG971&
M;W)M1&%T82@G8V%L96YD87(G*2`]/2`G*BIR96UO=&4G*2!["B`@("`D979E
M;G0@/2!+<F]N;VQI=&@Z.F=E=%)E;6]T945V96YT3V)J96-T*%5T:6PZ.F=E
M=$9O<FU$871A*"=R96UO=&5#86PG*2P@571I;#HZ9V5T1F]R;41A=&$H)V5V
M96YT240G*2D["GT@96QS92!["B`@("`D:W)O;F]L:71H+3YO<&5N*%5T:6PZ
M.F=E=$9O<FU$871A*"=C86QE;F1A<B<I*3L*("`@("1E=F5N="`]("8D:W)O
M;F]L:71H+3YG971%=F5N="A5=&EL.CIG971&;W)M1&%T82@G979E;G1)1"<I
M*3L*?0H*)&-A;&5N9&%R7VED(#T@)&5V96YT+3YG971#86QE;F1A<B@I.PHD
M7U-%4U-)3TY;)V%T=&5N9&5E<R==(#T@)&5V96YT+3YG971!='1E;F1E97,H
M*3L*"FEF("@D=&EM97-T86UP(#T@571I;#HZ9V5T1F]R;41A=&$H)W1I;65S
M=&%M<"<I*2!["B`@("`D;6]N=&@@/2!D871E*"=N)RP@)'1I;65S=&%M<"D[
M"B`@("`D>65A<B`](&1A=&4H)UDG+"`D=&EM97-T86UP*3L*?2!E;'-E('L*
M("`@("1M;VYT:"`](%5T:6PZ.F=E=$9O<FU$871A*"=M;VYT:"<L(&1A=&4H
M)VXG*2D["B`@("`D>65A<B`](%5T:6PZ.F=E=$9O<FU$871A*"=Y96%R)RP@
M9&%T92@G62<I*3L*?0H*)'5R;"`](%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG
M*3L*)'1I=&QE(#T@<W!R:6YT9BA?*")%9&ET("5S(BDL("1E=F5N="T^9V5T
M5&ET;&4H*2D["B1C86QE;F1A<G,@/2!+<F]N;VQI=&@Z.FQI<W1#86QE;F1A
M<G,H9F%L<V4L(%!%4DU37T5$250I.PH*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)W-T<FEP92YJ<R<L("=K<F]N;VQI=&@G+"!T<G5E*3L*2&]R9&4Z.F%D9%-C
M<FEP=$9I;&4H)V]P96Y?871T96YD965S7W=I;BYJ<R<I.PIR97%U:7)E($M2
M3TY/3$E42%]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q
M=6ER92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]M96YU+FEN8R<["G)E<75I
M<F4@2U)/3D],251(7U1%35!,051%4R`N("<O961I="]J879A<V-R:7!T+FEN
M8R<["@HD8G5T=&]N<R`](&%R<F%Y*"D["B1S:&%R92`](&ES<V5T*"1A;&Q?
M8V%L96YD87)S6U5T:6PZ.F=E=$9O<FU$871A*"=C86QE;F1A<B<I72D@/R`D
M86QL7V-A;&5N9&%R<UM5=&EL.CIG971&;W)M1&%T82@G8V%L96YD87(G*5T@
M.B!014%2.CIR86ES945R<F]R*"=N;W0@9F]U;F0G*3L*:68@*%5T:6PZ.F=E
M=$9O<FU$871A*"=C86QE;F1A<B<I(#T]("<J*G)E;6]T92<@?'P*("`@("$D
M<VAA<F4M/FAA<U!E<FUI<W-I;VXH075T:#HZ9V5T075T:"@I+"!015)-4U]%
M1$E4+"`D979E;G0M/F=E=$-R96%T;W))1"@I*2D@>PH@("`@:68@*"%E;7!T
M>2@D8V]N9ELG:&]O:W,G75LG<&5R;7-D96YI960G72D@?'P*("`@("`@("!+
M<F]N;VQI=&@Z.FAA<U!E<FUI<W-I;VXH)VUA>%]E=F5N=',G*2`]/3T@=')U
M92!\?`H@("`@("`@($MR;VYO;&ET:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V
M96YT<R<I(#X@2W)O;F]L:71H.CIC;W5N=$5V96YT<R@I*2!["B`@("`@("`@
M)&)U='1O;G-;72`]("<\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T
M=&]N(B!N86UE/2)S879E07-.97<B('9A;'5E/2(G("X@7R@B4V%V92!!<R!.
M97<B*2`N("<B(&]N8VQI8VL](G)E='5R;B!C:&5C:T-A=&5G;W)Y*"D[(B`O
M/B<["B`@("!]"GT@96QS92!["B`@("`D8G5T=&]N<UM=(#T@)SQI;G!U="!T
M>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&YA;64](G-A=F4B('9A;'5E
M/2(G("X@7R@B4V%V92!%=F5N="(I("X@)R(@;VYC;&EC:STB<F5T=7)N(&-H
M96-K0V%T96=O<GDH*3LB("\^)SL*("`@(&EF("@D979E;G0M/FES26YI=&EA
M;&EZ960H*2D@>PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;
M)W!E<FUS9&5N:65D)UTI('Q\"B`@("`@("`@("`@($MR;VYO;&ET:#HZ:&%S
M4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I(#T]/2!T<G5E('Q\"B`@("`@("`@
M("`@($MR;VYO;&ET:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I(#X@
M2W)O;F]L:71H.CIC;W5N=$5V96YT<R@I*2!["B`@("`@("`@("`@("1B=71T
M;VYS6UT@/2`G/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@
M;F%M93TB<V%V94%S3F5W(B!V86QU93TB)R`N(%\H(E-A=F4@07,@3F5W(BD@
M+B`G(B!O;F-L:6-K/2)R971U<FX@8VAE8VM#871E9V]R>2@I.R(@+SXG.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'-H87)E+3YH87-097)M:7-S:6]N*$%U
M=&@Z.F=E=$%U=&@H*2P@4$5235-?1$5,151%+"`D979E;G0M/F=E=$-R96%T
M;W))1"@I*2D@>PH@("`@("`@("`@("`D9&5L=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"=D96QE=F5N="YP:'`G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=E=F5N=$E$)R`]/B`D979E;G0M
M/F=E=$E$*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-A;&5N9&%R)R`]/B`D979E;G0M/F=E=$-A;&5N9&%R
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VUO;G1H)R`]/B`D;6]N=&@L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)WEE87(G+"`D>65A<BDI.PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1U<FPI*2!["B`@("`@("`@("`@("`@
M("`D9&5L=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1D96QU<FPL("=U<FPG
M+"`D=7)L*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H
M)'1I;65S=&%M<"DI('L*("`@("`@("`@("`@("`@("1D96QU<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H)&1E;'5R;"P@)W1I;65S=&%M<"<L("1T:6UE<W1A
M;7`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D96QU<FP@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)&1E;'5R;"D["B`@("`@("`@("`@("1B=71T
M;VYS6UT@/2`G/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@
M;F%M93TB9&5L971E(B!V86QU93TB)R`N(%\H(D1E;&5T92!%=F5N="(I("X@
M)R(@;VYC;&EC:STB<V5L9BYL;V-A=&EO;B`](%PG)R`N("1D96QU<FP@+B`G
M7"<[(')E='5R;B!F86QS93LB("\^)SL*("`@("`@("!]"B`@("!]"GT*"FEF
M("AI<W-E="@D=7)L*2D@>PH@("`@)&-A;F-E;'5R;"`]("1U<FP["GT@96QS
M92!["B`@("`D8V%N8V5L=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=M;VYT
M:"YP:'`G+"!A<G)A>2@G;6]N=&@G(#T^("1M;VYT:"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y
M96%R)RP@)'EE87(I*3L*("`@("1C86YC96QU<FP@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)&-A;F-E;'5R;"D["GT*"G)E<75I<F4@2U)/3D],251(7U1%
M35!,051%4R`N("<O961I="]E9&ET+FEN8R<["G)E<75I<F4@)')E9VES=')Y
M+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R
M+FEN8R<["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+V1E;&5V96YT86-T:6]N+G!H
M<```````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C`Q-P`Q,#0Q-S,V
M,C<U,P`P,C(Q-3,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+V1E;&5V
M96YT86-T:6]N+G!H<"QV(#$N,C(N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(Y.C`R
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@
M2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G2U)/3D],251(7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2D["G)E<75I<F5?;VYC92!+4D].3TQ)5$A?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*"B1K<F]N;VQI=&@M/F]P96XH571I;#HZ9V5T1F]R;41A=&$H)V-A
M;&5N9&%R)RDI.PII9B`H)&5V96YT240@/2!5=&EL.CIG971&;W)M1&%T82@G
M979E;G1)1"<I*2!["B`@("`D979E;G0@/2`F)&MR;VYO;&ET:"T^9V5T179E
M;G0H)&5V96YT240I.PH@("`@:68@*"$D979E;G0I('L*("`@("`@("!I9B`H
M*"1U<FP@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI(#T]/2!N=6QL*2![
M"B`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)'!R
M969S+3YG971686QU92@G9&5F875L='9I97<G*2`N("<N<&AP)RP@=')U92D[
M"B`@("`@("`@?0H@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L
M*3L*("`@("`@("!E>&ET.PH@("`@?0H@("`@)'-H87)E(#T@)B1K<F]N;VQI
M=&A?<VAA<F5S+3YG9713:&%R92@D979E;G0M/F=E=$-A;&5N9&%R*"DI.PH@
M("`@:68@*"$D<VAA<F4M/FAA<U!E<FUI<W-I;VXH075T:#HZ9V5T075T:"@I
M+"!015)-4U]$14Q%5$4L("1E=F5N="T^9V5T0W)E871O<DE$*"DI*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!D96QE=&4@=&AI<R!E=F5N="XB*2P@)VAO<F1E+G=A
M<FYI;F<G*3L*("`@('T@96QS92!["B`@("`@("`@:68@*%5T:6PZ.F=E=$9O
M<FU$871A*"=S96YD=7!D871E<R<L(&9A;'-E*2D@>PH@("`@("`@("`@("!+
M<F]N;VQI=&@Z.G-E;F1)5&EP3F]T:69I8V%T:6]N<R@D979E;G0L("1N;W1I
M9FEC871I;VXL($M23TY/3$E42%])5$E07T-!3D-%3"D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V9U='5R92<I*2!["B`@
M("`@("`@("`@("1R96-U<D5N9"`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G
M:&]U<B<@/3X@,2P@)VUI;B<@/3X@,2P@)W-E8R<@/3X@,2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@
M/3X@571I;#HZ9V5T1F]R;41A=&$H)VUO;G1H)RP@9&%T92@G;B<I*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M9&%Y)R`]/B!5=&EL.CIG971&;W)M1&%T82@G;61A>2<L(&1A=&4H)VHG*2D@
M+2`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)WEE87(G(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=Y96%R)RP@9&%T
M92@G62<I*2DI.PH@("`@("`@("`@("`D<F5C=7)%;F0M/F-O<G)E8W0H*3L*
M("`@("`@("`@("`@:68@*"1E=F5N="T^96YD+3YC;VUP87)E1&%T92@D<F5C
M=7)%;F0I(#X@,"D@>PH@("`@("`@("`@("`@("`@)&MR;VYO;&ET:"T^9&5L
M971E179E;G0H)&5V96YT+3YG971)9"@I*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1E=F5N="T^<F5C=7)%;F0@/2`D<F5C=7)%
M;F0["B`@("`@("`@("`@("`@("`D979E;G0M/G-A=F4H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G8W5R
M<F5N="<I*2!["B`@("`@("`@("`@("1E=F5N="T^861D17AC97!T:6]N*%5T
M:6PZ.F=E=$9O<FU$871A*"=Y96%R)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%5T:6PZ.F=E=$9O<FU$871A*"=M;VYT:"<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!5=&EL.CIG971&;W)M1&%T
M82@G;61A>2<I*3L*("`@("`@("`@("`@)&5V96YT+3YS879E*"D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&5V96YT+3YH87-296-U<E1Y<&4H2U)/3D],
M251(7U)%0U527TY/3D4I('Q\(%5T:6PZ.F=E=$9O<FU$871A*"=A;&PG*2!\
M?"`A)&5V96YT+3YH87-!8W1I=F5296-U<G)E;F-E*"DI('L*("`@("`@("`@
M("`@)&MR;VYO;&ET:"T^9&5L971E179E;G0H)&5V96YT+3YG971)1"@I*3L*
M("`@("`@("!]"B`@("!]"GT*"FEF("@D=&EM97-T86UP(#T@571I;#HZ9V5T
M1F]R;41A=&$H)W1I;65S=&%M<"<I*2!["B`@("`D;6]N=&@@/2!D871E*"=N
M)RP@)'1I;65S=&%M<"D["B`@("`D9&%Y(#T@9&%T92@G:B<L("1T:6UE<W1A
M;7`I.PH@("`@)'EE87(@/2!D871E*"=9)RP@)'1I;65S=&%M<"D["GT@96QS
M92!["B`@("`D;6]N=&@@/2!5=&EL.CIG971&;W)M1&%T82@G;6]N=&@G+"!D
M871E*"=N)RDI.PH@("`@)&1A>2`](%5T:6PZ.F=E=$9O<FU$871A*"=M9&%Y
M)RP@9&%T92@G:B<I*3L*("`@("1Y96%R(#T@571I;#HZ9V5T1F]R;41A=&$H
M)WEE87(G+"!D871E*"=9)RDI.PI]"@II9B`H)'5R;"`](%5T:6PZ.F=E=$9O
M<FU$871A*"=U<FPG*2D@>PH@("`@)&QO8V%T:6]N(#T@)'5R;#L*?2!E;'-E
M('L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'!R969S+3YG9716
M86QU92@G9&5F875L='9I97<G*2`N("<N<&AP)RP@)VUO;G1H)RP@)&UO;G1H
M*3L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)WEE87(G
M+"`D>65A<BD["B`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL
M("=M9&%Y)RP@)&1A>2D["B`@("`D;&]C871I;VX@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)'5R;"P@=')U92D["GT*"B1L;V-A=&EO;B`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D;&]C871I;VXL("=U<2<L(&UD-2AM:6-R;W1I;64H*2DI
M.PIH96%D97(H)TQO8V%T:6]N.B`G("X@)&QO8V%T:6]N*3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]D96QE=F5N="YP:'``````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,R-3(`,3`T,3<S
M-C(W-3,`,#(P-S4S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]D96QE
M=F5N="YP:'`L=B`Q+C0R+C@N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`R(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J+PH*0&1E
M9FEN92@G2U)/3D],251(7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E
M<75I<F5?;VYC92!+4D].3TQ)5$A?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*
M"B1K<F]N;VQI=&@M/F]P96XH571I;#HZ9V5T1F]R;41A=&$H)V-A;&5N9&%R
M)RDI.PHD979E;G0@/2`F)&MR;VYO;&ET:"T^9V5T179E;G0H571I;#HZ9V5T
M1F]R;41A=&$H)V5V96YT240G*2D["FEF("@A)&5V96YT*2!["B`@("!I9B`H
M*"1U<FP@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI(#T]/2!N=6QL*2![
M"B`@("`@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D<')E9G,M
M/F=E=%9A;'5E*"=D969A=6QT=FEE=R<I("X@)RYP:'`G+"!T<G5E*3L*("`@
M('T*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@(&5X:70[
M"GT@96QS96EF("@D979E;G0M/FAA<U)E8W5R5'EP92A+4D].3TQ)5$A?4D5#
M55)?3D].12D@)B8*("`@("$D<')E9G,M/F=E=%9A;'5E*"=C;VYF:7)M7V1E
M;&5T92<I*2!["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=D96QE=F5N=&%C=&EO;BYP:'`_)R`N("1?4T525D52
M6R=1545265]35%))3D<G72P@,2DI.PH@("`@97AI=#L*?0H*:68@*"1T:6UE
M<W1A;7`@/2!5=&EL.CIG971&;W)M1&%T82@G=&EM97-T86UP)RDI('L*("`@
M("1M;VYT:"`](&1A=&4H)VXG+"`D=&EM97-T86UP*3L*("`@("1Y96%R(#T@
M9&%T92@G62<L("1T:6UE<W1A;7`I.PH@("`@)&1A>2`](&1A=&4H)VHG+"`D
M=&EM97-T86UP*3L*?2!E;'-E('L*("`@("1M;VYT:"`](%5T:6PZ.F=E=$9O
M<FU$871A*"=M;VYT:"<L(&1A=&4H)VXG*2D["B`@("`D9&%Y(#T@571I;#HZ
M9V5T1F]R;41A=&$H)VUD87DG+"!D871E*"=J)RDI.PH@("`@)'EE87(@/2!5
M=&EL.CIG971&;W)M1&%T82@G>65A<B<L(&1A=&4H)UDG*2D["GT*"B1U<FP@
M/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD["@HD=&ET;&4@/2!S<')I;G1F
M*%\H(D1E;&5T92`E<R(I+"`D979E;G0M/F=E=%1I=&QE*"DI.PIR97%U:7)E
M($M23TY/3$E42%]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*
M<F5Q=6ER92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]M96YU+FEN8R<["F5C
M:&\@)SQD:78@:60](G!A9V4B/B<["FEF("@D979E;G0M/FAA<U)E8W5R5'EP
M92A+4D].3TQ)5$A?4D5#55)?3D].12DI('L*("`@(')E<75I<F4@2U)/3D],
M251(7U1%35!,051%4R`N("<O9&5L971E+V]N92YI;F,G.PI](&5L<V4@>PH@
M("`@<F5Q=6ER92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]D96QE=&4O9&5L
M971E+FEN8R<["GT*96-H;R`G/"]D:78^)SL*<F5Q=6ER92`D<F5G:7-T<GDM
M/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O9&%Y+G!H<```````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-38W`#$P-#$W,S8R-S4S
M`#`Q-S<S,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!K<F]N;VQI=&@O9&%Y+G!H<"QV
M(#$N-C,N."XV(#(P,#8O,#$O,#$@,C$Z,CDZ,#(@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=+4D].
M3TQ)5$A?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E
M($M23TY/3$E42%]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N
M8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]$87E6:65W+G!H<"<["@II9B`H
M)'1I;65S=&%M<"`]("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)W1I;65S=&%M
M<"<I*2!["B`@("`D9&%Y(#T@)FYE=R!(;W)D95]$871E*"1T:6UE<W1A;7`I
M.PH@("`@;&ES="@D>65A<BP@)&UO;G1H+"`D9&%Y*2`](&%R<F%Y*"1D87DM
M/GEE87(L("1D87DM/FUO;G1H+"`D9&%Y+3YM9&%Y*3L*?2!E;'-E('L*("`@
M("1Y96%R(#T@*&EN="E5=&EL.CIG971&;W)M1&%T82@G>65A<B<I.PH@("`@
M)&UO;G1H(#T@*&EN="E5=&EL.CIG971&;W)M1&%T82@G;6]N=&@G*3L*("`@
M("1D87D@/2`H:6YT*55T:6PZ.F=E=$9O<FU$871A*"=M9&%Y)RD["GT*)&1A
M>4]B(#T@)FYE=R!+<F]N;VQI=&A?1&%Y5FEE=R@D;6]N=&@L("1D87DL("1Y
M96%R*3L*)'1I=&QE(#T@)&1A>4]B+3YG9714:6UE*"1P<F5F<RT^9V5T5F%L
M=64H)V1A=&5?9F]R;6%T)RDI.PHD<')I;G1?=FEE=R`]("AB;V]L*55T:6PZ
M.F=E=$9O<FU$871A*"=P<FEN="<I.PH*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)W1O;VQT:7`N:G,G+"`G:&]R9&4G+"!T<G5E*3L*2&]R9&4Z.F%D9%-C<FEP
M=$9I;&4H)W-T<FEP92YJ<R<L("=K<F]N;VQI=&@G+"!T<G5E*3L*:68@*"$D
M<')I;G1?=FEE=RD@>PH@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W!O<'5P
M+FIS)RP@)VAO<F1E)RP@=')U92D["GT*<F5Q=6ER92!+4D].3TQ)5$A?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["@II9B`H)'!R:6YT7W9I
M97<I('L*("`@(')E<75I<F5?;VYC92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA
M=&5S)RP@)VAO<F1E)RD@+B`G+VIA=F%S8W)I<'0O<')I;G0N:G,G.PI](&5L
M<V4@>PH@("`@)'!R:6YT7VQI;FL@/2!5=&EL.CIA9&1087)A;65T97(H)V1A
M>2YP:'`G+"!A<G)A>2@G;6]N=&@G(#T^("1M;VYT:"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUD
M87DG(#T^("1D87DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=Y96%R)R`]/B`D>65A<BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1I;65S=&%M<"<@/3X@)'1I;65S=&%M<"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!R:6YT
M)R`]/B`G=')U92<I*3L*("`@("1P<FEN=%]L:6YK(#T@2&]R9&4Z.G5R;"@D
M<')I;G1?;&EN:RD["B`@("!R97%U:7)E($M23TY/3$E42%]414U03$%415,@
M+B`G+VUE;G4N:6YC)SL*?0H*96-H;R`G/&1I=B!I9#TB<&%G92(^)SL*:68@
M*"$D<')I;G1?=FEE=RD@>PH@("`@2W)O;F]L:71H.CIT86)S*"D["GT*)&1A
M>4]B+3YH=&UL*$M23TY/3$E42%]414U03$%415,I.PIE8VAO("<\+V1I=CXG
M.PIR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G
M*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:W)O;F]L:71H+V1A=&$N<&AP````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-S<W,@`Q,#0Q-S,V,C<U,P`P,C`P
M-S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+V1A=&$N<&AP+'8@,2XW
M,BXR+C@@,C`P-B\P,2\P,2`R,3HR.3HP,B!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#$M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+V=P;"YH=&UL+@H@*B\*"F9U;F-T:6]N(%]C;&5A;G5P*"D*>PH@("`@
M9VQO8F%L("1I;7!O<G1?<W1E<#L*("`@("1I;7!O<G1?<W1E<"`](#$["B`@
M("!R971U<FX@24U03U)47T9)3$4["GT*"D!D969I;F4H)TM23TY/3$E42%]"
M05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@2U)/3D],
M251(7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O1&%T82YP:'`G.PH*:68@*"$D8V]N9ELG;65N=2==6R=I;7!O<G1?97AP
M;W)T)UTI('L*("`@(')E<75I<F4@2U)/3D],251(7T)!4T4@+B`G+VEN9&5X
M+G!H<"<["B`@("!E>&ET.PI]"@HO*B!);7!O<G1A8FQE(&9I;&4@='EP97,N
M("HO"B1F:6QE7W1Y<&5S(#T@87)R87DH)V-S=B<@("`@("`@/3X@7R@B0V]M
M;6$@<V5P87)A=&5D('9A;'5E<R(I+`H@("`@("`@("`@("`@("`@("`@("=I
M8V%L96YD87(G(#T^(%\H(G9#86QE;F1A<B]I0V%L96YD87(B*2D["@HO*B!4
M96UP;&%T97,@9F]R('1H92!D:69F97)E;G0@:6UP;W)T('-T97!S+B`J+PHD
M=&5M<&QA=&5S(#T@87)R87DH"B`@("!)35!/4E1?0U-6(#T^(&%R<F%Y*"1R
M96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O9&%T82]C
M<W9I;F9O+FEN8R<I+`H@("`@24U03U)47TU!4%!%1"`]/B!A<G)A>2@D<F5G
M:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V1A=&$O8W-V
M;6%P+FEN8R<I+`H@("`@24U03U)47T1!5$5424U%(#T^(&%R<F%Y*"1R96=I
M<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O9&%T82]D871E
M;6%P+FEN8R<I"BD["FEF("A+<F]N;VQI=&@Z.FAA<U!E<FUI<W-I;VXH)VUA
M>%]E=F5N=',G*2`A/3T@=')U92`F)@H@("`@2W)O;F]L:71H.CIH87-097)M
M:7-S:6]N*"=M87A?979E;G1S)RD@/#T@2W)O;F]L:71H.CIC;W5N=$5V96YT
M<R@I*2!["B`@("`D;65S<V%G92`]($!H=&UL<W!E8VEA;&-H87)S*'-P<FEN
M=&8H7R@B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&5V96YT<RXB*2P@2W)O;F]L:71H.CIH87-097)M:7-S:6]N*"=M87A?
M979E;G1S)RDI+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["B`@
M("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P97)M<V1E;FEE9"==*2D@
M>PH@("`@("`@("1M97-S86=E(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?<&5R;7-?
M:&]O:U]D96YI960G+"!A<G)A>2@G:W)O;F]L:71H.FUA>%]E=F5N=',G*2P@
M)VAO<F1E)RP@)&UE<W-A9V4I.PH@("`@?0H@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"@D;65S<V%G92P@)VAO<F1E+G=A<FYI;F<G+"!A<G)A>2@G8V]N=&5N
M="YR87<G*2D["B`@("`D=&5M<&QA=&5S6TE-4$]25%]&24Q%72`](&%R<F%Y
M*$M23TY/3$E42%]414U03$%415,@+B`G+V1A=&$O97AP;W)T+FEN8R<I.PI]
M(&5L<V4@>PH@("`@)'1E;7!L871E<UM)35!/4E1?1DE,15T@/2!A<G)A>2A+
M4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]D871A+VEM<&]R="YI;F,G+"!+4D].
M3TQ)5$A?5$5-4$Q!5$53("X@)R]D871A+V5X<&]R="YI;F,G*3L*?0H*+RH@
M26YI=&EA;"!V86QU97,N("HO"B1I;7!O<G1?<W1E<"`@(#T@571I;#HZ9V5T
M1F]R;41A=&$H)VEM<&]R=%]S=&5P)RP@,"D@*R`Q.PHD86-T:6]N240@("`@
M("`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PHD;F5X=%]S=&5P
M("`@("`]($E-4$]25%]&24Q%.PHD87!P7V9I96QD<R`@("`](&%R<F%Y*"=T
M:71L92<@/3X@7R@B5&ET;&4B*2P*("`@("`@("`@("`@("`@("`@("`@("`G
M<W1A<G1?9&%T92<@/3X@7R@B4W1A<G0@1&%T92(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("=S=&%R=%]T:6UE)R`]/B!?*")3=&%R="!4:6UE(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@)V5N9%]D871E)R`]/B!?*")%;F0@1&%T
M92(I+`H@("`@("`@("`@("`@("`@("`@("`@("=E;F1?=&EM92<@/3X@7R@B
M16YD(%1I;64B*2P*("`@("`@("`@("`@("`@("`@("`@("`G86QA<FTG(#T^
M(%\H(D%L87)M(%-P86X@*&UI;G5T97,I(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@)V%L87)M7V1A=&4G(#T^(%\H(D%L87)M($1A=&4B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`G86QA<FU?=&EM92<@/3X@7R@B06QA<FT@5&EM
M92(I+`H@("`@("`@("`@("`@("`@("`@("`@("=D97-C<FEP=&EO;B<@/3X@
M7R@B1&5S8W)I<'1I;VXB*2P*("`@("`@("`@("`@("`@("`@("`@("`G8V%T
M96=O<GDG(#T^(%\H(D-A=&5G;W)Y(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@)VQO8V%T:6]N)R`]/B!?*"),;V-A=&EO;B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("=K97EW;W)D<R<@/3X@7R@B2V5Y=V]R9',B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`G<F5C=7)?='EP92<@/3X@7R@B4F5C=7)R96YC
M92!4>7!E(BDL"B`@("`@("`@("`@("`@("`@("`@("`@)W)E8W5R7V5N9%]D
M871E)R`]/B!?*")296-U<G)E;F-E($5N9"!$871E(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@)W)E8W5R7VEN=&5R=F%L)R`]/B!?*")296-U<G)E;F-E
M($EN=&5R=F%L(BDL"B`@("`@("`@("`@("`@("`@("`@("`@)W)E8W5R7V1A
M=&$G(#T^(%\H(E)E8W5R<F5N8V4@1&%T82(I*3L*)'1I;65?9FEE;&1S("`@
M/2!A<G)A>2@G<W1A<G1?9&%T92<@("`@(#T^("=D871E)RP*("`@("`@("`@
M("`@("`@("`@("`@("`G<W1A<G1?=&EM92<@("`@(#T^("=T:6UE)RP*("`@
M("`@("`@("`@("`@("`@("`@("`G96YD7V1A=&4G("`@("`@(#T^("=D871E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`G96YD7W1I;64G("`@("`@(#T^
M("=T:6UE)RP*("`@("`@("`@("`@("`@("`@("`@("`G<F5C=7)?96YD7V1A
M=&4G(#T^("=D871E)RD["B1P87)A;2`@("`@("`@(#T@87)R87DH)W1I;65?
M9FEE;&1S)R`]/B`D=&EM95]F:65L9',L"B`@("`@("`@("`@("`@("`@("`@
M("`@)V9I;&5?='EP97,G("`]/B`D9FEL95]T>7!E<RD["B1I;7!O<G1?9F]R
M;6%T(#T@571I;#HZ9V5T1F]R;41A=&$H)VEM<&]R=%]F;W)M870G+"`G)RD[
M"B1E<G)O<B`@("`@("`@(#T@9F%L<V4["@HO*B!,;V]P('1H<F]U9V@@=&AE
M(&%C=&EO;B!H86YD;&5R<RX@*B\*<W=I=&-H("@D86-T:6]N240I('L*8V%S
M92`G97AP;W)T)SH*("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G86QL7V5V
M96YT<R<I*2!["B`@("`@("`@)'-T87)T(#T@;G5L;#L*("`@("`@("`D96YD
M(#T@;G5L;#L*("`@('T@96QS92!["B`@("`@("`@)'-T87)T+3YM9&%Y(#T@
M571I;#HZ9V5T1F]R;41A=&$H)W-T87)T7V1A>2<I.PH@("`@("`@("1S=&%R
M="T^;6]N=&@@/2!5=&EL.CIG971&;W)M1&%T82@G<W1A<G1?;6]N=&@G*3L*
M("`@("`@("`D<W1A<G0M/GEE87(@/2!5=&EL.CIG971&;W)M1&%T82@G<W1A
M<G1?>65A<B<I.PH@("`@("`@("1E;F0M/FUD87D@/2!5=&EL.CIG971&;W)M
M1&%T82@G96YD7V1A>2<I.PH@("`@("`@("1E;F0M/FUO;G1H(#T@571I;#HZ
M9V5T1F]R;41A=&$H)V5N9%]M;VYT:"<I.PH@("`@("`@("1E;F0M/GEE87(@
M/2!5=&EL.CIG971&;W)M1&%T82@G96YD7WEE87(G*3L*("`@('T*"B`@("`D
M979E;G1S(#T@87)R87DH*3L*("`@("1C86QE;F1A<G,@/2!5=&EL.CIG971&
M;W)M1&%T82@G97AP;W)T0V%L)RP@)&1I<W!L87E?8V%L96YD87)S*3L*("`@
M(&EF("@A:7-?87)R87DH)&-A;&5N9&%R<RDI('L*("`@("`@("`D8V%L96YD
M87)S(#T@87)R87DH)&-A;&5N9&%R<RD["B`@("!]"B`@("!F;W)E86-H("@D
M8V%L96YD87)S(&%S("1C86PI('L*("`@("`@("!I9B`H)&MR;VYO;&ET:"T^
M9V5T0V%L96YD87(H*2`A/2`D8V%L*2!["B`@("`@("`@("`@("1K<F]N;VQI
M=&@M/F-L;W-E*"D["B`@("`@("`@("`@("1K<F]N;VQI=&@M/F]P96XH)&-A
M;"D["B`@("`@("`@?0H@("`@("`@("1E=F5N='-;)&-A;%T@/2`D:W)O;F]L
M:71H+3YL:7-T179E;G1S*"1S=&%R="P@)&5N9"D["B`@("!]"@H@("`@:68@
M*"%C;W5N="@D979E;G1S*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H7R@B5&AE<F4@=V5R92!N;R!E=F5N=',@=&\@97AP;W)T+B(I+"`G:&]R
M9&4N;65S<V%G92<I.PH@("`@("`@("1E<G)O<B`]('1R=64["B`@("`@("`@
M8G)E86L["B`@("!](&5L<V4@>PH@("`@("`@("1E>'!O<G1)1"`](%5T:6PZ
M.F=E=$9O<FU$871A*"=E>'!O<G1)1"<I.PH@("`@("`@('-W:71C:"`H)&5X
M<&]R=$E$*2!["B`@("`@("`@8V%S92!%6%!/4E1?0U-6.@H@("`@("`@("`@
M("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1E=F5N
M=',@87,@)&-A;"`]/B`D8V%L979E;G1S*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&MR;VYO;&ET:"T^9V5T0V%L96YD87(H*2`A/2`D8V%L*2!["B`@("`@
M("`@("`@("`@("`@("`@)&MR;VYO;&ET:"T^8VQO<V4H*3L*("`@("`@("`@
M("`@("`@("`@("`D:W)O;F]L:71H+3YO<&5N*"1C86PI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&-A;&5V96YT<R!A
M<R`D979E;G1)9"D@>PH@("`@("`@("`@("`@("`@("`@("1E=F5N="`]("8D
M:W)O;F]L:71H+3YG971%=F5N="@D979E;G1)9"D["@H@("`@("`@("`@("`@
M("`@("`@("1R;W<@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("1R
M;W=;)W1I=&QE)UT@/2`D979E;G0M/F=E=%1I=&QE*"D["B`@("`@("`@("`@
M("`@("`@("`@)')O=ULG8V%T96=O<GDG72`]("1E=F5N="T^8V%T96=O<GD[
M"B`@("`@("`@("`@("`@("`@("`@)')O=ULG;&]C871I;VXG72`]("1E=F5N
M="T^;&]C871I;VX["B`@("`@("`@("`@("`@("`@("`@)')O=ULG9&5S8W)I
M<'1I;VXG72`]("1E=F5N="T^9&5S8W)I<'1I;VX["B`@("`@("`@("`@("`@
M("`@("`@)')O=ULG:V5Y=V]R9',G72`](&EM<&QO9&4H)RPG+"`D979E;G0M
M/FME>7=O<F1S*3L*("`@("`@("`@("`@("`@("`@("`D<F]W6R=S=&%R=%]D
M871E)UT@/2!S<')I;G1F*"<E9"TE,#)D+24P,F0G+"`D979E;G0M/G-T87)T
M+3YY96%R+"`D979E;G0M/G-T87)T+3YM;VYT:"P@)&5V96YT+3YS=&%R="T^
M;61A>2D["B`@("`@("`@("`@("`@("`@("`@)')O=ULG<W1A<G1?=&EM92==
M(#T@<W!R:6YT9B@G)3`R9#HE,#)D.B4P,F0G+"`D979E;G0M/G-T87)T+3YH
M;W5R+"`D979E;G0M/G-T87)T+3YM:6XL("1E=F5N="T^<W1A<G0M/G-E8RD[
M"B`@("`@("`@("`@("`@("`@("`@)')O=ULG96YD7V1A=&4G72`]('-P<FEN
M=&8H)R5D+24P,F0M)3`R9"<L("1E=F5N="T^96YD+3YY96%R+"`D979E;G0M
M/F5N9"T^;6]N=&@L("1E=F5N="T^96YD+3YM9&%Y*3L*("`@("`@("`@("`@
M("`@("`@("`D<F]W6R=E;F1?=&EM92==(#T@<W!R:6YT9B@G)3`R9#HE,#)D
M.B4P,F0G+"`D979E;G0M/F5N9"T^:&]U<BP@)&5V96YT+3YE;F0M/FUI;BP@
M)&5V96YT+3YE;F0M/G-E8RD["B`@("`@("`@("`@("`@("`@("`@)')O=ULG
M86QA<FTG72`]("1E=F5N="T^86QA<FT["B`@("`@("`@("`@("`@("`@("`@
M)')O=ULG<F5C=7)?='EP92==(#T@)&5V96YT+3YR96-U<E1Y<&4["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1E=F5N="T^<F5C=7)4>7!E("$]($M23TY/
M3$E42%]214-54E].3TY%*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R
M;W=;)W)E8W5R7V5N9%]D871E)UT@/2!S<')I;G1F*"<E9"TE,#)D+24P,F0G
M+"`D979E;G0M/G)E8W5R16YD+3YY96%R+"`D979E;G0M/G)E8W5R16YD+3YM
M;VYT:"P@)&5V96YT+3YR96-U<D5N9"T^;61A>2D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1R;W=;)W)E8W5R7VEN=&5R=F%L)UT@/2`D979E;G0M/G)E
M8W5R26YT97)V86P["B`@("`@("`@("`@("`@("`@("`@("`@("1R;W=;)W)E
M8W5R7V1A=&$G72`]("1E=F5N="T^<F5C=7)$871A.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1R;W=;
M)W)E8W5R7V5N9%]D871E)UT@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<F]W6R=R96-U<E]I;G1E<G9A;"==(#T@;G5L;#L*("`@("`@("`@
M("`@("`@("`@("`@("`@)')O=ULG<F5C=7)?9&%T82==(#T@;G5L;#L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;
M72`]("1R;W<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1C<W8@/2`F2&]R9&5?1&%T83HZ<VEN9VQE=&]N*"=C<W8G
M*3L*("`@("`@("`@("`@)&-S=BT^97AP;W)T1FEL92A?*")E=F5N=',N8W-V
M(BDL("1D871A+"!T<G5E*3L*("`@("`@("`@("`@97AI=#L*"B`@("`@("`@
M8V%S92!%6%!/4E1?24-!3$5.1$%2.@H@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H<"<["B`@("`@("`@("`@("1I0V%L
M(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1E=F5N=',@87,@)&-A;"`]/B`D8V%L979E;G1S*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&MR;VYO;&ET:"T^9V5T0V%L96YD87(H*2`A/2`D8V%L
M*2!["B`@("`@("`@("`@("`@("`@("`@)&MR;VYO;&ET:"T^8VQO<V4H*3L*
M("`@("`@("`@("`@("`@("`@("`D:W)O;F]L:71H+3YO<&5N*"1C86PI.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1I9&5N=&ET>2`]
M("8D:W)O;F]L:71H7W-H87)E<RT^9V5T261E;G1I='E">5-H87)E*"1K<F]N
M;VQI=&A?<VAA<F5S+3YG9713:&%R92@D8V%L*2D["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D8V%L979E;G1S(&%S("1I9"D@>PH@("`@("`@("`@("`@
M("`@("`@("1E=F5N="`]("8D:W)O;F]L:71H+3YG971%=F5N="@D:60I.PH@
M("`@("`@("`@("`@("`@("`@("1I0V%L+3YA9&1#;VUP;VYE;G0H)&5V96YT
M+3YT;VE#86QE;F1A<B@D:4-A;"P@)&ED96YT:71Y*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1A=&$@/2`D:4-A
M;"T^97AP;W)T=D-A;&5N9&%R*"D["B`@("`@("`@("`@("1B<F]W<V5R+3YD
M;W=N;&]A9$AE861E<G,H7R@B979E;G1S+FEC<R(I+"`G=&5X="]C86QE;F1A
M<B<L(&9A;'-E+"!S=')L96XH)&1A=&$I*3L*("`@("`@("`@("`@96-H;R`D
M9&%T83L*("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"B`@("!B
M<F5A:SL*"F-A<V4@24U03U)47T9)3$4Z"B`@("`D7U-%4U-)3TY;)VEM<&]R
M=%]D871A)UU;)VEM<&]R=%]C86PG72`](%5T:6PZ.F=E=$9O<FU$871A*"=I
M;7!O<G1#86PG*3L*("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG<'5R
M9V4G72`](%5T:6PZ.F=E=$9O<FU$871A*"=P=7)G92<I.PH@("`@8G)E86L[
M"GT*"FEF("@A)&5R<F]R*2!["B`@("`D9&%T82`]("9(;W)D95]$871A.CIS
M:6YG;&5T;VXH)&EM<&]R=%]F;W)M870I.PH@("`@:68@*&ES7V$H)&1A=&$L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*%\H(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@)&YE>'1?<W1E<"`]($E-4$]25%]&24Q%
M.PH@("`@?2!E;'-E('L*("`@("`@("!I9B`H)&%C=&EO;DE$(#T]($E-4$]2
M5%]&24Q%*2!["B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D
M7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VEM<&]R=%]C86PG72P@2W)O;F]L
M:71H.CIL:7-T0V%L96YD87)S*"DI*2!["B`@("`@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*%\H(EEO=2!H879E('-P96-I9FEE9"!A;B!I;G9A
M;&ED(&-A;&5N9&%R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@
M("`@("1N97AT7W-T97`@/2`D9&%T82T^8VQE86YU<"@I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1K<F]N;VQI
M=&A?<VAA<F5S+3YG9713:&%R92@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;
M)VEM<&]R=%]C86PG72D["B`@("`@("`@("`@("`@("!I9B`H(21S:&%R92T^
M:&%S4&5R;6ES<VEO;BA!=71H.CIG971!=71H*"DL(%!%4DU37T5$250I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!A9&0@979E;G1S('1O('1H
M92!S96QE8W1E9"!C86QE;F1A<BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@
M("`@("`@("`@("`@("`@)&YE>'1?<W1E<"`]("1D871A+3YC;&5A;G5P*"D[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1N97AT7W-T97`@/2`D9&%T82T^;F5X=%-T97`H)&%C=&EO;DE$+"`D<&%R
M86TI.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1N97AT7W-T97`L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"@D;F5X=%]S=&5P+3YG971-97-S86=E*"DL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5X=%]S
M=&5P(#T@)&1A=&$M/F-L96%N=7`H*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D;F5X=%]S=&5P(#T@)&1A=&$M/FYE>'13=&5P
M*"1A8W1I;VY)1"P@)'!A<F%M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&YE
M>'1?<W1E<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"@D;F5X=%]S=&5P+3YG971-97-S86=E*"DL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@)&YE>'1?<W1E<"`]("1D
M871A+3YC;&5A;G5P*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"GT*"B\J(%=E(&AA=F4@82!F:6YA;"!R97-U;'0@<V5T+B`J+PII9B`H:7-?
M87)R87DH)&YE>'1?<W1E<"DI('L*("`@("1E=F5N=',@/2!A<G)A>2@I.PH@
M("`@)&5R<F]R(#T@9F%L<V4["B`@("`D;6%X7V5V96YT<R`]($MR;VYO;&ET
M:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I.PH@("`@:68@*"1M87A?
M979E;G1S("$]/2!T<G5E*2!["B`@("`@("`@)&YU;5]E=F5N=',@/2!+<F]N
M;VQI=&@Z.F-O=6YT179E;G1S*"D["B`@("!]"B`@("`D:W)O;F]L:71H+3YO
M<&5N*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:6UP;W)T7V-A;"==*3L*
M"B`@("`O*B!0=7)G92!O;&0@8V%L96YD87(@:68@<F5Q=65S=&5D+B`J+PH@
M("`@:68@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG<'5R9V4G72D@>PH@
M("`@("`@("1R97-U;'0@/2`D:W)O;F]L:71H+3YD96QE=&4H)%]315-324].
M6R=I;7!O<G1?9&%T82==6R=I;7!O<G1?8V%L)UTI.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!C86QE;F1A<B!C;W5L
M9"!N;W0@8F4@<'5R9V5D.B`E<R(I+"`D<F5S=6QT+3YG971-97-S86=E*"DI
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D-A;&5N9&%R('-U8V-E<W-F=6QL
M>2!P=7)G960N(BDL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@?0H@("`@
M?0H*("`@(&9O<F5A8V@@*"1N97AT7W-T97`@87,@)')O=RD@>PH@("`@("`@
M(&EF("@D;6%X7V5V96YT<R`A/3T@=')U92`F)B`D;G5M7V5V96YT<R`^/2`D
M;6%X7V5V96YT<RD@>PH@("`@("`@("`@("`D;65S<V%G92`]($!H=&UL<W!E
M8VEA;&-H87)S*'-P<FEN=&8H7R@B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&5V96YT<RXB*2P@2W)O;F]L:71H.CIH87-0
M97)M:7-S:6]N*"=M87A?979E;G1S)RDI+"!%3E1?0T]-4$%4+"!.3%,Z.F=E
M=$-H87)S970H*2D["B`@("`@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO
M;VMS)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@("`@("`@("`@("`D;65S
M<V%G92`]($AO<F1E.CIC86QL2&]O:R@G7W!E<FUS7VAO;VM?9&5N:65D)RP@
M87)R87DH)VMR;VYO;&ET:#IM87A?979E;G1S)RDL("=H;W)D92<L("1M97-S
M86=E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*"1M97-S86=E+"`G:&]R9&4N97)R;W(G+"!A<G)A>2@G8V]N=&5N
M="YR87<G*2D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@("`@
M("`D979E;G0@/2`F)&MR;VYO;&ET:"T^9V5T179E;G0H*3L*("`@("`@("!I
M9B`H(21E=F5N="!\?"!I<U]A*"1E=F5N="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`D;7-G(#T@7R@B0V%N)W0@8W)E871E(&$@;F5W(&5V96YT
M+B(I.PH@("`@("`@("`@("!I9B`H:7-?82@D979E;G0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("1M<V<@+CT@)R`G("X@<W!R:6YT9BA?
M*")4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(I+"`D979E;G0M
M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"@D;7-G+"`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("`@("`@)&5R<F]R(#T@=')U93L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<U]A*"1R;W<L("=(;W)D95]I0V%L96YD87)?
M=F5V96YT)RDI('L*("`@("`@("`@("`@)&5V96YT+3YF<F]M:4-A;&5N9&%R
M*"1R;W<I.PH@("`@("`@('T@96QS96EF("AI<U]A*"1R;W<L("=(;W)D95]I
M0V%L96YD87(G*2D@>PH@("`@("`@("`@("`O+R!3:VEP(&]T:&5R(&E#86QE
M;F1A<B!C;VUP;VYE;G1S(&9O<B!N;W<N"B`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V86QI9"`]("1E=F5N
M="T^9G)O;4AA<V@H)')O=RD["B`@("`@("`@("`@(&EF("AI<U]A*"1V86QI
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"@D=F%L:60L("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("`@("`@)&5R<F]R(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W5C8V5S<R`]("1E
M=F5N="T^<V%V92@I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M)'-U8V-E<W,L("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`D97)R;W(@
M/2!T<G5E.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@
M(&EF("@D;6%X7V5V96YT<R`A/3T@=')U92D@>PH@("`@("`@("`@("`D;G5M
M7V5V96YT<RLK.PH@("`@("`@('T*("`@('T*("`@(&EF("@A)&5R<F]R*2![
M"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(B5S(&9I
M;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F:6QE7W1Y<&5S6R1?4T534TE/3ELG:6UP
M;W)T7V1A=&$G75LG9F]R;6%T)UU=*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@
M('T*("`@("1N97AT7W-T97`@/2`D9&%T82T^8VQE86YU<"@I.PI]"@HD=&ET
M;&4@/2!?*"));7!O<G0O17AP;W)T($-A;&5N9&%R(BD["G)E<75I<F4@2U)/
M3D],251(7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U
M:7)E($M23TY/3$E42%]414U03$%415,@+B`G+VUE;G4N:6YC)SL*"F5C:&\@
M)SQD:78@:60](G!A9V4B/B<["F9O<F5A8V@@*"1T96UP;&%T97-;)&YE>'1?
M<W1E<%T@87,@)'1E;7!L871E*2!["B`@("!R97%U:7)E("1T96UP;&%T93L*
M?0IE8VAO("<\+V1I=CXG.PH*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M
M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O8V]N=&%C
M=',N<&AP````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T
M-S0S`#$P-#$W,S8R-S4S`#`R,#<W,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!K<F]N
M;VQI=&@O8V]N=&%C=',N<&AP+'8@,2XQ-BXQ,"XT(#(P,#8O,#$O,#$@,C$Z
M,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36%R
M8W5S($DN(%)Y86X@/&UA<F-U<T!R:6)O9FQA=FEN+FYE=#X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL
M+@H@*B\*"F1E9FEN92@G2U)/3D],251(7T)!4T4G+"!D:7)N86UE*%]?1DE,
M15]?*2D["G)E<75I<F5?;VYC92!+4D].3TQ)5$A?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*"FEF("@A075T:#HZ9V5T075T:"@I*2!["B`@("!5=&EL.CIC
M;&]S95=I;F1O=TI3*"D["B`@("!E>&ET.PI]"@HO*B!'970@=&AE(&QI<W1S
M(&]F(&%D9')E<W,@8F]O:W,@=&AR;W5G:"!!4$D@*B\*)'-O=7)C95]L:7-T
M(#T@)')E9VES=')Y+3YC86QL*"=C;VYT86-T<R]S;W5R8V5S)RD["@HO*B!)
M9B!W92!S96QF+7-U8FUI='1E9"P@=7-E('1H870@<V]U<F-E+B!/=&AE<G=I
M<V4L(&-H;V]S92!A(&=O;V0*("H@<V]U<F-E+B`J+PHD<V]U<F-E(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W-O=7)C92<I.PII9B`H96UP='DH)'-O=7)C92D@
M?'P@(6ES<V5T*"1S;W5R8V5?;&ES=%LD<V]U<F-E72DI('L*("`@("\J(%=E
M(&1O;B=T(&IU<W0@<&%S<R!T:&4@<V5C;VYD(&%R9W5M96YT('1O(&=E=$9O
M<FU$871A*"D@8F5C875S90H@("`@("H@=V4@=V%N="!T;R!T<F%P(&9O<B!I
M;G9A;&ED('-O=7)C97,L(&YO="!J=7-T(&YO('-O=7)C92X@*B\*("`@("1S
M;W5R8V4@/2!K97DH)'-O=7)C95]L:7-T*3L*?0H*+RH@1V5T('1H92!S96%R
M8V@@87,@<W5B;6ET=&5D("AD969A=6QT<R!T;R`G)R!W:&EC:"!S:&]U;&0@
M;&ES="!E=F5R>6]N92DN("HO"B1S96%R8V@@/2!5=&EL.CIG971&;W)M1&%T
M82@G<V5A<F-H)RD["B1A<&EA<F=S(#T@87)R87DH*3L*)&%P:6%R9W-;)V%D
M9')E<W-E<R==(#T@87)R87DH)'-E87)C:"D["B1A<&EA<F=S6R=A9&1R97-S
M8F]O:W,G72`](&%R<F%Y*"1S;W5R8V4I.PHD87!I87)G<ULG9FEE;&1S)UT@
M/2!A<G)A>2@I.PH*:68@*"1S96%R8VA?9FEE;&1S7W!R968@/2`D<')E9G,M
M/F=E=%9A;'5E*"=S96%R8VA?9FEE;&1S)RDI('L*("`@(&9O<F5A8V@@*&5X
M<&QO9&4H(EQN(BP@)'-E87)C:%]F:65L9'-?<')E9BD@87,@)',I('L*("`@
M("`@("`D<R`]('1R:6TH)',I.PH@("`@("`@("1S(#T@97AP;&]D92@B7'0B
M+"`D<RD["B`@("`@("`@:68@*"%E;7!T>2@D<ULP72D@)B8@*"1S6S!=(#T]
M("1S;W5R8V4I*2!["B`@("`@("`@("`@("1A<&EA<F=S6R=F:65L9',G75MA
M<G)A>5]S:&EF="@D<RE=(#T@)',["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*("`@('T*?0H*:68@*"1S96%R8V@@?'P@)'!R969S+3YG971686QU
M92@G9&ES<&QA>5]C;VYT86-T)RDI('L*("`@("1R97-U;'1S(#T@)')E9VES
M=')Y+3YC86QL*"=C;VYT86-T<R]S96%R8V@G+"`D87!I87)G<RD["GT@96QS
M92!["B`@("`D<F5S=6QT<R`](&%R<F%Y*"D["GT*"B\J(%1H92!R97-U;'1S
M(&QI<W0@<F5T=7)N<R!A;B!A<G)A>2!F;W(@96%C:"!S;W5R8V4@<V5A<F-H
M960@+2!A="!L96%S=`H@("!T:&%T)W,@:&]W(&ET(&QO;VMS('1O(&UE+B!-
M86ME(&ET(&%L;"!O;F4@87)R87D@:6YS=&5A9"X@*B\*)&%D9')E<W-E<R`]
M(&%R<F%Y*"D["FEF("@A:7-?82@D<F5S=6QT<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@9F]R96%C:"`H)')E<W5L=',@87,@)'(I('L*("`@("`@("`D861D
M<F5S<V5S(#T@87)R87E?;65R9V4H)&%D9')E<W-E<RP@)'(I.PH@("`@?0I]
M"@HO*B!)9B!S96QF+7-U8FUI='1E9"P@<')E<V5R=F4@=&AE(&-U<G)E;G1L
M>2!S96QE8W1E9"!U<V5R<R!E;F-O9&5D(&)Y"B`@(&IA=F%S8W)I<'0@=&\@
M<&%S<R!A<R!V86QU97QT97AT+B`J+PHD<V5L96-T961?861D<F5S<V5S(#T@
M87)R87DH*3L*)'-A(#T@97AP;&]D92@G?"<L(%5T:6PZ.F=E=$9O<FU$871A
M*"=S82<I*3L*9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'-A*2`M(#$[("1I
M("L](#(I('L*("`@("1S96QE8W1E9%]A9&1R97-S97-;)'-A6R1I75T@/2`D
M<V%;)&D@*R`Q73L*?0H*+RH@4V5T('1H92!D969A=6QT(&QI<W0@9&ES<&QA
M>2`H;F%M92!O<B!E;6%I;"DN("HO"B1D:7-P;&%Y(#T@571I;#HZ9V5T1F]R
M;41A=&$H)V1I<W!L87DG+"`G;F%M92<I.PH*+RH@1&ES<&QA>2!T:&4@9F]R
M;2X@*B\*)'1I=&QE(#T@7R@B061D<F5S<R!";V]K(BD["G)E<75I<F4@2U)/
M3D],251(7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U
M:7)E($M23TY/3$E42%]414U03$%415,@+B`G+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8R<["G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N
M;VQI=&@O8V%L96YD87)S+G!H<```````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$Q-3$R`#$P-#$W,S8R-S4S`#`R,3`W-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!K<F]N;VQI=&@O8V%L96YD87)S+G!H<"QV(#$N-#8N,BXU(#(P
M,#8O,#$O,#$@,C$Z,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@2F]E;"!686YD86P@/&IV86YD86Q`:6YF;W1E8VLN<6,N8V$^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2U)/3D],251(7T)!4T4G+"!D
M:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!+4D].3TQ)5$A?0D%3
M12`N("<O;&EB+V)A<V4N<&AP)SL*"B\O($5X:70@:68@=&AI<R!I<VXG="!A
M;B!A=71H96YT:6-A=&5D('5S97(N"FEF("@A075T:#HZ9V5T075T:"@I*2![
M"B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"1P<F5F<RT^9V5T5F%L=64H)V1E9F%U;'1V:65W)RD@+B`G+G!H<"<I
M*3L*("`@(&5X:70["GT*"B\O(%)U;B!T:')O=6=H('1H92!A8W1I;VX@:&%N
M9&QE<G,N"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)
M1"<I.PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=S879E)SH*("`@("1T
M;U]E9&ET(#T@571I;#HZ9V5T1F]R;41A=&$H)V5D:71?<VAA<F4G*3L*("`@
M("1I9"`](%5T:6PZ.F=E=$9O<FU$871A*"=I9"<I.PH@("`@:68@*&5M<'1Y
M*"1I9"DI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D-A;&5N
M9&%R<R!M=7-T(&AA=F4@82!N86UE+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!B<F5A:SL*("`@('T*"B`@("!I9B`H(7-T<FQE;B@D=&]?961I="DI
M('L*("`@("`@("`O+R!#<F5A=&4@;F5W('-H87)E+@H@("`@("`@("1C86P@
M/2`D:W)O;F]L:71H7W-H87)E<RT^;F5W4VAA<F4H;60U*&UI8W)O=&EM92@I
M*2D["B`@("`@("`@)&-A;"T^<V5T*"=N86UE)RP@)&ED*3L*("`@("`@("`D
M8V%L+3YS970H)V1E<V,G+"!5=&EL.CIG971&;W)M1&%T82@G9&5S8W)I<'1I
M;VXG+"`G)RDI.PH@("`@("`@("1R97-U;'0@/2`D:W)O;F]L:71H7W-H87)E
M<RT^861D4VAA<F4H)&-A;"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*"1R97-U;'0L("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4
M:&4@8V%L96YD87(@7"(E<UPB(&AA<R!B965N(&-R96%T960N(BDL("1I9"DL
M("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@
M("`@("`D8V%L(#T@)B1K<F]N;VQI=&A?<VAA<F5S+3YG9713:&%R92@D=&]?
M961I="D["B`@("`@("`@)&]R:6=I;F%L7VYA;64@/2`D8V%L+3YG970H)VYA
M;64G*3L*("`@("`@("`D8V%L+3YS970H)VYA;64G+"`D:60I.PH@("`@("`@
M("1C86PM/G-E="@G9&5S8R<L(%5T:6PZ.F=E=$9O<FU$871A*"=D97-C<FEP
M=&EO;B<L("<G*2D["@H@("`@("`@(&EF("@D;W)I9VEN86Q?;F%M92`A/2`D
M:60I('L*("`@("`@("`@("`@)')E<W5L="`]("1K<F]N;VQI=&@M/G)E;F%M
M92@D;W)I9VEN86Q?;F%M92P@)&ED*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E5N86)L92!T;R!R96YA;64@
M7"(E<UPB.B`E<R(I+"`D;W)I9VEN86Q?;F%M92P@)')E<W5L="T^9V5T365S
M<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*'-P<FEN=&8H7R@B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!R
M96YA;65D('1O(%PB)7-<(BXB*2P@)&]R:6=I;F%L7VYA;64L("1I9"DL("=H
M;W)D92YS=6-C97-S)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!C86QE;F1A<B!<
M(B5S7"(@:&%S(&)E96X@<V%V960N(BDL("1I9"DL("=H;W)D92YS=6-C97-S
M)RD["B`@("`@("`@?0H*("`@("`@("`D8V%L+3YS879E*"D["B`@("!]"@H@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G8V%L96YD87)S+G!H<"<L('1R=64I*3L*("`@(&5X:70["@IC87-E("=D
M96QE=&4G.@H@("`@)'1O7V1E;&5T92`](%5T:6PZ.F=E=$9O<FU$871A*"=E
M9&ET7W-H87)E)RD["B`@("`D:60@/2!5=&EL.CIG971&;W)M1&%T82@G:60G
M*3L*"B`@("!I9B`H)'1O7V1E;&5T92`]/2!!=71H.CIG971!=71H*"DI('L*
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&-A
M;&5N9&%R(%PB)7-<(B!C86YN;W0@8F4@9&5L971E9"XB*2P@)&ED*2P@)VAO
M<F1E+G=A<FYI;F<G*3L*("`@("`@("!B<F5A:SL*("`@('T*"B`@("!I9B`H
M:7-S970H)'1O7V1E;&5T92DI('L*("`@("`@("`D<VAA<F4@/2`D:W)O;F]L
M:71H7W-H87)E<RT^9V5T4VAA<F4H)'1O7V1E;&5T92D["B`@("`@("`@:68@
M*&ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3:&%R92!N;W0@9F]U;F0Z
M("5S(BDL("1S:&%R92T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@1&5L
M971E('1H92!C86QE;F1A<BX*("`@("`@("`D<F5S=6QT(#T@)&MR;VYO;&ET
M:"T^9&5L971E*"1T;U]D96QE=&4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"AS<')I;G1F*%\H(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<R(I+"`D<VAA<F4M/F=E="@G;F%M92<I+"`D<F5S=6QT+3YG971-97-S86=E
M*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O+R!296UO=F4@<VAA<F4@86YD(&%L;"!G<F]U<',O<&5R;6ES<VEO
M;G,N"B`@("`@("`@("`@("1K<F]N;VQI=&A?<VAA<F5S+3YR96UO=F53:&%R
M92@D<VAA<F4I.PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P
M<FEN=&8H7R@B5&AE(&-A;&5N9&%R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(I+"`D<VAA<F4M/F=E="@G;F%M92<I*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H7R@B66]U(&UU<W0@<V5L96-T(&$@8V%L96YD87(@=&\@8F4@9&5L
M971E9"XB*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@('T*"B`@("`O+R!-86ME
M('-U<F4@=V4@<W1I;&P@;W=N(&%T(&QE87-T(&]N92!C86QE;F1A<BX*("`@
M(&EF("AC;W5N="A+<F]N;VQI=&@Z.FQI<W1#86QE;F1A<G,H=')U92DI(#T]
M(#`I('L*("`@("`@("`O+R!)9B!T:&ES('-H87)E(&1O97-N)W0@97AI<W0@
M=&AE;B!C<F5A=&4@:70N"B`@("`@("`@:68@*"$D:W)O;F]L:71H7W-H87)E
M<RT^97AI<W1S*$%U=&@Z.F=E=$%U=&@H*2DI('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@("`@("`D
M:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@I.PH@("`@("`@("`@
M("`D;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN86UE)RD["B`@
M("`@("`@("`@(&EF("AT<FEM*"1N86UE*2`]/2`G)RD@>PH@("`@("`@("`@
M("`@("`@)&YA;64@/2!!=71H.CIR96UO=F5(;V]K*$%U=&@Z.F=E=$%U=&@H
M*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-H87)E(#T@)B1K<F]N
M;VQI=&A?<VAA<F5S+3YN97=3:&%R92A!=71H.CIG971!=71H*"DI.PH@("`@
M("`@("`@("`D<VAA<F4M/G-E="@G;F%M92<L('-P<FEN=&8H7R@B)7,G<R!#
M86QE;F1A<B(I+"`D;F%M92DI.PH@("`@("`@("`@("`D:W)O;F]L:71H7W-H
M87)E<RT^861D4VAA<F4H)'-H87)E*3L*("`@("`@("`@("`@)&%L;%]C86QE
M;F1A<G-;075T:#HZ9V5T075T:"@I72`]("1S:&%R93L*("`@("`@("!]"B`@
M("!]"@H@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@G8V%L96YD87)S+G!H<"<L('1R=64I*3L*("`@(&5X:70["GT*
M"B1R96UO=&5?8V%L96YD87)S(#T@=6YS97)I86QI>F4H)'!R969S+3YG9716
M86QU92@G<F5M;W1E7V-A;',G*2D["B1C=7)R96YT7W5S97(@/2!!=71H.CIG
M971!=71H*"D["B1M>5]C86QE;F1A<G,@/2!A<G)A>2@I.PHD<VAA<F5D7V-A
M;&5N9&%R<R`](&%R<F%Y*"D["F9O<F5A8V@@*$MR;VYO;&ET:#HZ;&ES=$-A
M;&5N9&%R<R@I(&%S("1I9"`]/B`D8V%L*2!["B`@("!I9B`H)&-A;"T^9V5T
M*"=O=VYE<B<I(#T]("1C=7)R96YT7W5S97(I('L*("`@("`@("`D;7E?8V%L
M96YD87)S6R1I9%T@/2`D8V%L.PH@("`@?2!E;'-E('L*("`@("`@("`D<VAA
M<F5D7V-A;&5N9&%R<ULD:61=(#T@)&-A;#L*("`@('T*?0H*2&]R9&4Z.F%D
M9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U92D["B1T:71L
M92`](%\H(DUY($-A;&5N9&%R<R(I.PIR97%U:7)E($M23TY/3$E42%]414U0
M3$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!+4D].3TQ)
M5$A?5$5-4$Q!5$53("X@)R]M96YU+FEN8R<["G)E<75I<F4@2U)/3D],251(
M7U1%35!,051%4R`N("<O8V%L96YD87)S+V-A;&5N9&%R<RYI;F,G.PIR97%U
M:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O
M8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:W)O;F]L:71H+V-A;&5N9&%R7W-E87)C:"YP:'``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3<P,0`Q,#0Q-S,V,C<U,P`P,C(R-#``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+V-A;&5N9&%R7W-E87)C:"YP:'`L
M=B`Q+C(N,BXR(#(P,#8O,#$O,#$@,C$Z,CDZ,#(@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=2!D:60@;F]T"B`J
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+V=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TM23TY/3$E42%]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@2U)/3D],251(
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@II9B`H(4%U=&@Z.F=E=$%U=&@H
M*2D@>PH@("`@571I;#HZ8VQO<V57:6YD;W=*4R@I.PH@("`@97AI=#L*?0H*
M)')E<W5L=',@/2!F86QS93L*:68@*"@D<V5A<F-H(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W-E87)C:"<L("<G*2D@(3T]("<G*2!["B`@("`D<F5S=6QT<R`]
M(&%R<F%Y7V9I;'1E<B@D86QL7V-A;&5N9&%R<RP@8W)E871E7V9U;F-T:6]N
M*"<F)'-H87)E)RP@)W)E='5R;B!S=')I<W1R*"1S:&%R92T^9V5T*")N86UE
M(BDL("1'3$]"04Q36R)S96%R8V@B72D@(3T](&9A;'-E.R<I*3L*?0H*+RH@
M1&ES<&QA>2!T:&4@9F]R;2X@*B\*)'1I=&QE(#T@7R@B4VAO=R!#86QE;F1A
M<B(I.PI(;W)D93HZ861D4V-R:7!T1FEL92@G<W1R:7!E+FIS)RP@)VMR;VYO
M;&ET:"<L('1R=64I.PIR97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G
M+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!+4D].3TQ)5$A?5$5-4$Q!
M5$53("X@)R]C86QE;F1A<G,O<V5A<F-H+FEN8R<["G)E<75I<F4@)')E9VES
M=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O
M=&5R+FEN8R<["@``````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:W)O;F]L:71H+V%T=&5N9&5E<RYP:'``````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C4P,0`Q,#0Q-S,V,C<U,P`P,C$Q
M,38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+V%T=&5N9&5E<RYP:'`L
M=B`Q+C<N."XX(#(P,#8O,#(O,#,@,3$Z,C`Z,3,@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@0V]D92!&=7-I;VX@(#QH='1P.B\O=W=W
M+F-O9&5F=7-I;VXN8V\N>F$O/@H@*B`@("`@("`@("`@("`@("!3='5A<G0@
M0FEN9V4@/',N8FEN9V5`8V]D969U<VEO;BYC;RYZ83X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*
M("HO"@I`9&5F:6YE*"=+4D].3TQ)5$A?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I*3L*<F5Q=6ER95]O;F-E($M23TY/3$E42%]"05-%("X@)R]L:6(O8F%S
M92YP:'`G.PIR97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]&
M0E9I97<N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+U5)+U1A8G,N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]687)I86)L97,N<&AP)SL*"B\O($=E="!T:&4@8W5R<F5N
M="!A='1E;F1E97,@87)R87D@9G)O;2!T:&4@<V5S<VEO;B!C86-H92X*)&%T
M=&5N9&5E<R`]("AI<W-E="@D7U-%4U-)3TY;)V%T=&5N9&5E<R==*2`F)B!I
M<U]A<G)A>2@D7U-%4U-)3TY;)V%T=&5N9&5E<R==*2D@/R`D7U-%4U-)3TY;
M)V%T=&5N9&5E<R==(#H@87)R87DH*3L*"B\O($=E="!O=7(@06-T:6]N($E$
M("8@5F%L=64N(%1H:7,@<W!E8VEF:65S('=H870@86-T:6]N('1H92!U<V5R
M(&EN:71I871E9"X*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C
M=&EO;DE$)RD["FEF("A5=&EL.CIG971&;W)M1&%T82@G8VQE87)!;&PG*2D@
M>PH@("`@)&%C=&EO;DE$(#T@("=C;&5A<B<["GT*)&%C=&EO;E9A;'5E(#T@
M571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO;E9A;'5E)RD["@HO+R!097)F;W)M
M('1H92!S<&5C:69I960@86-T:6]N+"!I9B!T:&5R92!I<R!O;F4N"G-W:71C
M:"`H)&%C=&EO;DE$*2!["F-A<V4@)V%D9"<Z"B`@("`O+R!!9&0@;F5W(&%T
M=&5N9&5E<RX@375L=&EP;&4@871T96YD965S(&-A;B!B92!S97!E<F%T960@
M;VX@80H@("`@+R\@<VEN9VQE(&QI;F4@8GD@=VAI=&5S<&%C92!A;F0O;W(@
M8V]M;6%S+@H@("`@)&YE=R`]('!R96=?<W!L:70H)R];7',L72LO)RP@571I
M;#HZ9V5T1F]R;41A=&$H)VYE=T%T=&5N9&5E<R<I+"`M,2P@4%)%1U]34$Q)
M5%].3U]%35!462D["B`@("!I9B`H:7-?87)R87DH)&YE=RDI('L*("`@("`@
M("!F;W)E86-H("@D;F5W(&%S("1N97=A='1E;F1E92D@>PH@("`@("`@("`@
M("`O+R!!=F]I9"!O=F5R=W)I=&EN9R!E>&ES=&EN9R!A='1E;F1E97,@=VET
M:"!T:&4@9&5F875L="!V86QU97,*("`@("`@("`@("`@:68@*"%I<W-E="@D
M871T96YD965S6R1N97=A='1E;F1E95TI*0H@("`@("`@("`@("`@("`@)&%T
M=&5N9&5E<ULD;F5W871T96YD965=(#T@87)R87DH)V%T=&5N9&%N8V4G(#T^
M($M23TY/3$E42%]005)47U)%455)4D5$+"`G<F5S<&]N<V4G(#T^($M23TY/
M3$E42%]215-03TY315].3TY%*3L*("`@("`@("!]"B`@("!]"@H@("`@)%]3
M15-324].6R=A='1E;F1E97,G72`]("1A='1E;F1E97,["B`@("!B<F5A:SL*
M"F-A<V4@)W)E;6]V92<Z"B`@("`O+R!296UO=F4@=&AE('-P96-I9FEE9"!A
M='1E;F1E92X*("`@(&EF("AI<W-E="@D871T96YD965S6R1A8W1I;VY686QU
M95TI*2!["B`@("`@("`@=6YS970H)&%T=&5N9&5E<ULD86-T:6]N5F%L=65=
M*3L*("`@("`@("`D7U-%4U-)3TY;)V%T=&5N9&5E<R==(#T@)&%T=&5N9&5E
M<SL*("`@('T*("`@(&)R96%K.PH*8V%S92`G8VAA;F=E871T)SH*("`@("\O
M($-H86YG92!T:&4@871T96YD86YC92!S=&%T=7,@;V8@86X@871T96YD964*
M("`@(&QI<W0H)'!A<G1V86PL("1P87)T;F%M92D@/2!E>'!L;V1E*"<@)RP@
M)&%C=&EO;E9A;'5E+"`R*3L*("`@(&EF("AI<W-E="@D871T96YD965S6R1P
M87)T;F%M95TI*2!["B`@("`@("`@)&%T=&5N9&5E<ULD<&%R=&YA;65=6R=A
M='1E;F1A;F-E)UT@/2`D<&%R='9A;#L*("`@("`@("`D7U-%4U-)3TY;)V%T
M=&5N9&5E<R==(#T@)&%T=&5N9&5E<SL*("`@('T*("`@(&)R96%K.PH*8V%S
M92`G9&ES;6ES<R<Z"B`@("`O+R!#;&]S92!T:&4@871T96YD964@=VEN9&]W
M+@H@("`@:68@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI
M('L*("`@("`@("!5=&EL.CIC;&]S95=I;F1O=TI3*"D["B`@("!](&5L<V4@
M>PH@("`@("`@("1U<FP@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD["@H@
M("`@("`@(&EF("@A96UP='DH)'5R;"DI('L*("`@("`@("`@("`@)&QO8V%T
M:6]N(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1U<FPL('1R=64I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A
M;65T97(H)'!R969S+3YG971686QU92@G9&5F875L='9I97<G*2`N("<N<&AP
M)RP@)VUO;G1H)RP@571I;#HZ9V5T1F]R;41A=&$H)VUO;G1H)RDI.PH@("`@
M("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=Y96%R
M)RP@571I;#HZ9V5T1F]R;41A=&$H)WEE87(G*2D["B`@("`@("`@("`@("1L
M;V-A=&EO;B`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D=7)L+"!T<G5E*3L*
M("`@("`@("!]"@H@("`@("`@("\O($UA:V4@<W5R92!54DP@:7,@=6YI<75E
M+@H@("`@("`@("1L;V-A=&EO;B`](%5T:6PZ.F%D9%!A<F%M971E<B@D;&]C
M871I;VXL("=U;FEQ=64G+"!M9#4H;6EC<F]T:6UE*"DI*3L*"B`@("`@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1L;V-A=&EO;BD["B`@("!]"B`@("!B
M<F5A:SL*"F-A<V4@)V5X<&%N9"<Z"B`@("`O+R!.;W0@:6UP;&5M96YT960@
M>65T+@H@("`@8G)E86L["@IC87-E("=C;&5A<B<Z"B`@("`O+R!296UO=F4@
M86QL('1H92!A='1E;F1E97,N"B`@("`D871T96YD965S(#T@87)R87DH*3L*
M("`@("1?4T534TE/3ELG871T96YD965S)UT@/2`D871T96YD965S.PH@("`@
M8G)E86L["GT*"B\O($=E="!T:&4@8W5R<F5N="!&<F5E+T)U<WD@=FEE=SL@
M9&5F875L="!T;R!T:&4@)V1A>2<@=FEE=R!I9B!N;VYE('-P96-I9FEE9"X*
M)'9I97<@/2!5=&EL.CIG971&;W)M1&%T82@G=FEE=R<L("=D87DG*3L*"B\O
M(%!R92UF;W)M870@;W5R(&1E;&5T92!I;6%G92]L:6YK+@HD9&5L:6UG(#T@
M2&]R9&4Z.FEM9R@G9&5L971E+G!N9R<L(%\H(E)E;6]V92!!='1E;F1E92(I
M+"!N=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*3L*"B1I
M9&5N="`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B1I9&5N=&ET:65S(#T@
M)&ED96YT+3YG971!;&PH)VED)RD["B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T
M1&5F875L=%9A<FEA8FQE<R@I.PHD=&%B<R`]("9N97<@2&]R9&5?54E?5&%B
M<RAN=6QL+"`D=F%R<RD["B1T86)S+3YA9&1486(H7R@B1&%Y(BDL("=J879A
M<V-R:7!T.G-W:71C:%9I97<H7"=D87E<)RDG+"`G9&%Y)RD["B1T86)S+3YA
M9&1486(H7R@B5V]R:R!7965K(BDL("=J879A<V-R:7!T.G-W:71C:%9I97<H
M7"=W;W)K=V5E:UPG*2<L("=W;W)K=V5E:R<I.PHD=&%B<RT^861D5&%B*%\H
M(E=E96LB*2P@)VIA=F%S8W)I<'0Z<W=I=&-H5FEE=RA<)W=E96M<)RDG+"`G
M=V5E:R<I.PH*)&%T=&5N9&5E7W9I97<@/2`F2W)O;F]L:71H7T9R965"=7-Y
M7U9I97<Z.G-I;F=L971O;B@D=FEE=RD["@HO+R!!9&0@=&AE(&-R96%T;W(@
M87,@82!R97%U:7)E9"!A='1E;F1E92!I;B!T:&4@1G)E92]"=7-Y(&1I<W!L
M87D@*&EF"B\O('1H92!U<V5R(&AA<R!A;B!E;6%I;"!A9&1R97-S(&-O;F9I
M9W5R960I+@HD;7EE;6%I;"`]("1I9&5N="T^9V5T5F%L=64H)V9R;VU?861D
M<B<I.PII9B`H(65M<'1Y*"1M>65M86EL*2D@>PH@("`@)'9F8B`]($MR;VYO
M;&ET:#HZ9V5T1G)E94)U<WDH)&UY96UA:6PI.PH@("`@:68@*"%I<U]A*"1V
M9F(L("=014%27T5R<F]R)RDI('L*("`@("`@("`D871T96YD965?=FEE=RT^
M861D4F5Q=6ER961-96UB97(H)'9F8BD["B`@("!](&5L<V4@>PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")%<G)O<B!R971R:65V
M:6YG(&9R964O8G5S>2!I;F9O<FUA=&EO;B!F;W(@)7,Z("5S(BDL("1M>65M
M86EL+"`D=F9B+3YG971-97-S86=E*"DI*3L*("`@('T*?0H*+R\@061D('1H
M92!&<F5E+T)U<WD@:6YF;W)M871I;VX@9F]R(&5A8V@@871T96YD964N"F9O
M<F5A8V@@*"1A='1E;F1E97,@87,@)&5M86EL(#T^("1S=&%T=7,I('L*("`@
M(&EF("@D<W1A='5S6R=A='1E;F1A;F-E)UT@/3T@2U)/3D],251(7U!!4E1?
M4D5154E2140I('L*("`@("`@("`D=F9B(#T@2W)O;F]L:71H.CIG971&<F5E
M0G5S>2@D96UA:6PI.PH@("`@("`@(&EF("@A:7-?82@D=F9B+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1A='1E;F1E95]V:65W+3YA9&1297%U
M:7)E9$UE;6)E<B@D=F9B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R;W(@<F5T<FEE
M=FEN9R!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<R(I+"`D96UA
M:6PL("1V9F(M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@('T*("`@('T@96QS
M96EF("@D<W1A='5S6R=A='1E;F1A;F-E)UT@/3T@2U)/3D],251(7U!!4E1?
M3U!424].04PI('L*("`@("`@("`D=F9B(#T@2W)O;F]L:71H.CIG971&<F5E
M0G5S>2@D96UA:6PI.PH@("`@("`@(&EF("@A:7-?82@D=F9B+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1A='1E;F1E95]V:65W+3YA9&1/<'1I
M;VYA;$UE;6)E<B@D=F9B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R;W(@<F5T<FEE
M=FEN9R!F<F5E+V)U<WD@:6YF;W)M871I;VX@9F]R("5S.B`E<R(I+"`D96UA
M:6PL("1V9F(M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@('T*("`@('T*?0H*
M)'1I;65S=&%M<"`]("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)W1I;65S=&%M
M<"<L('1I;64H*2D["B1V9F)?:'1M;"`]("1A='1E;F1E95]V:65W+3YR96YD
M97(H)'1I;65S=&%M<"D["@HD=&ET;&4@/2!?*")%9&ET(&%T=&5N9&5E<R(I
M.PIR97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=S=&%T=7,G
M*2D["G)E<75I<F4@2U)/3D],251(7U1%35!,051%4R`N("<O871T96YD965S
M+V%T=&5N9&5E<RYI;F,G.PIR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP
M;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+V%T
M=&5N9"YP:'``````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-#`V-0`Q,#0Q-S,V,C<U,P`P,C`T,C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@
M:W)O;F]L:71H+V%T=&5N9"YP:'`L=B`Q+C(N,BXS(#(P,#8O,#$O,#$@,C$Z
M,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=0
M3"DN("!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("HO"@I`
M9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2U)/3D],
M251(7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!+
M4D].3TQ)5$A?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B1U:60@/2!5=&EL
M.CIG971&;W)M1&%T82@G:2<I.PHD=7-E<B`](%5T:6PZ.F=E=$9O<FU$871A
M*"=U)RD["@IS=VET8V@@*%5T:6PZ.F=E=$9O<FU$871A*"=A)RDI('L*8V%S
M92`G86-C97!T)SH*("`@("1A8W1I;VX@/2!+4D].3TQ)5$A?4D534$].4T5?
M04-#15!4140["B`@("`D;7-G(#T@7R@B66]U(&AA=F4@<W5C8V5S<V9U;&QY
M(&%C8V5P=&5D(&%T=&5N9&5N8V4@=&\@=&AI<R!E=F5N="XB*3L*("`@(&)R
M96%K.PH*8V%S92`G9&5C;&EN92<Z"B`@("`D86-T:6]N(#T@2U)/3D],251(
M7U)%4U!/3E-%7T1%0TQ)3D5$.PH@("`@)&US9R`](%\H(EEO=2!H879E('-U
M8V-E<W-F=6QL>2!D96-L:6YE9"!A='1E;F1E;F-E('1O('1H:7,@979E;G0N
M(BD["B`@("!B<F5A:SL*"F-A<V4@)W1E;G1A=&EV92<Z"B`@("`D86-T:6]N
M(#T@2U)/3D],251(7U)%4U!/3E-%7U1%3E1!5$E613L*("`@("1M<V<@/2!?
M*")9;W4@:&%V92!T96YT871I=F5L>2!A8V-E<'1E9"!A='1E;F1E;F-E('1O
M('1H:7,@979E;G0N(BD["B`@("!B<F5A:SL*"F1E9F%U;'0Z"B`@("`D86-T
M:6]N(#T@2U)/3D],251(7U)%4U!/3E-%7TY/3D4["B`@("`D;7-G(#T@)R<[
M"B`@("!B<F5A:SL*?0H*:68@*&5M<'1Y*"1U:60I('Q\(&5M<'1Y*"1U<V5R
M*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")4:&4@<F5Q=65S="!W
M87,@:6YC;VUP;&5T92X@4V]M92!P87)A;65T97)S('1H870@87)E(&YE8V5S
M<V%R>2!T;R!A8V-E<'0@;W(@9&5C;&EN92!A;B!E=F5N="!A<F4@;6ES<VEN
M9RXB*2P@)VAO<F1E+F5R<F]R)RD["GT*"B1E=F5N="`]("1K<F]N;VQI=&@M
M/F=E=$)Y54E$*"1U:60I.PII9B`H:7-?82@D979E;G0L("=014%27T5R<F]R
M)RDI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&5V96YT+"`G:&]R9&4N
M97)R;W(G*3L*("`@("1T:71L92`]("<G.PI](&5L<V5I9B`H(21E=F5N="T^
M:&%S071T96YD964H)'5S97(I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*%\H(EEO=2!A<F4@;F]T(&%N(&%T=&5N9&5E(&]F('1H92!S<&5C:69I960@
M979E;G0N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@)'1I=&QE(#T@)&5V96YT
M+3YG9714:71L92@I.PI](&5L<V4@>PH@("`@)&5V96YT+3YA9&1!='1E;F1E
M92@D=7-E<BP@2U)/3D],251(7U!!4E1?24=.3U)%+"`D86-T:6]N*3L*("`@
M("1R97-U;'0@/2`D979E;G0M/G-A=F4H*3L*("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*"1R97-U;'0L("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E:68@*"%E
M;7!T>2@D;7-G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&US
M9RP@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T*("`@("1T:71L92`]("1E=F5N
M="T^9V5T5&ET;&4H*3L*?0H*<F5Q=6ER92!+4D].3TQ)5$A?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["@H_/@H\9&EV(&ED/2)M96YU(CX\
M:#$^)FYB<W`[/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1T:71L92D@
M/SX\+V@Q/CPO9&EV/@H\/W!H<`H*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R
M<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["G)E<75I<F4@)')E9VES
M=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O
M=&5R+FEN8R<["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:W)O;F]L:71H+V%D9&5V96YT86-T:6]N+G!H<```````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#,Q-@`Q,#0Q-S,V,C<U,P`P,C(Q,S<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:W)O;F]L:71H+V%D9&5V96YT86-T:6]N+G!H<"QV(#$N
M-3`N,BXT(#(P,#4O,3(O,3<@,38Z-3(Z,S@@8VAU8VL@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DL(#(P,#`@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=+4D].
M3TQ)5$A?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E
M($M23TY/3$E42%]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*:68@*"%5=&EL
M.CIG971&;W)M1&%T82@G8V%N8V5L)RDI('L*("`@("1C86QE;F1A<E]I9"`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=T87)G971C86QE;F1A<B<I.PH@("`@)'-H
M87)E(#T@)B1K<F]N;VQI=&A?<VAA<F5S+3YG9713:&%R92@D8V%L96YD87)?
M:60I.PH@("`@:68@*&ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H97)E('=A
M<R!A;B!E<G)O<B!A8V-E<W-I;F<@=&AE(&-A;&5N9&%R.B`E<R(I+"`D<VAA
M<F4M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E
M:68@*"$D<VAA<F4M/FAA<U!E<FUI<W-I;VXH075T:#HZ9V5T075T:"@I+"!0
M15)-4U]%1$E4+"!!=71H.CIG971!=71H*"DI*2!["B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(EEO=2!D;R!N;W0@:&%V92!P97)M
M:7-S:6]N('1O(&%D9"!E=F5N=',@=&\@)7,N(BDL("1S:&%R92T^9V5T*"=N
M86UE)RDI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@?2!E;'-E:68@*$MR;VYO
M;&ET:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I(#T]/2!T<G5E('Q\
M"B`@("`@("`@("`@("`@2W)O;F]L:71H.CIH87-097)M:7-S:6]N*"=M87A?
M979E;G1S)RD@/B!+<F]N;VQI=&@Z.F-O=6YT179E;G1S*"DI('L*("`@("`@
M("`D:W)O;F]L:71H+3YO<&5N*"1C86QE;F1A<E]I9"D["B`@("`@("`@)&5V
M96YT(#T@)B1K<F]N;VQI=&@M/F=E=$5V96YT*"D["B`@("`@("`@)&5V96YT
M+3YR96%D1F]R;2@I.PH@("`@("`@("1R97-U;'0@/2`D979E;G0M/G-A=F4H
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1U<V5R:6YF;R`]("1R97-U;'0M/F=E=%5S97));F9O
M*"D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=7-E<FEN9F\I*2!["B`@
M("`@("`@("`@("`@("`D=7-E<FEN9F\@/2!I;7!L;V1E*"<L("<L("1U<V5R
M:6YF;RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&UE<W-A9V4@/2`D
M<F5S=6QT+3YG971-97-S86=E*"D@+B`H)'5S97)I;F9O(#\@)R`Z("<@+B`D
M=7-E<FEN9F\@.B`G)RD["@H@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@
M979E;G0Z("5S(BDL("1M97-S86=E*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A
M*"=S96YD=7!D871E<R<L(&9A;'-E*2D@>PH@("`@("`@("`@("`@("`@)&5V
M96YT(#T@)B1K<F]N;VQI=&@M/F=E=$5V96YT*"1R97-U;'0I.PH@("`@("`@
M("`@("`@("`@2W)O;F]L:71H.CIS96YD251I<$YO=&EF:6-A=&EO;G,H)&5V
M96YT+"`D;F]T:69I8V%T:6]N+"!+4D].3TQ)5$A?251)4%]215%515-4*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*?0H*:68@*"1U<FP@/2!5
M=&EL.CIG971&;W)M1&%T82@G=7)L)RDI('L*("`@(&AE861E<B@G3&]C871I
M;VXZ("<@+B`D=7)L*3L*?2!E;'-E('L*("`@("1U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H)'!R969S+3YG971686QU92@G9&5F875L='9I97<G*2`N("<N
M<&AP)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VUO
M;G1H)R`]/B!5=&EL.CIG971&;W)M1&%T82@G;6]N=&@G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)WEE87(G(#T^(%5T:6PZ.F=E
M=$9O<FU$871A*"=Y96%R)RDI*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@
M+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)'5R;"P@=')U92DI.PI]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:W)O;F]L:71H+WEE87(N<&AP````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C(T-0`Q,#0Q-S,V,C<U,P`P
M,C`Q,3,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J("1(;W)D93H@:W)O;F]L:71H+WEE87(N<&AP+'8@
M,2XQ-BXR+C,@,C`P-B\P,2\P,2`R,3HR.3HP,B!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]G<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=+4D].3TQ)5$A?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E($M23TY/
M3$E42%]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*:68@*"1T:6UE<W1A;7`@
M/2`H:6YT*55T:6PZ.F=E=$9O<FU$871A*"=T:6UE<W1A;7`G*2D@>PH@("`@
M)'EE87(@/2!D871E*"=9)RP@)'1I;65S=&%M<"D["GT@96QS92!["B`@("`D
M>65A<B`]("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)WEE87(G+"!D871E*"=9
M)RDI.PI]"@HD=&]D87D@/2!M:W1I;64H,"P@,"P@,"D["B1T:6UE<W1A;7`@
M/2!M:W1I;64H,2P@,2P@,2P@,2P@,2P@)'EE87(I.PHD<')E=G-T86UP(#T@
M;6MT:6UE*#$L(#$L(#$L(#$L(#$L("1Y96%R("T@,2D["B1N97AT<W1A;7`@
M/2!M:W1I;64H,2P@,2P@,2P@,2P@,2P@)'EE87(@*R`Q*3L*)'1I=&QE(#T@
M<W1R9G1I;64H)R59)RP@)'1I;65S=&%M<"D["B1P<FEN=%]V:65W(#T@*&)O
M;VPI571I;#HZ9V5T1F]R;41A=&$H)W!R:6YT)RD["@I(;W)D93HZ861D4V-R
M:7!T1FEL92@G=&]O;'1I<"YJ<R<L("=H;W)D92<L('1R=64I.PII9B`H(21P
M<FEN=%]V:65W*2!["B`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G<&]P=7`N
M:G,G+"`G:&]R9&4G+"!T<G5E*3L*?0IR97%U:7)E($M23TY/3$E42%]414U0
M3$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*"FEF("@D<')I;G1?=FEE
M=RD@>PH@("`@<F5Q=6ER95]O;F-E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T
M97,G+"`G:&]R9&4G*2`N("<O:F%V87-C<FEP="]P<FEN="YJ<R<["GT@96QS
M92!["B`@("`D<')I;G1?;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<B@G>65A
M<BYP:'`G+"!A<G)A>2@G=&EM97-T86UP)R`]/B`D=&EM97-T86UP+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W!R:6YT)R`]/B`G=')U92<I*3L*("`@("1P<FEN=%]L:6YK(#T@
M2&]R9&4Z.G5R;"@D<')I;G1?;&EN:RD["B`@("!R97%U:7)E($M23TY/3$E4
M2%]414U03$%415,@+B`G+VUE;G4N:6YC)SL*?0H*)'!R979U<FP@/2!(;W)D
M93HZ87!P;&EC871I;VYU<FPH571I;#HZ861D4&%R86UE=&5R*"=Y96%R+G!H
M<"<L(&%R<F%Y*"=Y96%R)R`]/B!D871E*"=9)RP@)'!R979S=&%M<"DI*2D[
M"B1N97AT=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*%5T:6PZ.F%D9%!A
M<F%M971E<B@G>65A<BYP:'`G+"!A<G)A>2@G>65A<B<@/3X@9&%T92@G62<L
M("1N97AT<W1A;7`I*2DI.PH*96-H;R`G/&1I=B!I9#TB<&%G92(^)SL*"FEF
M("@A)'!R:6YT7W9I97<I('L*("`@($MR;VYO;&ET:#HZ=&%B<R@I.PI]"@IR
M97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G+WEE87(O:&5A9"YI;F,G
M.PH*)'-T87)T1&%T92`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G>65A<B<@
M/3X@)'EE87(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VUO;G1H)R`]/B`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=M9&%Y)R`]/B`Q*2D["B1E;F1$871E(#T@)FYE=R!(;W)D95]$871E
M*&%R<F%Y*"=Y96%R)R`]/B`D>65A<BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VUO;G1H)R`]/B`Q,BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VUD87DG(#T^(#,Q+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:&]U<B<@/3X@,C,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=M:6XG(#T^(#4Y+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<V5C)R`]/B`U.2DI.PHD<W1A<G1$871E
M+3YC;W)R96-T*"D["B1E;F1$871E+3YC;W)R96-T*"D["B1A;&QE=F5N=',@
M/2!+<F]N;VQI=&@Z.FQI<W1%=F5N=',H)'-T87)T1&%T92P@)&5N9$1A=&4L
M("1'3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R<R==*3L*"B1H=&UL(#T@)R<[
M"F9O<B`H)&UO;G1H(#T@,3L@)&UO;G1H(#P](#$R.R`D;6]N=&@K*RD@>PH@
M("`@)&AT;6P@+CT@)SQT9"!V86QI9VX](G1O<"(^)SL*"B`@("`O+R!(96%D
M:6YG(&9O<B!E86-H(&UO;G1H+@H@("`@)&UT:71L92`]('-T<F9T:6UE*"<E
M0B<L(&UK=&EM92@Q+"`Q+"`Q+"`D;6]N=&@L(#$L("1Y96%R*2D["B`@("`D
M:'1M;"`N/2`G/'1A8FQE(&-L87-S/2)N;W!A9&1I;F<B(&-E;&QS<&%C:6YG
M/2(P(B!W:61T:#TB,3`P)2(^/'1R/CQT:"!C;&%S<STB:&5A9&5R(CXG.PH*
M("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=M;VYT:"YP:'`G*2P@87)R87DH)VUO;G1H)R`]/B`D;6]N=&@L
M("=Y96%R)R`]/B!D871E*"=9)RP@)'1I;65S=&%M<"DL("=T:6UE<W1A;7`G
M(#T^("1T:6UE<W1A;7`I*3L*("`@("1H=&UL("X]("<\82!H<F5F/2(G("X@
M)'5R;"`N("<B/B<@+B`D;71I=&QE("X@)SPO83X\+W1H/CPO='(^)SL*("`@
M("1H=&UL("X]("<\='(^/'1D(&-L87-S/2)M;VYT:&=R:60B/CQT86)L92!C
M;&%S<STB;F]P861D:6YG(B!C96QL<W!A8VEN9STB,2(@=VED=&@](C$P,"4B
M/CQT<CXG.PH@("`@:68@*"$D<')E9G,M/F=E=%9A;'5E*"=W965K7W-T87)T
M7VUO;F1A>2<I*2!["B`@("`@("`@)&AT;6P@+CT@)SQT:"!C;&%S<STB:71E
M;2(^)R`N(%\H(E-U(BDN("<\+W1H/B<["B`@("!]"B`@("`D:'1M;"`N/2`G
M/'1H(&-L87-S/2)I=&5M(CXG("X@7R@B36\B*2`N("<\+W1H/B<["B`@("`D
M:'1M;"`N/2`G/'1H(&-L87-S/2)I=&5M(CXG("X@7R@B5'4B*2`N("<\+W1H
M/B<["B`@("`D:'1M;"`N/2`G/'1H(&-L87-S/2)I=&5M(CXG("X@7R@B5V4B
M*2`N("<\+W1H/B<["B`@("`D:'1M;"`N/2`G/'1H(&-L87-S/2)I=&5M(CXG
M("X@7R@B5&@B*2`N("<\+W1H/B<["B`@("`D:'1M;"`N/2`G/'1H(&-L87-S
M/2)I=&5M(CXG("X@7R@B1G(B*2`N("<\+W1H/B<["B`@("`D:'1M;"`N/2`G
M/'1H(&-L87-S/2)I=&5M(CXG("X@7R@B4V$B*2`N("<\+W1H/B<["B`@("!I
M9B`H)'!R969S+3YG971686QU92@G=V5E:U]S=&%R=%]M;VYD87DG*2D@>PH@
M("`@("`@("1H=&UL("X]("<\=&@@8VQA<W,](FET96TB/B<@+B!?*")3=2(I
M("X@)SPO=&@^)SL*("`@('T*("`@("1H=&UL("X]("(\+W1R/EQN/'1R/B([
M"@H@("`@)'-T87)T9&%Y(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=M9&%Y
M)R`]/B`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=M;VYT:"<@/3X@)&UO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=Y96%R)R`]/B`D>65A<BDI.PH@("`@)'-T87)T9&%Y
M(#T@)'-T87)T9&%Y+3YD87E/9E=E96LH*3L*"B`@("`D9&%Y<TEN5FEE=R`]
M($1A=&5?0V%L8SHZ=V5E:W-);DUO;G1H*"1M;VYT:"P@)'EE87(I("H@-SL*
M("`@(&EF("@A)'!R969S+3YG971686QU92@G=V5E:U]S=&%R=%]M;VYD87DG
M*2D@>PH@("`@("`@("1S=&%R=$]F5FEE=R`](#$@+2`D<W1A<G1D87D["@H@
M("`@("`@("\O(%=E(&UA>2!N965D('1O(&%D:G5S="!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE('9I97<@:68*("`@("`@("`O+R!W92=R92!S=&%R=&EN
M9R!W965K<R!O;B!3=6YD87DN"B`@("`@("`@:68@*"1S=&%R=&1A>2`]/2!(
M3U)$15]$051%7U-53D1!62D@>PH@("`@("`@("`@("`D9&%Y<TEN5FEE=R`M
M/2`W.PH@("`@("`@('T*("`@("`@("`D96YD9&%Y(#T@)FYE=R!(;W)D95]$
M871E*&%R<F%Y*"=M9&%Y)R`]/B!(;W)D95]$871E.CID87ES26Y-;VYT:"@D
M;6]N=&@L("1Y96%R*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=M;VYT:"<@/3X@)&UO;G1H+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)WEE87(G(#T^("1Y96%R*2D["B`@
M("`@("`@)&5N9&1A>2`]("1E;F1D87DM/F1A>4]F5V5E:R@I.PH@("`@("`@
M(&EF("@D96YD9&%Y(#T]($A/4D1%7T1!5$5?4U5.1$%9*2!["B`@("`@("`@
M("`@("1D87ES26Y6:65W("L](#<["B`@("`@("`@?0H@("`@?2!E;'-E('L*
M("`@("`@("!I9B`H)'-T87)T9&%Y(#T]($A/4D1%7T1!5$5?4U5.1$%9*2![
M"B`@("`@("`@("`@("1S=&%R=$]F5FEE=R`]("TU.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1S=&%R=$]F5FEE=R`](#(@+2`D<W1A<G1D87D[
M"B`@("`@("`@?0H@("`@?0H*("`@("1C=7)R96YT0V%L96YD87)S(#T@87)R
M87DH=')U92D["@H@("`@)&5V96YT0V%T96=O<FEE<R`](&%R<F%Y*"D["@H@
M("`@9F]R96%C:"`H)&-U<G)E;G1#86QE;F1A<G,@87,@)&ED(#T^("1C86PI
M('L*("`@("`@("`D8V5L;"`](#`["B`@("`@("`@9F]R("@D9&%Y(#T@)'-T
M87)T3V96:65W.R`D9&%Y(#P@)'-T87)T3V96:65W("L@)&1A>7-);E9I97<[
M("1D87DK*RD@>PH@("`@("`@("`@("`D9&%T92`]("9N97<@2&]R9&5?1&%T
M92AA<G)A>2@G>65A<B<@/3X@)'EE87(L("=M;VYT:"<@/3X@)&UO;G1H+"`G
M;61A>2<@/3X@)&1A>2DI.PH@("`@("`@("`@("`D9&%Y<W1A;7`@/2`D9&%T
M92T^=&EM97-T86UP*"D["B`@("`@("`@("`@("1D871E+3YH;W5R(#T@)'!R
M969S+3YG971686QU92@G='=E;G1Y1F]U<B<I(#\@,3(@.B`V.PH@("`@("`@
M("`@("`D=&EM97-T86UP(#T@)&1A=&4M/G1I;65S=&%M<"@I.PH@("`@("`@
M("`@("`D=V5E:R`]("1D871E+3YW965K3V9996%R*"D["@H@("`@("`@("`@
M("!I9B`H)&-E;&P@)2`W(#T](#`@)B8@)&-E;&P@(3T@,"D@>PH@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@(CPO='(^7&X\='(^(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H9&%T92@G;B<L("1D87ES=&%M<"D@(3T@)&UO
M;G1H*2!["B`@("`@("`@("`@("`@("`D<W1Y;&4@/2`G;6]N=&AG<FED)SL*
M("`@("`@("`@("`@?2!E;'-E:68@*&1A=&4H)W<G+"`D9&%Y<W1A;7`I(#T]
M(#`@?'P@9&%T92@G=R<L("1D87ES=&%M<"D@/3T@-BD@>PH@("`@("`@("`@
M("`@("`@)'-T>6QE(#T@)W=E96ME;F0G.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'-T>6QE(#T@)W1E>'0G.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!3970@=7`@=&AE(&QI;FL@=&\@=&AE(&1A
M>2!V:65W+B`J+PH@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=D87DN<&AP)RP@=')U92D["B`@("`@("`@("`@("1U<FP@/2!5
M=&EL.CIA9&1087)A;65T97(H)'5R;"P@87)R87DH)W1I;65S=&%M<"<@/3X@
M)&1A>7-T86UP*2D["@H@("`@("`@("`@("!I9B`H9&%T92@G;B<L("1D87ES
M=&%M<"D@(3T@)&UO;G1H*2!["B`@("`@("`@("`@("`@("`D8V5L;&1A>2`]
M("<F;F)S<#LG.PH@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1A;&QE
M=F5N='-;)&1A>7-T86UP72DI('L*("`@("`@("`@("`@("`@("\J(%1H97)E
M(&%R92!E=F5N=',[(&-R96%T92!A(&-E;&P@=VET:"!T;V]L=&EP('1O(&QI
M<W0*("`@("`@("`@("`@("`@("`J('1H96TN("HO"B`@("`@("`@("`@("`@
M("`D9&%Y7V5V96YT<R`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&%L;&5V96YT<ULD9&%Y<W1A;7!=(&%S("1E=F5N="D@>PH@("`@("`@("`@
M("`@("`@("`@("1D87E?979E;G1S("X](&1A=&4H)'!R969S+3YG971686QU
M92@G='=E;G1Y1F]U<B<I(#\@)T<Z:2<@.B`G9SII82<L("1E=F5N="T^<W1A
M<G0M/G1I;65S=&%M<"@I*2`N("<@+2`G("X@9&%T92@D<')E9G,M/F=E=%9A
M;'5E*"=T=V5N='E&;W5R)RD@/R`G1SII)R`Z("=G.FEA)RP@)&5V96YT+3YE
M;F0M/G1I;65S=&%M<"@I*3L*("`@("`@("`@("`@("`@("`@("`D9&%Y7V5V
M96YT<R`N/2`H)&5V96YT+3YG971,;V-A=&EO;B@I*2`_("<@*"<@+B`D979E
M;G0M/F=E=$QO8V%T:6]N*"D@+B`G*2<@.B`G)SL*("`@("`@("`@("`@("`@
M("`@("`D9&%Y7V5V96YT<R`N/2`G("<@+B`D979E;G0M/F=E=%1I=&QE*"D@
M+B`B7&XB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+RH@
M0F]L9"!T:&4@8V5L;"!I9B!T:&5R92!A<F4@979E;G1S+B`J+PH@("`@("`@
M("`@("`@("`@)&-E;&QD87D@/2`G/'-T<F]N9SXG("X@2&]R9&4Z.FQI;FM4
M;V]L=&EP*"1U<FPL(%\H(E9I97<@1&%Y(BDL("<G+"`G)RP@)R<L("1D87E?
M979E;G1S*2`N(&1A=&4H)VHG+"`D9&%Y<W1A;7`I("X@)SPO83X\+W-T<F]N
M9SXG.PH*("`@("`@("`@("`@("`@("\J(%-E="!T:&4@8F%C:V=R;W5N9"!C
M;VQO<B!T;R!D:7-T:6YG=6ES:"!T:&4@9&%Y("HO"B`@("`@("`@("`@("`@
M("`D<W1Y;&4@/2`G>65A<BUE=F5N="<["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`O*B!.;R!E=F5N=',L('!L86EN(&QI;FL@=&\@
M=&AE(&1A>2X@*B\*("`@("`@("`@("`@("`@("1C96QL9&%Y(#T@2&]R9&4Z
M.FQI;FM4;V]L=&EP*"1U<FPL(%\H(E9I97<@1&%Y(BDI("X@9&%T92@G:B<L
M("1D87ES=&%M<"D@+B`G/"]A/B<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1T;V1A>2`]/2`D9&%Y<W1A;7`@)B8@9&%T92@G;B<L("1D87ES
M=&%M<"D@/3T@)&UO;G1H*2!["B`@("`@("`@("`@("`@("`D<W1Y;&4@+CT@
M)R!T;V1A>2<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1H=&UL("X]
M("<\=&0@86QI9VX](F-E;G1E<B(@8VQA<W,](B<@+B`D<W1Y;&4@+B`G(B!H
M96EG:'0](C$P(B!W:61T:#TB-24B('9A;&EG;CTB=&]P(CXG.PH@("`@("`@
M("`@("`D:'1M;"`N/2`D8V5L;&1A>2`N("<\+W1D/B<["B`@("`@("`@("`@
M("1C96QL*RL["B`@("`@("`@?0H@("`@?0H*("`@("1H=&UL("X]("(\+W1R
M/CPO=&%B;&4^/"]T9#X\+W1R/CPO=&%B;&4^/"]T9#Y<;B(["B`@("!I9B`H
M)&UO;G1H("4@,R`]/2`P("8F("1M;VYT:"`A/2`Q,BD@>PH@("`@("`@("1H
M=&UL("X]("(\+W1R/EQN/'1R/B(["B`@("!]"GT*"F5C:&\@)&AT;6P@+B`G
M/"]T<CX\+W1A8FQE/CPO9&EV/B<["G)E<75I<F4@)')E9VES=')Y+3YG970H
M)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O8V]N9FEG````````````````````
M`````````````````````````````````````````````````````````#`Q
M,C`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S
M`#`R-C<U,P`@,B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:W)O;F]L
M:71H````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]A9&1E
M=F5N="YP:'``````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#8Q,#(`,3`T,3<S-C(W-3,`,#(P-S,T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR
M;VYO;&ET:"]A9&1E=F5N="YP:'`L=B`Q+C4U+C@N,R`R,#`V+S`Q+S`Q(#(Q
M.C(Y.C`R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A'4$PI+B`@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G2U)/3D],251(7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2D["G)E<75I<F4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]B87-E
M+G!H<"<["@HO*B!#:&5C:R!P97)M:7-S:6]N<RX@*B\*:68@*$MR;VYO;&ET
M:#HZ:&%S4&5R;6ES<VEO;B@G;6%X7V5V96YT<R<I("$]/2!T<G5E("8F"B`@
M("!+<F]N;VQI=&@Z.FAA<U!E<FUI<W-I;VXH)VUA>%]E=F5N=',G*2`\/2!+
M<F]N;VQI=&@Z.F-O=6YT179E;G1S*"DI('L*("`@("1M97-S86=E(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@979E;G1S+B(I+"!+<F]N;VQI=&@Z
M.FAA<U!E<FUI<W-I;VXH)VUA>%]E=F5N=',G*2DL($5.5%]#3TU0050L($Y,
M4SHZ9V5T0VAA<G-E="@I*3L*("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS
M)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@("`@)&UE<W-A9V4@/2!(;W)D
M93HZ8V%L;$AO;VLH)U]P97)M<U]H;V]K7V1E;FEE9"<L(&%R<F%Y*"=K<F]N
M;VQI=&@Z;6%X7V5V96YT<R<I+"`G:&]R9&4G+"`D;65S<V%G92D["B`@("!]
M"B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1M97-S86=E+"`G:&]R9&4N97)R
M;W(G+"!A<G)A>2@G8V]N=&5N="YR87<G*2D["B`@("`D=7)L(#T@571I;#HZ
M861D4&%R86UE=&5R*"1P<F5F<RT^9V5T5F%L=64H)V1E9F%U;'1V:65W)RD@
M+B`G+G!H<"<L(&%R<F%Y*"=M;VYT:"<@/3X@571I;#HZ9V5T1F]R;41A=&$H
M)VUO;G1H)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y
M96%R)R`]/B!5=&EL.CIG971&;W)M1&%T82@G>65A<B<I*2D["B`@("!H96%D
M97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1U<FPL
M('1R=64I*3L*("`@(&5X:70["GT*"B1C86QE;F1A<E]I9"`]($MR;VYO;&ET
M:#HZ9V5T1&5F875L=$-A;&5N9&%R*%!%4DU37T5$250I.PII9B`H(21C86QE
M;F1A<E]I9"D@>PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D<')E
M9G,M/F=E=%9A;'5E*"=D969A=6QT=FEE=R<I("X@)RYP:'`G+"!A<G)A>2@G
M;6]N=&@G(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=M;VYT:"<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G>65A<B<@/3X@571I;#HZ9V5T
M1F]R;41A=&$H)WEE87(G*2DI.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D=7)L+"!T<G5E*2D["GT*"B1E=F5N
M="`]("8D:W)O;F]L:71H+3YG971%=F5N="@I.PHD7U-%4U-)3TY;)V%T=&5N
M9&5E<R==(#T@)&5V96YT+3YG971!='1E;F1E97,H*3L*"FEF("@A)'1I;65S
M=&%M<"`](%5T:6PZ.F=E=$9O<FU$871A*"=T:6UE<W1A;7`G*2D@>PH@("`@
M)&UO;G1H(#T@571I;#HZ9V5T1F]R;41A=&$H)VUO;G1H)RP@9&%T92@G;B<I
M*3L*("`@("1D87D@/2!5=&EL.CIG971&;W)M1&%T82@G;61A>2<L(&1A=&4H
M)VHG*2D["B`@("`D>65A<B`](%5T:6PZ.F=E=$9O<FU$871A*"=Y96%R)RP@
M9&%T92@G62<I*3L*("`@("1H;W5R(#T@)'!R969S+3YG971686QU92@G='=E
M;G1Y1F]U<B<I(#\@,3(@.B`V.PH@("`@)'1I;65S=&%M<"`](&UK=&EM92@D
M:&]U<BP@,"P@,"P@)&UO;G1H+"`D9&%Y+"`D>65A<BD["GT*"B1U<FP@/2!5
M=&EL.CIG971&;W)M1&%T82@G=7)L)RD["@HD979E;G0M/G-T87)T(#T@)FYE
M=R!(;W)D95]$871E*"1T:6UE<W1A;7`I.PHO+R!$969A=6QT('1O(&$@,2!H
M;W5R(&1U<F%T:6]N+@HD979E;G0M/F5N9"`]("9N97<@2&]R9&5?1&%T92@D
M=&EM97-T86UP("L@,S8P,"D["B1E=F5N="T^<V5T4F5C=7)4>7!E*$M23TY/
M3$E42%]214-54E].3TY%*3L*)&UO;G1H(#T@)&5V96YT+3YS=&%R="T^;6]N
M=&@["B1Y96%R(#T@)&5V96YT+3YS=&%R="T^>65A<CL*"B1B=71T;VYS(#T@
M87)R87DH)SQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&YA
M;64](G-A=F4B('9A;'5E/2(G("X@7R@B4V%V92!%=F5N="(I("X@)R(@;VYC
M;&EC:STB<F5T=7)N(&-H96-K0V%T96=O<GDH*3LB("\^)RD["FEF("AI<W-E
M="@D=7)L*2D@>PH@("`@)&-A;F-E;'5R;"`]("1U<FP["GT@96QS92!["B`@
M("`D8V%N8V5L=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=M;VYT:"YP:'`G
M+"`G;6]N=&@G+"`D;6]N=&@I.PH@("`@)&-A;F-E;'5R;"`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D8V%N8V5L=7)L+"`G>65A<B<L("1Y96%R*3L*("`@("1C
M86YC96QU<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)&-A;F-E;'5R;"D[
M"GT*"B1T:71L92`](%\H(D%D9"!A(&YE=R!E=F5N="(I.PHD8V%L96YD87)S
M(#T@2W)O;F]L:71H.CIL:7-T0V%L96YD87)S*&9A;'-E+"!015)-4U]%1$E4
M*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W-T<FEP92YJ<R<L("=K<F]N;VQI
M=&@G+"!T<G5E*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V]P96Y?871T96YD
M965S7W=I;BYJ<R<I.PIR97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G
M+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!+4D].3TQ)5$A?5$5-4$Q!
M5$53("X@)R]M96YU+FEN8R<["G)E<75I<F4@2U)/3D],251(7U1%35!,051%
M4R`N("<O961I="]J879A<V-R:7!T+FEN8R<["G)E<75I<F4@2U)/3D],251(
M7U1%35!,051%4R`N("<O961I="]E9&ET+FEN8R<["G)E<75I<F4@)')E9VES
M=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O
M=&5R+FEN8R<["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]K<F]N;VQI=&@O=V]R
M:W=E96LN<&AP````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S-C`S`#$P-#$W,S8R-S4S`#`R,3`P,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!K
M<F]N;VQI=&@O=V]R:W=E96LN<&AP+'8@,2XS-"XX+C8@,C`P-2\Q,2\Q,2`R
M,SHR,SHU,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DL(#(P,#`@
M0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN
M:'1M;"X*("HO"@I`9&5F:6YE*"=+4D].3TQ)5$A?0D%312<L(&1I<FYA;64H
M7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E($M23TY/3$E42%]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@+B`G
M+VQI8B]7965K5FEE=RYP:'`G.PH*)'=E96L@/2`H:6YT*55T:6PZ.F=E=$9O
M<FU$871A*"=W965K)RD["B1Y96%R(#T@*&EN="E5=&EL.CIG971&;W)M1&%T
M82@G>65A<B<I.PII9B`H)'1I;65S=&%M<"`]("AI;G0I571I;#HZ9V5T1F]R
M;41A=&$H)W1I;65S=&%M<"<I*2!["B`@("`D9&%T92`]("9N97<@2&]R9&5?
M1&%T92@D=&EM97-T86UP*3L*("`@("1Y96%R(#T@)&1A=&4M/GEE87(["B`@
M("`D=V5E:R`]("1D871E+3YW965K3V9996%R*"D["B`@("!I9B`H(21P<F5F
M<RT^9V5T5F%L=64H)W=E96M?<W1A<G1?;6]N9&%Y)RD@)B8@)&1A=&4M/F1A
M>4]F5V5E:R@I(#T]($A/4D1%7T1!5$5?4U5.1$%9*2!["B`@("`@("`@)'=E
M96LK*SL*("`@('T*("`@(&EF("@D=V5E:R`^(#4Q("8F("1D871E+3YM;VYT
M:"`]/2`Q*2!["B`@("`@("`@)'EE87(M+3L*("`@('T*?0H*)'=E96M/8B`]
M("9N97<@2W)O;F]L:71H7U=E96M6:65W*"1W965K+"`D>65A<BP@2$]21$5?
M1$%415]-3TY$05DL($A/4D1%7T1!5$5?1E))1$%9*3L*)'1I=&QE(#T@<W!R
M:6YT9BA?*")7965K("5D(BDL("1W965K3V(M/G=E96LI.PHD<')I;G1?=FEE
M=R`]("AB;V]L*55T:6PZ.F=E=$9O<FU$871A*"=P<FEN="<I.PH*2&]R9&4Z
M.F%D9%-C<FEP=$9I;&4H)W1O;VQT:7`N:G,G+"`G:&]R9&4G+"!T<G5E*3L*
M2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W-T<FEP92YJ<R<L("=K<F]N;VQI=&@G
M+"!T<G5E*3L*:68@*"$D<')I;G1?=FEE=RD@>PH@("`@2&]R9&4Z.F%D9%-C
M<FEP=$9I;&4H)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U92D["GT*<F5Q=6ER
M92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<[
M"@II9B`H)'!R:6YT7W9I97<I('L*("`@(')E<75I<F5?;VYC92`D<F5G:7-T
M<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+VIA=F%S8W)I<'0O
M<')I;G0N:G,G.PI](&5L<V4@>PH@("`@)'!R:6YT7VQI;FL@/2!5=&EL.CIA
M9&1087)A;65T97(H)W=O<FMW965K+G!H<"<L(&%R<F%Y*"=W965K)R`]/B`D
M=V5E:T]B+3YW965K+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y96%R)R`]/B`D=V5E:T]B
M+3YY96%R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=P<FEN="<@/3X@)W1R=64G*2D["B`@
M("`D<')I;G1?;&EN:R`]($AO<F1E.CIU<FPH)'!R:6YT7VQI;FLI.PH@("`@
M<F5Q=6ER92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]M96YU+FEN8R<["GT*
M"F5C:&\@)SQD:78@:60](G!A9V4B/B<["FEF("@A)'!R:6YT7W9I97<I('L*
M("`@($MR;VYO;&ET:#HZ=&%B<R@I.PI]"B1W965K3V(M/FAT;6PH2U)/3D],
M251(7U1%35!,051%4RD["F5C:&\@)SPO9&EV/B<["@IR97%U:7)E("1R96=I
M<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O
M;W1E<BYI;F,G.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:W)O;F]L:71H+W=E96LN<&AP
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<W
M-@`Q,#0Q-S,V,C<U,P`P,C`Q,3,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:W)O;F]L
M:71H+W=E96LN<&AP+'8@,2XT,RXR+C<@,C`P-B\P,2\P,2`R,3HR.3HP,B!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*B\*
M"D!D969I;F4H)TM23TY/3$E42%]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI
M.PIR97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]B87-E+G!H
M<"<["G)E<75I<F5?;VYC92!+4D].3TQ)5$A?0D%312`N("<O;&EB+U=E96M6
M:65W+G!H<"<["@HD=V5E:R`]("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)W=E
M96LG*3L*)'EE87(@/2`H:6YT*55T:6PZ.F=E=$9O<FU$871A*"=Y96%R)RD[
M"FEF("@D=&EM97-T86UP(#T@*&EN="E5=&EL.CIG971&;W)M1&%T82@G=&EM
M97-T86UP)RDI('L*("`@("1D871E(#T@)FYE=R!(;W)D95]$871E*"1T:6UE
M<W1A;7`I.PH@("`@)'EE87(@/2`D9&%T92T^>65A<CL*("`@("1W965K(#T@
M)&1A=&4M/G=E96M/9EEE87(H*3L*("`@(&EF("@A)'!R969S+3YG971686QU
M92@G=V5E:U]S=&%R=%]M;VYD87DG*2`F)B`D9&%T92T^9&%Y3V97965K*"D@
M/3T@2$]21$5?1$%415]354Y$05DI('L*("`@("`@("`D=V5E:RLK.PH@("`@
M?0H@("`@:68@*"1W965K(#X@-3$@)B8@)&1A=&4M/FUO;G1H(#T](#$I('L*
M("`@("`@("`D>65A<BTM.PH@("`@?0I]"@II9B`H)'!R969S+3YG971686QU
M92@G=V5E:U]S=&%R=%]M;VYD87DG*2D@>PH@("`@)'=E96M/8B`]("9N97<@
M2W)O;F]L:71H7U=E96M6:65W*"1W965K+"`D>65A<BP@2$]21$5?1$%415]-
M3TY$05DL($A/4D1%7T1!5$5?4U5.1$%9("L@-RD["GT@96QS92!["B`@("`D
M=V5E:T]B(#T@)FYE=R!+<F]N;VQI=&A?5V5E:U9I97<H)'=E96LL("1Y96%R
M+"!(3U)$15]$051%7U-53D1!62P@2$]21$5?1$%415]305154D1!62D["GT*
M)'1I=&QE(#T@<W!R:6YT9BA?*")7965K("5D(BDL("1W965K3V(M/G=E96LI
M.PHD<')I;G1?=FEE=R`]("AB;V]L*55T:6PZ.F=E=$9O<FU$871A*"=P<FEN
M="<I.PH*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W1O;VQT:7`N:G,G+"`G:&]R
M9&4G+"!T<G5E*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W-T<FEP92YJ<R<L
M("=K<F]N;VQI=&@G+"!T<G5E*3L*:68@*"$D<')I;G1?=FEE=RD@>PH@("`@
M2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U
M92D["GT*<F5Q=6ER92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]C;VUM;VXM
M:&5A9&5R+FEN8R<["@II9B`H)'!R:6YT7W9I97<I('L*("`@(')E<75I<F5?
M;VYC92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G
M+VIA=F%S8W)I<'0O<')I;G0N:G,G.PI](&5L<V4@>PH@("`@)'!R:6YT7VQI
M;FL@/2!5=&EL.CIA9&1087)A;65T97(H)W=E96LN<&AP)RP@87)R87DH)W=E
M96LG(#T^("1W965K+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)WEE87(G(#T^("1Y96%R+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W!R:6YT)R`]/B`G=')U92<I*3L*("`@("1P<FEN=%]L:6YK(#T@
M2&]R9&4Z.G5R;"@D<')I;G1?;&EN:RD["B`@("!R97%U:7)E($M23TY/3$E4
M2%]414U03$%415,@+B`G+VUE;G4N:6YC)SL*?0H*96-H;R`G/&1I=B!I9#TB
M<&%G92(^)SL*:68@*"$D<')I;G1?=FEE=RD@>PH@("`@2W)O;F]L:71H.CIT
M86)S*"D["GT*)'=E96M/8BT^:'1M;"A+4D].3TQ)5$A?5$5-4$Q!5$53*3L*
M96-H;R`G/"]D:78^)SL*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA
M=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*```N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]V:65W979E;G0N<&AP
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(P-S<`,3`T
M,3<S-C(W-3,`,#(Q,38V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]V
M:65W979E;G0N<&AP+'8@,2XT.2XR+C$R(#(P,#8O,#,O,#,@,C,Z,#`Z,CD@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S
M($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@
M*B\*"D!D969I;F4H)TM23TY/3$E42%]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RDI.PIR97%U:7)E7V]N8V4@2U)/3D],251(7T)!4T4@+B`G+VQI8B]B87-E
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH*:68@*%5T
M:6PZ.F=E=$9O<FU$871A*"=C86QE;F1A<B<I(#T]("<J*G)E;6]T92<I('L*
M("`@("1E=F5N="`]($MR;VYO;&ET:#HZ9V5T4F5M;W1E179E;G1/8FIE8W0H
M571I;#HZ9V5T1F]R;41A=&$H)W)E;6]T94-A;"<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!5=&EL.CIG971&;W)M
M1&%T82@G979E;G1)1"<I*3L*?2!E;'-E:68@*"1U:60@/2!5=&EL.CIG971&
M;W)M1&%T82@G=6ED)RDI('L*("`@("1E=F5N="`]("8D:W)O;F]L:71H+3YG
M971">55)1"@D=6ED*3L*?2!E;'-E('L*("`@("1K<F]N;VQI=&@M/F]P96XH
M571I;#HZ9V5T1F]R;41A=&$H)V-A;&5N9&%R)RDI.PH@("`@)&5V96YT(#T@
M)B1K<F]N;VQI=&@M/F=E=$5V96YT*%5T:6PZ.F=E=$9O<FU$871A*"=E=F5N
M=$E$)RDI.PI]"FEF("@A)&5V96YT*2!["B`@("!I9B`H*"1U<FP@/2!5=&EL
M.CIG971&;W)M1&%T82@G=7)L)RDI(#T]/2!N=6QL*2!["B`@("`@("`@)'5R
M;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D<')E9G,M/F=E=%9A;'5E*"=D
M969A=6QT=FEE=R<I("X@)RYP:'`G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=')U92D["B`@("!]"B`@("!H96%D97(H)TQO8V%T
M:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HO*B!'970@=&AE(&5V96YT
M)W,@:&ES=&]R>2X@*B\*:68@*"1E=F5N="T^9V5T54E$*"DI('L*("`@("1H
M:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@)&QO
M9R`]("1H:7-T;W)Y+3YG971(:7-T;W)Y*"=K<F]N;VQI=&@Z)R`N("1E=F5N
M="T^9V5T0V%L96YD87(H*2`N("<Z)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5V96YT+3YG9715240H*2D["B`@("!I9B`H)&QO9R`F
M)B`A:7-?82@D;&]G+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@9F]R96%C
M:"`H)&QO9RT^9V5T1&%T82@I(&%S("1E;G1R>2D@>PH@("`@("`@("`@("!S
M=VET8V@@*"1E;G1R>5LG86-T:6]N)UTI('L*("`@("`@("`@("`@8V%S92`G
M861D)SH*("`@("`@("`@("`@("`@("1C<F5A=&5D(#T@)&5N=')Y6R=T<R==
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=M
M;V1I9GDG.@H@("`@("`@("`@("`@("`@)&UO9&EF:65D(#T@)&5N=')Y6R=T
M<R==.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"GT*"B1C871E9V]R>2`]("1E=F5N="T^9V5T0V%T96=O
M<GDH*3L*)&1E<V-R:7!T:6]N(#T@)&5V96YT+3YG971$97-C<FEP=&EO;B@I
M.PHD;&]C871I;VX@/2`D979E;G0M/F=E=$QO8V%T:6]N*"D["B1S=&%T=7,@
M/2!+<F]N;VQI=&@Z.G-T871U<U1O4W1R:6YG*"1E=F5N="T^9V5T4W1A='5S
M*"DI.PHD871T96YD965S(#T@)&5V96YT+3YG971!='1E;F1E97,H*3L*"FEF
M("@D8V]N9ELG;65T861A=&$G75LG:V5Y=V]R9',G72D@>PH@("`@:6YC;'5D
M92!+4D].3TQ)5$A?0D%312`N("<O8V]N9FEG+VME>7=O<F1S+G!H<"<["B`@
M("`D:V5Y=V]R9%]L:7-T(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1K97EW
M;W)D<R!A<R`D8V%T(#T^("1L:7-T*2!["B`@("`@("`@)'-U8E]L:7-T(#T@
M87)R87DH*3L*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D96YT<GDI('L*
M("`@("`@("`@("`@:68@*"1E=F5N="T^:&%S2V5Y=V]R9"@D96YT<GDI*2![
M"B`@("`@("`@("`@("`@("`D<W5B7VQI<W1;72`](&AT;6QS<&5C:6%L8VAA
M<G,H)&5N=')Y*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H8V]U;G0H)'-U8E]L:7-T*2D@>PH@("`@("`@("`@("`D:V5Y=V]R9%]L
M:7-T6R1C871=(#T@)'-U8E]L:7-T.PH@("`@("`@('T*("`@('T*?0H*:68@
M*"1T:6UE<W1A;7`@/2`H:6YT*55T:6PZ.F=E=$9O<FU$871A*"=T:6UE<W1A
M;7`G*2D@>PH@("`@)&UO;G1H(#T@9&%T92@G;B<L("1T:6UE<W1A;7`I.PH@
M("`@)'EE87(@/2!D871E*"=9)RP@)'1I;65S=&%M<"D["GT@96QS92!["B`@
M("`D;6]N=&@@/2`H:6YT*55T:6PZ.F=E=$9O<FU$871A*"=M;VYT:"<L(&1A
M=&4H)VXG*2D["B`@("`D>65A<B`]("AI;G0I571I;#HZ9V5T1F]R;41A=&$H
M)WEE87(G+"!D871E*"=9)RDI.PI]"@HD=&ET;&4@/2`D979E;G0M/F=E=%1I
M=&QE*"D["B1P<FEN=%]V:65W(#T@*&)O;VPI571I;#HZ9V5T1F]R;41A=&$H
M)W!R:6YT)RD["FEF("@A)'!R:6YT7W9I97<I('L*("`@($AO<F1E.CIA9&13
M8W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H;W)D92<L('1R=64I.PH@("`@2&]R
M9&4Z.F%D9%-C<FEP=$9I;&4H)W-T<FEP92YJ<R<L("=K<F]N;VQI=&@G+"!T
M<G5E*3L*?0IR97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)SL*"FEF("@D<')I;G1?=FEE=RD@>PH@("`@<F5Q=6ER
M95]O;F-E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N
M("<O:F%V87-C<FEP="]P<FEN="YJ<R<["GT@96QS92!["B`@("`D<')I;G1?
M;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ<V5L9E5R;"AT<G5E
M*2P@)W!R:6YT)RP@)W1R=64G*3L*("`@(')E<75I<F4@2U)/3D],251(7U1%
M35!,051%4R`N("<O;65N=2YI;F,G.PI]"@HD;7EL:6YK<R`](&%R<F%Y*"D[
M"B1I<U)E;6]T92`](%5T:6PZ.F=E=$9O<FU$871A*"=C86QE;F1A<B<I(#T]
M("<J*G)E;6]T92<["@II9B`H(21I<U)E;6]T92`F)@H@("`@)&%L;%]C86QE
M;F1A<G-;)&5V96YT+3YG971#86QE;F1A<B@I72T^:&%S4&5R;6ES<VEO;BA!
M=71H.CIG971!=71H*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%4DU37T1%3$5412P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5V96YT+3YG971#<F5A=&]R240H*2DI('L*("`@("1D96QU
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)V1E;&5V96YT+G!H<"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=E=F5N=$E$)R`]
M/B`D979E;G0M/F=E=$E$*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C86QE;F1A<B<@/3X@)&5V96YT+3YG971#86QE;F1A
M<B@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=&EM97-T86UP)R`]/B`D=&EM97-T86UP*2D["B`@("`D9&5L=7)L(#T@2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"1D96QU<FPI.PH@("`@:68@*"1U<FP@/2!5
M=&EL.CIG971&;W)M1&%T82@G=7)L)RDI('L*("`@("`@("`D9&5L=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1D96QU<FPL("=U<FPG+"`D=7)L*3L*("`@
M('T*("`@("1M>6QI;FMS6UT@/2!(;W)D93HZ=VED9V5T*"1D96QU<FPL("<G
M+"`G)RP@)R<L("<G+"!?*")$95]L971E(BDI.PI]"@II9B`H)&ES4F5M;W1E
M('Q\"B`@("`D86QL7V-A;&5N9&%R<ULD979E;G0M/F=E=$-A;&5N9&%R*"E=
M+3YH87-097)M:7-S:6]N*$%U=&@Z.F=E=$%U=&@H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M4$5235-?141)5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&5V96YT+3YG971#<F5A=&]R240H
M*2DI('L*("`@("1E9&ET=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=E9&ET
M979E;G0N<&AP)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=E=F5N=$E$)R`]/B`D979E;G0M/F=E=$E$*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V%L96YD87(G(#T^
M("1I<U)E;6]T92`_("<J*G)E;6]T92<@.B`D979E;G0M/F=E=$-A;&5N9&%R
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=&EM97-T86UP)R`]/B`D=&EM97-T86UP*2D["B`@("!I9B`H)&ES4F5M;W1E
M*2!["B`@("`@("`@)&5D:71U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&5D
M:71U<FPL("=R96UO=&5#86PG+"`D979E;G0M/G)E;6]T94-A;"D["B`@("!]
M"B`@("!I9B`H)'5R;"`](%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*2D@>PH@
M("`@("`@("1E9&ET=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1E9&ET=7)L
M+"`G=7)L)RP@)'5R;"D["B`@("!](&5L<V4@>PH@("`@("`@("1E9&ET=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1E9&ET=7)L+"`G=7)L)RP@2&]R9&4Z
M.G-E;&95<FPH=')U92DI.PH@("`@?0H@("`@)&5D:71U<FP@/2!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)&5D:71U<FPI.PH*("`@(&EF("@D:7-296UO=&4I
M('L*("`@("`@("`D;7EL:6YK<UM=(#T@2&]R9&4Z.G=I9&=E="@D961I='5R
M;"P@)R<L("<G+"`G)RP@)R<L(%\H(E-A=F4@07,@3F5W(BDI.PH@("`@?2!E
M;'-E('L*("`@("`@("`D;7EL:6YK<UM=(#T@2&]R9&4Z.G=I9&=E="@D961I
M='5R;"P@)R<L("<G+"`G)RP@)R<L(%\H(E]%9&ET(BDI.PH@("`@?0I]"@HO
M+R!$971E<FUI;F4@;W=N97(G<R!N86UE+@HD;W=N97(@/2!+<F]N;VQI=&@Z
M.F=E=%5S97).86UE*"1E=F5N="T^9V5T0W)E871O<DE$*"DI.PH*<F5Q=6ER
M92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]V:65W+W9I97<N:6YC)SL*<F5Q
M=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VMR;VYO;&ET:"]S96%R8V@N<&AP````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#<U-S$`,3`T,3<S-C(W-3,`,#(P-#(R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]S96%R8V@N<&AP+'8@,2XX+C0N-2`R
M,#`V+S`Q+S`Q(#(Q.C(Y.C`R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P-"TR,#`V($UE:6QO9B!6965N:6YG96X@/&UE:6QO9D!W86YA9&]O+FYL
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+V=P;"YH=&UL+@H@*B\*"B\J*@H@*B!5<V5D('=I=&@@=7-O<G0H*2!T
M;R!S;W)T(&5V96YT<R!B87-E9"!O;B!T:&5I<B!S=&%R="!T:6UE<RX*("HO
M"F9U;F-T:6]N(%]S;W)T179E;G1S*"1A+"`D8BD*>PH@("`@9VQO8F%L("1E
M=F5N=#L*"B`@("`D<W1A<G1?82`]("1A+3YN97AT4F5C=7)R96YC92@D979E
M;G0M/G-T87)T*3L*("`@("1S=&%R=%]B(#T@)&(M/FYE>'1296-U<G)E;F-E
M*"1E=F5N="T^<W1A<G0I.PH@("`@)&1I9F8@/2`D<W1A<G1?82T^=&EM97-T
M86UP*"D@+2`D<W1A<G1?8BT^=&EM97-T86UP*"D["B`@("!I9B`H)&1I9F8@
M/3T@,"D@>PH@("`@("`@(')E='5R;B!S=')C;VQL*"1A+3YT:71L92P@)&(M
M/G1I=&QE*3L*("`@('T@96QS92!["B`@("`@("`@<F5T=7)N("1D:69F.PH@
M("`@?0I]"@I`9&5F:6YE*"=+4D].3TQ)5$A?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I*3L*<F5Q=6ER95]O;F-E($M23TY/3$E42%]"05-%("X@)R]L:6(O
M8F%S92YP:'`G.PH*+RH@1V5T('-E87)C:"!P87)A;65T97)S+B`J+PHD<V5A
M<F-H7VUO9&4@/2!5=&EL.CIG971&;W)M1&%T82@G<V5A<F-H7VUO9&4G+"`G
M8F%S:6,G*3L*"FEF("@D<V5A<F-H7VUO9&4@(3T@)V)A<VEC)RD@>PH@("`@
M+RH@36%K92!A(&YE=R!E;7!T>2!E=F5N="!O8FIE8W0@=VET:"!D969A=6QT
M('9A;'5E<RX@*B\*("`@("1E=F5N="`]("8D:W)O;F]L:71H+3YG971%=F5N
M="@I.PH@("`@)&5V96YT+3YT:71L92`]("1E=F5N="T^8V%L96YD87)S(#T@
M)&5V96YT+3YC871E9V]R>2`]("1E=F5N="T^;&]C871I;VX@/0H@("`@)&5V
M96YT+3YS=&%T=7,@/2`D979E;G0M/F1E<V-R:7!T:6]N(#T@;G5L;#L*"B`@
M("`O*B!3970@<W1A<G0@;VX@=&]D87DL('-T;W`@;VX@=&]M;W)R;W<N("HO
M"B`@("`D979E;G0M/G-T87)T(#T@)FYE=R!(;W)D95]$871E*&UK=&EM92@P
M+"`P+"`P*2D["B`@("`D979E;G0M/F5N9"`]("9N97<@2&]R9&5?1&%T92AM
M:W1I;64H,"P@,"P@,"P@9&%T92@G;B<I+"!D871E*"=J)RD@*R`Q*2D["@H@
M("`@+RH@5V4@;F5E9"!T;R!S970@=&AE(&5V96YT('1O(&EN:71I86QI>F5D
M+"!O=&AE<G=I<V4@=V4@=VEL;"!E;F0@=7`@=VET:`H@("`@("H@82!D969A
M=6QT(&5N9"!D871E+B`J+PH@("`@)&5V96YT+3YI;FET:6%L:7IE9"`]('1R
M=64["@H@("`@)'%?=&ET;&4@/2!5=&EL.CIG971&;W)M1&%T82@G=&ET;&4G
M*3L*"B`@("!I9B`H:7-S970H)'%?=&ET;&4I*2!["B`@("`@("`@+RH@5V4G
M<F4@<F5T=7)N:6YG(&9R;VT@82!P<F5V:6]U<R!S96%R8V@N("HO"B`@("`@
M("`@)&5V96YT+3YR96%D1F]R;2@I.PH@("`@("`@(&EF("@D979E;G0M/F-A
M=&5G;W)Y(#T]("=?7V%N>2<I('L*("`@("`@("`@("`@)&5V96YT+3YC871E
M9V]R>2`](&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&
M;W)M1&%T82@G<W1A='5S)RD@/3T@2U)/3D],251(7U-405154U].3TY%*2![
M"B`@("`@("`@("`@("1E=F5N="T^<W1A='5S(#T@;G5L;#L*("`@("`@("!]
M"B`@("!]"GT*"B1D97-C(#T@571I;#HZ9V5T1F]R;41A=&$H)W!A='1E<FY?
M9&5S8R<I.PHD=&ET;&4@/2!5=&EL.CIG971&;W)M1&%T82@G<&%T=&5R;E]T
M:71L92<I.PII9B`H)&1E<V,@?'P@)'1I=&QE*2!["B`@("`O*B!792=R92!D
M;VEN9R!A('-I;7!L92!S96%R8V@N("HO"B`@("`D979E;G0@/2`F)&MR;VYO
M;&ET:"T^9V5T179E;G0H*3L*("`@("1E=F5N="T^<V5T1&5S8W)I<'1I;VXH
M)&1E<V,I.PH@("`@)&5V96YT+3YS9714:71L92@D=&ET;&4I.PH@("`@)&5V
M96YT+3YC871E9V]R>2`](&YU;&P["B`@("`D979E;G0M/G-T871U<R`](&YU
M;&P["@H@("`@)'1I;64Q(#T@=&EM92@I.PH@("`@)')A;F=E(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W)A;F=E)RD["B`@("!I9B`H)')A;F=E(#T]("<K)RD@
M>PH@("`@("`@("1E=F5N="T^<W1A<G0@/2`F;F5W($AO<F1E7T1A=&4H)'1I
M;64Q*3L*("`@("`@("`D979E;G0M/F5N9"`](&YU;&P["B`@("!](&5L<V5I
M9B`H)')A;F=E(#T]("<M)RD@>PH@("`@("`@("1E=F5N="T^<W1A<G0@/2!N
M=6QL.PH@("`@("`@("1E=F5N="T^96YD(#T@)FYE=R!(;W)D95]$871E*"1T
M:6UE,2D["B`@("!](&5L<V4@>PH@("`@("`@("1T:6UE,B`]("1T:6UE,2`K
M("1R86YG93L*("`@("`@("`D979E;G0M/G-T87)T(#T@)FYE=R!(;W)D95]$
M871E*&UI;B@D=&EM93$L("1T:6UE,BDI.PH@("`@("`@("1E=F5N="T^96YD
M(#T@)FYE=R!(;W)D95]$871E*&UA>"@D=&EM93$L("1T:6UE,BDI.PH@("`@
M?0H@("`@)&5V96YT<R`]($MR;VYO;&ET:#HZ<V5A<F-H*"1E=F5N="D["GT@
M96QS96EF("AI<W-E="@D<5]T:71L92DI('L*("`@("\J($%D=F%N8V5D('-E
M87)C:"X@*B\*("`@("1E=F5N=',@/2!+<F]N;VQI=&@Z.G-E87)C:"@D979E
M;G0I.PI]"@HD=&ET;&4@/2!?*")396%R8V@B*3L*2&]R9&4Z.F%D9%-C<FEP
M=$9I;&4H)W1O;VQT:7`N:G,G+"`G:&]R9&4G+"!T<G5E*3L*<F5Q=6ER92!+
M4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E
M<75I<F4@2U)/3D],251(7U1%35!,051%4R`N("<O;65N=2YI;F,G.PH*96-H
M;R`G/&1I=B!I9#TB<&%G92(^)SL*:68@*"1S96%R8VA?;6]D92`]/2`G8F%S
M:6,G*2!["B`@("!R97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G+W-E
M87)C:"]S96%R8V@N:6YC)SL*("`@("1N;W1I9FEC871I;VXM/G!U<V@H)V1O
M8W5M96YT+F5V96YT+G!A='1E<FY?=&ET;&4N9F]C=7,H*2<L("=J879A<V-R
M:7!T)RD["GT@96QS92!["B`@("!R97%U:7)E($M23TY/3$E42%]414U03$%4
M15,@+B`G+W-E87)C:"]S96%R8VA?861V86YC960N:6YC)SL*("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H)V1O8W5M96YT+F5V96YT+G1I=&QE+F9O8W5S*"DG
M+"`G:F%V87-C<FEP="<I.PI]"@HO*B!$:7-P;&%Y('-E87)C:"!R97-U;'1S
M+B`J+PII9B`H:7-S970H)&5V96YT<RDI('L*("`@(&EF("AC;W5N="@D979E
M;G1S*2D@>PH@("`@("`@('5S;W)T*"1E=F5N=',L("=?<V]R=$5V96YT<R<I
M.PH*("`@("`@("!R97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G+W-E
M87)C:"]H96%D97(N:6YC)SL*("`@("`@("!R97%U:7)E($M23TY/3$E42%]4
M14U03$%415,@+B`G+W-E87)C:"]E=F5N=%]H96%D97)S+FEN8R<["@H@("`@
M("`@(&9O<F5A8V@@*"1E=F5N=',@87,@)&9O=6YD*2!["B`@("`@("`@("`@
M("1S=&%R="`]("1F;W5N9"T^;F5X=%)E8W5R<F5N8V4H)&5V96YT+3YS=&%R
M="D["B`@("`@("`@("`@("1E;F0@/2`F;F5W($AO<F1E7T1A=&4H)'-T87)T
M+3YT:6UE<W1A;7`H*2`K("1F;W5N9"T^9'5R36EN("H@-C`I.PH@("`@("`@
M("`@("!R97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G+W-E87)C:"]E
M=F5N=%]S=6UM87)I97,N:6YC)SL*("`@("`@("!]"B`@("`@("`@<F5Q=6ER
M92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]S96%R8V@O979E;G1?9F]O=&5R
M<RYI;F,G.PH@("`@?2!E;'-E('L*("`@("`@("!R97%U:7)E($M23TY/3$E4
M2%]414U03$%415,@+B`G+W-E87)C:"]E;7!T>2YI;F,G.PH@("`@?0I]"@IE
M8VAO("<\+V1I=CXG.PIR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T
M97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VMR;VYO;&ET:"]M;VYT:"YP:'``````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<T,#(`,3`T,3<S
M-C(W-3,`,#(P,C<T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&MR;VYO;&ET:"]M;VYT
M:"YP:'`L=B`Q+C$W,"XT+C$P(#(P,#8O,#(O,#D@,C,Z-#4Z-3$@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B`@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G
M2U)/3D],251(7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?
M;VYC92!+4D].3TQ)5$A?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"FEF("@D
M=&EM97-T86UP(#T@*&EN="E5=&EL.CIG971&;W)M1&%T82@G=&EM97-T86UP
M)RDI('L*("`@("1M;VYT:"`](&1A=&4H)VXG+"`D=&EM97-T86UP*3L*("`@
M("1Y96%R(#T@9&%T92@G62<L("1T:6UE<W1A;7`I.PI](&5L<V4@>PH@("`@
M)&UO;G1H(#T@*&EN="E5=&EL.CIG971&;W)M1&%T82@G;6]N=&@G+"!D871E
M*"=N)RDI.PH@("`@)'EE87(@/2`H:6YT*55T:6PZ.F=E=$9O<FU$871A*"=Y
M96%R)RP@9&%T92@G62<I*3L*?0HD<VED96)Y<VED92`]("1P<F5F<RT^9V5T
M5F%L=64H)W-H;W=?<VAA<F5D7W-I9&5?8GE?<VED92<I.PHD=&EM97-T86UP
M(#T@;6MT:6UE*#$L(#$L(#$L("1M;VYT:"P@,2P@)'EE87(I.PHD<')E=G-T
M86UP(#T@;6MT:6UE*#$L(#$L(#$L("1M;VYT:"`M(#$L(#$L("1Y96%R*3L*
M)&YE>'1S=&%M<"`](&UK=&EM92@Q+"`Q+"`Q+"`D;6]N=&@@*R`Q+"`Q+"`D
M>65A<BD["B1T:71L92`]('-T<F9T:6UE*"<E0B`E62<L("1T:6UE<W1A;7`I
M.PHD<')I;G1?=FEE=R`]("AB;V]L*55T:6PZ.F=E=$9O<FU$871A*"=P<FEN
M="<I.PH*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W1O;VQT:7`N:G,G+"`G:&]R
M9&4G+"!T<G5E*3L*:68@*"$D<')I;G1?=FEE=RD@>PH@("`@2&]R9&4Z.F%D
M9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U92D["GT*<F5Q
M=6ER92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN
M8R<["@II9B`H)'!R:6YT7W9I97<I('L*("`@(')E<75I<F5?;VYC92`D<F5G
M:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+VIA=F%S8W)I
M<'0O<')I;G0N:G,G.PI](&5L<V4@>PH@("`@)'!R:6YT7VQI;FL@/2!5=&EL
M.CIA9&1087)A;65T97(H)VUO;G1H+G!H<"<L(&%R<F%Y*"=T:6UE<W1A;7`G
M(#T^("1T:6UE<W1A;7`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!R:6YT)R`]/B`G=')U92<I
M*3L*("`@("1P<FEN=%]L:6YK(#T@2&]R9&4Z.G5R;"@D<')I;G1?;&EN:RD[
M"B`@("!R97%U:7)E($M23TY/3$E42%]414U03$%415,@+B`G+VUE;G4N:6YC
M)SL*?0H*96-H;R`G/&1I=B!I9#TB<&%G92(^)SL*"FEF("@A)'!R:6YT7W9I
M97<I('L*("`@($MR;VYO;&ET:#HZ=&%B<R@I.PI]"@HD<W1A<G1D87D@/2`F
M;F5W($AO<F1E7T1A=&4H87)R87DH)VUD87DG(#T^(#$L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;6]N=&@G(#T^("1M;VYT:"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y96%R)R`]/B`D>65A
M<BDI.PHD<W1A<G1D87D@/2`D<W1A<G1D87DM/F1A>4]F5V5E:R@I.PHD9&%Y
M<TEN5FEE=R`]($1A=&5?0V%L8SHZ=V5E:W-);DUO;G1H*"1M;VYT:"P@)'EE
M87(I("H@-SL*:68@*"$D<')E9G,M/F=E=%9A;'5E*"=W965K7W-T87)T7VUO
M;F1A>2<I*2!["B`@("`D<W1A<G1/9E9I97<@/2`Q("T@)'-T87)T9&%Y.PH*
M("`@("\O(%=E(&UA>2!N965D('1O(&%D:G5S="!T:&4@;G5M8F5R(&]F(&1A
M>7,@:6X@=&AE('9I97<@:68@=V4G<F4*("`@("\O('-T87)T:6YG('=E96MS
M(&]N(%-U;F1A>2X*("`@(&EF("@D<W1A<G1D87D@/3T@2$]21$5?1$%415]3
M54Y$05DI('L*("`@("`@("`D9&%Y<TEN5FEE=R`M/2`W.PH@("`@?0H@("`@
M)&5N9&1A>2`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G;61A>2<@/3X@2&]R
M9&5?1&%T93HZ9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@/3X@)&UO;G1H
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>65A<B<@
M/3X@)'EE87(I*3L*("`@("1E;F1D87D@/2`D96YD9&%Y+3YD87E/9E=E96LH
M*3L*("`@(&EF("@D96YD9&%Y(#T]($A/4D1%7T1!5$5?4U5.1$%9*2!["B`@
M("`@("`@)&1A>7-);E9I97<@*ST@-SL*("`@('T*?2!E;'-E('L*("`@(&EF
M("@D<W1A<G1D87D@/3T@2$]21$5?1$%415]354Y$05DI('L*("`@("`@("`D
M<W1A<G1/9E9I97<@/2`M-3L*("`@('T@96QS92!["B`@("`@("`@)'-T87)T
M3V96:65W(#T@,B`M("1S=&%R=&1A>3L*("`@('T*?0H*)'!R979U<FP@/2!(
M;W)D93HZ87!P;&EC871I;VYU<FPH571I;#HZ861D4&%R86UE=&5R*"=M;VYT
M:"YP:'`G+"!A<G)A>2@G;6]N=&@G(#T^(&1A=&4H)VXG+"`D<')E=G-T86UP
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>65A<B<@/3X@9&%T92@G
M62<L("1P<F5V<W1A;7`I*2DI.PHD;F5X='5R;"`]($AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"A5=&EL.CIA9&1087)A;65T97(H)VUO;G1H+G!H<"<L(&%R<F%Y
M*"=M;VYT:"<@/3X@9&%T92@G;B<L("1N97AT<W1A;7`I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=Y96%R)R`]/B!D871E*"=9)RP@)&YE>'1S=&%M
M<"DI*2D["FEF("@D<VED96)Y<VED92D@>PH@("`@<F5Q=6ER92!+4D].3TQ)
M5$A?5$5-4$Q!5$53("X@)R]M;VYT:"]H96%D7W-I9&5?8GE?<VED92YI;F,G
M.PI](&5L<V4@>PH@("`@<F5Q=6ER92!+4D].3TQ)5$A?5$5-4$Q!5$53("X@
M)R]M;VYT:"]H96%D+FEN8R<["GT*"B1S=&%R=$1A=&4@/2`F;F5W($AO<F1E
M7T1A=&4H87)R87DH)WEE87(G(#T^("1Y96%R+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=M;VYT:"<@/3X@)&UO;G1H+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B`D<W1A<G1/
M9E9I97<I*3L*)&5N9$1A=&4@/2`F;F5W($AO<F1E7T1A=&4H87)R87DH)WEE
M87(G(#T^("1Y96%R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;6]N=&@G(#T^("1M;VYT:"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VUD87DG(#T^("1S=&%R=$]F5FEE=R`K("1D87ES26Y6:65W
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]U<B<@/3X@
M,C,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M:6XG(#T^
M(#4Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V5C)R`]
M/B`U.2DI.PHD<W1A<G1$871E+3YC;W)R96-T*"D["B1E;F1$871E+3YC;W)R
M96-T*"D["B1A;&QE=F5N=',@/2!+<F]N;VQI=&@Z.FQI<W1%=F5N=',H)'-T
M87)T1&%T92P@)&5N9$1A=&4L("1'3$]"04Q36R=D:7-P;&%Y7V-A;&5N9&%R
M<R==*3L*:68@*"1S:61E8GES:61E*2!["B`@("`D86QL0V%L96YD87)S(#T@
M2W)O;F]L:71H.CIL:7-T0V%L96YD87)S*"D["B`@("`D8W5R<F5N=$-A;&5N
M9&%R<R`](&%R<F%Y*"D["B`@("!F;W)E86-H("@D1TQ/0D%,4ULG9&ES<&QA
M>5]C86QE;F1A<G,G72!A<R`D:60I('L*("`@("`@("`D8W5R<F5N=$-A;&5N
M9&%R<ULD:61=(#T@)B1A;&Q#86QE;F1A<G-;)&ED73L*("`@('T*("`@("1S
M:&%R961#86QE;F1A<G,@/2`D1TQ/0D%,4ULG9&ES<&QA>5]C86QE;F1A<G,G
M73L*?2!E;'-E('L*("`@)&-U<G)E;G1#86QE;F1A<G,@/2!A<G)A>2AT<G5E
M*3L*?0H*)&5V96YT0V%T96=O<FEE<R`](&%R<F%Y*"D["@HD:'1M;"`]("<G
M.PII9B`H(21S:61E8GES:61E("8F(&-O=6YT*"1C=7)R96YT0V%L96YD87)S
M*2D@>PH@("`@)&AT;6P@+CT@)SQT<CXG.PI]"F9O<F5A8V@@*"1C=7)R96YT
M0V%L96YD87)S(&%S("1I9"`]/B`D8V%L*2!["B`@("!I9B`H)'-I9&5B>7-I
M9&4I('L*("`@("`@("`D:'1M;"`N/2`G/'1R/B<["B`@("!]"@H@("`@)&-E
M;&P@/2`P.PH@("`@9F]R("@D9&%Y(#T@)'-T87)T3V96:65W.R`D9&%Y(#P@
M)'-T87)T3V96:65W("L@)&1A>7-);E9I97<[("1D87DK*RD@>PH@("`@("`@
M("1D871E(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=Y96%R)R`]/B`D>65A
M<BP@)VUO;G1H)R`]/B`D;6]N=&@L("=M9&%Y)R`]/B`D9&%Y*2D["B`@("`@
M("`@)&1A>7-T86UP(#T@)&1A=&4M/G1I;65S=&%M<"@I.PH@("`@("`@("1D
M871E+3YH;W5R(#T@)'!R969S+3YG971686QU92@G='=E;G1Y1F]U<B<I(#\@
M,3(@.B`V.PH@("`@("`@("1T:6UE<W1A;7`@/2`D9&%T92T^=&EM97-T86UP
M*"D["B`@("`@("`@)'=E96L@/2`D9&%T92T^=V5E:T]F665A<B@I.PH*("`@
M("`@("!I9B`H)&-E;&P@)2`W(#T](#`@)B8@)&-E;&P@(3T@,"D@>PH@("`@
M("`@("`@("!I9B`H)'-I9&5B>7-I9&4I('L*("`@("`@("`@("`@("`@("1H
M=&UL("X]("<\=&0^)R`N("1C86PM/F=E="@G;F%M92<I.PH@("`@("`@("`@
M("`@("`@:68@*"$D<')I;G1?=FEE=RD@>PH@("`@("`@("`@("`@("`@("`@
M("1H=&UL("X]("<@)R`N($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E
M<BA(;W)D93HZ<V5L9E5R;"@I+"`G9&ES<&QA>5]C86PG+"`D8V%L+3YG9713
M:&]R=$YA;64H*2DL('-P<FEN=&8H7R@B2&ED92`E<R(I+"`D8V%L+3YG970H
M)VYA;64G*2DI("X@2&]R9&4Z.FEM9R@G9&5L971E+7-M86QL+G!N9R<L(%\H
M(DAI9&4B*2P@)R<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I
M<B@G:&]R9&4G*2D@+B`G/"]A/B<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D:'1M;"`N/2`G/"]T9#XG.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@(CPO='(^7&X\='(^(CL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H;6MT:6UE*#`L
M(#`L(#`I(#T]("1D87ES=&%M<"D@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G
M=&]D87DG.PH@("`@("`@('T@96QS96EF("AD871E*"=N)RP@)&1A>7-T86UP
M*2`A/2`D;6]N=&@I('L*("`@("`@("`@("`@)'-T>6QE(#T@)V]T:&5R;6]N
M=&@G.PH@("`@("`@('T@96QS96EF("AD871E*"=W)RP@)&1A>7-T86UP*2`]
M/2`P('Q\(&1A=&4H)W<G+"`D9&%Y<W1A;7`I(#T](#8I('L*("`@("`@("`@
M("`@)'-T>6QE(#T@)W=E96ME;F0G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1S='EL92`]("=T97AT)SL*("`@("`@("!]"@H@("`@("`@("1H
M=&UL("X]("<\=&0@8VQA<W,](B<@+B`D<W1Y;&4@+B`G(B!H96EG:'0](C<P
M(B!W:61T:#TB,30E(B!V86QI9VX](G1O<"(^/&1I=CXG.PH*("`@("`@("`D
M=7)L(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G9&%Y+G!H<"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1I;65S=&%M<"<L("1D87ES=&%M<"D["B`@("`@("`@)&AT;6P@+CT@
M)SQA(&-L87-S/2)D87DB(&AR968](B<@+B`D=7)L("X@)R(^)R`N(&1A=&4H
M)VHG+"`D9&%Y<W1A;7`I("X@)SPO83XG.PH*("`@("`@("!I9B`H2W)O;F]L
M:71H.CIG971$969A=6QT0V%L96YD87(H4$5235-?141)5"D@)B8@(21P<FEN
M=%]V:65W("8F"B`@("`@("`@("`@("@A96UP='DH)&-O;F9;)VAO;VMS)UU;
M)W!E<FUS9&5N:65D)UTI('Q\"B`@("`@("`@("`@("!+<F]N;VQI=&@Z.FAA
M<U!E<FUI<W-I;VXH)VUA>%]E=F5N=',G*2`]/3T@=')U92!\?`H@("`@("`@
M("`@("`@2W)O;F]L:71H.CIH87-097)M:7-S:6]N*"=M87A?979E;G1S)RD@
M/B!+<F]N;VQI=&@Z.F-O=6YT179E;G1S*"DI*2!["B`@("`@("`@("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"=A9&1E=F5N="YP:'`G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G=&EM97-T86UP)R`]/B`D=&EM97-T86UP+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U
M<FPG(#T^($AO<F1E.CIS96QF57)L*'1R=64L(&9A;'-E+"!T<G5E*2DI.PH@
M("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@D=7)L+"!?*")#<F5A
M=&4@82!.97<@179E;G0B*2P@)VYE=T5V96YT)RD*("`@("`@("`@("`@("`@
M("X@2&]R9&4Z.FEM9R@G;F5W7W-M86QL+G!N9R<L("<K)RD*("`@("`@("`@
M("`@("`@("X@)SPO83XG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1D871E
M+3YD87E/9E=E96LH*2`]/2!(3U)$15]$051%7TU/3D1!62D@>PH@("`@("`@
M("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=W965K+G!H<"<L("=W
M965K)RP@)'=E96LI.PH@("`@("`@("`@("!I9B`H)&UO;G1H(#T](#$R("8F
M("1W965K(#T](#$I('L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA
M9&1087)A;65T97(H)'5R;"P@)WEE87(G+"`D>65A<B`K(#$I.PH@("`@("`@
M("`@("!](&5L<V5I9B`H)&UO;G1H(#T](#$@)B8@)'=E96L@/B`U,2D@>PH@
M("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G>65A<B<L("1Y96%R("T@,2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL
M("=Y96%R)RP@)'EE87(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H
M=&UL("X]($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D=7)L
M*2P@)R<L("=W965K)RD@+B!S<')I;G1F*%\H(E=E96L@)60B*2P@)'=E96LI
M("X@)SPO83XG.PH@("`@("`@('T*"B`@("`@("`@)&AT;6P@+CT@)SPO9&EV
M/CQD:78@8VQA<W,](F-L96%R(CXF;F)S<#L\+V1I=CXG.PH*("`@("`@("!I
M9B`H(65M<'1Y*"1A;&QE=F5N='-;)&1A>7-T86UP72D@)B8*("`@("`@("`@
M("`@8V]U;G0H)&%L;&5V96YT<ULD9&%Y<W1A;7!=*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D86QL979E;G1S6R1D87ES=&%M<%T@87,@)&5V96YT*2![
M"B`@("`@("`@("`@("`@("!I9B`H(21S:61E8GES:61E('Q\("1E=F5N="T^
M9V5T0V%L96YD87(H*2`]/2`D:60I('L*("`@("`@("`@("`@("`@("`@("`D
M979E;G1#871E9V]R:65S6R1E=F5N="T^9V5T0V%T96=O<GDH*5T@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\9&EV(&-L87-S/2)M
M;VYT:"UE=F5N=&)O>"!C871E9V]R>2<@+B!M9#4H)&5V96YT+3YG971#871E
M9V]R>2@I*2`N("<B/B<@+@H@("`@("`@("`@("`@("`@("`@("`@("`D979E
M;G0M/F=E=$QI;FLH)'1I;65S=&%M<"D@+B`G/"]D:78^)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&AT
M;6P@+CT@(CPO=&0^7&XB.PH@("`@("`@("1C96QL*RL["B`@("!]"@H@("`@
M:68@*"1S:61E8GES:61E*2!["B`@("`@("`@)&AT;6P@+CT@)SPO='(^)SL*
M("`@('T*?0II9B`H(21S:61E8GES:61E("8F(&-O=6YT*"1C=7)R96YT0V%L
M96YD87)S*2D@>PH@("`@)&AT;6P@+CT@)SPO='(^)SL*?0H*96-H;R`D:'1M
M;"`N("<\+W1A8FQE/CPO=&0^/"]T<CX\+W1A8FQE/CPO9&EV/B<["G)E<75I
M<F4@2U)/3D],251(7U1%35!,051%4R`N("<O8V%T96=O<GE?;&5G96YD+FEN
M8R<["G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D
M92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82\`
M````````````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4V`#`Q-34T-``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1U<F)A+W-C<FEP=',O````````````````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#$W
M,C,P`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<V-R:7!T<R]S<6PO
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<U,P`P,C`P,C<`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M=7)B82]S8W)I<'1S+W-Q;"]T=7)B85]O8FIE8W1S+F]C:3@N<W%L````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q-C<Q`#$P-#$W,S8R-S4S`#`R-#(T,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M('1U<F)A+W-C<FEP=',O<W%L+W1U<F)A7V]B:F5C=',N;V-I."YS<6PL=B`Q
M+C,@,C`P-"\Q,2\Q-2`P-#HR-SHP-"!C:'5C:R!%>'`@)`H*0U)%051%(%1!
M0DQ%('1U<F)A7V]B:F5C=',@*`H@("`@;V)J96-T7VED(%9!4D-(05(R*#,R
M*2!.3U0@3E5,3"P*("`@(&]W;F5R7VED(%9!4D-(05(R*#(U-2D@3D]4($Y5
M3$PL"B`@("!O8FIE8W1?='EP92!605)#2$%2,B@R-34I($1%1D%53%0@)T]B
M:F5C="<@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED(%9!4D-(05(R*#(U-2DL
M"B`@("!O8FIE8W1?;65M8F5R<R!#3$]"+`H@("`@;V)J96-T7VYA;64@5D%2
M0TA!4C(H,C4U*2P*("`@(&]B:F5C=%]A;&EA<R!605)#2$%2,B@S,BDL"B`@
M("!O8FIE8W1?96UA:6P@5D%20TA!4C(H,C4U*2P*("`@(&]B:F5C=%]H;VUE
M861D<F5S<R!605)#2$%2,B@R-34I+`H@("`@;V)J96-T7W=O<FMA9&1R97-S
M(%9!4D-(05(R*#(U-2DL"B`@("!O8FIE8W1?:&]M97!H;VYE(%9!4D-(05(R
M*#(U*2P*("`@(&]B:F5C=%]W;W)K<&AO;F4@5D%20TA!4C(H,C4I+`H@("`@
M;V)J96-T7V-E;&QP:&]N92!605)#2$%2,B@R-2DL"B`@("!O8FIE8W1?9F%X
M(%9!4D-(05(R*#(U*2P*("`@(&]B:F5C=%]T:71L92!605)#2$%2,B@R-34I
M+`H@("`@;V)J96-T7V-O;7!A;GD@5D%20TA!4C(H,C4U*2P*("`@(&]B:F5C
M=%]N;W1E<R!#3$]"+`H@("`@;V)J96-T7W!G<'!U8FQI8VME>2!#3$]"+`H@
M("`@;V)J96-T7W-M:6UE<'5B;&EC:V5Y($-,3T(L"B`@("!O8FIE8W1?9G)E
M96)U<WEU<FP@5D%20TA!4C(H,C4U*2P*("`@(%!224U!4ED@2T59*&]B:F5C
M=%]I9"D**3L*"D-214%412!)3D1%6"!T=7)B85]O=VYE<E]I9'@@3TX@='5R
M8F%?;V)J96-T<R`H;W=N97)?:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L
M(%501$%412P@1$5,151%($].('1U<F)A7V]B:F5C=',@5$\@:&]R9&4["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T=7)B82]S8W)I<'1S+W-Q;"]T=7)B85]O8FIE8W1S+FUS<W%L+G-Q
M;````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S$S`#$P-#$W,S8R-S4S`#`R-#4S,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+2`D
M2&]R9&4Z('1U<F)A+W-C<FEP=',O<W%L+W1U<F)A7V]B:F5C=',N;7-S<6PN
M<W%L+'8@,2XQ+C(N,2`R,#`V+S`Q+S$X(#$Y.C4Y.C0P(&)E;B!%>'`@)`H*
M0U)%051%(%1!0DQ%('1U<F)A7V]B:F5C=',@*`H@("`@;V)J96-T7VED(%9!
M4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@;W=N97)?:60@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@;V)J96-T7W1Y<&4@5D%20TA!4B@R-34I($Y/5"!.
M54Q,($1%1D%53%0@)T]B:F5C="<L"B`@("!O8FIE8W1?=6ED(%9!4D-(05(H
M,C4U*2P*("`@(&]B:F5C=%]M96UB97)S($),3T(L"B`@("!O8FIE8W1?;F%M
M92!605)#2$%2*#(U-2DL"B`@("!O8FIE8W1?86QI87,@5D%20TA!4B@S,BDL
M"B`@("!O8FIE8W1?96UA:6P@5D%20TA!4B@R-34I+`H@("`@;V)J96-T7VAO
M;65A9&1R97-S(%9!4D-(05(H,C4U*2P*("`@(&]B:F5C=%]W;W)K861D<F5S
M<R!605)#2$%2*#(U-2DL"B`@("!O8FIE8W1?:&]M97!H;VYE(%9!4D-(05(H
M,C4I+`H@("`@;V)J96-T7W=O<FMP:&]N92!605)#2$%2*#(U*2P*("`@(&]B
M:F5C=%]C96QL<&AO;F4@5D%20TA!4B@R-2DL"B`@("!O8FIE8W1?9F%X(%9!
M4D-(05(H,C4I+`H@("`@;V)J96-T7W1I=&QE(%9!4D-(05(H,C4U*2P*("`@
M(&]B:F5C=%]C;VUP86YY(%9!4D-(05(H,C4U*2P*("`@(&]B:F5C=%]N;W1E
M<R!605)#2$%2*$U!6"DL"B`@("!O8FIE8W1?<&=P<'5B;&EC:V5Y(%9!4D-(
M05(H34%8*2P*("`@(&]B:F5C=%]S;6EM97!U8FQI8VME>2!605)#2$%2*$U!
M6"DL"B`@("!O8FIE8W1?9G)E96)U<WEU<FP@5D%20TA!4B@R-34I+`HM+2`@
M("`*("`@(%!224U!4ED@2T59*&]B:F5C=%]I9"D**3L*"D-214%412!)3D1%
M6"!T=7)B85]O=VYE<E]I9'@@3TX@='5R8F%?;V)J96-T<R`H;W=N97)?:60I
M.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].('1U
M<F)A7V]B:F5C=',@5$\@:&]R9&4["@``````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T=7)B82]S8W)I<'1S+W-Q;"]T=7)B85]W961D:6YG9W5E
M<W1S+G-Q;````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#<V`#$P-#$W,S8R-S4S`#`R
M-#8R-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+2`D2&]R9&4Z('1U<F)A+W-C<FEP=',O<W%L+W1U<F)A7W=E9&1I;F=G
M=65S=',N<W%L+'8@,2XS(#(P,#0O,3$O,34@,#0Z,C<Z,#0@8VAU8VL@17AP
M("0*"D-214%412!404),12!T=7)B85]W961D:6YG9W5E<W1S("@*("`@(&]B
M:F5C=%]I9"`@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$P@1$5&
M055,5"`G)RP*("`@(&]W;F5R7VED("`@("`@("`@("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`@("!O8FIE8W1?='EP92`@("`@
M("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("=/8FIE8W0G
M+`H@("`@;V)J96-T7W5I9"`@("`@("`@("`@("!605)#2$%2*#(U-2DL"B`@
M("!O8FIE8W1?;65M8F5R<R`@("`@("`@($),3T(L"B`@("!O8FIE8W1?;F%M
M93$@("`@("`@("`@(%9!4D-(05(H,C4U*2!$149!54Q4($Y53$PL"B`@("!O
M8FIE8W1?96UA:6PQ("`@("`@("`@(%9!4D-(05(H,C4U*2!$149!54Q4($Y5
M3$PL"B`@("!O8FIE8W1?:&]M96%D9')E<W,@("`@(%9!4D-(05(H,C4U*2!$
M149!54Q4($Y53$PL"B`@("!O8FIE8W1?:&]M97!H;VYE("`@("`@(%9!4D-(
M05(H,C4I($1%1D%53%0@3E5,3"P*("`@(&]B:F5C=%]M96%L,2`@("`@("`@
M("`@5D%20TA!4B@U,"D@1$5&055,5"!.54Q,+`H@("`@;V)J96-T7W1A8FQE
M("`@("`@("`@("!605)#2$%2*#4P*2!$149!54Q4($Y53$PL"B`@("!O8FIE
M8W1?<G-V<"`@("`@("`@("`@(%9!4D-(05(H-3`I($1%1D%53%0@3E5,3"P*
M("`@(&]B:F5C=%]B<G5N8VA?<G-V<"`@("`@5D%20TA!4B@U,"D@1$5&055,
M5"!.54Q,+`H@("`@;V)J96-T7V=I9G0@("`@("`@("`@("!605)#2$%2*#$P
M,"D@1$5&055,5"!.54Q,+`H@("`@;V)J96-T7W1H86YK>6]U("`@("`@("!6
M05)#2$%2*#4P*2!$149!54Q4($Y53$PL"B`@("!O8FIE8W1?;F]T97,@("`@
M("`@("`@(%1%6%0L"B`@("!O8FIE8W1?;65A;#(@("`@("`@("`@(%9!4D-(
M05(H-3`I($1%1D%53%0@3E5,3"P*("`@(&]B:F5C=%]N86UE,B`@("`@("`@
M("`@5D%20TA!4B@R-34I($1%1D%53%0@3E5,3"P*("`@(&]B:F5C=%]E;6%I
M;#(@("`@("`@("`@5D%20TA!4B@R-34I($1%1D%53%0@3E5,3"P*("`@(&]B
M:F5C=%]B<G5N8VA?:6YV:71E9"`@5D%20TA!4B@Q,"D@1$5&055,5"!.54Q,
M+`HM+0H@("`@4%))34%262!+15D@*&]B:F5C=%]I9"D**3L*"D-214%412!)
M3D1%6"!T=7)B85]W961D:6YG7VED>"!/3B!T=7)B85]W961D:6YG9W5E<W1S
M("AO=VYE<E]I9"D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$
M14Q%5$4@3TX@='5R8F%?=V5D9&EN9V=U97-T<R!43R!H;W)D93L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W-C<FEP
M=',O<W%L+W1U<F)A7V]B:F5C=',N<W%L````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$V-3,`,3`T,3<S-C(W-3,`,#(S-#`P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM("1(;W)D93H@='5R8F$O<V-R
M:7!T<R]S<6PO='5R8F%?;V)J96-T<RYS<6PL=B`Q+C,@,C`P-"\Q,2\Q-2`P
M-#HR-SHP-"!C:'5C:R!%>'`@)`H*0U)%051%(%1!0DQ%('1U<F)A7V]B:F5C
M=',@*`H@("`@;V)J96-T7VED(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@
M;W=N97)?:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@;V)J96-T7W1Y
M<&4@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)T]B:F5C="<L"B`@
M("!O8FIE8W1?=6ED(%9!4D-(05(H,C4U*2P*("`@(&]B:F5C=%]M96UB97)S
M($),3T(L"B`@("!O8FIE8W1?;F%M92!605)#2$%2*#(U-2DL"B`@("!O8FIE
M8W1?86QI87,@5D%20TA!4B@S,BDL"B`@("!O8FIE8W1?96UA:6P@5D%20TA!
M4B@R-34I+`H@("`@;V)J96-T7VAO;65A9&1R97-S(%9!4D-(05(H,C4U*2P*
M("`@(&]B:F5C=%]W;W)K861D<F5S<R!605)#2$%2*#(U-2DL"B`@("!O8FIE
M8W1?:&]M97!H;VYE(%9!4D-(05(H,C4I+`H@("`@;V)J96-T7W=O<FMP:&]N
M92!605)#2$%2*#(U*2P*("`@(&]B:F5C=%]C96QL<&AO;F4@5D%20TA!4B@R
M-2DL"B`@("!O8FIE8W1?9F%X(%9!4D-(05(H,C4I+`H@("`@;V)J96-T7W1I
M=&QE(%9!4D-(05(H,C4U*2P*("`@(&]B:F5C=%]C;VUP86YY(%9!4D-(05(H
M,C4U*2P*("`@(&]B:F5C=%]N;W1E<R!415A4+`H@("`@;V)J96-T7W!G<'!U
M8FQI8VME>2!415A4+`H@("`@;V)J96-T7W-M:6UE<'5B;&EC:V5Y(%1%6%0L
M"B`@("!O8FIE8W1?9G)E96)U<WEU<FP@5D%20TA!4B@R-34I+`HM+2`@("`*
M("`@(%!224U!4ED@2T59*&]B:F5C=%]I9"D**3L*"D-214%412!)3D1%6"!T
M=7)B85]O=VYE<E]I9'@@3TX@='5R8F%?;V)J96-T<R`H;W=N97)?:60I.PH*
M1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].('1U<F)A
M7V]B:F5C=',@5$\@:&]R9&4["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A
M+W-C<FEP=',O<W%L+W1U<F)A7V]B:F5C=',N<&=S<6PN<W%L````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-38`,3`T,3<S-C(W-3,`,#(T-3(S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM("1(;W)D93H@='5R
M8F$O<V-R:7!T<R]S<6PO='5R8F%?;V)J96-T<RYP9W-Q;"YS<6PL=B`Q+C(N
M."XS(#(P,#4O,3`O,3@@,3(Z-3`Z,3<@:F%N($5X<"`D"BTM(%EO=2!C86X@
M<VEM<&QY(&5X96-U=&4@=&AI<R!F:6QE(&EN('EO=7(@9&%T86)A<V4N"BTM
M(`HM+2!2=6X@87,Z"BTM"BTM("0@<'-Q;"`M9"!$051!0D%315].04U%(#P@
M='5R8F%?;V)J96-T<RYP9W-Q;"YS<6P*"D-214%412!404),12!T=7)B85]O
M8FIE8W1S("@*("`@(&]B:F5C=%]I9"!605)#2$%2*#,R*2!.3U0@3E5,3"P*
M("`@(&]W;F5R7VED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&]B:F5C
M=%]T>7!E(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("=/8FIE8W0G
M+`H@("`@;V)J96-T7W5I9"!605)#2$%2*#(U-2DL"B`@("!O8FIE8W1?;65M
M8F5R<R!415A4+`H@("`@;V)J96-T7VYA;64@5D%20TA!4B@R-34I+`H@("`@
M;V)J96-T7V%L:6%S(%9!4D-(05(H,S(I+`H@("`@;V)J96-T7V5M86EL(%9!
M4D-(05(H,C4U*2P*("`@(&]B:F5C=%]H;VUE861D<F5S<R!605)#2$%2*#(U
M-2DL"B`@("!O8FIE8W1?=V]R:V%D9')E<W,@5D%20TA!4B@R-34I+`H@("`@
M;V)J96-T7VAO;65P:&]N92!605)#2$%2*#(U*2P*("`@(&]B:F5C=%]W;W)K
M<&AO;F4@5D%20TA!4B@R-2DL"B`@("!O8FIE8W1?8V5L;'!H;VYE(%9!4D-(
M05(H,C4I+`H@("`@;V)J96-T7V9A>"!605)#2$%2*#(U*2P*("`@(&]B:F5C
M=%]T:71L92!605)#2$%2*#(U-2DL"B`@("!O8FIE8W1?8V]M<&%N>2!605)#
M2$%2*#(U-2DL"B`@("!O8FIE8W1?;F]T97,@5$585"P*("`@(&]B:F5C=%]P
M9W!P=6)L:6-K97D@5$585"P*("`@(&]B:F5C=%]S;6EM97!U8FQI8VME>2!4
M15A4+`H@("`@;V)J96-T7V9R965B=7-Y=7)L(%9!4D-(05(H,C4U*2P*("`@
M(`H@("`@4%))34%262!+15DH;V)J96-T7VED*0HI.PH*0U)%051%($E.1$58
M('1U<F)A7V]W;F5R7VED>"!/3B!T=7)B85]O8FIE8W1S("AO=VYE<E]I9"D[
M"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@='5R
M8F%?;V)J96-T<R!43R!H;W)D93L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<V-R:7!T<R]S<6PO='5R8F%?;V)J
M96-T<RYM>7-Q;"YS<6P`````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$U,@`Q,#0Q-S,V
M,C<U,P`P,C0U,S<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2T@)$AO<F1E.B!T=7)B82]S8W)I<'1S+W-Q;"]T=7)B85]O
M8FIE8W1S+FUY<W%L+G-Q;"QV(#$N,BXX+C(@,C`P-2\Q,"\Q."`Q,CHU,#HQ
M-R!J86X@17AP("0*+2T@66]U(&-A;B!S:6UP;'D@97AE8W5T92!T:&ES(&9I
M;&4@:6X@>6]U<B!D871A8F%S92X*+2T*+2T@4G5N(&%S.@HM+0HM+2`D(&UY
M<W%L("TM=7-E<CUR;V]T("TM<&%S<W=O<F0]/$UY4U%,+7)O;W0M<&%S<W=O
M<F0^(#QD8B!N86UE/B`\('1U<F)A7V]B:F5C=',N;7ES<6PN<W%L"@I54T4@
M:&]R9&4["@I#4D5!5$4@5$%"3$4@='5R8F%?;V)J96-T<R`H"B`@("!O8FIE
M8W1?:60@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!O=VYE<E]I9"!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!O8FIE8W1?='EP92!605)#2$%2*#(U
M-2D@3D]4($Y53$P@1$5&055,5"`G3V)J96-T)RP*("`@(&]B:F5C=%]U:60@
M5D%20TA!4B@R-34I+`H@("`@;V)J96-T7VUE;6)E<G,@0DQ/0BP*("`@(&]B
M:F5C=%]N86UE(%9!4D-(05(H,C4U*2P*("`@(&]B:F5C=%]A;&EA<R!605)#
M2$%2*#,R*2P*("`@(&]B:F5C=%]E;6%I;"!605)#2$%2*#(U-2DL"B`@("!O
M8FIE8W1?:&]M96%D9')E<W,@5D%20TA!4B@R-34I+`H@("`@;V)J96-T7W=O
M<FMA9&1R97-S(%9!4D-(05(H,C4U*2P*("`@(&]B:F5C=%]H;VUE<&AO;F4@
M5D%20TA!4B@R-2DL"B`@("!O8FIE8W1?=V]R:W!H;VYE(%9!4D-(05(H,C4I
M+`H@("`@;V)J96-T7V-E;&QP:&]N92!605)#2$%2*#(U*2P*("`@(&]B:F5C
M=%]F87@@5D%20TA!4B@R-2DL"B`@("!O8FIE8W1?=&ET;&4@5D%20TA!4B@R
M-34I+`H@("`@;V)J96-T7V-O;7!A;GD@5D%20TA!4B@R-34I+`H@("`@;V)J
M96-T7VYO=&5S(%1%6%0L"B`@("!O8FIE8W1?<&=P<'5B;&EC:V5Y(%1%6%0L
M"B`@("!O8FIE8W1?<VUI;65P=6)L:6-K97D@5$585"P*("`@(&]B:F5C=%]F
M<F5E8G5S>75R;"!605)#2$%2*#(U-2DL"B`@("`*("`@(%!224U!4ED@2T59
M*&]B:F5C=%]I9"D**3L*"D-214%412!)3D1%6"!T=7)B85]O=VYE<E]I9'@@
M3TX@='5R8F%?;V)J96-T<R`H;W=N97)?:60I.PH*1U)!3E0@4T5,14-4+"!)
M3E-%4E0L(%501$%412P@1$5,151%($].('1U<F)A7V]B:F5C=',@5$\@:&]R
M9&5`;&]C86QH;W-T.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B
M82]S8W)I<'1S+VQD87`O````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`R,#$U,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1U<F)A+W-C<FEP=',O;&1A<"]C;W)E+G-C:&5M82YP
M871C:```````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V,S0`,3`T,3<S-C(W-3,`
M,#(S,S8Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM+2!C;W)E+G-C:&5M82YO<FEG"3(P,#4M,#4M,C8@,3DZ-3(Z,30N
M-C<W,S@T-#8T("LP,C`P"BLK*R!C;W)E+G-C:&5M80DR,#`U+3`U+3(V(#$Y
M.C4T.C(P+C`T-#,R-3<Y,B`K,#(P,`I`0"`M,S@W+#@@*S,X-RPX($!`"B!O
M8FIE8W1C;&%S<R`H(#(N-2XV+C8@3D%-12`G<&5R<V]N)PH@"41%4T,@)U)&
M0S(R-38Z(&$@<&5R<V]N)PH@"5-54"!T;W`@4U1254-455)!3`HM"4U54U0@
M*"!S;B`D(&-N("D*+0E-05D@*"!U<V5R4&%S<W=O<F0@)"!T96QE<&AO;F5.
M=6UB97(@)"!S965!;'-O("0@9&5S8W)I<'1I;VX@*2`I"BL)35535"!C;@HK
M"4U!62`H('-N("0@=7-E<E!A<W-W;W)D("0@=&5L97!H;VYE3G5M8F5R("0@
M<V5E06QS;R`D(&1E<V-R:7!T:6]N("D@*0H@"B!O8FIE8W1C;&%S<R`H(#(N
M-2XV+C<@3D%-12`G;W)G86YI>F%T:6]N86Q097)S;VXG"B`)1$530R`G4D9#
M,C(U-CH@86X@;W)G86YI>F%T:6]N86P@<&5R<V]N)PI`0"`M,SDW+#<@*S,Y
M-RPW($!`"B`)"7!R969E<G)E9$1E;&EV97)Y365T:&]D("0@=&5L97A.=6UB
M97(@)"!T96QE=&5X5&5R;6EN86Q)9&5N=&EF:65R("0*(`D)=&5L97!H;VYE
M3G5M8F5R("0@:6YT97)N871I;VYA;&E31$Y.=6UB97(@)"`*(`D)9F%C<VEM
M:6QE5&5L97!H;VYE3G5M8F5R("0@<W1R965T("0@<&]S=$]F9FEC94)O>"`D
M('!O<W1A;$-O9&4@)`HM"0EP;W-T86Q!9&1R97-S("0@<&AY<VEC86Q$96QI
M=F5R>4]F9FEC94YA;64@)"!O=2`D('-T("0@;"`I("D**PD)<&]S=&%L061D
M<F5S<R`D('!H>7-I8V%L1&5L:79E<GE/9F9I8V5.86UE("0@;W4@)"!S="`D
M(&P@)"!O<F=A;FEZ871I;VY.86UE("D@*0H@"B!O8FIE8W1C;&%S<R`H(#(N
M-2XV+C@@3D%-12`G;W)G86YI>F%T:6]N86Q2;VQE)PH@"41%4T,@)U)&0S(R
M-38Z(&%N(&]R9V%N:7IA=&EO;F%L(')O;&4G"@``````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W-C<FEP=',O;&1A<"]A9&1O=0``
M````````````````````````````````````````````````````````````
M````,#$P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P-C(`,3`T,3<S
M-C(W-3,`,#(Q,38U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",A+V)I;B]S:`H*9F]R('@@:6X@*CL@9&\@+VAO;64O861D
M;W4N<&P@)'@[(&1O;F4*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T=7)B82]S8W)I<'1S+VQD87`O<F9C,C<S.2YS8VAE;6$`````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,3`Q`#$P-#$W,S8R-S4S`#`R,C0R
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M"B,@:'1T<#HO+W=W=RYF87%S+F]R9R]R9F-S+W)F8S(W,SDN:'1M;`HC(`HC
M($9R;VT@=&AE(%)&0SH*(R!4:&4@8V%L0V%L55))(&-O;G1A:6YS('1H92!5
M4DD@=&\@82!S;F%P<VAO="!O9B!T:&4@=7-E<B=S(&5N=&ER90HC(&1E9F%U
M;'0@8V%L96YD87(N(%1H92!C86Q&0E523"!C;VYT86EN<R!T:&4@55))('1O
M('1H92!U<V5R)W,@9&5F875L=`HC(&)U<WD@=&EM92!D871A+B!4:&4@8V%L
M0T%055))(')E<')E<V5N=',@8V]N=&%I;G,@82!54DD@=&AA="!C86X@8F4*
M(R!U<V5D('1O(&-O;6UU;FEC871E('=I=&@@=&AE('5S97(G<R!C86QE;F1A
M<BX@5&AE(&-A;$-A;$%D<E5220HC(&-O;G1A:6YS(&$@55))('1H870@<&]I
M;G1S('1O('1H92!L;V-A=&EO;B!T;R!W:&EC:"!E=F5N="!R97%U97-T<PHC
M('-H;W5L9"!B92!S96YT(&9O<B!T:&%T('5S97(N"B,*(R!4:&4@8V%L3W1H
M97)#86Q54DES(&ES(&$@;75L=&DM=F%L=65D('!R;W!E<G1Y(&-O;G1A:6YI
M;F<@55))<R!T;PHC('-N87!S:&]T<R!O9B!O=&AE<B!C86QE;F1A<G,@=&AA
M="!T:&4@=7-E<B!M87D@:&%V92X@5&AE"B,@8V%L3W1H97)&0E523',@:7,@
M82!M=6QT:2UV86QU960@<')O<&5R='D@8V]N=&%I;FEN9R!54DES('1O(&]T
M:&5R"B,@9G)E92]B=7-Y(&1A=&$@=&AA="!T:&4@=7-E<B!M87D@:&%V92X@
M5&AE(&-A;$]T:&5R0T%055))<R!A='1R:6)U=&4*(R!I<R!A(&UU;'1I+79A
M;'5E9"!P<F]P97)T>2!C;VYT86EN:6YG(%5227,@=&\@;W1H97(@8V%L96YD
M87)S('1H870*(R!T:&4@=7-E<B!M87D@:&%V92X@5&AE(&-A;$]T:&5R0V%L
M061R55))<R!A='1R:6)U=&4@:7,@82!M=6QT:2UV86QU960*(R!P<F]P97)T
M>2!C;VYT86EN:6YG(%5227,@=&\@;W1H97(@;&]C871I;VYS('1H870@82!U
M<V5R(&UA>2!W86YT"B,@979E;G0@<F5Q=65S=',@<V5N="!T;RX*(PHC(%1H
M97)E(&ES(&YO('!R961E=&5R;6EN960@;W)D97(@=&\@=&AE('9A;'5E<R!I
M;B!E:71H97(@;75L=&DM=F%L=65D"B,@<')O<&5R='DN"@HC"45154%,2519
M(&-A<V5)9VYO<F5)035-871C:`H*871T<FEB=71E("@Q+C(N.#0P+C$Q,S4U
M-BXQ+C0N-#<X"B`@3D%-12`G8V%L0V%L55)))PH@($1%4T,@)U-N87!S:&]T
M(&]F('5S97)S(&5N=&ER92!D969A=6QT(&-A;&5N9&%R)PH@($5154%,2519
M(&-A<V5)9VYO<F5)035-871C:`H@(%-50E-44B!C87-E26=N;W)E24$U4W5B
M<W1R:6YG<TUA=&-H"B`@4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R
M,2XQ+C(V"B`I"@IA='1R:6)U=&4@*#$N,BXX-#`N,3$S-34V+C$N-"XT-SD*
M("!.04U%("=C86Q&0E523"<*("!$15-#("=54DD@;V8@=&AE('5S97,@9G)E
M92!A;F0@8G5S>2!I;F9O<FUA=&EO;B<*("!%455!3$E462!C87-E26=N;W)E
M24$U36%T8V@*("!354)35%(@8V%S94EG;F]R94E!-5-U8G-T<FEN9W--871C
M:`H@(%-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-@H@*0H*
M871T<FEB=71E("@Q+C(N.#0P+C$Q,S4U-BXQ+C0N-#@P"B`@3D%-12`G8V%L
M0T%055)))PH@($1%4T,@)U5222!U<V5D('1O(&-O;6UU;FEC871E('=I=&@@
M=&AE('5S97)S(&-A;&5N9&%R)PH@($5154%,2519(&-A<V5)9VYO<F5)035-
M871C:`H@(%-50E-44B!C87-E26=N;W)E24$U4W5B<W1R:6YG<TUA=&-H"B`@
M4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V"B`I"@IA='1R
M:6)U=&4@*#$N,BXX-#`N,3$S-34V+C$N-"XT.#$*("!.04U%("=C86Q#86Q!
M9')54DDG"B`@1$530R`G55))('1O('=H:6-H(&5V96YT(')E<75E<W1S('-H
M;W5L9"!B92!S96YT(&9O<B!T:&4@=7-E<B<*("!%455!3$E462!C87-E26=N
M;W)E24$U36%T8V@*("!354)35%(@8V%S94EG;F]R94E!-5-U8G-T<FEN9W--
M871C:`H@(%-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-@H@
M*0H*871T<FEB=71E("@Q+C(N.#0P+C$Q,S4U-BXQ+C0N-#@R"B`@3D%-12`G
M8V%L3W1H97)#86Q54DES)PH@($1%4T,@)U5227,@=&\@;F]N+61E9F%U;'0@
M8V%L96YD87)S(&)E;&]N9VEN9R!T;R!T:&4@=7-E<B<*("!%455!3$E462!C
M87-E26=N;W)E24$U36%T8V@*("!354)35%(@8V%S94EG;F]R94E!-5-U8G-T
M<FEN9W--871C:`H@(%-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N
M,2XR-@H@*0H*871T<FEB=71E("@Q+C(N.#0P+C$Q,S4U-BXQ+C0N-#@S"B`@
M3D%-12`G8V%L3W1H97)&0E523',G"B`@1$530R`G55))<R!T;R!N;VXM9&5F
M875L="!F<F5E(&%N9"!B=7-Y(&EN9F]R;6%T:6]N(&9I;&5S)PH@($5154%,
M2519(&-A<V5)9VYO<F5)035-871C:`H@(%-50E-44B!C87-E26=N;W)E24$U
M4W5B<W1R:6YG<TUA=&-H"B`@4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U
M+C$R,2XQ+C(V"B`I"@IA='1R:6)U=&4@*#$N,BXX-#`N,3$S-34V+C$N-"XT
M.#0*("!.04U%("=C86Q/=&AE<D-!4%5227,G"B`@1$530R`G55))<R!F;W(@
M8V]M;75N:6-A=&EN9R!W:71H(&YO;BUD969A=6QT(&-A;&5N9&%R<R<*("!%
M455!3$E462!C87-E26=N;W)E24$U36%T8V@*("!354)35%(@8V%S94EG;F]R
M94E!-5-U8G-T<FEN9W--871C:`H@(%-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V
M+C$Q-2XQ,C$N,2XR-@H@*0H*871T<FEB=71E("@Q+C(N.#0P+C$Q,S4U-BXQ
M+C0N-#@U"B`@3D%-12`G8V%L3W1H97)#86Q!9')54DES)PH@($1%4T,@)T1E
M<W1I;F%T:6]N<R!F;W(@979E;G0@<F5Q=65S=',@=&\@;F]N+61E9F%U;'0@
M8V%L96YD87)S)PH@($5154%,2519(&-A<V5)9VYO<F5)035-871C:`H@(%-5
M0E-44B!C87-E26=N;W)E24$U4W5B<W1R:6YG<TUA=&-H"B`@4UE.5$%8(#$N
M,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V"B`I"@IO8FIE8W1C;&%S<R`H
M,2XR+C@T,"XQ,3,U-38N,2XU+C@W"B!.04U%("=C86Q%;G1R>2<@"B!$15-#
M("=#86QE;F1E<FEN9R!A;F0@1G)E92!"=7-Y(&EN9F]R;6%T:6]N)PH@4U50
M('1O<"!!55A)3$E!4ED*($U!62`H8V%L0V%L55))("0@8V%L1D)54DP@)"!C
M86Q#05!54DD@)"!C86Q#86Q!9')54DD@)"`*("`@("`@8V%L3W1H97)#86Q5
M4DES("0@8V%L3W1H97)&0E523',@)"!C86Q/=&AE<D-!4%5227,@)`H@("`@
M("!C86Q/=&AE<D-A;$%D<E5227,*("`@("`I"B`I"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O<V-R:7!T<R]L9&%P+V%D9&]U+G!L````````````
M```````````````````````````````````````````````````P,3`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,R-P`Q,#0Q-S,V,C<U,P`P,C$V
M,#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R$O=7-R+V)I;B]P97)L("UW"B,*(R!,1$%0(&%D9"!P97)S;VYA;"!O=2=S
M(&9R;VT@+VAO;64*(R!4:&ES('-C<FEP="!A9&1S(&%N(&]U(&9O<B!E86-H
M(&1I<F5C=&]R>2!I;B`O:&]M92X*(PHC(%-C<FEP="!B>2!T87)J96E`;G4N
M;F\N"B,@4F5M96UB97(@=&\@<F5M;W9E(&]U)W,@;&EK92!M86EL;6%N+"!M
M>7-Q;"P@<&]S=&=R97,L(&5T8RX*"B,@4V5T=&EN9W,@=&AA="!S:&]U;&0@
M8F4@8VAA;F=E9"!F;W(@>6]U<B!S971U<#H*)&)A<V5D;B`](")O=3UP97)S
M;VYA;%]A9&1R97-S8F]O:RP@9&,]97AA;7!L92P@9&,]8V]M(CL*)&)I;F1D
M;B`](")U:60]<F]O="P@;W4]4&5O<&QE+"!D8SUE>&%M<&QE+"!D8SUC;VTB
M.PHD<&%S<W=D(#T@(B(["B,@16YD(&]F(&-O;F9I9W5R871I;VX@<V5C=&EO
M;B`M(&1O;B=T(&5D:70@8F5L;W<@:&5R92X*"G5S92!'971O<'0Z.E-T9#L*
M;7D@)4]P=&EO;G,["B1U<V5R(#T@)$%21U9;,%T["G!R:6YT(")!9&1I;F<@
M;W4Z(&]U/21U<V5R+"1B87-E9&XB.PH*)$9)3$4@/2`B?"]U<W(O8FEN+VQD
M87!A9&0@+7@@)&]P=&EO;G,@+40@)R1B:6YD9&XG("UW("1P87-S=V0B.PH*
M;W!E;B!&24Q%(&]R(&1I93L*"G!R:6YT($9)3$4@/#Q%3T8["F1N.B!O=3TD
M=7-E<BPD8F%S961N"F]B:F5C=&-L87-S.B!T;W`*;V)J96-T0VQA<W,Z(&]R
M9V%N:7IA=&EO;F%L56YI=`IO=3H@)'5S97(*"D5/1@IC;&]S92!&24Q%.PIE
M>&ET(#`["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O='5R8F$O<V-R:7!T<R]U<&=R861E<R\`````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U
M,P`P,C$P-#(`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]S8W)I<'1S
M+W5P9W)A9&5S+W!U8FQI8U]T;U]H;W)D95]S:&%R92YP:'``````````````
M`````````````````````#`Q,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$S,C0P`#$P-#$W,S8R-S4S`#`R-C`W-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C(2]U<W(O;&]C86PO8FEN+W!H<`H\
M/W!H<`HO*BH*("H@)$AO<F1E.B!T=7)B82]S8W)I<'1S+W5P9W)A9&5S+W!U
M8FQI8U]T;U]H;W)D95]S:&%R92YP:'`L=B`Q+C,N,BXR(#(P,#8O,#$O,#$@
M,C$Z,CDZ,3<@:F%N($5X<"`D"B`J"B`J(%-C<FEP="!T;R!M:6=R871E(&%N
M(&5X:7-T:6YG("=P=6)L:6,G(%1U<F)A(&%D9')E<W,@8F]O:R!T;R!T:&4*
M("H@2&]R9&5?4VAA<F4@8F%S960@<WES=&5M+B`@5&AI<R!S8W)I<'0@:7,@
M9&5S:6=N960@9F]R(&$@4U%,('-O=7)C92!O;FQY+@H@*B!4:&ES('-C<FEP
M="!W:6QL(&UO=F4@*D%,3"H@97AI<W1I;F<@96YT<FEE<R!I;B!T:&4@='5R
M8F%?;V)J96-T<R!T86)L92!I;G1O"B`J(&$@<VEN9VQE+"!G;&]B86QL>2!S
M:&%R960@2&]R9&5?4VAA<F4@;W=N960@8GD@=&AE('5S97(@<W!E8VEF:65D
M(&)E;&]W+@H@*B!$3R!.3U0@4E5.(%1(25,@4T-225!4(%5.3$534R!Y;W4@
M:&%V92!B965N('5S:6YG("=P=6)L:6,G(#T^('1R=64@:6X*("H@82!344P@
M<V]U<F-E("AS=6-H(&%S("=L;V-A;'-Q;"<I("T@;W1H97)W:7-E+"!Y;W4@
M=VEL;"!T=7)N(&5V97)Y('5S97(G<PH@*B!P<FEV871E(&%D9')E<W,@8F]O
M:R!I;G1O(&$@<'5B;&EC('-O=7)C92$*("H*("H@0V]P>7)I9VAT(#(P,#4M
M,C`P-B!-:6-H865L($HN(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E
M;G-E<R]A<VPN<&AP+@H@*B\*"B\O(%-E="!U<"!T:&4@0TQ)(&5N=FER;VUE
M;G0N"G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["FEF("@A2&]R9&5?
M0TQ).CIR=6YN:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U
M;B!F<F]M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]"DAO<F1E7T-,23HZ:6YI
M="@I.PHD0TQ)(#T@)DAO<F1E7T-,23HZ<VEN9VQE=&]N*"D["@HO+R!,;V%D
M($AO<F1E(&%N9"!4=7)B82!E;G9I<F]M96YT<PI`9&5F:6YE*"=!551(7TA!
M3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B\N+B\N+B<I.PI`9&5F:6YE*"=455)"05]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC
M92!455)"05]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*+R\@3&]A9"!(;W)D
M95]3:&%R92!S='5F9BX*<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G
M.PHD<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)')E9VES=')Y
M+3YG971!<'`H*2D["FEF("AI<U]A*"1S:&%R97,L("=014%27T5R<F]R)RDI
M('L*("`@('9A<E]D=6UP*"1S:&%R92D["B`@("!E>&ET.PI]"@HD0TQ)+3YW
M<FET96QN*"=4:&ES('-C<FEP="!W:6QL('1U<FX@86QL(&5N=')I97,@:6X@
M=&AE(%-13"!A9&1R97-S(&)O;VL@:6YT;R!A(&=L;V)A;&QY('-H87)E9"!A
M9&1R97-S(&)O;VLN)RD["B1#3$DM/G=R:71E;&XH)TUA:V4@<W5R92!Y;W4@
M<F5A9"!T:&4@<V-R:7!T(&-O;6UE;G1S(&%N9"!B92!S=7)E('EO=2!K;F]W
M('=H870@>6]U(&%R92!D;VEN9RXG*3L*)'-U<F4@/2`D0TQ)+3YP<F]M<'0H
M)T%R92!Y;W4@)R`N("1#3$DM/F)O;&0H)W-U<F4G*2`N("<@>6]U('=A;G0@
M=&\@9&\@=&AI<S\G+"!A<G)A>2@G;F\G+"`G>65S)RDI.PII9B`H(21S=7)E
M*2!["B`@("!E>&ET.PI]"@HO+R!&:6YD(&]U="!W:&%T(&]U<B!!=71H(&1R
M:79E<B!W:6QL(&QE="!U<R!D;R!A;F0*+R\@9V5T('1H92!L:7-T(&]F(&%L
M;"!U<V5R<R!I9B!W92!C86XN"B1A=71H1')I=F5R(#T@)&-O;F9;)V%U=&@G
M75LG9')I=F5R)UT["B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D875T:$1R
M:79E<BD["FEF("@D875T:"T^:&%S0V%P86)I;&ET>2@G;&ES="<I*2!["B`@
M("`D=7-E<G,@/2`D875T:"T^;&ES=%5S97)S*"D["GT*"B\O($=E="!A;&P@
M=&AE(&1E=&%I;',N"F1O('L*("`@("1O=VYE<B`]("1#3$DM/G!R;VUP="@G
M57-E<FYA;64@;V8@=&AE('5S97(@>6]U('=O=6QD(&QI:V4@=&\@;W=N('1H
M92!N97<@<'5B;&EC('-O=7)C92XG*3L*("`@("\O($UI9VAT(&%S('=E;&P@
M8VAE8VL@=&AI<R!I9B!W92!H879E('1H92!L:7-T+@H@("`@:68@*"%E;7!T
M>2@D=7-E<G,I("8F("%I;E]A<G)A>2@D;W=N97(L("1U<V5R<RDI('L*("`@
M("`@("`D0TQ)+3YM97-S86=E*"1O=VYE<B`N("<@:7,@;F]T(&$@=F%L:60@
M=7-E<B$G+"`G8VQI+F5R<F]R)RD["B`@("`@("`@)&]W;F5R(#T@)R<["B`@
M("!]"GT@=VAI;&4H(21O=VYE<BD["@ID;R!["B`@("`D=&ET;&4@/2`D0TQ)
M+3YP<F]M<'0H)T5N=&5R('1H92!T:71L92!Y;W4@=V]U;&0@;&EK92!T;R!G
M:79E('1O('1H92!N97<@<'5B;&EC('-O=7)C92XG*3L*?2!W:&EL92`H(21T
M:71L92D["@HD<V]U<F-E2V5Y(#T@)$-,22T^<')O;7!T*"=7:&%T(&ES('1H
M92!I;G1E<FYA;"!N86UE(&]F('1H92!S:&%R92!W92!A<F4@8V]N=F5R=&EN
M9S\@6VQO8V%L<W%L72<I.PII9B`H(21S;W5R8V5+97DI('L*("`@("1S;W5R
M8V5+97D@/2`G;&]C86QS<6PG.PI]"@HO+R!#<F5A=&4@=&AE(&YE=R!S:&%R
M92X*)&]W;F5R7W5I9"`](&UD-2AM:6-R;W1I;64H*2D["B1S:&%R92`]("8D
M<VAA<F5S+3YN97=3:&%R92@D<V]U<F-E2V5Y("X@)SHG("X@)&]W;F5R7W5I
M9"D["FEF("AI<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@=F%R
M7V1U;7`H)'-H87)E*3L*("`@(&5X:70["GT*)'-H87)E+3YS970H)V]W;F5R
M)RP@)&]W;F5R*3L*)'-H87)E+3YS970H)W5I9"<L("1O=VYE<E]U:60I.PHD
M<VAA<F4M/G-E="@G;F%M92<L("1T:71L92D["B1S:&%R92T^<V5T*"=P97)M
M7V1E9F%U;'0G+"!015)-4U]32$]7('P@4$5235-?4D5!1"D["B1R97-U;'0@
M/2`D<VAA<F5S+3YA9&13:&%R92@D<VAA<F4I.PII9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("!V87)?9'5M<"@D<F5S=6QT*3L*("`@
M(&5X:70["GT*)'-H87)E+3YS879E*"D["B1#3$DM/FUE<W-A9V4H)T-R96%T
M960@;F5W($AO<F1E7U-H87)E(&]B:F5C="!F;W(@=&AE('-H87)E9"!A9&1R
M97-S(&)O;VLN)RP@)V-L:2YS=6-C97-S)RD["@HO+R!3:&%R92!C<F5A=&5D
M+"!N;W<@9V5T(&$@5'5R8F%?1')I=F5R(&%N9"!M86ME('1H92!C:&%N9V5S
M+@HD9')I=F5R(#T@)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1S;W5R8V5+
M97DI.PII9B`H:7-?82@D9')I=F5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("!V
M87)?9'5M<"@D9')I=F5R*3L*("`@(&5X:70["GT*)&1B(#T@)B`D9')I=F5R
M+3Y?9&(["FEF("AI<U]A*"1D8BP@)U!%05)?17)R;W(G*2D@>PH@("`@=F%R
M7V1U;7`H)&1B*3L*?0H*+R\@1V5T('1H92!T86)L96YA;64@:6X@8V%S92!W
M92!A<F5N)W0@=7-I;F<@:&]R9&4@9&5F875L=',N"B1T86)L94YA;64@/2`D
M9&(M/F1S;ELG=&%B;&4G73L*)%-13"`]("=314Q%0U0@0T]53E0H*BD@1E)/
M32`G("X@)'1A8FQE3F%M92`N("<[)SL*)&-O=6YT(#T@)&1B+3YG971/;F4H
M)%-13"D["B1#3$DM/FUE<W-A9V4H(DUO=FEN9R`D8V]U;G0@8V]N=&%C=',@
M=&\@)'1I=&QE+B(L("=C;&DN;65S<V%G92<I.PHD4U%,(#T@)U501$%412`G
M("X@)'1A8FQE3F%M92`N("<@4T54(&]W;F5R7VED/5PG)R`N("1O=VYE<E]U
M:60@+B`G7"<[)SL*)')E<W5L="`]("1D8BT^<75E<GDH)%-13"D["FEF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@('9A<E]D=6UP*"1R
M97-U;'0I.PH@("`@97AI=#L*?0HD<')E9D1R:79E<B`]("1C;VYF6R=P<F5F
M<R==6R=D<FEV97(G73L*:68@*"1P<F5F1')I=F5R("$]("=S<6PG*2!["B`@
M("`O+R!!=71O;6%T:6-A;&QY(&%P<&5N9"!T:&ES('-O=7)C92!T;R!T:&4@
M861D<F5S<V)O;VMS('!R968@:68@9&5S:7)E9"X*("`@("1A=71O07!P96YD
M(#T@)$-,22T^<')O;7!T*"=7;W5L9"!Y;W4@;&EK92!T;R!A9&0@=&AE(&YE
M=R!P=6)L:6,@<V]U<F-E('1O(&5V97)Y('5S97)<)W,@861D<F5S<R!B;V]K
M('!R969E<F5N8V4_)RP@87)R87DH)VYO)RP@)WEE<R<I*3L*("`@(&EF("@D
M875T;T%P<&5N9"D@>PH@("`@("`@("1344P@/2`G4T5,14-4('!R969?=6ED
M+"!P<F5F7W9A;'5E($923TT@:&]R9&5?<')E9G,@5TA%4D4@<')E9E]S8V]P
M93U<)W1U<F)A7"<@04Y$('!R969?;F%M93U<)V%D9')E<W-B;V]K<UPG.R<[
M"B`@("`@("`@)')E<W5L=',@/2`D9&(M/F=E=$%L;"@D4U%,*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("1#3$DM/FUE<W-A9V4H)U1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@=7-E<B!P<F5F97)E;F-E<SH@)R`N("1R97-U;'1S+3YG971-97-S
M86=E*"DL("=C;&DN97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!F;W)E86-H("@D<F5S=6QT<R!A<R`D<F]W*2!["B`@("`@("`@("`@
M("`@("`D;F5W5F%L=64@/2`D<F]W6S%=("X@(EQN)'-O=7)C94ME>3HD;W=N
M97)?=6ED(CL*("`@("`@("`@("`@("`@("1344P@/2`G55!$051%(&AO<F1E
M7W!R969S(%-%5"!P<F5F7W9A;'5E/5PG)R`N("1N97=686QU92`N("=<)R!7
M2$5212!P<F5F7W5I9#U<)R<@+B`D<F]W6S!=("X@)UPG($%.1"!P<F5F7W-C
M;W!E/5PG='5R8F%<)R!!3D0@<')E9E]N86UE/5PG861D<F5S<V)O;VMS7"<[
M)SL*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D9&(M/G%U97)Y*"1344PI
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("1#3$DM/FUE<W-A9V4H)T-O
M=6QD(&YO="!U<&1A=&4@<')E9F5R96YC97,@9F]R("<@+B`D<F]W6S!=("X@
M)SH@)R`N("1R97-U;'0M/F=E=$UE<W-A9V4H*2P@)V-L:2YE<G)O<B<I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-?82@D<F5S=6QT<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`D0TQ)+3YM97-S86=E*"=3=6-C97-S9G5L;'D@861D960@;F5W
M('-H87)E9"!A9&1R97-S(&)O;VL@=&\@=&AE('5S97(@<')E9F5R96YC97,N
M)RP@)V-L:2YS=6-C97-S)RD["B`@("`@("`@?0H@("`@?0I](&5L<V4@>PH@
M("`@)$-,22T^;65S<V%G92@G66]U<B!P<F5F97)E;F-E(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!U<&1A=&EN9R!A;&P@=7-E<B!P<F5F97)E;F-E<RXG
M+"`G8VQI+G=A<FYI;F<G*3L*("`@("1#3$DM/FUE<W-A9V4H)UEO=7(@=7-E
M<G,@;6%Y(&AA=F4@=&\@;6%N=6%L;'D@861D('1H92!N97<@<VAA<F5D(&%D
M9')E<W,@8F]O:R!T;R!T:&5I<B`B861D<F5S<V)O;VLB('!R969E<F5N8V4N
M)RP@)V-L:2YW87)N:6YG)RD["GT*+R\@4VAA<F4@;W5R('-U8V-E<W,N"B1#
M3$DM/G=R:71E;&XH)$-,22T^8F]L9"@B*BHJ("1T:71L92!S=6-C97-S9G5L
M;'D@8W)E871E9"`J*BHB*2D["B1#3$DM/G=R:71E;&XH)U-H87)E($EN9F\Z
M)RD["B1#3$DM/G=R:71E;&XH)$-,22T^:6YD96YT*"=4:71L93H@)R`N("1S
M:&%R92T^9V5T*"=N86UE)RDI*3L*)$-,22T^=W)I=&5L;B@D0TQ)+3YI;F1E
M;G0H)T]W;F5R.B`G("X@)'-H87)E+3YG970H)V]W;F5R)RDI*3L*)$-,22T^
M=W)I=&5L;B@D0TQ)+3YI;F1E;G0H)W5I9#H@("`G("X@)'-H87)E+3YG970H
M)W5I9"<I*2D["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W-C<FEP=',O=7!G
M<F%D97,O,2XR7W1O7S(N,"YS<6P`````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W
M-3(`,3`T,3<S-C(W-3,`,#(S,30U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"TM(%EO=2!C86X@<VEM<&QY(&5X96-U=&4@
M=&AI<R!F:6QE(&EN('EO=7(@9&%T86)A<V4N"BTM"BTM($9O<B!->5-13"!R
M=6XZ"BTM"BTM("0@;7ES<6P@+2UU<V5R/7)O;W0@+2UP87-S=V]R9#T\37E3
M44PM<F]O="UP87-S=V]R9#X@/&1B(&YA;64^(#P@,2XR7W1O7S(N,"YS<6P*
M+2T*+2T@3W(L(&9O<B!0;W-T9W)E4U%,.@HM+0HM+2`D('!S<6P@/&1B(&YA
M;64^("UF(#$N,E]T;U\R+C`N<W%L"@H*04Q415(@5$%"3$4@='5R8F%?;V)J
M96-T<R!!1$0@0T],54U.(&]B:F5C=%]U:60@5D%20TA!4B@R-34I.PI!3%1%
M4B!404),12!T=7)B85]O8FIE8W1S($%$1"!#3TQ534X@;V)J96-T7V9R965B
M=7-Y=7)L(%9!4D-(05(H,C4U*3L*04Q415(@5$%"3$4@='5R8F%?;V)J96-T
M<R!!1$0@0T],54U.(&]B:F5C=%]S;6EM97!U8FQI8VME>2!415A4.PI!3%1%
M4B!404),12!T=7)B85]O8FIE8W1S($%$1"!#3TQ534X@;V)J96-T7W!G<'!U
M8FQI8VME>2!415A4.PH`````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T=7)B82]S8W)I<'1S+W5P9W)A9&5S+S(P,#0M
M,3`M,C9?8W)E871E7V1E9F%U;'1?:&ES=&]R:65S+G!H<```````````````
M`#`Q,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,38R`#$P-#$W,S8R
M-S4S`#`R-S<R-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````C(2]U<W(O;&]C86PO8FEN+W!H<`H\/W!H<`HO*BH*("H@)$AO
M<F1E.B!T=7)B82]S8W)I<'1S+W5P9W)A9&5S+S(P,#0M,3`M,C9?8W)E871E
M7V1E9F%U;'1?:&ES=&]R:65S+G!H<"QV(#$N-2XT+C8@,C`P-B\P,R\P,2`Q
M.3HS,3HT-B!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A
M<VPN<&AP+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`
M9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M+RXN+RXN)RD["@HO+R!$;R!#3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S
M971U<"!F:7)S="X*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C
M;W)E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO+R!-
M86ME('-U<F4@;F\@;VYE(')U;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A
M2&]R9&5?0TQ).CIR=6YN:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T
M(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D
M('1H92!#3$D@96YV:7)O;FUE;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T
M:6UE(&QI;6ET+"!I;FET"B\O('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E
M7T-,23HZ:6YI="@I.PH*0&1E9FEN92@G5%520D%?0D%312<L(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@5%520D%?0D%3
M12`N("<O;&EB+V)A<V4N<&AP)SL*"B1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O
M<GDZ.G-I;F=L971O;B@I.PH*+R\@4G5N('1H<F]U9V@@979E<GD@8V]N=&%C
M="!S;W5R8V4N"F9O<F5A8V@@*"1C9F=3;W5R8V5S(&%S("1K97D@/3X@)&-U
M<E-O=7)C92D@>PH@("`@:68@*&5M<'1Y*"1C=7)3;W5R8V5;)V)R;W=S92==
M*2!\?"`A96UP='DH)&-U<E-O=7)C95LG<F5A9&]N;'DG72DI('L*("`@("`@
M("!C;VYT:6YU93L*("`@('T*"B`@("`D9')I=F5R(#T@)E1U<F)A7T1R:79E
M<CHZ<VEN9VQE=&]N*"1K97DI.PH@("`@:68@*&ES7V$H)&1R:79E<BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@('9A<E]D=6UP*"1D<FEV97(I.PH@("`@
M("`@(&5X:70["B`@("!]"@H@("`@96-H;R`B0W)E871I;F<@9&5F875L="!H
M:7-T;W)I97,@9F]R("1K97D@+BXN7&XB.PH*("`@("\O($QI<W0@86QL(&-O
M;G1A8W1S+@H@("`@)')E<W5L=',@/2`D9')I=F5R+3YS96%R8V@H87)R87DH
M*2P@)VYA;64G+"`G04Y$)RP@,"D["B`@("!W:&EL92`H)&]B:F5C="`]("1R
M97-U;'1S+3YN97AT*"DI('L*("`@("`@("`O*B!'970@=&AE(&-O;G1A8W0G
M<R!H:7-T;W)Y+B`J+PH@("`@("`@("1L;V<@/2`D:&ES=&]R>2T^9V5T2&ES
M=&]R>2@G='5R8F$Z)R`N("1O8FIE8W0M/F=E=%9A;'5E*"=?7W5I9"<I*3L*
M("`@("`@("`D8W)E871E9"`](&9A;'-E.PH@("`@("`@(&9O<F5A8V@@*"1L
M;V<M/F=E=$1A=&$H*2!A<R`D96YT<GDI('L*("`@("`@("`@("`@:68@*"1E
M;G1R>5LG86-T:6]N)UT@/3T@)V%D9"<I('L*("`@("`@("`@("`@("`@("1C
M<F5A=&5D(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!)9B!T:&5R92!I<VXG="!A
M;B!A9&0@96YT<GDL(&%D9"!O;F4@870@=&AE(&-U<G)E;G0@=&EM92X*("`@
M("`@("!I9B`H(21C<F5A=&5D*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D
M:&ES=&]R>2T^;&]G*"=T=7)B83HG("X@)&]B:F5C="T^9V5T5F%L=64H)U]?
M=6ED)RDL(&%R<F%Y*"=A8W1I;VXG(#T^("=A9&0G*2P@=')U92D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@('9A<E]D=6UP*"1R97-U;'0I.PH@("`@("`@("`@("`@
M("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*?0H*96-H
M;R`B7&XJ*B!$969A=6QT(&AI<W1O<FEE<R!S=6-C97-S9G5L;'D@8W)E871E
M9"`J*BI<;B(["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]S8W)I<'1S+RYH
M=&%C8V5S<P``````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#$V`#$P-#$W,S8R-S4S`#`R,3`R,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!$96YY(&9R;VT@86QL"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<V-R:7!T<R]I;7!O<G1?=F-A<F1S
M+G!H<```````````````````````````````````````````````````````
M```P,3`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0T-``Q,#0Q-S,V
M,C<U,P`P,C(V,C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R$O=7-R+V)I;B]P:'`*/#]P:'`*+RHJ"B`J(%1H:7,@<V-R
M:7!T(&EM<&]R=',@5D-!4D0@9&%T82!I;G1O('1U<F)A(&%D9')E<W,@8F]O
M:W,N"B`J(%1H92!60T%21"!D871A(&ES(')E860@9G)O;2!S=&%N9&%R9"!I
M;G!U="P@=&AE(&%D9')E<W,@8F]O:R!A;F0@=7-E<B!N86UE"B`J('!A<W-E
M9"!A<R!P87)A;65T97)S+@H@*@H@*B`D2&]R9&4Z('1U<F)A+W-C<FEP=',O
M:6UP;W)T7W9C87)D<RYP:'`L=B`Q+C0N,BXR(#(P,#8O,#$O,#$@,C$Z,CDZ
M,3<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN
M("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J+PH*0&1E
M9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%7T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*"B\O($1O($-,
M22!C:&5C:W,@86YD(&5N=FER;VYM96YT('-E='5P(&9I<G-T+@IR97%U:7)E
M7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]#3$DN<&AP)SL*"B\O($UA:V4@<W5R92!N;R!O;F4@<G5N
M<R!T:&ES(&9R;VT@=&AE('=E8BX*:68@*"%(;W)D95]#3$DZ.G)U;FYI;F=&
M<F]M0TQ)*"DI('L*("`@(&5X:70H(DUU<W0@8F4@<G5N(&9R;VT@=&AE(&-O
M;6UA;F0@;&EN95QN(BD["GT*"B\O($QO860@=&AE($-,22!E;G9I<F]N;65N
M="`M(&UA:V4@<W5R92!T:&5R92=S(&YO('1I;64@;&EM:70L(&EN:70@<V]M
M90HO+R!V87)I86)L97,L(&5T8RX*)&-L:2`]("9(;W)D95]#3$DZ.G-I;F=L
M971O;B@I.PHD8VQI+3YI;FET*"D["@HO+R!296%D(&-O;6UA;F0@;&EN92!P
M87)A;65T97)S+@II9B`H8V]U;G0H)&%R9W8I("$](#,I('L*("`@("1C;&DM
M/FUE<W-A9V4H)U1O;R!M86YY(&]R('1O;R!F97<@<&%R86UE=&5R<RXG+"`G
M8VQI+F5R<F]R)RD["B`@("!U<V%G92@I.PI]"B1S;W5R8V4@/2`D87)G=ELQ
M73L*)'5S97(@/2`D87)G=ELR73L*"B\O(%)E860@<W1A;F1A<F0@:6YP=70N
M"B1V8V%R9"`]("1C;&DM/G)E8613=&1I;B@I.PII9B`H96UP='DH)'9C87)D
M*2D@>PH@("`@)&-L:2T^;65S<V%G92@G3F\@:6UP;W)T(&1A=&$@<')O=FED
M960N)RP@)V-L:2YE<G)O<B<I.PH@("`@=7-A9V4H*3L*?0H*+R\@4F5G:7-T
M<GDN"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*"D["@HO+R!3
M970@=7-E<BX*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H
M)UU;)V1R:79E<B==*3L*)&%U=&@M/G-E=$%U=&@H)'5S97(L(&%R<F%Y*"DI
M.PH*+R\@26UP;W)T(&1A=&$N"B1R97-U;'0@/2`D<F5G:7-T<GDM/F-A;&PH
M)V-O;G1A8W1S+VEM<&]R="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)'9C87)D+"`G=&5X="]X+79C87)D)RP@)'-O=7)C92DI.PII9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D8VQI+3YF871A
M;"@D<F5S=6QT+3YT;U-T<FEN9R@I*3L*?0H*)&-L:2T^;65S<V%G92@G26UP
M;W)T960@<W5C8V5S<V9U;&QY("<@+B!C;W5N="@D<F5S=6QT*2`N("<@8V]N
M=&%C=',G+"`G8VQI+G-U8V-E<W,G*3L*"F9U;F-T:6]N('5S86=E*"D*>PH@
M("`@)$=,3T)!3%-;)V-L:2==+3YW<FET96QN*"=5<V%G93H@:6UP;W)T7W9C
M87)D<RYP:'`@<V]U<F-E('5S97(G*3L*("`@(&5X:70["GT*"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1U<F)A+W-C<FEP=',O5'5R8F$N<F5G````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$U-C8`,3`T,3<S-C(W-3,`
M,#(Q,#$Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/_^5P!I`&X`9`!O`'<`<P`@`%(`90!G`&D`<P!T`'(`>0`@`$4`9`!I
M`'0`;P!R`"``5@!E`'(`<P!I`&\`;@`@`#4`+@`P`#``#0`*``T`"@!;`$@`
M2P!%`%D`7P!,`$\`0P!!`$P`7P!-`$$`0P!(`$D`3@!%`%P`4P!/`$8`5`!7
M`$$`4@!%`%P`0P!L`&D`90!N`'0`<P!<`$,`;P!N`'0`80!C`'0`<P!=``T`
M"@!``#T`(@!4`'4`<@!B`&$`(@`-``H`#0`*`%L`2`!+`$4`60!?`$P`3P!#
M`$$`3`!?`$T`00!#`$@`20!.`$4`7`!3`$\`1@!4`%<`00!2`$4`7`!#`&P`
M:0!E`&X`=`!S`%P`0P!O`&X`=`!A`&,`=`!S`%P`5`!U`'(`8@!A`%T`#0`*
M`$``/0`B`%0`=0!R`&(`80`B``T`"@`-``H`6P!(`$L`10!9`%\`3`!/`$,`
M00!,`%\`30!!`$,`2`!)`$X`10!<`%,`3P!&`%0`5P!!`%(`10!<`$,`;`!I
M`&4`;@!T`',`7`!#`&\`;@!T`&$`8P!T`',`7`!4`'4`<@!B`&$`7`!S`&@`
M90!L`&P`70`-``H`#0`*`%L`2`!+`$4`60!?`$P`3P!#`$$`3`!?`$T`00!#
M`$@`20!.`$4`7`!3`$\`1@!4`%<`00!2`$4`7`!#`&P`:0!E`&X`=`!S`%P`
M0P!O`&X`=`!A`&,`=`!S`%P`5`!U`'(`8@!A`%P`<P!H`&4`;`!L`%P`;P!P
M`&4`;@!=``T`"@`-``H`6P!(`$L`10!9`%\`3`!/`$,`00!,`%\`30!!`$,`
M2`!)`$X`10!<`%,`3P!&`%0`5P!!`%(`10!<`$,`;`!I`&4`;@!T`',`7`!#
M`&\`;@!T`&$`8P!T`',`7`!4`'4`<@!B`&$`7`!S`&@`90!L`&P`7`!O`'``
M90!N`%P`8P!O`&T`;0!A`&X`9`!=``T`"@!``#T`(@!I`&4`>`!P`&P`;P!R
M`&4`+@!E`'@`90`@`"T`;@!O`&@`;P!M`&4`(`!W`&4`8@!M`&$`:0!L`"X`
M90!X`&$`;0!P`&P`90`N`&,`;P!M`"\`:`!O`'(`9`!E`"\`=`!U`'(`8@!A
M`"\`80!D`&0`;P!B`&H`90!C`'0`+@!P`&@`<``B``T`"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92\`````````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-38`,#$W,#`S`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C
M86QE+V)G7T)'+P``````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,P`P,3<W-#``(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T=7)B82]L;V-A;&4O8F=?0D<O3$-?34534T%'15,O````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`R,34R
M-0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]B9U]"1R],
M0U]-15-304=%4R]T=7)B82YM;P``````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#<W-C,`
M,3`T,3<S-C(W-3,`,#(S,C$U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````(P$``!P````T"0``A0$``$P2````
M````8!@```X```!A&```"````'`8```,````>1@```L```"&&```*````)(8
M```5````NQ@``!T```#1&```#@```.\8```(````_A@``#(````'&0``.```
M`#H9``!4````<QD``%$```#(&0``-````!H:```%````3QH```,```!5&@``
M#0```%D:```2````9QH```\```!Z&@``&0```(H:```'````I!H``!0```"L
M&@``#@```,$:```#````T!H```\```#4&@``!0```.0:```#````ZAH```H`
M``#N&@``#P```/D:```?````"1L``!$````I&P``#````#L;```)````2!L`
M`#D```!2&P``)P```(P;```L````M!L``"H```#A&P``"@````P<```5````
M%QP``"D````M'```$0```%<<```6````:1P``!8```"`'```!````)<<```)
M````G!P```8```"F'````P```*T<```#````L1P```@```"U'```(````+X<
M```&````WQP```H```#F'```#````/$<```.````_AP```8````-'0``%@``
M`!0=```'````*QT``!`````S'0``*P```$0=```:````<!T``!X```"+'0``
M&P```*H=```;````QAT``#,```#B'0``+P```!8>```I````1AX```,```!P
M'@```@```'0>```%````=QX``!````!]'@``&@```(X>```&````J1X```\`
M``"P'@``"@```,`>```O````RQX```D```#['@``#P````4?```$````%1\`
M``4````:'P``#0```"`?```;````+A\```T```!*'P``!0```%@?```0````
M7A\``!````!O'P``#P```(`?```+````D!\```\```"<'P``#````*P?```/
M````N1\``!,```#)'P``'@```-T?```5````_!\``!X````2(```(0```#$@
M```@````4R```"(```!T(````P```)<@```3````FR```!0```"O(```#```
M`,0@```)````T2```!L```#;(```!P```/<@```$````_R````8````$(0``
M!`````LA```)````$"$```4````:(0``%````"`A```&````-2$``!$````\
M(0``'@```$XA```$````;2$```0```!R(0``#````'<A```*````A"$```4`
M``"/(0``(````)4A```@````MB$``"8```#7(0``*0```/XA```*````*"(`
M``\````S(@``$@```$,B```0````5B(``!<```!G(@``!@```'\B```,````
MAB(```P```"3(@``#0```*`B```H````KB(``"L```#7(@``"`````,C```0
M````#",``!H````=(P``!@```#@C```'````/R,```(```!'(P``)0```$HC
M```$````<",```@```!U(P``#P```'XC```'````CB,```H```"6(P``!P``
M`*$C```&````J2,```D```"P(P``#````+HC```-````QR,```<```#5(P``
M%0```-TC```*````\R,```0```#^(P``&@````,D```'````'B0```4````F
M)```%P```"PD```"````1"0``#,```!')```,P```'LD```X````KR0``"T`
M``#H)```,0```!8E```L````2"4``!H```!U)0``"0```)`E```$````FB4`
M``4```"?)0```@```*4E```'````J"4```P```"P)0``$0```+TE```1````
MSR4```X```#A)0``"0```/`E```(````^B4```D````#)@``"@````TF```5
M````&"8```4````N)@``*````#0F```:````728```4```!X)@``$0```'XF
M```@````D"8``!0```"Q)@``,@```,8F```%````^28```0```#_)@``,@``
M``0G```J````-R<```8```!B)P``%0```&DG```/````?R<```0```"/)P``
M"0```)0G```#````GB<```8```"B)P``%0```*DG```2````OR<```\```#2
M)P``%````.(G```:````]R<``!<````2*```&@```"HH```7````12@``!L`
M``!=*```-````'DH```9````KB@``!\```#(*```5P```.@H```0````0"D`
M``0```!1*0``"````%8I```-````7RD```H```!M*0``!````'@I```.````
M?2D``!<```",*0``!@```*0I```'````JRD``!0```"S*0``!0```,@I```)
M````SBD``$H```#8*0``.````",J``!(````7"H``$D```"E*@``)@```.\J
M```P````%BL``&D```!'*P``/0```+$K``!E````[RL``$T```!5+```)P``
M`*,L```H````RRP``"X```#T+```+P```",M```L````4RT``!<```"`+0``
M)0```)@M```R````OBT``#X```#Q+0``)0```#`N```A````5BX``#````!X
M+@``'````*DN```-````QBX```4```#4+@```P```-HN```@````WBX``"0`
M``#_+@``(@```"0O```E````1R\``"8```!M+P``"0```)0O```&````GB\`
M``D```"E+P``$P```*\O```(````PR\```D```#,+P``"@```-8O```4````
MX2\```@```#V+P``/P```/\O```2````/S```!L```!2,```!P```&XP```&
M````=C````T```!],```"P```(LP```O````ES````P```#',```"@```-0P
M```"````WS````8```#B,````P```.DP```H````[3```"8````6,0``)0``
M`#TQ```H````8S$``!````",,0``<P```)TQ```?````$3(``!0````Q,@``
M#P```$8R```$````5C(```<```!;,@``!0```&,R``!5`0``:3(```\```"_
M,P``!P```,\S```(````US,```X```#@,P``)0```.\S```<````%30``!\`
M```R-```#````%(T```'````7S0``#4```!G-```-0```)TT``!2````TS0`
M`$\````F-0``-P```'8U```%````KC4```8```"T-0``%@```+LU```6````
MTC4``!8```#I-0``)@`````V```%````)S8```X````M-@``#@```#PV```'
M````2S8``!$```!3-@``"0```&4V```&````;S8```P```!V-@``#````(,V
M```C````D#8``!<```"T-@``#0```,PV```*````VC8``#<```#E-@``+0``
M`!TW```M````2S<``"\```!Y-P``"````*DW```8````LC<``#(```#+-P``
M#P```/XW```;````#C@``"4````J.```"0```%`X```'````6C@```D```!B
M.````P```&PX```#````<#@```@```!T.```)@```'TX```&````I#@```\`
M``"K.```$````+LX```1````S#@```<```#>.```)0```.8X```(````##D`
M`!,````5.0``*0```"DY```D````4SD``"4```!X.0``)0```)XY```G````
MQ#D``"4```#L.0``.@```!(Z```U````33H```8```"#.@```@```(HZ```)
M````C3H``!L```"7.@``)````+,Z```&````V#H``!$```#?.@``"@```/$Z
M```N````_#H```H````K.P``#0```#8[```(````1#L```4```!-.P``"P``
M`%,[```B````7SL``!````"".P``!@```),[```/````FCL``!````"J.P``
M#@```+L[```-````RCL``!0```#8.P``#````.T[```3````^CL``!@````.
M/```*0```"<\```A````43P``"$```!S/```,@```)4\```D````R#P``"@`
M``#M/```!````!8]```5````&ST``!8````Q/0``#````$@]```+````53T`
M`"8```!A/0``!@```(@]```%````CST```8```"5/0```@```)P]```+````
MGST```4```"K/0``%P```+$]```%````R3T```X```#//0``(0```-X]```%
M`````#X```8````&/@``#0````T^```/````&SX```4````K/@``+P```#$^
M```O````83X``#P```"1/@``)@```,X^```*````]3X```T`````/P``%```
M``X_```3````(S\``!\````W/P``"0```%<_```2````83\``!$```!T/P``
M$@```(8_```J````F3\``"T```#$/P``!````/(_```*````]S\``"$````"
M0```!````"1````%````*4````(````O0```+0```#)````$````8$````D`
M``!E0```$````&]````'````@$````X```"(0```!0```)=````%````G4``
M``@```"C0```#P```*Q````1````O$````<```#.0```%@```-9````*````
M[4````,```#X0```&@```/Q````%````%T$```8````=00``(P```"1!```"
M````2$$``"8```!+00``)@```')!```K````F4$``"L```#%00``+P```/%!
M```U````(4(``!D```!70@``#@```'%"```$````@$(```<```"%0@```@``
M`(U"```%````D$(```\```"60@``$````*9"```4````MT(``!$```#,0@``
M"0```-Y"```&````Z$(```<```#O0@``"````/="```2`````$,```8````3
M0P``,@```!I#```9````34,```<```!G0P``$@```&]#```>````@D,``!0`
M``"A0P``-P```+9#```*````[D,```8```#Y0P``0@````!$```I````0T0`
M``@```!M1```&@```'9$```7````D40```0```"I1```"0```*Y$```#````
MN$0```4```"\1```&@```,)$```@````W40```\```#^1```'0````Y%```9
M````+$4``!H```!&10``&````&%%```8````>D4``!X```"310``-@```+)%
M```C````Z44``"0````-1@``:````#)&```4````FT8```D```"P1@``#0``
M`+I&```1````R$8``!````#:1@``!@```.M&```)````\D8``!X```#\1@``
M!P```!M'```%````(T<``",````I1P``!@```$U'```*````5$<``$<```!?
M1P``*P```*='``!)````TT<``%<````=2```(@```'5(```O````F$@``%\`
M``#(2```-0```"A)``!A````7DD``#\```#`20``(P````!*```E````)$H`
M`"<```!*2@``'````')*```;````CTH``!<```"K2@``*@```,-*```Q````
M[DH``$4````@2P``(````&9+```D````ATL``#<```"L2P``(````.1+```5
M````!4P```@````;3````P```"1,```D````*$P``"H```!-3```*P```'A,
M```E````I$P``"@```#*3```"@```/-,```'````_DP```H````&30``'P``
M`!%-```#````,4T```0````U30``!0```#I-```8````0$T```@```!930``
M/0```&)-```2````H$T``"X```"S30``"````.)-```(````ZTT``!````#T
M30``#P````5.```T````%4X```P```!*3@``#@```%=.```"````9DX```<`
M``!I3@```@```'%.```A````=$X``"L```"63@``*@```,).```M````[4X`
M`!$````;3P``90```"U/```K````DT\```\```"_3P``$````,]/```$````
MX$\```<```#E3P``!0```.U/```!````E@```(8`````````HP```*(```#E
M````G````!<!``!A````S@````<`````````B0```-T`````````!P$`````
M``#T````&0$````````H`````````!0!`````````````+\```"%````````
M`/<```#8`````````,H````*`0``\````%,```"=````:@```$D```!L````
M;@```+(````^`````````(``````````XP`````````U````^0``````````
M````Q@```!,```"I````D0```!`!```1````T@````````#@````5@``````
M``#0````J`````````"X````S0```,4```!R````R````+<````9````*P``
M`+8```#H`````````"P````W````1`````````".````I````)0```"P````
M%0```%$`````````&P$````````6`````P```````````````````'P```!K
M`````````/,``````````````)4````"`0``ZP```-<`````````````````
M````````L0```'4```#G````O@```(\````J````^@```%4````!`0``````
M`%T```#`````<0```'X```#R````W@`````````;````<P````0```#;````
M(0```!8!``#!``````````(````N````/0```$P```!@````@0```%@```"K
M````)````&T````2`0``]@```&8```#[````_0```!X!``!&````[0```"T`
M````````(`$```````!]````BP```-8```!V````:0````````!?````.0``
M``````!D````GP````````"'````8@````````"\````F0`````````[````
M!@$``+L```#I`````````.0````G````J@```!T`````````,`````T!``!G
M````^````)X```!(````)@```/$```"@````'````%D````<`0``+P```/P`
M``#/````"0$``*8````3`0```````",!````````_@````````"3````P@``
M````````````````````````````"P````````##`````````*T```!.````
M``````L!``"8````U0````````"N`````````.X````4````Y@```$T````*
M`````P$``!\!``!'````D@```'<`````````(````!@!``!Z````%P```$,`
M```-````"`$```@```"0````O0```#$```#O`````````(,````?````(P``
M`!T!``"U````6P```)H```````````````````!P````N0```'\````.`0``
M`````/4```#L````0````*4```#?`````````!X```#:````%0$``#H```!"
M````2@```.(`````````$0$```````!>````5P```,L```"$````````````
M````````QP````````",````(@```,P`````````.``````!``#$````IP``
M`*$```!<````@@````8`````````-`````````#A`````````%````!:````
MN@````````"L````M````!@`````````2P```/\````A`0```````*\```#)
M```````````````.``````````D`````````T0`````````E`````````&@`
M```/`0``W`````````!O````!`$``!H!``"(````4@```(T`````````````
M`)L```"*````5````!(````,````00```+,````/````>0```#\````R````
M>P````4`````````=```````````````*0```#8```!X`````````!H````0
M````V0```-,```#J````/``````````,`0```````#,```!E````3P```)<`
M``!%``````````````#4````````````````````8P````4!````````(@$`
M```@*"5S(&1A>7,@86=O*0`@*'1O9&%Y*0`@*'EE<W1E<F1A>2D`)7,@+2!.
M;W1I8V4`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@9FEL92!S=6-C97-S9G5L;'D@
M:6UP;W)T960`)7,@:7,@<F5Q=6ER960`,C0@:&]U<G,`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$%-+U!-`$%D9`!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!
M9&0@82!N97<@=7-E<CH`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R
M97-S`$%D9')E<W,@0F]O:R!,:7-T:6YG`$%D;6EN:7-T<F%T:6]N`$%D<P!!
M9'9A;F-E9"!396%R8V@`06QI87,`06QL`$%L;"!'<F]U<',`06QL(%!E<FUI
M<W-I;VYS`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%S8V5N9&EN9P!!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1R
M:6)U=&5S`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=F%I;&%B;&4@9FEE;&1S.@!"
M860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`
M0F]L9`!";V]K;6%R:W,`0G)O=W-E`$--4P!#4D,`0V%L96YD87(`0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N8V5L`$-E;&P@4&AO;F4`
M0V]L;W(@4&EC:V5R`$-O;'5M;B!/<'1I;VYS`$-O;6EC<P!#;VUM82!S97!A
M<F%T960@=F%L=65S`$-O;7!A;GD`0V]N9FER;2!087-S=V]R9`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;G1A8W0@
M<F5M;W9E9"!F<F]M(&QI<W0N`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&1E
M8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP
M:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#=70`1$0`1&%I;'D`1&5F875L="!)
M9&5N=&ET>0!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$96QE=&4`1&5L
M971I;VX@9F%I;&5D`$1E<V-E;F1I;F<`1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@
M3W!T:6]N<P!%9&ET`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S
M<V5S(&UU<W0@;6%T8V@N`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>'!O<G0@061D<F5S<R!";V]K`$9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+@!&86EL960@=&\@8G)O=W-E(&QI<W0`1F%I;&5D('1O
M(&)R;W=S92!T:&4@9&ER96-T;W)Y`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&
M86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S`$9A>`!&:6QE($-O
M=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E
M<@!&:6QE($YA;64`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E
M<G,`1FEN9`!&;W)U;7,`1G)O;0!&=6QL($YA;64`1W)O=7``1W)O=7`@061M
M:6YI<W1R871I;VX`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$A45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(96QP`$AO;64`2&]M92!!9&1R97-S
M`$AO;64@4&AO;F4`2&]R9&4`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`26-O;G,@3VYL>0!)8V]N
M<R!W:71H('1E>'0`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD
M<SH`26YV86QI9"!D871A('-U8FUI='1E9"X`271A;&EC`$IU<W1I9GD@1G5L
M;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`3&%N9W5A9V4`3&ES="!(96QP(%1O
M<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G(&]U
M=`!-30!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$UA
M:6P`36%T8VAI;F<`36%T8VAI;F<@9FEE;&1S`$UE;6)E<G,`365N=2!M;V1E
M.@!-97-S86=E`$UE=&AO9`!-:6UE(%1Y<&4`36]B:6QE(%!H;VYE`$UO9&EF
M:65D($1A=&4`36]N=&AL>0!-=6QB97)R>2!!9&1R97-S($)O;VL`37D@06-C
M;W5N=`!.86UE`$YE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y`$YE='=O<FL`
M3F5V97(`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F\`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE
M9`!.;R!V86QU97,`3F]N90!.;W1E<P!/2P!/<'1I;VYS`$]R9&5R960@3&ES
M=`!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!01U`@4'5B
M;&EC($ME>0!02%`@4VAE;&P`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D
M.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VX`4&AO;F4`4&EN92!!9&1R97-S($)O;VL`4&QE87-E(&5N=&5R
M(&$@;6]N=&@@86YD(&$@>65A<BX`4')I=F%T92!!9&1R97-S($)O;VL`4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2X`4F%T:6\`4F5A9`!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!F<F]M('1H:7,@;&ES
M=`!296UO=F4@=7-E<CH@)7,`4F]L90!344P@4VAE;&P`4U-(`%-E87)C:`!3
M96QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C
M="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@
M=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('=H:6-H(&9I96QD
M<R!T;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+@!396QE8W0@>6]U
M<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93H`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M`%-H87)E9"!$:7)E8W1O<GD`4VAO=P!3:&]W($%L;`!3:&]W($-O;G1A8W1S
M`%-H;W<@3&ES=',`4VEZ90!3;W)T($1I<F5C=&EO;@!3<&5C:6%L($-H87)A
M8W1E<B!);G!U=`!3=6)M:70`4W5C8V5S<P!486(@<V5P87)A=&5D('9A;'5E
M<P!487-K<P!497AT($]N;'D`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE<F4@87)E(&YO(&)R;W=S
M96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W
M87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L
M;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!A(&YE
M=R!L:7-T+@!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!O8FIE
M8W0N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@
M9&%T82X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<P!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+@!4:6UE(%1R86-K:6YG`%1I=&QE`%523`!5
M;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M`%5N9&5R;&EN90!5<&1A=&4`57!D871E("5S`%5S97(@061M:6YI<W1R871I
M;VX`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE
M('-Y<W1E;3H`5F%C871I;VX`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<FES:6=N
M($1I<F5C=&]R>0!6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#H`5V%R;FEN
M9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N`%EO=7(@26YF;W)M871I;VX`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@
M<F5M;W1E('-E<G9E<G,Z`%ML:6YE("5S(&]F("5S70!F:6QE`'5N;F%M960`
M=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!4=7)B82`R+C`M8W9S"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P,BTQ,2TQ.2`R,#HT-"TP-3`P"DQA<W0M5')A;G-L871O<CH@
M36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^"DQA;F=U86=E
M+51E86TZ($)'(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@
M,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R#D[>@@[>#G
MX.0I`"`HY.WE\2D`("CB]^7PX"D`)7,@+2#'X.'EZ^7FZN``)7,@SN'QZ_/F
MXN#YZ"#N[^7PX/;HZ"`M(,_N\N+Z\.;DY>WHY0`E<R#3\>ONXNC_(._N(-'O
M[O#@Y_/LY>WHY?+N`"5S(/3@Z>L@X>7XY2#H[._N\/+H\.#M(//Q[^7X[>X`
M)7,@[>7NX?7NY.CL`#(T(/?@\>``Q^`@Y.`@ZO#H[_+H\.#RY2#OZ/'L[B#E
M(.WE[N'U[N3H["#O\^'KZ/?E[2!01U`@ZNO^]RX`Q^`@Y.`@[_#NXN7PZ/+E
M(._NY._H\>#M[B#OZ/'L[B#E(.WE[N'U[N3H["!01U`@ZNO^]RX`Q^`@Y.`@
MY.7J\.CO\NCPX/+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(.KK
M_O<L(.OH]^7M(.KK_O<@Z"#JZ_[W[N+@(/3PX.?@+@#'X"#DX"#O[N3OZ/CE
M\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@ZNO^]RP@Z^CWY>T@
MZNO^]R#H(.KK_O?NXN`@]/#@Y^`N`,?@(.3@(.KPZ._RZ/#@\N4@[^CQ[.X@
MY2#MY>[A]>[DZ.P@[_/AZ^CWY>T@4TU)344@ZNO^]RX`04TO4$T`Q.[AX.+H
M`,3NX>#B_^WE(.W@(.WNXN`@X_#S[^``Q.[AX.+_[>4@[>`@[>[BZ"#O\.#B
MX`#$[N'@XN@@[>[B(._N\O#EX>CRY>LZ`,3NX>#B_^WE\NX@[>`@[^[R\.7A
MZ/+EZ^@@Y2#GX.'PX.WE[>XN`,#D\.7Q`,#D\.7QY>T@\>_H\?KJ`,#D[.CM
MZ/'R\.CPX.WE`,3NX>#BZN@`T.#G^.CPY>WN(/+Z\/'E[>4`S_'EXN3N[>CL
M`,+QZ/?JZ`#"\>CWZN@@X_#S[^@`PO'H]^KH(._PX.+@`,+ZXN7DY>W@\N`@
M\?+NZ>WN\?(@[>4@Y2#D[N_S\?+H[.`N`-#@Y^SE\"#MX"#@\/7HXNWH_R#T
MX.GK`,CLY2#MX"#@\/7HXN``S>#PX/'RXN#YZ`#$X"#QY2#H\>K@(.OH(._N
M\N+Z\.;DY>WHY2#O\.7DZ"#NX?'K\^;BX/GH\N4@[N_E\.#VZ.@_`,/PY?CJ
MX"#O\.@@Z.?R\.CBX.WE(.W@(.WE\?KYY?'RXO/BX/G@(./P\^_@+@##\.7X
MZN`@[_#H(.CG\O#HXN#MY2#MY2#MY?'Z^>7Q\N+SXN#YZ"#O\.#BX"X`P_#E
M^.K@(._PZ"#PY>3@ZO+H\.#MY2#MX"#MY?'Z^>7Q\N+SXN#YZ"#O\.#BX"X`
MP/+PZ.'S\N@`P_#E^.K@(._PZ"#HY.7M\NCTZ.K@]NC_`,CDY>WRZ/3HZN#V
MZ/_RX"#AY?CE(.[R]>+Z\.OE[>`@[O(@4D%$2553(/'Z\.+Z\.`N`,W@Z^CW
M[>@@[^[KY?+@.@#-Y>+@Z^CD[>`@:V5R8F5R;W,@(._@\.[KX"X`S>7BX.OH
MY.WN(&ME<F)E<F]S(._N\O#EX>CRY>OQZNX@Z.SE+@#3Y.7AY>OE[>@`SO+L
MY?+JZ`#/\.7CZ^7DX.D`0TU3`$-20P#*X.OE[>3@\`##\.7XZN`@[_#H(/'B
M^O#GXN#MY2#Q(.SEZ>L@\?KPXOKP.B`E<P#.\NK@YN@`S.[AZ.OE[2#RY>OE
M].[M`,CGX>CPX.WE(.W@(/;B__(`SN_VZ.@@Y^`@ZN[K[NWH\N4`RN[LZ.KQ
MZ`!#4U8@+2#PX.?DY>OE[>@@\?KQ(.?@[^7RX/\@\?+NZ>WN\?+H`,KN[._@
M[>C_`,_N\N+Z\.3E\N4@[^#P[NO@\N``Q.[Q\OKOX"#D[B#O\^'KZ/?MZ/\@
M\?KPXOKP(.'E^.4@[O+JX.?@[2X`RN[M\N#J\OKR(.'E^.4@[_#E[.#U[>#R
M(.[R(/'OZ/'ZZN`N`,/PY?CJX"#O\.@@4$=0(.KPZ._RZ/#@[>7R[B#MX"#O
MZ/'L[BX`P_#E^.K@(._PZ"!01U`@[^[D[^CQXN#MY?+N(.W@(._H\>SN+@##
M\.7XZN`@[_#H(.3EZO#H[_+H\.#MY?+N(.W@(%!'4"#DX.WMZ"X`S>7J[O#E
MZO+E[2!E;6%I;"#@Y/#E\2#MX"#O[NOS]^#RY>O_+@##\.7XZN`@[_#H(._N
MZ_/WX.+@[>7R[B#MX"#O\^'KZ/?MZ/\@ZNO^]R#N\B#JZ_[W+?'Z\.+Z\.`N
M`,WEXOKG[.[F[>[Q\B#DX"#QY2#N\N+N\.@@SN'QZ_/FXN#YZ%_GX.3@]^@@
M[.[D\^L@)7,@`.CG\.7FZ`#$Q`#%YN7D[>7B[>X`R.3E[?+H]^WN\?(@[^X@
M[^[D\.#GX>CPX.WE`,_N\>[JX"#MX"#Q[O#RZ/#@[>4@[^X@[^[D\.#GX>CP
MX.WE.@#(Y_+PZ.D`P_#E^.K@(._PZ"#R\.CE[>4`S>#LX.O_XN#YZ`#$Y?+@
MZ>OH\N4@X?_UX"#PY>/H\?+PZ/#@[>@@Y^`@X.3LZ.WH\?+PX/+N\.`N`,3H
M\.7J\N[PZ/\`Q.CQ[^OEZ2#.[_;HZ`#0Y>3@ZO;H_P#/Z/'L[@#%;6%I;"#@
MY/#E\0!%;6%I;"#@Y/#E\>CRY2#R\/_AXN`@Y.`@\?KB[^#DX/(N`,_PX.?E
M[2#PY>?SZ_+@\BX`P_#E^.K@`,+QY>KH(#$U(.SH[?/RZ`#"\>7JZ"`S,"#Q
MY>KS[>3H`,+QY>KH(#4@[.CM\_+H`,+Q_^KN(.ONX^+@[>4`S>`@XO'EZN@@
M[^[K[N+H[2#WX/$`PO'_ZN`@[.CM\_+@`,_PZ.SE\.WH(/'R[NGM[O'RZ#H`
MQ>KQ[^[P\B#MX"#@Y/#E\>W@(.KMZ./@`,WEXOKG[.[F[>[Q\B#DX"#QY2#G
MX/#EY/_R(._PY?3E\.7M]NCH\N4N`,/PY?CJX"#O\.@@[_#EX^OEYN3@[>4@
M[>`@\>_H\?KJX`##\.7XZN`@[_#H(._PY>/KY>;DX.WE(.W@(._@[^K@\N``
MS>7B^N?L[N;M[O'R(.3@(/'E(.[Q^OGE\?+BZ"#B\/KGZN`@\2!,1$%0(/'Z
M\.+Z\"X`P_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(%--0B#Q^O#B^O`N`,WE
MXOKG[.[F[>[Q\B#GX"#R^O#QY>WE(.(@Y.CPY>KR[O#H_SH@)7,`U.#J\0#!
M\.[I(/3@Z>ONXN4Z("5S(/3@Z>L`P?#NZ2#TX.GK[N+E.B`E<R#TX.GKX`#4
MX.GK(.SE[>#FY?``R.SE(.W@(/3@Z>L`R.?O\.#YX.WE\NX@[>`@].#IZ^[B
MY2#MY2#QY2#O[N3D^O#FX"X`U.CK\OKP`-+Z\/'H`-3N\//LZ`#.\@#([.4@
M[>`@].#IZP##\//OX`#`Y.SH[>CQ\O#H\.#MY2#MX"#C\//OZ`##\//OZ`#/
M\.#BX"#GX"#C[O'RZ`!(5%10(.CDY>WRZ/3HZN#VZ/\@[>4@Y2#MX.SE\.7M
MX"X`S^[L[OD`S>#WX.ON`,3N[.#XY>T@X.3PY?$`Q.[LX/CE[2#RY>OE].[M
M`$AO<F1E`,/PY?CJX"#O\.@@\?KGY.#BX.WE(.W@($E-05`@[^[YY>WQZN`@
MZO/RZ/\Z("5S`,/PY?CJX"#O\.@@Z.?R\.CBX.WE(.W@($E-05`@[^[YY>WQ
MZN`@ZO/RZ/\Z("5S`,/PY?CJX"#O[O#@Y.@@ZN+N\N`@[_#H(/'ZY^3@XN#M
MY2#MX"!)34%0(._N^>7M\>K@(.KS\NC_.B`E<P!)4"#@Y/#E\>`@[>4@Y2#B
M(._NY^+NZ^7MZ/\@0TE$4B#AZ^[J+@#1X.SN(.CJ[NWH`,CJ[NWH(/$@\N7J
M\?(`R.SO[O#RZ/#@[>X@[^[KY3H@)7,`R.SO[O#RZ/#@[>@@[^[KY?+@.@#(
MY^_PX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N`,W@ZNON[>7MZ`#O^NOM
M[B#O[N3PX.+M_^+@[>4`Z__B[B#O[N3PX.+M_^+@[>4`Y/_Q[>X@[^[D\.#B
M[?_BX.WE`$ME<F)E<F]S(/'Z\.+Z\.`@[O+UXOKPZ^@@Z.3E[?+H].CJX/;H
M__+@+@#*Z_[WX"#BY??E(/'Z^>7Q\N+SXN`@XB#O\^'KZ/?MZ/\@ZNO^]_'Z
M\.+Z\"X`Q>?HZ@#/[NSN^2#RY>SH`-'OZ/'ZZN`@\2#O[O+PY>'H\N7KZ"#E
M(.?@X?#@[>7M+@#"]>[D`,CG]>[D`,S,`$U3+51.148@[_#HZO#E[^7MZ/_R
M(/3@Z>L@[>4@\?KD^O#FX/CE(.3@[>WH+@#/[OG@`-'ZY/KPYN#YZ`#1^N+O
MX.3@^>@@[^[KY?+@`-?KY>WNXN4`PNCD(.W@(.SE[?[R[CH`S^CQ[.X`S.7R
M[N0`36EM92#RZ.\`S.[AZ.OE[2#RY>OE].[M`,3@\N`@[>`@[_#N[.7M_^WE
M`,SE\>7W[>X`375L8F5R<GD@X.3PY?'MX"#J[>CCX`#,[O_RX"#/[OG@`,CL
MY0!.971C96YT97(@365M8F5R($1I<F5C=&]R>0#,\.7FX`#-Z.KNX^``S>[B
M[B#O[O+PY>'H\N7K\>KN(.CLY2`H[N_VZ.[MX.OM[BD`S>4`S?_LX"#GX.3@
MY.7MX"#J[NWTZ./S\.#VZ/\@Y^`@1E10(%9&4RX`S?_LX"#GX.3@Y.7MX"#J
M[NWTZ./S\.#VZ/\@Y^`@4U%,(%9&4RX`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S
M\.#VZ/\@Y^`@4U%,+49I;&4@5D93+@#-_^S@(.?@Y.#DY>W@(._@\.[KX"#G
MX"!)34%0(.CDY>WRZ/3HZN#VZ/\N`,W_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@
M($ME<F)E<F]S(.CDY>WRZ/3HZN#VZ/\N`,W_[.`@ZN[M].CC\_#@]NCN[>W@
M(.CM].[P[.#VZ/\@Y^`@4TU"(.CDY>WRZ/3HZN#VZ/\N`,+Z\.W@\NCRY2#D
MX.WMZ"#MY2#QX"!834P`S?_LX"#Q\N[I[>[Q\N@`S?_LX`#!Y>OEYNKH`,[*
M`,[O]NCH`,_NY/#EY.7M(/'OZ/'ZZ@#$\//CX"#H[?3N\.S@]NC_`,_PX.+@
M(.W@(._PZ/+EYN#RY>O_`%!'4"#/\^'KZ/?E[2#JZ_[W`%!'4"!3:&5L;`#/
MX/#NZ^``S^#P[NO@.@#/X/#NZ^`Z(`#-Y>KN\.7J\NW@(._@\.[KX"X`PNSZ
MZNWH`,3@(/'E(.CGXOKP^.+@\B#KZ"#NX?'K\^;BX/GH\N4@[N_E\.#VZ.@@
M[_#H(,+U[N0_`,#D[.CMZ/'R\.CPX.WE(.W@(._PX.+@\N``TN7KY?3N[0!0
M:6YE(,#D\.7Q[>`@ZNWHX^``S.[K_RP@XOKBY>3E\N4@[.7QY?8@Z"#C[N3H
M[>`N`-?@\?+MX"#`Y/#E\>W@(.KMZ./@`,KK_O?NXN`@Y.+NZ>K@(._SX>OH
M]^7M+_?@\?+E[2#JZ_[W(.WE(.'E^.4@X^7MY?#H\.#MX"X`RN[E].CVZ.7M
M\@#7Y?+E[>4`R/'JX/+E(.3@(.CG\O#HY?+E("5S(.OH/R#2X.?H(.[OY?#@
M]NC_(.WE(.SNYN4@Y.`@\>4@XOKP[>4@[>#GX.0N`,#D\.7Q(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`,_PY>S@]>WH`,_PY>S@]>+@
M[>4@[O(@\N[GZ"#Q[^CQ^NHN`,_PY>S@]>WH(._N\O#EX>CRY>LZ("5S`-#N
MZ_\`4U%,(%-H96QL`%-32`#2^O#QZ`#(Y^'E\.7RY2#C\//OX"#GX"#D[N'@
MXO_MY0#(Y^'E\.7RY2#M[N(@[_#H\N7FX/+EZR#MX"#C\//OX`#(Y^'E\.7R
MY2#Q^O#B^O``R.?AY?#H(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4`R.?AY?#E
M\N4@Q.#RX"#PX.?DY>OH\N7K.@#(Y^'E\.7RY2#T[O#LX/(@Y^`@Q.#RX/+@
M.@#(Y^'E\.7RY2#TX.GK(.?@(.CL[^[P\CH`R.?AY?#E\N4@].[P[.#R(.?@
M(-?@\>`Z`,CGX>7PY?+E(.3BY2#Q^N+OX.3@^>@@[^[KY?+@.@#(Y^'E\.7R
MY2#J[N@@[^[KY?+@(.3@(/'@(._NZN#GX.WH(.(@\>_H\?KJX"#Q(.#D\.7Q
MZ"X`R.?AY?#E\N4@XN#XX/+@(/'UY>S@(.?@(/;BY?+NXN7RY2X`R.?AY?#E
M\N4@[_#EY._N]^CRX.WH__(@[O(@PN#Q(.7GZ.HZ`,?@Y.#I\N4@PN#XY?+N
M(.W@]^#K[>X@[_#HZ^[FY>WHY2P@\?7E[.`@Y^`@]N+E\N[BY2P@[N_PY?'M
M_^+@[>4@[>`@\?+PX.WH]N#RX"#H(.3P\^/H(.[O]NCH(.?@(.3H\>_KY?\N
M`-'O[N3EZ^7MX"#$Z/#EZO+N\.C_`,_NZN#GXN#MY0#/[NK@YN@@XO'H]^KH
M`,_NZN#FZ"#J[NWRX.KRZ/+E`,_NZN#FZ"#Q[^CQ^O;H\N4`T.#G[.7P`-'N
M\/+H\.#MY0#"^N+EYN3@[>4@[>`@\>_E]NC@Z^WH(/'H[.+NZ^@`R.?O\.#R
MZ`#3\>_E]0!486(@*/+@X?/KX/;H_RD@\.#GY.7KY>WH(/'R[NGM[O'RZ`#'
MX.3@]^@`T>#L[B#RY>KQ\@#/\.CJ\.7OY>WH__(@4$=0(._NY._H\2#E(.WE
M[N'U[N3H["#GX"#DX"#QY2#O\.[BY?#H(._NY._H\>#M[O+N(._H\>SN+@#*
M\.CO\NCPX.WE\NX@Z.?H\>KBX"#J\.CO\NCPX.W@('=E8B#B\/KGZN`N`,SE
M\?+N[^[K[N;E[>CE\NX@[>`@1VYU4$<@].#IZ^`@\O#_X>+@(.3@(.'ZY.4@
MY.#DY>UO(.W@($-R>7!T7W!G<#HZ(&-L87,`S_#NX_#@[.#RX"P@ZN[_\NX@
M\>OSYN@@Y^`@[^[JX.?BX.WE(.W@(/+NY^@@\NCO(.3@[>WH("@E<RD@[>4@
MX>7XY2#N\NKPZ/+@(.(@\>CQ\N7LX/+@`,W_[.`@X.3PY?'MZ"#J[>CCZ"#G
MX"#O\.7CZ^7FY.#MY2X`S?_LX"#DXN[IZN@L(.KNZ/+N(.3@(.'ZY.#R(._N
MZN#GX.WH(.(@Z^CMZ/_RX"X`R.S@(/+B^O#DY2#L[>[C[B#QZ.SB[NOH(.(@
M\N[BX"#O[NOE+B#"^N+EZ^@@\?+E("5S(/'H[.+NZ^`[(/+P_^'BX"#DX"#B
M^N+EY.7RY2#O[BWLX.OJ[B#N\B`E<RX`P_#E^.K@(._PZ"#HY^_PX/G@[>7R
M[B#MX"#TX.GKX#H@)7,@[>4@X>7XY2#HY^_PX/+E[2X`R.S@^.4@[_#NX>OE
M["#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`N("5S(.4@[^XMX^[K_^P@[O(@
M[.#J\>CLX.OM[B#D[N_S\?+H[.C_(/#@Y^SE\"`H)60@X>#I\N`I+@##\.7X
MZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@Z>O@+B`E<R#AY?CE(/'@[.X@[O+W
MX/'RZ"#HY^_PX/+E[2X`P_#E^.K@(._PZ"#Q^N?DX.+@[>4@[>`@[>[B(/'O
MZ/'ZZBX`P_#E^.K@(._PZ"#HY_+PZ.+@[>7R[B#MX"#R[N?H(.[AY>KR+@##
M\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J[NWRX.KRZ"X`TN[BX"#M
MY2#E(.+@Z^CDY>T@<F%R(.#P]>CB+@#2[N+@(.WE(.4@XN#KZ.3E[2!Z:7`@
M].#IZRX`TN[BX"#O[NOE(.4@[>7NX?7NY.CL[BX`TN[BX"#O[NOE(.SNYN4@
MY.`@\?KD^O#FX"#QX.SN(/;EZ^@@]^CQZ^`N`-+NXN`@[^[KY2#L[N;E(.3@
M(/'ZY/KPYN`@\>#L[B#WZ/'KX"#H(.3B[N7R[O?HY2X`TN[BX"#O[NOE(/+P
M_^'BX"#DX"#E(.?@[^7RX/\@Z.OH(.CM\N7PXN#K(/#@Y^3EZ^7M(/'OZ/'Z
MZB#O\.[LY>WKZ.+H`-+@Y^@@].[P[.`@XN7WY2#AY?CE(.[A\.#A[O+E[>`N
M`-+NXN`@]^CQZ^X@\O#_X>+@(.3@(.4@[^[MY2#EY.CMZ/;@+@#2[N?H(/'Z
M\.+Z\"#MY2#L[N;E(.3@(.3EZN[L[_#E\>CPX"!Z:7`@Z"!G>FEP(/3@Z>ON
MXN4N`-+@Y^@@\?+NZ>WN\?(@\O#_X>+@(.3@(.4@]^CQZ^XN`,_P[O'KY>3_
MXN#MY2#MY2#B\.7LY0#$Z_KF[>[Q\@!54DP`S>7B^N?L[N;M[O'R(.?@(.+P
M^N?JX"#Q(%-13"#Q^O#B^O`N`,/PY?CJX"#O\.@@Y^#PY>;DX.WE(.W@(.3E
M].CMZ/;HZ/+E(.W@("5S+@##\.7XZN`@[_#H(.[RXN#P_^WE\NX@[>`@ZN[L
M[_#E\>CPX.T@X/#UZ.(N`,/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O
M="#OX._JX"X`P_#E^.K@(._PZ"#O\.7B[N3@(.W@(/+NY^@@5V]R9"#D[NKS
M[.7M\@#/[N3WY?#RX.WH`,[O\.7Q[>@`SN_PY?'MZ"`E<P#`Y.SH[>CQ\O#H
M\.#MY2#MX"#O[O+PY>'H\N7KZ/+E`,CLY0#([.4Z`,CLY3H@`,_N\O#EX>CR
MY>OH(.(@\>CQ\N7LX/+@.@#"X.K@[?;H_P##\.7XZN`@[_#H(._P[N+E\.K@
M\N`@+2#R[N+@(._H\>SN(.SNYN4@Y.`@Y2#AZ.ON(._NY._PX.+E[>XN`%9E
M<FES:6=N($1I<F5C=&]R>0#(Y^/KY>0L(.KNZ/+N(.3@(.'ZY.4@[^[JX.?@
M[2#O[B#O[N3PX.?AZ/#@[>4Z`,+MZ.S@[>CE`-'EY.SH]^WN`,3NX?#E(,3N
M^.OH(.(@)7,`Q.[A\.4@Y.[XZ^@L("5S`,CGX>7PY?+E(._PZ.ONYN7MZ.7R
M[BP@ZN[E\NX@)7,@Y.`@[^[JX.;E(/'KY>0@XO7NY"X`P>CG[>7Q(.#D\.7Q
M`,'HY^WE\2#RY>OE].[M`,/#`,/NY.CX[>X`Q.``S>4@XOKBY>3N]?+E(.+@
MZ^CDY>T@96UA:6P@X.3PY?$N`-+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H
M\N7K(.?@(.CG\O#HXN#MY2X`TO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CR
MY>L@Y^`@Y.[AX.+_[>4N`-+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K
M(.?@(.[O\.7Q[?_BX.WE+@#([?3N\.S@]NC_(.?@(,+@\0#"X/CH__(@Z.3E
M[?+H].CJX/;H[NWE[2#D\.#IXN7P(.WE(._NY.3Z\.;@(/'OZ/'ZZB#MX"#O
M[O+PY>'H\N7KZ/+E+"#HZ^@@\N#GZ"#B^N?L[N;M[O'R(.4@Y^#A\.#MY>W@
M+@#"X/CH\N4@ZN[M].CC\_#@]NCN[>WH(.[O]NCH(.'_]>`@[N'M[N+E[>@N
M`,+@^.CRY2#Q^O#B^O#H.@!;Z^CMZ/\@)7,@[O(@)7-=`/3@Z>L`X>7G(.CL
MY0!V0V%R9```````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T=7)B82]L;V-A;&4O87)?4UDO````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`R,#`Q-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]A<E]362],0U]-15-3
M04=%4R\`````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-3,`,#(Q-C`R`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C
M86QE+V%R7U-9+TQ#7TU%4U-!1T53+W1U<F)A+FUO````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R-#$P-P`Q,#0Q-S,V,C<U,P`P,C,R-34`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````WA($E0````"L````'````'P%
M``#E````W`H```````!P#@``)````'$.```E````E@X``!T```"\#@``"```
M`-H.```%````XPX```,```#I#@``"````.T.```&````]@X```<```#]#@``
M%`````4/```/````&@\```4````J#P```P```#`/```?````-`\```D```!4
M#P``.0```%X/```I````F`\``!$```#"#P``%@```-0/```6````ZP\```8`
M```"$```"`````D0```5````$A````H````H$```#````#,0```.````0!``
M``8```!/$```%@```%80```'````;1```!H```!U$```*0```)`0```"````
MNA````4```"]$```$````,,0```:````U!````8```#O$```#P```/80```*
M````!A$``!0````1$0``+P```"81```)````5A$```\```!@$0``)@```'`1
M```$````EQ$```4```"<$0``#0```*(1```%````L!$``!````"V$0``$```
M`,<1```/````V!$```L```#H$0``#P```/01```,````!!(```\````1$@``
M!@```"$2```3````*!(``!X````\$@``%0```%L2```>````<1(``"$```"0
M$@``(````+(2```B````TQ(```,```#V$@``!````/H2```$````_Q(```4`
M```$$P``!`````H3```$````#Q,```P````4$P``"@```"$3```%````+!,`
M``H````R$P``#P```#T3```2````31,``!````!@$P``*````'$3```(````
MFA,``!````"C$P``!@```+03```'````NQ,```(```##$P``!````,83```(
M````RQ,```\```#4$P``"@```.03```'````[Q,```P```#W$P``!P````04
M```5````#!0```0````B%```"P```"<4```%````,Q0```(````Y%```,P``
M`#P4```S````<!0``#@```"D%```,0```-T4```L````#Q4```0````\%0``
M!0```$$5```"````1Q4```<```!*%0``$0```%(5```(````9!4``!X```!M
M%0``!0```(P5```1````DA4``"@```"D%0``*0```,T5```3````]Q4``!4`
M```+%@``"P```"$6```1````+18```0````_%@``!````$06```,````218`
M``8```!6%@``&@```%T6```7````>!8``!H```"0%@``*````*L6```7````
MU!8``!L```#L%@``-`````@7```E````/1<``!\```!C%P``$P```(,7```(
M````EQ<```T```"@%P``"@```*X7```0````N1<```X```#*%P``%P```-D7
M```'````\1<``!0```#Y%P``!0````X8```)````%!@``"8````>&```)P``
M`$48```H````;1@``"$```"6&```'````+@8```%````U1@```,```#;&```
M+P```-\8```@````#QD``"0````P&0``)0```%49```@````>QD``"8```"<
M&0``#````,,9```(````T!D``!L```#9&0``!P```/49```&````_1D```T`
M```$&@``"P```!(:```,````'AH```H````K&@```@```#8:```&````.1H`
M``,```!`&@``10```$0:```K````BAH``#````"V&@``$````.<:```?````
M^!H``!`````8&P``#P```"D;```$````.1L```4````^&P``C@$``$0;```D
M````TQP``"0```#X'```&0```!T=```'````-QT```P````_'0``!0```$P=
M```)````4AT```D```!<'0``!P```&8=```3````;AT```D```""'0``"```
M`(P=```&````E1T``!@```"<'0``!@```+4=```F````O!T``"T```#C'0``
M$````!$>```?````(AX``"$```!"'@``!````&0>```%````:1X``!4```!O
M'@``#0```(4>```-````DQX```X```"A'@``!@```+`>```1````MQX```8`
M``#)'@``%P```-`>```J````Z!X```L````3'P``!````!\?```0````)!\`
M`!8````U'P```P```$P?```.````4!\```8```!?'P``"P```&8?```<````
M<A\```0```"/'P``#@```)0?```I````HQ\```4```#-'P``#0```-,?```-
M````X1\```,```#O'P``"P```/,?```+````_Q\```H````+(```!P```!8@
M```+````'B````@````J(```$````#,@```%````1"```!,```!*(```'P``
M`%X@```3````?B```!(```"2(```'P```*4@```>````Q2```!P```#D(```
M!`````$A```$````!B$```(````+(0``!@````XA```(````%2$```<````>
M(0``#````"8A```+````,R$```4````_(0``"P```$4A```/````42$``!0`
M``!A(0``$0```'8A```E````B"$```4```"N(0``%0```+0A```$````RB$`
M``0```#/(0``"P```-0A```&````X"$```P```#G(0``#0```/0A```-````
M`B(```4````0(@``#@```!8B```&````)2(``!(````L(@```P```#\B```+
M````0R(```4```!/(@```@```%4B```G````6"(``"<```"`(@``*0```*@B
M```@````TB(``!P```#S(@``!@```!`C```'````%R,```4````?(P``!@``
M`"4C```,````+",```L````Y(P``%````$4C```$````6B,``!8```!?(P``
M'````'8C```H````DR,```L```"\(P``#P```,@C```,````V",``!$```#E
M(P``!0```/<C```#````_2,```P````!)````P````XD```5````$B0``!,`
M```H)```%P```#PD```9````5"0``!$```!N)```%````(`D```K````E20`
M`!D```#!)```$@```-LD```8````[B0```H````')0``#P```!(E```-````
M(B4```P````P)0``"P```#TE```/````224```@```!9)0``$0```&(E```'
M````="4```8```!\)0``'P```(,E```?````HR4``!,```##)0``(P```-<E
M```;````^R4```4````7)@``#P```!TF```K````+28``!T```!9)@``%0``
M`'<F```?````C28``"X```"M)@``(@```-PF```/````_R8```P````/)P``
M%@```!PG```%````,R<```@````Y)P``#P```$(G```-````4B<```H```!@
M)P``"@```&LG```(````=B<```8```!_)P```P```(8G```F````BB<``!\`
M``"Q)P``+0```-$G```(````_R<``!$````(*```#P```!HH```0````*B@`
M``4````[*```!0```$$H```!````?@````4```""`````````),`````````
M`````)L````I````HP```"$````^``````````````"B`````````(\````9
M````D0````<````)````8````*8```"K````E````%````!\````3P```#(`
M```V````GP``````````````D````(D````K`````````$@```":````````
M`*0````2`````````"<```"#````@`````````!L````.P```'4````:````
M*@````0```!G````.@```$$``````````````($````E````%````&$````D
M````"P````````!7````3````*4```!_````70````````!T````#0```!4`
M```L````.`````````"7````````````````````9````%8```"5````C@``
M``````!C````G0`````````<`````````(P````P````F````"8`````````
M&P```#D```!N````?0```$T```!H``````````````!'````6@```%4````,
M````/P```'``````````%@```(8```"-````4P```&H``````````````!X`
M```*````````````````````7````(H`````````0`````````![````````
M`'<`````````>@```"````"6````#P````````!Q````H0````,```!)````
M``````````!8`````````%L`````````!@```#4```!M````(P````````"(
M````0@```&D````.`````````'@```"H````"`````````!O````$P```%(`
M```W````*````%D````T````40```#$`````````A0```*<````S````<P``
M`#P`````````:P```'(````?````A````&(````M````2P```!``````````
MH````(L````1````0P```)P```!4````D@```&8``````````````#T`````
M````G@```*P````"````&````'8``````````````%\```"'````+P```"(`
M``"9````2@```*H````N````7@```&4``````````````$0`````````%P``
M`!T```!%````>0```$X`````````J0```$8``````````")&:7)S=&YA;64@
M3&%S=&YA;64B("`H:64N($IO:&X@1&]E*0`B3&%S=&YA;64L($9I<G-T;F%M
M92(@*&EE+B!$;V4L($IO:&XI`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R
M=&5D`#(T(&AO=7)S`$%-+U!-`$%D9`!!9&0@<&%I<@!!9&0@=&\`061D<F5S
M<P!!9&1R97-S($)O;VL@3&ES=&EN9P!!9'9A;F-E9"!396%R8V@`06QI87,`
M06QL`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07-C96YD:6YG
M`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+@!!=F%I;&%B;&4@9FEE;&1S.@!"860@:V5R8F5R;W,@<&%S
M<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0G)O=W-E`$-A;&5N9&%R
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E(%=I;F1O
M=P!#;VQU;6X@3W!T:6]N<P!#;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A;'5E
M<P!#;VUP86YY`$-O;G1A8W0@<F5M;W9E9"!F<F]M(&QI<W0N`$-O=6QD(&YO
M="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1E
M9F%U;'0@261E;G1I='D`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5L
M971E`$1E;&5T:6]N(&9A:6QE9`!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1I<F5C=&]R>0!$:7-P;&%Y($]P=&EO;G,`1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``161I=`!%;6%I;`!%;7!T
M>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C
M;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AP;W)T`$5X<&]R
M="!!9&1R97-S($)O;VL`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!B<F]W<V4@;&ES=`!&86EL960@=&\@8G)O=W-E('1H92!D
M:7)E8W1O<GD`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!S96%R
M8V@@=&AE(&1I<F5C=&]R>3H@)7,`1F%X`$9I;F0`1G)O;0!'<F]U<`!(96QP
M`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`26-O;G,@3VYL
M>0!)8V]N<R!W:71H('1E>'0`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D
M(&9I96QD<SH`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+@!,86YG=6%G90!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@;W5T
M`$U-`$UA:6P`36%T8VAI;F<`36%T8VAI;F<@9FEE;&1S`$UE;G4@;6]D93H`
M365S<V%G90!-;V)I;&4@4&AO;F4`36]N=&AL>0!-=6QB97)R>2!!9&1R97-S
M($)O;VL`3F%M90!.86UE($9O<FUA=`!.979E<@!.;P!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F]N90!.;W1E<P!/2P!/<'1I;VYS`$]T:&5R
M($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<P!0:&]N90!0:6YE($%D9')E<W,@0F]O:P!0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4F5M;W9E(&9R;VT@=&AI<R!L:7-T`%)E;6]V92!P86ER`%)E='5R;B!T;R!/
M<'1I;VYS`%)O;&4`4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9F]R;6%T('5S
M960@=&\@9&ES<&QA>2!N86UE<SH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!W:&EC:"!F:65L
M9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RX`4V5L96-T('=H
M:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4VAO=R!!;&P`
M4VAO=R!#;VYT86-T<P!3:&]W($QI<W1S`%-K:7`@36%I;G1E;F%N8V4`4V]R
M="!$:7)E8W1I;VX`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5C8V5S<P!4
M86(@<V5P87)A=&5D('9A;'5E<P!487-K<P!497AT($]N;'D`5&AE<F4@87)E
M(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@=V%S(&%N(&5R
M<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N`%1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!T:&ES(&]B:F5C="X`5&AI<R!N=6UB97(@;75S="!B92!A="!L
M96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET;&4`
M55),`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O
M8W5M96YT`%5S97(@3W!T:6]N<P!5<V5R;F%M90!6:65W('1O(&1I<W!L87D@
M8GD@9&5F875L=#H`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC
M;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!S96QE8W0@870@
M;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N`%EO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P
M;W)T70!;;&EN92`E<R!O9B`E<UT`;F%M90!V0V%R9`!0<F]J96-T+4ED+59E
M<G-I;VXZ(%1U<F)A(`I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ
M,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#0M,S`@,3(Z,#`K,#(P
M,`I,87-T+51R86YS;&%T;W(Z("!0;&%T:6YU;2!$979E;&]P;65N="!496%M
M(#QD979T96%M0'!L871I;G5M+7-Y+F-O;3X*3&%N9W5A9V4M5&5A;3H@07)A
M8FEC(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U-@I#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L
M=7)A;',],CL@<&QU<F%L/2AN(#X@,2D["@`BQ^''T^,@H2#'X>'>R"(@("CC
MR\?A.B#CS>//(,?AVM'([2D`(L?AX=[((*$@Q^''T^,B("`HX\O'X3H@Q^':
MT<CM(./-X\\I`,KC(,?3RNW1Q\\@Q^'CX=T@)7,@R.3,Q\T`,C0@T\?:R0#D
MY<?1Q_`OX>WAQ_``Q=;'W<D`P];=(,ODQ\;M`,76Q]W)(,7A[`#'X=KDYL?D
M`-['QN/)(,_=RM$@Q^':Y,?F[>0`R,W+(./*WL_C`,?3XR#(S^WA`,?AS./M
MV@#*XR#*S<_MSR#>[>/)(-OMT2#CWLCFX<D`RM7'VL_M`,K#W^W/(,?AV.'(
M(-[(X2#'X<C/P2#(VN/A[<?*(,?AU>W'Y,F_`,KC(-'=UB#'X<K-WMX@X^0@
MQ^'EYNW)(./D(-[(X2#'X>/.S^,@T<?/[>;3+@#'X<W>YN$@Q^'CRN;=T<DZ
M`-_AX\D@X]'FT2#;R-$@X][(YN')("C?[='([='FTRD`Q]/C(,?AX]/*SL_C
M(-O(T2#CWLCFX2`HW^W1R.W1YM,I`,K5W<T`P\SDS\D`Q>';Q\$@Q^'(X<?;
M(-KD(./4W^')`,?AY<?*W2#'X<SFQ^$`Q=OAQ]X@Q^'DQ]W0R0#.[<?1Q\H@
MQ^'#VN//R0#1T^;CQ\H`WNWC(./=U>;AR2#(W<?1TLD`Q^'4T=_)`,?*U<?A
M(./-T.;=(./D(,?AWL?&X\DN`.''Q>/?Q^3MR2#AW<K-($UA:6YT96YA;F-E
M7U1A<VL@X>'(T>WCS"`E<P#MYN,@+2#1WN/MY`#MYN/M`,?ARLW>WB#'X<?=
MRM''UNT`Q\K,Q^4@Q^'=T=(@Q^''W<K1Q];M.@#-T-T`SMC#(,[AQ^$@Q^'-
MT-T`RN3'TN'M`-31S2#'X>/4W^')`,KC(,W=V2#'X<K=Q]7MX2#AX\_MT2#'
MX>39Q^,`X\SASP#.[<?1Q\H@Q^'%V>7'T0#AQR#*S\[A(./(Q]31R?`@Q>'L
M(,?AX^'=(&UA:6YT96YA;F-E+G!H<`#*S='MT0#(T>W/(,7AW\K1YN3M`.''
MRN;,SR#DRL?&S"X`SMC#`-_A(#$U(,_>[=[)`-_A(#,P(,_>[=[)`-_A(#4@
MS][MWLD`W^$@S\[FX0#?X2#DU=T@T\?:R0#?X2#/WNW>R0##X\OAR2#:X>P@
MQ^'>[>,Z`,K5S^W1`,K5S^W1(,_=RM$@Q^':Y,?F[>0`X<?%X]_'Y.W)(.'A
MVLOFT2#:X>P@Q^'*W=;MX<?*+@#.V,,@W>T@RM7=S2#'X=['QN/)`,[8PR#=
M[2#*U=W-(,?AX\SASP#AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C($Q$05`N
M`.''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@4TU"+@#.V,,@SN''X2#'X<C-
MRR#=[2#'X>/,X<\Z("5S`-W'W],`P^;,SP#CY`#CS./FVLD`Q^'CT\?:S\D`
MQ^'(S\?MR0#:Y.;'Y"#'X>/DTN$`Y<?*W2#'X>/DTN$`Y>;1S^T`P^W>YN3'
MRB#=WM@`P^W>YN3'RB#CVB#DU>;5`,?AS=[FX2#'X>/3RN;1S\DZ("5S`,?A
MS=[FX2#'X>/3RN;1S\DZ`,?AX\[/XR#?[='([='FTR#1W=8@Q^'*S=[>(./D
M(,?AY>;MR2X`Q^'AV\D`WL?&X\D@VN3'YNWD(,?AX]/'VL_)`,_.YN$`SM'F
MS`#4Y=$@+2#1WN/MY`#'X<C1[<\`X]C'R-[)(-7-[<W)`./8Q\C>R2#'X<W>
MYN$`YM;:(,?AX]#?T<?*.@#1T\?AR0#'X>7'RMT@Q^'CS>/FX0#4Y='MQ_``
MS]W*T2#:Y,?F[>0@Q^'*YLKM`,?3XP#*Y-/MWB#'X<?3XP##R,_'\`#AQP#A
MQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#'X=P@1E10(%9&4RX`X<?*YLS/
M(./:X>;CQ\H@S>;A(,7:S\?/Q\H@Q^'<(%-13"!61E,N`.''RN;,SR#CVN'F
MX\?*(,WFX2#%VL_'S\?*(./AW<?*(%-13"!61E,N`.''RN;,SR#?X>/)(./1
MYM$@X>'*S=[>(-_MT<CMT>;3`.''RN;,SR#?X>/)(./1YM$@X>'*S=[>(%--
M0CX`X<?MYLS/`./AQ\W9Q\H`X^;'W=X`SNW'T<?*`./:X>;CQ\H@PL[1[`#?
MX>/)(,?AX]'FT0#*Y-WMT"#:X^'MQ\H@Q^'5[<?DR0#EQ\K=`,_=RM$@Q^':
MY,?F[>0@Q^'5Y.;(T>T`Q^'1S,?!(,K2YNW/Y,<@X^'.U2#'X>/4W^')+@#'
MX=',Q\$@RM+F[<_DQR#(Q]/C(,?AX]/*SL_C(.;?X>/)(,?AT]$N`-31S2#'
MX>/4W^')`,?-T-T@X^0@Q^'>Q\;CR0#%TN')(,?AR^3'QNT`VN;/R2#%X>P@
MQ^'.[<?1Q\H`Q^'/YM$`S=W9`,W=V2#'X<[MQ]''R@#(S<L`Q\[*T2#'X=WF
MQ]7A(.'ARL?1[<XZ`,?.RM$@RN33[=X@Q^'*Q]'MSCH`Q\[*T2#CX=T@X>W*
MXR#'T\KMT<?/Y3H`Q\[*T2#*Y-/MWB#%V>7'T2#'X</3X\?!.@#'SLK1(,KD
MT^W>(,?AYM[*.@#%SLK1(,W>X>WD(./*X\?+X>WD+@#'SLK1(,W>YN''\"#A
M[<KC(,79Y<?1Y<<@W>T@WL?&X\D@Q^':Y,?F[>0N`,?.RM$@RN33[=X@Q=GE
MQ]$@Q^'#T^/'P2X`Q<[*T2#AV\K?(,?AX]W6X<DZ`,/1T^$@RM[1[=''\"#(
MX]3?X<D@S=7AR@#%V>7'T2#'X=_A`,79Y<?1(,?AQ\K5Q^''R@#%V>7'T2#'
MX=[FQ\;C`,7EX^$@Q^'5[<?DR0#'RLS'Y2#'X=W1T@#%S\['T2#-T>;=(,['
MU<D`RN,@R.3,Q\T`WNWC(./=U>;AR2#(X]/'S<D`Q^'CY>/'R@#DU2#=WM@`
MX<?MYLS/(,_=RM$@VN3'YNWD(-['R.$@X>'*U=W-+@#-U>$@SMC#(,[AQ^$@
MQ>34Q\$@WL?&X\D@S,_MS\DN`,W5X2#.V,,@SN''X2#'X<W0W2X`[<S((,/D
M(.W?YN0@Y=#'(,?AT=[C(,/?R-$@X^0@Q^'5W=$`[<S((,/D(,K?YN0@Y=#E
M(,?AWNWCR2#1WN,N`,?AX=[(`-KDYL?D(,?AQ>3*T>3MR@#AQR#%X]_'Y.W)
M(.'*V^WMT2#'X=/CQ\WMQ\H@X>/AW2!61E,@)7,O)7,N`.''(,7CW\?D[<D@
MX>'%RM7'X2#(X\[/XR!344PN`,K:T-$@RLWC[>$@RMK1[=TZ("5S+@#AQR#%
MX]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N`.''(,KFS,\@Q>/?Q^3MR2#A
MRMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RX`V^W1(-['S]$@VN'L(,K1
MS./)(./3RN3/(,?AYM'/(.70QP#.[<?1Q\H@Q^'CT\K.S^,`Q]/C(,?AX]/*
MSL_C`-3?X2#'X<79Y<?1(,?AQ]W*T<?6[3H`RN3([>4`P]/(YMKMQ_``P^7A
MQR#(W^,@Q>'L("5S`,/EX<<@YM/EX<<@)7,`Y<?*W2#'X=KCX0#EQ\K=(,?A
MVN/A`-/DR2`M(-?7`-/DYNW'\`#DVN,`[<S((-31S2#'X>/4W^')(-[(X2#'
MT=/'X2#*WM'MT<?P(,CEQRX`[<S((,K-S^W/(,?*U<?A(.;'S<\@VN'L(,?A
MP][A+@#'Y,KERB#5X<?-[<D@Q^''RM7'X2`E<RX@Q^'1S,?!(,7:Q\_)(,?A
MS\[FX2X`R.W'Y,?*WSH`RN,@RLW/[<L@Q^'.[<?1Q\H`6\K>T>W1(,?AX]3?
MX<E=`%O'X=/8T2`E<R#CY"`E<UT`Q^''T^,`=D-A<F0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T=7)B82]L;V-A;&4O8V%?15,O````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`Q-S<U,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]C85]%4R],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-3,`,#(Q-3,W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O
M;&]C86QE+V-A7T53+TQ#7TU%4U-!1T53+W1U<F)A+FUO````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q-3<T,0`Q,#0Q-S,V,C<U,P`P,C,R,38`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````!U````'```
M`,0#``"=````;`<```````#@"0``*````.$)```=````"@H```@````H"@``
M!0```#$*```#````-PH```@````["@``!P```$0*```/````3`H```4```!<
M"@``'P```&(*```1````@@H```8```"4"@``"````)L*```5````I`H```H`
M``"Z"@``#````,4*```.````T@H```<```#A"@``*0```.D*```"````$PL`
M``4````6"P``$````!P+```&````+0L```\````T"P``%````$0+```O````
M60L```D```")"P``#P```),+```F````HPL```0```#*"P``!0```,\+```-
M````U0L```4```#C"P``$````.D+```0````^@L```\````+#```"P```!L,
M```/````)PP```P````W#```#P```$0,```&````5`P``!X```!;#```(0``
M`'H,```B````G`P```,```"_#```!````,,,```$````R`P```0```#-#```
M#````-(,```*````WPP```4```#J#```$@```/`,```0`````PT```@````4
M#0``!````!T-```0````(@T```8````S#0``!P```#H-```"````0@T```0`
M``!%#0``"````$H-```/````4PT```<```!C#0``!P```&L-```$````<PT`
M``4```!X#0``!0```'X-```'````A`T``!$```",#0``"````)X-```>````
MIPT```4```#&#0``*````,P-```I````]0T``!,````?#@``"P```#,.```1
M````/PX```0```!1#@``!````%8.```,````6PX```8```!H#@``&@```&\.
M```7````B@X``!H```"B#@``%P```+T.```;````U0X``#0```#Q#@``'P``
M`"8/```3````1@\``!````!:#P``%P```&L/```'````@P\```4```"+#P``
M(0```)$/```<````LP\```4```#0#P```P```-8/```@````V@\``"0```#[
M#P``)@```"`0```,````1Q````@```!4$```!P```%T0```&````91````T`
M``!L$```"P```'H0```,````AA````H```"3$````@```)X0```&````H1``
M`$4```"H$```,````.X0```0````'Q$``!\````P$0``$````%`1```/````
M81$``%T!``!Q$0``*@```,\2```N````^A(```@````I$P``!0```#(3```&
M````.!,```T````_$P``!@```$T3```.````5!,```4```!C$P``(P```&D3
M```2````C1,```@```"@$P``"0```*D3```2````LQ,``!$```#&$P``#P``
M`-@3```5````Z!,```D```#^$P``,`````@4```"````.10```H````\%```
M&````$<4```(````8!0``!4```!I%```%P```'\4```W````EQ0```D```#/
M%```&````-D4```H````\A0```8````;%0``!0```"(5```.````*!4```4`
M```W%0``#@```#T5```.````3!4```T```!;%0``%````&D5```/````?A4`
M``H```".%0``$@```)D5```(````K!4``"4```"U%0``*0```-L5```G````
M!18```,````M%@``!@```#$6```"````.!8```4````[%@``#P```$$6```0
M````418```4```!B%@``$0```&@6```0````>A8```8```"+%@``!P```)(6
M```5````FA8```8```"P%@``$````+<6```"````R!8```8```#+%@``$P``
M`-(6```3````YA8```@```#Z%@``"P````,7```#````#Q<```,````3%P``
M!0```!<7```'````'1<``!`````E%P``"P```#87```C````0A<```<```!F
M%P``+P```&X7```]````GA<``!<```#<%P``#0```/07```0`````A@```8`
M```3&```!0```!H8```-````(!@```8````N&```)@```#48```A````7!@`
M`"<```!^&```(````*88```G````QQ@``$,```#O&```)@```#,9```.````
M6AD``!(```!I&0``'@```'P9```$````FQD```8```"@&0``*0```*<9```A
M````T1D```4```#S&0```P```/D9```J````_1D``"<````H&@``+@```%`:
M```0````?QH```8```"0&@``!````)<:```,````G!H```\```"I&@``#0``
M`+D:```.````QQH```\```#6&@```@```.8:```)````Z1H``$,```#S&@``
M1P```#<;```4````?QL``"0```"4&P``%@```+D;```0````T!L```$```!A
M````0`````````!T````9````#H```!I````/@`````````.````-0```#<`
M```[````$0````0`````````3````$$`````````1P```!``````````=0``
M`"0```!1```````````````A````0P```!@````*````<P```"H`````````
M!P````(```!0````$@```#D```!P````20`````````M`````````&@```!O
M````+P```%P````+``````````````!5````/````#0```!=````1````!4`
M````````:P```!H````P````8`````````!3````+````#T```!6````;```
M``@````X`````````#8`````````8@```%(``````````````$L```!C````
M`````&T```!"`````````"(`````````)P```!T````K````6@`````````I
M````7@`````````-`````````&8`````````#P```'(```!N````/P```!\`
M```6````````````````````)@```$@```!8````5P```````````````P``
M`!X```!J````%````&<`````````<0````P````S`````````$4````N````
M,@```%L````9````!@```$T````Q````5````"4```!?``````````````!*
M````'``````````%````"0```!,`````````1@```%D`````````%P``````
M``!.````&P```$\````H````(````&4````C````````````````)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!F:6QE('-U
M8V-E<W-F=6QL>2!I;7!O<G1E9``R-"!H;W5R<P!!32]030!!9&0`061D('!A
M:7(`061D<F5S<P!!9'9A;F-E9"!396%R8V@`06QI87,`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!=F%I;&%B;&4@9FEE;&1S.@!"<F]W<V4`
M0V%L96YD87(`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-E;&P@4&AO;F4`0VQO
M<V4@5VEN9&]W`$-O;'5M;B!/<'1I;VYS`$-O;7!A;GD`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&5F875L
M="!)9&5N=&ET>0!$96QE=&4`1&5L971I;VX@9F%I;&5D`$1E<V-R:6)E('1H
M92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$1I<F5C=&]R>0!$:7-P;&%Y($]P=&EO;G,`1&\@;F]T
M(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``161I=`!%;6%I;`!%
M;7!T>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@
M<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L
M9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AP;W)T`$9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O('-E87)C:"!T:&4@9&ER96-T
M;W)Y.B`E<P!&87@`1FEN9`!&<F]M`$AE;'``2&]M92!!9&1R97-S`$AO;64@
M4&AO;F4`2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD
M<SH`3&%N9W5A9V4`3&ES=`!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@
M;W5T`$U-`$UA:6P`36%T8VAI;F<`36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`
M36]N=&AL>0!.86UE`$YE=F5R`$YO=&5S`$]P=&EO;G,`3W1H97(@26YF;W)M
M871I;VX`4&%S<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS
M`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4')O8FQE;2!$97-C<FEP=&EO;@!296UO=F4@<&%I<@!2971U<FX@=&\@3W!T
M:6]N<P!2;VQE`%-A=F4`4V%V92!/<'1I;VYS`%-E87)C:`!396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE
M8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('=H:6-H(&9I
M96QD<R!T;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+@!396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`
M4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C
M97-S`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%523`!5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;&]A9"!T:&4@
M9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`57-E<B!/<'1I;VYS`%5S97)N86UE`%=A<FYI;F<`5V5E
M:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O
M<FL@4&AO;F4`65D`665A<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`%!R;VIE
M8W0M260M5F5R<VEO;CH@5'5R8F$@,2XQ"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP,BTQ
M."`P.3HS.2LP,3`P"DQA<W0M5')A;G-L871O<CH@06YG96QS($=U:6UE<N`@
M/$%N9V5L<RY'=6EM97)A0'5A8BYE<SX*3&%N9W5A9V4M5&5A;3H@0V%T86QA
M;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`3W!E<F%C:6]N<R!D92!-
M86YT96YI;65N="`E<R`M($-O;F9I<FUA8VGS`$PG87)X:74@)7,@:&$@97-T
M870@:6UP;W)T870@<V%T:7-F86-T\G)I86UE;G0`,C0@:&]R97,`04TO4$T`
M069E9VER`$%F96=I<B!P87)E;&P`061R9>=A`$-E<F-A($%V86[G861A`,!L
M:65S`%,G:&$@97-P96-I9FEC870@=6X@=F%L;W(@:6RW;&5G86PN`$-A;7!S
M(&1I<W!O;FEB;&5S.@!%>&%M:6YA<@!#86QE;F1A<FD`0V%N8V5LMVQA<B!)
M;F9O<FUE`%1E;.AF;VX@0V5LMVQU;&%R`%1A;F-A<B!&:6YE<W1R80!/<&-I
M;VYS(&1E(&QA($-O;'5M;F$`0V]M<&%N>6EA`$YO(',G:&$@<&]G=70@;V)R
M:7(@96P@;?)D=6P@)7,@36%I;G1E;F%N8V5?5&%S:P!$1`!$:>!R:6%M96YT
M`$ED96YT:71A="!0<F5D971E<FUI;F%D80!%;&EM:6YA<@!(82!F86QL870@
M86P@96QI;6EN87(`1&5S8W)I<&-I\R!D96P@4')O8FQE;6$`16QS(&1E=&%L
M;',@:&%N(&5S=&%T(')E9VES=')A=',@<&5R(&$@;"=A9&UI;FES=')A9&]R
M+@!$:7)E8W1O<FD`3W!C:6]N<R!D92!6:7-U86QI='IA8VGS`$YO(&%C8V5D
M:74@9&ER96-T86UE;G0@82!M86EN=&5N86YC92YP:'``161I=&%R`$5M86EL
M`%)E<W5L=&%T(&)U:70N`$5R<F]R`$-A9&$@,34@;6EN=71S`$-A9&$@,S`@
M<V5G;VYS`$-A9&$@-2!M:6YU=',`0V%D82!);FEC:2!D92!397-S:?,`0V%D
M82!M:71J82!H;W)A`$-A9&$@;6EN=70`17AE;7!L92!D92!V86QO<G,Z`$5X
M<&]R=&%R`$5R<F%D82!A;"!R96-U<&5R87(@;&5S('!R969E<NAN8VEE<RX`
M17)R861A(&%L(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED;W(@3$1!4"X`2&$@
M9F%L;&%T(&%L(&-E<F-A<B!E;B!E;"!D:7)E8W1O<FDZ("5S`$9A>`!4<F]B
M87(`1&4`06IU9&$`061R9>=A(%!E<G-O;F%L`%1E;.AF;VX@4&5R<V]N86P`
M2&]R9&4`0V%M<"!I;7!O<G1A=#H@)7,`0V%M<',@:6UP;W)T871S.@!)9&EO
M;6$`3&QI<W1A<@!,;&ES=&%R(%1E;65S(&0G06IU9&$`16YT<F%R`%-O<G1I
M<B!D92!S97-S:?,`34T`0V]R<F5U`'%U92!C;VEN8VED96EX:2!A;6(`0V%M
M<',@0V]R<F5S<&]N96YT<P!-:7-S871G90!-96YS=6%L;65N=`!.;VT`36%I
M`$YO=&5S`$]P8VEO;G,`06QT<F$@26YF;W)M86-I\P!#;VYT<F%S96YY80!2
M96%L:71Z87(@3W!E<F%C:6]N<R!D92!-86YT96YI;65N=`!496SH9F]N`%-I
M('5S('!L874L('!R;W!O<F-I;VYE=2!U;B!R97-U;2!D96P@<')O8FQE;6$N
M`%-I('5S('!L874L('!R;W!O<F-I;VYE=2!E;"!V;W-T<F4@;F]M(&0G=7-U
M87)I(&D@8V]N=')A<V5N>6$`1&5S8W)I<&-I\R!D96P@4')O8FQE;6$`5')E
M=7)E('!A<F5L;`!4;W)N87(@82!/<&-I;VYS`$9U;F-I\P!$97-A<@!$97-A
M<B!/<&-I;VYS`$-E<F-A<@!396QE8V-I;VYE=2!E;"!D96QI;6ET861O<B!D
M92!L82!D871A.@!396QE8V-I;VYE=2!E;"!F;W)M870@9&4@;&$@9&%T83H`
M4V5L96-C:6]N974@;"=A<GAI=2!Q=64@=F]L974@:6UP;W)T87(Z`%-E;&5C
M8VEO;F5U(&5L(&9O<FUA="!D92!L)VAO<F$Z`%-E;&5C8VEO;F5U(&1O<R!C
M86UP<R!Q=64@8V]I;F-I9&5I>&EN+@!396QE8V-I;VYE=2!Q=6EN<R!C86UP
M<R!V;VQE=2!V:7-U86QI='IA<B!E;B!L97,@;&QI<W1E<R!D)V%D<F5C97,N
M`%-E;&5C8VEO;F5U(&5L('9O<W1R92!I9&EO;6$@<')E9F5R:70Z`$5N=FEA
M<B!);F9O<FUE`$]M:71I<B!-86YT96YI;65N=`!%;G1R861A(&1E($-A<N!C
M=&5R<R!%<W!E8VEA;',`R'AI=`!&96EN97,`07%U97-T(&[Z;65R;R!H82!D
M92!S97(@8V]M(&$@;>UN:6T@=6X@,2X`07%U97-T('9A;&]R(&AA(&1E('-E
M<B!U;B!N^FUE<F\N`%3M=&]L`%523`!);F-A<&'G(&1E(&-O;FYE8W1A<G-E
M(&%L('-E<G9I9&]R(&1E(%-13"X`26YC87!AYR!D92!C87)R96=A<B!L82!D
M969I;FEC:?,@9&4@)7,N`$YO(.ES('!O<W-I8FQE('1R861U:7(@87%U97-T
M(&1O8W5M96YT(&1E(%=O<F0`3W!C:6]N<R!D)U5S=6%R:0!5<W5A<FD`07;M
M<P!3971M86YA;&UE;G0`0F5N=FEN9W5T<R!A("5S`$)E;G9I;F=U="P@)7,`
M061R9>=A($QA8F]R86P`5&5LZ&9O;B!,86)O<F%L`$%!`$%N=6%L;65N=`!(
M974@9&4@9&5S8W)I=7)E(&5L('!R;V)L96UA(&%B86YS(&0G96YV:6%R(&PG
M:6YF;W)M92!D96P@<')O8FQE;6$N`$QA('9O<W1R82!S97-S:?,@96X@)7,@
M:&$@97AP:7)A="X@4VD@=7,@<&QA=2P@:6YI8VEE=2!U;F$@;F]V82!S97-S
M:?,N`$QA('9O<W1R82!);F9O<FUA8VGS`$QE<R!O<&-I;VYS(&AA;B!E<W1A
M="!A8W1U86QI='IA9&5S+@!;26YF;W)M92!D96P@4')O8FQE;6%=`%ML[6YI
M82`E<R!D92`E<UT``````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+V1A7T1++P``
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<U,P`P,3<W-#(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B
M82]L;V-A;&4O9&%?1$LO3$-?34534T%'15,O````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4S`#`R,34R-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]D85]$2R],0U]-15-304=%4R]T
M=7)B82YM;P``````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30T,#,`,3`T,3<S-C(W-3,`
M,#(S,C`P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-X2!)4`````:@```!P```!L`P``E0```+P&````````$`D``"@````1
M"0``'0```#H)```(````6`D```4```!A"0```P```&<)```/````:PD```@`
M``!["0``"````(0)```9````C0D```<```"G"0``#@```*\)```/````O@D`
M``4```#."0``$0```-0)```(````Y@D``!4```#O"0``"@````4*```,````
M$`H```<````="@``$````"4*```I````-@H```(```!@"@``!0```&,*```0
M````:0H```8```!Z"@``#P```($*```4````D0H```D```"F"@``)@```+`*
M```$````UPH```4```#<"@``#0```.(*```%````\`H```L```#V"@``#P``
M``(+```&````$@L``"$````9"P``(@```#L+```#````7@L```P```!B"P``
M!````&\+```$````=`L```0```!Y"P``#````'X+```*````BPL```4```"6
M"P``$@```)P+```0````KPL``!````#`"P``&@```-$+```&````[`L```<`
M``#S"P```@```/L+```$````_@L```@````##```#P````P,```'````'`P`
M``<````D#```!````"P,```'````,0P```0````Y#```!0```#X,```(````
M1`P``!4```!-#```'@```&,,```%````@@P``"@```"(#```*0```+$,```3
M````VPP```L```#O#```!0```/L,```1`````0T```0````3#0``!````!@-
M```,````'0T```8````J#0``&@```#$-```7````3`T``!H```!D#0``%P``
M`'\-```;````EPT``!,```"S#0``$````,<-```7````V`T```<```#P#0``
M!0```/@-```%````_@T```,````$#@``(`````@.```D````*0X``"8```!.
M#@``"````'4.```4````?@X```<```"3#@``!@```)L.```+````H@X```P`
M``"N#@``"@```+L.```"````Q@X```8```#)#@``10```-`.```F````%@\`
M`"4````]#P``<P```&,/```0````UP\``&T!``#H#P``(````%81```;````
M=Q$```@```"3$0``!0```)P1```&````HA$``!4```"I$0``"0```+\1```,
M````R1$``"(```#6$0``!P```/D1```.`````1(```\````0$@``"0```"`2
M```4````*A(```@````_$@``'0```$@2```%````9A(```H```!L$@``!0``
M`'<2```/````?1(``"P```"-$@```@```+H2```&````O1(``!(```#$$@``
M!````-<2```4````W!(``!$```#Q$@``!P````,3```H````"Q,```<````T
M$P``!0```#P3```/````0A,```0```!2$P``#P```%<3```0````9Q,```D`
M``!X$P``+````((3```?````KQ,```,```#/$P``#0```-,3```$````X1,`
M``,```#F$P``!0```.H3```0````\!,``!`````!%```!0```!(4```6````
M&!0``!,````O%```&0```$,4```@````710```<```!^%```!@```(84```"
M````C10```0```"0%```!P```)44```6````G10```H```"T%```"````+\4
M```$````R!0```<```#-%```!P```-44```%````W10```<```#C%```&0``
M`.L4```5````!14```<````;%0``.@```",5```F````7A4``!(```"%%0``
M"````)@5```'````H14``!L```"I%0``!0```,45```#````RQ4``!,```#/
M%0```P```.,5```6````YQ4``!````#^%0``'P````\6```0````+Q8``"@`
M``!`%@``%P```&D6```;````@18``!\```"=%@``"````+T6```'````QA8`
M``4```#.%@```P```-06```K````V!8``"0````$%P``*````"D7```*````
M4A<``!,```!=%P``"````'$7```(````>A<```T```"#%P``$0```)$7```1
M````HQ<```(```"U%P``!0```+@7``!*````OA<``"\````)&```,````#D8
M``"#````:A@``!0```#N&````0```$L````Z````/0```$P````.````1P``
M````````````&@```"\````Q````3@````8`````````$P```&$````%````
M6````"T```!=```````````````L````*@```!````!0````)````!4```!J
M```````````````A````:`````H```!/`````````&`````\````5````$,`
M````````$@```"(````^`````````#D`````````4P````````!D````````
M`&4```!9`````````&(`````````&``````````4````````````````````
M(P```%4```!$`````````"4````X``````````D`````````2````"@`````
M````1@```%8`````````)P``````````````!P`````````P````6@``````
M```#````$0```%$````"`````````&8```!-`````````%X````(````````
M`!L```!!````.P```!\````6````-@```#4````-````#````!D```!?````
M20````0````_````,@```$H````7````4@```%<`````````+@```&<```!%
M````'````"L```````````````\```!"````'@```$``````````:0````L`
M``!<`````````!T````T````*0````````````````````````!;````(```
M`````````````````"8```!C````,P```#<`````)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!F:6QE('-U8V-E<W-F=6QL
M>2!I;7!O<G1E9``R-"!H;W5R<P!!32]030!!9&0`061D(&$@;F5W('5S97(Z
M`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D<F5S<P!!9&UI;FES=')A=&EO;@!!9'9A;F-E9"!396%R8V@`06QI87,`
M079A:6QA8FQE(&9I96QD<SH`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@4F5P
M;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]N9FER;2!0
M87-S=V]R9`!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!$1`!$86EL>0!$969A=6QT($ED96YT:71Y`$1E;&5T90!$96QE=&EO
M;B!F86EL960`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&ER96-T;W)Y`$1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5D:70`16UA:6P`
M16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2!,;V=I;@!%>&%M<&QE('9A;'5E
M<SH`17AP;W)T`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&
M86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S`$9A>`!&:6QE($UA
M;F%G97(`1FEN9`!&<F]M`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&ES
M="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@
M:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG`$UA=&-H:6YG(&9I96QD<P!-
M97-S86=E`$UO;G1H;'D`3F%M90!.971W;W)K`$YE=W,`3F]T97,`4&%S<W=O
M<F0`4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5S
M970`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E`%-A=F4@3W!T:6]N<P!3
M96%R8V@`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D
M871E(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;F0@4')O8FQE;2!297!O<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1A<VMS`%1I=&QE`%523`!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`57-E<FYA;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`
M5V%R;FEN9P!7965K;'D`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`65D`665A<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BX`6U!R;V)L96T@4F5P;W)T70!0<F]J96-T+4ED+59E<G-I;VXZ
M(%1U<F)A(#(N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`Q+3`V(#$S.C`T*S`Q
M,#`*3&%S="U4<F%N<VQA=&]R.B!-87)T:6X@3&ES="U0971E<G-E;B`\;6%R
M=&EN0&QI<W0M<&5T97)S96XN9&L^"DQA;F=U86=E+51E86TZ($1A;FES:"`\
M9&LM:&]R9&5`:'5L<'-Y<W1E;7,N;F5T/@I-24U%+59E<G-I;VXZ(#$N,`I#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`E<R!6961L:6=E:&]L
M9&5L<V4@+2!"96MRYF9T96QS90!);7!O<G0@868@)7,@9FEL96X@;'EK:V5D
M97,`,C0@=&EM97(`04TO4$T`5&EL9OAJ`$]P<F5T=&4@96X@;GD@8G)U9V5R
M.@!/<')E="!P87(`3W!R970@8G)U9V5R`$]P<F5T=&5L<V4@868@8G)U9V5R
M92!E<B!S;.5E="!F<F$`061R97-S90!!9&UI;FES=')A=&EO;@!59'9I9&5T
M('/X9VYI;F<`2V%L9&5N879N`$9E;'1E<B!T:6P@<N5D:6=H960Z`$MA;&5N
M9&5R`$%F8G)Y9"!R97!O<G1E<FEN9R!A9B!P<F]B;&5M`$UO8FEL`$QU:R!V
M:6YD=64`1FER;6$`0F5K<N9F="!K;V1E;W)D`$MU;FYE(&EK:V4@Y6)N92!M
M;V1U;"!T:6P@=F5D;&EG96AO;&1E;'-E("5S`$1$`$1A9VQI9P!3=&%N9&%R
M9"UI9&5N=&ET970`4VQE=`!3;&5T;FEN9R!M:7-L>6MK961E<P!"97-K<FEV
M('!R;V)L96UE=`!+871A;&]G`$1U(&WE(&EK:V4@:V%L9&4@;6%I;G1E;F%N
M8V4N<&AP(&1I<F5K=&4`4F5D:6=E<@!E36%I;`!);G1E="!R97-U;'1A="X`
M1F5J;`!!;'1I9"!V960@;&]G:6X`16MS96UP96QVYG)D:65R.@!%:W-P;W)T
M97(`2W5N;F4@:6MK92!FY2!F;W)B:6YD96QS92!T:6P@3$1!4"!S97)V97)E
M;BX`2W5N;F4@:6MK92!S^&=E(&D@:V%T86QO9V5T.B`E<P!&87@`1FEL:.5N
M9'1E<FEN9P!&:6YD`$9R80!(:N9L<`!!9')E<W-E("AH:F5M;64I`%1E;&5F
M;VX@*&AJ96UM92D`2&]R9&4`26UP;W)T97)E9&4@9F5L=&5R.B`E<P!);7!O
M<G1E<F5D92!F96QT97(Z`$]P;&ES=&YI;F<@868@:&KF;'!E96UN97(`5FES
M;FEN9R!A9B!B<G5G97)E(&5R('-LY65T(&9R82X`3&]G(&EN9`!,;V<@=60`
M34T`36%I;`!-871C:&5R`$]V97)E;G-P87-S96YD92!F96QT97(`365D9&5L
M96QS90!-Y6YE9&QI9P!.879N`$YE=';F<FL`3GEH961E<@!.;W1E<@!+;V1E
M;W)D`$MO9&5O<F1E;F4@<VMA;"!VYG)E(&5N<RX`561F^'(@=F5D;&EG96AO
M;&1E;'-E`%1E;&5F;VX`4VMR:78@=F5N;&EG<W0L(&AV860@<')O8FQE;65T
M(&?E<B!U9"!PY2!O9R!H=F%D(&1E<B!S:V5R+@!);F1T87-T('9E;FQI9W-T
M(&)R=6=E<FYA=FX@;V<@:V]D96]R9`!0<F]B;&5M8F5S:W)I=F5L<V4`4VQE
M="!P87(`3G5L<W1I;`!4:6QB86=E('1I;"!I;F1S=&EL;&EN9V5R;F4`4F5G
M96P`1V5M`$=E;6UE($EN9'-T:6QL:6YG97(`4_AG`%;F;&<@9&%T;RUA9'-K
M:6QL97)E;CH`5N9L9R!D871O9F]R;6%T.@!6YFQG(&9I;&5N('-O;2!S:V%L
M(&EM<&]R=&5R97,Z`%;F;&<@=&ED<V9O<FUA=#H`5N9L9R!T;R!F96QT97(L
M(&1E<B!S=F%R97(@=&EL(&AI;F%N9&5N+@!396YD('!R;V)L96UB97-K<FEV
M96QS90!3<')I;F<@=F5D;&EG96AO;&1E;'-E(&]V97(`26YD=&%S=&YI;F<@
M9F]R('-P96-I86QK87)A:W1E<@!,>6MK961E<P!/<&=A=F5R`%1I=&5L`%52
M3`!+=6YN92!I:VME(&;E(&9O<F)I;F1E;'-E('1I;"!344P@<V5R=F5R96XN
M`$MA;B!I:VME(&EN9&SF<V4@9&5F:6YI=&EO;F5N(&%F("5S+@!+=6YN92!I
M:VME(&]V97)SYG1T92!D971T92!7;W)D(&1O:W5M96YT`$)R=6=E<FYA=FX`
M0G)U9V5R92!I('-Y<W1E;65T.@!!9'9A<G-E;`!59V5N=&QI9P!696QK;VUM
M96XL("5S`$%D<F5S<V4@*&%R8F5J9&4I`%1E;&5F;VX@*&%R8F5J9&4I`,7%
M`,5R;&EG`$1U(&)L:79E<B!N^&0@=&EL(&%T(&QA=F4@96X@<')O8FQE;6)E
M<VMR:79E;'-E+"!F^'(@9'4@:V%N('-E;F1E(&1E;B!I;F0N`$1U('-K86P@
M86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!F:F5R;F4N`$1U('-K
M86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!T:6QF^&IE+@!$
M:6X@875T;W)I<V%T:6]N<RUB86-K96YD('5N9&5R<W3X='1E<B!I:VME(&]P
M;&ES=&YI;F=E;B!A9B!B<G5G97)E(&5L;&5R(&5R(&1E;B!F=6YK=&EO;B!A
M9B!E;B!E;&QE<B!A;F1E;B!G<G5N9"!B;&5V970@<VSE970@9G)A+@!;4')O
M8FQE;6)E<VMR:79E;'-E70``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O9&5?1$4O
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4S`#`Q-S<T,``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U
M<F)A+VQO8V%L92]D95]$12],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-3,`,#(Q-3(U`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+V1E7T1%+TQ#7TU%4U-!1T53
M+W1U<F)A+FUO```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#4P,#<P,0`Q,#0Q-S,V,C<U
M,P`P,C,Q-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````"0"```'````)Q$``!O"P``'(D```````#8M@``#@``
M`-FV```/````Z+8```T```#XM@``"`````:W```+````#[<```P````;MP``
M&0```"BW```9````0K<```0```!<MP``*0```&&W```8````B[<``!L```"D
MMP``+0```,"W```=````[K<``"0````,N```*0```#&X```I````6[@``!D`
M``"%N```*````)^X```D````R+@``"4```#MN```)@```!.Y```,````.KD`
M`"0```!'N0``#P```&RY```+````?+D```X```"(N0``!0```)>Y```H````
MG;D```@```#&N0``"@```,^Y```5````VKD```D```#PN0``$@```/JY```+
M````#;H``!T````9N@``A0```#>Z```.````O;H```H```#,N@``#0```->Z
M```.````Y;H``!$```#TN@``#0````:[```,````%+L```T````ANP``!@``
M`"^[``"4````-KL```H```#+NP``#P```-:[```8````YKL```P```#_NP``
M#@````R\```.````&[P```@````JO```"0```#.\```K````/;P``"X```!I
MO```&@```)B\```R````L[P``#@```#FO```5````!^]``!1````=+T``%H`
M``#&O0``5P```"&^```T````>;X```D```"NO@``#0```+B^```'````QKX`
M``H```#.O@``#P```-F^```%````Z;X```8```#OO@``$0```/:^```(````
M"+\``!$````1OP``"0```"._```)````+;\``"4````WOP``(````%V_```3
M````?K\``!,```"2OP``$````*:_```/````M[\```H```#'OP```P```-*_
M```/````UK\``!0```#FOP``"0```/N_```-````!<```!(````3P```&0``
M`";````>````0,````\```!?P```$````&_````A````@,````H```"BP```
M"````*W````/````ML````@```#&P```)````,_````&````],```!0```#[
MP```%@```!#!```(````)\$``$X````PP0``+0```'_!```A````K<$``!D`
M``#/P0``!P```.G!```,````\<$``!0```#^P0``#0```!/"```2````(<(`
M`"$````TP@``%P```%;"```I````;L(``"P```"8P@``#@```,7"```#````
MU,(```\```#8P@``"P```.C"```'````],(```<```#\P@``!0````3#```%
M````"L,```H````0PP```P```!O#```7````'\,```H````WPP``#P```$+#
M```.````4L,``!@```!APP``(P```'K#```.````GL,```X```"MPP``%```
M`+S#```7````T<,``!<```#IPP``%P````'$```3````&<0```\````MQ```
M#@```#W$```?````3,0``!T```!LQ```!P```(K$```&````DL0```@```"9
MQ```#P```*+$```&````LL0```H```"YQ```$P```,3$```+````V,0``!``
M``#DQ```%0```/7$```5````"\4```<````AQ0``$````"G%```%````.L4`
M`!4```!`Q0``$0```%;%```,````:,4``"@```!UQ0``.@```)[%```[````
MV<4``#@````5Q@``"0```$[&```'````6,8``!0```!@Q@```P```'7&```%
M````><8```D```!_Q@``$````(G&```)````FL8``!,```"DQ@``.0```+C&
M```2````\L8``"<````%QP``+````"W'```J````6L<``"4```"%QP``"@``
M`*O'```&````ML<```D```"]QP``!P```,?'```O````S\<``#<```#_QP``
M+@```#?(``!5````9L@``"T```"\R```+0```.K(```]````&,D``#\```!6
MR0``+0```);)``!`````Q,D``",````%R@``(P```"G*``!`````3<H``"T`
M``".R@``,P```+S*```E````\,H``!4````6RP``&0```"S+```I````1LL`
M`"0```!PRP``*````)7+```1````OLL```H```#0RP``#````-O+```*````
MZ,L``!````#SRP``%@````3,```6````&\P```<````RS```!P```#K,```4
M````0LP```H```!7S```"````&+,```G````:\P```@```"3S```#````)S,
M```'````J<P```<```"QS```!@```+G,```1````P,P```4```#2S```!P``
M`-C,```&````X,P``!0```#GS```"````/S,```I````!<T```X````OS0``
M"@```#[-```$````2<T```<```!.S0``"0```%;-```&````8,T``!$```!G
MS0``!P```'G-```6````@<T```0```"8S0``"````)W-```&````ILT```T`
M``"MS0``!@```+O-```>````PLT```8```#AS0``$0```.C-```(````^LT`
M``T````#S@``#````!'.```'````'LX``!$````FS@```P```#C.```#````
M/,X``!<```!`S@```P```%C.```3````7,X``!T```!PS@``"````([.```$
M````E\X```@```"<S@``"````*7.``!!````KLX``!H```#PS@``'`````O/
M```K````*,\``"````!4SP``%0```'7/```&````B\\```8```"2SP``%0``
M`)G/```8````K\\``"(```#(SP``+@```.O/```=````&M```"$````XT```
M5````%K0```I````K]````H```#9T```!P```.30```'````[-```!4```#T
MT```#@````K1```*````&=$```\````DT0``#0```#31```/````0M$```T`
M``!2T0``"0```&#1```4````:M$```8```!_T0``&````(;1```=````G]$`
M`!,```"]T0``$0```-'1```4````X]$```0```#XT0``!@```/W1```4````
M!-(``%0````9T@``9````&[2```$````T](```X```#8T@``#P```.?2```%
M````]](```4```#]T@``&P````/3```:````'],``!,````ZTP``#0```$[3
M```1````7-,``!$```!NTP``%@```(#3```7````E],``!P```"OTP``*@``
M`,S3```Y````]],``"(````QU```,@```%34```0````A]0``"$```"8U```
M!0```+K4```3````P-0```L```#4U```$@```.#4```*````\]0```\```#^
MU```#0````[5```1````'-4``!,````NU0``#````$+5```&````3]4```P`
M``!6U0``!@```&/5```7````:M4``!````""U0``$0```)/5```(````I=4`
M``4```"NU0``#````+35```0````P=4```4```#2U0``#@```-C5```-````
MY]4``",```#UU0``!@```!G6```6````(-8``"H````WU@``!P```&+6```-
M````:M8```<```!XU@``"P```(#6```'````C-8```<```"4U@``#P```)S6
M```)````K-8```D```"VU@``"@```,#6```9````R]8``#T```#EU@``'0``
M`"/7```,````0=<``!````!.UP``!0```%_7```E````9=<``!(```"+UP``
M$P```)[7```5````LM<``!(```#(UP``*P```-O7```[````!]@``"````!#
MV```#@```&38```(````<]@``!0```!\V```-@```)'8```A````R-@``!``
M``#JV```"````/O8```,````!-D```8````1V0``!````!C9```/````'=D`
M``X````MV0``!P```#S9```*````1-D```T```!/V0``'P```%W9```<````
M?=D``"$```":V0``'@```+S9```9````V]D``!X```#UV0``&P```!3:```A
M````,-H``"X```!2V@``)@```(':```<````J-H``!X```#%V@``'````.3:
M```F`````=L``"L````HVP``,P```%3;```F````B-L``"L```"OVP``.```
M`-O;```=````%-P``!4````RW```+P```$C<```@````>-P``!(```"9W```
M*0```*S<```>````UMP``"````#UW```$@```!;=``"B````*=T``!8```#,
MW0``(P```./=```H````!]X``"D````PW@``*````%K>```?````@]X``!4`
M``"CW@``(````+G>```E````VMX``"@`````WP``+0```"G?```P````5]\`
M`)(```"(WP``(0```!O@```6````/>```!P```!4X```)@```''@```J````
MF.```$$```##X```1`````7A```,````2N$```<```!7X0``!P```%_A```&
M````9^$``!,```!NX0``#0```(+A```=````D.$``!````"NX0``$@```+_A
M```'````TN$``!,```#:X0``$@```.[A```'`````>(```0````)X@``$```
M``[B```0````'^(```P````PX@``#@```#WB```-````3.(```\```!:X@``
M$P```&KB```-````?N(``"@```",X@```P```+7B```-````N>(```8```#'
MX@``$0```,[B```7````X.(``!L```#XX@``#@```!3C```"````(^,``$D`
M```FXP``!0```'#C```0````=N,```\```"'XP``!````)?C```-````G.,`
M``X```"JXP```P```+GC```.````O>,```@```#,XP``#P```-7C```/````
MY>,```<```#UXP``#0```/WC```0````"^0```T````<Y```&@```"KD```+
M````1>0```8```!1Y```$P```%CD```+````;.0``!,```!XY```#````(SD
M```*````F>0``!$```"DY```&0```+;D```7````T.0```L```#HY```#0``
M`/3D```B`````N4``!8````EY0``#P```#SE```;````3.4``#0```!HY0``
M"@```)WE```8````J.4``!(```#!Y0``&0```-3E```6````[N4``"(````%
MY@``(P```"CF```/````3.8```T```!<Y@``!P```&KF```*````<N8```H`
M``!]Y@``%````(CF```+````G>8``"(```"IY@``+P```,SF```+````_.8`
M``D````(YP``&0```!+G```+````+.<``!<````XYP``%P```%#G```)````
M:.<```<```!RYP``%@```'KG```/````D><``!D```"AYP``%@```+OG```.
M````TN<``!@```#AYP``"````/KG```-`````^@``"8````1Z```*````#CH
M``!#````8>@```@```"EZ```$@```*[H```?````P>@```@```#AZ```"P``
M`.KH```O````]N@```X````FZ0``#@```#7I```%````1.D```8```!*Z0``
M10```%'I```#````E^D```<```";Z0``!````*/I```)````J.D``!(```"R
MZ0``"@```,7I```*````T.D```\```#;Z0``$````.OI```7````_.D``!$`
M```4Z@``$0```";J```9````..H``!<```!2Z@``"0```&KJ```%````=.H`
M``L```!ZZ@``"@```(;J```"````D>H```4```"4Z@``#0```)KJ```;````
MJ.H``!<```#$Z@``%````-SJ```)````\>H```X```#[Z@``#0````KK```2
M````&.L``#@````KZP``(````&3K```(````A>L```X```".ZP``>P```)WK
M```8````&>P``!@````R[```/0```$OL```5````B>P``!$```"?[```!P``
M`+'L```%````N>P``",```"_[```,P```./L```8````%^T``!T````P[0``
M+@```$[M```>````?>T``!L```"<[0``&0```+CM```G````TNT``#<```#Z
M[0``)````#+N```;````5^X``!D```!S[@``$P```(WN```'````H>X```@`
M``"I[@``!@```++N```&````N>X``!````#`[@``#P```-'N```0````X>X`
M``\```#R[@``"P````+O```/````#N\```P````>[P``#P```"OO```'````
M.^\```8```!#[P``#@```$KO```,````6>\``"@```!F[P``#P```(_O```(
M````G^\```8```"H[P``$P```*_O```B````P^\``"T```#F[P``"````!3P
M```3````'?```!X````Q\```)0```%#P```:````=O```!4```"1\```'@``
M`*?P``!#````QO```"$````*\0``(````"SQ```9````3?$``!<```!G\0``
M)0```'_Q```E````I?$``!<```#+\0``%@```./Q```A````^O$``"(````<
M\@``!````#_R```;````1/(```T```!@\@``#````&[R```#````>_(```4`
M``!_\@``"````(7R```*````CO(```P```"9\@``"P```*;R```0````LO(`
M``P```##\@``#@```-#R```+````W_(```0```#K\@``!````/#R```3````
M]?(``!0````)\P``#````![S```)````*_,```X````U\P``"P```$3S```;
M````4/,```4```!L\P``!P```'+S```$````>O,```8```!_\P``!P```(;S
M```*````CO,```H```"9\P``#0```*3S```)````LO,```0```"\\P``!0``
M`,'S```#````Q_,``!@```#+\P``"@```.3S```$````[_,``"8```#T\P``
M#@```!OT``!\````*O0``!4```"G]```!0```+WT```'````P_0```P```#+
M]```"````-CT```*````X?0```8```#L]```"````//T```"````_/0```8`
M``#_]```!@````;U```4````#?4```P````B]0``#0```"_U```0````/?4`
M`!L```!.]0``!````&KU```)````;_4``!````!Y]0``"0```(KU```)````
ME/4```4```">]0``&@```*3U```(````O_4```8```#(]0``&0```,_U```.
M````Z?4```<```#X]0``!P````#V```%````"/8```D````.]@``"@```!CV
M```3````(_8```X````W]@```@```$;V```&````2?8```L```!0]@``#0``
M`%SV```)````:O8```8```!T]@``$@```'OV```)````CO8```<```"8]@``
M!0```*#V```4````IO8``!T```"[]@``0@```-GV```E````'/<``"4```!"
M]P``!@```&CW```*````;_<```0```!Z]P``"0```'_W```(````B?<``!$`
M``"2]P``"0```*3W```&````KO<```T```"U]P``!@```,/W```$````RO<`
M`#D```#/]P``/0````GX```Z````1_@``!X```""^```!0```*'X```.````
MI_@```0```"V^```!@```+OX```'````PO@``"$```#*^```#0```.SX```5
M````^O@```8````0^0``!````!?Y```1````'/D```8````N^0``"@```#7Y
M```B````0/D```0```!C^0``!0```&CY```=````;OD```0```",^0``#```
M`)'Y```)````GOD```P```"H^0``#@```+7Y```*````Q/D``!````#/^0``
M$P```.#Y```3````]/D```@````(^@``"0```!'Z```%````&_H``#H````A
M^@``,````%SZ```U````C?H``"D```##^@``1P```.WZ```X````-?L``"D`
M``!N^P``/P```)C[```N````V/L``"T````'_```'P```#7\```/````5?P`
M`!(```!E_```"P```'C\```F````A/P``"D```"K_```)````-7\```F````
M^OP```@````A_0``"@```"K]```)````-?T```<````__0``(````$?]```@
M````:/T``"8```")_0``!````+#]```@````M?T```H```#6_0``&0```.']
M```I````^_T``!8````E_@``$@```#S^```'````3_X```H```!7_@``#```
M`&+^```/````;_X``!````!__@``0````)#^``!P````T?X``&8```!"_P``
M#@```*G_```)````N/\```H```#"_P``$@```,W_```3````X/\```P```#T
M_P``!@````$``0`<````"``!``\````E``$`&P```#4``0`2````40`!`!``
M``!D``$`$0```'4``0`<````AP`!`",```"D``$`:@```,@``0`/````,P$!
M``4```!#`0$`$````$D!`0`)````6@$!``0```!D`0$`"P```&D!`0`@````
M=0$!`!0```"6`0$`#````*L!`0`,````N`$!``\```#%`0$`%0```-4!`0`I
M````ZP$!`"H````5`@$`)@```$`"`0`G````9P(!`"D```"/`@$`*@```+D"
M`0`9````Y`(!`$(```#^`@$`$0```$$#`0`2````4P,!`!,```!F`P$`%```
M`'H#`0`/````CP,!`!8```"?`P$`%P```+8#`0`0````S@,!`!$```#?`P$`
M-````/$#`0`3````)@0!`!(````Z!`$`-0```$T$`0`4````@P0!``<```"8
M!`$`#````*`$`0`*````K00!`"````"X!`$`$````-D$`0`4````Z@0!`!0`
M``#_!`$`$0```!0%`0`7````)@4!`!P````^!0$`#0```%L%`0`-````:04!
M`!,```!W!0$`%@```(L%`0`4````H@4!`!H```"W!0$`$0```-(%`0`,````
MY`4!`!````#Q!0$`&@````(&`0`>````'08!`!H````\!@$`$P```%<&`0`5
M````:P8!`!$```"!!@$`%P```),&`0`4````JP8!`!<```#`!@$`%0```-@&
M`0`)````[@8!`!````#X!@$`&0````D'`0`$````(P<!``<````H!P$`"P``
M`#`'`0`1````/`<!``8```!.!P$`!@```%4'`0`&````7`<!``4```!C!P$`
M!P```&D'`0`'````<0<!``4```!Y!P$`%@```'\'`0`&````E@<!``8```"=
M!P$`!````*0'`0`$````J0<!``<```"N!P$`#@```+8'`0`,````Q0<!``P`
M``#2!P$`#0```-\'`0`*````[0<!``X```#X!P$`!0````<(`0`H````#0@!
M``X````V"`$`#````$4(`0`/````4@@!``H```!B"`$`"````&T(`0`)````
M=@@!`"L```"`"`$`!````*P(`0`(````L0@!`"8```"Z"`$`$@```.$(`0`/
M````]`@!``8````$"0$`"@````L)`0!,````%@D!``<```!C"0$`"````&L)
M`0`@````=`D!``D```"5"0$`#0```)\)`0`)````K0D!`!0```"W"0$`#```
M`,P)`0`-````V0D!``X```#G"0$`%@```/8)`0`1````#0H!``8````?"@$`
M`P```"8*`0`&````*@H!`!D````Q"@$`!P```$L*`0`$````4PH!``L```!8
M"@$`"P```&0*`0`'````<`H!``4```!X"@$`!P```'X*`0`6````A@H!``T`
M``"="@$`#0```*L*`0`*````N0H!`!````#$"@$`#P```-4*`0`1````Y0H!
M`!<```#W"@$`"@````\+`0`1````&@L!``@````L"P$`!````#4+`0`/````
M.@L!`#H```!*"P$`!0```(4+`0`,````BPL!``0```"8"P$`'@```)T+`0`.
M````O`L!`!````#+"P$`"P```-P+`0`,````Z`L!``D```#U"P$`!P```/\+
M`0`*````!PP!``D````2#`$`#@```!P,`0`0````*PP!`!L````\#`$`&```
M`%@,`0`:````<0P!``H```",#`$`"0```)<,`0`*````H0P!``P```"L#`$`
M#P```+D,`0`(````R0P!``8```#2#`$`'````-D,`0`'````]@P!``4```#^
M#`$`"P````0-`0!'````$`T!``T```!8#0$`"0```&8-`0`$````<`T!``,`
M``!U#0$`$P```'D-`0`3````C0T!`!,```"A#0$`"@```+4-`0`"````P`T!
M``0```###0$`)0```,@-`0`#````[@T!``4```#R#0$`*@```/@-`0`*````
M(PX!``4````N#@$`!````#0.`0`*````.0X!``T```!$#@$`!@```%(.`0`(
M````60X!``@```!B#@$`!````&L.`0`%````<`X!`&@```!V#@$`"0```-\.
M`0`,````Z0X!`!````#V#@$`!0````</`0`&````#0\!`!L````4#P$`+P``
M`#`/`0`0````8`\!``H```!Q#P$`"````'P/`0`/````A0\!``H```"5#P$`
M"0```*`/`0`3````J@\!`!L```"^#P$`&````-H/`0`7````\P\!`!H````+
M$`$`'P```"80`0`.````1A`!`!<```!5$`$``P```&T0`0`'````<1`!``@`
M``!Y$`$`!P```((0`0`)````BA`!``H```"4$`$`"P```)\0`0`'````JQ`!
M`%$```"S$`$`$`````41`0`,````%A$!``T````C$0$`&@```#$1`0!*````
M3!$!`!D```"7$0$`!@```+$1`0`:````N!$!`"4```#3$0$`!@```/D1`0`&
M`````!(!`!\````'$@$`!@```"<2`0`)````+A(!`!@````X$@$`%P```%$2
M`0`H````:1(!``8```"2$@$`#0```)D2`0`H````IQ(!`"(```#0$@$`5P``
M`/,2`0`3````2Q,!`",```!?$P$`$P```(,3`0`"````EQ,!``L```":$P$`
M#````*83`0`(````LQ,!``T```"\$P$`"@```,H3`0`6````U1,!``<```#L
M$P$`%````/03`0`&````"10!``@````0%`$`#@```!D4`0`'````*!0!``H`
M```P%`$`"P```#L4`0`R````1Q0!`!<```!Z%`$`!P```)(4`0`,````FA0!
M``T```"G%`$`%P```+44`0`,````S10!``0```#:%`$`"0```-\4`0`)````
MZ10!``H```#S%`$`!P```/X4`0`)````!A4!``D````0%0$`"@```!H5`0`'
M````)14!``H````M%0$`%0```#@5`0`;````3A4!``\```!J%0$`20```'H5
M`0`2````Q!4!``H```#7%0$`%@```.(5`0`/````^14!`!`````)%@$`"0``
M`!H6`0`0````)!8!``<````U%@$`$@```#T6`0`$````4!8!``L```!5%@$`
M!P```&$6`0`%````:18!``4```!O%@$`&@```'46`0`+````D!8!`!0```"<
M%@$`$0```+$6`0`:````PQ8!`!8```#>%@$`%````/46`0`7````"A<!`!@`
M```B%P$`'````#L7`0`9````6!<!``<```!R%P$`!0```'H7`0`-````@!<!
M``P```".%P$`"P```)L7`0`(````IQ<!`!<```"P%P$`"P```,@7`0`,````
MU!<!`!\```#A%P$`&@````$8`0`3````'!@!``0````P&`$`"@```#48`0`$
M````0!@!``T```!%&`$`#````%,8`0`%````8!@!``D```!F&`$`"````'`8
M`0`%````>1@!``<```!_&`$`!0```(<8`0`$````C1@!``(```"2&`$`&```
M`)48`0`7````KA@!`#@```#&&`$`+````/\8`0`2````+!D!`"D````_&0$`
M,@```&D9`0`*````G!D!`"P```"G&0$`+@```-09`0`S`````QH!`#,````W
M&@$`.````&L:`0`1````I!H!``\```"V&@$`&````,8:`0`0````WQH!``\`
M``#P&@$`$P`````;`0`5````%!L!`!0````J&P$`$@```#\;`0`4````4AL!
M`!4```!G&P$`+0```'T;`0`M````JQL!`#$```#9&P$`+@````L<`0`O````
M.AP!`"P```!J'`$`8@```)<<`0`3````^AP!``T````.'0$`"````!P=`0`7
M````)1T!``@````]'0$`#````$8=`0`K````4QT!`"$```!_'0$`&````*$=
M`0`:````NAT!``D```#5'0$`10```-\=`0!!````)1X!``0```!G'@$`$P``
M`&P>`0`4````@!X!``X```"5'@$`$P```*0>`0`8````N!X!``8```#1'@$`
M"0```-@>`0`*````XAX!``\```#M'@$`$````/T>`0`'````#A\!``X````6
M'P$`!0```"4?`0`;````*Q\!``@```!''P$`!@```%`?`0`4````5Q\!`!$`
M``!L'P$`&````'X?`0`.````EQ\!`#@```"F'P$``@```-\?`0`&````XA\!
M``X```#I'P$`$````/@?`0`%````"2`!``<````/(`$`#@```!<@`0`&````
M)B`!`"@````M(`$`#````%8@`0`<````8R`!``0```"`(`$`F@```(4@`0`I
M````("$!`!<```!*(0$`'P```&(A`0`9````@B$!`%P```"<(0$`%````/DA
M`0`^````#B(!`!\```!-(@$`$````&TB`0`'````?B(!``X```"&(@$`#```
M`)4B`0`,````HB(!`!,```"O(@$`"@```,,B`0`=````SB(!`!D```#L(@$`
M!0````8C`0`1````#",!``T````>(P$`$0```"PC`0`D````/B,!`!(```!C
M(P$`%0```'8C`0`2````C",!``X```"?(P$`&0```*XC`0`(````R",!``D`
M``#1(P$`#0```-LC`0`'````Z2,!``H```#Q(P$`!P```/PC`0`/````!"0!
M``8````4)`$`"P```!LD`0`:````)R0!``H```!")`$`!P```$TD`0`(````
M520!``4```!>)`$`'P```&0D`0`&````A"0!`!````"+)`$`"````)PD`0`-
M````I20!``@```"S)`$`'@```+PD`0`2````VR0!`"P```#N)`$`&@```!LE
M`0`)````-B4!``H```!`)0$`%0```$LE`0`%````824!`!0```!G)0$`!```
M`'PE`0`0````@24!``8```"2)0$`!P```)DE`0`>````H24!`"@```#`)0$`
M"@```.DE`0`<````]"4!`!$````1)@$`$0```",F`0`+````-28!`!H```!!
M)@$`%````%PF`0`$````<28!``0```!V)@$`"P```'LF`0`%````AR8!``8`
M``"-)@$`$0```)0F`0`(````IB8!``8```"O)@$`"@```+8F`0`;````P28!
M`#0```#=)@$`-````!(G`0`@````1R<!`"D```!H)P$`(````)(G`0!!````
MLR<!`!H```#U)P$`(0```!`H`0`H````,B@!`"D```!;*`$`4````(4H`0`B
M````UB@!``8```#Y*`$`"``````I`0`%````"2D!``@````/*0$`&0```!@I
M`0`9````,BD!`"H```!,*0$`(P```'<I`0`9````FRD!`"X```"U*0$`-```
M`.0I`0`(````&2H!`!<````B*@$`"@```#HJ`0`'````12H!`"$```!-*@$`
M"````&\J`0`0````>"H!``X```")*@$`%````)@J`0`+````K2H!``<```"Y
M*@$`$P```,$J`0`(````U2H!``L```#>*@$`"@```.HJ`0`4````]2H!``\`
M```**P$`,@```!HK`0`+````32L!``X```!9*P$`!0```&@K`0`%````;BL!
M`!4```!T*P$`#````(HK`0`%````ERL!`!<```"=*P$`#P```+4K`0`$````
MQ2L!``H```#**P$`"0```-4K`0`+````WRL!``T```#K*P$`#````/DK`0`.
M````!BP!``4````5+`$`!````!LL`0`4````("P!``T````U+`$`(@```$,L
M`0`R````9BP!`!L```"9+`$`10```+4L`0`2````^RP!`!<````.+0$`!P``
M`"8M`0`>````+BT!`!0```!-+0$`!0```&(M`0`4````:"T!``8```!]+0$`
M!P```(0M`0`.````C"T!`"H```";+0$`!@```,8M`0`,````S2T!`!,```#:
M+0$`#0```.XM`0`1````_"T!`!4````.+@$`"P```"0N`0`V````,"X!``H`
M``!G+@$`(@```'(N`0`+````E2X!``\```"A+@$`A0```+$N`0`R````-R\!
M`!L```!J+P$`)0```(8O`0`P````K"\!`#$```#=+P$`+0````\P`0`.````
M/3`!``4```!,,`$`#@```%(P`0`3````83`!`!$```!U,`$`$@```(<P`0`'
M````FC`!`!$```"B,`$`$P```+0P`0`'````R#`!`!0```#0,`$`&````.4P
M`0`'````_C`!``4````&,0$`#`````PQ`0`,````&3$!`!(````F,0$`!```
M`#DQ`0`'````/C$!``H```!&,0$`"P```%$Q`0`,````73$!``X```!J,0$`
M#@```'DQ`0`%````B#$!``4```".,0$`+@```)0Q`0`F````PS$!`",```#J
M,0$``P````XR`0`2````$C(!``8````E,@$`'@```"PR`0`8````2S(!`!D`
M``!D,@$`)0```'XR`0`-````I#(!``D```"R,@$`'P```+PR`0`#````W#(!
M`!@```#@,@$`!P```/DR`0`*`````3,!``(````,,P$`#`````\S`0`5````
M'#,!``L````R,P$`&0```#XS`0`@````6#,!`!(```!Y,P$`!0```(PS`0`*
M````DC,!`!4```"=,P$`$@```+,S`0`,````QC,!``0```#3,P$`"0```-@S
M`0`'````XC,!``P```#J,P$`4@```/<S`0`7````2C0!`"0```!B-`$`(0``
M`(<T`0`2````J30!``<```"\-`$`!@```,0T`0`.````RS0!``T```#:-`$`
M$0```.@T`0`;````^C0!``P````6-0$`#````",U`0`-````,#4!`!4````^
M-0$`$@```%0U`0`/````9S4!`!0```!W-0$`"@```(PU`0`;````ES4!`"``
M``"S-0$`'@```-0U`0`0````\S4!``L````$-@$`)P```!`V`0`E````.#8!
M`&D```!>-@$`)@```,@V`0`:````[S8!`!<````*-P$`&0```"(W`0`:````
M/#<!`"4```!7-P$`*````'TW`0`G````IC<!`!H```#.-P$`%P```.DW`0`;
M`````3@!`$0````=.`$`-````&(X`0`E````ES@!`!D```"].`$`'P```-<X
M`0`;````]S@!`!,````3.0$`"````"<Y`0`'````,#D!``@````X.0$`"0``
M`$$Y`0`5````2SD!``T```!A.0$`(P```&\Y`0`-````DSD!`!,```"A.0$`
M"````+4Y`0`#````OCD!`$8```#".0$`/P````DZ`0`W````23H!`%<```"!
M.@$`!0```-DZ`0`?````WSH!`"\```#_.@$`"@```"\[`0`0````.CL!``@`
M``!+.P$`#0```%0[`0`M````8CL!``0```"0.P$`!P```)4[`0`(````G3L!
M``T```"F.P$`"@```+0[`0!/````OSL!`"4````//`$`'````#4\`0`+````
M4CP!`!\```!>/`$`'0```'X\`0`E````G#P!`"````#"/`$`)````.,\`0`@
M````"#T!``L````I/0$`!P```#4]`0`-````/3T!``P```!+/0$`%P```%@]
M`0`&````<#T!`#D```!W/0$`#````+$]`0`'````OCT!``D```#&/0$`$P``
M`-`]`0`)````Y#T!``0```#N/0$`$````/,]`0`(````!#X!``@````-/@$`
M!````!8^`0`+````&SX!``P````G/@$`$@```#0^`0`1````1SX!``P```!9
M/@$`&@```&8^`0`/````@3X!``<```"1/@$`#0```)D^`0`.````ISX!`!0`
M``"V/@$`#@```,L^`0`'````VCX!``P```#B/@$`&P```.\^`0`L````"S\!
M`!,````X/P$`'````$P_`0`H````:3\!``8```"2/P$`!P```)D_`0`3````
MH3\!``4```"U/P$`!````+L_`0`7````P#\!`#D```#8/P$`"@```!)``0`,
M````'4`!``D````J0`$`!@```#1``0`)````.T`!``@```!%0`$`"0```$Y`
M`0`*````6$`!`!$```!C0`$`!@```'5``0`.````?$`!``X```"+0`$`#0``
M`)I``0`+````J$`!`!T```"T0`$`"P```-)``0`"````WD`!`!P```#A0`$`
M!P```/Y``0`&````!D$!`&0````-00$`"0```')!`0`'````?$$!`"8```"$
M00$`*0```*M!`0`;````U4$!`#@```#Q00$`*P```"I"`0`:````5D(!`",`
M``!Q0@$`*@```)5"`0`M````P$(!`#L```#N0@$`*````"I#`0`T````4T,!
M`!D```"(0P$`%0```*)#`0`%````N$,!``<```"^0P$`"````,9#`0`'````
MST,!``4```#70P$`!P```-U#`0`.````Y4,!``D```#T0P$`!@```/Y#`0`(
M````!40!``L````.1`$`!P```!I$`0`(````(D0!``<````K1`$`%@```#-$
M`0`)````2D0!``8```!41`$`"P```%M$`0`0````9T0!``8```!X1`$`'```
M`']$`0`4````G$0!``<```"Q1`$`$0```+E$`0`(````RT0!``X```#41`$`
M`P```.-$`0`(````YT0!`!0```#P1`$`$`````5%`0`)````%D4!`!`````@
M10$`!@```#%%`0`9````.$4!``H```!210$`'````%U%`0`'````>D4!``4`
M``""10$`$````(A%`0`4````F44!``L```"N10$`#0```+I%`0`H````R$4!
M`!@```#Q10$`%P````I&`0`$````(D8!``D````G1@$`"@```#%&`0`'````
M/$8!``(```!$1@$`#@```$=&`0`(````5D8!`",```!?1@$`'P```(-&`0`X
M````HT8!`"8```#<1@$`,0````-'`0`G````-4<!`$0```!=1P$`)0```*)'
M`0`O````R$<!`"\```#X1P$`+P```"A(`0`H````6$@!`&0```"!2`$`%```
M`.9(`0!5````^T@!`#@```!120$`*0```(I)`0!*````M$D!`%L```#_20$`
M*````%M*`0`X````A$H!`"P```"]2@$`*````.I*`0`L````$TL!`"8```!`
M2P$`&P```&=+`0`^````@TL!`*D!``#"2P$`(P```&Q-`0`P````D$T!`!<`
M``#!30$`2````-E-`0"%````(DX!`#````"H3@$`)0```-E.`0!!````_TX!
M`%L```!!3P$`20```)U/`0`Q````YT\!`!T````94`$`&````#=0`0`K````
M4%`!`"$```!\4`$`'P```)Y0`0`K````OE`!`"8```#J4`$`)P```!%1`0`Z
M````.5$!`!T```!T40$`$0```))1`0`S````I%$!`"4```#840$`)P```/Y1
M`0`@````)E(!`"8```!'4@$`'P```&Y2`0`P````CE(!`,P```"_4@$`:0``
M`(Q3`0`Q````]E,!`$$````H5`$`,P```&I4`0`E````GE0!`#T```#$5`$`
M90````)5`0!-````:%4!`%X```"V50$`)P```!56`0`Q````/58!`#X```!O
M5@$`+````*Y6`0`F````VU8!`"\````"5P$`+@```#)7`0`I````85<!`#``
M``"+5P$`5````+Q7`0!:````$5@!`#$```!L6`$`2````)Y8`0!*````YU@!
M`#$````R60$`*@```&19`0`B````CUD!`"\```"R60$`*0```.)9`0`R````
M#%H!`"\````_6@$`+````&]:`0`M````G%H!`'$```#*6@$`9@```#Q;`0!O
M````HUL!`+,````37`$`%P```,=<`0`E````WUP!`#(````%70$`*0```#A=
M`0`^````8ET!`"(```"A70$`4@```,1=`0`B````%UX!`"4````Z7@$`"P``
M`&!>`0"Q````;%X!`$4````>7P$`(0```&1?`0`V````AE\!`#````"]7P$`
M)0```.Y?`0`<````%&`!`$@````Q8`$`,0```'I@`0`'````K&`!``<```"T
M8`$`!````+Q@`0`-````P6`!``L```#/8`$`#@```-M@`0`+````ZF`!``4`
M``#V8`$`$````/Q@`0`"````#6$!`%D````080$`!0```&IA`0`2````<&$!
M``0```"#80$`!P```(AA`0`(````D&$!``4```"980$`,````)]A`0`#````
MT&$!`!````#480$`#````.5A`0`3````\F$!``T````&8@$``@```!1B`0`'
M````%V(!``8````?8@$`%````"9B`0`,````.V(!`!@```!(8@$`!@```&%B
M`0`2````:&(!``P```![8@$``P```(AB`0`J````C&(!``0```"W8@$`!@``
M`+QB`0`'````PV(!`!\```#+8@$`-0```.MB`0`N````(6,!`"\```!08P$`
M%P```(!C`0`B````F&,!`"4```"[8P$`(````.%C`0`;`````F0!`!@````>
M9`$`)````#=D`0`?````7&0!`!H```!\9`$`(0```)=D`0`@````N60!`#``
M``#:9`$`&@````ME`0`R````)F4!`!H```!990$`+P```'1E`0`K````I&4!
M`!\```#090$`(P```/!E`0`?````%&8!`!H````T9@$`(0```$]F`0`E````
M<68!`"8```"79@$`)0```+YF`0`D````Y&8!`!@````)9P$`'0```")G`0`D
M````0&<!`!@```!E9P$`(@```'YG`0`L````H6<!`"\```#.9P$`%0```/YG
M`0`E````%&@!`#P````Z:`$`'P```'=H`0`C````EV@!`!\```"[:`$`(```
M`-MH`0`:````_&@!`!@````7:0$`)@```#!I`0`>````5VD!`"D```!V:0$`
M'@```*!I`0`Q````OVD!``D```#Q:0$`#````/MI`0`7````"&H!`"\````@
M:@$`)````%!J`0`'````=6H!``\```!]:@$`%````(UJ`0`.````HFH!``T`
M``"Q:@$`)````+]J`0`%````Y&H!``<```#J:@$`(@```/)J`0`E````%6L!
M`!H````[:P$`'0```%9K`0`:````=&L!``<```"/:P$`QP```)=K`0`+````
M7VP!`!P```!K;`$`%0```(AL`0`&````GFP!``D```"E;`$`"P```*]L`0`-
M````NVP!`!<```#);`$`!@```.%L`0`S````Z&P!`!,````<;0$`$P```#!M
M`0`'````1&T!``\```!,;0$`!P```%QM`0`R````9&T!``0```"7;0$`(0``
M`)QM`0`3````OFT!``P```#2;0$`$0```-]M`0`R````\6T!`!8````D;@$`
M"````#MN`0`=````1&X!``D```!B;@$`"@```&QN`0`4````=VX!``H```",
M;@$`'0```)=N`0`(````M6X!`!\```"^;@$`"````-YN`0`:````YVX!`"<`
M```";P$`!@```"IO`0`5````,6\!``<```!';P$`"````$]O`0`)````6&\!
M`#\```!B;P$`$@```*)O`0`'````M6\!``\```"];P$`#@```,UO`0`0````
MW&\!``D```#M;P$`"0```/=O`0`(`````7`!`!,````*<`$`"0```!YP`0`'
M````*'`!``P````P<`$`&0```#UP`0`*````5W`!`!L```!B<`$`%P```'YP
M`0`4````EG`!``H```"K<`$`#````+9P`0`7````PW`!``0```#;<`$`*@``
M`.!P`0`,````"W$!`!$````8<0$`!P```"IQ`0`"````,G$!`!`````U<0$`
M&````$9Q`0`+````7W$!``,```!K<0$`"````&]Q`0`+````>'$!``8```"$
M<0$`!P```(MQ`0`-````DW$!``L```"A<0$`%````*UQ`0`5````PG$!``X`
M``#8<0$`+P```.=Q`0`@````%W(!`!P````X<@$`%0```%5R`0`,````:W(!
M`#$```!X<@$`!0```*IR`0`2````L'(!`#\```##<@$`$@````-S`0`*````
M%G,!``8````A<P$`!````"AS`0`$````+7,!``H````R<P$`$P```#US`0`%
M````47,!``8```!7<P$`!@```%YS`0`(````97,!``0```!N<P$`#````'-S
M`0`)````@',!``P```"*<P$`"@```)=S`0`0````HG,!`!,```"S<P$`$P``
M`,=S`0`Y````VW,!`"X````5=`$`*0```$1T`0`%````;G0!`!@```!T=`$`
M&0```(UT`0`?````IW0!`!T```#'=`$`$0```.5T`0`"````]W0!``0```#Z
M=`$`"@```/]T`0`&````"G4!``4````1=0$``P```!=U`0`,````&W4!`$4`
M```H=0$`,@```&YU`0`\````H74!`!H```#>=0$`-````/EU`0`H````+G8!
M`%,```!7=@$`,````*MV`0`O````W'8!`#(````,=P$`&0```#]W`0!R````
M67<!`"````#,=P$`-0```.UW`0`A````(W@!`$4```!%>`$`,````(MX`0`F
M````O'@!`!X```#C>`$`*`````)Y`0`K````*WD!`"D```!7>0$`*0```(%Y
M`0`F````JWD!`"4```#2>0$`*````/AY`0`H````(7H!`"(```!*>@$`*P``
M`&UZ`0`N````F7H!`#````#(>@$`$@```/EZ`0`3````#'L!`!`````@>P$`
M>0```#%[`0`)````JWL!`*$```"U>P$`<P```%=\`0!\````RWP!`"L```!(
M?0$`5````'1]`0`7````R7T!`"P```#A?0$`)P````Y^`0`6````-GX!``\`
M``!-?@$`%P```%U^`0`?````=7X!`$````"5?@$`'P```-9^`0`<````]GX!
M`%$````3?P$`&@```&5_`0`4````@'\!``H```"5?P$`!0```*!_`0`&````
MIG\!``@```"M?P$`!0```+9_`0`2````O'\!`!````#/?P$`$P```.!_`0`=
M````]'\!``\````2@`$`"@```"*``0`/````+8`!``<````]@`$`!````$6`
M`0`)````2H`!``D```!4@`$`!P```%Z``0`+````9H`!``<```!R@`$`!0``
M`'J``0`4````@(`!``X```"5@`$`!@```*2``0`'````JX`!``@```"S@`$`
M#P```+R``0`1````S(`!``P```#>@`$`"````.N``0`,````](`!``\````!
M@0$`%@```!&!`0`'````*($!``8````P@0$`%````#>!`0`&````3($!``P`
M``!3@0$`$0```&"!`0`(````<H$!``0```![@0$`&0```("!`0`1````FH$!
M``H```"L@0$`&````+>!`0`3````T($!``L```#D@0$`#````/"!`0`,````
M_8$!``P````*@@$`'````!>"`0`1````-((!``0```!&@@$`#P```$N"`0`'
M````6X(!``0```!C@@$`&0```&B"`0`'````@H(!``(```"*@@$``@```(V"
M`0`1````D((!``D```"B@@$`!@```*R"`0`2````LX(!`!<```#&@@$`!@``
M`-Z"`0`G````Y8(!``(````-@P$`!````!"#`0`-````%8,!``0````C@P$`
M#P```"B#`0`3````.(,!``<```!,@P$`!P```%2#`0`1````7(,!``8```!N
M@P$`&````'6#`0`&````CH,!`!,```"5@P$`$````*F#`0`2````NH,!``(`
M``#-@P$`!@```-"#`0`,````UX,!``D```#D@P$`$0```.Z#`0`1`````(0!
M`!L````2A`$`(@```"Z$`0`'````480!``<```!9A`$`"P```&&$`0`%````
M;80!``(```!SA`$`"P```':$`0!9`0``@H0!``\```#<A0$`$P```.R%`0`.
M`````(8!``@````/A@$`"0```!B&`0`*````(H8!`!H````MA@$`%P```$B&
M`0`%````8(8!`#(```!FA@$`&@```)F&`0`?````M(8!`#(```#4A@$`,```
M``>'`0`I````.(<!`"@```!BAP$`.P```(N'`0`>````QX<!`#X```#FAP$`
M*````"6(`0`J````3H@!`#,```!YB`$`#````*V(`0`G````NH@!`!(```#B
MB`$`#````/6(`0`0`````HD!``4````3B0$`(0```!F)`0`0````.XD!`!``
M``!,B0$`%@```%V)`0`/````=(D!`!4```"$B0$`#````)J)`0`I````IXD!
M`(4```#1B0$`$````%>*`0`*````:(H!`!(```!SB@$`$````(:*`0`.````
MEXH!``P```"FB@$`#@```+.*`0`1````PHH!``8```#4B@$`P0```-N*`0`'
M````G8L!``L```"EBP$`&@```+&+`0`/````S(L!`!$```#<BP$`$0```.Z+
M`0`*`````(P!``<````+C`$`,P```!.,`0`L````1XP!`"0```!TC`$`50``
M`)F,`0!A````[XP!`'D```!1C0$`>````,N-`0!\````1(X!`'L```#!C@$`
M6````#V/`0`1````EH\!`!D```"HCP$`$````,*/`0`2````TX\!`!@```#F
MCP$`!0```/^/`0`&````!9`!`!(````,D`$`!P```!^0`0`5````)Y`!``T`
M```]D`$`#0```$N0`0`W````69`!`"X```"1D`$`&0```,"0`0`2````VI`!
M``T```#MD`$`$@```/N0`0`+````#I$!``H````:D0$`&P```"61`0`;````
M09$!`!````!=D0$`%@```&Z1`0`6````A9$!`!X```"<D0$`'@```+N1`0`E
M````VI$!`!4`````D@$`*````!:2`0`1````/Y(!`!````!1D@$`&@```&*2
M`0`/````?9(!`"H```"-D@$`#0```+B2`0`:````QI(!`!\```#AD@$`$P``
M``&3`0!Z````%9,!`$(```"0DP$`*P```-.3`0`O````_Y,!``<````OE`$`
M"@```#>4`0`/````0I0!``P```!2E`$`$0```%^4`0`E````<90!`!@```"7
ME`$`*0```+"4`0`P````VI0!``X````+E0$`!P```!J5`0`0````(I4!``L`
M```SE0$`"````#^5`0`(````2)4!``D```!1E0$`"P```%N5`0`,````9Y4!
M``0```!TE0$`%````'F5`0`,````CI4!``L```";E0$`$````*>5`0`9````
MN)4!`"8```#2E0$`$0```/F5`0`1````"Y8!`!H````=E@$`&@```#B6`0`>
M````4Y8!`!@```!RE@$`%````(N6`0`2````H)8!`!(```"SE@$`)P```,:6
M`0`G````[I8!``<````6EP$`!@```!Z7`0`(````)9<!``X````NEP$`!P``
M`#V7`0`)````19<!`!,```!/EP$`"0```&.7`0`/````;9<!`!4```!]EP$`
M&````).7`0`*````K)<!``\```"WEP$`!0```,>7`0`7````S9<!``L```#E
MEP$`"@```/&7`0`M````_)<!`$0````JF`$`2P```&^8`0!%````NY@!``L`
M```!F0$`"`````V9`0`5````%ID!``4````LF0$`!0```#*9`0`+````.)D!
M`!````!$F0$`"P```%69`0`7````89D!`"X```!YF0$`$````*B9`0`]````
MN9D!`#P```#WF0$`/P```#2:`0`_````=)H!``D```"TF@$`!@```+Z:`0`*
M````Q9H!``H```#0F@$`00```-N:`0`]````'9L!`$````!;FP$`<0```)R;
M`0`_````#IP!`$,```!.G`$`4P```)*<`0!0````YIP!`#\````WG0$`40``
M`'>=`0`S````R9T!`#<```#]G0$`5P```#6>`0`_````C9X!`$,```#-G@$`
M*@```!&?`0`@````/)\!`!P```!=GP$`/0```'J?`0`I````N)\!`"D```#B
MGP$`$@````R@`0`-````'Z`!``T````MH`$`"P```#N@`0`0````1Z`!`!L`
M``!8H`$`'P```'2@`0`'````E*`!``<```"<H`$`%@```*2@`0`+````NZ`!
M``@```#'H`$`+0```-"@`0`*````_J`!``X````)H0$`"@```!BA`0`'````
M(Z$!``8````KH0$`%@```#*A`0`%````2:$!``@```!/H0$`!@```%BA`0`B
M````7Z$!``H```""H0$`+0```(VA`0`2````NZ$!``@```#.H0$`!````->A
M`0`(````W*$!``L```#EH0$`!````/&A`0`,````]J$!``8````#H@$`$P``
M``JB`0`&````'J(!``@````EH@$`!0```"ZB`0`+````-*(!``D```!`H@$`
M*0```$JB`0`%````=*(!`!$```!ZH@$`"0```(RB`0`3````EJ(!``P```"J
MH@$`!P```+>B`0`2````OZ(!``,```#2H@$``P```-:B`0`7````VJ(!``,`
M``#RH@$`%P```/:B`0`W````#J,!``@```!&HP$`"0```$^C`0`*````6:,!
M``<```!DHP$`8P```&RC`0`L````T*,!`#D```#]HP$`.@```#>D`0`\````
M<J0!`"H```"OI`$`!@```-JD`0`)````X:0!`!@```#KI`$`+`````2E`0`E
M````,:4!`#8```!7I0$`,@```(ZE`0`S````P:4!`)$```#UI0$`2````(>F
M`0`)````T*8!``L```#:I@$`"````.:F`0`=````[Z8!``T````-IP$`#```
M`!NG`0`3````**<!``T````\IP$`$P```$JG`0`.````7J<!``P```!MIP$`
M%@```'JG`0`)````D:<!`!P```";IP$`'0```+BG`0`1````UJ<!`!(```#H
MIP$`%0```/NG`0`&````$:@!``8````8J`$`%P```!^H`0"$````-Z@!`'L`
M``"\J`$`!P```#BI`0`3````0*D!`!4```!4J0$`!0```&JI`0`%````<*D!
M`!\```!VJ0$`'@```):I`0`4````M:D!`!8```#*J0$`%P```.&I`0`>````
M^:D!`!D````8J@$`&@```#*J`0`T````3:H!`"\```""J@$`4P```+*J`0`O
M````!JL!`$X````VJP$`#P```(6K`0`H````E:L!``8```"^JP$`&````,6K
M`0`4````WJL!`!D```#SJP$`%0````VL`0`5````(ZP!`!$````YK`$`"@``
M`$NL`0`3````5JP!`!$```!JK`$`!@```'RL`0`+````@ZP!``<```"/K`$`
M"P```)>L`0`.````HZP!`!<```"RK`$`"0```,JL`0`%````U*P!``L```#:
MK`$`"````.:L`0`(````[ZP!``T```#XK`$`%`````:M`0`D````&ZT!``8`
M``!`K0$`%````$>M`0`H````7*T!``8```"%K0$`#````(RM`0`)````F:T!
M`!````"CK0$`!P```+2M`0`%````O*T!``T```#"K0$`"````-"M`0`+````
MV:T!``L```#EK0$`&@```/&M`0!$````#*X!`"L```!1K@$`$````'VN`0`3
M````CJX!``4```"BK@$`'````*BN`0`:````Q:X!`!L```#@K@$`'0```/RN
M`0`9````&J\!`#T````TKP$`3````'*O`0`H````OZ\!``P```#HKP$`"```
M`/6O`0`5````_J\!`#T````4L`$`)````%*P`0`/````=[`!``8```"'L`$`
M"P```(ZP`0`&````FK`!``@```"AL`$`&P```*JP`0`0````QK`!``D```#7
ML`$`"@```.&P`0`.````[+`!`#D```#[L`$`.0```#6Q`0`[````;[$!`#L`
M``"KL0$`*P```.>Q`0`J````$[(!`"P````^L@$`*@```&NR`0!"````EK(!
M`"\```#9L@$`+@````FS`0`P````.+,!`"@```!ILP$`+P```)*S`0`\````
MPK,!`#X```#_LP$`-````#ZT`0`Q````<[0!`#D```"EM`$`+P```-^T`0`R
M````#[4!`$8```!"M0$`,````(FU`0`?````NK4!`#H```#:M0$`+@```!6V
M`0`[````1+8!`!\```"`M@$`W````*"V`0`?````?;<!`"X```"=MP$`,0``
M`,RW`0`R````_K<!`#4````QN`$`,````&>X`0`N````F+@!`#$```#'N`$`
M.0```/FX`0`\````,[D!`$0```!PN0$`/````+6Y`0#%````\KD!`"\```"X
MN@$`(@```.BZ`0`O````"[L!`#,````[NP$`/@```&^[`0!D````KKL!`%T`
M```3O`$`#@```'&\`0`$````@+P!``4```"%O`$`"0```(N\`0`4````E;P!
M``X```"JO`$`'0```+F\`0`6````U[P!`!4```#NO`$`"`````2]`0`/````
M#;T!`!(````=O0$`"````#"]`0`$````.;T!`!$````^O0$`$0```%"]`0`-
M````8KT!`!````!PO0$`$0```(&]`0`0````D[T!`!@```"DO0$`#@```+V]
M`0!1````S+T!``P````>O@$`%````"N^`0`&````0+X!`!,```!'O@$`&0``
M`%N^`0`>````=;X!`!4```"4O@$``@```*J^`0!+````K;X!``<```#YO@$`
M$`````&_`0`0````$K\!``4````COP$`#0```"F_`0`-````-[\!``,```!%
MOP$`#P```$F_`0`(````6;\!``8```!BOP$`$0```&F_`0`(````>[\!``T`
M``"$OP$`$0```)*_`0`-````I+\!`!````"ROP$`#````,._`0`'````T+\!
M`!(```#8OP$`#0```.N_`0`0````^;\!``X````*P`$`"P```!G``0`.````
M)<`!`"$````TP`$`%P```%;``0`-````;L`!``X```!\P`$`)@```(O``0`?
M````LL`!`!,```#2P`$`%P```.;``0`M````_L`!``T````LP0$`'0```#K!
M`0`3````6,$!`!L```!LP0$`&@```(C!`0`N````H\$!`"@```#2P0$`&@``
M`/O!`0`1````%L(!``@````HP@$`"0```#'"`0`*````.\(!`!L```!&P@$`
M#````&+"`0`B````;\(!`#````"2P@$`"P```,/"`0`(````S\(!`!T```#8
MP@$`"@```/;"`0`5`````<,!`!4````7PP$`"P```"W#`0`'````.<,!`",`
M``!!PP$`%0```&7#`0`?````>\,!`!D```";PP$`#0```+7#`0`3````P\,!
M``D```#7PP$`#0```.'#`0`O````[\,!`#$````?Q`$`40```%'$`0`(````
MH\0!`!<```"LQ`$`(@```,3$`0`-````Y\0!`!````#UQ`$`-`````;%`0`3
M````.\4!``P```!/Q0$`!@```%S%`0`%````8\4!`$L```!IQ0$`!@```+7%
M`0`'````O,4!``H```#$Q0$`#P```,_%`0`7````W\4!`!````#WQ0$`$0``
M``C&`0`1````&L8!`!$````LQ@$`&@```#[&`0`9````6<8!`!T```!SQ@$`
M&@```)'&`0`8````K,8!``<```#%Q@$`!P```,W&`0`+````U<8!``H```#A
MQ@$``@```.S&`0`%````[\8!``P```#UQ@$`)0````+'`0`5````*,<!`!8`
M```^QP$`!P```%7'`0`0````7<<!`!````!NQP$`%````'_'`0`[````E,<!
M`"<```#0QP$`!P```/C'`0`1`````,@!`)<````2R`$`&0```*K(`0`C````
MQ,@!`%P```#HR`$`'````$7)`0`1````8LD!``<```!TR0$`!@```'S)`0`R
M````@\D!`#D```"VR0$`)@```/#)`0`E````%\H!`"P````]R@$`,@```&K*
M`0`P````G<H!`"0```#.R@$`-0```//*`0`\````*<L!`#$```!FRP$`)```
M`)C+`0`=````O<L!`!\```#;RP$`!P```/O+`0`)`````\P!``D````-S`$`
M!@```!?,`0`/````'LP!``X````NS`$`$````#W,`0`.````3LP!`!,```!=
MS`$`$0```'',`0`0````@\P!``X```"4S`$`"0```*/,`0`*````K<P!``X`
M``"XS`$`#````,?,`0`]````U,P!``T````2S0$`"````"#-`0`+````*<T!
M`!8````US0$`*@```$S-`0`M````=\T!`!````"ES0$`(P```+;-`0`S````
MVLT!`"\````.S@$`+````#[.`0`G````:\X!`"T```"3S@$`40```,'.`0`G
M````$\\!`"8````[SP$`+P```&+/`0`I````DL\!`#8```"\SP$`2P```///
M`0`L````/]`!`!4```!LT`$`+0```(+0`0`R````L-`!``8```#CT`$`#@``
M`.K0`0`&````^=`!`!``````T0$``P```!'1`0`$````%=$!``<````:T0$`
M$P```"+1`0`5````-M$!`!,```!,T0$`&0```&#1`0`*````>M$!``X```"%
MT0$`"P```)31`0`'````H-$!``4```"HT0$`$````*[1`0`2````O]$!``P`
M``#2T0$`"0```-_1`0`,````Z=$!``\```#VT0$`,0````;2`0`'````.-(!
M``8```!`T@$`$````$?2`0`'````6-(!``@```!@T@$`#````&G2`0`'````
M=M(!``X```!^T@$`%P```(W2`0`(````I=(!``@```"NT@$`!0```+?2`0`B
M````O=(!``P```#@T@$`!0```.W2`0`J````\](!`!`````>TP$`<0```"_3
M`0`3````H=,!``D```"UTP$`"@```+_3`0`-````RM,!``L```#8TP$`#0``
M`.33`0`%````\M,!``T```#XTP$``@````;4`0`&````"=0!``H````0U`$`
M%P```!O4`0`1````,]0!`!,```!%U`$`%@```%G4`0`Q````<-0!``,```"B
MU`$`!````*;4`0`9````J]0!``@```#%U`$`$@```,[4`0`%````X=0!`!D`
M``#GU`$`"`````'5`0`&````"M4!`!D````1U0$`#@```"O5`0`(````.M4!
M``L```!#U0$`!0```$_5`0`)````5=4!``<```!?U0$`%@```&?5`0`8````
M?M4!``,```"7U0$`!@```)O5`0`+````HM4!``P```"NU0$`"@```+O5`0`,
M````QM4!`!<```#3U0$`"````.O5`0`'````]-4!``8```#\U0$`$0````/6
M`0`C````%=8!`%`````YU@$`-@```(K6`0`Z````P=8!``<```#\U@$`"@``
M``37`0`$````#]<!``D````4UP$`"````![7`0`*````)]<!``D````RUP$`
M!@```#S7`0`-````0]<!``8```!1UP$`!````%C7`0`[````7=<!`#X```"9
MUP$`/0```-C7`0`F````%M@!``4````]V`$`$````$/8`0`&````5-@!``L`
M``!;V`$`#````&?8`0`9````=-@!`!````".V`$`&````)_8`0`$````N-@!
M``4```"]V`$`"P```,/8`0`%````S]@!``H```#5V`$`'@```.#8`0`$````
M_]@!``L````$V0$`#````!#9`0`*````'=D!``X````HV0$`#````#?9`0`+
M````1-D!``\```!0V0$`#@```&#9`0`3````;]D!`!\```"#V0$`#0```*/9
M`0`(````L=D!``D```"ZV0$`!0```,39`0`S````RMD!`#,```#^V0$`/```
M`#+:`0`O````;]H!`$X```"?V@$`2````.[:`0`U````-]L!`%8```!MVP$`
M.P```,3;`0!,`````-P!`#````!-W`$`$0```'[<`0`9````D-P!``L```"J
MW`$`0P```+;<`0`O````^MP!`"(````JW0$`+@```$W=`0`0````?-T!`!(`
M``"-W0$`!P```*#=`0`&````J-T!`#$```"OW0$`,0```.'=`0`X````$]X!
M``0```!,W@$`&0```%'>`0`*````:]X!`!L```!VW@$`*0```)+>`0`?````
MO-X!`!,```#<W@$`!@```/#>`0`*````]]X!``P````"WP$`#P````_?`0`9
M````']\!`%\````YWP$`?0```)G?`0!Z````%^`!``T```"2X`$`"````*#@
M`0`)````J>`!`!````"SX`$`$0```,3@`0`.````UN`!``8```#EX`$`(@``
M`.S@`0`7````#^$!`!H````GX0$`%0```$+A`0`3````6.$!`!0```!LX0$`
M&P```('A`0`J````G>$!`)4```#(X0$`$0```%[B`0`&````<.(!`!$```!W
MX@$`"@```(GB`0`+````E.(!``T```"@X@$`(P```*[B`0`6````TN(!``\`
M``#IX@$`$````/GB`0`-````"N,!`!<````8XP$`+````##C`0`K````7>,!
M`"L```")XP$`*@```+7C`0`V````X.,!`#4````7Y`$`'````$WD`0!/````
M:N0!`!4```"ZY`$`%````-#D`0`6````Y>0!`!4```#\Y`$`%@```!+E`0`6
M````*>4!`!4```!`Y0$`%0```%;E`0`4````;.4!`#,```"!Y0$`&````+7E
M`0`8````SN4!`#L```#GY0$`$@```"/F`0`(````-N8!`!0````_Y@$`#```
M`%3F`0`C````8>8!`!0```"%Y@$`%0```)KF`0`4````L.8!`!,```#%Y@$`
M&0```-GF`0`6````\^8!`!<````*YP$`$@```"+G`0`6````-><!`!\```!,
MYP$`&P```&SG`0`9````B.<!`!0```"BYP$`#P```+?G`0`3````Q^<!`!\`
M``#;YP$`(@```/OG`0`5````'N@!`!4````TZ`$`%P```$KH`0`5````8N@!
M`!H```!XZ`$`'0```)/H`0`;````L>@!`!@```#-Z`$`"````.;H`0`0````
M[^@!`!@`````Z0$`!````!GI`0`&````'ND!``L````EZ0$`%````#'I`0`&
M````1ND!``H```!-Z0$`!@```%CI`0`'````7^D!``<```!GZ0$`!@```&_I
M`0`%````=ND!`!<```!\Z0$`!@```)3I`0`)````F^D!``0```"EZ0$`!```
M`*KI`0`)````K^D!``H```"YZ0$`"0```,3I`0`0````SND!`!$```#?Z0$`
M"@```/'I`0`5````_.D!``4````2Z@$`-0```!CJ`0`/````3NH!`!(```!>
MZ@$`'````''J`0`.````CNH!``P```"=Z@$`#@```*KJ`0!)````N>H!``8`
M```#ZP$`"`````KK`0`A````$^L!``X````UZP$`$P```$3K`0`&````6.L!
M``L```!?ZP$`8P```&OK`0`)````S^L!``<```#9ZP$`!````.'K`0`-````
MYNL!``\```#TZP$`"`````3L`0`7````#>P!``\````E[`$`%@```#7L`0`4
M````3.P!`!L```!A[`$`&@```'WL`0`(````F.P!``8```"A[`$`!@```*CL
M`0`=````K^P!``<```#-[`$`!0```-7L`0`1````V^P!``L```#M[`$`!P``
M`/GL`0`%`````>T!``<````'[0$`!@````_M`0`-````%NT!``H````D[0$`
M#@```"_M`0`3````/NT!`!4```!2[0$`%````&CM`0`;````?>T!`!,```"9
M[0$`%0```*WM`0`(````P^T!``0```#,[0$`$@```-'M`0`7````Y.T!``4`
M``#\[0$`$0````+N`0`%````%.X!`"4````:[@$`%````$#N`0`6````5>X!
M`!$```!L[@$`#0```'[N`0`,````C.X!``D```"9[@$`#P```*/N`0`.````
ML^X!`!````#"[@$`$````-/N`0`P````Y.X!`#`````5[P$`+````$;O`0`)
M````<^\!``<```!][P$`!P```(7O`0`0````C>\!`!````">[P$``P```*_O
M`0`(````L^\!`"````"\[P$`"````-WO`0`(````YN\!``\```#O[P$`:0``
M`/_O`0`9````:?`!``L```"#\`$`!0```(_P`0`'````E?`!`!H```"=\`$`
M&@```+CP`0`3````T_`!``D```#G\`$``@```/'P`0`$````]/`!`"0```#Y
M\`$`!P```![Q`0`%````)O$!`"\````L\0$`"@```%SQ`0`%````9_$!``<`
M``!M\0$`%````'7Q`0`0````BO$!``8```";\0$`"````*+Q`0`)````J_$!
M``0```"U\0$`!0```+KQ`0!T````P/$!``L````U\@$`#@```$'R`0`8````
M4/(!``0```!I\@$`#````&[R`0`F````>_(!`#4```"B\@$`#@```-CR`0`*
M````Y_(!``0```#R\@$`$@```/?R`0`+````"O,!``D````6\P$`&0```"#S
M`0`H````.O,!`"D```!C\P$`*````(WS`0`<````MO,!`"````#3\P$`#@``
M`/3S`0`3`````_0!``,````7]`$`#@```!OT`0`'````*O0!``H````R]`$`
M"0```#WT`0`*````1_0!`!0```!2]`$`"0```&?T`0!:````<?0!`!P```#,
M]`$`#@```.GT`0`,````^/0!`!L````%]0$`3````"'U`0`=````;O4!``<`
M``",]0$`)````)3U`0`P````N?4!``@```#J]0$`!@```//U`0`B````^O4!
M``4````=]@$`!P```"/V`0`I````*_8!`"@```!5]@$`-````'[V`0`(````
ML_8!``T```"\]@$`(P```,KV`0`>````[O8!`&(````-]P$`&````'#W`0`6
M````B?<!`!4```"@]P$``@```+;W`0`+````N?<!``T```#%]P$`!0```-/W
M`0`.````V?<!``X```#H]P$`(````/?W`0`'````&/@!``\````@^`$`!@``
M`##X`0`(````-_@!``X```!`^`$`"0```$_X`0`*````6?@!``H```!D^`$`
M-P```&_X`0`B````I_@!``<```#*^`$`$@```-+X`0`3````Y?@!`!X```#Y
M^`$`$@```!CY`0`+````*_D!``H````W^0$`"@```$+Y`0`+````3?D!``D`
M``!9^0$`"@```&/Y`0`*````;OD!``L```!Y^0$`"0```(7Y`0`(````C_D!
M`!,```"8^0$`'P```*SY`0`1````S/D!`%(```#>^0$`#P```#'Z`0`*````
M0?H!``H```!,^@$`#P```%?Z`0`2````9_H!``L```!Z^@$`$0```(;Z`0`%
M````F/H!`!D```">^@$`!````+CZ`0`,````O?H!``<```#*^@$`!0```-+Z
M`0`%````V/H!`!\```#>^@$`"P```/[Z`0`8````"OL!`!(````C^P$`&0``
M`#;[`0`;````4/L!`"(```!L^P$`%@```(_[`0`7````IOL!`!(```"^^P$`
M%@```-'[`0`(````Z/L!``,```#Q^P$`#0```/7[`0`.`````_P!``T````2
M_`$`!P```"#\`0`=````*/P!``H```!&_`$`#@```%'\`0`F````8/P!`"L`
M``"'_`$`%@```+/\`0`+````ROP!``L```#6_`$`!@```.+\`0`0````Z?P!
M`!4```#Z_`$`!P```!#]`0`)````&/T!``D````B_0$`!0```"S]`0`'````
M,OT!``8````Z_0$`!````$']`0`$````1OT!`"@```!+_0$`'````'3]`0!`
M````D?T!`#H```#2_0$`%`````W^`0`S````(OX!`#L```!6_@$`$0```)+^
M`0!,````I/X!`#H```#Q_@$`2P```"S_`0!+````>/\!`%$```#$_P$`&```
M`!8``@`7````+P`"`!D```!'``(`%P```&$``@`5````>0`"`!T```"/``(`
M$P```*T``@`:````P0`"`!0```#<``(`%P```/$``@`<````"0$"`#<````F
M`0(`-P```%X!`@`[````E@$"`#@```#2`0(`.0````L"`@`V````10("`'4`
M``!\`@(`(P```/("`@`I````%@,"``P```!``P(`'````$T#`@`,````:@,"
M`!0```!W`P(`-````(P#`@`L````P0,"`"4```#N`P(`,````!0$`@`+````
M100"`%P```!1!`(`5@```*X$`@`%````!04"`!D````+!0(`%@```"4%`@`,
M````/`4"`!0```!)!0(`$@```%X%`@`(````<04"``H```!Z!0(`"0```(4%
M`@`0````CP4"`!0```"@!0(`$````+4%`@`2````Q@4"``L```#9!0(`)0``
M`.4%`@`(````"P8"``0````4!@(`$@```!D&`@`2````+`8"`!T````_!@(`
M$0```%T&`@`O````;P8"``(```"?!@(`!@```*(&`@`/````J08"`!4```"Y
M!@(`"0```,\&`@`'````V08"`!P```#A!@(`!````/X&`@`[`````P<"``X`
M```_!P(`&````$X'`@`$````9P<"`)@```!L!P(`+P````4(`@`9````-0@"
M`!\```!/"`(`)P```&\(`@!>````EP@"`!<```#V"`(`1P````X)`@`I````
M5@D"``T```"`"0(`#0```(X)`@`4````G`D"`!$```"Q"0(`#````,,)`@`6
M````T`D"``P```#G"0(`'0```/0)`@`6````$@H"``@````I"@(`%````#(*
M`@`4````1PH"``X```!<"@(`*@```&L*`@`2````E@H"`!D```"I"@(`&```
M`,,*`@`:````W`H"`"L```#W"@(`"````",+`@`)````+`L"`!D````V"P(`
M$0```%`+`@`3````8@L"`!(```!V"P(`&0```(D+`@`1````HPL"`!0```"U
M"P(`&P```,H+`@`*````Y@L"``P```#Q"P(`"````/X+`@`%````!PP"`"$`
M```-#`(`!@```"\,`@`/````-@P"``@```!&#`(`$0```$\,`@`(````80P"
M`!X```!J#`(`$0```(D,`@`Y````FPP"`!@```#5#`(`"0```.X,`@`*````
M^`P"`"(````##0(`"````"8-`@`?````+PT"``0```!/#0(`'````%0-`@`(
M````<0T"``<```!Z#0(`'````((-`@`P````GPT"``8```#0#0(`(````-<-
M`@`2````^`T"`!(````+#@(`!@```!X.`@`0````)0X"`!,````V#@(`!```
M`$H.`@`)````3PX"``L```!9#@(`!P```&4.`@`%````;0X"``\```!S#@(`
M"````(,.`@`%````C`X"``L```"2#@(`'P```)X.`@`^````O@X"`$P```#]
M#@(`)P```$H/`@`V````<@\"`"<```"I#P(`50```-$/`@`G````)Q`"`#,`
M``!/$`(`-P```(,0`@`W````NQ`"`(L```#S$`(`*````'\1`@`%````J!$"
M``<```"N$0(`"````+81`@`(````OQ$"`!L```#($0(`'0```.01`@`J````
M`A("`"H````M$@(`)@```%@2`@!`````?Q("`$8```#`$@(`"0````<3`@`7
M````$1,"``L````I$P(`"````#43`@`X````/A,"``8```!W$P(`%@```'X3
M`@`0````E1,"`!,```"F$P(`$@```+H3`@`(````S1,"`!,```#6$P(`"```
M`.H3`@`-````\Q,"`!8````!%`(`)P```!@4`@`H````0!0"`$,```!I%`(`
M"P```*T4`@`=````N10"``4```#7%`(`!P```-T4`@`?````Y10"``P````%
M%0(`&````!(5`@`C````*Q4"``P```!/%0(`!0```%P5`@`*````8A4"``P`
M``!M%0(`#````'H5`@`+````AQ4"`!H```"3%0(`"@```*X5`@`*````N14"
M``4```#$%0(`'0```,H5`@`1````Z!4"`"D```#Z%0(`20```"06`@`@````
M;A8"`%T```"/%@(`%````.T6`@`>`````A<"``P````A%P(`)@```"X7`@`<
M````51<"`!(```!R%P(`$P```(47`@`-````F1<"``L```"G%P(`$````+,7
M`@`M````Q!<"``D```#R%P(`#0```/P7`@`4````"A@"`!`````?&`(`%@``
M`#`8`@`:````1Q@"``P```!B&`(`/@```&\8`@`(````KA@"`"D```"W&`(`
M$````.$8`@`4````\A@"`)(````'&0(`10```)H9`@`B````X!D"`#,````#
M&@(`-P```#<:`@`T````;QH"`#````"D&@(`$````-4:`@`,````YAH"`!4`
M``#S&@(`'@````D;`@`,````*!L"`!<````U&P(`"@```$T;`@`7````6!L"
M`!X```!P&P(`!P```(\;`@`:````EQL"`!P```"R&P(`!@```,\;`@`&````
MUAL"`!(```#=&P(`#````/`;`@`7````_1L"``4````5'`(`"````!L<`@`.
M````)!P"`!$````S'`(`$@```$4<`@`3````6!P"`!,```!L'`(`!P```(`<
M`@`&````B!P"`"@```"/'`(`&P```+@<`@`:````U!P"``<```#O'`(`%0``
M`/<<`@`&````#1T"`",````4'0(`(P```#@=`@`>````7!T"`"L```!['0(`
M"P```*<=`@`)````LQT"`",```"]'0(``P```.$=`@`@````Y1T"``8````&
M'@(`"@````T>`@`"````&!X"``P````;'@(`%0```"@>`@`+````/AX"`!D`
M``!*'@(`(````&0>`@`7````A1X"``4```"='@(`"@```*,>`@`5````KAX"
M`!(```#$'@(`#0```-<>`@`)````Y1X"``X```#O'@(`#````/X>`@`7````
M"Q\"`%@````C'P(`'0```'P?`@`T````FA\"`"H```#/'P(`%````/H?`@`,
M````#R`"``4````<(`(`#0```"(@`@`4````,"`"`!@```!%(`(`)P```%X@
M`@`(````AB`"`!$```"/(`(`#P```*$@`@`@````L2`"`!@```#2(`(`$```
M`.L@`@`B````_"`"``X````?(0(`)@```"XA`@`S````52$"`#4```")(0(`
M$````+\A`@`0````T"$"`#H```#A(0(`.0```!PB`@"1````5B("`#(```#H
M(@(`(@```!LC`@`<````/B,"`!P```!;(P(`,0```'@C`@`M````JB,"`#8`
M``#8(P(`,0````\D`@`@````020"`!H```!B)`(`+````'TD`@!-````JB0"
M`$H```#X)`(`0````$,E`@`:````A"4"`",```"?)0(`&P```,,E`@`9````
MWR4"``\```#Y)0(`!P````DF`@`(````$28"``D````:)@(`%@```"0F`@`,
M````.R8"`"H```!()@(`$@```',F`@`6````AB8"``D```"=)@(`#````*<F
M`@![````M"8"`%0````P)P(`10```(4G`@!P````RR<"``T````\*`(`)0``
M`$HH`@`L````<"@"``H```"=*`(`%P```*@H`@`'````P"@"`!4```#(*`(`
M0@```-XH`@`&````(2D"``L````H*0(`#0```#0I`@`1````0BD"``\```!4
M*0(`5````&0I`@`P````N2D"`"(```#J*0(`$@````TJ`@`E````("H"`"H`
M``!&*@(`+P```'$J`@`I````H2H"`"\```#+*@(`)0```/LJ`@`5````(2L"
M``<````W*P(`#````#\K`@`.````3"L"`!<```!;*P(`"P```',K`@`]````
M?RL"``P```"]*P(`#````,HK`@`(````URL"`!,```#@*P(`"````/0K`@`%
M````_2L"`!T````#+`(`"````"$L`@`)````*BP"``8````T+`(`#0```#LL
M`@`-````22P"`!(```!7+`(`%````&HL`@`,````?RP"`!@```",+`(`#0``
M`*4L`@`(````LRP"`!$```"\+`(`#P```,XL`@`>````WBP"`!````#]+`(`
M!P````XM`@`)````%BT"`!H````@+0(`+````#LM`@`3````:"T"`"T```!\
M+0(`+0```*HM`@`-````V"T"``<```#F+0(`"````.XM`@`'````]RT"``0`
M``#_+0(`%0````0N`@!(````&BX"``P```!C+@(`#0```'`N`@`,````?BX"
M``4```"++@(`"0```)$N`@`(````FRX"``D```"D+@(`"0```*XN`@`8````
MN"X"``8```#1+@(`#@```-@N`@`&````YRX"``\```#N+@(`#````/XN`@`@
M````"R\"``H````L+P(``@```#<O`@`E````.B\"``<```!@+P(`"@```&@O
M`@"*````<R\"``P```#^+P(`!@````LP`@`C````$C`"`"X````V,`(`)@``
M`&4P`@`T````C#`"`#$```#!,`(`(````/,P`@`A````%#$"`"`````V,0(`
M+P```%<Q`@!7````AS$"`#$```#?,0(`-````!$R`@`C````1C("`"````!J
M,@(`!0```(LR`@`/````D3("``T```"A,@(`#P```*\R`@`&````OS("``T`
M``#&,@(`$P```-0R`@`/````Z#("``\```#X,@(`$0````@S`@`,````&C,"
M``<````G,P(`!P```"\S`@`(````-S,"`!8```!`,P(`"0```%<S`@`(````
M83,"``<```!J,P(`'````'(S`@`&````CS,"`!T```"6,P(`&0```+0S`@`(
M````SC,"`!,```#7,P(`"````.LS`@`-````]#,"``,````"-`(`"0````8T
M`@`2````$#0"`!4````C-`(`!P```#DT`@`5````030"``8```!7-`(`&P``
M`%XT`@`-````>C0"`!P```"(-`(`!0```*4T`@`(````JS0"``T```"T-`(`
M'P```,(T`@`*````XC0"``P```#M-`(`*0```/HT`@`<````)#4"`!(```!!
M-0(`!````%0U`@`(````634"``L```!B-0(`"0```&XU`@`"````>#4"`!8`
M``![-0(`"````)(U`@`F````FS4"`"8```#"-0(`/@```.DU`@`O````*#8"
M`#0```!8-@(`.@```(TV`@!1````R#8"`"0````:-P(`+P```#\W`@`O````
M;S<"`#,```"?-P(`+@```-,W`@!O`````C@"``D```!R.`(`;````'PX`@`[
M````Z3@"`"@````E.0(`4P```$XY`@!R````HCD"`"D````5.@(`1P```#\Z
M`@`J````ASH"`"\```"R.@(`,0```.(Z`@`T````%#L"`!\```!).P(`/@``
M`&D[`@#H`0``J#L"`"(```"1/0(`.0```+0]`@`)````[CT"`$D```#X/0(`
MJ````$(^`@`K````ZSX"`#4````7/P(`0P```$T_`@!V````D3\"`$@````(
M0`(`0@```%%``@`4````E$`"``H```"I0`(`/0```+1``@`?````\D`"`"(`
M```200(`,````#5!`@`J````9D$"`"D```"100(`4````+M!`@`2````#$("
M``@````?0@(`2````"A"`@`W````<4("`"H```"I0@(`)P```-1"`@`Z````
M_$("`"8````W0P(`*P```%Y#`@#K````BD,"`&@```!V1`(`0P```-]$`@!&
M````(T4"`$(```!J10(`.P```*U%`@!0````Z44"`&T````Z1@(`6````*A&
M`@"!`````4<"`#P```"#1P(`/0```,!'`@!$````_D<"`#@```!#2`(`,@``
M`'Q(`@!!````KT@"`#T```#Q2`(`.0```"])`@!`````:4D"`&8```"J20(`
M>````!%*`@`[````BDH"`'````#&2@(`<````#=+`@!!````J$L"`$$```#J
M2P(`.@```"Q,`@!!````9TP"`#P```"I3`(`.````.9,`@`N````'TT"`"X`
M``!.30(`,````'U-`@"#````KDT"`'@````R3@(`?P```*M.`@#3````*T\"
M`!H```#_3P(`+````!I0`@`V````1U`"`"L```!^4`(`6````*I0`@`M````
M`U$"`%<````Q40(`*@```(E1`@`J````M%$"``P```#?40(`O@```.Q1`@!=
M````JU("`",````)4P(`/0```"U3`@`X````:U,"`"<```"D4P(`(````,Q3
M`@!;````[5,"`$,```!)5`(`!@```(U4`@`'````E%0"``0```"<5`(`#0``
M`*%4`@`*````KU0"``L```"Z5`(`"P```,94`@`(````TE0"`!````#;5`(`
M`@```.Q4`@!?````[U0"``4```!/50(`'````%55`@`$````<E4"``<```!W
M50(`!@```']5`@`%````AE4"`#H```",50(`!````,=5`@`7````S%4"``T`
M``#D50(`$P```/)5`@`0````!E8"``(````75@(`"````!I6`@`&````(U8"
M`!4````J5@(`#````$!6`@`7````358"``8```!E5@(`#@```&Q6`@`*````
M>U8"``@```"&5@(`+@```(]6`@`(````OE8"``8```#'5@(`!P```,Y6`@`X
M````UE8"`%P````/5P(`2````&Q7`@!)````M5<"`#(```#_5P(`,````#)8
M`@`S````8U@"`#@```"76`(`+P```-!8`@`J`````%D"`#8````K60(`,0``
M`&)9`@`K````E%D"`#8```#`60(`+0```/=9`@!+````)5H"`"T```!Q6@(`
M0@```)]:`@`D````XEH"`#\````'6P(`.@```$=;`@`Q````@EL"`#4```"T
M6P(`,````.I;`@`K````&UP"`#8```!'7`(`,@```'Y<`@`V````L5P"`#4`
M``#H7`(`*P```!Y=`@`M````2ET"`#````!X70(`.P```*E=`@`K````Y5T"
M`"@````17@(`1@```#I>`@!)````@5X"`"<```#+7@(`-````/->`@!/````
M*%\"`#(```!X7P(`-@```*M?`@`Q````XE\"`#(````48`(`+````$=@`@`I
M````=&`"`"X```">8`(`,P```,U@`@!&`````6$"`"\```!(80(`8````'AA
M`@`-````V6$"`!P```#G80(`(@````1B`@!!````)V("`"4```!I8@(`$```
M`(]B`@`/````H&("`!P```"P8@(`%@```,UB`@`2````Y&("`"0```#W8@(`
M"0```!QC`@`)````)F,"`"4````P8P(`*````%9C`@`G````?V,"`"<```"G
M8P(`)````,]C`@`)````]&,"``,!``#^8P(`$@````)E`@`B````%64"`!T`
M```X90(`#@```%9E`@`0````964"`!8```!V90(`&````(UE`@`?````IF4"
M``D```#&90(`3@```-!E`@`:````'V8"`!,````Z9@(`!P```$YF`@`5````
M5F8"``P```!L9@(`60```'EF`@`(````TV8"`"D```#<9@(`$@````9G`@`5
M````&6<"`!4````O9P(`/@```$5G`@`<````A&<"``P```"A9P(`*````*YG
M`@`-````UV<"``X```#E9P(`%0```/1G`@`*````"F@"`"0````5:`(`"P``
M`#IH`@`9````1F@"``H```!@:`(`'0```&MH`@`M````B6@"``4```"W:`(`
M)P```+UH`@`'````Y6@"``<```#M:`(`"0```/5H`@!,````_V@"`!0```!,
M:0(`!P```&%I`@`1````:6D"``L```![:0(`%P```(=I`@`)````GVD"``D`
M``"I:0(`!P```+-I`@`6````NVD"``T```#2:0(`"P```.!I`@`0````[&D"
M`!X```#]:0(`#P```!QJ`@`0````+&H"`!@````]:@(`'````%9J`@`%````
M<VH"``<```!Y:@(`&0```(%J`@`'````FVH"`#$```"C:@(`#0```-5J`@`1
M````XVH"``<```#U:@(``@```/UJ`@`0`````&L"``\````1:P(`"P```"%K
M`@`#````+6L"``<````Q:P(`"P```#EK`@`+````16L"``H```!1:P(`$0``
M`%QK`@`.````;FL"`!L```!]:P(`'````)EK`@`*````MFL"`#8```#!:P(`
M)````/AK`@`J````'6P"`!<```!(;`(`#0```&!L`@`^````;FP"``8```"M
M;`(`%P```+1L`@!`````S&P"``X````-;0(`!P```!QM`@`'````)&T"``0`
M```L;0(`!````#%M`@`)````-FT"`!X```!`;0(`!0```%]M`@`&````96T"
M``@```!L;0(`#````'5M`@`&````@FT"`!0```");0(`$@```)YM`@`1````
ML6T"`!0```##;0(`&0```-AM`@`E````\FT"`!,````8;@(`0````"QN`@`T
M````;6X"`"X```"B;@(`#````-%N`@`>````WFX"`"$```#];@(`+P```!]O
M`@`I````3V\"`!0```!Y;P(``@```(YO`@`$````D6\"``P```"6;P(`"```
M`*-O`@`%````K&\"``(```"R;P(`$0```+5O`@!A````QV\"`"X````I<`(`
M.````%AP`@`:````D7`"`#H```"L<`(`+P```.=P`@!>````%W$"`#P```!V
M<0(`.P```+-Q`@`\````[W$"`!8````L<@(`?0```$-R`@`I````P7("`%8`
M``#K<@(`*0```$)S`@!`````;',"`#X```"M<P(`+0```.QS`@`G````&G0"
M`#4```!"=`(`,P```'AT`@`S````K'0"`$P```#@=`(`-0```"UU`@`W````
M8W4"`#D```";=0(`'P```-5U`@`N````]74"`#(````D=@(`,@```%=V`@!`
M````BG8"`!(```#+=@(`$@```-YV`@`,````\78"`(D```#^=@(`"````(AW
M`@#&````D7<"`'$```!8>`(`BP```,IX`@`M````5GD"`&4```"$>0(`%P``
M`.IY`@`T`````GH"`"8````W>@(`%P```%YZ`@`7````=GH"`!H```".>@(`
M)````*EZ`@!#````SGH"`"8````2>P(`(````#E[`@!K````6GL"`!P```#&
M>P(`#````.-[`@`+````\'L"``4```#\>P(`!@````)\`@`(````"7P"``4`
M```2?`(`%@```!A\`@`0````+WP"`!4```!`?`(`(````%9\`@`1````=WP"
M``L```")?`(`#P```)5\`@`&````I7P"``T```"L?`(`"0```+I\`@`)````
MQ'P"``@```#.?`(`#@```-=\`@`(````YGP"``8```#O?`(`%0```/9\`@`.
M````#'T"``<````;?0(`"0```"-]`@`)````+7T"`!,````W?0(`$P```$M]
M`@`.````7WT"``X```!N?0(`!P```'U]`@`2````A7T"`!L```"8?0(`!@``
M`+1]`@`.````NWT"`!D```#*?0(`"0```.1]`@`*````[GT"`!(```#Y?0(`
M"`````Q^`@`)````%7X"`"D````??@(`(@```$E^`@`0````;'X"`"4```!]
M?@(`%````*-^`@`+````N'X"``P```#$?@(`#````-%^`@`,````WGX"`!L`
M``#K?@(`$0````=_`@`*````&7\"`!8````D?P(`!P```#M_`@`%````0W\"
M`!4```!)?P(`!````%]_`@`"````9'\"``(```!G?P(`$@```&I_`@`&````
M?7\"``8```"$?P(`$@```(M_`@`7````GG\"``<```"V?P(`.@```+Y_`@`"
M````^7\"``0```#\?P(`$@````&``@`$````%(`"`!,````9@`(`&````"V`
M`@`*````1H`"``<```!1@`(`$@```%F``@`%````;(`"`!D```!R@`(`"```
M`(R``@`7````E8`"`!4```"M@`(`$P```,.``@`"````UX`"``X```#:@`(`
M#````.F``@`-````]H`"`!8````$@0(`%0```!N!`@`;````,8$"`#H```!-
M@0(`!P```(B!`@`)````D($"`!$```":@0(`!0```*R!`@`"````LH$"``L`
M``"U@0(``0````````!X!@``BP8``````````````````,T#``!S!P``:P<`
M`.P$````````Z@$``'X$``!,!```&0$``,H!```Y"````````.X&```Z!```
MH0(``*($```S```````````````$!@``_@$``/H#``"^!```70$```````"\
M!```F@8``/D$````````Z@0``-`!``#G!@``W`8``!4!``"D````"````+D`
M``"D`@``\P0`````````````C@@``)D!````````P0```!8!``"``P``,0<`
M````````````Q`,``$,$```.!@``T`````````"Q`@``;`@``,D$``!K!@``
M8@$``"P"``!5!@``CP@``#4(````````W`,``,($````````4`@``(H!````
M``````````````!U`@``Y````,X%``!:!0``*`0``#T#``!]!@``5@4```@#
M``!/!P``Q@,``+(%``!I`0``(@0```````"P`@``80@`````````````/00`
M`-X#```F!0``>00```````!C!0``@P(``$,"``!2!````````"8```!<`@``
MV@8``!P"````````/P0```D(``#L!P```````$,(``!2`0``V04``'P#``#V
M!0``#08````&``#%!0``,P@``.0#``#-`@``!`$```````"M!0``,04``'<"
M``#?!@``E`,``'4(```Z`0```````.0!``#O`0``+P```)8%``!7`@``404`
M`!((``!D!```!@0``#`(``!(!0``Q00``````````````````$8%``"-`P``
M3`8``($"``!W"`````````(&`````````````'P"``"0!@```````)L%``!E
M`P``$`<``#X'``">````;P<`````````````)`,```````"C!0``NP8`````
M```D!@``Y@8````$``````````````````"/`````````*P!```X!0``_0<`
M`+(!``";!@``>08```````#R`0``BP(```````!,`@``!`(``(H%```I`@``
M$00``&X$``#"`P``,@,``!(#````````?04``#D%``"``@``L@8`````````
M````A04`````````````P`0``%\$``#M`P``_`,``,(!``#X!@``````````
M````````AP$``!,'```A````'````&P%``#@!P``:P,``&<&````````"`<`
M`'<%``"_`@``.P,``!<$``!@`0``$@4``$(&``";`P``0`@``&\%````````
MH`4``+4```"6!P``!````'X"``#/!0``_P8``-8!`````````````!H$````
M`````````,L'``":`0``6@<``+@```!""````````/H"````````B`<``'0&
M```U!P```````,P'```K!0````````X!``#(````_@(``"8"````````````
M`,P&``"[`P`````````````8!P``6P(``(8(``!4!0``-P,``,@"``!="```
M`````"D!````````?@,``)($```9"````````,D```"^````%@0``!X(``"(
M!0``90$````````;!0``Q0```.4#``#\!P``+`4```````!&!P``,P(``'X(
M````````.````+8#``!_`@``)P8```````!6!@```````$L"``"J!@``U`8`
M`%(&``#C`0``,````.D'``````````````````#'!0``.@4```````"?!P``
M`````"H$``#4!```8@8``,T'````````````````````````AP8``'T!``#-
M!```7`0```````#F!P``J`,```,!``!_`0``=P```-("``!I`@``K0```*,"
M``!)"```$@8```````"("```<`4```4"```\````$P(``"T&``#9`P``X0,`
M```````'!@``^08``#4#``"%`P``,P<``(X"```&!@``````````````````
MA`@```````#W!```104``*D%``#U!@``,0```$(!``#N!P``M`$``&T%``!:
M"```PP```*0$``#'`````````#0$```D"```/`4``'@'``#!!0```````+H`
M````````B0(```````!S!@``7`,``'X%````````5`0``(P$```B!0``NP(`
M`)<```!$!```?P0``/D%``!M`P``60$``"4&```E`P``%0```+@'``#``@``
M!P4``)\%``"Q`P```@```%`!``#'!@``8@4``%D"``"Y!0``]`8``'8`````
M````*P0``$H!``!%`P```````!4(``#(`0``;@$``%,%````````.@```),`
M``!I!P``C0$``"8&``!?"```P0(```````#2````.P4`````````````G```
M`/,#``"0"```;P```%D(``"9!@``?````.,%````````S`,``"$"````````
M`@0``.H&``#1!@```@,``+T&````````^P4``($$`````````````!P!```%
M!0``#`@``$L&``#D!0``"0,``(<#``!#`````````!L`````````````````
M``!K`0```````)H"``#5`P````````````#/!````````)@!``"E`P``&@,`
M`%,```#P`0``6`4````````_!@``,@```,X#``"=!@``6P```.`#````````
MIP(``"\'``!``0```````,X!`````````````(@#``!8````(0$``*<!````
M`````````(8````5`P``````````````````DP$```````"#!````````*8&
M````````[0````T#``#Y!P````````````!L`P``B04```````"8!```````
M`+$```#F`0``D0,``+P#`````````````-X$``#F```````````````[!```
MD`,``%(```!F````9`(``)`!``",`@``?`@``)$'``"'!0``Q@<```````!H
M"````````#D#``"_`0``M`0``%P'``#F`@``'`@``.$&````````-08``(X'
M````````O@$``)D#````!P``'`<``&P&``!B"````````-D'``#1!```3@4`
M`-`"```&````8`<``#4!``"W!P``TP,```````#N!```:`4``!H&```R"```
M%@4``&X`````````&`4``*`$``!T!P``V`4```````!&!@``700``.L%````
M````Y@,``*X!``",!@``9@0``+,!``!X!```;`0``,8```!H!P``&@<``,T&
M``"G!```/P,````````0"`````````````#9!@``OP0``#L```#V`@``!0@`
M`$L$````````)`0``!H(```4`@``Q`8``+D!``!@!@``$0(``%P&``"C!@``
MY`(``/X%``"X!0``V````*P"``!X!0``3`@``"D(```*"```UP<``(0$````
M````H`(``#("``#T!P``=`(``+P"``!V!0```````(4'``!P!P``B@```$P'
M``"X!@``H0````````!R!0```````-@!````````,0@`````````````6P,`
M``````"5!0```````*@$```B!@``6@0``)$!`````````````)4````>!P``
M`````%8(``#L`@````````````!O!@``@0@```````!9````"P$``#P#```T
M`P``W@4``%D$``!\!@``.P(``'X&``!/`````````(T```#7`@``3@8``!\(
M````````B@0``&0&``"S!0``#````.H"``"Y!````````-4$``"N`@``<`8`
M`(($````````L@<```````!1!@``H@4``'$````@"```]P<`````````````
M+````#P$````````AP(``!4"``"?!````````-<$``",!0```````%P!````
M````````````````````H`<``/\%``"2!P```````-\!``!L`0```````'L`
M``````````@``+T%``!.!P``X@(``-X&``!7````+@$``'T"```"`@``NP$`
M`"@#``#-!0```````%8```!K!```=`@``(`'```T!0``WP(``'$!``"V`@``
M'00``$X````0`0``E````+`'````````VP<``'@```#8!P``7@@``$L%``#K
M`@``FP```&4%``#Y`@`````````````K!@``20$``.X#``!Q!```3@,``$\(
M```'"```908``-($``"]````#P$``'X```#E`0```````/,"````````````
M`%$```!%!P``EP,```````#O!0```````)H$`````````````#T"````````
MFP(``'<$``",`P``Q@$``),'``````````````````##!```K@,```D%```B
M`0``L0$```````!3!```,`0`````````````<0,``!4$```H!P``L`,`````
M`````````````#0"``#7!@```````'8&`````````````/$#``"D!P``!@,`
M``````#:`````0,```````##!0``80````````!A`0``!P$``.H'````````
ML08``(T'```@!P``*`$``,`'````````9P````X```![!P````````````!M
M`@``-````&8'```7`P``=08`````````````T`8```````"I`@`````````#
M```=!@``_P$``(0"```\!P``604```````#^````]04``*,```!C!@``V0$`
M`%L$````````E`(``-L```"`````)@0``!L&````````%P4``#@$```9`@``
M^0$``*,!``!G!```Y0(``-@#``"C!````````*,'```J!0```````)8"```G
M"`````````````#D!P```````+("``#Q`0``X@```)(%````````&P$``#$"
M``".!```@0$``!0``````````````!0$``!O`@``&0,``&H"``!+"```IP``
M``````",````]@```"0!````````&0````````!R`0``V`0``(D#````````
M9@$``!@````K````_P```,0%``"1!0```````/T"```Y````'P0```````#"
M!@``(P@``%@!````````E0(``/0$``#!!@``Z00``(0%``#5!0``7@0``/P$
M``!C`P``-@4``%D'``"^!@``<```````````````3P(````````^"```9P4`
M`/$%````````:@`````````!`0``2P```'4!````````:@,``'0```!["```
M2@(``*8```!/!````````,<'``!%"```\@8``*H`````````````````````
M`````P,`````````````100```````!>`@``;`<``"D#```;!P``+0(``%<'
M``!5`0``2`,``+P&``#P!````````*P'``#U`P``EP$``$D````9!@``````
M`,@#```J"```(@@``#H'``#%!@``X`8``',"``!M````<P@``-L%``#X`P``
M_@<``/\"````````%`8``!8'``#@`0``OP```+D&````````JP<``.L#````
M````$@```/\$``#V!@``B0<```````#]!```J@$``#L&````````]P,``/$'
M```@!```?P@``#<```#%`P``J@(```L&```C`P``300``$8#``#1!P``A@,`
M`(8$```E!0```````(((````````W0```.X%``"X`0``&`8``/H'````````
M;P$``&H&``"=`P``)0@``*`!```]!@``DP8``+,'``!R!P``=@<``)(!````
M````VP,``((&``!M!```/@$``$<#```X!P``9`@``&<"```/`P``@08``!T%
M``!N"```@0<````````6"````@<``)X&````````3@$```````#1`0``X00`
M`*$$```C!@```````%H#``#@`@```````.('```,!0``G`4``%,"``"7`@``
M^`(``"H'``"9``````````````"K!0``>@@````````)!@```````$0!``!P
M!````````,`&``!Y``````````$%``#5````X0<``!,(``!8!@``&@4``/T#
M``!Z`@``*`@```````!,`````````,X$``#=!```$@(````````Z`@``````
M`(T"``!-"```0@4``,\'``"8`P``DP4``$L'`````````````-8#````````
MJ`$``,H#````````20(``/D````P`0``R0$``",$``!Z`P``/0<```````!@
M"```I00``(X&``#[`0````````````"[!P``#`$``*4!``!Y`P```````#<"
M````````[`,``!(!``!G!P```````(4(``"G!0``0@````````#?````````
M`($#``#3!```*@$``+D'`````````````$<'````````>0(``+4"````````
MH08``+H'```?!P``]0(````````O`0``+P8``,0$```X!@``\@(``/`%``#/
M`@````````````"*"````````'<!`````````````'4#``"D!0```````%0(
M```'`P``]`(``!,&`````````````!,$`````````````!T!```+"```````
M`,D'``#@````1P(```````#P!@``\P```*<'``````````````````"4`0``
M````````````````RP(``+$$``!U!P``%P<`````````````%08``+D#````
M`````P```(H'```$"```MP,``(L%``"W!```9@@```````#?!```A00``)$`
M``#A`0``EP4``"\(````````T0```/8#```H!0``U`(``$@'``!3!@``````
M`'0#``#`!0```````+8&````````=@@```(!``"Z`0``-@@``(,'``">!0``
M``````````"W````XP(``.H`````````\@<``#`&``#2`P````````H#```>
M`0```````-8$```I!0``.@8``(`(```^!````````+,&``#[!P``=04``"$#
M``#-````U0<```````!5!```BP$``+H%``#/!@``WP,``,@'````````DP0`
M`"X"```)`@``%`4``*D#``"$`P``YP4``!@$````````OP,``"<```"4!```
M``````````"S````ZP$``/(```!(`@``0`<``%4````X`0``UP```+\&``"E
M!0``8P0``/L```"+!```HP,`````````````-`8``%D&```E`````````'<#
M``!\!0``2@`````````D`@``C@``````````````8@`````````7!@``````
M``````!U!````````*\%```/`@```````&$"````````:@4``$P%``#K!P``
MM@```-H#``#F!0```````#(!````````)`<``/(#``!*`P``0@(``%0&``"8
M`@``8P```````````````````"P$````````=@$``.`%````````:P4`````
M```J!@```````````````````````*\```!:!@``C`$```X(```S`0``*P<`
M`,0"``!/!0``Z`````````"E````'0<`````````````@P````````">!P``
M@`4``,4'````````G`0```X%``!D`0``=@(``'L#```U!0``#0````````#N
M`@``_04`````````````N@0``!\!``!H`P``#0<``%D#```1!P``+0<``&,"
M``!"`P```P(`````````````T`<```0'````````]0````````#^!@``````
M`(('```E`@``K@0```````!'!@``OP<``.P!````````8@,```````!8`P``
M5P8``!X%``"'"```00,`````````````I@0``/4'```Y!@``5@(``$8(```@
M`P```````-P!```M````,P0```````!!!@`````````````3`````````/@`
M```0`P``"@$``````````````````/,%```G!P``E`8``!\&``"P!```]@0`
M`.\'``#:`0```````,P```!=!@``208``)@&``!?`@``_P<``+`%````````
M`````.@'``!)!```P@<```<```"#`0```````$$'```:````I@(``&$$````
M````C0@``,X&```@!0``:P(```````"M!P``PP8``'\```#G`0``N`,`````
M``#[`@``>@0``'X'````````S0$```D````'!```30$``,H`````````]00`
M`.@&````````3P$```8!``"6!@``70<```````!*"```[P0```@&``#,!```
MZP0``&L````N`P``5`````````!]!```/`@``#8````L!@```````#@"``"/
M!P``Z`(``(8%```^!@``QP0``-P'`````````````!,#``#,!0``8`4``+0%
M````````)P0``,\#``!@````-0(``#8'````````!`4``/T&``"0!0``<@8`
M``L%``"N!0``KP0`````````````Y00``&X%``````````````````"2````
MPP$``&@`````````\`,``*<#```5!0``;@<```\(``"I`0``:`$``%0!``#3
M`@``-00``"X````>`P``50<``!@!```T"```5P$```,%``"+"```#P8`````
M````````X`0````````N"```^P8`````````````+`$``)````"]`@``````
M`/X$``!:`@```````,H%``![!@``3P,``/P```!R`````````#@#``"J`P``
MPP(``/0!``#+`P```````",'``!5`P``(@<``"(#````````$0@``#$#````
M````$`0`````````````Q@8``"H#``!3!P```````,L%``#B!0``"00``#D"
M``"=`0``7P,``$$"``!.`@``W`(``/(%```1!0```````*P&``!'`0``)@$`
M``````!@!```:P@``%,(``"_!0```````#@(```!`@````````P#``";!P``
M````````````````(00``&('`````````````,D&``#C!```&`(``'H%``!S
M!0``G@$``$P#``!8`@``'0```)`'```E!P``50@``',$``"F!0``%`,``+0&
M``!]```````````````J`@```````,`!``!F!0```````)D"````````````
M`+X'``"D!@``W@<```0#```0!0```````$8$``"H`````````*\&````````
MG04``````````````````&T'``#0`P``K`0```````"$!@``80,``,D#```_
M`0``;P@``)H'``````````4``%8$``"I!@``E@```#<$`````````````/@!
M``"Z`@``LP0``&D$``#7`0``#P4``$$%``!X`0```````-@"````````.0$`
M`!L(``#F!```5`,``*L"````````0`4``#`#````````&P0``*D'```.!P``
M[P```#\'````````VP$````````L"```"@<```````!>`P``1P@`````````
M````9`<``"<!````````:@0``%('``!Y"````````"@````8`P```````!\"
M```W`0``"@(``%,!``!4`@``T@4```````"5!P``F00``)P!```.`@``````
M`*T"``#C`P``U`,``/<&```G!0```````*4'```V`P``T@<```L"``!>````
MU0$``/H$`````0```````',!```````````````"``"T!P``RP```%H`````
M````E@,```````#R!```G0```*('``":!0```````'`"``!Q!@``G@0``/@$
M``"#`P````````@%```7`0``D0(```P"``!``@``^0,``.<'``"\````````
M`'L%````````*P@``#P&``!3`P``XP```"D'``!=!0``MP4``(\%``!J`0``
M(``````````4!P``'P,``&\#````````2`8``)\!``"5!@```````"X%```%
M`P```````,("``````````````````!N`@``%P```"0```!P"```W`4`````
M`````````````*(&```Y!P``1@$```(%`````````````/,!````````````
M`"<#````````F`<``!,%``#K````:`(``$$```#=`P``+0$``!X"``"#"```
M/P(```````"%`@```````#`%``"P````-@(```````#.````20,``+0```!$
M"```>P$```````"?````'@``````````````?P<``(X!````````AP0``(P'
M````````E0$``#T!``!#`0``/@(```````!1!P`````````````2!P``IP8`
M`)4$``!M!@``'P4``-D"``")!````````'P$``"Y`@``E@$````````/!```
M2`$``,\```"\!P``<@,``,<!``#M`@``LP(````````%!P```````&,(``!(
M``````````````"B`0````````````!Y!P``ZP8``!D%``"^!0``^`<``"D$
M``#`````O0$``*L`````````C04```````"(`@```````&T!``!D`P``````
M`#T(``!N!@```P0``$X(```9!P``4`4``)T$``!E"`````````````!$!P``
M`````%$$``#I!0``8@0```````#[!```]@$``'H'`````````````'8#``"/
M`P``Z`,``.<#``#E!@``$0,``$T&``#M!0``[08``+X"````````5P,``%8!
M````````@@(```````!I`P```````"0%``!T!0``/`$``!\````C`0``R`4`
M`'H!````````B@8```````!_!@```````-T!``!_!0``M@0``!L"````````
MJ`8``"(```"Z!@``:@@``````````````````+P!```6`P````````@!````
M``````````````!"!P``F```````````````:0@`````````````^`4``"\"
M````````Z`4``*4"``"D`P``4@(``,,'````````)@@``-\%``!$````````
M`$D%``!>`0``G@(```$&``#2`0```````(0!`````````````!$&``#0!0``
MM@$``.4%``"%!@``0`,```@(```P!P```````%X'``!S````C00``-8`````
M``````````T$````````KP(```````!P`0``X@$``)P&``"K`0``.P$``/$`
M``#&!```6P<``*$#``#J`P``@`$``$T`````````#0@``)P"``#,`@``#P``
M`$<%`````````````,X"``#N````````````````````*P,````````["```
M4`0``%`&```W!P```````$$(```A!P``#P<````````'`@``EP8```````"(
M!````````!@(````````\00``((!`````````````/0%````````)0$`````
M```1`0``H@````````"U!@``K08```````!"!```30,``)("````````!0``
M`(<`````````/@```*H$```@!@``J@4``/\#``"5`P``40@``/P%```-`0``
M70(``/,&``!7"```YP```'($``"@````10$``-8'```+`P``UP4``)0%```&
M`@``B0````````"3`@```````*P```"<!P``K`,``-X```!#`P``K@8``*@"
M``!H!````````````````````````'P'``"(!@``<04`````````````%P@`
M``````!A!0``+P0```X#````````!08```X$````````$0```%T`````````
MG0(``%`"```5!P``_0$``$0&``#Z`0``)00``$H$`````````````,4"````
M````-0```%(%``#3`````````/H```"W`@```````)`$``!D````R0(``"H`
M````````O0,```````!]!P``#04``(X%``"6!```%P(``*L&```#!P``````
M`"L!```A!0``2`0```````#I!@``K00``(L`````````U`$``&<#```V!```
M"0$``-,!``#O`P`````````````!!P``````````````````-P@``(H#````
M````Q```````````````GP,``-4&``#L!@``@P8````````=`P``;0@```T"
M``!+`P``G0<``"X&````````!P<`````````````,@8``*\#``"7!```]P(`
M`%$"````````)@,```````![`@``P@4``+4%```="```30(```D'``"/`@``
MG`,``/0```#H`0``3`$``&,'```I``````````L$``"[````T`0```````!%
M`@``C08``$,'````````=`$``.0&````````,P4``$\&```&!P``^P,``+<!
M``#=`@``50(``)H#``!@`P``20<``(8'````````0`````````#B!@``$`(`
M``````````````````````"Q!P``YP0``+0"```R!P``.@,``$,&```\`@``
M-`<```````"O!P``]P$``(D!``"F`P``````````````````K0,```````!7
M!```XP<``(D(```I!@```00``#H(```:`@``A0``````````````7@4``-P`
M``")!@``U@4``&<(`````````````#,&```V`0``H0<``-$#```A!@``:08`
M``((```O`P``V0`````````6````RP0```````"9!P``4````.@$``!P`P``
M;````'4`````````W@$``(`$`````````````"`"````````>@8```````#Z
M!@``9@8``-T'``#/`0```````+@"``#B`P``````````````````0P4``&0%
M``"V!0``$@0```````#V!P``V@0``(8&``#^`P```````$0%``!;!@``"`(`
M`"\%``!Q"```30<```H%``#Q`@``L`8```,&``!$`@``JP,```````!:`0``
M`0@``#\```!<````,08``'$"````````/0```.H%````````````````````
M````6P$```````#1!0``F04``*L$``""````U`<```````#L!0``B@(``.,&
M``#U`0``W08``/`'``"N````-P8````````$!```90```$8"``"1!@``Q0$`
M```````@`0```````(0```"I````H04``(8"``!+`0``10```.T!````````
M`````'$'``"8!0``6`@``-L$````````!0$``!`&```C!0``C`@`````````
M````Q`$``((%``!&````-`$``-0```#I`P``PP,``%$#``"U!```P00``"P#
M``#P````X0(``'("```4"````````%P%````````'@8````````[!P``_0``
M``````"'!P```````$4&``#A````90(``,8%``!Z````U0(``,<#``#E````
M6P@``+(```#*!@``<@@``,8"``!X"````````'P!```P`@``Q`<``+0#````
M`````````(L'````````L@,```````!*!P``]`,``$$!````````]P```(`&
M``!>!@``U@(``.X!``#:!0``O00```````"$!P``/04```````#8!@``````
M````````````!00``"("``"7!P``8@(``+8'``#.!P``P0$``#($````````
M?0@```````#!`P`````````````+````>0$```8(``!2`P```````.D"``#+
M!@``0`8``%<%```,!P``R@(``&@&``#B!```GP(``/,'``"R!```M0<``+T'
M````````9P$`````````````J00``%L%```N!P``"@````,(``#\!@``````
M`!8"``#``P``P0<``*(#``"X!````````(8!`````````````!P&````````
M`````$H%``#6!@``QP(```````#Q!@``K0$``)(#``#>`@``)P(``&$&``![
M!```80<``&4'```+!P`````````````L!P```````"T%``"U`P``'`,``-\'
M``````````````````"@`P``000``-H'```R!0```````),#```H`@``````
M`(L#``!F`P``O@,````````M`P```````#\(````````'`0``.$%````````
M?P,``%\!```V!@``!@4``($%``!S`P``8P$``-H"````````[````%\&```:
M`0``'@0``.\&````````YP(``+,#```M"```7P4``,P!``#D!````````+`!
M``````````````````#W!0``"@0``(,%``#\`@``+00``*8'````````[P(`
M``````!^`0``F@````````"/!@```````!8&``#9!```6`0``&D%``!.!```
M9@(``%P(``#3!@``GP8``(\!``#Z!0``-P4``-0%``#*!```M0$```````#P
M`@``1`,```````""`P``@0````````#(!@``E`<`````````````Z0``````
M``!W!P``Z0$````````C`@``,00``-<#```_!0``D@8``)L$``#*!P``````
M`-,%````````I08```````#;`@``,P,``"L"````````MP8```````#)!0``
M``````````!1`0``7P<``'D%``!?``````````````!W!@``;`(``/P!```,
M!````````$<````A"```70,``-$"```^!0```````'0$```<!0``CP0``&4$
M``"Q!0``%`$``%8#```9!```Y0<``*("``!8!P``2@8`````````````$P$`
M`*@%``"L!0``A0$``%8'````````NP4``+P%``#=!0```````(@!``!0`P``
MC@,```````">`P``*`8``-,'```,!@``T@8``,L!``"D`0``4@@``%0'``!5
M!0``J`<``)`"``!V!```1P0```````#"````2`@```````"N!P``.00``#X#
M````````304``&`"``"1!`````````````!X`@``'0(`````````````````
M`!````#;!@``:0```'T#``#M!````````%`'``"@!@``"@8``&H'```;`P``
M+@0``'@#```F!P```````.T'```C``````````````"Z`P``J@<``(@```"[
M!```H0$``&\$````````,0$``)L!``!`!````````&X#``"O`0```````*8!
M```(!```R`0``-P$````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I
M`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D
M87DI`"!!9&0@86X@24U34"!!9&1R97-S($)O;VL`($1E;&5T92!)35-0($%D
M9')E<W,@0F]O:P`@870@`"(E<R(@86QR96%D>2!E>&ES=',@86YD('=A<R!N
M;W0@:6UP;W)T960N`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES
M(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B
M)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B
M('=A<R!N;W0@8V]P:65D(&)E8V%U<V4@:70@:7,@82!L:7-T+@`B)7,B('=A
M<R!N;W0@8W)E871E9#H@)7,N`"(E<R(@=V%S(&YO="!M;W9E9"!B96-A=7-E
M(&ET(&ES(&$@;&ES="X`(D9I<G-T;F%M92!,87-T;F%M92(@("AI92X@2F]H
M;B!$;V4I`"),87-T;F%M92P@1FER<W1N86UE(B`H:64N($1O92P@2F]H;BD`
M)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@
M86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E
M9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@
M2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E
M<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A
M9&1E9"X`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&9I;&4@
M<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE
M8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E
M<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!"
M;V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`
M)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@
M:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK
M<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P
M97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@
M)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(
M;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`
M02!B<F]W<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9`!!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L
M;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W
M(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T
M+BXN`$%B;W9E('-E87)C:"!F;W)M`$%B<V)O='1O;0!!8G-M:61D;&4`06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-E<W,@9&5N:65D('1O("5S`$%C
M8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R
M;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL
M9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@
M4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H
M:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&%D
M9')E<W,@8F]O:P!!9&0@86YD($1E;&5T92!)35-0(&%D9')E<W,@8F]O:W,`
M061D(&-O;'5M;@!!9&0@9FEL90!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`
M061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;P!!
M9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D
M9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E
M9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D
M:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N`$%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061D<F5S<R!";V]K
M($QI<W1I;F<`061D<F5S<R!";V]K<P!!9&1R97-S(&)O;VL@96YT<GD`061D
M<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N`$%D9')E<W,@8F]O:R!T
M;R!D96QE=&4@`$%D9')E<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B92!D:7-P
M;&%Y960Z`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9'9A;F-E9"!396%R8V@`069G
M:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N
M=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL
M(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!
M;')E861Y($5X:7-T<P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,
M;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5
M<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M
M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S
M(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0
M<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P
M<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A
M9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E
M(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL
M92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N
M="!T;R!D96QE=&4@)7,_`$%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O
M(&1E;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@
M<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#
M24DM."D`07)T`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I;VX@27-L86YD`$%S
M8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I
M9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`
M075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S
M;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T
M($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R
M(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X
M8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O
M<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A
M:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O
M<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S
M96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5L
M;W<@<V5A<F-H(&9O<FT`0F5N:6X`0F5R;75D80!":'5T86X`0FEN9"!F86EL
M960Z("@E<RD@)7,`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO
M;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!"
M;VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S
M.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N
M80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y`$)R;W=S90!"<G5N96D@1&%R=7-S86QA;0!"=6QG
M87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$)U<VEN
M97-S($-A=&5G;W)Y`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`
M0U-6`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#
M86XG="!A9&0@82!G<F]U<"!T;R!I='-E;&8N`$-A;B=T(&%D;6EN:7-T97(@
M97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL
M92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R
M:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL
M(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L
M;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N
M=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N
M("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E
M($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG
M92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P
M;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAE
M8VL@7T%L;"].;VYE`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P
M;&EC871I;VXZ`$-H;V]S92!A(&YA;64`0VAO;W-E(&$@<&%S<W=O<F0`0VAO
M;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%D9')E<W,@8F]O:P!#:&]O<V4@
M86X@861D<F5S<R!B;V]K.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#
M:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!D:7-P;&%Y+"!A;F0@:6X@
M=VAA="!O<F1E<CH`0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E
M+@!#:&]O<V4@=VAI8V@@8V]L=6UN<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T
M(&]R9&5R.@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R
M(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S
M97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K
M871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R
M;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I
M9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@
M4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN($]P=&EO;G,`
M0V]L=6UN('1I=&QE<P!#;VQU;6YS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA
M>65D.@!#;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A;'5E<P!#;VUM82!S97!A
M<F%T960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RD`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY
M`$-O;7!A;GD@061D<F5S<P!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO
M;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O
M<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN
M`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#
M;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@
M9F%I;&5D.B``0V]N;F5C=&EO;B!F86EL960Z("5S`$-O;FYE8W1I;VX@9F%I
M;'5R90!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$-O;G1A8W0@4V5A<F-H`$-O;G1A8W1S`$-O;G1A8W1S(&EN(&QI
M<W0Z("5S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F
M:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`
M0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O
M<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z
M(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C
M:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@
M1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R
M>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@
M;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L
M:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T
M(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I
M;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R
M('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L
M9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S
M(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@
M)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#
M;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I
M<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E
M('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C
M:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S
M+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F
M:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A
M<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W
M:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E
M>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@061D<F5S<R!";V]K
M`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W($-O;G1A8W0@3&ES="!I;CH`
M0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871E9`!#
M<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA
M`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E
M;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@
M5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T
M('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@
M*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z
M96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`
M1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$
M871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M
M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E
M9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@
M4VAE;&P`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`
M1&5L971E`$1E;&5T92!!9&1R97-S($)O;VL`1&5L971E($-E;&P`1&5L971E
M($-O;F9I<FUA=&EO;@!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@
M4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!B
M=71T;VX@8F5H879I;W5R`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@9F%I;&5D
M.B`H)7,I("5S`$1E;&5T92!M97-S86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L971I;F<@8V]N=&%C=',@:7,@;F]T
M(&%V86EL86)L92X`1&5L971I;VX@9F%I;&5D`$1E;&EV97)Y('1I;64`1&5N
M;6%R:P!$97!A<G1M96YT`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L
M96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I
M;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>0!$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES
M<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I
M`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'``1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R
M:65S/P!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M
M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A
M;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O
M=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O=VYL;V%D('9#87)D`$1R;W`@9&]W
M;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV
M97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`
M15)2`$5C=6%D;W(`161I=`!%9&ET("(E<R(`161I="!!9&1R97-S($)O;VMS
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&5N=')Y
M(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O
M<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP
M=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E
M<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N
M9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T
M>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%
M;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@
M>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H
M92!L971T97)S(&)E;&]W.@!%;G1R>2!F;W(@)7,@=7!D871E9"P@8G5T('-A
M=FEN9R!T:&4@=7!L;V%D960@9FEL92!F86EL960Z("5S`$5N=')Y(&9O<B`E
M<R!U<&1A=&5D+@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R
M<F]R(&%D9&EN9R`E9"!C;VYT86-T*',I('1O(&QI<W0N`$5R<F]R(&%D9&EN
M9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C="AS*2!T;R!L:7-T+@!%<G)O
M<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@)60@8V]N=&%C
M="AS*2X`17)R;W(@9&5L971I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A
M8W1S*',I+@!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@
M9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@
M)7,`17)R;W(@<F5M;W9I;F<@)60@8V]N=&%C="AS*2!F<F]M(&QI<W0N`$5R
M<F]R(')E;6]V:6YG("5D(&]F("5D(')E<75E<W1E9"!C;VYT86-T*',I(&9R
M;VT@;&ES="X`17)R;W(@<V5A<F-H:6YG('1H92!A9&1R97-S(&)O;VLZ("5S
M`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I
M80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I
M)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X
M<&ER871I;VX@1&%T90!%>'!O;F5N=`!%>'!O<G0`17AP;W)T($%D9')E<W,@
M0F]O:P!%>'!O<G0@;VYL>2!T:&4@<V5L96-T960@8V]N=&%C=',N`$5X<&]R
M="!T:&4@9F]L;&]W:6YG(&%D9')E<W,@8F]O:R!C;VUP;&5T96QY+@!&1R!#
M;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+@!&86EL960@=&\@86-C97-S('1H92!A9&1R97-S(&)O;VLZ
M("5S`$9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S`$9A:6QE9"!T;R!B<F]W
M<V4@;&ES=`!&86EL960@=&\@8G)O=W-E('1H92!D:7)E8W1O<GD`1F%I;&5D
M('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@3F5W($1.
M(#T@)7,L(%)O;W0@/2`E<P!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E9#H@)7,`1F%I;&5D('1O(&UO=F4@
M=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86EL960@=&\@<V5A
M<F-H('1H92!A9&1R97-S(&)O;VL`1F%I;&5D('1O('-E87)C:"!T:&4@9&ER
M96-T;W)Y.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&
M87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`
M1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@
M4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O
M;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@
M)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO
M;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL
M97,`1FEL=&5R<P!&:6YD`$9I;FES:`!&:6YL86YD`$9I<G-T($AA;&8`1FER
M<W0@3F%M90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O
M9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE
M<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E96)U<WD@55),`$9R
M96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T
M:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R
M86QT87(`1VEV96X@3F%M90!';&]B86P@061D<F5S<R!";V]K`$=L;V)A;"!/
M<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R
M87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'
M<F5N861A`$=R;W5P`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`
M1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM
M`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI
M`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H
M97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(
M;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@
M061D<F5S<P!(;VUE($-I='D`2&]M92!#;W5N=')Y`$AO;64@1&ER96-T;W)Y
M`$AO;64@4&AO;F4`2&]M92!0;W-T86P@0V]D90!(;VUE(%-T871E+U!R;W9I
M;F-E`$AO;64@4W1R965T($%D9')E<W,`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R
M<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@
M;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@
M:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@
M97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!8
M34P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D
M92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(
M;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS
M*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T
M:6]N(&9A:6QE9#H@)7,`24U34`!)35-0($%D9')E<W,@0F]O:R!!9&UI;FES
M=')A=&EO;@!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`
M25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@
M;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N
M9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E
M;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R
M86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E
M(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M
M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T($%D9')E<W,@
M0F]O:RP@4W1E<"`E9`!);7!O<G0L(%-T97`@)60`26UP;W)T+T5X<&]R="!!
M9&1R97-S($)O;VMS`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L
M9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A
M;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO
M;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!)
M;G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E
M<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S
M<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`
M26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C
M;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A
M9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B
M969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L
M:7-T`$EN=F%L:60@240`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%D9')E<W,@8F]O:P!);G9A
M;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN
M=F%L:60@96UA:6P`26YV86QI9"!E;G1R>0!);G9A;&ED(&9I;&4@9F]R;6%T
M`$EN=F%L:60@:V5Y('-P96-I9FEE9"X`26YV86QI9"!L:6-E;G-E(&ME>2X`
M26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`
M26YV86QI9"!N86UE`$EN=F%L:60@;V)J96-T260`26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN
M=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`
M26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L
M:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L
M:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E
M;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M
M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`
M2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU
M;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*
M=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I
M9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG
M97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER
M:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`
M2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER
M9WEZ<W1A;@!,1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0
M(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N`$QA7WEO
M=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`
M3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S="!.86UE`$QA<W0@4&%S<W=O
M<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G
M:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V
M97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H
M;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT
M96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%
M87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E
M<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T`$QI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI
M<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T
M+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R
M:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A
M='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE
M(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN
M8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V
M90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S
M`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A
M9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA
M;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@
M;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I
M=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-
M87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA
M<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9P!-871C:&EN9R!F
M:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET
M+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M
M8F5R(&]F($-O;G1A8W1S`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,`36%X:6UU;2!L96YG=&@`36%X:6UU;2!N=6UB97(@;V8@<&%G97,`36%Y
M`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU($QI<W0`365N=2!M;V1E
M.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-
M971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC
M;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE
M(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!$3B!I;B!,1$%0
M('-O=7)C92!C;VYF:6=U<F%T:6]N+@!-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@
M=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P
M<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER
M960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`
M36]B:6QE($UA:6P`36]B:6QE(%!H;VYE`$UO9&5R871E`$UO9&EF:65D($1A
M=&4`36]D:69Y(%523`!-;V1I9GD@9F%I;&5D.B`H)7,I("5S`$UO9'5L=7,`
M36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N
M9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I
M96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-
M;W)E('1H86X@,2!E;G1R>2!F;W5N9`!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-
M;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3
M=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E
M(%5P`$UO=F4@9&]W;@!-;W9E(&QE9G0`36]V92!R:6=H=`!-;W9E('5P`$UO
M>F%M8FEQ=64`375L8F5R<GD@061D<F5S<R!";V]K`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<&5R<V]N
M<R!W:71H(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@
M86QR96%D>2!E>&ES=`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY($%D9')E<W,@0F]O:P!->2!!9&1R
M97-S($)O;VMS`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`
M3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M92!&;W)M870`3F%M:6)I80!.
M875R=0!.97!A;`!.971C96YT97(@365M8F5R($1I<F5C=&]R>0!.971H97)L
M86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.
M971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@
M55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@
M55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I
M8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R
M:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@0V]N=&%C
M=`!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N
M9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X
M+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA
M;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O
M<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6-K;F%M90!.:6=E<@!.:6=E<FEA
M`$YI9VAT`$YI=64`3F\`3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S`$YO(&%D
M9')E<W,@8F]O:W,@9F]U;F0N`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N
M(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S
M=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L
M871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+@!.;R!C;VYT86-T<R!F;W5N9`!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U
M;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N
M`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N
M=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S
M970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S
M`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V0V%R9"!D871A('=A<R!F;W5N9"X`3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.
M;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`
M3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@
M2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO
M="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M
M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@
M8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@:71E;7,@
M<&5R('!A9V4`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T
M`$]B:F5C="!#<F5A=&]R`$]B:F5C="!N;W0@9F]U;F0`3V-T86P`3V-T;V)E
M<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N8V4@>6]U('-A=F4@=&AI<R!O<'1I
M;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E<FUA;F5N=&QY
M(&1E;&5T960N($EF('1H:7,@:7,@;F]T('=H870@>6]U('=A;G0L('1H96X@
M>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N('1O(").;VYE(BX`3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+@!/;FQY(&]N92!V8V%R9"!S=7!P;W)T960N`$]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO
M;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T
M:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@
M26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N<P!0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I
M;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D
M($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-
M(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M
M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`
M4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL
M($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A
M<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I
M<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M
M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG
M(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D
M+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N(&1E;FEE9`!097)M:7-S
M:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O
M<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I
M;F4@061D<F5S<R!";V]K`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&YA;64@=&AE(&YE=R!C;VYT86-T
M(&QI<W0Z`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R
M979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I
M;W5S`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!!
M9&1R97-S($)O;VL`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R
M:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC
M($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2
M:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U97)Y(&9A:6QE9#H@
M*"5S*2`E<P!1=6EC:R!396%R8V@`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA
M=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N
M9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&9A:6QE9#H@*"5S*2`E<P!2
M96%D(&UE<W-A9V5S`%)E861I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L
M92X`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_`%)E86QL>2!R
M96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+@!296-O<F1S(&1I<W!L87EE9#H`4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS
M:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M
M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V
M90!296UO=F4@0FQO8VL`4F5M;W9E(&%D9')E<W,@8F]O:P!296UO=F4@8V]L
M=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M('1H:7,@;&ES=`!2
M96UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N
M;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R
M.B`E<P!297!L86-E(&5X:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I
M;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R!D96QE=&5S(&%L
M;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN/"]S=')O
M;F<^`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@`%)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+@!297%U97-T
M960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<V5T('1O($1E9F%U;'1S`%)E<W1O<F4@3&%S="!1=65R>0!2
M97-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`
M4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L
M=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X
M,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W
M('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E`%,O34E-12!0=6)L:6,@0V5R=&EF:6-A=&4`4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3
M:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!35$%2
M5%1,4R!F86EL960Z("@E<RD@)7,`4U5#0T534P!37U%,(%-H96QL`%-A`%-A
M:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`
M4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA
M<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R
M`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T
M:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C
M<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A
M=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`B)7,B+@!3879I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L
M92X`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%
M;F=I;F5S`%-E87)C:"!F86EL960`4V5A<F-H(&9A:6QE9#H@)7,`4V5A<F-H
M:6YG(&ES(&YO="!A=F%I;&%B;&4N`%-E87)C:&EN9RXN+@!396QE8W0@1FEL
M97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T
M(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O
M(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!3
M96QE8W0@86X@861D<F5S<R!B;V]K('1O(&1E;&5T90!396QE8W0@86X@861D
M<F5S<R!B;V]K('1O(&5D:70`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N
M90!396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3H`4V5L
M96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.@!396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82X`4V5L96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93H`
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O
M<FUA=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I
M;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E
M(&9I;&4Z`%-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE
M<SH`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E
M;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M
M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=FEE=R!T
M;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD('!A9VEN
M9R!O<'1I;VYS+@!396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@
M=&AE(&%D9')E<W,@;&ES=',N`%-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES
M<&QA>2!N86UE<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&5C=&5D(&%D9')E<W,@8F]O
M:R`B)7,B+@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I
M86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3
M970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z(`!397EC:&5L;&5S`%-H87)E9"!$:7)E8W1O<GD`4VAO<'!I;F<`
M4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W("5S`%-H;W<@06QL`%-H;W<@0V]N
M=&%C=',`4VAO=R!,:7-T<P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E
M('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R
M<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`
M4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N
M871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP
M($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W
M97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E
M<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R
M.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T
M($1I<F5C=&EO;@!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S
M<P!3;W5R8V5S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN
M(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I
M;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P96-I9GD@=VAE<F4@
M>6]U('=A;G0@861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R+@!3
M<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,
M86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0
M<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`
M4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N
M=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&%D9&5D("5D(&-O;G1A8W0H<RD@=&\@;&ES="X`
M4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S`%-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@(B5S(BX`4W5C8V5S
M<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(&1E;&5T960@)60@
M8V]N=&%C="AS*2X`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R96UO=F5D("5D(&-O;G1A8W0H<RD@
M9G)O;2!L:7-T+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO
M;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P
M9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R
M>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS
M970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P
M;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3
M=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`
M4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R
M86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M
M<P!4+5-T;W)M<R!%87)L>0!44U8`5%-6(&9I;&4`5&%B('-E<&%R871E9"!V
M86QU97,`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R
M=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES
M=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K
M<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E
M<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S
M+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M
M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG
M;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@
M97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E
M;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N
M9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@
M:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(%9&4R!B86-K96YD(&YE961S('1O
M(&)E(&-O;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RX`
M5&AE(&%D9')E<W,@8F]O:R`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@861D
M<F5S<R!B;V]K("(E<R(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+@!4:&4@
M861D<F5S<R!B;V]K("(E<R(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+@!4
M:&4@861D<F5S<R!B;V]K("(E<R(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D
M+@!4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S`%1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M
M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@
M;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N
M;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@8V]N
M=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+@!4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@(B5S(B!H
M87,@<W5C8V5S<V9U;&QY(&)E96X@9&5L971E9"X`5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S
M<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&EM<&]R="!C
M86X@8F4@9FEN:7-H960@9&5S<&ET92!T:&4@=V%R;FEN9W,N`%1H92!L969T
M+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B
M(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM
M=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H
M="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I
M9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F
M:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D
M:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!B<F]W<V5A
M8FQE(&%D9')E<W,@8F]O:W,N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL
M86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N`%1H97)E(&%R92!N;R!W<FET96%B;&4@861D<F5S<R!B;V]K
M<RX@3F]N92!O9B!T:&4@879A:6QA8FQE(&%D9')E<W,@8F]O:W,@87)E(&-O
M;F9I9W5R960@=&\@86QL;W<@>6]U('1O(&%D9"!N97<@96YT<FEE<R!T;R!T
M:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES(&ES(&%N(&5R<F]R+"!P;&5A<V4@
M8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@
M<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@
M9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@
M=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N`%1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE=R!C;VYT86-T
M+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@9F]R(&9U<G1H
M97(@:&5L<"X`5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG(&$@;F5W(&QI
M<W0N`%1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D9')E<W,@
M8F]O:SH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG("(E<R(@9G)O
M;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RX`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AE(&QI<W0`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!D871A.B`E<P!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@<F5M
M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S`%1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y.B`E<P!4
M:&5R92!W97)E(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N`%1H97-E(&%D9')E
M<W,@8F]O:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z`%1H97-E(&-O
M;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z`%1H:7,@24U!4"!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H
M:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS
M,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F
M;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES
M('!E<G-O;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R97-S
M(&)O;VL`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;&P@8F4@
M=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R(&EM<&]R
M=&EN9R!C;VYT86-T<RX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE
M(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE
M<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I
M<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A4
M34P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@;6%N
M>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P
M`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4
M;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@
M`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO
M;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E
M<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@;F5W('-H87)E+B!-:7-S:6YG
M('-O=7)C92!T>7!E+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ
M("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N
M`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN
M`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE
M9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@
M8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER
M871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO
M=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`
M56YS970@8V]L;W(`56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<P!5;G-U
M<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E
M<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A
M9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB
M97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E
M<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI
M;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B
M)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R
M<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E
M<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE
M>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@
M:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<FES:6=N($1I<F5C=&]R>0!6
M97)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A
M;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA
M;65S92`H5DE30TE)*0!6:65W("(E<R(`5FEE=R`E<P!6:65W($-O;G1A8W0`
M5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I97<@=&\@
M9&ES<&QA>2!B>2!D969A=6QT.@!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6
M:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6
M;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%
M(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES
M(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H
M97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`
M5V5B<VET92!54DP`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC
M;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U
M.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@
M)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R
M96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED
M=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T
M:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R
M;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I
M<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@0VET>0!7;W)K($-O=6YT
M<GD`5V]R:R!0:&]N90!7;W)K(%!O<W1A;"!#;V1E`%=O<FL@4W1A=&4O4')O
M=FEN8V4`5V]R:R!3=')E970@061D<F5S<P!7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E9
M65D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T
M;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S(&EN("(E<R(N
M`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T
M:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N
M;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA
M<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O
M<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@<&5R
M;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="X`66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VYS('1O(&1E;&5T92!T:&ES('-O=7)C92X`66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U
M(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E
M<W,@8F]O:RX`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N`%EO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+@!9;W4@;75S="!S
M96QE8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U
M(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(
M;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S
M92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN
M="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&%D9')E
M<W,@8F]O:R!I<R!N;W0@8G)O=W-E86)L92X`66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`
M66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M
M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E
M`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3
M:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UT`6VQI;F4@)7,@;V8@)7-=`%MN;R!V86QU95T`7T%D;6EN:7-T<F%T:6]N
M`%]"<F]W<V4`7T-,20!?0V]N=&%C=',`7T1A=&%4<F5E`%]$96QE=&4`7T1E
M;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?
M26UP;W)T+T5X<&]R=`!?3&ES=',`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y
M($QI;FLN+BX`7TUY($%D9')E<W,@0F]O:W,`7TYE=R!#;VYT86-T`%]/<'1I
M;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U)E;6]V92!F<F]M
M('1H:7,@;&ES=`!?4V5A<F-H`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN
M+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N
M9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E
M;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C
M;VYF:6=U<F%T:6]N(&5R<F]R`&-O;G1A8W0N=F-F`&-O;G1A8W1S+F-S=@!C
M;VYT86-T<RYT<W8`8V]N=&%C=',N=F-F`&-R:71I8V%L('-Y<W1E;2!F:6QE
M(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E;G1R>2!N;W0@9F]U
M;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S
M=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE
M`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L
M:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N
M`&UM`&YA;64`;F\@9F]R;6%T=&EN9P!N;VYE`&YO="!I;7!L96UE;G1E9`!N
M;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N
M(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN
M9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M
M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T
M`'1E;7!O<F%R>2!F86EL=7)E`'1O(&$@0V]N=&%C="!,:7-T`'1O(&$@9&EF
M9F5R96YT($%D9')E<W,@0F]O:P!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W
M.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A(#(N,2UC
M=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z-#<K,#$P,`I03RU2
M979I<VEO;BU$871E.B`R,#`U+3$R+3(X(#$T.C(S*S`Q,#`*3&%S="U4<F%N
M<VQA=&]R.B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@I,86YG=6%G
M92U496%M.B!'97)M86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E
M<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`
M("AV;W(@)7,@5&%G96XI`"`H6G5G<FEF9G-T87-T92`E<RD`("AI;B`E<R!4
M86=E;BD`("AH975T92D`("AM;W)G96XI`"`H9V5S=&5R;BD`24U34"U!9')E
M<W-B=6-H(&AI;GIU9OQG96X`24U34"U!9')E<W-B=6-H(&SV<V-H96X`(&UI
M="``(B5S(B!E>&ES=&EE<G0@8F5R96ET<R!U;F0@=W5R9&4@;FEC:'0@:6UP
M;W)T:65R="X`(B5S(B!I<W0@:V5I;B!697)Z96EC:&YI<RX`(B5S(B!I<W0@
M:V5I;F4@9_QL=&EG92!!=7-W86AL+@`B)7,B(&ES="!I;B!D97(@2&]R9&4@
M4F5G:7-T<GD@;FEC:'0@:V]N9FEG=7)I97)T+@!$97(@0F%U;2U296YD97)E
M<B!F_'(@(B5S(B!W=7)D92!N:6-H="!G969U;F1E;BX`(B5S(B!W=7)D92!Z
M=6T@1W)U<'!E;G-Y<W1E;2!H:6YZ=6=E9OQG="X`(B5S(B!W=7)D92!Z=6T@
M4F5C:'1E<WES=&5M(&AI;GIU9V5F_&=T+@`B)7,B('=U<F1E(&YI8VAT(&MO
M<&EE<G0L(&1A(&5S('-I8V@@=6T@96EN92!,:7-T92!H86YD96QT+@`B)7,B
M('=U<F1E(&YI8VAT(&5R<W1E;&QT.B`E<RX`(B5S(B!W=7)D92!N:6-H="!V
M97)S8VAO8F5N+"!D82!E<R!S:6-H('5M(&5I;F4@3&ES=&4@:&%N9&5L="X`
M(E9O<FYA;64@3F%C:&YA;64B("AZ+D(N($UA>"!-=7-T97)M86YN*0`B3F%C
M:&YA;64L(%9O<FYA;64B("AZ+D(N($UU<W1E<FUA;FXL($UA>"D`)2XR9DU"
M("@E,R0N,F8E)2D@=F]N("4R)"XR9DU"(&5R;&%U8G1E;B!V97)B<F%U8VAT
M`"5D("5S('5N9"`E<P!);B`E9"!486=E;B!W:7)D($EH<B!087-S=V]R="!U
M;F?\;'1I9RX`)60M5&%G92U6;W)H97)S86=E`"5S("T@2&EN=V5I<P`E<R!&
M:6YG97)A8F1R=6-K`"5S($M"`"5S(%=A<G1U;F=S87)B96ET96X@+2!"97-T
MY'1I9W5N9P`E<RU+;VYF:6=U<F%T:6]N`"5S(%)E9VES=')I97)U;F<`)7,@
M3G5T>G5N9W-B961I;F=U;F=E;@`E<R!H:6YZ=6=E9OQG="X`)7,@97AI<W1I
M97)T(&)E<F5I=',N`"5S(&UI="`E<R`E<P!$:64@)7,M1&%T96D@=W5R9&4@
M97)F;VQG<F5I8V@@:6UP;W)T:65R=``E<R!W:7)D(&1I92!787)T=6YG<V%R
M8F5I=&5N(&1U<F-H9OQH<F5N+"!D:64@=6YT96X@;6%R:VEE<G0@<VEN9"X@
M36%R:VEE<F5N(%-I92!A;&QE($%U9F=A8F5N+"!D:64@:F5T>G0@9'5R8VAG
M96;\:')T('=E<F1E;B!S;VQL96XN`"5S(&ES="!N;W1W96YD:6<`)7,@36EN
M=71E;@`E<R!N:6-H="!G969U;F1E;BX`)7,@8FES("5S('9O;B`E<P`E<W,@
M061R97-S8G5C:``E<W,@2V%L96YD97(`)7-S($YO=&EZ8FQO8VL`)7-S($%U
M9F=A8F5N;&ES=&4`)7,Z("5S`"5S.B!$:65S92!.86-H<FEC:'0@<W1A;6UT
M('5N=&5R(%5M<W3D;F1E;B!N:6-H="!V;VX@9&5M(&%N9V5G96)E;F5N($%B
M<V5N9&5R+B!&;VQG96X@4VEE(&ME:6YE;B!,:6YK<R!I;B!D:65S97(@3F%C
M:')I8VAT('5N9"!H_'1E;B!3:64@<VEC:"!D879O<BP@9&5M($%B<V5N9&5R
M('!E<G/V;FQI8VAE($1A=&5N('!R96ES>G5G96)E;BX`+"!B]FEG(``L(&)I
M9R`E<R`E<P`L('-C:'=A;FME;F0@=F]N("5S(&)I<R`E<P`M+2!!=7-WY&AL
M96X@+2T`,3(M4W1U;F1E;BU&;W)M870`,C0M4W1U;F1E;BU&;W)M870`,C0@
M4W1U;F1E;@`\6G5R_&-K`$5I;B!"<F]W<V5R+"!D97(@249R86UE<R!U;G1E
M<G-T_'1Z="P@=VER9"!B96[V=&EG=`!&<B!D:65S96X@0FQO8VL@=VER9"!E
M:6YE($1A=&5N8F%N:R!B96YT:6=T+@!%:6X@<V-H=V5R97(@1F5H;&5R(&ES
M="!A=69G971R971E;CH`16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L
M('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT
M(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P@=VER
M9"!F_'(@9&EE(-QB97)P<OQF=6YG(&5I;F5R('5N=&5R>F5I8VAN971E;B!.
M86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P
M<FEV871E<B!01U`M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R="!W:7)D
M(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B96[V
M=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%!'4"U3
M8VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E
M<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E
M;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L('-O
M=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG
M(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U
M;F0@96EN('!R:79A=&5R(%,O34E-12U38VAL_'-S96P@<V]W:64@96EN(%!A
M<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H
M<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@4R]-24U%+5-C:&S\
M<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR
M:6-H="!B96[V=&EG="X`5F]R;6ET=&%G<R!7;VQK96X`5F]R;6ET=&%G<R!L
M96EC:'1E<B!296=E;@!6;W)M:71T86=S(%)E9V5N`%9O<FUI='1A9W,@4V-H
M875E<@!6;W)M:71T86=S(%-C:&YE97-C:&%U97(`04TO4$T`05!)($E$`-QB
M97(@9&EE<V5N($5D:71O<@!);F9O+BXN`-QB97(@9&5M(%-U8VAF;W)M=6QA
M<@!!8G-O;'5T(%5N=&5N`$%B<V]L=70@36ET=&4`6G5G<FEF9B!V97)W96EG
M97)T(&)E:6T@06YL96=E;B!D97,@5D93+59E<GIE:6-H;FES<V5S+@!:=6=R
M:69F('9E<G=E:6=E<G0@8F5I;2!!;FQE9V5N(&1E<B!61E,M1&%T96DN`%IU
M9W)I9F8@875F("5S('9E<G=E:6=E<G0`2V]N=&]I;F9O<FUA=&EO;F5N`$MO
M;G1O<&%S<W=O<G0`2V]N=&\@96EN9V5F<F]R96XN`$)U8VAH86QT=6YG`$AI
M;GIU9OQG96X`3F5U92!5;G1E<F=R=7!P92!H:6YZ=6;\9V5N`$YE=64@56YT
M97)R96-H=&4@:&EN>G5F_&=E;@!(:65R(&AI;GIU9OQG96XZ`$YE=64@1W)U
M<'!E(&AI;GIU9OQG96X`3F5U92!296-H=&4@:&EN>G5F_&=E;@!5;G1E<F=R
M=7!P92!Z=2`B)7,B(&AI;GIU9OQG96X`56YT97)R96-H=&4@>G4@(B5S(B!H
M:6YZ=6;\9V5N`$;\9V5N(%-I92!E:6YE;B!N975E;B!"96YU='IE<B!H:6YZ
M=3H`061R97-S8G5C:"!H:6YZ=6;\9V5N`$E-4U`M061R97-S8OQC:&5R(&SV
M<V-H96X@=6YD(&AI;GIU9OQG96X`4W!A;'1E(&AI;GIU9OQG96X`1&%T96D@
M:&EN>G5F_&=E;@!.975E($UI=&=L:65D97(@:&EN>G5F_&=E;@!086%R(&AI
M;GIU9OQG96X`1&%S("5S+4UE;OP@>G5R($UO>FEL;&$@4VED96)A<B!H:6YZ
M=6;\9V5N`$AI;GIU9OQG96X@>G4`6G5M($%D<F5S<V)U8V@@:&EN>G5F_&=E
M;CH`6G4@;65I;F5M($%D<F5S<V)U8V@@:&EN>G5F_&=E;@!"96YU='IE<B!H
M:6YZ=6;\9V5N`"(E<R(@=W5R9&4@>G5M(%-Y<W1E;2!H:6YZ=6=E9OQG="P@
M86)E<B!D:64@>G5SY'1Z;&EC:&5N(%)E9VES=')I97)U;F=S:6YF;W)M871I
M;VYE;B!K;VYN=&5N(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;CH@)7,N`"(E
M<R(@=W5R9&4@>G5M(%-Y<W1E;2!H:6YZ=6=E9OQG="X@4VEE(&OV;FYE;B!S
M:6-H(&IE='IT(&%N;65L9&5N+@!(:6YZ=6;\9V5N('9O;B!+;VYT86MT96X@
M;FEC:'0@=6YT97)S=/QT>G0N`$1A<R!(:6YZ=6;\9V5N('9O;B!"96YU='IE
M<FX@:7-T(&YI8VAT(&WV9VQI8V@N`$%D<F5S<V4`061R97-S8G5C:`!!9')E
M<W-B=6-H;&ES=&4`061R97-S8OQC:&5R`$%D<F5S<V)U8VAE:6YT<F%G`$%D
M<F5S<V)U8V@@=W5R9&4@97)F;VQG<F5I8V@@9V5L965R="X`6G4@;/9S8VAE
M;F1E<R!!9')E<W-B=6-H`$%D<F5S<V+\8VAE<BP@9&EE(&YI8VAT(&%N9V5Z
M96EG="!W97)D96XZ`%9E<G=A;'1E;B`M(%)E8VAT92!F_'(@86YD97)E($)E
M;G5T>F5R(&9E<W1L96=E;@!!9&UI;FES=')A=&EO;@!797)B=6YG`$5R=V5I
M=&5R=&4@4W5C:&4`069G:&%N:7-T86X`06QB86YI96X`06QG97)I96X`4W!I
M='IN86UE`$%U<W)I8VAT=6YG`$%U<W)I8VAT=6YG.@!!;&QE`$%N9V5M96QD
M971E($)E;G5T>F5R`$%L;&4@1W)U<'!E;@!!;&QE(%)E8VAT90!!;&QE('9I
M97(@4V5I=&5N`$UE:')E<F4@061R97-S96X@97)L875B96X`1F]R;6%T('9O
M;B!N=6UM97)I97)T96X@3&ES=&5N(.1N9&5R;C\`17AI<W1I97)T(&)E<F5I
M=',`17AI<W1I97)T(&)E<F5I=',`06QT97)N871I=F4@24U34"U!;FUE;&1U
M;F<`06QT97)N871I=F5S($E-4U`M4&%S<W=O<G0`06QT97)N871I=F5R($E-
M4U`M0F5N=71Z97)N86UE`$%L=&5R;F%T:79E($5M86EL861R97-S90!!;'1E
M<FYA=&EV92!6;W)L86=E;@!!;'1E<FYA=&EV97(@5&5X=#H`06UE<FEK86YI
M<V-H+5-A;6]A`$5S('=U<F1E(&5I;B!U;F?\;'1I9V5R(%=E<G0@86YG96=E
M8F5N+@!%:6X@=6YB96MA;FYT97(@1F5H;&5R(&ES="!A=69G971R971E;BX`
M06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM97(@4')O>'D`06YT=V]R
M=`!!;G1A<FMT:7,`06YT:6=U82!U;F0@0F%R8G5D80!!;G=E;F1U;F<`06YW
M96YD=6YG<VQI<W1E`$%N=V5N9'5N9R!I<W0@8F5R96ET+@!!=68@56YT97)R
M96-H=&4@86YW96YD96X`0F5S=.1T:6=E;@!5;F=E9N1H<F4@1W+VWV4`07!R
M:6P`07)A8FES8V@@*%=I;F1O=W,M,3(U-BD`07)C:&EV9W+VWV4`07)C:&EV
M;F%M90!3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE("5S(&SV<V-H96X@;?9C
M:'1E;C\`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D:64@875S9V5WY&AL
M=&5N($5I;G1RY&=E(&SV<V-H96X@;?9C:'1E;C\`4VEN9"!3:64@<VEC:&5R
M+"!D87-S(%-I92!D:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!L
M]G-C:&5N(&WV8VAT96X_`%-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@(B5S
M(B!U;F0@86QL92!5;G1E<F=R=7!P96X@;/9S8VAE;B!M]F-H=&5N/P!!<F=E
M;G1I;FEE;@!!<FUE;FEE;@!!<FUE;FES8V@@*$%235-#24DM."D`2W5N<W0`
M07)U8F$`075F<W1E:6=E;F0`07-C96YS:6]N+4EN<V5L;@!!4T-)22U+=6YS
M=`!!<VEE;B]087II9FES8VAE(%)E9VEO;@!!;G-T96AE;F1E(%=A<G1U;F=S
M87)B96ET96X@8F5S=.1T:6=E;B!L87-S96X_`%IU;W)D;G5N9W-F96QD97(`
M17,@=W5R9&4@=F5R<W5C:'0L(&5I;F4@;FEC:'0@97AI<W1I97)E;F1E($=R
M=7!P92!Z=2!L]G-C:&5N+@!%<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT
M(&5X:7-T:65R96YD97,@4F5C:'0@>G4@;/9S8VAE;BX`17,@=W5R9&4@=F5R
M<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E87)B
M96ET96XN`$5S('=U<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI<W1I97)E
M;F1E<R!296-H="!Z=2!B96%R8F5I=&5N+@!!='1R:6)U=&4`075G=7-T`$%U
M<W1R86QI96X`UG-T97)R96EC:`!!=71H7V-Y<G-Q;#H@1&EE(&)E;O9T:6=T
M92!)34%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H
M7V-Y<G5S.B!$87,@0F%C:V5N9"!H870@;FEC:'0@9&EE(&)E;O9T:6=T96X@
M1N1H:6=K96ET96XN`$%U=&A?8WER=7,Z($1I92!B96[V=&EG=&4@24U!4"U%
M<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]F='`Z($1I
M92!B96[V=&EG=&4@1E10+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N
M9&5N+B!+;VUP:6QI97)E;B!3:64@4$A0(&UI="!D96T@+2UE;F%B;&4M9G1P
M(%!A<F%M971E<BX`075T:%]I;6%P.B!$:64@8F5N]G1I9W1E($E-05`M17)W
M96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?:W)B-3H@1&EE
M(&)E;O9T:6=T92!+97)B97)O<RU%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G
M969U;F1E;BX`075T:%]L9&%P.B!$87,@2&EN>G5F_&=E;B!V;VX@0F5N=71Z
M97)N('=I<F0@9OQR($%C=&EV92!$:7)E8W1O<GD@;FEC:'0@=6YT97)S=/QT
M>G0`075T:%]L9&%P.B!$87,@3/9S8VAE;B!V;VX@0F5N=71Z97)N('=I<F0@
M9OQR($%C=&EV92!$:7)E8W1O<GD@;FEC:'0@=6YT97)S=/QT>G0`075T:%]L
M9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M17)W96ET97)U;F<@=W5R9&4@;FEC
M:'0@9V5F=6YD96XN`$%U=&A?;&1A<#H@1&5R($)E;G5T>F5R("5S(&MO;FYT
M92!N:6-H="!H:6YZ=6=E9OQG="!W97)D96XN($UE;&1U;F<@9&5S(%-E<G9E
M<G,Z(`!!=71H7VQD87`Z($)E;G5T>F5R("5S(&MO;FYT92!N:6-H="!G96SV
M<V-H="!W97)D96X`075T:%]L9&%P.B!"96YU='IE<B`E<R!K;VYN=&4@;FEC
M:'0@86MT=6%L:7-I97)T('=E<F1E;@!!=71H7VQD87`Z($1A<R!!:W1U86QI
M<VEE<F5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@06-T:79E($1I<F5C=&]R
M>2!N:6-H="!U;G1E<G-T_'1Z="X`075T:%]M8V%L.B!$:64@8F5N]G1I9W1E
M($U#04PM17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?
M<VUB875T:#H@1&EE(&)E;O9T:6=T92!386UB82U%<G=E:71E<G5N9R!W=7)D
M92!N:6-H="!G969U;F1E;BX`06YM96QD=6YG(&)E:6T@24U!4"U397)V97(@
M9F5H;&=E<V-H;&%G96XN`$%U=&AE;G1I9FEZ:65R=6YG(&9E:&QG97-C:&QA
M9V5N`$%N;65L9'5N9R!F96AL9V5S8VAL86=E;BX@)7,`1&EE($%U=&AE;G1I
M9FEZ:65R=6YG('=U<F1E('9O;2!2041)55,M4V5R=F5R('IU<OQC:V=E=VEE
M<V5N+@!!;FUE;&1U;F<@8F5I;2!&5%`M4V5R=F5R(&9E:&QG97-C:&QA9V5N
M+@!!;FUE;&1U;F<@8F5I;2!334(M4V5R=F5R(&9E:&QG97-C:&QA9V5N+@!6
M97)F_&=B87)E($9E;&1E<CH`07-E<F)A:61S8VAA;@!"3T9(+4%U<W)E9&5N
M`$AI;G1E<F=R=6YD`$AI;G1E<F=R=6YD9F%R8F4`1F%L<V-H97,@2V5R8F5R
M;W,M4&%S<W=O<G0N`$9A;'-C:&5R($ME<F)E<F]S+4)E;G5T>F5R;F%M92X`
M0F%H86UA<P!"86AR96EN`$)A;'1I<V-H("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S8V@`0F%R8F%D;W,`0F%S:7,M0FEL9&5R+59E<GIE:6-H;FES("(E<R(@
M;FEC:'0@9V5F=6YD96XN`$=R=6YD;&EN:64`16EN9F%C:&4@4W5C:&4`5V5I
MWW)U;&%N9`!"96QG:65N`$)E;&EZ90!5;G1E<B!D96T@4W5C:&9O<FUU;&%R
M`$)E;FEN`$)E<FUU9&%S`$)H=71A;@!697)B:6YD=6YG(&9E:&QG97-C:&QA
M9V5N.B`H)7,I("5S`$=E8G5R='-T86<`0FQO8VL@(B5S(B!D97(@06YW96YD
M=6YG("(E<R(@;FEC:'0@9V5F=6YD96XN`$)L;V-K96EN<W1E;&QU;F=E;@!"
M;&]C:W1Y<`!&971T`$)O;&EV:65N`$QE<V5Z96EC:&5N`%)A;F0`4F%H;65N
M9&EC:V4Z`%+D;F1E<@!";W-N:65N+4AE<GIE9V]W:6YA`$)E:61E<P!";W1S
M=V%N80!5;G1E;@!";W5V971I;G-E;`!"<F%S:6QI96X`0G)I=&ES8VAE<R!4
M97)R:71O<FEU;2!I;2!);F1I<V-H96X@3WIE86X`3&ES=&4`0G)U;F5I($1A
M<G5S<V%L86T`0G5L9V%R:65N`%5N;G5M;65R:65R=&4@3&ES=&4`0G5R:VEN
M82!&87-O`$)U<G5N9&D`1V5S8VCD9G1S:V%T96=O<FEE`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;G-S=&5L;&4`0U-6`%]:96QL96YE:6=E;G-C:&%F=&5N
M+BXN`$1E<B!:=VES8VAE;G-P96EC:&5R(&MO;FYT92!N:6-H="!I;FET:6%L
M:7-I97)T('=E<F1E;BX`2V%L96YD97(`5VEN9'-T:6QL`$MA;6)O9'-C:&$`
M2V%M97)U;@!087-S=V]R="!K86YN(&YI8VAT(&%U=&]M871I<V-H('IU<OQC
M:V=E<V5T>G0@=V5R9&5N+"!B:71T92!W96YD96X@4VEE('-I8V@@86X@26AR
M96X@061M:6YI<W1R871O<BX`1&EE($1A=&5I("(E<R(@:V%N;B!N:6-H="!G
M97-P96EC:&5R="!W97)D96X`16EN92!'<G5P<&4@:V%N;B!N:6-H="!Z=2!S
M:6-H('-E;&)S="!H:6YZ=6=E9OQG="!W97)D96XN`$5X=&5R;F4@4V5S<VEO
M;BU(86YD;&5R(&OV;FYE;B!N:6-H="!A9&UI;FES=')I97)T('=E<F1E;BX`
M5F5R8FEN9'5N9R!Z=6T@24U!4"U397)V97(@:V%N;B!N:6-H="!H97)G97-T
M96QL="!W97)D96XZ("5S`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V7V
M9F9N970@=V5R9&5N+@!+86YA9&$`06)B<F5C:&5N`%!R;V)L96UB97)I8VAT
M(&%B8G)E8VAE;@!$:64@1&%T96D@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C
M:'0@=V5R9&5N+@!+96EN('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9V5F=6YD
M96XN`$9O<G1S971Z=6YG(&]H;F4@(G1A<F=E=$9I;&4B+5!A<F%M971E<B!N
M:6-H="!M]F=L:6-H+@!$87,@5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC
M:'0@96YT9F5R;G0@=V5R9&5N+@!+;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R
M9&5N+"`E9"!+:6YD97(@97AI<W1I97)E;BX`56US;W)T:65R96X@;FEC:'0@
M;?9G;&EC:"X@1&EE($%N>F%H;"!D97(@16EN='+D9V4L(&1I92!U;7-O<G1I
M97)T('=E<F1E;B!S;VQL96XL('-T:6UM="!N:6-H="!M:70@9&5R($%N>F%H
M;"!D97(@9V5S<&5I8VAE<G1E;B!%:6YT<N1G92#\8F5R96EN+@!$:64@3F%C
M:')I8VAT(&MO;FYT92!N:6-H="!A;B!D:64@86YG96=E8F4@3G5M;65R('=E
M:71E<F=E;&5I=&5T('=E<F1E;BX`2V%P(%9E<F1E`-QB97)S8VAR:69T`%!R
M;W9I9&5R`$MA=&5G;W)I96X@=6YD($)E<V-H<FEF='5N9V5N`$-A>6UA;BU)
M;G-E;&X`36]B:6QT96QE9F]N`%IE;&QE;F5I9V5N<V-H869T96X`26YN96YA
M8G-T86YD.@!:96QL96YE:6=E;G-C:&%F=&5N`%IE;&QE;F%B<W1A;F0Z`$UO
M8FEL=&5L969O;@!+96QT:7-C:"`H25-/+3@X-3DM,30I`%IE;G1R:65R=`!:
M96YT<F%L869R:6MA;FES8VAE(%)E<'5B;&EK`$UI='1E;&5U<F]PY&ES8V@@
M*$E33RTX.#4Y+3(I`%IE<G1I9FEK871D971A:6QS`%IE<G1I9FEK871B97-I
M='IE<@!:97)T:69I:V%T<FEC:'1L:6YI96X`5'-C:&%D`,1N9&5R;@#$;F1E
M<FX@4VEE($EH<B!087-S=V]R=`#$;F1E<FX@4VEE(&1E;B!.86UE;B!O9&5R
M(&1I92!%;6%I;&%D<F5S<V4L(&1I92!D:64@16UP9N1N9V5R($EH<F5R($5M
M86EL<R!S96AE;BP@=V5N;B!D:65S92!):')E($5M86EL<R!L97-E;B!O9&5R
M(&1A<F%U9B!A;G=O<G1E;BX`1&%S(,1N9&5R;B!):')E<R!087-S=V]R=',@
M=VER9"!V;VX@9&EE<V5M(%-Y<W1E;2!Z=7(@6F5I="!N:6-H="!U;G1E<G-T
M_'1Z="X@0FET=&4@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T
M<F%T;W(N`%IE:6-H96X`3&EN:R#\8F5R7W!R_&9E;BXN+@!?06QL92]+96EN
M92!A=7-WY&AL96X`0VAI;&4`0VAI;F$`0VAI;F5S:7-C:"!V97)E:6YF86-H
M="`H1T(R,S$R*0!#:&EN97-I<V-H('1R861I=&EO;F5L;"`H0FEG-2D`06YW
M96YD=6YG(&%U<W?D:&QE;CH`5^1H;&5N(%-I92!E:6YE;B!.86UE;@!7Y&AL
M96X@4VEE(&5I;B!087-S=V]R=`!7Y&AL96X@4VEE(&5I;F5N($)E;G5T>F5R
M;F%M96X`5^1H;&5N(%-I92!E:6X@061R97-S8G5C:`!7Y&AL96X@4VEE(&5I
M;B!!9')E<W-B=6-H.@!,96=E;B!3:64@9F5S="P@=VEE(&1A<R!$871U;2!A
M;F=E>F5I9W0@=V5R9&5N('-O;&PZ`$QI<W1E;F9O<FUA="!A=7-WY&AL96X@
M*&;\<B!N=6UM97)I97)T92!,:7-T96XI`%?D:&QE;B!3:64@875S+"!W96QC
M:&4@061R97-S8OQC:&5R(&EN('=E;&-H97(@4F5I:&5N9F]L9V4@86YG97IE
M:6=T('=E<F1E;B!S;VQL96XZ`%?D:&QE;B!3:64@9&EE('IU(&)E;G5T>F5N
M9&5N($%D<F5S<V+\8VAE<B!A=7,N`%?D:&QE;B!3:64@875S+"!W96QC:&4@
M4W!A;'1E;B!I;B!W96QC:&5R(%)E:6AE;F9O;&=E(&%N9V5Z96EG="!W97)D
M96X@<V]L;&5N.@!796EH;F%C:'1S:6YS96P`2VQA<W-E;F1E9FEN:71I;VX@
M9OQR("5S(&YI8VAT(&=E9G5N9&5N+@!(96ET97(`35,M3V9F:6-E+51A9W,@
M96YT9F5R;F5N`$%B9G)A9V4@>G5R_&-K<V5T>F5N`$)E;G5T>F5R9&%T96X@
M;/9S8VAE;CH@)7,`0F5N=71Z97)D871E;B!L]G-C:&5N`$)E;G5T>F5R9&%T
M96X@;/9S8VAE;@!3<.1T97(@075F:VQA<F5N9`!&;W)T9F%H<F5N`$-L:6-K
M871E;&P@<&5R($A45%``1F5N<W1E<B!S8VAL:67?96X`5V]L:V5N`$9R_&@@
M5V]L:V5N`$)E=_9L:W0`2V]K;W-I;G-E;&X`365N_"!E:6YF86AR96X`6G5S
M86UM96YHY&YG96YD92!286AM96X`2V]L=6UB:65N`$9A<F)E`$9A<F)A=7-W
M86AL`$9A<F)W86AL`%-P86QT96XZ`$%D<F5S<W-P86QT96X`4W!A;'1E;OQB
M97)S8VAR:69T96X`4W!A;'1E;BP@9&EE(&YI8VAT(&%N9V5Z96EG="!W97)D
M96XZ`$-O;6EC<P!+;VUM86=E=')E;FYT92!797)T90!+;VUM86=E=')E;FYT
M92!797)T92`H36EC<F]S;V9T($]U=&QO;VLI`$)E9F5H;`!"969E:&QS>F5I
M;&4`2V]M;65N=&%R`$5I;F1E=71I9V5R($YA;64`2V]M;W)E;@!&:7)M80!&
M:7)M96YA9')E<W-E`$-O;7!U=&5R`$)E9&EN9W5N9V5N`$)E9&EN9W5N9V5N
M`$MO;F9I9W5R871I;VYS=6YT97)S8VAI961E`$MO;F9I9W5R871I;VX@9&5R
M(%-Y;F-H<F]N:7IA=&EO;B!M:70@4$1!<RP@4VUA<G1P:&]N97,@=6YD($]U
M=&QO;VLN`$1I92!+;VYF:6=U<F%T:6]N(&UU<W,@86MT=6%L:7-I97)T('=E
M<F1E;BX`)7,@:V]N9FEG=7)I97)E;@!087-S=V]R="!B97-TY'1I9V5N`$MO
M;F=O`$1E;6]K<F%T:7-C:&4@4F5P=6)L:6,@2V]N9V\`5F5R8FEN9'5N9R!F
M96AL9V5S8VAL86=E;BX`5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E;CH@`%9E
M<F)I;F1U;F<@9F5H;&=E<V-H;&%G96XZ("5S`%9E<F)I;F1U;F<@9F5H;&=E
M<V-H;&%G96X`5F5R8FEN9'5N9R!Z=6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E
M;'-E<G9E<B!W=7)D92!A8F=E=VEE<V5N+@!697)B:6YD=6YG('IU;2#V9F9E
M;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E(&%B9V5W:65S96XN($=R
M=6YD.B`E<R`H)7,I`%9E<F)I;F1U;F<@>G5M($944"U397)V97(@9F5H;&=E
M<V-H;&%G96X`2V]N=&%K='-U8VAE`$MO;G1A:W1E`$MO;G1A:W1E(&EN($QI
M<W1E.B`E<P!$:64@2V]N=&%K=&4@=W5R9&5N(&5R9F]L9W)E:6-H($EH<F5M
M($%D<F5S<V)U8V@@:&EN>G5G96;\9W0N`$EN:&%L='-T>7`@9&5R(&MO;7!R
M:6UI97)T96X@1&%T96DZ(`!);FAA;'0@=F]N("(E<R(`5V5I=&5R`$-O;VLM
M26YS96QN`$-O;VMI90!+;W!I97)E;@!+;W!I97)E;B!F96AL9V5S8VAL86=E
M;CH@)7,`075S=V%H;"!K;W!I97)E;@!+;W-T96XM240`0V]S=&$@4FEC80!%
M;&9E;F)E:6YK_'-T90!$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@
M4$=0('9E<G-C:&S\<W-E;'0@=V5R9&5N.B``1&EE($YA8VAR:6-H="!K;VYN
M=&4@;FEC:'0@;6ET(%!'4"!U;G1E<GIE:6-H;F5T('=E<F1E;CH@`$1I92!.
M86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!3+TU)344@=F5R<V-H;/QS<V5L
M="!W97)D96XN`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!3+TU)
M344@=6YT97)Z96EC:&YE="!W97)D96XN`$MO;G1A:W0@:V]N;G1E(&YI8VAT
M(&=E<W!E:6-H97)T('=E<F1E;BX@)7,`5F5R8FEN9'5N9R!Z=6T@3$1!4"U3
M97)V97(@9F5H;&=E<V-H;&%G96XN`$MO;G1O<W1A;F0@:V]N;G1E(&YI8VAT
M(/QB97)P<OQF="!W97)D96XN("5S`%9E<F)I;F1U;F<@>G5M($Q$05`M4V5R
M=F5R(&9E:&QG97-C:&QA9V5N+@!&5%`M5F5R8FEN9'5N9R!Z=6T@4V5R=F5R
M("(E<R(@:V]N;G1E(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;CH@)7,`5F5R
M=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E;BX@)7,`
M4$=0+41A=&5N(&MO;FYT96X@;FEC:'0@96YT<V-H;/QS<V5L="!W97)D96XZ
M(`!3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E;G1S8VAL_'-S96QT('=E
M<F1E;BX`2V]N=&%K="!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B`E
M<P!697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M+B`E<P!$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T("(E<R(@:V]N;G1E(&YI
M8VAT(&=E;/9S8VAT('=E<F1E;BX`1&EE($5M86EL861R97-S92!D97,@16UP
M9N1N9V5R<R!K;VYN=&4@;FEC:'0@97)M:71T96QT('=E<F1E;BX`1&%S($%D
M<F5S<V)U8V@@:V]N;G1E(&YI8VAT(&MO;7!L971T(&=E;&5S96X@=V5R9&5N
M+@!697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D
M96XN("5S`$QI<W1E(&1E<B!697)T96EL97)L:7-T96X@:V]N;G1E(&YI8VAT
M(&%U<V=E;&5S96X@=V5R9&5N+@!$:64@4W1R871E9VEE("(E<R(@:V]N;G1E
M(&YI8VAT(&=E;&%D96X@=V5R9&5N+@!$87,@5F5R>F5I8VAN:7,@(B5S(B!K
M;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@#69F9E;G1L:6-H97(@4V-H
M;/QS<V5L(&MO;FYT92!N:6-H="!V;VT@4V-H;/QS<V5L<V5R=F5R(&=E:&]L
M="!W97)D96XN`"(E<R(@:V]N;G1E(&YI8VAT('IU;2!38VAR96EB96X@9V7V
M9F9N970@=V5R9&5N+@`E<R!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN
M`$1A<R!-86EN=&5N86YC95]487-K($UO9'5L("5S(&MO;FYT92!N:6-H="!G
M9?9F9FYE="!W97)D96X`5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@
M9V7V9F9N970@=V5R9&5N+@!697)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!K
M;VYN=&4@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N+@`E<R!K;VYN=&4@;FEC
M:'0@9V5L97-E;B!W97)D96XN`$1A<R!087-S=V]R="!F_'(@9&5N(&%N9V5G
M96)E;F5N($)E;G5T>F5R(&MO;FYT92!N:6-H="!Z=7+\8VMG97-E='IT('=E
M<F1E;BP@=V5I;"!E:6YI9V4@06YG86)E;B!N:6-H="!R:6-H=&EG('=A<F5N
M+B!697)S=6-H96X@4VEE(&5S(&5R;F5U="!O9&5R('=E;F1E;B!3:64@<VEC
M:"!A;B!):')E;B!!9&UI;FES=')A=&]R+"!W96YN(%-I92!W96ET97)E($AI
M;&9E(&)E;O9T:6=E;BX`04-,(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E
M;@!$87,@061R97-S8G5C:"!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN
M("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E
M<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&5N(&MO;FYT92!N:6-H="!A=7-G96QE
M<V5N('=E<F1E;BX@)7,`1&EE(%-E<G9E<F;D:&EG:V5I=&5N(&MO;FYT96X@
M;FEC:'0@875S9V5L97-E;B!W97)D96X`2V]N9FEG=7)A=&EO;B!K;VYN=&4@
M;FEC:'0@>G5R_&-K9V5S971Z="!W97)D96XN`%9E<GIE:6-H;FES("(E<R(@
M:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`)7,M2V]N9FEG=7)A=&EO
M;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!"86-K=7`@9&5R
M($MO;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E
M;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P
M96EC:&5R="!W97)D96XZ("5S`$1A<R!!:W1U86QI<VEE<G5N9W-S:W)I<'0@
M:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!G97-P96EC:&5R="!W97)D96XN`$)A
M8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I
M8VAE<G0@=V5R9&5N+@!$:64@2V]N9FEG=7)A=&EO;B`E<R!K;VYN=&4@;FEC
M:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B!3:64@:_9N;F5N(&5N='=E9&5R(&5I
M;F4@9&5R($WV9VQI8VAK96ET96X@=6YT97(@)7,@=F5R=V5N9&5N+"!U;2!D
M96X@0V]D92!Z=2!S<&5I8VAE<FXL(&]D97(@9&5N('5N=&5N<W1E:&5N9&5N
M($-O9&4@;6%N=65L;"!N86-H("5S(&MO<&EE<F5N+@!$97(@3$1!4"U397)V
M97(@:V]N;G1E(&YI8VAT(&1U<F-H<W5C:'0@=V5R9&5N+@`B)7,B(&MO;FYT
M92!N:6-H="!G96SV<V-H="!W97)D96XN`$1E<B!+;VYT86MT(&MO;FYT92!N
M:6-H="!G97-P96EC:&5R="!W97)D96XN("5S`%9E<G1E:6QE<FQI<W1E(&MO
M;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N+B`E<P!$:64@2V]N9FEG
M=7)A=&EO;B!F_'(@(B5S(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N.B`E<P!$:64@36]Z:6QL82!3:61E8F%R(&MO;FYT92!N:6-H="!G969U
M;F1E;B!W97)D96XN(%-T96QL96X@4VEE('-I8VAE<BP@9&%S<R!D:64@4VED
M96)A<B!G9?9F9FYE="!I<W0N`$1E;2!"96YU='IE<B`B)7,B(&MO;FYT96X@
M9&EE(&9O;&=E;F1E(%)E8VAT92!F_'(@9&5N($]R9&YE<B`B)7,B(&YI8VAT
M('IU9V5W:65S96X@=V5R9&5N.B`E<P!'97KD:&QT97(@5&5X=`!,86YD`$MU
M<G-E`$5R<W1E;&QE;@!!9')E<W-B=6-H($5R<W1E;&QE;@!,:6YK(&5R<W1E
M;&QE;@!.975E($MO;G1A:W1L:7-T92!A;FQE9V5N(&EN.@!.975E($ED96YT
M:73D="!A;FQE9V5N`%5N=&5R;W)D;F5R(&5R<W1E;&QE;@!%<G-T96QL=`!%
M<G-T96QL97)R96-H=&4`2W)E9&ET:V%R=&5N;G5M;65R`$MR;V%T:65N`$MU
M8F$`06MT=65L;&4@-"!0:&%S96X`06MT=65L;&4@4V5S<VEO;G,`06MT=65L
M;&4@6F5I=`!!:W1U96QL92!54DP@:7-T`$%K='5E;&QE($)E;G5T>F5R`$%K
M='5E;&QE<R!7971T97(`1&5R>F5I=&EG92!"961I;F=U;F=E;CH@`$%K='5E
M;&QE<B!3=&EL`$QE9V5N(%-I92!F97-T+"!W96QC:&4@075F9V%B96X@;F%C
M:"!D97(@06YM96QD=6YG(&)E:2`E<R!E<FQE9&EG="!W97)D96X@<V]L;&5N
M+@!!=7-S8VAN96ED96X`075S=V%H;"!A=7-S8VAN96ED96X`6GEP97)N`$MY
M<FEL;&ES8V@@*$M/23@M4BD`2WER:6QL:7-C:"`H5VEN9&]W<RTQ,C4Q*0!+
M>7)I;&QI<V-H+U5K<F%I;FES8V@@*$M/23@M52D`5'-C:&5C:&ES8VAE(%)E
M<'5B;&EK`%14`$133B`H<VEE:&4@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!4Y&=L
M:6-H`$1A=&%4<F5E($)R;W=S97(`1&%T96YB86YK86)F<F%G90!$871U;0!%
M;7!F86YG<V1A='5M`$1A='5M<V%U<W=A:&P`5&%G`%-P86QT92!?;/9S8VAE
M;@!$97IE;6)E<@!:86AL96X`16EN>G5G('9E<G)I;F=E<FX`4W1A;F1A<F0`
M4W1A;F1A<F1F87)B90!3=&%N9&%R9&ED96YT:73D=`!3=&%N9&%R9'-H96QL
M`%-O<G1I97)R:6-H='5N9SH`1&5F:6YI=&EO;F5N`$SV<V-H96X`061R97-S
M8G5C:"!,]G-C:&5N`%IE;&QE(&SV<V-H96X`3/9S8VAB97-TY'1I9W5N9P!'
M<G5P<&4@;/9S8VAE;@!,;V<@;/9S8VAE;@!296-H=&4@;/9S8VAE;@!.86-H
M<FEC:'1E;B!L]G-C:&5N('5N9"!E;G1F97)N96X`5F5R:&%L=&5N(&)E:6T@
M3/9S8VAE;BX`6F5L;&4@;/9S8VAE;@!3<&%L=&4@;/9S8VAE;@!"97-T96AE
M;F1E(&%L=&5R;F%T:79E(%9O<FQA9V4@;/9S8VAE;@!,]G-C:&5N(&9E:&QG
M97-C:&QA9V5N.B`H)7,I("5S`$YA8VAR:6-H=&5N(&SV<V-H96X`4F5C:'1E
M(&;\<B`B)7,B(&SV<V-H96X`4F5C:'1E(&;\<B`B)7,B('5N9"!A;&QE(%5N
M=&5R<F5C:'1E(&SV<V-H96X_`%IE:6QE(&SV<V-H96X`075S9V5WY&AL=&4@
M261E;G1I=.1T(&SV<V-H96X`56YT97)O<F1N97(@;/9S8VAE;@!$:64@86MT
M=65L;&4@4W!A;'1E(&SV<V-H96X`1&EE(&%K='5E;&QE(%IE:6QE(&SV<V-H
M96X`1&%S($%K='5A;&ES:65R=6YG<W-K<FEP="`B)7,B('=U<F1E(&=E;/9S
M8VAT+@!,]G-C:&5N('9O;B!+;VYT86MT96X@;FEC:'0@=6YT97)S=/QT>G0N
M`$SV<V-H96X@:7-T(&9E:&QG97-C:&QA9V5N`$%U<VQI969E<G5N9W-Z96ET
M`$3D;F5M87)K`$%B=&5I;'5N9P!!8G-T96EG96YD`$)E<V-H<F5I8F5N(%-I
M92!D87,@4')O8FQE;0!"97-C:')E:6)U;F<`1&5T86EL<R`H875C:"!I;B!(
M;W)D97,@3&]G9&%T96DI.@!$971A:6QS('=U<F1E;B!F_'(@9&5N($%D;6EN
M:7-T<F%T;W(@;6ET9V5L;V=G="X`16YT=VEC:VQU;F<`5&%U<'5N:W0`5&%U
M<'5N:W0@9&5R(&QE='IT96X@4W1U;F1E.B``5&%U<'5N:W0Z(`!6;VX@;&EN
M:W,@;F%C:"!R96-H=',`5F]N(')E8VAT<R!N86-H(&QI;FMS`%9E<GIE:6-H
M;FES`$%N>F5I9V4`6F5I="!I;2`R-"U3='5N9&5N+49O<FUA="!A;GIE:6=E
M;C\`06YZ96EG92U%:6YS=&5L;'5N9V5N`$1E=&%I;&EE<G1E(%9O<FAE<G-A
M9V4@86YZ96EG96X`5F]R:&5R<V%G92`H5$%&*2!A;GIE:6=E;@!!;GIE:6=E
M9F]R;6%T`$5M<&9A;F=S8F5S=.1T:6=U;F<`1'-C:&EB=71I`$YI8VAT(&SV
M<V-H96X`1W)E:69E;B!3:64@;FEC:'0@9&ER96MT(&%U9B!M86EN=&5N86YC
M92YP:'`@>G4`3?9C:'1E;B!3:64@9&%S($SV<V-H96X@=F]N($5I;G1RY&=E
M;B!B97-TY'1I9V5N/P!%;G1HY&QT(&1I92!E<G-T92!:96EL92!D:64@1F5L
M9&YA;65N/R!796YN(&IA+"!D:65S97,@075S=V%H;&OD<W1C:&5N(&UA<FMI
M97)E;CH`1&]M:6YI8V$`1&]M:6YI:V%N:7-C:&4@4F5P=6)L:6L`3F]C:"!K
M96EN96X@6G5G86YG/R!(:65R(&%N;65L9&5N+@!(97)U;G1E<FQA9&5N`"5S
M($AE<G5N=&5R;&%D96X`17)Z975G=&4@2V]N9FEG=7)A=&EO;B!A;',@4$A0
M+5-K<FEP="!H97)U;G1E<FQA9&5N+@!V0V%R9"!H97)U;G1E<FQA9&5N`$%U
M<W=A:&QL:7-T90!$<F]G96X`16UA:6P`16UA:6PM;F%C:"U335,M9V%T97=A
M>2!F_'(@4')O=FED97(L(&1I92!E:6YE;B!S;VQC:&5N($1I96YS="!U;G1E
M<G-T_'1Z96XN`$9%2$Q%4@!%8W5A9&]R`$)E87)B96ET96X`(B5S(B!B96%R
M8F5I=&5N`$%D<F5S<V+\8VAE<B!"96%R8F5I=&5N`$)L;V-K(&)E87)B96ET
M96X`1W)U<'!E(&)E87)B96ET96X`4F5C:'1E(&)E87)B96ET96X`4F5C:'1E
M(&)E87)B96ET96X`4F5C:'1E(&;\<B`G)7,G(&)E87)B96ET96X`16EN=')A
M9R!V;VX@)7,@8F5A<F)E:71E;@!%:6YS=&5L;'5N9V5N(&)E87)B96ET96X@
M9OQR.@!296-H=&4@9OQR("(E<R(@8F5A<F)E:71E;@!296-H=&4@9OQR("5S
M(&)E87)B96ET96X`0FEL9'5N9P#$9WEP=&5N`$5L(%-A;'9A9&]R`$5L96UE
M;G0N+BX`16T`16UA:6P`16UA:6QA9')E<W-E`$1I92!%;6%I;&%D<F5S<V5N
M(&W\<W-E;B!G;&5I8V@@<V5I;BX`16UA:6P@;6ET($)E<W3D=&EG=6YG`$5M
M86EL+6YA8V@M4TU3+4=A=&5W87D`4VUI;&5Y<P!,965R92!.86-H<FEC:'0N
M`$QE97)E<R!%<F=E8FYI<RX`4W5C:&)E9W)I9F9E(&SV<V-H96X`16EN9OQG
M96X@=F]N($)I;&1E<FX@875S($9O=&]G86QE<FEE;B!I;B!D96X@5&5X="!E
M<FQA=6)E;C\`2V]N=&5X=&UE;OP@8F5I(%)E8VAT<VML:6-K(&%K=&EV:65R
M96X_`$5N9&IA:'(`161I=&]R('9E<F=R]M]E<FX`1V5B96X@4VEE(&5I;F4@
M4VEC:&5R:&5I='-F<F%G92!E:6XL(&1I92!):&YE;B!G97-T96QL="!W:7)D
M+"!W96YN(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K<V5T>F5N(&WV8VAT96XL
M('HN($(N(")7:64@;&%U=&5T(&1E<B!.86UE($EH<F5S($AA=7-T:65R<S\B
M.@!(:65R(&1I92!":6QD+5523"!A;F=E8F5N`$=E8F5N('-I92!D:64@0G5C
M:'-T86)E;B!U;G1E;B!E:6XZ`$5I;G1R86<@=F]N("5S(&%K='5A;&ES:65R
M="P@86)E<B!D:64@:&]C:&=E;&%D96YE($1A=&5I(&MO;FYT92!N:6-H="!G
M97-P96EC:&5R="!W97)D96XZ("5S`$5I;G1R86<@=F]N("5S(&%K='5A;&ES
M:65R="X`Q'%U871O<FEA;"U'=6EN96$`17)I=')E80!&96AL97(`1F5H;&5R
M(&)E:6T@2&EN>G5F_&=E;B!V;VX@)60@2V]N=&%K=&5N('IU<B!,:7-T92X`
M1F5H;&5R(&)E:6T@2&EN>G5F_&=E;B!V;VX@)60@=F]N("5D($MO;G1A:W1E
M;B!Z=7(@3&ES=&4N`$9E:&QE<B!B96EM($5R<W1E;&QE;B!E:6YE<R!";&]C
M:W,Z("5S`$9E:&QE<B!B96EM($SV<V-H96X@=F]N("5D($MO;G1A:W1E;BX`
M1F5H;&5R(&)E:6T@3/9S8VAE;B!V;VX@)60@=F]N("5D($MO;G1A:W1E;BX`
M1F5H;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N<V%N:V5R
M<SH@)7,`1F5H;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N
M<VQO9W,Z("5S`$9E:&QE<B!B96EM($5R>F5U9V5N(&1E<R!);FAA;'1S.B`E
M<P!&96AL97(@8F5I;2!%;G1F97)N96X@=F]N("5D($MO;G1A:W1E;B!A=7,@
M9&5R($QI<W1E+@!&96AL97(@8F5I;2!%;G1F97)N96X@=F]N("5D('9O;B`E
M9"!+;VYT86MT96X@875S(&1E<B!,:7-T92X`1&%S($%D<F5S<V)U8V@@:V]N
M;G1E(&YI8VAT(&1U<F-H<W5C:'0@=V5R9&5N.B`E<P!&96AL97(@8F5I;2#$
M;F1E<FX@9&5S(%!A<W-W;W)T<SH@)7,`1F5H;&5R(&EN(&1E<B!%;6%I;&YA
M8VAR:6-H="X`1F5H;&5R(&)E:6T@4V-H<F5I8F5N('9O;B`B)7,B+@!%<W1L
M86YD`,1T:&EO<&EE;@!%=&YI<V-H97,`175R;W!A`$%L;&4@,34@36EN=71E
M;@!!;&QE(#(@36EN=71E;@!!;&QE(#,P(%-E:W5N9&5N`$%L;&4@-2!-:6YU
M=&5N`$)E:2!J961E<B!!;FUE;&1U;F<`06QL92!H86QB92!3='5N9&4`06QL
M92`V,"!396MU;F1E;@!"96ES<&EE;'=E<G1E.@!!=7-F_&AR96X`5F5R9W+V
MWV5R;@!-96[\(&%U<V9A:')E;@`G*2<@97)W87)T970`16EN>F5L;F5S(%=O
M<G0@;V1E<B!3=6-H8F5G<FEF9B!I;B!!;F;\:')U;F=S>F5I8VAE;B!E<G=A
M<G1E=`!697)F86QL<V1A='5M`$5X<&]N96YT`$5X<&]R=&EE<F5N`$%D<F5S
M<V)U8V@@97AP;W)T:65R96X`3G5R(&1I92!A=7-G97?D:&QT96X@2V]N=&%K
M=&4@97AP;W)T:65R96XN`$1A<R!F;VQG96YD92!!9')E<W-B=6-H(&MO;7!L
M971T(&5X<&]R=&EE<F5N+@!6;W)D97)G<G5N9&9A<F)E`$AO8VAL861E;B!D
M97(@2V]N9FEG=7)A=&EO;B!P97(@1E10`$)E;G5T>F5R96EN<W1E;&QU;F=E
M;B!K;VYN=&5N(&YI8VAT(&=E;&%D96X@=V5R9&5N+@!$87,@061R97-S8G5C
M:"!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N.B`E<P`E<R!K;VYN=&4@
M;FEC:'0@>G4@)7,@:&EN>G5G96;\9W0@=V5R9&5N.B`E<P!$:64@3&ES=&4@
M:V]N;G1E(&YI8VAT(&%N9V5Z96EG="!W97)D96X`1&%S(%9E<GIE:6-H;FES
M(&MO;FYT92!N:6-H="!A;F=E>F5I9W0@=V5R9&5N`$YA;64@:V]N;G1E(&YI
M8VAT(&=EY&YD97)T('=E<F1E;CH@*"5S*2`E<SL@06QT92!$3B`]("5S+"!.
M975E($1.(#T@)7,L(%)O;W0@/2`E<P!697)B:6YD=6YG('IU;2!,1$%0(%-E
M<G9E<B!G97-C:&5I=&5R="X`5F5R8FEN9'5N9R!Z=6T@4TU"+5-E<G9E<B!G
M97-C:&5I=&5R="X`17,@:V]N;G1E(&ME:6YE($MO<&EE('9O;B`B)7,B(&5R
M<W1E;&QT('=E<F1E;BX`17,@:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!K;W!I
M97)T('=E<F1E;BX`075F8F%U(&5I;F5N(&YE=65N(%-!4TPM5F5R8FEN9'5N
M9R!I<W0@9F5H;&=E<V-H;&%G96XN`$1A<R!/8FIE:W0L(&1A<R!H:6YZ=6=E
M9OQG="!W97)D96X@<V]L;'1E+"!K;VYN=&4@;FEC:'0@9V5F=6YD96X@=V5R
M9&5N.B`E<P!%<R!K;VYN=&4@;FEC:'0@;F%C:"`B)7,B('9E<G-C:&]B96X@
M=V5R9&5N+@!&96AL97(@8F5I;2!,97-E;CH@)7,`1&%S($%D<F5S<V)U8V@@
M:V]N;G1E(&YI8VAT(&1U<F-H<W5C:'0@=V5R9&5N`$1A<R!697)Z96EC:&YI
M<R`E<R!K;VYN=&4@;FEC:'0@9'5R8VAS=6-H="!W97)D96XN`$AE:71E<@!&
M86QK;&%N9&EN<V5L;@!&87+V97(`4V-H=V5R97(@1F5H;&5R.@!&87@`1F%X
M90!&96)R=6%R`$=E9OQH;'1E(%1E;7!E<F%T=7(`1V5F_&AL=&4@5&5M<&5R
M871U<CH@`%9E<F5I;GIE;'1E(%-C:&%U97(`5F5R96EN>F5L=&4@4V-H;F5E
M<V-H875E<@!&96QD;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="U&;VYT
M`$9I9'-C:&D`1&%T96D`06YZ86AL.B`E<R!$871E:0!!;GIA:&PZ("5S($1A
M=&5I96X`1&%T96EM86YA9V5R`$1A=&5I;F%M90!$871E:6%U<W=A:&P`1&%T
M96DM2&]C:&QA9&5N`$1A<R!(;V-H;&%D96X@=F]N($1A=&5I96X@=VER9"!N
M:6-H="!U;G1E<G-T_'1Z="X`1&%T96EE;@!&:6QT97(`1'5R8VAS=6-H96X@
M=F]N(`!"965N9&5N`$9I;FYL86YD`$5R<W1E($CD;&9T90!6;W)N86UE`$5R
M<W1E<R!6:65R=&5L`%9E<FCD;'1N:7,@>G5R_&-K<V5T>F5N`%5M9')E:&5N
M`%1E>'1F;'7?`$YE8F5L`$1A<R!697)Z96EC:&YI<R`E<R!E>&ES=&EE<G0@
M;FEC:'0`4V-H<FEF=&9A<F)E`$5S<V5N`$;\<B!"<F]W<V5R+"!D:64@:V5I
M;F4@0FEL9&5R('5N=&5R<W3\='IE;@!6;W)H97)S86=E("A4048I`%9O<FAE
M<F=E<V%G=&4@5&%G92`H5F]R:&5R<V%G96X@96YT:&%L=&5N(%1A9V4@=6YD
M($[D8VAT92P@96EN(&AO:&5R(%=E<G0@:V%N;B!Z=2!E:6YE;2!S96AR(&=R
M;]]E;B!";&]C:R!F_&AR96XI`%!A<W-W;W)T('9E<F=E<W-E;C\`1F]R;75L
M87)E`$=L_&-K<VME:W,`1VS\8VMS:V5K<W1Y<`!';/QC:W-K96MS90!';/QC
M:W-K96MS92`R`$9O<F5N`%=E:71E<FQE:71U;F<`1G(`4F%H;65N`$9R86YK
M<F5I8V@`175R;W#D:7-C:&5S($9R86YK<F5I8V@`1G)E:2TO1V5B=6-H="U5
M4DP`1G)A;GKV<VES8V@M1W5A>6%N80!&<F%N>O9S:7-C:"U0;VQY;F5S:65N
M`$9R86YZ]G-I<V-H92!'96)I971E(&EM('/\9&QI8VAE;B!);F1I<V-H96X@
M3WIE86X`5F]N`$%U<R``5F]L;'-TY&YD:6=E($)E<V-H<F5I8G5N9P!6;VQL
M;6]N9`!6;VQL<W3D;F1I9V5R($YA;64`1V%B=6X`0FEL9&5R(&%U<R!D:65S
M97(@1V%L97)I90!'86QE<FEE.@!'86UB:6$`)7,M2V]N9FEG=7)A=&EO;B!E
M<GIE=6=E;@!%<GIE=6=T97(@0V]D90!'96]R9VEE;@!$975T<V-H;&%N9`!'
M:&%N80!':6)R86QT87(`5F]R;F%M90!!;&QG96UE:6YE<R!!9')E<W-B=6-H
M`$%L;&=E;65I;F4@16EN<W1E;&QU;F=E;@!,;W,`1V]E9&5L`$=O;V=L92!-
M87!S`$=O;V=L92!3=6-H90!'<F%U<W1U9F5N`$=R:65C:&5N;&%N9`!'<FEE
M8VAI<V-H("A)4T\M.#@U.2TW*0!'<O9N;&%N9`!'<F5N861A`$=R=7!P90!'
M<G5P<&5N=F5R=V%L='5N9P!'<G5P<&5N;F%M96X@9/QR9F5N(&YI8VAT(&QE
M97(@<V5I;@!'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S(&MO;FYT92!N:6-H
M="!H:6YZ=6=E9OQG="!W97)D96XN($UE;&1U;F<@9&5S(%-E<G9E<G,Z(`!'
M<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S(&MO;FYT92!N:6-H="!G96SV<V-H
M="!W97)D96X`1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC
M:'0@86MT=6%L:7-I97)T('=E<F1E;@!'<G5P<&5N`$=U861E;&]U<&4`1W5A
M;0!'=6%T96UA;&$`1W5E<FYS97D`1V%S=')E8VAT90!'Y'-T96)U8V@`1W5I
M;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`1&5R($5D:71O<B!K86YN
M(&1I92!L971Z=&4@6F5L;&4@96EN97(@6F5I;&4@;FEC:'0@;/9S8VAE;BX`
M1&5R($5D:71O<B!K86YN(&1I92!L971Z=&4@4W!A;'1E(&5I;F5R(%1A8F5L
M;&4@;FEC:'0@;/9S8VAE;BX`1&5R($5D:71O<B!K86YN(&1I92!L971Z=&4@
M6F5I;&4@96EN97(@5&%B96QL92!N:6-H="!L]G-C:&5N+@!(5%10+4%U=&AE
M;G1I9FEZ:65R=6YG(&YI8VAT(&=E9G5N9&5N+@!(86ET:0!(87-H+4%L9V]R
M:71H;75S`$1I97-I9P#<8F5R<V-H<FEF=`!+;W!F96EN='+D9V4`2&5A<F0M
M('5N9"!-8T1O;F%L9&EN<V5L;@!38VAW97)E($=E=VET=&5R`$AE8G+D:7-C
M:"`H25-/+3@X-3DM."U)*0!(]FAE`$AI;&9E`$5D:71O<FAI;&9E`$AI;&9E
M`$AE;6ES<&AE<F4`1&EE<R!I<W0@9&5R($)E9VEN;B!D97(@1&%T96DZ`$AO
M8V@`7U-T87)T<V5I=&4`5F%T:6MA;G-T861T`%-T87)T<V5I=&4`061R97-S
M92!P<FEV870`4W1A9'0@<')I=F%T`$QA;F0@<')I=F%T`$AE:6UV97)Z96EC
M:&YI<P!496QE9F]N('!R:79A=`!0;W-T;&5I='IA:&P@<')I=F%T`$)U;F1E
M<W-T86%T(&]D97(@4')O=FEN>B!P<FEV870`4W1R8=]E('!R:79A=`!(;VYD
M=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%5N9_QL=&EG92`E
M<RU834PM1&%T96X@:6X@3F%C:')I8VAT("5S`$AO<F1E+TMO;&%B.B!%<R!P
M87-S="!K96EN92!.86-H<FEC:'0@>G5M($]B:F5K="`E<P!(;W)D92]+;VQA
M8CH@2V5I;B!/8FIE:W0@=F]M(%1Y<"`E<R!I;B!.86-H<FEC:'0@)7,@9V5F
M=6YD96X`2&]R9&4O2V]L86(Z("5S("(E<R(@=W5R9&4@97)F;VQG<F5I8V@@
M96YT9F5R;G0`2&]R9&4O2V]L86(Z($1I92!);G1E9W)A=&EO;G-F=6YK=&EO
M;F5N(&)E;O9T:6=E;B!D:64@(F1O;7AM;"(@4$A0+45R=V5I=&5R=6YG`$AO
M<F1E+TMO;&%B.B!&_'(@9&%S($]B:F5K="`E<R!K;VYN=&4@:V5I;B!N975E
M<B!834PM0F%U;2!E<GIE=6=T('=E<F1E;@!(;W)D92]+;VQA8CH@)7,@(B5S
M(B!K;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N.B`E<P!(;W)D92]+;VQA
M8CH@1&EE($U)344M240@9&5S($%B<V-H;FET=',@=F]M(%1Y<"`E<R!K;VYN
M=&4@;FEC:'0@:&5R875S9V5F=6YD96X@=V5R9&5N+@!(;W)D92]+;VQA8CH@
M)7,@(B5S(B!K;VYN=&4@;FEC:'0@<WEN8VAR;VYI<VEE<G0@=V5R9&5N.B`E
M<P!(;W)D92]+;VQA8CH@1&EE(&=E;65I;G-A;65N($]B:F5K=&4@:V]N;G1E
M;B!N:6-H="!S>6YC:')O;FES:65R="!W97)D96XZ("5S`$AO<F1E+TMO;&%B
M.B!5;F)E:V%N;G1E<R!G96UE:6YS86UE<R!/8FIE:W0@(B5S(@!(;W)I>F]N
M=&%L92!,:6YI90!(;W)I>F]N=&%L97(@26YN96YA8G-T86YD`$AO<FEZ;VYT
M86PZ`%=I92!S:6YD(%-I92!H:65R:&5R9V5L86YG=#\@0FET=&4@86X@9&EE
M($5N='=I8VML97(@>G5R_&-K;65L9&5N(2D`5VEE('9I96QE(%-P86QT96X@
M<V]L;&5N('IU<V%M;65N9V5F_&=T('=E<F1E;C\`5VEE=FEE;&4@1F5L9&5R
M("A3<&%L=&5N*2!G:6)T(&5S/P!7:64@=FEE;&4@6F5I;&5N('-O;&QE;B!Z
M=7-A;6UE;F=E9OQG="!W97)D96X_`$QU9G1F975C:'1I9VME:70`3'5F=&9E
M=6-H=&EG:V5I=#H@`$MO;6EK97(`56YG87)N`$%N;&5G96X@9&5S($E-05`M
M4&]S=&9A8VAS(&ES="!F96AL9V5S8VAL86=E;CH@)7,`3/9S8VAE;B!D97,@
M24U!4"U0;W-T9F%C:',@:7-T(&9E:&QG97-C:&QA9V5N.B`E<P!&97-T;&5G
M96X@9&5R($E-05`M4&]S=&9A8V@M475O=&$@:7-T(&9E:&QG97-C:&QA9V5N
M.B`E<P!)35-0`$E-4U`M061R97-S8G5C:'9E<G=A;'1U;F<`25`M061R97-S
M90!)4"U!9')E<W-E(&YI8VAT('9E<F;\9V)A<BX`25`M061R97-S92!N:6-H
M="!I;2!E<FQA=6)T96X@0TE$4BU";&]C:RX`5F5R;&5T>G5N9R!D97(@9F5S
M=&=E;&5G=&5N($E0+@!:96EL92!E:6YF_&=E;B!?=F]R`$ES;&%N9`!.=7(@
M0FEL9&5R`$EC;VYS(&;\<B`E<P!":6QD97(@=6YD(%1E>'0`0F5Z96EC:&YU
M;F<@9&5R($ED96YT:73D=`!796YN('-I92!N:6-H="!K;W)R96MT(&%N9V5Z
M96EG="!W:7)D+"`E<RP@=6T@<VEE(&EN(&5I;F5M(&YE=65N($9E;G-T97(@
M86YG97IE:6=T('IU(&)E:V]M;65N+@!796YN(%-I92!M:70@9&5M($EN=&5R
M;F5T($5X<&QO<F5R(&ME:6YE(%-Y;6)O;&4@<V5H96XL(&W\<W-E;B!3:64@
M9&EE<V5S($OD<W1C:&5N(&UA<FMI97)E;BP@=6T@4$Y'+51R86YP87)E;GH@
M875S>G5S=&5L;&5N+@!796YN(%-I92!D:65S92!.86-H<FEC:'0@86X@4W1E
M;&QE(&5I;F4@0FEL9&5S('-E:&5N+"!K86YN($EH<B!"<F]W<V5R(&1A<R!"
M:6QD+"!D87,@4VEE(&AO8VAL861E;B!M]F-H=&5N(&YI8VAT(&%N>F5I9V5N
M+@!":6QD=F]R<V-H874Z`$)I;&0M55),`$)I;&0M55),.@!":6QD('9O;B!'
M86QE<FEE`$)I;&0@=F]N($=A;&5R:64Z`$)I;&0M2&]C:&QA9&5N`$)I;&1E
M<@!!9')E<W-B=6-H(&EM<&]R=&EE<F5N+"!38VAR:71T("5D`$EM<&]R=&EE
M<F5N+"!38VAR:71T("5D`$%D<F5S<V+\8VAE<B!);7!O<G0O17AP;W)T`$EM
M<&]R=&EE<G1E<R!&96QD.B`E<P!);7!O<G1I97)T92!&96QD97(Z`%IE:6QE
M(&5I;F;\9V5N(%]N86-H`%5N9_QL=&EG92!!:W1I;VX@86YG96=E8F5N+@!5
M;F?\;'1I9V5R($)E;G5T>F5R;F%M92!U;F0O;V1E<B!087-S=V]R="X`1F%L
M<V-H97(@0F5N=71Z97)N86UE(&]D97(@16UA:6QA9')E<W-E+B!697)S=6-H
M96X@4VEE(&5S(&5R;F5U="!O9&5R('=E;F1E;B!3:64@<VEC:"!A;B!):')E
M;B!3>7-T96UA9&UI;FES=')A=&]R+"!W96YN(%-I92!W96ET97)E($AI;&9E
M(&)E;O9T:6=E;BX`16EN>G5G('9E<F=R]M]E<FX`26YD:65N`$5I;GIE;&YE
M($)E;G5T>F5R`$EN9&]N97-I96X`26YF;W)M871I;VX`26YF;W)M871I;VYE
M;@!);F9O<FUA=&EO;F5N(&YI8VAT(&UE:'(@=F5R9OQG8F%R+@!?4W!A;'1E
M(&1A=F]R(&5I;F;\9V5N`$)I;&0@:&EN>G5F_&=E;@!486)E;&QE(&5I;F;\
M9V5N`$QI;FL@96EN9OQG96X`4U]P86QT92!D86YA8V@@96EN9OQG96X`16EN
M92!N975E(%-P86QT92!N86-H(&1E<B!A:W1U96QL96X@96EN9OQG96X`16EN
M92!N975E(%-P86QT92!V;W(@9&5R(&%K='5E;&QE;B!E:6YF_&=E;@!%:6YE
M(&YE=64@6F5I;&4@;F%C:"!D97(@86MT=65L;&5N(&5I;F;\9V5N`$5I;F4@
M;F5U92!:96EL92!V;W(@9&5R(&%K='5E;&QE;B!E:6YF_&=E;@!%:6YE;B!N
M975E;B!!8G-A='H@;F%C:"!D96T@86MT=65L;&5N($5L96UE;G0@96EN9OQG
M96X`16EN96X@;F5U96X@06)S871Z('9O<B!D96T@86MT=65L;&5N($5L96UE
M;G0@96EN9OQG96X`06QT97)N871I=F4@5F]R;&%G92!E:6YF_&=E;@!'96)E
M;B!3:64@96EN92!%;6%I;&%D<F5S<V4@86XL(&%N(&1I92!D87,@;F5U92!0
M87-S=V]R="!G97-C:&EC:W0@=V5R9&5N('-O;&PZ`%IE;&QE(&1A;F%C:"!E
M:6YF_&=E;@!:96QL92!D879O<B!E:6YF_&=E;@!3<&%L=&4@9&%N86-H(&5I
M;F;\9V5N`%-P86QT92!D879O<B!E:6YF_&=E;@!.86-H<FEC:'1E;B!H:6YZ
M=6;\9V5N`$%B<V%T>B!D86YA8V@@96EN9OQG96X`06)S871Z(&1A=F]R(&5I
M;F;\9V5N`%IE:6QE(&1A;F%C:"!E:6YF_&=E;@!:96EL92!D879O<B!E:6YF
M_&=E;@!'96)E;B!3:64@9&EE($%N='=O<G0@875F(&1I92!3:6-H97)H96ET
M<V9R86=E(&5I;CH`0FEL9"!E:6YF_&=E;B]B96%R8F5I=&5N`$QI;FL@96EN
M9OQG96XO8F5A<F)E:71E;@!:=2!W96YI9R!'=71H86)E;BP@=6T@86X@9&EE
M(%9E<G1E:6QE<FQI<W1E('IU('9E<G-C:&EC:V5N+@!:=2!W96YI9R!'=71H
M86)E;BX`1V%N>GIA:&P`3&ES=&4@=F]N($=A;GIZ86AL96X`56YG_&QT:6=E
M($E$`%5N9_QL=&EG97(@541(+B`H57-E<B!$871A($AE861E<BDN`%5N9_QL
M=&EG92!:25`M1&%T96XN`%5N9_QL=&EG97,@061R97-S8G5C:`!5;F?\;'1I
M9V4@06YW96YD=6YG+@!5;F?\;'1I9V4@0F%T8V@M240N`%5N9_QL=&EG92!$
M871E;B!E:6YG96)E;BX`56YG_&QT:6=E(%II96QA9')E<W-E+@!5;F?\;'1I
M9V4@16UA:6PM061R97-S90!5;F?\;'1I9V5R($5I;G1R86<`56YG_&QT:6=E
M<R!$871E:69O<FUA=`!5;F?\;'1I9V5R(%-C:&S\<W-E;"!A;F=E9V5B96XN
M`%5N9_QL=&EG97(@3&EZ96YZ<V-H;/QS<V5L+@!5;F?\;'1I9V5R($]R="!A
M;F=E9V5B96XN`%5N9_QL=&EG97(@;7-G7W1Y<&4N`%5N9_QL=&EG97(@3F%M
M90!5;F?\;'1I9V4@3V)J96MT($E$`%5N9_QL=&EG92!O9&5R(&9E:&QE;F1E
M(&%P:5]I9"X`56YG_&QT:6=E(&]D97(@9F5H;&5N9&4@4&%R86UE=&5R+@!5
M;F?\;'1I9V5S(-QB97)R96-H="X`56YG_&QT:6=E(%!A<G1N97(M240N`%5N
M9_QL=&EG97(@4')O9'5K=&-O9&4N`%5N9_QL=&EG97,@4')O=&]K;VQL+@!5
M;F?\;'1I9V5R($5M<&;D;F=E<CH@(B5S(@!5;F?\;'1I9V5S(&=E;65I;G-A
M;65S($]B:F5K=`!5;F?\;'1I9V4@57)S<')U;F=S861R97-S92X`56YG_&QT
M:6=E(%5N:6-O9&4M1&%T96XN`$EN=F5N=&%R`$%U<W=A:&P@=6UK96AR96X`
M27-L86UI<V-H92!297!U8FQI:R!)<F%N`$ER86L`27)L86YD`$ES;&4@;V8@
M36%N`%9E<F5I;GIE;'1E($=E=VET=&5R`$ES<F%E;`!!=7-S=&5L;&5R`$MU
M<G-I=@!)=&%L:65N`$IA;6%I:V$`2F%N=6%R`$IA<&%N`$IA<&%N:7-C:"`H
M25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YI96X`2G5L:0!*=6YI`$)L;V-K
M<V%T>@!:96YT<FEE<F5N`$)L;V-K<V%T>@!,:6YK<R!A=7-R:6-H=&5N`%)E
M8VAT<R!A=7-R:6-H=&5N`$MA<V%C:'-T86X`3W)I9VEN86P@8F5I8F5H86QT
M96X_`$ME;FEA`$ME<F)E<F]S+5-E<G9E<B!H870@075T:&5N=&EF:7II97)U
M;F<@>G5R_&-K9V5W:65S96XN`$ME<FYE;"U.975L:6YG90!38VAL_'-S96QE
M<GIE=6=U;F<`1FEN9V5R86)D<G5C:R!D97,@4V-H;/QS<V5L<P!38VAL_'-S
M96QLY&YG90!38VAL_'-S96QT>7``4V-H;/QS<V5L>G=E8VL`1&5R(%-C:&S\
M<W-E;"!B969I;F1E="!S:6-H(&)E<F5I=',@875F(&1E;2#V9F9E;G1L:6-H
M96X@4V-H;/QS<V5L<V5R=F5R+@!+:6YD97(`2VER:6)A=&D`1&5M;VMR871I
M<V-H92!6;VQK<W)E<'5B;&EC($MO<F5A`%)E<'5B;&EK($MO<F5A`$MO<F5A
M;FES8V@@*$550RU+4BD`2W5W86ET`$MI<F=I<VES=&%N`$Q$05`M56YT97)S
M=/QT>G5N9R!W:7)D(&)E;O9T:6=T+"!A8F5R(&1A<R!,1$%0+4UO9'5L(&ES
M="!N:6-H="!V97)F_&=B87(@;V1E<B!W=7)D92!N:6-H="!G96QA9&5N+@!!
M;E]P87-S96X`4W!R86-H90!,86]S`$QE='IT92!(Y&QF=&4`3&5T>G1E(,1N
M9&5R=6YG`$YA8VAN86UE`$QE='IT92!087-S=V]R=.1N9&5R=6YG`$QE='IT
M97,@5FEE<G1E;`!,971Z=&4@06MT=6%L:7-I97)U;F<Z`$QE='IT92!!;FUE
M;&1U;F<Z("5S`$QE='IT92!!;FUE;&1U;F<Z("5S('9O;B`E<P!,971Z=&4@
M06YM96QD=6YG.B!.;V-H(&YI90!,971T;&%N9`!'97-E='H`1F]R;6%T`$QE
M97(@;&%S<V5N(&;\<B!K96EN96X@4F%H;65N`$QI8F%N;VX`3&EN:W,`3&EN
M:V4@W&)E<G-C:')I9G0`3&EN:V4@5V5R=&4`3&5S;W1H;P!%8F5N90!,:6)E
M<FEA`$QI8GEE;@!,:65C:'1E;G-T96EN`%-P<OQH<F5G96X`3&5I8VAT97(@
M4F5G96X`1G+\:"!L96EC:'1E<B!296=E;@!3<.1T97(@3&5I8VAT97(@4F5G
M96X`3&5I8VAT92!296=E;G-C:&%U97(`3&5I8VAT97(@4F5G96X@;6ET($=E
M=VET=&5R`$QE:6-H=&5R(%-C:&YE969A;&P`3&5I8VAT92!38VAN965S8VAA
M=65R`$QI;65R:6-K`$QI;FL`3&EN:R!V97)W96ES="!A=68Z`$5M86EL861R
M97-S92!V97)L:6YK96X_`$QI;FMS`$QI;G5X+4=L_&-K<VME:W-E`$QI<W1E
M`$QI<W0@+2!"96YU='IE<B!K86YN(&1E;B!/<F1N97(@<V5H96X`1&%T96YB
M86YK96X@86YZ96EG96X`2&EL9F5E:6YT<N1G92!A;GIE:6=E;@!486)E;&QE
M;B!A;GIE:6=E;@!,:7-T96XM07)C:&EV`$QI<W1E;BU(:6QF90!,:7-T96XM
M260`3&ES=&5N+4)E<VET>F5R`$QI<W1E;BU!9')E<W-E`$QI<W1E;BU!;FUE
M;&1U;F<`3&ES=&5N+4%B;65L9'5N9P!$87,@06YZ96EG96X@9&5R(%-E<W-I
M;VYS(&ES="!F96AL9V5S8VAL86=E;CH@)7,`1&%S($%N>F5I9V5N(&1E<B!"
M96YU='IE<B!I<W0@9F5H;&=E<V-H;&%G96XZ("5S`$1A<R!!;GIE:6=E;B!D
M97(@0F5N=71Z97(@:7-T(&YI8VAT(&WV9VQI8V@N`$QI=&5R871U<@!,:71A
M=65N`$QA9&4N+BX`3&]K86QE(%5H<GIE:70Z(`!3<')A8VAE('5N9"!:96ET
M`$]R=`!!;FUE;&1E;@!,;V<@9&5R(&QE='IT96X@4WEN8VAR;VYI<V%T:6]N
M+@!!8FUE;&1E;@!!;FUE;&1E;@!!;FUE;&1E875F9V%B96X`1&EE($%N;65L
M9'5N9R!I<W0@9F5H;&=E<V-H;&%G96XL('=E:6P@4VEE($EH<F5N($)E;G5T
M>F5R;F%M96X@;V1E<B!):'(@4&%S<W=O<G0@9F%L<V-H(&5I;F=E9V5B96X@
M:&%B96XN`$%N;65L9'5N9R!F96AL9V5S8VAL86=E;BX`3&%N9V5R(%1E>'0`
M3&EE8F4`3FEE9')I9P!+;"X@9W)I96-H:7-C:&4@0G5C:'-T86)E;@!+;"X@
M;&%T96EN:7-C:&4@0G5C:'-T86)E;@!+;"X@<O9M:7-C:&4@6F%H;&5N`$QU
M>&5M8G5R9P!-30!-3U1$`$U3+51.148M06YH86YG(&5N=&AI96QT(&ME:6YE
M($1A=&5N+@!(24Y714E3`$UA8V%O`$1I92!E:&5M86QI9V4@2G5G;W-L87=I
M<V-H92!297!U8FQI:R!-87IE9&]N:65N`$UA9&%G87-K87(`36%G:64`5V5B
M;6%I;`!%;6%I;"!!9&UI;FES=')A=&EO;@!,:6YK(%]A;FQE9V5N+BXN`$UA
M;&%W:0!-86QA>7-I80!-86QI9&EV96X`36%L:0!-86QT80!697)W86QT96X@
M4VEE(&1I92!+871E9V]R:65N+"!M:70@9&5N96X@4VEE($5L96UE;G1E('5N
M9"!%:6YT<N1G92!K96YN>F5I8VAN96X@:_9N;F5N+"!S;W=I92!D:64@>G5G
M96CV<FEG96X@1F%R8F5N+@!-87`R-"U+87)T90!-87!1=65S="U+87)T90!:
M=6]R9&YU;F=E;B!G97-P96EC:&5R="X`3>1R>@!!==]E;F%B<W1A;F0`36ET
M($=E;&5S96XM+U5N9V5L97-E;BU3=&%T=7,@=F5R<V5H96X`36ET(&%N9&5R
M96T@4W1A='5S('9E<G-E:&5N("AZ+D(N(%=I8VAT:6<O0F5A;G=O<G1E="D`
M36%R<VAA;&QI;G-E;&X`36%R=&EN:7%U90!N86-H`%IU9V5O<F1N971E($9E
M;&1E<@!-875R971A;FEE;@!-875R:71I=7,`36%X:6UA;"!E<FQA=6)T97(@
M2W)E9&ET+@!-87AI;6%L92!.86-H=&EC:'1E;G1E:6QE(/QB97)S8VAR:71T
M96XN`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT96X@,C0@4W1U;F1E;CH@
M`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT96X@-B!3='5N9&5N.B``36%X
M:6UA;&4@06YZ86AL(&%N($MO;G1A:W1E;@!-87AI;6%L92!!;GIA:&P@86X@
M4&]R=&%L8FSV8VME;@!-87AI;6%L92!,Y&YG90!-87AI;6%L92!396ET96YZ
M86AL`$UA:0!-87EO='1E($ES;&%N9`!-961I>FEN`$UI=&=L:65D97(`365N
M_&QI<W1E`$UE;OQM;V1U<SH`6F5L;&5N('IU<V%M;65N9OQG96X`3F%C:')I
M8VAT`$1I92!.86-H<FEC:'0@:V]N;G1E(&5R9F]L9W)E:6-H(/QB97)P<OQF
M="!W97)D96X@86)E<B!N:6-H="!D87,@6F5R=&EF:6MA="!D97,@06)S96YD
M97)S+@!.86-H<FEC:'0@;FEC:'0@;65H<B!G_&QT:6<N`$YA8VAR:6-H=&5N
M='EP`$UE=&%R(%=E='1E<@!-971A<F)L;V-K(&YI8VAT('9E<F;\9V)A<BX`
M365T87)B;&]C:R!N:6-H="!V97)F_&=B87(N($1E=&%I;',@=W5R9&5N(&;\
M<B!D96X@061M:6YI<W1R871O<B!M:71G96QO9V=T+@!+96EN92!697)B:6YD
M=6YG('IU<B!-971A<D1"+@!-971H;V1E`$1I92!-971H;V1E("(E<R(@:7-T
M(&YI8VAT(&1E9FEN:65R=`!-971H;V1E(&YI8VAT(&1E9FEN:65R="X@075F
M9V5R=69E;F4@365T:&]D93H@)7,`365T<FES8V@`365X:6MO`$;V9&5R:65R
M=&4@4W1A871E;B!V;VX@36EK<F]N97-I96X`36ET=&4`36EM971Y<`!4:65F
M<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T=6YD96XZ(`!4:65F<W1T
M96UP97)A='5R(&1E<B!L971Z=&5N(#8@4W1U;F1E;CH@`$1A<R!M:6YI;6%L
M92!087-S=V]R=&%L=&5R(&ES="!N;V-H(&YI8VAT(&%B9V5L875F96X`4W!I
M96=E;&X`5F5R<V-H:65D96YE<P!$3B!F96AL="!I;B!D97(@3$1!4"U+;VYF
M:6=U<F%T:6]N+@!014%2+5!A:V5T($A45%!?4F5Q=65S="!F96AL="X`1F5H
M;&5N9&4@2V]N9FEG=7)A=&EO;BX@4VEE(&W\<W-E;B!D:65S92!J971Z="!E
M<GIE=6=E;BP@=V5N;B!3:64@9&EE($%N=V5N9'5N9R!V97)W96YD96X@;?9C
M:'1E;BX`1F5H;&5N9&4@3F%C:')I8VAT96XM240N`%!%05(M4&%K970@36%I
M;"!F96AL="X`1F5H;&5N9&4@4VET>G5N9W,M240N`$UO`$5M86EL($UO8FEL
M`%1E;&5F;VX@;6]B:6P`3>3?:6<`Q&YD97)U;F=S9&%T=6T`55),(&)E87)B
M96ET96X`Q&YD97)U;F<@9F5H;&=E<V-H;&%G96XZ("@E<RD@)7,`36]D=6QU
M<P!297!U8FQI:R!-;VQD874`36]N86-O`$UO;F=O;&5I`$UO;F%T('5N9"!*
M86AR`$UO;F%T;&EC:`!-;VYT<V5R<F%T`$UO;F1P:&%S96X`365H<B!&96QD
M97(@:6X@6F5I;&4@)60@86QS(&1I92!E<G=A<G1E=&5N("5D(&=E9G5N9&5N
M+@!-96AR(&%L<R`Q($5I;G1R86<@>G5R_&-K9V5L:65F97)T`$UA<F]K:V\`
MW&)E<G=I96=E;F0@:&5I=&5R`-QB97)W:65G96YD($)E=_9L:W0`W&)E<G=I
M96=E;F0@0F5W]FQK="!U;F0@5VEN9&EG`-QB97)W:65G96YD(%-O;FYI9P!6
M97)S8VAI96)E;@!.86-H('5N=&5N`$YA8V@@;&EN:W,`3F%C:"!R96-H=',`
M3F%C:"!O8F5N`$YA8V@@=6YT96X`3F%C:"!L:6YK<P!.86-H(')E8VAT<P!.
M86-H(&]B96X`36]S86UB:6L`375L8F5R<GDM061R97-S8G5C:`!!=7-W86AL
M;&ES=&4@:6X@;65H<F5R96X@16)E;F5N`$UU;'1I;6%P+55++4MA<G1E`$UE
M:')E<F4@4&5R<V]N96X@;6ET(&1E<B!!9')E<W-E(%LE<UTL(&%B97(@:V5I
M;F4@;6ET(&1E;2!.86UE;B!;)7-=(&EM($%D<F5S<V)U8V@`365H<F9A8VAA
M=7-W86AL`$UE:6X@2V]N=&\`365I;B!+;VYT;P!-96EN($%D<F5S<V)U8V@`
M365I;F4@061R97-S8OQC:&5R`$UE:6X@4&]R=&%L`$UE:6X@4&]R=&%L;&%Y
M;W5T`$)U<FUA`$Y%24XL(&EC:"!S=&EM;64@3DE#2%0@>G4`3F%M90!.86UE
M;G-F;W)M870`3F%M:6)I80!.875R=0!.97!A;`!.971C96YT97(@36ET9VQI
M961E<G9E<GIE:6-H;FES`$YI961E<FQA;F1E`$YI961E<FSD;F1I<V-H92!!
M;G1I;&QE;@!.971S8V%P92U"87-I<RU54DP`3F5T<V-A<&4M0T$M4W!E<G)U
M;F=S+5523`!.971S8V%P92U#02U2:6-H=&QI;FEE;BU54DP`3F5T<V-A<&4M
M6F5T:69I:V%T<V5R;F5U97)U;F=S+5523`!.971S8V%P92U3<&5R<G5N9W,M
M55),`$YE='-C87!E+5-33"U397)V97)N86UE`$YE='-C87!E+4MO;6UE;G1A
M<@!.971S8V%P92U:97)T:69I:V%T='EP`$YE='IW97)K`$YI90!.975K86QE
M9&]N:65N`$YE=64@2V%T96=O<FEE`$YE=65R($MO;G1A:W0`3F5U;6]N9`!.
M975E<B!"96YU='IE<FYA;64@*&]P=&EO;F%L*0!.975S965L86YD`$YE=65S
M(%!A<W-W;W)T`$1A<R!N975E(%!A<W-W;W)D('=I<F0@86T@)7@@86)L875F
M96XN`$1I92!N975E;B!087-S=_9R=&5R('-T:6UM96X@;FEC:'0@_&)E<F5I
M;BX`3F5U97,@1F5N<W1E<B`H7V)L86YK*0!.86-H<FEC:'1E;@!.97=S9W)U
M<'!E;@!796ET97(`3N1C:'-T92`T(%!H87-E;@!.Y&-H<W1E($5I;G-T96QL
M=6YG96X`5V5I=&5R/@!.:6-A<F%G=6$`4W!I='IN86UE`$YI9V5R`$YI9V5R
M:6$`3F%C:'1S`$YI=64`3F5I;@!%<R!W=7)D92!K96EN("5S($5I;G1R86<@
M9OQR("5S(&=E9G5N9&5N`$ME:6YE($%D<F5S<V+\8VAE<B!G969U;F1E;BX`
M2V5I;F4@2V]N9FEG=7)A=&EO;G-D871E;B!V97)F_&=B87(L('5M(%5N=&5R
M<V-H:65D92!A;GIU>F5I9V5N+@!+96EN92!3=')A=&5G:64@>G5M($5R<W1E
M;&QE;B!V;VX@25-/+4%B8FEL9&5R;B!V97)F_&=B87(N`$ME:6YE($)A=&-H
M+59O<FQA9V4N`$5S(&5X:7-T:65R="!K96EN($)L;V-K(&%N(&1E<B!A;F=E
M9V5B96YE;B!0;W-I=&EO;@!+96EN($MA;&5N9&5R;F%M92!F_'(@9&EE($U#
M04PM075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+96EN92#$;F1E<G5N
M9V5N+@!5;G1E<FAA;&(@9&EE<V5R($5B96YE(&OV;FYE;B!K96EN92!W96ET
M97)E;B!5;G1E<G)E8VAT92!H:6YZ=6=E9OQG="!W97)D96XN`$;\<B`E<R!W
M=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N(&%N9V5G
M96)E;BX`1OQR(&1E;B!&5%`M5D93+51R96EB97(@=W5R9&5N(&ME:6YE($MO
M;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN`$;\<B!D96X@
M4U%,+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN
M9F]R;6%T:6]N96X@86YG96=E8F5N+@!&_'(@9&5N(%-13"U$871E:2U61E,M
M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO
M;F5N(&%N9V5G96)E;BX`2V5I;F4@2V]N=&%K=&4@9V5F=6YD96XN`$ME:6X@
M2W)E9&ET(&UE:'(@_&)R:6<N`$ME:6X@16UP9N1N9V5R(&%N9V5G96)E;BX`
M2V5I;F4@1&%T96D@:&]C:&=E;&%D96X`2V5I;F4@26-O;G,@9V5F=6YD96XN
M`$5S('=U<F1E(&ME:6X@3W)T(&9E<W1G96QE9W0N`$ME:6X@3W)T(&%N9V5G
M96)E;BX`2V5I;F4@3F%C:')I8VAT(&%N9V5G96)E;BX`2V5I;B!.86UE(&%N
M9V5G96)E;BX`2V5I;F4@3G5M;65R(&%N9V5G96)E;BX`2V5I;F4@86YS=/;?
M:6=E;B!';/QC:W-K96MS90!+96EN(%!A<W-W;W)T(&;\<B!D:64@2%144"U!
M=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR
M(&1I92!)34%0+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!0
M87-S=V]R="!F_'(@9&EE($ME<F)E<F]S+4%U=&AE;G1I9FEZ:65R=6YG(&%N
M9V5G96)E;BX`2V5I;B!087-S=V]R="!F_'(@9&EE($QO9VEN+4%U=&AE;G1I
M9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R="!F_'(@9&EE(%!!
M4U-71"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O
M<G0@9OQR(&1I92!334(M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+
M96EN(%!F860@>G5M($]P96Y34TPM4')O9W)A;6T@86YG96=E8F5N+B!$87,@
M3W!E;E-33"U0<F]G<F%M;2!W:7)D(&)E;O9T:6=T+"!U;2!02T-3+3$R+41A
M=&5N('9E<F%R8F5I=&5N('IU(&OV;FYE;BX`2V5I;F4@875S<W1E:&5N9&5N
M(%)E9VES=')I97)U;F=E;BX`2V5I;B!3<&5I8VAE<G!L871Z+4MO;G1I;F=E
M;G0@9F5S=&=E;&5G="X`2V5I;F4@4F%H;65N`$ME:6X@5')E;FYZ96EC:&5N
M(&%N9V5G96)E;BX`2V5I;F4@4V5I=&5N`$1A=&5I(&YI8VAT(&=E9G5N9&5N
M`$ME:6YE('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9OQR(&1E;B!#86-H92!G
M969U;F1E;BX`2V5I;B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O<G0@
M86YG96)E;BX`17,@=W5R9&5N(&ME:6YE('9#87)D+41A=&5N(&=E9G5N9&5N
M+@!%<R!W=7)D96X@:V5I;F4@9_QL=&EG96X@6$U,+41A=&5N('IU<OQC:V=E
M9V5B96X`2V5I;F4@5V5R=&4`2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@9&5R
M($]R:6=I;F%L:V]N9FEG=7)A=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE
M($EH<F4@2V]N9FEG=7)A=&EO;BX`2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@
M26AR97(@2V]N9FEG=7)A=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE($EH
M<F4@2V]N9FEG=7)A=&EO;BX`2V5I;F4`2V5I;G,@*%-T86YD87)D(&)E;G5T
M>F5N*0!.;W)D:7-C:"`H25-/+3@X-3DM,3`I`$YO<F9O;&MI;G-E;`!.]G)D
M;&EC:&4@2&5M:7-P:&5R90!.]G)D;&EC:&4@36%R:6%N96X`3F]R=V5G96X`
M1_QL=&EG(&)I<P!'_&QT:6<@86(`2V5I;B!697)Z96EC:&YI<P!.:6-H="!I
M;7!L96UE;G1I97)T+@!.:6-H="!F97-T9V5L96=T`$YI8VAT('5N=&5R<W3\
M='IT+@!"96UE<FMU;F=E;@!.:6-H=',@86YZ=7IE:6=E;BP@8FET=&4@>G5R
M_&-K9V5H96XN`$YO=F5M8F5R`%IA:&P`06YZ86AL(&1E<B!:96EC:&5N`$%N
M>F%H;"!D97(@4W!A;'1E;@!!;GIA:&P@9&5R($5I;G1RY&=E('!R;R!396ET
M90!!;GIA:&P@9&5R(%IE:6QE;@!+96EN92!.=6UM97)N(&;\<B!D:64@5F5R
M=&5I;&5R;&ES=&4@86YG96=E8F5N+@!/2P!/8FIE:W0`3V)J96MT97)S=&5L
M;&5R`$]B:F5K="!N:6-H="!G969U;F1E;@!/:W1A;'IA:&P`3VMT;V)E<@!&
M:6QT97(@9OQR(&%N<W3VWVEG92!);FAA;'1E`$+\<F\`26AR(&YE=65S(%!A
M<W-W;W)T(&UU<W,@<VEC:"!V;VX@26AR96T@86QT96X@=6YT97)S8VAE:61E
M;BX`06QT97,@4&%S<W=O<G0`1F%L<V-H97,@86QT97,@4&%S<W=O<G0N`$]M
M86X`5V5N;B!3:64@9&EE<V4@16EN<W1E;&QU;F<@<W!E:6-H97)N+"!W:7)D
M(&1A<R!A;F=E9V5B96YE($%D<F5S<V)U8V@@96YD9_QL=&EG(&=E;/9S8VAT
M+B!796YN(%-I92!D87,@;FEC:'0@;?9C:'1E;BP@Y&YD97)N(%-I92!):')E
M($%U<W=A:&P@875F(")K96EN(BX`3G5R($E-05`M4V5R=F5R('5N=&5R<W3\
M='IE;B!G96UE:6YS86UE($]R9&YE<BX`3G5R(&%N<W3VWVEG92!';/QC:W-K
M96MS90!.=7(@96EN92!%;6%I;"U!9')E<W-E(&5R;&%U8G0N`$YU<B!E:6YZ
M96QN92!V0V%R9',@=V5R9&5N('5N=&5R<W3\='IT+@!.=7(@9&5R($)E<VET
M>F5R(&]D97(@9&5R(%-Y<W1E;6%D;6EN:7-T<F%T;W(@:V%N;B!D96X@0F5S
M:71Z97(@;V1E<B!D:64@0F5S:71Z97)R96-H=&4@Y&YD97)N`$EN(&YE=65M
M($9E;G-T97(@]F9F;F5N`$]P96Y34TPM1F5H;&5R.B!3:6=N:65R=&4@4R]-
M24U%+41A=&5N(&MO;FYT96X@;FEC:'0@97AT<F%H:65R="!W97)D96XN`$1I
M97-E;B!,:6YK(&EN(&5I;F5M(&YE=65M($9E;G-T97(@]F9F;F5N`$)E=')I
M96)S>7-T96T`16EN<W1E;&QU;F=E;@!%:6YS=&5L;'5N9V5N(&;\<B`E<P!.
M=6UM97)I97)T92!,:7-T90!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N<V%B
M=&5I;'5N9P!/<F=A;FES:65R96X`3W)I9VEN86QV;W)L86=E(&1E<B!!;G=E
M;F1U;F<`3W)I9VEN86QV;W)L86=E(&EN("5S.@!3;VYS=&EG90!!;F1E<F4@
M26YF;W)M871I;VYE;@!!;F1E<F4@16EN<W1E;&QU;F=E;@!"97-I='IE<G)E
M8VAT90!004TM075T:&5N=&EF:7II97)U;F<@:7-T(&YI8VAT('9E<F;\9V)A
M<BX`4$5!4CHZ36%I;"U"86-K96YD`$1I9VET86QE(%!'4"U5;G1E<G-C:')I
M9G0`4$=0+79E<G-C:&S\<W-E;'1E($1A=&5N`-9F9F5N=&QI8VAE<B!01U`M
M4V-H;/QS<V5L`$UI="!01U`@=6YT97)Z96EC:&YE=&4O=F5R<V-H;/QS<V5L
M=&4@1&%T96X`4$A0($-O9&4`4$A0(%-H96QL`%9O<FUI='1A9W,@;&5I8VAT
M97(@4F5G96X`3F%C:&UI='1A9W,@4F5G96X`3F%C:&UI='1A9W,@4V-H875E
M<@!.86-H;6ET=&%G<R!38VAN964`3F%C:&UI='1A9W,@4V-H;F5E<V-H875E
M<@!.86-H;6ET=&%G<R!3;VYN90!.86-H;6ET=&%G<R!'97=I='1E<@!$:64@
M4$]325@M17)W96ET97)U;F<@9F5H;'0`7U!(4"!3:&5L;`!);FYE;F%B<W1A
M;F0`4&%K:7-T86X`4&%L874`0F5S971Z=&4@4&%LY'-T:6YE;G-I<V-H92!'
M96)I971E`%!A;F%M80!087!U82U.975G=6EN96$`4&%R86=U87D`5&5I;'=E
M:7-E($)E=_9L:W0`4&%S<W=O<G0`4&%S<W=O<G0@97)F;VQG<F5I8V@@9V7D
M;F1E<G0N`$9A;'-C:&5S(%!A<W-W;W)T`$ME:6X@4&%S<W=O<G0@9OQR(&1I
M92!2041)55,M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!087-S=V]R
M="!M:70@0F5S=.1T:6=U;F<`4&%S<W=O<G0Z`%!A<W-W;W)T.B``1&EE(%!A
M<W-W]G)T97(@;?QS<V5N(&=L96EC:"!S96EN+@!%:6YF_&=E;@!6;VX@9&5R
M(%IW:7-C:&5N86)L86=E(&5I;F;\9V5N`%!F860`075S<W1E:&5N9&4@4F5G
M:7-T<FEE<G5N9V5N.@!097)S;VYE;@!0<F]Z96YT`%=A<G1U;F=S87)B96ET
M96X@9'5R8VAF_&AR96X`5V%R='5N9W-A<F)E:71E;B!N86-H(&1E<B!!;FUE
M;&1U;F<@9'5R8VAF_&AR96X_`%)E8VAT90!296-H="`B)7,B('=U<F1E(&YI
M8VAT(&=E;/9S8VAT+@!:=6=R:69F('9E<G=E:6=E<G0`6G5G<FEF9B!V97)W
M96EG97)T`%)E8VAT90!296-H=&5V97)W86QT=6YG`%!E<G/V;FQI8VAE($%N
M9V%B96X`4&5R=0!(875S=&EE<F4`4&AI;&EP<&EN96X`5&5L969O;@!&;W1O
M<P!0:6YE+4%D<F5S<V)U8V@`4&ET8V%I<FX`4&EX96P`4&QA='1H96ET96X`
M0FET=&4@:VQI8VME;B!3:64@:6X@96EN92!:96QL90!":71T92!B97-TY'1I
M9V5N(%-I92P@9&%S<R!3:64@9&EE<V5S($5L96UE;G0@;/9S8VAE;B!M]F-H
M=&5N.@!":71T92!B973D=&EG96X@4VEE+"!D87-S(%-I92!D96X@3&EN:R!V
M;VX@9&EE<V5M($5L96UE;G0@96YT9F5R;F5N(&WV8VAT96XN`$)I='1E(&5I
M;F5N($UO;F%T('5N9"!E:6X@2F%H<B!A;F=E8F5N+@!":71T92!G96)E;B!3
M:64@96EN96X@3F%M96X@9OQR(&1I92!N975E($MA=&5G;W)I92!A;CH`0FET
M=&4@96EN92!G_&QT:6=E($E0+4%D<F5S<V4@96EN9V5B96XN`$)I='1E(&=E
M8F5N(%-I92!E:6X@9_QL=&EG97,@1&%T=6T@86X[(/QB97)P<OQF96X@4VEE
M(&1I92!:86AL(&1E<B!486=E(&EN(&1E;2!-;VYA="X`0FET=&4@96EN96X@
M9_QL=&EG96X@6F5I='=E<G0@96EN9V5B96XN`$)I='1E(&5I;F5N($YA;65N
M(&;\<B!D:64@;F5U92!+;VYT86ML:7-T92!A;F=E8F5N.@!":71T92!G96)E
M;B!3:64@96EN92!:=7-A;6UE;F9A<W-U;F<@26AR97,@4')O8FQE;7,@86XN
M`$)I='1E(&=E8F5N(%-I92!):')E;B!"96YU='IE<FYA;65N('5N9"!):'(@
M4&%S<W=O<G0@86X`0FET=&4@;&5S96X@4VEE('-I8V@@9&5N(&9O;&=E;F1E
M;B!497AT('-O<F=FY&QT:6<@9'5R8V@N(%-I92!-W%-314X@9&EE<V5N($)E
M9&EN9W5N9V5N('IU<W1I;6UE;BP@=V5N;B!3:64@9&EE<V5S(%-Y<W1E;2!B
M96YU='IE;B!M]F-H=&5N+@!":71T92!D96X@;F5U96X@2V%T96=O<FEE;F%M
M96X@96EN9V5B96XZ`%!O;&5N`%!O;&ET:6L`56UF<F%G96X`4&]R='5G86P`
M4&]S:71I;VYI97)U;F<@9&EE<V4@0FEL9&5S`%!O<VET:6]N:65R=6YG(&1I
M97-E<B!486)E;&QE`%-E;F1E;B!A;B!D:65S96X@3W)D;F5R("AN:6-H="!D
M=7)C:"!)34%0*0!.:65D97)S8VAL86<@:6X@9&5N(&QE='IT96X@)7,@4W1U
M;F1E*&XI.B``3FEE9&5R<V-H;&%G<RT\8G(@+SYW86AR<V-H96EN;&EC:&ME
M:70`4')E9G-?;&1A<#H@1&EE(&)E;O9T:6=T92!,1$%0+45R=V5I=&5R=6YG
M('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!0<F5F<U]S97-S:6]N.B!$:64@8F5N
M]G1I9W1E(%-E<W-I;VXM17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD
M96XN`$QU9G1D<G5C:P!,=69T9')U8VL@875F(%-E96CV:&4Z(`!,=69T9')U
M8VLZ(`!6;W)S8VAA=0!%:6YE(%9O<G-C:&%U(&1E<R!":6QD97,@:6X@96EN
M96T@;F5U96T@1F5N<W1E<B!A;GIE:6=E;@!:=7+\8VL`5F]H97)I9V4@16EN
M<W1E;&QU;F=E;@!$;VMU;65N="!D<G5C:V5N`%!R:79A=&5S($%D<F5S<V)U
M8V@`4')I=F%T97(@4V-H;/QS<V5L`%!R;V)L96UE`%!R;V)L96UB97-C:')E
M:6)U;F<`4')O:F5K=&4`3F%C:&9R86=E=&5X=`#69F9E;G1L:6-H97(@4V-H
M;/QS<V5L`$%L9V]R:71H;75S(&1E<R#V9F9E;G1L:6-H96X@4V-H;/QS<V5L
M<P!);F9O<FUA=&EO;F5N('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L`$1A
M<R#V9F9E;G1L:6-H92]P<FEV871E(%-C:&S\<W-E;'!A87(@:V]N;G1E(&YI
M8VAT(&5R<W1E;&QT('=E<F1E;BX`4'5E<G1O(%)I8V\`3F%C:')I8VAT96X@
M96YD9_QL=&EG(&SV<V-H96X`2V%T87(`06)F<F%G90!!8F9R86=E(&9E:&QG
M97-C:&QA9V5N.B`H)7,I("5S`%-C:&YE;&QS=6-H90!3<&5I8VAE<G!L871Z
M+4MO;G1I;F=E;G0`UF9F96YT;&EC:&5R(%)302!38VAL_'-S96P@*"5D($)I
M="D`075S=V%H;&MN;W!F`%)E9V5N`$9R_&@@4F5G96X`4W#D=&5R(%)E9V5N
M`%)E9V5N<V-H875E<@!38VAN965R96=E;@!296=E;B!I;B!38VAN964@_&)E
M<F=E:&5N9`!';/QC:W-K96MS`%9E<FCD;'1N:7,`3&5S96X`3&5S96X@9F5H
M;&=E<V-H;&%G96XZ("@E<RD@)7,`3F%C:')I8VAT96X@;&5S96X`06YZ96EG
M96X@=F]N($MO;G1A:W1E;B!N:6-H="!U;G1E<G-T_'1Z="X`)7,@=VER:VQI
M8V@@;/9S8VAE;C\@1&EE<V5R(%9O<F=A;F<@:V%N;B!N:6-H="!R_&-K9^1N
M9VEG(&=E;6%C:'0@=V5R9&5N+@!$:65S96X@2V]N=&%K="!W:7)K;&EC:"!L
M]G-C:&5N/P!$871E;B!D97,@0F5N=71Z97)S("5S('=I<FML:6-H(&SV<V-H
M96X_($1I97-E<B!6;W)G86YG(&MA;FX@;FEC:'0@<OQC:V?D;F=I9R!G96UA
M8VAT('=E<F1E;BX`06YG97IE:6=T92!%:6YT<N1G93H`1OQH<G0@;&5T>G1E
M($%K=&EO;B!E<FYE=70@875S`$%K='5A;&ES:65R90!$>6YA;6ES8VAE($UE
M;OQE;&5M96YT92!A:W1U86QI<VEE<F5N.@!0;W)T86QA;G-I8VAT(&%K='5A
M;&ES:65R96XZ`%)E9W5LY')E<B!!=7-D<G5C:P!697)B:6YD=6YG<RU"<F]W
M<V5R`$%K='5A;&ES:65R96X`0F5M97)K=6YG96X`16YT9F5R;G1E(%-E<G9E
M<@!397)V97)A9')E<W-E("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H`16YT9F5R;F5N`$)L;V-K(&SV<V-H96X`061R97-S8G5C:"!E;G1F97)N
M96X`4W!A;'1E(&5N=&9E<FYE;@!&;W)M871I97)U;F<@96YT9F5R;F5N`$%U
M<R!D:65S97(@3&ES=&4@96YT9F5R;F5N`%!A87(@;/9S8VAE;@!'97-P96EC
M:&5R=&5S(%-K<FEP="!A=7,@9&5M('1E;7!O<N1R96X@5F5R>F5I8VAN:7,@
M96YT9F5R;F5N+@!%;G1F97)N90!$:65S97,@16QE;65N="!A=7,@9&5M($1O
M:W5M96YT(&5N=&9E<FYE;@!"96YU='IE<B!L]G-C:&5N`$)E;G5T>F5R(&SV
M<V-H96XZ("5S`$5X:7-T:65R96YD97,@061R97-S8G5C:"!M:70@9&5M(&EM
M<&]R=&EE<G1E;B!E<G-E='IE;C\@/'-T<F]N9SY787)N=6YG.B!$86UI="!W
M97)D96X@86QL92!A:W1U96QL96X@16EN='+D9V4@:6X@9&5M($%D<F5S<V)U
M8V@@9V5L]G-C:'0N/"]S=')O;F<^`$%N9G)A9V4@:V]N;G1E(&YI8VAT(&)E
M86YT=V]R=&5T('=E<F1E;BX@6G5R_&-K9V5G96)E;F5R($9E:&QE<F-O9&4Z
M(`!'97?\;G-C:'1E<R!/8FIE:W0@;FEC:'0@9V5F=6YD96XN`$1E<B!G97?\
M;G-C:'1E($1I96YS="!K;VYN=&4@;FEC:'0@9V5F=6YD96X@=V5R9&5N+@`B
M)7,B('=U<F1E(&EN(&1E<B!+;VYF:6=U<F%T:6]N(&;\<B`E<R!N:6-H="!A
M;F=E9V5B96XN`"(E<R(@=W5R9&4@:6X@9&5R(%9&4RU+;VYF:6=U<F%T:6]N
M(&YI8VAT(&%N9V5G96)E;BX`(B5S(B!W=7)D92!I;B!D97(@2V]N9FEG=7)A
M=&EO;B!N:6-H="!A;F=E9V5B96XN`$YO='=E;F1I9V5S($9E;&0`6G5R_&-K
M<V5T>F5N`%!A<W-W;W)T('IU<OQC:W-E='IE;@!3971Z96X@4VEE($EH<B!0
M87-S=V]R="!Z=7+\8VL`6G5R_&-K<V5T>F5N`$QE='IT92!!8F9R86=E(&5I
M;F;\9V5N`$5R9V5B;FES<V4`6G5R_&-K('IU($5I;G-T96QL=6YG96X`3F5U
M97,@4&%S<W=O<G0@97)N975T(&5I;F=E8F5N`%+I=6YI;VX`2V]N9FEG=7)A
M=&EO;B!Z=7+\8VMS971Z96X`5UE325=91RU%9&ET;W(@16EN<W1E;&QU;F=E
M;@!2Y'1S96P`4F5C:'1S`%)E8VAT92#<8F5R<V-H<FEF=`!296-H=&4@5V5R
M=&4`7UIE:6QE;F5I9V5N<V-H869T96XN+BX`4F]L;&4`4G5MY&YI96X`56T@
M,3@PL"!D<F5H96X`3F%C:"!L:6YK<R!D<F5H96X`3F%C:"!R96-H=',@9')E
M:&5N`%IE:6QE;F5I9V5N<V-H869T96X`6F5I;&5N96EG96YS8VAA9G1E;@!:
M96EL96XZ`%)E9V5L;@!286AM96X@>G=I<V-H96X@86QL96X@6F5I;&5N('5N
M9"!3<&%L=&5N`%)A:&UE;B!N=7(@>G=I<V-H96X@4W!A;'1E;@!286AM96X@
M;G5R('IW:7-C:&5N(%IE:6QE;@!3=&%R=&5N`%)U<W-I<V-H92!&]G)D97)A
M=&EO;@!2=6%N9&$`4R]-24U%(&MR>71O9W)A<&AI<V-H92!5;G1E<G-C:')I
M9G0`36ET(%,O34E-12!V97)S8VAL_'-S96QT92!.86-H<FEC:'0`UF9F96YT
M;&EC:&5S(%,O34E-12U:97)T:69I:V%T`%-!4TPM075T:&5N=&EF:7II97)U
M;F<@:7-T(&YI8VAT('9E<F;\9V)A<BX`4TU3+59E<G-A;F0`4U%,(%-H96QL
M`%-13"U!;G=E:7-U;F<@>G5R($%B9G)A9V4@9&5R(%=E<G1E`%-32`!35$%2
M5%1,4R!F96AL9V5S8VAL86=E;CH@*"5S*2`E<P!%4D9/3$<`4U]13"!3:&5L
M;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@=6YD($YE=FES`%-A:6YT
M($QU8VEA`%-A:6YT(%!I97)R92!U;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N
M="!U;F0@9&EE($=R96YA9&EN96X`1VQE:6-H97(@4F%H;65N("A?<V5L9BD`
M4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!U;F0@4')I;F-I<&4`4V%T96QL
M:71E;G!R;W9I9&5R`%-A=61I+4%R86)I96X`4W!E:6-H97)N`"(E<R(@<W!E
M:6-H97)N`"5S('-P96EC:&5R;@!%:6YS=&5L;'5N9V5N('-P96EC:&5R;@!%
M<GIE=6=T92!+;VYF:6=U<F%T:6]N(&%L<R!02%`M4VMR:7!T(&EM('1E;7!O
M<N1R96X@5F5R>F5I8VAN:7,@26AR97,@4V5R=F5R<R!S<&5I8VAE<FXN`"5S
M+4MO;F9I9W5R871I;VX@9V5S<&5I8VAE<G0N`$1A<R!!:W1U86QI<VEE<G5N
M9W-S:W)I<'0@=W5R9&4@:6X@(B5S(B!G97-P96EC:&5R="X`4W!E:6-H97)N
M('9O;B!+;VYT86MT96X@;FEC:'0@=6YT97)S=/QT>G0N`%9E<F5I;GIE;'1E
M($=E=VET=&5R`%=I<W-E;G-C:&%F=`!3=6-H90!3=6-H;6%S8VAI;F5N`%-U
M8VAE(&9E:&QG97-C:&QA9V5N`%-U8VAE(&9E:&QG97-C:&QA9V5N.B`E<P!3
M=6-H96X@=F]N($MO;G1A:W1E;B!N:6-H="!U;G1E<G-T_'1Z="X`4W5C:&4N
M+BX`1&%T96EE;B!A=7-WY&AL96X`1&%T=6T@875S=^1H;&5N`$AI;GIU>G5F
M_&=E;F1E($=R=7!P96X@875S=^1H;&5N`$YE=65N($)E<VET>F5R(&%U<W?D
M:&QE;@!397)V97(@875S=^1H;&5N`$AI;GIU>G5F_&=E;F1E;B!"96YU='IE
M<B!A=7-WY&AL96X`06QL92!A=7-WY&AL96X`3&5G96X@4VEE(&%L;&4@1&%T
M=6US:V]M<&]N96YT96X@9F5S="X`5^1H;&5N(%-I92!D87,@061R97-S8G5C
M:"P@9&%S(&=E;/9S8VAT('=E<F1E;B!S;VQL`%?D:&QE;B!3:64@9&%S($%D
M<F5S<V)U8V@L(&1A<R!B96%R8F5I=&5T('=E<F1E;B!S;VQL`$]B:F5K="!A
M=7-WY&AL96X`2V5I;F5N(&%U<W?D:&QE;@!7Y&AL96X@4VEE(&1A<R!!9')E
M<W-B=6-H+"!A=7,@9&5M(&5X<&]R=&EE<G0@=V5R9&5N('-O;&PZ`%?D:&QE
M;B!3:64@9&%S($%D<F5S<V)U8V@L(&EN(&1A<R!I;7!O<G1I97)T('=E<F1E
M;B!S;VQL.@!7Y&AL96X@4VEE(&1I92!B96[V=&EG=&5N(%IE:6-H96X@875S
M(&1E;B!J97=E:6QI9V5N($9E;&1E<FX@875S+B!$86YN(&OV;FYE;B!3:64@
M9&EE<V4@875S(&1E;2!497AT9F5L9"!K;W!I97)E;B!U;F0@:6X@26AR92!.
M86-H<FEC:'0@96EN9OQG96XN`%?D:&QE;B!3:64@9&5N(%IE:6-H96YS871Z
M(&1E<B!I;7!O<G1I97)T96X@1&%T96DZ`%?D:&QE;B!3:64@9&%S($1A='5M
M<W1R96YN>F5I8VAE;CH`5^1H;&5N(%-I92!D87,@1&%T=6US9F]R;6%T.@!7
MY&AL96X@4VEE(&1A<R!%>'!O<G1F;W)M870Z`%?D:&QE;B!3:64@9&EE($1A
M=&5I+"!D:64@:6UP;W)T:65R="!W97)D96X@<V]L;#H`5^1H;&5N(%-I92!D
M87,@1F]R;6%T(&1E<B!I;7!O<G1I97)T96X@1&%T96DZ`$QE9V5N(%-I92!F
M97-T+"!W:64@9&EE($YA;65N(&%N9V5Z96EG="!W97)D96X@<V]L;&5N.@!7
MY&AL96X@4VEE(&1I92!)9&5N=&ETY'0L(&1I92!3:64@Y&YD97)N(&WV8VAT
M96XZ`%?D:&QE;B!3:64@9&%S(%IE:71T<F5N;GIE:6-H96XZ`%?D:&QE;B!3
M:64@9&%S(%IE:71F;W)M870Z`%?D:&QE;B!3:64@>G=E:2!Z=7-A;6UE;F=E
M:/9R:6=E($9E;&1E<B!A=7,N`%?D:&QE;B!3:64@9&EE(%-T86YD87)D86YS
M:6-H="!U;F0@16EN<W1E;&QU;F=E;B!F_')S(%-O<G1I97)E;B!U;F0@0FSD
M='1E<FXN`%?D:&QE;B!3:64@9&EE($9E;&1E<B!A=7,L(&1I92!I;B!D97(@
M061R97-S;&ES=&4@86YG97IE:6=T('=E<F1E;B!S;VQL96XN`%?D:&QE;B!3
M:64@9&%S($9O<FUA="P@:6X@9&5M(&1I92!.86UE;B!A;F=E>F5I9W0@=V5R
M9&5N('-O;&QE;BX`5^1H;&5N(%-I92!E:6X@1F%R8G-C:&5M82X`5^1H;&5N
M(%-I92!):')E(&)E=F]R>G5G=&4@4W!R86-H93H`061R97-S8G5C:"`B)7,B
M(&%U<V=E=^1H;'0N`%!R;V)L96UB97)I8VAT(&%B<V-H:6-K96X`4TU3('9E
M<G-C:&EC:V5N`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I96X@
M=6YD($UO;G1E;F5G<F\`4V5R:65N;G5M;65R`%-E<G9E<F1A=&5N('5N9_QL
M=&EG(&]D97(@;FEC:'0@=F5R9OQG8F%R+@!397-S<VEO;G9E<G=A;'1U;F<`
M4V5S<VEO;BU)1"!A8F=E;&%U9F5N+@!3:71Z=6YG96X`075S=V%H;"U3871Z
M`$QE9V5N(%-I92!D:64@16EN<W1E;&QU;F=E;B!F97-T+"!D:64@97,@26AN
M96X@97)L875B96X@26AR(%!A<W-W;W)T('IU<OQC:WIU<V5T>F5N+"!F86QL
M<R!S:64@97,@96EN;6%L('9E<F=E<W-E;B!S;VQL=&5N+@!,96=E;B!3:64@
M96YT9F5R;G1E(%-E<G9E<B!F97-T+"!A=68@9&EE(%-I92!V;VX@26AR96T@
M4&]R=&%L(&%U<R!Z=6=R96EF96X@;?9C:'1E;BX`5^1H;&5N(%-I92!):')E
M(&)E=F]R>G5G=&4@4W!R86-H92P@6F5I='IO;F4@=6YD($1A='5M<V5I;G-T
M96QL=6YG96XN`$QE9V5N(%-I92!D87,@9&EE(%-T87)T86YW96YD=6YG+"!D
M87,@1F%R8G-C:&5M82P@9&EE(%-E:71E;F%K='5A;&ES:65R=6YG('5N9"!A
M;F1E<F4@06YZ96EG965I;G-T96QL=6YG96X@9F5S="X`2V]N9FEG=7)A=&EO
M;@!!:W1U86QI<VEE<G5N9W-S:W)I<'1E('-I;F0@=F5R9OQG8F%R`$UE:')E
M<F4@<&%S<V5N9&4@3W)T92!M:70@9&EE<V5M(%!A<F%M971E<CH@`%-E>6-H
M96QL96X`1V5M96EN<V%M97,@5F5R>F5I8VAN:7,`16EN:V%U9@!+=7)Z92!:
M=7-A;6UE;F9A<W-U;F<`4V]L;&5N(%1A<W1E;FMO;6)I;F%T:6]N96X@9OQR
M(&1I92!M96ES=&5N($QI;FMS(&%K=&EV:65R="!W97)D96X_`%IE:6=E;@`E
M<R!A;GIE:6=E;@!!;&QE(&%N>F5I9V5N`$MO;G1A:W1E(&%N>F5I9V5N`$QI
M<W1E;B!A;GIE:6=E;@!5;G1E<G-C:&EE9&4@>G=I<V-H96X@9&5R(&%K='5E
M;&QE;B!U;F0@9&5R(&=E<F%D92!E<GIE=6=T96X@2V]N9FEG=7)A=&EO;B!A
M;GIE:6=E;BX`06YZ96EG96XL('=A;FX@9&EE(&QE='IT92!!;FUE;&1U;F<@
M97)F;VQG="!I<W0_`$5R:&%L=&5N(&1E<R!/<FEG:6YA;',@97)M]F=L:6-H
M96X`075S=^1H;&5R(&%N>F5I9V5N`%=E<FMZ975G;&5I<W1E(&;\<B!486)E
M;&QE;B!A;GIE:6=E;C\`1&%S("5S+4UE;OP@875F(&1E<B!L:6YK96X@4V5I
M=&4@86YZ96EG96X_`$1I86QO9R!F_'(@5&%B96QL96YZ96QL96YE:6=E;G-C
M:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YE:6=E;G-C:&%F
M=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YZ96EL96YE:6=E;G-C
M:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@0FEL9&5I9V5N<V-H869T96X@
M86YZ96EG96X`2&]C:&QA9&5N(&5R;?9G;&EC:&5N`%-C:&%U97(`1G+\:"!3
M8VAA=65R`%-PY'1E<B!38VAA=65R`%-C:&%U97(@:6X@9&5R(%5M9V5B=6YG
M`%9E<FML96EN97)N`%9E<FML96EN97)N(&]D97(@=F5R<V-H:65B96X@4VEE
M(&5R<W0@9&EE(&)E;F%C:&)A<G1E;B!";/9C:V4`4VEE<G)A($QE;VYE`%)E
M9VES=')I97)E;@!3:6=N871U<@!3:6=N871U<F%L9V]R:71H;75S`%-I;F=A
M<'5R`$=R]M]E`%=A<G1U;F=S87)B96ET96X@_&)E<G-P<FEN9V5N`%-L;W=A
M:V5I`%-L;W=E;FEE;@!38VAN964`4V-H;F5E<V-H875E<@!38VAN965S8VAA
M=65R`$9R_&@@4V-H;F5E<V-H875E<@!3<.1T97(@4V-H;F5E<V-H875E<@!3
M8VAN965H]FAE.B``4V-H;F5E;65N9V4@86QS(%=A<W-E<CH@`%-O;&]M;VYI
M;G-E;&X`4V]M86QI96X`3&EE9&5R("8@1V5D:6-H=&4`4V]R=&EE<G)I8VAT
M=6YG`$%U<W=A:&P@9&5R(%-O<G1I97)R96EH96YF;VQG90!5<G-P<G5N9W-A
M9')E<W-E`%%U96QL96X`4_QD869R:6MA`%/\9&5U<F]PY&ES8V@@*$E33RTX
M.#4Y+3,I`%/\9&=E;W)G:65N('5N9"!D:64@4_QD;&EC:&5N(%-A;F1W:6-H
M:6YS96QN`%/\9&QI8VAE($AE;6ES<&AE<F4`06)S=&%N9"!Z=VES8VAE;B!A
M=69E:6YA;F1E<B!F;VQG96YD96X@6F5L;&5N`$%B<W1A;F0@>G=I<V-H96X@
M26YH86QT('5N9"!286AM96X@=F]N(%IE;&QE;@!!8G-T86YD:&%L=&5R`$%B
M<W1A;F0`06)S=.1N9&4`4W!A;FEE;@!3<&%M`%-O;F1E<GIE:6-H96XM16EN
M9V%B90!'96)E;B!3:64@86XL('=O(&1I92!%<F=E8FYI<W-E(&1E<B!E<G=E
M:71E<G1E;B!3=6-H92!E<G-C:&5I;F5N('-O;&QE;BX`6F5L;&4@=&5I;&5N
M`%-P86QT92!T96EL96X`6F5I;&4@=&5I;&5N`%-P;W)T`%-R:2!,86YK80!3
M=&%N9&%R9`!3=&%R(%1R96L`4W1A<G1J86AR`$)U;F1E<W-T86%T(&]D97(@
M4')O=FEN>@!3=&%T=7,`4W!E:6-H97)F;W)M870`4W1R8=]E`$1U<F-H9V5S
M=')I8VAE;@!:96EC:&5N;&ES=&4`1&]M86EN(&%U<R!D97(@061R97-S92!E
M;G1F97)N96X`4W1I;"!;0U-370!3;P!5;G1E<G9E<GIE:6-H;FES("(E<R(@
M;FEC:'0@9V5F=6YD96XN`$)E=')E9F8`06)S8VAI8VME;@!$:64@4F5G:7-T
M<FEE<G5N9W-A;F9R86=E(&;\<B`B)7,B('=U<F1E(&%B9V5S8VAI8VMT+B!3
M:64@:_9N;F5N('-I8V@@;F]C:"!N:6-H="!A;FUE;&1E;BP@<V]L86YG92!D
M:64@06YF<F%G92!N;V-H(&YI8VAT(&)E<W3D=&EG="!W=7)D92X`5&EE9F=E
M<W1E;&QT`$5R9F]L9P`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&AI;GIU9V5F
M_&=T+@`E9"!+;VYT86MT92!E<F9O;&=R96EC:"!Z=7(@3&ES=&4@:&EN>G5G
M96;\9W0N`"5S('=U<F1E(&5R9F]L9W)E:6-H('IU("5S(&AI;GIU9V5F_&=T
M`$1A=&5N(&1E<R!"96YU='IE<G,@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G
M96SV<V-H="X`1&EE($MO;G1A:W1L:7-T92`B)7,B('=U<F1E(&5R9F]L9W)E
M:6-H(&5R<W1E;&QT+@`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&=E;/9S8VAT
M+@`E9"!+;VYT86MT92!E<F9O;&=R96EC:"!G96SV<V-H="X`(B5S(B!W=7)D
M92!E<F9O;&=R96EC:"!G96SV<V-H="X`)60@2V]N=&%K=&4@97)F;VQG<F5I
M8V@@875S(&1E<B!,:7-T92!E;G1F97)N="X`2V]N9FEG=7)A=&EO;B!E<F9O
M;&=R96EC:"!Z=7+\8VMG97-E='IT+B!396ET92!N974@;&%D96XL('5M(&1I
M92#$;F1E<G5N9V5N(&%N>G5Z96EG96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A
M=&EO;B!E<F9O;&=R96EC:"!G97-P96EC:&5R="X`0F%C:W5P(&1E<B!+;VYF
M:6=U<F%T:6]N("5S(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+@`B)7,B('=U
M<F1E(&5R9F]L9W)E:6-H(&%K='5A;&ES:65R=``E<R!W=7)D92!E<F9O;&=R
M96EC:"!G97-P96EC:&5R=`!3=61A;@!:=7-A;6UE;F9A<W-U;F<`4V]N;F5N
M875F9V%N9P!3;VYN96YU;G1E<F=A;F<`4V]N;FEG`%-O;FYE;F%U9F=A;F<`
M4V]N;F5N875F+W5N=&5R9V%N9P!3;VYN96YA=69G86YG.B``4V]N;F5N=6YT
M97)G86YG`%-O;FYE;G5N=&5R9V%N9SH@`$AO8VAG97-T96QL=`!3=7!P;W)T
M`%-U<FEN86T`3F%C:&YA;64`4W9A;&)A<F0@=6YD($IA;B!-87EE;@!3=V%S
M:6QA;F0`4V-H=V5D96X`4V-H=V5I>@!3>6YC:')O;FEZ871I;VYS;&]G(&=E
M;/9S8VAT`%-Y;F--3`!&;W)M871F96AL97(@:6X@4W5C:&)E9W)I9F9E;@!!
M<F%B:7-C:&4@4F5P=6)L:6L@4WER:65N`$=E=VET=&5R`$=E=VET=&5R('5N
M9"!7:6YD:6<`1V5W:71T97(`1G+\:"!'97=I='1E<@!44U8`5%-6+41A=&5I
M`%1A8F=E=')E;FYT92!797)T90!486)E;&QE;F5I9V5N<V-H869T96X`5&%B
M96QL90!486)E;&QE;F5I9V5N<V-H869T96X`5&%I=V%N`%1A:7=A;BP@8VAI
M;F5S:7-C:&4@4')O=FEN>@!4861S8VAI:VES=&%N`%9E<F5I;FEG=&4@4F5P
M=6)L:6L@5&%N<V%N:6$`6FEE;#H`075F9V%B96X`5&5L969O;FYU;6UE<@!4
M96UP97)A='5R(&1E<B!L971Z=&5N(%-T=6YD93H@`%1E;7!E<F%T=7(`5&5M
M<&5R871U<CH@`%1E;7!E<F%T=7(\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F
M9&5G.R5S`%9O<FQA9V4@(B5S(B!N:6-H="!G969U;F1E;BX`5F]R;&%G96YV
M97)W86QT=6YG`%1E>'0`3G5R(%1E>'0`075S<FEC:'1U;F<`5&5X="!/8F5N
M`$1O`%1H86ELY&YD:7-C:"`H5$E3+38R,"D`5&AA:6QA;F0`1&EE($944"U%
M>'1E;G-I;VX@:7-T(&YI8VAT('9E<F;\9V)A<BX`1&EE($-H<F]N:6L@<W1E
M:'0@;FEC:'0@>G5R(%9E<F;\9W5N9RX`1&EE($AO<F1E+TMO;&%B($EN=&5G
M<F%T:6]N<V9U;FMT:6]N96X@=6YT97)S=/QT>F5N("(E<R(@;FEC:'0`1&EE
M($E-4U`M3&]G9&%T96D@:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E;BX`
M1&EE($UA:6YT96YA;F-E.CH@2VQA<W-E(&MO;FYT92!N:6-H="!G96QA9&5N
M('=E<F1E;@!$87,@16EN<W1E;&QU;F=E;BU&96YS=&5R(&ES="!G97-C:&QO
M<W-E;B!W;W)D96XN($%B8G)U8V@N`$1A<R!61E,M0F%C:V5N9"!M=7-S(&MO
M;F9I9W5R:65R="!S96EN+"!U;2!D87,@2&]C:&QA9&5N('9O;B!$871E:65N
M('IU(&5R;&%U8F5N+@!$87,@061R97-S8G5C:"`B)7,B(&5X:7-T:65R="!N
M:6-H="X`1&%S($%D<F5S<V)U8V@@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!E
M<G-T96QL="X`1&%S($%D<F5S<V)U8V@@(B5S(B!W=7)D92!E<F9O;&=R96EC
M:"!G96SV<V-H="X`1&%S($%D<F5S<V)U8V@@(B5S(B!W=7)D92!E<F9O;&=R
M96EC:"!A:W1U86QI<VEE<G0N`$1A<R!!9')E<W-B=6-H(&MO;FYT92!N:6-H
M="!G96QE97)T('=E<F1E;CH@)7,`1&5R($%D;6EN:7-T<F%T;W(@;75S<R!E
M:6X@<&5R;6%N96YT97,@4F5C:'1E+4)A8VME;F0@96EN<FEC:'1E;BP@=V5N
M;B!3:64@9&EE(%)E8VAT979E<G=A;'1U;F<@;G5T>F5N(&WV8VAT96XN`$YU
M<B!U;G1E;@!$:64@240M3G5M;65R(&1E<R!+;VYT86MT<R!W=7)D92!N:6-H
M="!A;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92!I;B!D97(@1&%T96YB
M86YK(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`1&5R($MO;G1A:W0@=W5R9&4@
M97)F;VQG<F5I8V@@26AR96T@061R97-S8G5C:"!H:6YZ=6=E9OQG="X`1&5R
M(&%U<V=E=^1H;'1E($MO;G1A:W0@97AI<W1I97)T(&YI8VAT+@!$97(@4$=0
M+5-I9VYA='5R8FQO8VL@=VER9"!B96[V=&EG="P@=6T@9&EE('5N=&5R>F5I
M8VAN971E($YA8VAR:6-H="!Z=2#\8F5R<'+\9F5N+@!$:64@240M3G5M;65R
M(&1E<B!697)T96EL97)L:7-T92!W=7)D92!N:6-H="!A;F=E8F5N+"!W87(@
M;&5E<B!O9&5R(&MO;FYT92!I;B!D97(@1&%T96YB86YK(&YI8VAT(&=E9G5N
M9&5N('=E<F1E;BX`1&EE(%9E<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N
M9V5G96)E;BX`1&EE(%9E<G-C:&S\<W-E;'5N9W-F=6YK=&EO;F5N(&)E;O9T
M:6=E;B!E:6YE('-I8VAE<F4@4V5R=F5R=F5R8FEN9'5N9RX`1&EE($1A=&5I
M("(E<R(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N`$1I92!$871E:2`E
M<R!S;VQL=&4@96EN96X@)7,@16EN=')A9R!E;G1H86QT96XN`$1I92!$871E
M:2`E<R!S;VQL=&4@96EN:6=E("5S($5I;G1RY&=E(&5N=&AA;'1E;BX`1&EE
M($1A=&5I(&MA;FX@;FEC:'0@875F('-I8V@@<V5L8G-T(&MO<&EE<G0@=V5R
M9&5N+@!$:64@1&%T96D@96YT:&EE;'0@:V5I;F4@1&%T96XN`$AI97(@<VEN
M9"!D:64@2V]P9F5I;G1RY&=E(&;\<B!D:65S92!M97-S86=E+W)F8S@R,B!.
M86-H<FEC:'0N`$1E<B!6;VQL8FEL9&UO9'5S('9E<G5R<V%C:'0@875F($=R
M=6YD('9O;B!&96AL97)N(&EM($EN=&5R;F5T($5X<&QO<F5R(&)E:V%N;G1E
M<FUAWV5N(%!R;V)L96UE(&UI="!D:65S96T@0G)O=W-E<BP@9&EE('=I<B!N
M:6-H="!U;6=E:&5N(&OV;FYE;BX@56YT97(@56US=.1N9&5N(&5R:&%L=&5N
M(%-I92!E:6YE(&9E:&QE<FAA9G1E($%N>F5I9V4L(&9E:&QE;B!%9&ET;W)F
M=6YK=&EO;F5N+"!O9&5R(&1E<B!"<F]W<V5R('-T_')Z="!A8BX@075F(&5I
M;F5M(%=I;F1O=R`Y>"!3>7-T96T@=V5R9&5N(%-I92!V97)M=71L:6-H(&5I
M;F4@)T%L;&=E;65I;F4@4V-H=71Z=F5R;&5T>G5N9R<@97)H86QT96X@=6YD
M(&W\<W-E;B!D96X@4F5C:&YE<B!N974@<W1A<G1E;BY<;EQN4VEE('=U<F1E
M;B!G97=A<FYT+B!":71T92!D<OQC:V5N(%-I92!A=68@3TLL('=E;FX@4VEE
M(&YO8V@@:6UM97(@9&5N(%9O;&QB:6QD;6]D=7,@=F5R=V5N9&5N(&WV8VAT
M96XN`$1I92!)9&5N=&ETY'0@(B5S(B!W=7)D92!G96SV<V-H="X`1&5R($EM
M<&]R="!K86YN('1R;W1Z(&1E<B!787)N=6YG96X@86)G97-C:&QO<W-E;B!W
M97)D96XN`$YU<B!L:6YK<P!$97(@3W)T(&1E<R!';G501RU0<F]G<F%M;7,@
M;75S<R!D97(@0W)Y<'1?<&=P.CH@2VQA<W-E(/QB97)G96)E;B!W97)D96XN
M`$1I92!.86-H<FEC:'0@;6ET(&1E;2!"971R969F("(E,R1S(BP@9&EE(&%M
M("4Q)',@86X@)3(D<R!G97-C:&EC:W0@=W5R9&4L(&ES="!A;F=E>F5I9W0@
M=V]R9&5N+@I$87,@:&5IWW0@;FEC:'0L(&1A<W,@9&EE($YA8VAR:6-H="!A
M=6-H(&=E;&5S96X@;V1E<B!V97)S=&%N9&5N('=U<F1E+@!.86UE(&;\<B!D
M96X@3&EN:R!Z=7(@3F%C:')I8VAT96YE<G-T96QL=6YG`$1I92!!;GIA:&P@
M9&5R($9E;&1E<B!M=7-S(&%L<R!:86AL(&%N9V5G96)E;B!W97)D96XN`$1A
M<R!/<&5N4U-,+4UO9'5L('=I<F0@9OQR(&1I92!(;W)D95]#<GEP=%]S;6EM
M93HZ($ML87-S92!B96[V=&EG="X`1&EE($)E;G5T>F5R96EN<W1E;&QU;F<@
M(B5S(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+"!W96EL(&EH
M<F4@1&%T96X@9&EE(&UA>&EM86P@97)L875B=&4@1W+VWV4@_&)E<G-C:')E
M:71E;@!$87,@4')O9W)A;6T@9OQR(&1I92!!;GIE:6=E(&1I97-E<R!$871E
M:71Y<',@*"5S*2!W=7)D92!N:6-H="!G969U;F1E;BX`1&%S($%N9OQH<G5N
M9W-Z96EC:&5N(&UU<W,@86QS(&5I;GIE;&YE<R!:96EC:&5N(&%N9V5G96)E
M;B!W97)D96XN`$YU<B!L:6YK<R!U;F0@<F5C:'1S`$YU<B!R96-H=',`1&%S
M(%1R96YN>F5I8VAE;B!M=7-S(&%L<R!E:6YZ96QN97,@6F5I8VAE;B!A;F=E
M9V5B96X@=V5R9&5N+@!$97(@4V5R=F5R("(E<R(@=W5R9&4@96YT9F5R;G0N
M`$1E<B!397)V97(@(B5S(B!W=7)D92!G97-P96EC:&5R="X`1&EE(%)E9VES
M=')I97)U;F=S86YF<F%G92!V;VX@)7,@=W5R9&4@96YT9F5R;G0N`$1I92!A
M;F=E9V5B96YE(%IE:6QE("@E9"D@97AI<W1I97)T(&YI8VAT+@!$:64@=&5M
M<&]RY')E($1A=&5I("(E<R(@97AI<W1I97)T(&YI8VAT+@!$97(@5&5X="P@
M9&5N(%-I92!A;F=E9V5B96X@:&%B96XL(&5N='-P<FEC:'0@;FEC:'0@9&5M
M(%1E>'0@875F(&1E;2!":6QD<V-H:7)M+@!.=7(@;V)E;B!U;F0@=6YT96X`
M3G5R(&]B96X`1&EE(&AO8VAG96QA9&5N96X@1&%T96X@<VEN9"!N86-H(&1E
M;2!L971Z=&5N(%-C:')I='0@=F5R;&]R96X@9V5G86YG96XN`$1I92!H;V-H
M9V5L861E;F4@1&%T96D@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E
M;BX`1&5R('=E871H97(N8V]M($)L;V-K(&ES="!N:6-H="!V97)F_&=B87(N
M`%1H96UE;BU697)Z96EC:&YI<R`B)7,B(&YI8VAT(&=E9G5N9&5N+@!%<R!G
M:6)T(&ME:6YE($%D<F5S<V+\8VAE<BP@9&EE(&%U9F=E;&ES=&5T('=E<F1E
M;B!K]FYN96XN`$5S('-I;F0@:V5I;F4@16EN<W1E;&QU;F=E;B!V97)F_&=B
M87(N`$5S(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@3F%C:')I8VAT96YT96EL
M92X`17,@9VEB="!K96EN92!B97-C:')E:6)B87)E;B!!9')E<W-B_&-H97(N
M($ME:6YE<R!D97(@=F5R9OQG8F%R96X@061R97-S8OQC:&5R(&5R;&%U8G0@
M26AN96XL(&YE=64@061R97-S96X@:&EN>G5Z=6;\9V5N+B!796YN(%-I92!M
M96EN96XL(&1A<W,@97,@<VEC:"!D86)E:2!U;2!E:6YE;B!&96AL97(@:&%N
M9&5L="P@=V5N9&5N(%-I92!S:6-H(&)I='1E(&%N($EH<F5N(%-Y<W1E;2U!
M9&UI;FES=')A=&]R+@!$:65S97,@1F5L9"!E;G1HY&QT('IU('9I96QE(%IE
M:6-H96XN(%-I92!H86)E;B`E<R!:96EC:&5N(&%N9V5G96)E;CL@4VEE(&W\
M<W-E;B!W96YI9V5R(&%L<R`E<R!A;F=E8F5N+@!"96EM($AI;GIU9OQG96X@
M=F]N("(E<R(@>G5M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T
M96XZ("5S`$)E:6T@3/9S8VAE;B!D97(@1&%T96X@=F]N($)E;G5T>F5R("(E
M<R(@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B``0F5I;2!,]G-C:&5N
M('9O;B`B)7,B(&%U<R!D96T@4WES=&5M(&ES="!E:6X@4')O8FQE;2!A=69G
M971R971E;CH@`$)E:6T@06MT=6%L:7-I97)E;B!V;VX@(B5S(B!I<W0@96EN
M(%!R;V)L96T@875F9V5T<F5T96XZ("5S`$)E:6T@2&]C:&QA9&5N(&1E<B!$
M871E:2!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@)7,@=W5R9&4@;FEC
M:'0@:&]C:&=E;&%D96XN`$)E:6T@2&]C:&QA9&5N(&1E<B!$871E:2!I<W0@
M96EN($9E:&QE<B!A=69G971R971E;BX@)7,@=V%R(&=R]M]E<B!A;',@9&EE
M(&UA>&EM86P@97)L875B=&4@1W+VWV4@*"5D($)Y=&5S*2X`0F5I;2!(;V-H
M;&%D96X@9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E
M<R!W=7)D92!N=7(@=&5I;'=E:7-E(&AO8VAG96QA9&5N+@!"96EM($AI;GIU
M9OQG96X@9&EE<V5S($MO;G1A:W1S(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E
M=&5N+B!":71T92!W96YD96X@4VEE('-I8V@@86X@26AR96X@4WES=&5M861M
M:6YI<W1R871O<B!F_'(@=V5I=&5R92!(:6QF92X`0F5I;2!%<G-T96QL96X@
M96EN97(@;F5U96X@3&ES=&4@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN
M`$)E:6T@17)S=&5L;&5N(&1E<R!!9')E<W-B=6-H<R!I<W0@96EN($9E:&QE
M<B!A=69G971R971E;CH@)7,`0F5I;2!,]G-C:&5N('9O;B`B)7,B(&%U<R!D
M96T@061R97-S8G5C:"!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`0F5I
M;2!,]G-C:&5N(&1E<R!+;VYT86MT<R!I<W0@96EN($9E:&QE<B!A=69G971R
M971E;CH@)7,`0F5I;2!!;GIE:6=E;B!D97(@3&ES=&4@:7-T(&5I;B!&96AL
M97(@875F9V5T<F5T96X`0F5I;2!!;GIE:6=E;B!D:65S97,@3F%C:')I8VAT
M96YT96EL<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`0F5I;2!);7!O
M<G1I97)E;B!D97(@2V]N=&%K=&1A=&5N(&ES="!E:6X@1F5H;&5R(&%U9F=E
M=')E=&5N+@!"96EM($EM<&]R=&EE<F5N(&1E<B!$871E;B!I<W0@96EN($9E
M:&QE<B!A=69G971R971E;CH@)7,`0F5I;2!);7!O<G1I97)E;B!D97(@:4-A
M;&5N9&%R($1A=&5N(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+@!$87,@
M2V]N9FEG=7)A=&EO;G,M1F]R;75L87(@96YT:&EE;'0@96EN96X@1F5H;&5R
M+B!6:65L;&5I8VAT(&AA8F5N(%-I92!E:6X@4&9L:6-H=&9E;&0@;&5E<B!G
M96QA<W-E;BX`0F5I;2!!=7-F_&AR96X@9&5R(&%N9V5G96)E;F5N($%D<F5S
M<V)U8VAF=6YK=&EO;B!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET
M=&4@=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`$)E:6T@
M3/9S8VAE;B!D97,@061R97-S8G5C:',@:7-T(&5I;B!&96AL97(@875F9V5T
M<F5T96XZ("5S`$)E:2!D97(@06MT=6%L:7-I97)U;F<@9&5R($MO;G1A:W1D
M971A:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92!V97)S
M=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`0F5I(&1E<B!!:W1U
M86QI<VEE<G5N9R!D97(@5F5R=&5I;&5R;&ES=&4@:7-T(&5I;B!&96AL97(@
M875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO
M8V@@96EN;6%L+@!"96EM($%K='5A;&ES:65R96X@9&5S($%D<F5S<V)U8VAS
M(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N.B`E<P!"96EM($%K='5A;&ES
M:65R96X@9&EE<V5S($5I;G1R86=S(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E
M=&5N.B`E<P!%<R!K;VYN=&5N(&ME:6YE($%D<F5S<V5N('IU;2!%>'!O<G1I
M97)E;B!G969U;F1E;B!W97)D96XN`$1I97-E($%D<F5S<V+\8VAE<B!W97)D
M96X@:6X@9&5R(&9O;&=E;F1E;B!296EH96YF;VQG92!A;F=E>F5I9W0Z`$1I
M97-E(%-P86QT96X@=V5R9&5N(&EN(&1E<B!F;VQG96YD96X@4F5I:&5N9F]L
M9V4@86YG97IE:6=T.@!$:65S97(@24U!4"U397)V97(@=6YT97)S=/QT>G0@
M:V5I;F4@9V5M96EN<V%M96X@3W)D;F5R+@!$:65S('-C:&5I;G0@:V5I;B!G
M_&QT:6=E<R!205(M07)C:&EV('IU('-E:6XN`$1I97,@<V-H96EN="!K96EN
M(&?\;'1I9V5S(%I)4"U!<F-H:78@>G4@<V5I;BX`1&EE<R!S8VAE:6YT(&ME
M:6YE(&?\;'1I9V4@2V%R=&5N;G5M;65R('IU('-E:6XN`$1I97-E<B!4<F5I
M8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D
M=7)C:"!D96X@0VQI8VMA=&5L;"U'871E=V%Y("AH='1P.B\O8VQI8VMA=&5L
M;"YC;VTI(&UI="!(:6QF92!D97(@2%144"U!4$DN`$1I97-E<B!4<F5I8F5R
M(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C
M:"!D96X@5TE.+4=A=&5W87D@*&AT='`Z+R]W:6YP;&,N8V]M*2!M:70@2&EL
M9F4@9&5R($A45%`M05!)+@!$:65S97(@5')E:6)E<B!E<FQA=6)T(&1A<R!6
M97)S8VAI8VME;B!V;VX@3F%C:')I8VAT96X@9'5R8V@@9&5N('-M<S)M86EL
M+4=A=&5W87D@*&AT='`Z+R]S;7,R;6%I;"YC;VTI(&UI="!(:6QF92!D97(@
M2%144"U!4$DN`$1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC
M:V5N('9O;B!.86-H<FEC:'1E;B!P97(@4TU44"!D=7)C:"!D96X@5F]D869O
M;F4M271A;&EE;BU'871E=V%Y(&%U<W-C:&QI9=]L:6-H(&%N(%9O9&%F;VYE
M+4YU;6UE<FXN($1A9OQR('=I<F0@96EN($5M86EL:V]N=&\@8F5I(%9O9&%F
M;VYE($ET86QI96X@*&AT='`Z+R]W=W<N,3DP+FET*2!B96[V=&EG="X`1&EE
M<V5S($9E;&0@:7-T(&YO='=E;F1I9RX`1&EE<V5S($9E;&0@9&%R9B!N=7(@
M9V%N>F4@6F%H;&5N(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@9&%R9B!N=7(@
M6F%H;&5N('5N9"!E:6YE;B!0=6YK="!E;G1H86QT96XN`$1I97-E<R!&96QD
M(&1A<F8@;G5R($]K=&%L>F%H;&5N(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@
M;75S<R!E:6YE(&MO;6UA+2!O9&5R(&QE97)Z96EC:&5N9V5T<F5N;G1E($QI
M<W1E('9O;B!G86YZ96X@6F%H;&5N(&5N=&AA;'1E;@!$:65S97,@1F5L9"!M
M=7-S(&5I;F4@9_QL=&EG92!:86AL(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@
M;75S<R!E:6YE;B!&87)B=V5R="!I;2!H97AA9&5Z:6UA;&5N(%)'0BU&;W)M
M870@96YT:&%L=&5N+"!Z+B!"+B`G(S$R,S1A9B<N`$1I97-E<R!$871E:69O
M<FUA="!W:7)D(&YI8VAT('5N=&5R<W3\='IT+@!$:65S97,@1F]R;75L87(@
M=W5R9&4@8F5R96ET<R!V97)A<F)E:71E="X`1&EE<R!I<W0@)7,N`$1I92!I
M<W0@96EN($MO;&%B+4=R;W5P=V%R92U/8FIE:W0N(%5M(&1I97-E<R!/8FIE
M:W0@86YZ=7IE:6=E;BP@8F5N]G1I9V5N(%-I92!E:6X@16UA:6QP<F]G<F%M
M;2P@9&%S(&1A<R!+;VQA8BU'<F]U<'=A<F4M1F]R;6%T('5N=&5R<W3\='IT
M+B!%:6YE($QI<W1E('-O;&-H97(@4')O9W)A;6UE(&9I;F1E;B!3:64@=6YT
M97(@)7,`1&EE<V4@3F%C:')I8VAT('=U<F1E(&EN(&5I;F5M(%IE:6-H96YS
M871Z("@E<RD@97)S=&5L;'0L(&1E<B!N:6-H="!):')E;2!E:6=E;F5N(&5N
M='-P<FEC:'0N`$1I97-E(%IA:&P@;75S<R`Q(&]D97(@9W+VWV5R('-E:6XN
M`$1I97-E(%!E<G-O;B!H870@8F5R96ET<R!E:6YE;B`E<RU%:6YT<F%G(&EN
M($EH<F5M($%D<F5S<V)U8V@`1&EE<V5R(%-E<G9E<B!K86YN(%I)4"T@=6YD
M($=:25`M1&%T96EN(&YI8VAT(&5N='!A8VME;BX`1&EE<V5S(%-Y<W1E;2!I
M<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0N`$1I97-E<B!797)T(&UU<W,@96EN
M92!:86AL('-E:6XN`$1I97,@=VER9"!A;',@4W1A;F1A<F1A9')E<W-B=6-H
M(&;\<B!D87,@2&EN>G5F_&=E;B!O9&5R($EM<&]R=&EE<F5N('9O;B!+;VYT
M86MT96X@8F5N=71Z="X`1&EE<V5S($9E;G-T97(@;75S<R!V;VX@96EN96T@
M16EN<W1E;&QU;F=E;BU&96YS=&5R(&=E]F9F;F5T('=E<F1E;@!$;VYN97(`
M5&EC:V5T<P!:96ET`%IE:71E<F9A<W-U;F<`6F5I=&9O<FUA=`!:96ET875S
M=V%H;`!4:6UO<BU,97-T90!0;W-I=&EO;@!4:71E;"`H5&]O;'1I<"DZ`$%N
M`$AA;'1E;B!3:64@8F5I;2!+;&EC:V5N(%-T<F<@8GIW+B`H4$,I($-O;6UA
M;F0@*$UA8RD@9V5D<OQC:W0L('5M(&UE:')E<F4@16EN='+D9V4@875S>G5W
MY&AL96XN`$AE=71E`%IU($A434PM475E;&QC;V1E('5M<V-H86QT96X`5&]G
M;P!4;VME;&%U`$UO<F=E;@!4;VYG80!:=2!V:65L92!U;F?\;'1I9V4@06YM
M96QD979E<G-U8VAE(&EN(&1E;B!L971Z=&5N($UI;G5T96XN`$]B96X`Q'7?
M97)S=&5R(%)A:&UE;B`H7W1O<"D`W&)E<G-E='IU;F=E;@!4<FEN:61A9"!U
M;F0@5&]B86=O`%=A:'(@;V1E<B!F86QS8V@`1&D`5'5N97-I96X`5/QR:V5I
M`%3\<FMI<V-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,M('5N
M9"!#86EC;W-I;G-E;&X`5'5V86QU`$EH<F4@075S=V%H;#H@`%56+4EN9&5X
M.B``2&]M97!A9V4`55),($EH<F5S(%-K<FEP=',@9OQR(&1E;B!697)S86YD
M<W1A='5S8F5R:6-H=`!!9')E<W-E.@!59V%N9&$`56MR86EN90!!=68@9&%S
M(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@>G5G96=R:69F96X@=V5R
M9&5N+@!$:64@>G5SY'1Z;&EC:&5N($)E;G5T>F5R:6YF;W)M871I;VYE;B!K
M;VYN=&5N(&)E:2!D97(@4F5G:7-T<FEE<G5N9R!N:6-H="!H:6YZ=6;\9W0@
M=V5R9&5N+@!$:64@6G5G<FEF9G-R96-H=&4@9OQR(&1I92!61E,M1&%T96D@
M(B5S(B!K;VYN=&5N(&YI8VAT(&=EY&YD97)T('=E<F1E;BX`1&EE(%IU9W)I
M9F9S<F5C:'1E(&;\<B!D:64@5D93+41A=&5I("5S+R5S(&MO;FYT96X@;FEC
M:'0@9V7D;F1E<G0@=V5R9&5N+@!%<R!K86YN(&YI8VAT(&EN(%9E<GIE:6-H
M;FES("5S(&=E=V5C:'-E;'0@=V5R9&5N+@!$:64@1W+VWV4@=F]N("(E<R(@
M:V]N;G1E(&YI8VAT(&)E<W1I;6UT('=E<F1E;BX`1&EE($=R]M]E('9O;B`B
M)7,O)7,B(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN`%9E<F)I;F1U
M;F<@>G5M(%-13"!397)V97(@:V%N;B!N:6-H="!H97)G97-T96QL="!W97)D
M96XN`%-33"U697)B:6YD=6YG(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W
M97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&MO<&EE<G0@=V5R
M9&5N+@!$87,@5D93+59E<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&%N
M9V5L96=T('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC
M:'0@86YG96QE9W0@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H
M="!A;F=E;&5G="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@(B5S(B!K
M;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@!,965R92!61E,M1&%T96D@
M:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`1&%S(&=E;65I;G-A;64@
M061R97-S8G5C:"!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N+"!D97(@
M475E;&QT>7`@9F5H;'0N`$1I92!$871E;B!K;VYN=&5N(&YI8VAT(&1E:V]M
M<')I;6EE<G0@=V5R9&5N+@`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W
M97)D96XL(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC:'0@;&5E<BX`(B5S(B!K
M86YN(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N`"5S(&MO;FYT92!N:6-H
M="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC:'0@
M;&5E<@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!R96MU<G-I
M=B!G96SV<V-H="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E
M(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R!K
M;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N.B`E<RX`1&EE(%9&4RU$871E
M:2`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1I92!61E,M
M1&%T96D@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`1&%S(%9&4RU6
M97)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN
M`$1A<R!61E,@:V]N;G1E(&YI8VAT(')E:W5R<VEV(&=E;/9S8VAT('=E<F1E
M;CH@)7,N`$1A<R!A:W1U96QL92!697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@
M8F5S=&EM;70@=V5R9&5N+@!$:64@6F5R=&EF:6MA=&1E=&%I;',@:V]N;G1E
M;B!N:6-H="!A=7-G96QE<V5N('=E<F1E;@!$97(@)7,M5')E:6)E<B!K;VYN
M=&4@;FEC:'0@9V5L861E;B!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E
M(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N+@!$:64@5D93+41A=&5I("(E<R(@
M:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K
M;VYN=&4@;FEC:'0@>G5M($)E<V-H<F5I8F5N(&=E]F9F;F5T('=E<F1E;BX`
M1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!$
M87,@07)C:&EV(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN`$1I92!6
M1E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N("AF:6QE<VEZ
M92@I(&9E:&QG97-C:&QA9V5N*2X`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V5L97-E;B!W97)D96X@*&=E=$9I;&53:7IE*"D@9F5H;&=E<V-H;&%G
M96XI+@!$:64@1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N.B``
M1&%S('9F<W)O;W0M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@
M=V5R9&5N+@`E<R!K;VYN=&4@;FEC:'0@;F%C:"`E<R!U;6)E;F%N;G0@=V5R
M9&5N.B!$87,@6FEE;'9E<GIE:6-H;FES(&5X:7-T:65R="!B97)E:71S`$1A
M<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W97)D
M96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('5M8F5N86YN
M="!W97)D96XZ("5S+@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT
M('5M8F5N86YN="!W97)D96XN`$1I92!61E,M1&%T96D@)7,O)7,@:V]N;G1E
M(&YI8VAT('5M8F5N86YN="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E
M(&YI8VAT('5M8F5N86YN="!W97)D96XN`")M:VES;V9S(B!K;VYN=&4@;FEC
M:'0@875S9V5F_&AR="!W97)D96XN`$1I97-E<R!7;W)D+41O:W5M96YT(&SD
M<W-T('-I8V@@;FEC:'0@86YZ96EG96X`1&EE(%9&4RU$871E:2`B)7,B(&MO
M;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN`$1I92!61E,M1&%T96D@
M:V]N;G1E(&YI8VAT(&=E<V-H<FEE8F5N('=E<F1E;B`H8V]P>2@I(&9E:&QG
M97-C:&QA9V5N*2X`1&EE(%9&4RU$871E;B!K;VYN=&5N(&YI8VAT(&=E<V-H
M<FEE8F5N('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V5S
M8VAR:65B96X@=V5R9&5N+"!D87,@4W!E:6-H97)P;&%T>BU+;VYT:6YG96YT
M('?\<F1E(/QB97)S8VAR:71T96XN`%5N=&5R<W1R:6-H96X`Q&YD97)U;F=E
M;B!R_&-K9^1N9VEG(&UA8VAE;@!-86-H="!D:64@;&5T>G1E($%K=&EO;B!R
M_&-K9^1N9VEG`%5N9_QL=&EG92!2_&-K;65L9'5N9R!V;VT@4V5R=F5R(&)E
M:6T@2&5R<W1E;&QE;B!D97(@5F5R8FEN9'5N9SH@`%5N97)W87)T971E($%N
M='=O<G0@9&5S(%-E<G9E<G,@875F.B``3FEC:'0@>G5G96]R9&YE=`!5;FEC
M;V1E("A55$8M."D`5F5R96EN:6=T92!!<F%B:7-C:&4@16UI<F%T90!697)E
M:6YI9W1E<R!+]FYI9W)E:6-H`%9E<F5I;FEG=&4@4W1A871E;@!+;&5I;F5R
M92!!;65R:6MA;FES8VAE(-QB97)S965I;G-E;&X`16EN:&5I=&5N`%5N8F5K
M86YN=`!5;F)E:V%N;G1E(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N
M8F5K86YN=&4@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`17,@=W5R
M9&4@96EN('5N8F5K86YN=&5R($]R="!A;F=E9V5B96XN`%5N8F5K86YN=&5R
M($)E;G5T>F5R;F%M92!O9&5R(%!A<W-W;W)T+@!,:6YK('9O;2!A:W1U96QL
M96X@16QE;65N="!E;G1F97)N96X`56YB96YA;FYT`$%U<R!3:6-H97)H96ET
M<V=R_&YD96X@9/QR9F5N('5N875T;W)I<VEE<G1E(%-K<FEP=&4@;FEC:'0@
M875S8VAN96ED96XL(&MO<&EE<F5N('5N9"!E:6YF_&=E;BX@2VQI8VME;B!3
M:64@875F($]++"!U;2!E:6YE;B!(:6YW96ES(&%U9B!M;WII;&QA+F]R9R!A
M;F=E>F5I9W0@>G4@8F5K;VUM96XL(&1E<B!B97-C:')E:6)T+"!W:64@4VEE
M(&5I;F5M(%-K<FEP="!D96X@6G5G<FEF9B!A=68@9&EE(%IW:7-C:&5N86)L
M86=E(&5R;&%U8F5N(&OV;FYE;BX`1F%R8F4@>G5R_&-K<V5T>F5N`$YI8VAT
M('5N=&5R<W3\='IT97(@26YH86QT<W1Y<#H@)7,`17)W96ET97)U;F<@;FEC
M:'0@=6YT97)S=/QT>G0`06MT=6%L:7-I97)U;F<`)7,@86MT=6%L:7-I97)E
M;@!"96YU='IE<B!A:W1U86QI<VEE<F5N`"(E<R(@=W5R9&4@86MT=6%L:7-I
M97)T+@!!:W1U86QI<VEE<G5N9W-S:W)I<'0@9V5L]G-C:'0N`$AO8VAL861E
M;@!$:64@2V]N9FEG=7)A=&EO;G-D871E:65N(&%L;&5R($%N=V5N9'5N9V5N
M('=U<F1E;B!A=68@9&5N(%-E<G9E<B!H;V-H9V5L861E;BX`1W(N(&QA=&5I
M;FES8VAE($)U8VAS=&%B96X`1W(N('+V;6ES8VAE(%IA:&QE;@!5<G5G=6%Y
M`$%K='5E;&QE(&)E;G5T>F5N.B`E<P!34TP@8F5N=71Z96X`0FET=&4@875S
M9OQL;&5N+"!W96YN(%-I92!E:6YE;B!A;F1E<F5N($)E;G5T>F5R;F%M96XO
M4&%S<W=O<G0@9OQR(&1E;B!)35-0+5-E<G9E<B!H86)E;BX`0F5N=71Z97(`
M0F5N=71Z97(@)7,@:7-T(&;\<B`E<R!N:6-H="!A=71O<FES:65R="X`0F5N
M=71Z97)V97)W86QT=6YG`$)E;G5T>F5R96EN<W1E;&QU;F=E;@!"96YU='IE
M<G)E9VES=')I97)U;F<`1&EE($)E;G5T>F5R<F5G:7-T<FEE<G5N9R!W=7)D
M92!A=68@9&EE<V5M(%-Y<W1E;2!D96%K=&EV:65R="X`0F5N=71Z97)K;VYT
M;R!N:6-H="!G969U;F1E;@!"96YU='IE<FYA;64`1&5R($)E;G5T>F5R;F%M
M92`B)7,B(&5X:7-T:65R="!B97)E:71S+@!"96YU='IE<FYA;64Z`$)E;G5T
M>F5R;F%M93H@`$)E;G5T>F5R(&1E<R!3>7-T96US.@!5<V)E:VES=&%N`$1A
M<R!61E,M5F5R>F5I8VAN:7,@97AI<W1I97)T(&YI8VAT+@!!8G=E<V5N:&5I
M=`!087-S96YD92!G969U;F1E;F4@3W)T93H@`$?\;'1I9VME:70`5V5R="!I
M;B!-:6YU=&5N('9O;B!J971Z="!A;BX`1&5R(%=E<G0@:7-T(/QB97(@9&5R
M(&UA>&EM86QE;B!,Y&YG92!V;VX@)7,N`%=E<G1E`%=E<G1E+"!A=7,@9&5N
M96X@875S9V5WY&AL="!W97)D96X@:V%N;@!686YU871U`$1R96AE;F0`5F5N
M97IU96QA`-QB97)P<OQF=6YG(&9E:&QG97-C:&QA9V5N("T@9&EE<V4@3F%C
M:')I8VAT(&OV;FYT92!M86YI<'5L:65R="!W;W)D96X@<V5I;BX`5F5R:7-I
M9VX@5F5R>F5I8VAN:7,`5F5R<VEO;@!697)S:6]N<VMO;G1R;VQL90!!=7-R
M:6-H='5N9P!697)T:6MA;&5R($EN;F5N86)S=&%N9`!697)T:6MA;#H`4V5H
M<B!(;V-H`%9I971N86T`5FEE=&YA;65S:7-C:"`H5DE30TE)*0`B)7,B(&%N
M>F5I9V5N`"5S(&%N>F5I9V5N`$MO;G1A:W0@86YZ96EG96X`16EN92!E>'1E
M<FYE(%=E8G-E:71E(&%N>F5I9V5N`$%N>F5I9V5N(&%L<R`E<P!3=&%N9&%R
M9&%N<VEC:'0Z`$)R:71I<V-H92!*=6YG9F5R;FEN<V5L;@!!;65R:6MA;FES
M8VAE($IU;F=F97)N:6YS96QN`%-I8VAT`%-I8VAT.B``5F]D869O;F4@271A
M;&EE;B!P97(@4TU44`!705).54Y'`%=!4DY53D<A(2$@3-930TA%3B!3244@
M1$%3(%-+4DE05"!-04Y514Q,($%54R`E<RX`5TE.(/QB97(@2%144`!786QL
M:7,@=6YD($9U='5N80!787)N=6YG`$UI`%=E='1E<G9O<FAE<G-A9V4`5V5T
M=&5R9&%T96X@=F]N`%=E871H97(N8V]M`%=E8@!796)S:71E`%=E8G-I=&4M
M55),`%?V8VAE;G1L:6-H`%=I;&QK;VUM96X`5VEL;&MO;6UE;B!B96D@)7,`
M5VEL;&MO;6UE;BP@)7,`5V5S=&5U<F]PY&ES8V@@*$E33RTX.#4Y+3$I`%=E
M<W1E=7)O<.1I<V-H("A)4T\M.#@U.2TQ-2D`5V5S='-A:&%R80!796QC:&4@
M06YW96YD=6YG('-O;&P@)7,@;F%C:"!D96T@06YM96QD96X@86YG97IE:6=E
M;C\`5V5L8VAE<R!4<F5N;GIE:6-H96X@=VER9"!V97)W96YD970_`%=E;&-H
M92!!;F;\:')U;F=S>F5I8VAE;B!W97)D96X@=F5R=V5N9&5T/P!7:&5R96ES
M+4%U<W1R86QI82U+87)T90!796QC:&4@4&AA<V5N`%=E;&-H92!0;'5G:6YS
M(&;\<B!D96X@5UE325=91RU%9&ET;W(@<V]L;&5N(&%K=&EV:65R="!W97)D
M96X_`$)R96ET90!"<F5I=&4@:6X@0U-3+45I;FAE:71E;@!"<F5I=&4@9&5S
M("5S+4UE;OQS(&QI;FMS("AW:7)K<V%M(&YA8V@@9&5R(&[D8VAS=&5N($%N
M;65L9'5N9RDZ`%1A8F5L;&5N8G)E:71E`$5I;FAE:70`0G)E:71E.@!7:6MI
M`%=I;F0`1G+\:"!7:6YD`%=I;F1G97-C:'=I;F1I9W1K96ET(&EN($MN;W1E
M;@!7:6YD.@!7:6YD.B``5V5I<VAE:70`5W5N<V-H>F5T=&5L`$%R8F5I=`!!
M9')E<W-E(&=E<V-HY&9T;&EC:`!3=&%D="!G97-C:.1F=&QI8V@`3&%N9"!G
M97-C:.1F=&QI8V@`5&5L969O;B!G97-C:.1F=&QI8V@`4&]S=&QE:71Z86AL
M(&=E<V-HY&9T;&EC:`!"=6YD97-S=&%A="!O9&5R(%!R;W9I;GH@9V5S8VCD
M9G1L:6-H`%-T<F'?92!G97-C:.1F=&QI8V@`1F%L<V-H92!!;GIA:&P@86X@
M1F5L9&5R;B!I;B!:96EL92`E9"X@)60@97)W87)T970L("5D(&=E9G5N9&5N
M+@!&86QS8VAE($%N>F%H;"!A;B!&96QD97)N+B`E9"!E<G=A<G1E="P@)60@
M9V5F=6YD96XN`%5N9_QL=&EG97(@3V9F<V5T("5D(&)E:6T@3&5S96X@9&5R
M(%9&4RU$871E:2X`475E<G9E<G=E:7-E`%@U,#EV,R!'96YE<F5L;&4@16EN
M<V-H<N1N:W5N9P!8-3`Y=C,@17)W96ET97)T97(@4V-H;/QS<V5L>G=E8VL`
M6#4P.78S($%L=&5R;F%T:79E<B!.86UE(&1E<R!:97)T:69I:V%T:6YH86)E
M<G,`6#4P.78S($ED96YT:73D="!D97,@6F5R=&EF:6MA='-C:&S\<W-E;',`
M6#4P.78S($5R=V5I=&5R=6YG96X`2DH`2DI*2@!986AO;R$@2V%R=&4`2N1H
M<FQI8V@`2F5M96X`2F$`2F$L(&EC:"!S=&EM;64@>G4`4VEE(&)E9FEN9&5N
M('-I8V@@:6T@5&5X=&UO9'5S+B!"96YU='IE;B!3:64@9&5N(%L\/ET@2VYO
M<&8L('5M(&EN(&1E;B!765-)5TE'+4UO9'5S('IU('=E8VAS96QN+@!3:64@
M9/QR9F5N(&YI8VAT(&UE:'(@86QS("5D($)L]F-K92!E<G-T96QL96XN`%-I
M92!D_')F96X@;FEC:'0@;65H<B!A;',@)60@2V]N=&%K=&4@:6X@(B5S(B!E
M<G-T96QL96XN`%-I92!S:6YD(&YI8VAT(&%N9V5M96QD970N`%-I92!D_')F
M96X@9&%S(%IE:6-H96X@)UPG(&YI8VAT(&EN($EH<F5M($YA;65N('9E<G=E
M;F1E;BX`4VEE(&AA8F5N(&ME:6YE(&?\;'1I9V4@16UA:6QA9')E<W-E(&%N
M9V5G96)E;BX`4VEE(&AA8F5N(&ME:6YE($9E;&1E<B!A=7,@9&5N(&EM<&]R
M=&EE<G1E;B!$871E;B!D96X@96YT<W!R96-H96YD96X@1F5L9&5R;B!I;B`E
M<R!Z=6=E;W)D;F5T+@!3:64@:&%B96X@;FEC:'0@9V5N_&=E;F0@4F5C:'1E
M+"!U;2!D:65S96X@2V]N=&%K="!Z=2!S96AE;BX`4VEE(&AA8F5N(&YI8VAT
M(&=E;OQG96YD(%)E8VAT92P@=6T@9&EE<V5S($]B:F5K="!Z=2!S96AE;BX`
M4VEE(&AA8F5N(&YI8VAT(&=E;OQG96YD(%)E8VAT92P@=6T@9&EE<V4@475E
M;&QE('IU(&SV<V-H96XN`%-I92!W=7)D96X@86)G96UE;&1E="X`4VEE(&W\
M<W-E;B!E:6YE(&?\;'1I9V4@36]B:6QT96QE9F]N;G5M;65R(&%N9V5B96XL
M(&YU<B!A=7,@6F%H;&5N('5N9"!G9V8N(&5I;F5M("(K(B!F_'(@:6YT97)N
M871I;VYA;&4@5F]R=V%H;&5N(&)E<W1E:&5N9"X`4VEE(&W\<W-E;B!E:6YE
M;B!G_&QT:6=E;B!797)T(&%N9V5G96)E;BX`4VEE(&W\<W-E;B!E:6X@1&%T
M851R964M0F%C:V5N9"!K;VYF:6=U<FEE<F5N+"!U;2!296=I<W1R:65R=6YG
M96X@=F5R=V5N9&5N('IU(&OV;FYE;BX`4VEE(&W\<W-E;B!E:6X@5D93+4)A
M8VME;F0@:V]N9FEG=7)I97)E;BX`4VEE(&W\<W-E;B!D87,@4')O8FQE;2!B
M97-C:')E:6)E;BP@=6T@9&5N($)E<FEC:'0@86)Z=7-C:&EC:V5N+@!3:64@
M;?QS<V5N(&1I92!54DP@86YG96)E;BP@875F(&1I92!D:65S97(@3&EN:R!V
M97)W96ES96X@<V]L;`!3:64@;?QS<V5N(&5R<W0@96EN(%II96QA9')E<W-B
M=6-H(&%U<W?D:&QE;BX`4VEE(&W\<W-E;B!E<G-T(&5I;F4@6FEE;&QI<W1E
M(&%N9V5B96XN`%-I92!M_'-S96X@97)S="!D96X@>G4@96YT9F5R;F5N9&5N
M(%-E<G9E<B!A=7-WY&AL96XN`%-I92!M_'-S96X@97)S="!M:6YD97-T96YS
M(&5I;F5N($MO;G1A:W0@875S=^1H;&5N+@!3:64@;?QS<V5N(&5R<W0@;6EN
M9&5S=&5N<R!E:6YE;B!%:6YT<F%G(&%U<W?D:&QE;BX`4VEE(&W\<W-E;B!E
M:6YE;B!"96YU='IE<FYA;65N(&%N9V5B96XL(&1E<W-E;B!$871E;B!G96SV
M<V-H="!W97)D96X@<V]L;&5N+@!3:64@;?QS<V5N(&5I;F5N('IU(&SV<V-H
M96YD96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+@!3:64@;?QS<V5N(&5I;F5N
M(&AI;GIU>G5F_&=E;F1E;B!"96YU='IE<FYA;65N(&%N9V5B96XN`%-I92!M
M_'-S96X@9&5N('IU(&%K='5A;&ES:65R96YD96X@0F5N=71Z97)N86UE;B!A
M;F=E8F5N+@!3:64@;?QS<V5N(&5I;F4@06MT:6]N(&%N9V5B96XN`%-I92!M
M_'-S96X@96EN96X@;F5U96X@2V%T96=O<FEE;F%M96X@86YG96)E;BX`4VEE
M(&W\<W-E;B!E:6YE($ET86QI96YI<V-H92!496QE9F]N;G5M;65R(&%N9V5B
M96X`4VEE(&AA8F5N(&YU<B!D87,@4F5C:'0L(&1I97-E;B!+;VYT86MT(&%N
M>G5S96AE;BX`26AR92`E<RU397-S:6]N(&ES="!A8F=E;&%U9F5N+B!":71T
M92!M96QD96X@4VEE('-I8V@@97)N975T(&%N+@!):')E($5M86EL+4%D<F5S
M<V4`26AR92!6;VXZ($%D<F5S<V4Z`$EH<F4@06YG86)E;@!):')E($EN=&5R
M;F5T861R97-S92!H870@<VEC:"!G9>1N9&5R="P@<V5I="!3:64@9&EE("5S
M+5-I='IU;F<@8F5G;VYN96X@:&%B96XN(%IU;2!38VAU='H@26AR97(@4VEC
M:&5R:&5I="!M_'-S96X@4VEE('-I8V@@;F5U(&%N;65L9&5N+@!):'(@3F%M
M90!):'(@075T:&5N=&EF:7II97)U;F=S<WES=&5M(&5R;&%U8G0@:V5I;B!(
M:6YZ=6;\9V5N('9O;B!N975E;B!"96YU='IE<FXN(%=E;FX@4VEE($AO<F1E
M(&)E;G5T>F5N(&WV8VAT96XL('5M($EH<F4@0F5N=71Z97(@>G4@=F5R=V%L
M=&5N+"!M_'-S96X@4VEE(&5I;F5N(&%N9&5R96X@075T:&5N=&EF:7II97)U
M;F=S=')E:6)E<B!B96YU='IE;BX`26AR($%U=&AE;G1I9FEZ:65R=6YG<W-Y
M<W1E;2!E<FQA=6)T(&1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@;FEC:'0L
M(&]D97(@9&EE<V4@3?9G;&EC:&ME:70@=W5R9&4@875S9V5S8VAA;'1E="X`
M26AR($)R;W=S97(@:&%T('-I8V@@86YS8VAE:6YE;F0@9V7D;F1E<G0@<V5I
M="!3:64@9&EE("5S+5-I='IU;F<@8F5G;VYN96X@:&%B96XN(%IU;2!38VAU
M='H@26AR97(@4VEC:&5R:&5I="!M_'-S96X@4VEE('-I8V@@;F5U(&%N;65L
M9&5N+@!):'(@0G)O=W-E<B!U;G1E<G-T_'1Z="!D:65S92!&=6YK=&EO;B!N
M:6-H="X`26AR($)R;W=S97(@=6YT97)S=/QT>G0@9&EE<V4@1')U8VMF=6YK
M=&EO;B!N:6-H="X@0FET=&4@9'+\8VME;B!3:64@4W1R9R]+;VUM86YD;R`K
M(%`@=6T@>G4@9')U8VME;BX`26AR92!A:W1U96QL92!:96ET>F]N93H`26AR
M(%-T86YD87)D+4%D<F5S<V)U8V@@:V%N;B!N:6-H="!A;F=E>F5I9W0@=V5R
M9&5N+@!):')E(%-T86YD87)D:61E;G1I=.1T('=U<F1E(&=EY&YD97)T+@!)
M:')E(%-T86YD87)D:61E;G1I=.1T.@!):'(@=F]L;'-TY&YD:6=E<B!.86UE
M.@!):'(@6G5G86YG(&ES="!A8F=E;&%U9F5N+@!):'(@;F5U97,@4&%S<W=O
M<G0@9OQR("5S(&QA=71E=#H@)7,`26AR92!%:6YS=&5L;'5N9V5N('=U<F1E
M;B!F_'(@9&EE($1A=65R(&1I97-E<B!3:71Z=6YG(&=E<W!E:6-H97)T+@!)
M:')E($5I;G-T96QL=6YG96X@=W5R9&5N(&=E<W!E:6-H97)T+@!):'(@4&%S
M<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z=`!):'(@4&%S<W=O<G0@=W5R9&4@
M>G5R_&-K9V5S971Z="X@4G5F96X@4VEE($EH<F4@16UA:6QS(&%B('5N9"!M
M96QD96X@4VEE('-I8V@@;6ET($EH<F5M(&YE=65N(%!A<W-W;W)T(&%N+@!)
M:'(@4&%S<W=O<G0@:7-T(&%B9V5L875F96XN`$EH<F4@4V5R=F5R.@!*=6=O
M<VQA=VEE;@!:86ER90!386UB:6$`4VEM8F%B=V4`6FEP<'D`6UII=&%T=&5X
M="!V97)S=&5C:V5N70!;4')O8FQE;6)E<FEC:'1=`%M::71A='1E>'0@86YZ
M96EG96X@+0!;6FET871T97AT(&%N>F5I9V5N("T@)7,@6F5I;&5N70!;6F5I
M;&4@)7,@=F]N("5S70!;:V5I;B!797)T70!?061M:6YI<W1R871I;VX`7TQI
M<W1E`$)E7V9E:&QS>F5I;&4`7TMO;G1A:W1E`%]$871A5')E90!,]G-?8VAE
M;@!:96EL92!?;/9S8VAE;@!?1W)U<'!E;@!?2&EL9F4`7T)I;&1E:6=E;G-C
M:&%F=&5N+BXN`%]);7!O<G0O17AP;W)T`%],:7-T96X`06Y?;65L9&5N`$%B
M7VUE;&1E;@!,:6YK(%]B96%R8F5I=&5N+BXN`%]-96EN92!!9')E<W-B_&-H
M97(`7TYE=65R($MO;G1A:W0`7T5I;G-T96QL=6YG96X`7U)E8VAT90!,:6YK
M(%]E;G1F97)N96XN+BX`7T%U<R!D:65S97(@3&ES=&4@96YT9F5R;F5N`%]3
M=6-H90!?2V]N9FEG=7)A=&EO;@!?5&%B96QL96YE:6=E;G-C:&%F=&5N+BXN
M`%]"96YU='IE<@!!9')E<W-B=6-H`$%D<F5S<V%T('5N8F5K86YN=`!+86QE
M;F1E<@!W:6YD<W1I;&P`075S9V%B961A=&5I(&MO;FYT92!N:6-H="!E<G-T
M96QL="!W97)D96X`16EN9V%B92!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E
M;@!K;&EC:V5N(%-I92!H:65R`%5N9_QL=&EG92!"96YU='IU;F<@9&5R($MO
M;6UA;F1O>F5I;&4`2V]N9FEG=7)A=&EO;G-F96AL97(`861R97-S92YV8V8`
M861R97-S96XN8W-V`&%D<F5S<V5N+G1S=@!A9')E<W-E;BYV8V8`2W)I=&ES
M8VAE(%-Y<W1E;61A=&5I(&9E:&QT`$1A=&5N9F]R;6%T9F5H;&5R`&)E87)B
M96ET96X`16EN=')A9R!N:6-H="!G969U;F1E;@!F86QL96YD`$1A=&5I`&%U
M<R`E<R`H)7,I(&UI="`E<R`E<P!B]FEG`&@Z`&AH`$AO<W1N86UE('5N8F5K
M86YN=`!S;V9O<G0`26YL:6YE`$5I;BTO075S9V%B969E:&QE<@!);G1E<FYE
M<B!3;V9T=V%R969E:&QE<@!:96EL96Y=`&UK:7-O9G,M1F5H;&5R8V]D92`E
M9"!B96D@9&5R($5R<W1E;&QU;F<@9&5S($E33RU!8F)I;&1E<RX`;6T`3F%M
M90!+96EN92!&;W)M871I97)U;F<`:V5I;@!N:6-H="!I;7!L96UE;G1I97)T
M`$YO8V@@;FEC:'0@:6UP;&5M96YT:65R=`!.;W1I>F)L;V-K`%!R;WIE;G0`
M6G5G<FEF9B!V97)W96EG97)T`%!I>&5L`%)E;6]T969E:&QE<B!I;2!0<F]T
M;VMO;&P`<W1E:6=E;F0`4V5R=FEC92!N:6-H="!V97)F_&=B87(`56YT97)S
M8VAI961E(&%N>F5I9V5N`'-M<S)E;6%I;"#\8F5R($A45%``<W,`9VQE:6-H
M8FQE:6)E;F0`4WES=&5M9F5H;&5R`$%U9F=A8F5N;&ES=&4`5F]R_&)E<F=E
M:&5N9&5R($9E:&QE<@!Z=2!E:6YE<B!+;VYT86MT;&ES=&4`>G4@96EN96T@
M86YD97)E;B!!9')E<W-B=6-H`&=E8F5N(%-I92!D87,@4&%S<W=O<G0@96EN
M('IW96ET97,@36%L('IU<B!"97-TY'1I9W5N9R!E:6X`=6YI9FEE9`!U;F)E
M;F%N;G0`8F5N=71Z97)D969I;FEE<G0`=D-A<F0`8CH`=V5A=&AE<BYC;VT`
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M=7)B82]L;V-A;&4O9&5?1$4O:&5L<"YX;6P`````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$T-3$S`#$P-#$W,S8R-S4S`#`R,30Q,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/WAM;"!V97)S
M:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA+2T@)$AO<F1E
M.B!T=7)B82]L;V-A;&4O9&5?1$4O:&5L<"YX;6PL=B`Q+C8@,C`P-"\Q,B\P
M,R`P,3HS-CHP.2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M3W9E<G9I97<B(&UD-3TB,CDP-3`V861E-&4V9C<T.3(T-F8W-V)B935D-#@X
M,S4B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^W&)E<F)L:6-K/"]T
M:71L93X*("`@(#QH96%D:6YG/D5I;F;\:')U;F<\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@("`@36ET($AI;&9E(&1E<R!!9')E<W-B=6-H<R!K]FYN96X@
M4VEE(&5I;F9A8V@@=6YD('5N:V]M<&QI>FEE<G0*("`@("`@2V]N=&%K=&1A
M=&5N('-P96EC:&5R;BP@875S;&5S96X@=6YD(&)E;G5T>F5N+B!*92!N86-H
M9&5M+"!W:64@26AR"B`@("`@(%-Y<W1E;2!E:6YG97)I8VAT970@:7,@:V%N
M;B!E<R!S;W=O:&P@96EN('!R:79A=&5S(&%L<R!A=6-H(/9F9F5N=&QI8VAE
M+`H@("`@("!I;2!.971Z=V5R:R!V97)F_&=B87)E($%D9')E<W-B_&-H97(@
M>G5R(%9E<F;\9W5N9R!S=&5L;&5N+B!!=6-H"B`@("`@(%9E<G1E:6QE<FQI
M<W1E;B!W97)D96X@=6YT97)S=/QT>G0L('-O(&1A<W,@4VEE($EH<F4@96EG
M96YE;@H@("`@("`B36%I;&EN9VQI<W1E;B(@97)S=&5L;&5N(&OV;FYE;BX*
M("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UA9&0B
M(&UD-3TB,V,Q9CDR96(Q83@R.#,Y-#`T9#$Q9#EB,&$R,&(S8V4B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^365N_#H@2&EN>G5F_&=E;CPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY(:6YZ=6;\9V5N/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("`@($;\9V5N(%-I92!H:65R(%!E<G-O;F5N('IU($EH<F5M($%D
M<F5S<V)U8V@@:&EN>G4N(%-I92!K]FYN96X@4&5R<V]N96X*("`@("`@;G5R
M('IU(&1E;B!!9&1R97-S8OQC:&5R;B!H:6YZ=6;\9V5N+"!F_'(@9&EE(%-I
M92!38VAR96EB<F5C:'1E"B`@("`@(&AA8F5N+B!796YN(&=E;65I;G-A;64@
M;V1E<B#V9F9E;G1L:6-H92!!9')E<W-B_&-H97(@96EN9V5R:6-H=&5T"B`@
M("`@('=U<F1E;BP@<VEN9"!D:65S92!O9G0@<V-H<F5I8F=E<V-H_'1Z="P@
M<V\@9&%S<R!3:64@:V5I;F4@4&5R<V]N96X*("`@("`@:&EN>G5F_&=E;B!K
M]FYN96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](FUE
M;G4M<V5A<F-H(B!M9#4](CAD868X,6%B,C@V,#)D-S<R,S4X83$W-#4W,68Y
M860R(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE;OPZ(%-U8VAE
M/"]T:71L93X*("`@(#QH96%D:6YG/E-U8VAE/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("`@($1U<F-H<W5C:&5N(%-I92!H:65R(&5I;B!!9')E<W-B=6-H
M+"!U;2!);F9O<FUA=&EO;F5N('IU(&9I;F1E;BX@1&EE<PH@("`@("!I<W0@
M9OQR('-C:&YE;&QE(%-U8VAE;B!G961A8VAT+"!U;F0@4VEE(&OV;FYE;B!N
M=7(@96EN:6=E(&5I;F9A8VAE"B`@("`@($9E;&1E<B!D=7)C:'-U8VAE;BX@
M26T@06QL9V5M96EN96X@<VEN9"!D87,@9&5R($YA;64@=6YD(&1I90H@("`@
M("!%;6%I;&%D<F5S<V5N+"!D87,@:V%N;B!A8F5R(&IE(&YA8VAD96TL('=I
M92!):'(@4WES=&5M(&5I;F=E<FEC:'1E=`H@("`@("!W=7)D92P@=F%R:6EE
M<F5N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%5N=&5R("(\<F5F
M(&UO9'5L93TB='5R8F$B(&5N=')Y/2)M96YU+6%D=F%N8V5D+7-E87)C:"(^
M17)W96ET97)T90H@("`@("!3=6-H93PO<F5F/B(@:_9N;F5N(%-I92!A=6-H
M(&%N9&5R92!&96QD97(@9'5R8VAS=6-H96XN"B`@("`\+W!A<F$^"B`@/"]E
M;G1R>3X*("`\96YT<GD@:60](FUE;G4M861V86YC960M<V5A<F-H(B!M9#4]
M(C9B93<P,V9F96)A-C$T9C9A9&$Q-3$W-#EF830T86(U(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/DUE;OPZ($5R=V5I=&5R=&4@4W5C:&4\+W1I
M=&QE/@H@("`@/&AE861I;F<^17)W96ET97)T92!3=6-H93PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@("!$=7)C:'-U8VAE;B!3:64@:&EE<B!E:6X@061R
M97-S8G5C:"P@=6T@26YF;W)M871I;VYE;B!Z=2!F:6YD96XN($UI=`H@("`@
M("!D:65S97(@4W5C:&4@:_9N;F5N(%-I92!M96AR97)E($9E;&1E<B!G;&5I
M8VAZ96ET:6<@9'5R8VAS=6-H96XN(%=E;&-H90H@("`@("!&96QD97(@9OQR
M(&1I92!3=6-H92!Z=7(@5F5R9OQG=6YG('-T96AE;BP@:.1N9W0@=F]N(&1E
M;2!A=7-G97?D:&QT96X*("`@("`@061R97-S8G5C:"!A8BX*("`@(#PO<&%R
M83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UI;7!O<G0B(&UD-3TB
M,V,V8S0P9C)A-C(Q,V4Y9F,Q9CEA-S<X,C=B9F(U9#0B('-T871E/2)U<'1O
M9&%T92(^"B`@("`\=&ET;&4^365N_#H@26UP;W)T+T5X<&]R=#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY);7!O<G0O17AP;W)T/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("`@($1I97-E<B!-96[\<'5N:W0@97)L875B="!D96X@26UP;W)T
M(&EN('5N9"!D96X@17AP;W)T('9O;B!):')E;0H@("`@("!P97)S]FYL:6-H
M96X@061R97-S8G5C:"X@17,@=V5R9&5N($-35B`H:V]M;6%G971R96YN=&4@
M5V5R=&4I+"!/=71L;V]K+`H@("`@("!V0V%R9"!U;F0@86YD97)E('9E<F)R
M96ET971E($9O<FUA=&4@=6YT97)S=/QT>G0N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY);7!O<G0\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@56T@
M1&%T96X@:6X@26AR($%D<F5S<V)U8V@@>G4@:6UP;W)T:65R96XL(&W\<W-E
M;B!D:65S92!A=68@26AR96T*("`@("`@;&]K86QE;B!296-H;F5R("AA=68@
M9&5M(%-I92!D96X@0G)O=W-E<B!A=7-F_&AR96XI('9O<FQI96=E;BX@1&%Z
M=0H@("`@("!M_'-S96X@4VEE(&1A<R!!9&1R97-S8G5C:"!):')E<B!A:W1U
M96QL96X@061R97-S=F5R=V%L='5N9R!O9&5R($EH<F5S"B`@("`@($5M86EL
M+5!R;V=R86UM<R!Z=6[D8VAS="!E>'!O<G1I97)E;BX*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@("!796YN(%-I92!/=71L;V]K($5X<')E<W,@=F5R
M=V5N9&5N.@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(#$I($ML:6-K
M96X@4VEE(&%U9B!$871E:2`F9W0[($5X<&]R=&EE<F5N("9G=#L@061R97-S
M8G5C:`H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(#(I(%?D:&QE;B!S
M:64@(E1E>'1D871E:2`H;6ET($MO;6UA<R!A;',@5')E;FYZ96EC:&5N*2(@
M:6T*("`@("`@(D5X<&]R='!R;V=R86UM(&;\<B!D87,@061D<F5S<V)U8V@@
M(B!A=7,N($ML:6-K96X@<VEE(&%U9@H@("`@("`B17AP;W)T:65R96XB"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@,RD@26X@9&5M($9E;&0@(D5X
M<&]R=&EE<G1E($1A=&5I('-P96EC:&5R;B!U;G1E<CHB(&OV;FYE;B!3:64*
M("`@("`@96EN96X@8F5L:65B:6=E;B!.86UE;B!F_'(@9&%S(&5X<&]R=&EE
M<G1E($%D9')E<W-B=6-H(&%N9V5B96XN($ML:6-K96X*("`@("`@4VEE(&%U
M9B`B5V5I=&5R(BX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("`T*2!-
M87)K:65R96X@4VEE(&1I92!!=7-W86AL8F]X96X@=F]R(&%L;&5N($9E;&1E
M<FXL(&1I92!3:64@97AP;W)T:65R96X*("`@("`@;?9C:'1E;BX@2VQI8VME
M;B!3:64@875F(")&97)T:6<@<W1E;&QE;B(N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@("`@-2D@17,@<V]L;'1E(&5I;F4@3F%C:')I8VAT(&5R<V-H
M96EN96X@;6ET(&1E<B!-96QD=6YG(")$87,*("`@("`@061R97-S8G5C:"!W
M=7)D92!V;VQL<W3D;F1I9R!E>'!O<G1I97)T+B(@2VQI8VME;B!3:64@875F
M"B`@("`@(")/2R(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@-BD@
M2VQI8VME;B!3:64@875F(")38VAL:67?96XB(&EM(")%>'!O<G1P<F]G<F%M
M;2!F_'(@9&%S"B`@("`@($%D9')E<W-B=6-H("(@=6YD(&)E96YD96X@4VEE
M($]U=&QO;VL@17AP<F5S<RX*("`@(#PO<&%R83X*("`@(#QT:7`^"B`@("`@
M(%=E;FX@<VEC:"!D:64@1&%T96D@;6ET(&1E;2!E>'!O<G1I97)T96X@061R
M97-S8G5C:"!N:6-H="!A=68@26AR96T*("`@("`@1&5S:W1O<"!B969I;F1E
M="!U;F0@4VEE(&5I;B!7:6YD;W=S($)E=')I96)S<WES=&5M('9E<G=E;F1E
M;BP@:VQI8VME;@H@("`@("!3:64@875F(%-T87)T("9G=#L@4W5C:&5N("9G
M=#L@1&%T96EE;B]/<F1N97(L('-U8VAE;B!3:64@875F($EH<F5R"B`@("`@
M($9E<W1P;&%T=&4@;F%C:"!D96T@1&%T96EN86UE;BP@9&5N(%-I92!B96EM
M($5X<&]R=&EE<F5N('9E<G=E;F1E="!H86)E;@H@("`@("!U;F0@;65R:V5N
M(%-I92!S:6-H(&1E;B!/<G0@9&5R(&=E9G5N9&5N96X@1&%T96DN"B`@("`\
M+W1I<#X*("`@(#QP87)A/@H@("`@("!5;2!I;B!E:6X@061R97-S8G5C:"!Z
M=2!I;7!O<G1I97)E;BP@:VQI8VME;B!3:64@875F(&1A<PH@("`@("!);7!O
M<G0O17AP;W)T+5-Y;6)O;"!U;F0@=^1H;&5N(%-I92!D87,@061D<F5S<V)U
M8V@@875S+B!7Y&AL96X@4VEE(&1A<PH@("`@("!&;W)M870L(&EN(&1E;2!D
M:64@>G4@:6UP;W)T:65R96YD96X@1&%T96X@=F]R;&EE9V5N+"!A=7,@9&5R
M"B`@("`@($%U<W=A:&QL:7-T92!A=7,N($ML:6-K96X@4VEE(&%U9B!D96X@
M(D1U<F-H<W5C:&5N+BXN(BU+;F]P9BP*("`@("`@<W5C:&5N(%-I92!N86-H
M(&1E<B!$871E:2P@9&EE(&EM<&]R=&EE<G0@=V5R9&5N('-O;&PL('?D:&QE
M;B!3:64@9&EE<V4*("`@("`@875S('5N9"!K;&EC:V5N(%-I92!A=68@(DEM
M<&]R=&EE<F5N(BX*("`@(#PO<&%R83X*("`@(#QT:7`^"B`@("`@($5I;FEG
M92!K;VUP;&EZ:65R=&4@16EN='+D9V4@;V1E<B!%:6YT<N1G92!M:70@1F5L
M9&5R;BP@9&EE(&YI8VAT(&=E;F%U"B`@("`@(&1E;B!&96QD97)N(&EN($EH
M<F5M($%D<F5S<V)U8V@@96YT<W!R96-H96XL(&OV;FYE;B!U;G1E<B!5;7-T
MY&YD96X*("`@("`@;FEC:'0@<FEC:'1I9R!I;7!O<G1I97)T('=O<F1E;B!S
M96EN+B!$86AE<B!S;VQL=&5N(%-I92!D:64@:6UP;W)T:65R=&5N"B`@("`@
M($1A=&5N(&YA8V@@9&5M($EM<&]R="#\8F5R<'+\9F5N+@H@("`@/"]T:7`^
M"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G-E87)C:&EN9RUS96%R8VA?<F5S
M=6QT<R(@<W1A=&4](G5P=&]D871E(B!M9#4](F9F960X9#<R9F$S8C<Q,&1F
M.&4Y,#)C,C0Y,V(R-31F(CX*("`@(#QT:71L93Y3=6-H93H@4W5C:&5R9V5B
M;FES<V4\+W1I=&QE/@H@("`@/&AE861I;F<^4W5C:&5R9V5B;FES<V4\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@("`@5V5N;B!E:6YE(%-U8VAE(&5R9F]L
M9W)E:6-H('=A<BP@=V5R9&5N(&1I92!%<F=E8FYI<W-E(&EM($)E<F5I8V@*
M("`@("`@(E-U8VAE<F=E8FYI<W-E(B!A;F=E>F5I9W0N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@("`@5V5N;B!3:64@875F(&5I;B`B16UA:6PB+49E
M;&0@:VQI8VME;BP@]F9F;F5T('-I8V@@96EN(&YE=65S($9E;G-T97(L(&EN
M"B`@("`@(&1E;2!3:64@96EN92!.86-H<FEC:'0@86X@9&EE(&%N9V5G96)E
M;B!!9')E<W-E('-C:')E:6)E;B!K]FYN96XN(%=E;FX*("`@("`@4VEE(&%U
M9B!D87,@(DYA;64B+49E;&0@:VQI8VME;BP@=VER9"!D97(@>G5G96CV<FEG
M92!!9')E<W-B=6-H96EN=')A9PH@("`@("!A;F=E>F5I9W0@=6YD(%-I92!K
M]FYN96X@9&5N($5I;G1R86<@8F5A<F)E:71E;B!O9&5R(&SV<V-H96XN"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@2F4@;F%C:&1E;2P@=VEE($EH
M<B!3>7-T96T@96EN9V5R:6-H=&5T('=U<F1E+"!W97)D96X@9&EE(%-U8VAE
M<F=E8FYI<W-E"B`@("`@(&%D9&EE<G0N($IE9&4@=V5I=&5R92!3=6-H92!W
M:7)D(&1A;FX@9&EE($5R9V5B;FES<V4@>G4@9&5N('-C:&]N"B`@("`@('9O
M<FAA;F1E;F5N($5R9V5B;FES<V5N(&AI;GIU9OQG96XN($1A<R!K86YN(&AI
M;&9R96EC:"!S96EN+"!U;2!,:7-T96X*("`@("`@>G5S86UM96YZ=7-T96QL
M96XN(%5M(&1I92!%<F=E8FYI<W-E(&%L;&5R(%-U8VAE;B!W:65D97(@>G4@
M;/9S8VAE;B!U;F0*("`@("`@96EN92!N975E(%-U8VAE('IU(&)E9VEN;F5N
M+"!K;&EC:V5N(%-I92!A=68@9&5N(")3=6-H92!Z=7+\8VMS971Z96XB"B`@
M("`@($QI;FLN"B`@("`\+W!A<F$^"B`@("`\=&EP/@H@("`@("!796YN(%-I
M92!S:6-H(&5I;F4@3&ES=&4@=F]N($5I;G1RY&=E;B!A;GIE:6=E;B!L87-S
M96XL(&OV;FYE;B!3:64@9&EE"B`@("`@($5I;G1RY&=E(&YA8V@@86QL96X@
M1F5L9&5R;B!S;W)T:65R96XL(&EN9&5M(%-I92!A=68@9&EE(&IE=V5I;&EG
M90H@("`@("!3<&%L=&5N_&)E<G-C:')I9G0@:VQI8VME;BX@56T@9&EE(%-O
M<G1I97)R:6-H='5N9R!Z=2#D;F1E<FXL(&ML:6-K96X*("`@("`@4VEE(&%U
M9B!D87,@4&9E:6QS>6UB;VP@:6X@9&5R(%-P86QT96[\8F5R<V-H<FEF="X*
M("`@(#PO=&EP/@H@(#PO96YT<GD^"CPO:&5L<#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+V-S7T-:+P``````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U,P`P
M,C`P,#$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O8W-?
M0UHO3$-?34534T%'15,O````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S4S`#`R,34V-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1U<F)A+VQO8V%L92]C<U]#6B],0U]-15-304=%4R]T=7)B82YM;P``````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`S-C4W,38`,3`T,3<S-C(W-3,`,#(S,C4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
M/@<``!P````,.@``J0D``/QS````````H)H```X```"AF@``#P```+":```-
M````P)H```@```#.F@``"P```->:```,````XYH```0```#PF@``)````/6:
M```E````&IL```P```!`FP``#P```$V;```+````79L```X```!IFP``!0``
M`'B;```H````?IL```@```"GFP``"@```+";```5````NYL```D```#1FP``
M$@```-N;```+````[IL``!T```#ZFP``#@```!B<```*````)YP```T````R
MG```#@```$"<```-````3YP```P```!=G```#0```&J<```&````>)P```\`
M``!_G```&````(^<```,````J)P```X```"UG```#@```,2<```(````TYP`
M`"L```#<G```+@````B=```:````-YT``#(```!2G0``.````(6=``!4````
MOIT``%$````3G@``6@```&6>``!7````P)X``#0````8GP``!P```$V?```*
M````59\```\```!@GP``!0```'"?```&````=I\``!$```!]GP``"````(^?
M```1````F)\```D```"JGP``"0```+2?```E````OI\``"````#DGP``$```
M``6@```/````%J````H````FH````P```#&@```/````-:```!0```!%H```
M"0```%J@```-````9*```!(```!RH```#P```(6@```*````E:````\```"@
MH```"````+"@```D````N:````8```#>H```%````.6@```6````^J````@`
M```1H0``&0```!JA```'````-*$``!0````\H0``$@```%&A```A````9*$`
M`"P```"&H0``#@```+.A```#````PJ$```\```#&H0``"P```-:A```'````
MXJ$```<```#JH0``!0```/*A```%````^*$```H```#^H0```P````FB```7
M````#:(```H````EH@``#P```#"B```.````0*(``!@```!/H@``(P```&BB
M```.````C*(```X```";H@``%````*JB```7````OZ(``!<```#7H@``%P``
M`.^B```3````!Z,```\````;HP``#@```"NC```?````.J,```<```!:HP``
M!@```&*C```(````::,```\```!RHP``!@```(*C```*````B:,``!,```"4
MHP``"P```*BC```0````M*,``!4```#%HP``%0```-NC```'````\:,``!``
M``#YHP``!0````JD```5````$*0``!$````FI```#````#BD```H````1:0`
M`#H```!NI```.P```*FD```)````Y:0```<```#OI```%````/>D```#````
M#*4```4````0I0``"0```!:E```0````(*4```D````QI0``$P```#NE```Y
M````3Z4``!(```")I0``)P```)RE```L````Q*4``"H```#QI0``)0```!RF
M```*````0J8```8```!-I@``"0```%2F```'````7J8``"\```!FI@``-P``
M`):F```N````SJ8``%4```#]I@``+0```%.G```M````@:<``"T```"OIP``
M0````-VG```C````'J@``",```!"J```+0```&:H```S````E*@``!4```#(
MJ```&0```-ZH```I````^*@``"0````BJ0``$0```$>I```*````6:D```P`
M``!DJ0``"@```'&I```0````?*D``!8```"-J0``%@```*2I```'````NZD`
M``<```##J0``%````,NI```*````X*D```@```#KJ0``"````/2I```,````
M_:D```<````*J@``!P```!*J```&````&JH``!$````AJ@``!0```#.J```'
M````.:H```8```!!J@``%````$BJ```(````7:H``"D```!FJ@``#@```)"J
M```*````GZH```0```"JJ@``!P```*^J```)````MZH```8```#!J@``$0``
M`,BJ```'````VJH``!8```#BJ@``!````/FJ```(````_JH```8````'JP``
M#0````ZK```&````'*L``!X````CJP``$0```$*K```(````5*L```T```!=
MJP``#````&NK```'````>*L``!$```"`JP```P```)*K```#````EJL``!<`
M``":JP```P```+*K```3````MJL```@```#*JP``!````-.K```(````V*L`
M``@```#AJP``00```.JK```@````+*P```8```!-K```!@```%2L```5````
M6ZP``!@```!QK```(@```(JL```N````K:P``!T```#<K```(0```/JL``!4
M````'*T``"D```!QK0``"@```)NM```'````IJT``!4```"NK0``#@```,2M
M```*````TZT```\```#>K0``#0```.ZM```/````_*T```T````,K@``"0``
M`!JN```4````)*X```8````YK@``&````$"N```=````6:X``!,```!WK@``
M%````(NN```$````H*X```8```"EK@``5````*RN```$`````:\```X````&
MKP``#P```!6O```%````):\```4````KKP``&P```#&O```:````3:\``!$`
M``!HKP``$0```'JO```6````C*\``!P```"CKP``*@```,"O```0````ZZ\`
M`"$```#\KP``!0```!ZP```3````)+```!(````XL```"@```$NP```/````
M5K```!$```!FL```$P```'BP```,````C+````8```"9L```!@```*"P```7
M````I[```!````"_L```$0```-"P```(````XK````4```#KL```#````/&P
M```0````_K````4````/L0``#@```!6Q```-````)+$```8````RL0``%@``
M`#FQ```J````4+$```<```![L0``#0```(.Q```'````D;$```L```"9L0``
M!P```*6Q```'````K;$```\```"UL0``"0```,6Q```*````S[$``!D```#:
ML0``#````/2Q```0`````;(```4````2L@``)0```!BR```2````/K(``!,`
M``!1L@``%0```&6R```2````>[(``"L```".L@``.P```+JR```@````]K(`
M`!H````7LP``%````#*S```V````1[,```@```!^LP``#````(>S```&````
ME+,```0```";LP``#@```*"S```*````K[,```T```"ZLP``'@```,BS```;
M````Y[,``"$````#M```'@```"6T```9````1+0``!X```!>M```&P```'VT
M```F````F;0``!L```#`M```'@```-RT```<````^[0``"8````8M0``,P``
M`#^U```F````<[4``"L```":M0``.````,:U```O````_[4``!(````OM@``
M*0```$*V```2````;+8``*(```!_M@``%@```"*W```C````.;<``"@```!=
MMP``*0```(:W```H````L+<``!\```#9MP``(````/FW```E````&K@``#``
M``!`N```(0```'&X```<````D[@``"8```"PN```00```->X```,````&;D`
M``<````FN0``!P```"ZY```-````-KD``!````!$N0``$@```%6Y```'````
M:+D``!,```!PN0``$@```(2Y```'````E[D```0```"?N0``#````*2Y```.
M````L;D```\```#`N0``$P```-"Y```-````Y+D``"@```#RN0```P```!NZ
M```-````'[H```8````MN@``$0```#2Z```7````1KH``!L```!>N@``#@``
M`'JZ```"````B;H```4```",N@``$````)*Z```$````H[H```T```"HN@``
M#@```+:Z```#````Q;H```X```#)N@``"````-BZ```/````X;H```\```#Q
MN@``!P````&[```-````";L``!`````7NP``&@```"B[```+````0[L```8`
M``!/NP``$P```%:[```,````:KL``!$```!WNP``&0```(F[```7````H[L`
M``L```"[NP``#0```,>[```B````U;L``!8```#XNP``"@````^\```8````
M&KP``!D````SO```%@```$V\```/````9+P```T```!TO```!P```(*\```*
M````BKP```H```"5O```%````*"\```B````M;P``"\```#8O```"P````B]
M```)````%+T``!D````>O0``"P```#B]```7````1+T``!<```!<O0``"0``
M`'2]```6````?KT```\```"5O0``%@```*6]```.````O+T``!@```#+O0``
M"````.2]```-````[;T``"8```#[O0``*````"*^``!#````2[X```@```"/
MO@``$@```)B^```+````J[X``"\```"WO@``#@```.>^```.````]KX```4`
M```%OP``!@````N_```#````$K\```<````6OP``!````!Z_```*````([\`
M``H````NOP``#P```#F_```0````2;\``!<```!:OP``$0```'*_```1````
MA+\``!<```"6OP``"0```*Z_```%````N+\```L```"^OP``"@```,J_```"
M````U;\```4```#8OP``#0```-Z_```;````[+\``!<````(P```"0```"#`
M```.````*L````T````YP```$@```$?````X````6L```"````"3P```"```
M`+3````.````O<```'L```#,P```&````$C!```5````8<$``!$```!WP0``
M!P```(G!```%````D<$``!D```"7P0``!P```+'!```(````N<$```8```#"
MP0``!@```,G!```0````T,$```\```#AP0``$````/'!```/`````L(```L`
M```2P@``#P```!["```,````+L(```\````[P@``!P```$O"```&````4\(`
M``X```!:P@``#````&G"```H````=L(```\```"?P@``"````*_"```&````
MN,(``!,```"_P@``(@```-/"```M````]L(```@````DPP``$P```"W#```>
M````0<,``"4```!@PP``&@```(;#```5````H<,``!X```"WPP``0P```-;#
M```A````&L0``"`````\Q```&0```%W$```7````=\0``"4```"/Q```)0``
M`+7$```7````V\0``"(```#SQ```!````!;%```;````&\4```T````WQ0``
M#````$7%```#````4L4```@```!6Q0``"@```%_%```,````:L4```L```!W
MQ0``$````(/%```,````E,4```0```"AQ0``$P```*;%```4````NL4```P`
M``#/Q0``"0```-S%```.````YL4```L```#UQ0``&P````'&```'````'<8`
M``0````EQ@``!P```"K&```*````,L8```H````]Q@``#0```$C&```)````
M5L8```0```!@Q@``!0```&7&```#````:\8``!@```!OQ@``"@```(C&```$
M````D\8``"8```"8Q@``#@```+_&``!\````SL8``!4```!+QP``!0```&''
M```'````9\<```P```!OQP``"````'S'```*````A<<```8```"0QP``"```
M`)?'```"````H,<```8```"CQP``!@```*K'```4````L<<```P```#&QP``
M#0```-/'```0````X<<``!L```#RQP``!`````[(```)````$\@``!`````=
MR```"0```"[(```)````.,@```4```!"R```&@```$C(```(````8\@```8`
M``!LR```&0```'/(```.````C<@```<```"<R```!P```*3(```%````K,@`
M``D```"RR```"@```+S(```3````Q\@```(```#;R```!@```-[(```-````
MY<@```D```#SR```!@```/W(```2````!,D```D````7R0``!P```"')```%
M````*<D``!0````OR0``'0```$3)```&````8LD```H```!IR0``!````'3)
M```)````><D```@```"#R0``$0```(S)```)````GLD```8```"HR0``#0``
M`*_)```&````O<D```0```#$R0``.0```,G)```]`````\H``#H```!!R@``
M'@```'S*```%````F\H```X```"AR@``!````+#*```&````M<H``"$```"\
MR@``%0```-[*```&````],H```0```#[R@``$0````#+```&````$LL```H`
M```9RP``(@```"3+```$````1\L```4```!,RP``'0```%++```$````<,L`
M``P```!URP``"0```(++```,````C,L```H```"9RP``$````*3+```3````
MM<L``!,```#)RP``"````-W+```)````YLL```4```#PRP``.@```/;+```P
M````,<P``#4```!BS```*0```)C,``!'````PLP``#@````*S0``*0```$/-
M```_````;<T``"X```"MS0``+0```-S-```?````"LX```\````JS@``$@``
M`#K.```+````3<X``"8```!9S@``*0```(#.```D````JLX``"8```#/S@``
M"````/;.```*````_\X```D````*SP``!P```!3/```@````',\``"`````]
MSP``)@```%[/```$````A<\```H```"*SP``&0```)7/```I````K\\``!8`
M``#9SP``$@```/#/```'`````]````H````+T```#````!;0```/````(]``
M`!`````ST```0````$30``!P````A=```&8```#VT```#@```%W1```)````
M;-$```H```!VT0``$@```('1```3````E-$```P```"HT0``!@```+71```<
M````O-$```\```#9T0``&P```.G1```2````!=(``!`````8T@``$0```"G2
M```<````.](``",```!8T@``:@```'S2```/````Y](```4```#WT@``$```
M`/W2```)````#M,```0````8TP``"P```!W3```4````*=,```P````^TP``
M#````$O3```/````6-,``!4```!HTP``*0```'[3```J````J-,``"8```#3
MTP``)P```/K3```I````(M0``"H```!,U```&0```'?4``!"````D=0``!$`
M``#4U```$@```.;4```3````^=0``!0````-U0``#P```"+5```6````,M4`
M`!<```!)U0``$````&'5```1````<M4``#0```"$U0``$P```+G5```2````
MS=4``#4```#@U0``%````!;6```'````*]8```P````SU@``"@```$#6```@
M````2]8``!0```!LU@``%````('6```1````EM8``!<```"HU@``'````,#6
M```-````W=8```T```#KU@``$P```/G6```6````#=<``!$````DUP``#```
M`#;7```0````0]<``!H```!4UP``'@```&_7```:````CM<``!$```"IUP``
M%````+O7```7````T-<``!4```#HUP``"0```/[7```9````"-@```0````B
MV```!P```"?8```+````+]@``!$````[V```!@```$W8```&````5-@```8`
M``!;V```!0```&+8```'````:-@```<```!PV```!0```'C8```6````?M@`
M``8```"5V```!@```)S8```$````H]@```0```"HV```!P```*W8```.````
MM=@```P```#$V```#````-'8```-````WM@```H```#LV```#@```/?8```%
M````!MD``"@````,V0``#@```#79```,````1-D```\```!1V0``"@```&'9
M```(````;-D```D```!UV0``*P```'_9```$````J]D```@```"PV0``)@``
M`+G9```2````X-D```\```#SV0``!@````/:```*````"MH``$P````5V@``
M!P```&+:```(````:MH``"````!SV@``"0```)3:```-````GMH```D```"L
MV@``#````+;:```-````P]H```X```#1V@``%@```.#:```1````]]H```8`
M```)VP```P```!#;```&````%-L``!D````;VP``!P```#7;```$````/=L`
M``L```!"VP``"P```$[;```'````6ML```<```!BVP``%@```&K;```-````
M@=L```T```"/VP``"@```)W;```0````J-L```\```"YVP``$0```,G;```7
M````V]L```H```#SVP``$0```/[;```(````$-P```0````9W```#P```![<
M```Z````+MP```4```!IW```#````&_<```$````?-P``!X```"!W```#@``
M`*#<```0````K]P```L```#`W```#````,S<```)````V=P```<```#CW```
M"@```.O<```)````]MP```X`````W0``$`````_=```:````(-T```H````[
MW0``"0```$;=```*````4-T```P```!;W0``#P```&C=```(````>-T```8`
M``"!W0``!P```(C=```+````D-T``$<```"<W0``#0```.3=```)````\MT`
M``0```#\W0```P````'>```3````!=X``!,````9W@``$P```"W>```*````
M0=X```(```!,W@``!````$_>```E````5-X```,```!ZW@``!0```'[>```J
M````A-X```H```"OW@``!0```+K>```$````P-X```H```#%W@``#0```-#>
M```&````WMX```@```#EW@``"````.[>```$````]]X```4```#\W@``:```
M``+?```)````:]\```P```!UWP``!0```(+?```&````B-\``!L```"/WP``
M+P```*O?```0````V]\```H```#LWP``"````/??```/`````.````H````0
MX```"0```!O@```3````)>```!L````YX```&````%7@```7````;N````X`
M``"&X```%P```)7@```#````K>````<```"QX```"````+G@```'````PN``
M``H```#*X```"P```-7@```'````X>```%$```#IX```$````#OA```,````
M3.$```T```!9X0``&@```&?A``!*````@N$```8```#-X0``!@```-3A```&
M````V^$``!\```#BX0``!@````+B```)````">(``!@````3X@``%P```"SB
M```+````1.(```8```!0X@``#0```%?B```H````9>(``"(```".X@``5P``
M`+'B```3````">,``",````=XP``$P```$'C```"````5>,```L```!8XP``
M#````&3C```(````<>,```T```!ZXP``"@```(CC```6````D^,```<```"J
MXP``%````++C```&````Q^,```@```#.XP``#@```-?C```'````YN,```H`
M``#NXP``"P```/GC```7````!>0```<````=Y```#````"7D```-````,N0`
M``P```!`Y```!````$WD```)````4N0```D```!<Y```"@```&;D```'````
M<>0```D```!YY```"0```(/D```*````C>0```<```"8Y```"@```*#D```5
M````J^0``!L```#!Y```20```-WD```2````)^4```H````ZY0``"0```$7E
M```0````3^4```<```!@Y0``$@```&CE```$````>^4```L```"`Y0``!P``
M`(SE```%````E.4```4```":Y0``&@```*#E```+````N^4``!0```#'Y0``
M$0```-SE```:````[N4``!8````)Y@``%````"#F```7````->8``!@```!-
MY@``'````&;F```9````@^8```<```"=Y@``!0```*7F```-````J^8```P`
M``"YY@``"P```,;F```(````TN8``!<```#;Y@``"P```//F```3````_^8`
M``0````3YP``"@```!CG```$````(^<```P````HYP``"0```#7G```(````
M/^<```4```!(YP``!P```$[G```%````5N<```0```!<YP```@```&'G```8
M````9.<``!<```!]YP``.````)7G```L````SN<``!(```#[YP``*0````[H
M```R````..@```H```!KZ```+````';H```N````H^@``#,```#2Z```,P``
M``;I```X````.ND``!$```!SZ0``#P```(7I```8````E>D``!````"NZ0``
M#P```+_I```3````S^D``!0```#CZ0``$@```/CI```4````"^H``!4````@
MZ@``+0```#;J```M````9.H``#$```"2Z@``+@```,3J```O````\^H``"P`
M```CZP``8@```%#K```3````L^L```@```#'ZP``"````-#K```K````V>L`
M`"$````%[```&````"?L```:````0.P```D```!;[```10```&7L``!!````
MJ^P```0```#M[```$P```/+L```4````!NT```X````;[0``$P```"KM```8
M````/NT```8```!7[0``"0```%[M```*````:.T```\```!S[0``$````(/M
M```'````E.T```X```"<[0``!0```*OM```;````L>T```@```#-[0``!@``
M`-;M```4````W>T``!$```#R[0``&`````3N```.````'>X``#@````L[@``
M`@```&7N```&````:.X```X```!O[@``$````'[N```%````C^X```<```"5
M[@``#@```)WN```&````K.X```0```"S[@``*0```+CN```7````XNX``!\`
M``#Z[@``7````!KO```4````=^\``#X```",[P``'P```,OO```0````Z^\`
M``<```#\[P``#@````3P```,````$_````P````@\```$P```"WP```*````
M0?```!T```!,\```&0```&KP```%````A/```!$```"*\```#0```)SP```1
M````JO```"0```"\\```%0```.'P```2````]_````X````*\0``&0```!GQ
M```(````,_$```D````\\0``#0```$;Q```*````5/$```<```!?\0``#P``
M`&?Q```+````=_$```H```"#\0``!P```([Q```(````EO$```4```"?\0``
M'P```*7Q```&````Q?$``!````#,\0``"````-WQ```-````YO$```@```#T
M\0``$@```/WQ```L````$/(``!H````]\@``"0```%CR```*````8O(``!4`
M``!M\@``!0```(/R```4````B?(```0```">\@``$````*/R```&````M/(`
M``<```"[\@``'@```,/R```H````XO(```H````+\P``$0```!;S```1````
M*/,``!H````Z\P``%````%7S```$````:O,```0```!O\P``"P```'3S```%
M````@/,```8```"&\P``$0```(WS```(````G_,```8```"H\P``"@```*_S
M```;````NO,``#0```#6\P``-`````OT```@````0/0``"D```!A]```(```
M`(OT``!!````K/0``!H```#N]```*`````GU```I````,O4``"(```!<]0``
M!@```'_U```(````AO4```4```"/]0``"````)7U```9````GO4``!D```"X
M]0``*@```-+U```C````_?4``"X````A]@``-````%#V```(````A?8``!<`
M``".]@``"@```*;V```'````L?8``"$```"Y]@``$````-OV```.````[/8`
M`!0```#[]@``"P```!#W```'````'/<``!,````D]P``"````#CW```+````
M0?<```H```!-]P``%````%CW```R````;?<```L```"@]P``!0```*SW```%
M````LO<``!4```"X]P``#````,[W```7````V_<```\```#S]P``!`````/X
M```*````"/@```D````3^```"P```!WX```-````*?@```P````W^```#@``
M`$3X```%````4_@```0```!9^```%````%[X```-````<_@``#(```"!^```
M10```+3X```2````^O@``!<````-^0``'@```"7Y```4````1/D```4```!9
M^0``%````%_Y```'````=/D```X```!\^0``*@```(OY```&````MOD```P`
M``"]^0``#0```,KY```1````V/D``!4```#J^0``"P````#Z```V````#/H`
M``H```!#^@``(@```$[Z```+````<?H```\```!]^@``,@```(WZ```;````
MP/H```X```#<^@``!0```.OZ```.````\?H``!,`````^P``$0```!3[```'
M````)OL``!$````N^P``!P```$#[```4````2/L``!@```!=^P``!P```';[
M```%````?OL```P```"$^P``#````)'[```2````GOL```0```"Q^P``!P``
M`+;[```*````OOL```L```#)^P``#````-7[```.````XOL```X```#Q^P``
M!0````#\```%````!OP``"X````,_```)@```#O\```C````8OP```,```"&
M_```$@```(K\```&````G?P``!X```"D_```&````,/\```9````W/P``"4`
M``#V_```#0```!S]```)````*OT```,````T_0``&````#C]```'````4?T`
M``H```!9_0```@```&3]```,````9_T``!4```!T_0``"P```(K]```9````
MEOT``"````"P_0``$@```-']```%````Y/T```H```#J_0``%0```/7]```2
M````"_X```P````>_@``!````"O^```'````,/X```P````X_@``4@```$7^
M```7````F/X```<```"P_@``!@```+C^```.````O_X```T```#._@``$0``
M`-S^```,````[OX```P```#[_@``#0````C_```5````%O\``!(````L_P``
M#P```#__```4````3_\``!L```!D_P``$````(#_```G````D?\``"4```"Y
M_P``:0```-__```:````20`!`!<```!D``$`&0```'P``0`:````E@`!`"4`
M``"Q``$`*````-<``0`G``````$!`!H````H`0$`%P```$,!`0`;````6P$!
M`#0```!W`0$`)0```*P!`0`9````T@$!`!\```#L`0$`$P````P"`0`(````
M(`(!``<````I`@$`"````#$"`0`)````.@(!`!4```!$`@$`#0```%H"`0`3
M````:`(!``,```!\`@$`1@```(`"`0`_````QP(!`#<````'`P$`5P```#\#
M`0`%````EP,!`!\```"=`P$`+P```+T#`0`*````[0,!`!````#X`P$`"```
M``D$`0`-````$@0!`"T````@!`$`!````$X$`0`(````4P0!``T```!<!`$`
M"@```&H$`0!/````=00!`"4```#%!`$`'````.L$`0`+````"`4!`!\````4
M!0$`'0```#0%`0`E````4@4!`"````!X!0$`)````)D%`0`@````O@4!``L`
M``#?!0$`!P```.L%`0`-````\P4!``P````!!@$`%P````X&`0`&````)@8!
M`#D````M!@$`#````&<&`0`'````=`8!``D```!\!@$`$P```(8&`0`)````
MF@8!``0```"D!@$`$````*D&`0`(````N@8!``@```##!@$`!````,P&`0`+
M````T08!``P```#=!@$`$@```.H&`0`1````_08!``P````/!P$`&@```!P'
M`0`/````-P<!``<```!'!P$`#0```$\'`0`.````70<!`!0```!L!P$`#@``
M`($'`0`'````D`<!``P```"8!P$`&P```*4'`0`L````P0<!`!,```#N!P$`
M'`````((`0`H````'P@!``8```!("`$`!P```$\(`0`3````5P@!``4```!K
M"`$`!````'$(`0`7````=@@!`#D```"."`$`"@```,@(`0`,````TP@!``D`
M``#@"`$`!@```.H(`0`)````\0@!``@```#["`$`"0````0)`0`*````#@D!
M`!$````9"0$`!@```"L)`0`.````,@D!``X```!!"0$`#0```%`)`0`+````
M7@D!`!T```!J"0$`"P```(@)`0`"````E`D!``<```"7"0$`!@```)\)`0`)
M````I@D!``<```"P"0$`&P```+@)`0`[````U`D!`"@````0"@$`-````#D*
M`0`5````;@H!``4```"$"@$`!P```(H*`0`(````D@H!``<```";"@$`!0``
M`*,*`0`'````J0H!``X```"Q"@$`"0```,`*`0`&````R@H!``@```#1"@$`
M"P```-H*`0`'````Y@H!``@```#N"@$`!P```/<*`0`6````_PH!``D````6
M"P$`!@```"`+`0`+````)PL!`!P````S"P$`%````%`+`0`'````90L!``@`
M``!M"P$``P```'8+`0`(````>@L!`!0```"#"P$`!0```)@+`0`0````G@L!
M`!````"O"P$`!@```,`+`0`9````QPL!``H```#A"P$`'````.P+`0`'````
M"0P!``4````1#`$`$````!<,`0`4````*`P!``L````]#`$`#0```$D,`0`7
M````5PP!``0```!O#`$`"0```'0,`0`*````?@P!``<```")#`$``@```)$,
M`0`.````E`P!``@```"C#`$`'P```*P,`0`C````S`P!`#@```#P#`$`,0``
M`"D-`0`G````6PT!`"@```"##0$`9````*P-`0`4````$0X!`%4````F#@$`
M.````'P.`0`I````M0X!`$H```#?#@$`6P```"H/`0`H````A@\!`#@```"O
M#P$`*````.@/`0`L````$1`!`"<````^$`$`&P```&80`0`^````@A`!`*D!
M``#!$`$`(P```&L2`0`7````CQ(!`$@```"G$@$`A0```/`2`0`P````=A,!
M`$$```"G$P$`6P```.D3`0!)````110!`!T```"/%`$`&````*T4`0`A````
MQA0!`!\```#H%`$`*P````@5`0`A````-!4!`"<```!6%0$`'0```'X5`0`1
M````G!4!`#,```"N%0$`)0```.(5`0`G````"!8!`"8````P%@$`'P```%<6
M`0`P````=Q8!`,P```"H%@$`:0```'47`0`]````WQ<!`&4````=&`$`30``
M`(,8`0!>````T1@!`"<````P&0$`+````%@9`0`H````A1D!`"\```"N&0$`
M+@```-X9`0`I````#1H!`#`````W&@$`5````&@:`0!:````O1H!`$@````8
M&P$`2@```&$;`0`J````K!L!`"(```#7&P$`,@```/H;`0`O````+1P!`"P`
M``!='`$`+0```(H<`0!Q````N!P!`&\````J'0$`LP```)H=`0`7````3AX!
M`"4```!F'@$`,@```(P>`0`I````OQX!`#X```#I'@$`(@```"@?`0!2````
M2Q\!`"(```">'P$`)0```,$?`0`+````YQ\!`+$```#S'P$`10```*4@`0`A
M````ZR`!`#8````-(0$`,````$0A`0`E````=2$!`!P```";(0$`,0```+@A
M`0`'````ZB$!``<```#R(0$`!````/HA`0`-````_R$!``L````-(@$`#@``
M`!DB`0`+````*"(!``4````T(@$`$````#HB`0`"````2R(!`%D```!.(@$`
M!0```*@B`0`2````KB(!``0```#!(@$`!P```,8B`0`(````SB(!``4```#7
M(@$``P```-TB`0`0````X2(!``P```#R(@$`$P```/\B`0`-````$R,!``(`
M```A(P$`!P```"0C`0`&````+",!`!0````S(P$`#````$@C`0`8````52,!
M``8```!N(P$`$@```'4C`0`,````B",!``,```"5(P$`*@```)DC`0`$````
MQ",!``8```#)(P$`!P```-`C`0`?````V",!`#4```#X(P$`+@```"XD`0`O
M````720!`!<```"-)`$`(````*4D`0`;````QB0!`!@```#B)`$`)````/LD
M`0`?````("4!`!H```!`)0$`(````%LE`0`:````?"4!`#(```"7)0$`+P``
M`,HE`0`K````^B4!`!\````F)@$`(P```$8F`0`?````:B8!`!H```"*)@$`
M)0```*4F`0`F````RR8!`"4```#R)@$`)````!@G`0`8````/2<!`!T```!6
M)P$`)````'0G`0`8````F2<!`"(```"R)P$`)0```-4G`0`\````^R<!`!\`
M```X*`$`(P```%@H`0`?````?"@!`"````"<*`$`&@```+TH`0`8````V"@!
M`"8```#Q*`$`'@```!@I`0`I````-RD!`!X```!A*0$`"0```(`I`0`,````
MBBD!`!<```"7*0$`+P```*\I`0`D````WRD!``<````$*@$`#P````PJ`0`4
M````'"H!``X````Q*@$`#0```$`J`0`D````3BH!``4```!S*@$`!P```'DJ
M`0`B````@2H!`"4```"D*@$`'0```,HJ`0`:````Z"H!``<````#*P$`QP``
M``LK`0`+````TRL!`!4```#?*P$`!@```/4K`0`)````_"L!``L````&+`$`
M%P```!(L`0`&````*BP!`#,````Q+`$`$P```&4L`0`3````>2P!``<```"-
M+`$`#P```)4L`0`'````I2P!`#(```"M+`$`(0```.`L`0`3`````BT!``P`
M```6+0$`$0```",M`0`R````-2T!``@```!H+0$`"0```'$M`0`*````>RT!
M`!0```"&+0$`"@```)LM`0`=````IBT!``@```#$+0$`'P```,TM`0`(````
M[2T!`!H```#V+0$`!@```!$N`0`5````&"X!``<````N+@$`"````#8N`0`)
M````/RX!`#\```!)+@$`$@```(DN`0`'````G"X!``\```"D+@$`#@```+0N
M`0`0````PRX!``D```#4+@$`"0```-XN`0`(````Z"X!`!,```#Q+@$`!P``
M``4O`0`,````#2\!`!D````:+P$`"@```#0O`0`;````/R\!`!<```!;+P$`
M%````',O`0`*````B"\!``P```"3+P$`%P```*`O`0`$````N"\!`"H```"]
M+P$`$0```.@O`0`'````^B\!``(````",`$`$`````4P`0`8````%C`!``L`
M```O,`$``P```#LP`0`(````/S`!``L```!(,`$`!@```%0P`0`'````6S`!
M``T```!C,`$`"P```'$P`0`4````?3`!`!4```"2,`$`#@```*@P`0`O````
MMS`!`"````#G,`$`'`````@Q`0`,````)3$!`#$````R,0$`!0```&0Q`0`2
M````:C$!`#\```!],0$`$@```+TQ`0`*````T#$!``8```#;,0$`!````.(Q
M`0`$````YS$!``H```#L,0$`$P```/<Q`0`%````"S(!``8````1,@$`!@``
M`!@R`0`$````'S(!``P````D,@$`"0```#$R`0`,````.S(!``H```!(,@$`
M$````%,R`0`3````9#(!`!,```!X,@$`!0```(PR`0`8````DC(!`!D```"K
M,@$`'P```,4R`0`=````Y3(!`!$````#,P$``@```!4S`0`$````&#,!``H`
M```=,P$`!@```"@S`0`%````+S,!``,````U,P$`#````#DS`0!%````1C,!
M`!H```",,P$`-0```*<S`0`H````W3,!`%,````&-`$`,````%HT`0`O````
MBS0!`!D```"[-`$`<@```-4T`0`@````2#4!`#4```!I-0$`(0```)\U`0!%
M````P34!`#`````'-@$`)@```#@V`0`>````7S8!`"@```!^-@$`*0```*<V
M`0`I````T38!`"8```#[-@$`)0```"(W`0`H````2#<!`"@```!Q-P$`(@``
M`)HW`0`N````O3<!`#````#L-P$`$@```!TX`0`3````,#@!`!````!$.`$`
M>0```%4X`0`)````SS@!`',```#9.`$`?````$TY`0`K````RCD!`!<```#V
M.0$`%@````XZ`0`/````)3H!`!\````U.@$`0````%4Z`0`?````ECH!`!P`
M``"V.@$`40```-,Z`0`4````)3L!``H````Z.P$`!0```$4[`0`&````2SL!
M``@```!2.P$`!0```%L[`0`2````83L!`!````!T.P$`$P```(4[`0`=````
MF3L!``\```"W.P$`"@```,<[`0`/````TCL!``<```#B.P$`!````.H[`0`)
M````[SL!``<```#Y.P$`"P````$\`0`'````#3P!``4````5/`$`%````!L\
M`0`.````,#P!``<````_/`$`"````$<\`0`/````4#P!``@```!@/`$`#```
M`&D\`0`/````=CP!`!8```"&/`$`!P```)T\`0`&````I3P!`!0```"L/`$`
M!@```,$\`0`,````R#P!``@```#5/`$`!````-X\`0`*````XSP!``L```#N
M/`$`#````/H\`0`,````!ST!``<````4/0$`!````!P]`0`9````(3T!``(`
M```[/0$`"0```#X]`0`&````2#T!``8```!//0$`)P```%8]`0`$````?CT!
M``\```"#/0$`$P```),]`0`'````IST!``<```"O/0$`!@```+<]`0`&````
MOCT!`!````#%/0$`$@```-8]`0`&````Z3T!``D```#P/0$`(@```/H]`0`'
M````'3X!``<````E/@$`"P```"T^`0`%````.3X!``(````_/@$`"P```$(^
M`0#*`0``3CX!``X````90`$`%0```"A``0`-````/D`!``<```!,0`$`"```
M`%1``0`(````74`!``H```!F0`$`)````'%``0`G````ED`!``H```"^0`$`
M$@```,E``0`-````W$`!``@```#J0`$`!0```/-``0`=````^4`!``P````7
M00$`#0```"1!`0`5````,D$!``H```!(00$`$````%-!`0`+````9$$!`"``
M``!P00$`$````)%!`0`(````HD$!`!,```"K00$`#0```+]!`0`+````S4$!
M``L```#900$`#P```.5!`0`&````]4$!`!````#\00$`%@````U"`0`+````
M)$(!`!(````P0@$`$@```$-"`0`(````5D(!`"X```!?0@$`+0```(Y"`0`9
M````O$(!`#@```#60@$`00````]#`0!3````44,!`%$```"E0P$`60```/=#
M`0!7````440!`#L```"I1`$`"@```.5$`0`.````\$0!`!8```#_1`$`!0``
M`!9%`0`&````'$4!`!D````C10$`#````#U%`0`E````2D4!`!0```!P10$`
M%P```(5%`0`G````G44!`"8```#%10$`$0```.Q%`0`?````_D4!``\````>
M1@$`!@```"Y&`0`1````-48!`!````!'1@$`!P```%A&`0`4````8$8!`!$`
M``!U1@$`&````(=&`0`.````H$8!`!$```"O1@$`"@```,%&`0`I````S$8!
M``D```#V1@$`$P````!'`0`7````%$<!`!`````L1P$`(P```#U'`0`&````
M84<!``X```!H1P$`$````'='`0`>````B$<!`$H```"G1P$`#````/)'`0`(
M````_T<!`!4````(2`$`"P```!Y(`0`'````*D@!``@````R2`$`!0```#M(
M`0`(````04@!``H```!*2`$``P```%5(`0`9````64@!``\```!S2`$`&0``
M`(-(`0`4````G4@!`!(```"R2`$`*````,5(`0`,````[D@!``P```#[2`$`
M)P````A)`0`7````,$D!`",```!(20$`'0```&Q)`0`2````BDD!`!(```"=
M20$`#@```+!)`0`?````OTD!``8```#?20$`!@```.9)`0`(````[4D!``X`
M``#V20$`!P````5*`0`*````#4H!`!$````82@$`"````"I*`0`/````,TH!
M`!8```!#2@$`&@```%I*`0`(````=4H!`!(```!^2@$`!0```)%*`0`6````
METH!`!X```"N2@$`#0```,U*`0`C````VTH!`#````#_2@$`,````#!+`0`)
M````84L!``<```!K2P$`%````'-+`0`%````B$L!``4```".2P$`"0```)1+
M`0`0````GDL!``L```"O2P$`&@```+M+`0`S````UDL!``\````*3`$`)@``
M`!I,`0`S````04P!`#$```!U3`$`,````*=,`0`(````V$P!``4```#A3`$`
M"0```.=,`0`(````\4P!`#D```#Z3`$`+0```#1-`0`X````8DT!`%,```";
M30$`-P```.]-`0`W````)TX!`#8```!?3@$`-P```)9.`0`E````SDX!`"H`
M``#T3@$`-P```!]/`0`]````5T\!``\```"53P$`$P```*5/`0`G````N4\!
M`!P```#A3P$`#@```/Y/`0`+````#5`!``P````94`$`!@```"90`0`,````
M+5`!`!H````Z4`$`)@```%50`0`&````?%`!``<```"#4`$`%@```(M0`0`)
M````HE`!``@```"L4`$`!@```+50`0`(````O%`!``D```#%4`$`!@```,]0
M`0`%````UE`!`!X```#<4`$`!0```/M0`0`'`````5$!``8````)40$`&```
M`!!1`0`*````*5$!`"4````T40$`#P```%I1`0`)````:E$!``4```!T40$`
M!P```'I1`0`'````@E$!``4```"*40$`#0```)!1`0`&````GE$!`!,```"E
M40$``P```+E1`0`(````O5$!``H```#&40$`#0```-%1`0`(````WU$!`",`
M``#H40$`$0````Q2`0`)````'E(!`!(````H4@$`#````#M2`0`'````2%(!
M`!(```!04@$``P```&-2`0`#````9U(!`!0```!K4@$``P```(!2`0`4````
MA%(!``@```"94@$`"````*)2`0`(````JU(!``<```"T4@$`5P```+Q2`0`D
M````%%,!``8````Y4P$`!@```$!3`0`7````1U,!`!H```!?4P$`'````'I3
M`0`L````EU,!`!L```#$4P$`+@```.!3`0!R````#U0!`"4```""5`$`"@``
M`*A4`0`'````LU0!`!(```"[5`$`$0```,Y4`0`/````X%0!``X```#P5`$`
M%````/]4`0`0````%%4!`!0````E50$`#P```#I5`0`5````2E4!``4```!@
M50$`%P```&95`0`;````?E4!`!<```":50$`%````+)5`0`#````QU4!``8`
M``#+50$`:````-)5`0`$````.U8!`!8```!`5@$`$0```%=6`0`%````:58!
M``0```!O5@$`'@```'16`0`8````DU8!``P```"L5@$`&````+E6`0`/````
MTE8!`!@```#B5@$`+0```/M6`0`.````*5<!`"(````X5P$`"````%M7`0`:
M````9%<!`!@```!_5P$`$P```)A7`0`<````K%<!`!@```#)5P$`%````.)7
M`0`+````]U<!``@````#6`$`!P````Q8`0`0````%%@!`!4````E6`$`$```
M`#M8`0`(````3%@!``4```!56`$`"P```%M8`0`,````9U@!``@```!T6`$`
M$````'U8`0`-````CE@!``<```"<6`$`%P```*18`0`K````O%@!``8```#H
M6`$`$0```.]8`0`(`````5D!``P````*60$`!P```!=9`0`%````'UD!``P`
M```E60$`"````#)9`0`(````.UD!`!,```!$60$`"P```%A9`0`.````9%D!
M``4```!S60$`'0```'E9`0`0````EUD!`!$```"H60$`$P```+I9`0`/````
MSED!`#0```#>60$`1````!-:`0`?````6%H!`"$```!X6@$`%@```)I:`0`Q
M````L5H!``H```#C6@$`#P```.Y:`0`'````_EH!``D````&6P$`#P```!!;
M`0`)````(%L!`!$````J6P$`(0```#Q;`0`A````7EL!`"0```"`6P$`)```
M`*5;`0`8````REL!`"$```#C6P$`&P````5<`0`E````(5P!`!H```!'7`$`
M'0```&)<`0`8````@%P!`",```"97`$`*0```+U<`0`;````YUP!`"8````#
M70$`,````"I=`0`N````6UT!`!$```"*70$`*0```)Q=`0`.````QET!`+``
M``#570$`$````(9>`0`8````EUX!`",```"P7@$`)````-1>`0`?````^5X!
M`!L````97P$`(````#5?`0`A````5E\!`"X```!X7P$`'````*=?`0`>````
MQ%\!`"D```#C7P$`2P````U@`0`/````66`!``0```!I8`$`$@```&Y@`0`.
M````@6`!``X```"08`$`$@```)]@`0`)````LF`!``L```"\8`$`%````,A@
M`0`*````W6`!``0```#H8`$`#````.U@`0`/````^F`!``\````*80$`$P``
M`!IA`0`,````+F$!`#$````[80$`"P```&UA`0`1````>6$!``0```"+80$`
M#P```)!A`0`5````H&$!`!@```"V80$`#P```,]A`0`"````WV$!``4```#B
M80$`$@```.AA`0`%````^V$!``L````!8@$`#`````UB`0`#````&F(!``\`
M```>8@$`"````"YB`0`8````-V(!`!````!08@$`"@```&%B`0`0````;&(!
M`!,```!]8@$`&````)%B`0`(````JF(!``8```"S8@$`$0```+IB`0`.````
MS&(!``P```#;8@$`&````.AB`0`?`````6,!``P````A8P$`#@```"YC`0`C
M````/6,!`!@```!A8P$`#````'IC`0`>````AV,!`!<```"F8P$`%0```+YC
M`0`/````U&,!``P```#D8P$`!@```/%C`0`(````^&,!``@````!9`$`#@``
M``ID`0`G````&60!`#\```!!9`$`!0```(%D`0`)````AV0!`!X```"19`$`
M"P```+!D`0`3````O&0!`!,```#09`$`!P```.1D`0`9````[&0!`!$````&
M90$`&````!AE`0`0````,64!`!4```!"90$`"````%AE`0`(````864!`"8`
M``!J90$`(````)%E`0!(````LF4!``@```#[90$`%@````1F`0`*````&V8!
M`#$````F9@$`#@```%AF`0`/````9V8!``4```!W9@$`!@```'UF`0`#````
MA&8!``<```"(9@$`!P```)!F`0`,````F&8!``\```"E9@$`#0```+5F`0`-
M````PV8!`!0```#19@$`%@```.9F`0`5````_68!`!0````39P$`!0```"AG
M`0`%````+F<!``L````T9P$`"````$!G`0`"````26<!``4```!,9P$`#P``
M`%)G`0`A````8F<!`!(```"$9P$`$````)=G`0`/````J&<!`!$```"X9P$`
M'@```,IG`0`Q````Z6<!`"T````;:`$`"@```$EH`0`.````5&@!`(L```!C
M:`$`%@```.]H`0`B````!FD!`!`````I:0$`!P```#II`0`%````0FD!`"$`
M``!(:0$`"````&II`0`'````<VD!``<```![:0$`!@```(-I`0`0````BFD!
M``X```";:0$`$0```*II`0`/````O&D!`!L```#,:0$`$0```.AI`0`-````
M^FD!`!<````(:@$`!P```"!J`0`)````*&H!`!0````R:@$`#0```$=J`0`[
M````56H!`!D```"1:@$`"````*MJ`0`*````M&H!`!(```"_:@$`(@```-)J
M`0`I````]6H!``T````?:P$`'0```"UK`0`9````2VL!`!\```!E:P$`'```
M`(5K`0`8````HFL!`!D```"[:P$`1````-5K`0`A````&FP!`"`````\;`$`
M&@```%UL`0`;````>&P!`"4```"4;`$`(0```+IL`0`:````W&P!`!P```#W
M;`$`!0```!1M`0`=````&FT!`!`````X;0$`#@```$EM`0`#````6&T!``0`
M``!<;0$`#0```&%M`0`.````;VT!``\```!^;0$`%P```(YM`0`+````IFT!
M``0```"R;0$`&````+=M`0`9````T&T!``\```#J;0$`#0```/IM`0`-````
M"&X!``X````6;@$`'P```"5N`0`&````16X!``8```!,;@$`!@```%-N`0`.
M````6FX!``4```!I;@$`#@```&]N`0`-````?FX!``@```",;@$`"````)5N
M`0`$````GFX!`!0```"C;@$`"P```+AN`0`%````Q&X!`"0```#*;@$`#P``
M`.]N`0!K````_VX!`!H```!K;P$`"0```(9O`0`&````D&\!``H```"7;P$`
M!@```*)O`0`(````J6\!``0```"R;P$`"@```+=O`0`"````PF\!``0```#%
M;P$`!P```,IO`0`5````TF\!``T```#H;P$`$@```/9O`0`4````"7`!`!H`
M```><`$``@```#EP`0`"````/'`!``X````_<`$`!@```$YP`0`*````57`!
M``4```!@<`$`&0```&9P`0`(````@'`!``8```")<`$`%P```)!P`0`0````
MJ'`!``D```"Y<`$`!P```,-P`0`%````RW`!``D```#1<`$`#0```-MP`0`0
M````Z7`!``8```#Z<`$`!@````%Q`0`9````"'$!``L````B<0$`!0```"YQ
M`0`2````-'$!``<```!'<0$`!P```$]Q`0`'````5W$!`!@```!?<0$`'0``
M`'AQ`0`'````EG$!``H```"><0$`!````*EQ`0`)````KG$!``@```"X<0$`
M"P```,%Q`0`+````S7$!``8```#9<0$`#0```.!Q`0`&````[G$!``0```#U
M<0$`-P```/IQ`0!!````,G(!`#@```!T<@$`)@```*UR`0`%````U'(!``\`
M``#:<@$`!@```.IR`0`(````\7(!`!\```#Z<@$`&@```!IS`0`%````-7,!
M``@````[<P$`$P```$1S`0`(````6',!``D```!A<P$`%P```&MS`0`&````
M@W,!``8```"*<P$`%0```)%S`0`%````IW,!``L```"M<P$`$0```+ES`0`0
M````RW,!``P```#<<P$`"````.ES`0`:````\G,!`!$````-=`$`"````!]T
M`0`)````*'0!``4````R=`$`+@```#AT`0`T````9W0!`#P```"<=`$`)P``
M`-ET`0`^`````74!`#@```!`=0$`*````'EU`0`R````HG4!`"T```#5=0$`
M-0````-V`0`H````.78!`!(```!B=@$`$P```'5V`0`-````B78!`#$```"7
M=@$`'````,EV`0`<````YG8!`!H````#=P$`!P```!YW`0`(````)G<!``<`
M```O=P$`"````#=W`0`F````0'<!`"0```!G=P$`,0```(QW`0`$````OG<!
M``D```##=P$`&````,UW`0`H````YG<!`!8````/>`$`$@```"9X`0`&````
M.7@!``L```!`>`$`#````$QX`0`.````67@!``\```!H>`$`.````'AX`0"`
M````L7@!`&8````R>0$`#P```)EY`0`+````J7D!``P```"U>0$`$0```,)Y
M`0`2````U'D!``X```#G>0$`!P```/9Y`0`;````_GD!``\````:>@$`'@``
M`"IZ`0`4````27H!`!$```!>>@$`#P```'!Z`0`>````@'H!`#````"?>@$`
M?0```-!Z`0`0````3GL!``4```!?>P$`%````&5[`0`)````>GL!``D```"$
M>P$`"0```(Y[`0`2````F'L!``X```"K>P$`#@```+I[`0`3````R7L!`!4`
M``#=>P$`'P```/-[`0`A````$WP!`!T````U?`$`'P```%-\`0`@````<WP!
M`"(```"4?`$`&````+=\`0`W````T'P!``\````(?0$`$0```!A]`0`1````
M*GT!`!,````\?0$`#0```%!]`0`2````7GT!`!0```!Q?0$`#P```(9]`0`1
M````EGT!`#(```"H?0$`%@```-M]`0`4````\GT!`#P````'?@$`%````$1^
M`0`*````67X!`!,```!D?@$`"P```'A^`0`B````A'X!`!````"G?@$`$@``
M`+A^`0`H````RWX!`!D```#T?@$`&0````Y_`0`.````*'\!`!`````W?P$`
M%P```$A_`0`<````8'\!`!(```!]?P$`#@```)!_`0`3````GW\!`!\```"S
M?P$`(@```--_`0`:````]G\!`!(````1@`$`%P```"2``0`<````/(`!`!8`
M``!9@`$`"````'"``0`8````>8`!``0```"2@`$`!0```)>``0`+````G8`!
M`!````"I@`$`!@```+J``0`,````P8`!``<```#.@`$`!@```-:``0`'````
MW8`!``4```#E@`$`"````.N``0`8````](`!``8````-@0$`"0```!2!`0`(
M````'H$!``8````G@0$`"````"Z!`0`1````-X$!`!(```!)@0$`#P```%R!
M`0`0````;($!``H```!]@0$`$0```(B!`0`$````FH$!`"$```"?@0$`#P``
M`,&!`0`/````T8$!`!8```#A@0$`"P```/B!`0`)````!((!``L````.@@$`
M+P```!J"`0`$````2H(!``@```!/@@$`!````%B"`0`%````78(!`!$```!C
M@@$`!@```'6"`0`*````?((!`$(```"'@@$`"@```,J"`0`%````U8(!`",`
M``#;@@$`#@```/^"`0`1````#H,!``@````@@P$`$0```"F#`0`5````.X,!
M`!<```!1@P$`'````&F#`0`:````AH,!``4```"A@P$`!0```*>#`0`)````
MK8,!`!D```"W@P$`!P```-&#`0`&````V8,!``T```#@@P$`#@```.Z#`0`'
M````_8,!``<````%A`$`!0````V$`0`/````$X0!``X````CA`$`"@```#*$
M`0`0````/80!`!(```!.A`$`%````&&$`0`4````=H0!``T```"+A`$`%@``
M`)F$`0`(````L(0!``4```"YA`$`$@```+^$`0!(````TH0!``8````;A0$`
M#P```"*%`0`&````,H4!`",````YA0$`#P```%V%`0`5````;84!``X```"#
MA0$`#0```)*%`0`/````H(4!``D```"PA0$`#P```+J%`0`/````RH4!`!$`
M``#:A0$`$````.R%`0`>````_84!``H````<A@$`"````">&`0`,````,(8!
M``P````]A@$`#````$J&`0`%````5X8!``P```!=A@$`"0```&J&`0`>````
M=(8!`&<```"3A@$`$P```/N&`0`+````#X<!``4````;AP$`!0```"&'`0`2
M````)X<!`!0````ZAP$`$P```$^'`0`+````8X<!``(```!OAP$`"@```'*'
M`0`O````?8<!``,```"MAP$`!0```+&'`0`F````MX<!``H```#>AP$`!0``
M`.F'`0`%````[X<!`!,```#UAP$`$@````F(`0`&````'(@!``@````CB`$`
M!P```"R(`0`$````-(@!``4````YB`$`;@```#^(`0`*````KH@!``T```"Y
MB`$`!@```,>(`0`%````SH@!`"D```#4B`$`,@```/Z(`0`1````,8D!``H`
M``!#B0$`#@```$Z)`0`1````78D!``H```!OB0$`"0```'J)`0`9````A(D!
M`"<```">B0$`*0```,:)`0`H````\(D!``\````9B@$`%P```"F*`0`&````
M08H!``<```!(B@$`"````%"*`0`'````68H!``X```!AB@$`#````'"*`0`&
M````?8H!`$4```"$B@$`$````,J*`0`*````VXH!``8```#FB@$`'````.V*
M`0!A````"HL!``8```!LBP$`"````'.+`0`&````?(L!`!0```"#BP$`"0``
M`)B+`0`(````HHL!`"D```"KBP$`*````-6+`0`0````_HL!``D````/C`$`
M!0```!F,`0`G````'XP!`"L```!'C`$`9P```'.,`0`I````VXP!`"X````%
MC0$`&````#2-`0`"````38T!``T```!0C0$`#P```%Z-`0`%````;HT!`!0`
M``!TC0$`"@```(F-`0`7````E(T!``4```"LC0$`"````+*-`0`&````NXT!
M``D```#"C0$`"P```,R-`0`'````V(T!``@```#@C0$`"P```.F-`0`@````
M]8T!``8````6C@$`#@```!V.`0`0````+(X!`!$````]C@$`"0```$^.`0`-
M````68X!``\```!GC@$`$````'>.`0`/````B(X!``T```"8C@$`#P```*:.
M`0`0````MHX!``\```#'C@$`"````->.`0`0````X(X!`!X```#QC@$`/0``
M`!"/`0`3````3H\!``@```!BCP$`"@```&N/`0`6````=H\!``<```"-CP$`
M#P```)6/`0`%````I8\!``P```"KCP$`!P```+B/`0`%````P(\!``4```#&
MCP$`&@```,R/`0`(````YX\!`!$```#PCP$`$0````*0`0`:````%)`!`!8`
M```OD`$`%````$:0`0`7````6Y`!`!H```!SD`$`'P```(Z0`0`8````KI`!
M``,```#'D`$`!0```,N0`0`.````T9`!``X```#@D`$`#````.^0`0`6````
M_)`!`"(````3D0$`"P```#:1`0`4````0I$!``<```!7D0$`"@```%^1`0`%
M````:I$!``X```!PD0$`"0```'^1`0`/````B9$!``4```"9D0$`!P```)^1
M`0`#````IY$!``0```"KD0$``@```+"1`0`G````LY$!`!P```#;D0$`/@``
M`/B1`0`T````-Y(!`!0```!LD@$`*@```(&2`0!%````K)(!``H```#RD@$`
M+````/V2`0`S````*I,!`#@```!>DP$`.````)>3`0`]````T),!`!\````.
ME`$`%````"Z4`0`:````0Y0!`!L```!>E`$`'````'J4`0`;````EY0!`!\`
M``"SE`$`&P```-.4`0`;````[Y0!``X````+E0$`,````!J5`0`P````2Y4!
M`#0```!\E0$`/0```+&5`0`R````[Y4!`"\````BE@$`<@```%*6`0`F````
MQ98!``P```#LE@$`"@```/F6`0`S````!)<!`#4````XEP$`(0```&Z7`0`G
M````D)<!``T```"XEP$`1````,:7`0`_````"Y@!``4```!+F`$`&P```%&8
M`0`6````;9@!`!(```"$F`$`$0```)>8`0`9````J9@!``8```##F`$`!P``
M`,J8`0`)````TI@!``X```#<F`$`%````.N8`0`.`````)D!`!$````/F0$`
M"````"&9`0`>````*ID!``@```!)F0$`!0```%*9`0`+````6)D!``T```!D
MF0$`&````'*9`0`+````BYD!`#H```"7F0$``@```-*9`0`&````U9D!``X`
M``#<F0$`%````.N9`0`)`````)H!``4````*F@$`$@```!":`0`(````(YH!
M``0````LF@$`,P```#&:`0`.````99H!`"D```!TF@$`4````)Z:`0`5````
M[YH!`#H````%FP$`(````$";`0`/````89L!``@```!QFP$`#P```'J;`0`/
M````BIL!``H```":FP$`%````*6;`0`,````NIL!`!H```#'FP$`%0```.*;
M`0`'````^)L!`!$`````G`$`#@```!*<`0`1````(9P!`"$````SG`$`%```
M`%6<`0`2````:IP!`!````!]G`$`(P```(Z<`0`'````LIP!``L```"ZG`$`
M%````,:<`0`2````VYP!`!$```#NG`$`&@````"=`0`0````&YT!``P````L
MG0$`!P```#F=`0`(````09T!``4```!*G0$`(0```%"=`0`&````<IT!`!$`
M``!YG0$`"````(N=`0`.````E)T!``4```"CG0$`#P```*F=`0`O````N9T!
M`!(```#IG0$`!@```/R=`0`'`````YX!`!<````+G@$`!@```".>`0`2````
M*IX!``4````]G@$`%0```$.>`0`$````69X!``<```!>G@$`%@```&:>`0`Q
M````?9X!``4```"OG@$`$@```+6>`0`2````R)X!`!,```#;G@$`$````.^>
M`0`$`````)\!``X````%GP$`"````!2?`0`'````'9\!``H````EGP$`#```
M`#"?`0`(````/9\!``8```!&GP$`!0```$V?`0`@````4Y\!`#4```!TGP$`
M-0```*J?`0`;````X)\!`"0```#\GP$`(P```"&@`0`_````1:`!`!L```"%
MH`$`)@```*&@`0`M````R*`!`"0```#VH`$`!@```!NA`0`(````(J$!``D`
M```KH0$`"P```#6A`0`7````0:$!`!````!9H0$`+@```&JA`0`D````F:$!
M`#0```"^H0$`.````/.A`0`1````+*(!`"(````^H@$`$@```&&B`0`&````
M=*(!`!L```![H@$`$@```)>B`0`1````JJ(!``X```"\H@$`#0```,NB`0`'
M````V:(!``X```#AH@$`"````/"B`0`+````^:(!``P````%HP$`&P```!*C
M`0`T````+J,!``D```!CHP$`!0```&VC`0`)````<Z,!`!P```!]HP$`$@``
M`)JC`0`:````K:,!`!$```#(HP$`!````-JC`0`*````WZ,!``L```#JHP$`
M$````/:C`0`.````!Z0!``P````6I`$`%@```".D`0`%````.J0!``4```!`
MI`$`%@```$:D`0`/````7:0!`"P```!MI`$`2P```)JD`0`2````YJ0!`!8`
M``#YI`$`'0```!"E`0`:````+J4!``4```!)I0$`$````$^E`0`'````8*4!
M`!$```!HI0$`+````'JE`0`)````IZ4!``X```"QI0$`$0```,"E`0`5````
MTJ4!`!0```#HI0$`#0```/VE`0`Y````"Z8!``D```!%I@$`'0```$^F`0`3
M````;:8!`!<```"!I@$`+P```)FF`0`@````R:8!``\```#JI@$`$0```/JF
M`0`7````#*<!`!X````DIP$`(P```$.G`0`(````9Z<!`!(```!PIP$`!P``
M`(.G`0`4````BZ<!`!H```"@IP$`!P```+NG`0`'````PZ<!`!````#+IP$`
M#P```-RG`0`1````[*<!``4```#^IP$`"`````2H`0`-````#:@!``T````;
MJ`$`#@```"FH`0`0````.*@!`!````!)J`$`!@```%JH`0`(````8:@!`"X`
M``!JJ`$`)@```)FH`0`D````P*@!``<```#EJ`$`#@```.VH`0`&````_*@!
M`!<````#J0$`%P```!NI`0`9````,ZD!`"(```!-J0$`"@```'"I`0`+````
M>ZD!``,```"'J0$`&0```(NI`0`&````I:D!``P```"LJ0$``@```+FI`0`,
M````O*D!`!,```#)J0$`"P```-VI`0`9````Z:D!`"`````#J@$`$@```"2J
M`0`%````-ZH!``H````]J@$`%0```$BJ`0`1````7JH!``X```!PJ@$`!@``
M`'^J`0`)````AJH!`!````"0J@$`2@```*&J`0`7````[*H!``0````$JP$`
M!@````FK`0`4````$*L!``\````EJP$`$P```#6K`0`-````2:L!``X```!7
MJP$`#````&:K`0`B````<ZL!`!<```"6JP$`#0```*ZK`0`C````O*L!`!P`
M``#@JP$`#0```/VK`0`N````"ZP!`"\````ZK`$`8@```&JL`0`B````S:P!
M`!8```#PK`$`%P````>M`0`=````'ZT!`"(````]K0$`'@```&"M`0`K````
M?ZT!`"````"KK0$`%````,RM`0`>````X:T!`#4`````K@$`'0```#:N`0`6
M````5*X!`!\```!KK@$`&````(NN`0`*````I*X!``<```"OK@$`!P```+>N
M`0`$````OZX!`!,```#$K@$`#0```-BN`0`1````YJX!``@```#XK@$`00``
M``&O`0`\````0Z\!`$(```"`KP$`8````,.O`0`)````)+`!`#X````NL`$`
M+P```&VP`0`*````G;`!``\```"HL`$`"@```+BP`0`.````P[`!`#L```#2
ML`$`"`````ZQ`0`,````%[$!`!$````DL0$`$````#:Q`0`X````1[$!`"X`
M``"`L0$`(@```*^Q`0`/````TK$!`"D```#BL0$`&`````RR`0`P````);(!
M`"(```!6L@$`*````'FR`0`B````HK(!``\```#%L@$`"````-6R`0`.````
MWK(!``\```#ML@$`$````/VR`0`'````#K,!`#T````6LP$`#````%2S`0`.
M````8;,!``8```!PLP$`%0```'>S`0`(````C;,!``@```"6LP$`#P```)^S
M`0`)````K[,!``D```"YLP$`!P```,.S`0`0````R[,!`!````#<LP$`%@``
M`.VS`0`7````!+0!`!$````<M`$`&P```"ZT`0`3````2K0!``@```!>M`$`
M#0```&>T`0`,````=;0!``P```""M`$`#P```(^T`0`&````G[0!``P```"F
MM`$`&0```+.T`0`L````S;0!``\```#ZM`$`'P````JU`0`H````*K4!``@`
M``!3M0$`!@```%RU`0`0````8[4!``D```!TM0$`!````'ZU`0`8````@[4!
M`$````"<M0$`#@```-VU`0`0````[+4!``X```#]M0$`!0````RV`0`)````
M$K8!``@````<M@$`"0```"6V`0`+````+[8!`!$````[M@$`!````$VV`0`.
M````4K8!``4```!AM@$`"P```&>V`0`.````<[8!`"$```""M@$`"@```*2V
M`0`"````K[8!``<```"RM@$`!0```+JV`0`+````P+8!``<```#,M@$`&```
M`-2V`0`R````[;8!`"0````@MP$`,0```$6W`0`7````=[<!``4```"/MP$`
M!P```)6W`0`'````G;<!``P```"EMP$`"````+*W`0`-````N[<!`!,```#)
MMP$`#P```-VW`0`,````[;<!``X```#ZMP$`"P````FX`0`'````%;@!``@`
M```=N`$`"````":X`0`6````+[@!``D```!&N`$`!P```%"X`0`)````6+@!
M`"````!BN`$`!0```(.X`0`&````B;@!``8```"0N`$``P```)>X`0`*````
MF[@!`!0```"FN`$`!P```+NX`0`2````P[@!`!(```#6N`$`!@```.FX`0`6
M````\+@!``L````'N0$`&P```!.Y`0`$````+[D!``4````TN0$`#P```#JY
M`0`<````2KD!``<```!GN0$`"0```&^Y`0`5````>;D!``0```"/N0$`"@``
M`)2Y`0`/````G[D!``H```"ON0$``@```+JY`0`1````O;D!``<```#/N0$`
M'@```->Y`0`>````]KD!`#,````5N@$`)0```$FZ`0`I````;[H!`!H```"9
MN@$`70```+2Z`0`3````$KL!`%0````FNP$`+@```'N[`0`>````JKL!`$$`
M``#)NP$`7@````N\`0`@````:KP!`$H```"+O`$`*````-:\`0`R````_[P!
M`",````RO0$`'0```%:]`0`L````=+T!`.X!``"AO0$`&P```)"_`0`4````
MK+\!`$8```#!OP$`A0````C``0`_````CL`!`#$```#.P`$`2P````#!`0`X
M````3,$!`!P```"%P0$`%0```*+!`0`8````N,$!`!<```#1P0$`*P```.G!
M`0`<````%<(!`!\````RP@$`$P```%+"`0`,````9L(!`"\```!SP@$`'@``
M`*/"`0`?````PL(!`"P```#BP@$`(0````_#`0!"````,<,!`,,```!TPP$`
M4````#C$`0`U````B<0!`&$```"_Q`$`1@```"'%`0!:````:,4!`"L```##
MQ0$`+````._%`0`H````',8!`"\```!%Q@$`)P```'7&`0`E````G<8!`"P`
M``##Q@$`1P```/#&`0!0````.,<!`$$```")QP$`3@```,O'`0`N````&L@!
M`!\```!)R`$`+0```&G(`0`E````E\@!`"4```"]R`$`)@```./(`0!J````
M"LD!`&@```!UR0$`K@```-[)`0`;````C<H!`"H```"IR@$`-@```-3*`0`O
M````"\L!`$4````[RP$`(````('+`0!1````HLL!`"(```#TRP$`(0```!?,
M`0`+````.<P!`+4```!%S`$`/````/O,`0`B````.,T!`#0```!;S0$`*@``
M`)#-`0`K````N\T!`!P```#GS0$`+P````3.`0`&````-,X!``8````[S@$`
M`P```$+.`0`.````1LX!``L```!5S@$`"@```&'.`0`+````;,X!``4```!X
MS@$`#````'[.`0`$````B\X!`&X```"0S@$`!````/_.`0`6````!,\!``0`
M```;SP$`!P```"#/`0`%````*,\!``4````NSP$`!````#3/`0`0````.<\!
M``@```!*SP$`$0```%//`0`3````9<\!``(```!YSP$`!P```'S/`0`'````
MA,\!`!0```",SP$`#````*'/`0`6````KL\!``8```#%SP$`$P```,S/`0`,
M````X,\!``,```#MSP$`*````/'/`0`$````&M`!``8````?T`$`"````";0
M`0`;````+]`!`#0```!+T`$`)P```(#0`0`H````J-`!`!,```#1T`$`(```
M`.70`0`=````!M$!`!L````DT0$`(````$#1`0`;````8=$!`!H```!]T0$`
M(@```)C1`0`4````N]$!`#$```#0T0$`+P````+2`0`F````,M(!`!H```!9
MT@$`'@```'32`0`>````D](!`!D```"RT@$`(P```,S2`0`=````\-(!`"@`
M```.TP$`'````#?3`0`;````5-,!`"````!PTP$`(P```)'3`0`9````M=,!
M`"$```#/TP$`'@```/'3`0`V````$-0!`!X```!'U`$`(@```&;4`0`B````
MB=0!`",```"LU`$`'0```-#4`0`8````[M0!`"(````'U0$`(0```"K5`0`R
M````3-4!`"````!_U0$`"@```*#5`0`+````J]4!`!8```"WU0$`*````,[5
M`0`=````]]4!``H````5U@$`#P```"#6`0`7````,-8!``X```!(U@$`%@``
M`%?6`0`A````;M8!``@```"0U@$`!P```)G6`0`B````H=8!`"4```#$U@$`
M)0```.K6`0`6````$-<!``H````GUP$`W````#+7`0`1````#]@!`!4````A
MV`$`#````#?8`0`/````1-@!`!8```!4V`$`(P```&O8`0`&````C]@!`$``
M``"6V`$`%0```-?8`0`4````[=@!``<````"V0$`$P````K9`0`*````'MD!
M`#<````IV0$`*0```&'9`0`6````B]D!`!0```"BV0$`%````+?9`0`Q````
MS-D!`!$```#^V0$`$@```!#:`0`3````(]H!`!$````WV@$`"@```$G:`0`7
M````5-H!``@```!LV@$`(````'7:`0`(````EMH!`!,```"?V@$`!P```+/:
M`0`1````N]H!``<```#-V@$`"````-7:`0`)````WMH!`#8```#HV@$`$@``
M`!_;`0`%````,ML!``\````XVP$`%````$C;`0`1````7=L!``L```!OVP$`
M#````'O;`0`'````B-L!`!,```"0VP$`"P```*3;`0`0````L-L!`!L```#!
MVP$`$````-W;`0`5````[ML!`!H````$W`$`%P```!_<`0`+````-]P!``P`
M``!#W`$`&````%#<`0`)````:=P!`"H```!SW`$`$0```)[<`0`*````L-P!
M``(```"[W`$`$````+[<`0`7````S]P!``L```#GW`$``P```//<`0`*````
M]]P!``\````"W0$`!0```!+=`0`'````&-T!``P````@W0$`"P```"W=`0`4
M````.=T!`!4```!.W0$`#@```&3=`0`X````<]T!`!@```"LW0$`&````,7=
M`0`*````WMT!`"4```#IW0$`!0````_>`0`6````%=X!`#P````LW@$`#0``
M`&G>`0`.````=]X!``8```"&W@$`!````(W>`0`$````DMX!``H```"7W@$`
M%P```*+>`0`%````NMX!``8```#`W@$`"````,?>`0`%````T-X!`!0```#6
MW@$`&@```.O>`0`9````!M\!`!4````@WP$`$0```#;?`0`C````2-\!`!H`
M``!LWP$`!0```(??`0`7````C=\!`!X```"EWP$`'P```,3?`0`:````Y-\!
M`!````#_WP$``@```!#@`0`$````$^`!``L````8X`$`!0```"3@`0`%````
M*N`!``,````PX`$`#@```#3@`0!,````0^`!`!P```"0X`$`*@```*W@`0`F
M````V.`!`$X```#_X`$`,@```$[A`0`Q````@>$!`!\```"SX0$`70```-/A
M`0`=````,>(!`$<```!/X@$`(````)?B`0`Q````N.(!`#,```#JX@$`)@``
M`![C`0`E````1>,!`"@```!KXP$`+0```)3C`0`T````PN,!`#8```#WXP$`
M-````"[D`0`P````8^0!`"@```"4Y`$`(@```+WD`0`U````X.0!`#@````6
MY0$`%````$_E`0`5````9.4!``X```!ZY0$`80```(GE`0`*````Z^4!`&,`
M``#VY0$`:0```%KF`0`G````Q.8!`!L```#LY@$`&`````CG`0`1````(><!
M`!T````SYP$`.0```%'G`0`B````B^<!`!L```"NYP$`:@```,KG`0`6````
M->@!``H```!,Z`$`!````%?H`0`&````7.@!``@```!CZ`$`!0```&SH`0`5
M````<N@!`!(```"(Z`$`&0```)OH`0`C````M>@!``\```#9Z`$`#P```.GH
M`0`-````^>@!``H````'Z0$`!````!+I`0`)````%^D!``<````AZ0$`#0``
M`"GI`0`(````-^D!``D```!`Z0$`%@```$KI`0`6````8>D!``L```!XZ0$`
M"@```(3I`0`5````C^D!``D```"EZ0$`!@```*_I`0`3````MND!`!L```#*
MZ0$`"0```.;I`0`*````\.D!`!8```#[Z0$`"@```!+J`0`'````'>H!``@`
M```EZ@$`"````"[J`0`,````-^H!``P```!$Z@$`#````%'J`0`,````7NH!
M``8```!KZ@$`!@```'+J`0`9````>>H!``(```"3Z@$`"````);J`0`&````
MG^H!``8```"FZ@$`*0```*WJ`0`%````U^H!`!,```#=Z@$`&0```/'J`0`(
M````"^L!``<````4ZP$`!@```!SK`0`*````(^L!`!`````NZP$`&0```#_K
M`0`(````6>L!``P```!BZP$`(P```&_K`0`*````D^L!``D```">ZP$`$```
M`*CK`0`%````N>L!``(```"_ZP$`"P```,+K`0`!`````````-$```".`0``
MIP$``$`!``!8``````````````"D!0``4@,``"@`````````X0(``!0````=
M`@```````"X#``"-`0``RP```*X!``#<!```10(``/P"``!F`@``#0$``-D%
M``#H!@```````!L#`````````````/X&````````@@8``,($``"+`P``F@$`
M`#4"```W!0``>@0``.H%```$`0```````$T%````````S`(``+`"``!X!0``
MQ0$``.X$```-!0``\@$``#<````,!P``K@,``(P%`````````````/H"``!=
M`@``,P(``+L!``````````8``$D&```:!P``7P4``)T$``!A!```ZP0`````
M````````?0```#`&````````M@,``(H#````````;04``(4````J`P``1P,`
M`",$``!8!@``4P(``,T"```2!@``H@,``$("``")`@``G`(``$$$````````
M``````````!A`P``\`$```$#``!>`0``@@,```````",!@``$`(``'`%``"7
M````L`4``)\"````````E0(``/0&``!/`0``9`(``"8"``#@`0``Y`$`````
M````````:````-L#``#U!@``-00``+($```D`````````%D&````````B0``
M`$````#_!```OP8```D%``"``0``'P4``'<&````````;0```*,$````````
M`````*D#``"[`P``'08``$P````I`0``XP0``%8#```K`@``+00``.4&```<
M````&0,``+H%``!L`0```````)8&````````LP,```````"+`@``<P,``.@$
M``!U!@``T`8```````#G`P````,``"L'````````)0````````"^`P``VP(`
M`(T&```&!@``W08``*<%``!%!@``MP0`````````````I0$``(D#```I`P``
M`````,<`````````*`8``,(````G!0``Q@(``#($```````````````````V
M`@``G`8``#@'``#W`0``?04````````-`````````/L"```0!P``TP4``"`$
M````````@08`````````````'@0```````#`````'`(```````!B`P``;P4`
M`+P$```*`0``K@0``&X&````````'0$``*4```!=`0``%P<```````#\!@``
M`````*,```!W`P``%P,```````#N`P```````-<!```W`0```````+T%``!C
M`P````````````#:!@``/P0``!@%``#A`P``1@,``-P!``#1!0``VP0``.`$
M``!F!0``E04```````";`@```````*T&``#G!```5@````````#4`0``````
M`+D#```.!0``&`8``,@```"@`@``G`$``($"````````M`(``%4!``#,````
M\@```$\&````````;0$``#L````Z!```U`(`````````````+0<```````"N
M`@``I@$``!D&````````SP0``/````![!@``FP```+,!``"A````!`,`````
M````````)@8````````V!```````````````````````````````````80(`
M```````S`0```````$0&``!A`0``<08``+8%``!:`P``^`8``-T```"R````
M*P4````````D`@``E@,``&4"````````.P$```````!<`````````.,%``"9
M`@```````/D!``````````````````#N!@``IP``````````````$0``````
M``#I!0`````````````L`````````+$$```5!0``A@````````#.`P``````
M`#D$``!G`P``Z@,`````````````````````````````\@8``"<&````````
M`````-L&``!C`@```````+4%````````'@$``&L```"*!@``T0,``/P`````
M````500``!,"``#F!```_`,```````#P`P``Y@``````````````X`4``+X!
M``"9!```40(``.4%```K!@``X@0``(,%``#$!```7P8``-P"```<!P``C`(`
M``````!\!0```````#4'```*!P``4@$`````````````B@0``/$````)!P``
M`````!\'````````8`8``,`"```J!`````````````"/`@```````+D```"W
M`P``Q`4``","``#.`0``104``),"````````4`,``(8%``!E!```G`0`````
M````````````````````````90,``/X"```-!@``5@0``&D"``"``@``Y@4`
M``````!N`0``20(``#$!``#`!```9P```"P$```:!@``H04``-,&``#Q`0``
M)04``#$```"K`@``408```($```"`0``]`````X"``"G`P``:@```+\```!H
M!````@,``'(````@`@``9`0``&H%``"D!@``1````/<"``!J`@``A`0``(,`
M``"=`@````````````#Z!0``TP,````````W`@``=@$``+@!``!?`P``Y@8`
M`$$!```I!P``B`(`````````````I@8``/L#``"F!0````````````!:!```
M`````*H#``#G!0```````&`"``#P!0``K00```T'``#<!0``,`(``)(%``!T
M````$`$`````````````K@4``!4!``#Y!@```````",#````````6@4``.@`
M````````S00``+H$``!C`0```````/T"``!K!0``AP8```````"_!0``R@,`
M`)<&``![!0``L@$```````"3!@``L@,```````"K````M`$``#4%``"=`0``
M.@,``!H``````````````'D&``!J!@``P@(``,,`````````308``%4#````
M`````````````````````````$4!``"/`P```````"4$```"!P``1P4`````
M``!+!0``)@,````````Y`P``QP,```````#Q!0``Z`4``!,%``"@`P``&@4`
M`.L"``#_````S08``"$"```Z`0``/@,``+X%````````/08``(\!``##`@``
M"P,``"0#````````P`8``*@#```N!0``?@8``&(%``#3`0``?0(``)$!```_
M`0``=`0``)@!```````````````````#`P``H@(``*$$``"_`0``F````,\#
M`````````````$@#``!;!@```````,@#``!7`@```````%D!``#M!```>`,`
M````````````7`0``*T"```B`0```````'P&````````N@,``,\!``!/!0``
M`````"($```9!P``X@(``#X$``#Q`P````````````"X`P````````$'``#$
M!@``R`8``#<&````````&`0``,<&````````.P<````````4!````````%0`
M````````=0$``(L!``"\!0``200``&\&``"P!```T00```@#````````.`(`
M````````````)P```*D```#4!0````````````"#!@``?P,``+D"``"I!```
M=`,``$\`````````PP4``!@```!H`P``H08``#0%````````>0(``#(```"]
M!```A00``)L$```\!````````(D&``#B`0``,`4``.,`````````5P,``!0"
M``!+!@``````````````````>00``/0!``#!`@``%@,``-8$``"?`0``````
M``````!7!@````````````#9!````````+@$``#_`0``M0$````````3!```
MN`4``%D%``#?`````P```,8```!+`P``!@(``,L%```2`0```````*8"````
M````CP8``,4```!>`P``^````!`%``"T!0``````````````````#`8``'D#
M```V`P```````'`&``#1`@``=P(``(T#```P`P```````'T$```1!0``?0,`
M`(\$```````````````````;!0``]P4``*\"```<`0``/@4`````````````
M;`4`````````````-`0``"0$``!F`P``W0$``$H&``!Y!0```````-8`````
M````^P$``*L!``!D`P``TP(``-`"````````>0$``"L```"H!0```P$`````
M````````)P0``",'```4`0``DP4``$X$``#Z!````````!@'````````&P8`
M`*<$``"^````J`$``.,"``"T`P``N@(``.$```!>!0``1P8``,@"```:`@``
M@P(````````1!@```````!T`````````(0,```````!S`0``%@$``#P`````
M!```_04```<%``"Q`@``F08``(H"```9`0``[P$``%L$``#Z`P``^`,``/`"
M``#.````,`<``'<!``#?`P``Z@0``*,#``!%!```^P4``$@$``"D`@``(@,`
M`/,$```1!```^P0``!L'``"3````:`4``!<$````````W@```#P!``"(`0``
M8P0``.X"``!.`0``A@$```````#:`0``'`,``%("``#7````@````+P!``"6
M`0``9P(``````````````````#P'``"?!0``V`,``+,$``#B````U00``(L$
M```$!P``S`4``)@#``!-!```J@0```````#Z!@``'0,``%(%```C!@``C04`
M`,0#```B````N0$``&(````2!```6P$``!`````@`0``)0<``'`"``#]`0``
MBP```%\"````````Q````(,!```J`0```````',"```$`````````$X&````
M````*P0``,(&```1`0``<@,``#$&``#T`P``%@```&<!``#%`@``C0(``(8&
M`````````````#H&```8`P``O@(``-0```!4!@``$P```(\%````````D0,`
M`$8&``!+`@``+P<``'X````S!@````````````!O`@````````````#J`@``
M;@4`````````````8@8````````0`P``_`$```@'````````%`4``"8%```!
M!```[P,``"\!```D`0``````````````````,0,``.0&```M`@``#P<``#P%
M``!R!@``_@,``$$`````````E08``/(%``#4`P``>0````````!0````[08`
M``````!R!```\00``)<"``!_````.@4``"0%``!,!@``-`````````"6!0``
M3P0``,\"````````T````/T```#U`P``600``.D```#W````4`$``,D!``!>
M`@``>P,``/X$`````````````$T````H`@```````%P&``#V!```W`,``/H`
M``#A!```M00``!\!```)`0```````)\&``````````````````#^````[0(`
M`"8$```_````#@0``!,&``"@`0``````````````````MP$```````!8!```
M``````````#*!0``@`8``)X#``!5````N08````````?`@``%00``(D!``#X
M`@``J````/(#``"W!0``G@4``&L#``"J`0``2P0```````!*````6`4``!D$
M``#Y`@``RP(``-X!```J!@``I00```````"8!0``+`4``&@"``"9!0``4P``
M`,D&`````````````,@$``#=`@``MP````````##`0``I`,``#D%````````
MP0,`````````````#@$``!L```".!@``V`4``)$$```^`@``H@0``&P```#8
M!```)0(``,$$``#H`P``7`(``%(&````````7P$`````````````\08``'P"
M``!``@``)0$``"\````/`@``D@(```````!Q`P```````#@$````````[P0`
M`$H!```D!P``Q@,``)H"`````````````-<&```L!@``R`4`````````````
M`````$\#```<!```%0```#0'``"=!0``%08``-,$``#U!```>P$``(P$``!$
M!`````````````#7`P``\0(``%D"``!X!```Y````&<&```U`0```````)$"
M```S````T`4``.8#```/`0``T@```"\"`````````````-D#```A````5@8`
M`+4&````````70```#(%``!L`@````````````#N`0````````````"_`P``
M`````,0!``#:````&`$```(&```P````?0$`````````````8@0``.(%````
M`````````&,%``#E`0``,`0``%T%```7`@``F0```%<````*````)0,``)0`
M````````8`0``&4%```0!@``YP8````````2````@0```.(#```"````0`0`
M``````!0`@``;@(```````"J!0``Q@$````````#!0``%@<``"D&``"F````
MYP$``-,```#2`0``W@,`````````````M@$``+L$``!>!@``:0```(0```!A
M!@``3P(``*\&``#8`@``+`(``$$#````````:0$```````#L!@``YP``````
M```R`P``:P0``/0%```T`@``#P4``#L"``"0`0```````*(%``",`P``````
M``T"``#W!@``U0````````!R`0``Y`(``*\```!B`0```````/@$``#8!@``
M`````/P%````````F`8``)0&``!(````,P<``#<'``#7!0``D`0``/D$``"2
M`P``*04``#8'``#_!0````````````",````#@8```(%``!=!```S`0``+D$
M``"@!0``%0,``&8!``#M`0````````````#+!```WP8``&\````O!0``(@<`
M````````````D`4``'$```"B!@``E@(``*$!````````MP8``-\"````````
MZ@```#T!``#E!````````-("````````]@,``#4#````````PP,``)4!``"P
M!@```````*(!````````(00``$X%````````9````$$%``!Q`@``#`(``#<#
M``"'!0``*`,``!X```#T!```D@$``$(&````````!`0``.T#``#2`P``%0<`
M`-H"``#-!0``0`4```````!9````O0```,H"````````[P4``-D```#V!0``
M`````*@$``"0`P``"`$``.L&``!"`P``ZP```#,%``"%`@``"P0`````````
M````'@(``.P#``"Z`0``A`4``'````!$`@``$P$``%`&``!0!```;`,``'\&
M``"3`0``,`$```````"(!0```````-<$``!W````=`$``'\!``!"!```QP(`
M`*,"```5`@``"P(``,$`````````L````!(#`````````````*4&````````
M`````)@"``!F!@````````P!``![`````````-8&```]!```F@,``)8````7
M!0``Z@8````````1`P```@(````````*`P``W@(``%L#``#C!@``0P8``&@!
M````````(08```````!^!```E@0``,\```"W`@``O0,``($!````````+P,`
M`,4$``".````\P$``)\#````````*00```````!1`0``;`0``-H#``"@!@``
M^04``'0%````````/P8``!`$``!3`P``EP$``"H'```]!P``3`$```<```!=
M`P``Z0$``$$"````````G@(``$8"``!#!```"`4``*(````?````'@4``%0#
M``#)!`````````````"9`0``LP```)<%``#O````X````!8$``";`P``0`8`
M`,(#``!2````#00```4````!!0``:00``(8"````````?08``%0%``#/!@``
MP@$``'H"``"H`@``CP```"8!````````ZP,``-T#````````*0`````````9
M!0``I`$``-$!`````````````"`#``#S!0```````)H%``"N!@``````````
M``"2!```>@8``#8&```(!```*0(```````!S!@```````$D#``!7`0``/04`
M`!D"``#X`0```````"X!``!Q!```B`,``'8#```C`0``;`8``(<```!R!0``
MK`4```````!P!```````````````````2P$``&T&``!9`P``+@0``)X&````
M````204``#8`````````)@```&<$``!C````OP0``'8&````````WP4``!T%
M``!^`@``EP,`````````````I0,``*8#`````````````'@"````````40,`
M`*4"`````````````%$%``!Z!0```````-H%```]````M0(```````#C`0``
MEP0``#@&``!:`@``GP0``)P#``!M!```1P```,$!``#`!0``]@```,,$``!@
M`````````.T%``![!```V@0````````A!P``(P4``$<!```\`@```````"X"
M```L`P``!`(``(0#```N!@``6`(``#,#``"T````HP8```````"<````````
M`%H!```K`0``+@```),$``"\`@``.0(``#@!```Z````?`,``%X$``#I!@``
M```````"``"Q!0```````-8#````````E00``*T!``!U`P``C@0``+4#``"'
M!````````/T#`````````````(L&````````%@(```0&``!6`0``=00``!H#
M```Z`@```````,4%```4!P``908```````"[!@``BP4``(,#``#(`0``OP(`
M`(4#``"1````^P8``+0$````````R@0``,P&``!K`0``L@8``(<#````````
M`````!\#````````J0$````````4`P``90$``"$%```+!@``]0$```````"(
M!@``R@`````````'!````````(8#```Q!P```````'`!```%`0```````*,!
M``!U!0```````&<%````````Z`(```````!J`P``40```#L$``#)`@``D`8`
M``D```#>!````````((!``!I`P``:08```````#F`@```````"H````M!0``
M;@,``"@%``#]!@``R@$```4&``!.`@``(`4``',````H!P```````%X```#5
M`P``\P,``)X`````````!00``$P"````````M@(``+,&``"!`P``P04``)(`
M``!V!0``:P(``/8"```L!P``2`(``*0`````````O0$``(T`````````R0``
M``$"````````&@0``-D&``#_`P``.P4``/,"``#L!0``,@8`````````````
M2`$``-($````````C@4``*$#````````+0,```X#``#+!@``2P```)H```!^
M`0``5`$``*0$``#;``````````````"L`P``N`8``+@```#L`@``*`0``/X!
M``"M`P``4`4``-4&``!A```````````````\`P``````````````````````
M`#L#``">`0``1P0```,&``#2!@``1`$```````".`P```````'H#``#-`0``
M=@```/8!`````````````+8$`````````````((````C````400``.0#``!3
M!0``F0,```,"``!N````0P```.(&``"(`````````,<%``!A!0``'`4``,4#
M``!\`0``C`$``'$!```,!````````+L```"V!@``"P<``.P!````````'@,`
M`&8$``"[`@``XP,``!\&```3!P``20```-P````/`P```````%P#```6!@``
MKP$``%P!````````1@$``(D%```7!@```````!D```"G`@```````,P!````
M````-P0```@&````````+0```.D"``#F`0``\@0``-@````R`0``:@$``"`'
M````````J04```4%```L`0``_`0``$H%``!X````V0$``"T&``"$`0``````
M``````">!````````&L&```)`@```````#8%`````````````#X'``!J!```
ML0,``&0!```1`@``B00```````"L`@```````,L!``"@!```2`8`````````
M````U`8``,\%``"0````)P(```````"N`````````!<!``#6`0```````.$!
M``"'`@``@@4``"H%```U````<P4``*\$````````U0(```````!N!```-`,`
M````````````M0````````#0`0``%P```/<$```O!@````````````#Y`P``
M``<``+$!```&`0``4P$```````#.`@````````````!"!0``JP0``"4&````
M````^@$``"("``"A`@```````)(&```R!P``G0,``)0#````````J@(`````
M``!W!0``1@0```<&``#_!@``````````````````S`,``"<'```Q`@``$@<`
M``````#J`0``20$``$(`````````8P8``.`#```.!P``7P0``#D`````````
MN`(``)`"```&`P```````&\#``#R`@``;P0```````"Y!0``"````#\"```'
M`@``#0,```````#L!````````/,&``#O`@``?P0``*D"``"\````FP$`````
M``!5!@``@`4````````````````````````Z!P``YP(``!,#````````^P``
M``8$````````;0,``)0%`````````````-D"``!#`0``&P0``'<$```/````
M-08```,$``#%!@``?`0``````````````````#@%``#Y````0@$``)L&````
M`````````)@$````````=@0`````````````J@8``%,$``!X!@``JP,``!X&
M``"F!````P<``#0!``!``P```````-T%``"`!```(0$``,D#```(`@``T08`
M````````````T`0``%8"``"L!@```0$```4#````````O@0``.`&```H`0``
M_P(``$X#``!!!@``@00``"L#``"$`@```````,<!```Q!`````````X```"^
M!@``/P4```````#$`@``&P(``#,$`````````````+H`````````,04``%P%
M````````X04``-<"````````8`$``"````!.````!0(```H&````````````
M`+T"``#E`@``>@$``+$&``!#`@``50(``'8"````````#`````````"O`P``
MM@```$H$``#5`0````````P%``!-`0```````%8%````````P`$``%4%````
M````)P$``#D!``"4`0``VP$```8````)!```IP8````````X````KP4``%,&
M```T!@``1@4``!("`````````````&D%``#]!```.08```````!#`P``````
M`.\&``"M````F@0``,<$```2!0``FP4``%T&```)!@``B`0`````````````
MU@4`````````````;P$``$H"````````R04``,X%``#?`0``%@4``%L%``#U
M`@```````)$&````````]@8``,8$````````"P````````#@`@```````+`#
M````````(@8```````#4!```9`4```````!_`@``W`8``'\%``"4!```8`4`
M``````#D!0```````-\$``"@````E0,````````^!@``2`4``)T&````````
M`````*P!````!0`````````````=!```C@(``(H!```>!P```````.4#``"!
M!0``F@8``#X```!^`P``&@$```````!&`````````*L&````````````````
M``"1!0``1P(``+,%``#2!0``K`0``-8"``#&!0``"P$````````_`P``$0<`
M`.@!``""`@``=`8`````````````'P0``)P%```X`P```````'("``!:!@``
MK04``+(%``!@`P``]04``!@"```'`P``>@```%0$```;`0``T`,``&8```#M
M````LP(`````````````W@4``+`!````````.0<```````"H!@``<P0```4'
M``#5!0```````+("````````S0```.D$````````R@8``-@!``#;!0``````
M`"X'````````O`,````````J`@``#P8```````#.!```9`8```````#N!0``
MP08```````#X!0``3`4````````D!@```````#T#```/!```ZP$``,T#````
M`````````&T"``!X`0```````'`#````````?`````<!````````P`,``#P&
M``!*`P```````#("``#L````)P,``,(%``#N````J08``(,$```&!P``)@<`
M`,8&``````````````P#``"\!@``_@4``.D#``"%!0``B@4`````````````
M`````%@!````````!`4```L%````````1`4``%<%``"-!````````#T"``!-
M`P``@`,```````#S`````````)4```"*`````````.L%```!!@``1`,`````
M``!B`@``PP8``#L&``"L````AP$``+H&````````@@0``'L"````````'0<`
M`%\```!:````E`(```D#``!8`P``GP```)T```"%`0``A`8``````````0``
M`````"(%``"K!0``S@8`````````````0P4```````"3`P``=0```%<$``!,
M`P``]`(``+$````^`0``?@4````````'!P```````%0"``!U`@``````````
M```*`@``(`8``/`&`````````````*H```#U````W00``.4```!H!@``NP4`
M````````````+0$````````*!```'`8``$P$``!;`@``"@4``&4```#+`P``
M=`(```````#P!``````````````&!0``+P0``$4`````````W@8``'$%``#A
M!@````````````#W`P``M`8```````!-`@``%`8``*,%``"E!0``````````
M````````````````````````O08``%($``!%`P`````````````V`0``A08`
M````````````6P```.0$``"&!````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S
M:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H
M>65S=&5R9&%Y*0`@870@`")&:7)S=&YA;64@3&%S=&YA;64B("`H:64N($IO
M:&X@1&]E*0`B3&%S=&YA;64L($9I<G-T;F%M92(@*&EE+B!$;V4L($IO:&XI
M`"5D("5S(&%N9"`E<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@
M1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F
M($%G<F5E;65N=``E<R!A9&1E9"X`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T
M("5S("5S`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E
M<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E
M<P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S
M.B`E<P`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S
M`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R
M-"!H;W5R<P!!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E
M<75I<F5D`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!
M4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)O=F4@<V5A<F-H
M(&9O<FT`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U
M;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO
M;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`
M061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D
M9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!
M9&0@=&\`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@
M8F]O:P!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E
M<W,`061D<F5S<R!";V]K($QI<W1I;F<`061D<F5S<R!B;V]K(&5N=')Y`$%D
M9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+@!!9&UI;FES=&5R("T@
M<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO
M;@!!9',`061V86YC960@4V5A<F-H`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG
M97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC
M871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U
M<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!%>&ES=',`06QR96%D
M>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@
M4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M
M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X
M=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`
M06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A
M=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE
M`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@
M9&5L971E("5S/P!!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE
M=&4@=&AE('-E;&5C=&5D(&5N=')I97,_`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R9V5N
M=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!
M<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I
M9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S
M=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S
M`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A
M;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL86)L
M92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`
M0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K
M97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/
M+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F%S:6,@
M4V5A<F-H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5L;W<@<V5A<F-H(&9O
M<FT`0F5N:6X`0F5R;75D80!":'5T86X`0FEN9"!F86EL960Z("@E<RD@)7,`
M0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F
M;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`
M0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O
M<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U
M=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET
M;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`
M0G5R:VEN82!&87-O`$)U<G5N9&D`0G5S:6YE<W,@0V%T96=O<GD`0TU3`$-2
M0P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#4U8`0U]E;&P@4')O<&5R=&EE
M<RXN+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D
M96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A
M<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T
M(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T
M;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O
M<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L
M;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E
M;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E
M;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A
M;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T
M92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D
M9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L
M>2!T;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!?
M06QL+TYO;F4`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W
M;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A9&1R97-S(&)O;VL`
M0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL
M92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@
M35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#
M;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V
M:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D>0!#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D
M97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T
M:6]N`$-O;',Z`$-O;'5M;B!/<'1I;VYS`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA('-E<&%R871E9"!V86QU97,`0V]M;6$@<V5P87)A=&5D('9A;'5E
M<R`H36EC<F]S;V9T($]U=&QO;VLI`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#
M;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP86YY($%D
M9')E<W,`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I
M;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@9F%I
M;&5D.B`E<P!#;VYN96-T:6]N(&9A:6QU<F4`0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN
M96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T(')E;6]V960@
M9G)O;2!L:7-T+@!#;VYT86-T<R!I;B!L:7-T.B`E<P!#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N
M=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N
M`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@
M:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@)7,N
M`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED
M96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT960@
M=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N
M97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R
M;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R
M96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E
M;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y
M<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q
M*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`
M1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`
M1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E
M8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT
M($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!S;W)T:6YG(&1I<F5C
M=&EO;CH`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#;VYF:7)M871I;VX`
M1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R
M9V4@;65S<V%G97,`1&5L971E(&)U='1O;B!B96AA=FEO=7(`1&5L971E(&-E
M;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E
M;7!L871E`$1E;&5T92!F86EL960Z("@E<RD@)7,`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T:6]N(&9A:6QE9`!$96QI
M=F5R>2!T:6UE`$1E;FUA<FL`1&5P87)T;65N=`!$97-C96YD:6YG`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A
M<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D
M96QE=&EN9R!E;G1R:65S/P!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN
M:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$;W=N;&]A
M9"!V0V%R9`!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D
M;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N
M`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I
M="!E;G1R>2!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S
M:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE
M;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS
M`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E
M<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE
M;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT
M<GD@9F]R("5S('5P9&%T960N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`
M17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<W1O;FEA`$5T:&EO
M<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@
M)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`
M17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@061D<F5S
M<R!";V]K`$5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T<RX`17AP
M;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN`$9'
M($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N`$9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O
M:SH@)7,`1F%I;&5D('1O(&%D9"`E<R!T;R`E<SH@)7,`1F%I;&5D('1O(&)R
M;W=S92!L:7-T`$9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R>0!&86EL
M960@=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@
M1$X@/2`E<RP@4F]O="`]("5S`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL
M960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N
M`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D
M('1O(&9I;F0@;V)J96-T('1O(&)E(&%D9&5D.B`E<P!&86EL960@=&\@;6]V
M92!T;R`B)7,B+@!&86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S
M`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N
M9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS
M(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA
M=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&
M:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R
M<P!&:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!.86UE`$9I<G-T(%%U
M87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S
M(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@
M1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS
M(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L
M9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R
M9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N
M97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L
M($UE=')O<&]L:71A;@!&<F5E8G5S>2!54DP`1G)E;F-H($=U:6%N80!&<F5N
M8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M
M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA
M;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`
M1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O
M9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE
M`$=L;V)A;"!!9&1R97-S($)O;VL`1V\`1V]E9&5L`$=O;V=L92!396%R8V@`
M1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD
M`$=R96YA9&$`1W)O=7``1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M
M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'
M=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K
M`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W
M+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`
M2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R
M97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET
M;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F
M('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@
M4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@0VET>0!(;VUE($-O=6YT
M<GD`2&]M92!0:&]N90!(;VUE(%!O<W1A;"!#;V1E`$AO;64@4W1A=&4O4')O
M=FEN8V4`2&]M92!3=')E970@061D<F5S<P!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N
M=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C
M="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z
M(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE
M`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R
M>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB
M;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E
M871I;VX@9F%I;&5D.B`E<P!)35-0`$E0($%D9')E<W,`25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W
M($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS
M('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@
M17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T
M=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@
M4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL
M97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!)
M;7!O<G0@061D<F5S<R!";V]K+"!3=&5P("5D`$EM<&]R="P@4W1E<"`E9`!)
M;7!O<G0O17AP;W)T($%D9')E<W,@0F]O:W,`26UP;W)T960@9FEE;&0Z("5S
M`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T
M(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!)
M;F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T
M:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@
M5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!)
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L
M871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!)
M;G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@
M8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P
M:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F
M=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS
M=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!)
M;6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T
M;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT
M(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!)1`!);G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(&%D9')E<W,@
M8F]O:P!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!)
M;G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D
M9')E<W,N`$EN=F%L:60@96UA:6P`26YV86QI9"!E;G1R>0!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@:V5Y('-P96-I9FEE9"X`26YV86QI9"!M<V=?
M='EP92X`26YV86QI9"!N86UE`$EN=F%L:60@;V)J96-T260`26YV86QI9"!O
M<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<')O=&]C
M;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E
M<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O
M;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M
M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R
M<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*
M=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH
M<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J
M96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A
M=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@
M57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+
M4BD`2W5W86ET`$MY<F=Y>G-T86X`3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D
M(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@
M;&]A9&5D+@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A
M=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T($UO9&EF:65D`$QA<W0@3F%M
M90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I
M80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO
M;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&EB97)I
M80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@
M1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I
M;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN
M:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T
M:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#
M;V]K:64`3&ES=`!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES
M="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T
M+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O
M<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG
M+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G
M(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@
M9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N
M(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC
M`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I
M80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA
M<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T
M86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T
M8VAI;F<`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA
M>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!P86=E<P!-
M87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@
M8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B
M=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I
M9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A
M=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UI;FD@4V5A<F-H`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@1$X@
M:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BX`36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG
M(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@
M240N`$UO`$UO8FEL92!-86EL`$UO8FEL92!0:&]N90!-;V1E<F%T90!-;V1I
M9FEE9"!$871E`$UO9&EF>2!54DP`36]D:69Y(&9A:6QE9#H@*"5S*2`E<P!-
M;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-
M;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`
M36]R92!T:&%N(#$@96YT<GD@9F]U;F0`36]R;V-C;P!-;W-T;'D@0VQE87(`
M36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V90!-;W9E($1O=VX`36]V
M92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!L969T
M`$UO=F4@<FEG:'0`36]V92!U<`!-;WIA;6)I<75E`$UU;&)E<G)Y($%D9')E
M<W,@0F]O:P!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@
M<&5R<V]N<R!W:71H(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE
M(%LE<UT@86QR96%D>2!E>&ES=`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C
M;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)
M($1O($Y/5"!!9W)E90!.86UE`$YA;64@1F]R;6%T`$YA;6EB:6$`3F%U<G4`
M3F5P86P`3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GD`3F5T:&5R;&%N9',`
M3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.
M971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.
M971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V
M97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($-O;G1A8W0`3F5W
M($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W
M('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P
M=&EO;G,`3FEC87)A9W5A`$YI8VMN86UE`$YI9V5R`$YI9V5R:6$`3FEG:'0`
M3FEU90!.;P!.;R`E<R!E;G1R>2!F;W5N9"!F;W(@)7,`3F\@861D<F5S<R!B
M;V]K<R!F;W5N9"X`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-O
M;G1A8W1S(&9O=6YD`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@
M;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE
M('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E
M(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@
M8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S
M87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG
M;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="X`3F\@=D-A<F0@9&%T82!W87,@9F]U;F0N`$YO('9A;&ED
M(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@
M:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD
M`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S
M`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`
M3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S
M`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`
M3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R
M(&]F(&ET96US('!E<B!P86=E`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T
M('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N
M`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8FIE8W0@;F]T(&9O=6YD`$]C
M=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]M86X`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S
M:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI
M<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`3W=N
M97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A
M=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!0
M2%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-
M(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`
M4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL
M($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A
M<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W
M;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A
M<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R
M9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R
M;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N($1E
M;FEE9`!097)M:7-S:6]N(&1E;FEE9`!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN
M97,`4&AO;F4`4&AO=&]S`%!I;F4@061D<F5S<R!";V]K`%!I=&-A:7)N`%!I
M>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A
M<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T
M=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0
M<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T
M92!!9&1R97-S($)O;VL`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E
M<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B
M;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E
M<GD`475E<GD@9F%I;&5D.B`H)7,I("5S`%%U:6-K(%-E87)C:`!24T$@4'5B
M;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A
M<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@
M=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@9F%I;&5D
M.B`H)7,I("5S`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E8V]R9',@9&ES<&QA>65D.@!2961O97,@>6]U<B!L87-T
M(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S
M:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5M
M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@
M8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M('1H:7,@;&ES
M=`!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U
M<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z(`!297%U97-T960@;V)J96-T(&YO="!F;W5N9"X`4F5Q
M=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!0
M87-S=V]R9`!297-E="!T;R!$969A=6QT<P!297-U;'1S`%)E='5R;B!T;R!/
M<'1I;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT
M($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I
M9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O
M=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T
M:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N
M9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R
M>7!T960@365S<V%G90!3+TU)344@4'5B;&EC($-E<G1I9FEC871E`%-!4TP@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN
M9P!344P@4VAE;&P`4U-(`%-405)45$Q3(&9A:6QE9#H@*"5S*2`E<P!354-#
M15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N
M9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N
M`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@
M*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP
M90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E
M<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!38VEE;F-E`%-E87)C
M:`!396%R8V@@16YG:6YE<P!396%R8V@@9F%I;&5D`%-E87)C:"!F86EL960Z
M("5S`%-E87)C:&EN9RXN+@!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!3
M96QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C
M="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@=&AE(&%D
M9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3H`4V5L96-T('1H92!A9&1R97-S
M(&)O;VL@=&\@:6UP;W)T('1O.@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP
M;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E
M;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SH`4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=VAI8V@@9FEE;&1S('1O
M(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N`%-E;&5C="!W:&EC:"!F
M;W)M870@=&\@9&ES<&QA>2!N86UE<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H
M96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O
M8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB
M97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO
M;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D
M92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L
M92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H87)E9"!$:7)E
M8W1O<GD`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W($%L;`!3
M:&]W($-O;G1A8W1S`%-H;W<@3&ES=',`4VAO=R!D:69F97)E;F-E<R!B971W
M965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I
M;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K
M97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S
M`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@
M=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I
M>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N
M;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO
M=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E
M;7,`4V]R="!$:7)E8W1I;VX`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E
M(&%D9')E<W,`4V]U<F-E<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I
M;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&5C:69Y
M('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P
M<&5A<BX`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T
M<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A
M=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!
M9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN
M(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3=6)M
M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O
M("5S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`
M4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`
M4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E
M<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD
M($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`
M5"U3=&]R;0!4+5-T;W)M<P!44U8`5%-6(&9I;&4`5&%B('-E<&%R871E9"!V
M86QU97,`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S
M`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E
M;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U
M<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S
M(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S
M<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+@!4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S`%1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M
M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@
M;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N
M;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@8V]N
M=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+@!4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A
M=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE
M<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES
M(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R
M97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W
M<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE
M<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H
M92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA
M;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA
M<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N
M86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD
M(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M
M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE
M=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y
M<W1E;2X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT
M+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I
M9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B
M)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D
M<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4
M:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92X`5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S(&)O;VMS+B!.;VYE
M(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R!A<F4@8V]N9FEG=7)E
M9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S('1O('1H96TN($EF
M('EO=2!B96QI979E('1H:7,@:7,@86X@97)R;W(L('!L96%S92!C;VYT86-T
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E
M<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM
M=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T
M:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE
M(&YE=R!C;VYT86-T+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@9F]R(&9U<G1H97(@:&5L<"X`5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T
M:6YG(&$@;F5W(&QI<W0N`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T
M:&ES(&-O;G1A8W0Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T
M:&ES(&]B:F5C="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI
M<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!D871A.B`E<P!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q
M=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H
M92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H:7,@96YT<GDZ("5S`%1H97)E('=E<F4@;F\@861D<F5S
M<V5S('1O(&5X<&]R="X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A
M9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I
M<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N
M`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G
M+@!4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N`%1H:7,@9F]R
M;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI
M<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O
M8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E
M<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES
M="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@
M;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O
M=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92X`5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I
M;B!T:&4@861D<F5S<R!B;V]K`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@
M9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE
M("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W
M:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`
M5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4
M<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E
M`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM
M96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@
M>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A
M:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DN`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U
M<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE
M('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X
M=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@
M9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`
M56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@
M16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE
M9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@
M($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N
M;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@
M86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D
M($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A
M9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@
M;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E
M;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E
M9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S
M97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R
M;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I
M<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I
M;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S
M(&9R;VT@;F]W+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A
M='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T
M:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)I
M<VEG;B!$:7)E8W1O<GD`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC
M86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H
M`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W($-O
M;G1A8W0`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I
M97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.@!6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI
M='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@86YD($9U
M='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A
M('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!796)S:71E
M(%523`!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7
M97-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E
M<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I
M:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`
M5VEN9#H@`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7;W)K($-I='D`5V]R
M:R!#;W5N=')Y`%=O<FL@4&AO;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K(%-T
M871E+U!R;W9I;F-E`%=O<FL@4W1R965T($%D9')E<W,`6"U2968`6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA
M:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D
M<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O
M<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A
M8W0N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O
M8FIE8W0N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA
M;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A
M('1A<F=E="!A9&1R97-S(&)O;VLN`%EO=2!M=7-T('-E;&5C="!A('1A<F=E
M="!L:7-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T
M960N`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@96YT<GD@9FER<W0N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H
M870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T
M96=O<GD@;F%M92X`66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@
M=&AI<R!C;VYT86-T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O
M;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO
M=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T
M:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO
M9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T92!S97)V
M97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;
M2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T
M960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE
M("5S(&]F("5S70!;;F\@=F%L=65=`%]!9&UI;FES=')A=&EO;@!?0G)O=W-E
M`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2;W<`7T=R;W5P<P!?
M2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&]G
M(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES
M<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]296UO=F4@9G)O;2!T:&ES(&QI<W0`
M7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D
M9')E<W,@8F]O:P!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`8V]N=&%C="YV
M8V8`8V]N=&%C=',N8W-V`&-O;G1A8W1S+G1S=@!F86QL:6YG`&9I;&4`9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI
M;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`
M;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E
M<&%D`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-M
M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@
M<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO
M;CH@5'5R8F$@,BXP+C(*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`@,C`P,2TP-RTR-B`Q-#HU-BTP
M-S`P"DQA<W0M5')A;G-L871O<CH@36EL;W,@5VEM;65R(#QW:6UM97)`>F-U
M+F-Z/@I,86YG=6%G92U496%M.B!#>F5C:"`\9&5V0&QI<W1S+FAO<F1E+F]R
M9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4E33RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@."UB:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE
M,3`]/3$@)B8@;B4Q,#`A/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@;B4Q,#P]-"`F
M)B`H;B4Q,#`\,3`@?'P@;B4Q,#`^/3(P*2`_(#$@.B`R*3L*`"`H</AE9"`E
M<R!D;GDI`"`H4/CM<W1U<&]V_2!K;.WH("5S*0`@*'8@)7,@9&YE8V@I`"`H
M9&YE<RD`("AZ[71R82D`("AVZ&5R82D`(')Y8VAL;W-T(``B2FWI;F\@</CM
M:FUE;NTB("AN87#X+B!*;W-E9B!.;W;A:RD`(E#X[6IM96[M+"!J;>EN;R(@
M*&YA</@N($YO=N%K+"!*;W-E9BD@`"5D("5S(&$@)7,`)60M9&5N;NT@</AE
M9'!O=NSO`"5S("T@;WINX6UE;NT`)7,@;W1I<VL`)7,@2T(`)7,@;W!E<F%C
M92#Z9'*^8GD@+2!P;W1V<GIE;NT`)7,@;F%S=&%V96[M`"5S(')E9VES=')A
M8V4`)7,@<&]D;>UN:WD@<&]UONUVX6[M`"5S('#X:63A;BX`)7,@:FF^(&5X
M:7-T=6IE+@`E<R!N82`E<R`E<P`E<R!S;W5B;W(@8GEL(/IS<.RY;NP@:6UP
M;W)T;W;A;@`E<R!J92!P;[YA9&]VX6YO`"5S(&UI;G5T`"5S(&YE8GEL;R!N
M86QE>F5N;RX`)7,@8;X@)7,@>B`E<P`E<R!K86QE;F3A^``E<R!ZX7!I<V[M
M:P`E<R!S97IN86T@^FMO;/D`)7,Z("5S`"P@;N%R87IO=OT@)7,@)7,`+"!P
M<F]M[&YNX2!O9"`E<R!D;R`E<P`M+2!V_6+L<B`M+0`Q,B!H;V1I;F]V_2!F
M;W)MX70`,C0@:&]D:6YO=OT@9F]R;>%T`#(T(&AO9&EN`$IE(&YU=&[I('!O
M=;[M="!P<F]H;.V^9>@@<&]D<&]R=6KM8^T@:49R86UE<RX`4')O('1E;G1O
M(&)L;VL@:F4@=GF^861O=N%N(&1A=&%BX7IO=OT@>F1R;VHN`%9Y<VMY=&QA
M('-E('KA=F&^;N$@8VAY8F$`4')O('IAN6EF<F]VX6[M('IP<N%V>2!J92!N
M=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"X`4')O('9E<FEF:6MA8VD@
M<&]D97!S86[I('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@
M:VSMZ"X`4')O(&1EN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@
M=F7X96IN_2!01U`@:VSMZ"P@<')I=N%T;NT@4$=0(&ML[>@@82!H97-L;RX`
M4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@
M4$=0(&ML[>@L('!R:7;A=&[M(%!'4"!K;.WH(&$@:&5S;&\N`%!R;R!D9;EI
M9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4R]-24U%
M(&ML[>@L('!R:7;A=&[M(%,O34E-12!K;.WH(&$@:&5S;&\N`%!R;R!P;V1E
M<'/A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K
M;.WH+"!P<FEVX71N[2!3+TU)344@:VSMZ"!A(&AE<VQO+@!0<F\@>F&Y:69R
M;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K
M;.WH+@!286YN[2!DZ;F[`%)A;F[M('#X96CA\FMY`%)A;F[M('-N[&AO=ND@
M</AE:.'R:WD`04TO4$T`05!)($E$`$EN9F]R;6%C92!O('1O;71O(&5D:71O
M<G4`26YF;W)M86-E+BXN`%;]N64@=79E9&5N_2!F;W)M=6SA^"!P<F\@=GEH
M;&5DX7;A;NT`5&5X="!D;VSY(&1O(&]B<N%Z:W4`5&5X="!D;W!R;W-T^&5D
M(&]B<N%Z:W4`5GET=F_X96[M(%9&4R!A9')A<^'X92!N96)Y;&\@<&]V;VQE
M;F\N`%9Y='9O^&5N[2!61E,@<V]U8F]R=2!N96)Y;&\@<&]V;VQE;F\N`%6^
M:79A=&5L<VOI(&AE<VQO`%6^:79A=&5L:_T@^NAE="!B>6P@>F%B;&]K;W;A
M;BX`5;YI=F%T96QKZ2#ZZ'1Y`%#X:61A=`!0^&ED870@<&]D<VMU<&EN=0!0
M^&ED870@<&]D+7!RX79A`%#X:61A=#H`4/AI9&%T(&YO=F]U('-K=7!I;G4`
M4/AI9&%T(&YO=N$@<'+A=F$`4/AI9&%T(&YO=NEH;R!UOFEV871E;&4Z`%#X
M:61A="!S;&]U<&5C`%#X:61A="!N;W;I(.AL96YY`%#X:61A="!PX7(`4/AI
M9&%T("5S(&UE;G4@:F%K;R!B;^AN[2!S;&]U<&5C($UO>FEL;'D`4/AI9&%T
M(&1O`%#X:61A="!D;R!A9')E<^'X93H`4/AI9&%T(&1O(&WI:&\@861R97/A
M^&4`4/AI9&%T('6^:79A=&5L90!0^&EDX7;A;NT@=;YI=F%T96SY(&IE('IA
M8FQO:V]VX6YO+@!!9')E<V$`5OUP:7,@861R97/A^&4`4&]L;[YK82!A9')E
M<^'X90!!9')E<^'X(&)Y;"#Z<W#LN6[L('9YZ&ES=.QN_2X`5GEK;V[A=F%T
M(&%D;6EN:7-T<F%C:2`M(&YA<W1A=F5N[2!P^.US='5P;W;]8V@@<'+A=B!P
M<F\@;W-T871N[2!UOFEV871E;&4`061M:6YI<W1R86-E`$EN>F5RX71Y`%!O
M:W)OZ&ELZ2!V>6AL963A=N%N[0!!9F=HX6YI<W3A;@!!;&+A;FEE`$%LONUR
M<VMO`$%L:6%S`%IA<F]V;F%T`%IA<F]V;N%N[3H`5KEE`%:Y:6-H;FD@;W;L
M^&5N[2!UOFEV871E;.D`5KEE8VAN>2!S:W5P:6YY`%:Y96-H;F$@=;YI=F%T
M96QS:^$@<'+A=F$`5KEE8VAN>2#H='GX:2!S=')A;GD`4&]V;VQI="!V[6-E
M(&%D<F5S`%!O=F]L:70@;F%S=&%V96[M('1Y<'4@<V5T^.UD[&[]('-E>FYA
M;3\`2FF^(&5X:7-T=6IE`$IIOB!E>&ES='5J90!!;'1E<FYA=&EV;NT@24U3
M4"!P^&EH;.&Y96[M(&1O('-Y<W3I;74`06QT97)N871I=F[M($E-4U`@:&5S
M;&\`06QT97)N871I=F[M($E-4U`@=;YI=F%T96QS:^D@:FWI;F\`06QT97)N
M871I=F[M(&4M;6%I;&]VX2!A9')E<V$`06QT97)N871I=F[M('9Z;W)Y`$%L
M=&5R;F%T:79N[2!T97AT.@!!;65R:6-KX2!386UO80!">6QA('IA9.%N82!N
M97!O=F]L96[A(&AO9&YO=&$N`$%N9&]R80!!;F=O;&$`06YG=6EL;&$`06YO
M;GEM;NT@<')O>'D`3V1P;W;L[P!!;G1A<FMT:6MA`$%N=&EG=6$@82!"87)B
M=61A`$%P;&EK86-E`%-E>FYA;2!A<&QI:V%C[0!!<&QI:V%C92!J92!P^&EP
M<F%V96YA`%!O=;[M="!P<F\@9.QD:>ANZ2!S9.UL96[M`%-C:';A;&ET`%#X
M:6)L:;YNX2!V96QI:V]S=`!$=6)E;@!!<F%B<VMY("A7:6YD;W=S+3$R-38I
M`%9E;&EK;W-T(&%R8VAI=F]V86[I:&\@<V]U8F]R=0!*;>EN;R!A<F-H:79U
M`$IS=&4@<VD@:FES=.TL(+YE(&-H8V5T92!S;6%Z870@)7,_`$IS=&4@<VD@
M:FES=.TL(+YE(&-H8V5T92!S;6%Z870@=GEB<F%NZ2!P;VQOOFMY/P!5<NAI
M=.P@8VAC971E('9Y;6%Z870@ON%D;W-T(&\@</AI:&SAN65N[2!D;R`E<S\`
M07)G96YT:6YA`$%R;>EN:64`07)MZ6YS:_T@*$%235-#24DM."D`56WL;NT`
M07)U8F$`5GIE<W1U<&[L`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@=6WL;NT`
M07-I92]R96=I;VX@5&EC:.EH;R!O8V7A;G4`4&^^X61A="!O('!O='9R>F5N
M[2!P^&5D('!R;W9E9&5N[6T@;W!E<F%C[2#Z9'*^8GD_`%-L;W5P8V4@<R#Z
M:V]L>0!0;VMU<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC[2!S:W5P:6YY+@!0
M;VMU<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC[6-H('6^:79A=&5L<VO]8V@@
M<'+A=BX`4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J[6/M8V@@=;YI=F%T96QS
M:_UC:"!P<N%V+@!0;VMU<R!O(/IP<F%V=2!N965X:7-T=6KM8^UH;R!S9.UL
M96[I:&\@;V)J96MT=2X`071R:6)U='D`4W)P96X`075S='+A;&EE`%)A:V]U
M<VMO`$%U=&A?8WER<W%L.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P
M^.UP;VYA('!R;R!I;6%P+@!!=71H7V-Y<G5S.B!:9')O:B!N96WA('!OOF%D
M;W9A;ND@<V-H;W!N;W-T:2X`075T:%]C>7)U<SH@3F5B>6QA(&YA;&5Z96YA
M('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:6UA<"X`075T:%]F='`Z($YE8GEL
M82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&9T<"X@2V]M<&EL
M=6IT92!02%`@<R`M+65N86)L92UF='``075T:%]I;6%P.B!.96)Y;&$@;F%L
M97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!)34%0+@!!=71H7VMR8C4Z
M($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&MR8C4N
M`$%U=&A?;&1A<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N
M82!P<F\@3$1!4`!!=71H7VQD87`Z($YE;'IE('#X:61A="!UOFEV871E;&4@
M)7,N($ALX;EE;NT@<V5R=F5R=3H@`$%U=&A?;&1A<#H@3F5L>F4@=GEM87IA
M="!UOFEV871E;&4@)7,`075T:%]L9&%P.B!.96QZ92!A:W1U86QI>F]V870@
M=;YI=F%T96QE("5S`$%U=&A?;6-A;#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D
M;W9A;N$@</CM<&]N82!P<F\@34-!3"X`075T:%]S;6)A=71H.B!.96)Y;&$@
M;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!S;6)A=71H+@!/=NSX
M96[M('-E;&AA;&\`3W;L^&5N[2!S96QH86QO+B`E<P!/=NSX96[M(&)Y;&\@
M>F%M[71N=71O(%)!1$E54R!S97)V97)E;2X`4V5L:&%L;R!O=NSX96[M($94
M4"!S979E<F5M+@!$;W-T=7!NX2!P;VQE.@!!>F5R8F%J9+[A;@!"3T9((';]
M;6QU=GD`4&]Z863M`$)A<G9A('!O>F%D[0"I<&%T;ND@:&5S;&\@<')O(&ME
M<F)E<F]S+@"I<&%T;ND@=;YI=F%T96QS:^D@:FWI;F\@<')O(&ME<F)E<F]S
M+@!"86AA;7D`0F%H<F%I;@!"86QT:6-KZ2`H25-/+3@X-3DM,3,I`$)A;F=L
M863IN0!"87)B861O<P!:X6ML860`5GEH;&5D870`0NQL;W)U<VMO`$)E;&=I
M90!"96QI>@!0;V0@9F]R;75LX?AE;2!P<F\@=GEH;&5DX7;A;NT`0F5N:6X`
M0F5R;75D>0!":/ITX6X`4W!O:F5N[2!S96QH86QO.B`H)7,I("5S`$YA<F]Z
M96YI;GD`3F5L>F4@;F%LZ7IT(.CA<W0@(B5S(B!A<&QI:V%C92`B)7,B+@!.
M87-T879E;NT@8FQO:W4`5'EP(&)L;VMU`%1UZ&[L`$)O;.UV:64`6N%L;[YK
M>0!/:W)A:@"I[?AK82!O:W)A:F4Z`$]K<F%J90!";W-N82!A($AE<F-E9V]V
M:6YA`$]B80!";W1S=V%N80!$;VQN[2#HX7-T`$)O=79E="!)<VQA;F0`0G)A
M>NUL:64`0G)I='-KX2!T97)I=&]R:6$@=B!);F1I8VOI;2!O8V7A;NP`0G)U
M;F5I($1A<G5S<V%L86T`0G5L:&%R<VMO`%-E>FYA;2!S(&]D<N&^:V%M:0!"
M=7)K:6YA($9A<V\`0G5R=6YD80!/8F-H;V1N[2!K871E9V]R:64`0TU3`$-2
M0P!#4DP@9&ES=')I8G7H;NT@8F]D>0!#4U8`5FQA<W1N;W-T:2!B7W7R:WDN
M+BX`2V%L96YDX?@`0F5Z=NQT^.T`2V%M8F]DOF$`2V%M97)U;@!(97-L;R!N
M96QZ92!N87-T879I="!A=71O;6%T:6-K>2P@<')O<^UM(&MO;G1A:W1U:G1E
M(%9AN65H;R!S>7-TZ6UO=NEH;R!A9&UI;FES='+A=&]R82X`3F5L>F4@<V4@
M</AI<&]J:70@:R!)34%0('-E<G9E<G4Z("5S`$MA;F%D80!3=&]R;F\`4W1O
M<FYO(&ALX;EE;NT@<')O8FSI;74`3F5L>F4@=GEM87IA="!S;W5B;W(@(B5S
M(BX`3F5L>F4@;F%J[70@9&_H87-N_2!A9')E<^'X+@!.96QZ92!P;VMR8>AO
M=F%T(&)E>B!P87)A;65T<G4@)W1A<F=E=$9I;&4G+@!.96QZ92!V>6UA>F%T
M(&%D<F5SX?@@(B5S(BX`3F5L>F4@=GEM87IA="P@<')O=&^^92!E>&ES='5J
M[2!P;V1S:W5P:6YY("5D+@!.96QZ92!P<F]VZ7-T('IM[&YU('5S<&_XX63A
M;NTL('!OZ&5T('!O<VMY=&YU=/UC:"!P;VQOOF5K('!R;R!N;W;I('5S<&_X
MX63A;NT@;F5O9'!O=NUDX2!P;^AT=2!U;&^^96[]8V@@<&]L;[YE:RX`3F5L
M>F4@>F%S;&%T('IP<N%V=2!N82!Z861A;ND@Z.US;&\N(`!#87!E(%9E<F1E
M`%1I='5L:WD`2V%T96=O<FEE(&$@>FYAZ&MY`$MA:FUA;G-KZ2!O<W1R;W9Y
M`$UO8FEL;NT@=&5L969O;@!-;[YN;W-T:2!B=?)K>0!/9'-T=7`@;65Z:2!B
M=?)K86UI.@!6;&%S=&YO<W1I(&)U\FMY`$UE>F5R>2!M97II(&)U\FMA;6DZ
M`$UO8FEL;NT@=&5L969O;@!+96QT<VO]("A)4T\M.#@U.2TQ-"D`4W3X960`
M4W3X961O869R:6-KX2!R97!U8FQI:V$`4W3X961O979R;W!S:_T@*$E33RTX
M.#4Y+3(I`%!O9')O8FYO<W1I(&-E<G1I9FEKX71U`%!O9&WM;FMY(&-E<G1I
M9FEKX71U`,AA9`!:;>QN:70`3F%S=&%V96[M(&IMZ6YA(&$@96UA:6QO=ND@
M861R97-Y+B!4>71O('!O;&^^:WD@;&EDZ2!U=FED[2P@:V1YOB!S:2#H=&]U
M(&YE8F\@;V1P;W;M9&%J[2!N82!68;EE('IP<N%V>2X`6FYA:P!::V]N=%]R
M;VQO=F%T(&]D:V%Z+BXN`%9Y8G)A="!?=KEE+[[A9&[I`$-H:6QE`,CM;F$`
MR.UNN71I;F$@>FIE9&YO9'6Y96[A("A'0C(S,3(I`%1R861IZ&[M(.CM;KET
M:6YA("A":6<U*0!:=F]L=&4@:&5S;&\`6G9O;'1E('6^:79A=&5L<VOI(&IM
MZ6YO`%9Y8F5R=&4@861R97/A^`!6>6)R870@>F]B<F%Z96[M(&1A='5M=3H`
M5GEB<F%T('1Y<"!S='EL=2!S97IN86UU("AP<F\@^&%Z96[I('-E>FYA;7DI
M`%;A;F_H;NT@;W-T<F]V`$YE8GEL82!N86QE>F5N82!D969I;FEC92!T^.UD
M>2`E<RX`5GGH:7-T:70`5GGH:7-T:70@>FYAZ&MY('H@35-/9F9I8V4`3V1S
M=')A;NQN[2!UOFEV871E;&4Z("5S`$]D<W1R86YI="!UOFEV871E;&4`3V1S
M=')A;NQN[2#Z9&%J^2!O('6^:79A=&5L:0!+;&EK;NQT92!P<F\@<&]K<F'H
M;W;A;NT`0VQI8VMA=&5L;"!P^&5S($A45%``6F%V^.UT(&]K;F\`6F%T8;YE
M;F\`3V)L8>AN;P!+;VMO<V]VZ2!O<W1R;W9Y`%-K;&%P;F]U="!B;^AN[2!L
M:;ET=0!3:VQA<&YO=70@;VMR86IE`$MO;'5M8FEE`$)A<G9A`%;]8NQR(&)A
M<F5V`%!A;&5T82!B87)E=@!3;&]U<&-E.@!-;[YN;W-T:2!S;&]U<&-E`$[A
M>G9Y('-L;W5P8V4`2V]M:6MS>0#(X7)K;W4@;V1D[&QE;ND@:&]D;F]T>0#(
MX7)K;W4@;V1D[&QE;ND@:&]D;F]T>2`H36EC<F]S;V9T($]U=&QO;VLI`%#X
M[6MA>@!0^.UK87IO=N$@:V]N>F]L80!0;WINX6UK80!/8F5C;ND@:FWI;F\`
M2V]M;W)O<P!&:7)M80!!9')E<V$@9FER;7D`4&_H[71AZ&4`4&]D;>UN:WD`
M4F]Z9.UL>2!V(&YA<W1A=F5N[0!.87-T879I="`E<P!0;W1V<F1I="!H97-L
M;P!+;VYG;P!+;VYG;RP@1&5M;VMR871I8VOA(')E<'5B;&EK80!3<&]J96[M
M('-E;&AA;&\N`%-P;VIE;NT@<V5L:&%L;SH@`%-P;VIE;NT@<V5L:&%L;SH@
M)7,`4W!O:F5N[2!S96QH86QO`$)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V
M9?AE:F[];2!K;.WH;W;];2!S97)V97)E;2X`0GEL;R!Z86WM=&YU=&\@<W!O
M:F5N[2!S('9E^&5J;OUM(&ML[>AO=OUM('-E<G9E<F5M+B!$^79O9"`Z("5S
M("@E<RD`4V5L:&%L;R!S<&]J96[M(',@1E10('-E<G9E<F5M+@!+;VYT86MT
M(&)Y;"!O9'-T<F%N[&X@>F4@<V5Z;F%M=2X`2V]N=&%K='D@=B!S97IN86UU
M.B`E<P!+;VYT86MT>2!B>6QY(/IS<.RY;NP@</AI9.%N>2!D;R!68;EE:&\@
M861R97/A^&4N`%!O:W)AZ&]V870`0V]O:V]V>2!O<W1R;W9Y`$MO;.'H96L`
M2V]P[7)O=F%T`$MO<.UR;W9A="!V_6+L<@!+;W-T87)I:V$`4&]B^&6^[2!S
M;&]N;W9I;GD`6G!RX79U(&YE;'IE(+EI9G)O=F%T('!O;6]C[2!01U`N`%IP
M<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@4$=0+@!:<'+A=G4@;F5L>F4@
MN6EF<F]V870@<&]M;V/M(%,O34E-12X`6G!RX79U(&YE;'IE('!O9&5P<V%T
M('!O;6]C[2!3+TU)344N`$YE;'IE('#X:61A="!K;VYT86MT+B`E<P!.96QZ
M92!S92!P^&EP;VII="!K($Q$05`@<V5R=F5R=2X`3F5L>F4@>FMO;G1R;VQO
M=F%T(/KH970N("5S`$YE;'IE('9Y='9O^&ET(&1I<W1R:6)UZ&[M('-E>FYA
M;2X@)7,`3F5L>F4@9&6Y:69R;W9A="!01U`@9&%T82X`3F5L>F4@9&6Y:69R
M;W9A="!3+TU)344@9&%T82X`3F5L>F4@<VUA>F%T(&MO;G1A:W0N("5S`$YE
M;'IE('-M87IA="!D:7-T<FEB=>AN[2!S97IN86TN("5S`$YE;'IE('IJ:7-T
M:70@92UM86EL;W9O=2!A9')E<W4@</CM:F5M8V4N`$YE;'IE('KM<VMA="#Z
M<&QN_2!A9')E<^'X+@!.96QZ92!Z[7-K870@^G!L;OT@9&ES=')I8G7H;NT@
M<V5Z;F%M+@!.96QZ92!Z[7-K870@^G!L;OT@<V5Z;F%M(&1I<W1R:6)UZ&[M
M8V@@<V5Z;F%M^2X`3F5L>F4@>NUS:V%T('9E^&5J;OT@:VSMZ"!Z(&ML[>AO
M=NEH;R!S97)V97)U+@!.96QZ92!O=&5V^.UT("5S+@!.96QZ92!P<F]VZ7-T
M(&]P97)A8V4@^F1ROF)Y('!R;R!M;V1U;"`E<P!.96QZ92#H[7-T("5S+@!.
M96QZ92!R97-E=&]V870@:&5S;&\@<')O(&1A;NEH;R!UOFEV871E;&4N(%:Y
M96-H;GD@;F5B;R!N[&MT97+I('H@<&]D<F]B;F]S=.T@;F5B>6QY('-P<N%V
M;NP@>F%DX6YY+B!::W5S=&4@=&\@>FYO=G4@;F5B;R!P;VMU9"!P;W3X96)U
M:F5T92!P;VUO8RP@:V]N=&%K='5J=&4@<W!RX79C92!S>7-TZ6UU+@!.96QZ
M92!Z[7-K870@04-,`$YE;'IE('KM<VMA="!A9')E<^'X+B`E<P!.96QZ92!Z
M[7-K870@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!Z[7-K870@9&ES
M=')I8G7H;NT@<V5Z;F%M>2X@)7,`3F5L>F4@>NUS:V%T('-C:&]P;F]S=&D@
M<V5R=F5R=0!.96QZ92!P^&5P;F]U="!K;VYF:6=U<F%C:2X`3F5L>F4@=6QO
MOFET(&MO;F9I9W5R86-I('!R;R`E<RX`3F5L>F4@=6QOOFET('KA;&^^;NT@
M:V]N9FEG=7)A8VDN`$YE;'IE('5L;[YI="!ZX6QO:'4@:V]N9FEG=7)AZ&[M
M:&\@<V]U8F]R=2`E<RX`3F5L>F4@:&QE9&%T('8@3$1!4"!S97)V97)U+@!.
M96QZ92!A:W1U86QI>F]V870@:V]N=&%K="X@)7,`3F5L>F4@86MT=6%L:7IO
M=F%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,`3F5L>F4@;F%LZ7IT(&)OZ&[M
M(&QIN71U('!R;R!-;WII;&QU+B!0<F]S[6T@</AE<W;L9.AT92!S92P@OF4@
M:F4@;W1E=OAE;N$N`$]D<&_H[71A;OT@=&5X=`!:96WL`%9Y=>AO=F%C[2!P
M^&5D;>QT>0!6>71V;_AI="!O9&MA>@!6>71V;_AI="!N;W9O=0!6>71V;_AI
M="!P;V1S;&^^:WD`5GET=F_X96YO`%1V^7)C92!P<N%V`,CM<VQO(&MR961I
M=&[M(&MA<G1Y`$-H;W)V871S:V\`2W5B80!!:W1UX6QN[2#H87,`06MT=>%L
M;NT@55),(&IE`$%K='7A;&[M('!OZ&%S[0!!:W1UX6QN[2!P;V1M[6YK>3H@
M`$YY;NQJN>T@<W1Y;`!.87-T879E;NT@^FMO;/D@<')O=N%D[&[]8V@@</AI
M('#X:6ALX;EE;NT@9&\@)7,N`%9Y<W3X:6AN;W5T`%9Y<W3X:6AN;W5T(';]
M8NQR`$MY<'(`07IB=6MA("A+3TDX+5(I`$%Z8G5K82`H5VEN9&]W<RTQ,C4Q
M*0!!>F)U:V$O56MR86II;F$@*$M/23@M52D`R&5S:^$@<F5P=6)L:6MA`$1$
M`$1E;F[L`$1A=&%4<F5E('!R;VAL[;YEZ`!$871U;0!0^&EJ871O(&1N90!6
M_6+L<B!D871U;74`1&5N`%-M85]Z870@<VQO=7!E8P!0<F]S:6YE8P#([7-L
M82!D97/M=&MO=ND@<V]U<W1A=GD`6FUE;KEI="!O9'-A>F5N[0!);7!L:6-I
M=&[M`$EM<&QI8VET;NT@8F%R=F$`26UP;&EC:71N[2!I9&5N=&ET80!);7!L
M:6-I=&[M('-M['(@=/CM9.QN[3H`1&5F:6YI8V4`4VUA>F%T`%!O='9R>F5N
M[2!S;6%ZX6[M`%-M87IA="!S:W5P:6YU`%-M87IA="!P<N%V80!3;6%Z870@
M82!V>>AI<W1I="!Z<'+A=GD`5FQA<W1N;W-T:2!T;&'H[71K82!P<F\@<VUA
M>N%N[0!3;6%Z870@8G7R:W4`4VUA>F%T('-L;W5P96,`4VUA>F%T(&5X:7-T
M=6KM8^T@86QT97)N871I=F[M('9Z;W(`4VUA>F%N[2!S96QH86QO.B`H)7,I
M("5S`%-M87IA="#XX61E:P!3;6%Z870@=GEB<F%N;W4HZ2D@:61E;G1I='4H
M>2D`4VUA>F%T('-O=>AA<V[]('-L;W5P96,`4VUA>F%T('-O=>AA<V[](/CA
M9&5K`%-M87IA;NT@<V5L:&%L;P#(87,@9&]R=>AE;NT`1.%N<VMO`$]D9.QL
M[&[M`%-E<W1U<&[L`%!O<'-A="!P<F]B;.EM`%!O9')O8FYO<W1I("AT86OI
M('8@;&]G('-O=6)O<G4@2&]R9&4I.@!0;V1R;V)N;W-T:2!B>6QY('IA>FYA
M;65NX6YY(&1O(&QO9R!S;W5B;W)U('!R;R!A9&UI;FES='+A=&]R82X`5OUV
M;VH`4F]S;OT@8F]D`%)O<V[](&)O9"!Z82!P;W-L961N[2!H;V1I;G4Z(`!2
M;W-N_2!B;V0Z(`!3;>QR('H@;&5V82!D;W!R879A`%-M['(@>B!P<F%V82!D
M;VQE=F$`061R97/A^`!:;V)R87II="`R-"UH;V1I;F]V_2#H87,_`%IO8G)A
M>FET(&UOOFYO<W1I`%IO8G)A>FET('#X961P;W;L[R`H5$%&*0!&;W)MX70@
M>F]B<F%Z96[M`$1I<W!O>FGH;NT@=7!O>F]R;NQN[0!$:FEB;W5T:0!.97-M
M87IA=`!.97#X:7-T=7!O=F%T('#X[6UO(&1O(&UA:6YT96YA;F-E+G!H<`!#
M:&-E=&4@<&]T=G)D:70@<VUA>N%N[2!P;VQOOF5K/P!/8G-A:'5J92!P<G9N
M[2#XX61E:R!NX7IE=B!S;&]U<&/Y/R!0;VMU9"!A;F\L('IAN6MR=&[L=&4@
M=&5N=&\@<N%M9>AE:SH`1&]M:6YI:V$`1&]M:6YI:^%N<VOA(')E<'5B;&EK
M80!3=&&^96[M("5S`%-T86AN;W5T(&=E;F5R;W9A;F]U(&MO;F9I9W5R86-I
M(&IA:V\@4$A0('-K<FEP="X`4W1A:&YO=70@=D-A<F0`4F]L971O=OT@<V5Z
M;F%M`$1R;V=Y`$4M;6%I;`!%4E(`16MVX61O<@!5<')A=FET`%5P<F%V:70@
M8FQO:P!5<')A=FET('-K=7!I;G4`57!R879I="!P<N%V80!5<')A=FET('!R
MX79A`%5P<F%V:70@<'+A=F$@<')O("5S`%5P<F%V:70@<&]L;[YK=2!P<F\@
M)7,`57!R879I="!M;[YN;W-T:2!P<F\Z`%5P<F%V:70@<'+A=F$@<')O("5S
M`%;]=6MA`$5G>7!T`$5L(%-A;'9A9&]R`%!R=F5K+BXN`$5M`$5M86EL`$5M
M86EL;W;A(&%D<F5S80!%;6%I;&]VZ2!A9')E<WD@<V4@;75S[2!S:&]D;W9A
M="X`16UA:6P@<R!P;W1V<GIE;NUM`$EK;VYK>2!S(&5M;V-E;6D`4'+A>F1N
MX2!Z<'+A=F$N`%!RX7ID;OT@=OUS;&5D96LN`%!RX7ID;OT@=&5R;>UN('!R
M;R!V>6AL963A=N%N[0!0;W9O;&ET('9K;.%DX6[M(&]B<F%Z:_D@>B!F;W1O
M(&=A;&5R:>T@9&\@=&5X='4_`$%K=&EV;W9A="!P<F%VZ2!K;&EK;G5T[2!P
M<F\@:V]N=&5X=&]VZ2!M96YU/P!+;VYE8R!R;VMU`%IV['2Y:70@961I=&]R
M`%IA9&5J=&4@8F5Z<&7H;F]S=&[M(&]TX7IK=2P@;F$@:W1E<F]U(&)U9&5T
M92!M=7-E="!O9'!O=NQD['0@<&]K=60@<VD@8G5D971E(&-H=.UT(')E<V5T
M;W9A="!S=ND@:&5S;&\L(&YA</@N("=*86OI(&IE(&IMZ6YO(%9AN65H;R!P
M<V$_)SH`6F1E('9L;[YI="!54DP@;V)RX7IK=0!0;VQOOFMY('!R;R`E<R!B
M>6QY(&%K='5A;&EZ;W;A;GDN`%)O=F[M:V]VX2!'=6EN96$`17)I=')E80!#
M:'EB80!.87-T86QA(&-H>6)A(',@<&^Y=&]V;NT@>G!RX79O=2X`17-T;VYS
M:V\`171I;W!I90!%=&YI8VOI`$5V<F]P80!+8;YD_6-H(#$U(&UI;G5T`$MA
MOF3I(#(@;6EN=71Y`$MAOF3]8V@@,S`@<V5K=6YD`$MAOF3]8V@@-2!M:6YU
M=`!+8;YDZ2!P^&EH;.&Y96[M(&1O('-Y<W3I;74`2V&^9&]U('#Y;"!H;V1I
M;G4`2V&^9&]U(&UI;G5T=0!6>F]R;W;]('#X[6ML860@:&]D;F]T.@!0<F]V
MZ7-T`%)O>G9I;F]U=`!2;WIB86QI="!B;^AN[2!L:;ET=0!/Z&5KX7;A;F$@
M)RDG`$_H96OA=N%N;R!S86UO<W1A=&[I('-L;W9O(&YE8F\@:&QE9&%N_2!T
M97)M[6X@=B!U=F]Z;W9KX6-H`$1A='5M('!R;R!K;VYE8R!P;&%T;F]S=&D`
M17AP;VYE;G0`17AP;W)T;W9A=`!%>'!O<G1O=F%T(&%D<F5SX?@`17AP;W)T
M;W9A="!P;W5Z92!V>6)R86[I(&MO;G1A:W1Y+@!+;VUP;&5T;NP@97AP;W)T
M;W9A="!NX7-L961U:NUC[2!A9')E<^'X+@!"87)V82!P;W#X963M`%#X96YO
M<R!K;VYF:6=U<F%C92!P;VUO8^T@1E10`%-E;&AA;&\@>NUS:^%N[2!M;[YN
M;W-T[2X`3F5L>F4@</AI<W1O=7!I="!K(&%D<F5SX?AI.B`E<P!396QH86QO
M('#X:63A;NT@)7,@9&\@)7,Z("5S`$YE;'IE('!R;VALZ61N;W5T('-E>FYA
M;0!.96QZ92!P<F]H;.ED;F]U="!A9')E<^'X`%-E;&AA;&$@>FWL;F$@:FWI
M;F$Z("@E<RD@)7,[('-T87+I($1.(#T@)7,L(&YO=ND@1$X@/2`E<RP@4F]O
M="`]("5S`$YE;'IE('-E('#X:7!O:FET(&L@3$1!4"!S97)V97)U+@!.96QZ
M92!S92!P^&EP;VII="!K(%--0B!S97)V97)U+@!396QH86QO(&MO<.UR;W;A
M;NT@>B`B)7,B+@!396QH86QO(&MO<.UR;W;A;NT@9&\@(B5S(BX`4V5L:&%L
M;R!Z86QOOF5N[2!N;W;I:&\@4T%33"!S<&]J96[M+@!.96QZ92!N86SI>G0@
M;V)J96MT(&L@</AI9.%N[3H@)7,`4V5L:&%L;R!P^&5S=6YU=.T@9&\@(B5S
M(BX`3F5L>F4@<')O:&QE9&%T(&MO;G1A:W1Y.B`E<P!$;V)RZ0!&86QK;&%N
M9'-KZ2!O<W1R;W9Y("A-86QV:6YY*0!&87)I:G-KZ2!O<W1R;W9Y`%KA=F&^
M;N$@8VAY8F$Z`$9A>`#:;F]R`$/M=&ET('-E(&IA:V\`0^UT:70@<V4@:F%K
M;SH`1')O8F[I('#X96CA\FMY`$1R;V)NZ2!S;NQH;W;I('#X96CA\FMY`$UA
M=&EC92!P;VQE`$9I:FD`4&_H970@<V]U8F]R^3H@)7,@<V]U8F]R`%!OZ&5T
M('-O=6)O<ODZ("5S('-O=6)O<OD`4W!RX79C92!S;W5B;W+Y`$[A>F5V('-O
M=6)O<G4`5OUB['(@<V]U8F]R=0!0^&5NZ7-T('-O=6)O<@!0^&5N;W,@<V]U
M8F]R^2!N96[M('!O9'!O<F]VX6XN`$9I;'1R>0!(;&5D870`1FEN<VMO`%!R
M=F[M('!O;&]V:6YA`$IMZ6YO`%!R=F[M(.AT=G)T:6YA`%!E=F[I(&WL^.UT
M:V\`4/AE:&]D:70`4&QO=F]U8^T`36QH80!3;&^^:V$@)7,@;F5E>&ES='5J
M90!"87)V82!P[7-M80!*[61L;P!0<F\@<')O:&SMOF7H92!N97!O9'!O<G5J
M[6/M(&]B<N%Z:WD`4/AE9'!O=NSO("A4048I`%#X961P;W;L[R!P;^AA<^T@
M<')O(&1N>2`H<&]Z;N%M:V$Z('#X961P;W;L[R!J92!P<F\@9&YY(&D@;F]C
M:3L@=&]T;R!M^;YE('9Y='9O^&ET('!O;>QR;NP@;V)SX6AL_2!S97IN86TN
M`%IA<&]M;NQL:2!J<W1E(%9AN64@:&5S;&\_`$9O<FUU;.'X90"I=.QS=.T`
M5'EP(+ET['-T[0"I=.QS=.T`J73L<W3M(#(`1O-R80!0^&5P;W-LX6[M`%#A
M`%+A;7D`1G)A;F-I90!&<F%N8VEE+"!M971R;W!O;&ET;NT`1G)E92]"=7-Y
M(%523`!&<F%N8V]U<VOA($=U86GA;F$`1G)A;F-O=7-KX2!0;VQY;NES:64`
M1G)A;F-O=7-KX2!J:;YN[2!T97)I=&]R:6$`3V0`3V0`4&]D<F]B;OT@<&]P
M:7,`VG!L;NQK`$-E;.D@:FWI;F\`1V%B;VX`1V%L97)I92!P<F\@=OUB['(@
M;V)RX7IK^0!'86QE<FEE.@!'86UB:64`5GET=F_X:70@)7,@:V]N9FEG=7)A
M8VD`5GEG96YE<F]V86[](&OS9`!'<G5Z[6YS:V\`3NQM96-K;P!':&%N80!'
M:6)R86QT87(`2_AE<W1N[2!J;>EN;P!';&]BX6QN[2!A9')E<^'X`$ID:2!N
M80!';V5D96P`5GEH;&5DX7;A;NT@<&]M;V/M($=O;V=L=0!3='5P;NP@N65D
M:0#896-K;P#896-KZ2`H25-/+3@X-3DM-RD`1W+S;G-K;P!'<F5N861A`%-K
M=7!I;F$`061M:6YI<W1R86-E('!R;R!S:W5P:6YY`$UU<^T@8OUT('IA9.%N
M;R!J;>EN;R!S:W5P:6YY`%-K=7!I;GD`1W5A9&5L;W5P90!'=6%M`$=U871E
M;6%L80!'=65R;G-E>0!0<N%V82!H;W-T^0!+;FEH82!H;W-T^0!'=6EN96$`
M1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!Z8F%B[&QE(&]D
M;>UTX2!S;6%Z870@<&]S;&5D;NT@8G7R:W4@;F$@^.%D:W4N`$A434Q!<F5A
M('IB86+L;&4@;V1M[73A('-M87IA="!P;W-L961N[2!B=?)K=2!V92!S;&]U
M<&-I('1A8G5L:WDN`$A434Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P
M;W-L961N[2#XX61E:R!V('1A8G5L8V4N`$]V[/AO=N%N[2!P;VUO8^T@2%14
M4"!N96)Y;&\@;F%L97IE;F\N`$AA:71I`$AA<V@M86QG;W)I=&UU<P!-;&AA
M=F\`2&QA=FGH:V$`2&5A<F0@27-L86YD(&$@36-$;VYA;&0@27-L86YD<P!(
M96)R96JY=&EN82`H25-/+3@X-3DM."U)*0!6_;EK80!.X7!O=NQD80!.X7!O
M=NQD82!P<F\@961I=&]R`%!O;6]C;NUK`$AE;6ES9NER80!:9&4@:F4@>F'H
MX71E:R!S;W5B;W)U.@!6>7-O:^$`7TAO<F1E`%-V873I($WL<W1O("A6871I
M:^%N*0!(;W)D90!!9')E<V$@9&]M^0!-['-T;R!A9')E<WD@9&]M^0!:96WL
M(&%D<F5S>2!D;VWY`%1E;&5F;VX@9&]M^0!04\@@9&]M^0!3=.%T+W!R;W9I
M;F-I92!A9')E<WD@9&]M^0!5;&EC92!A9')E<WD@9&]M^0!(;VYD=7)A<P!(
M;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($YE<&QA=&[I("5S(%A-3"!D
M871A('9E('IP<N%V["`E<P!(;W)D92]+;VQA8CH@KN%D;N$@>G!RX79A('-E
M(&YE<VAO9'5J92!S(&]B:F5K=&5M("5S`$AO<F1E+TMO;&%B.B!.96)Y;"!N
M86QE>F5N(+[A9&[](&]B:F5K="!T>7!U("5S('9E('IP<N%V["`E<P!(;W)D
M92]+;VQA8CH@VG-P[+ENZ2!O9'-T<F%N[&[M("5S("(E<R(`2&]R9&4O2V]L
M86(Z($EN=&5G<F'H;NT@;N%S=')O:B!P;W3X96)U:F4@4$A0('#X[7!O;G4@
M)V1O;7AM;"<`2&]R9&4O2V]L86(Z($YE;'IE('9Y='9O^&ET(&YO=OT@<W1R
M;VT@6$U,('!R;R!O8FIE:W0@)7,`2&]R9&4O2V]L86(Z($YE;'IE(&]D<W1R
M86YI="`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@3F5L>F4@>NUS:V%T($U)
M344@240@<')O(.CA<W0@='EP=2`E<P!(;W)D92]+;VQA8CH@3F5L>F4@<WEN
M8VAR;VYI>F]V870@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YE;'IE('-Y
M;F-H<F]N:7IO=F%T('-D[6QE;ND@;V)J96MT>3H@)7,`2&]R9&4O2V]L86(Z
M($YE>F[A;?T@<V3M;&5N_2!O8FIE:W0@(B5S(@!6;V1O<F]V;ND@<')A=NUT
M:V\`2&]R:7IO;G3A;&[M(&]D<W1U<`!(;W)I>F]N=.%L;NTZ`$IA:R!J<W1E
M('-E('-E;2!D;W-T86QI/R`H6F&Y;&5T92!P<F]S[6T@>G!RX79U(2D`2V]L
M:6L@<VQO=7!C^2!C:&-E=&4@<W!O:FET/P!+;VQI:R!J92!T86T@<&]L[2`H
M<VQO=7!C^2D_`$MO;&EK(/CA9&OY(&-H8V5T92!S<&]J:70_`%9L:&MO<W0`
M5FQH:V]S=#H`2'5M;W)NZ0!-8>]A<G-K;P!396QH86QO('9Y='9O^&5N[2!)
M34%0;W;I('-C:'+A;FMY.B`E<P!396QH86QO('-M87KA;NT@24U!4&]VZ2!S
M8VARX6YK>3H@)7,`4V5L:&%L;R!N87-T879E;NT@:W;S='D@<')O($E-05!O
M=F]U('-C:'+A;FMU.B`E<P!)35-0`$E0(&%D<F5S80!)4"!A9')E<V$@;F5N
M[2!D;W-T=7!NX2X`25`@861R97-A(&YE;NT@=B!P;W9O;&5NZ6T@0TE$4B!R
M;WIS86AU+@!0;W)UN65N[2!I;G1E9W)I='D@25`N`%9?;&^^=&4@^.%D96L@
M</AE9`!)<VQA;F0`4&]U>F4@:6MO;GD`26MO;GD@<')O("5S`$EK;VYY(',@
M=&5X=&5M`$[A>F5V(&ED96YT:71Y.@!0;VMU9"!Z;V)R87IE;NT@;F5N[2!V
M('!O^.%D:W4L("5S(&]T97;X[70@=B!N;W;I;2!O:V[L+@!0;VMU9"!P;W6^
M[7;A=&4@26YT97)N970@17AP;&]R97(@82!N979I9.UT92"^X61NZ2!I:V]N
M>2P@>OAE:FWL('!O=/AE8G5J971E(&]Z;F'H:70@=&5N=&\@<N%M9>AE:R!P
M<F\@=GEP;G5T[2!03D<@=')A;G-P87)E;F-E+@!0;VMU9"!V:63M=&4@='5T
M;R!Z<'+A=G4@;>US=&\@;V)RX7IK=2P@;V)RX7IE:R!K=&5R_2!C:&-E=&4@
M</AE;NES="!N96QZ92!68;GM;2!P<F]H;.V^9>AE;2!Z;V)R87II="X`3N%H
M;&5D(&]B<N%Z:W4Z`%523"!O8G+A>FMU`%523"!O8G+A>FMU.@!/8G+A>F5K
M('H@9V%L97)I90!/8G+A>F5K('H@9V%L97)I93H`4/AE;F]S(&]B<N%Z:W4`
M3V)RX7IK>0!);7!O<G1O=F%T(&%D<F5SX?@L(&MR;VL@)60`26UP;W)T+"!K
M<F]K("5D`$EM<&]R=&]V870O97AP;W)T;W9A="!A9')E<^'X90!);7!O<G1O
M=F%NZ2!P;VQE.B`E<P!);7!O<G1O=F%NX2!P;VQE.@!6;&^^:70@^.%D:W4@
M>F$`0GEL('IA9.%N(&YE<W!RX79N_2!A:^AN[2!K\V0N`$YE<W!RX79N["!Z
M861A;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+@!.97-P<N%V
M;ND@=;YI=F%T96QS:^D@:FWI;F\@;F5B;R!A;'1E<FYA=&EV;NT@861R97-A
M+B!::W5S=&4@:F6Y=.P@:F5D;F]U(&YE8F\@:V]N=&%K='5J=&4@5F&Y96AO
M('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T;W)A+@!:=NQTN6ET(&]D<V%Z96[M
M`$EN9&EE`$IE9&YO=&QI=NT@=;YI=F%T96SI`$EN9&]NZ7-I90!);F9O<FUA
M8V4`26YF;W)M86-E`%9L;[YI="!S7VQO=7!E8R!Z80!6;&^^:70@;V)RX7IE
M:P!6;&^^:70@=&%B=6QK=0!6;&^^:70@=V5B;W;](&]D:V%Z`%9L;[YI="!?
M<VQO=7!E8R!P^&5D(`!6;&^^:70@;F]V_2!S;&]U<&5C('IA('-O=>AA<V[]
M`%9L;[YI="!N;W;]('-L;W5P96,@</AE9"!S;W7H87-N_0!6;&^^:70@;F]V
M_2#XX61E:R!Z82!S;W7H87-N_0!6;&^^:70@;F]V_2#XX61E:R!P^&5D('-O
M=>AA<V[]`%9L;[YI="!O9'-T879E8R!Z82!S;W7H87-N_2!U>F5L`%9L;[YI
M="!O9'-T879E8R!P^&5D('-O=>AA<V[]('5Z96P`5FQOOFET(&%L=&5R;F%T
M:79N[2!V>F]R`%9L;[YT92!E;6%I;&]V;W4@861R97-U+"!N82!K=&5R;W4@
M;V)D<K[M=&4@;F]VZ2!H97-L;SH`5FQOOFET(&)U\FMU('IA`%9L;[YI="!B
M=?)K=2!P^&5D`%9L;[YI="!S;&]U<&5C('IA`%9L;[YI="!S;&]U<&5C('#X
M960`5FQOOFET('IP<N%V>0!6;&^^:70@;V1S=&%V96,@>F$`5FQOOFET(&]D
M<W1A=F5C('#X960`5FQOOFET(/CA9&5K('IA`%9L;[YI="#XX61E:R!P^&5D
M`%9L;[YT92!P;[YA9&]V86YO=2!O9'!O=NSO(&YA(&)E>G!EZ&YO<W1N[2!O
M=.%Z:W4Z`%9L;[YI="]U<')A=FET(&]B<N%Z96L`5FQOOFET+W5P<F%V:70@
M;V1K87H`3F5D;W-T871EZ&[](&MR961I="!K(&]D97-LX6[M('IP<N%V>2!N
M82!D:7-T<FEB=>AN[2!S97IN86TN`$YE9&]S=&%T9>AN_2!K<F5D:70N`$-E
M;.D@Z.US;&\`4V5Z;F%M(&-E;/UC:"#H[7-E;`!.97!L871NZ2!)1`!.97-P
M<N%V;ND@541(+B`H57-E<B!$871A($AE861E<BDN`$YE<&QA=&[](&%D<F5S
MX?@`3F5P;&%T;N$@87!L:6MA8V4N`$YE<&QA=&[I(&ED96YT:69I:V'H;NT@
MZ.US;&\@*$E$*2!DX79K>2X`0GEL82!Z863A;F$@;F5P;&%T;N$@9&%T80!.
M97!L871NX2!A9')E<V$@</CM:F5M8V4N`$YE<&QA=&[](&5M86EL`$YE<&QA
M=&[A('!O;&^^:V$`3F5P;&%T;OT@9F]R;>%T('-O=6)O<G4`0GEL('!O<VMY
M=&YU="!N97!L871N_2!K;.WH+@!.97!L871N_2!M<V=?='EP92X`3F5P;&%T
M;ND@:FWI;F\`3F5P;&%T;ND@240@;V)J96MT=0!.97!L871NZ2!N96)O(&-H
M>6+L:NUC[2!A<&E?:60N`$YE<&QA=&[I(&YE8F\@8VAY8NQJ[6/M('!A<F%M
M971R>2X`3F5P;&%T;N$@=FQA<W1N:6-KX2!P<N%V82X`3F5P;&%T;OT@<')O
M=&]K;VPN`$YE<&QA=&[]('-D[6QE;OT@;V)J96MT`$YE<&QA=&[A(&%D<F5S
M82!O9&5S[6QA=&5L92X`3F5P;&%T;N$@9&%T82!U;FEC;V1E+@!);G9E;G3A
M^`#-<N%N+"!)<VSA;7-KX2!R97!U8FQI:V$`27+A:P!)<G-K;P!/<W1R;W8@
M;76^90!/:F5D:6[L;.D@8F]U^&MY`$ES<F%E;`!0;W-K>71O=F%T96P`2W5R
M>NUV80!)=.%L:64`2F%M86IK80!,961E;@!*87!O;G-K;P!*87!O;KET:6YA
M("A)4T\M,C`R,BU*4"D`5')I:V]T`$IO<F3A;G-K;P#(97)V96YE8P#(97)V
M96X`6F%R;W9N870`6F%R;W9N870@;F$@<W3X960`6F%R;W9N870@=GEP;&[L
M;NUM`%IA<F]V;F%T(&1O;&5V80!:87)O=FYA="!D;W!R879A`$MA>F%C:'-T
MX6X`56-H;W9A="!O<FEG:6[A;#\`2V7R80!+97)B97)O<R!S97)V97(@>F%M
M[71N=6P@;W;L^&5N[2X`3F]VX>AC:2!K97)N96QU`%9Y='9O^&5N[2!K;.WH
M90!6>71V;_AE;NT@;W1I<VMU(&ML[>AE`$3I;&MA(&ML[>AE`%1Y<"!K;.WH
M90!5OFET[2!K;.WH90!+;.WH(&IIOB!E>&ES='5J92!N82!V9?AE:F[I;2!K
M;.WH;W;I;2!S97)V97)U+@!$['1I`$MI<FEB871I`$M,1%(`2V]R96$`2V]R
M96IS:WD@*$550RU+4BD`2W5V86IT`$MY<F=I>G-TX6X`2F4@=GF^861O=N%N
M($Q$05`L(&%L92!T96YT;R!M;V1U;"!N96[M(&1O<W1U<&[](&YE8F\@:6YS
M=&%L;W9A;OTN`%]2;WIL;[YE;NT`2F%Z>6L`3&%O<RP@3&ED;W;L($1E;6]K
M<F%T:6-K82!297!U8FQI:V$`1')U:.$@<&]L;W9I;F$`3F%P;W-L961Y('IM
M[&[L;F\`4/CM:FUE;NT`4&]S;&5D;NT@Z'1V<G1I;F$`4&]S;&5D;NT@86MT
M=6%L:7IA8V4Z`%!O<VQE9&[M('#X:6ALX;EE;NTZ("5S`%!O<VQE9&[M('#X
M:6ALX;EE;NTZ("5S('H@)7,`4&]S;&5D;NT@</AI:&SAN65N[3H@3FEK9'D`
M3&ET=F$`4'+A=F\`4F]Z;&^^96[M`$YE8VAA="!P<N%Z9&[I(&)E>B!O:W)A
M:F4`3&EB86YO;@!$;VQE=F$`3&5VX2!H;&%V:>AK80!(;V1N;W1Y(&YA;&5V
M;P!,97-O=&AO`$QI8NER:64`3&EB:64`3&EC:'1E;KET96IN<VMO`$QE:&OI
M(&UR:&]L96[M`$QE:&O](&3IN;L`0G)Z:_T@;&5H:_T@9.FYNP!0;WID[&II
M(&QE:&O](&3IN;L`3&5H:^D@9&6YNV]VZ2!S<N&^:WD`3&5H:_T@9.FYNR!S
M(&CX;>QN[6T`3&5H:^D@<V[LOF5N[0!,96AKZ2!S;NQH;W;I('#X96CA\FMY
M`$QI;65R:6-K`$]D:V%Z`$]D:V%Z>2!U:V%Z=6KM(&YA.@!0;W6^[70@;V1K
M87IY(&YA(&5M86EL;W;I(&%D<F5S>2!P^&D@>F]B<F%Z;W;A;NT@<W1RX6YK
M>2!P<F\@<'-A;NT@>G!RX78`3V1K87IY`$QI;G5X;W;I(&-O;VMI90!397IN
M86T`4V5Z;F%M("T@=;YI=F%T96P@;?F^92!V:63L="!S;&^^:W4`4V5Z;F%M
M(&1A=&%BX7KM`%-E>FYA;2!TZ6UA="!NX7!O=NQD>0!397IN86T@=&%B=6QE
M:P!397IN86TM07)C:&EV`%-E>FYA;2U.X7!O=NQD80!397IN86TM260`4V5Z
M;F%M+59L87-T;NUK`%-E>FYA;2U/9&5S;.%N[0!397IN86TM4/AI:&SAN65N
M[0!397IN86TM3V1H;.&Y96[M`%;]<&ES('6^:79A=&5L^2!N96[M(&1O<W1U
M<&[]+@!,:71E<F%T=7)A`$QO='FY<VMO`$YA:'+A=N%N[2XN+@!-[7-T;NT@
MZ&%S.B``3&]C86QE(&$@Z&%S`$WM<W1O`%#X:6ALX7-I="!S90!/9&ALX;EE
M;NT`VFMO;'D@<')O=N%D[&[I('#X:2!P^&EH;.&Y96[M`%-E;&AA;&\@</AI
M:&SAN65N[2!D;R!S>7-TZ6UU+B!0<F%V9.QP;V1O8F[L(%9AN64@=;YI=F%T
M96QS:^D@:FWI;F\@82]N96)O(&AE<VQO(&YE8GEL;R!S<'+A=F[L('IA9.%N
M;RX`4/AI:&SAN65N[2!S96QH86QO+@!$;&]U:/T@=&5X=`!,X7-K80!.[7IK
MX0!-86SA(/AE8VOA('#M<VUE;F$`36%LX2!T:7-K86/M('#M<VUE;F$`36%L
MZ2#X[6US:^D@Z.US;&EC90!,=6-E;6)U<G-K;P!-30!:<'+A=F$@9&YE`%#X
M:7!O:F5N_2!S;W5B;W(@35,M3E1%1B!N96]B<V%H=6IE(+[A9&[A(&1A=&$N
M`$U31P!-86MA;P!-86ME9&]N:64L(&+]=F%LX2!297!U8FQI:V$@2G5G;W-L
MX79I90!-861A9V%S:V%R`$UA9VEE`%!ON71A`$%D;6EN:7-T<N%T;W(@<&^Y
M='D`5GET=F_X:70@;V1?:V%Z+BXN`$UA;&%W:0!-86QA:G-I90!-86QD:79Y
M`$UA;&D`36%L=&$`4')O('5M;[YN[&[M(&]V;.%DX6[M(&MA=&5G;W)I[2!J
M92!Z87!O=/AE8NT@;WIN8>AI="!P;VQOOFMY(&)A<G9A;6DL(&MT97+I(&IS
M;W4@</AI^&%Z96YY(&L@=.QM=&\@:V%T96=O<FGM;2X`36%P82!-87`R-`!-
M87!A($UA<%%U97-T`$+X97IE;@!/:W)A:@!/>FYAZ&ET('IN8>AK;W4@4')O
M:&SI9&YU=&\O3F5P<F]H;.ED;G5T;P!/>FYAZ&ET(&II;OUM:2!Z;F'H:V%M
M:2`H:F%K;R!$^6QEOFETZ2]/9'!O=NQZ96[I*0!-87*Y86QS:^D@3W-T<F]V
M>0!-87)T:6YI<75E`%-H;V1U:NUC[2!S92!S`%-H;V1U:NUC[2!S92!P;VQE
M`$UA=7)E=.%N:64`36%U<FEC:75S`$UA>&EM86QN[2!P;W9O;&5N_2!K<F5D
M:70`0GEL82!P^&5K<F_H96YA(&UA>&EM86QN[2!DZ6QK82!Z<'+A=GDN`$YE
M:G9YN;GM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`R-"!H;V1I;CH@`$YE:G9Y
MN;GM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`V(&AO9&EN.B``36%X:6WA;&[M
M(&3I;&MA`$UA>&EMX6QN[2!P;^AE="!S='+A;F5K`$MV['1E;@!-87EO='1E
M`$UE9&EC[6YA`,AL96YO=ND`3?-D>2!P<F\@;65N=3H`4W!O:FET(&)U\FMY
M`%IP<N%V80!:<'+A=F$@8GEL82!O=NSX96YA('8@<&_XX61K=2P@86QE(&YE
M;'IE(&]V[/AI="!P;V1P:7-O=OT@8V5R=&EF:6OA="X`6G!RX79A('!R;W!A
M9&QA+@!4>7`@>G!RX79Y`%!OZ&%S[0!";&]K(&\@<&_H87/M(&YE;NT@9&]S
M='5P;OTN`$)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T=7!N_2X@4&]D<F]B;F]S
M=&D@8GEL>2!Z87IN86UE;N%N>2!P<F\@<WES=.EM;W;I:&\@861M:6YI<W1R
MX71O<F$@9&\@;&]G=2X`365T;V1A`$UE=')I8VO]`$UE>&EK;P!-:6MR;V[I
M<VEE+"!&961E<F%C90!5<')O<W3X960`5'EP($UI;64`3F5J;FF^N>T@=&5P
M;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``3F5J;FF^N>T@=&5P;&]T
M82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!-86SI('9Y:&QE9.%VX6[M`%IR
M8V%D;&]V[`!2^7INZ0!#:'EB[&KM8^T@1$X@=2!K;VYF:6=U<F%C92!Z9')O
M:F4@3$1!4"X`4')O9W)A;6]V_2!B86SM:R!(5%107U)E<75E<W0@8VAY8NT@
M=B!014%2+@!#:'EB[&KM8^T@:V]N9FEG=7)A8V4N(%!O:W5D('-I('#X96IE
M=&4@<&]UONUV870@='5T;R!A<&QI:V%C:2P@;75S[71E('9Y9V5N97)O=F%T
M(&MO;F9I9W5R8>AN[2!S;W5B;W(N`$-H>6+L:NUC[2!)1"!Z<'+A=GD@*&ED
M96YT:69I:V'H;NT@Z.US;&\I`%!OOF%D;W9A;OT@<')O9W)A;6]V_2!B86SM
M:R!-86EL(&-H>6+M('8@4$5!4BX`0VAY8NQJ[6/M($E$('!R;R!R96QA8VDN
M`%!O`$UO8FEL;NT@<&^Y=&$`36]B:6QN[2!T96QE9F]N`$WM<F[]`$1A='5M
M('!O<VQE9&[M('IM[&YY`%IM[/)I="!54DP`4V5L:&%L82#Z<')A=F$Z("@E
M<RD@)7,`36]D=6P`36]L9.%V:64`36]N86MO`$UO;F=O;'-K;P!-['/M8R!A
M(')O:P!-['/MZ&[L`$UO;G-E<F%T`$;A>F4@3>QS[6-E`$)Y;&$@;F%L97IE
M;F$@=NUC92!N9;X@,2!P;VQOOFMA`$UA<F]K;P!0^&5VX;YN["!J87-N;P!0
M^&5VX;YN["!O8FQAZ&YO`%#X97;AOF[L('-L=6YEZ&YO`%#X97-U;F]U=`!0
M;W-U;F]U="!D;VSY`%!O<W5N;W5T(&1O;&5V80!0;W-U;F]U="!D;W!R879A
M`%!O<W5N;W5T(&YA:&]R=0!0;W-U;F]U="!D;VSY`%#X97-U;F]U="!V;&5V
M;P!0^&5S=6YO=70@=G!R879O`%!O<W5N;W5T(&YA:&]R=0!-;W-A;6)I:P!-
M=6QB97)R>2!A9')E<^'X`%;M8V4M^G)O=O)O=ND@<F]L971O=ND@<V5Z;F%M
M>0!6[6-E(&]S;V(@<R!A9')E<V]U(%LE<UTL(&%L92!S92!J;>EN96T@6R5S
M72!N965X:7-T=6IE(&YI:V1O`%;M8V5NX7-O8F[A('-E;&5K8V4`3?EJ(/KH
M970`3?EJ('!O<G3A;`!-;VIE(')O>FQOOF5N[2!P;W)TX6QU`$UY86YM87(`
M3D4L($Y%4T]52$Q!4\U-`$IMZ6YO`$9O<FWA="!J;>EN80!.86UI8FEE`$YA
M=7)U`$YE<.%L`$YE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y`$YI>F]Z96WM
M`$YI>F]Z96US:^D@06YT:6QY`$YE='-C87!E($)A<V4@55),`$YE='-C87!E
M($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T
M<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`2FWI
M;F\@3F5T<V-A<&4@4U-,('-E<G9E<G4`4&]Z;N%M:V$@:R!C97)T:69I:^%T
M=2!.971S8V%P=0!4>7`@8V5R=&EF:6OA='4@3F5T<V-A<'4`4^V[`$YI:V1Y
M`$YO=N$@2V%L961O;FEE`$YO=N$@:V%T96=O<FEE`$YO=OT@:V]N=&%K=`!-
M['/M8R!V('!R=F[M(.AT=G)T:6[L`$YO=ND@=;YI=F%T96QS:^D@:FWI;F\@
M*&YE<&]V:6YNZ2D`3F]V_2!:Z6QA;F0`3F]VZ2!O:VYO("A?<'+A>F1NZ2D`
M3F]V:6YK>0!.97=S9W)O=7!S`$1A;+GM`$1A;+GM(&UOOFYO<W1I`$YI:V%R
M86=U80!0^&5Z9.UV:V$O86QI87,`3FEG97(`3FEGZ7)I90!.;V,`3FEU90!.
M90"NX61NX2!P;VQOOFMA("5S(&YE8GEL82!N86QE>F5N82!P<F\@)7,`3F5B
M>6P@;F%L97IE;B"^X61N_2!A9')E<^'X+@"N861NX2!K;VYF:6=U<F'H;NT@
M9&%T82!N96IS;W4@9&]S='5P;N$@<')O('IO8G)A>F5N[2!R;WID[6SY+@!.
M96[M(&1O<W1U<&[A(+[A9&[A('-T<F%T96=I92!P<F\@='9O<F)U($E33R!O
M8G)A>ODN`$)E>B!DX79K;W;I:&\@=GIO<G4N`$YA('!OOF%D;W9A;ND@<&]Z
M:6-I(&YE97AI<W1U:F4@ON%D;OT@8FQO:P!.96)Y;&\@<&]S:WET;G5T;R"^
MX61NZ2!J;>EN;R!P<F\@:V%L96YDX?@@</AI(&]V[/AO=N%N[2!P;VUO8^T@
M34-!3"X`0F5Z('IM[&YY+@!.96QZ92!P^&ED870@ON%D;N$@<&]D+7!RX79A
M(&L@=.QM=&\@<'+A=OEM+@!.96)Y;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U
M<F'H;NT@:6YF;W)M86-E('!R;R`E<RX`3F5B>6QY('5V961E;GD@ON%D;ND@
M:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@1E10(%9&4RX`3F5B>6QY('5V
M961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@4U%,(%9&
M4RX`3F5B>6QY('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C
M92!P<F\@4U%,+49I;&4@5D93+@!.96)Y;'D@;F%L97IE;GD@ON%D;ND@:V]N
M=&%K='DN`$YE;>%T92"^X61N_2!K<F5D:70N`$YE8GEL('!O<VMY=&YU=""^
MX61N_2!C[6PN`*[A9&[]('-O=6)O<B!N96)Y;"!P^&5N97-E;@!.96)Y;'D@
M;F%L97IE;GD@ON%D;ND@:6MO;GDN`$YE8GEL;R!V>6)RX6YO(+[A9&[I(&WM
M<W1O+@!.96)Y;'D@<&]S:WET;G5T>2"^X61NZ2!Z<'+A=GDN`$YE8GEL;R!U
M=F5D96YO(+[A9&[I(&IMZ6YO+@!.96)Y;&\@=79E9&5N;R"^X61NZ2#H[7-L
M;RX`0F5Z(&YE<VQUN6[]8V@`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O
M(&]V[/AE;NT@<&]M;V/M($A45%`N`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO
M('!R;R!O=NSX96[M('!O;6]C[2!)34%0+@!.96)Y;&\@<&]S:WET;G5T;R!H
M97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@2V5R8F5R;W,N`$YE8GEL;R!P;W-K
M>71N=71O(&AE<VQO('!R;R!O=NSX96[M('#X:6ALX;EE;NT@<V4@9&\@<WES
M=.EM=2X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M
M;V/M(%!!4U-71"X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE
M;NT@<&]M;V/M(%--0BX`3F5B>6QA('!O<VMY=&YU=&$@8V5S=&$@:R!B:6[A
M<F[M;74@<V]U8F]R=2!/<&5N4U-,+B!":6[A<F[M('-O=6)O<B!/<&5N4U-,
M(&IE('IA<&]T^&5B[2!P<F\@<'+A8VD@<R!02T-3(#$R(&1A='DN`*[A9&[I
M(&YE=GGX[7IE;ND@ON%D;W-T:2!O('#X:6ALX;EE;NTN`$)E>B!P<F%V:61E
M;`!"97H@;VMR86KY`*[A9&[]('H@9&_H87-N_6-H(&%D<F5SX?CY(&YE;NT@
M9&]S='5P;OT@<')O(&-A8VAE+@!.96)Y;&\@;V1E<VSA;F\@ON%D;ND@=;YI
M=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+@!.96)Y;'D@;F%L97IE;GD@
MON%D;N$@=D-A<F0@9&%T82X`3F5B>6QA(&YA=G+A8V5N82"^X61NX2!P;&%T
M;N$@6$U,(&1A=&$N`*[A9&[I(&AO9&YO='D`5B!O<FEG:6[A;&[M(&MO;F9I
M9W5R86-I(&YE8GEL82!N86QE>F5N82!V97)Z92X@3V)N;W9T92!K;VYF:6=U
M<F%C:2X`5F4@5F&Y[2!K;VYF:6=U<F%C:2!N96)Y;&$@;F%L97IE;F$@=F5R
M>F4N($]B;F]V=&4@:V]N9FEG=7)A8VDN`*[A9&[]`*[A9&[]("AP;W6^:6IT
M92!I;7!L:6-I=&[M*0!3979E<G-K_2`H25-/+3@X-3DM,3`I`$YO<F9O;&MS
M:^D@;W-T<F]V>0!3979E<F[M('!O;&]K;W5L90!3979E<F[M($UA<FGA;G-K
MZ2!O<W1R;W9Y`$YO<G-K;P!.96[M('!O`$YE;NT@</AE9`!.96[M(&%D<F5S
MX?AE;0!.96[M(&EM<&QE;65N=&]VX6YO+@!.96[M(&YA<W1A=F5N;P!.96[M
M('!O9'!O<F]VX6YO+@!0;WINX6UK80!.:6,@:R!P<F]H;.ED;G5T[2P@8NR^
M=&4@>G#L="X`3&ES=&]P860`R.US;&\`4&_H970@>FYA:_D`4&_H970@<VQO
M=7!C^0!0;^AE="!P;VQOOF5K(&YA('-T<N%N:W4`4&_H970@^.%D:_D`3F5B
M>6QA('IA9.%N82#H[7-L82!P<F\@86MT=6%L:7IA8VD@9&ES=')I8G7H;NUH
M;R!S97IN86UU+@!/2P!/8FIE:W0`5';Y<F-E(&]B:F5K=/D`3V)J96MT(&YE
M8GEL(&YA;&5Z96X`3W-M:>AK;W;]`-CM:F5N`$9I;'1R;W9A="!N97-L=;EN
MZ0!+86YC96SA^`!/;>%N`%-D[6QE;ND@<VQOOFMY(&IS;W4@<&]S:WET;W;A
M;GD@<&]U>F4@24U!4"!S97)V97)Y+@!0;W5Z92!N97-L=;ENZ0!*92!P;W9O
M;&5N82!P;W5Z92!J961N82!E+6UA:6QO=N$@861R97-A+@!0;W5Z92!V;&%S
M=&[M:R!N96)O('-Y<W3I;6]V_2!A9&UI;FES='+A=&]R(&WYOF4@;>QN:70@
M<'+A=F$@<')O('-D[6QE;OT@;V)J96MT+@!/=&5V^.UT('8@;F]VZ6T@;VMN
M["X`0VAY8F$@3W!E;E-33#H@3F5L>F4@>NUS:V%T(&1A=&$@>B!P;V1E<'-A
M;ND@Z.%S=&D@4R]-24U%+@!/=&5V^.UT('1E;G1O(&]D:V%Z('8@;F]VZ6T@
M;VMN[`!/<&5R8>AN[2!S>7-TZ6T`36^^;F]S=&D`36^^;F]S=&D@<')O("5S
M`%-E^&%Z96[]('-E>FYA;0!/<F=A;FEZ86-E`$]R9V%N:7IAZ&[M(&IE9&YO
M=&MA`$]R9V%N:7IO=N%N[0!/<FEG:6[A;&[M('9Z;W(@<')O(+[A9&]S=`!/
M<FEG:6[A;&[M('9Z;W(@=B`E<SH`3W-T871N[0!/<W1A=&[M(&EN9F]R;6%C
M90!$86RY[2!M;[YN;W-T:0!5OFEV871E;'-KX2!P<N%V80!/=NSX96[M('!O
M;6]C[2!004T@;F5N[2!D;W-T=7!NZ2X`4$=0(&1I9VETX6QN[2!P;V1P:7,`
M4$=0(+EI9G)O=F%NX2!D871A`%9E^&5J;OT@4$=0(&ML[>@`1&%T82!P;V1E
M<'-A;N$ON6EF<F]V86[A('!O;6]C[2!01U``4$A0(&OS9`!02%`@:V]N>F]L
M80!/9'!O;&5D;NT@;&5H:_T@9.FYNP!/9'!O;&5D;NT@</AE:.'R:WD`3V1P
M;VQE9&[M('-N[+YE;NT`3V1P;VQE9&[M('-N[&AO=ND@</AE:.'R:WD`3V1P
M;VQE9&[M(&)O=?AK>0!07TA0(&MO;GIO;&$`3V1S='5P>0!0X6MI<W3A;@!0
M86QA=0!086QE<W1I;G-KZ2!T97)I=&]R:75M+"!O:W5P;W9A;ND`4&%N86UA
M`%!A<'5A($YO=N$@1W5I;F5A`%!A<F%G=6%Y`$WM<W1Y('IA=&&^96YO`$AE
M<VQO`$YE<W!RX79NZ2!H97-L;P!0<F\@;W;L^&5N[2!P;VUO8^T@4D%$54E3
M(&IE(&YU=&YO('IA9&%T(&AE<VQO+@!(97-L;R!S('!O='9R>F5N[6T`2&5S
M;&\Z`$AE<VQO.B``2&5S;&$@<V4@;75S[2!S:&]D;W9A="X`5FQOOFET`%9L
M;[YI="!Z92!S8VARX6YK>0!#97-T80"NX61O<W1I(&\@</AI:&SAN65N[3H`
M3&EDZ0!0<F]C96YT`%!R;W;I<W0@;W!E<F%C92#Z9'*^8GD`4')O=NES="!O
M<&5R86-E(/ID<KYB>2!P^&D@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!0<N%V
M80!.97!O=F]L96[]('#X[7-T=7``3F5P;W9O;&5N_2!P^.US='5P`$%D;6EN
M:7-T<F'H;NT@<'+A=F$`3W-O8F[M(&EN9F]R;6%C90!097)U`$1O;>%C[2!Z
M=NWX871A`$9I;&EP[6YY`%1E;&5F;VX`1F]T;V=R869I90!0:6YE(&%D<F5S
MX?@`4&ET8V%I<FX`4&EX96SY`$9RX7IE`%!R;W/M;2!K;&EK;NQT92!N82!N
M[&IA:V]U(&)U\FMU`%!R;W/M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O
M9'-T<F%N:70@=&5N=&\@<')V96LZ`%!R;W/M;2!P;W1V<N]T92P@OF4@<VD@
M</AE:F5T92!O9'-T<F%N:70@=&5N=&\@<')V96LN`%!R;W/M;2!Z861E:G1E
M(&WL<^UC(&$@<F]K+@!0<F]S[6T@>F%D96IT92!NX7IE=B!N;W;I(&MA=&5G
M;W)I93H`4')O<^UM('IA9&5J=&4@<W!RX79N;W4@25`@861R97-U+BX`4')O
M<^UM('IA9&5J=&4@<W!RX79N_2!D871U;2!A('IK;VYT<F]L=6IT92!P;^AE
M="!D;NT@=B!M['/M8VDN`%!R;W/M;2!Z861E:G1E('-P<N%V;OT@Z&%S+@!0
M<F]S[6T@=79E[W1E('-H<FYU=.T@5F&Y96AO('!R;V)LZ6UU+@!0<F]S[6T@
M>F%D96IT92!68;EE('6^:79A=&5L<VOI(&IMZ6YO(&$@:&5S;&\`4')O<^UM
M('IA9&5J=&4@;F]V_2!NX7IE=B!K871E9V]R:64Z`%!O;'-K;P!0;VQI=&EK
M80!(;&%S;W;A;NT`4&]R='5G86QS:V\`56WM<W3L;NT@=&]H;W1O(&]B<N%Z
M:W4`56WM<W3L;NT@=&%B=6QK>0!:87-L870@9&\@=.ET;R!S;&^^:WD@*&YE
M;NT@<&]S:WET;G5T;R!)34%096TI`%-RX;YK>2!Z82!P;W-L961N[2AC:"D@
M)7,@:&]D:6XH=2DZ(`!0<F5F<U]L9&%P.B!.96)Y;&$@;F%L97IE;F$@<&^^
M861O=F%NX2!P^.UP;VYA($Q$05`N`%!R969S7W-E<W-I;VXZ($YE8GEL82!N
M86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<V5K8V4N`$)A<F]M971R:6-K
M_2!T;&%K`$)A<F]M971R:6-K_2!T;&%K(&YA(/IR;W9N:2!M;_AE.B``0F%R
M;VUE=')I8VO]('1L86LZ`$[A:&QE9`!.X6AL960@;V)RX7IK=2!V(&YO=NEM
M(&]K;NP`4/AE9&-H;WKM(&UOOFYO<W1I`%1I<VMN;W5T(&1O:W5M96YT`$]S
M;V)N[2!A9')E<^'X`%!R:7;A=&[M(&ML[>@`4')O8FSI;0!0;W!I<R!P<F]B
M;.EM=0!0<F]J96MT>0!0<F]M<'0@=&5X=`!69?AE:F[](&ML[>@`06QG;W)I
M=&UU<R!P<F\@=F7X96IN_2!K;.WH`%9E^&5J;OTO<')I=N%T;NT@:VSMZ&]V
M_2!PX7(@;F5B>6P@^G-P[+EN["!V>71V;_AE;BX`4&]R=&]R:6MO`$MA=&%R
M`%9Y:&QE9.%N[0!6>6AL963A=N%N[2!S96QH86QO.B`H)7,I("5S`%)Y8VAL
MZ2!V>6AL963A=N%N[0!24T$@=F7X96IN_2!K;.WH("@E9"!B:73Y*0!3</AA
MOF5NZ2!T;&'H[71K;P!$Z;F[`$)R>FO](&3IN;L`4&]Z9&[M(&3IN;L`1&6Y
MNV]VZ2!P^&5HX?)K>0!$Z;F[('-E('-N[&AE;0!$Z;F[(&&^('-N[6@`3N%H
M;V1N["!V>6)R86[I(+ET['-T[0!0;VWL<@#(=&5C[0#(=&5N[2!S96QH86QO
M.B`H)7,I("5S`%#X9>AT96[I('IP<N%V>0!/<')A=F1U('-M87IA="`E<S\@
M5&%T;R!O<&5R86-E(&IE(&YE=G)A=&[A+@!/<')A=F1U('-M87IA="!UOFEV
M871E;'-KX2!D871A('!R;R!UOFEV871E;&4@)7,_(%1A=&\@;W!E<F%C92!J
M92!N979R871NX2X`6F]B<F%Z96[I('KA>FYA;7DZ`$]P86MO=F%T('!O<VQE
M9&[M(&%K8VD`3V)N;W9I="!D>6YA;6EC:^D@<')V:WD@;65N=3H`3V)N;W9A
M('IO8G)A>F5N[2!P;W)TX6QU.B``4F5G97@`4')O:&SMOF7H('9Z=&%H^0!(
M;V1N;W1Y`%9Z9.%L96[I('-E<G9E<GDN`%9Z9.%L96[A(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$]D<W1R86YI=`!/9'-T<F%N:70@
M8FQO:P!/9'-T<F%N:70@<VQO=7!E8P!/9'-T<F%N:70@9F]R;>%T;W;A;NT`
M3V1S=')A;FET('IE('-E>FYA;74`3V1S=')A;FET('#A<@!/9'-T<F%T:70@
M=6QOOF5N_2!S:W)I<'0@>B!D;^AA<V[I:&\@861R97/A^&4@;F$@<V5R=F5R
M=2X`3V1S=')A;FET`$]D<W1R86YI="!T=71O(.CA<W0@9&]K=6UE;G1U`$]D
M<W1R86YI="!UOFEV871E;&4`3V1S=')A;FET('6^:79A=&5L93H@)7,`3F5L
M>F4@;V1P;W;L9.QT(&YA('!OOF%D879E:RX@0VAY8F]VZ2!H;.&Y96[M.B``
M4&^^861O=F%N_2!O8FIE:W0@;F5B>6P@;F%L97IE;BX`4&^^861O=F%NZ2!P
M;VQE`%;]8VAO>NT@;F%S=&%V96[M`%;]8VAO>NT@;F%S=&%V96[M(&AE<VQA
M`%;]8VAO>NT@;F%S=&%V96[M(%9AN65H;R!H97-L80!.87-T879I="!V_6-H
M;WKM(&EM<&QI8VET;NT@:&]D;F]T>0!6_7-L961K>0!.X79R870@9&\@;6^^
M;F]S=.T`4F5U;FEO;@!0^&5P;F]U="!K;VYF:6=U<F%C:0!-;[YN;W-T:2!2
M:6-H(%1E>'0@961I=&]R=0!(X61A;FMY`$1O<')A=F$`2&QA=FGH:V$@;F%P
M<F%V;P!(;V1N;W1Y(&YA<')A=F\`5FQA<W1N;W-T:2#XX5]D:W4`VFQO:&$`
M4G5M=6YS:V\`3W1OZ&ET(&\@,3@PL`!/=&_H:70@9&]L979A`$]T;^AI="!D
M;W!R879A`%9L87-T;F]S=&D@^.%D:W4`5FQA<W1N;W-T:2#XX61K=0#8X61K
M>3H`4')A=FED;&$`4')A=FED;&$@<V4@=7!L871N[2!M97II(':Y96UI(/CA
M9&MY(&$@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M('!O=7IE(&UE>FD@
M<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M('!O=7IE(&UE>FD@^.%D:WD`
M4')O=NES=`!2=7-KX2!F961E<F%C90!2=V%N9&$`4R]-24U%(+EI9G)O=F%N
M_2!P;V1P:7,`4R]-24U%(+EI9G)O=F%NX2!Z<'+A=F$`4R]-24U%('9E^&5J
M;OT@8V5R=&EF:6OA=`!/=NSX96[M('!O;6]C[2!305-,(&YE;NT@9&]S='5P
M;NDN`%--4R!Z<'+A=GD`4U%,(&MO;GIO;&$`4U-(`%-405)45$Q3('-E;&AA
M;&\Z("@E<RD@)7,`VE-0S$-(`%-?44P@:V]N>F]L80!3;P!3=F%TX2!(96QE
M;F$`4W9A=/T@2VET=',@82!.979I<P!386EN="!,=6-I80!386EN="!0:65R
M<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S`%-T96IN_2!RX6T@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4
M;VUE(&%N9"!0<FEN8VEP90!6;&%S=&[M:R!S871E;&ET=0!3875D<VOA($%R
MX6)I90!5;&^^:70`56QOOFET("5S`%5L;[YE;NT@;6^^;F]S=.T`56QOOFET
M('9Y='9O^&5N_2!K;VYF:6=U<F'H;NT@4$A0('-K<FEP="!D;R!D;^AA<V[I
M:&\@861R97/A^&4@;F$@<V5R=F5R=2X`2V]N9FEG=7)A8V4@)7,@=6QOOF5N
M82X`5NQD80!(;&5D870`5GEH;&5DX79A8^T@;N%S=')O:F4`2&QE9.%N[2!S
M96QH86QO`$AL963A;NT@<V5L:&%L;SH@)7,`5GEH;&5DX7;A;2XN+@!6>6)R
M870@<V]U8F]R>0!6>6)R870@9&%T=6T`5GEB<F%T('-K=7!I;G4L(&MT97+A
M(&)U9&4@</AI9.%N80!6>6)R870@;F]VZ6AO('9L87-T;NUK80!6>6)R870@
M<V5R=F5R`%9Y8G)A="!UOFEV871E;&4L(&MT97+](&)U9&4@</AI9.%N`%9Y
M8G)A="!VN65C:&YY(.CA<W1I(&1A='5M=2X`5GEB<F%T(&]B:F5K=`!6>6)E
M<G1E(&%D<F5SX?@L('IE(&MT97+I:&\@8G5D971E(&5X<&]R=&]V870Z`%9Y
M8F5R=&4@861R97/A^"P@9&\@:W1E<NEH;R!S92!B=61E(&EM<&]R=&]V870Z
M`%9Y8F5R=&4@<&]T^&5B;ND@>FYA:WD@>B!N[;YE('5V961E;OUC:"!B;WCY
M+B!0;W3I(&IE(&WYOF5T92!K;W#M<F]V870@82!V;&^^:70@>B!T97AT;W;I
M(&]B;&%S=&DN`%9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R!D871U;3H`
M5GEB97)T92!F;W)MX70@9&%T=6UU.@!696)E<G1E(&9O<FWA="!E>'!O<G1U
M.@!6>6)E<G1E('-O=6)O<B!K(&EM<&]R=&]VX6[M.@!6>6)E<G1E(&9O<FWA
M="!Z9')O:F]VZ6AO('-O=6)O<G4Z`%9Y8F5R=&4@9F]R;>%T('IO8G)A>F5N
M[2!J;65N.@!6>6)E<G1E(&ED96YT:71U+"!K=&5R;W4@<VD@</AE:F5T92!Z
M;>QN:70Z`%9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R#H87,Z`%9Y8F5R
M=&4@9F]R;>%T(.AA<W4Z`%9Y8F5R=&4@9';L(&]D<&]V[61A:NUC[2!P;VQE
M+@!6;VQB82!P;VSM+"!K=&5RX2!M86KM(&+]="!Z;V)R87IE;F$@=B!S97IN
M86UU(&%D<F5S+@!6;VQB82!F;W)MX71U('IO8G)A>F5N[2!J;65N+@!6>6)E
M<G1E(&)A<F5V;OT@;6]T:78N`%9Y8F5R=&4@5N%M:2!P<F5F97)O=F%N_2!J
M87IY:SH`4&]S;&%T('IP<N%V=2!O('!R;V)LZ6UU`%!O<VQA="!335,`4V5N
M96=A;`!396YS;W(Z`%KA^.T`4W)B<VMO(&$@R&5R;N$@2&]R80!3Z7)I;W;I
M(.CM<VQO`$E$('-E:V-E('IA;FEK;&\N`$YA<W1A=FET`$YA<W1A=FET(&UO
MOFYO<W1I('!R;R!P;W9O;&5N[2!R97-E='4@:&5S;&$L('!O:W5D(&AO('IA
M<&]M96YE=&4N`$YA<W1A=FET('9Z9.%L96[I('-E<G9E<GD@=&%K+""^92!B
M=61O=2!P^.US='5P;ND@>B!P;W)TX6QU+@!.87-T879E;NT@5N%M:2!P<F5F
M97)O=F%NZ6AO(&IA>GEK82P@Z&%S;W;I:&\@<.%S;6$@82!T>7!U(&1A='5M
M=2X`3F%S=&%V96[M('!OZ.%T9>AN[2!A<&QI:V%C92P@8F%R979NZ6AO(&UO
M=&EV=2P@;V)N;W9O=N%N[2!S='+A;F5K(&$@9&%LN>UC:"!M;[YN;W-T[2!Z
M;V)R87IE;NTN`$YA<W1A=F5N[0!.87-T879O=F%C[2!K;VYF:6=U<F'H;NT@
M<VMR:7!T>2!P<F\@86MT=6%L:7IA8VD@:G-O=2!D;W-T=7!NZ0!.[&MT97+A
M(&WM<W1A(&QZ92!N87-T879I="!S('3M;71O('!A<F%M971R96TZ(`!397EC
M:&5L;&5S`%-D[6QE;OT@861R97/A^`!.86MU<&]VX6[M`$MRX71KZ2!S:')N
M=73M`$WL;'D@8GD@8OUT('#X[7-T=7!O=ND@:VSMZ&4@9&5F:6YO=N%N>2!P
M<F\@=NQTN6EN=2!O9&MA>OD_`%IO8G)A>FET`%IO8G)A>FET(':Y90!:;V)R
M87II="!K;VYT86MT>0!:;V)R87II="!S97IN86UY`%IO8G)A>FET(')O>F3M
M;'D@;65Z:2!S;W7H87-N;W4@82!P^&5D8VAO>NT@:V]N9FEG=7)A8^TN`%IO
M8G)A>FET(.AA<R!P;W-L961N[6AO('#X:6ALX;EE;NT@9&\@<WES=.EM=3\`
M6F]B<F%Z:70@;6^^;F]S="!U9'*^96[M(&]R:6=I;N%L=0!:;V)R87II="!S
M8NQR8>@`6F]B<F%Z:70@;65N=2!O<&5R8>AN[2!L:;ET=2!P<F\@=&%B=6QK
M>3\`6F]B<F%Z:70@)7,@;65N=2!N86QE=F\_`%IO8G)A>FET(&1I86QO9R!P
M<F\@=FQA<W1N;W-T:2!B=6[L:R!V('1A8G5L:^%C:`!:;V)R87II="!D:6%L
M;V<@=FQA<W1N;W-T[2!T86)U;&5K`%IO8G)A>FET(&1I86QO9R!V;&%S=&YO
M<W3M(/CA9&5K('1A8G5L96L`6F]B<F%Z:70@9&EA;&]G('9L87-T;F]S=.T@
M;V)RX7IK^0!:;V)R87II="!P^&5N;W,`4/AE:.'R:WD`0G)Z:^D@</AE:.'R
M:WD`4&]Z9&[M('#X96CA\FMY`%#X96CA\FMY('8@;VMO;.T`6FUE;KEI=`!:
M;65NN6ET(&YE8F\@<&]S=6YO=70@9&\@<V]U<V5D;NUH;R!B;&]K=2CY*2P@
M>B!C97-T>2!P<G9N[6UU`%-I97)R82!,96]N90!296=I<W1R;W9A="!S90!0
M;V1P:7,`06QG;W)I=&UU<R!P<F\@<&]D<&ES`%-I;F=A<'5R`%9E;&EK;W-T
M`%9Y;F5C:&%T(/ID<KYB=0!3;&]V96YS:V\`4VQO=FEN<VMO`%-N[+YE;NT`
M4V[L:&]VX2!P^&5HX?)K80!3;NQH;W;I('#X96CA\FMY`%)A;F[M('-N[&AO
M=ND@</AE:.'R:WD`4&]Z9&[M('-N[&AO=ND@</AE:.'R:WD`4V[L:&]VX2!P
M;VMR_79K83H`5F]D;NT@96MV:79A;&5N="!P<F\@<V[M:#H@`*EA;&%M;W5N
M;W9Y(&]S=')O=GD`4V]MX6QS:V\`4.US;NP@82!BX7-N[`!3;>QR('3X[63L
M;NT`4VWL<B!T^.UD[&[M`%ID<F]J;W;A(&%D<F5S80!:9')O:F4`2FF^;NT@
M069R:6MA`$II:&]E=G)O<'-K_2`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`2FF^;NT@<&]L;VMO
M=6QE`%!R;W-T;W(@;65Z:2!S;W5S961N[6UI(&)U\FMA;6D`4')O<W1O<B!M
M97II(&]B<V%H96T@82!H<F%N:6-E;6D@=B!B=?)C90!-97IE<F[M:P!-97IE
M<GD`3V1S='5P>2!A(&UE>F5R>0"I<&%N[&QS:V\`4W!A;0!6<W1U<"!P<F\@
M>G9LX;ET;NT@>FYA:WD`57+H971E(&MA;2!S:2!P^&5J971E('IO8G)A>FET
M(';]<VQE9&MY('!O:W)OZ&ELZ6AO('9Y:&QE9.%VX6[M+@!2;WID[&QI="!B
M=?)K=0!2;WID[&QI="!S;&]U<&5C`%)O>F3L;&ET(/CA9&5K`%-P;W)T`%-R
M:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4F]K('IAZ.%T:W4`4W3A="#H
M:2!P<F]V:6YC:64`4W1A=@!&;W)MX70@=6QOOF5N[0!5;&EC90!0^&6Y:W)T
M;G5T_0!397IN86T@^&5T['IC90!/9'-T<F%N:70@9&]MZ6YO=ND@:FWI;F\@
M>B!A9')E<WD`4W1Y;"!;0U-370!.90!0^&5D;>QT`%!O9&%T`$1O;&[M(&EN
M9&5X`-IS<.RY;NP`VG-P[+EN["!P^&EDX6YO("5S(&1O("5S`$MO;F9I9W5R
M86-E(&)Y;&$@^G-P[+EN["!Z;>QN[&YA+B!/8FYO=G1E('-T<N%N:W4N`-IS
M<.RY;ND@=6QOOF5N[2!ZX6QOOF[M(&MO;F9I9W5R86-E+@#:<W#LN6[I('5L
M;[YE;NT@>N%L;VAY(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N`"5S(&)Y
M;&\@^G-P[+EN["!Z87!SX6YO`%-U9.%N`%-H<FYU=.T`4W;M=.%N[0!:X7!A
M9"!3;'5N8V4`4VQU;F7H;F\`5OUC:&]D(%-L=6YC90!6_6-H;V0O>N%P860@
M4VQU;F-E`%;]8VAO9"!3;'5N8V4Z(`!:X7!A9"!3;'5N8V4`6N%P860@4VQU
M;F-E.B``2&]R;NT@:6YD97@`4&]D<&]R80!3=7)I;F%M90!0^.UJ;65N[0!3
M=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;'-K;P"I=NED<VMO`*EV_6-A
M<G-K;P!3>6YT87AO=N$@8VAY8F$@=B!H;&5D86[I;2!T97AT=0!3_7)I90!"
M;W7X:V$`0F]U^&MY`%135@!44U8@<V]U8F]R`%1A8B!O9&3L;&5NZ2!H;V1N
M;W1Y`%1A8G5L:V$`5FQA<W1N;W-T:2!T86)U;&MY`%9L87-T;F]S=&D@=&%B
M=6QK>0!486EW86X`5&%I=V%N+"!P<F]V:6YC:64@R.UN>0!4862^:6MI<W3A
M;@!486YZX6YI92P@4W!O:F5NX2!R97!U8FQI:V$`0^UL.@#::V]L>0!496QE
M9F]N;NT@Z.US;&\`5&5P;&]T82!Z82!P;W-L961N[2!H;V1I;G4Z(`!497!L
M;W1A`%1E<&QO=&$Z(`!6>F]R('!R;R!A9&UI;FES=')A8VD`5&5X=`!0;W5Z
M92!T97AT`%IA<F]V;N%N[2!T97AT=0!6<F-H('1E>'1U`,AT`%1H86IS:WD@
M*%1)4RTV,C`I`%1H86IS:V\`1.QK=6IE;64@>F$@<&]UONUVX6[M('-Y<W3I
M;74N`%#X[7!O;F$@<')O($944"!N96[M(&1O<W1U<&[A+@!);G1E9W)AZ&[M
M(&%L9V]R:71M>2!V($AO<F1E+TMO;&%B(&YE<&]D<&]R=6KM("(E<R(`3F7Z
M<W#LN6[I(&YAZ'1E;NT@=/CM9'D@36%I;G1E;F%N8V4Z.@!">6QO('5Z87;X
M96YO(&]K;F\@<R!M;[YN;W-T;6DN(%5K;V[H96YO+@!.96QZ92!V>>AI<W1I
M="!A9')E<^'X.B`E<P!!9&UI;FES='+M=&]R('!O=/AE8G5J92!N86MO;F9I
M9W5R;W9A="!T<G9A;.$@<'+A=F$@=B!S>7-TZ6UU+"!P;VMU9"!S:2!P^&5J
M971E('!O=;[M="!P<N%V82X`4&]U>F4@<W!O9&[M('-T<F%N80!.96)Y;&\@
M=79E9&5N;R!)1"!P<F\@:V]N=&%K="P@;F5B>6QO(&YA;&5Z96YO('8@9&%T
M86+A>FD@;F5B;R!B>6QO(/IP;&[L('9Y;F5C:.%N;RX`2V]N=&%K="!B>6P@
M^G-P[+EN["!P^&EDX6X@9&\@5F&Y96AO(&%D<F5SX?AE+@!0;[YA9&]V86[]
M(&MO;G1A:W0@;F5E>&ES='5J92X`2R!O=NSX96[M('!O9&5P<V%NZ2!Z<'+A
M=GD@:F4@=/AE8F$@;V1D[&QE;OT@8FQO:R!S(%!'4"!P;V1P:7-E;2X`3F5B
M>6QO('5V961E;F\@240@9&ES=')I8G7H;NUH;R!S97IN86UU+"!N96)Y;&\@
M;F%L97IE;F\@=B!D871A8N%Z:2!N96)O(&)Y;&\@^G!L;NP@=GEN96-HX6YO
M+@!.96)Y;"!U=F5D96X@9&ES=')I8G7H;NT@<V5Z;F%M+@"I:69R;W9A8^T@
M;6^^;F]S=&D@;'IE('9Y=;[M="!P;W5Z92!P^&D@8F5Z<&7H;NEM('-P;VIE
M;NT@<R!W96)E;2`H:'1T<',I+@!3;W5B;W(@)7,@8GD@;>QL(&]B<V%H;W9A
M="!N87-T879E;NT@)7,N`%-O=6)O<B`E<R!B>2!M[&P@;V)S86AO=F%T(&[L
M:W1E<N$@>B!N87-T879E;NT@)7,N`%-O=6)O<B!N96QZ92!K;W#M<F]V870@
M<^%M(&1O('-E8F4N`%-O=6)O<B!N96]B<V%H=6IE(+[A9&[A(&1A=&$N`$[A
M<VQE9'5J[2!H;&%V:>AK>2!P<F\@;65S<V%G92]R9F,X,C(@>G!RX79U`$IE
M('INX6WI+""^92!M\V0@</AE<R!C96QO=2!O8G)A>F]V:W4@=B!);G1E<FYE
M="!%>'!L;W)E<G4@</ES;V+M('!R;V)LZ6UY+"!P<F]T;[YE('-E('8@;NQM
M('9Y<VMY='5J92!C:'EB82P@:W1E<ND@<V4@;F5L>F4@=GEH;F]U="X@2F%K
M;R!NX7-L961E:R!M^;YE(&+]="!NX6AO9&[I('IH<F]U8V5N[2!T;VAO=&\@
M<')O9W)A;74L(&-H>6+L:NUC[2!F=6YK8V4@961I=&]R=2!N96)O(&YE<W!R
MX79NZ2!Z;V)R87IO=N%N[2X@4&]K=60@:F4@5N&Y('-Y<W1E;>EM(%=I;F]D
M=W,@.7@L(&IE('9E;&UI('!R879D['!O9&]B;NDL(+YE('-E(&]B:F5V[2!C
M:'EB;W;I(&ALX;EE;NT@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@82!B
M=61E=&4@;75S970@<F5S=&%R=&]V870@<&_H[71AZ"Y<;EQN0GEL:2!J<W1E
M('9A<F]VX6YI+B!0<F]S[6T@<W1I<VMN['1E($]+('!O:W5D('-I('#X96IE
M=&4@<&]K<F'H;W9A="!V(&WS9'4@</AE<R!C96QO=2!O8G)A>F]V:W4N`$ED
M96YT:71A("(E<R(@8GEL82!S;6%ZX6YA+@!0;W5Z92!N82!L97;I('-T<F%N
M[`!5;>US=.QN[2!B:6[A<F[M:&\@<V]U8F]R=2!';G501R!M=7/M(&+]="!Z
M863A;F\@9&\@=/CM9'D@0W)Y<'1?<&=P.CHN`%IP<N%V82!Z87-L86[A('8@
M)7,@:R`E<R!S('#X961M['1E;2`B)7,B(&)Y;&$@>F]B<F%Z96YA+@I4;W1O
M(&YE>F%R=>AU:F4L(+YE('IP<N%V82!B>6QA('#X9>AT96YA(&YE8F\@OF4@
M:NT@861R97/A="AK82D@<F]Z=6WL;"AA*2X`3N%Z978L(&MT97+](&)U9&4@
M<&]UOFET('#X:2!O9&MA>F]VX6[M(&YA('-T<N%N8V4@='9O<F)Y('IP<N%V
M`%3X[61A($AO<F1E7T-R>7!T7W-M:6UE.CH@=GF^861U:F4@;6]D=6P@;W!E
M;G-S;"X`3F5L>F4@=6QOOFET(&YA<W1A=F5N[2`B)7,B+"!P<F]T;[YE(&IE
M:&\@=F5L:6MO<W0@</AE<^%H;&$@<&]V;VQE;OT@;&EM:70N`$YE8GEL82!N
M86QE>F5N82!A<&QI:V%C92!P<F\@Z'1E;NT@=&]H;W1O('1Y<'4@9&%T("@E
M<RDN`%!O=7IE(&YA('!R87;I(&$@;&5VZ2!S=')A;NP`4&]U>F4@;F$@<')A
M=ND@<W1R86[L`%-E<G9E<B`B)7,B(&)Y;"!V>6UA>N%N+@!397)V97(@(B5S
M(B!B>6P@=6QOOF5N+@!">6QA(&]D<W1R86[L;F$@ON%D;W-T(&\@</AI:&SA
MN65N[2!P<F\@)7,N`%!OOF%D;W9A;OT@^.%D96L@;F5E>&ES='5J92X`1&_H
M87-N_2!S;W5B;W(@(B5S(B!N965X:7-T=6IE+@!0;W5Z92!N86AO^&4@82!D
M;VQE`%!O=7IE(&YA:&_X90!:=')A=&EL82!S92!P^&5N97-E;N$@9&%T82!Z
M('#X961C:&]Z[6AO(&MR;VMU+@!0^&5N97-E;OT@<V]U8F]R(&YE;'IE('5L
M;[YI="X`0FQO:R!W96%T:&5R+F-O;2!N96[M(&1O<W1U<&[]+@!.96IS;W4@
M9&]S='5P;ND@OF%D;ND@861R97/A^&4@:R!P<F]H;.V^96[M+@"NX61NZ2!Z
M(&UOOFYO<W3M(&YE:G-O=2!D;W-T=7!NZ2X`3F5B>6QY(&YA;&5Z96YY(+[A
M9&[I(.CA<W1I+"!K=&5RZ2!B>2!B>6QO(&UOOFYO('IO8G)A>FET('8@^.%D
M:W4N`$YE:G-O=2!Z9&4@ON%D;ND@861R97/A^&4@<R!M;[YN;W-T[2!ZX7!I
M<W4N(*[A9&[I(&%D<F5SX?AE(&YE:G-O=2!N86MO;F9I9W5R;W;A;GD@<')O
M('KA<&ES(&YO=OUC:"!P;VQOOF5K+B!0;VMU9"!S:2!M>7-L[71E+""^92!J
M92!T;R!C:'EB82P@<')O<^UM(&MO;G1A:W1U:G1E('-VZ6AO('-Y<W3I;6]V
MZ6AO(&%D;6EN:7-T<N%T;W)A+@!0^.UL:;D@;6YO:&\@>FYA:_D@=B!P;VQI
M+B!:861A;&D@:G-T92`E<R!Z;F%K^3L@;75S[71E('IA9&%T(&WI;NP@;F6^
M("5S('IN86OY+@!.87-T86QA(&-H>6)A('#X:2!P^&5N;W-U('-O=6)O<G4Z
M("5S(&YE8GEL('#X96YE<V5N+@!.87-T86QA(&-H>6)A('#X:2!P^&5N;W-U
M('-O=6)O<G4N("5S(&YE;?F^92!B_70@=NQTN>T@;F6^(&UA>&EMX6QN[2!P
M;W9O;&5NX2!V96QI:V]S="`H)60@8GET^2DN`$YA<W1A;&$@8VAY8F$@</AI
M('#X96YO<W4@<V]U8F]R=3H@8GEL82!P^&5N97-E;F$@:F5N(.CA<W0@<V]U
M8F]R=2`E<RX`3F%S=&%L82!C:'EB82!P^&D@=FMLX63A;NT@;F]VZ6AO(&MO
M;G1A:W1U+B!+;VYT86MT=6IT92!68;EE:&\@<WES=.EM;W;I:&\@861M:6YI
M<W1RX71O<F$N`$YA<W1A;&$@8VAY8F$@</AI('9Y=';A^&5N[2!N;W;I:&\@
M<V5Z;F%M=2X`3F%S=&%L82!C:'EB82!P^&D@;6%ZX6[M('1O:&]T;R!K;VYT
M86MT=3H@)7,`3F%S=&%L82!C:'EB82!P^&D@;6%ZX6[M('1O:&]T;R!O8FIE
M:W1U+@!$;[EL;R!K(&-H>6+L('#X:2!Z;V)R87IO=N%N[2!TZ71O(.CA<W1I
M('IP<N%V>0!.87-T86QA(&-H>6)A('#X:2!I;7!O<G1O=N%N[2!K;VYT86MT
M=2X`3F%S=&%L82!C:'EB82!P^&D@:6UP;W)T;W;A;NT@9&%T.B`E<P!0^&D@
M:6UP;W)T;W;A;NT@:4-A;&5N9&%R(&1A="!D;[EL;R!K(&-H>6+L+@!#:'EB
M82!V(&MO;F9I9W5R8>AN[6T@9F]R;75LX?AI+B!:^&5J;>P@:G-T92!V>6YE
M8VAA;&D@<&^^861O=F%NZ2!P;VQE+@!.87-T86QA(&-H>6)A('#X:2!P<F]V
MX63L;NT@>F%D86[I(&]P97)A8V4@=B!A9')E<^'X:2X@4')O<^UM('IK=7-T
M92!T;R!P;WID[&II+@!.87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!K
M;VYT86MT=2X@4')O<^UM('IK=7-T92!T;R!P;WID[&II+@!.87-T86QA(&-H
M>6)A('#X:2!A:W1U86QI>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA;74N(%!R
M;W/M;2!Z:W5S=&4@=&\@<&]Z9.QJ:2X`3F%S=&%L82!C:'EB82!P^&D@86MT
M=6%L:7IA8VD@=.ET;R!P;VQOOFMY.B`E<P"NX61NZ2!K;VYT86MT>2!P<F\@
M97AP;W)T;W;A;NTN`%1E;G1O($E-05`@<V5R=F5R(&YE<&]D<&]R=6IE('-D
M[6QE;NT@<VQOOF5K+@!4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[](')A<B!A
M<F-H:78N`%1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T;OT@>FEP('-O=6)O<BX`
M5&]T;R!N979Y<&%DX2!J86MO('!L871NZ2#H[7-L;R!K87)T>2X`5&5N=&\@
M;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO8^T@0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!B<N%N>2!P^&D@<&]UOFET
M[2!(5%10($%020!496YT;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP
M<N%V('!O;6]C[2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!B
M<N%N>2!P^&D@<&]UOFET[2!(5%10($%020!496YT;R!O=FQA9&'H('5M;[[R
M=6IE('!O<^ULX6[M('IP<N%V('!O;6]C[2!33510(&1O(%9O9&%F;VYE($ET
M86QY(&)RX6YY('!O=7IE('!R;R#H[7-L82!P;W-K>71N=73I(%9O9&%F;VYE
M;2X@375S[71E(&WM="!E;6%I;&]V_2#ZZ&5T('4@5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2X`5&]T;R!P;VQE(&IE(&YU=&[I('9Y<&QN
M:70N`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!C96SA(.CM<VQA
M+@!4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L82!A
M(&1V;VIT9>AK=2X`5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&]S
M;6GH:V]VZ2#H[7-L82X`5&]T;R!P;VQE(&UU<^T@8OUT('-E>FYA;2!C96S]
M8V@@Z.US96P@;V1D[&QE;OUC:"#HX7)K;W4@;F5B;R!M97IE<F]U`%1O=&\@
M<&]L92!M=7/M(&+]="!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M=7/M('!B
M<V%H;W9A="!B87)E=F[](&OS9"!V(+EE<W1NX6-K;W;I;2!21T(@9F]R;>%T
M=2P@;F%P^"X@)R,Q,C,T868G+@!496YT;R!F;W)MX70@<V]U8F]R=2!N96QZ
M92!P;W6^[70N`%1E;G1O(&9O<FUU;.'X(&IIOB!B>6P@>G!R86-O=N%N+@!4
M;W1O(&IE("5S+@!4;W1O(&IE(&]B:F5K="!+;VQA8B!'<F]U<'=A<G4N($L@
M>FALZ61N=73M('1O:&]T;R!O8FIE:W1U(&IE('IA<&]T^&5B[2!M[70@<&^Y
M=&]V;NUH;R!K;&EE;G1A+"!K=&5R_2!R;WIU;>T@9F]R;>%T=2!+;VQA8B!'
M<F]U<'=A<G4N(%!R;R!S97IN86T@=&%K;W;]8V@@:VQI96YT^2!P<F]S[6T@
M;F%VN71I=G1E("5S`%1A=&\@>G!RX79A(&)Y;&$@;F%P<^%N82!V(&II;ND@
M>FYA:V]VZ2!S863L("@E<RD@;F6^(%9AN>TN(`!4;W1O(.CM<VQO(&UU<^T@
M8OUT(&YE:FWI;NP@:F5D;F$N`%1A=&\@;W-O8F$@<V4@:FF^(&YA8VCA>NT@
M=F4@5F&Y96T@861R97/A^&D@:F%K;R`E<RX`4V5R=F5R(&YE;?F^92!R;WIB
M86QI="!Z:7`@82!G>FEP('-O=6)O<GDN`%1E;G1O('-Y<W3I;2!J92!V('-O
M=>AA<VYO<W1I(&1E86MT:79O=F%N_2X`5&%T;R!H;V1N;W1A(&UU<^T@8OUT
M(.CM<VQO+@!4;W1O(&]K;F\@;76^92!B_70@=F]LX6YO('!O=7IE('H@;VMN
M82!M;[YN;W-T[0!(^&WL;NT`3.US=&MY`,AA<P!3;&5D;W;A;NT@Z&%S=0!&
M;W)MX70@Z&%S=0!6_6+L<B#H87-U`%1I;6]R+4QE<W1E`%1I='5L`%1I='5L
M("AT:7`I.@!+;VUU`%!O:W5D('-I('#X96IE=&4@=GEB<F%T(';M8V4@<&]L
M;[YE:RP@>FWAZ&MN['1E(&MLX79E<W4@0V]N=')O;"`H4$,I(&YE8F\@0V]M
M;6%N9"`H36%C*2!A(&ML:6MN['1E(&YA('!O;&^^:W4N`$1N97,`4/AE<&YO
M=70@;F$@2%1-3"!Z9')O:@!4;V=O`%1O:V5L874`6NUT<F$`5&]N9V$`5G)C
M:`!(;W)N[2!RX6T@*%]T;W`I`%#X96ML861Y`%1R:6YI9&%D(&$@5&]B86=O
M`%-P<N%V;NP@;F5B;R"Y<&%T;NP`VG0`5'5N:7-K;P!4=7)E8VMO`%1U<F5C
M:WD@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W3A;@!4=7)K<R!A($-A:6-O<R!O
M<W1R;W9Y`%1U=F%L=0!.87!IN71E(%9AN6D@=F]L8G4Z`%4N5BX@:6YD97@Z
M(`!54DP`55),('!R;R!Z<'+A=G4@;R!S=&%V=2!Z87-L86[I:&\@<VMR:7!T
M=0!54DPZ`%5G86YD80!5:W)A:FEN80!61E,@861R97/A^"!J92!N97#X[7-T
M=7!N_2X`4/AI(')E9VES=')A8VD@;F5L>F4@</AI9&%T(&5X=')A('6^:79A
M=&5L<VOI(/ID86IE+@!.96QZ92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B
M;W(@(B5S(BX`3F5L>F4@>FWL;FET('!RX79A('!R;R!61E,@<V]U8F]R("5S
M+R5S+@!.96QZ92!Z;>QN:70@;F$@)7,N`$YE;'IE('-E('#X:7!O:FET(&L@
M4U%,('-E<G9E<G4N`$YE;'IE('-E('#X:7!O:FET('!O;6]C[2!34TPN`$YE
M;'IE(&MO<.UR;W9A="!61E,@<V]U8F]R+@!.96QZ92!V>71V;_AI="!61E,@
M861R97/A^"`B)7,B+@!.96QZ92!V>71V;_AI="!61E,@861R97/A^"X`3F5L
M>F4@=GET=F_X:70@5D93('-O=6)O<BX`3F5L>F4@=GET=F_X:70@<'+A>F1N
M_2!61E,@<V]U8F]R+@!.96QZ92!R;WIB86QI="!D871A+@!.96QZ92!V>6UA
M>F%T("(E<R(L('!R;W1OOF4@861R97/A^"!N96[M('!RX7ID;OTN`$YE;'IE
M('9Y;6%Z870@)7,L('!R;W1OOF4@861R97/A^"!N96[M('!RX7ID;OTN`$YE
M;'IE(')E:W5R>FEV["!O9'-T<F%N:70@5D93(&%D<F5SX?@N`$YE;'IE('9Y
M;6%Z870@5D93(&%D<F5SX?@N`$YE;'IE('9Y;6%Z870@5D93(&%D<F5SX?@Z
M("5S+@!.96QZ92!V>6UA>F%T(%9&4R!S;W5B;W(@(B5S(BX`3F5L>F4@=GEM
M87IA="!61E,@<V]U8F]R+@!.96QZ92!R96MU<GII=F[L(&]D<W1R86YI="!6
M1E,Z("5S+@!.96QZ92!U<NAI="!A:W1UX6QN[2!A9')E<^'X+@!.96QZ92!Z
M:FES=&ET('!O9')O8FYO<W1I(&\@8V5R=&EF:6OA='4N`$YE;'IE(&1O<^%H
M;F]U="!D969I;FEC:2`E<RX`3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(N
M`$YE;'IE('#X97-U;F]U="!61E,@<V]U8F]R("(E<R(N`%9&4R!S;W5B;W(@
M;F5L>F4@;W1E=OCM="!P<F\@>N%P:7,N`$YE;'IE(&]T97;X[70@5D93('-O
M=6)O<BX`3F5L>F4@;W1E=OCM="!A<F-H:79O=F%N_2!S;W5B;W(N`$YE;'IE
M(.CM<W0@>B!V9G-R;V]T(&%D<F5SX?AE+@!.96QZ92!P^&5J;65N;W9A="`E
M<R!N82`E<SH@8^UL;W;A('-L;[YK82!J:;X@97AI<W1U:F4`5D93(&%D<F5S
MX?@@;F5L>F4@</AE:FUE;F]V870N`%9&4R!A9')E<^'X(&YE;'IE('#X96IM
M96YO=F%T.B`E<RX`3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<B`B)7,B
M+@!.96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R("5S+R5S+@!.96QZ92!P
M^&5J;65N;W9A="!61E,@<V]U8F]R+@!.96QZ92!P<F]VZ7-T("=M:VES;V9S
M)RX`5&5N=&\@9&]K=6UE;G0@5V]R9"!N96QZ92!P^&5L;[YI=`!.96QZ92!Z
M87!S870@9&\@5D93('-O=6)O<G4@(B5S(BX`3F5L>F4@>F%P<V%T(&1A=&$@
M9&\@5D93('-O=6)O<G4@*'-E;&AA;&\@8V]P>2@I*2X`3F5L>F4@>F%P<V%T
M(&1A=&$@9&\@5D93('-O=6)O<G4`4&]D=')H;G5TZ0!3=&]R;F\@>FWL;@!3
M=&]R;F]V870@<&]S;&5N[2!A:V-I`$YE;^AE:^%V86[A(&]D<&]V[.\@<V5R
M=F5R=2!N82!S<&]J96[M.B``3F5OZ&5KX79A;N$@;V1P;W;L[R!S97)V97)U
M.B``3F5V>7!L;NQN;P!5;FEC;V1E("A55$8M."D`4W!O:F5NZ2!!<F%B<VOI
M($5M:7+A='D`5F5L:^$@0G)I=.%N:64`4W!O:F5NZ2!3=.%T>2!!;65R:6-K
MZ0!3<&]J96[I(%-TX71Y($UE;KEI;F]V_6-H(&]S=')O=OD`2F5D;F]T:WD`
M3F5Z;N%MZ0!.97INX6WI(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`$YE
M>F[A;>D@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`3F5Z;N%MZ2!U
MOFEV871E;'-KZ2!J;>EN;R!N96)O(&AE<VQO+@!/9'!O:FET('-O=>AA<V[]
M('!R=F5K`$)E>F4@:FWI;F$`3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M
M;VAO=2!V>76^[79A="!F=6YK8V$@5GEJ;6]U="]+;W#M<F]V870O5FQOOB!Z
M(&)E>G!EZ&YO<W1N[6-H(&3Y=F]D^2X@2VQI:V[L=&4@;F$@3TL@86)Y<W1E
M('9I9.QL:2!T96-H;FEC:V]U('IP<N%V=2!Z(&UO>FEL;&$N;W)G+"!K=&5R
MX2!V>7-V['1L=6IE+"!J86L@;F%S=&%V:70@<VMR:7!T('!R;R!P^.US='5P
M(&ME('-C:'+A;F-E+@!.96YA<W1A=F5NX2!B87)V80!.97!O9'!O<F]V86[A
M('#X[7!O;F$`06MT=6%L:7IO=F%T`$%K='5A;&EZ;W9A="`E<P!!:W1U86QI
M>F]V870@=;YI=F%T96QE`%-K<FEP="!P<F\@86MT=6%L:7IA8VD@8GEL('9Y
M;6%ZX6XN`%#X96YO<P!6N65C:&YY('-O=6)O<GD@<')O(&YA<W1A=F5N[2!A
M<&QI:V%C[2!B>6QY('#X96YE<V5N>2!N82!S97)V97(N`%9E;&OA('1I<VMA
M8^T@<.US;65N80!696QKZ2#X[6US:^D@Z.US;&EC90!5<G5G=6%Y`%!O=;[M
M="!A:W1UX6QN[3H@)7,`4&]UONUT(%-33`!0;W6^[70@<&]K=60@:FWI;F\O
M:&5S;&\@:G-O=2!J:6[I(&YEOB!P<F\@24U34"!S97)V97(N`%6^:79A=&5L
M("5S(&YE;NT@;W!RX79N[&X@:R!P;W6^[7;A;NT@)7,N`$%D;6EN:7-T<F%C
M92!UOFEV871E;/D`5;YI=F%T96QS:^D@;6^^;F]S=&D`4F5G:7-T<F%C92!U
MOFEV871E;/D`3F$@=&]M=&\@<V5R=F5R=2!N96[M(&UOOF[A(')E9VES=')A
M8V4@=;YI=F%T96SY+@!5OFEV871E;'-KZ2!J;>EN;P!5OFEV871E;'-KZ2!J
M;>EN;SH`5;YI=F%T96QS:^D@:FWI;F\Z(`!397IN86T@=;YI=F%T96SY.@!5
M>F)E:VES=.%N`%9&4R!A9')E<^'X(&YE97AI<W1U:F4N`$1O=F]L96[A`$YA
M;&5Z96[A('!L871NX2!M[7-T82!Z86AR;G5J[3H@`%!L871N;W-T`$AO9&YO
M=&$@=B!M:6YU=.%C:"X`2&]D;F]T>0!6>6)R86[I(&AO9&YO='D@>@!686YU
M871U`%!R;VWL;F[I`%9E;F5Z=65L80!396QH86QA('9E<FEF:6MA8V4@+2!T
M871O('IP<N%V82!M;VAL82!B_70@>F9A;+EO=N%N82X`5F5R:7-I9VX@1&ER
M96-T;W)Y`%9E<GIE`%9E<G-I;VX@0V]N=')O;`!697)T:6OA;&[M('IA<F]V
M;N%N[0!697)T:6OA;&[M(&]D<W1U<`!697)T:6OA;&[M.@!696QM:2!V>7-O
M:^$`5FEE=&YA;0!6:65T;F%M<VMY("A625-#24DI`%IO8G)A>FET("5S`%IO
M8G)A>FET(&MO;G1A:W0`6F]B<F%Z:70@97AT97)N[2!W96)S='+A;FMU`%IO
M8G)A>FET(&IA:V\@)7,`26UP;&EC:71N[2!Z;V)R87IE;NTZ`%!A;FYE;G-K
MZ2!/<W1R;W9Y+"!"<FET<VOI`%!A;FYE;G-KZ2!/<W1R;W9Y+"!5+E,N`%9I
M9&ET96QN;W-T`%9I9&ET96QN;W-T.@!6;V1A9F]N92!)=&%L>2!P^&5S(%--
M5%``55!/6D]23DE4`%503UI/4D[,3LTA(2$@3T135%)!TE1%(%-+4DE05"!2
M5<A.S"!:("5S+@!786QL:7,@86YD($9U='5N80!5<&]Z;W)N[&[M`%-T`%#X
M961P;W;L[R!P;^AA<^T`1&%T82!O('!OZ&%S[2!P;W-K>71U:F4`5V5A=&AE
M<BYC;VT`5V5B`%=E8B!S97)V97(`55),('=W=R!S='+A;FMY`%3]9&[L`%;M
M=&5J=&4`5NUT96IT92!V("5S`%;M=&5J=&4L("5S`%KA<&%D;NT@*$E33RTX
M.#4Y+3$I`%KA<&%D;NT@*$E33RTX.#4Y+3$U*0!:X7!A9&[M(%-A:&%R80!+
M=&5R;W4@87!L:6MA8VD@;>$@)7,@>F]B<F%Z:70@<&\@</AI:&SAN65N[2!D
M;R!S>7-TZ6UU/P!*86O](&IE(&]D9.QL;W9A8^T@>FYA:S\`2F%K_2!J92!Z
M;F%K('!R;R!C:71A8VD_`$MT97+I(&;A>F4`5F]L8F$@<F]ZN>WX96[M('!R
M;R!2:6-H(%1E>'0@961I=&]R+@"I[?AK80"I[?AK82!V($-34R!J961N;W1K
MX6-H`*GM^&MA("5S(&UE;G4@=FQE=F\@*'IM[&YA('-E(&]B:F5V[2!P^&D@
M9&%LN>UM('#X:6ALX;EE;NTI.@"I[?AK82!T86)U;&MY`$IE9&YO=&MA(+GM
M^&MY`*GM^&MA.@!7:6MI`%;M='(`4F%N;NT@=NUT<@!2>6-H;&]S="!V['1R
M=2!V('5Z;&5C:`!6[71R.@!6[71R.B``36]U9')O<W0`4'+A8V4`061R97-A
M(&1O('IA;>QS=&[A;NT`3>QS=&\@861R97-Y(&1O('IA;>QS=&[A;NT`6F5M
M["!A9')E<WD@9&\@>F%M['-T;N%N[0!496QE9F]N(&1O('IA;>QS=&[A;NT`
M4%/((&1O('IA;>QS=&[A;NT`4W3A="]P<F]V:6YC:64@861R97-Y(&1O('IA
M;>QS=&[A;NT`56QI8V4@861R97-Y(&1O('IA;>QS=&[A;NT`6"U2968`6#4P
M.78S('KA:VQA9&[M(&]M97IE;NT`6#4P.78S(')O>KGM^&5NZ2!P;W6^:73M
M(&ML[>AE`%@U,#EV,R!A;'1E<FYA=&EV;NT@:FWI;F\@;W-O8GD`6#4P.78S
M(&ED96YT:69I:^%T;W(@:VSMZ&4`6#4P.78S(')O>KGM^&5N[0!24@!24E)2
M`$UA<&$@66%H;V\A`%)OZ&[L`$IE;65N`$%N;P!!;F\L('-O=6AL87/M;0!*
M<W1E('8@5$585$]6R4T@3=-$52X@4&]UOFEJ=&4@6SP^72!T;&'H[71K82!K
M('IP['1NZ6UU('#X97!N=73M(&1O(%=94TE764<N`$YE8GEL:2!J<W1E('-P
M<N%V;NP@;W;L^&5N:2X`6FYA:R`G7"<@;F5M^;YE(&+]="!S;W7HX7-T[2!6
M8;EE:&\@:FWI;F$N`$)Y;&$@>F%DX6YA(&YE<&QA=&[A(&4M;6%I;&]VX2!A
M9')E<V$N`$YE;6%P;W9A;&D@:G-T92"^X61NX2!P;VQE('H@:6UP;W)T;W9A
M;NEH;R!S;W5B;W)U(&L@;V1P;W;M9&%J[6/M;2!P;VSM;2!V("5S+@!.961O
M<W1A=&7H;N$@<'+A=F$@<')O('!R;VAL[;YE;NT@=&]H;W1O(&MO;G1A:W1U
M+@!.961O<W1A=&7H;N$@<'+A=F$@<')O('!R;VAL[;YE;NT@=&]H;W1O(&]B
M:F5K='4N`$)Y;&D@:G-T92!O9&ALX;EE;FD@>F4@<WES=.EM=2X`5FQOOG1E
M(.CM<VQO(&UO8FEL;NUH;R!T96QE9F]N=2P@<&]UOFEJ=&4@:F5N(.CM<VQI
M8R!N96)O('#X[7!A9&[L("<K)R!P<F\@;65Z:6[A<F]D;NT@Z&ES;&$N`$UU
M<^UT92!Z861A="!P;&%T;F]U(&AO9&YO='4N`$UU<^UT92!K;VYF:6=U<F]V
M870@9&%T86+A>FD@9&%T+"!P;VMU9"!S:2!P^&5J971E('!O=;[M=F%T(%)E
M9VES=')A8V4N`$UU<^UT92!K;VYF:6=U<F]V870@5D93(&)A8VME;F0N`$UU
M<^UT92!N96ID^.UV92!P;W!S870@<')O8FSI;2!A('!O=.D@:&\@;V1E<VQA
M="X`375S[71E('IA9&%T(%523"!N82!K=&5RZ2!B=61E('1E;G1O(&]D:V%Z
M('5K87IO=F%T`$UU<^UT92!N96ID^.UV92!V>6)R870@8^UL;W;](&%D<F5S
MX?@N`$UU<^UT92!N96ID^.UV92!V>6)R870@8^UL;W;]('-E>FYA;2X`375S
M[71E('9Y8G)A="!S97)V97(L(&MT97+](&)U9&4@<VUA>N%N+@!-=7/M=&4@
M;F5J9/CM=F4@=GEB<F%T(&%L97-P;_(@:F5D;G4@<&]L;[YK=2X`375S[71E
M('9Y8G)A="!UOFEV871E;'-KZ2!J;>EN;RP@:W1E<ND@8G5D92!S;6%ZX6YO
M+@!-=7/M=&4@>F%D870@=;YI=F%T96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@
M;V1S=')A;NQN;RX`3F5U=F5D;&D@:G-T92!UOFEV871E;'-KZ2!J;>EN;RP@
M:W1E<ND@8G5D92!P^&EDX6YO+@!.975V961L:2!J<W1E('6^:79A=&5L<VOI
M(&IMZ6YO('!R;R!A:W1U86QI>F%C:2X`375S[71E('IA9&%T(&%K8VDL(&MT
M97+A(&)U9&4@<')O=F5D96YA+@!-=7/M=&4@>F%D870@:FWI;F\@;F]VZ2!K
M871E9V]R:64N`%9AN64@<'+A=F$@9&]V;VQU:NT@<&]U>F4@<')O:&SMOF5N
M[2!T;VAO=&\@:V]N=&%K='4N`%9AN64@)7,@<F5L86-E(&)Y;&$@=6MO;NAE
M;F$N($]P['0@<V4@</AI:&QAN71E+"!P<F]S[6TN`%9AN64@96UA:6QO=N$@
M861R97-A`%9AN64@3V0M:V]H;SH@861R97-A.@!68;EE(&EN9F]R;6%C90!6
M(')E;&%C:2`E<R!S92!Z;>QN:6QA(%9AN64@:6YT97)N971O=N$@861R97-A
M+B!:(&)E>G!EZ&YO<W1N[6-H(&3Y=F]D^2!S92!M=7/M=&4@;W#L="!P^&EH
M;.%S:70N`%9AN64@:FWI;F\`5N&Y(&]V[/AO=F%C[2!S>7-TZ6T@;F5P;V1P
M;W)U:F4@=OUP:7,@=;YI=F%T96SY(&%N96)O('1A=&\@;6^^;F]S="!N96[M
M('#X[7-T=7!NX2!Z(&II;OUC:"!D^79O9/DN`%IDX2!S92P@OF4@=B!P<OEB
M[&AU(')E;&%C92`E<R!S92!Z;>QN:6P@5N&Y('!R;VAL[;YEZ"X@6B!B97IP
M9>AN;W-T;NUC:"!D^79O9/D@<V4@;75S[71E(&]P['0@</AI:&SA<VET+@!6
MX;D@<')O:&SMOF7H(&YE<&]D<&]R=6IE('1U=&\@;6^^;F]S="X`5F&Y92!S
M;W7H87-NZ2#H87-O=ND@<.%S;6\Z`%9AN64@:6UP;&EC:71N[2!I9&5N=&ET
M80!68;EE(/IP;&[I(&IMZ6YO.@!68;EE(&YO=ND@:&5S;&\@<')O("5S(&IE
M.B`E<P!68;EE(&YA<W1A=F5N[2!B>6QO(&%K='5A;&EZ;W;A;F\@<')O('1R
M=N%N[2!TZ71O(')E;&%C92X`5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI
M>F]VX6YO+@!68;EE(&AE<VQO(&)Y;&\@<F5S971O=N%N;RX`5F&Y92!H97-L
M;R!B>6QO(')E<V5T;W;A;F\L('IK;VYT<F]L=6IT92!S:2!Z<'+A=GD@96QE
M:W1R;VYI8VOI('!ON71Y(&$@</AI:&QAN71E('-E(',@5F&Y[6T@;F]V_6T@
M:&5S;&5M+@!68;EE('9Z9.%L96[I('-E<G9E<GDZ`$IU9V]S;.%V:64`6F%I
M<@!:86UB:64`6FEM8F%B=F4`6FEP<'D`6U5K<OUT(&-I=&]V86[]('1E>'1=
M`%M(;.&Y96[M('!R;V)LZ6UU70!;6F]B<F%Z:70@8VET;W9A;OT@=&5X="`M
M`%M:;V)R87II="!C:71O=F%N_2!T97AT("T@)7,@^.%D:_E=`%OXX61E:R`E
M<R!Z("5S70!;ON%D;N$@:&]D;F]T85T`7T%D;6EN:7-T<F%C90!?4')O:&SM
MOF5T`%]#3$D`7T1A=&%4<F5E`%]3;6%Z870`7U-M87IA="#XX61E:P!?4VMU
M<&EN>0!?3N%P;W;L9&$`7U9L87-T;F]S=&D@;V)RX7IK=2XN+@!?26UP;W)T
M;W9A="]E>'!O<G1O=F%T`%]0^&EH;.&Y96[M`%]/9&ALX;EE;NT`7TUO9&EF
M:6MO=F%T(&]D:V%Z+BXN`%]-;[YN;W-T:0!?4'+A=F$`7T]D<W1R86YI="!O
M9&MA>BXN+@!?3V1S=')A;FET('H@=&]H;W1O('-E>FYA;74`7U9Y:&QE9&%T
M`%].87-T879E;NT`7U9L87-T;F]S=&D@=&%B=6QK>2XN+@!?5;YI=F%T96SI
M`&%D<F5SX?@`:V%L96YDX?@`8F5Z=NQT^.T`:VQI:VYO=70@>F1E`&MO;G1A
M:W1Y+G9C9@!K;VYT86MT>2YC<W8`:V]N=&%K='DN='-V`'-RX;YK>0!S;W5B
M;W(`>B`E<R`H)7,I(')Y8VAL;W-T[2`E<R`E<P!H.@!O:V%MOFET[`!V(/AA
M9.P`^.%D:_E=`&-H>6)O=OT@:_-D(&UK:7-O9G,@)60@</AI('9Y=';A^&5N
M[2!)4T\N`&IMZ6YO`&YE;NT@:6UP;&5M96YT;W;A;F\`;F5N[2!D;W-U9"!I
M;7!L96UE;G1O=N%N;P!ZX7!I<V[M:P!P<F]C96YT`'!I>&5L^0!S=&]U<&%J
M[6/M`'IO8G)A>FET(')O>F3M;'D`<VUS,F5M86EL('IA('!O=;YI=.T@2%14
M4`!V>71R=F%LZ0!S97IN86T@^FMO;/D`<')O('!O='9R>F5N[2!N87!IN71E
M(&AE<VQO(&1V86MRX70`<VIE9&YO8V5N_0!B97H@;N%Z=G4`=GEB<F%T('6^
M:79A=&5L90!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+V5L7T=2+P``````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U
M,P`P,3<W-S``(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O
M96Q?1U(O3$-?34534T%'15,O````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S4S`#`R,34U-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1U<F)A+VQO8V%L92]E;%]'4B],0U]-15-304=%4R]T=7)B82YM;P``
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C$W,C8`,3`T,3<S-C(W-3,`,#(S,C,T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-X2!)4`
M````D@```!P```"L!```Q0```#P)````````4`P``"@```!1#```'0```'H,
M```(````F`P```4```"A#````P```*<,```(````JPP```8```"T#```!P``
M`+L,```4````PPP```\```#8#```!0```.@,```#````[@P``!\```#R#```
M"0```!(-```1````'`T```8````N#0``"````#4-```5````/@T```H```!4
M#0``#````%\-```.````;`T``!8```![#0``!P```)(-```:````F@T```(`
M``"U#0``!0```+@-```0````O@T``!H```#/#0``!@```.H-```/````\0T`
M``H````!#@``%`````P.```O````(0X```D```!1#@``#P```%L.```F````
M:PX```0```"2#@``!0```)<.```-````G0X```4```"K#@``$````+$.```0
M````P@X```\```#3#@``"P```.,.```/````[PX```P```#_#@``#P````P/
M```&````'`\``!,````C#P``'@```#</```5````5@\``!X```!L#P``(0``
M`(L/```B````K0\```,```#0#P``!````-0/```$````V0\```4```#>#P``
M!````.0/```,````Z0\```H```#V#P``!0````$0```*````!Q````\````2
M$```$@```"(0```0````-1````@```!&$```$````$\0```&````8!````<`
M``!G$````@```&\0```$````<A````@```!W$```#P```(`0```*````D!``
M``<```";$```#````*,0```'````L!```!4```"X$```!````,X0```%````
MTQ````0```#9$```!0```-X0```'````Y!```!$```#L$```"````/X0```>
M````!Q$```4````F$0``$0```"P1```H````/A$``"D```!G$0``$P```)$1
M```+````I1$``!$```"Q$0``!````,,1```$````R!$```P```#-$0``!@``
M`-H1```:````X1$``!<```#\$0``&@```!02```7````+Q(``!L```!'$@``
M-````&,2```?````F!(``!,```"X$@``"````,P2```-````U1(```H```#C
M$@``$````.X2```.````_Q(``!<````.$P``!P```"83```4````+A,```4`
M``!#$P``"0```$D3```F````4Q,``"<```!Z$P``*````*(3```A````RQ,`
M`!P```#M$P``!0````H4```#````$!0``"`````4%```)````#44```F````
M6A0```P```"!%```"````(X4```;````EQ0```<```"S%```!@```+L4```-
M````PA0```L```#0%```#````-P4```*````Z10```(```#T%```!@```/<4
M``!%````_A0``"L```!$%0``,````'`5```0````H14``!\```"R%0``$```
M`-(5```/````XQ4```4```#S%0``;`$``/D5```G````9A<``"````".%P``
M"P```*\7```%````NQ<```@```#!%P``$````,H7```,````VQ<```D```#H
M%P``$0```/(7```0````!!@```D````5&````P```!\8```B````(Q@```<`
M``!&&```$````$X8```%````7Q@```H```!E&```'````'`8```/````C1@`
M`!(```"=&```#P```+`8```<````P!@```<```#=&```(@```.48```"````
M"!D```@````+&0``%P```!09```E````+!D```@```!2&0``$````%L9```(
M````;!D``!D```!U&0``-0```(\9```)````Q1D``!(```#/&0``0````.(9
M```+````(QH```4````O&@``'@```#4:```%````5!H```T```!:&@``%```
M`&@:```,````?1H``"0```"*&@``#0```*\:```*````O1H``!8```#(&@``
M!P```-\:```;````YQH``#<````#&P``)0```#L;```G````81L``"P```")
M&P``+@```+8;```#````Y1L```D```#I&P```P```/,;```%````]QL```<`
M``#]&P``$P````4<```2````&1P```T````L'```#@```#H<```5````21P`
M`!4```!?'```%0```'4<```&````BQP``!8```"2'```!P```*D<```&````
ML1P```(```"X'```#````+L<```,````R!P``!0```#5'```$````.H<```&
M````^QP```\````"'0``!P```!(=```9````&AT```4````T'0``!````#H=
M```&````/QT```H```!&'0``"````%$=```1````6AT```<```!L'0``'P``
M`'0=```(````E!T``!4```"='0``+````+,=```Q````X!T``!4````2'@``
M$````"@>```7````.1X```4```!1'@``"@```%<>```3````8AX```D```!V
M'@``(P```(`>```L````I!X``",```#1'@``)0```/4>```B````&Q\``$$`
M```^'P``%P```(`?```=````F!\```T```"V'P``#P```,0?```/````U!\`
M`!(```#D'P``%@```/<?```;````#B````@````J(```'````#,@```(````
M4"````P```!9(```/0```&8@```Y````I"```#X```#>(```,````!TA```D
M````3B$```8```!S(0``%0```'HA```N````D"$``"H```"_(0``+P```.HA
M```/````&B(```P````J(@``'0```#<B```-````52(```L```!C(@``$0``
M`&\B```/````@2(``!(```"1(@``$0```*0B```"````MB(```8```"Y(@``
M00```,`B```D`````B,``$$````G(P``$@```&DC```B````?",``!4```"?
M(P``$@```+4C```-````R",```$```!G`````````"P```!"````*@```&D`
M``!8````"@`````````^````A@```%8```!(````/0```"$```!$````````
M``L````&````20```%````!B`````````$P``````````````#4````Z````
M````````````````.P```!D````N````-````%$````5````B0```!(````W
M````&P````````!O````:@`````````0````8P```"D````4````2P```((`
M``!X`````````"@```!E`````````($`````````7````"(```!'````5P``
M`#D````E````BP````````"0````C0```!$````P`````````"0```!L````
M``````````!M````"0```!X```"%````'P```&X```!V`````````%4`````
M````$P```",```!#````.````%,````V````0````$X`````````CP```$H`
M```%`````````%X```!@``````````````!R`````````&0```!K````````
M`(X```!%````=0```%L`````````D0``````````````<0````X```!S````
M/````!@````(````+0`````````````````````````K````60````````![
M````,@````(````G````B````!T```!4````7P````\````F`````````(<`
M````````:````!<````@``````````````!/``````````````!2`````P``
M`$$```"`````#0```%T```"$````@P````0```!T````C````"\`````````
M%@```&$`````````30```'T````S````>@```!H````'````````````````
M````6@`````````<````=P```'P````_````,0````````"*````D@```'D`
M``!^````?P```&8``````````````'``````````#````$8``````````"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@9FEL
M92!S=6-C97-S9G5L;'D@:6UP;W)T960`,C0@:&]U<G,`04TO4$T`061D`$%D
M9"!P86ER`$%D9"!T;P!!9&1R97-S`$%D9')E<W,@0F]O:R!,:7-T:6YG`$%D
M=F%N8V5D(%-E87)C:`!!;&EA<P!!;&P`06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+@!!<V-E;F1I;F<`079A:6QA8FQE(&9I96QD<SH`0G)O=W-E
M`$-A;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L
M;W-E(%=I;F1O=P!#;VQU;6X@3W!T:6]N<P!#;VUM82!S97!A<F%T960@=F%L
M=65S`$-O;7!A;GD`0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES="X`1$0`1&%I
M;'D`1&5F875L="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N
M.@!$96QE=&4`1&5L971I;VX@9F%I;&5D`$1E<V-E;F1I;F<`1&5S8W)I8F4@
M=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@3W!T:6]N<P!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%9&ET`$5M86EL
M`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S
M,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H
M86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>'!O<G0`
M17AP;W)T($%D9')E<W,@0F]O:P!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RX`1F%I;&5D('1O(&)R;W=S92!L:7-T`$9A:6QE9"!T;R!B<F]W<V4@
M=&AE(&1I<F5C=&]R>0!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`1F%I;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E<P!&87@`1FEN
M9`!&<F]M`$=R;W5P`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R
M9&4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`26UP;W)T960@9FEE;&0Z
M("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC
M<P!,;V<@:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG`$UA=&-H:6YG(&9I
M96QD<P!-96YU(&UO9&4Z`$UE<W-A9V4`36]B:6QE(%!H;VYE`$UO;G1H;'D`
M375L8F5R<GD@061D<F5S<R!";V]K`$YA;64`3F5V97(`3F]N90!.;W1E<P!/
M<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0:6YE($%D9')E<W,@0F]O:P!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5T=7)N('1O($]P=&EO;G,`4F]L
M90!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!F
M:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!W:&EC:"!F:65L9',@=&\@
M9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RX`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-H;W<@06QL
M`%-H;W<@0V]N=&%C=',`4VAO=R!,:7-T<P!3:VEP($UA:6YT96YA;F-E`%-O
M<G0@1&ER96-T:6]N`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`
M5&%B('-E<&%R871E9"!V86QU97,`5&%S:W,`5&5X="!/;FQY`%1H97)E(&%R
M92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O:W,N`%1H97)E('=A<R!A;B!E
M<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+@!4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@=&AI<R!O8FIE8W0N`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE
M`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`57-E<B!/<'1I;VYS`%5S97)N86UE
M`%9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.@!787)N:6YG`%=E96ML>0!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H
M;VYE`%E9`%EE87)L>0!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+@!9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U
M<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`'9#87)D`%!R;VIE
M8W0M260M5F5R<VEO;CH@5'5R8F$Z(#$N,BUC=G,*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`Q
M+3`W+3(V(#$Q.C,V*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!3=&5F86YO<R!)
M+B!$:6UI=')I;W4@/'-U<'!O<G1?=V5B;6%I;$!T96EA=&@N9W(^"DQA;F=U
M86=E+51E86TZ($=R965K(#QD979`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E
M<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M:7-O+3@X-3DM-PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`
M)7,@R^7I]._U\>/?Y?(@T_7M]-[QY_/G\B`M(,7PZ>+EXN'?^?/G`"5S(,7P
MZ?3U]_[R(.7I\^'C^>/>(/3O]2#A\??EW^_U`#(T_O'G(.SO\?;>`-#,+\S,
M`-#Q[_/HWNKG`-#Q[_/HWNKG(.;E_>/O]?(`T/'O\^C>ZN<@\_3O`,3IY?WH
M]>WSYP#+W_/TX2#$Z>7UZ/WM\^7Y[0#%Z>3IZMX@P>WAYM[TY_/G`-CE]>3^
M[?7L[P"\Z^$`S_'?\_3GZN4@[-_A(.SG(.7PZ?3QY?#\[.7MYR#TZ>S>+@#!
M_>[O]?/A`,3IX>C=\^GLX2#0Y>3?X3H`R]_S].$`Q^SE\>_K_./I[P#!ZOWQ
M^?/G(,'MX?;O\=SR(-#Q[^+KWNSA]._R`,KI[>?T_"#4Y^O=]OGM[P#*Z^7?
M\^GL[R#0X?'<Z/7Q[_4`Q?#IZ^_CW?(@T_3GZ_[M`-3I[-WR(.3IX??Y\>GS
M[-WMY?(@[.4@ZOSL[.$`Q?3AZ?'?X0#'(.KA\?3=Z^$@X?;AZ?'=Z.?JY2#A
M\/P@].<@Z]_S].$N`$1$`,?LY?'>\^GA`-#Q[^7PZ>OEX^S=[><@U.'U]/ST
MY_3A`-#Q[^7PZ>OEX^S=[><@ZN'TY?WH]>WSYR#TX>[I[?SLY_/G\CH`Q.GA
MX_'A]MX`Q.GAX_'A]MX@X?#=]/7WY0#6Z-_M[_7SX0#0Y?'IX_'A]MX@]._U
M(-#Q[^+KWNSA]._R`,_I(.OE\/3O[-WQY>GE\B#=]^_U[2#JX?3AX_'A]N7?
M(./IX2#T[^T@Y.GA]^7I\>GS]-XN`,KA]-SK[^/O\@#%\.GK[^/=\B#%[/;<
M[>GSY_(`S.?M(.7PZ??EZ?'>\^7TY2#MX2#A[>_?[N7TY2#A\.7UZ.7?X?(@
M].\@X?'WY=_O(&UA:6YT96YA;F-E+G!H<`#%\.7NY?'CX?/?X0!%;6%I;`#$
MY>T@Y?#I\_3QW/;GZN'M(,'P[_3EZ]WS[.'TX2X`R]SH[_(`RMSHY2`Q-2#K
MY?#TW`#*W.CE(#,P(.3E]?3E\?SKY?#TX0#*W.CE(#4@Z^7P]-P`RMSHY2#V
M[_'<(/#O]2#L\.'?[>7TY2#S].?M(/7PY_'E\]_A`,K<Z.4@[.GSWB#^\>$`
MRMSHY2#KY?#T_`#0X?'AY.7IX^SA].GJW?(@].GLW?(Z`,7NX>/YX]X`Q>[A
MX_GCWB#"Z>+KW^_U(,3IY?7H_>WSY?GM`,'P[_3U]]_A(.KA]-P@].?M(/#Q
M[_/PW.CEZ>$@X>W<ZO3G\^?R(/3Y[2#P\>_TZ>S>\^7Y[2X`P?#O]/7WW^$@
MZN'TW"#TY^T@Y>SVW.WI\^<@].?R(.O?\_3A\@#!\._T]???X2#JX?3<(/3G
M[2#P\>_B[^O>(/3O]2#JX?3AZ_SC[_4`P?#O]/7WW^$@\_WMY.7SY_(@\_3O
M[2#DZ>'J[^SI\_3>(,KA].'K_./O]2X`P?#O]/7WW^$@ZN'TW"#TY^T@X>WA
MYM[TY_/G(//T[^T@ZN'TW.OOX^\@.B`E<P#6X>X`P>WAYM[TY_/G`,'P_`#/
M[-SDX0#"[][HY>GA`,3IY?WH]>WSYR#*X?3OZ>K?X?(`U.?KW?;Y[>\@RN'T
M[^GJW^'R`,'Q]^GJWB#3Y>O?Y.$`S/SM[R#%Z>KO[=_DZ>$`Q>GJ[^W?Y.GA
M(.KAZ2#*Y=_LY>WO`-#EY-_O(/#O]2#EZ?/>]^CG.B`E<P#0Y>3?X2#P[_4@
MY>GSWO?HY_/A[3H`P^O^\_/A`,O?\_3A(.CE[-ST^>T@PN_>Z.7IX?(`Q=_S
M[^3O\@"X[N_D[_(`S,P`P>OKY^OOX_'A]M_A`-3AZ?'IW.;EZ2#LY0#0Y>3?
MX2#P[_4@].'I\>G<YN_U[0#*X?3<\_3A\^<@S.7M[_TZ`,S>[?7LX0#*Z>WG
M]/P@U.?KW?;Y[>\`S.?MZ>'?X0#$Z>7UZ/7M\^GOX_'<]N_R($UU;&)E<G)Y
M`+SM[^SA`-#O]-T`RN'MW>WA`-/G[.7I_O/EZ?(`Q?#IZ^_CW?(`P>OKY?(@
MT.OG\>_V[_'?Y?(`ROGDZ>K\\@#%ZO3=Z^7SYR#+Y>GT[_7QX^G^[2#3]>WT
MWO'G\^?R`-3GZ]WV^>WO`,3IY?7H]>WSZ>_C\=SV[_(@4&EN90#0X?'AZN'K
M_B#D_O/TY2#LW^$@\.7QW^OG^.<@]._U(/#Q[^+KWNSA]._R+@#0X?'AZN'K
M_B#D_O/TY2#T[R"\[>_LX2#7\=[S].<@ZN'I(/3O[2#J^>3IZOP@\^'R`-#E
M\>GC\>'VWB#0\>_BZ][LX?3O\@#!]N'?\>7SYR#FY?WC[_7R`,7PZ?/T\>_V
MWB#S].GR(,7PZ>OOX]WR`-'\Z^_R`,'P[^C>ZN7U\^<`P?#OZ-[JY?7SYR#%
M\.GK[^/^[0#![>'FWO3G\^<`Q?#IZ^_CWB#T[_4@Y.GA]_GQZ?/TWB#G[.7Q
M[^SG[=_A\CH`Q?#IZ^_CWB#TY_(@[._Q]M[R(/#O]2#HX2#=]^7I(.<@Y^SE
M\>_LY^W?X3H`Q?#IZ]WN].4@].\@X?'WY=_O(/#O]2#HX2#EZ?/A]^CEWSH`
MQ?#IZ^_CWB#TY_(@[._Q]M[R(/#O]2#HX2#=]^7I(.<@_O'A.@#%\.GKW>[T
MY2#D_>\@\.7DW^$@\._U(/3AZ?'IW.;O]>TN`,7PZ>OOX]X@]/GM(/#EY-_Y
M[2#P[_4@Z.$@Y>SVX>W?YN_M].'I(//TYR#KW_/TX2#T^>T@Y.GE]>C][?/E
M^>TN`,7PZ>O=[O3E(/3G(./K_O/SX2#SX?(Z`,'P[_/T[^O>(,'MX?;O\=SR
M(-#Q[^+KWNSA]._R`,7L]MSMZ?/G(+SK^>T`Q>SVW.WI\^<@Q?#A]O[M`,7L
M]MSMZ?/G(,OI\_3^[0#!ZOWQ^?/G(-/U[?3>\>?SY_(`RN'TY?WH]>WSYR#4
MX>[I[?SLY_/G\@#%Z?/AX_GCWB#%Z>3IZO[M(-?A\>'J]-[Q^>T`Q?#I]/7W
MW^$`U.GLWO(@Y.GA]_GQZ?/LW>WE\B#LY2`G5&%B)P#%\>/A\]_E\@#,_.WO
M(,KEW^SE[>\`Q.7M(/7PW/'W[_7M(.3IY?7H]>WSZ>_C\=SV[^D@]._U\B#O
M\._?[_7R(.SP[_'EW_3E(.WA(.3EW_3E+@#0X?'O]?/IW//TY^KE(//VW.OL
MX2#JX?3<(/3G[2#DY^SI[_7QX]_A(/3G\B#MW>'R(.O?\_3A\BX`T.'Q[_7S
MZ=SS].?JY2#S]MSK[.$@ZN'TW"#TY^T@Y.GAX_'A]MX@X?7T[_T@]._U(.'M
M].GJY>GLW>WO]2X`P?7T_/(@[R#A\>GH[/SR(/#QW?#EZ2#MX2#EW^WAZ2#T
M[_7KW/?I\_3O[2#=[>$N`,'U]-X@YR#TZ>S>(/#QW?#EZ2#MX2#EW^WAZ2#A
M\>GH[/SR+@#4W_3K[_(`Q^OEZO3Q[^WIZMX@Q.GE_>CU[?/G`,3E[2#EW^WA
MZ2#D]>WA]-X@YR#S_>WDY?/G(//T[R#DZ>'J[^SI\_3>(%-13"X`Q.7M(.SP
M[_'O_>T@[>$@X]_M[_7M(._I(/'UZ.S?\^7I\B#T[_4@)7,N`,3E[2#L\/SQ
MY?/E(.WA(.SE].'V\>'S].7?(.'U]/P@].\@W>/C\>'V[R!7;W)D`,7PZ>OO
MX]WR(-?QWO/TYP"\[>_LX2#7\=[S].<`QR#P\>_B[^O>(/#O]2#HX2#E[/;A
M[=_FY?3AZ3H`T/'OY>GD[_#OW^?SYP#%XN3O[.'DZ>'?X0#*X>OY\][QZ.7R
M(//T[R`E<P#*X>O^\B#>Z^CE\BP@)7,`Q.GE_>CU[?/G(,7QX^'SW^'R`-3G
MZ]WV^>WO(,7QX^'SW^'R`%E9`,7TWO/IX0#0\=WPY>D@[>$@\.7QZ>/QW/CE
M].4@].\@\/'\XNOG[.$@\/'I[2#S].7?Z^7TY2#A[>'V[_'<(./IX2#A]?3\
M+@#0\=WPY>D@\/'^].$@[>$@Y?#IZ]WNY?3E(.S?X2#E\.'VWBX`QR#S_>WD
MY?/G(//A\B`E<R#DZ>'J_/#GZN4N(-#A\>'JX>O^(.3OZNGLW//TY2#MX2#N
MX>WA\_7MY.7HY=_TY2X`S^D@T.OG\>_V[_'?Y?(@\^'R`,_I(.7PZ>OOX]WR
M(//A\B#=]^_U[2#A\._HY^KE]?3EWRX`6\'MX?;O\=P@T/'OXNO>[.'T[_)=
M`%OC\>'L[-X@)7,@X?#\("5S70#8Y_;IX>K>(,K<\?3A````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+V9A7TE2+P``````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-``P
M,3<W-C$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O9F%?
M25(O3$-?34534T%'15,O````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S4T`#`R,34T-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1U<F)A+VQO8V%L92]F85])4B],0U]-15-304=%4R]T=7)B82YM;P``````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`T,C<W-S<`,3`T,3<S-C(W-30`,#(S,C0U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
M@08``!P````D-```K0@``"QH````````X(H```X```#AB@``#P```/"*```-
M`````(L```@````.BP``"P```!>+```,````(XL```0````PBP``*0```#6+
M```D````7XL``"D```"$BP``&0```*Z+```D````R(L``"4```#MBP``)@``
M`!.,```,````.HP``"0```!'C```#P```&R,```+````?(P```X```"(C```
M!0```)>,```H````G8P```@```#&C```"@```,^,```5````VHP```D```#P
MC```$@```/J,```+````#8T``!T````9C0``A0```#>-```.````O8T```H`
M``#,C0``#0```->-```.````Y8T```T```#TC0``#`````*.```-````#XX`
M``8````=C@``"@```"2.```/````+XX``!@````_C@``#````%B.```.````
M98X```X```!TC@``"````(..```K````C(X``"X```"XC@``&@```.>.```R
M`````H\``#@````UCP``5````&Z/``!1````PX\``%H````5D```5P```'"0
M```T````R)````T```#]D```!P````N1```*````$Y$```\````>D0``!0``
M`"Z1```1````-)$```@```!&D0``$0```$^1```)````89$```D```!KD0``
M)0```'61```@````FY$``!,```"\D0``$P```-"1```0````Y)$```\```#U
MD0``"@````62```#````$)(```\````4D@``%````"22```)````.9(```T`
M``!#D@``$@```%&2```>````9)(```\```"#D@``$````).2```*````I)(`
M``@```"OD@``#P```+B2```(````R)(``"0```#1D@``!@```/:2```4````
M_9(``!8````2DP``"````"F3```9````,I,```<```!,DP``%````%23```-
M````:9,``!(```!WDP``(0```(J3```I````K),``"P```#6DP``#@````.4
M```#````$I0```\````6E```!0```":4```%````+)0```H````RE````P``
M`#V4```7````090```H```!9E```#P```&24```.````=)0``!@```"#E```
M(P```)R4```.````P)0```X```#/E```%````-Z4```7````\Y0``!<````+
ME0``%P```".5```3````.Y4```\```!/E0``'P```%^5```/````?Y4```8`
M``"/E0``"P```):5```0````HI4``!4```"SE0``%0```,F5```'````WY4`
M`!````#GE0``!0```/B5```5````_I4``!$````4E@``#````":6```H````
M,Y8``#H```!<E@``.P```)>6```4````TY8```,```#HE@``"0```.R6```Y
M````]I8``!(````PEP``)P```$.7```L````:Y<``"H```"8EP``)0```,.7
M```*````Z9<```8```#TEP``+P```/N7```W````*Y@``"X```!CF```50``
M`)*8```M````Z)@``"T````6F0``+0```$29``!`````<ID``",```"SF0``
M(P```->9```M````^YD``#,````IF@``%0```%V:```9````<YH``"D```"-
MF@``)````+>:```1````W)H```H```#NF@``$````/F:```6````"IL``!8`
M```AFP``%````#B;```(````39L```P```!6FP``$0```&.;```4````=9L`
M``@```"*FP``*0```).;```.````O9L```H```#,FP``!````->;```)````
MW)L```8```#FFP``$0```.V;```'````_YL```0````'G```!@````R<```&
M````$YP```T````:G```$0```"B<```#````.IP```,````^G```%P```$*<
M```#````6IP``!,```!>G```"````'*<```$````>YP``$$```"`G```&@``
M`,*<```<````W9P``"````#ZG```%0```!N=```&````,9T``!4````XG0``
M&````$Z=```B````9YT``"X```"*G0``'0```+F=```A````UYT``%0```#Y
MG0``*0```$Z>```'````>)X```<```"`G@``%0```(B>```*````GIX```\`
M``"IG@``#0```+F>```/````QYX```T```#7G@``"0```.6>```4````[YX`
M``8````$GP``'0````N?```3````*9\``!0````]GP``!@```%*?```4````
M69\``%0```!NGP``9````,.?```$````**````X````MH```#P```#R@```%
M````3*```!L```!2H```&@```&Z@```1````B:```!$```";H```%@```*V@
M```7````Q*```!P```#<H```*@```/F@```Y````)*$``"(```!>H0``,@``
M`(&A```A````M*$```4```#6H0``$P```-RA```2````\*$```H````#H@``
M#P````ZB```1````'J(``!,````PH@``#````$2B```&````4:(```8```!8
MH@``$````%^B```1````<*(```4```""H@``#````(BB```0````E:(```4`
M``"FH@``#@```*RB```-````NZ(``",```#)H@``!@```.VB```6````]*(`
M`"H````+HP``!P```#:C```-````/J,```<```!,HP``"P```%2C```'````
M8*,```\```!HHP``"0```'BC```)````@J,```H```",HP``&0```)>C```,
M````L:,``!````"^HP``$@```,^C```3````XJ,``!4```#VHP``$@````RD
M```K````'Z0``#L```!+I```(````(>D```6````J*0``!H```"_I```"```
M`-JD```4````XZ0``#8```#XI```"````"^E```&````.*4```0````_I0``
M#@```$2E```>````4Z4``!L```!RI0``(0```(ZE```>````L*4``!D```#/
MI0``'@```.FE```=````"*8``!L````FI@``(````$*F```F````8Z8``!L`
M``"*I@``'@```*:F```<````Q:8``"8```#BI@``,P````FG```F````/:<`
M`"L```!DIP``.````)"G```O````R:<``!(```#YIP``*0````RH```2````
M-J@``*(```!)J```%@```.RH```C`````ZD``"@````GJ0``*0```%"I```H
M````>JD``!\```"CJ0``(````,.I```E````Y*D``"@````*J@``,````#.J
M``"2````9*H``"$```#WJ@``'````!FK```F````-JL``$$```!=JP``#```
M`)^K```'````K*L```<```"TJP``#0```+RK```=````RJL``!````#HJP``
M$@```/FK```'````#*P``!,````4K```$@```"BL```,````.ZP```X```!(
MK```#P```%>L```3````9ZP```T```![K```*````(FL```#````LJP```T`
M``"VK```$0```,2L```7````UJP``!L```#NK````@````JM```%````#:T`
M`!`````3K0``!````"2M```-````*:T```X````WK0```P```$:M```.````
M2JT```@```!9K0``#P```&*M```/````<JT```<```""K0``#0```(JM```0
M````F*T```T```"IK0``&@```+>M```+````TJT```8```#>K0``$P```.6M
M```,````^:T``!$````&K@``&0```!BN```7````,JX```L```!*K@``#0``
M`%:N```B````9*X``!8```"'K@``&P```)ZN```T````NJX```H```#OK@``
M&````/JN```9````$Z\``!8````MKP``#P```$2O```-````5*\```H```!B
MKP``"@```&VO```4````>*\``"(```"-KP``+P```+"O```+````X*\```D`
M``#LKP``&0```/:O```+````$+```!<````<L```%P```#2P```)````3+``
M``<```!6L```%@```%ZP```/````=;```!D```"%L```%@```)^P```.````
MMK```!@```#%L```#0```-ZP```F````[+```"@````3L0``0P```#RQ```(
M````@+$```L```")L0``+P```)6Q```.````Q;$```X```#4L0``!0```..Q
M```&````Z;$```,```#PL0``!````/2Q```*````^;$```H````$L@``#P``
M``^R```0````'[(``!<````PL@``$0```$BR```1````6K(``!D```!LL@``
M%P```(:R```)````GK(```H```"HL@```@```+.R```%````MK(```T```"\
ML@``&P```,JR```7````YK(```D```#^L@``#@````BS```-````%[,``!(`
M```ELP``.````#BS```@````<;,```@```"2LP``#@```)NS``![````JK,`
M`!@````FM```/0```#^T```5````?;0``!L```"3M```!0```*^T```8````
MM;0``!D```#.M```&P```.BT```9````!+4```8````>M0``!@```"6U```0
M````++4```\````]M0``$````$VU```/````7K4```L```!NM0``#P```'JU
M```,````BK4```\```"7M0``!P```*>U```&````K[4```X```"VM0``#```
M`,6U```/````TK4```@```#BM0``!@```.NU```3````\K4``"(````&M@``
M+0```"FV```(````5[8``!,```!@M@``'@```'2V```E````D[8``!H```"Y
MM@``%0```-2V```>````ZK8``$,````)MP``(0```$VW```@````;[<``!D`
M``"0MP``%P```*JW```E````PK<``"4```#HMP``%P````ZX```B````)K@`
M``0```!)N```#````$ZX```#````6[@```@```!?N```"P```&BX```0````
M=+@``!,```"%N```%````)FX```,````KK@```D```"[N```#@```,6X```+
M````U+@``!L```#@N```!0```/RX```'`````KD```0````*N0``!@````^Y
M```*````%KD```H````AN0``#0```"RY```)````.KD```4```!$N0```P``
M`$JY```8````3KD```H```!GN0``!````'*Y```F````=[D```X```">N0``
M%0```*VY```%````P[D```<```#)N0``#````-&Y```(````WKD```H```#G
MN0``!@```/*Y```(````^;D```(````"N@``!@````6Z```,````#+H```0`
M```9N@``"0```!ZZ```0````*+H```D````YN@``"0```$.Z```:````3;H`
M``@```!HN@``&0```'&Z```.````B[H```H```":N@``$P```*6Z```"````
MN;H```T```"\N@``"0```,JZ```2````U+H```4```#GN@``%````.VZ```=
M`````KL```8````@NP``$0```">[```)````.;L```0```!#NP``.0```$B[
M```]````@KL``#H```#`NP``'@```/N[```.````&KP```0````IO```!@``
M`"Z\```5````-;P```8```!+O```!````%*\```1````5[P```8```!IO```
M"@```'"\```B````>[P```0```">O```!0```*.\```$````J;P```P```"N
MO```"0```+N\```,````Q;P```X```#2O```"@```.&\```0````[+P``!,`
M``#]O```$P```!&]```%````);T``#H````KO0``,````&:]```U````E[T`
M`"D```#-O0``.````/>]```I````,+X``#\```!:O@``+@```)J^```M````
MR;X``!\```#WO@``#P```!>_```2````)[\```L````ZOP``)@```$:_```I
M````;;\``"0```"7OP``)@```+R_```(````X[\```H```#LOP``(````/>_
M```@````&,```"8````YP```!````&#````*````9<```!D```!PP```*0``
M`(K````2````M,````H```#'P```#````-+````/````W\```!````#OP```
M0`````#!``!P````0<$``&8```"RP0``#@```!G"```)````*,(```H````R
MP@``$@```#W"```3````4,(```P```!DP@``!@```''"```<````>,(```\`
M``"5P@``&P```*7"```2````P<(``!````#4P@``$0```.7"```<````]\(`
M`",````4PP``:@```#C#```/````H\,``!````"SPP``!````,3#```+````
MR<,``"````#5PP``%````/;#```,````"\0```P````8Q```#P```"7$```5
M````-<0``"D```!+Q```*@```'7$```F````H,0``"<```#'Q```*0```._$
M```J````&<4``!D```!$Q0``0@```%[%```1````H<4``!(```"SQ0``$P``
M`,;%```4````VL4```\```#OQ0``%@```/_%```7````%L8``!`````NQ@``
M$0```#_&```T````4<8``!,```"&Q@``$@```)K&```U````K<8``!0```#C
MQ@``!P```/C&```,`````,<```H````-QP``(````!C'```4````.<<``!0`
M``!.QP``$0```&/'```7````=<<``!P```"-QP``#0```*K'```-````N,<`
M`!,```#&QP``%@```-K'```1````\<<```P````#R```$````!#(```:````
M(<@``!X````\R```&@```%O(```1````=L@``!<```"(R```%````*#(```7
M````M<@``!4```#-R```"0```./(```0````[<@``!$```#^R```!@```!#)
M```&````%\D```<````>R0``%@```";)```&````/<D```0```!$R0``!```
M`$G)```'````3LD```X```!6R0``#````&7)```,````<LD```T```!_R0``
M#@```(W)```H````G,D```P```#%R0``#P```-+)```*````XLD```@```#M
MR0``"0```/;)```K`````,H```0````LR@``#P```#'*``!,````0<H```<`
M``".R@``"````);*```)````G\H```T```"IR@``"0```+?*```4````P<H`
M``P```#6R@``#0```./*```.````\<H``!8`````RP``$0```!?+```#````
M*<L```8````MRP``!````#3+```+````.<L```L```!%RP``#0```%'+```*
M````7\L``!````!JRP``#P```'O+```1````B\L``!<```"=RP``"@```+7+
M```1````P,L```0```#2RP``#P```-?+```Z````Y\L```4````BS```#```
M`"C,```$````-<P``!X````ZS```#@```%G,```0````:,P```L```!YS```
M#````(7,```)````DLP```<```"<S```"@```*3,```)````K\P```X```"Y
MS```$````,C,```:````V<P```H```#TS```"@```/_,```,````"LT```\`
M```7S0``"````"?-```&````,,T```<````WS0``!0```#_-```+````1<T`
M`$<```!1S0``#0```)G-```)````I\T```0```"QS0```P```+;-```3````
MNLT``!,```#.S0``$P```.+-```"````]LT```0```#YS0``)0```/[-```#
M````),X```4````HS@``!````"[.```*````,\X```T````^S@``:````$S.
M```)````M<X```P```"_S@``!0```,S.```&````TLX``!L```#9S@``+P``
M`/7.```(````)<\```\````NSP``$P```#[/```;````4L\``!@```!NSP``
M%P```(?/```:````G\\```X```"ZSP``%P```,G/```#````X<\```@```#E
MSP``!P```.[/```)````]L\```H`````T```"P````O0```'````%]```%$`
M```?T```$````''0```,````@M````T```"/T```&@```)W0``!*````N-``
M``8````#T0``!@````K1```&````$=$```D````8T0``&````"+1```7````
M.]$```L```!3T0``!@```%_1```-````9M$``"@```!TT0``5P```)W1```3
M````]=$``!,````)T@```@```!W2```+````(-(```P````LT@``"````#G2
M```-````0M(```H```!0T@``%@```%O2```.````<M(```<```"!T@``"P``
M`(G2```7````E=(```P```"MT@``#0```+K2```,````R-(```0```#5T@``
M"0```-K2```)````Y-(```H```#NT@``!P```/G2```)`````=,```D````+
MTP``"@```!73```'````(-,``!4````HTP``&P```#[3``!)````6M,``!(`
M``"DTP``"@```+?3```6````PM,```D```#9TP``$````./3```2````]-,`
M``0````'U```"P````S4```:````&-0``!$````SU```&@```$74```6````
M8-0``!0```!WU```%P```(S4```<````I-0``!D```#!U```!P```-O4```%
M````X]0```P```#IU```"P```/;4```(`````M4``!<````+U0``#````"/5
M```?````,-4``!H```!0U0``$P```&O5```$````?]4```H```"$U0``!```
M`(_5```,````E-4```@```"AU0``!0```*K5```"````L-4``!@```"SU0``
M%P```,S5```X````Y-4``"P````=U@``$@```$K6```I````7=8``#(```"'
MU@``"@```+K6```L````Q=8``"X```#RU@``,P```"'7```S````5=<``#@`
M``")UP``$0```,+7```/````U-<``!@```#DUP``$````/W7```/````#M@`
M`!,````>V```%````#+8```2````1]@``!0```!:V```%0```&_8```M````
MA=@``"T```"SV```,0```.'8```N````$]D``"\```!"V0``+````'+9```3
M````G]D```@```"SV0``%P```+S9```(````U-D``"L```#=V0``(0````G:
M```8````*]H``!H```!$V@``"0```%_:``!%````:=H``$$```"OV@``!```
M`/':```3````]MH``!0````*VP``$P```!_;```)````,]L```H````]VP``
M#P```$C;```0````6-L```<```!IVP``#@```'';```%````@-L``!L```"&
MVP``"````*+;```&````J]L``!0```"RVP``$0```,?;```8````V=L```X`
M``#RVP``.`````'<```"````.MP```8````]W```#@```$3<```0````4]P`
M``4```!DW```!P```&K<```.````<MP```8```"!W```*````(C<```,````
ML=P``!P```"^W```*0```-O<```7````!=T``!\````=W0``&0```#W=``!<
M````5]T``!0```"TW0``'P```,G=```0````Z=T```<```#ZW0``#@````+>
M```,````$=X```P````>W@``$P```"O>```*````/]X``!T```!*W@``&0``
M`&C>```%````@MX``!$```"(W@``#0```)K>```1````J-X``"0```"ZW@``
M%0```-_>```2````]=X```X````(WP``&0```!??```(````,=\```D````Z
MWP``#0```$3?```*````4M\```<```!=WP``#P```&7?```+````==\``!H`
M``"!WP``"@```)S?```'````I]\```T```"OWP``"````+W?```>````QM\`
M`!(```#EWP``+````/C?```:````)>````D```!`X```"@```$K@```5````
M5>````4```!KX```%````''@```$````AN```!````"+X```!@```)S@```'
M````H^```!X```"KX```*````,K@```*````\^```!P```#^X```$0```!OA
M```1````+>$``!H````_X0``%````%KA```$````;^$```4```!TX0``!@``
M`'KA```1````@>$```8```"3X0``&P```)KA```T````MN$``#0```#KX0``
M(````"#B```I````0>(``"````!KX@``00```(SB```:````SN(``"$```#I
MX@``*`````OC```I````-.,``%````!>XP``(@```*_C```(````TN,```4`
M``#;XP``&0```.'C```9````^^,``"H````5Y```(P```$#D```N````9.0`
M`#0```"3Y```"````,CD```7````T>0```H```#IY```!P```/3D```A````
M_.0```@````>Y0``$````"?E```.````..4``!0```!'Y0``"P```%SE```'
M````:.4``!,```!PY0``"````(3E```+````C>4```H```"9Y0``%````*3E
M```R````N>4```4```#LY0``%0```/+E```,````".8```4````5Y@``%P``
M`!OF```/````,^8```0```!#Y@``"@```$CF```)````4^8```L```!=Y@``
M#0```&GF```,````=^8```X```"$Y@``!0```)/F```$````F>8``!0```">
MY@``#0```+/F```R````P>8``!L```#TY@``10```!#G```2````5N<``!<`
M``!IYP``'@```('G```4````H.<``!0```"UYP``!P```,KG```.````TN<`
M`"H```#AYP``!@````SH```,````$^@``!,````@Z```#0```#3H```1````
M0N@``!4```!4Z```"P```&KH```V````=N@```H```"MZ```(@```+CH```+
M````V^@```\```#GZ```A0```/?H```R````?>D``!L```"PZ0``#@```,SI
M```%````V^D```X```#AZ0``$P```/#I```1````!.H```<````6Z@``$0``
M`![J```3````,.H```<```!$Z@``%````$SJ```8````8>H```<```!ZZ@``
M!0```(+J```,````B.H```P```"5Z@``$@```*+J```$````M>H```H```"Z
MZ@``"P```,7J```,````T>H```X```#>Z@``#@```.WJ```%````_.H```4`
M```"ZP``+@````CK```F````-^L``",```!>ZP```P```(+K```8````ANL`
M`!D```"?ZP``)0```+GK```-````W^L```D```#MZP```P```/?K```8````
M^^L```<````4[```"@```!SL```"````)^P``!(````J[```!````#WL```'
M````0NP```P```!*[```4@```%?L```7````JNP```<```#"[```!@```,KL
M```.````T>P```\```#@[```#0```/#L```1````_NP```P````0[0``#```
M`!WM```-````*NT``!4````X[0``$@```$[M```/````8>T``!0```!Q[0``
M"@```(;M```;````D>T``!````"M[0``"P```+[M```G````RNT``"4```#R
M[0``:0```!CN```F````@NX``!H```"I[@``%P```,3N```9````W.X``!H`
M``#V[@``)0```!'O```H````-^\``"<```!@[P``&@```(CO```7````H^\`
M`!L```"[[P``1````-?O```T````'/```"4```!1\```&0```'?P```?````
MD?```!,```"Q\```"````,7P```(````SO````D```#7\```#0```.'P```3
M````[_````,````#\0``1@````?Q```_````3O$``#<```".\0``5P```,;Q
M```%````'O(``!\````D\@``+P```$3R```0````=/(```@```"%\@``#0``
M`([R```M````G/(```0```#*\@``!P```,_R```(````U_(```T```#@\@``
M"@```.[R``!/````^?(``"4```!)\P``'````&_S```+````C/,``!\```"8
M\P``'0```+CS```E````UO,``"````#\\P``)````!WT```@````0O0```L`
M``!C]```!P```&_T```-````=_0```P```"%]```!@```)+T```Y````F?0`
M``<```#3]```"0```-OT```3````Y?0```0```#Y]```$````/[T```$````
M#_4```L````4]0``#````"#U```2````+?4``!$```!`]0``#````%+U```:
M````7_4```T```!Z]0``#@```(CU```4````E_4```X```"L]0``!P```+OU
M```;````P_4``!,```#?]0``'````//U```H````$/8```8````Y]@``!P``
M`$#V```3````2/8```0```!<]@``%P```&'V```Y````>?8```H```"S]@``
M#````+[V```)````R_8```8```#5]@``"````-SV```)````Y?8```H```#O
M]@``$0```/KV```&````#/<```X````3]P``#@```"+W```+````,?<```L`
M```]]P```@```$GW```'````3/<```8```!4]P``"0```%OW```'````9?<`
M`!L```!M]P``*P```(GW```:````M?<``#L```#0]P``*`````SX```T````
M-?@``!4```!J^```!P```(#X```(````B/@```<```"1^```!0```)GX```'
M````G_@```X```"G^```"0```+;X```&````P/@```@```#'^```"P```-#X
M```'````W/@```<```#D^```'````.SX```'````"?D```@````1^0```P``
M`!KY```(````'OD``!0````G^0``!0```#SY```0````0OD``!````!3^0``
M!P```&3Y```%````;/D``!````!R^0``%````(/Y```+````F/D```T```"D
M^0``%P```++Y```$````ROD```D```#/^0``"@```-GY```'````Y/D```(`
M``#L^0``#@```._Y```?````_OD``",````>^@``,0```$+Z```G````=/H`
M`$0```"<^@``)0```.'Z```H````!_L``&0````P^P``%````)7[``!5````
MJOL``#@`````_```*0```#G\``!*````8_P``%L```"N_```*`````K]```X
M````,_T``"P```!L_0``*````)G]```L````POT``"<```#O_0``&P```!?^
M``"I`0``,_X``",```#=_P``,`````$``0`7````,@`!`(4```!*``$`,```
M`-```0`E`````0$!`%L````G`0$`20```(,!`0`=````S0$!`!@```#K`0$`
M*P````0"`0`A````,`(!`!\```!2`@$`*P```'("`0`A````G@(!`"<```#`
M`@$`'0```.@"`0`1````!@,!`#,````8`P$`)0```$P#`0`G````<@,!`"8`
M``":`P$`'P```,$#`0`P````X0,!`,P````2!`$`:0```-\$`0`]````204!
M`&4```"'!0$`30```.T%`0!>````.P8!`"8```":!@$`)P```,$&`0`L````
MZ08!`"@````6!P$`)@```#\'`0`O````9@<!`"X```"6!P$`*0```,4'`0`P
M````[P<!`%0````@"`$`6@```'4(`0`T````T`@!`$@````%"0$`2@```$X)
M`0`J````F0D!`"(```#$"0$`+P```.<)`0`I````%PH!`#(```!!"@$`+P``
M`'0*`0`L````I`H!`"T```#1"@$`%P```/\*`0`E````%PL!`#(````]"P$`
M*0```'`+`0`^````F@L!`"(```#9"P$`(@```/P+`0`+````'PP!`$4````K
M#`$`(0```'$,`0`V````DPP!`#````#*#`$`)0```/L,`0`<````(0T!`#$`
M```^#0$`!P```'`-`0`'````>`T!``0```"`#0$`#0```(4-`0`+````DPT!
M``X```"?#0$`!0```*X-`0`0````M`T!``(```#%#0$`60```,@-`0`%````
M(@X!``@````H#@$``P```#$.`0`0````-0X!``P```!&#@$`#0```%,.`0`"
M````80X!`!0```!D#@$`$@```'D.`0`,````C`X!``,```"9#@$`!````)T.
M`0`?````H@X!`#4```#"#@$`+@```/@.`0`O````)P\!`!<```!7#P$`(```
M`&\/`0`;````D`\!`!@```"L#P$`)````,4/`0`?````Z@\!`!H````*$`$`
M(````"40`0`:````1A`!`#(```!A$`$`&@```)00`0`O````KQ`!`"L```#?
M$`$`'P````L1`0`C````*Q$!`!\```!/$0$`&@```&\1`0`E````BA$!`"8`
M``"P$0$`)0```-<1`0`D````_1$!`!@````B$@$`'0```#L2`0`D````61(!
M`!@```!^$@$`(@```)<2`0`E````NA(!`#P```#@$@$`'P```!T3`0`C````
M/1,!`!\```!A$P$`(````($3`0`:````HA,!`!@```"]$P$`)@```-83`0`>
M````_1,!`"D````<%`$`'@```$84`0`)````910!``P```!O%`$`%P```'P4
M`0`O````E!0!`"0```#$%`$`!P```.D4`0`/````\10!``4````!%0$`!P``
M``<5`0`=````#Q4!`!H````M%0$`!P```$@5`0#'````4!4!``L````8%@$`
M'````"06`0`5````018!``8```!7%@$`"0```%X6`0`+````:!8!``T```!T
M%@$`%P```((6`0`&````FA8!`#,```"A%@$`$P```-46`0`3````Z18!``\`
M``#]%@$`!P````T7`0`R````%1<!`"$```!(%P$`$P```&H7`0`,````?A<!
M`!$```"+%P$`,@```)T7`0`6````T!<!``@```#G%P$`"0```/`7`0`*````
M^A<!`!0````%&`$`'0```!H8`0`(````.!@!`!\```!!&`$`"````&$8`0`:
M````:A@!`"<```"%&`$`!@```*T8`0`5````M!@!``@```#*&`$`$@```-,8
M`0`'````YA@!``\```#N&`$`#@```/X8`0`0````#1D!``D````>&0$`"0``
M`"@9`0`3````,AD!``<```!&&0$`#````$X9`0`9````6QD!``H```!U&0$`
M&P```(`9`0`*````G!D!``P```"G&0$`*@```+09`0`'````WQD!``(```#G
M&0$`$````.H9`0`8````^QD!``L````4&@$``P```"`:`0`(````)!H!``L`
M```M&@$`!@```#D:`0`'````0!H!``T```!(&@$`"P```%8:`0`4````8AH!
M`!4```!W&@$`+P```(T:`0`@````O1H!`!P```#>&@$`#````/L:`0`Q````
M"!L!``4````Z&P$`$@```$`;`0`_````4QL!`!(```"3&P$`"@```*8;`0`&
M````L1L!``0```"X&P$`!````+T;`0`*````PAL!`!,```#-&P$`!0```.$;
M`0`&````YQL!``8```#N&P$`!````/4;`0`,````^AL!``D````''`$`#```
M`!$<`0`*````'AP!`!`````I'`$`$P```#H<`0`3````3AP!``(```!B'`$`
M!````&4<`0`&````:AP!``,```!Q'`$`#````'4<`0!%````@AP!`#P```#(
M'`$`&@````4=`0`U````(!T!`"@```!6'0$`4P```'\=`0`P````TQT!`"\`
M```$'@$`&0```#0>`0!R````3AX!`"````#!'@$`-0```.(>`0`A````&!\!
M`$4````Z'P$`,````(`?`0`F````L1\!`!X```#8'P$`*````/<?`0`K````
M("`!`"D```!,(`$`*0```'8@`0`F````H"`!`"4```#'(`$`*````.T@`0`H
M````%B$!`"(````_(0$`+@```&(A`0`P````D2$!`!(```#"(0$`$P```-4A
M`0`0````Z2$!`'D```#Z(0$`"0```'0B`0!S````?B(!`'P```#R(@$`*P``
M`&\C`0`7````FR,!`!8```"S(P$`#P```,HC`0`7````VB,!`!\```#R(P$`
M0````!(D`0`?````4R0!`!P```!S)`$`40```)`D`0`:````XB0!`!0```#]
M)`$`$@```!(E`0`0````)24!`!,````V)0$`'0```$HE`0`/````:"4!``H`
M``!X)0$`#P```(,E`0`'````DR4!``0```";)0$`"0```*`E`0`)````JB4!
M``<```"T)0$`"P```+PE`0`'````R"4!``4```#0)0$`%````-8E`0`.````
MZR4!``8```#Z)0$`!P````$F`0`(````"28!``\````2)@$`#````"(F`0`(
M````+R8!``P````X)@$`#P```$4F`0`6````528!``<```!L)@$`!@```'0F
M`0`4````>R8!``8```"0)@$`#````)<F`0`(````I"8!``0```"M)@$`"@``
M`+(F`0`+````O28!``P```#))@$`#````-8F`0`,````XR8!``0```#P)@$`
M&0```/4F`0`'````#R<!``(````7)P$`"0```!HG`0`&````)"<!``8````K
M)P$`!````#(G`0`/````-R<!`!,```!')P$`!P```%LG`0`'````8R<!``8`
M``!K)P$`!@```'(G`0`0````>2<!``8```"*)P$`"0```)$G`0`1````FR<!
M`!L```"M)P$`(@```,DG`0`'````["<!``<```#T)P$`"P```/PG`0`%````
M""@!``(````.*`$`"P```!$H`0!W`0``'2@!`!,```"5*0$`&@```*DI`0`0
M````Q"D!``T```#5*0$`"P```.,I`0`-````[RD!``8```#]*0$`6@````0J
M`0`X````7RH!`#8```"8*@$`)````,\J`0`A````]"H!`"$````6*P$`.@``
M`#@K`0`+````<RL!`#H```!_*P$`'````+HK`0`-````URL!`!0```#E*P$`
M$P```/HK`0`K````#BP!`!\````Z+`$`$````%HL`0`6````:RP!`!(```""
M+`$`(````)4L`0`-````MBP!`#H```#$+`$`PP```/\L`0`;````PRT!``T`
M``#?+0$`$@```.TM`0`2`````"X!``T````3+@$`#````"$N`0`8````+BX!
M``8```!'+@$`"0```$XN`0`/````6"X!`!\```!H+@$`#@```(@N`0`8````
MERX!`!@```"P+@$`#P```,DN`0!(````V2X!`%(````B+P$`*0```'4O`0!=
M````GR\!`&\```#]+P$`E````&TP`0".`````C$!`)(```"1,0$`D0```"0R
M`0!;````MC(!`"`````2,P$`&0```#,S`0`9````33,!`!<```!G,P$`#0``
M`'\S`0`D````C3,!``\```"R,P$`'````,(S`0`3````WS,!``\```#S,P$`
M.`````,T`0`\````/#0!`"@```!Y-`$`%P```*(T`0`6````NC0!`!,```#1
M-`$`$````.4T`0`3````]C0!`"4````*-0$`*````#`U`0`;````634!`"4`
M``!U-0$`)0```)LU`0`T````P34!`"T```#V-0$`*P```"0V`0`<````4#8!
M`"````!M-@$`)P```(XV`0`:````MC8!`%0```#1-@$`&````"8W`0`Q````
M/S<!`#4```!Q-P$`'@```*<W`0`T````QC<!``@```#[-P$`(@````0X`0`?
M````)S@!`"(```!'.`$`.````&HX`0!.````HS@!`$P```#R.`$`#@```#\Y
M`0`.````3CD!`!L```!=.0$`$P```'DY`0`1````C3D!``D```"?.0$`!@``
M`*DY`0`X````L#D!`!8```#I.0$`%@`````Z`0`8````%SH!`!P````P.@$`
M20```$TZ`0`F````ESH!`!T```"^.@$`'````-PZ`0`A````^3H!`"<````;
M.P$`,0```$,[`0`@````=3L!`!8```"6.P$`-0```*T[`0`,````XSL!``@`
M``#P.P$`(````/D[`0`O````&CP!`!X```!*/`$`,@```&D\`0`*````G#P!
M`!D```"G/`$`"@```,$\`0`5````S#P!`"0```#B/`$`$0````<]`0!(````
M&3T!`&T```!B/0$`=````-`]`0`4````13X!``8```!:/@$`"@```&$^`0!<
M````;#X!`!D```#)/@$`1````.,^`0!$````*#\!`$H```!M/P$`3@```+@_
M`0`1````!T`!``H````90`$`.@```"1``0!=````7T`!`#8```"]0`$`-@``
M`/1``0`W````*T$!`#@```!C00$`.````)Q!`0!W````U4$!`#$```!-0@$`
M/````']"`0`X````O$(!`#X```#U0@$`*P```#1#`0`O````8$,!`$@```"0
M0P$`0@```-E#`0`E````'$0!`!$```!"1`$`&````%1$`0`C````;40!`"<`
M``"11`$`%````+E$`0`-````SD0!`!4```#<1`$`&````/)$`0`K````"T4!
M``\````W10$`10```$=%`0`7````C44!``\```"E10$`"````+5%`0`-````
MOD4!``8```#,10$`$@```--%`0`-````YD4!``D```#T10$`"@```/Y%`0`(
M````"48!`!H````21@$`$P```"U&`0`#````048!``,```!%1@$`%P```$E&
M`0`#````848!`!H```!E1@$`"@```(!&`0`(````BT8!`)8```"41@$`,0``
M`"M'`0!%````74<!`$\```"C1P$`-@```/-'`0`,````*D@!`"<````W2`$`
M.````%](`0`X````F$@!`%,```#12`$`,@```"5)`0!#````6$D!`,$```"<
M20$`40```%Y*`0`*````L$H!``@```"[2@$`(0```,1*`0`,````YDH!`!<`
M``#S2@$`$P````M+`0`7````'TL!`"`````W2P$`#````%A+`0`4````94L!
M``@```!Z2P$`'0```(-+`0`8````H4L!`!L```"Z2P$`"P```-9+`0`M````
MXDL!`)`````03`$`I````*%,`0`*````1DT!`!@```!130$`)````&I-`0`#
M````CTT!`!L```"330$`&@```*]-`0`?````RDT!`"4```#J30$`*@```!!.
M`0`K````.TX!`#````!G3@$`2@```)A.`0!A````XTX!`$8```!%3P$`3```
M`(Q/`0`F````V4\!``8`````4`$`(P````=0`0`?````*U`!`!H```!+4`$`
M)0```&90`0`G````C%`!`!T```"T4`$`$P```-)0`0`*````YE`!``@```#Q
M4`$`(0```/I0`0`;````'%$!``8````X40$`'@```#]1`0`3````7E$!``T`
M``!R40$`'@```(!1`0`9````GU$!`#X```"Y40$`"````/A1`0`P`````5(!
M`$0````R4@$`"@```'=2`0`5````@E(!``H```"84@$`$0```*-2`0`(````
MM5(!`!$```"^4@$`$P```-!2`0`&````Y%(!``H```#K4@$`(0```/92`0`3
M````&%,!`!@````L4P$`(````$53`0`@````9E,!`"0```"'4P$`%P```*Q3
M`0`Z````Q%,!`$T```#_4P$`-@```$U4`0`I````A%0!`"4```"N5`$`#```
M`-14`0`C````X50!`%\````%50$`"@```&55`0`(````<%4!``P```!Y50$`
M-@```(95`0`]````O54!`#D```#[50$`0````#56`0`\````=E8!`#@```"S
M5@$`-````.Q6`0`S````(5<!`#(```!55P$`-@```(A7`0`_````OU<!`#X`
M``#_5P$`00```#Y8`0`S````@%@!`$(```"T6`$`7@```/=8`0!'````5ED!
M`$<```">60$`5@```.99`0!7````/5H!`"<```"56@$`3````+U:`0`D````
M"EL!`"@!```O6P$`.0```%A<`0!1````DEP!`%$```#D7`$`40```#9=`0!5
M````B%T!`#H```#>70$`/````!E>`0!$````5EX!`$D```";7@$`5````.5>
M`0`B`0``.E\!`#H```!=8`$`/@```)A@`0!,````UV`!`(,````D80$`&```
M`*AA`0`(````P6$!``\```#*80$`&@```-IA`0`R````]6$!`!H````H8@$`
M(````$-B`0`1````9&(!`"0```!V8@$`(@```)MB`0`1````OF(!`!,```#0
M8@$`&0```.1B`0`5````_F(!``\````48P$`/````"1C`0`*````86,!`!<`
M``!L8P$`$0```(1C`0`7````EF,!`!L```"N8P$``@```,IC`0`,````S6,!
M`!X```#:8P$`"@```/EC`0`>````!&0!`!<````C9`$`!@```#MD`0`/````
M0F0!``P```!29`$`%0```%]D`0`<````=60!``T```"29`$`%````*!D`0`8
M````M60!`!H```#.9`$`)P```.ED`0`,````$64!``8````>90$`$0```"5E
M`0`/````-V4!``\```!'90$`)P```%=E`0`:````?V4!``\```":90$`#P``
M`*IE`0`K````NF4!`"4```#F90$`(@````QF`0!'````+V8!``T```!W9@$`
M)0```(5F`0`8````JV8!`!8```#$9@$`'````-MF`0`3````^&8!``H````,
M9P$`"@```!=G`0`/````(F<!``\````R9P$`10```$)G`0`*````B&<!`!$`
M``"39P$`,````*5G`0`3````UF<!`!X```#J9P$`'@````EH`0`(````*&@!
M``H````Q:`$`.@```#QH`0`>````=V@!`"@```"6:`$`&P```+]H`0`3````
MVV@!`!$```#O:`$`#P````%I`0!`````$6D!`$X```!2:0$`A````*%I`0`.
M````)FH!`!$````U:@$`4@```$=J`0`4````FFH!`!P```"O:@$`#````,QJ
M`0`=````V6H!``,```#W:@$`#````/MJ`0`5````"&L!`!4````>:P$`%0``
M`#1K`0`9````2FL!`"4```!D:P$`)````(IK`0`A````KVL!`"H```#1:P$`
M*````/QK`0`.````)6P!``L````T;`$``@```$!L`0`9````0VP!`"@```!=
M;`$`4@```(9L`0`O````V6P!``X````);0$`'0```!AM`0`<````-FT!`"<`
M``!3;0$`50```'MM`0!+````T6T!`!,````=;@$`(@```#%N`0"[````5&X!
M`#`````0;P$`=P```$%O`0`N````N6\!`"H```#H;P$`!@```!-P`0`>````
M&G`!`"`````Y<`$`,0```%IP`0`V````C'`!``H```##<`$`"@```,YP`0`<
M````V7`!`!0```#V<`$`%`````MQ`0`6````('$!`!(````W<0$`%````$IQ
M`0`/````7W$!`!8```!O<0$`"````(9Q`0`/````CW$!`"(```"?<0$`&0``
M`,)Q`0`7````W'$!``X```#T<0$`$0````-R`0`I````%7(!`#@````_<@$`
M0@```'AR`0`:````NW(!`!,```#6<@$`,@```.IR`0!#````'7,!`#@```!A
M<P$`*0```)IS`0`G````Q',!`&<```#L<P$`.````%1T`0`X````C70!`#8`
M``#&=`$`-P```/UT`0`_````-74!`$<```!U=0$`+0```+UU`0`O````ZW4!
M``@````;=@$`$0```"1V`0`.````-G8!``H```!%=@$`$P```%!V`0`/````
M9'8!`"@```!T=@$`*````)UV`0`5````QG8!`!,```#<=@$`&0```/!V`0`7
M````"G<!`#H````B=P$`%@```%UW`0`.````='<!`!````"#=P$`"@```)1W
M`0`/````GW<!``8```"O=P$`#0```+9W`0`1````Q'<!``P```#6=P$`#P``
M`.-W`0`@````\W<!``T````4>`$`!@```")X`0!7````*7@!`!````"!>`$`
M/0```))X`0`*````T'@!``@```#;>`$`#P```.1X`0`,````]'@!``\````!
M>0$`#@```!%Y`0`.````('D!``@````O>0$`$````#AY`0`7````27D!``0`
M``!A>0$`!0```&9Y`0`/````;'D!``\```!\>0$`#P```(QY`0`L````G'D!
M``L```#)>0$`'@```-5Y`0`6````]'D!`!8````+>@$`)````")Z`0`&````
M1WH!`!4```!.>@$`%P```&1Z`0`2````?'H!``@```"/>@$`%P```)AZ`0`L
M````L'H!`!0```#=>@$`&0```/)Z`0`;````#'L!``0````H>P$`20```"U[
M`0!)````=WL!`$D```#!>P$`+`````M\`0`5````.'P!``\```!.?`$`"@``
M`%Y\`0`5````:7P!``H```!_?`$`#````(I\`0`S````EWP!`!$```#+?`$`
M#P```-U\`0`X````[7P!``@````F?0$`"````"]]`0`(````.'T!`!$```!!
M?0$`&````%-]`0`:````;'T!`!,```"'?0$`'````)M]`0`?````N'T!`"<`
M``#8?0$`)P````!^`0`(````*'X!`%H````Q?@$`1P```(Q^`0!.````U'X!
M`#8````C?P$`6@```%I_`0`R````M7\!`%P```#H?P$`0@```$6``0!+````
MB(`!`"\```#4@`$`$P````2!`0`@````&($!``D````Y@0$`4````$.!`0`^
M````E($!`"X```#3@0$`/`````*"`0`*````/X(!``P```!*@@$`/````%>"
M`0`X````E((!`$T```#-@@$`!````!N#`0`+````((,!`"H````L@P$`2P``
M`%>#`0`H````HX,!`!4```#,@P$`&@```.*#`0`:````_8,!`!(````8A`$`
M>````"N$`0"8````I(0!`.`````]A0$`'0```!Z&`0`.````/(8!``\```!+
MA@$`&@```%N&`0`;````=H8!`!4```"2A@$`#````*B&`0`U````M88!`!T`
M``#KA@$`0@````F'`0`E````3(<!`"L```!RAP$`*````)Z'`0`U````QX<!
M`#4```#]AP$`W0```#.(`0`;````$8D!`!4````MB0$`#@```$.)`0`.````
M4HD!`#````!AB0$`&P```)*)`0`1````KHD!``\```#`B0$`%@```-")`0`H
M````YXD!`$0````0B@$`1````%6*`0!`````FHH!`$````#;B@$`00```!R+
M`0!!````7HL!`"````"@BP$`9@```,&+`0`6````*(P!`!8````_C`$`%@``
M`%:,`0`6````;8P!`!$```"$C`$`'@```):,`0`>````M8P!`!4```#4C`$`
M%````.J,`0!1````_XP!`!P```!1C0$`'````&Z-`0!*````BXT!`!D```#6
MC0$`#P```/"-`0`:`````(X!`!$````;C@$`$@```"V.`0`F````0(X!`"P`
M``!GC@$`&@```)2.`0`K````KXX!`"````#;C@$`*@```/R.`0`9````)X\!
M`"8```!!CP$`)0```&B/`0`@````CH\!`!4```"OCP$`&````,6/`0!`````
MWH\!`#H````?D`$`'@```%J0`0`;````>9`!`",```"5D`$`/0```+F0`0`D
M````]Y`!`"4````<D0$`#````$*1`0`?````3Y$!``@```!OD0$`%0```'B1
M`0`-````CI$!``P```"<D0$`%@```*F1`0`4````P)$!``H```#5D0$`"```
M`."1`0`8````Z9$!`!@````"D@$`&@```!N2`0`6````-I(!`!L```!-D@$`
M(P```&F2`0`]````C9(!`!,```#+D@$`&@```-^2`0`/````^I(!``\````*
MDP$`%0```!J3`0!+````,),!`!````!\DP$`#P```(V3`0"0````G9,!``X`
M```NE`$`"````#V4`0`1````1I0!`!4```!8E`$`%P```&Z4`0`C````AI0!
M``T```"JE`$`'@```+B4`0`7````UY0!`"````#OE`$`'0```!"5`0`(````
M+I4!``X````WE0$`!````$:5`0`/````2Y4!`!$```!;E0$`%@```&V5`0`5
M````A)4!`"8```":E0$`)@```,&5`0`C````Z)4!`"@````,E@$`#0```#66
M`0`;````0Y8!``H```!?E@$`&0```&J6`0"`````A)8!`!$````%EP$`%0``
M`!>7`0`*````+9<!`$(````XEP$`'@```'N7`0`D````FI<!`!4```"_EP$`
M%0```-67`0`7````ZY<!``T````#F`$`$P```!&8`0`3````)9@!`!<````Y
MF`$`'@```%&8`0`T````<)@!``P```"EF`$`$0```+*8`0`3````Q)@!`!@`
M``#8F`$`#````/&8`0`(````_I@!``@````'F0$`"````!"9`0`3````&9D!
M`'0````MF0$`'P```**9`0`/````PID!``8```#2F0$`"@```-F9`0`>````
MY)D!`!P````#F@$`(````"":`0`"````09H!`!$```!$F@$`0````%::`0`#
M````EYH!``@```";F@$`'0```*2:`0`5````PIH!`!@```#8F@$`@P```/&:
M`0`)````=9L!``P```!_FP$`"````(R;`0`*````E9L!`$X```"@FP$`7```
M`.^;`0`*````3)P!`!X```!7G`$`(@```':<`0`T````F9P!`#,```#.G`$`
M,0````*=`0`F````-)T!`!,```!;G0$`)````&^=`0`$````E)T!``H```"9
MG0$`"@```*2=`0`9````KYT!`!8```#)G0$`%P```."=`0`*````^)T!`(8`
M```#G@$`&@```(J>`0`1````I9X!`!8```"WG@$`*P```,Z>`0!Q````^IX!
M``8```!LGP$`$P```'.?`0`&````AY\!``L```".GP$`+P```)J?`0`M````
MRI\!`!<```#XGP$`"````!"@`0`,````&:`!`"T````FH`$`KP```%2@`0`B
M````!*$!`"$````GH0$`#````$FA`0`1````5J$!`!,```!HH0$`$P```'RA
M`0`@````D*$!``X```"QH0$`*0```,"A`0`0````ZJ$!``P```#[H0$`$P``
M``BB`0`I````'*(!`!$```!&H@$`$P```%BB`0`7````;*(!``P```"$H@$`
M'````)&B`0`:````KJ(!`!H```#)H@$`&@```.2B`0`<````_Z(!`!8````<
MHP$`&@```#.C`0`:````3J,!`"$```!IHP$`+````(NC`0")````N*,!`!4`
M``!"I`$`#0```%BD`0`<````9J0!``\```"#I`$`'@```).D`0`A````LJ0!
M``8```#4I`$`#P```-ND`0`?````ZZ0!`!4````+I0$`&@```"&E`0`6````
M/*4!`!0```!3I0$`%P```&BE`0`>````@*4!`!H```"?I0$`"````+JE`0`(
M````PZ4!`!$```#,I0$`$0```-ZE`0`+````\*4!`"T```#\I0$`%@```"JF
M`0`M````0:8!`#(```!OI@$`'@```**F`0`*````P:8!`!H```#,I@$`#0``
M`.>F`0`<````]:8!`!,````2IP$`!````":G`0`$````*Z<!`#`````PIP$`
M*0```&&G`0!I````BZ<!`$\```#UIP$`)0```$6H`0!&````:Z@!`%D```"R
MJ`$`$P````RI`0!:````(*D!`$(```![J0$`1P```+ZI`0!'````!JH!`$P`
M``!.J@$`(0```)NJ`0`I````O:H!`",```#GJ@$`+@````NK`0`F````.JL!
M`"4```!AJP$`)0```(>K`0`?````K:L!`"T```#-JP$`)````/NK`0!.````
M(*P!`$X```!OK`$`4@```+ZL`0!2````$:T!`%````!DK0$`30```+6M`0!"
M`````ZX!`!,```!&K@$`,P```%JN`0`/````CJX!`#D```">K@$`1````-BN
M`0`G````':\!`$4```!%KP$`$P```(NO`0!R````GZ\!`'D````2L`$`!@``
M`(RP`0`T````D[`!`!0```#(L`$`&````-VP`0`+````]K`!``L````"L0$`
M%@````ZQ`0`>````);$!`!,```!$L0$`&0```%BQ`0`2````<K$!`#P```"%
ML0$`#````,*Q`0`&````S[$!`!P```#6L0$`%P```/.Q`0`H````"[(!`!4`
M```TL@$`4@```$JR`0`*````G;(!``8```"HL@$`'````*^R`0`6````S+(!
M``P```#CL@$`"@```/"R`0`<````^[(!``\````8LP$`40```"BS`0`8````
M>K,!`"T```"3LP$`8P```,&S`0`@````);0!`$(```!&M`$`,@```(FT`0">
M````O+0!`"L```!;M0$`/0```(>U`0`3````Q;4!`!8```#9M0$`%@```/"U
M`0`8````![8!``P````@M@$`%P```"VV`0`2````1;8!`#$```!8M@$`(```
M`(JV`0`(````J[8!`!<```"TM@$`'````,RV`0`:````Z;8!`#@````$MP$`
M(@```#VW`0`F````8+<!`!<```"'MP$`-@```)^W`0`(````UK<!``X```#?
MMP$`)````.ZW`0`9````$[@!`!4````MN`$`%P```$.X`0`(````6[@!`"L`
M``!DN`$`#@```)"X`0`7````G[@!`!,```"WN`$`#@```,NX`0`X````VK@!
M`"(````3N0$`0@```#:Y`0`>````>;D!``\```"8N0$`$````*BY`0`S````
MN;D!``X```#MN0$`(P```/RY`0`(````(+H!`"(````IN@$`"````$RZ`0`(
M````5;H!`"8```!>N@$`2P```(6Z`0`(````T;H!`!P```#:N@$`&````/>Z
M`0`8````$+L!`!L````INP$`%P```$6[`0`9````7;L!``@```!WNP$`"@``
M`("[`0`<````B[L!``X```"HNP$`-0```+>[`0!=````[;L!`&L```!+O`$`
M.````+>\`0!!````\+P!`#4````RO0$`=````&B]`0`U````W;T!`#\````3
MO@$`0P```%.^`0!.````E[X!`(<```#FO@$`.P```&Z_`0`.````JK\!``@`
M``"YOP$`*P```,*_`0`I````[K\!`!L````8P`$`+````#3``0`Y````8<`!
M`#\```";P`$`"````-O``0`?````Y,`!``H````$P0$`$P````_!`0`]````
M(\$!``@```!AP0$`'````&K!`0`-````A\$!`"(```"5P0$`$0```+C!`0`(
M````RL$!`!,```#3P0$`$0```.?!`0`1````^<$!`!,````+P@$`)````!_"
M`0!-````1,(!``\```"2P@$`+@```*+"`0`5````T<(!``H```#GP@$`)```
M`/+"`0`7````%\,!``H````OPP$`&P```#K#`0`;````5L,!`!@```!RPP$`
M%````(O#`0`6````H,,!`!4```"WPP$`"````,W#`0`,````UL,!`"L```#C
MPP$`'`````_$`0!*````+,0!`#,```!WQ`$`=@```*O$`0`L````(L4!`"T`
M``!/Q0$`.@```'W%`0`C````N,4!`",```#<Q0$`#@````#&`0`B````#\8!
M``,````RQ@$`!@```#;&`0`/````/<8!`!\```!-Q@$`#P```&W&`0`8````
M?<8!`!T```"6Q@$`#0```+3&`0!1````PL8!``8````4QP$`(````!O'`0`1
M````/,<!`!4```!.QP$```$``&3'`0!7````9<@!`"H```"]R`$`(````.C(
M`0`0````"<D!`!X````:R0$`,P```#G)`0`E````;<D!``H```"3R0$`(P``
M`)[)`0`N````PLD!`!````#QR0$`)0````+*`0`K````*,H!``P```!4R@$`
M"````&'*`0`3````:LH!`!4```!^R@$`&````)3*`0`&````K<H!`!@```"T
MR@$`$@```,W*`0`6````X,H!`!4```#WR@$`%0````W+`0`+````(\L!``H`
M```ORP$`4@```#K+`0!+````C<L!`$D```#9RP$`"````"/,`0`K````+,P!
M`!P```!8S`$`.0```'7,`0`.````K\P!``X```"^S`$``P```,W,`0`F````
MT<P!`!````#XS`$`#@````G-`0`(````&,T!`"`````AS0$`!@```$+-`0`2
M````2<T!`!@```!<S0$`@0```'7-`0`?````]\T!``8````7S@$`"@```![.
M`0`0````*<X!`!8````ZS@$`(````%'.`0`D````<LX!``T```"7S@$`(```
M`*7.`0`<````QLX!`#<```#CS@$`(P```!O/`0`>````/\\!`#D```!>SP$`
M$P```)C/`0`T````K,\!`!8```#ASP$`'@```/C/`0!%````%]`!`$4```!=
MT`$`\````*/0`0!#````E-$!`"4```#8T0$`(0```/[1`0`H````(-(!`#8`
M``!)T@$`,@```(#2`0`L````L](!`$<```#@T@$`)0```"C3`0`?````3M,!
M`"4```!NTP$`A@```)33`0!C````&]0!`"L```!_U`$`(0```*O4`0`M````
MS=0!`!4```#[U`$`#@```!'5`0`*````(-4!``X````KU0$`%P```#K5`0`D
M````4M4!``H```!WU0$`D@```(+5`0"1````%=8!`%(```"GU@$`@````/K6
M`0`:````>]<!`%,```"6UP$`/@```.K7`0`5````*=@!``@````_V`$`%0``
M`$C8`0!D````7M@!``H```##V`$`#0```,[8`0`1````W-@!`!<```#NV`$`
M'`````;9`0!K````(]D!`%<```"/V0$`.P```.?9`0`B````(]H!`%0```!&
MV@$`0P```)O:`0`]````W]H!`"\````=VP$`-@```$W;`0`Q````A-L!`!4`
M``"VVP$`"````,S;`0`;````U=L!`!L```#QVP$`#0````W<`0`Y````&]P!
M``T```!5W`$`"@```&/<`0`;````;MP!``P```"*W`$`(````)?<`0`&````
MN-P!``@```"_W`$`"````,C<`0`;````T=P!`!L```#MW`$`#P````G=`0`=
M````&=T!`!H````WW0$`&````%+=`0`E````:]T!`!4```"1W0$`$P```*?=
M`0`;````N]T!`!@```#7W0$`+0```/#=`0`V````'MX!`!4```!5W@$`"@``
M`&O>`0`K````=MX!``X```"BW@$`(P```+'>`0!*````U=X!`!,````@WP$`
M$P```#3?`0`1````2-\!``H```!:WP$`$@```&7?`0`*````>-\!``\```"#
MWP$`&@```)/?`0`-````KM\!`!P```"\WP$`%0```-G?`0`3````[]\!``X`
M```#X`$`#````!+@`0`*````'^`!``H````JX`$`#@```#7@`0`0````1.`!
M`"X```!5X`$`/````(3@`0`F````P>`!`)````#HX`$`00```'GA`0!1````
MN^$!`"@````-X@$`"@```#;B`0`3````0>(!`!,```!5X@$`#````&GB`0`(
M````=N(!`!$```!_X@$`"@```)'B`0`(````G.(!``H```"EX@$`$````+#B
M`0`0````P>(!`!<```#2X@$`+````.KB`0`(````%^,!``@````@XP$``P``
M`"GC`0`0````+>,!`#L````^XP$`"````'KC`0`7````@^,!`!<```";XP$`
M!P```+/C`0`*````N^,!`!,```#&XP$`'````-KC`0`3````]^,!`!4````+
MY`$`&0```"'D`0`&````.^0!``T```!"Y`$`#P```%#D`0`1````8.0!``X`
M``!RY`$`#@```('D`0!)````D.0!`"<```#:Y`$`/0````+E`0`V````0.4!
M`&T```!WY0$`,````.7E`0!"````%N8!`)\```!9Y@$`&@```/GF`0!E````
M%.<!`%0```!ZYP$`-````,_G`0!O````!.@!`&$```!TZ`$`,````-;H`0!D
M````!^D!`#,```!LZ0$`.@```*#I`0`\````V^D!`$D````8Z@$`-````&+J
M`0`.`0``E^H!`"0```"FZP$`6P```,OK`0`4````)^P!`+P````\[`$`;0``
M`/GL`0`X````9^T!`'P```"@[0$`LP```!WN`0`@````T>X!`!@```#R[@$`
M,P````OO`0`F````/^\!`"8```!F[P$`10```(WO`0`L````T^\!`#``````
M\`$`)@```#'P`0`8````6/`!`$T```!Q\`$`0````+_P`0`Q`````/$!`$T`
M```R\0$`,@```(#Q`0!2````L_$!`'4!```&\@$`R@```'SS`0!2````1_0!
M`(L```":]`$`@@```";U`0"O````J?4!`$<```!9]@$`1P```*'V`0`Y````
MZ?8!`#H````C]P$`.P```%[W`0!(````FO<!`%$```#C]P$`0P```#7X`0!,
M````>?@!`(@```#&^`$`E````$_Y`0!*````Y/D!`'8````O^@$`>````*;Z
M`0!-````'_L!`$4```!M^P$`8P```+/[`0!1````%_P!`%0```!I_`$`1@``
M`+[\`0!(````!?T!`$H```!._0$`*````)G]`0!%````POT!`$P````(_@$`
M3@```%7^`0"(````I/X!`#@````M_P$`/@```&;_`0`9````I?\!`(\```"_
M_P$`+P```$\``@!7````?P`"`%$```#7``(`/P```"D!`@`J````:0$"`%D`
M``"4`0(`!@```.X!`@`,````]0$"``@````"`@(`%0````L"`@`1````(0("
M`!<````S`@(`"@```$L"`@`C````5@("``0```!Z`@(`CP```'\"`@`*````
M#P,"``@````:`P(`"````",#`@`@````+`,"`!$```!-`P(`'0```%\#`@`-
M````?0,"`!0```"+`P(`*P```*`#`@`0````S`,"``,```#=`P(`!````.$#
M`@`R````Y@,"`&H````9!`(`4````(0$`@!6````U00"`"L````L!0(`-```
M`%@%`@`H````C04"`$8```"V!0(`/````/T%`@`W````.@8"`#L```!R!@(`
M0````*X&`@`N````[P8"`#H````>!P(`+@```%D'`@`X````B`<"`%````#!
M!P(`,P```!((`@`X````1@@"`#P```!_"`(`-P```+P(`@!,````]`@"`#P`
M``!!"0(`1@```'X)`@`R````Q0D"`#L```#X"0(`/````#0*`@!)````<0H"
M`#<```"["@(`.@```/,*`@`R````+@L"`&P```!A"P(`/````,X+`@!!````
M"PP"`$4```!-#`(`1@```),,`@!`````V@P"`#(````;#0(`/0```$X-`@`W
M````C`T"`#(```#$#0(`.P```/<-`@`3````,PX"`"$```!'#@(`*P```&D.
M`@!&````E0X"`#0```#<#@(`#P```!$/`@`/````(0\"``P````Q#P(`&0``
M`#X/`@`X````6`\"`",```"1#P(`"P```+4/`@"3`0``P0\"`!H```!5$0(`
M*P```'`1`@`@````G!$"`!(```"]$0(`%0```-`1`@`=````YA$"`!P````$
M$@(`-````"$2`@`3````5A("`',```!J$@(`'````-X2`@`@````^Q("`!P`
M```<$P(`%P```#D3`@!D````41,"`$````"V$P(`&0```/<3`@`>````$10"
M`!@````P%`(`3````$D4`@`C````EA0"`!$```"Z%`(`$@```,P4`@`3````
MWQ0"`!P```#S%`(`(````!`5`@`.````,14"`$0```!`%0(`#````(45`@`H
M````DA4"`$$```"[%0(`#````/T5`@`G````"A8"``P````R%@(`$P```#\6
M`@`(````4Q8"`!,```!<%@(`$P```'`6`@`B````A!8"``L```"G%@(`$0``
M`+,6`@`3````Q18"``L```#9%@(`$P```.46`@`F````^18"`!H````@%P(`
M&````#L7`@`9````5!<"`!L```!N%P(`3P```(H7`@`,````VA<"`!````#G
M%P(`&````/@7`@`]````$1@"``L```!/&`(`!````%L8`@`-````8!@"`!$`
M``!N&`(`"@```(`8`@`1````BQ@"`!D```"=&`(`%@```+<8`@`4````SA@"
M`!4```#C&`(`6@```/D8`@`C````5!D"`"@```!X&0(`#P```*$9`@!L````
ML1D"``8````>&@(`'````"4:`@!=````0AH"`!,```"@&@(`$0```+0:`@`)
M````QAH"``0```#0&@(`!P```-4:`@`9````W1H"`"\```#W&@(`!P```"<;
M`@`(````+QL"``8````X&P(`!@```#\;`@`6````1AL"`!0```!=&P(`%@``
M`'(;`@`6````B1L"`!H```"@&P(`(P```+L;`@`C````WQL"``4````#'`(`
M!`````D<`@`,````#AP"``8````;'`(`%0```"(<`@!R````.!P"`$X```"K
M'`(`)P```/H<`@!B````(AT"`%,```"%'0(`C````-D=`@!!````9AX"`#\`
M``"H'@(`&````.@>`@"Q`````1\"`$D```"S'P(`>@```/T?`@!3````>"`"
M`$H```#,(`(`:````!<A`@!,````@"$"`#L```#-(0(`4@````DB`@!/````
M7"("`%$```"L(@(`4P```/XB`@!1````4B,"`%<```"D(P(`7@```/PC`@!1
M````6R0"`#\```"M)`(`0````.TD`@!6````+B4"`"0```"%)0(`(````*HE
M`@`5````RR4"`+T```#A)0(`#0```)\F`@#:````K28"`+D```"()P(`3```
M`$(H`@`W````CR@"`"````#'*`(`%P```.@H`@`H`````"D"`#4````I*0(`
M7````%\I`@`[````O"D"`#0```#X*0(`H0```"TJ`@`N````SRH"`"T```#^
M*@(`,0```"PK`@`6````7BL"`"D```!U*P(`,@```)\K`@`3````TBL"`!4`
M``#F*P(`#@```/PK`@`(````"RP"``,````4+`(`#````!@L`@`1````)2P"
M``8````W+`(`#0```#XL`@`4````3"P"``P```!A+`(`'````&XL`@`C````
MBRP"`!$```"O+`(`"````,$L`@`(````RBP"`!@```#3+`(`$0```.PL`@`1
M````_BP"``P````0+0(`%````!TM`@`=````,BT"``H```!0+0(`&@```%LM
M`@`:````=BT"``X```"1+0(`&````*`M`@`*````N2T"``@```#$+0(`(0``
M`,TM`@`+````[RT"``P```#[+0(`#`````@N`@`+````%2X"``P````A+@(`
M%P```"XN`@`&````1BX"``(```!-+@(`"@```%`N`@`(````6RX"``D```!D
M+@(`!@```&XN`@`<````=2X"`"P```"2+@(`!P```+\N`@`(````QRX"``X`
M``#0+@(`"````-\N`@`9````Z"X"``\````"+P(`%0```!(O`@`=````*"\"
M`"D```!&+P(`0P```'`O`@`1````M"\"``L```#&+P(`%P```-(O`@`%````
MZB\"``(```#P+P(`"P```/,O`@`!`````````$4%```>`@``_0(````````K
M`@``J@$``-0%``#L!0```````/X```#]!```!0$``%,"``#-`0``'P,``+0$
M``"W`0```0$```````#K`0``@`,```T`````````9@```)T$``"G`P``9@8`
M`)D%``"8````@P,``(P%```E!```@08``#P```#2!```R0(```````"N`0``
M:```````````````@`$``+L!``!D`P```````````````````````/L"``!!
M`@``+P$``#8"````````[`,``)X!```$`P``$@$``.H$``#`!```%`$`````
M````````!@```-8#````````+`(``!\"``!P`0``%@$``(\$``#'`0``R@4`
M`&P%``"9`````````&,!``#W`0``C`(```4`````````808``,(%``!N````
M3@8```````!G`0``)P```````````````````*L%```C!0``%P,``$D&```-
M!0``Y0(````````.!@````````@```#N`0``.P4``/\`````````.00``,H`
M```B`@``0`8``"T```!]!```;@(``%P$``!O!```$@4``&<```#F`0``````
M```````H`P``)`(``'\$``#/````(0,`````````````908``)P%````````
M20(``%\$````````6P0````````D`P``LP,```````!Y`@``JP$```````#H
M````*`$``,L$```<!0``]P4``.($``#K`P``H@(``!8&``!%`@``````````
M`````````````)L```!;`````````!X$``"P````I0```*<"``"F````````
M`!D!``#W````S0,``-0`````````.`,``*@!``!"`@``?@4``-$#``"O!```
M1@```.<#`````````````#0!```%!@``00,``'0"``"-!```J04``.@!```/
M`@``EP4``,D%``!+`@``J0,```H%``!K`@``.0$``#8!``#?`P``Y0$``"H%
M```A!@``U@$```D```!K`P```````#H"``#>````&@0``,<#``!3!0``SP(`
M``````!3!```````````````````FP4``+L$````````$`0``)X"```H````
M``````````"C`@``8P0``(,!``#=`0``.@``````````````C0````L```#[
M!0``-@````P&``!M!0``<00``$X$````````I`(````````=`@``%P0``)0%
M``#8`P``$`(```8&```-`P``9`$```T$````````M`4``%@%````````*00`
M`'<&```L!@````````````!\`0``;`0``)8!``#W`P``%0```%8```!E!```
M`P,``/T`````````1`0```````!.`0```````"T&```$!```>@```%T$```'
M````+0(````````9`@``+0,``'P`````````@0(``#H%``!9`0``6@0`````
M````````VP$``+$!```2`P``(0$``#<%``"T````XP,``(H#```$`0``TP4`
M`',&``">````````````````````\P```'H!````````D0````````!T`0``
M<@8``,,$``#4!```-P8```````![````,P,``.(#```1`0``X`(``,("``!6
M!```%P4``/8%``!H!```<`,```````#C`@```08``!0$```.`0``+@8`````
M``"Q!```H@0```````!%!@``=`0``"H`````````A@0``!$#````````````
M`-4"```H!0```````!,$``!1!0``00$``+D#``#R!0```````"\#````````
MIP$```````"I`@```````-("````````MP4````````D````(P,``!0&````
M````<P,`````````````]@$``````````````````(8%```O!0``5`0`````
M````````+04```````#&`0```````-<!````````?`0``,\%``"<`@``!@0`
M``````#1````&`0````````M!```IP```"P!````````K`4``",```#8`@``
M[P``````````````1`(``-D$```1!@```````"8%``#>!````P0``)4%````
M````,@0``/`%``!+!@``TP`````"```D!0``X`4``*,%``#B!0``K@,`````
M``!H`P``P`(``)P!``"'`0``````````````````2@4``*`#````````?@0`
M``````#1!```S`4``$(#``!B!```^04``!8%``#H!````````*8!``!,!0``
ME`(``$8&````````"`(``,8"``!4`P``*P0``)D$```E`P``&0````4"``#G
M`0``:P$```````"P!```*0$``)H```"B`P``"@(``!0#```9!0``U04``*<%
M``!J!```9@4``.T#``#\````8@4``#<"``#=`@``&````&@!````````!@,`
M``````!]!@``3@,``"P%```=````"`$```````!"````;P8``+L#``!D`@``
M`````%`$````````30,```(```")`0``S@4``'\!```0````6@,``(X!``"R
M`P`````````````#`@``V@`````````R!@`````````````U!@``HP```$@`
M```)`0```````"$%```Z!```&P4`````````````PP,``/8"``#Z`@``DP``
M`#8$````````P0$``(T%``!]````[`$``(\!``#I`0``<@4``&X$``#]`0``
M`````.@"````````=@4``#P$``!:`0```````+\!```F`P``L@4`````````
M``````````T!``#9`0``B@(``($%``!?!0```````(`"``!"!@``=P0``)`"
M``````````````````"6`P``K`0``"X"```F`0``````````````````````
M`!`#````````]0,``$D````B````8P4```L"``#A````L`4```````!A`P``
M`````)\```#)`P```````&D&```V!@``9@(``%(```"I`0``A`(``!8#````
M````N@````````"Z!````````/D!``#!!0``I`$``'@%``!R!```U`(``)T`
M``"<`P```````!4"``#(`0``>`0``%@`````````:P4``!H!``!5`0``^@0`
M````````````&`$``+4#````````7@8``-,$````````T`,``&\!````````
MC0(``````````````````.L```!F!```J@````````!=````N@$```````!U
M`0``?@$``*8%```,!```!P(```````#8!```S@```$4```"'````*P$`````
M```*`P``,0(``*\!````````C@0``,L"``"X`0````````````#1`@``V@4`
M``````"A`0```````&`&````````;P(``#@!``"K````UP,```````!(`@``
MX`0``$<"``"`!@``M`(```````#R`P``B0,``)@"```%!`````````````#%
M````T@```,P$``#T`P``100```````"J!0``N0```#$$``"J!```@@(``(,"
M``!$````*08``-0!``!Y!`````````````"[````8`0``#@%````````<P(`
M``4%````````MP````````!I````%@(``-`!````````XP0``-$%````````
MBP$``%P`````````5P$``"(#``"P`@``&@,``(`$``!+!0``X0,``"<&``!K
M!@``U`,``.$!``!3````FP,``!<!````````M@$`````````````20,``*0%
M``!!!0``?`,``(H```#Q!````````/L!````````L0````````"U!```````
M`!X&``#%`P``N0$``"$"```G`P``WP`````````N`0``VP0``#$#``#$`0``
M[`0``&\#````````O````$P"``#$!0``YP4``-L"```X`@```````)<$````
M````B@4``"4!``"9`0```````%T!``!1`@``-0```+4"````````3`8`````
M``![!```>`8``"\$``#"`P````````````!9!@``/`(``/<$````````````
M`&D!``">`P```````'4```"^````WP0``"\"````````204``+T$``"\`0``
MJ@(``*$`````````604``*P!`````````````(D```#@`P``!P8``&L```#_
M!0``CP,``!L$```$````)`0``+<#``!1!@``<`4``#$&```]````@0,`````
M``!`!```(@4``)`$`````````````.8%``!1`````````!,&``"E!0``A@$`
M`'````"M`P````````````````````````````"L`@``]@,```$$``!4!@``
M0`(``!,"`````````````.,!```````````````````?`0``,04``%(&``#T
M!```>`(``$`%``!.````8P8``+,$``#U`0``8`(``+T!``#2`P``>0$``!@&
M``"C!```M@4``*<$```'`0``:@````````!<`P``>`,``*$"``#T!0``````
M`/$"```@!@``4P,```T"``!=`P```````!$%```@`P```````&P```#<`0``
MS04```P#``!5`@``H0,`````````````/`,``/D#````````9@,``$L!``"O
M!0``-0(``*P````^`@``YP0``)T%``!B````E0(``'8&````````````````
M``!A````/0,``,L```#<`````````.\$``"2`````````(@#``"T`P``#@,`
M``````#D````N`4``&X&````````3P8```````#$`@``30(``-L```!-`0``
M/P4`````````````-`(``$H$`````````````+T"````````@P```$T`````
M`````````!<&```.````O@$``&H&``#L`````````!<"``#\!```/P```-8$
M````````Q@```,0$``"1!0``O@(``#\"``"P`0```````)T#````````````
M`-\%``"H````@@$``!T#``#'!0```````'D%``")!0``^`$``!L!```9!@``
MY`$``'T%``````````````4#``"4`0``D@4`````````````80$``$8$```/
M`P``%08```````"_`@``A`0``(T#``"1`@```P$````````;``````````\!
M``#U````_`4``+D%``!0````$@(`````````````?`(``/T#``#%`0``V`4`
M``````!7!0``,P4``%0!``".`P```````#X````^`0``[@(``%P&``!E`@``
M]00``%T%``!7````%0$``#0```"\!```F`4``.@%``"K!```:P0``&(!``"H
M!```LP(``&P!``#I`````````&$$``#!`@``$`4```@%``!>`0``\0,`````
M``!^!@``>@4``/P#```Y````"`8``'(````Q```````````````'!```1@$`
M`$,!``#U`@``@0````````!W`0``;00```````!U!```*`0````````<!@``
M`````-<``````````````&<%```=!@``GP4``#T&`````````````'$"``#X
M`P```````!\%``#Y`````````*T%````````3``````````K!0```````)D"
M``!(`P``U0````````!S````GP(``'\"``"_!0``[P4````````X!@``FP$`
M``````![`P``1@,``$$```"+!0``4P$``#@``````````````$H&``!W`@``
MV@(````````!`P``Z0,``$$&```L`P``D00``#\#``":!`````0```````"E
M`@``300``$\#```U!````````&4%``!B`@``S@(``#P%``";!```.@$``&8!
M``""!```3`$``"L#```2!@```````.``````````S0```%@#``!W````YP``
M`,8#````````7P$``)T"``"@!```J`(``$,#````````[0(``(P```"9`P``
M````````````````DP$``%\#````````9P(``&H%``!>!```/@,``+H#````
M````Y0,``$\`````````W`,``'X#``!S!0``2`8``"L&````````J0```/,"
M``"(`@```04``!$```!D````E`````````">!```AP(```````"#!```7@,`
M`)("``#```````````````#B`@``4`$``'`"```)!@``+@0``'(#````````
MB`0``+X%````````K0$``.$$``"5!```5@$````````9!```(P(````````X
M!````````$<%``"[`@``>0,```\```!Z`P``,P$``"P```!T````````````
M``#2`0``#`(``/@```"&````7@```.T$``!Z!@``KP,``,H!```0`0``(@$`
M``````"$`0``U00``&4```"E`P``L@````````!8`@``G````*,#``#R````
MW0````````"I!```5@,``+P%``!1`0```````.X%``"%`P``>P$``'$&``#!
M````4`(``!X```!O````0P4```````"0`P``,0$```````!Q````Q00`````
M``#P`P``.0,``*L#```V!0``,`$`````````````.P,``'8#``"@!0``R`,`
M`/X#``"@`0```````(P$````````I````+,!``"0!0````````````!B!@``
M/@0``,,```#C!0``]04```(%```5!0``K0```,P```#0`@``_@(``#(!``"+
M`@``;@$``&4!```"!@``DP0````````8!0``C`,````````9`P``R`````X%
M```U`0``8P```&`%```O````R@,```````#N``````````````#]!0``0```
M``````!_`P``Z@```$H!``#A`@``I@,```<%````````:@$``#`#``!4`@``
M`````#P&````````MP(```````"?!```V04``*(!``"[!0``"0(``%@$``#_
M!```P`$``!T!``!J`P```````"H!``"%`@``P`,``-,#``!:!@``I00`````
M``!\!@````````X"````````)0````````"'`P``^`0``-T#````````10$`
M`((%````````9P0````````3``````````,%``!"`0``;08``#L`````!0``
MV`$``%@&```S!@``(@8``'@!``!V!```_P(``"$```!T!@``E0,``(0```"Y
M`@````$``($!``#^!```SP0```````#;!0```@,``/`!``#?`@``0P(``(P!
M``!)`0``8P(``"X%```#````I`,``!$"```P````90,``&`!``!:!0``[P(`
M`$4#``#5`0``4P8``-$!``#2!0``'P8``(4%```:!0````8`````````````
M3`,``'4#``#[!```D0,``!8$```(!```.04``%L&`````````````)<````=
M!0````````P%````````<04``-8```#(`@``@@````````!,!```%`4``-,!
M````````EP(``(H$``!W!0```````/0!``#Q`0``=@(``)<!``!=`@``W@4`
M`````````````````%(%``#/`0``W04``"H#``"`!0``7P```-,"```3!0``
M6@(`````````````X04``,0#``#P!```H00``%@!``#E!````````!P#```E
M!0```````#`"```T`P``%`````````#@`0``%`(``#,"``":`P``!@(`````
M``"8`P``K0(``(4!``#(!```2P```*$%````````"P0```````"<!```\0``
M`',!````````<0$``'H$`````````@(``+T%````````&@(``+8"```*`0``
M-`4`````````````^`(``&@&``#"!```F`0````````R`@``$`8``%L%``!1
M`P``=@``````````````Z@,```````#S`0``?0,```````!^`````````,(`
M``"+````O`,``-`%````````:`(``$\!````````"P$`````````````````
M`,P!``#Y!````````.8"``!L`@``?0$``+4%```D`0``6P,```````"Q`P``
M2@(``(@```">!0```````-X"```P!@``R@(````````"!```-`0``-\!```@
M`0``@00``,P#```]!0``!`(``!$$`````````````+,````J!@``DP(``&(#
M``#B`0``Z04`````````````9P,```````#[`P``'00``+@#```'`P``````
M`.4```#B````SP,``"8`````````QP0``#X&````````)@(``),#````````
MT`0````````M`0``:0(``-T$``"'!```1`,``+H%````````F@(``/X%``#Z
M````>P8``````````````0(``#H&``#[````(P0```````#.!```:00`````
M`````````````%X%``````````````````!9`````````$@$````````"04`
M`"L``````````````'0%``#Q!0```````-4#````````>0`````````I`@``
M`````!X%````````GP$```````!'!```E0$``$8%```E!@``504``.4%``!/
M!0``A0```(D"````````1P,``,<```!L`P```````"@&````````#```````
M````````N@(``-H$``"+`P``;0$```P!``".!0```````)T!``!M````W@$`
M````````````U@4``%<"``#F````.P(``+$%``!G!@```````*4!``"*`0``
MUP(```````!2!```L@0```````#N!```<P0``&H"```R!0``\@0``)0$``#O
M`0``#P8````````/!0```````!P!``!Z`@````````````#-!````````.H%
M``#+`0```````/<"``#_`P``2`4````````P!````````.8$``"J`P``%00`
M`(@%``!\!0``O0``````````````+`0````````-!@```````*X"````````
M&P8````````A!```[P,``$8"``"Q`@```@$```H```"N!```2P,`````````
M````LP4``&,#````````*@0``-P"``"R`@``VP,``%4$````````````````
M``````````,```````#K!0```````,P"````````;@4``#`%``#K!```Q@0`
M`#<```#M````&`(```0%```````````````````I!0``\@(```````"3!0``
M`````(D$```U!0``M0```-P%``!0!@``@````/(!``!R`@`````````````2
M!````````,4"``#>`P``5P,```````!)!`````````````#+!0``Q04``!\`
M``#-`@``MP0```````!D!0``CP```+P"``#J`0``,P```+8$````````D`$`
M``D$``!N`P````````````"5````V0,```````"0````C0$``*8$``!6!0``
M``````````````````````````!+!```"@0``*@%``#D!0``Y@,```````#Z
M`0`````````````F!````````%4&````````]@0``-D"```@!0``.P0``!<`
M``"D!```>08``"X```#D`@``*`(``"<%``"6!```-0,``$H```#)!```400`
M`$0!``#X!0``6P$```````##!0``V0```'L"``#\`@``:04``,L#```Y!@``
M````````````````^0(``"`$``#Z!0``)P$``+4!``"#!0``````````````
M````>P4``,H$```/!```R0``````````````=08``.D$``!#````V@,`````
M```5`P```````!L"````````"0,``%4```!U`@```````%`#````````[@,`
M``````"V`P``FP(``(@!````````;`8``'(!``!4````&P,````````C!@``
MOP````````#!`P``.@,``.,````B!```8`,```L&``"_`P``"P4``'X"``"X
M`@``/0$``#P!``"X!```0P0```````#H`P``D@,```````"'!0``YP(``!@#
M``#S!0``A@,``$X%`````````````!,#``"@`````````"<"``!9`P``;0,`
M`$T&```]!```'`(``#<$``#'`@````````````!M`@``5P0``"H"``!$!0``
MOP0```````!@````$@````````!'!@```````.D"``#S!`````````0&``!6
M`@````````````!I`P``'@$``%("``":`0``````````````````E@4``!\$
M``!O!0``[04``%(!```````````````````<`````````#L&```T!@``1P``
M``8!``#L`@``>````!H```!2`P``K`,```````"^!```:`4```````"^`P``
M/P8``$($```6````0`,``+(!``"V````````````````````+@,```````#^
M`0``E`,``/\!``"6`````````'\%``#)`0``UP4````````C`0``A00``-``
M````````C@(``#\!```Y`@``)@8```````"C`0```````(L$``!!!```304`
M`*T$``"O````-@,``````````````````"\&````````0@4```,&``!'`0``
M6P(``)@!```<!```N00``*@#```[`0```````.L"``!?!@``V@$```L#```I
M`````````#(#```.!```<`0``#<!``!]`@``A`4``(X``````````````"`"
M``!>`@``GP,``,@%`````````````%T&``#J`@``<0,``*`"``!V`0``5@8`
M``````"/`@``PP(``-8"``#D`P```````/````!_````W`0``*L"``#S`P``
M`````/0"```*!@``V````,8%````````[0$``)8"````````1`8``*X```!?
M`@``D@$``-<$````````"`,``%<&``!(`0`````````````R````5`4`````
M```>`P``60(``*8"``"&`@``_`$`````````````M`$``/`"``"O`@``=P,`
M```````I`P``/0(``(0#``!T`P``2@,``,`%``!0!0``(``````````E`@``
M80(``,X#``"]`P````````````!#!@``]````/8`````````3P(```````!<
M!0``50,```````""`P``H@```&0&``!_!@```````/H#``!P!@``PP$`````
M``!/!```CP4```````#"`0``!@4```````#D!```L`,``%P!``!<`@``K@4`
M`%D$```:!@```````)$!```W`P``)P0``$`!``#$````/@4``)($``"X````
M$P$`````````````=04```````!:````804``&0$``"7`P``,P0`````````
M`````````,X!````````F@4``#\$``"B!0``)`8``$X"``#!!````"`H)7,@
M9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D
M87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@86QR96%D
M>2!E>&ES=',@86YD('=A<R!N;W0@:6UP;W)T960N`"(E<R(@=V%S(&%D9&5D
M('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@
M<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N
M`")&:7)S=&YA;64@3&%S=&YA;64B("`H:64N($IO:&X@1&]E*0`B3&%S=&YA
M;64L($9I<G-T;F%M92(@*&EE+B!$;V4L($IO:&XI`"4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T
M`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG
M;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@861D960N`"5S(&%L<F5A
M9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!F:6QE('-U8V-E<W-F=6QL>2!I
M;7!O<G1E9``E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R
M(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES
M('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD
M+@`E<R!T;R`E<R!O9B`E<P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E
M<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E
M<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@8G)O=W-E<B!T
M:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960`02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R
M<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!,:6=H="!286EN`$%-
M(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`06)O=70@
M=&AI<R!E9&ET;W(`06)O=70N+BX`06)O=F4@<V5A<F-H(&9O<FT`06)S8F]T
M=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S
M<R!D96YI960@=&\@)7,`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A
M<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI
M;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.
M97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD('!E<FUI
M<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&%D9')E<W,@8F]O
M:P!!9&0@8V]L=6UN`$%D9"!F:6QE`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O
M`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`
M061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:R!,:7-T:6YG`$%D9')E<W,@0F]O:W,`061D<F5S<R!B;V]K
M(&5N=')Y`$%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+@!!9&1R
M97-S(&)O;VMS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.@!!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES
M=')A=&EO;@!!9',`061V86YC960@4V5A<F-H`$%L:6%S`$%L:6=N`$%L:6=N
M;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`
M06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E
M/P!!;')E861Y($5X:7-T<P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U3
M4"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@
M=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!
M<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`
M07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E
M;&5T92`E<S\`07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E
M('1H92!S96QE8W1E9"!E;G1R:65S/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<FUE;FEA
M;B`H05)-4T-)22TX*0!!<G0`07-C96YD:6YG`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I
M9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M`$%T=')I8G5T97,`075G=7-T`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E
M<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q
M=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E
M<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`
M075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB
M875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE
M(&9I96QD<SH`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B
M97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86QT:6,@
M*$E33RTX.#4Y+3$S*0!"87-E;&EN90!"87-I8R!396%R8V@`0F5L;W<@<V5A
M<F-H(&9O<FT`0FEN9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`0FQO8VL@
M(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T
M=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;VMM87)K<P!";W)D97(`0F]R9&5R
M('1H:6-K;F5S<SH`0F]R9&5R<P!";W1H`$)O='1O;0!"<F]W<V4`0G5L;&5T
M960@3&ES=`!"=7-I;F5S<R!#871E9V]R>0!#35,`0U)#`$-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S`$-35@!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R
M`$-A;&T`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F
M:6QE("(E<R(`0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+@!#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S
M(BX`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E
M(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BX`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD
M($QA8F5L<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I
M;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#
M96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@
M<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O
M;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA
M<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!?06QL+TYO;F4`0VAI;&4`0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I
M9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!A;B!A9&1R97-S(&)O;VL`0VAO;W-E(&%N(&%D9')E<W,@8F]O:SH`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('=H:6-H(&%D9')E<W,@
M8F]O:W,@=&\@9&ES<&QA>2P@86YD(&EN('=H870@;W)D97(Z`$-H;V]S92!W
M:&EC:"!A9&1R97-S(&)O;VMS('1O('5S92X`0VAO;W-E('=H:6-H(&-O;'5M
M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CH`0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A
M9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D
M871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO
M<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]L;&%P<V4@4VED96)A<@!#;VQL
M87!S960@8F]R9&5R<P!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C
M=&EO;@!#;VQS.@!#;VQU;6X@3W!T:6]N<P!#;VQU;6X@=&ET;&5S`$-O;'5M
M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z`$-O;6EC<P!#;VUM82!S
M97!A<F%T960@=F%L=65S`$-O;6UA('-E<&%R871E9"!V86QU97,@*$UI8W)O
M<V]F="!/=71L;V]K*0!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#
M;VUM;VX@3F%M90!#;VUP86YY`$-O;7!A;GD@061D<F5S<P!#;VUP=71E<G,`
M0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(&9A:6QE9#H@
M)7,`0V]N;F5C=&EO;B!F86EL=7)E`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C="!A9&1E9"!T;R!L:7-T
M+@!#;VYT86-T(')E;6]V960@9G)O;2!L:7-T+@!#;VYT86-T<P!#;VYT86-T
M<R!I;B!L:7-T.B`E<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&EN=64`0V]O:VEE`$-O<'D`
M0V]P>2!S96QE8W1I;VX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R
M`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL
M(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R
M:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO
M="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R
M96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@
M<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T
M(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@
M)7,`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E(&$@
M;&EN:P!#<F5A=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.@!#<F5A=&4@82!N
M97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R
M;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-U<G)E;G0@5&EM90!#=7)R
M96YT(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ
M(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L
M;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WER:6QL:6,@*$M/23@M
M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E
M(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$
M96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U
M;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE
M;&P`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L
M971E`$1E;&5T92!#;VYF:7)M871I;VX`1&5L971E($=R;W5P`$1E;&5T92!0
M97)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&)U
M='1O;B!B96AA=FEO=7(`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE
M=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!F86EL960Z
M("@E<RD@)7,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`
M1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H
M92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T
M:6]N(&9A:6QE9`!$96QI=F5R>2!T:6UE`$1E<&%R=&UE;G0`1&5S8V5N9&EN
M9P!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T
M('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$
M:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS
M`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`
M1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I
M97,_`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@
M)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="X`1&]W;FQO860@=D-A<F0`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-
M86EL`$524@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI
M<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET(&5N=')Y(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E
M<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D
M=6-A=&EO;@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T
M:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M
M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F
M<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E
M<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D
M(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E
M(%523"!H97)E`$5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H
M92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,`16YT<GD@9F]R("5S('5P9&%T
M960N`$5N=')Y('-U8V-E<W-F=6QL>2!D96QE=&5D+@!%<G)O<@!%<G)O<B!C
M<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M
M97-S86=E+@!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@
M,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V
M97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L
M92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C
M=&5D("<I)P!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R
M="!!9&1R97-S($)O;VL`17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A
M8W1S+@!%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE
M=&5L>2X`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&%C8V5S<R!T:&4@861D
M<F5S<R!B;V]K.B`E<P!&86EL960@=&\@861D("5S('1O("5S.B`E<P!&86EL
M960@=&\@8G)O=W-E(&QI<W0`1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T
M;W)Y`$9A:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@
M)7,L($YE=R!$3B`]("5S+"!2;V]T(#T@)7,`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@
M=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N
M+@!&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S`$9A:6QE
M9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C
M=&]R>3H@)7,`1F%I<@!&871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E=R!3
M:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEL92!#;W5N=#H@)7,@9FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I
M;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QE<P!&:6QT97)S`$9I;F0`1FEN:7-H`$9I<G-T($AA;&8`
M1FER<W0@3F%M90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&]A=`!&;V<`
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H
M5$%&*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R965B=7-Y(%523`!&<F]M`$9R;VT@=&AE(`!&=6QL($1E
M<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VT`1V%L;&5R>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;@!'96YE<F%T960@0V]D90!':79E;B!.86UE`$=L;V)A;"!!9&1R97-S($)O
M;VL`1V\`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96L@*$E33RTX.#4Y
M+3<I`$=R;W5P`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!'=65S
M=&)O;VL`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(87-H
M+4%L9V]R:71H;0!(87IE`$AE861E<@!(96)R97<@*$E33RTX.#4Y+3@M22D`
M2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE
M<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO
M7VUE`$AO;64`2&]M92!!9&1R97-S`$AO;64@0VET>0!(;VUE($-O=6YT<GD`
M2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VUE(%!O<W1A;"!#;V1E`$AO
M;64@4W1A=&4O4')O=FEN8V4`2&]M92!3=')E970@061D<F5S<P!(;W)D90!(
M;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I
M;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O
M;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y
M<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S
M<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y
M<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H
M87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I
M>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO
M=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I
M96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$E-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F
M86EL960Z("5S`$E-4U``25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO
M8VLN`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E
M<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN
M=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T
M:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@
M=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N
M`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R
M;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!)
M;6%G97,`26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9`!);7!O<G0L(%-T
M97`@)60`26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS`$EM<&]R=&5D(&9I
M96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R
M;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!)
M;F1E;G0`26YD:79I9'5A;"!5<V5R<P!);F9O`$EN9F]R;6%T:6]N`$EN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK
M`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS
M97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@
M;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R
M87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E
M`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI
M;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E
M9V5R(&QI<W0`26YV86QI9"!)1`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+@!);G9A;&ED(&%D9')E<W,@8F]O:P!);G9A;&ED(&%P<&QI8V%T
M:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D
M+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@96UA:6P`
M26YV86QI9"!E;G1R>0!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@:V5Y
M('-P96-I9FEE9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!N86UE`$EN
M=F%L:60@;V)J96-T260`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV
M86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT
M.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D
M9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T
M('-E;&5C=&EO;@!)<V]L871E9"!4+5-T;W)M<P!)<W-U97(`271A;&EC`$IA
M;G5A<GD`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2G5L>0!*=6YE
M`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@
M3&5F=`!*=7-T:69Y(%)I9VAT`$ME97`@;W)I9VEN86P_`$ME<F)E<F]S('-E
M<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME
M>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+
M97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI
M9',`2V]R96%N("A%54,M2U(I`$Q$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B
M=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO
M861E9"X`3&%?>6]U=`!,86YG=6%G90!,87-T($AA;&8`3&%S="!-;V1I9FEE
M9`!,87-T($YA;64`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R
M`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87<`3&%Y;W5T`$QE9G0`3&5F
M="!H96%D97(`3&5F="!V86QU97,`3&EG:'0@1')I>GIL90!,:6=H="!286EN
M`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@
M4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG
M:'0@4VYO=R!3:&]W97(`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES=`!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E
M`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A
M=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,
M;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E
M<G,`3&]W97(@<F]M86X@;G5M8F5R<P!-30!-3U1$`$U3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA9VEC`$UA:6P`36%I;"!!
M9&UI;@!-86ME(&QI;E]K+BXN`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-
M87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT
M+T%N<W=E<F5D*0!-871C:&EN9P!-871C:&EN9R!F:65L9',`36%X(&%L;&]W
M960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA
M>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S`$UA>&EM=6T@;&5N9W1H`$UA>&EM
M=6T@;G5M8F5R(&]F('!A9V5S`$UA>0!-961I8VEN90!-96UB97)S`$UE;G4@
M3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`
M365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D
M`$UE=')I8P!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI(%-E87)C:`!-:7)R
M;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O
M;F9I9W5R871I;VXN`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@
M=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P
M<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]B:6QE(%!H;VYE`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1I9GD@9F%I;&5D.B`H)7,I("5S
M`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]O;B!0:&%S97,`36]R92!T:&%N
M(#$@96YT<GD@9F]U;F0`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S
M=&QY(%-U;FYY`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@;&5F=`!-;W9E(')I9VAT`$UO=F4@
M=7``375L8F5R<GD@061D<F5S<R!";V]K`$UU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<P!-=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B
M=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T`$UU;'1I<&QE
M('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`
M37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`3D\L($D@1&\@3D]4($%G<F5E
M`$YA;64`3F%M92!&;W)M870`3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GD`
M3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.
M971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E
M<@!.97<@0V%T96=O<GD`3F5W($-O;G1A8W0`3F5W($UO;VX`3F5W(%5S97)N
M86UE("AO<'1I;VYA;"D`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W
M('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P
M=&EO;G,`3FEC:VYA;64`3FEG:'0`3F\`3F\@)7,@96YT<GD@9F]U;F0@9F]R
M("5S`$YO(&%D9')E<W,@8F]O:W,@9F]U;F0N`$YO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A
M=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+@!.;R!C;VYT86-T<R!F;W5N9`!.;R!C<F5D:70@;&5F="X`
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@
M:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;65S<V%G92!S
M=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I
M960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P96YD
M:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N
M`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO
M('9#87)D(&1A=&$@=V%S(&9O=6YD+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D
M:6,@*$E33RTX.#4Y+3$P*0!.;W)T:&5R;B!(96UI<W!H97)E`$YO="!!9G1E
M<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N
M`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C
M=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@:71E;7,@<&5R('!A
M9V4`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C
M="!#<F5A=&]R`$]B:F5C="!N;W0@9F]U;F0`3V-T86P`3V-T;V)E<@!/9F9E
M;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO
M="!C;W)R96-T+@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I
M;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE('9C87)D('-U<'!O<G1E9"X`
M3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H
M86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA
M<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F
M;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA
M;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA
M=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O
M<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3
M:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-
M($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R
M<P!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@
M`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B
M;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N
M("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I
M;VX@9&5N:65D`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E=',`4&AO;F4`4&AO=&]S`%!I;F4@061D<F5S<R!"
M;V]K`%!I>&5L<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!N86UE('1H
M92!N97<@8V]N=&%C="!L:7-T.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T
M96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L:71I
M8W,`4&]L;',`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O
M8W5M96YT`%!R:79A=&4@061D<F5S<R!";V]K`%!R:79A=&4@2V5Y`%!R;V)L
M96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0
M=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%%U97)Y`%%U
M97)Y(&9A:6QE9#H@*"5S*2`E<P!1=6EC:R!396%R8V@`475O=&$`4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%
M87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN
M('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&9A:6QE
M9#H@*"5S*2`E<P!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!D96QE=&4@
M=&AI<R!C;VYT86-T/P!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C;W)D
M<R!D:7-P;&%Y960Z`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!2
M96QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!A9&1R97-S(&)O;VL`4F5M;W9E(&-O
M;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@9G)O;2!T:&ES(&QI<W0`
M4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E
M<CH@)7,`4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@
M:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@9&5L971E<R!A
M;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R
M;VYG/@!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E
M<G)O<F-O9&4Z(`!297%U97-T960@;V)J96-T(&YO="!F;W5N9"X`4F5Q=6ER
M960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-E="!T;R!$969A=6QT<P!297-U;'1S`%)E='5R;B!T;R!/<'1I
M;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG
M=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H
M=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN
M+@!2;VQE`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!3+TU)344@4'5B;&EC($-E<G1I9FEC871E`%-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!3
M44P@4VAE;&P`4U-(`%-405)45$Q3(&9A:6QE9#H@*"5S*2`E<P!354-#15-3
M`%-?44P@4VAE;&P`4V$`4V%M92!F<F%M92`H7W-E;&8I`%-A=F4`4V%V92`E
M<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!38VEE;F-E`%-E87)C
M:`!396%R8V@@16YG:6YE<P!396%R8V@@4F5S=6QT<SH`4V5A<F-H(&9A:6QE
M9`!396%R8V@@9F%I;&5D.B`E<P!396%R8VAI;F<N+BX`4V5L96-T($9I;&5S
M`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A
M(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A
M9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L
M96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&%D9')E<W,@
M8F]O:R!T;R!E>'!O<G0@9G)O;3H`4V5L96-T('1H92!A9&1R97-S(&)O;VL@
M=&\@:6UP;W)T('1O.@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!C:&%R
M<V5T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!D871E(&1E;&EM
M:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!E>'!O
M<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@
M=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@9F]R
M;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SH`4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L
M('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+@!396QE8W0@=VAI
M8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N`%-E
M;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RX`4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N<V]R.B``4V5P
M=&5M8F5R`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@
M;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z(`!3:&%R960@1&ER96-T;W)Y`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M`%-H;W<`4VAO=R`E<P!3:&]W($%L;`!3:&]W($-O;G1A8W1S`%-H;W<@3&ES
M=',`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R
M<R!,871E`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEG;B!U<`!3:6=N871U<F4`
M4VEG;F%T=7)E($%L9V]R:71H;0!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VYO
M=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY
M`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE
M;G0@:6X@=V%T97(Z(`!3;VYG<R`F(%!O96US`%-O<G0@1&ER96-T:6]N`%-O
M<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=7)C97,`4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H97)N($AE;6ES<&AE<F4`
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I
M;F<@86YD('!A9&1I;F<`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M<&5C:69Y('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S
M('1O(&%P<&5A<BX`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W
M`%-P;W)T<P!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O
M<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E
M<W,`4W1R:6YG(&QI<W0`4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3=6)M:70`
M4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S
M`%-U8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@(B5S(BX`
M4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C
M8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N
M<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R;F%M90!3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%0M4W1O<FT`5"U3=&]R;7,`5%-6
M`%135B!F:6QE`%1A8B!S97!A<F%T960@=F%L=65S`%1A8FQE`%1A8FQE(%!R
M;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!487)G970Z`%1A<VMS`%1E;&5P
M:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`
M5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`
M5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@5D93(&)A8VME;F0@;F5E9',@
M=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@871T86-H;65N="!U<&QO861S
M+@!4:&4@861D<F5S<R!B;V]K("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!A
M9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,`5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!C;VYT86-T('EO
M=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N`%1H92!D971A8VAE9"!01U`@
M<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG
M;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN
M('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`B)7,B(&AA<R!S=6-C
M97-S9G5L;'D@8F5E;B!D96QE=&5D+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D
M(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE
M(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@
M=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F
M=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD
M(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L
M96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U
M;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE(&EM<&]R="!C86X@8F4@9FEN:7-H960@9&5S<&ET92!T
M:&4@=V%R;FEN9W,N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E
M96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N
M=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE('!R969E<F5N
M8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V
M960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP
M;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&)R
M;W=S96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S
M(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R!A
M<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S
M('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@:7,@86X@97)R;W(L('!L
M96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H97)E
M(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H
M879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S
M<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!A9&1I;F<@=&AE(&YE=R!C;VYT86-T+B!#;VYT86-T('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@9F]R(&9U<G1H97(@:&5L<"X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&%D9&EN9R!T:&ES(&]B:F5C="X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&-R96%T:6YG(&$@;F5W(&QI<W0N`%1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!T:&ES(&-O;G1A8W0Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!T:&ES(&]B:F5C="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AE(&QI<W0`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI
M<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!D871A.B`E<P!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q
M=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H
M92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@82!C
M;VYT86-T(&9R;VT@=&AE(&QI<W0N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,`5&AE<F4@=V5R92!N
M;R!A9&1R97-S97,@=&\@97AP;W)T+@!4:&5S92!A9&1R97-S(&)O;VMS('=I
M;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4:&5S92!C;VQU;6YS('=I;&P@
M9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4:&ES($E-05`@<V5R=F5R(&1O97,@
M;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T
M('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G
M97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@
M=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@
M=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@
M82!V86QI9"!N=6UB97(N`%1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O
M<G1E9"X`5&AI<R!I<R`E<RX`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('!E<G-O;B!A
M;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R97-S(&)O;VL`5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4
M:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`
M5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@
M:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@
M*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;VUO<G)O=P!4;W``
M5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')U92!O<B!F86QS90!4
M=0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4>7!E('EO=7(@8VAO:6-E.B``52Y6
M+B!I;F1E>#H@`%523`!54DPZ`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5
M;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D
M96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@
M)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=',`56YK;F]W;@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@
M8V]L;W(`56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<P!5;G-U<'!O<G1E
M9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A
M=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S
M92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T
M:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T
M(&9O=6YD`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN
M('1H92!S>7-T96TZ`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A
M8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I
M='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T
M:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L
M96-T(&9R;VT`5F%R:6%B;&4`5F5R:7-I9VX@1&ER96-T;W)Y`%9E<G-I;VX`
M5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I
M;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T;F%M97-E("A625-#24DI`%9I
M97<@)7,`5FEE=R!#;VYT86-T`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`
M5FEE=R!A<R`E<P!6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#H`5FES:6)I
M;&ET>0!6:7-I8FEL:71Y.B``5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!7
M96%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3
M:71E`%=E8G-I=&4@55),`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/
M+3@X-3DM,34I`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7
M:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD
M.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@0VET>0!7;W)K($-O
M=6YT<GD`5V]R:R!0:&]N90!7;W)K(%!O<W1A;"!#;V1E`%=O<FL@4W1A=&4O
M4')O=FEN8V4`5V]R:R!3=')E970@061D<F5S<P!960!965E9`%EE87)L>0!9
M97,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8V]N=&%C
M=',@:6X@(B5S(BX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U
M(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="X`
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R
M969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T
M(&%D9')E<W,@8F]O:RX`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N
M`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U
M(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+@!9;W4@
M;75S="!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N`%EO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N
M=&%C="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9
M;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT
M('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@
M;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R
M<SH`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;
M;&EN92`E<R!O9B`E<UT`6VYO('9A;'5E70!?061M:6YI<W1R871I;VX`7T)R
M;W=S90!?0TQ)`%]#;VYT86-T<P!?1&%T851R964`7T1E;&5T90!?1&5L971E
M(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%]);7!O
M<G0O17AP;W)T`%],:7-T<P!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN
M:RXN+@!?3F5W($-O;G1A8W0`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO
M=F4@3&EN:RXN+@!?4F5M;W9E(&9R;VT@=&AI<R!L:7-T`%]396%R8V@`7U-E
M='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`
M8V%L96YD87(`8V%L;0!C;&EC:R!H97)E`&-O;G1A8W0N=F-F`&-O;G1A8W1S
M+F-S=@!C;VYT86-T<RYT<W8`8V]N=&%C=',N=F-F`&9I;&4`9G)O;2!T:&4@
M)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&EM;65D:6%T90!I;FQI;F4`
M;&EN97-=`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT
M960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E
M;F-E<P!S=&5A9'D`=&%S:R!L:7-T`'1O(&$@0V]N=&%C="!,:7-T`'1O(&$@
M9&EF9F5R96YT($%D9')E<W,@0F]O:P!T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R
M9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A(#(@
M04Q02$$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`U+3`W+3`X(#$R.C0U*S`T,S`*3&%S="U4
M<F%N<VQA=&]R.B!!;6ER:V%B:7(@365T86YE='=O<FMI;F<@;'1D+B`\<&5R
M<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RYC;VT^"DQA;F=U86=E+51E86TZ
M(%!E<G-I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ
M(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]551&+3@*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("C8L=F(V+(@V8+8
MJ-F$("5S*0`HVJG9A-N,V*\@V*_8L]BJV+'8L]N,("5S*0`HV*_8L2`E<R#8
ML=F(V+(I`"`HV*?9A=BQV8C8LBD`("C9@=BQV*_8IRD`("C8K]N,V+'9B-BR
M*0`@V*_8L2``(B5S(B#8K]BQ(-BMV*?9A"#8K=BGV+;8L2#9A=F(V*S9B-BO
M(-F%VXSB@(S8J-BGV+38KR#9B"#8K]BQV8C9AN*`C-BHV+'8KR#9AMBTV*_9
MAR#8J-F(V*\N`"(E<R(@V*C9AR#:K]BQV8C9A^*`C-F'V*?;C"#8L]BGV878
MI]F&V8<@V*?8MMBGV8'9AR#8M-BO`"(E<R(@V*C9AR#8L]BGV878I]F&V8<@
MV878K-F(V++B@(S9A]BG(-BGV+;8I]F!V8<@V+38KP`B)7,B(-BGVXS8K-BG
MV*\@V8;8M-BOV8<@V*C9B-BO.B`E<RX`(MF&V*?9A2`@V8;8I]F%(-BNV*?9
MAMF(V*?8K]JOVXPB`"+9AMBGV84@V*[8I]F&V8C8I]BOVJ_;C"`@V8;8I]F%
M(@`E+C)F34(@V*?8L]BJV8'8I]BOV8<@V+38K]F'(-BGV+(@)2XR9DU"(-F%
MV*S8I]BR("@E+C)F34(I`"5D("5S(-F(("5S`-BGV+/9A2#8L=F%V+(@V+39
MA=BG("5D(-BQV8C8LB#8K]N,VJ_8L2#9A=BYV*K8J-BQ(-BGV+/8JBX`V;[;
MC-BTPJW8J-N,V8;;C"`E9"W8L=F(V++9AP`E<R`M(-BJV8C8K-F'`-BGV*O8
ML2#8I]F&VJ_8M-BJ("5S`-JIVXS9A-F(V*C8I]N,V*H@)7,`)7,@V+G9A=F$
MVXS8I]BJ(-F&VJ_9A]BOV*?8L=N,("T@V*K8H]N,VXS8KP`@V+'8I]F')B-X
M,C`P8SO8I]F&V*_8I]BRVXP@)7,@`"5S(-BKV*C8JB#9AMBGV84`V+38L=F(
MV+<@V*K9B-BGV8'9@B`E<P`E<R#8I]BVV*?9@=F'(-BTV*\`)7,@V*?8LB#9
M@MBHV80@V879B-BLV8C8KR#8I]BSV*H`)7,@V*_8L2`E<R`E<P#9OMBQV8C9
MAMBOV8<@)7,@V*C8IR#9A=F(V8'9@MN,V9'8JB#8K]BQV8C9AN*`C-BHV+'8
MKR#8M-BO`"5S(-BBV878I]BOV8<@V*?8K-BQV*?;C"#8N=F%V83;C-BGV*H@
MV8;:K]F'V*_8I]BQVXP@V*?9AMBJV*[8I]BH(-BTV*_9AR#8I]BSV*HN(-BL
MV+G8J-F'(-F'V+$@V+G9A=F$VXS8I]BJVXP@V+'8IR#:J=F'(-F'V84@V*?:
MJ=F&V8C9AB#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV*S8L=BG(-JIV8;;C-BO
M(-BYV838I]F%V*H@V*C8LMF&VXS8KP`E<R#9A=F(V+'8KR#9AMN,V*?8LB#8
MI]BSV*H`)7,@V*_9@MN,V8+9AP`E<R#9OMN,V*_8IR#9AMBTV*\`)7,@V*C9
MAR`E<R#8I]BR("5S`-BJV8+9B-N,V84@)7,`)7,G<R!.;W1E<&%D`-F!V8?8
ML=BSV*H@V8C8N-BGVXS9@2`E<P`E<SH@)7,`V(P@V*C8I]BO`-B,(-BHV*?8
MKR`E<R`E<P#8C"#9A=BJV+K;C-N,V+$@V*?8LB`E<R#8J-F'("5S`"#8I]F&
MV*K8KMBGV*@@`-F"V*?9A-BH(-NQV[(@V+/8I]BYV*K;C`#9@MBGV838J"#;
MLMNT(-BSV*?8N=BJVXP`V[+;M"#8L]BGV+G8JMF'`-F%V+'9B-BQVJ_8L=N,
M(-JIV8<@:49R86UE<R#8L=BG(-F^V+38JMN,V*C8I]F&VXP@VJG9AMBO(-F$
MV*?8LMF%(-BGV+/8J@#;C-JI(-F^V+38JMN,V*C8I]F&(-BOV*?8K]JOV*?9
MAB#8J-BQV*?;C"#8I]N,V88@V*C9A-BGVJD@V879B-BQV*\@V8;;C-BGV+(@
MV*?8L]BJ`-N,VJD@V*[8M]BGVXP@V*S8K]N,(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@V*C8L=BGVXP@V+'9
MA=BRV*C9AMBOVXP@VXS:J2#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR
M(-BGV+/8J@#;C-JI(-JIV83;C-BO(-BYV879B-F%VXP@4$=0(-BHV+'8I]N,
M(-BHV*?8LMBHVXS9AMN,(-N,VJD@V;[;C-BZV*?9A2#8I]F%V+;8I]BA(-BT
MV*_9AR#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8
MN=F%V8C9A=N,V(P@VXS:J2#:J=F$VXS8KR#8KMBUV8C8M=N,(%!'4"#9B"#;
MC-JI(-BYV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-BQV878LMJOV+38I]N,
MVXP@VXS:J2#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;
MC-JI(-JIV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79
MB-BUVXP@4$=0(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@
MV*?9A=BVV*?8H2#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@
MV*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@VJG9A-N,
MV*\@V*[8M=F(V+7;C"!3+TU)344@V8@@VXS:J2#8N=BHV*?8L=BJ(-JOV+#8
ML2#8J-BQV*?;C"#8L=F%V++:K]BTV*?;C-N,(-F^VXS8NMBGV84@V879B-BQ
MV*\@V8;;C-BGV+(@V*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,
M(-N,VJD@VJG9A-N,V*\@V*[8M=F(V+7;C"!3+TU)344@V8@@VXS:J2#8N=BH
MV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#8I]F%V+;8I]BA(-N,VJD@V;[;C-BZ
MV*?9A2#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8
MN=F%V8C9A=N,(%,O34E-12#8J-BQV*?;C"#8L=F%V++8J-F&V*_;C"#9OMN,
MV+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#8J-BGV+'8I]F&(-BS
MV*C:J2#8M=BHV*W:K]BGV8?;C`#8J-BGV+'8I]F&(-BUV*C8K=JOV*?9A]N,
M`-BQVJ_8J-BGV+$@V+78J-BMVJ_8I]F'VXP`V*K:K]BQVJ\@V+78J-BMVJ_8
MI]F'VXP`V+78J-BM+]BYV+78L0#8K]BQV*C8I]BQV8<@V*?;C-F&(-F(VXS8
ML=BGV+/8JMBGV+$`V*_8L=BHV*?8L=F'+BXN`-BHV*?9A-BGVXP@V8'8L=F%
M(-BLV+/8JMBLV8@`V;[8I]N,VXS9AB#9A=BWV839@@#9B-BSV+<@V878M]F$
MV8(`V*?;C-BLV*?8KR#8M-BGV*[9AR!61E,@V878K-F(V+(@V*_8L]BJV+'8
ML]N,(-F&V*_8I]BQV*\`V*?;C-BLV*?8KR#9OMBQV8C9AMBOV8<@5D93(-F%
MV*S9B-BR(-BOV+/8JMBQV+/;C"#9AMBOV*?8L=BO`-BYV*_9A2#8I]BLV*?8
MLMF'V90@V*_8L]BJV+'8L]N,(-BHV8<@)7,`V*?8M]F$V*?8N=BGV*H@V*W8
ML]BGV*@`V*?8L]F%(-BQV878LB#8K=BSV*?8J`#8K=BSV*?8J"#9A=BSV*_9
MB-BO`-BMV+/8I]BHV*_8I]BQVXP`V*?8MMBGV8'9AR#:J=BQV*_9A@#8I]BV
MV*?9@=F'(-JIV+'8K]F&(-JOV+'9B-F'(-F!V+'8N=N,`-BGV+;8I]F!V8<@
MVJG8L=BOV88@V878K-F(V+(@V8'8L=BYVXSB@(P`V*?;C-F&V*S8IR#8I]BV
MV*?9@=F'(-JIV88Z`-BGV+;8I]F!V8<@VJG8L=BOV88@VJ_8L=F(V8<@V*S8
MK]N,V*\`V*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BLV8C8LB#8K-BOVXS8KP#8
MI]BVV*?9@=F'(-JIV+'8K]F&(-N,VJD@V878K-F(V+(@V8'8L=BYVXP@V*C9
MAR`B)7,B`-BGV+;8I]F!V8<@VJG8L=BOV88@VXS:J2#:J=BGV+'8J-BQ(-BL
MV*_;C-BO.@#8I]BVV*?9@=F'(-JIV+'8K]F&(-JIV*K8I]BHVH;9A]F4(-BB
MV*_8L=BS`-BGV+;8I]F!V8<@VJG8L=BOV88@V+/8JMF(V88`V*?8MMBGV8'9
MAR#:J=BQV*_9AB#9OMBQV8C9AMBOV8<`V*?8MMBGV8'9AR#:J=BQV*_9AB#8
MI]BYV+;8I]N,(-BLV*_;C-BO`-BGV+;8I]F!V8<@VJG8L=BOV88@V++9B-BL
M`"#8I]BVV*?9@=F'(-JIV+'8K]F&(-JOV++;C-F&VJ_8I]F&("5S(-BHV+G9
MAMF(V*?9AB#9AMF(V*?8L2#8K-BGV8;8J-N,(-F%V8C8LMN,V838IP#8I]BV
MV*?9@=F'(-JIV+'8K]F&(-BHV8<`V*?8MMBGV8'9AR#:J=BQV*_9AB#8J-F'
M(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS.@#8I]BVV*?9@=F'(-JIV+'8K]F&
M(-BHV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V879A@#8I]BVV*?9@=F'
M(-F#V+'8K]F&(-JIV*?8L=BHV+$`V*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BG
MV+'8J-BQV*?9AB#9@=BYV*?9A"#9AMN,V+/8J@#8HMBOV+'8LP#9@=F'V+'8
ML]BJ(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS`-JIV*K8I]BHVH;9A^*`C-F'
MV*?;C"#8HMBOV+'8LR``V8C8L=F(V*_;C"#:J=BJV*?8J-J&V8?9E"#8HMBO
MV+'8LP#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8J-BGV879B-F!V8+;C-F1
MV*H@V*[8I]F$VXP@V+38KP#:J=BJV*?8J-J&V8<@V*+8K]BQV+/B@(S9A]BG
MVXS;C"#:J=F'(-F&V878I]N,V+0@V*_8I]BOV8<@V8;8KMF(V*?9A]F&V*\@
MV+38KSH`V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9ART@V*K8N=N,VXS9AB#9
MA=BLV8C8LMF'V*?;C"#:J=BGV+'8J-BQV*?9AB#8K]N,VJ_8L0#8L]BQV;[8
ML=BSV*K;C`#8JMBHV83;C-BZV*?8J@#8K-BSV*K8K-F(VXP@V;[;C-BTV+'9
M@=BJV8<`V8;8I]F%(-F%V+/8JMBYV*?8L0#8JMBQV*?8LB#:J=BQV*_9A@#8
MJMBQV*?8LCH`V8?9A=F'`-BJV878I]F%VXP@VJG8I]BQV*C8L=BGV88@V*K8
MH]N,VXS8KR#8M=F$V*?8K=N,V*H@V+38K]F'`-F'V879AR#:K]BQV8C9A^*`
MC-F'V*<`V8?9A=F'(-F%V*S9B-BRXH",V8?8IP#9A]F%V8?9E"#:AMF'V*?8
ML2#8L]F%V*H`V*?8K-BGV++9AR#:AMF&V*\@V*+8K]BQV+/;C`#8HMN,V*<@
MV*?8K-BGV++9AR#8JMF&V+C;C-F%(-F&V8C8N2#9@=F'V+'8L]BJ(-F%V+'8
MJMBH(-BOV*?8K]F'(-BTV8C8K]B?`-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@
MV87;C.*`C-BHV*?8M-BO`-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ
M`-F(V+'9B-BO($E-4U`@V*S8I]N,VJ_8LMN,V88`V*?8L]F%(-BQV878LB!)
M35-0(-BLV*?;C-JOV++;C-F&`-F&V*?9A2#:J=BGV+'8J-BQVXP@24U34"#8
MK-BGVXS:K]BRVXS9A@#8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;
MC-JI(-BLV*?;C-JOV++;C-F&`-BGV83:K]F(XH",V8?8I]N,(-BLV*?;C-JO
MV++;C-F&`-F%V*K9AB#8K-BGVXS:K]BRVXS9ACH`VXS:J2#9A=F"V*_8I]BQ
M(-F&V*?8K]BQV+/8JB#8JMBYVXS;C-F&(-BTV*_9AR#8J-F(V*\`V;[;C-BT
MVJG8I]BQ`-F^V*?8L]BN`-BHV+'9AMBGV879A]F4XH",(-JIV*?8L=BHV+'8
MK]N,`-F!V8?8L=BSV*H@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-JIV*?8L=BH
MV+'8K]N,`-BHV+'9AMBGV879AR#8HMF%V*?8K]F'(-BGV+/8J@#8I]BYV878
MI]F$(-BHV+$@V+'9B-N,(-BGV+38JMBQV*?:J=F'V*?;C"#9@=BQV+G;C`#8
MJMBUV8C;C-BH`-BGV8;8K]BGV++9AR#8JMF"V+';C-BHVXP`V*+9B-BQVXS9
MA`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`V*?9AMBOV*?8LMF'(-F^V+'9B-F&
MV*_9AR#8HMBQV+3;C-F(`-F&V*?9A2#8HMBQV+3;C-F(`-BBVXS8IR#9A=BW
MV878IMF&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@)7,@V+'8IR#8
MK=BPV8$@VJG9AMN,V*_8GP#8HMN,V*<@V878M]F%V*;9AMN,V*\@VJG9AR#9
MA=N,XH",V*[9B-BGV8?;C-BO(-F(V+'9B-BOVXSB@(S9A]BGVXP@V*?9AMBJ
MV*[8I]BH(-BTV*_9AR#8L=BG(-BMV+#9@2#:J=F&VXS8K]B?`-BBVXS8IR#8
MM-F%V*<@V878M]F%V*;9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO
M(-BGV+?9A-BGV+G8I]BJ(-BGV8'8JMBJV*?8K2#8K=BSV*?8J"`E<R#8L=BG
M(-F^V*?:J2#:J=F&VXS8K]B?`$%R;65N:6%N("A!4DU30TE)+3@I`-F'V8;8
ML0#8M=BYV8C8K]N,`-BBVXS8IR#9@MBHV80@V*?8LB#8N=F%V83;C-BGV*H@
MV8;:K]F'V*_8I]BQVXP@V*C8L=BGVXP@V*K8H]N,VXS8KR#8HMF&(-BSV*;9
MB-BGV80@V+39B-BOV)\@`-BGV8;8JMBSV*?8J"#8L]BJV8C9AMF'V*<`V+/8
MN=N,(-BOV+$@V*W8L-F!(-JOV+'9B-F'VXP@V+38K]F'(-BGV+/8JB#:J=F'
M(-F%V8C8K-F(V*\@V8;;C-BSV*H`V+/8N=N,(-BOV+$@V*W8L-F!(-F%V*S9
MB-BRVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`
MV+/8N=N,(-BOV+$@V8C;C-BQV*?;C-BT(-F%V*S9B-BRVXP@V+38K]F'(-BG
MV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`V+/8N=N,(-BOV+$@V8C;
MC-BQV*?;C-BT(-BGV+38JMBQV*?:J=N,(-BTV*_9AR#8I]BSV*H@VJG9AR#9
MA=F(V*S9B-BO(-F&VXS8L]BJ`.*`C-F(VXS:F-JOVXS9A]BG`-BBVJ_9B-BS
MV*H`075T:%]C>7)S<6PZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!)34%0
M(-F^VXS8K]BG(-F&V+38KP!!=71H7V-Y<G-Q;#H@V+/8I]F%V*?9AMF'(-F^
MV+38JMN,V*C8I]F&(-F"V*?8J-F$VXS8JMF'V*?;C"#9A=F(V+'8KR#9AMN,
MV*?8LB#8L=BG(-F&V*_8I]BQV*\`075T:&EM<#H@V*C8L]BW(-F%V8C8L=BO
M(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?9G1P.B#8J-BS
MV+<@V879B-BQV*\@V8;;C-BGV+(@1E10(-F^VXS8K]BG(-F&V+38KP!!=71H
M7VEM<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@
MV8;8M-BO`$%U=&A?:W)B-3H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR(&MR
M8C4@V;[;C-BOV*<@V8;8M-BO`$%U=&A?;&1A<#H@V*C8L]BW(-F%V8C8L=BO
M(-F&VXS8I]BR($Q$05`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?;&1A<#K8I]BV
MV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BS
MV*HN(-BGVXS9AB#:AMN,V++;C"#8I]BSV*H@VJG9AR#:J=BGV+'8L]BGV+(@
MVJ_9@=BJV8<@V*?8L]BJ`$%U=&A?;&1A<#K8K=BPV8$@VJG8I]BQV*C8L2`E
M<R#9A=F%VJG9AB#9AMN,V+/8JB``075T:%]L9&%P.MBHV+'9B-BRV+'8L]BG
MV8;;C"#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ`$%U=&A?;6-A
M;#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($U#04P@V;[;C-BOV*<@V8;8
MM-BO`$%U=&A?<VUB875T:#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR('-M
M8F%U=&@@V;[;C-BOV*<@V8;8M-BO`-BJV+78K]N,V8(@V8?9B-N,V9'8JB#9
MAMBGV879B-F!V9'9@B#8J-F(V*\`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&
MV*?9A=F(V8'9D=F"(-BHV8C8KRX@)7,`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M(-BGV+(@V+?8L=F!(-JIV*?8L=BSV*?8LB!2041)55,@V+'8KR#8M-BOV8<@
MV*?8L]BJ`-BJV+78K]N,V8(@V8?9B-N,V9'8JB#8K]BQ(-JIV*?8L=BSV*?8
MLB!&5%`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(`#9@=N,V838K]F'V*?;C"#9
M@MBGV*C9A"#8K]BSV*K8L=BSVXPZ`-F^V+/B@(S8LMF%VXS9AMF'`-BQV8;:
MKR#9OMBSXH",V++9A=N,V8;9AP#8I]BSV84@V+'9A=BR(-F&V*?8K]BQV+/8
MJB!K97)B97)O<P#9AMBGV84@VJG8I]BQV*C8L2#9AMBGV*_8L=BSV*H@:V5R
M8F5R;W,`0F%L=&EC("A)4T\M.#@U.2TQ,RD`V*[8MR#9A=BHV8;8IP#8K-BS
MV*K8K-F(VXP@V+/8I]BOV8<`V++;C-BQ(-F!V+'9A2#8K-BSV*K8K-F(`-F^
MVXS9B-BSV*K9AB#9AMBGV879B-F!V9'9@B#8J-F(V*\Z("@E<RD@)7,`V+'9
MB-BR(-BJV8C9A-BO`-BHV839B-JI("(E<R(@V*?8LB#8J-BQV8;8I]F%V8?9
ME"#:J=BGV+'8J-BQV*_;C"`B)7,B(-N,V*?9@=BJ(-F&V+38KP#8JMF&V+C;
MC-F%V*?8JB#8J-F$V8C:J0#9AMF(V+D@V*C9A-F(VJD`V+/;C-BGV8<`VH;9
MB-BH(-BGV839@0#9A-BHV8<`V;[9A]F&V*?;C"#9A-BHV8<Z`-F$V*C9A^*`
MC-F'V*<`V8?8L2#8K]F(`-F^V*?;C-N,V88`V878L=F(V+$`V83;C-BSV*H@
MV*C9B-F$V*KB@(S8K]BGV+$`V*_8L]BJV8<@V*K8K-BGV+';C`!#35,`0U)#
M`-F&V8+8I]BW(-BJV8C8LMN,V+D@0U),`$-35@#8KMBUV8C8M=N,V*?8JB#8
ML]F$V8C9A"XN+@#8JMF"V8C;C-F%`-BBV+'8I]F%`-F&V87;C.*`C-BJV8C8
MI]F&(-BGV+/9A2#8L=F%V+(@V+'8IR#8J-BWV8C8L2#8KMF(V*_:J=BGV+$@
MV*_9B-BHV*?8L=F'(-BHV*?8LMF&V+38I]F&V*_8C"#8J-BG(-BSV+'9OMBQ
MV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO(-BJV878I]BS(-BHVJ_;C-BQVXS8
MKP#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR`B)7,B(-F&
MV8C8M-BJ`-F&V87;C.*`C-BJV8C8I]F&(-N,VJD@VJ_8L=F(V8<@V+'8IR#8
MJ-F'(-BNV8C8K]BT(-BGV+;8I]F!V8<@VJG8L=BO+@#9AMF%VXSB@(S8JMF(
MV*?9AB#8J-F'(-JIV*?8L=BSV*?8LB#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;
MC-JI(-F%V*K8M=F$(-BTV*\Z("5S`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9
MB-F&V*_9AR`B)7,B(-BQV*<@V*C8I]BR(-JIV+'8KP#8I]F&V+78L=BGV8$`
MV*?9AMBUV+'8I]F!(-BGV+(@V*?8L=BSV*?9A"#:K]BRV*?8L=BT`-F&V87;
MC.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR`B)7,B(-BQV*<@V*W8L-F!(-JI
MV+'8KR`@`-F&V87;C.*`C-BJV8C8I]F&(-N,VJD@V+38I]BNV8<@V879B-F"
MV*H@V;[;C-BOV*<@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-BHV*_9B-F&
M(-F^V*?8L=BGV878JMBQ("?9OMBQV8C9AMBOV8<@V879@MBUV*\G(-BGV*_8
MI]F%V8<@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'("(E<R+8
ML=BG(-BMV+#9@2#:J=BQV*\@`-F&V87;C.*`C-BJV8C8I]F&(-BMV+#9@2#9
MAMF%V8C8K]B,("5D(-F!V+'8LMF&V*\@V879B-BLV8C8KR#8I]BSV*H`V8;9
MA=N,XH",V*K9B-BGV88@V*_9B-BHV*?8L=F'(-F%V+'8JMBH(-F&V879B-BO
MV(P@V*C8L=BNVXP@V*?8LB#9B-BQV8C8K]N,V8?8I]N,(-F!V+'8I]F'V84@
MV+38K]F'(-BHV+'8I]N,(-F%V+'8JMBH(-BSV*?8LMN,(-BHV*<@V+39A=BG
MV+'9A^*`C-F'V*?;C"#8L-BNVXS8L=F'(-BTV*_9A]B,(-BSV*?8LMJOV*?8
ML2#9AMN,V+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#9OMN,V+K8I]F%(-BQV*<@
MV*C9AR#8M-F%V*?8L=F'(-BJV+G;C-N,V88@V+38K]F'(-JOV+#8L2#8K]BG
MV*\`V+G9AMF(V*?9A@#8K=BGV879A`#:K]BQV8C9A^*`C-F'V*<@V8@@V*C8
ML=J&V+/8J-F'V*<`V879B-BHV*?;C-F$`-BNV+79B-BUVXS8I]BJ(-BSV839
MB-F$`-F!V*?8M=F$V8<@V+/9A-F(V80`V*[8M=F(V+7;C-BGV*H@V+/9A-F(
MV80`V8'8I]BUV839A^*`C-JOV+#8I]BQVXP@V+/9A-F(V80`V879B-BHV*?;
MC-F$`$-E;'1I8R`H25-/+3@X-3DM,30I`-F%V+':J=BR`$-E;G1R86P@175R
M;W!E86X@*$E33RTX.#4Y+3(I`-BLV++8IMN,V*?8JB#:K]F(V*?9A]N,(`#8
ML]N,V*?8L]BJV8?8I]N,(-JOV8C8I]F'VXP`V*K8NMN,VXS8L2``V*?8L]F%
M(-BQV878LB#8KMF(V*\@V+'8IR#8JMBZVXS;C-BQ(-BOV8?;C-BO`-BJV+K;
MC-N,V+'8K]BGV*_9AB#9AMBGV84@V8@@V*+8K]BQV+/;C"#:J=F'(-BGV8'8
ML=BGV*\@V8?9AMJOV*?9A2#8KMF(V*?9AMBOV88@V8@@V;[8I]BSV*X@V*_8
MI]BOV88@V*C9AR#9AMBGV879A]F4(-BTV878IR#8KMF(V*?9A]F&V*\@V*_;
MC-BO(`#8JMBZVXS;C-BQV*_8I]BOV88@V*?8L]F%(-BQV878LB#8M-F%V*<@
MV*_8L2#9OMN,VJG8L=BHV8;8K]N,(-F!V+G9A-N,(-F^V+38JMN,V*C8I]F&
MVXP@V8;9A=N,XH",V+39B-BO+B#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878
MI]F&V8<@V*[9B-BO(-BJV878I]BS(-BHVJ_;C-BQVXS8KP#9AMF(VXS8L]F'
M`-BHV+'8L=BSVXP@V;[;C-F(V8;8KRXN+@#8J-BQV+'8L]N,("#9A]F%V8<O
MV8?;C-J&XH",VJG8K]BGV84`XH",`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0#8I]F&V*K8KMBGV*@@
MVXS:J2#8I]BSV84@V+'9A=BR`-BGV8;8JMBNV*?8J"#;C-JI(-F&V*?9A2#:
MJ=BGV+'8J-BQVXP`V*?9AMBJV*[8I]BH(-N,VJD@VJG8JMBGV*C:AMF'V90@
MV*+8K]BQV+,@`-BGV8;8JMBNV*?8J"#;C-JI(-JIV*K8I]BHVH;9A]F4(-BB
MV*_8L=BS.B``V*?9AMBJV*[8I]BH(-J&VJ_9B-F&VJ_;C"#9AMF%V*?;C-BT
M(-BJV*?8L=N,V*XZ`-BGV8;8JMBNV*?8J"#9AMF(V+D@V+/8J-JI(-F!V8?8
ML=BSV*H@*-BHV+'8I]N,(-F!V8?8L=BSV*K9A]BGVXP@V878L=BJV*@I`-BG
MV8;8JMBNV*?8J"#:J=BJV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,@V8@@
MV*K8N=N,VXS9AB#8JMBQV*K;C-BH(-BBV8;9A]BG(-BHV+'8I]N,(-F&V878
MI]N,V+0`V*?9AMBJV*[8I]BH(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BSXH",
MV8?8I]N,(-F%V8C8L=BO(-BGV+/8JMF!V*?8K]F'(`#8I]F&V*K8KMBGV*@@
MV8;8I]F%(-F((-BJV+'8JMN,V*@@V+/8JMF(V8;9A]BGVXP@V8;9A=BGVXS8
MM"#8K]BGV*_9AR#8M-BOV8<Z`-BJV+G8L=N,V8$@VJG9A-BGV+,@)7,@VXS8
MI]F!V*H@V8;8M-BO`-BUV*?9@0#9OMBGVJD@VJG8L=BOV88@V*K:K]F'V*?;
MC"!-4T]F9FEC90#9OMBGVJD@VJG8L=BOV88@VJG8I]BQV*C8L2`Z("5S`-F^
MV*?:J2#:J=BQV*_9AB#:J=BGV+'8J-BQ`-F^V*?:J2#:J=BQV*_9AB#8K]BG
MV*_9A]F4(-JIV*?8L=BHV+$`V*C8L=BGVXP@V*?8K]BGV879A]B,(-JIV83;
MC-JI(-JIV8;;C-BO`$-L:6-K871E;&P@V*?8LB#8M]BQVXS9@B!(5%10`-BH
MV+/8JMF&(-F^V8;8K-BQV8<`V*?8J-BQV8?8IP#8I]BHV+';C`#8K-F%V+D@
MV+38K]F&(-F&V8C8I]BQ(-JIV8;8I]BQVXP`VH;9A=BY(-BTV*_9AB#9A-BH
MV8?B@(S9A]BG`-BQV8;:KP#8I]F&V*K8KMBGV*@@VJG9AMF&V*_9AR#8L=F&
MVJ\`V*?9AMBJV*[8I]BH(-BQV8;:KP#8L]BJV8C9AMF'V*<Z`-JOV++;C-F&
MV8?B@(S9A]BGVXP@V+/8JMF(V8;;C`#8N=F&V*?9B-N,V88@V+/8JMF(V8;9
MA]BG`-BSV*K9B-F&V8?8I]N,VXP@VJG9AR#9AMF%V*?;C-BT(-BOV*?8K]F'
M(-F&V*[9B-BGV8?9AMBO(-BTV*\Z`-F%V+;8K=JI`-F%V8+8I]BOVXS8L2#8
MK-BOV*<@V+38K]F'(-BJV8C8L]BW(-F(VXS8L=JOV8C9A`#9A=F"V*?8K]N,
MV+$@V*S8K]BG(-BTV*_9AR#8JMF(V+/8MR#9B-N,V+':K]F(V80@*$UI8W)O
M<V]F="!/=71L;V]K*0#9@=BQV878I]F&`-F^V8C8L]BJV8<@V8'8L=F%V*?9
MA@#8JMF(V+;;C-BM`-F&V*?9A2#8N=F%V8C9A=N,`-BTV+':J=BJ`-BBV*_8
ML=BS(-BTV+':J=BJ`-BQV*?;C-BGV8;9A^*`C-F'V*<`V+38L=BW`-BTV+'8
MI]N,V+<`V*K9@=BGV8C8JMF'V*?;C"#9OMN,VJG8L=BHV8;8K]N,`-F^VXS:
MJ=BQV*C9AMBOVXP@)7,`V*K8H]N,VXS8KR#8I]BSV84@V+'9A=BR`-BGV*K8
MM=BGV80@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-BGV*K8M=BGV80@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO`-BGV*K8M=BGV80@V8;8I]F%V8C9@=F1V8(@V*C9
MB-BO.B`E<P#8KMBQV*?8J-N,(-BGV+'8JMBHV*?8MP#8I]BJV+78I]F$(-BH
MV8<@VJG8I]BQV+/8I]BR(-JIV83;C-BO(-BYV879B-F%VXP@V+'8KR#8M-BO
M`-BGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@VJG9A-N,V*\@V+G9A=F(
MV87;C"#8L=BO(-BTV*\N(-BOV83;C-F$.B`E<R`H)7,I`-BGV*K8M=BGV80@
MV*C9AR#:J=BGV+'8L]BGV+(@1E10(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP#8
MJMF%V*?8LR#8J-F'(-F!V8?8L=BSV*H@V*?8MMBGV8'9AR#8M-BO+@#8JMF%
MV*?8LR#8I]BR(-F!V8?8L=BSV*H@V*W8L-F!(-BTV*\N`-F&V878I]BSV8?8
MIP#8JMF%V*?8L^*`C-F'V*<@V*_8L2#9@=F'V+'8L]BJ.B`E<P#8JMF%V*?8
ML]F'V*<@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@VJG8JMBGV*C:AMF'
MV90@V*+8K]BQV+,@V+39A=BG(-BGV+;8I]F!V8<@V+38K]F'(-BHV8C8KP#8
MI]BOV*?9A=F'`-JIV8C:J=N,`-BQV8C9AMF(V+38J@#8L=F(V8;9B-BTV*H@
MV*C8L=BOV*?8M-BJV88@V*?8LB#8J-BNV+0@V*?9AMBJV*[8I]BHVXP`V8;9
MA=N,XH",V*K9B-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V+'9A=BRV*C9AMBO
MVXP@VJG9AMBO(%!'4`#9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@
MV+'8IR#8I]F%V+;8I]BA(-JIV8;8KR!01U``V8;9A=N,XH",V*K9B-BGV8;8
MKR#9OMN,V+K8I]F%(-BQV*<@V+'9A=BRV*C9AMBOVXP@VJG9AMBO(%,O34E-
M10#9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8I]F%V+;8
MI]BA(-JIV8;8KR!3+TU)344`V8;9A=N,XH",V*K9B-BGV88@V*K9A=BGV+/9
MA]BG(-BQV*<@V*?8MMBGV8'9AR#:J=BQV*\@)7,`V8;9A=N,XH",V*K9B-BG
MV88@V*C9AR#:J=BGV+'8L]BGV+(@3$1!4"#9OMN,V8C8L]BJ(`#9AMF%VXSB
M@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!L9&%P(-F^VXS9B-BSV*H`
MV8;9A=N,XH",V*K9B-BGV88@V*C8I]F$V*?9AMBS(-BQV*<@VH;:J2#:J=BQ
MV*\@)7,`V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@;&1A
M<"#9A=BJV+79A"#8M-BO`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@
MV*K9B-BRVXS8N=N,(-BGVXS8K-BGV*\@VJG8L=BO+B`E<P#9AMF%VXSB@(S8
MJMF(V*?9AB#8K]BGV*_9AR!01U`@V+'8IR#8L=F%V++:K]BTV*?;C-N,(-F&
MV879B-BO(`#9AMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR!3+TU)344@V+'8
MIR#8L=F%V++:K]BTV*?;C-N,(-F&V879B-BO(`#9AMF%VXSB@(S8JMF(V*?9
MAB#8JMF%V*?8LR#8L=BG(-BMV+#9@2#9AMF%V8C8KRX@)7,`V8;9A=N,XH",
MV*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8K=BPV8$@
MV8;9A=F(V*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-BBV*_8L=BS(-JOVXS8
ML=F&V*_9AR#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BQV*<@
MV*K8M-BNVXS8M2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@VJG9A"#:J=BJ
MV*?8J-J&V8?9E"#8HMBOV+'8LR#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\`
MV8;9A=N,XH",V*K9B-BGV88@VJG9A"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;
MC"#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@
MV8'9A]BQV+/8JB#:J=BGV879A"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8
ML=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@VJG9
MA-N,V*\@V+G9A=F(V87;C"#8L=BG(-BGV+(@VJG8I]BQV+/8I]BR(-JIV83;
MC-BO(-BHV*_8L]BJ(-BBV8C8L=BO`-F&V87;C.*`C-BJV8C8I]F&("5S(-BQ
MV*<@V*C8I]BR(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9A=BOV8C9A"#9
MB-BXV*?;C-F!(-F&VJ_9A]BOV*?8L=N,("5S(-BQV*<@V*C8I]BR(-F&V879
MB-BO`-F&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*[9B-BGV8;8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#8I]BSV84@V+'9A=BR(-BQV*<@V*C8L=BGVXP@VJG8
MI]BQV*C8L2#9A=F(V+'8KR#9AMBXV+$@V*C8I]BRV8;8M-BGV8;8KRX@V*C8
MN=BVVXP@VXS8IR#9A]F%V8<@V*S8LMBFVXS8I]BJ(-F%V+'8J-F(V+<@V*C9
MAR#8HMF&(-F&V*?8K]BQV+/8JB#9A=N,XH",V*C8I]BTV*\N(-BOV8C8J-BG
MV+'9AR#8L]BYVXP@VJG9AMN,V*\@VXS8IR#8J-BQV*?;C"#:J=F%VJD@V*C;
MC-BTV*K8L2#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO
M(-BJV878I]BS(-BHVJ_;C-BQVXS8KP#9AMF%VXSB@(S8JMF(V*?9AB!!0TP@
MV+'8IR#8K]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\`V8;9A=N,XH",
MV*K9B-BGV88@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+'8IR#8K]F(V*C8
MI]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&
M(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*_9B-BHV*?8L=F'(-BH
MV*_8L]BJ(-BBV8C8L=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8
ML]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8
MHMF(V+'8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V8+8I]BHV83;C-BJV8?8
MI]N,(-JIV*?8L=BSV*?8LB#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8
MHMF(V+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-BQ
MV*<@V*C8I]BRVJ_8L=BOV*?9AMBO`-F&V87;C.*`C-BJV8C8I]F&(-F^VXS:
MJ=BQV*C9AMBOVXP@)7,@V+'8IR#8K]BNVXS8L=F'(-JIV+'8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-F^V+38JMN,V*C8I]F&(-BQ
MV*<@V*W9@=BX(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BH
MV8;8K]N,(-F^V+38JMN,V*C8I]F&(-BQV*<@V*W9@=BX(-JIV+'8KSH@)7,@
M`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#9OMBTV*K;C-BHV*?9
MAB#9OMN,VJG8L=BHV8;8K]N,("5S(-BQV*<@V*W9@=BX(-JIV+'8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@V;[;C-JIV+'8J-F&V*_;C"`E
M<R#8L=BG(-BMV8'8N"#9AMF%V8C8KRX@V+39A=BG(-F%VXP@V*K9B-BGV8;;
MC-BO(-BGV+(@VXS:J=N,(-BGV+(@VJ_8LMN,V8;9A^*`C-F'V*<@V*C8L=BG
MVXP@V*W9@=BX(-JIV*\@V*C8L2#8L=F(VXP@)7,@V*?8L]BJV8'8I]BOV8<@
MV8;9A=BGVXS;C-BO(-F((-N,V*<@V*?;C-F&VJG9AR#8I]BR(-JIV*\@V*C9
MAR#8M=F(V+'8JB#8K]BSV*K;C"#8K]BQ)7,@V+'9B-F&V8C8M-BJ(-BJV8?;
MC-F'(-F&V878I]N,VXS8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=BGV+'8L]BG
MV+(@3$1!4"#8L=BG(-BLV+/8JMBLV8@@VJG8L=BO`-F&V87;C.*`C-BJV8C8
MI]F&(-BJV878I]BS("#8L=BG(-BHV+'9B-BRV+'8L]BGV8;;C"#:J=BQV*\N
M("5S`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,
M(-BQV*<@V*C8L=F(V++8L=BSV*?9AMN,(-JIV+'8KRX@)7,`V8;9A=N,XH",
MV*K9B-BGV88@V8;9B-BGV+$@V*S8I]F&V*C;C"#9A=F(V++;C-F$V*<@V+'8
MIR#9OMN,V*_8IR#:J=BQV*\N(-F%V+?9A=BFV88@V+39B-N,V*\@VJG9AR#9
MAMF(V*?8L2#8K-BGV8;8J-N,(-BHV*?8LB#8I]BSV*H`V878JMF&(-BTV878
MI]BQV+0@V+38K]F'`-JIV+39B-BQ`-BOV8C8L=F'XH",V8?8IP#8I]N,V*S8
MI]BO(-N,VJD@V;[;C-F(V8;8KP#8I]N,V*S8I]BO(-N,VJD@V8'9A]BQV+/8
MJB#8JMF%V*?8LR#8K-BOVXS8KR#8K]BQ.@#8I]N,V*S8I]BO(-N,VJG;C"#8
MK-BOVXS8KP#8I]N,V*S8I]BO(-BRVXS8L=F^V8C8M-F'XH",V8?8IP#8I]N,
MV*S8I]BO(-BTV*_9AP#9A=BLV8C8LMF'V*?;C"#8I]N,V*S8I]BO(-JIV8;9
MAMBOV8<`V+39A=BGV+'9AR#:J=BGV+'8JB#8I]BYV*K8J-BGV+';C`#8L]BG
MV+G8JB#9@=BYV83;C`!54DP@V8'8N=F$VXP@V8?8L]BJ`-BBV*@@V8@@V8?9
MB-BGVXP@V8'8N=F$VXP`V+38L=BGVXS8MR#9@=BYV83;C#H@`-BSV*C:J2#9
M@=BYV83;C`#8L]F!V*?8L=BTVXP@VJG8L=BOV88@V8C8N-BGVXS9@2#9A]F&
MVJ_8I]F%(-F(V+'9B-BO(-BHV8<@)7,`V*C8L=N,V*_9A@#8J-BQVXS8K]F&
M(-BGV8;8JMBNV*?8J`!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`1$0`V+'9
MB-BRV*?9AMF'`-F%V+'9B-BQVJ_8L2#8K]BQV*[8JB#8K]BGV*_9AP#8JMBG
MV+';C-BN`-BJV*?8L=N,V*X@V*_8L=N,V*?9@=BJ(-BTV*_9AP#8JMBGV+';
MC-BN(-BGV8;8JMBNV*?8J`#8L=F(V+(`V*W8L-F!(-BSV*K9B-F&`-BOV+/8
MI]F%V*C8L0#8I]BYV*_8I]BO(-BOV8?8K]F'VXP`VJG9A2#:J=BQV*_9AB#8
MJMF(V+'9@=BJVJ_;C`#9OMN,V+0@V8'8L=BV`-BQV8;:KR#9OMN,V+0@V8'8
ML=BV`-F'V8C;C-F1V*H@V;[;C-BT(-F!V+'8M@#9OMF(V+/8JMF'V90@V;[;
MC-BT(-F!V+'8M@#8K-F'V*H@V878L=BJV*@@V+/8I]BRVXP@V;[;C-BT(-F!
MV+'8MCH`V*K8N=BGV+';C-F!`-BMV+#9@0#8JMBCVXS;C-BO(-BMV+#9@0#8
MK=BPV8$@VJ_8L=F(V8<`V*W8L-F!(-F%V*S9B-BR`-BMV+#9@2#9B"#9OMBG
MVJG8L]BGV++;C"#9OMN,V+K8I]F%V8?8IP#8L=F!V*K8I]BQ(-JIV83;C-BO
M(-BMV+#9@0#8K=BPV8$@V+/9A-F(V80`V*W8L-F!(-BSV*K9B-F&`-BMV+#9
M@2#8I]F$VJ_9B-N,(-BLV*?;C-JOV++;C-F&(-F%V8C8K-F(V*\`V*W8L-F!
M(-F&V*?9A=F(V8'9D=F"(-BHV8C8KSH@*"5S*2`E<P#8K=BPV8$@V878K-F(
MV++9A]BG(-BHV+'8I]N,("`B)7,B`-BBVXS8IR#9A=BLV8C8LMF'V*<@V8@@
MV++;C-BQV878K-F(V++9A]BG(-BHV+'8I]N,("(E<R(@V*W8L-F!(-BTV8C8
MK]B?`-BMV+#9@2#8L]BWV+$`V*W8L-F!(-F'V8C;C-F1V*H@V*?9AMBJV*[8
MI]BH(-BTV*_9AP#8K=BPV8$@V+/8JMF(V88@V8'8N=F$VXP`V*W8L-F!(-BS
MV+?8L2#9@=BYV83;C`#8K=BPV8$@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-BR
MV878I]F&(-BGV+'8L]BGV80`V*?8K]BGV+'9AP#9AMBRV8C9A-N,`-BTV+'8
MK2#9A=BTVJG9A`#8K-BRV9#8IMN,V*?8JCH`(-BLV++8IMN,V*?8JB#8J-BQ
MV*?;C"#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BKV*C8JB#8M-BOV8<@
MV*?8L]BJ`-JOV+/8JMBQV+0`V8;9@MBWV8<@V+38J-F&V84`V8;9@MBWV8<@
MV+38J-F&V84@V*C8L=BGVXP@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@`-F&V8+8
MM]F'(-BTV*C9AMF%.B``V*S9A]BJ(-BGV+(@VH;9OB#8J-F'(-BQV*?8L]BJ
M`-BLV8?8JB#8I]BR(-BQV*?8L]BJ(-BHV8<@VH;9O@#8M-BGV*[9AP#9AMF%
MV*?;C-BT`-BBVXS8IR#8LMF%V*?9AB`R-"#8L]BGV+G8JMF'(-F&V878I]N,
MV+0@V*_8I]BOV8<@V+39B-BOV)\`VJ_8LMN,V8;9A^*`C-F'V*?;C"#9AMF%
MV*?;C-BT`-F&V878I]N,V+0@V*S8LMBFVXS8I]BJ(-F^VXS8M,*MV*C;C-F&
MVXP`V8;9A=BGVXS8M"#9OMN,V+3"K=BHVXS9AMN,`-F&V878I]N,V+0@V8+8
MI]F$V*@`V*W8I]F$V*H@V*K8L-JIV+$`V*W8L-F!(-F&V+39B-BO`-BOV+/8
MJMBQV+/;C"#9A=BSV*K9@MN,V84@V*C9AR!M86EN=&5N86YC92YP:'`@V879
MA=JIV88@V8;;C-BSV*H`V*+;C-BG(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*W8
ML-F!(-F(V+'9B-BOVXSB@(S9A]BG(-BQV*<@V*K8H]N,VXS8KR#:J=F&VXS8
MK]B?`-BBVXS8IR#8L]BWV+$@V*?9B-F$(-BTV*?9A=F$(-F!VXS9A-BO(-F&
MV*?9A2#9A=N,XH",V*C8I]BTV*_8GR#8I]JOV+$@VH;9AMN,V88@V*?8L]BJ
MV(P@V*?;C-F&(-BLV+G8J-F'(-BQV*<@V+G9A-BGV878JB#8J-BRV8;;C-BO
M.@#8I]BSV*K9@MBQV*?8L0#8I]BSV*K9@MBQV*?8L2`E<P#8I]BSV*K9@MBQ
MV*?8L2#9OMN,VJG8L=BHV8;8K]N,(-BJV8C9A-N,V*\@V+38K]F'(-BHV+G9
MAMF(V*?9AB#8K]BSV*H@V8;9B-N,V+,@4$A0`-BGV+/8JMF"V+'8I]BQ('9#
M87)D`-F!V8?8L=BSV*H@V;[8I]N,VXS9AN*`C-F^V+$`V*_8I]BQV8C9A]BG
M`-F&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:J=N,`$524@#9B-N,V+'8I]N,
MV+0`V8C;C-BQV*?;C-BT(-BHV839B-JI`-F(VXS8L=BGVXS8M"#:K]BQV8C9
MAP#9B-N,V+'8I]N,V+0@V878K-F(V+(`V8C;C-BQV*?;C-BT(-F%V*S9B-BR
MV8?8IP#9B-N,V+'8I]N,V+0@V878K-F(V++9A]BG(-BHV+'8I]N,("5S`-F(
MVXS8L=BGVXS8M"#9B-BQV8C8K]N,(-BHV+'8I]N,("5S(`#:K]BRVXS9AMF'
MXH",V8?8I]N,(-F(VXS8L=BGVXS8M#H`V8C;C-BQV*?;C-BT(-F%V*S9B-BR
MXH",V8?8IR#8J-BQV*?;C"`B)7,B`-F(VXS8L=BGVXS8M"#9A=BLV8C8LN*`
MC-F'V*<@V*C8L=BGVXP@)7,`V*K8K=BUVXS9A-BGV*H`V+G9AMBUV+$N+BX`
M16T`V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J0#8HMBOV+'8LR#9AMBGV879
MA]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,`-BBV*_8L=BSV8?8I]N,(-F&V*?9
MA=F'XH",V8?8I]N,(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BHV*?;C-BO(-F%
MV8;8M]BHV8(@V*C8I]BTV*\`V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,
MVJG;C"#8J-BG(-BJV*/;C-N,V*\`V*?8K=BSV*?8L]BGV*H`V*[8I]F$VXP@
MVJG8L=BOV88@V;[;C-BZV*?9A2``V*[8I]F$VXP@VJG8L=BOV88@V8;8JMN,
MV*S9AP#8KMBGV83;C"#:J=BQV*_9AB#9A=F(V*?8L=BO(-BLV+/8JMBLV8@`
MV*+;C-BG(-BOV+'8K"#8JMBUV*?9B-N,V+$@V*?8LB#:K]BGV838L=N,V8?8
MI]N,(-BYVJG8LR#8K]BQ(-F%V*K9AB#9@=BYV*?9A"#8M-F(V*_8GP#8HMN,
MV*<@VJ_8LMN,V8;:K]BGV88@V++9A=N,V8;9AR#8L=F(VXP@VJG9A-N,VJD@
MV+'8I]BSV*H@V8'8N=BGV80@V+39B-BOV)\`V*?9AMBJV8?8I]N,(-BSV*?9
MA`#8J-BRV+':KR#:J=BQV*_9AB#9B-N,V+'8I]BSV*K8I]BQ`-N,VJD@V+/8
MIMF(V*?9A"#8I]F%V8;;C-BJVXP@V*C8L=BGVXP@V;[8L=BSV+0@V*?8LB#8
MM-F%V*<@V*C9AR#9A]F&VJ_8I]F%(-BHV*?8LMF&V+38I]F&V*_9AB#8I]BS
MV84@V+'9A=BR(-F(V*?8L=BO(-JIV8;;C-BOV(P@V878J]F$V*?9DB`GV8;8
MI]F%(-BMVXS9B-BGV88@V*[8I]F&VJ_;C"#8M-F%V*<@VH;;C-BSV*K8GR<`
M55),(-BJV+79B-N,V+$@V+'8IR#8I]N,V8;8K-BG(-F(V*?8L=BO(-JIV8;;
MC-BO`-F(V+'9B-BOVXP@V*C8L=BGVXP@)7,@V*C8L=F(V++8L=BSV*?9AMN,
M(-BTV*\@V*?9A=BG(-BMV8'8N"#9OMBQV8C9AMBOV8?9E"#8I]BQV+/8I]F$
M(-BTV*_9AR#9AMBGV879B-F!V9'9@B#8J-F(V*\Z("5S`-F(V+'9B-BOVXP@
MV*C8L=BGVXP@)7,@V*C8L=F(V++8L=BSV*?9AMN,(-BTV*\`V8C8L=F(V*_;
MC"#8J-BG(-F%V8C9@=F"VXS9D=BJ(-BMV+#9@2#8M-BO`-BNV+?8IP#8J-F$
MV8C:J2#8I]N,V*S8I]BO(-BNV+?8ISH@)7,`V*[8M]BG(-BOV+$@VJG8L]BH
M(-F%V*W8JMF(V*<Z)7,`V*[8M]BG(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,
M(-BGV+/9A2#8L=F%V+(@.B`E<P#8KMBWV*<@V*C8IR#9OMN,V+K8I]F%(-F&
MV*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXP`V+G8JMN,V8+9AP#8I]BQ
MV8C9OMBG`-F'V+$@V;[8I]F&V++8K]F'(-BOV8+;C-F"V8<`V8?8L2#8K]F(
M(-BOV8+;C-F"V8<`V8?8L2#8L]N,(-BOV8+;C-F"V8<`V8?8L2#9OMF&V*P@
MV*_9@MN,V8+9AP#8K]BQ(-F'V+$@V8C8L=F(V*\`V8?8L2#9AMN,V84@V+/8
MI]BYV*H`V8?8L2#8K]F"VXS9@MF'`-F%V8+8I]BOVXS8L2#9A=BKV*?9A#H`
MV*?8K-BQV*<`V*C8I]BR(-JIV+'8K]F&`-BHV*?8LMJIV+'8K]F&(-F&V8C8
MI]BQ(-JIV8;8I]BQVXP`V*?9AMBJV+C8I]BQ(-BHV+'8I]N,("<H)P#8JMBG
MV+';C-BN(-BGV8;9@MBVV*?8H0#9AMF%V*?;C-F&V*_9AP#8J-BQV8C9AN*`
MC-BHV+'8KP#8J-BQV8C9AN*`C-BHV+'8KR#:J=BJV*?8J-J&V8?9E"#8HMBO
MV+'8LP#8J-BQV8C9AN*`C-BHV+'8KR#8I]BWV838I]BYV*?8JB#8JMF%V*?8
MLR#8I]F&V*K8KMBGV*C;C`#8J-BQV8C9AN*`C-BHV+'8KR#:J=BJV*?8J-J&
MV8?9E"#8HMBOV+'8LR#8LMN,V+$@V*C8M]F(V+$@VJG8I]F%V80`V+'9AMJO
M(-F^VXS8M.*`C-BRV87;C-F&V8<`1E10('5P;&]A9"!O9B!S971U<``@V*C8
MI]BRVXS8I]BHVXP@V*K9@MBOV878I]BJ(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKP#8K]BSV*K8L=BSVXP@V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#9
MAMBGV879B-F!V9'9@B#8J-F(V*\Z("5S`-BGV+;8I]F!V8<@VJG8L=BOV88@
M)7,@V*C9AR`E<R#9AMBGV879B-F!V9'9@B#8J-F(V*\Z("5S`-F%V+'9B-BQ
M(-F!V8?8L=BSV*H@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-F%V+'9B-BQ(-BT
MV*?8KMF'(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP#8JMBZVXS;C-BQ(-F&V*?9
MA2#9AMBGV879B-F!V9'9@B#8J-F(V*\Z("`H)7,I("5SV)L@1$X@V8+8J-F$
MVXP]("5S(-B,($1.(-BLV*_;C-BO/2`E<R#8C"#8L=N,V+39AST@("5S`"#8
MI]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR($Q$05`@V8;8I]F%V8C9@=F1
MV8(@V*C9B-BO`"#8I]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR(%--0B#9
MAMBGV879B-F!V9'9@B#8J-F(V*\@`"#8JMF'VXS9AR#8L=F(V8;9B-BTV*H@
MV*?8LB`B)7,B(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP#8I]N,V*S8I]BO(-BQ
MV8C9AMF(V+38JB#8K]BQ("(E<R(@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`"#8
MI]N,V*S8I]BO(-N,VJD@V*?8JMBUV*?9A"#8K-BOVXS8KR!305-,(-F&V*?9
MA=F(V8'9D=F"(-BHV8C8KP#9OMN,V*_8IR#:J=BQV*_9AB#8M-N,V*$@V*?8
MMMBGV8'9A^*`C"#8M-BOV8<@V8;8I]F%V8C9@=F1V8(@V*C9B-BO.B`E<P`@
MV*?9AMBJV8+8I]F$(-BHV8<@(B5S(B#9AMBGV879B-F!V9'9@B#8J-F(V*\`
MV*S8L]BJV*S9B-N,(-BTV*?8KMF'(-F&V*?9A=F(V8'9D=F"(-BHV8C8KSH@
M)7,`V838M]N,V8$`V*[8M]BGVXP@V*S8K]N,.B``V*_9B-BQV8;:K]BGV+$`
MV8'9B-BQVXS9AP#8L=JOV*C8I]BQ(-BNV8';C-F!`-JIV87;C"#8JMJOV+':
MKP#8M-F%V*?8L=BT(-F^V+'9B-F&V*_9ASH@)7,@V;[8L=F(V8;8K]F'`-BT
MV878I]BQV+0@V;[8L=F(V8;8K]F'.B`E<R#9OMBQV8C9AMBOV8<`V878K]N,
MV+$@V;[8L=F(V8;8K]F'`-F&V*?9A2#9OMBQV8C9AMBOV8<`V*?9AMBJV*[8
MI]BH(-F^V+'9B-F&V*_9AP#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AP#8I]BQ
MV+/8I]F$(-F^V+'9B-F&V*_9AR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`
MC-BTV8C8KRXN`-F^V+'9B-F&V*_9A^*`C-F'V*?B@(P`V8';C-F$V*K8L=F'
MV*<`V;[;C-BOV*?:J=BQV*_9A@#8KMBGV*K9A=F'`-F&VXS9A=F'(-BGV8C9
MA`#9AMBGV84`V+'8J-BY(-BGV8C9A`#9AMBSV*C8JB#8J]BGV*C8J@#8I]BY
MV+38I]BQVXP`V879A^*`C-BBV839B-BO`-F^V8C8M-F'("5S(-F%V8C8K-F(
MV*\@V8;;C-BSV*H@`-BQV8;:KR#9@MF$V84`V+K8L-BG`-BHV+'8I]N,(-F%
MV+'9B-BQVJ_8L=F'V*?;C-N,(-JIV8<@V*K8M=BGV8C;C-BQ(-BQV*<@V;[8
MM-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V8;8KP#9OMN,V+3"K=BHVXS9
MAMN,`-BGV+/9A2#8L=F%V+(@V*[9B-BO(-BQV*<@V8'8L=BGV879B-BT(-JI
MV+'8K]F'XH",V*?B@(S;C-BOV)\`V8'8L=F%V8?8IP#8M]BGV838N0#9AMF(
MV+D@V+?8I]F$V+D`V+?8I]F$V+G9A]BG`-BWV*?9A-BYV8?8IR#;L@#8I]F&
MV*S9A=F&V8?8IP#8I]BQV*S8I]BYV8?8IP#8K-F%V+G9AP#:AMBGV+':AMF(
MV*C9A]BG`%523"#8HMBRV*?8KR_9A=BTV+K9B-F$`-BGV+(`V*?8LB``V+38
ML=BM(-JIV*?9A=F$`-F%V*?9AR#:J=BGV879A`#9AMBGV84@VJG8I]F%V80`
MVJ_8I]F$V+';C"#8J-BQV*?;C"#8K]BQVXS8I]F!V*H@V*K8M=F(VXS8L2``
MVJ_8I]F$V+';C#H`V*K9B-F$VXS8KR#9OMN,VJG8L=BHV8;8K]N,("5S`-JI
MV*\@V*K9B-F$VXS8KR#8M-BOV8<`V8;8I]F%(-BOV*?8K]F'(-BTV*_9AP#:
MJ=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8L]BQV*?8L]BQVXP`V*C8L=F(`-BL
MV+/9AMBLV8C;C"#:K]F(VJ_9A`#8K]BQV*S9AR#8KMBGVJG8L]BJV+';C`!'
M<F5E:R`H25-/+3@X-3DM-RD`VJ_8L=F(V8<`V+/8L=F^V+'8L]BJVXP@VJ_8
ML=F(V8<`V8;8I]F%(-JOV+'9B-F'(-F&V*C8I]N,V*\@V*[8I]F$VXP@V*C8
MI]BTV*\`VJ_8L=F(V8<F(W@R,#!C.]F'V*<`V878K-F(V++9A]BGVXP@V879
MA]F%V*?9A@#:J=BJV*?8J-J&V8?9E"#;C-BGV*_8J-F(V*\`2%1-3`!(5$U,
M07)E82#8K=BPV8$@V*+8KMBQVXS9AB#8L]F$V8C9A"#8L=BG(-BOV+$@V+'8
MK]N,V8$@V+'8KR#9A=N,XH",VJG9AMBO`$A434Q!<F5A(-BMV+#9@2#8HMBN
MV+';C-F&(-BSV*K9B-F&(-BQV*<@V*_8L2#8K-BOV8C9A"#8L=BO(-F%VXSB
M@(S:J=F&V*\`2%1-3$%R96$@V*W8L-F!(-BBV*[8L=N,V88@V+'8K]N,V8$@
MV+'8IR#8K]BQ(-BLV*_9B-F$(-BQV*\@V87;C.*`C-JIV8;8KP#8JMBUV*_;
MC-F"(-F'V8C;C-F1V*H@2%144"#;C-BGV8'8JMF'(-F&V+38KP#8I]F$VJ_9
MB-BQVXS8JMF%($AA<V@`V879A^*`C-BBV839B-BO`-BSV+'8HMF%V*\`2&5B
M<F5W("A)4T\M.#@U.2TX+4DI`-BHV839AMBOVXP`V+'8I]F'V8;9A=BG`-BQ
MV*?9A]F&V878I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V8C;C-BQV*?;C-BT
MVJ_8L0#:J=F%VJD@VJG9AMF&V*_9AP#9AMN,V87B@(S:J=BQV8<`V*?;C-F&
MV*S8IR#8I]BHV*K8K]BGVXP@V;[8L=F(V8;8K]F'XH",(-F%VXSB@(S8J-BG
MV+38KSH`V*C8I]F$V*<`V*[8I]F&V8<`V*[8I]F&V8<`V*+8K]BQV+,@V879
MAMBRV80`V+39A]BQ(-F%V*W9A"#8L]JIV8C9AMBJ`-JIV+39B-BQ(-F%V*W9
MA"#8I]F"V*?9A=BJ`-BTV*?8KMF'V90@V*?8M=F$VXP`V+39A=BGV+'9AR#8
MJMF$V8'9AB#9A=F&V++9A`#:J=BO(-F^V+/8JMN,(-F%V*W9A"#8L]JIV8C9
MAMBJ`-BGVXS8I]F$V*HOV*?8L]BJV*?9AB#9A=BMV80@V+/:J=F(V8;8J@#8
MHMBOV+'8LR#8KMN,V*?8J-BGV88@V878K=F$(-BSVJG9B-F&V*H`V8?9B-BQ
MV*\`2&]R9&4O2V]L86(Z("5S(-BHV*<@V*_8I]BOV8<@V8;8I]BOV+'8L]BJ
M(%A-3"#8K]BQ(-F^VXS8NMBGV84@)7,@V879B-BGV*S9AR#8M-BOV8<@V*?8
ML]BJ`$AO<F1E+TMO;&%B.B#9A]N,VH8@V;[;C-BZV*?9A=N,(-F%V+?8I]BH
MV8+8JB#8J-BG(-BTVXS8H2`E<R#9AMBOV*?8L=BO`$AO<F1E+TMO;&%B.B#9
MA]N,VH8@V+3;C-BFVXP@V*?8LB#9AMF(V+D@)7,@V*_8L2#9OMN,V+K8I]F%
M("5S(-N,V*?9@=BJ(-F&V+38KP!(;W)D92]+;VQA8CH@V*C8IR#9A=F(V8'9
MD=F"VXS9D=BJ("5S("(E<R(@V*W8L-F!(-BTV*\`2&]R9&4O2V]L86(Z(-BJ
MV8C9A-N,V*\@VXS:J2#8K]BQV*[8JB#8K-BOVXS8KR!834P@V*C8L=BGVXP@
MV+3;C-BA("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@`$AO<F1E+TMO;&%B.B#8
MK=BPV8$@)7,@(B5S(CHE<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ`$AO<F1E+TMO
M;&%B.B#8J-BGV++;C-BGV*C;C"`@34E-12!)1"#8J-BQV*?;C"#9@MBSV878
MJMN,(-BGV+(@V8;9B-BY("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@`$AO<F1E
M+TMO;&%B.B#8L]F&VJG8L=F(V88@VJG8L=BOV88@)7,@(B5S(CH@)7,@V879
M@MBOV8C8L2#9AMN,V+/8J@!(;W)D92]+;VQA8CH@V+/9AMJIV+'9B-F&(-JI
MV+'8K]F&(-BGV+38JMBQV*?:J=F'V*<@V879@MBOV8C8L2#9AMN,V+/8JCH@
M)7,`2&]R9&4O2V]L86(Z(-BGV+38JMBQV*?:J2#9AMBGV+39AMBGV*[8JMF'
M("(E<R(`V8+8I]F&V8C9AB#8I]F!V8+;C`#9@=BGV+79A-F'XH",VJ_8L-BG
MV+';C"#8I]F!V8+;C``ZV*?9@=F"VXP`VH;:K]F(V8;9AR#8J-BG(-BGVXS9
MAMBLV*<@V*+8M-F&V*<@V+38K]N,V*_8GR`HV838M]F!V*?9BR#:K]BRV*?8
ML=BT(-BOV8?;C-BO*2$`VH;9AMBO(-BSV*K9B-F&(-BQV*<@V87;C.*`C-BN
MV8C8I]F'VXS8KR#8I]BOV+K8I]F%(-JIV8;;C-BOV)\`VH;9AMBO(-F!VXS9
MA-BO("C8L]BJV8C9ABD@V8C8K-F(V*\@V*_8I]BQV*_8GP#:AMF&V*\@V+/8
MM]BQ(-BQV*<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BOV+K8I]F%(-JIV8;;
MC-BOV)\`V+'8M]F(V*C8J@#8L=BWV8C8J-BJ.B``V*?;C-BLV*?8KR#9AMBG
MV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8KSH@("5S
M`-BMV+#9@2#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"
M(-BHV8C8KR`Z("5S`-BGVXS8K-BGV*\@V878K=BOV8C8K]N,V9'8JB#9AMBG
MV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR`Z("5S
M`$E-4U``V*+8K]BQV+,@25``V*+8K]BQV+,@25`@V8+8I]BHV80@V*_8L]BJ
MV+'8L]N,(-F&VXS8L]BJ`-BBV*_8L=BS($E0(-BOV+$@V*_8I]BNV80@V*C9
MA-F(VJD@0TE$4B#8I]BLV*?8LMF'(-BOV*?8K]F'(-F&V87;C.*`C-BTV8C8
MKP#8I]BHV*K8K]BG(-BSV+?8L2#8L=BG(-F(V*?8L=BO(-JIV8;;C-BO`-F!
MV8+8MR#8HMN,VJG9B-F&V8?8IP#8HMN,VJG9B-F&V8?8IR#8J-BQV*?;C"`E
M<P#8HMN,VJG9B-F&V8?8IR#8J-BG(-F%V*K9A@#9AMBGV84@V8?9B-N,V9'8
MJCH`V*?:K]BQ(-BBV88@V*C9AR#8K]BQV+/8JMN,(-F&V878I]N,V+0@V*_8
MI]BOV8<@V8;8M-BOV(P@)7,@(-BHV+'8I]N,(-BHV*?8LB#:J=BQV*_9AB#8
MHMF&(-BOV+$@VXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO`-BGVJ_8L2#8M-F%
MV*<@V8?;C-J&(-BBVXS:J=F(V8;;C"#8L=BG(-BOV+$@V878L=F(V+':K]BQ
M(-F&V*C;C-F&VXS8K]B,(-F%V87:J=F&(-BGV+/8JB#9A-BGV++9A2#8J-BG
MV+38KR#:J=F'(%!.1R!4<F%N<W!A<F5N8WD@V+'8IR#8KMBGV879B-BT(-JI
MV8;;C-BO`-BGVJ_8L2#8M-F%V*<@V*?;C-F&(-F^VXS8NMBGV84@V+'8IR#9
MA=BTV*?9A]BOV8<@VJG9AMN,V*\@V*?9A=BG(-BJV+79B-N,V+';C"#8L=BG
M(-F%V+38I]F'V*_9AR#9AMJIV8;;C-BOV(P@V*?;C-F&(-BHV8<@V*?;C-F&
M(-BYV838JB#8KMF(V*?9A]BO(-BHV8C8KR#:J=F'(-F%V+'9B-BQVJ_8L2#8
MM-F%V*<@V8'8I]BOV+$@V*C9AR#9AMF%V*?;C-BT(-BJV+79B-N,V+$@V8;;
MC-BSV*H@`-F^VXS8M.*`C-F&V878I]N,(-BJV+79B-N,V+$Z`%523"#8JMBU
MV8C;C-BQ`%523"#8JMBUV8C;C-BQ.@#8JMBUV8C;C-BQ(-BGV+(@VJ_8I]F$
MV+';C`#8JMBUV8C;C-BQ(-BGV+(@VJ_8I]F$V+';C#H`V*?8L=BSV*?9A"#8
MJMBUV8C;C-BQ`-BJV+78I]F(VXS8L0#8K]BQV8C9AN*`C-BHV+'8KR#:J=BJ
MV*?8J-J&V8?9E"#8HMBOV+'8L]B,(-JOV*?9A2`E9`#8K]BQV8C9AN*`C-BH
MV+'8K]B,(-JOV*?9A2`E9`#8K]BQV8C9AN*`C-BHV+'8KR_8J-BQV8C9AN*`
MC-BHV+'8KR#:J=BJV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,`V8';C-F$
MV*\@V*_8L=F(V8;B@(S8J-BQV*\@V+38K]F'.B`E<P#9@=N,V838K^*`C-F'
MV*?;C"#8K]BQV8C9AN*`C-BHV+'8KR#8M-BOV8<Z`-BHV+G8K]BGV8L@V+/8
MM]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\`VJG8KR#8N=F%V83:J=BQV*\@
MV8;8I]BOV+'8L]BJ(-BOV*?8K]F'(-BTV*_9AR#8I]BSV*H`(-F&V*?9A2#:
MJ=BGV+'8J-BQ+]BGV+/9A2#8L=F%V+(@(-F&V*?8K]BQV+/8JB#8I]BSV*H`
MV8;8I]F%(-JIV*?8L=BHV+$@VXS8IR#8HMBOV+'8LR#8K-BGVXS:K]BRVXS9
MAB#9AMBGV*_8L=BSV*H@V87;C.*`C-BHV*?8M-BO+B#9A-BWV8'8IR#9A=BL
MV*_8K]BGV9(@V+/8N=N,(-JIV8;;C-BO(-F((-N,V*<@V*_8L2#8M=F(V+'8
MJB#9AMN,V*?8LB#8J-F'(-JIV87:J2#8J-N,V+38JMBQ(-BHV*<@V+/8L=F^
MV+'8L]BJ(-BSV*?9A=BGV8;9AR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\`V*?9
M@=BRV*?;C-BT(-BJV8C8L=F!V*K:K]N,`-JIV*?8L=BHV+'8I]F&(-BNV*?8
MM0#8I]BWV838I]BYV*?8J@#8I]BWV838I]BYV*?8J@#8I]BWV838I]BYV*?8
MJB#8K]N,VJ_8L2#8K]BQ(-BOV+/8JMBQV+,@V8;;C-BSV*H`V*_8L=BL(-BS
MV*K9B-F&(-BHV+G8KR#8I]BR`-BOV+'8K"#8JMBUV8C;C-BQ`-BOV+'8K"#8
MK-BOV8C9A`#8K]BQV*P@V;[;C-F(V8;8KR#9B-BH`-BGV*C8JMBOV*<@V+/8
MJMF(V88@V+'8IR#8K]BQV*P@VJG9AMN,V*\`VXS:J2#8L]BJV8C9AB#8K-BO
MVXS8KR#8J-BYV*\@V*?8LB#8L]BJV8C9AB#9@=BYV83;C"#8K]BQV*P@VJG9
MAMN,V*\`VXS:J2#8L]BJV8C9AB#8K-BOVXS8KR#9@MBHV80@V*?8LB#8L]BJ
MV8C9AB#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\`VXS:J2#8L]BWV+$@V*S8
MK]N,V*\@V*C8N=BO(-BGV+(@V+/8M]BQ(-F!V+G9A-N,(-BOV+'8K"#:J=F&
MVXS8KP#;C-JI(-BSV+?8L2#8K-BOVXS8KR#9@MBHV80@V*?8LB#8L]BWV+$@
MV8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO`-N,VJD@V;[8I]BQV*?:K]BQV*?9
M@2#8J-BYV*\@V*?8LB#:K]BQV8<@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO
M`-N,VJD@V;[8I]BQV*?:K]BQV*?9@2#9@MBHV80@V*?8LB#:K]BQV8<@V8'8
MN=F$VXP@V*_8L=BL(-JIV8;;C-BO`-BOV+'8K"#8I]F$VJ_9B-N,(-BLV*?;
MC-JOV++;C-F&`-N,VJD@V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&
MVXS:J2#8J-BQV*?;C"#8K]BQVXS8I]F!V*H@V*?8L]F%(-BQV878LB`@V*S8
MK]N,V*\@V*_8L=BL(-JIV8;;C-BO(`#8K]BQV*P@V+/9A-F(V80@V*C8N=BO
M`-BOV+'8K"#8L]F$V8C9A"#9@MBHV80`V*_8L=BL(-BSV*K9B-F&(-BHV+G8
MKP#8K]BQV*P@V+/8JMF(V88@V8+8J-F$`-BOV+'8K"#9OMN,V+K8I]F%`-BO
MV+'8K"#9OMBGV+'8I]JOV+'8I]F!(-BHV+G8KP#8K]BQV*P@V;[8I]BQV*?:
MK]BQV*?9@2#9@MBHV80`V*_8L=BL(-BSV+?8L2#8J-BYV*\@`-BOV+'8K"#8
ML]BWV+$@V8+8J-F$`-F^V*?8L]BN(-F%V8C8L=BO(-F&VXS8I]BR(-BQV*<@
MV*C8L=BGVXP@V+/8IMF(V*?9A"#8I]F%V8;;C-BJVXP@V*_8L=BL(-JIV8;;
MC-BO.@#8K]BQV*POV*K8NMN,VXS8L2#8JMBUV8C;C-BQ`-BOV+'8K"_8JMBZ
MVXS;C-BQ(-F^VXS9B-F&V*\`V*?8N=BJV*C8I]BQ(-F&V*?:J=BGV8';C"#8
MJ-BQV*?;C"#8I]BQV+/8I]F$(-BHV8<@V8'9A]BQV+/8JB#8JMF(V++;C-BY
MVXP`V*?8N=BJV*C8I]BQ(-F&V*?:J=BGV8';C`#8N=BOV*\@V+78K=N,V*T`
MV8'9A]BQV+/8JB#8N=BOV*\@V+78K=N,V*T`240@V8;8I]F%V+G8JMBHV+$`
M541((-F&V*?9A=BYV*K8J-BQ`-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F&
MV*?9A=BYV*K8J-BQ`-BHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(-F&
MV*?9A=BYV*K8J-BQ`-BOV+/8JMF'($E$(-F&V*?9A=BYV*K8J-BQ`-BOV*?8
MK]F'V90@V8;8I]F%V+G8JMBHV+$@V*?8L=BGV*;9AR#8M-BOV8<`V*+8K]BQ
MV+,@V879@MBUV*\@V8;8I]F%V+G8JMBHV+$`V;[8L]BJ(-BGV83:J=BJV+'9
MB-F&VXS:J=N,(-F&V*?9A=BYV*K8J-BQ`-F(V+'9B-BOVXP@V8;8I]F%V+G8
MJMBHV+$`V8+8I]F$V*@@V;[8L=F(V8;8K]F'V90@V8;8I]F%V+G8JMBHV+$`
MVJG9A-N,V*\@V8;8I]F%V+G8JMBHV+$@V878M-BNV+4@V+38KP#9AMF(V+D@
MV;[;C-BZV*?9A2#9AMBGV878N=BJV*C8L0#9AMBGV84@V8;8I]F%V+G8JMBH
MV+$`:60@V+3;C-BA(-F&V*?9A=BYV*K8J-BQ`&%P:5]I9"#9AMBGV878N=BJ
MV*C8L2#8I]BSV*H@V8@@VXS8IR#8I]BR(-BHVXS9AB#8L=F!V*K9AR#8I]BS
MV*H`V;[8I]BQV*?9A=BJV+$@V8;8I]F%V+G8JMBHV+$@V8@@VXS8IR#8I]BR
M(-BHVXS9AB#8L=F!V*K9AP#9A=BLV8C8LB#9OMBOV+$@V8;8I]F%V+G8JMBH
MV+$`V;[8L=F(V*K:J=F$(-F&V*?9A=BYV*K8J-BQ`-JOVXS8L=F&V*_9A]F4
M(-F&V*?9A=BYV*K8J-BQ.B`B)7,B`-BTVXS8H2#8J-F'(-BGV+38JMBQV*?:
MJ2#:K]BPV*?8M-BJV8<@V+38K]F'V90@V8;8I]F%V+G8JMBHV+$`V*+8K]BQ
MV+,@V+/8L=J&V+39A=F'(-F&V*?9A=BYV*K8J-BQ`-BOV*?8K]F'(-N,V8C9
MAMN,VJG8KR#9AMBGV878N=BJV*C8L2``V879B-BLV8C8K]N,`-BHV+':K]BQ
MV*_8I]F&V*_9AB#8I]F&V*K8KMBGV*@`5"U3=&]R;7,`V879AMBJV+38L2#:
MJ=F&V8;8K]F'`-BMV+'9B-F!(-JIV*P`VIC8I]F&V8C;C-F'`$IA<&%N97-E
M("A)4T\M,C`R,BU*4"D`V++;C-BQV;[;C-BQV*?9A]F&VXP`VIC9B-BFVXS9
MAP#:F-F(V*;9A@#9A]F%XH",V*K8L=BGV+(@VJG8L=BOV88`V8?9A>*`C-BJ
MV+'8I]BRVXP@V8C8L]BW`-F'V87B@(S8JMBQV*?8LMN,(-JIV*?9A=F$`-F'
MV87B@(S8JMBQV*?8LMN,(-J&V;X`V8?9A>*`C-BJV+'8I]BRVXP@V+'8I]BS
MV*H@`-BGV+79A-N,(-F&VJ_9AR#8K]BGV+38JMF'(-BTV8C8K]B?`-JIV*?8
ML=BSV*?8LB!K97)B97)O<V4@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BQV*<@
MV+'8KR#:J=BQV*\`V*?;C-BLV*?8KR#:J=F$VXS8KP#8I]BKV+$@V*?9AMJO
MV+38JB#:J=F$VXS8KP#8M]F(V80@VJG9A-N,V*\`V8;9B-BY(-JIV83;C-BO
M`-JIV*?8L=BHV+'8KR#:J=F$VXS8KP#:J=F$VXS8KR#9@MBHV838I]F+(-BO
MV+$@VJG8I]BQV+/8I]BR(-BYV879B-F%VXP@VJG9A-N,V*\@V879B-BLV8C8
MKR#8I]BSV*H`XH",V*C:AMF'XH",V8?8IP!+;W)E86X@*$550RU+4BD`V;[8
MM-BJVXS8J-BGV8;;C"!,1$%0(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8JBX@
MV*?9A=BG(-F%V*_9B-F$($Q$05`@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&
MVXS8L]BJ(-F((-N,V*<@V*?;C-F&VJG9AR#8J-BGV+$@V8;8M-BOV8?B@(S8
MI]BSV*HN`-BLV*?9AMF%V*?;C-N,`-BRV*C8I]F&`-F&VXS9A=F'V90@V*+8
MKMBQ`-BBV*[8L=N,V88@V*?8M=F$V*?8K0#9AMBGV84@V*[8I]F&V8C8I]BO
MVJ_;C`#8JMBZVXS;C-BQ(-BBV*[8L=N,V88@V*?8L]F%(-BQV878L@#8L=BH
MV+D@V*+8KMBQ`-BBV*[8L=N,V88@V*C8L=F(V++8L=BSV*?9AMN,.@#8HMBN
MV+';C-F&(-F(V+'9B-BO.B`E<P#8HMBNV+';C-F&(-F(V+'9B-BO(#H@)7,@
MV*?8LB`E<P#8HMBNV+';C-F&(-F(V+'9B-BO.B#9A]BQVJ_8L@#8K=F"V8C9
M@@#8K-BGV8;9A=BGVXS;C`#:AMF^`-BSV+'8HMF%V*\@VH;9O@#9A=F"V*?8
MK]N,V+$@VH;9O@#9AMF%XH",V8;9A2#8J-BGV+'8I]F&`-BHV*?8L=F&V*_:
MK]N,(-BSV*C:J0#8J-BGV+'9AMBOVJ_;C"#8L]BHVJD@V++9B-BOV8?9AMJO
MV*?9A0#8J-BGV+'9AMBOVJ_;C"#8L]BHVJD@V*_;C-BQV8?9AMJOV*?9A0#8
MJ-BGV+'9AMBOVJ_;C"#9B"#8L=JOV*C8I]BQ(-BSV*C:J0#8J-BGV+'8I]F&
M(-BSV*C:J2#8J-F'(-F'V878L=BGV8<@V+'8N=BO`-BHV+'9@2#8L]BHVJD`
MV*C8L=F!(-F((-BQVJ_8J-BGV+$@V+/8J-JI`-F^VXS9B-F&V*\`V8;9@MBG
MV+<@V;[;C-F(V8;8KR#8J-F'.@#8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8
ML=F(V8;;C-JI(-BQV*<@V*C9AR#8M=F!V*W9AR#8I]N,V*S8I]BO(-F^VXS8
MNMBGV878C"#8J-F'(-F'V8;:K]BGV84@V878M-BGV8?8K]F'V(P@V;[;C-F(
MV8;8KR#8K]F'VXS8KP#9OMN,V8C9AMBOXH",V8?8IP#:J=F(VJG;C"#9A-N,
MV8;9B-JIV+,`V8'9A]BQV+/8J@#9@=F'V+'8L]BJ("T@VJG8I]BQV*C8L2#9
MA=N,XH",V*K9B-BGV8;8KR#9OMF(V+39AR#8L=BG(-BHV*C;C-F&V*\`V8'9
MA]BQV+/8JB#8K]BGV*_:K]BGV8;9A]BGXH",`-F!V8?8L=BSV*H@V+G9AMBG
MV8C;C-F&(-BQV*?9A]F&V878IP#9@=F'V+'8L]BJ(-BLV*_8I]F(V80`V8'9
MA]BQV+/8JB#8HMBQV+3;C-F(`-F!V8?8L=BSV*H@V+'8I]F'V8;9A=BG`-F!
MV8?8L=BSV*H@260`V8'9A]BQV+/8JB#9A=BGV83:J0#9@=F'V+'8L]BJ(-F^
MV+/8JMN,`-F!V8?8L=BSV*H@V+G8MMF(VXS9D=BJ`-F!V8?8L=BSV*H@V+G8
MK]F%(-BYV+;9B-N,V9'8J@#9@=F'V+'8L]BJ(-JIV*?8L=BHV+'8I]F&(-F!
MV+G8I]F$(-F&V87;C.*`C-BHV*?8M-BO`-BGV*_8J-N,V*?8J@#8J-BGV+':
MJ=BQV*_9ABXN+@#8L]BGV+G8JB#9A=BMV83;C#H@`-F%V*W9A-N,V9'8JB#9
MB"#8L]BGV+G8J@#9A=F(V8+8N=N,V*H`V8C8L=F(V*\`V*[8L=F(V*P`V8C8
ML=F(V*\`V8C8N-BGVXS9@2#9B-BQV8C8KP#9B-BQV8C8KR#9AMBGV879B-F!
MV9'9@B#8J-F(V*\@V++;C-BQV*<@V8;8I]F%(-JIV*?8L=BHV+$@V8@@VXS8
MIR#8I]BSV84@V+'9A=BR(-F(V*?8L=BO(-BTV*_9AR#8I]BTV*K8J-BGV8<@
MV*C9B-BO(`#9B-BQV8C8KR#9AMBGV879B-F!V9'9@B#8J-F(V*\N`-F%V*K9
MAB#8J-F$V8;8KP#8N=BTV8(`V;[8I]N,VXS9A@#8K=BQV8C9@2#:J=F(VH;:
MJ2#;C-F(V8;8I]F&VXP`V*W8L=F(V8$@VJG9B-J&VJD@V838I]BJVXS9A@#8
MI]BYV*_8I]BO(-JIV8C:AMJI(-N,V8C9AMBGV8;;C`!-30#9OMN,V+K8I]F%
M(-BQV8C8L@#9OMN,V8C8L]BJ($U3+51.148@V+38I]F%V80@V8?;C-J&(-BO
MV*?8K]F'XH",V*?B@(S;C-N,(-F&VXS8L]BJ`$U31P#8K-BGV*_9B`#9AMBG
MV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C`#8L]BQV;[8L=BSV*H@V8;8I]F%
MV8<`V+/8I]BNV*K9AB#9OMN,V8C9AMBO+BXN`-F%V*_;C-BQVXS8JB#9B"#8
MJMBYVXS;C-F&(-BQV8;:KR#8K]BSV*K9A^*`C-F'V*?;C-N,(-JIV8<@V+39
MA=BG(-F%V8C8I]BQV*\@V+'8IR#8J-BG(-BBV8;9A]BG(-F&V*?9A>*`C-JO
MV+#8I]BQVXP@V87;C.*`C-JIV8;;C-BO`$UA<#(T(&UA<`!-87!1=65S="!M
M87``V878I]BQV+,`V*W8I]BTVXS9AP#8N=F$V*?9A=BJ(-JOV+#8I]BQVXP@
MV*C8IR#9OMBQVH;9A2#9A=BTV*?9A]BOV8<@V+38K]F'+R#9A=BTV*?9A]BO
MV8<@V8;8M-BOV8<`(-BYV838I]F%V*H@VJ_8L-BGV+';C"#8J-BG(-BYV838
MI]BFV84@V*_;C-JOV+$@*-F%V*?9AMF&V*\@V879A]F%+]F^V*?8L]BN(-BO
MV*?8K]F'(-BTV*_9ARD`V*K8M]BGV*C9@@#9@=N,V838K^*`C-F'V*?;C"#8
MI]F&V+?8J-BGV8(`V*C;C-BTVXS9AMF'(-BGV+G8JMBHV*?8L2#9A=BLV*?8
ML@#8JMBNV+?;C"#8I]BR(-BHVXS8M-N,V8;9AR#9@MBSV878JMF'V*?;C"#9
MOMN,V+K8I]F%`-BHVXS8M-N,V8;9AR#8K]F%V*<@V*_8L2#;LMNT(-BSV*?8
MN=BJ(-JOV+#8M-BJV8<Z(`#8J-N,V+3;C-F&V8<@V*_9A=BG(-BOV+$@V[8@
MV+/8I]BYV*H@VJ_8L-BTV*K9ASH@`-BHVXS8M-N,V8;9A]F4(-BJV+G8K]BG
MV*\@V*K9A=BGV+/9A]BG`-BHVXS8M-N,V8;9AR#8M]F(V80`V*C;C-BTV8K9
MAMF'V90@V*K8N=BOV*?8KR#8M=F!V*W8I]BJ`-F%VXP`V;[8LMBTVJG;C`#8
MI]BYV+;8I]BA`-F!V8?8L=BSV*H@VJ_8LMN,V8;:K]BGV88`V878KR#:K]BR
MVXS9AMJOV*?9AMN,.@#8I]BOV+K8I]F%(-BSV839B-F$V8?8IP#9OMN,V+K8
MI]F%`-F^VXS8NMBGV84@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV*?8LMBH
MVXS9AMN,(-BTV*\@V*?9A=BG(-JOV8C8I]F'VXP@V*?9A=BVV*?8H2#:J=F&
MV8;8K]F'(-F&V87;C.*`C-BJV8C8I]F&V*\@V*C8I]BRV*C;C-F&VXP@V+39
MB-BO`-F^VXS8NMBGV84@V879AMF"V+;;C"#8M-BO`-F&V8C8N2#9OMN,V+K8
MI]F%`-BBV*@@V8@@V8?9B-BGVXP@365T87(`V*C9A-F(VJD@365T87(@V8+8
MI]BHV80@V*_8L]BJV+'8LR#9AMN,V+/8J@#8J-F$V8C:J2!-971A<B#9@MBG
MV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ+B#8K-BRV*;;C-BGV*H@V*C8L=BG
MVXP@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8J]BHV*H@V+38K]F'(-BG
MV+/8J@#8L=F(V+0`V*?9AMBOV*?8LMF'XH",V*?;C`#9B-BSV+<`V8;9B-BY
M($UI;64`(-JIV87;C-F&V8<@V*_9A=BGVXP@V[+;M"#8L]BGV+G8JB#:K]BP
MV+38JMF'.B``(-JIV87;C-F&V8<@V*_9A=BGVXP@V[8@V+/8I]BYV*H@VJ_8
ML-BTV*K9ASH@`-BLV+/8JMBLV8C;C"#9A=BMV*_9B-BO`-BBVXS9AMF'`-F%
MV*K9@=BQV8+9AP#8N=BOV84@V8C8K-F(V*\@1$X@V*_8L2#9OMN,VJG8L=BH
MV8;8K]N,($Q$05``V;[;C-JIV+'8J-F&V*_;C"#9A=F(V*S9B-BO(-F&VXS8
ML]BJ+B#8M-F%V*<@V*?:K]BQ(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8LB#8
MI]N,V88@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@V*?8L]BJV8'8
MI]BOV8<@VJG9AMN,V*\@V*C8I]N,V*\@V*+9AMBQV*<@V*K9B-F$VXS8KR#:
MJ=F&VXS8KP#8I]BR(-BHVXS9AB#8L=F!V*K9AB!)1"#9OMN,V+K8I]F%`-BG
MV+(@V*C;C-F&(-BQV8'8JMF&($E$(-F&V+38L]BJ(`#8K]F(V+39AMBHV8<`
MV;[8L]BJ(-BSV839B-F$VXP`V*K9A-F!V88@V8?9A=BQV*?9AP#9A=BYV*K8
MK]F$(-JIV+'8K]F&`-BJV*?8L=N,V*X@V*K8NMN,VXS8L2#;C-BGV8'8JMF'
M`-BJV+K;C-N,V+$@55),`-BJV+K;C-N,V+$@V8;8I]F%V8C9@=F1V8(@V*C9
MB-BO.B`H)7,I("5S`-F%V*?9AR#9B"#8L]BGV80`V878I]F'V*?9AMF'`-F!
MV*?8LMF'V*?;C"#9A=BGV8<`V*C;C-BT(-BGV+(@VXS:J2#9B-BQV8C8K]N,
M(-F^VXS8K]BG(-BTV*\`V*C;C-BTV*K8L2#8M=BGV8$`V*C;C-BTV*K8L2#8
MI]BHV+';C`#8J-N,V+38JMBQ(-BBV8'8JMBGV*C;C`#8I]F&V*K9@MBGV80`
MV*?9AMBJV8+8I]F$(-BHV8<@V;[8I]N,VXS9A@#8I]F&V*K9@MBGV80@V*C9
MAR#8J-BGV838IP#8I]F&V*K9@MBGV80@V*C9AR#8L=BGV+/8J@#8I]F&V*K9
M@MBGV80@V*C9AR#8J-BGV838IP#8I]F&V*K9@MBGV80@V*C9AR#9OMBGVXS;
MC-F&`-BGV8;8JMF"V*?9A"#8J-F'(-J&V;X`V*?9AMBJV8+8I]F$(-BHV8<@
MV+'8I]BSV*H`V*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<`VJG8JMBGV*C:
MAMF'V90@V*+8K]BQV+,@375L8F5R<GD@`-F!V8?8L=BSV*H@V;[8I]N,VXS9
MAN*`C-F^V+$@VH;9AMBO(-BSV+?8K=N,`-J&V8;8KR#9AMF!V+$@V*C8IR#8
MHMBOV+'8LR!;)7-=+"#8I]F%V*<@V8?;C-J&XH",VJG8K]BGV84@V*C8IR#9
MAMBGV84@6R5S72#8K]BQ(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BGV+(@
MV8+8J-F$(-F%V8C8K-F(V*\@V8;;C-BSV*HN`-J&V8;8KR#8I]F&V*K8KMBG
MV*C;C`#8K=BSV*?8J"#9A=F&`-BGV+?9A-BGV+G8I]BJ(-BMV+/8I]BH(-F%
MV88`V*_8L=JOV*?9AR#9A=F&`-BLV*?9AMF%V*?;C-N,(-BOV+':K]BGV8<@
MV879A@#9AMF'V(P@V879AB#9A=F(V*?9@=F"(-F&VXS8L]BJV84`V8;8I]F%
M`-F"V*?9A-BH(-F&V*?9A0#8M-BGV*[9A]F4(-BGV+G8MMBGVXP@3F5T8V5N
M=&5R`%523"#9OMBGVXS9AR!.971S8V%P90!.971S8V%P92!#02!2979O8V%T
M:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W
M86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`-BJV8C8MMN,V*T@VJ_9
MB-BGV8?;C"!.971S8V%P90#9AMF(V+D@VJ_9B-BGV8?;C"!.971S8V%P90#8
MM-BHVJG9AP#9A]BQVJ_8L@#8K]BSV*K9AR#8K-BOVXS8KP#8JMF%V*?8LR#8
MK-BOVXS8KP#9A=BGV8<@V8;9B`#9AMBGV84@VJG8I]BQV*C8L=N,(-BLV*_;
MC-BO("C8I]BNV*K;C-BGV+';C"D`V*?8L]F%(-BQV878LB#8K-BOVXS8KP#8
MI]BSV84@V+'9A=BR(-F$V+K9B"#8KMF(V*?9A]BO(-BTV*\@V*_8L2`E>"``
MV*?8L]F%(-BQV878LMF'V*?;C"#8K-BOVXS8KR#8JMBWV*?8J-F"(-F&V*_8
MI]BQV*\`V;[9AMBLV+'9AR#8K-BOVXS8KR`HV*[8I]F$VXPI`-BGV*[8J-BG
MV+$`VJ_8L=F(V8?B@(S9A]BGVXP@V*[8J-BQVXP`VJ_8I]F%(-BHV+G8KP#:
MK]BRVXS9AMF'XH",V8?8I]N,(-BHV+G8K]N,`-F&V*?9A2#9A=BSV*K8N=BG
MV+$`V+38J`#9AMF'`-F'VXS:AB#9B-BQV8C8K]N,("5S(-BHV+'8I]N,("5S
M(-F^VXS8K]BG(-F&V+38KP#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8L]N,(-F^
MVXS8K]BG(-F&V+38KP#8K]BGV*_9AR#9OMN,VJG8L=BHV8;8K]N,(-BOV+$@
MV*_8L]BJV+'8L]N,(-BHV+'8I]N,(-F&V+38I]F&(-BOV*?8K]F&(-BJV8'8
MI]F(V*K9A]BG(-F(V*S9B-BO(-F&V*_8I]BQV*\`25-/(-F&VXS8L]BJ(-BG
MV+/8JMBQV*?8JMJ8VXP@V*_8L2#8K]BSV*K8L=BSVXP@V*C8L=BGVXP@V+/8
MI]BNV*K9AB#8JMBUV8C;C-BQ(`#8I]F$VJ_9B-N,(-BOV+/8JMF'XH",V*?;
MC-N,(-F&VXS8L]BJ`-BHV838I]JIVXP@V*_8L2#9A=F(V8+8N=N,V*H@V*_8
ML=BNV8C8I]BSV*H@V+38K]F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`V8?;C-J&
M(-F&V*?9A2#8JMF"V8C;C-F%VXP@V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(
MVXS9D=BJ($U#04P@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8K]F(
MV88@V*K8NMN,VXS8L0#9A]N,VH8@V878K-F(V+(@V8'8L=BYVXSB@(S8I]N,
M(-F&V87;C.*`C-BJV8C8I]F&V*\@V*C9AR#8I]N,V88@V878K-F(V+(@V*?8
MMMBGV8'9AR#8M-F(V*\`V8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQ
MV*C9AMBOVXP@V*C8L=BGVXP@)7,@V878M-BNV+4@V8;8M-BO`-F'VXS:AB#8
MI]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,($944"!6
M1E,@V878M-BNV+4@V8;8M-BO`-F'VXS:AB#8I]BWV838I]BYV*?8JB#9OMN,
MVJG8L=BHV8;8K]N,(-BHV+'8I]N,(%-13"!61E,@V878M-BNV+4@V8;8M-BO
M`-F'VXS:AB#8I]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8
MI]N,(%-13"U&:6QE(%9&4R#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BJV878
MI]BSVXP@V;[;C-BOV*<@V8;8M-BO`-F'VXS:AB#8I]BYV*K8J-BGV+';C"#8
MJ-BGV8+;C"#9AMF%V*?9AMBO`-F'VXS:AB#9A=F"V+78K]N,(-F!V+'8I]F'
MV84@V8;8M-BO`-F'VXS:AB#9OMBQV8C9AMBOV8?B@(S8I]N,VXP@V*?8L=BS
MV*?9A"#9AMBTV*\`V8?;C-J&(-BBVXS:J=F(V8;;C.*`C"#9OMN,V*_8IR#9
MAMBTV*\`V8?;C-J&(-F%VJG8I]F&VXP@V*K9AMBXVXS9A2#9AMBTV*_9AP#9
MA]N,VH8@V;[;C-BZV*?9A=N,(-F!V+'8I]F'V84@V8;8M-BO`-F'VXS:AB#9
MAMBGV87;C"#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BTV878I]BQV8?B@(S8
MI^*`C-N,VXP@V878M-BNV+4@V8;8M-BO`-BBVXS9AMBOV8<@V8;8I]F%V+?8
MJ-F(V+G;C"#9AMN,V+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@2%144"#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8
MI]BSV*H`V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($E-05`@V*?8
ML]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8
MI]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!+97)B97)O<R#8I]BSV84@V+'9
MA=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8L=BGVXP@V*K8
MM=BOVXS9@B#9A]F(VXS9D=BJ(-F(V+'9B-BO(-BGV+/9A2#8L=F%V++;C"#9
M@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"
M(-F'V8C;C-F1V*H@4$%34U=$(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%
M(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@4TU"(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BG
MV+/8J@#8JMF"V*?8MMBGVXP@V*O8J-BJ(-F&V*?9A=N,(-BOV+$@V*?9AMBJ
MV+C8I]BQ(-BJV*/;C-N,V*\@V8;;C-BSV*H`V*C8K]F(V88@V8+9B-BGV+G8
MKP#9A]N,VH8@V*S8K]BGVJG9AMF&V*_9A^*`C-BGXH",VXS;C"#9A=BTV*[8
MM2#9AMBTV*\`V*C8K]F(V88@V+/9A=BJ`-BTV*?8KMF'(-F%V8C9@MBJVXP@
MV*C8L=BGVXP@VJG8I]BTV8<@V879B-BLV8C8KR#9AMN,V+/8J@#9A]N,VH8@
MV8;8I]F%(-JIV*?8L=BHV+';C"#9B"#;C-BG(-BGV+/9A2#8L=F%V++;C"#8
MI]BQV+/8I]F$(-F&V+38KP#9A]N,VH8@V*_8I]BOV8?9E"!V0V%R9"#9OMN,
MV*_8IR#9AMBTV*\`V8?;C-J&(-BOV*?8K]F'(%A-3"#9A=BYV*K8J-BQVXP@
MV*C8I]BRVJ_8L=BOV*?9AMBOV8<@V8;8M-BOV8<@V*?8L]BJ`-BHV*_9B-F&
M(-F%V8+8K]BGV+$`V8;8L]BNV8?B@(P@V*_8L2#9OMN,VJG8L=BHV8;8K]N,
M(-BGV+79A-N,(-F^VXS8K]BG(-F&V+38KRX@V;[;C-JIV+'8J-F&V*_;C"#8
ML=BG(-BOV8C8J-BGV+'9AR#8JMF(V83;C-BO(-JIV8;;C-BO`-F&V+/8KMF'
MXH",(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#8M-F%V*<@V;[;C-BOV*<@V8;8
MM-BOV8<@V*?8L]BJ+B#9OMN,VJG8L=BHV8;8K]N,(-BQV*<@V*_9B-BHV*?8
ML=F'(-BJV8C9A-N,V*\@VJG9AMN,V*\`V8?;C-J&`-F'VXS:AN*`C-JIV*_8
MI]F%("C8MMF%V8;;C"#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KRD`3F]R9&EC
M("A)4T\M.#@U.2TQ,"D`V8;;C-F%(-JIV+'9AR#8M-F%V*?9A-N,`-F&V8<@
MV*C8N=BO`-F&V8<@V8+8J-F$`-N,VJD@V+38I]BNV8<@V8;;C-BSV*H`V;[;
MC-BGV*_9A^*`C-BSV*?8LMN,(-F&V+38K]F'`-BJV8;8N-N,V84@V8;8M-BO
MV8<`V;[8M-BJVXS8J-BGV8;;C"#9AMBTV*_9AP#;C-BGV*_8K]BGV+38JMF'
MV*<`VH;;C-BRVXP@V*C8L=BGVXP@V878L=F(V+$@V8;;C-BSV*K8C"#8J-F'
M(-BYV8+8J"#8J-BQVJ_8L=BO`-F&V8C8I]F%V*C8L0#8N=BOV*\`V*K8N=BO
MV*?8KR#9AMF(VXS8L]F'XH",V8?8IP#8JMBYV*_8I]BO(-BSV*K9B-F&V8?8
MIP#8JMBYV*_8I]BO(-F%V8C8I]BQV*\@V*_8L2#9A]BQ(-BUV8'8K=F'`-BJ
MV+G8K]BGV*\@V+/8M]BQV8?8IP#8I]BYV*_8I]BO(-BHV+'8I]N,(-BHV+'9
MB-BRV+'8L]BGV8;;C"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#9A=BTV*[8
MM2#9AMBTV*_9AMBO`-BJV*/;C-N,V*\`V+3;C-BA`-BGVXS8K-BGV*\@VJG9
MAMF&V*_9AR#8M-N,V*$`V+3;C-BA(-F^VXS8K]BG(-F&V+38KP#9A]BTV*K8
MI]N,VXP`V*?:J=BJV*C8L0#9@=N,V838JMBQ(-BHVXSB@(S8K=BQV878JMN,
M`-BOV8'8JMBQ(-JIV*?8L0#8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-F((-BG
MV+/9A2#8L=F%V+(@V8'8N=F$VXP@V*C8I]N,V*\@V878JMF!V*?9B-BJ(-BH
MV*?8M-F&V*\`V*?8L]F%(-BQV878LB#9@MBOVXS9A=N,`-BGV+/9A2#8L=F%
MV+(@(-F"V*_;C-F%VXP@V8;8I]BOV+'8L]BJ(-BGV+/8J@#8JMF&V8?8IR#:
MJ=BGV+'8L]BGV++9A]BGVXP@24U!4-F^V8C8M-F'XH",V8?8I]N,(-F%V+38
MJMBQVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F%VXSB@(S:J=F&V8;8KR``
MV8'9@MBW(-BBVXS9AMBOV8<@V8;8I]F%V+?8J-F(V+D`V*K9AMF'V*<@VXS:
MJ2#8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V878K-BG
MV+(@V*?8L]BJ`-BJV8;9A]BG(-N,VJD@=F-A<F0@V;[8M-BJVXS8J-BGV8;;
MC"#9A=N,XH",V+39B-BO`-BJV8;9A]BG(-F%V*?9A-JI(-N,V*<@V+/8L=F^
MV+'8L]BJ(-BSV*?9A=BGV8;9AR#9A=N,XH",V*K9B-BGV8;8KR#9A=BGV83:
MJ=N,V*H@VXS8IR#9A=BLV8C8LMF'V*?;C"#9A=BGV83:J2#8L=BG(-BHV+'8
MI]N,(-N,VJD@V*?8M-BJV+'8I]JI(-BJV+K;C-N,V+$@V*_9A]BO`-BOV+$@
MVXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO(-BHV*?8LB#8M-F(V*\`V*?;C-F&
M(-F^VXS9B-F&V*\@V*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@V*C8
MI]BR(-BTV8C8KP#8L]N,V+/8JMF%(-BYV*?9A=F$`-JOV++;C-F&V8<F(W@R
M,#!C.]F'V*<`VJ_8LMN,V8;9A^*`C-F'V*?;C"`E<P#9A-N,V+/8JB#9A=BQ
MV*K8J"#8M-BOV8<`V+/8I]BRV878I]F&`-F(V*?8K=BO(-BSV*?8LMF%V*?9
MAMN,`-BSV*?8LMF%V*?9AMBOV8?;C`#8I]F$VJ_9B-N,(-BGV+79A-N,(-BH
MV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,`-BGV83:K]F(V8?8I]N,(-BG
MV+79A-N,(-BOV+$@)7,Z`-BOVXS:K]BQ`-BGV+?9A-BGV+G8I]BJ(-BOVXS:
MK]BQ`-JOV++;C-F&V8?B@(S9A]BGVXP@V*_;C-JOV+$`V878K-F(V++B@(S9
MA]BGVXP@V878I]F$VJD`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%!!32#9@MBG
MV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*H`V*?9A=BVV*?8H>*`C"#8K]N,
MV*S;C-BJV*?9A-N,(%!'4`#9OMN,V+K8I]F%(-BQV878LMBHV8;8K]N,(-BT
MV*_9A]F4(%!'4`#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'4`#9OMN,V+K8I]F%
M(-BQV878LMBHV8;8K]N,(-BTV*_9AR_8I]F%V+;8I]BA(-BTV*_9AR!01U``
MVJG8KR!02%``V;[9B-BSV*K9AR!02%``V*C8I]BQV8;8K]JOVXP@V+/8J-JI
M(-BYV+78L=JOV*?9A]N,`-BQVJ_8J-BGV+$@V+G8M=BQVJ_8I]F'VXP`V*C8
ML=F!(-BYV+78L=JOV*?9A]N,`-BJVJ_8L=JO(-BYV+78L=JOV*?9A]N,`%0M
M4W1O<FUS`-BHV+/8MR!03U-)6"#8I]BR(-BHVXS9AB#8L=F!V*K9AR#B@(S8
MI]BSV*H`V;[9B-BSV*K9AR!02%``V8'8I]BUV839A^*`C-JOV+#8I]BQVXP`
MV8+8L]F%V*K;C"#8I]BHV+';C`#8I]BSV84@V+'9A=BR(`#8I]BSV84@V+'9
MA=BR(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8JMBZVXS;C-BQ(-N,V*?9@=BJ
M+@#8I]BSV84@V+'9A=BR("#9AMBGV*_8L=BSV*H@V*?8L]BJ`-BGV+/9A2#8
ML=F%V+(@(-BHV8<@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%)!1$E54R#9AMN,
MV*?8LB#8K]BGV+'8KP#8I]BSV84@V+'9A=BR("#8J-BG(-BJV*/;C-N,V*\`
MV*?8L]F%(-BQV878LB`Z`-BGV+/9A2#8L=F%V+(@.B``V*?8L]F%(-BQV878
MLN*`C-F'V*<@V*C8I]N,V*\@V879AMBWV*C9@B#8J-BGV+39AMBO`-J&V+/8
MJ-BGV8;8K]F&`-J&V+/8J-BGV8;8K]F&(-BGV+(@V*K8KMBJV8<@V+'8L]F%
M`-F%V+/;C-BQ`-BKV*C8JB#9AMBGV879A]BGVXP@V8;8I]F%V+G9A-F(V84`
MV878L=BOV84`V*_8L=BUV*\`V*?8K-BQV*?;C"#8N=F%V83;C-BGV*H@V8;:
MK]F'V*_8I]BQVXP`V*+;C-BG(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';
MC"#8K]BQ(-F$V*W8N-F'(-F(V+'9B-BO(-BGV*S8L=BG(-BTV8C8K]B?`-F%
MV*S9B-BR`-F%V*S9B-BR("`B)7,B(-BMV+#9@2#9AMBTV*\`V+G8K]F%(-F(
MV*S9B-BO(-F%V*S9B-BR`-BYV*_9A2#9B-BLV8C8KR#9A=BLV8C8L@#8L]BQ
MV;[8L=BSV*K;C"#9A=BLV8C8LMF'V*<`V*?8M]F$V*?8N=BGV*H@V+38KMBU
MVXP`V*W;C-F(V*?9AMBGV*H@V*[8I]F&VJ_;C`#8JMF$V8'9A@#8N=JIV+/9
MA]BG`-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(%!I;F4`V;[;C-JIV+/9A-F'
MV*<`V838M]F!V*?9BR#8K]BGV*[9A"#:AMF&V*\@V+/9A-F(V80@VJG9A-N,
MVJD@VJG9AMN,V*\`V838M]F!V*?9BR#8JMBCVXS;C-BO(-JIV8;;C-BO(-JI
MV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]N,V88@V+G9AMBUV+$@V+'8IR#8
MK=BPV8$@VJG9AMN,V*\Z`-F$V+?9@=BGV8L@V*K8H]N,VXS8KR#:J=F&VXS8
MKR#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V;[;C-F(V8;8KR#8I]N,V88@
MV+G9AMBUV+'9A]BG(-BQV*<@V8+8M]BY(-JIV8;;C-BO`-F$V+?9@=BGV8L@
MVXS:J2#9A=BGV8<@V8@@VXS:J2#8L]BGV80@V8C8I]BQV*\@VJG9AMN,V*\N
M`-F$V+?9@=BGV8L@V8;8I]F%VXP@V*C8L=BGVXP@V*_8L]BJV8<@V*S8K]N,
MV*\@V8C8I]BQV*\@VJG9AMN,V*\Z`-F$V+?9@=BGV8L@V*+8K]BQV+,@25`@
MV878N=BJV*C8L=N,(-F(V*?8L=BO(-JIV8;;C-BO`-F$V+?9@=BGV8L@VXS:
MJ2#8JMBGV+';C-BN(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMN,V*_8C"#8
MJMBYV*_8I]BO(-BQV8C8LMF'V*<@V*_8L2#9A=BGV8<@V+'8IR#:J=F&V*K8
ML=F$(-JIV8;;C-BO`-F$V+?9@=BGV8L@VXS:J2#8LMF%V*?9AB#9A=BYV*K8
MJ-BQ(-F(V*?8L=BO(-JIV8;;C-BO`-F$V+?9@=BGV8L@V*C9AR#9@=F'V+'8
ML]BJ(-BJV878I]BS(-BLV*_;C-BO(-F&V*?9A=N,(-BOV8?;C-BO.@#9A-BW
MV8'8I]F+(-BNV838I]BUV8?B@(S8I^*`C-N,VXP@V*?8LB#9A=BTVJG9A"#8
ML=BG(-BHV8;9B-N,V+/;C-BO`-F$V+?9@=BGV8L@V8;8I]F%(-JIV*?8L=BH
MV+$@V8@@V*?8L]F%(-BQV878LB`@V*[9B-BO(-BQV*<@V*+9A=BGV*_9AR#:
MJ=F&VXS8KP#9A-BWV8'8I]F+(-F%V*K9AB#8LMN,V+$@V+'8IR#8J-BNV8C8
MI]F&VXS8KRX@V+39A=BG(-BHV+'8I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@
MV+/8I]F%V*?9AMF'(-BHV*?;C-BO(-BTV+'9B-BW(-BQV*<@V8+8J-F(V80@
MVJG9AMN,V*\`V838M]F!V*?9BR#9AMBGV84@V*_8L]BJV8<@V*S8K]N,V*\@
MV+'8IR#9B-BGV+'8KR#:J=F&VXS8KSH`V+/;C-BGV+/8JMF'V*<`V*+8L=BG
MV*$`V878K=F$(-F"V+'8I]BQVJ_8L=F!V*K9AB#8I]N,V88@V*K8M=F(VXS8
ML0#9A=BMV80@V8+8L=BGV+':K]BQV8'8JMF&(-BGVXS9AB#8K-BOV8C9A`#9
MOMBSV*H@V*C9AR#8I]N,V88@V;[9B-BTV8<`V*_8L=BUV*\@V+'8M]F(V*C8
MJB#8K]BQ("5S(-BSV*?8N=BJ(-F"V*C9A#H`4')E9G-?;&1A<#H@V*C8L]BW
M(-F%V8C8L=BO(-F&VXS8I]BR($Q$05`@V;[;C-BOV*<@V8;8M-BO`%!R969S
M7W-E<W-I;VXZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!S97-S:6]N(-F^
MVXS8K]BG(-F&V+38KP#9@=BTV*?8L0#9@=BTV*?8L2#8K]BQ(-BSV+?8K2#8
MK]BQVXS8ISH@`-F!V+38I]BQ.B``V;[;C-BTXH",V8;9A=BGVXS8M`#9OMN,
MV+3B@(S9AMF%V*?;C-BT(-BJV+79B-N,V+$@V*_8L2#;C-JI(-F^V8;8K-BQ
MV8<@V*S8K]N,V*\@`-F"V*C9A-N,`-JOV++;C-F&V8?B@(S9A]BGVXP@V8+8
MJ-F$VXP`VH;8I]F^(-BSV8;8KP#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8
MKMBUV8C8M=N,`-JIV83;C-BO(-BTV*[8M=N,`-F%V+3:J=F$`-BJV8C8MMN,
MV*T@V878M-JIV80`V;[8L=F(VIC9A^*`C-F'V*<`V878JMF&(-BGV+G9A-BG
MV88`VJG9A-N,V*\@V+G9A=F(V87;C`#8I]F$VJ_9B-BQVXS8JMF%(-JIV83;
MC-BO(-BYV879B-F%VXP`V*S9@=BJ(-JIV83;C-BO(-BYV879B-F%VXPOV*[8
MM=F(V+7;C"#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*K9B-F$VXS8KR#9AMBT
MV*\`V;[8L=BSXH",V8C8K-F(`-F^V+'8L^*`C-F(V*S9B"#9AMBGV879B-F!
MV9'9@B#8J-F(V*\Z("@E<RD@)7,`V*S8L]BJV*S9B-N,(-BSV+';C-BY`-BS
MV8?9A=N,V8<`(-JIV83;C-BO(-BYV879B-F%VXP@4E-!("@E9"#8J-N,V*HI
M`-BGV8;8JMBNV*?8J"#8L=BGV*_;C-F(`-BHV*?8L=BGV88`V*C8I]BQV*?9
MAB#8LMF(V*_9A]F&VJ_8I]F%`-BHV*?8L=BGV88@V*_;C-BQV8?9AMJOV*?9
MA0#8J-BGV+'8I]F&(-F((-BQVJ_8J-BGV+$`V*C8I]BQV*?9AB#9B"#8J-BQ
MV8$`V*C8I]BQV*?9AB#8J-F'(-BHV+'9@0#8M]BGV838N2#8JMBUV*?8K]F!
MVXP`V8;8L]BHV*H`V*[9B-BGV8;8K]F&`-BNV8C8I]F&V*_9AB#9AMBGV879
MB-F!V9'9@B#8J-F(V*\Z("@E<RD@)7,`V*[9B-BGV8;8K]F&(-F^VXS8NMBG
MV879A]BG(`#9B-BGV8+8N=BGV9(@)7,@V*W8L-F!(-BTV8C8K]B?(-BGVXS9
MAB#8N=F%V80@V8+8I]BHV80@V8C8I]JOV+'8KR#9AMN,V+/8J@#8HMN,V*<@
MV8C8I]F"V+G8I]F2(-BGVXS9AB#8JMF%V*?8LR#8K=BPV8$@V+39B-BOV)\`
MV8C8I]F"V+G8I]F+(-BOV*?8K]F'V90@VJG8I]BQV*C8L=N,(-BHV+'8I]N,
M(-JIV*?8L=BHV+$@)7,@V*W8L-F!(-BTV8C8K]B?(-BGVXS9AB#8N=F%V80@
MV8+8I]BHV80@V8C8I]JOV+'8KR#9AMN,V+/8J@#8L=JIV8C8L=BOV8?8I]N,
M(-F&V878I]N,V+0@V*_8I]BOV8<@V+38K]F'.@#8I]F&V*S8I]F%(-BBV*[8
ML=N,V88@V+G9A=F$(-BTV878IR#8I]BR(-F&V8@`V*C8I]BRV*+9B-BQVXP@
MV+G9AMBGV+78L2#:K]BRVXS9AMJOV*?9AB#8K]N,V8;8I]F%VXS:J=N,.@#8
MJ-BGV++8HMF(V+';C"#9AMF%V*?;C"#8K]BQVJ_8I]F'.@#9A=BQV8C8L=JO
MV+$@V+'8I]BHV+?9A^*`C-BGXH",VXS;C`#8JMF(V+;;C-BMV*?8J@#:J=BG
MV+'8L]BGV++9A]BGVXP@V+'8I]F'XH",V*_9B-BQ`%523`#8K=BPV8$`V*W8
ML-F!(-BHV839B-JI`-BMV+#9@2#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR``
MV*W8L-F!(-BSV*K9B-F&`-BMV+#9@2#9@MBGV838J"#8J-F&V*_;C`#8K=BP
MV8$@V*?8LB#8I]N,V88@V8'9A]BQV+/8J@#8K=BPV8$@V++9B-BL`-BMV+#9
M@2#8K]BSV*H@XH",V8;9B-N,V+/9A]BGVXP@V*W9@=BX(-BTV*_9AR#8K]BQ
M(-BTV*?8KMF'(-F%V8C9@MBJ(-JIV*?8L=BSV*?8L@#8K=BPV8$`V*W8L-F!
M(-BGVXS9AB#:K]BQV8<@V*?8LB#8L]F&V*\`V*W8L-F!(-JIV*?8L=BHV+$`
MV*W8L-F!(-JIV*?8L=BHV+$Z("5S`-BBVXS8IR#:J=BJV*?8J-J&V8<@V*+8
MK]BQV+,@V879B-BLV8C8KR#8J-BG(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS
M(-BOV+'9B-F&XH",V*C8L=BO(-BTV*_9AR#8K-BGV*C8K-BG(-BTV8C8K]B?
M(#QS=')O;F<^V*?8KMBWV*?8L3H@V*?;C-F&(-BYV879A"#8JMF%V*?9A=N,
M(-F(V+'9B-BOVXSB@(S9A]BGVXP@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@
MVJG9AMF(V8;;C"#8M-F%V*<@V+'8IR#8K=BPV8$@V87;C.*`C-JIV8;8KRX\
M+W-T<F]N9SX`V*K9@MBGV+;8IR#9@MBGV*C9A"#9OMBGV+/8KMJOV8C;C-N,
M(-F&VXS8L]BJ+B#:J=BO(-BNV+?8I]N,(-BHV+':K]BQV*_8I]F&V*_9AR#8
MM-BOV8<Z`-BTVXS8H2#8KMF(V*?8L]BJV8<@V+38K]F'(-F^VXS8K]BG(-F&
MV+38KP#9@=N,V838K]F'V*?;C"#9A=F(V+'8KR#9AMN,V*?8L@#8J-BGV++9
MAMBTV*?9AMN,`-BHV*?8LMF&V+38I]F&VXP@V*?8L]F%(-BQV878L@#8I]BS
MV84@V+'9A=BR(-BNV8C8KR#8L=BG(-BHV*?8LMF&V+38I]F&VXP@VJG9AMN,
MV*\`V*C8I]BRV8;8M-BGV8;;C"#9OMN,V+0@V8'8L=BVXH",V8?8IP#9AMBJ
MV*?;C-BL`-BHV*?8LMJOV+38JB#8J-F'(-JOV++;C-F&V8?B@(S9A]BG`-BJ
MV*?;C-F^(-BOV8C8J-BGV+'9AR#8I]BSV84@V+'9A=BR("#8K-BOVXS8KR``
MVJ_8L=BOV8?9A=BGVXS;C`#8J-BGV++:K]BQV*_8I]F&V*_9AB#9OMN,VJG8
ML=BHV8;8K]N,`-JOV++;C-F&V8?B@(S9A]BGVXP@V8C;C-BQV*?;C-BTVJ_8
ML2#9A=BJV88`V878N=F%V*?9A]BG`-BQV*?8L]BJ`-BSV+'8HMF%V*\@V+'8
MI]BSV*H`V879@MBGV*_;C-BQ(-BQV*?8L]BJ`-BNV+79B-BUVXS8I]BJ(-BS
MV+?8L2XN+@#9AMF"V+0`VH;8L=BNV+0@V[';N-NP(-BOV+'8K-F'`-J&V+'8
MKMBT(-BHV8<@VH;9O@#:AMBQV*[8M"#8J-F'(-BQV*?8L]BJ`-BNV+79B-BU
MVXS8I]BJ(-BSV+?8L0#8KMBUV8C8M=N,V*?8JB#8L]BWV+$`V+/8M]BQV8?8
MISH`V8+9B-BGV+G8KP#9@MF(V*?8N=BO(-BHVXS9AB#8JMF%V*?9A2#8L]BW
MV+'9A]BG(-F((-BSV*K9B-F&V8?8IR#9AMF%V*?;C-BGV88@V*[9B-BGV8?8
MKR#8M-BO`-F"V8C8I]BYV*\@V8'9@MBW(-BHVXS9AB#8JMF%V*?9A2#8L]BJ
MV8C9AMF'V*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@V+38KP#9@MF(V*?8
MN=BO(-F!V8+8MR#8J-N,V88@V*K9A=BGV84@V+/8M]BQV8?8IR#9AMF%V*?;
MC-BGV88@V*[9B-BGV8?8KR#8M-BO`-BGV*S8L=BG`-F^VXS8NMBGV84@V+'9
MA=BRV*C9AMBOVXP@(-BTV*_9A]F4(%,O34E-12``VJ_9B-BGV8?;C"#8N=F%
MV8C9A=N,(%,O34E-10#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@4T%33"#9@MBG
MV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*H`V;[;C-BZV*?9A2!335,`V;[9
MB-BSV*K9AR!344P`4U-(`%-405)45$Q3(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKR`H)7,I("5S`-F%V8C9@=F1V8+;C-F1V*H`V;[9B-BSV*K9AR!344P`V+39
MAMBHV8<`V8?9A=BGV88@VH;8I]BQVH;9B-BH("C8KMF(V*_8M"D`V*W9@=BX
M`-BMV8'8N"#:J=BQV*_9AB`E<P#8K=F!V+@@VJ_8LMN,V8;9A^*`C-F'V*<`
MV;[;C-JIV+'8J-F&V*_;C"#8JMF(V83;C-BO(-BTV*_9AR#8J-BYV8;9B-BG
MV88@V*_8L]BJ(.*`C-F&V8C;C-BS(%!(4"#8K]BQ(-BTV*?8KMF'V90@V879
MB-F"V*H@VJG8I]BQV+/8I]BR(-BTV878IR#8K=F!V+@@V+39B-BO`-F^VXS:
MJ=BQV*C9AMBOVXP@)7,@V*W9@=BX(-BTV*\`V+G9A-F%`-BLV+/8JMBLV8@`
MV*S9B-N,V+3:K]BQV8?8IP#9AMBJV*?;C-BL(-BLV+/8JMBLV8@Z`-BLV+/8
MJMBLV8@@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-BLV+/8JMBLV8@@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO.B`E<P#8K-BSV*K8K-F(+BXN`-BGV8;8JMBNV*?8
MJ"#9OMBQV8C9AMBOV8?B@(S9A]BG`-BGV8;8JMBNV*?8J"#;C-JI(-BJV*?8
ML=N,V*X`V*?9AMBJV*[8I]BH(-N,VJD@VJ_8L=F(V8<@V*C8L=BGVXP@V*?8
MMMBGV8'9AR#:J=BQV*_9A@#8I]F&V*K8KMBGV*@@VXS:J2#9A=BGV83:J2#8
MK-BOVXS8KP#8I]F&V*K8KMBGV*@@VXS:J2#:J=BGV+'8L]BGV+(`V*?9AMBJ
MV*[8I]BH(-N,VJD@VJG8I]BQV*C8L2#8J-BQV*?;C"#8I]BVV*?9@=F'(-JI
MV+'8K]F&`-BGV8;8JMBNV*?8J"#9A]F%V8<`V*?9AMBJV*[8I]BH(-BJV878
MI]F%(-F%V*39A-F!V8?B@(S9A]BGVXP@V*K8I]BQVXS8K@#8I]F&V*K8KMBG
MV*@@VXS:J2#8M-BF`-BGV8;8JMBNV*?8J"#9A]N,VH;B@(S:J=BOV*?9A0#8
MI]F&V*K8KMBGV*@@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V*C8L=BGVXP@
MV*C8L=F(V8;B@(S8J-BQV*\@V*?8LCH`V*?9AMBJV*[8I]BH(-JIV*K8I]BH
MVH;9A]F4(-BBV*_8L=BS(-BHV+'8I]N,(-BOV+'9B-F&XH",V*C8L=BO(-BH
MV8<Z`-F&V8C;C-BSV8?B@(S9A]BGVXS;C"#:J=F'(-F$V*?8LMF%(-BOV*?8
ML=N,V*\@V+'8IR#8I]BR(-BLV+G8J-F'(-BRVXS8L2#8I]F&V*K8KMBGV*@@
MVJG9AMN,V*\N(-BSV;[8LR#8M-F%V*<@V87;C.*`C-BJV8C8I]F&VXS8KR#8
MI]BR(-BBV8;9A]BG(-BOV+$@V879AMBWV8+9AR#9A=BJV88@V8;8L]BNV8?B
M@(S8J-BQV*_8I]BQVXP@VJG8L=BOV8<@V8@@V*_8L2#9A=BMV80@V*_;C-JO
MV+$@V*C:AMBSV*C8I]F&VXS8KP#8I]F&V*K8KMBGV*@@V878K-F%V8C8N=F'
MV90@V8;9B-N,V+/9AR#9OMBQV8C9AMBOV8?9E"#8L]BQVH;8M-F%V8<Z`-BG
MV8;8JMBNV*?8J"#9A=BMV*_9B-BOV8<@V*K8I]BQVXS8KCH`V*?9AMBJV*[8
MI]BH(-F"V*?9A-BH(-BJV*?8L=N,V*XZ`-BGV8;8JMBNV*?8J"#9@MBGV838
MJ"#8J-BQV8C9AN*`C-BHV+'8KSH`V*?9AMBJV*[8I]BH("#9OMBQV8C9AMBO
MV8<@V*C8L=BGVXP@V*_8L=F(V8;B@(S8J-BQV*\Z`-BGV8;8JMBNV*?8J"#9
M@MBGV838J"#9OMBQV8C9AMBOV8?9E"#8L]BQVH;8M-F%V8<Z`-BGV8;8JMBN
MV*?8J"#9@MBGV838J"#9AMF%V*?;C-BT(-BGV+/8I]F%VXPZ`-BGV8;8JMBN
MV*?8J"#9A]F(VXS9D=BJVXP@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BJ
MV+K;C-N,V+$@V*_9A]N,V*\Z`-BGV8;8JMBNV*?8J"#9A=BMV*_9B-BOV8?9
ME"#8LMF%V*?9ACH`V*?9AMBJV*[8I]BH(-F"V*?9A-BH(-BRV878I]F&.@#8
MI]F&V*K8KMBGV*@@V*_9B"#9@=N,V838KR#9A=F&V+?8J-F"`-BGV8;8JMBN
MV*?8J"#9AMBMV8C9A]F4(-F&V878I]N,V+0@V;[;C-BT(-F!V+'8MMB,(-JO
MV++;C-F&V8?B@(S9A]BGVXP@V878L=BJV*CB@(P@V+/8I]BRVXP@V8@@VJ_8
MLMN,V8;9A^*`C-F'V*?;C"#8M=F!V*W9A^*`C-BHV8;8K]N,`-BGV8;8JMBN
MV*?8J"#9@=N,V838K]F'V*?;C-N,(-JIV8<@V*_8L2#9@=F'V+'8L]BJ(-BB
MV*_8L=BSV8?8IR#9AMF%V*?;C-BT(-BOV*?8K]F'(-F%VXSB@(S8M-F(V8;8
MKP#8I]F&V*K8KMBGV*@@V8+8I]F$V*@@V8;9A=BGVXS8M"#8I]BSV*?9A=N,
M`-BGV8;8JMBNV*?8J"#8M]BQV*T@V+'9AMJO(-BTV878IP#8I]F&V*K8KMBG
MV*@@V++8J-BGV88@V879B-BQV*\@V8;8N-BQ(-BTV878ISH`V*?8L=BSV*?9
MA"#:K]BRV*?8L=BT`-BGV+'8L]BGV80@4TU3`-BMV+/:K]BQ.B``V+/9OMBJ
MV*?9A=BHV+$`V*?8N=BOV*?8KR#8JMBQV*K;C-BHVXP`240@V8;8M-BSV*H@
MV879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ`-BJV8;8N-N,V84`V*K9AMBXVXS9
MA2#:K]BRVXS9AMF'XH",V8?8IR#8J-BQV*?;C"#8I]BLV*?8LMF'(-BOV*?8
MK]F&(-BHV8<@V+39A=BG(-BHV+'8I]N,(-BHV*?8LMF&V+38I]F&VXP@V*?8
ML]F%(-BQV878LB#8J-F'(-F'V8;:K]BGV84@V8'8L=BGV879B-BTVXP@V*+9
MAB``V*K9AMBXVXS9A2#:J=BGV+'8L]BGV++9A]BGVXP@V+'8I]F'(-BOV8C8
ML=N,(-JIV8<@V+39A=BG(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8LB#8K]BQ
MVJ_8I]F'(-BNV8C8KR#8J-F'(-BBV88@V*_8L]BJV+'8L]N,(-BOV*?8M-BJ
MV8<@V*C8I]BTVXS8KP#8I]F&V*K8KMBGV*@@V++8J-BGV88@V879B-BQV*\@
MV8;8N-BQV(P@V+/8I]BYV*H@V8@@VJ_8LMN,V8;9A^*`C-F'V*?;C"#8JMBG
MV+';C-BN`-BGV8;8JMBNV*?8J"#8J-BQV8;8I]F%V8<@V++9A=BGV88@V+38
ML=F(V+G8C"#8M]BQV*T@V+'9AMJOV(P@V*C8I]BRV*+9B-BQVXP@V+79@=BM
MV8<@V8@@V*C9@MN,V8<@VJ_8LMN,V8;9A^*`C-F'V*?;C"#9AMF%V*?;C-BT
M`-BQV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,`-BOV+/8JB#B@(S9AMF(VXS8
MLR`@V*C8L=F(V++8L=BSV*?9AMN,(-BQV*?9A^*`C-BGV8;8K]BGV++;C"#8
MK]BQ(-BOV+/8JMBQV+,@V*?8L]BJ`-J&V8;8K]N,V88@V879B-F"V+G;C-F1
MV*H@V*C8IR#9OMBGV+'8I]F%V*K8L2#9A=F%VJG9AB#8I]BSV*HZ`-BTV*?8
MKMF'V90@V878M-BJV+':J0#8KMBQVXS8KP#8KMF$V*?8M=F'(-JIV8C8JMBG
MV8<`V*+;C-BG(-JIV83;C-BOV8?8I]N,(-BOV+/8JMBQV+/;C"#8J-BGVXS8
MKR#8J-BQV*?;C"#8J-N,V+38JMBQ(-F^VXS9B-F&V*_9A]BG(-BJV+G8L=N,
MV8$@V+39B-F&V*_8GP#9AMF%V*?;C-BT`-F&V878I]N,V+0@)7,`V8;9A=BG
MVXS8M"#9A]F%V8<`V8;9A=BGVXS8M"#8JMF%V*?8L]F'V*<`V8;9A=BGVXS8
MM"#9@=F'V+'8L]BJXH",V8?8IP`@V8;9A=BGVXS8M"#8JMF!V*?9B-BJV8?8
MI]N,(-F%VXS8I]F&(-F^VXS:J=BQV*C9AMBOVXP@V*W9@=BX(-BTV*_9AR#9
M@=BYV83;C"#9B"#8JMF(V83;C-BO(-BTV*_9AR#8K-BOVXS8KP#8HMN,V*<@
MV++9A=BGV88@V*+8KMBQVXS9AB#9B-BQV8C8KR#8J-F'(-F'V8;:K]BGV84@
MV8C8L=F(V*\@V8;8M-BGV88@V*_8I]BOV8<@V+39B-BOV)\`V8;9A=BGVXS8
MM"#:K]BRVXS9AMF'XH",V8?8IR#8J-BQV*?;C"#9AMJOV8?8K]BGV+';C"#8
MI]BUV80`V*?9AMBJV*[8I]BH(-F#V8;9AMBOV8<@V8;9A=BGVXS8M`#8HMN,
MV*<@V87;C-F$V8<@VJ_8LMN,V8;:K]BGV88@V+G9A=F$VXS8I]BJ(-BLV*_9
MB-F$XH",(-F&V878I]N,V+0@V*_8I]BOV8<@V+39B-BOV)\`V*+;C-BG(-JO
MV++;C-F&VJ_8I]F&("5S(-BSV878JB#8L=BGV+/8JB#9AMBTV*?9AB#8K]BG
MV*_9AR#8M-F(V*_8GP#9AMF%V*?;C-BT(-JOV8'8JN*`C-F(VJ_9B-N,(-BN
MV+79B-BUVXS8I]BJ(-BSV839B-F$(-BLV*_9B-F$`-F&V878I]N,V+0@VJ_9
M@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$`-F&V878I]N,V+0@
MVJ_9@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BSV+?8L2#8K-BOV8C9A`#9
MAMF%V*?;C-BT(-JOV8'8JMJOV8C;C"#8KMBUV8C8M=N,V*?8JB#8JMBUV8C;
MC-BQ`-F&V878I]N,V+0@V*?8L=BSV*?9A`#8JMJOV+':KP#8L=JOV*C8I]BQ
M(-BRV8C8K]F'V8;:K]BGV84`V+':K]BHV*?8L2#8K]N,V+'9A]F&VJ_8I]F%
M`-BLV878N2#8M-BOV88`V*S9A=BY(-BTV*_9AB#;C-BG(-BGV8;8JMF"V*?9
MA"#8J-F$V8C:J=F'V*?;C"#9A=BLV*?9B-BQ`-BKV*C8JB#9AMBGV84`V*?9
MA=BVV*?8H0#8I]F$VJ_9B-BQVXS8JMF%(-BGV878MMBGV*$`V*?9AMBOV*?8
MLMF'`-BUV+'9@=F&V+C8L2#8I]BR(-F&VJ_9A]BOV*?8L=N,`-BHV+'9@0#8
MJMJOV+':KP#8JMJOV+':KP#8L=JOV*C8I]BQ(-BRV8C8K]F'V8;:K]BGV84`
MV+':K]BHV*?8L2#8K]N,V+'9A]F&VJ_8I]F%`-BYV879@B#8J-BQV8$Z(`#9
MA=BYV*?8K]F$(-BHV+'9@2#8K]BQ(-BBV*@Z(`#8M-BYV+'9A]BG(-F((-BB
MV8C8I]BRV8?8IP#8K-F'V*H@V878L=BJV*@@V+/8I]BRVXP`V*?9AMBJV*[8
MI]BH(-BLV8?8JB#9A=BQV*K8J"#8L]BGV++;C`#8HMBOV+'8LR#8L]BQVH;8
MM-F%V8<`V+/8L=J&V+39A=F'XH",V8?8IP!3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RD`V8;;C-F%(-JIV+'9AR#8K-F&V8C8J-N,`-F!V*?8M=F$V8?9
ME"#8J-N,V88@V+/9A-F(V839A]BGVXP@V878K-BGV8C8L0#9@=BGV+79A-F'
MV90@V*C;C-F&(-F%V*W8JMF(V*<@V8@@V838J-F'(-BOV+$@V+/9A-F(V80`
MV8'8I]BUV839A^*`C-JOV+#8I]BQ`-F!V*?8M=F$V8<`V8'8I]BUV839A^*`
MC-JOV+#8I]BQVXP@V8@@V*_8L=BRVJ_8L-BGV+';C`#9A]BQV++9AMBGV879
MAP#:J=BGV+'8I]JIV*K8L2#8KMBGV+4@V8C8I]BQV*\@V+38KP#9A=BTV*[8
MM2#:J=BQV*_9AB#9A=BMV80@V8;9A=BGVXS8M"#9AMBJV*?;C-BL(-BLV+/8
MJMBLV8C;C"#9OMN,V+38L=F!V*K9AP#8JMF"V+/;C-F%(-BSV839B-F$`-BJ
MV8+8L]N,V84@V+/8JMF(V88`V*K9@MBSVXS9A2#8L]BWV+$`V8C8L=BRV+3;
MC`#8I]BSV*K8I]F&V*_8I]BQV*\`V+/8JMBGV+'9AP#8L]BGV80@V+38L=F(
MV+D`V8C8MMBYVXS8JB#8K=F(V++9A^*`C-F'V*<`V8C8MMBYVXS8JN*`C`#9
M@MBGV838J"#8L-BNVXS8L=F'(-BSV*?8LMN,`-BBV*_8L=BS(-BNVXS8I]BH
MV*?9A@#9@=F'V+'8L]BJ(-BQV+38JMF'`-BTVXS9B-F'(%M#4U-=`-N,VJG8
MM-F&V*C9AP#8N=F&V8C8I]F&`-BGV+'8L]BGV80`V++;C-BQV8;9B-N,V+,`
MV879B-F!V9'9@MN,V9'8J@`E<R#8J-BG(-F%V8C9@=F"VXS9D=BJ(-BHV8<@
M)7,@V*?8MMBGV8'9AR#8M-BO`-F!V8?8L=BSV*H@V*K9A=BGV+,@(B5S(B#8
MJ-BG(-F%V8C9@=F"VXS9D=BJ(-BGVXS8K-BGV*\@V+38KP`B)7,B(-BHV*<@
MV879B-F!V9'9@MN,V9'8JB#8K=BPV8$@V+38KP#9OMN,VJG8L=BHV8;8K]N,
M(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-BGV++:K]BQV*_8I]F&V*_9AR#8
MM-BO+B#8J-BQV*?;C"#9A=BTV*?9A]BOV8<@V*K8NMN,VXS8L=BGV*H@V878
MK-BOV*_8I]F2(-BBV8;8L=BG(-BHV*?8L2#9AMF%V*?;C-N,V*\`V;[;C-JI
MV+'8J-F&V*_;C"#9OMBTV*K;C-BHV*?9AB#8J-BG(-F%V8C9@=F1V8+;C-F1
MV*H@V*W9@=BX(-BTV*\`V;[8L=F(V8;8K]F'(-F^V+38JMN,V*C8I]F&(-F^
MVXS:J=BQV*C9AMBOVXP@)7,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BMV8'8
MN"#8M-BO`"5S(-BHV*<@V879B-F!V9'9@MN,V9'8JB#9AMF(V+38JMF'(-BT
MV*\`V*[9A-BGV+79AP#8M]F$V8C8N2#8HMF!V*K8I]BH`-BZV+'9B-BH(-BB
MV8'8JMBGV*@`V*+9@=BJV*?8J-N,`-BWV839B-BY`-BWV839B-BY+]BZV+'9
MB-BH`-BWV839B-BY.B``V+K8L=F(V*@`V+K8L=F(V*@Z(`#8J-BGV838I]F&
MV8C;C-BS`-F^V+38JMN,V*C8I]F&VXP`V8;8I]F%(-BNV*?9AMF(V*?8K]JO
MVXP`V*[8M]BGVXP@V8;8K=F(VXP@V*_8L2#9A=F(V*?8L=BO(-BLV+/8JMBL
MV8@`5"U3=&]R;7,`5"U3=&]R;7,`5%-6`-F^V+'9B-F&V*_9AR!44U8`V879
M@MBGV*_;C-BQ(-BLV*_8IR#8M-BOV8<@V*C8IR#9@=BGV+79A-F'V90@VH;9
MAMBOV*K8I]N,VXP`V*S8K]F(V80`V*[8M=F(V+7;C-BGV*H@V*S8K]F(V80`
MV*[8M=F(V+7;C-BGV*H@V*S8K]F(V80`V8?8K]F!.@#9B-BXV*?;C-F!`-BT
MV878I]BQV8<@V*K9A-F!V88`V*_9A=BGVXP@V+/8I]BYV*H@V*?8KMN,V+$Z
M(`#8K]BQV*S9AR#8K=BQV*?8L=BJ`-BOV+'8K-F'(-BMV+'8I]BQV*HZ(`#8
MI]F$VJ_9B-N,(-BSV+'9OMBQV+/8JMN,`-F%V*K9A@#9@=F"V+<@V878JMF&
M`-BJV+'8I]BR(-F%V*K9A@#8J-BGV838I]N,(-F%V*K9A@#9OMF&V*S8M-F&
MV*C9AP!4:&%I("A425,M-C(P*0#8I]BR(-BTV878IR#8J-F'(-BNV*?8M]BQ
M(-BGV+/8JMF!V*?8K]F'(-BGV+(@V+/8I]F%V*?9AMF'(-F%V*K8M-JIV+';
MC-F%`-BHV+/8MR!&5%`@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,V+/8J@#9
MAMJOV8?8K]BGV+';C#HZ(-JIV838I]BS(-BHV*<@V879B-F!V9'9@MN,V9'8
MJB#8J-BGV+$@V8;8M-BO`-F^V8;8K-BQV8?9E"#:K]BRVXS9AMF'XH",V8?8
MIR#8J-BSV*K9AR#8M-BO+B#8KMBQV8C8K`#9OMBTV*K;C-BHV*?9AB!61E,@
MV*C8I]N,V*\@V;[;C-JIV+'8J-F&V*_;C"#8M-F(V*\@V*K8IR#9OMN,V8C8
ML]BJV8?8IR#8J-BJV8C8I]F&V8;8KR#8K]BQVXS8I]F!V*H@V+39B-F&V*\N
M`-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS("`B)7,BV879B-BLV8C8KR#9AMN,
MV+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8
MLR#8L=BG(-BNV*?9A-N,(-JIV+'8KSH@)7,`V+/8L=F^V+'8L]BJ(-BHV*?;
MC-BO(-N,VJD@V;[8M-BJVXS8J-BGV88@V878K-F(V++9A]BG(-BQV*?8C"`@
MV*_8L2#8M=F(V+'8JB#8JMF%V*?;C-F$(-BTV878IR#8J-F'(-BGV+/8JMF!
MV*?8K]F'(-BGV+(@V878K-F(V++9A]BGV(P@V;[;C-JIV+'8J-F&V*_;C"#:
MJ=F&V*\N`-BJV8;9A]BG(-BSV878JB#9OMBGVXS;C-F&`-BTV878I]BQV8<@
M240@V*K9A=BGV+,@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJV(P@V*?;C-F&
M(-BTV878I]BQV8<@V*_8L2#8K]BGV*_:K]BGV88@VXS8I]F!V*H@V8;8M-BO
M`-BJV878I]BS("`E<R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C9AR#:J=BJ
MV*?8J-J&V8<@V*+8K]BQV+,@V+39A=BG(-BGV+;8I]F!V8<@V+38KP#8JMF%
MV*?8LR#8K]BQV*[9B-BGV+/8JMN,(-BTV878IR#9A=F(V*S9B-BO(-F&VXS8
ML]BJ`-N,VJD@V*C9A-F(VJD@V*?9A=BVV*?;C"!01U`@V*C8L=BGVXP@V*C8
MI]BRV*C;C-F&VXP@VXS:J2#9OMN,V+K8I]F%(-BGV878MMBGV*$@V+38K]F'
M(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@!)1"#9@=F'V+'8L]BJ(-BJV8C8
MLMN,V+G;C"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*H@V8@@VXS8IR#8K]BQ
M(-BOV*?8K]JOV*?9AB#9A=F(V*S9B-BO(-F&VXS8L]BJ`-F!V8?8L=BSV*H@
MV*K9B-BRVXS8N=N,(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8J@#9A=BTV*[8
MM=F'XH",XH",V8?8I]N,(-BQV878LMBHV8;8K]N,(-F&VXS8I]BRV879AMBO
M(-N,VJD@V*?8L=BJV+78I]F$(-BGV879AB#9B-BH(-F%VXSB@(S8J-BGV+39
MAMBO`-F^V+'9B-F&V*_9A]F4("(E<R(@V*C8IR#9A=F(V8'9@MN,V9'8JB#8
MK=BPV8$@V+38KP#9OMBQV8C9AMBOV8<@)7,@V*C8I]N,V*\@V*_8I]BQV*?;
MC"#8JMF&V+C;C-F%("5S(-BHV*?8M-BO`-F^V+'9B-F&V*_9AR`E<R#8J-BG
MVXS8KR#8K=BGV8C;C"#8JMF&V+C;C-F%V*?8JB`E<R#8J-BGV+38KP#9OMBQ
MV8C9AMBOV8<@V*C8L2#8L=F(VXP@V*[9B-BOV+0@V8;9A=N,XH",V*K9B-BG
MV8;8KR#8L=F(V8;9B-BTV*H@V+39B-BO`-F^V+'9B-F&V*_9AR#8K=BGV8C;
MC"#8K]BGV*_9A^*`C-BGXH",VXS;C"#9AMN,V+/8JB``V878KR#8JMF%V*?9
MA2#8M=F!V*W9AR#8J-BG($E%(-F%V+3:J=F$(-BOV*?8L=BO(-F((-BGVXS9
MAB#8I]BR(-F%V+3:J=F$V*?8JB#9A=BQV8C8L=JOV+$@V87;C.*`C-BHV*?8
MM-BO+B#8I]JOV+$@V8?9AMF(V+(@V87;C.*`C-BNV8C8I]F'VXS8KR#8K=BG
MV838JB#9B-N,V+'8I]N,V+3:K]BQ(-BJV878I]F%(-BUV8'8K=F'(-BQV*<@
MV*?9A=BJV*W8I]F&(-JIV8;;C-BOV(P@V838M]F!V*?9BR#:J=F$VXS8KR#8
MJMBCVXS;C-BO(-BQV*<@V8'8M-BGV+$@V*_9A]N,V*\@`-F'V8C;C-F1V*H@
M(B5S(B#8K=BPV8$@V+38K]F'(-BGV+/8J@#8K]BQV8C9AN*`C-BHV+'8KR#8
MN=F$VXSB@(S8L=BZV84@V8C8K-F(V*\@V*?8KMBWV*?8L2#9A=N,XH",V*K9
MB-BGV8;8KR#8KMBGV*K9A=F'(-N,V*?8J-BO`-BJV8;9A]BG(-BSV878JB#:
MAMF^`-F^VXS8NMBGV84@V8'8L=BSV*K8I]BOV8<@V+38K]F'(-BQV8C;C"`E
M<R#8J-F'("5S(-BHV*<@V879B-BVV8C8N2`B)7,B(-F&V878I]N,V+0@V*_8
MI]BOV8<@V+38K]F'(-BGV+/8JBX*V*K8MMF%VXS9AMN,(-BHV+'8I]N,(-BN
MV8C8I]F&V*_9AR#8M-BOV88@V8@@VXS8IR#8K]BQVJD@V*+9AB#9B-BLV8C8
MKR#9AMBOV*?8L=BO`-F&V*?9A=N,(-JIV8<@V*C9AR#9A]F&VJ_8I]F%(-F^
MVXS9B-F&V*_8K]F'VXP@V*C9AR#8M=F!V*W9AR#8I]N,V*S8I]BO(-F&V*?9
MA=F'(-BGV+/8JMF!V*?8K]F'(-F%VXSB@(S8M-F(V*\`V*K8N=BOV*?8KR#9
M@=N,V838K^*`C-F'V*<@V*C8I]N,V*\@VXS:J2#8N=BOV*\@V*C8I]BTV*\`
MV*?9B-F$V8C;C-BJ("(E<R(@V8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!V+@@
MVJ_8L=BOV*\@V++;C-BQV*<@V879@MBOV*?8L2#8K]BGV*_9AR#8HMF&(-BG
MV+(@V*W8KR#9A=BLV*?8LB#8J-N,V+38JMBQ(-BGV+/8J@#8J-BQV8;8I]F%
MV8?B@(S8I^*`C-N,VXP@VJG9AR#8J-BQV*?;C"#9A=BTV*?9A]BOV8<@V*?;
MC-F&(-F&V8C8N2#8K]BGV*_9AR`H)7,I(-F"V*C9A-BGV8L@V879B-BQV*\@
MV*?8L]BJV8'8I]BOV8<@V8+8L=BGV+$@V87;C.*`C-JOV+'9@=BJV(P@V*_8
ML2#8L]BGV878I]F&V8<@V879B-BLV8C8KR#9AMN,V+/8J@#8JMF&V8?8IR#8
ML]F%V*H@V+'8I]BSV*H@V8@@VH;9O@#8JMF&V8?8IR#8L]F%V*H@V+'8I]BS
MV*H`V*S8K]BG(-JIV8;9AMBOV8<@V*C8I]N,V*\@VXS:J2#9AMF(VXS8L]F'
M(-BHV*?8M-BO`-JIV*?8L=BSV*?8LB`B)7,B(-BMV+#9@2#8M-BOV8<@V*?8
ML]BJ`-JIV*?8L=BSV*?8LB`B)7,B(-BMV8'8N"#8M-BOV8<@V*?8L]BJ`-BO
MV+'8KMF(V*?8L]BJ(-BGV8'8JMBJV*?8K2#8K=BSV*?8J"#8J-BQV*?;C"`E
M<R#8K=BPV8$@V+38K]F'(-BGV+/8J@#8L=BOVXS9@2#9A=BTV*[8M2#8M-BO
MV8<@V8C8K-F(V*\@V8;8K]BGV+'8KP#9OMBQV8C9AMBOV8<@V879B-F"V*K;
MC"`@(B5S(MF%V8C8K-F(V*\@V8;;C-BSV*H`V*K9AMF'V*<@V+/9A=BJ(-BH
MV*?9A-BG(-F((-F^V*?;C-N,V88`V*K9AMF'V*<@V+/9A=BJ(-BHV*?9A-BG
M`-BOV*?8K]F'V90@V*?8L=BSV*?9A"#8M-BOV8<@V*?8LB#:K]BGV84@V8+8
MJ-F$VXP@V*?8LB#8K]BSV*H@V+'9@=BJV8<@V*?8L]BJ`-F^V+'9B-F&V*_9
MAR#8I]BQV+/8I]F$(-BTV*_9AR#9AMF%VXSB@(S8JMF(V*?9AMBO(-BMV8'8
MN"#8M-F(V*\`V*C9A-F(VJD@=V5A=&AE<BYC;VT@V8+8I]BHV80@V*_8L]BJ
MV+'8LR#9AMN,V+/8J@#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8L^*`C"#9@MBG
MV*C9A"#9A=BQV8C8L=N,(-F%V8C8K-F(V*\@V8;9A=N,XH",V*C8I]BTV8;8
MKP#:K]BRVXS9AMF'XH",V*?B@(SB@(S;C-N,(-BOV+$@V*_8L]BJV+'8LR#9
MAMN,V+/8J@#8J-BNV+3;C"#:J=F'(-BHV*K9B-BGV8;8KR#8J-BQV*[8MR#9
MAMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8KR#9A=F(V*S9B-BO(-F&VXS8L]BJ
M`-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F"V*?8J-F$(-F&V8C8M-BJV88@
MV879B-BLV8C8KR#9AMN,V+/8JBX@V8?;C-J&(-N,VJD@V*?8LB#:J=BJV*?8
MJ-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,@V8+8I]BHV80@V*_8L]BJV+'8L]N,
MV(P@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9AB#9B-BQV8C8K]N,(-BL
MV*_;C-BO(-BHV8<@V*+9AMF'V*?8C"#9OMN,VJG8L=BHV8;8K]N,(-F&V+38
MK]F'XH",V*?9AMBO+B#8I]JOV+$@V8':J=BQ(-F%VXSB@(S:J=F&VXS8KR#8
MI]N,V88@V*W8I]F$V*H@VXS:J2#8KMBWV*?8L]BJV(P@V838M]F!V*?9BR#8
MJ-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO(-BJV878I]BS
M(-BHVJ_;C-BQVXS8KRX`V8;9B-N,V+/9A^*`C-F'V*?;C"#8LMN,V*?8K]N,
M(-BOV+$@V*?;C-F&(-F!VXS9A-BO(-F"V+'8I]BQ(-BOV*?8L=BO+B#8M-F%
MV*<@)7,@V8;9B-N,V+/9AR#9B-BGV+'8KR#:J=BQV*_9A^*`C-BGXH",VXS8
MKR#8K]BQ(-BMV*?9A-N,(-JIV8<@V+39A=BG(-BHV*?;C-BO(-JIV878JMBQ
M(-BGV+(@)7,@V8;9B-N,V+/9AR#9B-BGV+'8KR#:J=F&VXS8KP#9A=BTVJG9
MA-N,(-BOV+$@V*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<@V+'8KB#8K]BGV*_9
MAR#8I]BSV*HZ("5S(-BGV+'8L]BGV80@V8;8M-BO`-F%V+3:J=F$VXP@V*_8
ML2#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#8L=BN(-BOV*?8K]F'(-BGV+/8
MJCH@V*?9AMBOV*?8LMF'("5S(-BHVXS8M-BJV+$@V*?8LB#8K=BO(-F%V*S8
MI]BR(-BHV8C8K]F'(-BGV+/8JB`H("5D(-BHV*?;C-BJ*2X`V878M-JIV83;
MC"#8K]BQ(-BGV+'8L]BGV80@V;[8L=F(V8;8K]F'(-F(V*S9B-BO(-BOV*?8
MM-BJV8<@V*?8L]BJ.B`@)7,@V*C9AR#8M=F(V+'8JB#8JMJIV8?B@(S8I^*`
MC-N,VXP@V*?8L=BSV*?9A"#8M-BOV8<@V*?8L]BJ(`#8KMBWV*?;C-N,(-BO
MV+$@V*?8MMBGV8'9AR#:J=BQV*_9AB#8JMF%V*?8LR#8K-BOVXS8KR#8L=BN
M(-BOV*?8K]F'(-BGV+/8JBX@V*C8L=BGVXP@V+'8I]F'V8;9A=BGVXS;C"#8
MJ-N,V+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9A]F4(-BN
MV8C8KR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\N`-BNV+?8I]N,VXP@V*_8L2#8
MI]BVV*?9@=F'(-JIV+'8K]F&(-BGVXS9AB#8M-N,V*$@V+'8KB#8K]BGV*_9
MAR#8I]BSV*HN`-BNV+?8I]N,VXP@V*_8L2#8I]N,V*S8I]BO(-N,VJD@V83;
MC-BSV*H@V*S8K]N,V*\@V+'8KB#8K]BGV*_9AR#8I]BSV*HN`-BNV+?8I]N,
MVXP@V*_8L2#8K=BPV8$@V*K9A=BGV+,@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ
M("5S+@#8KMBWV*?;C-N,(-BOV+$@V*W8L-F!(-BGVXS9AB#8M-N,V*$@V+'8
MKB#8K]BGV*_9AR#8I]BSV*HN`-BNV+?8I]N,VXP@V*_8L2#9AMF%V*?;C-BT
M(-F!V8?8L=BSV*H@V+'8KB#8K]BGV*_9AR#8I]BSV*HN`-BNV+?8I]N,VXP@
MV*_8L2#9AMF%V*?;C-BT(-BGVXS9AB#8J-BNV+0@V;[;C-BZV*?9A2#8L=BN
M(-BOV*?8K]F'(-BGV+/8J@#8KMBWV*?;C-N,(-BOV+$@V*_8L=F(V8;B@(S8
MJ-BQV*\@VJG8L=BOV88@V*_8I]BOV8<@V*K9A=BGV+,@V+'8KB#8K]BGV*_9
MAR#8I]BSV*H`V*[8M]BGVXS;C"#8K]BQ(-BOV+'9B-F&XH",V*C8L=BO(-BO
MV*?8K]F'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<P#8KMBWV*?;C-N,(-BO
MV+$@V*_8L=F(V8;B@(S8J-BQV*\@V*_8I]BOV8?9E"!I0V%L96YD87(@V+'8
MKB#8K]BGV*_9AR#8I]BSV*HN`-BNV+?8I]N,VXP@V*_8L2#9OMN,VJG8L=BH
MV8;8K]N,(-F!V+'9A2#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V+38I]N,V*\@
MV8';C-F$V*\@V879B-BQV*\@V8;;C-BGV++;C"#8L=BG(-BLV*<@V*?9AMBO
MV*?8KMBJV8?B@(S8I^*`C-N,V*\`V*[8M]BGVXS;C"#8K]BQ(-BGV*S8L=BG
M(-JIV+'8K]F&(-BYV879A-N,V*?8JB#9A=BTV*[8M2#8M-BOV8?9E"#:J=BJ
MV*?8J-J&V8<@V*+8K]BQV+,@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-F$V+?9
M@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KP#8KMBWV*?;C-N,
M(-BOV+$@V*W8L-F!(-N,VJD@V*K9A=BGV+,@V*?8LB#9@=F'V+'8L]BJ(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ+@#8KMBWV*?;C-N,(-BOV+$@V*C8L=F(V++8
ML=BSV*?9AMN,(-BLV++8IMN,V*?8JB#8JMF%V*?8LR#8L=BN(-BOV*?8K]F'
M(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;
MC-BO`-BNV+?8I]N,VXP@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V8'9A]BQ
MV+/8JB#8JMF(V++;C-BYVXP@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-F$V+?9
M@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KP#8KMBWV*?;C-N,
M(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-BGVXS9AB#9B-BQV8C8K]N,(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<P#8HMBOV+'8L]N,(-BHV+'8I]N,(-BH
MV+'9B-F&XH",V*C8L=BO(-F&V879B-BOV88@V879B-BLV8C8KR#9AMN,V+/8
MJBX`V*?;C-F&(-JIV*K8I]BHVH;9A^*`C-F'V*?;C"#8HMBOV+'8LR#8J-BG
M(-BGVXS9AB#8JMBQV*K;C-BH(-F&V878I]N,V+0@V*_8I]BOV8<@V*[9B-BG
MV8?9AMBO(-BTV*\Z`-BGVXS9AB#8L]BJV8C9AMF'V*<@V*C8IR#8I]N,V88@
MV*K8L=BJVXS8J"#9AMF%V*?;C-BT(-BOV*?8K]F'(-BNV8C8I]F'V8;8KR#8
MM-BO.@`@VJG8I]BQV+/8I]BR($E-05#9OMF(V+39A^*`C-F'V*?;C"#9A=BT
MV*K8L=JI(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V*\`
M(-BHV8<@V8;8N-BQ(-F&V87;C.*`C-BQV+/8KR#:J=F'(-BBV+'8M-N,V8@@
M<F%R(-F%V+G8JMBHV+';C"#8J-BGV+38KP`@V*C9AR#9AMBXV+$@V8;9A=N,
MXH",V+'8L]BO(-JIV8<@V;[8L=F(V8;8K]F'('II<"#9A=BYV*K8J-BQVXP@
MV*C8I]BTV*\`V*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V+39
MA=BGV+'9AR#:J=BGV+'8JB#9A=BYV*K8J-BQVXP@V*C8I]BTV*\`V*?;C-F&
M(-F!VXS9A-BO(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#8I]N,V88@V8';
MC-F$V*\@V879A=JIV88@V*?8L]BJ(-BTV*?9A=F$(-BGV+G8K]BGV*\@V+78
MK=N,V*T@V*C8I]BTV*\`V*?;C-F&(-F!VXS9A-BO(-F%V87:J=F&(-BGV+/8
MJB#8M-BGV879A"#8I]BYV*_8I]BO(-F((-F(VXS8L=JOV8C9A"#8J-BGV+38
MKP#8I]N,V88@V8';C-F$V*\@V879A=JIV88@V*?8L]BJ(-BTV*?9A=F$(-F%
MV8+8I]BOVXS8L2#9A]BTV*H@V8?8M-BJVXP@V*C8I]BTV*\`V*?;C-F&(-F!
MVXS9A-BO(-BHV*?;C-BO(-BMV*?9B-N,(-JIV*?9A=BG(-F((-N,V*<@V8'9
MA]BQV+/8JMN,(-BGV+(@V*?8N=BOV*?8KR#8M=BMVXS8K2#8K-BOV*<@V+38
MK]F'(-BHV*<@V8;9B-N,V+/9AR#8KMBGV83;C"#8J-BGV+38KP#8I]N,V88@
MV8';C-F$V*\@V*C8I]N,V*\@VXS:J2#8N=BOV*\@V878N=BJV*C8L2#8J-BG
MV+38KP#9@MBGV838J"#8I]N,V88@V;[8L=F(V8;8K]F'(-F^V+38JMN,V*C8
MI]F&VXP@V8;9A=N,XH",V+39B-BO+@#8I]N,V88@)7,@V87;C.*`C-BHV*?8
MM-BO`-BGVXS9AB#9OMN,V+K8I]F%(-BHV*<@V878K-F%V8C8N=F'(-JIV*?8
ML=BGVJG8JMBQ("5S(-F&V8C8M-BJV8<@V+38K]F'(-BGV+/8JB#:J=F'(-BH
MV*<@V878K-F%V8C8N=F'(-JIV*?8L=BGVJG8JMBQ(-BTV878IR#9A=BJV8'8
MI]F(V*H@V*?8L]BJ`-BGVXS9AB#8N=BOV*\@V*W8K]BGV8+9A"#8J-BGVXS8
MKR#;C-JI(-BHV*?8M-BO`-BGVXS9AB#9@=BQV*\@V8?9A2#8I]JIV8;9B-F&
M(-N,VJD@V8C8L=F(V*_;C"`E<R#8K]BQ(-JIV*K8I]BHVH;9A]F4(-BBV*_8
ML=BS(-BOV*?8L=BO+@#8I]N,V88@VJG8I]BQV+/8I]BR(-F^V+'9B-F&V*_9
MA^*`C-F'V*?;C"!Z:7`@V8@@9WII<"#8L=BG(-BHV*?8LB#9AMF%VXSB@(S:
MJ=F&V*\`V*?;C-F&(-BSV*?9A=BGV8;9AR#8K]BQ(-BMV*?9A"#8K=BGV+;8
ML2#8NMN,V+$@V8'8N=BGV80@V*?8L]BJ`-BGVXS9AB#9A=F"V*_8I]BQ(-BH
MV*?;C-BO(-BYV*_8KR#8J-BGV+38KP#8I]N,V88@V;[9AMBLV+'9AR#8J-BG
MVXS8KR#8I]BR(-F^V8;8K-BQV8?9E"#:K]BRVXS9AMF'XH",XH",V8?8IR#9
M@=BQV*?8KMF(V*?9AMN,(-BTV8C8KP#8L=BYV*\`V*C9A-N,V+?9A]BG`-BR
MV878I]F&`-BQV*_;C-BGV*C;C"#8LMF%V*?9A@#9@MBGV838J"#8LMF%V*?9
MA@`@V*?9AMBJV*[8I]BH(-BRV878I]F&(`#8N=F&V8C8I]F&`-BYV8;9B-BG
MV88@*-BQV*?9A]F&V878I]N,(-BBV8;;C"DZ`-BHV8<`V*C8L=BGVXP@V*?9
MAMBJV*[8I]BH(-J&V8;8KR#9@=N,V838K]B,(-BOVJG9A=F'($-T<FP@V+'9
MB-N,("A00RD@VXS8IR!#;VUM86YD(-BQV8C;C"`H36%C*2#8L=BG(-BOV+$@
MV878K]BJ(-JIV83;C-JI(-JIV+'8K]F&(-F&VJ_9A]BOV*?8L=N,V*\`V*?9
MA=BQV8C8L@#9@=BQV*_8IP#8J-BGV838IP#:AMBGV+':AMF(V*@@V*C8I]F$
MV*<@*-BHV*?9A-BG*0#8JMBQV*S9A=F'XH",V8?8IP#8K]BQV+/8JB#9B"#;
MC-BG(-F&V*?8K]BQV+/8J@#8L]F'(-BTV8;8J-F'`%1U<FMI<V@@*$E33RTX
M.#4Y+3DI`-BGV8;8JMBNV*?8J"#8KMF(V*\@V+'8IR#8JMBGVXS9OB#:J=F&
MVXS8KSH`V+38I]BNV+4@52Y6+B`Z(`!54DP`55),.@#8I]F%VJG8I]F&(-BO
MV+/8JMBQV+/;C"#8J-F'(-BTV*?8KMF'(%9&4R#9AMN,V+/8J@#8I]F%VJG8
MI]F&(-BGV+;8I]F!V8<@VJG8L=BOV88@V*?8M]F$V*?8N=BGV*H@V*?8MMBG
MV8';C"#:J=BGV+'8J-BQ(-BHV8<@V8?9AMJOV*?9A2#8J]BHV*H@V8;8I]F%
M(-F&VXS8L]BJ`-F&V87;C.*`C-BJV8C8I]F&(-F%V*S9B-BRV8?8IR#8L=BG
M(-BHV+'8I]N,(-F^V+'9B-F&V*_9AR`B)7,B(-BJV+K;C-N,V+$@V*_8I]BO
M`-F&V87;C.*`C-BJV8C8I]F&(-F%V*S9B-BRV8?8IR#8L=BG(-BHV+'8I]N,
M(-F^V+'9B-F&V*_9AR`E<R\E<R!61E,@(-BJV+K;C-N,V+$@V*_8I]BO`-F&
MV87;C.*`C-BJV8C8I]F&(-BOV+$@)7,@V*K8NMN,VXS8L2#8K]BGV*\`V8;9
MA=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@4U%,V878JMBUV80@
MV+38KP#9AMF%VXSB@(S8JMF(V*?9AB#8J-BG(%-33"#9A=BJV+79A"#8M-BO
M`-F&V87;C.*`C-BJV8C8I]F&(-BGV+(@V;[8L=F(V8;8K]F'(%9&4R#8L=F(
MV8;9B-BTV*H@V*K9A]N,V8<@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@
MV+38I]BNV8<@5D93("(E<R(@V+'8IR#8I]N,V*S8I]BO(-F&V879B-BO`-F&
MV87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BGVXS8K-BGV*\@
MV8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8
ML=BG(-BGVXS8K-BGV*\@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V;[8
ML=F(V8;8K]F'(-BNV*?9A-N,(%9&4R`@V*?;C-BLV*?8KR#9AMF%V8C8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR#8L=BG(-BHV*?8LB#:J=BQV*\@
M`-BMV+#9@2`B)7,B(-F%V87:J=F&(-F&VXS8L]BJV(P@V+38I]BNV8<@V*[8
MI]F$VXP@V8;;C-BSV*H`V8;9A=N,XH",V*K9B-BGV88@(B5S(B#8L=BG(-BM
MV+#9@2#:J=BQV*\Z("5S+@#8K=BPV8$@)7,@V879A=JIV88@V8;;C-BSV*K8
MC"#8M-BGV*[9AR#8KMBGV83;C"#9AMN,V+/8J@#9AMF%VXSB@(S8JMF(V*?9
MAB#8M-BGV*[9AR!61E,@V+'8IR#8J-F'(-BUV8C8L=BJ(-BJV8@@V*_8L2#8
MJMF((-BMV+#9@2#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9
MAR!61E,@V+'8IR#8K=BPV8$@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@
MV+38I]BNV8<@5D93(-BQV*<@V*W8L-F!(-F&V879B-BO.B`E<RX`V8;9A=N,
MXH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`B)7,B(-BQV*<@V*W8L-F!
M(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@
MV+'8IR#8K=BPV8$@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@5D93(-BQ
MV*<@V*C9AR#8M=F(V+'8JB#8JMF((-BOV+$@V*K9B"#8K=BPV8$@V8;9A=F(
MV*\Z("5S+@#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9A]F4(-F!V+G9A-N,
M(-BQV*<@V*K8M-BNVXS8M2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V*S8
MLMBFVXS8I]BJ(-JOV8C8I]F'VXP@V+'8IR#8I]BSV*K8KMBQV*?8K"#9AMF%
MV8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8JMBYV+';C-F!("5S(-BQV*<@V*C8
MI]BQVJG8L=BO+@#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93
M(-BQV*<@V*?9AMBJV8+8I]F$(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#9
MOMBQV8C9AMBOV8<@5D93("(E<R(@V+'8IR#8J-BGV+(@V8;9A=F(V*\`V8;9
MA=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BHV+'8I]N,
M(-F&V8C8M-BJV88@V*C8I]BR(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9
MOMBQV8C9AMBOV8<@5D93(-BQV*<@V*C8I]BR(-F&V879B-BO`-F&V87;C.*`
MC-BJV8C8I]F&(-BBV+'8M-N,V8@@V8'8M-BQV*_9AR#8L=BG(-BHV*?8LB#:
MJ=BQV*\`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@=F9S<F]O="#8L=BG
M(-BNV8C8I]F&V*\`V8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8J-F'("5S
M("#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\Z(-F^V8C8M-F'(-F%V8+8M=BO
M(-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ`-F&V87;C.*`C-BJV8C8
MI]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8
MKP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8JMBZVXS;
MC-BQ(-F&V*?9A2#8K]BGV*\Z("5S+@#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQ
MV8C9AMBOV8<@5D93("(E<R(@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BG
MV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`E<R\E<R#8
ML=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9
MAB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8
MI]BO`-F&V87;C.*`C-BJV8C8I]F&("=M:VES;V9S)R#8L=BG(-BGV*S8L=BG
M(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BGVXS9AB#8L]F&V*\@5V]R
M9"#8L=BG(-BJV+'8K-F%V8<@V8;9A=F(V*\`(-F&V87;C.*`C-BJV8C8I]F&
M(-BOV+$@V;[8L=F(V8;8K]F'("(E<R(@5D93("#9AMF(V+38J@`@V8;9A=N,
MXH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@5D93(-F&V8C8M-BJ+@#9
MAMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9A]F4(-BOV*?8K]F'
M(%9&4R#9AMF(V+38J@#8LMN,V+'8KMBWXH",V*_8I]BQ`-F(V*?:K]BQV*_8
MI]F&V*_9AB#8JMBZVXS;C-BQV*?8J@#9B-BGVJ_8L=BOV*?9AMBOV88@V*+8
MKMBQVXS9AB#8N=F%V80@V+39A=BG`-F^V*?8L]BN(-BZVXS8L2#9A=F&V*K8
MN-BQV8<@V*?8LB#:J=BGV+'8L]BGV+(@V*C8L2#8L=F(VXP@V*?8JMBUV*?9
MA#H`V;[8I]BSV*X@V+K;C-BQ(-F%V8;8JMBXV+'9AR#8I]BR(-JIV*?8L=BS
MV*?8LB#8J-F'.@#8NMN,V+$@V*W9B-BRV8<`56YI8V]D92`H551&+3@I`-F(
MV*?8K=BOV8?8IP#8K]BGV*_9AR#9AMBGV+39AMBGV*[8JMF'`-F&V*?9A2#:
MJ=BGV+'8J-BQ(-F((-N,V*<@V*?8L]F%(-BQV878LB#9AMBGV+39AMBGV*[8
MJMF'`-F"V+?8N2#9OMN,V8C9AMBO(-BYV8;8M=BQ(-F!V+G9A-N,`-BHVXP@
MV8;8I]F%`-BOV+/8JB#B@(S9AMF(VXS8L]F'V*?;C"#8J-BOV8C9AB#8I]F%
MV*K;C-BGV+(@V*C9AR#8K]F$VXS9A"#8I]F%V8;;C-BJVXP@V8;9A=N,XH",
MV*K9B-BGV8;9AMBO(-BGV+(@V+?8L=N,V8(@V*C8L=F&V*?9A=F'(-F&V8C;
MC-BSVXP@V*C8L=N,V*_9AR_8L=F(V8;9B-BTV*H@VJ_8L=F!V*K9AR_:AMBS
MV*C;C-BOV8<@V+39B-F&V*\N(-JIV83;C-BO(-BJV*/;C-N,V*\@V+'8IR#9
M@=BTV*?8L2#8K]F'VXS8KR#8JMBG(-F%V*K9AB#9@=F&VXSB@(S8I^*`C-N,
MVXP@V+'8IR#8K]BQ(&UO>FEL;&$N;W)G(-BHV*<@V+G9AMF(V*?9AB#:AMJO
MV8C9AMJOVXP@V*_8L]BJV+'8L]N,(-N,VJD@V*_8L]BJ(.*`C-F&V8C;C-BS
M(-BHV8<@V*K8KMBJV8?9E"#8L=BSV84@V+'8IR#9A=BTV*?9A]BOV8<@VJG9
MAMN,V*\`V+'9AMJO(-BJV8;8N-N,V84@V8;8M-BOV8<`V8;9B-BY(-F%V*K9
MAB#8J-BOV8C9AB#9OMBTV*K;C-BHV*?9AMN,.B`E<P#8J-BSV+<@V*C8K]F(
MV88@V;[8M-BJVXS8J-BGV8;;C`#8J-BQV8C8LMBQV+/8I]F&VXP`V*C8L=F(
MV++8L=BSV*?9AMN,("5S`-BHV+'9B-BRV+'8L]BGV8;;C"#:J=BGV+'8J-BQ
M`"(E<R(@V*C8L=F(V++8L=BSV*?9AMN,(-BTV*\`V*_8L]BJXH",(-F&V8C;
MC-BS(-BHV8?;C-F&V8?B@(S8L]BGV++;C"#8K=BPV8$@V+38KP#8I]BQV+/8
MI]F$(-JIV+'8K]F&`-BJV878I]F%(-F^V+'9B-F&V*_9A^*`C.*`C-F'V*?;
MC"#8JMF&V+C;C-F%(-BHV+'9AMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQ
MV*_;C"#8J-F'(-JIV*?8L=BSV*?8LB#8I]BQV+/8I]F$(-BTV*\`V*W8L=F(
MV8$@V*C8LMBQVJ\@V838I]BJVXS9A@#8I]BYV*_8I]BO(-N,V8C9AMBGV8;;
MC"#8J-BRV+':KP`@V*?8L]BJV8'8I]BOV8<@V8'8N=F$VXPZ("5S`-BGV+/8
MJMF!V*?8K]F'(-BGV+(@4U-,`-BGVJ_8L2#9AMBGV84OV*?8L]F%(-BQV878
MLB#8J-BQV*?;C"#:J=BGV+'8L]BGV+(@24U34"#9A=BJV8'8I]F(V*H@V*?8
ML]BJV(P@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\`VJG8I]BQV*C8L2`E<R`@
MV*C8L=BGVXP@)7,@V*?8K=BQV*?8LB#9A]F(VXS9D=BJ(-F&V+38K]F'(-BG
MV+/8J@#8L]BQV;[8L=BSV*K;C"#:J=BGV+'8J-BQ`-JOV++;C-F&V8?B@(S9
MA]BGVXP@VJG8I]BQV*C8L0#8J]BHV*H@V8;8I]F%(-JIV*?8L=BHV+$`V*O8
MJ-BJ(-JIV*?8L=BHV+$@V*C8L=BGVXP@V*?;C-F&(-F^V*?;C-JOV*?9AR#8
MNMN,V+$@V8'8N=BGV80@V+38K]F'(-BGV+/8J@#8K=BSV*?8J"#:J=BGV+'8
MJ-BQ(-F^VXS8K]BG(-F&V+38KP#9AMBGV84@VJG8I]BQV*C8L0#9AMBGV84@
MVJG8I]BQV*C8L3H`V8;8I]F%(-JIV*?8L=BHV+$Z(`#:J=BGV+'8J-BQV*?9
MAB#8L]BGV878I]F&V8<Z`-BTV*?8KMF'(%9&4R#9B-BLV8C8KR#9AMBOV*?8
ML=BO`-BJV+G8M]N,V838I]BJ`-F%V8C9@MBYVXS8JMF'V*?;C"#9A=BYV*K8
MJ-BQ(-N,V*?9@=BJV8<@V+38K]F'(-BYV*C8I]BQV*K9AMBO(-BGV+(Z`-BG
MV+G8JMBHV*?8L0#9A=F"V*_8I]BQ(-BHV8<@V*_9@MN,V8+9AR#8I]BR(-BM
MV*?9A-BG`-F%V8+8K]BGV+$@V*?8LB#8J-N,V+3;C-F&V8<@V+?9B-F$(-F%
MV*S8I]BR("5S(-BHVXS8M-BJV+$@V*?8L]BJ`-F%V8+8I]BOVXS8L0#9A=F"
MV*?8K]N,V+$@V*C8L=BGVXP@V*?9AMBJV*[8I]BH(-BGV+(`V878JMBZVXS;
MC-BQ`-BTV*?8KMF'V90@5F5R:7-I9VX`V8;8L]BNV8<`VJG9AMBJV+'9A"#9
MAMBSV*[9AP#8JMBQV*?8LB#8N=F%V8C8K]N,`-F!V*?8M=F$V8?B@(S:K]BP
MV*?8L=N,(-BYV879B-BOVXP`V+G9A=F(V*_;C#H`V*[;C-F$VXP@V*C8I]F$
MV*<`5FEE=&YA;65S92`H5DE30TE)*0#9AMF%V*?;C"`E<P#9AMF%V*?;C-BT
M(-BJV878I]BS`-F&V878I]N,(-N,VJD@V+79@=BMV8<@V8C8J"#8KMBGV+'8
MK-N,`"#9AMF%V*<@V*C9AR#8N=F&V8C8I]F&("5S`-F&V878I]N,V+0@V;[;
MC-BT(-F!V+'8M@#9@MBGV*C9A-N,V*H@V878M-BGV8?8K]F'`-F"V*?8J-F$
MVXS8JB#9A=BTV*?9A]BOV8<Z(`#8I]BNV+?8I]BQ(2$A(-BOV+/8JB#B@(S9
MAMF(VXS8LR#8L=BG(-BHV+?9B-BQ(-BOV+/8JMN,(-BGV+(@)7,@V*W8L-F!
M(-JIV8;;C-BO`-BGV*[8M]BGV+$Z(`#:AMF'V*?8L=BTV8;8J-F'`-F^VXS8
MM.*`C-BHVXS9AMN,(-F'V8C8IP#8K]BGV*_9AR#8HMBH(-F((-F'V8C8I]N,
MVXP@V8'8L=BGV8?9A2#8M-BOV8<@V*C9AR#9B-BSVXS9A-F'`'=E871H97(N
M8V]M`-F(V*@`V8C8J.*`C-JOV*?9AP!54DP@V8C8J.*`C-JOV*?9AP#9A]F!
MV*K:K]N,`-BNV8C8M"#8HMF%V*_;C-BO`-BHV8<@)7,@V*[9B-BT(-BBV878
MK]N,V*\`)7/8C"#8KMF(V+0@V*+9A=BOVXS8KP!797-T97)N("A)4T\M.#@U
M.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`VH;9AR#8J-BQV8;8I]F%V8?9
ME"#:J=BGV+'8J-BQV*_;C"#8L=BG("5S(-BHV*?;C-BO(-BHV+G8KR#8I]BR
M(-F(V+'9B-BO(-F&V+38I]F&(-BOV8?8K]B?`-F&V8C;C-BSV8?9E.*`C"#8
MK=BGV*;9A"#:AMN,V+/8JMB?`-F&V8C;C-BSV8?B@(S;C"#9AMF"V80@V8+9
MB-F$(-J&VXS8L]BJV)\`VJG8K]BGV84@V8'8I]BR`-JIV*_8I]F%(-BHV+'9
MAMBGV879A^*`C-F'V*?;C"#9A=BJV+79A.*`C-JIV8;9AMBOV8<@XH",V*C8
ML=BGVXP@V8C;C-BQV*?;C-BTVJ_8L2#9A=BJV88@V8'8N=BGV80@V*C8I]BT
MV8;8KP#8N=BQV+8`(-F^V8?9AMBG(-BOV+$@V8C8I]BMV*\@0U-3(`#9OMF'
MV8;8I]N,(-JOV++;C-F&VJ_8I]F&("5S(-BOV+$@V+'8I]BSV*H@*-BOV+$@
MV8C8L=F(V*\@V*C8N=BOVXP@V879B-BKV+$@V87;C.*`C-JOV+'8K]BO*3H`
MV;[9A]F&V*?;C"#8K-BOV8C9A`#9B-BGV*W8KR#9OMF'V8;8IP#9OMF'V8;8
MISH`5VEK:0#8J-BGV*\Z`-BHV*?8KR#8LMF(V*_9A]F&VJ_8I]F%.B``V+/8
ML=BYV*H@V*C8I]BO(-BHV+'8K=BSV*@@V8'9B-BJ(-BHV+$@V+/8I]BYV*H`
MV*C8I]BO.@#8J-BGV*\Z(`#8N=F"V80`VJG8I]BQ`-BBV*_8L=BS(-F%V*W9
MA"#:J=BGV+$`V+39A]BQ(-F%V*W9A"#:J=BGV+$`VJG8M-F(V+$@V878K=F$
M(-JIV*?8L0#8JMF$V8'9AB#9A=BMV80@VJG8I]BQ`-JIV*_9OMBSV*K;C"#9
MA=BMV80@VJG8I]BQ`-BGVXS8I]F$V*HOV*?8L]BJV*?9AB#9A=BMV80@VJG8
MI]BQ`-BBV*_8L=BS(-BNVXS8I]BHV*?9AB#9A=BMV80@VJG8I]BQ`.*`C%E9
M`%E965D`V+/8I]F$V*?9AMF'`-BBV+';C`#8J-F$V8?8C"#9A=F(V*?9@=F"
MV84`V+39A=BG(-BOV+$@V878KR#9A=BJV88@V8?8L]BJVXS8KRX@V*?8LB#8
MK]JIV879AR`@6SP^72#8J-BQV*?;C"#8J-BQVJ_8M-BJV88@V*C9AR!765-)
M5UE'(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO`-BTV878IR#9A=BLV8C8LB#8
MI]N,V*S8I]BO(-BHVXS8M"#8I]BR("5D(-BJV878I]BS(-BQV*<@V*_8L2`B
M)7,B(-F&V*_8I]BQVXS8KP#8M-F%V*<@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M(-F&V+38K]N,V*\`V+39A=BG(-F&V87;C.*`C-BJV8C8I]F&VXS8KR#9AMF(
MVXS8L]F'("=<)R#8L=BG(-BOV+$@V8;8I]F%(-JIV*?9A=F$(-BNV8C8KR#8
MK]BGV+38JMF'(-BHV*?8M-N,V*\`V+39A=BG(-BBV*_8L=BS(-F^V+/8JB#8
MI]F$VJG8JMBQV8C9AMN,VJD@V878N=BJV*C8L=N,(-F(V*?8L=BO(-F&VJG8
ML=BOV8?B@(S8I]N,V*\`V+39A=BG(-F'VXS:AB#9@=N,V838K]N,(-BQV*<@
MV*_8L2#9OMBQV8C9AMBOV8<@V*_8L=F(V8;B@(S8J-BQV*\@V+38K]F'(-BH
MV8<@V8';C-F$V*\@V878JMF"V*?8J-F$VXP@V*_8L2`E<R#9AMJOV*?8M-BJ
M(-F&VJG8L=BOV8?B@(S8I]N,V*\`V+39A=BG(-F%V*S9B-BR(-F%V+38I]F'
MV*_9A]F4(-BGVXS9AB#8JMF%V*?8LR#8L=BG(-F&V*_8I]BQVXS8KRX`V+39
MA=BG(-F%V*S9B-BR(-F%V+38I]F'V*_9A]F4(-BGVXS9AB#8M-N,V*$@V+'8
MIR#9AMBOV*?8L=N,V*\N`-BTV878IR#8KMBGV+'8K"#8M-BOVXS8KP#8M-F%
MV*<@V878K-BHV8C8L2#9A]BSV*K;C-BO(-N,VJD@V+39A=BGV+'9AR#8JMF$
MV8'9AB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BOV(P@V*?8LB#8N=F$
MV*?9A=BJ("<K)R#8J-BQV*?;C"#8M-F%V*?8L=F'XH",V8?8I]N,(-BHVXS9
MAB#8I]F$V879A-F$VXP@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\`V+39A=BG
M(-F%V*S8J-F(V+$@V8?8L]BJVXS8KR#;C-JI(-F%V8+8K]BGV+$@V878N=BJ
MV*C8L2#9B-BGV+'8KR#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#9
MOMBTV*K;C-BHV*?9AB#8K]BQV*[8JB#8K]BGV*_9AR#8J-BQV*?;C"#8I]BS
MV*K9@=BGV*_9AR#8I]BR(-BKV*C8JB#9AMBGV84@V;[;C-JIV+'8J-F&V*_;
MC"#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#8L]BGV878I]F&V8<@
MV;[8M-BJVXS8J-BGV88@5D93(-BQV*<@V;[;C-JIV+'8J-F&V*_;C"#:J=F&
MVXS8KP#9@MBHV80@V*?8LB#8I]BQV+/8I]F$(-JOV++8I]BQV+38C"#8J-BG
MVXS8KR#9A=BTVJG9A"#8L=BG(-BTV+'8K2#8K]F'VXS8KP#8M-F%V*<@V*C8
MI]N,V*\@55),V*?;C"#:J=F'(-BGVXS9AB#9OMN,V8C9AMBO(-BHV8<@V*+9
MAB#8I]BTV*?8L=F'(-F%VXSB@(S:J=F&V*\@V+'8IR#9B-BGV+'8KR#:J=F&
MVXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#:J=BJV*?8J-J&V8?9E"#8HMBO
MV+'8LR#9A=F"V+78KR#8I]F&V*K8KMBGV*@@VJG9AMN,V*\N`-BTV878IR#8
MJ-BGVXS8KR#;C-JI(-F!V8?8L=BSV*H@V879@MBUV*\@V878M-BNV+4@VJG9
MAMN,V*\N`-BTV878IR#8J-BGVXS8KR#;C-JI(-JIV*?8L=BSV*?8LMB,(-BH
MV+'8I]N,(-BMV+#9@2#:J=BQV*_9AB#8I]F&V*K8KMBGV*@@VJG9AMN,V*\`
MV+39A=BG(-BOV+$@V*?8J-BJV*_8IR#8J-BGVXS8KR#8K=BOV*?9@MF$(-N,
MVJD@V*K9A=BGV+,@V*?9AMBJV*[8I]BH(-JIV8;;C-BO+@#8M-F%V*<@V*_8
ML2#8I]BHV*K8K]BG(-BHV*?;C-BO(-BMV*_8I]F"V80@VXS:J2#9B-BQV8C8
MK]N,(-BGV8;8JMBNV*?8J"#:J=F&VXS8KRX`V+39A=BG(-BHV*?;C-BO(-N,
MVJD@V8;8I]F%(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8K=BPV8$@VJG8L=BO
MV88@V878M-BNV+4@VJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(-N,VJD@V8;8
MI]F%(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8K=BPV8$@V+38K]F&(-F%V+38
MKMBU(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-F&V*?9A2#:J=BG
MV+'8J-BQV(P@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BTV*[8
MM2#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#8M-F&V*?8L]F'(-JI
MV*?8L=BHV+'8C"#8J-BQV*?;C"#8J-BQV8C8LMBQV+/8I]F&VXP@V*?9AMBJ
MV*[8I]BH(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#9A=BTV*[8M2#:J=F&
MVXS8KR#:J=F'(-J&V8<@V+G9A=F$VXP@V*C8I]N,V*\@V*?9AMBLV*?9A2#:
MK]N,V+'8KP#8M-F%V*<@V*C8I]N,V*\@V8;8I]F%(-BLV*_;C-BO(-BOV+/8
MJMF'(-BQV*<@V*K8I]N,V;X@VJG9AMN,V*\`V+39A=BG(-F!V8+8MR#9A=BL
MV*?8LB#8J-F'(-BOVXS8K]F&(-BGVXS9AB#8JMF%V*?8LR#9A]BSV*K;C-BO
M+@#9AMBTV+/8JB`E<R#8M-F%V*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ
M+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#9B-BGV+'8KR#8M-F(VXS8KP#8
MHMBOV+'8LR#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8M-F%V*<`V*+8K]BQV+,@
MV8'8L=BSV*K9AMBOV8<Z(-BTV878ISH`V*?8M]F$V*?8N=BGV*H@V+39A=BG
M`-BBV*_8L=BS(-BGVXS9AMBJV+'9AMBJVXP@V+39A=BG(-F&V+/8J-BJ(-BH
MV8<@V*?8J-BJV*_8I]N,(-F&V+38L]BJ("5S(-BTV878IR#8JMBZVXS;C-BQ
M(-JIV+'8K]F'(-BGV+/8JB[8J-BQV*?;C"#8L=BYV*?;C-BJ(-F%V+/8I]BF
MV80@V*?9A=F&VXS8JMN,(-BHV*?;C-BO(-BOV8C8J-BGV+'9AR#9B-BGV+'8
MKR#8M-F(VXS8KP#9AMBGV84@V+39A=BG`-BSV*?9A=BGV8;9AR#9OMBTV*K;
MC-BHV*?9AB#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V+39A=BG(-F!V8?8L=BS
MV*H@VJG8L=BOV88@VJG8I]BQV*C8L=BGV88@V+'8IR#9OMBTV*K;C-BHV*?9
MAMN,(-F&V87;C.*`C-JIV8;8K]B,(-N,V*<@V+38I]N,V*\@V*C9AMBG(-BH
MV8<@V*_9A-N,V80@V*_;C-JOV+';C"#8I]N,V88@VJG8I]BQ(-BGV8;8K-BG
MV84@V8;9A=N,XH",V+39B-BO`-BXV*?9A]BQ(-F%V+'9B-BQVJ_8L2#8M-F%
MV*<@V8;8L]BHV*H@V*C9AR#8I]BHV*K8K]BGVXP@V8;8M-BSV*H@)7,@V+39
MA=BG(-BJV+K;C-N,V+$@VJG8L=BOV8<@V*?8L]BJ+MBHV+'8I]N,(-BQV+G8
MI]N,V*H@V878L]BGV*;9A"#8I]F%V8;;C-BJVXP@V*C8I]N,V*\@V*_9B-BH
MV*?8L=F'(-F(V*?8L=BO(-BTV8C;C-BO`-F%V+'9B-BQVJ_8L2#8M-F%V*<@
MV*?;C-F&(-F%V+38KMBUV8<@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;
MC.*`C-JIV8;8KRX`V++9A=BGV88@V8'8N=F$VXP@V879AMBWV8+9AR#8K-BZ
MV+'8I]F!VXS8I]N,VXP@V+39A=BG.@#9A]F(VXS9D=BJ(-F^VXS8M"#9@=BQ
MV+8@V+39A=BG.@#9AMBGV84@VJG8I]F%V80@V+39A=BG.@#9B-BQV8C8KR#8
MM-F%V*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ`-BGV+/9A2#8L=F%V+(@
M(-BLV*_;C-BO(-BTV878IR#8J-BQV*?;C"`E<R#9A]BSV*HZ("5S`-JOV++;
MC-F&V8?B@(S9A]BGVXP@V+39A=BG(-BHV+'8I]N,(-BWV8C9A"#8I]N,V88@
MV8;8M-BSV*H@V*C8L=F(V++8L=BSV*?9AMN,(-BTV*_9AR#8I]BSV*H@`-JO
MV++;C-F&V8?B@(S9A]BGVXP@V+39A=BG(-BHV+'9B-BRV+'8L]BGV8;;C"#8
MM-BOV8<@V*?8L]BJ`-BGV+/9A2#8L=F%V+(@(-BTV878IR#8J-BGV++9AMBT
MV*?9AMN,(-BTV*_9AR#8I]BSV*H`V*?8L]F%(-BQV878LB#8M-F%V*<@V*C8
MI]BRV8;8M-BGV8;;C"#8M-BOV8<@V*?8L]BJV(P@V;[8L]BJ(-BGV83:J=BJ
MV+'9B-F&VXS:J2#8KMF(V*\@V+'8IR#:AMJI(-JIV8;;C-BO(-F((-BHV*<@
MV*?8L]F%(-BQV878LB#8K-BOVXS8KR#8KMF(V*\@V8C8I]BQV*\@V+39B-N,
MV*\`V*?8L]F%(-BQV878LB`@V+39A=BG(-F%V8;9@MBVVXP@V+38K]F'(-BG
MV+/8J@#:J=BGV+'8L]BGV++B@(S9A]BGVXP@V+'8I]F'XH",V*_9B-BQ(-BT
MV878ISH`6]F^V8;9A]BGV88@VJG8L=BOV88@V878JMF&(-F&V8+9A"#9@MF(
MV80@V+38K]F'70!;VJ_8LMBGV+'8M"#9A=BTVJG9A%T@`%O9AMF%V*?;C-BT
M(-F%V*K9AB#9AMF"V80@V8+9B-F$(-BTV*_9AR`M`-F&V878I]N,V+0@V878
MJMF&(-F&V8+9A"#9@MF(V80@V+38K]F'6R`M("5S(-BNV+==`%O8KMBW("5S
M(-BGV+(@)7,@72``6]BHV*_9B-F&(-F%V8+8K]BGV+%=`-BSV+'9OMBQV+/8
MJMN,`-F%V+'9B-BQ`$-,20#9AMF%V*?8L]F'V*<`V*_8L=BNV*H@V*_8I]BO
MV8<`V*W8L-F!`-BMV+#9@2#8L]BWV+$`VJ_8L=F(V8<F(W@R,#!C.]F'V*<`
MV+'8I]F'V8;9A=BG`-BNV+79B-BUVXS8I]BJ(-BJV+79B-N,V+$N+BX`V*_8
ML=F(V8;B@(S8J-BQV*\OV*C8L=F(V8;B@(S8J-BQV*\`V8'9A]BQV+/8JN*`
MC-F'V*<`V8C8L=F(V*\`V*[8L=F(V*P`V*K8NMN,VXS8L2#9OMN,V8C9AMBO
M+BXN`-BJV878I]BS(-BLV*_;C-BO`-JOV++;C-F&V8?B@(S9A]BG`-F%V*S9
MB-BRV8?8IP#8K=BPV8$@V;[;C-F(V8;8KRXN+@#8K=BPV8$@V*?8LB#8I]N,
MV88@V8'9A]BQV+/8J@#8K-BSV*K8K-F(`-BQV*?9AR8C>#(P,&,[V*?9AMBO
MV*?8LMN,`-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$+BXN`-JIV*?8L=BHV+'8
MI]F&`-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(`#8JMF"V8C;C-F%`-BBV+'8
MI]F%`-BGVXS9AMBLV*<@V+'8IR#9@=BTV*?8L2#8K]F'VXS8KP!C;VYT86-T
M+G9C9@!C;VYT86-T<RYC<W8`8V]N=&%C=',N='-V`&-O;G1A8W0N=F-F`-F^
MV+'9B-F&V*_9AP#8I]BR("5S("@E<RD@V*_8L2`E<R`E<P#8J-BGV*\`:#H`
MV8'9B-BQV*?9BP#8K]BQV*[8MP#8KMBWV8C8MUT`V8;8I]F%`-F^VXS8I]BO
MV8<@V+/8I]BRVXP@V8;8M-BOV8<`V8?9AMF(V+(@V;[;C-BGV*_9AR#8L]BG
MV++;C"#9AMBTV*_9AR#8I]BSV*H`;F]T97!A9`#8K]BQV+78KP#9OMN,VJG8
ML]F$V8?8IP#8M]F$V8C8N0#9AMF%V*?;C-BT(-BJV8'8I]F(V*K9A]BG`-F^
MVXSB@(S8K]BQV;[;C`#9@=F'V+'8L]BJ(-F(V+C;C-F!V8<`V*C9AR#;C-JI
M(-F!V8?8L=BSV*H@V*K9A=BGV+,`V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBO
MV+'8LR#9A=BJV8'8I]F(V*H`V*?8L]F%(-BQV878LB#8L=BG(-BHV+'8I]N,
M(-BJV*/;C-N,V*\@V*_9B-BHV*?8L2#9B-BGV+'8KR#:J=F&VXS8KP#;C-JO
MV*?9AMF'(-BTV*_9AP#8J-N,(-F&V*?9A0#8I]F&V*K8KMBGV*@@VJG8I]BQ
MV*C8L0!V0V%R9`!W.@!W96%T:&5R+F-O;0``+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T=7)B82]L;V-A;&4O9F%?25(O:&5L<"YX;6P`````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,3,R`#$P-#$W,S8R-S4T`#`R,30S
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2<Q+C`G/SX*/"$M+2`D2&]R9&4Z('1U<F)A+VQO8V%L
M92]F85])4B]H96QP+GAM;"QV(#$N,2`R,#`U+S`T+S$@,C(Z,3`Z,3(@<&5R
M<VEA;BUH;W)D92!I;B!-971A3D54("TM/@H\:&5L<#X*"CQE;G1R>2!I9#TB
M3W9E<G9I97<B/@H@("`@/'1I=&QE/MF%V+'9B-BQ/"]T:71L93X*("`@(#QH
M96%D:6YG/MF%V8+8K]F%V8<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(-JI
MV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F*VJD@V+'9B-BT(-BSV*?8K]F'(-BQ
MV*<@V*C8L=BGVXP@V*W9@=BX(-F((-F(V*?:J=BTVXP@V*?8M]F$V*?8N=BG
MV*H@V*K9A=BGV+,@V*_8L2#8I]BNV*K9BMBGV+$@V8+8L=BGV+$@V87;C.*`
MC-BOV8?8KRX@V*C8L]BJV8<@V*C9AR#8I]F*V8;:J=F'(-BSV+'9OMBQV+/8
MJB#8L]BGV878I]F&V8?9E"#8M-F%V*<@VH;:K]F(V8;9AR#8L]BGV878I]F&
MV8<@V+'8IR#9OMF*VJG8L=BHV8;8K]N,(-F&V878I]F*V*_8C"`*("`@V+39
MA=BG(-F%VXSB@(S8JMF(V*?9AMF*V*\@VJG8JMBGV*C:AMF'V90@V*+8K]BQ
MV+/9A]BGVXP@V878KMBJV839@=N,(-BOV*?8M-BJV8<@V*C8I]BTV8K8KRX@
MV8?9A=J&V8;9BMF&(-BOV+$@V*?9BMF&(-BSV*?9A=BGV8;9AR#8I]BR(-BG
MV8K8K-BGV*\@V8'9A]BQV+/8JMF'V*?;C"#9OMBSV*K;C"#9AMF*V+(@V;[8
MM-BJV8K8J-BGV8;;C"#9A=N,XH",V+39B-BO+B`*("`@(#PO<&%R83X*/"]E
M;G1R>3X*"CQE;G1R>2!I9#TB;65N=2UA9&0B/@H@("`@/'1I=&QE/MJOV++;
MC-F&VJ_8I]F&.B#8I]BVV*?9@=F'(-JIV+'8K]F&/"]T:71L93X*("`@(#QH
M96%D:6YG/MBGV+;8I]F!V8<@VJG8L=BOV88\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(-BGV+;8I]F!V8<@VJG8L=BOV88@V8K:J2#9B-BQV8C8K]N,(-BO
MV+$@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,Z(-BTV878IR#8JMF&V8?8IR#9
MA=N,XH",V*K9B-BGV8;9BMBO(-BOV+$@VJG8JMBGV*C:AMF'V90@V*+8K]BQ
MV+/9A]BGV8K;C"#9B-BQV8C8K]N,(-BLV*_9BMBO(-BOV+'8K"#9AMF%V*?9
MBMF*V*\@VJG9AR`*("`@(-F%V*S9B-BR(-F&V8C8M-BJV88@V*_8L2#8HMF&
MV8?8IR#8L=BG(-BOV*?8M-BJV8<@V*C8I]BTV8K8KRX@V+G9A=F(V878I]F2
M(-BOV+$@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+/9A]BGVXP@V878M-BJV+':
MJ2#9B"#9BMBG(-BYV879B-F%VXP@V*?9@=BQV*?8KR#9A=BLV8C8LB#9AMF(
MV+38JMF&(-F&V*_8I]BQV8;8KPH@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N
M=')Y(&ED/2)M96YU+7-E87)C:"(^"B`@("`\=&ET;&4^VJ_8LMN,V8;:K]BG
MV88Z(-BLV+/8JMBLV8@\+W1I=&QE/@H@("`@/&AE861I;F<^V*S8L]BJV*S9
MB#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@V*S8L]BJV*S9B-N,(-F*VJD@
MVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V*C8L=BGVXP@V8K8I]F!V*K9AB#8
MI]BWV838I]BYV*?8JB#9A=F(V+'8KR#9AMBXV+$Z(-BOV+$@V*?9BMF&(-BQ
MV8C8M"#9BMJI(-BLV+/8JMBLV8C;C"#8L]BQV8K8N2#8M=F(V+'8JB#:K]BQ
MV8'8JMF'(-F((-BLV+/8JMBLV8@@V*K9AMF'V*<@V*C8L2#8L=F(VXP@V8'9
MBMF$V*_9A]BGVXP@V878K=BOV8C8K]N,"B`@("#8M=F(V+'8JB#9A=N,XH",
MVJ_9BMBQV*\N(-F!V8K9A-BOV8?8I]N,(-F%V+38KMBU(-BTV*_9AR#8K]BQ
M(-BGV8K9AB#9@MBSV878JB#8J-BSV*K9AR#8J-F'(-F'V+$@V+/8I]F%V*?9
MAMF'(-F%VXSB@(S8JMF(V*?9AMBO(-F%V*K9@=BGV8C8JB#8J-BGV+38KRX*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@V*C8L=BGVXP@V*S8L]BJV*S9
MB-N,(-F^V8K8M-BQV8'8JMF'(-BTV878IR#9A=N,XH",V*K9B-BGV8;9BMBO
M(-BGV+(@("9Q=6]T.SQR968@;6]D=6QE/2)T=7)B82(@96YT<GD](FUE;G4M
M861V86YC960M<V5A<F-H(C[8K-BSV*K8K-F(VXP@V;[9BMBTV+'9@=BJV8<\
M+W)E9CXF<75O=#L@"B`@("#8I]BSV*K9@=BGV*_9AR#:J=F&V8K8KR#:J=F'
M(-BHV8<@V+39A=BG(-BGV*S8I]BRV8<@V*S8L]BJV*S9B"#8J-BQ(-BQV8C;
MC"#9@=F*V838K]F'V*?;C"#8K]F*VJ_8L2#8L=BG(-F%VXSB@(S8K]F'V*\N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](FUE;G4M861V86YC
M960M<V5A<F-H(CX*("`@(#QT:71L93[:K]BRVXS9AMJOV*?9ACK8K-BSV*K8
MK-F(VXP@V;[9BMBTV+'9@=BJV8<\+W1I=&QE/@H@("`@/&AE861I;F<^V*S8
ML]BJV*S9B-N,(-F^V8K8M-BQV8'8JMF'/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("#9BMJI(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BQV*<@V*C8L=BG
MVXP@V8K8I]F!V*K9AB#8I]BWV838I]BYV*?8JB#9A=F(V+'8KR#9AMBXV+$@
MV*S8L]BJV*S9B"#9A=N,XH",VJG9AMBO+B#8K]BQ(-BGV8K9AB#8L=F(V+0@
MV*S8L]BJV*S9B"#8J-BQ(-BQV8C;C"#:AMF&V*_9BMF&(-F!V8K9A-BO("C8
MJ-BSV*K9AR#8J-F'(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BGV8;8JMBN
MV*?8J-N,*2#8M=F(V+'8JB#9A=N,XH",VJ_9BMBQV*\*("`@(#PO<&%R83X*
M/"]E;G1R>3X*"CQE;G1R>2!I9#TB;65N=2UI;7!O<G0B/@H@("`@/'1I=&QE
M/MJOV++;C-F&VJ_8I]F&.B#8K]BQV8C9AN*`C-BHV+'8KR\@V*C8L=F(V8;B
M@(S8J-BQV*\\+W1I=&QE/@H@("`@/&AE861I;F<^V*C8L=F(V8;B@(S8J-BQ
MV*\O(-BOV+'9B-F&XH",V*C8L=BO/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("#8I]F*V88@VJ_8LMN,V8;:K]BGV88@V*C9AR#8J-BQV8C9AN*`C-BHV+'8
MKR#9B"#9BMBG(-BOV+'9B-F&XH",V*C8L=BO(-BGV+?9A-BGV+G8I]BJ(-BH
MV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+39A=BG(-JIV87:J2#9A=N,
MXH",V8;9A=BGV8K8KRX@(`H@("`@V*_8L2#8I]F*V88@V*W8I]F$V*H@V*?8
MLB#9@MBGV838J-F'V*?;C"#8LMF*V*?8K]N,(-F^V+38JMF*V*C8I]F&VXP@
MV87;C.*`C-BTV8C8KRX*("`@(#PO<&%R83X*"B`@("`\:&5A9&EN9S[8K]BQ
MV8C9AN*`C-BHV+'8KSPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@(-BHV+'8
MI]N,(-BGV*[8L"#8I]BWV838I]BYV*?8JB#8I]BR(-F*VJD@VJG8JMBGV*C:
MAMF'V90@V*+8K]BQV+,@V+39A=BG(-BHV*?9BMBO(-BGV+?9A-BGV+G8I]BJ
M(-BBV88@VJG8JMBGV*C:AMF'(-BBV*_8L=BS(-BQV*<@V*C8L2#8L=F(VXP@
MVJG8I]F%V;[9BMF(V*K8L2#9A=BMV83;C"#8KMF(V*\@V*_8L=F(V8;B@(S8
MJ-BQV*\@V8;9A=BGV8K9BMBO+B`@(`H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("#8I]JOV+$@V+39A=BG(-BGV+(@3W5T;&]O:R#8I]BSV*K9@=BGV*_9
MAR#:J=F&V8K8KSH*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@V[$I(-BH
MV+$@V+'9B-N,(-JOV++;C-F&VJ_8I]F&(-JIV*K8I]BHVH;9A]F4(-BBV*_8
ML=BS("T^(-BHV+'9B-F&XH",V*C8L=BO("T^(-F^V+'9B-F&V*_9AR#:J=F$
MV8K:J2#9AMF%V*?9BMF*V*\@"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M(-NR*2`@)G%U;W0[V8'8I]F*V80@V878JMF&VXPF<75O=#L@V+'8IR#8I]F&
MV*K8KMBGV*@@V8;9A=BGV8K9BMBO(`H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("#;LRD@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V879B-BQV*\@V8;8
MN-BQ(-BQV*<@V*?9AMBJV*[8I]BH(-F&V878I]F*V8K8KRX*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@V[0I(-F!V8K9A-BOV8?8I]F*V8H@V+'8IR#:
MJ=F'(-F%V*?9BMF$(-BHV8<@V*C8L=F(V8;B@(S8J-BQV*\@V*+9AMF'V*<@
MV8?8L]BJV8K8KR#8N=F$V*?9A=BJ(-BRV*_9AR#9B"#8L]F^V+,@VJG9A-F*
MV*\@V*[8I]BJV879AR#8L=BG(-F!V+38I]BQ(-BOV8?9BMBO+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("#;M2D@V*_8L2#8I]F&V*K9A]BGVXP@V+G9
MA=F$(-BHV+'9B-F&XH",V*C8L=BO(-F^V8K8NMBGV84@)]BNV*?8JMF%V8<@
MV+G9A=F$(-BHV+'9B-F&XH",V*C8L=BO)R#8L=BG(-BOV+'9BMBGV8'8JB#8
MKMF(V*?9A]F*V*\@V8;9A=F(V*\@"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@(-NV*2#8J-BQ(-BQV8C;C"#:J=F$V8K8KR#8KMBGV8;9A=F'(-F!V+38
MI]BQ(-BOV8?9BMBO("`@(`H@("`@/"]P87)A/@H*("`@(#QT:7`^"B`@("`@
MVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V*C8L=F(V8;B@(S8J-BQV*\@V+38
MK]F'(-BHV+$@V+'9B-N,(-JIV*?9A=F^V8K9B-BJV+$@V878K=F$V9';C"#8
MM-F%V*<@V8+8L=BGV+$@V*[9B-BGV8?8KR#:K]BQV8'8JBX@V*_8L2#8M=F(
MV+'8JB#8N=BOV84@V878M-BGV8?8K]F'(-BBV88@V*C8L2#8L=F(VXP@V+79
M@=BMV8<@9&5S:W1O<"#9A=N,XH",V*K9B-BGV8;9BMBO(-BHV8<@V*S8L]BJ
MV*S9B-N,(-BBV88@V*_8L2#9@=BVV*?;C"#8K]F*V+/:J2#8L]BNV*H@V*[9
MB-BO(-BHV;[8L=BOV*?8LMF*V*\N("`@(`H@("`@/"]T:7`^"@H@("`@/'!A
M<F$^"B`@("#8J-BQV*?;C"#9B-BQV8C8KR#8I]BWV838I]BYV*?8JB#8J-F'
M(-F*VJD@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+/8C"#8I]BHV*K8K]BG(-BH
MV*?9BMBO(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F%V8C8L=BO(-F&V+C8
ML2#8L=BG(-BHV*?8LB#:J=BQV*_9AR#9B"#8J-BQ(-BQV8C;C"#:J=F$V8K8
MKR#8K]BQV8C9AN*`C-BHV+'8KR_8J-BQV8C9AN*`C-BHV+'8KR#:J=F$V8K:
MJ2#9AMF%V8C8K]F'(-F("B`@("#9OMBQV8C9AMBOV8?9E"#9A=F(V+'8KR#9
MAMBXV+$@V+'8IR#8J-BQV*?;C"#8I]BWV838I]BYV*?8JB#8I]F&V*K8KMBG
MV*@@V8;9A=F(V*_9AR#9B"#:J=F$V8K8KR#9B-BQV8C8KR#8L=BG(-F!V+38
MI]BQ(-BOV8?9BMBO+@H@("`@/"]P87)A/@H@("`@/'1I<#X*("`@(-F(V+'9
MB-BOVXSB@(S9A]BGVXP@V;[9BMJ&V8K8K]F'(-F((-F*V*<@V8C8L=F(V*_;
MC.*`C-F'V*?9BMF*(-JIV8<@V*C8IR#9@=F*V838K]F'V*?;C"#:J=BJV*?8
MJ-J&V8?9E"#8HMBOV+'8LR#8M-F%V*<@V*K8M]BGV*C9@B#9AMBOV*?8L=F&
MV*\@V879A=JIV88@V*?8L]BJ(-BHV8<@V*[9B-BHVXP@V*_8L2#:J=BJV*?8
MJ-J&V8?9E"#8HMBOV+'8LR#8M-F%V*<@V*_8L=BL(-F&V+39B-F&V*\N(-BG
MV8K9AB#9B-BQV8C8K]N,XH",V8?8IR#8J-BYV*\@V*?8LB#8KMBGV*K9A=F'
M(-BYV879A"#9B-BQV8C8KPH@("`@V*C8I]F*V*\@VJG9AMBJV+'9A"#8M-F(
MV8;8KRX*("`@(#PO=&EP/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)S96%R8VAI
M;F<M<V5A<F-H7W)E<W5L=',B/@H@("`@/'1I=&QE/MBLV+/8JMBLV8@Z(-F&
MV*K8I]F*V*P@V*S8L]BJV*S9B#PO=&ET;&4^"B`@("`\:&5A9&EN9S[9AMBJ
MV*?9BMBL(-BLV+/8JMBLV8@\+VAE861I;F<^"B`@("`\<&%R83X*("`@(-BG
MVJ_8L2#8K-BSV*K8K-F((-F%V8C9@=F1V8(@V*C8I]BTV*_8C"#9AMBJV*?9
MBMBL(-BBV88@V+'8IR#8K]BQ(-BHV*[8M"`F<75O=#O9AMBJV8K8K-F'(-BL
MV+/8JMBLV8@F<75O=#L@V878M-BGV8?8K]F'(-BNV8C8I]F'V*\@VJ_8L=BO
MV8K8KRX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@VH;9AMBGV8;:AMF'
M(-BOV+$@V*?9BMF&(-BHV*[8M"#8J-BQ(-BQV8C;C"#:J=F$V8K8KR`F<75O
M=#O9OMBSV*H@V*?9A-JIV*K8L=F(V8;9BMJI("9Q=6]T.R`HV*C8L=BGVXP@
MV8?8L2#9B-BQV8C8K]N,*2#9@=BTV*?8L=BOV8?9BMBO(-F^V8;8K-BQV8?9
ME"#8I]F&V+38I]N,(-F^V8K8NMBGV84@V*C8L=BGVXP@V*+9AB#8HMBOV+'8
MLR#:K]BTV8C8K]F'(-BTV*_9AR#9B"#8K]BQ(`H@("`@V8@@VH;9AMBGV8;:
MAMF'(-BHV+$@V+'9B-N,(-F!V8K9A-BO("9Q=6]T.]F&V*?9A29Q=6]T.R#:
MJ=F$V8K:J2#9AMF%V*?9BMF*V*\@V8+8I]BOV+$@V*[9B-BGV8?9BMBO(-BH
MV8C8KR#8I]BWV838I]BYV*?8JB#9A=BQV*C9B-BW(-BHV8<@V8C8L=F(V*_;
MC"#9A=F(V+'8KR#9AMBXV+$@V+'8IR#9B-F*V+'8I]F*V+0@V8;9A=BGV8K9
MBMBO+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("#8J-BSV*K9AR#8J-F'
M(-F&V8C8N2#9OMF*VJG8L=BHV8;8K]N,(-BGV8;8K-BGV84@V+38K]F'(-BG
MV+(@V+?8L=F!(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8?9E"#8M-F%V*?8
MC"#8K-BSV*K8K-F((-F%VXSB@(S8JMF(V*?9AMBO(-BHV8<@V+79B-BQV*H@
MV*K8K-F%V+G;C"#8M=F(V+'8JB#:K]F*V+'8KR#:J=F'(-BOV+$@V*?9BMF&
M(-BMV*?9A-BJ(-F&V*K8I]F*V*P@V8?8L2#8K-BSV*K8K-F((-BHV8<@V*S8
ML]BJV*S9B-N,(`H@("`@V8+8J-F$VXP@V*?9@=BRV8C8K]F'(-F%VXSB@(S:
MK]BQV*_8KRX@V*_8L2#8I]F*V88@V*W8I]F$V*H@V*C8L=BGVXP@V*W8L-F!
M(-F&V*K8I]F*V*P@V8+8J-F$(-F%VXSB@(S8J-BGV8K8L]BJ(-BHV+$@V+'9
MB-N,(-JIV839BMBO(-F^V*?:J2#:J=BQV*_9AB#9AMBJV*?9BMBL(-BLV+/8
MJMBLV8@@V8'8M-BGV+$@V*_9A]F*V*\N"B`@("`\+W!A<F$^"@H@("`@/'1I
M<#X*("`@("#9A]F&VJ_8I]F%VXP@VJG9AR#9BMJI(-F!V8?8L=BSV*H@V*?8
MLB#9B-BQV8C8K]N,XH",V8?8IR#9A=BTV*?9A]BOV8<@V87;C.*`C-BTV8C8
MKR#8M-F%V*<@V87;C.*`C-BJV8C8I]F&V8K8KR#9AMBJV*?9BMBL(-BQV*<@
MV*C8L2#8I]BSV*?8LR#9@=F*V838KR#8K]F$V*[9B-BGV8<@V*[9B-BO(-F%
MV+'8JMBH(-F&V878I]F*V8K8KRX@V*C8L=BGVXP@V*K8NMF*V8K8L0H@("`@
MV*K8L=BJV8K8J"#9A=BQV*K8J"#8L]BGV++;C"#8J-BQ(-BQV8C;C"#9@=F$
MV+0@VJG9AMBGV+$@V+/8JMF(V88@V879B-BQV*\@V8;8N-BQ(-F!V+38I]BQ
M(-BOV8?9BMBO+@H@("`@/"]T:7`^"CPO96YT<GD^"@H\+VAE;'`^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L
M;V-A;&4O96Y?55,O````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`R,#`Q,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]E;E]54R]H96QP+GAM;```````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(T,#,`,3`T,3<S-C(W-34`,#(Q
M-#8R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_>&UL('9E<G-I;VX])S$N,"<_/@H\(2TM("1(;W)D93H@='5R8F$O;&]C
M86QE+V5N7U53+VAE;'`N>&UL+'8@,2XQ,B`R,#`T+S$P+S(V(#(R.C$P.C$R
M(&UD:G5K:6,@17AP("0@+2T^"CQH96QP/@H*/&5N=')Y(&ED/2)/=F5R=FEE
M=R(^"B`@("`\=&ET;&4^3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE861I;F<^
M26YT<F]D=6-T:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@061D
M<F5S<R!";V]K('!R;W9I9&5S(&$@8V]N=F5N:65N="!M971H;V0@86YD('!L
M86-E('1O('-T;W)E(&-O;G1A8W0@:6YF;W)M871I;VX@9F]R(&5A<WD@<F5T
M<FEE=F%L(&%N9"!U<V4N($1E<&5N9&EN9R!O;B!H;W<@>6]U<B!A9&UI;FES
M=')A=&]R(&AA<R!S970@=7`@=&AE('-Y<W1E;2!I="!C86X@<')O=FED92!A
M('!R:79A=&4@861D<F5S<R!B;V]K(&%S('=E;&P@87,@86-C97-S('1O('!U
M8FQI8R!N971W;W)K(&1I<F5C=&]R>2!S97)V:6-E<RX@270@86QS;R!S=7!P
M;W)T<R!D:7-T<FEB=71I;VX@;&ES=',@<V\@>6]U(&-A;B!C<F5A=&4@>6]U
M<B!O=VX@(FUA:6QI;F<@;&ES=',N(@H@("`@/"]P87)A/@H\+V5N=')Y/@H*
M/&5N=')Y(&ED/2)M96YU+6%D9"(^"B`@("`\=&ET;&4^365N=3H@061D/"]T
M:71L93X*("`@(#QH96%D:6YG/D%D9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@061D(&$@=7-E<B!T;R!A;B!A9&1R97-S(&)O;VLN(%EO=2!C86X@;VYL
M>2!A9&0@=7-E<G,@=&\@=&AE(&%D9')E<W,@8F]O:W,@=&\@=VAI8V@@>6]U
M(&AA=F4@=W)I=&4@86-C97-S+B!)9B!S:&%R960@;W(@<'5B;&EC(&%D9')E
M<W,@8F]O:W,@:&%V92!B965N(&5N86)L960@=&AE>2!A<F4@;V9T96X@<F5A
M9"UO;FQY(&%N9"!Y;W4@=VEL;"!N;W0@8F4@86)L92!T;R!A9&0@8V]N=&%C
M=',@=&\@=&AE;2X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB
M;65N=2US96%R8V@B/@H@("`@/'1I=&QE/DUE;G4Z(%-E87)C:#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY396%R8V@\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%-E87)C:"!A;B!A9&1R97-S(&)O;VL@=&\@;&]C871E(&EN9F]R;6%T:6]N
M+B!4:&ES(&ES(&EN=&5N9&5D(&%S(&$@<75I8VL@<V5A<F-H(&%N9"!O;FQY
M(&%L;&]W<R!Y;W4@=&\@<V5A<F-H(&]N(&$@9F5W(&)A<VEC(&9I96QD<RX@
M57-U86QL>2!T:&ES(&ES('1H92!N86UE(&%N9"!E;6%I;"!A9&1R97-S(&9I
M96QD<RP@8G5T(&-O=6QD('9A<GD@9&5P96YD:6YG(&]N(&AO=R!Y;W5R(&%D
M;6EN:7-T<F%T;W(@<V5T('5P('1H92!A9&1R97-S(&)O;VLN"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@($9O<B!A(&UO<F4@8V]M<&QE>"!S96%R8V@@
M>6]U(&-A;B!U<V4@=&AE("9Q=6]T.SQR968@;6]D=6QE/2)T=7)B82(@96YT
M<GD](FUE;G4M861V86YC960M<V5A<F-H(CY!9'9A;F-E9"!396%R8V@\+W)E
M9CXF<75O=#L@=VAI8V@@<&5R;6ET<R!S96%R8VAI;F<@;VX@;W1H97(@9FEE
M;&1S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)M96YU+6%D
M=F%N8V5D+7-E87)C:"(^"B`@("`\=&ET;&4^365N=3H@061V86YC960@4V5A
M<F-H/"]T:71L93X*("`@(#QH96%D:6YG/D%D=F%N8V5D(%-E87)C:#PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@4V5A<F-H(&%N(&%D9')E<W,@8F]O:R!T
M;R!L;V-A=&4@:6YF;W)M871I;VXN(%1H:7,@<V5A<F-H(&%L;&]W<R!Y;W4@
M=&\@<V5A<F-H(&]N(&UU;'1I<&QE(&9I96QD<RX@5VAI8V@@9FEE;&1S(&%R
M92!A=F%I;&%B;&4@9F]R('-E87)C:&EN9R!D97!E;F1S(&]N('1H92!A9&1R
M97-S(&)O;VL@8F5I;F<@<V5A<F-H960N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"@H\96YT<GD@:60](FUE;G4M:6UP;W)T(CX*("`@(#QT:71L93Y-96YU.B!)
M;7!O<G0O17AP;W)T/"]T:71L93X*("`@(#QH96%D:6YG/DEM<&]R="]%>'!O
M<G0\+VAE861I;F<^"@H@("`@/'!A<F$^"B`@("!4:&ES(&UE;G4@86QL;W=S
M(&EM<&]R=&EN9R!T;R!A;F0@97AP;W)T:6YG(&9R;VT@>6]U<B!P97)S;VYA
M;"!A9&1R97-S(&)O;VLN($ET('-U<'!O<G1S(&)O=&@@0U-6("A#;VUM82!3
M97!A<F%T960@5F%R:6%B;&4I+"!/=71L;V]K+"!A;F0@=D-A<F0@9F]R;6%T
M<RP@87,@=V5L;"!A<R!S;VUE(&]T:&5R('!O<'5L87(@9F]R;6%T<RX*("`@
M(#PO<&%R83X*"B`@("`\:&5A9&EN9SY);7!O<G1I;F<\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1O(&EM<&]R="!A;B!A9&1R97-S(&)O;VLL('EO=2!N
M965D('1O(&AA=F4@=&AE(&%D9')E<W,@8F]O:R!D871A('1O(&EM<&]R="!O
M;B!Y;W5R(&QO8V%L(&UA8VAI;F4@*&]N('=H:6-H('1H92!W96(@8G)O=W-E
M<B!I<R!R=6YN:6YG*2X@5&\@9&\@=&AI<RP@>6]U('=I;&P@;F5E9"!T;R!F
M:7)S="!E>'!O<G0@=&AE(&%D9')E<W,@8F]O:R!I;F9O<FUA=&EO;B!F<F]M
M('EO=7(@8W5R<F5N="!E;6%I;"!C;&EE;G0N"B`@("`\+W!A<F$^"@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@=7-E($]U=&QO;VL@17AP<F5S<SH*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@,2D@0VQI8VL@;VX@1FEL92`^($5X<&]R
M="`^($%D9')E<W,@0F]O:PH@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`R
M*2!396QE8W0@)G%U;W0[5&5X="!&:6QE)G%U;W0[("A#;VUM82!397!A<F%T
M960@5F%L=65S*2!I;B!T:&4@)G%U;W0[061D<F5S<R!";V]K($5X<&]R="!4
M;V]L)G%U;W0[+B!#;&EC:R!O;B`F<75O=#M%>'!O<G0F<75O=#LN"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@(#,I($EN('1H92`F<75O=#M3879E(&5X
M<&]R=&5D(&9I;&5S(&%S)G%U;W0[(&9I96QD+"!T>7!E(&EN(&$@;F%M92!F
M;W(@>6]U<B!A9&1R97-S(&)O;VLN($-L:6-K("9Q=6]T.TYE>'0F<75O=#LN
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#0I(%!U="!A(&-H96-K;6%R
M:R!I;B!T:&4@8F]X('1O('1H92!L969T(&]F(&5A8V@@;V8@=&AE(&9I96QD
M<R!T:&%T('EO=2!W:7-H('1O(&5X<&]R="X@0VQI8VL@)G%U;W0[1FEN:7-H
M)G%U;W0[+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`U*2!9;W4@<VAO
M=6QD(')E8V5I=F4@82!M97-S86=E('1H870@<W1A=&5S("=!9&1R97-S(&)O
M;VL@97AP;W)T('!R;V-E<W,@:&%S(&-O;7!L971E9"<N($-L:6-K("=/2R<N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#8I($-L:6-K("=#;&]S92<@
M;VX@=&AE("=!9&1R97-S($)O;VL@17AP;W)T(%1O;VPG(&%N9"!C;&]S92!/
M=71L;V]K($5X<')E<W,N"B`@("`\+W!A<F$^"@H@("`@/'1I<#X*("`@($EF
M('1H92!E>'!O<G1E9"!A9&1R97-S(&)O;VL@9FEL92!I<R!N;W0@;&]C871E
M9"!O;B!Y;W5R(&1E<VMT;W`L(&%N9"!Y;W4G<F4@=7-I;F<@82!7:6YD;W=S
M(&]P97)A=&EN9R!S>7-T96TL(&-L:6-K(&]N(%-T87)T(#X@1FEN9"!O<B!3
M96%R8V@@/B!&:6QE<R!O<B!&;VQD97)S(&%N9"!S96%R8V@@>6]U<B!M86EN
M(&AA<F0@9')I=F4@9F]R('1H92!F:6QE(&YA;64@=&AA="!Y;W4@=7-E9"!I
M;B!S=&5P(#,N($UA:V4@82!N;W1E(&]F('1H92!F:6QE)W,@;&]C871I;VXN
M"B`@("`\+W1I<#X*"B`@("`\<&%R83X*("`@(%1O(&EM<&]R="!A;B!A9&1R
M97-S(&)O;VLL(&]P96X@=&AE(&%D9')E<W,@8F]O:R!Y;W4@=V%N="!T;R!I
M;7!O<G0@=&AE(&EN9F]R;6%T:6]N(&EN=&\N($-L:6-K(&]N('1H92`F<75O
M=#M);7!O<G0O17AP;W)T)G%U;W0[($EC;VXN(%-E;&5C="!T:&4@='EP92!O
M9B!A9&1R97-S(&EN9F]R;6%T:6]N(&1A=&$@9FEL92!Y;W4@=V%N="!T;R!I
M;7!O<G0@9G)O;2!T:&4@<V5L96-T:6]N(&QI<W0N($-L:6-K(&]N('1H92`F
M<75O=#MB<F]W<V4F<75O=#L@8G5T=&]N('1O(&QO;VL@9F]R('1H92!A9&1R
M97-S(&1A=&$@9FEL92!O;B!Y;W5R(&-O;7!U=&5R+B!396QE8W0@=&AE(&9I
M;&4L(&%N9"!C;&EC:R!O;B!T:&4@)G%U;W0[26UP;W)T)G%U;W0[(&)U='1O
M;BX@5&AE(&EN9F]R;6%T:6]N(&EN('1H92!F:6QE('=I;&P@8F4@:6UP;W)T
M960@:6YT;R!Y;W5R(&%D9')E<W,@8F]O:RX*("`@(#PO<&%R83X*("`@(#QT
M:7`^"B`@("!3;VUE(&-O;7!L97@@96YT<FEE<RP@;W(@96YT<FEE<R!W:71H
M(&9I96QD<R!T:&%T(&1O(&YO="!M871C:"!Y;W5R(&%D9')E<W,@8F]O:R!F
M:65L9',L(&UA>2!N;W0@:6UP;W)T(&-O<G)E8W1L>2X@66]U('-H;W5L9"!V
M97)I9GD@=&AE(&EM<&]R=&5D(&1A=&$@869T97(@86X@:6UP;W)T+@H@("`@
M/"]T:7`^"CPO96YT<GD^"@H\96YT<GD@:60](G-E87)C:&EN9RUS96%R8VA?
M<F5S=6QT<R(^"B`@("`\=&ET;&4^4V5A<F-H:6YG.B!396%R8V@@4F5S=6QT
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY396%R8V@@4F5S=6QT<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@268@82!S96%R8V@@:7,@<W5C8V5S<V9U;"P@
M=&AE(')E<W5L=',@=VEL;"!S:&]W('5P(&EN('1H92`F<75O=#M396%R8V@@
M4F5S=6QT<R9Q=6]T.R!A<F5A+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!#;&EC:VEN9R!O;B!A;B`F<75O=#M%;6%I;"9Q=6]T.R!F:65L9"!E;G1R
M>2!W:6QL(&]P96X@82!N97<@0V]M<&]S92!W:6YD;W<@=&\@<V5N9"!M86EL
M('1O('1H870@861D<F5S<RX@0VQI8VMI;F<@;VX@82`F<75O=#M.86UE)G%U
M;W0[(&9I96QD(&5N=')Y('=I;&P@9&ES<&QA>2!T:&4@861D<F5S<R!B;V]K
M(')E8V]R9"!F;W(@=&AA="!N86UE+"!A;&QO=VEN9R!Y;W4@=&\@=&AE;B!E
M9&ET(&]R(&1E;&5T92!T:&4@96YT<GDN"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@($1E<&5N9&EN9R!O;B!H;W<@>6]U<B!S>7-T96T@:&%S(&)E96X@
M<V5T('5P(&)Y('1H92!A9&UI;FES=')A=&]R('-E87)C:"!R97-U;'1S(&-A
M;B!B92!C=6UU;&%T:79E+B!%86-H('-E87)C:"!W:6QL(&%D9"!A;GD@;F5W
M(')E<W5L=',@=&\@>6]U<B!E>&ES=&EN9R!R97-U;'1S+B!4:&ES(&ES(&AE
M;'!F=6P@=VAE;B!B=6EL9&EN9R!L:7-T<RX@5&\@<F5M;W9E('1H92!R97-U
M;'1S(&]F(&-U;75L871I=F4@<V5A<F-H97,@86YD('-T87)T(&$@;F5W('-E
M87)C:"P@8VQI8VL@;VX@=&AE("9Q=6]T.T-L96%R(%-E87)C:"9Q=6]T.R!L
M:6YK+@H@("`@/"]P87)A/@H*("`@(#QT:7`^"B`@("!7:&5N('9I97=I;F<@
M82!L:7-T(&]F(&5N=')I97,L('EO=2!C86X@<V]R="!T:&4@96YT<FEE<R!B
M>2!E86-H(&9I96QD('-H;W=N(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R
M:6%T92!C;VQU;6X@:&5A9&EN9RX@5&\@<W=I=&-H(&-O;'5M;G,@8F5T=V5E
M;B!A<V-E;F1I;F<@86YD(&1E<V-E;F1I;F<@<V]R="!O<F1E<BP@8VQI8VL@
M;VX@=&AE(&%R<F]W(&EC;VX@:6X@=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@
M/"]T:7`^"CPO96YT<GD^"@H\+VAE;'`^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L
M92]E<U]%4R\`````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-34`,#(P,#`P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O='5R8F$O;&]C86QE+V5S7T53+TQ#7TU%4U-!1T53+P``````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C$U-C4`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O97-?15,O3$-?
M34534T%'15,O='5R8F$N;6\`````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#<T-S,S`#$P
M-#$W,S8R-S4U`#`R,S(U-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#>$@25`````)`(```<````G$0``&\+```<B0``````
M`-BV```.````V;8```\```#HM@``#0```/BV```(````!K<```L````/MP``
M#````!NW```9````*+<``!D```!"MP``!````%RW```I````8;<``!@```"+
MMP``&P```*2W```M````P+<``!T```#NMP``)`````RX```I````,;@``"D`
M``!;N```&0```(6X```H````G[@``"0```#(N```)0```.VX```F````$[D`
M``P````ZN0``)````$>Y```/````;+D```L```!\N0``#@```(BY```%````
ME[D``"@```"=N0``"````,:Y```*````S[D``!4```#:N0``"0```/"Y```2
M````^KD```L````-N@``'0```!FZ``"%````-[H```X```"]N@``"@```,RZ
M```-````U[H```X```#EN@``$0```/2Z```-````!KL```P````4NP``#0``
M`"&[```&````+[L``)0````VNP``"@```,N[```/````UKL``!@```#FNP``
M#````/^[```.````#+P```X````;O```"````"J\```)````,[P``"L````]
MO```+@```&F\```:````F+P``#(```"SO```.````.:\``!4````'[T``%$`
M``!TO0``6@```,:]``!7````(;X``#0```!YO@``"0```*Z^```-````N+X`
M``<```#&O@``"@```,Z^```/````V;X```4```#IO@``!@```.^^```1````
M]KX```@````(OP``$0```!&_```)````([\```D````MOP``)0```#>_```@
M````7;\``!,```!^OP``$P```)*_```0````IK\```\```"WOP``"@```,>_
M```#````TK\```\```#6OP``%````.:_```)````^[\```T````%P```$@``
M`!/````9````)L```!X```!`P```#P```%_````0````;\```"$```"`P```
M"@```*+````(````K<````\```"VP```"````,;````D````S\````8```#T
MP```%````/O````6````$,$```@````GP0``3@```##!```M````?\$``"$`
M``"MP0``&0```,_!```'````Z<$```P```#QP0``%````/[!```-````$\(`
M`!(````AP@``(0```#3"```7````5L(``"D```!NP@``+````)C"```.````
MQ<(```,```#4P@``#P```-C"```+````Z,(```<```#TP@``!P```/S"```%
M````!,,```4````*PP``"@```!##```#````&\,``!<````?PP``"@```#?#
M```/````0L,```X```!2PP``&````&'#```C````>L,```X```">PP``#@``
M`*W#```4````O,,``!<```#1PP``%P```.G#```7`````<0``!,````9Q```
M#P```"W$```.````/<0``!\```!,Q```'0```&S$```'````BL0```8```"2
MQ```"````)G$```/````HL0```8```"RQ```"@```+G$```3````Q,0```L`
M``#8Q```$````.3$```5````]<0``!4````+Q0``!P```"'%```0````*<4`
M``4````ZQ0``%0```$#%```1````5L4```P```!HQ0``*````'7%```Z````
MGL4``#L```#9Q0``.````!7&```)````3L8```<```!8Q@``%````&#&```#
M````=<8```4```!YQ@``"0```'_&```0````B<8```D```":Q@``$P```*3&
M```Y````N,8``!(```#RQ@``)P````7'```L````+<<``"H```!:QP``)0``
M`(7'```*````J\<```8```"VQP``"0```+W'```'````Q\<``"\```#/QP``
M-P```/_'```N````-\@``%4```!FR```+0```+S(```M````ZL@``#T````8
MR0``/P```%;)```M````ELD``$````#$R0``(P````7*```C````*<H``$``
M``!-R@``+0```([*```S````O,H``"4```#PR@``%0```!;+```9````+,L`
M`"D```!&RP``)````'#+```H````E<L``!$```"^RP``"@```-#+```,````
MV\L```H```#HRP``$````//+```6````!,P``!8````;S```!P```#+,```'
M````.LP``!0```!"S```"@```%?,```(````8LP``"<```!KS```"````)/,
M```,````G,P```<```"IS```!P```+',```&````N<P``!$```#`S```!0``
M`-+,```'````V,P```8```#@S```%````.?,```(````_,P``"D````%S0``
M#@```"_-```*````/LT```0```!)S0``!P```$[-```)````5LT```8```!@
MS0``$0```&?-```'````><T``!8```"!S0``!````)C-```(````G<T```8`
M``"FS0``#0```*W-```&````N\T``!X```#"S0``!@```.'-```1````Z,T`
M``@```#ZS0``#0````/.```,````$<X```<````>S@``$0```";.```#````
M.,X```,````\S@``%P```$#.```#````6,X``!,```!<S@``'0```'#.```(
M````CLX```0```"7S@``"````)S.```(````I<X``$$```"NS@``&@```/#.
M```<````"\\``"L````HSP``(````%3/```5````=<\```8```"+SP``!@``
M`)+/```5````F<\``!@```"OSP``(@```,C/```N````Z\\``!T````:T```
M(0```#C0``!4````6M```"D```"OT```"@```-G0```'````Y-````<```#L
MT```%0```/30```.````"M$```H````9T0``#P```"31```-````--$```\`
M``!"T0``#0```%+1```)````8-$``!0```!JT0``!@```'_1```8````AM$`
M`!T```"?T0``$P```+W1```1````T=$``!0```#CT0``!````/C1```&````
M_=$``!0````$T@``5````!G2``!D````;M(```0```#3T@``#@```-C2```/
M````Y](```4```#WT@``!0```/W2```;`````],``!H````?TP``$P```#K3
M```-````3M,``!$```!<TP``$0```&[3```6````@-,``!<```"7TP``'```
M`*_3```J````S-,``#D```#WTP``(@```#'4```R````5-0``!````"'U```
M(0```)C4```%````NM0``!,```#`U```"P```-34```2````X-0```H```#S
MU```#P```/[4```-````#M4``!$````<U0``$P```"[5```,````0M4```8`
M``!/U0``#````%;5```&````8]4``!<```!JU0``$````(+5```1````D]4`
M``@```"EU0``!0```*[5```,````M-4``!````#!U0``!0```-+5```.````
MV-4```T```#GU0``(P```/75```&````&=8``!8````@U@``*@```#?6```'
M````8M8```T```!JU@``!P```'C6```+````@-8```<```",U@``!P```)36
M```/````G-8```D```"LU@``"0```+;6```*````P-8``!D```#+U@``/0``
M`.76```=````(]<```P```!!UP``$````$[7```%````7]<``"4```!EUP``
M$@```(O7```3````GM<``!4```"RUP``$@```,C7```K````V]<``#L````'
MV```(````$/8```.````9-@```@```!SV```%````'S8```V````D=@``"$`
M``#(V```$````.K8```(````^]@```P````$V0``!@```!'9```$````&-D`
M``\````=V0``#@```"W9```'````/-D```H```!$V0``#0```$_9```?````
M7=D``!P```!]V0``(0```)K9```>````O-D``!D```#;V0``'@```/79```;
M````%-H``"$````PV@``+@```%+:```F````@=H``!P```"HV@``'@```,7:
M```<````Y-H``"8````!VP``*P```"C;```S````5-L``"8```"(VP``*P``
M`*_;```X````V]L``!T````4W```%0```#+<```O````2-P``"````!XW```
M$@```)G<```I````K-P``!X```#6W```(````/7<```2````%MT``*(````I
MW0``%@```,S=```C````X]T``"@````'W@``*0```##>```H````6MX``!\`
M``"#W@``%0```*/>```@````N=X``"4```#:W@``*`````#?```M````*=\`
M`#````!7WP``D@```(C?```A````&^```!8````]X```'````%3@```F````
M<>```"H```"8X```00```,/@``!$````!>$```P```!*X0``!P```%?A```'
M````7^$```8```!GX0``$P```&[A```-````@N$``!T```"0X0``$````*[A
M```2````O^$```<```#2X0``$P```-KA```2````[N$```<````!X@``!```
M``GB```0````#N(``!`````?X@``#````##B```.````/>(```T```!,X@``
M#P```%KB```3````:N(```T```!^X@``*````(SB```#````M>(```T```"Y
MX@``!@```,?B```1````SN(``!<```#@X@``&P```/CB```.````%.,```(`
M```CXP``20```";C```%````<.,``!````!VXP``#P```(?C```$````E^,`
M``T```"<XP``#@```*KC```#````N>,```X```"]XP``"````,SC```/````
MU>,```\```#EXP``!P```/7C```-````_>,``!`````+Y```#0```!SD```:
M````*N0```L```!%Y```!@```%'D```3````6.0```L```!LY```$P```'CD
M```,````C.0```H```"9Y```$0```*3D```9````MN0``!<```#0Y```"P``
M`.CD```-````].0``"(````"Y0``%@```"7E```/````/.4``!L```!,Y0``
M-````&CE```*````G>4``!@```"HY0``$@```,'E```9````U.4``!8```#N
MY0``(@````7F```C````*.8```\```!,Y@``#0```%SF```'````:N8```H`
M``!RY@``"@```'WF```4````B.8```L```"=Y@``(@```*GF```O````S.8`
M``L```#\Y@``"0````CG```9````$N<```L````LYP``%P```#CG```7````
M4.<```D```!HYP``!P```'+G```6````>N<```\```"1YP``&0```*'G```6
M````N^<```X```#2YP``&````.'G```(````^N<```T````#Z```)@```!'H
M```H````..@``$,```!AZ```"````*7H```2````KN@``!\```#!Z```"```
M`.'H```+````ZN@``"\```#VZ```#@```";I```.````->D```4```!$Z0``
M!@```$KI``!%````4>D```,```"7Z0``!P```)OI```$````H^D```D```"H
MZ0``$@```++I```*````Q>D```H```#0Z0``#P```-OI```0````Z^D``!<`
M``#\Z0``$0```!3J```1````)NH``!D````XZ@``%P```%+J```)````:NH`
M``4```!TZ@``"P```'KJ```*````ANH```(```"1Z@``!0```)3J```-````
MFNH``!L```"HZ@``%P```,3J```4````W.H```D```#QZ@``#@```/OJ```-
M````"NL``!(````8ZP``.````"OK```@````9.L```@```"%ZP``#@```([K
M``![````G>L``!@````9[```&````#+L```]````2^P``!4```")[```$0``
M`)_L```'````L>P```4```"Y[```(P```+_L```S````X^P``!@````7[0``
M'0```##M```N````3NT``!X```!][0``&P```)SM```9````N.T``"<```#2
M[0``-P```/KM```D````,NX``!L```!7[@``&0```'/N```3````C>X```<`
M``"A[@``"````*GN```&````LNX```8```"Y[@``$````,#N```/````T>X`
M`!````#A[@``#P```/+N```+`````N\```\````.[P``#````![O```/````
M*^\```<````[[P``!@```$/O```.````2N\```P```!9[P``*````&;O```/
M````C^\```@```"?[P``!@```*CO```3````K^\``"(```##[P``+0```.;O
M```(````%/```!,````=\```'@```#'P```E````4/```!H```!V\```%0``
M`)'P```>````I_```$,```#&\```(0````KQ```@````+/$``!D```!-\0``
M%P```&?Q```E````?_$``"4```"E\0``%P```,OQ```6````X_$``"$```#Z
M\0``(@```!SR```$````/_(``!L```!$\@``#0```&#R```,````;O(```,`
M``![\@``!0```'_R```(````A?(```H```".\@``#````)GR```+````IO(`
M`!````"R\@``#````,/R```.````T/(```L```#?\@``!````.OR```$````
M\/(``!,```#U\@``%`````GS```,````'O,```D````K\P``#@```#7S```+
M````1/,``!L```!0\P``!0```&SS```'````<O,```0```!Z\P``!@```'_S
M```'````AO,```H```".\P``"@```)GS```-````I/,```D```"R\P``!```
M`+SS```%````P?,```,```#'\P``&````,OS```*````Y/,```0```#O\P``
M)@```/3S```.````&_0``'P````J]```%0```*?T```%````O?0```<```##
M]```#````,OT```(````V/0```H```#A]```!@```.ST```(````\_0```(`
M``#\]```!@```/_T```&````!O4``!0````-]0``#````"+U```-````+_4`
M`!`````]]0``&P```$[U```$````:O4```D```!O]0``$````'GU```)````
MBO4```D```"4]0``!0```)[U```:````I/4```@```"_]0``!@```,CU```9
M````S_4```X```#I]0``!P```/CU```'`````/8```4````(]@``"0````[V
M```*````&/8``!,````C]@``#@```#?V```"````1O8```8```!)]@``"P``
M`%#V```-````7/8```D```!J]@``!@```'3V```2````>_8```D```".]@``
M!P```)CV```%````H/8``!0```"F]@``'0```+OV``!"````V?8``"4````<
M]P``)0```$+W```&````:/<```H```!O]P``!````'KW```)````?_<```@`
M``")]P``$0```)+W```)````I/<```8```"N]P``#0```+7W```&````P_<`
M``0```#*]P``.0```,_W```]````"?@``#H```!'^```'@```(+X```%````
MH?@```X```"G^```!````+;X```&````N_@```<```#"^```(0```,KX```-
M````[/@``!4```#Z^```!@```!#Y```$````%_D``!$````<^0``!@```"[Y
M```*````-?D``"(```!`^0``!````&/Y```%````:/D``!T```!N^0``!```
M`(SY```,````D?D```D```">^0``#````*CY```.````M?D```H```#$^0``
M$````,_Y```3````X/D``!,```#T^0``"`````CZ```)````$?H```4````;
M^@``.@```"'Z```P````7/H``#4```"-^@``*0```,/Z``!'````[?H``#@`
M```U^P``*0```&[[```_````F/L``"X```#8^P``+0````?\```?````-?P`
M``\```!5_```$@```&7\```+````>/P``"8```"$_```*0```*O\```D````
MU?P``"8```#Z_```"````"']```*````*OT```D````U_0``!P```#_]```@
M````1_T``"````!H_0``)@```(G]```$````L/T``"````"U_0``"@```-;]
M```9````X?T``"D```#[_0``%@```"7^```2````//X```<```!/_@``"@``
M`%?^```,````8OX```\```!O_@``$````'_^``!`````D/X``'````#1_@``
M9@```$+_```.````J?\```D```"X_P``"@```,+_```2````S?\``!,```#@
M_P``#````/3_```&`````0`!`!P````(``$`#P```"4``0`;````-0`!`!(`
M``!1``$`$````&0``0`1````=0`!`!P```"'``$`(P```*0``0!J````R``!
M``\````S`0$`!0```$,!`0`0````20$!``D```!:`0$`!````&0!`0`+````
M:0$!`"````!U`0$`%````)8!`0`,````JP$!``P```"X`0$`#P```,4!`0`5
M````U0$!`"D```#K`0$`*@```!4"`0`F````0`(!`"<```!G`@$`*0```(\"
M`0`J````N0(!`!D```#D`@$`0@```/X"`0`1````00,!`!(```!3`P$`$P``
M`&8#`0`4````>@,!``\```"/`P$`%@```)\#`0`7````M@,!`!````#.`P$`
M$0```-\#`0`T````\0,!`!,````F!`$`$@```#H$`0`U````300!`!0```"#
M!`$`!P```)@$`0`,````H`0!``H```"M!`$`(````+@$`0`0````V00!`!0`
M``#J!`$`%````/\$`0`1````%`4!`!<````F!0$`'````#X%`0`-````6P4!
M``T```!I!0$`$P```'<%`0`6````BP4!`!0```"B!0$`&@```+<%`0`1````
MT@4!``P```#D!0$`$````/$%`0`:`````@8!`!X````=!@$`&@```#P&`0`3
M````5P8!`!4```!K!@$`$0```($&`0`7````DP8!`!0```"K!@$`%P```,`&
M`0`5````V`8!``D```#N!@$`$````/@&`0`9````"0<!``0````C!P$`!P``
M`"@'`0`+````,`<!`!$````\!P$`!@```$X'`0`&````50<!``8```!<!P$`
M!0```&,'`0`'````:0<!``<```!Q!P$`!0```'D'`0`6````?P<!``8```"6
M!P$`!@```)T'`0`$````I`<!``0```"I!P$`!P```*X'`0`.````M@<!``P`
M``#%!P$`#````-('`0`-````WP<!``H```#M!P$`#@```/@'`0`%````!P@!
M`"@````-"`$`#@```#8(`0`,````10@!``\```!2"`$`"@```&((`0`(````
M;0@!``D```!V"`$`*P```(`(`0`$````K`@!``@```"Q"`$`)@```+H(`0`2
M````X0@!``\```#T"`$`!@````0)`0`*````"PD!`$P````6"0$`!P```&,)
M`0`(````:PD!`"````!T"0$`"0```)4)`0`-````GPD!``D```"M"0$`%```
M`+<)`0`,````S`D!``T```#9"0$`#@```.<)`0`6````]@D!`!$````-"@$`
M!@```!\*`0`#````)@H!``8````J"@$`&0```#$*`0`'````2PH!``0```!3
M"@$`"P```%@*`0`+````9`H!``<```!P"@$`!0```'@*`0`'````?@H!`!8`
M``"&"@$`#0```)T*`0`-````JPH!``H```"Y"@$`$````,0*`0`/````U0H!
M`!$```#E"@$`%P```/<*`0`*````#PL!`!$````:"P$`"````"P+`0`$````
M-0L!``\````Z"P$`.@```$H+`0`%````A0L!``P```"+"P$`!````)@+`0`>
M````G0L!``X```"\"P$`$````,L+`0`+````W`L!``P```#H"P$`"0```/4+
M`0`'````_PL!``H````'#`$`"0```!(,`0`.````'`P!`!`````K#`$`&P``
M`#P,`0`8````6`P!`!H```!Q#`$`"@```(P,`0`)````EPP!``H```"A#`$`
M#````*P,`0`/````N0P!``@```#)#`$`!@```-(,`0`<````V0P!``<```#V
M#`$`!0```/X,`0`+````!`T!`$<````0#0$`#0```%@-`0`)````9@T!``0`
M``!P#0$``P```'4-`0`3````>0T!`!,```"-#0$`$P```*$-`0`*````M0T!
M``(```#`#0$`!````,,-`0`E````R`T!``,```#N#0$`!0```/(-`0`J````
M^`T!``H````C#@$`!0```"X.`0`$````-`X!``H````Y#@$`#0```$0.`0`&
M````4@X!``@```!9#@$`"````&(.`0`$````:PX!``4```!P#@$`:````'8.
M`0`)````WPX!``P```#I#@$`$````/8.`0`%````!P\!``8````-#P$`&P``
M`!0/`0`O````,`\!`!````!@#P$`"@```'$/`0`(````?`\!``\```"%#P$`
M"@```)4/`0`)````H`\!`!,```"J#P$`&P```+X/`0`8````V@\!`!<```#S
M#P$`&@````L0`0`?````)A`!``X```!&$`$`%P```%40`0`#````;1`!``<`
M``!Q$`$`"````'D0`0`'````@A`!``D```"*$`$`"@```)00`0`+````GQ`!
M``<```"K$`$`40```+,0`0`0````!1$!``P````6$0$`#0```",1`0`:````
M,1$!`$H```!,$0$`&0```)<1`0`&````L1$!`!H```"X$0$`)0```-,1`0`&
M````^1$!``8`````$@$`'P````<2`0`&````)Q(!``D````N$@$`&````#@2
M`0`7````41(!`"@```!I$@$`!@```)(2`0`-````F1(!`"@```"G$@$`(@``
M`-`2`0!7````\Q(!`!,```!+$P$`(P```%\3`0`3````@Q,!``(```"7$P$`
M"P```)H3`0`,````IA,!``@```"S$P$`#0```+P3`0`*````RA,!`!8```#5
M$P$`!P```.P3`0`4````]!,!``8````)%`$`"````!`4`0`.````&10!``<`
M```H%`$`"@```#`4`0`+````.Q0!`#(```!'%`$`%P```'H4`0`'````DA0!
M``P```":%`$`#0```*<4`0`,````M10!``0```#"%`$`"0```,<4`0`)````
MT10!``H```#;%`$`!P```.84`0`)````[A0!``D```#X%`$`"@````(5`0`'
M````#14!``H````5%0$`%0```"`5`0`;````-A4!``\```!2%0$`20```&(5
M`0`2````K!4!``H```"_%0$`%@```,H5`0`/````X14!`!````#Q%0$`"0``
M``(6`0`0````#!8!``<````=%@$`$@```"46`0`$````.!8!``L````]%@$`
M!P```$D6`0`%````418!``4```!7%@$`&@```%T6`0`+````>!8!`!0```"$
M%@$`$0```)D6`0`:````JQ8!`!8```#&%@$`%````-T6`0`7````\A8!`!@`
M```*%P$`'````",7`0`9````0!<!``<```!:%P$`!0```&(7`0`-````:!<!
M``P```!V%P$`"P```(,7`0`1````CQ<!``@```"A%P$`%P```*H7`0`+````
MPA<!``P```#.%P$`'P```-L7`0`:````^Q<!`!,````6&`$`!````"H8`0`*
M````+Q@!``0````Z&`$`#0```#\8`0`,````31@!``4```!:&`$`"0```&`8
M`0`(````:A@!``4```!S&`$`!P```'D8`0`%````@1@!``0```"'&`$``@``
M`(P8`0`8````CQ@!`!<```"H&`$`.````,`8`0`L````^1@!`!(````F&0$`
M*0```#D9`0`R````8QD!``H```"6&0$`+````*$9`0`N````SAD!`#,```#]
M&0$`,P```#$:`0`X````91H!`!$```">&@$`#P```+`:`0`8````P!H!`!``
M``#9&@$`#P```.H:`0`3````^AH!`!4````.&P$`%````"0;`0`2````.1L!
M`!0```!,&P$`%0```&$;`0`M````=QL!`"T```"E&P$`,0```-,;`0`N````
M!1P!`"\````T'`$`+````&0<`0!B````D1P!`!,```#T'`$`#0````@=`0`(
M````%AT!`!<````?'0$`"````#<=`0`,````0!T!`"L```!-'0$`(0```'D=
M`0`8````FQT!`!H```"T'0$`"0```,\=`0!%````V1T!`$$````?'@$`!```
M`&$>`0`3````9AX!`!0```!Z'@$`#@```(\>`0`3````GAX!`!@```"R'@$`
M!@```,L>`0`)````TAX!``H```#<'@$`#P```.<>`0`0````]QX!``<````(
M'P$`#@```!`?`0`%````'Q\!`!L````E'P$`"````$$?`0`&````2A\!`!0`
M``!1'P$`$0```&8?`0`8````>!\!``X```"1'P$`.````*`?`0`"````V1\!
M``8```#<'P$`#@```.,?`0`0````\A\!``4````#(`$`!P````D@`0`.````
M$2`!``8````@(`$`*````"<@`0`,````4"`!`!P```!=(`$`!````'H@`0":
M````?R`!`"D````:(0$`%P```$0A`0`?````7"$!`!D```!\(0$`7````)8A
M`0`4````\R$!`#X````((@$`'P```$<B`0`0````9R(!``<```!X(@$`#@``
M`(`B`0`,````CR(!``P```"<(@$`$P```*DB`0`*````O2(!`!T```#((@$`
M&0```.8B`0`%`````",!`!$````&(P$`#0```!@C`0`1````)B,!`"0````X
M(P$`$@```%TC`0`5````<",!`!(```"&(P$`#@```)DC`0`9````J",!``@`
M``#"(P$`"0```,LC`0`-````U2,!``<```#C(P$`"@```.LC`0`'````]B,!
M``\```#^(P$`!@````XD`0`+````%20!`!H````A)`$`"@```#PD`0`'````
M1R0!``@```!/)`$`!0```%@D`0`?````7B0!``8```!^)`$`$````(4D`0`(
M````EB0!``T```"?)`$`"````*TD`0`>````MB0!`!(```#5)`$`+````.@D
M`0`:````%24!``D````P)0$`"@```#HE`0`5````124!``4```!;)0$`%```
M`&$E`0`$````=B4!`!````![)0$`!@```(PE`0`'````DR4!`!X```";)0$`
M*````+HE`0`*````XR4!`!P```#N)0$`$0````LF`0`1````'28!``L````O
M)@$`&@```#LF`0`4````5B8!``0```!K)@$`!````'`F`0`+````=28!``4`
M``"!)@$`!@```(<F`0`1````CB8!``@```"@)@$`!@```*DF`0`*````L"8!
M`!L```"[)@$`-````-<F`0`T````#"<!`"````!!)P$`*0```&(G`0`@````
MC"<!`$$```"M)P$`&@```.\G`0`A````"B@!`"@````L*`$`*0```%4H`0!0
M````?R@!`"(```#0*`$`!@```/,H`0`(````^B@!``4````#*0$`"`````DI
M`0`9````$BD!`!D````L*0$`*@```$8I`0`C````<2D!`!D```"5*0$`+@``
M`*\I`0`T````WBD!``@````3*@$`%P```!PJ`0`*````-"H!``<````_*@$`
M(0```$<J`0`(````:2H!`!````!R*@$`#@```(,J`0`4````DBH!``L```"G
M*@$`!P```+,J`0`3````NRH!``@```#/*@$`"P```-@J`0`*````Y"H!`!0`
M``#O*@$`#P````0K`0`R````%"L!``L```!'*P$`#@```%,K`0`%````8BL!
M``4```!H*P$`%0```&XK`0`,````A"L!``4```"1*P$`%P```)<K`0`/````
MKRL!``0```"_*P$`"@```,0K`0`)````SRL!``L```#9*P$`#0```.4K`0`,
M````\RL!``X`````+`$`!0````\L`0`$````%2P!`!0````:+`$`#0```"\L
M`0`B````/2P!`#(```!@+`$`&P```),L`0!%````KRP!`!(```#U+`$`%P``
M``@M`0`'````("T!`!X````H+0$`%````$<M`0`%````7"T!`!0```!B+0$`
M!@```'<M`0`'````?BT!``X```"&+0$`*@```)4M`0`&````P"T!``P```#'
M+0$`$P```-0M`0`-````Z"T!`!$```#V+0$`%0````@N`0`+````'BX!`#8`
M```J+@$`"@```&$N`0`B````;"X!``L```"/+@$`#P```)LN`0"%````JRX!
M`#(````Q+P$`&P```&0O`0`E````@"\!`#````"F+P$`,0```-<O`0`M````
M"3`!``X````W,`$`!0```$8P`0`.````3#`!`!,```!;,`$`$0```&\P`0`2
M````@3`!``<```"4,`$`$0```)PP`0`3````KC`!``<```#",`$`%````,HP
M`0`8````WS`!``<```#X,`$`!0`````Q`0`,````!C$!``P````3,0$`$@``
M`"`Q`0`$````,S$!``<````X,0$`"@```$`Q`0`+````2S$!``P```!7,0$`
M#@```&0Q`0`.````<S$!``4```"",0$`!0```(@Q`0`N````CC$!`"8```"]
M,0$`(P```.0Q`0`#````"#(!`!(````,,@$`!@```!\R`0`>````)C(!`!@`
M``!%,@$`&0```%XR`0`E````>#(!``T```">,@$`"0```*PR`0`?````MC(!
M``,```#6,@$`&````-HR`0`'````\S(!``H```#[,@$``@````8S`0`,````
M"3,!`!4````6,P$`"P```"PS`0`9````.#,!`"````!2,P$`$@```',S`0`%
M````AC,!``H```",,P$`%0```)<S`0`2````K3,!``P```#`,P$`!````,TS
M`0`)````TC,!``<```#<,P$`#````.0S`0!2````\3,!`!<```!$-`$`)```
M`%PT`0`A````@30!`!(```"C-`$`!P```+8T`0`&````OC0!``X```#%-`$`
M#0```-0T`0`1````XC0!`!L```#T-`$`#````!`U`0`,````'34!``T````J
M-0$`%0```#@U`0`2````3C4!``\```!A-0$`%````'$U`0`*````AC4!`!L`
M``"1-0$`(````*TU`0`>````SC4!`!````#M-0$`"P```/XU`0`G````"C8!
M`"4````R-@$`:0```%@V`0`F````PC8!`!H```#I-@$`%P````0W`0`9````
M'#<!`!H````V-P$`)0```%$W`0`H````=S<!`"<```"@-P$`&@```,@W`0`7
M````XS<!`!L```#[-P$`1````!<X`0`T````7#@!`"4```"1.`$`&0```+<X
M`0`?````T3@!`!L```#Q.`$`$P````TY`0`(````(3D!``<````J.0$`"```
M`#(Y`0`)````.SD!`!4```!%.0$`#0```%LY`0`C````:3D!``T```"-.0$`
M$P```)LY`0`(````KSD!``,```"X.0$`1@```+PY`0`_`````SH!`#<```!#
M.@$`5P```'LZ`0`%````TSH!`!\```#9.@$`+P```/DZ`0`*````*3L!`!``
M```T.P$`"````$4[`0`-````3CL!`"T```!<.P$`!````(H[`0`'````CSL!
M``@```"7.P$`#0```*`[`0`*````KCL!`$\```"Y.P$`)0````D\`0`<````
M+SP!``L```!,/`$`'P```%@\`0`=````>#P!`"4```"6/`$`(````+P\`0`D
M````W3P!`"`````"/0$`"P```",]`0`'````+ST!``T````W/0$`#````$4]
M`0`7````4CT!``8```!J/0$`.0```'$]`0`,````JST!``<```"X/0$`"0``
M`,`]`0`3````RCT!``D```#>/0$`!````.@]`0`0````[3T!``@```#^/0$`
M"`````<^`0`$````$#X!``L````5/@$`#````"$^`0`2````+CX!`!$```!!
M/@$`#````%,^`0`:````8#X!``\```![/@$`!P```(L^`0`-````DSX!``X`
M``"A/@$`%````+`^`0`.````Q3X!``<```#4/@$`#````-P^`0`;````Z3X!
M`"P````%/P$`$P```#(_`0`<````1C\!`"@```!C/P$`!@```(P_`0`'````
MDS\!`!,```";/P$`!0```*\_`0`$````M3\!`!<```"Z/P$`.0```-(_`0`*
M````#$`!``P````70`$`"0```"1``0`&````+D`!``D````U0`$`"````#]`
M`0`)````2$`!``H```!20`$`$0```%U``0`&````;T`!``X```!V0`$`#@``
M`(5``0`-````E$`!``L```"B0`$`'0```*Y``0`+````S$`!``(```#80`$`
M'````-M``0`'````^$`!``8`````00$`9`````=!`0`)````;$$!``<```!V
M00$`)@```'Y!`0`I````I4$!`!L```#/00$`.````.M!`0`K````)$(!`!H`
M``!00@$`(P```&M"`0`J````CT(!`"T```"Z0@$`.P```.A"`0`H````)$,!
M`#0```!-0P$`&0```()#`0`5````G$,!``4```"R0P$`!P```+A#`0`(````
MP$,!``<```#)0P$`!0```-%#`0`'````UT,!``X```#?0P$`"0```.Y#`0`&
M````^$,!``@```#_0P$`"P````A$`0`'````%$0!``@````<1`$`!P```"5$
M`0`6````+40!``D```!$1`$`!@```$Y$`0`+````540!`!````!A1`$`!@``
M`')$`0`<````>40!`!0```"61`$`!P```*M$`0`1````LT0!``@```#%1`$`
M#@```,Y$`0`#````W40!``@```#A1`$`%````.I$`0`%````_T0!`!`````%
M10$`"0```!9%`0`0````($4!``8````Q10$`&0```#A%`0`*````4D4!`!P`
M``!=10$`!P```'I%`0`%````@D4!`!````"(10$`%````)E%`0`+````KD4!
M``T```"Z10$`*````,A%`0`8````\44!`!<````*1@$`!````")&`0`)````
M)T8!``H````Q1@$`!P```#Q&`0`"````1$8!``X```!'1@$`"````%9&`0`C
M````7T8!`!\```"#1@$`.````*-&`0`F````W$8!`#$````#1P$`)P```#5'
M`0!$````74<!`"4```"B1P$`+P```,A'`0`O````^$<!`"\````H2`$`*```
M`%A(`0!D````@4@!`!0```#F2`$`50```/M(`0`X````44D!`"D```"*20$`
M2@```+1)`0!;````_TD!`"@```!;2@$`.````(1*`0`L````O4H!`"@```#J
M2@$`+````!-+`0`F````0$L!`!L```!G2P$`/@```(-+`0"I`0``PDL!`",`
M``!L30$`,````)!-`0`7````P4T!`$@```#930$`A0```").`0`P````J$X!
M`"4```#93@$`00```/].`0!;````04\!`$D```"=3P$`,0```.=/`0`=````
M&5`!`!@````W4`$`*P```%!0`0`A````?%`!`!\```">4`$`*P```+Y0`0`F
M````ZE`!`"<````140$`.@```#E1`0`=````=%$!`!$```"240$`,P```*11
M`0`E````V%$!`"<```#^40$`(````"92`0`F````1U(!`!\```!N4@$`,```
M`(Y2`0#,````OU(!`&D```",4P$`,0```/93`0!!````*%0!`#,```!J5`$`
M)0```)Y4`0`]````Q%0!`&4````"50$`30```&A5`0!>````ME4!`"<````5
M5@$`,0```#U6`0`^````;U8!`"P```"N5@$`)@```-M6`0`O`````E<!`"X`
M```R5P$`*0```&%7`0`P````BU<!`%0```"\5P$`6@```!%8`0`Q````;%@!
M`$@```">6`$`2@```.=8`0`Q````,ED!`"H```!D60$`(@```(]9`0`O````
MLED!`"D```#B60$`,@````Q:`0`O````/UH!`"P```!O6@$`+0```)Q:`0!Q
M````REH!`&8````\6P$`;P```*-;`0"S````$UP!`!<```#'7`$`)0```-]<
M`0`R````!5T!`"D````X70$`/@```&)=`0`B````H5T!`%(```#$70$`(@``
M`!=>`0`E````.EX!``L```!@7@$`L0```&Q>`0!%````'E\!`"$```!D7P$`
M-@```(9?`0`P````O5\!`"4```#N7P$`'````!1@`0!(````,6`!`#$```!Z
M8`$`!P```*Q@`0`'````M&`!``0```"\8`$`#0```,%@`0`+````SV`!``X`
M``#;8`$`"P```.I@`0`%````]F`!`!````#\8`$``@````UA`0!9````$&$!
M``4```!J80$`$@```'!A`0`$````@V$!``<```"(80$`"````)!A`0`%````
MF6$!``,```"?80$`$````*-A`0`,````M&$!`!,```#!80$`#0```-5A`0`"
M````XV$!``<```#F80$`!@```.YA`0`4````]6$!``P````*8@$`&````!=B
M`0`&````,&(!`!(````W8@$`#````$IB`0`#````5V(!`"H```!;8@$`!```
M`(9B`0`&````BV(!``<```"28@$`'P```)IB`0`U````NF(!`"X```#P8@$`
M+P```!]C`0`7````3V,!`"(```!G8P$`)0```(IC`0`@````L&,!`!L```#1
M8P$`&````.UC`0`D````!F0!`!\````K9`$`&@```$MD`0`A````9F0!`"``
M``"(9`$`,````*ED`0`:````VF0!`#(```#U9`$`&@```"AE`0`O````0V4!
M`"L```!S90$`'P```)]E`0`C````OV4!`!\```#C90$`&@````-F`0`A````
M'F8!`"4```!`9@$`)@```&9F`0`E````C68!`"0```"S9@$`&````-AF`0`=
M````\68!`"0````/9P$`&````#1G`0`B````36<!`"P```!P9P$`+P```)UG
M`0`5````S6<!`"4```#C9P$`/`````EH`0`?````1F@!`",```!F:`$`'P``
M`(IH`0`@````JF@!`!H```#+:`$`&````.9H`0`F````_V@!`!X````F:0$`
M*0```$5I`0`>````;VD!`#$```".:0$`"0```,!I`0`,````RFD!`!<```#7
M:0$`+P```.]I`0`D````'VH!``<```!$:@$`#P```$QJ`0`4````7&H!``X`
M``!Q:@$`#0```(!J`0`D````CFH!``4```"S:@$`!P```+EJ`0`B````P6H!
M`"4```#D:@$`&@````IK`0`=````)6L!`!H```!#:P$`!P```%YK`0#'````
M9FL!``L````N;`$`'````#IL`0`5````5VP!``8```!M;`$`"0```'1L`0`+
M````?FP!``T```"*;`$`%P```)AL`0`&````L&P!`#,```"W;`$`$P```.ML
M`0`3````_VP!``<````3;0$`#P```!MM`0`'````*VT!`#(````S;0$`!```
M`&9M`0`A````:VT!`!,```"-;0$`#````*%M`0`1````KFT!`#(```#`;0$`
M%@```/-M`0`(````"FX!`!T````3;@$`"0```#%N`0`*````.VX!`!0```!&
M;@$`"@```%MN`0`=````9FX!``@```"$;@$`'P```(UN`0`(````K6X!`!H`
M``"V;@$`)P```-%N`0`&````^6X!`!4`````;P$`!P```!9O`0`(````'F\!
M``D````G;P$`/P```#%O`0`2````<6\!``<```"$;P$`#P```(QO`0`.````
MG&\!`!````"K;P$`"0```+QO`0`)````QF\!``@```#0;P$`$P```-EO`0`)
M````[6\!``<```#W;P$`#````/]O`0`9````#'`!``H````F<`$`&P```#%P
M`0`7````37`!`!0```!E<`$`"@```'IP`0`,````A7`!`!<```"2<`$`!```
M`*IP`0`J````KW`!``P```#:<`$`$0```.=P`0`'````^7`!``(````!<0$`
M$`````1Q`0`8````%7$!``L````N<0$``P```#IQ`0`(````/G$!``L```!'
M<0$`!@```%-Q`0`'````6G$!``T```!B<0$`"P```'!Q`0`4````?'$!`!4`
M``"1<0$`#@```*=Q`0`O````MG$!`"````#F<0$`'`````=R`0`5````)'(!
M``P````Z<@$`,0```$=R`0`%````>7(!`!(```!_<@$`/P```))R`0`2````
MTG(!``H```#E<@$`!@```/!R`0`$````]W(!``0```#\<@$`"@````%S`0`3
M````#',!``4````@<P$`!@```"9S`0`&````+7,!``@````T<P$`!````#US
M`0`,````0G,!``D```!/<P$`#````%ES`0`*````9G,!`!````!Q<P$`$P``
M`()S`0`3````EG,!`#D```"J<P$`+@```.1S`0`I````$W0!``4````]=`$`
M&````$-T`0`9````7'0!`!\```!V=`$`'0```)9T`0`1````M'0!``(```#&
M=`$`!````,ET`0`*````SG0!``8```#9=`$`!0```.!T`0`#````YG0!``P`
M``#J=`$`10```/=T`0`R````/74!`#P```!P=0$`&@```*UU`0`T````R'4!
M`"@```#]=0$`4P```"9V`0`P````>G8!`"\```"K=@$`,@```-MV`0`9````
M#G<!`'(````H=P$`(````)MW`0`U````O'<!`"$```#R=P$`10```!1X`0`P
M````6G@!`"8```"+>`$`'@```+)X`0`H````T7@!`"L```#Z>`$`*0```"9Y
M`0`I````4'D!`"8```!Z>0$`)0```*%Y`0`H````QWD!`"@```#P>0$`(@``
M`!EZ`0`K````/'H!`"X```!H>@$`,````)=Z`0`2````R'H!`!,```#;>@$`
M$````.]Z`0!Y`````'L!``D```!Z>P$`H0```(1[`0!S````)GP!`'P```":
M?`$`*P```!=]`0!4````0WT!`!<```"8?0$`+````+!]`0`G````W7T!`!8`
M```%?@$`#P```!Q^`0`7````+'X!`!\```!$?@$`0````&1^`0`?````I7X!
M`!P```#%?@$`40```.)^`0`:````-'\!`!0```!/?P$`"@```&1_`0`%````
M;W\!``8```!U?P$`"````'Q_`0`%````A7\!`!(```"+?P$`$````)Y_`0`3
M````KW\!`!T```##?P$`#P```.%_`0`*````\7\!``\```#\?P$`!P````R`
M`0`$````%(`!``D````9@`$`"0```".``0`'````+8`!``L````U@`$`!P``
M`$&``0`%````28`!`!0```!/@`$`#@```&2``0`&````<X`!``<```!Z@`$`
M"````(*``0`/````BX`!`!$```";@`$`#````*V``0`(````NH`!``P```##
M@`$`#P```-"``0`6````X(`!``<```#W@`$`!@```/^``0`4````!H$!``8`
M```;@0$`#````"*!`0`1````+X$!``@```!!@0$`!````$J!`0`9````3X$!
M`!$```!I@0$`"@```'N!`0`8````AH$!`!,```"?@0$`"P```+.!`0`,````
MOX$!``P```#,@0$`#````-F!`0`<````YH$!`!$````#@@$`!````!6"`0`/
M````&H(!``<````J@@$`!````#*"`0`9````-X(!``<```!1@@$``@```%F"
M`0`"````7((!`!$```!?@@$`"0```'&"`0`&````>X(!`!(```""@@$`%P``
M`)6"`0`&````K8(!`"<```"T@@$``@```-R"`0`$````WX(!``T```#D@@$`
M!````/*"`0`/````]X(!`!,````'@P$`!P```!N#`0`'````(X,!`!$````K
M@P$`!@```#V#`0`8````1(,!``8```!=@P$`$P```&2#`0`0````>(,!`!(`
M``")@P$``@```)R#`0`&````GX,!``P```"F@P$`"0```+.#`0`1````O8,!
M`!$```#/@P$`&P```.&#`0`B````_8,!``<````@A`$`!P```"B$`0`+````
M,(0!``4````\A`$``@```$*$`0`+````180!`'T!``!1A`$`#P```,^%`0`2
M````WX4!``T```#RA0$`!@````"&`0`)````!X8!``<````1A@$`)P```!F&
M`0`I````088!``,```!KA@$`'P```&^&`0`9````CX8!`!\```"IA@$`,@``
M`,F&`0`O````_(8!`"@````LAP$`+0```%6'`0`E````@X<!`!D```"IAP$`
M*````,.'`0`E````[(<!`"8````2B`$`*P```#F(`0`*````98@!`"X```!P
MB`$`%@```)^(`0`*````MH@!`!0```#!B`$`!0```-:(`0`N````W(@!`!,`
M```+B0$`"P```!^)`0`:````*XD!`!$```!&B0$`#0```%B)`0`.````9HD!
M`#````!UB0$`F0```*:)`0`-````0(H!``H```!.B@$`%P```%F*`0`.````
M<8H!`!P```"`B@$`#````)V*`0`6````JHH!``P```#!B@$`!@```,Z*`0"=
M````U8H!``H```!SBP$`#P```'Z+`0`5````CHL!`!$```"DBP$`$P```+:+
M`0`3````RHL!``@```#>BP$`"0```.>+`0`N````\8L!`#8````@C`$`)```
M`%>,`0`X````?(P!`$,```"UC`$`90```/F,`0!B````7XT!`&L```#"C0$`
M:````"Z.`0`Z````EXX!``\```#2C@$`%0```.*.`0`.````^(X!`!,````'
MCP$`&0```!N/`0`%````-8\!``D````[CP$`$0```$6/`0`,````5X\!`!\`
M``!DCP$`#0```(2/`0`-````DH\!`#0```"@CP$`,0```-6/`0`4````!Y`!
M``D````<D`$`%````":0`0`4````.Y`!``P```!0D`$`"````%V0`0`9````
M9I`!`!X```"`D`$`#````)^0`0`,````K)`!`!$```"YD`$`(P```,N0`0`H
M````[Y`!`!(````8D0$`'0```"N1`0`N````29$!``X```!XD0$`#@```(>1
M`0`/````EI$!``H```"FD0$`+P```+&1`0`(````X9$!`!D```#JD0$`&0``
M``22`0`.````'I(!`%P````MD@$`.@```(J2`0`=````Q9(!`"H```#CD@$`
M"0````Z3`0`6````&),!`!8````ODP$`%P```$:3`0`D````7I,!`#8```"#
MDP$`(@```+J3`0`L````W9,!`#0````*E`$`#@```#^4`0`(````3I0!`!$`
M``!7E`$`"@```&F4`0`'````=)0!``<```!\E`$`!0```(24`0`'````BI0!
M``L```"2E`$`!````)Z4`0`A````HY0!`!````#%E`$`%0```-:4`0`/````
M[)0!`!L```#\E`$`-````!B5`0`)````394!``D```!7E0$`%P```&&5`0`6
M````>94!`!@```"0E0$`(0```*F5`0`7````RY4!`!$```#CE0$`#P```/65
M`0`?````!98!`"4````EE@$`!P```$N6`0`&````4Y8!``<```!:E@$`#0``
M`&*6`0`)````<)8!``D```!ZE@$`$@```(26`0`*````EY8!`!4```"BE@$`
M&0```+B6`0`L````TI8!``<```#_E@$`$0````>7`0`%````&9<!`!8````?
MEP$`$@```#:7`0`2````29<!`"8```!<EP$`/@```(.7`0`^````PI<!`#X`
M```!F`$`"0```$"8`0`'````2I@!`!,```!2F`$`!````&:8`0`%````:Y@!
M``H```!QF`$`#@```'R8`0`.````BY@!`!<```":F`$`1P```+*8`0`6````
M^I@!`"8````1F0$`*P```#B9`0`L````9)D!`#0```"1F0$`"0```,:9`0`&
M````T)D!``D```#7F0$`!P```.&9`0`X````Z9D!`#H````BF@$`-P```%V:
M`0!<````E9H!`#8```#RF@$`-@```"F;`0!'````8)L!`$L```"HFP$`-@``
M`/2;`0!.````*YP!`"P```!ZG`$`+@```*><`0!-````UIP!`#8````DG0$`
M/````%N=`0`N````F)T!`!@```#'G0$`'````."=`0`S````_9T!`"T````Q
MG@$`+0```%^>`0`3````C9X!``H```"AG@$`#````*R>`0`%````N9X!``X`
M``"_G@$`'P```,Z>`0`F````[IX!``<````5GP$`!P```!V?`0`5````)9\!
M``H````[GP$`"````$:?`0`S````3Y\!``H```"#GP$`#P```(Z?`0`'````
MGI\!``<```"FGP$`!@```*Z?`0`I````M9\!``4```#?GP$`"````.6?`0`&
M````[I\!`!\```#UGP$`"@```!6@`0`T````(*`!`!(```!5H`$`#@```&B@
M`0`'````=Z`!``<```!_H`$`"@```(>@`0`%````DJ`!`!$```"8H`$`!@``
M`*J@`0`2````L:`!``4```#$H`$`"````,J@`0`(````TZ`!``X```#<H`$`
M!@```.N@`0`I````\J`!``@````<H0$`$0```"6A`0`(````-Z$!`!$```!`
MH0$`#````%*A`0`'````7Z$!`!0```!GH0$``P```'RA`0`#````@*$!`!H`
M``"$H0$``P```)^A`0`8````HZ$!`"H```"\H0$`!@```.>A`0`%````[J$!
M``<```#TH0$`!P```/RA`0!E````!*(!`"<```!JH@$`)P```)*B`0`X````
MNJ(!`"D```#SH@$`(@```!VC`0`&````0*,!``@```!'HP$`'0```%"C`0`E
M````;J,!`"<```"4HP$`-````+RC`0`H````\:,!`"T````:I`$`8@```$BD
M`0`V````JZ0!``H```#BI`$`"0```.VD`0`)````]Z0!`!8````!I0$`#```
M`!BE`0`.````):4!`!0````TI0$`$````$FE`0`4````6J4!`!,```!OI0$`
M#@```(.E`0`5````DJ4!``<```"HI0$`&````+"E`0`;````R:4!`!@```#E
MI0$`&P```/ZE`0`9````&J8!``0````TI@$`!P```#FF`0`4````0:8!`%@`
M``!6I@$`<@```*^F`0`'````(J<!`!4````JIP$`&````$"G`0`%````6:<!
M``4```!?IP$`&P```&6G`0`8````@:<!``L```":IP$`#P```*:G`0`4````
MMJ<!`!H```#+IP$`(0```.:G`0`A````"*@!`!X````JJ`$`.P```$FH`0`Y
M````A:@!`#````"_J`$`*@```/"H`0`.````&ZD!`"P````JJ0$`!P```%>I
M`0`;````7ZD!``\```![J0$`$@```(NI`0`.````GJD!`!@```"MJ0$`$```
M`,:I`0`6````UZD!`!,```#NJ0$`#@````*J`0`%````$:H!``\````7J@$`
M!@```">J`0`8````+JH!`!4```!'J@$`#P```%VJ`0`(````;:H!``4```!V
MJ@$`$0```'RJ`0`2````CJH!``D```"AJ@$`$P```*NJ`0`7````OZH!`!T`
M``#7J@$`!@```/6J`0`;````_*H!`#(````8JP$`!P```$NK`0`1````4ZL!
M``H```!EJP$`#````'"K`0`'````?:L!``@```"%JP$`$0```(ZK`0`+````
MH*L!``D```"LJP$`"P```+:K`0`?````PJL!`$D```#BJP$`)0```"RL`0`-
M````4JP!`!0```!@K`$`!0```'6L`0`@````>ZP!`!(```"<K`$`$P```*^L
M`0`5````PZP!`!$```#9K`$`.@```.NL`0!*````)JT!`"<```!QK0$`%0``
M`)FM`0`)````KZT!`!D```"YK0$`/````-.M`0`J````$*X!`!$````[K@$`
M"0```$VN`0`*````5ZX!``8```!BK@$`!@```&FN`0`2````<*X!`!````"#
MK@$`"P```)2N`0`*````H*X!``\```"KK@$`+````+NN`0`L````Z*X!`"T`
M```5KP$`+@```$.O`0`B````<J\!`"4```"5KP$`(@```+NO`0`F````WJ\!
M`#8````%L`$`+@```#RP`0`F````:[`!`"@```"2L`$`)````+NP`0`Q````
MX+`!`$4````2L0$`0````%BQ`0`U````F;$!`#0```#/L0$`/@````2R`0`F
M````0[(!`"4```!JL@$`/````)"R`0`E````S;(!`!4```#SL@$`.0````FS
M`0`E````0[,!`"<```!ILP$`%````)&S`0#*````IK,!`!L```!QM`$`,0``
M`(VT`0`P````O[0!`#,```#PM`$`,0```"2U`0`G````5K4!`"@```!^M0$`
M*P```*>U`0`R````T[4!`#4````&M@$`2P```#RV`0`T````B+8!`*0```"]
MM@$`)P```&*W`0`=````BK<!`"8```"HMP$`,P```,^W`0`Q`````[@!`$X`
M```UN`$`50```(2X`0`-````VK@!``0```#HN`$`!@```.VX`0`%````]+@!
M`!P```#ZN`$`#P```!>Y`0`9````)[D!``4```!!N0$`$0```$>Y`0`&````
M6;D!`!8```!@N0$`'````'>Y`0`'````E+D!``0```"<N0$`$````*&Y`0`1
M````LKD!``L```#$N0$`"@```-"Y`0`1````V[D!``T```#MN0$`$@```/NY
M`0`-````#KH!`#H````<N@$`!@```%>Z`0`0````7KH!``8```!ON@$`$0``
M`':Z`0`7````B+H!`!L```"@N@$`#P```+RZ`0`"````S+H!`$D```#/N@$`
M"P```!F[`0`,````);L!`!P````RNP$`!0```$^[`0`7````5;L!`!(```!M
MNP$``P```("[`0`1````A+L!``D```"6NP$`$0```*"[`0`0````LKL!``L`
M``##NP$`$0```,^[`0`5````X;L!`!$```#WNP$`)0````F\`0`,````+[P!
M``@````\O`$`'P```$6\`0`.````9;P!`!L```!TO`$`#@```)"\`0`1````
MG[P!`!,```"QO`$`&@```,6\`0`B````X+P!``X````#O0$`$````!*]`0`K
M````([T!`"T```!/O0$`$0```'V]`0`<````C[T!`$0```"LO0$`#0```/&]
M`0`?````_[T!`!0````?O@$`&0```#2^`0`6````3KX!`$,```!EO@$`'P``
M`*F^`0`D````R;X!`!````#NO@$`"0```/^^`0`,````";\!``L````6OP$`
M%````"*_`0`+````-[\!`#8```!#OP$`-0```'J_`0`*````L+\!`!4```"[
MOP$`*0```-&_`0`7````^[\!`!8````3P`$`%@```"K``0`*````0<`!``T`
M``!,P`$`(````%K``0`9````>\`!`!P```"5P`$`&````++``0`9````R\`!
M`!@```#EP`$`"````/[``0`+````!\$!`"D````3P0$`+````#W!`0!8````
M:L$!``@```##P0$`%````,S!`0`B````X<$!``D````$P@$`#`````["`0`V
M````&\(!``\```!2P@$`$0```&+"`0`&````=,(!``8```![P@$`50```(+"
M`0`#````V,(!``<```#<P@$`"0```.3"`0`.````[L(!`"$```#]P@$`$```
M`!_#`0`/````,,,!`!0```!`PP$`%0```%7#`0`;````:\,!`!<```"'PP$`
M%@```)_#`0`=````ML,!`!L```#4PP$`"0```/##`0`&````^L,!``L````!
MQ`$`"P````W$`0`"````&<0!``8````<Q`$`$P```"/$`0`O````-\0!`!<`
M``!GQ`$`%0```'_$`0`*````E<0!`!$```"@Q`$`%````++$`0`<````Q\0!
M`#D```#DQ`$`-P```![%`0`2````5L4!``\```!IQ0$`A@```'G%`0`C````
M`,8!`"`````DQ@$`5P```$7&`0`C````G<8!`!$```#!Q@$`!P```-/&`0`%
M````V\8!`#T```#AQ@$`40```!_'`0`<````<<<!`"\```".QP$`0P```+['
M`0`M`````L@!`#,````PR`$`'P```&3(`0`[````A,@!`$X```#`R`$`/0``
M``_)`0`E````3<D!`!\```!SR0$`%P```)/)`0`'````J\D!``<```"SR0$`
M!@```+O)`0`&````PLD!``\```#)R0$`#@```-G)`0`0````Z,D!``X```#Y
MR0$`%0````C*`0`/````'LH!``L````NR@$`$P```#K*`0`(````3LH!``@`
M``!7R@$`%0```&#*`0`/````=LH!`$4```"&R@$`%````,S*`0`)````X<H!
M``@```#KR@$`'P```/3*`0`J````%,L!`#H````_RP$`#@```'K+`0`?````
MB<L!`"````"IRP$`,````,K+`0`;````^\L!`!X````7S`$`(0```#;,`0!.
M````6,P!`"<```"GS`$`)@```,_,`0`8````]LP!`!<````/S0$`(````"?-
M`0`J````2,T!`!@```!SS0$`%@```(S-`0`O````H\T!`"0```#3S0$`"0``
M`/C-`0`9`````LX!``L````<S@$`%````"C.`0`#````/<X!``4```!!S@$`
M!P```$?.`0`.````3\X!`!````!>S@$`#0```&_.`0`8````?<X!`!````"6
MS@$`$0```*?.`0`/````N<X!``0```#)S@$`!P```,[.`0`:````ULX!`!L`
M``#QS@$`"`````W/`0`1````%L\!`!0````HSP$`#@```#W/`0`G````3,\!
M``@```!TSP$`!P```'W/`0`)````A<\!``@```"/SP$`"0```)C/`0`0````
MHL\!``T```"SSP$`$````,'/`0`*````TL\!``<```#=SP$`"P```.7/`0`&
M````\<\!`!@```#XSP$`#@```!'0`0`&````(-`!`"@````GT`$`$````%#0
M`0";````8=`!`!L```#]T`$`"P```!G1`0`'````)=$!``\````MT0$`"```
M`#W1`0`*````1M$!``4```!1T0$`"````%?1`0`#````8-$!``8```!DT0$`
M!P```&O1`0`6````<]$!`!@```"*T0$`$````*/1`0`2````M-$!`!T```#'
MT0$``@```.71`0`$````Z-$!`!0```#MT0$`"@````+2`0`/````#=(!``4`
M```=T@$`(P```"/2`0`(````1](!``8```!0T@$`&P```%?2`0`/````<](!
M``<```"#T@$`"````(O2`0`%````E-(!``D```":T@$`#P```*32`0`=````
MM-(!`!$```#2T@$``@```.32`0`&````Y](!``\```#NT@$`$@```/[2`0`0
M````$=,!``8````BTP$`$P```"G3`0`+````/=,!``<```!)TP$`!0```%'3
M`0`8````5],!`#````!PTP$`30```*'3`0`K````[],!`"T````;U`$`!@``
M`$G4`0`)````4-0!``0```!:U`$`"0```%_4`0`)````:=0!`!<```!SU`$`
M#````(O4`0`&````F-0!``T```"?U`$`!P```*W4`0`$````M=0!`$$```"Z
MU`$`2````/S4`0!!````1=4!`"<```"'U0$`!0```*_5`0`-````M=4!``<`
M``##U0$`"````,O5`0`)````U-4!`!L```#>U0$`&0```/K5`0`5````%-8!
M``8````JU@$`!0```#'6`0`0````-]8!``@```!(U@$`"@```%'6`0`C````
M7-8!``0```"`U@$`!P```(76`0`G````C=8!``8```"UU@$`"0```+S6`0`4
M````QM8!`!(```#;U@$`$P```.[6`0`3`````M<!`!L````6UP$`'@```#+7
M`0`7````4=<!``@```!IUP$`"0```'+7`0`%````?-<!`$<```""UP$`-```
M`,K7`0!!````_]<!`#(```!!V`$`20```'38`0`[````OM@!`"P```#ZV`$`
M/@```"?9`0`O````9MD!`#T```"6V0$`,0```-39`0`0````!MH!`!$````7
MV@$`"P```"G:`0`R````-=H!`"$```!HV@$`'P```(K:`0`>````JMH!``<`
M``#)V@$`"0```-':`0`*````V]H!``<```#FV@$`*0```.[:`0`L````&-L!
M`#T```!%VP$`!````(/;`0`M````B-L!``P```"VVP$`(P```,/;`0`V````
MY]L!`!8````>W`$`%0```#7<`0`(````2]P!``L```!4W`$`#````&#<`0`0
M````;=P!`!<```!^W`$`10```);<`0!\````W-P!`&<```!9W0$`#0```,'=
M`0`0````S]T!`!$```#@W0$`%````/+=`0`5````!]X!`!<````=W@$`"```
M`#7>`0`H````/MX!`!$```!GW@$`*0```'G>`0`3````H]X!`!(```"WW@$`
M%0```,K>`0`N````X-X!`"T````/WP$`EP```#W?`0`1````U=\!``4```#G
MWP$`%0```.W?`0`)`````^`!``L````-X`$`"P```!G@`0`E````)>`!`!@`
M``!+X`$`#P```&3@`0`.````=.`!`!0```"#X`$`&0```)C@`0`M````LN`!
M`"X```#@X`$`*@````_A`0`J````.N$!`"8```!EX0$`*````(SA`0`>````
MM>$!`$$```#4X0$`%0```!;B`0`4````+.(!`!<```!!X@$`%@```%GB`0`1
M````<.(!`!<```""X@$`%@```)KB`0`4````L>(!`!0```#&X@$`.P```-OB
M`0`9````%^,!`!H````QXP$`.@```$SC`0`3````A^,!``8```";XP$`$```
M`*+C`0`,````L^,!`"T```#`XP$`%````.[C`0`G`````^0!`!4````KY`$`
M%0```$'D`0`@````5^0!`!X```!XY`$`)````)?D`0`2````O.0!`!P```#/
MY`$`(P```.SD`0`<````$.4!`"<````MY0$`$P```%7E`0`0````:>4!`!(`
M``!ZY0$`(````(WE`0`F````KN4!`"````#5Y0$`&0```/;E`0`=````$.8!
M`!0````NY@$`'````$/F`0`<````8.8!`"$```!]Y@$`&0```)_F`0`*````
MN>8!`!(```#$Y@$`&P```-?F`0`$````\^8!``<```#XY@$`"P````#G`0`2
M````#.<!``8````?YP$`!@```";G`0`'````+><!``8````UYP$`!P```#SG
M`0`%````1.<!``4```!*YP$`%0```%#G`0`&````9N<!``8```!MYP$`!0``
M`'3G`0`%````>N<!``H```"`YP$`$0```(OG`0`*````G><!`!8```"HYP$`
M%````+_G`0`*````U.<!`!<```#?YP$`!0```/?G`0`U````_><!`!(````S
MZ`$`$0```$;H`0`:````6.@!``\```!SZ`$`#0```(/H`0`0````D>@!`#0`
M``"BZ`$`!0```-?H`0`(````W>@!`"<```#FZ`$`$P````[I`0`0````(ND!
M``8````SZ0$`"@```#KI`0!)````1>D!``T```"/Z0$`!@```)WI`0`B````
MI.D!`!````#'Z0$`$P```-CI`0`-````[.D!`!L```#ZZ0$`$````!;J`0`5
M````)^H!`!$````]Z@$`&@```$_J`0`4````:NH!``8```!_Z@$`!0```(;J
M`0`,````C.H!`"8```"9Z@$`!P```,#J`0`)````R.H!`!(```#2Z@$`%P``
M`.7J`0`'````_>H!``4````%ZP$`!P````OK`0`6````$^L!``T````JZP$`
M#P```#CK`0`-````2.L!`!8```!6ZP$`&````&WK`0`/````ANL!`!$```"6
MZP$`#````*CK`0`8````M>L!``P```#.ZP$`!P```-OK`0`4````X^L!`$(`
M``#XZP$`"````#OL`0`,````1.P!``4```!1[`$`+0```%?L`0`5````A>P!
M`!4```";[`$`#0```+'L`0`,````O^P!``D```#,[`$`!P```-;L`0`*````
MWNP!``D```#I[`$`#@```//L`0`0`````NT!`"D````3[0$`)0```#WM`0`J
M````8^T!``H```".[0$`"````)GM`0`*````HNT!``P```"M[0$`#0```+KM
M`0`)````R.T!``X```#2[0$`-0```.'M`0`%````%^X!``X````=[@$`&@``
M`"SN`0!=````1^X!`!H```"E[@$`#@```,#N`0`$````S^X!``0```#4[@$`
M&@```-GN`0`:````].X!`!H````/[P$`"@```"KO`0`"````->\!``0````X
M[P$`)0```#WO`0`#````8^\!``4```!G[P$`*0```&WO`0`*````E^\!``4`
M``"B[P$`!@```*CO`0`+````K^\!`!$```"[[P$`!@```,WO`0`'````U.\!
M``@```#<[P$`!````.7O`0`%````ZN\!`&L```#P[P$`"@```%SP`0`-````
M9_`!`!T```!U\`$`!0```)/P`0`&````F?`!`"D```"@\`$`-@```,KP`0`.
M`````?$!``D````0\0$`"P```!KQ`0`3````)O$!``H````Z\0$`"````$7Q
M`0`7````3O$!`#@```!F\0$`'P```)_Q`0`>````O_$!`!H```#>\0$`(P``
M`/GQ`0`/````'?(!`!@````M\@$`!````$;R`0`'````2_(!``@```!3\@$`
M"````%SR`0`-````9?(!`!$```!S\@$`#P```(7R`0`'````E?(!`&$```"=
M\@$`$0```/_R`0`/````$?,!``\````A\P$`&P```#'S`0!1````3?,!`!P`
M``"?\P$`!@```+SS`0`?````P_,!`"8```#C\P$`!P````KT`0`&````$O0!
M`"`````9]`$`"````#KT`0`)````0_0!`"$```!-]`$`(````&_T`0`\````
MD/0!``@```#-]`$`"@```-;T`0`L````X?0!`"<````.]0$`5````#;U`0`;
M````B_4!`!\```"G]0$`&@```,?U`0`#````XO4!``P```#F]0$`#@```//U
M`0`(`````O8!`!D````+]@$`#0```"7V`0`C````,_8!``8```!7]@$`%@``
M`%[V`0`&````=?8!``@```!\]@$`"0```(7V`0`,````C_8!``H```"<]@$`
M$````*?V`0!!````N/8!`"$```#Z]@$`"0```!SW`0`:````)O<!`!<```!!
M]P$`&````%GW`0`)````<O<!`!4```!\]P$`&````)+W`0`6````J_<!`!8`
M``#"]P$`%0```-GW`0`8````[_<!`!8````(^`$`%@```!_X`0`*````-O@!
M`!\```!!^`$`'P```&'X`0`0````@?@!`%<```"2^`$`$@```.KX`0`)````
M_?@!``P````'^0$`"@```!3Y`0`,````'_D!``D````L^0$`&0```#;Y`0`'
M````4/D!`!<```!8^0$`!@```'#Y`0`1````=_D!``<```")^0$`!0```)'Y
M`0`%````E_D!`!\```"=^0$`!P```+WY`0`3````Q?D!`!0```#9^0$`(@``
M`.[Y`0`B````$?H!`!T````T^@$`'````%+Z`0`B````;_H!`"8```"2^@$`
M'P```+GZ`0`#````V?H!``4```#=^@$`#P```./Z`0`/````\_H!``8````#
M^P$`$P````K[`0`*````'OL!`"(````I^P$`#0```$S[`0`0````6OL!`",`
M``!K^P$`'0```(_[`0`6````K?L!``@```#$^P$`#@```,W[`0`)````W/L!
M`!````#F^P$`$P```/?[`0`*````"_P!``D````6_`$`!0```"#\`0`%````
M)OP!``<````L_`$`!0```#3\`0`$````.OP!``(````__`$`*@```$+\`0`>
M````;?P!`#<```",_`$`.P```,3\`0`9`````/T!`"8````:_0$`1@```$']
M`0`,````B/T!`#0```"5_0$`.P```,K]`0!$````!OX!`$0```!+_@$`3```
M`)#^`0`>````W?X!``\```#\_@$`(`````S_`0`?````+?\!`!P```!-_P$`
M'P```&K_`0`?````BO\!`"````"J_P$`(````,O_`0`@````[/\!``P````-
M``(`00```!H``@!!````7``"`$4```">``(`1@```.0``@!#````*P$"`$``
M``!O`0(`>0```+`!`@`5````*@("`!````!``@(`"0```%$"`@`C````6P("
M``<```!_`@(`%````(<"`@`Z````G`("`#@```#7`@(`'@```!`#`@`D````
M+P,"``L```!4`P(`4P```&`#`@!*````M`,"``<```#_`P(`%P````<$`@`5
M````'P0"``\````U!`(`$````$4$`@`8````5@0"``<```!O!`(`"@```'<$
M`@`(````@@0"`!,```"+!`(`$````)\$`@`.````L`0"`!(```"_!`(`!0``
M`-($`@`D````V`0"``D```#]!`(`!@````<%`@`4````#@4"`!(````C!0(`
M'@```#8%`@`/````504"`$@```!E!0(`!P```*X%`@`&````M@4"`!(```"]
M!0(`'@```-`%`@`%````[P4"``<```#U!0(`#P```/T%`@`'````#08"`#4`
M```5!@(`$@```$L&`@`E````7@8"``0```"$!@(`G@```(D&`@`[````*`<"
M``X```!D!P(`*````','`@`:````G`<"`(<```"W!P(`&@```#\(`@!%````
M6@@"`"<```"@"`(`$0```,@(`@`(````V@@"``X```#C"`(`#@```/((`@`,
M`````0D"`!,````."0(`#````"()`@`@````+PD"`!P```!0"0(`!````&T)
M`@`0````<@D"``X```"#"0(`&P```)()`@`J````K@D"`!4```#9"0(`$0``
M`.\)`@`6`````0H"`!$````8"@(`'P```"H*`@`*````2@H"``P```!5"@(`
M$P```&(*`@`1````=@H"`!<```"("@(`$````*`*`@`<````L0H"``X```#.
M"@(`%0```-T*`@`B````\PH"``T````6"P(`!@```"0+`@`(````*PL"``4`
M```T"P(`(````#H+`@`&````6PL"`!(```!B"P(`"````'4+`@`3````?@L"
M``H```"2"P(`*````)T+`@`5````Q@L"`$$```#<"P(`&P```!X,`@`+````
M.@P"``P```!&#`(`)0```%,,`@`%````>0P"`!8```!_#`(``P```)8,`@`1
M````F@P"``4```"L#`(`"@```+(,`@`E````O0P"`#D```#C#`(`"@```!T-
M`@`F````*`T"`!````!/#0(`$````&`-`@`+````<0T"`!T```!]#0(`%```
M`)L-`@`$````L`T"``@```"U#0(`"0```+X-`@`(````R`T"``L```#1#0(`
M'@```-T-`@`(````_`T"``<````%#@(`!P````T.`@`2````%0X"`"H````H
M#@(`-P```%,.`@`;````BPX"`"L```"G#@(`(P```-,.`@!!````]PX"`!L`
M```Y#P(`)P```%4/`@`D````?0\"`"T```"B#P(`3````-`/`@`H````'1`"
M``<```!&$`(`"````$X0`@`)````5Q`"``@```!A$`(`%0```&H0`@`4````
M@!`"`"P```"5$`(`+P```,(0`@`B````\A`"`#<````5$0(`/P```$T1`@`'
M````C1$"`!H```"5$0(`"0```+`1`@`,````NA$"`"X```#'$0(`"````/81
M`@`3````_Q$"`!(````3$@(`'@```"82`@`-````11("``L```!3$@(`&```
M`%\2`@`)````>!("`!(```""$@(`$0```)42`@`:````IQ("`!P```#"$@(`
M.0```-\2`@`+````&1,"`!`````E$P(`!0```#83`@`(````/!,"`!\```!%
M$P(`#P```&43`@`%````=1,"`!H```![$P(`#P```)83`@`&````IA,"``\`
M``"M$P(`$0```+T3`@`(````SQ,"``X```#8$P(`#@```.<3`@`3````]A,"
M``4````*%`(`$````!`4`@`>````(10"``T```!`%`(`(````$X4`@`\````
M;Q0"`"(```"L%`(`4@```,\4`@`4````(A4"`"(````W%0(`"@```%H5`@`G
M````914"`!L```"-%0(`!0```*D5`@`7````KQ4"``D```#'%0(`#0```-$5
M`@`2````WQ4"`"H```#R%0(`!@```!T6`@`-````)!8"`!\````R%@(`#@``
M`%(6`@`0````818"`!0```!R%@(`"@```(<6`@`]````DA8"``D```#0%@(`
M(````-H6`@`0````^Q8"`!0````,%P(`E@```"$7`@!`````N!<"`"0```#Y
M%P(`)@```!X8`@!"````11@"`$,```"(&`(`/````,P8`@`/````"1D"``<`
M```9&0(`$@```"$9`@`2````-!D"`",```!'&0(`&0```&L9`@`*````A1D"
M`!,```"0&0(`&P```*09`@`'````P!D"`!<```#(&0(`*````.`9`@`&````
M"1H"``<````0&@(`$````!@:`@`5````*1H"`!<````_&@(`!P```%<:`@`'
M````7QH"``D```!G&@(`%````'$:`@`2````AAH"`!,```"9&@(`$P```*T:
M`@`&````P1H"``4```#(&@(`,0```,X:`@`H`````!L"`"4````I&P(`"```
M`$\;`@`/````6!L"``8```!H&P(`&@```&\;`@`9````BAL"`!H```"D&P(`
M*P```+\;`@`)````ZQL"``P```#U&P(`)P````(<`@`#````*AP"`!P````N
M'`(`!0```$L<`@`-````41P"``,```!?'`(`#````&,<`@`3````<!P"``L`
M``"$'`(`%P```)`<`@`8````J!P"`!,```#!'`(`!0```-4<`@`*````VQP"
M`!8```#F'`(`%0```/T<`@`.````$QT"``<````B'0(`#````"H=`@`*````
M-QT"`!````!"'0(`70```%,=`@`F````L1T"`#P```#8'0(`(P```!4>`@`2
M````.1X"``<```!,'@(`!@```%0>`@`+````6QX"`!8```!G'@(`&@```'X>
M`@`?````F1X"``L```"Y'@(`%````,4>`@`4````VAX"`!P```#O'@(`'P``
M``P?`@`6````+!\"`!X```!#'P(`$````&(?`@`M````<Q\"`#````"A'P(`
M,0```-(?`@`5````!"`"``T````:(`(`,````"@@`@`W````62`"`&X```"1
M(`(`-0`````A`@`D````-B$"`"````!;(0(`)0```'PA`@`A````HB$"`"D`
M``#$(0(`-0```.XA`@`K````)"("`",```!0(@(`'P```'0B`@`C````E"("
M`%,```"X(@(`0`````PC`@`D````32,"`"4```!R(P(`'P```)@C`@`I````
MN","`!L```#B(P(`"@```/XC`@`'````"20"``@````1)`(`"@```!HD`@`3
M````)20"``\````Y)`(`+0```$DD`@`8````=R0"`!P```"0)`(`"````*TD
M`@`*````MB0"`%(```#!)`(`10```!0E`@!`````6B4"`'@```";)0(`#0``
M`!0F`@`P````(B8"`#$```!3)@(`"@```(4F`@`5````D"8"``<```"F)@(`
M#0```*XF`@`Z````O"8"`!,```#W)@(`"@````LG`@`,````%B<"`!$````C
M)P(`#@```#4G`@!$````1"<"`"T```"))P(`)P```+<G`@`0````WR<"`#(`
M``#P)P(`(P```",H`@`S````1R@"`"H```![*`(`,@```*8H`@`K````V2@"
M``T````%*0(`"0```!,I`@`1````'2D"`!,````O*0(`&````$,I`@`'````
M7"D"`#<```!D*0(`#````)PI`@`$````J2D"``4```"N*0(`$@```+0I`@`(
M````QRD"``8```#0*0(`%````-<I`@`*````["D"``D```#W*0(`!0````$J
M`@`1````!RH"`!$````9*@(`&@```"LJ`@`<````1BH"`!4```!C*@(`(0``
M`'DJ`@`-````FRH"``<```"I*@(`$@```+$J`@`8````Q"H"`"D```#=*@(`
M"0````<K`@`(````$2L"``D````:*P(`&P```"0K`@`H````0"L"``X```!I
M*P(`(0```'@K`@`T````FBL"``D```#/*P(`"0```-DK`@`2````XRL"``8`
M``#V*P(`!````/TK`@`B`````BP"`$D````E+`(`#0```&\L`@`/````?2P"
M``P```"-+`(`"````)HL`@`)````HRP"``@```"M+`(`"0```+8L`@`-````
MP"P"`!(```#.+`(`!@```.$L`@`9````Z"P"`!4````"+0(`!P```!@M`@`0
M````("T"`"`````Q+0(`#````%(M`@`#````7RT"`"4```!C+0(`!@```(DM
M`@`&````D"T"`'L```"7+0(`"0```!,N`@`%````'2X"`"P````C+@(`.0``
M`%`N`@`D````BBX"`$8```"O+@(`*0```/8N`@`C````("\"`#````!$+P(`
M+P```'4O`@`\````I2\"`%````#B+P(`.@```#,P`@`]````;C`"`"0```"L
M,`(`(````-$P`@`%````\C`"``<```#X,`(`"``````Q`@`)````"3$"``<`
M```3,0(`"````!LQ`@`2````)#$"``H````W,0(`"0```$(Q`@`+````3#$"
M``L```!8,0(`!P```&0Q`@`'````;#$"``@```!T,0(`%````'TQ`@`+````
MDC$"``8```">,0(`!0```*4Q`@`D````JS$"``8```#0,0(`+0```-<Q`@`8
M````!3("``@````>,@(`%````"<R`@`)````/#("`!,```!&,@(``P```%HR
M`@`+````7C("`"$```!J,@(`!0```(PR`@`4````DC("``4```"G,@(`%```
M`*TR`@`&````PC("`!H```#),@(`"@```.0R`@`<````[S("``@````,,P(`
M!@```!4S`@`2````'#,"`"0````O,P(`"P```%0S`@`-````8#,"`"H```!N
M,P(`(0```)DS`@`<````NS,"``4```#8,P(`"@```-XS`@`3````Z3,"`!@`
M``#],P(``P```!8T`@`3````&C0"``D````N-`(`)````#@T`@`H````730"
M`#,```"&-`(`*````+HT`@`U````XS0"`"\````9-0(`0P```$DU`@`I````
MC34"`#H```"W-0(`/0```/(U`@`_````,#8"`"\```!P-@(`9````*`V`@`6
M````!3<"`%P````<-P(`.@```'DW`@`A````M#<"`$D```#6-P(`:P```"`X
M`@`J````C#@"`$$```"W.`(`+@```/DX`@`Q````*#D"`#<```!:.0(`+0``
M`)(Y`@`=````P#D"`$(```#>.0(`TP$``"$Z`@`B````]3L"`#@````8/`(`
M%P```%$\`@!,````:3P"`(````"V/`(`-P```#<]`@`L````;ST"`#\```"<
M/0(`7@```-P]`@!*````.SX"`"H```"&/@(`(@```+$^`@`4````U#X"`!\`
M``#I/@(`(0````D_`@`@````*S\"`"L```!,/P(`)````'@_`@`C````G3\"
M`#X```#!/P(`(@````!``@`5````(T`"`#<````Y0`(`)@```'%``@`L````
MF$`"`"L```#%0`(`+0```/%``@`:````'T$"`"T````Z00(`X````&A!`@!I
M````24("`#8```"S0@(`20```.I"`@`W````-$,"`"T```!L0P(`0````)I#
M`@!P````VT,"`%(```!,1`(`9@```)]$`@`G````!D4"`#P````N10(`20``
M`&M%`@`Q````M44"`"<```#G10(`-0````]&`@`W````148"`"T```!]1@(`
M-````*M&`@!K````X$8"`',```!,1P(`/P```,!'`@!:`````$@"`%D```!;
M2`(`00```+5(`@`P````]T@"`!\````H20(`*@```$A)`@`J````<TD"`#<`
M``">20(`*0```-9)`@`I`````$H"`"\````J2@(`>0```%I*`@!N````U$H"
M`'<```!#2P(`Q````+M+`@`6````@$P"`"<```"73`(`.````+],`@`O````
M^$P"`$T````H30(`*@```'9-`@!C````H4T"`"H````%3@(`(P```#!.`@`+
M````5$X"`*@```!@3@(`2@````E/`@`I````5$\"`$(```!^3P(`.````,%/
M`@`J````^D\"`",````E4`(`0````$E0`@`]````BE`"``8```#(4`(`"P``
M`,]0`@`$````VU`"``H```#@4`(`#P```.M0`@`1````^U`"``L````-40(`
M!@```!E1`@`1````(%$"``0````R40(`9@```#=1`@`#````GE$"`!0```"B
M40(`!````+=1`@`'````O%$"``8```#$40(`!0```,M1`@`(````T5$"`!4`
M``#:40(`#````/!1`@`1````_5$"`!$````/4@(``P```"%2`@`%````)5("
M``<````K4@(`$@```#-2`@`,````1E("`!0```!34@(`!@```&A2`@`5````
M;U("``T```"%4@(``P```)-2`@`N````EU("``0```#&4@(`!@```,M2`@`'
M````TE("`"4```#:4@(`1P````!3`@`X````2%,"`#D```"!4P(`&````+M3
M`@`G````U%,"`"H```#\4P(`)@```"=4`@`<````3E0"`"$```!K5`(`*```
M`(U4`@`C````ME0"`"````#:5`(`)````/M4`@`F````(%4"`#P```!'50(`
M(@```(15`@`V````IU4"`!T```#>50(`,P```/Q5`@`Y````,%8"`"8```!J
M5@(`*@```)%6`@`H````O%8"`",```#E5@(`*`````E7`@`R````,E<"`"L`
M``!E5P(`,````)%7`@`F````PE<"`"0```#I5P(`)0````Y8`@`N````-%@"
M`"````!C6`(`)P```(18`@`W````K%@"`#H```#D6`(`'````!]9`@`F````
M/%D"`#T```!C60(`)P```*%9`@`K````R5D"`"@```#U60(`*@```!Y:`@`D
M````25H"`!X```!N6@(`*P```(U:`@`H````N5H"`#<```#B6@(`+@```!I;
M`@`Y````25L"``D```"#6P(`$````(U;`@`8````GEL"`#(```"W6P(`)0``
M`.I;`@`-````$%P"``\````>7`(`%@```"Y<`@`*````15P"``X```!07`(`
M*@```%]<`@`(````BEP"``L```"37`(`+P```)]<`@`Q````SUP"`"D````!
M70(`(@```"M=`@`D````3ET"``H```!S70(`[````'Y=`@`,````:UX"`"(`
M``!X7@(`%@```)M>`@`*````LEX"``T```"]7@(`$@```,M>`@`7````WEX"
M`"H```#V7@(`!@```"%?`@!2````*%\"`!H```![7P(`&@```)9?`@`'````
ML5\"``\```"Y7P(`"````,E?`@!"````TE\"``<````58`(`+0```!U@`@`:
M````2V`"`!,```!F8`(`%````'I@`@`T````CV`"`"````#$8`(`!P```.5@
M`@`D````[6`"``@````280(`"0```!MA`@`7````)6$"``H````]80(`'```
M`$AA`@`(````96$"`"X```!N80(`!P```)UA`@`C````I6$"`"<```#)80(`
M!P```/%A`@`5````^6$"``<````/8@(`"````!=B`@`)````(&("`$`````J
M8@(`$P```&MB`@`'````?V("``P```"'8@(`$P```)1B`@`/````J&("``D`
M``"X8@(`"````,)B`@`'````RV("`!,```#38@(`"````.=B`@`&````\&("
M``P```#W8@(`&@````1C`@`+````'V,"`!L````K8P(`&@```$=C`@`4````
M8F,"``L```!W8P(`#0```(-C`@`@````D6,"``4```"R8P(`-0```+AC`@`,
M````[F,"``\```#[8P(`"P````MD`@`#````%V0"`!0````;9`(`(@```#!D
M`@`+````4V0"``,```!?9`(`"````&-D`@`/````;&0"``P```!\9`(`"@``
M`(ED`@`0````E&0"``X```"E9`(`$@```+1D`@`3````QV0"`!$```#;9`(`
M.````.UD`@`A````)F4"`!\```!(90(`(0```&AE`@`)````BF4"`#0```"4
M90(`!P```,EE`@`7````T64"`$````#I90(`$P```"IF`@`3````/F8"``@`
M``!29@(`!````%MF`@`&````8&8"``\```!G9@(`'0```'=F`@`'````E68"
M``@```"=9@(`"0```*9F`@`&````L&8"``8```"W9@(`%0```+YF`@`2````
MU&8"`!````#G9@(`%````/AF`@`9````#6<"`!P````G9P(`%0```$1G`@!"
M````6F<"`#,```"=9P(`*0```-%G`@`%````^V<"`!L````!:`(`'0```!UH
M`@`C````.V@"`"<```!?:`(`$@```(=H`@`"````FF@"``0```"=:`(`#P``
M`*)H`@`*````LF@"``4```"]:`(``@```,-H`@`-````QF@"`$@```#4:`(`
M-P```!UI`@!!````56D"`!8```"7:0(`-P```*YI`@`L````YFD"`%H````3
M:@(`,0```&YJ`@`O````H&H"`#0```#0:@(`%P````5K`@"#````'6L"`"4`
M``"A:P(`.@```,=K`@`B`````FP"`#8````E;`(`.````%QL`@`\````E6P"
M`"L```#2;`(`+0```/YL`@`S````+&T"`#,```!@;0(`+````)1M`@`L````
MP6T"`"H```#N;0(`+@```!EN`@`N````2&X"`#(```!W;@(`,P```*IN`@`S
M````WFX"`#(````2;P(`%@```$5O`@`-````7&\"``X```!J;P(`A@```'EO
M`@`)`````'`"`*T````*<`(`<0```+AP`@"%````*G$"`"L```"P<0(`7```
M`-QQ`@`4````.7("`"H```!.<@(`*````'ER`@`6````HG("`!````"Y<@(`
M)````,IR`@`B````[W("`$(````2<P(`(````%5S`@`>````=G,"`%P```"5
M<P(`&@```/)S`@`3````#70"``H````A=`(`!0```"QT`@`&````,G0"``@`
M```Y=`(`!0```$)T`@`6````2'0"`!4```!?=`(`%P```'5T`@`B````C70"
M`!````"P=`(`"P```,%T`@`/````S70"``D```#==`(`!````.=T`@`*````
M['0"``P```#W=`(`"0````1U`@`.````#G4"``<````==0(`!@```"5U`@`9
M````+'4"`!(```!&=0(`!P```%EU`@`/````874"``8```!Q=0(`%0```'AU
M`@`-````CG4"``<```"<=0(`"0```*1U`@`,````KG4"`!0```"[=0(`%P``
M`-!U`@`'````Z'4"``P```#P=0(`&````/UU`@`)````%G8"``L````@=@(`
M&````"QV`@`&````178"``4```!,=@(`)P```%)V`@`;````>G8"``H```"6
M=@(`&0```*%V`@`6````NW8"``P```#2=@(`#0```-]V`@`-````[78"``T`
M``#[=@(`)`````EW`@`9````+G<"``D```!(=P(`%0```%)W`@`(````:'<"
M``<```!Q=P(`%P```'EW`@`'````D7<"``(```"9=P(``@```)QW`@`?````
MGW<"``X```"_=P(`"````,YW`@`7````UW<"`!D```#O=P(`!P````EX`@`K
M````$7@"``(````]>`(`!@```$!X`@`+````1W@"``<```!3>`(`#P```%MX
M`@`9````:W@"``4```"%>`(`"@```(MX`@`3````EG@"``<```"J>`(`&0``
M`+)X`@`*````S'@"`!<```#7>`(`$P```.]X`@`2`````WD"``(````6>0(`
M!P```!EY`@`1````(7D"``8````S>0(`#@```#IY`@`)````27D"`!<```!3
M>0(`,````&MY`@`)````G'D"``H```"F>0(`%````+%Y`@`%````QGD"``(`
M``#,>0(`"P```,]Y`@`!`````````'@&``"+!@``````````````````S0,`
M`','``!K!P``[`0```````#J`0``?00``$P$```9`0``R@$``#D(````````
M[P8``#H$``"A`@``H@0``#,```````````````0&``#^`0``^@,``+X$``!=
M`0```````+P$``";!@``^00```````#J!```T`$``.@&``#=!@``%0$``*0`
M```(````N0```*0"``#S!`````````````"."```F0$```````#!````%@$`
M`(`#```Q!P````````````#$`P``0P0```X&``#0`````````+$"``!L"```
MR00``&L&``!B`0``+`(``%4&``"/"```-0@```````#<`P``P@0```````!0
M"```B@$``````````````````'4"``#D````S@4``%H%```H!```/0,``'T&
M``!6!0``"`,``$\'``#&`P``L@4``&D!```B!````````+`"``!A"```````
M```````]!```W@,``"8%``!X!````````&,%``"#`@``0P(`````````````
M)@```%P"``#;!@``'`(````````_!```"0@``.P'````````0P@``%(!``#9
M!0``?`,``/8%```-!@````8``,4%```S"```Y`,``,T"```$`0```````*T%
M```Q!0``=P(``.`&``"4`P``=0@``#H!````````Y`$``.\!```O````E@4`
M`%<"``!1!0``$@@``&,$```&!```,`@``$@%``#%!```````````````````
M1@4``(T#``!,!@``@0(``'<(`````````@8`````````````?`(``)$&````
M````FP4``&4#```1!P``/@<``)X```!O!P`````````````D`P```````*,%
M``"\!@```````"0&``#G!@````0``````````````````(\`````````K`$`
M`#@%``#]!P``L@$``)P&``!Y!@```````/(!``"+`@```````$P"```$`@``
MB@4``"D"```1!```;00``,(#```R`P``$@,```````!]!0``.04``(`"``"S
M!@````````````"%!0````````````#`!```7@0``.T#``#\`P``P@$``/D&
M`````````````!T(``"'`0``%`<``"$````<````;`4``.`'``!K`P``9P8`
M```````)!P``=P4``+\"```[`P``%P0``&`!```2!0``0@8``)L#``!`"```
M;P4```````"@!0``M0```)8'```$````?@(``,\%````!P``U@$`````````
M````&@0`````````````RP<``)H!``!:!P``N````$((````````^@(`````
M``"(!P``=`8``#4'````````S`<``"L%````````#@$``,@```#^`@``)@(`
M````````````S08``+L#`````````````!D'``!;`@``A@@``%0%```W`P``
MR`(``%T(````````*0$```````!^`P``D@0``!D(````````R0```+X````6
M!```'@@``(@%``!E`0```````!L%``#%````Y0,``/P'```L!0```````$8'
M```S`@``?@@````````X````M@,``'\"```G!@```````%8&````````2P(`
M`*L&``#5!@``4@8``.,!```P````Z0<``````````````````,<%```Z!0``
M`````)\'````````*@0``-0$``!B!@``S0<```````````````````````"'
M!@``?0$``,T$``!;!````````.8'``"H`P```P$``'\!``!W````T@(``&D"
M``"M````HP(``$D(```2!@```````(@(``!P!0``!0(``#P````3`@``+08`
M`-D#``#A`P````````<&``#Z!@``-0,``(4#```S!P``C@(```8&````````
M``````````"$"````````/<$``!%!0``J04``/8&```Q````0@$``.X'``"T
M`0``;04``%H(``##````I`0``,<`````````-`0``"0(```\!0``>`<``,$%
M````````N@````````")`@```````',&``!<`P``?@4```````!3!```C`0`
M`"(%``"[`@``EP```$0$``!^!```^04``&T#``!9`0``)08``"4#```5````
MN`<``,`"```'!0``GP4``+$#```"````4`$``,@&``!B!0``60(``+D%``#U
M!@``=@`````````K!```2@$``$4#````````%0@``,@!``!N`0``4P4`````
M```Z````DP```&D'``"-`0``)@8``%\(``#!`@```````-(````[!0``````
M``````"<````\P,``)`(``!O````60@``)H&``!\````XP4```````#,`P``
M(0(````````"!```ZP8``-(&```"`P``O@8```````#[!0``@00`````````
M````'`$```4%```,"```2P8``.0%```)`P``AP,``$,`````````&P``````
M`````````````&L!````````F@(``-4#`````````````,\$````````F`$`
M`*4#```:`P``4P```/`!``!8!0```````#\&```R````S@,``)X&``!;````
MX`,```````"G`@``+P<``$`!````````S@$`````````````B`,``%@````A
M`0``IP$`````````````A@```!4#``````````````````"3`0```````(,$
M````````IP8```````#M````#0,``/D'`````````````&P#``")!0``````
M`)@$````````L0```.8!``"1`P``O`,`````````````W@0``.8`````````
M`````#L$``"0`P``4@```&8```!D`@``D`$``(P"``!\"```D0<``(<%``#&
M!P```````&@(````````.0,``+\!``"T!```7`<``.8"```<"```X@8`````
M```U!@``C@<```````"^`0``F0,```$'```=!P``;`8``&((````````V0<`
M`-$$``!.!0``T`(```8```!@!P``-0$``+<'``#3`P```````.X$``!H!0``
M&@8``#((```6!0``;@`````````8!0``H`0``'0'``#8!0```````$8&``!<
M!```ZP4```````#F`P``K@$``(T&``!E!```LP$``'<$``!K!```Q@```&@'
M```;!P``S@8``*<$```_`P```````!`(`````````````-H&``"_!```.P``
M`/8"```%"```2P0````````D!```&@@``!0"``#%!@``N0$``&`&```1`@``
M7`8``*0&``#D`@``_@4``+@%``#8````K`(``'@%``!,"```*0@```H(``#7
M!P``A`0```````"@`@``,@(``/0'``!T`@``O`(``'8%````````A0<``'`'
M``"*````3`<``+D&``"A`````````'(%````````V`$````````Q"```````
M``````!;`P```````)4%````````J`0``"(&``!9!```D0$`````````````
ME0```!\'````````5@@``.P"`````````````&\&``"!"````````%D````+
M`0``/`,``#0#``#>!0``6`0``'P&```[`@``?@8``$\`````````C0```-<"
M``!.!@``'P@```````"*!```9`8``+,%```,````Z@(``+D$````````U00`
M`*X"``!P!@``@@0```````"R!P```````%$&``"B!0``<0```"`(``#W!P``
M```````````L````/`0```````"'`@``%0(``)\$````````UP0``(P%````
M````7`$```````````````````````"@!P``_P4``)('````````WP$``&P!
M````````>P``````````"```O04``$X'``#B`@``WP8``%<````N`0``?0(`
M``("``"[`0``*`,``,T%````````5@```&H$``!T"```@`<``#0%``#?`@``
M<0$``+8"```=!```3@```!`!``"4````L`<```````#;!P``>````-@'``!>
M"```2P4``.L"``";````904``/D"`````````````"L&``!)`0``[@,``'`$
M``!.`P``3P@```<(``!E!@``T@0``+T````/`0``?@```.4!````````\P(`
M````````````40```$4'``"7`P```````.\%````````F@0`````````````
M/0(```````";`@``=@0``(P#``#&`0``DP<``````````````````,,$``"N
M`P``"04``"(!``"Q`0```````%($```P!`````````````!Q`P``%00``"@'
M``"P`P``````````````````-`(``-@&````````=@8`````````````\0,`
M`*0'```&`P```````-H````!`P```````,,%``!A`````````&$!```'`0``
MZ@<```````"R!@``C0<``"$'```H`0``P`<```````!G````#@```'L'````
M`````````&T"```T````9@<``!<#``!U!@````````````#1!@```````*D"
M``````````,``!T&``#_`0``A`(``#P'``!9!0```````/X```#U!0``HP``
M`&,&``#9`0``6@0```````"4`@``VP```(`````F!```&P8````````7!0``
M.`0``!D"``#Y`0``HP$``&8$``#E`@``V`,``*,$````````HP<``"H%````
M````E@(``"<(`````````````.0'````````L@(``/$!``#B````D@4`````
M```;`0``,0(``(X$``"!`0``%```````````````%`0``&\"```9`P``:@(`
M`$L(``"G`````````(P```#V````)`$````````9`````````'(!``#8!```
MB0,```````!F`0``&````"L```#_````Q`4``)$%````````_0(``#D````?
M!````````,,&```C"```6`$```````"5`@``]`0``,(&``#I!```A`4``-4%
M``!=!```_`0``&,#```V!0``60<``+\&``!P``````````````!/`@``````
M`#X(``!G!0``\04```````!J``````````$!``!+````=0$```````!J`P``
M=````'L(``!*`@``I@```$\$````````QP<``$4(``#S!@``J@``````````
M```````````````#`P````````````!%!````````%X"``!L!P``*0,``!P'
M```M`@``5P<``%4!``!(`P``O08``/`$````````K`<``/4#``"7`0``20``
M`!D&````````R`,``"H(```B"```.@<``,8&``#A!@``<P(``&T```!S"```
MVP4``/@#``#^!P``_P(````````4!@``%P<``.`!``"_````N@8```````"K
M!P``ZP,````````2````_P0``/<&``")!P```````/T$``"J`0``.P8`````
M``#W`P``\0<``"`$``!_"```-P```,4#``"J`@``"P8``",#``!-!```1@,`
M`-$'``"&`P``A@0``"4%````````@@@```````#=````[@4``+@!```8!@``
M^@<```````!O`0``:@8``)T#```E"```H`$``#T&``"4!@``LP<``'('``!V
M!P``D@$```````#;`P``@@8``&P$```^`0``1P,``#@'``!D"```9P(```\#
M``"!!@``'04``&X(``"!!P```````!8(```#!P``GP8```````!.`0``````
M`-$!``#A!```H00``",&````````6@,``.`"````````X@<```P%``"<!0``
M4P(``)<"``#X`@``*@<``)D``````````````*L%``!Z"`````````D&````
M````1`$``&\$````````P08``'D``````````04``-4```#A!P``$P@``%@&
M```:!0``_0,``'H"```H"````````$P`````````S@0``-T$```2`@``````
M`#H"````````C0(``$T(``!"!0``SP<``)@#``"3!0``2P<`````````````
MU@,```````"H`0``R@,```````!)`@``^0```#`!``#)`0``(P0``'H#```]
M!P```````&`(``"E!```CP8``/L!`````````````+L'```,`0``I0$``'D#
M````````-P(```````#L`P``$@$``&<'````````A0@``*<%``!"````````
M`-\`````````@0,``-,$```J`0``N0<`````````````1P<```````!Y`@``
MM0(```````"B!@``N@<``"`'``#U`@```````"\!```O!@``Q`0``#@&``#R
M`@``\`4``,\"`````````````(H(````````=P$`````````````=0,``*0%
M````````5`@```<#``#T`@``$P8`````````````$P0`````````````'0$`
M``L(````````R0<``.````!'`@```````/$&``#S````IP<`````````````
M`````)0!``````````````````#+`@``L00``'4'```8!P`````````````5
M!@``N0,````````#````B@<```0(``"W`P``BP4``+<$``!F"````````-\$
M``"%!```D0```.$!``"7!0``+P@```````#1````]@,``"@%``#4`@``2`<`
M`%,&````````=`,``,`%````````MP8```````!V"````@$``+H!```V"```
M@P<``)X%`````````````+<```#C`@``Z@````````#R!P``,`8``-(#````
M````"@,``!X!````````U@0``"D%```Z!@``@`@``#X$````````M`8``/L'
M``!U!0``(0,``,T```#5!P```````%0$``"+`0``N@4``-`&``#?`P``R`<`
M``````"3!```+@(```D"```4!0``J0,``(0#``#G!0``&`0```````"_`P``
M)P```)0$`````````````+,```#K`0``\@```$@"``!`!P``50```#@!``#7
M````P`8``*4%``!B!```^P```(L$``"C`P`````````````T!@``608``"4`
M````````=P,``'P%``!*`````````"0"``".``````````````!B````````
M`!<&`````````````'0$````````KP4```\"````````80(```````!J!0``
M3`4``.L'``"V````V@,``.8%````````,@$````````E!P``\@,``$H#``!"
M`@``5`8``)@"``!C````````````````````+`0```````!V`0``X`4`````
M``!K!0```````"H&````````````````````````KP```%H&``",`0``#@@`
M`#,!```K!P``Q`(``$\%``#H`````````*4````>!P````````````"#````
M`````)X'``"`!0``Q0<```````"<!```#@4``&0!``!V`@``>P,``#4%```-
M`````````.X"``#]!0````````````"Z!```'P$``&@#```.!P``60,``!('
M```M!P``8P(``$(#```#`@````````````#0!P``!0<```````#U````````
M`/\&````````@@<``"4"``"N!````````$<&``"_!P``[`$```````!B`P``
M`````%@#``!7!@``'@4``(<(``!!`P````````````"F!```]0<``#D&``!6
M`@``1@@``"`#````````W`$``"T````S!````````$$&`````````````!,`
M````````^````!`#```*`0``````````````````\P4``"<'``"5!@``'P8`
M`+`$``#V!```[P<``-H!````````S````%T&``!)!@``F08``%\"``#_!P``
ML`4`````````````Z`<``$D$``#"!P``!P```(,!````````00<``!H```"F
M`@``8`0```````"-"```SP8``"`%``!K`@```````*T'``#$!@``?P```.<!
M``"X`P```````/L"``!Y!```?@<```````#-`0``"0````<$``!-`0``R@``
M``````!_!```Z08```````!/`0``!@$``)<&``!=!P```````$H(``#O!```
M"`8``,P$``#K!```:P```"X#``!4`````````'P$```\"```-@```"P&````
M````.`(``(\'``#H`@``A@4``#X&``#'!```W`<`````````````$P,``,P%
M``!@!0``M`4````````G!```SP,``&`````U`@``-@<````````$!0``_@8`
M`)`%``!R!@``"P4``*X%``"O!```]00```````#E!```;@4`````````````
M`````)(```##`0``:`````````#P`P``IP,``!4%``!N!P``#P@``*D!``!H
M`0``5`$``-,"```U!```+@```!X#``!5!P``&`$``#0(``!7`0```P4``(L(
M```/!@````````````#@!````````"X(``#\!@`````````````L`0``D```
M`+T"````````_@0``%H"````````R@4``'L&``!/`P``_````'(`````````
M.`,``*H#``##`@``]`$``,L#````````)`<``%4#```C!P``(@,````````1
M"```,0,````````0!`````````````#'!@``*@,``%,'````````RP4``.(%
M```)!```.0(``)T!``!?`P``00(``$X"``#<`@``\@4``!$%````````K08`
M`$<!```F`0```````%\$``!K"```4P@``+\%````````.`@```$"````````
M#`,``)L'```````````````````A!```8@<`````````````R@8``.,$```8
M`@``>@4``',%``">`0``3`,``%@"```=````D`<``$H'``!5"```<@0``*8%
M```4`P``M08``'T``````````````"H"````````P`$``&8%````````F0(`
M````````````O@<``*4&``#>!P``!`,``!`%````````1@0``*@`````````
ML`8```````"=!0``````````````````;0<``-`#``"L!````````(0&``!A
M`P``R0,``#\!``!O"```F@<`````````!0``500``*H&``"6````-P0`````
M````````^`$``+H"``"S!```:`0``-<!```/!0``004``'@!````````V`(`
M```````Y`0``&P@``.8$``!4`P``JP(```````!`!0``,`,````````;!```
MJ0<```\'``#O````/P<```````#;`0```````"P(```+!P```````%X#``!'
M"`````````````!D!P``)P$```````!I!```4@<``'D(````````*````!@#
M````````'P(``#<!```*`@``4P$``%0"``#2!0```````)4'``"9!```G`$`
M``X"````````K0(``.,#``#4`P``^`8``"<%````````I0<``#8#``#2!P``
M"P(``%X```#5`0``^@0````!````````<P$```````````````(``+0'``#+
M````6@````````"6`P```````/($``"=````H@<``)H%````````<`(``'$&
M``">!```^`0``(,#````````"`4``!<!``"1`@``#`(``$`"``#Y`P``YP<`
M`+P`````````>P4````````K"```/`8``%,#``#C````*0<``%T%``"W!0``
MCP4``&H!```@`````````!4'```?`P``;P,```````!(!@``GP$``)8&````
M````+@4```4#````````P@(``````````````````&X"```7````)````'`(
M``#<!0``````````````````HP8``#D'``!&`0```@4`````````````\P$`
M````````````)P,```````"8!P``$P4``.L```!H`@``00```-T#```M`0``
M'@(``(,(```_`@```````(4"````````,`4``+`````V`@```````,X```!)
M`P``M````$0(``![`0```````)\````>``````````````!_!P``C@$`````
M``"'!```C`<```````"5`0``/0$``$,!```^`@```````%$'````````````
M`!,'``"H!@``E00``&T&```?!0``V0(``(D$````````>P0``+D"``"6`0``
M``````\$``!(`0``SP```+P'``!R`P``QP$``.T"``"S`@````````8'````
M````8P@``$@``````````````*(!`````````````'D'``#L!@``&04``+X%
M``#X!P``*00``,````"]`0``JP````````"-!0```````(@"````````;0$`
M`&0#````````/0@``&X&```#!```3@@``!H'``!0!0``G00``&4(````````
M`````$0'````````400``.D%``!A!````````/L$``#V`0``>@<`````````
M````=@,``(\#``#H`P``YP,``.8&```1`P``308``.T%``#N!@``O@(`````
M``!7`P``5@$```````""`@```````&D#````````)`4``'0%```\`0``'P``
M`",!``#(!0``>@$```````"*!@```````'\&````````W0$``'\%``"V!```
M&P(```````"I!@``(@```+L&``!J"```````````````````O`$``!8#````
M````"`$``````````````````$('``"8``````````````!I"```````````
M``#X!0``+P(```````#H!0``I0(``*0#``!2`@``PP<````````F"```WP4`
M`$0`````````204``%X!``">`@```08``-(!````````A`$`````````````
M$08``-`%``"V`0``Y04``(4&``!``P``"`@``#`'````````7@<``',```"-
M!```U@``````````````#00```````"O`@```````'`!``#B`0``G08``*L!
M```[`0``\0```,8$``!;!P``H0,``.H#``"``0``30`````````-"```G`(`
M`,P"```/````1P4`````````````S@(``.X````````````````````K`P``
M`````#L(``!0!```4`8``#<'````````00@``"('```0!P````````<"``"8
M!@```````(@$````````&`@```````#Q!```@@$`````````````]`4`````
M```E`0```````!$!``"B`````````+8&``"N!@```````$($``!-`P``D@(`
M```````%````AP`````````^````J@0``"`&``"J!0``_P,``)4#``!1"```
M_`4```T!``!=`@``]`8``%<(``#G````<00``*````!%`0``U@<```L#``#7
M!0``E`4```8"``")`````````),"````````K````)P'``"L`P``W@```$,#
M``"O!@``J`(``&<$````````````````````````?`<``(@&``!Q!0``````
M```````7"````````&$%```O!```#@,````````%!@``#@0````````1````
M70````````"=`@``4`(``!8'``#]`0``1`8``/H!```E!```2@0`````````
M````Q0(````````U````4@4``-,`````````^@```+<"````````D`0``&0`
M``#)`@``*@````````"]`P```````'T'```-!0``C@4``)8$```7`@``K`8`
M``0'````````*P$``"$%``!(!````````.H&``"M!```BP````````#4`0``
M9P,``#8$```)`0``TP$``.\#``````````````('```````````````````W
M"```B@,```````#$``````````````"?`P``U@8``.T&``"#!@```````!T#
M``!M"```#0(``$L#``"=!P``+@8````````(!P`````````````R!@``KP,`
M`)<$``#W`@``40(````````F`P```````'L"``#"!0``M04``(P&``!-`@``
M"@<``(\"``"<`P``]````.@!``!,`0``8P<``"D`````````"P0``+L```#0
M!````````$4"``".!@``0P<```````!T`0``Y08````````S!0``3P8```<'
M``#[`P``MP$``-T"``!5`@``F@,``&`#``!)!P``A@<```````!`````````
M`.,&```0`@```````````````````````+$'``#G!```M`(``#('```Z`P``
M0P8``#P"```T!P```````*\'``#W`0``B0$``*8#``````````````````"M
M`P```````%8$``#C!P``B0@``"D&```!!```.@@``!H"``"%````````````
M``!>!0``W````(D&``#6!0``9P@`````````````,P8``#8!``"A!P``T0,`
M`"$&``!I!@```@@``"\#``#9`````````!8```#+!````````)D'``!0````
MZ`0``'`#``!L````=0````````#>`0``@`0`````````````(`(```````!Z
M!@```````/L&``!F!@``W0<``,\!````````N`(``.(#````````````````
M``!#!0``9`4``+8%```2!````````/8'``#:!```A@8``/X#````````1`4`
M`%L&```(`@``+P4``'$(``!-!P``"@4``/$"``"Q!@```P8``$0"``"K`P``
M`````%H!```!"```/P```%P````Q!@``<0(````````]````Z@4`````````
M``````````````!;`0```````-$%``"9!0``JP0``((```#4!P```````.P%
M``"*`@``Y`8``/4!``#>!@``\`<``*X````W!@````````0$``!E````1@(`
M`)(&``#%`0```````"`!````````A````*D```"A!0``A@(``$L!``!%````
M[0$`````````````<0<``)@%``!8"```VP0````````%`0``$`8``",%``",
M"`````````````#$`0``@@4``$8````T`0``U````.D#``##`P``40,``+4$
M``#!!```+`,``/````#A`@``<@(``!0(````````7`4````````>!@``````
M`#L'``#]`````````(<'````````108``.$```!E`@``Q@4``'H```#5`@``
MQP,``.4```!;"```L@```,L&``!R"```Q@(``'@(````````?`$``#`"``#$
M!P``M`,`````````````BP<```````"R`P````````````#T`P``00$`````
M``#W````@`8``%X&``#6`@``[@$``-H%``"]!````````(0'```]!0``````
M`-D&```````````````````%!```(@(``)<'``!B`@``M@<``,X'``#!`0``
M,@0```````!]"````````,$#``````````````L```!Y`0``!@@``%(#````
M````Z0(``,P&``!`!@``5P4```T'``#*`@``:`8``.($``"?`@``\P<``+($
M``"U!P``O0<```````!G`0````````````"I!```6P4``"X'```*`````P@`
M`/T&````````%@(``,`#``#!!P``H@,``+@$````````A@$`````````````
M'`8`````````````2@4``-<&``#'`@```````/(&``"M`0``D@,``-X"```G
M`@``808``'H$``!A!P``90<```P'`````````````"P'````````+04``+4#
M```<`P``WP<``````````````````*`#``!!!```V@<``#(%````````DP,`
M`"@"````````BP,``&8#``"^`P```````"T#````````/P@````````<!```
MX04```````!_`P``7P$``#8&```&!0``@04``',#``!C`0``V@(```````#L
M````7P8``!H!```>!```\`8```````#G`@``LP,``"T(``!?!0``S`$``.0$
M````````L`$``````````````````/<%```*!```@P4``/P"```M!```I@<`
M``````#O`@```````'X!``":`````````)`&````````%@8``-D$``!7!```
M:04``$X$``!F`@``7`@``-0&``"@!@``CP$``/H%```W!0``U`4``,H$``"U
M`0```````/`"``!$`P```````((#``"!`````````,D&``"4!P``````````
M``#I`````````'<'``#I`0```````","```Q!```UP,``#\%``"3!@``FP0`
M`,H'````````TP4```````"F!@```````-L"```S`P``*P(```````"X!@``
M`````,D%`````````````%$!``!?!P``>04``%\``````````````'<&``!L
M`@``_`$```P$````````1P```"$(``!=`P``T0(``#X%````````<P0``!P%
M``"/!```9`0``+$%```4`0``5@,``!D$``#E!P``H@(``%@'``!*!@``````
M```````3`0``J`4``*P%``"%`0``5@<```````"[!0``O`4``-T%````````
MB`$``%`#``".`P```````)X#```H!@``TP<```P&``#3!@``RP$``*0!``!2
M"```5`<``%4%``"H!P``D`(``'4$``!'!````````,(```!("````````*X'
M```Y!```/@,```````!-!0``8`(``)$$`````````````'@"```=`@``````
M````````````$````-P&``!I````?0,``.T$````````4`<``*$&```*!@``
M:@<``!L#```N!```>`,``"8'````````[0<``",``````````````+H#``"J
M!P``B````+L$``"A`0``;@0````````Q`0``FP$``$`$````````;@,``*\!
M````````I@$```@$``#(!```W`0````@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@
M*'EE<W1E<F1A>2D`($%D9"!A;B!)35-0($%D9')E<W,@0F]O:P`@1&5L971E
M($E-4U`@061D<F5S<R!";V]K`"!A="``(B5S(B!A;')E861Y(&5X:7-T<R!A
M;F0@=V%S(&YO="!I;7!O<G1E9"X`(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN
M`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN`"(E<R(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N
M`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`(B5S(B!W87,@;F]T(&UO=F5D
M(&)E8V%U<V4@:70@:7,@82!L:7-T+@`B1FER<W1N86UE($QA<W1N86UE(B`@
M*&EE+B!*;VAN($1O92D`(DQA<W1N86UE+"!&:7)S=&YA;64B("AI92X@1&]E
M+"!*;VAN*0`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X
M<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P
M<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%D9&5D+@`E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`
M)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E
M<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!
M9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!4
M87-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R
M;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@
M86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I
M=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S
M=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T
M("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0
M<F5V:6]U<P!!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E
M<75I<F5D`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S
M`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET
M;W(`06)O=70N+BX`06)O=F4@<V5A<F-H(&9O<FT`06)S8F]T=&]M`$%B<VUI
M9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D96YI960@
M=&\@)7,`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C
M8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``
M061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``
M061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`
M061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R
M.@!!9&0@861D<F5S<R!B;V]K`$%D9"!A;F0@1&5L971E($E-4U`@861D<F5S
M<R!B;V]K<P!!9&0@8V]L=6UN`$%D9"!F:6QE`$%D9"!N97<@;65M8F5R<P!!
M9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`
M061D('1O`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S
M(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+@!!9&1I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92X`061D:6YG
M('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&1R
M97-S($)O;VL@3&ES=&EN9P!!9&1R97-S($)O;VMS`$%D9')E<W,@8F]O:R!E
M;G1R>0!!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"X`061D<F5S
M<R!B;V]K('1O(&1E;&5T92``061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T
M(&)E(&1I<W!L87EE9#H`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F
M;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%D=F%N8V5D(%-E
M87)C:`!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`
M06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R
M;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_`$%L<F5A9'D@17AI<W1S`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A
M`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO
M;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A
M<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO
M;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P
M<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!T:&%T
M('EO=2!W86YT('1O(&1E;&5T92`E<S\`07)E('EO=2!S=7)E('1H870@>6]U
M('=A;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/P!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@
M86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA
M;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YD:6YG`$%S8V5N<VEO;B!)
M<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M
M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER
M960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E
M<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC
M871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F
M86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--
M0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N
M`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A
M:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H
M`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!"87-E;&EN90!"87-I8R!396%R8V@`0F5L87)U<P!"96QG:75M`$)E
M;&EZ90!"96QO=R!S96%R8V@@9F]R;0!"96YI;@!"97)M=61A`$)H=71A;@!"
M:6YD(&9A:6QE9#H@*"5S*2`E<P!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P
M<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C
M:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T
M:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H
M`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)O=W-E`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0G5S:6YE<W,@0V%T96=O<GD`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<P!#4U8`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A
M<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R
M;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL
M92`B)7,B`$-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BX`0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`
M0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E
M;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@
M<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU
M;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T
M(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O
M('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R
M`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H
M;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R
M=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y
M+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@
M175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R
M=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N
M9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@
M;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN
M("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN
M:RXN+@!#:&5C:R!?06QL+TYO;F4`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP
M;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H
M;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@;F%M90!#:&]O<V4@82!P87-S
M=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@861D<F5S<R!B;V]K
M`$-H;V]S92!A;B!A9&1R97-S(&)O;VLZ`$-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I`$-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O(&1I<W!L87DL
M(&%N9"!I;B!W:&%T(&]R9&5R.@!#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K
M<R!T;R!U<V4N`$-H;V]S92!W:&EC:"!C;VQU;6YS('1O(&1I<W!L87D@86YD
M(&EN('=H870@;W)D97(Z`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A
M9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`
M0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L
M;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO
M<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@
M3W!T:6]N<P!#;VQU;6X@=&ET;&5S`$-O;'5M;G,@=&AA="!W:6QL(&YO="!B
M92!D:7-P;&%Y960Z`$-O;6EC<P!#;VUM82!S97!A<F%T960@=F%L=65S`$-O
M;6UA('-E<&%R871E9"!V86QU97,@*$UI8W)O<V]F="!/=71L;V]K*0!#;VUM
M86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S
M`$-O;7!A;GD`0V]M<&%N>2!!9&1R97-S`$-O;7!U=&5R<P!#;VYD:71I;VX`
M0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R
M871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@
M3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG
M=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N
M;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(&9A:6QE9#H@)7,`0V]N;F5C
M=&EO;B!F86EL=7)E`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"X`0V]N=&%C="!396%R8V@`0V]N=&%C=',`0V]N=&%C
M=',@:6X@;&ES=#H@)7,`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP
M<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@
M27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE
M8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S
M(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B
M+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I
M8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#
M;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@
M:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F
M;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I
M<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S
M=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T
M:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E
M(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I
M;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N
M;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@
M;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O
M=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C
M86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O
M=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H
M92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O
M=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!!9&1R
M97-S($)O;VL`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@0V]N=&%C="!,
M:7-T(&EN.@!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#
M<F5A=&5D`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R
M`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO
M;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`
M0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S
M='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N
M`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU
M<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE
M=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!)
M;F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F875L="!3:&5L;`!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$969I
M;FET:6]N<P!$96QE=&4`1&5L971E($%D9')E<W,@0F]O:P!$96QE=&4@0V5L
M;`!$96QE=&4@0V]N9FER;6%T:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G
M`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L971E(&)U='1O;B!B96AA=FEO=7(`1&5L971E(&-E;&P`1&5L971E(&-O
M;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T
M92!F86EL960Z("@E<RD@)7,`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E
M;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E
M9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QE=&EN9R!C;VYT86-T
M<R!I<R!N;W0@879A:6QA8FQE+@!$96QE=&EO;B!F86EL960`1&5L:79E<GD@
M=&EM90!$96YM87)K`$1E<&%R=&UE;G0`1&5S8V5N9&EN9P!$97-C<FEB92!T
M:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T
M('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$
M:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS
M`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`
M1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T
M:6YG(&5N=')I97,_`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`
M1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG
M;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1&]W;FQO860@=D-A<F0`
M1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@(B5S(@!%9&ET($%D9')E
M<W,@0F]O:W,`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO
M;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D
M:70@96YT<GD@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T
M:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA
M:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@
M=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC
M;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`
M16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5N=')Y(&9O<B`E<R!U<&1A=&5D
M+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,`16YT
M<GD@9F]R("5S('5P9&%T960N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`
M17)R;W(`17)R;W(@861D:6YG("5D(&-O;G1A8W0H<RD@=&\@;&ES="X`17)R
M;W(@861D:6YG("5D(&]F("5D(')E<75E<W1E9"!C;VYT86-T*',I('1O(&QI
M<W0N`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R`E
M9"!C;VYT86-T*',I+@!%<G)O<B!D96QE=&EN9R`E9"!O9B`E9"!R97%U97-T
M960@8V]N=&%C=',H<RDN`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C
M;VYT96YT.B`E<P!%<G)O<B!R96UO=FEN9R`E9"!C;VYT86-T*',I(&9R;VT@
M;&ES="X`17)R;W(@<F5M;W9I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A
M8W0H<RD@9G)O;2!L:7-T+@!%<G)O<B!S96%R8VAI;F<@=&AE(&%D9')E<W,@
M8F]O:SH@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA
M`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`
M179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M
M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP
M96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@
M061D<F5S<R!";V]K`$5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T
M<RX`17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E
M;'DN`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E
M<W,@8F]O:SH@)7,`1F%I;&5D('1O(&%D9"`E<R!T;R`E<SH@)7,`1F%I;&5D
M('1O(&)R;W=S92!L:7-T`$9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R
M>0!&86EL960@=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S
M+"!.97<@1$X@/2`E<RP@4F]O="`]("5S`$9A:6QE9"!T;R!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O
M("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`
M1F%I;&5D('1O(&9I;F0@;V)J96-T('1O(&)E(&%D9&5D.B`E<P!&86EL960@
M=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:6QE
M9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:P!&86EL960@=&\@<V5A<F-H
M('1H92!D:7)E8W1O<GDZ("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&
M96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&
M97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&
M:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE
M($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@
M<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+@!&:6QE<P!&:6QT97)S`$9I;F0`1FEN:7-H`$9I;FQA;F0`1FER<W0@
M2&%L9@!&:7)S="!.86UE`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``
M1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E8G5S
M>2!54DP`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R
M:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T
M86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O
M;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H
M86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!!9&1R97-S($)O;VL`
M1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!3
M96%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E
M96YL86YD`$=R96YA9&$`1W)O=7``1W)O=7`@061M:6YI<W1R871I;VX`1W)O
M=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O
M=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A
M9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S
M:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A4
M34P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE
M+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!
M;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX
M.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R
M`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO
M;64`2&]M92!!9&1R97-S`$AO;64@0VET>0!(;VUE($-O=6YT<GD`2&]M92!$
M:7)E8W1O<GD`2&]M92!0:&]N90!(;VUE(%!O<W1A;"!#;V1E`$AO;64@4W1A
M=&4O4')O=FEN8V4`2&]M92!3=')E970@061D<F5S<P!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@
M96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO
M(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L
M86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX
M;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A
M=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z
M("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A
M;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU
M;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`
M2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O
M=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)35-0`$E-4U`@061D<F5S<R!";V]K
M($%D;6EN:7-T<F%T:6]N`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A
M:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R
M90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@
M=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE
M=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM
M86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@
M061D<F5S<R!";V]K+"!3=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O
M17AP;W)T($%D9')E<W,@0F]O:W,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R
M=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO
M;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!)
M;F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN
M9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN
M($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,
M:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`
M26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E
M<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R
M86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F
M;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y
M($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!)
M;G1E9V5R(&QI<W0`26YV86QI9"!)1`!);G9A;&ED(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@861D<F5S<R!B
M;V]K`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN
M=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RX`26YV86QI9"!E;6%I;`!);G9A;&ED(&5N=')Y`$EN=F%L:60@9FEL
M92!F;W)M870`26YV86QI9"!K97D@<W!E8VEF:65D+@!);G9A;&ED(&QI8V5N
M<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US
M9U]T>7!E+@!);G9A;&ED(&YA;64`26YV86QI9"!O8FIE8W1)9`!);G9A;&ED
M(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T
M;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O
M;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE
M8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A
M=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D
M(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`
M2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*
M;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF
M>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`
M2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D
M(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`
M2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E
M`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U
M8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU
M=V%I=`!+>7)G>7IS=&%N`$Q$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@
M=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E
M9"X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8P!,87-T($AA;&8`3&%S="!-;V1I9FEE9`!,87-T($YA;64`3&%S
M="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`
M3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO
M9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@
M;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E
M<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY
M80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H
M="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E
M<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N
M;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0`3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4
M;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T
M+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M
M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z
M(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@
M=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN
M(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/
M5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`
M36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC
M(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN
M7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S
M=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA
M9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG`$UA
M=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E
M9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X
M:6UU;2!.=6UB97(@;V8@0V]N=&%C=',`36%X:6UU;2!.=6UB97(@;V8@4&]R
M=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!P
M86=E<P!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@3&ES=`!-
M96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G
M92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN
M960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R
M:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED
M9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E
M;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO
M="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG($1.
M(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R871I;VXN`$UI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN
M9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N
M($E$+@!-;P!-;V)I;&4@36%I;`!-;V)I;&4@4&AO;F4`36]D97)A=&4`36]D
M:69I960@1&%T90!-;V1I9GD@55),`$UO9&EF>2!F86EL960Z("@E<RD@)7,`
M36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`
M36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S
M`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N`$UO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD`$UO<F]C8V\`36]S=&QY
M($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4`36]V92!$
M;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO
M=F4@;&5F=`!-;W9E(')I9VAT`$UO=F4@=7``36]Z86UB:7%U90!-=6QB97)R
M>2!!9&1R97-S($)O;VL`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU
M;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;
M)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T`$UU
M;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M
M871I;VX`37D@061D<F5S<R!";V]K`$UY($%D9')E<W,@0F]O:W,`37D@4&]R
M=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R
M964`3F%M90!.86UE($9O<FUA=`!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&-E
M;G1E<B!-96UB97(@1&ER96-T;W)Y`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S
M($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C
M871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N
M97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE
M9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!#;VYT86-T`$YE=R!-97-S86=E('1O
M("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L
M86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B
M;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT
M(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI8VMN86UE`$YI9V5R`$YI9V5R
M:6$`3FEG:'0`3FEU90!.;P!.;R`E<R!E;G1R>2!F;W5N9"!F;W(@)7,`3F\@
M861D<F5S<R!B;V]K<R!F;W5N9"X`3F\@879A:6QA8FQE(&-O;F9I9W5R871I
M;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE
M('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M
M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET
M:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N
M=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!6
M1E,N`$YO(&-O;G1A8W1S(&9O=6YD`$YO(&-R961I="!L969T+@!.;R!D97-T
M:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F
M;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E
M9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO
M(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E
M9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A
M('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED
M97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N`$YO('9#87)D(&1A=&$@=V%S(&9O=6YD+@!.;R!V86QI9"!834P@9&%T
M82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG
M:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET
M*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R
M;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`
M3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L
M96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O
M9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!I=&5M
M<R!P97(@<&%G90!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE
M8W0`3V)J96-T($-R96%T;W(`3V)J96-T(&YO="!F;W5N9`!/8W1A;`!/8W1O
M8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R
M9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O
M<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYC92!Y;W4@<V%V92!T:&ES(&]P
M=&EO;B!P86=E+"!T:&4@861D<F5S<R!B;V]K('=I;&P@8F4@<&5R;6%N96YT
M;'D@9&5L971E9"X@268@=&AI<R!I<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE
M;B!Y;W4@;75S="!C:&%N9V4@>6]U<B!S96QE8W1I;VX@=&\@(DYO;F4B+@!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N`$]N;'D@;VYE('9C87)D('-U<'!O<G1E9"X`3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A
M(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@
M9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK
M(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T
M:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES
M871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@
M=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE
M<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I;VYS
M`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-
M86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T
M960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$
M871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`
M4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@
M5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L
M;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`
M4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E
M<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N
M9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T
M(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I
M;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T
M960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VX@9&5N:65D`%!E<FUI
M<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`
M4&EN92!!9&1R97-S($)O;VL`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A
M8W0@;&ES=#H`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@
M='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0
M;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``
M4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E
M=FEO=7,`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E
M($%D9')E<W,@0F]O:P!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L
M:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A
M=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O
M(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`475E<GD`475E<GD@9F%I;&5D
M.B`H)7,I("5S`%%U:6-K(%-E87)C:`!1=6]T80!24T$@4'5B;&EC($ME>2`H
M)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@
M3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!2
M86YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@9F%I;&5D.B`H)7,I("5S
M`%)E860@;65S<V%G97,`4F5A9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA
M8FQE+@!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296%L;'D@9&5L971E('1H:7,@8V]N=&%C=#\`4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N`%)E8V]R9',@9&ES<&QA>65D.@!2961O97,@
M>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO
M;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!2
M96UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M
M;W9E`%)E;6]V92!";&]C:P!296UO=F4@861D<F5S<R!B;V]K`%)E;6]V92!C
M;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E(&9R;VT@=&AI<R!L:7-T
M`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S
M97(Z("5S`%)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K('=I=&@@=&AE
M(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES(&1E;&5T97,@
M86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@8F]O:RX\+W-T
M<F]N9SX`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B``4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N`%)E<75E
M<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@
M4&%S<W=O<F0`4F5S970@=&\@1&5F875L=',`4F5S=&]R92!,87-T(%%U97)Y
M`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R
M9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V
M86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@
M,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2
M;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4`4R]-24U%(%!U8FQI8R!#97)T:69I8V%T90!305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,
M(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-4
M05)45$Q3(&9A:6QE9#H@*"5S*2`E<P!354-#15-3`%-?44P@4VAE;&P`4V$`
M4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I
M80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@
M36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED
M97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/
M<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z("(E<R(N`%-A=FEN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA
M8FQE+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5A<F-H(&9A:6QE9`!396%R8V@@9F%I;&5D.B`E<P!396%R
M8VAI;F<@:7,@;F]T(&%V86EL86)L92X`4V5A<F-H:6YG+BXN`%-E;&5C="!&
M:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE
M8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@
M=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M`%-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@9&5L971E`%-E;&5C="!A;B!A
M9&1R97-S(&)O;VL@=&\@961I=`!396QE8W0@86X@;V)J96-T`%-E;&5C="!N
M;VYE`%-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.@!3
M96QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z`%-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+@!396QE8W0@=&AE(&-H87)S970@;V8@=&AE('-O=7)C92!F:6QE
M.@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E;&5C="!T:&4@
M9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R
M8V4@9FEL93H`4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA
M;65S.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`
M4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O
M<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!V:65W
M('1O(&1I<W!L87D@8GD@9&5F875L="P@<V]R="!O<'1I;VYS+"!A;F0@<&%G
M:6YG(&]P=&EO;G,N`%-E;&5C="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I
M;B!T:&4@861D<F5S<R!L:7-T<RX`4V5L96-T('=H:6-H(&9O<FUA="!T;R!D
M:7-P;&%Y(&YA;65S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@861D<F5S<R!B
M;V]K("(E<R(N`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A
M;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E
M<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L
M92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS
M`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES
M<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F5D($1I<F5C=&]R>0!3:&]P<&EN
M9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D
M(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@)7,`4VAO=R!!;&P`4VAO=R!#
M;VYT86-T<P!3:&]W($QI<W1S`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C
M=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W
M97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET
M>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H
M;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO
M=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O
M<G0@1&ER96-T:6]N`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R
M97-S`%-O=7)C97,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M
M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!E8VEF>2!W:&5R
M92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I
M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R
M(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S
M<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M
M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B
M(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@
M=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@
M=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I
M<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@861D960@)60@8V]N=&%C="AS*2!T;R!L:7-T
M+@!3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,`4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A8W0@;&ES="`B)7,B+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@9&5L971E9"`E
M9"!C;VYT86-T*',I+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E;6]V960@)60@8V]N=&%C="AS
M*2!F<F]M(&QI<W0N`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@
M=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM
M87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U
M;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U
M<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N
M`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E
M9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@
M07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O
M<FUS`%0M4W1O<FUS($5A<FQY`%135@!44U8@9FEL90!486(@<V5P87)A=&5D
M('9A;'5E<P!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L
M92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G
M970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R
M.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O
M/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O
M=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!4
M97AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O
M<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R
M871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L
M;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z
M.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@5D93(&)A8VME;F0@
M;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@871T86-H;65N="!U
M<&QO861S+@!4:&4@861D<F5S<R!B;V]K("(E<R(@9&]E<R!N;W0@97AI<W0N
M`%1H92!A9&1R97-S(&)O;VL@(B5S(B!W87,@8W)E871E9"!S=6-C97-S9G5L
M;'DN`%1H92!A9&1R97-S(&)O;VL@(B5S(B!W87,@<F5M;W9E9"!S=6-C97-S
M9G5L;'DN`%1H92!A9&1R97-S(&)O;VL@(B5S(B!W87,@<W5C8V5S<V9U;&QY
M('5P9&%T960N`%1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E
M9#H@)7,`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T
M('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`%1H92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N`%1H
M92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O
M('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@
M;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T
M=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL
M92`B)7,B(&AA<R!S=6-C97-S9G5L;'D@8F5E;B!D96QE=&5D+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A
M;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+
M(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I
M=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W87)N:6YG<RX`
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!'
M;G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@
M8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J
M96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A
M;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S
M=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M
M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I
M8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O
M('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`
M5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4
M:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M
M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U
M(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N
M+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@
M;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A
M=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`
M5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO
M(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO(&]P=&EO
M;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@
M9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R
M97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K
M<R!A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R
M:65S('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@:7,@86X@97)R;W(L
M('!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@
M;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B
M('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I
M;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E
M('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ
M(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A
M<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A
M;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W
M(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F
M;W(@9G5R=&AE<B!H96QP+@!4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@
M82!N97<@;&ES="X`5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@
M861D<F5S<R!B;V]K.B`E<P!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M(B5S(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+@!4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<P!4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES=`!4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,`5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D9')E<W,@
M8F]O:SH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT
M<GDZ("5S`%1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="X`5&AE
M<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CH`
M5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CH`5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C
M:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N
M=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T
M<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@
M271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T
M:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI
M<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@
M82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T
M('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N
M9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@
M<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A
M9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@
M=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N`%1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE
M(&%D9')E<W,@8F]O:P!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@
M=VEL;"!B92!T:&4@9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@
M;W(@:6UP;W)T:6YG(&-O;G1A8W1S+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4
M:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`
M5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE
M8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I
M(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4
M;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A
M`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A
M;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R
M:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC
M;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD
M97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R92X@36ES
M<VEN9R!S;W5R8V4@='EP92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`
M56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E
M;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B
M;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F
M86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@
M=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O
M("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5
M;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@
M16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P
M<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,`
M56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E
M('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5
M<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@
M;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA
M;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``
M57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y
M(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!6
M86QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)I<VEG;B!$:7)E8W1O
M<GD`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R
M=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I
M971N86UE<V4@*%9)4T-)22D`5FEE=R`B)7,B`%9I97<@)7,`5FEE=R!#;VYT
M86-T`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W
M('1O(&1I<W!L87D@8GD@9&5F875L=#H`5FER9VEN($ES;&%N9',L($)R:71I
M<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y
M.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A
M;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!7
M96%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3
M:71E`%=E8G-I=&4@55),`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/
M+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`
M5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H
M`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@
M;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD
M($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O
M;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K($-I='D`5V]R:R!#
M;W5N=')Y`%=O<FL@4&AO;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K(%-T871E
M+U!R;W9I;F-E`%=O<FL@4W1R965T($%D9')E<W,`5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R
M;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`
M5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2
M968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!9
M60!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R
M964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B`B
M)7,B+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA
M=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N`%EO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N<R!T;R!D96QE=&4@=&AI<R!S;W5R8V4N`%EO
M=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F
M:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T
M:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!A
M9&1R97-S(&)O;VLN`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+@!9
M;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M
M=7-T('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="X`66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE
M+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R
M`%EO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C
M="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@
M86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z
M`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@
M<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!A
M9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N`%EO=7(@9&5F875L="!I
M9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@
M;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R
M(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB
M86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T
M70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=`%ML:6YE("5S(&]F("5S70!;;F\@=F%L=65=`%]!9&UI;FES=')A
M=&EO;@!?0G)O=W-E`%]#3$D`7T-O;G1A8W1S`%]$871A5')E90!?1&5L971E
M`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N
M+BX`7TEM<&]R="]%>'!O<G0`7TQI<W1S`%],;V<@:6X`7TQO9R!O=70`7TUO
M9&EF>2!,:6YK+BXN`%]->2!!9&1R97-S($)O;VMS`%].97<@0V]N=&%C=`!?
M3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]296UO=F4@
M9G)O;2!T:&ES(&QI<W0`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I
M97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C
M86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T
M(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C;VYT86-T+G9C9@!C;VYT86-T<RYC
M<W8`8V]N=&%C=',N='-V`&-O;G1A8W1S+G9C9@!C<FET:6-A;"!S>7-T96T@
M9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T
M(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN
M;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R
M;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@
M25-/+@!M;0!N86UE`&YO(&9O<FUA='1I;F<`;F]N90!N;W0@:6UP;&5M96YT
M960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&5R;6ES
M<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R
M:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M
M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@
M;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T;R!A($-O;G1A8W0@3&ES=`!T;R!A
M(&1I9F9E<F5N="!!9&1R97-S($)O;VL`='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A
M<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!4=7)B82`R
M+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3`Q(#$R.C`V*S`Q,#`*
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTP,2`Q,CHP-BLP,3`P"DQA<W0M
M5')A;G-L871O<CH@36%N=65L(%`N($%Y86QA(#QM87EA;&%`=6YE>"YE<SX*
M3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S
M:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E3
M3RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R
M86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3L*`"`H:&%C
M92`E<R!D[6%S*0`@*$%C8V5D:65N9&\@82`E<RD`("AE;B`E<R!D[6%S*0`@
M*&AO>2D`("AM8?%A;F$I`"`H87EE<BD`($'Q861I<B!U;F$@3&EB<F5T82!D
M92!D:7)E8V-I;VYE<R!)35-0`"!%;&EM:6YA<B!U;F$@3&EB<F5T82!D92!D
M:7)E8V-I;VYE<R!)35-0`&5N(``B)7,B('EA(&5X:7-T92!Y(&YO('-E(&EM
M<&]R=/,N`"(E<R(@;F\@97,@=6X@9&ER96-T;W)I;RX`(B5S(B!N;R!E<R!U
M;F$@96QE8V-I\VX@=N%L:61A+@!.;R!S92!H82!C;VYF:6=U<F%D;R`B)7,B
M(&5N(&5L(')E9VES=')O(&1E($AO<F1E+@!.;R!S92!E;F-O;G1R\R!E;"!G
M96YE<F%D;W(@9&4@X7)B;VQE<R!D92`B)7,B+@!392!H82!A\6%D:61O("(E
M<R(@86P@<VES=&5M82!D92!G<G5P;W,N`%-E(&AA(&'Q861I9&\@(B5S(B!A
M;"!S:7-T96UA(&1E('!R:79I;&5G:6]S+@!.;R!S92!C;W!I\R`B)7,B('!O
M<G%U92!E<R!U;F$@;&ES=&$N`$YO('-E(&AA(&-R96%D;R`B)7,B.B`E<RX`
M3F\@<V4@=')A<VQA9/,@(B5S(B!P;W)Q=64@97,@=6YA(&QI<W1A+@`B3F]M
M8G)E($%P96QL:61O<R(@("AP+F4N($IU86X@3F%D:64I`")!<&5L;&ED;W,L
M($YO;6)R92(@*'`N92X@3F%D:64L($IU86XI`%5S861O<R`E+C)F34(@9&4@
M)2XR9DU"('!E<FUI=&ED;W,@*"4N,F8E)2D`)60@)7,@>2`E<P!1=65D86X@
M)60@9.UA<R!H87-T82!Q=64@97AP:7)E(&QA(&-O;G1R87-E\6$N`"5D('!R
M;V[S<W1I8V]S(&1I87)I;W,`)7,@+2!!=FES;P!(=65L;&$@9&EG:71A;"!D
M92`E<P`E<R!+0@`E<R!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O("T@
M0V]N9FER;6%C:?-N`$-O;F9I9W5R86-I\VX@9&4@)7,`1FER;6$@9&4@)7,`
M06-U97)D;W,@9&4@;&EC96YC:6$@9&4@)7,`4V4@:&$@8?%A9&ED;R`E<RX`
M66$@97AI<W1E("5S+@`E<R!A(&QA<R`E<R`E<P!%;"!A<F-H:79O("5S('-E
M(&AA(&EM<&]R=&%D;R!S871I<V9A8W1O<FEA;65N=&4`)7,@97-TX2!P<F5P
M87)A9&\@<&%R82!R96%L:7IA<B!L87,@;W!E<F%C:6]N97,@9&4@;6%N=&5N
M:6UI96YT;R!S96QE8V-I;VYA9&%S+D%C=&EV92!L87,@8V%S:6QL87,@9&4@
M;&%S(&]P97)A8VEO;F5S('%U92!D97-E82!E:F5C=71A<B!E;B!E<W1A(&]C
M87-I\VXN`$AA8V4@9F%L=&$@)7,`)7,@;6EN=71O<P!.;R!S92!H82!E;F-O
M;G1R861O("5S+@`E<R!A;"`E<R!D92`E<P!,:6)R971A(&1E(&1I<F5C8VEO
M;F5S(&1E("5S`$%G96YD82!D92`E<P!,:6)R971A(&1E(&YO=&%S(&1E("5S
M`%1A<F5A<R!D92`E<P`E<SH@)7,`)7,Z($5S=&4@;65N<V%J92!P=65D92!Q
M=64@;F\@<')O8V5D82!D92!Q=6EE;B!P87)E8V4@<V5R+B!%=FET92!S96=U
M:7(@8W5A;'%U:65R(';M;F-U;&\@:6YC;'7M9&\@;R!S=6UI;FES=')A<B!C
M=6%L<75I97(@:6YF;W)M86-I\VX@<&5R<V]N86P@86P@<F5M:71E;G1E+@`L
M('9E;G1O<V\@`"P@=F5N=&]S;R`E<R`E<P`L('9A<FEA8FQE(&1E("5S(&$@
M)7,`+2T@<V5L96-C:6]N87(@+2T`1F]R;6%T;R!D92`Q,B!H;W)A<P!&;W)M
M871O(&1E(#(T(&AO<F%S`#(T(&AO<F%S`#Q!;G1E<FEO<@!(86-E(&9A;'1A
M('5N(&YA=F5G861O<B!C;VX@<V]P;W)T92!D92!I1G)A;65S`%!A<F$@97-T
M92!B;&]Q=64@:&%C92!F86QT82!U;B!M;W1O<B!D92!B87-E(&1E(&1A=&]S
M+@!392!H82!P<F]D=6-I9&\@=6X@97)R;W(@:7)R97!A<F%B;&4`2&%C92!F
M86QT82!U;F$@8VQA=F4@4$=0('#Z8FQI8V$@<&%R82!C:69R87(@=6X@;65N
M<V%J92X`2&%C92!F86QT82!U;F$@8VQA=F4@4$=0('#Z8FQI8V$@<&%R82!C
M;VUP<F]B87(@=6X@;65N<V%J92!F:7)M861O+@!(86-E;B!F86QT82!U;F$@
M8VQA=F4@4$=0('#Z8FQI8V$L('5N82!C;&%V92!01U`@<')I=F%D82!Y('5N
M82!F<F%S92!C;&%V92!P87)A(&1E<V-I9G)A<B!U;B!M96YS86IE+@!(86-E
M;B!F86QT82!U;F$@8VQA=F4@4$=0('#Z8FQI8V$L('5N82!C;&%V92!01U`@
M<')I=F%D82!Y('5N82!F<F%S92!C;&%V92!P87)A(&9I<FUA<B!U;B!M96YS
M86IE+@!(86-E;B!F86QT82!U;F$@8VQA=F4@4R]-24U%('#Z8FQI8V$L('5N
M82!C;&%V92!3+TU)344@<')I=F%D82!Y('5N82!F<F%S92!C;&%V92!P87)A
M(&1E<V-I9G)A<B!U;B!M96YS86IE+@!(86-E;B!F86QT82!U;F$@8VQA=F4@
M4R]-24U%('#Z8FQI8V$L('5N82!C;&%V92!3+TU)344@<')I=F%D82!Y('5N
M82!F<F%S92!C;&%V92!P87)A(&9I<FUA<B!U;B!M96YS86IE+@!(86-E(&9A
M;'1A('5N82!C;&%V92!334E-12!P^F)L:6-A('!A<F$@8VEF<F%R('5N(&UE
M;G-A:F4N`$YU8F5S(&UA=&EN86QE<P!,:6=E<F$@;&QU=FEA(&UA=&EN86P`
M3&QU=FEA(&UA=&EN86P`06=U86-E<F]S(&UA=&EN86QE<P!!9W5A8V5R;R!M
M871I;F%L(&1E(&YI979E`$%-+U!-`$E$(&1E($%020!!8V5R8V$@9&5L(&5D
M:71O<@!!8V5R8V$@9&4N+BX`4V]B<F4@96P@9F]R;75L87)I;R!D92!B^G-Q
M=65D80!);F9E<FEO<B!!8G,N`$5N(&UE9&EO($%B<RX`4V4@:&$@9&5N96=A
M9&\@96P@86-C97-O(&%L(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93+@!392!H
M82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@96P@87)C:&EV;R!61E,N
M`$%C8V5S;R!D96YE9V%D;R!A("5S`$ED96YT:61A9`!#;VYT<F%S9?%A(&1E
M(&%C8V5S;P!)9&5N=&ED860@8FQO<75E861A+@!#;VYT86)I;&ED860`0?%A
M9&ER(&$`0?%A9&ER(&=R=7!O(&1E<V-E;F1I96YT90!!\6%D:7(@<')I=FEL
M96=I;R!D97-C96YD:65N=&4`0?%A9&ER(&%Q=>TZ`$'Q861I<B!G<G5P;P!!
M\6%D:7(@<')I=FEL96=I;P!!\6%D:7(@82`B)7,B('5N(&=R=7!O(&1E<V-E
M;F1I96YT90!!\6%D:7(@82`B)7,B('5N('!R:79I;&5G:6\@9&5S8V5N9&EE
M;G1E`$'Q861I<B!U;B!U<W5A<FEO.@!!\6%D:7(@;&EB<F5T82!D92!D:7)E
M8V-I;VYE<P!!\6%D:7(@>2!E;&EM:6YA<B!L:6)R971A<R!D92!D:7)E8V-I
M;VYE<R!)35-0`$'Q861I<B!C;VQU;6YA`$'Q861I<B!A<F-H:79O`$'Q861I
M<B!M:65M8G)O<P!!\6%D:7(@<&%R`$'Q861I<B!E;"!M96[Z("5S(&-O;6\@
M<&%N96P@;&%T97)A;"!D92!-;WII;&QA`$'Q861I<B!A`$'Q861I<B!A(&QA
M<R!D:7)E8V-I;VYE<SH`0?%A9&ER(&$@;&%S(&1I<F5C8VEO;F5S.@!!\6%D
M:7(@=7-U87)I;P!392!H82!A\6%D:61O("(E<R(@86P@<VES=&5M82P@<&5R
M;R!N;R!S92!P=65D92!A\6%D:7(@;&$@:6YF;W)M86-I\VX@861I8VEO;F%L
M(&1E(&%L=&$Z("5S+@!392!H82!A\6%D:61O("(E<R(@86P@<VES=&5M82X@
M66$@<'5E9&4@:6YI8VEA<B!L82!S97-I\VXN`$YO('-E('!U961E(&'Q861I
M<B!C;VYT86-T;W,N`$QA(&%D:6-I\VX@9&4@=7-U87)I;W,@97-TX2!D97-H
M86)I;&ET861A+@!$:7)E8V-I\VX`3&EB<F5T82!D92!D:7)E8V-I;VYE<P!,
M:7-T861O(&1E(&1I<F5C8VEO;F5S`$QI8G)E=&%S(&1E(&1I<F5C8VEO;F5S
M`$5N=')A9&$@9&4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<P!392!H82!V
M86-I861O(&-O<G)E8W1A;65N=&4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE
M<RX`3&EB<F5T82!D92!D:7)E8V-I;VYE<R!A(&5L:6UI;F%R(`!,:6)R971A
M<R!D92!D:7)E8V-I;VYE<R!Q=64@;F\@<V4@;6]S=')A<N%N.@!!9&UI;FES
M=')A9&]R("T@9&5F:6YE('!R:79I;&5G:6]S(&1E(&]T<F]S('5S=6%R:6]S
M`$%D;6EN:7-T<F%C:?-N`$%N=6YC:6]S`$+Z<W%U961A(&%V86YZ861A`$%F
M9V%N:7-TX6X`06QB86YI80!!<F=E;&EA`$%L:6%S`$%L:6YE87(`06QI;F5A
M8VGS;CH`5&]D;P!4;V1O<R!L;W,@=7-U87)I;W,@875T96YT:69I8V%D;W,`
M5&]D;W,@;&]S(&=R=7!O<P!4;V1O<R!L;W,@<')I=FEL96=I;W,`5&]D;W,@
M;&]S(&QA9&]S`%!E<FUI=&ER('9A<FEA<R!D:7)E8V-I;VYE<P"_4&5R;6ET
M:7(@8V]N9FEG=7)A8VGS;B!D92!T:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_
M`%EA(&5X:7-T90!982!E>&ES=&4`06-C97-O($E-4U`@86QT97)N871I=F\`
M0VQA=F4@24U34"!A;'1E<FYA=&EV80!5<W5A<FEO($E-4%,@86QT97)N871I
M=F\`1&ER96-C:?-N(&5L96-T<O-N:6-A(&%L=&5R;F%T:79A`%!L86YT:6QL
M87,@86QT97)N871I=F%S`%1E>'1O(&%L=&5R;F%T:79O`%-A;6]A($%M97)I
M8V%N80!392!H82!I;F1I8V%D;R!U;B!V86QO<B!I;&5G86PN`%-E(&AA('!R
M;V1U8VED;R!U;B!E<G)O<B!D97-C;VYO8VED;RX`06YD;W)R80!!;F=O;&$`
M06YG=6EL80!0<F]X>2!A;O-N:6UO`%)E<W!U97-T80!!;G3A<G1I9&$`06YT
M:6=U82!Y($)A<F)A9&]S`$%P;&EC86-I\VX`3&ES=&$@9&4@87!L:6-A8VEO
M;F5S`$QA(&%P;&EC86-I\VX@97-TX2!L:7-T82X`07!L:6-A<B!A(')E8W5R
M<V]S(&-O;7!A<G1I9&]S(&1E<V-E;F1I96YT97,`07!R;V)A<@!486UA\6\@
M87!R;WAI;6%D;P!!8G)I;`!!<N%B:6=O("A7:6YD;W=S+3$R-38I`%1A;6'Q
M;R!D96P@87)C:&EV;P!.;VUB<F4@9&5L(&%R8VAI=F\`OT5S=.$@<V5G=7)O
M(&1E('%U92!D97-E82!E;&EM:6YA<B`E<S\`OT5S=&$@<V5G=7)O(&1E('%U
M92!D97-E82!E;&EM:6YA<B!L87,@96YT<F%D87,@<V5L96-C:6]N861A<S\`
MOT5S=&$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!L82!S;VQI8VET
M=60@9&4@86QT82!D92`E<S\`OT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!E
M;&EM:6YA<B`B)7,B('D@=&]D;W,@<W5S('-U8F=R=7!O<S\`07)G96YT:6YA
M`$%R;65N:6$`07)M96YI;R`H05)-4T-)22TX*0!!<G1E`$%R=6)A`$%S8V5N
M9&5N=&4`27-L82!!<V-E;G-I\VX`1W+A9FEC;W,@07-C:6D`4F5G:?-N(&1E
M($%S:6$O4&%C[69I8V\`OU-O;&EC:71A<B!C;VYF:7)M86-I\VX@86YT97,@
M9&4@<F5A;&EZ87(@;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;S\`0V]L
M=6UN87,@9&4@87-I9VYA8VGS;@!);G1E;G1A(&5L:6UI;F%R('5N(&=R=7!O
M(&EN97AI<W1E;G1E+@!);G1E;G1A(&5L:6UI;F%R('5N('!R:79I;&5G:6\@
M:6YE>&ES=&5N=&4N`$EN=&5N=&$@;6]D:69I8V%R('5N('!R:79I;&5G:6\@
M:6YE>&ES=&5N=&4N`$EN=&5N=&$@;6]D:69I8V%R('5N(')E8W5R<V\@8V]M
M<&%R=&ED;R!I;F5X:7-T96YT92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<F%L
M:6$`075S=')I80!!=71H7V-Y<G-Q;#H@3F\@<V4@96YC;VYT<O,@;&$@97AT
M96YS:?-N(&EM87`@;F5C97-A<FEA+@!!=71H7V-Y<G5S.B!%;"!M;W1O<B!C
M87)E8V4@9&4@;&%S(&-A<&%C:61A9&5S(&YE8V5S87)I87,N`$%U=&A?8WER
M=7,Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!I;6%P(&YE8V5S87)I
M82X`075T:%]F='`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!&5%`@
M;F5C97-A<FEA+B!#;VUP:6QE(%!(4"!C;VX@;&$@;W!C:?-N("TM96YA8FQE
M+69T<"X`075T:%]I;6%P.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@
M24U!4"!N96-E<V%R:6$N`$%U=&A?:W)B-3H@3F\@<V4@96YC;VYT<O,@;&$@
M97AT96YS:?-N(&MR8C4@;F5C97-A<FEA+@!!=71H7VQD87`Z($YO(&5S=.$@
M<V]P;W)T861A(&QA(&%D:6-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&5L:6UI
M;F%C:?-N(&1E('5S=6%R:6]S(&1E($%C=&EV92!$:7)E8W1O<GD`075T:%]L
M9&%P.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@3$1!4"!N96-E<V%R
M:6$N`$%U=&A?;&1A<#H@3F\@<V4@<'5E9&4@8?%A9&ER(&5L('5S=6%R:6\@
M)7,N(,ES=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(Z(`!!=71H7VQD
M87`Z($EN8V%P87H@9&4@96QI;6EN87(@96P@=7-U87)I;R`E<P!!=71H7VQD
M87`Z($EN8V%P87H@9&4@86-T=6%L:7IA<B!E;"!U<W5A<FEO("5S`$%U=&A?
M;&1A<#H@3F\@97-TX2!S;W!O<G1A9&$@;&$@86-T=6%L:7IA8VGS;B!D92!U
M<W5A<FEO<R!D92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;6-A;#H@3F\@<V4@
M96YC;VYT<O,@;&$@97AT96YS:?-N($U#04P@;F5C97-A<FEA+@!!=71H7W-M
M8F%U=&@Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!S;6)A=71H(&YE
M8V5S87)I82X`1F%L;/,@;&$@875T96YT:69I8V%C:?-N(&-O;B!E;"!S97)V
M:61O<B!)34%0+@!&86QL\R!L82!A=71E;G1I9FEC86-I\VX`1F%L;/,@;&$@
M875T96YT:69I8V%C:?-N+B`E<P!%;"!S97)V:61O<B!2041)55,@:&$@<F5C
M:&%Z861O(&QA(&%U=&5N=&EF:6-A8VGS;BX`1F%L;/,@;&$@875T96YT:69I
M8V%C:?-N(&-O;B!E;"!S97)V:61O<B!&5%`N`$9A;&SS(&QA(&%U=&5N=&EF
M:6-A8VGS;B!C;VX@96P@<V5R=FED;W(@4TU"+@!#86UP;W,@9&ES<&]N:6)L
M97,Z`$%Z97)B86EJ86X`17AC=7-A<R!"3T9(`$9O;F1O`$-O;&]R(&1E(&9O
M;F1O`$-O;G1R87-E\6$@:V5R8F5R;W,@:6YC;W)R96-T82X`3F]M8G)E(&1E
M('5S=6%R:6\@:V5R8F5R;W,@:6YC;W)R96-T;RX`0F%H86UA<P!"86AR86EN
M`$+A;'1I8V\@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$YO
M('-E(&5N8V]N='+S(&5L(&1I<F5C=&]R:6\@8F%S92!D92!I;>%G96YE<R`B
M)7,B+@!,[6YE82!B87-E`$+Z<W%U961A('-I;7!L90!"96QA<G5S`$+I;&=I
M8V$`0F5L:7IE`$$@8V]N=&EN=6%C:?-N(&1E;"!F;W)M=6QA<FEO(&1E(&+Z
M<W%U961A`$)E;FEN`$)E<FUU9&%S`$)H=71A;@!(82!F86QL861O(&5L(&5N
M;&%Z861O.B`H)7,I("5S`$-U;7!L96'Q;W,`3F\@<V4@96YC;VYT<O,@96P@
M8FQO<75E("(E<R(@9&4@;&$@87!L:6-A8VGS;B`B)7,B+@!/<&-I;VYE<R!D
M92!B;&]Q=64`5&EP;R!D92!B;&]Q=64`3F5G<FET80!";VQI=FEA`$UA<F-A
M9&]R97,`0F]R9&4`1W)O<V]R(&1E;"!B;W)D93H`0F]R9&5S`$)O<VYI82!(
M97)Z96=O=FEN80!!;6)O<P!";W1S=V%N80!);F9E<FEO<@!)<VQA(&1E($)O
M=79E=`!"<F%S:6P`5&5R<FET;W)I;R!O8V7A;FEC;R!D92!L82!);F1I82!B
M<FETX6YI8V$`17AA;6EN87(`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`
M3&ES=&$@9&5S;W)D96YA9&$`0G5R:VEN82!&87-O`$)U<G5N9&D`0V%T96=O
M<NUA(&1E(&YE9V]C:6\`0TU3`$-20P!0=6YT;W,@9&4@9&ES=')I8G5C:?-N
M($-20P!#4U8`4')O<&EE9&%D97,@9&4@7V-E;&1A+BXN`$YO('-E(&AA(&9I
M;F%L:7IA9&\@96P@:6YI8VEO(&1E(&QA(&-A8VCI+@!!9V5N9&$`0V%L;6$`
M0V%M8F]Y80!#86UE<OIN`$YO('-E('!U961E(')E86IU<W1A<B!L82!C;&%V
M92!A=71O;>%T:6-A;65N=&4L('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L
M(&%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N`$YO('-E('!U961E(&5S8W)I
M8FER(&5N(&5L(&%R8VAI=F\@(B5S(@!.;R!S92!P=65D92!A\6%D:7(@=6X@
M9W)U<&\@82!S[2!M:7-M;RX`3F\@<V4@<'5E9&5N(&%D;6EN:7-T<F%R(&UA
M;F5J861O<F5S(&1E('-E<VGS;B!E>'1E<FYO<RX`3F\@<V4@<'5E9&4@8V]N
M96-T87(@86P@<V5R=FED;W(@24U!4#H@)7,`3F\@<V4@<'5E9&4@86)R:7(@
M96P@87)C:&EV;R`B)7,B+@!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@:6YF
M;W)M92!D92!P<F]B;&5M87,`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@87)C
M:&EV;R`B)7,B+@!.;R!S92!E;F-U96YT<F$@=6X@9&ER96-T;W)I;R!T96UP
M;W)A;"X`3F\@<V4@<'5E9&4@8V]N=&EN=6%R('-I;B!E;"!P87+A;65T<F\@
M)W1A<F=E=$9I;&4G+@!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!D:7)E8W1O
M<FEO("(E<R(N`$YO('-E('!U961E(&5L:6UI;F%R+"!T:65N92`E9"!D97-C
M96YD:65N=&5S+@!.;R!S92!P=65D92!R96]R9&5N87(L(&5L(&[Z;65R;R!D
M92!E;G1R861A<R!Q=64@<V4@9&5S96$@;W)D96YA<B!N;R!C;VEN8VED92!C
M;VX@;&%S(&%L;6%C96YA9&%S+@!.;R!S92!P=65D92!D:7)I9VER(&5L(&UE
M;G-A:F4@86P@;OIM97)O(&5S<&5C:69I8V%D;RX`0V%B;R!697)D90!3=6)T
M[71U;&\`4')O=F5E9&]R`$-A=&5G;W+M87,@>2!E=&EQ=65T87,`27-L87,@
M0V%I;>%N`%1E;.EF;VYO(&WS=FEL`%!R;W!I961A9&5S(&1E(&-E;&1A`$UA
M<F=E;B!D92!C96QD83H`4')O<&EE9&%D97,@9&4@8V5L9&$`17-P86-I861O
M(&1E(&-E;&1A.@!496SI9F]N;R!M\W9I;`!#Z6QT:6-O("A)4T\M.#@U.2TQ
M-"D`0V5N=')A<@!297#Z8FQI8V$@0V5N=')O869R:6-A;F$`175R;W!A($-E
M;G1R86P@*$E33RTX.#4Y+3(I`$1E=&%L;&5S(&1E;"!C97)T:69I8V%D;P!0
M<F]P:65T87)I;R!D96P@8V5R=&EF:6-A9&\`4&]L[71I8V%S(&1E;"!C97)T
M:69I8V%D;P!#:&%D`$-A;6)I87(`0V%M8FEE(&QA(&-O;G1R87-E\6$`0V%M
M8FEA(&5L(&YO;6)R92!Y(&QA(&1I<F5C8VGS;B!E;&5C='+S;FEC82!V:7-I
M8FQE<R!A;"!L965R(&\@<F5S<&]N9&5R(&$@<W5S(&UE;G-A:F5S+@!,82!C
M;VYF:6=U<F%C:?-N(&%C='5A;"!N;R!S;W!O<G1A(&5L(&-A;6)I;R!D92!C
M;VYT<F%S9?%A<RX@4/-N9V%S92!E;B!C;VYT86-T;R!C;VX@96P@861M:6YI
M<W1R861O<B!D96P@<VES=&5M82X`1W+A9FEC;P!697)I9FEC87(@7W;M;F-U
M;&\N+BX`0V]M<')O8F%R(%]4;V1A<R].:6YG=6YA`$-H:6QE`$-H:6YA`$-H
M:6YO('-I;7!L:69I8V%D;R`H1T(R,S$R*0!#:&EN;R!T<F%D:6-I;VYA;"`H
M0FEG-2D`07!L:6-A8VGS;CH`16QI:F$@=6X@;F]M8G)E`$5L:6IA('5N82!C
M;VYT<F%S9?%A`$5L:6IA('5N(&YO;6)R92!D92!U<W5A<FEO`$5L:6IA('5N
M82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+@!%;&EJ82!U;F$@;&EB<F5T82!D
M92!D:7)E8V-I;VYE<SH`16QI:F$@8_-M;R!M;W-T<F%R(&QA<R!F96-H87,Z
M`%-E;&5C8VEO;F%R('1I<&\@9&4@97-T:6QO(&1E(&QI<W1A("AP87)A(&QI
M<W1A<R!O<F1E;F%D87,I`$5L:6IA('%UZ2!L:6)R971A<R!D92!D:7)E8V-I
M;VYE<R!M;W-T<F%R('D@96X@<77I(&]R9&5N.@!%;&EJ82!L82!L:6)R971A
M(&1E(&1I<F5C8VEO;F5S('%U92!Q=6EE<F$@=7-A<BX`16QI:F$@<77I(&-O
M;'5M;F%S(&UO<W1R87(@>2!E;B!Q=>D@;W)D96XZ`$ES;&$@9&4@4&%S8W5A
M`$YO('-E(&5N8V]N='+S(&QA(&1E9FEN:6-I\VX@9&4@8VQA<V4@9&4@)7,N
M`$QI;7!I87(`16QI;6EN87(@971I<75E=&%S($U33V9F:6-E`$)O<G)A<B!C
M;VYS=6QT80!";W)R87(@=7-U87)I;SH@)7,`0F]R<F%R('5S=6%R:6\`0F]R
M<F%R(&1A=&]S(&1E;"!U<W5A<FEO`$1E<W!E:F%D;R!T87)D[6\`2&%G82!C
M;&EC:R!P87)A('-E9W5I<@!#;&EC:V%T96QL('!O<B!(5%10`$-E<G)A<B!V
M96YT86YA`$YU8F5S`$YU8F5S('1E;7!R86YA<P!N=6)O<V\`27-L87,@9&4@
M8V]C;W,@*$ME96QI;F<I`$]C=6QT87(@8F%R<F$@;&%T97)A;`!#;VQA<'-A
M<B!B;W)D97,`0V]L;VUB:6$`0V]L;W(`4V5L96-T;W(@9&4@8V]L;W(`4V5L
M96-C:?-N(&1E(&-O;&]R`$-O;'5M;F%S.@!/<&-I;VYE<R!D92!C;VQU;6YA
M`%3M='5L;W,@9&4@;&%S(&-O;'5M;F%S`$-O;'5M;F%S('%U92!N;R!S92!M
M;W-T<F%RX6XZ`$/S;6EC<P!686QO<F5S('-E<&%R861O<R!P;W(@8V]M87,`
M5F%L;W)E<R!S97!A<F%D;W,@<&]R(&-O;6%S("A/=71L;V]K(&1E($UI8W)O
M<V]F="D`0V]M86YD;P!);G3I<G!R+B!C;VUA;F1O<P!#;VUE;G1A<FEO`$YO
M;6)R92!C;VWZ;@!#;VUO<F]S`$-O;7!A\>UA`$1O;6EC:6QI;R!L86)O<F%L
M`$]R9&5N861O<F5S`$-O;F1I8VGS;@!#;VYD:6-I;VYE<P!$:69E<F5N8VEA
M<R!D92!L82!C;VYF:6=U<F%C:?-N`$-O;F9I9W5R86-I\VX@<&%R82!S:6YC
M<F]N:7IA8VGS;B!C;VX@4$1!<RP@3?-V:6QE<R!C;VX@86=E;F1A('D@3W5T
M;&]O:RX`3&$@8V]N9FEG=7)A8VGS;B!E<W3A(&1E<V%C='5A;&EZ861A+@!#
M;VYF:6=U<F%R("5S`$-O;F9I<FUA<B!C;VYT<F%S9?%A`$-O;F=O`$-O;F=O
M+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&5L`$9A;&SS(&QA(&-O;F5X:?-N
M+@!&86QL\R!L82!C;VYE>&GS;CH@`$9A;&QO(&%L(&-O;F5C=&%R.B`E<P!&
M86QL;R!A;"!C;VYE8W1A<@!392!H82!R96-H87IA9&\@;&$@8V]N97AI\VX@
M86P@<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N`%-E(&AA(')E8VAA>F%D
M;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RX@
M36]T:79O.B`E<R`H)7,I`$AA(&9A;&QA9&\@;&$@8V]N97AI\VX@86P@<V5R
M=FED;W(@1E10+@!"^G-Q=65D82!D92!C;VYT86-T;W,`0V]N=&%C=&]S`$-O
M;G1A8W1O<R!E;B!L82!L:7-T83H@)7,`4V4@:&%N(&'Q861I9&\@8V]R<F5C
M=&%M96YT92!L;W,@8V]N=&%C=&]S(&$@<W5S(&1I<F5C8VEO;F5S`%1I<&\@
M9&4@8V]N=&5N:61O(&1E;"!A<F-H:79O(&-O;7!R:6UI9&\Z(`!#;VYT96YI
M9&\@9&4@(B5S(@!#;VYT:6YU87(`27-L87,@0V]O:P!#;V]K:64`0V]P:6%R
M`$9A;&SS(&QA(&-O<&EA.B`E<P!#;W!I87(@<V5L96-C:?-N`$E$(&1E(&-O
M<W1E`$-O<W1A(%)I8V$`0V]S=&$@9&4@36%R9FEL`$YO('-E('!U961E(&-I
M9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E('!U961E(&9I
M<FUA<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E('!U961E(&-I
M9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%,O34E-10!.;R!S92!P=65D92!F
M:7)M87(@96P@;65N<V%J92!M961I86YT92`@4R]-24U%`$YO('-E('!U961E
M(&'Q861I<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@96YL87IA<B!A
M;"!S97)V:61O<B!,1$%0+@!.;R!S92!P=65D92!C;VUP<F]B87(@96P@<V%L
M9&\N("5S`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($Q$05`N
M`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R("(E<R(@;65D:6%N
M=&4@1E10.B`E<P!.;R!S92!P=65D92!C<F5A<B!L82!L:7-T82!D92!D:7-T
M<FEB=6-I\VXN("5S`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A=&]S
M(%!'4#H@`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A=&]S(%,O34E-
M12X`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@8V]N=&%C=&\N("5S`$YO('-E
M('!U961E(&5L:6UI;F%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`
M3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS
M;B!D92!C;VYF:6=U<F%C:?-N("(E<R(N`$YO('-E('!U961E(&1E=&5R;6EN
M87)A(&QA(&1I<F5C8VGS;B!D92!C;W)R96\@9&5L(&1E<W1I;F%T87)I;RX`
M3F\@<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!C
M;VUP;&5T82X`3F\@<V4@<'5E9&4@=')A97(@;&$@;&ES=&$@9&4@9&ES=')I
M8G5C:?-N(&-O;7!L971A+@!.;R!S92!P=65D92!T<F%E<B!L82!L:7-T82!C
M;VUP;&5T82!D92!L:7-T87,@9&4@9&ES=')I8G5C:?-N+@!.;R!S92!P=65D
M92!C87)G87(@;&$@97-T<F%T96=I82`B)7,B+@!.;R!S92!P=65D92!C<F5A
M<B!E;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&]B=&5N97(@;&$@
M8VQA=F4@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=F5S+@!.;R!S92!P
M=65D92!A8G)I<B`B)7,B('!A<F$@97-C<FEB:7(N`$YO('-E('!U961E(&%B
M<FER("5S+@!.;R!S92!P=65D92!A8G)I<B!E;"!M\V1U;&\@9&4@=&%R96%S
M(&1E(&UA;G1E;FEM:65N=&\@)7,`3F\@<V4@<'5E9&4@86)R:7(@96P@9&ER
M96-T;W)I;R`B)7,B+@!.;R!S92!P=65D92!L;V-A;&EZ87(@96P@<V5R=FED
M;W(@3$1!4"X`3F\@<V4@<'5E9&4@;&5E<B`E<RX`3F\@<V4@<'5E9&4@<F5S
M=&%B;&5C97(@;&$@8V]N=')A<V7Q82!D96P@=7-U87)I;R!S;VQI8VET861O
M+B!087)T92!D92!L;W,@9&5T86QL97,@;R!T;V1O<RP@<V]N(&EN8V]R<F5C
M=&]S+B!0<G5E8F4@;W1R82!V97H@;R!P\VYG87-E(&5N(&-O;G1A8W1O(&-O
M;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA('!A<F$@;>%S(&EN9F]R
M;6%C:?-N+@!.;R!S92!P=65D92!O8G1E;F5R(&QA($%#3"X`3F\@<V4@<'5E
M9&4@;V)T96YE<B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B`E<P!.;R!S
M92!P=65D92!O8G1E;F5R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`
M3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S(&QI<W1A<R!D92!D:7-T<FEB=6-I
M\VXN("5S`$YO('-E('!U961E;B!O8G1E;F5R(&QA<R!C87!A8VED861E<R!D
M96P@<V5R=FED;W(`3F\@<V4@<'5E9&4@<F5S=&%U<F%R(&QA(&-O;F9I9W5R
M86-I\VXN`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@(B5S
M(BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;VYF:6=U<F%C:?-N(&1E("5S
M+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C;VYF:6=U
M<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C
M;VYF:6=U<F%C:?-N.B`E<P!.;R!S92!P=65D92!G=6%R9&%R(&5L(&=U:?-N
M(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS;B!E;CH@(B5S
M(BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;W!I82`E<R!D92!L82!C;VYF
M:6=U<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R(&5L(&%R8VAI=F\@)7,@
M9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@=71I;&EZ87(@=6YA(&1E(&QA<R!O
M<&-I;VYE<R!P87)A(')E<W1A=7)A<B!E;"!C\V1I9V\@9&4@)7,@;R!C;W!I
M87(@;6%N=6%L;65N=&4@82`E<R!E;"!C\V1I9V\@<VEG=6EE;G1E+@!.;R!S
M92!P=65D92!B=7-C87(@96X@96P@<V5R=FED;W(@3$1!4"X`3F\@<V4@<'5E
M9&4@9&5S=FEN8W5L87(@(B5S(BX`3F\@<V4@<'5E9&4@86-T=6%L:7IA<B!E
M;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@86-T=6%L:7IA<B!L82!L:7-T
M82!D92!D:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E(&5S8W)I8FER(&QA
M(&-O;F9I9W5R86-I\VX@9&4@(B5S(CH@)7,`3F\@<V4@<'5E9&4@;&]C86QI
M>F%R(&5L('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL82X@0V]M<')U96)E('%U
M92!E<W3I(&%B:65R=&\N`$YO('-E('!U961E;B!O=&]R9V%R(&%L('5S=6%R
M:6\@(B5S(B!L;W,@<VEG=6EE;G1E<R!D97)E8VAO<R!P87)A(&QA(&-A<G!E
M=&$@(B5S(CH@)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O<P!#<F5A<@!#
M<F5A<B!L:6)R971A(&1E(&1I<F5C8VEO;F5S`$-R96$@=6X@=NUN8W5L;P!#
M<F5A<B!U;F$@;G5E=F$@3&ES=&$@96XZ`$-R96%R`$-R96%R('-U8F-A<G!E
M=&%S`$-R96%D;P!0<FEV:6QE9VEO<R!D92!C<F5A9&]R`$[Z;65R;R!D92!T
M87)J971A(&1E(&-RZ61I=&\`0W)O86-I80!#=6)A`#0@1F%S97,@86-T=6%L
M97,`4V5S:6]N97,@86-T=6%L97,`2&]R82!A8W1U86P`55),(&%C='5A;`!5
M<W5A<FEO<R!A8W1U86QE<P!4:65M<&\@86-T=6%L`$-O;F1I8VGS;B!A8W1U
M86PZ(`!%<W1I;&\@86-T=6%L`%!E<G-O;F%L:7IA(&QA<R!T87)E87,@82!E
M:F5C=71A<B!A;"!I;FEC:6%R('-E<VGS;B!E;B`E<RX`0V]R=&%R`$-O<G1A
M<B!S96QE8V-I\VX`0VAI<')E`$-I<NUL:6-O("A+3TDX+5(I`$-I<NUL:6-O
M("A7:6YD;W=S+3$R-3$I`$-I<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5*0!2
M97#Z8FQI8V$@0VAE8V$`1$0`1%-.("AV96$@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO97,O<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP
M*0!$:6%R:6%M96YT90#!<E]B;VP@9&%T;W,`0V]N<W5L=&$@9&4@;&$@8F%S
M92!D92!D871O<P!&96-H80!392!H82!R96-I8FED;R!L82!F96-H80!396QE
M8V-I\VX@9&4@9F5C:&$`1.UA`$5?;&EM:6YA<B!C;VQU;6YA`$1I8VEE;6)R
M90!.^FUE<F]S(&1E8VEM86QE<P!2961U8VER('-A;F=R861O`%!O<B!O;6ES
M:?-N`$-O;&]R('!O<B!O;6ES:?-N`$ED96YT:61A9"!P;W(@;VUI<VGS;@!3
M:&5L;"!P;W(@;VUI<VGS;@!396YT:61O(&1E(&-L87-I9FEC86-I\VX@<&]R
M(&]M:7-I\VXZ`$1E9FEN:6-I;VYE<P!%;&EM:6YA<@!%;&EM:6YA<B!L:6)R
M971A(&1E(&1I<F5C8VEO;F5S`$5L:6UI;F%R(&-E;&1A`$-O;F9I<FUA8VGS
M;B!D92!E;&EM:6YA8VGS;@!%;&EM:6YA<B!G<G5P;P!%;&EM:6YA<B!R96=I
M<W1R;P!%;&EM:6YA<B!P<FEV:6QE9VEO`$5L:6UI;F%R('D@=F%C:6%R(&UE
M;G-A:F5S`$-O;7!O<G1A;6EE;G1O(&1E;"!B;W3S;B!%;&EM:6YA<B``16QI
M;6EN87(@8V5L9&$`16QI;6EN87(@8V]L=6UN80!%;&EM:6YA<B!P;&%N=&EL
M;&%S(&%L=&5R;F%T:79A<R!E>&ES=&5N=&5S`%-E(&AA('!R;V1U8VED;R!U
M;B!E<G)O<B!A;"!E;&EM:6YA<CH@*"5S*2`E<P!%;&EM:6YA<B!M96YS86IE
M<P!%;&EM:6YA<B!P<FEV:6QE9VEO<R!D92`B)7,B`+]%;&EM:6YA<B!P<FEV
M:6QE9VEO<R!P87)A("(E<R(@>2!C=6%L<75I97(@<')I=FEL96=I;R!D97-C
M96YD:65N=&4_`$5L:6UI;F%R(&9I;&$`16QI;6EN87(@:61E;G1I9&%D('-E
M;&5C8VEO;F%D80!%;&EM:6YA<B!S=6)C87)P971A<P!%;&EM:6YA(&QA(&-O
M;'5M;F$@86-T=6%L`$5L:6UI;F$@;&$@9FEL82!A8W1U86P`4V4@:&$@96QI
M;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG
M=7)A8VGS;B`B)7,B+@!.;R!S92!P=65D92!E;&EM:6YA<B!C;VYT86-T;W,N
M`%-E(&AA('!R;V1U8VED;R!U;B!E<G)O<B!A;"!E;&EM:6YA<@!(;W)A(&1E
M(&5N=')E9V$Z`$1I;F%M87)C80!$97!A<G1A;65N=&\`1&5S8V5N9&5N=&4`
M1&5S8W)I8F$@96P@<')O8FQE;6$`1&5S8W)I<&-I\VX`1&5T86QL97,@*'1A
M;6)IZ6X@96X@96P@87)C:&EV;R!D92!R96=I<W1R;R!D92!(;W)D92DZ`%-E
M(&AA;B!R96=I<W1R861O(&QO<R!D971A;&QE<R!P87)A(&5L(&%D;6EN:7-T
M<F%D;W(N`$1E<V%R<F]L;&\`4'5N=&\@9&4@8V]N9&5N<V%C:?-N`%!U;G1O
M(&1E(&-O;F1E;G-A8VGS;B!D92!L82#Z;'1I;6$@:&]R83H@`%!U;G1O(&1E
M(&-O;F1E;G-A8VGS;CH@`$1E(&EZ<75I97)D82!A(&1E<F5C:&$`1&4@9&5R
M96-H82!A(&EZ<75I97)D80!$:7)E8W1O<FEO`%9I<W5A;&EZ86-I\VX`OTUO
M<W1R87(@96X@9F]R;6%T;R!D92`R-"UH;W)A<S\`3W!C:6]N97,@9&4@5FES
M=6%L:7IA8VGS;@!-;W-T<F%R('!R;V[S<W1I8V\@9&5T86QL861O`$UO<W1R
M87(@<')O;O-S=&EC;R`H5$%&*0!&;W)M871O(&1E('9I<W5Z86QI>F%C:?-N
M`$YO=&EF:6-A8VGS;B!D92!C;VYS=6QT80!$:FEB;W5T:0!.;R!E;&EM:6YA
M<@!.;R!A8V-E9&5R(&1I<F5C=&%M96YT92!A(&UA:6YT96YA;F-E+G!H<`"_
M1&5S96$@8V]N9FER;6%R(&5L(&)O<G)A9&\@9&4@;&%S(&5N=')A9&%S/P"_
M0V]N=&EE;F4@;&$@<')I;65R82!F:6QA(&QO<R!N;VUB<F5S(&1E(&QO<R!C
M86UP;W,_(%-I(&5S(&%S[2P@<V5L96-C:6]N92!E<W1A(&-A<VEL;&$Z`$1O
M;6EN:6-A`%)E</IB;&EC82!$;VUI;FEC86YA`+].;R!D:7-P;VYE(&1E(&-U
M96YT83\@4V]L:6/M=&5L82X`1&5S8V%R9V%R`$1E<V-A<F=A<B`E<P!$97-C
M87)G87(@;&$@8V]N9FEG=7)A8VGS;B!G96YE<F%D82!C;VUO('5N(&=U:?-N
M(%!(4"X`1&5S8V%R9V%R('9#87)D`$QI<W1A(&1E<W!L96=A8FQE`$1R;V=A
M<P!#;W)R96\`0V]N=')O;&%D;W(@9&4@<&%S87)E;&$@0V]R<F5O+6$M4TU3
M('!A<F$@<')O=F5E9&]R97,@<75E('!R;W!O<F-I;VYE;B!E<W1E('-E<G9I
M8VEO+@!%4E(`16-U861O<@!-;V1I9FEC87(`36]D:69I8V%R("(E<R(`36]D
M:69I8V%R($QI8G)E=&%S(&1E(&1I<F5C8VEO;F5S`$UO9&EF:6-A<B!B;&]Q
M=64`36]D:69I8V%R(&=R=7!O`$UO9&EF:6-A<B!P<FEV:6QE9VEO`$UO9&EF
M:6-A<B!P<FEV:6QE9VEO<P!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,`
M36]D:69I8V%R(&5N=')A9&$@9&4@)7,`36]D:69I8V%R(&]P8VEO;F5S(&1E
M.@!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@(B5S(@!-;V1I9FEC87(@<')I
M=FEL96=I;W,@9&4@)7,`161U8V%C:?-N`$5G:7!T;P!%;"!386QV861O<@!%
M;&5M96YT;RXN+@!%;0!#;W)R96\`1&ER96-C:?-N(&1E(&-O<G)E;P!,87,@
M9&ER96-C:6]N97,@9&4@8V]R<F5O('1I96YE;B!Q=64@8V]I;F-I9&ER+@!#
M;W)R96\@8V]N(&-O;F9I<FUA8VGS;@!087-A<F5L82!#;W)R96\M82U335,`
M16UO=&EC;VYE<P!-96YS86IE(&5N(&)L86YC;P!297-U;'1A9&\@96X@8FQA
M;F-O+@!,:6UP:6%R('3I<FUI;F]S(&1E(&+Z<W%U961A`+]097)M:71I<B!I
M;G-E<F-I\VX@9&4@:6WA9V5N97,@9&4@;&%S($=A;&5R[6%S(&1E(&9O=&]S
M/P"_4&5R;6ET:7(@;65N^B!D92!C;VYT97AT;R!D96P@8F]T\VX@9&5R96-H
M;R!D96P@<F%T\VX_`$'Q;R!D92!T97)M:6YA8VGS;@!!9W)A;F1A<B!E9&ET
M;W(`26YT<F]D=7IC82!U;F$@<')E9W5N=&$@9&4@<V5G=7)I9&%D('%U92!S
M92!L92!F;W)M=6QA<N$@<VD@<')E8VES82!R96%J=7-T87(@;&$@8V]N=')A
M<V7Q82P@<"YE+B`GOT-UX6P@97,@96P@;F]M8G)E(&1E('-U(&UA<V-O=&$_
M)SH`26YT<F]D=7IC82!A<77M(&QA(%523"!D92!L82!I;6%G96X`26YT<F]D
M=7IC82!L87,@;&5T<F%S(&1E(&1E8F%J;SH`4V4@:&$@86-T=6%L:7IA9&\@
M;&$@96YT<F%D82!D92`E<RP@<&5R;R!N;R!S92!H82!P;V1I9&\@9W5A<F1A
M<B!E;"!A<F-H:79O(&-A<F=A9&\Z("5S`%-E(&AA(&%C='5A;&EZ861O(&QA
M(&5N=')A9&$@9&4@)7,N`$=U:6YE82!%8W5A=&]R:6%L`$5R:71R96$`17)R
M;W(`4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&%L(&'Q861I<B`E9"!C;VYT
M86-T;RAS*2!A(&QA(&QI<W1A+@!392!H82!P<F]D=6-I9&\@=6X@97)R;W(@
M86P@8?%A9&ER("5D(&1E("5D(&-O;G1A8W1O*',I('-O;&EC:71A9&\H<RD@
M82!L82!L:7-T82X`17)R;W(@86P@8W)E87(@96P@8FQO<75E.B`E<P!392!P
M<F]D=6IO('5N(&5R<F]R(&%L(&5L:6UI;F%R("5D(&-O;G1A8W1O*',I+@!3
M92!P<F]D=6IO('5N(&5R<F]R(&%L(&5L:6UI;F%R("5D(&1E("5D(&-O;G1A
M8W1O*',I('-O;&EC:71A9&\H<RDN`$5R<F]R(&%L(&5L:6UI;F%R(&%N8VQA
M(&1E('-I;F-R;VYI>F%C:?-N.B`E<P!%<G)O<B!A;"!E;&EM:6YA<B!E;"!R
M96=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;CH@)7,`17)R;W(@86P@;V)T96YE
M<B!C;VYT96YI9&]S.B`E<P!392!P<F]D=6IO('5N(&5R<F]R(&%L(&5L:6UI
M;F%R("5D(&-O;G1A8W1O*',I(&1E(&QA(&QI<W1A+@!392!P<F]D=6IO('5N
M(&5R<F\@86P@96QI;6EN87(@)60@9&4@)60@8V]N=&%C=&\H<RD@<V]L:6-I
M=&%D;RAS*2!D92!L82!L:7-T82X`4V4@<')O9'5J;R!U;B!E<G)O<B!B=7-C
M86YD;R!E;B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S.B`E<P!%<G)O<B!A
M;"!A8W1U86QI>F%R(&QA(&-O;G1R87-E\6$Z("5S`$5R<F]R(&-O;B!E;"!M
M96YS86IE(&1E(&-O<G)E;RX`17)R;W(@86P@97-C<FEB:7(@(B5S(BX`17-T
M;VYI80!%=&EO<.UA`,ET;FEC;P!%=7)O<&$`0V%D82`Q-2!M:6YU=&]S`$-A
M9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI;G5T;W,`
M0V%D82!I;FEC:6\@9&4@<V5S:?-N`$-A9&$@;65D:6$@:&]R80!#861A(&UI
M;G5T;P!686QO<F5S(&1E(&5J96UP;&\Z`$5J96-U=&%R`$5X<&%N9&ER`$UO
M<W1R87(@8F%R<F$@;&%T97)A;`!S92!E<W!E<F%B82`G*2<`4V4@97-P97)A
M8F$@=6YA(/IN:6-A('!A;&%B<F$@;R!U;B!TZ7)M:6YO(&1E(&+Z<W%U961A
M(&5N=')E8V]M:6QL861O`$9E8VAA(&1E('9E;F-I;6EE;G1O`$5X<&]N96YT
M90!%>'!O<G1A<@!%>'!O<G1A<B!L:6)R971A(&1E(&1I<F5C8VEO;F5S`$5X
M<&]R=&%R('/S;&\@;&]S(&-O;G1A8W1O<R!S96QE8V-I;VYA9&]S+@!%>'!O
M<G1A<B!L87,@<VEG=6EE;G1E<R!L:6)R971A<R!D92!D:7)E8V-I;VYE<R!C
M;VUP;&5T87,N`$-O;&]R(&1E(&QE=')A`$-A<F=A<B!L82!C;VYF:6=U<F%C
M:?-N('!O<B!&5%``1F%L;&\@86P@=')A97(@;&%S('!R969E<F5N8VEA<RX`
M1F%L;&\@86P@86-C961E<B!A(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,Z
M("5S`$9A;&QO(&%L(&'Q861I<B`E<R!A("5S.B`E<P!&86QL;R!A;"!V:7-U
M86QI>F%R(&5L(&QI<W1A9&\`1F%L;&\@86P@=FES=6%L:7IA<B!E;"!D:7)E
M8W1O<FEO`$9A;&QO(&%L(&-A;6)I87(@96P@;F]M8G)E.B`H)7,I("5S.R!!
M;G1I9W5O($1.(#T@)7,L($YU979O($1.(#T@)7,L(%)A:7H@/2`E<P!);F-A
M<&%Z(&1E(&-O;F5C=&%R<V4@86P@<V5R=FED;W(@3$1!4"X`26YC87!A>B!D
M92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R(%--0BX`1F%L;&\@86P@8V]P:6%R
M(&1E("(E<R(N`$9A;&QO(&%L(&-O<&EA<B!A("(E<R(N`$9A;&QO(&%L(&-R
M96%R('5N82!C;VYE>&GS;B!305-,`$9A;&QO(&%L(&QO8V%L:7IA<B!E;"!O
M8FIE8W1O(&$@8?%A9&ER.B`E<P!&86QL;R!A;"!T<F%S;&%D87(@(B5S(BX`
M1F%L;&\@86P@<F5C=7!E<F%R.B`E<P!.;R!S92!P=65D92!B=7-C87(@96X@
M;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<P!&86QL;R!A;"!B=7-C87(@96X@
M96P@9&ER96-T;W)I;SH@)7,`1&5S<&5J861O`$ES;&%S($UA;'9I;F%S("A&
M86QK;&%N9"D`27-L87,@1F%R;V4`17)R;W(@:7)R96-U<&5R86)L93H`1F%X
M`$9A>&5S`$9E8G)E<F\`4V4@<VEE;G1E(&-O;6\`4V4@<VEE;G1E(&-O;6\Z
M(`!0;V-A<R!L;'5V:6%S`$5S8V%S;R!A9W5A8V5R;R!D92!N:65V90!-871R
M:7H@9&4@8V%M<&]S`$-!4%1#2$$@9&4@1FEG;&5T`$QE=')A(&1E($9I9VQE
M=`!&:6II`$%R8VAI=F\`3KH@9&4@87)C:&EV;W,Z("5S(&%R8VAI=F\`3KH@
M9&4@87)C:&EV;W,Z("5S(&%R8VAI=F]S`$%R8VAI=F]S`$YO;6)R92!D92!A
M<F-H:79O`%-E;&5C8VGS;B!D92!A<F-H:79O`$-A<F=A<B!A<F-H:79O`$QA
M(&-A<F=A(&1E(&%R8VAI=F]S(&YO(&5S=.$@<V]P;W)T861A+@!!<F-H:79O
M<P!&:6QT<F]S`$5N8V]N=')A<@!497)M:6YA<@!&:6YL86YD:6$`0W5A<G1O
M(&-R96-I96YT90!0<FEM97(@;F]M8G)E`$-U87)T;R!C<F5C:65N=&4`4F%Z
M\VX@9FEJ80!6;VQT96%R`$1I<W!O<VEC:?-N`$YI96)L80!,82!C87)P971A
M("5S(&YO(&5X:7-T92X`0V]L;W(@9&4@;&5T<F$`0V]M:61A`%!A<F$@;F%V
M96=A9&]R97,@<75E(&YO(&%D;6ET86X@:6WA9V5N97,`4')O;O-S=&EC;R`H
M5$%&*0!$[6%S(&1E;"!P<F]N\W-T:6-O("AT96YG82!E;B!C=65N=&$@<75E
M(&5L('!R;V[S<W1I8V\@9F%C:6QI=&%D;R!I;F-L=7EE('1A;G1O(&5L(&3M
M82!C;VUO(&QA(&YO8VAE.R!U;B!N^FUE<F\@9W)A;F1E('-E('1R861U8VER
MX2!E;B!U;B!B;&]Q=64@;75Y(&%N8VAO*0"_2&$@;VQV:61A9&\@;&$@8V]N
M=')A<V7Q83\`1F]R;75L87)I;W,`1F]R='5N80!4:7!O(&1E(&9O<G1U;F$`
M1F]R='5N87,`1F]R='5N87,@,@!&;W)O<P!2965N=NUO<P!6:64`1G)A;65S
M`$9R86YC:6$`1G)A;F-I82P@365T<F]P;VQI=&%N80!54DP@9&4@=&EE;7!O
M(&1I<W!O;FEB;&4`1W5A>6%N82!F<F%N8V5S80!0;VQI;F5S:6$@9G)A;F-E
M<V$`5&5R<FET;W)I;W,@9G)A;F-E<V5S(&1E;"!S=7(`1&4`1&5L(`!$97-C
M<FEP8VGS;B!C;VUP;&5T80!,=6YA(&QL96YA`$YO;6)R92!C;VUP;&5T;P!'
M86+S;@!'86QE<NUA(&1E(&QA('%U92!O8G1E;F5R(&QA(&EM86=E;@!'86QE
M<NUA.@!'86UB:6$`1V5N97)A<B!C;VYF:6=U<F%C:?-N(&1E("5S`$/S9&EG
M;R!G96YE<F%D;P!'96]R9VEA`$%L96UA;FEA`$=H86YA`$=I8G)A;'1A<@!.
M;VUB<F4@:6YD:6-A9&\`3&EB<F5T82!D92!D:7)E8V-I;VYE<R!G;&]B86P`
M3W!C:6]N97,@9VQO8F%L97,`27(`1V]E9&5L`$UA<&%S(&1E($=O;V=L90!"
M^G-Q=65D82!E;B!';V]G;&4`17-C86QA(&1E(&=R:7-E<P!'<F5C:6$`1W)I
M96=O("A)4T\M.#@U.2TW*0!'<F]E;FQA;F1I80!'<F%N861A`$=R=7!O`$%D
M;6EN:7-T<F%C:?-N(&1E(&=R=7!O<P!,;W,@;F]M8G)E<R!D92!G<G5P;R!N
M;R!P=65D96X@9&5J87)S92!E;B!B;&%N8V\`1W)O=7!?;&1A<#H@3F\@<V4@
M<'5E9&4@8?%A9&ER(&5L(&=R=7!O("5S+B#)<W1O(&5S(&QO('%U92!D:6IO
M(&5L('-E<G9I9&]R.B``1W)O=7!?;&1A<#H@26YC87!A>B!D92!E;&EM:6YA
M<B!E;"!G<G5P;R`E<P!'<F]U<%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A;&EZ
M87(@96P@9W)U<&\@)7,`1W)U<&]S`$=U861A;'5P90!'=6%M`$=U871E;6%L
M80!'=65R;F5S97D`4')I=FEL96=I;W,@9&4@:6YV:71A9&\`3"X@:6YV:71A
M9&]S`$=U:6YE80!'=6EN96$M0FES<V%U`$=U87EA;F$`2%1-3`!(5$U,('-E
M(&YI96=A(&-O8F%R9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM82!C96QD
M82!D92!L82!F:6QA+@!(5$U,07)E82!S92!N:65G82!C;V)A<F1E;65N=&4@
M82!E;&EM:6YA<B!L82#Z;'1I;6$@8V]L=6UN82!D92!L82!T86)L82X`2%1-
M3"!S92!N:65G82!C;V)A<F1E;65N=&4@82!E;&EM:6YA<B!L82#Z;'1I;6$@
M9FEL82!D92!L82!T86)L82X`3F\@<V4@96YC;VYT<O,@;&$@875T96YT:69I
M8V%C:?-N($A45%`N`$AA:73M`$%L9V]R:6UO($AA<V@`3F5B;&EN80!#86)E
M8V5R80!#86)E8V5R87,`27-L82!(96%R9"!E($ES;&%S($UC1&]N86QD`%1O
M<FUE;G1A('1R;W!I8V%L(&EN=&5N<V$`2&5B<F5O("A)4T\M.#@U.2TX+4DI
M`$%L='5R80!!>75D80!!>75D82!D96P@961I=&]R`$%Y=61A;G1E`$AE;6ES
M9F5R:6\`07%U[2!T:65N92!E;"!C;VUI96YZ;R!D96P@87)C:&EV;SH`06QT
M80!?26YI8VEO`%-A;G1A(%-E9&4@*$-I=61A9"U%<W1A9&\@9&5L(%9A=&EC
M86YO*0!);FEC:6\`1&]M:6-I;&EO`$-I=61A9"!D96P@9&]M:6-I;&EO`%!A
M:7,@9&5L(&1O;6EC:6QI;P!$:7)E8W1O<FEO('!E<G-O;F%L`%1E;.EF;VYO
M('!A<G1I8W5L87(`0_-D:6=O('!O<W1A;"!D96P@9&]M:6-I;&EO`$5S=&%D
M;R]0<F]V:6YC:6$@9&5L(&1O;6EC:6QI;P!$:7)E8V-I\VX@9&5L(&1O;6EC
M:6QI;P!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%-E
M(&AA;B!E;F-O;G1R861O(&1A=&]S(%A-3"`E<R!N;R!VX6QI9&]S(&5N(&5L
M(&UE;G-A:F4@)7,`2&]R9&4O2V]L86(Z($YI;F?Z;B!M96YS86IE(&-O<G)E
M<W!O;F1E(&%L(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@3F\@<V4@96YC;VYT
M<O,@=6X@;V)J971O(&1E('1I<&\@)7,@96X@96P@;65N<V%J92`E<P!(;W)D
M92]+;VQA8CH@4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@)7,@(B5S
M(@!(;W)D92]+;VQA8CH@16P@;6]T;W(@9&4@:6YT96=R86-I\VX@<')E8VES
M82!D92!L82!E>'1E;G-I\VX@4$A0("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!)
M;F-A<&%Z(&1E(&-R96%R(&YU979O(.%R8F]L(%A-3"!D96P@;V)J971O("5S
M`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E(&5L:6UI;F%R("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E(&]B=&5N97(@240@34E-12!D92!L
M82!P87)T92!D92!T:7!O("5S`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E('-I
M;F-R;VYI>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E
M('-I;F-R;VYI>F%R(&5L96UE;G1O<R!C;VUP87)T:61O<SH@)7,`2&]R9&4O
M2V]L86(Z($5L96UE;G1O(&-O;7!A<G1I9&\@9&5S8V]N;V-I9&\@(B5S(@!,
M[6YE82!H;W)I>F]N=&%L`$UA<F=E;B!H;W)I>F]N=&%L`$AO<FEZ;VYT86PZ
M`+]#\VUO(&QL96?S(&AA<W1A(&%Q=>T_("BA0V]M=6[M<75E;&\L('!O<B!F
M879O<B$I`+]#=6%N=&%S(&-O;'5M;F%S(&1E<V5A(&-O;6)I;F%R/P"_0W7A
M;G1O<R!C86UP;W,@*&-O;'5M;F%S*2!H87D_`+]#=6%N=&%S(&9I;&%S(&1E
M<V5A(&-O;6)I;F%R/P!(=6UE9&%D`$AU;65D860Z(`!(=6UO<FES=&%S`$AU
M;F=R[6$`2&$@9F%L;&%D;R!L82!C<F5A8VGS;B!D96P@8G5Z\VX@24U!4#H@
M)7,`2&$@9F%L;&%D;R!L82!E;&EM:6YA8VGS;B!D96P@8G5Z\VX@24U!4#H@
M)7,`2&$@9F%L;&%D;R!L82!C<F5A8VGS;B!D92!E<W!A8VEO(&%S:6=N861O
M(&1E;"!B=7KS;B!)34%0.B`E<P!)35-0`$%D;6EN:7-T<F%C:?-N(&1E(&QI
M8G)E=&$@9&4@9&ER96-C:6]N97,@24U34`!$:7)E8V-I\VX@25``3&$@9&ER
M96-C:?-N($E0(&YO(&5S=.$@9&ES<&]N:6)L92X`3&$@9&ER96-C:?-N($E0
M(&YO(&5S=.$@96YT<F4@8FQO<75E<R!#2412('!E<FUI=&ED;W,N`%9I;VQA
M8VGS;B!L;V-K9&]W;B!)4"X`25]N<V5R=&%R(&9I;&$@96YC:6UA`$ES;&%N
M9&EA`%/S;&\@:6-O;F]S`$EC;VYO<R!D92`E<P!)8V]N;W,@8V]N('1E>'1O
M`$YO;6)R92!D92!L82!I9&5N=&ED860Z`%-I(&YO('-E(&UU97-T<F$@8V]R
M<F5C=&%M96YT92P@)7,@<&%R82!A8G)I<FQO(&5N('5N82!V96YT86YA(&YU
M979A+@!3:2!N;R!V92!N:6YG^FX@:6-O;F\@;65D:6%N=&4@26YT97)N970@
M17AP;&]R97(L('!U961E('1E;F5R('%U92!A8W1I=F%R(&5S=&$@8V%S:6QL
M82!P87)A(&1E<V%C=&EV87(@;&$@=')A;G-P87)E;F-I82!03D<N`%-I('9E
M(&5S=&4@;65N<V%J92!S:6X@;FEN9W5N82!I;6%G96XL(&QA(&EM86=E;B!Q
M=64@<75I97)E(&-A<F=A<B!N;R!S92!P=65D92!M;W-T<F%R(&5N('-U(&YA
M=F5G861O<BX`5FES=&$@<')E=FEA.@!54DP@9&4@;&$@:6UA9V5N`%523"!D
M92!L82!I;6%G96XZ`$EM86=E;B!D92!L82!G86QE<NUA`$EM86=E;B!D92!L
M82!G86QE<NUA.@!392!H82!C87)G861O(&QA(&EM86=E;@!);>%G96YE<P!)
M;7!O<G1A<B!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B!087-O("5D`$EM<&]R
M=&%R+"!P87-O("5D`$EM<&]R=&%R+T5X<&]R=&%R(&QI8G)E=&%S(&1E(&1I
M<F5C8VEO;F5S`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R=&%D
M;W,Z`$EN7W-E<G1A<B!F:6QA(&1E8F%J;P!392!H82!I;F1I8V%D;R!U;B!C
M\V1I9V\@9&4@86-C:?-N(&EN8V]R<F5C=&\N`$YO;6)R92!D92!U<W5A<FEO
M('DO;R!C;VYT<F%S9?%A(&EN8V]R<F5C=&]S+@!.;VUB<F4@9&4@=7-U87)I
M;R!O(&1I<F5C8VGS;B!A;'1E<FYA=&EV82!I;F-O<G)E8W1O<RX@5G5E;'9A
M(&$@:6YT96YT87)L;R!O('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D
M;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<&%R82!MX7,@:6YF;W)M86-I\VXN
M`$%U;65N=&%R('-A;F=R861O`$EN9&EA`%5S=6%R:6]S(&EN9&EV:61U86QE
M<P!);F1O;F5S:6$`26YF;W)M86-I\VX`26YF;W)M86-I\VX`3&$@:6YF;W)M
M86-I\VX@>6$@;F\@97-TX2!D:7-P;VYI8FQE+@!);G-E<G1A<B!C7V]L=6UN
M82!D971RX7,`26YS97)T87(@:6UA9V5N`$EN<V5R=&%R('1A8FQA`$EN<V5R
M=&%R(';M;F-U;&\@5V5B`$EN<V5R=&%R(%]C;VQU;6YA(&1E;&%N=&4`26YS
M97)T82!U;F$@;G5E=F$@8V]L=6UN82!D971RX7,@9&4@;&$@86-T=6%L`$EN
M<V5R=&$@=6YA(&YU979A(&-O;'5M;F$@9&5L86YT92!D92!L82!A8W1U86P`
M26YS97)T82!U;F$@9FEL82!N=65V82!D96)A:F\@9&4@;&$@86-T=6%L`$EN
M<V5R=&$@=6YA(&9I;&$@;G5E=F$@96YC:6UA(&1E(&QA(&%C='5A;`!);G-E
M<G1A('5N('#A<G)A9F\@=')A<R!E;"!N;V1O(&%C='5A;`!);G-E<G1A('5N
M('#A<G)A9F\@86YT97,@9&5L(&YO9&\@86-T=6%L`$EN<V5R=&%R('!L86YT
M:6QL82!A;'1E<FYA=&EV80!);G-E<G1A<B!U;F$@9&ER96-C:?-N(&1E(&-O
M<G)E;R!E;B!L82!Q=64@<F5C:6)I<B!L82!C;VYT<F%S9?%A.@!);G-E<G1A
M<B!C96QD82!D971RX7,`26YS97)T87(@8V5L9&$@86YT97,`26YS97)T87(@
M8V]L=6UN82!D971RX7,`26YS97)T87(@8V]L=6UN82!A;G1E<P!);G-E<G1A
M<B!M96YS86IE<P!);G-E<G1A<B!PX7)R869O(&1E='+A<P!);G-E<G1A<B!P
MX7)R869O(&%N=&5S`$EN<V5R=&%R(&9I;&$@9&5B86IO`$EN<V5R=&%R(&9I
M;&$@96YC:6UA`$EN<V5R=&%R(&QA(')E<W!U97-T82!N96-E<V%R:6$@82!L
M82!P<F5G=6YT82!D92!S96=U<FED860Z`$EN<V5R=&%R+TUO9&EF:6-A<B!I
M;6%G96X`26YS97)T87(O36]D:69I8V%R(';M;F-U;&\`4V%L9&\@:6YS=69I
M8VEE;G1E('!A<F$@96YV:6%R(&$@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N
M+@!386QD;R!I;G-U9FEC:65N=&4N`$5N=&5R;P!,:7-T82!D92!E;G1E<F]S
M`$E$(&YO(';A;&ED;P!51$@@*$-A8F5C97)A(&1E($1A=&]S(&1E(%5S=6%R
M:6\I(&YO(';A;&ED82X`1&%T;W,@6DE0(&YO(';A;&ED;W,`3&$@;&EB<F5T
M82!D92!D:7)E8V-I;VYE<R!N;R!E<R!VX6QI9&$N`$%P;&EC86-I\VX@;F\@
M=N%L:61A+@!)1"!D92!L;W1E(&YO(';A;&ED;RX`4V4@:&%N(&5N=FEA9&\@
M9&%T;W,@;F\@=N%L:61O<RX`1&ER96-C:?-N(&1E(&-O<G)E;R!N;R!VX6QI
M9&$N`$QA(&1I<F5C8VGS;B!D92!C;W)R96\@;F\@97,@=N%L:61A+@!%;G1R
M861A(&YO(';A;&ED82X`1F]R;6%T;R!D92!A<F-H:79O(&YO(';A;&ED;P!3
M92!H82!I;F1I8V%D;R!U;F$@8VQA=F4@;F\@=N%L:61A+@!#;&%V92!D92!L
M:6-E;F-I82!N;R!VX6QI9&$N`%-E(&AA(&EN9&EC861O('5N82!U8FEC86-I
M\VX@;F\@=N%L:61A+@!M<V=?='EP92!N;R!VX6QI9&\N`$YO;6)R92!N;R!V
MX6QI9&\`3V)J96-T260@;F\@=N%L:61O`&%P:5]I9"!N;R!VX6QI9&\@;R!D
M97-A<&%R96-I9&\N`%!A<N%M971R;W,@;F\@=N%L:61O<R!O(&1E<V%P87)E
M8VED;W,N`%!R:79I;&5G:6\@9&5L('!A9')E(&YO(';A;&ED;W,N`$E$(&1E
M(&%S;V-I861O(&YO(';A;&ED;RX`0_-D:6=O(&1E('!R;V1U8W1O(&YO(';A
M;&ED;RX`4')O=&]C;VQO(&YO(';A;&ED;RX`1&5S=&EN871A<FEO(&YO(';A
M;&ED;SH@(B5S(@!/8FIE=&\@8V]M<&%R=&ED;R!N;R!VX6QI9&\N`$1I<F5C
M8VGS;B!D96P@<F5M:71E;G1E(&YO(';A;&ED80!$871O<R!U;FEC;V1E(&YO
M(';A;&ED;W,N`$EN=F5N=&%R:6\`26YV97)T:7(@<V5L96-C:?-N`$ERX6XL
M(%)E</IB;&EC82!)<VSA;6EC82!D90!)<F%Q`$ER;&%N9&$`27-L82!D92!-
M86X`0F]R<F%S8V%S(&%I<VQA9&%S`$ES<F%E;`!%;6ES;W(`0W5R<VEV80!)
M=&%L:6$`2F%M86EC80!%;F5R;P!*87#S;@!*87!O;NES("A)4T\M,C`R,BU*
M4"D`2F5R<V5Y`$IO<F3A;@!*=6QI;P!*=6YI;P!*=7-T:69I8V%R`$%L:6YE
M87(@86P@8V5N=')O`$IU<W1I9FEC87(`06QI;F5A<B!A(&QA(&EZ<75I97)D
M80!!;&EN96%R(&$@;&$@9&5R96-H80!+87IA:VAS=&%N`+]#;VYS97)V87(@
M96P@;W)I9VEN86P_`$ME;GEA`$5L('-E<G9I9&]R($ME<F)E<F]S(&AA(')E
M8VAA>F%D;R!L82!A=71E;G1I9FEC86-I\VXN`$YO=F%T;W,@9&5L($ME<FYE
M;`!#<F5A8VGS;B!D92!C;&%V90!(=65L;&$@9&EG:71A;"!D92!L82!C;&%V
M90!486UA\6\@9&4@8VQA=F4`5&EP;R!D92!C;&%V90!5<V\@9&4@;&$@8VQA
M=F4Z`$QA(&-L879E('EA(&5X:7-T92!E;B!E;"!S97)V:61O<B!D92!C;&%V
M97,@</IB;&EC;RX`3FGQ;W,`2VER:6)A=&D`0V]R96$L(%)E</IB;&EC82!0
M;W!U;&%R($1E;6]C<N%T:6-A(&1E`$-O<F5A+"!297#Z8FQI8V$@9&4`0V]R
M96%N;R`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!392!P<F5C:7-A('-O
M<&]R=&4@3$1!4"!P97)O(&5L(&WS9'5L;R!,1$%0(&YO(&5S=.$@9&ES<&]N
M:6)L92!O(&-A<F=A9&\N`%]$:7-T<FEB=6-I\VX`261I;VUA`$QA;RP@4F5P
M^F)L:6-A($1E;6]C<N%T:6-A(%!O<'5L87(`0W5A<G1O(&UE;F=U86YT90#:
M;'1I;6$@;6]D:69I8V%C:?-N`-IL=&EM;R!N;VUB<F4`VFQT:6UO(&-A;6)I
M;R!D92!C;VYT<F%S9?%A`$-U87)T;R!M96YG=6%N=&4`VFQT:6UA(&%C='5A
M;&EZ86-I\VXZ`-IL=&EM82!S97-I\VXZ("5S`-IL=&EM82!S97-I\VXZ("5S
M(&1E<V1E("5S`-IL=&EM82!S97-I\VXZ($YU;F-A`$QA='9I80!,97EE<P!$
M:7-T<FEB=6-I\VX`1&5J87(@96X@8FQA;F-O('!A<F$@96QI;6EN87(@96P@
M8F]R9&4`3&5B86YO;@!)>G%U:65R9&$`0V%B96-E<F$@:7IQ=6EE<F1A`%9A
M;&]R97,@9&4@;&$@:7IQ=6EE<F1A`$QE<V]T:&\`3FEV96P`3&EB97)I80!,
M:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG97)A(&QL
M;W9I>FYA`$QL=79I82!L:6=E<F$`3&QU=FEA(&QI9V5R82!M871U=&EN80!,
M;'5V:6$@;&EG97)A('9E<W!E<G1I;F$`06=U86-E<F\@;&EG97)O`$QL=79I
M87,@>2!T<G5E;F]S`$YE=F%D82!S=6%V90!,:6=E<F\@86=U86-E<F\@9&4@
M;FEE=F4`0VAA<V-A<G)I;&QO`%;M;F-U;&\`16P@=NUN8W5L;R!A<'5N=&$@
M83H`5FEN8W5L87(@9&ER96-C:?-N(&1E(&-O<G)E;R!A(&QA('#A9VEN82!D
M92!C;VUP;W-I8VGS;B!A;"!M;W-T<F%R`%;M;F-U;&]S`$-O;VMI92!,:6YU
M>`!,:7-T80!,:7-T87(@+2!E;"!U<W5A<FEO('!U961E(&5X86UI;F%R(&QA
M(&-A<G!E=&$`3&ES=&%R(&)A<V5S(&1E(&1A=&]S`$QI<W1A<B!T96UA<R!D
M92!A>75D80!,:7-T87(@=&%B;&%S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``
M3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,
M:7-T+55N<W5B<V-R:6)E`$AA(&9A;&QA9&\@96P@;&ES=&%D;R!D92!L87,@
M<V5S:6]N97,Z("5S`$AA(&9A;&QA9&\@96P@;&ES=&%D;R!D92!U<W5A<FEO
M<SH@)7,`16P@;&ES=&%D;R!D92!U<W5A<FEO<R!E<W3A(&1E<VAA8FEL:71A
M9&\N`$QI=&5R871U<F$`3&ET=6%N:6$`3&5Y96YD;RXN+@!(;W)A(&QO8V%L
M.B``261I;VUA('D@:&]R80!58FEC86-I\VX`26YI8VEA<B!S97-I\VX`4F5G
M:7-T<F\@9&4@;&%S('-E<VEO;F5S(&1E('-I;F-R;VYI>F%C:?-N(&%N=&5R
M:6]R97,`4V%L:7(`26YI8VEA<B!S97-I\VX`5&%R96%S(&1E(&EN:6-I;R!D
M92!S97-I\VX`1F%L;/,@96P@:6YI8VEO(&1E('-E<VGS;B!P;W)Q=64@:6YT
M<F]D=6IO(&EN8V]R<F5C=&%M96YT92!S=2!N;VUB<F4@9&4@=7-U87)I;R!O
M(&-O;G1R87-E\6$N`$9A;&SS(&5L(&EN:6-I;R!D92!S97-I\VXN`%1E>'1O
M(&-O;7!L971O`$%M;W(`0F%J80!!;&9A8F5T;R!G<FEE9V\@96X@;6EN^G-C
M+@!!;&9A8F5T;R!L871I;F\@96X@;6EN^G-C+@!.^FUE<F]S(')O;6%N;W,@
M96X@;6EN^G-C+@!,=7AE;6)U<F=O`$U-`$U/5$0`16P@861J=6YT;R!-4RU4
M3D5&(&YO(&-O;G1E;NUA(&1A=&]S+@!-4T<`36%C86\`36%C961O;FEA+"!!
M;G1I9W5A(%)E</IB;&EC82!9=6=O<VQA=F$@9&4`36%D86=A<V-A<@!-86=I
M80!#;W)R96\`061M+B!C;W)R96\`0W)E87(@7W;M;F-U;&\N+BX`36%L87=I
M`$UA;&%S:6$`36%L9&EV87,`36%L:0!-86QT80!'97-T:6]N82!L82!L:7-T
M82!D92!C871E9V]R[6%S(&-O;B!L82!Q=64@971I<75E=&%R(&5L96UE;G1O
M<R!Y(&QO<R!C;VQO<F5S(&%S;V-I861O<R!A(&1I8VAA<R!C871E9V]R[6%S
M+@!-87!A(&UA<#(T`$UA<&$@;6%P<75E<W0`0V]R<F5S<&]N9&5N8VEA<R!A
M;&UA8V5N861A<RX`36%R>F\`36%R9V5N`$UA<F-A<B!C;VX@;&%S(&)A;F1E
M<F%S(&1E($QE[61O+U-I;B!L965R`$UA<F-A<B!C;VX@;W1R87(@8F%N9&5R
M87,@*'`N92X@26UP;W)T86YT92]297-P;VYD:61O*0!)<VQA<R!-87)S:&%L
M;`!-87)T:6YI8V$`0V]I;F-I9&5N=&4`0V%M<&]S(&-O:6YC:61E;G1E<P!-
M875R:71A;FEA`$UA=7)I8VEO`%-A;&1O(&WA>&EM;R!P97)M:71I9&\N`%-E
M(&AA('-O8G)E<&%S861O(&5L(&[Z;65R;R!MX7AI;6\@9&4@<&%R=&5S(&1E
M(&UE;G-A:F4N`%1E;7`N(&WA>&EM82#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M
M<"X@;>%X:6UA(/IL=&EM87,@-B!H;W)A<SH@`$[Z;65R;R!MX7AI;6\@9&4@
M0V]N=&%C=&]S`$[Z;65R;R!MX7AI;6\@9&4@8FQO<75E<R!D96P@<&]R=&%L
M`$QO;F=I='5D(&WA>&EM80!.^FUE<F\@;>%X:6UO(&1E('#A9VEN87,`36%Y
M;P!-87EO='1E`$UE9&EC:6YA`$UI96UB<F]S`$QI<W1A(&1E(&UE;OH`1F]R
M;6%T;R!D96P@;65N^CH`0V]M8FEN87(@8V5L9&%S`$UE;G-A:F4`4V4@:&$@
M8V]M<')O8F%D;R!C;W)R96-T86UE;G1E(&5L(&UE;G-A:F4@<&5R;R!N;R!S
M92!P=65D92!V97)I9FEC87(@96P@8V5R=&EF:6-A9&\@9&5L(&9I<FUA;G1E
M+@!-96YS86IE(&-A9'5C861O+@!4:7!O(&1E(&UE;G-A:F4`5&EE;7!O(&1E
M($UE=&%R`$)L;W%U92!-971A<B!N;R!D:7-P;VYI8FQE+@!";&]Q=64@365T
M87(@;F\@9&ES<&]N:6)L92X@4V4@:&%N(')E9VES=')A9&\@;&]S(&1E=&%L
M;&5S('!A<F$@96P@861M:6YI<W1R861O<BX`3F\@97-TX2!C;VYE8W1A9&$@
M;&$@365T87)$0@!-Z71O9&\`16P@;>ET;V1O("(E<R(@;F\@97-TX2!D969I
M;FED;P!-Z71O9&\@;F\@9&5F:6YI9&\N($WI=&]D;R!L;&%M861O.B`E<P!-
MZ71R:6-O`$WI:FEC;P!-:6-R;VYE<VEA+"!%<W1A9&]S($9E9&5R861O<R!D
M90!%;B!M961I;P!4:7!O($UI;64`5&5M<"X@;>UN+B!L87,@^FQT:6UA<R`R
M-"!H;W)A<SH@`%1E;7`N(&WM;BX@;&%S(/IL=&EM87,@-B!H;W)A<SH@`%1O
M9&%V[6$@;F\@:&$@97AP:7)A9&\@;&$@86YT:6?\961A9"!M[6YI;6$@9&4@
M;&$@8V]N=')A<V7Q80!2969L96IA<@!-:7-C96SA;F5A`$9A;'1A($1.(&5N
M(&QA(&-O;F9I9W5R86-I\VX@;W)I9V5N(&1E($Q$05`N`%!A<75E=&4@4$5!
M4B!(5%107U)E<75E<W0@9&5S87!A<F5C:61O+@!&86QT82!L82!C;VYF:6=U
M<F%C:?-N+B!4:65N92!Q=64@9V5N97)A<FQA(&%H;W)A('-I(&1E<V5A('5T
M:6QI>F%R(&5S=&$@87!L:6-A8VGS;BX`240@9&4@;65N<V%J92!D97-A<&%R
M96-I9&\N`%!A<75E=&4@4$5!4B!-86EL(&1E<V%P87)E8VED;RX`240@9&4@
M<V5S:?-N(&1E<V%P87)E8VED;RX`3'5N`$-O<G)E;R!M\W9I;`!496SI9F]N
M;R!M\W9I;`!-;V1E<F%D;P!392!H82!M;V1I9FEC861O(&QA(&9E8VAA`$UO
M9&EF:6-A<B!54DP`2&$@9F%L;&%D;R!L82!M;V1I9FEC86-I\VXZ("@E<RD@
M)7,`3?-D=6QO`$UO;&1A=FEA+"!297#Z8FQI8V$@9&4`3?-N86-O`$UO;F=O
M;&EA`$UE<R!Y(&'Q;P!-96YS=6%L;65N=&4`36]N='-E<G)A=`!&87-E<R!D
M92!L82!L=6YA`%-E(&AA;B!E;F-O;G1R861O(&WA<R!C86UP;W,@96X@;&$@
M;.UN96$@)60@<75E(&QO<R`E9"!E<W!E<F%D;W,N`%-E(&AA(&5N8V]N=')A
M9&\@;>%S(&1E(#$@96YT<F%D80!-87)R=65C;W,`1G5N9&%M96YT86QM96YT
M92!D97-P96IA9&\`1G5N9&%M96YT86QM96YT92!N=6)O<V\`1G5N9&%M96YT
M86QM96YT92!S;VQE861O`%1R87-L861A<@!$97-P;&%Z87(@:&%C:6$@86)A
M:F\`1&5S<&QA>F%R(&$@;&$@:7IQ=6EE<F1A`$1E<W!L87IA<B!A(&QA(&1E
M<F5C:&$`1&5S<&QA>F%R(&AA8VEA(&%R<FEB80!$97-P;&%Z87(@:&%C:6$@
M86)A:F\`1&5S<&QA>F%R(&$@;&$@:7IQ=6EE<F1A`$1E<W!L87IA<B!A(&QA
M(&1E<F5C:&$`1&5S<&QA>F%R(&AA8VEA(&%R<FEB80!-;WIA;6)I<75E`$QI
M8G)E=&$@9&4@9&ER96-C:6]N97,@375L8F5R<GD`3&ES=&%S(&1E<W!L96=A
M8FQE<R!M=6QT:2UN:79E;`!-87!A(%5+(&WZ;'1I<&QE`%9A<FEA<R!P97)S
M;VYA<R!C;VX@;&$@9&ER96-C:?-N(%LE<UT@<&5R;R!T;V1A=NUA(&YO(&5X
M:7-T92!N:6YG=6YA(&-O;B!E;"!N;VUB<F4@6R5S70!396QE8V-I\VX@;?IL
M=&EP;&4`261E;G1I9&%D`$UI(&ED96YT:61A9`!-:2!L:6)R971A`$UI<R!L
M:6)R971A<P!-:2!P;W)T86P`1&ES=')I8G5C:?-N(&1E(&UI('!O<G1A;`!-
M>6%N;6%R`$Y/+"!.3R!E<W1O>2!D92!A8W5E<F1O`$YO;6)R90!&;W)M871O
M(&1E(&YO;6)R90!.86UI8FEA`$YA=7)U`$YE<&%L`$1I<F5C=&]R:6\@;6EE
M;6)R;R!D92!.971C96YT97(`2&]L86YD80!!;G1I;&QA<R!(;VQA;F1E<V%S
M`%523"!B87-E(&1E($YE='-C87!E`%523"!D92!A;G5L86-I\VX@9&4@0T$@
M9&4@3F5T<V-A<&4`55),(&1E('!O;.UT:6-A<R!D92!#02!D92!.971S8V%P
M90!54DP@9&4@<F5N;W9A8VGS;B!D92!.971S8V%P90!54DP@9&4@86YU;&%C
M:?-N(&1E($YE='-C87!E`$YO;6)R92!D92!S97)V:61O<B!34TP@9&4@3F5T
M<V-A<&4`0V]M96YT87)I;R!D96P@8V5R=&EF:6-A9&\@9&4@3F5T<V-A<&4`
M5&EP;R!D92!C97)T:69I8V%D;R!D92!.971S8V%P90!2960`3G5N8V$`3G5E
M=F$@0V%L961O;FEA`$YU979A(&-A=&5G;W+M80!!\6%D:7(`16YV:6%R(&UE
M;G-A:F4@82`E<P!,=6YA(&YU979A`$YU979O(&YO;6)R92!D92!U<W5A<FEO
M("AO<&-I;VYA;"D`3G5E=F$@6F5L86YD80!#;VYT<F%S9?%A(&YU979A`$QA
M(&YU979A(&-O;G1R87-E\6$@97AP:7)A<N$@96P@)7@N`$QA<R!C;VYT<F%S
M9?%A<R!N;R!C;VEN8VED96XN`$YU979A('9E;G1A;F$@*%]B;&%N:RD`3F]T
M:6-I87,`1RX@9&4@;F]T:6-I87,`4VEG=6EE;G1E`%!R\WAI;6%S(#0@9F%S
M97,`3W!C:6]N97,@<VEG=6EE;G1E<P!3:6=U:65N=&4^`$YI8V%R86=U80!!
M<&]D;P!.:6=E<@!.:6=E<FEA`$YO8VAE`$YI=64`3F\`3F\@<V4@:&$@96YC
M;VYT<F%D;R!U;F$@96YT<F%D82`E<R!P87)A("5S`$YO('-E(&AA;B!E;F-O
M;G1R861O(&QI8G)E=&%S+@!.;R!H87D@9&%T;W,@9&4@8V]N9FEG=7)A8VGS
M;B!P87)A(&UO<W1R87(@9&EF97)E;F-I87,N`$YO('-E(&1I<W!O;F4@9&4@
M97-T<F%T96=I82!D92!E;&%B;W)A8VGS;B!D92!I;>%G96YE<R!)4T\N`$YO
M(&AA>2!P;&%N=&EL;&$@9&4@;&]T97,`3F\@:&%Y(&)L;W%U97,@96X@;&$@
M<&]S:6-I\VX@:6YD:6-A9&$`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@;F]M
M8G)E(&1E(&%G96YD82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!-0T%,+@!3
M:6X@8V%M8FEO<RX`3F\@<V4@<'5E9&5N(&'Q861I<B!D97-C96YD:65N=&5S
M(&$@97-T92!P<FEV:6QE9VEO+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF
M;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A("5S+@!.;R!S92!H82!E
M<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A
M(%9&4R!P;W(@1E10+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I
M\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@4U%,+@!.;R!S92!H
M82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P
M87)A(%9&4R!P;W(@87)C:&EV;R!344PN`$YO('-E(&AA;B!E;F-O;G1R861O
M(&-O;G1A8W1O<P!.;R!Q=65D82!S86QD;RX`3F\@<V4@:&$@:6YT<F]D=6-I
M9&\@96P@9&5S=&EN;RX`3F\@<V4@:&$@8V%R9V%D;R!N:6YG^FX@87)C:&EV
M;P!.;R!S92!H86X@96YC;VYT<F%D;R!I8V]N;W,N`$YO('-E(&AA(&1E9FEN
M:61O(&QA('5B:6-A8VGS;BX`3F\@<V4@:&$@9&5F:6YI9&\@;&$@=6)I8V%C
M:?-N+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;B!M96YS86IE+@!.;R!S92!H
M82!E<W!E8VEF:6-A9&\@=6X@;F]M8G)E+@!.;R!S92!H82!E<W!E8VEF:6-A
M9&\@=6X@;OIM97)O+@!.;R!O9F5N<VEV87,`3F\@<V4@:&$@:6YT<F]D=6-I
M9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@2%14
M4"X`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L
M82!A=71E;G1I9FEC86-I\VX@24U!4"X`3F\@<V4@:&$@:6YT<F]D=6-I9&\@
M=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@2V5R8F5R
M;W,N`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@
M;&$@875T96YT:69I8V%C:?-N(&1E(&EN:6-I;RX`3F\@<V4@:&$@:6YT<F]D
M=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@
M4$%34U=$+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P
M87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!334(N`$YO('-E(&AA(&EN9&EC861O
M(';M82!D92!A8V-E<V\@82!L;W,@8FEN87)I;W,@3W!E;E-33"X@4&%R82!T
M<F%B86IA<B!C;VX@9&%T;W,@4$M#4R`Q,B!H86-E;B!F86QT82!L;W,@8FEN
M87)I;W,@3W!E;E-33"X`4VEN(&%L=&%S('!E;F1I96YT97,N`$-A<F5C92!D
M92!Q=6]T82X`4VEN(')A>6%S`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!S
M97!A<F%D;W(N`$YI;F=U;F\`3F\@97AI<W1E(&5L(&%R8VAI=F\`3F\@<V4@
M9&ES<&]N92!D92!U;B!D:7)E8W1O<FEO(&1E(&%L;6%C96YA;6EE;G1O('1E
M;7!O<F%L+@!.;R!S92!H82!E;G9I861O(&5L(&YO;6)R92!D92!U<W5A<FEO
M('DO;R!L82!C;VYT<F%S9?%A+@!.;R!S92!E;F-O;G1R87)O;B!D871O<R!V
M0V%R9"X`3F\@<V4@:&%N(&1E=G5E;'1O(&1A=&]S(%A-3"!VX6QI9&]S`%-I
M;B!V86QO<F5S`$YO('-E(&5N8V]N='+S(&QA('9E<G-I\VX@96X@;&$@8V]N
M9FEG=7)A8VGS;B!O<FEG:6YA;"X@4F5G96YE<F%R(&QA(&-O;F9I9W5R86-I
M\VXN`$YO('-E(&5N8V]N='+S(&QA('9E<G-I\VX@96X@;&$@8V]N9FEG=7)A
M8VGS;BX@4F5G96YE<F%R(&QA(&-O;F9I9W5R86-I\VXN`$YI;F=U;F$`3FEN
M9W5N;R`H=7-O(&EM<&SM8VET;RD`3O-R9&EC;R`H25-/+3@X-3DM,3`I`$ES
M;&$@9&4@3F]R9F]L:P!(96UI<V9E<FEO(&YO<G1E`$ES;&%S($UA<FEA;F%S
M(&1E;"!.;W)T90!.;W)U96=A`$YO(&1E<W!UZ7,`3F\@86YT97,`3F\@97,@
M=6X@9&ER96-T;W)I;P!3:6X@9&5S87)R;VQL87(N`%-I;B!E<W1A8FQE8V5R
M`$YO(&5S=.$@<V]P;W)T861O+@!.;W1A<P!.;R!H87D@;F%D82!V:7-U86QI
M>F%B;&4L(')E=')O8V5D82X`3F]V:65M8G)E`$[Z;65R;P!.^FUE<F\@9&4@
M8V%R86-T97)E<P!.^FUE<F\@9&4@8V]L=6UN87,`3OIM97)O(&1E(&%R=.UC
M=6QO<R!P;W(@<.%G:6YA`$[Z;65R;R!D92!F:6QA<P!.;R!S92!H86X@97-P
M96-I9FEC861O(&[Z;65R;W,@82!A8W1U86QI>F%R(&5N(&QA(&QI<W1A(&1E
M(&1I<W1R:6)U8VGS;BX`06-E<'1A<@!/8FIE=&\`0W)E861O<B!D92!O8FIE
M=&]S`$YO('-E(&AA(&5N8V]N=')A9&\@96P@;V)J971O+@!/8W1A;`!/8W1U
M8G)E`$9I;'1R87(@;V9E;G-A<P!/9FEC:6YA`$QA(&-O;G1R87-E\6$@86YT
M:6=U82!Y(&QA(&YU979A(&1E8F5N('-E<B!D:7-T:6YT87,N`$-O;G1R87-E
M\6$@86YT:6=U80!,82!C;VYT<F%S9?%A(&%N=&EG=6$@;F\@97,@8V]R<F5C
M=&$N`$]MX6X`56YA('9E>B!G=6%R9&4@97-T82!PX6=I;F$@9&4@;W!C:6]N
M97,L(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,@<V4@8F]R<F%RX2!D969I
M;FET:79A;65N=&4N(%-I(&YO(&5S(&QO('%U92!D97-E82P@9&5B97+M82!C
M86UB:6%R(&QA('-E;&5C8VGS;B!A(").:6YG=6YO(BX`4_-L;R!L;W,@<V5R
M=FED;W)E<R!)34%0('-O<&]R=&%N(&QA<R!C87)P971A<R!C;VUP87)T:61A
M<RX`4_-L;R!O9F5N<VEV87,`4_-L;R!S92!P97)M:71E('5N82!D:7)E8V-I
M\VX@9&4@8V]R<F5O+@!3\VQO('-E('-O<&]R=&$@=6YA('9C87)D+@!3\VQO
M(&5L('!R;W!I971A<FEO(&\@=6X@861M:6YI<W1R861O<B!D92!S:7-T96UA
M<R!P=65D92!C86UB:6%R(&QA('!R;W!I961A9"!O(&QO<R!P<FEV:6QE9VEO
M<R!D92!P<F]P:65T87)I;R!D92!U;B!R96-U<G-O(&-O;7!A<G1I9&\`06)R
M:7(@96X@=6YA(&YU979A('9E;G1A;F$`17)R;W(@3W!E;E-33#H@3F\@<V4@
M<'5E9&5N(&5X=')A97(@9&%T;W,@9&4@;&$@<&%R=&4@4R]-24U%(&9I<FUA
M9&$N`$%B<FER(&5S=&4@=NUN8W5L;R!E;B!U;F$@=F5N=&%N82!N=65V80!3
M:7-T96UA(&]P97)A=&EV;P!/<&-I;VYE<P!/<&-I;VYE<R!D92`E<P!,:7-T
M82!O<F1E;F%D80!/<F=A;FEZ86-I\VX`56YI9&%D(&]R9V%N:7IA=&EV80!/
M<F=A;FEZ86-I\VX`4&QA;G1I;&QA(&1E(&%P;&EC86-I\VX@;W)I9VEN86P`
M4&QA;G1I;&QA<R!O<FEG:6YA;&5S(&5N("5S.@!/=')O`$]T<F$@:6YF;W)M
M86-I\VX`3W1R87,@;W!C:6]N97,`4')I=FEL96=I;W,@9&5L('!R;W!I971A
M<FEO`$QA(&%U=&5N=&EF:6-A8VGS;B!004T@;F\@97-TX2!D:7-P;VYI8FQE
M+@!014%2.CI-;W1O<B!D92!C;W)R96\`1FER;6$@9&EG:71A;"!01U``1&%T
M;W,@8VEF<F%D;W,@8V]N(%!'4`!#;&%V92!01U`@</IB;&EC80!$871O<R!F
M:7)M861O<R]C:69R861O<R!C;VX@4$=0`$/S9&EG;R!02%``26YTZ7)P<BX@
M4$A0`$QL;W9I>FYA('9E<W!E<G1I;F$`3&QU=FEA('9E<W!E<G1I;F$`0VAA
M<&%R<F]N97,@=F5S<&5R=&EN;W,`3FEE=F4@=F5S<&5R=&EN80!!9W5A8V5R
M;R!D92!N:65V92!V97-P97)T:6YO`%-O;"!V97-P97)T:6YO`$)O<G)A<V-A
M<R!V97-P97)T:6YA<P!.;R!S92!E;F-U96YT<F$@;&$@97AT96YS:?-N(%!/
M4TE8`$EN=.ER<'(N(%!?2%``36%R9V5N`%!A:VES=.%N`%!A;&%U`%!A;&5S
M=&EN;W,L(%1E<G)I=&]R:6]S($]C=7!A9&]S`%!A;F%MX0!087#Z82!.=65V
M82!'=6EN96$`4&%R86=U87D`4&%R8VEA;&UE;G1E(&YU8F]S;P!#;VYT<F%S
M9?%A`$QA(&-O;G1R87-E\6$@<V4@8V%M8FEA9&\@8V]R<F5C=&%M96YT92X`
M0V]N=')A<V7Q82!I;F-O<G)E8W1A`$AA>2!Q=64@:6YT<F]D=6-I<B!U;F$@
M8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!2041)55,N`$-O
M;G1R87-E\6$@8V]N(&-O;F9I<FUA8VGS;@!#;VYT<F%S9?%A.@!#;VYT<F%S
M9?%A.B``3&%S(&-O;G1R87-E\6%S('1I96YE;B!Q=64@8V]I;F-I9&ER+@!0
M96=A<@!096=A<B!D96P@<&]R=&%P87!E;&5S`%;M80!!;'1A<R!P96YD:65N
M=&5S.@!'96YT90!0;W)C96YT86IE`%)E86QI>F%R(&]P97)A8VEO;F5S(&1E
M(&UA;G1E;FEM:65N=&\`OU)E86QI>F%R(&]P97)A8VEO;F5S(&1E(&UA;G1E
M;FEM:65N=&\@86P@:6YI8VEA<B!S97-I\VX_`%!R:79I;&5G:6\`3F\@<V4@
M:&$@96QI;6EN861O(&5L('!R:79I;&5G:6\@(B5S(BX`4&5R;6ES;R!D96YE
M9V%D;P!097)M:7-O(&1E;F5G861O`%!R:79I;&5G:6]S`$%D;6EN:7-T<F%C
M:?-N(&1E('!R:79I;&5G:6]S`$EN9F]R;6%C:?-N('!E<G-O;F%L`%!E<OH`
M36%S8V]T87,`1FEL:7!I;F%S`%1E;.EF;VYO`$9O=&]G<F%F[6%S`$QI8G)E
M=&$@9&4@9&ER96-C:6]N97,@9&4@4&EN90!0:71C86ER;@!0[7AE;&5S`%3S
M<&EC;W,`4'5L<V4@96X@=6YA(&-E;&1A`$-O;F9I<FUE('%U92!D97-E82!E
M;&EM:6YA<B!E<W1E(&5L96UE;G1O.@!#;VYF:7)M92!Q=64@9&5S96$@96QI
M;6EN87(@96P@=NUN8W5L;R!A(&5S=&4@96QE;65N=&\N`$EN=')O9'5Z8V$@
M=6X@;65S('D@=6X@8?%O+@!);G1R;V1U>F-A(&5L(&YO;6)R92!D92!L82!N
M=65V82!C871E9V]R[6$Z`$EN=')O9'5Z8V$@=6YA(&1I<F5C8VGS;B!)4"!V
MX6QI9&$N`$EN=')O9'5Z8V$@=6YA(&9E8VAA(';A;&ED82P@8V]M<')U96)E
M(&5L(&[Z;65R;R!D92!D[6%S(&1E;"!M97,N`$EN=')O9'5Z8V$@=6YA(&AO
M<F$@=N%L:61A+@!);G1R;V1U>F-A(&5L(&YO;6)R92!D92!L82!N=65V82!L
M:7-T83H`4')O<&]R8VEO;F4@=6X@<F5S=6UE;B!D96P@<')O8FQE;6$N`$EN
M=')O9'5Z8V$@<W4@;F]M8G)E(&1E('5S=6%R:6\@>2!C;VYT<F%S9?%A+@!,
M96$@96P@=&5X=&\@<VEG=6EE;G1E+B!$14)%(&%C97!T87(@;&]S('3I<FUI
M;F]S('-I('%U:65R92!U<V%R(&5L('-I<W1E;6$N`$EN=')O9'5Z8V$@96P@
M;G5E=F\@;F]M8G)E(&1E(&-A=&5G;W+M83H`4&]L;VYI80!0;VSM=&EC80!%
M;F-U97-T87,`4&]R='5G86P`4&]S:6-I\VX@9&4@;&$@:6UA9V5N`%!O<VEC
M:?-N(&1E(&QA('1A8FQA`$5N=FEA<B!A(&5S=&$@8V%R<&5T82`H;F\@;V)L
M:6=A9&\@<&]R($E-05`I`%!R96-I<&ET86-I;VYE<R!D92!L82AS*2#Z;'1I
M;6$H<RD@)7,@:&]R82AS*3H@`%!R;V)A8FEL:61A9#QB<B`O/F1E('!R96-I
M<&ET86-I\VX`4')E9G-?;&1A<#H@;F\@<V4@96YC;VYT<O,@;&$@97AT96YS
M:?-N($Q$05`@<F5Q=65R:61A+@!0<F5F<U]S97-S:6]N.B!N;R!S92!E;F-O
M;G1R\R!L82!E>'1E;G-I\VX@9&4@<V5S:?-N(')E<75E<FED82X`4')E<VGS
M;@!0<F5S:?-N(&%L(&YI=F5L(&1E;"!M87(Z(`!0<F5S:?-N.B``5FES=&$@
M<')E=FEA`%9I<W1A('!R979I82!D92!L82!I;6%G96X@96X@=6YA(&YU979A
M('9E;G1A;F$`06YT97)I;W(`3W!C:6]N97,@86YT97)I;W)E<P!);7!R:6UI
M<B!D;V-U;65N=&\`3&EB<F5T82!D92!D:7)E8V-I;VYE<R!P<FEV861A`$-L
M879E('!R:79A9&$`OU!R;V)L96UA<S\`1&5S8W)I<&-I\VX@9&5L('!R;V)L
M96UA`%!R;WEE8W1O<P!497AT;R!D96P@:6YD=6-T;W(`0VQA=F4@4$=0('#Z
M8FQI8V$`06QG;W)I=&UO(&1E(&-L879E('#Z8FQI8V$`26YF;W)M86-I\VX@
M9&4@8VQA=F4@</IB;&EC80!.;R!S92!G96YE<F%R;VX@8V]R<F5C=&%M96YT
M92!L87,@8VQA=F5S(%#Z8FQI8V$O4')I=F%D82X`4'5E<G1O(%)I8V\`3&EM
M<&EA<B!M96YS86IE<P!1871A<@!#;VYS=6QT80!(82!F86QL861O(&QA(&-O
M;G-U;'1A.B`H)7,I("5S`$+Z<W%U961A('+A<&ED80!1=6]T80!#;&%V92!2
M4T$@</IB;&EC82`H)60@8FET*0!";W3S;B!D92!O<&-I\VX`3&QU=FEA`$QL
M=79I82!M871U=&EN80!,;'5V:6$@=F5S<&5R=&EN80!!9W5A8V5R;P!,;'5V
M:6$@>2!.:65V90!,;'5V:6$@82!.:65V90!2=65D82!D92!L82!F;W)T=6YA
M`%)A>O-N`"9N8G-P.TQE97(F;F)S<#L`2&$@9F%L;&%D;R!L82!L96-T=7)A
M.B`H)7,I("5S`$QE97(@;65N<V%J97,`3F\@<V4@<'5E9&5N(&QE97(@;&]S
M(&-O;G1A8W1O<RX`OT5L:6UI;F%R(')E86QM96YT92`E<S\@17-T82!O<&5R
M86-I\VX@;F\@<V4@<'5E9&4@9&5S:&%C97(N`+]%;&EM:6YA<B!R96%L;65N
M=&4@97-T92!C;VYT86-T;S\`OT5L:6UI;F%R(')E86QM96YT92!L;W,@9&%T
M;W,@9&5L('5S=6%R:6\@)7,_($5S=&$@;W!E<F%C:?-N(&YO('-E('!U961E
M(&1E<VAA8V5R+@!296=I<W1R;W,@;6]S=')A9&]S.@!6=65L=F4@82!R96%L
M:7IA<B!L82#Z;'1I;6$@86-C:?-N`$%C='5A;&EZ87(`06-T=6%L:7IA<B!E
M;&5M96YT;W,@9&4@;65N^B!D:6[A;6EC;W,Z`$%C='5A;&EZ87(@=FES=&$@
M9&5L('!O<G1A;`!296=E>`!.879E9V%D;W(@9&4@<F5L86-I;VYE<P!2969R
M97-C87(`3V)S97)V86-I;VYE<P!397)V:61O<F5S(')E;6]T;W,`55),(')E
M;6]T82`H:'1T<#HO+W=W=RYE:F5M<&QO+F-O;2]H;W)D92DZ`%%U:71A<@!1
M=6ET87(@8FQO<75E`$5L:6UI;F%R(&QI8G)E=&$@9&4@9&ER96-C:6]N97,`
M475I=&%R(&-O;'5M;F$`16QI;6EN87(@9F]R;6%T;P!1=6ET87(@9&4@97-T
M82!L:7-T80!1=6ET87(@<&%R`$5L:6UI;F%R(&=U:?-N(&=U87)D861O(&1E
M;"!D:7)E8W1O<FEO('1E;7!O<F%L(&1E;"!S97)V:61O<BX`16QI;6EN87(@
M`$5L:6UI;F%R(&5S=&4@;F]D;R!D96P@9&]C=6UE;G1O`$5L:6UI;F%R('5S
M=6%R:6\`16QI;6EN87(@=7-U87)I;SH@)7,`OU-U<W1I='5I<B!L82!L:6)R
M971A(&5X:7-T96YT92!P;W(@;&$@:6UP;W)T861A/R`\<W1R;VYG/D%D=F5R
M=&5N8VEA.B#)<W1O(&5L:6UI;F%RX2!T;V1A<R!L87,@96YT<F%D87,@9&4@
M<W4@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!A8W1U86PN/"]S=')O;F<^`$YO
M('-E('!U961E(')E<W!O;F1E<B!A(&QA('-O;&EC:71U9"X@0_-D:6=O(&1E
M(&5R<F]R(&1E=G5E;'1O.B``3F\@<V4@96YC;VYT<O,@96P@;V)J971O('-O
M;&EC:71A9&\N`$YO('-E(&5N8V]N='+S(&5L('-E<G9I8VEO('-O;&EC:71A
M9&\N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!E;"`B)7,B(')E<75E<FED;R!E
M;B!L82!C;VYF:6=U<F%C:?-N(&1E("5S+@!.;R!S92!H82!E<W!E8VEF:6-A
M9&\@96P@(B5S(B!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A8VGS;B!D92!6
M1E,N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!E;"`B)7,B(')E<75E<FED;R!E
M;B!L82!C;VYF:6=U<F%C:?-N+@!#86UP;R!N96-E<V%R:6\`3&EM<&EA<@!,
M:6UP:6%R(&-O;G1R87-E\6$`3&EM<&EA<B!C;VYT<F%S9?%A`%)E<W1A=7)A
M<B!A(&QO<R!V86QO<F5S('!O<B!O;6ES:?-N`%)E<W1A=7)A<B#Z;'1I;6$@
M8V]N<W5L=&$`4F5S=6QT861O<P!296=R97-A<B!A(&]P8VEO;F5S`%)E97-C
M<FEB:7(@8V]N=')A<V7Q82!N=65V80!2975N:?-N`%)E<W1A=7)A<B!C;VYF
M:6=U<F%C:?-N`$]P8VEO;F5S(&1E(&5D:6-I\VX@9&4@=&5X=&\@96YR:7%U
M96-I9&\`0W)I8F%S`$1E<F5C:&$`0V%B96-E<F$@9&5R96-H80!686QO<F5S
M(&1E(&QA(&1E<F5C:&$`4')O<&EE9&%D97,@9&4@7V9I;&$N+BX`1G5N8VGS
M;@!2=6UA;NUA`$=I<F%R(#$X,`!':7)A<B!A(&QA(&EZ<75I97)D80!':7)A
M<B!A(&QA(&1E<F5C:&$`4')O<&EE9&%D97,@9&4@9FEL80!0<F]P:65D861E
M<R!D92!F:6QA`$9I;&%S.@!287EA<P!!<&%R96-E<N%N(')A>6%S(&5N=')E
M('1O9&%S(&QA<R!F:6QA<R!Y(&-O;'5M;F%S`$%P87)E8V5RX6X@<F%Y87,@
M<_-L;R!E;G1R92!L87,@8V]L=6UN87,`07!A<F5C97+A;B!R87EA<R!S\VQO
M(&5N=')E(&QA<R!F:6QA<P!%:F5C=71A<@!&961E<F%C:?-N(%)U<V$`4G5A
M;F1A`$9I<FUA(&-R:7!T;V=RX69I8V$@4R]-24U%`$UE;G-A:F4@8VEF<F%D
M;R!E;B!3+TU)344`0V5R=&EF:6-A9&\@4R]-24U%('#Z8FQI8V\`3F\@97-T
MX2!D:7-P;VYI8FQE(&QA(&%U=&5N=&EF:6-A8VGS;B!305-,+@!-96YS+B!3
M35,`26YTZ7)P<BX@4U%,`%-E;G1E;F-I82!344P@<&%R82!C;VYS=6QT87,@
M9&4@=F%L;W)E<P!34T@`2&$@9F%L;&%D;R!35$%25%1,4SH@*"5S*2`E<P#)
M6$E43P!);G3I<G!R+B!37U%,`%-A8@!386YT82!(96QE;F$`4V%I;G0@2VET
M=',@>2!.979I<P!386YT82!,=6/M80!386EN="!0:65R<F4@>2!-:7%U96QO
M;@!386X@5FEC96YT92!Y($=R86YA9&EN87,`36ES;6\@9G)A;64@*%]S96QF
M*0!386UO80!386X@36%R:6YO`%-A;G1O(%1O;>%S('D@4'+M;F-I<&4`4')O
M=F5E9&]R(&1E('-A=.EL:71E`$%R86)I82!3875D:71A`$=U87)D87(`1W5A
M<F1A<B`B)7,B`$=U87)D87(@)7,`1W5A<F1A<B!O<&-I;VYE<P!'=6%R9&%R
M(&QA(&-O;F9I9W5R86-I\VX@9V5N97)A9&$@8V]M;R!U;B!G=6GS;B!02%`@
M96X@96P@9&ER96-T;W)I;R!T96UP;W)A;"!D92!S=2!S97)V:61O<BX`4V4@
M:&$@9W5A<F1A9&\@;&$@8V]N9FEG=7)A8VGS;B!D92`E<RX`1W5A<F1A<B!G
M=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX@96XZ
M("(E<R(N`$YO('-E('!U961E;B!G=6%R9&%R(&QO<R!C;VYT86-T;W,N`$)O
M<G)A<V-A<R!A:7-L861A<P!#:65N8VEA`$)U<V-A<@!-+B!B^G-Q=65D80!(
M82!F86QL861O(&QA(&+Z<W%U961A`$AA(&9A;&QA9&\@;&$@8OIS<75E9&$Z
M("5S`$YO('-E('!U961E(')E86QI>F%R(&+Z<W%U961A<RX`0G5S8V%N9&\N
M+BX`4V5L96-C:6]N87(@87)C:&EV;W,`4V5L96-C:6]N92!U;F$@9F5C:&$`
M4V5L96-C:6]N92!E;"!G<G5P;R!A(&'Q861I<@!396QE8V-I;VYE('5N(&YU
M979O('!R;W!I971A<FEO`%-E;&5C8VEO;F4@=6X@<V5R=FED;W(`4V5L96-C
M:6]N92!E;"!U<W5A<FEO(&$@8?%A9&ER`%-E;&5C8VEO;F%R('1O9&\`4V5L
M96-C:6]N92!T;V1O<R!L;W,@8V]M<&]N96YT97,@9&4@;&$@9F5C:&$N`%-E
M;&5C8VEO;F4@=6YA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,@82!E;&EM:6YA
M<@!396QE8V-I;VYE('5N82!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&$@;6]D
M:69I8V%R`%-E;&5C8VEO;F%R('5N(&]B:F5T;P!3:6X@<V5L96-C:?-N`%-E
M;&5C8VEO;F4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!A(&5X<&]R=&%R
M.@!396QE8V-I;VYE(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,@82!L82!Q
M=64@:6UP;W)T87(Z`%-E;&5C8VEO;F4@;&]S(&-A<N%C=&5R97,@<75E(&YE
M8V5S:71E(&1E(&QA<R!C87-I;&QA<R!D92!A8F%J;RX@4'5E9&4@8V]P:6%R
M;&]S('D@<&5G87)L;W,@9&5L(.%R96$@9&4@=&5X=&\N`%-E;&5C8VEO;F4@
M96P@:G5E9V\@9&4@8V%R86-T97)E<R!D96P@87)C:&EV;R!O<FEG96XZ`%-E
M;&5C8VEO;F4@96P@9&5L:6UI=&%D;W(@9&4@9F5C:&%S.@!396QE8V-I;VYE
M(&5L(&9O<FUA=&\@9&4@9F5C:&%S.@!396QE8V-I;VYE(&5L(&9O<FUA=&\@
M9&4@97AP;W)T86-I\VXZ`%-E;&5C8VEO;F4@96P@87)C:&EV;R!A(&EM<&]R
M=&%R.@!396QE8V-I;VYE(&5L(&9O<FUA=&\@9&5L(&%R8VAI=F\@;W)I9V5N
M.@!396QE8V-I;VYE(&5L(&9O<FUA=&\@=7-A9&\@<&%R82!M;W-T<F%R(&QO
M<R!N;VUB<F5S.@!396QE8V-I;VYE(&QA(&ED96YT:61A9"!Q=64@<75I97)A
M(&-A;6)I87(Z`%-E;&5C8VEO;F4@96P@9&5L:6UI=&%D;W(@9&4@:&]R87,Z
M`%-E;&5C8VEO;F4@96P@9F]R;6%T;R!D92!H;W)A<SH`4V5L96-C:6]N92!D
M;W,@8V%M<&]S(&-O:6YC:61E;G1E<RX`4V5L96-C:6]N92!L82!V:7-T82!M
M;W-T<F%D82!P;W(@;VUI<VGS;B!Y(&QA<R!O<&-I;VYE<R!D92!O<F1E;F%C
M:?-N('D@<&%G:6YA8VGS;BX`4V5L96-C:6]N92!L;W,@8V%M<&]S('9I<W5A
M;&EZ861O<R!E;B!E;"!L:7-T861O(&1E(&1I<F5C8VEO;F5S+@!396QE8V-I
M;VYE(&/S;6\@;6]S=')A<B!L;W,@;F]M8G)E<RX`4V5L96-C:6]N92!S=2!C
M;VUB:6YA8VGS;B!D92!C;VQO<F5S+@!396QE8V-I;VYE('-U(&ED:6]M82!P
M<F5F97)I9&\Z`$QI8G)E=&$@9&4@9&ER96-C:6]N97,@<V5L96-C:6]N861A
M("(E<R(N`$5N=FEA<B!I;F9O<FUE(&1E('!R;V)L96UA<P!%;G9I87(@4TU3
M`%-E;F5G86P`4V5N<V]R.B``4V5P=&EE;6)R90!397)B:6$@>2!-;VYT96YE
M9W)O`$[Z;65R;R!D92!S97)I90!$871O<R!D96P@<V5R=FED;W(@97)R\VYE
M;W,@;R!N;R!D:7-P;VYI8FQE<RX`061M:6YI<W1R86-I\VX@9&4@<V5S:?-N
M`$AA(&-A9'5C861O(&5L($E$(&1E('-E<VGS;BX`4V5S:6]N97,`17-T86)L
M96-E<@!%<W1A8FQE8V4@;W!C:6]N97,@<75E(&QE('!E<FUI=&5N(')E86IU
M<W1A<B!S=2!C;VYT<F%S9?%A('-I(&QL96=A<F$@82!O;'9I9&%R;&$N`$-O
M;F9I9W5R82!S97)V:61O<F5S(')E;6]T;W,@82!L;W,@<75E(&1E<V5E(&%C
M8V5D97(@9&5S9&4@96P@<&]R=&%L+@!$969I;F4@;&%S(&]P8VEO;F5S('!R
M969E<FED87,@9&4@:61I;VUA+"!Z;VYA(&AO<F%R:6$@>2!F96-H87,N`$1E
M9FEN92!L82!A<&QI8V%C:?-N(&1E(&EN:6-I;RP@;&$@8V]M8FEN86-I\VX@
M9&4@8V]L;W)E<RP@;&$@86-T=6%L:7IA8VGS;B!D92!PX6=I;F$@>2!O=')A
M<R!O<&-I;VYE<R!D92!V:7-U86QI>F%C:?-N+@!#;VYF:6=U<F%C:?-N`$AA
M>2!G=6EO;F5S(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS
M;@!687)I87,@=6)I8V%C:6]N97,@9&ES<&]N:6)L97,@8V]N(&5L('!A<N%M
M971R;SH@`%-E>6-H96QL97,`1&ER96-T;W)I;R!C;VUP87)T:61O`$-O;7!R
M87,`4F5S=6UE;B!C;W)T;P"_1&5F:6YI<B!C;&%V97,@9&4@86-C97-O('!A
M<F$@;&$@;6%Y;W+M82!D92!L;W,@=NUN8W5L;W,_`"9N8G-P.TUO<W1R87(F
M;F)S<#L`36]S=')A<B`E<P!-;W-T<F%R('1O9&\`36]S=')A<B!C;VYT86-T
M;W,`36]S=')A<B!L:7-T87,`375E<W1R82!L87,@9&EF97)E;F-I87,@96YT
M<F4@;&$@;G5E=F$@8V]N9FEG=7)A8VGS;B!Y(&QA(&%L;6%C96YA9&$`OTUO
M<W1R87(@:&]R82!D92!L82#Z;'1I;6$@<V5S:?-N(&%L(&EN:6-I87(_`$UO
M<W1R87(@;W!C:?-N(&1E(&-O;G-E<G9A<B!E;"!O<FEG:6YA;`!-;W-T<F%R
M('-E;&5C=&]R`+]-;W-T<F%R(&QA(&)A<G)A(&1E(&UE;OH@9&4@;W!E<F%C
M:6]N97,@9&4@=&%B;&$_`+]-;W-T<F%R(&5L(&UE;OH@)7,@82!L82!I>G%U
M:65R9&$_`$UU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!C
M96QD82!D92!T86)L80!-=65S=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D
M97,@9&4@=&%B;&$`375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S
M(&1E(&9I;&$@9&4@=&%B;&$`375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I
M961A9&5S(&1E(&EM86=E;@!-;W-T<F%R(&-A<F=A`$%G=6%C97)O<P!,;'5V
M:6%S(&UA='5T:6YA<P!,;'5V:6%S('9E<W!E<G1I;F%S`$%G=6%C97)O<R!E
M;B!L82!V96-I;F1A9`!2961U8VER`%!R:6UE<F\@<F5D=7IC82!O('%U:71E
M(&1E(&5N;65D:6\@;&]S(&)L;W%U97,@8V5R8V%N;W,`4VEE<G)A($QE;VYA
M`$%L=&$`1FER;6$`06QG;W)I=&UO(&1E(&9I<FUA`%-I;F=A<'5R`%1A;6'Q
M;P!/;6ET:7(@;6%N=&5N:6UI96YT;P!%<VQO=F%Q=6EA`$5S;&]V96YI80!.
M:65V90!!9W5A8V5R;R!D92!N:65V90!!9W5A8V5R;R!D92!N:65V90!!9W5A
M8V5R;R!D92!N:65V92!M871U=&EN;P!!9W5A8V5R;R!D92!N:65V92!V97-P
M97)T:6YO`$5S<&5S;W(@9&4@;&$@;FEE=F4Z(`!%<75I=F%L96YT92!D92!L
M82!N:65V92!E;B!A9W5A.B``27-L87,@4V%L;VWS;@!3;VUA;&EA`$-A;F-I
M;VYE<R`F(%!O96UA<P!396YT:61O(&1E(&-L87-I9FEC86-I\VX`4V5L96-C
M:?-N(&1E;"!S96YT:61O(&1E(&QA(&-L87-I9FEC86-I\VX`4F5M:71E;G1E
M`$]R[6=E;F5S`%-U9.%F<FEC80!%=7)O<&$@9&5L('-U<B`H25-/+3@X-3DM
M,RD`1V5O<F=I82!D96P@4W5R(&4@27-L87,@4V%N9'=I8V@@9&5L(%-U<@!(
M96UI<V9E<FEO('-U<@!%<W!A8VEA9&\@96YT<F4@8V5L9&%S(&%D>6%C96YT
M97,`17-P86-I861O(&5N=')E(&5L(&-O;G1E;FED;R!Y(&5L(&)O<F1E(&1E
M('5N82!C96QD80!397!A<F%D;W(`17-P86-I861O`$5S<&%C:6%D;R!Y(&UA
M<F=E;@!%<W!A\6$`4W!A;0!%<V-R:71U<F$@9&4@8V%R86-T97)E<R!E<W!E
M8VEA;&5S`$EN9&EQ=64@9/-N9&4@9&5S96$@<75E(&%P87)E>F-A;B!L;W,@
M<F5S=6QT861O<R!D92!L82!B^G-Q=65D82!A=F%N>F%D82X`1&EV:61I<B!C
M96QD80!$:79I9&ER(&-O;'5M;F$`1&EV:61I<B!F:6QA`$1E<&]R=&5S`%-R
M:2!,86YK80!%<W3A;F1A<@!3=&%R(%1R96L`0?%O(&1E(&EN:6-I;P!%<W1A
M9&\@;R!P<F]V:6YC:6$`17-T861O`$9O<FUA=&\@9&4@86QM86-E;F%M:65N
M=&\`1&ER96-C:?-N(&1E(&QA(&-A;&QE`%1A8VAA9&$`3&ES=&$@9&4@8V%D
M96YA<P!%;&EM:6YA<B!D;VUI;FEO(&1E(&QA(&1I<F5C8VGS;@!%<W1I;&\@
M6T-34UT`1&]M`$YO('-E(&5N8V]N='+S(&5L('-U8F1I<F5C=&]R:6\@(B5S
M(BX`07-U;G1O`$5N=FEA<@!392!H82!E;G9I861O('5N82!S;VQI8VET=60@
M9&4@86QT82!D92`B)7,B(&5N(&5L('-I<W1E;6$N($YO('!O9'+A(&EN:6-I
M87(@<V5S:?-N(&AA<W1A('%U92!S92!H87EA(&%P<F]B861O(&QA('-O;&EC
M:71U9"X`4W5B[6YD:6-E`,EX:71O`%-E(&AA(&'Q861I9&\@8V]R<F5C=&%M
M96YT92`B)7,B(&%L('-I<W1E;6$N`%-E(&AA*&XI(&'Q861I9&\@8V]R<F5C
M=&%M96YT92`E9"!C;VYT86-T;RAS*2!A(&QA(&QI<W1A+@!392!H82!A\6%D
M:61O(&-O<G)E8W1A;65N=&4@)7,@82`E<RX`4V4@:&%N(&5L:6UI;F%D;R!C
M;W)R96-T86UE;G1E(&QO<R!D871O<R!D96P@=7-U87)I;R`B)7,B(&1E;"!S
M:7-T96UA+@!392!H82!C<F5A9&\@8V]R<F5C=&%M96YT92!L82!L:7-T82`B
M)7,B+@!392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`B)7,B+@!392!H
M82AN*2!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`E9"!C;VYT86-T;RAS*2X`
M4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@(B5S(B!D96P@<VES=&5M
M82X`4V4@:&$H;BD@96QI;6EN861O(&-O<G)E8W1A;65N=&4@)60@8V]N=&%C
M=&\H<RD@9&4@;&$@;&ES=&$N`%-E(&AA(')E<W1A=7)A9&\@8V]R<F5C=&%M
M96YT92!L82!C;VYF:6=U<F%C:?-N+B!2969R97-Q=64@<&%R82!V97(@;&]S
M(&-A;6)I;W,N`%-E(&AA(&=U87)D861O(&-O<G)E8W1A;65N=&$@;&$@8V]P
M:6$@9&4@;&$@8V]N9FEG=7)A8VGS;BX`4V4@:&$@9W5A<F1A9&\@8V]R<F5C
M=&%M96YT92!L82!C;W!I82`E<R!D92!L82!C;VYF:6=U<F%C:?-N+@!392!H
M82!A8W1U86QI>F%D;R!C;W)R96-T86UE;G1E("(E<R(`4V4@:&$@97-C<FET
M;R!C;W)R96-T86UE;G1E("<E<R<`4W5DX6X`4F5S=6UE;@!!;6%N96-E<@!!
M=&%R9&5C97(`4V]L96%D;P!!;6%N96-E<@!!;6%N96-E<B]!=&%R9&5C97(`
M06UA;F5C97(Z(`!!=&%R9&5C97(`071A<F1E8V5R.B``4W5P97+M;F1I8V4`
M4V]P;W)T90!3=7)I;F%M`$%P96QL:61O`%-V86QB87)D('D@2F%N($UA>65N
M`%-W87II;&%N9&EA`%-U96-I80!3=6EZ80!296=I<W1R;R!D92!S:6YC<F]N
M:7IA8VGS;B!E;&EM:6YA9&\`4WEN8TU,`$5R<F]R(&1E('-I;G1A>&ES(&5N
M(&QO<R!TZ7)M:6YO<R!D92!B^G-Q=65D80!297#Z8FQI8V$@P7)A8F4@9&4@
M4VER:6$`0VAU8F%S8V\`0F]R<F%S8V]S;R!Y('9E;G1O<V\`0F]R<F%S8V%S
M`$)O<G)A<V-A<R!M871U=&EN87,`5%-6`$%R8VAI=F\@5%-6`%9A;&]R97,@
M<V5P87)A9&]S('!O<B!T86)U;&%D;W)E<P!486)L80!0<F]P:65D861E<R!D
M92!T86)L80!486)L80!0<F]P:65D861E<R!D92!T86)L80!486EWX6X`5&%I
M=^%N+"!0<F]V:6YC:6$@9&4@0VAI;F$`5&%Y:6MI<W3A;@!486YZ86YI82P@
M4F5P^F)L:6-A(%5N:61A(&1E`$1E<W1I;F\Z`%1A<F5A<P!.^FUE<F\@9&4@
M=&5LZ69O;F\`5&5M<&5R871U<F$@9'5R86YT92!L82#Z;'1I;6$@:&]R83H@
M`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``5&5M<&5R871U<F$\8G(@+SXH
M)7--X7@E<R\E<TWM;B5S*2`F9&5G.R5S`$YO('-E(&5N8V]N='+S(&QA('!L
M86YT:6QL82`B)7,B+@!!9&UI;FES=')A8VGS;B!D92!P;&%N=&EL;&%S`%1E
M>'1O`%/S;&\@=&5X=&\`06QI;F5A8VGS;B!D92!T97AT;P!";W)D92!S=7!E
M<FEO<B!D96P@=&5X=&\`2G5E`%1A:6QA;F3I<R`H5$E3+38R,"D`5&%I;&%N
M9&EA`$YO(&5S=.$@9&ES<&]N:6)L92!L82!E>'1E;G-I\VX@1E10+@!%;"!S
M:7-T96UA(&AI<W3S<FEC;R!E<W3A(&1E<VAA8FEL:71A9&\N`$5L(&UO=&]R
M(&1E(&EN=&5G<F%C:?-N($AO<F1E+TMO;&%B(&YO('-O<&]R=&$@(B5S(@!.
M;R!S92!P=65D92!I;FEC:6%R(&5L(')E9VES=')O(&1E($E-4U`N`$YO('-E
M(&AA(&-A<F=A9&\@8V]R<F5C=&%M96YT92!L82!C;&%S92!-86EN=&5N86YC
M93HZ`%-E(&AA(&-E<G)A9&\@;&$@=F5N=&%N82!D92!O<&-I;VYE<RX@4V%L
M:65N9&\N`$AA>2!Q=64@8V]N9FEG=7)A<B!E;"!M;W1O<B!61E,@<&%R82!P
M97)M:71I<B!L82!C87)G82!D92!A9&IU;G1O<RX`3&$@;&EB<F5T82!D92!D
M:7)E8V-I;VYE<R`B)7,B(&YO(&5X:7-T92X`4V4@:&$@8W)E861O(&-O<G)E
M8W1A;65N=&4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R`B)7,B+@!392!H
M82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92!L82!L:6)R971A(&1E(&1I<F5C
M8VEO;F5S("(E<R(N`%-E(&AA(&%C='5A;&EZ861O(&-O<G)E8W1A;65N=&4@
M;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R`B)7,B+@!.;R!S92!P=61O('9A
M8VEA<B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S.B`E<P!3:2!D97-E82!U
M=&EL:7IA<B!P97)M:7-O<RP@96P@861M:6YI<W1R861O<B!T:65N92!Q=64@
M8V]N9FEG=7)A<B!U;B!S;W!O<G1E(&1E('!E<FUI<V]S('!E<FUA;F5N=&4N
M`%/S;&\@96P@8F]R9&4@:6YF97)I;W(`16P@240@9&5L(&-O;G1A8W1O(&YO
M('-E(&5S<&5C:69I8_,L('-E(&1E:O,@96X@8FQA;F-O(&\@;F\@<V4@96YC
M;VYT<O,@96X@;&$@8F%S92!D92!D871O<RX`4V4@:&$@8?%A9&ED;R!C;W)R
M96-T86UE;G1E(&5L(&-O;G1A8W1O(&$@<W5S(&1I<F5C8VEO;F5S+@!%;"!C
M;VYT86-T;R!S;VQI8VET861O(&YO(&5X:7-T92X`4&%R82!C;VUP<F]B87(@
M96P@;65N<V%J92!F:7)M861O(&AA8V4@9F%L=&$@96P@8FQO<75E(&1E(&9I
M<FUA('-E<&%R861O+@!%;"!)1"!D92!L82!L:7-T82!D92!D:7-T<FEB=6-I
M\VX@;F\@<V4@97-P96-I9FEC\RP@<V4@9&5J\R!E;B!B;&%N8V\@;R!N;R!S
M92!E;F-O;G1R\R!E;B!L82!B87-E(&1E(&1A=&]S+@!.;R!S92!E<W!E8VEF
M:6/S(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX`3&%S(&-A<F%C=&5R[7-T
M:6-A<R!D92!C:69R861O(&YE8V5S:71A;B!U;F$@8V]N97AI\VX@=V5B('-E
M9W5R82X`16P@87)C:&EV;R`B)7,B('-E(&AA(&5L:6UI;F%D;R!C;W)R96-T
M86UE;G1E+@!%;"!A<F-H:79O("5S('1E;F1R[6$@<75E(&-O;G1E;F5R('5N
M82!O<&-I\VX@)7,N`$5L(&%R8VAI=F\@)7,@=&5N9'+M82!Q=64@8V]N=&5N
M97(@86QG=6YA<R!O<&-I;VYE<R`E<RX`3F\@<V4@<'5E9&4@8V]P:6%R(&5L
M(&%R8VAI=F\@<V]B<F4@<^T@;6ES;6\N`$5L(&%R8VAI=F\@;F\@8V]N=&EE
M;F4@9&%T;W,N`$$@8V]N=&EN=6%C:?-N('1I96YE(&QA<R!C86)E8V5R87,@
M9&4@97-T92!M96YS86IE(&UE<W-A9V4O<F9C.#(R+@!392!S86)E('%U92!E
M;"!M;V1O(&1E('!A;G1A;&QA(&-O;7!L971A(&1A('!R;V)L96UA<R!C;VX@
M26YT97)N970@17AP;&]R97(@9&5B:61O(&$@9F%L;&]S(&1E;"!N879E9V%D
M;W(@<75E(&YO(&AE;6]S('!O9&ED;R!S;W-L87EA<BX@4'5E9&4@<W5F<FER
M('9I<W5A;&EZ86-I\VX@9&4@8F%S=7)A+"!PZ7)D:61A(&1E(&9U;F-I;VYE
M<R!D96P@961I=&]R('DO;R!C=65L9W5E<R!A;&5A=&]R:6]S(&1E;"!N879E
M9V%D;W(N(%-I('-U('-I<W1E;6$@;W!E<F%T:79O(&5S(%=I;F1O=W,@.7@L
M(&5S(&UU>2!P<F]B86)L92!Q=64@<W5F<F$@=6X@9F%L;&\@9&4@<')O=&5C
M8VGS;B!G96YE<F%L('D@=&5N9V$@<75E(')E:6YI8VEA<B!E;"!E<75I<&\N
M7&Y<;EEA(&5S=.$@879I<V%D;RX@4'5L<V4@06-E<'1A<B!S:2!A^FX@9&5S
M96$@<')O8F%R(&5L(&5D:71O<B!E;B!M;V1O(&1E('!A;G1A;&QA(&-O;7!L
M971A+@!392!H82!E;&EM:6YA9&\@;&$@:61E;G1I9&%D("(E<R(N`%-E('!U
M961E(&-O;7!L971A<B!L82!I;7!O<G1A8VGS;B!A('!E<V%R(&1E(&QO<R!A
M=FES;W,N`%/S;&\@96P@8F]R9&4@:7IQ=6EE<F1O`$AA>2!Q=64@:6YD:6-A
M<FQE(&$@;&$@8VQA<V4@0W)Y<'1?<&=P.CH@;&$@=6)I8V%C:?-N(&1E(&QO
M<R!B:6YA<FEO<R!';G501RX`4V4@:&$@;6]S=')A9&\@96P@;65N<V%J92!E
M;G9I861O(&5L("5S(&$@)7,@8V]N(&5L(&%S=6YT;R`B)7,B+@K)<W1O(&YO
M(&=A<F%N=&EZ82!Q=64@96P@;65N<V%J92!H87EA('-I9&\@;&5I9&\@;R!C
M;VUP<F5N9&ED;RX`3F]M8G)E('5T:6QI>F%D;R!A;"!V:6YC=6QA<B!A(&QA
M('#A9VEN82!D92!C;VUP;W-I8VGS;@!%;"!N^FUE<F\@9&4@8V%M<&]S('1I
M96YE('%U92!S97(@=6X@;OIM97)O+@!(86-E(&9A;'1A(&5L(&WS9'5L;R!O
M<&5N<W-L('!A<F$@;&$@8VQA<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BX`3F\@
M<V4@<'5E9&4@9W5A<F1A<B!L82!P<F5F97)E;F-I82`B)7,B('!O<G%U92!S
M=7,@9&%T;W,@<V]B<F5P87-A;B!E;"!T86UA\6\@;>%X:6UO('!E<FUI=&ED
M;P!.;R!S92!E;F-O;G1R\R!E;B!E;"!S:7-T96UA(&5L('!R;V=R86UA('!A
M<F$@=F5R(&5S=&4@=&EP;R!D92!D871O<R`H)7,I+@!%;"!C87+A8W1E<B!D
M92!C:71A(&1E8F4@<V5R('-E<B!S\VQO('5N;RX`4_-L;R!L;W,@;&%D;W,@
M:7IQ=6EE<F1O('D@9&5R96-H;P!3\VQO(&5L(&QA9&\@9&5R96-H;P!%;"!S
M97!A<F%D;W(@9&5B92!S97(@<_-L;R!U;F\N`%-E(&AA(&5L:6UI;F%D;R!E
M;"!S97)V:61O<B`B)7,B+@!392!H82!G=6%R9&%D;R!E;"!S97)V:61O<B`B
M)7,B+@!392!H82!E;&EM:6YA9&\@;&$@<V]L:6-I='5D(&1E(&%L=&$@9&4@
M)7,N`$QA(&9I;&$@97-P96-I9FEC861A("@E9"D@;F\@97AI<W1E+@!%;"!A
M<F-H:79O('1E;7!O<F%L("(E<R(@;F\@97AI<W1E+@!%;"!T97AT;R!Q=64@
M:&$@:6YT<F]D=6-I9&\@;F\@8V]I;F-I9&4@8V]N(&5L(&1E(&QA('!A;G1A
M;&QA+@!3\VQO(&QO<R!L861O<R!S=7!E<FEO<B!E(&EN9F5R:6]R`%/S;&\@
M96P@;&%D;R!S=7!E<FEO<@!392!P97)D:65R;VX@;&]S(&1A=&]S(&-A<F=A
M9&]S(&1E<V1E(&5L('!A<V\@86YT97)I;W(N`$YO('-E('!U9&\@9W5A<F1A
M<B!E;"!A<F-H:79O(&-A<F=A9&\N`$YO(&5S=.$@9&ES<&]N:6)L92!E;"!B
M;&]Q=64@9&4@=V5A=&AE<BYC;VTN`$YO('-E(&5N8V]N='+S(&5L(&1I<F5C
M=&]R:6\@9&4@5&5M87,@(B5S(BX`3F\@:&%Y(&QI8G)E=&%S(&1E(&1I<F5C
M8VEO;F5S('9I<W5A;&EZ86)L97,N`$YO('-E(&1I<W!O;F4@9&4@;W!C:6]N
M97,N`$YO(&AA>2!P87)T97,@<75E('-E('!U961A;B!M;W-T<F%R(&5N(&SM
M;F5A+@!.;R!H87D@;&EB<F5T87,@9&4@9&ER96-C:6]N97,@96X@;&%S('%U
M92!S92!P=65D82!E<V-R:6)I<BX@3FEN9W5N82!D92!L87,@9&ES<&]N:6)L
M97,@97-TX2!C;VYF:6=U<F%D82!P87)A('!E<FUI=&ER;&4@8?%A9&ER(&5N
M=')A9&%S(&5N(&5L;&%S+B!3:2!C;VYS:61E<F$@<75E(&5S=&\@97,@=6X@
M97)R;W(L(&-O;G1A8W1E(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E('-I<W1E
M;6%S+@!%;B!E<W1E(&-A;7!O(&AA>2!D96UA<VEA9&]S(&-A<F%C=&5R97,N
M($AA(&EN=')O9'5C:61O("5S(&-A<F%C=&5R97,@>2!T:65N92!Q=64@:6YT
M<F]D=6-I<B!M96YO<R!D92`E<RX`4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A
M;"!A\6%D:7(@82`B)7,B(&%L('-I<W1E;6$Z("5S`%-E('!R;V1U:F\@=6X@
M<')O8FQE;6$@86P@8F]R<F%R(&QO<R!D871O<R!D96P@=7-U87)I;R`B)7,B
M(&1E;"!S:7-T96UA.B``4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!E;&EM
M:6YA<B!A("(E<R(@9&5L('-I<W1E;6$Z(`!392!P<F]D=6IO('5N('!R;V)L
M96UA(&%L(&%C='5A;&EZ87(@(B5S(CH@)7,`4V4@<')O9'5J;R!U;B!P<F]B
M;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\Z($YO('-E(&-A<F?S("5S
M+@!392!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D96P@87)C
M:&EV;RX@16P@)7,@97)A(&WA<R!G<F%N9&4@<75E(&5L('1A;6'Q;R!MX7AI
M;6\@<&5R;6ET:61O("@E9"!B>71E<RDN`%-E('!R;V1U:F\@=6X@<')O8FQE
M;6$@8V]N(&QA(&-A<F=A(&1E;"!A<F-H:79O+B!3\VQO('-E(&-A<F?S('!A
M<F-I86QM96YT92!E;"`E<RX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A\6%D
M:7(@96P@8V]N=&%C=&\N($-O;G1A8W1E(&%L(&%D;6EN:7-T<F%D;W(@9&4@
M<VES=&5M87,@<&%R82!MX7,@:6YF;W)M86-I\VXN`%-E('!R;V1U:F\@=6X@
M97)R;W(@86P@8W)E87(@=6YA(&QI<W1A+@!392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&-R96%R(&5S=&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<SH@)7,`4V4@
M<')O9'5J;R!U;B!E<G)O<B!A;"!E;&EM:6YA<B`B)7,B(&1E(&QA(&QI8G)E
M=&$@9&4@9&ER96-C:6]N97,@;W)I9V5N+@!392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&5L:6UI;F%R(&5S=&4@8V]N=&%C=&\Z("5S`%-E('!R;V1U:F\@=6X@
M97)R;W(@86P@;6]S=')A<B!L82!L:7-T80!392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&UO<W1R87(@97-T82!P87)T92!D96P@;65N<V%J90!392!P<F]D=6IO
M('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QO<R!D871O<R!D96P@8V]N=&%C=&\N
M`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S.B`E
M<P!392!P<F]D=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QO<R!D871O<R!I
M0V%L96YD87(N`%-E('!R;V1U:F\@=6X@97)R;W(@96X@96P@9F]R;75L87)I
M;R!D92!C;VYF:6=U<F%C:?-N+B!0=65D92!Q=64@:&%Y82!O;'9I9&%D;R!R
M96QL96YA<B!U;B!C86UP;R!N96-E<V%R:6\N`%-E('!R;V1U:F\@=6X@97)R
M;W(@86P@96IE8W5T87(@;&$@9G5N8VGS;B!E<W!E8VEF:6-A9&$@9&4@;&$@
M;&EB<F5T82!D92!D:7)E8V-I;VYE<RX@5G5E;'9A(&$@<')O8F%R(&WA<R!A
M9&5L86YT92X`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!E;&EM:6YA<B!E<W1A
M(&QI8G)E=&$@9&4@9&ER96-C:6]N97,Z("5S`%-E('!R;V1U:F\@=6X@97)R
M;W(@86P@86-T=6%L:7IA<B!L;W,@9&5T86QL97,@9&5L(&-O;G1A8W1O+B!6
M=65L=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+@!392!P<F]D=6IO('5N(&5R
M<F]R(&%L(&%C='5A;&EZ87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B!6
M=65L=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+@!392!P<F]D=6IO('5N(&5R
M<F]R(&%L(&%C='5A;&EZ87(@97-T82!L:6)R971A(&1E(&1I<F5C8VEO;F5S
M.B`E<P!392!P<F]D=6IO('5N(&5R<F]R(&%L(&%C='5A;&EZ87(@;&$@96YT
M<F%D83H@)7,`3F\@:'5B;R!D:7)E8V-I;VYE<R!A(&5X<&]R=&%R+@!%<W1A
M<R!L:6)R971A<R!S92!M;W-T<F%RX6X@96X@97-T92!O<F1E;CH`17-T87,@
M8V]L=6UN87,@<V4@;6]S=')A<N%N(&5N(&5S=&4@;W)D96XZ`$5S=&4@<V5R
M=FED;W(@24U!4"!N;R!S;W!O<G1A(&QA<R!C87)P971A<R!C;VUP87)T:61A
M<RX`R7-T92!N;R!P87)E8V4@<V5R('5N(&%R8VAI=F\@<F%R(';A;&ED;RX`
MR7-T92!N;R!P87)E8V4@<V5R('5N(&%R8VAI=F\@>FEP(';A;&ED;RX`R7-T
M92!N;R!P87)E8V4@<V5R('5N(&[Z;65R;R!D92!T87)J971A(';A;&ED;RX`
M17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!A('1R
M87;I<R!D92!L82!P87-A<F5L82!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA
M=&5L;"YC;VTI+"!M961I86YT92!L82!!4$D@2%144`!%<W1E(&-O;G1R;VQA
M9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A
M<V%R96QA(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI+"!M961I86YT92!L82!!
M4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A
M:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA('-M<S)E;6%I;"`H:'1T<#HO
M+W-M<S)E;6%I;"YC;VTI+"!M961I86YT92!L82!!4$D@2%144`!%<W1E(&-O
M;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S('9I82!33510(&$@
M=')A=NES(&1E(&QA('!A<V%R96QA(&1E(%9O9&%F;VYE(&1E($ET86QI82P@
M<_-L;R!A(&[Z;65R;W,@5F]D869O;F4N($AA8V4@9F%L=&$@=6YA(&-U96YT
M82!D92!C;W)R96\@9&4@5F]D869O;F4@9&4@271A;&EA("AH='1P.B\O=W=W
M+C$Y,"YI="DN`$AA8V4@9F%L=&$@97-T92!C86UP;RX`17-T92!C86UP;R!S
M\VQO('!U961E(&-O;G1E;F5R(&5N=&5R;W,N`$5S=&4@8V%M<&\@<_-L;R!P
M=65D92!C;VYT96YE<B!N^FUE<F]S('D@;&]S(&1O<R!P=6YT;W,N`$5S=&4@
M8V%M<&\@<_-L;R!P=65D92!C;VYT96YE<B!V86QO<F5S(&]C=&%L97,N`$5S
M=&4@8V%M<&\@=&EE;F4@<75E('-E<B!U;F$@;&ES=&$@9&4@96YT97)O<R!S
M97!A<F%D;W,@<&]R(&-O;6%S(&\@97-P86-I;W,N`$5S=&4@8V%M<&\@=&EE
M;F4@<75E('-E<B!U;B!N^FUE<F\@=N%L:61O+@!%<W1E(&-A;7!O('1I96YE
M('%U92!C;VYT96YE<B!U;B!C\V1I9F\@9&4@8V]L;W(@96X@9F]R;6%T;R!2
M1T(@2&5X861E8VEM86PL('!O<B!E:F5M<&QO("<C,3(S-&%F)RX`17-T92!F
M;W)M871O(&1E(&%R8VAI=F\@;F\@97-TX2!S;W!O<G1A9&\N`%EA('-E(&AA
M('!R;V-E<V%D;R!E<W1E(&9O<FUU;&%R:6\N`$5S=&\@97,@)7,N`,ES=&\@
M97,@=6X@;V)J971O(&1E($MO;&%B($=R;W5P=V%R92X@4&%R82!V97)L;R!N
M96-E<VET82!U;B!C;&EE;G1E(&1E(&-O<G)E;R`@<75E(&5N=&EE;F1A(&5L
M(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!U;F$@;&ES=&$@
M9&4@9&EC:&]S(&-L:65N=&5S('9I<VET92`E<P!%<W1E(&UE;G-A:F4@<V4@
M97-C<FEB:?,@8V]N('5N(&IU96=O(&1E(&-A<F%C=&5R97,@*"5S*2!D:7-T
M:6YT;R!A;"!S=7EO+@!%<W1E(&[Z;65R;R!D96)E('-E<B!P;W(@;&\@;65N
M;W,@=6X@=6YO+@!%<W1A('!E<G-O;F$@>6$@=&EE;F4@=6YA(&5N=')A9&$@
M)7,@96X@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RX`17-T92!S97)V:61O
M<B!N;R!P=65D92!D97-C;VUP<FEM:7(@87)C:&EV;W,@>FEP('D@9WII<"X`
M17-T92!S:7-T96UA(&%C='5A;&UE;G1E(&5S=.$@9&5S86-T:79A9&\N`$5S
M=&4@=F%L;W(@=&EE;F4@<75E('-E<B!U;B!N^FUE<F\N`,ES=&$@<V5RX2!L
M82!L:6)R971A('!O<B!O;6ES:?-N(&%L(&'Q861I<B!O(&EM<&]R=&%R(&-O
M;G1A8W1O<RX`17-T82!V96YT86YA('/S;&\@<'5E9&4@86)R:7)S92!D97-D
M92!U;F$@=F5N=&%N82!D92!O<&-I;VYE<P!4<G5E;F\`26YC:61E;F-I87,`
M2&]R80!#+B!T:65M<&]S`$9O<FUA=&\@:&]R87)I;P!396QE8V-I\VX@9&4@
M:&]R80!4:6UO<BU,97-T90!4[71U;&\`5.UT=6QO("AC;VYS96IO*3H`4&%R
M80!087)A('-E;&5C8VEO;F%R('9A<FEO<R!C86UP;W,L(&UA;G1E;F=A('!U
M;'-A9&$@;&$@=&5C;&$@0V]N=')O;"`H4$,I(&\@0V]M86YD;R`H36%C*2!A
M;"!H86-E<B!C;&EC:RX`2&]Y`$-O;FUU=&%R(&]R:6=E;B!(5$U,`%1O9V\`
M5&]K96QA=0!-8?%A;F$`5&]N9V$`4W5P97)I;W(`1G)A;64@<W5P97)I;W(@
M*%]T;W`I`%1R861U8V-I;VYE<P!4<FEN:61A9"!Y(%1O8F%G;P!697)D861E
M<F\@;R!F86QS;P!-87(`5/IN97H`5'5R<77M80!4=7)C;R`H25-/+3@X-3DM
M.2D`5'5R:VUE;FES=.%N`$ES;&%S(%1U<FMS('D@0V%I8V]S`%1U=F%L=0!%
M<V-R:6)A('-U(&5L96-C:?-N.B``S6YD:6-E(%4N5BXZ(`!54DP`55),(&1E
M('-U(&EN9F]R;64@9&4@97-T861O(&1E(&5N=NUO(&1E;"!G=6GS;@!54DPZ
M`%5G86YD80!58W)A;FEA`$EN8V%P87H@9&4@86-C961E<B!A;"!D:7)E8W1O
M<FEO(%9&4RX`26YC87!A>B!D92!A\6%D:7(@:6YF;W)M86-I\VX@9&4@=7-U
M87)I;R!A9&EC:6]N86P@86P@<F5A;&EZ87(@96P@86QT82X`26YC87!A>B!D
M92!C86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C:&EV;R!61E,@(B5S
M(BX`26YC87!A>B!D92!C86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C
M:&EV;R!61E,@)7,O)7,N`$EN8V%P87H@9&4@8V%M8FEA<B!A("5S+@!);F-A
M<&%Z(&1E(&-O;7!R;V)A<B!E;"!T86UA\6\@9&4@(B5S(BX`26YC87!A>B!D
M92!C;VUP<F]B87(@96P@=&%M8?%O(&1E("(E<R\E<R(N`$EN8V%P87H@9&4@
M8V]N96-T87)S92!A;"!S97)V:61O<B!344PN`$EN8V%P87H@9&4@8V]N96-T
M87(@8V]N(%-33"X`26YC87!A>B!D92!C;W!I87(@96P@87)C:&EV;R!61E,N
M`$EN8V%P87H@9&4@8W)E87(@96P@9&ER96-T;W)I;R!61E,@(B5S(BX`26YC
M87!A>B!D92!C<F5A<B!E;"!D:7)E8W1O<FEO(%9&4RX`26YC87!A>B!D92!C
M<F5A<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!C<F5A<B!L82!C87)P
M971A(%9&4R`B)7,B`$EN8V%P87H@9&4@8W)E87(@=6X@87)C:&EV;R!61E,@
M=F%C[6\N`$YO('-E('!U961E(&-R96%R('5N(&YU979O(")S:&%R92(N($9A
M;'1A(&5L('1I<&\@9&4@;W)I9V5N+@!);F-A<&%Z(&1E(&1E<V-O;7!R:6UI
M<B!L;W,@9&%T;W,N`$EN8V%P87H@9&4@96QI;6EN87(@(B5S(BP@96P@9&ER
M96-T;W)I;R!N;R!E<W3A('9A8^UO+@!);F-A<&%Z(&1E(&5L:6UI;F%R("(E
M<R(Z("5S+@!);F-A<&%Z(&1E(&5L:6UI;F%R("5S+"!E;"!D:7)E8W1O<FEO
M(&YO(&5S=.$@=F%C[6\`26YC87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E8W1O
M<FEO(%9&4R!D92!F;W)M82!R96-U<G-I=F$N`$EN8V%P87H@9&4@96QI;6EN
M87(@96P@9&ER96-T;W)I;R!61E,N`$EN8V%P87H@9&4@96QI;6EN87(@96P@
M9&ER96-T;W)I;R!61E,Z("5S+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&%R
M8VAI=F\@5D93("(E<R(N`$EN8V%P87H@9&4@96QI;6EN87(@96P@87)C:&EV
M;R!61E,N`$EN8V%P87H@9&4@96QI;6EN87(@;&$@8V%R<&5T82!61E,@(B5S
M(BX`26YC87!A>B!D92!E;&EM:6YA<B!E;"!61E,@9&4@9F]R;6$@<F5C=7)S
M:79A.B`E<RX`26YC87!A>B!D92!D971E<FUI;F%R(&5L(&1I<F5C=&]R:6\@
M86-T=6%L+@!);F-A<&%Z(&1E(&5X=')A97(@;&]S(&1E=&%L;&5S(&1E;"!C
M97)T:69I8V%D;RX`26YC87!A>B!D92!C87)G87(@;&$@9&5F:6YI8VGS;B!D
M92`E<RX`26YC87!A>B!D92!T<F%S;&%D87(@96P@87)C:&EV;R!61E,N`$EN
M8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!61E,@(B5S(BX`26YC87!A>B!D
M92!A8G)I<B!E;"!A<F-H:79O(%9&4R!P87)A(&5S8W)I8FER+@!);F-A<&%Z
M(&1E(&%B<FER(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&%B<FER(&5L
M(&%R8VAI=F\@8V]M<')I;6ED;RX`26YC87!A>B!D92!L965R('5N(&%R8VAI
M=F\@5D93("AH82!F86QL861O(&9I;&5S:7IE*"DI+@!);F-A<&%Z(&1E(&QE
M97(@=6X@87)C:&EV;R!61E,@*&AA(&9A;&QA9&\@9V5T1FEL95-I>F4H*2DN
M`$EN8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O.B``26YC87!A>B!D92!L965R
M(&5L(&1I<F5C=&]R:6\@=F9S<F]O="X`26YC87!A>B!D92!R96YO;6)R87(@
M)7,@8V]M;R`E<SH@;&$@8V%R<&5T82!D97-T:6YO('EA(&5X:7-T90!);F-A
M<&%Z(&1E(')E;F]M8G)A<B!E;"!D:7)E8W1O<FEO(%9&4RX`26YC87!A>B!D
M92!R96YO;6)R87(@96P@9&ER96-T;W)I;R!61E,Z("5S+@!);F-A<&%Z(&1E
M(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4R`B)7,B`$EN8V%P87H@9&4@<F5N
M;VUB<F%R(&5L(&%R8VAI=F\@5D93("5S+R5S+@!);F-A<&%Z(&1E(')E;F]M
M8G)A<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!E:F5C=71A<B`G;6MI
M<V]F<R<N`$YO('-E('!U961E('1R861U8VER(&5S=&4@9&]C=6UE;G1O(&1E
M(%=O<F0`26YC87!A>B!D92!E<V-R:6)I<B!E;"!A<F-H:79O(%9&4R`B)7,B
M+@!);F-A<&%Z(&1E(&5S8W)I8FER('5N(&%R8VAI=F\@5D93("AH82!F86QL
M861O(&-O<'DH*2DN`$EN8V%P87H@9&4@97-C<FEB:7(@;&]S(&1A=&]S(&1E
M;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!E<V-R:6)I<B!U;B!A<F-H:79O
M(%9&4RP@<V4@<W5P97)A<N$@;&$@<75O=&$N`%-U8G)A>6%D80!$97-H86-E
M<B!C86UB:6]S`$1E<VAA8V4@;&$@^FQT:6UA(&%C8VGS;@!297-P=65S=&$@
M:6YE<W!E<F%D82!D96P@<V5R=FED;W(@96X@;&$@8V]N97AI\VXZ(`!297-P
M=65S=&$@:6YE<W!E<F%D82!D96P@<V5R=FED;W(@83H@`%-I;B!C871E9V]R
M[6$`56YI8V]D92`H551&+3@I`$5M:7)A=&]S(,%R86)E<R!5;FED;W,`26YG
M;&%T97)R80!%<W1A9&]S(%5N:61O<P!%<W1A9&]S(%5N:61O<R!M96YO<R!L
M87,@:7-L87,@<&5R:6;I<FEC87,`56YI9&%D97,`1&5S8V]N;V-I9&\`07!I
M;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E(&UE;G-A:F4@9&4@;&$@05!)*2X`
M0VQI;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E(&UE;G-A:F4@9&5L(&-L:65N
M=&4I+@!392!H82!D969I;FED;R!U;F$@=6)I8V%C:?-N(&1E<V-O;F]C:61A
M+@!5<W5A<FEO(&\@8V]N=')A<V7Q82!D97-C;VYO8VED;W,N`$5L:6UI;F%R
M(';M;F-U;&\@9&5L(&5L96UE;G1O(&%C='5A;`!3:6X@;F]M8G)E`$QO<R!G
M=6EO;F5S('-I;B!P<FEV:6QE9VEO<R!N;R!P=65D96X@86-C961E<B!D92!F
M;W)M82!P<F]G<F%MX71I8V$@82!#;W)T87(O0V]P:6%R+U!E9V%R('!O<B!R
M87IO;F5S(&1E('-E9W5R:61A9"X@4'5L<V4@06-E<'1A<B!P87)A('9E<B!E
M;B!M;WII;&QA+F]R9R!U;F$@;F]T82!TZ6-N:6-A('%U92!L92!M=65S=')E
M(&/S;6\@<&5R;6ET:7(@<75E('5N(&=U:?-N(&%C8V5D82!A;"!P;W)T87!A
M<&5L97,N`$%N=6QA<B!C;VQO<@!4:7!O(&1E(&-O;G1E;FED;R!N;R!S;W!O
M<G1A9&\Z("5S`$5X=&5N<VGS;B!N;R!S;W!O<G1A9&$`06-T=6%L:7IA<@!!
M8W1U86QI>F%R("5S`$%C='5A;&EZ87(@=7-U87)I;P!392!H82!A8W1U86QI
M>F%D;R`B)7,B+@!392!H82!E;&EM:6YA9&\@96P@9W5I\VX@9&4@86-T=6%L
M:7IA8VGS;BX`0V%R9V%R`%-E(&AA;B!C87)G861O(&5N(&5L('-E<G9I9&]R
M('1O9&]S(&QO<R!A<F-H:79O<R!D92!C;VYF:6=U<F%C:?-N(&1E(&%P;&EC
M86-I;VYE<RX`06QF86)E=&\@;&%T:6YO(&5N(&UA>?IS8RX`3OIM97)O<R!R
M;VUA;F]S(&5N(&UA>?IS8RX`57)U9W5A>0!5<V%R(&%C='5A;#H@)7,`57-A
M<B!34TP`4V4@=7-A('-I(&5L('5S=6%R:6\O8V]N=')A<V7Q82!S;VX@9&ES
M=&EN=&]S(&5N(&5L('-E<G9I9&]R($E-4U`N`%5S=6%R:6\`16P@=7-U87)I
M;R`E<R!C87)E8V4@9&4@875T;W)I>F%C:?-N('!A<F$@)7,N`$%D;6EN:7-T
M<F%C:?-N(&1E('5S=6%R:6]S`$]P8VEO;F5S(&1E('5S=6%R:6\`4F5G:7-T
M<F\@9&4@=7-U87)I;W,`17-T82!S961E('1I96YE(&1E<V%C=&EV861O(&5L
M(')E9VES=')O(&1E('5S=6%R:6]S+@!.;R!S92!H82!E;F-O;G1R861O(&QA
M(&ED96YT:61A9`!5<W5A<FEO`%EA(&5X:7-T92!E;"!N;VUB<F4@9&4@=7-U
M87)I;R`B)7,B+@!5<W5A<FEO.@!5<W5A<FEO.B``57-U87)I;W,@96X@96P@
M<VES=&5M83H`57IB96MI<W3A;@!.;R!E>&ES=&4@96P@9&ER96-T;W)I;R!6
M1E,N`$%U<V5N8VEA`$QA<R!U8FEC86-I;VYE<R!VX6QI9&%S(&5N8V]N=')A
M9&%S(&EN8VQU>65N.B``5F%L:61E>@!686QO<B!E;B!M:6YU=&]S(&$@<&%R
M=&ER(&1E(&%H;W)A+@!%;"!V86QO<B!E>&-E9&4@96P@=&%M8?%O(&WA>&EM
M;R!D92`E<RX`5F%L;W)E<P!686QO<F5S(&$@<V5L96-C:6]N87(`5F%N=6%T
M=0!687)I86)L90!696YE>G5E;&$`2&$@9F%L;&%D;R!L82!C;VUP<F]B86-I
M\VX@+2!E<W1E(&UE;G-A:F4@<'5E9&4@:&%B97)S92!F;W)Z861O+@!$:7)E
M8W1O<FEO(%9E<FES:6=N`%9E<G-I\VX`0RX@=F5R<VEO;F5S`$%L:6YE86-I
M\VX@=F5R=&EC86P`36%R9V5N('9E<G1I8V%L`%9E<G1I8V%L.@!-=7D@86QT
M80!6:65T;F%M`%9I971N86UI=&$@*%9)4T-)22D`5F5R("(E<R(`5F5R("5S
M`%9E<B!C;VYT86-T;P!697(@=6YA('#A9VEN82!W96(@97AT97)N80!697(@
M8V]M;R`E<P!6:7-T82!M;W-T<F%D82!P;W(@;VUI<VGS;CH`27-L87,@5NUR
M9V5N97,L($)R:73A;FEC87,`27-L87,@5NUR9V5N97,L(%4N4RX`5FES:6)I
M;&ED860`5FES:6)I;&ED860Z(`!6;V1A9F]N92!D92!)=&%L:6$@;65D:6%N
M=&4@4TU44`!!5DE33P"AH:%!1%9%4E1%3D-)02$A(2!%3$E-24Y%($U!3E5!
M3$U%3E1%($5,($=52=-.($1%("5S+@!724X@<&]R($A45%``5V%L;&ES('D@
M1G5T=6YA`$%D=F5R=&5N8VEA`$UI90!0<F5V:7-I\VX@9&5L('1I96UP;P!$
M871O<R!D96P@=&EE;7!O('-U;6EN:7-T<F%D;W,@<&]R`%=E871H97(N8V]M
M`%=E8@!3961E(%=E8@!54DP@9&4@<V5D92!796(`4V5M86YA;&UE;G1E`$)I
M96YV96YI9&\`0FEE;G9E;FED;W,@82`E<P!":65N=F5N:61O+"`E<P!/97-T
M92`H25-/+3@X-3DM,2D`3V5S=&4@*$E33RTX.#4Y+3$U*0!3X6AA<F$@3V-C
M:61E;G1A;`"_477I(&%P;&EC86-I\VX@9&5B97+M82!M;W-T<F%R("5S(&%L
M(&EN:6-I87(@;&$@<V5S:?-N/P"_0W7A;"!E<R!E;"!C87+A8W1E<B!D96QI
M;6ET861O<C\`OT-UX6P@97,@96P@8V%RX6-T97(@9&4@8VET861O/P!-87!A
M(&1E(&QO8V%L:7IA8VGS;B!D92!!=7-T<F%L:6$`477I(&9A<V5S`%!L=6=I
M;G,@:&%B:6QI=&%D;W,@9&5L(&5D:71O<B!D92!T97AT;R!E;G)I<75E8VED
M;RX`06YC:'5R80!!;F-H=7)A(&5N('5N:61A9&5S($-34P!!;F-H=7)A(&1E
M;"!M96[Z("5S(&EZ<75I97)D;R`H9&ES<&]N:6)L92!E;B!L82!P<O-X:6UA
M('-E<VGS;BDZ`$%N8VAU<F$@9&4@;&$@=&%B;&$`56YI9&%D97,@9&4@86YC
M:'5R80!!;F-H=7)A.@!7:6MI`%9I96YT;P!6:65N=&\@;6%T=71I;F$`5F5L
M;V-I9&%D(&1E;"!V:65N=&\@96X@;G5D;W,`5FEE;G1O.@!6:65N=&\Z(`!3
M86)I9'5R[6$`1&5S96]S`$5M<&QE;P!$:7)E8V-I\VX@9&5L('1R86)A:F\`
M0VEU9&%D(&1E;"!T<F%B86IO`%!A[7,@9&5L('1R86)A:F\`5&5LZ69O;F\@
M9&5L('1R86)A:F\`0_-D:6=O('!O<W1A;"!D96P@=')A8F%J;P!%<W1A9&\O
M<')O=FEN8VEA(&1E;"!T<F%B86IO`$1I<F5C8VGS;B!D96P@=')A8F%J;P!.
M^FUE<F\@97)R\VYE;R!D92!C86UP;W,@96X@;&$@;.UN96$@)60N(%-E(&5S
M<&5R86)A;B`E9"!Y(&AA>2`E9"X`3OIM97)O(&5R<O-N96\@9&4@8V%M<&]S
M+B!392!E<W!E<F%B86X@)60@>2!H87D@)60N`$]F9G-E="`E9"!E<G+S;F5O
M(&%L(&QE97(@=6X@87)C:&EV;R!61E,N`%@M4F5F`$QI;6ET86-I;VYE<R!B
MX7-I8V%S(%@U,#EV,P!5<V\@9&4@8VQA=F4@97AT96YD:61A(%@U,#EV,P!.
M;VUB<F4@86QT97)N871I=F\@9&4@87-U;G1O(%@U,#EV,P!)9&5N=&EF:6-A
M9&]R(&1E(&-L879E(&1E(&%S=6YT;R!8-3`Y=C,`17AT96YS:6]N97,@6#4P
M.78S`$%!`$%!04$`H4UA<&$@9&4@66%H;V\A`$%N=6%L;65N=&4`665M96X`
M4^T`4^TL(&QO(&%C97!T;P!%<W3A(&5N($U/1$\@5$585$\N(%5T:6QI8V4@
M96P@8F]T\VX@6SP^72!P87)A(')E9W)E<V%R(&%L(&UO9&\@5UE325=91RX`
M3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A(&-R96%R(&WA<R!D92`E
M9"!B;&]Q=65S+@!.;R!D:7-P;VYE(&1E('!R:79I;&5G:6]S('!A<F$@8W)E
M87(@;>%S(&1E("5D(&-O;G1A8W1O<R!E;B`B)7,B+@!.;R!E<W3A(&%U=&5N
M=&EF:6-A9&\N`$YO('!U961E(&EN8VQU:7(@96P@8V%RX6-T97(@(EPB(&5N
M(&5L(&YO;6)R92!C;VUP;&5T;RX`3F\@:6YT<F]D=6IO('5N82!D:7)E8V-I
M\VX@9&4@8V]R<F5O(';A;&ED82X`3F\@87-O8VGS(&YI;F=U;F\@9&4@;&]S
M(&-A;7!O<R!D96P@87)C:&EV;R!I;7!O<G1A9&\@82!L;W,@8V%M<&]S(&-O
M<G)E<W!O;F1I96YT97,@9&4@)7,N`$YO(&1I<W!O;F4@9&4@<')I=FEL96=I
M;W,@<&%R82!V97(@97-T92!C;VYT86-T;RX`3F\@9&ES<&]N92!D92!P<FEV
M:6QE9VEO<R!P87)A('9E<B!E<W1E(&]B:F5T;RX`3F\@9&ES<&]N92!D92!P
M<FEV:6QE9VEO<R!P87)A(&5L:6UI;F%R(&5S=&4@;W)I9V5N+@!(82!S86QI
M9&\@9&4@;&$@<V5S:?-N+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N^FUE
M<F\@9&4@=&5LZ69O;F\@;?-V:6P@=N%L:61O+"!S\VQO(&3M9VET;W,@8V]N
M('5N("<K)R!O<&-I;VYA;"!P87)A(&5L('!R969I:F\@9&4@;&QA;6%D82!I
M;G1E<FYA8VEO;F%L+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!V86QO<B!V
MX6QI9&\N`%!A<F$@=7-A<B!!;'1A<R!T:65N92!Q=64@8V]N9FEG=7)A<B!U
M;B!M;W1O<B!D92!$871A5')E92X`5&EE;F4@<75E(&-O;F9I9W5R87(@=6X@
M;6]T;W(@5D93+@!$96)E(&1E<V-R:6)I<B!E;"!P<F]B;&5M82!A;G1E<R!D
M92!E;G9I87(@96P@:6YF;W)M92X`5&EE;F4@<75E(&EN=')O9'5C:7(@;&$@
M55),(&$@;&$@<75E(&%P=6YT82!E<W1E(';M;F-U;&\`5&EE;F4@<75E('-E
M;&5C8VEO;F%R('5N82!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&1E(&1E<W1I
M;F\N`%1I96YE('%U92!S96QE8V-I;VYA<B!U;F$@;&ES=&$@9&4@9&5S=&EN
M;RX`5&EE;F4@<75E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R(&$@96QI;6EN
M87(N`%!R:6UE<F\@=&EE;F4@<75E('-E;&5C8VEO;F%R(&%L(&UE;F]S('5N
M(&-O;G1A8W1O+@!0<FEM97)O('1I96YE('%U92!S96QE8V-I;VYA<B!A;"!M
M96YO<R!U;F$@96YT<F%D82X`5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S
M=6%R:6\@82!E;&EM:6YA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S
M=6%R:6\@82!E;&EM:6YA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S
M=6%R:6\@82!A\6%D:7(N`%1I96YE('%U92!E<W!E8VEF:6-A<B!E;"!U<W5A
M<FEO(&$@86-T=6%L:7IA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('%UZ2!A
M8V-I\VX@<V4@96IE8W5T87+A+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N
M=65V;R!N;VUB<F4@9&4@8V%T96=O<NUA+@!4:65N92!Q=64@:6YT<F]D=6-I
M<B!U;B!N^FUE<F\@9&4@=&5LZ69O;F\@:71A;&EA;F\`4_-L;R!D:7-P;VYE
M(&1E('!R:79I;&5G:6]S('!A<F$@=F5R(&5S=&4@8V]N=&%C=&\N`$AA(&5X
M<&ER861O('-U('-E<VGS;B`E<RX@5G5E;'9A(&$@:6YI8VEA<B!S97-I\VXN
M`%-U(&1I<F5C8VGS;B!D92!C;W)R96\`1&ER96-C:?-N($1E.@!3=2!I;F9O
M<FUA8VGS;@!(82!C86UB:6%D;R!S=2!D:7)E8V-I\VX@9&4@26YT97)N970@
M9&5S9&4@96P@8V]M:65N>F\@9&4@<W4@<V5S:?-N("5S+B!0;W(@<F%Z;VYE
M<R!D92!S96=U<FED860@=&EE;F4@<75E('9O;'9E<B!A(&EN:6-I87(@;&$@
M<V5S:?-N+@!3=2!N;VUB<F4`4W4@;6]T;W(@9&4@875T96YT:69I8V%C:?-N
M(&YO('!E<FUI=&4@8?%A9&ER('5S=6%R:6]S+B!3:2!Q=6ES:65R82!U<V%R
M($AO<F1E('!A<F$@861M:6YI<W1R87(@8W5E;G1A<R!D92!U<W5A<FEO+"!T
M96YD<N$@<75E('5T:6QI>F%R('5N(&UO=&]R(&1E(&%U=&5N=&EF:6-A8VGS
M;B!D:7-T:6YT;RX`4W4@;6]T;W(@9&4@875T96YT:69I8V%C:?-N(&YO('!E
M<FUI=&4@;&ES=&%R('5S=6%R:6]S+"!O('-E(&AA(&1E<VAA8FEL:71A9&\@
M;&$@8V%R86-T97+M<W1I8V$@<&]R(&%L9_IN(&UO=&EV;RX`4&%R96-E('%U
M92!H82!C86UB:6%D;R!S=2!N879E9V%D;W(@9&5S9&4@96P@8V]M:65N>F\@
M9&4@<W4@<V5S:?-N("5S+B!0;W(@<F%Z;VYE<R!D92!S96=U<FED860@=&EE
M;F4@<75E('9O;'9E<B!A(&EN:6-I87(@;&$@<V5S:?-N+@!3=2!N879E9V%D
M;W(@;F\@861M:71E(&5S=&$@8V%R86-T97+M<W1I8V$N`$5L(&YA=F5G861O
M<B!N;R!A9&UI=&4@97-T82!O<&-I\VX@9&4@:6UP<F5S:?-N+B!0<F5S:6]N
M92!#;VYT<F]L+T-O;6%N9&\@*R!0('!A<F$@:6UP<FEM:7(N`%IO;F$@:&]R
M87)I82!A8W1U86PZ`$QA(&QI8G)E=&$@<&]R(&]M:7-I\VX@;F\@<V4@<'5E
M9&4@:&]J96%R+@!392!H82!C86UB:6%D;R!S=2!I9&5N=&ED860@<&]R(&]M
M:7-I\VXN`$ED96YT:61A9"!P;W(@;VUI<VGS;CH`3F]M8G)E(&-O;7!L971O
M.@!392!H82!A9V]T861O('-U('1I96UP;R!D92!C;VYE>&GS;BX`3&$@;G5E
M=F$@8V]N=')A<V7Q82!P87)A("5S(&5S.B`E<P!392!H86X@86-T=6%L:7IA
M9&\@<W5S(&]P8VEO;F5S('/S;&\@<&]R(&QA(&1U<F%C:?-N(&1E(&QA('-E
M<VGS;BX`4V4@:&%N(&%C='5A;&EZ861O('-U<R!O<&-I;VYE<RX`4V4@:&$@
M<F5A:G5S=&%D;R!S=2!C;VYT<F%S9?%A`%-E(&AA(')E86IU<W1A9&\@<W4@
M8V]N=')A<V7Q82P@8V]M<')U96)E(&5L(&-O<G)E;R!E(&EN:6-I92!S97-I
M\VX@8V]N('-U(&YU979A(&-O;G1R87-E\6$N`$QA(&-O;G1R87-E\6$@:&$@
M97AP:7)A9&\N`%-E<G9I9&]R97,@<F5M;W1O<SH`675G;W-L879I80!:86ER
M90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6T]C=6QT87(@=&5X=&\@8VET861O
M70!;26YF;W)M92!D92!P<F]B;&5M85T`6TUO<W1R87(@=&5X=&\@8VET861O
M("T`6TUO<W1R87(@=&5X=&\@8VET861O("T@)7,@;.UN96%S70!;;.UN96$@
M)7,@9&4@)7-=`%MS:6X@=F%L;W)=`%]!9&UI;FES=')A8VGS;@!?17AA;6EN
M87(`7T-,20!?0V]N=&%C=&]S`,%R7V)O;"!D871O<P!%;&E?;6EN87(`15]L
M:6UI;F%R(&9I;&$`7T=R=7!O<P!!7WEU9&$`4')O<&EE9&%D97,@9&4@7VEM
M86=E;BXN+@!?26UP;W)T87(O17AP;W)T87(`7TQI<W1A<P!?26YI8VEA<B!S
M97-I\VX`7U-A;&ER`$UO9&EF:6-A<B!?=NUN8W5L;RXN+@!?36ES(&QI8G)E
M=&%S`%]!\6%D:7(`7T]P8VEO;F5S`%]0<FEV:6QE9VEO<P!?16QI;6EN87(@
M=NUN8W5L;RXN+@!%7VQI;6EN87(@9&4@97-T82!L:7-T80!?0G5S8V%R`$-O
M;E]F:6=U<F%C+@!0<F]P:65D861E<R!D92!?=&%B;&$N+BX`7U5S=6%R:6]S
M`&1I<F5C8VEO;F5S`&1E<W1I;F%T87)I;R!D97-C;VYO8VED;P!A9V5N9&$`
M8V%L;6$`;F\@<V4@<'5E9&4@8W)E87(@96P@87)C:&EV;R!D92!D97-T:6YO
M`&YO('-E('!U961E(&%B<FER(&5L(&]R:6=E;@!P=6QS92!A<77M`&5R<F]R
M(&1E(&SM;F5A(&1E(&-O;6%N9&\`97)R;W(@9&4@8V]N9FEG=7)A8VGS;@!C
M;VYT86-T;RYV8V8`8V]N=&%C=&]S+F-S=@!C;VYT86-T;W,N='-V`&-O;G1A
M8W1O<RYV8V8`9F%L=&$@=6X@87)C:&EV;R!C<NUT:6-O(&1E;"!S:7-T96UA
M`&5R<F]R(&1E(&9O<FUA=&\@9&4@9&%T;W,`;6]D:69I8V%R`&5N=')A9&$@
M;F\@96YC;VYT<F%D80!D97-C96YS;P!A<F-H:79O`&1E;"`E<R`H)7,I(&$@
M;&%S("5S("5S`'9E;G1O<V\`:#H`:&@`;F]M8G)E(&1E(&%N9FET<FGS;B!D
M97-C;VYO8VED;P!I;FUE9&EA=&%M96YT90!E;B!L[6YE80!E<G)O<B!D92!E
M;G1R861A+W-A;&ED80!E<G)O<B!D92!S;V9T=V%R92!I;G1E<FYO`&SM;F5A
M<UT`8_-D:6=O(&1E(&5R<F]R(&UK:7-O9G,@)60@86P@<F5A;&EZ87(@25-/
M+@!M;0!N;VUB<F4`<VEN(&9O<FUA=&\`;FEN9W5N;P!S:6X@9&5S87)R;VQL
M87(`8?IN(&YO('-E(&AA(&1E<V%R<F]L;&%D;P!N;W1A<P!P;W)C96YT86IE
M`'!R:79I;&5G:6\@9&5N96=A9&\`<.UX96QE<P!E<G)O<B!R96UO=&\@9&4@
M<')O=&]C;VQO`&5N(&%U;65N=&\`<V5R=FEC:6\@;F\@9&ES<&]N:6)L92X`
M;6]S=')A<B!D:69E<F5N8VEA<P!S;7,R96UA:6P@<&]R($A45%``<W,`97-T
M86)L90!E<G)O<B!D96P@<VES=&5M80!T87)E87,`9F%L;&\@=&5M<&]R86P`
M=6YA($QI<W1A`'5N82!,:6)R971A(&1E(&1I<W1I;G1A`&5S8W)I8F$@9&]S
M('9E8V5S(&QA(&-O;G1R87-E\6$@<&%R82!C;VYF:7)M87)L80!U;FEF:6-A
M9&\`<VEN(&YO;6)R90!U<W5A<FEO('-E;&5C8VEO;F%D;P!V0V%R9`!W.@!W
M96%T:&5R+F-O;0``````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O97-?
M15,O:&5L<"YX;6P`````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U
M,3,W`#$P-#$W,S8R-S4U`#`R,30U-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M
M+2`D2&]R9&4Z('1U<F)A+VQO8V%L92]E<U]%4R]H96QP+GAM;"QV(#$N,B`R
M,#`T+S$R+S$P(#$S.C0P.C$U(&IA;B!%>'`@)"`M+3X*/&AE;'`^"@H\96YT
M<GD@:60](D]V97)V:65W(B!M9#4](C(Y,#4P-F%D931E-F8W-#DR-#9F-S=B
M8F4U9#0X.#,U(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DEN=')O
M9'5C8VDF(WA&,SMN/"]T:71L93X*("`@(#QH96%D:6YG/DEN=')O9'5C8VDF
M(WA&,SMN/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!,82!L:6)R971A(&1E
M(&1I<F5C8VEO;F5S(&]F<F5C92!U;B!M)B-X13D[=&]D;R!Y(&QU9V%R(&%D
M96-U861O<R!P87)A(&%L;6%C96YA<B!L82!I;F9O<FUA8VDF(WA&,SMN(&1E
M(&-O;G1A8W1O<R!P87)A('-U(&,F(WA&,SMM;V1A(')E8W5P97)A8VDF(WA&
M,SMN('D@=7-O+B!%;B!F=6YC:28C>$8S.VX@9&4@8R8C>$8S.VUO(&AA>6$@
M8V]N9FEG=7)A9&\@96P@<VES=&5M82!E;"!A9&UI;FES=')A9&]R+"!P=65D
M92!D:7-P;VYE<B!D92!L:6)R971A<R!D92!D:7)E8V-I;VYE<R!P<FEV861A
M<R!A<R8C>$5$.R!C;VUO(&%C8V5D97(@82!S97)V:6-I;W,@9&4@9&ER96-T
M;W)I;R!D92!R960@<"8C>$9!.V)L:6-O<RX@5&%M8FDF(WA%.3MN(&%D;6ET
M92!L:7-T87,@9&4@9&ES=')I8G5C:28C>$8S.VX@9&4@9F]R;6$@<75E('!U
M961A(&-R96%R('-U<R!P<F]P:6%S(")L:7-T87,@9&4@8V]R<F5O(BX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB;65N=2UA9&0B(&UD-3TB
M,V,Q9CDR96(Q83@R.#,Y-#`T9#$Q9#EB,&$R,&(S8V4B('-T871E/2)U<'1O
M9&%T92(^"B`@("`\=&ET;&4^365N)B-X1D$[.B!!)B-X1C$[861I<CPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY!)B-X1C$[861I<CPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@028C>$8Q.V%D92!U;B!U<W5A<FEO(&$@;&$@;&EB<F5T82!D
M92!D:7)E8V-I;VYE<RX@4R8C>$8S.VQO('-E('!U961E(&$F(WA&,3MA9&ER
M('5S=6%R:6]S(&$@;&%S(&QI8G)E=&%S(&1E(&1I<F5C8VEO;F5S('-I(&1I
M<W!O;F4@9&4@<')I=FEL96=I;W,@9&4@97-C<FET=7)A+B!3:2!E<W0F(WA%
M,3MN(&%C=&EV861A<R!L:6)R971A<R!D92!D:7)E8V-I;VYE<R!C;VUP87)T
M:61A<R!O('`F(WA&03MB;&EC87,L(&$@;65N=61O<R!S;VX@9&4@<R8C>$8S
M.VQO(&QE8W1U<F$@>2!N;R!P;V1R)B-X13$[(&$F(WA&,3MA9&ER(&-O;G1A
M8W1O<R!E;B!E;&QA<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I
M9#TB;65N=2US96%R8V@B(&UD-3TB.&1A9C@Q86(R.#8P,F0W-S(S-3AA,3<T
M-3<Q9CEA9#(B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^365N)B-X
M1D$[.B!"=7-C87(\+W1I=&QE/@H@("`@/&AE861I;F<^0G5S8V%R/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!,92!P97)M:71E(&)U<V-A<B!E;B!U;F$@
M;&EB<F5T82!D92!D:7)E8V-I;VYE<R!P87)A(&QO8V%L:7IA<B!I;F9O<FUA
M8VDF(WA&,SMN+B!392!T<F%T82!D92!U;F$@8B8C>$9!.W-Q=65D82!S96YC
M:6QL82!Q=64@<R8C>$8S.VQO(&QE('!E<FUI=&ER)B-X13$[(&)U<V-A<B!P
M;W(@86QG=6YO<R!C86UP;W,@8B8C>$4Q.W-I8V]S+B!.;W)M86QM96YT92!E
M;"!N;VUB<F4@>2!L82!D:7)E8V-I)B-X1C,[;B!D92!C;W)R96\L('!E<F\@
M<'5E9&4@=F%R:6%R(&1E<&5N9&EE;F1O(&1E(&,F(WA&,SMM;R!H87EA(&-O
M;F9I9W5R861O(&5L(&%D;6EN:7-T<F%D;W(@;&$@;&EB<F5T82X*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@4&%R82!U;F$@8B8C>$9!.W-Q=65D82!M
M)B-X13$[<R!C;VUP;&5J82P@<'5E9&4@=71I;&EZ87(@;&$@(CQR968@;6]D
M=6QE/2)T=7)B82(@96YT<GD](FUE;G4M861V86YC960M<V5A<F-H(CY")B-X
M1D$[<W%U961A(&%V86YZ861A/"]R968^(B!Q=64@;&4@<&5R;6ET:7(F(WA%
M,3L@8G5S8V%R(&5N(&]T<F]S(&-A;7!O<RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*"CQE;G1R>2!I9#TB;65N=2UA9'9A;F-E9"US96%R8V@B(&UD-3TB-F)E
M-S`S9F9E8F$V,31F-F%D83$U,3<T.69A-#1A8C4B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^365N)B-X1D$[.B!")B-X1D$[<W%U961A(&%V86YZ
M861A/"]T:71L93X*("`@(#QH96%D:6YG/D(F(WA&03MS<75E9&$@879A;GIA
M9&$\+VAE861I;F<^"B`@("`\<&%R83X*("`@($QE('!E<FUI=&4@8G5S8V%R
M(&5N('5N82!L:6)R971A(&1E(&1I<F5C8VEO;F5S('!A<F$@;&]C86QI>F%R
M(&EN9F]R;6%C:28C>$8S.VXN($5S=&4@;28C>$4Y.W1O9&\@9&4@8B8C>$9!
M.W-Q=65D82!L92!P97)M:71E(&)U<V-A<B!E;B!V87)I;W,@8V%M<&]S+B!,
M;W,@8V%M<&]S(&1I<W!O;FEB;&5S('!A<F$@;&$@8B8C>$9!.W-Q=65D82!D
M97!E;F1E;B!D92!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&5N(&QA('%U
M92!E<W0F(WA%.3L@8G5S8V%N9&\N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\
M96YT<GD@:60](FUE;G4M:6UP;W)T(B!M9#4](C-C-F,T,&8R838R,3-E.69C
M,68Y83<W.#(W8F9B-60T(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/DUE;B8C>$9!.SH@26UP;W)T87(O17AP;W)T87(\+W1I=&QE/@H@("`@/&AE
M861I;F<^26UP;W)T87(O17AP;W)T87(\+VAE861I;F<^"@H@("`@/'!A<F$^
M"B`@("!%<W1E(&UE;B8C>$9!.R!P97)M:71E(&QA(&EM<&]R=&%C:28C>$8S
M.VX@;R!E>'!O<G1A8VDF(WA&,SMN(&$@;R!D97-D92!S=2!L:6)R971A(&1E
M(&1I<F5C8VEO;F5S('!E<G-O;F%L+B!3;W!O<G1A('1A;G1O(&5L(&9O<FUA
M=&\@0U-6("A686QO<F5S('-E<&%R861O<R!P;W(@8V]M87,I(&1E($]U=&QO
M;VL@8V]M;R!E;"!V0V%R9"!A<R8C>$5$.R!C;VUO(&%L9W5N;W,@;W1R;W,@
M9F]R;6%T;W,@:&%B:71U86QE<RX*("`@(#PO<&%R83X*"B`@("`\:&5A9&EN
M9SY);7!O<G1A<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4&%R82!I;7!O
M<G1A<B!U;F$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RP@;F5C97-I=&$@=&5N
M97(@96X@;&$@;28C>$4Q.W%U:6YA(&QO8V%L("AE;B!L82!Q=64@<V4@96IE
M8W5T82!E;"!N879E9V%D;W(@=V5B*2!L;W,@9&%T;W,@9&4@;&$@;&EB<F5T
M82!D92!D:7)E8V-I;VYE<R!Q=64@<75I97)A(&EM<&]R=&%R+B!087)A(&5L
M;&\@<')I;65R;R!T96YD<B8C>$4Q.R!Q=64@97AP;W)T87(@;&$@:6YF;W)M
M86-I)B-X1C,[;B!D92!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&1E('-U
M(&-L:65N=&4@9&4@8V]R<F5O(&%C='5A;"X*("`@(#PO<&%R83X*"B`@("`\
M<&%R83X*("`@(%-I('5T:6QI>F$@3W5T;&]O:R!%>'!R97-S.@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("`Q*2!396QE8V-I;VYE(&5L(&UE;B8C>$9!
M.R!!<F-H:79O("9G=#L@17AP;W)T87(@)F=T.R!,:6)R971A(&1E(&1I<F5C
M8VEO;F5S"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#(I(%-E;&5C8VEO
M;F4@(D%R8VAI=F\@9&4@=&5X=&\B("A686QO<F5S('-E<&%R861O<R!P;W(@
M8V]M87,I(&5N(&QA(")(97)R86UI96YT82!D92!E>'!O<G1A8VDF(WA&,SMN
M(&1E(&1I<F5C8VEO;F5S(BX@4'5L<V4@(D5X<&]R=&%R(BX*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@,RD@16X@96P@8V%M<&\@(D=U87)D87(@87)C
M:&EV;R!E>'!O<G1A9&\@8V]M;R(@97-C<FEB82!U;B!N;VUB<F4@<&%R82!L
M82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B!0=6QS92`B4VEG=6EE;G1E(BX*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@-"D@06-T:79E(&QA(&-A<VEL
M;&$@9&4@;&$@:7IQ=6EE<F1A(&1E(&-A9&$@=6YO(&1E(&QO<R!C86UP;W,@
M<75E(&1E<V5E(&5X<&]R=&%R+B!0=6QS92`B5&5R;6EN87(B+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("`U*2!$96)E<B8C>$5$.V$@96P@<VEG=6EE
M;G1E(&UE;G-A:F4@:6YF;W)M871I=F\@)U!R;V-E<V\@9&4@97AP;W)T86-I
M)B-X1C,[;B!D92!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S('1E<FUI;F%D
M;R<N(%!U;'-E("=!8V5P=&%R)RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@-BD@4'5L<V4@)T-E<G)A<B<@96X@;&$@)TAE<G)A;6EE;G1A(&1E(&5X
M<&]R=&%C:28C>$8S.VX@9&4@9&ER96-C:6]N97,G('D@8VEE<G)E($]U=&QO
M;VL@17AP<F5S<RX*("`@(#PO<&%R83X*"B`@("`\=&EP/@H@("`@4VD@96P@
M87)C:&EV;R!D92!D:7)E8V-I;VYE<R!E>'!O<G1A9&\@;F\@97-T)B-X13$[
M(&5N('-U(&5S8W)I=&]R:6\@>2!E<W0F(WA%,3L@=71I;&EZ86YD;R!U;B!S
M:7-T96UA(&]P97)A=&EV;R!7:6YD;W=S+"!P=6QS92!E;"!M96XF(WA&03L@
M26YI8VEO("9G=#L@0G5S8V%R("9G=#L@07)C:&EV;W,@;R!#87)P971A<R!Y
M(&)U<W%U92!E;B!S=2!U;FED860@9&4@9&ES8V\@9'5R;R!P<FEN8VEP86P@
M96P@;F]M8G)E(&1E(&%R8VAI=F\@<75E('5T:6QI>B8C>$8S.R!E;B!E;"!P
M87-O(#,N($%N;W1E(&QA(&QO8V%L:7IA8VDF(WA&,SMN(&1E;"!A<F-H:79O
M+@H@("`@/"]T:7`^"@H@("`@/'!A<F$^"B`@("!087)A(&EM<&]R=&%R('5N
M82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+"!A8G)A(&QA(&QI8G)E=&$@9&4@
M9&ER96-C:6]N97,@82!L82!Q=64@9&5S964@:6UP;W)T87(@;&$@:6YF;W)M
M86-I)B-X1C,[;BX@4'5L<V4@96P@:6-O;F\@(DEM<&]R=&%R+T5X<&]R=&%R
M(BX@4V5L96-C:6]N92!E;B!E;"!L:7-T861O(&1E<W!L96=A8FQE(&5L('1I
M<&\@9&4@87)C:&EV;R!D92!D871O<R!D92!I;F9O<FUA8VDF(WA&,SMN(&1E
M(&1I<F5C8VEO;F5S('%U92!D97-E92!I;7!O<G1A<BX@4'5L<V4@96P@8F]T
M)B-X1C,[;B`B17AA;6EN87(B('!A<F$@;&]C86QI>F%R(&5L(&%R8VAI=F\@
M9&4@9&%T;W,@9&4@9&ER96-C:6]N97,@96X@<W4@;W)D96YA9&]R+B!396QE
M8V-I;VYE(&5L(&%R8VAI=F\@>2!P=6QS92!E;"!B;W0F(WA&,SMN(")3:6=U
M:65N=&4B+B!3:6=A(&QA<R!I;G-T<G5C8VEO;F5S('D@;&$@:6YF;W)M86-I
M)B-X1C,[;B!D96P@87)C:&EV;R!S92!I;7!O<G1A<B8C>$4Q.R!A('-U(&QI
M8G)E=&$@9&4@9&ER96-C:6]N97,N"B`@("`\+W!A<F$^"B`@("`\=&EP/@H@
M("`@06QG=6YA<R!E;G1R861A<R!C;VUP;&5J87,@;R!C=7EO<R!C86UP;W,@
M;F\@8V]I;F-I9&%N(&-O;B!L;W,@9&4@<W4@;&EB<F5T82!D92!D:7)E8V-I
M;VYE<R!P=65D96X@;F\@:6UP;W)T87)S92!C;W)R96-T86UE;G1E+B!%<R!C
M;VYV96YI96YT92!Q=64@8V]M<')U96)E(&QO<R!D871O<R!I;7!O<G1A9&]S
M('1R87,@=6YA(&]P97)A8VDF(WA&,SMN(&1E(&EM<&]R=&%C:28C>$8S.VXN
M"B`@("`\+W1I<#X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB<V5A<F-H:6YG+7-E
M87)C:%]R97-U;'1S(B!M9#4](F9F960X9#<R9F$S8C<Q,&1F.&4Y,#)C,C0Y
M,V(R-31F(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D(F(WA&03MS
M<75E9&$Z(%)E<W5L=&%D;W,@9&4@;&$@8B8C>$9!.W-Q=65D83PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY297-U;'1A9&]S(&1E(&QA(&(F(WA&03MS<75E9&$\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-I('5N82!B)B-X1D$[<W%U961A
M(&]B=&EE;F4@<F5S=6QT861O<RP@<V4@;6]S=')A<B8C>$4Q.VX@96X@96P@
M)B-X13$[<F5A(&1E(")297-U;'1A9&]S(&1E(&QA(&(F(WA&03MS<75E9&$B
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!0=6QS86YD;R!E;B!U;B!C
M86UP;R!D92`B0V]R<F5O(B!S92!A8G)I<B8C>$4Q.R!U;F$@=F5N=&%N82!D
M92!R961A8V-I)B-X1C,[;B!D92!M96YS86IE<R!P87)A(&5N=FEA<B!C;W)R
M96\@82!E<V$@9&ER96-C:28C>$8S.VXN(%!U;'-A;F1O(&5N('5N(&-A;7!O
M(&1E(").;VUB<F4B('-E(&UO<W1R87(F(WA%,3L@96P@<F5G:7-T<F\@9&4@
M97-E(&YO;6)R92!D92!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+"!P97)M
M:71I)B-X13D[;F1O;&4@;6]D:69I8V%R(&\@96QI;6EN87(@;&$@96YT<F%D
M82X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@16X@9G5N8VDF(WA&,SMN
M(&1E(&,F(WA&,SMM;R!H87EA(&-O;F9I9W5R861O(&5L('-I<W1E;6$@<W4@
M861M:6YI<W1R861O<BP@;&]S(')E<W5L=&%D;W,@9&4@;&%S(&(F(WA&03MS
M<75E9&%S('!O9'(F(WA%,3MN('-E<B!A8W5M=6QA=&EV;W,N($-A9&$@8B8C
M>$9!.W-Q=65D82!A)B-X1C$[861I<B8C>$4Q.R!L;W,@<F5S=6QT861O<R!N
M=65V;W,@82!L;W,@97AI<W1E;G1E<RX@)B-X0SD[<W1O(&5S("8C>$9!.W1I
M;"!A;"!E;&%B;W)A<B!L:7-T87,N(%!A<F$@96QI;6EN87(@;&]S(')E<W5L
M=&%D;W,@9&4@8B8C>$9!.W-Q=65D87,@86-U;75L861A<R!Y(&5M<&5Z87(@
M=6YA(&YU979A+"!P=6QS92!E;"!V)B-X140[;F-U;&\@(DQI;7!I87(@8B8C
M>$9!.W-Q=65D82(N"B`@("`\+W!A<F$^"@H@("`@/'1I<#X*("`@($%L('9E
M<B!U;B!L:7-T861O(&1E(&5N=')A9&%S+"!P=65D92!O<F1E;F%R;&%S('!O
M<B!C861A('5N;R!D92!L;W,@8V%M<&]S(&UO<W1R861O<R!P=6QS86YD;R!E
M;B!L82!C86)E8V5R82!D92!C;VQU;6YA(&%D96-U861A+B!087)A(&-O;FUU
M=&%R(&5L('-E;G1I9&\@9&4@;&$@8VQA<VEF:6-A8VDF(WA&,SMN(&5N=')E
M(&%S8V5N9&5N=&4@>2!D97-C96YD96YT92P@<'5L<V4@96P@:6-O;F\@9&4@
M9FQE8VAA(&1E(&QA(&-A8F5C97)A(&1E(&QA(&-O;'5M;F$N"B`@("`\+W1I
M<#X*/"]E;G1R>3X*"CPO:&5L<#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O9FE?1DDO````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U
M`#`Q-S<U-@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]F
M:5]&22],0U]-15-304=%4R\`````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-34`,#(Q-30S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O='5R8F$O;&]C86QE+V9I7T9)+TQ#7TU%4U-!1T53+W1U<F)A+FUO````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#0V,S0U,P`Q,#0Q-S,V,C<U-0`P,C,R,S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````WA($E0``
M``"1"```'````*1$``!O"P``+(D```````#HM@``#@```.FV```/````^+8`
M``T````(MP``"````!:W```+````'[<```P````KMP``&0```#BW```9````
M4K<```0```!LMP``*0```'&W```8````F[<``!L```"TMP``+0```-"W```=
M````_K<``"0````<N```*0```$&X```I````:[@``!D```"5N```*````*^X
M```D````V+@``"4```#]N```)@```".Y```,````2KD``"0```!7N0``#P``
M`'RY```+````C+D```X```"8N0``!0```*>Y```H````K;D```@```#6N0``
M"@```-^Y```5````ZKD```D`````N@``$@````JZ```+````';H``!T````I
MN@``A0```$>Z```.````S;H```H```#<N@``#0```.>Z```.````];H``!$`
M```$NP``#0```!:[```,````)+L```T````QNP``!@```#^[``"4````1KL`
M``H```#;NP``#P```.:[```8````]KL```P````/O```#@```!R\```.````
M*[P```@````ZO```"0```$.\```K````3;P``"X```!YO```&@```*B\```R
M````P[P``#@```#VO```5````"^]``!1````A+T``%H```#6O0``5P```#&^
M```T````B;X```D```"^O@``#0```,B^```'````UKX```H```#>O@``#P``
M`.F^```%````^;X```8```#_O@``$0````:_```(````&+\``!$````AOP``
M"0```#._```)````/;\``"4```!'OP``(````&V_```3````CK\``!,```"B
MOP``$````+:_```/````Q[\```H```#7OP```P```.*_```/````YK\``!0`
M``#VOP``"0````O````-````%<```!(````CP```&0```#;````>````4,``
M``\```!OP```$````'_````A````D,````H```"RP```"````+W````/````
MQL````@```#6P```)````-_````&````!,$``!0````+P0``%@```"#!```(
M````-\$``$X```!`P0``+0```(_!```A````O<$``!D```#?P0``!P```/G!
M```,`````<(``!0````.P@``#0```"/"```2````,<(``"$```!$P@``%P``
M`&;"```I````?L(``"P```"HP@``#@```-7"```#````Y,(```\```#HP@``
M"P```/C"```'````!,,```<````,PP``!0```!3#```%````&L,```H````@
MPP```P```"O#```7````+\,```H```!'PP``#P```%+#```.````8L,``!@`
M``!QPP``(P```(K#```.````KL,```X```"]PP``%````,S#```7````X<,`
M`!<```#YPP``%P```!'$```3````*<0```\````]Q```#@```$W$```?````
M7,0``!T```!\Q```!P```)K$```&````HL0```@```"IQ```#P```++$```&
M````PL0```H```#)Q```$P```-3$```+````Z,0``!````#TQ```%0````7%
M```5````&\4```<````QQ0``$````#G%```%````2L4``!4```!0Q0``$0``
M`&;%```,````>,4``"@```"%Q0``.@```*[%```[````Z<4``#@````EQ@``
M"0```%[&```'````:,8``!0```!PQ@```P```(7&```%````B<8```D```"/
MQ@``$````)G&```)````JL8``!,```"TQ@``.0```,C&```2`````L<``"<`
M```5QP``+````#W'```J````:L<``"4```"5QP``"@```+O'```&````QL<`
M``D```#-QP``!P```-?'```O````W\<``#<````/R```+@```$?(``!5````
M=L@``"T```#,R```+0```/K(```]````*,D``#\```!FR0``+0```*;)``!`
M````U,D``",````5R@``(P```#G*``!`````7<H``"T```">R@``,P```,S*
M```E`````,L``!4````FRP``&0```#S+```I````5LL``"0```"`RP``*```
M`*7+```1````SLL```H```#@RP``#````.O+```*````^,L``!`````#S```
M%@```!3,```6````*\P```<```!"S```!P```$K,```4````4LP```H```!G
MS```"````'+,```G````>\P```@```"CS```#````*S,```'````N<P```<`
M``#!S```!@```,G,```1````T,P```4```#BS```!P```.C,```&````\,P`
M`!0```#WS```"`````S-```I````%<T```X````_S0``"@```$[-```$````
M6<T```<```!>S0``"0```&;-```&````<,T``!$```!WS0``!P```(G-```6
M````D<T```0```"HS0``"````*W-```&````MLT```T```"]S0``!@```,O-
M```>````TLT```8```#QS0``$0```/C-```(````"LX```T````3S@``#```
M`"'.```'````+LX``!$````VS@```P```$C.```#````3,X``!<```!0S@``
M`P```&C.```3````;,X``!T```"`S@``"````)[.```$````I\X```@```"L
MS@``"````+7.``!!````OLX``!H`````SP``'````!O/```K````.,\``"``
M``!DSP``%0```(7/```&````F\\```8```"BSP``%0```*G/```8````O\\`
M`"(```#8SP``+@```/O/```=````*M```"$```!(T```5````&K0```I````
MO]````H```#IT```!P```/30```'````_-```!4````$T0``#@```!K1```*
M````*=$```\````TT0``#0```$31```/````4M$```T```!BT0``"0```'#1
M```4````>M$```8```"/T0``&````);1```=````K]$``!,```#-T0``$0``
M`.'1```4````\]$```0````(T@``!@````W2```4````%-(``%0````IT@``
M9````'[2```$````X](```X```#HT@``#P```/?2```%````!],```4````-
MTP``&P```!/3```:````+],``!,```!*TP``#0```%[3```1````;-,``!$`
M``!^TP``%@```)#3```7````I],``!P```"_TP``*@```-S3```Y````!]0`
M`"(```!!U```,@```&34```0````E]0``"$```"HU```!0```,K4```3````
MT-0```L```#DU```$@```/#4```*`````]4```\````.U0``#0```![5```1
M````+-4``!,````^U0``#````%+5```&````7]4```P```!FU0``!@```'/5
M```7````>M4``!````"2U0``$0```*/5```(````M=4```4```"^U0``#```
M`,35```0````T=4```4```#BU0``#@```.C5```-````]]4``",````%U@``
M!@```"G6```6````,-8``"H```!'U@``!P```'+6```-````>M8```<```"(
MU@``"P```)#6```'````G-8```<```"DU@``#P```*S6```)````O-8```D`
M``#&U@``"@```-#6```9````V]8``#T```#UU@``'0```#/7```,````4=<`
M`!````!>UP``!0```&_7```E````==<``!(```";UP``$P```*[7```5````
MPM<``!(```#8UP``*P```.O7```[````%]@``"````!3V```#@```'38```(
M````@]@``!0```",V```-@```*'8```A````V-@``!````#ZV```"`````O9
M```,````%-D```8````AV0``!````"C9```/````+=D```X````]V0``!P``
M`$S9```*````5-D```T```!?V0``'P```&W9```<````C=D``"$```"JV0``
M'@```,S9```9````Z]D``!X````%V@``&P```"3:```A````0-H``"X```!B
MV@``)@```)':```<````N-H``!X```#5V@``'````/3:```F````$=L``"L`
M```XVP``,P```&3;```F````F-L``"L```"_VP``.````.O;```=````)-P`
M`!4```!"W```+P```%C<```@````B-P``!(```"IW```*0```+S<```>````
MYMP``"`````%W0``$@```";=``"B````.=T``!8```#<W0``(P```//=```H
M````%]X``"D```!`W@``*````&K>```?````D]X``!4```"SW@``(````,G>
M```E````ZMX``"@````0WP``+0```#G?```P````9]\``)(```"8WP``(0``
M`"O@```6````3>```!P```!DX```)@```('@```J````J.```$$```#3X```
M1````!7A```,````6N$```<```!GX0``!P```&_A```&````=^$``!,```!^
MX0``#0```)+A```=````H.$``!````"^X0``$@```,_A```'````XN$``!,`
M``#JX0``$@```/[A```'````$>(```0````9X@``$````![B```0````+^(`
M``P```!`X@``#@```$WB```-````7.(```\```!JX@``$P```'KB```-````
MCN(``"@```"<X@```P```,7B```-````R>(```8```#7X@``$0```-[B```7
M````\.(``!L````(XP``#@```"3C```"````,^,``$D````VXP``!0```(#C
M```0````AN,```\```"7XP``!````*?C```-````K.,```X```"ZXP```P``
M`,GC```.````S>,```@```#<XP``#P```.7C```/````]>,```<````%Y```
M#0````WD```0````&^0```T````LY```&@```#KD```+````5>0```8```!A
MY```$P```&CD```+````?.0``!,```"(Y```#````)SD```*````J>0``!$`
M``"TY```&0```,;D```7````X.0```L```#XY```#0````3E```B````$N4`
M`!8````UY0``#P```$SE```;````7.4``#0```!XY0``"@```*WE```8````
MN.4``!(```#1Y0``&0```.3E```6````_N4``"(````5Y@``(P```#CF```/
M````7.8```T```!LY@``!P```'KF```*````@N8```H```"-Y@``%````)CF
M```+````K>8``"(```"YY@``+P```-SF```+````#.<```D````8YP``&0``
M`"+G```+````/.<``!<```!(YP``%P```&#G```)````>.<```<```""YP``
M%@```(KG```/````H><``!D```"QYP``%@```,OG```.````XN<``!@```#Q
MYP``"`````KH```-````$^@``"8````AZ```*````$CH``!#````<>@```@`
M``"UZ```$@```+[H```?````T>@```@```#QZ```"P```/KH```O````!ND`
M``X````VZ0``#@```$7I```%````5.D```8```!:Z0``10```&'I```#````
MI^D```<```"KZ0``!````+/I```)````N.D``!(```#"Z0``"@```-7I```*
M````X.D```\```#KZ0``$````/OI```7````#.H``!$````DZ@``$0```#;J
M```9````2.H``!<```!BZ@``"0```'KJ```%````A.H```L```"*Z@``"@``
M`);J```"````H>H```4```"DZ@``#0```*KJ```;````N.H``!<```#4Z@``
M%````.SJ```)`````>L```X````+ZP``#0```!KK```2````*.L``#@````[
MZP``(````'3K```(````E>L```X```">ZP``>P```*WK```8````*>P``!@`
M``!"[```/0```%OL```5````F>P``!$```"O[```!P```,'L```%````R>P`
M`",```#/[```,P```//L```8````)^T``!T```!`[0``+@```%[M```>````
MC>T``!L```"L[0``&0```,CM```G````XNT``#<````*[@``)````$+N```;
M````9^X``!D```"#[@``$P```)WN```'````L>X```@```"Y[@``!@```,+N
M```&````R>X``!````#0[@``#P```.'N```0````\>X```\````"[P``"P``
M`!+O```/````'N\```P````N[P``#P```#OO```'````2^\```8```!3[P``
M#@```%KO```,````:>\``"@```!V[P``#P```)_O```(````K^\```8```"X
M[P``$P```+_O```B````T^\``"T```#V[P``"````"3P```3````+?```!X`
M``!!\```)0```&#P```:````AO```!4```"A\```'@```+?P``!#````UO``
M`"$````:\0``(````#SQ```9````7?$``!<```!W\0``)0```(_Q```E````
MM?$``!<```#;\0``%@```//Q```A````"O(``"(````L\@``!````$_R```;
M````5/(```T```!P\@``#````'[R```#````B_(```4```"/\@``"````)7R
M```*````GO(```P```"I\@``"P```+;R```0````PO(```P```#3\@``#@``
M`.#R```+````[_(```0```#[\@``!`````#S```3````!?,``!0````9\P``
M#````"[S```)````._,```X```!%\P``"P```%3S```;````8/,```4```!\
M\P``!P```(+S```$````BO,```8```"/\P``!P```);S```*````GO,```H`
M``"I\P``#0```+3S```)````PO,```0```#,\P``!0```-'S```#````U_,`
M`!@```#;\P``"@```/3S```$````__,``"8````$]```#@```"OT``!\````
M.O0``!4```"W]```!0```,WT```'````T_0```P```#;]```"````.CT```*
M````\?0```8```#\]```"`````/U```"````#/4```8````/]0``!@```!;U
M```4````'?4```P````R]0``#0```#_U```0````3?4``!L```!>]0``!```
M`'KU```)````?_4``!````")]0``"0```)KU```)````I/4```4```"N]0``
M&@```+3U```(````S_4```8```#8]0``&0```-_U```.````^?4```<````(
M]@``!P```!#V```%````&/8```D````>]@``"@```"CV```3````,_8```X`
M``!']@```@```%;V```&````6?8```L```!@]@``#0```&SV```)````>O8`
M``8```"$]@``$@```(OV```)````GO8```<```"H]@``!0```+#V```4````
MMO8``!T```#+]@``0@```.GV```E````+/<``"4```!2]P``!@```'CW```*
M````?_<```0```"*]P``"0```(_W```(````F?<``!$```"B]P``"0```+3W
M```&````OO<```T```#%]P``!@```-/W```$````VO<``#D```#?]P``/0``
M`!GX```Z````5_@``!X```"2^```!0```+'X```.````M_@```0```#&^```
M!@```,OX```'````TO@``"$```#:^```#0```/SX```5````"OD```8````@
M^0``!````"?Y```1````+/D```8````^^0``"@```$7Y```B````4/D```0`
M``!S^0``!0```'CY```=````?OD```0```"<^0``#````*'Y```)````KOD`
M``P```"X^0``#@```,7Y```*````U/D``!````#?^0``$P```/#Y```3````
M!/H```@````8^@``"0```"'Z```%````*_H``#H````Q^@``,````&SZ```U
M````G?H``"D```#3^@``1P```/WZ```X````1?L``"D```!^^P``/P```*C[
M```N````Z/L``"T````7_```'P```$7\```/````9?P``!(```!U_```"P``
M`(C\```F````E/P``"D```"[_```)````.7\```F````"OT```@````Q_0``
M"@```#K]```)````1?T```<```!/_0``(````%?]```@````>/T``"8```"9
M_0``!````,#]```@````Q?T```H```#F_0``&0```/']```I````"_X``!8`
M```U_@``$@```$S^```'````7_X```H```!G_@``#````'+^```/````?_X`
M`!````"/_@``0````*#^``!P````X?X``&8```!2_P``#@```+G_```)````
MR/\```H```#2_P``$@```-W_```3````\/\```P````$``$`!@```!$``0`<
M````&``!``\````U``$`&P```$4``0`2````80`!`!````!T``$`$0```(4`
M`0`<````EP`!`",```"T``$`:@```-@``0`/````0P$!``4```!3`0$`$```
M`%D!`0`)````:@$!``0```!T`0$`"P```'D!`0`@````A0$!`!0```"F`0$`
M#````+L!`0`,````R`$!``\```#5`0$`%0```.4!`0`I````^P$!`"H````E
M`@$`)@```%`"`0`G````=P(!`"D```"?`@$`*@```,D"`0`9````]`(!`$(`
M```.`P$`$0```%$#`0`2````8P,!`!,```!V`P$`%````(H#`0`/````GP,!
M`!8```"O`P$`%P```,8#`0`0````W@,!`!$```#O`P$`-`````$$`0`3````
M-@0!`!(```!*!`$`-0```%T$`0`4````DP0!``<```"H!`$`#````+`$`0`*
M````O00!`"````#(!`$`$````.D$`0`4````^@0!`!0````/!0$`$0```"0%
M`0`7````-@4!`!P```!.!0$`#0```&L%`0`-````>04!`!,```"'!0$`%@``
M`)L%`0`4````L@4!`!H```#'!0$`$0```.(%`0`,````]`4!`!`````!!@$`
M&@```!(&`0`>````+08!`!H```!,!@$`$P```&<&`0`5````>P8!`!$```"1
M!@$`%P```*,&`0`4````NP8!`!<```#0!@$`%0```.@&`0`)````_@8!`!``
M```(!P$`&0```!D'`0`$````,P<!``<````X!P$`"P```$`'`0`1````3`<!
M``8```!>!P$`!@```&4'`0`&````;`<!``4```!S!P$`!P```'D'`0`'````
M@0<!``4```")!P$`%@```(\'`0`&````I@<!``8```"M!P$`!````+0'`0`$
M````N0<!``<```"^!P$`#@```,8'`0`,````U0<!``P```#B!P$`#0```.\'
M`0`*````_0<!``X````("`$`!0```!<(`0`H````'0@!``X```!&"`$`#```
M`%4(`0`/````8@@!``H```!R"`$`"````'T(`0`)````A@@!`"L```"0"`$`
M!````+P(`0`(````P0@!`"8```#*"`$`$@```/$(`0`/````!`D!``8````4
M"0$`"@```!L)`0!,````)@D!``<```!S"0$`"````'L)`0`@````A`D!``D`
M``"E"0$`#0```*\)`0`)````O0D!`!0```#'"0$`#````-P)`0`-````Z0D!
M``X```#W"0$`%@````8*`0`1````'0H!``8````O"@$``P```#8*`0`&````
M.@H!`!D```!!"@$`!P```%L*`0`$````8PH!``L```!H"@$`"P```'0*`0`'
M````@`H!``4```"("@$`!P```(X*`0`6````E@H!``T```"M"@$`#0```+L*
M`0`*````R0H!`!````#4"@$`#P```.4*`0`1````]0H!`!<````'"P$`"@``
M`!\+`0`1````*@L!``@````\"P$`!````$4+`0`/````2@L!`#H```!:"P$`
M!0```)4+`0`,````FPL!``0```"H"P$`'@```*T+`0`.````S`L!`!````#;
M"P$`"P```.P+`0`,````^`L!``D````%#`$`!P````\,`0`*````%PP!``D`
M```B#`$`#@```"P,`0`0````.PP!`!L```!,#`$`&````&@,`0`:````@0P!
M``H```"<#`$`"0```*<,`0`*````L0P!``P```"\#`$`#P```,D,`0`(````
MV0P!``8```#B#`$`'````.D,`0`'````!@T!``4````.#0$`"P```!0-`0!'
M````(`T!``T```!H#0$`"0```'8-`0`$````@`T!``,```"%#0$`$P```(D-
M`0`3````G0T!`!,```"Q#0$`"@```,4-`0`"````T`T!``0```#3#0$`)0``
M`-@-`0`#````_@T!``4````"#@$`*@````@.`0`*````,PX!``4````^#@$`
M!````$0.`0`*````20X!``T```!4#@$`!@```&(.`0`(````:0X!``@```!R
M#@$`!````'L.`0`%````@`X!`&@```"&#@$`"0```.\.`0`,````^0X!`!``
M```&#P$`!0```!</`0`&````'0\!`!L````D#P$`+P```$`/`0`0````<`\!
M``H```"!#P$`"````(P/`0`/````E0\!``H```"E#P$`"0```+`/`0`3````
MN@\!`!L```#.#P$`&````.H/`0`7`````Q`!`!H````;$`$`'P```#80`0`.
M````5A`!`!<```!E$`$``P```'T0`0`'````@1`!``@```")$`$`!P```)(0
M`0`)````FA`!``H```"D$`$`"P```*\0`0`'````NQ`!`%$```##$`$`$```
M`!41`0`,````)A$!``T````S$0$`&@```$$1`0!*````7!$!`!D```"G$0$`
M!@```,$1`0`:````R!$!`"4```#C$0$`!@````D2`0`&````$!(!`!\````7
M$@$`!@```#<2`0`)````/A(!`!@```!($@$`%P```&$2`0`H````>1(!``8`
M``"B$@$`#0```*D2`0`H````MQ(!`"(```#@$@$`5P````,3`0`3````6Q,!
M`",```!O$P$`$P```),3`0`"````IQ,!``L```"J$P$`#````+83`0`(````
MPQ,!``T```#,$P$`"@```-H3`0`6````Y1,!``<```#\$P$`%`````04`0`&
M````&10!``@````@%`$`#@```"D4`0`'````.!0!``H```!`%`$`"P```$L4
M`0`R````5Q0!`!<```"*%`$`!P```*(4`0`,````JA0!``T```"W%`$`%P``
M`,44`0`,````W10!``0```#J%`$`"0```.\4`0`)````^10!``H````#%0$`
M!P````X5`0`)````%A4!``D````@%0$`"@```"H5`0`'````-14!``H````]
M%0$`%0```$@5`0`;````7A4!``\```!Z%0$`20```(H5`0`2````U!4!``H`
M``#G%0$`%@```/(5`0`/````"18!`!`````9%@$`"0```"H6`0`0````-!8!
M``<```!%%@$`$@```$T6`0`$````8!8!``L```!E%@$`!P```'$6`0`%````
M>18!``4```!_%@$`&@```(46`0`+````H!8!`!0```"L%@$`$0```,$6`0`:
M````TQ8!`!8```#N%@$`%`````47`0`7````&A<!`!@````R%P$`'````$L7
M`0`9````:!<!``<```""%P$`!0```(H7`0`-````D!<!``P```">%P$`"P``
M`*L7`0`(````MQ<!`!<```#`%P$`"P```-@7`0`,````Y!<!`!\```#Q%P$`
M&@```!$8`0`3````+!@!``0```!`&`$`"@```$48`0`$````4!@!``T```!5
M&`$`#````&,8`0`%````<!@!``D```!V&`$`"````(`8`0`%````B1@!``<`
M``"/&`$`!0```)<8`0`$````G1@!``(```"B&`$`&````*48`0`7````OA@!
M`#@```#6&`$`+`````\9`0`2````/!D!`"D```!/&0$`,@```'D9`0`*````
MK!D!`"P```"W&0$`+@```.09`0`S````$QH!`#,```!'&@$`.````'L:`0`1
M````M!H!``\```#&&@$`&````-8:`0`0````[QH!``\`````&P$`$P```!`;
M`0`5````)!L!`!0````Z&P$`$@```$\;`0`4````8AL!`!4```!W&P$`+0``
M`(T;`0`M````NQL!`#$```#I&P$`+@```!L<`0`O````2AP!`"P```!Z'`$`
M8@```*<<`0`3````"AT!``T````>'0$`"````"P=`0`7````-1T!``@```!-
M'0$`#````%8=`0`K````8QT!`"$```"/'0$`&````+$=`0`:````RAT!``D`
M``#E'0$`10```.\=`0!!````-1X!``0```!W'@$`$P```'P>`0`4````D!X!
M``X```"E'@$`$P```+0>`0`8````R!X!``8```#A'@$`"0```.@>`0`*````
M\AX!``\```#]'@$`$`````T?`0`'````'A\!``X````F'P$`!0```#4?`0`;
M````.Q\!``@```!7'P$`!@```&`?`0`4````9Q\!`!$```!\'P$`&````(X?
M`0`.````IQ\!`#@```"V'P$``@```.\?`0`&````\A\!``X```#Y'P$`$```
M``@@`0`%````&2`!``<````?(`$`#@```"<@`0`&````-B`!`"@````](`$`
M#````&8@`0`<````<R`!``0```"0(`$`F@```)4@`0`I````,"$!`!<```!:
M(0$`'P```'(A`0`9````DB$!`%P```"L(0$`%`````DB`0`^````'B(!`!\`
M``!=(@$`$````'TB`0`'````CB(!``X```"6(@$`#````*4B`0`,````LB(!
M`!,```"_(@$`"@```-,B`0`=````WB(!`!D```#\(@$`!0```!8C`0`1````
M'",!``T````N(P$`$0```#PC`0`D````3B,!`!(```!S(P$`%0```(8C`0`2
M````G",!``X```"O(P$`&0```+XC`0`(````V",!``D```#A(P$`#0```.LC
M`0`'````^2,!``H````!)`$`!P````PD`0`/````%"0!``8````D)`$`"P``
M`"LD`0`:````-R0!``H```!2)`$`!P```%TD`0`(````920!``4```!N)`$`
M'P```'0D`0`&````E"0!`!````";)`$`"````*PD`0`-````M20!``@```##
M)`$`'@```,PD`0`2````ZR0!`"P```#^)`$`&@```"LE`0`)````1B4!``H`
M``!0)0$`%0```%LE`0`%````<24!`!0```!W)0$`!````(PE`0`0````D24!
M``8```"B)0$`!P```*DE`0`>````L24!`"@```#0)0$`"@```/DE`0`<````
M!"8!`!$````A)@$`$0```#,F`0`+````128!`!H```!1)@$`%````&PF`0`$
M````@28!``0```"&)@$`"P```(LF`0`%````ER8!``8```"=)@$`$0```*0F
M`0`(````MB8!``8```"_)@$`"@```,8F`0`;````T28!`#0```#M)@$`-```
M`"(G`0`@````5R<!`"D```!X)P$`(````*(G`0!!````PR<!`!H````%*`$`
M(0```"`H`0`H````0B@!`"D```!K*`$`4````)4H`0`B````YB@!``8````)
M*0$`"````!`I`0`%````&2D!``@````?*0$`&0```"@I`0`9````0BD!`"H`
M``!<*0$`(P```(<I`0`9````JRD!`"X```#%*0$`-````/0I`0`(````*2H!
M`!<````R*@$`"@```$HJ`0`'````52H!`"$```!=*@$`"````'\J`0`0````
MB"H!``X```"9*@$`%````*@J`0`+````O2H!``<```#)*@$`$P```-$J`0`(
M````Y2H!``L```#N*@$`"@```/HJ`0`4````!2L!``\````:*P$`,@```"HK
M`0`+````72L!``X```!I*P$`!0```'@K`0`%````?BL!`!4```"$*P$`#```
M`)HK`0`%````IRL!`!<```"M*P$`#P```,4K`0`$````U2L!``H```#:*P$`
M"0```.4K`0`+````[RL!``T```#[*P$`#`````DL`0`.````%BP!``4````E
M+`$`!````"LL`0`4````,"P!``T```!%+`$`(@```%,L`0`R````=BP!`!L`
M``"I+`$`10```,4L`0`2````"RT!`!<````>+0$`!P```#8M`0`>````/BT!
M`!0```!=+0$`!0```'(M`0`4````>"T!``8```"-+0$`!P```)0M`0`.````
MG"T!`"H```"K+0$`!@```-8M`0`,````W2T!`!,```#J+0$`#0```/XM`0`1
M````#"X!`!4````>+@$`"P```#0N`0`V````0"X!``H```!W+@$`(@```((N
M`0`+````I2X!``\```"Q+@$`A0```,$N`0`R````1R\!`!L```!Z+P$`)0``
M`)8O`0`P````O"\!`#$```#M+P$`+0```!\P`0`.````33`!``4```!<,`$`
M#@```&(P`0`3````<3`!`!$```"%,`$`$@```)<P`0`'````JC`!`!$```"R
M,`$`$P```,0P`0`'````V#`!`!0```#@,`$`&````/4P`0`'````#C$!``4`
M```6,0$`#````!PQ`0`,````*3$!`!(````V,0$`!````$DQ`0`'````3C$!
M``H```!6,0$`"P```&$Q`0`,````;3$!``X```!Z,0$`#@```(DQ`0`%````
MF#$!``4```">,0$`+@```*0Q`0`F````TS$!`",```#Z,0$``P```!XR`0`2
M````(C(!``8````U,@$`'@```#PR`0`8````6S(!`!D```!T,@$`)0```(XR
M`0`-````M#(!``D```#",@$`'P```,PR`0`#````[#(!`!@```#P,@$`!P``
M``DS`0`*````$3,!``(````<,P$`#````!\S`0`5````+#,!``L```!",P$`
M&0```$XS`0`@````:#,!`!(```"),P$`!0```)PS`0`*````HC,!`!4```"M
M,P$`$@```,,S`0`,````UC,!``0```#C,P$`"0```.@S`0`'````\C,!``P`
M``#Z,P$`4@````<T`0`7````6C0!`"0```!R-`$`(0```)<T`0`2````N30!
M``<```#,-`$`!@```-0T`0`.````VS0!``T```#J-`$`$0```/@T`0`;````
M"C4!``P````F-0$`#````#,U`0`-````0#4!`!4```!.-0$`$@```&0U`0`/
M````=S4!`!0```"'-0$`"@```)PU`0`;````IS4!`"````##-0$`'@```.0U
M`0`0`````S8!``L````4-@$`)P```"`V`0`E````2#8!`&D```!N-@$`)@``
M`-@V`0`:````_S8!`!<````:-P$`&0```#(W`0`:````3#<!`"4```!G-P$`
M*````(TW`0`G````MC<!`!H```#>-P$`%P```/DW`0`;````$3@!`$0````M
M.`$`-````'(X`0`E````IS@!`!D```#-.`$`'P```.<X`0`;````!SD!`!,`
M```C.0$`"````#<Y`0`'````0#D!``@```!(.0$`"0```%$Y`0`5````6SD!
M``T```!Q.0$`(P```'\Y`0`-````HSD!`!,```"Q.0$`"````,4Y`0`#````
MSCD!`$8```#2.0$`/P```!DZ`0`W````63H!`%<```"1.@$`!0```.DZ`0`?
M````[SH!`"\````/.P$`"@```#\[`0`0````2CL!``@```!;.P$`#0```&0[
M`0`M````<CL!``0```"@.P$`!P```*4[`0`(````K3L!``T```"V.P$`"@``
M`,0[`0!/````SSL!`"4````?/`$`'````$4\`0`+````8CP!`!\```!N/`$`
M'0```(X\`0`E````K#P!`"````#2/`$`)````/,\`0`@````&#T!``L````Y
M/0$`!P```$4]`0`-````33T!``P```!;/0$`%P```&@]`0`&````@#T!`#D`
M``"'/0$`#````,$]`0`'````SCT!``D```#6/0$`$P```.`]`0`)````]#T!
M``0```#^/0$`$`````,^`0`(````%#X!``@````=/@$`!````"8^`0`+````
M*SX!``P````W/@$`$@```$0^`0`1````5SX!``P```!I/@$`&@```'8^`0`/
M````D3X!``<```"A/@$`#0```*D^`0`.````MSX!`!0```#&/@$`#@```-L^
M`0`'````ZCX!``P```#R/@$`&P```/\^`0`L````&S\!`!,```!(/P$`'```
M`%P_`0`H````>3\!``8```"B/P$`!P```*D_`0`3````L3\!``4```#%/P$`
M!````,L_`0`7````T#\!`#D```#H/P$`"@```")``0`,````+4`!``D````Z
M0`$`!@```$1``0`)````2T`!``@```!50`$`"0```%Y``0`*````:$`!`!$`
M``!S0`$`!@```(5``0`.````C$`!``X```";0`$`#0```*I``0`+````N$`!
M`!T```#$0`$`"P```.)``0`"````[D`!`!P```#Q0`$`!P````Y!`0`&````
M%D$!`&0````=00$`"0```()!`0`'````C$$!`"8```"400$`*0```+M!`0`;
M````Y4$!`#@````!0@$`*P```#I"`0`:````9D(!`",```"!0@$`*@```*5"
M`0`M````T$(!`#L```#^0@$`*````#I#`0`T````8T,!`!D```"80P$`%0``
M`+)#`0`%````R$,!``<```#.0P$`"````-9#`0`'````WT,!``4```#G0P$`
M!P```.U#`0`.````]4,!``D````$1`$`!@````Y$`0`(````%40!``L````>
M1`$`!P```"I$`0`(````,D0!``<````[1`$`%@```$-$`0`)````6D0!``8`
M``!D1`$`"P```&M$`0`0````=T0!``8```"(1`$`'````(]$`0`4````K$0!
M``<```#!1`$`$0```,E$`0`(````VT0!``X```#D1`$``P```/-$`0`(````
M]T0!`!0`````10$`!0```!5%`0`0````&T4!``D````L10$`$````#9%`0`&
M````1T4!`!D```!.10$`"@```&A%`0`<````<T4!``<```"010$`!0```)A%
M`0`0````GD4!`!0```"O10$`"P```,1%`0`-````T$4!`"@```#>10$`&```
M``=&`0`7````($8!``0````X1@$`"0```#U&`0`*````1T8!``<```!21@$`
M`@```%I&`0`.````748!``@```!L1@$`(P```'5&`0`?````F48!`#@```"Y
M1@$`)@```/)&`0`Q````&4<!`"<```!+1P$`1````'-'`0`E````N$<!`"\`
M``#>1P$`+P````Y(`0`O````/D@!`"@```!N2`$`9````)=(`0`4````_$@!
M`%4````120$`.````&=)`0`I````H$D!`$H```#*20$`6P```!5*`0`H````
M<4H!`#@```":2@$`+````--*`0`H`````$L!`"P````I2P$`)@```%9+`0`;
M````?4L!`#X```"92P$`J0$``-A+`0`C````@DT!`#````"F30$`%P```-=-
M`0!(````[TT!`(4````X3@$`,````+Y.`0`E````[TX!`$$````53P$`6P``
M`%=/`0!)````LT\!`#$```#]3P$`'0```"]0`0`8````35`!`"L```!F4`$`
M(0```))0`0`?````M%`!`"L```#44`$`)@````!1`0`G````)U$!`#H```!/
M40$`'0```(I1`0`1````J%$!`#,```"Z40$`)0```.Y1`0`G````%%(!`"``
M```\4@$`)@```%U2`0`?````A%(!`#````"D4@$`S````-52`0!I````HE,!
M`#$````,5`$`00```#Y4`0`S````@%0!`"4```"T5`$`/0```-I4`0!E````
M&%4!`$T```!^50$`7@```,Q5`0`G````*U8!`#$```!35@$`/@```(56`0`L
M````Q%8!`"8```#Q5@$`+P```!A7`0`N````2%<!`"D```!W5P$`,````*%7
M`0!4````TE<!`%H````G6`$`,0```()8`0!(````M%@!`$H```#]6`$`,0``
M`$A9`0`J````>ED!`"(```"E60$`+P```,A9`0`I````^%D!`#(````B6@$`
M+P```%5:`0`L````A5H!`"T```"R6@$`<0```.!:`0!F````4EL!`&\```"Y
M6P$`LP```"E<`0`7````W5P!`"4```#U7`$`,@```!M=`0`I````3ET!`#X`
M``!X70$`(@```+==`0!2````VET!`"(````M7@$`)0```%!>`0`+````=EX!
M`+$```""7@$`10```#1?`0`A````>E\!`#8```"<7P$`,````--?`0`E````
M!&`!`!P````J8`$`2````$=@`0`Q````D&`!``<```#"8`$`!P```,I@`0`$
M````TF`!``T```#78`$`"P```.5@`0`.````\6`!``L`````80$`!0````QA
M`0`0````$F$!``(````C80$`60```"9A`0`%````@&$!`!(```"&80$`!```
M`)EA`0`'````GF$!``@```"F80$`!0```*]A`0`P````M6$!``,```#F80$`
M$````.IA`0`,````^V$!`!,````(8@$`#0```!QB`0`"````*F(!``<````M
M8@$`!@```#5B`0`4````/&(!``P```!18@$`&````%YB`0`&````=V(!`!(`
M``!^8@$`#````)%B`0`#````GF(!`"H```"B8@$`!````,UB`0`&````TF(!
M``<```#98@$`'P```.%B`0`U`````6,!`"X````W8P$`+P```&9C`0`7````
MEF,!`"(```"N8P$`)0```-%C`0`@````]V,!`!L````89`$`&````#1D`0`D
M````360!`!\```!R9`$`&@```))D`0`A````K60!`"````#/9`$`,````/!D
M`0`:````(64!`#(````\90$`&@```&]E`0`O````BF4!`"L```"Z90$`'P``
M`.9E`0`C````!F8!`!\````J9@$`&@```$IF`0`A````968!`"4```"'9@$`
M)@```*UF`0`E````U&8!`"0```#Z9@$`&````!]G`0`=````.&<!`"0```!6
M9P$`&````'MG`0`B````E&<!`"P```"W9P$`+P```.1G`0`5````%&@!`"4`
M```J:`$`/````%!H`0`?````C6@!`",```"M:`$`'P```-%H`0`@````\6@!
M`!H````2:0$`&````"UI`0`F````1FD!`!X```!M:0$`*0```(QI`0`>````
MMFD!`#$```#5:0$`"0````=J`0`,````$6H!`!<````>:@$`+P```#9J`0`D
M````9FH!``<```"+:@$`#P```)-J`0`4````HVH!``X```"X:@$`#0```,=J
M`0`D````U6H!``4```#Z:@$`!P````!K`0`B````"&L!`"4````K:P$`&@``
M`%%K`0`=````;&L!`!H```"*:P$`!P```*5K`0#'````K6L!``L```!U;`$`
M'````(%L`0`5````GFP!``8```"T;`$`"0```+ML`0`+````Q6P!``T```#1
M;`$`%P```-]L`0`&````]VP!`#,```#^;`$`$P```#)M`0`3````1FT!``<`
M``!:;0$`#P```&)M`0`'````<FT!`#(```!Z;0$`!````*UM`0`A````LFT!
M`!,```#4;0$`#````.AM`0`1````]6T!`#(````';@$`%@```#IN`0`(````
M46X!`!T```!:;@$`"0```'AN`0`*````@FX!`!0```"-;@$`"@```*)N`0`=
M````K6X!``@```#+;@$`'P```-1N`0`(````]&X!`!H```#];@$`)P```!AO
M`0`&````0&\!`!4```!';P$`!P```%UO`0`(````96\!``D```!N;P$`/P``
M`'AO`0`2````N&\!``<```#+;P$`#P```--O`0`.````XV\!`!````#R;P$`
M"0````-P`0`)````#7`!``@````7<`$`$P```"!P`0`)````-'`!``<````^
M<`$`#````$9P`0`9````4W`!``H```!M<`$`&P```'AP`0`7````E'`!`!0`
M``"L<`$`"@```,%P`0`,````S'`!`!<```#9<`$`!````/%P`0`J````]G`!
M``P````A<0$`$0```"YQ`0`'````0'$!``(```!(<0$`$````$MQ`0`8````
M7'$!``L```!U<0$``P```(%Q`0`(````A7$!``L```".<0$`!@```)IQ`0`'
M````H7$!``T```"I<0$`"P```+=Q`0`4````PW$!`!4```#8<0$`#@```.YQ
M`0`O````_7$!`"`````M<@$`'````$YR`0`5````:W(!``P```"!<@$`,0``
M`(YR`0`%````P'(!`!(```#&<@$`/P```-ER`0`2````&7,!``H````L<P$`
M!@```#=S`0`$````/G,!``0```!#<P$`"@```$AS`0`3````4W,!``4```!G
M<P$`!@```&US`0`&````=',!``@```![<P$`!````(1S`0`,````B7,!``D`
M``"6<P$`#````*!S`0`*````K7,!`!````"X<P$`$P```,ES`0`3````W7,!
M`#D```#Q<P$`+@```"MT`0`I````6G0!``4```"$=`$`&````(IT`0`9````
MHW0!`!\```"]=`$`'0```-UT`0`1````^W0!``(````-=0$`!````!!U`0`*
M````%74!``8````@=0$`!0```"=U`0`#````+74!``P````Q=0$`10```#YU
M`0`R````A'4!`#P```"W=0$`&@```/1U`0`T````#W8!`"@```!$=@$`4P``
M`&UV`0`P````P78!`"\```#R=@$`,@```")W`0`9````57<!`'(```!O=P$`
M(````.)W`0`U`````W@!`"$````Y>`$`10```%MX`0`P````H7@!`"8```#2
M>`$`'@```/EX`0`H````&'D!`"L```!!>0$`*0```&UY`0`I````EWD!`"8`
M``#!>0$`)0```.AY`0`H````#GH!`"@````W>@$`(@```&!Z`0`K````@WH!
M`"X```"O>@$`,````-YZ`0`2````#WL!`!,````B>P$`$````#9[`0!Y````
M1WL!``D```#!>P$`H0```,M[`0!S````;7P!`'P```#A?`$`*P```%Y]`0!4
M````BGT!`!<```#??0$`+````/=]`0`G````)'X!`!8```!,?@$`#P```&-^
M`0`7````<WX!`!\```"+?@$`0````*M^`0`?````['X!`!P````,?P$`40``
M`"E_`0`:````>W\!`!0```"6?P$`"@```*M_`0`%````MG\!``8```"\?P$`
M"````,-_`0`%````S'\!`!(```#2?P$`$````.5_`0`3````]G\!`!T````*
M@`$`#P```"B``0`*````.(`!``\```!#@`$`!P```%.``0`$````6X`!``D`
M``!@@`$`"0```&J``0`'````=(`!``L```!\@`$`!P```(B``0`%````D(`!
M`!0```"6@`$`#@```*N``0`&````NH`!``<```#!@`$`"````,F``0`/````
MTH`!`!$```#B@`$`#````/2``0`(`````8$!``P````*@0$`#P```!>!`0`6
M````)X$!``<````^@0$`!@```$:!`0`4````38$!``8```!B@0$`#````&F!
M`0`1````=H$!``@```"(@0$`!````)&!`0`9````EH$!`!$```"P@0$`"@``
M`,*!`0`8````S8$!`!,```#F@0$`"P```/J!`0`,````!H(!``P````3@@$`
M#````"""`0`<````+8(!`!$```!*@@$`!````%R"`0`/````88(!``<```!Q
M@@$`!````'F"`0`9````?H(!``<```"8@@$``@```*""`0`"````HX(!`!$`
M``"F@@$`"0```+B"`0`&````PH(!`!(```#)@@$`%P```-R"`0`&````]((!
M`"<```#[@@$``@```".#`0`$````)H,!``T````K@P$`!````#F#`0`/````
M/H,!`!,```!.@P$`!P```&*#`0`'````:H,!`!$```!R@P$`!@```(2#`0`8
M````BX,!``8```"D@P$`$P```*N#`0`0````OX,!`!(```#0@P$``@```..#
M`0`&````YH,!``P```#M@P$`"0```/J#`0`1````!(0!`!$````6A`$`&P``
M`"B$`0`B````1(0!``<```!GA`$`!P```&^$`0`+````=X0!``4```"#A`$`
M`@```(F$`0`+````C(0!`%<!``"8A`$`$P```/"%`0`1````!(8!``X````6
MA@$`"0```"6&`0`+````+X8!``@````[A@$`%@```$2&`0`7````6X8!``$`
M``!SA@$`(````'6&`0`5````EH8!`!H```"LA@$`*@```,>&`0`A````\H8!
M`"(````4AP$`&@```#>'`0`C````4H<!`!(```!VAP$`)````(F'`0`M````
MKH<!`"X```#<AP$`*@````N(`0`+````-H@!`"8```!"B`$`$@```&F(`0`-
M````?(@!``X```"*B`$`!0```)F(`0`C````GX@!``H```##B`$`$````,Z(
M`0`.````WX@!``L```#NB`$`$@```/J(`0`/````#8D!`!P````=B0$`90``
M`#J)`0`0````H(D!``P```"QB0$`#P```+Z)`0`,````SHD!`!````#;B0$`
M#@```.R)`0`0````^XD!`!$````,B@$`!@```!Z*`0#"````)8H!``\```#H
MB@$`%0```/B*`0`5````#HL!``T````DBP$`%0```#*+`0`5````2(L!``D`
M``!>BP$`"@```&B+`0`S````<XL!`#P```"GBP$`%0```.2+`0`P````^HL!
M`$,````KC`$`7@```&^,`0!@````SHP!`%P````OC0$`9@```(R-`0`R````
M\XT!``D````FC@$`$@```#".`0`'````0XX!``H```!+C@$`#@```%:.`0`%
M````98X!``8```!KC@$`$@```'*.`0`*````A8X!`!D```"0C@$`"0```*J.
M`0`-````M(X!`"X```#"C@$`+0```/&.`0`3````'X\!`!@````SCP$`&@``
M`$R/`0`6````9X\!``H```!^CP$`!0```(F/`0`.````CX\!``\```">CP$`
M#````*Z/`0`0````NX\!`!$```#,CP$`&P```-Z/`0`6````^H\!`!0````1
MD`$`$0```":0`0`B````.)`!``P```!;D`$`#@```&B0`0`3````=Y`!``H`
M``"+D`$`*````):0`0`0````OY`!`!0```#0D`$`%0```.60`0`.````^Y`!
M`%L````*D0$`.````&:1`0`O````GY$!`"$```#/D0$`!@```/&1`0`+````
M^)$!`!,````$D@$`#````!B2`0`5````)9(!`!H````[D@$`&````%:2`0`A
M````;Y(!`#D```"1D@$`"````,N2`0`)````U)(!``T```#>D@$`"@```.R2
M`0`'````]Y(!``<```#_D@$`!0````>3`0`%````#9,!``<````3DP$`!@``
M`!N3`0`>````(I,!``T```!!DP$`#P```$^3`0`9````7Y,!`!4```!YDP$`
M)P```(^3`0`.````MY,!``X```#&DP$`)P```-63`0`<````_9,!`"(````:
ME`$`(@```#V4`0`5````8)0!`!8```!VE`$`$@```(V4`0`7````H)0!`!H`
M``"XE`$`!P```-.4`0`&````VY0!``@```#BE`$`#@```.N4`0`'````^I0!
M``D````"E0$`$@````R5`0`'````'Y4!``P````GE0$`$@```#25`0`A````
M1Y4!``<```!IE0$`#0```'&5`0`(````?Y4!`!4```"(E0$`#````)Z5`0`,
M````JY4!`"4```"XE0$`*@```-Z5`0`_````"98!`#\```!)E@$`"0```(F6
M`0`'````DY8!`!,```";E@$`!0```*^6`0`%````M98!``<```"[E@$`$```
M`,.6`0`+````U)8!`!8```#@E@$`-P```/>6`0`0````+Y<!`"4```!`EP$`
M)P```&:7`0`G````CI<!`"0```"VEP$`#P```-N7`0`&````ZY<!``D```#R
MEP$`"````/R7`0`V````!9@!`#\````\F`$`-0```'R8`0!=````LI@!`#0`
M```0F0$`-````$69`0!!````>ID!`$,```"\F0$`-`````":`0!'````-9H!
M`"@```!]F@$`*@```*::`0!%````T9H!`#0````7FP$`.@```$R;`0`L````
MAYL!`!D```"TFP$`'0```,Z;`0`N````[)L!`"L````;G`$`*P```$><`0`;
M````<YP!``L```"/G`$`#P```)N<`0`&````JYP!``H```"RG`$`&````+V<
M`0`>````UIP!``8```#UG`$`!P```/R<`0`4````!)T!``H````9G0$`"```
M`"2=`0`N````+9T!``H```!<G0$`$P```&>=`0`,````>YT!``8```"(G0$`
M!@```(^=`0`9````EIT!``4```"PG0$`!P```+:=`0`&````OIT!`"````#%
MG0$`#````.:=`0`H````\YT!``\````<G@$`#````"R>`0`)````.9X!``<`
M``!#G@$`#````$N>`0`%````6)X!``\```!>G@$`!@```&Z>`0`2````=9X!
M``@```"(G@$`"````)&>`0`$````FIX!``T```"?G@$`"````*V>`0`G````
MMIX!``4```#>G@$`$````.2>`0`(````]9X!``T```#^G@$`#`````R?`0`'
M````&9\!`!<````AGP$``P```#F?`0`#````/9\!`!,```!!GP$``P```%6?
M`0`0````69\!`",```!JGP$`"0```(Z?`0`%````F)\!``D```">GP$`!P``
M`*B?`0!&````L)\!`"$```#WGP$`'@```!F@`0`Z````.*`!`"8```!SH`$`
M'````)J@`0`&````MZ`!``0```"^H`$`$@```,.@`0`@````UJ`!`"$```#W
MH`$`+P```!FA`0`A````2:$!`"@```!KH0$`80```)2A`0`I````]J$!``D`
M```@H@$`"@```"JB`0`0````-:(!`!4```!&H@$`#0```%RB`0`,````:J(!
M``P```!WH@$`#````(2B`0`,````D:(!``P```">H@$`#````*NB`0`4````
MN*(!``H```#-H@$`%P```-BB`0`;````\*(!`!$````,HP$`$P```!ZC`0`5
M````,J,!``0```!(HP$`!0```$VC`0`1````4Z,!`$L```!EHP$`4P```+&C
M`0`&````!:0!`!,````,I`$`&0```""D`0`%````.J0!``4```!`I`$`(```
M`$:D`0`8````9Z0!``\```"`I`$`#````)"D`0`0````G:0!`!8```"NI`$`
M$P```,6D`0`4````V:0!`!\```#NI`$`,`````ZE`0`]````/Z4!`"4```!]
MI0$`.@```*.E`0`+````WJ4!`"````#JI0$`!@````NF`0`5````$J8!``T`
M```HI@$`$P```#:F`0`/````2J8!`!<```!:I@$`$@```'*F`0`4````A:8!
M`!<```":I@$`#````+*F`0`&````OZ8!`!$```#&I@$`"````-BF`0`7````
MX:8!`!0```#YI@$`$@````ZG`0`(````(:<!``0````JIP$`#````"^G`0`+
M````/*<!``8```!(IP$`%0```$^G`0`3````9:<!`",```!YIP$`"@```)VG
M`0`8````J*<!`"P```#!IP$`!P```.ZG`0`-````]J<!``D````$J`$`#```
M``ZH`0`'````&Z@!``8````CJ`$`$````"JH`0`+````.Z@!``@```!'J`$`
M"@```%"H`0`/````6Z@!`$,```!KJ`$`&@```*^H`0`2````RJ@!`"H```#=
MJ`$`!0````BI`0`?````#JD!`!,````NJ0$`%````$*I`0`6````5ZD!`!(`
M``!NJ0$`,P```(&I`0!"````M:D!`"0```#XJ0$`$P```!VJ`0`,````,:H!
M`!D````^J@$`)@```%BJ`0`=````?ZH!``X```"=J@$`!0```*RJ`0`+````
MLJH!``8```"^J@$`!@```,6J`0`9````S*H!``X```#FJ@$`!P```/6J`0`*
M````_:H!`!$````(JP$`)0```!JK`0`Q````0*L!`"<```!RJP$`,P```)JK
M`0`;````SJL!`#````#JJP$`'0```!NL`0`C````.:P!`#D```!=K`$`'P``
M`)>L`0`G````MZP!`"D```#?K`$`(0````FM`0`A````*ZT!`"<```!-K0$`
M0@```'6M`0`A````N*T!`"$```#:K0$`*P```/RM`0`?````**X!`!\```!(
MK@$`.@```&BN`0`B````HZX!`!4```#&K@$`)P```-RN`0`@````!*\!`"L`
M```EKP$`%0```%&O`0"2````9Z\!`!H```#ZKP$`'P```!6P`0`?````-;`!
M`"````!5L`$`+@```':P`0`=````I;`!`!\```##L`$`(````..P`0`L````
M!+$!`"X````QL0$`,````&"Q`0`O````D;$!`*$```#!L0$`*P```&.R`0`@
M````C[(!`"0```"PL@$`(P```-6R`0`L````^;(!`$`````FLP$`1````&>S
M`0`/````K+,!``,```"\LP$`!P```,"S`0`#````R+,!``\```#,LP$`#P``
M`-RS`0`H````[+,!``@````5M`$`&0```!ZT`0`%````.+0!`!(````^M`$`
M$@```%&T`0`'````9+0!``4```!LM`$`&````'*T`0`6````B[0!`!D```"B
MM`$`%````+RT`0`7````T;0!`!$```#IM`$`%````/NT`0`3````$+4!`$X`
M```DM0$`!P```'.U`0`/````>[4!``8```"+M0$`$P```)*U`0`9````IK4!
M`!L```#`M0$`$````-RU`0`"````[;4!`%````#PM0$`"@```$&V`0`/````
M3+8!``X```!<M@$`!P```&NV`0`8````<[8!`!,```",M@$`!0```*"V`0`.
M````IK8!``@```"UM@$`$````+ZV`0`3````S[8!``8```#CM@$`"@```.JV
M`0`.````];8!`!0````$MP$`&@```!FW`0`+````-+<!``8```!`MP$`$@``
M`$>W`0`+````6K<!`!$```!FMP$`#````'BW`0`+````A;<!``T```"1MP$`
M*@```)^W`0`H````RK<!``L```#SMP$`#0```/^W`0`K````#;@!`"`````Y
MN`$`%````%JX`0`7````;[@!`$$```"'N`$`"P```,FX`0`7````U;@!`!D`
M``#MN`$`%0````>Y`0`3````';D!`!\````QN0$`*P```%&Y`0`7````?;D!
M``P```"5N0$`!@```**Y`0`&````J;D!``<```"PN0$`#P```+BY`0`&````
MR+D!`#D```#/N0$`.`````FZ`0`'````0KH!``P```!*N@$`'P```%>Z`0`.
M````=[H!`!H```"&N@$`&@```*&Z`0`)````O+H!``8```#&N@$`'0```,VZ
M`0`1````Z[H!`"0```#]N@$`'````"*[`0`*````/[L!`!,```!*NP$`"```
M`%Z[`0`.````9[L!`"0```!VNP$`*````)N[`0!`````Q+L!``X````%O`$`
M&````!2\`0`P````+;P!``@```!>O`$`"P```&>\`0`D````<[P!``X```"8
MO`$`#P```*>\`0`'````M[P!`!````"_O`$`5@```-"\`0`%````)[T!``<`
M```MO0$`!P```#6]`0`,````/;T!`!4```!*O0$`#@```&"]`0`.````;[T!
M`!````!^O0$`$0```(^]`0`8````H;T!`!8```"ZO0$`$@```-&]`0`8````
MY+T!`!8```#]O0$`"````!2^`0`&````';X!``L````DO@$`#````#"^`0`"
M````/;X!``H```!`O@$`$````$N^`0`G````7+X!`!D```"$O@$`%````)Z^
M`0`&````L[X!``T```"ZO@$`#@```,B^`0`/````U[X!`#H```#GO@$`+0``
M`"*_`0`.````4+\!`!$```!?OP$`9P```'&_`0`4````V;\!`!0```#NOP$`
M3P````/``0`>````4\`!`!8```!RP`$`!P```(G``0`%````D<`!`#0```"7
MP`$`.0```,S``0`?````!L$!`"T````FP0$`,@```%3!`0`L````A\$!`"(`
M``"TP0$`'@```-?!`0`V````]L$!`#L````MP@$`+````&G"`0`B````EL(!
M`!H```"YP@$`&P```-3"`0`%````\,(!``<```#VP@$`!P```/["`0`(````
M!L,!`!(````/PP$`$0```"+#`0`2````-,,!`!$```!'PP$`(````%G#`0`4
M````>L,!``\```"/PP$`#P```)_#`0`'````K\,!``@```"WPP$`%````,##
M`0`6````U<,!`#````#LPP$`#P```!W$`0`+````+<0!``,````YQ`$`#P``
M`#W$`0`>````3<0!`"0```!LQ`$`!P```)'$`0`@````F<0!`!L```"ZQ`$`
M(P```-;$`0`B````^L0!`!H````=Q0$`'0```#C%`0!/````5L4!`"0```"F
MQ0$`(P```,O%`0`?````[\4!`!\````/Q@$`*0```"_&`0`H````6<8!`!P`
M``""Q@$`%@```)_&`0`?````ML8!`"$```#6Q@$`!@```/C&`0`<````_\8!
M``H````<QP$`#0```"?'`0`%````-<<!``8````[QP$`"````$+'`0`+````
M2\<!``T```!7QP$`$````&7'`0`4````=L<!``X```"+QP$`#@```)K'`0`/
M````J<<!``4```"YQP$`"````+_'`0`B````R,<!`",```#KQP$`%0````_(
M`0`.````)<@!`!$````TR`$`$````$;(`0`H````5\@!``D```"`R`$`"P``
M`(K(`0`$````EL@!``4```";R`$`!0```*'(`0`4````I\@!``<```"\R`$`
M%0```,3(`0`,````VL@!``T```#GR`$`!P```/7(`0`$````_<@!`!P````"
MR0$`#P```!_)`0`%````+\D!`"$````UR0$`#0```%?)`0"3````9<D!`!4`
M``#YR0$`"0````_*`0`*````&<H!`!,````DR@$`#````#C*`0`.````1<H!
M``@```!4R@$`$@```%W*`0`"````<,H!``@```!SR@$`!@```'S*`0`1````
M@\H!``P```"5R@$`#@```*+*`0`1````L<H!`!T```##R@$`!0```.'*`0`*
M````Y\H!``\```#RR@$`"`````++`0`)````"\L!``4````5RP$`'````!O+
M`0`)````.,L!``8```!"RP$`$````$G+`0`/````6LL!``<```!JRP$`!0``
M`'++`0`%````>,L!``D```!^RP$`!P```(C+`0`3````D,L!`!$```"DRP$`
M!````+;+`0`%````N\L!``T```#!RP$`"P```,_+`0`*````V\L!``<```#F
MRP$`%````.[+`0`)`````\P!``<````-S`$`!0```!7,`0`/````&\P!`",`
M```KS`$`2````$_,`0`K````F,P!`"L```#$S`$`!@```/#,`0`*````]\P!
M``0````"S0$`"0````?-`0`(````$<T!`!0````:S0$`"P```"_-`0`&````
M.\T!``T```!"S0$`!@```%#-`0`$````5\T!`$8```!<S0$`3P```*/-`0!+
M````\\T!`"`````_S@$`!0```&#.`0`.````9LX!``0```!US@$`!@```'K.
M`0`&````@<X!`!@```"(S@$`%````*'.`0`5````MLX!``<```#,S@$`!```
M`-3.`0`6````V<X!``0```#PS@$`#P```/7.`0`;````!<\!``8````ASP$`
M!0```"C/`0`G````+L\!``0```!6SP$`"@```%O/`0`,````9L\!``<```!S
MSP$`#0```'O/`0`.````B<\!`!(```"8SP$`$@```*O/`0`1````OL\!``@`
M``#0SP$`"0```-G/`0`%````X\\!`#````#ISP$`,@```!K0`0`Z````3=`!
M`"````"(T`$`20```*G0`0`Y````\]`!`"D````MT0$`.````%?1`0`J````
MD-$!`"P```"[T0$`(0```.C1`0`1````"M(!`!`````<T@$`"P```"W2`0`E
M````.=(!`"<```!?T@$`(0```(?2`0`C````J=(!``<```#-T@$`"0```-72
M`0`*````W](!``8```#JT@$`*0```/'2`0`I````&],!`#(```!%TP$`!```
M`'C3`0`:````?=,!``D```"8TP$`'P```*+3`0`M````PM,!`!8```#PTP$`
M$0````?4`0`'````&=0!``L````AU`$`#0```"W4`0`0````.]0!``\```!,
MU`$`0````%S4`0"-````G=0!`&0````KU0$`$0```)#5`0`(````HM4!``D`
M``"KU0$`$````+75`0`1````QM4!``P```#8U0$`!0```.75`0`=````Z]4!
M`!`````)U@$`%0```!K6`0`0````,-8!``X```!!U@$`$P```%#6`0`<````
M9-8!`"8```"!U@$`=````*C6`0`0````'=<!``4````NUP$`%0```#37`0`)
M````2M<!``0```!4UP$`"P```%G7`0`>````9=<!`!4```"$UP$`"@```)K7
M`0`.````I=<!`!````"TUP$`$P```,77`0`B````V=<!`"````#\UP$`(```
M`!W8`0`>````/M@!`"0```!=V`$`(@```(+8`0`:````I=@!`#4```#`V`$`
M$@```/;8`0`0````"=D!`!(````:V0$`$@```"W9`0`4````0-D!`!4```!5
MV0$`$P```&O9`0`0````?]D!`!(```"0V0$`*0```*/9`0`3````S=D!`!4`
M``#AV0$`2@```/?9`0`<````0MH!``P```!?V@$`$0```&S:`0`/````?MH!
M`"$```".V@$`%0```+#:`0`4````QMH!`!$```#;V@$`$@```.W:`0`=````
M`-L!`!\````>VP$`'0```#[;`0`5````7-L!`!8```!RVP$`(````(G;`0`7
M````JML!`!4```#"VP$`$P```-C;`0`1````[-L!`!4```#^VP$`'0```!3<
M`0`@````,MP!`"4```!3W`$`$P```'G<`0`4````C=P!`!0```"BW`$`'```
M`+?<`0`5````U-P!`!4```#JW`$`&0````#=`0`+````&MT!`!L````FW0$`
M'````$+=`0`$````7]T!``<```!DW0$`"0```&S=`0`7````=MT!``8```".
MW0$`$0```)7=`0`*````I]T!``8```"RW0$`!P```+G=`0`(````P=T!``8`
M``#*W0$`%````-'=`0`&````YMT!``@```#MW0$`"````/;=`0`'````_]T!
M``<````'W@$`$`````_>`0`.````(-X!`!(````OW@$`$````$+>`0`)````
M4]X!`!4```!=W@$`!0```'/>`0`P````>=X!`!,```"JW@$`#@```+[>`0`0
M````S=X!``X```#>W@$`#@```.W>`0`.````_-X!`"L````+WP$`!@```#??
M`0`(````/M\!`#4```!'WP$`'@```'W?`0`.````G-\!``8```"KWP$`"0``
M`++?`0!-````O-\!``D````*X`$`!0```!3@`0`D````&N`!`!4````_X`$`
M$0```%7@`0`(````9^`!`!D```!PX`$`%@```(K@`0`4````H>`!`"$```"V
MX`$`)0```-C@`0`M````_N`!``8````LX0$`!````#/A`0`(````..$!`!P`
M``!!X0$`!P```%[A`0`%````9N$!``P```!LX0$`"P```'GA`0`&````A>$!
M``0```",X0$`!P```)'A`0`5````F>$!``P```"OX0$`#@```+SA`0`/````
MR^$!`!@```#;X0$`&0```/3A`0`3````#N(!`!T````BX@$`$P```$#B`0`3
M````5.(!``D```!HX@$`!@```'+B`0`0````>>(!`#\```"*X@$`!@```,KB
M`0`/````T>(!``4```#AX@$`'@```.?B`0`1````!N,!`!4````8XP$`#```
M`"[C`0`.````.^,!``L```!*XP$`"0```%;C`0`/````8.,!``P```!PXP$`
M#0```'WC`0`=````B^,!`"(```"IXP$`(@```,SC`0`H````[^,!``P````8
MY`$`!P```"7D`0`+````+>0!`!,````YY`$`%````$WD`0`&````8N0!``\`
M``!IY`$`(@```'GD`0`-````G.0!``\```"JY`$`'@```+KD`0!E````V>0!
M`"`````_Y0$`#````&#E`0`'````;>4!``8```!UY0$`'@```'SE`0`=````
MF^4!`!H```"YY0$`"0```-3E`0`"````WN4!``0```#AY0$`(````.;E`0`&
M````!^8!``4````.Y@$`*@```!3F`0`*````/^8!``<```!*Y@$`"@```%+F
M`0`/````7>8!``X```!MY@$`!@```'SF`0`'````@^8!``H```"+Y@$`!0``
M`);F`0`%````G.8!`(,```"BY@$`#````";G`0`/````,^<!`!@```!#YP$`
M"0```%SG`0`*````9N<!`!X```!QYP$`+````)#G`0`/````O><!``H```#-
MYP$``@```-CG`0`0````V^<!``H```#LYP$`"0```/?G`0`:`````>@!`"D`
M```<Z`$`)P```$;H`0`F````;N@!`!P```"5Z`$`'@```++H`0`6````T>@!
M`!T```#HZ`$`"`````;I`0`)````#^D!``H````9Z0$`!P```"3I`0`,````
M+.D!``P````YZ0$`#0```$;I`0`&````5.D!`%(```!;Z0$`#P```*[I`0`.
M````OND!``D```#-Z0$`(````-?I`0!9````^.D!`!H```!2Z@$`!@```&WJ
M`0`>````=.H!`"T```"3Z@$`"````,'J`0`'````RNH!`!\```#2Z@$`"```
M`/+J`0`+````^^H!`"<````'ZP$`)@```"_K`0`E````5NL!``D```!\ZP$`
M"@```(;K`0`D````D>L!`"(```"VZP$`7````-GK`0`4````-NP!`"8```!+
M[`$`%````'+L`0`"````A^P!`!$```"*[`$`#````)SL`0`+````J>P!`!8`
M``"U[`$`#@```,SL`0`=````V^P!``<```#Y[`$`$@````'M`0`&````%.T!
M``@````;[0$`$0```"3M`0`-````-NT!``H```!$[0$`#````$_M`0`S````
M7.T!`!\```"0[0$`!P```+#M`0`1````N.T!`!(```#*[0$`(````-WM`0`7
M````_NT!``8````6[@$`#P```!WN`0`1````+>X!``\````_[@$`#P```$_N
M`0`/````7^X!`!$```!O[@$`#P```('N`0`/````D>X!``@```"A[@$`%```
M`*KN`0`<````O^X!`!X```#<[@$`40```/ON`0`+````3>\!`!(```!9[P$`
M'0```&SO`0`/````BN\!`!$```":[P$`#````*SO`0`7````N>\!``\```#1
M[P$`#0```.'O`0`$````[^\!``L```#T[P$`!P````#P`0`%````"/`!``4`
M```.\`$`&````!3P`0`*````+?`!`!4````X\`$`$0```$[P`0`:````8/`!
M`!8```![\`$`%````)+P`0`7````I_`!`!X```"_\`$`'0```-[P`0`:````
M_/`!``8````7\0$`"@```![Q`0`.````*?$!``T````X\0$`$````$;Q`0`'
M````5_$!`",```!?\0$`#0```(/Q`0`-````D?$!`!H```"?\0$`)@```+KQ
M`0`4````X?$!``<```#V\0$`$````/[Q`0`(````#_(!`!0````8\@$`$P``
M`"WR`0`)````0?(!``D```!+\@$`"0```%7R`0`%````7_(!``<```!E\@$`
M`@```&WR`0`$````</(!``(```!U\@$`'P```'CR`0`E````F/(!`$0```"^
M\@$`0P````/S`0`-````1_,!`"(```!5\P$`-@```'CS`0`,````K_,!`"D`
M``"\\P$`'0```.;S`0`B````!/0!`"(````G]`$`)P```$KT`0`9````<O0!
M`!````",]`$`%````)WT`0`>````LO0!`!4```#1]`$`&````.?T`0`7````
M`/4!`!,````8]0$`%P```"SU`0`<````1/4!`!H```!A]0$`+P```'SU`0`O
M````K/4!`#,```#<]0$`,````!#V`0`Q````0?8!`"X```!S]@$`:P```*+V
M`0`E````#O<!`!D````T]P$`"P```$[W`0`;````6O<!``H```!V]P$`%0``
M`('W`0`J````E_<!`"P```#"]P$`&@```._W`0`H````"O@!``D````S^`$`
M6P```#WX`0!-````F?@!``D```#G^`$`(````/'X`0`F````$OD!``X````Y
M^0$`&````$CY`0`;````8?D!``4```!]^0$`"@```(/Y`0`(````COD!`!``
M``"7^0$`$@```*CY`0`+````N_D!``H```#'^0$`#0```-+Y`0`E````X/D!
M``D````&^@$`"0```!#Z`0`2````&OH!`!4````M^@$`&0```$/Z`0`0````
M7?H!`#D```!N^@$``@```*CZ`0`'````J_H!``X```"S^@$`%````,+Z`0`'
M````U_H!``<```#?^@$`$P```.?Z`0`(````^_H!`#@````$^P$`#@```#W[
M`0`9````3/L!``0```!F^P$`G@```&O[`0`P````"OP!`!P````[_`$`+```
M`%C\`0`9````A?P!`%4```"?_`$`%@```/7\`0!'````#/T!`",```!4_0$`
M$0```'C]`0`)````BOT!`!````"4_0$`$0```*7]`0`,````M_T!`!,```#$
M_0$`#````-C]`0`;````Y?T!`!L````!_@$``P```!W^`0`+````(?X!``X`
M```M_@$`$@```#S^`0`H````3_X!`!P```!X_@$`'@```)7^`0`3````M/X!
M`!(```#(_@$`)P```-O^`0`)`````_\!`!$````-_P$`$@```!__`0`'````
M,O\!``H````Z_P$`!P```$7_`0`.````3?\!``<```!<_P$`$````&3_`0`<
M````=?\!`!(```"2_P$`!0```*7_`0`(````J_\!``4```"T_P$`'````+K_
M`0`&````U_\!`!$```#>_P$`"````/#_`0`1````^?\!``@````+``(`&@``
M`!0``@`.````+P`"`"L````^``(`%P```&H``@`)````@@`"``H```",``(`
M'0```)<``@`%````M0`"`!,```"[``(`!0```,\``@`H````U0`"``<```#^
M``(`"0````8!`@`<````$`$"`#P````M`0(`!@```&H!`@`;````<0$"`!``
M``"-`0(`$````)X!`@`(````KP$"`!,```"X`0(`"P```,P!`@`$````V`$"
M``@```#=`0(`"P```.8!`@`'````\@$"``D```#Z`0(`$`````0"`@`(````
M%0("``<````>`@(`!P```"8"`@`5````+@("`"T```!$`@(`.P```'("`@`7
M````K@("`"````#&`@(`%0```.<"`@`^````_0("`!P````\`P(`)@```%D#
M`@`=````@`,"`"4```">`P(`6````,0#`@`@````'00"``4````^!`(`"@``
M`$0$`@`'````3P0"``D```!7!`(`$@```&$$`@`5````=`0"`#@```"*!`(`
M(P```,,$`@`?````YP0"`#4````'!0(`.@```#T%`@`*````>`4"`!H```"#
M!0(`#````)X%`@`*````JP4"`"$```"V!0(`"0```-@%`@`3````X@4"`!(`
M``#V!0(`%@````D&`@`.````(`8"``<````O!@(`#P```#<&`@`)````1P8"
M`!````!1!@(`#@```&(&`@`:````<08"`!<```",!@(`,````*0&`@`+````
MU08"`!\```#A!@(`!0````$'`@`&````!P<"`!L````.!P(`"````"H'`@`'
M````,P<"`!X````[!P(`#````%H'`@`$````9P<"`!````!L!P(`#P```'T'
M`@`)````C0<"``P```"7!P(`#@```*0'`@`6````LP<"``4```#*!P(`!```
M`-`'`@`9````U0<"`!(```#O!P(`*0````((`@`Q````+`@"`"0```!>"`(`
M1````(,(`@`3````R`@"`!<```#<"`(`!P```/0(`@`C````_`@"`!@````@
M"0(`%````#D)`@`.````3@D"``\```!="0(`#0```&T)`@`-````>PD"`"\`
M``")"0(`!@```+D)`@`+````P`D"`!(```#,"0(`#0```-\)`@`/````[0D"
M`!4```#]"0(`"P```!,*`@`\````'PH"``8```!<"@(`'@```&,*`@`/````
M@@H"`!,```"2"@(`CP```*8*`@`G````-@L"`!\```!>"P(`'P```'X+`@`[
M````G@L"`#P```#:"P(`.````!<,`@`1````4`P"``@```!B#`(`$0```&L,
M`@`3````?0P"`!$```"1#`(`&````*,,`@`(````O`P"`!````#%#`(`%@``
M`-8,`@`'````[0P"`!$```#U#`(`'`````<-`@`+````)`T"``4````P#0(`
M#````#8-`@`+````0PT"`!````!/#0(`!0```&`-`@`'````9@T"``H```!N
M#0(`$P```'D-`@`3````C0T"``P```"A#0(`#````*X-`@`&````NPT"``D`
M``#"#0(`-@```,P-`@`H`````PX"`",````L#@(`!P```%`.`@`@````6`X"
M``8```!Y#@(`)````(`.`@`5````I0X"`!@```"[#@(`*````-0.`@`1````
M_0X"`!$````/#P(`'````"$/`@`#````/@\"`!T```!"#P(`"````&`/`@`2
M````:0\"``(```!\#P(`#````'\/`@`4````C`\"``L```"A#P(`&````*T/
M`@`<````Q@\"`!@```#C#P(`!0```/P/`@`*`````A`"`!0````-$`(`'```
M`"(0`@`-````/Q`"``<```!-$`(`#````%40`@`*````8A`"`!$```!M$`(`
M2@```'\0`@`<````RA`"`#<```#G$`(`+0```!\1`@`8````31$"``4```!F
M$0(`!````&P1`@`*````<1$"`!````!\$0(`%````(T1`@`:````HA$"``H`
M``"]$0(`$0```,@1`@`2````VA$"`!<```#M$0(`%0````42`@`0````&Q("
M`!H````L$@(`#@```$<2`@`D````5A("`!\```![$@(`'@```)L2`@`/````
MNA("`!````#*$@(`*P```-L2`@`K````!Q,"`&L````S$P(`(````)\3`@`@
M````P!,"`!X```#A$P(`(P`````4`@`H````)!0"`!T```!-%`(`&P```&L4
M`@`<````AQ0"`"````"D%`(`&````,44`@`D````WA0"`#T````#%0(`*@``
M`$$5`@`@````;!4"`!(```"-%0(`&0```*`5`@`9````NA4"`!0```#4%0(`
M"@```.D5`@`'````]!4"``L```#\%0(`!P````@6`@`4````$!8"``L````E
M%@(`.@```#$6`@`3````;!8"`!H```"`%@(`"````)L6`@`%````I!8"`$H`
M``"J%@(`3P```/46`@!-````11<"`&0```"3%P(`!P```/@7`@`H`````!@"
M`"P````I&`(`"@```%88`@`0````81@"``@```!R&`(`#0```'L8`@`R````
MB1@"``4```"\&`(`"````,(8`@`,````RQ@"`!(```#8&`(`#````.L8`@!2
M````^!@"`"P```!+&0(`)````'@9`@`.````G1D"`"````"L&0(`'````,T9
M`@`C````ZAD"`!T````.&@(`(P```"P:`@`:````4!H"``P```!K&@(`!P``
M`'@:`@`0````@!H"`!$```"1&@(`%````*,:`@`(````N!H"`$````#!&@(`
M#`````(;`@`(````#QL"``T````8&P(`&@```"8;`@`)````01L"``0```!+
M&P(`%@```%`;`@`(````9QL"``@```!P&P(`!````'D;`@`+````?AL"``L`
M``"*&P(`%````)8;`@`3````JQL"``X```"_&P(`%````,X;`@`.````XQL"
M``<```#R&P(`$````/H;`@`3````"QP"`!P````?'`(`"P```#P<`@`'````
M2!P"``T```!0'`(`&P```%X<`@`J````>AP"`!@```"E'`(`'@```+X<`@`J
M````W1P"``0````('0(`!`````T=`@`-````$AT"``<````@'0(`"@```"@=
M`@`6````,QT"`#H```!*'0(`"````(4=`@`*````CAT"``@```"9'0(`!P``
M`*(=`@`)````JAT"``D```"T'0(`"0```+X=`@`,````R!T"``X```#5'0(`
M!````.0=`@`.````Z1T"``H```#X'0(`"@````,>`@`/````#AX"`!P````>
M'@(`"P```#L>`@`"````1QX"`!\```!*'@(`!P```&H>`@`&````<AX"`&@`
M``!Y'@(`#````.(>`@`(````[QX"`"@```#X'@(`,````"$?`@`@````4A\"
M`$0```!S'P(`)P```+@?`@`?````X!\"`"@`````(`(`+0```"D@`@`Q````
M5R`"`%@```")(`(`)@```.(@`@`I````"2$"`!@````S(0(`'0```$PA`@`%
M````:B$"``H```!P(0(`#0```'LA`@`-````B2$"``L```"7(0(`#0```*,A
M`@`5````L2$"``\```#'(0(`#0```-<A`@`/````Y2$"``\```#U(0(`!```
M``4B`@`'````"B("``@````2(@(`&0```!LB`@`(````-2("``8````^(@(`
M!P```$4B`@`3````32("``8```!A(@(`&P```&@B`@`6````A"("``L```";
M(@(`&0```*<B`@`,````P2("`!8```#.(@(``P```.4B`@`,````Z2("`"(`
M``#V(@(`"````!DC`@`/````(B,"`!(````R(P(`#P```$4C`@`&````52,"
M`!<```!<(P(`"P```'0C`@`>````@","``8```"?(P(`"````*8C`@`-````
MKR,"`"````"](P(`"0```-XC`@`+````Z","`"8```#T(P(`&````!LD`@`0
M````-"0"``8```!%)`(`"P```$PD`@`.````6"0"``D```!G)`(``@```'$D
M`@`.````="0"``<```"#)`(`)@```(LD`@`I````LB0"`"L```#<)`(`'```
M``@E`@`L````)24"`"D```!2)0(`3@```'PE`@`B````RR4"`"(```#N)0(`
M(@```!$F`@`D````-"8"`",```!9)@(`6@```'TF`@`-````V"8"`$T```#F
M)@(`-````#0G`@`H````:2<"`%,```"2)P(`3````.8G`@`A````,R@"`#,`
M``!5*`(`'P```(DH`@`F````J2@"`#(```#0*`(`*P````,I`@`3````+RD"
M`#T```!#*0(`F`(``($I`@`:````&BP"`#@````U+`(`$````&XL`@`_````
M?RP"`(4```"_+`(`+@```$4M`@`E````="T"`$0```":+0(`3P```-\M`@!*
M````+RX"`"P```!Z+@(`&0```*<N`@`0````P2X"`"4```#2+@(`&P```/@N
M`@`<````%"\"`"@````Q+P(`)P```%HO`@`J````@B\"`#````"M+P(`&0``
M`-XO`@`-````^"\"`"L````&,`(`)````#(P`@`H````5S`"`"$```"`,`(`
M'````*(P`@`<````OS`"`#H```#<,`(`O@```!<Q`@!E````UC$"`#4````\
M,@(`2P```'(R`@`U````OC("`"@```#T,@(`-@```!TS`@!<````5#,"`#H`
M``"Q,P(`6@```.PS`@`F````1S0"`"D```!N-`(`10```)@T`@`R````WC0"
M`"(````1-0(`+P```#0U`@`H````9#4"`",```"--0(`+````+$U`@!7````
MWC4"`%8````V-@(`,P```(TV`@!'````P38"`$4````)-P(`,P```$\W`@`Q
M````@S<"`"$```"U-P(`,0```-<W`@`N````"3@"`"\````X.`(`*0```&@X
M`@`I````DC@"`"D```"\.`(`:````.8X`@!B````3SD"`&L```"R.0(`NP``
M`!XZ`@`:````VCH"`"X```#U.@(`-P```"0[`@`H````7#L"`&0```"%.P(`
M&````.H[`@!8`````SP"`"$```!</`(`'````'X\`@`+````FSP"`,P```"G
M/`(`3P```'0]`@`B````Q#T"`#$```#G/0(`/````!D^`@`@````5CX"`!@`
M``!W/@(`00```)`^`@`S````TCX"``8````&/P(`!P````T_`@`$````%3\"
M``P````:/P(`$````"<_`@`,````.#\"``L```!%/P(`!P```%$_`@`2````
M63\"``T```!L/P(`@@```'H_`@`&````_3\"`!4````$0`(`!````!I``@`'
M````'T`"``@````G0`(`!0```#!``@!2````-D`"``0```")0`(`&0```(Y`
M`@`*````J$`"`!(```"S0`(`$````,9``@`"````UT`"``<```#:0`(`!@``
M`.)``@`3````Z4`"``P```#]0`(`%@````I!`@`&````(4$"`!0````H00(`
M#P```#U!`@`#````34$"`"X```!100(`!````(!!`@`&````A4$"``<```",
M00(`'@```)1!`@`\````LT$"`"X```#P00(`+P```!]"`@`6````3T("`"@`
M``!F0@(`,````(]"`@`B````P$("`"H```#C0@(`(`````Y#`@`C````+T,"
M`!X```!30P(`'````')#`@`L````CT,"`"0```"\0P(`,0```.%#`@`:````
M$T0"`"X````N1`(`&@```%U$`@`L````>$0"`#````"E1`(`(````-9$`@`D
M````]T0"`"0````<10(`'P```$%%`@`C````844"`"P```"%10(`)P```+)%
M`@`G````VD4"`"4````"1@(`'P```"A&`@`D````2$8"`#````!M1@(`'0``
M`)Y&`@`J````O$8"`#8```#G1@(`.0```!Y'`@`:````6$<"`"<```!S1P(`
M30```)M'`@`I````Z4<"`"T````32`(`+0```$%(`@`N````;T@"`"@```">
M2`(`)@```,=(`@`A````[D@"`"<````020(`.````#A)`@`J````<4D"`#4`
M``"<20(`#````-))`@`.````WTD"`"````#N20(`*@````]*`@`A````.DH"
M``\```!<2@(`#P```&Q*`@`:````?$H"`!H```"72@(`"P```+)*`@`G````
MODH"``P```#F2@(`"@```/-*`@`E````_DH"`"@````D2P(`(@```$U+`@`G
M````<$L"`"(```"82P(`!P```+M+`@#<````PTL"``L```"@3`(`&@```*Q,
M`@`3````QTP"``<```#;3`(`"@```.-,`@`0````[DP"`!(```#_3`(`'```
M`!)-`@`#````+TT"`#,````S30(`&P```&=-`@`8````@TT"``<```"<30(`
M$@```*1-`@`2````MTT"`#,```#*30(`"````/Y-`@`I````!TX"`!,````Q
M3@(`$P```$5.`@`9````64X"`#,```!S3@(`'0```*=.`@`.````Q4X"`",`
M``#43@(`#P```/A.`@`0````"$\"`!<````93P(`"@```#%/`@`?````/$\"
M``\```!<3P(`'0```&Q/`@`/````BD\"`!X```":3P(`)@```+E/`@`%````
MX$\"`!````#F3P(`!P```/=/`@`+````_T\"``D````+4`(`.````!50`@`2
M````3E`"``8```!A4`(`#P```&A0`@`1````>%`"`!````"*4`(`"P```)M0
M`@`/````IU`"``<```"W4`(`$````+]0`@`*````T%`"``@```#;4`(`$@``
M`.10`@`;````]U`"``@````340(`'0```!Q1`@`;````.E$"`!L```!640(`
M"P```')1`@`-````?E$"`!P```",40(`"````*E1`@`Q````LE$"`!$```#D
M40(`$````/91`@`(````!U("``(````04@(`"@```!-2`@`8````'E("``L`
M```W4@(``P```$-2`@`+````1U("``L```!34@(`"P```%]2`@`*````:U("
M`!<```!V4@(`#@```(Y2`@`8````G5("`!X```"V4@(`#````-52`@`Y````
MXE("`"(````<4P(`(P```#]3`@`9````8U,"``T```!]4P(`10```(M3`@`&
M````T5,"`!H```#84P(`5@```/-3`@`/````2E0"`!````!:5`(`!P```&M4
M`@`$````<U0"``4```!X5`(`$0```'Y4`@`6````D%0"``8```"G5`(`!P``
M`*Y4`@`'````ME0"``L```"^5`(``P```,I4`@`,````SE0"``X```#;5`(`
M"0```.I4`@`-````]%0"`!$````"50(`%````!15`@`0````*54"`#D````Z
M50(`+@```'15`@`L````HU4"``4```#050(`%@```-95`@`E````[54"`"(`
M```35@(`'P```#96`@`3````5E8"``(```!J5@(`!````&U6`@`-````<E8"
M``H```"`5@(`!0```(M6`@`%````D58"``\```"75@(`30```*=6`@`D````
M]58"`#0````:5P(`%P```$]7`@`B````9U<"`#````"*5P(`3@```+M7`@`Q
M````"E@"`#8````\6`(`+P```'-8`@`6````HU@"`'X```"Z6`(`'@```#E9
M`@!9````6%D"`"H```"R60(`3P```-U9`@`P````+5H"`"H```!>6@(`)```
M`(E:`@`H````KEH"`#(```#76@(`+0````I;`@`M````.%L"`"T```!F6P(`
M*P```)1;`@`N````P%L"`"D```#O6P(`*````!E<`@`L````0EP"`#(```!O
M7`(`-P```*)<`@`4````VEP"`!H```#O7`(`#`````I=`@"H````%UT"``8`
M``#`70(`N0```,==`@"%````@5X"`*`````'7P(`(````*A?`@!7````R5\"
M`!`````A8`(`*````#)@`@`=````6V`"`!$```!Y8`(`!P```(M@`@`9````
MDV`"`!X```"M8`(`00```,Q@`@`9````#F$"`!8````H80(`5P```#]A`@`:
M````EV$"``\```"R80(`"@```,)A`@`%````S6$"``8```#380(`"````-IA
M`@`%````XV$"`!D```#I80(`"0````-B`@`8````#6("`"(````F8@(`#P``
M`$EB`@`*````66("``D```!D8@(`!@```&YB`@`.````=6("``T```"$8@(`
M"0```))B`@`'````G&("``P```"D8@(`!P```+%B`@`%````N6("`!````"_
M8@(`"````-!B`@`'````V6("`!````#A8@(`#@```/)B`@`0`````6,"`!(`
M```28P(`$0```"5C`@`*````-V,"``D```!"8P(`$````$QC`@`6````76,"
M``4```!T8P(`"````'IC`@`3````@V,"``H```"78P(`"P```*)C`@`8````
MKF,"``D```#'8P(`!@```-%C`@`;````V&,"`!@```#T8P(`#@````UD`@`4
M````'&0"``L````Q9`(`#````#UD`@`,````2F0"``P```!79`(`#````&1D
M`@`F````<60"`!0```"89`(`!P```*UD`@`5````M60"``<```#+9`(`"```
M`--D`@`B````W&0"``L```#_9`(``@````ME`@`"````#F4"`!H````190(`
M#````"QE`@`&````.64"``@```!`90(`&@```$EE`@`&````9&4"`"4```!K
M90(``@```)%E`@`$````E&4"``P```"990(`"0```*9E`@`1````L&4"`!<`
M``#"90(`"P```-IE`@`)````YF4"`!````#P90(`"@````%F`@`6````#&8"
M``<````C9@(`'````"MF`@`*````2&8"`!<```!39@(``@```&MF`@`%````
M;F8"`!````!T9@(`#````(5F`@`2````DF8"`!(```"E9@(`$0```+AF`@`I
M````RF8"``<```#T9@(`!P```/QF`@`1````!&<"``4````69P(``@```!QG
M`@`+````'V<"``$`````````>`8``(L&``````````````````#-`P``=`<`
M`&P'``#L!````````.H!``!^!```3`0``!D!``#*`0``.@@```````#O!@``
M.@0``*$"``"B!```,P``````````````!`8``/X!``#Z`P``O@0``%T!````
M````O`0``)L&``#Y!````````.H$``#0`0``Z`8``-T&```5`0``I`````@`
M``"Y````I`(``/,$`````````````(\(``"9`0```````,$````6`0``@`,`
M`#('`````````````,0#``!#!```#@8``-``````````L0(``&T(``#)!```
M:P8``&(!```L`@``508``)`(```V"````````-P#``#"!````````%$(``"*
M`0``````````````````=0(``.0```#.!0``6@4``"@$```]`P``?08``%8%
M```(`P``4`<``,8#``"R!0``:0$``"($````````L`(``&((````````````
M`#T$``#>`P``)@4``'D$````````8P4``(,"``!#`@``4@0````````F````
M7`(``-L&```<`@```````#\$```*"```[0<```````!$"```4@$``-D%``!\
M`P``]@4```T&````!@``Q04``#0(``#D`P``S0(```0!````````K04``#$%
M``!W`@``X`8``)0#``!V"```.@$```````#D`0``[P$``"\```"6!0``5P(`
M`%$%```3"```9`0```8$```Q"```2`4``,4$``````````````````!&!0``
MC0,``$P&``"!`@``>`@````````"!@````````````!\`@``D08```````";
M!0``90,``!$'```_!P``G@```'`'`````````````"0#````````HP4``+P&
M````````)`8``.<&````!```````````````````CP````````"L`0``.`4`
M`/X'``"R`0``G`8``'D&````````\@$``(L"````````3`(```0"``"*!0``
M*0(``!$$``!N!```P@,``#(#```2`P```````'T%```Y!0``@`(``+,&````
M`````````(4%`````````````,`$``!?!```[0,``/P#``#"`0``^08`````
M````````'@@``(<!```4!P``(0```!P```!L!0``X0<``&L#``!G!@``````
M``D'``!W!0``OP(``#L#```7!```8`$``!(%``!"!@``FP,``$$(``!O!0``
M`````*`%``"U````EP<```0```!^`@``SP4````'``#6`0`````````````:
M!`````````````#,!P``F@$``%L'``"X````0P@```````#Z`@```````(D'
M``!T!@``-@<```````#-!P``*P4````````.`0``R````/X"```F`@``````
M``````#-!@``NP,`````````````&0<``%L"``"'"```5`4``#<#``#(`@``
M7@@````````I`0```````'X#``"2!```&@@```````#)````O@```!8$```?
M"```B`4``&4!````````&P4``,4```#E`P``_0<``"P%````````1P<``#,"
M``!_"````````#@```"V`P``?P(``"<&````````5@8```````!+`@``JP8`
M`-4&``!2!@``XP$``#````#J!P``````````````````QP4``#H%````````
MH`<````````J!```U`0``&(&``#.!P```````````````````````(<&``!]
M`0``S00``%P$````````YP<``*@#```#`0``?P$``'<```#2`@``:0(``*T`
M``"C`@``2@@``!(&````````B0@``'`%```%`@``/````!,"```M!@``V0,`
M`.$#````````!P8``/H&```U`P``A0,``#0'``".`@``!@8`````````````
M`````(4(````````]P0``$4%``"I!0``]@8``#$```!"`0``[P<``+0!``!M
M!0``6P@``,,```"D!```QP`````````T!```)0@``#P%``!Y!P``P04`````
M``"Z`````````(D"````````<P8``%P#``!^!0```````%0$``",!```(@4`
M`+L"``"7````1`0``'\$``#Y!0``;0,``%D!```E!@``)0,``!4```"Y!P``
MP`(```<%``"?!0``L0,```(```!0`0``R`8``&(%``!9`@``N04``/4&``!V
M`````````"L$``!*`0``10,````````6"```R`$``&X!``!3!0```````#H`
M``"3````:@<``(T!```F!@``8`@``,$"````````T@```#L%````````````
M`)P```#S`P``D0@``&\```!:"```F@8``'P```#C!0```````,P#```A`@``
M``````($``#K!@``T@8```(#``"^!@```````/L%``"!!``````````````<
M`0``!04```T(``!+!@``Y`4```D#``"'`P``0P`````````;````````````
M````````:P$```````":`@``U0,`````````````SP0```````"8`0``I0,`
M`!H#``!3````\`$``%@%````````/P8``#(```#.`P``G@8``%L```#@`P``
M`````*<"```P!P``0`$```````#.`0````````````"(`P``6````"$!``"G
M`0````````````"&````%0,``````````````````),!````````@P0`````
M``"G!@```````.T````-`P``^@<`````````````;`,``(D%````````F`0`
M``````"Q````Y@$``)$#``"\`P````````````#>!```Y@``````````````
M.P0``)`#``!2````9@```&0"``"0`0``C`(``'T(``"2!P``AP4``,<'````
M````:0@````````Y`P``OP$``+0$``!=!P``Y@(``!T(``#B!@```````#4&
M``"/!P```````+X!``"9`P```0<``!T'``!L!@``8P@```````#:!P``T00`
M`$X%``#0`@``!@```&$'```U`0``N`<``-,#````````[@0``&@%```:!@``
M,P@``!8%``!N`````````!@%``"@!```=0<``-@%````````1@8``%T$``#K
M!0```````.8#``"N`0``C08``&8$``"S`0``>`0``&P$``#&````:0<``!L'
M``#.!@``IP0``#\#````````$0@`````````````V@8``+\$```[````]@(`
M``8(``!+!````````"0$```;"```%`(``,4&``"Y`0``8`8``!$"``!<!@``
MI`8``.0"``#^!0``N`4``-@```"L`@``>`4``$T(```J"```"P@``-@'``"$
M!````````*`"```R`@``]0<``'0"``"\`@``=@4```````"&!P``<0<``(H`
M``!-!P``N08``*$`````````<@4```````#8`0```````#((````````````
M`%L#````````E04```````"H!```(@8``%H$``"1`0````````````"5````
M'P<```````!7"```[`(`````````````;P8``(((````````60````L!```\
M`P``-`,``-X%``!9!```?`8``#L"``!^!@``3P````````"-````UP(``$X&
M```@"````````(H$``!D!@``LP4```P```#J`@``N00```````#5!```K@(`
M`'`&``""!````````+,'````````408``*(%``!Q````(0@``/@'````````
M`````"P````\!````````(<"```5`@``GP0```````#7!```C`4```````!<
M`0```````````````````````*$'``#_!0``DP<```````#?`0``;`$`````
M``![``````````$(``"]!0``3P<``.("``#?!@``5P```"X!``!]`@```@(`
M`+L!```H`P``S04```````!6````:P0``'4(``"!!P``-`4``-\"``!Q`0``
MM@(``!T$``!.````$`$``)0```"Q!P```````-P'``!X````V0<``%\(``!+
M!0``ZP(``)L```!E!0``^0(`````````````*P8``$D!``#N`P``<00``$X#
M``!0"```"`@``&4&``#2!```O0````\!``!^````Y0$```````#S`@``````
M``````!1````1@<``)<#````````[P4```````":!``````````````]`@``
M`````)L"``!W!```C`,``,8!``"4!P``````````````````PP0``*X#```)
M!0``(@$``+$!````````4P0``#`$`````````````'$#```5!```*0<``+`#
M```````````````````T`@``V`8```````!V!@````````````#Q`P``I0<`
M``8#````````V@````$#````````PP4``&$`````````80$```<!``#K!P``
M`````+(&``".!P``(0<``"@!``#!!P```````&<````.````?`<`````````
M````;0(``#0```!G!P``%P,``'4&`````````````-$&````````J0(`````
M`````P``'08``/\!``"$`@``/0<``%D%````````_@```/4%``"C````8P8`
M`-D!``!;!````````)0"``#;````@````"8$```;!@```````!<%```X!```
M&0(``/D!``"C`0``9P0``.4"``#8`P``HP0```````"D!P``*@4```````"6
M`@``*`@`````````````Y0<```````"R`@``\0$``.(```"2!0```````!L!
M```Q`@``C@0``($!```4```````````````4!```;P(``!D#``!J`@``3`@`
M`*<`````````C````/8````D`0```````!D`````````<@$``-@$``")`P``
M`````&8!```8````*P```/\```#$!0``D04```````#]`@``.0```!\$````
M````PP8``"0(``!8`0```````)4"``#T!```P@8``.D$``"$!0``U04``%X$
M``#\!```8P,``#8%``!:!P``OP8``'```````````````$\"````````/P@`
M`&<%``#Q!0```````&H``````````0$``$L```!U`0```````&H#``!T````
M?`@``$H"``"F````3P0```````#(!P``1@@``/,&``"J````````````````
M``````````,#`````````````$4$````````7@(``&T'```I`P``'`<``"T"
M``!8!P``50$``$@#``"]!@``\`0```````"M!P``]0,``)<!``!)````&08`
M``````#(`P``*P@``",(```[!P``Q@8``.$&``!S`@``;0```'0(``#;!0``
M^`,``/\'``#_`@```````!0&```7!P``X`$``+\```"Z!@```````*P'``#K
M`P```````!(```#_!```]P8``(H'````````_00``*H!```[!@```````/<#
M``#R!P``(`0``(`(```W````Q0,``*H"```+!@``(P,``$T$``!&`P``T@<`
M`(8#``"&!```)04```````"#"````````-T```#N!0``N`$``!@&``#[!P``
M`````&\!``!J!@``G0,``"8(``"@`0``/08``)0&``"T!P``<P<``'<'``"2
M`0```````-L#``""!@``;00``#X!``!'`P``.0<``&4(``!G`@``#P,``($&
M```=!0``;P@``(('````````%P@```,'``"?!@```````$X!````````T0$`
M`.$$``"A!```(P8```````!:`P``X`(```````#C!P``#`4``)P%``!3`@``
MEP(``/@"```K!P``F0``````````````JP4``'L(````````"08```````!$
M`0``<`0```````#!!@``>0`````````!!0``U0```.('```4"```6`8``!H%
M``#]`P``>@(``"D(````````3`````````#.!```W00``!("````````.@(`
M``````"-`@``3@@``$(%``#0!P``F`,``),%``!,!P````````````#6`P``
M`````*@!``#*`P```````$D"``#Y````,`$``,D!```C!```>@,``#X'````
M````80@``*4$``"/!@``^P$`````````````O`<```P!``"E`0``>0,`````
M```W`@```````.P#```2`0``:`<```````"&"```IP4``$(`````````WP``
M``````"!`P``TP0``"H!``"Z!P````````````!(!P```````'D"``"U`@``
M`````*(&``"[!P``(`<``/4"````````+P$``"\&``#$!```.`8``/("``#P
M!0``SP(`````````````BP@```````!W`0````````````!U`P``I`4`````
M``!5"```!P,``/0"```3!@`````````````3!``````````````=`0``#`@`
M``````#*!P``X````$<"````````\08``/,```"H!P``````````````````
ME`$``````````````````,L"``"Q!```=@<``!@'`````````````!4&``"Y
M`P````````,```"+!P``!0@``+<#``"+!0``MP0``&<(````````WP0``(4$
M``"1````X0$``)<%```P"````````-$```#V`P``*`4``-0"``!)!P``4P8`
M``````!T`P``P`4```````"W!@```````'<(```"`0``N@$``#<(``"$!P``
MG@4`````````````MP```.,"``#J`````````/,'```P!@``T@,````````*
M`P``'@$```````#6!```*04``#H&``"!"```/@0```````"T!@``_`<``'4%
M```A`P``S0```-8'````````500``(L!``"Z!0``T`8``-\#``#)!P``````
M`),$```N`@``"0(``!0%``"I`P``A`,``.<%```8!````````+\#```G````
ME`0`````````````LP```.L!``#R````2`(``$$'``!5````.`$``-<```#`
M!@``I04``&,$``#[````BP0``*,#`````````````#0&``!9!@``)0``````
M``!W`P``?`4``$H`````````)`(``(X``````````````&(`````````%P8`
M````````````=00```````"O!0``#P(```````!A`@```````&H%``!,!0``
M[`<``+8```#:`P``Y@4````````R`0```````"4'``#R`P``2@,``$("``!4
M!@``F`(``&,````````````````````L!````````'8!``#@!0```````&L%
M````````*@8```````````````````````"O````6@8``(P!```/"```,P$`
M`"P'``#$`@``3P4``.@`````````I0```!X'`````````````(,`````````
MGP<``(`%``#&!P```````)P$```.!0``9`$``'8"``![`P``-04```T`````
M````[@(``/T%`````````````+H$```?`0``:`,```X'``!9`P``$@<``"X'
M``!C`@``0@,```,"`````````````-$'```%!P```````/4`````````_P8`
M``````"#!P``)0(``*X$````````1P8``,`'``#L`0```````&(#````````
M6`,``%<&```>!0``B`@``$$#`````````````*8$``#V!P``.08``%8"``!'
M"```(`,```````#<`0``+0```#,$````````008`````````````$P``````
M``#X````$`,```H!``````````````````#S!0``*`<``)4&```?!@``L`0`
M`/8$``#P!P``V@$```````#,````708``$D&``"9!@``7P(````(``"P!0``
M``````````#I!P``200``,,'```'````@P$```````!"!P``&@```*8"``!A
M!````````(X(``#/!@``(`4``&L"````````K@<``,0&``!_````YP$``+@#
M````````^P(``'H$``!_!P```````,T!```)````!P0``$T!``#*````````
M`/4$``#I!@```````$\!```&`0``EP8``%X'````````2P@``.\$```(!@``
MS`0``.L$``!K````+@,``%0`````````?00``#T(```V````+`8````````X
M`@``D`<``.@"``"&!0``/@8``,<$``#=!P`````````````3`P``S`4``&`%
M``"T!0```````"<$``#/`P``8````#4"```W!P````````0%``#^!@``D`4`
M`'(&```+!0``K@4``*\$`````````````.4$``!N!0``````````````````
MD@```,,!``!H`````````/`#``"G`P``%04``&\'```0"```J0$``&@!``!4
M`0``TP(``#4$```N````'@,``%8'```8`0``-0@``%<!```#!0``C`@```\&
M`````````````.`$````````+P@``/P&`````````````"P!``"0````O0(`
M``````#^!```6@(```````#*!0``>P8``$\#``#\````<@`````````X`P``
MJ@,``,,"``#T`0``RP,````````D!P``50,``",'```B`P```````!((```Q
M`P```````!`$`````````````,<&```J`P``5`<```````#+!0``X@4```D$
M```Y`@``G0$``%\#``!!`@``3@(``-P"``#R!0``$04```````"M!@``1P$`
M`"8!````````8`0``&P(``!4"```OP4````````Y"````0(````````,`P``
MG`<``````````````````"$$``!C!P````````````#*!@``XP0``!@"``!Z
M!0``<P4``)X!``!,`P``6`(``!T```"1!P``)@<``%8(``!S!```I@4``!0#
M``"U!@``?0``````````````*@(```````#``0``9@4```````"9`@``````
M``````"_!P``I08``-\'```$`P``$`4```````!&!```J`````````"P!@``
M`````)T%``````````````````!N!P``T`,``*P$````````A`8``&$#``#)
M`P``/P$``'`(``";!P`````````%``!6!```J@8``)8````W!```````````
M``#X`0``N@(``+,$``!I!```UP$```\%``!!!0``>`$```````#8`@``````
M`#D!```<"```Y@0``%0#``"K`@```````$`%```P`P```````!L$``"J!P``
M#P<``.\```!`!P```````-L!````````+0@```L'````````7@,``$@(````
M`````````&4'```G`0```````&H$``!3!P``>@@````````H````&`,`````
M```?`@``-P$```H"``!3`0``5`(``-(%````````E@<``)D$``"<`0``#@(`
M``````"M`@``XP,``-0#``#X!@``)P4```````"F!P``-@,``-,'```+`@``
M7@```-4!``#Z!`````$```````!S`0```````````````@``M0<``,L```!:
M`````````)8#````````\@0``)T```"C!P``F@4```````!P`@``<08``)X$
M``#X!```@P,````````(!0``%P$``)$"```,`@``0`(``/D#``#H!P``O```
M``````![!0```````"P(```\!@``4P,``.,````J!P``704``+<%``"/!0``
M:@$``"``````````%0<``!\#``!O`P```````$@&``"?`0``E@8````````N
M!0``!0,```````#"`@``````````````````;@(``!<````D````<0@``-P%
M``````````````````"C!@``.@<``$8!```"!0````````````#S`0``````
M```````G`P```````)D'```3!0``ZP```&@"``!!````W0,``"T!```>`@``
MA`@``#\"````````A0(````````P!0``L````#8"````````S@```$D#``"T
M````10@``'L!````````GP```!X``````````````(`'``".`0```````(<$
M``"-!P```````)4!```]`0``0P$``#X"````````4@<`````````````$P<`
M`*@&``"5!```;08``!\%``#9`@``B00```````!\!```N0(``)8!````````
M#P0``$@!``#/````O0<``'(#``#'`0``[0(``+,"````````!@<```````!D
M"```2```````````````H@$`````````````>@<``.P&```9!0``O@4``/D'
M```I!```P````+T!``"K`````````(T%````````B`(```````!M`0``9`,`
M```````^"```;@8```,$``!/"```&@<``%`%``"=!```9@@`````````````
M10<```````!1!```Z04``&($````````^P0``/8!``![!P````````````!V
M`P``CP,``.@#``#G`P``Y@8``!$#``!-!@``[04``.X&``"^`@```````%<#
M``!6`0```````(("````````:0,````````D!0``=`4``#P!```?````(P$`
M`,@%``!Z`0```````(H&````````?P8```````#=`0``?P4``+8$```;`@``
M`````*D&```B````NP8``&L(``````````````````"\`0``%@,````````(
M`0``````````````````0P<``)@``````````````&H(`````````````/@%
M```O`@```````.@%``"E`@``I`,``%("``#$!P```````"<(``#?!0``1```
M``````!)!0``7@$``)X"```!!@``T@$```````"$`0`````````````1!@``
MT`4``+8!``#E!0``A08``$`#```)"```,0<```````!?!P``<P```(T$``#6
M```````````````-!````````*\"````````<`$``.(!``"=!@``JP$``#L!
M``#Q````Q@0``%P'``"A`P``Z@,``(`!``!-``````````X(``"<`@``S`(`
M``\```!'!0````````````#.`@``[@```````````````````"L#````````
M/`@``%`$``!0!@``.`<```````!""```(@<``!`'````````!P(``)@&````
M````B`0````````9"````````/$$``""`0````````````#T!0```````"4!
M````````$0$``*(`````````M@8``*X&````````0@0``$T#``"2`@``````
M``4```"'`````````#X```"J!```(`8``*H%``#_`P``E0,``%((``#\!0``
M#0$``%T"``#T!@``6`@``.<```!R!```H````$4!``#7!P``"P,``-<%``"4
M!0``!@(``(D`````````DP(```````"L````G0<``*P#``#>````0P,``*\&
M``"H`@``:`0```````````````````````!]!P``B`8``'$%````````````
M`!@(````````804``"\$```.`P````````4&```.!````````!$```!=````
M`````)T"``!0`@``%@<``/T!``!$!@``^@$``"4$``!*!`````````````#%
M`@```````#4```!2!0``TP````````#Z````MP(```````"0!```9````,D"
M```J`````````+T#````````?@<```T%``".!0``E@0``!<"``"L!@``!`<`
M```````K`0``(04``$@$````````Z@8``*T$``"+`````````-0!``!G`P``
M-@0```D!``#3`0``[P,``````````````@<``````````````````#@(``"*
M`P```````,0``````````````)\#``#6!@``[08``(,&````````'0,``&X(
M```-`@``2P,``)X'```N!@````````@'`````````````#(&``"O`P``EP0`
M`/<"``!1`@```````"8#````````>P(``,(%``"U!0``C`8``$T"```*!P``
MCP(``)P#``#T````Z`$``$P!``!D!P``*0`````````+!```NP```-`$````
M````10(``(X&``!$!P```````'0!``#E!@```````#,%``!/!@``!P<``/L#
M``"W`0``W0(``%4"``":`P``8`,``$H'``"'!P```````$``````````XP8`
M`!`"````````````````````````L@<``.<$``"T`@``,P<``#H#``!#!@``
M/`(``#4'````````L`<``/<!``")`0``I@,``````````````````*T#````
M````5P0``.0'``"*"```*08```$$```["```&@(``(4``````````````%X%
M``#<````B08``-8%``!H"``````````````S!@``-@$``*('``#1`P``(08`
M`&D&```#"```+P,``-D`````````%@```,L$````````F@<``%````#H!```
M<`,``&P```!U`````````-X!``"`!``````````````@`@```````'H&````
M````^P8``&8&``#>!P``SP$```````"X`@``X@,``````````````````$,%
M``!D!0``M@4``!($````````]P<``-H$``"&!@``_@,```````!$!0``6P8`
M``@"```O!0``<@@``$X'```*!0``\0(``+$&```#!@``1`(``*L#````````
M6@$```((```_````7````#$&``!Q`@```````#T```#J!0``````````````
M`````````%L!````````T04``)D%``"K!```@@```-4'````````[`4``(H"
M``#D!@``]0$``-X&``#Q!P``K@```#<&````````!`0``&4```!&`@``D@8`
M`,4!````````(`$```````"$````J0```*$%``"&`@``2P$``$4```#M`0``
M``````````!R!P``F`4``%D(``#;!`````````4!```0!@``(P4``(T(````
M`````````,0!``""!0``1@```#0!``#4````Z0,``,,#``!1`P``M00``,$$
M```L`P``\````.$"``!R`@``%0@```````!<!0```````!X&````````/`<`
M`/T`````````B`<```````!%!@``X0```&4"``#&!0``>@```-4"``#'`P``
MY0```%P(``"R````RP8``',(``#&`@``>0@```````!\`0``,`(``,4'``"T
M`P````````````",!P```````+(#````````2P<``/0#``!!`0```````/<`
M``"`!@``7@8``-8"``#N`0``V@4``+T$````````A0<``#T%````````V08`
M``````````````````4$```B`@``F`<``&("``"W!P``SP<``,$!```R!```
M`````'X(````````P0,`````````````"P```'D!```'"```4@,```````#I
M`@``S`8``$`&``!7!0``#0<``,H"``!H!@``X@0``)\"``#T!P``L@0``+8'
M``"^!P```````&<!`````````````*D$``!;!0``+P<```H````$"```_08`
M```````6`@``P`,``,('``"B`P``N`0```````"&`0`````````````<!@``
M``````````!*!0``UP8``,<"````````\@8``*T!``"2`P``W@(``"<"``!A
M!@``>P0``&('``!F!P``#`<`````````````+0<````````M!0``M0,``!P#
M``#@!P``````````````````H`,``$$$``#;!P``,@4```````"3`P``*`(`
M``````"+`P``9@,``+X#````````+0,```````!`"````````!P$``#A!0``
M`````'\#``!?`0``-@8```8%``"!!0``<P,``&,!``#:`@```````.P```!?
M!@``&@$``!X$``#P!@```````.<"``"S`P``+@@``%\%``#,`0``Y`0`````
M``"P`0``````````````````]P4```H$``"#!0``_`(``"T$``"G!P``````
M`.\"````````?@$``)H`````````D`8````````6!@``V00``%@$``!I!0``
M3@0``&8"``!="```U`8``*`&``"/`0``^@4``#<%``#4!0``R@0``+4!````
M````\`(``$0#````````@@,``($`````````R08``)4'`````````````.D`
M````````>`<``.D!````````(P(``#$$``#7`P``/P4``),&``";!```RP<`
M``````#3!0```````*8&````````VP(``#,#```K`@```````+@&````````
MR04`````````````40$``&`'``!Y!0``7P``````````````=P8``&P"``#\
M`0``#`0```````!'````(@@``%T#``#1`@``/@4```````!T!```'`4``(\$
M``!E!```L04``!0!``!6`P``&00``.8'``"B`@``60<``$H&````````````
M`!,!``"H!0``K`4``(4!``!7!P```````+L%``"\!0``W04```````"(`0``
M4`,``(X#````````G@,``"@&``#4!P``#`8``-,&``#+`0``I`$``%,(``!5
M!P``504``*D'``"0`@``=@0``$<$````````P@```$D(````````KP<``#D$
M```^`P```````$T%``!@`@``D00`````````````>`(``!T"````````````
M```````0````W`8``&D```!]`P``[00```````!1!P``H08```H&``!K!P``
M&P,``"X$``!X`P``)P<```````#N!P``(P``````````````N@,``*L'``"(
M````NP0``*$!``!O!````````#$!``";`0``0`0```````!N`P``KP$`````
M``"F`0``"`0``,@$``#<!````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@061D(&%N($E-4U`@061D<F5S<R!";V]K`"!$96QE=&4@24U3
M4"!!9&1R97-S($)O;VL`(&%T(``B)7,B(&%L<F5A9'D@97AI<W1S(&%N9"!W
M87,@;F]T(&EM<&]R=&5D+@`B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S
M(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@
M;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E
M;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`
M(B5S(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET(&ES(&$@;&ES="X`(B5S
M(B!W87,@;F]T(&-R96%T960Z("5S+@`B)7,B('=A<R!N;W0@;6]V960@8F5C
M875S92!I="!I<R!A(&QI<W0N`")&:7)S=&YA;64@3&%S=&YA;64B("`H:64N
M($IO:&X@1&]E*0`B3&%S=&YA;64L($9I<G-T;F%M92(@*&EE+B!$;V4L($IO
M:&XI`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D
M("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E
M<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT
M`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`
M)7,@861D960N`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!F
M:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I<R!R96%D>2!T;R!P97)F
M;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N
M($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI
M;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E
M<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML
M:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W
M:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@
M;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A
M;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG
M("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`
M,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I
M;W5S`$$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER
M960`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L
M;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!
M32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@
M4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!
M8F]U="XN+@!!8F]V92!S96%R8V@@9F]R;0!!8G-B;W1T;VT`06)S;6ED9&QE
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C97-S(&1E;FEE9"!T;R`E
M<P!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N
M="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@
M0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@
M3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D
M9"!A9&1R97-S(&)O;VL`061D(&%N9"!$96QE=&4@24U34"!A9&1R97-S(&)O
M;VMS`$%D9"!C;VQU;6X`061D(&9I;&4`061D(&YE=R!M96UB97)S`$%D9"!P
M86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@
M=&\`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O
M:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L
M9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`
M061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N
M`$%D9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+@!!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D9')E<W,@
M0F]O:R!,:7-T:6YG`$%D9')E<W,@0F]O:W,`061D<F5S<R!B;V]K(&5N=')Y
M`$%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+@!!9&1R97-S(&)O
M;VL@=&\@9&5L971E(`!!9&1R97-S(&)O;VMS('1H870@=VEL;"!N;W0@8F4@
M9&ES<&QA>65D.@!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`061V86YC960@4V5A<F-H
M`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!%>&ES=',`06QR96%D>2!E>&ES=',`06QT97)N871E($E-
M4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-
M4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E
M('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@
M:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R
M(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO
M=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D
M80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES
M(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI
M;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E
M($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('1H870@>6]U
M('=A;G0@=&\@9&5L971E("5S/P!!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N=')I97,_`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@
M86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!
M4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N
M9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`
M07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@
M<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E
M;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO
M;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E
M<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&
M2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R
M8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA
M<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R
M8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`$)A<V5L:6YE`$)A<VEC(%-E87)C:`!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;&]W('-E87)C:"!F;W)M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I;F0@
M9F%I;&5D.B`H)7,I("5S`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC
M871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y
M<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K
M;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T
M<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>0!"<F]W<V4`0G)U;F5I($1A<G5S<V%L86T`
M0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!"
M=7-I;F5S<R!#871E9V]R>0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S`$-35@!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`
M0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E
M<R(`0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+@!#86XG="!A9&UI;FES
M=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@
M=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA
M9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E
M(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T
M96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#
M:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN
M`$-H96-K(%]!;&PO3F]N90!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E
M($%P<&QI8V%T:6]N.@!#:&]O<V4@82!N86UE`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A9&1R97-S(&)O;VL`0VAO
M;W-E(&%N(&%D9')E<W,@8F]O:SH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@9&ES<&QA>2P@86YD
M(&EN('=H870@;W)D97(Z`$-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O
M('5S92X`0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@
M=VAA="!O<F1E<CH`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#
M;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A
M<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#
M;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S
M($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S
M92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O
M;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!/<'1I
M;VYS`$-O;'5M;B!T:71L97,`0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I
M<W!L87EE9#H`0V]M:6-S`$-O;6UA('-E<&%R871E9"!V86QU97,`0V]M;6$@
M<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI`$-O;6UA;F0`
M0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M
M<&%N>0!#;VUP86YY($%D9')E<W,`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD
M:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO
M;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L
M;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@
M)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T
M:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T
M:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@9F%I;&5D.B`E<P!#;VYN96-T:6]N
M(&9A:6QU<F4`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!#;VYT86-T(%-E87)C:`!#;VYT86-T<P!#;VYT86-T<R!I
M;B!L:7-T.B`E<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S
M960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA
M;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO
M;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@
M4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD
M(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A
M8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S
M:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@
M9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O
M=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R
M97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O
M=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I
M;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD
M(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@
M9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W
M<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D
M(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D
M971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`
M0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D
M<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I
M97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@
M<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S
M879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@
M<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@
M;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E
M:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E
M(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T
M;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N
M)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I
M9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O
M;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E
M9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E($%D9')E<W,@
M0F]O:P!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@
M:6XZ`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T
M960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O
M871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#
M=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R
M96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE
M`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T
M`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP
M:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A
M=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#
M;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N
M=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A
M=6QT(%-H96QL`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I
M;VYS`$1E;&5T90!$96QE=&4@061D<F5S<R!";V]K`$1E;&5T92!#96QL`$1E
M;&5T92!#;VYF:7)M871I;VX`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L
M971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@8G5T=&]N(&)E:&%V:6]U<@!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&9A
M:6QE9#H@*"5S*2`E<P!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@
M86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T
M960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E
M='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&5T:6YG(&-O;G1A8W1S(&ES
M(&YO="!A=F%I;&%B;&4N`$1E;&5T:6]N(&9A:6QE9`!$96QI=F5R>2!T:6UE
M`$1E;FUA<FL`1&5P87)T;65N=`!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L
M87D`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I
M`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB
M;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@
M96YT<FEE<S\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI
M;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$;W=N;&]A9"!V0V%R9`!$<F]P
M(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@
M9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I
M8V4N`$524@!%8W5A9&]R`$5D:70`161I="`B)7,B`$5D:70@061D<F5S<R!"
M;V]K<P!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D
M:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!E
M;G1R>2!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N
M<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`
M16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!
M9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H
M(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`
M16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R
M;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SH`16YT<GD@9F]R("5S('5P9&%T960L(&)U
M="!S879I;F<@=&AE('5P;&]A9&5D(&9I;&4@9F%I;&5D.B`E<P!%;G1R>2!F
M;W(@)7,@=7!D871E9"X`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O
M<@!%<G)O<B!A9&1I;F<@)60@8V]N=&%C="AS*2!T;R!L:7-T+@!%<G)O<B!A
M9&1I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@=&\@;&ES="X`
M17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG("5D(&-O
M;G1A8W0H<RDN`$5R<F]R(&1E;&5T:6YG("5D(&]F("5D(')E<75E<W1E9"!C
M;VYT86-T<RAS*2X`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R
M<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E
M;G0Z("5S`$5R<F]R(')E;6]V:6YG("5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T
M+@!%<G)O<B!R96UO=FEN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C="AS
M*2!F<F]M(&QI<W0N`$5R<F]R('-E87)C:&EN9R!T:&4@861D<F5S<R!B;V]K
M.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H
M:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E
M9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R="!!9&1R
M97-S($)O;VL`17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+@!%
M>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2X`
M1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B
M;V]K.B`E<P!&86EL960@=&\@861D("5S('1O("5S.B`E<P!&86EL960@=&\@
M8G)O=W-E(&QI<W0`1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y`$9A
M:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE
M=R!$3B`]("5S+"!2;V]T(#T@)7,`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A
M:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S
M(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL
M960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S`$9A:6QE9"!T;R!M
M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I;&5D('1O
M('-E87)C:"!T:&4@861D<F5S<R!B;V]K`$9A:6QE9"!T;R!S96%R8V@@=&AE
M(&1I<F5C=&]R>3H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U
M87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3
M;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE
M="!F;VYT`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U
M;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE
M8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M`$9I;&5S`$9I;'1E<G,`1FEN9`!&:6YI<V@`1FEN;&%N9`!&:7)S="!(86QF
M`$9I<G-T($YA;64`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A
M=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O
M9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E
M8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@
M='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R965B=7-Y(%52
M3`!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I
M;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@
M:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`
M1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($%D9')E<W,@0F]O:P!';&]B
M86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C
M:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA
M;F0`1W)E;F%D80!'<F]U<`!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R
M:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M
M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI
M9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(
M;VUE($%D9')E<W,`2&]M92!#:71Y`$AO;64@0V]U;G1R>0!(;VUE($1I<F5C
M=&]R>0!(;VUE(%!H;VYE`$AO;64@4&]S=&%L($-O9&4`2&]M92!3=&%T92]0
M<F]V:6YC90!(;VUE(%-T<F5E="!!9&1R97-S`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O
M=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@
M5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@
M4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U
M;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U
M(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG
M87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I
M;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C
M<F5A=&EO;B!F86EL960Z("5S`$E-4U``24U34"!!9&1R97-S($)O;VL@061M
M:6YI<W1R871I;VX`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC
M96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT
M`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!)
M;6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@
M9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="!!9&1R
M97-S($)O;VLL(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O
M<G0@061D<F5S<R!";V]K<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@
M9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV
M:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M
M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T
M97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`
M26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T
M97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D
M9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O
M<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E
M<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M
M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A
M<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN
M:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G
M97(@;&ES=`!);G9A;&ED($E$`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A9&1R97-S(&)O;VL`
M26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI
M9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S
M+@!);G9A;&ED(&5M86EL`$EN=F%L:60@96YT<GD`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&ME>2!S<&5C:69I960N`$EN=F%L:60@;&EC96YS92!K
M97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y
M<&4N`$EN=F%L:60@;F%M90!);G9A;&ED(&]B:F5C=$ED`$EN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@
M:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!)
M;G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!)
M;G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`
M26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3
M=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU
M87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A
M;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U
M;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P
M(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@
M1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S
M`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC
M(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET
M`$MY<F=Y>G-T86X`3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@
M3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+@!,
M85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC`$QA<W0@2&%L9@!,87-T($UO9&EF:65D`$QA<W0@3F%M90!,87-T(%!A
M<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T
M(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ
M($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE
M<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI
M96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A
M:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3
M:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES=`!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI
M=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S
M('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT
M`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T
M=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A
M;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`
M36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN
M+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E
M9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-
M87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D
M*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<`36%T8VAI
M;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R
M961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M
M($YU;6)E<B!O9B!#;VYT86-T<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@
M0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F('!A9V5S
M`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!,:7-T`$UE;G4@
M;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y
M<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C
M;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-
M97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`
M36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@1$X@:6X@
M3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BX`36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N
M`$UO`$UO8FEL92!-86EL`$UO8FEL92!0:&]N90!-;V1E<F%T90!-;V1I9FEE
M9"!$871E`$UO9&EF>2!54DP`36]D:69Y(&9A:6QE9#H@*"5S*2`E<P!-;V1U
M;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT
M:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R
M92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E
M9"X`36]R92!T:&%N(#$@96YT<GD@9F]U;F0`36]R;V-C;P!-;W-T;'D@0VQE
M87(`36]S=&QY($-L;W5D>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T
M;'D@4W5N;GD`36]V90!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`
M36]V92!5<`!-;W9E(&1O=VX`36]V92!L969T`$UO=F4@<FEG:'0`36]V92!U
M<`!-;WIA;6)I<75E`$UU;&)E<G)Y($%D9')E<W,@0F]O:P!-=6QT:2UL979E
M;"!D<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('!E
M<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL(&)U="!N;VYE('=I=&@@;F%M92!;
M)7-=(&%L<F5A9'D@97AI<W0`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U
M;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!!9&1R97-S($)O;VL`37D@
M061D<F5S<R!";V]K<P!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N
M;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;64@1F]R;6%T`$YA;6EB
M:6$`3F%U<G4`3F5P86P`3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GD`3F5T
M:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!5
M4DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L
M:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T
M:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE
M='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($-O
M;G1A8W0`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE
M86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O
M;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H
M7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE
M>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEC:VYA;64`3FEG97(`3FEG
M97)I80!.:6=H=`!.:75E`$YO`$YO("5S(&5N=')Y(&9O=6YD(&9O<B`E<P!.
M;R!A9&1R97-S(&)O;VMS(&9O=6YD+@!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T
M96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RX`3F\@8V]N=&%C=',@9F]U;F0`3F\@8W)E9&ET(&QE9G0N`$YO(&1E
M<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS
M(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I
M9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`
M3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N
M=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@
M=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O
M=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S
M:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I
M;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@
M<V5N="X`3F\@=D-A<F0@9&%T82!W87,@9F]U;F0N`$YO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC
M:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H
M97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A
M>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM
M<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R
M(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(&ET
M96US('!E<B!P86=E`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B
M:F5C=`!/8FIE8W0@0W)E871O<@!/8FIE8W0@;F]T(&9O=6YD`$]C=&%L`$]C
M=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S
M=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;F-E('EO=2!S879E('1H:7,@
M;W!T:6]N('!A9V4L('1H92!A9&1R97-S(&)O;VL@=VEL;"!B92!P97)M86YE
M;G1L>2!D96QE=&5D+B!)9B!T:&ES(&ES(&YO="!W:&%T('EO=2!W86YT+"!T
M:&5N('EO=2!M=7-T(&-H86YG92!Y;W5R('-E;&5C=&EO;B!T;R`B3F]N92(N
M`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N
M;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@
M86QL;W=E9"X`3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D+@!/;FQY('1H92!O
M=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R
M<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN
M(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C
M="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/
M<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N
M:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO
M;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z
M.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y
M<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I
M;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!0
M32!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H
M96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C
M8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N
M9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L
M971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;B!D96YI960`4&5R
M;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@
M26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O
M<P!0:6YE($%D9')E<W,@0F]O:P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E
M<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N
M`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A
M('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L
M(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S
M92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!N86UE('1H92!N97<@8V]N
M=&%C="!L:7-T.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R
M;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W
M;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S
M`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S
M:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN
M;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E
M<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z
M(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0
M<F5V:6]U<P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A
M=&4@061D<F5S<R!";V]K`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$
M97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U
M8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R
M=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=65R>2!F86EL
M960Z("@E<RD@)7,`475I8VL@4V5A<F-H`%%U;W1A`%)302!0=6)L:6,@2V5Y
M("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I
M;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W
M`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!F86EL960Z("@E<RD@
M)7,`4F5A9"!M97-S86=E<P!296%D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I
M;&%B;&4N`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E86QL>2!D96QE=&4@=&AI<R!C;VYT86-T/P!296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C;W)D<R!D:7-P;&%Y960Z`%)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T
M:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S
M`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!2
M96UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!A9&1R97-S(&)O;VL`4F5M;W9E
M(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@9G)O;2!T:&ES(&QI
M<W0`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T
M:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@9&5L971E
M<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO
M<W1R;VYG/@!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z(`!297%U97-T960@;V)J96-T(&YO="!F;W5N9"X`4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-E="!T;R!$969A=6QT<P!297-T;W)E($QA<W0@475E
M<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W
M;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT
M('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T
M92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S
M`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!3+TU)344@4'5B;&EC($-E<G1I9FEC871E`%-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!3
M44P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`
M4U1!4E143%,@9F%I;&5D.B`H)7,I("5S`%-50T-%4U,`4U]13"!3:&5L;`!3
M80!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A
M;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V
M:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E
M($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@(B5S(BX`4V%V:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I
M;&%B;&4N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R
M8V@@16YG:6YE<P!396%R8V@@9F%I;&5D`%-E87)C:"!F86EL960Z("5S`%-E
M87)C:&EN9R!I<R!N;W0@879A:6QA8FQE+@!396%R8VAI;F<N+BX`4V5L96-T
M($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E
M;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E
M<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RX`4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4`4V5L96-T(&%N
M(&%D9')E<W,@8F]O:R!T;R!E9&ET`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T
M(&YO;F4`4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ
M`%-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SH`4V5L96-T
M('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W
M+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T
M97AT(&%R96$N`%-E;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T
M92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H
M92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O
M=7)C92!F:6QE.@!396QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@
M;F%M97,Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('9I
M97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P
M86=I;F<@;W!T:6]N<RX`4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P;&%Y
M(&EN('1H92!A9&1R97-S(&QI<W1S+@!396QE8W0@=VAI8V@@9F]R;6%T('1O
M(&1I<W!L87D@;F%M97,N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396QE8W1E9"!A9&1R97-S
M(&)O;VL@(B5S(BX`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE
M9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`
M4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA
M8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO
M;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T
M92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P
M;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D
M:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@
M<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&%R960@1&ER96-T;W)Y`%-H;W!P
M:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R`E<P!3:&]W($%L;`!3:&]W
M($-O;G1A8W1S`%-H;W<@3&ES=',`4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@
M:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H
M;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``
M4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`
M4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@
M4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3
M:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`
M4V]R="!$:7)E8W1I;VX`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D
M9')E<W,`4V]U<F-E<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E
M<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`
M4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&5C:69Y('=H
M97)E('EO=2!W86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A
M<BX`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3
M<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@
M;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R
M97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C
M<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!A9&1E9"`E9"!C;VYT86-T*',I('1O(&QI
M<W0N`%-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<P!3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@8W)E871E9"!T:&4@8V]N=&%C="!L:7-T("(E<R(N`%-U
M8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!D96QE=&5D
M("5D(&-O;G1A8W0H<RDN`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O
M;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`E9"!C;VYT86-T
M*',I(&9R;VT@;&ES="X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A
M=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL
M>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U
M;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O
M4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`
M4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y
M96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE
M=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA
M;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3
M=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6`%135B!F:6QE`%1A8B!S97!A<F%T
M960@=F%L=65S`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO
M=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R
M("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@
M9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY
M`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N
M9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES
M=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E
M9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0
M(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC
M93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!61E,@8F%C:V5N
M9"!N965D<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT
M('5P;&]A9',N`%1H92!A9&1R97-S(&)O;VL@(B5S(B!D;V5S(&YO="!E>&ES
M="X`5&AE(&%D9')E<W,@8F]O:R`B)7,B('=A<R!C<F5A=&5D('-U8V-E<W-F
M=6QL>2X`5&AE(&%D9')E<W,@8F]O:R`B)7,B('=A<R!R96UO=F5D('-U8V-E
M<W-F=6QL>2X`5&AE(&%D9')E<W,@8F]O:R`B)7,B('=A<R!S=6-C97-S9G5L
M;'D@=7!D871E9"X`5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@8F4@<'5R
M9V5D.B`E<P!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`5&AE(&-O;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="X`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F
M:6QE("(E<R(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@
M8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E
M;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N
M970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E
M;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E
M(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N
M9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@
M:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E
M="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@
M3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E
M9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!I;7!O<G0@8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S
M+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U
M8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A
M<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E
M<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C
M;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE
M<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(
M;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B
M(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D
M('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL
M>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D
M+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N
M`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T
M96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y
M;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E
M96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED
M92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P
M<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@
M;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D
M9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O
M;VMS(&%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N
M=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R!I<R!A;B!E<G)O
M<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`
M5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@
M66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E
M<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N
M97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&9O<B!F=7)T:&5R(&AE;'`N`%1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN
M9R!A(&YE=R!L:7-T+@!4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI
M<R!A9&1R97-S(&)O;VLZ("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R`B)7,B(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O;VLN`%1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S`%1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!L:7-T`%1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE
M87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@861D<F5S
M<R!B;V]K.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E
M;G1R>3H@)7,`5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4
M:&5S92!A9&1R97-S(&)O;VMS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R
M.@!4:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II
M<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH
M='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET
M(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L
M>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN
M('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4
M:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N`%1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I
M<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE
M8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T
M86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O
M9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92X`5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T
M:&4@861D<F5S<R!B;V]K`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@
M>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@
M9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI
M<R!W:6QL(&)E('1H92!D969A=6QT(&%D9')E<W,@8F]O:R!W:&5N(&%D9&EN
M9R!O<B!I;7!O<G1I;F<@8V]N=&%C=',N`%1H:7,@=VEN9&]W(&UU<W0@8F4@
M8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S
M`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO
M;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E
M;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A0
M0RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y
M`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N
M9V$`5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI
M;G5T97,N`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN
M:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K
M97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N
M9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N
M5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S
M=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S
M(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R
M92X@36ES<VEN9R!S;W5R8V4@='EP92X`56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O
M97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D
M($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK
M;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O
M('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E;G0M5'EP
M93H@)7,`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`
M57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N
M86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R
M:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)I<VEG;B!$
M:7)E8W1O<GD`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI
M9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@
M3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`B)7,B`%9I97<@)7,`5FEE
M=R!#;VYT86-T`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E
M<P!6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#H`5FER9VEN($ES;&%N9',L
M($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I
M8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(
M5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E
M8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B
M`%=E8B!3:71E`%=E8G-I=&4@55),`%=E96ML>0!796QC;VUE`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R
M;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K($-I='D`
M5V]R:R!#;W5N=')Y`%=O<FL@4&AO;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K
M(%-T871E+U!R;W9I;F-E`%=O<FL@4W1R965T($%D9')E<W,`5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS
M:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L
M($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T
M<R!I;B`B)7,B+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N
M;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N`%EO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N<R!T;R!D96QE=&4@=&AI<R!S;W5R
M8V4N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A('1A
M<F=E="!A9&1R97-S(&)O;VLN`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!L
M:7-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="X`
M66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R`%EO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@
M8V]N=&%C="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES
M:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N
M9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N`%EO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I
M<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!;;F\@=F%L=65=`%]!9&UI
M;FES=')A=&EO;@!?0G)O=W-E`%]#3$D`7T-O;G1A8W1S`%]$871A5')E90!?
M1&5L971E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E
M<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQI<W1S`%],;V<@:6X`7TQO9R!O
M=70`7TUO9&EF>2!,:6YK+BXN`%]->2!!9&1R97-S($)O;VMS`%].97<@0V]N
M=&%C=`!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]2
M96UO=F4@9G)O;2!T:&ES(&QI<W0`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK
M;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`
M8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A
M9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C;VYT86-T+G9C9@!C;VYT
M86-T<RYC<W8`8V]N=&%C=',N='-V`&-O;G1A8W1S+G9C9@!C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT
M<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I
M871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A
M<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!M;0!N86UE`&YO(&9O<FUA='1I;F<`;F]N90!N;W0@:6UP
M;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`
M<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N
M8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R
M`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T;R!A($-O;G1A8W0@3&ES
M=`!T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VL`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE
M8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!4
M=7)B82`R+C$M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3(T(#$P.C0V
M*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ,R`Q,CHU.2LP,C`P
M"DQA<W0M5')A;G-L871O<CH@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3X*
M3&%N9W5A9V4M5&5A;3H@1FEN;FES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#@M8FET"@`@*"5S('#D:7;DY"!S:71T96XI`"`H4&EK86[D<'#D:6X@)7,I
M`"`H)7,@<.1I=N1S<^0I`"`H=.1NY.1N*0`@*&AU;VUE;FYA*0`@*&5I;&5N
M*0!,:7/DY"!)35-0+6]S;VET96MI<FIA`%!O:7-T82!)35-0+6]S;VET96MI
M<FIA`"``(B5S(B!O;B!J;R!O;&5M87-S82!J82!E:2!T=6]T=2X`(B5S(B!E
M:2!O;&4@:&%K96UI<W1O`"(E<R(@96D@:V5L<&%A('9A;&EN;F%K<VDN`"(E
M<R(@96D@;VQE(&%S96YN971T=2!(;W)D96X@<F5K:7-T97)I<W/D+@`B)7,B
M('!U:61E;B!K=79A86IA82!E:2!L]GET>6YY="X`(B5S(B!L:7/D='1I:6X@
M<GEH;>1JY')J97-T96QMY.1N+@`B)7,B(&QI<^1T=&EI;B!O:6ME=6MS:6EN
M+@`B)7,B(&5I(&MO<&EO:71U(&MO<VMA('-E(&]N(&QI<W1A+@`B)7,B(&5I
M(&QU;W1U.B`E<RX`(B5S(B!E:2!S:6ER<F5T='D@:V]S:V$@<V4@;VX@;&ES
M=&$N`")%='5N:6UI(%-U:W5N:6UI(B`@*&5S:6TN($UA='1I($UE:6OD;.1I
M;F5N*0`B4W5K=6YI;6DL($5T=6YI;6DB("AE<VEM+B!-96EKY&SD:6YE;BP@
M36%T=&DI`"4N,F9-0B!KY'ET971T>2`E+C)F34(@<V%L;&ET=7-T82`H)2XR
M9B4E*0`E9"`E<R!J82`E<P!386QA<V%N87-I('9A;FAE;G1U=2`E9"!PY&EV
MY&X@<.3D<W3D+@`E9"!PY&EVY&X@96YN=7-T=7,`)7,@+2!);&UO:71U<P`E
M<R!3;W)M96YJY&QK:0`E<R!+0@`E<R!9;&SD<&ET;W1O:6UE;G!I=&5E="`M
M(%9A<FUI<W1U<P`E<R!A<V5N;G5S`"5S(&MI<FIA=71U;6EN96X`)7,@:^1Y
M='3V96AD;W0`)7,@;&ESY'1T>2X`)7,@;VX@:F\@;VQE;6%S<V$N`"5S('-U
M=6YT82`E<R`E<P`E<R!T:65D;W-T;VX@='5O;G1I(&]N;FES='5I`"5S(&]N
M('9A;&UI<R!S=6]R:71T86UA86X@>6QLY'!I=&]T;VEM96YP:71E:73D+B!6
M86QI='-E('9A;&EN=&%R=75D=6ES=&$@<W5O<FET971T879A="!T;VEM96YP
M:71E970N`"5S(&]N('!A:V]L;&EN96X`)7,@;6EN=75T=&EA`"5S(&5I(&SV
M>71Y;GET+@`E<R`M("5S("\@)7,`)7,Z;B!O<V]I=&5K:7)J80`E<SIN(&MA
M;&5N=&5R:0`E<SIN(&UU:7-T:6QI<W1A`"5S.FX@=&5H=.1VY&QI<W1A`"5S
M.B`E<P`E<R`Z(%3D;>0@=FEE<W1I(&5I(&]L92!VY&QT=.1MY'1TY"!S:6QT
MY"!LY&AE='3D:N1L=.0L(&IO:V$@;VX@;65R:VET='D@;.1H971TY&KD:W-I
M+B!3=6AT875D=2!V87)A=6MS96QL82!V:65S=&ES<^0@;VQE=FEI;B!L:6YK
M:V5I:&EN(&IA('9A<F\@86YT86UA<W1A(&SD:&5T=.1JY&QL92!M:73DY&X@
M>6MS:6SV:79IY"!T:65T;VIA+@`L('!U=7-K:71T86ES=&$`+"!P=75S:VET
M=&%I<W1A("5S("5S`"P@=F%I:'1E;&5V86$@)7,@+2`E<P`M+2!V86QI='-E
M("TM`#$R+71U;FYI;B!JY')J97-T96QMY``R-"UT=6YN:6X@:N1R:F5S=&5L
M;>0`,C0@='5N=&EA`#Q%9&5L;&EN96X`5&%R=FET86%N('-E;&%I;BP@:F]S
M<V$@;VX@='5K:2!I1G)A;65S('1O:6UI;FYO;&QE`%1I971O:V%N=&%T875S
M=&%JY')J97-T96QMY.0@96D@;VQE(&WDY')I=&5L='D@=.1L;&4@;W-I;VQL
M90!487!A:'1U:2!V86MA=F$@=FER:&4`5FEE<W1I;B!S86QA=6MS965N('1A
M<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XN`$%L;&5K:7)J;VET971U;B!V
M:65S=&EN('1A<FMI<W1U:W-E96X@=&%R=FET86%N(&IU;&MI;F5N(%!'4"UA
M=F%I;BX`4V%L871U;B!V:65S=&EN(&%V86%M:7-E96X@=&%R=FET86%N(&IU
M;&MI;F5N(%!'4"UA=F%I;BP@<V%L86EN96X@4$=0+6%V86EN(&IA('-A;&%S
M86YA=&5K<W1I+@!6:65S=&EN(&%L;&5K:7)J;VET=&%M:7-E:W-I('1A<G9I
M=&%A;B!J=6QK:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'4"UA=F%I;B!J
M82!S86QA<V%N871E:W-T:2X`5FEE<W1I;B!A=F%A;6ES965N('1A<G9I=&%A
M;B!J=6QK:6YE;B!3+TU)344M879A:6XL('-A;&%I;F5N(%,O34E-12UA=F%I
M;B!J82!S86QA<V%N871E:W-T:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A;6ES
M96MS:2!T87)V:71A86X@:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA:6YE
M;B!3+TU)344M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@<V%L
M875K<V5E;B!T87)V:71A86X@:G5L:VEN96X@4TU)344M879A:6XN`$%-(%!I
M;'9IY`!!32!K979Y='3D('-A9&5T=&$`04T@<V%D90!!32!S871E:71A`$%-
M(&QU;6ES871E:71A`$%-+U!-`$%022!)1`!4:65T;VIA(&5D:71O<FES=&$`
M5&EE=&]J82XN+@!H86MU;&]M86MK965N('ELY'!U;VQE;&QA`$%B<RX@86QI
M;@!!8G,N(&ME<VME;&SD`%-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!L=6]D
M82!61E,M:&%K96UI<W1O82X`4VEN=6QL82!E:2!O;&4@;VEK975K<VEA(&QU
M;V1A(%9&4RUT:65D;W-T;V$N`"5S(&OD>71T]B!K:65L;&5T='D`2^1Y='3D
M:N1T=6YN=6MS96X@=&EE9&]T`$OD>71TY&KD='5N;G5K<V5N('-A;&%S86YA
M`$OD>71TY&KD=&EL:2!S=6QJ971T=2X`2VER:F%N<&ET;P!,:7/DY`!,:7/D
MY"!A;&ER>6AMY`!,:7/DY"!A;&EO:6ME=7,`3&ESY.0@=.1HY&XZ`$QI<^3D
M('5U<VD@<GEH;>0`3&ESY.0@=75S:2!O:6ME=7,`3&ESY.0@86QI<GEH;>0@
M<GEH;>3D;B`B)7,B`$QI<^3D(&%L:6]I:V5U9&5T("(E<R(`3&ESY.0@=75S
M:2!KY'ET=.1JY#H`3&ESY.0@;W-O:71E:VER:F$`3&ESY.0@:F$@<&]I<W1A
M($E-4U`M;W-O:71E:VER:F]J80!,:7/DY"!S87)A:V4`3&ESY.0@=&EE9&]S
M=&\`3&ESY.0@=75S:6$@:N1S96YIY`!,:7/DY"!P87)I`$QI<^3D("5S('9A
M;&EK:V\@36]Z:6QL86X@4VED96)A<B!O<VEO;VX`3&ESY.0@:V]H=&5E<V5E
M;@!,:7/DY"!O<V]I=&5K:7)J86%N.@!,:7/DY"!O<V]I=&5K:7)J86%N:3H`
M3&ESY.0@:^1Y='3D:N0`3&ESY'1T:6EN("(E<R(@:N1R:F5S=&5L;>3D;BP@
M;75T=&$@96D@=F]I(&QI<^1TY"!S:7/DY&YK:7)J875T=6UI<W!Y>6YN]FX@
M;&ESY'1I971O:F$Z("5S+@!,:7/D='1I:6X@(B5S(B!JY')J97-T96QMY.1N
M+B!6;VET(&YY="!K:7)J875T=6$@<VESY.1N+@!9:'1E>7-T:65T;VIE;B!L
M:7/DY&UI;F5N(&5I(&]L92!KY'ET971TY'9I<W/D+@!+Y'ET=.1J:65N(&QI
M<^3D;6EN96X@;VX@97-T971T>2X`3W-O:71E`$]S;VET96MI<FIA`$]S;VET
M96MI<FIA;B!S96QA=7,`3W-O:71E:VER:F%T`$]S;VET96MI<FIA;B!M97)K
M:6YTY`!/<V]I=&5K:7)J82!T>6AJ96YN971T:6EN+@!0;VES=&5T=&%V82!O
M<V]I=&5K:7)J82``3W-O:71E:VER:F%A(&5I('9O:71U(&[D>71TY.0Z("5S
M`%9O:2!A<V5T=&%A('1A:2!MY.1R:71E;&SD(&]I:V5U:W-I82!T;VES:6QL
M92!KY'ET=.1J:6QL90!9;&SD<&ET;P!-86EN;VMS970`5&%R:V5M<&D@:&%K
M=0!!9F=A;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!487-A80!487-A
M=7,Z`$MA:6MK:0!+86EK:VD@875T96YT:6MO:61U="!KY'ET=.1JY'0`2V%I
M:VMI(')Y:&WD=`!+86EK:VD@;VEK975D970`2V%I:VEL=&$@;F5L:N1L=.0@
M<VEV=6QT80!386QL:2!M;VYE="!O<V]I='1E970`4V%L;&D@:N1R:F5S=&5T
M>6X@;&ES=&%N('1Y>7!I;B!A<V5T=7,N`$]N(&IO(&]L96UA<W-A`$]N(&IO
M(&]L96UA<W-A`%9A:6AT;V5H=&]I;F5N($E-4U`M<VESY.1N:VER:F%U='5M
M:6YE;@!686EH=&]E:'1O:6YE;B!)35-0+7-A;&%S86YA`%9A:6AT;V5H=&]I
M;F5N($E-4U`M:^1Y='3D:N1T=6YN=7,`5F%I:'1O96AT;VES970@<^1H:_9P
M;W-T:6]S;VET=&5E=`!686EH=&]E:'1O:7-E="!M86QL:70`5F%I:'1O96AT
M;VEN96X@=&5K<W1I.@!9:&1Y<W9A;'1A:6X@4V%M;V$`06YN971T=2!A<G9O
M(&5I(&ME;'!A82X`=&%P86AT=6D@='5N=&5M871O;B!V:7)H92X`06YD;W)R
M80!!;F=O;&$`06YG=6EL;&$`06YO;GEY;6D@<')O>'D`5F%S=&%U<P!!;G1A
M<FMT:7,`06YT:6=U82!J82!"87)B=61A`$]H:F5L;6$`3VAJ96QM86QI<W1A
M`$]H:F5L;6$@;VX@=F%L;6ES+@!,86ET82!KY'ET=/;V;B!K86EK:VD@86QI
M:F%K;VEH:6X`2'EVY&MS>0!!<G9I;VET=2!K;VMO`&AU:'1I:W5U`$%R86)I
M82`H5VEN9&]W<RTQ,C4V*0!086ME=&EN(&MO:V\`4&%K971I;B!N:6UI`$]L
M971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82`E<S\`3VQE=&MO('9A
M<FUA+"!E='3D(&AA;'5A="!P;VES=&%A('9A;&ET=70_`$]L971K;R!V87)M
M82P@971TY"!H86QU870@<&]I<W1A82!S:7/DY&YK:7)J875T=6UI<W!Y>6YN
M]FX@)7,@/P!/;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@(B5S
M(B!J82!K86EK:VD@<V5N(&%L:7)Y:&WD=#\`06=E;G1I:6YA`$%R;65N:6$`
M07)M96YI82`H05)-4T-)22TX*0!486ED90!!<G5B80!.;W5S979A`$%S8V5N
M<VEO;B!S86%R970`07-C:6DM=&%I9&4`07-I86XO5'EY;F5N;65R96X@86QU
M90!+>7-Y('9A<FUI<W1U<R!E;FYE;B!K=6EN('1E:&3DY&X@>6QLY'!I=&]T
M;VEM96YP:71E970N`%1E:'3D=N1S87)A:VME970`67)I=&5T=&EI;B!P;VES
M=&%A(&]L96UA=&]N=&$@<GEH;>3D+@!9<FET971T:6EN('!O:7-T86$@;VQE
M;6%T;VYT82!O:6ME=71T82X`67)I=&5T=&EI;B!M=6]K871A(&]L96UA=&]N
M=&$@;VEK975T=&$N`%ER:71E='1I:6X@;75O:V%T82!O;&5M871O;G1A(&IA
M:V]A+@!,:7/D;>3D<FET>6MS970`96QO:W5U`$%U<W1R86QI80!)=.1V86QT
M80!!=71H7V-Y<G-Q;#H@5&%R=FET=&%V86$@24U!4"UL86%J96YN=7-T82!E
M:2!L]GET>6YY="X`075T:%]C>7)U<SH@5&%U<W1A:N1R:F5S=&5L;>0@96D@
M='5E('1A<G9I='1A=FEA(&]M:6YA:7-U=6MS:6$N`$%U=&A?8WER=7,Z(%1A
M<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?
M9G1P.B!T87)V:71T879A82!&5%`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N
M($ODY&YNY"!02%`@:^1Y='3D96X@+2UE;F%B;&4M9G1P(&%S971U<W1A+@!!
M=71H7VEM87`Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y
M='EN>70N`$%U=&A?:W)B-3H@5&%R=FET=&%V86$@:W)B-2UL86%J96YN=7-T
M82!E:2!L]GET>6YY="X`075T:%]L9&%P.B!KY'ET=.1J:65N(&QI<^3D;6EN
M96X@06-T:79E($1I<F5C=&]R>7EN(&5I(&]L92!T=65T='4`075T:%]L9&%P
M.B!+Y'ET=.1J:65N('!O:7-T86UI96YN($%C=&EV92!$:7)E8W1O<GES=.0@
M96D@;VQE('1U971T=0!!=71H7VQD87`Z(%1A<G9I='1A=F%A($Q$05`M;&%A
M:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?;&1A<#H@16D@=F]I9&$@;&ES
MY'3D(&OD>71TY&KDY"`E<RX@4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L
M:3H@`$%U=&A?;&1A<#H@16D@=F]I9&$@<&]I<W1A82!KY'ET=.1JY.0@)7,`
M075T:%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D("5S`$%U
M=&A?;&1A<#H@2^1Y='3D:FEE;B!PY&EV:71TY&UI;F5N($%C=&EV92!$:7)E
M8W1O<GEY;B!E:2!O;&4@='5E='1U+@!!=71H7VUC86PZ(%1A<G9I='1A=F%A
M($U#04PM;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?<VUB875T:#H@
M5&%R=FET=&%V86$@<VUB875T:"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`
M075T96YT:6MO:6YT:2!)34%0+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`
M075T96YT:6MO:6YT:2!E<.1O;FYI<W1U:0!!=71E;G1I:V]I;G1I(&5PY&]N
M;FES='5I+B`E<P!!=71E;G1I:V]I;G1I(%)!1$E54RUP86QV96QI;65L=&$@
M97#D;VYN:7-T=6DN`$%U=&5N=&EK;VEN=&D@1E10+7!A;'9E;&EM96QL92!E
M<.1O;FYI<W1U:2X`075T96YT:6MO:6YT:2!334(M<&%L=F5L:6UE;&QE(&5P
MY&]N;FES='5I+@!+Y'ET971TY'9I<W/D;VQE=F%T(&ME;G3D=#H`07IE<F)A
M:7ID86X`0D]&2"!S96QI='EK<V5T`%1A=7-T80!4875S=&%VY')I`%;DY'+D
M(&ME<F)E<F]S('-A;&%S86YA+@!6Y.1RY"!K97)B97)O<R!KY'ET=.1JY'1U
M;FYU<RX`0F%H86UA`$)A:')A:6X`0F%L=&EA("A)4T\M.#@U.2TQ,RD`0F%N
M9VQA9&5S:`!"87)B861O<P!'<F%F:6EK;VED96X@<&5R=7-H86ME;6ES=&]A
M("(E<R(@96D@;/9Y='EN>70N`%!E<G5S=FEI=F$`66MS:6YK97)T86EN96X@
M:&%K=0!686QK;RU696[D:N0`0F5L9VEA`$)E;&EZ90!(86MU;&]M86MK965N
M(&%L87!U;VQE;&QA`$)E;FEN`$)E<FUU9&$`0FAU=&%N`%EH9&ES=.1M:6YE
M;B!E<.1O;FYI<W1U:2`H)7,I("5S`%-Y;G1Y;>1PY&EVY`!/<VEO=&$@(B5S
M(B!O:&IE;&UA;&QE("(E<R(@96D@;/9Y='EN>70N`$]S:6]N(&%S971U:W-E
M=`!/<VEO;B!T>7EP<&D`3&EH879O:71U`$)O;&EV:6$`2VER:F%N;65R:VET
M`%)E=6YA`%)E=6YA;B!V86AV=75S.@!2975N870`0F]S;FEA($AE<GIE9V]V
M:6YA`$UO;&5M;6%T`$)O='-W86YA`$%L:6X`0F]U=F5T('-A87)E=`!"<F%S
M:6QI80!"<FET86YN:6%N($EN=&EA;B!V86QT86UE<F5N('1E<G)I=&]R:6\`
M4V5L86$`0G)U;F5I($1A<G5S86QA;0!"=6QG87)I80!086QL=6MK86QI<W1A
M`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$QI:6ME=&]I;6EN;F%N(&QU;VMI='5S
M`$--4P!#4D,`0U),+6IA:V5L=6]S;VET=&5E=`!#4U8`4U]O;'5N('1I961O
M="XN+@!6Y&QI;75I<W1I;B!A;'5S='5S(&5I('9A;&UI<W1U;G5T+@!+86QE
M;G1E<FD`5'EY;FD`2V%M<'5T<V5A`$MA;65R=6X`4V%L87-A;F%A(&5I('9O
M:2!T>6AJ96YTY.0@875T;VUA871T:7-E<W1I+"!O=&$@>6AT97ET=.0@>6QL
MY'!I=.1JY.1N+@!%:2!V;VD@:VER:F]I='1A82!T:65D;W-T;V]N("(E<R(`
M16D@=F]I(&QI<^1TY"!R>6AMY.0@:71S965N<^0N`%5L:V]I<VEA(&ES='5N
M=&]KY'-I='1E;&EJ]FETY"!E:2!O;&4@;6%H9&]L;&ES=&$@:&%L;&ET82X`
M24U!4"UP86QV96QI;65E;B!E:2!S86%T=2!Y:'1E>71TY#H@)7,`16D@=F]I
M(&%V871A('1I961O<W1O82`B)7,B+@!+86YA9&$`4&5R=0!097)U(&]N9V5L
M;6%V:65S=&D`16D@=F]I9&$@<&]I<W1A82!T:65D;W-T;V$@(B5S(BX`5N1L
M:6%I:V%I<VAA:V5M:7-T;V$@96D@;/9Y='EN>70N`$5I('9O:61A(&IA=&MA
M82!I;&UA;B`G=&%R9V5T1FEL92<@+7!A<F%M971R:6$N`$5I('9O:61A('!O
M:7-T86$@:&%K96UI<W1O82`B)7,B+@!%:2!V;VED82!P;VES=&%A+"`E9"!A
M;&ET87-O:F$@;VQE;6%S<V$N`$5I('9O:2!U=61E;&QE96YJY')J97-TY.0L
M(&%N;F5T='5J96X@=&EE='5E:61E;B!MY.1RY"!E:2!V87-T86$@=&%L;&5T
M971T=6IE;B!T:65T=65I9&5N(&WDY'+DY"X`16D@=F]I(&]H:F%T82!V:65S
M=&GD(&%N;F5T='5U;B!N=6UE<F]O;BX`2V%P(%9E<F1E`$MU=F%T96MS=&D`
M4&%L=F5L=6YT87)J;V%J80!+871E9V]R:6%T(&IA(&]T<VEK;W0`0V%Y;6%N
M('-A87)E=`!0=6AE;&EN*$=332D`4V]L=6X@=&EE9&]T`%-O;'5N('3D>71E
M.@!3;VQU;B!T:65D;W0`4V]L=6X@=N1L>7,Z`$UA=&MA<'5H96QI;@!+96QT
M=&D@*$E33RTX.#4Y+3$T*0!+97-K:71E='1Y`$ME<VMI+4%F<FEK86X@=&%S
M879A;'1A`$ME<VMI+45U<F]O<'!A("A)4T\M.#@U.2TR*0!687)M96YT965N
M('1I961O=`!687)M96YT965N(&]M:7-T86IA`%9A<FUE;G1E96X@<&]L:71I
M:6MA=`!4<V%D`$UU=71A`%9A:6AD82!S86QA<V%N87-I`%9O:70@;75U='1A
M82!LY&AE='3D;6ES<^1S:2!SY&AK]G!O<W1E:7-S82!NY&MY=FGD(&YI;6DM
M('1A:2!O<V]I=&5T:65T;VIA+@!386QA<V%N86X@=F%I:'1O(&5I(&]L92!K
MY'ET]G-SY"!N>6MY:7-I;&SD(&%S971U:W-I;&QA+B!/=&$@>6AT97ET=.0@
M>6QLY'!I=.1J:6EN+@!-97)K:VD`5&%R:VES=%]A(&QI;FMK:2XN+@!686QI
M='-E(%]K86EK:VDO96D@;6ETY.1N`$-H:6QE`$MI:6YA`$MI:6YA('EK<VEN
M:V5R=&%I<W1E='1U("A'0C(S,3(I`$MI:6YA('!E<FEN=&5I;F5N("A":6<U
M*0!686QI='-E(&]H:F5L;6$`5F%L:71S92!N:6UI`%9A;&ET<V4@<V%L87-A
M;F$`5F%L:71S92!KY'ET=.1JY'1U;FYU<P!686QI='-E(&]S;VET96MI<FIA
M`%9A;&ET<V4@;W-O:71E:VER:F$Z`%9A;&ET<V4@<.1I=N1MY.1R:65N(&5S
M:71Y<V%S=3H`5F%L:71S92!L:7-T86X@='EY<'!I("AJY')J97-T971Y:6QL
M92!L:7-T;VEL;&4I`%9A;&ET<V4@;6ET:^0@;W-O:71E:VER:F%T(&[D>71E
M=.3D;B!J82!M:7-SY"!JY')J97-T>6MS97-SY#H`5F%L:71S92!M:73D(&]S
M;VET96MI<FIO:F$@:^1Y=&5TY.1N+@!686QI='-E(&UI=&OD('-A<F%K:V5E
M="!NY'ET973DY&X@:F$@;6ES<^0@:N1R:F5S='EK<V5S<^0Z`$IO=6QU<V%A
M<F5T`$QU;VMK86WDY')I='ES=.0@)7,@96D@;/9Y='EN>70N`%-E;&MEY`!0
M;VES=&$@35-/9F9I8V4@=&%G:70`4&]I<W1A(&MY<V5L>0!0;VES=&$@:^1Y
M='3D:N0Z("5S`%!O:7-T82!KY'ET=.1JY`!0;VES=&$@:^1Y='3D:N1N('1I
M961O=`!396QK96YE=N3D(&UY]FCDY&X`3F%P<V%U=&$@:F%T:V%A:W-E<VD`
M0VQI:V%T96QL($A45%`Z;B!K875T=&$`4W5L:F4@:6MK=6YA`%!I;'9IY`!0
M:6QV:6YE;B!A:6MA:7-I;@!0:6QV:6YE;@!+;V]K;W,@*$ME96QI;F<I('-A
M87)E=`!0:65N96YNY"!S:79U=F%L:6MK;P!0:65N96YN971Y="!R975N870`
M2V]L=6UB:6$`5N1R:0!6Y')I=F%L:71S:6X`5N1R:79A;&EN=&$`4V%R86LZ
M`%-A<F%K:V5I9&5N(&%S971U:W-E=`!387)A:VME:61E;B!O='-I:V]T`%-A
M<F%K:V5I=&$L(&IO:71A(&5I('9O:71U(&[D>71TY.0Z`%-A<FIA:W5V870`
M4&EL:W5I;&QA(&5R;W1E='5T(&%R=F]T`%!I;&MU:6QL82!E<F]T971U="!A
M<G9O="`H36EC<F]S;V9T($]U=&QO;VLI`$MO;65N=&\`2V]M96YT;W1U;&MK
M:0!+;VUM96YT=&D`66QE:6YE;B!N:6UI`$MO;6]R:70`67)I='ES`%ER:71Y
M:W-E;B!O<V]I=&4`5&EE=&]K;VYE970`3VQO<W5H9&4`3VQO<W5H=&5E=`!!
M<V5T=6MS:65N(&5R;W0`07-E='5K<V5T(%!$02UL86ET=&5I9&5N+"#D;'EP
M=6AE;&EM:65N(&IA($]U=&QO;VMI;B!S>6YK<F]N;VET:6EN+@!!<V5T=6MS
M:6$@<&ETY.0@<.1I=FET=.3D+@!!<V5T82!A<V5T=6MS970@)7,`5F%H=FES
M=&$@:VER:F]I='1A;6%L;&$@<V%L87-A;F$@=75D97-T86%N`$MO;F=O`$MO
M;F=O;B!D96UO:W)A871T:6YE;B!T87-A=F%L=&$`66AT97ES(&5PY&]N;FES
M='5I+@!9:'1E>7,@97#D;VYN:7-T=6DZ(`!9:'1E>7,@97#D;VYN:7-T=6DZ
M("5S`%EH=&5Y<R!E<.1O;FYI<W1U:0!9:'1E>7,@:G5L:VES=&5N(&%V86EN
M=&5N('!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`66AT97ES(&IU;&MI<W1E
M;B!A=F%I;G1E;B!P86QV96QI;65L;&4@97#D;VYN:7-T=6DN(%9I<FAE.B`E
M<R`H)7,I`%EH=&5Y<R!F='`M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!9
M:'1E>7-T:65T;VIE;B!H86MU`%EH=&5Y<W1I961O=`!9:'1E>7-T:65D;W0@
M;&ES=&%S<V$Z("5S`%EH=&5Y<W1I961O="!L:7/D='1I:6X@;W-O:71E:VER
M:F%A<VDN`%1I:79I<W1E='EN('1I961O<W1O;B!T>7EP<&DZ`"(E<R(Z;B!S
M:7/D;'3V`$IA=&MA`$-O;VL@<V%A<F5T`$5VY'-T90!+;W!I;VD`2V]P:6]I
M;G1I(&5PY&]N;FES='5I.B`E<P!+;W!I;VD@=F%L:6YT80!#;W-T($E$`$-O
M<W1A(%)I8V$`3F]R<W5N;'5U<F%N;FEK:V\`5FEE<W1I;B!01U`M<V%L875S
M=&$@96D@=F]I='4@=&5H9.0Z(`!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T
M86$@4$=0+6%L;&5K:7)J;VET=7-T83H@`%9I97-T:6X@4R]-24U%+7-A;&%U
M<W1A(&5I('9O:71U('1E:&3D+@!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T
M86$@4R]-24U%+6%L;&5K:7)J;VET=7-T82X`16D@=F]I='4@;W1T86$@>6AT
M97ET=.0N("5S`$QD87`M<&%L=F5L:6UE96X@96D@<V%A='4@875T;W)I<V]I
M='5A('EH=&5Y='3D+@!%:2!V;VET=2!T87)K:7-T86$@<V%L9&]A+B`E<P!,
M1$%0+7!A;'9E;&EM965N(&5I('-A871U('EH=&5Y='3D+@!%:2!V;VET=2!O
M='1A82!Y:'1E>71TY"!P86QV96QI;65E;B`B)7,B(&OD>71TY&5N($944#H@
M)7,`16D@=F]I='4@;'5O9&$@:F%K96QU;&ES=&%A+B`E<P!01U`M<V%L871T
M=6$@=&EE=&]A(&5I('9O:71U(&%U:V%I<W1A.B``4R]-24U%+7-A;&%T='5A
M('1I971O82!E:2!V;VET=2!A=6MA:7-T82X`16D@=F]I='4@<&]I<W1A82!Y
M:'1E>7-T:65T;V$N("5S`$5I('9O:71U('!O:7-T86$@:F%K96QU;&ES=&%A
M+B`E<P!%:2!V;VET=2!P;VES=&%A('#D:79I='ES<VMR:7!T:>0@(B5S(BX`
M5FEE<W1I;B!LY&AE='3D:N1N('/D:&OV<&]S=&EO<V]I=&5T=&$@96D@<'ES
M='ET='D@;>3D<FET=&5L96WDY&XN`$5I('9O:71U(&AA:V5A(&MO:V\@;W-O
M:71E:VER:F%A+@!%:2!V;VET=2!H86ME82!K;VMO(&IA:V5L=6QI<W1A82X`
M16D@=F]I='4@:&%K96$@:V]K;R!L:7-T86$@:F%K96QU;&ES=&]I<W1A+@!%
M:2!V;VET=2!L=6ME82!S=')A=&5G:6%A("(E<R(N`$MO;65N=&\@;6MD:7(@
M(B5S(B!E<.1O;FYI<W1U:2X`2G5L:VES=&5N(&%V86EN=&5N('!A;'9E;&EM
M96QT82!E:2!S86%T=2!J=6QK:7-T82!A=F%I;G1A+@!4:65D;W-T;V]N("(E
M<R(@96D@=F]I(&MI<FIO:71T86$N`$5I('9O:71U(&%U:V%I<W1A("5S+@!9
M;&SD<&ET;VUO9'5U;&EN("5S(&%U:V%I<W4@97#D;VYN:7-T=6D`16D@=F]I
M(&%U:V%I<W1A(&AA:V5M:7-T;V$@(B5S(BX`3$1!4"UP86QV96QI;65L=&$@
M96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD+@`E<SKDY"!E:2!V;VET=2!L=6ME
M82X`2^1Y='3D:N1N('-A;&%S86YA82!E:2!V;VET=2!N;VQL871A+B!*;W1K
M=70@=&%R=FET=&%V870@=&EE9&]T(&]V870@=N3D<FEN+B!9<FETY"!U=61E
M<W1A86X@=&%I(&]T82!Y:'1E>71TY"!Y;&SD<&ET;V]N(&IO<R!T87)V:71S
M970@;&ESY.0@87!U82X`16D@=F]I='4@:&%K96$@04-,+71I971O:F$`16D@
M=F]I='4@:&%K96$@;W-O:71E:VER:F%A+B`E<P!%:2!V;VET=2!H86ME82!J
M86ME;'5L:7-T86$N("5S`$5I('9O:71U(&AA:V5A(&IA:V5L=6QI<W1O:F$N
M("5S`$5I('9O:71U(&AA:V5A('1I971O:F$@<&%L=F5L:6UE;B!T;VEM:6YN
M;VES=&$`16D@=F]I='4@<&%L875T=&%A(&%S971U:W-I82X`2V]M96YT;R!R
M;61I<B`B)7,B(&5PY&]N;FES='5I+@!%:2!V;VET=2!T86QL971T86$@)7,@
M87-E='5K<VEA+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU
M=7-K;W!I;W1A+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU
M=7-K;W!I;W1A("5S`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-PY&EV:71Y
M<W-K<FEP=&GD.B`B)7,B+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N
M('9A<FUU=7-K;W!I;W1A("5S+@!!<V5T=7-T:65D;W-T;VX@)7,@=&%L;&5T
M=7,@97#D;VYN:7-T=6DN(%9O:70@:^1Y='3DY"!J;W1A:VEN(&%S971U<W1A
M('1A;&QE='1A86MS97-I(&MO;V1I;B!T86MA:7-I;B`E<R!T86D@=&%I(&MO
M<&EO:61A(&OD<VEN(&%L;&$@;VQE=F%N(&MO;V1I;B!T:65D;W-T;V]N("5S
M+@!,1$%0+7!A;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L;&ES=&$@971S:>0N
M`$MO;65N=&\@=6YL:6YK("(E<R(@97#D;VYN:7-T=6DN`$5I('9O:71U('#D
M:79I='3DY"!Y:'1E>7-T:65T;VIA+B`E<P!%:2!V;VET=2!PY&EV:71TY.0@
M:F%K96QU;&ES=&%A+B`E<P!6:65S=&5JY"!E:2!V;VET=2!P;VES=&%A(&MA
M;G-I;W-T82`B)7,B.B`E<P!-;WII;&QA(%-I9&5B87(@96D@;/9Y='EN>70N
M(%9A<FUI<W1A(&5T=.0@4VED96)A<B!O<VEO(&]N(&%U:VDN`$OD>71TY&KD
M;&QE("(E<R(@96D@=F]I='4@86YT86$@<V5U<F%A=FEA(&]I:V5U<VEA(&MA
M;G-I;V]N("(E<R(Z("5S`$QA<VME='1U('1E:W-T:0!-86$`2W5R<W-I=`!,
M=6\`3'5O(&]S;VET96MI<FIA`$QU;R!U=7-I(&QI;FMK:0!,=6\@=75S:2!Y
M:'1E>7-T:65T;VQI<W1A(&]S;VET96MI<FIA86XZ`$QU;R!U=7-I`%9O:2!L
M=6]D82!U=7-I82!K86YS:6]I=&$`3'5O='4`3VEK975D970@=&5K:6KD;&SD
M`$QU;W1T;VMO<G1I;FYU;65R;P!+<F]A=&EA`$MU=6)A`%3D;>1N:&5T:VEN
M96X@-"!V86EH971T80!4Y&WD;FAE=&MI<V5T(&ES='5N;F]T`$ME;&QO;F%I
M:V$@=.1L;.0@:&5T:V5L;.0`5.1MY&YH971K:6YE;B!54DP@;VX`5.1MY&YH
M971K:7-E="!KY'ET=.1JY'0`5.1MY&YH971K:6YE;B!SY.0`5.1MY&YH971K
M:6YE;B!T:6QA.B``5.1MY&YH971K:6YE;B!T>7EL:0!6;VET(&UU;VMA=&$@
M=&5H=.1V:>0L(&IO=&MA('-U;W)I=&5T86%N(&MU;B!K:7)J875D=71A86X@
M<VESY.1N(&]H:F5L;6%A;B`E<RX`3&5I:VMA80!,96EK:V%A('9A;&ET='4`
M2WEP<F]S`$MY<FEL;&EN96X@*$M/23@M4BD`2WER:6QL:6YE;B`H5VEN9&]W
M<RTQ,C4Q*0!+>7)I;&QI;F5N+U5K<F%I;F$@*$M/23@M52D`5'-E:VEN('1A
M<V%V86QT80!04`!$4TX@*&QI<^1T:65T;V$@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP
M*0!0Y&EV:71TY&EN`$1A=&%4<F5E+7-E;&%I;@!4:65T;VMA;G1A:&%K=0!0
MY&EVY'ES`%#D:7;D;>3D<N0@=F%S=&%A;F]T971T=0!0Y&EVY&WDY'+D;B!V
M86QI;G1A`%#D:7;D`%!O7VES=&$@<V%R86ME`&IO=6QU:W5U`$1E<VEM86%L
M:6YU;65R;W0`4&EE;F5N;N0@<VES96YN>7-TY`!/;&5T=7,`3VQE='5S=N1R
M:0!/;&5T=7-P<F]F:6EL:0!/;&5T=7,@:V]M96YT;W1U;&MK:0!/;&5T=7-J
MY')J97-T>6MS96X@<W5U;G1A.@!-Y.1R:71E;&WD=`!0;VES=&$`4&]I<W1A
M(&]S;VET96MI<FIA`%!O:7-T82!S;VQU`%!O:7-T;VX@=F%R;6ES='5S`%!O
M:7-T82!R>6AMY`!0;VES=&$@;&]K:0!0;VES=&$@;VEK975S`%9O:2!P;VES
M=&%A(&IA('1U:&]T82!P;VES=&5T='5J82!V:65S=&5JY`!6;VET(&UU=71T
M86$@4&]I<W1A('!A:6YI:VME96X@=&]I;6EN=&%A`%!O:7-T82!S;VQU`%!O
M:7-T82!S87)A:V4`4&]I<W1A(&]L96UA<W-A(&]L979A="!V86EH=&]E:'1O
M:6YE;B!M86QL:0!0;VES=&%M:6YE;B!E<.1O;FYI<W1U:3H@*"5S*2`E<P!6
M;VD@<&]I<W1A82!V:65S=&5JY`!0;VES=&$@(B5S(CIN(&]I:V5U:W-I80!/
M;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@(B5S(B!J82!K86EK
M:VD@<V5N(&%L:6]I:V5U9&5T/P!0;VES=&$@<FEV:0!0;VES=&$@=F%L:71T
M=2!P<F]F:6EL:0!6;VD@;'5O9&$@=75S:6$@:V%N<VEO:71A`%!O:7-T82!V
M86QI='1U('-A<F%K90!0;VES=&$@=F%L:71T=2!R:79I`%!O:7-T971T=2!P
MY&EV:71Y<W-K<FEP=&D@(B5S(BX`66AT97ES=&EE=&]J96X@<&]I<W1O(&5I
M(&]L92!KY'ET971TY'9I<W/D+@!0;VES=&%M:6YE;B!E<.1O;FYI<W1U:0!4
M;VEM:71U<V%I:V$`5&%N<VMA`$]S87-T;P!,87-K979A`$]N9V5L;6%N(&MU
M=F%U<P!+=79A=7,`5&%R:V5M;6%T('1I961O="`H;/9Y='EVY'0@;7GV<R!(
M;W)D93IN(&QO:VET:65D;W-T;W-T82DZ`%1A<FME;6UA="!T:65D;W0@;VX@
M=&%L;&5T971T=2!Y;&SD<&ED;VX@:^1S:71E;'3D=N1K<VDN`$ME:&ET>7,`
M2V]S=&5U<W!I<W1E`$5D96QL:7-E;B!T=6YN:6X@:V]S=&5U<W!I<W1E.B``
M2V]S=&5U<W!I<W1E.B``4W5U;G1A('9A<V5M;6%L=&$@;VEK96%L;&4`4W5U
M;G1A(&]I:V5A;'1A('9A<V5M;6%L;&4`2&%K96UI<W1O`$[D:WEMY`!+Y'ET
MY"`R-"UT=6YN:6X@86EK865S:71Y<W3D+@!.Y&MY;>1N(&%S971U:W-E=`!%
M<VET>7-T87!A('EK<VET>6ES:V]H=&%I;F5N(&5N;G5S=&4`17-I='ES=&%P
M82!E;FYU<W1E96QL92`H5$%&*0!%<VET>7-T87!A`%!E<FEL;&5M96YO:6QM
M;VET=7,`1&II8F]U=&D`16D@<V%A('!O:7-T86$`Q&SD(&OD>73D('-U;W)A
M86X@;6%I;G1E;F%N8V4N<&AP.G3D`%9A<FUI<W1A(&%I;F$@:W5N('!O:7-T
M971A86X@;65R:VEN=/9JY"X`2F]S(&5N<VEM;>1I;F5N(')I=FD@<VESY&QT
MY.0@<V%R86MK96ED96X@;W1S:6MO="P@;FEI;B!V86QI='-E.@!$;VUI;FEK
M86%N:6YE;@!$;VUI;FEK86%N:6YE;B!T87-A=F%L=&$`16EK]B!O;&4@:^1Y
M='3D:N1T=6YN=7-T83\@2VER:F%U9'4@:^1Y='3D:N1K<VDN`%1A;&QE;FYA
M`%1A;&QE;FYA("5S`%1A;&QE;FYA(&QU;W1U(&%S971U<R!02%`M<VMR:7!T
M:6[D+@!486QL96YN82!60V%R9`!!;&%S=F5T;W9A;&EK:V\`2'5U;65E=`!3
MY&AK]G!O<W1I;W-O:71E`$5-86EL+71O+5--4R!G871E=V%Y(&%J=7)I+"!N
M:6EL;&4@<&%L=F5L=6YT87)J;V%J:6QL92P@:F]T:V$@=&%R:F]A=F%T('3D
M=.0@<&%L=F5L=6$N`%9)4DA%`$5C=6%D;W(`375O:VMA80!-=6]K:V%A("(E
M<R(`375O:VMA82!O<V]I=&5K:7)J;VIA`$UU;VMK86$@;W-I;W1A`$UU;VMK
M86$@<GEH;>3D`$UU;VMK86$@;VEK975T=&$`375O:VMA82!O:6ME=6MS:6$`
M375O:VMA82`G)7,G.FX@;VEK975K<VEA`$UU;VMK86$@)7,Z;B!M97)K:6YT
MY.0`375O:VMA82!A<V5T=6MS:6$Z`$UU;VMK86$@(B5S(CIN(&]I:V5U:W-I
M80!-=6]K:V%A("5S.FX@;VEK975K<VEA`$MO=6QU='5S`$5G>7!T:0!%;"!3
M86QV861O<@!%;&5M96YT=&DN+BX`16T`4^1H:_9P;W-T:0!3Y&AK]G!O<W1I
M;W-O:71E`%/D:&OV<&]S=&EO<V]I='1E:61E;B!P:73DY"!O;&QA('-A;6%T
M+@!3Y&AK]G!O<W1I('9A<FUI<W1U:W-E;&QA`$5M86EL+71O+5--4R!'871E
M=V%Y`$AY;6GV=`!4>6AJY"!V:65S=&DN`%1Y:&KD('9A<W1A=7,N`%1Y:&KD
M(&AA:W5T97)M:0!386QL:2!K=79I96X@;&%I='1A;6EN96X@:W5V86=A;&QE
M<FEA<W1A('1E:W-T:6X@:F]U:VMO;VXN`$QA:71A('#DY&QL92!O:6ME86X@
M<&%I;FEK:V5E;B!K;VYT96MS=&EM96YU+@!0Y.1T='EM:7-V=6]S:0!3=75R
M96YN82!E9&ET;W)I80!!;FYA(&MY<WEM>7,@:F]K82!K>7-Y=.3D;BP@:F]S
M('-A;&%S86YA<VD@:F]U9'5T86%N(&YO;&QA86UA86X@97-I;65R:VEK<VD@
M)VUI:^0@;VX@;&5M;6EK:VES:2!N:6UI/R<Z`$QA:71A(&MU=F$@55),('3D
M:.1N`$%N;F$@:VER:F%I;65T(&%L;&4Z`$UE<FMI;G3DY"`E<R!PY&EV:71E
M='1I:6XL(&UU='1A('1U;V1U;B!T:65D;W-T;VX@=&%L;&5T=&%M:6YE;B!E
M<.1O;FYI<W1U:3H@)7,`365R:VEN=.0@)7,Z<W3D(&]N('#D:79I=&5T='DN
M`$5K=F%T;W)I86%L:6YE;B!'=6EN96$`17)I=')E80!6:7)H90!487!A:'1U
M:2!V:7)H92!L:7/D='3D97-SY"`E9"!Y:'1E>7-T:65T;V$@;&ES=&%L;&4N
M`%1A<&%H='5I('9I<FAE(&QI<^1T=.1E<W/D("5D("\@)60@>6AT97ES=&EE
M=&]A(&QI<W1A;&QE+@!6:7)H92!PY&EV:71E='3D97-SY"!O<VEO=&$Z("5S
M`%1A<&%H='5I('9I<FAE('!O:7-T971T865S<V$@)60@>6AT97ES=&EE=&]A
M+@!487!A:'1U:2!V:7)H92!P;VES=&5T=&%E<W-A("5D("\@)60@;W-O:71E
M=&EE=&]A+@!6:7)H92!PY&EV:71E='3D97-SY"!S>6YC(&%N8VAO<B`M=&EE
M=&]A.B`E<P!6:7)H92!P;VES=&5T=&%E<W-A('-Y;F,@;&]K:6$Z("5S`%9I
M<FAE(&AA971T865S<V$@<VESY&QT]N0Z("5S+@!487!A:'1U:2!V:7)H92!P
M;VES=&5T=&%E<W-A("5D(&]S;VET971I971O82!L:7-T86QT82X`5&%P86AT
M=6D@=FER:&4@<&]I<W1E='1A97-S82`E9"`O("5D(&]S;VET971I971O82!L
M:7-T86QT82X`5&%P86AT=6D@=FER:&4@:&%E='1A97-S82!O<V]I=&5K:7)J
M87-T83H@)7,`5FER:&4@<.1I=FET971TY&5S<^0@<V%L87-A;F%A.B`E<P!6
M:7)H92!SY&AK]G!O<W1I=FEE<W1I<W/D+@!6:7)H92!K:7)J;VET971T865S
M<V$@(B5S(BX`165S=&D`171I;W!I80!%=&YI;F5N`$5U<F]O<'!A`#$U(&UI
M;G5U=&EN(';D;&5I;@`R(&UI;G5U=&EN(';D;&5I;@`S,"!S96MU;FYI;B!V
MY&QE:6X`-2!M:6YU=71I;B!VY&QE:6X`2F]K86ES96QL82!S:7/DY&YK:7)J
M875T=6UI<V5L;&$`4'5O;&5N('1U;FYI;B!VY&QE:6X`36EN=75T:6X@=N1L
M96EN`$5S:6UE<FMK:6%R=F]T.@!3=6]R:71A`$QA86IE;FYA`$QA86IE;FYA
M('-I=G5V86QI:VMO`$]D;W1E='1I:6X@;65R:VMIY"`G*2<`4V%N82!S96QL
M86ES96YA86X@=&%I(&AA:W5T97)M:2!L86EN875S;65R:V5I<W/D`$QO<'!U
M<.1I=N1MY.1RY`!%:W-P;VYE;G1T:0!6:64`5FEE(&]S;VET96MI<FIA`%9I
M92!V86EN('9A;&ET=70@>6AT97ES=&EE9&]T+@!6:64@<V5U<F%A=F%T(&]S
M;VET96MI<FIA="!K;VMO;F%A;BX`1D<@=N1R:0!!<V5T=7-T:65D;W-T;VIE
M;B!T=6]N=&D@1E10.FQLY`!!<V5T=7-T96X@:&%K=2!E<.1O;FYI<W1U:2X`
M3W-O:71E:VER:F%A;B!E:2!S86%T=2!Y:'1E>71TY#H@)7,`)7,Z;B!L:7/D
M>7,@97#D;VYN:7-T=6D@)7,ZY.1N.B`E<P!,:7-T86X@<V5L875S(&5PY&]N
M;FES='5I+@!(86ME;6ES=&]N('-E;&%U<R!E<.1O;FYI<W1U:0!.:6UE;B!M
M=75T=&%M:6YE;B!E<.1O;FYI<W1U:3H@*"5S*2`E<SL@575S:2!$3B`]("5S
M+"!686YH82!$3B`]("5S+"!*=75R:2`]("5S`%EH=&5Y<R!,1$%0+7!A;'9E
M;&EM965N(&5PY&]N;FES='5I+@!9:'1E>7,@4TU"+7!A;'9E;&EM965N(&5P
MY&]N;FES='5I+@!+;W!I;VEN=&D@(B5S(CIL=.0@97#D;VYN:7-T=6DN`$MO
M<&EO:6YT:2`B)7,B.FQL92!E<.1O;FYI<W1U:2X`575D96X@4T%33"UY:'1E
M>61E;B!L=6]M:6YE;B!E<.1O;FYI<W1U:2X`3&ESY'1TY';D;B!O8FIE:W1I
M;B!H86MU(&5PY&]N;FES='5I.B`E<P!3:6ER=&\@(B5S(CKDY&X@97#D;VYN
M:7-T=6DN`%-I:7)T;R!E<.1O;FYI<W1U:3H@)7,`2&%K=2!O<V]I=&5K:7)J
M87-T82!E<.1O;FYI<W1U:0!(86MU(&5PY&]N;FES='5I(&AA:V5M:7-T;W-T
M83H@)7,`2V%U;FES`$9A;&ML86YD:6X@<V%A<F5T("A-86QV:6YA<RD`1N1R
M('-A87)E=`!686MA=F$@=FER:&4Z`$9A:W-I`$9A:W-I=`!H96QM:6MU=0!4
M=6YT=74@:W5I;@!4=6YT=74@:W5I;CH@`$UU=71A;6EA('-A=&5I=&$`375U
M=&%M:6$@;'5M:7-A=&5I=&$`2V5N='3D;6%T<FEI<VD`1FEG;&5T($-!4%1#
M2$$`1FEG;&5T(&MI<FIA<VEN`$9I9'II`%1I961O<W1O`%1I961O<W1O:F5N
M(&QU:W5MY.1RY#H@)7,@=&EE9&]S=&\`5&EE9&]S=&]J96X@;'5K=6WDY'+D
M.B`E<R!T:65D;W-T;V$`5&EE9&]S=&]J96X@:^1S:71T96QY`%1I961O<W1O
M;B!N:6UI`%1I961O<W1O;B!V86QI;G1A`%1I961O<W1O;B!T=6]N=&D`5&EE
M9&]S=&]J96X@='5O;G1I(&5I(&]L92!KY'ET971TY'9I<W/D+@!4:65D;W-T
M;W0`4W5O9&%T=&EM970`2&%K=0!0Y.1TY`!3=6]M:0!%;G-I;6WD:6YE;B!P
M=6]L:7-K;P!%='5N:6UI`$5N<VEM;>1I;F5N(&YE;&KD;FYE<P!+;W)J86$@
M<W5H9&4`2^3D;F[D('EM<.1R:0!+96QL=79A`%-U;74`2V%N<VEO=&$@)7,@
M96D@;VQE(&]L96UA<W-A+@!+:7)J87-I;65N(';D<FD`4G5O:V$`4V5L86EM
M:6QL92P@:F]T:V$@96EVY'0@='5E(&MU=FEA`$5N;G5S=&4@*%1!1BD`16YN
M=7-T971T879A="!V=6]R;VMA=61E="`H2'5O;6%A=&AA;B!E='3D(&5N;G5S
M='5K<V5S<V$@;VX@=&EE9&]T('-E:^0@<.1I=FES=.0@971TY"#V:7-TY"P@
M:F]T96X@<W5U<FD@;>3D<N0@<.1I=FGD(&%I:&5U='1A82!L:6EA;B!L979E
MY&X@;W-I;VXI`%5N;VAD:71K;R!S86QA<V%N87-I/P!,;VUA:VME970`36EE
M=&5L875S90!-:65T96QA=7-E96X@='EY<'!I`$UI971E;&%U<V5E=`!-:65T
M96QA=7-E970@,@!&;V]R=6UI=`!5=61E;&QE96YO:&IA=6MS970`<&4`2V5H
M>6MS970`4F%N<VMA`%)A;G-K82P@365T<F]P;VQI`$9R965B=7-Y(%523`!2
M86YS:V%N($=U>6%N80!286YS:V%N(%!O;'EN97-I80!286YS:V%N(&5T96SD
M:7-E="!T97)R:71O<FEO=`!,Y&AD90!3=75N;F%S=&$@`%!I9&5M<&D@:W5V
M875S.@!4Y'ES:6MU=0!+;VMO(&YI;6D`1V%B;VX`1V%L;&5R:6$L(&IO<W1A
M(&MU=F$@;W1E=&%A;@!'86QL97)I83H`1V%M8FEA`%1E92`E<R!A<V5T=6MS
M970`1V5N97)O:71U(&MO;V1I`$=E;W)G:6$`4V%K<V$`1VAA;F$`1VEB<F%L
M=&%R`$5T=6YI;6D`66QE:6YE;B!O<V]I=&5K:7)J80!9;&5I<V5T(&%S971U
M:W-E=`!-96YE`$?V9&5L`$=O;V=L92!+87)T870`1V]O9VQE(&AA:W4`2&%R
M;6%A<^1V>0!+<F5I:VMA`$MR96EK:V$@*$E33RTX.#4Y+3<I`$=R]FYL86YT
M:0!'<F5N861A`%)Y:&WD`%)Y:&WD;B!Y;&SD<&ET;P!2>6AM:65N(&YI;65T
M(&5I=N1T('-A82!O;&QA('1Y:&IIY`!'<F]U<%]L9&%P.B!%:2!V;VED82!L
M:7/D=.0@:^1Y='3D:N3D("5S+B!086QV96QI;65N('9I<FAE:6QM;VET=7,@
M;VQI.B``1W)O=7!?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D(&OD>71TY&KD
MY"`E<P!'<F]U<%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D
M("5S`%)Y:&WD=`!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y
M`%9I97)A:6QI:F%N(&]I:V5U9&5T`%9I97)A<VMI<FIA`$=U:6YE80!'=6EN
M96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A('!E;&MU<FEM86ES97-T
M:2!K:65L=.1Y='EY('!O:7-T86UA<W1A(')I=FEN('9I:6UE:7-TY"!S;VQU
M82X`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET>7D@<&]I<W1A
M;6%S=&$@=FEI;65I<W3D('-A<F%K971T82!T875L=6MO<W1A+@!(5$U,07)E
M82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!V:6EM
M96ES=.0@<FEV:>0@=&%U;'5K;W-T82X`2%144"UA=71E;G1I:V]I;G1I82!E
M:2!L]GET>6YY="X`2&%I=&D`2&%S:"UA;&=O<FET;6D`57-V80!/='-A:V4`
M3W1S86ME`$AE87)D(&IA($UC1&]N86QD('-A87)E=`!6;VEM86MA<R!U:VMO
M<VUY<G-K>0!(97!R96$@*$E33RTX.#4Y+3@M22D`2V]R:V5U<P!/:&IE`$%P
M=6$@961I=&]R:6X@:^1Y='3V]FX`3VAJ90!086QL;VYP=6]L:7-K;SH`5.1S
M<^0@;VX@=&EE9&]S=&]N(&%L:W5O<V$Z`$MO<FME80!+;U]T:0!0>6CD(&ES
M='5I;B`H5F%T:6MA86YI;B!K875P=6YK:79A;'1I;RD`2V]T:0!+;W1I;W-O
M:71E`$MO=&EK875P=6YK:0!+;W1I;6%A`$MO=&EH86ME;6ES=&\`4'5H96QI
M;B`H:V]T:2D`4&]S=&EN=6UE<F\@*&MO=&DI`$MO=&ELY.1N:2!T86D@86QU
M90!+871U;W-O:71E("AK;W1I*0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`
M2&]R9&4O2V]L86(Z($5PY&ME;'!O82`E<R!834PM9&%T86$@=FEE<W1I<W/D
M("5S`$AO<F1E+TMO;&%B.B!9:W-I:^3D;B!V:65S=&D@96D@=F%S=&%A(&]B
M:F5K=&EA("5S`$AO<F1E+TMO;&%B.B!9:'3D:^3D;B!O8FIE:W1I82`E<R!E
M:2!L]GET>6YY="!V:65S=&ES=.0@)7,`2&]R9&4O2V]L86(Z(%!O:7-T971T
M:6EN("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F%A=&EO:V]N92!V86%T
M:6D@=&]I;6EA:W-E96X@)V1O;7AM;"<@4$A0+6QA86IE;FYU:W-E;@!(;W)D
M92]+;VQA8CH@16D@=F]I9&$@;'5O9&$@=75T=&$@6$U,+7!U=71A(&]B:F5K
M=&EL;&4@)7,`2&]R9&4O2V]L86(Z($5I('9O:71U('!O:7-T86$@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z($5I('9O:61A(&AA:V5A($U)344@240ZY"!O
M<VEO;&QE('1Y>7!P:>0@)7,`2&]R9&4O2V]L86(Z($5I('9O:2!S>6MR;VYO
M:61A("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2!V;VED82!S>6YK<F]N
M;VED82!J86MO:F$Z("5S`$AO<F1E+TMO;&%B.B!4=6YT96UA=&]N(&IA:V\@
M(B5S(@!686%K87-U;W)A('/DY&YT]@!686%K87-U;W)A('3D>71E`%9A86MA
M<W5O<F$Z`$UI=&5N('1U;&ET('3D;FYE/R`H4F%P;W)T;VD@:VEI=&]S(2D`
M2W5I;FMA(&UO;G1A('-A<F%K971T82!H86QU870@>6AD:7-TY.0_`$ME;G1T
M:65N("AS87)A:VME:61E;BD@;'5K=6WDY'+D+@!+=6EN:V$@;6]N=&$@<FEV
M:>0@:&%L=6%T('EH9&ES=.3D/P!+;W-T975S`$MO<W1E=7,Z(`!(=6UO<FES
M=&ET`%5N:V%R:0!)34%0+7!O<W1I;&%A=&EK;VX@;'5O;G1I(&5PY&]N;FES
M='5I.B`E<P!)34%0+7!O<W1I;&%A=&EK;VX@<&]I<W1O(&5PY&]N;FES='5I
M.B`E<P!)34%0+7!O<W1I;&%A=&EK;VX@:VEI;G1I]FX@;'5O;G1I(&5PY&]N
M;FES='5I.B`E<P!)35-0`$E-4U`M;W-O:71E:VER:F%N(&AA;&QI;G1A`$E0
M+6]S;VET90!)4"UO<V]I=&4@96D@;VQE(&OD>71E='3D=FES<^0N`$E0+6]S
M;VET92!E:2!O;&4@<V%L;&ET=6X@0TE$4BUB;&]K:6X@<VESY&QLY`!)4"US
MY.1N;O9S=/9N(')I:VMO;75S`$Q?86ET82!R:79I(&5N;F5N`$ES;&%N=&D`
M5F%I;B!I:V]N:70`26MO;FET("5S.FQL90!):V]N:70@:F$@=&5K<W1I`%!R
M;V9I:6QI;B!N:6UI.@!*;W,@<VEV=2!E:2!NY'D@:W5N;F]L;&$L(&YI:6X@
M875K86ES92`E<R!E<FEL;&ES97-SY"!I:VMU;F%S<V$N`$IO<R!E="!NY&4@
M:6MO;F5I=&$@:^1Y='3D97-SY'-I($EN=&5R;F5T($5X<&QO<F5R('-E;&%I
M;G1A+"!N:6EN('-I;G5N('!I=.3D(&]T=&%A('!O:7,@<.3D;'3D(%!.1R!L
MY'!I;N1K>79Y>7,@<F%S=&ET=&%M86QL82!TY&WD(&QA871I:VMO+@!*;W,@
M;N1E="!TY&WD;B!V:65S=&EN+"!M=71T82!E="!K=79A82P@;FEI;B!T=6]M
M86%S:2!K=79A82!E:2!V;VD@;N1Y='3DY"!KY'ET=.1MY'-SY'-I('-E;&%I
M;65S<V$N`$MU=FEE;B!E<VEK871S96QU`$MU=F$@55),`$MU=F$@55),.@!+
M=79A(&=A;&QE<FEA<W1A`$MU=F$@9V%L;&5R:6%S=&$Z`$MU=F%N('9I96YT
M:0!+=79A=`!/<V]I=&5K:7)J86X@='5O;G1I+"!A<VME;"`E9`!4=6]N=&DL
M(&%S:V5L("5D`%1U;R]6:64@;W-O:71E:VER:F]J80!4=6]T=2!K96YT=.0Z
M("5S`%1U;V1U="!K96YTY'0Z`$QA7VET82!R:79I(&KD;&ME96X`5N3D<N0@
M=&]I;6EN=&]K;V]D:2!A;FYE='1U+@!+Y'ET=.1JY'1U;FYU<R!T86D@<V%L
M87-A;F$@;VX@=N3D<FEN+@!6Y.1RY"!KY'ET=.1JY'1U;FYU<R!T86D@=F%I
M:'1O96AT;VEN96X@;W-O:71E+B!9<FETY"!U=61E<W1A86X@:F$@;W1A('EH
M=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E="!L:7/DY"!A<'5A+@!,
M:7/DY"!S:7-E;FYY<W3D`$EN=&EA`%EK<VET=.1I<V5T(&OD>71TY&KD=`!)
M;F1O;F5S:6$`26YF;P!);F9O<FUA871I;P!4:65T;V$@96D@;VQE(&5NY.0@
M<V%A=&%V:6QL82X`3&%I=&$@<U]A<F%K92!JY&QK965N`$QA:71A(&MU=F$`
M3&%I=&$@=&%U;'5K:V\`3&%I=&$@=W=W+6QI;FMK:0!,86ET82!?<V%R86ME
M(&5N;F5N`$QA:71A('5U<VD@<V%R86ME(&YY:WEI<V5N(&KD;&ME96X`3&%I
M=&$@=75S:2!S87)A:V4@96YN96X@;GEK>6ES=.0`3&%I=&$@=75S:2!R:79I
M(&YY:WEI<V5N(&KD;&ME96X`3&%I=&$@=75S:2!R:79I(&5N;F5N(&YY:WEI
M<W3D`$QA:71A(&MA<'!A;&4@;GEK>6ES96X@;F]D96X@:N1L:V5E;@!,86ET
M82!K87!P86QE(&5N;F5N(&YY:WEI<W3D(&YO9&5A`$QA:71A('9A:6AT;V5H
M=&]I;F5N(&UA;&QI`$%N;F$@<^1H:_9P;W-T:6]S;VET92!J;VAO;B!U=7-I
M('-A;&%S86YA(&SD:&5T973DY&XZ`$QA:71A('-O;'4@:N1L:V5E;@!,86ET
M82!S;VQU(&5N;F5N`$QA:71A('-O;'4@:N1L:V5E;@!,86ET82!S87)A:V4@
M96YN96X`5F]I(&QA:71T86$@=FEE<W1E:N0`3&%I=&$@:V%P<&%L92!JY&QK
M965N`$QA:71A(&MA<'!A;&4@96YN96X`3&%I=&$@<FEV:2!E;FYE;@!,86ET
M82!R:79I(&KD;&ME96X`06YN82!V86%D:71T879A('9A<W1A=7,@='5R=F%K
M>7-Y;7EK<V5E;CH`3&EI=.0O375O:VMA82!K=79I80!,:6ETY"]-=6]K:V%A
M(&QI;FMK:>0`4VEN=6QL82!E:2!O;&4@=&%R<&5E:W-I(&MR961I:71T96KD
M(&SD:&5T=.3D:W-E<VD@=FEE<W1I;B!J86ME;'5L:7-T86QL92X`4FEI='3D
M;>1T=/9MY'-T:2!K<F5D:6ET=&5JY`!+;VMO;F%I<VQU:W4`2V]K;VYA:7-L
M=6MU;&ES=&$`5FER:&5E;&QI;F5N($E$`$5PY&ME;'!O("!51$@@*%5S97(@
M1&%T82!(96%D97(I+@!%<.1K96QP;V$@6DE0+71I971O82X`17#D:V5L<&\@
M;W-O:71E:VER:F$`17#D:V5L<&\@;VAJ96QM82X`17#D:V5L<&\@8F%T8V@@
M240N`$SD:&5T971T:6EN(&5PY&ME;'!O82!T:65T;V$N`$5PY&ME;'!O('9A
M<W1A86YO='1A:F%N(&]S;VET92X`5FER:&5E;&QI;F5N('/D:&OV<&]S=&EO
M<V]I=&4`5FER:&5E;&QI;F5N(&UE<FMI;G3D`$5PY&ME;'!O('1I961O<W1O
M;75O=&\`3>3D<FET96QT>2!A=F%I;B!O;B!V:7)H965L;&EN96X`17#D:V5L
M<&\@;&ES96YS<VEA=F%I;BX`17#D:V5L<&\@<&%I:VMA=&EE=&\N`$5PY&ME
M;'!O(&US9U]T>7!E("X`5FER:&5E;&QI;F5N(&YI;6D`5FER:&5E;&QI;F5N
M(&]B:F5C=$ED`$5PY&ME;'!O('1A:2!P=75T='5V82!A<&E?:60N`$5PY&ME
M;'!O('1A:2!P=75T='5V82!P87)A;65T<FDN`$5PY&ME;'9O="!O:6ME=61E
M="!Y;&5M;>1L;.0@=&%S;VQL82X`17#D:V5L<&\@<&%R;F5R(&ED+@!%<.1K
M96QP;R!T=6]T96MO;V1I+@!%<.1K96QP;R!P<F]T;VMO;&QA+@!%<.1K96QP
M;R!V87-T86%N;W1T86IA.B`B)7,B`$5PY&ME;'!O(&IA:V\M;V)J96MT:0!%
M<.1K96QP;R!LY&AD96]S;VET92X`17#D:V5L<&]A('5N:6-O9&4M=&EE=&]A
M+@!);G9E;G1A87)I;P!+Y.1N;N0@=F%L:6YT82!KY.1N=&5I<V5K<VD`27)A
M;BP@27-L86UI;&%I;F5N('1A<V%V86QT80!)<F%K`$ER;&%N=&D`36%N+7-A
M87)I`$5R:6QL:7-IY"!5:VMO<VUY<G-K>6KD`$ES<F%E;`!,:6EK:V5E;&QE
M;&%S:VEJ80!+=7)S:79O:71U`$ET86QI80!*86UA:6MA`'1A;6UI:W5U`$IA
M<&%N:0!*87!A;FD@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:6$`:&5I
M;N1K=74`:V5SY&MU=0!+97-K:73D`$ME<VMI=.0@:V5S:V5L;&4`2V5S:VET
MY"!TY'ES:6X`2V5S:VETY"!V87-E;6UA;&QE`$ME<VMI=.0@;VEK96%L;&4`
M2V%Z86MS=&%N`%/D:6QY=.0@86QK=7!E<N1I;F5N/P!+96YI80!!=71E;G1I
M:V]I;G1I(&5PY&]N;FES='5I($ME<F)E<F]S+7!A;'9E;&EM96QL92X`2V5R
M;F5L(&%L;VET=&5L:6IA=`!!=F%I;65N(&QU;VYT:0!!=F%I;65N('1U;FYI
M<W1E`$%V86EM96X@<&ET=75S`$%V86EM96X@='EY<'!I`$%V86EM96X@:^1Y
M='3V`$%V86EN(&]N(&IO(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L
M;&$`3&%P<V5T`$MI<FEB871I`$MO<F5A+"!D96UO:W)A871T:6YE;B!K86YS
M86YT87-A=F%L=&$@*%!O:&IO:7,M2V]R96$I`$MO<F5A+"!T87-A=F%L=&$@
M*$5T96SD+4MO<F5A*0!+;W)E82`H155#+4M2*0!+=7=A:70`2VER9VES=&%N
M`$Q$05`M='5K:2!O;B!P86MO;&QI;F5N+"!M=71T82!,1$%0+6UO9'5U;&D@
M96D@;VQE(&OD>71E='3D=FES<^0@=&%I(&QA9&%T='4N`$%S7V5T=&5L=0!+
M:65L:0!,86]S+"!D96UO:W)A871T:6YE;B!K86YS86YT87-A=F%L=&$`2N1L
M:VEM;>1I;F5N('!U;VQI<VMO`$UU;VMA='1U('9I:6UE:W-I`%-U:W5N:6UI
M`$5D96QL:6YE;B!S86QA<V%N86YV86EH=&\`2N1L:VEM;>1I;F5N(&YE;&KD
M;FYE<P!0Y&EV:71E='1Y('9I:6UE:W-I.@!%9&5L;&EN96X@<VESY.1N:VER
M:F%U='5M:6YE;CH@)7,`161E;&QI;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ
M("5S+"`E<P!%9&5L;&EN96X@<VESY.1N:VER:F%U='5M:6YE;CH@16D@;6EL
M;&]I;FMA86X`3&%T=FEA`$QA:VD`07-E='1E;'4`2N1TY"!T>6AJY&MS:2!J
M;W,@96D@<F5U;F]J80!,:6)A;F]N`%9A<V5N`%9A<V5N(&]T<V%K90!687-E
M;B!A<G9O=`!,97-O=&\`5&%S;P!,:6)E<FEA`$QI8GEA($%R86(@2F%M86AI
M<FEY80!,:6-H=&5N<W1A:6X`2V5V>71TY"!RY&YTY.0`2VER:F%U9'4@<VES
MY.1N`$ME=GET=.0@<V%D971T82!A:6MA:7-I;@!+979Y='3D('-A9&5T=&$@
M;7GV:&5M;6EN`$ME=GEI=.0@<V%D96MU=7)O:F$`2V5V>71TY"!S861E='1A
M(&IA(&UY<G-K>6ES=.0`2V5V>71TY"!L=6UI<V%D971T80!+979Y:73D(&QU
M;6EK=75R;VIA`$QI;65R:6MI=`!,:6YK:VD`3&EN:VMI(&]S;VET=&%A.@!,
M:6YK:73D('/D:&OV<&]S=&EO<V]I=&4@:VER:F]I=&$@=75S:2!V:65S=&D@
M<VEV=6QL92!NY&MY;>1S<^0`3&EN:VET`$QI;G5X('!I<&%R96ET80!,:7-T
M80!6;VD@;&ES=&%U:W-E<W-A(&[D:&3D(&MA;G-I;VX`3N1Y=.0@=&EE=&]K
M86YN870`3N1Y=.0@;VAJ96ED96X@86EH965T`$[D>73D('1A=6QU=`!,:7-T
M86XM07)K:7-T;P!,:7-T86XM3VAJ90!,:7-T86XM260`3&ES=&%N+4]M:7-T
M86IA`$QI<W1A+79I97-T:0!,:7-T86XM5&EL875S`$QI<W1A;BU4:6QA=6MS
M96XM;&]P971T86UI;F5N`$ES='5N=&]J96X@;&ES=&%U<R!E<.1O;FYI<W1U
M:3H@)7,`2^1Y='3D:FEE;B!L:7-T875S(&5PY&]N;FES='5I.B`E<P!+Y'ET
M=.1JY'1I971O:F5N(&[D>71TY&UI;F5N(&]N(&5S=&5T='DN`$MI<FIA;&QI
M<W5U<P!,:65T='5A`$QA9&%T86%N+BXN`%!A:6MA;&QI<W1A(&%I:V%A.B``
M3&]K86QI<V%A=&EO(&IA(&%I:V$`4&%I:VMA`$MI<FIA=61U('-I<^3D;@!%
M9&5L;&ES96X@<WEN:W)O;F]I;G1I<V5S<VEO;B!L;VMI`$MI<FIA=61U('5L
M;W,`2VER:F%U9'4@<VESY.1N`%1E:'3D=N1T('-I<^3D;FMI<FIA=71U;6ES
M97-S80!3:7/DY&YK:7)J875T=6UI<V5S:2!E<.1O;FYI<W1U:2X@5&]D96YN
MY&OV:7-E<W1I(&MI<FIO:71I="!VY.1R:6X@:^1Y='3D:N1T=6YN=6MS97-I
M('1A:2!S86QA<V%N87-I+@!3:7/DY&YK:7)J875T=6UI;F5N(&5PY&]N;FES
M='5I+@!0:71KY"!T96MS=&D`4F%K:V%U<P!-871A;&$`4&EE;F5T(&MR96EK
M:V%L86ES970@:VER:F%I;65T`%!I96YE="!L871I;F%L86ES970@:VER:F%I
M;65T`%!I96YE="!R;V]M86QA:7-E="!N=6UE<F]T`$QU>&5M8G5R9P!+2P!-
M3U1$`$U3+51.148@;&EI=&5T:65D;W-T;R!O;&D@='EH:N0N`%9)15-420!-
M86-A;P!-86ME9&]N:6$L($5N=&EN96X@2G5G;W-L879I86X@=&%S879A;&QA
M;BX`36%D86=A<VMA<@!486EK=75S`%/D:&OV<&]S=&D`4&]S=&EN('EL;.1P
M:71O`%1E92!L:6YK7VMI+BXN`$UA;&%W:0!-86QE<VEA`$UA;&5D:6EV:70`
M4&]S=&D`36%L=&$`5F]I="!H86QL:6YN;VED82!L:7-T86$@:V%T96=O<FEO
M:7-T82P@:F]I9&5N(&%V=6QL82!V;VET(&QI:71TY.0@87-I;VET82!Y:'1E
M96X@<V%M;VIE;B!O='-A:VME:61E;B!A;&QE(&IA(&QI:71TY.0@;FEI:&EN
M(';D<F5JY"X`36%P,C0@:V%R='1A`$UA<%%U97-T(&MA<G1T80!687-T86%V
M=75D970@=&%L;&5T971T=2X`;6%A;&ES:W5U`$UA<F=I;F%A;&D`5F]I(&UE
M<FMI=.0@5F%N:&$O575S:2!T:65T;VIA`%9O:2!M97)K:73D('9I97-T96KD
M("AE<VEM+B!4Y')K9>0O5F%S=&%T='4I`$UA<G-H86QL('-A87)E=`!-87)T
M:6YI<75E`$]N`%3D<VWDY';D="!K96YTY'0`36%U<FET86YI80!-875R:71I
M=7,`4W5U<FEN('-A;&QI='1Y(&MR961I:71T:2X`4W5U<FEN('-A;&QI='1U
M('9I97-T:6]S:6]MY.1RY"!Y;&ET971T>2X`161E;&QI<V5N(#(T('1U;FYI
M;B!K;W)K96EN(&SD;7#V=&EL83H@`$5D96QL:7-E;B`V('1U;FYI;B!K;W)K
M96EN(&SD;7#V=&EL83H@`%EH=&5Y<W1I971O:F5N(&5N:6UMY&ES;>3D<N0`
M4&]R=&%A;&EO<VEO:61E;B!E;FEM;>1I<VWDY'+D`%-U=7)I;B!S86QL:71T
M=2!P:71U=7,`4W5U<FEN('-A;&QI='1U(&WDY'+D('-I=G5J82X`=&]U:V]K
M=74`36%Y;VYE='1E`$SDY&ME=&EE9&4`2N1S96YE=`!686QI:VMO;&ES=&$`
M365N=6X@;75O=&\Z`%EH9&ES=.0@<V]L=70`5FEE<W1I`%9I97-T:6X@=&%R
M:VES='5S(&]N;FES='5I+"!M=71T82!A;&QE:VER:F]I='1A:F%N('9A<FUE
M;FYE='1A(&5I('9O:71U('1A<FMI<W1A82X`5FEE<W1I('9A;FAE;FDN`%9I
M97-T:6X@='EY<'!I`$UE=&%R('/DY`!-971A<BUO<VEO(&5I(&]L92!KY'ET
M971TY'9I<W/D+@!-971A<BUO<VEO(&5I(&]L92!KY'ET971TY'9I<W/D+B!4
M87)K96UM870@=&EE9&]T(&]N('1A;&QE=&5T='4@>6QLY'!I9&]N(&OD<VET
M96QTY';D:W-I+@!-971A<D1"(&5I(&]L92!Y:&1I<W1E='1Y+@!-971O9&D`
M365T;V1I82`B)7,B(&5I(&]L92!MY.1R:71E;'1Y`$UE=&]D:6$@96D@;VQE
M(&WDY')I=&5L='DN($MU='-U=F$@;65T;V1I.B`E<P!-971R:6YE;@!-96MS
M:6MO`$UI:W)O;F5S:6$L(%EH9&ES='EN965T('9A;'1I;W0`2V5S:V5L;.0`
M36EM92UT>7EP<&D`161E;&QI<V5N(#(T('1U;FYI;B!M871A;&EN(&SD;7#V
M=&EL83H@`$5D96QL:7-E;B`V('1U;FYI;B!M871A;&EN(&SD;7#V=&EL83H@
M`%-A;&%S86YA(&5I(&]L92!V:65LY"!T87)P965K<VD@=F%N:&$`4&5I;&EK
M=79A`%-E:V%L86ES970`1$X@<'5U='1U=2!,1$%0(&SD:&1E;>3D<FET=&5L
M>6ES=.0N`%!%05(M<&%K971T:2!(5%107U)E<75E<W0@<'5U='1U=2X`4'5U
M='1U=F%T(&%S971U<W1I961O<W1O+B!3:6YU;B!P:73DY"!T96ADY"!A<V5T
M=7-T:65D;W-T;R!J;W,@:&%L=6%T(&OD>71TY.0@=.1TY"!O:&IE;&UA82X`
M4'5U='1U=F$@;65S<V%G92!)1"X`5N1L='3D;>1T]FX@4$5!4BUP86ME='1I
M($UA:6P@<'5U='1U=2X`4'5U='1U=F$@<V5S<VEO;B!)1"X`;6$`36]B:6EL
M:7/D:&OV<&]S=&D`36%T:V%P=6AE;&EN`$MO:'1A;&%I;F5N`$UU;VMK875K
M<V5N('#D:7;D;>3D<N0`375O:VMA82!54DPZ:6$`375O:VMA=7,@97#D;VYN
M:7-T=6DZ("@E<RD@)7,`2V5R<F]I;@!-;VQD;W9A+"!T87-A=F%L=&$`36]N
M86-O`$UO;F=O;&EA`&MU=6MA=7-I(&IA('9U;W-I`$MU=6MA=7-I='1A:6X`
M36]N='-E<G)A=`!+=75N('9A:6AE970`4FEV:6QTY"`E9"!L]GET>6D@96YE
M;6WD;B!K96YT=&GD(&MU:6X@;V1O=&5T='4@)60N`$SV>71Y:2!U<V5A;7!I
M(&MU:6X@,2!M97)K:6YTY.0`36%R;VMK;P!%;FEM;>1K<VD@<V5L:V7DY`!%
M;FEM;>1K<VD@<&EL=FES=.0`16YI;6WD:W-E96X@<&EL=FES=.0@:F$@='5U
M;&ES=&$`16YI;6WD:W-E96X@875R:6YK;VES=&$`4VEI<G+D`%-I:7)RY"!A
M;&%S<.1I;@!3:6ER<N0@=F%S96UM86QL90!3:6ER<N0@;VEK96%L;&4`4VEI
M<G+D('EL]G-PY&EN`%-I:7)RY"!A;&%S<.1I;@!3:6ER<N0@=F%S96UM86QL
M90!3:6ER<N0@;VEK96%L;&4`4VEI<G+D('EL]G-PY&EN`$UO<V%M8FEK`$UU
M;&)E<G)Y+6]S;VET96MI<FIA`$UO;FET87-O:6YE;B!A;&%S=F5T;W9A;&EK
M:V\`375L=&EM87`@27-O+4)R:71A;FYI86X@:V%R='1A`$]S;VET96MI<FIA
M<W-A(&]L:2!M;VYT82!H96YK:6SVY"!O<V]I='1E96QL82!;)7-=+"!M=71T
M82!E:2!K973DY&X@;FEM96QLY"!;)7-=+@!-;VYI=F%L:6YT80!+Y'ET=.1J
MY'1U;FYU:W-E;FD`3VUA;B!KY'ET=.1JY'1U;FYU:W-E;B!T:65D;W0`3VUA
M(&]S;VET96MI<FIA`$]M870@;W-O:71E:VER:F%T`$]M82!P;W)T86%L:0!/
M;6%N('!O<G1A86QI;B!A<V5T=&5L=0!->6%N;6%R("A"=7)M82D`14DL($5.
M('-U;W-T=0!.:6UI`$YI;65N(&UU;W1O`$YA;6EB:6$`3F%U<G4`3F5P86P`
M3F5T8V5N=&5R(&KD<V5N:&%K96UI<W1O`$%L86YK;VUA870`06QA;FMO;6%I
M9&5N($%N=&EL;&ET`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E
M=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@
M4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M4U-,+7!A;'9E;&EM96X@;W-O:71E`$YE='-C87!E('9A<FUE;G1E96X@:V]M
M;65N='1I`$YE='-C87!E('9A<FUE;G1E96X@='EY<'!I`%9E<FMK;P!%:2!K
M;W-K86%N`%5U<VDM2V%L961O;FEA`%5U<VD@;'5O:VET=7,`575S:2!Y:'1E
M>7-T:65T;P!5=7-I:W5U`%5U<VD@:^1Y='3D:N1T=6YN=7,@*'9A<&%A96AT
M;VEN96XI`%5U<VDM4V5E;&%N=&D`575S:2!S86QA<V%N80!5=7-I('-A;&%S
M86YA('9A;FAE;F5E("5X+@!!;G1A;6%S:2!U=61E="!S86QA<V%N870@96EV
MY'0@=.1S;>3D+@!5=7-I(&EK:W5N82`H7V)L86YK*0!5=71I<V5T`$ME<VMU
M<W1E;'5R>6AMY'0`4V5U<F%A=F$`4V5U<F%A=F%T(#0@=F%I:&5T=&$`4V5U
M<F%A=F%T(&%S971U:W-E=`!3975R86%V83X`3FEC87)A9W5A`$QE;7!I;FEM
M:0!.:6=E<@!.:6=E<FEA`%GV`$YI=64`16D`365R:VEN=.3D("5S(&5I(&SV
M>71Y;GET("5S.FQL90!%:2!L]GET>6YY="!A:6YU='1A:V%A;B!O<V]I=&5K
M:7)J86$N`$%S971U<W1I971O:F$@96D@;VQE('-A871A=FEL;&$L(&IO<W1A
M('9O:7-I(&[D>71TY.0@97)O879A:7-U=6MS:6$N`$5I(&]L92!S86%T879I
M;&QA('-U=6YN:71E;&UA82!)4T\@;&5V>6MU=F%T:65D;W-T;VIE;B!T96ME
M;6ES96MS:2X`16D@97+D;6%L;&EA+@!/<VEO=&$@96D@;VQE('!Y>61E='ES
M<^0@<&%I:V%S<V$N`$MA;&5N=&5R:6X@;FEM9>0@96D@;VQE(&%N;F5T='4@
M34-!3"UA=71E;G1I:V]I;FYI;&QE+@!%:2!M=75T;W-T82X`06QI=&%S;VIA
M(&5I('9O:2!L:7/D=.0@=.1L;&4@;VEK975D96QL92X`07-E='5K<VEA(&5I
M(&SV>71Y;GET("5S.FQL92X`07-E='5K<VEA(&5I(&SV>71Y;GET($944"!6
M1E,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@4U%,(%9&4SIL;&4N`$%S
M971U:W-I82!E:2!L]GET>6YY="!344PM1FEL92!61E,Z;&QE+@!%:2!L]GET
M>6YY="!Y:'1E>7-T:65T;VIA`$MR961I:71I="!L;W!P=2X`2V]H9&5T=&$@
M96D@86YN971T=2X`16D@='5O='4@86EN=71T86MA86X@=&EE9&]S=&]A`$EK
M;VYE:71A(&5I(&SV>71Y;GET+@!086EK:V%A(&5I(&]L92!A<V5T971T=2X`
M4&%I:VMA82!E:2!O;&4@86YN971T=2X`16D@86YN971T=2!V:65S=&GD+@!.
M:6UEY"!E:2!O;&QU="!A;FYE='1U+@!,=6MU;>3D<N3D(&5I(&]L;'5T(&%N
M;F5T='4N`$5I(&QO=6MK86%V870@;6EE=&5L875S965T`%-A;&%S86YA82!E
M:2!O;&4@86YN971T=2!(5%10+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA
M82!E:2!O;&4@86YN971T=2!)34%0+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S
M86YA82!E:2!O;&4@86YN971T=2!+97)B97)O<RUA=71E;G1I:V]I;FYI<W-A
M+@!386QA<V%N86$@96D@;VQE(&%N;F5T='4@3&]G:6X@875T96YT:6MO:6YN
M:7-S82X`4V%L87-A;F%A(&5I(&]L92!A;FYE='1U(%!!4U-71"UA=71E;G1I
M:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE(&%N;F5T='4@4TU"+6%U=&5N
M=&EK;VEN;FES<V$N`%!O;&MU82!/<&5N4U-,(&MO;65N=&]O;B!E:2!O;&4@
M;>3D<FET96QT>2X@3W!E;E-33"!P:73DY"!O;&QA(&OD>71E='3D=FES<^0@
M:F]S(&OD<VET96QLY.1N(%!+0U,@,3(@9&%T86$N`$5I('-I<^3D;FMI<FIA
M=71U;6ES<'EY;G3V:N0@:F]N;W-S82X`2VEI;G1I]G3D(&5I(&]L92!A<V5T
M971T=0!%:2!SY.1N=/9JY`!%<F]T:6YT82!E:2!O;&4@;>3D<FET96QT>2X`
M16D@<F5U;F]J80!%:2!L]GET>6YY="!T:65D;W-T;V$`5N1L:6UU:7-T:6QL
M92!E:2!O;&4@=N1L:6%I:V%I<VAA:V5M:7-T;V$N`$OD>71TY&KD='5N;G5S
M=&$@=&%I('-A;&%S86YA82!E:2!LY&AE=&5T='DN`'9#87)D('1I971O:F$@
M96D@;/9Y='EN>70N`$MA:6MK:2!P86QA=71U;G5T(%A-3"UD871A(&]L:2!E
M<.1K96QP;V$`16D@87)V;VIA`%9E<G-I;W1I971O:F$@96D@;/9Y='EN>70@
M86QK=7!E<N1I<VETY"!A<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@
M87-E='5K<V5T('5U9&5S=&%A;BX`5F5R<VEO=&EE=&]J82!E:2!L]GET>6YY
M="!A<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5K<V5T('5U
M9&5S=&%A;BX`16D@;6ETY.1N`$5I(&UI=.3D;B`H2^1Y=.0@:6UP;&ES:6ET
M=&ES=.0I`$QA<'!I+U!O:&IO:7-M86%T+T5S:VEM;R`H25-/+3@X-3DM,3`I
M`$YO<F9O;&L@<V%A<F5T`%!O:&IO:6YE;B!P86QL;VYP=6]L:7-K;P!0;VAJ
M;VES970@36%R:6%A;FEE;B!S86%R970`3F]R:F$`16D@:N1L:V5E;@!%:2!E
M;FYE;@!%:2!O;&4@:&%K96UI<W1O`$5I(&]L92!T;W1E=71E='1U+@!%:2!A
M<V5T971T=0!%:2!T=65T='4N`$UU:7-T:6EN<&%N;W0`16D@;6ETY.1N('-E
M;&%T=&%V86$L('!A;&%A('1A:V%I<VEN+@!M87)R87-K=74`3'5K=6WDY'+D
M`$UE<FMK:65N(&QU:W5MY.1RY`!387)A:VME:61E;B!L=6MU;>3D<N0`5&EE
M=&]J82!L=6MU;>3D<N0@<VEV=6QL80!2:79I96X@;'5K=6WDY'+D`$IA:V5L
M=6QI<W1A;B!N=6UE<F]I=&$@96D@;VQE(&WDY')I=&5L='D@<.1I=FET971T
MY';D:W-I+@!/2P!/8FIE:W1I`$]B:F5K=&EN(&QU;VIA`$]B:F5K=&EA(&5I
M(&SV>71Y;GET`$]K=&%A;&D`;&]K86MU=0!,;W5K:V%A=G5U<W-U;V1A=&EN
M`%1O:6UI<W1O`%5U<VD@<V%L87-A;F$@96D@<V%A(&]L;&$@<V%M82!K=6EN
M(&YY:WEI;F5N('-A;&%S86YA<VDN`%9A;FAA('-A;&%S86YA`%9A;FAA('-A
M;&%S86YA(&]N(';DY')I;BX`3VUA;@!+=6X@=&%L;&5T870@=.1MY&X@87-E
M='5S<VEV=6XL(&YI:6X@;W-O:71E:VER:F%S:2!P;VES='5U(&QO<'5L;&ES
M97-T:2X@2F]S(&5T(&AA;'5A('!O:7-T86$@;W-O:71E:VER:F%A<VDL(&YI
M:6X@<VEN=6X@<&ETY.0@;75U='1A82!V86QI;FYA:W-I(")%:2!M:73DY&XB
M+@!686EN($E-05`M<&%L=F5L:6UE="!T=6ME=F%T(&IA971T=6IA(&MA;G-I
M;VET82X`5F%I;B!L;W5K:V%A=F%T(&UI971E;&%U<V5E=`!6;VET(&QA:71T
M86$@=F%I;B!Y:&1E;B!SY&AK]G!O<W1I;W-O:71T965N+@!4=65T='5N82!V
M86EN('EK<VD@=F-A<F0N`%9A:6X@;VUI<W1A:F$@=&%I(&KD<FIE<W1E;&WD
M;B!Y;&SD<&ETY&KD('9O:2!M=75T=&%A(&IA:V]J96X@;VUI<W1A:FEA('1A
M:2!O:6ME=6MS:6$`079A82!U=61E<W-A(&EK:W5N87-S80!/<&5N4U-,('9I
M<FAE.B!4:65T;VIA(&5I('-A871U(&5S:6QL92!A;&QE:VER:F]I=&5T=7-T
M82!3+TU)344M;W-A<W1A+@!!=F%A('3D;>1N(&QI;FMI;B!U=61E<W-A(&EK
M:W5N87-S80!+Y'ET=/9JY')J97-T96QMY`!!<V5T=6MS970`07-E='5K<V5T
M("5S.FQL90!*Y')J97-T971T>2!L:7-T80!/<F=A;FES86%T:6\`3W)G86YI
M<V%A=&EO>6MS:6MK]@!/<F=A;FES;VEN=&D`06QK=7!E<N1I;F5N(&]H:F5L
M;6%N(&UA;&QI`$%L:W5P97+D:7-E="!M86QL:70@)7,Z<W/D.@!-=74`375U
M="!T:65D;W0`375U="!A<V5T=6MS970`3VUI<W1A:F%N(&]I:V5U9&5T`%!!
M32UA=71E;G1I:V]I;G1I82!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`4$5!4CHZ
M36%I;"!T875S=&%JY')J97-T96QMY`!$:6=I=&%A;&EN96X@4$=0+6%L;&5K
M:7)J;VET=7,`4$=0+7-A;&%T='5A('1I971O80!*=6QK:6YE;B!01U`M879A
M:6X`4$=0+6%L;&5K:7)J;VET971T=6$@:F$@<V%L871T=6$@=&EE=&]A`%!(
M4"UK;V]D:0!02%`M:V]M96YT;W1U;&MK:0!032!K979Y='3D('-A9&5T=&$`
M4$T@<V%D90!032!K=75R;VIA`%!-(&QU;6D`4$T@;'5M:7-A=&5I=&$`4$T@
M;'5M:0!032!U:VMO<VUY<G-K>6KD`%!/4TE8+6QA86IE;FYU:W-E="!P=75T
M='5V870`4%](4"UK;VUE;G1O='5L:VMI`%3D>71E`%!A:VES=&%N`%!A;&%U
M`%!A;&5S=&EI;F$@*&UI96AI=&5T='D@86QU92D`4&%N86UA`%!A<'5A(%5U
M<VDM1W5I;F5A`%!A<F%G=6%Y`$]S:71T86EN('!I;'9I<W3D`%-A;&%S86YA
M`%-A;&%S86YA;B!V86EH=&\@;VYN:7-T=6DN`%;DY'+D('-A;&%S86YA`%-A
M;&%S86YA82!T87)V:71A86X@4D%$2553+6%U=&5N=&EK;VEN=&EI;BX`4V%L
M87-A;F$@=F%R;6ES='5K<V5L;&$`4V%L87-A;F$Z`%-A;&%S86YA.B``4V%L
M87-A;F]J96X@<&ETY.0@;VQL82!S86UA="X`3&EI=.0`3&EI=.0@;&5I:V5P
M]GEDY&QTY`!0;VQK=0!*;VYO<W-A(&]L979A="!S:7/DY&YK:7)J875T=6UI
M<W!Y>6YN]G0Z`$EH;6ES970`4')O<V5N='1I`%-U;W)I=&$@>6QLY'!I=&]T
M;VEM96YP:71E970`4W5O<FET82!Y;&SD<&ET;W1O:6UE;G!I=&5E="!S:7/D
MY&YK:7)J875T=6UI<V5N('EH=&5Y9&5S<^0N`$]I:V5U<P!/:6ME=71T82`B
M)7,B(&5I('!O:7-T971T=2X`2^1Y='3V(&MI96QL971T>0!+Y'ET=/8@:VEE
M;&QE='1Y`$]I:V5U9&5T`$]I:V5U:W-I96X@>6QLY'!I=&\`3VUA="!T:65D
M;W0`4&5R=0!,96UM:6MI=`!&:6QI<'!I:6YI=`!0=6AE;&EN`%9A;&]K=79A
M=`!0:6YE+6]S;VET96MI<FIA`%!I=&-A:7)N`%!I:W-E;&D`2VQI<V5E=`!.
M87!S875T82!J;W1A:6X@<V]L=6$`5F%R;6ES=&$@971TY"!H86QU870@<&]I
M<W1A82!TY&WD;B!E;&5M96YT:6XZ`%9A<FUI<W1A(&5T=.0@:&%L=6%T('!O
M:7-T86$@;&EN:VET>6MS96X@=.1HY&X@96QE;65N='1I:6XN`$%N;F$@:W5U
M:V%U<VD@:F$@=G5O<VDN`$%N;F$@;FEM:2!U=61E;&QE(&QU;VMI='5K<V5L
M;&4Z`$%N;F$@;VEK96$@25`M;W-O:71E+@!!;FYA(&]I:V5A('#D:7;D;>3D
M<N0[(%1A<FMI<W1A('#D:79I96X@;'5K=6WDY'+D(&MU=6MA=61E<W-A+@!!
M;FYA(&%I:V$@;VEK96%S<V$@;75O9&]S<V$N`$%N;F$@;FEM:2!U=61E;&QE
M('EH=&5Y<W1I971O;&ES=&%L;&4Z`$%N;F$@;'EH>70@:W5V875S(&]N9V5L
M;6%S=&$N`$%N;F$@:^1Y='3D:N1T=6YN=6MS97-I(&IA('-A;&%S86YA<VD`
M3'5E('-E=7)A879A('1E:W-T:2X@4VEN=6X@4$E4Q,0@<W5O<W1U82!KY'ET
M=/9E:'1O:6AI;B!V;VED86MS97-I(&OD>71TY.0@:N1R:F5S=&5L;>3D+@!!
M;FYA(&YI;6D@=75D96QL92!L=6]K:71U:W-E;&QE.@!0=6]L80!0;VQI=&EI
M:VMA`$MY<V5L>70`4&]R='5G86QI`%3D;>1N(&MU=F%N('!A:6MK80!4Y&WD
M;B!T875L=6MO;B!P86EK:V$`5F]I(&SD:&5T=.3D('9I97-T96KD(&MA;G-I
M;V]N("AE:2!K;W-K92!)34%0('EH=&5Y:W-IY"D`4V%D96WDY'+D(&5D96QL
M:7-I;&QE("5S('1U;FYI;&QE.B``2&%I:'1U=G5U<R`\8G(@+SYT;V1E;F[D
M:_9I<WEY<P!0<F5F<U]L9&%P.B!487)V:71T879A82!,1$%0+6QA86IE;FYU
M<W1A(&5I(&SV>71Y;GET+@!0<F5F<U]S97-S:6]N.B!487)V:71T879A82!S
M97-S:6]N+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET`$EL;6%N<&%I;F4`26QM
M86YP86EN92!M97)E;G!I;FYA<W-A.B``26QM86YP86EN93H@`$5S:6MA='-E
M;'4`17-I:V%T<V5L92!K=79A('5U9&5S<V$@:6MK=6YA<W-A`$5D96QL:6YE
M;@!%9&5L;&ES970@87-E='5K<V5T`%1U;&]S=&$@9&]K=6UE;G1T:0!9:W-I
M='EI;F5N(&]S;VET96MI<FIA`%-A;&%I;F5N(&%V86EN`$]N9V5L;6$`3VYG
M96QM86X@:W5V875S`%!R;VIE:W1I=`!+96AO='1E96X@=&5K<W1I`$IU;&MI
M;F5N(&%V86EN`$IU;&MI<V5N(&%V86EM96X@86QG;W)I=&UI`$IU;&MI<V5N
M(&%V86EM96X@=&EE9&]T`$IU;&MI<V5N+W-A;&%I<V5N(&%V86EN<&%R:6X@
M;'5O;G1I(&5PY&]N;FES='5I+@!0=65R=&\@4FEC;P!6;VD@='5H;W1A('!O
M:7-T971T=6IA('9I97-T96KD`%%A=&%R`$MY<V5L90!+>7-E;'D@97#D;VYN
M:7-T=6DZ("@E<RD@)7,`4&EK86AA:W4`2VEI;G1I]@!24T$@2G5L:VEN96X@
M879A:6X@*"5D(&)I='1IY"D`4F%D:6]P86EN:6ME`%-A9&4`4V%D971T82!A
M:6MA:7-I;@!3861E='1A(&UY]FCDY&X`4V%D96MU=7)O`%9E<VD@:F$@;'5M
M:0!6961E<W3D(&QU;65E;@!3871U;FYA:6YE;B!M:65T96QA=7-E`%-U:&1E
M`$QU:W4`3'5K=2!E<.1O;FYI<W1U:3H@*"5S*2`E<P!6;VD@;'5K96$@=FEE
M<W1E:N0`66AT97ES=&EE=&]J96X@;'5K=2!E:2!O;&4@:^1Y=&5T=.1V:7-S
MY"X`4&]I<W1E=&%A;FMO("5S/R!4Y'3D('1O:6UI;G1O82!E:2!V;VD@<&5R
M=75T=&%A+@!(86QU871K;R!P;VES=&%A('3D;>1N('EH=&5Y<W1I961O;C\`
M4&]I<W1E=&%A;FMO('1I961O="!KY'ET=.1JY'-TY"`E<S\@5.1TY"!T;VEM
M:6YT;V$@96D@=F]I('!E<G5U='1A82X`3N1Y=&5T=.1VY'0@=&EE9&]T.@!4
M964@;75U=&]K<V5T('5U9&5S=&%A;@!0Y&EV:73D`%#D:7;D="!D>6YA86UI
M<V5T('9A;&EK:V]E;&5M96YT:70Z`%#D:79I=.0@<&]R=&%A;&ENY&MY;>3D
M.@!3Y.1N;O9L;&EN96X@;&%U<V5K90!296QA871I;W-E;&%I;@!,871A82!U
M=61E;&QE96X`375I<W1I:6YP86YO=`!%=.1P86QV96QI;65T`$5TY'!A;'9E
M;'5N(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%!O:7-T
M80!0;VES=&$@;W-I;P!0;VES=&$@;W-O:71E:VER:F$`4&]I<W1A('-A<F%K
M90!0;VES=&$@;75O=&]I;'4`4&]I<W1A('3D;'3D(&QI<W1A;'1A`%!O:7-T
M82!P87)I`%!O:7-T82!T86QL971E='1U('-K<FEP=&D@<&%L=F5L:6UE;B!V
MY&QI86EK86ES:&%K96UI<W1O<W1A+@!0;VES=&$`4&]I<W1A('3D;>0@;F]O
M9&D@9&]K=6UE;G1I<W1A`%!O:7-T82!KY'ET=.1JY`!0;VES=&$@:^1Y='3D
M:N0Z("5S`$MO<G9A82!O;&5M87-S86]L979A(&]S;VET96MI<FIA('1U;V1U
M;&QA(&]S;VET96MI<FIA;&QA+B`\<W1R;VYG/E9A<F]I='5S.B!4Y&WD('!O
M:7-T86$@:V%I:VMI(&UE<FMI;F[D="!N>6MY:7-E<W3D(&]S;VET96MI<FIA
M<W1A<VDN/"]S=')O;F<^`%!Y>6YT]O9N(&5I('9O:71U('9A<W1A=&$N(%9I
M<FAE:V]O9&DZ(`!0>7ED971T>>0@;V)J96MT:6$@96D@;/9Y='EN>70N`%!Y
M>61E='1YY"!P86QV96QU82!E:2!L]GET>6YY="X`5&%R=FET=&%V86$@(B5S
M(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2`E<R!A<V5T=6MS:7-S82X`
M5&%R=FET=&%V86$@(B5S(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2!6
M1E,@87-E='5K<VES<V$N`%1A<G9I='1A=F%A("(E<R(M=&EE=&]A(&5I(&]L
M;'5T(&WDY')I=&5L='D@87-E='5K<VES<V$N`%!A:V]L;&EN96X@:V5N='3D
M`%1Y:&IE;F[D`%1Y:&IE;F[D('-A;&%S86YA`%1Y:&IE;F[D('-A;&%S86YA
M<VD`4&%L875T82!O;&5T=6MS970`4&%L875T82!E9&5L;&EN96X@:WES96QY
M`%1U;&]K<V5T`%!A;&%A(&%S971U:W-I:6X`5F%H=FES=&$@=75S:2!S86QA
M<V%N80!2975N:6]N`%!A;&%U=&$@87-E='5K<V5T`%)I8V@@5&5X="!%9&ET
M;W)I;B!A<V5T=6MS970`07)V;VET=6MS970`3VEK96$`3VEK96$@;W1S86ME
M`$]I:V5A(&%R=F]T`%)I=FE?;B!T:65D;W0N+BX`4F]O;&D`4F]M86YI80!+
MY.1N;N0@,3@P`$ODY&YNY"!V87-T87#D:7;DY&X`2^3D;F[D(&UY]G3D<.1I
M=N3D;@!2:79I;B!T:65D;W0`4FEV:6X@=&EE9&]T`%)I=FET.@!6:6EV;VET
M:6X`5FEI=F]I=&EN(&[D:WEY(&MA:6MK:65N(')I=FEE;B!J82!S87)A:VME
M:61E;B!VY&QI;&SD`%9I:79O:71I;B!NY&MY>2!V86EN('-A<F%K:V5I9&5N
M(';D;&EL;.0`5FEI=F]I=&EN(&[D:WEY('9A:6X@<FEV:65N(';D;&EL;.0`
M4W5O<FET80!696[D:N1N($9E9&5R871I:79I;F5N('1A<V%V86QT80!2=6%N
M9&$`4R]-24U%(&MR>7!T;V=R86%F:6YE;B!A;&QE:VER:F]I='5S`%,O34E-
M12!S86QA='1U('9I97-T:0!*=6QK:6YE;B!3+TU)344M=F%R;65N;F4`4T%3
M3"UA=71E;G1I:V]I;G1I(&5I(&]L92!KY'ET971TY'9I<W/D+@!335,@5&5K
M<W1I=FEE<W1I=`!344PM:V]M96YT;W1U;&MK:0!344PM;&%U<V4@87)V;VIE
M;B!H86ME;6ES965N`%-32`!35$%25%1,4R!E<.1O;FYI<W1U:3H@*"5S*2`E
M<P!/3DY)4U1520!37U%,+6MO;65N=&]T=6QK:VD`;&$`4V%I;G0@2&5L96YA
M`%-A:6YT($MI='1S(&IA($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R
M92!J82!-:7%U96QO;@!386EN="!6:6YC96YT(&IA($=R96YA9&EI;FET`%-A
M;6%A;B!K96AY:W-E96X@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4
M;VUE(&IA(%!R:6YC:7!E`%-A=&5L;&EI='1I('!A;'9E;'5N=&%R:F]A:F$`
M4V%U9&EA($%R86)I80!486QL971A`%1A;&QE=&$@(B5S(@!486QL971A("5S
M`%1A;&QE=&$@87-E='5K<V5T`%1A;&QE=&$@;'5O9'5T(&%S971U:W-E="!0
M2%`M<VMR:7!T:6[D('!A;'9E;&EM97-I(';D;&EA:6MA:7-H86ME;6ES=&]O
M;BX@`%1A;&QE=&5T=&EI;B`E<SIN(&%S971U:W-E="X`07-E='5S=&5N('#D
M:79I='ES<VMR:7!T:2!O;B!T86QL971E='1U('!A:6MK86%N.B`B)7,B+@!9
M:'1E>7-T:65T;VIE;B!T86QL971U<R!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`
M2&%J86YA:7-I82!U:VMO<VUY<G-K>6KD`%1I961E`$AA:W4`2&%K=6MO;F5E
M=`!(86MU(&5PY&]N;FES='5I`$AA:W4@97#D;VYN:7-T=6DZ("5S`$AA:W4@
M96D@;VQE(&OD>71E='3D=FES<^0N`$AA971A86XN+BX`5F%L:71S92!T:65D
M;W-T;W0`5F%L:71S92!PY&EVY&WDY'+D`%9A;&ET<V4@;&ESY'1TY';D(')Y
M:&WD`%9A;&ET<V4@=75S:2!O;6ES=&%J80!686QI='-E('!A;'9E;&EN`%9A
M;&ET<V4@;&ESY'1TY';D(&OD>71TY&KD`%9A;&ET<V4@:V%I:VMI`%9A;&ET
M<V4@:V%I:VMI('#D:7;D;>3D<N1K;VUP;VYE;G1I=`!686QI='-E('!O:7-T
M971T879A(&]S;VET96MI<FIA`%9A;&ET<V4@;75O:V%T=&%V82!O<V]I=&5K
M:7)J80!686QI='-E(&]B:F5K=&D`5'EH:F5N;N0@=F%L:6YT80!686QI='-E
M(&]S;VET96MI<FIA+"!J;W-T82!V:65DY.1N('1I971O:F$Z`%9A;&ET<V4@
M;W-O:71E:VER:F$L(&IO:&]N('1U;V1A86X@=&EE=&]J83H`5F%L:71S92!T
M87)V:71T879A="!M97)K:70@86QL82!O;&5V:7-T82!V86QI:V]I<W1A+B!6
M;VET('-E;B!JY&QK965N(&MO<&EO:61A(&IA(&QI:71TY.0@;65R:VET('1E
M:W-T:6ES:2X`5F%L:71S92!LY&AD971I961O<W1O;B!M97)K:7-T]CH`5F%L
M:71S92!PY&EVY'EK<V5N(&5R;W1I;FUE<FMK:3H`5F%L:71S92!PY&EVY'EK
M<V5N(&5S:71Y<W1A<&$Z`%9A;&ET<V4@=FEE;FYI<W/D(&OD>71E='3D=N0@
M;75O=&\Z`%9A;&ET<V4@=&EE9&]S=&\L(&IO<W1A('1U;V1A86X@=&EE=&]J
M83H`5F%L:71S92!LY&AD971I961O<W1O;B!M=6]T;SH`5F%L:71S92!N:6UI
M96X@97-I='ES;75O=&\Z`%9A;&ET<V4@;75U=&5T=&%V82!P<F]F:6EL:3H`
M5F%L:71S92!K96QL;VYA:F%N(&5R;W1I;FUE<FMK:3H`5F%L:71S92!A:F%N
M(&5S:71Y<W1A<&$Z`%9A;&ET<V4@:V%K<VD@>6AT965N<V]P:79A82!K96YT
M=.3D+@!686QI='-E(&]L971U<V[D:WEMY"P@:N1R:F5S='ES87-E='5K<V5T
M(&IA('-I=G5T=7-A<V5T=6MS970N`%9A;&ET<V4@;W-O:71E;&ES=&%S<V$@
M;N1Y=&5T=.1VY'0@:V5N=.1T+@!6;VET('9A;&ET82!N:6UI96X@97-I='ES
M;75O9&]N+@!686QI='-E(';D<FET965M82X`5F%L:71S92!KY'ET971TY';D
M(&MI96QI.@!686QI='1U(&]S;VET96MI<FIA("(E<R(N`$SD:&5TY"!O;F=E
M;&UA=FEE<W1I`$SD:&5TY"!335,`4V5N96=A;`!4=6YN:7-T:6XZ(`!S>7ES
M:W5U`%-E<F)I82!J82!-;VYT96YE9W)O`%-A<FIA;G5M97)O`%!A;'9E;&EM
M96X@=&EE9&]T(&]V870@=N3D<FGD('1A:2!E:7;D="!O;&4@:^1Y=&5T=.1V
M:7-SY"X`27-T=6YT;VIE;B!H86QL:6YT80!397-S:6]N($E$(&]N('9A;FAE
M;G1U;G5T+@!)<W1U;FYO=`!!<V5T80!386QA<V%N86X@<F5S971O:6YT:6EN
M(&QI:71T>79IY"!A<V5T=6MS:6$L(&IO<R!J;W-K=7,@=6YO:&1A="!S86QA
M<V%N87-I+@!6;VET(&%S971T86$@=6QK;VES=&5N('!A;'9E;&EM:65N(&%S
M971U:W-E="P@:F]I=&$@:&%L=6%T(&OD>71TY.0@<&]R=&%A;&ES<V$N`%9O
M:70@87-E='1A82!KY'ET971TY';D;B!K:65L96XL(&%I:V%V>?9H>6MK965N
M(&IA(&UU:71A('#D:7;D;>3D<N1A<V5T=6MS:6$N`%9O:70@87-E='1A82!A
M;&]I='5S;VAJ96QM86XL(';D<FET965M86XL(&[D:WEMY&X@<.1I=FET>6MS
M96X@:F$@;75I=&$@;N1K>6WDY&X@;&EI='1Y=FGD(&%S971U:W-I82X`07-E
M;FYU<P!!<V5N;G5K<V5N('#D:79I='ES<VMR:7!T:2!O;B!S86%T879I;&QA
M`%5S96%T('!A:6MA="!S;W!I=F%T(&%N;F5T='5U;B!P87)A;65T<FEI;CH@
M`%-E>6-H96QL:70`2F%E='1U(&AA:V5M:7-T;P!/<W1O:W-E=`!,>6AY="!K
M=79A=7,Z`$%S971E=&$@<&EK879A;&EN=&%NY'!PY&EM970@=7-E:6UM:6QL
M92!L:6YK96EL;&4N`$[D>73D`$[D>73D("5S`$[D>73D(&MA:6MK:0!.Y'ET
MY"!Y:'1E>7-T:65D;W0`3N1Y=.0@;&ES=&%T`$[D>73D(&5R;V%V86ES=75D
M970@87-E='5K<VEE;B!T86QL971E='5S<V$@:F$@=75D97-S82!J=75R:2!M
M=6]K871U<W-A('9E<G-I;W-S82X`3N1Y=.0@961E;&QI<V5N('-I<^3D;FMI
M<FIA=71U;6ES96X@<.1I=N1Y<RX`3N1Y=.0@87-E='5S('!I=.3D:W-E<VD@
M86QK=7!E<N1I<V5N`$[D>73D('9A;&ET<VEN`$[D>73D('1A=6QU:VMO=&]I
M;6EN;F]T('9A;&EK:V\N`$[D>73D('9A<V5M;6%L;&$@)7,@=F%L:6MK;RX`
M3N1Y=.0@=&%U;'5K;VX@<V]L=6X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@=&%U
M;'5K;VX@=&EE9&]T(&1I86QO9VD`3N1Y=.0@=&%U;'5K;VX@<FEV:6X@=&EE
M9&]T(&1I86QO9VD`3N1Y=.0@:W5V86X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@
M='5O;G1I`%-A=&5I=&$`4V%T96ET82!A:6MA:7-I;@!3871E:71A(&UY]FAE
M;6UI;@!3871E:71A(&SD:&5T='EV:6QL80!0:65N96YNY`!0:65N96YNY"!T
M86D@<VEI<G+D('9I97)E:7-IY"!O<VEO:71A+"!J;W1T82!N92!E:7;D="!O
M;&4@=&EE;&SD`%-I97)R82!,96]N90!+:7)J875D=0!!;&QE:VER:F]I='5S
M`$%L;&5K:7)J;VET=6MS96X@86QG;W)I=&UI`%-I;F=A<&]R90!+;VMO`$]H
M:71A('EL;.1P:71O=&5H=.1VY'0`4VQO=F%K:6$`4VQO=F5N:6$`3'5M:0!,
M=6UI<V%D971T80!,=6UI<V%T96ET80!,=6UI<V%T96ET82!A:6MA:7-I;@!,
M=6UI<V%T96ET82!M>?9HY.1N`$QU;65N('-Y=GEY<SH@`$QU;65N(&WDY'+D
M('9E=&5NY#H@`%-A;&]M;VX@<V%A<F5T`%-O;6%L:6$`3&%U;'5T(&IA(%)U
M;F]U<P!*Y')J97-T>6MS96X@<W5U;G1A`$KD<FIE<W1Y:W-E;B!S=75N;F%N
M('9A;&EN=&$`3.1H9&5O<V]I=&4`3.1H=&5E=`!%=&5LY"U!9G)I:VMA`$5T
M96SD+45U<F]O<'!A("A)4T\M.#@U.2TS*0!%=&5LY"U'96]R9VEA(&IA(&5T
M96SD:7-E="!386YD=VEC:"!S86%R970`171E;.1I;F5N('!A;&QO;G!U;VQI
M<VMO`%;D;&D@=FEE<F5I<V5T('-O;'5J96X@=N1L:7-SY`!6Y&QI('-O;'5N
M(&QE:7#D=&5K<W1I;B!J82!R975N86X@=N1L:7-SY"``5N1L:0!6Y&QI`%;D
M;&D@:F$@=.1Y=&4`17-P86YJ80!2;W-K87!O<W1I`$5R:6MO:7-M97)K:VEE
M;B!S>?9T=/8`3>3D<FET=&5L92!M:6AI;B!H86QU870@961I<W1Y;F5E;B!H
M875N('1U;&]K<VEE;B!T=6QE=F%N+@!*86$@<V]L=0!*86$@<V%R86ME`$IA
M82!R:79I`%5R:&5I;'4`4W)I($QA;FMA`%-T86YD87)D:0!3=&%R(%1R96L`
M06QK86UI<W9U;W-I`$SDY&YI('1A:2!A;'5E`%1I;&$`5&%L;&5N;G5S;75O
M=&\`2V%T=6]S;VET90!,Y'!I;'GV;G1I`$UE<FMK:6IO;F]L:7-T80!0;VES
M=&$@=&]I;6EA;'5E(&]S;VET=&5E<W1A`%1Y>6QI(%M#4U-=`'-U`$%L:6AA
M:V5M:7-T;V$@(B5S(B!E:2!L]GET>6YY="X`3W1S:6MK;P!,Y&AE=.0`3.1H
M971E='1I:6X@(B5S(CIN(&QI<^1Y<W!Y>6YT]BX@170@=F]I(&MI<FIA=71U
M82!S:7/DY&X@96YN96X@:W5I;B!P>7EN=/9S:2!O;B!KY'-I=&5L='D@:F$@
M:'EVY&MS>71T>2X`06QI:VER:F]I='5S`$]N;FES='5I`"(E<R(Z(&QI<^3D
M;6EN96X@:N1R:F5S=&5L;>3D;B!O;FYI<W1U:2X`3VYN:7-T=71T:6EN(&QI
M<^3D;>3D;B`E9"!Y:'1E>7-T:65T;V$@;&ES=&%L;&4N`$]N;FES='5T=&EI
M;B!L:7/DY&WDY&X@)7,@)7,ZY.1N`$OD>71TY&KD;B`B)7,B(&OD>71TY&KD
M=&EE=&]J96X@<&]I<W1A;6EN96X@:N1R:F5S=&5L;>1S=.0@;VYN:7-T=6DN
M`%EH=&5Y<W1I971O;&ES=&%N("(E<R(@;'5O;G1I(&]N;FES='5I+@`B)7,B
M('!O:7-T971T:6EN(&]N;FES='5N965S=&DN`$]N;FES='5T=&EI;B!P;VES
M=&%M86%N("5D('EH=&5Y<W1I971O82X`(B5S(CH@;VYN:7-T=71T:6EN('!O
M:7-T86UA86X@:N1R:F5S=&5L;>1S=.0N`$]N;FES='5T=&EI;B!P;VES=&%M
M86%N("5D('EH=&5Y<W1I971O82!L:7-T86QT82X`4&%L871T:6EN(&]N;FES
M='5N965S=&D@=F%N:&]I:&EN(&%S971U:W-I:6XN($QA=&%A('-I=G4@=75D
M97-T86%N(&[D:&3D:W-E<VD@;75U=&]K<V5T+@!486QL96YN971T:6EN(&%S
M971U:W-I96X@=F%R;75U<VMO<&EO+@!486QL96YN971T:6EN(&%S971U:W-I
M96X@=F%R;75U<VMO<&EO("5S+@`G)7,G.B!PY&EV:71Y<R!O;FYI<W1U:2X`
M)7,Z;B!K:7)J;VET=&%M:6YE;B!O;FYI<W1U:2X`4W5D86X`66AT965N=F5T
M;P!!=7)I;F=O;FYO=7-U`$%U<FEN9V]N;&%S:W4`075R:6YK;VEN96X`075R
M:6YG;VYN;W5S=0!!=7)I;FMO(&YO=7-E92]L87-K964`075R:6YG;VYN;W5S
M=3H@`$%U<FEN9V]N;&%S:W4`075R:6YG;VYL87-K=3H@`%#DY&QL96MI<FIO
M:71U<P!4=6MI`%-U<FEN86T`4W5K=6YI;6D`2'5I<'!U=G5O<F5T(&IA($IA
M;B!-87EE;@!3=V%Z:6UA80!2=6]T<VD`4W9E:71S:0!3>6YC(&QO:VD@<&]I
M<W1E='1U`%-Y;F--3`!3>6YT86MS:79I<FAE(&AA:W5T97)M96ES<^0`4WEY
M<FEA+"!A<F%B:71A<V%V86QT80!5:VMO<VUY<G-K>0!5:VMO<VUY<G-K>6KD
M(&IA('1U=6QI<W1A`%5K:V]S;7ER<VMY=`!5:VMO<VUY<G-K>6KD(&%I:V%I
M<VEN`%135@!44U8M=&EE9&]S=&\`5&%B=6QA871T;W)E:6XH5$%"*2!E<F]T
M971U="!A<G9O=`!4875L=6MK;P!4875L=6MO;B!T:65D;W0`5&%U;'5K;VX@
M87-E='5K<V5T`%1A=6QU:V]N('1I961O=`!486EW86X`5&%I=V%N+"!+:6EN
M86X@;6%A:W5N=&$`5&%D>FEK:7-T86X`5&%N>F%N:6$L(%EH9&ES='EN>70@
M=&%S879A;'1A`$MO:&1E.@!496ATY';D=`!0=6AE;&EN;G5M97)O`$SD;7#V
M=&EL82!E9&5L;&ES96QL92!T=6YN:6QL93H@`$SD;7#V=&EL80!,Y&UP]G1I
M;&$Z(`!,Y&UP]G1I;&$\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!-
M86QL:6$@(B5S(B!E:2!L]GET>6YY="X`36%L;&EE;B!H86QL:6YT80!496MS
M=&D`5F%I;B!T96MS=&D`5&5K<W1I;B!T87-A=7,`5&5K<W1I=&]P`'1O`%1H
M86D@*%1)4RTV,C`I`%1H86EM86$`1E10+6QI<^1T;VEM:6YT;R!E:2!O;&4@
M:^1Y=&5T=.1V:7-SY"X`2&ES=&]R>2!JY')J97-T96QMY"!E:2!O;&4@:^1Y
M=&5T=.1V:7-SY"X`2&]R9&4O2V]L86(@:6YT96=R;VEN=&EM;V]T=&]R:2!E
M:2!T=64@(B5S(@!)35-0(&QO:VEA(&5I('9O:71U(&%L=7-T86$N`$UA:6YT
M96YA;F-E.CH@+6QU;VMA;B!L871A86UI;F5N(&5PY&]N;FES='5I`$%S971U
M:W-E="!I:VMU;F$@;VX@<W5L:F5T='4N(%!O:7-T=71A86XN`%9&4RUT875S
M=&%JY')J97-T96QMY"!P:73DY"!O;&QA(&OD>71E='3D=FES<^0@96YN96X@
M:W5I;B!L:6ET=&5I=.0@=F]I('1U;V1A+@!/<V]I=&5K:7)J86$@(B5S(B!E
M:2!O;&4@;VQE;6%S<V$N`$]S;VET96MI<FIA;B`B)7,B(&QU;VYT:2!O;FYI
M<W1U:2X`3W-O:71E:VER:F%N("(E<R(@<&]I<W1O(&]N;FES='5I+@!/<V]I
M=&5K:7)J86X@(B5S(B!M=6]K:V%U<R!O;FYI<W1U:2X`3W-O:71E:VER:F%A
M(&5I('9O:71U('1Y:&IE;G3DY#H@)7,`66QLY'!I9&]N('!I=.3D(&]T=&%A
M(&OD>71T]O9N('!Y<WEVY"!T86QL971U<W1Y>7!P:2!097)M:7-S:6]N+"!J
M;W,@:&%L=6%T(&OD>71TY.0@;FEI=.0N`%9A:6X@86QA<'5O;&D`0V]N=&%C
M="!I9"!N=6UE<F]A(&5I(&]L92!MY.1R:71E;'1Y+"!O;B!T>6AJY"!T86D@
M96D@;/9Y='EN>70@=&EE=&]K86YN87-T82X`66AT97ES=&EE9&]T(&QI<^1T
M=&EI;B!O;FYI<W1U;F5E<W1I(&]S;VET96MI<FIA87-I+@!0>7ETY&WDY'-I
M('EH=&5Y<W1I971O82!E:2!O;&4@;VQE;6%S<V$N`%9I97-T:6X@86QL96MI
M<FIO:71U:W-E;B!T87)K:7-T86UI<V5E;B!T87)V:71A86X@97)I;&QI;F5N
M(%!'4"UA;&QE:VER:F]I='5S;&]H:V\N`$IA:V5L=6QI<W1A;B!)1"!E:2!O
M;&QU="!MY.1R:71E;'1Y+"!O;B!T>6AJY"!T86D@96D@;/9Y='EN>70@=&EE
M=&]K86YN87-T82X`2F%K96QU;&ES=&%A(&5I(&]L;'5T(&WDY')I=&5L='DN
M`%-A;&%U<W1O:6UI;FYO;B!KY'ET=/8@=F%A=&D@<V%L871T=6$@5U=7+7EH
M=&5Y='3D+@!4:65D;W-T;VX@(B5S(B!P;VES=&\@;VYN:7-T=6DN`%1I961O
M<W1O<W-A("5S('!I=.1I<VD@;VQL82`E<R!A<V5T=7,N`%1I961O<W1O<W-A
M("5S('!I=.1I<VD@;VQL82!J;VET86MI;B`E<R!A<V5T=6MS:6$N`%1I961O
M<W1O82!E:2!V;VED82!K;W!I;VED82!I='-E;G/D('#DY&QL92X`5&EE9&]S
M=&\@;VQI('1Y:&KD+@!3975R86%V87-S82!O;B!O='-I:VMO=&EE9&]T('3D
M<W3D(&UE<W-A9V4O<F9C.#(R("UV:65S=&ES=.0N`$MO:V]R=75D=6X@;N1Y
M='3V=&EL82!A:6AE=71T86$@;VYG96QM:6$@:F]I;&QA:VEN($EN=&5R;F5T
M($5X<&QO<F5R('-E;&%I;65N(&OD>71TY&II;&SD+B!686QI=&5T=&%V87-T
M:2!K>7-E:6YE;B!S96QA:6X@<VESY&QTY.0@<&EI<G1E:73D(&IA('9I<FAE
M:73D(&IO:6AI;B!E:2!O;&4@;/9Y='EN>70@:V]R:F%U<W1A('1A:2!K96EN
M;V$@:VEE<G3DY"!O;F=E;&UA+B!(=6]M86%T:&%N(&5T=.0@:F]S(&OD>73D
M="!TY'3D(&[D>71T]G1I;&%A(&IA($EN=&5R;F5T($5X<&QO<F5R('-E;&%I
M;G1A+"!N:6EN(&[D>71T]B!S86%T=&%A(&UE;F[D('-E:V%I<VEN+"!J;W1K
M=70@=&]I;6EN;F]T(&5I=N1T('1O:6UI('1A:2!S96QA:6X@<V%A='1A82!K
M86%T=6$N($IO<R!KY'ETY'0@5VEN9&]W<R`Y>"!T86D@344@=F5R<VEO=&$L
M(&YI:6X@;VX@;6%H9&]L;&ES=&$@971TY"!KY'ET=/9JY')J97-T96QMY"!K
M86%T=74@;G,N("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G("UV:7)H965S
M965N(&IA('-I;G5N('!I=.3D(&OD>6YN:7-TY.0@:V]N92!U=61E<W1A86XN
M7&Y<;B!-=6ES=&$@971TY"!S:6YU82!O;B!V87)O:71E='1U+B!.87!S875T
M82!/2RUN87!P=6QA82!J;W,@:&%L=6%T(&MO:V5I;&QE(&5D:71O<FEN(&MO
M:V]R=75T=2!NY'ET=/9T:6QA82X`4&]I<W1E='1I:6X@<')O9FEI;&D@(B5S
M(BX`5'5O;FYI;B!V;VD@<W5O<FET=&%A(&QO<'!U=6X@=F%I:VMA('1U;&ES
M:2!V87)O:71U:W-I82X`5F%I;B!V87-E;B!P=6]L:0!';G501R!O:&IE;&UA
M;B!S:6IA:6YT:2!P:73DY"!MY.1R:71E;&SD($-R>7!T7W!G<#HZ("UL=6]K
M87-S82X`5FEE<W1I(&SD:&5T971T>2`E<R!V87-T86%N;W1T86IA;&QE("5S
M(&]T<VEK:V]N82`B)7,B(&]N(&[D>71E='1Y+@I%:2!O;&4@;6ETY.1N('1A
M:V5I=&$@<VEI=.0@971TY"!V:65S=&D@;VX@;'5E='1U('1A:2!Y;6WD<G)E
M='1Y+@!.:6UI(&IO=&$@:^1Y=&5TY.1N(&QI;FMI=&5T=.1E<W-A(&QU;R!S
M:79U;&QE`$ME;G1T:65N(&WDY'+D('!I=.3D(&%N=&%A(&YU;65R;VEN82X`
M36]D=75L:2!O<&5N<W-L('1A<G9I=&%A;B!(;W)D95]#<GEP=%]S;6EM93HZ
M("UL=6]K86X@:^1Y='3D;6ES96MS:2X`07-E='5S=&$@(B5S(B!K;W-K82!S
M96X@=&EE9&]T('EL:71T:7;D="!T86QL971U<W1A=F%N('-U=7)I;6UA;B!S
M86QL:71U;B!R86IA;@!/:&IE;&UA82P@:F]L;&$@=F]I(&MA='-O82!V:65S
M=&ET>7EP<&GD("@E<RDL(&5I(&SV>71Y;GET(&KD<FIE<W1E;&WD<W3D+@!,
M86EN875S;65R:VMI('!I=.3D(&]L;&$@>6MS:71TY&EN96X@;65R:VMI+@!6
M86EN(&]I:V5A(&IA('9A<V5N('!U;VQI`%9A:6X@;VEK96$@<'5O;&D`17)O
M=&EN('!I=.3D(&]L;&$@>6MS:71TY&EN96X@;65R:VMI+@!086QV96QI;B`B
M)7,B(&]N('!O:7-T971T=2X`4&%L=F5L:6X@(B5S(B!O;B!T86QL971E='1U
M+@!3:7/DY&YK:7)J875T=6UI<W!Y>6YT]B`E<R!O;B!P;VES=&5T='4N`$WD
MY')I=&5L='GD(')I=FGD("@E9"D@96D@;VQE(&]L96UA<W-A+@!686QIY&%I
M:V%I<W1I961O<W1O82`B)7,B(&5I(&]L92!O;&5M87-S82X`2VER:F]I='1A
M;6%S:2!T96MS=&D@96D@=F%S=&%A('1E:W-T:>0@<G5U9'5L;&$N`%9A:6X@
M>6SD<'5O;&D@:F$@86QA<'5O;&D`5F%I;B!Y;.1P=6]L:0!4=6]T=2!T:65T
M;R!HY'9I<VD@961E;&QI<V5N(&MO:&1A;B!A:6MA;F$N`%1U;W1U82!T:65D
M;W-T;V$@96D@=F]I='4@=&%L;&5T=&%A+@!/<VEO=&$@=V5A=&AE<BYC;VT@
M96D@;VQE(&OD>71E='3D=FES<^0N`%1E96UA:&%K96UI<W1O82`B)7,B(&5I
M(&SV>71Y;GET+@!/<V]I=&5K:7)J;VIA(&5I('9O:2!S96QA=&$N`$%S971U
M:W-I82!E:2!O;&4@<V%A=&%V:6QL82X`16D@;VQE(&]S:6]I=&$L(&IO=&MA
M('9O:61A86X@;N1Y='3DY"!V:65S=&EE;B!Y:'1E>61E<W/D+@!/<V]I=&5K
M:7)J;VEH:6X@96D@=F]I(&MI<FIO:71T86$N($OD>71E='3D=FES<^0@;VQE
M=F%T(&]S;VET96MI<FIA="!E:7;D="!S86QL:2!S:6YU;B!L:7/D=.0@;FEI
M:&EN('5U<VEA(&]S;VET=&5I=&$N($IO<R!E<.1I;&5T('9I<FAE=&EL86YN
M971T82P@;FEI;B!O=&$@>6AT97ES(&KD<FIE<W1E;&WD;B!Y;&SD<&ETY&KD
MY&XN`%3D<W/D(&ME;G3D<W/D(&]N(&QI:6%N(&UO;G1A(&UE<FMK:>0N($%N
M;F]I="`E<R!M97)K:VGD.R!S:6YU;B!P:73DY"!A;G1A82!VY&AE;6WD;B!K
M=6EN("5S(&UE<FMK:>0N`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@;&ESY.1M
M:7-E<W/D(&KD<FIE<W1E;&WDY&XZ("5S`$OD>71TY&KD;B`B)7,B(&OD>71T
MY&KD=&EE=&]J96X@<&]I<W1A;6ES97-S82!JY')J97-T96QMY'-SY"!O;&D@
M;VYG96QM:6$Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('!O:7-T86UI<V5S
M<V$@:N1R:F5S=&5L;>1S=.0Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('#D
M:79I='EK<V5S<^0Z("5S`%1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L
M;6EA+B!9:'3DY&X@)7,Z82!E:2!T=6]T=0!4:65D;W-T;VX@='5O;FYI<W-A
M(&]L:2!O;F=E;&UI82X@)7,@:V]K;R!O;&D@<W5U<F5M<&D@:W5I;B!S=75R
M:6X@<V%L;&ET='4@:V]K;R`H)60@=&%V=6$I+@!4:65D;W-T;VX@='5O;FYI
M<W-A(&]L:2!O;F=E;&UI82X@)7,@;&%T875T=6D@=F%I;B!O<V%K<VDN`%1A
M<&%H='5I('9I<FAE('5U<VEE;B!Y:'1E>7-T:65T;VIE;B!L:7/DY&UI<V5S
M<^0N($]T82!Y:'1E>71TY"!JY')J97-T96QMY&X@>6QLY'!I=.1JY.1N+@!4
M87!A:'1U:2!V:7)H92!T96ATY&5S<^0@=75T=&$@;&ES=&%A+@!487!A:'1U
M:2!V:7)H92!L=6]T865S<V$@;W-O:71E:VER:F%A.B`E<P!487!A:'1U:2!V
M:7)H92!P;VES=&5T=&%E<W-A("(E<R(@;.1H=&5E;N0@:^1Y=&5T>7-TY"!O
M<V]I=&5K:7)J87-T82X`5&%P86AT=6D@=FER:&4@<&]I<W1E='1A97-S82!T
MY'3D('EH=&5Y<W1I971O83H@)7,`5&%P86AT=6D@=FER:&4@;N1Y=&5T=.1E
M<W/D(&QI<W1A80!487!A:'1U:2!V:7)H92!NY'ET971TY&5S<^0@=FEE<W1I
M;B!TY'3D(&]S:6]T80!9:'1E>7-T:65T;VIE;B!T=6]N;FES<V$@=&%P86AT
M=6D@=FER:&4N`%1A<&%H='5I('9I<FAE('1U;W1A97-S82!T:65T;V$Z("5S
M`&E#86QE;F1A<BUT:65T;VIE;B!T=6]N;FES<V$@=&%P86AT=6D@=FER:&4N
M`$%S971U<W1I971O;&]M86MK965S<V$@;VX@:F]K:6X@=FER:&4N($5H:^0@
M:N1T:70@:F]N:W5N('!A:V]L;&ES96X@:V]H9&%N('3D>71TY&WD='3D+@!4
M87!A:'1U:2!V:7)H92!Y<FET971TY&5S<^0@<W5O<FET=&%A(&]S;VET96MI
M<FIA=&]I;6EN=&]A+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N+@!487!A
M:'1U:2!V:7)H92!P;VES=&5T=&%E<W-A('3D=.0@;W-O:71E:VER:F%A.B`E
M<RX`66AT97ES=&EE=&]J96X@<.1I=FET>6MS97-SY"!T87!A:'1U:2!V:7)H
M92X@67)I=.0@;7GV:&5M;6EN('5U9&5S=&%A;BX`2F%K96QU;&ES=&%N('#D
M:79I='EK<V5S<^0@=&%P86AT=6D@=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U
M=61E<W1A86XN`%1A<&%H='5I('9I<FAE('#D:79I=&5T=.1E<W/D('3D=.0@
M;W-O:71E:VER:F%A.B`E<P!4Y&WD;B!M97)K:6YNY&X@<.1I=FET>6MS97-S
MY"!T87!A:'1U:2!V:7)H93H@)7,N`$5I(&]L92!Y:'3DY&X@=FEE=.1VY.0@
M;W-O:71E='1A+@!.Y&WD(&]S;VET96MI<FIA="!NY'ET973DY&X@=.1S<^0@
M:N1R:F5S='EK<V5S<^0Z`$[D;>0@<V%R86MK965T(&[D>71E=.3D;B!TY'-S
MY"!JY')J97-T>6MS97-SY#H`5.1MY"!)34%0('!A;'9E;&EN(&5I('1U92!K
M86YS:6]I9&5N(&IA:V%M:7-T82X`5.1MY"!T:65D;W-T;R!E:2!V86EK=71A
M(')A<BUT:65D;W-T;VQT82X`5.1MY"!T:65D;W-T;R!E:2!V86EK=71A('II
M<"UT:65D;W-T;VQT82X`5.1MY"!E:2!V86EK=71A(&]I:V5A;'1A(&MO<G1T
M:6YU;65R;VQT82X`5.1L;.0@86IU<FEL;&$@=F]I(&SD:&5T=.3D('9I97-T
M96KD($-L:6-K871E;&QI;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E
M=V%Y('!A;'9E;'5A($A45%`@05!).FQL82X`5.1L;.0@86IU<FEL;&$@=F]I
M(&SD:&5T=.3D('9I97-T96KD(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A
M=&5W87D@<&%L=F5L=6X@:V%U='1A($A45%`@05!).FQL82X`5.1L;.0@86IU
M<FEL;&$@=F]I(&SD:&5T=.3D('9I97-T96KD('-M<S)E;6%I;"`H:'1T<#HO
M+W-M<S)E;6%I;"YC;VTI(&=A=&5W87D@<&%L=F5L=6X@:V%U='1A($A45%`@
M05!).FQL82X`5.1L;.0@86IU<FEL;&$@=F]I(&SD:&5T=.3D('9I97-T96KD
M(%9O9&%F;VYE;B!N=6UE<F]I:&EN(%--5%`Z;&SD(&OD>71TY&5N(%9O9&%F
M;VYE($ET86QY(&=A=&5W87D@<&%L=F5L=6$N(%3D=.0@<&%L=F5L=6$@=F]I
M(&OD>71TY.0@=F%I;B!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I('1U;FYU:W-I;&QA+@!4Y&WD(&ME;G1TY"!O;B!P86MO;&QI;F5N+@!4
MY'-SY"!K96YTY'-SY"!P:73DY"!O;&QA('9A:6X@:V]K;VYA:7-L=6MU:F$N
M`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@;G5M97)O:71A(&IA('!I;&MK
M=2UM97)K:V5JY"X`5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!O:W1A86QI
M;'5K=6IA+@!4Y'-SY"!K96YTY'-SY"!P:73DY"!O;&QA(&QI<W1A(&MO:V]N
M86ES;'5K=6IA+"!J;W1K82!P:73DY"!O;&QA(&5R;W1E='1U('!I;&MU;&QA
M('1A:2!VY&QI;'GV;FYI;&SD`$%R=F]N('!I=.3D(&]L;&$@;G5M97)O+@!4
MY'-SY"!K96YTY'-SY"!O;B!VY')I;>3D<FET>7,L(&IO;FMA('!I=.3D(&]L
M;&$@4D="($AE>"!M=6]D;W-S+"!E<VEM97)K:6MS:2`G(S$R,S1A9B<N`%3D
M;>0@=&EE9&]S=&]M=6]T;R!E:2!O;&4@='5E='1U+@!4Y&WD(&QO;6%K92!O
M;B!J;R!KY'-I=&5L='DN`%3D;>0@;VX@)7,N`%3D;>0@;VX@2V]L86(@1W)O
M=7!W87)E(&]B:F5K=&DN($MA='-O86MS97-I('3D;>1N(&]B:F5K=&EN('-I
M;G5L;&$@<&ETY.0@;VQL82!SY&AK]G!O<W1I;VAJ96QM82P@:F]K82!Y;6WD
M<G3DY"!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A='1I82X@3&ES=&$@>6AT965N
M<V]P:79I<W1A('/D:&OV<&]S=&EO:&IE;&UI<W1A(&SV>71Y>2!O<V]I='1E
M97-T82`E<P!4Y&WD('9I97-T:2!O;B!K:7)J;VET971T=2!E<FD@;65R:VES
M=/9L;.0@*"5S*2!K=6EN(&UI:^0@<VEN=6QL82!O;B!KY'ET]G-SY"X@`$YU
M;65R;VX@<&ETY.0@;VQL82!VY&AI;G3DY&X@>6MS:2X`5.1L;.0@:&5N:VEL
M]FQLY"!O;B!J;R`E<R!M97)K:6YTY"!O<V]I=&5K:7)J87-S80!4Y&QLY"!P
M86QV96QI;65L;&$@96D@=F]I(&%U:V%I<W1A('II<"T@=&%I(&=Z:7`M=&EE
M9&]S=&]J82X`5.1MY"!JY')J97-T96QMY"!O;B!P;VES('#DY&QTY"X`07)V
M;VX@<&ETY.0@;VQL82!N=6UE<F\N`%3D;>0@;VX@;VQE='5S;W-O:71E:VER
M:F$@:W5N(&QI<^1TY.1N('1A:2!T=6]D86%N('EH=&5Y<W1I971O:F$N`%3D
M;>1N(&EK:W5N86X@=F]I(&%U:V%I<W1A('9A:6X@07-E='5K<V5T(&EK:W5N
M87-T80!->7)S:WD`5&EK971I=`!!:6MA`$%J86YS975R86YT80!!:F%N(&5S
M:71Y<VUU;W1O`$%J86X@=F%L:6YT80!4:6UO<BU,97-T90!4:71T96QI`$]T
M<VEK:V\@*'1O;VQT:7`I.@!687-T86%N;W1T86IA`%9O:61A:W-E<VD@=F%L
M:71A('5S96%M<&EA('9A:6AT;V5H=&]J82P@<&EDY"!#;VYT<F]L+2`H4$,I
M('1A:2!#;VUM86YD+2`H36%C*2!NY'!PY&EN=.0@<&]H:F%S<V$@:W5N(&YA
M<'-A=71A="!H:6ER96X@<&%I;FEK971T82X`5.1NY.1N`$[D>73D($A434PM
M;.1H9&5K;V]D:0!4;V=O`%1O:V5L874`2'5O;65N;F$`5&]N9V$`3&EI86X@
M;6]N=&$@97#D;VYN:7-T=6YU='1A(&MI<FIA=71U;6ES>7)I='ES=.0@=FEI
M;65I<VEM<&EE;B!M:6YU=71T:65N(&MU;'5E<W-A+@!9;/9S`%EL:6UPY.1N
M(&ME:'EK<V5E;B`H7W1O<"D`2^3D;F[V:W-E=`!4<FEN:61A9"!J82!4;V)A
M9V\`5&]S:2!V86D@97#D=&]S:0!T:0!4=6YI<VEA`%1U<FMK:0!4=7)K:VD@
M*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!J82!#86EC;W,@<V%A
M<F5T`%1U=F%L=0!+:7)J;VET82!V86QI;G1A<VDZ(`!5+E8N("UI;F1E:W-I
M.B``55),`%523"!J;VAO;B!P86QA=71E=&%A;B!S:W)I<'1I;B!S=&%T=7,@
M<F%P;W)T=&D`55),.@!59V%N9&$`56MR86EN80!61E,M:&%K96UI<W1O82!E
M:2!V;VET=2!L=6ME82X`2^1Y='3D:N1N(&QI<^1T:65T;VIE;B!L:7/D>7,@
M96D@;VYN:7-T=6YU="!K:7)J875T=6UI<V5S<V$N`$5I('9O:2!V86EH=&%A
M(&]I:V5U:W-I82!61E,M=&EE9&]S=&]L;&4@(B5S(BX`16D@=F]I('9A:6AT
M86$@;VEK975K<VEA(%9&4RUT:65D;W-T;VQL92`E<R\E<RX`16D@=F]I9&$@
M=F%I:'1A82`E<SIN+@!4:65D;W-T;VX@(B5S(B!K;VMO82!E:2!V;VET=2!T
M87)K:7-T86$N`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I961O
M<W1O82`B)7,O)7,B+@!344PM<&%L=F5L:6UE96X@96D@<V%A9&$@>6AT97ET
M=.0N`%EH=&5Y='3D(&5I('9O:61A(&UU;V1O<W1A82!34TPM<V%L871T=6YA
M+@!61E,M=&EE9&]S=&]A(&5I('9O:61A(&MO<&EO:61A+@!%:2!V;VED82!L
M=6]D82!61E,M:&%K96UI<W1O82`B)7,B+@!%:2!V;VED82!L=6]D82!61E,M
M:&%K96UI<W1O82X`16D@=F]I='4@;'5O9&$@5D93+71I961O<W1O80!%:2!V
M;VED82!N:6UE=.0@=75D96QL965N(%9&4RUK86YS:6]T82`B)7,B+@!%:2!V
M;VET=2!L=6]D82!T>6AJY.0@5D93+71I961O<W1O82X`16D@=F]I(&QU;V1A
M('5U='1A(&IA:V]A+B!,Y&AT965N('1Y>7!P:2!P=75T='5U+@!4:65T;V$@
M96D@=F]I9&$@;&%A:F5N=&%A+@!%:2!V;VED82!P;VES=&%A("(E<R(L(&AA
M:V5M:7-T;R!E:2!O;&4@='EH:N0N`$5I('9O:61A('!O:7-T86$@(B5S(CH@
M)7,N`$5I('9O:61A('!O:7-T86$@)7,L(&AA:V5M:7-T;R!E:2!O;&4@='EH
M:N0N`$5I('9O:61A('!O:7-T86$@5D93+6AA:V5M:7-T;V$@<F5K=7)S:6EV
M:7-E<W1I+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A+@!%:2!V
M;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A.B`E<RX`16D@=F]I9&$@<&]I
M<W1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A('!O:7-T86$@5D93
M+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M:V%N<VEO=&$@(B5S
M(BX`16D@=F]I9&$@<&]I<W1A82!61E,ZY.0@<F5K=7)S:6EV:7-E<W1I.B`E
M<RX`3GEK>6ES=.0@:&%K96UI<W1O82!E:2!V;VET=2!S96QV:71TY.0N`%9A
M<FUE;G1E96X@=&EE=&]J82!E:2!V;VED82!E>'1R86MT;VED80!-Y.1R:71Y
M:W-E;B`E<R!L=6ME;6EN96X@97#D;VYN:7-T=6DN`$5I('9O:61A('-I:7)T
MY.0@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S
M=&]A("(E<R(N`$5I('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$@:VER:F]I
M='5S=&$@=F%R=&5N+@!%:2!V;VED82!A=F%T82!61E,M=&EE9&]S=&]A+@!4
M:6EV:7-T971Y;B!T:65D;W-T;VX@875K86ES=2!E<.1O;FYI<W1U:2X`16D@
M=F]I='4@;'5K96$@5D93+71I961O<W1O82`H9FEL97-I>F4H*2!E<.1O;FYI
M<W1U:2DN`$5I('9O:61A(&QU:V5A(%9&4RUT:65D;W-T;V$@*&=E=$9I;&53
M:7IE*"D@97#D;VYN:7-T=6DI+@!%:2!V;VET=2!L=6ME82!T:65D;W-T;V$Z
M(`!V9G-R;V]T(&IU=7)I:&%K96UI<W1O82!E:2!V;VET=2!L=6ME82X`575D
M96QL965N;FEM9>1M:6YE;B`E<R`E<SIK<VD@97#D;VYN:7-T=6D@:V]S:V$@
M:V]H9&5H86ME;6ES=&\@;VX@:F\@;VQE;6%S<V$`16D@=F]I9&$@;FEM973D
M('5U9&5L;&5E;B!61E,M:&%K96UI<W1O82X`16D@=F]I9&$@;FEM973D('5U
M9&5L;&5E;B!61E,M:&%K96UI<W1O83H@)7,N`$5I('9O:61A(&YI;65TY"!U
M=61E;&QE96X@5D93+71I961O<W1O82`B)7,B+@!%:2!V;VED82!N:6UE=.0@
M=75D96QL965N(%9&4RUT:65D;W-T;V$@)7,O)7,N`$5I('9O:71U(&YI;65T
MY"!U=61E;&QE96X@5D93+71I961O<W1O82X`16D@=F]I9&$@<W5O<FET=&%A
M(&MO;65N=&]A("=M:VES;V9S)RX`5V]R9"UD;VMU;65N='1I82!E:2!V;VET
M=2!KY.1N=.3D`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O<W1O82`B
M)7,B+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T;V]N("AC;W!Y
M*"D@97#D;VYN:7-T=6DI+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D
M;W-T;VX@=&EE=&]J82X`16D@=F]I9&$@:VER:F]I='1A82!61E,M=&EE9&]S
M=&]A+"!K:6EN=&GV(&]N('3D>6YNY"X`06QL979I:79A='1U`%!E<G4@;75U
M=&]K<V5T`%!E<G5U='1A82!E9&5L;&ES96X@=&]I;65N<&ET965N`%1U;G1E
M;6%T;VX@=F%S=&%U<R!P86QV96QI;65L=&$@>6AT97ET965N.@!4=6YT96UA
M=&]N('9A<W1A=7,@<&%L=F5L:6UE;'1A.B``3'5O:VET=&5L96UA=&]N`%5N
M:6-O9&4@*%541BTX*0!9:&1I<W1Y;F5E="!A<F%B:65M:7)A871I=`!9:&1I
M<W1Y;F5E="!K=6YI;F=A<VMU;FYA=`!9:&1Y<W9A;&QA=`!9:&1Y<W9A;'1O
M:F5N(%1Y>6YE;FUE<F5N(&5R:6QL:7-S86%R970`36ET=&%Y:W-I:_9T`%1U
M;G1E;6%T;VX`5'5N=&5M871O;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+@!4=6YT96UA=&]N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$%N
M;F5T='4@<&%I:VMA=&EE=&\@;VX@='5N=&5M871O;BX`5'5N=&5M871O;B!K
MY'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$N`%!O:7-T82!N>6MY:7-E;B!E
M;&5M96YT:6X@;&EN:VET>7,`3FEM973V;@!4:65T;W1U<G9A<WEI<W3D(&5I
M+7!R:79I;&5E9VES970@<VMR:7!T:70@96EVY'0@=F]I(&MU='-U82!,96EK
M:V%A+TMO<&EO:2],:6ETY"!T;VEM:6YT;VIA+B!.87!S875T82!/2RUN87!P
M=6QA82!NY&ADY&MS97-I(&UO>FEL;&$N;W)G('-I=G5I;&QA(&]L979A;B!O
M:&IE96XL(&IO<W-A(&YE=79O=&%A;B!M:71E;B!S:W)I<'1I<VD@=F]I=F%T
M(&OD>71TY.0@;&5I:V5P]GETY.0N`%!O:7-T82!VY')I`$5I('1U971T=2!#
M;VYT96YT+51Y<&4Z("5S`$5I+71U971T=2!L86%J96YN=7,`4.1I=FETY`!0
MY&EV:73D("5S`%#D:79I=.0@:^1Y='3D:N0`4.1I=FET971T:6EN("(E<R(N
M`%#D:79I='ES<VMR:7!T:2!P;VES=&5T=&EI;BX`5'5O`'1U;R!K86EK:VD@
M;VAJ96QM:65N(&%S96YN=7-T:65D;W-T;W0@<&%L=F5L:6UE;&QE+@!)<V]T
M(&QA=&EN86QA:7-E="!K:7)J86EM970`27-O="!R;V]M86QA:7-E="!N=6UE
M<F]T`%5R=6=U87D`2^1Y=.0@;GEK>6ES=.0Z("5S`$OD>73D(%-33"US86QA
M=7-T80!+Y'ETY"!J;W,@='5N;G5S+W-A;&%S86YA(&]N(&5R:2!)35-0+7!A
M;'9E;&EM96QL92X`2^1Y='3D:N0`2^1Y='3D:N1L;.0@)7,@96D@;VQE(&]I
M:V5U:W-I82!T96ADY"`E<RX`2^1Y='3D:FEE;B!Y;&SD<&ET;P!+Y'ET=.1J
MY&X@87-E='5K<V5T`$OD>71TY&KD;B!R96MI<W1E<O9I;6EN96X`5.1S<^0@
M:N1R:F5S=&5L;>1S<^0@96D@=F]I(')E:VES=&5R]FEDY"!KY'ET=.1J:>0N
M`$OD>71TY&KD='5N;G5S=&$@96D@;/9Y='EN>70N`$OD>71TY&KD='5N;G5S
M`$OD>71TY&KD='5N;G5S("(E<R(@;VX@:F\@;VQE;6%S<V$N`$OD>71TY&KD
M='5N;G5S.@!+Y'ET=.1JY'1U;FYU<SH@`$KD<FIE<W1E;&WD;B!KY'ET=.1J
MY'0Z`%5Z8F5K:7-T86X`5D93+6AA:V5M:7-T;V$@96D@;VQE(&]L96UA<W-A
M+@!0;VES<V%O;&]V:65S=&D`4&%I:VMO:F$@;/9Y='EI(&5S:6UE<FMI:W-I
M.B``5F]I;6%S<V%O;&]A:6MA`$%R=F\@;6EN=75T96ES<V$@;GEK>6AE=&ME
M<W3D+@!!<G9O(&]N('EL:2!P:71U=61E;B!M86MS:6UI87)V;VX@)7,N/`!!
M<G9O=`!686QI='1A=F%T(&%R=F]T`%9A;G5A='4`5F%I:'1E;&5V86$`5F5N
M97IU96QA`%1A<FMI<W1U<R!E<.1O;FYI<W1U:2`M(%3D=.0@=FEE<W1IY"!O
M;B!V;VET=2!KY'-I=&5L;.0N`%9E<FES:6=N(&AA:V5M:7-T;P!697)S:6\`
M5F5R<VEO;FAA;&QI;G1A`%!Y<W1Y<W5O<F$@=&%S875S`%!Y<W1Y<W5O<F$@
M=.1Y=&4`4'ES='ES=6]R83H`17)I='3D:6X@:V]R:V5A`%9I971N86T`5FEE
M=&YA;2`H5DE30TE)*0!.Y'ETY"`B)7,B`$[D>73D("5S`$[D>73D('EH=&5Y
M<W1I961O=`!.Y'ETY"!E<FEL;&ES96[D('=W=RUS:79U;F$`3N1Y=.0@)7,`
M3VQE='5K<V5N82!KY'ET971TY';D(&[D:WEMY#H`3F5I='-Y='-A87)E="P@
M0G)I='1I;.1I;F5N`$YE:71S>71S86%R970L(%EH9'ES=F%L=&%I;@!.Y&MY
M=N1I<WEY<P!.Y&MY=N1I<WEY<SH@`%9O9&%F;VYE($ET86QY(%--5%`Z;B!A
M=G5L;&$`5D%23TE455,`5D%23TE455,A(2$@4$])4U1!(%-+4DE05$D@2^13
M24X@4$%,5D5,24U%3%1!("5S+@!724X@2%144#IN(&%V=6QL80!786QL:7,@
M:F$@1G5T=6YA`%9A<F]I='5S`&ME`%/DY&5N;G5S=&4`4^3D=&EE9&]T(&]N
M('1O:6UI='1A;G5T`%=E871H97(N8V]M`%=75P!75U<M<VEV=7-T;P!796)S
M:71E(%523`!6:6EK;VET=&%I;@!497)V971U;&]A`%1E<G9E='5L;V$@;VAJ
M96QM86%N("5S`%1E<G9E='5L;V$L("5S`$SD;G-I;6%I;F5N("A)4T\M.#@U
M.2TQ*0!,Y&YS:6UA:6YE;B]%=7)O("A)4T\M.#@U.2TQ-2D`3.1N<VDM4V%H
M87)A`$UI;FOD(&]H:F5L;6%N("5S(&OD>6YN:7-TY.0@<VESY.1N:VER:F%U
M='5M:7-E;B!JY&QK965N+@!-:73D(&UE<FMK:>0@:^1Y=&5TY.1N(&5R;W1T
M:6UE;F$_`$UI=.0@;65R:VMIY"!KY'ET973DY&X@;&%I;F%U:W-E96X_`%=H
M97)E:7,@075S=')A;&EA;B!K87)T=&$`36ET:^0@=F%I:&5E=`!6;VET(&WD
MY')I=&5L;.0@;&ESY'1O:6UI;G1O:F$@;&%I=&5T86%N('#DY&QL92!2:6-H
M(%1E>'0@961I=&]R:7-S82X`3&5V97ES`$QE=F5Y<R!#4U,@;6ET=&%Y:W-I
M:VOV:6[D`%9A<V5M;6%L;&$@;VQE=F%N("5S('9A;&EK;VX@;&5V97ES("AT
M=6QE92!V;VEM86%N('-E=7)A879A;&QA('-I<^3D;FMI<FIA=71U;6ES96QL
M82DZ`%1A=6QU:V]N(&QE=F5Y<P!,979E>61E;B!Y:W-I:VOV`$QE=F5Y<SH`
M5VEK:0!4=75L:0!4=75L:7-T82!A:6MA:7-I;@!4=75L96YN;W!E=7,@<V]L
M;75I<W-A`%1U=6QI.@!4=75L:3H@`%9I:7-A=7,`5&]I=F5L:7-T870`5'GV
M`$]S;VET92`H='GV*0!+875P=6YK:2`H='GV*0!-86$@*'1Y]BD`4'5H96QI
M;B`H='GV*0!0;W-T:6YU;65R;R`H='GV*0!,Y.1N:2!T86D@86QU92`H='GV
M*0!+871U;W-O:71E("AT>?8I`%;DY'+D(&WDY'+D(&ME;G1T:>0@<FEV:6QL
MY"`E9"X@3V1O=&5T=&EI;B`E9"P@;/9Y='EI("5D+@!6Y.1RY"!MY.1RY"!K
M96YT=&GD+B!/9&]T971T:6EN("5D+"!L]GET>6D@)60N`%;DY'+D('!O:6MK
M96%M82`E9"!L=65T=&%E<W-A(%9&4RUT:65D;W-T;V$N`%@M4F5F`%@U,#EV
M,R!P97)U<W)A:F]I='1E970`6#4P.78S(&QI<^1T;VEM:6YN;W0@879A:6UE
M;B!KY'ET]FQL90!8-3`Y=C,@2V]H=&5E;B!V86EH=&]E:'1O:6YE;B!N:6UI
M`%@U,#EV,R!+;VAT965N(&%V86EM96X@='5N;FES=&4`6#4P.78S+6QA86IE
M;FYU:W-E=`!65@!65E96`%EA:&]O(2!K87)T=&$`5G5O<VET=&%I;@!*96UE
M;@!+>6QLY`!+>6QLY"P@<W5O<W1U;BX`2^1Y=.1T(%1%2U-4251)3$%!+B!+
MY'ETY"!;/#Y=(&YA<'!U;&%A('9A:6AT86%K<V5S:2!T86MA:7-I;B!765-)
M5UE'+71I;&%A;BX`170@=F]I('1E:&3D(&5N96UPY.0@:W5I;B`E9"!O<VEO
M=&$N`$5I('9O:2!L=6]D82!K=6EN(&5N:6YTY.1N("5D('EH=&5Y<W1I971O
M82`B)7,B.F5E;BX`170@;VQE(&%U=&5N=&EK;VET=6YU="X`3FEM97-SY'-I
M(&5I('-A82!O;&QA("=<)RUM97)K:VGD+@!%="!A;G1A;G5T(&]I:V5A;B!M
M=6]T;VES=&$@<^1H:_9P;W-T:6]S;VET971T82X`170@;>3D<FET96QL>70@
M;6ET:^0@='5O9'5N('1I961O<W1O;B!K96YTY'0@=F%S=&%A=F%T(&UI=.1K
M:6X@:V5N='1IY"`E<SIS<^0N`%-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!N
MY&ADY"!TY'3D('EH=&5Y<W1I971O82X`4VEN=6QL82!E:2!O;&4@;VEK975K
M<VEA(&[D:&3D('3D;>1N(&]B:F5K=&EN('1I971O:F$N`%-I;G5L;&$@96D@
M;VQE(&]I:V5U:W-I82!P;VES=&%A('3D=.0@;.1H9&5T=.0N`$]L970@:VER
M:F%U='5N=70@=6QO<RX`4VEN=6X@<&ETY.0@86YT86$@;VEK96$@;6%T:V%P
M=6AE;&EN;G5M97)O+"!V86EN(&YU;65R;VET82!J82!M86AD;VQL:7-E<W1I
M("<K)R!J;W,@:^1Y=.1T(&MA;G-A:6YVY&QI<W3D('!U:&5L:6YN=6UE<F]M
M=6]T;V$N`%-I;G5N('3D>71Y>2!A;G1A82!O:6ME82!A<G9O+@!3:6YU;B!P
M:73DY"!A<V5N=&%A($1A=&%4<F5E+71A=7-T86KD<FIE<W1E;&WD(&5N;F5N
M(&MU:6X@=F]I="!KY'ET=.3D(%-I9VYU<"UT;VEM:6YT;VIA+@!3:6YU;B!P
M:73DY"!A<V5N=&%A(%9&4RUT875S=&%JY')J97-T96QMY"X`4VEN=6X@='5L
M964@:W5V86EL;&$@;VYG96QM871I;&%N;F5T=&$@96YN96X@:W5I;B!V;VET
M(&SD:&5T=.3D(&]N9V5L;6%V:65S=&EN+@!3:6YU;B!P:73DY"!A;G1A82!5
M4DP@;6EH:6X@=.1MY"!L:6YK:VD@;W-O:71T86$`4VEN=6X@<&ETY.0@96YS
M:6X@=F%L:71A(&MO:&1E;W-O:71E:VER:F$N`%-I;G5N('!I=.3D(&5N<VEN
M('9A;&ET82!K;VAD96QI<W1A+@!3:6YU;B!P:73DY"!V86QI=&$@<&]I<W1E
M='1A=F$@<&%L=F5L:6XN`%-I;G5N('!I=.3D(&5N<VEN('9A;&ET82!A:6YA
M:VEN('EK<VD@>6AT97ES=&EE=&\N`%-I;G5N('!I=.3D(&5N<VEN('9A;&ET
M82!A:6YA:VEN('EK<VD@=&EE='5E+@!3:6YU;B!P:73DY"!A;G1A82!P;VES
M=&5T=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@<&]I
M<W1E='1A=F$@:^1Y='3D:N1T=6YN=7,N`%-I;G5N('!I=.3D(&%N=&%A(&QI
M<^1T=.1VY"!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@<.1I
M=FET971TY';D(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!V86QI=&$@
M<W5O<FET971T879A('1O:6UI;G1O+@!3:6YU;B!P:73DY"!A;G1A82!U=61E
M;B!K871E9V]R:6%N(&YI;6DN`%-I;G5N('!I=.3D(&%N=&%A(&ET86QI86QA
M:6YE;B!P=6AE;&EN;G5M97)O`%-I;G5L;&$@;VX@;VEK975D970@=F%I;B!K
M871S;V$@=.1TY"!Y:'1E>7-T:65T;V$N`$ES='5N=&]S:2`E<R!O;B!V86YH
M96YT=6YU="X@2VER:F%U9'4@=75D96QL965N('-I<^3D;BX`4^1H:_9P;W-T
M:6]S;VET=&5E<VD`4VEN=6X@;.1H971TY&KD;W-O:71T965S:3H`3VUA="!T
M:65T;W-I`%-I;G5N('1I971O:V]N965S:2!KY'ET=.1MY"!T:65T;W9E<FMK
M;RUO<V]I=&4@;VX@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T(&%L
M;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN=6X@
M<&ETY.0@:VER:F%U='5A('5U9&5S=&%A;B!JY')J97-T96QMY.1N+@!.:6UE
M<VD`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J97-T96QM
MY"!E:2!T=64@:^1Y='3D:FEE;B!L:7/DY&UI<W3D+B!*;W,@:&%L=6%T(&AA
M;&QI;FYO:61A(&OD>71TY&KD='5N;G5K<VEA+"!S:6YU;B!P:73DY"!KY'ET
M=.3D(&IO=&%K:6X@=&]I<W1A(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE
M<W1E;&WDY"X`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J
M97-T96QMY"!E:2!T=64@:^1Y='3D:N1T:65T;VIE;B!NY'ET=.1M:7-TY"!T
M86D@=.1MY"!P:6ER<F4@96D@;VQE(&IO<W1A:VEN('-Y>7-TY"!KY'ET971T
MY'9I<W/D+@!3:6YU;B!KY'ET=.1MY'-I('=W=RUS96QA:6X@;N1Y='3DY"!O
M;&5V86X@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T(&%L;VET=&%N
M=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN=6X@<&ETY.0@
M:VER:F%U='5A('5U9&5S=&%A;FKD<FIE<W1E;&WDY&XN`%-E;&%I;65S:2!E
M:2!T=64@=.1TY"!T;VEM:6YT;V$N`%-E;&%I;65S:2!E:2!T=64@=&%R=FET
M=&%V86$@='5L;W-T=7-T;VEM:6YT;V$N(%!A:6YA($-O;G1R;VPO3W!T:6]N
M("L@4"!T=6QO<W1A86MS97-I+@!!:6MA=GGV:'EK:V5E<VDZ`$]L971U<V]S
M;VET96MI<FIA<VD@96D@;VQE('-E;&%T=&%V:7-S82X`3VQE='5S<')O9FEI
M;&ES:2!O;B!M=75T971T=2X`3VQE='5S<')O9FEI;&ES:3H`3FEM97-I.@!)
M<W1U;G1O<VD@;VX@=F%N:&5N='5N=70N`%-I;G5N('-A;&%S86YA<VD@)7,Z
M;&QE(&]N.B`E<P!!<V5T=6MS97-I(&]N('#D:79I=&5T='D@:F$@;F4@;W9A
M="!V;VEM87-S82!TY&WD;B!I<W1U;FYO;B!A:F%N+@!!<V5T=6MS97-I(&]N
M('#D:79I=&5T='DN`%-A;&%S86YA<VD@;VX@;F]L;&%T='4`4V%L87-A;F%S
M:2!O;B!N;VQL871T=2P@=&%R:VES=&$@<^1H:_9P;W-T:7-I(&IA(&MI<FIA
M=61U('-I<^3D;B!U=61E;&QA('-A;&%S86YA;&QA<VDN`%-A;&%S86YA<VD@
M;VX@=F%N:&5N='5N=70N`$5TY'!A;'9E;&EM97-I.@!*=6=O<VQA=FEA`%IA
M:7)E`%-A;6)I80!::6UB86)W90!::7!P>0!;4&EI;&]T82!L86EN871T=2!T
M96MS=&E=`%M/;F=E;&UA70!;3N1Y=.0@;&%I;F%T='4@=&5K<W1I("T`6T[D
M>73D(&QA:6YA='1U('1E:W-T:2`M("5S(')I=FGD70!;<FEV:6QLY"`E<R\E
M<UT`6V5I(&%R=F]A70!?66QLY'!I=&\`7U-E;&%A`%]+;VUE;G1O='5L:VMI
M`%]9:'1E>7-T:65D;W0`7T1A=&%4<F5E`%]0;VES=&$`7U!O:7-T82!R:79I
M`%]2>6AMY'0`7T]H:F4`7TMU=F%N('1I961O="XN+@!?5'5O+U9I90!?3&ES
M=&%T`%]+:7)J875D=2!S:7/DY&X`7TMI<FIA=61U('5L;W,`7TUU;VMK86$@
M;&EN:VMIY`!/7VUA="!O<V]I=&5K:7)J870`7U5U<VD@>6AT97ES=&EE=&\`
M7T%S971U:W-E=`!?3VEK975D970`4&]I<W1A(&QI;FMK:2XN+@!?4&]I<W1A
M('3D;'3D(&QI<W1A;'1A`%](86MU`%]!<V5N;G5S`%]4875L=6MO;B!T:65D
M;W0N+BX`7TOD>71TY&KD=`!O<V]I=&5K:7)J80!V87-T86%N;W1T86IA('1U
M;G1E;6%T;VX`:V%L96YT97)I`'1Y>6YTY`!E:2!V;VD@;'5O9&$@='5L;W-T
M:65D;W-T;V$`96D@=F]I(&%U:V%I<W1A(&SD:&1E='3D`&YA<'-A=71A('3D
M<W3D`'9I<FAE(&MO;65N=&]R:79I;&SD`&%S971U<W9I<FAE`&-O;G1A8W1S
M+G9C9@!C;VYT86-T<RYC<W8`8V]N=&%C=',N8W-V`&-O;G1A8W1S+G9C9@!K
M<FEI='1I;F5N(&KD<FIE<W1E;&WD=&EE9&]S=&\@<'5U='1U=0!M=6]T;W9I
M<FAE('1I961O:7-S80!M=6]K:V%A`'1I971U971T82!E:2!L]GET>6YY=`!L
M87-K979A`'1I961O<W1O`'-U=6YN87-T82`E<R`H)7,I(&YO<&5U9&5L;&$@
M)7,@)7,`<'5U<VMI='1A:6X`:#H`:&@`='5N=&5M871O;B!P86QV96QI;65N
M(&YI;6D`=N1L:71T]FWD<W1I`&EN;&EN90!I;RUV:7)H90!O:&IE;&UI<W1O
M;B!S:7/D:6YE;B!V:7)H90!R:79I=%T`;6MI<V]F<R!V:7)H96MO;V1I("5D
M($E33SIA('1E:&1E<W/D+@!M;0!N:6UI`&5I(&UU;W1O:6QU80!%:2!M:73D
MY&X`96D@;VQE('1O=&5U=&5T='4`96D@;VQE('9I96SD('1O=&5U=&5T='4`
M;75I<W1I;&ES=&$`<')O<V5N='1I`&OD>71T]B!K:65L;&5T='D`<&EK<V5L
M96ETY`!E=.1V:7)H92!P<F]T;VMO;&QA<W-A`&YO=7-E=F$`<&%L=F5L=2!E
M:2!O;&4@:^1Y=&5T=.1V:7-SY`!NY'ETY"!E<F]T`'-M<S)E;6%I;"!(5%10
M.FX@879U;&QA`'-S`'9A:V%A`&KD<FIE<W1E;&WD=FER:&4`=&5H=.1VY&QI
M<W1A`';D;&EA:6MA:6YE;B!V:7)H90!Y:'1E>7-T:65T;VQI<W1A86X`97)I
M(&]S;VET96MI<FIA86X`=F%R;6ES=&%A:W-E<VD@:VER:F]I=&$@<V%L87-A
M;F$@:V%H9&5S=&D`=6YI9FEE9`!N:6UE=/9N`&OD>71TY&KD;B!V86QI;G1A
M`'9#87)D`'<Z`'=E871H97(N8V]M````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C
M86QE+V9I7T9)+VAE;'`N>&UL````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q-#8T,0`Q,#0Q-S,V,C<U-0`P,C$T,S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP
M(C\^"CPA+2T@)$AO<F1E.B!T=7)B82]L;V-A;&4O9FE?1DDO:&5L<"YX;6PL
M=B`Q+C0N,3`N,R`R,#`V+S`R+S(P(#$Q.C(P.C0T(&IA;B!%>'`@)"`M+3X*
M/&AE;'`^"B`@/&5N=')Y(&ED/2)/=F5R=FEE=R(@;60U/2(R.3`U,#9A9&4T
M939F-S0Y,C0V9C<W8F)E-60T.#@S-2(@<W1A=&4](G5P=&]D871E(CX*("`@
M(#QT:71L93Y9;&5I<VMU=F$\+W1I=&QE/@H@("`@/&AE861I;F<^17-I='1E
M;'D\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]S;VET96MI<FIA86X@=F]I
M="!T86QL971T86$@:V%I:VMI('EH=&5Y<W1I961O="!S:71E;B!E='0F(WA%
M-#L@;F4*("`@(&]V870@86EN82!K)B-X130[=&5V)B-X130[<W1I('-A871A
M=FEL;&$@:F$@:R8C>$4T.WET971T)B-X130[=FES<R8C>$4T.RX@4FEI<'!U
M96X@;6ET96X*("`@(&]H:F5L;6ES=&\@;VX@87-E;FYE='1U+"!S:6YU;B!O
M;B!M86AD;VQL:7-T82!T96AD)B-X130["B`@("!H96YK:6PF(WA&-CMK;VAT
M86EN96X@;W-O:71E:VER:F$@=&%I(&LF(WA%-#MY='0F(WA%-#LF(WA%-#L@
M:G5L:VES:6$@;W-O:71E:VER:F]J80H@("`@=&%I(&AA:V5M:7-T;W!A;'9E
M;'5J82X@5F]I="!M>28C>$8V.W,@=&5H9"8C>$4T.R!O;6EA(&QI<W1O:F$L
M(&IO=&MA(&]V870*("`@(&LF(WA%-#MY="8C>$4T.VYN)B-X1C8[<W,F(WA%
M-#L@<VEN=6X@;VUI82!S)B-X130[:&LF(WA&-CMP;W-T:6QI<W1O:F$N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)M96YU+6%D9"(@;60U
M/2(S8S%F.3)E8C%A.#(X,SDT,#1D,3%D.6(P83(P8C-C92(@<W1A=&4](G5P
M=&]D871E(CX*("`@(#QT:71L93Y686QI:VMO.B!,:7,F(WA%-#LF(WA%-#L\
M+W1I=&QE/@H@("`@/&AE861I;F<^3&ES)B-X130[)B-X130[/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!6;VET(&QI<R8C>$4T.W0F(WA%-#L@:R8C>$4T
M.WET="8C>$4T.VHF(WA%-#MN('1I961O="!O<V]I=&5K:7)J86%N+B!6;VET
M(&QI<R8C>$4T.W0F(WA%-#L@;W-O:71T96ET82!V86EN"B`@("!N:6EH:6X@
M;W-O:71E:VER:F]I:&EN+"!J;VEH:6X@<VEN=6QL82!O;B!K:7)J;VET=7-O
M:6ME=7,N($IO<PH@("`@:R8C>$4T.WET)B-X1C8[<W,F(WA%-#L@;VX@:F%E
M='1U:F$@=&%I(&IU;&MI<VEA(&]S;VET96MI<FIO:F$L(&YI:6X@;B8C>$4T
M.VTF(WA%-#L@;VX*("`@('EL965N<R8C>$4T.R!J865T='4@=F%I;B!L=6MU
M+W-E;&%U<V]I:V5U:W-I;&QA(&IA(&5T('9O:2!L:7,F(WA%-#MT)B-X130[
M(&YI:6AI;@H@("`@;W-O:71T96ET82X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](FUE;G4M<V5A<F-H(B!M9#4](CAD868X,6%B,C@V,#)D
M-S<R,S4X83$W-#4W,68Y860R(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/E9A;&EK:V\Z($AA:W4\+W1I=&QE/@H@("`@/&AE861I;F<^2&%K=3PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5F]I="!H86ME82!T:65T;VIA(&]S
M;VET96MI<FIA<W1A+B!4)B-X130[;28C>$4T.R!O;B!P:6MA:&%K=2!J82!V
M;VET(&5T<VDF(WA%-#L*("`@('1I971O:F$@=F%I;B!M=75T86UA;B!K96YT
M)B-X130[;B!P97)U<W1E96QL82X@2R8C>$4T.WET)B-X130[;FXF(WA&-CMS
M<R8C>$4T.R!N)B-X130[;28C>$4T.PH@("`@971S:71T)B-X130[=B8C>$4T
M.W0@:V5N="8C>$4T.W0@;W9A="!N:6UI('1A:2!S)B-X130[:&LF(WA&-CMP
M;W-T:6]S;VET92P@;75T=&$@<FEI<'!U96X*("`@('EL;"8C>$4T.W!I9&]N
M(&%S971T86UI<W1A(&%S971U:W-I<W1A(&LF(WA%-#MY="8C>$8V.W-S)B-X
M130[('9O:2!O;&QA(&UY)B-X1C8[<PH@("`@;75I=&$@:V5N='1I)B-X130[
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!*;W,@<VEN=6X@<&ET)B-X
M130[)B-X130[(&5T<VDF(WA%-#L@;W-O:71E:VER:F%S=&$@:R8C>$4T.WET
M="8C>$4T.V5N('1A<FME;7!I80H@("`@:&%K=71E<FUE:B8C>$4T.RP@;FEI
M;B!V;VET(&LF(WA%-#MY='0F(WA%-#LF(WA%-#L@(CQR968@;6]D=6QE/2)T
M=7)B82(@96YT<GD](FUE;G4M861V86YC960M<V5A<F-H(CY487)K96UP:2!H
M86MU/"]R968^(B`M=&]I;6EN=&]A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB;65N=2UA9'9A;F-E9"US96%R8V@B(&UD-3TB-F)E-S`S
M9F9E8F$V,31F-F%D83$U,3<T.69A-#1A8C4B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^5F%L:6MK;SH@5&%R:V5M<&D@:&%K=3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY487)K96UP:2!H86MU/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!6;VET(&AA:V5A('1I971O:F$@;W-O:71E:VER:F%S=&$N(%0F(WA%
M-#ML;"8C>$4T.R!T;VEM:6YN;VQL82!V;VET(&AA:V5A"B`@("!O<V]I=&5K
M:7)J87-T82!K)B-X130[>71T)B-X130[96X@;6]N:6$@:V5N='1I)B-X130[
M+B!+)B-X130[>71E='0F(WA%-#MV:7-S)B-X130[(&]L979A="!K96YT)B-X
M130[=`H@("`@<FEI<'!U=F%T('-I:70F(WA%-#L@;6ES="8C>$4T.R!O<V]I
M=&5K:7)J87-T82!T:65T;VIA(&AA971A86XN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)M96YU+6EM<&]R="(@;60U/2(S8S9C-#!F,F$V
M,C$S93EF8S%F.6$W-S@R-V)F8C5D-"(@<W1A=&4](G5P=&]D871E(CX*("`@
M(#QT:71L93Y686QI:VMO.B!4=6\O5FEE/"]T:71L93X*("`@(#QH96%D:6YG
M/E1U;R]6:64\+VAE861I;F<^"@H@("`@/'!A<F$^"B`@("!4)B-X130[<W0F
M(WA%-#L@=F%L:6MO<W1A('9O:70@='5O9&$@=&%I('9I960F(WA%-#L@=&EE
M=&]J82!H96YK:6PF(WA&-CMK;VAT86ES97-T80H@("`@;W-O:71E:VER:F%A
M<W1A+B!6;VET(&LF(WA%-#MY='0F(WA%-#LF(WA%-#LF(WA%-#L@0U-6("A#
M;VUM82!397!A<F%T960@5F%R:6%B;&4I+`H@("`@3W5T;&]O:R!T86D@=D-A
M<F0@=&EE9&]S=&]M=6]T;VIA+@H@("`@/"]P87)A/@H*("`@(#QH96%D:6YG
M/E1U;VYT:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5'5O9&%K<V5S:2!T
M:65T;VIA(&]S;VET96MI<FIA86XL('-I;G5L;&$@<&ET)B-X130[)B-X130[
M(&]L;&$@='5O=&%V870*("`@('1I961O="!T:65D;W-T;VYA('!A:6MA;&QI
M<V5L;&$@=&EE=&]K;VYE96QL82`H<VEL;"8C>$4T.R!K;VYE96QL82P*("`@
M(&IO;&QA(&LF(WA%-#MY="8C>$4T.W0@=W=W+7-E;&%I;G1A*2X@16YS:6X@
M<VEN=6X@:W5I=&5N:VEN('!I="8C>$4T.R8C>$4T.R!V:65D)B-X130["B`@
M("!O<V]I=&5K:7)J871I961O="!K)B-X130[>71T)B-X130[;28C>$4T.W-T
M)B-X130[<VD@<R8C>$4T.VAK)B-X1C8[<&]S=&EO:&IE;&UA<W1A+@H@("`@
M/"]P87)A/@H*("`@(#QP87)A/@H@("`@2F]S(&LF(WA%-#MY="8C>$4T.W0@
M3W5T;&]O:R!%>'!R97-S("UO:&IE;&UA83H*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@,2D@3F%P<V%U=&$@1FEL92`F9W0[($5X<&]R="`F9W0[($%D
M9')E<W,@0F]O:PH@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`R*2!686QI
M='-E(")497AT($9I;&4B("A#;VUM82!397!A<F%T960@5F%L=65S*2`B061D
M<F5S<R!";V]K($5X<&]R="!4;V]L(B!A<'5O:&IE;&UA<W-A+B!.87!S875T
M82`B17AP;W)T(BX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@,RD@(E-A
M=F4@97AP;W)T960@9FEL97,@87,B(&ME;G1T)B-X130[)B-X130[;BP@:VER
M:F]I=&$@;W-O:71E:VER:F%S:2!N:6UI+B!.87!S875T82`B3F5X="(N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#0I(%9A;&ET<V4@=F%S96UM86QL
M82!O;&5V87-T82!V86QI;G1A;&%A=&EK;VQL82!K86EK:VD@;F4@:V5N="8C
M>$4T.W0L(&IO=&MA(&AA;'5A="!V:65D)B-X130[+B!.87!S875T82`B1FEN
M:7-H(BX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@-2D@4VEN=6QL92!P
M:70F(WA%-#MI<VD@;GET('1U;&QA('9I97-T:2`G061D<F5S<R!B;V]K(&5X
M<&]R="!P<F]C97-S(&AA<R!C;VUP;&5T960G+B!.87!S875T82`G3TLG+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`V*2!.87!S875T82`G0VQO<V4G
M(&%P=6]H:F5L;6%S<V$@)T%D9')E<W,@0F]O:R!%>'!O<G0@5&]O;"<@:F$@
M<W5L:F4@3W5T;&]O:R!%>'!R97-S("UO:&IE;&UA+@H@("`@/"]P87)A/@H*
M("`@(#QT:7`^"B`@("!*;W,@=FEE='D@;W-O:71E:VER:F%T:65D;W-T;R!E
M:2!O;&4@<VEN=6X@='DF(WA&-CMP)B-X1C8[>60F(WA%-#ML;"8C>$4T.W-I
M+"!J82!K)B-X130[>70F(WA%-#MT(%=I;F1O=W,@:R8C>$4T.WET="8C>$8V
M.VHF(WA%-#MR:F5S=&5L;28C>$4T.R8C>$4T.RP@;FEI;B!N87!S875T82!3
M=&%R="`F9W0[($9I;F0@;W(@4V5A<F-H("9G=#L@1FEL97,@;W(@1F]L9&5R
M<R!J82!H864@,RX@:V]H9&%S<V$@:V%L96YT97)I=&EE9&]S=&]L;&4@86YT
M86UA87-T:2!T:65D;W-T;VX@;FEM928C>$4T.R!K:6EN=&]L979Y;'0F(WA%
M-#LN($]T82!T86QT965N('1I971O('-I:70F(WA%-#L@;6EH:6X@='5O('1I
M961O<W1O(&]N('1A;&QE=&5T='4N"B`@("`\+W1I<#X*"B`@("`\<&%R83X*
M("`@(%1U;V1A:W-E<VD@;W-O:71E:VER:F%N(&]H:F5L;6%A;BP@;FEI;B!A
M=F%A(&5N<VEN(&]S;VET96MI<FIA"B`@("!J;VAO;B!T=6]T('1I971O:F$N
M($YA<'-A=71A(")4=6\O5FEE(B`M:6MO;FEA+B!686QI='-E('1U;VYN:7-S
M80H@("`@:R8C>$4T.WET971T)B-X130[=B8C>$4T.R!T:65D;W-T;VUU;W1O
M+B!.87!S875T82`B4V5L86$B("UP86EN:6ME='1A(&IA('9A;&ET<V4*("`@
M('!A:6MA;&QI<V5L=&$@=&EE=&]K;VYE96QT82!T=6]T879A(&]S;VET96MI
M<FIA=&EE9&]S=&\N(%9A;&ET<V4*("`@('1I961O<W1O(&IA(&YA<'-A=71A
M(")4=6\B("UP86EN:6ME='1A+B!4)B-X130[;28C>$4T.VX@:B8C>$4T.VQK
M965N('1I961O=`H@("`@<&ET)B-X130[:7-I(&EL;65S='DF(WA%-#L@;W-O
M:71E:VER:F%A<VDN"B`@("`\+W!A<F$^"B`@("`\=&EP/@H@("`@2F]S('1I
M961O<W1O<W-A(&]N(&UO;FEM=71K86ES96UP:6$@;65R:VEN="8C>$8V.VHF
M(WA%-#L@=&%I(&ME;G1T:28C>$4T.RP@:F]T:V$*("`@(&5I=B8C>$4T.W0@
M="8C>$4T.W-M)B-X130[)B-X130[(&]S;VET96MI<FIA;B!K96YT=&EE;B!K
M86YS<V$L(&YI:6X@=&EE=&\@96D*("`@('8F(WA%-#ML='0F(WA%-#MM)B-X
M130[='0F(WA%-#L@<VEI<G)Y(&]I:V5I;BX@4VEN=6X@:V%N;F%T=&%A(&%I
M;F$@=&%R:VES=&%A"B`@("!O<V]I=&5K:7)J86%N('1U;V1U="!T:65D;W0N
M"B`@("`\+W1I<#X*/"]E;G1R>3X*("`\96YT<GD@:60](G-E87)C:&EN9RUS
M96%R8VA?<F5S=6QT<R(@;60U/2)F9F5D.&0W,F9A,V(W,3!D9CAE.3`R8S(T
M.3-B,C4T9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y(86MU.B!(
M875N('1U;&]K<V5T/"]T:71L93X*("`@(#QH96%D:6YG/DAA=6X@='5L;VMS
M970\+VAE861I;F<^"B`@("`\<&%R83X*("`@($IO<R!H86MU(&]N;FES='5I
M+"!N:6EN('1U;&]K<V5T('!I="8C>$4T.VES:2!N)B-X130[:WDF(WA%-#L@
M:V]H9&%S<V$@(DAA=6X@='5L;VMS970B+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("!.87!S875T=&%M86QL82`B4R8C>$4T.VAK)B-X1C8[<&]S=&EO
M<V]I=&4B("UK96YT)B-X130[)B-X130[(&%V875T=74@=FEE<W1I;FMI<FIO
M='5S:6MK=6YA+"!J82!V;VET(&PF(WA%-#MH971T)B-X130[)B-X130[('9I
M97-T:6X@<VEI:&5N(&]S;VET=&5E<V5E;BX@3F%P<V%U='1A;6%L;&$@(DYI
M;6DB("UK96YT="8C>$4T.R8C>$4T.R!T=6QE92!N)B-X130[:WEV:6EN(&]S
M;VET96MI<FIA;65R:VEN;B8C>$4T.VX@=&EE9&]T(&IA('9O:70@;75O:V%T
M82!T86D@<&]I<W1A82!M97)K:6YN)B-X130[;BX*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@4FEI<'!U96X@>6QL)B-X130[<&ED;VX@87-E='1A;6ES
M=&$@87-E='5K<VES=&$@:&%K=71U;&]S('9O:2!O;&QA(&MU;75L871I:79I
M;F5N+B!4)B-X130[;28C>$4T.R!T87)K;VET=&%A(&5T="8C>$4T.R!J;VMA
M:7-E;B!H875N('1U;&]S(&QI<R8C>$4T.W0F(WA%-#LF(WA%-#MN(&]L96UA
M<W-A(&]L979I:6X@='5L;VMS:6EN+B!4)B-X130[;28C>$4T.R!V;VD@;VQL
M82!K)B-X130[=&5V)B-X130[)B-X130[+"!J;W,@97-I;65R:VEK<VD@;VQE
M="!T96ME;28C>$4T.W-S)B-X130[(&QI<W1O:F$N(%9O:70@<&]I<W1A82!H
M86MU:F5N('1U;&]K<V5T(&YA<'-A=71T86UA;&QA(")4>6AJ96YN)B-X130[
M(&AA:W4B("UL:6YK:VDF(WA%-#LN"B`@("`\+W!A<F$^"@H@("`@/'1I<#X*
M("`@($QI<W1A82!O;B!M86AD;VQL:7-T82!L86II=&5L;&$@;6EN:R8C>$4T
M.R!T86AA;G-A('-A<F%K:V5E;B!M=6MA86X@;F%P<V%U='1A;6%L;&$@<V%R
M86MK965N(&]T<VEK:V]A+B!6;VET(&UU=71T86$@;&%J:71T96QU82!N;W5S
M979A:W-I('1A:2!L87-K979A:W-I(&YA<'-A=71T86UA;&QA(&]T<VEK;VX@
M=FEE<F5S<R8C>$4T.R!O;&5V86$@;G5O;&D@:6MO;FEA+@H@("`@/"]T:7`^
M"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1U<F)A+VQO8V%L92]E=%]%12\`````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-34`,#$W-S8S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+V5T7T5%+TQ#7TU%
M4U-!1T53+P``````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<U-0`P,C$U-3``(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L
M;V-A;&4O971?144O3$-?34534T%'15,O='5R8F$N;6\`````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#(P-#$W`#$P-#$W,S8R-S4U`#`R,S(R,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#>$@25`````(T````<````
MA`0``+\```#L"````````.@+```H````Z0L``!T````2#```"````#`,```%
M````.0P```,````_#```#P```$,,```(````4PP```@```!<#```&0```&4,
M```'````?PP```X```"'#```#P```)8,```?````I@P``"<```#&#```+```
M`.X,```J````&PT``!$```!&#0``!@```%@-```(````7PT```8```!H#0``
M%0```&\-```*````A0T```P```"0#0``#@```)T-```'````K`T``!````"T
M#0``*0```,4-```"````[PT```4```#R#0``$````/@-```&````"0X```\`
M```0#@``%````"`.```O````-0X```D```!E#@``#P```&\.```F````?PX`
M``0```"F#@``!0```*L.```-````L0X```4```"_#@``$````,4.```0````
MU@X```\```#G#@``"P```/<.```/`````P\```P````3#P``#P```"`/```&
M````,`\``"$````W#P``(@```%D/```#````?`\```P```"`#P``!````(T/
M```$````D@\``!0```"7#P``!@```*P/```$````LP\```P```"X#P``"@``
M`,4/```%````T`\``!(```#6#P``$````.D/```(````^@\```0````#$```
M$`````@0```:````&1````8````T$```!P```#L0```"````0Q````0```!&
M$```"````$L0```/````5!````<```!D$```!P```&P0```'````=!````0`
M``!\$```!P```($0```%````B1```!H```"/$```!0```*H0```'````L!``
M`!$```"X$```"````,H0```5````TQ```!X```#I$```&@````@1```%````
M(Q$``"@````I$0``*0```%(1```3````?!$```0```"0$0``!@```)41```+
M````G!$``!$```"H$0``!````+H1```$````OQ$```P```#$$0``!@```-$1
M```:````V!$``!<```#S$0``&@````L2```7````)A(``!L````^$@``-```
M`%H2```9````CQ(``!\```"I$@``$P```,D2```$````W1(``!````#B$@``
M%P```/,2```'````"Q,```4````3$P``(0```!D3```<````.Q,```4```!8
M$P``(````%X3```D````?Q,``"8```"D$P``$P```,L3```,````WQ,```@`
M``#L$P``%````/43```'````"A0```8````2%```#0```!D4```+````)Q0`
M``P````S%```"@```$`4```"````2Q0```8```!.%```10```%44```F````
MFQ0``"4```#"%```,````.@4```0````&14``',````J%0``'P```)X5```0
M````OA4```\```#/%0``70$``-\5```9````/1<``!@```!7%P``"````'`7
M```%````>1<```0```!_%P``$@```(07```)````EQ<```T```"A%P``(0``
M`*\7```'````T1<```8```#9%P``#P```.`7```;````\!<``"`````,&```
M'@```"T8```:````3!@``!(```!G&```!0```'H8```(````@!@```4```")
M&```!0```(\8```-````E1@```D```"C&```#````*T8```%````NA@``!``
M``#`&```*0```-$8```"````^Q@```@```#^&```#P````<9```'````%QD`
M`!<````?&0``$@```#<9```H````2AD```@```!S&0``!0```'P9```N````
M@AD```<```"Q&0``!@```+D9```0````P!D```0```#1&0``%````-89```5
M````ZQD``!,````!&@``$P```!4:```6````*1H```P```!`&@``#P```$T:
M```'````71H``"(```!E&@``(0```(@:```$````JAH```L```"O&@``!```
M`+L:```'````P!H```\```#(&@``!@```-@:```#````WQH```X```#C&@``
M#@```/(:```%`````1L``!,````'&P``$@```!L;```$````+AL```@````S
M&P``&````#P;```G````51L```H```!]&P``"@```(@;```"````DQL```,`
M``"6&P``#@```)H;```.````J1L```<```"X&P``!0```,`;```)````QAL`
M``0```#0&P``!````-4;```,````VAL``"4```#G&P``!P````T<```)````
M%1P```@````?'```"````"@<```:````,1P``!,```!,'```#0```&`<```'
M````;AP``!,```!V'```)````(H<```3````KQP```,```##'```!P```,<<
M```,````SQP``!(```#<'```!````.\<```(````]!P``!(```#]'```!@``
M`!`=```7````%QT``!8````O'0``%0```$8=```6````7!T``!@```!S'0``
M-0```(P=```0````PAT``!0```#3'0``&0```.@=```%`````AX``!,````(
M'@``$P```!P>```*````,!X```0````['@``(````$`>```?````81X```0`
M``"!'@``'@```(8>```B````I1X``"H```#('@``#@```/,>```2`````A\`
M``P````5'P``%````"(?```'````-Q\```P````_'P``$@```$P?```1````
M7Q\```H```!Q'P``"@```'P?```"````AQ\```L```"*'P``+@```)8?```I
M````Q1\``"8```#O'P``-0```!8@```)````3"```'<```!6(```'P```,X@
M```0````[B````\```#_(````0```%P```!0````A`````8`````````#@``
M````````````$0```!T```!-````1````#D`````````%@```'<```!O````
M8P```````````````````(T`````````!````$8```!^````#0```#8`````
M`````````&4````R````)@```'D`````````*`````4`````````AP```&L`
M```+````:````'8````O`````````&X````?````&``````````*````````
M`#,```!S`````@```%<`````````0`````@```![````5````(D````/````
M4@```&``````````+```````````````8@```'0````)`````````$X`````
M````>````(P````T````6P`````````M````>@```'(```!9````%0``````
M``!L````:@```"<````<`````````((``````````````'`````A````````
M`#P```!=````/P`````````B````&0`````````I````B````!0`````````
M20`````````U````7@````P`````````9@```&D```!M````40```(H````W
M````2P```%@```!(````9P```%4```!]````?P``````````````@````#``
M````````&P``````````````$`````<`````````.@```"4````J````3P``
M`$,````7````+@``````````````'@`````````2````?`````````!"````
MA@````````"!````.`````````!U````4P```!H```!A````6@```$<````@
M`````````"L```!Q````9``````````]````10```(4`````````2@```"0`
M``"#``````````,````C`````````!,```!,````5@```#L````^````,0``
M`(L```!?````00``````````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``R
M-"!H;W5R<P!!32]030!!9&0`061D(&$@;F5W('5S97(Z`$%D9"!P86ER`$%D
M9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&UI
M;FES=')A=&EO;@!!9'9A;F-E9"!396%R8V@`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN`$%V86EL86)L92!F:65L9',Z`$)R;W=S90!#86QE;F1A<@!#86YC
M96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN
M9&]W`$-O;'5M;B!/<'1I;VYS`$-O;7!A;GD`0V]N9FER;2!087-S=V]R9`!#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!$1`!$
M86EL>0!$969A=6QT($ED96YT:71Y`$1E;&5T90!$96QE=&EO;B!F86EL960`
M1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@3W!T
M:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%
M9&ET`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E
M<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I
M;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S
M.@!%>'!O<G0`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,`1F%X`$9I;&4@36%N
M86=E<@!&:6YD`$9R;VT`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7!S`$AE
M;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`26UP;W)T960@9FEE
M;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N9W5A9V4`3&ES=`!,:7-T($AE
M;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO9R!I;@!,
M;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<`36%T8VAI;F<@9FEE;&1S`$UE;6)E
M<G,`365S<V%G90!-;VYT:&QY`$YA;64`3F5T=V]R:P!.979E<@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;W1E<P!/<'1I;VYS`$]T:&5R($EN9F]R
M;6%T:6]N`%!A<W-W;W)D`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VX`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E860`4F5M;W9E`%)E;6]V92!P
M86ER`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V90!3879E($]P=&EO;G,`
M4V5A<F-H`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E
M<W,@;&ES=',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-H
M;W<`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M=6-C97-S`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N=`!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5
M<V5R;F%M90!5<V5R<R!I;B!T:&4@<WES=&5M.@!787)N:6YG`%=E96ML>0!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H
M;VYE`%E9`%EE87)L>0!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO
M;@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E
M<UT`4')O:F5C="U)9"U697)S:6]N.B!4=7)B82`R+C`M8W9S"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-"TP-BTP,B`Q,#HT.2LP,C`P"DQA<W0M5')A;G-L871O<CH@5&]O
M;6%S($%A<R`\=&]O;6%S+F%A<T!M86EL+F5E/@I,86YG=6%G92U496%M.B!%
M<W1O;FEA;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3$S"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`E<R!(;V]L
M9'5S=/;V9"`M(&MI;FYI='5S`"5S(&9A:6QI(&EM<&]R="#U;FYE<W1U<P`R
M-"!T=6YD:0!%3"]03`!,:7-A`$QI<V$@=75S(&MA<W5T86IA.@!,:7-A('!A
M87(`3&ES82!K87-U=&%J80!+87-U=&%J871E(&QI<V%M:6YE('!O;&4@;'5B
M871U9"X`06%D<F5S<P!(86QD=7,`4/5H:F%L:6L@;W1S:6YG`%-I<V5S=&%T
M:2!L=6)A;6%T=2!VY.1R='5S+@!+871S92!K=7-T=71A9&$@;VQE;6%T=70@
M9W)U<'!I+@!+871S92!K=7-T=71A9&$@;VQE;6%T=70@;'5B82X`2V%T<V4@
M;75U=&$@;VQE;6%T=70@;'5B82X`2V%S=71A=&%V860@=N1L:F%D`%-I<G9I
M`$MA;&5N9&5R`$QO;V)U`$QO;V)U`$UO8FEI;'1E;&5F;VX`4W5L92!A:V5N
M`%9E97)U('-E861E9`!&:7)M80!+:6YN:71A('-A;&%S]6YA`$5I('-U=61A
M(&OD:79I=&%D82!H;V]L9'5S=/;V(&UO;V1U;&ET("5S`%!0`$EG82!PY&5V
M`%9A:6ME:61E;G1I=&5E=`!+=7-T=71A`$MU<W1U=&%M:6YE(&5B8?5N;F5S
M='5S`$MI<FIE;&1A('!R;V)L965M:0#<:W-I:V%S:F%D(&QO9VET:2!A9&UI
M;FES=')A871O<FD@:F%O:W,N`$MA=&%L;V]G`$[D:71A`,1R82#\<FET82!M
M86EN=&5N86YC92YP:'`@9F%I;&D@;W1S92!KY&EV:71A9&$`4&%R86YD80!%
M+6UA:6P`5'5L96UU<R!O;B!T_&AI+@!6:6=A`$EG82`Q-2!M:6YU=&D@=&%G
M86YT`$EG82`S,"!S96MU;F1I('1A9V%N=`!)9V$@-2!M:6YU=&D@=&%G86YT
M`$EG86P@<VES<V5L;V=I;6ES96P`26=A('!O;VQE('1U;FYI('1A9V%N=`!+
M;W)D(&UI;G5T:7,`3N1I9&ES=N3D<G1U<V5D`$5K<W!O<G0`16D@<V%A;G5D
M(/QH96YD=7-T($Q$05`@<V5R=F5R:6=A+@!/='-I;F<@:V%T86QO;V=I<W0@
M)7,@96)A]6YN97-T=7,`1F%K<P!&86EL:6AA;&1U<@!,96EA`$ME;&QE;'0`
M1W)U<'!I9&4@:&%L9'5S`$=R=7!I9`!!8FD`2V]D=6YE(&%A9')E<W,`2V]D
M=6YE('1E;&5F;VX`2&]R9&4`26UP;W)D:71U9"!VY&QI.B`E<P!);7!O<F1I
M='5D(';D;&IA9#H`2V5E;`!.:6UE:VER:0!!8FEI;F9O('1E96UA9&4@;FEM
M96MI<FD`2V%S=71A:F%T92!N:6UE:VER:F$@<&]L92!L=6)A='5D(&[D:&$N
M`$QO9VD@<VES<V4`3&]G:2!VY&QJ80!+2P!)35``(&UI<R!S:7-A;&1A8B``
M4V]B:79A9"!VY&QJ860`3&EI:VUE9`!496%D90!+;W)D(&MU=7,`3FEM:0!6
M]7)K`$UI='1E(&MU;F%G:0!%:2!T86=A<W1A='5D(&MO<G)E:W1S96ED(%A-
M3"!A;F1M96ED`$WD<FMM960`2.3D;&5S='5S`$UU=2!I;F9O`%-A;&%S]6YA
M`%-A;&%S]6YA9"!P96%V860@:VQA<'!I;6$N`$OD:79I=&$@:&]O;&1U<W3V
M]F0`3'5B861E(&AA;&1U<P!496QE9F]N`$MI<FIE;&1A('!R;V)L965M:2X`
M4VES97-T82!O;6$@:V%S=71A:F%N:6UI(&IA('-A;&%S]6YA`%!R;V)L965M
M:2!K:7)J96QD=7,`3&]E`$5E;6%L9&$`165M86QD82!P86%R`%1A9V%S:2!H
MY.1L97-T=7-S90!2;VQL`%-A;'9E<W1A`%-A;'9E<W1A(&CDY&QE<W1U<P!/
M='-I;F<`5F%L:2!K=75PY&5V82!E<F%L9&%J83H`5F%L:2!K=75PY&5V82!F
M;W)M86%T.@!686QI(&EM<&]R9&ET878@9F%I;#H`5F%L:2!K96QL86%J82!F
M;W)M86%T.@!686QI(&MA:W,@<V]B:79A="!VY&QJ82X`5F%L:2!M:6QL:7-E
M:60@=N1L:G4@;N1I9&%T82!A861R97-S:61E(&YI;65K:7)J861E<RX`5F%L
M:2!VY')V:7-K965M+@!686QI(&]M82!L96UM:6MK965L.@!386%D82!P<F]B
M;&5E;6D@:VER:F5L9'5S`$[D:71A`$KD=&$@:&]O;&1U<R!V86AE;&4`17)I
M;>1R:VED92!S:7-E<W1U<P!,Y&MS(&MO<F1A`%3V]F0`4V5E(&%R=B!P96%B
M(&]L96UA(';D:&5M86QT(/QK<RX`4V5L;&4@:V]H82!P96%L('!E86(@;VQE
M;6$@87)V+@!!;65T`$5I('-A82#\:&5N9'5S="!344P@<V5R=F5R:6=A+@!%
M:2!S=75D82!L86%D:61A("5S(&1E9FEN:71S:6]O;FDN`%-E9&$@5V]R9&D@
M9&]K=6UE;G1I(&]N(';U:6UA='4@=/5L9V5N9&%D80!+87-U=&%J86AA;&1U
M<P!+87-U=&%J82!HY.1L97-T=7,`2V%S=71A:F%N:6UI`$MA<W5T86IA9"!S
M_'-T965M:7,Z`$AO:6%T=7,`2V]R9"!NY&1A;&%S`%1E<F4@='5L96UA<W0@
M)7,M:0!497)E('1U;&5M87-T+"`E<P!4]O9A861R97-S`%3V]G1E;&5F;VX`
M04$`2V]R9"!A87-T87,`16YN92!S86%T;6ES="!O;&5K<R!T87)K('!R;V)L
M965M:2!K:7)J96QD861A+@!096%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI
M9&$@965M86QD861A+@!096%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@
M;&ES861A+@!3:6YU("5S('-E<W-I;V]N(&]N(&%E9W5N=60N(%!A;'5N(&QO
M9VD@=75E<W1I('-I<W-E+@!3:6YU(&EN9F\`4VEN=2!A=71E;G1I;6ES<_QS
M=&5E;2!E:2!V]6EM86QD82!K87-U=&%J871E(&YI;65K:7)J82!NY&AA+"!V
M]6D@;VX@<V5E(';U:6UA;'5S(&UI;F=I;"!M=75L('#U:&IU<V5L(';D;&IA
M(&S\;&ET871U9"X`4VEN=2!M=75D871U<V5D(&]N('-A;'9E<W1A='5D+@!;
M2&]R9&4@<')O8FQE96U=`%MR:61A("5S("5S+7-T70``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O9G)?
M1E(O````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S4U`#`R,#`P,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1U<F)A+VQO8V%L92]F<E]&4B],0U]-15-304=%4R\`````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-34`,#(Q-38U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+V9R7T92+TQ#7TU%4U-!
M1T53+W1U<F)A+FUO````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#4P,#(V,@`Q,#0Q-S,V
M,C<U-0`P,C,R-#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````"*"```'````&Q$``!E"P``O(@```````!0M@``
M#@```%&V```/````8+8```T```!PM@``"````'ZV```+````A[8```P```"3
MM@``&0```*"V```9````NK8```0```#4M@``*0```-FV```8`````[<``!L`
M```<MP``+0```#BW```=````9K<``"0```"$MP``*0```*FW```I````T[<`
M`!D```#]MP``*````!>X```D````0+@``"4```!EN```)@```(NX```,````
MLK@``"0```"_N```#P```.2X```+````]+@```X`````N0``!0````^Y```H
M````%;D```@````^N0``"@```$>Y```5````4KD```D```!HN0``$@```'*Y
M```+````A;D``!T```"1N0``A0```*^Y```.````-;H```H```!$N@``#0``
M`$^Z```.````7;H``!$```!LN@``#0```'ZZ```,````C+H```T```"9N@``
M!@```*>Z``"4````KKH```H```!#NP``#P```$Z[```8````7KL```P```!W
MNP``#@```(2[```.````D[L```@```"BNP``"0```*N[```K````M;L``"X`
M``#ANP``&@```!"\```R````*[P``#@```!>O```5````)>\``!1````[+P`
M`%H````^O0``5P```)F]```T````\;T```D````FO@``#0```#"^```'````
M/KX```H```!&O@``#P```%&^```%````8;X```8```!GO@``$0```&Z^```(
M````@+X``!$```")O@``"0```)N^```)````I;X``"4```"OO@``(````-6^
M```3````]KX``!,````*OP``$````!Z_```/````+[\```H````_OP```P``
M`$J_```/````3K\``!0```!>OP``"0```'._```-````?;\``!(```"+OP``
M&0```)Z_```>````N+\```\```#7OP``$````.>_```A````^+\```H````:
MP```"````"7````/````+L````@````^P```)````$?````&````;,```!0`
M``!SP```%@```(C````(````G\```$X```"HP```+0```/?````A````)<$`
M`!D```!'P0``!P```&'!```,````:<$``!0```!VP0``#0```(O!```2````
MF<$``"$```"LP0``%P```,[!```I````YL$``"P````0P@``#@```#W"```#
M````3,(```\```!0P@``"P```&#"```'````;,(```<```!TP@``!0```'S"
M```%````@L(```H```"(P@```P```)/"```7````E\(```H```"OP@``#P``
M`+K"```.````RL(``!@```#9P@``(P```/+"```.````%L,```X````EPP``
M%````#3#```7````2<,``!<```!APP``%P```'G#```3````D<,```\```"E
MPP``#@```+7#```?````Q,,``!T```#DPP``!P````+$```&````"L0```@`
M```1Q```#P```!K$```&````*L0```H````QQ```$P```#S$```+````4,0`
M`!````!<Q```%0```&W$```5````@\0```<```"9Q```$````*'$```%````
MLL0``!4```"XQ```$0```,[$```,````X,0``"@```#MQ```.@```!;%```[
M````4<4``#@```"-Q0``"0```,;%```'````T,4``!0```#8Q0```P```.W%
M```%````\<4```D```#WQ0``$`````'&```)````$L8``!,````<Q@``.0``
M`##&```2````:L8``"<```!]Q@``+````*7&```J````TL8``"4```#]Q@``
M"@```"/'```&````+L<```D````UQP``!P```#_'```O````1\<``#<```!W
MQP``+@```*_'``!5````WL<``"T````TR```+0```&+(```]````D,@``#\`
M``#.R```+0````[)``!`````/,D``",```!]R0``(P```*')``!`````Q<D`
M`"T````&R@``,P```#3*```E````:,H``!4```".R@``&0```*3*```I````
MOLH``"0```#HR@``*`````W+```1````-LL```H```!(RP``#````%/+```*
M````8,L``!````!KRP``%@```'S+```6````D\L```<```"JRP``!P```+++
M```4````NLL```H```#/RP``"````-K+```G````X\L```@````+S```#```
M`!3,```'````(<P```<````IS```!@```#',```1````.,P```4```!*S```
M!P```%#,```&````6,P``!0```!?S```"````'3,```I````?<P```X```"G
MS```"@```+;,```$````P<P```<```#&S```"0```,[,```&````V,P``!$`
M``#?S```!P```/',```6````^<P```0````0S0``"````!7-```&````'LT`
M``T````ES0``!@```#/-```>````.LT```8```!9S0``$0```&#-```(````
M<LT```T```![S0``#````(G-```'````ELT``!$```">S0```P```+#-```#
M````M,T``!<```"XS0```P```-#-```3````U,T``!T```#HS0``"`````;.
M```$````#\X```@````4S@``"````!W.``!!````)LX``!H```!HS@``'```
M`(/.```K````H,X``"````#,S@``%0```.W.```&`````\\```8````*SP``
M%0```!'/```8````)\\``"(```!`SP``+@```&//```=````DL\``"$```"P
MSP``5````-+/```I````)]````H```!1T```!P```%S0```'````9-```!4`
M``!LT```#@```(+0```*````D=````\```"<T```#0```*S0```/````NM``
M``T```#*T```"0```-C0```4````XM````8```#WT```&````/[0```=````
M%]$``!,````UT0``$0```$G1```4````6]$```0```!PT0``!@```'71```4
M````?-$``%0```"1T0``9````.;1```$````2](```X```!0T@``#P```%_2
M```%````;](```4```!UT@``&P```'O2```:````E](``!,```"RT@``#0``
M`,;2```1````U-(``!$```#FT@``%@```/C2```7````#],``!P````GTP``
M*@```$33```Y````;],``"(```"ITP``,@```,S3```0````_],``"$````0
MU```!0```#+4```3````.-0```L```!,U```$@```%C4```*````:]0```\`
M``!VU```#0```(;4```1````E-0``!,```"FU```#````+K4```&````Q]0`
M``P```#.U```!@```-O4```7````XM0``!````#ZU```$0````O5```(````
M'=4```4````FU0``#````"S5```0````.=4```4```!*U0``#@```%#5```-
M````7]4``",```!MU0``!@```)'5```6````F-4``"H```"OU0``!P```-K5
M```-````XM4```<```#PU0``"P```/C5```'````!-8```<````,U@``#P``
M`!36```)````)-8```D````NU@``"@```#C6```9````0]8``#T```!=U@``
M'0```)O6```,````N=8``!````#&U@``!0```-?6```E````W=8``!(````#
MUP``$P```!;7```5````*M<``!(```!`UP``*P```%/7```[````?]<``"``
M``"[UP``#@```-S7```(````Z]<``!0```#TUP``-@````G8```A````0-@`
M`!````!BV```"````'/8```,````?-@```8```")V```!````)#8```/````
ME=@```X```"EV```!P```+38```*````O-@```T```#'V```'P```-78```<
M````]=@``"$````2V0``'@```#39```9````4]D``!X```!MV0``'0```(S9
M```;````JMD``"````#&V0``+@```.?9```F````%MH``!P````]V@``'@``
M`%K:```<````>=H``"8```"6V@``*P```+W:```S````Z=H``"8````=VP``
M*P```$3;```X````<-L``!T```"IVP``%0```,?;```O````W=L``"`````-
MW```$@```"[<```I````0=P``!X```!KW```(````(K<```2````J]P``*(`
M``"^W```%@```&'=```C````>-T``"@```"<W0``*0```,7=```H````[]T`
M`!\````8W@``%0```#C>```@````3MX``"4```!OW@``*````)7>```M````
MOMX``#````#LW@``D@```!W?```A````L-\``!8```#2WP``'````.G?```F
M````!N```"H````MX```00```%C@``!$````FN````P```#?X```!P```.S@
M```'````].````8```#\X```$P````/A```-````%^$``!T````EX0``$```
M`$/A```2````5.$```<```!GX0``$P```&_A```2````@^$```<```"6X0``
M!````)[A```0````H^$``!````"TX0``#````,7A```.````TN$```T```#A
MX0``#P```._A```3````_^$```T````3X@``*````"'B```#````2N(```T`
M``!.X@``!@```%SB```1````8^(``!<```!UX@``&P```(WB```.````J>(`
M``(```"XX@``20```+OB```%````!>,``!`````+XP``#P```!SC```$````
M+.,```T````QXP``#@```#_C```#````3N,```X```!2XP``"````&'C```/
M````:N,```\```!ZXP``!P```(KC```-````DN,``!````"@XP``#0```+'C
M```:````O^,```L```#:XP``!@```.;C```3````[>,```L````!Y```$P``
M``WD```,````(>0```H````NY```$0```#GD```9````2^0``!<```!EY```
M"P```'WD```-````B>0``"(```"7Y```%@```+KD```;````T>0``#0```#M
MY```"@```"+E```8````+>4``!D```!&Y0``%@```&#E```B````=^4``",`
M``":Y0``#P```+[E```-````SN4```<```#<Y0``"@```.3E```*````[^4`
M`!0```#ZY0``"P````_F```B````&^8``"\````^Y@``"P```&[F```)````
M>N8``!D```"$Y@``"P```)[F```7````JN8``!<```#"Y@``"0```-KF```'
M````Y.8``!8```#LY@``#P````/G```9````$^<``!8````MYP``#@```$3G
M```8````4^<```@```!LYP``#0```'7G```F````@^<``"@```"JYP``0P``
M`-/G```(````%^@``!(````@Z```'P```#/H```(````4^@```L```!<Z```
M+P```&CH```.````F.@```X```"GZ```!0```+;H```&````O.@``$4```##
MZ````P````GI```'````#>D```0````5Z0``"0```!KI```2````).D```H`
M```WZ0``"@```$+I```/````3>D``!````!=Z0``%P```&[I```1````AND`
M`!$```"8Z0``&0```*KI```7````Q.D```D```#<Z0``!0```.;I```+````
M[.D```H```#XZ0```@````/J```%````!NH```T````,Z@``&P```!KJ```7
M````-NH``!0```!.Z@``"0```&/J```.````;>H```T```!\Z@``$@```(KJ
M```X````G>H``"````#6Z@``"````/?J```.`````.L``'L````/ZP``&```
M`(OK```8````I.L``#T```"]ZP``%0```/OK```1````$>P```<````C[```
M!0```"OL```C````,>P``#,```!5[```&````(GL```=````HNP``"X```#`
M[```'@```._L```;````#NT``!D````J[0``)P```$3M```W````;.T``"0`
M``"D[0``&P```,GM```9````Y>T``!,```#_[0``!P```!/N```(````&^X`
M``8````D[@``!@```"ON```0````,NX```\```!#[@``$````%/N```/````
M9.X```L```!T[@``#P```(#N```,````D.X```\```"=[@``!P```*WN```&
M````M>X```X```"\[@``#````,ON```H````V.X```\````![P``"````!'O
M```&````&N\``!,````A[P``(@```#7O```M````6.\```@```"&[P``$P``
M`(_O```>````H^\``"4```#"[P``&@```.CO```5`````_```!X````9\```
M0P```#CP```A````?/```"````">\```&0```+_P```7````V?```"4```#Q
M\```)0```!?Q```7````/?$``!8```!5\0``(0```&SQ```B````CO$```0`
M``"Q\0``&P```+;Q```-````TO$```P```#@\0```P```.WQ```%````\?$`
M``@```#W\0``"@````#R```,````"_(```L````8\@``$````"3R```,````
M-?(```X```!"\@``"P```%'R```$````7?(```0```!B\@``$P```&?R```4
M````>_(```P```"0\@``"0```)WR```.````I_(```L```"V\@``&P```,+R
M```%````WO(```<```#D\@``!````.SR```&````\?(```<```#X\@``"@``
M``#S```*````"_,```T````6\P``"0```"3S```$````+O,```4````S\P``
M`P```#GS```8````/?,```H```!6\P``!````&'S```F````9O,```X```"-
M\P``?````)SS```5````&?0```4````O]```!P```#7T```,````/?0```@`
M``!*]```"@```%/T```&````7O0```@```!E]````@```&[T```&````<?0`
M``8```!X]```%````'_T```,````E/0```T```"A]```$````*_T```;````
MP/0```0```#<]```"0```.'T```0````Z_0```D```#\]```"0````;U```%
M````$/4``!H````6]0``"````#'U```&````.O4``!D```!!]0``#@```%OU
M```'````:O4```<```!R]0``!0```'KU```)````@/4```H```"*]0``$P``
M`)7U```"````J?4```8```"L]0``"P```+/U```-````O_4```D```#-]0``
M!@```-?U```2````WO4```D```#Q]0``!P```/OU```%`````_8``!0````)
M]@``'0```![V``!"````//8``"4```!_]@``)0```*7V```&````R_8```H`
M``#2]@``!````-WV```)````XO8```@```#L]@``$0```/7V```)````!_<`
M``8````1]P``#0```!CW```&````)O<```0````M]P``.0```#+W```]````
M;/<``#H```"J]P``'@```.7W```%````!/@```X````*^```!````!GX```&
M````'O@```<````E^```(0```"WX```-````3_@``!4```!=^```!@```'/X
M```$````>O@``!$```!_^```!@```)'X```*````F/@``"(```"C^```!```
M`,;X```%````R_@``!T```#1^```!````._X```,````]/@```D````!^0``
M#`````OY```.````&/D```H````G^0``$````#+Y```3````0_D``!,```!7
M^0``"````&OY```)````=/D```4```!^^0``.@```(3Y```P````O_D``#4`
M``#P^0``*0```";Z``!'````4/H``#@```"8^@``*0```-'Z```_````^_H`
M`"X````[^P``+0```&K[```?````F/L```\```"X^P``$@```,C[```+````
MV_L``"8```#G^P``*0````[\```D````./P``"8```!=_```"````(3\```*
M````C?P```D```"8_```!P```*+\```@````JOP``"````#+_```)@```.S\
M```$````$_T``"`````8_0``"@```#G]```9````1/T``"D```!>_0``%@``
M`(C]```2````G_T```<```"R_0``"@```+K]```,````Q?T```\```#2_0``
M$````.+]``!`````\_T``'`````T_@``9@```*7^```.````#/\```D````;
M_P``"@```"7_```2````,/\``!,```!#_P``#````%?_```&````9/\``!P`
M``!K_P``#P```(C_```;````F/\``!(```"T_P``$````,?_```1````V/\`
M`!P```#J_P``(P````<``0!J````*P`!``\```"6``$`!0```*8``0`0````
MK``!``D```"]``$`!````,<``0`+````S``!`"````#8``$`%````/D``0`,
M````#@$!``P````;`0$`#P```"@!`0`5````.`$!`"D```!.`0$`*@```'@!
M`0`F````HP$!`"<```#*`0$`*0```/(!`0`J````'`(!`!D```!'`@$`0@``
M`&$"`0`1````I`(!`!(```"V`@$`$P```,D"`0`4````W0(!``\```#R`@$`
M%@````(#`0`7````&0,!`!`````Q`P$`$0```$(#`0`T````5`,!`!,```")
M`P$`$@```)T#`0`U````L`,!`!0```#F`P$`!P```/L#`0`,`````P0!``H`
M```0!`$`(````!L$`0`0````/`0!`!0```!-!`$`%````&($`0`1````=P0!
M`!<```")!`$`'````*$$`0`-````O@0!``T```#,!`$`$P```-H$`0`6````
M[@0!`!0````%!0$`&@```!H%`0`1````-04!``P```!'!0$`$````%0%`0`:
M````904!`!X```"`!0$`&@```)\%`0`3````N@4!`!4```#.!0$`$0```.0%
M`0`7````]@4!`!0````.!@$`%P```",&`0`5````.P8!``D```!1!@$`$```
M`%L&`0`9````;`8!``0```"&!@$`!P```(L&`0`+````DP8!`!$```"?!@$`
M!@```+$&`0`&````N`8!``8```"_!@$`!0```,8&`0`'````S`8!``<```#4
M!@$`!0```-P&`0`6````X@8!``8```#Y!@$`!@`````'`0`$````!P<!``0`
M```,!P$`!P```!$'`0`.````&0<!``P````H!P$`#````#4'`0`-````0@<!
M``H```!0!P$`#@```%L'`0`%````:@<!`"@```!P!P$`#@```)D'`0`,````
MJ`<!``\```"U!P$`"@```,4'`0`(````T`<!``D```#9!P$`*P```.,'`0`$
M````#P@!``@````4"`$`)@```!T(`0`2````1`@!``\```!7"`$`!@```&<(
M`0`*````;@@!`$P```!Y"`$`!P```,8(`0`(````S@@!`"````#7"`$`"0``
M`/@(`0`-`````@D!``D````0"0$`%````!H)`0`,````+PD!``T````\"0$`
M#@```$H)`0`6````60D!`!$```!P"0$`!@```(()`0`#````B0D!``8```"-
M"0$`&0```)0)`0`'````K@D!``0```"V"0$`"P```+L)`0`+````QPD!``<`
M``#3"0$`!0```-L)`0`'````X0D!`!8```#I"0$`#0`````*`0`-````#@H!
M``H````<"@$`$````"<*`0`/````.`H!`!$```!("@$`%P```%H*`0`*````
M<@H!`!$```!]"@$`"````(\*`0`$````F`H!``\```"="@$`.@```*T*`0`%
M````Z`H!``P```#N"@$`!````/L*`0`>``````L!``X````?"P$`$````"X+
M`0`+````/PL!``P```!+"P$`"0```%@+`0`'````8@L!``H```!J"P$`"0``
M`'4+`0`.````?PL!`!````"."P$`&P```)\+`0`8````NPL!`!H```#4"P$`
M"@```.\+`0`)````^@L!``H````$#`$`#`````\,`0`/````'`P!``@````L
M#`$`!@```#4,`0`<````/`P!``<```!9#`$`!0```&$,`0`+````9PP!`$<`
M``!S#`$`#0```+L,`0`)````R0P!``0```#3#`$``P```-@,`0`3````W`P!
M`!,```#P#`$`$P````0-`0`*````&`T!``(````C#0$`!````"8-`0`E````
M*PT!``,```!1#0$`!0```%4-`0`J````6PT!``H```"&#0$`!0```)$-`0`$
M````EPT!``H```"<#0$`#0```*<-`0`&````M0T!``@```"\#0$`"````,4-
M`0`$````S@T!``4```#3#0$`:````-D-`0`)````0@X!``P```!,#@$`$```
M`%D.`0`%````:@X!``8```!P#@$`&P```'<.`0`O````DPX!`!````###@$`
M"@```-0.`0`(````WPX!``\```#H#@$`"@```/@.`0`)`````P\!`!,````-
M#P$`&P```"$/`0`8````/0\!`!<```!6#P$`&@```&X/`0`?````B0\!``X`
M``"I#P$`%P```+@/`0`#````T`\!``<```#4#P$`"````-P/`0`'````Y0\!
M``D```#M#P$`"@```/</`0`+`````A`!``<````.$`$`40```!80`0`0````
M:!`!``P```!Y$`$`#0```(80`0`:````E!`!`$H```"O$`$`&0```/H0`0`&
M````%!$!`!H````;$0$`)0```#81`0`&````7!$!``8```!C$0$`'P```&H1
M`0`&````BA$!``D```"1$0$`&````)L1`0`7````M!$!`"@```#,$0$`!@``
M`/41`0`-````_!$!`"@````*$@$`(@```#,2`0!7````5A(!`!,```"N$@$`
M(P```,(2`0`3````YA(!``(```#Z$@$`"P```/T2`0`,````"1,!``@````6
M$P$`#0```!\3`0`*````+1,!`!8````X$P$`!P```$\3`0`4````5Q,!``8`
M``!L$P$`"````',3`0`.````?!,!``<```"+$P$`"@```),3`0`+````GA,!
M`#(```"J$P$`%P```-T3`0`'````]1,!``P```#]$P$`#0````H4`0`,````
M&!0!``0````E%`$`"0```"H4`0`)````-!0!``H````^%`$`!P```$D4`0`)
M````410!``D```!;%`$`"@```&44`0`'````<!0!``H```!X%`$`%0```(,4
M`0`;````F10!``\```"U%`$`20```,44`0`2````#Q4!``H````B%0$`%@``
M`"T5`0`/````1!4!`!````!4%0$`"0```&45`0`0````;Q4!``<```"`%0$`
M$@```(@5`0`$````FQ4!``L```"@%0$`!P```*P5`0`%````M!4!``4```"Z
M%0$`&@```,`5`0`+````VQ4!`!0```#G%0$`$0```/P5`0`:````#A8!`!8`
M```I%@$`%````$`6`0`7````518!`!@```!M%@$`'````(86`0`9````HQ8!
M``<```"]%@$`!0```,46`0`-````RQ8!``P```#9%@$`"P```.86`0`1````
M\A8!``@````$%P$`%P````T7`0`+````)1<!``P````Q%P$`'P```#X7`0`:
M````7A<!`!,```!Y%P$`!````(T7`0`*````DA<!``0```"=%P$`#0```*(7
M`0`,````L!<!``4```"]%P$`"0```,,7`0`(````S1<!``4```#6%P$`!P``
M`-P7`0`%````Y!<!``0```#J%P$``@```.\7`0`8````\A<!`!<````+&`$`
M.````",8`0`L````7!@!`!(```")&`$`*0```)P8`0`R````QA@!``H```#Y
M&`$`+`````09`0`N````,1D!`#,```!@&0$`,P```)09`0`X````R!D!`!$`
M```!&@$`#P```!,:`0`8````(QH!`!`````\&@$`#P```$T:`0`3````71H!
M`!4```!Q&@$`%````(<:`0`2````G!H!`!0```"O&@$`%0```,0:`0`M````
MVAH!`"T````(&P$`,0```#8;`0`N````:!L!`"\```"7&P$`+````,<;`0!B
M````]!L!`!,```!7'`$`#0```&L<`0`(````>1P!`!<```""'`$`"````)H<
M`0`,````HQP!`"L```"P'`$`(0```-P<`0`8````_AP!`!H````7'0$`"0``
M`#(=`0!%````/!T!`$$```""'0$`!````,0=`0`3````R1T!`!0```#='0$`
M#@```/(=`0`3`````1X!`!@````5'@$`!@```"X>`0`)````-1X!``H````_
M'@$`#P```$H>`0`0````6AX!``<```!K'@$`#@```',>`0`%````@AX!`!L`
M``"('@$`"````*0>`0`&````K1X!`!0```"T'@$`$0```,D>`0`8````VQX!
M``X```#T'@$`.`````,?`0`"````/!\!``8````_'P$`#@```$8?`0`0````
M51\!``4```!F'P$`!P```&P?`0`.````=!\!``8```"#'P$`*````(H?`0`,
M````LQ\!`!P```#`'P$`!````-T?`0":````XA\!`"D```!](`$`%P```*<@
M`0`?````OR`!`!D```#?(`$`7````/D@`0`4````5B$!`#X```!K(0$`'P``
M`*HA`0`0````RB$!``<```#;(0$`#@```.,A`0`,````\B$!``P```#_(0$`
M$P````PB`0`*````("(!`!T````K(@$`&0```$DB`0`%````8R(!`!$```!I
M(@$`#0```'LB`0`1````B2(!`"0```";(@$`$@```,`B`0`5````TR(!`!(`
M``#I(@$`#@```/PB`0`9````"R,!``@````E(P$`"0```"XC`0`-````.",!
M``H```!&(P$`!P```%$C`0`/````62,!``8```!I(P$`"P```'`C`0`:````
M?",!``H```"7(P$`!P```*(C`0`(````JB,!``4```"S(P$`'P```+DC`0`&
M````V2,!`!````#@(P$`"````/$C`0`-````^B,!``@````()`$`'@```!$D
M`0`2````,"0!`"P```!#)`$`&@```'`D`0`)````BR0!``H```"5)`$`%0``
M`*`D`0`%````MB0!`!0```"\)`$`!````-$D`0`0````UB0!``8```#G)`$`
M!P```.XD`0`>````]B0!`"@````5)0$`"@```#XE`0`<````224!`!$```!F
M)0$`$0```'@E`0`+````BB4!`!H```"6)0$`%````+$E`0`$````QB4!``0`
M``#+)0$`"P```-`E`0`%````W"4!``8```#B)0$`$0```.DE`0`(````^R4!
M``8````$)@$`"@````LF`0`;````%B8!`#0````R)@$`-````&<F`0`@````
MG"8!`"D```"])@$`(````.<F`0!!````""<!`!H```!*)P$`(0```&4G`0`H
M````AR<!`"D```"P)P$`4````-HG`0`B````*R@!``8```!.*`$`"````%4H
M`0`%````7B@!``@```!D*`$`&0```&TH`0`9````AR@!`"H```"A*`$`(P``
M`,PH`0`9````\"@!`"X````**0$`-````#DI`0`(````;BD!`!<```!W*0$`
M"@```(\I`0`'````FBD!`"$```"B*0$`"````,0I`0`0````S2D!``X```#>
M*0$`%````.TI`0`+`````BH!``<````.*@$`$P```!8J`0`(````*BH!``L`
M```S*@$`"@```#\J`0`4````2BH!``\```!?*@$`,@```&\J`0`+````HBH!
M``4```"N*@$`!0```+0J`0`5````NBH!``P```#0*@$`!0```-TJ`0`7````
MXRH!``\```#[*@$`!`````LK`0`*````$"L!``D````;*P$`"P```"4K`0`-
M````,2L!``P````_*P$`#@```$PK`0`%````6RL!``0```!A*P$`%````&8K
M`0`-````>RL!`"(```")*P$`,@```*PK`0`;````WRL!`$4```#[*P$`$@``
M`$$L`0`7````5"P!``<```!L+`$`'@```'0L`0`4````DRP!``4```"H+`$`
M%````*XL`0`&````PRP!``<```#*+`$`#@```-(L`0`J````X2P!``8````,
M+0$`#````!,M`0`3````("T!``T````T+0$`$0```$(M`0`5````5"T!``L`
M``!J+0$`-@```'8M`0`*````K2T!`"(```"X+0$`"P```-LM`0`/````YRT!
M`(4```#W+0$`,@```'TN`0`;````L"X!`"4```#,+@$`,````/(N`0`Q````
M(R\!`"T```!5+P$`#@```(,O`0`%````DB\!``X```"8+P$`$P```*<O`0`1
M````NR\!`!(```#-+P$`!P```.`O`0`1````Z"\!`!,```#Z+P$`!P````XP
M`0`4````%C`!`!@````K,`$`!P```$0P`0`%````3#`!``P```!2,`$`#```
M`%\P`0`2````;#`!``0```!_,`$`!P```(0P`0`*````C#`!``L```"7,`$`
M#````*,P`0`.````L#`!``X```"_,`$`!0```,XP`0`%````U#`!`"X```#:
M,`$`)@````DQ`0`C````,#$!``,```!4,0$`$@```%@Q`0`&````:S$!`!X`
M``!R,0$`&````)$Q`0`9````JC$!`"4```#$,0$`#0```.HQ`0`)````^#$!
M`!\````",@$``P```"(R`0`8````)C(!``<````_,@$`"@```$<R`0`"````
M4C(!``P```!5,@$`%0```&(R`0`+````>#(!`!D```"$,@$`(````)XR`0`2
M````OS(!``4```#2,@$`"@```-@R`0`5````XS(!`!(```#Y,@$`#`````PS
M`0`$````&3,!``D````>,P$`!P```"@S`0`,````,#,!`%(````],P$`%P``
M`)`S`0`D````J#,!`"$```#-,P$`$@```.\S`0`'`````C0!``8````*-`$`
M#@```!$T`0`-````(#0!`!$````N-`$`&P```$`T`0`,````7#0!``P```!I
M-`$`#0```'8T`0`5````A#0!`!(```":-`$`#P```*TT`0`4````O30!``H`
M``#2-`$`&P```-TT`0`@````^30!`!X````:-0$`$````#DU`0`+````2C4!
M`"<```!6-0$`)0```'XU`0!I````I#4!`"8````.-@$`&@```#4V`0`7````
M4#8!`!D```!H-@$`&@```((V`0`E````G38!`"@```##-@$`)P```.PV`0`:
M````%#<!`!<````O-P$`&P```$<W`0!$````8S<!`#0```"H-P$`)0```-TW
M`0`9`````S@!`!\````=.`$`&P```#TX`0`3````63@!``@```!M.`$`!P``
M`'8X`0`(````?C@!``D```"'.`$`%0```)$X`0`-````IS@!`",```"U.`$`
M#0```-DX`0`3````YS@!``@```#[.`$``P````0Y`0!&````"#D!`#\```!/
M.0$`-P```(\Y`0!7````QSD!``4````?.@$`'P```"4Z`0`O````13H!``H`
M``!U.@$`$````(`Z`0`(````D3H!``T```":.@$`+0```*@Z`0`$````UCH!
M``<```#;.@$`"````.,Z`0`-````[#H!``H```#Z.@$`3P````4[`0`E````
M53L!`!P```![.P$`"P```)@[`0`?````I#L!`!T```#$.P$`)0```.([`0`@
M````"#P!`"0````I/`$`(````$X\`0`+````;SP!``<```![/`$`#0```(,\
M`0`,````D3P!`!<```">/`$`!@```+8\`0`Y````O3P!``P```#W/`$`!P``
M``0]`0`)````##T!`!,````6/0$`"0```"H]`0`$````-#T!`!`````Y/0$`
M"````$H]`0`(````4ST!``0```!</0$`"P```&$]`0`,````;3T!`!(```!Z
M/0$`$0```(T]`0`,````GST!`!H```"L/0$`#P```,<]`0`'````UST!``T`
M``#?/0$`#@```.T]`0`4````_#T!``X````1/@$`!P```"`^`0`,````*#X!
M`!L````U/@$`+````%$^`0`3````?CX!`!P```"2/@$`*````*\^`0`&````
MV#X!``<```#?/@$`$P```.<^`0`%````^SX!``0````!/P$`%P````8_`0`Y
M````'C\!``H```!8/P$`#````&,_`0`)````<#\!``8```!Z/P$`"0```($_
M`0`(````BS\!``D```"4/P$`"@```)X_`0`1````J3\!``8```"[/P$`#@``
M`,(_`0`.````T3\!``T```#@/P$`"P```.X_`0`=````^C\!``L````80`$`
M`@```"1``0`<````)T`!``<```!$0`$`!@```$Q``0!D````4T`!``D```"X
M0`$`!P```,)``0`F````RD`!`"D```#Q0`$`&P```!M!`0`X````-T$!`"L`
M``!P00$`&@```)Q!`0`C````MT$!`"H```#;00$`+0````9"`0`[````-$(!
M`"@```!P0@$`-````)E"`0`9````SD(!`!4```#H0@$`!0```/Y"`0`'````
M!$,!``@````,0P$`!P```!5#`0`%````'4,!``<````C0P$`#@```"M#`0`)
M````.D,!``8```!$0P$`"````$M#`0`+````5$,!``<```!@0P$`"````&A#
M`0`'````<4,!`!8```!Y0P$`"0```)!#`0`&````FD,!``L```"A0P$`$```
M`*U#`0`&````OD,!`!P```#%0P$`%````.)#`0`'````]T,!`!$```#_0P$`
M"````!%$`0`.````&D0!``,````I1`$`"````"U$`0`4````-D0!``4```!+
M1`$`$````%%$`0`)````8D0!`!````!L1`$`!@```'U$`0`9````A$0!``H`
M``">1`$`'````*E$`0`'````QD0!``4```#.1`$`$````-1$`0`4````Y40!
M``L```#Z1`$`#0````9%`0`H````%$4!`!@````]10$`%P```%9%`0`$````
M;D4!``D```!S10$`"@```'U%`0`'````B$4!``(```"010$`#@```)-%`0`(
M````HD4!`",```"K10$`.````,]%`0`F````"$8!`#$````O1@$`)P```&%&
M`0!$````B48!`"4```#.1@$`+P```/1&`0`O````)$<!`"\```!41P$`*```
M`(1'`0!D````K4<!`!0````22`$`50```"=(`0`X````?4@!`"D```"V2`$`
M2@```.!(`0!;````*TD!`"@```"'20$`.````+!)`0`L````Z4D!`"@````6
M2@$`+````#]*`0`F````;$H!`!L```"32@$`/@```*]*`0"I`0``[DH!`",`
M``"83`$`,````+Q,`0`7````[4P!`$@````%30$`A0```$Y-`0`P````U$T!
M`"4````%3@$`00```"M.`0!;````;4X!`$D```#)3@$`,0```!-/`0`=````
M14\!`!@```!C3P$`*P```'Q/`0`A````J$\!`!\```#*3P$`*P```.I/`0`A
M````%E`!`"<````X4`$`.@```&!0`0`=````FU`!`!$```"Y4`$`,P```,M0
M`0`E````_U`!`"<````E40$`(````$U1`0`F````;E$!`!\```"540$`,```
M`+51`0#,````YE$!`&D```"S4@$`,0```!U3`0!!````3U,!`#,```"14P$`
M)0```,53`0`]````ZU,!`&4````I5`$`30```(]4`0!>````W50!`"<````\
M50$`,0```&15`0`^````EE4!`"P```#550$`)@````)6`0`O````*58!`"X`
M``!95@$`*0```(A6`0`P````LE8!`%0```#C5@$`6@```#A7`0`Q````DU<!
M`$@```#%5P$`2@````Y8`0`Q````65@!`"H```"+6`$`(@```+98`0`O````
MV5@!`"D````)60$`,@```#-9`0`O````9ED!`"P```"660$`+0```,-9`0!Q
M````\5D!`&8```!C6@$`;P```,I:`0"S````.EL!`!<```#N6P$`)0````9<
M`0`R````+%P!`"D```!?7`$`/@```(E<`0`B````R%P!`%(```#K7`$`(@``
M`#Y=`0`E````85T!``L```"'70$`L0```)-=`0!%````15X!`"$```"+7@$`
M-@```*U>`0`P````Y%X!`"4````57P$`'````#M?`0!(````6%\!`#$```"A
M7P$`!P```--?`0`'````VU\!``0```#C7P$`#0```.A?`0`+````]E\!``X`
M```"8`$`"P```!%@`0`%````'6`!`!`````C8`$``@```#1@`0!9````-V`!
M``4```"18`$`$@```)=@`0`$````JF`!``<```"O8`$`"````+=@`0`%````
MP&`!``,```#&8`$`$````,I@`0`,````VV`!`!,```#H8`$`#0```/Q@`0`"
M````"F$!``<````-80$`!@```!5A`0`4````'&$!``P````Q80$`&````#YA
M`0`&````5V$!`!(```!>80$`#````'%A`0`#````?F$!`"H```""80$`!```
M`*UA`0`&````LF$!``<```"Y80$`'P```,%A`0`U````X6$!`"X````78@$`
M+P```$9B`0`7````=F(!`"(```".8@$`)0```+%B`0`@````UV(!`!L```#X
M8@$`&````!1C`0`D````+6,!`!\```!28P$`&@```')C`0`A````C6,!`"``
M``"O8P$`,````-!C`0`:`````60!`#(````<9`$`&@```$]D`0`O````:F0!
M`"L```":9`$`'P```,9D`0`C````YF0!`!\````*90$`&@```"IE`0`A````
M164!`"4```!G90$`)@```(UE`0`E````M&4!`"0```#:90$`&````/]E`0`=
M````&&8!`"0````V9@$`&````%MF`0`B````=&8!`"P```"79@$`+P```,1F
M`0`5````]&8!`"4````*9P$`/````#!G`0`?````;6<!`",```"-9P$`'P``
M`+%G`0`@````T6<!`!H```#R9P$`&`````UH`0`F````)F@!`!X```!-:`$`
M*0```&QH`0`>````EF@!`#$```"U:`$`"0```.=H`0`,````\6@!`!<```#^
M:`$`+P```!9I`0`D````1FD!``<```!K:0$`#P```'-I`0`4````@VD!``X`
M``"8:0$`#0```*=I`0`D````M6D!``4```#::0$`!P```.!I`0`B````Z&D!
M`"4````+:@$`&@```#%J`0`=````3&H!`!H```!J:@$`!P```(5J`0#'````
MC6H!``L```!5:P$`'````&%K`0`5````?FL!``8```"4:P$`"0```)MK`0`+
M````I6L!``T```"Q:P$`%P```+]K`0`&````UVL!`#,```#>:P$`$P```!)L
M`0`3````)FP!``<````Z;`$`#P```$)L`0`'````4FP!`#(```!:;`$`!```
M`(UL`0`A````DFP!`!,```"T;`$`#````,AL`0`1````U6P!`#(```#G;`$`
M%@```!IM`0`(````,6T!`!T````Z;0$`"0```%AM`0`*````8FT!`!0```!M
M;0$`"@```()M`0`=````C6T!``@```"K;0$`'P```+1M`0`(````U&T!`!H`
M``#=;0$`)P```/AM`0`&````(&X!`!4````G;@$`!P```#UN`0`(````16X!
M``D```!.;@$`/P```%AN`0`2````F&X!``<```"K;@$`#P```+-N`0`.````
MPVX!`!````#2;@$`"0```.-N`0`)````[6X!``@```#W;@$`$P````!O`0`)
M````%&\!``<````>;P$`#````"9O`0`9````,V\!``H```!-;P$`&P```%AO
M`0`7````=&\!`!0```",;P$`"@```*%O`0`,````K&\!`!<```"Y;P$`!```
M`-%O`0`J````UF\!``P````!<`$`$0````YP`0`'````('`!``(````H<`$`
M$````"MP`0`8````/'`!``L```!5<`$``P```&%P`0`(````97`!``L```!N
M<`$`!@```'IP`0`'````@7`!``T```")<`$`"P```)=P`0`4````HW`!`!4`
M``"X<`$`#@```,YP`0`O````W7`!`"`````-<0$`'````"YQ`0`5````2W$!
M``P```!A<0$`,0```&YQ`0`%````H'$!`!(```"F<0$`/P```+EQ`0`2````
M^7$!``H````,<@$`!@```!=R`0`$````'G(!``0````C<@$`"@```"AR`0`3
M````,W(!``4```!'<@$`!@```$UR`0`&````5'(!``@```!;<@$`!````&1R
M`0`,````:7(!``D```!V<@$`#````(!R`0`*````C7(!`!````"8<@$`$P``
M`*ER`0`3````O7(!`#D```#1<@$`+@````MS`0`I````.G,!``4```!D<P$`
M&````&IS`0`9````@W,!`!\```"=<P$`'0```+US`0`1````VW,!``(```#M
M<P$`!````/!S`0`*````]7,!``8`````=`$`!0````=T`0`#````#70!``P`
M```1=`$`10```!YT`0`R````9'0!`#P```"7=`$`&@```-1T`0`T````[W0!
M`"@````D=0$`4P```$UU`0`P````H74!`"\```#2=0$`,@````)V`0`9````
M-78!`'(```!/=@$`(````,)V`0`U````XW8!`"$````9=P$`10```#MW`0`P
M````@7<!`"8```"R=P$`'@```-EW`0`H````^'<!`"L````A>`$`*0```$UX
M`0`I````=W@!`"8```"A>`$`)0```,AX`0`H````[G@!`"@````7>0$`(@``
M`$!Y`0`K````8WD!`"X```"/>0$`,````+YY`0`2````[WD!`!,````">@$`
M$````!9Z`0!Y````)WH!``D```"A>@$`H0```*MZ`0!S````37L!`'P```#!
M>P$`*P```#Y\`0!4````:GP!`!<```"_?`$`+````-=\`0`G````!'T!`!8`
M```L?0$`#P```$-]`0`7````4WT!`!\```!K?0$`0````(M]`0`?````S'T!
M`!P```#L?0$`40````E^`0`:````6WX!`!0```!V?@$`"@```(M^`0`%````
MEGX!``8```"<?@$`"````*-^`0`%````K'X!`!(```"R?@$`$````,5^`0`3
M````UGX!`!T```#J?@$`#P````A_`0`*````&'\!``\````C?P$`!P```#-_
M`0`$````.W\!``D```!`?P$`"0```$I_`0`'````5'\!``L```!<?P$`!P``
M`&A_`0`%````<'\!`!0```!V?P$`#@```(M_`0`&````FG\!``<```"A?P$`
M"````*E_`0`/````LG\!`!$```#"?P$`#````-1_`0`(````X7\!``P```#J
M?P$`#P```/=_`0`6````!X`!``<````>@`$`!@```":``0`4````+8`!``8`
M``!"@`$`#````$F``0`1````5H`!``@```!H@`$`!````'&``0`9````=H`!
M`!$```"0@`$`"@```**``0`8````K8`!`!,```#&@`$`"P```-J``0`,````
MYH`!``P```#S@`$`#`````"!`0`<````#8$!`!$````J@0$`#P```#R!`0`'
M````3($!``0```!4@0$`&0```%F!`0`'````<X$!``(```![@0$``@```'Z!
M`0`1````@8$!``D```"3@0$`!@```)V!`0`2````I($!`!<```"W@0$`!@``
M`,^!`0`G````UH$!``(```#^@0$`!`````&"`0`-````!H(!``0````4@@$`
M#P```!F"`0`3````*8(!``<````]@@$`!P```$6"`0`1````38(!``8```!?
M@@$`&````&:"`0`&````?X(!`!,```"&@@$`$````)J"`0`2````JX(!``(`
M``"^@@$`!@```,&"`0`,````R((!``D```#5@@$`$0```-^"`0`1````\8(!
M`!L````#@P$`(@```!^#`0`'````0H,!``<```!*@P$`"P```%*#`0`%````
M7H,!``(```!D@P$`"P```&>#`0":`0``<X,!`!(````.A0$`&P```"&%`0`0
M````/84!``X```!.A0$`"0```%V%`0`'````9X4!`"$```!OA0$`(P```)&%
M`0`#````M84!`"P```"YA0$`&P```.:%`0`A`````H8!`#4````DA@$`,0``
M`%J&`0`K````C(8!`"\```"XA@$`,P```.B&`0`=````'(<!`#4````ZAP$`
M*@```'"'`0`L````FX<!`"T```#(AP$`"P```/:'`0`R`````H@!`!0````U
MB`$`"P```$J(`0`3````5H@!``4```!JB`$`,0```'"(`0`0````HH@!`!$`
M``"SB`$`'@```,6(`0`*````Y(@!``\```#OB`$`"P```/^(`0`>````"XD!
M`)8````JB0$`$@```,&)`0`*````U(D!``T```#?B0$`#@```.V)`0`7````
M_(D!``P````4B@$`$````"&*`0`5````,HH!``<```!(B@$`G0```%"*`0`,
M````[HH!``P```#[B@$`%`````B+`0`2````'8L!`!`````PBP$`$````$&+
M`0`)````4HL!``H```!<BP$`.````&>+`0!$````H(L!`"````#EBP$`/@``
M``:,`0!-````18P!`&X```"3C`$`:@````*-`0!T````;8T!`'````#BC0$`
M00```%..`0`/````E8X!`!4```"EC@$`#@```+N.`0`0````RHX!`!@```#;
MC@$`!0```/2.`0`&````^HX!`!<````!CP$`"P```!F/`0`D````)8\!``H`
M``!*CP$`#0```%6/`0`T````8X\!`#````"8CP$`$0```,F/`0`4````VX\!
M`!8```#PCP$`#@````>0`0`'````%I`!``<````>D`$`%@```":0`0`D````
M/9`!``T```!BD`$`&0```'"0`0`?````BI`!`!\```"JD`$`)0```,J0`0`?
M````\)`!`!P````0D0$`,````"V1`0`3````7I$!`!(```!RD0$`&P```(61
M`0`1````H9$!`"@```"SD0$`"0```-R1`0`>````YI$!`!\````%D@$`%@``
M`"62`0!A````/)(!`#````">D@$`*0```,^2`0`R````^9(!``<````LDP$`
M$0```#23`0`3````1I,!`!(```!:DP$`'````&V3`0`F````BI,!`!X```"Q
MDP$`+@```-"3`0!#````_Y,!``X```!#E`$`!````%*4`0`1````5Y0!``L`
M``!IE`$`!P```'64`0`'````?90!``4```"%E`$`!P```(N4`0`,````DY0!
M``0```"@E`$`(@```*64`0`0````R)0!`!8```#9E`$`$````/"4`0`L````
M`94!`#$````NE0$`"P```&"5`0`+````;)4!`"$```!XE0$`'````)J5`0`A
M````MY4!`!\```#9E0$`#@```/F5`0`2````")8!``\````;E@$`)````"N6
M`0`C````4)8!``<```!TE@$`!@```'R6`0`(````@Y8!``T```",E@$`!P``
M`)J6`0`+````HI8!`!(```"NE@$`"P```,&6`0`4````S98!`!<```#BE@$`
M&P```/J6`0`(````%I<!`!0````?EP$`!0```#27`0`4````.I<!`!D```!/
MEP$`$````&F7`0`K````>I<!`$(```"FEP$`30```.F7`0!!````-Y@!``D`
M``!YF`$`!P```(.8`0`4````BY@!``,```"@F`$`!0```*28`0`)````JI@!
M``\```"TF`$`"0```,28`0`5````SI@!`$D```#DF`$`$P```"Z9`0`N````
M0ID!`#4```!QF0$`-P```*>9`0`R````WYD!``H````2F@$`!````!V:`0`)
M````(IH!``@````LF@$`,````#6:`0`W````9IH!`"\```">F@$`7@```,Z:
M`0`O````+9L!`"\```!=FP$`2P```(V;`0!.````V9L!`"\````HG`$`5```
M`%B<`0`T````K9P!`#<```#BG`$`5P```!J=`0`O````<IT!`#4```"BG0$`
M+````-B=`0`;````!9X!`!X````AG@$`+@```$">`0`K````;YX!`"L```";
MG@$`%````,>>`0`+````W)X!``P```#HG@$`#P```/6>`0`/````!9\!`!T`
M```5GP$`(0```#.?`0`'````59\!``<```!=GP$`$P```&6?`0`*````>9\!
M``<```"$GP$`+````(R?`0`-````N9\!`!````#'GP$`!P```-B?`0`(````
MX)\!``8```#IGP$`)0```/"?`0`%````%J`!``@````<H`$`!P```"6@`0`6
M````+:`!``P```!$H`$`*@```%&@`0`3````?*`!``P```"0H`$`!````)V@
M`0`'````HJ`!``<```"JH`$`!P```+*@`0`9````NJ`!``4```#4H`$`$@``
M`-J@`0`(````[:`!``@```#VH`$``P```/^@`0`&`````Z$!``8````*H0$`
M*@```!&A`0`)````/*$!`!(```!&H0$`"````%FA`0`-````8J$!``P```!P
MH0$`!P```'VA`0`1````A:$!`!(```"7H0$``P```*JA`0!!````KJ$!``,`
M``#PH0$`&0```/2A`0`P````#J(!``8````_H@$`!0```$:B`0`(````3*(!
M``@```!5H@$`9````%ZB`0`J````PZ(!`"H```#NH@$`/P```!FC`0`J````
M6:,!`"8```"$HP$`!@```*NC`0`'````LJ,!`!X```"ZHP$`*@```-FC`0`N
M````!*0!`#<````SI`$`+0```&ND`0`W````F:0!`&\```#1I`$`,P```$&E
M`0`(````=:4!``<```!^I0$`#````(:E`0`8````DZ4!``L```"LI0$`%```
M`+BE`0`8````S:4!`"(```#FI0$`&`````FF`0`:````(J8!`!4````]I@$`
M$P```%.F`0`'````9Z8!`!D```!OI@$`'0```(FF`0`5````IZ8!`!H```"]
MI@$`&@```-BF`0`%````\Z8!``@```#YI@$`&P````*G`0!R````'J<!`'D`
M``"1IP$`!`````NH`0`1````$*@!`!,````BJ`$`!0```#:H`0`%````/*@!
M`!H```!"J`$`&P```%VH`0`7````>:@!``X```"1J`$`%P```*"H`0`;````
MN*@!`!P```#4J`$`'@```/&H`0`G````$*D!`#8````XJ0$`/P```&^I`0`H
M````KZD!`#D```#8J0$`#@```!*J`0`J````(:H!``<```!,J@$`'@```%2J
M`0`2````<ZH!`!D```"&J@$`%0```*"J`0`D````MJH!`!\```#;J@$`%P``
M`/NJ`0`3````$ZL!`!$````GJP$`!@```#FK`0`/````0*L!``<```!0JP$`
M"@```%BK`0`8````8ZL!`!$```!\JP$`"````(ZK`0`'````EZL!`!,```"?
MJP$`%P```+.K`0`&````RZL!`!0```#2JP$`$0```.>K`0`F````^:L!``0`
M```@K`$`(0```"6L`0`U````1ZP!``@```!]K`$`#@```(:L`0`+````E:P!
M``D```"AK`$`!P```*NL`0`'````LZP!`!<```"[K`$`"P```-.L`0`)````
MWZP!``H```#IK`$`'````/2L`0!)````$:T!`"(```!;K0$`#0```'ZM`0`9
M````C*T!``4```"FK0$`(````*RM`0`5````S:T!`!@```#CK0$`&@```/RM
M`0`5````%ZX!`"T````MK@$`/P```%NN`0`D````FZX!`!4```#`K@$`"```
M`-:N`0`;````WZX!`#P```#[K@$`)P```#BO`0`1````8*\!``H```!RKP$`
M"0```'VO`0`/````AZ\!``8```"7KP$`%@```)ZO`0`5````M:\!``@```#+
MKP$`"@```-2O`0`-````WZ\!`"0```#MKP$`)@```!*P`0`N````.;`!`"<`
M``!HL`$`(````)"P`0`E````L;`!`"0```#7L`$`*@```/RP`0`E````)[$!
M`#0```!-L0$`,````(*Q`0`K````L[$!`"P```#?L0$`(P````RR`0`Q````
M,+(!`#8```!BL@$`-@```)FR`0`K````T+(!`#$```#\L@$`00```"ZS`0`J
M````<+,!`"D```";LP$`0P```,6S`0`K````";0!`!L````UM`$`,0```%&T
M`0`G````@[0!`"<```"KM`$`&@```-.T`0"S````[K0!`!\```"BM0$`*@``
M`,*U`0`N````[;4!`#`````<M@$`+0```$VV`0`R````>[8!`"D```"NM@$`
M*P```-BV`0`[````!+<!`#L```!`MP$`0````'RW`0!"````O;<!`+(`````
MN`$`)P```+.X`0`A````V[@!`"4```#]N`$`,@```".Y`0`Y````5KD!`$8`
M``"0N0$`3P```->Y`0`,````)[H!``0````TN@$`!0```#FZ`0`%````/[H!
M`!H```!%N@$`#0```&"Z`0`K````;KH!`!````":N@$`%0```*NZ`0`$````
MP;H!`!<```#&N@$`&0```-ZZ`0`'````^+H!``0`````NP$`$@````6[`0`1
M````&+L!``X````JNP$`&@```#F[`0`4````5+L!`!8```!INP$`%0```("[
M`0`-````EKL!`#D```"DNP$`!@```-Z[`0`3````Y;L!``8```#YNP$`$P``
M``"\`0`9````%+P!`!T````NO`$`$@```$R\`0`"````7[P!`$D```!BO`$`
M"P```*R\`0`6````N+P!`!````#/O`$`!````."\`0`1````Y;P!`!0```#W
MO`$`!`````R]`0`5````$;T!``@````GO0$`$````#"]`0`6````0;T!``8`
M``!8O0$`$@```%^]`0`3````<KT!`",```"&O0$`&0```*J]`0`+````Q+T!
M``<```#0O0$`'@```-B]`0`2````][T!`!L````*O@$`$P```":^`0`0````
M.KX!`!@```!+O@$`(````&2^`0`E````A;X!`!(```"KO@$`$@```+Z^`0`B
M````T;X!`"$```#TO@$`)0```!:_`0!%````/+\!`!$```""OP$`(0```)2_
M`0`;````MK\!`!H```#2OP$`-P```.V_`0`Q````)<`!`!<```!7P`$`$@``
M`&_``0`(````@L`!``L```"+P`$`"@```)?``0`3````HL`!``L```"VP`$`
M-````,+``0`T````]\`!``T````LP0$`#@```#K!`0`H````2<$!`!$```!R
MP0$`$@```(3!`0`2````E\$!``H```"JP0$`"0```+7!`0`8````O\$!`!,`
M``#8P0$`'P```.S!`0`;````#,(!`!(````HP@$`$0```#O"`0`(````3<(!
M`!````!6P@$`+````&?"`0`R````E,(!`&(```#'P@$`"0```"K#`0`6````
M-,,!`"T```!+PP$`"P```'G#`0`.````A<,!`#@```"4PP$`$0```,W#`0`0
M````W\,!``<```#PPP$`%0```/C#`0!)````#L0!``,```!8Q`$`"````%S$
M`0`&````9<0!``T```!LQ`$`'0```'K$`0`.````F,0!`!````"GQ`$`%0``
M`+C$`0`6````SL0!`"(```#EQ`$`)0````C%`0`9````+L4!`"(```!(Q0$`
M'@```&O%`0`)````BL4!``8```"4Q0$`"````)O%`0`*````I,4!``(```"O
MQ0$`"````++%`0`4````N\4!`#````#0Q0$`&@````'&`0`9````',8!``H`
M```VQ@$`#0```$'&`0`.````3\8!`!@```!>Q@$`10```'?&`0`O````O<8!
M``X```#MQ@$`$@```/S&`0"@````#\<!`"8```"PQP$`'P```-?'`0!0````
M]\<!`!P```!(R`$`$@```&7(`0`(````>,@!``8```"!R`$`,P```(C(`0!%
M````O,@!`"<````"R0$`+P```"K)`0`V````6LD!`$````"1R0$`0````-+)
M`0`N````$\H!`#0```!"R@$`.P```'?*`0`Y````L\H!`#(```#MR@$`%P``
M`"#+`0`J````.,L!``<```!CRP$`"````&O+`0`(````=,L!``8```!]RP$`
M&0```(3+`0`4````GLL!`!8```"SRP$`%````,K+`0`2````W\L!`!H```#R
MRP$`$@````W,`0`4````(,P!``@````US`$`"@```#[,`0`8````2<P!``X`
M``!BS`$`,P```'',`0`1````I<P!``P```"WS`$`"````,3,`0`3````S<P!
M`"D```#AS`$`,@````O-`0`4````/LT!`#H```!3S0$`(P```([-`0`N````
MLLT!`"$```#AS0$`(@````/.`0`D````)LX!`%8```!+S@$`)@```*+.`0`E
M````R<X!`"````#OS@$`'P```!#/`0`O````,,\!`"P```!@SP$`(0```(W/
M`0`B````K\\!`$,```#2SP$`/````!;0`0`$````4]`!`!D```!8T`$`"@``
M`'+0`0`/````?=`!``D```"-T`$`"@```)?0`0`'````HM`!`!4```"JT`$`
M&````,#0`0`0````V=`!`!@```#JT`$`$@````/1`0`.````%M$!`!H````E
MT0$`!0```$#1`0`'````1M$!`!<```!.T0$`%P```&;1`0`8````?M$!``X`
M``"7T0$`$````*;1`0`9````M]$!`"T```#1T0$`"````/_1`0`'````"-(!
M``H````0T@$`"````!O2`0`(````)-(!``X````MT@$`!@```#S2`0`0````
M0](!``X```!4T@$`"0```&/2`0`(````;=(!``H```!VT@$`%@```('2`0`1
M````F-(!``H```"JT@$`,0```+72`0`/````Y](!`(0```#WT@$`)0```'S3
M`0`+````HM,!``@```"NTP$`$````+?3`0`)````R-,!``L```#2TP$`!@``
M`-[3`0`+````Y=,!``(```#QTP$`!@```/33`0`&````^],!`!4````"U`$`
M%@```!C4`0`0````+]0!`!,```!`U`$`*P```%34`0`$````@-0!``,```"%
MU`$`%````(G4`0`+````GM0!``L```"JU`$`!0```+;4`0`:````O-0!``<`
M``#7U`$`!@```-_4`0`>````YM0!``L````%U0$`!P```!'5`0`)````&=4!
M``4````CU0$`"0```"G5`0`&````,]4!`!@````ZU0$`!0```%/5`0`&````
M6=4!``T```!@U0$`$````&[5`0`.````?]4!``4```".U0$`$0```)35`0`)
M````IM4!``<```"PU0$`!@```+C5`0`:````O]4!`"P```#:U0$`4`````?6
M`0`P````6-8!`#$```")U@$`!P```+O6`0`*````P]8!``0```#.U@$`"0``
M`-/6`0`)````W=8!`!<```#GU@$`"@```/_6`0`&````"M<!``T````1UP$`
M!@```!_7`0`$````)M<!`$8````KUP$`1````'+7`0!#````M]<!`"(```#[
MUP$`!0```![8`0`5````)-@!``L````ZV`$`!P```$;8`0`(````3M@!`!8`
M``!7V`$`#P```&[8`0`5````?M@!``<```"4V`$`!````)S8`0`3````H=@!
M``0```"UV`$`"@```+K8`0`;````Q=@!``4```#AV`$`"````.?8`0`/````
M\-@!``<`````V0$`$`````C9`0`%````&=D!``0````?V0$`%````"39`0`-
M````.=D!``L```!'V0$`#0```%/9`0`#````8=D!``@```!EV0$`"0```&[9
M`0`%````>-D!`$0```!^V0$`-0```,/9`0`^````^=D!`"P````XV@$`2P``
M`&7:`0!%````L=H!`#$```#WV@$`4@```"G;`0`W````?-L!`#H```"TVP$`
M)````._;`0`1````%-P!`!8````FW`$`#````#W<`0`S````2MP!`"L```!^
MW`$`)P```*K<`0`J````TMP!``@```#]W`$`"P````;=`0`*````$MT!``<`
M```=W0$`+P```"7=`0`R````5=T!`#D```"(W0$`!````,+=`0!%````Q]T!
M``H````-W@$`&@```!C>`0`D````,]X!`!@```!8W@$`%0```''>`0`'````
MA]X!`!````"/W@$`#@```*#>`0`1````K]X!``\```#!W@$`30```-'>`0"+
M````']\!`'<```"KWP$`$P```"/@`0`6````-^`!`!@```!.X`$`$````&?@
M`0`2````>.`!`!<```"+X`$`!@```*/@`0`G````JN`!`!4```#2X`$`(P``
M`.C@`0`2````#.$!`!$````?X0$`%0```#'A`0`8````1^$!`#4```!@X0$`
M>````);A`0`7````#^(!``0````GX@$`&````"SB`0`)````1>(!``0```!/
MX@$`#````%3B`0`D````8>(!`!8```"&X@$`#0```)WB`0`2````J^(!`!,`
M``"^X@$`%@```-+B`0`V````Z>(!`#8````@XP$`-````%?C`0`T````C.,!
M`#````#!XP$`,````/+C`0`7````(^0!`%0````[Y`$`%0```)#D`0`5````
MIN0!`!4```"\Y`$`%0```-+D`0`4````Z.0!`!@```#]Y`$`&````!;E`0`4
M````+^4!`!0```!$Y0$`,````%GE`0`:````BN4!`!P```"EY0$`.P```,+E
M`0`3````_N4!``8````2Y@$`#@```!GF`0`4````*.8!`!\````]Y@$`%```
M`%WF`0`:````<N8!`!4```"-Y@$`$P```*/F`0`;````M^8!`"````#3Y@$`
M$0```/3F`0`/````!N<!`!L````6YP$`&````#+G`0`9````2^<!`!T```!E
MYP$`%````(/G`0`,````F.<!`!$```"EYP$`'@```+?G`0`B````UN<!`!0`
M``#YYP$`&P````[H`0`9````*N@!`!,```!$Z`$`'@```%CH`0`9````=^@!
M`!@```"1Z`$`&````*KH`0`*````P^@!`!4```#.Z`$`!````.3H`0`$````
MZ>@!``<```#NZ`$`"@```/;H`0`0`````>D!``8````2Z0$`"````!GI`0`(
M````(ND!``8````KZ0$`"````#+I`0`'````.^D!``4```!#Z0$`%@```$GI
M`0`&````8.D!``@```!GZ0$`!P```'#I`0`$````>.D!``D```!]Z0$`!P``
M`(?I`0`)````C^D!`!````"9Z0$`$````*KI`0`*````N^D!`!,```#&Z0$`
M!0```-KI`0`P````X.D!`!(````1Z@$`$````"3J`0`4````->H!`!,```!*
MZ@$`#````%[J`0`6````:^H!`#8```""Z@$`!P```+GJ`0`(````P>H!``T`
M``#*Z@$`#````-CJ`0`/````Y>H!``8```#UZ@$`#````/SJ`0!.````">L!
M``T```!8ZP$`!@```&;K`0`$````;>L!``X```!RZP$`%0```('K`0`#````
ME^L!`"4```";ZP$`$````,'K`0`6````TNL!`!<```#IZP$`)@````'L`0`;
M````*.P!``@```!$[`$``P```$WL`0`,````4>P!`"D```!>[`$`!0```(CL
M`0`&````CNP!``T```"5[`$`$0```*/L`0`'````M>P!``8```"][`$`!P``
M`,3L`0`%````S.P!``T```#2[`$`#0```.#L`0`,````[NP!`"````#[[`$`
M$0```!SM`0`/````+NT!`!H````^[0$`$P```%GM`0`6````;>T!``4```"$
M[0$`!````(KM`0`5````C^T!`$P```"E[0$`!0```/+M`0`-````^.T!``4`
M```&[@$`*`````SN`0`:````->X!``\```!0[@$`$P```&#N`0`4````=.X!
M`!````")[@$`#P```)KN`0`8````JNX!`!````##[@$`%0```-3N`0`9````
MZNX!`",````$[P$`)P```"CO`0`W````4.\!``L```"([P$`"````)3O`0`-
M````G>\!``\```"K[P$`#P```+OO`0`$````R^\!``D```#0[P$`+P```-KO
M`0`+````"O`!``D````6\`$`$P```"#P`0!K````-/`!`!,```"@\`$`"@``
M`+3P`0`%````O_`!``8```#%\`$`&@```,SP`0`9````Y_`!`!D````!\0$`
M"@```!OQ`0`"````)O$!`!8````I\0$`,P```$#Q`0`#````=/$!``4```!X
M\0$`%P```'[Q`0`*````EO$!``4```"A\0$`"````*?Q`0`:````L/$!``X`
M``#+\0$`!@```-KQ`0`(````X?$!``@```#J\0$`!````//Q`0`%````^/$!
M`$H```#^\0$`#P```$GR`0`2````6?(!`!T```!L\@$`!````(KR`0`%````
MC_(!`"4```"5\@$`.0```+OR`0`-````]?(!``H````#\P$`"0````[S`0`1
M````&/,!``H````J\P$`"P```#7S`0`6````0?,!`!L```!8\P$`+P```'3S
M`0`N````I/,!`!H```#3\P$`(@```.[S`0`0````$?0!`!<````B]`$``P``
M`#KT`0`'````/O0!``H```!&]`$`!P```%'T`0`$````6?0!``X```!>]`$`
M%@```&WT`0`'````A/0!`%H```",]`$`#P```.?T`0`/````]_0!``L````'
M]0$`)P```!/U`0!=````._4!`!L```"9]0$`!P```+7U`0`C````O?4!`"D`
M``#A]0$`"`````OV`0`'````%/8!`!L````<]@$`!@```#CV`0`)````/_8!
M`"X```!)]@$`+0```'CV`0`W````IO8!``8```#>]@$`!@```.7V`0`T````
M[/8!`"P````A]P$`9@```$[W`0`7````M?<!`"0```#-]P$`%P```/+W`0`"
M````"O@!`!$````-^`$`"P```!_X`0`&````*_@!`!0````R^`$`#@```$?X
M`0`B````5O@!``8```!Y^`$`"````(#X`0`&````B?@!``@```"0^`$`#0``
M`)GX`0`-````I_@!``H```"U^`$`$0```,#X`0`[````TO@!`!D````.^0$`
M!0```"CY`0`7````+OD!`!0```!&^0$`%P```%OY`0`(````<_D!``L```!\
M^0$`$0```(CY`0`1````FOD!``P```"L^0$`"P```+GY`0`1````Q?D!`!$`
M``#7^0$`#````.GY`0`*````]OD!`!$````!^@$`(````!/Z`0`5````-/H!
M`%,```!*^@$`$@```)[Z`0`5````L?H!`!@```#'^@$`#````.#Z`0`-````
M[?H!``L```#[^@$`&P````?[`0`(````(_L!`!4````L^P$``P```$+[`0`-
M````1OL!``<```!4^P$`!0```%S[`0`%````8OL!`!L```!H^P$`"````(3[
M`0`6````C?L!`!<```"D^P$`)````+S[`0`C````X?L!`!X````%_`$`&@``
M`"3\`0`;````/_P!`"(```!;_`$`&P```'[\`0`&````FOP!``8```"A_`$`
M$@```*C\`0`2````N_P!``\```#._`$`%````-[\`0`-````\_P!`"4````!
M_0$`$````"?]`0`4````./T!`"<```!-_0$`)0```'7]`0`9````F_T!``D`
M``"U_0$`!@```+_]`0`'````QOT!`!(```#._0$`$0```.']`0`(````\_T!
M``D```#\_0$`!@````;^`0`%````#?X!``<````3_@$`!````!O^`0`$````
M(/X!``,````E_@$`(@```"G^`0`?````3/X!`$@```!L_@$`-@```+7^`0`E
M````[/X!`"H````2_P$`00```#W_`0`,````?_\!`$````",_P$`-@```,W_
M`0`Y````!``"`#D````^``(`/@```'@``@`4````MP`"`!@```#,``(`&P``
M`.4``@`4`````0$"`!,````6`0(`'````"H!`@`@````1P$"`!0```!H`0(`
M$P```'T!`@`6````D0$"`!H```"H`0(`.P```,,!`@`[````_P$"`#\````[
M`@(`-````'L"`@`[````L`("`#@```#L`@(`>P```"4#`@`>````H0,"`!@`
M``#``P(`#0```-D#`@`:````YP,"``P````"!`(`$@````\$`@`X````(@0"
M`#,```!;!`(`'````(\$`@`J````K`0"``T```#7!`(`4P```.4$`@!,````
M.04"``4```"&!0(`'@```(P%`@`6````JP4"``L```#"!0(`#P```,X%`@`6
M````W@4"``<```#U!0(`"0```/T%`@`)````!P8"``X````1!@(`#P```"`&
M`@`'````,`8"`!,````X!@(`!0```$P&`@`F````4@8"``@```!Y!@(`!@``
M`((&`@`4````B08"`!(```">!@(`%P```+$&`@`1````R08"`$0```#;!@(`
M`@```"`'`@`%````(P<"`!`````I!P(`$````#H'`@`%````2P<"``<```!1
M!P(`%0```%D'`@`&````;P<"`#T```!V!P(`$P```+0'`@`C````R`<"``0`
M``#L!P(`L````/$'`@`X````H@@"`"8```#;"`(`)@````()`@`>````*0D"
M`%T```!("0(`(````*8)`@!-````QPD"`"H````5"@(`%@```$`*`@`'````
M5PH"``\```!?"@(`#P```&\*`@`,````?PH"`!<```","@(`#````*0*`@`=
M````L0H"`!L```#/"@(`!0```.L*`@`3````\0H"``X````%"P(`&P```!0+
M`@`L````,`L"`!$```!="P(`%P```&\+`@`5````APL"`!````"="P(`'0``
M`*X+`@`(````S`L"`!````#5"P(`&0```.8+`@`4``````P"`!(````5#`(`
M'````"@,`@`3````10P"`!,```!9#`(`%P```&T,`@`1````A0P"``L```"7
M#`(`"````*,,`@`%````K`P"`!T```"R#`(`!@```-`,`@`9````UPP"``@`
M``#Q#`(`%0```/H,`@`,````$`T"`"0````=#0(`%@```$(-`@`S````60T"
M`!X```"-#0(`#@```*P-`@`/````NPT"`"H```#+#0(`!@```/8-`@`?````
M_0T"``8````=#@(`&@```"0.`@`)````/PX"``L```!)#@(`)P```%4.`@`X
M````?0X"``H```"V#@(`*0```,$.`@`2````ZPX"`!(```#^#@(`#@```!$/
M`@`>````(`\"`!0````_#P(`!0```%0/`@`'````6@\"``L```!B#P(`"0``
M`&X/`@`&````>`\"``T```!_#P(`"````(T/`@`&````E@\"``H```"=#P(`
M'````*@/`@`M````Q0\"`#$```#S#P(`)0```"40`@`S````2Q`"`"8```!_
M$`(`1P```*80`@`A````[A`"`"\````0$0(`)P```$`1`@`^````:!$"`%P`
M``"G$0(`,`````02`@`'````-1("``D````]$@(`"````$<2`@`(````4!("
M`!<```!9$@(`%@```'$2`@`L````B!("`"X```"U$@(`&0```.02`@`P````
M_A("`#H````O$P(`"````&H3`@`?````<Q,"``L```"3$P(`!@```)\3`@`K
M````IA,"``D```#2$P(`$P```-P3`@`4````\!,"``X````%%`(`"P```!04
M`@`(````(!0"`!<````I%`(`!P```$$4`@`+````210"``T```!5%`(`&P``
M`&,4`@`A````?Q0"`#P```"A%`(`"@```-X4`@`%````Z10"``<```#O%`(`
M'0```/<4`@`4````%14"``4````J%0(`&P```#`5`@`/````3!4"``4```!<
M%0(`$@```&(5`@`:````=14"``<```"0%0(`#@```)@5`@`0````IQ4"`!,`
M``"X%0(`!````,P5`@`$````T14"`!H```#6%0(`#````/$5`@`M````_A4"
M`!X````L%@(`)0```$L6`@!:````<18"`!H```#,%@(`'P```.<6`@`*````
M!Q<"`"L````2%P(`(````#X7`@`6````7Q<"`!8```!V%P(`"0```(T7`@`)
M````EQ<"`!$```"A%P(`+@```+,7`@`'````XA<"``\```#J%P(`'@```/H7
M`@`2````&1@"`!0````L&`(`$P```$$8`@`0````51@"`$$```!F&`(`"@``
M`*@8`@`<````LQ@"`!4```#0&`(`&@```.88`@"9`````1D"`#D```";&0(`
M$0```-49`@`C````YQD"`$P````+&@(`4````%@:`@!)````J1H"`!$```#S
M&@(``P````4;`@`=````"1L"`"(````G&P(`)@```$H;`@`=````<1L"``D`
M``"/&P(`$P```)D;`@`A````K1L"``<```#/&P(`)0```-<;`@`>````_1L"
M``H````<'`(`!@```"<<`@`0````+AP"`!$````_'`(`'````%$<`@`$````
M;AP"``@```!S'`(`"P```'P<`@`0````B!P"`!````"9'`(`%P```*H<`@`7
M````PAP"``D```#:'`(`!@```.0<`@!`````ZQP"`#0````L'0(`,P```&$=
M`@`&````E1T"``8```"<'0(`!@```*,=`@`=````JAT"`!8```#('0(`&```
M`-\=`@`L````^!T"``X````E'@(`$````#0>`@`D````11X"``,```!J'@(`
M&P```&X>`@`&````BAX"`!$```"1'@(``@```*,>`@`-````IAX"`!H```"T
M'@(`#````,\>`@`8````W!X"`!\```#U'@(`$@```!4?`@`2````*!\"``L`
M```['P(`%````$<?`@`5````7!\"``\```!R'P(`"P```((?`@`2````CA\"
M``X```"A'P(`%P```+`?`@!H````R!\"`"(````Q(`(`/P```%0@`@`R````
ME"`"``T```#'(`(`!P```-4@`@`*````W2`"`!0```#H(`(`%0```/T@`@`:
M````$R$"`"$````N(0(`%0```%`A`@`7````9B$"`!4```!^(0(`(````)0A
M`@`D````M2$"`!<```#:(0(`)0```/(A`@`1````&"("`"\````J(@(`+P``
M`%HB`@`L````BB("`!,```"W(@(`%0```,LB`@`V````X2("`#8````8(P(`
MD````$\C`@`U````X","`"0````6)`(`(````#LD`@`D````7"0"`"0```"!
M)`(`*````*8D`@`Z````SR0"`#$````*)0(`)````#PE`@`C````824"`"0`
M``"%)0(`60```*HE`@`^````!"8"`#8```!#)@(`)0```'HF`@`D````H"8"
M`",```#%)@(`'0```.DF`@`+````!R<"``<````3)P(`"````!LG`@`)````
M)"<"`!0````N)P(`#P```$,G`@`W````4R<"`!L```"+)P(`%@```*<G`@`(
M````OB<"``P```#')P(`:@```-0G`@!"````/R@"`$H```""*`(`@````,TH
M`@`-````3BD"`#$```!<*0(`,0```(XI`@`*````P"D"`!(```#+*0(`!0``
M`-XI`@`&````Y"D"`$4```#K*0(`"````#$J`@`+````.BH"``T```!&*@(`
M$0```%0J`@`/````9BH"`&8```!V*@(`-0```-TJ`@`H````$RL"`!0````\
M*P(`)P```%$K`@`>````>2L"`"T```"8*P(`-P```,8K`@!$````_BL"`#<`
M``!#+`(`&P```'LL`@`'````ERP"`!L```"?+`(`%P```+LL`@`5````TRP"
M``D```#I+`(`-````/,L`@`,````*"T"``H````U+0(`"0```$`M`@`7````
M2BT"``D```!B+0(`!@```&PM`@`6````<RT"``D```"*+0(`"````)0M`@`%
M````G2T"``\```"C+0(`$````+,M`@`D````Q"T"`"````#I+0(`$P````HN
M`@`T````'BX"``P```!3+@(`!P```&`N`@`2````:"X"``L```![+@(`&P``
M`(<N`@`.````HRX"``<```"R+@(`#@```+HN`@`9````R2X"`"8```#C+@(`
M#@````HO`@`@````&2\"`#8````Z+P(`"````'$O`@`*````>B\"`!D```"%
M+P(`!P```)\O`@`(````IR\"`!,```"P+P(`2P```,0O`@`2````$#`"`!(`
M```C,`(`$0```#8P`@`&````2#`"``D```!/,`(`"````%DP`@`)````8C`"
M``X```!L,`(`$````'LP`@`&````C#`"`!0```"3,`(``P```*@P`@`%````
MK#`"`!````"R,`(`'P```,,P`@`+````XS`"``(```#O,`(`(0```/(P`@`%
M````%#$"``4````:,0(`<@```"`Q`@`&````DS$"``8```":,0(`'````*$Q
M`@`C````OC$"`"$```#B,0(`1@````0R`@`A````2S("`!X```!M,@(`'0``
M`(PR`@`<````JC("`"0```#',@(`6P```.PR`@`[````2#,"`$\```"$,P(`
M(````-0S`@`5````]3,"``8````+-`(`"````!(T`@`/````&S0"`!$````K
M-`(`"@```#TT`@`/````2#0"`!<```!8-`(`$0```'`T`@`1````@C0"`!0`
M``"4-`(`"````*DT`@`*````LC0"`!T```"]-`(`#@```-LT`@`:````ZC0"
M``D````%-0(`!0````\U`@`&````%34"`",````<-0(`!@```$`U`@`N````
M1S4"``4```!V-0(`!@```'PU`@`-````@S4"``8```"1-0(`#P```)@U`@`#
M````J#4"``L```"L-0(`'P```+@U`@`'````V#4"`!4```#@-0(`$@```/8U
M`@`5````"38"``8````?-@(`&0```"8V`@`*````0#8"``@```!+-@(`!P``
M`%0V`@`&````7#8"`!,```!C-@(`)0```'<V`@`+````G38"``X```"I-@(`
M*````+@V`@`8````X38"`!H```#Z-@(`!0```!4W`@`*````&S<"`!,````F
M-P(`#0```#HW`@`"````2#<"``X```!+-P(`"0```%HW`@`E````9#<"`#H`
M``"*-P(`*P```,4W`@`X````\3<"`"P````J.`(`5@```%<X`@`I````KC@"
M`"<```#8.`(`*P`````Y`@`M````+#D"`"\```!:.0(`9P```(HY`@`;````
M\CD"`&`````..@(`.````&\Z`@`@````J#H"`$H```#).@(`60```!0[`@`O
M````;CL"`#$```">.P(`(0```-`[`@`K````\CL"`#$````>/`(`+P```%`\
M`@`F````@#P"`#T```"G/`(`(@(``.4\`@`C````"#\"`#<````L/P(`&```
M`&0_`@!*````?3\"`($```#(/P(`,P```$I``@`O````?D`"`$````"N0`(`
M6@```.]``@!0````2D$"`#D```";00(`(P```-5!`@`7````^4$"`"P````1
M0@(`(0```#Y"`@`C````8$("`#,```"$0@(`'P```+A"`@`J````V$("`#8`
M```#0P(`&P```#I#`@`1````5D,"`%0```!H0P(`*P```+U#`@`M````Z4,"
M`"<````71`(`+@```#]$`@`B````;D0"`"T```"11`(`L0```+]$`@!9````
M<44"`#4```#+10(`5`````%&`@`Z````5D8"`#P```"11@(`3@```,Y&`@!O
M````'4<"`%@```"-1P(`=P```.9'`@`[````7D@"`$@```":2`(`4@```.-(
M`@!!````-DD"`#<```!X20(`1P```+!)`@!*````^$D"`#X```!#2@(`1```
M`()*`@!K````QTH"`'4````S2P(`2P```*E+`@!I````]4L"`&8```!?3`(`
M2P```,9,`@`_````$DT"`"T```!230(`-P```(!-`@`N````N$T"`#\```#G
M30(`+0```"=.`@`L````54X"`#````""3@(`=P```+-.`@!F````*T\"`'4`
M``"23P(`P`````A0`@`9````R5`"`"H```#C4`(`/0````Y1`@`R````3%$"
M`%(```!_40(`)````-)1`@!;````]U$"`"@```!34@(`(````'Q2`@`)````
MG5("`+T```"G4@(`2@```&53`@`C````L%,"`#X```#44P(`/0```!-4`@`F
M````450"`"$```!X5`(`4@```)I4`@`^````[50"``@````L50(`!P```#55
M`@`%````/54"``T```!#50(`#@```%%5`@`4````8%4"``X```!U50(`"```
M`(15`@`3````C54"``$```"A50(`>0```*-5`@`+````'58"`!,````I5@(`
M!````#U6`@`'````0E8"``8```!*5@(`!0```%%6`@`$````5U8"`!0```!<
M5@(`"P```'%6`@`1````?58"``P```"/5@(``@```)Q6`@`'````GU8"``<`
M``"G5@(`$0```*]6`@`,````P58"`!<```#.5@(`!@```.96`@`5````[58"
M``P````#5P(``P```!!7`@`M````%%<"``0```!"5P(`!P```$=7`@`'````
M3U<"`"D```!75P(`1@```(%7`@!"````R%<"`$$````+6`(`'@```$U8`@`V
M````;%@"`#D```"C6`(`)````-U8`@`;`````ED"`"0````>60(`+0```$-9
M`@`F````<5D"`",```"860(`+0```+Q9`@`I````ZED"`$<````46@(`+@``
M`%Q:`@`\````BUH"`"8```#(6@(`-P```.]:`@`P````)UL"`"D```!86P(`
M+P```();`@`M````LEL"`"8```#@6P(`,`````=<`@`J````.%P"`"P```!C
M7`(`+P```)!<`@`J````P%P"`"8```#K7`(`*@```!)=`@`O````/5T"`",`
M``!M70(`+0```)%=`@`X````OUT"`#L```#X70(`(````#1>`@`L````55X"
M`#X```""7@(`*0```,%>`@`N````ZUX"`"T````:7P(`+````$A?`@`F````
M=5\"`"````"<7P(`*````+U?`@`J````YE\"`$,````18`(`+P```%5@`@`\
M````A6`"``D```#"8`(`&0```,Q@`@`<````YF`"`#4````#80(`(@```#EA
M`@`.````7&$"``\```!K80(`$P```'MA`@`+````CV$"``H```";80(`'P``
M`*9A`@`&````QF$"``<```#-80(`(@```-5A`@`E````^&$"`"`````>8@(`
M*@```#]B`@`8````:F("``@```"#8@(`^````(QB`@`:````A6,"`"$```"@
M8P(`'0```,)C`@`(````X&,"``L```#I8P(`%@```/5C`@`6````#&0"`"4`
M```C9`(`!P```$ED`@!3````460"`!H```"E9`(`&@```,!D`@`'````VV0"
M`!D```#C9`(`#````/UD`@!,````"F4"``L```!790(`,````&-E`@`?````
ME&4"`!@```"T90(`'P```,UE`@`\````[64"`!T````J9@(`$0```$AF`@`G
M````6F8"`!,```""9@(`%````)9F`@`6````JV8"``L```#"9@(`&@```,YF
M`@`(````Z68"`"P```#R9@(`"````!]G`@`I````*&<"`"\```!29P(`!P``
M`()G`@`9````BF<"``<```"D9P(`"````*QG`@`)````M6<"`$4```"_9P(`
M$P````5H`@`'````&6@"`!,````A:`(`$P```#5H`@`4````26@"``H```!>
M:`(`"@```&EH`@`'````=&@"`!0```!\:`(`"P```)%H`@`'````G6@"`!,`
M``"E:`(`&0```+EH`@`-````TV@"`!8```#A:`(`&0```/AH`@`;````$FD"
M``H````N:0(`#0```#EI`@`7````1VD"``8```!?:0(`-````&9I`@`,````
MFVD"`!````"H:0(`"0```+EI`@`"````PVD"`!````#&:0(`&@```-=I`@`+
M````\FD"``,```#^:0(`"`````)J`@`/````"VH"``X````;:@(`"0```"IJ
M`@`.````-&H"``T```!#:@(`%P```%%J`@`8````:6H"`!$```"":@(`/```
M`)1J`@`E````T6H"`",```#W:@(`%P```!MK`@`.````,VL"`#0```!":P(`
M!P```'=K`@`5````?VL"`%D```"5:P(`$@```.]K`@`0`````FP"``D````3
M;`(`!````!UL`@`$````(FP"`!$````G;`(`'@```#EL`@`&````6&P"``<`
M``!?;`(`!P```&=L`@`3````;VP"``<```"#;`(`#@```(ML`@`/````FFP"
M``X```"J;`(`"P```+EL`@`5````Q6P"`!<```#;;`(`#0```/-L`@!"````
M`6T"`#0```!$;0(`.````'EM`@`%````LFT"`!L```"X;0(`(0```-1M`@`9
M````]FT"`"(````0;@(`$0```#-N`@`"````16X"``0```!(;@(`$0```$UN
M`@`,````7VX"``4```!L;@(``P```')N`@`.````=FX"`%8```"%;@(`,@``
M`-QN`@!!````#V\"`!P```!1;P(`00```&YO`@`V````L&\"`%@```#G;P(`
M,````$!P`@`O````<7`"`#D```"A<`(`&0```-MP`@!Y````]7`"`"@```!O
M<0(`2````)AQ`@`D````X7$"`$<````&<@(`+````$YR`@`W````>W("`#``
M``"S<@(`+````.1R`@`T````$7,"`#0```!&<P(`+P```'MS`@`N````JW,"
M`"X```#:<P(`.`````ET`@`L````0G0"`#0```!O=`(`+0```*1T`@`T````
MTG0"`#4````'=0(`&0```#UU`@`C````5W4"`!@```![=0(`>@```)1U`@`)
M````#W8"`,L````9=@(`D````.5V`@!\````=G<"`"T```#S=P(`;@```"%X
M`@`=````D'@"`#L```"N>`(`)@```.IX`@`3````$7D"`!,````E>0(`%@``
M`#EY`@`J````4'D"`$````![>0(`(0```+QY`@`E````WGD"`'$````$>@(`
M'````'9Z`@`7````DWH"``L```"K>@(`!0```+=Z`@`&````O7H"``@```#$
M>@(`!0```,UZ`@`6````TWH"`!4```#J>@(`&0````![`@`D````&GL"`!``
M```_>P(`#P```%![`@`/````8'L"``<```!P>P(`$@```'A[`@`)````BWL"
M``D```"5>P(`"@```)][`@`4````JGL"``@```"_>P(`!0```,A[`@`9````
MSGL"`!(```#H>P(`!P```/M[`@`*`````WP"``P````.?`(`&````!M\`@`.
M````-'P"`!````!#?`(`"````%1\`@`,````77P"`!````!J?`(`%````'M\
M`@`*````D'P"``X```";?`(`%@```*I\`@`-````P7P"`!$```#/?`(`%```
M`.%\`@`&````]GP"``4```#]?`(`*`````-]`@`<````+'T"``L```!)?0(`
M+````%5]`@`7````@GT"``L```":?0(`#````*9]`@`,````LWT"``P```#`
M?0(`)0```,U]`@`:````\WT"`!$````.?@(`!P```"!^`@`'````*'X"`!D`
M```P?@(`"0```$I^`@`#````5'X"``(```!8?@(`$@```%M^`@`-````;GX"
M``H```!\?@(`%@```(=^`@`9````GGX"``<```"X?@(`)@```,!^`@`"````
MYWX"``,```#J?@(`#P```.Y^`@`%````_GX"`!(````$?P(`&0```!=_`@`*
M````,7\"``L````\?P(`$@```$A_`@`&````6W\"`"$```!B?P(`"0```(1_
M`@`7````CG\"`!<```"F?P(`$@```+Y_`@`"````T7\"``0```#4?P(`#@``
M`-E_`@`/````Z'\"`!````#X?P(`&@````F``@`?````)(`"`"\```!$@`(`
M!@```'2``@`(````>X`"`!<```"$@`(`!0```)R``@`#````HH`"``L```"F
M@`(``0````T$``!#`P```````$T&``#7!P``K0<``!(```"F````Z0,`````
M`````````````&\%``"L`P```````*D!``!&!0``=04``.4'````````T0(`
M``````!X`P```````#D#``````````````````#9``````````````#&!P``
MGP<``!8$``#I`@``0P8``&$'``!S!P```````#$#``#%!@``1@$``(@"```*
M`@``"`(``)\$``#+`0``W````!`&``#=!0``D@<```````!1`P````4``(((
M```B````>0@``````````````````"H#``"=````[`4``&@#``"<`P``O`8`
M`/D$```A!@```````+T'```<!@```````.`%```X`````````'`````]!0``
M`````'T'``"-!P```````/H%```5`0``20(``%<"``!8`P``Z`8``*D"``!]
M!@```````!T(``"M`P``9@@``$T$````````A@8``!$'``!R`P```````#0&
M``!D!P``E`8```````#``@``VP(``'P%``"[!0````````````"7`0``````
M`(8!``!R!P```````!`"``!N!0``DP,``!L(```:!P``N`(```````!X!P``
M`````)(%```\`P``.08``&H```")````Z@```,$#```,!````P@``+X```!9
M!```80@```@#```.`P```````.\"```*`P``P@$`````````````NP```,,%
M``!\!P``,00``,8#``"3`@````````````",`0``P@,``,,!``!&!P``R@$`
M```````0`P````````````"(!P```````+0#````````4`,```````!R````
MTP```$\%```Y!```[0,``!0!```#!@`````````````]!@``N@```(`&``!?
M`@``2`````$$```3`P``\@,``$P!```H`P``L`$``',```#^!P``,0<``,8"
M``#O!`````<``-\$``"8!```;@8````````0`0``O08``-(```!B"```V@4`
M`/,#```M!`````````<#``!)!P``"@8``+(!``!3"```M`4``$P$```8````
M````````````````]`4```````#;`P``(`0``/,$``!6`0```````"$```#&
M!```OP8``&$$``!Y!@``J@0```````!B`@``^`0``,("```7!P```````#H&
M``!Z`````````(\#``#=`@``A00``-,$``!Y`@``;P8``-8$````````T`,`
M`````````````````"\(``"\`P``&04``.\!````````]P8```````#Y`0``
M9@4```````"``0``\0`````````R!```B`0``"\$``"/`0``T@,```````"8
M!@``J@8``#8#```&"`````````H````8!P```````!\"``!`!P``E@$``#<$
M``"Y!0````````\(``!;!0``;@,``#X"````````!@,```````";!```,@@`
M``````!:`@``G0$``'8$`````````````(8%``#I!```SP<``"X(``"N!```
MK@$````````]"`````````````"3!@``;`8``.H"````````ZP,``)4&````
M````P@8````````\"```G@4``+8'``!)`P``S````&H$````````U0(``)\"
M``"@!0```````!4&```?`0````````````#\`0``$P@``,@```#O!P``V@<`
M``````"1!P``&00``*(#``")`P``P@````````#K````V`$``"P```!O!P``
MS`4``)L'``":!P``K`4`````````````,P(````````8!0``<0```'@(```U
M!````````!,```!4!P``T@4``/L'``"1`@``E00``#,$```7````3`<`````
M``#Z`@```````-X'```%!0``EP(```````#V!@```````&L!````````N@4`
M````````````Y`<```````!W!0``LP,``)`&``"D```````````````:!0``
MD@(`````````````#P,``#\```#B`@``7@8``/,"``#!!P``8P$``)X&``!+
M!@```@,``,L&``"S!@```````/`$``"7`P```````.X#``!X`@``T00`````
M``"(`0``5P0``)@%````````4@```'@%``#J!```UP8``)````!,`P``TP$`
M`"<(``"O`0``J``````````%`P``N`,````````X!0``+`8``-\'```'!@``
ME@,``!4%```&!````````.H&``!R`@``!0@``$X(``````````````````"A
M!P``2@<``.0"````````+@4```````#*````P@0``(P#``"[!@``IP,``*('
M``"I!`````,``,X%``!)`0``40$``"X#```L`0``,@$``&<!``!^!@``>@,`
M`+T$``"]!0``<P0```P%``#D!@``FP$``#H(``#]!0```````#P!``#K!```
MJ08```0$```5"```X00```````"D!P``0`4``+\%```X!```>`0````````A
M!P```````%D`````````Z@,```````!(`0``F0````````!C`P``%P8`````
M``"=`P``,`<`````````````\@$``',%```N!```:@8``%8$``#.````````
M```````G!`````````````!-````\04``,P&````````1`$``.`'``#+!```
M[@$``,`$``"@`P```````%`%``#&````+@$``.<&``![!P``7P8```````#+
M`P```````!X#````````$@0``$((``#B!P``:@4``&8`````````^@,``&<$
M````````!P4``,4"```D!@``CP```-L````@`@```````/D%``"9`P``6@0`
M`!,&``!Q!0``&0,``/8```#4`@``OP```+0'``":`@``T@(``,D#````````
M<00`````````````H`$````````K`@``S@(``%H!````````3@0```````##
M````````````````````;P,``,T'```%`@``J@,``&<```````````````X`
M```(!P```````$4"````````(P<``+4"```M!P``1P```#<!``!4!```[`<`
M`"$$``#I!P```````%,$``!1!P``(````(,```#^`0``.`@``&0(````````
MR00``$(!``"Q`@``EP8``,H&``"?`P``<0,``-8&``!]`P``J04``.,!``"Y
M!```V@8``-,#``#4!@``?@@``%L!``#O!0``9```````````````3`8``$X"
M````````````````````````)`@``*$$````````5P,````````%`0``'@(`
M`-0'```)!0``]0<``````````````````,P#`````````````$4(``!,!0``
MM0$``+D'``!?!P``D08```````!B`0``?@$````````H!P```````#,%```>
M!P``[04``$0&```;`0``U00``(T&``#%````%@(``*L"```<!P``>@4``%X%
M``#W!P``V`,``)\```#I!@``A@,``!$&``#W`P```````"`%```Z`P``Z@$`
M````````````@@,``+0$``#<`P``<`(``$P```!Y!P````````@```!2!```
MMP,```````"A!@````````````#"!0``R`4````````<`P``I04``!,"``"'
M!0```````)P'``#7!```_`,```````!>!P``0@0``%4`````````;`,``'4"
M````````_@(````````D`P``#P(``&<'``!I!````````)<```"2`P``````
M`"$%````````OP,``(0&``#3!@``804``%\!``"'!@```````'\%````````
M7P,```````"C!P``^`8``(`#````````"@0``````````````````-`'```;
M!0```````(\&``#Q!```#@(``&L'```)!```'@```%@'``##`P``JP``````
M``"/!P``````````````````]P```+X#````````*0,````````B!P``&0$`
M`%$&``#*!```P`4``#H!``#9!```9@(``!4```!A`0``E@<``*D#``!W`0``
M>P4``%0!``!K````8`$``$(````6`P``1P4``&8$``!6`@``5P$``(4%``#_
M`0``Z`0```<'````````:0@``$H!`````````````#`%``"D`0``\`$``%,%
M``",!@``10,``$@%``!Q!P```````&P"``">!P``3P@`````````````;08`
M`#L%``!3`P``-`(``,<#``#G!0```````%8````B!@``0`0``!D````+````
M`````$8"``"^`@```````&4!``".!0``2P4``%<'``!#````8P0``'@`````
M````@`(````````O!@``&P(``%T(``!,"````````+,'``#1`0``;`$`````
M``!/!@``1@0``',"``````````@``*,$````````%@```(0'```L!P``````
M`!4#``"_`0```````/$'````````BP<``&@"``#=!````````!L$``!)!0``
MDP<``/$!``"1`0``R`$````````#!```=`4``!\$``!K!0``/P4``"4&````
M````%`4``-````!%!0``$P4``,,'``!^`@``V04``!<$``!N`@``4@<``%(&
M```1!````````*<``````````````"`#```-"```WP(``,\%``!U"````@@`
M`)T"```F````#0<``(L#````````[0(```````!U`P``!08````````+`P``
M=`(``"T"```E!P``RP```)0!``#'!0``AP$````````6!0``_0<``!,'````
M````X@,``+<!`````````````*D'``#$!P```````!H"`````````````.4`
M``!V`0``1``````````W!P``:@<```````"O!@``W@,``$`#``#^````&@0`
M`#4'````````:0$``&P%``"H`0```````$8#``"`````.P$``'\`````````
M#P8``,D"``#E!@``E04``"(#``!&````(`<``&X!````````.P````````!C
M"```[0````````"*"````````#L&````````&@$``(8'``#N!0``]@4``!$#
M``"R!`````````````!``0``3@,``+@'````````B0@``'`#```2"```````
M`"\#``"N`P``;0,``+4'``!M`@``@08``)H```!@`@``JP$``)0%````````
M``````P"````````]P$``.@!````````_P``````````````?0(``"@&``!7
M"```/P(`````````````IP<``,<'``"C`0``J`4``!8'`````````````"H`
M``!Z!@```````"<!````````@@(````````7!0``@0@````````,`0``2@@`
M`(($``!D!```(P````("``#\!0``>@0````````!`0``G`(``'<'``"U````
M`````````````````````%4(``!"!P``]`8```````#.`P``3P<``*H```#!
M`0``5`````````#_`P``U@(```````````````````<(````````JP,``(0"
M````````[@<``(\"``#]!@``6`@``+P$```A`0``E`(```X'``#G`0``\0(`
M`/,&``"*`P``9`,`````````````(0@```````#'`0```````*T!```9"```
M<`4```X!```Q`@``J0```#4(``#-````UP(``*<$``#]!```J@<``/8#``"T
M`0``90,``&,'```?!P``!@(``-L%``"E`P````````````"+!@````````$(
M``!K!@```````)P&``"Q`P````````$#``!$!```4P(``,D!```P`0``````
M`)T%````````````````````````+0$``/L``````````````),!```^!P``
M\P<``/4"``#$!0``AP,``"X```">````-P(````````X`P```````*T&``#>
M`0``.0```,\$```0````]04``!0&```S`````````.`&````````4@(``&T!
M```7"```\`,```````!<"```=P0``,`!````````2P$```````"X!@``KP(`
M`$,(``"U!0``.P@```````#X`0``)P(```````!G!@``;@<``-P!``#/`0``
M7`4``%X"``!0"````````%\(``""!0``@`<``"`!``"P`@``)00``)4```#A
M`P``'04``/@#``#B`0``?P,``#\$``"P!@``````````````````T`4``-$`
M``#4````@P(```````"!`P``C0$```````#\!P``-P8``+0"``#/````````
M``(%``!H!`````````````"B`0````````````"K!P``S`0```````#-`@``
M"0@``&\$```]`@````````````!T"```508``,<$``"N`@``B@0`````````
M````%P(```\```!2!0``<@8``.L&``#<`@``:@(```````!T!@``&P<``.<$
M````````<@4``+T!````````<0(```````!C!0```````/D#````````(@$`
M`#P"````````+`,``#(```"B````=0<``$4```"[`P``EP<``,P"``"'!P``
MOP<```````"Z!```R@4``(`$``"U!@``=@(````&````````0`@`````````
M`````````-0%```1!0``'`$``/0#``#'!@``!0```)$```#V!```200`````
M``!["```5@<```X%``#/`@``0`8``+$'``"F`@``&@8``&@(``#@!```B08`
M`&D```#E`0````````````!:"```G`4````````2!P``/0```%T````*!P``
M'`4``-0$``#R!```UP`````````\!```E@8``%`"```4`P``70$````````I
M`@```````"D(`````````````%P&````````:````,`#``!D`0``D00``+`'
M``"9`0````````````#L!@```````#H'``!!!```@P0``.$!``#&`0``+`0`
M`!H```#S`0``$`@``)L"``"Q!@```````-D!```D!```[`$``)8`````````
M2`8````````E`0``_`(```````!Q`0```````*`&````````-04``'\!```<
M`@```````-4'`````````````%L&```S`0``50<``'4````>`0``@00``(`(
M``"&"````````,L%````````!`4``/4$````````J@(`````````````````
M``X(```T!0``50$```<```"*!P```````!,!```U`@``N`4```````".!@``
MW0```","````````)0(``)4#``"-!```=@<``'0$````````A0@``!\(``!L
M"`````````````!0!P```````/H$``!6!@```````-,"``"2`0``"P4``-0!
M``````````````````#?!@``&0<```0```!+!P````````````"#"```)@<`
M`'($````````<`<``!(#`````````````+L"``!P!@````````P'```-!@``
M'`0``$<$``#]`@``[P```"H%``#9`P``X`,```````!/`P``9@$``(\$````
M````T0<``+P```![!@``#````'4!``````````0``)\!```M````'0,`````
M``#B!@``F08```````"$!0``>`8``````````````````.,&``#%!0``B04`
M``(!``!-"```"`@``$L````0!P````````0"````````500``*L%``!Y`P``
M`````%T%````````O@<``&\"```)!@``20@```````#G`P````````````#5
M!0````````````"6!0``MP<``(@#``",!```>@$``)L#``!C``````````$&
M``"W!````````)T$``"R!@``?`0``.H'``"$!````````#\#```>!```R`<`
M`+8%``#,`0``-08``.$````D`@``(P$``&L#``#>`@`````````````R!0``
MC`(```````!M!````P4```````#!!```G0<```````"%````*@<``/4#``":
M!```6@<``,4#``#X!0```````-T!```?!@``U0````0&``"C!0``LP0``&('
M``![`@``H@4``.D!````````^````%$$``"^!0```````!\#``#P````K0``
M``````#P`@``=P``````````````Q`,```````!3````"@4`````````````
M```````````1`@``?`,``$,'``#3!P```````'4&``!Y`0``I`0``"L!``!1
M````N0$``#<#```:`P``^@<``*L&`````````````#,'``"_`@``(`8``&L$
M``#B!```^P0````````D````]`<`````````````S@$```````#P!@``<P@`
M````````````(@@`````````````*@@``.@"``",!0````````````#F!```
M#P$``$L#``!9!P``````````````````L`4```\'``!#!0``.`$``'L`````
M````O0,``"<&````````AP@``$(#````````N@(``&@%````````B00``%T"
M``"M`@``QP````````#?````S08``(,&``!4!@``[````.$'``"Q````````
M`-`&``##!```A0<``,('``!.!@```````(4&````````8P(```````":`P``
ME@0``.D%``"N!0``8`8```````"*`@``#0(```````````````````$'```7
M`0````````````!Z`@``;`0``(@%``!&!@``,08```T```"@!```!`<``'@!
M``!T`0``9@8``+0&````````:0<``"(%``#D!```>P$``,X$````````#04`
M`$$&``##`@``VP$``/`'`````````````/0"````````YP<``&`(``!;````
M`````*L$``"'!```2P@``"D!````````-0```-@&``!E!```W`8``)X#````
M`````````$4'```=!@``!@```/P&``#1`P```````,$"```O````9`(``/,`
M``!O"```@0```*4&````````B@8```($```\!0``-````!(%``!H!P``````
M`#<(```(!0``V0<``)X!``#^`P```````/\'``":`0``G````!X%``#U`0``
M*`@```````"<!```M@(``"T(````````B0<``%H``````````````'`(``"O
M!0``/`<``-@"```2!@``*P```$("````````F@4``)4!``#Q!@```````,\&
M``!K"```U@4``+$%``#]`0``&`8`````````````!P(``/(%``#)!P``+P(`
M``````!%!````````#\'````````*`0``"`(````````]@$````````_"```
M`````%X$````````J`<``#X(``!V"```@@$```````"%`0``4`0``.L"```Y
M!0``*08``*X'``"0`0``C0,``"8"``!B!`````````H!``!N"```Q`0``,0`
M``"M!```U08``/8'``"A`@```@<``+(#``!.!P``?P8``/$#``#A`@``````
M`-L&```U`P``OP0``*8#```4`@``C0(```````"-!0``2`,```````#6````
MGP4```0!````````Q0<``.4"``!F`P``?@,``",#``#L`P``V````%0%```X
M!@```````%L$``#]`P``6@4``*0"``"8````V`0``'D```#:`P```````&$`
M``#2!```N@,``(@```"G!@``Y@,```````!>"````````(@&``"!!0``,P@`
M`/D'```)!P``V@(``%@$````````=P8``&<(``!^!```:`$`````````````
M`````&(#````````00(```````#[`@``[@(``#8!``#!````C0``````````
M````"P8``,@$```4"```Y````,`'```+!```;``````````^!@``;04``+<%
M```V````T04``!(!``#:`0``*P4````````)````608```L(``!]"```]@(`
M`#`$``!;!P``Y0,``"L$``"]````I`4``#D'```5!```NP<`````````````
M3P$``)8"``!.`````````'P(``"D!@```````/0!``"H`@```````!<#```:
M"```Y@$``"P%``#H!0``V@0``$T'``"F!0``````````````````9`4``/(&
M````````<08``/X&``!-`0``.@4``!0'``"^`0``Z````.8&``!)````T@8`
M`/\$````````808``*\```!W`@``)P````0#````````>00``+D"``#/`P``
M4P<``#P`````````WP4``%\%```.!@```````)`"```F!```4P$````````F
M!@```P```#D!``"*````W`4``````````````P$```````"^!@``O`$``&(%
M``!R`0```````&P'``"%`P``IP(``"$"````````I00``+`#``"9`@``7`$`
M`!P````+`@````````````!(`@``^0````L!```8"```LP```$<'``#U!@``
MR08``#`"``"+!0``ZP$``)0#``"X!```"`8```````#W`@``EP4```````"+
M````&P,``/(```""!P``/@4``-<!``![`P``T@<``%(!```U`0```````*P!
M``!?!```'@8``,L"``"'````=@4```````#O!@``/`8``"P"``"'`@``:08`
M`#$(````````M@````````!E`````````.X&````````8`<``$\$``"N!@``
M`````((``````````````%D"``"!!P``&`0`````````````30(``,L'``"V
M!```M@8``$$(``#C!P``,@,```````!0!@```````'X%``"8!P``/@0``(X`
M`````````````*P```"Q!```4P8```````"R````^08``&D"``"E!P``#`,`
M```````N!P``F`,```````!%!@``N````)L````*"```Q@4```,#``"F`0``
M`````"("```R!P``=00``,`````I````)0````````!8!@``LP4``'((````
M````S@<```4'```X`@``00````@$``"U!```4`$```@!``!4`P```````(`%
M```&`0``S0,``&D%```+!P``(0,``!4'`````````````'P&````````.P(`
M`+,!````````CP4`````````````G@(``(P'``"A`````````#`(``"V`0``
M708``(X"``!O`0```````(L!````````7@,``#L'``".`P``W`<``&4&```2
M`@``8P8``,@"``!$`P``DP4```````#A!@``XP```+("````````3@4``)$%
M````````_P(```P(````````_P4``.T&````````$`4``.P"``#*`@``````
M`.<```"L!```.@```(8$``"5!P``X`$``$@$``!8`0``?`(``%8(``!=!P``
MV`4``-@'```H!0````````````!/````.0@```````"H!@``*````'P!``"Z
M`0```````&4(````````WP,`````````````:@,``"H!````````N0```,4!
M``#]``````````````!F!P``NP$``#````!"!@``0P0```````!*!```+P$`
M`+P%``#K!0```````"<%````````*00```````"3!```EP0`````````````
MB`@``*``````````)P<````````Z`@````````D!``"$"```2@4``"L'``"+
M`@``#P0```````"E`@``?0```,<"``#*!P``1`@``$4!````````0`(``',!
M`````````````'<#```C"```<0@``-,%```K`P``U0$```````"W````````
M`#X!``#@``````````````!'!@``HP```(X'``!2`P``!P$`````````````
MN`$```````#0`@``H@0```````"Y!@``@0$``"T&````````Y@```!\%``!]
M!```(@0``#0(````````J`0``$H#```P!@``@P$``*,#```H`0``]P0``",$
M``#T````L0$``$@(`````````````/L#```6!@``````````````````B0(`
M``D#````````XP4``.8%``!O````D`,``.0!```T!P``D@0``+,"````````
MH`<``"D'```-`P``,04``%P'``!1"```D0,``%0"``!_"```)0,``)D%````
M`````````%X```#T!```.@0``'X```!7````]0```-X%``!,`@``S04``)L%
M``!<`P```````,H#```W```````````````8`P``60$```8'``!#`@``````
M`%H#``"5`@``D`<``%D#````````NP0``)X$``#)`````````)(````]!```
M90(``-L$``"R!0````````````!J`0``A@(``*H!``"C!@``-@(```````#\
M!```9P,``&(&`````````````*$#````````^@8``#D"```W!0``+`@``'8&
M```Q````[0<```````!_!P``V08``+('```F"```2@(``.4$``!8!0``50,`
M``````#-!````````+<&```V!P```````*<!``!S!@``'@@````````.!```
MI`,``/@'``"C`@`````````"``"#!P``=P@``#T'```P`P``]P4``&``````
M````^P8````````_!@```````$0"``"\!P``*P8``!\```#4`P``````````
M```!`@``IP4``((&```=`@``-@@``#\!``!8`````````-8'``!0````1P,`
M`$H&``!:!@``)@$``+0````;`````````%\````#`@``$0$``.D```"O!```
M```````````Q`0``[`0```(&````````C@0``#0!``"#!0``B@4``-<#``!7
M!0``)04``'H'``#^!```````````````````904````````1````?P0``!T!
M``#@`@``5@4``&(````T`P```````"0%``#N````R04```````!N!```````
M`"@"``#0!````````'P`````````)0@``.@#```0!```)@4`````````````
M70,``%P```"J!0``H@8``-(!``!T`P``Z`<``/L!``#7!0``XP0``%4%````
M````P08``-T'``#C`@``L`0``"H$``````````````````#>!```````````
M````````Q`8``$,!``#G`@``````````````````X04``&$"``!'`@``````
M``````!T!P``/0,```````!P!```%`0``&T(````````\@<``$L$``!<!```
M6P@``*P&```S`P```````+D#``"B`@``P`8``!$(``"^!````````%$"```8
M`0``^`(``-$&`````````````````````````````%$%```%!````````.L'
M``#>`````````&0&``#C`P``[0$``$\"``!M!P```````&4'``")`0``````
M``````#F!P``_@4``!4"``"A`0````````````!9!0``4@@``'X'``!`````
MJ`,``.(```!)!@```````"D%``#6`0``30,``"<#``!_`@``^0(````````V
M!@``.P0```````#\`````````/H!``!K`@``-@0``$X!```N!@```````+8#
M``"8`@``H04```,'`````````````'H(```)`@`````````!``"0!```=@,`
M``````!>`0``S0$``*8$``#$`0``MP(``%@"``!I`P``^P4``)\&``!&"```
MY@(``.X$````````)`<```````"<`0``FP8``$$'````````;@````````"L
M!P``?04```````!@!```9P(```````!J"``````````````D`0``>04``$@'
M``"9!P```````)H&``!!`P``Q@8`````````````W`0``",%``"#`P``````
M```````````````````````'!```1P@````````O!P```@```)@!``!9"```
MI0$``+4#````````#P4``#L#``!<`@```````&<%```6"```P04```````#M
M!````````#(&``!"!0``C@$``'0```#%!```I0```*\#``"\`@``A@```-L'
M`````````````"H"``"0!0``X@4``,P'``!+`@``````````````````````
M`#8%```&!0```````*\'``##!@``A`$``)0$``!=!```&P8```````!!!0``
M`````*8'``!6`P``+04``),```!M`````````'T!````````304``#T!````
M````K`(```````#D!0``%@$``*T%``!*````_P8```````!P`0``````````
M````````.`<``'L$``!'`0```````.0#``!7!@```````!0```"F!@``````
M`',#`````````04``"L(`````````````%0(````````#`8``-T&``"*`0``
MR`,``,X&``"!`@``[P,``!,$```-`0```````+H'````````L````#X#````
M`````````(P```#:````)@,``)0'````````+@(``#X````M`P``````````
M``#$`@``&`(``,@&``"$`P``K@```#,&``````````````````#5`P``8`4`
M``````#?`0``G08```````#J!0``=@```(0`````````'`@``+T"```C!@``
MA0(``!T'```&!@````````````#Z``````````````#9`@``E````/("````
M````!`@``-`!``!;`@``BP0``)(&``!$!0``*@8``"\%``!5`@``\`4``&@&
M``"Z!@``U@,``#("`````````````!D"``!;`P``1`<``&`#``#>!@``80,`
M`/,%````````'00``.4%`````````````$$!````````H`(``!D&``"9!```
M`````#0$```=````W0,````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E
M<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E
M<F1A>2D`($%D9"!A;B!)35-0($%D9')E<W,@0F]O:P`@1&5L971E($E-4U`@
M061D<F5S<R!";V]K`"!A="``(B5S(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S
M(&YO="!I;7!O<G1E9"X`(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E
M<R(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N`"(E<R(@
M=V%S(&YO="!C<F5A=&5D.B`E<RX`(B5S(B!W87,@;F]T(&UO=F5D(&)E8V%U
M<V4@:70@:7,@82!L:7-T+@`B1FER<W1N86UE($QA<W1N86UE(B`@*&EE+B!*
M;VAN($1O92D`(DQA<W1N86UE+"!&:7)S=&YA;64B("AI92X@1&]E+"!*;VAN
M*0`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E
M<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N
M`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E
M<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S
M(&%D9&5D+@`E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@9FEL
M92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU
M=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO
M;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI
M;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E
M<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U
M<P!!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D
M`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--
M24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@
M0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N
M;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O
M=70N+BX`06)O=F4@<V5A<F-H(&9O<FT`06)S8F]T=&]M`$%B<VUI9&1L90!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D96YI960@=&\@)7,`
M06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@
M9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H
M:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE
M=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@
M861D<F5S<R!B;V]K`$%D9"!A;F0@1&5L971E($E-4U`@861D<F5S<R!B;V]K
M<P!!9&0@8V]L=6UN`$%D9"!F:6QE`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O
M`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`
M061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!
M9&1I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92X`061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&1R97-S($)O
M;VL@3&ES=&EN9P!!9&1R97-S($)O;VMS`$%D9')E<W,@8F]O:R!E;G1R>0!!
M9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"X`061D<F5S<R!B;V]K
M('1O(&1E;&5T92``061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I
M<W!L87EE9#H`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%D=F%N8V5D(%-E87)C:`!!
M9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM
M96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!
M;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_
M`$%L<F5A9'D@17AI<W1S`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0
M($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0
M(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T
M96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H
M87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S
M(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`
M07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R
M96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA
M=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&
M:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!T:&%T('EO=2!W
M86YT('1O(&1E;&5T92`E<S\`07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@
M=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/P!!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N
M>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-
M4T-)22TX*0!!<G0`07)U8F$`07-C96YD:6YG`$%S8V5N<VEO;B!)<VQA;F0`
M07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S
M<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C
M>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B
M:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO
M="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W
M:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!
M3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D
M('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@
M870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE
M8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@
M17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`
M0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A
M9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"
M87-E;&EN90!"87-I8R!396%R8V@`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"
M96QO=R!S96%R8V@@9F]R;0!"96YI;@!"97)M=61A`$)H=71A;@!":6YD(&9A
M:6QE9#H@*"5S*2`E<P!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T
M:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E
M`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE
M<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W
M86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GD`0G)O=W-E`$)R=6YE:2!$87)U<W-A;&%M`$)U
M;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0G5S
M:6YE<W,@0V%T96=O<GD`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<P!#4U8`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@
M8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B
M`$-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BX`0V%N)W0@861M:6YI<W1E
M<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A
M`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F
M:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R
M+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E
M+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O
M9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H
M(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G
M;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E
M;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#
M96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#
M96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A
M=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA
M;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U
M<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#
M:&5C:R!?06QL+TYO;F4`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D
M("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!
M<'!L:6-A=&EO;CH`0VAO;W-E(&$@;F%M90!#:&]O<V4@82!P87-S=V]R9`!#
M:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@861D<F5S<R!B;V]K`$-H;V]S
M92!A;B!A9&1R97-S(&)O;VLZ`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E
M<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I
M`$-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I
M;B!W:&%T(&]R9&5R.@!#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U
M<V4N`$-H;V]S92!W:&EC:"!C;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H
M870@;W)D97(Z`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE
M87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@
M=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI
M8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%
M87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO
M<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@3W!T:6]N
M<P!#;VQU;6X@=&ET;&5S`$-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P
M;&%Y960Z`$-O;6EC<P!#;VUM82!S97!A<F%T960@=F%L=65S`$-O;6UA('-E
M<&%R871E9"!V86QU97,@*$UI8W)O<V]F="!/=71L;V]K*0!#;VUM86YD`$-O
M;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A
M;GD`0V]M<&%N>2!!9&1R97-S`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET
M:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S
M`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC
M(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO
M;B!F86EL960Z(`!#;VYN96-T:6]N(&9A:6QE9#H@)7,`0V]N;F5C=&EO;B!F
M86EL=7)E`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`0V]N=&%C="!396%R8V@`0V]N=&%C=',`0V]N=&%C=',@:6X@
M;&ES=#H@)7,`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D
M(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD
M<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`
M0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N
M("5S`$-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E
M='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@
M8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@
M;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO
M="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R
M<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E
M($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R
M971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R
M="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@
M;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`
M0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG
M=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U
M;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U
M<G-E<P!#<F5A=&4`0W)E871E($%D9')E<W,@0F]O:P!#<F5A=&4@82!L:6YK
M`$-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@:6XZ`$-R96%T92!A(&YE=R!O
M;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S
M:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@
M-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N
M="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N
M="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP
M<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$
M1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E
M($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$
M871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C
M:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9F%U;'0@
M<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@
M061D<F5S<R!";V]K`$1E;&5T92!#96QL`$1E;&5T92!#;VYF:7)M871I;VX`
M1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8G5T=&]N(&)E:&%V:6]U
M<@!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&9A:6QE9#H@*"5S*2`E<P!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!$96QE=&EN9R!C;VYT86-T<R!I<R!N;W0@879A
M:6QA8FQE+@!$96QE=&EO;B!F86EL960`1&5L:79E<GD@=&EM90!$96YM87)K
M`$1E<&%R=&UE;G0`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$
M97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I
M<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y
M(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@
M;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_
M`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E
M<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO
M860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@4$A0('-C<FEP="X`1&]W;FQO860@=D-A<F0`1')O<"!D;W=N(&QI
M<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@
M9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`
M16-U861O<@!%9&ET`$5D:70@(B5S(@!%9&ET($%D9')E<W,@0F]O:W,`161I
M="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI
M<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@96YT<GD@9F]R
M("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E
M<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L
M(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M
M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE
M<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y
M96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@
M=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE
M='1E<G,@8F5L;W<Z`$5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG
M('1H92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,`16YT<GD@9F]R("5S('5P
M9&%T960N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@
M861D:6YG("5D(&-O;G1A8W0H<RD@=&\@;&ES="X`17)R;W(@861D:6YG("5D
M(&]F("5D(')E<75E<W1E9"!C;VYT86-T*',I('1O(&QI<W0N`$5R<F]R(&-R
M96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R`E9"!C;VYT86-T*',I
M+@!%<G)O<B!D96QE=&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C=',H
M<RDN`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE
M=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%
M<G)O<B!R96UO=FEN9R`E9"!C;VYT86-T*',I(&9R;VT@;&ES="X`17)R;W(@
M<F5M;W9I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@9G)O;2!L
M:7-T+@!%<G)O<B!S96%R8VAI;F<@=&AE(&%D9')E<W,@8F]O:SH@)7,`17)R
M;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T
M:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`
M179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`
M17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X
M<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A
M=&EO;B!$871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@061D<F5S<R!";V]K
M`$5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T<RX`17AP;W)T('1H
M92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,`
M1F%I;&5D('1O(&%D9"`E<R!T;R`E<SH@)7,`1F%I;&5D('1O(&)R;W=S92!L
M:7-T`$9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R>0!&86EL960@=&\@
M8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@/2`E
M<RP@4F]O="`]("5S`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@
M8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&9I
M;F0@;V)J96-T('1O(&)E(&%D9&5D.B`E<P!&86EL960@=&\@;6]V92!T;R`B
M)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:6QE9"!T;R!S96%R8V@@
M=&AE(&%D9')E<W,@8F]O:P!&86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O
M<GDZ("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E
M($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L
M<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W
M97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&
M:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I
M;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QE<P!&
M:6QT97)S`$9I;F0`1FEN:7-H`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!.
M86UE`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!
M1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@
M>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R
M='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R
M86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E8G5S>2!54DP`1G)E;F-H
M($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@
M36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`
M1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A
M<@!':79E;B!.86UE`$=L;V)A;"!!9&1R97-S($)O;VL`1V\`1V]E9&5L`$=O
M;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E
M:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7``1W)O=7`@
M061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D
M96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G
M<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R
M;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE
M82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T
M86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F
M;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R
M<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3
M=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U
M<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@0VET>0!(
M;VUE($-O=6YT<GD`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VUE(%!O
M<W1A;"!#;V1E`$AO;64@4W1A=&4O4')O=FEN8V4`2&]M92!3=')E970@061D
M<F5S<P!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(
M;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M
M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I
M;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E
M<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)35-0
M`$E-4U`@061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N`$E0($%D9')E<W,`
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H
M:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN
M`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@
M9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET
M(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN
M(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T
M:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@
M<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@
M=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O
M=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA
M9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L
M;V%D`$EM86=E<P!);7!O<G0@061D<F5S<R!";V]K+"!3=&5P("5D`$EM<&]R
M="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($%D9')E<W,@0F]O:W,`26UP;W)T
M960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T
M97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@
M86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E
M87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!)
M;F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@
M5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!)
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L
M871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!)
M;G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@
M8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P
M:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F
M=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS
M=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!)
M;6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T
M;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT
M(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!)1`!);G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A
M`$EN=F%L:60@861D<F5S<R!B;V]K`$EN=F%L:60@87!P;&EC871I;VXN`$EN
M=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L
M:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!E;6%I;`!);G9A;&ED
M(&5N=')Y`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!K97D@<W!E8VEF
M:65D+@!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&YA;64`26YV86QI
M9"!O8FIE8W1)9`!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES
M<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D
M92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`
M26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`
M26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T
M:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES
M;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A
M;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/
M+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S
M=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y
M(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W
M8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`
M2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`
M2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$Q$05`@<W5P<&]R
M="!I<R!R97%U:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I
M;&%B;&4@;W(@;F]T(&QO861E9"X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!-;V1I
M9FEE9`!,87-T($YA;64`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R
M=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U
M=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T
M(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB
M>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ
M;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T
M90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,
M:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN
M:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE
M`$QI<W0`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T
M86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H
M:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI
M<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N
M<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG
M('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D
M:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`
M3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,
M;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,
M;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L
M971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R
M<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-
M86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I
M=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O
M8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U
M97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I
M=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T
M:6YI<75E`$UA=&-H:6YG`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA
M=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@
M;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',`36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-
M87AI;75M(&YU;6)E<B!O9B!P86=E<P!-87D`36%Y;W1T90!-961I8VEN90!-
M96UB97)S`$UE;G4@3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A
M9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N
M97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A
M9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D
M("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L
M;&%N96]U<P!-:7-S:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R871I
M;VXN`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN
M9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@
M:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@
M;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V)I;&4@
M4&AO;F4`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9&EF
M>2!F86EL960Z("@E<RD@)7,`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O
M9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT
M<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@
M)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F4@=&AA;B`Q(&5N=')Y(&9O
M=6YD`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY
M(%-U;FYY`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO
M=F4@57``36]V92!D;W=N`$UO=F4@;&5F=`!-;W9E(')I9VAT`$UO=F4@=7``
M36]Z86UB:7%U90!-=6QB97)R>2!!9&1R97-S($)O;VL`375L=&DM;&5V96P@
M9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!P97)S
M;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S
M72!A;')E861Y(&5X:7-T`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT
M`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@061D<F5S<R!";V]K`$UY($%D
M9')E<W,@0F]O:W,`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA
M<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UE($9O<FUA=`!.86UI8FEA
M`$YA=7)U`$YE<&%L`$YE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y`$YE=&AE
M<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),
M`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC
M>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W
M;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!#;VYT
M86-T`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H
M;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O
M<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T
M8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`
M3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI
M8VMN86UE`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R`E<R!E;G1R
M>2!F;W5N9"!F;W(@)7,`3F\@861D<F5S<R!B;V]K<R!F;W5N9"X`3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM
M86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T
M:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED
M960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI
M;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&
M4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-O;G1A8W1S(&9O=6YD`$YO(&-R
M961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U
M<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.
M;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@
M;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N
M<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG
M('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R
M('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9#87)D(&1A=&$@=V%S(&9O=6YD
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`
M3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F
M;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA
M;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@
M9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R
M=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB
M97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU
M;6YS`$YU;6)E<B!O9B!I=&5M<R!P97(@<&%G90!.=6UB97(@;V8@<F]W<P!.
M=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U
M=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V)J96-T(&YO
M="!F;W5N9`!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P
M87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYC
M92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D<F5S<R!B;V]K
M('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E9"X@268@=&AI<R!I<R!N;W0@
M=VAA="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N9V4@>6]U<B!S96QE
M8W1I;VX@=&\@(DYO;F4B+@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H
M87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE('9C87)D('-U<'!O
M<G1E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@
M4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R
M9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I
M9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS
M`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG
M;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,
M:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`
M4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG
M`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA
M;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A
M`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA
M;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R
M9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R
M9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S
M=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`
M4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B
M(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N(&1E
M;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0
M97)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO
M;F4`4&AO=&]S`%!I;F4@061D<F5S<R!";V]K`%!I=&-A:7)N`%!I>&5L<P!0
M;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&YA;64@=&AE
M(&YE=R!C;VYT86-T(&QI<W0Z`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O
M9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9
M;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E
M;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`
M4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F
M;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E
M`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0
M<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W`%!R979I;W5S`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE
M;G0`4')I=F%T92!!9&1R97-S($)O;VL`4')I=F%T92!+97D`4')O8FQE;0!0
M<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI
M8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U97)Y(&9A:6QE9#H@*"5S
M*2`E<P!1=6EC:R!396%R8V@`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I
M="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`
M4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M
M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&9A:6QE9#H@*"5S*2`E<P!296%D
M(&UE<W-A9V5S`%)E861I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92X`
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92X`4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_`%)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!296-O<F1S(&1I<W!L87EE9#H`4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M
M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP
M($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!2
M96UO=F4@0FQO8VL`4F5M;W9E(&%D9')E<W,@8F]O:P!296UO=F4@8V]L=6UN
M`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M('1H:7,@;&ES=`!296UO
M=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297!L86-E(&5X:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I;7!O
M<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R!D96QE=&5S(&%L;"!E
M;G1R:65S(&EN('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN/"]S=')O;F<^
M`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@`%)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+@!297%U97-T960@
M<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W
M;W)D`%)E<V5T('1O($1E9F%U;'1S`%)E<W1O<F4@3&%S="!1=65R>0!297-U
M;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U
M;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S
M`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2
M;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R
M;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@
M0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E`%,O34E-12!0=6)L:6,@0V5R=&EF:6-A=&4`4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L
M;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!35$%25%1,
M4R!F86EL960Z("@E<RD@)7,`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT
M($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I
M;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN
M;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A
M=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N
M<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D
M("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B`B)7,B+@!3879I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92X`
M4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I
M;F5S`%-E87)C:"!F86EL960`4V5A<F-H(&9A:6QE9#H@)7,`4V5A<F-H:6YG
M(&ES(&YO="!A=F%I;&%B;&4N`%-E87)C:&EN9RXN+@!396QE8W0@1FEL97,`
M4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@
M;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D
M9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE
M8W0@86X@861D<F5S<R!B;V]K('1O(&1E;&5T90!396QE8W0@86X@861D<F5S
M<R!B;V]K('1O(&5D:70`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!3
M96QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3H`4V5L96-T
M('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.@!396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82X`4V5L96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z`%-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SH`
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=FEE=R!T;R!D
M:7-P;&%Y(&)Y(&1E9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O
M<'1I;VYS+@!396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE
M(&%D9')E<W,@;&ES=',N`%-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA
M>2!N86UE<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&5C=&5D(&%D9')E<W,@8F]O:R`B
M)7,B+@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N
M<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@
M3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E
M<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@
M;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z(`!397EC:&5L;&5S`%-H87)E9"!$:7)E8W1O<GD`4VAO<'!I;F<`4VAO
M<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\`4VAO=P!3:&]W("5S`%-H;W<@06QL`%-H;W<@0V]N=&%C
M=',`4VAO=R!,:7-T<P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO
M=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%
M87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR
M:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U
M<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA
M:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`
M4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@
M3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``
M4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T($1I
M<F5C=&EO;@!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3
M;W5R8V5S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3
M<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P96-I9GD@=VAE<F4@>6]U
M('=A;G0@861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R+@!3<&QI
M="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK
M80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V
M:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R
M:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@
M861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@
M9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D
M9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL
M('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U
M8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(&%D9&5D("5D(&-O;G1A8W0H<RD@=&\@;&ES="X`4W5C
M8V5S<V9U;&QY(&%D9&5D("5S('1O("5S`%-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@(B5S(BX`4W5C8V5S<V9U
M;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(&1E;&5T960@)60@8V]N
M=&%C="AS*2X`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!R96UO=F5D("5D(&-O;G1A8W0H<RD@9G)O
M;2!L:7-T+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C
M:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T
M960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3
M=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`
M4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T
M`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z
M:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN
M8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@
M4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4
M+5-T;W)M<R!%87)L>0!44U8`5%-6(&9I;&4`5&%B('-E<&%R871E9"!V86QU
M97,`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O
M<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II
M:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!4
M87-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E
M;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(
M:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`
M5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A
M;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!61E,@
M8F%C:V5N9"!N965D<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A
M8VAM96YT('5P;&]A9',N`%1H92!A9&1R97-S(&)O;VL@(B5S(B!D;V5S(&YO
M="!E>&ES="X`5&AE(&%D9')E<W,@8F]O:R`B)7,B('=A<R!C<F5A=&5D('-U
M8V-E<W-F=6QL>2X`5&AE(&%D9')E<W,@8F]O:R`B)7,B('=A<R!R96UO=F5D
M('-U8V-E<W-F=6QL>2X`5&AE(&%D9')E<W,@8F]O:R`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@=7!D871E9"X`5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@
M8F4@<'5R9V5D.B`E<P!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY
M`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`5&AE(&-O;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E
M>&ES="X`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("(E<R(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!I;7!O<G0@8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A
M<FYI;F=S+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W
M:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O
M('1H92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B
M92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC
M92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M
M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U
M;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E
M(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@
M>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R
M965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I
M9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E
M(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO(&]P
M=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO('=R:71E86)L92!A
M9&1R97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B
M;V]K<R!A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E
M;G1R:65S('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@:7,@86X@97)R
M;W(L('!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N
M(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B
M)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE
M87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T
M96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@
M;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<B!F;W(@9G5R=&AE<B!H96QP+@!4:&5R92!W87,@86X@97)R;W(@8W)E871I
M;F<@82!N97<@;&ES="X`5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H
M:7,@861D<F5S<R!B;V]K.B`E<P!4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@(B5S(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+@!4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES=`!4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D9')E
M<W,@8F]O:SH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@
M96YT<GDZ("5S`%1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="X`
M5&AE<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E
M<CH`5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CH`
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R
M9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H
M:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`
M5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@
M=&AE(&%D9')E<W,@8F]O:P!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H
M:7,@=VEL;"!B92!T:&4@9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I
M;F<@;W(@:6UP;W)T:6YG(&-O;G1A8W1S+@!4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T
M<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I
M;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A
M>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O
M;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A
M9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`
M5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@
M:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W
M:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R92X@
M36ES<VEN9R!S;W5R8V4@='EP92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O
M(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A
M<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F
M86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E
M860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL
M;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@
M>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R
M86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET
M960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W
M;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO
M;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL
M:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@
M<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA
M=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@
M)7,`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D
M871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D
M+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M
M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S
M97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T
M:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E
M<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE
M.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T
M;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B
M;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)I<VEG;B!$:7)E
M8W1O<GD`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`
M5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M
M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`B)7,B`%9I97<@)7,`5FEE=R!#
M;VYT86-T`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6
M:65W('1O(&1I<W!L87D@8GD@9&5F875L=#H`5FER9VEN($ES;&%N9',L($)R
M:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL
M:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10
M`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S
M=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E
M8B!3:71E`%=E8G-I=&4@55),`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H
M25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E
M;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I
M9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED
M=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7
M:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I
M<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K($-I='D`5V]R
M:R!#;W5N=')Y`%=O<FL@4&AO;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K(%-T
M871E+U!R;W9I;F-E`%=O<FL@4W1R965T($%D9')E<W,`5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`
M6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E
M9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8
M-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N
M<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@
M06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T
M=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I
M;B`B)7,B+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T
M(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N`%EO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N<R!T;R!D96QE=&4@=&AI<R!S;W5R8V4N
M`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N
M(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P
M<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R
M92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A('1A<F=E
M="!A9&1R97-S(&)O;VLN`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T
M+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO
M=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="X`66]U
M(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M
M8F5R`%EO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N
M=&%C="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@
M;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R
M<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N`%EO=7(@9&5F875L
M="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@
M<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9
M;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!:
M:6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!;;F\@=F%L=65=`%]!9&UI;FES
M=')A=&EO;@!?0G)O=W-E`%]#3$D`7T-O;G1A8W1S`%]$871A5')E90!?1&5L
M971E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I
M97,N+BX`7TEM<&]R="]%>'!O<G0`7TQI<W1S`%],;V<@:6X`7TQO9R!O=70`
M7TUO9&EF>2!,:6YK+BXN`%]->2!!9&1R97-S($)O;VMS`%].97<@0V]N=&%C
M=`!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]296UO
M=F4@9G)O;2!T:&ES(&QI<W0`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E
M<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W
M;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N
M;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C;VYT86-T+G9C9@!C;VYT86-T
M<RYC<W8`8V]N=&%C=',N='-V`&-O;G1A8W1S+G9C9@!C<FET:6-A;"!S>7-T
M96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5N=')Y(&YO="!F
M;W5N9`!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G
M=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI
M;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R
M`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RX`;6T`;F%M90!N;R!F;W)M871T:6YG`&YO;F4`;F]T(&EM<&QE;65N=&5D
M`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I
M;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES
M:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R
M96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI
M<W0`=&5M<&]R87)Y(&9A:6QU<F4`=&\@82!#;VYT86-T($QI<W0`=&\@82!D
M:69F97)E;G0@061D<F5S<R!";V]K`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D
M`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@9G)?1E(*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#(M,3@@,C(Z,S@K,#$P,`I03RU2979I<VEO
M;BU$871E.B`R,#`V+3`R+3$Y(#`Y.C4U*S`Q,#`*3&%S="U4<F%N<VQA=&]R
M.B!4:&EE<G)Y(%1H;VUA<R`\=&AI97)R>4!P;VUP;RYN970^"DQA;F=U86=E
M+51E86TZ($9R86[G86ES(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U6
M97)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H\
M8F5N0&)E;F]I='-T+6%N9')E+FYE=#X*4&QU<F%L+49O<FUS.B!N<&QU<F%L
M<STR.R!P;'5R86P]*&X@/B`Q*3L*`"`H:6P@>2!A("5S(&IO=7)S*0`@*%1O
M=6-H92!D)V%C8^AS(')A<&ED92`E<RD`("AD86YS("5S(&IO=7)S*0`@*&%U
M:F]U<F0G:'5I*0`@*&1E;6%I;BD`("AH:65R*0!!:F]U=&5R('5N(&-A<FYE
M="!D)V%D<F5S<V5S($E-4U``4W5P<')I;65R('5N(&-A<FYE="!D)V%D<F5S
M<V5S($E-4U``(.`@`*N@)7.@NR!E>&ES=&%I="!DZ6K@(&5T(&XG82!P87,@
MZ73I(&EM<&]R=.DN`*N@)7.@NR!N)V5S="!P87,@=6X@9&]S<VEE<@"KH"5S
MH+L@;B=E<W0@<&%S('5N(&-H;VEX('9A;&ED92X`JZ`E<Z"[(&XG97-T('!A
M<R!C;VYF:6=U<ND@9&%N<R!L92!R96=I<W1R92!D92!(;W)D92X`3"=I;G1E
M<G!RZ71E=7(@9"=A<F)R92"KH"5SH+L@;B=A('!A<R#I=.D@=')O=7;I+@"K
MH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64@9&5S(&=R;W5P97,N`*N@
M)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM92!D97,@<&5R;6ES<VEO;G,N
M`*L@)7,@NR!N)V$@<&%S(.ETZ2!C;W!IZ2!P87)C92!Q=64@8R=E<W0@=6YE
M(&QI<W1E+@"KH"5SH+L@;B=A('!A<R#I=.D@8W+IZ:`Z("5S+@"K("5S(+L@
M;B=A('!A<R#I=.D@9.EP;&%CZ2!P87)C92!Q=64@8R=E<W0@=6YE(&QI<W1E
M+@"KH%!RZ6YO;2!.;VV@NR`@*&,N(.`@9"XN($UI8VAE;"!4<F5M8FQA>2D`
MJZ!.;VTL(%!RZ6YO;:"[("`H8RX@X"!D+BX@5')E;6)L87DL($UI8VAE;"D`
M)2XR9J!-;R!U=&EL:7/I<R!S=7(@)2XR9J!-;R!P97)M:7,@*"4N,F:@)24I
M`"5D("5S(&5T("5S`"5D(&IO=7)S(&%V86YT(&PG97AP:7)A=&EO;B!D92!V
M;W1R92!M;W0@9&4@<&%S<V4N`"5D+7!RZ79I<VEO;B!D=2!J;W5R`"5S("T@
M3F]T:6-E`$5M<')E:6YT92!01U`@9&4@)7,`)7.@2V\`)7,@;W#I<F%T:6]N
M<R!D92!M86EN=&5N86YC92`F;F1A<V@[($-O;F9I<FUA=&EO;@!#;VYF:6=U
M<F%T:6]N("5S`$EN<V-R:7!T:6]N(&1E("5S`$-O;F1I=&EO;G,@9"=U=&EL
M:7-A=&EO;B!D92`E<P`E<R!A:F]U=.DN`"5S(&5X:7-T92!DZ6K@+@`@)7.@
MX"`E<R`E<P!F:6-H:65R("5S(&EM<&]R=.D@879E8R!S=6-CZ',`)7,@97-T
M('!RZG0@X"!E9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N
M8V4@8V]C:.EE<R!C:2UD97-S;W5S+B!3Z6QE8W1I;VYN97H@;&$@;W4@;&5S
M(&]PZ7)A=&EO;BAS*2!Q=64@=F]U<R!V;W5L97H@969F96-T=65R(&-E='1E
M(&9O:7,M8VDN`"5S(&5S="!O8FQI9V%T;VER90`E<R!M:6YU=&5S`"5S(&YO
M;B!T<F]U=ND`)7,@X"`E<R!S=7(@)7,`0V%R;F5T(&0G861R97-S97,@9&4@
M)7,`06=E;F1A(&1E("5S`$)L;V,M;F]T97,@9&4@)7,`3&ES=&4@9&4@=.)C
M:&5S(&1E("5S`"5SH#H@)7,`)7.@.B!L)^EM971T975R(&1E(&-E(&UE<W-A
M9V4@82!P=2#J=')E(&9A;'-I9FGI+B!!='1E;G1I;VX@96X@<W5I=F%N="!L
M97,@;&EE;G,@<74G:6P@8V]N=&EE;G0@;W4@96X@9F]U<FYI<W-A;G0@9&5S
M(&EN9F]R;6%T:6]N<R!P97)S;VYN96QL97,@X"!L)^EM971T975R+@`L(&5N
M(')A9F%L92``<F%F86QE("5S("5S`'9A<FEA8FQE(&1U("5S(&%U("5S`"TM
M(%/I;&5C=&EO;FYE<B`M+0!&;W)M870@,3(@:&5U<F5S`$9O<FUA="`R-"!H
M975R97,`,C0@:&5U<F5S`#Q0<NECZ61E;G0`56X@;F%V:6=A=&5U<B!S=7!P
M;W)T86YT(&QE<R!C861R97,@*&E&<F%M97,I(&5S="!R97%U:7,`56YE(&)A
M<V4@9&4@9&]N;NEE<R!P<FEN8VEP86QE("AB86-K96YD*2!E<W0@;NEC97-S
M86ER92!P;W5R(&-E(&)L;V,`56YE(&5R<F5U<B!F871A;&4@<R=E<W0@<')O
M9'5I=&4`56YE(&-L968@<'5B;&EQ=64@4$=0(&5S="!NZ6-E<W-A:7)E('!O
M=7(@8VAI9F9R97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4$=0
M(&5S="!NZ6-E<W-A:7)E('!O=7(@=NER:69I97(@;&$@<VEG;F%T=7)E(&0G
M=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4$=0+"!U;F4@8VQE9B!P
M<FEVZ64@4$=0+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A
M:7)E<R!P;W5R(&3I8VAI9F9R97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B
M;&EQ=64@4$=0+"!U;F4@8VQE9B!P<FEVZ64@4$=0+"!E="!U;F4@<&AR87-E
M('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E<R!P;W5R('-I9VYE<B!U;B!M97-S
M86=E+@!5;F4@8VQE9B!P=6)L:7%U92!3+TU)344L('5N92!C;&5F('!R:7;I
M92!3+TU)344L(&5T('5N92!P:')A<V4@<V5C<NAT92!S;VYT(&[I8V5S<V%I
M<F5S('!O=7(@9.EC:&EF9G)E<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L
M:7%U92!3+TU)344L('5N92!C;&5F('!R:7;I92!3+TU)344L(&5T('5N92!P
M:')A<V4@<V5C<NAT92!S;VYT(&[I8V5S<V%I<F5S('!O=7(@<VEG;F5R('5N
M(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%,O34E-12!E<W0@;NEC97-S
M86ER92!P;W5R(&-H:69F<F5R('5N(&UE<W-A9V4N`$YU86=E<R!L92!M871I
M;@!0;'5I92!LZ6?H<F4@;&4@;6%T:6X`4&QU:64@;&4@;6%T:6X`079E<G-E
M<R!L92!M871I;@!#:'5T97,@9&4@;F5I9V4@;&4@;6%T:6X`04TO4$T`05!)
M($E$`,`@<')O<&]S(&1E(&-E="#I9&ET975R`,`@<')O<&]S+BXN`$%U+61E
M<W-U<R!D=2!F;W)M=6QA:7)E(&1E(')E8VAE<F-H90!"87,@86)S;VQU`$UI
M;&EE=2!A8G-O;'4`06-CZ',@<F5F=7/I(&QO<G,@9&4@;&$@8W+I871I;VX@
M9&4@<NEP97)T;VER92!61E,@+@!!8V/H<R!R969U<^D@;&]R<R!D92!L82!C
M<NEA=&EO;B!D92!F:6-H:65R(%9&4RX`06-CZ',@X"`E<R!R969U<^D`1&]N
M;NEE<R!P97)S;VYN96QL97,`36]T(&1E('!A<W-E(&1U(&-O;7!T90!#;VUP
M=&4@:6YA8W1I9@!#;VUP=&5S`$%J;W5T97(`06IO=71E<B!U;B!S;W5S+6=R
M;W5P90!!:F]U=&5R('5N92!N;W5V96QL92!S;W5S+7!E<FUI<W-I;VX`06IO
M=71E<B!I8VF@.@!!:F]U=&5R('5N(&YO=79E874@9W)O=7!E`$%J;W5T97(@
M=6YE(&YO=79E;&QE('!E<FUI<W-I;VX`06IO=71E<B!U;B!G<F]U<&4@9FEL
M<R#@(*N@)7.@NP!!:F]U=&5R('5N92!P97)M:7-S:6]N(&9I;&QE(.`@JZ`E
M<Z"[`$%J;W5T97(@=6X@;F]U=F5L('5T:6QI<V%T975RH#H`06IO=71E<B!U
M;B!C87)N970@9"=A9')E<W-E<P!!:F]U=&5R(&5T('-U<'!R:6UE<B!D97,@
M8V%R;F5T<R!D)V%D<F5S<V5S($E-4U``06IO=71E<B!U;F4@8V]L;VYN90!!
M:F]U=&5R('5N(&9I8VAI97(`06IO=71E<B!D92!N;W5V96%U>"!M96UB<F5S
M`$%J;W5T97(@=6YE('!A:7)E`$%J;W5T97(@;&4@;65N=2`E<R#@(&QA(&)A
M<G)E(&1E($UO>FEL;&$`06IO=71E<B#@`$%J;W5T97(@874@8V%R;F5T(&0G
M861R97-S97.@.@!!:F]U=&5R(.`@;6]N(&-A<FYE="!D)V%D<F5S<V5S`$%J
M;W5T97(@=6X@=71I;&ES871E=7(`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S
M>7-TZ&UE+"!M86ES(&PG86IO=70@9"=I;F9O<FUA=&EO;B!S=7!P;.EM96YT
M86ER97,@)7,@;B=E<W0@<&%S('!O<W-I8FQE+@"KH"5SH+L@82#I=.D@86IO
M=73I+B!6;W5S('!O=79E>B!V;W5S(&-O;FYE8W1E<BX`3"=A:F]U="!D92!C
M;VYT86-T<R!N)V5S="!P87,@9&ES<&]N:6)L92X`3&$@9F]N8W1I;VX@9"=A
M:F]U="!D)W5T:6QI<V%T975R<R!E<W0@9.ES86-T:7;I92X`061R97-S90!#
M87)N970@9"=A9')E<W-E<P!,:7-T92!D97,@86YN=6%I<F5S`$-A<FYE=',@
M9"=A9')E<W-E<P!$;VYNZ65S(&1U(&-A<FYE="!D)V%D<F5S<V5S`$-A<FYE
M="!D)V%D<F5S<V5S(&YE='1O>>D@879E8R!S=6-CZ',N`$-A<FYE="!D)V%D
M<F5S<V5S(.`@<W5P<')I;65R(`!#87)N970@9"=A9')E<W-E<R!Q=6D@;F4@
M<V5R;VYT('!A<R!A9F9I8VCI<Z`Z`$%D;6EN:7-T<F%T975R("T@86IU<W1E
M<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!D)V%U=')E<R!U=&EL:7-A=&5U<G,`
M061M:6YI<W1R871I;VX`4'5B<P!296-H97)C:&4@879A;F/I90!!9F=H86YI
M<W1A;@!!;&)A;FEE`$%L9^ER:64`06QI87,`06QI9VYE<@!!;&EG;F5M96YT
MH#H`5&]U=`!4;W5S(&QE<R!P87)T:6-I<&%N=',@875T:&5N=&EF:>ES`%1O
M=7,@;&5S(&=R;W5P97,`5&]U=&5S(&QE<R!P97)M:7-S:6]N<P!,97,@<75A
M=')E(&/T=.ES`%!E<FUE='1R92!D97,@861R97-S97,@9&4@8V]U<G)I96P@
M;75L=&EP;&5S`$%U=&]R:7-E<B!L82!M:7-E(&5N('!L86-E(&1E(&QI<W1E
M<R!N=6WI<F]TZ65SH#\`17AI<W1E(&3I:N``17AI<W1E(&3I:N``3F]M(&0G
M=71I;&ES871E=7(@24U34"!A;'1E<FYA=&EF`$UO="!D92!P87-S92!)35-0
M(&%L=&5R;F%T:68`3F]M(&0G=71I;&ES871E=7(@24U34"!A;'1E<FYA=&EF
M`$%D<F5S<V4@9&4@8V]U<G)I96P@86QT97)N871I=F4`075T<F5S(&UO9.AL
M97,`5&5X=&4@86QT97)N871I9J`Z`%-A;6]A($%MZ7)I8V%I;@!5;F4@=F%L
M975R(&EL;.EG86QE(&$@Z73I('-PZ6-I9FGI92X`56YE(&5R<F5U<B!I;F-O
M;FYU92!S)V5S="!P<F]D=6ET92X`06YD;W)R90!!;F=O;&$`06YG=6EL;&$`
M4')O>'D@86YO;GEM90!2Z7!O;G-E`$%N=&%R8W1I<75E`$%N=&EG=6$M970M
M0F%R8G5D80!!<'!L:6-A=&EO;@!,:7-T92!D)V%P<&QI8V%T:6]N<P!,)V%P
M<&QI8V%T:6]N(&5S="!P<NIT90!!<'!L:7%U97(@875X('!A<G1A9V5S(&9I
M;',`07!P<F]U=ND`5&%I;&QE(&%P<')O>&EM871I=F4`079R:6P`07)A8F4@
M*%=I;F1O=W,M,3(U-BD`5&%I;&QE(&1U(&9I8VAI97(@87)C:&EV90!.;VT@
M9&4@;"=A<F-H:79E`,IT97,M=F]U<R!C97)T86EN(&1E('9O=6QO:7(@<W5P
M<')I;65R("5SH#\`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!S=7!P
M<FEM97(@;&5S(&5N='+I97,@<^EL96-T:6]N;NEE<Z`_`,IT97,M=F]U<R!C
M97)T86EN(&1E('9O=6QO:7(@<W5P<')I;65R(&-E='1E(')E<77J=&4@9"=I
M;G-C<FEP=&EO;B`@<&]U<B`E<Z`_`,IT97,M=F]U<R!C97)T86EN(&1E('9O
M=6QO:7(@969F86-E<B"KH"5SH+L@970@<V5S('-O=7,M9W)O=7!E<Z`_`$%R
M9V5N=&EN90!!<FWI;FEE`$%R;>EN:65N("A!4DU30TE)+3@I`$%R=`!!<G5B
M80!!<V-E;F1A;G0`07-C96YS:6]N("C.;&4I`$%R="!!4T-)20!2Z6=I;VX@
M07-I92]086-I9FEQ=64`1&5M86YD97(@=6YE(&-O;F9I<FUA=&EO;B!A=F%N
M="!D92!L86YC97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V6@/P!#
M;VQO;FYE<R!D97,@=.)C:&5S`%1E;G1A=&EV92!D)V5F9F%C96UE;G0@9"=U
M;B!G<F]U<&4@:6YE>&ES=&%N="X`5&5N=&%T:79E("!D)V5F9F%C96UE;G0@
M9"=U;F4@<&5R;6ES<VEO;B!I;F5X:7-T86YT92X`5&5N=&%T:79E(&1E(&UO
M9&EF:6-A=&EO;B!D)W5N92!P97)M:7-S:6]N(&EN97AI<W1A;G1E+@!496YT
M871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6X@<&%R=&%G92!I;F5X:7-T86YT
M+@!0<F]P<FGI=.ES`$%O^W0`075S=')A;&EE`$%U=')I8VAE`$%U=&A?8WER
M=7.@.B!%>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE+@!!=71H
M7V-Y<G5SH#H@;&4@8F%C:V5N9"!N)V$@<&%S(&QE<R!C87!A8VETZ7,@<F5Q
M=6ES97,N`$%U=&A?8WER=7.@.B!E>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO
M;B!T<F]U=NEE`$%U=&A?9G1PH#H@97AT96YS:6]N(')E<75I<V4@1E10(&YO
M;B!T<F]U=NEE+B!);"!F875T(&-O;7!I;&5R(%!(4"!A=F5C(&PG;W!T:6]N
M("TM96YA8FQE+69T<"X`075T:%]I;6%PH#H@97AT96YS:6]N(')E<75I<V4@
M24U!4"!N;VX@=')O=7;I92X`075T:%]K<F(UH#H@97AT96YS:6]N(')E<75I
M<V4@:W)B-2!N;VX@=')O=7;I92X`075T:%]L9&%PH#H@;"=A:F]U="!D)W5T
M:6QI<V%T975R<R!N)V5S="!P87,@<W5P<&]R=.D@879E8R!!8W1I=F4@1&ER
M96-T;W)Y`$%U=&A?;&1A<*`Z(&QE(')E=')A:70@9"=U=&EL:7-A=&5U<G,@
M;B=E<W0@<&%S('-U<'!O<G3I(&%V96,@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE+@!!
M=71H7VQD87"@.B!I;7!O<W-I8FQE(&0G86IO=71E<B!L)W5T:6QI<V%T975R
M("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U('-E<G9E=7*@.B``075T:%]L
M9&%PH#H@:6UP;W-S:6)L92!D92!S=7!P<FEM97(@;"=U=&EL:7-A=&5U<B`E
M<P!!=71H7VQD87"@.B!M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D92!L)W5T
M:6QI<V%T975R("5S`$%U=&A?;&1A<*`Z(&QA(&UO9&EF:6-A=&EO;B!D97,@
M=71I;&ES871E=7)S(&XG97-T('!A<R!S=7!P;W)TZ64@879E8R!!8W1I=F4@
M1&ER96-T;W)Y+@!!=71H7VUC86R@.B!E>'1E;G-I;VX@<F5Q=6ES92!-0T%,
M(&YO;B!T<F]U=NEE+@!!=71H7W-M8F%U=&B@.B!E>'1E;G-I;VX@<F5Q=6ES
M92!S;6)A=71H(&YO;B!T<F]U=NEE+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC
M871I;VX@874@<V5R=F5U<B!)34%0+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC
M871I;VX`R6-H96,@9&4@;"=A=71H96YT:69I8V%T:6]N("5S`$QE('-E<G9E
M=7(@4D%$2553(&$@<F5J973I(&PG875T:&5N=&EF:6-A=&EO;BX`R6-H96,@
M9&4@;"=A=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@1E10+@#)8VAE8R!D
M92!L)V%U=&AE;G1I9FEC871I;VX@874@<V5R=F5U<B!334(N`$-H86UP<R!D
M:7-P;VYI8FQE<Z`Z`$%Z97)B8>]D:F%N`$5X8W5S97,@0D]&2`!#;W5L975R
M(&1E(&9O;F0`0V]U;&5U<B!D92!F;VYD`$UO="!D92!P87-S92!+97)B97)O
M<R!E<G)O;NDN`$YO;2!D92!C;VYN97AI;VX@2V5R8F5R;W,@97)R;V[I+@!"
M86AA;6%S`$)A:')E[VX`0F%L=&4@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H
M`$)A<F)A9&4`4NEP97)T;VER92!D97,@9W)A<&AI<75E<R"KH"5SH+L@;F]N
M('1R;W5VZ2X`3&EG;F4@9&4@8F%S90!296-H97)C:&4@<VEM<&QE`$+I;&%R
M=7,`0F5L9VEQ=64`0F5L:7IE`$%U(&1E<W-O=7,@9'4@9F]R;75L86ER92!D
M92!R96-H97)C:&4`0NEN:6X`0F5R;75D97,`0FAO=71A;@#)8VAE8R!D=2!L
M:65NH"@E<RDZ("5S`$%N;FEV97)S86ER90!";&]C(*LE<R"[(&1E(&PG87!P
M;&EC871I;VX@JZ`E<Z"[(&EN8V]N;G4`4'+I9NER96YC97,@9&4@8FQO8P!4
M>7!E(&1E(&)L;V,`1W)A<P!";VQI=FEE`%-I9VYE=',`0F]R9'5R90#)<&%I
M<W-E=7(@9&4@;&$@8F]R9'5R9:`Z`$)O<F1S`$)O<VYI92U(97)ZZ6=O=FEN
M90!,97,@9&5U>`!";W1S=V%N80!"87,`0F]U=F5T`$)RZ7-I;`!497)R:71O
M:7)E<R!B<FET86YN:7%U97,@9&4@;"=/8^EA;B!);F1I96X`4&%R8V]U<FER
M`%-U;'1A;F%T(&1U($)R=6[I:0!"=6QG87)I90!,:7-T92#@('!U8V5S`$)U
M<FMI;F$@1F%S;P!"=7)U;F1I`$-A=.EG;W)I92!A9F9A:7)E`$=E<W1I;VX@
M9&4@8V]N=&5N=0!#4D,`1&ES=')I8G5T:6]N(&1E<R!P;VEN=',@3%)#("A,
M:7-T92!D92!RZ79O8V%T:6]N(&1E<R!C97)T:69I8V%T<RD`0U-6`%!R;W!R
M:>ETZ7,@9&4@;&$@0U]E;&QU;&4`3"=I;FET:6%L:7-A=&EO;B!D=2!C86-H
M92!N92!S)V5S="!P87,@=&5R;6ENZ64N`$%G96YD80!#86QM90!#86UB;V1G
M90!#86UE<F]U;@!);7!O<W-I8FQE(&1E('+I:6YI=&EA;&ES97(@;&4@;6]T
M(&1E('!A<W-E(&%U=&]M871I<75E;65N="P@8V]N=&%C=&5Z('9O=')E(&%D
M;6EN:7-T<F%T975R('-Y<W3H;64N`$EM<&]S<VEB;&4@9&4@<W5P<')I;65R
M(&QE(&9I8VAI97(@JZ`E<Z"[+@!);7!O<W-I8FQE(&0G86IO=71E<B!U;B!G
M<F]U<&4@X"!L=6DM;>IM92X`26UP;W-S:6)L92!D)V%D;6EN:7-T<F5R(&1E
M<R!G97-T:6]N;F%I<F5S(&1E('-E<W-I;VX@97AT97)N97,N`,EC:&5C(&1E
M(&QA(&-O;FYE>&EO;B!A=2!S97)V975R($E-05"@.B`E<P!);7!O<W-I8FQE
M(&0G;W5V<FER(&QE(&9I8VAI97(@JZ`E<Z"[+@!#86YA9&$`06YN=6QE<@!!
M;FYU;&5R(&QE(')A<'!O<G0@9'4@<')O8FSH;64`26UP;W-S:6)L92!D92!S
M=7!P<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@=')O
M=79E<B!U;B!RZ7!E<G1O:7)E('1E;7!O<F%I<F4`26UP;W-S:6)L92!D92!P
M<F]CZ61E<B!S86YS(&QE('!A<F%MZ'1R92"K('1A<F=E=$9I;&4@NP!);7!O
M<W-I8FQE(&1E('-U<'!R:6UE<B!L92!RZ7!E<G1O:7)E(*N@)7.@NRX`4W5P
M<')E<W-I;VX@:6UP;W-S:6)L92P@:6P@>2!A("5D(&5N<F5G:7-T<F5M96YT
M<R!F:6QS+@!);7!O<W-I8FQE(&1E('+I;W)D;VYN97(L(&QE(&YO;6)R92!D
M)^ELZ6UE;G1S(.`@<NEO<F1O;FYE<B!N92!C;W)R97-P;VYD('!A<R!A=2!N
M;VUB<F4@9"?I;.EM96YT<R!E;G)E9VES='+I<RX`3F4@<&5U="!D:7)I9V5R
M(&QE(&UE<W-A9V4@=F5R<R!L92!N;VUB<F4@<W#I8VEF:>DN`$-A<"U697)T
M`$SI9V5N9&4`5')A;G-P;W)T975R`$-A=.EG;W)I97,@970@R71I<75E='1E
M<P#.;&5S($-A[VUA;@!4Z6SI<&AO;F4@8V5L;'5L86ER90!0<F]P<FGI=.ES
M(&1E(&QA(&-E;&QU;&4`4F5M<&QI<W-A9V4@875T;W5R(&1E(&QA(&-E;&QU
M;&6@.@!0<F]P<FGI=.ES(&1E(&QA(&-E;&QU;&4`17-P86-E;65N="!D92!L
M82!C96QL=6QEH#H`5.ELZ7!H;VYE(&-E;&QU;&%I<F4@`$-E;'1E("A)4T\M
M.#@U.2TQ-"D`0V5N=')E<@!2Z7!U8FQI<75E(&-E;G1R869R:6-A:6YE`$5U
M<F]PZ65N(&-E;G1R86P@*$E33RTX.#4Y+3(I`$3I=&%I;',@9'4@8V5R=&EF
M:6-A=`!0<F]P<FGI=&%I<F4@9'4@8V5R=&EF:6-A=`!0;VQI=&EQ=64@9&4@
M8V5R=&EF:6-A=&EO;@!48VAA9`!-;V1I9FEE<@!-;V1I9FEE<B!V;W1R92!M
M;W0@9&4@<&%S<V4`0VAA;F=E<B!L92!N;VTL(&PG861R97-S92!E="!L82!S
M:6=N871U<F4@<75E(&QE<R!P97)S;VYN97,@=F]I96YT('%U86YD(&5L;&5S
M(&QI<V5N="!E="!RZ7!O;F1E;G0@X"!V;W,@;65S<V%G97,N`$QA(&UO9&EF
M:6-A=&EO;B!D92!V;W1R92!M;W0@9&4@<&%S<V4@;B=E<W0@<&%S('-U<'!O
M<G3I92!A=F5C(&QA(&-O;F9I9W5R871I;VX@86-T=65L;&4N($-O;G1A8W1E
M>B!V;W1R92!A9&UI;FES=')A=&5U<BX`0VAA<@!6Z5]R:69I97(@;&4@;&EE
M;@!6Z7)I9FEE<B!?5&]U="]2:65N`$-H:6QI`$-H:6YE`$-H:6YO:7,@<VEM
M<&QI9FGI("A'0C(S,3(I`$-H:6YO:7,@=')A9&ET:6]N;F5L("A":6<U*0!#
M:&]I<VER(&PG87!P;&EC871I;VZ@.@!#:&]I<VER('5N(&YO;0!#:&]I<VER
M('5N(&UO="!D92!P87-S90!#:&]I<VER('5N(&YO;2!D92!C;VYN97AI;VX`
M0VAO:7-I<B!U;B!C87)N970@9"=A9')E<W-E<P!#:&]I<VER('5N(&-A<FYE
M="!D)V%D<F5S<V5SH#H`0VAO:7-I<B!L92!M;V1E(&0G869F:6-H86=E(&1E
M<R!D871E<Z`Z`$-H;VES:7(@;&4@<W1Y;&4@9&4@;&ES=&4@*'!O=7(@;&5S
M(&QI<W1E<R!N=6WI<FEQ=65S*0!#:&]I<VER('%U96QS(&-A<FYE=',@9"=A
M9')E<W-E<R!A9F9I8VAE<BP@970@9&%N<R!Q=65L(&]R9')EH#H`0VAO:7-I
M<B!Q=65L(&-A<FYE="!D)V%D<F5S<V5S('5T:6QI<V5R+@!#:&]I<VES<V5Z
M('%U96QL97,@8V]L;VYN97,@869F:6-H97(@970@9&%N<R!Q=65L(&]R9')E
MH#H`SFQE<R!#:')I<W1M87,`1.EF:6YI=&EO;B!D92!L82!C;&%S<V4@9&4@
M)7,@;F]N('1R;W5VZ64N`$5F9F%C97(`3F5T=&]Y97(@;&5S(&)A;&ES97,@
M35,M3V9F:6-E`$5F9F%C97(@;&$@<F5Q=>IT90!2971I<F5R(&PG=71I;&ES
M871E=7(Z("5S`$5F9F%C97(@;"=U=&EL:7-A=&5U<@!%9F9A8V5R(&QE<R!D
M;VYNZ65S(&1E(&PG=71I;&ES871E=7(`R6-L86ER8VEE<R!T87)D(&1A;G,@
M;&$@:F]U<F[I90!#;&EQ=65R('!O=7(@<&]U<G-U:79R90!#;&EC:V%T96QL
M('9I82!(5%10`$9E<FUE<B!L82!F96[J=')E`$YU86=E<P!.=6%G97,@;6%T
M:6YA=7@`3G5A9V5U>`#.;&5S($-O8V]S`%)E<&QI97(@;&$@8F%R<F4@9&4@
M8_1TZ0!2Z61U:7)E(&QE<R!B;W)D<P!#;VQO;6)I90!#;W5L975R`%!A;&5T
M=&4@9&4@8V]U;&5U<G,`4^EL96-T:6]N(&0G=6YE(&-O=6QE=7(`0V]L<Z`Z
M`$]P=&EO;G,@9&5S(&-O;&]N;F5S`%1I=')E<R!D92!C;VQO;FYE`$-O;&]N
M;F5S('%U:2!N92!S97)O;G0@<&%S(&%F9FEC:.EE<Z`Z`$(N1"X`5F%L975R
M<R!SZ7!A<NEE<R!P87(@9&5S('9I<F=U;&5S`%9A;&5U<G,@<^EP87+I97,@
M<&%R(&1E<R!V:7)G=6QE<R`H36EC<F]S;V9T($]U=&QO;VLI`$-O;6UA;F1E
M`$-O;6UA;F1E('-H96QL`$-O;6UE;G1A:7)E`$YO;2!U<W5E;`!#;VUO<F5S
M`%-O8VGI=.D`061R97-S92!P<F]F97-S:6]N;F5L;&4`3W)D:6YA=&5U<G,`
M0V]N9&ET:6]N`$-O;F1I=&EO;G,`1&EF9NER96YC97,@9&4@8V]N9FEG=7)A
M=&EO;@!3>6YC:')O;FES871I;VX@9&5S(&%S<VES=&%N=',@<&5R<V]N;F5L
M<RP@/$D^<VUA<G1P:&]N97,\+TD^(&5T($]U=&QO;VLN`$QA(&-O;F9I9W5R
M871I;VX@;B=E<W0@<&%S(.`@:F]U<BX`0V]N9FEG=7)E<B`E<P!#;VYF:7)M
M97(@;&4@;6]T(&1E('!A<W-E`$-O;F=O`%+I<'5B;&EQ=64@9.EM;V-R871I
M<75E(&1U($-O;F=O`,EC:&5C(&1E(&QA(&-O;FYE>&EO;@#)8VAE8R!D92!L
M82!C;VYN97AI;VZ@.B``3&$@8V]N;F5X:6]N(&$@Z6-H;W7IH#H@)7,`R6-H
M96,@9&4@;&$@8V]N;F5X:6]N`$-O;FYE>&EO;B!A=2!S97)V975R(&1E(&-L
M969S('!U8FQI8R!R969U<^EE+@!#;VYN97AI;VX@874@<V5R=F5U<B!D92!C
M;&5F<R!P=6)L:6,@<F5F=7/I92X@4F%I<V]NH#H@("5S("@E<RD`R6-H96,@
M9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@1E10`%)E8VAE<F-H92!D92!C
M;VYT86-T<P!#;VYT86-T<P!#;VYT86-T<R!D86YS(&QA(&QI<W1EH#H@)7,`
M0V5S(&-O;G1A8W1S(&]N="!B:65N(.ETZ2!A:F]U=.ES(.`@=F]T<F4@8V%R
M;F5T(&0G861R97-S97,N`%1Y<&4@9&4@8V]N=&5N=2!D=2!F:6-H:65R(&-O
M;7!R97-SZ:`Z(`!#;VYT96YU(&1E(*N@)7.@NP!0;W5R<W5I=G)E`,YL97,@
M0V]O:P!4Z6UO:6X@*&-O;VMI92D`0V]P:65R`,EC:&5C(&1E(&QA(&-O<&EE
MH#H@)7,`4^EL96-T:6]N(&0G=6YE(&-O<&EE`$ED+B!C;_MT`$-O<W1A(%)I
M8V$`0_1T92!D)TEV;VER90!);7!O<W-I8FQE(&1E(&-H:69F<F5R(&QE(&UE
M<W-A9V6@.B``4VEG;F%T=7)E(%!'4"!D=2!M97-S86=E(&EM<&]S<VEB;&6@
M.B``26UP;W-S:6)L92!D92!C:&EF9G)E<B!L92!M97-S86=E(&%V96,@4R]-
M24U%+@!3:6=N871U<F4@4R]-24U%(&1U(&UE<W-A9V4@:6UP;W-S:6)L92X`
M06IO=70@9'4@8V]N=&%C="`E<R!I;7!O<W-I8FQE+B``3F4@<&5U="!S92!C
M;VYN96-T97(@874@<V5R=F5U<B!,1$%0+@!.92!P975T('-E(&-O;FYE8W1E
M<B!A=2!S97)V975R($Q$05``5NER:69I8V%T:6]N(&1E(&QA(&)A;&%N8V4@
M)7,@:6UP;W-S:6)L92X@`,EC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V
M975R($Q$05``R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@JZ`E
M<Z"[('9I82!&5%"@.B`E<P!#<NEA=&EO;B!D92!L:7-T92!D92!D:7-T<FEB
M=71I;VX@:6UP;W-S:6)L92X@)7,`26UP;W-S:6)L92!D92!DZ6-H:69F<F5R
M(&QE<R!D;VYNZ65S(%!'4*`Z(`!);7!O<W-I8FQE(&1E(&3I8VAI9F9R97(@
M;&5S(&1O;F[I97,@4R]-24U%+@!.92!P975T('!A<R!S=7!P<FEM97(@;&4@
M8V]N=&%C="`E<P!.92!P975T('!A<R!S=7!P<FEM97(@;&$@;&ES=&4@9&4@
M9&ES=')I8G5T:6]N("5S`$YE('!E=70@<&%S('-U<'!R:6UE<B!L92!S8W)I
M<'0@9&4@;6ES92#@(&IO=7(@JZ`E<Z"[+@!$Z71E<FUI;F%T:6]N(&1E(&PG
M861R97-S92!D=2!D97-T:6YA=&%I<F4@:6UP;W-S:6)L92X`3F4@<&5U="!R
MZ6-U<.ER97(@=&]U="!L92!C87)N970@9"=A9')E<W-E+@!.92!P975T('+I
M8W5PZ7)E<B!T;W5T92!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN`$XG82!P
M87,@<'4@<NEC=7#I<F5R(&QA(&QI<W1E(&-O;7!LZ'1E(&1E(&QI<W1E<R!D
M92!D:7-T<FEB=71I;VXN`$EM<&]S<VEB;&4@9&4@8VAA<F=E<B!L82!S=')A
M=.EG:64@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(&-RZ65R(&QE('+I<&5R=&]I
M<F4@JZ`E<Z"[+@!);7!O<W-I8FQE(&0G;V)T96YI<B!L82!C;&5F('!U8FQI
M<75E(.`@<&%R=&ER(&1U('-E<G9E=7(@9&4@8VQE9G,N`$]U=F5R='5R92!D
M92"KH"5SH+L@:6UP;W-S:6)L92!E;B#I8W)I='5R92X`3W5V97)T=7)E(&1E
M("5S(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9"=O=79R:7(@;&4@;6]D=6QE
M($UA:6YT96YA;F-E7U1A<VL@)7,`3W5V97)T=7)E(&1U(&1O<W-I97(@JZ`E
M<Z"[(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9"=A='1E:6YD<F4@;&4@<V5R
M=F5U<B!,1$%0+@!,96-T=7)E(&1E("5S(&EM<&]S<VEB;&4N(`!.)V$@<'4@
M<F5M971T<F4@X"!ZZ7)O(&QE(&UO="!D92!P87-S92!P;W5R(&PG=71I;&ES
M871E=7(@9&5M86YDZ2X@0V5R=&%I;G,@*&]U('1O=7,I(&QE<R!DZ71A:6QS
M(&YE('-O;G0@<&%S(&-O<G)E8W1S+B!2Z65S<V%Y97H@;W4@8V]N=&%C=&5Z
M('9O=')E(&%D;6EN:7-T<F%T975R('!O=7(@9&4@;"=A:61E+@!2Z6-U<.ER
M871I;VX@9&5S($%#3"!I;7!O<W-I8FQE`$YE('!E=70@<NEC=7#I<F5R(&QE
M(&-A<FYE="!D)V%D<F5S<V5S+B`E<P!.92!P975T('+I8W5PZ7)E<B!L82!L
M:7-T92!D92!D:7-T<FEB=71I;VXN("5S`$YE('!E=70@<NEC=7#I<F5R(&QE
M<R!L:7-T97,@9&4@9&ES=')I8G5T:6]N+B`E<P!.92!P975T('+I8W5PZ7)E
M<B!L97,@<&]S<VEB:6QI=.ES(&1U('-E<G9E=7(`3F4@<&5U="!P87,@<F5V
M96YI<B#@(&QA(&-O;F9I9W5R871I;VX@<'+I8^ED96YT92X`169F86-E;65N
M="!D=2!D;W-S:65R(*N@)7.@NR!I;7!O<W-I8FQE+B``3F4@<&5U="!P87,@
M96YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B`E<P!.92!P975T('!A<R!E
M;G)E9VES=')E<B!U;F4@<V%U=F5G87)D92!D92!L82!C;VYF:6=U<F%T:6]N
M+@!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@=6YE(&-O<&EE(&1E(&QA(&-O
M;F9I9W5R871I;VZ@.B`E<P!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@;&4@
M<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&1A;G.@.B"KH"5SH+LN`$EM<&]S<VEB
M;&4@9"=E;G)E9VES=')E<B!U;F4@8V]P:64@9'4@9FEC:&EE<B!D92!C;VYF
M:6=U<F%T:6]N("5S+@!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@;&4@9FEC
M:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+B!6;W5S('!O=79E>B!S;VET('5T
M:6QI<V5R('5N92!D97,@;W!T:6]N<R!P;W5R('-A=79E<B!L92!C;V1E('-U
M<B`E<R!S;VET(&-O<&EE<B!M86YU96QL96UE;G0@;&4@8V]D92!C:2UD97-S
M;W5S(&1A;G,@)7,N`$YE('!E=70@<&%S(')E8VAE<F-H97(@;&4@<V5R=F5U
M<B!,1$%0+@!3=7!P<F5S<VEO;B!D92"KH"5SH+L@:6UP;W-S:6)L92X`36ES
M92#@(&IO=7(@9'4@8V]N=&%C="!I;7!O<W-I8FQE+B`E<P!.92!P975T(&UE
M='1R92#@(&IO=7(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<P!.92!P
M975T('!A<R!E;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N('!O=7(@JZ`E
M<Z"[H#H@)7,`3F4@<&5U="!T<F]U=F5R(&QA(&)A<G)E(&1E($UO>FEL;&$N
M("!!<W-U<F5Z+79O=7,@<74G96QL92!E<W0@86-T:79E+@!.92!P975T(&%T
M=')I8G5E<B!C97,@9')O:71S(.`@;"=U=&EL:7-A=&5U<B"KH"5SH+L@('-U
M<B!L92!D;W-S:65R(*N@)7.@NZ`Z("5S`%1E>'1E(&-O;7!TZ0!087ES`$-O
M=7)S`$-RZ65R`$-RZ65R('5N(&-A<FYE="!D)V%D<F5S<V5S`$-RZ65R('5N
M(&QI96X`0W+I97(@=6YE(&YO=79E;&QE(&QI<W1E(&1E(&-O;G1A8W1S(&1A
M;G.@.@!#<NEE<B!U;B!N;W5V96%U`$-RZ65R('5N('-O=7,M9&]S<VEE<@!#
M<NGI`%!E<FUI<W-I;VYS($1E($-RZ6%T975R`$YU;>ER;R!D92!C87)T92!D
M92!C<NED:70`0W)O871I90!#=6)A`#0@<&AA<V5S(&-O=7)A;G1E<P!397-S
M:6]N<R!E;B!C;W5R<P!(975R92!A8W1U96QL90!,)V%D<F5S<V4@55),(&%C
M='5E;&QE(&5S=`!5=&EL:7-A=&5U<G,@86-T=65L<P!/8G-E<G9A=&EO;G,@
M86-T=65L;&5S`$-O;F1I=&EO;B!A8W1U96QL9:`Z(`!3='EL92!C;W5R86YT
M`$3I9FEN:7(@;&5S('3B8VAE<R#@(&5F9F5C='5E<B!L;W)S(&1E(&QA(&-O
M;FYE>&EO;B#@("5S+@!#;W5P97(`0V]U<&5R(&QA('/I;&5C=&EO;@!#:'EP
M<F4`0WER:6QL:7%U92`H2T])."U2*0!#>7)I;&QI<75E("A7:6YD;W=S+3$R
M-3$I`$-Y<FEL;&EQ=64O56MR86EN:65N("A+3TDX+54I`%+I<'5B;&EQ=64@
M5&-HZ'%U90!*2@!$4TX@*$-F+B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$-H87%U
M92!J;W5R`$YA=FEG871E=7(@9&4@1&%T851R964`06QI87,@9&4@;&$@8F%S
M90!$871E`$1A=&4@9&4@<NEC97!T:6]N`%/I;&5C=&EO;B!D)W5N92!D871E
M`$IO=7(`4W5P<')I;65R(%]L82!C;VQO;FYE`$3I8V5M8G)E`$YO;6)R97,@
M9.EC:6UA=7@`1&EM:6YU97(@;"=I;F1E;G1A=&EO;@!$Z69A=70`0V]U;&5U
M<B!P87(@9.EF875T`$ED96YT:73I('!A<B!DZ69A=70`26YT97)P<NET975R
M(&1E(&-O;6UA;F1E('!A<B!DZ69A=70`3W)D<F4@9&4@=')I('!A<B!DZ69A
M=72@.@!$Z69I;FET:6]N<P!%9F9A8V5R`%-U<'!R:6UE<B!U;B!C87)N970@
M9"=A9')E<W-E<P!%9F9A8V5R(&QA(&-E;&QU;&4`0V]N9FER;6%T:6]N(&1E
M('-U<'!R97-S:6]N`%-U<'!R:6UE<B!U;B!G<F]U<&4`169F86-E<B!L82!T
M<F%C90!3=7!P<FEM97(@=6YE('!E<FUI<W-I;VX`4W5P<')I;65R(&5T('!U
M<F=E<B!L97,@;65S<V%G97,`0V]M<&]R=&5M96YT(&1U(&)O=71O;B!D92!S
M=7!P<F5S<VEO;@!%9F9A8V5R(&QA(&-E;&QU;&4`169F86-E<B!L82!C;VQO
M;FYE`%-U<'!R:6UE<B!U;B!A=71R92!M;V3H;&4@97AI<W1A;G0`R6-H96,@
M9&4@;&$@<W5P<')E<W-I;VZ@.B`H)7,I("5S`%-U<'!R:6UE<B!L97,@<&5R
M;6ES<VEO;G,@<&]U<B"KH"5SH+L`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U
M;&]I<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U<RUP97)M:7-S:6]N<Z`_
M`$5F9F%C97(@;&$@<F%N9^EE`%-U<'!R:6UE<B!L)VED96YT:73I('/I;&5C
M=&EO;F[I90!%9F9A8V5R(&QA(&-O;&]N;F4@86-T=65L;&4`169F86-E<B!L
M82!R86YGZ64@86-T=65L;&4`4V-R:7!T(&1E(&-O;F9I9W5R871I;VX@9&4@
M;6ES92#@(&IO=7(@<W5P<')I;>D@JZ`E<Z"[+@!,82!S=7!P<F5S<VEO;B!D
M97,@8V]N=&%C=',@;B=E<W0@<&%S(&1I<W!O;FEB;&4N`,EC:&5C(&1E(&QA
M('-U<'!R97-S:6]N`$AE=7)E(&1E(&QI=G)A:7-O;@!$86YE;6%R:P!$Z7!A
M<G1E;65N=`!$97-C96YD86YT`$3I8W)I<F4@;&4@<')O8FSH;64`1&5S8W)I
M<'1I;VX`1.ET86EL<R`H875S<VD@9&%N<R!L92!F:6-H:65R(&1E('1R86-E
M<R!D92!(;W)D92F@.@!,97,@9.ET86EL<R!O;G0@Z73I(&-O;G-I9V[I<R!P
M;W5R(&PG861M:6YI<W1R871E=7(N`$3I=F5L;W!P96UE;G0`4&]I;G0@9&4@
M<F]SZ64`4&]I;G0@9&4@<F]SZ64@<&]U<B!L82!D97)N:>AR92!H975R9:`Z
M(`!0;VEN="!D92!R;W/I9:`Z(`!$92!G875C:&4@X"!D<F]I=&4`1&4@9')O
M:71E(.`@9V%U8VAE`%+I<&5R=&]I<F4`069F:6-H86=E`$%F9FEC:&5R('-U
M<B`R-"!H975R97.@/P!/<'1I;VYS(&0G869F:6-H86=E`$%F9FEC:&5R(&QA
M('!RZ79I<VEO;B!DZ71A:6QLZ64`069F:6-H97(@;&$@<'+I=FES:6]N("A4
M048I`$9O<FUA="!D)V%F9FEC:&%G90!!=FES(&1E(&QI=G)A:7-O;@!$:FEB
M;W5T:0!.92!P87,@<W5P<')I;65R`$YE('!A<R!A8V/I9&5R(&1I<F5C=&5M
M96YT(.`@;6%I;G1E;F%N8V4N<&AP`%9O=6QE>BUV;W5S(&-O;F9I<FUE<B!L
M82!S=7!P<F5S<VEO;B!D97,@96YT<NEE<Z`_`$QE('!R96UI97(@96YR96=I
M<W1R96UE;G0@8V]N=&EE;G0M:6P@;&4@;F]M(&1E<R!C:&%M<'.@/R!$86YS
M(&PG869F:7)M871I=F4L(&-O8VAE>B!C971T92!B;^YT9:`Z`$1O;6EN:7%U
M90!2Z7!U8FQI<75E(&1O;6EN:6-A:6YE`%9O=7,@;B=A=F5Z('!A<R!D92!C
M;VUP=&6@/R!%;G)E9VES=')E>BUV;W5S+@!4Z6SI8VAA<F=E<@!4Z6SI8VAA
M<F=E<B`E<P!4Z6SI8VAA<F=E<B!L82!C;VYF:6=U<F%T:6]N(&?I;NERZ64@
M8V]M;64@=6X@<V-R:7!T(%!(4`!4Z6SI8VAA<F=E<B!V0V%R9`!,:7-T92!D
MZ7)O=6QA;G1E`$1R;V=U97,`0V]U<G)I97(@Z6QE8W1R;VYI<75E`%!I;&]T
M92!D92!P87-S97)E;&QE(&-O=7)R:65R("\@4TU3+"!P;W5R(&QE<R!F;W5R
M;FES<V5U<G,@9&4@8V4@<V5R=FEC92X`15)2`,EQ=6%T975R`,ED:71E<@#)
M9&ET97(@JZ`E<Z"[`,ED:71E<B!L97,@8V%R;F5T<R!D)V%D<F5S<V5S`,ED
M:71E<B!L92!B;&]C`,ED:71E<B!U;B!G<F]U<&4`R61I=&5R('5N92!P97)M
M:7-S:6]N`,ED:71E<B!L97,@<&5R;6ES<VEO;G,`R61I=&5R(&QE<R!P97)M
M:7-S:6]N<R!P;W5R(*N@)7.@NP!-;V1I9FEE<B!L97,@:6YF;W)M871I;VYS
M('!O=7(@JZ`E<Z"[`,ED:71E<B!L97,@;W!T:6]N<R!P;W5RH#H`R61I=&5R
M(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NP#)9&ET97(@;&5S('!E<FUI
M<W-I;VYS('!O=7(@)7,`R61U8V%T:6]N`,EG>7!T90!386QV861O<@#);.EM
M96YT+BXN`$5M`$-O=7)R:65L`$%D<F5S<V4@Z6QE8W1R;VYI<75E`$QE<R!A
M9')E<W-E<R#I;&5C=')O;FEQ=65S(&1O:79E;G0@8V]R<F5S<&]N9')E+@!#
M;W5R<FEE<B!A=F5C(&-O;F9I<FUA=&EO;@!087-S97)E;&QE(&-O=7)R:65R
M("\@4TU3`,EM;W1I8_1N97,`365S<V%G92!V:61E+@!2Z7-U;'1A="!V:61E
M+@!497)M97,@9&4@<F5C:&5R8VAE('9I9&4`06-T:79E<B!L)VEN<V5R=&EO
M;B!D)VEM86=E<R!V96YA;G0@9&5S(&%L8G5M<R!P:&]T;W,@9&%N<R!L92!T
M97AT9:`_`$%C=&EV97(@;&4@;65N=2!C;VYT97AT=65L(&%V96,@=6X@8VQI
M8R!D<F]I=*`_`$9I;B!D92!L)V%N;NEE`$%G<F%N9&ER(&PGZ61I=&5U<@#)
M8W)I=F5Z('5N92!Q=65S=&EO;B!D92!SZ6-U<FETZ2!Q=2=O;B!V;W5S('!O
M<V5R82!S:2!V;W5S(&1E=F5Z(')E;65T=')E(.`@>NER;R!V;W1R92!M;W0@
M9&4@<&%S<V4L('!A<B!E>&5M<&QE(*L@475E;"!E<W0@;&4@;F]M(&1E('9O
M=')E(&%N:6UA;"!P<NEFZ7+IH#^@NZ`Z`$EN<V-R:79E>B!L)V%D<F5S<V4@
M55),(&1E(&PG:6UA9V4@:6-I`$5N=')E>B!L97,@;&5T=')E<R!C:2UD97-S
M;W5SH#H`16YT<NEE(&1E("5S(&UI<V4@X"!J;W5R+"!M86ES(.EC:&5C(&1E
M(&QA('-A=79E9V%R9&4@9'4@9FEC:&EE<B!TZ6SI8VAA<F?IH#H@)7,`36ES
M92#@(&IO=7(@9&4@)7,@969F96-T=>EE+@!'=6ENZ64@Z7%U871O<FEA;&4`
MR7)Y=&ARZ64`17)R975R`$5R<F5U<B!L;W)S(&1E(&PG86IO=70@9&4@)60@
M8V]N=&%C="AS*2#@(&QA(&QI<W1E+@!%<G)E=7(@;&]R<R!D92!L)V%J;W5T
M(.`@;&$@;&ES=&4@9&4@)60@<W5R("5D(&-O;G1A8W0H<RD@9&5M86YDZ2AS
M*2X`17)R975R(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@8FQO8Z`Z("5S`$5R
M<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E("5D(&-O;G1A8W0H<RDN
M`$5R<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E("5D(&-O;G1A8W0H
M<RD@<W5R("5D+@!%<G)E=7(@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D92!L
M)V%N8W)E(&1E('-Y;F-H<F]N:7-A=&EO;J`Z("5S`$5R<F5U<B!L;W)S(&1E
M(&QA('-U<'!R97-S:6]N(&1U(&IO=7)N86P@9&4@<WEN8VAR;VYI<V%T:6]N
MH#H@)7,`17)R975R(&QO<G,@9&4@;&$@<NEC=7#I<F%T:6]N(&1U(&-O;G1E
M;G6@.B`E<P!%<G)E=7(@;&]R<R!D=2!R971R86ET(&1E("5D(&-O;G1A8W0H
M<RD@9&4@;&$@;&ES=&4N`$5R<F5U<B!L;W)S(&1U(')E=')A:70@9&4@;&$@
M;&ES=&4@9&4@)60@8V]N=&%C="AS*2!S=7(@)60N`$5R<F5U<B!L;W)S(&1E
M(&QA(')E8VAE<F-H92!D86YS(&QE(&-A<FYE="!D)V%D<F5S<V6@.B`E<P!%
M<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D=2!M;W0@9&4@<&%S<V6@
M.B`E<P!%<G)E=7(@879E8R!L92!M97-S86=E+@!%<G)E=7(@;&]R<R!D92!L
M)V5N<F5G:7-T<F5M96YT(&1E(*N@)7.@NRX`17-T;VYI90#)=&AI;W!I90!%
M=&AN:7%U90!%=7)O<&4`5&]U<R!L97,@)F9R86,Q-#L@9"=H975R90!4;W5T
M97,@;&5S(#(@;6EN=71E<P!4;W5T97,@;&5S(#,P('-E8V]N9&5S`%1O=71E
M<R!L97,@-2!M:6YU=&5S`,`@8VAA<75E(&-O;FYE>&EO;@!4;W5T97,@;&5S
M("9F<F%C,3([(&AE=7)E<P!4;W5T97,@;&5S(&UI;G5T97,`17AE;7!L92!D
M92!V86QE=7)SH#H`17CI8W5T97(`1.EV96QO<'!E<@!$Z7!L:65R(&QA(&)A
M<G)E(&1E(&/T=.D`JR`I(+L@871T96YD=64`56X@<V5U;"!M;W0@;W4@97AP
M<F5S<VEO;B!E;G1R92!G=6EL;&5M971S(&%T=&5N9'5S`$1A=&4@9"=E>'!I
M<F%T:6]N`%)E<'+I<V5N=&%N=`!%>'!O<G1E<@!%>'!O<G1E<B!L)V%N;G5A
M:7)E`$XG97AP;W)T97(@<75E(&QE<R!C;VYT86-T<R!SZ6QE8W1I;VYNZ7,N
M`$5X<&]R=&5R(&5N('1O=&%L:73I(&QE(&-A<FYE="!D)V%D<F5S<V5S('-U
M:79A;G0N`$-O=6QE=7(@9"=A=F%N="UP;&%N`%3I;.EC:&%R9V5M96YT('9E
M<G,@;&4@<V5R=F5U<B!D92!L82!C;VYF:6=U<F%T:6]N('!A<B!&5%``3&5C
M='5R92!D97,@<'+I9NER96YC97,@:6UP;W-S:6)L92X`26UP;W-S:6)L92!D
M)V%C8^ED97(@874@8V%R;F5T(&0G861R97-S97.@.B`E<P!);7!O<W-I8FQE
M(&0G86IO=71E<B`E<R#@("5SH#H@)7,`26UP;W-S:6)L92!D)V%C8^ED97(@
MX"!C971T92!L:7-T90!);7!O<W-I8FQE(&0G86-CZ61E<B#@(&-E('+I<&5R
M=&]I<F4`26UP;W-S:6)L92!D92!M;V1I9FEE<B!L92!N;VV@.B`H)7,I("5S
MH#L@86YC:65N($1.(#T@)7,L(&YO=79E874@1$X@/2`E<RP@<F%C:6YE(#T@
M)7,`R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@3$1!4"X`R6-H
M96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@4TU"+@#)8VAE8R!D92!L
M82!C;W!I92!D97!U:7,@JZ`E<Z"[+@#)8VAE8R!D92!L82!C;W!I92!V97)S
M(""KH"5SH+LN`$EM<&]S<VEB;&4@9&4@8W+I97(@=6YE(&YO=79E;&QE(&-O
M;FYE>&EO;B!305-,`$EM<&]S<VEB;&4@9&4@=')O=79E<B!U;B!S=6IE="#@
M(&%J;W5T97(Z("5S`,EC:&5C(&1U(&3I<&QA8V5M96YT('9E<G,@JZ`E<Z"[
M+@#)8VAE8R!L;W)S(&1E(&QA('+I8W5PZ7)A=&EO;J`Z("5S`$EM<&]S<VEB
M;&4@9"=E9F9E8W1U97(@=6YE(')E8VAE<F-H92!D86YS(&-E(&-A<FYE="!D
M)V%D<F5S<V5SH#H@)7,`26UP;W-S:6)L92!D)V5F9F5C='5E<B!U;F4@<F5C
M:&5R8VAE(&1A;G,@8V4@<NEP97)T;VER9:`Z("5S`$)E874`SFQE<R!&86QK
M;&%N9"`H36%L;W5I;F5S*0#.;&5S($;I<F_I`$5R<F5U<B!F871A;&6@.@!4
MZ6SI8V]P:64`5.ELZ6-O<&EE<P!&Z79R:65R`%1E;7#I<F%T=7)E(')E<W-E
M;G1I90!496UPZ7)A='5R92!R97-S96YT:66@.B``475E;'%U97,@879E<G-E
M<P!1=65L<75E<R!C:'5T97,@9&4@;F5I9V4`36%T<FEC92!D97,@8VAA;7!S
M`$9I9VQE="!#05!40TA!`%!O;&EC92!D92!L82`\23YF:6=L970\+TD^`$9I
M9&II`$9I8VAI97(`3F]M8G)E(&1E(&9I8VAI97)SH#H@)7,`3F]M8G)E(&1E
M(&9I8VAI97)SH#H@)7,`1V5S=&EO;FYA:7)E(&1E(&9I8VAI97)S`$YO;2!D
M=2!F:6-H:65R`$-H;VEX(&1E(&9I8VAI97(`5.ELZ6-H87)G96UE;G0@9&4@
M9FEC:&EE<@!,)V5N=F]I(&1E(&9I8VAI97)S(&XG97-T('!A<R!P<FES(&5N
M(&-O;7!T92X`1FEC:&EE<G,`1FEL=')E<P!296-H97)C:&5R`%1E<FUI;F5R
M`$9I;FQA;F1E`%!R96UIZ')E(&1E;6EE`%!RZ6YO;0!0<F5M:65R('%U87)T
M:65R`$9I>&5R(&QE(')A=&EO`%)E=&]U<FYE<@!&;&]T=&%N=`!"<F]U:6QL
M87)D`$1O<W-I97(@)7,@:6YE>&ES=&%N="X`0V]U;&5U<B!D92!P;VQI8V4`
M3F]U<G)I='5R90!0;W5R(&QE<R!N879I9V%T975R<R!N92!S=7!P;W)T86YT
M('!A<R!L97,@:6UA9V5S`%!RZ79I<VEO;B`H5$%&*0!*;W5R<R!D92!P<NEV
M:7-I;VX@*&YO=&5Z('%U92!L97,@<'+I=FES:6]N<R!F;W5R;FEE<R!D;VYN
M96YT(&QE(&IO=7(@970@;&$@;G5I=*`[('5N(&=R86YD(&YO;6)R92!I8VD@
M<&5U="!F86ER92!U;B!B;&]C('1RZ',@;&%R9V4`5F]U<R!A=F5Z(&]U8FQI
MZ2!V;W1R92!M;W0@9&4@<&%S<V6@/P!&;W)M=6QA:7)E<P!#:71A=&EO;@!4
M>7!E(&1E(&-I=&%T:6]N`$-I=&%T:6]N<P!#:71A=&EO;G,@,@!&;W)U;7,`
M4F5D:7)E8W1I;VX`5F4`0V%D<F5S`$9R86YC90!&<F%N8V4@;>ET<F]P;VQI
M=&%I;F4`55),(&1E<R!D:7-P;VYI8FEL:73I<P!'=7EA;F4@9G)A;N=A:7-E
M`%!O;'ENZ7-I92!F<F%NYV%I<V4`5&5R<F5S(&%U<W1R86QE<R!E="!A;G1A
M<F-T:7%U97,@9G)A;N=A:7-E<P!$86YS`$1U(`!$97-C<FEP=&EO;B!C;VUP
M;.AT90!0;&5I;F4@;'5N90!.;VT@8V]M<&QE=`!'86)O;@!!;&)U;2!D)V]R
M:6=I;F4@9&4@;"=I;6%G90!!;&)U;:`Z`$=A;6)I90!'Z6[I<F5R(&QA(&-O
M;F9I9W5R871I;VX@9&4@)7,`0V]D92!GZ6[I<ND`1^EO<F=I90!!;&QE;6%G
M;F4`1VAA;F$`1VEB<F%L=&%R`%!RZ6YO;0!#87)N970@9"=A9')E<W-E<R!G
M;&]B86P`06QL97(`1V]E9&5L`$-A<G1E<R!';V]G;&4`4F5C:&5R8VAE($=O
M;V=L90!.:79E874@9&4@9W)I<P!'<NAC90!'<F5C("A)4T\M.#@U.2TW*0!'
M<F_K;FQA;F0`1W)E;F%D90!'<F]U<&4`061M:6YI<W1R871I;VX@9&5S(&=R
M;W5P97,`3&5S(&YO;7,@9&4@9W)O=7!E(&YE('!E=79E;G0@<&%S(.IT<F4@
M=FED97,`1W)O=7!?;&1A<*`Z(&EM<&]S<VEB;&4@9"=A:F]U=&5R(&QE(&=R
M;W5P92`E<RX@0V5C:2!E<W0@;&$@<NEP;VYS92!D=2!S97)V975RH#H`1W)O
M=7!?;&1A<*`Z('-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@9W)O=7!E("5S
M`$=R;W5P7VQD87"@.B!M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D=2!G<F]U
M<&4@)7,`1W)O=7!E<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M97-E>0!097)M:7-S:6]N<R!D97,@:6YV:73I<P!,:79R92!D)V]R`$=U:6[I
M90!'=6ENZ64M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(')E9G5S92!B
MZG1E;65N="!D92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@8V5L;'5L92!D92!L
M82!R86YGZ64`2%1-3$%R96$@<F5F=7-E(&+J=&5M96YT(&1E('-U<'!R:6UE
M<B!L82!D97)N:>AR92!C;VQO;FYE(&1U('1A8FQE874`2%1-3$%R96$@<F5F
M=7-E(&+J=&5M96YT(&1E('-U<'!R:6UE<B!L82!D97)N:>AR92!R86YGZ64@
M9'4@=&%B;&5A=0!!=71H96YT:69I8V%T:6]N($A45%`@;F]N('1R;W5VZ64N
M`$AA[W1I`$%L9V]R:71H;64@9&4@:&%C:&%G90!"<G5M92!SZ&-H90!%;BUT
MZG1E`$5N+73J=&5S`,YL97,@2&5A<F0@970@36-$;VYA;&0`3W)A9V5S('9I
M;VQE;G1S`$CI8G)E=2`H25-/+3@X-3DM."U)*0!(875T975R`$%I9&4`06ED
M92!P;W5R(&PGZ61I=&5U<@!!:61E`$CI;6ES<&CH<F4`5F]I8VD@;&4@9.EB
M=70@9'4@9FEC:&EE<J`Z`$AA=71E`$%?8V-U96EL`$-I=.D@9'4@5F%T:6-A
M;@!!8V-U96EL`$%D<F5S<V4@9&]M:6-I;&4`5FEL;&4`4&%Y<P!2Z7!E<G1O
M:7)E('!E<G-O;FYE;`!4Z6PN(&1O;6EC:6QE`$-O9&4@<&]S=&%L`,ET870O
M4')O=FEN8V4`4G5E`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+
M;VQA8J`Z(&1O;F[I97,@6$U,("5S(&EN=F%L:61E<R!R971R;W5VZ65S(&1A
M;G,@;&4@;65S<V%G92`E<P!(;W)D92]+;VQA8J`Z(&%U8W5N(&UE<W-A9V4@
M;F4@8V]R<F5S<&]N9"!A=2!S=6IE="`E<P!(;W)D92]+;VQA8J`Z('!A<R!D
M)V]B:F5T(&1E('1Y<&4@)7,@=')O=7;I(&1A;G,@;&4@;65S<V%G92`E<P!(
M;W)D92]+;VQA8J`Z("5S('-U<'!R:6WI(*N@)7.@NR!A=F5C('-U8V/H<P!(
M;W)D92]+;VQA8J`Z(&QE(&UO=&5U<B!D)VEN=.EG<F%T:6]N(&[I8V5S<VET
M92!L)V5X=&5N<VEO;B`G9&]M>&UL)R!D92!02%``2&]R9&4O2V]L86*@.B!I
M;7!O<W-I8FQE(&1E(&-RZ65R('5N(&YO=79E;"!A<F)R92!834P@<&]U<B!L
M)V]B:F5T("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D)V5N;&5V97(@
M)7,@JZ`E<Z"[H#H@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E('+I
M8W5PZ7)E<B!L)VED96YT:69I86YT($U)344@<&]U<B!L82!P87)T:64@9&4@
M='EP92`E<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<WEN8VAR;VYI
M<V5R("5S(*N@)7.@NZ`Z("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D
M92!S>6YC:')O;FES97(@;&5S('!A<G1A9V5SH#H@)7,`2&]R9&4O2V]L86*@
M.B!P87)T86=E(&EN8V]N;G4@JZ`E<Z"[`$QI9VYE(&AO<FEZ;VYT86QE`%)E
M;7!L:7-S86=E(&AO<FEZ;VYT86P`2&]R:7IO;G1A;*`Z`$-O;6UE;G0@ZG1E
M<RUV;W5S(&%R<FEVZ2!I8VF@/R`H4U90(')A<'!O<G1E>BUL9:`A*0!#;VUB
M:65N(&1E(&-O;&]N;F5S('9O=6QE>BUV;W5S(&9U<VEO;FYE<J`_`$-O;6)I
M96X@9&4@8VAA;7!S("AC;VQO;FYE<RD@>2!A+70M:6R@/P!#;VUB:65N(&1E
M(')A;F?I97,@=F]U;&5Z+79O=7,@9G5S:6]N;F5RH#\`2'5M:61I=.D`2'5M
M:61I=.F@.B``2'5M;W)I<W1E<P!(;VYG<FEE`,EC:&5C(&QO<G,@9&4@;&$@
M8W+I871I;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S`,EC:&5C(&QO<G,@9&4@
M;&$@<W5P<')E<W-I;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S`,EC:&5C(&QO
M<G,@9&4@;&$@8W+I871I;VX@9'4@<75O=&$@<W5R(&QA(&)O[G1E($E-05"@
M.B`E<P!)35-0`$%D;6EN:7-T<F%T:6]N(&1E<R!A;FYU86ER97,@24U34"`H
M26YT97)N970@365S<V%G92!3=7!P;W)T(%!R;W1O8V]L*0!!9')E<W-E($E0
M`$%D<F5S<V4@25`@;F]N(&1I<W!O;FEB;&4N`$%D<F5S<V4@25`@:&]R<R!D
M=2!B;&]C($-)1%(@86QL;W7I+@!6:6]L871I;VX@9&4@8FQO8V%G92!)4"X`
M25]N<^ER97(@<F%N9^EE(&%V86YT`$ES;&%N9&4`26/T;F5S('-E=6QE;65N
M=`!)8_1N97,@<&]U<B`E<P!)8_1N97,@<&QU<R!T97AT90!.;VT@9'4@8V]M
M<'1EH#H`4VD@;"=A9F9I8VAA9V4@;B=E<W0@<&%S(&-O<G)E8W0L("5S('!O
M=7(@;"=O=79R:7(@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R92X`4VD@=F]U
M<R!N92!V;WEE>B!A=6-U;B!I8_1N92!E;B!U=&EL:7-A;G0@26YT97)N970@
M17AP;&]R97(L('9O=7,@<&]U=F5Z(&%V;VER(.`@8V]C:&5R(&-E='1E(&-A
M<V4@<&]U<B!DZ7-A8W1I=F5R(&QA('1R86YS<&%R96YC92!D97,@4$Y'+@!3
M:2!V;W5S('9O>65Z(&-E(&UE<W-A9V4@;6%I<R!A=6-U;F4@:6UA9V4L(&PG
M:6UA9V4@<75E('9O=7,@=F]U;&5Z(&5N=F]Y97(@;F4@<&5U="#J=')E(&%F
M9FEC:.EE('!A<B!V;W1R92!N879I9V%T975R+@!!<&5RYW4@9&4@;"=I;6%G
M9:`Z`$%D<F5S<V4@55),(&1E(&PG:6UA9V4`061R97-S92!54DP@9&4@;"=I
M;6%G9:`Z`$EM86=E(&1E(&PG86QB=6T`26UA9V4@9&4@;"=A;&)U;:`Z`%3I
M;.EC:&%R9V5M96YT(&0G:6UA9V5S`$EM86=E<P!);7!O<G1E<B!U;B!C87)N
M970@9"=A9')E<W-E<RP@Z71A<&4@)60`26UP;W)T871I;VXL(.ET87!E("5D
M`$EM<&]R=&5R+T5X<&]R=&5R(&-A<FYE="!D)V%D<F5S<V5S`$-H86UP(&EM
M<&]R=.F@.B`E<P!#:&%M<',@:6UP;W)TZ7.@.@!);E]SZ7)E<B!R86YGZ64@
M87!RZ',`0V]D92!D)V%C=&EO;B!I;F-O<G)E8W0N`$YO;2!D)W5T:6QI<V%T
M975R(&5T+V]U('9O=')E(&UO="!D92!P87-S92!I;F-O<G)E8W0N`$YO;2!D
M)W5T:6QI<V%T975R(&]U(&%D<F5S<V4@86QT97)N871I=F4@:6YC;W)R96-T
M+B`@4NEE<W-A>65Z(&]U(&-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U
M<B!S>7-TZ&UE('!O=7(@9&4@;"=A:61E+@!!=6=M96YT97(@;"=I;F1E;G1A
M=&EO;@!);F1E`%5T:6QI<V%T975R<R!I;F1I=FED=65L<P!);F1O;NES:64`
M26YF;P!);F9O<FUA=&EO;G,`3"=I;F9O<FUA=&EO;B!N)V5S="!P;'5S(&1I
M<W!O;FEB;&4N`$EN<^ER97(@8U]O;&]N;F4@87!RZ',`26YSZ7)E<B!I;6%G
M90!);G/I<F5R('5N('1A8FQE874`26YSZ7)E<B!U;B!L:65N('=E8@!);G/I
M<F5R(%]C;VQO;FYE(&%V86YT`$EN<^ER97(@=6YE(&YO=79E;&QE(&-O;&]N
M;F4@87!RZ',@;&$@8V]L;VYN92!A8W1U96QL90!);G/I<F5R('5N92!N;W5V
M96QL92!C;VQO;FYE(&%V86YT(&QA(&-O;&]N;F4@86-T=65L;&4`26YSZ7)E
M<B!U;F4@;F]U=F5L;&4@<F%N9^EE(&%P<NAS(&QA(')A;F?I92!A8W1U96QL
M90!);G/I<F5R('5N92!N;W5V96QL92!R86YGZ64@879A;G0@;&$@<F%N9^EE
M(&%C='5E;&QE`$EN<^ER97(@=6X@<&%R86=R87!H92!A<'+H<R!L92!N)F]E
M;&EG.W5D(&%C='5E;`!);G/I<F5R('5N('!A<F%G<F%P:&4@879A;G0@;&4@
M;B9O96QI9SMU9"!A8W1U96P`26YSZ7)E<B!U;B!A=71R92!M;V3H;&4`26YS
M8W)I=F5Z('5N92!A9')E<W-E(&1E(&-O=7)R:65R(.`@;&%Q=65L;&4@=F]U
M<R!R96-E=G)E>B!L92!N;W5V96%U(&UO="!D92!P87-S9:`Z`$EN<^ER97(@
M8V5L;'5L92!A<'+H<P!);G/I<F5R(&-E;&QU;&4@879A;G0`26YSZ7)E<B!C
M;VQO;FYE(&%P<NAS`$EN<^ER97(@8V]L;VYN92!A=F%N=`!);G/I<F5R(&QE
M<R!M97-S86=E<P!);G/I<F5R('!A<F%G<F%P:&4@87!RZ',`26YSZ7)E<B!P
M87)A9W)A<&AE(&%V86YT`$EN<^ER97(@<F%N9^EE(&%P<NAS`$EN<^ER97(@
M<F%N9^EE(&%V86YT`$EN<V-R:79E>B!L82!RZ7!O;G-E(.`@;&$@<75E<W1I
M;VX@9&4@<^EC=7)I=.F@.@!);G/I<F5R+TUO9&EF:65R('5N92!I;6%G90!)
M;G/I<F5R+TUO9&EF:65R('5N(&QI96X@=V5B`$-RZ61I="!I;G-U9F9I<V%N
M="!P;W5R(&5N=F]Y97(@X"!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN`$-R
MZ61I="!I;G-U9F9I<V%N="X`16YT:65R`$QI<W1E(&-O;7!LZ'1E`$ED96YT
M:69I86YT(&EN=F%L:61E`%5$2"`H57-E<B!$871A($AE861E<BD@:6YV86QI
M9&4`1&]N;NEE(%I)4"!I;G9A;&ED92X`0V%R;F5T(&0G861R97-S97,@:6YV
M86QI9&4`07!P;&EC871I;VX@:6YV86QI9&4N`$=R;W5P92!)1"!I;G9A;&ED
M92X`16YV;VD@9&4@9&]N;NEE<R!I;G9A;&ED97,N`$%D<F5S<V4@9&4@9&5S
M=&EN871I;VX@:6YV86QI9&4N`$-O=7)R:65L(&EN=F%L:61E`$5N='+I92!I
M;G9A;&ED90!&;W)M870@9&4@9FEC:&EE<B!I;G9A;&ED92X`0VQE9B!S<.EC
M:69IZ64@:6YV86QI9&4N`$-L968@9&4@;&EC96YC92!I;G9A;&ED92X`16UP
M;&%C96UE;G0@:6YD:7%UZ2!I;G9A;&ED92X`JVUS9U]T>7!ENR!I;G9A;&ED
M92X`3F]M(&EN=F%L:61E`$]B:F5C=$ED(&EN=F%L:61E`*MA<&E?:62[(&EN
M=F%L:61E(&]U(&UA;G%U86YT+@!087)A;>AT<F5S(&EN=F%L:61E<R!O=2!M
M86YQ=6%N=',N`%!E<FUI<W-I;VX@:6YV86QI9&4N`$ED+B!D92!P87)T96YA
M:7)E(&EN=F%L:61E+@!#;V1E(&1E('!R;V1U:70@:6YV86QI9&4N`%!R;W1O
M8V]L92!I;G9A;&ED92X`1&5S=&EN871A:7)E(&EN=F%L:61EH#H@JZ`E<Z"[
M`$]B:F5T(&1E('!A<G1A9V4@:6YV86QI9&4`061R97-S92!S;W5R8V4@:6YV
M86QI9&4N`$1O;F[I92!5;FEC;V1E(&EN=F%L:61E+@!);G9E;G1A:7)E`$EN
M=F5R<V5R(&QA('/I;&5C=&EO;@!)<F%N`$ER86L`27)L86YD90#.;&4@9&4@
M36%N`%1E;7#J=&5S(&ES;VSI97,`27-R8>ML`,EM971T975R`$ET86QI<75E
M`$ET86QI90!*86UA[W%U90!*86YV:65R`$IA<&]N`$IA<&]N86ES("A)4T\M
M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE`$IU:6QL970`2G5I;@!*=7-T:69I
M97(`0V5N=')E<@!*=7-T:69I97(`06QI9VYE<B#@(&=A=6-H90!!;&EG;F5R
M(.`@9')O:71E`$MA>F%K:'-T86X`1V%R9&5R(&PG;W)I9VEN86R@/P!+96YY
M80!,92!S97)V975R($ME<F)E<F]S(&$@<F5J973I(&PG875T:&5N=&EF:6-A
M=&EO;BX`1.EB=71A;G1S(&1U(&YO>6%U`$-RZ6%T:6]N(&1E(&-L968`16UP
M<F5I;G1E(&1E(&QA(&-L968`3&]N9W5E=7(@9&4@;&$@8VQE9@!4>7!E(&1E
M(&-L968`571I;&ES871I;VX@9&4@;&$@8VQE9@!,82!C;&5F('-E('1R;W5V
M92!DZ6K@('-U<B!L92!S97)V975R(&1E(&-L969S('!U8FQI8RX`16YF86YT
M<P!+:7)I8F%T:0!#;W+I92!D=2!.;W)D`$-O<NEE(&1U(%-U9`!#;W+I96X@
M*$550RU+4BD`2V]W9>]T`$MI<F=H:7II<W1A;@!,92!S=7!P;W)T($Q$05`@
M97-T(')E<75I<R!M86ES(&QE(&UO9'5L92!,1$%0(&5S="!I;F%C8V5S<VEB
M;&4@;W4@;F]N(&-H87)GZ2X`4'+I7W-E;G1A=&EO;@!,86YG=64`3&%O<P!$
M97)N:>AR92!D96UI90!$97)N:>AR92!M;V1I9FEC871I;VX`3F]M`$1E<FYI
MZ')E(&UO9&EF:6-A=&EO;B!D=2!M;W0@9&4@<&%S<V4`1&5R;FEE<B!Q=6%R
M=&EE<@!$97)N:>AR92!M:7-E(.`@:F]U<J`Z`$1E<FYIZ')E(&-O;FYE>&EO
M;J`Z("5S`$1E<FYIZ')E(&-O;FYE>&EO;J`Z("5S(.`@<&%R=&ER(&1E("5S
M`$1E<FYIZ')E(&-O;FYE>&EO;J`Z(&IA;6%I<P!,971T;VYI90!,;VD`4'+I
M<V5N=&%T:6]N`$QA:7-S97(@=FED92!P;W5R(&YE('!A<R!A=F]I<B!D92!B
M;W)D=7)E`$QI8F%N`$=A=6-H90!%;G3J=&4@9V%U8VAE`%9A;&5U<G,@9&4@
M9V%U8VAE`$QE<V]T:&\`3FEV96%U`$QI8NER:6$`3&EB>64`3&EE8VAT96YS
M=&5I;@!"<G5I;F4@;.EGZ')E`%!L=6EE(&SI9^AR90!0;'5I92!LZ6?H<F4@
M=/1T(&1A;G,@;&$@:F]U<F[I90!0;'5I92!LZ6?H<F4@=&%R9`!!=F5R<V5S
M(&SI9^AR97,`4&QU:64@;.EGZ')E(&%V96,@=&]N;F5R<F4`3F5I9V4@:6YT
M97)M:71T96YT90!!=F5R<V4@9&4@;F5I9V4@;.EGZ')E`%)I;65S`$QI96X`
M3&4@;&EE;B!P;VEN=&4@=F5R<Z`Z`$QI92!L)V%D<F5S<V4@9&4@8V]U<G)I
M96P@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N(&1U(&UE<W-A9V4@96X@;"=A
M9F9I8VAA;G0`3&EE;G,`0FES8W5I="!,:6YU>`!,:7-T90!,:7-T92`M('5T
M:6QI<V%T975R('!E=70@=F]I<B!L92!D;W-S:65R`$QI<W1E(&1E<R!B87-E
M<R!D92!D;VYNZ65S`$EN9&5X(&1E(&PG86ED90!!9F9I8VAE<B!L97,@=&%B
M;&5S`$%R8VAI=F5S(&1E(&QA(&QI<W1E`$%I9&4@9&4@;&$@;&ES=&4`260N
M(&1E(&QA(&QI<W1E`%!R;W!R:>ET86ER92!D92!L82!L:7-T90!%;G9O:2#@
M(&QA(&QI<W1E`$%B;VYN96UE;G0@X"!L82!L:7-T90!$Z7-A8F]N;F5M96YT
M(&1E(&QA(&QI<W1E`,EC:&5C(&1E(&QA(&QI<W1E(&1E<R!S97-S:6]N<Z`Z
M("5S`,EC:&5C(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G.@.B`E<P!,
M)V%F9FEC:&%G92!D92!L82!L:7-T92!D97,@=71I;&ES871E=7)S(&5S="!D
MZ7-A8W1I=NDN`$QI='3I<F%T=7)E`$QI='5A;FEE`$-H87)G96UE;G0N+BX`
M2&5U<F4@;&]C86QEH#H@`$AE=7)E(&5T(&QO8V%L90!,:65U`$-O;FYE>&EO
M;@!4<F%C92!D92!L82!D97)N:>AR92!S97-S:6]N(&1E('-Y;F-H<F]N:7-A
M=&EO;@!$Z6-O;FYE>&EO;@!#;VYN97AI;VX`5.)C:&5S(&1E(&-O;FYE>&EO
M;@!,82!C;VYN97AI;VX@97-T(')E9G5SZ64N($EL(&5S="!P<F]B86)L92!Q
M=64@=F]T<F4@;F]M(&0G=71I;&ES871E=7(@;W4@=F]T<F4@;6]T(&1E('!A
M<W-E(&$@Z73I(&UA;"!S86ES:0#)8VAE8R!D92!C;VYN97AI;VXN`%1E>'1E
M(&QO;F<`06UO=7(`1F%I8FQE`$QE='1R92!G<F5C<75E<R!M:6YU<V-U;&5S
M`$QE='1R92!L871I;F5S(&UI;G5S8W5L97,`3F]M8G)E(')O;6%I;G,@;6EN
M=7-C=6QE<P!,=7AE;6)O=7)G`$U-`$UE<W-A9V4@9'4@:F]U<B`H34]41"D`
M3&$@<&GH8V4@:F]I;G1E($U3+51.148@;F4@8V]N=&5N86ET(&%U8W5N92!D
M;VYNZ64N`$U31P!-86-A;P!2Z7!U8FQI<75E(&1E($UA8^ED;VEN90!-861A
M9V%S8V%R`$UA9VEE`$-O=7)R:65R`$%D;6EN:7-T<F%T:6]N(&1U(&-O=7)R
M:65L`$9A:7)E('5N(&QI95]N`$UA;&%W:0!-86QA:7-I90!-86QD:79E<P!-
M86QI`$UA;'1E`$%D;6EN:7-T<F5Z(&QA(&QI<W1E(&1E(&-A=.EG;W)I97,@
M970@;&5S(&-O=6QE=7)S(&QIZ65S(.`@8V5S(&-A=.EG;W)I97,N`$-A<G1E
M(*L@36%P,C0@NP!#87)T92"K($UA<'%U97-T(+L`0V]R<F5S<&]N9&%N8V5S
M(&5N<F5G:7-T<NEE<RX`36%R<P!-87)G90!-87)Q=65R(&%V96,@9&5S(.ET
M:7%U971T97,@5G4O3F]N('9U`$UA<G%U97(@879E8R!D)V%U=')E<R#I=&EQ
M=65T=&5S("AE>"XZ($EM<&]R=&%N="]2Z7!O;F1U*0#.;&5S($UA<G-H86QL
M`$UA<G1I;FEQ=64`0V]N=&5N86YT`$-H86UP<R!A<'!A<F5N=.ES`$UA=7)I
M=&%N:64`SFQE($UA=7)I8V4`0W+I9&ET(&UA>&EM=6T@86QL;W7I+@!,:6UI
M=&4@9'4@;65S<V%G92!DZ7!A<W/I92X`5&5M<.ER871U<F4@;6%X:6UA;&4@
M9&5S(#(T(&1E<FYIZ')E<R!H975R97.@.B``5&5M<.ER871U<F4@;6%X:6UA
M;&4@9&5S(#8@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!.;VUB<F4@;6%X:6UA;"!D
M92!C;VYT86-T<P!.;VUB<F4@;6%X:6UU;2!D92!B;&]C<R!D=2!P;W)T86EL
M`$QO;F=U975R(&UA>&EM=6T`3F]M8G)E(&UA>&EM86P@9&4@<&%G97,`36%I
M`$UA>6]T=&4`3>ED:6-A;65N=`!-96UB<F5S`$UE;G4`5'EP92!D92!M96YU
MH#H`1G5S:6]N;F5R(&QE<R!C96QL=6QE<P!-97-S86=E`%;I<FEF:6-A=&EO
M;B!D=2!M97-S86=E('+I=7-S:64L(&UA:7,@;&4@8V5R=&EF:6-A="!D=2!S
M:6=N871A:7)E(&XG82!P87,@<'4@ZG1R92!VZ7)I9FGI+@!-97-S86=E(&5X
M<&ERZ2X`5'EP92!D92!M97-S86=E`$WI=.EO($UE=&%R`$QE(&)L;V,@JR!-
M971A<B"[(&XG97-T('!A<R!D:7-P;VYI8FQE+@!,92!B;&]C(*L@365T87(@
MNR!N)V5S="!P87,@9&ES<&]N:6)L92X@($QE<R!DZ71A:6QS(&]N="#I=.D@
M8V]N<VEG;NES('!O=7(@;"=A9&UI;FES=')A=&5U<BX`365T87)$0B!N)V5S
M="!P87,@8V]N;F5C=.DN`$WI=&AO9&4`3&$@;>ET:&]D92"KH"5SH+L@;B=E
M<W0@<&%S(&3I9FEN:64`3>ET:&]D92!N;VX@9.EF:6YI92X@3>ET:&]D92!A
M<'!E;.EEH#H@)7,`3>ET<FEQ=64`365X:7%U90#)=&%T<R!FZ63I<NES(&1E
M($UI8W)O;NES:64`36EL:65U`%1Y<&4@34E-10!496UPZ7)A='5R92!M:6YI
M;75M(&1E<R`R-"!D97)N:>AR97,@:&5U<F5SH#H@`%1E;7#I<F%T=7)E(&UI
M;FEM=6T@9&5S(#8@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!,82!D=7+I92!M:6YI
M;6%L92!D=2!M;W0@9&4@<&%S<V4@;B=A('!A<R!E;F-O<F4@97AP:7+I`$UI
M<F]I<@!687)IZ7,`1$X@;6%N<75A;G0@9&%N<R!L82!C;VYF:6=U<F%T:6]N
M(&1E(&QA('-O=7)C92!,1$%0+@!,92!P87%U971A9V4@2%144%]R97%U97-T
M(%!%05(@97-T(&UA;G%U86YT+@!#;VYF:6=U<F%T:6]N(&EN97AI<W1A;G1E
M+B!6;W5S(&1E=F5Z(&QA(&?I;NER97(@;6%I;G1E;F%N="!S:2!V;W5S('9O
M=6QE>B!U=&EL:7-E<B!C971T92!A<'!L:6-A=&EO;BX`240@9'4@;65S<V%G
M92!M86YQ=6%N="X`3&4@<&%Q=65T86=E(%!%05(@36%I;"!E<W0@;6%N<75A
M;G0N`$E$(&1E('-E<W-I;VX@;6%N<75A;G0N`$QU`$-O=7)R:65L('-A;G,@
M9FEL`%3I;"X@;6]B:6QE`$UO9.ERZ0!$871E(&1E(&UO9&EF:6-A=&EO;@!-
M;V1I9FEE<B!L)U523`#)8VAE8R!D92!L82!M;V1I9FEC871I;VZ@.B`H)7,I
M("5S`$UO9'5L;P!-;VQD879I90!-;VYA8V\`36]N9V]L:64`36]I<R!E="!A
M;F[I90!-96YS=65L;&5M96YT`$UO;G1S97)R870`4&AA<V5S(&1E(&QA(&QU
M;F4`0VAA;7!S('-U<'!LZ6UE;G1A:7)E<R!T<F]U=NES(.`@;&$@;&EG;F4@
M)60@*&%T=&5N9'5S("5D*2X`4&QU<R!D)W5N92!E;G1RZ64@=')O=7;I90!-
M87)O8P!'Z6[I<F%L96UE;G0@96YS;VQE:6QLZ0!'Z6[I<F%L96UE;G0@;G5A
M9V5U>`!'Z6[I<F%L96UE;G0@96YS;VQE:6QLZ0!$Z7!L86-E<@!697)S(&QE
M(&)A<P!$Z7!L86-E<B#@(&=A=6-H90!$Z7!L86-E<B#@(&1R;VET90!697)S
M(&QE(&AA=70`5F5R<R!L92!B87,`1.EP;&%C97(@X"!G875C:&4`1.EP;&%C
M97(@X"!D<F]I=&4`5F5R<R!L92!H875T`$UO>F%M8FEQ=64`06YN=6%I<F4@
M375L8F5R<GD`3&ES=&5S(&3I<F]U;&%N=&5S(&UU;'1I+6YI=F5A=7@`0V%R
M=&4@JZ!-=6QT:6UA<"!52Z"[`%!L=7-I975R<R!P97)S;VYN97,@879E8R!L
M)V%D<F5S<V4@6R5S72P@;6%I<R!A=6-U;F4@879E8R!L92!N;VT@6R5S72!E
M>&ES=&5N="!DZ6K@`%/I;&5C=&EO;B!M=6QT:7!L90!087)A;>ET<F%G92!D
M=2!C;VUP=&4`365S(&1O;F[I97,@<&5R<V]N;F5L;&5S`$UO;B!A;FYU86ER
M90!-97,@86YN=6%I<F5S`$UO;B!P;W)T86EL`%!RZ7-E;G1A=&EO;B!D92!M
M;VX@<&]R=&%I;`!":7)M86YI90!.3TXL(&IE(&XG86-C97!T92!P87,`3F]M
M`$9O<FUA="!D92!N;VT`3F%M:6)I90!.875R=0!.Z7!A;`!2Z7!E<G1O:7)E
M($UE;6)R92!.971C96YT97(`4&%Y<RU"87,`06YT:6QL97,@;NEE<FQA;F1A
M:7-E<P!54DP@9&4@8F%S92!D92!.971S8V%P90!54DP@9&4@<NEV;V-A=&EO
M;B!D92!L)T$N0RX@3F5T<V-A<&4`55),(&1E(&QA('!O;&ET:7%U92!D)T$N
M0RX@3F5T<V-A<&4`55),(&1E(')E;F]U=F5L;&5M96YT($YE='-C87!E`%52
M3"!D92!RZ79O8V%T:6]N($YE='-C87!E`$YO;2!D=2!S97)V975R(%-33"!.
M971S8V%P90!#;VUM96YT86ER92!D=2!C97)T:69I8V%T($YE='-C87!E`%1Y
M<&4@9'4@8V5R=&EF:6-A="!.971S8V%P90!2Z7-E874`2F%M86ES`$YO=79E
M;&QE+4-A;.ED;VYI90!.;W5V96QL92!C873I9V]R:64`3F]U=F5A=2!C;VYT
M86-T`$YO=79E874@;65S<V%G92#@("5S`$YO=79E;&QE(&QU;F4`3F]U=F5A
M=2!N;VT@9&4@8V]N;F5X:6]N("AF86-U;'1A=&EF*0!.;W5V96QL92U:Z6QA
M;F1E`$YO=79E874@;6]T(&1E('!A<W-E`$QE(&YO=79E874@;6]T(&1E('!A
M<W-E(&5X<&ER97)A(&QE("5X+@!,97,@;F]U=F5A=7@@;6]T<R!D92!P87-S
M92!D:69FZ')E;G0N`$YO=79E;&QE(&9E;NIT<F4@*%]B;&%N:RD`3F]U=F5L
M;&5S`$9O<G5M<P!3=6EV86YT`#0@<&AA<V5S('-U:79A;G1E<P!/<'1I;VYS
M('-U:79A;G1E<P!3=6EV86YT/@!.:6-A<F%G=6$`4W5R;F]M`$YI9V5R`$YI
M9V5R:6$`3G5I=`!.:75E`$YO;@!!=6-U;F4@96YT<NEE("5S('1R;W5VZ64@
M<&]U<B`E<RX@`$%U8W5N(&-A<FYE="!D)V%D<F5S<V5S('1R;W5VZ2X`4&%S
M(&1E(&1O;F[I97,@9&4@8V]N9FEG=7)A=&EO;B!P;W5R(&QE<W%U96QL97,@
M;6]N=')E<B!L97,@9&EF9NER96YC97,N`%!A<R!D92!S=')A=.EG:64@9&ES
M<&]N:6)L92!P;W5R(&9A:7)E(&1E<R!I;6%G97,@25-/+@!087,@9&4@9V%B
M87)I="!E;B!T<F%I=&5M96YT('!A<B!L;W0N`$%U8W5N(&)L;V,@;B=E>&ES
M=&4@X"!L82!P;W-I=&EO;B!D96UA;F3I90!087,@9&4@;F]M(&1E(&-A;&5N
M9')I97(@9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!-0T%,
M+@!.;VX@;6]D:69IZ2X`075C=6YE('-O=7,M<&5R;6ES<VEO;B!N)V$@8F5S
M;VEN(&0GZG1R92!A:F]U=.EE('-O=7,@8V4@;FEV96%U+@!!=6-U;F4@:6YF
M;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!S<.EC:69IZ64@<&]U<B`E<RX`
M075C=6YE(&EN9F]R;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@9F]U<FYI92!P
M;W5R($944"!61E,N`$%U8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T
M:6]N(&9O=7)N:64@<&]U<B!344P@5D93+@!!=6-U;F4@:6YF;W)M871I;VX@
M9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE('!O=7(@4U%,+49I;&4@5D93+@!!
M=6-U;B!C;VYT86-T('1R;W5VZ0!!=6-U;B!C<NED:70@9&ES<&]N:6)L92X`
M075C=6YE(&1E<W1I;F%T:6]N('1R;W5VZ64N`$%U8W5N(&9I8VAI97(@96YV
M;WGI`$%U8W5N(&EC]&YE('1R;W5VZ2X`075C=6X@;&EE=2!N)V5S="!SZ6QE
M8W1I;VYNZ0!!=6-U;B!E;7!L86-E;65N="!N)V5S="!I;F1I<77I+@!!=6-U
M;B!M97-S86=E(&9O=7)N:0!!=6-U;B!N;VT@<W#I8VEF:>DN`$%U8W5N(&YO
M;6)R92!S<.EC:69IZ2X`4&%S(&0G87!H;W)I<VUE<R!C:&]Q=6%N=',`075C
M=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO
M;B!P87(@2%144"X`075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG
M875T:&5N=&EF:6-A=&EO;B!P87(@24U!4"X`075C=6X@;6]T(&1E('!A<W-E
M(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@2V5R8F5R;W,N
M`$%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF
M:6-A=&EO;BX`075C=6X@;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A
M=71H96YT:69I8V%T:6]N(%!!4U-71"X`075C=6X@;6]T(&1E('!A<W-E('-P
MZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%--0BX`075C=6X@8VAE
M;6EN('9E<G,@;&4@8FEN86ER92!/<&5N4U-,(&9O=7)N:2X@3&4@8FEN86ER
M92!D)T]P96Y34TP@97-T(&[I8V5S<V%I<F4@<&]U<B!F;VYC=&EO;FYE<B!A
M=F5C(&1E<R!D;VYNZ65S(%!+0U,@,3(N`$%U8W5N92!C;VYF:7)M871I;VX@
M96X@871T96YT90!087,@9&4@<75O=&$@<&]S:71I;VYNZ2X`4&%S(&1E('+H
M9VQE<P!!=6-U;B!SZ7!A<F%T975R('-PZ6-I9FGI+@!087,@9&4@8_1TZ7,`
M1FEC:&EE<B!I;F5X:7-T86YT`$%U8W5N('+I<&5R=&]I<F4@=&5M<&]R86ER
M92!E<W0@9&ES<&]N:6)L92!P;W5R(&QA(&-A8VAE`$%U8W5N(&YO;2!D)W5T
M:6QI<V%T975R(&5T("]O=2!M;W0@9&4@<&%S<V4@96YV;WGI+@!!=6-U;F4@
M9&]N;NEE('9#87)D('1R;W5VZ64N`$%U8W5N92!D;VYNZ64@6$U,('9A;&ED
M92!N)V$@Z73I(')E=&]U<F[I90!087,@9&4@=F%L975R`%!A<R!D92!V97)S
M:6]N('1R;W5VZ64@9&%N<R!L82!C;VYF:6=U<F%T:6]N(&]R:6=I;F%L92X@
M4NEGZ6[I<F5Z(&QA(&-O;F9I9W5R871I;VXN`%!A<R!D92!V97)S:6]N('1R
M;W5VZ64@9&%N<R!V;W1R92!C;VYF:6=U<F%T:6]N+B!2Z6?I;NER97H@;&$@
M8V]N9FEG=7)A=&EO;BX`075C=6X`075C=6X@*'5T:6QI<V5R(&EM<&QI8VET
M96UE;G0I`$YO<F1I<75E("A)4T\M.#@U.2TQ,"D`SFQE($YO<F9O;&L`2.EM
M:7-P:.AR92!.;W)D`,YL97,@36%R:6%N;F5S(&1U(&YO<F0`3F]R=NAG90!0
M87,@87!RZ',`4&%S(&%V86YT`%!A<R!U;B!D;W-S:65R`$YO;B!I;7!LZ6UE
M;G3I+@!);F%C=&EF`$YO;B!P<FES(&5N(&-O;7!T92X`3F]T97,`4FEE;B#@
M(&YA=FEG=65R+"!R971O=7)N97H@96X@87)R:>AR92X`3F]V96UB<F4`3F]M
M8G)E`$YO;6)R92!D92!C87)A8W3H<F5S`$YO;6)R92!D92!C;VQO;FYE<P!.
M;VUB<F4@9"=I=&5M<R!P87(@<&%G90!.;VUB<F4@9&4@<F%N9^EE<P!.;VUB
M<F4@;F]N('-PZ6-I9FGI('!O=7(@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES
M=&4@9&4@9&ES=')I8G5T:6]N+@!/2P!/8FIE=`!#<NEA=&5U<B!D)V]B:F5T
M`%-U:F5T(&YO;B!T<F]U=ND`3V-T86P`3V-T;V)R90!&:6QT<F4@86YT:2UO
M9F9E;G-A;G0`0G5R96%U`$PG86YC:65N(&5T(&QE(&YO=79E874@;6]T<R!D
M92!P87-S92!D;VEV96YT(.IT<F4@9&EF9NER96YT<RX`06YC:65N(&UO="!D
M92!P87-S90!,)V%N8VEE;B!M;W0@9&4@<&%S<V4@97-T(&EN8V]R<F5C=`!/
M;6%N`$%P<NAS(&%V;VER('-A=79E<B!C971T92!P86=E(&0G;W!T:6]N<RP@
M;&4@8V%R;F5T(&0G861R97-S97,@<V5R82!S=7!P<FEMZ2!DZ69I;FET:79E
M;65N="X@4VD@8V4@;B=E<W0@<&%S(&-E('%U92!V;W5S('9O=6QE>BP@=F]U
M<R!D979E>B!C:&%N9V5R('9O=')E('/I;&5C=&EO;B!E;B"KH$%U8W5NH+LN
M`%-E=6P@;&5S('-E<G9E=7)S($E-05`@<W5P<&]R=&5N="!L97,@9&]S<VEE
M<G,@<&%R=&%GZ7,N`%-E=6QE;65N="!L97,@JZ!F;W)T=6YE<Z"[(&]F9F5N
M<V%N=&5S`%5N92!S975L92!A9')E<W-E(&1E(&-O=7)R:65L('!E<FUI<V4N
M`%5N92!S975L92!V0V%R9"!E<W0@<W5P<&]R=.EE+@!3975L<R!L92!P<F]P
M<FGI=&%I<F4@;W4@;"=A9&UI;FES=')A=&5U<B!S>7-TZ&UE('!E=70@;6]D
M:69I97(@;&5S('!E<FUI<W-I;VYS(&0G=6X@<&%R=&%G92X`3W5V<FER(&1A
M;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`17)R975R($]P96Y34TR@.B!I;7!O
M<W-I8FQE(&0G97AT<F%I<F4@;&5S(&1O;F[I97,@9&4@;&$@<&%R=&EE('-I
M9V[I92!3+TU)344`3W5V<FER(&QE<R!L:65N<R!D86YS('5N92!N;W5V96QL
M92!F96[J=')E`%-Y<W3H;64@9"=E>'!L;VET871I;VX`3W!T:6]N<P!/<'1I
M;VYS('!O=7(@)7,`3&ES=&4@;G5MZ7)O=.EE`$]R9V%N:7-A=&EO;@!5;FET
MZ2!O<F=A;FES871I;VYN96QL90!/<F=A;FES871I;VX`36]DZ&QE(&]R:6=I
M;F%L(&0G87!P;&EC871I;VX`36]DZ&QE<R!O<FEG:6YA=7@@9&%N<R`E<Z`Z
M`$%U=')E`$%U=')E<R!I;F9O<FUA=&EO;G,`075T<F5S(&]P=&EO;G,`4&5R
M;6ES<VEO;G,@9'4@<')O<')IZ71A:7)E`$PG875T:&5N=&EF:6-A=&EO;B!0
M04T@;B=E<W0@<&%S(&1I<W!O;FEB;&4N`$UO9'5L92!014%2.CI-86EL`%-I
M9VYA='5R92!N=6WI<FEQ=64@4$=0`$1O;F[I97,@4$=0(&-H:69F<NEE<P!#
M;.D@<'5B;&EQ=64@4$=0`$1O;F[I97,@4$=0('-I9V[I97,O8VAI9F9RZ65S
M`$-O9&4@4$A0`$EN=&5R<'+I=&5U<B!02%``4&QU:64@;.EGZ')E(&PG87!R
MZ',M;6ED:0!!=F5R<V5S(&PG87!RZ',M;6ED:0!.96EG92!L)V%P<NAS+6UI
M9&D`0VAU=&5S(&1E(&YE:6=E(&PG87!RZ',M;6ED:0!3;VQE:6P@;"=A<'+H
M<RUM:61I`$]R86=E<R!L)V%P<NAS+6UI9&D`17AT96YS:6]N(%!/4TE8(&%B
M<V5N=&4`26YT97)P<NET975R(%!?2%``4F5M<&QI<W-A9V4`4&%K:7-T86X`
M0F5L874`4&%L97-T:6YE("AT97)R:71O:7)E(&]C8W5PZ2D`4&%N86UA`%!A
M<&]U87-I92U.;W5V96QL92U'=6ENZ64`4&%R86=U87D`4&%R=&EE;&QE;65N
M="!N=6%G975X`$UO="!D92!P87-S90!#:&%N9V5M96YT(&1U(&UO="!D92!P
M87-S92!E9F9E8W1UZ2X`36]T(&1E('!A<W-E(&EN8V]R<F5C=`!-;W0@9&4@
M<&%S<V4@<F5Q=6ES('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%)!1$E54RX`
M36]T(&1E('!A<W-E(&%V96,@8V]N9FER;6%T:6]N`$UO="!D92!P87-S9:`Z
M`$UO="!D92!P87-S9:`Z(`!,97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT
M<F4@:61E;G1I<75E<RX`0V]L;&5R`$-O;&QE<B!D97!U:7,@;&4@<')E<W-E
M+7!A<&EE<G,`0VAE;6EN`$-O;F9I<FUA=&EO;G,@96X@871T96YT9:`Z`%!E
M<G-O;FYE<P!0;W5R8V5N=&%G90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@
M9&4@;6%I;G1E;F%N8V4`169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA
M:6YT96YA;F-E(.`@;&$@8V]N;F5X:6]NH#\`4&5R;6ES<VEO;@!,82!P97)M
M:7-S:6]N(*N@)7.@NR!N)V5S="!P87,@<W5P<')I;>EE+@!097)M:7-S:6]N
M(')E9G5SZ64`4&5R;6ES<VEO;B!R969U<^EE`$1R;VET<R!D)V%C8^AS`$%D
M;6EN:7-T<F%T:6]N(&1E<R!P97)M:7-S:6]N<P!$;VYNZ65S('!E<G-O;FYE
M;&QE<P!0Z7)O=0!!;FEM875X`%!H:6QI<'!I;F5S`%3I;.EP:&]N90!0:&]T
M;W,`06YN=6%I<F4@4&EN90!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!3
M5E`@8VQI<75E>B!D86YS('5N92!C96QL=6QE`%-64"!C;VYF:7)M97H@;&$@
M<W5P<')E<W-I;VX@9&4@8V5T(.ELZ6UE;G2@.@!35E`@8V]N9FER;65Z('%U
M92!V;W5S('9O=6QE>B!DZ6QI97(@8V5T(.ELZ6UE;G0N`%9E=6EL;&5Z('-A
M:7-I<B!U;B!M;VES(&5T('5N92!A;F[I92X`5F5U:6QL97H@<V%I<VER('5N
M(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A=.EG;W)I9:`Z`%9E=6EL;&5Z(&5N
M=')E<B!U;F4@861R97-S92!)4"!V86QI9&4N`%9E=6EL;&5Z(&5N=')E<B!U
M;F4@9&%T92!V86QI9&6@.R!VZ7)I9FEE>B!L92!N;VUB<F4@9&4@:F]U<G,@
M9'4@;6]I<RX@`%9E=6EL;&5Z(&5N=')E<B!U;F4@:&5U<F4@=F%L:61E+@!6
M975I;&QE>B!N;VUM97(@;&$@;F]U=F5L;&4@;&ES=&4@9&4@8V]N=&%C='.@
M.@!6975I;&QE>B!F;W5R;FER('5N('+I<W5MZ2!D=2!P<F]B;.AM92X`5F5U
M:6QL97H@9F]U<FYI<B!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!E="!V;W1R
M92!M;W0@9&4@<&%S<V4`5F5U:6QL97H@;&ER92!L92!T97AT92!S=6EV86YT
M+B!6;W5S(&1E=F5Z(&%C8V5P=&5R(&QE<R!C;VYD:71I;VYS('!O=7(@=71I
M;&ES97(@;&4@<WES=.AM92X`5F5U:6QL97H@96YT<F5R(&QE(&YO=79E874@
M;F]MH&1E(&QA(&-A=.EG;W)I9:`Z`%!O;&]G;F4`4&]L:71I<75E`%-C<G5T
M:6YS`%!O<G1U9V%L`%!O<VET:6]N(&1E(&-E='1E(&EM86=E`%!O<VET:6]N
M(&1E(&-E('1A8FQE874`16YV;WEE<B#@(&-E(&1O<W-I97(@*&YO;B!A<'!L
M:7%UZ2!P87(@24U!4"D`4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@9&5R
M;FGH<F5S(&AE=7)E<Z`Z(`!0<F]B86)I;&ETZ3QB<B`O/F1E('!L=6EE`%!R
M969S7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE
M+@!0<F5F<U]S97-S:6]NH#H@97AT96YS:6]N(')E<75I<V4@JZ!S97-S:6]N
MH+L@;F]N('1R;W5VZ64N`%!R97-S:6]N`%!R97-S:6]N(&%U(&YI=F5A=2!D
M92!L82!M97*@.B``4')E<W-I;VZ@.B``07!E<N=U`$%P97+G=2!D92!L)VEM
M86=E(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`4'+I8^ED96YT`$]P=&EO
M;G,@<'+I8^ED96YT97,`26UP<FEM97(@;&4@9&]C=6UE;G0`06YN=6%I<F4@
M<')I=ND`0VQE9B!P<FEVZ64`4')O8FSH;64`1&5S8W)I<'1I;VX@9'4@<')O
M8FSH;64`4')O:F5T<P!497AT92!C;W5R=`!#;&5F('!U8FQI<75E`$%L9V]R
M:71H;64@9&4@8VQE9B!P=6)L:7%U90!);F9O<FUA=&EO;G,@<W5R(&QA(&-L
M968@<'5B;&EQ=64`R6-H96,@9&4@;&$@9^ENZ7)A=&EO;B!D92!L82!P86ER
M92!D92!C;&5F<R!P=6)L:7%U92]P<FEVZ64N`%!O<G1O(%)I8V\`46%T87(`
M4F5Q=>IT90#)8VAE8R!D92!L82!R97%UZG1EH#H@*"5S*2`E<P!296-H97)C
M:&4@<VEM<&QI9FGI90!1=6]T80!#;&5F('!U8FQI<75E(%)302`H)60@8FET
M<RD`4^EL96-T:6]N(')A9&EO`%!L=6EE`%!L=6EE('3T="!L92!M871I;@!0
M;'5I92!T87)D(&1A;G,@;&$@:F]U<F[I90!!=F5R<V5S`%!L=6EE(&5T(&YE
M:6=E`%!L=6EE('!U:7,@;F5I9V4`07!H;W)I<VUE(&%U(&AA<V%R9`!4875X
M`$QI<F4`R6-H96,@9&4@;&5C='5R9:`Z("@E<RD@)7,`365S<V%G97,@;'5S
M`$QA(&QE8W1U<F4@9&5S(&-O;G1A8W1S(&XG97-T('!A<R!D:7-P;VYI8FQE
M+@!3=7!P<F5S<VEO;B!DZ69I;FET:79E(&1E("5SH#\`4W5P<')I;65R(&-E
M(&-O;G1A8W0@9.EF:6YI=&EV96UE;G2@/P!3=7!P<F5S<VEO;B!DZ69I;FET
M:79E(&1E<R!D;VYNZ65S('!O=7(@;"=U=&EL:7-A=&5U<B`E<Z`_($-E='1E
M(&]PZ7)A=&EO;B!E<W0@9.EF:6YI=&EV92X`16YR96=I<W1R96UE;G1S(&%F
M9FEC:.ESH#H`4F5P<F5N9')E('9O=')E(&1E<FYIZ')E(&%C=&EO;@!2869R
M8>YC:&ER`%)A9G)A[F-H:7(@;&5S(.ELZ6UE;G1S(&1U(&UE;G4@9'EN86UI
M<75EH#H`4F%F<F'N8VAI<B!L)^EC<F%N(&1U('-O;6UA:7)EH#H`17AP<F5S
M<VEO;B!R871I;VYN96QL90!.879I9V%T975R(')E;&%T:6]N;F5L`%)E8VAA
M<F=E<@!296UA<G%U97,`4V5R=F5U<G,@9&ES=&%N=',`55),(&1I<W1A;G1E
M("AH='1P.B\O=W=W+F5X96UP;&4N8V]M+VAO<F1E+RF@.@!2971I<F5R`%)E
M=&ER97(@;&4@8FQO8P!3=7!P<FEM97(@=6X@8V%R;F5T(&0G861R97-S97,`
M4F5T:7)E<B!L82!C;VQO;FYE`%)E=&ER97(@;&4@9F]R;6%T86=E`%)E=&ER
M97(@9&4@;&$@;&ES=&4`4F5T:7)E<B!L82!P86ER90!%;FQE=F5R(&QE('-C
M<FEP="!E;G)E9VES='+I(&1U('+I<&5R=&]I<F4@=&5M<&]R86ER92!D=2!S
M97)V975R+@!2971I<F5R(&QE`%)E=&ER97(@8V4@;F]E=60@9'4@9&]C=6UE
M;G0`4F5T:7)E<B!L)W5T:6QI<V%T975R`%)E=&ER97(@;"=U=&EL:7-A=&5U
M<J`Z("5S`%)E;7!L86-E<B!L92!C87)N970@9"=A9')E<W-E<R!E>&ES=&%N
M="!P87(@8V5L=6D@:6UP;W)TZ:`_(#QS=')O;F<^071T96YT:6]NH#H@8V5L
M82!S=7!P<FEM97)A('1O=71E<R!V;W,@96YT<NEE<R!D=2!P<NES96YT(&-A
M<FYE="!D)V%D<F5S<V5S+CPO<W1R;VYG/@!!=6-U;F4@<NEP;VYS92#@('9O
M=')E(')E<77J=&4N($-O9&4@9"=E<G)E=7(@<F5T;W5R;NF@.B``4W5J970@
M;F]N('1R;W5VZ2X`3&4@<V5R=FEC92!D96UA;F3I(&5S="!I;G1R;W5V86)L
M92X`3&4@<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@
M<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N("5S+@!,92!P87)A;>AT
M<F4@;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS
M(&QA(&-O;F9I9W5R871I;VX@9'4@5D93+@!,92!P87)A;>AT<F4@;V)L:6=A
M=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA(&-O;F9I
M9W5R871I;VXN`$-H86UP(&]B;&EG871O:7)E`%+`6@!296UI<V4@X"!ZZ7)O
M(&1U(&UO="!D92!P87-S90!296UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E
M('!A<W-E`%)E;65T=')E(.`@;&$@8V]N9FEG=7)A=&EO;B!P87(@9.EF875T
M`%)E=F5N:7(@X"!L82!D97)N:>AR92!R97%UZG1E`%+I<W5L=&%T<P!2979E
M;FER(&%U>"!O<'1I;VYS`%+I+65N=')E<B!L92!N;W5V96%U(&UO="!D92!P
M87-S90!2Z75N:6]N`%)E=F5N:7(@X"!L82!C;VYF:6=U<F%T:6]N('!RZ6/I
M9&5N=&4`3W!T:6]N<R!D92!L)^ED:71E=7(@4FEC:"!497AT`$1E=FEN971T
M97,`1')O:71E`$5N=.IT92!D92!D<F]I=&4`5F%L975R<R!C;W)R96-T97,`
M4')O<')IZ73I<R!D92!L82!R86Y?9^EE("XN+@!2]&QE`%)O=6UA;FEE`%!I
M=F]T97(@,3@P`%!I=F]T97(@X"!G875C:&4`4&EV;W1E<B#@(&1R;VET90!0
M<F]P<FGI=.ES(&1E(&QA(')A;F?I90!0<F]P<FGI=.ES(&1E(&QA(')A;F?I
M90!286YGZ65SH#H`4NAG;&5S`$1E<R!F:6QE=',@87!P87)A[G1R;VYT(&5N
M=')E('1O=71E<R!L97,@<F%N9^EE<R!E="!L97,@8V]L;VYN97,`1&5S(&9I
M;&5T<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(&-O;&]N;F5S('-E=6QE;65N
M=`!$97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!L97,@<F%N9^EE<R!S
M975L96UE;G0`3&%N8V5R`%)U<W-I90!2=V%N9&$`4VEG;F%T=7)E(.EL96-T
M<F]N:7%U92!3+TU)344`365S<V%G92!C:&EF9G+I(%,O34E-10!#97)T:69I
M8V%T('!U8FQI8R!3+TU)344`3"=A=71H96YT:69I8V%T:6]N(%-!4TP@;B=E
M<W0@<&%S(&1I<W!O;FEB;&4`365S<V%G97)I92!335,`26YT97)P<NET975R
M(%-13`!/<F1R92!344P@<&]U<B!R971O=7)N97(@;&5S('9A;&5U<G,`4U-(
M`,EC:&5C(&1E(%-405)45$Q3H#H@*"5S*2`E<P!354-#R%,`26YT97)P<NET
M975R(%-?44P`4V$`4V%I;G1E+4CI;.AN90!386EN="U#:')I<W1O<&AE+65T
M+4YIZ7;H<P!386EN=&4M3'5C:64`4V%I;G0M4&EE<G)E(&5T($UI<75E;&]N
M`%-A:6YT+59I;F-E;G0M970M;&5S($=R96YA9&EN97,`3>IM92!C861R92`H
M7W-E;&8I`%-A;6]A(&]C8VED96YT86QE<P!386EN="U-87)I;@!386\M5&]M
MZ2UE="U0<FEN8VEP90!&;W5R;FES<V5U<B!S871E;&QI=&4`07)A8FEE(%-A
M;W5D:71E`$5N<F5G:7-T<F5R`$5N<F5G:7-T<F5R(*N@)7.@NP!%;G)E9VES
M=')E<B`E<P!%;G)E9VES=')E<B!L97,@;W!T:6]N<P!%;G)E9VES=')E<B!L
M82!C;VYF:6=U<F%T:6]N(&?I;NERZ64@8V]M;64@=6X@<V-R:7!T(%!(4"!D
M86YS(&QE('+I<&5R=&]I<F4@=&5M<&]R86ER92!D92!V;W1R92!S97)V975R
M+@!%;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N(&1E("5S`%-C<FEP="!D
M92!M:7-E(.`@:F]U<B!D92!C;VYF:6=U<F%T:6]N(&5N<F5G:7-T<ND@<V]U
M<Z`Z(*L@)7.@NP!,)V5N<F5G:7-T<F5M96YT(&1E<R!C;VYT86-T<R!N)V5S
M="!P87,@9&ES<&]N:6)L90!/<F%G97,@:7-O;.ES`%-C:65N8V4`4F5C:&5R
M8VAE<@!-;W1E=7)S(&1E(')E8VAE<F-H90!,82!R96-H97)C:&4@82#I8VAO
M=>D`R6-H96,@9&4@;&$@<F5C:&5R8VAEH#H@)7,`3&$@<F5C:&5R8VAE(&XG
M97-T('!A<R!D:7-P;VYI8FQE`%)E8VAE<F-H92!E;B!C;W5R<RXN+@!#:&]I
M<VES<V5Z(&QE<R!F:6-H:65R<P!3Z6QE8W1I;VYN97H@=6YE(&1A=&4`4^EL
M96-T:6]N;F5Z('5N(&=R;W5P92#@(&%J;W5T97(`4^EL96-T:6]N;F5Z('5N
M(&YO=79E874@<')O<')IZ71A:7)E`%/I;&5C=&EO;FYE>B!U;B!S97)V975R
M`%/I;&5C=&EO;FYE>B!U;B!U=&EL:7-A=&5U<B#@(&%J;W5T97(`5&]U="!S
MZ6QE8W1I;VYN97(`4^EL96-T:6]N;F5Z('1O=71E<R!L97,@8V]M<&]S86YT
M97,@9&4@;&$@9&%T92X`4^EL96-T:6]N;F5Z(&QE(&-A<FYE="!D)V%D<F5S
M<V5S(.`@<W5P<')I;65RH#H`4^EL96-T:6]N;F5Z(&QE(&-A<FYE="!D)V%D
M<F5S<V5S(.`@Z61I=&5RH#H`0VAO:7-I<W-E>B!U;B!O8FIE=`!.92!SZ6QE
M8W1I;VYN97(@875C=6X`4^EL96-T:6]N;F5Z(&QE(&-A<FYE="!D)V%D<F5S
M<V5S('!O=7(@;"=E>'!O<G1A=&EO;J`Z`%/I;&5C=&EO;FYE>B!L92!C87)N
M970@9"=A9')E<W-E<R!P;W5R(&PG:6UP;W)T871I;VZ@.@!3Z6QE8W1I;VYN
M97H@;&5S(&-A<F%C=.AR97,@9&]N="!V;W5S(&%V97H@8F5S;VEN(.`@;"=A
M:61E(&1E(&PG;W5T:6P@8VDM9&5S<V]U<RX@5F]U<R!P;W5V97H@96YS=6ET
M92!L97,@8V]P:65R(&5T(&QE<R!C;VQL97(@9&%N<R!V;W1R92!T97AT92X`
M4^EL96-T:6]N;F5Z(&QE(&IE=2!D92!C87)A8W3H<F5S(&1U(&9I8VAI97(@
M<V]U<F-EH#H`4^EL96-T:6]N;F5Z(&QE(&3I;&EM:71E=7(@9&4@9&%T9:`Z
M`%/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@9&%T9:`Z`$-H;VES:7-S97H@
M;&4@9F]R;6%T(&0G97AP;W)T871I;VZ@.@!3Z6QE8W1I;VYN97H@;&4@9FEC
M:&EE<B#@(&EM<&]R=&5RH#H`0VAO:7-I<W-E>B!L92!F;W)M870@9'4@9FEC
M:&EE<B!S;W5R8V6@.@!3Z6QE8W1I;VYN97H@;&4@9F]R;6%T(.`@=71I;&ES
M97(@<&]U<B!A9F9I8VAE<B!L97,@;F]M<Z`Z`%/I;&5C=&EO;FYE<B!L92!P
M<F]F:6P@<75E('9O=7,@9.ES:7)E>B!M;V1I9FEE<CH`4^EL96-T:6]N;F5Z
M(&QE(&3I;&EM:71E=7(@9"=H975R9:`Z`%/I;&5C=&EO;FYE>B!L92!F;W)M
M870@9&4@;"=H975R9:`Z`%/I;&5C=&EO;FYE>B!D975X(&-H86UP<R!A<'!A
M<F5N=.ES+@!3Z6QE8W1I;VYN97H@;&$@=G5E(.`@869F:6-H97(@<&%R(&3I
M9F%U="P@86EN<VD@<75E(&QE<R!O<'1I;VYS(&1E('1R:2!E="!D92!P86=I
M;F%T:6]N+@!3Z6QE8W1I;VYN97H@;&5S(&-H86UP<R#@(&%F9FEC:&5R(&1A
M;G,@;&$@;&ES=&4@9&5S(&%D<F5S<V5S+@!3Z6QE8W1I;VYN97H@;&4@9F]R
M;6%T('5T:6QI<^D@<&]U<B!A9F9I8VAE<B!L97,@;F]M<RX`4^EL96-T:6]N
M;F5Z('9O=')E('1HZ&UE(&1E(&-O=6QE=7)S+@!3Z6QE8W1I;VYN97H@=F]T
M<F4@;&%N9W5E('!RZ6;I<NEEH#H`0V%R;F5T(&0G861R97-S97,@<^EL96-T
M:6]N;NF@.B`E<RX`16YV;WEE<B!L92!R87!P;W)T(&0G86YO;6%L:64`16YV
M;WEE<B!335,`4^ENZ6=A;`!3;VYD9:`Z(`!397!T96UB<F4`4V5R8FEE(&5T
M($UO;G1E;F5G<F\`3G5MZ7)O(&1E('/I<FEE`$QE<R!D;VYNZ65S(&1U('-E
M<G9E=7(@<V]N="!F875S<V5S(&]U(&YO;B!D:7-P;VYI8FQE<RX`061M:6YI
M<W1R871I;VX@9&5S('-E<W-I;VYS`$ED+B!D92!S97-S:6]N(&5X<&ERZ2X`
M4V5S<VEO;G,`4^EL96-T:6]N;F5R`$-O;F9I9W5R97(@;&5S(&]P=&EO;G,@
M<&]U<B!V;W5S('!E<FUE='1R92!D92!R96UE='1R92#@('KI<F\@=F]T<F4@
M;6]T(&1E('!A<W-E('-I(&IA;6%I<R!V;W5S(&PG;W5B;&EE>BX`0V]N9FEG
M=7)E<B!L97,@<V5R=F5U<G,@9&ES=&%N=',@86-C97-S:6)L97,@9&5P=6ES
M('9O=')E('!O<G1A:6PN`%/I;&5C=&EO;FYE>B!V;W1R92!L86YG=64@<'+I
M9NERZ64L(&9U<V5A=2!H;W)A:7)E(&5T(&QE<R!O<'1I;VYS(&1E(&1A=&4N
M`$3I9FEN:7-S97H@;&$@<')E;6GH<F4@87!P;&EC871I;VX@;&%N8^EE+"!L
M92!T:.AM92!D92!C;W5L975R<RP@;&4@<F%F<F'N8VAI<W-E;65N="!D97,@
M<&%G97,L(&5T(&0G875T<F5S(&]P=&EO;G,@9"=A9F9I8VAA9V4N`$-O;F9I
M9W5R871I;VX`4V-R:7!T(&1E(&-O;F9I9W5R871I;VX@9&4@;6ES92#@(&IO
M=7(@9&ES<&]N:6)L90!0;'5S:65U<G,@96YD<F]I=',@<&]S<VEB;&5S(&%V
M96,@;&4@<&%R86WH=')EH#H@`%-E>6-H96QL97,`4NEP97)T;VER92!P87)T
M86?I`$%C:&%T`%+I<W5MZ0!$;VET+6]N(&3I9FEN:7(@9&5S('1O=6-H97,@
M9&4@<F%C8V]U<F-I<R!P;W5R(&QA('!L=7!A<G0@9&5S(&QI96YSH#\`069F
M:6-H97(`069F:6-H97(@)7,`069F:6-H97(@=&]U=`!!9F9I8VAE<B!C;VYT
M86-T<P!!9F9I8VAE<B!L:7-T97,`36]N=')E<B!L97,@9&EF9NER96YC97,@
M96YT<F4@;&$@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I92!A8W1U96QL96UE
M;G0@970@8V5L;&4@;F]U=F5L;&5M96YT(&?I;NERZ64N`$UO;G1R97(@;"=H
M975R92!D92!L82!D97)N:>AR92!C;VYN97AI;VX@X"!L)V5N='+I9:`_`$UO
M;G1R97(@;"=O<'1I;VX@9&4@8V]N<V5R=F5R(&PG;W)I9VEN86P`36]N=')E
M<B!L92!SZ6QE8W1E=7(`069F:6-H97(@;&$@8F%R<F4@9&4@;65N=2!D92!T
M86)L96%U>*`_`$%F9FEC:&5R(&QE(&UE;G4@)7,@X"!G875C:&6@/P!!9F9I
M8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!T86)L96%U(&-E;&QU;&4`069F
M:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ETZ7,@9'4@
M=&%B;&5A=0!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!D97,@<')O
M<')IZ73I<R!D92!L82!R86YGZ64@9'4@=&%B;&5A=0!!9F9I8VAE<B!L82!B
M;^YT92!D92!D:6%L;V=U92!D97,@<')O<')IZ73I<R!D92!L)VEM86=E`$%F
M9FEC:&5R(&PG96YV;VD@9&4@9FEC:&EE<@!!=F5R<V5S`$%V97)S97,@=/1T
M(&1A;G,@;&$@:F]U<F[I90!!=F5R<V5S('1A<F0@96X@:F]U<F[I90!!=F5R
M<V5S(&%U>"!A;&5N=&]U<G,`4F5S<V5R<F5R`%)E<W-E<G)E<B!O=2!DZ6=A
M9V5R(&0G86)O<F0@;&4H<RD@8FQO8RAS*2!V;VES:6XH<RD`4VEE<G)A($QE
M;VYE`%,G:6YS8W)I<F4`4VEG;F%T=7)E`$%L9V]R:71H;64@9&4@<VEG;F%T
M=7)E`%-I;F=A<&]U<@!486EL;&4`06YN=6QE<B!L82!M86EN=&5N86YC90!3
M;&]V87%U:64`4VQO=NEN:64`3F5I9V4`079E<G-E(&1E(&YE:6=E`$%V97)S
M97,@9&4@;F5I9V4`079E<G-E<R!D92!N96EG92!T]'0@9&%N<R!L82!J;W5R
M;NEE`$%V97)S97,@9&4@;F5I9V4@=&%R9"!E;B!J;W5R;NEE`$AA=71E=7(@
M9&4@;F5I9V6@.B``475A;G1I=.D@9"=E874@Z7%U:79A;&5N=&4@X"!L82!Q
M=6%N=&ETZ2!D92!N96EG9:`Z(`#.;&5S(%-A;&]M;VX`4V]M86QI90!#:&%N
M<V]N<R!E="!P;^AM97,`4V5N<R!D=2!T<FD`4^EL96-T:6]N(&1E(&PG;W)D
M<F4@9&4@=')I`$%D<F5S<V4@<V]U<F-E`%-O=7)C97,`069R:7%U92!D=2!S
M=60`4W5D+65U<F]PZ65N("A)4T\M.#@U.2TS*0!'Z6]R9VEE+61U+7-U9"!E
M="#N;&5S(%-A;F1W:6-H+61U+7-U9`!(Z6UI<W!HZ')E(%-U9`!%<W!A8V4@
M96YT<F4@8V5L;'5L97,@861J86-E;G1E<P!%<W!A8V4@96YT<F4@;&4@8V]N
M=&5N=2!E="!L82!B;W)D=7)E(&1A;G,@=6YE(&-E;&QU;&4`17-P86-E=7(`
M17-P86-E;65N=`!%<W!A8V5M96YT(&5T(')E;7!L:7-S86=E`$5S<&%G;F4`
M4&]U<G)I96P`0V%R86-TZ')E<R!S<.EC:6%U>`!3<.EC:69I97(@;"=E;F1R
M;VET(&_Y(&QE('+I<W5L=&%T(&1E(&QA(')E8VAE<F-H92!A=F%N8^EE(&1O
M:70@<R=A9F9I8VAE<BX`4V-I;F1E<B!L82!C96QL=6QE`%-C:6YD97(@;&$@
M8V]L;VYN90!38VEN9&5R(&QA(')A;F?I90!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!!;F[I92!D92!DZ6)U=`#)=&%T(&]U('!R;W9I
M;F-E`%-T871U=`!&;W)M870@9&4@<V%U=F5G87)D90!2=64`0F%R<ND`3&ES
M=&4@9&4@8VAA[FYE<P!2971I<F5R(&QE(&1O;6%I;F4@9&4@;"=A9')E<W-E
M`%-T>6QE(%M#4U-=`$1I`%-O=7,M<NEP97)T;VER92"KH"5SH+L@;F]N('1R
M;W5VZ0!3=6IE=`!%;G9O:0!,82!D96UA;F1E(&0G86IO=70@9&4@JZ`E<Z"[
M(&%U('-Y<W3H;64@82#I=.D@<V]U;6ES92X@5F]U<R!N92!P;W5R<F5Z('!A
M<R!V;W5S(&-O;FYE8W1E<B!J=7-Q=2?@('-O;B!A<'!R;V)A=&EO;BX`26YD
M:6-E`%-U8V/H<P"KH"5SH+L@82!B:65N(.ETZ2!A:F]U=.DH92DN`"5D(&-O
M;G1A8W0H<RD@86IO=73I*',I(.`@;&$@;&ES=&4N`*N@)7.@NR!A(&)I96X@
MZ73I(&%J;W5TZ2AE*2#@("5S+@!,97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T
M975R(*N@)7.@NR!O;G0@8FEE;B#I=.D@<F5T:7+I97,@9'4@<WES=.AM92XN
M`$QA(&QI<W1E(*N@)7.@NR!A(&)I96X@Z73I(&-RZ>EE+@"KH"5SH+L@82!B
M:65N(.ETZ2!S=7!P<FEMZ2AE*2X`4W5P<')E<W-I;VX@9&4@)60@8V]N=&%C
M="AS*2X`JZ`E<Z"[(&$@8FEE;B#I=.D@<F5T:7+I*&4I+@`E9"!C;VYT86-T
M*',I(')E=&ERZ2AS*2!D92!L82!L:7-T92X`4F5T;W5R(.`@;&$@8V]N9FEG
M=7)A=&EO;B!I;FET:6%L92!RZ75S<VDN("!2869R8>YC:&ER(&QA('!A9V4@
M<&]U<B!V;VER(&QE<R!M;V1I9FEC871I;VYS+@!%;G)E9VES=')E;65N="!D
M92!L82!C;VYF:6=U<F%T:6]N(&1E(&QA('-A=79E9V%R9&4@<NEU<W-I+@!%
M;G)E9VES=')E;65N="!RZ75S<VD@9&4@;&$@8V]P:64@9&4@<V%U=F5G87)D
M92!D=2!F:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N`*N@)7.@NR!A(&)I
M96X@Z73I(&UI<RAE*2#@(&IO=7(N`,EC<FET=7)E(&1E("5S('+I=7-S:0!3
M;W5D86X`4V]M;6%I<F4`3&5V97(@9'4@4V]L96EL`$-O=6-H97(@9'4@4V]L
M96EL`$5N<V]L96EL;.D`3&5V97(@9'4@4V]L96EL`$QE=F5R+T-O=6-H97(@
M9'4@4V]L96EL`$QE=F5R(&1U(%-O;&5I;#H@`$-O=6-H97(@9'4@4V]L96EL
M`$-O=6-H97(@9'4@4V]L96ELH#H@`$5X<&]S86YT`$%S<VES=&%N8V4`4W5R
M:6YA;2!O=2!'=7EA;F4@:&]L;&%N9&%I<V4`3F]M(&1E(&9A;6EL;&4`SFQE
M<R!3=F%L8F%R9"!E="!*86X@36%Y96X`4W=A>FEL86YD`%-UZ&1E`%-U:7-S
M90!*;W5R;F%L(&1E('-Y;F-H<F]N:7-A=&EO;B!S=7!P<FEMZ0!3>6YC34P`
M17)R975R(&1E('-Y;G1A>&4@9&%N<R!L97,@=&5R;65S(&1E(')E8VAE<F-H
M90!3>7)I90!/<F%G97,`3W)A9V4@970@=F5N=`!/<F%G97,`3W)A9V5S(&UA
M=&EN875X`%135@!&:6-H:65R(%135@!686QE=7)S('/I<&%RZ65S('!A<B!T
M86)U;&%T:6]N`%1A8FQE874`4')O<')IZ73I<R!D=2!T86)L96%U`%1A8FQE
M874@9&4@=F%L975R<P!0<F]P<FGI=.ES(&1U('1A8FQE874`5&'O=V%N`%1A
M[W=A;BP@<')O=FEN8V4@9&4@0VAI;F4`5&%J:6MI<W1A;@!486YZ86YI90!#
M:6)L9:`Z`%3B8VAE<P!.=6WI<F\@9&4@=.ELZ7!H;VYE`%1E;7#I<F%T=7)E
M('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``5&5M<.ER871U<F4`5&5M<.ER
M871U<F6@.B``5&5M<.ER871U<F4\8G(@+SXH)7-(825S+R5S0F$E<RD@)F1E
M9SLE<P!0<F]F:6P@JZ`E<Z"[(&YO;B!T<F]U=ND`061M:6YI<W1R871I;VX@
M9&5S(&UO9.AL97,`5&5X=&4`5&5X=&4@<V5U;`!!;&EG;F5M96YT(&1U('1E
M>'1E`%1E>'1E(&5N(&AA=70`2F4`5&AA[R`H5$E3+38R,"D`5&AA[VQA;F1E
M`$PG97AT96YS:6]N($944"!N)V5S="!P87,@9&ES<&]N:6)L92X`3&4@;6]T
M975R(&0G:6YTZ6=R871I;VX@2&]R9&4O2V]L86(@;F4@<W5P<&]R=&4@<&%S
M(*N@)7.@NP!,92!J;W5R;F%L($E-4U`@;B=A('!A<R!P=2#J=')E(&EN:71I
M86QI<^DN`$QA(&-L87-S92!-86EN=&5N86YC93HZ(&XG82!P87,@Z73I(&-H
M87)GZ64@8V]R<F5C=&5M96YT`$QA(&9E;NIT<F4@9&5S(&]P=&EO;G,@<R=E
M<W0@9F5R;>EE+B!3;W)T:64N`$QE(&UO9'5L92!61E,@9&]I="#J=')E(&-O
M;F9I9W5RZ2!P;W5R('!E<FUE='1R92!L92!TZ6SI8VAA<F=E;65N="!D97,@
M<&GH8V5S(&IO:6YT97,N`$QE(&-A<FYE="!D)V%D<F5S<V5S(*N@)7.@NR!N
M)V5X:7-T92!P87,N`$QE(&-A<FYE="!D)V%D<F5S<V5S(*N@)7.@NR!A(.ET
MZ2!C<NGI+@!,92!C87)N970@9"=A9')E<W-E<R"KH"5SH+L@82#I=.D@<W5P
M<')I;>DN`$QE(&-A<FYE="!D)V%D<F5S<V5S(*N@)7.@NR!A(.ETZ2!M:7,@
MX"!J;W5R+@!,92!C87)N970@9"=A9')E<W-E<R!N)V$@<&%S('!U(.IT<F4@
M<'5R9^F@.B`E<P!,)V%D;6EN:7-T<F%T975R(&1O:70@8V]N9FEG=7)E<B!U
M;B!B86-K96YD('!E<FUA;F5N="!P;W5R(&QE<R!P97)M:7-S:6]N<R!S:2!V
M;W5S('9O=6QE>B!L97,@96UP;&]Y97(N`$QA(&)O<F1U<F4@9'4@8F%S('-E
M=6QE;65N=`!,)TE$(&1U(&-O;G1A8W0@;B=A('!A<R#I=.D@<W#I8VEF:>DL
M(&QA:7-SZ2!V:61E(&]U(&XG82!P87,@Z73I('1R;W5VZ2!D86YS(&QA(&)A
M<V4@9&4@9&]N;NEE<RX`0V4@8V]N=&%C="!A(&)I96X@Z73I(&%J;W5TZ2#@
M('9O=')E(&-A<FYE="!D)V%D<F5S<V5S+B``3&4@8V]N=&%C="!D96UA;F3I
M(&XG97AI<W1E('!A<RX`3&4@8FQO8R!D92!S:6=N871U<F4@4$=0('/I<&%R
MZ2!E<W0@;NEC97-S86ER92!P;W5R(';I<FEF:65R(&QA('-I9VYA='5R92X`
M3"=)1"!D92!L82!L:7-T92!N)V$@<&%S(.ETZ2!S<.EC:69IZ2P@;&%I<W/I
M('9I9&4@;W4@;F]N('1R;W5VZ2!D86YS(&QA(&)A<V4@9&4@9&]N;NEE<RX`
M3&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N(&XG82!P87,@Z73I('-PZ6-I9FGI
M92X`3&4@8VAI9F9R96UE;G0@;NEC97-S:71E('5N92!C;VYN97AI;VX@<^EC
M=7)I<^EE+@!,92!F:6-H:65R(*N@)7.@NR!A(.ETZ2!S=7!P<FEMZ2X`3&4@
M9FEC:&EE<B`E<R!D;VET(&-O;G1E;FER(&QE<R!O<'1I;VYS("5S+@!,92!F
M:6-H:65R("5S(&1O:70@8V]N=&5N:7(@8V5R=&%I;F5S(&]P=&EO;G,@)7,N
M`$QE(&9I8VAI97(@;F4@<&5U="!P87,@ZG1R92!C;W!IZ2!S=7(@;'5I+6WJ
M;64N`$QE(&9I8VAI97(@;F4@8V]N=&5N86ET(&%U8W5N92!D;VYNZ64N`$-E
M('%U:2!S=6ET('-O;G0@;&5S(&5N+73J=&5S('!O=7(@8V4@;65S<V%G92!M
M97-S86=E+U)&0S@R,BX`3&4@;6]D92!P;&5I;B#I8W)A;B!C875S92!D97,@
M<')O8FSH;65S(&%V96,@26YT97)N970@17AP;&]R97(@9/L@X"!D97,@8F]G
M=65S(&1U(&YA=FEG871E=7(@<75I(&XG;VYT('!U(.IT<F4@8V]N=&]U<F[I
M<RX@5F]U<R!P;W5V97H@ZG1R92!C;VYF<F]N=.ES(.`@9&4@;"=A9F9I8VAA
M9V4@9&4@8V%R86-TZ')E<R#I=')A;F=E<RP@874@;F]N+69O;F-T:6]N;F5M
M96YT(&1E<R!C97)T86EN97,@9F]N8W1I;VYS(&5T+V]U(&%U('!L86YT86=E
M(&%LZ6%T;VER92!D=2!N879I9V%T975R+B!3:2!V;W1R92!S>7-TZ&UE(&5S
M="!U;B!7:6YD;W=S(#EX+"!I;"!E<W0@='+H<R!P;W-S:6)L92!Q=64@=F]U
M<R!A=7)E>B!U;F4@)T9A=71E(&?I;NER86QE(&1E('!R;W1E8W1I;VXG(&5T
M('%U92!V;W5S(&1E=G)E>B!R963I;6%R<F5R('9O=')E(&]R9&EN871E=7(N
M7&Y<;E9O=7,@879E>B#I=.D@<'+I=F5N=7,N(%-64"!A<'!U>65Z('-U<B!/
M2R!S:2!V;W5S('9O=6QE>B!T;W5J;W5R<R!E<W-A>65R(&QE(&UO9&4@<&QE
M:6X@Z6-R86X@9&4@;"?I9&ET975R`$PG:61E;G1I=.D@JZ`E<Z"[("!A(.ET
MZ2!S=7!P<FEMZ64N`$PG:6UP;W)T871I;VX@<R=E<W0@=&5R;6ENZ64@;6%L
M9W+I(&QE<R!A=F5R=&ES<V5M96YT<RX`3&4@8_1TZ2!G875C:&4@<V5U;&5M
M96YT`$PG96UP;&%C96UE;G0@9'4@<')O9W)A;6UE($=N=5!'(&1O:70@ZG1R
M92!F;W5R;FD@X"!L82!C;&%S<V4@0W)Y<'1?<&=P.CHN`$QE(&UE<W-A9V4@
M96YV;WGI(&QE("5S(.`@)7,@879E8R!C;VUM92!S=6IE=""KH"5SH+L@82#I
M=.D@869F:6-HZ2X@"DEL(&XG>2!A(&%U8W5N92!G87)A;G1I92!Q=64@8V4@
M;65S<V%G92!A(.ETZ2!L=2!O=2!C;VUP<FES+@!,92!N;VT@X"!U=&EL:7-E
M<B!E;B!L:6%N="#@(&QA('!A9V4@9&4@8V]M<&]S:71I;VX`3&4@;F]M8G)E
M(&1E(&-H86UP<R!D;VET(.IT<F4@=6X@;F]M8G)E('9A;&ED92X`3&4@;6]D
M=6QE($]P96Y34TP@97-T(')E<75I<R!P;W5R(&QA(&-L87-S92!(;W)D95]#
M<GEP=%]S;6EM93HZ+@!,82!P<NEFZ7)E;F-E(*N@)7.@NR!N)V$@<&%S('!U
M(.IT<F4@96YR96=I<W1RZ64@8V%R('-A('1A:6QL92!DZ7!A<W-E(&QE(&UA
M>&EM=6T@875T;W)I<^D`3&4@<')O9W)A;6UE('5T:6QI<^D@<&]U<B!V:7-U
M86QI<V5R(&-E('1Y<&4@9&4@9&]N;NEE<R`H)7,I(&XG82!P87,@Z73I('1R
M;W5VZ2X`3&4@8V%R86-TZ')E(&1E('!R;W1E8W1I;VX@9&]I="#J=')E('5N
M(&-A<F%C=.AR92!U;FEQ=64N`$QE<R!C]'3I<R!G875C:&4@970@9')O:70@
M<V5U;&5M96YT`$QE(&/T=.D@9')O:70@<V5U;&5M96YT`$QE('/I<&%R871E
M=7(@9&]I="#J=')E('5N(&-A<F%C=.AR92!U;FEQ=64N`$QE('-E<G9E=7(@
MJZ`E<Z"[(&$@Z73I('-U<'!R:6WI+@!,92!S97)V975R(*N@)7.@NR!A(.ET
MZ2!E;G)E9VES='+I+@!,82!R97%UZG1E(&0G96YR96=I<W1R96UE;G0@<&]U
M<B`E<R!A(.ETZ2!DZ7!L86/I92X`3&$@;&EG;F4@9&5M86YDZ64@;B=E>&ES
M=&4@<&%S+@!,92!F:6-H:65R('1E;7!O<F%I<F4@JR`E<Z"[(&XG97AI<W1E
M('!A<RX`3&4@=&5X=&4@96YT<ND@;F4@8V]R<F5S<&]N9"!P87,@874@=&5X
M=&4@<W5R(&PGZ6-R86XN`$QE(&AA=70@970@;&4@8F%S('-E=6QE;65N=`!,
M92!H875T('-E=6QE;65N=`!,97,@9&]N;NEE<R!TZ6SI8VAA<F?I97,@=F5R
M<R!L92!S97)V975R(&]N="#I=.D@<&5R9'5E<R!D97!U:7,@;"?I=&%P92!P
M<NECZ61E;G1E+B``3&4@9FEC:&EE<B#I;6ES(&XG82!P87,@<'4@ZG1R92!E
M;G)E9VES='+I+@!,92!B;&]C(*N@=V5A=&AE<BYC;VV@NR!N)V5S="!P87,@
M9&ES<&]N:6)L92X`4NEP97)T;VER92!D97,@=&CH;65S(*N@)7.@NR!N;VX@
M=')O=7;I`$%U8W5N(&-A<FYE="!D)V%D<F5S<V5S(&1I<W!O;FEB;&4@96X@
M;&5C='5R92X`26P@;B=Y(&$@<&%S(&0G;W!T:6]N<R!D:7-P;VYI8FQE<P!!
M=6-U;F4@<&%R=&EE(&YE('!E=70@ZG1R92!A9F9I8VCI92!E;B!L:6=N92X`
M075C=6X@9&5S(&%N;G5A:7)E<R!D:7-P;VYI8FQE<R!N)V5S="!C;VYF:6=U
M<ND@<&]U<B!V;W5S('!E<FUE='1R92!D)V%J;W5T97(@=6X@;F]U=F5A=2!C
M;VYT86-T+B!3:2!V;W5S('!E;G-E>B!Q=64@8V5C:2!E<W0@=6YE(&5R<F5U
M<BP@8V]N=&%C=&5Z('9O=')E(&%D;6EN:7-T<F%T975R('-Y<W3H;64N`$EL
M('D@(&$@=')O<"!D92!C87)A8W3H<F5S(&1A;G,@8V4@8VAA;7`N(%9O=7,@
M96X@879E>B!E;G1RZ2`E<Z`[(&EL(&5N(&9A=70@;6]I;G,@9&4@)7,N`%5N
M('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L)V%J;W5T(&1E(*N@)7.@
MNZ`Z("5S`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P
M<F5S<VEO;B!D97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R(*N@)7.@NZ`Z
M(`!5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;&$@<W5P<')E<W-I
M;VX@9&4@JZ`E<Z"[H#H@`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D
M92!L82!M:7-E(.`@:F]U<B!D92"KH"5SH+N@.B`E<P!5;B!P<F]B;.AM92!E
M<W0@87!P87)U(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65RH#H@875C=6X@
M)7,@;B=A(.ETZ2!T<F%N<VUI<RX`56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@
M;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!L92`E<R#I=&%I="!P;'5S
M(&=R;W,@<75E(&QE(&UA>&EM=6T@875T;W)I<^D@*"5D(&]C=&5T<RDN`%5N
M92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H
M:65RH#H@;&4@)7,@82#I=.D@=')A;G-M:7,@<&%R=&EE;&QE;65N="X`56YE
M(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V%J;W5T(&1E(&-E(&-O
M;G1A8W0N($-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U<B!S>7-TZ&UE
M('!O=7(@<&QU<R!D)VEN9F]R;6%T:6]N<RX`56YE(&5R<F5U<B!E<W0@<W5R
M=F5N=64@;&]R<R!D92!L82!C<NEA=&EO;B!D92!C971T92!L:7-T92X`56YE
M(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L82!C<NEA=&EO;B!D92!C
M92!C87)N970@9"=A9')E<W-E<Z`Z("5S`%5N92!E<G)E=7(@97-T('-U<G9E
M;G5E(&QO<G,@9&4@;"=E9F9A8V5M96YT(&1E("5S(&1U(&-A<FYE="!D)V%D
M<F5S<V5S(&0G;W)I9VEN92X`56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R
M<R!D92!L82!S=7!P<F5S<VEO;B!D92!C92!C;VYT86-TH#H@)7,`56YE(&5R
M<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V%F9FEC:&%G92!D92!L82!L
M:7-T90!5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=A9F9I
M8VAA9V4@9&4@8V5T=&4@<&%R=&4@9'4@;65S<V%G90!5;F4@97)R975R(',G
M97-T('!R;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE
M<R!D92!C92!C;VYT86-T+@!5;F4@97)R975R(&5S="!S=7)V96YU92!L;W)S
M(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I97.@.B`E<P!5;F4@97)R975R
M(&5S="!S=7)V96YU92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I
M97,@:4-A;&5N9&%R+@!);"!Y(&%V86ET('5N92!E<G)E=7(@9&%N<R!L92!F
M;W)M=6QA:7)E(&1E(&-O;F9I9W5R871I;VXN(%!E=70MZG1R92!A=F5Z+79O
M=7,@;&%I<W/I('5N(&-H86UP(')E<75I<R!V:61E+@!5;F4@97)R975R(',G
M97-T('!R;V1U:71E(&QO<G,@9&4@;"=E>.EC=71I;VX@9&4@8V5T=&4@9F]N
M8W1I;VX@9'4@8V%R;F5T(&0G861R97-S92X@4U90(&5S<V%Y97(@X"!N;W5V
M96%U('!L=7,@=&%R9"X`56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D
M92!L82!S=7!P<F5S<VEO;B!D92!C92!C87)N970@9"=A9')E<W-E<Z`Z("5S
M`$EL('D@82!E=2!U;F4@97)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@
M9&5S(&EN9F]R;6%T:6]N<R!S=7(@;&4@8V]N=&%C="X@(%9E=6EL;&5Z(&5S
M<V%Y97(@X"!N;W5V96%U+@!);"!Y(&$@974@=6YE(&5R<F5U<B!L;W)S(&1E
M(&QA(&UI<V4@X"!J;W5R(&1E(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@
M(%9E=6EL;&5Z(&5S<V%Y97(@9&4@;F]U=F5A=2X`56YE(&5R<F5U<B!E<W0@
M<W5R=F5N=64@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D92!C92!C87)N970@
M9"=A9')E<W-E<Z`Z("5S`%5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@
M9&4@;&$@;6ES92#@(&IO=7(@9&4@;"=E;G1RZ66@.B`E<P!);"!N)WD@82!P
M87,@9&4@8V%R;F5T(&0G861R97-S97,@X"!E>'!O<G1E<BX`0V5S(&-A<FYE
M=',@9"=A9')E<W-E<R!S97)O;G0@869F:6-HZ7,@9&%N<R!C970@;W)D<F6@
M.@!#97,@8V]L;VYN97,@<V5R;VYT(&%F9FEC:.EE<R!D86YS(&-E="!O<F1R
M9:`Z`$QE('!RZ7-E;G0@<V5R=F5U<B!)34%0(&YE('-U<'!O<G1E('!A<R!L
M92!P87)T86=E(&1E(&1O<W-I97)S+@#'82!N92!S96UB;&4@<&%S(.IT<F4@
M=6YE(&%R8VAI=F4@4D%2('9A;&ED92X`QV$@;F4@<V5M8FQE('!A<R#J=')E
M('5N(&9I8VAI97(@6DE0('9A;&ED92X`QV$@;F4@<V5M8FQE('!A<R#J=')E
M('5N(&YU;>ER;R!D92!C87)T92!V86QI9&4N`$-E('!I;&]T92!P97)M970@
M;"=E;G9O:2!D92!M97-S86=E<R#@('1R879E<G,@;&$@<&%S<V5R96QL92!#
M;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&5N('5T:6QI<V%N
M="!L)T%022!(5%10`$-E('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S
M86=E<R!V:6$@;&$@<&%S<V5R96QL92!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144`!#92!P:6QO=&4@<&5R;65T(&PG
M96YV;VD@9&4@;65S<V%G97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@<VUS
M,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@96X@=71I;&ES86YT(&PG
M05!)($A45%``0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S
M('!A<B!33510(.`@=')A=F5R<R!L82!P87-S97)E;&QE(%9O9&%F;VYE($ET
M86QI92P@<V5U;&5M96YT(&%U>"!N=6WI<F]S(%9O9&%F;VYE+B!#96QA(&[I
M8V5S<VET92!U;B!C;VUP=&4@9&4@8V]U<G)I96P@5F]D869O;F4@271A;&EE
M("AH='1P.B\O=W=W+C$Y,"YI="DN`$-E(&-H86UP(&5S="!O8FQI9V%T;VER
M92X`0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S(&5N=&EE<G,N
M`$-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E<R!N;VUB<F5S(&5T
M(&QE<R!D975X+7!O:6YT<RX`0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q
M=64@9&5S('9A;&5U<G,@;V-T86QE<RX`0V4@8VAA;7`@9&]I="!C;VYT96YI
M<B!U;F4@;&ES=&4@9"=E;G1I97)S('/I<&%RZ7,@<&%R(&1E<R!V:7)G=6QE
M<R!O=2!D97,@97-P86-E<P!#92!C:&%M<"!D;VET(.IT<F4@=6X@;F]M8G)E
M('9A;&ED92X`0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U;B!C;V1E(&1E(&-O
M=6QE=7(@874@9F]R;6%T(%)'0B!H97AA9.EC:6UA;"P@<&%R(&5X96UP;&4@
M)R,Q,C,T868G+@!#92!F;W)M870@9&4@9FEC:&EE<B!N)V5S="!P87,@<W5P
M<&]R=.DN`$-E(&9O<FUU;&%I<F4@82!DZ6K@(.ETZ2!T<F%I=.DN`$,G97-T
M("5S+@!#96-I(&5S="!U;B!O8FIE="!+;VQA8B!'<F]U<'=A<F4N(%!O=7(@
M=F]I<B!C970@;V)J970L('9O=7,@9&5V<F5Z(&%V;VER('5N(&-L:65N="!D
M92!C;W5R<FEE;"!Q=6D@8V]M<')E;F0@;&4@9F]R;6%T($MO;&%B($=R;W5P
M=V%R92X@4&]U<B!U;F4@;&ES=&4@9&4@8V5S(&-L:65N=',@9&4@8V]U<G)I
M96PL('9I<VET97H@)7,`0V4@;65S<V%G92!A(.ETZ2#I8W)I="!D86YS('5N
M(&-O9&4@9&4@8V%R86-TZ')E<R`H)7,I(&%U=')E('%U92!L92!V]'1R92X`
M0V4@;F]M8G)E(&1O:70@ZG1R92!S=7#I<FEE=7(@X"!U;BX`0V5T=&4@<&5R
M<V]N;F4@82!DZ6K@('5N92!E;G1RZ64@)7,@9&%N<R!L92!C87)N970@9"=A
M9')E<W-E<RX`0V4@<V5R=F5U<B!N92!P975T('!A<R!DZ6-O;7!R97-S97(@
M;&5S(&9I8VAI97)S(%I)4"!E="!G>FEP+@!#92!S>7-TZ&UE(&5S="!P<NES
M96YT96UE;G0@9.ES86-T:7;I+@!#971T92!V86QE=7(@9&]I="#J=')E('5N
M(&YO;6)R92X`0V4@<V5R82!L92!C87)N970@9"=A9')E<W-E<R!P87(@9.EF
M875T('!O=7(@;"=A:F]U="!O=2!L)VEM<&]R=&%T:6]N(&1E(&-O;G1A8W1S
M+@!#971T92!F96[J=')E(&1O:70@ZG1R92!A<'!E;.EE(&1E<'5I<R!U;F4@
M9F5NZG1R92!D97,@;W!T:6]N<P!4;VYN97)R90!4:6-K971S`$AE=7)E`%-U
M:79I(&AO<F%I<F4`1F]R;6%T(&0G:&5U<F4`4^EL96-T:6]N(&1E(&PG:&5U
M<F4`5&EM;W(@;W)I96YT86P`1F]N8W1I;VX`5&ET<F4@*&EN9F]B=6QL92F@
M.@#``%!O=7(@<^EL96-T:6]N;F5R('!L=7-I975R<R!I=&5M<R#@(&QA(&9O
M:7,L(&UA:6YT96YE>B!E;F9O;F/I(&QE(&)O=71O;B"KH$-T<FR@NR`H4$,I
M(&]U(*N@0V]M;6%N9&6@NR`H36%C*2!E;B!C;&EQ=6%N="X`075J;W5R9"=H
M=6D`5F]I<B!L82!S;W5R8V4@2%1-3`!4;V=O`%1O:V5L874`1&5M86EN`%1O
M;F=A`$AA=70`0V%D<F4@9'4@:&%U="`H7W1O<"D`5')A9'5C=&EO;G,`5')I
M;FETZ2UE="U4;V)A9V\`5G)A:2!O=2!F875X`$UA`%1U;FES:64`5'5R<75I
M90!4=7)C("A)4T\M.#@U.2TY*0!4=7)K;>EN:7-T86X`SFQE<R!4=7)Q=65S
M(&5T($-A[W%U97,`5'5V86QU`$5N=')E>B!V;W1R92!C:&]I>*`Z(`!);F1I
M8V4@55:@.B``55),`%523"!P;W5R('9O=')E(')A<'!O<G0@9&4@;&EV<F%I
M<V]N(&1U('-C<FEP=`!54DPZ`$]U9V%N9&$`56MR86EN90!);7!O<W-I8FQE
M(&0G871T96EN9')E(&QE('+I<&5R=&]I<F4@5D93+@!);7!O<W-I8FQE(&0G
M86IO=71E<B!D97,@:6YF;W)M871I;VYS(&-O;7!LZ6UE;G1A:7)E<R#@(&PG
M:6YS8W)I<'1I;VXN`$EM<&]S<VEB;&4@9&4@;6]D:69I97(@;&5S('!E<FUI
M<W-I;VYS('!O=7(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE
M(&1E(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N<R!P;W5R(&QE(&9I8VAI97(@
M5D93("5S+R5S+@!);7!O<W-I8FQE(&1E(&-H86YG97(@<&]U<B`E<RX`26UP
M;W-S:6)L92!D92!VZ7)I9FEE<B!L82!T86EL;&4@9'4@9FEC:&EE<B!D92"K
MH"5SH+LN`$EM<&]S<VEB;&4@9&4@=NER:69I97(@;&$@=&%I;&QE(&1U(&9I
M8VAI97(@9&4@JR`E<R\E<R"[+@!#;VYN97AI;VX@:6UP;W-S:6)L92!A=2!S
M97)V975R(%-13"X`0V]N;F5X:6]N(&EM<&]S<VEB;&4@96X@4U-,`$EM<&]S
M<VEB;&4@9&4@8V]P:65R('5N(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&1E
M(&-RZ65R('5N('+I<&5R=&]I<F4@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D
M92!C<NEE<B!U;B!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S:6)L92!D92!C<NEE
M<B!L92!F:6-H:65R(%9&4RX`26UP;W-S:6)L92!D92!C<NEE<B!L92!RZ7!E
M<G1O:7)E(%9&4R"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@8W+I97(@=6X@9FEC
M:&EE<B!61E,@=FED92X@`$EM<&]S<VEB;&4@9&4@8W+I97(@=6X@;F]U=F5A
M=2!P87)T86=E+B!);"!M86YQ=64@;&4@='EP92!D92!L82!S;W5R8V4N`$]U
M=F5R='5R92!I;7!O<W-I8FQE(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE+B``
M4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92"KH"5SH+LL(&QE(&1O<W-I97(@
M;B=E<W0@<&%S('9I9&4N`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@JZ`E
M<Z"[H#H@)7,N`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@)7,L(&QE(&1O
M<W-I97(@;B=E<W0@<&%S('9I9&4`4W5P<')E<W-I;VX@<NEC=7)S:79E(&1U
M(&1O<W-I97(@5D93(&EM<&]S<VEB;&4N`%-U<'!R97-S:6]N(&1U('+I<&5R
M=&]I<F4@5D93(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9&4@<W5P<')I;65R
M(&QE('+I<&5R=&]I<F4@5D93H#H@)7,N`%-U<'!R97-S:6]N(&EM<&]S<VEB
M;&4@9'4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!3=7!P<F5S<VEO;B!I;7!O<W-I
M8FQE(&1U(&9I8VAI97(@5D93+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U
M('+I<&5R=&]I<F4@5D93(*N@)7.@NRX`4W5P<')E<W-I;VX@5D93('+I8W5R
M<VEV92!I;7!O<W-I8FQEH#H@)7,N`$EM<&]S<VEB;&4@9&4@9.ET97)M:6YE
M<B!L92!D;W-S:65R(&-O=7)A;G0N`$EM<&]S<VEB;&4@9"=E>'1R86ER92!L
M97,@9.ET86EL<R!D=2!C97)T:69I8V%T`$EM<&]S<VEB;&4@9&4@8VAA<F=E
M<B!L82!DZ69I;FET:6]N(&1E("5S+@!);7!O<W-I8FQE(&1E(&3I<&QA8V5R
M(&QE(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&0G;W5V<FER(&QE(&9I8VAI
M97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D)V]U=G)I<B!U;B!F:6-H:65R
M(%9&4R!E;B#I8W)I='5R92X`26UP;W-S:6)L92!D)V]U=G)I<B!U;B!F:6-H
M:65R(%9&4RX`3W5V97)T=7)E(&EM<&]S<VEB;&4@9&4@;"=A<F-H:79E(&-O
M;7!R97-SZ64N`$EM<&]S<VEB;&4@9&4@;&ER92!L92!F:6-H:65R(%9&4R`H
MZ6-H96,@9&4@9FEL97-I>F4H*2DN`$EM<&]S<VEB;&4@9&4@;&ER92!L92!F
M:6-H:65R(%9&4R`HZ6-H96,@9&4@9V5T1FEL95-I>F4H*2DN`$EM<&]S<VEB
M;&4@9&4@;&ER92!L92!F:6-H:65RH#H@`$QE8W1U<F4@9'4@<NEP97)T;VER
M92!R86-I;F4@5D93(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9&4@<F5N;VUM
M97(@)7,@96X@)7.@.B!L92!D;W-S:65R(&-I8FQE(&5X:7-T92!DZ6K@`$EM
M<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@<NEP97)T;VER92!61E,N`$EM<&]S
M<VEB;&4@9&4@<F5N;VUM97(@;&4@<NEP97)T;VER92!61E.@.B`E<RX`26UP
M;W-S:6)L92!D92!R96YO;6UE<B!L92!F:6-H:65R(%9&4R"KH"5SH+LN`$EM
M<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@9FEC:&EE<B!61E,@)7,O)7,N`$EM
M<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@9FEC:&EE<B!61E,N`$EM<&]S<VEB
M;&4@9"=E>.EC=71E<B`G;6MI<V]F<R<N`$EM<&]S<VEB;&4@9&4@=')A9'5I
M<F4@8V4@9&]C=6UE;G0@5V]R9"X`26UP;W-S:6)L92!D)^EC<FER92!L92!F
M:6-H:65R(%9&4R"KH"5SH+LN`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&5S(&1O
M;F[I97,@9'4@9FEC:&EE<B!61E,@*&-O<'DH*2!I;7!O<W-I8FQE*2X`26UP
M;W-S:6)L92!D)^EC<FER92!L97,@9&]N;NEE<R!D=2!F:6-H:65R(%9&4RX`
M26UP;W-S:6)L92!D)^EC<FER92!L92!F:6-H:65R(%9&4RP@;&4@<75O=&$@
M<V5R86ET(&3I<&%S<^DN`%-O=6QI9VYE<@!$Z69A:7)E(&QE<R!M;V1I9FEC
M871I;VYS`$%N;G5L92!V;W1R92!D97)N:>AR92!A8W1I;VX`4NEP;VYS92!I
M;F%T=&5N9'5E(&1U('-E<G9E=7(@;&]R<R!D92!L82!C;VYN97AI;VZ@.B``
M4NEP;VYS92!I;F%T=&5N9'5E(&1U('-E<G9E=7(@X*`Z(`!(;W)S(&-A=.EG
M;W)I90!5;FEC;V1E("A55$8M."D`R6UI<F%T<R!!<F%B97,@56YI<P!2;WEA
M=6UE+55N:0#)=&%T<RU5;FES`,YL97,@97ATZ7)I975R97,@9&5S(,ET871S
M+55N:7,`56YI=.ES`$EN8V]N;G4`87!I;7-G:60@:6YC;VYN=2`H05!)($UE
M<W-A9V4@240I+@!C;&EM<V=I9"!I;F-O;FYU("A#;&EE;G0@365S<V%G92!)
M1"DN`$5M<&QA8V5M96YT('/I;&5C=&EO;F[I(&EN8V]N;G4N`$YO;2!D)W5T
M:6QI<V%T975R(&]U(&UO="!D92!P87-S92!I;F-O;FYU+@!$Z6QI97(@;"?I
M;.EM96YT(&-O=7)A;G0`4V%N<R!N;VT`3&5S('-C<FEP=',@;F]N+7!R:79I
M;.EG:>ES(&YE('!E=79E;G0@86-CZ61E<B!A=7@@9F]N8W1I;VYS(&-O=7!E
M<B]C;W!I97(O8V]L;&5R('!O=7(@9&5S(')A:7-O;G,@9&4@<^EC=7)I=.DN
M($%P<'5Y97H@<W5R($]+('!O=7(@=F]I<B!U;F4@;F]T92!T96-H;FEQ=64@
M<W5R(&UO>FEL;&$N;W)G('%U:2!V;W5S(&5X<&QI<75E<F$@8V]M;65N="!A
M=71O<FES97(@=6X@<V-R:7!T(.`@=71I;&ES97(@;&4@<')E<W-E+7!A<&EE
M<G,`4F5M971T<F4@;&$@8V]U;&5U<B#@('KI<F\`5'EP92!D92!C;VYT96YU
M(&YO;BUS=7!P;W)TZ:`Z("5S`$5X=&5N<VEO;B!N;VX@<')I<V4@96X@8V]M
M<'1E`$UO9&EF:65R`$UO9&EF:65R("5S`$UO9&EF:65R(&PG=71I;&ES871E
M=7(`36ES92#@(&IO=7(@9&4@JZ`E<Z"[+@!,92!S8W)I<'0@9&4@;6ES92#@
M(&IO=7(@97-T('-U<'!R:6WI`$-H87)G97(`5&]U<R!L97,@9FEC:&EE<G,@
M9&4@8V]N9FEG=7)A=&EO;B!D97,@87!P;&EC871I;VYS(&]N="#I=.D@96YV
M;WGI<R!S=7(@;&4@<V5R=F5U<BX`3&5T=')E<R!L871I;F5S(&UA:G5S8W5L
M97,`3F]M8G)E<R!R;VUA:6YS(&UA:G5S8W5L97,`57)U9W5A>0!%;7!L;WGI
M(&%C='5E;&QE;65N=*`Z("5S`%5T:6QI<V5R(%-33`!5=&EL:7-E<B!S:2!L
M92!N;VT@9"=U=&EL:7-A=&5U<B]M;W0@9&4@<&%S<V4@97-T(&1I9F;I<F5N
M="!D=2!S97)V975R($E-4U`N`%5T:6QI<V%T975R`$PG=71I;&ES871E=7(@
M)7,@;B=A('!A<R!L)V%U=&]R:7-A=&EO;B!P;W5R("5S+@!!9&UI;FES=')A
M=&EO;B!D97,@=71I;&ES871E=7)S`%!RZ6;I<F5N8V5S('!E<G-O;FYE;&QE
M<P!%;G)E9VES=')E;65N="!D97,@=71I;&ES871E=7)S`$PG96YR96=I<W1R
M96UE;G0@9"=U=&EL:7-A=&5U<B!E<W0@9.ES86-T:7;I('-U<B!C92!S>7-T
MZ&UE+@!#;VUP=&4@=71I;&ES871E=7(@;F]N('1R;W5VZ0!.;VT@9"=U=&EL
M:7-A=&5U<@!,92!N;VT@9&4@8V]N;F5X:6]N(*N@)7.@NR!E>&ES=&4@9.EJ
MX"X`3F]M(&0G=71I;&ES871E=7*@.@!.;VT@9"=U=&EL:7-A=&5U<J`Z(`!5
M=&EL:7-A=&5U<G,@9.EF:6YI<Z`Z`$]U>F+I:VES=&%N`%+I<&5R=&]I<F4@
M5D93(&EN97AI<W1A;G0N`$%B<V5N8V5S`$QE<R!E;7!L86-E;65N=',@=F%L
M:61E<R!T<F]U=NES(&EN8VQU96YTH#H@`%9A;&ED:73I`%9A;&5U<B!E;B!M
M:6YU=&5S(.`@<&%R=&ER(&1E(&UA:6YT96YA;G0N`%9A;&5U<B!S=7#I<FEE
M=7)E(.`@;&$@;&]N9W5E=7(@;6%X:6UA;&4@9&4@)7,N`%9A;&5U<G,`5F%L
M975R<R#@('/I;&5C=&EO;FYE<B!D90!686YU871U`%9A<FEA8FQE`%;I;NEZ
M=65L80#)8VAE8R!D92!L82!VZ7)I9FEC871I;VX@)FUD87-H.R!C92!M97-S
M86=E(&$@<&5U="WJ=')E(.ETZ2!F86QS:69IZ2X`4NEP97)T;VER92!697)I
M<VEG;@!697)S:6]N`$-O;G1R]&QE(&1E('9E<G-I;VX`06QI9VYE;65N="!V
M97)T:6-A;`!296UP;&ES<V%G92!V97)T:6-A;`!697)T:6-A;*`Z`%1RZ',@
M:&%U=&4`5FEE=&YA;0!6:>IT+6YA;6EE;B`H5DE30TE)*0!6;VER(*N@)7.@
MNP!6;VER("5S`$%F9FEC:&5R(&QE(&-O;G1A8W0`5F]I<B!U;F4@<&%G92!W
M96(@97AT97)N90!6;VER(&-O;6UE("5S`$%F9FEC:&%G92!P87(@9.EF875T
MH#H`SFQE<R!6:65R9V5S(&)R:71A;FYI<75E<P#.;&5S(%9I97)G97,@9&5S
M(,ET871S+55N:7,`5FES:6)I;&ETZ0!6:7-I8FEL:73IH#H@`%9O9&%F;VYE
M($ET86QY('9I82!33510`$Y/5$E#10!!5%1%3E1)3TXA(2$@(%-54%!224U%
M4B!,12!30U))4%0@34%.545,3$5-14Y4($1%("5S`%=)3B!V:6$@2%144`!7
M86QL:7,@970@1G5T=6YA`$%T=&5N=&EO;@!-90!0<NEV:7-I;VYS(&WI=.EO
M`$1O;F[I97,@;>ETZ6\@9F]U<FYI97,@<&%R`%=E871H97(N8V]M`%=E8@!3
M:71E('=E8@!54DP@9'4@<VET92!W96(`0VAA<75E('-E;6%I;F4`0FEE;G9E
M;G5E`$)I96YV96YU92#@("5S`$)I96YV96YU92P@)7,`3V-C:61E;G1A;"`H
M25-/+3@X-3DM,2D`3V-C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A:&%R82!/
M8V-I9&5N=&%L`%%U96QL92!A<'!L:6-A=&EO;B`E<R!D;VET+6EL('!RZ7-E
M;G1E<B!A<'+H<R!L82!C;VYN97AI;VZ@/P!1=65L(&5S="!L92!C87)A8W3H
M<F4@9&4@<^EP87)A=&EO;J`_`%%U96P@97-T(&QE(&-A<F%C=.AR92!D92!C
M:71A=&EO;J`_`$-A<G1E(%=H97)E:7,@075S=')A;&EE`%%U96QL97,@<&AA
M<V5S`%%U96QL97,@97AT96YS:6]N<R!A8W1I=F5R('!O=7(@;"?I9&ET975R
M(%)I8V@@5&5X="X`3&%R9V5U<@!,87)G975R(&5N('5N:73I<R!#4U,`3&%R
M9V5U<B!D=2!M96YU(&1E(&=A=6-H92`E<R`@*&QA(&-O;F9I9W5R871I;VX@
M<')E;F1R82!E9F9E="#@(&QA('!R;V-H86EN92!C;VYN97AI;VXIH#H`3&%R
M9V5U<B!D=2!T86)L96%U`%5N:73I(&1E(&QA<F=E=7(`3&%R9V5U<J`Z`%=I
M:VD`5F5N=`!696YT('3T="!L92!M871I;@!6:71E<W-E(&1U('9E;G0@96X@
M;B9O96QI9SMU9',`5F5N=*`Z`%9E;G2@.B``4V%G97-S90!,:7-T92!D92!V
M)F]E;&EG.W5X`%1R879A:6P`061R97-S92!B=7)E874`5FEL;&4@9'4@8G5R
M96%U`%!A>7,@9'4@8G5R96%U`%3I;"X@8G5R96%U`$-O9&4@<&]S=&%L(&1U
M(&)U<F5A=0#)=&%T+U!R;W9I;F-E(&1U(&)U<F5A=0!2=64@9'4@8G5R96%U
M`$YO;6)R92!D92!C:&%M<',@:6YC;W)R96-T(.`@;&$@;&EG;F4@)60N("5D
M(&%T=&5N9'5S+"`E9"!T<F]U=NES+@!.;VUB<F4@9&4@8VAA;7!S(&EN8V]R
M<F5C="X@)60@871T96YD=7,L("5D('1R;W5VZ7,N`$3I8V%L86=E("5D(&EN
M8V]R<F5C="!L;W)S(&1E(&QA(&QE8W1U<F4@9&4@9FEC:&EE<B!61E,N`%@M
M4F5F`$-O;G1R86EN=&5S(&)A<VEQ=65S(%@U,#EV,P!5=&EL:7-A=&EO;B!D
M92!C;.D@Z71E;F1U92!8-3`Y=C,`075T<F4@;F]M(&1U('-U:F5T(%@U,#EV
M,P!)9&5N=&EF:6%N="!D92!C;.D@9'4@<W5J970@6#4P.78S`$5X=&5N<VEO
M;G,@6#4P.78S`$%!`$%!04$`0V%R=&4@JZ!986AO;Z`AH+L`06YN=65L;&5M
M96YT`%GI;65N`$]U:0!/=6DL(&HG86-C97!T90!6;W5S(.IT97,@96X@;6]D
M92"KH%1E>'1EH+LN(%5T:6QI<V5Z(&QE(&)O=71O;B!;/#Y=('!O=7(@<F5V
M96YI<B!A=2!M;V1E(*N@5UE325=91Z"[+@!6;W5S(&XGZG1E<R!P87,@875T
M;W)I<^D@X"!C<NEE<B!P;'5S(&1E("5D(&)L;V-S+@!6;W5S(&XGZG1E<R!P
M87,@875T;W)I<^D@X"!C<NEE<B!P;'5S(&1E("5D(&-O;G1A8W1S(&1A;G,@
MJZ`E<Z"[+@!6;W5S(&XGZG1E<R!P87,@875T:&5N=&EF:>DN`%9O=7,@;F4@
M<&]U=F5Z('!A<R!A=F]I<B!L92!C87)A8W3H<F4@JUR[(&1A;G,@=F]T<F4@
M;F]M(&-O;7!L970N`%9O=7,@;B=A=F5Z('!A<R!S86ES:2!U;F4@861R97-S
M92#I;&5C=')O;FEQ=64@=F%L:61E+@!6;W5S(&XG879E>B!P87,@87-S;V-I
MZ2!L97,@8VAA;7!S(&1U(&9I8VAI97(@:6UP;W)TZ2!A=7@@8VAA;7!S(&-O
M<G)E<W!O;F1A;G1S(&1A;G,@)7,N`%9O=7,@;B?J=&5S('!A<R!A=71O<FES
MZ2#@(&-O;G-U;'1E<B!C92!C;VYT86-T+@!6;W5S(&XGZG1E<R!P87,@875T
M;W)I<^D@X"!C;VYS=6QT97(@8V5T(&]B:F5T+@!6;W5S(&XG879E>B!P87,@
M;"=A=71O<FES871I;VX@9&4@<W5P<')I;65R(&-E='1E('-O=7)C92X`5F]U
M<R!A=F5Z(.ETZ2!DZ6-O;FYE8W3I+@!6;W5S(&1E=F5Z(&EN<V-R:7)E('5N
M(&YU;>ER;R!D92!C96QL=6QA:7)E('9A;&ED92P@<V5U;',@9&5S(&YO;6)R
M97,@970@=6X@JRN[(&]P=&EO;FYE;"!P;W5R(&QE<R!A<'!E;',@:6YT97)N
M871I;VYA=7@N`%9O=7,@;B=A=F5Z('!A<R!S86ES:2!U;F4@96YT<NEE('9A
M;&ED92X`5F]U<R!D979E>B!C;VYF:6=U<F5R('5N(&)A8VME;F0@1&%T851R
M964@<&]U<B!U=&EL:7-E<B!L97,@:6YS8W)I<'1I;VYS`%9O=7,@9&5V97H@
M8V]N9FEG=7)E<B!U;B!M;V1U;&4@5D93+@!6;W5S(&1E=F5Z(&3I8W)I<F4@
M;&4@<')O8FSH;64@879A;G0@9&4@;F]U<R!F86ER92!P87)V96YI<B!L92!R
M87!P;W)T+@!6;W5S(&1E=F5Z(&5N=')E<B!U;F4@55),(&_Y('!O:6YT92!D
M92!L:65N+@!);"!F875T(&0G86)O<F0@<^EL96-T:6]N;F5R('5N(&-A<FYE
M="!D)V%D<F5S<V4@8VEB;&4N`%9O=7,@9&5V97H@9"=A8F]R9"!SZ6QE8W1I
M;VYN97(@=6YE(&QI<W1E(&-I8FQE+@!);"!F875T('/I;&5C=&EO;FYE<B!U
M;B!S97)V975R(.`@<W5P<')I;65R+@!6;W5S(&1E=F5Z(&0G86)O<F0@<^EL
M96-T:6]N;F5R(&%U(&UO:6YS('5N(&-O;G1A8W0N`%9O=7,@9&5V97H@9"=A
M8F]R9"!SZ6QE8W1I;VYN97(@874@;6]I;G,@=6YE(&5N='+I92X`5F]U<R!D
M979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+B``5F]U
M<R!D979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+@!6
M;W5S(&1E=F5Z('-PZ6-I9FEE<B!U;B!U=&EL:7-A=&5U<B#@(&%J;W5T97(N
M`%9O=7,@9&5V97H@<W#I8VEF:65R(&QE(&YO;2!D92!L)W5T:6QI<V%T975R
M(.`@;6]D:69I97(N`%9O=7,@9&5V97H@:6YD:7%U97(@<75E;&QE(&%C=&EO
M;B!A8V-O;7!L:7(N`%9O=7,@9&5V97H@Z6-R:7)E('5N(&YO;2!P;W5R(&QA
M(&YO=79E;&QE(&-A=.EG;W)I92X`5F]U<R!D979E>B!F;W5R;FER('5N(&ZP
M(&1E('3I;.EP:&]N92!I=&%L:65N`%9O=7,@ZG1E<R!S975L96UE;G0@875T
M;W)I<^D@X"!C;VYS=6QT97(@8V4@8V]N=&%C="X`5F]T<F4@<V5S<VEO;B`E
M<R!A(&5X<&ERZ2X@5F5U:6QL97H@=F]U<R!R96-O;FYE8W1E<BX`5F]T<F4@
M861R97-S92!D92!C;W5R<FEE;`!6;W1R92!A9')E<W-E(&1E(&-O=7)R:65L
M(*L@1&4Z(+N@.@!6;W,@9&]N;NEE<R!P97)S;VYN96QL97,`5F]T<F4@861R
M97-S92!);G1E<FYE="!A(&-H86YGZ2!D97!U:7,@;"=O=79E<G1U<F4@9&4@
M=F]T<F4@<V5S<VEO;B`E<RX@(%!O=7(@=F]T<F4@<^EC=7)I=.DL('9O=7,@
M9&5V97H@=F]U<R!R96-O;FYE8W1E<BX`5F]T<F4@;F]M`%9O=')E(&UO9'5L
M92!D)V%U=&AE;G1I9FEC871I;VX@;F4@<W5P<&]R=&4@<&%S(&PG86IO=70@
M9"=U=&EL:7-A=&5U<G,L(%-I('9O=7,@<V]U:&%I=&5Z('5T:6QI<V5Z($AO
M<F1E('!O=7(@861M:6YI<W1R97(@;&5S(&-O;7!T97,@=71I;&ES871E=7)S
M+"!V;W5S(&1E=F5Z('5T:6QI<V5R('5N(&%U=')E(&UO9'5L92!D)V%U=&AE
M;G1I9FEC871I;VXN`%9O=')E(&UO9'5L92!D)V%U=&AE;G1I9FEC871I;VX@
M;B=E<W0@<&%S(&5N(&UE<W5R92!D)^ET86)L:7(@=6YE(&QI<W1E(&1E<R!U
M=&EL:7-A=&5U<G,L(&]U(&-E='1E(&9O;F-T:6]N(&$@Z73I(')E=&ERZ64@
M<&]U<B!U;F4@875T<F4@<F%I<V]N+@!6;W1R92!N879I9V%T975R('-E;6)L
M92!A=F]I<B!C:&%N9^D@9&5P=6ES(&QE(&3I8G5T(&1E('9O=')E('-E<W-I
M;VX@)7,N("!0;W5R('9O=')E('/I8W5R:73I+"!V;W5S(&1E=F5Z('9O=7,@
M<F5C;VYN96-T97(N`%9O=')E(&YA=FEG871E=7(@;F4@<W5P<&]R=&4@<&%S
M(&-E='1E(&]P=&EO;@!6;W1R92!N879I9V%T975R(&YE('!R96YD('!A<R!E
M;B!C;VUP=&4@8V5T=&4@;W!T:6]N(&0G:6UP<F5S<VEO;BX@4')E<W-E>B!#
M;VYT<O1L92]#;VUM86YD92`K(%`@<&]U<B!I;7!R:6UE<@!6;W1R92!F=7-E
M874@:&]R86ER92!A8W1U96R@.@!);7!O<W-I8FQE(&1E('!A<F-O=7)I<B!V
M;W1R92!C87)N970@9"=A9')E<W-E<R!P87(@9.EF875T+@!6;W1R92!P<F]F
M:6P@<&%R(&3I9F%U="!A(.ETZ2!M;V1I9FGI+@!0<F]F:6P@<&%R(&3I9F%U
M=*`Z`%9O=')E(&YO;2!C;VUP;&5TH#H`5F]T<F4@8V]M<'1E(&$@97AP:7+I
M+@!6;W1R92!N;W5V96%U(&UO="!D92!P87-S92!P;W5R("5S(&5S=*`Z)7,`
M5F]S(&]P=&EO;G,@;VYT(.ETZ2!M:7-E<R#@(&IO=7(@<&]U<B!L82!D=7+I
M92!D92!C971T92!S97-S:6]N+@!6;W,@;W!T:6]N<R!O;G0@Z73I(&UI<V5S
M(.`@:F]U<BX`5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E;6ES(.`@>NER
M;P!6;W1R92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@X"!ZZ7)O+"!VZ7)I
M9FEE<B!V;W1R92!C;W5R<FEE<B!E="!C;VYN96-T97HM=F]U<R!A=F5Z('9O
M=')E(&YO=79E874@;6]T(&1E('!A<W-E+@!6;W1R92!M;W0@9&4@<&%S<V4@
M82!E>'!I<NDN`%9O<R!S97)V975R<R!D:7-T86YT<Z`Z`%EO=6=O<VQA=FEE
M`%IA[W)E`%IA;6)I90!::6UB86)W90!::7!P>0!;0V%C:&5R(&QE<R!C:71A
M=&EO;G-=`%M287!P;W)T(&1E('!R;V)LZ&UE70!;069F:6-H97(@;&4@=&5X
M=&4@8VETZ2`M`%M!9F9I8VAE<B!L92!T97AT92!C:73I("T@)7,@;&EG;F5S
M70!;;&EG;F4@)7,@9&4@)7-=`%M087,@9&4@=F%L975R70!?061M:6YI<W1R
M871I;VX`7TQI<W1E<@!,:6=N92!D92!?8V]M;6%N9&4`7T-O;G1A8W1S`%]$
M871A5')E90!37W5P<')I;65R`%-U<'!R:6UE<B!L82!?<F%N9^EE`%]'<F]U
M<&5S`%]!:61E`%!R;W!R7VGI=.ES(&1E(&PG:6UA9V4N+BX`7TEM<&]R=&5R
M+T5X<&]R=&5R`%],:7-T97,`7T-O;FYE>&EO;@!?1.EC;VYN97AI;VX`7TUO
M9&EF:65R('5N(&QI96X@=V5B+BXN`%]-97,@86YN=6%I<F5S`%].;W5V96%U
M(&-O;G1A8W0`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]2971I<F5R('5N(&QI
M96X`7U)E=&ER97(@9&4@;&$@;&ES=&4`7U)E8VAE<F-H90!?0V]N9FEG=7)A
M=&EO;@!0<F]P<FGI=.ES(&1U(%]T86)L96%U`%]5=&EL:7-A=&5U<G,`8V%R
M;F5T(&0G861R97-S97,`9&5S=&EN871A:7)E(&EN8V]N;G4`86=E;F1A`&-A
M;&UE`&EM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!D92!S;W)T:64`
M:6UP;W-S:6)L92!D)V]U=G)I<B!L)V5N='+I90!C;&EQ=65Z(&EC:0!E<G)E
M=7(@9"=U=&EL:7-A=&EO;B!D92!L82!L:6=N92!D92!C;VUM86YD90!E<G)E
M=7(@9&4@8V]N9FEG=7)A=&EO;@!C;VYT86-T+G9C9@!C;VYT86-T<RYC<W8`
M8V]N=&%C=',N='-V`&-O;G1A8W1S+G9C9@!A8G-E;F-E(&-R:71I<75E(&0G
M=6X@9FEC:&EE<B!S>7-TZ&UE`&5R<F5U<B!D92!F;W)M870@9&4@9&]N;NEE
M`&5N='+I92!N;VX@=')O=7;I`'1O;6)A;G0`9FEC:&EE<@!D97!U:7,@;&4@
M)7,@*"5S*2#@("5S("5S`&5N(')A9F%L90!HH#H`:&@`;F]M(&0G:/1T92!I
M;F-O;FYU`&EM;>ED:6%T96UE;G0`:6YC;W)P;W+I90!E<G)E=7(@9"=E;G1R
MZ64O<V]R=&EE`&5R<F5U<B!L;V=I8VEE;&QE(&EN=&5R;F4`;&EG;F5S70!E
M<G)E=7(@;6MI<V]F<R!C;V1E("5D(&5N(&-RZ6%N="!L)TE33P!M;0!N;VT`
M075C=6X@9F]R;6%T86=E`&%U8W5N`&YO;B!P<FES(&5N(&-O;7!T90!P87,@
M96YC;W)E('!R:7,@96X@8V]M<'1E`&)L;V,M;F]T97,`<&]U<F-E;G1A9V4`
M<&5R;6ES<VEO;B!R969U<^EE`'!I>&5L<P!E<G)E=7(@9&ES=&%N=&4@9&%N
M<R!L92!P<F]T;V-O;&4`<R?I;&5V86YT`'-E<G9I8V4@;F]N(&1I<W!O;FEB
M;&4N`&UO;G1R97(@;&5S(&1I9F;I<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%14
M4`!S<P!F:7AE`&5R<F5U<B!S>7-TZ&UE`&QI<W1E(&1E('3B8VAE<P#I8VAE
M8R!T96UP;W)A:7)E`'9E<G,@=6YE(&QI<W1E(&1E(&-O;G1A8W1S`'9E<G,@
M=6X@875T<F4@8V%R;F5T(&0G861R97-S97,`96YT<F5Z(&QE(&UO="!D92!P
M87-S92!D975X(&9O:7,@<&]U<B!C;VYF:7)M97(`=6YI9FGI`'-A;G,@;F]M
M`%/I;&5C=&EO;B!D)W5T:6QI<V%T975R`'9#87)D`&R@.@!W96%T:&5R+F-O
M;0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T=7)B82]L;V-A;&4O9VQ?15,O````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`Q-S<W,P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]G;%]%4R],0U]-15-3
M04=%4R\`````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-34`,#(Q-38P`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C
M86QE+V=L7T53+TQ#7TU%4U-!1T53+W1U<F)A+FUO````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q-C<U,0`Q,#0Q-S,V,C<U-0`P,C,R-#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````WA($E0````!\````'````/P#
M``"G````W`<```````!X"@``)````'D*```E````G@H``"@```#$"@``'0``
M`.T*```(````"PL```4````4"P```P```!H+```(````'@L```<````G"P``
M#P```"\+```%````/PL``!\```!%"P``$0```&4+```&````=PL```@```!^
M"P``%0```(<+```*````G0L```P```"H"P``#@```+4+```'````Q`L``"D`
M``#,"P```@```/8+```%````^0L``!````#_"P``!@```!`,```/````%PP`
M`!0````G#```+P```#P,```)````;`P```\```!V#```)@```(8,```$````
MK0P```4```"R#```#0```+@,```%````Q@P``!````#,#```$````-T,```/
M````[@P```L```#^#```#P````H-```,````&@T```\````G#0``!@```#<-
M```3````/@T``!X```!2#0``(0```'$-```B````DPT```,```"V#0``!```
M`+H-```$````OPT```0```#$#0``#````,D-```*````U@T```4```#A#0``
M$@```.<-```0````^@T```@````+#@``!````!0.```0````&0X```8````J
M#@``!P```#$.```"````.0X```0````\#@``"````$$.```/````2@X```<`
M``!:#@``!P```&(.```$````:@X```L```!O#@``!0```'L.```%````@0X`
M``<```"'#@``$0```(\.```(````H0X``!X```"J#@``!0```,D.```H````
MSPX``"D```#X#@``$P```"(/```+````-@\``!$```!"#P``!````%0/```$
M````60\```P```!>#P``!@```&L/```:````<@\``!<```"-#P``&@```*4/
M```H````P`\``!<```#I#P``&P````$0```T````'1```"4```!2$```'P``
M`'@0```3````F!```!````"L$```%P```+T0```'````U1````4```#=$```
M(0```.,0```<````!1$```4````B$0```P```"@1```@````+!$``"0```!-
M$0``)@```'(1```,````F1$```@```"F$0``&P```*\1```'````RQ$```8`
M``#3$0``#0```-H1```+````Z!$```P```#T$0``"@````$2```"````#!(`
M``8````/$@``10```!82```P````7!(``!````"-$@``'P```)X2```0````
MOA(```\```#/$@``4`$``-\2```@````,!0``"$```!1%```*@```',4```E
M````GA0```@```#$%```!0```,T4```'````TQ0```X```#;%```"````.H4
M```.````\Q0```8````"%0``)`````D5```3````+A4```@```!"%0``"@``
M`$L5```?````5A4```X```!V%0``#P```(45```2````E14```@```"H%0``
M,@```+$5```"````Y!4```L```#G%0``&0```/,5```&````#18```\````4
M%@``%@```"06```O````.Q8```H```!K%@``&````'86```K````CQ8```8`
M``"[%@``$@```,(6```.````U18```0```#D%@``#P```.D6```0````^18`
M``X````*%P``%0```!D7```/````+Q<```L````_%P``$P```$L7```(````
M7Q<``!X```!H%P``(P```(<7```C````JQ<``"$```#/%P```P```/$7```&
M````]1<```(```#\%P``!0```/\7```0````!1@``!`````6&```!0```"<8
M```3````+1@``!(```!!&```!@```%08```&````6Q@``!@```!B&```!@``
M`'L8```/````@A@```(```"2&```!@```)48```0````G!@``!8```"M&```
M!P```,08```,````S!@```0```#9&```#P```-X8```%````[A@```4```#T
M&```!P```/H8```1`````AD```\````4&0``(0```"09```(````1AD``!X`
M``!/&0``+P```&X9```6````GAD```L```"U&0``$P```,$9```'````U1D`
M``8```#=&0``$0```.09```&````]AD``"$```#]&0``'0```!\:```E````
M/1H``#$```!C&@``'0```)4:```E````LQH``#<```#9&@``*P```!$;```4
M````/1L``!T```!2&P``$P```'`;```?````A!L```T```"D&P``!P```+(;
M```B````NAL``!L```#=&P``!@```/D;```#`````!P``"H````$'```*```
M`"\<```O````6!P``!(```"('```!P```)L<```;````HQP```4```"_'```
M#````,4<```,````TAP```T```#?'```%````.T<```4`````AT```(````7
M'0``"@```!H=```N````)1T``#P```!4'0``$0```)$=```?````HQT``!4`
M``##'0``#P```-D=```!````<````'<````Z````6P````````!T````+0``
M```````Q````<@```&,```!6````&@```"\```!<````"0```&H`````````
M:P```%@`````````0P```````````````````````````````@```&T```!@
M````.````#0```!H````4P``````````````4````!\````.`````````"8`
M````````/@```&<`````````50```&D`````````"@````````!(````(0``
M`!T`````````3````!$```!4````(````"<```````````````````!Q````
M*``````````E````%0````8`````````<P```'8````;````0@````````!&
M````%@```!@```!X````-P```&P````$````'````$D````L````````````
M``!\````.0```&8```!Y````%````'L```!D````1P```%D```!/````/0``
M`!,````'````30```$L```!:````$````'H````C````00``````````````
M2@```&$```!O````7P```````````````````"D````2````40````,````[
M````/````"(`````````7@````````!U`````````#\````%````-0```!D`
M`````````````#````!%``````````@`````````8@```#8````J````````
M`#(`````````3@````P````K`````````"0```!=````"P```!X```!E````
M%P```#,```!N``````````````!$````4@````\`````````0````"X````-
M````5P`````B1FER<W1N86UE($QA<W1N86UE(B`@*&EE+B!*;VAN($1O92D`
M(DQA<W1N86UE+"!&:7)S=&YA;64B("AI92X@1&]E+"!*;VAN*0`E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(&9I;&4@<W5C
M8V5S<V9U;&QY(&EM<&]R=&5D`#(T(&AO=7)S`$%-+U!-`$%D9`!!9&0@<&%I
M<@!!9&1R97-S`$%D=F%N8V5D(%-E87)C:`!!;&EA<P!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%V86EL86)L92!F:65L9',Z`$)R;W=S90!#
M86QE;F1A<@!#86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&]S
M92!7:6YD;W<`0V]L=6UN($]P=&EO;G,`0V]M<&%N>0!#;W5L9"!N;W0@;W!E
M;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!$1`!$86EL>0!$969A=6QT
M($ED96YT:71Y`$1E;&5T90!$96QE=&EO;B!F86EL960`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%9&ET`$5M86EL`$5M
M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>'!O<G0`17AP
M;W)T($%D9')E<W,@0F]O:P!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,`1F%X`$9I;F0`1G)O;0!(96QP
M`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD
M.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI<W0`3&ES="!(96QP
M(%1O<&EC<P!,;V<@:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG`$UA=&-H
M:6YG(&9I96QD<P!-97-S86=E`$UO;G1H;'D`3F%M90!.86UE($9O<FUA=`!.
M979E<@!.;W1E<P!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D
M`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4F5M;W9E('!A:7(`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E
M`%-A=F4@3W!T:6]N<P!396%R8V@`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O
M(&EM<&]R=#H`4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA
M;65S.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RX`4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P;&%Y(&EN
M('1H92!A9&1R97-S(&QI<W1S+@!396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I
M<W!L87D@;F%M97,N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`
M4V5N9"!0<F]B;&5M(%)E<&]R=`!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@
M0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`5&%S:W,`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E
M<BX`5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5<V5R($]P=&EO;G,`
M57-E<FYA;64`5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0Z`%=A<FYI;F<`
M5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`65D`665A<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`%!R
M;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@,2XQ"E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP
M."TQ.2`Q,CHQ,T=-5"LQ"DQA<W0M5')A;G-L871O<CH@9W5I;&QE(#QG=6EL
M;&5`=7-C+F5S/@I,86YG=6%G92U496%M.B!'86QE9V\*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX
M.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E;F5R
M871O<CH@2T)A8F5L(#`N.2XU"@!.;VUE+"!!<&5L:61O<R`H<"YE+B!8;V%N
M($?S;65Z*0!!<&5L:61O<RP@3F]M92`H<"YE+B!'\VUE>BP@6&]A;BD`3W!E
M<F%C:?-N<R!D92!M86YT96UE;G1O("5S("T@0V]N9FER;6%C:?-N`$\@87)Q
M=6EV;R`E<R!I;7!O<G1O=7-E(&-O<G)E8W1A;65N=&4`,C0@:&]R87,`04TO
M4$T`16YG861I<@!%;F=A9&ER('5N('!A<@!%;F1E<F5Z;P!"=7-C82!A=F%N
M>F%D80!!;&-U;64`3R!V86QO<B!Q=64@97-P96-I9FEC;W4@;F]N(.D@=N%L
M:61O`$-A;7!O<R!D:7-P;_%I8FQE<SH`17AA;6EN87(`0V%L96YD87)I;P!#
M86YC96QA<B!O(&EN9F]R;64@9&4@<')O8FQE;6%S`%1E;.EF;VYO(&WS8FEL
M`%!E8VAA<B!A('AA;F5L80!/<&-I\VYS(&1A(&-O;'5M;F$`0V]M<&'Q[6$`
M1F%L;&\@\R!A8G)I<B!O(&WS9'5L;R!D92!T87)E9F%S(&1E(&UA;G1E;65N
M=&\@)7,`1$0`1&EA<FEA;65N=&4`261E;G1I9&%D92!P<F5D971E<FUI;F%D
M80!";W)R87(`1F%L;&]U(/,@8F]R<F%R`$1E<V-R:6-I\VX@9&\@<')O8FQE
M;6$`4F5X:7-T<N%R;VYS92!O<R!D971A;&QE<R!P87)A(&\@861M:6YI<W1R
M861O<BX`1&ER96-T;W)I;P!/<&-I\VYS(&1E('9I<W5A;&EZ86-I\VX`3F]N
M(&%C8V5D82!D:7)E8W1A;65N=&4@82`B;6%I;G1E;F%N8V4N<&AP(@!%9&ET
M87(`0V]R<F5O($5L96-T<O-N:6-O`%-E;B!R97-U;'1A9&\N`$5R<F\`0V%D
M82`Q-2!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI;G5T;W,`
M0V%D82!I;FEC:6\@9&4@<V5S:?-N`$-A9&$@;65D:6$@:&]R80!#861A(&UI
M;G5T;P!%>&5M<&QO(&1E('9A;&]R97,Z`$5X<&]R=&%R`$5X<&]R=&%R(&$@
M87AE;F1A(&1E(&5N9&5R97IO<P!&86QL;W4@\R!R96-U<&5R87(@87,@<')E
M9F5R96YC:6%S+@!&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0
M+@!&86QL;W4@;R!B=7-C87(@;F\@9&ER96-T;W)I;SH@)7,`1F%X`$%T;W!A
M<@!$90!!>'5D80!%;F1E<F5Z;R!P97)S;V%L`%1E;.EF;VYO('!E<G-O86P`
M2&]R9&4`0V%M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@:6UP;W)T861O<SH`
M3&EN9W5A`$QI<W1A<@!,:7-T87(@;W,@=&5M87,@9&4@87AU9&$`16YT<F%R
M`%!E8VAA<B!A('-E<VGS;@!-30!#;W)R96\`<75E(&-O:6YC:61A(&-O;@!#
M86UP;W,@8V]R<F5S<&]N9&5N=&5S`$UE;G-A>&4`365N<W5A;&UE;G1E`$YO
M;64`1F]R;6%T;R!D;R!N;VUE`$YU;F-A`$YO=&%S`$]P8VGS;G,`3W5T<F$@
M:6YF;W)M86-I\VX`0VAA=F4@9&4@86-C97-O`%)E86QI>F%R(&]P97)A8VGS
M;G,@9&4@;6%N=&5M96YT;P!496SI9F]N;P!!8VAE9W5E('5N(')E<W5M;R!D
M;R!P<F]B;&5M82X`06-H96=U92!O('-E=2!N;VUE(&1E('5S=6%R:6\@92!C
M:&%V92!D92!A8V-E<V\`1&5S8W)I8VGS;B!D;R!P<F]B;&5M80!386-A<B!O
M('!A<@!296=R97-A<B#A<R!O<&-I\VYS`$9U;F-I\VX`1V%R9&%R`$=A<F1A
M<B!A<R!O<&-I\VYS`$)U<V-A<@!396QE8V-I;VYE(&\@9&5L:6UI=&%D;W(@
M9&$@9&%T83H`4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@9&%T83H`17-C;VQL
M82!O(&%R<75I=F\@<75E('%U97)E(&EM<&]R=&%R.@!396QE8V-I;VYA<B!O
M(&9O<FUA=&\@=7-A9&\@<&%R82!A;6]S87(@;W,@;F]M97,Z`%-E;&5C8VEO
M;F4@;R!F;W)M871O(&1A(&AO<F$Z`%-E;&5C8VEO;F4@9&]U<R!C86UP;W,@
M<75E(&-O:6YC:61A;BX`17-C;VQL82!O<R!C86UP;W,@<75E('-E('9E<N%N
M(&YA<R!L:7-T87,@9&4@96YD97)E>F]S+@!396QE8V-I;VYA<B!O(&9O<FUA
M=&\@<&%R82!A;6]S87(@;W,@;F]M97,N`%-E;&5C8VEO;F4@82!L:6YG=6$Z
M`$5N=FEA<B!O(&EN9F]R;64@9&4@<')O8FQE;6%S`$]M:71I<B!O(&UA;G1E
M;65N=&\`16YT<F%D82!D92!C87)A8W1E<F5S(&5S<&5C:6%I<P!#;W)R96-T
M86UE;G1E`%1A<F5F87,`3R!N^FUE<F\@9&5B92!S97(@<&]L;R!M96YO<R!U
M;B`Q+@!/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R;RX`5.UT=6QO`%523`!.
M;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"X`3F]N
M(.D@<&]S:6)L92!C87)G87(@82!D969I;FEC:?-N(&1E("5S+@!.;VX@9F]I
M('!O<VEB;&4@=')A9'5C:7(@97-T92!D;V-U;65N=&\@9&4@5V]R9`!/<&-I
M\VYS(&1O('5S=6%R:6\`57-U87)I;P!6:7-T82!A(&%M;W-A<B!P;W(@9&5F
M96-T;SH`079I<V\`4V5M86YA;&UE;G1E`$)E;G9I9&$@82`E<P!"96YV:61O
M+V$L("5S`$5N9&5R97IO(&1O('1R86)A;&QO`%1E;.EF;VYO(&1O('1R86)A
M;&QO`$%!`$%N=6%L;65N=&4`1&5S8W)I8F$@;R!P<F]B;&5M82!A;G1E<R!D
M92!E;G9I87(@;R!I;F9O<FUE+@!#861U8V]U(&$@<_IA('-E<VGS;B!E;B`E
M<R!E>'!I<F]U+B!);FEC:64@=6YH82!N;W9A('-E<VGS;BX`02!S^F$@:6YF
M;W)M86-I\VX`06-T=6%L:7KA<F]N<V4@87,@<_IA<R!O<&-I\VYS+@!;26YF
M;W)M92!D;R!0<F]B;&5M85T`6VQI\6$@)7,@9&4@)7-=````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L
M;V-A;&4O:'5?2%4O````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`R,#`Q,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]H=5](52],0U]-15-304=%4R\`````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-34`,#(Q
M-3<W`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+VAU7TA5
M+TQ#7TU%4U-!1T53+W1U<F)A+FUO````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0W-3,P
M-0`Q,#0Q-S,V,C<U-0`P,C,R-C0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````WA($E0````!T"```'````+Q#``!'"P``7(<`
M``````!XM```#@```'FT```/````B+0```T```"8M```"````*:T```+````
MK[0```P```"[M```&0```,BT```9````XK0```0```#\M```*0````&U```8
M````*[4``!L```!$M0``+0```&"U```=````CK4``"0```"LM0``*0```-&U
M```I````^[4``!D````EM@``*````#^V```D````:+8``"4```"-M@``)@``
M`+.V```,````VK8``"0```#GM@``#P````RW```+````'+<```X````HMP``
M*````#>W```(````8+<```H```!IMP``%0```'2W```)````BK<``!(```"4
MMP``"P```*>W```=````L[<``(4```#1MP``#@```%>X```*````9K@```T`
M``!QN```#@```'^X```1````CK@```T```"@N```#````*ZX```-````N[@`
M`)0```#)N```"@```%ZY```/````:;D``!@```!YN0``#````)*Y```.````
MG[D```X```"NN0``"````+VY```)````QKD``"L```#0N0``+@```/RY```:
M````*[H``#(```!&N@``.````'FZ``!4````LKH``%$````'NP``6@```%F[
M``!7````M+L``#0````,O```"0```$&\```-````2[P```<```!9O```"@``
M`&&\```/````;+P```4```!\O```!@```(*\```1````B;P```@```";O```
M$0```*2\```)````MKP```D```#`O```)0```,J\```@````\+P``!,````1
MO0``$P```"6]```0````.;T```\```!*O0``"@```%J]```#````9;T```\`
M``!IO0``%````'F]```)````CKT```T```"8O0``$@```*:]```9````N;T`
M`!X```#3O0``#P```/*]```0`````KX``"$````3O@``"@```#6^```(````
M0+X```\```!)O@``"````%F^```D````8KX```8```"'O@``%````(Z^```6
M````H[X```@```"ZO@``3@```,.^```M````$K\``"$```!`OP``&0```&*_
M```'````?+\```P```"$OP``%````)&_```-````IK\``!(```"TOP``(0``
M`,>_```7````Z;\``"D````!P```+````"O````.````6,````,```!GP```
M#P```&O````+````>\````<```"'P```!P```(_````%````E\````4```"=
MP```"@```*/````#````KL```!<```"RP```"@```,K````/````U<````X`
M``#EP```&````/3````C````#<$```X````QP0``#@```$#!```4````3\$`
M`!<```!DP0``%P```'S!```7````E,$``!,```"LP0``#P```,#!```.````
MT,$``!\```#?P0``'0```/_!```'````'<(```8````EP@``"````"S"```/
M````-<(```8```!%P@``"@```$S"```3````5\(```L```!KP@``$````'?"
M```5````B,(``!4```">P@``!P```+3"```0````O,(```4```#-P@``%0``
M`-/"```1````Z<(```P```#[P@``*`````C#```Z````,<,``#L```!LPP``
M.````*C#```)````X<,```<```#KPP``%````//#```#````",0```4````,
MQ```"0```!+$```0````',0```D````MQ```$P```#?$```Y````2\0``!(`
M``"%Q```)P```)C$```L````P,0``"H```#MQ```)0```!C%```*````/L4`
M``8```!)Q0``"0```%#%```'````6L4``"\```!BQ0``-P```)+%```N````
MRL4``%4```#YQ0``+0```$_&```M````?<8``#T```"KQ@``/P```.G&```M
M````*<<``$````!7QP``(P```)C'```C````O,<``$````#@QP``+0```"'(
M```S````3\@``"4```"#R```%0```*G(```9````O\@``"D```#9R```)```
M``/)```H````*,D``!$```!1R0``"@```&/)```,````;LD```H```![R0``
M$````(;)```6````E\D``!8```"NR0``!P```,7)```'````S<D``!0```#5
MR0``"@```.K)```(````]<D``"<```#^R0``"````";*```,````+\H```<`
M```\R@``!P```$3*```&````3,H``!$```!3R@``!0```&7*```'````:\H`
M``8```!SR@``%````'K*```(````C\H``"D```"8R@``#@```,+*```*````
MT<H```0```#<R@``!P```.'*```)````Z<H```8```#SR@``$0```/K*```'
M````#,L``!8````4RP``!````"O+```(````,,L```8````YRP``#0```$#+
M```&````3LL``!X```!5RP``!@```'3+```1````>\L```@```"-RP``#0``
M`);+```,````I,L```<```"QRP``$0```+G+```#````R\L```,```#/RP``
M%P```-/+```#````Z\L``!,```#ORP``'0````/,```(````(<P```0````J
MS```"````"_,```(````.,P``$$```!!S```&@```(/,```<````GLP``"L`
M``"[S```(````.?,```5````",T```8````>S0``!@```"7-```5````+,T`
M`!@```!"S0``(@```%O-```N````?LT``!T```"MS0``(0```,O-``!4````
M[<T``"D```!"S@``"@```&S.```'````=\X```<```!_S@``%0```(?.```.
M````G<X```H```"LS@``#P```+?.```-````Q\X```\```#5S@``#0```.7.
M```)````\\X``!0```#]S@``!@```!+/```8````&<\``!T````RSP``$P``
M`%#/```1````9,\``!0```!VSP``!````(O/```&````D,\``!0```"7SP``
M5````*S/``!D`````=````0```!FT```#@```&O0```/````>M````4```"*
MT```!0```)#0```;````EM```!H```"RT```$P```,W0```-````X=```!$`
M``#OT```$0````'1```6````$]$``!<````JT0``'````$+1```J````7]$`
M`#D```"*T0``(@```,31```R````Y]$``!`````:T@``(0```"O2```%````
M3=(``!,```!3T@``"P```&?2```2````<](```H```"&T@``#P```)'2```-
M````H=(``!$```"OT@``$P```,'2```,````U=(```8```#BT@``#````.G2
M```&````]M(``!<```#]T@``$````!73```1````)M,```@````XTP``!0``
M`$'3```,````1],``!````!4TP``!0```&73```.````:],```T```!ZTP``
M(P```(C3```&````K-,``!8```"STP``*@```,K3```'````]=,```T```#]
MTP``!P````O4```+````$]0```<````?U```!P```"?4```/````+]0```D`
M```_U```"0```$G4```*````4]0``!D```!>U```/0```'C4```=````MM0`
M``P```#4U```$````.'4```%````\M0``"4```#XU```$@```![5```3````
M,=4``!4```!%U0``$@```%O5```K````;M4``#L```":U0``(````-;5```.
M````]]4```@````&U@``%`````_6```V````)-8``"$```!;U@``$````'W6
M```(````CM8```P```"7U@``!@```*36```$````J]8```\```"PU@``#@``
M`,#6```'````S]8```H```#7U@``#0```.+6```?````\-8``!P````0UP``
M(0```"W7```>````3]<``!D```!NUP``'@```(C7```;````I]<``"$```##
MUP``+@```.77```F````%-@``!P````[V```'@```%C8```<````=]@``"8`
M``"4V```*P```+O8```S````Y]@``"8````;V0``*P```$+9```X````;MD`
M`!T```"GV0``%0```,79```O````V]D``"`````+V@``$@```"S:```I````
M/]H``!X```!IV@``(````(C:```2````J=H``*(```"\V@``%@```%_;```C
M````=ML``"@```":VP``*0```,/;```H````[=L``!\````6W```%0```#;<
M```@````3-P``"4```!MW```*````)/<```M````O-P``#````#JW```D@``
M`!O=```A````KMT``!8```#0W0``'````.?=```F````!-X``"H````KW@``
M00```%;>``!$````F-X```P```#=W@``!P```.K>```'````\MX```8```#Z
MW@``$P````'?```-````%=\``!T````CWP``$````$'?```2````4M\```<`
M``!EWP``$P```&W?```2````@=\```<```"4WP``!````)S?```0````H=\`
M`!````"RWP``#````,/?```.````T-\```T```#?WP``#P```.W?```3````
M_=\```T````1X```*````!_@```#````2.````T```!,X```!@```%K@```1
M````8>```!<```!SX```&P```(O@```.````I^````(```"VX```20```+G@
M```%`````^$``!`````)X0``#P```!KA```$````*N$```T````OX0``#@``
M`#WA```#````3.$```X```!0X0``"````%_A```/````:.$```\```!XX0``
M!P```(CA```-````D.$``!````">X0``#0```*_A```:````O>$```L```#8
MX0``!@```.3A```3````Z^$```L```#_X0``$P````OB```,````'^(```H`
M```LX@``$0```#?B```9````2>(``!<```!CX@``"P```'OB```-````A^(`
M`"(```"5X@``%@```+CB```/````S^(``!L```#?X@``-````/OB```*````
M,.,``!@````[XP``$@```%3C```9````9^,``!8```"!XP``(@```)CC```C
M````N^,```\```#?XP``#0```._C```'````_>,```H````%Y```"@```!#D
M```4````&^0```L````PY```(@```#SD```O````7^0```L```"/Y```"0``
M`)OD```9````I>0```L```"_Y```%P```,OD```7````X^0```D```#[Y```
M!P````7E```6````#>4```\````DY0``&0```#3E```6````3N4```X```!E
MY0``&````'3E```(````C>4```T```"6Y0``)@```*3E```H````R^4``$,`
M``#TY0``"````#CF```2````0>8``!\```!4Y@``"````'3F```+````?>8`
M`"\```")Y@``#@```+GF```.````R.8```4```#7Y@``!@```-WF``!%````
MY.8```,````JYP``!P```"[G```$````-N<```D````[YP``$@```$7G```*
M````6.<```H```!CYP``#P```&[G```0````?N<``!<```"/YP``$0```*?G
M```1````N><``!D```#+YP``%P```.7G```)````_><```4````'Z```"P``
M``WH```*````&>@```(````DZ```!0```"?H```-````+>@``!L````[Z```
M%P```%?H```4````;^@```D```"$Z```#@```([H```-````G>@``!(```"K
MZ```.````+[H```@````]^@```@````8Z0``#@```"'I``![````,.D``!@`
M``"LZ0``&````,7I```]````WND``!4````<Z@``$0```#+J```'````1.H`
M``4```!,Z@``(P```%+J```S````=NH``!@```"JZ@``'0```,/J```N````
MX>H``!X````0ZP``&P```"_K```9````2^L``"<```!EZP``-P```(WK```D
M````Q>L``!L```#JZP``&0````;L```3````(.P```<````T[```"````#SL
M```&````1>P```8```!,[```$````%/L```/````9.P``!````!T[```#P``
M`(7L```+````E>P```\```"A[```#````+'L```/````ONP```<```#.[```
M!@```-;L```.````W>P```P```#L[```*````/GL```/````(NT```@````R
M[0``!@```#OM```3````0NT``"(```!6[0``+0```'GM```(````I^T``!,`
M``"P[0``'@```,3M```E````X^T``!H````)[@``%0```"3N```>````.NX`
M`$,```!9[@``(0```)WN```@````O^X``!D```#@[@``%P```/KN```E````
M$N\``"4````X[P``%P```%[O```6````=N\``"$```"-[P``(@```*_O```$
M````TN\``!L```#7[P``#0```//O```,`````?````,````.\```!0```!+P
M```(````&/````H````A\```#````"SP```+````.?```!````!%\```#```
M`%;P```.````8_````0```!R\```!````'?P```3````?/```!0```"0\```
M#````*7P```)````LO````X```"\\```"P```,OP```;````U_````4```#S
M\```!P```/GP```$`````?$```8````&\0``!P````WQ```*````%?$```H`
M```@\0``#0```"OQ```)````.?$```0```!#\0```P```$CQ```8````3/$`
M``H```!E\0``!````'#Q```F````=?$```X```"<\0``?````*OQ```5````
M*/(```4````^\@``!P```$3R```,````3/(```@```!9\@``"@```&+R```&
M````;?(```@```!T\@```@```'WR```&````@/(```8```"'\@``%````([R
M```,````H_(```T```"P\@``$````+[R```;````S_(```0```#K\@``"0``
M`/#R```0````^O(```D````+\P``"0```!7S```%````'_,``!H````E\P``
M"````$#S```&````2?,``!D```!0\P``#@```&KS```'````>?,```<```"!
M\P``!0```(GS```)````C_,```H```"9\P``$P```*3S```.````N/,```(`
M``#'\P``!@```,KS```+````T?,```T```#=\P``"0```.OS```&````]?,`
M`!(```#\\P``"0````_T```'````&?0```4````A]```%````"?T```=````
M//0``$(```!:]```)0```)WT```E````P_0```8```#I]```"@```/#T```$
M````^_0```D`````]0``"`````KU```1````$_4```D````E]0``!@```"_U
M```-````-O4```8```!$]0``.0```$OU```]````A?4``#H```##]0``'@``
M`/[U```%````'?8```X````C]@``!````#+V```&````-_8```<````^]@``
M(0```$;V```-````:/8``!4```!V]@``!@```(SV```$````D_8``!$```"8
M]@``!@```*KV```*````L?8``"(```"\]@``!````-_V```%````Y/8``!T`
M``#J]@``!`````CW```,````#?<```D````:]P``#````"3W```.````,?<`
M``H```!`]P``$````$OW```3````7/<``!,```!P]P``"````(3W```)````
MC?<```4```"7]P``.@```)WW```P````V/<``#4````)^```*0```#_X``!'
M````:?@``#@```"Q^```*0```.KX```_````%/D``"X```!4^0``+0```(/Y
M```?````L?D```\```#1^0``$@```.'Y```+````]/D``"8`````^@``*0``
M`"?Z```D````4?H``"8```!V^@``"````)WZ```*````IOH```D```"Q^@``
M!P```+OZ```@````P_H``"````#D^@``)@````7[```@````+/L```H```!-
M^P``&0```%C[```I````<OL``!8```"<^P``$@```+/[```'````QOL```H`
M``#.^P``#````-G[```/````YOL``!````#V^P``0`````?\``!P````2/P`
M`&8```"Y_```#@```"#]```)````+_T```H````Y_0``$@```$3]```3````
M5_T```P```!K_0``!@```'C]```<````?_T```\```"<_0``&P```*S]```2
M````R/T``!````#;_0``$0```.S]```<````_OT``",````;_@``:@```#_^
M```/````JOX```4```"Z_@``$````,#^```)````T?X```0```#;_@``"P``
M`.#^```@````[/X``!0````-_P``#````"+_```,````+_\```\````\_P``
M%0```$S_```I````8O\``"H```",_P``)@```+?_```G````WO\``"D````&
M``$`*@```#```0`9````6P`!`$(```!U``$`$0```+@``0`2````R@`!`!,`
M``#=``$`%````/$``0`/````!@$!`!8````6`0$`%P```"T!`0`0````10$!
M`!$```!6`0$`-````&@!`0`3````G0$!`!(```"Q`0$`-0```,0!`0`4````
M^@$!``<````/`@$`#````!<"`0`*````)`(!`"`````O`@$`$````%`"`0`4
M````80(!`!0```!V`@$`$0```(L"`0`7````G0(!`!P```"U`@$`#0```-("
M`0`-````X`(!`!,```#N`@$`%@````(#`0`4````&0,!`!H````N`P$`$0``
M`$D#`0`,````6P,!`!````!H`P$`&@```'D#`0`>````E`,!`!H```"S`P$`
M$P```,X#`0`5````X@,!`!$```#X`P$`%P````H$`0`4````(@0!`!<````W
M!`$`%0```$\$`0`)````900!`!````!O!`$`&0```(`$`0`$````F@0!``<`
M``"?!`$`"P```*<$`0`1````LP0!``8```#%!`$`!@```,P$`0`&````TP0!
M``4```#:!`$`!P```.`$`0`'````Z`0!``4```#P!`$`%@```/8$`0`&````
M#04!``8````4!0$`!````!L%`0`$````(`4!``<````E!0$`#@```"T%`0`,
M````/`4!``P```!)!0$`#0```%8%`0`*````9`4!``X```!O!0$`!0```'X%
M`0`H````A`4!``X```"M!0$`#````+P%`0`/````R04!``H```#9!0$`"```
M`.0%`0`)````[04!`"L```#W!0$`!````",&`0`(````*`8!`"8````Q!@$`
M$@```%@&`0`/````:P8!``8```![!@$`"@```((&`0!,````C08!``<```#:
M!@$`"````.(&`0`@````ZP8!``D````,!P$`#0```!8'`0`)````)`<!`!0`
M```N!P$`#````$,'`0`-````4`<!``X```!>!P$`%@```&T'`0`1````A`<!
M``8```"6!P$``P```)T'`0`&````H0<!`!D```"H!P$`!P```,('`0`$````
MR@<!``L```#/!P$`"P```-L'`0`'````YP<!``4```#O!P$`!P```/4'`0`6
M````_0<!``T````4"`$`#0```"((`0`*````,`@!`!`````["`$`#P```$P(
M`0`1````7`@!`!<```!N"`$`"@```(8(`0`1````D0@!``0```"C"`$`#P``
M`*@(`0`Z````N`@!``4```#S"`$`#````/D(`0`$````!@D!`!X````+"0$`
M#@```"H)`0`0````.0D!``L```!*"0$`#````%8)`0`)````8PD!``<```!M
M"0$`"@```'4)`0`)````@`D!``X```"*"0$`$````)D)`0`;````J@D!`!@`
M``#&"0$`&@```-\)`0`*````^@D!``D````%"@$`"@````\*`0`,````&@H!
M``\````G"@$`"````#<*`0`&````0`H!`!P```!'"@$`!P```&0*`0`%````
M;`H!``L```!R"@$`1P```'X*`0`-````Q@H!``D```#4"@$`!````-X*`0`#
M````XPH!`!,```#G"@$`$P```/L*`0`3````#PL!``H````C"P$``@```"X+
M`0`$````,0L!`"4````V"P$``P```%P+`0`%````8`L!`"H```!F"P$`"@``
M`)$+`0`%````G`L!``0```"B"P$`"@```*<+`0`-````L@L!``8```#`"P$`
M"````,<+`0`(````T`L!``0```#9"P$`!0```-X+`0!H````Y`L!``D```!-
M#`$`#````%<,`0`0````9`P!``4```!U#`$`!@```'L,`0`;````@@P!`"\`
M``">#`$`$````,X,`0`*````WPP!``@```#J#`$`#P```/,,`0`*`````PT!
M``D````.#0$`$P```!@-`0`;````+`T!`!@```!(#0$`%P```&$-`0`:````
M>0T!`!\```"4#0$`#@```+0-`0`7````PPT!``,```#;#0$`!P```-\-`0`(
M````YPT!``<```#P#0$`"0```/@-`0`*`````@X!``L````-#@$`!P```!D.
M`0!1````(0X!`!````!S#@$`#````(0.`0`-````D0X!`!H```"?#@$`2@``
M`+H.`0`9````!0\!``8````?#P$`&@```"8/`0`E````00\!``8```!G#P$`
M!@```&X/`0`?````=0\!``8```"5#P$`"0```)P/`0`8````I@\!`!<```"_
M#P$`*````-</`0`&`````!`!``T````'$`$`*````!40`0`B````/A`!`%<`
M``!A$`$`$P```+D0`0`C````S1`!`!,```#Q$`$``@````41`0`+````"!$!
M``P````4$0$`"````"$1`0`-````*A$!``H````X$0$`%@```$,1`0`'````
M6A$!`!0```!B$0$`!@```'<1`0`(````?A$!``X```"'$0$`!P```)81`0`*
M````GA$!``L```"I$0$`,@```+41`0`7````Z!$!``<`````$@$`#`````@2
M`0`-````%1(!``P````C$@$`!````#`2`0`)````-1(!``D````_$@$`"@``
M`$D2`0`'````5!(!``D```!<$@$`"0```&82`0`*````<!(!``<```![$@$`
M"@```(,2`0`5````CA(!`!L```"D$@$`#P```,`2`0!)````T!(!`!(````:
M$P$`"@```"T3`0`6````.!,!``\```!/$P$`$````%\3`0`)````<!,!`!``
M``!Z$P$`!P```(L3`0`2````DQ,!``0```"F$P$`"P```*L3`0`'````MQ,!
M``4```"_$P$`!0```,43`0`:````RQ,!``L```#F$P$`%````/(3`0`1````
M!Q0!`!H````9%`$`%@```#04`0`4````2Q0!`!<```!@%`$`&````'@4`0`<
M````D10!`!D```"N%`$`!P```,@4`0`%````T!0!``T```#6%`$`#````.04
M`0`+````\10!`!$```#]%`$`"`````\5`0`7````&!4!``L````P%0$`#```
M`#P5`0`?````214!`!H```!I%0$`$P```(05`0`$````F!4!``H```"=%0$`
M!````*@5`0`-````K14!``P```"[%0$`!0```,@5`0`)````SA4!``@```#8
M%0$`!0```.$5`0`'````YQ4!``4```#O%0$`!````/45`0`"````^A4!`!@`
M``#]%0$`%P```!86`0`X````+A8!`"P```!G%@$`$@```)06`0`I````IQ8!
M`#(```#1%@$`"@````07`0`L````#Q<!`"X````\%P$`,P```&L7`0`S````
MGQ<!`#@```#3%P$`$0````P8`0`/````'A@!`!@````N&`$`$````$<8`0`/
M````6!@!`!,```!H&`$`%0```'P8`0`4````DA@!`!(```"G&`$`%````+H8
M`0`5````SQ@!`"T```#E&`$`+0```!,9`0`Q````01D!`"X```!S&0$`+P``
M`*(9`0`L````TAD!`&(```#_&0$`$P```&(:`0`-````=AH!``@```"$&@$`
M%P```(T:`0`(````I1H!``P```"N&@$`*P```+L:`0`A````YQH!`!@````)
M&P$`&@```"(;`0`)````/1L!`$4```!'&P$`00```(T;`0`$````SQL!`!,`
M``#4&P$`%````.@;`0`.````_1L!`!,````,'`$`&````"`<`0`&````.1P!
M``D```!`'`$`"@```$H<`0`/````51P!`!````!E'`$`!P```'8<`0`.````
M?AP!``4```"-'`$`&P```),<`0`(````KQP!``8```"X'`$`%````+\<`0`1
M````U!P!`!@```#F'`$`#@```/\<`0`X````#AT!``(```!''0$`!@```$H=
M`0`.````41T!`!````!@'0$`!0```'$=`0`'````=QT!``X```!_'0$`!@``
M`(X=`0`H````E1T!``P```"^'0$`'````,L=`0`$````Z!T!`)H```#M'0$`
M*0```(@>`0`7````LAX!`!\```#*'@$`&0```.H>`0!<````!!\!`!0```!A
M'P$`/@```'8?`0`?````M1\!`!````#5'P$`!P```.8?`0`.````[A\!``P`
M``#]'P$`#`````H@`0`3````%R`!``H````K(`$`'0```#8@`0`9````5"`!
M``4```!N(`$`$0```'0@`0`-````AB`!`!$```"4(`$`)````*8@`0`2````
MRR`!`!4```#>(`$`$@```/0@`0`.````!R$!`!D````6(0$`"````#`A`0`-
M````.2$!``<```!'(0$`"@```$\A`0`'````6B$!``\```!B(0$`!@```'(A
M`0`+````>2$!`!H```"%(0$`!P```*`A`0`(````J"$!``4```"Q(0$`'P``
M`+<A`0`&````UR$!`!````#>(0$`"````.\A`0`-````^"$!``@````&(@$`
M'@````\B`0`2````+B(!`"P```!!(@$`&@```&XB`0`)````B2(!``H```"3
M(@$`%0```)XB`0`%````M"(!`!0```"Z(@$`!````,\B`0`0````U"(!``8`
M``#E(@$`!P```.PB`0`>````]"(!`"@````3(P$`"@```#PC`0`<````1R,!
M`!$```!D(P$`$0```'8C`0`+````B",!`!H```"4(P$`%````*\C`0`$````
MQ",!``0```#)(P$`"P```,XC`0`%````VB,!``8```#@(P$`$0```.<C`0`(
M````^2,!``8````")`$`"@````DD`0`;````%"0!`#0````P)`$`-````&4D
M`0`@````FB0!`"D```"[)`$`(````.4D`0!!````!B4!`!H```!()0$`(0``
M`&,E`0`H````A24!`"D```"N)0$`4````-@E`0`B````*28!``8```!,)@$`
M"````%,F`0`%````7"8!``@```!B)@$`&0```&LF`0`9````A28!`"H```"?
M)@$`(P```,HF`0`9````[B8!`"X````()P$`-````#<G`0`(````;"<!`!<`
M``!U)P$`"@```(TG`0`'````F"<!`"$```"@)P$`"````,(G`0`0````RR<!
M``X```#<)P$`%````.LG`0`+`````"@!``<````,*`$`$P```!0H`0`(````
M*"@!``L````Q*`$`"@```#TH`0`4````2"@!``\```!=*`$`,@```&TH`0`+
M````H"@!``X```"L*`$`!0```+LH`0`%````P2@!`!4```#'*`$`#````-TH
M`0`%````ZB@!`!<```#P*`$`#P````@I`0`$````&"D!``H````=*0$`"0``
M`"@I`0`+````,BD!``T````^*0$`#````$PI`0`.````62D!``4```!H*0$`
M!````&XI`0`4````<RD!``T```"(*0$`(@```)8I`0`R````N2D!`!L```#L
M*0$`10````@J`0`2````3BH!`!<```!A*@$`!P```'DJ`0`>````@2H!`!0`
M``"@*@$`%````+4J`0`&````RBH!``<```#1*@$`#@```-DJ`0`J````Z"H!
M``8````3*P$`#````!HK`0`3````)RL!``T````[*P$`$0```$DK`0`5````
M6RL!``L```!Q*P$`-@```'TK`0`*````M"L!`"(```"_*P$`"P```.(K`0`/
M````[BL!`(4```#^*P$`,@```(0L`0`;````MRP!`"4```#3+`$`,````/DL
M`0`Q````*BT!`"T```!<+0$`#@```(HM`0`%````F2T!``X```"?+0$`$P``
M`*XM`0`1````PBT!`!(```#4+0$`!P```.<M`0`1````[RT!`!,````!+@$`
M!P```!4N`0`4````'2X!`!@````R+@$`!P```$LN`0`%````4RX!``P```!9
M+@$`#````&8N`0`2````<RX!``0```"&+@$`!P```(LN`0`*````DRX!``L`
M``">+@$`#````*HN`0`.````MRX!``X```#&+@$`!0```-4N`0`%````VRX!
M`"X```#A+@$`)@```!`O`0`C````-R\!``,```!;+P$`$@```%\O`0`&````
M<B\!`!X```!Y+P$`&````)@O`0`9````L2\!`"4```#++P$`#0```/$O`0`?
M````_R\!``,````?,`$`&````",P`0`'````/#`!``(```!$,`$`#````$<P
M`0`5````5#`!``L```!J,`$`&0```'8P`0`@````D#`!`!(```"Q,`$`!0``
M`,0P`0`*````RC`!`!4```#5,`$`$@```.LP`0`,````_C`!``0````+,0$`
M"0```!`Q`0`'````&C$!``P````B,0$`4@```"\Q`0`7````@C$!`"0```":
M,0$`(0```+\Q`0`2````X3$!``<```#T,0$`!@```/PQ`0`.`````S(!``T`
M```2,@$`$0```"`R`0`;````,C(!``P```!.,@$`#````%LR`0`-````:#(!
M`!4```!V,@$`$@```(PR`0`/````GS(!`!0```"O,@$`"@```,0R`0`;````
MSS(!`"````#K,@$`'@````PS`0`0````*S,!``L````\,P$`)P```$@S`0`E
M````<#,!`&D```"6,P$`)@`````T`0`:````)S0!`!<```!"-`$`&0```%HT
M`0`:````=#0!`"4```"/-`$`*````+4T`0`G````WC0!`!H````&-0$`%P``
M`"$U`0`;````.34!`$0```!5-0$`-````)HU`0`E````SS4!`!D```#U-0$`
M'P````\V`0`;````+S8!`!,```!+-@$`"````%\V`0`'````:#8!``@```!P
M-@$`"0```'DV`0`5````@S8!``T```"9-@$`(P```*<V`0`-````RS8!`!,`
M``#9-@$`"````.TV`0`#````]C8!`$8```#Z-@$`/P```$$W`0`W````@3<!
M`%<```"Y-P$`!0```!$X`0`?````%S@!`"\````W.`$`"@```&<X`0`0````
M<C@!``@```"#.`$`#0```(PX`0`M````FC@!``0```#(.`$`!P```,TX`0`(
M````U3@!``T```#>.`$`"@```.PX`0!/````]S@!`"4```!'.0$`'````&TY
M`0`+````BCD!`!\```"6.0$`'0```+8Y`0`E````U#D!`"````#Z.0$`)```
M`!LZ`0`@````0#H!``L```!A.@$`!P```&TZ`0`-````=3H!``P```"#.@$`
M%P```)`Z`0`&````J#H!`#D```"O.@$`#````.DZ`0`'````]CH!``D```#^
M.@$`$P````@[`0`)````'#L!``0````F.P$`$````"L[`0`(````/#L!``@`
M``!%.P$`!````$X[`0`+````4SL!``P```!?.P$`$@```&P[`0`1````?SL!
M``P```"1.P$`&@```)X[`0`/````N3L!``<```#).P$`#0```-$[`0`.````
MWSL!`!0```#N.P$`#@````,\`0`'````$CP!``P````:/`$`&P```"<\`0`L
M````0SP!`!,```!P/`$`'````(0\`0`H````H3P!``8```#*/`$`!P```-$\
M`0`3````V3P!``4```#M/`$`!````/,\`0`7````^#P!`#D````0/0$`"@``
M`$H]`0`,````53T!``D```!B/0$`!@```&P]`0`)````<ST!``@```!]/0$`
M"0```(8]`0`*````D#T!`!$```";/0$`!@```*T]`0`.````M#T!``X```##
M/0$`#0```-(]`0`+````X#T!`!T```#L/0$`"P````H^`0`"````%CX!`!P`
M```9/@$`!P```#8^`0`&````/CX!`&0```!%/@$`"0```*H^`0`'````M#X!
M`"8```"\/@$`*0```.,^`0`;````#3\!`#@````I/P$`*P```&(_`0`:````
MCC\!`",```"I/P$`*@```,T_`0`M````^#\!`#L````F0`$`*````&)``0`T
M````BT`!`!D```#`0`$`%0```-I``0`%````\$`!``<```#V0`$`"````/Y`
M`0`'````!T$!``4````/00$`!P```!5!`0`.````'4$!``D````L00$`!@``
M`#9!`0`(````/4$!``L```!&00$`!P```%)!`0`(````6D$!``<```!C00$`
M%@```&M!`0`)````@D$!``8```",00$`"P```)-!`0`0````GT$!`!P```"P
M00$`%````,U!`0`'````XD$!`!$```#J00$`"````/Q!`0`.````!4(!``@`
M```40@$`%````!U"`0`%````,D(!`!`````X0@$`$````$E"`0`&````6D(!
M`!D```!A0@$`"@```'M"`0`<````AD(!``<```"C0@$`!0```*M"`0`0````
ML4(!`!0```#"0@$`"P```-="`0`-````XT(!`"@```#Q0@$`&````!I#`0`7
M````,T,!``0```!+0P$`"0```%!#`0`*````6D,!``<```!E0P$``@```&U#
M`0`.````<$,!``@```!_0P$`(P```(A#`0`?````K$,!`#@```#,0P$`)@``
M``5$`0`Q````+$0!`"<```!>1`$`1````(9$`0`E````RT0!`"\```#Q1`$`
M+P```"%%`0`O````444!`"@```"!10$`9````*I%`0`4````#T8!`%4````D
M1@$`.````'I&`0`I````LT8!`$H```#=1@$`6P```"A'`0`H````A$<!`#@`
M``"M1P$`+````.9'`0`H````$T@!`"P````\2`$`)@```&E(`0`;````D$@!
M`#X```"L2`$`J0$``.M(`0`C````E4H!`#````"Y2@$`%P```.I*`0!(````
M`DL!`(4```!+2P$`,````-%+`0`E`````DP!`$$````H3`$`6P```&I,`0!)
M````QDP!`#$````030$`'0```$)-`0`8````8$T!`"L```!Y30$`(0```*5-
M`0`?````QTT!`"L```#G30$`)@```!-.`0`G````.DX!`#H```!B3@$`'0``
M`)U.`0`1````NTX!`#,```#-3@$`)0````%/`0`G````)T\!`"````!/3P$`
M)@```'!/`0`?````ET\!`#````"W3P$`S````.A/`0!I````M5`!`#$````?
M40$`00```%%1`0`S````DU$!`"4```#'40$`/0```.U1`0!E````*U(!`$T`
M``"14@$`7@```-]2`0`G````/E,!`#$```!F4P$`/@```)A3`0`L````UU,!
M`"8````$5`$`+P```"M4`0`N````6U0!`"D```"*5`$`,````+14`0!4````
MY50!`%H````Z50$`,0```)55`0!(````QU4!`$H````05@$`,0```%M6`0`J
M````C58!`"(```"X5@$`+P```-M6`0`I````"U<!`#(````U5P$`+P```&A7
M`0`L````F%<!`"T```#%5P$`<0```/-7`0!F````95@!`&\```#,6`$`LP``
M`#Q9`0`7````\%D!`"4````(6@$`,@```"Y:`0`I````85H!`#X```"+6@$`
M(@```,I:`0!2````[5H!`"(```!`6P$`)0```&-;`0`+````B5L!`+$```"5
M6P$`10```$=<`0`A````C5P!`#8```"O7`$`,````.9<`0`E````%UT!`!P`
M```]70$`2````%I=`0`Q````HUT!``<```#570$`!P```-U=`0`$````Y5T!
M``T```#J70$`"P```/A=`0`.````!%X!``L````37@$`!0```!]>`0`0````
M)5X!``(````V7@$`60```#E>`0`%````DUX!`!(```"97@$`!````*Q>`0`'
M````L5X!``@```"Y7@$`!0```,)>`0`#````R%X!`!````#,7@$`#````-U>
M`0`3````ZEX!``T```#^7@$``@````Q?`0`'````#U\!``8````77P$`%```
M`!Y?`0`,````,U\!`!@```!`7P$`!@```%E?`0`2````8%\!``P```!S7P$`
M`P```(!?`0`J````A%\!``0```"O7P$`!@```+1?`0`'````NU\!`!\```##
M7P$`-0```.-?`0`N````&6`!`"\```!(8`$`%P```'A@`0`B````D&`!`"4`
M``"S8`$`(````-E@`0`;````^F`!`!@````680$`)````"]A`0`?````5&$!
M`!H```!T80$`(0```(]A`0`@````L6$!`#````#280$`&@````-B`0`R````
M'F(!`!H```!18@$`+P```&QB`0`K````G&(!`!\```#(8@$`(P```.AB`0`?
M````#&,!`!H````L8P$`(0```$=C`0`E````:6,!`"8```"/8P$`)0```+9C
M`0`D````W&,!`!@````!9`$`'0```!ID`0`D````.&0!`!@```!=9`$`(@``
M`'9D`0`L````F60!`"\```#&9`$`%0```/9D`0`E````#&4!`#P````R90$`
M'P```&]E`0`C````CV4!`!\```"S90$`(````--E`0`:````]&4!`!@````/
M9@$`)@```"AF`0`>````3V8!`"D```!N9@$`'@```)AF`0`Q````MV8!``D`
M``#I9@$`#````/-F`0`7`````&<!`"\````89P$`)````$AG`0`'````;6<!
M``\```!U9P$`%````(5G`0`.````FF<!``T```"I9P$`)````+=G`0`%````
MW&<!``<```#B9P$`(@```.IG`0`E````#6@!`!H````S:`$`'0```$YH`0`:
M````;&@!``<```"':`$`QP```(]H`0`+````5VD!`!P```!C:0$`%0```(!I
M`0`&````EFD!``D```"=:0$`"P```*=I`0`-````LVD!`!<```#!:0$`!@``
M`-EI`0`S````X&D!`!,````4:@$`$P```"AJ`0`'````/&H!``\```!$:@$`
M!P```%1J`0`R````7&H!``0```"/:@$`(0```)1J`0`3````MFH!``P```#*
M:@$`$0```-=J`0`R````Z6H!`!8````<:P$`"````#-K`0`=````/&L!``D`
M``!::P$`"@```&1K`0`4````;VL!``H```"$:P$`'0```(]K`0`(````K6L!
M`!\```"V:P$`"````-9K`0`:````WVL!`"<```#Z:P$`!@```")L`0`5````
M*6P!``<````_;`$`"````$=L`0`)````4&P!`#\```!:;`$`$@```)IL`0`'
M````K6P!``\```"U;`$`#@```,5L`0`0````U&P!``D```#E;`$`"0```.]L
M`0`(````^6P!`!,````";0$`"0```!9M`0`'````(&T!``P````H;0$`&0``
M`#5M`0`*````3VT!`!L```!:;0$`%P```'9M`0`4````CFT!``H```"C;0$`
M#````*YM`0`7````NVT!``0```#3;0$`*@```-AM`0`,`````VX!`!$````0
M;@$`!P```")N`0`"````*FX!`!`````M;@$`&````#YN`0`#````5VX!``@`
M``!;;@$`"P```&1N`0`&````<&X!``<```!W;@$`#0```']N`0`+````C6X!
M`!0```"9;@$`%0```*YN`0`.````Q&X!`"\```#3;@$`(`````-O`0`<````
M)&\!`!4```!!;P$`#````%=O`0`Q````9&\!``4```"6;P$`$@```)QO`0`_
M````KV\!`!(```#O;P$`"@````)P`0`&````#7`!``0````4<`$`!````!EP
M`0`*````'G`!`!,````I<`$`!0```#UP`0`&````0W`!``8```!*<`$`"```
M`%%P`0`$````6G`!``P```!?<`$`"0```&QP`0`,````=G`!``H```"#<`$`
M$````(YP`0`3````GW`!`!,```"S<`$`.0```,=P`0`N`````7$!`"D````P
M<0$`!0```%IQ`0`8````8'$!`!D```!Y<0$`'P```)-Q`0`=````LW$!`!$`
M``#1<0$``@```.-Q`0`$````YG$!``H```#K<0$`!@```/9Q`0`%````_7$!
M``,````#<@$`#`````=R`0!%````%'(!`#(```!:<@$`/````(UR`0`:````
MRG(!`#0```#E<@$`*````!IS`0!3````0W,!`#````"7<P$`+P```,AS`0`R
M````^',!`!D````K=`$`<@```$5T`0`@````N'0!`#4```#9=`$`(0````]U
M`0!%````,74!`#````!W=0$`)@```*AU`0`>````SW4!`"@```#N=0$`*P``
M`!=V`0`I````0W8!`"D```!M=@$`)@```)=V`0`E````OG8!`"@```#D=@$`
M*`````UW`0`B````-G<!`"L```!9=P$`+@```(5W`0`P````M'<!`!(```#E
M=P$`$P```/AW`0`0````#'@!`'D````=>`$`"0```)=X`0"A````H7@!`',`
M``!#>0$`?````+=Y`0`K````-'H!`%0```!@>@$`%P```+5Z`0`L````S7H!
M`"<```#Z>@$`%@```")[`0`/````.7L!`!<```!)>P$`'P```&%[`0!`````
M@7L!`!\```#">P$`'````.)[`0!1````_WL!`!H```!1?`$`%````&Q\`0`*
M````@7P!``4```",?`$`!@```))\`0`(````F7P!`!(```"B?`$`$````+5\
M`0`3````QGP!`!T```#:?`$`#P```/A\`0`*````"'T!``\````3?0$`!P``
M`"-]`0`$````*WT!``D````P?0$`!P```#I]`0`+````0GT!``<```!.?0$`
M!0```%9]`0`4````7'T!``X```!Q?0$`!@```(!]`0`'````AWT!``@```"/
M?0$`#P```)A]`0`1````J'T!``P```"Z?0$`"````,=]`0`,````T'T!``\`
M``#=?0$`%@```.U]`0`'````!'X!``8````,?@$`%````!-^`0`&````*'X!
M``P````O?@$`$0```#Q^`0`(````3GX!``0```!7?@$`&0```%Q^`0`1````
M=GX!``H```"(?@$`&````)-^`0`3````K'X!`!P```#`?@$`$0```-U^`0`$
M````[WX!``\```#T?@$`!P````1_`0`$````#'\!`!D````1?P$`!P```"M_
M`0`"````,W\!`!$````V?P$`"0```$A_`0`2````4G\!`!<```!E?P$`!@``
M`'U_`0`G````A'\!``0```"L?P$`#0```+%_`0`$````OW\!``\```#$?P$`
M$P```-1_`0`'````Z'\!``<```#P?P$`$0```/A_`0`&````"H`!`!@````1
M@`$`!@```"J``0`3````,8`!`!````!%@`$`$@```%:``0`&````:8`!``P`
M``!P@`$`"0```'V``0`1````AX`!`!$```"9@`$`&P```*N``0`B````QX`!
M``<```#J@`$`"P```/*``0`%````_H`!``(````$@0$`8P$```>!`0`4````
M:X(!`!,```"`@@$`#P```)2"`0`%````I((!``D```"J@@$`"0```+2"`0`<
M````OH(!`!@```#;@@$``P```/2"`0`P````^((!`!0````I@P$`'````#Z#
M`0`L````6X,!`"L```"(@P$`(0```+2#`0`M````UH,!`"P````$A`$`'```
M`#&$`0`M````3H0!`"L```!\A`$`+0```*B$`0`S````UH0!``L````*A0$`
M+````!:%`0`4````0X4!`!,```!8A0$`"P```&R%`0`H````>(4!``P```"A
MA0$`%0```*Z%`0`;````Q(4!`!<```#@A0$`(0```/B%`0`*````&H8!`"H`
M```EA@$`@P```%"&`0`6````U(8!``<```#KA@$`$0```/.&`0`5````!8<!
M``X````;AP$`"@```"J'`0`/````-8<!`!$```!%AP$`F@```%>'`0`-````
M\H<!`!4`````B`$`&0```!:(`0`/````,(@!`!````!`B`$`$````%&(`0`&
M````8H@!``8```!IB`$`1````'"(`0`\````M8@!`!X```#RB`$`.0```!&)
M`0!,````2XD!`&L```"8B0$`9P````2*`0!Q````;(H!`&T```#>B@$`/```
M`$R+`0`2````B8L!`!,```"<BP$`#````+"+`0`1````O8L!`!(```#/BP$`
M!0```.*+`0`K````Z(L!`!(````4C`$`"@```">,`0`3````,HP!``D```!&
MC`$`"@```%",`0`S````6XP!`"T```"/C`$`-P```+V,`0`9````]8P!``8`
M```/C0$`(0```!:-`0`)````.(T!``<```!"C0$`%0```$J-`0`B````8(T!
M`!$```"#C0$`%@```)6-`0`:````K(T!`!T```#'C0$`*@```.6-`0`;````
M$(X!``T````LC@$`)@```#J.`0`)````88X!``\```!KC@$`$@```'N.`0`1
M````CHX!`"X```"@C@$`"P```,^.`0`<````VXX!`!T```#XC@$`&0```!:/
M`0!E````,(\!`$(```"6CP$`&P```-F/`0`P````]8\!``,````FD`$`"@``
M`"J0`0`0````-9`!``P```!&D`$`#P```%.0`0`B````8Y`!`!8```"&D`$`
M&P```)V0`0`\````N9`!``X```#VD`$`"@````61`0`1````$)$!``L````B
MD0$`!P```"Z1`0`'````-I$!``4````^D0$`"@```$21`0`)````3Y$!``L`
M``!9D0$`'0```&61`0`.````@Y$!`!(```"2D0$`(````*61`0`;````QI$!
M`#,```#BD0$`"P```!:2`0`+````(I(!`!\````ND@$`$@```$Z2`0`>````
M89(!``\```"`D@$`$P```)"2`0`2````I)(!``\```"WD@$`(@```,>2`0`8
M````ZI(!``<````#DP$`!@````N3`0`(````$I,!`"@````;DP$`!@```$23
M`0`*````2Y,!`!(```!6DP$`"@```&F3`0`4````=),!`!,```")DP$`+0``
M`)V3`0`*````RY,!`!$```#6DP$`!P```.B3`0`3````\),!`!P````$E`$`
M&@```"&4`0`B````/)0!`#8```!?E`$`/0```):4`0`Z````U)0!``D````/
ME0$`#````!F5`0`2````)I4!``@````YE0$`!0```$*5`0`'````2)4!``<`
M``!0E0$`#````%B5`0`:````994!`$D```"`E0$`%P```,J5`0`I````XI4!
M`"T````,E@$`-````#J6`0`Y````;Y8!``T```"IE@$`"0```+>6`0`*````
MP98!``@```#,E@$`-````-66`0!(````"I<!`#,```!3EP$`7@```(>7`0`R
M````YI<!`#(````9F`$`10```$R8`0`^````DI@!`#(```#1F`$`1@````29
M`0`N````2YD!`#L```!ZF0$`0@```+:9`0`R````^9D!`#@````LF@$`.@``
M`&6:`0`E````H)H!`"@```#&F@$`.0```.^:`0`Z````*9L!`#D```!DFP$`
M&P```)Z;`0`,````NIL!`"````#'FP$`!@```.B;`0`+````[YL!`!X```#[
MFP$`)@```!J<`0`'````09P!``<```!)G`$`$P```%&<`0`)````99P!``@`
M``!OG`$`-0```'B<`0`+````KIP!``<```"ZG`$`$````,*<`0`'````TYP!
M``8```#;G`$`$@```.*<`0`%````]9P!``<```#[G`$`!@````.=`0`K````
M"IT!``L````VG0$`+0```$*=`0`6````<)T!`!(```"'G0$`"````)J=`0`'
M````HYT!`!````"KG0$`!0```+R=`0`/````PIT!``<```#2G0$`$P```-J=
M`0`)````[IT!``@```#XG0$`!`````&>`0`-````!IX!``@````4G@$`&@``
M`!V>`0`)````.)X!`!$```!"G@$`"````%2>`0`*````79X!``P```!HG@$`
M!P```'6>`0`0````?9X!`!4```".G@$``P```*2>`0`L````J)X!``,```#5
MG@$`$P```-F>`0`I````[9X!``8````7GP$`!P```!Z?`0`)````)I\!``<`
M```PGP$`0````#B?`0`>````>9\!`",```"8GP$`.P```+R?`0`J````^)\!
M`"0````CH`$`!@```$B@`0`%````3Z`!`!H```!5H`$`(0```'"@`0`_````
MDJ`!`#L```#2H`$`(P````ZA`0`B````,J$!`%<```!5H0$`+````*VA`0`2
M````VJ$!``H```#MH0$`"P```/BA`0`7````!*(!``\````<H@$`#0```"RB
M`0`2````.J(!`!(```!-H@$`$@```&"B`0`3````<Z(!``T```"'H@$`$P``
M`)6B`0`%````J:(!`!D```"OH@$`&@```,FB`0`7````Y*(!`!D```#\H@$`
M)````!:C`0`$````.Z,!``L```!`HP$`$P```$RC`0!$````8*,!`%P```"E
MHP$`"`````*D`0`2````"Z0!`!P````>I`$`!0```#ND`0`$````0:0!`!X`
M``!&I`$`&0```&6D`0`=````?Z0!`!@```"=I`$`$0```+:D`0`>````R*0!
M`!H```#GI`$`&P````*E`0`M````'J4!`#8```!,I0$`20```(.E`0`W````
MS:4!`#0````%I@$`$@```#JF`0`H````3:8!``8```!VI@$`&0```'VF`0`4
M````EZ8!`!8```"LI@$`%0```,.F`0`?````V:8!`!````#YI@$`)`````JG
M`0`H````+Z<!`!$```!8IP$`"0```&JG`0`1````=*<!``H```"&IP$`#P``
M`)&G`0`=````H:<!`!$```"_IP$`"````-&G`0`$````VJ<!``P```#?IP$`
M#0```.RG`0`)````^J<!`!8````$J`$`$0```!NH`0`7````+:@!``8```!%
MJ`$`'@```$RH`0`R````:Z@!``<```">J`$`$````*:H`0`*````MZ@!``X`
M``#"J`$`#P```-&H`0`)````X:@!``X```#KJ`$`#````/JH`0`1````!ZD!
M`!$````9J0$`'0```"NI`0!8````2:D!`"````"BJ0$`$0```,.I`0`5````
MU:D!``4```#KJ0$`'P```/&I`0`7````$:H!`!@````IJ@$`'````$*J`0`8
M````7ZH!`#8```!XJ@$`0P```*^J`0`L````\ZH!``H````@JP$`"0```"NK
M`0`1````-:L!`#0```!'JP$`'@```'RK`0`-````FZL!``D```"IJP$`#0``
M`+.K`0`$````P:L!``L```#&JP$`&@```-*K`0`8````[:L!`!0````&K`$`
M"@```!NL`0`0````)JP!`"P````WK`$`+P```&2L`0`^````E*P!`#$```#3
MK`$`+`````6M`0`>````,JT!`$0```!1K0$`+````):M`0`^````PZT!`"P`
M```"K@$`/0```"^N`0`_````;:X!`"(```"MK@$`*````-"N`0`W````^:X!
M`#$````QKP$`+0```&.O`0`O````D:\!`#P```#!KP$`(@```/ZO`0`G````
M(;`!`#\```!)L`$`*P```(FP`0`<````M;`!`"D```#2L`$`)@```/RP`0`>
M````([$!`!$```!"L0$`Q````%2Q`0`Z````&;(!`"D```!4L@$`*P```'ZR
M`0`M````JK(!`"\```#8L@$`-0````BS`0`C````/K,!`"@```!BLP$`+@``
M`(NS`0`Q````NK,!`#D```#LLP$`-````":T`0"0````6[0!`#0```#LM`$`
M&````"&U`0`M````.K4!`"L```!HM0$`+P```)2U`0!$````Q+4!`$H````)
MM@$`#P```%2V`0`&````9+8!``H```!KM@$`"@```':V`0`6````@;8!`!``
M``"8M@$`'````*FV`0`.````QK8!`!0```#5M@$`"@```.JV`0`H````];8!
M``\````>MP$`#````"ZW`0`$````.[<!`!$```!`MP$`(@```%*W`0`*````
M=;<!``\```"`MP$`%@```)"W`0`2````I[<!`!X```"ZMP$`$````-FW`0!+
M````ZK<!``<````VN`$`&````#ZX`0`&````5[@!``\```!>N`$`%0```&ZX
M`0`5````A+@!`!````":N`$``@```*NX`0!=````KK@!``<````,N0$`$0``
M`!2Y`0`9````)KD!``4```!`N0$`$0```$:Y`0`2````6+D!``8```!KN0$`
M#@```'*Y`0`(````@;D!``8```"*N0$`$````)&Y`0`/````HKD!`!\```"R
MN0$`(0```-*Y`0`5````]+D!`"\````*N@$`"@```#JZ`0`&````1;H!`!(`
M``!,N@$`#P```%^Z`0`5````;[H!`!$```"%N@$`%P```)>Z`0`5````K[H!
M``\```#%N@$`&0```-6Z`0`/````[[H!`!$```#_N@$`*````!&[`0`>````
M.KL!`!$```!9NP$`'0```&N[`0`^````B;L!``T```#(NP$`(````-:[`0`3
M````][L!`!H````+O`$`%P```":\`0`K````/KP!`"(```!JO`$`%0```(V\
M`0`2````H[P!``4```"VO`$`!P```+R\`0`(````Q+P!`!L```#-O`$`!@``
M`.F\`0`O````\+P!`$$````@O0$`"@```&*]`0`*````;;T!`!4```!XO0$`
M#````(Z]`0`2````F[T!`!(```"NO0$`!@```,&]`0`,````R+T!`#(```#5
MO0$`&0````B^`0`E````(KX!`"8```!(O@$`%@```&^^`0`F````AKX!``@`
M``"MO@$`"P```+:^`0`L````PKX!`#T```#OO@$`0````"V_`0`(````;K\!
M`!4```!WOP$`)P```(V_`0`(````M;\!``\```"^OP$`/0```,Z_`0`.````
M#,`!``\````;P`$`#````"O``0`%````.,`!`%$````^P`$`!````)#``0`'
M````E<`!``D```"=P`$`#P```*?``0`7````M\`!``\```#/P`$`$0```-_`
M`0`5````\<`!`!@````'P0$`'@```"#!`0`5````/\$!`!T```!5P0$`(```
M`'/!`0`>````E,$!``<```"SP0$`"````+O!`0`(````Q,$!``<```#-P0$`
M%@```-7!`0`%````[,$!``D```#RP0$`(0```/S!`0`7````'L(!`!`````V
MP@$`#@```$?"`0`,````5L(!``P```!CP@$`&0```'#"`0!#````BL(!`#8`
M``#.P@$`#`````7#`0`6````$L,!`'H````IPP$`&@```*3#`0`:````O\,!
M`$T```#:PP$`&@```"C$`0`1````0\0!``<```!5Q`$`!````%W$`0`^````
M8L0!`$$```"AQ`$`)P```./$`0`E````"\4!`"@````QQ0$`-@```%K%`0`]
M````D<4!`"(```#/Q0$`.P```/+%`0`^````+L8!`#,```!MQ@$`+````*'&
M`0`8````SL8!`"<```#GQ@$`"@````_'`0`'````&L<!``P````BQP$`!@``
M`"_'`0`-````-L<!``P```!$QP$`$@```%''`0`,````9,<!`!<```!QQP$`
M"P```(G'`0`*````E<<!``X```"@QP$`"P```*_'`0`,````N\<!`!\```#(
MQP$`&P```.C'`0!-````!,@!`!<```!2R`$`!@```&K(`0`*````<<@!`!8`
M``!\R`$`,````)/(`0`B````Q,@!``0```#GR`$`)P```.S(`0`Q````%,D!
M`"$```!&R0$`)0```&C)`0`?````CLD!`"(```"NR0$`4@```-')`0`>````
M),H!`!T```!#R@$`*P```&'*`0`J````C<H!`"P```"XR@$`,0```.7*`0`M
M````%\L!`!P```!%RP$`)P```&++`0`H````BLL!``8```"SRP$`'````+K+
M`0`.````U\L!`!<```#FRP$``P```/[+`0`#`````LP!``<````&S`$`$```
M``[,`0`2````'\P!``T````RS`$`%@```$#,`0`+````5\P!`"8```!CS`$`
M!@```(K,`0`$````D<P!`!(```"6S`$`$@```*G,`0`.````O,P!``<```#+
MS`$`#@```-/,`0`/````XLP!`"$```#RS`$`!````!3-`0`&````&<T!``0`
M```@S0$`"0```"7-`0`*````+\T!``@````ZS0$`"@```$/-`0`+````3LT!
M`!8```!:S0$`$0```''-`0`#````@\T!`!0```"'S0$`"````)S-`0`&````
MI<T!`#D```"LS0$`&````.;-`0",````_\T!`!D```",S@$`#````*;.`0`&
M````L\X!``X```"ZS@$`"````,G.`0`*````TLX!``<```#=S@$`#````.7.
M`0`"````\LX!``@```#US@$`#0```/[.`0`-````#,\!`!0````:SP$`#@``
M`"_/`0`1````/L\!`!8```!0SP$`!@```&?/`0`'````;L\!`!````!VSP$`
M"````(?/`0`*````D,\!``4```";SP$`(````*'/`0`+````PL\!``8```#.
MSP$`)````-7/`0`1````^L\!``8````,T`$`"P```!/0`0`%````']`!``D`
M```ET`$`"@```"_0`0`3````.M`!`!0```!.T`$`!0```&/0`0`%````:=`!
M``T```!OT`$`#@```'W0`0`,````C-`!``L```"9T`$`$@```*70`0`(````
MN-`!``<```#!T`$`!P```,G0`0`6````T=`!`!P```#HT`$`0P````71`0`K
M````2=$!`#@```!UT0$`"0```*[1`0`*````N-$!``0```##T0$`"0```,C1
M`0`(````TM$!`!0```#;T0$`"P```/#1`0`&````_-$!``T````#T@$`!@``
M`!'2`0!`````&-(!`$4```!9T@$`0@```)_2`0`K````XM(!``4````.TP$`
M#P```!33`0`#````)-,!``8````HTP$`!@```"_3`0`;````-M,!``P```!2
MTP$`%````%_3`0`(````=-,!``@```!]TP$`(P```(;3`0`(````JM,!``<`
M``"STP$`$````+O3`0`$````S-,!``@```#1TP$`#````-K3`0`(````Y],!
M`!$```#PTP$`$@````+4`0`3````%=0!`!0````IU`$`#P```#[4`0`9````
M3M0!`!P```!HU`$`$0```(74`0`(````E]0!``@```"@U`$`!0```*G4`0`T
M````K]0!`#<```#DU`$`-P```!S5`0`L````5-4!`$4```"!U0$`0P```,?5
M`0`O````"]8!`%@````[U@$`-````)36`0!*````R=8!`"T````4UP$`$```
M`$+7`0`0````4]<!``L```!DUP$`(P```'#7`0`D````E-<!`!<```"YUP$`
M(````-'7`0`,````\M<!``X```#_UP$`"@````[8`0`,````&=@!`"X````F
MV`$`*@```%78`0`_````@-@!`!@```#`V`$`!@```-G8`0`>````X-@!`#``
M``#_V`$`'````##9`0`6````3=D!``8```!DV0$`"P```&O9`0`*````=]D!
M`!````""V0$`)0```)/9`0!&````N=D!`)$`````V@$`=````)+:`0`/````
M!]L!``P````7VP$`#0```"3;`0`;````,ML!`!<```!.VP$`#@```&;;`0`%
M````==L!`"$```![VP$`%0```)W;`0`<````L]L!`!4```#0VP$`$P```.;;
M`0`6````^ML!`!<````1W`$`-````"G<`0"-````7MP!`!````#LW`$`!0``
M`/W<`0`2`````]T!``D````6W0$`"@```"#=`0`*````*]T!`"@````VW0$`
M%P```%_=`0`0````=]T!`!4```"(W0$`$````)[=`0`6````K]T!`!<```#&
MW0$`%@```-[=`0`3````]=T!`!,````)W@$`'````!W>`0`;````.MX!`"``
M``!6W@$`/P```'?>`0`9````M]X!`!@```#1W@$`%P```.K>`0`6`````M\!
M`!(````9WP$`'````"S?`0`;````2=\!`!,```!EWP$`$P```'G?`0`P````
MC=\!`!L```"^WP$`'````-K?`0!"````]]\!`!\````ZX`$`!0```%K@`0`4
M````8.`!`!D```!UX`$`+0```(_@`0`C````O>`!`!$```#AX`$`(0```//@
M`0`F````%>$!`"4````\X0$`'0```&+A`0`0````@.$!`!L```"1X0$`(P``
M`*WA`0`<````T>$!`",```#NX0$`'````!+B`0`B````+^(!`!H```!2X@$`
M'P```&WB`0!!````C>(!`"(```#/X@$`)P```/+B`0`G````&N,!`"````!"
MXP$`(````&/C`0`C````A.,!`"D```"HXP$`(@```-+C`0`C````]>,!``T`
M```9Y`$`%P```"?D`0`8````/^0!``0```!8Y`$`"````%WD`0`*````9N0!
M`!0```!QY`$`!@```(;D`0`5````C>0!``0```"CY`$`"P```*CD`0`'````
MM.0!``8```"\Y`$`!0```,/D`0`3````R>0!``8```#=Y`$`"````.3D`0`&
M````[>0!``8```#TY`$`"@```/OD`0`0````!N4!`!H````7Y0$`$````#+E
M`0`1````0^4!``H```!5Y0$`&````&#E`0`%````>>4!`#D```!_Y0$`%@``
M`+GE`0`1````T.4!`!$```#BY0$`#@```/3E`0`+`````^8!`!(````/Y@$`
M+P```"+F`0`(````4N8!``@```!;Y@$`)````&3F`0`2````B>8!``\```"<
MY@$`!@```*SF`0`,````L^8!`%X```#`Y@$`"0```!_G`0`%````*><!`"0`
M```OYP$`"@```%3G`0`0````7^<!``D```!PYP$`%@```'KG`0`-````D><!
M`!,```"?YP$`&````+/G`0`C````S.<!`"<```#PYP$`"@```!CH`0`#````
M(^@!``H````GZ`$`(@```#+H`0`'````5>@!``,```!=Z`$`$0```&'H`0`2
M````<^@!``<```"&Z`$`!0```([H`0`'````E.@!`"H```"<Z`$`#0```,?H
M`0`2````U>@!``H```#HZ`$`$P```//H`0`7````!^D!``P````?Z0$`#@``
M`"SI`0`.````.^D!``X```!*Z0$`!````%GI`0`1````7ND!`$,```!PZ0$`
M!@```+3I`0`%````N^D!``4```#!Z0$`)P```,?I`0`6````[^D!`#0````&
MZ@$`%0```#OJ`0`.````4>H!`!,```!@Z@$`#P```'3J`0`0````A.H!``\`
M``"5Z@$`'@```*7J`0`?````Q.H!`#4```#DZ@$`*P```!KK`0`F````1NL!
M``@```!MZP$`"````';K`0`+````?^L!``L```"+ZP$`$0```)?K`0`$````
MJ>L!``T```"NZP$`*@```+SK`0`-````Y^L!``T```#UZP$`)@````/L`0!1
M````*NP!`!T```!\[`$`#0```)KL`0`(````J.P!``@```"Q[`$`#@```+KL
M`0`.````R>P!`!4```#8[`$`"0```.[L`0`"````^.P!``T```#[[`$`(P``
M``GM`0`&````+>T!``4````T[0$`"0```#KM`0`+````1.T!``D```!0[0$`
M"0```%KM`0`4````9.T!``X```!Y[0$`!@```(CM`0`(````C^T!``\```"8
M[0$`!````*CM`0`%````K>T!`&L```"S[0$`#````!_N`0`/````+.X!`"``
M```\[@$`!P```%WN`0`%````9>X!`"H```!K[@$`,0```);N`0`1````R.X!
M``H```#:[@$``P```.7N`0`9````Z>X!``H````#[P$`"0````[O`0`J````
M&.\!`!X```!#[P$`*0```&+O`0`H````C.\!`!L```"U[P$`*P```-'O`0`/
M````_>\!`!H````-\`$`!0```"CP`0`'````+O`!``T````V\`$`!0```$3P
M`0`)````2O`!`!,```!4\`$`%@```&CP`0`&````?_`!`%D```"&\`$`'@``
M`.#P`0`0````__`!`!8````0\0$`)````"?Q`0!F````3/$!`!@```"S\0$`
M!P```,SQ`0`?````U/$!`#````#T\0$`"````"7R`0`&````+O(!`!X````U
M\@$`!0```%3R`0`*````6O(!`"X```!E\@$`+0```)3R`0`[````PO(!`!,`
M``#^\@$`!@```!+S`0`U````&?,!`"0```!/\P$`5@```'3S`0`?````R_,!
M`!P```#K\P$`.0````CT`0`"````0O0!`!D```!%]`$`#````%_T`0`'````
M;/0!`!(```!T]`$`$0```(?T`0`A````F?0!``<```"[]`$`%````,/T`0`&
M````V/0!``@```#?]`$`"P```.CT`0`'````]/0!``H```#\]`$`"P````?U
M`0`L````$_4!`!@```!`]0$`!P```%GU`0`0````8?4!`!````!R]0$`#P``
M`(/U`0`)````D_4!``D```"=]0$`#````*?U`0`-````M/4!``H```#"]0$`
M"0```,WU`0`%````U_4!``8```#=]0$`"@```.3U`0`(````[_4!`!,```#X
M]0$`&P````SV`0`>````*/8!`$@```!']@$`%````)#V`0`:````I?8!`!8`
M``#`]@$`$````-?V`0`3````Z/8!`!8```#\]@$`(````!/W`0`'````-/<!
M`!8````\]P$``P```%/W`0`,````5_<!``<```!D]P$`!0```&SW`0`%````
M<O<!`!L```!X]P$`"0```)3W`0`0````GO<!`!(```"O]P$`,P```,+W`0`N
M````]O<!`"(````E^`$`)````$CX`0`7````;?@!`!\```"%^`$`&0```*7X
M`0`'````O_@!``0```#'^`$`#````,SX`0`,````V?@!`!(```#F^`$`$0``
M`/GX`0`&````"_D!`!X````2^0$`"0```#'Y`0`)````._D!`"L```!%^0$`
M)0```''Y`0`/````E_D!``4```"G^0$`#````*WY`0`)````NOD!`!$```#$
M^0$`$````-;Y`0`*````Y_D!``D```#R^0$`!P```/SY`0`%````!/H!``<`
M```*^@$`!P```!+Z`0`$````&OH!``,````?^@$`'````"/Z`0`=````0/H!
M`%D```!>^@$`+0```+CZ`0!$````YOH!`!L````K^P$`/0```$?[`0`/````
MA?L!`$````"5^P$`*0```-;[`0`>`````/P!`!X````?_`$`(P```#[\`0`>
M````8OP!`#8```"!_`$`#0```+C\`0`P````QOP!`!D```#W_`$`%0```!']
M`0`5````)_T!``\````]_0$`%````$W]`0`5````8OT!`"$```!X_0$`/0``
M`)K]`0`^````V/T!`$$````7_@$`/@```%G^`0`_````F/X!`#T```#8_@$`
M;0```!;_`0`>````A/\!`!8```"C_P$`&@```+K_`0`E````U?\!``\```#[
M_P$`$`````L``@`[````'``"`"L```!8``(`(@```(0``@`M````IP`"``H`
M``#5``(`*0```.```@`K````"@$"``4````V`0(`)@```#P!`@`6````8P$"
M``X```!Z`0(`#@```(D!`@`7````F`$"``@```"P`0(`"@```+D!`@`,````
MQ`$"``X```#1`0(`+P```.`!`@`/````$`("``\````@`@(`"@```#`"`@`F
M````.P("``@```!B`@(`!````&L"`@`0````<`("``X```"!`@(`)@```)`"
M`@`+````MP("`#4```##`@(``@```/D"`@`(````_`("`!<````%`P(`'0``
M`!T#`@`,````.P,"``<```!(`P(`!@```%`#`@`1````5P,"`"L```!I`P(`
M#0```)4#`@`<````HP,"``0```#``P(`C````,4#`@`W````4@0"`",```"*
M!`(`'@```*X$`@`J````S00"`'<```#X!`(`%P```'`%`@!(````B`4"`"<`
M``#1!0(`$@```/D%`@`&````#`8"``X````3!@(`%````"(&`@`)````-P8"
M`!$```!!!@(`#@```%,&`@`>````8@8"`!4```"!!@(`!0```)<&`@`0````
MG08"`!$```"N!@(`&@```,`&`@`R````VP8"`!4````.!P(`%0```"0'`@`8
M````.@<"`!,```!3!P(`'P```&<'`@`'````AP<"`!<```"/!P(`"P```*<'
M`@`4````LP<"`!0```#(!P(`%@```-T'`@`0````]`<"`!8````%"`(`&```
M`!P(`@`+````-0@"``D```!!"`(`!0```$L(`@`=````40@"``8```!O"`(`
M#P```'8(`@`(````A@@"`!(```"/"`(`!@```*((`@`D````J0@"`!0```#.
M"`(`,P```.,(`@`5````%PD"``<````M"0(`"````#4)`@`>````/@D"``L`
M``!="0(`&P```&D)`@`'````A0D"`",```"-"0(`!P```+$)`@`(````N0D"
M`"0```#""0(`.P```.<)`@`+````(PH"`"4````O"@(`*````%4*`@`B````
M?@H"``T```"A"@(`&@```*\*`@`0````R@H"``0```#;"@(`#@```.`*`@`.
M````[PH"``<```#^"@(`#@````8+`@`/````%0L"``@````E"P(`!0```"X+
M`@`)````-`L"`!T````^"P(`)@```%P+`@`_````@PL"`"@```##"P(`)0``
M`.P+`@`?````$@P"`#L````R#`(`'@```&X,`@`D````C0P"`"H```"R#`(`
M,@```-T,`@!=````$`T"`"4```!N#0(`#0```)0-`@`(````H@T"``H```"K
M#0(`"@```+8-`@`1````P0T"`!8```#3#0(`1P```.H-`@`E````,@X"`!H`
M``!8#@(`.````',.`@!`````K`X"``D```#M#@(`)@```/<.`@`+````'@\"
M`!0````J#P(`)P```#\/`@`%````9P\"``P```!M#P(`&0```'H/`@`4````
ME`\"``P```"I#P(`#@```+8/`@`.````Q0\"``\```#4#P(`$````.0/`@`/
M````]0\"`!L````%$`(`&@```"$0`@`U````/!`"``L```!R$`(`&@```'X0
M`@`%````F1`"`!4```"?$`(`'0```+40`@`-````TQ`"``4```#A$`(`'@``
M`.<0`@`7````!A$"``,````>$0(`#````"(1`@`0````+Q$"``4```!`$0(`
M#@```$81`@`(````51$"``\```!>$0(`!0```&X1`@`'````=!$"`!8```!\
M$0(`$````),1`@`B````I!$"`$D```#'$0(`/P```!$2`@!0````41("`!<`
M``"B$@(`)P```+H2`@`)````XA("`#(```#L$@(`*P```!\3`@`1````2Q,"
M``D```!=$P(`#````&<3`@`0````=!,"`#(```"%$P(`!@```+@3`@`-````
MOQ,"`!0```#-$P(`#@```.(3`@`5````\1,"`!,````'%`(`#0```!L4`@!<
M````*10"``H```"&%`(`)0```)$4`@`5````MQ0"`!8```#-%`(`D````.04
M`@`L````=14"`"(```"B%0(`)@```,45`@`^````[!4"`$$````K%@(`.P``
M`&T6`@`.````J18"``4```"X%@(`$P```+X6`@`<````TA8"`!@```#O%@(`
M(`````@7`@`(````*1<"`!,````R%P(`&P```$87`@`'````8A<"`!\```!J
M%P(`%P```(H7`@`0````HA<"``0```"S%P(`$@```+@7`@`3````RQ<"`!0`
M``#?%P(`!@```/07`@`'````^Q<"`!,````#&`(`#@```!<8`@`/````)A@"
M`!$````V&`(`$0```$@8`@`&````6A@"``<```!A&`(`*````&D8`@`D````
MDA@"`"````"W&`(`"````-@8`@`/````X1@"``8```#Q&`(`&````/@8`@`I
M````$1D"`!P````[&0(`*0```%@9`@`*````@AD"`!@```"-&0(``P```*89
M`@`6````JAD"``@```#!&0(``P```,H9`@`2````SAD"`!0```#A&0(`"P``
M`/89`@`8`````AH"`",````;&@(`%P```#\:`@`&````5QH"``H```!>&@(`
M%````&D:`@`7````?AH"``P```"6&@(`!@```*,:`@`,````JAH"``H```"W
M&@(`%0```,(:`@!Y````V!H"`!\```!2&P(`+P```'(;`@`L````HAL"`!0`
M``#/&P(`"````.0;`@`'````[1L"`!<```#U&P(`%@````T<`@`:````)!P"
M`!D````_'`(`"@```%D<`@`7````9!P"`!@```!\'`(`(@```)4<`@`=````
MN!P"`!(```#6'`(`)0```.D<`@`1````#QT"`"8````A'0(`,````$@=`@`S
M````>1T"`!@```"M'0(`%P```,8=`@`S````WAT"`#(````2'@(`@P```$4>
M`@`S````R1X"`"@```#]'@(`'P```"8?`@`E````1A\"`"(```!L'P(`+```
M`(\?`@`K````O!\"`#@```#H'P(`)P```"$@`@`>````22`"`"L```!H(`(`
M5@```)0@`@`^````ZR`"`"H````J(0(`(P```%4A`@`G````>2$"`!\```"A
M(0(`%````,$A`@`+````UB$"``@```#B(0(`"0```.LA`@`*````]2$"`!4`
M````(@(`"P```!8B`@`[````(B("`"D```!>(@(`-P```(@B`@`6````P"("
M``8```#7(@(`10```-XB`@!5````)","`#0```!Z(P(`G````*\C`@`+````
M3"0"`#<```!8)`(`+P```)`D`@`2````P"0"``P```#3)`(`"````.`D`@`3
M````Z20"`$0```#])`(`#````$(E`@`0````3R4"``\```!@)0(`%@```'`E
M`@`3````AR4"`%@```";)0(`2````/0E`@`H````/28"`!0```!F)@(`(@``
M`'LF`@`B````GB8"`"P```#!)@(`(@```.XF`@`K````$2<"`!\````])P(`
M%0```%TG`@`'````<R<"`!````![)P(`%````(PG`@`-````H2<"``L```"O
M)P(`40```+LG`@`,````#2@"`!X````:*`(`$0```#DH`@`?````2R@"``D`
M``!K*`(`!0```'4H`@`8````>R@"``D```"4*`(`"0```)XH`@`'````J"@"
M``<```"P*`(`"0```+@H`@`2````PB@"`!P```#5*`(`#P```/(H`@`?````
M`BD"`!`````B*0(`"````#,I`@`-````/"D"`!8```!**0(`)@```&$I`@`+
M````B"D"`!,```"4*0(`"@```*@I`@`8````LRD"`"8```#,*0(`#````/,I
M`@`B`````"H"`"L````C*@(`"P```$\J`@`(````6RH"`"$```!D*@(`#0``
M`(8J`@`9````E"H"`!L```"N*@(`/````,HJ`@`4````!RL"`!8````<*P(`
M$@```#,K`@`%````1BL"``D```!,*P(`"````%8K`@`)````7RL"``H```!I
M*P(`%````'0K`@`'````B2L"`!````"1*P(`"@```*(K`@`(````K2L"``P`
M``"V*P(`(0```,,K`@`,````Y2L"``(```#R*P(`(P```/4K`@`%````&2P"
M``H````?+`(`>@```"HL`@`*````I2P"``@```"P+`(`*@```+DL`@`J````
MY"P"`"$````/+0(`.@```#$M`@`J````;"T"`!H```"7+0(`'0```+(M`@`N
M````T"T"`"T```#_+0(`70```"TN`@`C````BRX"`#,```"O+@(`+P```.,N
M`@`E````$R\"``8````Y+P(`#0```$`O`@`(````3B\"``D```!7+P(`!0``
M`&$O`@`(````9R\"`!(```!P+P(`"@```(,O`@`)````CB\"``L```"8+P(`
M"P```*0O`@`:````L"\"``@```#++P(`"0```-0O`@`5````WB\"``H```#T
M+P(`"@```/\O`@`%````"C`"`"X````0,`(`)@```#\P`@`8````9C`"``<`
M``!_,`(`$@```(<P`@`)````FC`"``\```"D,`(`,P```+0P`@`D````Z#`"
M``@````-,0(`&````!8Q`@`8````+S$"``8```!(,0(`!@```$\Q`@`-````
M5C$"`!P```!D,0(`!@```($Q`@`)````B#$"``L```"2,0(`'````)XQ`@`+
M````NS$"``T```#',0(`*@```-4Q`@`?`````#("`!@````@,@(`!@```#DR
M`@`+````0#("`!````!,,@(`#0```%TR`@`#````:S("``X```!O,@(`"```
M`'XR`@`=````AS("`"\```"E,@(`,````-4R`@`J````!C,"`"X````Q,P(`
M+@```&`S`@!1````CS,"`"$```#A,P(`+0````,T`@`J````,30"`"X```!<
M-`(`'@```(LT`@".````JC0"`!8````Y-0(`8P```%`U`@`X````M#4"`"<`
M``#M-0(`80```!4V`@!I````=S8"`"$```#A-@(`30````,W`@`G````43<"
M`#P```!Y-P(`1P```+8W`@`>````_C<"`!@````=.`(`(P```#8X`@#]`0``
M6C@"`!T```!8.@(`-@```'8Z`@`=````K3H"`$D```#+.@(`H````!4[`@`T
M````MCL"`"D```#K.P(`1P```!4\`@!:````73P"`&0```"X/`(`,@```!T]
M`@`@````4#T"`!X```!Q/0(`-````)`]`@`<````Q3T"`!\```#B/0(`)```
M``(^`@`@````)SX"`"8```!(/@(`+P```&\^`@`:````GSX"`!8```"Z/@(`
M,0```-$^`@`J`````S\"`"0````N/P(`/````%,_`@`O````D#\"`!H```#`
M/P(`,@```-L_`@"_````#D`"`'$```#.0`(`.P```$!!`@`Z````?$$"`#(`
M``"W00(`*0```.I!`@!'````%$("`&T```!<0@(`7P```,I"`@!>````*D,"
M`"L```")0P(`.@```+5#`@`W````\$,"`#(````H1`(`)0```%M$`@`P````
M@40"`#````"R1`(`)````.-$`@`S````"$4"`$X````\10(`9@```(M%`@`K
M````\D4"`$T````>1@(`4P```&Q&`@`N````P$8"`#0```#O1@(`&@```"1'
M`@`X````/T<"`#4```!X1P(`20```*Y'`@`G````^$<"`"<````@2`(`)```
M`$A(`@!X````;4@"`&T```#F2`(`=P```%1)`@#.````S$D"`!P```";2@(`
M+````+A*`@`V````Y4H"`"X````<2P(`4````$M+`@`<````G$L"`$````"Y
M2P(`(0```/I+`@`_````'$P"``4```!<3`(`R````&),`@!&````*TT"`"(`
M``!R30(`,P```)5-`@`^````R4T"`"<````(3@(`'````#!.`@!3````34X"
M`"P```"A3@(`"0```,Y.`@`6````V$X"``,```#O3@(`%@```/-.`@`,````
M"D\"``T````73P(`"P```"5/`@`'````,4\"``T````Y3P(`!P```$=/`@!U
M````3T\"``(```#%3P(`%@```,A/`@`$````WT\"``<```#D3P(`!@```.Q/
M`@`%````\T\"``4```#Y3P(`%0```/]/`@`*````%5`"`!(````@4`(`#P``
M`#-0`@`"````0U`"``<```!&4`(`"P```$Y0`@`2````6E`"``T```!M4`(`
M&0```'M0`@`&````E5`"`!D```"<4`(`"@```+90`@`#````P5`"`%L```#%
M4`(`!````"%1`@`&````)E$"``<````M40(`)P```#51`@!,````75$"`$8`
M``"J40(`1P```/%1`@`J````.5("`"X```!D4@(`,0```)-2`@`=````Q5("
M`"(```#C4@(`'`````93`@`R````(U,"`"H```!64P(`)````(%3`@`F````
MIE,"`"<```#-4P(`20```/53`@`N````/U0"`"L```!N5`(`'@```)I4`@`I
M````N50"`"H```#C5`(`'P````Y5`@`C````+E4"`"$```!250(`&0```'15
M`@`B````CE4"`"P```"Q50(`,@```-Y5`@`S````$58"`"<```!%5@(`'0``
M`&U6`@`D````BU8"`"D```"P5@(`'0```-I6`@`G````^%8"`#@````@5P(`
M.P```%E7`@`9````E5<"`",```"O5P(`.@```--7`@`B````#E@"`"8````Q
M6`(`)````%A8`@`E````?5@"`!P```"C6`(`)````,!8`@`P````Y5@"`!X`
M```660(`,0```#59`@`A````9UD"`#8```")60(`"0```,!9`@`0````RED"
M`"(```#;60(`1P```/Y9`@`L````1EH"``P```!S6@(`#P```(!:`@`7````
MD%H"`!(```"H6@(`$````+M:`@`G````S%H"``8```#T6@(`"@```/M:`@`E
M````!EL"`"@````L6P(`&P```%5;`@`H````<5L"`!P```":6P(`#P```+=;
M`@#T````QUL"`!4```"\7`(`(````-)<`@`7````\UP"``D````+70(`%P``
M`!5=`@`B````+5T"`!T```!070(`'@```&Y=`@`)````C5T"`#X```"770(`
M#P```-9=`@`6````YET"``<```#]70(`&P````5>`@`1````(5X"`$X````S
M7@(`$````()>`@`B````DUX"`!P```"V7@(`&````-->`@`C````[%X"`&$`
M```07P(`)P```')?`@`0````FE\"`"<```"K7P(`$0```--?`@`2````Y5\"
M`!@```#X7P(`"P```!%@`@`=````'6`"`"D````[8`(`'P```&5@`@`+````
MA6`"`#,```"18`(`/0```,5@`@`'`````V$"`!,````+80(`!P```!]A`@`'
M````)V$"``D````O80(`20```#EA`@`/````@V$"``8```"380(`#0```)IA
M`@`0````J&$"`!8```"Y80(`"P```-!A`@`,````W&$"``<```#I80(`$0``
M`/%A`@`1`````V("``\````58@(`%@```"5B`@`<````/&("`!<```!98@(`
M*````'%B`@`4````FF("`!@```"O8@(`#````,AB`@`.````U6("`"P```#D
M8@(`#@```!%C`@`V````(&,"`!H```!78P(`$````')C`@`.````@V,"``,`
M``"28P(`%````)9C`@`;````JV,"``,```#'8P(`"0```,MC`@`'````U6,"
M``<```#=8P(`"@```.5C`@`.````\&,"``X```#_8P(`&P````YD`@`<````
M*F0"``X```!'9`(`-````%9D`@`:````BV0"`!4```"F9`(`&0```+QD`@`-
M````UF0"`#(```#D9`(`"0```!=E`@`7````(64"`%8````Y90(`%0```)!E
M`@`9````IF4"``H```#`90(`!````,ME`@`$````T&4"`!8```#590(`%0``
M`.QE`@`%`````F8"``8````(9@(`"@````]F`@`-````&F8"``4````H9@(`
M%````"YF`@`5````0V8"`!8```!99@(`$@```'!F`@`<````@V8"`!\```"@
M9@(`%````,!F`@`_````U68"`#(````59P(`*0```$AG`@`@````<F<"`!P`
M``"39P(`(P```+!G`@`H````U&<"`"````#]9P(`%0```!YH`@`"````-&@"
M``0````W:`(`#0```#QH`@`&````2F@"``4```!1:`(`!````%=H`@`1````
M7&@"`'@```!N:`(`)````.=H`@`]````#&D"`"T```!*:0(`+P```'AI`@`C
M````J&D"`$@```#,:0(`-P```!5J`@`L````36H"`#4```!Z:@(`&0```+!J
M`@".````RFH"`"(```!9:P(`5````'QK`@`A````T6L"`%<```#S:P(`+@``
M`$ML`@`U````>FP"`"\```"P;`(`*0```.!L`@`X````"FT"`"X```!#;0(`
M0````')M`@`S````LVT"`"\```#G;0(`/P```!=N`@`=````5VX"`"4```!U
M;@(`*````)MN`@`U````Q&X"`$T```#Z;@(`$````$AO`@`;````66\"`!0`
M``!U;P(`=0```(IO`@`*`````'`"`-8````+<`(`A0```.)P`@!^````:'$"
M`#@```#G<0(`>@```"!R`@`<````FW("`#H```"X<@(`-P```/-R`@`J````
M*W,"`!(```!6<P(`)0```&ES`@`D````CW,"`$8```"T<P(`(@```/MS`@`<
M````'G0"`%D````[=`(`+P```)5T`@`F````Q70"``L```#L=`(`!0```/AT
M`@`&````_G0"``@````%=0(`(@````YU`@`.````,74"`"````!`=0(`*```
M`&%U`@`+````BG4"``P```"6=0(`#P```*-U`@`*````LW4"``L```"^=0(`
M"0```,IU`@`&````U'4"``D```#;=0(`"@```.5U`@`)````\'4"`!8```#Z
M=0(`#@```!%V`@`&````('8"``T````G=@(`#@```#5V`@`4````1'8"`!,`
M``!9=@(`$@```&UV`@`'````@'8"``X```"(=@(`$0```)=V`@`3````J78"
M``@```"]=@(`#````,9V`@`6````TW8"``T```#J=@(`"@```/AV`@`4````
M`W<"``8````8=P(`!P```!]W`@`E````)W<"`"(```!-=P(`#@```'!W`@`0
M````?W<"`!(```"0=P(`)````*-W`@`1````R'<"``D```#:=P(`%0```.1W
M`@`'````^G<"``0````">`(`(P````=X`@`+````*W@"``(````W>`(`%0``
M`#IX`@`(````4'@"`!$```!9>`(`$0```&MX`@`$````?7@"`$D```"">`(`
M`P```,QX`@`2````T'@"``<```#C>`(`+P```.MX`@`O````&WD"``L```!+
M>0(`"````%=Y`@`<````8'D"``4```!]>0(`'0```(-Y`@`)````H7D"`"0`
M``"K>0(`&@```-!Y`@`@````ZWD"``L````,>@(`#````!AZ`@`,````)7H"
M``T````R>@(`#@```$!Z`@`6````3WH"`"D```!F>@(`"@```)!Z`@`?````
MFWH"``4```"[>@(``P```,%Z`@`!``````````````!"`0``10``````````
M```````````````$!P``B0(``,T%````````P``````````]`0``-`<`````
M``#S`@````8``/T%``#;!0```````#`!```/!P``C0,```````#!`0``5P0`
M`#0"````````/0@``#(&``#B`@`````````````<!P````````````!*"```
M9P4```````"6`@``W@<`````````````FP(``,@'```K`0```````#8%````
M````SP8``.$!``#'!```[04``-<&``!J!```:@$```````"4!P```````#T`
M````````\0,``'0"````````,@<``$D(````````.P,``)4&``#.!0``````
M`%(%``!&!P``"08`````````````J`,``+@"```)!0```````,(%``"O!0``
M`P<``,P````.!`````````````!"`@```````%P#``"F!P``70<``(<&````
M````%P````````#1`0``#0<``#L&``#]`@``<@,```````!L!@``@@4``/H$
M```;"```!P8``+`"``#H`@``>P8``(H$``!0!P``O`(``-D!```B!```#P4`
M`$<"``!X`P``X`8``%`#``"]`@````,``*@"````````C08````````-````
M`````$H!`````````````)`!``"1````+`@``,X!``"+!0``P@0```,#``"+
M````````````````````K`(``!\```!,`0```````!T&``!T!P```````+\#
M``#E`0``YP8`````````````-@,``.L#`````````````"L%``"^!P``>@0`
M`%$'``#.`P``@P(``+@#```F"`````````````!1`@``FP$``.<"````````
MI0$``)8!```2`P``````````````````WP0``*D'``#@`0``I`<``-X#``#B
M!0``>@4```````!S!0``O`$``*P&````````MP4``)H```"1!0``8@<`````
M``#X!```2P0``/8"``!?"```-`8``"(%````````)@8`````````````````
M`*,'``";````2P4```````#;`P``.P$``%<"``!K!```=@$``&`'``"Y`@``
MQP<``!D!```I!@``A`8```````#G!P``OP$``+D#````````Y`0``.X'``"\
M`P``JP(``````````````````)P!```7!@```````%,(```'!```$`$```8'
M``#U!@``6`0``-L"``#"````H@4```````#X!P``]`,``"@%````````````
M`",!``!?`P```````-4&``!:`P``C`,``#D&``#E`@``)P$``*X&``!'!0``
M/@4``-T%```^!`````````````"Y!P``0@```&`&``!`!```,P0``&,'```\
M"```6`8``%D!````````P`8``.4'``!9!P`````````````L!```;P```%4'
M``!1!0``BP8``#4&````````^`$``-\!```=!P``NP0``/4"````````A`,`
M`%,`````````%`(``#T"```&!@``K08```T(``"H!@```````#4$````````
MEP4``%T!```[`@````````P#```!`@``M`<``%<```"3!@``G`8``&<(``#&
M!@```````'\$```Q!@``D`<``,(#````````)0<``&H"``!N!@``P@(``.@`
M``#7!````````.<$``"_````U0$```````!_`0``0P```%X$````````GP$`
M`%0"```Q`@```@$``(\'``#]!```H0```(4!``#G`P``&04``"X%``#(!```
M_P4``,D&``#N`P``X04``,L'``#$`0``B````````````````````!0#```(
M!P``8`4``,X`````````VP<``````````````````(,&````````'P4``'8#
M``!O"```.@<``/8$```@````&@<``(@"``#?!0``5`8``*$$````````@`$`
M`-$```#R!0``Z`8``,P"``#)`P``]@<``,$'``#8!```'00```X#```Z`@``
M"P(```````"J`P``?`$```0(``#/!0``(`4``.D```!/`P``"@8````````"
M!0``<04`````````````(`<``+8&````````H08``.\%````````````````
M``"4!```X`,``+H$````````$0@````````E````@@(``*(````?!P``>`(`
M`#0```#X!@``=`4``#P$``"Y!```Y@8``*L!```V!````````,<%``!3!P``
M]0```-T$```@`P``1P$``)T````#`@``L@(``)(`````````5P$``,0`````
M````-@$``%D(```9!````````%L(``!(!```$@$``.\`````````-P@``'D`
M```J`P```````&L#```C````3`<``!`&``"%`P``"````)<!``!E!```+P8`
M`+@$````````'04``(X!``!K!P``=````,8'```:`0``(P8``(('````````
M<@<`````````````90,``"X(``!P!@```````#<"```8!0```````&<#``!U
M!```30```)@"``"R!@```````#D````+!0``$P(``$0'``!6`P``B00``%4(
M``````````````````"$!P```````'<#`````````````*('``!.`P``````
M``````#9`@``KP,``),"``#S!0``2`<```````""!@``@`8`````````````
M<````#`%``"2`0``#0$``%4#````````#P@````````.!0```````$($``#_
M!P``ZP8```````!$!```10,``+`!````````!0,```\&``!'`P``:04`````
M```V`@``AP$`````````````!P<``.P!``!#`0``B`<``/(!````````=`,`
M`-,#```H`@```````-0!````````]`4``-L$````````6`@``'4#````````
M`````!T"``"S!@````````````#O`@```````$(%```V"```(0(```````#=
M`````0@``+@&``"<!P``O````$`&`````````````.<%```+`0``I@4``%L%
M``"/!```6P$``*D#```S`P``70(````````7!P```````"@````I!```\04`
M`&@```#H!0``$`0``&H#``#+!```I`,````````F`@``9P(```,&```+!```
MJ0```)H%``!\!````````*,$```2!`````````````!%!0````````H$```_
M!```!@@``+8%````````S00``&`(````````````````````````/`8``"$`
M````````X`(``+$```"P`P``6`$``(8#````````T0,``+<!``!^`0``Y@``
M`.P%``!(!0``M@$``'$`````````J`<``%,$````````;`0``"D````/````
M3P4```````#D`0``U04```````#X````V`4``+<````:"```'P@```````!L
M!0``S`$``)4'```M`@``_P$``!@```!:`0```````(4"````````;P0``%($
M``"=!P``0@8``)T"``!H`P```````(0$``"M````2P8`````````````C`(`
M``,$``!A`0```````.(#```;!@``3P$``"4%``!H!0``6`4``'D'````````
MY@0``)`&```%!P``CP(``#X!``#Q!@``]0<``````````````````%<%````
M````P@<``-`$```]!0``F0$```\"`````````````,T!````````````````
M```Z!@``?@,`````````````L@,``*`$```>!@``I@0``)`"``!F`0``````
M`*8&``"A!P``+P<`````````````<@0``*T!```O`0``JP0``%0(``!'````
MJ@(``+8#``!]!```60(``"P!```J!@``GP<``(0"````````3````"\"```A
M`0``30<````````*`@``:0,``"P&``":`@```````"$%``!A````#08``"0#
M``#,!```$P$`````````````?@(``&4(``"R!```?04``,,'``!$`0``U@(`
M`!0%``!V!P``W`<``&("``!K``````````````#S!@``\`4``"8$````````
M*04``$X%``!."````````"T(``#M!P``E0(``(\%``!Y!@````<``%8'``"F
M`@``E0,``(8&``"R`0``'@<```H(``#Y!0``M0<``.P```!6`0```````)``
M``!A"```#@<``%H(```;!P``+P```$`'``"1`P``4@<``*P$```8`P``,`(`
M`/<!``````````````````#=`0``UP,`````````````%0@``.D'``"9`@``
M'`,``'P&```,!P```P$``/T'``!)`P``RP(```T"``!Q`P```````$`"````
M````\`(``+\&``#4`P``?`4``/8#``#B````G0$``'4&``"8`P``(00``+X$
M``!7"```+P4``&4&``">````9`4``',```#U`P``^P4``-$$``!F`P``````
M````````````*@$``,4$````````!@```-P$`````````````#D#```C!```
M`````-X"```)`P```````&(#````````U````/(#``">`P``<0<``+4#````
M````_P0`````````````8`(``'\%``!Z`P``[`8``*D!````````800``/,'
M``"S`P``[@```&($````````:P@``(`$````````G`,```$%````````B@$`
M``````"\!0``Y08``#@#```W`P``/````%H$``#:!```````````````````
M@@0``(\&``#[!P``)`$``+8$```7!```F@<```D```!'!```HP(``$L```"(
M`0``U@0`````````````V0,``&X"````````UP<``````````````````"8#
M``!0!`````````````!U!P``3P```*H!``"`````,P$``&`!```%!0``.P0`
M`&@&```7"```[`,``$T(``"0`P``)@$``*@%``".`P``&P0``/T&``!L````
ML`<``(X````+````:P(``%0#``!<!```D00``!4&``"7`@```````)$"``!>
M````V@<``$,#````````4P$``!H&````````*@(``!,'``!?`0``A0<``/<$
M````````_P8```````#)!P``;P$``*X#```4!```(`(`````````````5```
M`!T!``!M`````````.D"``!G````1@(``-\"```8`0``6@8``$``````````
MD`4``%4%``#N`0``=@```%D%``#I`P```````"("```%````?`(``-<%``!2
M`````````$@!```$!@``@P0``%````#/````M`4````````>`0``-P<``!$'
M``#[!@``PP4``-4```#C````*`<```@%````````X`4```````#+`P``?@<`
M``('```?`P``SP(``#L````>`@``100``(D&``##`P``/@@```````#8`P``
M``````````#O!```E@<```````!J!P``&`@``````````````````&D```"M
M`@```````/`'``#B`0``7@<``%$&````````6@4``/P#````````9P<``-D&
M``"T````/P4``&P'``"1`0``#@(``.($``#0````-`,``#L(```S!@``````
M`#D(``#T!@``)0(``,T#``#J`0``5@8``)X%``!6!0``E`$``'L$``!;`@``
M%0```+<#```7`@```````*$#````````?0(```````"-!P``(@,``,8!``!F
M!@``^P```#T$``!S!@```````",'``"N!0`````````````3"```E@8``.H#
M``"Y!0```````%D``````````````!@$````````\0$`````````````````
M`'X`````````T@$```````#\!0``T`(``#($````````9@@``'@$````````
M&P```%P"````````8`,``/L"``"Y`0```0,``%(&```````````````````5
M!```'0@``$8```````````````````#U!0``4`8```````#X`@```````)0&
M``"7`P``AP`````````T!0```````-P%````````Y@(```````!F`@``#`0`
M`!`%``"9!P````````````"O!```;`$``/0$````````;P8``$8%``#]````
MK`,``'(%``#F`P``-0(````````%`0````````\$``#-`@``Y0```"P'````
M``````````````"[!P``M@```%P'``#)!0``R@0``),!``"N!```;P(``"X$
M````````L0(```````"7````F00``*<%``!*!P``$@(```````!9!```4P(`
M`/\```#[`P``'`4``#$!``!G!````````/,!``!4!```^P0``&(!````````
M`````*L&```P!@``J````$@#``!/`@``U`8````````D"```-0```*D%````
M````:@@``!,%``!;````G`4``%\"```X`````````*,&``![`@```````'T`
M`````````@,``'D%````````+@$`````````````004``)X!``!I"```U@``
M`/($``"K````R`,```````#<````;P,``"$&``"J!```L````&L&```5`@``
M/`$``)8#``#Y!@``Z`<``#`(```%`@```````"L#```""```]````%,&````
M````00```'<!```,`@```````+H%````````3@$``!4#````````9P8`````
M```9"````````!$```"C`P```````.H&``#1`@``40```(8'``#G`0``+@8`
M`+T`````````2P<``(`#````````SP0``.H"````````)@4``#<$``#4`@``
M<0$``.0#````````Y@<``+P&``!J````!`,``"<"````````Y0,``"H%```F
M!P``7P0``"\(```&`P``=0```)8```#?!P``R@$```````!%!P``>`8`````
M```^`P``Q`8``(X&``"L`````````"`(``!=````EP8`````````````^@8`
M`/P"````````%P4````````:````50(`````````````W@4```````!A!P``
ML`4``/T#``"E`````````$,$````````IP8```P&```2!@``IP0``"<`````
M`````````(`'``"-````Q04``*X"```L````508```````!#`@``S@8``*4&
M``#$!P``)`<``*P!``!*!0``[@(``&4"``#J!P````````````#Q!```````
M``````#;`0``,0,``+(```!O!0``R@<``)@'``!%`@``1P@```````"Z!P``
M`````"(!`````````````$4&``"+`0``&0(``-@&``"#!P```````$X&````
M`````````)(&```(`P``^0,``$P#````````C@(````````6`P``\P``````
M```F````4P,``.,"``#/`P``DP,````````>!0``'@,``"D"````````*P0`
M`,$#``!\!P``704``#\"``#P!```N`<``$H&``!5````H0(````````*!P``
M`````)P$``"U`0``1@,``"H'`````````````(`%``!P!P```````'T&``!C
M`0```````+,'````````A@$````````@`0```````($$``"]!```$P8`````
M``#^!```DP<``,<"``#'````[0(``/`&``#T!P``E0$```````"F`P``Q@(`
M`.H```"(!0``)`0``,<&``````````````````"U````/P```((#``"$````
M`````+X#``"*`P``.P<``(4```#T`@``'`@``*L'``"$!0```````-,%```3
M!```[0,``&D!``!@````E`(``"L"``#K`0``!`(``%X"``"@`P``]P```'$&
M``"'`P```````*@!``"Z!@``N@,``#@&`````````````.P'````````T@,`
M`"$(``#W!P``B@4``"T%````````<`4``+L&``!-`@`````````````G`P``
M0P4``%T(```1`0```````&H&``!>`0````````````!&!```N`$``!0&```W
M!@``RP8``!H$````````.`0``*0$```S``````````````#I!```60,``.L`
M```?!```/`,``*4$```'`@``"`@`````````````=@(``)L$```D!0``G@8`
M`),$``!>"```C`<```````#A!@```````````````````````-,!``"Q`0``
M^@$``-P&``!4!P```````,$"````````70,``*<```"_`@``"`(``/<#``!]
M`0``'P$``.\'```_!P``700``*,!``"M`P```````/(```"G`@``*@@``,H"
M``"(!@``X@8``,D!``!<!@``[@8``%`"``"J!@```````*H%``"9````````
M`&,&``"L!0``CP$``&$#``"A`0``#@8``,4`````````````````````````
M`````*4%``"5````(0,````````X`@`````````````A!P``DP``````````
M````<00``!L%``""`0````(``&`$````````````````````````TP8``-8%
M``"Z````+0,``+T'````````````````````````&P(``+L#``!:````P`(`
M``````#*`P``K00```````!1"`````````````!/"`````````````#>````
MU@,``!D&````````,@$`````````````TP(``````````````````)<$``!M
M`P``,0@``,,`````````)P8``($```#C!```[@0``-\&``!_!@``!P,``.<`
M``!M`@``;0<``*H```!)!@``3`8``,@```#V````_@4``","```&!0``;`,`
M``````")!0```````$\'````````H`4``&0&``#A!```XP$````````)`@``
M`P@``'$(``!7!P``?P,```(&````````1`,``&T$```!!@``V@$``-H```"7
M!P```````.@#``#E!```[P$```````!("````````,`#```&`@``B0<``(4%
M````````.@$``$X'```C`P```````'H!```#````=P4```````!R`0``^@<`
M`)4%```<`@```````,4"``">!```;0@``%("``"!!@``.04````````<````
MU@<``"(&``"V!P``TP``````````````O@````D$``#&`P``A00``$$$```'
M````;@0``-D%``"8!@```````,X"`````````````&X'```_"```*0$`````
M``#+`0``4@,``,`!``"F`0``H@8`````````````V`(``(X%```C"```!`0`
M`/D"``"U!```T`8``%<&``!H!P``S@<````````."````````#D"````````
MY@4``$T%````````Y`(```````#-!@```````&\'````````>P```%(!``!?
M!@``<`@`````````````J@<````````8!@``50$`````````````]0$``!X`
M``!(!@````````````````````````````#3!```W0,``)\&``"[````````
M``````!F````O0$``"T&````````.P4``*D&``",!0``708``+X!``";!P``
MN``````````*!0``_`8```````!-!@```````+\%````````"@````````"?
M!0``T`<``````````````````(L$``"9!@``4@@``,(!``!`!0``[`(``$H#
M````````D08`````````````#00``*,```````````````````!.`@``.`4`
M`#((``#K`@````````````!I!@``;@$``',#````````Q0$``$$#``#[`0``
M>`<``+$'``":!````````'(`````````=P<```0!``#\!```;`@``'P`````
M````C````#0!``",`0``SP$``-@!```6!P``>0,```````"(!```/0,`````
M``"&!```B@```'@``````````````!8$``"N!P```````#D'``#!``````@`
M```````P!P``%P,``%,%``"N`0``W@$``"L(``!&!@``W`(```````!L`@``
M$00```L&````````F@,``$H`````````00$``,8$``"U!0``9P$`````````
M````N@(``/H"``"I`@``^@,``-`!````````'P(`````````````O@(``-4'
M``!F!P``Q`,```8$```P````>@```-<"``#I!@``$`(``*T%```L`@``[P8`
M`!4%``!N`P````````````!^!0``<P$``*0"`````````````)H!```+"```
M^0````````#S!```*`8```````!Y!````@0``/8&``##!@``#P,``#4%``!<
M!0```````&$%``#^!@``GP,``.D!```G!P``H`8``+`$``!P`@``PP0``,0$
M``!D"``````````````B"```Q0<``#4(````````W@0``/("`````````P4`
M``````"``@``Q`(```````!<````O08``-L```!6!```W0(```````!W!```
MT@(``&4%``!K`0``6``````````W`0```````%8```">`@``^`4``/0!``"'
M!0``=`@``#0(``![!P```````+$%````````F0,``(,#````````.`$``"0&
M````````V@4``'`#``#6!@``VP8``)\$``!#"```7`@``&T%``#-````&`(`
M`.X%``"K`P```````%0!````````!`4``.T$```W!0```````"P#``!:!P``
M``````````#<`P``,00``"P%````````E`,``'(&````````.@4`````````
M`````````-$'````````2P,``'0&```^`@``I`8``$D```"8`0``@@```-$%
M```>"````````*\'``#P`P```````#(#````````XP,``#(```#]`0``GP``
M`.8!``#,!@``9`<```````"#`0````````````#Q`@``````````````````
M`````$0"``!/!@``D@4``#,'````````E````.0'``"*`@```````(4&``"[
M!0```````)($`````0``M`(``"T$```C!0``P08```````!8!P``````````
M``"=!```L00``'("``"@`@``UP$``$0&```^!@``?`,`````````````````
M`$T$```H!````00`````````````D0<```````#(!0``'0````````#D!0``
M``````````".!````````&4'``!J!0``*P<``+<"``#L!```X0<``!(```"E
M!P``<0(``#4#````````N@$``"T'``````````````````#\`0``/08``!0`
M``#/!P``20$``+$#``#,!P``J`0``!D```!H`@``$04``-D`````````&@(`
M`%H"````````E@0``)('````````%`@````````\`@``?@8```````!,!```
MI@```-(&```%!```0P8``&((``"C!0```````!\&```E!@``K`<``,4&````
M`````````!(%``!;`P``.@````````!)!````````,<#````````T@4``$H$
M``!0!0```````(8"````````Z`$``#$%```J!````````,<!````````7P<`
M``T%``"S`0``ZP<````````I!P``P04``/8%```T!```$08``,`'``!+"```
M(`0``'L%``"S```````````%``"3!0``P`0``(T!`````````````"@#``!;
M!@``TP<``/P```#6`0``CP,``+\'``!U!0``V@,```````!0"`````0`````
M``#5`@``)0,``+,$````````@04```````"T`P``_@,``/P'``!)!P``NP$`
M`#`$```<!```%`$``#4!``!H!```I0(``'\"``##`@``5`4`````````````
M`````#H#``"V`@```````#,%````````>`4``$,'``!``0``O04```D'``"@
M!P``_@```/`!````````O@8``*($``#Y!```S`,``"0```"8!0```````'`!
M````````````````````````3P0``.D%``!Y`0``-0<``#D$```!`0``/0<`
M`"<(``#J!0``$`<`````````````B@<``'D"```3`P```````)T&``!!!@``
M7`$``$D"```````````````````4!P```````````````````````/<&``"P
M!@```@(```````"O!@``C0(``$H"``!6"```9`````D!````````R@```,L`
M``"R!P``H@$``&(&``!%`0````````````#H!```4`$````````.`0``````
M`"<%``"8!```<@@``*````"X!0``-@8``',$``!(````B0$``%X&````````
MZ@0``*L%``!?!0```````-@'```S"```W@8``.T`````````N0```'8%````
M````7@,````````/`0``8P,```@&``#@!P``%P$``+$&`````````````'L#
M````````GP(``)L#```1`P``:`@``*0```"$`0``,@(```````"+`P``8P``
M`+<&```H`0``Q0,``$('``!D`P```````$0```#=!@``)0$`````````````
MXP<```````"A!0``10@``"T!````````,@4``*("````````]00``"4$``#`
M!0``````````````````%@```*`!``#Q````+P,```````!N"````````'<`
M````````B@8``"X"```=`P``&0<``!````"6!0``;@4```P(``"G!P``@P4`
M``````!C!0``0@@``*\````;`0``S0<``+L"`````````````!((``!.!```
M00<```````!5!```&P,``$D%`````````````&0!``"G`0``C04``.,&``"\
M!```R`(```````"!!P```````)`$``"W!```*0,```D(``#M!@``%@$``*<#
M```H"````````!8"``!+`@``80(``(,```!U`@``+0```!8&```\!0``:00`
M`'T'```(`0``*0@````````N!P``U`4``.L%``#A````OP0```````##`0``
MW`$``!8(``#_`P```````(<"```9`P```````*0!``!_!P``K0<``,@&``!,
M"```O@4``'T#`````````````&T!```B````*P```!('``#Y`0```````/X'
M``!`"```T@```.``````````X0(``"L&```5!P``B0```+P'``#0!0``AP<`
M`&@!``#.!````````,@!``#5!```40,``#@(``!V!@````````P%```8!P``
M2P$``)@```"S!0``R@8`````````````30$``&,$``#S`P``>@8``*X````+
M`P``AP0``$<'``#O`P``S`4`````````````Q@4```````#@!````````%$$
M``!T`0``$0(``'X$``#!!```RP4``*\!```N`````0<``"\$``!"`P``<P(`
M````````````6`(``/H```#0`P``X@<``(8%``"4!0``(`8``%@#``"!`P``
M`````)P"``!,!0``.0$``!X$```*`P``\0<``"<$``">!P``M08````````0
M`P``;@```)T#```J````^0<`````````````V0<``*D$``"]`P```````$X`
M````````9@0````````Q````\`````````"O`@``0`,```````",!@``T@0`
M`#H$````````=@0``!8%````````R0(``','``#E!0``N08```T#````````
M````````````````A@```````````````````#\!```Q!P``/@```.,%``"2
M`P``M`8``/@#````````^@4``#<````_`P``'`8```````!7`P```@````H!
M``!W`@``C`0``)("``!&"```"`0``(L"``!F!0``.@@```````#4!```8P(`
M`)L&``!'!@``UP```%X%``"!`0``Y`8``'@!``#V`0```````$T#``")`P``
M>P$``-$&``````````````````!$"```,`,``+(%```$````90$``,D```#"
M!@```````!,`````````40$``#X'````````!P4``,D$``!B````B`,``"0"
M````````"P<``*0%`````````````&(%`````````````/<%``!Z!P``.`<`
M`%L'``#R!@``C00``%D&````````-@<``!P!``!M!@```````$$"``#&````
M`````,H%``#$!0``(@<``#8````:`P``?P```%8"``!D`@``!0@`````````
M````!08``($"``"E`P``90```)P```!S"```/P8```````#D````E00``-@`
M``#K!```1@$``-\```"+!P``/`<``/<"````````9`0```````!;!```F04`
M`+0!``#2!P```````!`(``#_`@```````$P"``"U`@``>@(``+,"``"/````
M00@```8!``#:!@``!P@`````````````F@8```X```#4!P``WP,``+0$````
M````&@4```````".!P``G04``&D"``!P!```_@$``/X"``"B`P``:P4```P`
M``";!0``=`0``%\```!W!@``+@,`````````````V00``&$&```E"```8P@`
M`/('````````2`(``&D'``#=!P```````-4#``!$!0````````````#:`@``
M``````<!````````X0,``#,"``"W!P`````````````5`0``=0$``.T!```,
M`0```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A
M>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@061D(&%N
M($E-4U`@061D<F5S<R!";V]K`"!$96QE=&4@24U34"!!9&1R97-S($)O;VL`
M(&%T(``B)7,B(&%L<F5A9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM<&]R=&5D
M+@`B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B
M('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-O
M<&EE9"!B96-A=7-E(&ET(&ES(&$@;&ES="X`(B5S(B!W87,@;F]T(&-R96%T
M960Z("5S+@`B)7,B('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI
M<W0N`")&:7)S=&YA;64@3&%S=&YA;64B("`H:64N($IO:&X@1&]E*0`B3&%S
M=&YA;64L($9I<G-T;F%M92(@*&EE+B!$;V4L($IO:&XI`"4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5
M<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@861D960N`"5S(&%L<F5A9'D@
M97AI<W1S+@`E<R!A="`E<R`E<P`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O
M<G1E9``E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E
M<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R
M`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B!4:&ES(&UE<W-A9V4@
M;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@
M;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G
M=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O
M("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA
M=``R-"!H;W5R<P`\4')E=FEO=7,`02!B<F]W<V5R('1H870@<W5P<&]R=',@
M:49R86UE<R!I<R!R97%U:7)E9`!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q
M=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A
M:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B
M;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B;W9E('-E87)C:"!F;W)M`$%B
M<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!
M8V-E<W,@9&5N:65D('1O("5S`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N
M="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D
M($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!
M9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G
M<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!
M9&0@82!N97<@=7-E<CH`061D(&%D9')E<W,@8F]O:P!!9&0@86YD($1E;&5T
M92!)35-0(&%D9')E<W,@8F]O:W,`061D(&-O;'5M;@!!9&0@9FEL90!!9&0@
M;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R`$%D9"!T;P!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@
M=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO
M=2!C86X@;&]G(&EN(&YO=RX`061D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I
M;&%B;&4N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R
M97-S($)O;VL`061D<F5S<R!";V]K($QI<W1I;F<`061D<F5S<R!";V]K<P!!
M9&1R97-S(&)O;VL@96YT<GD`061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P
M=7)G960N`$%D9')E<W,@8F]O:R!T;R!D96QE=&4@`$%D9')E<W,@8F]O:W,@
M=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z`$%D;6EN:7-T97(@+2!S970@
M<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D
M<P!!9'9A;F-E9"!396%R8V@`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA
M`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D
M(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I
M9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y($5X:7-T<P!!;')E861Y(&5X
M:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S
M=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@
M861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!
M;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA
M`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!
M;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI
M<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E
M<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD
M;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@
M>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@)7,_`$%R92!Y;W4@
M<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L96-T960@96YT
M<FEE<S\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R
M;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N9&EN
M9P!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G
M:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R
M86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!
M=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H
M7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T
M:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T
M:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD
M<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O
M=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S
M('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R
M=7,`0F5L9VEU;0!"96QI>F4`0F5L;W<@<V5A<F-H(&9O<FT`0F5N:6X`0F5R
M;75D80!":'5T86X`0FEN9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`0FQO
M8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@
M4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O
M<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"
M<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R;W=S90!"
M<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI
M;F$@1F%S;P!"=7)U;F1I`$)U<VEN97-S($-A=&5G;W)Y`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL(%!R;W!E<G1I97,N+BX`
M0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#
M86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T
M('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&0@82!G<F]U<"!T;R!I='-E
M;&8N`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R
M<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E
M;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P
M;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A
M<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES
M;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG
M.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L
M=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U
M8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T
M92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC
M:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H
M87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@7T%L;"].;VYE`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A(&YA;64`
M0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N
M(&%D9')E<W,@8F]O:P!#:&]O<V4@86X@861D<F5S<R!B;V]K.@!#:&]O<V4@
M:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@
M*&9O<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K
M<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CH`0VAO;W-E('=H:6-H
M(&%D9')E<W,@8F]O:W,@=&\@=7-E+@!#:&]O<V4@=VAI8V@@8V]L=6UN<R!T
M;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.@!#:')I<W1M87,@27-L86YD
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A
M<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E
M<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L
M:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN
M9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG
M*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`
M0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN($]P=&EO;G,`0V]L=6UN('1I=&QE<P!#;VQU;6YS('1H
M870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.@!#;VUI8W,`0V]M;6$@<V5P87)A
M=&5D('9A;'5E<P!#;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R;W-O9G0@
M3W5T;&]O:RD`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N
M($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!A;GD@061D<F5S<P!#;VUP=71E
M<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA
M<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F
M(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O
M;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO
M;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!F86EL
M960Z("5S`$-O;FYE8W1I;VX@9F%I;'5R90!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W0@4V5A<F-H`$-O
M;G1A8W1S`$-O;G1A8W1S(&EN(&QI<W0Z("5S`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT
M('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#
M;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z
M("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G
M279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N
M;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N
M;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO
M="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E
M<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E
M<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS
M('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY
M('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E
M('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E
M<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T
M90!#<F5A=&4@061D<F5S<R!";V]K`$-R96%T92!A(&QI;FL`0W)E871E(&$@
M;F5W($-O;G1A8W0@3&ES="!I;CH`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@
M<W5B(&9O;&1E<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I
M="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#
M=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#
M=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO
M;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL
M:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O=W-E<@!$
M871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T
M:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E
M<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A
M=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F875L="!S;W)T:6YG(&1I
M<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!!9&1R97-S($)O
M;VL`1&5L971E($-E;&P`1&5L971E($-O;F9I<FUA=&EO;@!$96QE=&4@1W)O
M=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&5T92!B=71T;VX@8F5H879I;W5R`$1E;&5T92!C
M96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T90!$96QE=&4@9F%I;&5D.B`H)7,I("5S`$1E;&5T92!M97-S86=E
M<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@
M<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E
M<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L
M971I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92X`1&5L971I;VX@9F%I
M;&5D`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97!A<G1M96YT`$1E<V-E;F1I
M;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H
M86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@
M4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$
M:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M=`!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I
M<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L
M87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@=&\@
M8V]N9FER;2!D96QE=&EN9R!E;G1R:65S/P!$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N
M(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O
M=VYL;V%D('9#87)D`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I
M;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P
M<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET("(E
M<R(`161I="!!9&1R97-S($)O;VMS`$5D:70@0FQO8VL`161I="!'<F]U<`!%
M9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<P!%9&ET(&5N=')Y(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'
M871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N
M`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM
M86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%;G1R>2!F
M;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D960@9FEL92!F
M86EL960Z("5S`$5N=')Y(&9O<B`E<R!U<&1A=&5D+@!%<75A=&]R:6%L($=U
M:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&%D9&EN9R`E9"!C;VYT86-T*',I
M('1O(&QI<W0N`$5R<F]R(&%D9&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N
M=&%C="AS*2!T;R!L:7-T+@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R
M;W(@9&5L971I;F<@)60@8V]N=&%C="AS*2X`17)R;W(@9&5L971I;F<@)60@
M;V8@)60@<F5Q=65S=&5D(&-O;G1A8W1S*',I+@!%<G)O<B!D96QE=&EN9R!S
M>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R
M<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@<F5M;W9I;F<@)60@8V]N
M=&%C="AS*2!F<F]M(&QI<W0N`$5R<F]R(')E;6]V:6YG("5D(&]F("5D(')E
M<75E<W1E9"!C;VYT86-T*',I(&9R;VT@;&ES="X`17)R;W(@<V5A<F-H:6YG
M('1H92!A9&1R97-S(&)O;VLZ("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D
M.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@
M(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U
M(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E
M<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R
M>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N
M9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!%
M>'!O<G0`17AP;W)T($%D9')E<W,@0F]O:P!%>'!O<G0@;VYL>2!T:&4@<V5L
M96-T960@8V]N=&%C=',N`$5X<&]R="!T:&4@9F]L;&]W:6YG(&%D9')E<W,@
M8F]O:R!C;VUP;&5T96QY+@!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P
M`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@86-C
M97-S('1H92!A9&1R97-S(&)O;VLZ("5S`$9A:6QE9"!T;R!A9&0@)7,@=&\@
M)7,Z("5S`$9A:6QE9"!T;R!B<F]W<V4@;&ES=`!&86EL960@=&\@8G)O=W-E
M('1H92!D:7)E8W1O<GD`1F%I;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S
M.R!/;&0@1$X@/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@/2`E<P!&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL
M960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,
M(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E
M9#H@)7,`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I
M979E.B`E<P!&86EL960@=&\@<V5A<F-H('1H92!A9&1R97-S(&)O;VL`1F%I
M;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E<P!&86ER`$9A;&ML86YD
M($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R
M.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``
M1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG
M;&5T($-!4%1#2$$`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL97,`1FEL=&5R<P!&:6YD`$9I;FES:`!&:6YL86YD`$9I<G-T
M($AA;&8`1FER<W0@3F%M90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP
M`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E96)U<WD@55),
M`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE
M<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO
M;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I
M;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!'
M:6)R86QT87(`1VEV96X@3F%M90!';&]B86P@061D<F5S<R!";V]K`$=L;V)A
M;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H
M`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N
M9`!'<F5N861A`$=R;W5P`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A
M9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U
M<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`
M1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(
M87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(
M96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R
M90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?
M;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D
M9')E<W,`2&]M92!#:71Y`$AO;64@0V]U;G1R>0!(;VUE($1I<F5C=&]R>0!(
M;VUE(%!H;VYE`$AO;64@4&]S=&%L($-O9&4`2&]M92!3=&%T92]0<F]V:6YC
M90!(;VUE(%-T<F5E="!!9&1R97-S`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R
M:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S`$E-4U`@061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N
M`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W
M;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS
M($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S
M(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E
M;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM
M86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R
M>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@061D<F5S<R!";V]K+"!3
M=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($%D9')E<W,@
M0F]O:W,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?
M<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!)
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S
M`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO
M;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!)
M;6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L
M=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT
M97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@
M8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A
M9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS
M97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!)
M;G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS
M97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`
M26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV
M86QI9"!)1`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A
M;&ED(%I)4"!D871A`$EN=F%L:60@861D<F5S<R!B;V]K`$EN=F%L:60@87!P
M;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M
M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!E
M;6%I;`!);G9A;&ED(&5N=')Y`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI
M9"!K97D@<W!E8VEF:65D+@!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED
M(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED
M(&YA;64`26YV86QI9"!O8FIE8W1)9`!);G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED
M('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I
M<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R
M8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)
M;G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A
M<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E
M;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*
M87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE
M`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@
M3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`
M2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT
M`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+
M;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@
M4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N
M`$Q$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE
M(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E9"X`3&%?>6]U=`!,86YG
M=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA
M;&8`3&%S="!-;V1I9FEE9`!,87-T($YA;64`3&%S="!087-S=V]R9"!#:&%N
M9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`
M3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V
M:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N
M;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L
M`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN
M`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI
M9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I
M=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;FL`
M3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE
M(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O
M:VEE`$QI<W0`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,
M;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I
M;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U
M=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I
M;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-
M87)T:6YI<75E`$UA=&-H:6YG`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA
M`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A
M<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E
M;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',`
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T
M:`!-87AI;75M(&YU;6)E<B!O9B!P86=E<P!-87D`36%Y;W1T90!-961I8VEN
M90!-96UB97)S`$UE;G4@3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE
M<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE
M<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T
M:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#
M86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU
M;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES
M8V5L;&%N96]U<P!-:7-S:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R
M871I;VXN`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES
M<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N
M;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I
M;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@
M36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V)I
M;&4@4&AO;F4`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO
M9&EF>2!F86EL960Z("@E<RD@)7,`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI
M8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-
M;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI
M;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F4@=&AA;B`Q(&5N=')Y
M(&9O=6YD`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S
M=&QY(%-U;FYY`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@;&5F=`!-;W9E(')I9VAT`$UO=F4@
M=7``36]Z86UB:7%U90!-=6QB97)R>2!!9&1R97-S($)O;VL`375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!P
M97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@
M6R5S72!A;')E861Y(&5X:7-T`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O
M=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@061D<F5S<R!";V]K`$UY
M($%D9')E<W,@0F]O:W,`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA
M;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UE($9O<FUA=`!.86UI
M8FEA`$YA=7)U`$YE<&%L`$YE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y`$YE
M=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@
M55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O
M;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.
M971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!#
M;VYT86-T`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M
M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE
M>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A
M`$YI8VMN86UE`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R`E<R!E
M;G1R>2!F;W5N9"!F;W(@)7,`3F\@861D<F5S<R!B;V]K<R!F;W5N9"X`3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/
M(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-O;G1A8W1S(&9O=6YD`$YO
M(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL
M92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T
M+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`
M3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F
M9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%14
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD
M:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A
M=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9#87)D(&1A=&$@=V%S(&9O
M=6YD+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U
M<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.
M;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA
M<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T
M(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P
M<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V
M96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C
M;VQU;6YS`$YU;6)E<B!O9B!I=&5M<R!P97(@<&%G90!.=6UB97(@;V8@<F]W
M<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V)J96-T
M(&YO="!F;W5N9`!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC
M90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L
M9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`
M3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D<F5S<R!B
M;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E9"X@268@=&AI<R!I<R!N
M;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N9V4@>6]U<B!S
M96QE8W1I;VX@=&\@(DYO;F4B+@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE('9C87)D('-U
M<'!O<G1E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@
M9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I
M;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T
M`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`
M3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA
M=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I
M;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@
M4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!-($QI9VAT(%)A
M:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S
M`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9P!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`
M4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E
M<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N
M9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T
M(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I
M;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T
M960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VX@9&5N:65D`%!E<FUI
M<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`
M4&EN92!!9&1R97-S($)O;VL`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A
M8W0@;&ES=#H`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@
M='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0
M;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``
M4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E
M=FEO=7,`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E
M($%D9')E<W,@0F]O:P!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L
M:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A
M=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O
M(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`475E<GD`475E<GD@9F%I;&5D
M.B`H)7,I("5S`%%U:6-K(%-E87)C:`!1=6]T80!24T$@4'5B;&EC($ME>2`H
M)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@
M3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!2
M86YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@9F%I;&5D.B`H)7,I("5S
M`%)E860@;65S<V%G97,`4F5A9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA
M8FQE+@!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296%L;'D@9&5L971E('1H:7,@8V]N=&%C=#\`4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N`%)E8V]R9',@9&ES<&QA>65D.@!2961O97,@
M>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296QA=&EO;G-H:7`@
M0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@861D<F5S<R!B;V]K`%)E;6]V92!C;VQU;6X`
M4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E(&9R;VT@=&AI<R!L:7-T`%)E;6]V
M92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@
M9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S
M`%)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R
M=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES(&1E;&5T97,@86QL(&5N
M=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@8F]O:RX\+W-T<F]N9SX`
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B``4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N`%)E<75E<W1E9"!S
M97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O
M<F0`4F5S970@=&\@1&5F875L=',`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L
M=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N
M:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`
M4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4`4R]-24U%(%!U8FQI8R!#97)T:69I8V%T90!305-,(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U1!4E143%,@9F%I;&5D.B`H
M)7,I("5S`%-50T-%4U,`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N
M9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N
M`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@
M*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP
M90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B
M)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-A=FEN9R!C;VYT
M86-T<R!I<R!N;W0@879A:6QA8FQE+@!38V%T=&5R960@5"U3=&]R;7,`4V-I
M96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H(&9A:6QE9`!396%R
M8V@@9F%I;&5D.B`E<P!396%R8VAI;F<@:7,@;F]T(&%V86EL86)L92X`4V5A
M<F-H:6YG+BXN`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A
M(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R
M=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@
M9&5L971E`%-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@961I=`!396QE8W0@
M86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@861D<F5S<R!B;V]K
M('1O(&5X<&]R="!F<F]M.@!396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I
M;7!O<G0@=&\Z`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&-H87)S970@
M;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F
M;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@
M9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!F;W)M870@
M=7-E9"!T;R!D:7-P;&%Y(&YA;65S.@!396QE8W0@=&AE(&ED96YT:71Y('EO
M=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`
M4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N`%-E;&5C="!V:65W('1O(&1I<W!L87D@8GD@9&5F875L="P@<V]R
M="!O<'1I;VYS+"!A;F0@<&%G:6YG(&]P=&EO;G,N`%-E;&5C="!W:&EC:"!F
M:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RX`4V5L96-T
M('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+@!396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`
M4V5L96-T960@861D<F5S<R!B;V]K("(E<R(N`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA
M(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$
M(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F5D
M($1I<F5C=&]R>0!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E
M<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@
M)7,`4VAO=R!!;&P`4VAO=R!#;VYT86-T<P!3:&]W($QI<W1S`%-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U
M<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W
M97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I
M9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R
M82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM
M`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO
M=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W
M97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W
M(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI
M80!3;VYG<R`F(%!O96US`%-O<G0@1&ER96-T:6]N`%-O<G0@;W)D97(@<V5L
M96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=7)C97,`4V]U=&@@069R:6-A`%-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E
M`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C
M:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W!E8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@
M<F5S=6QT<R!T;R!A<'!E87(N`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P
M;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3
M=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O
M<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T
M`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U
M`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`
M4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D
M960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@861D960@)60@
M8V]N=&%C="AS*2!T;R!L:7-T+@!3=6-C97-S9G5L;'D@861D960@)7,@=&\@
M)7,`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A
M8W0@;&ES="`B)7,B+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`E9"!C;VYT86-T*',I+@!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E
M;6]V960@)60@8V]N=&%C="AS*2!F<F]M(&QI<W0N`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`
M4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WEN8R!L;V<@9&5L971E9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@
M5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B('-E
M<&%R871E9"!V86QU97,`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P
M<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A
M:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z
M`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``
M5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD
M+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT
M(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE
M($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@
M<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I
M;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@
M8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I
M;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@5D93(&)A8VME;F0@;F5E
M9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@871T86-H;65N="!U<&QO
M861S+@!4:&4@861D<F5S<R!B;V]K("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H
M92!A9&1R97-S(&)O;VL@(B5S(B!W87,@8W)E871E9"!S=6-C97-S9G5L;'DN
M`%1H92!A9&1R97-S(&)O;VL@(B5S(B!W87,@<F5M;W9E9"!S=6-C97-S9G5L
M;'DN`%1H92!A9&1R97-S(&)O;VL@(B5S(B!W87,@<W5C8V5S<V9U;&QY('5P
M9&%T960N`%1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@
M)7,`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C
M="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H
M92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N`%1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES
M="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E
M<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`B
M)7,B(&AA<R!S=6-C97-S9G5L;'D@8F5E;B!D96QE=&5D+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO
M="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N
M;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI
M<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B
M86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@
M<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@:6UP
M;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W87)N:6YG<RX`5&AE
M(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T
M("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@
M<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R
M87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL
M>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO
M=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D
M+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE
M;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&)R
M;W=S96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S
M(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R!A
M<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S
M('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@:7,@86X@97)R;W(L('!L
M96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H97)E
M(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H
M879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S
M<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O
M('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A
M<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4
M:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U
M<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O
M;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F;W(@
M9G5R=&AE<B!H96QP+@!4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N
M97<@;&ES="X`5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D
M<F5S<R!B;V]K.B`E<P!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@(B5S
M(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+@!4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<P!4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES=`!4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D9')E<W,@8F]O
M:SH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT<GDZ
M("5S`%1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="X`5&AE<V4@
M861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CH`5&AE
M<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CH`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT
M='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F
M:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D
M9')E<W,@8F]O:P!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A
M;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEL
M;"!B92!T:&4@9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@
M:6UP;W)T:6YG(&-O;G1A8W1S+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE
M`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM
M;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@
M;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G
M;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O
M<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@
M5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES
M:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z
M(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P
M;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@
M)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R92X@36ES<VEN
M9R!S;W5R8V4@='EP92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI
M<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A
M=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G
M:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V
M:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H
M;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N
M`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,`56YS
M=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S
M97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO
M860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M
M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S
M97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M
M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S
M97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I
M=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@
M(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E
M<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O
M97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@
M:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N
M`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU
M97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N
M97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)I<VEG;B!$:7)E8W1O<GD`
M5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC
M86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N
M86UE<V4@*%9)4T-)22D`5FEE=R`B)7,B`%9I97<@)7,`5FEE=R!#;VYT86-T
M`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W('1O
M(&1I<W!L87D@8GD@9&5F875L=#H`5FER9VEN($ES;&%N9',L($)R:71I<V@`
M5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``
M5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T
M:&5R(&1A=&$@<')O=FED960@8GD`5V5B`%=E8B!3:71E`%=E8G-I=&4@55),
M`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S
M=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E
M<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L
M:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U
M;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@
M969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I
M9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E
M960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K
M`%=O<FL@061D<F5S<P!7;W)K($-I='D`5V]R:R!#;W5N=')Y`%=O<FL@4&AO
M;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K(%-T871E+U!R;W9I;F-E`%=O<FL@
M4W1R965T($%D9')E<W,`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE
M("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F
M:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D
M('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S
M(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M
M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B`B)7,B+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M=FEE=R!T:&ES(&-O;G1A8W0N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N
M('1O('9I97<@=&AI<R!O8FIE8W0N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S
M:6]N<R!T;R!D96QE=&4@=&AI<R!S;W5R8V4N`%EO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@
M=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I
M9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O
M8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN`%EO
M=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+@!9;W4@;75S="!S96QE8W0@
M86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A="!L
M96%S="!O;F4@8V]N=&%C="!F:7)S="X`66]U(&UU<W0@<V5L96-T(&%T(&QE
M87-T(&]N92!E;G1R>2!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P
M<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=2!O;FQY(&AA=F4@
M<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA
M:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I
M;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M
M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E
M;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN
M(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!A9&1R97-S(&)O;VL@:7,@
M;F]T(&)R;W=S96%B;&4N`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E
M;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N
M86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R
M9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO
M=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9
M;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S
M.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;2&ED92!1=6]T
M960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M
M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S
M70!;;F\@=F%L=65=`%]!9&UI;FES=')A=&EO;@!?0G)O=W-E`%]#3$D`7T-O
M;G1A8W1S`%]$96QE=&4`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA
M9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R=`!?3&ES=',`7TQO9R!I
M;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7TUY($%D9')E<W,@0F]O:W,`
M7TYE=R!#;VYT86-T`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI
M;FLN+BX`7U)E;6]V92!F<F]M('1H:7,@;&ES=`!?4V5A<F-H`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E
M<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E
M;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@
M870@)7,@)7,`9W5S=&EN9P!H.@!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA
M=&4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R
M`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RX`;F%M90!N;R!F;W)M871T:6YG`&YO;F4`;F]T(&EM<&QE;65N=&5D`&YO
M="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@
M9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG
M`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA
M:6P@=FEA($A45%``<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M
M<&]R87)Y(&9A:6QU<F4`=&\@82!#;VYT86-T($QI<W0`=&\@82!D:69F97)E
M;G0@061D<F5S<R!";V]K`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O
M;F9I<FT`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!0<F]J96-T+4ED
M+59E<G-I;VXZ(%1U<F)A(#(N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ
M-R`Q,#HP,"LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,3@@,3,Z
M,30K,#$P,`I,87-T+51R86YS;&%T;W(Z($QA<WIL;R!,+B!4;W)N;V-I(#QT
M;W)L87-Z0'AE;FEA+G-O=&4N:'4^"DQA;F=U86=E+51E86TZ($AU;F=A<FEA
M;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@;F%P<&%L(&5Z
M96SU='0I`"`H06QT+6)I;&QE;G1Y^R`E<RD`("@E<R!N87`@;?IL=F$I`"`H
M;6$I`"`H:&]L;F%P*0`@*'1E9VYA<"D`($E-4U`@8^UM:F5G>7KI:R!LZ71R
M96AO>N%S80`@24U34"!C[6UJ96=Y>NEK('3V<FSI<V4`(#H@`"(E<R(@;>%R
M(&SI=&5Z:6LL(&%Z(&EM<&]R=.%LX7,@;F5M('3V<G3I;G0@;65G+@`B)7,B
M(&YE;2!A;&OV;GEV=.%R+@`B)7,B(&YE;2#I<G;I;GEE<R!VX6QA<WITX7,N
M`"(E<R(@;FEN8W,@:V]N9FEG=7+A;'9A(&$@2&]R9&4@4F5G:7-T<GEB96XN
M`"(E<R(@9F%S=')U:W3Z<F$M;65G:F5L96[M=/4@;F5M('1A;.%L:&%T\RX`
M(B5S(BUT(&AO>GKA861T=6L@82!C<V]P;W)T;VMH;WHN`"(E<R(M="!H;WIZ
MX6%D='5K(&$@:F]G;W-U;'1SX6=I(')E;F1S>F5R:&5Z+@!-:79E;"`B)7,B
M(&5G>2!L:7-T82P@97KI<G0@;F5M(&WA<V]L='5K(.%T+@`B)7,B+70@;F5M
M(&AO>G1U:R!LZ71R93H@)7,N`$UI=F5L("(E<R(@96=Y(&QI<W1A+"!E>NER
M="!N96T@:&5L>65Z=/QK(.%T+@`B2V5R97-Z=&[I=B!697IE=.EK;NEV(B`@
M*'!L+B!*X6YO<R!+;W;A8W,I`")697IE=.EK;NEV+"!+97)E<WIT;NEV(B`@
M*'!L+B!+;W;A8W,L($KA;F]S*0`E+C)F34(@9F5L:&%S>F[A;'0@82`E+C)F
M34(@;65G96YG961E='1B]6P@*"4N,F8E)2D`)60@)7,@Z7,@)7,`)60@;F%P
M(&WZ;'9A(&QE:N%R(&IE;'-Z87;A;F%K(.ER=NEN>65S<^EG92X`)60@;F%P
M;W,@96SU<F5J96QZZ7,`)7,@+2!&:6=Y96QM97IT973I<P`E<R!L96YY;VUA
M=``E<R!K87)B86YT87)TX7-I(&9E;&%D871O:R`M(&UE9V5R]7/M=.ES`"5S
M(&)EX6QL[73A<P`E<R!L;V=I;B!NZ78@:6?I;GELZ7,`)7,@<WIO;&?A;'1A
M=.%S:2!F96QTZ71E;&5K`"5S(&)E=FET96QE(&UE9W3V<G3I;G0N`$$@(B5S
M(B!N97;[(.%L;&]MX6YY(&WA<B!LZ71E>FEK+@`E<R`Z("5S("5S`$$@)7,@
M9N%J;"!I;7!O<G3A;.%S82!S:6ME<F5S96X@;65G=/9R=.EN=`!!*'HI("5S
M(&OI<WIE;B#A;&P@87H@86SA8F)I(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K
M(&5L=NEG>NESZ7)E+DIE;/9L:F4@:VD@87IO:V%T(&$@9F5L861A=&\H:V$I
M="P@86UI*&ME*70@;6]S="!E;"!K[7;A;B!VZ6=E>FYI+@`E<R!K:73V;'3I
M<V4@<WK\:W/I9V5S`"5S('!E<F,`)7,@;F5M('1A;.%L:&%T\RX`)7,@+2`E
M<R`H]G-S>F5S96X@)7,I`"5S(&/M;6IE9WEZZ6ME`"5S(&YA<'3A<F$`)7,@
M9F5L:F5G>7KI<V5I`"5S(&9E;&%D871L:7-TX6IA`"5S.B!,96AE='/I9V5S
M+"!H;V=Y(&5Z(&$@;&5VZ6P@=F%L\VKA8F%N(&YE;2!A(&UE9V%D;W1T(&9E
M;&%D\W3S;"!S>N%R;6%Z:6LN($=O;F1O;&IA(&UE9RP@;6EE;/5T="!RX6MA
M='1I;G0@=F%L86UI<F4L('9A9WD@<WIE;>EL>65S(&EN9F]R;>%C:?-T(&%D
M(&UE9RX`+"!S>NEL;/9KZ7-E:P`L("5S("5S+7,@<WKI;&SV:^ES96L`+"!V
MX6QT;WKS("5S(.ES("5S(&OV>O9T=``M+2!VX6QA<W-Z;VX@+2T`,3(@\W+A
M<R!F;W)MX71U;0`R-"#S<N%S(&9O<FWA='5M`#(T(/-R80`\16SU>O4`16AH
M97H@:49R86UE(&9U;FMC:6]N86QI=.%S<V%L(')E;F1E;&ME>O4@8O9N9^ES
M>O5P<F]G<F%M('-Z_&MSZ6=E<RX`17IE;B!B;&]K:R!H87-Z;N%L873A:&]Z
M(&5G>2!A9&%T8N%Z:7,@86QR96YD<WIE<B!S>OQK<^EG97,N`$AE;'ER96AO
M>FAA=&%T;&%N(&AI8F$@=/9R=.EN=`!!(&QE=NEL('1I=&MO<^UTX7/A:&]Z
M(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S('-Z_&MSZ6=E<RX`02!D:6=I=.%L
M:7-A;B!A;.'M<G0@;&5VZ6P@96QL96[U<GKI<^EH97H@96=Y(&YY:6QVX6YO
M<R!01U`@:W5L8W,@<WK\:W/I9V5S+@!!('1I=&MO<^UT;W1T(&QE=NEL(&1E
M:_-D;VSA<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,L(&5G>2!T:71K
M;W,@4$=0(&MU;&-S(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+@!!(&QE
M=NEL(&1I9VETX6QI<R!A;.'M<N%SX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K
M=6QC<RP@96=Y('1I=&MO<R!01U`@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S
M>OQK<^EG97,N`$$@=&ET:V]S[71O='0@;&5VZ6P@9&5K\V1O;.%SX6AO>B!E
M9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<RP@96=Y('1I=&MO<R!3+TU)344@
M:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG97,N`$$@;&5VZ6P@9&EG
M:73A;&ES(&%LX>URX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU;&-S
M+"!E9WD@=&ET:V]S(%,O34E-12!K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z
M_&MSZ6=E<RX`02!L97;I;"!T:71K;W/M=.%SX6AO>B!E9WD@;GEI;';A;F]S
M(%,O34E-12!K=6QC<R!S>OQK<^EG97,N`$3I;&5L]71T(&)O<G5L="#I9P!$
MZ6QE;/5T="!G>65N9V4@97/U`$3I;&5L]71T(&5S]0!$Z6QE;/5T=&D@>N%P
M;W)O:P!$Z6QE;/5T="!H\WKA<&]R;VL`9&4O9'4`05!)($E$("AA('!R;V=R
M86UO>N%S:2!F96S\;&5T(&%Z;VYO<^UT\VIA*0!%<G+U;"!A>B!E9&ET;W)R
M\VP`3NEV:F5G>2XN+@!A(&ME<F5S]69O<FT@9O9L]G1T`&%B<WH@86QU;`!A
M8G-Z(&OV>NEP`$YI;F-S(&IO9V]S=6QT<^%G82!A(%9&4R!A;&OV;GEV=.%R
M(&SI=')E:&]ZX7/A:&]Z+@!.:6YC<R!J;V=O<W5L='/A9V$@82!61E,@9N%J
M;"!LZ71R96AO>N%SX6AO>BX`)7,@96SI<NESZ6AE>B!N96T@<F5N9&5L:V5Z
M:6L@;65G9F5L96SU(&IO9V]S=6QT<^%G9V%L+@!"96IE;&5N=&ME>NES:2!I
M;F9O<FWA8VGS`$IE;'-Z\P!!(&IO9V]S=6QT<^%G(&9E;"!V86X@9OQG9V5S
M>G1V92X`4.EN>OQG>65K`$)E=FET96P`06QC<V]P;W)T(&SI=')E:&]ZX7-A
M`$IO9V]S=6QT<^%G:2!A;&-S;W!O<G0@;.ET<F5H;WKA<V$`061D:G5K(&AO
M>GKA(&ET=#H`VFH@8W-O<&]R="!LZ71R96AO>N%S80#::B!J;V=O<W5L='/A
M9R!LZ71R96AO>N%S80!!;&-S;W!O<G0@:&]Z>N%A9.%S82`B)7,B+6AE>@!*
M;V=O<W5L='/A9VD@86QC<V]P;W)T(&AO>GKA863A<V$@(B5S(BUH97H`VFH@
M9F5L:&%S>F[A;/,@;.ET<F5H;WKA<V$Z`-IJ(&/M;6IE9WEZZ6L`24U34"!C
M[6UJ96=Y>NEK96L@;.ET<F5H;WKA<V$L('3V<FSI<V4`^FH@;W-Z;&]P`$;A
M:FP@:&]Z>N%A9.%S80#::B!T86=O:R!F96QVZ71E;&4`VFH@<.%R(&AO>GKA
M863A<V$`02AZ*2`E<R!M96[\="!A9&IU:R!H;WIZX2!A($UO>FEL;&$@;65N
M_'-O<FAO>@!!9&IU:R!H;WIZX0!!9&IU:R!H;WIZX2!A(&/M;6IE9WEZZ6MH
M97HZ`$%D:G5K(&AO>GKA(&$@8^UM:F5G>7KI:V5M:&5Z`-IJ(&9E;&AA<WIN
MX6SS(&AO>GKA863A<V$`(B5S(B!F96QH87-Z;N%L\W0@:&]Z>N%A9'1U:R!A
M(')E;F1S>F5R:&5Z+"!D92!N96T@<VEK97+\;'0@82!T]F)B:2!B96IE;&5N
M=&ME>NES:2!A9&%T('3A<F]LX7-A.B`E<RX`(B5S(B!F96QH87-Z;N%L\W0@
M9F5L=F5T=.EK(&$@<F5N9'-Z97)B92X@36]S="!MX7(@8F5J96QE;G1K97IH
M970N`$$@8^UM:F5G>7KI:R!N96T@8O5V[71H973U+@!!(')E;F1S>F5R:&5Z
M(&YE;2!A9&AA=/-K(&AO>GKA(/IJ(&9E;&AA<WINX6SS:RX`0^UM`$/M;6IE
M9WEZZ6L`0^UM:F5G>7KI:R!L:7-T80!#[6UJ96=Y>NEK96L`0^UM:F5G>7KI
M:R!A9&%T`$$@8^UM:F5G>7KI:V5T('-I:V5R97-E;B!T]G+V;'3\:RX`02!T
M]G)L96YD]2!C[6UJ96=Y>NEK(`!.96T@;65G:F5L96[U(&/M;6IE9WEZZ6ME
M:SH`061M:6YI<WIT<N%C:?,@+2!J;V=O<W5L='/A9V]K(&%DX7-A('1O=N%B
M8FD@9F5L:&%S>F[A;/-K;F%K`$%D;6EN:7-Z='+A8VGS`$AI<F1E=.ES96L`
M4NES>FQE=&5S(&ME<F5SZ7,`069G86YI<WITX6X`06QBX6YI80!!;&?I<FEA
M`$%L:6%S`$5L:&5L>65ZZ7,`4F5N9&5ZZ7,Z`&%Z(/9S<WIE<V5T`$UI;F1E
M;B!N96T@=F5N9.EG(&9E;&AA<WINX6SS`$UI;F1E;B!C<V]P;W)T`$UI;F1E
M;B!J;V=O<W5L='/A9P!-:6YD(&$@;NEG>2!O;&1A;&]N(&QE9WEE;B!K97)E
M=`!%;F=E9&K\;FL@;65G('3V8F(@8^UM970@:7,`02!S;W)S>N%M;W,@9F5L
M<V]R;VSA<R!T[7!U<V$@=N%L=&]Z=&%T:&%T\R!L96=Y96X_`$WA<B!LZ71E
M>FEK`$WA<B!LZ71E>FEK`$E-4U`@8F5J96QE;G1K97KI<VD@<&%R86WI=&5R
M96L`3>%S:6LL($E-4U`@:F5L<WKS`$WA<VEK+"!)35-0(&)E:F5L96YT:V5Z
MZ7-I(&[I=@!-X7-I:R!E;6%I;"!C[6T`06QT97)N873M=B!S86)L;VYO:P!!
M;'1E<FYA=.UV('-Z]G9E9SH`06UE<FEK86D@4WIA;6]A`$$@;65G861O='0@
MZ7)TZ6L@;F5M(&9O9V%D:&%T\R!E;"X`27-M97)E=&QE;B!H:6)A('3V<G3I
M;G0N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;2!P<F]X>6X@:V5R
M97-Z=/QL:2!I;G1E<FYE="!E;.ERZ7,`5N%L87-Z`$%N=&%R:W1I<WH`06YT
M:6=U82#I<R!"87)B=61A`$%L:V%L;6%ZX7,`06QK86QM87KA<V]K(&QI<W3A
M:F$`07H@86QK86QM87KA<R!KZ7-Z+@!!(&OV>O9S('3A<G1E<OQL970@86QC
M<V]P;W)T:F%I<F$@:7,@Z7)VZ6YY97,`2O-VX6AA9WGA<P!+]G+\;&)E;/QL
M:2!MZ7)E=`#A<')I;&ES`&%R86(@*%=I;F1O=W,M,3(U-BD`02!T]FWV<NUT
M971T(.%L;&]MX6YY(&WI<F5T90!!('3V;?9R[71E='0@X6QL;VWA;GD@;F5V
M90!":7IT;W,L(&AO9WD@=/9R]FQN:2!K[7;A;FIA("5S+70_`$)I>G1O<R!A
M8F)A;BP@:&]G>2!T]G+V;&YI(&OM=N%N:F$@97IE:V5T(&%Z(&%D871O:V%T
M/P!":7IT;W,@8F5N;F4L(&AO9WD@=/9R]FQN:2!K[7;A;FIA("5S(&)E:F5L
M96YT:V5ZZ7-I(&EGZ6YYZ70_`$)I>G1O<RP@:&]G>2!T]G+V;&YI(&%K87)J
M82`B)7,B+70@86QC<V]P;W)T:F%I=F%L(&5G>?QT=#\`07)G96YT[6YA`-9R
M;>EN>6]R<WKA9P#V<FWI;GD@*$%235-#24DM."D`3?MVZ7-Z970`07)U8F$`
M;O9V96MV]0!0;VAN<&5I`$%S8VEI(')A:GIO:P#!>G-I82]#<V5N9&5S+?-C
M9>%N:2!RZ6=I\P!+Z7)J96X@82!R96YD<WIE<B!M96=E<O5S[73I<W0@82!K
M87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<V4@96SU='0_`$AO>GKA
M<F5N9&5LZ7-I(&]S>FQO<&]K`$YE;6SI=&5Z]2!C<V]P;W)T;W0@:^USZ7)E
M;'0@;65G('3V<O9L;FDN`$YE;6SI=&5Z]2!J;V=O<W5L='/A9V]T(&OM<^ER
M96QT(&UE9R!T]G+V;&YI+@!.96ULZ71E>O4@:F]G;W-U;'1SX6=O="!K[7/I
M<F5L="!M96<@;65G=N%L=&]Z=&%T;FDN`$YE;6SI=&5Z]2!K]GKV<R!TX7)T
M97+\;&5T970@:^USZ7)E;'0@;65G(&UE9W;A;'1O>G1A=&YI+@!4=6QA:F1O
M;G/A9V]K`&%U9W5S>G1U<P!!=7-Z='+A;&EA`$%U<WIT<FEA`$%U=&A?8WER
M<W%L.B!A('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`
M075T:%]C>7)U<SH@82!HX71TZ7)S>F]L9^%L=&%TX7,@;F5M(')E;F1E;&ME
M>FEK(&$@:^UVX6YT(&OI<&5S<^EG96MK96PN`$%U=&A?8WER=7,Z(&$@<WK\
M:W/I9V5S(&EM87`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H7V9T<#H@
M82!S>OQK<^EG97,@9G1P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX@1F]R9.UT
M<V$@;&4@82!02%`M="!A>B`M+65N86)L92UF='`@;W!C:?-V86PN`$%U=&A?
M:6UA<#H@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N
M`$%U=&A?:W)B-3H@82!S>OQK<^EG97,@:W)B-2!B]7;M=.ES(&YE;2!T86SA
M;&AA=/,N`$%U=&A?;&1A<#H@;F5M(&AO>FAA=/-K(&SI=')E(/IJ(&9E;&AA
M<WINX6SS:R!!8W1I=F4@1&ER96-T;W)Y(&5S973I;@!!=71H7VQD87`Z(&9E
M;&AA<WINX6SS:R!N96T@=/9R]FQH973U:R!!8W1I=F4@1&ER96-T;W)Y(&5S
M973I;@!!=71H7VQD87`Z(&$@<WK\:W/I9V5S($Q$05`@8O5V[73I<R!N96T@
M=&%LX6QH873S+@!!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS(&AO>GKA863A
M<V$@;F5M('-I:V5R_&QT+B!!('-Z97)V97(@=N%L87-Z83H@`$%U=&A?;&1A
M<#H@)7,@9F5L:&%S>F[A;/,@=/9R;.ES92!N96T@<VEK97+\;'0`075T:%]L
M9&%P.B`E<R!F96QH87-Z;N%L\R!A9&%T86EN86L@;65G^FKM=.%S82!N96T@
M<VEK97+\;'0`075T:%]L9&%P.B!A(&9E;&AA<WINX6SS:R!N96T@;?-D;W/M
M=&AA=/-K($%C=&EV92!$:7)E8W1O<GD@97-E=.EN`$%U=&A?;6-A;#H@82!S
M>OQK<^EG97,@34-!3"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?<VUB
M875T:#H@82!S>OQK<^EG97,@<VUB875T:"!B]7;M=.ES(&YE;2!T86SA;&AA
M=/,N`$YE;2!S:6ME<OQL="!A>B!)34%0('-Z97)V97)E;B!V86SS(&9E;&AA
M<WINX6SS87IO;F]S[73A<RX`02!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M
M('-I:V5R_&QT+@!!(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@<VEK97+\
M;'0N("5S`$$@9F5L:&%S>F[A;/,@87IO;F]S[73A<^%T(&$@4D%$2553('-Z
M97)V97(@96QU=&%S[71O='1A+@!.96T@<VEK97+\;'0@87H@1E10('-Z97)V
M97)H97H@=F%L\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N`$YE;2!S:6ME<OQL
M="!A>B!334(@<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S
M+@!!(')E;F1E;&ME>NES<F4@X6QL\R!M97KU:SH`07IE<F)A:F1Z<^%N`$$@
M9V]N;W-Z(')E;F1S>F5R9V%Z9&$@;65N='/I9V5I`$CA='3I<@!(X71TZ7(@
M<WKM;@!.96T@;65G9F5L96SU(&ME<F)E<F]S(&IE;'-Z\RX`3F5M(&UE9V9E
M;&5L]2!K97)B97)O<R!F96QH87-Z;N%L\V[I=BX`0F%H86WA:P!"86AR96EN
M`&)A;'1I("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S`$)A<F)A9&]S`$$@9W)A
M9FEK=7,@X6QL;VWA;GEO:R`B)7,B(&%L:_9N>79TX7)A(&YE;2!T86SA;&AA
M=/,N`&%L87!V;VYA;&]N`$ME<F5SZ7,`1F5HZ7)O<F]S>F]R<WKA9P!"96QG
M:75M`$)E;&EZ90!A(&ME<F5S]69O<FT@86QA='0`0F5N:6X`0F5R;75D80!"
M:'5TX6X`02!K87!C<V]L870@9F5L=NET96QE(&YE;2!S:6ME<OQL=#H@*"5S
M*2`E<P!3>OQL973I<VYA<`!!("(E<R(@8FQO:VL@82`B)7,B('!R;V=R86UM
M86P@;F5M('1A;.%L:&%T\RX`2^EP97)N>?5RZ7-Z(&)EX6QL[73A<P!+Z7!E
M<FYY]7+I<WH@=.UP=7,`9NEL:_9VZ7(`0F]L[79I80!+961V96YC('=E8F/M
M;65K`$ME<F5T`$ME<F5T=F%S=&%G<^%G.@!+97)E=&5K`$)O<WIN:6$M2&5R
M8V5G;W9I;F$`36EN9&ME='3U`$)O='-W86YA`&%L=6P`0F]U=F5T+7-Z:6=E
M=`!"<F%Z[6QI80!"<FET($EN9&EA:2WS8V7A;FD@5&5R_&QE=`!"]FYGZ7-Z
MZ7,`0G)U;F5I($1A<G5S<V%L86T`0G5L9^%R:6$`1F5L<V]R;VSA<P!"=7)K
M:6YA($9A<V\`0G5R=6YD:0#<>FQE=&D@:V%T96?S<FEA`%=E8F]L9&%L(&MA
M<F)A;G1A<G3A<P!#4D,`02!T86[Z<^UT=N%N>79I<W-Z879O;N%S:2!L:7-T
MX6L@*$-23"D@8^UM96D`0U-6`$-E;&QA('1U;&%J9&]N<^%G;VL`02!C86-H
M92!I;FEC:6%L:7KA;.%S82!N96T@9F5J97KU9/9T="!B92X`3F%P=.%R`$YY
M=6=O9'0`2V%M8F]D>G-A`$MA;65R=6X`3F5M('-I:V5R_&QT(&$@:F5L<WKS
M="#A=.%L;.UT86YI+"!F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+@!!
M*'HI("(E<R(@X6QL;VWA;GD@;F5M(.UR:&%T\RX`16=Y(&-S;W!O<G0@;F5M
M(&QE:&5T(/9N;6%G82!T86=J82X`02!K_&QS]2!F96QH87-Z;N%L\VMA<&-S
M;VQA="UK97IE;/5K(&YE;2!A9&UI;FES>G1RX6QH873S:RX`02!K]G9E=&ME
M>O4@24U!4"!S>F5R=F5R(&YE;2#I<FAE=/4@96PZ("5S`$$H>BD@(B5S(B#A
M;&QO;>%N>2!N96T@;GEI=&AA=/,@;65G+@!+86YA9&$`3>EG<V4`3>EG<V4@
M:_QL9/9K(&AI8F%J96QE;G3I<W0`02AZ*2`B)7,B(.%L;&]MX6YY(&YE;2!T
M]G+V;&AE=/4N`$YE;2!T86SA;&AA=/,@87H@:61E:6=L96YE<R#A;&QO;>%N
M>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV=.%R+@!!("=T87)G971&:6QE)R!P
M87)A;>ET97(@;65G863A<V$@;NEL:_QL(&YE;2!F;VQY=&%T:&%T:G5K+@!!
M*'HI("(E<R(@86QK]FYY=G3A<B!N96T@=/9R]FQH973U+@!.96T@=/9R]FQH
M973U+"`E9"!A;&-S;W!O<G1J82!V86XN`$%Z(/IJ('-O<F)A<F5N9&5ZZ7,@
M;F5M(&QE:&5T<^EG97,L(&$@;65G861O='0@861A=&]K('-ZX6UA(&YE;2!E
M9WEE>FEK(&$@=.%R;VQT86OI=F%L+@!!(&UE9V%D;W1T('-ZX6UR82!N96T@
M:_QL9&AE=/4@96P@87H@_'IE;F5T+@!:]FQD+69O:VDM<WII9V5T96L`P6)R
M87-Z]G9E9P!3>F]L9^%L=&%T\P!+871E9_-R:>%K(.ES(&IE;/9LZ7/\:P!+
M86IMX6XM<WII9V5T96L`36]B:6P@=&5L969O;@!#96QL871U;&%J9&]N<^%G
M;VL`0V5L;&$@8F5L<_4@;6%R9_,Z`$-E;&QA='5L86ID;VYSX6=O:P!#96QL
MX6L@:_9Z]G1T:2!RZ7,Z`$UO8FEL('1E;&5F;VX`:V5L=&$@*$E33RTX.#4Y
M+3$T*0!K]GKI<`!+]GKI<"UA9G)I:V%I($OV>G3A<G-A<^%G`&ME;&5T+65U
M<O-P86D@*$E33RTX.#4Y+3(I`$$@=&%N^G/M=';A;GD@<NES>FQE=&5I`$$@
M=&%N^G/M=';A;GD@='5L86ID;VYO<V$`5&%N^G/M=';A;GD@9F5L:&%S>F[A
M;.%S:2!I<N%N>65L=F5K`$-SX60`5N%L=&]Z=&%TX7,`02!J96QS>O,@X73A
M;&SM=.%S80!!>B#6;B#A;'1A;"!E;&O\;&3V='0@;&5V96QE:V5N('-Z97)E
M<&SU(&[I=B#I<R!C[6T@;65G=N%L=&]Z=&%TX7-A+@!!(&IE;&5N(&MO;F9I
M9W5RX6-I\V)A;B!N96T@;&5H971SZ6=E<R!A(&IE;'-Z879A:R!M\V1O<^UT
MX7-A+B!&;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+@!+87)A:W1E<@!,
M:6Y?:V5L;&5N]7)ZZ7,N+BX`2F5L]FQJ_&L@:VD@;6EN9"]E9WEI:V5T('-E
M;0!#:&EL90!+[6YA`&OM;F%I+"!E9WES>F5R^W/M=&5T="`H1T(R,S$R*0!K
M[6YA:2P@:&%G>6]MX6YY;W,@*$)I9S4I`%;A;&%S<WIO;B!K:2!E9WD@86QK
M86QM87KA<W0Z`%;A;&%S<WIO;B!E9WD@96QN979E>NES=`!6X6QA<W-Z;VX@
M:F5L<WKS=`!6X6QA<W-Z;VX@96=Y(&9E;&AA<WINX6SS;F5V970`5N%L87-S
M>F]N(&5G>2!C[6UJ96=Y>NEK970`5N%L87-S>F]N(&5G>2!C[6UJ96=Y>NEK
M970Z`%;A;&%S<WIA(&MI(&$@9.%T=6UO:R!M96=J96QE;NUTZ7-I(&9O<FWA
M:N%T.@!6X6QA<W-Z82!K:2!A(&9E;'-O<F]LX7,@=.UP=7/A="`H<WKA;6]Z
M;W1T(&QI<W3A:V[A;"D`5N%L87-S>F$@:VDL(&AO9WD@;65L>2!C[6UJ96=Y
M>NEK96L@:F5L96YJ96YE:R!M96<L(.ES(&UI;'EE;B!S;W)R96YD8F5N.@!6
MX6QA<W-Z82!K:2P@;65L>6EK(&/M;6IE9WEZZ6ME*&ME*70@:^UVX6YJ82!H
M87-Z;N%L;FDN`$UE;'EI:R!O<WIL;W!O:R!J96QE;FIE;F5K(&UE9R#I<R!M
M:6QY96X@<V]R<F5N9&)E;CH`2V%RX6-S;VYY+7-Z:6=E=&5K`$$H>BD@)7,@
M8VQA<W,@9&5F:6[M8VGS:F$@;F5M('1A;.%L:&%T\RX`1&5R_&QT`%3V<FQI
M(&%Z($U33V9F:6-E('1A9V5K970`02!L96OI<F1E>NES('3V<FSI<V4`)7,@
M9F5L:&%S>F[A;/,@=/9R;.ES90!!(&9E;&AA<WINX6SS('3V<FSI<V4`02!F
M96QH87-Z;N%L\R!A9&%T86EN86L@=/9R;.ES90!%<W3I<F4@9&5R_&QT(.EG
M`$$@9F]L>71A=.%S:&]Z(&MA='1I;G1S;VX@87H@96?I<G)E;`!#;&EC:V%T
M96QL('-Z;VQGX6QT873A<R!(5%10+6X@:V5R97-Z=/QL`$%Z(&%B;&%K(&)E
M>N%RX7-A`$)O<G5L="#I9P!296=G96P@9F5L:/5S(&ED]0!&96QH]7,@:63U
M`$OS:W5S>BUS>FEG971E:P!4_&YT97-S_&L@96P@87H@;VQD86QS\R!M96[\
M=`#6<W-Z97KA<G0@:V5R971E:P!+;VQU;6)I80!3>NUN`%-Z[6YVX6QA<WIT
M\P!3>NUN=N%L87-Z=.%S`$]S>FQO<&]K.@!!>B!O<WIL;W!O:R!B9>%L;.UT
MX7-A`$%Z(&]S>FQO<&]K(&/M;65I`$YE;2!M96=J96QE;O4@;W-Z;&]P;VLZ
M`%9I8V-E:P!697-S>O5V96P@96QVX6QA<WIT;W1T(.ER=.EK96L`5F5S<WKU
M=F5L(&5L=N%L87-Z=&]T="#I<G3I:V5K("A-:6-R;W-O9G0@3W5T;&]O:RD`
M4&%R86YC<P!087)A;F-SZ7)T96QM97KU`$UE9VIE9WEZZ7,`3NEV+"!E;&YE
M=F5ZZ7,`0V]M;W)E+7-Z:6=E=&5K`$UU;FMA:&5L>0!-=6YK86AE;'EI(&/M
M;0!3>N%M[73S9^EP96L`263U:N%RX7-I(&AE;'EZ970`263U:N%RX7-I(&AE
M;'EZ970`2_QL]FYB<^EG96L@82!K;VYF:6=U<N%C:?-B86X`2^EZ:7-ZX6WM
M=/-GZ7!E:VME;"P@;VMO<W1E;&5F;VYO:VMA;"P@3W5T;&]O:VMA;"!V86SS
M(&%D871S>FEN:W)O;FEZX6SA<R!K;VYF:6=U<N%C:?-J80!!(&MO;F9I9W5R
MX6-I\R!MX7(@;F5M(.ER=NEN>65S+@`E<R!K;VYF:6=U<N%C:?-J80!!(&IE
M;'-Z\R!M96=E<O5S[73I<V4`2V]N9_,`2V]N9_-I($1E;6]K<F%T:6MU<R!+
M]GITX7)S87/A9P!3:6ME<G1E;&5N(&$@:V%P8W-O;&%T+@!3:6ME<G1E;&5N
M(&$@:V%P8W-O;&%T.B``02!K87!C<V]L870@;F5M('-I:V5R_&QT.B`E<P!!
M(&MA<&-S;VQA="!N96T@<VEK97+\;'0`02!N>6EL=N%N;W,@:W5L8W-O:R!S
M>F5R=F5R92!E;'5T87/M=&IA(&$@:V%P8W-O;&%T;W0N`$$@;GEI;';A;F]S
M(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA=&]T+B!/
M:V$Z("5S("@E<RD`4VEK97)T96QE;B!A>B!&5%`@<WIE<G9E<G)E;"!V86SS
M(&MA<&-S;VQA="X`0^UM:V5R97/I<P!087)T;F5R96L`02`E<R!L:7-T82!T
M86=J86D`02!P87)T;F5R96ME="!S:6ME<F5S96X@:&]Z>N%A9'1U:R!A(&/M
M;6IE9WEZZ6OI:&5Z+@!!('3V;?9R[71E='0@X6QL;VWA;GD@=.UP=7-A.B``
M(B5S(B!T87)T86QM80!&;VQY=&%TX7,`0V]O:RUS>FEG971E:P!3_'1I`$WA
M<V]L:G5K(.%T`$$@;>%S;VSA<R!N96T@<VEK97+\;'0Z("5S`$$@:VEJ96SV
M;'0@<NES>B!MX7-O;.%S80!3>N%M;.%ZX7-I(&%Z;VYO<^UT\P!#;W-T82!2
M:6-A`$5L96;A;G1C<V]N='!A<G0`3F5M('-I:V5R_&QT(%!'4"UV96P@=&ET
M:V]S[71A;FD@82!L979E;&5T.B``02!L979E;&5T(&YE;2!S:6ME<OQL="!0
M1U`@86SA[7+A<W-A;"!E;&SA=&YI.B``02!L979E;&5T(&YE;2!S:6ME<OQL
M="!A>B!3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&%N:2X`02!L
M979E;&5T(&YE;2!S:6ME<OQL="!3+TU)344@86SA[7+A<W-A;"!E;&SA=&YI
M+@!!('!A<G1N97(@861A=&%I="!N96T@<VEK97+\;'0@96QTX7)O;&YI+B`E
M<P!!>B!,1$%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`3F5M('-I:V5R_&QT
M(&5L;&5N]7)I>FYI(&$@<WKA;6SA:N%N(')E;F1E;&ME>NES<F4@X6QL\R#V
M<W-Z96=E="X@)7,`3F5M('-I:V5R_&QT(&%Z($Q$05`@<WIE<G9E<FAE>B!K
M87!C<V]L\V1N:2X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(B!S>F5R=F5R<F5L
M($944"!K87!C<V]L871O="!F96QV96YN:3H@)7,`3F5M('-I:V5R_&QT(&SI
M=')E:&]Z;FD@82!K]G)L97;I;&QI<W3A="X@)7,`07H@861A=&]K(%!'4"!T
M:71K;W/M=.%S8O-L('3V<G3I;O4@9&5K\V1O;.%S82!N96T@<VEK97+\;'0Z
M(`!!>B!A9&%T;VL@4R]-24U%('1I=&MO<^UTX7-B\VP@=/9R=.EN]2!D96OS
M9&]LX7-A(&YE;2!S:6ME<OQL="X`02!P87)T;F5R('3V<FSI<V4@;F5M('-I
M:V5R_&QT+B`E<P!!(&OV<FQE=NEL;&ES=&$@=/9R;.ES92!N96T@<VEK97+\
M;'0N("5S`$YE;2!S:6ME<OQL="!T]G+V;&YI(&$H>BD@(B5S(B!S971U<"!U
M<&=R861E('!R;V=R86UO="X`3F5M('-I:V5R_&QT(&UE9^%L;&%P[71A;FD@
M82!C[6UZ971T(&5M86EL(&/M;>ET+@!.96T@<VEK97+\;'0@8F5O;'9A<VYI
M(&$@=&5L:F5S(&/M;6IE9WEZZ6ME="X`3F5M('-I:V5R_&QT(&)E;VQV87-N
M:2!A('1E;&IE<R!K]G)L97;I;&QI<W3A="X`3F5M('-I:V5R_&QT(&)E;VQV
M87-N:2!A(&OV<FQE=NEL;&ES=.%K('1E;&IE<R!F96QS;W)O;.%SX70N`$$H
M>BD@(B5S(B!S=')A=.EG:6$@;F5M('1A;.%L:&%T\RX`02AZ*2`B)7,B(&%L
M:_9N>79TX7(@;F5M(&AO>FAA=/,@;.ET<F4N`$$@;GEI;';A;F]S(&MU;&-S
M;W0@;F5M('-I:V5R_&QT(&UE9W-Z97)E>FYI(&$@:W5L8W-S>F5R=F5R<O5L
M+@!.96T@<VEK97+\;'0@(B5S(BUT(.URX7-I(&/I;&QA;"!M96=N>6ET;FDN
M`$YE;2!S:6ME<OQL="`E<RUT(&UE9VYY:71N:2X`02`E<R!K87)B86YT87)T
MX7-I(&UO9'5L(&YE;2!N>6ET:&%T\R!M96<`02AZ*2`B)7,B(&%L:_9N>79T
MX7(@;F5M(&YY:71H873S(&UE9RX`07H@3$1!4"!S>F5R=F5R(&YE;2#I<FAE
M=/4@96PN`"5S(&YE;2!O;'9A<VAA=/,N`$YE;2!S:6ME<OQL="!A(&OM=N%N
M="!F96QH87-Z;N%L\R!J96QS>F%VX70@X73A;&SM=&%N:2X@07H@;65G861O
M='0@861A=&]K(&YE;2!V86=Y(&YE;2!T96QJ97-E;B!F96QE;&YE:R!M96<N
M(%!R\V+A;&IA(/IJ<F$L('9A9WD@:&$@=&]VX6)B:2!S96?M='/I9W)E('9A
M;B!S>OQK<^EG92P@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BX`3F5M
M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A>B!E;.ERZ7-I(&IO9V]S=6QT<^%G
M;VMA="`H04-,*0!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@8^UM:F5G>7KI
M:V5T+B`E<P!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5VZ6QL:7-T
MX70N("5S`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A
M:V%T+B`E<P!.96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&$@<WIE<G9E<B!K
MZ7!E<W/I9V5I=`!.96T@<VEK97+\;'0@=FES<WIAX6QL[71A;FD@97H@97)E
M9&5T:2!K;VYF:6=U<N%C:?-T+@!!*'HI("(E<R(@86QK]FYY=G3A<B!N96T@
M=/9R]FQH973U+@!.96T@<VEK97+\;'0@96QM96YT96YI("5S(&MO;F9I9W5R
MX6-I\W0N`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82!B86-K=7`@:V]N9FEG
M=7+A8VGS="X`3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A(&)A8VMU<"!K;VYF
M:6=U<N%C:?-T.B`E<P!.96T@<VEK97+\;'0@96QM96YT96YI(&$H>BD@(B5S
M(B!S971U<"!U<&=R861E('!R;V=R86UO="X`3F5M('-I:V5R_&QT(&5L;65N
M=&5N:2!A*'HI("5S(&)A8VMU<"!K;VYF:6=U<N%C:?-T+@!!*'HI("5S(&MO
M;F9I9W5RX6-I\W,@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!E;&UE;G1E;FDN
M(%9A9WD@:&%S>F[A;&IA(&$@)7,@;VQD86QO;B!L97;U(&QE:&5T]7/I9V5K
M970L('9A9WD@;>%S;VQJ82#A="!A>B!A;.%B8FD@:_-D;W0@:61E.B`E<RX`
M07H@3$1!4"!S>F5R=F5R96X@;F5M('-I:V5R_&QT(&5L=NEG97IN:2!A(&ME
M<F5SZ7-T+@`B)7,B(&YE;2!V;VQT('3V<O9L:&5T]2X`02!P87)T;F5R(&%D
M871A:70@;F5M('-I:V5R_&QT(&WS9&]S[71A;FDN("5S`$YE;2!S:6ME<OQL
M="!A(&OV<FQE=NEL;&ES=&$@;?-D;W/M=.%S82X@)7,`3F5M('-I:V5R_&QT
M(&5L;65N=&5N:2`B)7,B(&MO;F9I9W5RX6-I\VKA=#H@)7,`02!-;WII;&QA
M(&UE;OQS;W(@;F5M('1A;.%L:&%T\RX@16QL96[U<FEZ>F4L(&AO9WD@;65G
M('9A;BUE(&YY:71V82X`3F5M('-I:V5R_&QT("(E<R(@9F5L:&%S>F[A;/-N
M86L@:F]G;W-U;'1SX6=O="!A9&YI(&$H>BD@(B5S(B!M87!PX6AO>CH@)7,`
M2V]R;.%T;W,@<WKV=F5G`$]R<WKA9P!4X79O:W1A=.%S`$SI=')E:&]ZX7,`
M0^UM:F5G>7KI:R!LZ71R96AO>N%S80!,:6YK(&SI=')E:&]ZX7-A`-IJ(&/M
M;6QI<W1A(&SI=')E:&]ZX7-A(&ET=#H`VFH@;.ET<F5H;WKA<V$`06QM87!P
MX6L@;.ET<F5H;WKA<V$`3.ET<F5H;WIV80!!>B!O8FIE:W1U;2!LZ71R96AO
M>O-JX6YA:R!J;V=O<W5L='/A9V%I`$AI=&5L:^%R='EA<WKA;0!(;W)VX71O
M<G-ZX6<`2W5B80!*96QE;FQE9VD@-"!FX7II<P!!(&IE;&5N;&5G:2!F96QH
M87-Z;N%L\VMA<&-S;VQA=&]K`%!O;G1O<R!I9/4`02!J96QE;FQE9VD@55),
M`$IE;&5N;&5G:2!F96QH87-Z;N%L\VL`2F5L96YL96=I(&ED]6KA<N%S`$$@
M:F5L96YL96=I(&ED]6KA<N%S:2!H96QY>F5T.@!*96QE;FQE9VD@<W3M;'5S
M`$UI;'EE;B!P87)A;F-S;VL@9G5S<V%N86L@;&4@875T;VUA=&EK=7-A;B!A
M("5S8F4@=/9R=.EN]2!B96IE;&5N=&ME>NES:V]R+@!+:7;A9^%S`$$@:VEJ
M96SV;'0@<NES>B!K:7;A9^%S80!#:7!R=7,`8VER:6QL("A+3TDX+5(I`&-I
M<FEL;"`H5VEN9&]W<RTQ,C4Q*0!C:7)I;&PM=6MRX6X@*$M/23@M52D`0W-E
M:"!+]GITX7)S87/A9P!$1`!$4TX@*&%D871F;W)RX7-L9>UR\R`M(&SA<V0Z
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"D`;F%P;VYT80!$871A5')E92!B]FYGZ7-Z
M]0!!9&%T8N%Z:7-B86X@=F%L\R!K97)E<^ES`$3A='5M`$$@8F7I<FME>NES
M(&YA<&IA`$3A='5M(&MI=N%L87-Z=.%S80!N87!P86P`3W-Z;&]P('3V<FSI
M<V4`9&5C96UB97(`<WKA;6]K`$)E:V5Z9.ES(&MI:FIE8F(`06QA<.ER=&5L
M;65Z971T`$%Z(&%L87#I<G1E;&UE>NES('-Z97)I;G1I('-Z[6X`06QA<.ER
M=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S[73S`$%L87#I<G1E;&UE>F5T="!S
M:&5L;`!!('-O<F)A<F5N9&5ZZ7,@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@
M:7+A;GEA.@!$969I;NUC:?-K`%3V<FSI<P!#[6UJ96=Y>NEK('3V<FSI<V4`
M02!C96QL82!T]G)LZ7-E`$$@=/9R;.ES(&UE9V5R]7/M=.ES90!!(&-S;W!O
M<G0@=/9R;.ES90!!(&YA<&SSX6QL;VWA;GD@=/9R;.ES90!!(&IO9V]S=6QT
M<^%G('3V<FSI<V4`3&5V96QE:R!T]G)LZ7-E`$$@=/9R;.ES(&=O;6(@=FES
M96QK963I<V4`02!C96QL82!T]G)LZ7-E`$%Z(&]S>FQO<"!T]G)LZ7-E`%3V
M<O9L:OQK(&MI(&$@;65G;.EV]2!A;'1E<FYA=.UV('-A8FQO;G0`02!T]G)L
MZ7,@;F5M('-I:V5R_&QT.B`H)7,I("5S`$$@;&5V96QE:R!T]G)LZ7-E`"(E
M<R(@:F]G;W-U;'1SX6=A:6YA:R!T]G)LZ7-E`%3V<O9L:OQK("(E<R(@:F]G
M;W-U;'1SX6=A:70@Z7,@96YN96L@97-E=&QE9V5S(&%L8W-O<&]R=&IA:70_
M`$$@<V]R('3V<FSI<V4`02!K:7;A;&%S>G1O='0@87IO;F]S[73S('3V<FSI
M<V4`07H@86QM87!PX6L@=/9R;.ES90!!(&IE;&5N;&5G:2!O<WIL;W`@=/9R
M;.ES90!!(&IE;&5N;&5G:2!S;W(@=/9R;.ES90!4]G+V;'3\:R!A*'HI("(E
M<R(@<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N`$$@8^UM:F5G>7KI:V+U;"!N
M96T@;&5H970@=/9R]FQN:2X`02!T]G)LZ7,@;F5M('-I:V5R_&QT`$$@:^EZ
M8F5S[73I<R!I9&5J90!$X6YI80!2Z7-Z;&5G`&-S]FMK96[U`$%D:F]N(&QE
M[7+A<W0@82!P<F]B;.EMX7+S;`!,9>URX7,`4NES>FQE=&5K("AA($AO<F1E
M(&QO9V;A:FQB86X@:7,@;65G=&%LX6QH873S*3H`02!RZ7-Z;&5T96L@82!R
M96YD<WIE<F=A>F1A('-ZX6WA<F$@:^ES>OQL]2!N87!L\V;A:FQB82!K97+\
M;'1E:RX`1F5J;&5S>G3I<P!(87)M871P;VYT`$AA<FUA='!O;G0@:F5L96YL
M96<Z(`!(87)M871P;VYT.B``8F%L<O-L(&IO8F)R82#M<N%S`&IO8F)R\VP@
M8F%L<F$@[7+A<P!#[6UTX7(`365G:F5L96[M=.ES`$%Z(&ED]7!O;G1O:V%T
M(#(T(/-RX7,@9F]R;>%T=6UB86X@:F5L96[M='/\:R!M96<_`$UE9VIE;&5N
M[73I<VD@8F7A;&SM=.%S;VL`02!RZ7-Z;&5T97,@96SU<F5J96QZZ7,@;65G
M:F5L96[M=.ES90!%;/5R96IE;'KI<R!M96=J96QE;NUTZ7-E("AR97#\;/5T
MZ7)I*0!-96=J96QE;NUTZ7-I(&9O<FWA='5M`,ER=&5S[73I<R!A(&OI>F)E
M<^UT971T(&QE=NEL('-O<G/A<O-L`$1Z<VEB=71I`$YE('3V<O9L:OQK`$$@
M;6%I;G1E;F%N8V4N<&AP(&YE;2#I<FAE=/4@96P@:_9Z=F5T;&5N_&PN`$%Z
M(&%D871O:R!T]G)LZ7/I="!M96=E;/5Z]65N(/-H86IT+64@96=Y(&UE9V5R
M]7/M=/4@:^ER9.ES=#\`07H@96QS]2!S;W(@82!M97KU:R!N979E:70@=&%R
M=&%L;6%Z>F$_($AA(&EG96XL(&IE;/9L:F4@:VD@97IT.@!$;VUI;FEK80!$
M;VUI;FEK86D@2_9Z=.%R<V%SX6<`3FEN8W,@;>EG(&QO9VEN(&YE=F4_($EG
MZ6YY96QJ96X@96=Y970N`$QE=/9L=.ES`%3V;'1S_&L@;&4@)7,M=`!4]FQT
M<_QK(&QE(%!(4"!P<F]G<F%M(&9O<FWA:N%B86X@87H@96QKZ7-Z_&QT(&MO
M;F9I9W5RX6-I\W0N`'9#87)D(&QE=/9L=.ES`$QE9_9R9/QL]2!L:7-T80!+
MX6+M=/-S>F5R96L`96UA:6P`16UA:6QB]6P@4TU3+6O\;&3U(&UE9VAA:G3S
M+"!H82!A('1E;&5F;VYTX7)S87/A9R!B:7IT;W/M=&IA(&5Z="!A('-Z;VQG
MX6QT873A<W0N`$A)0D$`16-U861O<@!-\V1O<^UTX7,`(B5S(B!M\V1O<^UT
MX7-A`$/M;6IE9WEZZ6ME:R!M\V1O<^UTX7-A`$)L;VMK(&WS9&]S[73A<P!#
M<V]P;W)T(&WS9&]S[73A<P!*;V=O<W5L='/A9R!M\V1O<^UTX7,`2F]G;W-U
M;'1SX6=O:R!M\V1O<^UTX7-A`"5S(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M
M=.%S80!-\V1O<^UT<W5K("5S(&%D871A:70`365L>6EK(&]P8VGS:V%T(';A
M;'1O>G1A<W-U:SH`(B5S(B!J;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$`
M)7,@:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A`$]K=&%TX7,`16=Y:7!T
M;VT`4V%L=F%D;W(`16QE;2XN+@!A>B`G;2<@8F5T^R!S>NEL97-SZ6=E`$5M
M86EL`$5M86EL(&/M;0!!>B!E;6%I;"!C[6UE:VYE:R!E9WEE>FYI_&L@:V5L
M;"X`16UA:6P@=FES<WIA:6=A>F]LX7-S86P`16UA:6PM4TU3(.%T:N%R\P!(
M86YG=6QA=&EK;VYO:P#<<F5S(/QZ96YE="X`3FEN8W,@:6QY96XN`%3V<O9L
M:OQK(&MI(&$@:V5R97/I<V5K970`16YG961J_&L@;65G+"!H;V=Y(&OI<&5K
M970@:6QL97-S>OQN:R!A('-Z]G9E9V)E(&$@1F]T\V=A;.ER:>%K8O-L/P!,
M96=Y96X@:F]B8B!E9^ER9V]M8F)A;"!E;.ER:&5T]2P@:V]N=&5X='5S9OQG
M9_4@;65N_#\`07H@=71O;'/S(.EV`,%T=N%L=.%S(&O\;/9N(&%B;&%K<F$`
M061J82!M96<@87IT(&$@8FEZ=&]N<^%G:2!KZ7)DZ7-T+"!A;65L>7)E(&UA
M:F0@=N%L87-Z;VQN:6$@:V5L;"!J96QS>F%VX6YA:R#A=.%L;.UTX7/A:&]Z
M+"!P;"X@)VAO9WD@:.UV:N%K(&$@:W5T>>%JX70_)SH`061J82!M96<@82!K
MZ7`@55),+6KI="!I='0`S7)J82!B92!A>B!A;.%B8FD@8F5T^VME=#H`)7,@
M861A=&%I="!M\V1O<^UT;W1T=6LL(&1E(&$@9F5L=/9L=/9T="#A;&QO;>%N
M>70@;F5M('-I:V5R_&QT(&5L;65N=&5N:3H@)7,`)7,@^FH@861A=&%I="!E
M;&UE;G1E='3\:RX`16=Y96YL[73U:2U'=6EN96$`17)I=')E80!(:6)A`$AI
M8F$@=/9R=.EN="!A("5D('!A<G1N97)N96L@82!C[6UL:7-TX6AO>B!V86SS
M(&AO>GKA863A<V%K;W(N`"5D(&AI8F$@=/9R=.EN="!A("5D('!A<G1N97)N
M96L@82!C[6UL:7-TX6AO>B!V86SS(&AO>GKA863A<V%K;W(N`$AI8F$@=/9R
M=.EN="!A(&)L;VMK(&SI=')E:&]ZX7-A:V]R.B`E<P!(:6)A('3V<G3I;G0@
M82`E9"!P87)T;F5R('3V<FSI<V5K;W(N`"5D(&AI8F$@=/9R=.EN="!A("5D
M('!A<G1N97(@=/9R;.ES96MO<BX`2&EB82!T]G)TZ6YT(&%Z(&%D871S>FEN
M:W)O;FEZX6-I\W,@:F5L('3V<FSI<V5K;W(Z("5S`$%Z(&%D871S>FEN:W)O
M;FEZX6-I\W,@;F%P;//A;&QO;>%N>2!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@
M)7,`2&EB82!T]G)TZ6YT(&%Z(&%D871L96OI<NES8F5N.B`E<P!(:6)A('3V
M<G3I;G0@82`E9"!P87)T;F5R;F5K(&$@8^UM;&ES=.%B\VP@=F%L\R!T]G)L
MZ7-E:V]R+@`E9"!H:6)A('3V<G3I;G0@82`E9"!P87)T;F5R;F5K(&$@8^UM
M;&ES=.%B\VP@=F%L\R!T]G)LZ7-E:V]R+@!(:6)A('3V<G3I;G0@82!C[6UJ
M96=Y>NEK8F5N('9A;/,@:V5R97/I<R!S;W+A;CH@)7,`2&EB82!T]G)TZ6YT
M(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%S86MO<CH@)7,`2&EB82!A>B!E;6%I
M;"#\>F5N971B96XN`$$H>BD@(B5S(B#A;&QO;>%N>7)A(&YE;2!S:6ME<OQL
M="#M<FYI+@#)<WIT;W)S>N%G`$5T:?-P:6$`3F5M>F5T:7/I9V5K`$5U<O-P
M80`Q-2!P97)C96YKZ6YT`#(@<&5R8V5N:^EN=``S,"!MX7-O9'!E<F-E;FOI
M;G0`-2!P97)C96YKZ6YT`&UI;F1E;B!B96IE;&5N=&ME>NES:V]R`&;I;/-R
MX6YKZ6YT`'!E<F-E;FOI;G0`4.EL9&$@Z7)TZ6ME:SH`5NEG<F5H86ITX7,`
M3GEI<W-U:R!S>NET`$IE;&5N[71S_&L@;65G(&%Z(&]L9&%L<_,@;65N_'0`
M271T("<I)R!K96QL96YE(&OV=F5T:V5Z>F5N`$ET="!C<W5P87-Z('-Z\VYA
M:R!V86=Y(&EDZ7KU:F5L8F5N(&QE=O4@:V5R97/I<VD@:VEF96IE>NES;F5K
M(&ME;&QE;F4@;&5N;FEE`$%Z(.ER=NEN>65S<^EG(&QE:N%R871A`$MI=&5V
M]0!%>'!O<G3A;.%S`$/M;6IE9WEZZ6L@97AP;W)TX6SA<V$`0W-A:R!A(&MI
M:F5L]FQT(&QE=F5L97KU<&%R=&YE<F5K970@97AP;W)TX6QJ=6LN`$$@=&5L
M:F5S(&/M;6IE9WEZZ6ME="!E>'!O<G3A;&IU:RX`4WKM;@!!(&MO;F9I9W5R
MX6-I\R!&5%`M;B#A="!V86SS(&9E;'3V;'3I<V4`02!S>F5MZ6QY97,@8F7A
M;&SM=.%S;VMA="!N96T@<VEK97+\;'0@8F5O;'9A<VYI+@!!*'HI("5S(&/M
M;6IE9WEZZ6L@;F5M(.ER:&5T]2!E;"X`3F5M('-I:V5R_&QT("5S(&AO>GKA
M863A<V$@)7,M:&5Z.B`E<P!.96T@<VEK97+\;'0@82!L:7-T82!B]FYGZ7-Z
MZ7-E`$$@8^UM=.%R(&+V;F?I<WKI<V4@;F5M(&QE:&5T<^EG97,`3F5M('-I
M:V5R_&QT(&$@;NEV(&UE9W;A;'1O>G1A=.%S83H@*"5S*2`E<SL@<NEG:2!$
M3B`]("5S+"#Z:B!$3B`]("5S+"!G>?9KZ7(@/2`E<P!!>B!,1$%0('-Z97)V
M97(@;F5M(.ER:&5T]2!E;"X`07H@4TU"('-Z97)V97(@;F5M(.ER:&5T]2!E
M;"X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(BUB]6P@=/9R=.EN]2!MX7-O;.%S
M+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B+6)E('3V<G3I;O4@;>%S;VSA<RX`
M3F5M('-I:V5R_&QT(/IJ(%-!4TP@:V%P8W-O;&%T;W0@;.ET<F5H;WIN:2X`
M3F5M('-I:V5R_&QT(&UE9W1A;.%L;FD@82!B979I96YD]2!O8FIE:W1U;6]T
M.B`E<P!.96T@<VEK97+\;'0@82AZ*2`B)7,B+6)E('3V<G3I;O4@X71H96QY
M97KI<RX`P6QL;VWA;GEH;WIZX6;I<NES:2!H:6)A.B`E<P!!(&/M;6IE9WEZ
MZ6MB96X@;F5M('-I:V5R_&QT(&$@:V5R97/I<RX`3F5M('-I:V5R_&QT(&$@
M)7,@8^UM=.%R8F%N('9A;/,@:V5R97/I<P!4:7-Z=&$`1F%L:VQA;F0M<WII
M9V5T96L@*$UA;'9I;F%S*0!&87)O92US>FEG971E:P!(96QY<F5H;WIH871A
M=&QA;B!H:6)A.@!&87@`1F%X`&9E8G)UX7(`2/5MZ7)SZ6ML973I<GIE=`!(
M]6WI<G/I:VQE=.ER>F5T.B``16=Y+65G>2!ZX7!O<@!3>O-R=N%N>6]S86X@
M:/-ZX7!O<F]K`$UE>O4@;>%T<FEX`$9I9VQE="!#05!40TA!("AB973[:VER
M86OS(&AU;>%N=&5S>G0I`$9I9'IS:0!&X6IL`$$@9N%J;&]K('-ZX6UA.B`E
M<P!!(&;A:FQO:R!S>N%M83H@)7,`1N%J;"!M96YE9'IS97(`1N%J;&[I=@!&
MX6IL(&MI:F5L]FSI<P!&X6IL(&9E;'3V;'3I<V4`1N%J;&]K(&9E;'3V;'3I
M<V4@;F5M(&QE:&5T<^EG97,N`$;A:FP`4WK[<O5K`$UE>O4`0F5F96IE>NES
M`$9I;FYO<G-ZX6<`96QS]2!FZ6P`2V5R97-Z=&[I=@!E;'/U(&YE9WEE9`!6
MX6QT;WIA=&QA;B!MZ7)E=&%RX6YY`%3\:W+V>NES("AF]FPO;&4I`$OV9``E
M<R!M87!P82!N96T@;.ET97II:P!"973[<WKM;@#)=&5L96L`3VQY86X@8O9N
M9^ES>O5K('-ZX6WA<F$L(&%M:6L@;F5M(&IE;&5N[71I:R!M96<@82!KZ7!E
M:V5T`$5L]7)E:F5L>NES("AR97#\;/5TZ7)I*0!!>B!E;/5R96IE;'KI<R!I
M9/5T87)T86UA(&YA<&]K8F%N("AA>B!E;/5R96IE;'KI<R!N87!P86QI(.ES
M(.EJ<WIA:V%I(&%D871O:V%T('1A<G1A;&UA>BP@97KI<G0@82!N86=Y('-Z
MX6UO:R!S>NEL97,@8FQO:VMO="!E<F5D;>EN>65Z;F5K*0!%;&9E;&5J=&5T
M=&4@82!J96QS>F%VX70_`-MR;&%P:V5Z96SI<P!)9.EZ970`263I>F5T(&9A
M:G3A:F$`263I>F5T96L`263I>F5T96L@,@!&\W)U;6]K`%1O=N%B8NUTX7-O
M:P!0Z0!&<F%M92UE:P!&<F%N8VEA;W)S>N%G`$9R86YC:6%O<G-ZX6<`263U
M8F5O<WITX7-I('=E8B!C[6T`1G)A;F-I82!'=7EA;F$`1G)A;F-I82!0;VQI
M;NEZ:6$`1G)A;F-I82!$Z6QI(%1E<OQL971E:P!H;VYN86X`27+A;GDZ(`!2
MZ7-Z;&5T97,@;&7M<N%S`'1E;&EH;VQD`%1E;&IE<R!NZ78`1V%B;VX`365L
M>6EK(&=A;.ER:>%B\VP@=F5G>?QK(&$@:^EP970`2^EP9V%LZ7)I83H`1V%M
M8FEA`$AO>GIU:R!LZ71R92!A*'HI("5S(&MO;F9I9W5RX6-I\VKA=`!!(&ME
M;&5T:V5Z971T(&OS9`!'<OIZ:6$`3NEM971O<G-ZX6<`1VCA;F$`1VEB<F%L
M=.%R`$ME<F5S>G1NZ78`1VQO8N%L:7,@8^UM:F5G>7KI:P!';&]BX6QI<R!B
M9>%L;.UTX7-O:P!-96AE=`!']F1E;`!';V]G;&4@=.ER:^EP`$=O;V=L92!K
M97)E<^ES`$9E:V5T92]F96CI<@!']G+V9V]R<WKA9P!G]G+V9R`H25-/+3@X
M-3DM-RD`1W+V;FQA;F0`1W)E;F%D80!#<V]P;W)T`$-S;W!O<G0@861M:6YI
M<WIT<N%C:?,`02!C<V]P;W)T;NEV(&UA<F%D:&%T(/QR97-E;@!'<F]U<%]L
M9&%P.B`E<R!C<V]P;W)T(&AO>GKA863A<V$@;F5M('-I:V5R_&QT+B!!('-Z
M97)V97(@=N%L87-Z83H@`$=R;W5P7VQD87`Z("5S(&-S;W!O<G0@=/9R;.ES
M92!N96T@<VEK97+\;'0`1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!A9&%T86EN
M86L@;65G^FKM=.%S82!N96T@<VEK97+\;'0`0W-O<&]R=&]K`$=U861E;&]U
M<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`5F5N9.EG(&IO9V]S=6QT<^%G
M;VL`5F5N9.EG:_9N>78`1W5I;F5A`$)I<W-A=2U'=6EN96$`1W5Y86YA`$A4
M34Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A('-O<B!U=&]L<_,@
M8V5L;.%JX70@=/9R]FQN:2X`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA
M:FQA;F3S(&$@=.%B;.%Z870@=71O;'/S(&]S>FQO<.%T('3V<O9L;FDN`$A4
M34Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A('3A8FSA>F%T('5T
M;VQS\R!S;W+A="!T]G+V;&YI+@!!($A45%`@9F5L:&%S>F[A;/-A>F]N;W/M
M=.%S(&YE;2!T86SA;&AA=/,N`$AA:71I`$AA<V@@86QG;W)I=&UU<P!+]F0`
M1F5J;.EC`$9E:FSI8P!(96%R9"T@Z7,@36-$;VYA;&0M<WII9V5T96L`17+U
M<R!Z:79A=&%R`&CI8F5R("A)4T\M.#@U.2TX+4DI`$UA9V%S<^%G`%-E9^UT
M<^EG`%-E9^UT<^EG(&$@<WIE<FME<WIT]2!H87-Z;N%L873A:&]Z`%-E9^UT
M<^EG`$;I;'1E:V4`17H@82!FX6IL(&5L96IE.@!N86=Y`$ME>F3U;&%P`%9A
M=&EKX6YVX7)O<P!+97ID]6QA<`!/='1H;VYI(&/M;3H@=71C80!/='1H;VYI
M(&/M;3H@=N%R;W,`3W1T:&]N:2!C[6TZ(&]R<WKA9P!3>F5MZ6QY97,@86QK
M]FYY=G3A<@!/='1H;VYI('1E;&5F;VX`3W1T:&]N:2!C[6TZ(&ERX6YY[73S
M<WKA;0!/='1H;VYI(&/M;3H@X6QL86TO=&%R=&]MX6YY`$]T=&AO;FD@8^UM
M.B!U=&-A`$AO;F1U<F%S`$AO;F=K;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!H
M:6+A<R`E<R!834P@861A="!V86X@82AZ*2`E<R#\>F5N971B96X`2&]R9&4O
M2V]L86(Z(&YI;F-S(&$H>BD@)7,@;V)J96MT=6UN86L@;65G9F5L96SU(/QZ
M96YE=`!(;W)D92]+;VQA8CH@;FEN8W,@)7,@=.UP=7/Z(&]B:F5K='5M(&$H
M>BD@)7,@_'IE;F5T8F5N`$AO<F1E+TMO;&%B.B!3:6ME<F5S96X@=/9R]FQT
M_&L@97IT.B`E<R`B)7,B`$AO<F1E+TMO;&%B.B!A>B!I;G1E9W+A;/,@<')O
M9W)A;6AO>B!S>OQK<^EG97,@82`G9&]M>&UL)R!02%`@8O5V[73I<P!(;W)D
M92]+;VQA8CH@;F5M('-I:V5R_&QT(/IJ(%A-3"!FX70@;.ET<F5H;WIN:2!A
M*'HI("5S(&]B:F5K='5M:&]Z`$AO<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@
M=/9R]FQN:2`E<RUT("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!N96T@<VEK97+\
M;'0@;65G:&%TX7)O>FYI(&$@34E-12!)1"UJX70@82!K]G9E=&ME>O4@=.UP
M=7/Z(&UE;&SI:VQE=&YE:SH@)7,`2&]R9&4O2V]L86(Z($YE;2!S:6ME<OQL
M="!S>FEN:W)O;FEZX6QN:2`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@3F5M
M('-I:V5R_&QT(&$@:_9V971K97KU(&OV>O9S('3A<G1E<OQL970@<WII;FMR
M;VYI>N%LX7-A.B`E<P!(;W)D92]+;VQA8CH@:7-M97)E=&QE;B!K]GKV<R!T
MX7)T97+\;&5T("(E<R(`5NUZ<WII;G1E<R!V;VYA;`!6[7IS>FEN=&5S(&UA
M<F?S`%;M>G-Z:6YT97,Z`$AO9WD@:G5T;W1T(&ED93\@*$OI<FK\:R#M<FIA
M(&UE9R$I`$CA;GD@;W-Z;&]P;W0@:^UVX6X@]G-S>F5O;'9A<WIT86YI/P!(
MX6YY(&UE>O4@*&]S>FQO<"D@=F%N/P!(X6YY('-O<G0@:^UVX6X@]G-S>F5O
M;'9A<WIT86YI/P!0X7)A=&%R=&%L;VT`4.%R871A<G1A;&]M.B``2'5M;W)I
M<W3A:P!-86=Y87)O<G-ZX6<`07H@24U!4"!L97;I;&SA9&$@;.ET<F5H;WKA
M<V$@;F5M('-I:V5R_&QT.B`E<P!!>B!)34%0(&QE=NEL;.%D82!T]G)LZ7-E
M(&YE;2!S:6ME<OQL=#H@)7,`07H@24U!4"!L97;I;&SA9.%H;WH@=&%R=&]Z
M\R!K=O-T82!LZ71R96AO>N%S82!N96T@<VEK97+\;'0Z("5S`$E-4U`@8^UM
M:F5G>7KI:R!K97IE;.ES90!)4"!C[6T`07H@25`@8^UM(&YE;2!H873A<F]Z
M:&%T\R!M96<N`$%Z($E0(&/M;2!N:6YC<R!A(&UE9V5N9V5D971T($-)1%(@
M=&%R=&]MX6YY8F%N+@!4:6QT;W1T+VUE9W;A;'1O>F]T="!)4"!C[6TN`%-O
M<B!B96EL;&5S>G3I<V4@96;V;.D`27IL86YD`&-S86L@:6MO;F]K`"5S(&EK
M;VYJ86D`:6MO;F]K(.ES('-Z]G9E9P!!>B!A>F]N;W/M=/-H;WH@=N%L87-Z
M=&]T="!E;&YE=F5ZZ7,Z`$AA(&$@;65G:F5L96[M=.ES(&YE;2!M96=F96QE
M;/4L("5S(&5G>2#Z:B!A8FQA:V)A;B!V86SS(&UE9VYY:73A<VAO>BX`2&$@
MUFX@26YT97)N970@17AP;&]R97)T(&AA<WINX6PL(.ES(&YE;2!J96QE;FYE
M:R!M96<@87H@:6MO;F]K+"!A:VMO<B!VX6QA<W-Z82!E>G0@87H@;W!C:?-T
M+"!M96QL>65L(&MI:V%P8W-O;&IA(&$@4$Y'(&OI<&5K('1R86YS>G!A<F5N
M8VGA:N%T+@!(82!LX71J82!E>G0@82!S>O9V96=E="P@9&4@82!KZ7!E="!N
M96TL(&%K:V]R(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!KZ7!E<R!M96=J96QE
M;NUT96YI(&$@<WIE<G9E<G)E(&O\;&1E;F3U(&OI<&5T+@!%;/5Z971E<R!N
MZ7IE=#H`02!KZ7`@55),+6IE`$$@:^EP(%523"UJ93H`365L>6EK(&=A;.ER
M:>%B\VP@=F%N(&$@:^EP`$OI<"!E8F+U;"!A(&=A;.ER:>%B\VPZ`$OI<"!F
M96QT]FQTZ7-E`$OI<&5K`$/M;6IE9WEZZ6L@:6UP;W)TX6SA<V$L("5D+B!L
MZ7#I<P!);7!O<G3A;.%S+"`E9"X@;.EPZ7,`0^UM:F5G>7KI:V5K(&EM<&]R
M="]E>'!O<G1J80!!>B!I;7!O<G3A;'0@;65Z]3H@)7,`07H@:6UP;W)TX6QT
M(&UE>O5K.@!3;W(@8F5I;&QE<WITZ7-E(&5Z86SA`$AI8N%S('!A<F%N8W-P
M87)A;>ET97(N`$YE;2!M96=F96QE;/4@82!B96IE;&5N=&ME>NES:2!NZ78@
MZ7,O=F%G>2!A(&IE;'-Z\RX`3F5M(&UE9V9E;&5L]2!A(&9E;&AA<WINX6SS
M:2!NZ78@=F%G>2!A>B!A;'1E<FYA=.UV(&/M;2X@4'+S8N%L:F$@^FIR82!V
M86=Y(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHL(&AA('1O=N%B8FD@
M<V5G[71SZ6=R92!V86X@<WK\:W/I9V4N`$)E:V5Z9.ES(&)E;&IE8F(`26YD
M:6$`16=Y97,@9F5L:&%S>F[A;/-K`$EN9&]NZ7II80!);F9O<FWA8VGS`$EN
M9F]R;>%C:?,`07H@:6YF;W)MX6-I\R!MX7(@;F5M(.%L;"!R96YD96QK97KI
M<W)E+@!/<WIL;W`@8F5S>OIRX7-A(&5Z=73A;@!+Z7`@8F5I;&QE<WITZ7-E
M`%3A8FSA>F%T(&)E:6QL97-Z=.ES90!,:6YK(&SI=')E:&]ZX7-A`$]S>FQO
M<"!B97-Z^G+A<V$@97IE;.D`3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6X`3W-Z
M;&]P(&)E<WKZ<N%S82!E>F5LZ0!3;W(@8F5S>OIRX7-A(&5Z86SA`%-O<B!B
M97-Z^G+A<V$@96;V;.D`0F5K97IDZ7,@8F5I;&QE<WITZ7-E(&5Z=73A;@!"
M96ME>F3I<R!B96EL;&5S>G3I<V4@97IE;.D`2&]Z>G5N:R!LZ71R92!A;'1E
M<FYA=.UV('-A8FQO;G0`061J;VX@;65G(&5G>2!E;6%I;"!C[6UE="P@;65L
M>7)E(&5L:_QL9&AE=/4@87H@UFX@^FH@:F5L<WIA=F$Z`$-E;&QA(&)E:6QL
M97-Z=.ES92!E>G5TX6X`0V5L;&$@8F5I;&QE<WITZ7-E(&5Z96SI`$]S>FQO
M<"!B97-Z^G+A<V$@97IU=.%N`$]S>FQO<"!B97-Z^G+A<V$@97IE;.D`3&5V
M96QE:R!B96WA<V]LX7-A`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>G5TX6X`
M0F5K97IDZ7,@8F5I;&QE<WITZ7-E(&5Z96SI`%-O<B!B97-Z^G+A<V$@97IA
M;.$`4V]R(&)E<WKZ<N%S82!E9O9LZ0!!9&IA(&UE9R!A(&OM=N%N="!VX6QA
M<WIT(&$@8FEZ=&]N<^%G:2!KZ7)DZ7-R93H`2^EP(&)E:6QL97-Z=.ES92]M
M\V1O<^UTX7-A`$QI;FL@8F5I;&QE<WITZ7-E+VWS9&]S[73A<V$`02!S>N%M
M;.%JX6X@;FEN8W,@96SI9R!F961E>F5T(/QZ96YE=&5T(&O\;&1E;FD@82!K
M]G)L97;I;&QI<W3A<F$N`$$@<WKA;6SA:N%N(&YI;F-S(&5LZ6<@9F5D97IE
M="X`16?I<WH`16?I<WH@<WKA;6]K(&QI<W3A:F$`2&EBX7,O96QF;V=A9&AA
M=&%T;&%N($E$+@!(:6+A<R]E;&9O9V%D:&%T871L86X@541(("A5<V5R($1A
M=&$@2&5A9&5R*2X`2&EBX7,O96QF;V=A9&AA=&%T;&%N(%I)4"!T]FWV<NUT
MZ7,`2&EBX7,@8^UM:F5G>7KI:RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&%L
M:V%L;6%ZX7,N`$AI8N%S+V5L9F]G861H871A=&QA;B!B871C:"!A>F]N;W/M
M=/,N`$$@:_QL9/9T="!A9&%T(&AI8N%S+V5L9F]G861H871A=&QA;BX`2&EB
MX7,O96QF;V=A9&AA=&%T;&%N(&/M;7KI<RX`2&EBX7,@96UA:6P@8^UM+@!(
M:6+A<R]E;&9O9V%D:&%T871L86X@861A="X`2&EBX7,O96QF;V=A9&AA=&%T
M;&%N(&;A:FP@9F]R;>%T=6T`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&MU;&-S
M+@!(:6+A<R]E;&9O9V%D:&%T871L86X@;&EC96YS>FMU;&-S+@!(:6+A<R]E
M;&9O9V%D:&%T871L86X@=N%R;W,N`$AI8N%S+V5L9F]G861H871A=&QA;B#\
M>F5N971T[7!U<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&[I=BX`2&EBX7,O
M96QF;V=A9&AA=&%T;&%N(&]B:F5C=$ED+@!(:6+A<R]E;&9O9V%D:&%T871L
M86X@=F%G>2!H:>%N>7KS('!R;V=R86UO>N%S:69E;/QL970M87IO;F]S[73S
M+@!(:6+A<R]E;&9O9V%D:&%T871L86X@<&%R86WI=&5R96LN`$AI8N%S(&%Z
M(&]B:F5K='5M(&5LZ7+I<VD@:F]G;W-U;'1SX6=A+@!(:6+A<R]E;&9O9V%D
M:&%T871L86X@<&%R=&YE<F%Z;VYO<^UT\RX`2&EBX7,O96QF;V=A9&AA=&%T
M;&%N('1E<FWI:VOS9"X`2&EBX7,O96QF;V=A9&AA=&%T;&%N('!R;W1O:V]L
M;"X`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&/M;7IE='0Z("(E<R(`2&EBX7,O
M96QF;V=A9&AA=&%T;&%N(&UE9V]S>G1O='0@;V)J96MT=6T`2&EBX7,O96QF
M;V=A9&AA=&%T;&%N(&9E;&%D\VD@8^UM+@!(:6+A<R]E;&9O9V%D:&%T871L
M86X@=6YI8V]D92!A9&%T+@!.>6EL=N%N=&%R=.%S`$$@:VEJ96SV;.ES(&EN
M=F5R=.%LX7-A`$ERX6YI($ES>FSA;2!+]GITX7)S87/A9P!)<F%K`,UR;W)S
M>N%G`$UA;BUS>FEG970`4WKS<G;A;GEO<R!Z:79A=&%R;VL`27IR865L`$$@
M=&%N^G/M=';A;GD@:VEA9/-J80!D]6QT`$]L87-Z;W)S>N%G`$IA;6%I8V$`
M:F%N=>%R`$IA<.%N`&IA<.%N("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F3A
M;FEA`&KZ;&EU<P!J^FYI=7,`4V]R:VEZX7+A<P!K]GKI<')E(')E;F1E>NES
M`'-O<FMI>N%RX7,@;6EN9&OI="!O;&1A;')A`'-O<FMI>N%RX7,@8F%L<F$`
M<V]R:VEZX7+A<R!J;V)B<F$`2V%Z86AS>G3A;@!487)T<W5K(&UE9R!A>B!E
M<F5D971I=#\`2V5N>6$`02!K97)B97)O<R!S>F5R=F5R(&5L=71A<^UT;W1T
M82!A(&9E;&AA<WINX6SS87IO;F]S[73A<W0N`$ME>F3U(&ME<FYE;&9E:FQE
M<WIT]6L`2W5L8W,@;.ET<F5H;WKA<V$`02!K=6QC<R!L96YY;VUA=&$`2W5L
M8W-H;W-S>OISX6<`2W5L8W,@=.UP=7,`02!K=6QC<R!H87-Z;N%L871A`$$@
M:W5L8W,@;>%R(&SI=&5Z:6L@82!N>6EL=N%N;W,@:W5L8W-S>F5R=F5R96XN
M`$=Y97)E:V5K`$MI<FEB871I`$MO<F5A:2!.Z7!I($1E;6]K<F%T:6MU<R!+
M]GITX7)S87/A9P!+;W)E86D@2_9Z=.%R<V%SX6<`:V]R96%I("A%54,M2U(I
M`$MU=F%I=`!+:7)G:7II<WITX6X`3$1!4"!TX6UO9V%TX7-R82!L96YN92!S
M>OQK<^EG+"!D92!A>B!,1$%0(&UO9'5L(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R
M92P@=F%G>2!N96T@=/9L=/5D]G1T(&)E+@!?5&5R=F5ZZ7,`3GEE;'8`3&%O
M<WII($[I<&D@1&5M;VMR871I:W5S($OV>G3A<G-A<^%G`'5T;VQS\R!FZ6P`
M571O;'/S(&WS9&]S[73A<P!#<V%LX61NZ78`07H@=71O;'/S(&IE;'-Z\W;A
M;'3A<P!U=&]L<_,@;F5G>65D`%5T;VQS\R!VX6QT;WIT873A<SH`571O;'/S
M(&)E:F5L96YT:V5ZZ7,Z("5S`%5T;VQS\R!B96IE;&5N=&ME>NES.B`E<RP@
M)7,@8^UM<O5L`%5T;VQS\R!B96IE;&5N=&ME>NES.B!MZ6<@<V]H82!N96T@
M=F]L=`!,971T;W)S>N%G`$IO9P!%;&AE;'EE>NES`$AA9WEJ82#\<F5S96XL
M(&AA(&YE;2!A:V%R(&ME<F5T970`3&EB86YO;@!B86P`0F%L(&]L9&%L:2!F
M96ILZ6,`0F%L(&]L9&%L:2#I<G3I:V5K`$QE<V]T:&\`4WII;G0`3&EBZ7)I
M80!,[6)I86D@07)A8B!3>F]C:6%L:7-T82!.86=Y($[I<&D@2_9Z]G-SZ6<`
M3&EE8VAT96YS=&5I;@!'>65N9V4@<WII=.%L\R!E<_4`1WEE;F=E(&5S]0!$
MZ6QE;/5T="!G>65N9V4@97/U`$3I;'5TX6XO97-T92!G>65N9V4@97/U`$=Y
M96YG92!ZX7!O<@!'>65N9V4@>FEV871A<@!'>65N9V4@:&%V87KA<P!'>65N
M9V4@:/-ZX7!O<@!,:6YK`$$@;&EN:R!I9&4@;75T870Z`$UE9VIE;&5N[73I
M<VMO<B!M=71A<W-O;B!E9WD@;&EN:R!A(&QE=NEL8^UM<O5L(&$@;&5VZ6SM
M<O,@86)L86MH;WH`3&EN:V5K`$QI;G5X`$QI<W1A`$QI<W3A>N%S("T@82!F
M96QH87-Z;N%L\R!LX71J82!A(&UA<'#A=`!!>B!A9&%T8N%Z:7-O:R!L:7-T
MX6IA`$%Z;VMN86L@82!TZ6WA:VYA:R!A(&QI<W3A:F$@86UI<O5L('-E9^UT
M<^EG(&MA<&AA=/,`07H@861A='3A8FSA:R!L:7-TX6IA`$QI<W1A(&%R8VCM
M=G5M`$QI<W1A('-E9^UT<^EG:^ERZ7,`3&ES=&$@87IO;F]S[73S`$QI<W1A
M('1U;&%J9&]N;W,`3&ES=&$@;&5VZ6SM<N%S`$QI<W1A(&9E;&ER871K;WKA
M<R`H<W5B<V-R:6)E*0!,:7-T82!L96ER871K;WKA<R`H=6YS=6)S8W)I8F4I
M`$$@9F5L:&%S>F[A;/-K87!C<V]L871O:R!K:6QI<W3A>N%S82!N96T@<VEK
M97+\;'0Z("5S`$$@9F5L:&%S>F[A;/-K(&MI;&ES=.%ZX7-A(&YE;2!S:6ME
M<OQL=#H@)7,`02!F96QH87-Z;N%L\VL@:VEL:7-TX7KA<V$@=&EL='9A('9A
M;BX`27)O9&%L;VT`3&ET=N%N:6$`3&5T]FQTZ7,N+BX`2&5L>6D@:63U.B``
M3GEE;'8L(&3A='5M+"!I9/4`2&5L>0!"96IE;&5N=&ME>NES`$%Z(&5L]7KU
M(&%D871S>FEN:W)O;FEZX6-I\R!N87!L\^%L;&]MX6YY80!+:6IE;&5N=&ME
M>NES`$)E:F5L96YT:V5ZZ7,`0F5J96QE;G1K97KI<W-E;"!K87!C<V]L871O
M<R!F96QA9&%T;VL`02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="P@;65R
M="!R;W-S>B!F96QH87-Z;N%L\VYE=F5T('9A9WD@:F5L<WKS="!A9&]T="!M
M96<N`$$@8F5J96QE;G1K97KI<R!N96T@<VEK97+\;'0N`$AO<W-Z^B!S>O9V
M96<`4WIE<F5L96T`86QA8W-O;GD`9_9R]F<@:VES8F5T^VL`;&%T:6X@:VES
M8F5T^VL`:VES8F5T^W,@<O-M86D@<WKA;6]K`$QU>&5M8G5R9P!-30!.87!I
M(/QZ96YE=&5K`$%Z($U3+51.148@;65L;.EK;&5T8F5N(&YI;F-S(&%D870N
M`-Q:14Y%5`!-86MA\P!-86ME9/-N:6$`36%D86=A<WIKX7(`5F%RX7IS;&%T
M`$QE=F5L97KI<P!%;6%I;"!D;VUA:6X@:V5Z96SI<P!,:6YK(&OI<WKM=.ES
M90!-86QA=VD`36%L86IZ:6$`36%L9.UV+7-Z:6=E=&5K`$UA;&D`3>%L=&$`
M061A=&%I="!K871E9_-R:>%K8F$@<V]R;VQH871J82X@17IE:R!I='0@9&5F
M:6YIX6QH873S:RP@;?-D;W/M=&AA=/-K+"!T;W;A8F+A('-Z[6YE:R!R96YD
M96QH973U:R!H;WIZX6IU:RX`36%P,C0@=.ER:^EP`$UA<%%U97-T('3I<FOI
M<`!!(&AO>GKA<F5N9&5LZ7-E:V5T(&5L;65N=&5T=/QK+@!MX7)C:75S`$UA
M<F?S`$%Z($]L=F%S;W1T+T]L=F%S871L86X@:F5L>F5T96L@:&%S>F[A;&%T
M80!-X7,@:F5L>F5T96L@*'!L+B!&;VYT;W,O365G=N%L87-Z;VQT*2!H87-Z
M;N%L871A`$UA<G-H86QL+7-Z:6=E=&5K`$UA<G1I;FEQ=64`;6ET`$5G>6WA
M<VYA:R!M96=F96QE;/4@;65Z]6L`36%U<FETX6YI80!-875R:71I=7,`36%X
M:6WA;&ES(')E;F1E;&ME>NES<F4@X6QL\R!S>N%M;&'V<W-Z96<N`$%Z(/QZ
M96YE="!T^FP@<V]K('+I<WIB]6P@X6QL+@!!>B!E;&WZ;'0@,C0@\W)A(&UA
M>&EMX6QI<R!H]6WI<G/I:VQE=&4Z(`!!>B!E;&WZ;'0@-B#S<F$@;6%X:6WA
M;&ES(&CU;>ER<^EK;&5T93H@`$$@<&%R=&YE<F5K(&UA>&EMX6QI<R!S>N%M
M80!!>B#V<W-Z96?U;VQD86P@8FQO:VMJ86EN86L@;6%X:6WA;&ES('-ZX6UA
M`$UA>&EMX6QI<R!H;W-S>@!!>B!O;&1A;&%K(&UA>&EMX6QI<R!S>N%M80!M
MX6IU<P!-87EO='1E`$]R=F]S='5D;VWA;GD`5&%G;VL`365N_&QI<W1A`$$@
M;65N_"!M96=J96QE;NES93H`0V5L;.%K(&5G>6)E;VQV87-Z=.%S80#<>F5N
M970`02!D:6=I=.%L:7-A;B!A;.'M<G0@_'IE;F5T(&AI=&5L97,L(&1E(&%Z
M(&%LX>UR\R!T86[Z<^UT=N%N>>%T(&YE;2!S:6ME<OQL="!E;&QE;O5R:7IN
M:2X`3&5JX7)T(&%Z(/QZ96YE="#I<G;I;GEE<W/I9V4N`$%Z(/QZ96YE="!T
M[7!U<V$`365T87(@:63U:N%RX7-J96QE;G3I<P!!($UE=&%R(&)L;VMK(&YE
M;2#A;&P@<F5N9&5L:V5ZZ7-R92X`02!-971A<B!B;&]K:R!N96T@X6QL(')E
M;F1E;&ME>NES<F4N($$@<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S>N%M
MX7)A(&OI<WK\;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN`$$@365T87)$0B!N
M96T@Z7)H973U(&5L+@!-\V1S>F5R`$$H>BD@(B5S(B!M\V1S>F5R(&1E9FEN
M:>%L871L86X`02!M\V1S>F5R(&1E9FEN:>%L871L86XN($$@;65G:.UV;W1T
M(&WS9'-Z97(Z("5S`$UE=')I:W5S`$UE>&EK\P!-:6MR;V[I>FEA:2!3>O9V
M971SZ6=I(,%L;&%M;VL`:_9ZZ7``34E-12!T[7!U<P!!>B!E;&WZ;'0@,C0@
M\W)A(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T93H@`$%Z(&5L;?IL="`V
M(/-R82!L96=A;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z(`!-Z6<@;F5M('1E
M;'0@96P@82!M:6YI;>%L:7,@:63U(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%S
MX6AO>@!4_&MR]GKI<R`H:F]B8B]B86PI`%9E9WEE<P!!>B!,1$%0('-Z97)V
M97(@:V]N9FEG=7+A8VGS:N%B86X@;FEN8W,@;65G861V82!A($1.+@!(:>%N
M>7II:R!A($A45%!?4F5Q=65S="!014%2(&-S;VUA9RX`2V]N9FEG=7+A8VGS
M('-Z_&MSZ6=E<RX@17IT(&UO<W0@:V5L;"!LZ71R96AO>FYI82P@:&$@:&%S
M>F[A;&YI(&%K87)J82!A>B!A;&MA;&UA>N%S="X`2&GA;GEZ:6L@87H@_'IE
M;F5T(&%Z;VYO<^UT\VIA+@!(:>%N>7II:R!A($UA:6P@4$5!4B!C<V]M86<N
M`$AIX6YY>FEK(&$@9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S[73S:F$@
M*'-E<W-I;VX@240I+@!(Z0!,979E;&5ZZ7,@;6]B:6QT96QE9F]N<O-L`$UO
M8FEL=&5L969O;@!+]GIE<&5S`$$@;?-D;W/M=.%S(&3A='5M80!!>B!54DP@
M;?-D;W/M=.%S80!!(&WS9&]S[73A<R!N96T@<VEK97+\;'0Z("@E<RD@)7,`
M36]D=6QU<P!-;VQD;W9A:2!+]GITX7)S87/A9P!-;VYA8V\`36]N9_-L:6$`
M2/-N87`@Z7,@Z78`:&%V;VYT80!-;VYT<V5R<F%T`$AO;&1FX7II<V]K`$$@
M)60N('-O<F)A;B!T]F)B(&UE>O4@=F]L="P@;6EN="!A(';A<G0@)60N`%3V
M8F(L(&UI;G0@,2!T86SA;&%T('9A;@!-87)O:VOS`%3V8F)N>6ER92!D97+\
M;'0`5/9B8FYY:7)E(&)O<G5L=`!4]F)B;GEI<F4@;F%P;W,`5&5G>?QK(.%T
M`'9I9WG\:R!L90!V:6=Y_&L@8F%L<F$`=FEG>?QK(&IO8F)R80!V:6=Y_&L@
M9O9L`'9I9WG\:R!L90!B86QR80!J;V)B<F$`=FEG>?QK(&;V;`!-;WIA;6)I
M:P!-=6QB97)R>2!C[6UJ96=Y>NEK`%3V8F)S>FEN=/L@;&5G]G)D_&SU(&QI
M<W3A:P!-=6QT:6UA<"!.86=Y+4)R:71A;FYI82!TZ7)KZ7``5/9B8B!S>F5M
MZ6QY(&ES('9A;B!MX7(L(&%K:6YE:R!A(&/M;64@6R5S72P@9&4@96=Y:6MN
M96L@<V5M(%LE<UT@82!N979E`%3V8F)S>O9R]G,@=N%L87-Z=.%S`$)E:F5L
M96YT:V5ZZ7-I(&)EX6QL[73A<V]K`$)E:F5L96YT:V5ZZ7-I(&%D871A:6T`
M4V%JX70@8^UM:F5G>7KI:P!386KA="!C[6UJ96=Y>NEK96EM`%-A:N%T(/9S
M<WIE9WKU(&]L9&%L86T`4V%JX70@]G-S>F5G>O4@;VQD86QA;2!T97)V97KI
M<V4`36EA;FUA<@!.14TL(&YE;2!E9WEE>F5M(&)E;&4N`$[I=@!.Z78@9F]R
M;>%T=6T`3F%M[6)I80!.875R=0!.97#A;`!.971C96YT97(@365M8F5R(&/M
M;6IE9WEZZ6L`2&]L;&%N9&EA`$AO;&QA;F0@06YT:6QLX6L`3F5T<V-A<&4@
M8N%Z:7,M55),`$YE='-C87!E('1A;OIS[71VX6YY:VEA9.%S:6IO9RA#02DM
M=FES<WIA=F]NX7-I(%523`!.971S8V%P92!T86[Z<^UT=N%N>69E;&AA<WIN
MX6SA<VD@:7+A;GEE;'8@55),`$YE='-C87!E('1A;OIS[71VX6YY;65G^FKM
M=.%S:2!54DP`3F5T<V-A<&4@=&%N^G/M=';A;GEV:7-S>F%V;V[A<VD@55),
M`$YE='-C87!E(%-33"!S>F5R=F5R;NEV`$YE='-C87!E('1A;OIS[71VX6YY
M(&UE9VIE9WEZZ7,`3F5T<V-A<&4@=&%N^G/M=';A;GET[7!U<P!(X6SS>F%T
M`'-O:&$`VFHM2V%L963S;FEA`-IJ(&MA=&5G\W)I80#::B!L979E;&5Z]7!A
M<G1N97(`VFH@;&5VZ6P@)7,@8^UM<F4`^FIH;VQD`-IJ(&9E;&AA<WINX6SS
M;NEV("AO<&-I;V[A;&ES*0#::BU:Z6QA;F0`VFH@:F5L<WKS`$%Z(/IJ(&IE
M;'-Z\R#I<G;I;GEE<W/I9V4@96MK;W(@:N%R(&QE.B`E>"X`02!M96=A9&]T
M="#Z:B!J96QS>F%V86L@;F5M(&5G>65Z;F5K+@#::B!A8FQA:R`H_')E<RD`
M2.UR96L`2.UR8W-O<&]R=&]K`$OV=F5T:V5Z]0!+]G9E=&ME>O4@-"!FX7II
M<P!+]G9E=&ME>O4@;W!C:?-K`$OV=F5T:V5Z]3X`3FEC87)A9W5A`$)E8V5N
MZ78`3FEG97(`3FEGZ7)I80#I:G-Z86MA`$YI=64`3F5M`$YI;F-S("5S(&%D
M870@82AZ*2`E<R!C[6UH97H`16=Y(&/M;6IE9WEZZ6L@<V5M('1A;.%L:&%T
M\RX`3FEN8W,@<F5N9&5L:V5ZZ7-R92#A;&SS(&MO;F9I9W5RX6-I\RP@86UI
M:&5Z(&OI<&5S="!A(&O\;/9N8G/I9V5K970@;65G(&QE:&5T;F4@;75T871N
M:2X`3FEN8W,@;&5H973U<^EG($E33R#A;&QO;>%N>6]K(&SI=')E:&]ZX7/A
M<F$N`$AIX6YY>FEK(&$@:_9T96=E;'0@9F5L9&]L9V]ZX7-H;WH@<WK\:W/I
M9V5S(&UI;G1A("AB871C:"!T96UP;&%T92DN`$$@:^UVX6YT(&AE;'EE;B!N
M:6YC<R!B;&]K:P!!>B!-0T%,(&9E;&AA<WINX6SS87IO;F]S[73A<VAO>B!N
M:6YC<R!M96=A9'9A(&$@;F%P=.%R(&YE=F4N`$YI;F-S(';A;'1O>N%S+@!%
M:&AE>B!A(&IO9V]S=6QT<^%G:&]Z(&YE;2!H;WIH873S(&SI=')E(&IO9V]S
M=6QT<^%G:2!A;&-S;W!O<G0N`$AIX6YY;WIN86L@82!K;VYF:6=U<N%C:?-S
M(&%D871O:R`E<RUH97HN`$%Z($944"!61E,@;FEN8W,@:V]N9FEG=7+A;'9A
M+@!!>B!344P@5D93(&YI;F-S(&MO;F9I9W5RX6QV82X`07H@4U%,+49I;&4@
M5D93(&YI;F-S(&MO;F9I9W5RX6QV82X`3F5M('1A;.%L='5N:R!E9WD@<&%R
M=&YE<G0@<V5M`$%Z(-9N('-ZX6ULX6KA;B!E;&9O9WEO='0@82!R96YD96QK
M97KI<W)E(.%L;/,@]G-S>F5G+@!.:6YC<R!C[6UZZ7,N`$$@<WIE<G9E<G)E
M(&YE;2!T]FQT]63V='0@9F5L('-E;6UI;'EE;B#A;&QO;>%N>0!!>B!I:V]N
M;VL@;F5M('1A;.%L:&%T\VLN`$YI;F-S(&UE9V%D=F$@82!H96QY+@!.:6YC
M<R!M96=A9'9A(&$@:&5L>2X`07H@_'IE;F5T(/QR97,N`$YI;F-S(&UE9V%D
M=F$@82!NZ78N`$YI;F-S(&UE9V%D=F$@82!S>N%M+@!.92!L96=Y96X@;65G
M8F]T<N%N:V]Z=&%T\R!I9.EZ970`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!(
M5%10(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J
M96QS>O,@;65G861V82!A>B!)34%0(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N
M;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G861V82!A($ME<F)E<F]S(&%L
M87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@
M;65G861V82!A($QO9VEN(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S
M:&]Z+@!.:6YC<R!J96QS>O,@;65G861V82!A(%!!4U-71"!A;&%P^B!F96QH
M87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@
M87H@4TU"(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC
M<R!M96=A9'9A(&%Z($]P96Y34TP@<')O9W)A;2!E;.ERZ7-I(/IT=F]N86QA
M+B!!>B!/<&5N4U-,('!R;V=R86T@<WK\:W/I9V5S(&$@4$M#4R`Q,B!A9&%T
M;VL@:V5Z96SI<^EH97HN`$YI;F-S(/IJ(&)E:F5L96YT:V5ZZ7-I(&EGZ6YY
M+@!.:6YC<R!K=O-T82!B9>%L;.UT=F$N`$YE(&QE9WEE;F5K('9O;F%L86L@
M<V5H;VPN`$YI;F-S(&1E9FEN:>%L=F$@96QVX6QA<WIT\R!K87)A:W1E<BX`
M3F4@;&5G>65N(&ME<F5T`$YI;F-S(&EL>65N(&;A:FP`3FEN8W,@:61E:6=L
M96YE<R#A;&QO;>%N>6]K('3A<F]LX7/A<F$@<WIO;&?A;/,@86QK]FYY=G3A
M<BX`2&GA;GEZ:6L@82!F96QH87-Z;N%L\V[I=B#I<R]V86=Y(&$@:F5L<WKS
M+@!.96T@<VEK97+\;'0@=D-A<F0@861A=&]T('1A;.%L;FDN`$$@=FES<WIA
M:V%P;W1T(&%D871O:R!N96T@Z7)VZ6YY97,@6$U,(&%D871O:P!.:6YC<R!A
M9&%T`$YI;F-S(&WI9R!K;VYF:6=U<N%C:?,L(&=E;F5RX6QJ;VX@96=Y970N
M`$YI;F-S(&WI9R!K;VYF:6=U<N%C:?-J82P@9V5N97+A;&IO;B!E9WEE="X`
M;FEN8W,`;FEN8W,@;65G861V82`H;&5G>65N(&%L87#I<G1E;&UE>F5T="D`
M;F]R9&EK=7,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK+7-Z:6=E=`#)<WIA:VD@
M9NEL=&5K90#)<WIA:VDM36%R:6%N82US>FEG971E:P!.;W)VZ6=I80!.96T@
M:^ES]6)B`$YE;2!K;W+A8F)A;@!.96T@86QK]FYY=G3A<@!!('!R;V=R86UN
M86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!.:6YC<R!B
M9>%L;.UT=F$`3F5M('3A;6]G871O='0N`$UE9VIE9WEZZ7,`3FEN8W,@8O9N
M9^ES>FAE=/4@861A="P@=.ER:F5N('9I<W-Z82X`;F]V96UB97(`4WKA;0!+
M87)A:W1E<F5K('-ZX6UA`$]S>FQO<&]K('-ZX6UA`$%Z(&]L9&%L;VX@;65G
M:F5L96[M=&5N9/4@96QE;65K('-ZX6UA`%-O<F]K('-ZX6UA`$$@:_9R;&5V
MZ6QL:7-T82!M\V1O<^UTX7/A:&]Z(&YE;2!A9&]T="!M96<@<WKA;6]K870N
M`$]+`$]B:F5K='5M`$%Z(&]B:F5K='5M(&SI=')E:&]Z\VIA`$%Z(&]B:F5K
M='5M(&YE;2!T86SA;&AA=/,@;65G`$]K=.%L:7,@<WKA;0!O:W3S8F5R`%-Z
M^W+I<P!(:79A=&%L+VUU;FMA:&5L>0!!('+I9VD@Z7,@87H@^FH@:F5L<WKS
M;F%K(&O\;/9N8O9Z;FEE(&ME;&PN`$$@<NEG:2!J96QS>O,`02!RZ6=I(&IE
M;'-Z\R!N96T@;65G9F5L96SU+@!/;>%N`$AA(&5L;65N=&D@97IE:V5T(&$@
M8F7A;&SM=.%S;VMA="P@86MK;W(@82!C[6UJ96=Y>NEK(';I9^ER=NEN>65S
M96X@=/9R;/5D:6LN($AA(&5Z="!N96T@<WIE<F5T;NDL(&%K:V]R(&YE(';A
M;&%S<WIO;B!K:2!T]G)LZ7-R92!E9WEE="!S96TN`$-S86L@87H@24U!4"!S
M>F5R=F5R96L@=.%M;V=A=&KA:R!A(&UA<'#A:R!M96=O<WITX7/A="X`0W-A
M:R!M96=B;W1RX6YK;WIT873S(&EDZ7IE="!L96=Y96X`0W-A:R!E9WD@96UA
M:6P@8^UM(&%D:&%T\R!M96<N`$-S86L@96=Y971L96X@=F-A<F0@:&%S>F[A
M;&%T82!L96AE='/I9V5S+@!#<V%K(&$@='5L86ID;VYO<R!V86=Y(&$@<F5N
M9'-Z97)G87ID82!VX6QT;WIT871H871J82!M96<@96=Y(&OV>O9S('3A<G1E
M<OQL970@='5L86ID;VYO<^%T('9A9WD@96SI<NES:2!J;V=O<W5L='/A9V%I
M=`!.>6ES<W5K(&UE9R#Z:B!A8FQA:V)A;@!/<&5N4U-,(&AI8F$Z($YE;2!S
M:6ME<OQL="!K:6YY97)N:2!A>B!A9&%T;VMA="!A>B!A;.'M<G0@4R]-24U%
M('+I<WIB]6P`3GEI<W-U:R!M96<@97IT(&$@8^UM970@96=Y(/IJ(&%B;&%K
M8F%N`$]P97+A8VGS<R!R96YD<WIE<@!/<&-I\VL`)7,@8F7A;&SM=.%S86D`
M4V]R<WKA;6]S(&9E;'-O<F]LX7,`4WIE<G9E>F5T`%-Z97)V97IE=&D@96=Y
M<^EG`$UU;FMA<WIE<G9E>NES`$%Z(&%L:V%L;6%ZX7,@97)E9&5T:2!S86)L
M;VYJ80`E<R!E<F5D971I('-A8FQO;FIA:3H`16=YZ6(`16=YZ6(@:6YF;W)M
MX6-I\P!%9WGI8B!B9>%L;.UTX7-O:P!!('1U;&%J9&]N;W,@:F]G;W-U;'1S
MX6=A:0!!(%!!32!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M(.%L;"!R96YD
M96QK97KI<W)E+@!014%2.CI-86EL(&%L<F5N9'-Z97(`4$=0(&1I9VETX6QI
M<R!A;.'M<N%S`%!'4"UV96P@=&ET:V]S[71O='0@861A=`!01U`@;GEI;';A
M;F]S(&MU;&-S`%!'4"UV96P@86SA[7)T+W1I=&MO<^UT;W1T(&%D870`4$A0
M(&OS9`!$Z6QU=.%N+V5S=&4@9WEE;F=E(&5S]0!$Z6QU=.%N(&5S]0!$Z6QU
M=.%N+V5S=&4@>N%P;W)O:P!$Z6QU=.%N+V5S=&4@:&%V87KA<P!$Z6QU=.%N
M+V5S=&4@:/-ZX7!O<F]K`$3I;'5TX6X@;F%P<_QTZ7,`1.EL=73A;B]E<W1E
M('II=F%T87)O:P!(:>%N>7II:R!A(%!/4TE8(&+U=NUTZ7,`8F5L<_4@;6%R
M9_,`4&%K:7-Z=.%N`%!A;&%U`%!A;&5S>G1I;B!497+\;&5T("AM96=S>N%L
M;'0I`%!A;F%M80!0X7!U82#::BU'=6EN96$`4&%R86=U87D`3>ER<^EK96QT
M96X@8F]R=6QT`$IE;'-Z\P!!(&IE;'-Z\W0@<VEK97)E<V5N(&UE9W;A;'1O
M>G1A='1U:RX`3F5M(&UE9V9E;&5L]2!J96QS>O,`02!2041)55,@9F5L:&%S
M>F[A;/-A>F]N;W/M=.%S:&]Z(&IE;'-Z\R!S>OQK<^EG97,N`$IE;'-Z\R!M
M96=E<O5S[73I<W-E;`!*96QS>O,Z`$IE;'-Z\SH@`$$@:F5L<WIA=F%K;F%K
M(&5G>65Z;FG\:R!K96QL+@!"96EL;&5S>G3I<P!"96EL;&5S>G3A<R!A(';A
M9_-A<WIT86QR\VP`VG1V;VYA;`#::B!F96QH87-Z;N%L\VYA:R!B96IE;&5N
M=&ME>F5T=&5K.@!%;6)E<F5K`'-ZX7IA;.EK`$MA<F)A;G1A<G3A<VD@9F5L
M861A=&]K(';I9W)E:&%J=.%S80!"96IE;&5N=&ME>NES:V]R(&AA:G1S=6L@
M=NEG<F4@82!K87)B86YT87)TX7-I(&9E;&%D871O:V%T/P!*;V=O<W5L='/A
M9P!!*'HI("(E<R(@:F]G;W-U;'1SX6=O="!N96T@=/9R]FQT_&LN`$5H:&5Z
M(&YI;F-S(&5H:&5Z(&UE9V9E;&5L]2!J;V=O<W5L='/A9V$`16AH97H@;FEN
M8W,@;65G9F5L96SU(&IO9V]S=6QT<^%G80!*;V=O<W5L='/A9V]K`$IO9V]S
M=6QT<^%G(&%D;6EN:7-Z='+A8VGS`%-Z96WI;'EE<R!A9&%T;VL`4&5R=0#!
M;&QA=&ME9'9E;F-E:P!&_&SV<"US>FEG971E:P!496QE9F]N`$;I;GEKZ7!G
M86SI<FEA`%!I;F4@8^UM:F5G>7KI:P!0:71C86ER;@!P:7AE;`!+]GIH96QY
M96L`2V%T=&EN='-O;B!V86QA;65L>6EK(&-E;&SA<F$`0FEZ=&]S86X@=/9R
M]FQN:2!A:V%R:F$@97IT(&%Z(&5L96UE=#H`2^ER96T@97+U<^UT<V4@;65G
M+"!H;V=Y('9A;/-B86X@=/9R]FQN:2!K[7;A;FIA(&5Z="!A>B!E;&5M970N
M`$OI<F5M(&%D:F]N(&UE9R!E9WD@:/-N87!O="#I<R!E9WD@Z79E="X`2^ER
M96T@861J82!M96<@87H@^FH@:V%T96?S<FEA(&YE=NET.@!+Z7)E;2!V86SS
M<R!)4"!C[6UE="!A9&IO;B!M96<N`$OI<F5M('9A;/-S(&3A='5M;W0@861J
M;VX@;65G+"!E;&QE;O5R:7IZ92!A(&CS;F%P(&YA<&IA:70N`$OI<F5M('9A
M;/-S(&3A='5M;W0@861J;VX@;65G+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!C
M[6UL:7-T82!N97;I=#H`2^ER96T@<O9V:61E;B#M<FIA(&QE(&$@<')O8FSI
M;6$@;.EN>65GZ70N`$OI<F5M(&%D:F$@;65G(&$@8F5J96QE;G1K97KI<VD@
M;F5VZ70@Z7,@:F5L<WIA=N%T`$OI<F5M(&]L=F%S<V$@96P@82!K]G9E=&ME
M>O4@<WKV=F5G970N($$@<F5N9'-Z97(@:&%S>F[A;&%TX6YA:R!F96QTZ71E
M;&5I="!E;"!+14Q,(&9O9V%D;FEA+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K
M871E9_-R:6$@;F5VZ70Z`$QE;F=Y96QO<G-ZX6<`4&]L:71I:V$`4WIA=F%Z
MX7-O:P!0;W)T=6?A;&EA`$$@:^EP(&5L:&5L>65ZZ7-E`$$@=.%B;.%Z870@
M96QH96QY97KI<V4`2_9Z=F5T;&5N(&QE=NEL:_QL9.ES(&5B8F4@82!M87!P
MX6)A("A)34%0(&YE;2!M:6YD:6<@=F5S>FD@9FEG>65L96UB92D`07H@96QM
M^FQT("5S(/-R82!C<V%P863I:VUE;FYY:7/I9V4Z(`!#<V%P863I:SQB<B`O
M/G9A;/-S>NUN^W/I9P!0<F5F<U]L9&%P.B!N96T@=&%LX6QH873S(&$@<WK\
M:W/I9V5S($Q$05`@:VET97)J97-Z=.ES+@!0<F5F<U]S97-S:6]N.B!N96T@
M=&%LX6QH873S(&$@<WK\:W/I9V5S("AS97-S:6]N*2!K:71E<FIE<WITZ7,N
M`$SI9VYY;VWA<P!!('1E;F=E<G-Z:6YT;F5K(&UE9V9E;&5L]2!LZ6=N>6]M
MX7,Z(`!,Z6=N>6]MX7,Z(`!%;/5Z971E<R!M96=T96MI;G3I<P!!(&OI<"!E
M;/5Z971E<R!M96=T96MI;G3I<V4@^FH@86)L86MB86X`16SU>O4`16SU>O4@
M;W!C:?-K`$$@9&]K=6UE;G1U;2!K:6YY;VUT873A<V$`4WIE;>EL>65S(&/M
M;6IE9WEZZ6L`5&ET:V]S(&MU;&-S`$AI8F%B96IE;&5N=.ES`$$@:&EB82!L
M9>URX7-A`%!R;VIE:W0@:V5Z96SI<P!!('!R;VUP="!S>O9V96=E`$YY:6QV
MX6YO<R!K=6QC<P!.>6EL=N%N;W,@:W5L8W/Z(&%L9V]R:71M=7,`3GEI;';A
M;F]S(&MU;&-S(&EN9F]R;>%C:?,`02!N>6EL=N%N;W,O=&ET:V]S(&MU;&-S
M<.%R="!N96T@<VEK97+\;'0@;.ET<F5H;WIN:2X`4'5E<G1O(%)I8V\`02!L
M979E;&5K(';I9VQE9V5S('3V<FSI<V4`2V%T87(`2V5R97/U+W!A<F%N8W,@
M<W1R:6YG`$$@:V5R97/I<R!S:6ME<G1E;&5N.B`H)7,I("5S`$=Y;W)S(&ME
M<F5SZ7,`2W;S=&$`4E-!(&YY:6QVX6YO<R!K=6QC<R`H)60@8FET97,I`%+A
M9&GS9V]M8F]S(&MI=N%L87-Z=.%S`$5S]0!%<_4@9.EL96SU='0`17/U(&3I
M;'5TX6XO97-T90!:X7!O<@!%<_4@Z7,@:&%V87KA<P!(879A<V5S]0!6Z6QE
M=&QE;B!I9.EZ970`07+A;GD`3VQV87/A<P!/;'9A<^%S:2!H:6)A.B`H)7,I
M("5S`$QE=F5L96L@;VQV87/A<V$`02!P87)T;F5R96L@861A=&%I(&YE;2!O
M;'9A<VAA=/-K+@!4Z6YY;&5G('3V<O9L:OQK("5S(&9E;&AA<WINX6SS=#\@
M17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT:&%T\R!V:7-S>F$N`%9A;/-B
M86X@=/9R]FQN:2!K[7;A;FIA(&5N;F5K(&$@;&5V96QE>O5P87)T;F5RZ6YE
M:R!A>B!A9&%T86ET/P!4Z6YY;&5G('3V<O9L:OQK("5S(&9E;&AA<WINX6SS
M(&%D871A:70_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M(&9O<F3M=&AA=/,@=FES
M<WIA+@!!(&UE9VIE;&5N[71E='0@861A=&]K.@#::G)A(';I9W)E:&%J=&IA
M(&%Z('5T;VQS\R!VX6QT;WIT873A<W0`1G)I<W/M=.ES`$$@;65N_"!D:6YA
M;6EK=7,@96QE;65I;F5K(&9R:7-S[73I<VD@9WEA:V]R:7/A9V$Z`$%Z(/9S
M<WIE9WKU;VQD86P@9G)I<W/M=.ESZ6YE:R!G>6%K;W)I<^%G83H`3V)J96MT
M=6T@8O9N9^ES>O4`1G)I<W/M=.ES`$UE9VIE9WEZZ7-E:P!4X79O;&D@<WIE
M<G9E<F5K`$$@=.%V;VQI(%523"`H<&PN(&AT='`Z+R]W=W<N=F%L86UI+FAU
M+VUE9W9A;&%M:2DZ`%3V<FSI<P!";&]K:R!T]G)LZ7-E`$$@8^UM:F5G>7KI
M:R!T]G)LZ7-E`&]S>FQO<"!T]G)LZ7-E`$$@9F]R;6%T=.%LX7,@=/9R;.ES
M90!4]G+V;&K\:R!A(&QI<W3A<O-L`$$@<.%R('3V<FSI<V4`5/9R]FQJ_&L@
M87H@96QM96YT971T('!R;V=R86UO="!A('-Z97)V97(@:61E:6=L96YE<R#A
M;&QO;>%N>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV=.%RX6+S;"X`5F5G>?QK
M(&MI(`!696=Y_&L@:VD@97IT(&$@<NES>G0@82!D;VMU;65N='5M8O-L`$$@
M9F5L:&%S>F[A;/,@=/9R;.ES90`E<R!F96QH87-Z;N%L\R!T]G)LZ7-E`,UR
M:G5K(&9E;/QL(&$@:VEVX6QA<WIT;W1T(&/M;6IE9WEZZ6ME="!A>B!I;7!O
M<G3A;'1T86P_(#QS=')O;F<^1FEG>65L;65Z=&5TZ7,Z(&5Z(&MI=/9R;&D@
M87H@]G-S>F5S(&%D871O="!A(&IE;&5N;&5G:2!C[6UJ96=Y>NEK8O5L(3PO
M<W1R;VYG/@!!(&OI<NES(&YE;2!T96QJ97/M=&AE=/4N($$@:V%P;W1T(&AI
M8F%K\V0Z(`!!(&ME<F5S971T(&]B:F5K='5M(&YE;2!T86SA;&AA=/,N`$$@
M:V5R97-E='0@<WIO;&?A;'1A=.%S(&YE;2!T86SA;&AA=/,N`$$@:_9T96QE
M>O5E;B!M96=A9&%N9/,@(B5S(B!N96T@<WIE<F5P96P@)7,@:V]N9FEG=7+A
M8VGS:N%B86XN`$$@:_9T96QE>O5E;B!M96=A9&%N9/,@(B5S(B!N96T@<WIE
M<F5P96P@82!61E,@:V]N9FEG=7+A8VGS:N%B86XN`$$@:_9T96QE>O5E;B!M
M96=A9&%N9/,@(B5S(B!N96T@<WIE<F5P96P@82!K;VYF:6=U<N%C:?-B86XN
M`%-Z_&MSZ6=E<R!M97KU`%)E<V5T`$$@:F5L<WKS(.%TX6QL[73A<V$`07H@
MUFX@:F5L<WIA=N%N86L@X73A;&SM=.%S80!+97ID:OQK(/IJ<F$@82!K:73V
M;'3I<W0`07H@=71O;'/S(&ME<F5SZ7,@=FES<WIAX6QL[73A<V$`17)E9&WI
M;GD`5FES<WIA(&%Z(&]P8VGS:VAO>@!!>B#Z:B!J96QS>O-T(.UR:F$@8F4@
M:7-MZ70`4NEU;FEO;@#!;&SM='-U:R!V:7-S>F$@82!K;VYF:6=U<N%C:?-T
M`%)I8V@@5&5X="!%9&ET;W(@;W!C:?-K`%1A;.%L\W,@:^ER9.ES96L`:F]B
M8@!*;V)B(&]L9&%L:2!F96ILZ6,`2F]B8B!O;&1A;&D@Z7)TZ6ME:P!3;W(@
M='5L86ID;VYSX6=O:RXN+@!3>F5R97``4F]MX6YI80!&;W)G873A<R`Q.#`@
M9F]K:V%L`$)A;')A(&9O<F=A=.%S`$IO8F)R82!F;W)G873A<P!3;W(@='5L
M86ID;VYSX6=O:P!3;W(@='5L86ID;VYSX6=O:P!3;W)O:SH`5F]N86QA:P!-
M:6YD96X@<V]R(.ES(&]S>FQO<"!K]GKV='0@;&5G>65N('9O;F%L`$-S86L@
M87H@;W-Z;&]P;VL@:_9Z]G1T(&QE9WEE;B!V;VYA;`!#<V%K(&$@<V]R;VL@
M:_9Z]G1T(&QE9WEE;B!V;VYA;`!&=71T873A<P!/<F]S>B!&]F1E<N%C:?,`
M4G5A;F1A`%,O34E-12!D:6=I=.%L:7,@86SA[7+A<P!3+TU)344@<WIA8G;A
M;GD@<WIE<FEN="!T:71K;W/M=&]T="!L97;I;`!3+TU)344@;GEI;';A;F]S
M('1A;OIS[71VX6YY`%-!4TP@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!T
M86SA;&AA=/,N`%--4R!K_&QDZ7,`4U%,('!A<F%N8W,@82!K97)E<^ES:&5Z
M`%-32`!35$%25%1,4R!H:6)A.B`H)7,I("5S`%-)2T52W$Q4`%-Z;P!3>F5N
M="!);&]N82US>FEG970`4V%I;G0@2VET=',@Z7,@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(.ES($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@Z7,@
M1W)E;F%D:6YE+7-Z:6=E=&5K`%5G>6%N87H@82!F<F%M92`H7W-E;&8I`%-Z
M86UO80!386X@36%R:6YO`%-A;R!4;VWI(.ES(%!R[6YC:7!E`$W[:&]L9&%S
M(&EN=&5R;F5T96SI<NES`%-Z8?ID+4%RX6)I80!-96YTZ7,`(B5S(B!M96YT
MZ7-E`"5S(&UE;G3I<V4`02!B9>%L;.UTX7-O:R!M96YTZ7-E`$UE;G1S_&L@
M96P@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0@4$A0('!R;V=R86T@9F]R
M;>%JX6)A;B!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N>6]K870@=&%R
M=&%L;6%Z\R!A;&OV;GEV=.%RX6)A;BX`)7,@:V]N9FEG=7+A8VGS:N%T(&5L
M;65N=&5T=/QK+@!%;&UE;G1E='3\:R!A('-E='5P('5P9W)A9&4@<')O9W)A
M;6]T(&ED93H@(B5S(@!!(&QE=F5L97KU<&%R=&YE<F5K(&%D871A:2!N96T@
M;65N=&AE=/5K(&5L+@!3>O-R=N%N>6]S('II=F%T87)O:P!4=61O;>%N>0!+
M97)E<^ES`$ME<F5SZ7-I('-Z;VQGX6QT873A<V]K`$$@:V5R97/I<R!N96T@
M<VEK97+\;'0`02!K97)E<^ES(&YE;2!S:6ME<OQL=#H@)7,`02!K97)E<^ES
M(&YE;2!L96AE='/I9V5S+@!+97)E<^ES+BXN`,%L;&]MX6YY;VL@:VEVX6QA
M<WITX7-A`%;A;&%S<WIO;B!K:2!E9WD@9.%T=6UO=`!-96QY:6L@8W-O<&]R
M=&]T(&OM=N%N:F$@:&]Z>N%A9&YI`%;A;&%S<WIA(&MI(&%Z(/IJ('1U;&%J
M9&]N;W-T`%;A;&%S<WIO;B!S>F5R=F5R=`!-96QY:6L@9F5L:&%S>F[A;/-T
M(&OM=N%N:F$@:&]Z>N%A9&YI`$UI;F1E="!K:6IE;/9L:OQK`%;A;&%S<WIA
M(&MI(&%Z(/9S<WIE<R!DX71U;?9S<WIE=&5V]70N`%;A;&%S<WIA(&MI+"!M
M96QY:6L@8^UM:F5G>7KI:V5T(&OM=N%N:F$@=/9R]FQN:0!6X6QA<W-Z82!K
M:2P@;65L>6EK(&/M;6IE9WEZZ6ME="!K[7;A;FIA(&WS9&]S[71A;FD`5N%L
M87-S>F]N(&5G>2!O8FIE:W1U;6]T`$5G>2!S92!L96=Y96X@:VEJ96SV;'9E
M`%;A;&%S<WIA(&MI+"!M96QY:6L@8^UM:F5G>7KI:V+U;"!K[7;A;B!E>'!O
M<G3A;&YI.@!6X6QA<W-Z82!K:2P@;65L>6EK(&/M;6IE9WEZZ6MB92!K[7;A
M;B!I;7!O<G3A;&YI.@!6X6QA<W-Z82!K:2!A(&OM=N%N="!K87)A:W1E<BAE
M:V4I="!A>B!A;.%B8FD@;&5H973U<^EG96L@:_9Z_&PN($5Z=73A;B`B8V]P
M>2]P87-T92(@;?-D<WIE<G)E;"!A(&UE9V9E;&5L]2!H96QY<F4@;>%S;VQH
M871J82#U:V5T+@!6X6QA<W-Z82!K:2!A>B!I;7!O<G3A;&%N9/,@9N%J;"!K
M87)A:W1E<FOI<WIL973I=#H`5N%L87-S>F$@:VD@82!DX71U;65L=N%L87-Z
M=/,@:V%R86MT97)T.@!6X6QA<W-Z82!K:2!A(&3A='5M(&9O<FWA='5MX70Z
M`%;A;&%S<WIA(&MI(&%Z(&5X<&]R=.%LX7,@9F]R;>%T=6WA=#H`5N%L87-S
M>F$@:VD@87H@:6UP;W)TX6QA;F3S(&;A:FQT.@!6X6QA<W-Z82!K:2!A>B!I
M;7!O<G3A;&%N9/,@9N%J;"!F;W)MX71U;>%T.@!6X6QA<W-Z82!K:2!A(&YE
M=F5K(&UE9VIE;&5N[73I<VD@9F]R;>%JX70Z`%;A;&%S<WIA(&MI+"!M96QY
M:6L@87IO;F]S[73S:N%T(&OM=N%N:F$@;65G=N%L=&]Z=&%T;FDZ`%;A;&%S
M<WIA(&MI(&%Z(&ED]65L=N%L87-Z=/,@:V%R86MT97)T.@!6X6QA<W-Z82!K
M:2!A>B!I9/4@9F]R;>%T=6WA=#H`5N%L87-S>F]N(&MI(&OI="!E9WEMX7-N
M86L@;65G9F5L96SU(&UE>O5T+@!+:7;A;&%S>G1H873S(&%Z(&%L87#I<G1E
M;&UE>F5T="!M96=J96QE;NUTZ7,L('-O<F)A<F5N9&5ZZ7-I(.ES(&QA<&]Z
MX7-I(&)EX6QL[73A<V]K+@!+:7;A;&%S>G1H873S+"!H;V=Y(&$@8^UM;&ES
M=.%B86X@;6EL>65N(&UE>O5K(&IE;&5N:F5N96L@;65G+@!+:7;A;&%S>G1H
M873S(&$@;F5V96L@;65G:F5L96[M=.ES:2!M\V1J82X`5N%L87-S>F$@:VD@
M82!K[7;A;G0@<WKM;F5G>?QT=&5S="X`5N%L87-S>F$@:VD@87H@UFYN96L@
M;65G9F5L96SU(&YY96QV970Z`$$@:VEVX6QA<WIT;W1T(&/M;6IE9WEZZ6L@
M(B5S(BX`2&EB86IE;&5N=.ES(&O\;&3I<V4`4TU3(&O\;&3I<V4`4WIE;F5G
MX6P`4WIE;GIO<CH@`'-Z97!T96UB97(`4WIE<F)I82#I<R!-;VYT96YE9W+S
M`%-O<F]Z871S>N%M`$$@<WIE<G9E<G3U;"!K87!O='0@861A="!H:6+A<RP@
M=F%G>2!N96T@X6QL(')E;F1E;&ME>NES<F4N`$$@9F5L:&%S>F[A;/-K87!C
M<V]L871O:R!A9&UI;FES>G1RX6-I\VIA`$QE:N%R="!A(&9E;&AA<WINX6SS
M:V%P8W-O;&%T(&%Z;VYO<^UT\VIA("AS97-S:6]N($E$*2X`1F5L:&%S>F[A
M;/-K87!C<V]L871O:P!(86QM87H`3&5H973U<^EG(&IE;'-Z87;A;F%K(.%T
MX6QL[73A<^%R82P@86)B86X@87H@97-E=&)E;BP@:&$@96QF96QE:G1E;NDN
M`%3A=F]L:2!S>F5R=F5R96L@96SI<NES92#A;&SM=&AA=/,@8F4L(&UE;'EE
M:V5T(&%Z(&EN9'5L\V]L9&%LX6X@:^UVX6X@;65G:F5L96[M=&5N:2X`02!K
M[7;A;G0@;GEE;'8L(&ED]7KS;F$@Z7,@9.%T=6UF;W)MX71U;2!B9>%L;.UT
MX7-A+@!"9>%L;.UT:&%T\RP@:&]G>2!M96QY:6L@86QK86QM87KA<R!J96QE
M;FIE;B!M96<@82!B96IE;&5N=&ME>NES('5TX6XL(&UI;'EE;B!S>NUN96=Y
M_'1T97-T+"!O;&1A;&9R:7-S[73I<VD@9WEA:V]R:7/A9V]T(&EL;"X@96=Y
MZ6(@8F7A;&SM=.%S;VMA="!S>F5R971N92X`0F7A;&SM=.%S;VL`02!B9>%L
M;.UTX7-O:V%T(&UE9_IJ[73S('!R;V=R86UO:R#A;&QN86L@<F5N9&5L:V5Z
MZ7-R90!!(&UE9V%D;W1T('!A<F%MZ71E<B!T]F)B(&AE;'EE="!I<R!J96QE
M;G1H970Z(`!397EC:&5L;&4M<WII9V5T96L`2_9Z]G,@8^UM=.%R`%;A<^%R
M;.%S`%+V=FED(/9S<WIE9F]G;&%LX7,`16P@:^UVX6YJ82#I<FYI(&%Z(&5G
M>65S(&9U;FMC:?-K870@06QT+6)I;&QE;G1Y^RUK;VUB:6[A8VGS:VMA;"!I
M<S\`365G:F5L96[M=.ES`"5S(&UE9VIE;&5N[73I<V4`375T87-S=6L@;6EN
M9&5T`$UU=&%S<W5K(&$@<&%R=&YE<F5K970`375T87-S=6L@82!L:7-TX6MA
M=`!-=71A<W-U:R!M96<@82!K_&SV;F)SZ6=E:V5T(&%Z(&5L;65N=&5T="#I
M<R!A>B#Z:F]N;F%N(&SI=')E:&]Z;W1T(&MO;F9I9W5RX6-I\R!K]GKV='0N
M`$UI;F1E;B!B96IE;&5N=&ME>NES:V]R(.UR\V1JZ6L@:VD@82!K;W+A8F)I
M('5T;VQS\R!B96IE;&5N=&ME>NES(&ED96IE/P!6X6QA<WIT:&%T\R!L96=Y
M96X@87H@97)E9&5T:2!M96=T87)TX7-A`$QE9WEE;B!DX71U;7;A;&%S>G3S
M`$QE9WEE;B!E9WD@=.%B;.%Z871K97IE;/4@;65N_'-O<C\`375T87-S=6L@
M82`E<R!M96[\="!A(&)A;"!O;&1A;&]N/P!.Z7IZ_&L@;65G('3A8FSA>F%T
M(&-E;&SA:6YA:R!T=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G('3A8FSA>F%T
M('1U;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@=.%B;.%Z870@<V]R86EN86L@
M='5L86ID;VYSX6=A:70`3NEZ>OQK(&UE9R!A(&OI<"!T=6QA:F1O;G/A9V%I
M=`!-=71A<W-U:R!A(&9E;'3V;'3I<W0`6N%P;W)O:P!:X7!O<F]K(&3I;&5L
M]71T`%KA<&]R;VL@9.EL=73A;B]E<W1E`$AE;'EI('KA<&]R;VL`2VEC<VEN
M>>UTZ7,`16SU<WKV<B!K:6-S:6YY[71E;FEE(&ME;&PL('9A9WD@96P@:V5L
M;"!M;WID[71A;FEA(&$@:&5L>65T(&5L9F]G;&%L\R!B;&]K:V]K870N`%-I
M97)R82!,96]N90#::B!F96QH87-Z;N%L\VL@8F5J96QE;G1K97KI<V4`1&EG
M:73A;&ES(&%LX>URX7,`02!D:6=I=.%L:7,@86SA[7+A<R!A;&=O<FET;75S
M80!3>FEN9V%P^G(`3>ER970`02!K87)B86YT87)TX7,@:VEH86=YX7-A`%-Z
M;&]VX6MI80!3>FQO=NEN:6$`2&%V87KA<P!(\WKA<&]R`$CS>N%P;W)O:P!(
M\WKA<&]R;VL@9.EL96SU='0`2^ES]2!DZ6QU=.%N:2]E<W1I(&CS>N%P;W)O
M:P!!(&CS(&WI;'ESZ6=E.B``2/,@=NUZ;65N;GEI<^EG96)E;B!K:69E:F5Z
M=F4Z(`!386QA;6]N+7-Z:6=E=&5K`%-Z;VWA;&EA`$1A;&]K+"!V97)S96L`
M02!S;W)B87)E;F1E>NES(&ERX6YY80!!('-O<F)A<F5N9&5ZZ7,@:7+A;GGA
M;F%K(&MI=N%L87-Z=.%S80!&96QA9/-I(&/M;0!#[6UJ96=Y>NEK(&9O<G+A
M<V]K`$3I;"U!9G)I:V$`9.EL+65U<O-P86D@*$E33RTX.#4Y+3,I`$3I;&DM
M1V5O<F=I82#I<R!$Z6QI(%-A;F1W:6-H+7-Z:6=E=&5K`$3I;&D@9NEL=&5K
M90!3>F]M<WKI9&]S(&-E;&SA:R!K]GKV='1I('3A=F]L<^%G`$$@8V5L;&$@
M=&%R=&%L;6$@Z7,@:V5R971E(&OV>O9T=&D@=.%V;VQSX6<`2&5L>6MI=/9L
M=/4`5.%V;VQSX6<`5.%V;VQSX6<@Z7,@8F5L<_4@;6%R9_,@8F7A;&SM=.%S
M`%-P86YY;VQO<G-ZX6<`4W!A;6%S<V%S<VEN92!B9>%L;.UTX7-O:P!3<&5C
M:>%L:7,@:V%R86MT97(@8F5V:71E;&4`5N%L87-S>F$@:VDL(&AO;"!J96QE
M;FIE;B!M96<@82!RZ7-Z;&5T97,@:V5R97/I<R!E<F5D;>EN>64N`$$@8V5L
M;&$@:V5T=.EB;VYTX7-A`$%Z(&]S>FQO<"!K971TZ6)O;G3A<V$`02!S;W(@
M:V5T=.EB;VYTX7-A`%-P;W)T`%-R[2!,86YK80!3=&%N9&%R9`!3=&%R(%1R
M96L`07H@96QS]2#I=@#!;&QA;2!V86=Y('1A<G1O;>%N>0#!;&QA<&]T`$UE
M;G3I<VD@9F]R;>%T=6T`0^UM("AU=&-A*0#A=&CZ>F]T=`!3=')I;F<@;&ES
M=&$`5/9R]FQJ_&L@82!C[6UB]6P@82!`('5TX6YI('+I<WIT`%-T[6QU<R!;
M0U-370!680!!*'HI("(E<R(@86QK]FYY=G3A<B!N96T@=&%LX6QH873S+@!4
MX7)G>0!+_&QD:OQK(&5L`"(E<R(@^FH@9F5L:&%S>F[A;/,@8F5J96QE;G1K
M97KI<VD@:^ER96QMZ70@=&]VX6)B[71O='1U:RX@UFX@8W-A:R!KZ7)E;&WI
M;F5K(&5L9F]G863A<^%T(&OV=F5T]65N('1U9"!M86ID(&)E:F5L96YT:V5Z
M;FDN`&%L<_,@:6YD97@`4VEK97+\;'0`4VEK97)E<V5N(&AO>GKA861T=6L@
M(B5S(BUT(&$@<F5N9'-Z97)H97HN`$$@;&ES=.%H;WH@<VEK97)E<V5N(&AO
M>GKA861T=6YK("5D(&/M;65T+@`E<R!H;WIZX6%DX7-A("5S+6AE>B!S:6ME
M<F5S('9O;'0`(B5S(B!F96QH87-Z;N%L\R!A9&%T86ET('-I:V5R97-E;B!T
M]G+V;'3\:R!A(')E;F1S>F5R8O5L+@!3:6ME<F5S96X@;.ET<F5H;WIT=6L@
M82AZ*2`B)7,B(&/M;6QI<W3A="X`4VEK97)E<V5N('3V<O9L=/QK("(E<R(M
M="X`4VEK97)E<V5N('3V<O9L=/QN:R`E9"!C[6UE="X`4VEK97)E<V5N(&5L
M=.%V;VSM=&]T='5K("(E<R(M="!A(')E;F1S>F5R8O5L+@!3:6ME<F5S96X@
M96QTX79O;.UT;W1T=6L@)60@8^UM970@82!L:7-TX7+S;"X`02!K;VYF:6=U
M<N%C:?-T('-I:V5R97-E;B!V:7-S>F'A;&SM=&]T='5K+B!!(';A;'1O>N%S
M;VL@;65G=&5K:6YTZ7/I:&5Z(&9R:7-S[71S92!A>B!O;&1A;'0N`$$@8F%C
M:W5P(&MO;F9I9W5RX6-I\W0@96QM96YT971T_&LN`%-I:V5R97-E;B!E;&UE
M;G1E='3\:R!A*'HI("5S(&)A8VMU<"!K;VYF:6=U<N%C:?-T+@`B)7,B(&%D
M871A:6YA:R!M\V1O<^UTX7-A('-I:V5R97-E;B!M96=T]G)TZ6YT+@!3:6ME
M<F5S96X@96QM96YT971T_&L@82`E<R#A;&QO;>%N>70N`%-Z=63A;@#6<W-Z
M969O9VQA;.%S`$YA<&ME;'1E`$YA<&YY=6=T80!N87!O<P!.87!K96QT90!.
M87!K96QT92]N87!N>75G=&$`3F%P:V5L=&4Z(`!.87!N>75G=&$`3F%P;GEU
M9W1A.B``9F5L<_4@:6YD97@`3VYL:6YE(&MO;6UU;FEKX6-I\R`H8VAA="D`
M4W5R:6YA;64`0W-A;.%D;NEV`%-V86QB87)D(.ES($IA;B!-87EE;@!3>G;A
M>FEF]FQD`%-VZ61O<G-ZX6<`4W;A:F,`07H@861A='-Z:6YK<F]N:7KA8VGS
M<R!N87!L\^%L;&]MX6YY="!T]G+V;'3\:P!3>FEN=&%K=&EK86D@:&EB82!A
M(&ME<F5S]6MI9F5J97KI<V)E;@!3>NUR:6%I($%R86(@2_9Z=.%R<V%SX6<`
M6FEV871A<@!::79A=&%R+"!E<O5S('-ZZ6P`6FEV871A<F]K`$MO<F%I('II
M=F%T87)O:P!44U8@*%1!0B!K87)A:W1E<G)E;"!E;';A;&%S>G1O='0@Z7)T
MZ6ME:RD@X6QL;VWA;GD`5$%"(&MA<F%K=&5R<F5L(&5L=N%L87-Z=&]T="#I
M<G3I:V5K`%3A8FSA>F%T`$$@=.%B;.%Z870@='5L86ID;VYSX6=A:0!!('3A
M8FSA>F%T('1U;&%J9&]N<^%G86D`5&%J=F%N`%1A:G9A;@!4861Z<VEK:7-Z
M=.%N`%1A;GKA;FEA:2!%9WEE<_QL="!+:7+A;'ESX6<`02!CZ6PZ`$9E;&%D
M871O:P!496QE9F]N<WKA;0!!>B!E;&WZ;'0@\W)A(&CU;>ER<^EK;&5T93H@
M`$CU;>ER<^EK;&5T`$CU;>ER<^EK;&5T.B``2/5MZ7)SZ6ML970\8G(@+SXH
M)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S`$$H>BD@(B5S(B!S86)L;VX@;F5M
M('1A;.%L:&%T\RX`4V%B;&]N;VL@861M:6YI<WITX6-I\VIA`%-Z]G9E9P!C
M<V%K('-Z]G9E9P!3>O9V96=E;&AE;'EE>NES`'-Z]G9E9R!T971E:F4`0W/\
M`'1H86D@*%1)4RTV,C`I`%1H86EF]FQD`$%Z(&9T<"!B]7;M=.ES(&YE;2!T
M86SA;&AA=/,N`$$@2&ES=&]R>2!R96YD<WIE<B!M^VOV9.ES92!N:6YC<R!E
M;F=E9.EL>65Z=F4N`$$@2&]R9&4O2V]L86(@:6YT96=RX6-I\R!E>G0@;F5M
M('3A;6]G871J83H@(B5S(@!!>B!)35-0(&YA<&SS>N%S="!N96T@<VEK97+\
M;'0@;65G:V5Z9&5N:2X`02!-86EN=&5N86YC93HZ(&]S>G3A;'D@8F5T]FQT
MZ7-E(&YE;2!S:6ME<OQL=`!!>B!/<&-I\R!A8FQA:R!B97KA<F]D;W1T+B!+
M:6SI<.ES(&OV=F5T:V5Z:6LN`$$@5D93(&%L<F5N9'-Z97(@8F7A;&SM=.%S
M86EB86X@96YG963I;'EE>FYI(&ME;&P@82!M96QLZ6ML971E:R!F96QT]FQT
M:&5T]7/I9^ET+@!!*'HI("(E<R(@8^UM:F5G>7KI:R!N96T@;.ET97II:RX`
M02AZ*2`B)7,B(&/M;6IE9WEZZ6ME="!S:6ME<F5S96X@;.ET<F5H;WIT=6LN
M`$$H>BD@(B5S(B!C[6UJ96=Y>NEK970@<VEK97)E<V5N('3V<O9L=/QK+@!!
M*'HI("(E<R(@8^UM:F5G>7KI:V5T('-I:V5R97-E;B!M\V1O<^UT;W1T=6LN
M`$$@8^UM:F5G>7KI:R!N96T@=/9R]FQH973U.B`E<P!!($IO9V]S=6QT<^%G
M;VL@:&%S>F[A;&%TX6YA:R!E;/5F96QTZ71E;&4L(&AO9WD@82!R96YD<WIE
M<F=A>F1A(&MO;F9I9W5RX6QJ;VX@96=Y(&$@:F]G;W-U;'1SX6=I(&%D871O
M:V%T('1A<G3S<V%N('3A<F]L;FD@:^EP97,@86QR96YD<WIE<G0N`$-S86L@
M86QU;"!L96=Y96X@:V5R970`02!P87)T;F5R(&%Z;VYO<^UT\W-ZX6UA(&YE
M;2!V;VQT(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871BX7II
M<V)A;B!N96T@=F]L="!M96=T86SA;&AA=/,N`$$@<&%R=&YE<B!A9&%T86ET
M('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI:^EH97HN`$$@:V5R
M97-E='0@;&5V96QE>O5P87)T;F5R(&YE;2!LZ71E>FEK+@!+_&SV;N%L;/,@
M4$=0(&%LX>URX7-I(&)L;VMK('-Z_&MSZ6=E<R!A(&1I9VETX6QI<V%N(&%L
MX>UR="#\>F5N970@:&ET96QE<W/I9^EN96L@96QL96[U<GKI<^EH97HN`$$@
M:_9R;&5VZ6QL:7-T82!A>F]N;W/M=/-S>N%M82!N96T@=F]L="!M96=A9'9A
M+_QR97-E;B!M87)A9'0@=F%G>2!A>B!A9&%T8N%Z:7-B86X@;F5M('9O;'0@
M;65G=&%LX6QH873S+@!!(&OV<FQE=NEL;&ES=&$@;F5M('9O;'0@;65G861V
M82X`02!T:71K;W/M=.%S:2!S>F]L9^%L=&%TX7-O:VAO>B!B:7IT;VYSX6=O
M<R`H=&ET:V]S[71O='0I('=E8B!K87!C<V]L870@:V5L;"X`02AZ*2`B)7,B
M(.%L;&]MX6YY="!S:6ME<F5S96X@=/9R]FQT_&LN`$$H>BD@)7,@X6QL;VWA
M;GEB86X@<WIE<F5P96QN:64@:V5L;&5N92!E9WD@)7,@8F7A;&SM=.%S;F%K
M+@!!*'HI("5S(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@=F%L
M86UI;'EE;B`E<R!B9>%L;.UTX7,H;VLI;F%K+@!!(&;A:FP@;F5M(&WA<V]L
M:&%T\R#V;FUA9^%R82X`02!FX6IL8F%N(&YE;2!V;VQT(&%D870N`$%Z(/QZ
M96YE="!F96ILZ6-S;W)A:2!A(&OV=F5T:V5Z]6LN`$$@=&5L:F5S(&OI<&5R
M;GGU<R#\>F5M;?-D('!R;V)LZ6WA:V%T(&]K;WIH870@87H@26YT97)N970@
M17AP;&]R97(@:&%S>F[A;&%T82!E<V5TZ6XL(&UE<G0@96)B96X@;VQY86X@
M<')O9W)A;6AI8N%K('9A;FYA:RP@86UI:V5T(&YE;2!T=61T=6YK(&UE9VME
M<OQL;FDN($$@:^EP97)N>?5J92!O;'9A<VAA=&%T;&%N;N$@=N%L:&%T+"!B
M:7IO;GEO<R!E9&ET;W(@9G5N:V-I\VL@:&GA;GEO>FAA=&YA:R#I<R]V86=Y
M(';A<F%T;&%N=6P@;&5F86=Y:&%T(&$@8O9N9^ES>O5P<F]G<F%M+B!7:6YD
M;W=S(#EX(&AA<WINX6QA=&$@97-E=.EN(&YA9WEO;B!V86SS<WKM;OLL(&AO
M9WD@)T=E;F5R86P@<')O=&5C=&EO;B!F875L="<@:&EB82!M:6%T="#Z:G)A
M(&ME;&P@:6YD[71A;FEA(&UA:F0@82!GZ7#I="Y<;EQN1FEG>65L;65Z=&5T
M=/QK(2!+871T:6YT<V]N(&%Z($]+(&=O;6)R82P@:&$@;>EG:7,@;65G(&OM
M=N%N:F$@:^USZ7)E;&YI(&$@=&5L:F5S(&OI<&5R;GGU<R#\>F5M;?-D;W0N
M`$$@(B5S(B!A>F]N;W/M=/-T(&MI=/9R]FQT_&LN`$%Z(&EM<&]R=.%LX7,@
M82!F:6=Y96QM97IT973I<V5K(&5L;&5NZ7)E(&)E9F5J97IH973U+@!#<V%K
M(&)A;"!O;&1A;&]N(&QE9WEE;B!K97)E=`!!($=N=5!'('!R;V=R86T@:&5L
M>>ET(&UE9R!K96QL(&%D;FD@82!#<GEP=%]P9W`Z.B!O<WITX6QY(&AA<WIN
MX6QA=.%H;WHN`$$@;&5VZ6PL(&UE;'EE="`E<R!N87!JX6X@:_QL9/9T="`E
M<R!C[6UZ971T;F5K("(E<R(@=.%R9WEB86XL(&$@8^UM>F5T="!S>N%M[73S
M9^EPZ6X@;65G:F5L96YT+B!!<G)A(&YI;F-S(&=A<F%N8VEA+"!H;V=Y(&5L
M(&ES(&]L=F%S=.%K(&EL;"X@:&]G>2!M96?I<G1E='3I:RX`36D@;&5G>65N
M(&$@;&5VZ6SM<O,@86)L86MH;WH@;75T873S(&QI;FL@96QN979E>NES90!!
M(&UE>O5K('-ZX6UA(&-S86L@;G5M97)I:W5S(.ER=.EK(&QE:&5T+@!!>B!O
M<&5N<W-L(&UO9'5L('-Z_&MSZ6=E<R!A($AO<F1E7T-R>7!T7W-M:6UE.CH@
M;W-Z=.%L>2!H87-Z;N%L873A:&]Z+@!!("(E<R(@<WIE;>EL>65S(&)EX6QL
M[73A<R!N96T@;65N=&AE=/4@96PL(&UE<G0@;>ER971E(&UE9VAA;&%D:F$@
M82!M96=E;F=E9&5T="!M87AI;75M;W0`3F5M('1A;.%L:&%T\R!A>B!A('!R
M;V=R86T@82!S>F5R=F5R96XL(&%M:2!S>OQK<^EG97,@96YN96L@87H@861A
M='3M<'5S;F%K("@E<RD@82!M96=J96QE;NUTZ7/I:&5Z+@!!>B!I9.EZ]6IE
M;"!K87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+@!*;V)B
M(.ES(&)A;"!O;&1A;&]N(&QE9WEE;B!K97)E=`!#<V%K(&IO8F(@;VQD86QO
M;B!L96=Y96X@:V5R970`07H@96QVX6QA<WIT\R!K87)A:W1E<B!C<V%K(&5G
M>65T;&5N(&MA<F%K=&5R(&QE:&5T+@!!*'HI("(E<R(@<WIE<G9E<G0@=/9R
M]FQT_&LN`$$H>BD@(B5S(B!S>F5R=F5R="!E;&UE;G1E='3\:RX`)7,@8F5J
M96QE;G1K97KI<VD@:^ER96QMZ70@=/9R]FQT_&LN`$$@;65G861O='0@<V]R
M("@E9"D@;F5M(&SI=&5Z:6LN`$$H>BD@(B5S(B!I9&5I9VQE;F5S(&;A:FP@
M;F5M(&SI=&5Z:6LN`$$@8F7M<G0@<WKV=F5G(&YE;2!E9WEE>FEK(&$@:^EP
M97)N>?5N(&QE=O5V96PN`$%L=6P@Z7,@9O9L_&P@;&5G>65N(&ME<F5T`$-S
M86L@9F5N="!L96=Y96X@:V5R970`02!F96QT]FQT]G1T(&%D871O:R!A>B!E
M;/5Z]2!LZ7#I<R#S=&$@96QV97-Z=&5K+@!!(&9E;'3V;'3V='0@9N%J;'0@
M;F5M('-I:V5R_&QT(&5L;65N=&5N:2X`02!W96%T:&5R+F-O;2!B;&]K:R!N
M96T@:&%S>F[A;&AA=/,N`$$@;65G:F5L96[I<VD@<W3M;'5S("AT:&5M97,I
M(&%L:_9N>79TX7(@(B5S(B!N96T@=&%LX6QH873S+@!.:6YC<V5N(&]L>6%N
M(&/M;6IE9WEZZ6LL(&%M:6)E;B!B]FYGZ7-Z;FD@='5D+@!.:6YC<V5N(';A
M;&%S>G1H873S(&]P8VGS+@!.:6YC<R!A(&QE=NEL(&)E;'-E:NEB96X@;65G
M:F5L96[M=&AE=/4@;65L;.EK;&5T+@!.:6YC<R#M<FAA=/,@8^UM:F5G>7KI
M:RX@16=Y971L96X@<F5N9&5L:V5ZZ7-R92#A;&SS(&/M;6IE9WEZZ6MH97H@
M<V5M(&IO9V]S=6QT(/IJ86)B(&)E:F5G>7KI<V5K970@:&]Z>N%T96YN:2X@
M2&$@^F=Y(&=O;F1O;&IA+"!H;V=Y(&5Z(')E;F1E;&QE;F5S+"!A:VMO<B!F
M;W)D=6QJ;VX@82!H96QY:2!R96YD<WIE<F=A>F3A:&]Z+@!4^FP@<V]K(&MA
M<F%K=&5R('9A;B!E8F)E;B!A(&UE>O5B96XN(-9N("5S(&MA<F%K=&5R="!A
M9&]T="!M96<[(&$@;6%X:6WA;&ES86X@;65G861H873S('!E9&EG(&ME=F5S
M96)B+"!M:6YT("5S+@`B)7,B(&9E;&AA<WINX6SS;F%K(&$@<F5N9'-Z97)H
M97H@863A<V%K;W(@:&EB82!T]G)TZ6YT+B`E<P`B)7,B(&9E;&AA<WINX6SS
M(&%D871A:6YA:R!T]G)LZ7-E('-O<N%N(&AI8F$@;.EP971T(&9E;#H@`"(E
M<R(@<F5N9'-Z97)B]6P@=F%L\R!T]G)LZ7-E:V]R(&AI8F$@;.EP971T(&9E
M;#H@`"(E<R(@;?-D;W/M=.%S82!S;W+A;B!H:6)A(&SI<&5T="!F96PZ("5S
M`$%Z(.%L;&]MX6YY="!N96T@<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L
M=&5N:2X@)7,@;F5M('3V;'3U9/9T="!F96PN`$%Z(.%L;&]MX6YY="!N96T@
M<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@)7,@;F%G>6]B8BP@
M;6EN="!A(&UA>&EMX6QI<V%N(&UE9V5N9V5D971T(&WI<F5T("@E9"!BX6IT
M*2X`07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT
M]FQT96YI+B!!*'HI("5S(&;A:FQN86L@8W-A:R!E9WD@<NES>F4@=/9L=/5D
M]G1T(&;V;"X`02!P87)T;F5R(&%D871A:6YA:R!H;WIZX6%DX7-A(&YE;2!S
M:6ME<OQL="X@5&]VX6)B:2!S96?M='/I9^ER="!F;W)D=6QJ;VX@82!R96YD
M<WIE<F=A>F3A:&]Z+@!(:6)A('3V<G3I;G0@87H@^FH@;&ES=&$@;.ET<F5H
M;WKA<V$@<V]RX6XN`$AI8F$@=/9R=.EN="!E;FYE:R!A(&/M;6IE9WEZZ6MN
M96L@82!LZ71R96AO>N%S82!S;W+A;CH@)7,`(B5S(BUT(&YE;2!S:6ME<OQL
M="!K:73V<O9L;FD@87H@97)E9&5T:2!C[6UJ96=Y>NEK8O5L+@!!('!A<G1N
M97(@861A=&%I;F%K('3V<FSI<V4@<V]RX6X@:&EB82!T]G)TZ6YT.B`E<P!!
M(&QI<W1A(&UE9VIE;&5N[73I<V5K;W(@:&EB82!T]G)TZ6YT`$$@;&5VZ6P@
M92!RZ7-ZZ6YE:R!M96=J96QE;NUTZ7-E:V]R(&AI8F$@=/9R=.EN=`!!('!A
M<G1N97(@861A=&]K(&EM<&]R=.%LX7-A('-O<N%N(&AI8F$@=/9R=.EN="X`
M07H@:6UP;W)TX6SA<R!S;W+A;B!H:6)A('3V<G3I;G0Z("5S`$%Z(&E#86QE
M;F1A<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@:&EB82!T]G)TZ6YT+@!(
M:6+A<R!A(&UE9V%D;W1T(&MO;F9I9W5RX6-I\RX@3&5H970L(&AO9WD@;F5M
M('3V;'3V='0@:VD@96=Y('-Z_&MSZ6=E<R!M97KU="X`02!P87)T;F5R:F5G
M>7KI:VME;"!K87!C<V]L871O<R!F96QA9&%T(';I9W)E:&%J=.%S82!S;W+A
M;B!H:6)A(&SI<&5T="!F96PN($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N
M`$AI8F$@=/9R=.EN="!E(&/M;6IE9WEZZ6L@=/9R;.ES92!S;W+A;CH@)7,`
M2&EB82!T]G)TZ6YT(&$@<&%R=&YE<B!A9&%T86EN86L@9G)I<W/M=.ES92!S
M;W+A;BX@2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BX`02!K]G)L97;I;&QI
M<W1A(&%D871A:6YA:R!F<FES<^UTZ7-E('-O<N%N(&AI8F$@=/9R=.EN="X@
M2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BX`2&EB82!T]G)TZ6YT(&4@8^UM
M:F5G>7KI:R!M\V1O<^UTX7-A('-O<N%N.B`E<P!(:6)A('3V<G3I;G0@96YN
M96L@87H@861A=&YA:R!A(&WS9&]S[73A<V$@<V]RX6XZ("5S`$YE;2!V;VQT
M(&5X<&]R=.%L:&%T\R!C[6TN`$5Z96L@82!C[6UJ96=Y>NEK96L@82!K]G9E
M=&ME>O4@<V]R<F5N9&)E;B!J96QE;FYE:R!M96<Z`$5Z96L@87H@;W-Z;&]P
M;VL@82!K]G9E=&ME>O4@<V]R<F5N9&)E;B!J96QE;FYE:R!M96<Z`$5Z(&%Z
M($E-05`@<WIE<G9E<B!N96T@=.%M;V=A=&IA(&$@;6%P<.%K:&]Z('9A;/,@
M:&]Z>N%FZ7+I<R!M96=O<WITX7/A="X`17H@;F5M('3[;FEK('-Z86+A;'EO
M<R!R87(@X6QL;VWA;GEN86LN`$5Z(&YE;2!T^VYI:R!S>F%BX6QY;W,@>FEP
M(.%L;&]MX6YY;F%K+@!%>B!N96T@=/MN:6L@Z7)VZ6YY97,@:^%R='EA<WKA
M;6YA:RX`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10
M+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&$@0VQI8VMA=&5L;"`H:'1T
M<#HO+V-L:6-K871E;&PN8V]M*2!S>F]L9^%L=&%T\VX@X70N`$5Z(&$@;65G
M:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!3
M35,M="!K_&QD:OQN:R!A(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI('-Z;VQG
MX6QT873S;B#A="X`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G
M>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&%Z('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI('-Z;VQGX6QT873S;B#A="X`17H@
M82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!33510+6MA<&-S;VQA
M=&]N(%--4RUT(&O\;&1J_&YK(%9O9&%F;VYE('-ZX6UO:W)A(&$@5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!S>F]L9^%L=&%T\VX@X70N
M($$@<WIO;&?A;'1A=.%S(&EGZ6YY8F5VZ71E;.EH97H@5F]D869O;F4@271A
M;'D@96UA:6P@8^UM('-Z_&MSZ6=E<RX`17H@82!M97KU(&YE;2!M87)A9&AA
M="#\<F5S+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@X6QL
M:&%T;F%K+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@Z7,@
M:V5T=/5S<&]N="!L96AE="X`16)B96X@82!M97KU8F5N(&-S86L@;VMTX6QI
M<R!S>N%M;VL@X6QL:&%T;F%K+@!%>B!A(&UE>O4@8W-A:R!V97-S>O5V96P@
M=F%G>2!S>O-K]GIZ96P@96QVX6QA<WIT;W1T(&5GZ7-Z('-ZX6UO:V%T('1A
M<G1A;&UA>FAA=`!%>B!A>B#I<G3I:R!C<V%K('-ZX6T@;&5H970N`$5B8F5N
M(&$@;65Z]6)E;B!H97AA9&5C:6WA;&ES(%)'0B!S>NUN:_-D(.%L;&AA="P@
M<&PN("<C,3(S-&%F)RX`07H@82!FX6IL9F]R;>%T=6T@;F5M('3A;6]G871O
M='0N`$5Z96X@861A=&]K:V%L(&MA<&-S;VQA=&]S(&9E;&%D871O:V%T(&$@
M<WIE<G9E<B!MX7(@96QVZ6=E>G1E+@!%>B`E<P!%>B!E9WD@2V]L86(@1W)O
M=7!W87)E(&]B:F5K='5M+B!!>B!I;'EE;B!O8FIE:W1U;2!M96=J96QE;NUT
MZ7/I:&5Z(&]L>6%N(&5M86EL(&ML:65N<W!R;V=R86T@<WK\:W/I9V5S+"!A
M;65L>2!KZ7!E<R!A($MO;&%B($=R;W5P=V%R92!F;W)MX71U;2!K97IE;.ES
MZ7)E+B!);'EE;B!E;6%I;"!K;&EE;G-E:R!L:7-TX6IA(&SA=&AA=/,@:71T
M.B`E<P!%>G0@82!L979E;&5T(&WA<R!K87)A:W1E<FOI<WIL971T96P@*"5S
M*2#M<G3A:RP@;6EN="!A;6ET(-9N(&AA<WINX6PN`$5Z(&$@<WKA;2!N96T@
M;&5H970@96=Y;NEL(&MI<V5B8BX`17H@82!S>F5MZ6QY(&WA<B!S>F5R97!E
M;"!A(&/M;6IE9WEZZ6OI8F5N+"!M:6YT("5S`$5Z(&$@<WIE<G9E<B!N96T@
M:^EP97,@:VEB;VYT86YI(&$@>FEP(&EL;"X@9WII<"#A;&QO;>%N>6]K870N
M`$5Z(&$@<F5N9'-Z97(@:F5L96YL96<@:6YA:W1I=N%L=F$@=F%N+@!%>B!A
M>B#I<G3I:R!C<V%K('-ZX6T@;&5H970N`$5Z(&QE<WH@87H@86QA<.ER=&5L
M;65Z971T(&/M;6IE9WEZZ6L@^FH@861A=&]K(&SI=')E:&]ZX7-A:V]R(&EL
M;"X@:6UP;W)TX6SA<V%K;W(N`$5Z="!A>B!A8FQA:R!C<V%K(&%Z($]P8VGS
M:R!A8FQA:V+S;"!H[79H873S`%9I;&SA;6SA<P!(:6)A8F5J96QE;G3I<RUK
M97IE;.ES`$ED]0!-=6YK86ED]2UN>6EL=N%N=&%R=.%S`$ED]2!F;W)MX71U
M;0!)9/4@=N%L87-Z=.%S`$ME;&5T+51I;6]R`%1I='5L=7,`0^UM("AT;V]L
M=&EP*0!#[6UZ971T`$AA('3V8F(@96QE;65T(&ES(&MI(&%K87(@:F5L]FQN
M:2P@=&%R='-A(&QE;GEO;79A(&$@0V]N=')O;"`H4$,I('9A9WD@82!#;VUM
M86YD("A-86,I(&)I;&QE;G1Y^W0@82!K871T:6YTX7,@:_9Z8F5N+@!-80!(
M5$U,(&9O<G+A<V[I>F5T(&MI+V)E`%1O9V\`5&]K96QA=0!(;VQN87``5&]N
M9V$`9O9L_&P`3&5G9F5L<_4@9G)A;64@*%]T;W`I`$9O<F3M=.%S;VL`5')I
M;FED860@Z7,@5&]B86=O`$EG87H@=F%G>2!H86UI<P!+90!4=6[I>FEA`%3V
M<O9K;W)S>N%G`'3V<O9K("A)4T\M.#@U.2TY*0!4_')K;65N:7-Z=.%N`%1U
M<FMS+2#I<R!#86EC;W,M<WII9V5T96L`5'5V86QU`,UR:F$@8F4L(&UI="!V
MX6QA<WIT;W1T.B``558@:6YD97@Z(`!54DP`55),+"!M96QY96X@96=Y('!R
M;V=R86T@96QF;V=A9&IA(&$@<WIO;&?A;'1A=/,@X6QT86P@:_QL9/9T="!K
M_&QD]G1T(&OI>F)E<^UTZ7-I(&IE;&5N=.ES=`!54DPZ`%5G86YD80!5:W)A
M:FYA`$YE;2!S:6ME<OQL="!A(%9&4R!A;&OV;GETX7)B82!B96SI<&YI+@!!
M(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%G(&EGZ6YY;.ES96MO<B!N96T@
M<VEK97+\;'0@87H@861A=&]K(&5L=.%R;VSA<V$N`$YE;2!S:6ME<OQL="!A
M*'HI("(E<R(@5D93(&;A:FP@96SI<NES:2!J;V=O<W5L='/A9V%I="!M96=V
MX6QT;WIT871N:2X`3F5M('-I:V5R_&QT(&$H>BD@)7,O)7,@5D93(&;A:FP@
M96SI<NES:2!J;V=O<W5L='/A9V%I="!M96=VX6QT;WIT871N:2X`3F5M('-I
M:V5R_&QT(&$H>BD@)7,@86QK]FYY=G3A<F)A(&)E;.EP;FDN`$$H>BD@(B5S
M(B#A;&QO;>%N>2!MZ7)E=&4@;F5M(.%L;&%P[71H873S(&UE9RX`02AZ*2`B
M)7,O)7,B(.%L;&]MX6YY(&WI<F5T92!N96T@X6QL87#M=&AA=/,@;65G+@!!
M>B!344P@<WIE<G9E<B!N96T@Z7)H973U(&5L+@!!>B!34TP@:V%P8W-O;&%T
M(&YE;2#I<.UT:&5T]2!F96PN`$$@5D93(&;A:FP@;F5M(&WA<V]L:&%T\R#A
M="X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(B!61E,@86QK]FYY=G3A<G0@;.ET
M<F5H;WIN:2X`3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@82!61E,@86QK]FYY
M=G3A<G0N`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@5D93(&;A:FQT+@!!
M*'HI("(E<R(@5D93(&UA<'!A(&YE;2!H;WIH873S(&SI=')E+@!.96T@<VEK
M97+\;'0@;.ET<F5H;WIN:2#\<F5S(%9&4R!FX6IL="X`3F5M('-I:V5R_&QT
M(&SI=')E:&]Z;FD@82!K]GKV<R!C[6UJ96=Y>NEK970N($ES;65R971L96X@
M82!F;W)RX7,@=.UP=7-A+@!!('3V;?9R[71E='0@X6QL;VWA;GET(&YE;2!S
M:6ME<OQL="!K:6)O;G1A;FDN`"(E<R(@;F5M('3V<O9L:&5T]2P@87H@86QK
M]FYY=G3A<B!N96T@_')E<RX`(B5S(B!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@
M)7,N`"5S(&YE;2!T]G+V;&AE=/4L(&%Z(&%L:_9N>79TX7(@;F5M(/QR97,N
M`$$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2!R96MU<GKM=F%N+@!!
M(%9&4R!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N`$$@5D93(&%L:_9N>79T
MX7(@;F5M('3V<O9L:&5T]3H@)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@
M=/9R]FQH973U+@!!(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N`$$H>BD@(B5S
M(B!61E,@;6%P<&$@;F5M('3V<O9L:&5T]2X`3F5M(';I9V5Z:&5T\R!R96MU
M<GKM=B!T]G)LZ7,@82!61E,M8F5N.B`E<RX`3F5M(&AA=.%R;WIH873S(&UE
M9R!A(&IE;&5N;&5G(.ER=NEN>65S(&%L:_9N>73A<BX`02!T86[Z<^UT=N%N
M>2!RZ7-Z;&5T97,@861A=&%I(&YE;2!H873A<F]Z:&%T\VL@;65G`$YE;2!S
M:6ME<OQL="!B96]L=F%S;FD@)7,@9&5F:6[M8VGS:N%T+@!!(%9&4R!FX6IL
M(&YE;2!H96QY97IH973S(.%T+@!!*'HI("(E<R(@5D93(&;A:FP@;F5M(&YY
M:71H873S(&UE9RX`02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G(.URX7-I
M(&/I;&QA;"X`02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G("X`02!T]FWV
M<NUT971T(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<N`$$@5D93(&;A:FP@
M;F5M(&]L=F%S:&%T\R`H82!F:6QE<VEZ92@I('-I:V5R=&5L96X@=F]L="DN
M`$$@5D93(&;A:FP@;F5M(&]L=F%S:&%T\R`H82!G971&:6QE4VEZ92@I('-I
M:V5R=&5L96X@=F]L="DN`$5Z(&$@9N%J;"!N96T@;VQV87-H873S.B``02!V
M9G-R;V]T(&%L:_9N>79TX7(@;F5M(&]L=F%S:&%T\RX`)7,@;F5M(&YE=F5Z
M:&5T]2#A="`E<R!NZ79R93H@;>%R(&SI=&5Z:6L@:6QY96X@;F5V^R!M87!P
M80!!(%9&4R!A;&OV;GEV=.%R(&YE;2!N979E>FAE=/4@X70N`$$@5D93(&%L
M:_9N>79TX7(@;F5M(&YE=F5Z:&5T]2#A=#H@)7,N`$$H>BD@(B5S(B!61E,@
M9N%J;"!N96T@;F5V97IH973U(.%T+@!!*'HI("5S+R5S(%9&4R!FX6IL(&YE
M;2!N979E>FAE=/4@X70N`$$@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`
M07H@)VUK:7-O9G,G('!R;V=R86T@;F5M(&9U='1A=&AA=/,N`$YE;2!S:6ME
M<OQL="!L969O<F3M=&%N:2!E>G0@82!7;W)D(&1O:W5M96YT=6UO=`!!*'HI
M("(E<R(@5D93(&;A:FP@;F5M(.UR:&%T\RX`02!61E,@9N%J;"!N96T@[7)H
M873S("AA(&-O<'DH*2!S:6ME<G1E;&5N('9O;'0I+@!!(%9&4R!FX6IL(&%D
M871A:2!N96T@[7)H873S:R!K:2X`02!61E,@9N%J;"#M<N%S82!K=O-T873Z
M;&SI<.ES(&UI871T(&YE;2!F96IE>FAE=/4@8F4N`&%LX6CZ>F]T=`!-Z6=S
M92!M96YT<_QK(&5L`%9I<W-Z879O;FIA(&%Z('5T;VQS\R!VX6QT;WIT873A
M<W0`02!K87!C<V]L870@9F5L=NET96SI="!K]G9E=/5E;B!VX7)A=&QA;B!V
MX6QA<WH@Z7)K97IE='0@82!S>F5R=F5R=/5L.B``5N%R871L86X@=N%L87-Z
M(.ER:V5Z971T(&$@<WIE<G9E<G3U;"!E<G)E.B``0F5S;W)O;&%T;&%N`%5N
M:6-O9&4@*%541BTX*0!%9WEE<_QL="!!<F%B($5M[7)SZ6=E:P!%9WEE<_QL
M="!+:7+A;'ESX6<`16=Y97/\;'0@P6QL86UO:P!%9WEE<_QL="#!;&QA;6]K
M+"!K:7-E8F(@:_QL<_4@<WII9V5T96L`96=Y<^EG`$ES;65R971L96X`27-M
M97)E=&QE;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!)<VUE<F5T;&5N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$$@;65G861O='0@:&5L
M>2!I<VUE<F5T;&5N+@!)<VUE<F5T;&5N(&9E;&AA<WINX6SS:2!NZ78@=F%G
M>2!J96QS>O,N`%3A=F]L[71S=6L@96P@:6YN96X@82!L:6YK970`3FEN8W,@
M96QN979E>G9E`$)I>G1O;G/A9VD@;VMO:V+S;"!A(&9E;&AA<WINX6SS:2!P
M<F]G<F%M;VL@;F5M(&AA<WINX6QH871JX6L@82!+:7;A9^%S+TWA<V]LX7,O
M0F5I;&QE<WITZ7,@;?-D<WIE<G0N($MA='1I;G1S;VX@87H@3TL@9V]M8G)A
M+"!H82!A(&UO>FEL;&$N;W)G('=E8F]L9&%L;VX@96P@:^UVX6YJ82!O;'9A
M<VYI(&$@=&5C:&YI:V%I(&QE[7+A<W0@;65L>2!M96=A9&IA+"!H;V=Y86X@
M;&5H970@97IT(&WI9VES(&5N9V5DZ6QY97IN:2X`02!S>NUN('9I<W-Z8>%L
M;.UTX7-A`$YE;2!TX6UO9V%T;W1T('1A<G1A;&]M=.UP=7,Z("5S`$YE;2!T
MX6UO9V%T;W1T(&5X=&5N>FGS`$WS9&]S[73A<P`E<R!A9&%T86EN86L@;?-D
M;W/M=.%S80!!(&9E;&AA<WINX6SS(&%D871A:6YA:R!M\V1O<^UTX7-A`"(E
M<R(@=N%L=&]ZX7-A:70@96QM96YT971T_&LN`$%Z('5P9W)A9&4@<')O9W)A
M;6]T('3V<O9L=/QK+@!&96QT]FQTZ7,`07H@]G-S>F5S(&%L:V%L;6%ZX7,@
M:V]N9FEG=7+A8VGS:N%T(&9E;'3V;'3V='3\:R!A('-Z97)V97)R92X`;&%T
M:6X@;F%G>6)E=/MK`&YA9WEB973[<R!R\VUA:2!S>N%M;VL`57)U9W5A>0!(
M87-Z;N%L:G5K(&$@:F5L96YL96=I=#H@)7,`2&%S>F[A;&IU;FL@4U-,+70`
M06MK;W(@:&%S>F[A;&IU:RP@:&$@87H@24U34"!S>F5R=F5R96X@;>%S(&$@
M8F5J96QE;G1K97KI<VD@;F5V_&YK+VIE;'-Z879U;FLN`$9E;&AA<WINX6SS
M:2!NZ78`)7,@9F5L:&%S>F[A;/,@;F5M(&IO9V]S=6QT("5S+7)E+@!&96QH
M87-Z;N%L\VL@861M:6YI<WIT<N%LX7-A`$9E;&AA<WINX6SS:2!B9>%L;.UT
MX7-O:P!"96IE;&5N=&ME>NES(&IO9V]S=6QT<^%G(&EGZ6YY;.ES90!%>F5N
M(&$@<F5N9'-Z97)E;B!N:6YC<R!E;F=E9.EL>65Z=F4@87H@^FH@9F5L:&%S
M>F[A;/-K(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%GX6YA:R!I9^EN>6SI
M<V4N`$%Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=/,@;F5M('1A;.%L:&%T\P!&
M96QH87-Z;N%L\VD@;NEV`$$H>BD@(B5S(B!F96QH87-Z;N%L\VD@;NEV(&WA
M<B!LZ71E>FEK+@!&96QH87-Z;N%L\VD@;NEV.@!&96QH87-Z;N%L\VD@;NEV
M.B``02!R96YD<WIE<B!F96QH87-Z;N%L\VDZ`-QZ8F5G:7-Z=.%N`$$@5D93
M(&%L:_9N>79TX7(@;F5M(&SI=&5Z:6LN`%-Z86)A9'/A9R!A;&%T=&D@875T
M;VUA=&EK=7,@96UA:6PM=N%L87-Z`$$@:_9V971K97KU(&AE;'EE:V5T('1A
M;.%L='5K.B``R7)VZ6YY97-SZ6<`07H@Z7)TZ6ME:V5T('!E<F-B96X@861J
M=6L@;65G+"!M;W-T86YT\VP@<WKA;>UT=F$N`$$@Z7)TZ6L@;F%G>6]B8BP@
M;6EN="!A(&QE9VYA9WEO8F(@;65G96YG961E='0@:&]S<WKZ<^%G.B`E<RX`
MR7)TZ6ME:P!6X6QA<WIT:&%T\R#I<G3I:V5K`%9A;G5A='4`=N%L=&]Z\P!6
M96YE>G5E;&$`02!H:71E;&5S[73I<R!N96T@<VEK97+\;'0@+2!L96AE="P@
M:&]G>2!A(&QE=F5L970@=F%L86MI(&UE9W;A;'1O>G1A='1A+@!697)I<VEG
M;B!C[6UTX7(`5F5R>FGS`%9E<GII\VOV=F5TZ7,`1OQG9RX@96QH96QY97KI
M<P!&_&=G]6QE9V5S(&)E;'/U(&UA<F?S`&;\9V?U;&5G97,Z`&YA9WEO;B!M
M86=A<P!6:65T;F%M`'9I971N86UI("A625-#24DI`"(E<R(@;65G=&5K:6YT
MZ7-E`"5S(&UE9W1E:VEN=.ES90#::B!B96IE9WEZZ7,@<O9G>NUTZ7-E`$O\
M;'/U('=E8F]L9&%L(&UE9VIE;&5N[73I<V4`2F5L96[M='/\:R!M96<L(&UI
M;G0@)7,`07H@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@;65G:F5L96[M=.ES
M.@!"<FET(%9I<F=I;BUS>FEG971E:P!!;65R:6MA:2!6:7)G:6XM<WII9V5T
M96L`3.%T\W3A=F]L<^%G`$SA=/-TX79O;'/A9SH@`%9O9&%F;VYE($ET86QY
M('-Z;VQGX6QT873A<R!33510+6X@:V5R97-Z=/QL`$9)1UE%3$U%6E1%5,E3
M`$9)1UE%3$U%6E1%5,E3(2!+R5I:14P@5,%63TS-5%-!($5,($$@4T-225!4
M150@)7,M4M5,+@!724X@<WIO;&?A;'1A=.%S($A45%`M;B#A=`!786QL:7,@
MZ7,@1G5T=6YA`$9I9WEE;&UE>G1E=.ES`%-Z90!)9/5JX7+A<R!E;/5R96IE
M;'KI<P!!>B!I9/5JX7+A<VD@861A=&]K(&9O<G+A<V$`5V5B`%=E8FAE;'EE
M:P!796(@8^UM`&AE=&5N=&4`W&1V]GKV;&K\:P#<9';V>O9L:OQK.B`E<P#<
M9';V>O9L:OQK+"`E<P!N>75G870M975R\W!A:2`H25-/+3@X-3DM,2D`;GEU
M9V%T+65U<O-P86D@*$E33RTX.#4Y+3$U*0!.>75G870M4WIA:&%R80!-:6QY
M96X@86QK86QM87KA<W0@;75T87-S;VX@)7,@82!B96IE;&5N=&ME>NES('5T
MX6X_`$UI(&%Z(&5L=N%L87-Z=/,@:V%R86MT97(_`$UI(&%Z(&EDZ7IE=&MA
M<F%K=&5R/P!7:&5R96ES($%U<WIT<N%L:6$@=.ER:^EP`$UE;'EI:R!C:6ML
M=7,`365L>6EK(&UO9'5L;VMA="!A:W1I=N%L:G5K(&$@4FEC:"!497AT(&5D
M:71O<F)A;C\`4WKI;&5S<^EG`%-ZZ6QE<W/I9R!#4U,@96=Y<^EG8F5N`$$@
M)7,@;65N_"!S>NEL97-SZ6=E(&$@8F%L(&]L9&%L;VX@*&$@:_9V971K97KU
M(&)E:F5L96YT:V5ZZ7-T(&OV=F5T]65N(&QE<WH@Z7)VZ6YY97,I`$$@=.%B
M;.%Z870@<WKI;&5S<^EG90!!('-ZZ6QE<W/I9R!MZ7)TZ6ME9WESZ6=E`%-Z
MZ6QE<W/I9SH`5VEK:0!3>NEL`%-ZZ6P@82!R96=G96QI(/-RX6MB86X`4WKI
M;'-E8F5S<^EG(&-S;VWS8F%N`%-ZZ6PZ`%-ZZ6PZ(`!"]FQC<V5S<^EG`$OM
M=N%N<^%G;&ES=&$`375N:V$`375N:V%H96QY:2!C[6TZ('5T8V$`375N:V%H
M96QY:2!C[6TZ(';A<F]S`$UU;FMA:&5L>6D@8^UM.B!O<G-ZX6<`375N:V%H
M96QY:2!T96QE9F]N`$UU;FMA:&5L>6D@8^UM.B!I<N%N>>UT\W-ZX6T`375N
M:V%H96QY:2!C[6TZ(.%L;&%M+W1A<G1O;>%N>0!-=6YK86AE;'EI(&/M;3H@
M=71C80!!("5D+B!S;W)B86X@;F5M(&UE9V9E;&5L]2!A(&UE>O5K('-ZX6UA
M+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"X`3F5M(&UE9V9E;&5L]2!A(&UE>O5K
M('-ZX6UA+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"X`2&EBX7,@;V9F<V5T("@E
M9"D@82!61E,@9N%J;"!O;'9A<^%S86MO<BX`3&EN=7@@9F]R<N%S:_-D(&ME
M<F5S>G)E9F5R96YC:6$`6#4P.78S(&%L87!V973U(&MO<FSA=&]ZX7-O:P!8
M-3`Y=C,@:VET97)J97-Z=&5T="!K=6QC<VAA<WINX6QA=`!8-3`Y=C,@='5L
M86ID;VYO<R!A;'1E<FYA=.UV(&UE9VYE=F5ZZ7-E`%@U,#EV,R!T=6QA:F1O
M;F]S(&MU;&-S87IO;F]S[73S`%@U,#EV,R!K:71E<FIE<WITZ7-E:P!960!9
M65E9`%EA:&]O(2!TZ7)KZ7``Z79E;G1E`$IE;65N`$EG96X`26=E;BP@8F5L
M96=Y97IE;2X`36]S="!(5$U,(%1%6%0@;?-D8F%N('9A;BX@2&%S>F[A;&IA
M(&$@6SP^72!G;VUB;W0L(&AA('9I<W-Z82!A:V%R(';A;'1A;FD@82!S>F]K
MX7-O<R!G<F%F:6MU<R`H5UE325=91RD@;65G:F5L96[M=.ES<F4N`$YE;2!H
M;WIH870@;.ET<F4@)60@8FQO:VMNX6P@=/9B8F5T+@!.96T@:&]Z:&%T(&SI
M=')E('3V8F(L(&UI;G0@)60@<&%R=&YE<G0@82`B)7,B(&/M;6IE9WEZZ6MB
M96XN`$%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73A<V$@;F5M('3V<G3I;G0@
M;65G+@!!('1E;&IE<R!NZ79B96X@;F5M('-Z97)E<&5L:&5T(&$@)UPG(&MA
M<F%K=&5R+@!.96T@861O='0@;65G(.ER=NEN>65S(&5M86EL(&/M;65T+@!.
M96T@861T82!M96<@82!M96=F96QE;'1E=.ES="!A>B!I;7!O<G3A;'0@9N%J
M;"#I<R!A*'HI("5S(&UE>O5I(&OV>O9T="X`16YN96L@82!S>F5MZ6QY;F5K
M(&%Z(&%D=&%I="!N96T@:F]G;W-U;'0@;65G=&5K:6YT96YI+@!%>G0@87H@
M;V)J96MT=6UO="!N96T@:F]G;W-U;'0@;65G=&5K:6YT96YI+@#6;FYE:R!N
M:6YC<R!J;V=O<W5L='/A9V$@=/9R]FQN:2!E>G0@87H@8^UM:F5G>7KI:V5T
M+@!3:6ME<F5S96X@:VEJ96QE;G1K97IE='0N`$5G>2!M;V)I;'1E;&5F;VYS
M>N%M;W0@:V5L;"!M96=A9&YI82P@8W-A:R!A('-ZX6UJ96=Y96ME="P@97-E
M=&QE9R!E9WD@)RLG(&MA<F%K=&5R<F5L(&ME>F1V92P@:&$@;F5M>F5T:_9Z
M:2!TX7)C<^%ZX7-I(&WS9&]T(&OM=N%N(&AA<WINX6QN:2X`16QF;V=A9&AA
M=/,@Z7)TZ6ME="!K96QL(&UE9V%D;FEA+@!!($1A=&%4<F5E(&%L<F5N9'-Z
M97)T(&)E(&ME;&P@X6QL[71A;FD@82!B96IE;&5N=&ME>NES:2!J;V=O<W5L
M='/A9V]K(&EGZ6YY;.ESZ6AE>BX`02!61E,@86QR96YD<WIE<B!N:6YC<R!B
M9>%L;.UT=F$N`$5L]6)B(&QE(&ME;&P@[7)N:6$L(&AO9WD@;6EL>65N('!R
M;V)LZ6WA="!T87!A<WIT86QT+"!M:65L]71T(&5L:_QL9&D@82!H:6)A:F5L
M96YTZ7-T+@!-96<@:V5L;"!A9&YI(&5G>2!54DPM="P@86AO=F$@97H@82!L
M:6YK(&UU=&%T`$5L]7-Z]G(@8^EL:^EN="!K:2!K96QL(';A;&%S>G1A;FEA
M(&5G>2!C[6UJ96=Y>NEK970N`$5L]7-Z]G(@8^EL:^EN="!K:2!K96QL(';A
M;&%S>G1A;FEA(&5G>2!L:7-TX70N`$MI(&ME;&P@=N%L87-Z=&%N:2!E9WD@
M=/9R;&5N9/4@<WIE<G9E<G0N`$5L]6)B(&MI(&ME;&P@=N%L87-Z=&%N:6$@
M;&5G86SA8F(@96=Y(&QE=F5L97KU<&%R=&YE<G0N`$5L]6)B(&MI(&ME;&P@
M=N%L87-Z=&%N:6$@;&5G86SA8F(@96=Y(&%D871O="X`365G(&ME;&P@861N
M:6$L(&AO9WD@;65L>6EK(&9E;&AA<WINX6SS(&%D871A:70@:^UVX6YJ82!T
M]G+V;&YI+@!-96<@:V5L;"!A9&YI82!A>B!E;'3A=F]L[71A;F3S(&9E;&AA
M<WINX6SS:2!N979E="X`365G(&ME;&P@861N:6$@82!H;WIZX6%D86YD\R!F
M96QH87-Z;N%L\R!N97;I="X`365G(&ME;&P@861N:6$L(&AO9WD@;65L>6EK
M(&9E;&AA<WINX6SS(&%D871A:70@:^UVX6YJ82#A=.UR;FDN`$UE9R!K96QL
M(&%D;FEA(&5G>2!P87)A;F-S;W0N`$UE9R!K96QL(&%D;FEA(&%Z(/IJ(&MA
M=&5G\W)I82!N97;I="X`3VQA<WIO<G-ZX6=I('1E;&5F;VYS>N%M;W0@:V5L
M;"!M96=A9&YI80!%('-Z96WI;'D@861A=&%I="!C<V%K(&UE9W1E:VEN=&5N
M:2!V86X@:F]G;W-U;'1SX6=A+@!!>B#6;B`E<R!K87!C<V]L871A(&ED]73Z
M;&SI<.ES(&UI871T(&UE9W-Z86MA9'0N($OI<F5M(&IE;&5N=&ME>GIE;B!B
M92#Z:G)A+@!!>B#6;B!E;6%I;"!C[6UE`$%Z(-9N(&9E;&%D\VD@*$9R;VTZ
M*2!C[6UE.@!3>F5MZ6QY97,@:6YF;W)MX6-I\P!!>B#6;B`E<R!K87!C<V]L
M873A;F%K(&ME>F1E=&4@\W1A(&UE9W;A;'1O>F]T="!A>B!I;G1E<FYE="!C
M[6UE+B!":7IT;VYSX6?A;F%K(.ER9&5KZ6)E;B!I<VWI="!B92!K96QL(&IE
M;&5N=&ME>FYI92X`07H@UFX@;F5V90!!>B#6;B!F96QH87-Z;N%L\V%Z;VYO
M<^UT\R!A;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U=ND@87H@^FH@9F5L
M:&%S>F[A;/-K(&SI=')E:&]ZX7/A="X@2&$@82!(;W)D92!R96YD<WIE<G)E
M;"!K[7;A;FIA(&ME>F5L;FD@82!F96QH87-Z;N%L\VD@861A=&]K870L(&%K
M:V]R(&WA<VEK(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z97)R92!V
M86X@<WK\:W/I9V4N`$%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N
M9'-Z97)E(&YE;2!T97-Z:2!L96AE=/5VZ2!A(&9E;&AA<WINX6SS:R!L:7-T
MX7KA<^%T+"!V86=Y('9A;&%M:2!O:V+S;"!L971I;'1O='3A:R!E>G0@82!L
M96AE=/5SZ6=E="X`07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;65G=N%L=&]Z
M;W1T(&%Z(-9N("5S(&UU;FMA:V%P8W-O;&%TX6YA:R!K97ID971E(/-T82X@
M0FEZ=&]N<^%G82#I<F1E:^EB96X@:7-MZ70@8F4@:V5L;"!J96QE;G1K97IN
M:64N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T:F$@97IT
M(&$@;&5H973U<^EG970N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!T
MX6UO9V%T:F$@97IT(&$@;GEO;71A=.%S:2!O<&-I\W0N(%!R\V+A;&IO;B!A
M($-T<FPM4"`H=F%G>2!#;VUM86YD+5`I(&QE;GEO;>%SX79A;"!N>6]M=&%T
M;FDN`$$@:F5L96YL96<@Z7)VZ6YY97,@:63U>O-N83H`07H@UFX@86QA<.ER
M=&5L;65ZZ7,@<WIE<FEN=&D@8^UM:F5G>7KI:V4@;F5M(&+V;F?I<WIH973U
M+@!!>B#6;B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/-J82!M
M96=VX6QT;WIO='0N`$%Z(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z
M;VYO<^UT\VIA.@!!>B#6;B!T96QJ97,@;F5V93H`3&5JX7)T(&$@8F5J96QE
M;G1K97KI<VD@:F]G;W-U;'1SX6=A+@!!>B#6;B`E<RUR92!H87-Z;N%L="#Z
M:B!J96QS>F%V83H@)7,`07H@UFX@^FH@8F7A;&SM=.%S86ET(.ER=NEN>65S
M[71E='3\:R!A(&UO<W1A;FD@8F5J96QE;G1K97KI<R!I9&5JZ7)E+@!!>B#6
M;B#Z:B!B9>%L;.UTX7-A:70@96QM96YT971T_&LN`$%Z(-9N(&IE;'-Z87;A
M="#A=.%L;.UT;W1T=6L`07H@UFX@:F5L<WIA=N%T(.%TX6QL[71O='1U:RP@
M;NEZ>F4@;65G(&$@;&5V96QE:70L(&UA:F0@:F5L96YT:V5Z>F5N(&)E(&%Z
M(/IJ(&IE;'-Z\W9A;"X`07H@UFX@:F5L<WIA=N%N86L@;&5JX7)T(&%Z(.ER
M=NEN>65S<^EG:2!I9&5J92X`07H@UFX@X6QT86P@:&%S>F[A;'0@=.%V;VQI
M('-Z97)V97)E:SH`2G5G;W-Z;.%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E
M`%M.92!M=71A<W-U:R!A(&)E:63I>F5T="!S>O9V96=E=%T`6TAI8F%J96QE
M;G3I<UT`6TUU=&%S<W5K(&$@8F5I9.EZ971T('-Z]G9E9V5T("T`6TUU=&%S
M<W5K(&$@8F5I9.EZ971T('-Z]G9E9V5T("T@)7,@<V]R70!;)7,O)7,@<V]R
M70!;;FEN8W,@861A=%T`7T%D;6EN:7-Z='+A8VGS`%]"]FYGZ7-ZZ7,`7U!A
M<F%N8W-S;W(`4&%R=&YE<F5K`%3V<FSI<P!3;W)T]G)LZ7,`7T-S;W!O<G1O
M:P!395]G[71SZ6<`02!KZ7`@='5L86ID;VYSX6=A:2XN+@!);7!O<G0O7T5X
M<&]R=`!,:7-TX6L`0F5J96QE;G1K97KI<P!?2VEJ96QE;G1K97KI<P!!(&QI
M;FL@;?-D;W/M=.%S82XN+@!386KA="!C[6UJ96=Y>NEK96EM`-IJ(&QE=F5L
M97KU<&%R=&YE<@!?3W!C:?-K`%]*;V=O<W5L='/A9V]K`$$@;&EN:R!T]G)L
MZ7-E+BXN`%3V<O9L:OQK(&$@;&ES=.%R\VP`2V5R95]SZ7,`7T)EX6QL[73A
M<V]K`%3A8FSA>F%T('1U;&%J9&]N<^%G;VL`7T9E;&AA<WINX6SS:P!C[6UJ
M96=Y>NEK`&$@8^UM>F5T="!I<VUE<F5T;&5N`&YA<'3A<@!N>75G;V1T`&$@
M:VEM96YE=&D@X6QL;VWA;GD@;F5M(&AO>FAA=/,@;.ET<F4`82!B96UE;O4@
MX6QL;VWA;GD@;F5M(&YY:71H873S(&UE9P!K871T:6YT<V]N(&ED90!P87)A
M;F-S<V]R:2!H:6)A`&MO;F9I9W5RX6-I\W,@:&EB80!H:>%N>7II:R!E9WD@
M9F]N=&]S(')E;F1S>F5RX6QL;VWA;GD`861A=&9O<FWA='5M(&AI8F$`;?-D
M;W/M=.%S`&%Z(&%D870@;F5M('1A;.%L:&%T\P!C<_9K:V5N`&;A:FP`)7,@
M*"5S*2!I<N%N>6+S;"P@)7,@)7,@<V5B97-SZ6=G96P`<WKI;&SV:^ES96L`
M;3H`82!GZ7`@;F5V92!N96T@:7-M97)T`&%Z;VYN86QI`&EN<'5T+V]U='!U
M="!H:6)A`&)E;'/U('!R;V=R86UH:6)A`'-O<ET`07H@;6MS:6]F<R!P<F]G
M<F%M("5D(&AI8F%K\V1D86P@;&7A;&QT(&%Z($E33R#A;&QO;>%N>2!KZ7-Z
M[73I<V4@:_9Z8F5N+@!NZ78`9F]R;6%T=.%LX7,@;NEL:_QL`&5G>2!S96T`
M02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE9W9A;/-S[71V
M82X`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE9W9A;/-S
M[71V82X`:F5G>7IE='3V;6(`<WKA>F%LZ6L`;FEN8W,@;65G9F5L96SU(&IO
M9V]S=6QT<^%G80!P:7AE;`!A9&%TX71V:71E;&D@*'!R;W1O:V]L;"D@:&EB
M80!E;65L:V5D:6L`82!S>F]L9^%L=&%TX7,@;F5M(.%L;"!R96YD96QK97KI
M<W)E`&[I>GK\:R!M96<@82!K_&SV;F)SZ6=E:V5T`'-M<S)E;6%I;"!S>F]L
M9^%L=&%TX7,@2%144"UN(.%T`';A;'1O>F%T;&%N`')E;F1S>F5R:&EB80!F
M96QA9&%T;&ES=&$`X71M96YE=&D@:&EB80!E9WD@8^UM;&ES=.%B80!E9WD@
M;>%S:6L@8^UM:F5G>7KI:V)E`&UE9V5R]7/M=.ES:^EN="!KZ71S>F5R(.UR
M:F$@8F4@82!J96QS>O-T`&[I=B!NZ6QK_&P`82!F96QH87-Z;N%L\R#A;'1A
M;"!VX6QA<WIT:&%T\P!V0V%R9`!S>CH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T=7)B82]L;V-A;&4O:F%?2E`O````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`Q-S<V-0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]J85]*4"],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-34`,#(Q-34R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O
M;&]C86QE+VIA7TI0+TQ#7TU%4U-!1T53+W1U<F)A+FUO````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#(P-38P-P`Q,#0Q-S,V,C<U-0`P,C,R,S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````"[`P``'```
M`/0=``#]!```S#L```````#`3P``#@```,%/```/````T$\```@```#@3P``
M#````.E/```D````]D\``"4````;4```"P```$%0```.````35````4```!<
M4```*````&)0```*````BU```!4```"64```"0```*Q0```2````ME```!T`
M``#)4```#@```.=0```*````]E````T````!40``#0````]1```,````'5$`
M``T````J40``#````#A1```.````15$```X```!440``"````&-1```K````
M;%$``"X```"840``&@```,=1```R````XE$``#@````54@``5````$Y2``!1
M````HU(``%H```#U4@``5P```%!3```T````J%,```4```#=4P``$0```.-3
M```1````]5,``"4````'5```(````"U4```0````3E0```\```!?5```#P``
M`&]4```4````?U0```D```"45```#0```)Y4```2````K%0```\```"_5```
M"@```,]4```/````VE0```@```#J5```)````/-4```&````&%4``!0````?
M50``%@```#15```(````2U4``!D```!450``!P```&Y5```4````=E4``!(`
M``"+50``#@```)Y5```#````K54```\```"Q50``!0```,%5```#````QU4`
M`!<```#+50``"@```.-5```/````[E4``",```#^50``#@```")6```.````
M,58``!0```!`5@``%P```%56```7````;58``!<```"%5@``$P```)U6```?
M````L58```\```#15@``"P```.%6```5````[58```<````#5P``!0````M7
M```1````$5<```P````C5P``*````#!7```Z````65<``#L```"45P``"0``
M`-!7```Y````VE<``"<````46```+````#Q8```J````:5@``"4```"46```
M"@```+I8```&````Q5@``"\```#,6```-P```/Q8```N````-%D``%4```!C
M60``+0```+E9```M````YUD``"T````56@``0````$-:```C````A%H``",`
M``"H6@``+0```,Q:```S````^EH``!4````N6P``&0```$1;```I````7EL`
M`"0```"(6P``$0```*U;```*````OUL``!````#*6P``%@```-M;```6````
M\EL```P````)7```$0```!9<```4````*%P```@````]7```"@```$9<```$
M````45P```D```!67```!@```&!<```1````9UP```<```!Y7```#0```(%<
M```1````CUP```,```"A7````P```*5<```7````J5P```@```#!7```(```
M`,I<```&````ZUP``!4```#R7```&`````A=```B````(5T``!T```!$70``
M(0```&)=``!4````A%T``"D```#970``!P````->```5````"UX```H````A
M7@``#P```"Q>```-````/%X```\```!*7@``#0```%I>```)````:%X```8`
M``!R7@``$P```'E>```4````C5X```8```"B7@``5````*E>```1````_EX`
M`!$````07P``%@```")?```<````.5\``"$```!67P``$@```'A?```*````
MBU\``!$```"67P``#````*A?```%````M5\```P```"[7P``$````,A?```%
M````V5\```X```#?7P``#0```.Y?```&````_%\``!8````#8```*@```!I@
M```'````16````T```!-8```!P```%M@```+````8V````<```!O8```#P``
M`'=@```9````AV````P```"A8```$````*Y@```2````OV```!4```#28```
M$@```.A@```K````^V```#L````G80``(````&-A```:````A&$``#8```"?
M80``!````-9A```.````VV$``!X```#J80``&P````EB```A````)6(``!X`
M``!'8@``&0```&9B```>````@&(``!L```"?8@``)@```+MB```;````XF(`
M`!X```#^8@``'````!UC```F````.F,``#,```!A8P``)@```)5C```K````
MO&,``#@```#H8P``+P```"%D```2````460``"D```!D9```$@```(YD```C
M````H60``"@```#%9```*0```.YD```?````&&4``"`````X90``)0```%EE
M```A````?V4``!P```"A90``)@```+YE``!!````Y64```<````G9@``$```
M`"]F```2````0&8```<```!39@``$P```%MF```2````;V8```P```""9@``
M*````(]F```#````N&8```T```"\9@```@```,IF```%````S68``!````#3
M9@``#0```.1F```.````\F8```@````!9P``#P````IG```/````&F<```T`
M```J9P``$````#AG```:````26<```8```!D9P``$P```&MG```,````?V<`
M`!$```",9P``%P```)YG```+````MF<```T```#"9P``(@```-!G```6````
M\V<```H````*:```&````!5H```9````+F@``!8```!(:```#P```%]H```-
M````;V@```H```!]:```"@```(AH```4````DV@``"\```"H:```"P```-AH
M```7````Y&@``!<```#\:```"0```!1I```6````'FD```\````U:0``#0``
M`$5I```F````4VD``"@```!Z:0``0P```*-I```+````YVD``"\```#S:0``
M#@```"-J```&````,FH```0````Y:@``"@```#YJ```*````26H```\```!4
M:@``$````&1J```7````=6H``!$```"-:@``$0```)]J```7````L6H```4`
M``#):@``#0```,]J```;````W6H```X```#Y:@``#0````AK```X````%FL`
M`"````!/:P``#@```'!K```5````?VL```4```"5:P``&0```)MK```0````
MM6L```\```#&:P``$````-9K```/````YVL```L```#W:P``#P````-L```,
M````$VP```\````@;```!P```#!L```&````.&P```\````_;```"````$]L
M```&````6&P``!,```!?;```(@```'-L```M````EFP```@```#$;```$P``
M`,UL```>````X6P``"4`````;0``&@```"9M```5````06T``!X```!7;0``
M(0```'9M```@````F&T``!D```"Y;0``%P```--M```E````ZVT``"4````1
M;@``%P```#=N```B````3VX```@```!R;@``$P```'MN```4````CVX```P`
M``"D;@``"0```+%N```.````NVX```L```#*;@``&P```-9N```'````\FX`
M``0```#Z;@``"@```/]N```%````"F\```8````0;P```@```!=O```&````
M&F\```P````A;P``$````"YO```)````/V\``!D```!);P``#@```&-O```*
M````<F\``!,```!];P``!0```)%O```4````EV\``!T```"L;P``!@```,IO
M```1````T6\```D```#C;P``'@```.UO```.````#'````8````;<```!@``
M`")P```$````*7````0````N<```#````#-P```)````0'````P```!*<```
M"@```%=P```0````8G```!,```!S<```!0```(=P```/````C7```"D```"=
M<```)````,=P```F````['```"`````3<0``(````#1Q```F````57$``"D`
M``!\<0``%@```*9Q```*````O7$```\```#(<0``$````-AQ``!`````Z7$`
M`'`````J<@``#@```)MR```)````JG(```H```"T<@``!@```+]R```<````
MQG(```\```#C<@``&P```/-R```2````#W,``!`````B<P``'````#-S```C
M````4',```\```!T<P``$````(1S```+````E7,``!0```"A<P``#````+9S
M```,````PW,```\```#0<P``%0```.!S```I````]G,``"H````@=```)@``
M`$MT```G````<G0``"D```":=```*@```,1T```9````[W0``!$````)=0``
M$@```!MU```3````+G4``!0```!"=0``%@```%=U```7````;G4``!````"&
M=0``$0```)=U```3````J74``!(```"]=0``-0```-!U```4````!G8```H`
M```;=@``%````"9V```4````.W8``!<```!0=@``'````&AV```-````A78`
M``T```"3=@``%@```*%V```,````N'8``!````#%=@``&@```-9V```7````
M\78``!4````)=P``!@```!]W```&````)G<```<````M=P``!````#5W```$
M````.G<```<````_=P``#@```$=W```,````5G<```P```!C=P``#0```'!W
M```H````?G<```P```"G=P``#P```+1W```*````Q'<```@```#/=P``*P``
M`-AW``!,````!'@```@```!1>```#0```%IX```.````:'@``!8```!W>```
M$0```(YX```&````H'@```X```"G>```$````+9X```+````QW@``!H```#3
M>```#P```.YX```(````_G@```8````'>0``!P````YY```+````%GD``$<`
M```B>0``#0```&IY```3````>'D``!,```",>0``$P```*!Y```"````M'D`
M`"4```"W>0``!````-UY``!H````XGD```4```!+>@``"````%%Z```/````
M6GH``!<```!J>@```P```()Z```'````AGH```H```".>@``"P```)EZ```'
M````I7H``%$```"M>@``!@```/]Z```)````!GL```L````0>P``5P```!Q[
M```"````='L```L```!W>P``#````(-[```-````D'L``!8```">>P``!P``
M`+5[```7````O7L```0```#5>P``"0```-I[```)````Y'L```H```#N>P``
M!P```/E[```)`````7P```D````+?```"@```!5\```'````('P``!4````H
M?```"@```#Y\```2````27P```0```!<?```"P```&%\```:````;7P```<`
M``"(?```!0```)!\```,````EGP```L```"C?```%P```*]\```$````QWP`
M``@```#,?```&````-5\```7````[GP``#@````&?0``"@```#]]```L````
M2GT``#,```!W?0``,P```*M]```X````WWT``!$````8?@``#P```"I^```8
M````.GX``!0```!3?@``$@```&A^```4````>WX``"T```"0?@``+0```+Y^
M```Q````['X``"X````>?P``+P```$U_```L````?7\``&(```"J?P``$P``
M``V````A````(8```!@```!#@```&@```%R````)````=X```$4```"!@```
M00```,>````$````"8$```D````.@0``"@```!B!```%````(X$```@````I
M@0``&````#*!```X````2X$```(```"$@0``!@```(>!```.````CH$``!``
M``"=@0``!P```*Z!```&````MH$``"D```"]@0``'P```.>!``!<````!X(`
M`!0```!D@@``/@```'F"```'````N((```X```#`@@``#````,^"```,````
MW((``!,```#I@@``"@```/V"```=````"(,``!$````F@P``#0```#B#```1
M````1H,``"0```!8@P``%0```'V#```2````DX,```X```"F@P``&0```+6#
M```(````SX,```D```#8@P``!P```.*#```(````ZH,``!(```#S@P``+```
M``:$```:````,X0```D```!.A```"@```%B$```5````8X0```4```!YA```
M%````'^$```0````E(0```<```"EA```'@```*V$```H````S(0```H```#U
MA```$0````"%```1````$H4``!H````DA0``%````#^%```%````5(4``!$`
M``!:A0``!@```&R%```@````<X4``"D```"4A0``00```+Z%```H`````(8`
M`"D````IA@``!0```%.&```N````688``#0```"(A@``!P```+V&```A````
MQ88```X```#GA@``%````/:&```+````"X<```<````7AP``$P```!^'```*
M````,X<``!0````^AP``,@```%.'```%````AH<``!4```",AP``#````**'
M```7````KX<```4```#'AP``!````,V'```4````TH<``#(```#GAP``10``
M`!J(```7````8(@``!X```!XB```%````)>(```.````K(@``"H```"[B```
M!@```.:(```,````[8@```T```#ZB```%0````B)```+````'HD```L````J
MB0``#P```#:)```R````1HD``!L```!YB0``!0```)6)```1````FXD```<`
M``"MB0``$0```+6)```4````QXD``!@```#<B0``!````/6)```.````^HD`
M``X````)B@``!0```!B*```#````'HH``!X````BB@``&````$&*```9````
M6HH``"4```!TB@``"0```)J*```#````I(H```(```"HB@``!````*N*```'
M````L(H```P```"XB@``%P```,6*```&````W8H```T```#DB@``$0```/**
M```,````!(L```T````1BP``%0```!^+```2````-8L```\```!(BP``%```
M`%B+```G````;8L``"4```"5BP``:0```+N+```:````)8P``!<```!`C```
M&0```%B,```:````<HP``"4```"-C```*````+.,```G````W(P``!H````$
MC0``%P```!^-```;````-XT``#0```!3C0``)0```(B-```9````KHT``!\`
M``#(C0``$P```.B-```(````_(T```D````%C@``#0````^.```_````'8X`
M`#<```!=C@``5P```)6.```0````[8X```T```#^C@``+0````R/```$````
M.H\```@````_CP``#0```$B/```*````5H\``"4```!ACP``'P```(>/```=
M````IX\```8```#%CP``.0```,R/```'````!I````D````.D```$P```!B0
M```$````+)```!`````QD```#@```$*0```.````49````<```!@D```!P``
M`&B0```3````<)```!<```"$D```.0```)R0```1````UI````8```#HD```
M#@```.^0```-````_I````L````,D0```@```!B1```&````&Y$```D````B
MD0``!P```"R1```;````-)$``!4```!0D0``!P```&:1```+````;I$```<`
M``!ZD0``"````(*1```4````BY$```4```"@D0``$````*:1```0````MY$`
M``4```#(D0``$````,Z1```)````WY$```H```#ID0```@```/21```?````
M]Y$``",````7D@``,0```#N2```G````;9(``"@```"5D@``9````+Z2``!5
M````(Y,``"D```!YDP``2@```*.3``!;````[I,``"@```!*E```.````'.4
M```;````K)0``*D!``#(E```(P```'*6``!(````EI8``$$```#?E@``6P``
M`"&7``!)````?9<``"$```#'EP``'P```.F7```S````"9@``"4````]F```
M)@```&.8```P````BI@``,P```"[F```:0```(B9```]````\ID``&4````P
MF@``30```)::``!>````Y)H``"<```!#FP``+````&N;```H````F)L``"X`
M``#!FP``*0```/";```P````&IP``%H```!+G```2````*:<``!*````[YP`
M`"H````ZG0``(@```&6=```R````B)T``"\```"[G0``+````.N=```M````
M&)X``!<```!&G@``)0```%Z>```R````A)X``"D```"WG@``/@```.&>``!2
M````()\``"(```!SGP``)0```):?``!%````O)\``"$````"H```-@```"2@
M```P````6Z```"4```",H```'````+*@```Q````SZ````T````!H0``!0``
M``^A``!9````%:$```(```!OH0```P```'*A```N````=J$``"\```"EH0``
M%P```-6A```@````[:$``!L````.H@``&````"JB```D````0Z(``!\```!H
MH@``&@```(BB```@````HZ(``!H```#$H@``,@```-^B```O````$J,``"4`
M``!"HP``)````&BC```B````C:,``"4```"PHP``)@```-:C```)````_:,`
M``P````'I```%P```!2D```'````+*0```<````TI```!P```#RD```5````
M1*0```8```!:I```"0```&&D```+````:Z0``!,```!WI```$P```(ND```/
M````GZ0``#(```"OI```$P```.*D```,````]J0``!$````#I0``"````!6E
M```)````'J4```H````HI0``%````#.E```(````2*4```@```!1I0``/P``
M`%JE```2````FJ4```<```"MI0``!P```+6E```,````O:4``!L```#*I0``
M!P```.:E```"````[J4```L```#QI0``!@```/VE```'````!*8```T````,
MI@``"P```!JF```O````)J8``"````!6I@``'````'>F```Q````E*8```4`
M``#&I@``/P```,RF```2````#*<```P````?IP``"0```"RG```,````-J<`
M``H```!#IP``$````$ZG```3````7Z<``!@```!SIP``&0```(RG```?````
MIJ<``!T```#&IP``$0```.2G```"````]J<```0```#YIP``!@```/ZG```#
M````!:@```P````)J```10```!:H```:````7*@``#4```!WJ```*````*VH
M``!3````UJ@``#`````JJ0``+P```%NI```9````BZD``"````"EJ0``-0``
M`,:I``!%````_*D``#````!"J@``)@```'.J```>````FJH``"@```"YJ@``
M*0```.*J```I````#*L``"8````VJP``)0```%VK```H````@ZL``"@```"L
MJP``(@```-6K```N````^*L``#`````GK```$@```%BL```3````:ZP``!``
M``!_K```>0```)"L```)````"JT``',````4K0``?````(BM```7````!:X`
M`!8````=K@``#P```#2N```?````1*X``!0```!DK@``$````'FN```/````
MBJX```\```":K@``!P```*JN```'````LJX```L```"ZK@``!P```,:N```%
M````SJX``!0```#4K@``#@```.FN```'````^*X```@`````KP``#P````FO
M```(````&:\```P````BKP``#P```"^O```6````/Z\```<```!6KP``!@``
M`%ZO```4````9:\```8```!ZKP``#````(&O```(````CJ\```H```"7KP``
M!````**O```3````IZ\```<```"[KP``!@```,.O```B````RJ\```<```#M
MKP``8@$``/6O```*````6+$```\```!CL0``!P```'.Q```'````>[$``!P`
M``"#L0``'@```*"Q```)````O[$```L```#)L0``!0```-6Q```1````V[$`
M``\```#ML0``"P```/VQ```3````";(``!4````=L@``(P```#.R```,````
M5[(```4```!DL@``$0```&JR```+````?+(```L```"(L@``$0```)2R```*
M````IK(```H```"QL@``"@```+RR```'````Q[(``"@```#/L@``)@```/BR
M```<````'[,``"D````\LP``,0```&:S``!*````F+,``$0```#CLP``4```
M`"BT``!*````>;0``"P```#$M```!0```/&T```6````][0``!`````.M0``
M+P```!^U```K````3[4``!8```![M0``'@```)*U```2````L;4``!0```#$
MM0``"P```-FU```4````Y;4``!8```#ZM0``$@```!&V```(````)+8``!(`
M```MM@``"@```$"V```L````2[8```H```!XM@``$0```(.V```6````E;8`
M``P```"LM@``)@```+FV```$````X+8```X```#EM@``#@```/2V```$````
M`[<```,````(MP``"`````RW```$````%;<```0````:MP``#````!^W```.
M````++<``!`````[MP``*@```$RW```.````=[<```X```"&MP``%````)6W
M```6````JK<``!0```#!MP``%````-:W```2````Z[<``!H```#^MP``#@``
M`!FX```0````*+@``!8````YN```!````%"X```$````5;@``!@```!:N```
M#````'.X```B````@+@``"0```"CN```,0```,BX```$````^K@``"X```#_
MN```*@```"ZY```L````6;D``"P```"&N0``)@```+.Y```$````VKD```0`
M``#?N0``,0```.2Y```V````%KH``"X```!-N@``:@```'RZ```I````Y[H`
M`"D````1NP``*0```#N[```U````9;L``"4```";NP``)0```,&[```I````
MY[L``"\````1O```$@```$&\```6````5+P``"@```!KO```%P```)2\```6
M````K+P```0```##O```!@```,B\```@````S[P``!X```#PO```"`````^]
M```0````&+T``!4````IO0``!@```#^]```.````1KT```0```!5O0``#```
M`%J]```"````9[T```H```!JO0```@```'6]```(````>+T```@```"!O0``
M`P```(J]```#````CKT``!````"2O0``!@```*.]```E````JKT```H```#0
MO0``'````-N]```@````^+T``"(````9O@``)@```#R^```F````8[X``$@`
M``"*O@``,@```-.^```$````!K\```P````+OP``"````!B_```(````(;\`
M``H````JOP``"````#6_```*````/K\```@```!)OP``!````%*_```,````
M5[\```X```!DOP``!````'._```P````>+\``!````"IOP``#@```+J_```0
M````R;\```X```#:OP``(````.F_```0````"L````H````;P```$@```";`
M```2````.<````(```!,P```!@```$_````&````5L````0```!=P```$```
M`&+````*````<\````H```!^P```$````(G````D````FL````@```"_P```
M#@```,C````(````U\````8```#@P```!````.?````(````[,````H```#U
MP```#0````#!```0````#L$```H````?P0``#````"K!```(````-\$``"8`
M``!`P0``,P```&?!```A````F\$``"(```"]P0``)````.#!```&````!<(`
M``8````,P@``*P```!/"```I````/\(``"X```!IP@``+````)C"```@````
MQ<(``"<```#FP@``'@````[#```F````+<,``"8```!4PP``*0```'O#```@
M````I<,``"8```#&PP``,@```.W#```J````(,0``"P```!+Q```+````'C$
M```J````I<0``!\```#0Q```*@```/#$```5````&\4``"0````QQ0``)@``
M`%;%```F````?<4``!P```"DQ0``'P```,'%```J````X<4``!T````,Q@``
M(````"K&```F````2\8``$````!RQ@```@```+/&```(````ML8``!(```"_
MQ@``!````-+&```2````U\8``!0```#JQ@``"@```/_&```O````"L<```@`
M```ZQP``"````$/'```"````3,<```0```!/QP``#0```%3'```*````8L<`
M``H```!MQP``!````'C'```&````?<<```P```"$QP``#````)''```-````
MGL<``!0```"LQP``!````,''```*````QL<```X```#1QP``#@```.#'```0
M````[\<```@`````R```"`````G(```6````$L@``!T````IR```"````$?(
M```0````4,@``!(```!AR```$@```'3(```4````A\@```@```"<R```!```
M`*7(```$````JL@```X```"OR```)````+[(```$````X\@```H```#HR```
M"@```//(```&````_L@```H````%R0``#@```!#)```*````'\D``"X````J
MR0``(````%G)``!%````>LD``!$```#`R0``-P```-+)```4````"LH```H`
M```?R@``!````"K*```.````+\H```X````^R@``$````$W*```0````7LH`
M`!4```!OR@``#0```(7*```2````D\H``!4```"FR@``#@```+S*```/````
MR\H``"L```#;R@``$@````?+```4````&LL``"X````ORP``)````%[+```6
M````@\L``!D```":RP``!@```+3+```<````N\L```8```#8RP``!0```-_+
M```&````Y<L```4```#LRP``"@```/++```&````_<L```4````$S```"@``
M``K,```$````%<P```0````:S```"````!_,```$````*,P```P````MS```
M&````#K,```D````4\P``#````!XS```!@```*G,```=````L,P``"0```#.
MS```)````//,```=````&,T``!H````VS0``&@```%'-```C````;,T``"(`
M``"0S0``(0```+/-```?````U<T``"````#US0``*@```!;.```=````0<X`
M`"````!?S@``!````(#.```7````A<X``!<```"=S@``$@```+7.```*````
MR,X```P```#3S@``%````.#.```N````]<X```@````DSP``!````"W/```&
M````,L\```@````YSP``"@```$+/```"````3<\```(```!0SP``#````%//
M```*````8,\```0```!KSP``%0```'#/```0````AL\```(```"7SP``#@``
M`)K/```(````J<\```P```"RSP``'````+_/```(````W,\``!````#ESP``
M#````/;/```;`````]```!0````?T```!@```#30```$````.]````8```!`
MT```!@```$?0```*````3M````@```!9T```"````&+0```.````:]````X`
M``!ZT```#````(G0```%````EM````0```"<T```&@```*'0```B````O-``
M`!H```#?T```*P```/K0```K````)M$``#,```!2T0``,@```(;1```0````
MN=$```P```#*T0``$@```-?1```(````ZM$``$4```#ST0``60```#G2```.
M````D](```@```"BT@``"0```*O2```$````M=(``",```"ZT@``%P```-[2
M```D````]M(``!\````;TP``'````#O3```L````6-,``"@```"%TP``#```
M`*[3```*````N],``!(```#&TP``$````-G3```*````ZM,```@```#UTP``
M#````/[3```.````"]0``!@````:U```%@```#/4```8````2M0``!8```!C
MU```&@```'K4```8````E=0``!8```"NU```$````,74```.````UM0```X`
M``#EU```#@```/34```0`````]4```X````4U0``#@```"/5```,````,M4`
M`!`````_U0``$@```%#5```H````8]4``!````",U0``#@```)W5```4````
MK-4``!P```#!U0``'0```-[5```<````_-4``!@````9U@``#@```#+6```<
M````0=8```X```!>U@``&0```&W6```<````A]8``!@```"DU@``&0```+W6
M```&````U]8```0```#>U@``!````./6```$````Z-8```0```#MU@``!@``
M`/+6```(````^=8```@````"UP``!@````O7```&````$M<``",````9UP``
M"````#W7```&````1M<```0```!-UP``!@```%+7```H````6=<``$P```""
MUP``!````,_7```(````U-<``!(```#=UP``'@```/#7```4````#]@```H`
M```DV```$````"_8```4````0-@```@```!5V```)````%[8```*````@]@`
M``0```".V```"````)/8```*````G-@```\```"GV```/@```+?8```8````
M]M@``!8````/V0``%````";9```4````.]D```(```!0V0``+0```%/9```*
M````@=D``#````",V0``!````+W9```.````PMD``!P```#1V0``#@```.[9
M```$````_=D```8````"V@``#@````G:```(````&-H```0````AV@``0@``
M`";:```(````:=H```D```!RV@``"````'S:``!6````A=H```(```#<V@``
M"@```-_:```(````ZMH```8```#SV@``$0```/K:```$````#-L``!`````1
MVP``!````"+;```$````)]L```0````LVP``!````#';```$````-ML```0`
M```[VP``"````$#;```(````2=L```0```!2VP``&0```%?;```*````<=L`
M``P```!\VP``!````(G;```*````CML``!H```"9VP``#````+3;```$````
MP=L```@```#&VP``"@```,_;```4````VML```(```#OVP``#````/+;```5
M````_]L``!P````5W```)@```#+<```*````6=P``#(```!DW```*````)?<
M```H````P-P``"P```#IW```%@```!;=```2````+=T``!P```!`W0``(```
M`%W=```:````?MT``!H```"9W0``(P```+3=```C````V-T``"<```#\W0``
M)P```"3>```E````3-X``"@```!RW@``70```)O>```8````^=X``"H````2
MWP``'@```#W?```;````7-\```8```!XWP``.````'_?```\````N-\```0`
M``#UWP``"@```/K?```*````!>````0````0X```!````!7@```/````&N``
M`#0````JX````@```%_@```,````8N```!(```!OX```'````(+@```$````
MG^````0```"DX```,@```*G@```I````W.```$(````&X0``%````$GA``!)
M````7N$```H```"HX0``#0```+/A```,````P>$```0```#.X0``!````-/A
M```$````V.$``"````#=X0``%@```/[A```2````%>(``!(````HX@``&@``
M`#OB```,````5N(```H```!CX@``"@```&[B```7````>>(```D```"1X@``
M"0```)OB```$````I>(```H```"JX@``'````+7B```C````TN(``!````#V
MX@``"P````?C```,````$^,``!H````@XP``"````#OC```(````1.,``!8`
M``!-XP``"@```&3C```2````;^,``"0```""XP``"@```*?C```8````LN,`
M`!@```#+XP``$````.3C```(````]>,```0```#^XP``%0````/D```(````
M&>0``!H````BY```(0```#WD```^````7^0``"(```">Y```*````,'D```&
M````ZN0``#````#QY```,P```"+E```*````5N4``!P```!AY0``!````'[E
M```0````@^4```8```"4Y0``!````)OE```.````H.4```8```"OY0``$@``
M`+;E```E````R>4```@```#OY0``%P```/CE```(````$.8``!,````9Y@``
M`@```"WF```$````,.8``!,````UY@``-````$GF``!#````?N8```@```#"
MY@``&0```,OF```0````Y>8``!````#VY@``+`````?G```$````-.<```X`
M```YYP``"````$CG```.````4><```H```!@YP``#````&OG```0````>.<`
M`!8```")YP``+@```*#G```(````S^<``!````#8YP``!````.GG```0````
M[N<```X```#_YP``'@````[H```$````+>@```8````RZ```!@```#GH```$
M````0.@```0```!%Z```#P```$KH```-````6N@``!$```!HZ```&P```'KH
M```*````EN@```,```"AZ````@```*7H```$````J.@```D```"MZ```$```
M`+?H```7````R.@```0```#@Z```"````.7H```,````[N@```H```#[Z```
M&`````;I```B````'^D``!X```!"Z0``&````&'I```@````>ND``"T```";
MZ0``*P```,GI``!2````]>D``"0```!(Z@``'@```&WJ```G````C.H``"D`
M``"TZ@``(P```-[J```=`````NL``!,````@ZP``)````#3K```>````6>L`
M`"H```!XZP``*````*/K```<````S.L``!<```#IZP``%P````'L```6````
M&>P```@````P[```!````#GL```$````/NP``#(```!#[```(````';L``!7
M````E^P```P```#O[```#````/SL```\````">T```0```!&[0``"````$OM
M```,````5.T```P```!A[0``+@```&[M```>````G>T``"0```"\[0``!```
M`.'M```R````YNT```P````9[@``"````";N```4````+^X```8```!$[@``
M$@```$ON```&````7NX```X```!E[@``!@```'3N```$````>^X```H```"`
M[@``#@```(ON```P````FNX```H```#+[@``!````-;N```(````V^X```@`
M``#D[@``#@```.WN```"````_.X```0```#_[@``!@````3O```$````"^\`
M`!D````0[P``%0```"KO```$````0.\```8```!%[P```@```$SO```+````
M3^\```X```!;[P```@```&KO```&````;>\```8```!T[P``!@```'OO```(
M````@N\```P```"+[P``"````)CO```"````H>\``!X```"D[P``%@```,/O
M```R````VN\``"X````-\```)````#SP``!,````8?```%P```"N\```(```
M``OQ```\````+/$``%P```!I\0``)````,;Q```F````Z_$``"(````2\@``
MY````#7R```:````&O,``$<````U\P``.````'WS``!'````MO,``$H```#^
M\P``'@```$GT```>````:/0``#(```"']```*@```+KT```B````Y?0``"8`
M```(]0``J@```"_U``!>````VO4``$L````Y]@``7P```(7V``!/````Y?8`
M`%H````U]P``*````)#W```J````N?<``"H```#D]P``,@````_X```N````
M0O@``#````!Q^```3@```*+X``!&````\?@``$8````X^0``*````'_Y```J
M````J/D``#8```#3^0``*P````KZ```I````-OH``"@```!@^@``&@```(GZ
M```J````I/H``#(```#/^@``*P````+[``!.````+OL``$8```!]^P``(@``
M`,3[```D````Y_L``$P````,_```*0```%G\```X````@_P``#$```"\_```
M*@```.[\```B````&?T``$(````\_0``#````'_]```$````C/T``%L```"1
M_0```@```.W]```#````\/T``#````#T_0``,0```"7^```5````5_X``!P`
M``!M_@``%@```(K^```@````H?X``"@```#"_@``(@```.O^```>````#O\`
M`",````M_P``&````%'_```V````:O\``#0```"A_P``'````-;_```=````
M\_\``!X````1``$`(@```#```0`@````4P`!``0```!T``$`#@```'D``0`(
M````B``!``8```"1``$`!````)@``0`$````G0`!`!P```"B``$`!````+\`
M`0`/````Q``!`!````#4``$`%````.4``0`4````^@`!`!(````/`0$`.P``
M`"(!`0`*````7@$!`!````!I`0$`"@```'H!`0`(````A0$!``D```".`0$`
M"@```)@!`0`4````HP$!``0```"X`0$`!@```+T!`0`S````Q`$!`!,```#X
M`0$``@````P"`0`)````#P(!``P````9`@$`%0```"8"`0`$````/`(!``(`
M``!!`@$`"@```$0"`0`$````3P(!``@```!4`@$`#0```%T"`0`1````:P(!
M`#````!]`@$`%@```*X"`0`4````Q0(!`"P```#:`@$``@````<#`0`Q````
M"@,!``8````\`P$`#````$,#`0`*````4`,!``H```!;`P$`$````&8#`0`0
M````=P,!``X```"(`P$`#P```)<#`0`/````IP,!`!,```"W`P$`%P```,L#
M`0`/````XP,!``(```#S`P$``@```/8#`0`$````^0,!``0```#^`P$`"@``
M``,$`0`]````#@0!`!P```!,!`$`)P```&D$`0`H````D00!`%$```"Z!`$`
M*@````P%`0`P````-P4!`!,```!H!0$`&@```'P%`0!-````EP4!`#H```#E
M!0$`(P```"`&`0`@````1`8!`!X```!E!@$`(@```(0&`0`@````IP8!`"0`
M``#(!@$`)````.T&`0`D````$@<!`"0````W!P$`)@```%P'`0`>````@P<!
M`#0```"B!P$`/P```-<'`0`2````%P@!`!<````J"`$`&@```$((`0!H````
M70@!``P```#&"`$`=@```-,(`0!H````2@D!``X```"S"0$`%0```,()`0`,
M````V`D!`!@```#E"0$`#P```/X)`0`0````#@H!``H````?"@$`!@```"H*
M`0`&````,0H!``8````X"@$`"@```#\*`0`*````2@H!``@```!5"@$`$P``
M`%X*`0`-````<@H!``H```"`"@$`#````(L*`0`,````F`H!``P```"E"@$`
M#````+(*`0`,````OPH!`!````#,"@$`!@```-T*`0`.````Y`H!``@```#S
M"@$`"````/P*`0`*````!0L!``8````0"P$`#@```!<+`0`(````)@L!`!8`
M```O"P$`"@```$8+`0`(````40L!`"4```!:"P$`!@```(`+`0`!````V0``
M`"@`````````%0,``,\"``"B`@``6@```)H#``#T````LP```&4````;`P``
MS@$``!8"```J`0``K0(``!`````F````X`(``%T!``">`P``/0,```````"N
M`P```````#H!``!=````>`````````!V`0``XP```-<!``"?`0```````(,#
M```$`@``Q`$````````3`@``)@,``%$!``#-````#@$````!````````D`$`
M`!,```"'`0``-0$``!4```"B`P``;@``````````````_@(```@#```P`0``
M@P```,,"```T````P@```.,!``!Q`@````````````#M``````````0`````
M````>0````````!.`@``PP````````!S`@```````+$"````````=0``````
M`````````````+@"```O`P``#P$``"0#```-`P````````,"``!&`@``3`,`
M`!\#``!7`0```````-H!`````````````/P!``````````````````!F`0``
MW@(```````"X`````````'<"``#<`0``````````````````!P,``#("``!?
M````)P$``-X```#.`@``S@```````````````````,0```"&`@``"0$``$(!
M````````T`````````"%`0``4````.(!````````L`(``.P```#I`0``?```
M`'P!```\`0``(0```&("````````XP(``(8!``"#`0```````)T#````````
ME0(``````````````````(X#``"L`@````````H````@`P```````*P```"?
M`@``D0(``+8```"7````!P`````````E`@``;0(````````K`0``)P,``((!
M``!Z``````````````"T`P``80(``(L#````````#@```(@!``!D`0``;@,`
M`%L!```R````*P,``+H`````````.0```!X````"`0``&0(``#@!```I`@``
M6@$```T!``"1`P``Q0````````!F`@```````*8```"E`P``20,``+H#```Z
M`P``+@,````````-````+`(``%X"``"3`P```````*D#``!L`P``=P,`````
M```R`0```````*$!``#-`@``OP(```````!I`P``P0$``+4"````````'@(`
M`*`#``!@````K@````````#`````#P,``/0"``!:`@``I@$``!0"``#4`0``
MW0$``'$#``#R````````````````````00$````````X````-P(``$T```"4
M`P``Z`$``%@```!#````HP(```````!;`P```````$D"``":````7@$``%H#
M``"U````SP$`````````````<0```````````````````(D#``!K`0``NP$`
M````````````D`````\"``#1`0``MP,````````?`@```````!\````\`@``
M!P$``*8"```;`0```````*@!``!2````7`,``)8"``````````````(#``"G
M`0``]@(```````"-`0``?0,``)`#````````J@```+T!````````H@$``*X"
M```U`@``%P$``"$"``````````````````#^`````````*H!```!`0``^P(`
M`.$```"@`@``'`,```@"```=`P```````)0````]````-P,``!$"```C````
MP`$``+<"````````1@```/,!``"4`@``+@(``*0```!Z`0``2P,``)8```#_
M`0```````(,"``"D`P``M@$``&0````)`@``.0(``'H#````````7P(``'`"
M```S````2@(``#\#````````N0,````````7`@``<`$``%L"```E````+`,`
M`*\"``!+`0```````"8!``"/`@```````,D!``#(`@```````)X"```%`@``
M@@(``````````````````%(#``!E`@``X@````````"=`0``A0,``%<#```7
M`P``,0,```````#;`@`````````````I`0`````````````+`0``;P(``!`#
M``"O`P``H0```&D"``"$`@``G`(``%,```!%````;`$``-H"``!U`@``K0``
M```````4`0``0@(```$#```1`P``@0,``.8"``"3`````````.4!```8`@``
M9`,``$4"``#5````````````````````C@$``-$"`````````````&$!``!?
M`0``P0````T"``!-`@````````````!=`P```````'0````B`P```````"@"
M````````[`(``&H#````````"@$``!@#``";`@``]0(`````````````[P``
M``````![`0``-@(``.<!``!_`P``$@```*<"````````)@(```````#-`0``
M`````/\"```3`P``L`$``($```!^`0``^0(```````!8`P``.`(``%4#``!6
M`P``E0$```D#```_`````P$``(8#`````````````,4!```[`0``8`$``'L`
M``!/`P``2P```%D```"S`P``````````````````80,```,#````````````
M`$`!``!@`P``EP,``$P!``!J`@````````0!```<`0``0`,```````!"`P``
M``````````!$`0``8P(``"\"``#9`@``%@```*P!``"+`@``L@(``.H```#J
M`@``N@(``',#````````.0,``-`"```^`@``CP,``'<!``!1`@``>P,``+,!
M``!$`@``LP(````````,`P``K`,``/0!``!6`0``!0,``+H!```[`@``N`,`
M``````#Q````H0,``(@`````````:@$```````!B````.0$``(P"```\`P``
MAP````````!O`P``JP$``(L````S`@``J0$``*D`````````9P,`````````
M`````````.8!``!(`P``U@(``%L````*`@``X````(\!``#(`0``^````"<`
M````````J`,``#<!``#M`@``M`$`````````````FP$``)@#``"`````!0$`
M`"<"``!Y`P``@@```/@"``"5`P``7@`````````1`0``TP$``#X#````````
M0@````D```!'`P``C0,``+\!```]`@``VP```(\```#<`@``$0```'T!``!U
M`0``D@(``(T"`````````````+8"``#N`0``+0,```````#>`0``!@(``$\`
M``"(`@``(P(`````````````$@,``&P"```````````````````B````````
M`%("``!V`P``^0$``!L"``"+`0``_````&D````C`P``K0,``,P"````````
M#`$``"0!``!0`0``5P(``(4"````````;@(``/<!``!&`P```````&$```!5
M````Q0(`````````````G`,``/L```!M`0``X0(```````!4`````````$,#
M```E`P``O`(``'P"``#N`@``#````'8"```_`0```````"``````````R@``
M````````````B0(``*,!``#8`@``T`$```````"N`0``8`(``,0"````````
M+P$```````!.`P``R```````````````<P$``'<```!1`P```@`````````@
M`@``Y`(``#H"``#*`@``S`$````````O`````P```,H!````````[P(``+<`
M``"^`@``<@(```````!U`P``%P```````````````````%4"``"Q````'@$`
M`$@"``#K`@``<`,``!,!``!R`0``]0$``#L#``#?`@```````*8#````````
M:````$`"``#6````O@```),"``#\`@``:P,```````!\`P``_0(```````!?
M`P``[`$``'````!!````J0(````````Z````%@,``'(```"G`P``DP$``!T`
M``"J`@``````````````````$@$``+(!```"`@```````&H````$`P``````
M````````````GP````````!-`0``(0$``$P"``!E`0``;P$``,8!````````
MV`$``)T```!9`@```````)(```!+`@``F`$``%0#````````P@$````````6
M`0``7`````````#V`0``T@(``!D`````````I0(``*4````8````30,``.@`
M```9`0``F`(``$H#``!H`0``J````%P!```I`P``,````)0!``#'````+@``
M`)P```#4````J`(``&D!```+`@```0(``.@"``!C`0``EP$``$$"```0`0``
MT0```&T#````````/P(```````"V`P```````.`!```````````````````V
M`P``OP```&<```#]`0```````-L!`````````````$D!````````=`(``#0"
M````````;````+`#``!N`0```````(H```````````````````"T`@``7@,`
M```#``#6`0`````````````.`@``2`$``!P```#Y````X0$``$0#``"K`@``
M+@$``(4```#+````[P$``$,"````````/@$``!("```^````L@,``.<"````
M````H`$``!@!``"?`P```````(`"```````````````````U`P``Q@(``/`"
M```0`@```````-T````E`0``B@(``.("``!$````)`(``",!````````U0$`
M`&8```!^`P``40```,L!``#3`@````````````"Q`0``-P```(T`````````
M````````````````V````-<"``!6`@``_P```)P!``!%`P``9P$``/8`````
M````4`(```````!9`0``A`,```````!'`0``O`$`````````````*P(`````
M``"]`@```````*0"``"$`0``NP(``#4```"7`@``Y0(```````#Z````:P``
M`)D"`````````````)H"``".````:P(``-\!```&````'@,``((#``!<`@``
MKP$``!T!````````%`````L```!```````````````!C````4`,``+0```"K
M`P``A@````X#``!D`@``00,``-,```!3`0``````````````````&@$``$8!
M````````T@```$<"``"Y`0```````!4!``#W`@```````/,"``!Z`@``P`(`
M`/`````M````'0(``%,#``",````G@$```4```"(`P```````&@#``!4`@``
M2@$```````#E````20```/`!``!T`P```````%<```!S````"@,``/X!``",
M`0``PP$``#`"``"8````QP(``!D#````````*@(```````#Z`@``D@$``.H!
M```:`@```````$\!````````+0(``(D``````````````!4"``"D`0``+`$`
M`.L!```H`0``3@$``````````````````(<#```Q`@``L@```"(!```T`P``
M"`$`````````````B@$```````#9`0```````-0"``"C````?0```#8````T
M`0`````````````J`P``,0$```@```"M`0``5`$``````````````````!H#
M``"Q`P``C`,``'\!````````;0````````#<````4@$``'8```":`0``````
M``8!````````4P(``)4```!Y`0``'`(``*$"```S`0```````/$"``#S````
M?@```'(#``"G````^P$``!\!``"]````^@$``)L#````````N0```*,#``#=
M`@``>0(``)(#``!6````_0````````````````````<"````````2@```/4`
M``!#`0````````````#)````A`````````"W`0``-@$``'@"``!^`@``````
M`(`!``"6`0```````'\````+`P``!@,``,L"````````NP,`````````````
M`````+4#``"K```````````````P`P``(@(``.0!``"1`````````*H#``!.
M````(`$``&(!``!Q`0```````.T!``#&````Z0````\`````````P0(``,("
M```:````O````%D#```R`P``3````'\"``!8`@```````/@!```J````NP``
M`&<"``!X`0``D`(``"0```!F`P``+````$<```#,````\@(``-\```#K````
MF0$``"D`````````\0$``+4!```4`P``]P```'@#``"=`@```````)8#``!E
M`P``H@```.0`````````2````#$``````````````-4"``#)`@``?0(``)D`
M``!/`@``@0(`````````````*P`````````\````10$``&,#`````@``*`,`
M``````"X`0``D0$``($!````````.P```'L"``#I`@``V@````````"'`@``
M```````````,`@``H```````````````50$``&@"``"^`0``UP``````````
M`````````(D!``!T`0``FP````````#'`0```````(H#``"O`````````(`#
M``#R`0``&P```#@#``"E`0``[@```.8```"Y`@```````&(#``#/````6`$`
M`.<````S`P```````(X"``"9`P``G@```&\```"P````70(``-(!````````
M+0$````````]`0``(0,````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E
M<RD`("AT;V1A>2D`("AY97-T97)D87DI`")&:7)S=&YA;64@3&%S=&YA;64B
M("`H:64N($IO:&X@1&]E*0`B3&%S=&YA;64L($9I<G-T;F%M92(@*&EE+B!$
M;V4L($IO:&XI`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4VEG
M;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@861D960N`"5S(&%L<F5A
M9'D@97AI<W1S+@`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I
M<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,G<R!#86QE
M;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``M+2!S96QE8W0@+2T`
M,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!B<F]W
M<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9`!!(&1A=&%B
M87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-+U!-`$%B;W5T
M('1H:7,@961I=&]R`$%B;W9E('-E87)C:"!F;W)M`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`
M061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E
M.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@
M=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D
M('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;P!!9&0@
M=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U
M<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S
M($)O;VL@3&ES=&EN9P!!9&1R97-S(&)O;VL@96YT<GD`061M:6YI<W1R871I
M;VX`061S`$%D=F%N8V5D(%-E87)C:`!!;&EA<P!!;&P`06QL($%U=&AE;G1I
M8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!%>&ES=',`
M06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E
M($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N
M871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N;VYY;6]U<R!0<F]X>0!!<'!L
M:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P<F]V90!!<')I;`!!
M<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('1H
M870@>6]U('=A;G0@=&\@9&5L971E("5S/P!!<F4@>6]U('-U<F4@=&AA="!Y
M;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N=')I97,_`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_`$%S8V5N9&EN9P!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@
M=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N9`!"86-K9W)O
M=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S
M('5S97)N86UE+@!"87-I8R!396%R8V@`0F5L;W<@<V5A<F-H(&9O<FT`0FEN
M9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`0FQO8VL@5'EP90!";VQD`$)O
M;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!"=6QL
M971E9"!,:7-T`$)U<VEN97-S($-A=&5G;W)Y`$--4P!#4D,`0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',`0V%L96YD87(`0V%N)W0@8V]N;F5C="!T;R!)34%0
M('-E<G9E<CH@)7,`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN
M;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L
M(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@
M;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E
M('1O('-P96-I9FEE9"!N=6UB97(N`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@
M3&%B96QS`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E
M;G1E<@!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S
M`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P
M;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL
M<RX`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E
M(&%N(&%D9')E<W,@8F]O:P!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<B!O=70@
M=7-E<CH@)7,`0VQE87(@=7-E<@!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7
M:6YD;W<`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L
M<SH`0V]L=6UN($]P=&EO;G,`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6$@
M<V5P87)A=&5D('9A;'5E<P!#;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R
M;W-O9G0@3W5T;&]O:RD`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`
M0V]M;6]N($YA;64`0V]M<&%N>0!#;VUP86YY($%D9')E<W,`0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R
M9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z("5S`$-O
M;FYE8W1I;VX@9F%I;'5R90!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N`$-O;G1A8W0@<F5M;W9E9"!F<F]M(&QI<W0N
M`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1R>0!#
M<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-U<G)E;G0@
M5&EM90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N
M`$-U=`!#=70@<V5L96-T:6]N`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`
M1&%T92!296-E:79E9`!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L
M(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@0V]L;W(`1&5F875L
M="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$96QE=&4`
M1&5L971E($-O;F9I<FUA=&EO;@!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI
M<W-I;VX`1&5L971E(&)U='1O;B!B96AA=FEO=7(`1&5L971E(&-E;&P`1&5L
M971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M`$1E;&5T92!F86EL960Z("@E<RD@)7,`1&5L971E(')O=P!$96QE=&4@<V5L
M96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T:6]N(&9A:6QE9`!$96QI=F5R>2!T
M:6UE`$1E<&%R=&UE;G0`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE
M;0!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E
M8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R
M('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&\@;F]T(&1E;&5T90!$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T
M;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#H`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1&]W;FQO860@=D-A<F0`12U-86EL`$5D
M:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET
M(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@96YT
M<GD@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16YA8FQE
M(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@
M=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YL87)G
M92!%9&ET;W(`16YT<GD@9F]R("5S('5P9&%T960N`$5R<F]R`$5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92X`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AE8W5T90!%>'!A;F0`17AP:7)A=&EO;B!$871E`$5X<&]N96YT
M`$5X<&]R=`!%>'!O<G0@061D<F5S<R!";V]K`$5X<&]R="!O;FQY('1H92!S
M96QE8W1E9"!C;VYT86-T<RX`17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S
M<R!B;V]K(&-O;7!L971E;'DN`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T
M=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!A
M8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,`1F%I;&5D('1O(&%D9"`E<R!T
M;R`E<SH@)7,`1F%I;&5D('1O(&)R;W=S92!L:7-T`$9A:6QE9"!T;R!B<F]W
M<V4@=&AE(&1I<F5C=&]R>0!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E9#H@)7,`1F%I;&5D('1O(&UO=F4@
M=&\@(B5S(BX`1F%I;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E<P!&
M96)R=6%R>0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I
M;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL
M92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`
M1FEN9`!&;VYT($-O;&]R`$9O<FUS`$9O<G5M<P!&<@!&<F%M97,`1G)E96)U
M<WD@55),`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!.86UE`$=E;F5R871E("5S
M($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1VEV96X@3F%M90!';&]B
M86P@061D<F5S<R!";V]K`$=R;W5P`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'=65S="!097)M
M:7-S:6]N<P!'=65S=&)O;VL`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA<V@M06QG;W)I=&AM`$AE861E<@!(96EG:'0`2&5L<`!(;VUE`$AO
M;64@061D<F5S<P!(;VUE($-I='D`2&]M92!#;W5N=')Y`$AO;64@4&AO;F4`
M2&]M92!0;W-T86P@0V]D90!(;VUE(%-T871E+U!R;W9I;F-E`$AO<F1E`$AO
M<FEZ;VYT86P@4G5L90!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N
M(&9A:6QE9#H@)7,`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)8V]N<R!/;FQY`$EC
M;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D
M:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I
M;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N
M970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T
M;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!);6%G92!0<F5V:65W.@!)
M;6%G92!54DP`26UA9V4@55),.@!);6%G97,`26UP;W)T($%D9')E<W,@0F]O
M:RP@4W1E<"`E9`!);7!O<G0L(%-T97`@)60`26UP;W)T+T5X<&]R="!!9&1R
M97-S($)O;VMS`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z
M`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"X`26YC<F5A<V4@26YD96YT`$EN9&EV:61U
M86P@57-E<G,`26YF;W)M871I;VX`26YS97)T($-?;VQU;6X@069T97(`26YS
M97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T
M(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&-E;&P@869T97(`26YS97)T
M(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M
M;B!B969O<F4`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R
M87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E
M`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=F%L:60@240`26YV86QI9"!A
M9&1R97-S(&)O;VL`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!D871A
M('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A
M;&ED(&5M86EL`$EN=F%L:60@96YT<GD`26YV86QI9"!K97D@<W!E8VEF:65D
M+@!);G9A;&ED(&YA;64`26YV86QI9"!O8FIE8W1)9`!);G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+@!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED
M('5N:6-O9&4@9&%T82X`27-S=65R`$ET86QI8P!*86YU87)Y`$IU;'D`2G5N
M90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y
M($QE9G0`2G5S=&EF>2!2:6=H=`!+97)B97)O<R!S97)V97(@<F5J96-T960@
M875T:&5N=&EC871I;VXN`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`
M2V5Y($QE;F=T:`!+97D@5'EP90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N`$Q$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B
M=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO
M861E9"X`3&%N9W5A9V4`3&%S="!-;V1I9FEE9`!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA>6]U
M=`!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S
M`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$U-`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`36%I
M;`!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+@!-87)C:`!-871C:&EN9P!-871C:&EN9R!F:65L
M9',`36%X:6UU;2!N=6UB97(@;V8@<&%G97,`36%Y`$UE;6)E<G,`365N=2!M
M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E('9E<FEF:65D+@!-971H;V0`36EM92!4>7!E`$UI;FD@4V5A<F-H
M`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-
M;P!-;V)I;&4@36%I;`!-;V)I;&4@4&AO;F4`36]D:69I960@1&%T90!-;V1I
M9GD@9F%I;&5D.B`H)7,I("5S`$UO;G1H;'D`36]R92!T:&%N(#$@96YT<GD@
M9F]U;F0`36]V90!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V
M92!5<`!-;W9E(&1O=VX`36]V92!L969T`$UO=F4@<FEG:'0`36]V92!U<`!-
M=6QB97)R>2!!9&1R97-S($)O;VL`37D@06-C;W5N=`!.3RP@22!$;R!.3U0@
M06=R964`3F%M90!.86UE($9O<FUA=`!.971C96YT97(@365M8F5R($1I<F5C
M=&]R>0!.971W;W)K`$YE=F5R`$YE=R!#871E9V]R>0!.97<@0V]N=&%C=`!.
M97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97AT`$YI8VMN86UE`$YO("5S(&5N
M=')Y(&9O=6YD(&9O<B`E<P!.;R!A9&1R97-S(&)O;VMS(&9O=6YD+@!.;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`
M3F\@8V]N=&%C=',@9F]U;F0`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P
M96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0@<V5N="X`3F\@=D-A<F0@9&%T82!W87,@9F]U;F0N`$YO('9A
M;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;W0@069T
M97(`3F]T($)E9F]R90!.;W1E<P!.;W9E;6)E<@!.=6UB97(@;V8@:71E;7,@
M<&5R('!A9V4`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R
M`$]B:F5C="!N;W0@9F]U;F0`3V-T;V)E<@!/9F9I8V4`3VYL>2!)34%0('-E
M<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M
M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+@!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@
M3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ
M:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]T:&5R($EN9F]R
M;6%T:6]N`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I
M9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0
M(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4&%D
M9&EN9P!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!E;F1I
M;F<@4VEG;G5P<SH`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A
M=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VX@9&5N
M:65D`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R
M;6%T:6]N`%!H;VYE`%!I;F4@061D<F5S<R!";V]K`%!I>&5L<P!0;&5A<V4@
M96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!O;&QS`%!R
M969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=P!0<FEN="!D;V-U;65N=`!0<FEV871E($%D9')E<W,@0F]O:P!0<FEV
M871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4'5B;&EC($ME
M>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!1=65R>0!1=65R>2!F86EL
M960Z("@E<RD@)7,`475I8VL@4V5A<F-H`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)A=&EO`%)E860`4F5A9"!F86EL960Z("@E<RD@)7,`4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A
M;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A
M;"!6:65W.@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO
M=F4@8V]L=6UN`%)E;6]V92!F<F]M('1H:7,@;&ES=`!296UO=F4@<&%I<@!2
M96UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B
M92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D(&]B
M:F5C="!N;W0@9F]U;F0N`%)E<V5T`%)E<V5T('1O($1E9F%U;'1S`%)E<W5L
M=',`4F5T=7)N('1O($]P=&EO;G,`4F5V97)T($-O;F9I9W5R871I;VX`4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS`%)O;&4`4F]W(%!R;W!E<G1I97,`4F]W
M('!R;W!E<G1I97,`4F]W<SH`4G5N`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4R]-24U%(%!U8FQI
M8R!#97)T:69I8V%T90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%-13"!3:&5L;`!34T@`4V$`4V%V90!3879E("5S`%-A=F4@3W!T
M:6]N<P!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!396%R8V@`4V5A<F-H(&9A
M:6QE9`!396%R8V@@9F%I;&5D.B`E<P!396%R8VAI;F<N+BX`4V5L96-T(&$@
M9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R
M`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@
M=&AE(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3H`4V5L96-T('1H92!A
M9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.@!396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z`%-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SH`
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=VAI8V@@9FEE
M;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N`%-E;&5C="!W
M:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RX`4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5P=&5M8F5R`%-E<FEA;"!.
M=6UB97(`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-H87)E9"!$:7)E
M8W1O<GD`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W($%L;`!3:&]W($-O;G1A
M8W1S`%-H;W<@3&ES=',`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G
M:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H<FEN:P!3:')I;FL@;W(@;6]V
M92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`
M4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4V]R="!$:7)E8W1I;VX`4V]U<F-E(&%D9')E<W,`
M4V]U<F-E<P!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!E8VEA;"!#
M:&%R86-T97(@26YP=70`4W!E8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A;F-E
M9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N`%-T871E(&]R(%!R;W9I;F-E
M`%-T871U<P!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T>6QE(%M#
M4U-=`%-U`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M861D960@)7,@=&\@)7,`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U;6UA<GD`
M4W5P97)S8W)I<'0`4W5R;F%M90!44U8@9FEL90!486(@<V5P87)A=&5D('9A
M;'5E<P!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`
M5&%S:W,`5&5L97!H;VYE($YU;6)E<@!497AT($]N;'D`5&5X="!A;&EG;@!4
M:`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!-86EN=&5N86YC93HZ(&-L
M87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&1R97-S(&)O;VL@8V]U
M;&0@;F]T(&)E('!U<F=E9#H@)7,`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('EO=2!R
M97%U97-T960@9&]E<R!N;W0@97AI<W0N`%1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H
M92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E
M8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O
M8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D
M:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N
M("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@
M;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA
M>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W
M('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&5R92!A<F4@;F\@8G)O=W-E
M86)L92!A9&1R97-S(&)O;VMS+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO('=R:71E86)L
M92!A9&1R97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S
M<R!B;V]K<R!A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE
M=R!E;G1R:65S('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@:7,@86X@
M97)R;W(L('!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A
M<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE=R!C;VYT86-T+B!#;VYT86-T('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@9F]R(&9U<G1H97(@:&5L<"X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N`%1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S`%1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C="X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<P!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O
M;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@
M)7,`5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4:&ES($E-
M05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E
M<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F
M;W)M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<&5R<V]N(&%L
M<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:P!4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A
M;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&EM92!4<F%C:VEN9P!4:71L
M90!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N
M=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG
M+@!4=0!54DP`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W
M:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@=')A
M;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1E<FQI;F4`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N9FEL960`56YK;F]W;@!5
M;FYA;65D`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S
M`%5P9&%T92!U<V5R`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@
M;G5M8F5R<P!5<V4@0W5R<F5N=#H@)7,`57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B!!9&UI;FES=')A
M=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<FYA;64`
M57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`5F%C
M871I;VX`5F%L:61I='D`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<FES:6=N($1I
M<F5C=&]R>0!697)S:6]N`%9I97<@)7,`5FEE=R!#;VYT86-T`%9I97<@=&\@
M9&ES<&QA>2!B>2!D969A=6QT.@!787)N:6YG`%=E`%=E8G-I=&4@55),`%=E
M96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&]F('1H92`E<R!M96YU
M(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7
M:61T:"!O9B!T:&4@=&%B;&4`5V]R:R!!9&1R97-S`%=O<FL@0VET>0!7;W)K
M($-O=6YT<GD`5V]R:R!0:&]N90!7;W)K(%!O<W1A;"!#;V1E`%=O<FL@4W1A
M=&4O4')O=FEN8V4`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT
M96YS:6]N<P!960!965E9`%EE87)L>0!997,`665S+"!)($%G<F5E`%EO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D
M9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N
M`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT
M86-T+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@
M;V)J96-T+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E
M<W,@8F]O:RX`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N`%EO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9
M;W4@;VYL>2!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N
M`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9
M;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B
M<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE
M.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<F5M;W1E
M('-E<G9E<G,Z`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`%]!
M9&UI;FES=')A=&EO;@!?0G)O=W-E`%]$96QE=&4`7T1E;&5T92!2;W<`7T=R
M;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T+T5X<&]R
M=`!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?
M4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]296UO=F4@9G)O;2!T:&ES
M(&QI<W0`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S
M97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C;&EC:R!H97)E`&9I;&4`;F]T
M('EE="!I;7!L96UE;G1E9`!P97)C96YT`'!I>&5L<P!T>7!E('1H92!P87-S
M=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N;F%M960`4')O:F5C="U)9"U697)S
M:6]N.B!4=7)B82`R+C`*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`Q+3$S(#`X.C`P*S`Y
M,#`*3&%S="U4<F%N<VQA=&]R.B!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C
M+G1S=6MU8F$N86,N:G`^"DQA;F=U86=E+51E86TZ($IA<&%N97-E(#QU;FMN
M;W=N0'5N:VYO=VXN9&]M86EN/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]4TA)1E1?2DE3"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@D_J13RD`@T&#3H-:@UB#
M3(-#("5S`"`HC:&3^BD`("B-\)/Z*0`BD*D@EKPB+")&:7)S=&YA;64@3&%S
M=&YA;64B`"*6O"P@D*DB+"),87-T;F%M92P@1FER<W1N86UE(@"2RI)M("T@
M)7,`)7,@DV2.<8YWEN0`)7,@2T(`)7,@E=N.YY&`C>R"S(IME$8`)7,@@U2#
M0X.3@T&#8H-V`"5S().OB-./\(V``"5S((+PDL>)P8*U@MR"M8*]@4(`)7,@
M@LV*^8+)D;:-W8*U@MR"MX%"`"5S((-T@T"#0X.+@JJ#0X.3@WR!6X-G@K."
MZH+<@K6"O8%"`"5S@JJ52Y=V@L6"MP`E<R"5J@`E<R""JH*@@NB"W(*Y@O&!
M0@`E<R""S)=<DNB57``E<R""S(.!@X*2H``E<R""S(->@UB#3H.*@UB#9P`M
M+2"129'P("TM`#$RCIZ*U(Q@CJX`,C2.GHK4C&".K@`R-"".GHK4`&E&<F%M
M97,@@O"#5(-\@5N#9X*W@NF#=8.)@T6#58*JE4N7=H+%@K<`@K&"S(-U@XV#
M8H-.@LV#9H%;@UZ#>(%;@UB"JI5+EW:"Q8*W@4(`DG:6O9-)@LB#1X.)@5N"
MJI2MD+:"M8+<@K6"O0!01U",]HI*C*Z"JH.!@V*#6H%;@U>"S(C#C8:)NX+)
ME4N7=H+%@K>!0@!01U",]HI*C*Z"JH^0EKR"LX+J@KV#@8-B@UJ!6X-7@LR,
MGX_8@LF52Y=V@L6"MX%"`%!'4(SVBDJ,KH%!4$=0E.F6IXRN@JB"YH+1@W"#
M6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7@LR5G(V&@LF52Y=V@L6"MX%"
M`%!'4(SVBDJ,KH%!4$=0E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ#@8-B
M@UJ!6X-7@LR/D):\@LF52Y=V@L6"MX%"`%,O34E-18SVBDJ,KH%!4R]-24U%
ME.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7@LR5
MG(V&@LF52Y=V@L6"MX%"`%,O34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN@JB"
MYH+1@W"#6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/D):\@LF52Y=V@L6"MX%"
M`%,O34E-18SVBDJ,KH*J@X&#8H-:@5N#5X+,B,.-AHF[@LF52Y=V@L6"MX%"
M`$%-+U!-`(*Q@LR#1X-F@T*#7H%;@LF"PH*B@L0`C)^-]8-T@TB!6X.`@LR/
MXP!61E.#9H-"@XR#3H-G@XJ"S(WLD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U
M@KV!0@!61E.#=(-`@T.#BX+,C>R0K(+-@T&#3H-:@UB+D93;@K."ZH+<@K6"
MO8%"`(-!@TJ#18.3@V>"S(-P@UB#CX%;@V@`@T&#2H-%@Y.#9X+-DX",BX*S
M@NJ"Q(*B@MR"MX%"`(-4@W6#3X.+@5N#=H+PDL>)P0"#5(-U@T&#3H-:@UB,
MH(+PDL>)P0""L8*Q@LF2QXG!.@"05H*U@J*#3X.+@5N#=H+PDL>)P0"05H*U
M@J*"\(-!@TZ#6H-8C*"2QXG!`)!6BTN#AH%;@U6"\)+'B<&!1@"7\8+,DL>)
MP0"05HM+@X&#DX-O@O"2QXG!@48`@WF#08+PDL>)P0`E<R"#@8-J@X6!6X+P
M($UO>FEL;&$@@LR#5(-#@VB#;X%;@LF2QXG!@K>"Z0""L8*Q@LF2QXG!`(-!
M@VB#C(-8DJ""R9+'B<$Z`(Z$@LR"S(-!@VB#C(-8DJ""R9+'B<$`@X:!6X-5
M@O"2QXG!`(.&@5N#58+,DL>)P8^(EYV"S9:SC/B"R8+(@L&"Q(*B@MR"MX%"
M`(]:CXH`@T&#:(.,@UB2H(CJEY<`@T&#:(.,@UB2H(V`EMH`BL>7G0!!9',`
MC]J-UXR?C?4`E<J6O`"14X+$`)%3E$:/V(.&@5N#50"14X+$@LR#3X.+@5N#
M=@"14X+$@LR#08-.@UJ#6(R@`)34C8:5=(*K@XJ#6(-G@O"0W9+H@L6"JX+I
M@N:"I(+)@K6"W(*W@JF!2`"*^8+)D;:-W8*U@MR"MP"*^8+)D;:-W8*U@MR"
MMP"1XY'6@LP@24U34""#C8-/@T.#DP"1XY'6@LP@24U34""#<(-8@X^!6X-H
M`)'CD=:"S"!)35-0((.&@5N#59:\`)'CD=:"S(.!@5N#BX-!@VB#C(-8`)'C
MD=:"S(-E@Y.#=H.,@5N#9P"5<Y"S@LB2;(*JCG>2Z(*S@NJ"Q(*B@MR"MP"3
MO9:\@W:#C8-,@U:!6P"#08-V@XJ#4(%;@U:#AX.3`(-!@W:#BH-0@5N#5H.'
M@Y..9Y=PB<(`C[.41@""4XR.`(-!@5N#2H-#@W6#=(-`@T.#BX-4@T.#60"#
M08%;@TJ#0X-UEKP`EGN3EH+)("5S((+PC>V/G(*U@L2"X(*B@J*"Q8*W@JF!
M2`"129'P@K."ZH*]C8"6VH+PEGN3EH+)C>V/G(*U@MR"MX*I@4@`)7,@@LR#
M5(-#@Y.#08-B@W:7=HN!@O"6>Y.6@LF-[8^<@K6"Q(*B@J*"Q8*W@JF!2`"/
MN(^'`)7;CN>-[(O&@LR.P(USD4^"R8IME$:"\(N!@M^"Z8+F@J2"R8*U@MR"
MMX*I@4@`D;:-W8*U@LB"HH-/@XN!6X-V@O"-[8^<@K6"YH*D@L:"M8+<@K6"
MO8%"`)&VC=V"M8+(@J*#08-.@UJ#6(R@@O"-[8^<@K6"YH*D@L:"M8+<@K6"
MO8%"`)&VC=V"M8+(@J*#08-.@UJ#6(R@@O"5TH]7@K6"YH*D@L:"M8+<@K6"
MO8%"`)&VC=V"M8+(@J*+I)=,@O"5TH]7@K6"YH*D@L:"M8+<@K6"O8%"`)&N
MD*L`@E>,C@!!=71H7V-Y<G-Q;#H@E4N7=H+(24U!4(IGDJ.+0)1<@JJ,J8+"
M@JF"Z(+<@KF"\8%"`$%U=&A?8WER=7,Z((-O@V*#3H-'@Y.#:(+-E4N7=H+(
ME%R7S8+PETR"M8+$@J*"W(*Y@O&!0@!!=71H7V-Y<G5S.B"7=HN!@K>"Z6EM
M87"*9Y*C@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?9G1P.B!&5%"*9Y*CBT"4
M7(*J@MV"PH*I@NB"W(*Y@O$N(%!(4(+P("TM96YA8FQE+69T<""#28-V@U:#
MAX.3@O""PH*O@L2#4H.3@W"#0X.+@K6"R(*H@K6"Q(*M@KZ"LX*B@4(`075T
M:%]I;6%P.B!)34%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]K
M<F(U.B!K<F(UBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]L9&%P
M.B!,1$%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]L9&%P.B"#
MAH%;@U4@)7,@@O"2QXG!@L6"JX+<@KF"\8%"@U2!6X-O@LR)GI.:.B``075T
M:%]L9&%P.B"#AH%;@U4@)7,@@O"-[8^<@L6"JX+<@KF"\0!!=71H7VQD87`Z
M((.&@5N#52`E<R""\(U8D%:"Q8*K@MR"N8+Q`$%U=&A?;6-A;#H@34-!4(IG
MDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?<VUB875T:#H@<VUB875T
M:(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`)1&C]B"R8ZXE'."M8+<@K6"
MO0"41H_8@LF.N)1S@K6"W(*U@KV!0B5S`%)!1$E54X-4@5N#;X+)@N:"Z)1&
MC]B"JHN1E-N"LX+J@MR"M8*]@4(`1E10@U2!6X-O@LR41H_8@LF.N)1S@4(`
MCF>7<(G"E%R"R(-T@T*!6X.+@VB!1@"4=XQI`)1WC&F01@!+97)O8F5R;W,@
M@W"#6(./@5N#:(*JEK.,^(+%@K>!0@!+97)O8F5R;W,@@X:!6X-5EKR"JI:S
MC/B"Q8*W@4(`BLB(U8R?C?4`C)^-]8-T@TB!6X.`@LR)N@"#;X-#@Y.#:(ZX
ME',Z("@E<RD@)7,`DF&0MI/Z`(-U@XV#8H-.@UZ#0X-V`)&^CIH`@W6#8H-.
M@WV!6X-.`(F/`(F/@LR1OH*S@48`B8\`B=./\(^1@JL`D$6+QI6JE]X`0TU3
M`$-20P!#4DP@E'J5>H-\@T.#DX-G`)=<DNB57`!)34%0((-4@5N#;X+)D-J1
ML8+%@JN"W(*Y@O&"Q8*U@KTZ("5S`(-,@X.#DX-:@XL`C^&*48.,@WR!6X-G
M@O"#3(.#@Y.#6H.+@K>"Z0"#=(-`@T.#BR`B)7,B((+PC>V/G(+%@JN"W(*Y
M@O&!0@"-[(O&@V:#0H.,@TZ#9X.*@JJ,J95T@JF"Z(+<@KF"\8%"`(-F@T*#
MC(-.@V>#BH%;("(E<R(@@O"-[8^<@L6"JX+<@KF"\8%"`(WMCYR"Q8*K@MR"
MN8+Q@4*.<9&W@JH@)60@D;:-W8*U@MR"MX%"`)7`@M>1UH*F@LR1SH_;@LR0
ME(*JE=N1MH*S@NJ"Q(*B@NF0E(+&C8>"[8+(@J*"S(+%E<""UY'6@J:"JH+%
M@JN"W(*Y@O&!0@".=Y+H@K."ZH*]E-2-AH+)@X&#8H-:@5N#5X+PE'J1EX+%
M@JN"W(*Y@O&"Q8*U@KV!0@"57)'H`)6JE]Z"QH.)@WB#BP",9Y'1DV288@"#
M6H.+D:Z0JP"#6H.+EH21D(%&`(-:@XN1KI"K`(-:@XN77922@48`C&>1T9-D
MF&(`DH:)FP"/V):^CY&"S(_:C=<`C]B6OH^1@WR#BH-6@5L`E<^-6`"39(YQ
M@X&#0X.+@LF.9Y=P@K>"Z9:\D4^"QH-!@VB#C(-8@O"5SXU8@K6"W(*W@4(`
M@W"#6(./@5N#:(+PD4F1\`"#AH%;@U66O(+PD4F1\`"#08-H@XR#6)*@@O"1
M29'P`)/ZE7257(ZFC&".KH%&`(-.@XF#6)+HBV`@)7,@@JJ,J95T@JF"Z(+<
M@KF"\8%"`(.&@5N#58+,D=Z+CH%&)7,`@X:!6X-5C\&+C@"#3H.*@V*#3H*W
M@NF"QHZ?@M8`@T6#0H.3@VB#18+PE<*"MH+I`)!&`)!&D4F1\`"01I%)D?``
ME_&!1@"57(ZFE_&#28-V@U:#AX.3`)?Q@UZ#0X-G@XL`@U*#?H-B@TZ#6`"#
M4H.3@WV+YI#8@NB,8(ZN`(-2@Y.#?8OFD-B"Z(Q@CJX@*$UI8W)O<V]F="!/
M=71L;V]K*0"#4H-]@Y.#:`"#4H-]@Y.#:(-6@T:#BP"#4H.!@Y.#9P"+I)+*
MEKP`B>^.T`")[X[0CUJ/B@"0W9+H@LR-MY6J`"5S((+PD-V2Z(*W@ND`@W"#
M6(./@5N#:(+PBFV41@"0VI&QCKB4<X%"`)#:D;&.N)1S.B`E<P"0VI&QCKB4
M<P",]H]/C*Z#5(%;@V^"UH+,D-J1L8*JBY&4VX*S@NJ"W(*U@KV!0@",]HI*
MC*Z#5(%;@V^"UH+,D-J1L8*JBY&4VX*S@NJ"W(*U@KV!0I>=EU*!1B5S("@E
M<RD`1E10@U2!6X-O@M:"S)#:D;&"R8ZXE'."M8+<@K6"O8%"`)A!EXV0YH+-
M@XJ#6(-G@JF"YXWMCYR"LX+J@MR"M8*]@4(`F$&7C9#F@LV#08-H@XR#6)*@
M@LF2QXG!@K."ZH+<@K6"O8%"`(-2@W.!6P"#4H-S@5L`@X&#8H-:@5N#5X+,
M(%!'4""(PXV&B;N"JH+%@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@
M4$=0((^0EKR"JH+%@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@4R]-
M24U%((C#C8:)NX*J@L6"JX+<@KF"\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!3
M+TU)344@CY"6O(*J@L6"JX+<@KF"\8+%@K6"O8%"`)A!EXV0YH+PDL>)P8+%
M@JN"W(*Y@O&"Q8*U@KV!0B5S`$Q$05`@@U2!6X-O@LF#;X-#@Y.#:(+%@JN"
MW(*Y@O&"Q8*U@KV!0@".8XV"@JJ*;91&@L6"JX+<@KF"\8+%@K6"O8%")7,`
MD9>039#F@XJ#6(-G@JJ-[)"L@L6"JX+<@KF"\8+%@K6"O8%")7,`4$=0((-F
M@5N#7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(`4R]-24U%((-F@5N#
M7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(`F$&7C9#F@JJ-[8^<@L6"
MJX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#6(-G@JJ-[8^<@L6"JX+<@KF"
M\8+%@K6"O8%")7,`CO.038[2@LR39(YQ@X&!6X.+@T&#:(.,@UB"JHIMDNB"
MQ8*K@MR"N8+Q@L6"M8*]@4(`@T&#:(.,@UB2H(*JBJZ14X+)@LV.YI.^@L6"
MJX+<@KF"\8+%@K6"O8%"`)&7D$V0YH.*@UB#9X*JBJZ14X+)@LV.YI.^@L6"
MJX+<@KF"\8+%@K6"O8%"`)&7D$V0YH.*@UB#9X*JBJZ14X+)@LV.YI.^@L6"
MJX+<@KF"\8+%@K6"O8%"`(SVBDJ,KH+PC*Z#5(%;@V^"J8+GCN:3OH+%@JN"
MW(*Y@O&"Q8*U@KV!0@`E<R""\(-)@5N#=H.3@L6"JX+<@KF"\8+%@K6"O8%"
M`)7;CN>-[(O&@X*#5X.%@5N#BR`E<R""\(I*@J^"W(*Y@O&"Q8*U@KV!0@`E
M<R""JI/'@MV/;X*Y@MR"N8+Q@4(`@T&#:(.,@UB2H(+PCN:3OH+%@JN"W(*Y
M@O&"Q8*U@KV!0B5S`)&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U
M@KV!0B5S`)&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S
M`)#=DNB"\(RS@LF6WX*Y@MR"N8+Q@L6"M8*]@4(`)7,@D-V2Z(+PE=N1MH+%
M@JN"W(*Y@O&"Q8*U@KV!0@"0W9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"Q8*K
M@MR"N8+Q@L6"M8*]@4(`3$1!4""#5(%;@V^"JHR?C?6"Q8*K@MR"N8+Q@4(`
MF$&7C9#F@O"-6)!6@L6"JX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#6(-G
M@O"-6)!6@L6"JX+<@KF"\8+%@K6"O8%")7,`36]Z:6QL82""S(-4@T.#:(-O
M@5N"JHRIE72"J8+H@MR"N8+Q@4*#5(-#@VB#;X%;@O"*2H*B@L2)NH*S@J*!
M0@"-D0"05HM+C>R0K`"#5(-U@W2#2(.+@U^"\(WLD*P`C>R0K`"-[)"LCM*"
MS(-!@TZ#6H-8C*``@TZ#C(-7@V*#9X-*@5N#:)34C88`C+N-W8+,CIZ*U``E
M<R""UH+,@XV#3X-)@Y..GH+)CL"-<X*W@NF#7H-8@TZ"\)#=DNB"M8+<@K>!
M0@"0V(+HCN:"Z`"0V(+HCN:"Z`"3^@"6B)/Z`$1A=&%4<F5E((E[EY<`@V:!
M6X->CO.030!?3)?Q@LR-[8^<`#$RC(X`CUR0:9"4`))IB;J"L(+PD/."K0"#
M9H-T@TB#BX-GD$8`@V:#=(-(@XN#9R!)1`"#9H-T@TB#BX-G@LR5P(+1CX>!
M1@"-[8^<`(WMCYR"S(IME$8`@T^#BX%;@W:"\(WMCYP`@T&#3H-:@UB,H(WM
MCYP`C>V/G(-[@UZ#DX+,DZZ-[`"#6H.+C>V/G`"7\8+,C>V/G`"1XY'6@V6#
MDX-V@XR!6X-G@LR-[8^<`(WMCYR"Q8*K@MR"N8+Q@L6"M8*].B`H)7,I("5S
M`(US@LR-[8^<`)%)D?""M8*]242"\(WMCYP`C+N-W8C*DG6"S)?Q@O"-[8^<
M`(R[C=V(RI)U@LR-<X+PC>V/G`"-[8^<@L6"JX+<@KF"\8+%@K6"O0"4>I&7
MCIZ*U`"5E(^0`(U^CX<`C^&*49/@EV6"S)#@EKX`C]J-UX*JBL>7G8[2@LR"
MO8+?@LF+3)A>@K."ZH+<@K6"O8%"`(I*E*T`C;:"J8+GB46"U@")18*I@N>-
MMH+6`)!LEKR5ZP`R-(Z>BM257(ZF`)5<CJ:#28-V@U:#AX.3`(WMCYR"M8+(
M@J(`;6%I;G1E;F%N8V4N<&AP((+)DKR0VH-!@TZ#6H-8@K6"R(*B@L6"K8*^
M@K."H@"-@);:@O"-[8^<@K>"Z8W;@LF*;91&@K6"W(*W@JF!2`"-Q8^)@LR7
M\8*J@W2#0H%;@XN#:):\@O"*W(+Q@L6"HH+<@K>"J3\@@KN"I(+(@N>#8(-&
M@V*#3H*U@L2"K8*^@K."HBX`)7,@@LR#7X-%@Y.#C8%;@V@`D+:0K(*U@KV0
MW9+H@O`@4$A0((-8@TZ#BH-V@V>"\(+&@K6"Q(-?@T6#DX.-@5N#:(*W@NF!
M0@!60V%R9"""S(-?@T6#DX.-@5N#:`"39(YQ@X&!6X.+`)72CU<`@W6#C8-B
M@TZ"S)72CU<`@T^#BX%;@W:"S)72CU<`@T&#3H-:@UB,H(+,E=*/5P"#08-.
M@UJ#6(R@@LR5TH]7`"5S((+,@T&#3H-:@UB,H(+,E=*/5P`E<R"-@);:@LR5
MTH]7`(-)@W:#5H.'@Y."S)72CU>!1@`E<R""S(-!@TZ#6H-8C*""S)72CU<`
M@X&!6X.+@T&#:(.,@U@`18.!@5N#BX-!@VB#C(-8`$6#@8%;@XN#08-H@XR#
M6(*JB.J2=H*U@LB"KX+J@LZ"HH*O@MR"N8+Q@4(`B_.#@8-B@UJ!6X-7@L6"
MMX%"`(F]@N",J8+"@JF"Z(+<@KF"\8%"`(--@X.#B8.*@5N"J8+GB>:1G(+P
MD7V3_(+%@JN"Z8+F@J2"R8*U@MR"MX*I@4@`B46#3H.*@V*#3H+%@X&#:H.%
M@5N"\)5<CJ:"M8+<@K>"J8%(`(-'@V:#0H->@5N)YI;*@O"1Y8*K@JT`)7,@
M@LR-@);:@O"-6)!6@K6"W(*U@KV!0@"#1X.)@5L`@X&!6X.+@T&#:(.,@UB"
MS(-'@XF!6X+%@K>!0@`Q-96JEH@`,I6JEH@`,S"5JI:(`#65JI:(`(.-@T^#
M0X.3EH@`,S"5JI:(`#&5JI:(`(YWDNB2;(+,E^$`CL"-<P"35XI*`)=,C/B*
M^HS``(YWD)0`@T>#3H-8@WR!6X-G`(-!@VB#C(-8DJ""S(-'@TZ#6(-\@5N#
M9P"129'P@K."ZH*]@N""S(*^@J^#1X-.@UB#?(%;@V>"MX+I@4(`B,B)NH+,
M@T&#:(.,@UB2H(+,D5."Q(+,D^"798+P@T>#3H-8@WR!6X-G@K>"Z8%"`)%/
MC&F01@"0W9+H@O`@1E10((+%@T&#8H-V@XV!6X-H@K>"Z0"#=H.,@W2#0(.,
M@Y.#6)#=DNB"\([FD[Z"Q8*K@MR"N8+Q@4(`@T&#:(.,@UB2H(+)D-J1L8+%
M@JN"W(*Y@O&"Q8*U@KTZ("5S`"5S((+P("5S((+)DL>)P8+%@JN"W(*Y@O$Z
M("5S`(.*@UB#9X+,B7N7EX+)CKB4<X*U@MR"M8*]`)!LEKR5ZX+,B7N7EX+)
MCKB4<X*U@MR"M8*]`$Q$05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8+%@K6"
MO8%"`%--0B"#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"M8*]@4(`(B5S(B""
MJ8+G@LR#4H-S@5N"R8ZXE'."M8+<@K6"O8%"`"(E<R(@@M:"S(-2@W.!6X+)
MCKB4<X*U@MR"M8*]@4(`D%:+2X+,(%-!4TP@D-J1L8+)CKB4<X*U@MR"M8*]
M@4(`DL>)P8*W@M>"JX-)@W6#5X-&@TZ#9X*JC*F5=(*I@NB"W(*Y@O$Z("5S
M`"(E<R(@@M:"S(C:DZZ"R8ZXE'."M8+<@K6"O8%"`)!LEKR5ZX+PC)^-]8+%
M@JN"W(*Y@O&"Q8*U@KTZ("5S`()1C(X`@W2#0(-#@XN0E#H@)7,@@W2#0(-#
M@XL`@W2#0(-#@XN0E#H@)7,@@W2#0(-#@XL`@W2#0(-#@XN#?8-L@5N#5X.#
M`(-T@T"#0X.+EKP`@W2#0(-#@XN129'P`(-T@T"#0X.+@T&#8H-V@XV!6X-H
M`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q
M@4(`@W2#0H.+@UX`C)^-]0"5MHZ:D$8`@W2#2(%;@X``@W2#2(%;@XF#@`"+
MX`"89P"77)+HC^Z5\2!54DP`C]J"M8*BD."6O@".@9:\`"5S((U<D*R/[I7Q
M@O"0MI"L@K>"Z0"0MI"L@K."ZH*]@U*!6X-H`)"I`(U,B.:#08-H@XR#6)*@
M`(-/@XN!6X-V`(-/@XN!6X-VBL>7G0"#3X.+@5N#=I:\@LV+\Y22@L6"S8+(
M@J*"L8+&`(-/@XN!6X-V`(-1@UB#9X-!@TZ#6H-8C*``@U&#6(-G@W6#8H-.
M`$A45%`@E$:/V(*J@MV"PH*I@NB"W(*Y@O&!0@"#;H-B@U:#A8-!@XN#4X.*
M@UF#@`"#=X-B@U\`C8*"LP"#=X.+@W8`@WJ!6X.``(ZID>Z"S(]:CXH`CJF1
M[H+,CG,`CJF1[H+,C9$`CJF1[H+,DV288I34C88`CJF1[H+,EUB5UI34C88`
MCJF1[H+,CT*!7HRG`$AO<F1E`(FAD/P`@J*"K8+"@LR7\8+PC(N-AX*U@MR"
MMX*I@4@`@W2#0H%;@XN#:"B-<RF"S)"4@LV"HH*M@L*"Q8*W@JF!2`""HH*M
M@L*"S(US@O",BXV'@K6"W(*W@JF!2`!)34%0((.!@5N#BX-[@V*#3H-8@LR-
M[)"L@LF.N)1S@K6"W(*U@KTZ("5S`$E-05`@@X&!6X.+@WN#8H-.@UB"S(WM
MCYR"R8ZXE'."M8+<@K6"O3H@)7,`24U!4""#@8%;@XN#>X-B@TZ#6(-.@TB!
M6X->@LR-[)"L@LF.N)1S@K6"W(*U@KTZ("5S`$E0@T&#:(.,@UB"JHN6B<*"
MLX+J@KU#2412@W6#C8-B@TZ3X(+)@J""Z(+<@KF"\8%"`$E0E96-O8CAE+V"
MQ8*W@4(`@T&#0X-2@Y."S(+=`(-!@T.#4H.3@L:#98-,@UB#9P!)1(+,EKR1
M3P""X(*U@N"0LX*U@JV57(ZF@K."ZH+(@J*"R(+G@4$E<R""M8+$D%:"M8*B
M@T6#0X.3@VB!6X+PBDJ"HH+$B;J"LX*B@4(`@N""M8+@($EN=&5R;F5T($5X
M<&QO<F5R((+PCF>"P8+$@J*"Q(%!@T&#0X-2@Y."JI5<CJ:"LX+J@LB"HH+(
M@N>!08*Q@K&"\)%)D?""M8+$B;J"LX*B@4(`B>:1G(-V@XR#<H.%@5L`B>:1
MG"!54DP`B>:1G"!54DPZ`(GFD9P`@T&#:(.,@UB2H(+,@T.#DX-\@5N#9X%!
M@UB#98-B@W8@)60`@T.#DX-\@5N#9X%!@UB#98-B@W8@)60`@T&#:(.,@UB2
MH(+,@T.#DX-\@5N#9X%>@T>#3H-8@WR!6X-G`(-#@Y.#?(%;@V>"LX+J@KV#
M=(-"@5N#BX-H@48@)7,`@T.#DX-\@5N#9X*S@NJ"O8-T@T*!6X.+@VB!1@"*
MU(CA@L&"O8-!@TZ#5H.'@Y.#4H%;@VB"JI=>@J:"YX+J@L2"HH+<@K>!0@"#
MAH%;@U66O(*I@W"#6(./@5N#:(*JD+."M8*M@J""Z(+<@KF"\8%"`))IB;J"
ML(+PD%N"K0",PI7*@X:!6X-5`(-#@Y.#=(-(@X&!6X-6@X>#DP!?3XSC@NN"
MR9?Q@O"1?9/\`(GFD9R"\)%]D_P`E5R"\)%]D_P`@XJ#DX-.@O"1?9/\`%]#
MD4^"R9?Q@O"1?9/\`(R[C=V(RI)U@LR,XX+K@LF7\8+PD7V3_`",NXW=B,J2
M=8+,D4^"R9?Q@O"1?9/\`(R[C=V(RI)U@LR,XX+K@LF-<X+PD7V3_`",NXW=
MB,J2=8+,D4^"R8US@O"1?9/\`(R[C=V(RI)U@LR,XX+K@LF2:9>.@O"1?9/\
M`(R[C=V(RI)U@LR13X+)DFF7CH+PD7V3_`"1XY'6@V6#DX-V@XR!6X-G@LR1
M?9/\`(SC@NN"R8-:@XN"\)%]D_P`D4^"R8-:@XN"\)%]D_P`C.."ZX+)E_&"
M\)%]D_P`D4^"R8-:@XN"\)%]D_P`C.."ZX+)DFF7CH+PD7V3_`"13X+)DFF7
MCH+PD7V3_`",XX+K@LF-<X+PD7V3_`"13X+)C7."\)%]D_P`B>:1G(+,D7V3
M_(%>E<^-6`"#BH.3@TZ"S)%]D_R!7I7/C5@`D9>039#F@LF1EX+I@KV"WX+,
MCF.-@H*JE7.1JX*U@L2"HH+<@K>!0@".8XV"@JJ5<Y&K@L6"MX%"`)5SD+."
MR"!)1"""Q8*W`)5SD+."R(-!@VB#C(-8DJ""Q8*W`)5SD+."R(-!@W:#BH-0
M@5N#5H.'@Y."Q8*W@4(`EK.,^(+(@V:!6X->@JJ2\8]O@K."ZH+<@K6"O2X`
MD9>"Z)#F@LR#08-H@XR#6(*JE7.0LX+%@K>!0@"5<Y"S@LB#@8%;@XN#08-H
M@XR#6(+%@K<`E7.0LX+(D_R7S8+%@K<`E7.0LX+(@TR#0X*JCG>2Z(*S@NJ"
MW(*U@KV!0@"5<Y"S@LB6O)%/@L6"MP"5<Y"S@LB#28-U@U>#1H-.@V=)1"""
MQ8*W`(_CB,J"S(-!@TZ#6H-8C*""JI5SD+."Q8*W@4(`C+."S(-!@VB#C(-8
M@JJ5<Y"S@L6"MX%"`)5SD+."R'5N:6-O9&6#9H%;@UZ"Q8*W@4(`E*V-<X[2
M`([.D<P`@E",C@""5HR.`()5C(X`D;6"IH+I`)*&B9N1M8*F`)>\DEN1M8*F
M`(VVD;6"I@")19&U@J8`2V5R8F5R;W,@@U2!6X-O@JJ41H_8BY&4VX*U@MR"
MM8*]@4(`C*Z-[)"LD_H`C*Z.=Y;D`(RNDK<`C*Z.[9?>`)-DCG&,KH*J@K>"
MQ8+)C/:/3XRN@U2!6X-O@LF1MHW=@K6"W(*W@4(`3$1!4"""S(-4@WR!6X-G
M@JJ52Y=V@L6"MX*J@4%,1$%0((."@U>#A8%;@XN"JI:S@J*"J8.-@5N#:(+%
M@JN"W(*Y@O&"Q8*U@KV!0@",OHSJ`(W%CTF5SXU8`)%/B?&"S(.-@T^#0X.3
M.B`E<P"13XGQ@LR#C8-/@T.#DSH@)3(D<R""J8+G("4Q)',`D4^)\8+,@XV#
M3X-#@Y,Z((+(@K4`@XR#0X-!@T6#9P"#9H%;@UZ#>(%;@UB(ZI>7`(-W@XN#
M=HV`EMJ"\)5<CJ:"MX+I`)5<@LR(ZI>7`(.&@5N#58+,@XJ#6(-G@LV6LXSX
M@LF"R(+!@L2"HH+<@K>!0@"2;HCF@L:.GHK4`(_JCXH`@XV#3X-#@Y,`@XV#
M3X-!@T6#9P"#C8-/@T.#DR"#7H-8@TX`@X:!6X-5EKR"J8-P@UB#CX%;@VB"
MJI"S@K6"K8+(@J*"O8+?@LF#C8-/@T.#DX+)CKB4<X*U@MR"M8*]@4(`@XV#
M3X-#@Y."R8ZXE'."M8+<@K6"O8%"`(--@XJ#5H.#E;:.FH%ICZR5MHZ:@6H`
M@XF#98.3E;:.FH%ICZR5MHZ:@6H`@XV!6X-]D)2.FH%ICZR5MHZ:@6H`C(X`
MDUF5=(*S@NJ"O2!-4RU43D5&((+-@V:!6X->@O"*W(+Q@L6"HH+<@KF"\8%"
M`)-DCG&#@8%;@XL`D$:5=(*O@K."ZH*]@XF#>(.+@O"1SHF>@K."N8+$E:J7
MWH+PBL>7G8*U@MR"MX%"`()2C(X`@JJ.GX+)B.J2=H*W@ND`@W2#0H%;@XN#
M:(+PB.J2=H*S@KF"Q(*B@MR"MP"-Q9'E@LR#>8%;@U>0E`""5(R.`(.!@Y.#
M;P"#@8-J@X6!6X."@5N#:`"#6H.+C(N-AP"6>Y6V`(.!@V*#6H%;@U>"S8R?
MC]B"Q8*K@MR"M8*]@JJ!08^0EKR.TH+,D&>,LX+-C)^/V(+%@JN"W(*Y@O&"
MQ8*U@KV!0@"#@8-<@V*#:`!-:6UE(%1Y<&4`BLB(U8R?C?4`D-V2Z(*J@J""
MZ(+<@KF"\8%"@K&"S(-!@W:#BH-0@5N#5H.'@Y."\(YGEW""MX+I@KV"WX+)
M@LV0W9+H@O"-[)"L@K>"Z95+EW:"JH*@@NB"W(*W@4(`C(X`C&>1T8.!@5N#
MBP",9Y'1DV288@"/0Y"SD_H`E<^-6(ZXE',Z("@E<RD@)7,`EHB,C@""4(+"
MB,B/XX*@@NB"W(*W`(C:DZX`B;J"U@"-MH+6`(E%@M8`C^."U@")NH+6`(VV
M@LF(VI.N`(E%@LF(VI.N`(_C@M8`375L8F5R<GD@C&".KH+,@T&#:(.,@UB2
MH`"#08-*@T6#DX-G`).OB-."M8+<@KF"\0"6O)%/`):\D4^"S(Q@CJX`3F5T
M8V5N=&5R((.!@Y.#;X%;@LR0;):\E>L`@VR#8H-G@X^!6X-.`(+(@K4`D%:+
M2Y6JE]X`D%:+2YA!EXV0Y@"05H*U@J*#AH%;@U66O"B40XC3*0".GP"#:H-B
M@TZ#;(%;@X``)7,@@LT@)7,@@LF"H(+H@MR"N8+Q`(-!@VB#C(-8DJ""JHRI
ME72"J8+H@MR"N8+Q@4(`C;>5JH+PE5R.IH*W@NF"O8+?@LR0W9+H@JJ"H(+H
M@MR"N8+Q@4(`E<^-6(+(@K6!0@""L8+,@T&#3H-:@UB,H(+)@LV#5(-U@T&#
M3H-:@UB,H(+-DL>)P8+%@JN"W(*Y@O&!0@!&5%`@5D93((+,C5R0K(_NE?&"
MJHYWDNB"LX+J@L2"HH+<@KF"\8%"`%-13"!61E,@@LR-7)"LC^Z5\8*JCG>2
MZ(*S@NJ"Q(*B@MR"N8+Q@4(`4U%,((-*@V6#4X.*@LR-7)"LC^Z5\8*JCG>2
MZ(*S@NJ"Q(*B@MR"N8+Q@4(`F$&7C9#F@JJ,J95T@JF"Z(+<@KF"\0".8XV"
M@JJ"H(+H@MR"N8+Q@4(`D9>039#F@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@"#
M@8-B@UJ!6X-7@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@"6O)%/@JJ.=Y+H@K."
MZH+$@J*"W(*Y@O&!0@"4U(V&@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@!(5%10
M()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@!)34%0()1&C]B"S(-P
M@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@!+97)B97)O<R"41H_8@LR#<(-8@X^!
M6X-H@JJ"H(+H@MR"N8+Q@4(`@XV#3X-#@Y,@E$:/V(+,@W"#6(./@5N#:(*J
M@J""Z(+<@KF"\8%"`%!!4U-71""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"
MN8+Q@4(`4TU"()1&C]B"S(U<D*R/[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!
M0@!/<&5N4U-,((-V@XV#3X.)@X""S(-P@UB"JHYWDNB"LX+J@L2"HH+<@KF"
M\8%"3W!E;E-33"""S2!02T-3(#$R((+,@V:!6X->@O"(M8*D@LR"R95+EW:"
MQ8*W@4(`E=N7KX+,@U2#0X.3@T&#8H-V@LB"M8%"`(.&@5N#59:\@JF#<(-8
M@X^!6X-H@JJ1EX+G@NJ"W(*Y@O&"Q8*U@KV!0@!V0V%R9""#9H%;@UZ"JHRI
ME72"J8+H@MR"N8+Q@4(`EK.,^(+,6$U,@V:!6X->@JJ5U(+H@MR"M8*]`))L
M@LB"M0",LX+,D-V2Z(+)@V^!6X-7@X>#DX*J@J""Z(+<@KF"\8%"C<23>)#=
MDNB"\)"VD*R"M8+<@K>!0@""H(+(@KV"S)#=DNB"R8-O@5N#5X.'@Y."JH*@
M@NB"W(*Y@O&!0HW$DWB0W9+H@O"0MI"L@K6"W(*W@4(`@LB"M0""L8+J@N:"
MZ)%/`(*Q@NJ"YH+HC.,`DHV+3``Q,8R.`#&#>8%;@U>"S(V`EMJ0E`"1EY!-
MD.:#BH-8@V>"\(U8D%:"O8+?@LR4U(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"
MO8%"`$]+`(-)@W6#5X-&@TZ#9P"#28-U@U>#1H-.@V>-[)"LCM(`@TF#=8-7
M@T:#3H-G@JJ,J95T@JF"Z(+<@KF"\0`Q,(R.`(GOCM``BZ273(-T@TB#BX-?
M@LT@24U!4""#5(%;@V^"OH*O@JJ#5(-\@5N#9X+%@JN"W(*W@4(`DV2.<8.!
M@5N#BX-!@VB#C(-8@LTQ@L*"OH*OCG>2Z(+%@JN"W(*W@4(`CXJ73([2@JF#
M5H-8@V6#@(K'EYV.TH*^@J^"JHNDETR"S(^*ETR,H(+&@T&#3H-:@UB,H(+P
ME<^-6(+%@JN"W(*W`)!6BTN#18-#@Y.#:(%;@LF57(ZF`$]P96Y34TP@@T>#
MB8%;@493+TU)344@CY"6O(*S@NJ"O8-P@5N#9X*I@N>#9H%;@UZ"\([F@NB/
M;X*Y@MR"N8+Q@L6"M8*]@4(`@TF#=H-6@X>#DP`E<R"#28-V@U:#AX.3`(^'
MCYB5=(.*@UB#9P"19Y!$`)64CY``D*Z7G0",LX+,@T&#=H.*@U"!6X-6@X>#
MDX-E@Y.#=H.,@5N#9P"1O(+,@T.#DX-T@TB#@8%;@U:#AX.3`(*[@LR1O(+,
M@TF#=H-6@X>#DP"/BI=,CM*"S(-!@TZ#6H-8C*``4$%-()1&C]B"S8YGEW""
MQ8*K@MR"N8+Q@4(`4$=0()-DCG&/D):\`%!'4""(PXV&E;8`4$=0((SVBDJ,
MK@!01U`@CY"6O(W/+XC#C8:)NX-F@5N#7@!02%"#4H%;@V@`4$A0@U:#1H.+
M`):$D9``@W"#6(./@5N#:`"#<(-8@X^!6X-H@JJ0LX*U@JV"H(+H@MR"N8+Q
M`%)!1$E54R"41H_8@LR#<(-8@X^!6X-H@JJ52Y=V@L6"MX%"`(-P@UB#CX%;
M@VB"S(IME$8`@W"#6(./@5N#:#H`@W"#6(./@5N#:#H@`(-P@UB#CX%;@VB"
MJHCJDG:"M8+<@KF"\8%"`)-<@NB5=(*O`)-<@NB5=(*O`)7;EZ^2AH+,@U2#
M0X.3@T&#8H-V@48`@W"!6X-:@Y.#9P"5VX[GD8"-[(+PCL"-<X*W@ND`@XV#
M3X-#@Y..GH+)E=N.YY&`C>R"\([`C7."M8+<@K>"J8%(`(-!@TZ#6H-8C*``
M@T&#3H-:@UB"JHN1E-N"LX+J@MR"M8*]`(-!@TZ#6H-8@JJ+D93;@K."ZH+<
M@K6"O0"#08-.@UJ#6(R@@LR*QY>=`(S"D&R/[I7Q`)-DF&(`4&EN92",8(ZN
M@LR#08-H@XR#6)*@`(-S@TZ#6H.+`(R.@L:43H+PD_R7S8*U@L2"K8*^@K."
MHH%"`)!6@K6"HI6JE]Z"S):\D4^"\)/\E\V"M8+$B;J"LX*B.@"0LX*U@J*3
M^I5T@O"3_)?-@K6"Q(*M@KZ"LX*B+B",CH+,D_J0E(+P@V"#1H-B@TZ"M8+$
M@JV"OH*S@J*!0@"/X8I1D^"798+PEW:6\8*U@L2"LHM,D_R"K8*^@K."HH%"
M`(.&@5N#59:\@L:#<(-8@X^!6X-H@O"3_)?-@K6"Q(*M@KZ"LX*B@4(`DXJ5
M6Y"4`%!R969S7VQD87`Z()5+EW:"R$Q$05"*9Y*CBT"47(*JC*F"PH*I@NB"
MW(*Y@O&!0@!0<F5F<U]L9&%P.B"52Y=V@LAS97-S:6]NBF>2HXM`E%R"JHRI
M@L*"J8+H@MR"N8+Q@4(`@W:#C(-R@X6!6P"05H*U@J*#18-#@Y.#:(%;@LF)
MYI&<@O"57(ZF`(CSC?P`C,*0;)-)@T&#:(.,@UB2H`"4Z9:GC*X`C^&*40"/
MX8I1D^"798+,D."6O@",]HI*C*X`C/:/3XRN@T&#BX-3@XJ#68.``(SVCT^,
MKB^4Z9:GC*Z"JI"VD*R"Q8*K@MR"N8+Q@L6"M8*]@4(`@TZ#1X.*@5L`EN*"
MHHV'@NV"N8ZXE',Z("@E<RD@)7,`BLB(U8R?C?4`4E-!C/:/3XRN*"5D@W*#
M8H-G*0"4Y`"3QX+>`)/'C9Z"W8ZXE',Z("@E<RD@)7,`EGN3EH+)("5S((+P
MC>V/G(*U@MR"MX*I/R""L8+,D8"-[(+-C+."R9;?@KF"W(*Y@O&!0@"6>Y.6
M@LF#AH%;@U4@)7,@@LR#9H%;@UZ"\(WMCYR"M8+<@K>"J8%(((*Q@LR1@(WL
M@LV.YH+HC\&"N8+<@KF"\8%"`(+B@NB2O(*W`).NDTF#@8-J@X6!6X+,C<25
M7(ZFBM2*=3H`@WR!6X->@XN"S(W$E5R.I@"#BH."@5N#9X-4@5N#<H-8`(.*
M@X*!6X-G55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H@`(WM
MCYP`@W6#C8-B@TZ"\(WMCYP`E_&"\(WMCYP`@XJ#6(-G@JF"YXI/@K<`@WF#
M08+PC>V/G`"#AH%;@U6"\(WMCYP`@X:!6X-5@O"-[8^<.B`E<P"7=HN!@LF5
MU).:@L6"JX+<@KF"\3H@`)=VBX&"LX+J@KV#28-U@U>#1H-.@V>"S8RIE72"
MJ8+H@MR"N8+Q@L6"M8*]@4(`@XJ#6H-B@V<`@V:#=(-(@XN#9X+)EM^"MP",
MBXG*`(-)@W:#5H.'@Y."R9;?@ND`C+."S(U<D*R"R9;?@K<`@V6#3(-8@V>#
M1X-F@T*#7H%;@LR#28-V@U:#AX.3`);PBH0`C7.1KI"K`(USD:Z0JP"-<X%&
M`([`C7,`4R]-24U%((C#C8:/D):\`%,O34E-12"(PXV&E;8`4R]-24U%((SV
MBDJ/V):^CY$`4T%33""41H_8@LV.9Y=P@L6"JX+<@KF"\8%"`%-13""#5H-&
M@XL`4U-(`)-Y`)7;D;8`)7,@@O"5VY&V`(-)@W:#5H.'@Y."\)7;D;8`)7,@
MD-V2Z(+PE=N1MH*U@MR"M8*]@4(`C)^-]0",GXWUCKB4<P",GXWUCKB4<SH@
M)7,`C)^-]9*&("XN+@"3^I5T@O".=Y+H@K6"Q(*M@KZ"LX*B@48`DL>)P8*W
M@NF#3X.+@5N#=H+PD4F1\(*U@L2"K8*^@K."H@"05H*U@J*/BHZ=CM*"\)%)
MD?""M8+$@JV"OH*S@J(`@U2!6X-O@O"129'P@K6"Q(*M@KZ"LX*B`)+'B<&"
MMX+I@X:!6X-5@O"129'P@K6"Q(*M@KZ"LX*B`(-'@TZ#6(-\@5N#9X*W@NF#
M08-H@XR#6)*@@O"129'P@K6"Q(*M@KZ"LX*B.@"#0X.3@WR!6X-GD.:"S(-!
M@VB#C(-8DJ""\)%)D?""M8+$@JV"OH*S@J(Z`)5+EW:"R)6VCIJ"\(FZ@LR#
M>X-B@TZ#6(*I@N>128+Q@L6#4H-S@5N"MX+I@L:!08-E@TR#6(-G@T>#BH-!
M@M:#>8%;@UB#9X+%@JN"W(*W@4(`D_J5=(+,B^:0V(+HE;:.FH+PCG>2Z(*U
M@L2"K8*^@K."HH%&`)/ZE72"S(Q@CJZ"\(YWDNB"M8+$@JV"OH*S@J*!1@"#
M1X-.@UB#?(%;@V>"MX+IC&".KH+PD4F1\(*U@L2"K8*^@K."HCH`@T.#DX-\
M@5N#9X*W@NF#=(-`@T.#BX+PD4F1\(*U@L2"K8*^@K."HCH`C+."S(-T@T"#
M0X.+@LR,8(ZN@O"129'P@K6"Q(FZ@K."HCH`E5R.IH+,C&".KH+PD4F1\(*U
M@L2"K8*^@K."HCH`E<^-6(*U@KV"HDE$@O"129'P.@".GHV/@LR+YI#8@NB5
MMHZ:@O".=Y+H@K6"Q(*M@KZ"LX*B@48`CIZ-CX+,C&".KH+PCG>2Z(*U@L2"
MK8*^@K."HH%&`(CJDG:"MX+I@E&"PH+,@W2#0H%;@XN#:(+PD4F"\8+%@JV"
MOH*S@J*!0@"#08-H@XR#6(+,B.J7EX+%E5R.IH*W@NF7\8+PD4F1\(*U@MR"
MMX%"`):\D4^"S)5<CJ:,8(ZN@O"129'P@K6"W(*W@4(`D$:2LH+PD4F1\(*U
M@L2"K8*^@K."HBX`C+Z,ZH+PD4F1\(*U@L2"K8*^@K."HCH`C^&*48.,@WR!
M6X-G@O"1EY!-@K>"Z0!335,@D9>030""6(R.`)+*E-0`@WR!6X->@XN"Q8-!
M@TZ#6H-8@K>"Z8.*@X*!6X-G@U2!6X-O@O"0W9+H@K6"W(*W@4(`C+Z,ZH%!
MCIZ*U)'1@4&3^I5T@O"0W9+H@K6"W(*W@4(`BDJ.;HZ>@LR#08-V@XJ#4(%;
M@U:#AX.3@4&01I*R@4&#>8%;@U>-Q)5<CJ:!08*[@LR1O(+,E5R.IH-)@W:#
M5H.'@Y."\)%)D?""M8+$@JV"OH*S@J(N`(NDETR"S)!LEKR5ZP"*R))0@LB7
M=I;Q@48`@6F#@8-J@X6!6X+(@L>"Q8%J@U:#AX%;@V>#2H-B@V>#3(%;@JJ.
M9X*F@NF"YH*D@LF"M8+<@K>"J8%(`)5<CJ8`D5."Q)5<CJ8`F$&7C9#F@LR5
M7(ZF`(.*@UB#9X+,E5R.I@"#C8-/@T.#DXZ>@LF13XGQ@LR#C8-/@T.#DXZ>
MBM2"\)5<CJ:"M8+<@K>"J8%(`)5<D8"-[(.!@VJ#A8%;@O"57(ZF@K6"W(*W
M@JF!2`")YI;*C;:"R2`E<R"#@8-J@X6!6X+PE5R.IH*U@MR"MX*I@4@`CVN/
MK`""W(*XE]>"Z(+,@W6#C8-B@TZ"\(]KCZR"W(*]@LV(VI.N@K."N8+$@JV"
MOH*S@J*!0@"#5(-#@Y.#08-B@W8`DV2.<8^0EKP`DV2.<8^0EKR#08.+@U.#
MBH-9@X``@U2#0X-9`)7;CN>"\(-8@TR#8H-V@K>"Z0"5P(+1CX<`D9>038RS
M@T&#:(.,@U@`@UR!6X-8`)==E)(`EUV4DH+&EH21D`"3P8[JE;:.FH+,D_R7
MS0"/VHW7C)^-]8+,C(N)RH+P@L>"L8+)E5R.IH*W@NF"J8YWDNB"M8+$B;J"
MLX*B@4(`CT*"W(*]@LV,IP"/\Y'4`(]:CXJ4U))N`([FC\&"M9#\`(-8@UZ#
M0X.+(%M#4U-=`)/Z`([`C7,`B;J5=(*K`)"LC/<`)7,@@LT@)7,@@LF2QXG!
M@K."ZH+<@K6"O0`E<R""S8^1@JN-GH+<@NJ"W(*U@KT`BE27=@"/XY5T@JL`
MD*D`5%-6@W2#0(-#@XL`@UZ#=8OFD-B"Z(Q@CJX`E5P`E5R1KI"K`)5<D:Z0
MJP"#7H-8@TX`DV288I34C88`@V6#3(-8@V>"S(+=`)6VCIJ4>I)U`);8`(*R
MEYB7<(*@@NB"JH+&@J2"LH*T@J*"W(*U@KV!0@!&5%`@BF>2HX*J@J""Z(+<
M@KF"\8%"`$UA:6YT96YA;F-E((-.@XF#6(+,D\>-GH+=@JJ0LX_M@LF-<X*F
M@MR"N8+Q@L6"M8*]`(-)@W:#5H.'@Y.#18-"@Y.#:(-%@O"5PH*V@MR"M8*]
M@4*/29>Y@K6"W(*W@4(`@T&#:(.,@UB2H(+PC\&+CH+%@JN"W(*Y@O&"Q8*U
M@KTZ("5S`(-!@TZ#6H-8C*""\)=,C/B"R8*W@NF"R8+-BL>7G8[2@JJ"NX+,
M@V^#8H-.@T>#DX-H@O"0W9+H@K>"Z8*Q@L:"JI5+EW:"Q8*W@4(`F$&7C9#F
M2424U(V&@JJ.=Y+H@K."ZH+(@JF"P8*]@JF!08OS@KZ"P8*]@JF!08*@@NF"
MHH+-@V:!6X->@WB!6X-8DH:"R8RIE72"J8+H@MR"N8+Q@L6"M8*]@4(`EW:+
M@8*S@NJ"O9A!EXV0YH+-D;:-W8*U@MR"N8+Q@4(`DV2.<8^0EKR"LX+J@KV#
M@8-B@UJ!6X-7@O",GX_8@K>"Z8+)@LV!05!'4""/D):\@JJ52Y=V@L6"MX%"
M`)&7D$V0YDE$E-2-AH*JCG>2Z(*S@NJ"R(*I@L&"O8*I@4&+\X*^@L&"O8*I
M@4&"H(+I@J*"S8-F@5N#7H-X@5N#6)*&@LF,J95T@JF"Z(+<@KF"\8+%@K6"
MO8%"`)&7D$V0YDE$E-2-AH*JCG>2Z(*S@NJ"W(*Y@O&"Q8*U@KV!0@"(PXV&
MB;N"R8+-B,"14X+(@T6#1H-UD-J1L8*JE4N7=H+%@K>!0@"#=(-`@T.#BX*J
M@V:!6X->@O"*W(+Q@L6"HH+<@KF"\8%"`)*-B-.!22"#=(.+@UB#3H.*@5N#
MDX."@5N#:(+-($EN=&5R;F5T($5X<&QO<F5R((+%@LV6XI'H@JJ4K9"V@K>"
MZ8*Q@L:"JH*@@NB"W(*W@6F#=8.)@T6#58+,@V^#3X+%@K>!:H%"B>:6RH+)
M@U.#?H*JE5R.IH*S@NJ"O8+H@4%7:6YD;W=S((*J@TZ#B8-B@U:#A8*U@KV"
MZ(*W@NF"J8+@@K6"ZH+<@KF"\8%"7&Z#=(.+@UB#3H.*@5N#DX."@5N#:(+)
M@K>"Z8+(@N<@3TL@@O")GX*U@L2)NH*S@J*!0@!)1"`B)7,B((+-C>V/G(*S
M@NJ"W(*U@KV!0@!';G501R"#;X-#@VF#BH+,@W"#6(*J($-R>7!T7W!G<""#
M3H.)@UB"R9#=DNB"LX+J@L2"HH+IE4N7=H*J@J""Z(+<@K>!0@!(;W)D95]#
M<GEP=%]S;6EM98-.@XF#6(+)@LUO<&5N<W-L@X*#5X.%@5N#BX*JE4N7=H+%
M@K>!0@"#=H.,@W2#0(.,@Y.#6"(E<R*"S8-F@5N#7H*J@U2#0X-9D*>,P(+P
MB7J"IH*]@KV"WY7;D;:"Q8*K@MR"N8+Q@L6"M8*]+@""L8+,@V:!6X->C%XH
M)7,I@O"57(ZF@K>"Z8*]@M^"S(-V@XV#3X.)@X""JH*Q@LR#5H-8@V6#@(+)
M@MV"PH*I@NB"W(*Y@O&!0@"#5(%;@V\@(B5S(B""S8WMCYR"LX+J@MR"M8*]
M@4(`@U2!6X-O("(E<R(@@LV5VY&V@K."ZH+<@K6"O8%"`(-!@V*#=H.-@5N#
M:(-F@5N#7H*JDKR13X+,@UB#98-B@W:"Q8_!CKB"M8+<@K6"O8%"`(-!@V*#
M=H.-@5N#:(-F@5N#7H+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0@")>Y>7B<*4
M7(+(@T&#:(.,@UB2H(+-@J""Z(+<@KF"\8%"`(-#@Y.#B8-#@Y.57(ZF@L6"
MJX+IE925JH+-@J""Z(+<@KF"\8%"`(^1@JN-GH+=B<*47(+(@T&#:(.,@UB2
MH(+-@J""Z(+<@KF"\8%"@J""R(*]@JJ05H*U@J*-@);:@O"2QXG!@L6"JX+I
M@N:"I(+(@T&#:(.,@UB2H(+-EW"(TX*S@NJ"Q(*B@MR"N8+Q@4*"NX+J@JJ*
MU(CA@J*"OH+&CG:"I(+(@N>!08-6@UB#98.`BL>7G8[2@LF"J);B@J*-AX+M
M@KF"K8*^@K."HH%"`)6VCIJ0E(*J@K&"S(-T@T*!6X.+@VB"R9&]B=^"K(+<
M@K<N("5S((+,E;:.FH*JD_R7S8*S@NJ"Q(*B@MR"MRX@)7,@B,B)NH+%@LB"
MK8+$@LV"HH*O@MR"N8+Q@4(`@W2#0(-#@XN#08-B@W:#C8%;@VB"R9;BD>B"
MJI2MD+:"M8+<@K6"O3H@)7,@@LV#08-B@W:#C8%;@VB"LX+J@L2"HH+<@KF"
M\8%"`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ
M("5S((+-@W2#0(-#@XN"S(-4@T.#69"GC,"2;"@E9(-O@T.#9RF"\(EZ@J:"
MQ(*B@MR"MX%"`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"
MW(*U@KTZ("5S((+-B.J5E(+,@MV#08-B@W:#C8%;@VB"LX+J@MR"M8*]@4(`
MF$&7C9#F@LR2QXG!DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4*/VHW7@LF"
MPH*B@L2"S8-6@UB#98.`BL>7G8[2@LF"J);B@J*-AX+M@KF"K8*^@K."HH%"
M`)!6BTN#BH-8@V>-[)"LCIZ"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4(`@K&"
MS)A!EXV0YH+,C>V/G)*&@LF#1X.)@5N"JH*@@NB"W(*U@KTZ("5S`(-)@W6#
M5X-&@TZ#9XWMCYR2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0@"809>-D.:#
M9H%;@UZ"S(-#@Y.#?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0@"#
M9H%;@UZ"S(-#@Y.#?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KTZ("5S
M`&E#86QE;F1A<B""S(-#@Y.#?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U
M@KV!0@".=Y+H@K."ZH*]@T&#:(.,@UB2H(+,D8"-[)*&@LF#1X.)@5N"JI2M
MD+:"M8+<@K6"O8%"C.."Q8W$DWB.P(US@K6"Q(*M@KZ"LX*B@4(`F$&7C9#F
M@LR/VHW7@O"-6)!6DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4*,XX+%C<23
M>([`C7."M8+$@JV"OH*S@J*!0@"1EY!-D.:#BH-8@V>"S(U8D%:2AH+)@T>#
MB8%;@JJ4K9"V@K6"W(*U@KV!0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K."HH%"
M`(*Q@LR-@);:@LR-6)!6DH:"R8-'@XF!6X*J@J""Z(+<@K6"O3H@)7,`@T>#
M3H-8@WR!6X-G@K>"UX*K@T&#:(.,@UB2H(*J@J""Z(+<@KF"\8%"`(*Q@LP@
M24U!4""#5(%;@V^"S8NDETR#=(-(@XN#7X+P@U2#?(%;@V>"M8+$@J*"W(*Y
M@O&!0@""L8+J@LV73(SX@LAR87*#08%;@TJ#0X-U@L6"S8+(@J*"YH*D@L6"
MMX%"`(*Q@NJ"S9=,C/B"R'II<(-T@T"#0X.+@L6"S8+(@J*"YH*D@L6"MX%"
M`(*Q@NJ"S9=,C/B"R(-*@5N#:)34C8:"Q8+-@LB"HH+F@J2"Q8*W@4(`@K&"
MS(-T@T*!6X.+@VB"S95+D'N"Q8*W@4(`@K&"S(-T@T*!6X.+@VB"S9"ND)2"
MQ8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L:#
M4H.-@Y."Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LTX
MD&F0E(+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S8-2
M@Y.#?8+<@KV"S8OSE)*"Q8OFD-B"YX+J@KV0KI"4@LR#BH-8@V>"Q8+(@JV"
MQ(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LTQ-I!I4D="E5R+3(+,
MD$:#4H%;@VB"R(*M@L2"S8*B@J^"W(*Y@O&!0I?A.B<C,3(S-&%F)RX`@K&"
MS(Q@CJZ"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!0@""L8+,@W2#2(%;@X""
MS8KY@LF/B)>=@K."ZH+$@J*"W(*W@4(`@K&"S(.!@V*#6H%;@U>"S8*@@LB"
MO8*JCF>7<(*W@NF"S(+&B-F"R(+IE;:.FH-:@V*#9X%I)7.!:H+%CY&"J8+J
M@L2"HH+<@K>!0@""L8+,E-2-AH+-C<6/K(+%@N`Q@L6"R(*M@L2"S8*B@J^"
MW(*Y@O&!0@""L8+,D&R5J(+-@K>"Q8+)@T&#:(.,@UB2H(+)("5S((+&@K6"
MQ)-OF%Z"LX+J@L2"HH+<@K>!0@""L8+,@U2!6X-O@L6"S7II<(+&9WII<(-T
M@T"#0X.+@O"35XI*@L6"JX+<@KF"\8%"`(*Q@LR#5H-8@V6#@(+-B.J.GI-)
M@LF6LXSX@LF"R(+!@L2"HH+<@K>!0@""L8+,DFR"S9"4CIJ"Q8+(@J^"ZH+.
M@LB"Z(+<@KF"\8%"`(*Q@LR#18-"@Y.#:(-%@LV#28-V@U:#AX.3@T6#0H.3
M@VB#18*I@N>,Q(]O@K."ZH+IE4N7=H*J@J""Z(+<@K>!0@"#7H-#@X"#5H%;
M@V<`C*B/D0"5H9"4@LR-@);:@O"129'P@K>"Z8+)@LV!05!#@L6"S4-O;G1R
M;VR#3(-#@4%-86."R(+G0V]M;6%N9(-,@T."\(F?@K6"R(*J@N>#3H.*@V*#
M3H*U@MR"MX%"`(G.`%523`!61E,@@W2#0(-#@XL@(B5S(B""S(-!@TZ#6H-8
MC*""S97/C5B"Q8*K@MR"N8+Q@4(`5D93((-T@T"#0X.+("5S+R5S((+,@T&#
M3H-:@UB,H(+-E<^-6(+%@JN"W(*Y@O&!0@`E<R""R97/C5B"Q8*K@MR"N8+Q
M@4(`4U%,((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!0@!34TP@@L60VI&Q@L6"
MJX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+P@U*#<X%;@L6"JX+<@KF"\8%"`%9&
M4R"#9H-"@XR#3H-G@XH@(B5S(B""\(WLD*R"Q8*K@MR"N8+Q@4(`5D93((-F
M@T*#C(-.@V>#BH+PC>R0K(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XN"\(WL
MD*R"Q8*K@MR"N8+Q@4(`B_."S"!61E,@@W2#0(-#@XN"\(WLD*R"Q8*K@MR"
MN8+Q@4(`@V:!6X->@O"(LX]K@L6"JX+<@KF"\8%"`"(E<R*"\(WMCYR"Q8*K
M@MR"N8+Q+B"#9H-"@XR#3H-G@XJ"JHOS@L6"S8*@@NB"W(*Y@O&!0@`E<X+P
MC>V/G(+%@JN"W(*Y@O$N((-F@T*#C(-.@V>#BH*JB_."Q8+-@J""Z(+<@KF"
M\8%"`(_8EKZ/D8+,C]J-UX*JCN:"Z(]O@KF"W(*Y@O$`)7,@@LR2Z(M@@O"#
MC8%;@VB"Q8*K@MR"N8+Q@4(`B+./:X^1C,F#=(-`@T.#BX+PBDJ"KX+<@KF"
M\8%"`'9F<W)O;W0@@V:#0H.,@TZ#9X.*@O"3QX+?@MR"N8+Q@4(`@K&"S"!7
M;W)D()6VCY&"\)9\EO."Q8*K@MR"N8+Q@4(`B;J0_`"5SXU8@O".YH+HC\&"
MMP",LX+)EM^"MP"6HI"NEYT`E7.6O@"6LY:\`(-4@WR!6X-G@K6"Q(*B@LB"
MHHIGDJ..<8+%@K<`C5B05@`E<R""\(U8D%:"MX+I@4(`@X:!6X-5@O"-6)!6
M@K>"Z0"#B8-E@Y.5MHZ:@6F1Y96VCIJ!:@"#C8%;@WV0E(Z:@6F1Y96VCIJ!
M:@",NXW=@LR2;(+PCF>7<(%&)7,`24U34""#5(%;@V^"S(.&@5N#59:\@5Z#
M<(-8@X^!6X-H@JJ(V8+(@NF/ZHV'@LF.9Y=P@K6"W(*W@4(`@X:!6X-5BL>7
MG0"#AH%;@U6#28-V@U:#AX.3`(.&@5N#59-OF%X`@X:!6X-5EKP`@X:!6X-5
MEKPZ`(.&@5N#59:\.B``@U:#6(-E@X"2AH+,@X:!6X-5@48`BWB)R0"73(SX
MD*L`C)^/V(ZXE',@+2""L8+,@X&#8H-:@5N#5X+-B?SB@H*S@NJ"Q(*B@NF"
MYH*D@L6"MX%"`%9E<FES:6=N(([0@LR0;):\E>L`E,4`)7,@@O",J8+I`)A!
MEXV0YH+PE5R.I@"#9H-T@TB#BX-G@LR57(ZFB>:6RCH`C'B-D`"0A0!796(@
M@LP@55),`):(CU0`@N:"I(*Q@KL`)7,@@LF"YH*D@K&"NP`E<R""LX+Q@4&"
MYH*D@K&"NP`E<X.-@T^#0X.3C.."QX+,@T&#=H.*@U"!6X-6@X>#DX+PE5R.
MIH*U@MR"MX*I@4@`B^:0V(+HE;:.FH+-B;V"Q8*W@JF!2`"(^)=PE;:.FH+-
MB;V"Q8*W@JF!2`"#98-,@UB#9X-'@V:#0H->@5N"S(-V@XF#3X-#@Y."\)%)
MD?""M8+<@K>!0@"5G0"-MH+)DG6"K25S@X&#:H.%@5N"S)6=@6F.GXGQ@LR#
MC8-/@T.#DX*I@N>73(SX@6HZ`)5<@LR5G0"+SI:QD.:"S(]:CXH`B\Z6L9#F
M@LR.<P"+SI:QD.:"S(V1`(O.EK&0YH+,DV288I34C88`B\Z6L9#F@LR76)76
ME-2-A@"+SI:QD.:"S(]"@5Z,IP!8-3`Y=C,@BNZ6>Y"GC,``6#4P.78S((RN
MCF>7<)9``%@U,#EV,R".Y9',CM*"S)7*EKP`6#4P.78S(([ED<R.TH+,C*Z.
MKY7*CG$`6#4P.78S((IGDJ.+0)1<`)1.`)1.`):(E$X`@LV"H@"3KXC3@K6"
MW(*W`(VA@LV#98-,@UB#9X."@5N#:(+%@K>!0EL\/EV#>X->@Y."Q4=528."
M@5N#:(+)E<^-6(+%@JN"W(*W@4(`@J""R(*]@LV41H_8@K."ZH+$@J*"W(*Y
M@O&!0@"6O)%/@LR2AH+)("=<)R""QH*B@J25MHZ:@LV.9X*F@MR"N8+Q@4(`
METR,^(+(DV2.<8.!@5N#BX-!@VB#C(-8@L6"S8*@@NB"W(*Y@O&!0@"#0X.3
M@WR!6X-G@K."ZH*]@W2#0(-#@XN"S(-T@T*!6X.+@VB"\"5SD^""S)'.B9Z"
MMX+I@W2#0H%;@XN#:(+)@WV#8H-V@K6"Q(+<@KF"\2X`@J""R(*]@LV"L8+,
MF$&7C9#F@O",J8+IC*"7F(*J@J""Z(+<@KF"\8%"`(*@@LB"O8+-@K&"S(-)
M@W6#5X-&@TZ#9X+PC*F"Z8R@EYB"JH*@@NB"W(*Y@O&!0@"#C8-/@T&#18-G
M@K6"W(*U@KTN`)"S@K6"HI)L@O"3_)?-@K6"Q(FZ@K."HH%"`(-4@T.#DX-!
M@V*#=H+PEYB7<(*W@NF"O8+?@LF"S2!$871A5')E92"#;X-B@TZ#1X.3@VB"
M\)#=DNB"MX+IE4N7=H*J@J""Z(+<@K<N`(_ABE&"S)/@EV6"\(M,CW&"M8+$
M@JF"YX%!C^&*48.,@WR!6X-G@O"1EY!-@K6"Q(*M@KZ"LX*B@4(`@K&"L8+)
M@XJ#DX-.@K>"Z5523(+PD_R7S8*U@L2)NH*S@J(`EMJ328+,@T&#:(.,@UB2
MH(+PD4F"\8+%B;J"LX*B@4(`EMJ328+,@XJ#6(-G@O"128+Q@L6"K8*^@K."
MHH%"`(WMCYR"MX+I@U2!6X-O@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`CZV"R(*M
M@L:"X()0@L*"\)%)@O&"Q8*M@KZ"LX*B@4(`C\&+CH*W@NF#AH%;@U66O(+P
MCG>2Z(*U@L2"K8*^@K."HH%"`(WMCYR"MX+I@X:!6X-5EKR"\(YWDNB"M8+$
M@JV"OH*S@J*!0@"2QXG!@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B
M@4(`C5B05H*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"`([`C7."
MMX+I@T&#3H-6@X>#DX+PCG>2Z(*U@L2"K8*^@K."HH%"`)!6@K6"HI6JE]Z6
MO(+PD_R7S8*U@L2)NH*S@J*!0@""H(+(@KV"R8+-@K&"S)A!EXV0YH+PC*F"
MZ8*^@J^"S(R@EYB"M8*I@J""Z(+<@KF"\8%"`"5S((-:@V*#5H.'@Y."S)=,
MC/B*^HS`@JJ0V(+J@L2"HH+<@K>!0HW$@XV#3X-#@Y."M8+$@JV"OH*S@J*!
M0@"39(YQ@X&!6X.+@T&#:(.,@U@`@J""R(*]@LP@1G)O;3H@@T&#:(.,@U@`
M@J""R(*]@LR#0X.3@W2#2(.!@5N#5H.'@Y,`@UJ#8H-6@X>#DR`E<R""S(K4
M@LF"H(+(@KV"S(-!@VB#C(-8@JJ5SXU8@K."ZH+<@K6"O8%"@UJ#3(.%@XJ#
M98-"@5N5VXSL@LR"O8+?@LF#C8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(`@J""
MR(*]@LR6O)%/`(*Q@LR41H_8@V^#8H-.@T>#DX-H@L6"S8%!@X:!6X-5@LR#
MBH-8@V>"JH-4@WR!6X-G@K."ZH+$@J*"R(*B@JF!08*@@NF"HH+-B;V"YX*I
M@LR7G9=2@L6"L8+,BT"47(*JEK.,^(+)@LB"P8+$@J*"W(*W@4(`@UJ#8H-6
M@X>#DR`E<R""S(K4@LF"H(+(@KV"S(-U@XF#18-5@JJ5SXU8@K."ZH+<@K6"
MO8%"@UJ#3(.%@XJ#98-"@5N5VXSL@LR"O8+?@LF#C8-/@T.#DX*UDKR"MX+7
M@JN"Q8*W@4(`@UZ#0X.`@UV!6X.3@48`@J""R(*]@LR#9H-T@TB#BX-G240Z
M`(*@@LB"O8+,CH&6O`"#28-V@U:#AX.3@O"-6)!6@K6"W(*U@KT`@XJ#@H%;
M@V>#5(%;@V\Z`(%MC^&*48.,@WR!6X-G@6X`6XUS.B5S+R5S70!?08K'EYT`
M7T*)>Y>7`%]$C>V/G`!?1(US@O"-[8^<`%]'@T^#BX%;@W8`7TB#=X.+@W8`
M7TF)YI&<@W:#C8-P@V6#0BXN+@!?28-#@Y,O@T&#18-G`%],@XV#3X-#@Y,`
M7TR#C8-/@T&#18-G`%]-@XJ#DX-.E<^-6`!?3X-)@W:#5H.'@Y,`7U"#08-.
M@UJ#6(R@`%]2@XJ#DX-.C>V/G`!?4H.*@UB#9X*I@N>-[8^<`%]3C)^-]0!?
M4X-:@V*#9X-!@V*#=@!?5)5<D:Z0JP!?58.&@5N#50"#08-H@XR#6)*@`)=<
MDNB57`""L8*Q@O"#3H.*@V*#3@"#=(-`@T.#BP""W(*^CL"1E8*S@NJ"Q(*B
M@MR"N8+Q`(-P@5N#6H.3@V<`@W.#3H-:@XL`BFV41H+,@KV"WX-P@UB#CX%;
M@V@RDWB3_)?-@K6"Q(FZ@K."H@"6O):S@K4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O
M;&]C86QE+VES7TE3+P``````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C`P,3``(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T=7)B82]L;V-A;&4O:7-?25,O3$-?34534T%'15,O````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`R
M,34W-0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]I<U])
M4R],0U]-15-304=%4R]T=7)B82YM;P``````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$T
M,C8`,3`T,3<S-C(W-34`,#(S,C4Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-X2!)4`````L@```!P```"L!0``[P```#P+
M````````^`X``!````#Y#@```P````H/```&````#@\```P````5#P``#P``
M`"(/```%````,@\```,````X#P``'P```#P/```%````7`\``"@```!B#P``
M.@```(L/```)````Q@\```8```#0#P``"P```-</```*````XP\```T```#N
M#P``#````/P/```$````"1```!8````.$```!@```"40```&````+!````\`
M```S$```%@```$,0```9````6A````<```!T$```%````'P0```4````D1``
M``X```"F$```!````+40```&````NA```"@```#!$```!````.H0```(````
M[Q```!````#X$```&@````D1```&````)!$```H````K$0``"0```#81```/
M````0!$```@```!0$0``"P```%D1```$````91$```4```!J$0``#0```'`1
M```%````?A$``!````"$$0``$````)41```/````IA$```\```"V$0``#```
M`,81```&````TQ$``!,```#:$0``"````.X1```'````]Q$```0```#_$0``
M!`````02```$````"1(```P````.$@``"@```!L2```0````)A(```<````W
M$@``!````#\2```$````1!(```@```!)$@``#0```%(2```.````8!(``!8`
M``!O$@``$0```(82```&````F!(```8```"?$@``!P```*82```$````KA(`
M``<```"S$@``"0```+L2```&````Q1(```<```#,$@``"P```-02```$````
MX!(```8```#E$@``"````.P2```(````]1(```0```#^$@``!0````,3```&
M````"1,``!`````0$P``"````"$3```*````*A,```,````U$P``)````#D3
M```'````7A,```8```!F$P``'P```&T3```&````C1,```T```"4$P```@``
M`*(3```,````I1,```H```"R$P``!@```+T3```&````Q!,```0```#+$P``
M"0```-`3```'````VA,```0```#B$P``!0```.<3```+````[1,```0```#Y
M$P```@```/X3```$`````10```4````&%```"`````P4```"````%10```<`
M```8%```!P```"`4```-````*!0```@````V%```%````#\4```I````5!0`
M`!4```!^%```!0```)04```1````FA0```0```"L%```!@```+$4```.````
MN!0``!$```#'%```#````-D4```3````YA0```L```#Z%```'P````85```)
M````)A4```D````P%0``!````#H5```(````/Q4```T```!(%0``"@```%85
M```.````814```L```!P%0``!````'P5```.````@14```<```"0%0``!P``
M`)@5```$````H!4``",```"E%0``+P```,D5```A````^14``!P````;%@``
M!0```#@6```"````/A8```P```!!%@``!P```$X6```,````5A8```@```!C
M%@``!P```&P6```'````=!8```T```!\%@``#````(H6```*````EQ8```,`
M``"B%@``,````*86```3````UQ8``!````#K%@``4P```/P6```7````4!<`
M`!8```!H%P``#P```'\7```?````CQ<```0```"O%P``!P```+07```'````
MO!<```4```#$%P``#@```,H7```(````V1<```@```#B%P``%@```.L7```'
M`````A@```0````*&```!@````\8```8````%A@``$<!```O&```#````'<9
M```(````A!D```@```"-&0``"P```)89```,````HAD```H```"O&0``$```
M`+H9```6````RQD```4```#B&0``)````.@9```N````#1H```@````\&@``
M!0```$4:```-````2QH```T```!9&@``#````&<:```,````=!H```0```"!
M&@``%@```(8:```)````G1H```8```"G&@``$````*X:```1````OQH``!L`
M``#1&@``"0```.T:```1````]QH``!8````)&P``#0```"`;```%````+AL`
M``<````T&P``.````#P;```$````=1L```@```!Z&P``%````(,;```4````
MF!L```0```"M&P``"````+(;```+````NQL``!````#'&P``%@```-@;```9
M````[QL```8````)'```!P```!`<```'````&!P```4````@'```$````"8<
M```0````-QP``!4```!('```$0```%X<```/````<!P```D```"`'```%0``
M`(H<```'````H!P```0```"H'```!0```*T<```!````LQP```4```"U'```
M#````+L<```)````R!P```H```#2'```!@```-T<```$````Y!P```0```#I
M'```"````.X<```/````]QP``!$````''0``&````!D=```5````,AT```@`
M``!('0``"P```%$=```'````71T```<```!E'0``!P```&T=```'````=1T`
M``@```!]'0``!@```(8=```5````C1T```D```"C'0``!@```*T=```(````
MM!T```X```"]'0``!````,P=```$````T1T```<```#6'0``#0```-X=```.
M````[!T```D```#['0```P````4>```F````"1X```8````P'@``!@```#<>
M```*````/AX```8```!)'@``"````%`>```"````61X```<```!<'@``"P``
M`&0>```&````<!X```8```!W'@``!@```'X>```,````A1X```H```"2'@``
M!````)T>```&````HAX```X```"I'@``!0```+@>```#````OAX```4```#"
M'@``!@```,@>```(````SQX```8```#8'@``!P```-\>```-````YQX``!``
M``#U'@``"`````8?```6````#Q\``"$````F'P``%0```$@?```*````7A\`
M`!8```!I'P``!0```(`?```%````AA\``!$```",'P``#P```)X?```(````
MKA\``!,```"W'P``#````,L?```:````V!\```D```#S'P``"0```/T?```$
M````!R````D````,(```#@```!8@```*````)2````X````P(```"@```#\@
M```%````2B````H```!0(```!````%L@```)````8"````4```!J(```'@``
M`'`@```Q````CR```",```#!(```(````.4@```&````!B$```,````-(0``
M%````!$A```&````)B$``!$````M(0``"P```#\A```'````2R$```<```!3
M(0``$````%LA```0````;"$```D```!](0```@```(<A```O````BB$``!L`
M``"Z(0``"P```-8A``!5````XB$``!0````X(@``%@```$TB```0````9"(`
M`"8```!U(@``"````)PB```%````I2(```0```"K(@``!0```+`B```-````
MMB(```8```#$(@``"0```,LB```5````U2(```4```#K(@``!0```/$B```(
M````]R(``!4`````(P```0```!(`````````3P```%H```!7````D@```"4`
M````````G0```#H`````````;0```"H`````````B@```"`````,````FP``
M``````"%````E````&8```"G````&0```%(`````````&P```'0`````````
M2`````````!,````;@```&0````4````'@```"L```!+````&@````````!\
M`````````*8```"0````C````"X```!P````4P`````````3````````````
M``")````6P``````````````B````%\```"'````4``````````P````'P``
M`#T```!I````/P```(8```"Q````````````````````30````@```!#````
M>@``````````````0```````````````L@```"@```".````=0```)\````F
M````H0``````````````.P```(T`````````:````$X```"9````,P``````
M``"N````#0````````!Y````<0```*`````B````E0``````````````5@``
M`$$````1````7@````L```!K````(0``````````````,0``````````````
M`````'@```!R````L````'L```!G````<P```$8`````````)P```#0````M
M````*0`````````6``````````````">````#P```(0```"K````50```*\`
M````````1````$<````%````J@```&````"3````D0``````````````````
M`*,```"L````"@```($````Y``````````````!4`````````%T```!L````
M40````````"H``````````````!9````EP```'<````8````?P```&\````#
M`````````&,````0````/@```(\````"````?@````8`````````#@```#4`
M``""````6````"0```````````````0``````````````*4````O````````
M`(````"M````BP```!T```!B````'```````````````+````)P````V````
M=@```'T`````````F````$H```!J`````````*(```!E````(P```*0```!<
M````E@```(,````5````80```#(```":````!P```*D```!%````/````$(`
M```X````-P`````````7````20````D`````061?=F%N8V5D(%-E87)C:`!!
M9&0`061D('1O`$%D9')E<W,@0F]O:P!!9'9A;F-E9"!396%R8V@`06QI87,`
M06QL`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07!R:6P`07)E
M('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/P!!<F4@>6]U
M('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N
M=')I97,_`$%S8V5N9&EN9P!!=6=U<W0`0F%?8VL@=&\@)7,`0F%C:R!T;R`E
M<P!"87-I7V,@4V5A<F-H`$)A<VEC(%-E87)C:`!";W1H`$)U:6QD:6YG(&QO
M8V%L92`E<RXN+B``0V%N8V5L`$-H86YG90!#:&5C:R!?06QL+TYO;F4`0VAO
M;W-E(&%N(&%D9')E<W,@8F]O:P!#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@
M`$-O;7!A;GD`0V]M<&]S92!-97-S86=E("@E<RD`0V]N=&%C=',@:6X@;&ES
M=#H@)7,`0V]N=&5N=',@;V8@)7,`0V]P>0!#<F5A=&4`0W5S=&]M:7IE('1A
M<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!$871E`$1E8V5M8F5R`$1E
M9F%U;'0@261E;G1I='D`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5L
M971E`$1E<V-E;F1I;F<`1&ER96-T;W)Y`$1I<W!L87D@3W!T:6]N<P!$;W=N
M;&]A9`!$;W=N;&]A9"`E<P!%9&ET`$5M86EL`$5M86EL($%D9')E<W,`17)R
M;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X<&]R=`!%
M>'!O<G0@061D<F5S<R!";V]K`$9E8G)U87)Y`$9I;'1E<G,`1FEN9`!&<F]M
M`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`261E;G1I='DG<R!N86UE
M.@!*86YU87)Y`$IU;'D`2G5N90!,86YG=6%G90!,87-T(%5P9&%T960Z`$QA
M<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I
M;CH@3F5V97(`3&%T=FEA`$QA>6]U=`!,96)A;F]N`$QE9G0`3&EB97)I80!,
M:71H=6%N:6$`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`36%I;`!-86QA
M=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-87)C:`!-87)G:6X`36%R<VAA
M;&P@27-L86YD<P!-871C:&EN9P!-875R:71A;FEA`$UA>0!-97)G:6YG('1R
M86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BX`365S<V%G90!-97AI8V\`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:7)R;W(`36ES8V5L;&%N
M96]U<P!-;P!-;V)I;&4@4&AO;F4`36]D:69Y(%523`!-;V1U;&4`36]N86-O
M`$UO=F4`36]V92!$;W=N`$UO=F4@57``3F%M90!.979E<@!.97<@0V]N=&%C
M=`!.97AT`$YO`$YO;F4`3F]T97,`3F]V96UB97(`3TL`3V-T;V)E<@!/<'1I
M;VYS`$]T:&5R($]P=&EO;G,`4&%S<W=O<F0`4&5R<V]N86P@26YF;W)M871I
M;VX`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4F5M;W9E(&9R;VT@=&AI<R!L:7-T`%)E<V5T`%)E<V5T('1O($1E9F%U;'1S
M`%-A=F4`4V5A<F-H`%-E87)C:"!297-U;'1S`%-E87)C:&EN9R!/<'1I;VYS
M`%-E87)C:&EN9RXN+@!396QE8W0@061D<F5S<R!";V]K`%-E;&5C="!,:7-T
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5P=&5M8F5R`%-H
M;U]W($%L;`!3:&]W`%-H;W<@06QL`%-H;W<@0V]N=&%C=',`4VAO=R!,:7-T
M<P!3:&]W(%]#;VYT86-T<P!3:&]W(%],:7-T<P!3:7IE`%-O<G0@1&ER96-T
M:6]N`%-U8FIE8W0`4W5C8V5S<P!497AT`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%1O
M`%5N9&\@0VAA;F=E<P!5;FYA;65D`%5S97(@3W!T:6]N<P!5<V5R;F%M90!6
M:65W("5S`%=A<FYI;F<`5V5L8V]M92!T;R`E<P!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!997,`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O
M<FUA=&EO;@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/<'1I;VX@*R!0('1O('!R:6YT
M+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960N`%]!9&0`7T)R;W=S90!?1&5L971E`%](96QP`%]);7!O<G0O17AP
M;W)T`%],;V<@;W5T`%]/<'1I;VYS`%]296UO=F4@9G)O;2!T:&ES(&QI<W0`
M7U-E87)C:`!D;VYE`&9A:6QE9`!T;R!396QE8W1E9"!!9&1R97-S($)O;VL`
M4')O:F5C="U)9"U697)S:6]N.B!D:7-K(#$*4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&)J;W-S:4!S;F5R<&$N:7,*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3$M,3D@,C`Z,S,K,#`P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3$Q+3$Y
M(#(P.C,S*S`P,#`*3&%S="U4<F%N<VQA=&]R.B!":F]R;B!$879I9'-S;VX@
M/&)J;W-S:4!S;F5R<&$N:7,^"DQA;F=U86=E+51E86TZ('-U<'!O<G1`<VYE
M<G!A+FES"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:70*`,UT87)L96<@;&5I=`!"YG1A('9I\`!"YG1A('9I\`!.
M971F86YG86+S:P#-=&%R;&5G(&QE:70`4W1U='1N969N:0!!;&QA<B!S:W+A
M;FEN9V%R`--TYFMT(&=I;&1I('1I;&=R96EN="X`87!R[6P`17)T(/[Z('9I
M<W,@=6T@8?`@_OH@=FEL:FER(&5Y\&$@)7,_`$5R="#^^B!V:7-S('5M(&'P
M(/[Z('9I;&II<B!E>?!A(';V;&1U;2!L[6YU;3\`2.9K:V%N9&D`X6?Z<W0`
M5&EL(&)A:V$@[2`E<P!4:6P@8F%K82#M("5S`$5I;F;V;&0@;&5I=`!%:6YF
M]FQD(&QE:70`0N;P:0!">6=G:2!N^B!L;V-A;&4@)7,@+BXN`$CF='1A('9I
M\`!"<F5Y=&$`5F5L:F$@86QL82]E;F=A;@!696QD=2!N971F86YG86+S:P!(
M<F5I;G-A('1I;"#M(&QO8V%L92`E<R`N+BX`1GER:7)TYFMI`%-E;6IA('-K
M97ET:2`H)7,I`%1E;F=I;&GP:7(@[2!L:7-T83H@)7,`26YN:6AA;&0@[2`E
M<P!!9G)I=`!"^F$@=&EL`%-T:6QL82!A\&=E<O!I<B!S96T@97)U(&9R86UK
M=N9M9&%R(/YE9V%R(/[Z('1E;F=I<W0@)7,N`$1A9W,`9&5S96UB97(`4VKA
M;&9G969I\"!K96YN:6UA<FL`4VKA;&9G969I;B!U<'!R]O!U;CH`17GP80!,
MYFMK86YD:0!.971F86YG86+S:P#:=&QI='-S=&EL;&EN9V%R`%/F:VIA('EF
M:7(@X2!V:6YN=7-T]O``4^9K:F$@)7,@>69I<B#A('9I;FYU<W3V\`!"<F5Y
M=&$`3F5T9F%N9P!.971F86YG`%9I;&QA`,$@:V]R=&5R<R!F<F5S=&D`P2`S
M,"!S96LN(&9R97-T:0#!(&9I;6T@;>UN^G1N82!F<F5S=&D`P2!HX6QF=.UM
M82!F<F5S=&D`P2!M[6[Z='4@9G)E<W1I`$9L>71J82#Z=`!&;'ET:F$@^G0@
M;F5T9F%N9V%B\VL`9F5B<OIA<@!3[75R`$9I;FYA`.T`2&KA;'``2&5I;6EL
M:7-F86YG`$AE:6UA<^UM:0!+96YN:6YA9FXZ`&IA;OIA<@!J^FSM`&KZ;NT`
M5'5N9W5MX6P`<^WP87-T('5P<&;F<G0Z`%/M\&%S="!T96YG<W0Z("5S`%/M
M\&%S="!T96YG<W0Z("5S(&9RX2`E<P!3[?!A<W0@=&5N9W-T.B!!;&1R96D`
M3&5T=&QA;F0`1G)A;7-E=&YI;F<`3.UB86YO;@!6:6YS=')I`$SM8F5R[6$`
M3&ET:.%E;@!496YG:F%S=`#:='-K<N$`5F5R:V5F;FD@=FGP('1E;F=I;F=U
M`%9E9G#S<W1U<@!-86QA=NT`36%L8>US[6$`1W+F;FCV9O!A97EJ87(`36%L
M[0!M87)S`%-PX7-S[6$`36%R<VAA;&QE>6IA<@!S96T@<&%S<V%R('9I\`!-
MX7+M=&%N[6$`;6'M`%-A;65I;F$@_OWP:6YG87(@9GER:7(@)7,@96EN:6YG
M=6YA+BXN`%-K97ET:0!-97CM:_,`3>UK<O-N97/M80!3<&5G;&$`W6UI<VQE
M9W0`3>$`1F%R<^UM:0!"<F5Y=&$@<VSS\`!%:6YI;F<`3?-N86OS`$9L>71J
M80!&;'ET:F$@;FGP=7(`1FQY=&IA('5P<`!.869N`$%L9')E:0!._7(@=&5N
M9VEL:?!U<@!.YG-T80!.96D`16YG:6X`1VSS<W5R`&[S=F5M8F5R`,T@;&%G
M:0!O:W3S8F5R`%9A;'-T:6QL:6YG87(`0?!R87(@<W1I;&QI;F=A<@!,>6MI
M;&]R\`!5<'!L_7-I;F=A<B!U;2!N;W1A;F1A`%-LX?!U(&EN;B!N;W1A;F1A
M;F%F;B!O9R!L>6ML:6]R\`!&:F%R;.9G:F$@^G(@;&ES=&%N=6T`16YD=7)S
M971J80!%;F1U<G-E=&IA(&QE:71A<G)E:71I`%9I<W1A`$QE:71A`$YI\'5R
M<W1A\&$@;&5I=&%R`$QE:71A<G9A;&MO<W1I<@!,96ET82XN+@!696QJ:?`@
M;F5T9F%N9V%B\VLZ`%9A;&EN;B!L:7-T80!696QD=2!S:N%L9F=E9FGP('1U
M;F=U;>%L.@!S97!T96UB97(`4_UN82!A;&QT`%/];F$`4_UN82!A;&QT`%/]
M;F$@=&5N9VEL:?!I`%/];F$@;&ES=&$`4_UN82!T96YG:6QI\&D`4_UN82!L
M:7-T80!3=.9R\`!2]O!U;F%RX71T`$5F;FD`1G)A;6MVYFUT`%1E>'1I`$ME
M;FYI;G4@(B5S(B!H969U<B!V97)I\"!E>71T+@!6:6QL82!K;VT@=7!P('9I
M\"!B:7)T:6YG=2#^97-S82!H;'5T82!S:V5Y=&ES:6YS`%1A;&%N('9E<O!U
M<B!A\"!V97)A(&'P(&SA9VUA<FMI(#$N`-YE='1A(&=I;&1I('9E<O!U<B!A
M\"!V97)A('1A;&$N`%1I=&EL;`!4:6P`1FIA<FSF9VIA(&)R97ET:6YG87(`
MTVYE9FYT`%9A;&MO<W1I<B!N;W1A;F1A`$YO=&%N9&%N869N`%/];F$@)7,`
M0?!V]G)U;@!696QK;VUI;BAN*2#M("5S`$AE:6UI;&ES9BX@=FEN;G4`5FEN
M;G5S[6UI`$KA`$QO=&%N("5S(&5R(')U;FYI;B#Z="#A('3M;6$N(%1E;F=D
M=2#^:6<@869T=7(N`$9U;&QT(&YE=&9A;F<@_FET="`H1G+A.BD@.@!5<'!L
M_7-I;F=A<@!6969S:V_P87)I(/YI;FX@<W1Y\'5R(&5K:VD@_F5S<V$@<')E
M;G1A\&=E<O`N($YO=&'P=2!#5%),+T]P=&EO;B!O9R!0('1I;"!A\"!P<F5N
M=&$N`$[Z=F5R86YD:2!T[6UA8F5L=&DZ`%-JX6QF9V5F:?`@:V5N;FD@_FET
M=#H`1G5L;'0@;F%F;B#^:71T.@!3=&EL;&EN9V%R(/[M;F%R(&AA9F$@=F5R
M:?`@=7!P9N9R\&%R+@!"YG1A('9I\`!3:V_P80!%>?!A`$AJX6QP`$9L>71J
M82!I;FXO^G0`VG1S:W+A`%9A;&MO<W1I<@!&:F%R;.9G:F$@^G(@;&ES=&%N
M=6T`3&5I=&$`;&]K:?``:VQI:VMA\&D`[2!V86QI;FYI(&YE=&9A;F=A8O-K
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C
M86QE+VET7TE4+P``````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C`P,3(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T=7)B82]L;V-A;&4O:71?250O3$-?34534T%'15,O````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`R,34W
M-P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]I=%])5"],
M0U]-15-304=%4R]T=7)B82YM;P``````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S`R,C$`
M,3`T,3<S-C(W-34`,#(S,C0U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````Y0(``!P```!$%P``WP,``&PN````
M````Z#T```0```#I/0``)````.X]```E````$SX```P````Y/@``"P```$8^
M```H````4CX``!4```![/@``"0```)$^```+````FSX``!T```"G/@``"@``
M`,4^```-````T#X```X```#>/@``#P```.T^```8````_3X```X````6/P``
M#@```"4_```(````-#\``"L````]/P``"@```&D_```%````=#\```D```!Z
M/P``"0```(0_```0````CC\```H```"?/P``#P```*H_```)````NC\```T`
M``#$/P``#P```-(_```*````XC\```\```#M/P``"````/T_```&````!D``
M``@````-0```&0```!9````4````,$```!(```!%0```(0```%A````.````
M>D````,```")0```#P```(U````%````G4````4```"C0```"@```*E````#
M````M$```!<```"X0```"@```-!````/````VT````X```#K0```#@```/I`
M```7````"4$``!<````A00``$P```#E!```/````34$```8```!=00``"P``
M`&1!```5````<$$```4```"&00``*````(Q!```Z````M4$``#L```#P00``
M"0```"Q"```Y````-D(``"<```!P0@``+````)A"```J````Q4(``"4```#P
M0@``!@```!9#```1````'4,```H````O0P``"````#I#```,````0T,``!0`
M``!00P``#@```&5#```*````=$,```0```!_0P``"0```(1#```&````CD,`
M``<```"50P``!@```)U#```1````I$,```,```"V0P```P```+I#```3````
MOD,```@```#20P``!````-M#```&````X$,``!4```#G0P``!P```/U#```5
M````!40```\````;1```#0```"M$```/````.40```T```!)1```!@```%=$
M```&````7D0``%0```!E1```!````+I$```.````OT0``!8```#.1```'```
M`.5$```2`````D4```H````510``#P```"!%```1````,$4```P```!"10``
M!@```$]%```&````5D4``!$```!=10``!0```&]%```,````=44```4```""
M10``#@```(A%```&````ET4``!8```">10``*@```+5%```'````X$4```T`
M``#H10``!P```/9%```/````_D4```H````.1@``#````!E&```0````)D8`
M`!4````W1@``$@```$U&```:````8$8``!0```![1@``"````)!&```$````
MF48```X```">1@``'P```*U&```@````S48``"4```#N1@``!P```!1'```-
M````'$<``!`````J1P``!P```#M'```3````0T<```P```!71P``#@```&1'
M```/````<T<``!,```"#1P``#0```)='```H````I4<```,```#.1P``#0``
M`-)'```"````X$<``!````#C1P``#0```/1'```#`````D@```X````&2```
M"````!5(```/````'D@```T````N2```&@```#Q(```&````5T@``!,```!>
M2```#````')(```7````?T@```L```"72```#0```*-(```B````L4@``!8`
M``#42```"@```.M(```8````]D@``!D````/20``%@```"E)```/````0$D`
M``H```!020``"@```%M)```4````9DD```L```![20``"0```(=)```)````
MD4D``!8```";20``#P```+))```-````PDD``"8```#020``*````/=)``!#
M````($H``"\```!D2@``#@```)1*```$````HTH```H```"H2@``"@```+-*
M```0````ODH``!<```#/2@``$0```.=*```1````^4H``!<````+2P``!0``
M`"-+```-````*4L``!4````W2P``!0```$U+```0````4TL```\```!D2P``
M$````'1+```/````A4L```\```"52P``#````*5+```/````LDL```<```#"
M2P``!@```,I+```3````T4L```@```#E2P``$P```.Y+```:`````DP``!4`
M```=3```'@```#-,```E````4DP``"(```!X3```!````)M,```#````H$P`
M``@```"D3```"@```*U,```,````N$P```L```#%3```#````-%,```'````
MWDP```0```#F3```"@```.M,```*````]DP```T````!30``!0````]-```*
M````%4T``"8````@30``%0```$=-```%````74T```<```!C30``#````&M-
M```(````>$T```8```"!30``"````(A-```"````D4T```8```"430``#```
M`)M-```$````J$T```D```"M30``$````+=-```)````R$T```D```#230``
M&0```-Q-```.````]DT``!,````%3@```@```!E.```-````'$X```4````J
M3@``%````#!.```&````14X``!$```!,3@``!@```%Y.```$````94X```H`
M``!J3@``!````'5.```%````>DX```P```"`3@``"0```(U.```,````ETX`
M``H```"D3@``$````*].```3````P$X```4```#43@``$@```-I.```+````
M[4X``"D```#Y3@``)````"-/```F````2$\```@```!O3P``!````'A/```2
M````?4\```H```"03P``#P```)M/```0````JT\```X```"\3P``"0```,M/
M```*````U4\```8```#@3P``'````.=/```/````!%```!L````44```$@``
M`#!0```0````0U```!$```!44```$````&90```+````=U```!0```"#4```
M#````)A0```,````I5````\```"R4```%0```,)0```I````V%```"H````"
M40``)@```"U1```G````5%$``!D```!\40``$0```)91```2````J%$``!,`
M``"[40``%````,]1```6````Y%$``!<```#[40``$````!-2```1````)%(`
M`!,````V4@``%````$I2```4````7U(```T```!T4@``#0```()2```6````
MD%(```P```"G4@``&@```+12```)````SU(```8```#94@``!P```.!2```6
M````Z%(```0```#_4@``!`````13```'````"5,```<````14P``"````!E3
M```-````(E,```D````P4P``#````#I3```-````1U,```X```!54P``%@``
M`&13```1````>U,```8```"-4P``!````)13```*````F5,``!````"D4P``
M&@```+53```*````T%,```P```#;4P``#P```.A3```(````^%,```8````!
M5```!P````A4```+````$%0```,````<5```$P```"!4```"````-%0```0`
M```W5```"@```#Q4``!H````1U0```4```"P5```!@```+94```(````O50`
M``\```#&5```%P```-94```#````[E0```<```#R5```"P```/I4```-````
M!E4``!H````450``2@```"]5```&````>E4```8```"!50``"P```(A5```"
M````E%4```L```"750``#````*-5```(````L%4```H```"Y50``%@```,15
M```7````VU4```P```#S50``!`````!6```)````!58```H````/5@``%0``
M`!I6``!)````,%8```H```!Z5@``"0```(56```0````CU8``!(```"@5@``
M!````+-6```+````N%8```<```#$5@``!0```,Q6```,````TE8```L```#?
M5@``%P```.M6```$`````U<```H````(5P``!````!-7```(````&%<```4`
M```A5P``&````"=7```L````0%<``!$```!M5P``$P```']7```(````DU<`
M``@```"<5P``*P```*57```8````T5<``$4```#J5P``00```#!8```$````
M<E@```<```!W6```!0```']8```(````A5@``!$```".6```&````*!8```.
M````N5@```(```#(6```#@```,M8```0````VE@```<```#K6```!@```/-8
M```4````^E@``!\````/60``!P```"]9```.````-UD```H```!&60``'0``
M`%%9```%````;UD``!$```!U60``#0```(=9```1````E5D```X```"G60``
M"````+99```-````OUD```@```#-60``"0```-99```*````X%D``!4```#K
M60``!0````%:```$````!UH``!`````,6@``!P```!U:```>````)5H``"@`
M``!$6@``"@```&U:```1````>%H``!H```"*6@``%````*5:```&````NEH`
M`!$```#!6@``!@```--:```T````VEH``#0````/6P``*0```$1;```I````
M;EL```4```"86P``&0```)Y;```9````N%L```@```#26P``%P```-M;```*
M````\UL```<```#^6P``(0````9<```.````*%P``!0````W7```!P```$Q<
M```3````5%P```@```!H7```!0```'%<```5````=UP```P```"-7```!```
M`)I<```*````GUP```D```"J7```#@```+1<```$````PUP``!0```#(7```
M,@```-U<``!%````$%T``!(```!670``%````&E=```'````?ET```X```"&
M70``*@```)5=```&````P%T```P```#'70``#0```-1=```1````XET``!4`
M``#T70``"P````I>```*````%EX```L````A7@``#P```"U>```;````/5X`
M``4```!97@``#@```%]>```3````;EX```<```""7@``$0```(I>```4````
MG%X``!@```"Q7@``!P```,I>```%````TEX``!(```#87@``#@```.M>```.
M````^EX```4````)7P``!0````]?```#````%5\``!D````97P``#0```#-?
M```"````05\```0```!$7P``!P```$E?```,````45\``%(```!>7P``%P``
M`+%?```&````R5\```X```#07P``#0```-]?```1````[5\```P```#_7P``
M%0````Q@```2````(F````\````U8```%````$5@```G````6F```"4```""
M8```:0```*A@```:````$F$``!<````M80``&0```$5A```:````7V$``"4`
M``!Z80``*````*!A```:````R6$``!<```#D80``&P```/QA```T````&&(`
M`"4```!-8@``&0```'-B```?````C6(``!,```"M8@``"````,%B```)````
MRF(``#\```#48@``-P```!1C``!7````3&,``!\```"D8P``$````,1C```(
M````U6,```T```#>8P``+0```.QC```$````&F0```@````?9```#0```"AD
M```*````-F0``"4```!!9```'P```&=D```=````AV0``"4```"E9```(```
M`,MD```D````[&0```<````190``#0```!EE```,````)V4``!`````T90``
M#````$5E```.````4F4```<```!A90``!P```&EE```$````<64``!<```!V
M90``"@```(YE```,````F64```D```"F90``"````+!E```&````N64```(`
M``#`90``"0```,-E```'````S64``!L```#590``*````/%E```5````&F8`
M``<````P9@``"````#AF```'````068```<```!)9@``#@```%%F```)````
M8&8```8```!J9@``"````'%F```+````>F8```<```"&9@``!P```(YF```(
M````EF8```,```"?9@``%````*-F```0````N&8``!````#)9@``!P```-IF
M```%````XF8``!0```#H9@``"P```/UF```-````"6<``!<````79P``"0``
M`"]G```*````.6<```<```!$9P```@```$QG```?````3V<``"D```!O9P``
M(P```)EG```A````O6<``!\```#?9P``*P```/]G```G````*V@``"8```!3
M:```S````'IH``!>````1VD``"<```"F:0``*````,YI```I````]VD``"H`
M```A:@``(@```$QJ```B````;VH```L```"2:@``-@```)YJ```'````U6H`
M``<```#=:@``#0```.5J```+````\VH```4```#_:@``!0````5K```(````
M"VL```,````4:P```@```!AK```#````&VL```0````?:P``)````"1K```)
M````26L```P```!3:P``!P```&!K```%````:&L``!H```!N:P``"P```(EK
M```&````E6L```D```"<:P``"P```*9K```7````LFL```8```#*:P``$P``
M`-%K```3````Y6L``!$```#Y:P``,@````ML```(````/FP```D```!';```
M"@```%%L```4````7&P```@```!Q;```"````'IL```2````@VP```\```"6
M;```#@```*9L```0````M6P```D```#&;```"0```-!L```,````VFP``!D`
M``#G;```&P````%M```*````'6T```P````H;0```@```#5M```0````.&T`
M``,```!);0``"P```$UM```'````66T```T```!A;0``"P```&]M```O````
M>VT``"````"K;0``'````,QM```%````Z6T``!(```#O;0``"@````)N```&
M````#6X```4````4;@``!@```!IN```,````(6X```P````N;@``"@```#MN
M```0````1FX``!,```!7;@```@```&MN```,````;FX``#````![;@``+P``
M`*QN```9````W&X``"8```#V;@``'@```!UO```H````/&\``"D```!E;P``
M*0```(]O```F````N6\``"4```#@;P``*`````9P```N````+W```!(```!>
M<```$P```'%P```0````A7````D```"6<```<P```*!P```K````%'$``!<`
M``!`<0``%@```%AQ```/````;W$``!0```!_<0``$````)1Q```3````I7$`
M``\```"Y<0``!P```,EQ```)````T7$```<```#;<0``"P```.-Q```'````
M[W$```4```#W<0``%````/UQ```.````$G(```@````A<@``#P```"IR```(
M````.G(```P```!#<@``#P```%!R```6````8'(```<```!W<@``%````']R
M```&````E'(```0```";<@``"P```*!R```,````K'(```P```"Y<@``&0``
M`,9R```&````X'(```0```#G<@``!P```.QR```&````]'(```8```#[<@``
M!@````)S```B````"7,```4````L<P``"P```#)S``!F`0``/G,```8```"E
M=```(````*QT```B````S70```H```#P=```#P```/MT```H````"W4``!``
M```T=0``#````$5U```*````4G4``!X```!==0``"0```'QU```/````AG4`
M``T```"6=0``"0```*1U```6````KG4```X```#%=0``#@```-1U```&````
MXW4``"T```#J=0``"0```!AV```%````(G8```4````H=@``!@```"YV```0
M````-78```P```!&=@``%0```%-V```-````:78``!4```!W=@``&0```(UV
M```0````IW8``!@```"X=@``#0```-%V```*````WW8```\```#J=@``+```
M`/IV```.````)W<``"`````V=P``'@```%=W```/````=G<```H```"&=P``
M$````)%W```%````HG<```P```"H=P``#0```+5W```%````PW<``!P```#)
M=P``#@```.9W```0````]7<``!0````&>```#@```!MX```7````*G@``!L`
M``!">```%P```%YX```2````=G@```@```")>```#````))X```7````GW@`
M``8```"W>```(@```+YX```N````X7@``$`````0>0``"@```%%Y```\````
M7'D``#0```"9>0``-0```,YY```P````!'H``#`````U>@``!@```&9Z```2
M````;7H```8```"`>@``"````(=Z```0````D'H``!4```"A>@``$P```+=Z
M```.````RWH```D```#:>@``"0```.1Z```'````[GH```<```#V>@``!0``
M`/YZ```0````!'L```,````5>P```P```!E[```9````'7L```H````W>P``
M!0```$)[```(````2'L``!P```!1>P``!P```&Y[```5````=GL``!4```",
M>P``#P```*)[```5````LGL```T```#(>P``!@```-9[```(````W7L``'0`
M``#F>P``!````%M\```1````8'P``!(```!R?```)````(5\```2````JGP`
M``X```"]?```(P```,Q\```5````\'P``!(````&?0``!@```!E]```&````
M('T``!(````G?0``!@```#I]```0````07T```@```!2?0``#P```%M]```(
M````:WT``!H```!T?0``+@```(]]```'````OGT``!````#&?0``!P```-=]
M```0````WWT```H```#P?0``#````/M]```1````"'X``!<````:?@``$P``
M`#)^```=````1GX``!@```!D?@``"````'U^```%````AGX``!(```",?@``
M*````)]^```I````R'X``#P```#R?@``!0```"]_```4````-7\``!````!*
M?P``!@```%M_```4````8G\```L```!W?P``$````(-_```-````E'\``!0`
M``"B?P``#0```+=_```U````Q7\```8```#[?P``$`````*````"````$X``
M`!`````6@```#0```">````&````-8```!`````\@```"````$V````/````
M5H```!$```!F@```$@```'B````(````BX```!D```"4@```#0```*Z````6
M````O(````T```#3@```#P```.&````7````\8```!T````)@0``"P```">!
M```>````,X$``!L```!2@0``&````&Z!```4````AX$```P```"<@0``"P``
M`*F!```4````M8$```@```#*@0``$````-.!```(````Y($``!X```#M@0``
M&@````R"```-````)X(``"L````U@@``.P```&&"``!.````G8(``#,```#L
M@@``#0```""#```(````+H,```\````W@P``#P```$>#```1````5X,``!@`
M``!I@P``%@```(*#```5````F8,``!@```"O@P``!0```,B#```2````SH,`
M`!P```#A@P``!@```/Z#```.````!80```T````4A```#P```"*$```-````
M,H0```T```!`A```"P```$Z$```2````6H0```H```!MA```!P```'B$```/
M````@(0```D```"0A```*0```)J$```D````Q(0``!X```#IA```+`````B%
M```K````-84``"(```!AA0``!@```(2%```#````BX4```@```"/A0``#0``
M`)B%```/````IH4``!````"VA0``#````,>%```&````U(4```4```#;A0``
M"P```.&%```$````[84```\```#RA0``!0````*&```+````"(8``"H````4
MA@``(````#^&```&````8(8```@```!GA@``#````'"&```(````?88```4`
M``"&A@``!P```(R&```#````E(8```8```"8A@``$P```)^&```"````LX8`
M``0```"VA@``%````+N&```*````T(8```T```#;A@``&0```.F&```/````
M`X<```\````3AP``!0```".'```.````*8<```8````XAP``%@```#^'```&
M````5H<```\```!=AP``!P```&V'```%````=8<```@```![AP``!````(2'
M```&````B8<``!0```"0AP``!0```*6'```%````JX<``!,```"QAP```P``
M`,6'```1````R8<```4```#;AP``%P```.&'```,````^8<``!H````&B```
M'P```"&(```8````08@```<```!:B```!````&*(```8````9X@```H```"`
MB```#P```(N(```3````FX@``!(```"OB```#````,*(```,````SX@```@`
M``#<B```'0```.6(```1`````XD``!@````5B0``$P```"Z)```0````0HD`
M`!@```!3B0``$@```&R)```,````?XD``!L```",B0``%0```*B)```1````
MOHD``!H```#0B0``&````.N)```P````!(H``#0````UB@``+0```&J*```Q
M````F(H``"$```#*B@``%````.R*```5`````8L``!4````7BP``%P```"V+
M```8````18L``!D```!>BP``$P```'B+```4````C(L``!L```"ABP``$P``
M`+V+```6````T8L``!P```#HBP``$`````6,```<````%HP``!`````SC```
M$````$2,```*````58P```<```!@C```!P```&B,```8````<(P```8```")
MC```!@```)",```,````EXP```@```"DC```!@```*V,```/````M(P```<`
M``#$C```#0```,R,```5````VHP``!(```#PC```&`````.-```3````'(T`
M``<````PC0``"````#B-```/````08T``!T```!1C0``*@```&^-```*````
MFHT```P```"EC0``#````+*-```%````OXT```4```#%C0``!````,N-```:
M````T(T```4```#KC0``%P```/&-```"````"8X```4````,C@``&````!*.
M``!6````*XX```4```""C@``!P```(B.```.````D(X``!0```"?C@``+0``
M`+2.```&````XHX```8```#IC@``#````/".```-````_8X``!8````+CP``
M)0```"*/```'````2(\```8```!0CP``#@```%>/```#````9H\```L```!J
MCP``"0```':/```(````@(\```P```")CP``&0```):/```>````L(\``!4`
M``#/CP``!@```.6/```1````[(\```\```#^CP``$`````Z0``!+````'Y``
M``L```!KD```"P```'>0```7````@Y```!<```";D```!````+.0```,````
MN)````0```#%D````P```,J0```/````SI````X```#>D```'0```.V0```'
M````"Y$``!$````3D0``"@```"61```$````,)$```4````UD0``'@```#N1
M```H````6I$``!<```"#D0``(````)N1```.````O)$```L```#+D0``-@``
M`->1```:````#I(``%0````ID@``3@```'Z2```'````S9(```T```#5D@``
M!````..2```(````Z)(``!$```#QD@``$P````.3```/````%Y,```(````G
MDP``#````"J3```3````-Y,```<```!+DP``!P```%.3```6````6Y,``"H`
M``!RDP``!P```)V3```.````I9,```D```"TDP``%````+Z3```%````TY,`
M`!(```#9DP``#0```.R3```9````^I,``!,````4E```"@```"B4```2````
M,Y0```@```!&E```"0```$^4```*````690``"$```!DE```!P```(:4```(
M````CI0``!@```"7E```"P```+"4```D````O)0``"X```#AE```"````!"5
M```/````&94``!P````IE0``%@```$:5```$````794```P```!BE0``!0``
M`&^5```G````=94``",```"=E0``*0```,&5```N````ZY4```@````:E@``
M(@```".6```@````1I8```D```!GE@``'@```'&6```+````D)8```D```"<
ME@``*0```*:6```1````T)8``!$```#BE@``"````/26```8````_98```@`
M```6EP``!P```!^7```6````)Y<```X````^EP``!P```$V7```.````59<`
M``T```!DEP``#P```'*7```%````@I<``!@```"(EP``0P```*&7``!.````
MY9<``!4````TF```)````$J8```$````;Y@```T```!TF```*@```(*8```'
M````K9@```X```"UF```#P```,28```5````U)@``!<```#JF```#`````*9
M```*````#YD```X````:F0``$@```"F9```>````/)D```<```!;F0``$```
M`&.9```7````=)D```D```",F0``$P```):9```9````JID``!@```#$F0``
M!P```-V9```&````Y9D``!@```#LF0``%`````6:```4````&IH```8````O
MF@``!@```#::```&````/9H``!L```!$F@``#````&":```#````;9H```4`
M``!QF@``"````'>:```-````@)H``%H```".F@``'0```.F:```%````!YL`
M`!$````-FP``#P```!^;```3````+YL``!,```!#FP``(````%>;```?````
M>)L``!,```"8FP``(0```*R;```D````SIL``"P```#SFP``<P```""<```B
M````E)P``!\```"WG```(@```-><```?````^IP``"8````:G0``-````$&=
M```C````=IT``!L```":G0``(P```+:=```U````VIT``"\````0G@``'P``
M`$">```C````8)X``!P```"$G@``"0```*&>```)````JYX``#\```"UG@``
M+P```/6>``!>````)9\``"T```"$GP``$P```+*?```(````QI\```\```#/
MGP``+0```-^?```&````#:````P````4H```#P```"&@```,````,:```"(`
M```^H```+P```&&@```A````D:```"$```"SH```&P```-6@```@````\:``
M``H````2H0``$@```!VA```0````,*$``!(```!!H0``%0```%2A```8````
M:J$```L```"#H0``"@```(^A```$````FJ$``!(```"?H0``#````+*A```.
M````OZ$```L```#.H0``"````-JA```%````XZ$```,```#IH0``"P```.VA
M```(````^:$``!T````"H@``&@```""B```7````.Z(```D```!3H@``!```
M`%VB```(````8J(```0```!KH@``#0```'"B```&````?J(```@```"%H@``
M"@```(ZB```+````F:(```@```"EH@``"@```*ZB```*````N:(```,```#$
MH@``%@```,BB```1````WZ(``!$```#QH@``#0````.C```(````$:,``!@`
M```:HP``"P```#.C```-````/Z,``!@```!-HP``"@```&:C```2````<:,`
M``T```"$HP```P```)*C```@````EJ,``!\```"WHP``(P```->C```B````
M^Z,``"`````>I```-P```#^D```H````=Z0``"$```"@I```L0```,*D``!U
M````=*4``"H```#JI0``*````!6F```E````/J8``$,```!DI@``(P```*BF
M```O````S*8```T```#\I@``,P````JG```%````/J<```8```!$IP``$@``
M`$NG```+````7J<```8```!JIP``!````'&G```&````=J<```0```!]IP``
M`P```(*G```#````AJ<```0```"*IP``*@```(^G```*````NJ<```@```#%
MIP``"@```,ZG```%````V:<``!D```#?IP``#@```/FG```(````"*@```L`
M```1J```#P```!VH```B````+:@```@```!0J```$0```%FH```6````:Z@`
M`!0```""J```.````)>H```+````T*@```P```#<J```#````.FH```3````
M]J@```<````*J0``"0```!*I```2````'*D``!(````OJ0``#````$*I```5
M````3ZD```H```!EJ0``"@```'"I```3````>ZD``"$```"/J0``'0```+&I
M```*````SZD```P```#:J0```P```.>I```0````ZZD```,```#\J0``"P``
M``"J```)````#*H```X````6J@``#0```"6J```P````,ZH``!X```!DJ@``
M(````(.J```)````I*H``!8```"NJ@``#P```,6J```*````U:H```8```#@
MJ@``!P```.>J```3````[ZH```4````#JP``$@````FK```#````'*L``!$`
M```@JP```@```#*K```2````-:L``"X```!(JP``+@```'>K```>````IJL`
M`"0```#%JP``,P```.JK```H````'JP``"L```!'K```*@```'.L```J````
MGJP``"L```#)K```*P```/6L```O````(:T``!,```!1K0``$P```&6M```3
M````>:T```L```"-K0``AP```)FM```I````(:X``!L```!+K@``$P```&>N
M```,````>ZX``!4```"(K@``)P```)ZN```7````QJX``!````#>K@``"```
M`.^N```)````^*X```@````"KP``#0````NO```'````&:\```8````AKP``
M&P```"BO```0````1*\```X```!5KP``$@```&2O```(````=Z\```D```"`
MKP``$````(JO```8````FZ\```8```"TKP``&````+NO```'````U*\```4`
M``#<KP``#````.*O```,````[Z\```P```#\KP``&`````FP```&````(K``
M``0````IL```"````"ZP```&````-[````L````^L```"````$JP```K````
M4[````4```!_L```"P```(6P```!````XP$``)L"````````(`(``*,!``#J
M`0``2P$``.,````3`0``B@$``+\!``"R````D0```%0!``";````>0````\!
M``"=`0```````%X```!V`@``G`$``!4```"V`````````.8!``"X`@``R`(`
M`*\````(`@``'0```#8!````````<`(```X!``!$````20$``+X!````````
M`````,H```!"`0``'0(``"T````Z````&`$````````P````I````#H!``#.
M`@```````%,!````````N@(``'4```"$`0``Q0(````"``#!`0``7P$``'X`
M``!^`0``PP$``!X```#$`0``J0```$P!``!M`0```````&("```0`@``````
M```````Q````U`(````````J````;`(``/T!````````]`$``-0!```\````
M?P$```````#[`0``:0(``-P"```7`0``X0(``'H````]`@```````*$!``"H
M`0``(0(````````_`````````,<````N`0````````````"?`````````.("
M````````[P$``+T!``!&`@```````-,"``#,````Q@$``"(```!8`0``)P$`
M`/<!``#M````L0````````#+````1P```$L"````````*P(``/0```!J````
MZ````%D"`````````````%$!````````G0(``+<"````````E0(```$"````
M````:P(`````````````[0$``(0`````````00(``%$"``!C`0``O`$``"P!
M``!E````P@$``*P`````````H@```),!```W`0``M0(``(8"``!J`0``````
M``````"4````?0$``(4```#$`@``S0(`````````````6P$```4```!=`@``
MX0```+X"``#O````7`(``*$````[`0``\````'\``````````````&8```"3
M`@``60$`````````````U0```-4"```I`0````````("``"[`0``\0$``+\"
M`````````````+D````Y````'P(``'P!``#>`@``@`````\```!D````H`(`
M`$<!````````MP$```````".````=@$```````!)````)P(``(@!```^`@``
MPP(``)H!`````````@```#@!````````+P```/,```"S````G@$```@!````
M````8`(``"H"``!O`0``80$``&``````````10$```P!``"T`0``````````
M``#K````4@(``$@"``"&``````````0!````````)@(``-<!``"7````````
M`#P!```;````]@```(@"``!F`@``V@```)("``#+`0```````$("``#)````
M3@``````````````(P$``&@!``">````)`(``(P"``!Q`@``]P````````!$
M`@``IP```(,````A````````````````````N@```!T!``"C`@``T@``````
M``"+`@```````.4````6`````````*,````#````00$`````````````DP``
M`!$````,````N````(4"````````"P(``+`!``!H````30```)P`````````
M"P```)(`````````6````$D"``"6````3@(``'L```!7`0```````#,!``!6
M`0``W0```!("``"Q`0``!````(("````````_@$```H!```5`0```````"\!
M`````````````*0!`````````````'H!````````?`````````"H````````
M`!H"``"*`@``D`(```````"7`0``$P(```````!P````:0$```````!I````
M=`(```````#%`````````,T!``#,`@```````!P"``"G`@``NP````````!A
M````L`````````#P`0``!@```&L!```E`0```````+@!````````,`$``%\`
M```;`0```````+H!``#+`@```````&<!````````<0``````````````T`$`
M``````````````````<!``"I`0```````(D```!5````O@````````#D`@``
M`````-T"```H`0``40```$$```#K`0``*`(``'8`````````\P$``-<```#[
M````L0(```````#1````^`$``!H!`````````````$8`````````G0```#\!
M`````````````',"```D````QP$``$L```#@`0``"0````````#``0``JP$`
M`+4!````````0P(```````"O`0``10(``-,```!:`````````&`!````````
M.P(``/X```"K`@````````,"````````L@(```````#B````.0(``"8!````
M````6`(``'(`````````I0```,4!``!_`@``F0```.X!````````(P```&,`
M``#?`0``6P(``$`!````````BP$``"@`````````P0```,<"````````$@``
M`*(!``#I`0``K@```,0````,`@``P`(``-P!``!0`@``>`$``$<"````````
M+`(``'`!``![`@``C@$```````!T````"0(``!<"``"8`0``#0````````#9
M````EP(``+P"``!9````$````*P!``#C`@``:`(``&P!````````7@(`````
M```%`0```````.@!```?`0``*0````````">`@``V`$``+L"``#/`0``4```
M`((```#\`0````````````!L````P@(``(,!``"S`0``3P(``/T```!M````
M`````.0!````````"0$``',```!5`0```````*4!```A`0``,0$``&$"````
M````GP$```@``````````````,(`````````VP$``&8!```S`@``@@$``!X"
M``!?`@``I@````````!$`0``L`(``)H```#Y````&0$``!D`````````S@``
M``````!3`@``/0$``&L```#L`0``0P```'$!````````K0```+<````:````
M'@$``'(!```&`@``V0(```````"<`@``E`$``,,````Q`@``"@````````"]
M`@``5@```#8"``"+````/@$`````````````FP$``'("```2`0``-@```)4`
M`````````````*4"````````9`(````````S````TP$``%P!```B`@``U```
M`+D!``#7`@``A0$```````#5`0```````"8```"S`@``````````````````
M```````````U````%0(``%,```"J`@``YP$```4"````````5@(``)H"````
M`````````"X```#>`0``AP```$H!```+`0``W@`````````M`@``1@$`````
M``!=`0``8P(```````#A`0``B0(``"H!````````]0$``#@```",````,@(`
M`.4!``"-`@``V0$```````"N`@```````(`"````````%@(``.(!``#N````
M6P```*L```#0`@``%`(``-(!``#`````)0(`````````````Q@```$X!``!(
M`````````#0!``#R````K@$```````!%`````````(T!```K`0``J`(``#L`
M```@````S`$``"<```"'`@``90$``/D!``"L`@``N0(``)D!```<````;P``
M`($``````````````#D!``#Z`0````````````!:`0``*P```,\`````````
M9`$``,@`````````R0$``&\"``"O`@````````````"2`0``-0(``,$"``"/
M`@```````%0````R`0``3P$````````7````M`(``/\!````````0````-@`
M``"!`0```````,H"``#D`````````'4!```8````-````!L"``".`@``\0``
M`($"``"@`0``7````/P````W````Q@(``$H```"A`@``/`(``(<!``"5`0``
MK0$``.D```#_````U@```"D"``#<````-`(``!P!``#1`@```````%0"``"/
M`0``/@````0"``"4`@```````+T```!0`0```````,X!``````````````H"
M``!U`@``%````!8!```Z`@`````````````E`````````'<```#U````YP``
M`,H!``!7`@``U@$````````_`@``R`$``(D!`````````````"P```!W`0``
M```````````1`@``V@$``#(`````````O````&T"``!B`0``F````*D"```-
M`0``9P`````````'`@``H@(``"`!```W`@``9P(``'@```!S`0``J@```'D"
M``!7````A`(``$T"``"F`@```````(`!``#@````0@```'T"````````````
M``````!5`@````````````!/`````````-L"````````IP$``.`"````````
M`````/@````/`@``D0$``!@"``!]````8@```'0!```N`@``Z@````````!2
M`0``I@$```T"``!J`@```````"0!``#)`@````$``)\"``"/````]@$`````
M````````6@(```````",`0``3````+8"``#1`0```````!\`````````$0$`
M`&X"```&`0``30$`````````````F`(```````"D`@``[```````````````
MC0```-H"````````M0````````"#`@``^@```,T```"6`@``#@(``.8`````
M````>@(``*H!``"(````````````````````.`(```(!```U`0``Y0(``!,`
M``"1`@```````-8"``#2`@``,`(```$!``!E`@```````)8!````````A@$`
M`$,!``#;````>`(``"\"``"0`0```````","``"M`@````````X`````````
M0`(``%X!``"@````B@`````````'````D````!0!``#/`@``T````"T!``![
M`0``````````````````F0(````````9`@``$`$```````"T`````````-@"
M```B`0``?@(``'P"``!=````4@`````````]````WP```$P"````````2`$`
M`+\`````````;@$``$H"``#R`0``WP(``'D!``!N`````````+(!``#=`0``
M```````````#`0``=P(``+8!`````````"!A="``(D9I<G-T;F%M92!,87-T
M;F%M92(@("AI92X@2F]H;B!$;V4I`"),87-T;F%M92P@1FER<W1N86UE(B`H
M:64N($1O92P@2F]H;BD`)60@)7,@86YD("5S`"5S("T@3F]T:6-E`"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@5&5R;7,@
M;V8@06=R965M96YT`"5S(&%D9&5D+@`E<R!A="`E<R`E<P`E<R!F:6QE('-U
M8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`
M)7,@=&\@)7,@;V8@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<P`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H
M;W5R<P!!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I
M<F5D`$%-(%-H;W=E<G,`04TO4$T`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-O
M=6YT(%!A<W-W;W)D`$%C8V]U;G1I;F<`061D($-H:6QD($=R;W5P`$%D9"!(
M97)E.@!!9&0@3F5W($=R;W5P`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN
M`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&\`061D('5S97(`061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S($)O;VL@3&ES=&EN9P!!
M9&1R97-S(&)O;VL@96YT<GD`061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P
M=7)G960N`$%D;6EN:7-T<F%T:6]N`$%D<P!!9'9A;F-E9"!396%R8V@`06QI
M87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E
M<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`
M06QR96%D>2!%>&ES=',`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N
M871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA
M=&4@=&5X=#H`06YS=V5R`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E
M861Y+@!!<')I;`!!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE
M=&4@)7,_`$%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T
M:&4@<V5L96-T960@96YT<FEE<S\`07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07-C96YD:6YG
M`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`
M075G=7-T`$%V86EL86)L92!F:65L9',Z`$)A8VMG<F]U;F0`0F%S96QI;F4`
M0F%S:6,@4V5A<F-H`$)I;F0@9F%I;&5D.B`H)7,I("5S`$)L;V-K(%-E='1I
M;F=S`$)L;V-K(%1Y<&4`0F]L9`!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<G,`
M0F]T=&]M`$)U<VEN97-S($-A=&5G;W)Y`$--4P!#4U8`0U]E;&P@4')O<&5R
M=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A;F-E;`!#86YC96P@4')O8FQE;2!2
M97!O<G0`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A
M8VEN9SH`0V5N=&5R`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&]O<V4@86X@
M861D<F5S<R!B;V]K`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VQE
M87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L
M:6-K('1O($-O;G1I;G5E`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O
M;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQS.@!#;VQU
M;6X@3W!T:6]N<P!#;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A;'5E<P!#;VUM
M82!S97!A<F%T960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RD`0V]M;6%N
M9`!#;VUM86YD(%-H96QL`$-O;7!A;GD`0V]M<&%N>2!!9&1R97-S`$-O;F1I
M=&EO;G,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N;F5C=&EO
M;B!F86EL960Z("5S`$-O;FYE8W1I;VX@9F%I;'5R90!#;VYT86-T(')E;6]V
M960@9G)O;2!L:7-T+@!#;VYT86-T<R!I;B!L:7-T.B`E<P!#;VYT:6YU90!#
M;W!Y`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5R<V5S`$-R96%T
M92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&5D`$-R96%T;W(@4&5R
M;6ES<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@
M5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T
M('-E;&5C=&EO;@!$1`!$871A5')E92!"<F]W<V5R`$1A=&4@4F5C96EV960`
M1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$
M969A=6QT($-O;&]R`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T
M90!$96QE=&4@0V]N9FER;6%T:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@8G5T
M=&]N(&)E:&%V:6]U<@!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&9A:6QE9#H@
M*"5S*2`E<P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$
M96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R
M;W<`1&5L971I;VX@9F%I;&5D`$1E<&%R=&UE;G0`1&5S8V5N9&EN9P!$97-C
M<FEB92!T:&4@4')O8FQE;0!$979E;&]P;65N=`!$97<@4&]I;G0`1&ER96-T
M;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1O
M(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'``1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R:65S
M/P!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O=VYL;V%D('9#87)D`$5D
M:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!E;G1R>2!F;W(@)7,`161I="!O
M<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`16UA:6P`16UA
M:6P@061D<F5S<P!%;G1R>2!F;W(@)7,@=7!D871E9"X`17)R;W(`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%
M=F5R>2`U(&UI;G5T97,`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%
M>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!O<G0`17AP;W)T($%D9')E<W,@
M0F]O:P!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!T;R!A
M9&0@)7,@=&\@)7,Z("5S`$9A:6QE9"!T;R!B<F]W<V4@;&ES=`!&86EL960@
M=&\@8G)O=W-E('1H92!D:7)E8W1O<GD`1F%I;&5D('1O(&9I;F0@;V)J96-T
M('1O(&)E(&%D9&5D.B`E<P!&86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O
M<GDZ("5S`$9A:7(`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK
M93H@`$9E=R!3:&]W97)S`$9I;&4@36%N86=E<@!&:6QT97)S`$9I;F0`1FER
M<W0@2&%L9@!&:7)S="!.86UE`$9I<G-T(%%U87)T97(`1FQO870`1F]N="!#
M;VQO<@!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&
M;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y
M<&4`1F]R='5N97,`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F5E8G5S
M>2!54DP`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO
M;VX`1G5L;"!.86UE`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A
M=&5D($-O9&4`1VQO8F%L($%D9')E<W,@0F]O:P!';P!';V]G;&4@4V5A<F-H
M`$=R;W5P`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P<P!'=65S="!097)M
M:7-S:6]N<P!(96EG:'0`2&5L<`!(96UI<W!H97)E`$AI9V@`2&]?;64`2&]M
M92!!9&1R97-S`$AO;64@0VET>0!(;VUE($-O=6YT<GD`2&]M92!0:&]N90!(
M;VUE(%!O<W1A;"!#;V1E`$AO;64@4W1A=&4O4')O=FEN8V4`2&]R9&4`2&]R
M:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(=6UI9&ET>0!)35-0`$E?;G-E<G0@4F]W($)E9F]R90!)
M8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E<P!);7!O
M<G0@061D<F5S<R!";V]K+"!3=&5P("5D`$EM<&]R="P@4W1E<"`E9`!);7!O
M<G0O17AP;W)T($%D9')E<W,@0F]O:W,`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YD:79I9'5A;"!5
M<V5R<P!);F9O<FUA=&EO;@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R
M="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU
M;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0O36]D:69Y($EM86=E`$EN=F%L:60@861D<F5S<R!B;V]K`$EN
M=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@96UA:6P`26YV86QI9"!E;G1R
M>0!);G9A;&ED(&ME>2!S<&5C:69I960N`$EN=F%L:60@;F%M90!);G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+@!);G9E;G1O<GD`271A;&EC`$IA;G5A<GD`
M2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*=6QY`$IU;F4`2G5S=&EF>0!,85]Y
M;W5T`$QA;F=U86=E`$QA<W0@36]D:69I960`3&%S="!.86UE`$QA<W0@475A
M<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%Y;W5T`$QE9G0`3&EG
M:'0@4F%I;@!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$QI=&5R871U<F4`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM
M90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;W<`3&]W
M97(@<F]M86X@;G5M8F5R<P!-30!-86EL`$UA:6P@061M:6X`36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RX`36%R8V@`36%R9VEN`$UA=&-H:6YG`$UA=&-H:6YG(&9I96QD<P!-
M87AI;75M(&YU;6)E<B!O9B!P86=E<P!-87D`365M8F5R<P!-97)G92!C96QL
M<P!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=')I8P!-:61D;&4`36EN
M:2!396%R8V@`36\`36]B:6QE($UA:6P`36]B:6QE(%!H;VYE`$UO9&5R871E
M`$UO9&EF>2!54DP`36]D:69Y(&9A:6QE9#H@*"5S*2`E<P!-;W)E('1H86X@
M,2!E;G1R>2!F;W5N9`!-;W-T;'D@0VQE87(`36]V90!-;W9E(&QE9G0`36]V
M92!R:6=H=`!-=6QB97)R>2!!9&1R97-S($)O;VL`375L=&EP;&4@<&5R<V]N
M<R!W:71H(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@
M86QR96%D>2!E>&ES=`!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@
M3&%Y;W5T`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;64@1F]R;6%T`$YE
M='=O<FL`3F5V97(`3F5W($-A=&5G;W)Y`$YE=R!#;VYT86-T`$YE=R!5<V5R
M;F%M92`H;W!T:6]N86PI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YI8VMN86UE
M`$YI9VAT`$YO("5S(&5N=')Y(&9O=6YD(&9O<B`E<P!.;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYT86-T<R!F
M;W5N9`!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S`$YO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@
M=D-A<F0@9&%T82!W87,@9F]U;F0N`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I
M9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO="!S970`3F]T97,`3F]V
M96UB97(`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(&ET96US('!E<B!P
M86=E`$YU;6)E<B!O9B!R;W=S`$]+`$]B:F5C="!#<F5A=&]R`$]B:F5C="!N
M;W0@9F]U;F0`3V-T;V)E<@!/9F9I8V4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<'1I;VYS`$]P=&EO
M;G,@9F]R("5S`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!/
M=VYE<B!097)M:7-S:6]N<P!01U`@4'5B;&EC($ME>0!02%`@0V]D90!032!,
M:6=H="!286EN`%!A<W-W;W)D`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W
M;W)D<R!M=7-T(&UA=&-H+@!087-T90!0871H`%!E;F1I;F<@4VEG;G5P<SH`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;W1O<P!0:6YE($%D9')E<W,@0F]O
M:P!0:7AE;',`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D`%!O;&QS`%!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0<F5S<W5R90!0<F5S
M<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R
M:79A=&4@061D<F5S<R!";V]K`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO
M;@!0<F]J96-T<P!1=65R>0!1=65R>2!F86EL960Z("@E<RD@)7,`475I8VL@
M4V5A<F-H`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%N9&]M($9O<G1U
M;F4`4F5A9`!296%D(&9A:6QE9#H@*"5S*2`E<P!296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5C;W)D<R!D:7-P;&%Y960Z`%)E9G)E<V@@4&]R
M=&%L(%9I97<Z`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@
M0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@
M9G)O;2!T:&ES(&QI<W0`4F5M;W9E('!A:7(`4F5M;W9E('1H90!296UO=F4@
M=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U
M;F0N`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`
M4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2979E<G0@0V]N9FEG=7)A=&EO
M;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2;U]W
M(%!R;W!E<G1I97,N+BX`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`
M4F]W<SH`4G5L97,`4G5N`%,O34E-12!0=6)L:6,@0V5R=&EF:6-A=&4`4TU3
M($UE<W-A9VEN9P!380!3879E`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO
M=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N
M9FEG=7)A=&EO;BX`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!F86EL
M960`4V5A<F-H(&9A:6QE9#H@)7,`4V5A<F-H:6YG+BXN`%-E;&5C="!A(&=R
M;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R
M`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!T:&4@861D<F5S<R!B;V]K
M('1O(&5X<&]R="!F<F]M.@!396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I
M;7!O<G0@=&\Z`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X
M<&]R="!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C
M="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!F
M;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA;65S.@!396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P
M;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+@!396QE8W0@=VAI8V@@9F]R;6%T
M('1O(&1I<W!L87D@;F%M97,N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@
M4F5P;W)T`%-E;G-O<CH@`%-E<'1E;6)E<@!3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@
M;W!T:6]N<RX`4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3:&%R
M960@1&ER96-T;W)Y`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO
M=R!!;&P`4VAO=R!#;VYT86-T<P!3:&]W($QI<W1S`%-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9P!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,
M871E`%-K:7`@36%I;G1E;F%N8V4`4VYO=R!D97!T:#H@`%-O<G0@1&ER96-T
M:6]N`%-O=7)C97,`4W!A8VEN9P!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3=&%N9&%R
M9`!3=&%T=7,`4W4`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D
M9&5D("5S('1O("5S`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U;6UA<GD`4W5N(%)I
M<V4`4W5N(%-E=`!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3
M=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!4+5-T;W)M`%0M
M4W1O<FUS`%135@!486(@<V5P87)A=&5D('9A;'5E<P!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%R9V5T.@!487-K<P!496UP(&9O<B!L
M87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E
M($%D;6EN:7-T<F%T:6]N`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@8V]N=&%C
M="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+@!4:&4@:61E;G1I='D@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A
M<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4:&5R92!A<F4@;F\@
M=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L
M92!A9&1R97-S(&)O;VMS(&%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T
M;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI
M<R!I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BX`5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W
M(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F
M;W(@9G5R=&AE<B!H96QP+@!4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@
M82!N97<@;&ES="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@
M;V)J96-T+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A
M.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@
M)7,`5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4:&ES(&9I
M;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N`%1H:7,@:7,@)7,N`%1H:7,@
M<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@
M8F]O:P!4:'5N9&5R`%1I8VME=',`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:71L90!4;V1A>0!4;VUO<G)O=P!4;W``5'4`55),`%523#H`56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N9&5R;&EN90!5;F1O
M($-H86YG97,`56YF:6QE9`!5;FET<P!5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N=`!5;G-E="!C;VQO<@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R
M`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5S97(@061M:6YI<W1R871I;VX`57-E<B!296=I<W1R871I;VX`
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92X`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@
M=&AE('-Y<W1E;3H`5F%C871I;VX`5F%R:6%B;&4`5F5R:7-I9VX@1&ER96-T
M;W)Y`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P
M861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE=R!#;VYT86-T`%9I97<@
M86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U
M;'0Z`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%=E`%=E871H97(@1F]R96-A
M<W0`5V5B`%=E8G-I=&4@55),`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC
M;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=I9'1H`%=I9'1H(&]F('1H
M92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6YD.@!7:6YD.B``5V]R:R!!
M9&1R97-S`%=O<FL@0V]U;G1R>0!7;W)K(%!H;VYE`%=O<FL@4&]S=&%L($-O
M9&4`5V]R:R!3=&%T92]0<F]V:6YC90!960!997,L($D@06=R964`66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N
M`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&UU<W0@<V5L96-T(&$@
M=&%R9V5T(&%D9')E<W,@8F]O:RX`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T
M(&QI<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!O;FQY(&AA=F4@<&5R;6ES
M<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U<B!%;6%I;"!!9&1R97-S
M`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($YA
M;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8W5R<F5N="!T:6UE
M('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z
M`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!?061M:6YI<W1R871I;VX`7T)R;W=S90!?1&%T851R
M964`7T1E;&5T90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0
M<F]P97)T:65S+BXN`%]);7!O<G0O17AP;W)T`%],;V<@;W5T`%]-;V1I9GD@
M3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN
M`%]296UO=F4@9G)O;2!T:&ES(&QI<W0`7U-E87)C:`!?5&%B;&4@4')O<&5R
M=&EE<RXN+@!?57-E<G,`8V%L;0!C;VYT86-T+G9C9@!C;VYT86-T<RYC<W8`
M8V]N=&%C=',N='-V`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`;&EN97-=
M`&YA;64`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-T96%D>0!T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'9#87)D`'=E871H97(N8V]M`%!R
M;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@,"XP+C,*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U
M+3`R+3(S(#$W.C0P*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!-87)C;R!0:7)O
M=F%N;R`\;6%R8V\N<&ER;W9A;F]`=6YI8F]C8V]N:2YI=#X*3&%N9W5A9V4M
M5&5A;3H@271A;&EA;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S
M:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES
M;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`(&%L
M;&4@`").;VUE($-O9VYO;64B("AE<RX@36%R:6\@4F]S<VDI`")#;V=N;VUE
M+"!.;VUE(B`H97,N(%)O<W-I+"!-87)I;RD`)60@)7,@92`E<P`E<R`M($%T
M=&5N>FEO;F4`)7,@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO;F4@+2!#;VYF
M97)M80`E<R!497)M:6YI(&0G57-O`"5S(&%G9VEU;G1O+@`E<R!A("5S("5S
M`$9I;&4@)7,@:6UP;W)T871O(&-O;B!S=6-C97-S;P`E<R!M:6YU=&D`)7,@
M;F]N('1R;W9A=&\N`"5S(&$@)7,@9&D@)7,`+"!A("5S("5S`"P@=F%R:6%B
M:6QE(&1A("5S(&$@)7,`1F]R;6%T;R`Q,B!O<F4`1F]R;6%T;R`R-"!O<F4`
M,C0@;W)E`$4G(&YE8V5S<V%R:6\@=6X@8G)O=W-E<B!C:&4@<W5P<&]R=&D@
M:49R86UE<P!-;W-T<F$@04T`04TO4$T`5F%I(&$`4F5G;VQE`$%C8V]U;G0@
M4&%S<W=O<F0`0V]N=&%B:6QI=&$G`$%G9VEU;F=I(%-O='1O($=R=7!P;P!!
M9V=I=6YG:2!Q=6DZ`$%G9VEU;F=I($YU;W9O(%5T96YT90!!9V=I=6YG:2!U
M;B!N=6]V;R!U=&5N=&4Z`$%G9VEU;F=I(&-O;&]N;F$`06=G:75N9VD@=6X@
M;G5O=F\@;65M8G)O`$%G9VEU;F=I('!A:6\`06=G:75N9VD@80!!9V=I=6YG
M:2!U=&5N=&4`3&$@9G5N>FEO;F4@9&D@86=G:75N=&$@=71E;G1I(&YO;B#H
M(&%T=&EV82X`3&ES=&$@4G5B<FEC82X`26YS97)I;65N=&\@<V-H961A(&YE
M;&QA(')U8G)I8V$`4G5B<FEC82!S=G5O=&%T82!C;VX@<W5C8V5S<V\N`$%M
M;6EN:7-T<F%Z:6]N90!0=6)B;&EC:73@`%)I8V5R8V$@079A;GIA=&$`06QI
M87,`06QL:6YE86UE;G1O`$%L;&EN96%M96YT;SH`5'5T=&D`5'5T=&D@9VQI
M(%5T96YT:2!!=71E;G1I8V%T:0!4=71T:2!I($=R=7!P:0!4=71T:2!I(%!E
M<FUE<W-I`%1U='1I(&D@<75A='1R;R!L871I`$=I82<@97-I<W1E;G1E`%5T
M96YZ82!)35-0(&%L=&5R;F%T:79A`$EN9&ER:7IZ;R!E;6%I;"!A;'1E<FYA
M=&EV;P!!=G9I<V$@<W4@86=G:6]R;F%M96YT:0!497-T;R!A;'1E<FYA=&EV
M;SH`4FES<&]S=&$`07!P;&EC87II;VYE`$%P<&QI8V%Z:6]N92!E)R!P<F]N
M=&$N`$%P<FEL90!396D@<VEC=7)O(&1I('9O;&5R(&-A;F-E;&QA<F4@)7,_
M`%-E:2!S:6-U<F\@9&D@=F]L97(@96QI;6EN87)E('%U97-T;R!A<G1I8V]L
M;S\`4V5I('-I8W5R;R!D:2!V;VQE<B!E;&EM:6YA<F4@;&$@<FEC:&EE<W1A
M(&1I(&ES8W)I>FEO;F4@<&5R("5S/P!!<V-E;F1E;G1E`$-H:65D:2!C;VYF
M97)M82!P<FEM82!D:2!E<V5G=6ER92!O<&5R87II;VYI(&1I(&UA;G5T96YZ
M:6]N90!496YT871I=F\@9&D@8V%N8V5L;&%Z:6]N92!D:2!U;B!G<G5P<&\@
M:6YE<VES=&5N=&4N`%1E;G1A=&EV;R!D:2!E;&EM:6YA>FEO;F4@9&D@=6X@
M<&5R;65S<V\@:6YE<VES=&5N=&4N`%1E;G1A=&EV;R!D:2!M;V1I9FEC82!D
M:2!U;B!P97)M97-S;R!I;F5S:7-T96YT90!496YT871I=F\@9&D@;6]D:69I
M8V$@9&D@=6X@<&5R;65S<V\@:6YE<VES=&5N=&4`06=O<W1O`$-A;7!I(&1I
M<W!O;FEB:6QI.@!39F]N9&\`0F%S96QI;F4`4FEC97)C82!396UP;&EC90!,
M:6YK(&9A;&QI=&\N("@E<RD@)7,`26UP;W-T87II;VYI($)L;V-C;P!4:7!O
M(&1I($)L;V-C;P!'<F%S<V5T=&\`4')E9F5R:71I`$UA<F=I;F4`36%R9VEN
M:0!"87-S;P!#871E9V]R:6$@069F87)I`$--4P!30U8`4')O<')I973@(&1E
M;&QE($-?96QL92XN+@!#86QE;F1A<FEO`$-A;&UO`$-A;F-E;&QA`$5L:6UI
M;F$@4F%P<&]R=&\@9&D@4')O8FQE;6$`3W!Z:6]N:0!#871E9V]R:64@92!%
M=&EC:&5T=&4`4')O<')I973@(&1E;&QE(&-E;&QE`%-P97-S;W)E(&-E;&QE
M.@!0<F]P<FEE=.`@9&5L;&4@8V5L;&4`4W!A>FEO(&-E;&QE.@!#96YT<F$`
M36]D:69I8V$`36]D:69I8V$@;F]M92P@:6YD:7)I>GIO(&4@9FER;6$@8VAE
M('9E<G)A;FYO('9I<W5A;&EZ>F%T:2!D86QL92!P97)S;VYE(&-H92!L96=G
M;VYO(&4@<FES<&]N9&]N;R!A:70@='5O:2!M97-S86=G:2X`0VEA9`!697)I
M9FE?8V$@3&EN:RXN+@!38V5G;&D@=6YA(')U8G)I8V$`4V5L97II;VYA(&-O
M;64@=FES=6%L:7IZ87)E(&QE(&1A=&4Z`$5L:6UI;F$@=71E;G1E.B`E<P!%
M;&EM:6YA('5T96YT90!%;&EM:6YA(&QE(&EN9F]R;6%Z:6]N:2!D96QL)W5T
M96YT90!#;&EC8V$@<&5R($-O;G1I;G5A<F4`0VAI=61I(&QA($9I;F5S=')A
M`$YU=F]L90!.=79O;&4`36%R9VEN:2!C;VQL87-S871I`$-O;&]R90!396QE
M>FEO;F$@0V]L;W)E`$-O;&]N;F4Z`$]P>FEO;FD@0V]L;VYN90!6:6=N971T
M90!686QO<FD@<V5P87)A=&D@9&$@=FER9V]L90!686QO<FD@<V5P87)A=&D@
M9&$@=FER9V]L92`H36EC<F]S;V9T($]U=&QO;VLI`$-O;6%N9&\`4VAE;&P@
M9&D@0V]M86YD:0!!>FEE;F1A`$EN9&ER:7IZ;R!,879O<F\`0V]N9&EZ:6]N
M:0!#;VYF:6=U<F$@)7,`0V]N9F5R;6$@4&%S<W=O<F0`0V]N;F5S<VEO;F4@
M9F%L;&ET83H@)7,`0V]N;F5S<VEO;F4@9F%L;&ET80!#;VYT871T:2!R:6UO
M<W-I(&1A;&QA(&QI<W1A+@!#;VYT871T:2!N96QL82!L:7-T83H@)7,`0V]N
M=&EN=6$`0V]P:6$`4V5L97II;VYE(&QA(&-O<&EA`$EM<&]S<VEB:6QE(&EN
M=F5R=&ER92!L82!C;VYF:6=U<F%Z:6]N92X`26UP;W-S:6)I;&4@<V%L=F%R
M92!L82!C;VYF:6=U<F%Z:6]N92`E<RX`26UP;W-S:6)I;&4@<V%L=F%R92!U
M;F$@8V]P:6$@9&D@<V-O<G1A(&1E;&QA(&-O;F9I9W5R87II;VYE`$-O<G-I
M`$-R96$@=6X@8V]L;&5G86UE;G1O`$-R96%N92!U;F\@;G5O=F\`0W)E871O
M`%!E<FUE<W-I(&1I($-R96%T;W)E`$]R82!A='1U86QE`$QA(%523"!A='1U
M86QE(.@`365T96\@071T=6%L90!#;VYD:7II;VYI(&%T='5A;&DZ(`!3=&EL
M92!A='1U86QE`$EM<&]S=&$@;&4@;W!E<F%Z:6]N:2!D82!E<V5G=6ER92!Q
M=6%N9&\@96YT<FD@:6X@)7,N`%1A9VQI80!396QE>FEO;F4@5&%G;&EA`$='
M`$)R;W=S97(@1&%T851R964`1&%T82!2:6-E=G5T;P!':6]R;F\`15]L:6UI
M;F$@0V]L;VYN80!$:6-E;6)R90!.=6UE<F\@9&5C:6UA;&4`0V]L;W)E(&1I
M($1E9F%U;'0`3W)D:6YE(&1I(&1E9F%U;'0Z`$-A;F-E;&QA`$-O;F9E<FUA
M(&1I(&-A;F-E;&QA>FEO;F4`16QM:6YA($=R=7!P;P!%;&EM:6YA(%9A;&]R
M92!/<'II;VYE`$5L:6UI;F$@8V5L;&$`16QI;6EN82!C;VQO;FYA`$%V=FES
M82!S=2!A9V=I;W)N86UE;G1I`$5L:6UI;F%Z:6]N92!F86QL:71A.B`H)7,I
M("5S`$5L;6EN82!R:6=A`$5L:6UI;F$@;"=I9&5N=&ETX"!S96QE>FEO;F%T
M80!%;&EM:6YA(&QA(&-O;&]N;F$@8V]R<F5N=&4`16QI;6EN82!L82!R:6=A
M(&-O<G)E;G1E`$5L:6UI;F%Z:6]N92!&86QL:71A`$1I<&%R=&EM96YT;P!$
M:7-C96YD96YT90!$97-C<FEV:2!I;"!0<F]B;&5M80!3=FEL=7!P;P!0=6YT
M;R!D:2!2=6=I861A`$-A<G1E;&QA`%9I<W5A;&EZ>F$@;F5L(&9O<FUA=&\@
M,C0@;W)E/P!/<'II;VYI(&1I(%9I<W5A;&EZ>F%Z:6]N90!.;VX@96QI;6EN
M87)E`$YO;B!A8V-E9&5R92!D:7)E='1A;65N=&4@82!M86EN=&5N86YC92YP
M:'``4VEC=7)O(&1I('9O;&5R(&-A;F-E;&QA<F4@4$5234%.14Y414U%3E1%
M('%U97-T:2!M97-S86=G:3\`3&$@<')I;6$@<FEG82!C;VYT:65N92!L92!E
M=&EC:&5T=&4@9&D@8V%M<&\_($UA<F-A('-E('-I+"!L87-C:6$@=G5O=&$@
M<V4@;F\Z`%-C87)I8V$@;&$@8V]N9FEG=7)A>FEO;F4@9V5N97)A=&$@8V]M
M92!S8W)I<'0@4$A0+@!38V%R:6-A(&-#87)D`$UO9&EF:6-A`$UO9&EF:6-A
M($)L;V-C;P!-;V1I9FEC82!'<G5P<&\`36]D:69I8V$@4&5R;65S<VD`36]D
M:69I8V$@<&5R;65S<VD@<&5R("5S`$UO9&EF:6-A('-C:&5D82!P97(@)7,`
M36]D:69I8V$@;W!Z:6]N:2!P97(Z`$UO9&EF:6-A('!E<FUE<W-I('!E<B`E
M<P!%;6%I;`!);F1I<FEZ>F\@9&D@4&]S=&$`06=G:6]R;F%T82!L82!S8VAE
M9&$@<&5R("5S+@!%<G)O<F4`3V=N:2`Q-2!M:6YU=&D`3V=N:2`R(&UI;G5T
M:0!/9VYI(#,P('-E8V]N9&D`3V=N:2`U(&UI;G5T:0!/9VYI($UE>GHG;W)A
M`$]G;FD@;6EN=71O`%9A;&]R:2!D:2!E<V5M<&EO.@!%<V5C=7II;VYE`$5S
M<&]R=&$`17-P;W)T82!2=6)R:6-A`$-O;&]R92!&1P!5<&QO860@*$-A<FEC
M86UE;G1O*2!F:6QE(&YO;B!S=7!P;W)T871O+@!!9V=I=6YG:6UE;G1O(&1E
M;"`E<R!A("5S(&9A;&ET83H@)7,`26UP;W-S:6)I;&4@97-A;6EN87)E(&QA
M(&QI<W1A`$EM<&]S<VEB:6QE('!A<W-A<F4@:6X@<F%S<V5G;F$@;&$@9&ER
M96-T;W)Y`%)I8V5R8V$@9&D@;V=G971T:2!D82!A9V=I=6YG97)E(&9A;&ET
M83H@)7,`4FEC97)C82!N96QL82!D:7)E8W1O<GD@9F%L:71A.B`E<P!':75S
M=&\`1F%X`$9E8F)R86EO`%-I('-E;G1E(&-O;64`4VD@<V5N=&4@8V]M93H@
M`%!O8VAI($%C<75A>GIO;FD`1FEL92!-86YA9V5R`$9I;'1R:0!4<F]V80!0
M<FEM82!-971A)P!.;VUE`%!R:6UO(%1R:6UE<W1R90!&;&]A=`!#;VQO<F4@
M1F]N=`!097(@8G)O=W-E<B!C:&4@;F]N('-O<'!O<G1A;F\@;&4@:6UM86=I
M;FD`2&%I(&1I;65N=&EC871O(&QA('1U82!P87-S=V]R9#\`36]D=6QI`$EN
M9&]V:6YO`$9O<G1U;F4@5'EP90!&;W)T=6YE<P!&;W)U;0!);F]L=')I`%9E
M;@!&<F%M97,`55),(&QI8F5R;R]O8V-U<&%T;P!$80!$86P@`$1E<V-R:7II
M;VYE($-O;7!L971A`$QU;F$@4&EE;F$`3F]M92!#;VUP;&5T;P!'96YE<F$@
M0V]N9FEG=7)A>FEO;F4@)7,@`$-O9&EC92!'96YE<F%T;P!2=6)R:6-A(&=L
M;V)A;&4`5F%I(&$`4FEC97)C82!';V]G;&4`1W)U<'!O`$%M;6EN:7-T<F%Z
M:6]N92!'<G5P<&D`1W)U<'!I`%!E<FUE<W-I($]S<&ET:0!!;'1E>GIA`$%I
M=71O`$5M:7-F97)O`$%L=&$`2&]?<F1E`$EN9&ER:7IZ;R!!8FET87II;VYE
M`$-I='3@`%!A97-E`%1E;&5F;VYO($%B:71A>FEO;F4`0T%0`%!R;W9I;F-I
M82!O(%-T871O`$AO<F1E`%)I96UP:6UE;G1O($]R:7IZ;VYT86QE`$]R:7IZ
M;VYT86QE.@!1=6%N=&4@8V]L;VYN92!V=6]I('5N:7)E/P!1=6%N=&D@8V%M
M<&D@*&-O;&]N;F4I(&-I('-O;F\_`%%U86YT92!R:6=H92!V=6]I('5N:7)E
M/P!5;6ED:73@`$E-4U``25]N<V5R:7-C:2!L82!R:6=A('!R:6UA`%-O;&\@
M26-O;F4`26-O;F4@8V]N(%1E<W1O`$YO;64@9&5L;"=)9&5N=&ETX#H`06YT
M97!R:6UE($EM;6%G:6YE`%523"!);6UA9VEN90!54DP@26UM86=I;F4`26UM
M86=I;FD`26UP;W)T87II;VYE(%)U8G)I8V$L('-T97`@)60`26UP;W)T82P@
M4&%S<V\@)60`26UP;W)T82]%<W!O<G1A(%)U8G)I8VAE`$-A;7!O(&EM<&]R
M=&%T;SH@)7,`0V%M<&D@:6UP;W)T871I.@!);E]S97)I<V-I('5N82!R:6=A
M(&1O<&\`571E;G1I($EN9&EV:61U86QI`$EN9F]R;6%Z:6]N90!);G-E<FES
M8VD@=6YA($-?;VQO;FYA(&1O<&\`26YS97)I<V-I('5N)VEM;6%G:6YE`$EN
M<V5R:7-C:2!486)E;&QA`$EN<V5R:7-C:2!#;VQL96=A;65N=&\@5V5B`$EN
M<V5R:7-C:2!?8V]L;VYN82!0<FEM80!);G-E<FES8VD@=6YA(&YU;W9A(&-O
M;&]N;F$@9&]P;R!Q=65L;&$@8V]R<F5N=&4`26YS97)I<V-I('5N82!N=6]V
M82!C;VQO;FYA('!R:6UA(&1I('%U96QL82!C;W)R96YT90!);G-E<FES8VD@
M=6YA(&YU;W9A(')I9V$@9&]P;R!Q=65L;&$@8V]R<F5N=&4`26YS97)I<V-I
M('5N82!N=6]V82!R:6=A('!R:6UA(&1I('%U96QL82!C;W)R96YT90!);G-E
M<FES8VD@=6X@=&5M<&QA=&4@86QT97)N871I=F\`26YS97)I<V-I(&-E;&QA
M(&1O<&\`26YS97)I<V-I(&-E;&QA('!R:6UA`$%G9VEU;F=I(&-O;&]N;F$@
M9&]P;P!);G-E<FES8VD@8V]L;VYN82!P<FEM80!);G-E<FES8VD@<&%R86=R
M869O(&1O<&\`26YS97)I<V-I('!A<F%G<F%F;R!P<FEM80!);G-E<FES8VD@
M<FEG82!D;W!O`$EN<V5R:7-C:2!R:6=A('!R:6UA`$EN<V5R:7-C:2]-;V1I
M9FEC82!);6UA9VEN90!2=6)R:6-A(&YO;B!V86QI9&$N`$%P<&QI8V%Z:6]N
M92!I;G9A;&ED82X`26YD:7)I>GIO(&4M;6%I;"!N;VX@=F%L:61O+@!$871O
M(&YO;B!V86QI9&\N`$-H:6%V92!I;G9A;&ED82!S<&5C:69I8V%T82X`3F]M
M92!N;VX@=F%L:61O+@!$871O(&YO;B!V86QI9&\N`$EN=F5N=&%R:6\`0V]R
M<VEV;P!'96YN86EO`$=I87!P;VYE<V4@*$E33RTR,#(R+4I0*0!,=6=L:6\`
M1VEU9VYO`$=I=7-T:69I8V%T;P!?1F]R;6%T;P!,:6YG=6$`56QT:6UA($UO
M9&EF:6-A`$-O9VYO;64`56QT:6UO(%%U87)T;P!5;'1I;6\@06=G:6]R;F%M
M96YT;SH`56QT:6UO(&%C8V5S<V\Z("5S`%5L=&EM;R!A8V-E<W-O.B`E<R!D
M82`E<P!5;'1I;6\@86-C97-S;SH@36%I`$9O<FUA=&\`<VEN:7-T<F$`4&EO
M9V=I82!,96=G97)A`$5L96YC82!G;&D@87)G;VUE;G1I(&1I($%I=71O`$YO
M;B#H(&%T=&EV82!L82!F=6YZ:6]N92!D:2!E;&5N8V\@=71E;G1I+@!,:71E
M<F%T=7)A`$]R82!L;V-A;&4Z(`!,:6YG=6$@92!/<F$`3'5O9V\`16YT<F$`
M17-C:0!#;VUP:71I(&1I(&EN:7II;R!S97-S:6]N90!"87-S80!N=6UE<FD@
M<F]M86YI('!I^2!B87-S:0!-30!0;W-T80!);F1I<FEZ>F\@06UM:6YI<W1R
M871O<F4`1V5S=&ES8VD@;&$@;&ES=&$@9&5L;&4@8V%T96=O<FEE(&1A;F1O
M(&QO<F\@=6XG971I8VAE='1A(&4@87-S;V-I86YD;R!L;W)O('5N(&-O;&]R
M92X`36%R>F\`36%R9VEN90!#;W)R:7-P;VYD96YT90!#86UP:2!C;W)R:7-P
M;VYD96YT:0!);"!N=6UE<F\@;6%S<VEM;R!D:2!P86=I;F4@92<@9VEA)R!P
M<F5S96YT92X`36%G9VEO`$UE;6)R:0!5;FES8VD@0V5L;&4`365T96\@071T
M=6%L90!";&]C:R!N;VX@9&ES<&]N:6)I;&4N`$1E='1A9VQI(&QO9V=A=&D@
M<&5R(&PG86UM:6YI<W1R871O<F4`;65T<FEC;P!#96YT<F\`4FEC97)C82!6
M96QO8V4`3'5N`$UO8FEL92!-86EL`$-E;&QU;&%R90!-;V1E<F%T;P!-;V1I
M9FEC82!54DP`36]D:69I8V$@9F%L;&ET83H@*"5S*2`E<P!2:7-U;'1A('!I
M)G5G<F%V93L@9&D@=6X@9&%T;RX`4')I;F-I<&%L;65N=&4@4V5R96YO`%-P
M;W-T80!3<&]S=&$@82!S:6YI<W1R80!3<&]S=&$@82!D97-T<F$`4G5B<FEC
M82!-=6QB97)R>0!$:79E<G-E('!E<G-O;F4@8V]N(&EN9&ER:7IZ;R!;)7-=
M+"!M82!N97-S=6YA(&-O;B!N;VUE(%LE<UT@;F5L;&$@<G5B<FEC82X`36EO
M($%C8V]U;G0`36EO(%!O<G1A;&4`1F]R;6%T;R!D96P@36EO(%!O<G1A;&4`
M3D\L($Y/3B!3;VYO(&0G06-C;W)D;RX`3F]M90!&;W)M871O($YO;64`4F5T
M90!-86D`3G5O=F$@0V%T96=O<FEA`$YU;W9O($-O;G1A='1O`$YU;W9O($YO
M;64@571E;G1E("A/<'II;VYA;&4I`$YO=&EZ:64`1W)U<'!I(&1I(&YO=&EZ
M:64`4W5C8V5S<VEV;P!N;VUE`$YO='1E`$YE<W-U;B!D871O("5S('1R;W9A
M=&\@<&5R("5S+@!.;VX@<'5O:2!C<F5A<F4@9FEG;&D@82!Q=65S=&\@<&5R
M;65S<V\N`$YE<W-U;B!C;VYT871T;R!T<F]V871O`$YE<W-U;F$@<F5G:7-T
M<F%Z:6]N92!I;B!A='1E<V$N`$YE<W-U;F$@<F5G;VQA`$YE<W-U;B!L871O
M`$YE<W-U;B!D:7)E='1O<FEO('1E;7!O<F%N96\@9&ES<&]N:6)I;&4@<&5R
M(&QA(&-A8VAE+@!.97-S=6X@8V]M<&QE86YN;R!T<F]V871O+@!.97-S=6YA
M('9E<G-I;VYE('1R;W9A=&$@;F5L;&$@8V]N9FEG=7)A>FEO;F4@;W)I9VEN
M86QE+B!296=E;F5R82!L82!C;VYF:6=U<F%Z:6]N92X`3F5S<W5N82!V97)S
M:6]N92!T<F]V871A(&YE;&QA('1U82!C;VYF:6=U<F%Z:6]N92X@4F5G96YE
M<F$@;&$@8V]N9FEG=7)A>FEO;F4N`$YE<W-U;F\`3F]N(&EM<&]S=&%T;P!.
M;W1E`$YO=F5M8G)E`$YU;65R;R!D:2!C;VQO;FYE`$YU;65R;R!D:2!C87)A
M='1E<FD`3G5M97)O(&1I(')I9VAE`$]+`%!R;W!R:65T87)I;P!/9V=E='1O
M(&YO;B!T<F]V871O`$]T=&]B<F4`569F:6-I;P!!<')I(&EN(&YU;W9A(&9I
M;F5S=')A`$%P<FD@<75E<W1O(&-O;&QE9V%M96YT;R!I;B!N=6]V82!F:6YE
M<W1R80!/<'II;VYI`$]P>FEO;FD@9F]R("5S`$=R;W5P5V%R90!A<'!L:6-A
M>FEO;F4@:6YT97)N80!!;'1R;P!!;'1R92!);F9O<FUA>FEO;FD`06QT<F4@
M3W!Z:6]N:0!097)M97-S:2!D96P@4')O<')I971A<FEO`$-H:6%V92!01U`@
M<'5B8FQI8V$`0V]D:6-E(%!(4`!032!0:6]G9VEA($QE9V=E<F$`4&%S<W=O
M<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``3&4@<&%S<W=O<F0@9&5V;VYO(&-O
M<G)I<W!O;F1E<F4N`$EN8V]L;&$`4&5R8V]R<V\`4F5G:7-T<F%Z:6]N:2!I
M;B!!='1E<V$Z`%!E<F-E;G1U86QE`$5S96=U:2!L92!/<&5R87II;VYI(&1I
M($UA;G5T96YZ:6]N90!%<V5G=6D@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N
M>FEO;F4@86P@;&]G:6X_`%!E<FUE<W-I`%!E<FUE<W-O($YE9V%T;P!!;6UI
M;FES=')A>FEO;F4@9&5I(%!E<FUE<W-I`$EN9F]R;6%Z:6]N:2!097)S;VYA
M;&D`1F]T;P!2=6)R:6-A(%!I;F4`4&EX96P`4')E9V\@8V]N9F5R;6%R92!E
M;&EM:6YA>FEO;F4@96QE;65N=&\Z`%!R96=O(&-O;F9E<FUA<F4@96QI;6EN
M87II;VYE(&QI;FLZ`$EN<V5R:7-C:2!U;B!N;VUE('!E<B!L82!N=6]V82!C
M871E9V]R:6$Z`$1E=FD@:6YS97)I<F4@:6P@='5O(&YO;64@=71E;G1E(&4@
M;&$@<&%S<W=O<F0`4V]N9&%G9VD`4&]S:7II;VYA;65N=&\@9&D@<75E<W1A
M(&EM;6%G:6YE+@!0;W-I>FEO;F%M96YT;R!D:2!Q=65S=&$@=&%B96QL80!0
M<F5S<VEO;F4`4')E<W-I;VYE(&%L(&QI=F5L;&\@9&D@;6%R93H@`%!R97-S
M:6]N93H@`$%N=&5P<FEM80!!;G1E<')I;6$@9&5L;"=I;6UA9VEN92!I;B!N
M=6]V82!F:6YE<W1R80!3=&%M<&$@9&]C=6UE;G1O(`!2=6)R:6-A(%!E<G-O
M;F%L90!0<F]B;&5M80!$97-C<FEZ:6]N92!D96P@<')O8FQE;6$`4')O9V5T
M=&D`1&]M86YD80!1=65R>2!F86QL:71A.B`H)7,I("5S`%)I8V5R8V$@5F5L
M;V-E`%!I;V=G:6$`4&EO9V=I82!0<F5S=&\`4&EO9V=I82!487)D:0!&;W)T
M=6YA($-A<W5A;&4`3&5G9VD`3&5T='5R82!F86QL:71A.B`H)7,I("5S`%-I
M8W5R;R!D:2!V;VQE<B!E;&EM:6-A<F4E<S\@3"=O<&5R87II;VYE(&YO;B!P
M=6\G(&5S<V5R92!A;FYU;&QA=&$`4VEC=7)O(&1I('9O;&5R(&5L:6UI;F%R
M92!I(&1A=&D@9&D@)7,_($PG;W!E<F%Z:6]N92!N;VX@<'5O)R!E<W-E<F4@
M86YN=6QL871A`%-I(')I<&5T92!O9VYI(&=I;W)N;P!!9V=I;W)N82!L82!V
M:7-U86QI>GIA>FEO;F4@4&]R=&%L93H`3F]T90!397)V97(@4F5M;W1I`%52
M3"!R96UO=&$@*&AT='`Z+R]W=W<N97-E;7!I;RYC;VTO:&]R9&4I.@!%;&EM
M:6YA`$5L:6UI;F$@8FQO8V-O`%)I;75O=FD@8V]L;VYN80!2:6UU;W9I($9O
M<FUA='1A>FEO;F4`16QI;6EN82!D82!Q=65S=&$@;&ES=&$`16QI;6EN82!P
M86EO`$5L:6UI;F$@:6P`16QI;6EN82!U=&5N=&4`16QI;6EN82!U=&5N=&4Z
M("5S`$]G9V5T=&\@<FEC:&EE<W1O(&YO;B!T<F]V871O+@!!;FYU;&QA`$%N
M;G5L;&$@4&%S<W=O<F0`06YN=6QL82!L82!T=6$@4&%S<W=O<F0`4FES=6QT
M871I`%1O<FYA(&%L;&4@3W!Z:6]N:2X`26YV97)T:2!L82!#;VYF:6=U<F%Z
M:6]N90!/<'II;VYI($5D:71O<B!2:6-H(%1E>'0`4FED9&QE<P!$97-T<F$`
M4')O<')I973@(&1E;&QA(%)?:6=A+BXN`%!R;W!R:65T82!D96QL82!R:6=A
M`%!R;W!R:65TX"!D96QL82!R:6=A`%)I9VAE.@!296=O;&4`17-E9W5I`$-E
M<G1I9FEC871O(%!U8F)L:6-O(%,O34E-10!-97-S86=G:2!335,`4V%B`%-A
M;'9A`%-A;'9A("5S`%-A;'9A($]P>FEO;FD`4V%L=F$@;&$@8V]N9FEG=7)A
M>FEO;F4@9V5N97)A=&4@8V]M92!S8W)I<'0@4$A0('-U;&QA(&-A<G1E;&QA
M('1E;7!O<F%N96$@9&5L('1U;R!S97)V97(N`%-A;'9A=&\@;&$@8V]N9FEG
M=7)A>FEO;F4@)7,N`$-E<F-A`$UO=&]R92!D:2!R:6-E<F-A`%)I8V5R8V$@
M9F%L;&ET80!2:6-E<F-A(&9A;&QI=&$Z("5S`%)I8V5R8V$@:6X@8V]R<V\N
M+BX`4VQE>FEO;F$@=6X@9W)U<'!O(&1A(&%G9VEU;F=E<F4`4V5L97II;VYA
M('5N(&YU;W9O('!R;W!R:65T87)I;P!396QE>FEO;F$@=6X@<V5R=F5R`%-E
M;&5Z:6]N82!U;B!U=&5N=&4@9&$@86=G:75N9V5R90!396QE>FEO;F$@;&$@
M9F]N=&4@9&$@8W5I(&5S<&]R=&%R93H`4V5L97II;VYA(&EL(&-A;&5N9&%R
M:6\@=F5R<V\@8W5I(&EM<&]R=&%R93H`4V5L97II;VYA(&D@8V%R871T97)I
M(&1I(&-U:2!H86D@8FES;V=N;R!D86QL92!C87-E;&QE('%U:2!S;W1T;RX@
M4'5O:2!Q=6EN9&D@8V]P:6%R;&4@92!I;F-O;&QA<FQE(&1A;&QA('1E>'1A
M<F5A+@!396QE>FEO;F$@:6P@9&5L:6UI=&%T;W)E(&1I(&1A=&$Z`%-E<V-E
M9VQI(&EL(&9O<FUA=&\@9&5L;&$@9&%T83H`4V5L97II;VYA(&EL(&9O<FUA
M=&\@<&5R(&5S<&]R=&%R90!396QE>FEO;F$@:6P@9FEL92!D82!I;7!O<G1A
M<F4Z`%-E;&5Z:6]N82!I;"!F;W)M871O(&EN(&-U:2!E<W!O<G1A<F4Z`%-E
M;&5Z:6]N82!I;"!F;W)M871O('5T:6QI>GIA=&\@<&5R(&UO<W1R87)E(&D@
M;F]M:3H`4V5L97II;VYA(&EL(&1E;&EM:71A=&]R92!D96QL)V]R83H`4V-E
M9VQI(&EL(&9O<FUA=&\@9&5L;"=O<F$Z`%-E;&5Z:6]N82!D=64@8V%M<&D@
M8V]R<FES<&]N9&5N=&DN`%-E;&5Z:6]N82!Q=6%L:2!C86UP:2!M;W-T<F%R
M92!N96QL82!L:7-T82!I;F1I<FEZ>FDN`%-E;&5Z:6]N82!I;B!Q=6%L92!F
M;W)M871O('9I<W5A;&EZ>F%R92!I(&YO;6DN`%-E;&5Z:6]N82!I;"!T=6\@
M<V-H96UA(&-O;&]R:2X`4V5L97II;VYA(&QA(&QI;F=U82!C:&4@<')E9F5R
M:7-C:3H`26YV:6$@:6P@<F5P;W)T(&1E;"!P<F]B;&5M80!396YS;W)E.B``
M4V5T=&5M8G)E`$EM<&]S=&D@:2!S97)V97(@<F5M;W1I(&%I('%U86QI('9U
M;VD@86-C961E<F4@9&%L('1U;R!P;W)T86QE+@!396QE>FEO;F$@;&$@;&EN
M9W5A('!R969E<FET82!E(&EL(&9U<V\@;W)A<FEO+@!-;V1I9FEC82!L82!T
M=6$@87!P;&EC87II;VYE(&1I(&%V=FEO+"!G;&D@<V-H96UI(&-O;&]R92P@
M960@86QT<F4@;W!Z:6]N:2!D:2!V:7-U86QI>GIA>FEO;F4N`%-C<FEP="!D
M:2!A9V=I;W)N86UE;G1O(&1E;"!S971U<"!D:7-P;VYI8FEL90!$:7)E8W1O
M<GD@0V]N9&EV:7-A`%-H;W!P:6YG`$)R979E(%)I87-S=6YT;P!$969I;FEA
M;6\@9VQI(&%C8V5S<VD@9&$@=&%S=&EE<F$@<&5R(&D@;&EN:S\`36]S=')A
M`$UO<W1R82!4=71T;P!-;W-T<F$@0V]N=&%T=&D`36]S=')A($QI<W1E`$UO
M<W1R82!L)W5L=&EM;R!L;V=I;B!A;&PG86-C97-S;S\`36]S=')A('1A8F5L
M;&$@;W!E<F%Z:6]N:2!N96QL82!B87)R82!D96P@;65N=3\`36]S=')A(&EL
M("5S($UE;F\@<W5L;&$@<VEN:7-T<F$_`$UO<W1R82!L92!0<F]P<FEE=.`@
M5&%B96QL82!#96QL80!-;W-T<F$@;&4@4')O<')I973@(%1A8F5L;&$`36]S
M=')A(&QE(%!R;W!R:65TX"!486)E;&QA(%)I9V$`06-Q=6%Z>F]N:0!!8W%U
M87IZ;VYI(&$@0G)E=F4`06-Q=6%Z>F]N:2!487)D:0!386QT82!-86YU=&5N
M>FEO;F4`4')O9F]N9&ET82<@9&D@;F5V93H@`$1I<F5Z:6]N92!D:2!O<F1I
M;F%M96YT;P!54DP@3F]T:7II80!3<&%Z:6%T=7)A`%-P86T`0V%R871T97)E
M(%-P96-I86QE`$1I=FED:2!#96QL80!$:79I9&D@8V]L;VYN80!$:79I9&D@
M4FEG80!3=&%N9&%R9`!3=&%T;P!$;VT`4V]T=&]S8W)I=FD`4W5C8V5S<V\`
M06=G:75N=&\@8V]N('-U8V-E<W-O("5S(&$@)7,`4V%L=F%T;R!L82!C;VYF
M:6=U<F%Z:6]N92X`4V-R:71T;R!C;VX@<W5C8V5S<V\@)7,`4FEA<W-U;G1O
M`$%L8F$`5')A;6]N=&\`06QB80!!;&)A+U1R86UO;G1O`$%L8F$Z(`!4<F%M
M;VYT;P!4<F%M;VYT;SH@`%-U<&5R<V-R:7!T`%-U<'!O<G1O`%0M5&5M<&5S
M=&$`5"U496UP97-T90!44U8`5F%L;W)I('-E<&%R871I(&1A(%1A8@!0<F]P
M<FEE=.`@5&%B96QL80!0<F]P<FEE=.`@5&%B96QL80!$97-T:6YA>FEO;F4Z
M`$%T=&EV:73@`%1E;7!E<F%T=7)A('5L=&EM82!O<F$Z(`!496UP97)A='5R
M80!496UP97)A='5R83H@`$%M;6EN:7-T<F%Z:6]N92!496UP;&%T90!3;VQO
M(%1E<W1O`$%L;&EN96%M96YT;R!T97-T;P!497-T;R!I;B!A;'1O`$=I;P!'
M<F%Z:64@9&D@879E<B!U<V%T;R!I;"!S:7-T96UA+@!,)V]G9V5T=&\@<FEC
M:&EE<W1O(&YO;B!E<VES=&4N`$PG:61E;G1I=.`@(B5S(B!E)R!S=&%T82!E
M;&EM:6YA=&$N`$EL('-E<G9E<B`B)7,B(&4G('-T871O(&5L:6UI;F%T;RX`
M26P@<V5R=F5R("(E<R(@92<@<W1A=&\@<V%L=F%T;RX`3&$@<FEC:&EE<W1A
M(&1I(')E9VES=')A>FEO;F4@<&5R("5S(.@@<W1A=&$@96QI;6EN871A+@!)
M;"!M;V1U;&\@=V5A=&AE<BYC;VT@;F]N(.@@9&ES<&]N:6)I;&4N`$YO;B!C
M:2!S;VYO(')U8G)I8VAE(&5S86UI;F%B:6QI+@!.97-S=6YA(&1E;&QE(')U
M8G)I8VAE(&1I<W!O;FEB:6QI(.@@8V]N9FEG=7)A=&$@:6X@;6]D;R!D82!C
M;VYS97)T:7)T:2!D:6%G9VEU;F=E<F4@;G5O=F4@96YT<F%T92X@4V4@<&5N
M<VD@<VEA('5N(&5R<F]R92P@<&5R(&9A=F]R92!C;VYT871T82!I;"!T=6\@
M86UM:6YI<W1R871O<F4@9&D@<VES=&5M82X`0R<F96=R879E.R!S=&%T;R!U
M;B!E<G)O<F4@86=G:75N9V5N9&\@<75E<W1O(&]G9V5T=&\N($-O;G1A='1A
M(&EL('1U;R!A;6UI;FES=')A=&]R92!D:2!S:7-T96UA('!E<B!U;'1E<FEO
M<F4@86EU=&\N`$5R<F]R92!N96QL82!C<F5A>FEO;F4@9&D@=6YA(&YU;W9A
M(&QI<W1A+@!%<G)O<F4@;F5L;&$@8V%N8V5L;&%Z:6]N92!D96QL)V]G9V5T
M=&\N`$5R<F]R92!N96QL)VEM<&]R=&%Z:6]N92!D96D@9&%T:3H@)7,`4VD@
M92<@=F5R:69I8V%T;R!U;B!E<G)O<F4@;F5L;"=A9V=I;W)N86UE;G1O(&1I
M('%U97-T;R!O9V=E='1O.B`E<P!.;VX@8VD@<V]N;R!I;F1I<FEZ>FD@9&$@
M97-P;W)T87)E+@!1565S=&\@9F]R;6%T;R!D:2!F:6QE(&YO;B`F96=R879E
M.R!S=7!P;W)T871O+@!1=65S=&\@92<@)7,N`%%U97-T82!P97)S;VYA(&AA
M(&=I82<@=6YA("5S('-C:&5D82!N96QL82!R=6)R:6-A+@!4=6]N;P!4:6-K
M970`1V5S=&EO;F4@9&5L(%1E;7!O`$9O<FUA=&\@3W)A`%1I=&]L;P!/9V=I
M`$1O;6%N:0!!;'1O`$UA<@!54DP`55),.@!);7!O<W-I8FEL92!C87)I8V%R
M92!L92!D969I;FEZ:6]N:2!D:2`E<RX`4V]T=&]L:6YE80!);F1I971R;P!)
M;F1E9FEN:71O`%5N:73@`$5L:6UI;F$@16QE;65N=&\@0V]R<F5N=&4`16QI
M;6EN82!#;VQO<F4`06=G:6]R;F$`06=G:6]R;F$@)7,`06=G:6]R;F$@=71E
M;G1E`%-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&5L:6UI;F%T;RX`06=G:6]R
M;F$`3G5M97(@<F]M86YI(&%L=&D`06UM:6YI<W1R87II;VYE(%5T96YT:0!2
M96=I<W1R87II;VYE(%5T96YT90!)<V-R:7II;VYE(%5T96YT92!E)R!S=&%T
M;R!D:7-A8FEL:71A=&\@<&5R('%U97-T;R!S:71O+@!.;VUE(%5T96YT90!.
M;VUE(%5T96YT93H`3F]M92!5=&5N=&4Z`%5T96YT:2!N96P@<VES=&5M83H`
M5F%C86YZ90!687)I86)I;&4`1&ER96-T;W)Y(%9E<FES:6=N`$-O;G1R;VQL
M;R!697)S:6]N90!!;&QI;F5A;65N=&\`4FEE;7!I;65N=&\@5F5R=&EC86QE
M`%9E<G1I8V%L93H`36]L=&\@06QT;P!6:7-U86QI>GIA($-O;G1A='1O`%9I
M<W5A;&EZ>F$@=6YA('!A9VEN82!W96(@97-T97)N80!6:7-T82!D82!M;W-T
M<F%R92!D:2!D969A=6QT.@!6:7-I8FEL:73@`%9I<VEB:6QI=.`Z(`!-97(`
M4')E=FES:6]N92!-971E;P!796(`55),(&1I(&)A<V4`0F5N=F5N=71O`$)E
M;G9E;G5T;R!A("5S`$)E;G9E;G5T;RP@)7,`0VAE(&%P<&QI8V%Z:6]N92`E
M<R!D979E(&UO<W1R87)E(&1O<&\@:6P@;&]G:6X_`$-O<V$@92<@8V%R871T
M97)E(&1E;&EM:71A=&]R90!#;W-A(&4G(&EL(&-A<F%T=&5R92!V:7)G;VQE
M='1E/P!,87)G:&5Z>F$`06UP:65Z>F$@9&5L;&$@=&%B96QL80!5;FETX"!,
M87)G:&5Z>F$`3&%R9VAE>GIA.@!696YT;SH`5F5N=&\Z(`!);F1I<FEZ>F\@
M9&D@3&%V;W)O`%!A97-E`%1E;&5F;VYO(&1I(&QA=F]R;P!#05``4')O=FEN
M8VEA(&\@4W1A=&\`04$`4VDL('-O;F\@9"=A8V-O<F1O`$YO;B!H86D@:6P@
M<&5R;65S<V\@9&D@=FES=6%L:7IZ87)E(&PG;V=G971T;RX`3F]N(&AA:2!I
M;"!P97)M97-S;R!D:2!V:7-U86QI>GIA<F4@;"=O9V=E='1O+@!,82!S97-S
M:6]N92#H('-T871A('1E<FUI;F%T82X`1&5V:2!P<FEM82!S96QE>FEO;F%R
M92!U;B!I;F1I<FEZ>F\N`$1E=FD@<')I;6$@<V5L97II;VYA<F4@=6YA(&-A
M<V5L;&$@9&D@9&5S=&EN87II;VYE+@!$979I('-P96-I9FEC87)E(&EL('-E
M<G9E<B!D82!E;&EM:6YA<F4N`$1E=FD@<')I;6$@<W!E8VEF:6-A<F4@86QM
M96YO('5N(&UE<W-A9V=I;RX`1&5V:2!S<&5C:69I8V%R92!L;R!U<V5R;F%M
M92!D82!R:6UU;W9E<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@
M9&$@<FEM=6]V97)E+@!$979I('-P96-I9FEC87)E(&QO('5S97)N86UE(&1A
M(&%G9VEU;F=E<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@9&$@
M86=G:6]R;F%R92X`2&%I('-O;&\@:6P@<&5R;65S<V\@9&D@=FES=6%L:7IZ
M87)E(&PG;V=G971T;RX`5'5O($EN9&ER:7IZ;R!%;6%I;`!4=6\@26YD:7)I
M>GIO($5M86EL`%9O<W1R82!I;F9O<FUA>FEO;F4`26P@='5O(&YO;64`26P@
M='5O(&)A8VME;F0@9&D@875T96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A(&QA
M(&5L96YC87II;VYE(&1E9VQI('5T96YT:2P@;R!L82!C87)A='1E<FES=&EC
M82#H('-T871A(&1I<V%B:6QI=&%T82!P97(@<75A;&-H92!M;W1I=F\N`$EL
M('1U;R!B<F]W<V5R(&YO;B!H82!Q=65S=&$@8V%P86)I;&ET82<N`$EL('1U
M;R!F=7-O(&]R87)I;R!A='1U86QE.@!)9&5N=&ETX"!D:2!$969A=6QT`$EL
M('1U;R!N;VUE.@!)('1U;VD@<V5R=F5R(')E;6]T:3H`6T1O8W5M96YT;R!D
M:2!D97-C<FEZ:6]N92!D96P@<')O8FQE;6%=`%M-;W-T<F$@5&5S=&\@<75O
M=&%T;R`M`%]!;6UI;FES=')A>FEO;F4`7U-F;V=L:6$`7T1A=&%4<F5E`%]%
M;&EM:6YA`%]%;&EM:6YA(%)I9V$`7T=R=7!P:0!?06EU=&\`4')O<')I973@
M(&1E;&PG7TEM;6%G:6YE+BXN`%]);7!O<G1A+T5S<&]R=&$`7T9I;F4@<V5S
M<VEO;F4`7TUO9&EF:6-A($QI;FLN+BXZ`%]/<'II;VYI`%]097)M97-S:0!?
M16QI;6EN82!,:6YK+BXN`%]%;&EM:6YA(&1A('%U97-T82!L:7-T80!?0V5R
M8V$`4')O<')I973@(&1E;&QA(%]486)E;&QA`%]5=&5N=&D`8V%L;6\`8V]N
M=&%T=&DN8W-V`&-O;G1A='1I+F-S=@!C;VYT871T:2YT<W8`9&%L;&4@)7,@
M*"5S*2!A;&QE("5S("5S`&QI;F5E70!N;VUE`'!E<F-E;G1O`'!I>&5L<P!A
M=6UE;G1A;F1O)P!C;W-T86YT90!D:6=I=&$@;&$@<&%S<W=O<F0@9'5E('9O
M;'1E('!E<B!C;VYF97)M87)E`'9#87)D`'=E871H97(N8V]M````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]K;U]+4B\`
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-34`,#(P,#`W`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R
M8F$O;&]C86QE+VMO7TM2+TQ#7TU%4U-!1T53+P``````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C$U-S0`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O:V]?2U(O3$-?34534T%'15,O
M='5R8F$N;6\``````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<R,#0Q`#$P-#$W,S8R-S4U
M`#`R,S(T-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#>$@25`````!4"```<````Q!```,\"``!L(0```````*@L```/````
MJ2P```@```"Y+```"P```,(L```,````SBP``"0```#;+```)0`````M```H
M````)BT```D```!/+0``$@```%DM```=````;"T```X```"*+0``"````)DM
M```K````HBT```4```#.+0``$0```-0M```#````YBT```\```#J+0``"@``
M`/HM```(````!2X```8````.+@``"````!4N```9````'BX```<````X+@``
M%````$`N```2````52X``"$```!H+@``#@```(HN```/````F2X```4```"I
M+@``!0```*\N```*````M2X```,```#`+@``#@```,0N```.````TRX```\`
M``#B+@``'P```/(N```%````$B\``#H````8+P``"0```%,O```Y````72\`
M``8```"7+P``$0```)XO```*````L"\``!````"[+P``#````,PO```(````
MV2\```0```#B+P``!@```.<O```1````[B\```<`````,```!`````@P```&
M````#3````T````4,````P```"(P```3````)C````@````Z,```!@```$,P
M```5````2C````<```!@,```"@```&@P```/````<S````T```"#,```#P``
M`)$P```-````H3````D```"O,```!@```+DP```&````P#````X```#',```
M#P```-8P```%````YC```!8```#L,```*@````,Q```3````+C$```P```!"
M,0``$````$\Q```1````8#$```4```!R,0``!0```'@Q```.````?C$```8`
M``"-,0``%@```)0Q```J````JS$```<```#6,0``#P```-XQ```0````[C$`
M`!4```#_,0``$@```!4R```4````*#(```0````],@``#@```$(R```I````
M43(```T```![,@``!P```(DR```.````D3(```T```"@,@```P```*XR```-
M````LC(```(```#`,@``!0```,,R```$````R3(```X```#.,@``"````-TR
M```/````YC(```\```#V,@``!P````8S```0````#C,``!H````?,P``!@``
M`#HS```3````03,``!<```!5,P``"P```&TS```-````>3,``!8```"',P``
M"@```)XS```9````J3,``!8```##,P``#P```-HS```*````ZC,```H```#U
M,P``%``````T```O````%30```D```!%-```#P```$\T```F````7S0``"@`
M``"&-```0P```*\T```+````\S0```X```#_-```!`````XU```7````$S4`
M`!$````K-0``$0```#TU```*````3S4```(```!:-0``!0```%TU```)````
M8S4```T```!M-0``#@```'LU```8````BC4``!4```"C-0``!0```+DU```0
M````OS4``!````#0-0``#P```.$U```+````\34```\```#]-0``#`````TV
M```/````&C8```X````J-@``!@```#DV```3````0#8```@```!4-@``'@``
M`%TV```E````?#8``!H```"B-@``%0```+TV```>````TS8``"$```#R-@``
M)0```!0W```B````.C<```,```!=-P``"````&$W```,````:C<```<```!W
M-P``!````'\W```*````A#<```H```"/-P``!@```)HW```$````H3<```<`
M``"F-P``$P```*XW```"````PC<```8```#%-P``!````,PW```1````T3<`
M`"(```#C-P``#`````8X```)````$S@```P````=.```"@```"HX```0````
M-3@``!,```!&.```$P```%HX```%````;C@```\```!T.```$@```(0X```+
M````ES@``"D```"C.```)````,TX```F````\C@``!(````9.0``"@```"PY
M```/````-SD``!````!'.0``#@```%@Y```)````9SD```H```!Q.0``'```
M`'PY```;````F3D``!(```"U.0``$````,@Y```1````V3D```\```#K.0``
M%````/LY```,````$#H```P````=.@``#P```"HZ```5````.CH``"D```!0
M.@``*@```'HZ```F````I3H``"<```#,.@``*0```/0Z```J````'CL``!$`
M``!).P``$@```%L[```3````;CL``!0```"".P``%@```)<[```7````KCL`
M`!````#&.P``$0```-<[```3````Z3L``!(```#].P``%````!`\```-````
M)3P```P````S/```$````$`\```&````43P```<```!8/```!0```&`\```6
M````9CP```0```!]/```!````((\```'````ASP```X```"//```#````)X\
M```,````JSP```T```"X/```$@```,8\```/````V3P```@```#I/```#0``
M`/(\```)`````#T```X````*/0``%@```!D]```1````,#T```8```!"/0``
M!````$D]```$````3CT``!````!3/0``&@```&0]```&````?ST```<```"&
M/0``"P```(X]```3````FCT``!,```"N/0``$P```,(]```"````UCT```0`
M``#9/0``#0```-X]```%````[#T```8```#R/0``"````/D]```/`````CX`
M`!<````2/@```P```"H^```*````+CX```L````Y/@``!P```$4^```&````
M33X```L```!4/@``#````&`^```*````;3X``!8```!X/@``!P```(\^```$
M````ESX```D```"</@``!P```*8^```)````KCX```H```"X/@``%0```,,^
M``!)````V3X```0````C/P``"P```"@_```'````-#\```4````\/P``"P``
M`$(_```3````3C\```0```!B/P``"````&<_```"````<#\``!<```!S/P``
M,P```(L_```S````OS\``#@```#S/P``$0```"Q````8````/D````0```!7
M0```!0```%Q````(````8D```!$```!K0```&````'U````.````ED```!``
M``"E0```!P```+9````?````OD````<```#>0```#@```.9````,````]4``
M``P````"00``!0````]!```1````%4$```T````G00``!P```#5!```(````
M/4$``!4```!&00``!0```%Q!```4````8D$```0```!W00``!P```'Q!```>
M````A$$``!$```"C00``$0```+5!```4````QT$```4```#<00``$0```.)!
M```&````]$$``"@```#[00``*0```"1"```'````3D(``"$```!60@``#@``
M`'A"```4````AT(``!,```"<0@``%0```+!"```,````QD(``!(```#30@``
M%P```.9"```-````_D(``!4````,0P``"P```")#```%````+D,``!$````T
M0P``$0```$9#```%````6$,``!(```!>0P``!````'%#```.````=D,```X`
M``"%0P``!0```)1#```2````FD,```0```"M0P``#````+)#```&````OT,`
M``T```#&0P``$0```-1#```,````YD,``"<```#S0P``)0```!M$``!I````
M040``!H```"K1```%P```,9$```9````WD0``!H```#X1```)0```!-%```H
M````.44``!<```!B10``&P```'I%```T````ED4``"4```#+10``'P```/%%
M```3````$48```D````E1@``$````"]&```(````0$8```T```!)1@``"@``
M`%=&```E````8D8``"````"(1@``)````*E&```@````SD8```0```#O1@``
M$````/1&```.````!4<```<````41P``'````!Q'```H````.4<```<```!B
M1P``$P```&I'```7````?D<```H```"61P``#````*%'```)````KD<```T`
M``"X1P``"P```,9'```'````TD<```8```#:1P``"0```.%'```'````ZT<`
M`!L```#S1P``!P````](```+````%T@``!0````C2```$````#A(```0````
M24@```4```!:2```!````&!(```)````94@```H```!O2```'P```'I(```H
M````FD@``"D```##2```&P```.U(```^````"4D``",```!(20``)@```&Q)
M```?````DTD``,P```"S20``/0```(!*``!>````ODH``"<````=2P``+```
M`$5+```H````<DL``"D```";2P``,````,5+```J````]DL``"(````A3```
M(0```$1,```V````9DP``!P```"=3```!0```+I,```0````P$P```(```#1
M3```$@```-1,```#````YTP``!````#K3````P```/Q,```O`````$T``"``
M```P30``)````%%-```E````=DT``"````"<30``)@```+U-```)````Y$T`
M``P```#N30``%P```/M-```.````$TX```T````B3@``&@```#!.```'````
M2TX```L```!33@``$P```%].```3````<TX```P```"'3@``"````)1.```4
M````G4X``!(```"R3@``#@```,5.```0````U$X```<```#E3@``#````.U.
M```;````^DX```<````63P``!@```!Y/```'````)4\```T````M3P``"P``
M`#M/```@````1T\``!P```!H3P``!0```(5/```2````BT\```H```">3P``
M!@```*E/```,````L$\```D```"]3P``#````,=/```*````U$\``!````#?
M3P``$P```/!/```3````!%````(````84```!@```!M0```#````(E```$4`
M```F4```&0```&Q0``!%````AE```#````#,4```)@```/U0```>````)%$`
M`"D```!#40``)@```&U1```E````E%$``"X```"Z40``,````.E1```2````
M&E(``!,````M4@``$````$%2```)````4E(``',```!<4@``*P```-!2```7
M````_%(``!8````44P``#P```"M3``!`````.U,``!\```!\4P``$@```)Q3
M```0````KU,``!,```#`4P``'0```-13```/````\E,```H````"5```#P``
M``U4```'````'50```<````E5```"P```"U4```%````.50``!0````_5```
M#@```%14```(````8U0```\```!L5```"````'Q4```/````A50``!8```"5
M5```!P```*Q4```4````M%0```8```#)5```!````-!4```'````U50```8`
M``#=5```!P```.14```%````[%0``%(!``#R5```#````$56```'````4E8`
M``<```!:5@``!P```&)6```5````:E8``!<```"`5@``%P```)A6```*````
ML%8``!4```"[5@``(@```-%6```3````]%8```<````(5P``)P```!!7```)
M````.%<```L```!"5P``!````$Y7```3````4U<```D```!G5P``#P```'%7
M```$````@5<```L```"&5P``%````))7```$````IU<```T```"L5P``"P``
M`+I7```:````QE<```0```#A5P``"0```.97```$````\%<```0```#U5P``
M!0```/I7```)`````%@```@````*6```"P```!-8```'````'U@``!<````G
M6````P```#]8```@````0U@```@```!D6```%P```&U8```#````A5@```P`
M``")6```!````)98```)````FU@```D```"E6```!````*]8```$````M%@`
M``0```"Y6```"0```+Y8```$````R%@```0```#-6```!````-)8```+````
MUU@```,```#C6```#````.=8```$````]%@```0```#Y6```$@```/Y8```$
M````$5D```8````660``!P```!U9```'````)5D```<````M60``!P```#59
M```&````/5D```8```!$60``!````$M9```.````4%D```0```!?60``!```
M`&19```+````:5D``!4```!U60``%````(M9```'````H%D```T```"H60``
M"P```+99```$````PED```,```#'60``"0```,M9```&````U5D``!````#<
M60``&P```.U9```$````"5H```D````.6@``"0```!A:```-````(EH```D`
M```P6@``%P```#I:```$````4EH```0```!76@``*P```%Q:```+````B%H`
M``0```"46@``"@```)E:```+````I%H```8```"P6@``!@```+=:```"````
MOEH```0```#!6@``!````,9:```)````RUH```0```#56@``!````-I:```(
M````WUH```0```#H6@``"P```.U:```.````^5H```0````(6P``"0````U;
M```.````%UL```<````F6P``!P```"Y;```2````-EL```<```!)6P``#```
M`%%;```,````7EL```D```!K6P``!````'5;```(````>EL```D```"#6P``
M*@```(U;```(````N%L```D```#!6P``)P```,M;```0````\UL``$,````$
M7```"P```$A<```.````5%P```0```!C7```#````&A<```,````=5P```X`
M``""7```!P```)%<```"````F5P```8```"<7```"````*-<```)````K%P`
M``L```"V7```#0```,)<```)````T%P```0```#:7```"0```-]<```)````
MZ5P```@```#S7```"P```/Q<```)````"%T```0````270```P```!==```-
M````&UT```@````I70``#P```#)=```&````0ET``!,```!)70``%````%U=
M```8````<ET``!````"+70``$0```)Q=```3````KET``!H```#"70``%@``
M`-U=```$````]%T```,```#Y70``"P```/U=```$````"5X```0````.7@``
M!````!->```)````&%X```8````B7@``!````"E>```$````+EX```L````S
M7@``!````#]>```$````1%X```8```!)7@``!@```%!>```>````5UX```<`
M``!V7@``!````'Y>```$````@UX```<```"(7@``"````)!>```%````F5X`
M``<```"?7@``!0```*=>```&````K5X```D```"T7@``!0```+Y>```3````
MQ%X```X```#87@``$P```.=>```.````^UX```8````*7P``#0```!%?```,
M````'U\```X````L7P``"````#M?```)````1%\``!@```!.7P``&````&=?
M```/````@%\```P```"07P``$````)U?```(````KE\``!````"W7P``"0``
M`,A?```'````TE\```P```#:7P``#@```.=?```7````]E\``!<````.8```
M%P```"9@```7````/F```!@```!68```&````&]@```,````B&````P```"5
M8```#````*)@```,````KV````X```"\8```#@```,M@```,````VF````P`
M``#G8```#@```/1@```.`````V$```T````280``#@```"!A```,````+V$`
M`!(````\80``"````$]A```#````6&$```0```!<80``%````&%A```#````
M=F$```,```!Z80``!````'YA```+````@V$```D```"/80``"0```)EA```+
M````HV$```@```"O80``#P```+AA```$````R&$```L```#-80```@```-EA
M```1````W&$``"````#N80``$P````]B```(````(V(```0````L8@``!@``
M`#%B```+````.&(``!L```!$8@``!@```&!B```(````9V(```\```!P8@``
M#0```(!B```+````CF(``!````":8@```@```*MB```$````KF(``!````"S
M8@```P```,1B```(````R&(```L```#18@``#0```-UB```-````ZV(```,`
M``#Y8@``"0```/UB```)````!V,```8````18P``!@```!AC```+````'V,`
M``8````K8P``"````#)C```2````.V,```0```!.8P``!````%-C```+````
M6&,```D```!D8P``#0```&YC```/````?&,```\```",8P``00```)QC```$
M````WF,```D```#C8P``"````.UC```(````]F,``!(```#_8P``#0```!)D
M```$````(&0```0````E9```!@```"ID```+````,60``",````]9```'```
M`&%D```A````?F0```L```"@9```%````*QD```-````P60```0```#/9```
M!````-1D```'````V60``!(```#A9```!P```/1D```)````_&0```0````&
M90``$0````ME```(````'64```L````F90``"0```#)E```$````/&4```0`
M``!!90``"0```$9E```)````4&4```0```!:90``!````%]E```9````9&4`
M``8```!^90``$P```(5E```$````F64```8```">90``$P```*5E```)````
MN64```D```##90``"0```,UE```(````UV4```L```#@90``!````.QE```A
M````\64``!X````39@``"````#)F```0````.V8```D```!,9@``"P```%9F
M```)````8F8``!(```!L9@``"0```']F```$````B68``!````".9@``"0``
M`)]F```/````J68```\```"Y9@``"0```,EF```&````TV8``!$```#:9@``
M!@```.QF```,````\V8```0`````9P``!P````5G```'````#6<```,````5
M9P``$@```!EG```$````+&<```T````Q9P``!````#]G```)````1&<```T`
M``!.9P``"0```%QG```3````9F<``!,```!Z9P``.P```(YG```3````RF<`
M``X```#>9P``$@```.UG```3`````&@``!,````4:```%````"AH```.````
M/6@``!D```!,:```'@```&9H```3````A6@``!\```"9:```&````+EH```#
M````TF@```T```#6:```"0```.1H```+````[F@```L```#Z:```#@````9I
M```.````%6D```X````D:0``$````#-I```$````1&D```T```!):0``"0``
M`%=I```$````86D```8```!F:0``&@```&UI```$````B&D```T```"-:0``
M#@```)MI```'````JFD```<```"R:0``!P```+II```(````PFD```L```#+
M:0``!````-=I```$````W&D```@```#A:0``!````.II```;````[VD```0`
M```+:@``!@```!!J```0````%VH```<````H:@``!P```#!J```$````.&H`
M``8````]:@``!````$1J```)````26H``!@```!3:@``'0```&QJ```9````
MBFH``!X```"D:@``+0```,-J```>````\6H``!T````0:P``'P```"YK``![
M````3FL``#\```#*:P``1@````IL```9````46P```X```!K;```"0```'IL
M```8````A&P``!X```"=;```#0```+QL```?````RFP``"D```#J;```)P``
M`!1M```8````/&T```0```!5;0``#0```%IM```)````:&T```X```!R;0``
M`@```(%M```1````A&T```,```"6;0``+0```)IM```>````R&T``!L```#G
M;0``)`````-N```H````*&X``"$```!1;@``!````'-N```1````>&X``!``
M``"*;@``!````)MN```$````H&X``!4```"E;@``"0```+MN```)````Q6X`
M``T```#/;@``$````-UN```/````[FX```@```#^;@``$`````=O```1````
M&&\```D````J;P``"0```#1O```'````/F\```L```!&;P``#````%)O```$
M````7V\```0```!D;P``!````&EO```6````;F\```X```"%;P``%P```)1O
M```7````K&\```0```#$;P``"0```,EO```)````TV\```4```#=;P``"0``
M`.-O```)````[6\```D```#W;P``"0````%P```-````"W````H````9<```
M"0```"1P```"````+G````0````Q<````@```#9P```]````.7```!0```!W
M<```/@```(QP```I````RW```!D```#U<```&0````]Q```9````*7$``"4`
M``!#<0``)0```&EQ```E````CW$``"P```"U<0``#````.)Q```*````[W$`
M``0```#Z<0``!0```/]Q``!S````!7(``"<```!Y<@``#````*%R```,````
MKG(```H```"[<@``'P```,9R```6````YG(```T```#]<@``#P````MS```,
M````&W,``!,````H<P``#@```#QS```)````2W,```8```!5<P``!@```%QS
M```&````8W,```D```!J<P``!@```'1S```.````>W,``!,```"*<P``"@``
M`)YS```.````J7,```H```"X<P``#0```,-S```6````T7,```8```#H<P``
M#````.]S```#````_',```0`````=```!@````5T```$````#'0```D````1
M=```!0```!MT```!````]P$``($!````````.`$``-,```````````````T!
M``#Z`````````$T```!X`0```````+P````Y`0````````(!````````HP$`
M`%8!``"R````NP$``&4!``"&````CP$``.T`````````P`````P`````````
MR````!P!``!0`0``*P$``(H```!&````G`$``#````"N````<@```.@```#P
M``````````8"``#[`````````!0`````````+`````````##````/@$`````
M```O`0``H```````````````$`(``+<````D`0``H`$``/P!``!F````]0``
M`#`!``#V`0```````#H!``#0`0````````4````$``````````````#S````
M=0$``(4!```;`0```````/0!`````````````%@````Q````K0$``'H`````
M````!@$``#D```!O`0```````/X!``#L`0``V0$```````!>````X```````
M```#````*@$``+P!````````(P$``*D!``"S`0```````-P```!.`0``JP``
M``````#:````Y````-L!``"U`0``W@```/T!```_`0``DP````````!+`0``
ML0$``.<```!%````>````)@!``#=`0``7@$``-(`````````&0```((```#&
M`0```````.`!```R````"`(``$H!``#]````AP$``!$!``#'````1```````
M```)`@``V0```%T!````````6@$``$0!``"V````R@$``*$```")`0``3```
M`.,!``#/````/0$```````"Y````T`````X"````````RP````````#'`0``
MT@$`````````````:0```#0```!O````````````````````B````.4```"E
M````"@(``%0````#`@``P`$``$D!``#G`0```````%P```!7````-@```#0!
M```Z````BP```#L````````````````````2`@``0````$P!``!P````\`$`
M````````````2`$```````#"`0``!@```'P```!V````]@```$8!```8````
M<0$````!``#H`0```````.H!``!L````>0````````"J`0``S@```)$!```!
M`@```````.8```"H````K`$``/D!``"1`````````!@!``!5`0``$P```)D!
M``#<`0```````$(!``#%`0``*@`````````!`0``8`$``/X```!N````"P(`
M`````````````````!4"```9`0```````)8```#=````]0$``)0!``#Q````
M````````````````D@$``&0!``!S````[P$``,4```!]`0``#P(``+H```!T
M`0``*P```*X!````````"`$``*P```!B`0``<`$``)`!````````_````$\!
M``"P````A0`````````N````50```&````"-````3@```+@!````````````
M``@````@`0``1P```)4```!/````Y@$```````!;````EP````````"7`0``
M```````````S`0``-0```)T``````````````'0``````````````+\!``"[
M````TP$``#P!```*`````````/@!``#8`0``9@$```````#?````J0``````
M`````````````-4````/`0````````````"R`0``+`$``!4````2````D@``
M`'\!```4`0``!0(``%8```#4`````````(P````M````)P````````"/````
M4@```#8!``#Z`0``FP```````````````````.,```!Y`0``/P`````````:
M````'0````````#W````)0```#$!`````````````!$`````````+@$`````
M```F`0``S`$``$`!``"^````[@$```````#6`0``````````````````````
M```````+`0``20```,8````>`0``@P$``$$!``"Q````%@````P"````````
M`````.L!``!\`0``X@$``$L```#X````````````````````%P$``&(`````
M`````````,0```#A````P0```/(!``"F`0``7`$``,T!````````SP$``*(`
M````````:`$`````````````@`$``'L!```4`@``2````"$!````````````
M`%0!``"Z`0``@@$``'\```#!`0``\P$``.(```!3`````````-@`````````
M`````&,```"B`0``````````````````IP$``%\`````````JP$``&$`````
M`````````),!``#1`0``.````,0!````````'@```'<```!9````A`$``%\!
M```B`0``GP```&4```"*`0``^P$`````````````G@$``,H```##`0```@``
M````````````N0$``.P```!;`0``"P```"T!``":````IP```&0```!'`0``
MM`$``"(```!I`0``/````',!``#N````!0$``(L!`````````````*\!``"4
M````'````(<```":`0``KP```%<!```O````U0$``&T!```A````%P``````
M```U`0``````````````````:`````````"8``````````````!%`0``4@$`
M`*0```!0````70```'X```#Q`0``;@$``-<!``!V`0```````,P`````````
M`````)\!``"M`````````-0!```[`0``>@$```X!```,`0``@P``````````
M````I@````````!1````>P````T"````````_P```!\```"X````C@$``(P!
M``!^`0``S0````D!```'````0P$``.$!``#7````VP``````````````M```
M`!``````````(`````````!C`0``9P```+X!``!G`0```````"8```#J````
MR0```!\!``"_````$`$``#(!``!A`0```````&L!````````0@```%D!``#K
M```````````````I`````P$``"D!``!W`0``$P$```0!```W`````````+T`
M``!-`0``C0$``'$`````````F0```"<!``#:`0``40$``.D`````````'0$`
M`#T```!U````O0$``%,!``!J`0``\@```/\!```.````B`$``$$`````````
M`````,X!``#?`0```@(```<"``#E`0``M0````````!:````;`$``!,"````
M````&P```!4!``";`0``U@````````"6`0``;0````````#D`0```````#,`
M```2`0``)0$``#<!```)````W@$```T```#1`````````+,```"C````Z0$`
M``0"``"W`0``<@$``*$!``#O````P@```````````````````+8!``!*````
M0P```,L!``".````E0$````````*`0```````($`````````)````,D!``!8
M`0``@````!H!```C`````````!8!`````````````)`````H````#P```&L`
M``"&`0``G````*0!```1`@```````*4!``!J````G@```+`!````````?0``
M``````"=`0``B0````````"$`````````#X`````````[0$````"````````
M`````"@!``#(`0``!P$``*H```#T`````````*@!``````````````````#Y
M```````````@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`
M("AY97-T97)D87DI`")&:7)S=&YA;64@3&%S=&YA;64B("`H:64N($IO:&X@
M1&]E*0`B3&%S=&YA;64L($9I<G-T;F%M92(@*&EE+B!$;V4L($IO:&XI`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@861D
M960N`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!F:6QE('-U8V-E<W-F=6QL>2!I
M;7!O<G1E9``E<R!T;R`E<R!O9B`E<P`R-"!H;W5R<P!!(&)R;W=S97(@=&AA
M="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D`$%-+U!-`$%B;W5T('1H
M:7,@961I=&]R`$%D9`!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@
M<&%I<@!!9&0@=&\`061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!!9&1R97-S`$%D9')E<W,@0F]O:R!,:7-T:6YG`$%D9')E<W,@8F]O:R!E
M;G1R>0!!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"X`061M:6YI
M<W1R871I;VX`061V86YC960@4V5A<F-H`$%L:6%S`$%L:6=N`$%L:6=N;65N
M=#H`06QL`$%L;"!F;W5R('-I9&5S`$%L<F5A9'D@17AI<W1S`$%L=&5R;F%T
M92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P<FEL
M`$%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L
M96-T960@96YT<FEE<S\`07-C96YD:6YG`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!=6=U<W0`
M079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A<VEC(%-E87)C:`!":7)T:&1A>0!";VQD`$)O<F1E<@!";W)D97(@=&AI
M8VMN97-S.@!";W)D97)S`$)O=&@`0F]T=&]M`$)U;&QE=&5D($QI<W0`0U-6
M`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%N8V5L`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#87!T:6]N`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T
M:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN
M9SH`0V5L;'!H;VYE`$-E;G1E<@!#:&%N9V4`0VAE8U]K($QI;FLN+BX`0VAE
M8VL@7T%L;"].;VYE`$-H:6YA`$-H;V]S92!A;B!A9&1R97-S(&)O;VL`0VAO
M;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-L96%R
M($U33V9F:6-E('1A9W,`0VQO<V4@5VEN9&]W`$-O;&QA<'-E(%-I9&5B87(`
M0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L<SH`0V]L=6UN($]P=&EO;G,`
M0V]M:6-S`$-O;6UA('-E<&%R871E9"!V86QU97,`0V]M;6$@<V5P87)A=&5D
M('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI`$-O;7!A;GD`0V]M<&%N>2!!
M9&1R97-S`$-O;F9I<FT@4&%S<W=O<F0`0V]N;F5C=&EO;B!F86EL960Z("5S
M`$-O;FYE8W1I;VX@9F%I;'5R90!#;VYT86-T<R!I;B!L:7-T.B`E<P!#;W!Y
M`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-R96%T92!A(&QI;FL`0W)E871E9`!#=7)R96YT(%52
M3"!I<P!#=7)R96YT('-T>6QE`$-U=`!#=70@<V5L96-T:6]N`$1$`$1A:6QY
M`$1A=&4`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S
M`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@261E;G1I='D`1&5F
M875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5L971E`$1E;&5T92!#;VYF:7)M
M871I;VX`1&5L971E(&)U='1O;B!B96AA=FEO=7(`1&5L971E(&-E;&P`1&5L
M971E(&-O;'5M;@!$96QE=&4@9F%I;&5D.B`H)7,I("5S`$1E;&5T92!R;W<`
M1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@
M<F]W`$1E;&5T:6]N(&9A:6QE9`!$97!A<G1M96YT`$1E<V-E;F1I;F<`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@3W!T:6]N
M<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y
M;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]W;FQO860@)7,`1&]W;FQO860@=D-A<F0`161I
M=`!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&5N=')Y(&9O<B`E<P!%
M9&ET(&]P=&EO;G,@9F]R.@!%;&5M96YT+BXN`$5M`$5M86EL`$5M;W1I8V]N
M<P!%;7!T>2!R97-U;'0N`$5N;&%R9V4@161I=&]R`$5N=&5R('1H92!I;6%G
M92!54DP@:&5R90!%;G1R>2!F;W(@)7,@=7!D871E9"X`17)R;W(`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!%>'!A;F0@4VED96)A<@!%>'!O<G0`17AP;W)T($%D9')E
M<W,@0F]O:P!&1R!#;VQO<@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E<P!&86EL
M960@=&\@861D("5S('1O("5S.B`E<P!&86EL960@=&\@8G)O=W-E(&QI<W0`
M1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@
M8F4@861D960Z("5S`$9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@
M)7,`1F%X`$9E8G)U87)Y`$9I;&4@36%N86=E<@!&:6QT97)S`$9I;F0`1FER
M<W0@3F%M90!&;VYT($-O;&]R`$9R86UE<P!&<F]M`$=E<FUA;GD`1VQO8F%L
M($%D9')E<W,@0F]O:P!';P!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O
M<@!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AO;64@061D
M<F5S<P!(;VUE($-I='D`2&]M92!#;W5N=')Y`$AO;64@4&AO;F4`2&]M92!0
M;W-T86P@0V]D90!(;VUE(%-T871E+U!R;W9I;F-E`$AO;64@4W1R965T($%D
M9')E<W,`2&]R9&4`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`25]N
M<V5R="!2;W<@0F5F;W)E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$ED
M96YT:71Y)W,@;F%M93H`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E
M(%523#H`26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9`!);7!O<G0O17AP
M;W)T($%D9')E<W,@0F]O:W,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D
M(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC<F5A<V4@26YD96YT`$EN
M<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`
M26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@
M82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E
M<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@
M=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L
M;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E
M9F]R90!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@
M8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS
M97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YV86QI9"!A
M9&1R97-S(&)O;VL`26YV86QI9"!E;6%I;`!);G9A;&ED(&YA;64`26YV86QI
M9"!O8FIE8W1)9`!)=&%L:6,`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/
M+3(P,C(M2E`I`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU
M<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+;W)E82P@
M4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$QA;F=U86=E`$QA<W0@36]D
M:69I960`3&%S="!.86UE`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S
M(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%Y;W5T`$QE9G0`3&ES=`!,
M:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO
M9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO=V5R(&=R965K(&QE='1E<G,`
M3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$U-`$UA
M:6P`36%K92!L:6Y?:RXN+@!-87)C:`!-87)G:6X`36%T8VAI;F<`36%T8VAI
M;F<@9FEE;&1S`$UA>&EM=6T@;G5M8F5R(&]F('!A9V5S`$UA>0!-96YU(&UO
M9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`36ED9&QE`$UI;FD@4V5A<F-H`$UO
M8FEL92!0:&]N90!-;V1I9GD@55),`$UO9&EF>2!F86EL960Z("@E<RD@)7,`
M36]N=&AL>0!-;W9E`$UO=F4@1&]W;@!-;W9E(%5P`$UO=F4@;&5F=`!-;W9E
M(')I9VAT`$UU;&)E<G)Y($%D9')E<W,@0F]O:P!-=6QT:7!L92!P97)S;VYS
M('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A
M;')E861Y(&5X:7-T`$YA;64`3F%M92!&;W)M870`3F5T=V]R:P!.979E<@!.
M97<@0V]N=&%C=`!.97<@=VEN9&]W("A?8FQA;FLI`$YE>'0`3FEC:VYA;64`
M3F\`3F\@861D<F5S<R!B;V]K<R!F;W5N9"X`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+@!.;R!C;VYT86-T<R!F;W5N9`!.;R!V0V%R9"!D871A('=A<R!F
M;W5N9"X`3F]N90!.;W1E<P!.;W9E;6)E<@!.=6UB97(@;V8@8V]L=6UN<P!.
M=6UB97(@;V8@:71E;7,@<&5R('!A9V4`3G5M8F5R(&]F(')O=W,`3V)J96-T
M(&YO="!F;W5N9`!/8W1O8F5R`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO
M;G,`4&%D9&EN9P!087-S=V]R9`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!097)C96YT`%!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)M:7-S:6]N($1E;FEE9`!097)M
M:7-S:6]N(&1E;FEE9`!097)S;VYA;"!);F9O<FUA=&EO;@!0:&]N90!0:6YE
M($%D9')E<W,@0F]O:P!0:7AE;',`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<FEN="!D;V-U;65N=`!0<FEV871E($%D9')E<W,@0F]O
M:P!0<F]B;&5M($1E<V-R:7!T:6]N`%%U97)Y(&9A:6QE9#H@*"5S*2`E<P!1
M=6EC:R!396%R8V@`4F5C;W)D<R!D:7-P;&%Y960Z`%)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9R;VT@=&AI<R!L:7-T
M`%)E;6]V92!P86ER`%)E<V5T`%)E<V5T('1O($1E9F%U;'1S`%)E='5R;B!T
M;R!/<'1I;VYS`%)I9VAT`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O=R!0
M<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%-A;64@9G)A;64@*%]S
M96QF*0!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5A<F-H(&9A:6QE9`!3
M96%R8V@@9F%I;&5D.B`E<P!396%R8VAI;F<N+BX`4V5L96-T('1H92!A9&1R
M97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ`%-E;&5C="!T:&4@861D<F5S<R!B
M;V]K('1O(&EM<&]R="!T;SH`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N
M965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A
M;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R
M=#H`4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE
M8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@;F%M97,Z`%-E;&5C="!T
M:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!3
M96QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@
M;&ES=',N`%-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RX`
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@
M4F5P;W)T`%-E<'1E;6)E<@!3:&%R960@1&ER96-T;W)Y`%-H;W<@06QL`%-H
M;W<@0V]N=&%C=',`4VAO=R!,:7-T<P!3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:7IE`%-K:7`@36%I;G1E
M;F%N8V4`4V]R="!$:7)E8W1I;VX`4V]U<F-E<P!3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R
M(&EN(&-E;&P`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P96-I86P@
M0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET
M(')O=P!3=')I:V5T:')O=6=H`%-T>6QE(%M#4U-=`%-U8FIE8W0`4W5B;6ET
M`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E
M<P!3=6UM87)Y`%-U<&5R<V-R:7!T`%1A8B!S97!A<F%T960@=F%L=65S`%1A
M8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!487-K<P!497AT`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y
M<W1E;2X`5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E
M<P!4:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+@!4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@
M=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`
M5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE<F4@87)E
M(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO(&]P
M=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E
M<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS
M(&%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I
M97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R!I<R!A;B!E<G)O<BP@
M<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N
M97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&9O<B!F=7)T:&5R(&AE;'`N`%1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN
M9R!A(&YE=R!L:7-T+@!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI
M<R!C;VYT86-T.B`E<P!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI
M<R!O8FIE8W0N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A
M=&$Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E
M;G1R>3H@)7,`5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4
M:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!P97)S;VX@
M86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET;&4`5&ET;&4@*'1O;VQT
M:7`I.@!4;P!4;V=G;&4@2%1-3"!3;W5R8V4`5&]P`%1O<"!F<F%M92`H7W1O
M<"D`55),`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@
M;&%S="!A8W1I;VX`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<V5T(&-O;&]R`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<V5R($]P
M=&EO;G,`57-E<FYA;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`5F5R:7-I9VX@
M1&ER96-T;W)Y`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5FEE
M=R`E<P!6:65W($-O;G1A8W0`5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0Z
M`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_`%=I9'1H`%=I9'1H(&]F('1H92!T86)L
M90!7:61T:"!U;FET`%=I9'1H.@!7;W)K($%D9')E<W,`5V]R:R!#:71Y`%=O
M<FL@0V]U;G1R>0!7;W)K(%!H;VYE`%=O<FL@4&]S=&%L($-O9&4`5V]R:R!3
M=&%T92]0<F]V:6YC90!7;W)K(%-T<F5E="!!9&1R97-S`%E9`%EE87)L>0!9
M97,`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S
M="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K+@!9;W4@;75S="!S96QE
M8W0@82!T87)G970@;&ES="X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N
M92!E;G1R>2!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+@!9;W4@;VYL>2!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A
M8W0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S
M.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT
M(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M(:61E(%%U;W1E
M9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`
M6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=
M`%MN;R!V86QU95T`7T%D;6EN:7-T<F%T:6]N`%]"<F]W<V4`7T1E;&5T90!?
M1&5L971E(%)O=P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?26UP;W)T
M+T5X<&]R=`!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U)E
M;6]V92!,:6YK+BXN`%]296UO=F4@9G)O;2!T:&ES(&QI<W0`7U-E87)C:`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!L:6YE<UT`;F%M90!P97)C96YT`'!I>&5L
M<P!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@,BXP
M+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#$M,3$M,3`@,#(Z-#`K,#DP,`I,87-T+51R
M86YS;&%T;W(Z($II;FAY;VL@2&5O(#QN;W9E;6)R94!O=7)N871U<F4N;W)G
M/@I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%+59E
M<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M975C+6MR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`HM-S#
MX,6P("5S*0`@*+_`M,,I`"`HL[O`SRD`("B^[L&F*0#`S+BG(+RZ*+^Y.B!*
M;VAN($1O92D`O+HL(,#,N*<HO[DZ($1O92P@2F]H;BD`)7,@P*_!]K#\N*X@
MP-N^]R`M(,BNP,X`)7,@P]^PH;7*+@`B)7,BM,(@P,RYS"#`UKW`M,^TV2X`
M)7,@QL3`S\"[(+RZL/C`^\"XM\X@L*'!KK_4O<"TS[39+@`E<R!^("5S+"#`
M_,.\("5S(+"S`#(T(+W#L*,`:49R86UEP+L@P?:_^,?/M,(@NNJV\[_LP:ZP
MH2#'RK_DQ]6TS[39`+_`P/POO\#(Q`#`S""_H;7PQ<VTP@##W["A`+OUM\Z_
M[B"[Y[_KP-H@P]^PH3H`Q*ZWLR##W["A`,;DONXH<&%I<BD@P]^PH0##W["A
M`+OGO^O`VB##W["A`+OGO^O`VB##W["A(+OGO^N^R,?4`,'6O-(`P=:\TK?/
M(+BNO;K&K@#!UKS2M\\@P-2WP@#!UKS2M\_`S""\NK#XP/O`N+?.(+KQO_;!
M_`"P_+BN`+#ML=X@L,N[]@"ZL+CM`,&DM\0`P:2WQ#H`N/"USB"\L<7#`+CP
MM><@-+CI`,#,N<P@P;C`Y\?4`+3KP[P@L=L`P-^X^+7((+FNP-JPH2#`UKW`
MM,^TV2X`-+_Y`+RQQ</'T2"PS;7IP+L@P:2XNR#!]K_LL-J]P+3/L>X_`+_`
MN*?"][SX`,"OP?:P_+BNO<?'X,#\(,BNP,['S['B`#B_^0"PH;3)Q]$@Q\JU
MY3H`N>BPY@"YZ+#F(+OVL?(`L>*ZNR"PR[OV`+O]P,\`L;VPU`"PYK#H`+#F
ML.@@M<ZRL@"PYK#H`+CPM<X`OL:WH0"QXLBC(+BNO;K&K@!#4U8`7V6\OR"\
MT[RZ+BXN`+3>M\(`P^N\T@"_P+?Y(+JXL.W'S['B(,/KO-(`Q+B\QP#(WK3K
MQOD`O+\@O-.\N@"\OR#&Y+7Y`+R_(+S3O+H`O+\@L*.PW0#(WK3KQOD`L*&_
M[K6E`+JOL.8`7VNXM<6I(+#+N^<N+BX`O+'%PP#!W[&Y`,'6O-*WSR"\L<7#
M`+SXO*T@N*Z]NL:N(,&^M_D@O+'%PP!-4[_`Q\>]NB#%U['7(,'VO^RQX@##
MHB"TW;'B`+_>PLJXM[3K(+3=L>(`Q]7#Q,'X(+#FL.@`N_:Q\@"_K3H`Q,.W
MLR"_R;S'`$-O;6EC<P#$WKBVM\X@L;BZT+7((+"J`,3>N+:WSB"QN+K0M<@@
ML*HHOL:_]+?H(+_K*0#(N+OG`,BXN^<@P=:\T@"^S\BC(,BNP,X`OZRPX2"]
MQ\;0.B`E<P"_K+#A(+W'QM``)7,@N*Z]NL:NP,<@OZRV],.S(+CQM\\`NKF[
MYP"ZN;OG`$UA:6YT96YA;F-E7U1A<VL@N/"UXB`E<R"XIB"_K2"\]B"^^+W`
MM,^TV2X`N+7%J2"XN+7IL>(`N_V\N@#']L#G(%523,"Z`,?VP.<@O;K%N,#/
M`,#:N*.QX@#`VKBCL>(`1$0`P,^ZL`"SK\*E`%]LOZT@N^C!I@`Q,K_Y`+S]
MP-H`L[N^[KZRL>(`L>*ZNP"QXKJ[(+W$NK#`V@"QXKJ[(,&DM\0@N>:Y_0"[
MZ,&F`+OHP:8@R*[`S@"[Z,&F(+GVQK`@M;_`VP"\OR"[Z,&F`+^M(+OHP:8`
MN^C!IB"]Q\;0.B`H)7,I("5S`,?@(+OHP:8`Q_;`YR"_K2#!]K_R`,?VP.<@
MQ^`@P?:_\@"[Z,&F(+W'QM``NLZ\K0"SN[BRPO>\^`"_P+?Y(+RSN.T`O+RZ
MSL&DNKBPH2"P_+BNP-JXIB#`I\?8(+'BM\^UQ[[NP;.]P+3/M-DN`+7PM[K%
MY+BN`,BMN.D@O+/!I`!M86EN=&5N86YC92YP:'"_H2#!]\&B(,&BL=G'S\'V
M(+BVO+R_Y"X`P?:_[R"VIR#(KL#.Q\^QX@##N;GXPK`@Q^#`NB#'U[CQ(,#,
MN*?`NR"PKK#M(,#6O<"TS['N/R"QU[>XM-FXZ2P@OZFQXKBF(,.\Q:G'S[R\
MO^0Z`"5S(+.[M\&YWK'B`'9#87)D(+.[M\&YWK'B`+SVP:0`)7,@L<?'T2"\
M]L&D`"5S(,?7N/$@O/;!I`"\L<7#N^?'UR"\]L&D.@"_Y+S2+BXN`&5M`,#,
MN-[`SP#`S+CPQKS$W`"PX;#Z(+[XP+T`QNW!_;'B(,BNM.L`L=>XLB!54DP@
MP-2WP@`E<R"\]L&DM<H`O\"W^0`Q-;K0(+BVM-D`,S##RB"XMK39`#6ZT""X
MMK39`+CPM><@M\ZQU\#.`#,PNM`@N+:TV0"XQ;K0`+^Y.@"_WL+*N+>TZR#(
MKL#E`+.[NKBSN['B`,'6O-*WSR"SN[JXL[NQX@#`_+#FN_8`R*^PYKRSP:0@
MP-"QXB"_P+?Y+@#!UKS2M\\@P:*QV2"]Q\;0.B`E<P`E<[BF("5SOZ$@P]^P
MH2"]Q\;0(#H@)7,`N*Z]NL:N(,6]N_8@O<?&T`"U\+>ZQ>2XKB"PR[OVO<?&
MT`!,1$%0(+RMN?8@P:*\TR"]Q\;0`,/?L*''TB"TZ[OSP+L@PZ/!]B"X^,?4
M.B5S`+7PM[K%Y+BN(+#+N_8@O<?&T#H@)7,`QM&]N@`RO_D`QL3`SR"P_+BN
MP-H`Q\K%S0##H['B`,#,N*<`L=O`VB"[]K'R`,?!M[G`TP#`I\2A`+6VP,\`
MP/S#O"#!UKS2M\\`L*&QX@"S],#,`+6UO_*XNP"UM;_RN+L`QL3`S\#'(+W#
MP-O`S""TV<"]L/H@L+"]P+3/M-DZ`,'](,'6O-(`M;6]PP"QN;"A`,'](,#\
MR*T`O^S&[;GXR*,`O<,OM;4`P?T@P=:\T@!(;W)D90"\]L;RO+$`L*&WSB##
MI+_R`+"AM\XZ`,?5Q*&P[2"]S<"Z(+^MP,<@O/8`Q]>X\2B_K2G`QR"\]C\`
MQ]7$H;#M(+W-P+H@Q^#`QR"\]@!?;K[5OZ$@Q^`@P]^PH0"^QL#,Q-P`OL;`
MS,3<L/H@N:[`V@"]Q+JPP-H@P,RXISH`L=>XLB"YS+BNNKBQXCH`L=>XLB!5
M4DP`L=>XLB!54DPZ`,'6O-*WSR"PH<&NO\"QXBP@M-RPZ"`E9`#!UKS2M\\@
ML*'!KK_`L>(OL[NZN+.[L>(`L*'!KK_"(,?7N/$Z("5S`+"AP:Z_PB#'U[CQ
M.@!?<[39P+V_H2#'X"##W["A`+7IOZF^LK'B`%]OM-G`O;^A(+^M(,/?L*$`
ML=>XLB##W["A`,>E(,/?L*$`P*4@N+7%J2##W["A`%]COM6_H2"_K2##W["A
M`,?VP.<@OZT@M=J_H2"[]2"_K2##W["A`,?VP.<@OZT@OM6_H2"[]2"_K2##
MW["A`,?VP.<@Q^`@M=J_H2"[]2#'X"##W["A`,?VP.<@Q^`@OM6_H2"[]2#'
MX"##W["A`,?VP.<@P?;!H2"UVK^A(+3<MO0@P]^PH0#']L#G(,'VP:$@OM6_
MH2"TW+;T(,/?L*$`M=J_H2"\OR##W["A`+[5OZ$@O+\@P]^PH0"UVK^A(+^M
M(,/?L*$`OM6_H2"_K2##W["A`+7:OZ$@M-RV]"##W["A`+[5OZ$@M-RV]"##
MW["A`+7:OZ$@Q^`@P]^PH0"^U;^A(,?@(,/?L*$`L=>XLB##W["A+[SVP:0`
MN+7%J2##W["A+[SVP:0`P-^X^+7((,'6O-*WSP#`W[CXM<@@P,RXWL#/+@#`
MW[CXM<@@P,RXIRX`P-^X^+7((+"TP[P@OL;`S+7P`+'BO^_`S+'B`#&_^0#`
MS[J[`,#/NKN^[B`H25-/+3(P,C(M2E`I`#>_^0`VO_D`P:2WQ`"PH;_NM:4@
MP:2WQ`"^Y\+*(,&DM\0`O]["RB#!I+?$`+_`N*7"RB#!I+?$`+3KQ]&YSK&Y
M`,?1L;F^[B`H155#+4M2*0"^\+[N`+BVP?:XMR"\]L&D`+RZ`+BVP?:XMR"W
MSK'7P,XZ("5S`+BVP?:XMR"WSK'7P,XZ("5S+"#!HKS3(,"GQ*$Z("5S`+BV
MP?:XMR"WSK'7P,XZ(+[XP+T`M[G`S+[&O_0`O]["R@"XKKVZQJX`M;6_\K[+
M(+CQPO<`N^>_Z\?2(+SV(+[XM,(@N^>_Z\#:(+CQM\\N`+?.L=?`S@"WSK'7
MOL:_]`"WSK'7P,X@O</`V\#;OO<`L=>XKKVZ(+S2N:[`V@"V\\:^(+S2N:[`
MV@"WSKBV(+S2N:[`VB"\_<#:`$U-`+C>P,\`7VNXM<6I(+BXM>FQXBXN+@`S
MO_D`L*'`Y<#:N*X`PZ.TPB"YKL#:OZT`P,_$H<?/M,(@Q]>X\0##UK3K(,;D
MP,S!]KSV`#6_^0"XWK2Z(+CPM>4`O+\@Q]7$H;'B`+C>O</!]@"PH;_NM:4`
ML*.TW,?1(+#+N_8`Q]JUY<;Y`%523""\]L&D`+SVP:0@O<?'I3H@*"5S*2`E
M<P"XQ;_Y`,#,M;\`OL:WH;?.(,#,M;\`P*>WSB#`S+6_`+_>PLK`N+?.(,#,
MM;\`O\"XI<+*P+BWSB#`S+6_`$UU;&)E<G)Y(,'6O-*WSP`E<R#!UKS2N*8@
ML*'!^""[Y[;WP+H@P,RYS"#`UL"XLZHL("5S(,#,N*?`N+?.(,&XP.?'S[3"
M(+#-P+H@OOC`O0#`S+BG`,#,N*<@Q_R]Q`"SU\:NO_;%J0"[Y[_KOLC'U`"[
M];?.O^X@OZRV],.S(,/?L*$`N_4@PZ(H7V)L86YK*0"TV<"]`+JPN.T`OL:T
MS[_``,'6O-*WSR"^^,"]`$944"!61E.XIB#`I\?1(+RSP:3!I+JXL*$@OOB]
MP+3/M-DN`%-13"!61E,@O+/!I,&DNKBPH2"^^+W`M,^TV2X`4U%,+49I;&4@
M5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN`+^LMO3#LR"^^,"]`'9#87)D(,&D
MNK@@PZ/!]B"X^,?4`+RQQ</'S\'V(+[*P+T`POS!M@`Q,;_Y`+^MP,<@O/8`
MQN3`S,'VM.<@L.&P^B"PN;SV`,?@P,<@O/8`PZ/!]B"X^,?4`#$PO_D`N_4@
MPZ*_H2"XM<6I(+^ML>(`O+'%P[OGQ]<`)7,@O+'%P[OGQ]<`O/W`VB"X\;?/
M`+3<P[P`L>+%N`"QXL6X(,&DNK@`L>+%N""\L\&D`,;DM?D`OL_(HP"^S\BC
ML*$@P,_$H<?/P?8@OLJ]P+3/M-DN`+K9P,RQX@#%K+BSNKBUY;^AO*T@NMG`
MS+'B`+#FM\X`QMN\OL:N`,"OP?8@L/RXKB#`V[[W(+W'Q^``L<?'T2"^^,"]
M`+''Q]$@OOC`O0"PL\#.(,&DNK@`P/S(K;GXR*,`4&EN92#!UKS2M\\`Q\B\
MOP"YKL&FOZ$@M.O'T2"_Y+[@P+L@P-2WPL?8(,'6O+R_Y"X`N^>_Z\#:P,RX
MI[#Z(+[/R*.XIB#`U+?"Q\^\O+_D`+G,N*ZZN+'B`+OU(,.BOZ$@N<RXKKJX
ML>(`N:Z\K2#`SKSB`+"SP,X@P=:\TK?/`+FNP:8@O+.X[0"PR[OV(+W'QM`Z
M("@E<RD@)7,`NZ&XKB##H['B`,>EO<,`N+;!]KBW(+CMM\D@N=VZN0#$KK>S
M(+OHP:8`N*Z]NL:NOZ&\K2#!IK#%`,;DONXH<&%I<BD@N^C!I@#`U+?"(,/K
MO-(`P\JQXLBM`+_)O,?`N+?.(+6YOL:PH;'B`+_`N*7"R@!?=\?@(+S3O+HN
M+BX`OZK'T@#'X""\T[RZ`,?@(+S3O+H`Q^`Z`+"PP+H@Q\&WN<#3*%]S96QF
M*0#`^L#E`+RQQ<.[Y\?7(,#ZP.4`L,N[]@"PR[OV(+W'QM``L,N[]B"]Q\;0
M.B`E<P##H[3"P=\N+BX`L[NZN+.^(,'6O-*WSR"\L<7#.@"PH<&NO\,@P=:\
MTK?/(+RQQ<,Z`+[&MZ$@N_/`VK^AO*T@Q\J_Y,?1(+FNP-JXIB"\L<7#Q\^P
M[2"ZN;OGQ\^_J2"ZV;^IL];`N+R\O^0N`+.OP-H@L;BZT,>EO<,@O+'%PSH`
MLZ_`VB#'_+W$(+RQQ<,`L[NZN+.[L>(@Q_R]Q""\L<7#`,#3QO?&KL?2(,;$
MP,\@O+'%PSH`O-*]NB#&Q,#/(,;WN,L@O+'%PP#`S+BG(,>EO<,@Q_R]Q""\
ML<7#.@"]P["C(,?\O<0@O+'%PP"USK"SP,<@P,_$H<?/M,(@Q]>X\2"\L<7#
M`,'6O-(@N*Z]NL:NOZ$@QZ6]P\?2(,?7N/$@O+'%PP#`S+BG(,>EO<,@Q_R]
MQ""\L<7#`,#:P=:[Y[_KQ\^TPB"^\+[NN*8@O+'%P\?/O+R_Y"X`N:[!IKG?
MN_T@NKBP[;RM(,#\O-O'S['B`#F_^0"P^,"O(+7PM[K%Y+BN`+CPM<X@NKBQ
MX@"_K+;TP[,@NKBQX@"XKKVZQJX@NKBQX@"\OR"\T[RZPZ(@NKBQX@#'I2"\
MT[RZPZ(@NKBQX@"_K2"\T[RZPZ(@NKBQX@"QU[BR(+S3O+K#HB"ZN+'B`,6I
ML>(`P*_!]K#\N*X@N_VWJP#!I+?$(+GFN?T`O-*]N@"\O["CL-T`O+\@L.:P
MZ+_-(+.[O^L@N^?`S,#'(+"CL-T`L,6XK@"PQ;BNO\T@PZ2_[+'B`,:OO/8@
MN:[`VB#`U+?"`+R_(+K0Q](`OZT@NM#'T@#'X""ZT,?2`+"AO^ZUI<'9`+VZ
MQ;C`SUM#4U-=`,&FN/$`P:;#X@"^QK>AP[?`V@"\NK#X`"5SL*$@)7._H2"\
MNK#XP/O`N+?.(,/?L*&UR@"_Y+[@`,"MP[?`V@#%Q\"XM\X@L;BZT+7((+"J
M`,>E(+S3O+H`QZ4@O-.\N@#`V[[W`+FNP-J_K0"YKL#:`+FNP-H@P:2WQ`"[
MY[_KQ]C!UKS%O*T@L*B[Y\?5M,^TV2X`P=:\TK?/P+L@NO&_[R"\]B"^^+W`
MM,^TV3H@)7,`O^3#N\?1(+^LMO3#L["A(+[XO<"TS[39+@#&Q,#/OZ$@OL:Y
MJ[>Q(,#:M^&PH2"^^+W`M,^TV2X`OL:WH;3"(,#,(&UE<W-A9V4O<F9C.#(R
M(,;MP?;`QR"XT[BTN+O`U+3/M-DN`+W$NK#`VB`B)7,B(+"A(+OHP::UQ[[Z
MO<"TS[39+@#%O;OVL*&TR<?1(,'6O-*WS\#,(+[XO<"TS[39+@#`S+_KL*&T
MR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN`+OUM\Z_[B#'U[CQP+L@P]^PH<?2
M(+SV(,#6M;6WSR"\L\&DM<@@P=:\TK?/P,P@OOB]P+3/M-DN(+BXON`@P,RP
MS<#,(+_`M_FV\[#M(+O]L*+'S[W%M-FXZ2P@L/RXKL#:OZ&PU""YKL#'Q\^]
MP['B(+G9MOBTS[39+@#&Q,#/(+_#N*ZQXK^A(+FNP::PH2#`UKW`M,^TV2X@
M)7,@QL3`S\#,(+[WM\ZUY;7'P?8@OLJ^TKW`M,^TV2X`P]^PH<?/M,*UI2"_
MP+?YL*$@N=^[_<??O<"TS[39+B"P_+BNP-J_H;#4(+6UO_+`NR"_Y,.[Q\^]
MP['B(+G9MOBTS[39+@"[];?.O^X@N*Z]NL:N(+BXM>FQXB"_P+?Y`+OHP:8@
MO\"W^2`Z("5S`+OHP:8@O\"W^0"UI<#,Q;@@L*'!KK_`L>(@O\"W^3H@)7,`
M:4-A;&5N9&%R(+6EP,S%S2"PH<&NO\"QXB"_P+?Y`+SVP:0@O\"W^3H@)7,`
ML*'!KK_#(+SV(,#6M,(@P=:\TK"A(+[XO<"TS[39+@#`S""\_<#:M,(@P]:\
MTL?1(#'`VKBN(,#,N_/`S+[NOM\@Q]6TS[39+@`G)7,GM,(@P,RYS"#!UKS2
MM\^_H2"U[K?/M<>^[B#`UKW`M,^TV2X`P,P@L*K`NB"\_<#:OZF^WR#'U;3/
MM-DN`,&FN/$`Q;C`S,:R*,7XQL$I.@"YWK3"(+OGMO<`2%1-3""\TKVZ(+JX
ML>(`P*<`N_/`IR#'P;>YP-,H7W1O<"D`55),`%9&4R#&Q,#/("5S+R5SP,<@
MQMNYS+S'P+L@NJ^PYL?2(+SV(+[XO<"TS[39+@!344P@O*VY]K^A(,&BO-/'
MTB"\]B"^^+W`M,^TV2X`)7,@P:3`Q[BF(,#0P+L@O/8@OOB]P+3/M-DN`'9F
M<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+@!61E,@QL3`SR`E
M<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN`,#,(+_VM>6YKKRMN*8@
MNJ^PYL?2(+SV(+[XO<"TS[39+@"YV,'9`+JOL.:[Y\?7(+7'M;FXKK'B`+BV
MP?:XMR"X[;?)(,/KO-(`O[6QN0"YS+&Y`,?VP.<@O^2\TK^A(+BUQ:D@P::P
MQ0#`S+BG(+[XP+T`N_:Q\B#!IK#%`+;SQKZ^[B"TZ[FNP-H`M\ZXMB"TZ[FN
MP-H@O/W`V@"[Y[_KP-H@O+'%P[OGQ]<`N^>_Z\#:N.T`O<.]NL7;P,<@N^>_
MZ\#:.@!697)I<VEG;B"U\+>ZQ>2XK@"\]L'W(,&DM\0`O/;!]R##I+_R`"5S
M(+JXL>(`OZRV],.S(+JXL>(`P[D@L>*ZNR#(K;CI`+#FL.T`N,7!U@#(K[^U
M`,BOO[7'U;3/M-DA("5S(,#4M,^TV2X`R*^_M<?5M,^TV2P@)7,`L;BZT""Y
MKL#:M,(@N:N^^<#4M,^Q[C\`P,Z_ZR"ZSLBCM,(@N:N^^<#4M,^Q[C\`L\JZ
M\0#'I<#'(+/*NO$`L\JZ\2"TW,"G`+/*NO$Z`,'WP.4@P=:\T@#!]\#E(+6U
MO<,`P??`Y2"QN;"A`,'WP.4@P/S(K0#!]\#E(+_LQNVY^,BC`,'WP.4@O<,O
MM;4`P??`Y2#!UKS2`%E9`+C%L^(`O[D`5$585+CPM>7`U+3/M-DN(%L\/ET@
MN?;&L,"[(+2IN*.XZ2!765-)5UE'(+CPM>6WSB"UN;[&L*FTS[39+@"WSK'7
MOL:_]"#'S[^TO<"TS[39+@"YKL&F(+JXL.V\K;BF(+JXL[NQXL#\OZ$@P,RY
MKL&FOZ$@M.O'T2"\L[CMP+L@P-2WPL?8OM\@Q]6TS[39+@#`S""XM<6IL*$@
ML*&XKL2AM,(@55),P+L@P-2WPL?8OM\@Q]6TS[39+@#!UKS2M\_`NR"\L<7#
MQ]B^WR#'U;3/M-DN`+BNO;K&KKBF(+RQQ</'V+[?(,?5M,^TV2X`OZRV],.S
MN*8@N-7`^B"\L<7#Q\^\O+_D+@"[Z,&FQ](@N^>_Z\#:(,#,N*?`NR#`U+?"
MQ]B^WR#'U;3/M-DN`,/?L*''TB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5
MM,^TV2X`P,P@N/&WS\"[(+J\(+SV(,#6M,(@L<?'T;BX(,#6O<"TS[39+@`E
M<R"\O+S'P,P@N+BWX;7'OOJ]P+3/M-DN(+39O<,@M\ZQU\#.Q\^\O+_D+@#`
MS+C>P,\@P=:\TCH`N-[`SR#!UKS2.@#!I+JX`,#,N*<Z`+3GO<7`QR#`SL'U
MQ:RV\\#,OO#&KK"A(+OGO^O`VB"X\;?/NKBQXKBF(,'VO_C'S\'V(+[*O<"T
MS[39+B"VQ[3"(+39N*4@P,S`K[?.(+OGO^O`VB"X\;?/NKBQXKBF(+OGO^O'
MTB"\]B"^^+W`M,^TV2X`NNJV\[_LP/JPH2#`S""QXK3)P+L@P?:_^,?/P?8@
MOLJ]P+3/M-DN`,?VP.<@O<.PH[3K.@"QXKJ[(+W$NK#`VCH`P/S#O"#`S+BG
M.@#`S""\O+S'(+6_OL@@O\F\Q\#,(,#ZP.6UR[3/M-DN`+_)O,?`S"#`^L#E
MM<>^^KW`M,^TV2X`6\#.O^L@O/NQXK'B70!;O\"W^2"ZN+#MQ\^QXET`6\#.
MO^L@NKBQXB`M`%O`SK_K(+JXL>(@+2`E<R#!V5T`6[;SP,X@)7,@+R`E<UT`
M6["J(+[XP+U=`%]!L/RXK@!?0L6]N_8`7T2[Z,&F`%]$Q^`@P?:_\@"UM;_R
MN+L`7TFQU[BR(+S3O+HN+BX`7TFPH<&NO\"QXB^SN[JXL[NQX@!?3+?.L=>^
MQK_T`%]MN+7%J2"\]L&D+BXN`%]/O+'%P[OGQ]<`7W*XM<6I(+OHP:8N+@!?
M4L#,(+BNO;K&KK^AO*T@P?:_[+'B`%]3L,N[]@!?=,>E(+S3O+HN+BX`P=E=
M`,#,N*<`QMN\OL:N`,?(O+\`P,RXIR"^^,"]`'9#87)D````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M=7)B82]L;V-A;&4O;'1?3%0O````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`R,#`R,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]L=%],5"],0U]-15-304=%
M4R\`````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-34`,#(Q-C`U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE
M+VQT7TQ4+TQ#7TU%4U-!1T53+W1U<F)A+FUO````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#,V,#<V,P`Q,#0Q-S,V,C<U-0`P,C,R-S,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0`````4!P``'````+PX``!Q
M"0``7'$````````@EP``#@```"&7```/````,)<```@```!`EP``#````$F7
M```$````5I<``"0```!;EP``)0```("7```,````II<```\```"SEP``"P``
M`,.7```.````SY<```4```#>EP``*````.27```*````#9@``!4````8F```
M"0```"Z8```2````.)@```L```!+F```'0```%>8```.````=9@```H```"$
MF```#0```(^8```.````G9@```T```"LF```#````+J8```-````QY@```8`
M``#5F```#P```-R8```8````[)@```P````%F0``#@```!*9```.````(9D`
M``@````PF0``*P```#F9```N````99D``!H```"4F0``,@```*^9```X````
MXID``%0````;F@``40```'":``!:````PIH``%<````=FP``-````'6;```*
M````JIL```4```"UFP``!@```+N;```1````PIL```@```#4FP``$0```-V;
M```)````[YL```D```#YFP``)0````.<```@````*9P``!````!*G```#P``
M`%N<```*````:YP```\```!VG```%````(:<```)````FYP```T```"EG```
M$@```+.<```/````QIP```H```#6G```#P```.&<```(````\9P``"0```#Z
MG```!@```!^=```4````)IT``!8````[G0``"````%*=```9````6YT```<`
M``!UG0``%````'V=```2````DIT``"$```"EG0``+````,>=```.````])T`
M``,````#G@``#P````>>```+````%YX```<````CG@``!P```"N>```%````
M,YX```4````YG@``"@```#^>```#````2IX``!<```!.G@``"@```&:>```/
M````<9X```X```"!G@``&````)">```C````J9X```X```#-G@``#@```-R>
M```4````ZYX``!<`````GP``%P```!B?```7````,)\``!,```!(GP``#P``
M`%R?```.````;)\``!\```![GP``!P```)N?```&````HY\```@```"JGP``
M#P```+.?```&````PY\```H```#*GP``$P```-6?```+````Z9\``!4```#U
MGP``%0````N@```'````(:````4````IH```%0```"^@```1````1:````P`
M``!7H```*````&2@```Z````C:```#L```#(H```"0````2A```'````#J$`
M`!0````6H0```P```"NA```%````+Z$```D````UH0``$````#^A```)````
M4*$``!,```!:H0``.0```&ZA```2````J*$``"<```"[H0``+````..A```J
M````$*(``"4````[H@``"@```&&B```&````;*(```D```!SH@``!P```'VB
M```O````A:(``#<```"UH@``+@```.VB``!5````'*,``"T```!RHP``+0``
M`*"C```M````SJ,``$````#\HP``(P```#VD```C````8:0``"T```"%I```
M,P```+.D```5````YZ0``!D```#]I```*0```!>E```D````0:4``!$```!F
MI0``"@```'BE```,````@Z4```H```"0I0``$````)NE```6````K*4``!8`
M``##I0``!P```-JE```'````XJ4``!0```#JI0``"@```/^E```(````"J8`
M``@````3I@``#````!RF```'````*:8```<````QI@``!@```#FF```1````
M0*8```4```!2I@``!P```%BF```&````8*8``!0```!GI@``"````'RF```.
M````A:8```H```"4I@``!````)^F```'````I*8```D```"LI@``!@```+:F
M```1````O:8```<```#/I@``%@```->F```$````[J8```@```#SI@``!@``
M`/RF```-`````Z<```8````1IP``'@```!BG```1````-Z<```@```!)IP``
M#0```%*G```,````8*<```<```!MIP``$0```'6G```#````AZ<```,```"+
MIP``%P```(^G```#````IZ<``!,```"KIP``"````+^G```$````R*<```@`
M``#-IP``"````-:G``!!````WZ<``"`````AJ```!@```$*H```&````2:@`
M`!4```!0J```&````&:H```B````?Z@``"X```"BJ```'0```-&H```A````
M[Z@``%0````1J0``*0```&:I```*````D*D```<```";J0``%0```*.I```.
M````N:D```H```#(J0``#P```-.I```-````XZD```\```#QJ0``#0````&J
M```)````#ZH``!0````9J@``!@```"ZJ```8````-:H``!T```!.J@``$P``
M`&RJ```4````@*H```0```"5J@``!@```)JJ``!4````H:H```0```#VJ@``
M#@```/NJ```/````"JL```4````:JP``!0```""K```;````)JL``!H```!"
MJP``$0```%VK```1````;ZL``!8```"!JP``'````)BK```J````M:L``!``
M``#@JP``(0```/&K```%````$ZP``!,````9K```$@```"VL```*````0*P`
M``\```!+K```$0```%NL```3````;:P```P```"!K```!@```(ZL```&````
ME:P``!<```"<K```$0```+2L```(````QJP```4```#/K```#````-6L```0
M````XJP```4```#SK```#@```/FL```-````"*T```8````6K0``%@```!VM
M```J````-*T```<```!?K0``#0```&>M```'````=:T```L```!]K0``!P``
M`(FM```'````D:T```\```"9K0``"0```*FM```*````LZT``!D```"^K0``
M#````-BM```0````Y:T```4```#VK0``)0```/RM```2````(JX``!,````U
MK@``%0```$FN```2````7ZX``"L```!RK@``.P```)ZN```@````VJX``!H`
M``#[K@``%````!:O```V````*Z\```@```!BKP``#````&NO```&````>*\`
M``0```!_KP``#@```(2O```*````DZ\```T```">KP``'@```*RO```;````
MRZ\``"$```#GKP``'@````FP```9````*+```!X```!"L```&P```&&P```F
M````?;```!L```"DL```'@```,"P```<````W[```"8```#\L```,P```".Q
M```F````5[$``"L```!^L0``.````*JQ```O````X[$``!(````3L@``*0``
M`":R```2````4+(``*(```!CL@``%@````:S```C````';,``"@```!!LP``
M*0```&JS```H````E+,``!\```"]LP``(````-VS```E````_K,``"$````D
MM```'````$:T```F````8[0``$$```"*M```#````,RT```'````V;0```<`
M``#AM```#0```.FT```0````][0``!(````(M0``!P```!NU```3````([4`
M`!(````WM0``!P```$JU```$````4K4```P```!7M0``#@```&2U```/````
M<[4``!,```"#M0``#0```)>U```H````I;4```,```#.M0``#0```-*U```&
M````X+4``!$```#GM0``%P```/FU```;````$;8```X````MM@```@```#RV
M```%````/[8``!````!%M@``!````%:V```-````6[8```X```!IM@```P``
M`'BV```.````?+8```@```"+M@``#P```)2V```/````I+8```T```"TM@``
M$````,*V```:````T[8```L```#NM@``!@```/JV```3`````;<```P````5
MMP``$0```"*W```9````-+<``!<```!.MP``"P```&:W```-````<K<``"(`
M``"`MP``%@```*.W```*````NK<``!@```#%MP``&0```-ZW```6````^+<`
M``\````/N```#0```!^X```'````+;@```H````UN```"@```$"X```4````
M2[@``"(```!@N```+P```(.X```+````L[@```D```"_N```&0```,FX```+
M````X[@``!<```#ON```%P````>Y```)````'[D``!8````IN0``#P```$"Y
M```6````4+D```X```!GN0``&````':Y```(````C[D```T```"8N0``)@``
M`*:Y```H````S;D``$,```#VN0``"````#JZ```2````0[H```L```!6N@``
M+P```&*Z```.````DKH```X```"AN@``!0```+"Z```&````MKH```,```"]
MN@``!P```,&Z```$````R;H```H```#.N@``"@```-FZ```/````Y+H``!``
M``#TN@``%P````6[```1````';L``!$````ONP``%P```$&[```)````6;L`
M``4```!CNP``"P```&F[```*````=;L```(```"`NP``!0```(.[```-````
MB;L``!L```"7NP``%P```+.[```)````R[L```X```#5NP``#0```.2[```2
M````\KL``#@````%O```(````#Z\```(````7[P```X```!HO```>P```'>\
M```8````\[P``!4````,O0``$0```"*]```'````-+T```4````\O0``&0``
M`$*]```'````7+T```@```!DO0``!@```&V]```&````=+T``!````![O0``
M#P```(R]```0````G+T```\```"MO0``"P```+V]```/````R;T```P```#9
MO0``#P```.:]```'````]KT```8```#^O0``#`````6^```H````$KX```\`
M```[O@``"````$N^```&````5+X``!,```!;O@``(@```&^^```M````DKX`
M``@```#`O@``$P```,F^```>````W;X``"4```#\O@``&@```"*_```5````
M/;\``!X```!3OP``(0```'*_```@````E+\``!D```"UOP``%P```,^_```E
M````Y[\``"4````-P```%P```#/````B````2\````0```!NP```&P```'/`
M```-````C\````,```"=P```"````*'````*````JL````P```"UP```"P``
M`,+````$````SL```!,```#3P```%````.?````,````_,````D````)P0``
M#@```!/!```+````(L$``!L````NP0``!P```$K!```$````4L$```<```!7
MP0``"@```%_!```*````:L$```T```!UP0``"0```(/!```$````C<$```4`
M``"2P0```P```)C!```8````G,$```H```"UP0``!````,#!```F````Q<$`
M``X```#LP0``?````/O!```5````>,(```4```".P@``!P```)3"```,````
MG,(```@```"IP@``"@```++"```&````O<(```@```#$P@```@```,W"```&
M````T,(```8```#7P@``%````-["```,````\\(```T`````PP``$`````[#
M```;````'\,```0````[PP``"0```$##```0````2L,```D```!;PP``"0``
M`&7#```%````;\,``!H```!UPP``"````)##```&````F<,``!D```"@PP``
M#@```+K#```'````R<,```<```#1PP``!0```-G#```)````W\,```H```#I
MPP``$P```/3#```"````",0```8````+Q```#0```!+$```)````(,0```8`
M```JQ```$@```#'$```)````1,0```<```!.Q```!0```%;$```4````7,0`
M`!T```!QQ```!@```(_$```*````EL0```0```"AQ```"0```*;$```(````
ML,0``!$```"YQ```"0```,O$```&````U<0```T```#<Q```!@```.K$```$
M````\<0``#D```#VQ```/0```##%```Z````;L4``!X```"IQ0``!0```,C%
M```.````SL4```0```#=Q0``!@```.+%```A````Z<4``!4````+Q@``!@``
M`"'&```$````*,8``!$````MQ@``!@```#_&```*````1L8``"(```!1Q@``
M!````'3&```%````><8``!T```!_Q@``!````)W&```,````HL8```D```"O
MQ@``#````+G&```*````QL8``!````#1Q@``$P```.+&```(````]L8```D`
M``#_Q@``!0````G'```Z````#\<``#````!*QP``-0```'O'```I````L<<`
M`$<```#;QP``.````"/(```I````7,@``#\```"&R```+@```,;(```M````
M]<@``!\````CR0``#P```$/)```2````4\D```L```!FR0``)@```'+)```I
M````F<D``"0```##R0``)@```.C)```(````#\H```H````8R@``"0```"/*
M```'````+<H``"`````UR@``(````%;*```F````=\H```0```">R@``"@``
M`*/*```9````KLH``"D```#(R@``%@```/+*```2````"<L```<````<RP``
M"@```"3+```/````+\L``!`````_RP``0````%#+``!F````D<L```X```#X
MRP``"0````?,```*````$<P``!(````<S```$P```"_,```,````0\P```8`
M``!0S```'````%?,```/````=,P``!L```"$S```$@```*#,```0````L\P`
M`!$```#$S```'````-;,```C````\\P``&H````7S0``#P```(+-```%````
MDLT``!````"8S0``"0```*G-```$````L\T```L```"XS0``%````,3-```,
M````V<T```P```#FS0``#P```//-```5`````\X``"D````9S@``*@```$/.
M```F````;LX``"<```"5S@``*0```+W.```J````Y\X``!D````2SP``0@``
M`"S/```1````;\\``!(```"!SP``$P```)3/```4````J,\```\```"]SP``
M%@```,W/```7````Y,\``!````#\SP``$0````W0```T````']```!,```!4
MT```$@```&C0```U````>]```!0```"QT```!P```,;0```,````SM````H`
M``#;T```(````.;0```4````!]$``!0````<T0``$0```#'1```7````0]$`
M`!P```!;T0``#0```'C1```-````AM$``!,```"4T0``%@```*C1```1````
MO]$```P```#1T0``$````-[1```:````[]$``!X````*T@``&@```"G2```1
M````1-(``!0```!6T@``%P```&O2```5````@](```D```"9T@``&0```*/2
M```$````O=(```<```#"T@``"P```,K2```1````UM(```8```#HT@``!@``
M`._2```&````]M(```4```#]T@``!P````/3```'````"],```4````3TP``
M%@```!G3```&````,-,```8````WTP``!````#[3```$````0],```<```!(
MTP``#@```%#3```,````7],```P```!LTP``#0```'G3```*````A],```X`
M``"2TP``!0```*'3```H````I],```X```#0TP``#````-_3```/````[-,`
M``H```#\TP``"`````?4```)````$-0``"L````:U```!````$;4```(````
M2]0``"8```!4U```$@```'O4```/````CM0```8```">U```"@```*74``!,
M````L-0```<```#]U```"`````75```@````#M4```D````OU0``#0```#G5
M```)````1]4```P```!1U0``#0```%[5```.````;-4``!8```![U0``$0``
M`)+5```&````I-4```,```"KU0``!@```*_5```9````MM4```<```#0U0``
M!````-C5```+````W=4```L```#IU0``!P```/75```'````_=4``!8````%
MU@``#0```!S6```-````*M8```H````XU@``$````$/6```/````5-8``!$`
M``!DU@``%P```';6```*````CM8``!$```"9U@``"````*O6```$````M-8`
M``\```"YU@``.@```,G6```%````!-<```P````*UP``'@```!?7```.````
M-M<``!````!%UP``"P```%;7```,````8M<```D```!OUP``!P```'G7```*
M````@=<```D```",UP``#@```);7```0````I=<``!H```"VUP``"@```-'7
M```)````W-<```H```#FUP``#````/'7```/````_M<```@````.V```!@``
M`!?8```'````'M@```L````FV```1P```#+8```-````>M@```D```"(V```
M!````)+8```#````E]@``!,```";V```$P```*_8```3````P]@```H```#7
MV````@```.+8```$````Y=@``"4```#JV````P```!#9```%````%-D``"H`
M```:V0``"@```$79```%````4-D```0```!6V0``"@```%O9```-````9MD`
M``8```!TV0``"````'O9```(````A-D```0```"-V0``!0```)+9``!H````
MF-D```D````!V@``#`````O:```%````&-H```8````>V@``&P```"7:```O
M````0=H``!````!QV@``"@```(+:```(````C=H```\```"6V@``"@```*;:
M```)````L=H``!,```"[V@``&P```,_:```8````Z]H``!<````$VP``#@``
M`!S;```7````*]L```,```!#VP``!P```$?;```(````3]L```<```!8VP``
M"@```&#;```+````:]L```<```!WVP``40```'_;```0````T=L```P```#B
MVP``#0```._;```:````_=L``$H````8W```!@```&/<```&````:MP```8`
M``!QW```'P```'C<```&````F-P```D```"?W```&````*G<```7````PMP`
M``L```#:W```!@```.;<```-````[=P``"@```#[W```(@```"3=``!7````
M1]T``!,```"?W0``(P```+/=```3````U]T```(```#KW0``"P```.[=```,
M````^MT```@````'W@``#0```!#>```*````'MX``!8````IW@``!P```$#>
M```4````2-X```8```!=W@``"````&3>```.````;=X```<```!\W@``"@``
M`(3>```+````C]X``!<```";W@``!P```+/>```,````N]X```T```#(W@``
M#````-;>```$````X]X```D```#HW@``"0```/+>```*````_-X```<````'
MWP``"0````_?```)````&=\```H````CWP``!P```"[?```*````-M\``!4`
M``!!WP``&P```%??``!)````<]\``!(```"]WP``"@```-#?```)````V]\`
M`!````#EWP``!P```/;?```2````_M\```0````1X```"P```!;@```'````
M(N````4````JX```!0```##@```:````-N````L```!1X```%````%W@```1
M````<N```!H```"$X```%@```)_@```4````MN```!<```#+X```&````./@
M```<````_.```!D````9X0``!P```#/A```%````.^$```T```!!X0``#```
M`$_A```+````7.$```@```!HX0``%P```''A```+````B>$``!,```"5X0``
M!````*GA```*````KN$```0```"YX0``#````+[A```)````R^$```@```#5
MX0``!0```-[A```'````Y.$```4```#LX0``!````/+A```"````]^$``!@`
M``#ZX0``%P```!/B```X````*^(``"P```!DX@``$@```)'B```I````I.(`
M`#(```#.X@``"@````'C```L````#.,``"X````YXP``,P```&CC```S````
MG.,``#@```#0XP``$0````GD```/````&^0``!@````KY```$````$3D```3
M````5>0``!0```!IY```$@```'[D```4````D>0``!4```"FY```+0```+SD
M```M````ZN0``#$````8Y0``+@```$KE```O````>>4``"P```"IY0``8@``
M`-;E```3````.>8```@```!-Y@``"````%;F```K````7^8``"$```"+Y@``
M&````*WF```:````QN8```D```#AY@``10```.OF``!!````,><```0```!S
MYP``$P```'CG```4````C.<```X```"AYP``$P```+#G```8````Q.<```8`
M``#=YP``"0```.3G```*````[N<```\```#YYP``$`````GH```'````&N@`
M``X````BZ```!0```#'H```;````-^@```@```!3Z```!@```%SH```4````
M8^@``!$```!XZ```&````(KH```.````H^@``#@```"RZ````@```.OH```&
M````[N@```X```#UZ```$`````3I```%````%>D```<````;Z0``#@```"/I
M```&````,ND```0````YZ0``*0```#[I```7````:.D``!\```"`Z0``7```
M`*#I```4````_>D``!\````2Z@``$````#+J```'````0^H```X```!+Z@``
M#````%KJ```,````9^H``!,```!TZ@``"@```(CJ```=````D^H``!D```"Q
MZ@``!0```,OJ```1````T>H```T```#CZ@``$0```/'J```D`````^L``!4`
M```HZP``$@```#[K```.````4>L``!D```!@ZP``"````'KK```)````@^L`
M``T```"-ZP``"@```)OK```+````INL```H```"RZP``!P```+WK```(````
MQ>L```4```#.ZP``'P```-3K```&````].L``!````#[ZP``"`````SL```-
M````%>P```@````C[```$@```"SL```L````/^P``!H```!L[```"0```(?L
M```*````D>P``!4```"<[```!0```++L```4````N.P```0```#-[```$```
M`-+L```&````X^P```<```#J[```'@```/+L```H````$>T```H````Z[0``
M$0```$7M```1````5^T``!H```!I[0``%````(3M```$````F>T```0```">
M[0``"P```*/M```%````K^T```8```"U[0``$0```+SM```(````SNT```8`
M``#7[0``"@```-[M```;````Z>T``#0````%[@``-````#KN```@````;^X`
M`"D```"0[@``(````+KN``!!````V^X``!H````=[P``*````#CO```I````
M8>\``"(```"+[P``!@```*[O```(````M>\```4```"^[P``"````,3O```9
M````S>\``!D```#G[P``*@````'P```C````+/```"X```!0\```-````'_P
M```(````M/```!<```"]\```"@```-7P```'````X/```"$```#H\```$```
M``KQ```.````&_$``!0````J\0``"P```#_Q```'````2_$``!,```!3\0``
M"````&?Q```+````</$```H```!\\0``%````(?Q```R````G/$```L```#/
M\0``!0```-OQ```%````X?$``!4```#G\0``#````/WQ```7````"O(```\`
M```B\@``!````#+R```*````-_(```D```!"\@``"P```$SR```.````6/(`
M``4```!G\@``!````&WR```4````<O(```T```"'\@``,@```)7R``!%````
MR/(``!(````.\P``%P```"'S```>````.?,``!0```!8\P``!0```&WS```4
M````<_,```<```"(\P``#@```)#S```J````G_,```8```#*\P``#````-'S
M```-````WO,``!$```#L\P``%0```/[S```+````%/0``#8````@]```"@``
M`%?T```B````8O0```L```"%]```#P```)'T```R````H?0``!L```#4]```
M!0```/#T```.````]O0``!,````%]0``$0```!GU```'````*_4``!$````S
M]0``!P```$7U```4````3?4``!@```!B]0``!P```'OU```%````@_4```P`
M``")]0``#````);U```2````H_4```0```"V]0``!P```+OU```*````P_4`
M``L```#.]0``#````-KU```.````Y_4```X```#V]0``!0````7V```%````
M"_8``"X````1]@``)@```$#V```C````9_8```,```"+]@``$@```(_V```&
M````HO8``!X```"I]@``&````,CV```9````X?8``"4```#[]@``#0```"'W
M```)````+_<```,````Y]P``!P```#WW```*````1?<```(```!0]P``#```
M`%/W```5````8/<```L```!V]P``&0```(+W```@````G/<``!(```"]]P``
M!0```-#W```*````UO<``!4```#A]P``$@```/?W```,````"O@```0````7
M^```!P```!SX```,````)/@``%(````Q^```%P```(3X```'````G/@```8`
M``"D^```#@```*OX```-````NO@``!$```#(^```#````-KX```,````Y_@`
M``T```#T^```%0````+Y```2````&/D```\````K^0``%````#OY```;````
M4/D``!````!L^0``)P```'WY```E````I?D``&D```#+^0``&@```#7Z```7
M````4/H``!D```!H^@``&@```(+Z```E````G?H``"@```##^@``)P```.SZ
M```:````%/L``!<````O^P``&P```$?[```T````8_L``"4```"8^P``&0``
M`+[[```?````V/L``!,```#X^P``"`````S\```'````%?P```@````=_```
M"0```";\```5````,/P```T```!&_```$P```%3\```#````:/P``$8```!L
M_```/P```+/\```W````\_P``%<````K_0``'P```(/]```O````H_T```H`
M``#3_0``$````-[]```(````[_T```T```#X_0``+0````;^```$````-/X`
M``@````Y_@``#0```$+^```*````4/X``$\```!;_@``)0```*O^```<````
MT?X```L```#N_@``'P```/K^```=````&O\``"4````X_P``(````%[_```D
M````?_\``"````"D_P``"P```,7_```'````T?\```T```#9_P``#````.?_
M```&````]/\``#D```#[_P``#````#4``0`'````0@`!``D```!*``$`$P``
M`%0``0`)````:``!``0```!R``$`$````'<``0`(````B``!``@```"1``$`
M"P```)H``0`,````I@`!`!H```"S``$`#P```,X``0`'````W@`!``T```#F
M``$`#@```/0``0`4`````P$!``X````8`0$`!P```"<!`0`,````+P$!`!L`
M```\`0$`+````%@!`0`3````A0$!`!P```"9`0$`*````+8!`0`&````WP$!
M``<```#F`0$`$P```.X!`0`%`````@(!``0````(`@$`%P````T"`0`Y````
M)0(!``H```!?`@$`#````&H"`0`)````=P(!``8```"!`@$`"0```(@"`0`(
M````D@(!``D```";`@$`"@```*4"`0`1````L`(!``8```#"`@$`#@```,D"
M`0`.````V`(!``T```#G`@$`"P```/4"`0`=`````0,!``L````?`P$``@``
M`"L#`0`'````+@,!``8````V`P$`"0```#T#`0`'````1P,!`!L```!/`P$`
M.P```&L#`0`H````IP,!`!4```#0`P$`!0```.8#`0`'````[`,!``@```#T
M`P$`!P```/T#`0`%````!00!``<````+!`$`#@```!,$`0`)````(@0!``8`
M```L!`$`"````#,$`0`+````/`0!``<```!(!`$`"````%`$`0`'````600!
M`!8```!A!`$`"0```'@$`0`&````@@0!``L```")!`$`'````)4$`0`4````
ML@0!``<```#'!`$`"````,\$`0`#````V`0!``@```#<!`$`%````.4$`0`%
M````^@0!`!``````!0$`$````!$%`0`&````(@4!`!D````I!0$`"@```$,%
M`0`<````3@4!``<```!K!0$`!0```',%`0`0````>04!`!0```"*!0$`"P``
M`)\%`0`-````JP4!`!<```"Y!0$`!````-$%`0`)````U@4!``H```#@!0$`
M!P```.L%`0`"````\P4!``X```#V!0$`"`````4&`0`?````#@8!`",````N
M!@$`.````%(&`0`Q````BP8!`"<```"]!@$`*````.4&`0!D````#@<!`!0`
M``!S!P$`50```(@'`0`X````W@<!`"D````7"`$`2@```$$(`0!;````C`@!
M`"@```#H"`$`.````!$)`0`H````2@D!`"P```!S"0$`)P```*`)`0`;````
MR`D!`#X```#D"0$`J0$``",*`0`C````S0L!`!<```#Q"P$`2`````D,`0"%
M````4@P!`#````#8#`$`00````D-`0!;````2PT!`$D```"G#0$`'0```/$-
M`0`8````#PX!`"$````H#@$`'P```$H.`0`K````:@X!`"$```"6#@$`'0``
M`+@.`0`1````U@X!`#,```#H#@$`)0```!P/`0`G````0@\!`"8```!J#P$`
M'P```)$/`0`P````L0\!`,P```#B#P$`:0```*\0`0`]````&1$!`&4```!7
M$0$`30```+T1`0!>````"Q(!`"<```!J$@$`+````)(2`0`H````OQ(!`"\`
M``#H$@$`+@```!@3`0`I````1Q,!`#````!Q$P$`5````*(3`0!:````]Q,!
M`$@```!2%`$`2@```)L4`0`J````YA0!`"(````1%0$`,@```#05`0`O````
M9Q4!`"P```"7%0$`+0```,05`0!Q````\A4!`&\```!D%@$`LP```-06`0`7
M````B!<!`"4```"@%P$`,@```,87`0`I````^1<!`#X````C&`$`(@```&(8
M`0!2````A1@!`"(```#8&`$`)0```/L8`0`+````(1D!`+$````M&0$`10``
M`-\9`0`A````)1H!`#8```!'&@$`,````'X:`0`E````KQH!`!P```#5&@$`
M,0```/(:`0`'````)!L!``<````L&P$`!````#0;`0`-````.1L!``L```!'
M&P$`#@```%,;`0`+````8AL!``4```!N&P$`$````'0;`0`"````A1L!`%D`
M``"(&P$`!0```.(;`0`2````Z!L!``0```#[&P$`!P`````<`0`(````"!P!
M``4````1'`$``P```!<<`0`0````&QP!``P````L'`$`$P```#D<`0`-````
M31P!``(```!;'`$`!P```%X<`0`&````9AP!`!0```!M'`$`#````((<`0`8
M````CQP!``8```"H'`$`$@```*\<`0`,````PAP!``,```#/'`$`*@```-,<
M`0`$````_AP!``8````#'0$`!P````H=`0`?````$AT!`#4````R'0$`+@``
M`&@=`0`O````EQT!`!<```#''0$`(````-\=`0`;`````!X!`!@````<'@$`
M)````#4>`0`?````6AX!`!H```!Z'@$`(````)4>`0`:````MAX!`#(```#1
M'@$`+P````0?`0`K````-!\!`!\```!@'P$`(P```(`?`0`?````I!\!`!H`
M``#$'P$`)0```-\?`0`F````!2`!`"4````L(`$`)````%(@`0`8````=R`!
M`!T```"0(`$`)````*X@`0`8````TR`!`"(```#L(`$`)0````\A`0`\````
M-2$!`!\```!R(0$`(P```)(A`0`?````MB$!`"````#6(0$`&@```/<A`0`8
M````$B(!`"8````K(@$`'@```%(B`0`I````<2(!`!X```";(@$`"0```+HB
M`0`,````Q"(!`!<```#1(@$`+P```.DB`0`D````&2,!``<````^(P$`#P``
M`$8C`0`4````5B,!``X```!K(P$`#0```'HC`0`D````B",!``4```"M(P$`
M!P```+,C`0`B````NR,!`"4```#>(P$`'0````0D`0`:````(B0!``<````]
M)`$`QP```$4D`0`+````#24!`!4````9)0$`!@```"\E`0`)````-B4!``L`
M``!`)0$`%P```$PE`0`&````9"4!`#,```!K)0$`$P```)\E`0`3````LR4!
M``<```#')0$`#P```,\E`0`'````WR4!`#(```#G)0$`(0```!HF`0`3````
M/"8!``P```!0)@$`$0```%TF`0`R````;R8!``@```"B)@$`"0```*LF`0`*
M````M28!`!0```#`)@$`"@```-4F`0`=````X"8!``@```#^)@$`'P````<G
M`0`(````)R<!`!H````P)P$`!@```$LG`0`5````4B<!``<```!H)P$`"```
M`'`G`0`)````>2<!`#\```"#)P$`$@```,,G`0`'````UB<!``\```#>)P$`
M#@```.XG`0`0````_2<!``D````.*`$`"0```!@H`0`(````(B@!`!,````K
M*`$`!P```#\H`0`,````1R@!`!D```!4*`$`"@```&XH`0`;````>2@!`!<`
M``"5*`$`%````*TH`0`*````PB@!``P```#-*`$`%P```-HH`0`$````\B@!
M`"H```#W*`$`$0```"(I`0`'````-"D!``(````\*0$`$````#\I`0`8````
M4"D!``L```!I*0$``P```'4I`0`(````>2D!``L```""*0$`!@```(XI`0`'
M````E2D!``T```"=*0$`"P```*LI`0`4````MRD!`!4```#,*0$`#@```.(I
M`0`O````\2D!`"`````A*@$`'````$(J`0`,````7RH!`#$```!L*@$`!0``
M`)XJ`0`2````I"H!`#\```"W*@$`$@```/<J`0`*````"BL!``8````5*P$`
M!````!PK`0`3````(2L!``4````U*P$`!@```#LK`0`&````0BL!``0```!)
M*P$`#````$XK`0`)````6RL!``P```!E*P$`"@```'(K`0`0````?2L!`!,`
M``".*P$`!0```*(K`0`8````J"L!`!D```#!*P$`'P```-LK`0`=````^RL!
M`!$````9+`$``@```"LL`0`$````+BP!``H````S+`$`!@```#XL`0`%````
M12P!``,```!++`$`#````$\L`0!%````7"P!`!H```"B+`$`-0```+TL`0`H
M````\RP!`%,````<+0$`,````'`M`0`O````H2T!`!D```#1+0$`<@```.LM
M`0`@````7BX!`#4```!_+@$`10```+4N`0`P````^RX!`"8````L+P$`'@``
M`%,O`0`H````<B\!`"D```";+P$`*0```,4O`0`F````[R\!`"4````6,`$`
M*````#PP`0`H````93`!`"(```".,`$`+@```+$P`0`P````X#`!`!(````1
M,0$`$P```"0Q`0`0````.#$!`'D```!),0$`"0```,,Q`0!S````S3$!`'P`
M``!!,@$`*P```+XR`0`7````ZC(!`!8````",P$`#P```!DS`0`?````*3,!
M`!\```!),P$`'````&DS`0!1````AC,!`!0```#8,P$`"@```.TS`0`%````
M^#,!``8```#^,P$`"`````4T`0`%````#C0!`!(````4-`$`$````"<T`0`3
M````.#0!`!T```!,-`$`#P```&HT`0`*````>C0!``\```"%-`$`!P```)4T
M`0`$````G30!``D```"B-`$`!P```*PT`0`+````M#0!``<```#`-`$`!0``
M`,@T`0`4````SC0!``X```#C-`$`!P```/(T`0`(````^C0!``\````#-0$`
M"````!,U`0`,````'#4!``\````I-0$`%@```#DU`0`'````4#4!``8```!8
M-0$`%````%\U`0`&````=#4!``P```![-0$`"````(@U`0`$````D34!``H`
M``"6-0$`"P```*$U`0`,````K34!``P```"Z-0$`!P```,<U`0`$````SS4!
M`!D```#4-0$``@```.XU`0`)````\34!``8```#[-0$`!@````(V`0`G````
M"38!``0````Q-@$`#P```#8V`0`3````1C8!``<```!:-@$`!P```&(V`0`&
M````:C8!``8```!Q-@$`$````'@V`0`2````B38!``8```"<-@$`"0```*,V
M`0`B````K38!``<```#0-@$`!P```-@V`0`+````X#8!``4```#L-@$``@``
M`/(V`0`+````]38!`%<!```!-P$`$@```%DX`0`.````;#@!``L```![.`$`
M"````(<X`0`!````D#@!`"8```"2.`$`*````+DX`0`+````XC@!`!$```#N
M.`$`#``````Y`0`-````#3D!``4````;.0$`*0```"$Y`0`/````2SD!``P`
M``!;.0$`#````&@Y`0`2````=3D!``@```"(.0$`&P```)$Y`0`1````K3D!
M``H```"_.0$`#````,HY`0`3````USD!``X```#K.0$`$0```/HY`0`0````
M##H!``8````=.@$`#@```"0Z`0`5````,SH!`!$```!).@$`$P```%LZ`0`3
M````;SH!``L```"#.@$`)P```(\Z`0`L````MSH!`!(```#D.@$`/0```/<Z
M`0!)````-3L!`&4```!_.P$`9@```.4[`0!H````3#P!`&D```"U/`$`0```
M`!\]`0`*````8#T!``4```!K/0$`!@```'$]`0`2````>#T!``<```"+/0$`
M%P```),]`0`1````JST!`!,```"]/0$`*P```-$]`0`H````_3T!``L````F
M/@$`$P```#(^`0`(````1CX!``\```!//@$`$````%\^`0`0````<#X!`!,`
M``"!/@$`%0```)4^`0`:````JSX!`!````#&/@$`%@```-<^`0`,````[CX!
M`"T```#[/@$`"0```"D_`0`:````,S\!`!\```!./P$`$0```&X_`0`<````
M@#\!``<```"=/P$`#P```*4_`0`6````M3\!`"(```#,/P$`.0```.\_`0`(
M````*4`!``@````R0`$`#@```#M``0`,````2D`!``@```!70`$`!P```&!`
M`0`(````:$`!``@```!Q0`$`"P```'I``0`%````AD`!`!H```",0`$`#```
M`*=``0`,````M$`!`!0```#!0`$`%````-9``0`A````ZT`!``X````-00$`
M#@```!Q!`0`?````*T$!`!T```!+00$`(@```&E!`0`>````C$$!`!4```"K
M00$`%````,%!`0`.````UD$!`!L```#E00$`!@````%"`0`&````"$(!``<`
M```/0@$`&0```!="`0`)````,4(!``H````[0@$`$@```$9"`0`'````64(!
M`!4```!A0@$`%P```'="`0`+````CT(!``@```";0@$`%P```*1"`0`3````
MO$(!`!D```#00@$`'0```.I"`0`M````"$,!`#,````V0P$`"0```&I#`0`(
M````=$,!`!4```!]0P$`!0```)-#`0`%````F4,!``\```"?0P$`'0```*]#
M`0`+````S4,!`"````#90P$`+@```/I#`0`5````*40!`"@````_1`$`*@``
M`&A$`0`K````DT0!`"L```"_1`$`"0```.M$`0`)````]40!``H```#_1`$`
M"`````I%`0`O````$T4!`"P```!#10$`+@```'!%`0!0````GT4!`"T```#P
M10$`+0```!Y&`0`M````3$8!`#\```!Z1@$`*0```+I&`0`K````Y$8!`"T`
M```01P$`,P```#Y'`0`4````<D<!`!@```"'1P$`*@```*!'`0`G````RT<!
M``X```#S1P$`#0````)(`0`1````$$@!``4````B2`$`"P```"A(`0`A````
M-$@!`"8```!62`$`!P```'U(`0`)````A4@!`!8```"/2`$`"@```*9(`0`*
M````L4@!``X```"\2`$`$@```,M(`0`+````WD@!``<```#J2`$`!P```/)(
M`0`8````^D@!``<````320$`"````!M)`0`'````)$D!`!T````L20$`"P``
M`$I)`0`0````5DD!``L```!G20$`"@```'-)`0`(````?DD!``<```"'20$`
M!P```(])`0`0````ETD!``<```"H20$`%@```+!)`0`%````QTD!``@```#-
M20$`"````-9)`0`*````WTD!``D```#J20$`(````/1)`0`5````%4H!``D`
M```K2@$`$0```#5*`0`.````1TH!``D```!62@$`$````&!*`0`#````<4H!
M``,```!U2@$`%P```'E*`0`#````D4H!`!0```"52@$`"P```*I*`0`$````
MMDH!``@```"[2@$`"0```,1*`0!/````SDH!`"H````>2P$`!@```$E+`0`(
M````4$L!`!P```!92P$`'````'9+`0`A````DTL!`"@```"U2P$`'P```-Y+
M`0`I````_DL!`%@````H3`$`+````(%,`0`*````KDP!``L```"Y3`$`"P``
M`,5,`0`-````T4P!`!$```#?3`$`$````/%,`0`.`````DT!`!`````130$`
M$@```")-`0`3````-4T!`!,```!)30$`!@```%U-`0`<````9$T!`!X```"!
M30$`$P```*!-`0`2````M$T!``4```#'30$`"````,U-`0!B````UDT!``@`
M```Y3@$`%@```$).`0`5````64X!``0```!O3@$`!@```'1.`0`<````>TX!
M`!L```"83@$`%@```+1.`0`;````RTX!`!H```#G3@$`(0````)/`0`D````
M)$\!``L```!)3P$`#P```%5/`0`&````94\!`!@```!L3P$`'0```(5/`0`;
M````HT\!`!L```"_3P$`!0```-M/`0`3````X4\!``X```#U3P$`"0````10
M`0`)````#E`!`!8````84`$`&P```"]0`0`)````2U`!``8```!54`$`$@``
M`%Q0`0`4````;U`!``L```"$4`$`%````)!0`0`5````I5`!``@```"[4`$`
M'0```,10`0`Q````XE`!``<````440$`$````!Q1`0`*````+5$!``X````X
M40$`!P```$=1`0`)````3U$!`!(```!940$`#````&Q1`0`'````>5$!`!0`
M``"!40$`#P```)91`0`5````IE$!``8```"\40$`'````,-1`0`5````X%$!
M`!8```#V40$`&`````U2`0`4````)E(!`#$````[4@$`/@```&U2`0`G````
MK%(!`!(```#44@$`$@```.=2`0`R````^E(!``4````M4P$`"@```#-3`0`.
M````/E,!``D```!-4P$`%0```%=3`0`*````;5,!`!8```!X4P$`'@```(]3
M`0`?````KE,!`"$```#.4P$`(@```/!3`0`=````$U0!`"@````Q5`$`'P``
M`%I4`0`I````>E0!`!\```"D5`$`(@```,14`0`>````YU0!`"H````&50$`
M*P```#%5`0`C````754!`"D```"!50$`,````*M5`0`O````W%4!`!8````,
M5@$`+@```"-6`0`5````4E8!`+<```!H5@$`$@```"!7`0`B````,U<!`"<`
M``!65P$`)P```'Y7`0`E````IE<!`!P```#,5P$`(````.E7`0`O````"E@!
M`"`````Z6`$`(````%M8`0`L````?%@!`$<```"I6`$`#P```/%8`0`(````
M`5D!``8````*60$`#P```!%9`0`4````(5D!`!0````V60$`!P```$M9`0`0
M````4UD!`!L```!D60$`"````(!9`0`$````B5D!`!$```".60$`$0```*!9
M`0`6````LED!`!0```#)60$`$@```-Y9`0`S````\5D!``@````E6@$`%```
M`"Y:`0`&````0UH!`!$```!*6@$`%P```%Q:`0`?````=%H!`!(```"46@$`
M`@```*=:`0`'````JEH!`!<```"R6@$`!````,I:`0`%````SUH!`!(```#5
M6@$`!0```.A:`0`2````[EH!``<````!6P$`%0````E;`0`5````'UL!`!(`
M```U6P$`%````$A;`0`=````75L!``L```![6P$`"````(=;`0`5````D%L!
M``X```"F6P$`#@```+5;`0`9````Q%L!`!<```#>6P$`#0```/9;`0`1````
M!%P!`"H````67`$`&@```$%<`0`/````7%P!`!H```!L7`$`%````(=<`0`3
M````G%P!`!$```"P7`$`$0```,)<`0`&````U%P!``T```#;7`$`#P```.E<
M`0`3````^5P!`"X````-70$`+0```#Q=`0`(````:ET!``D```!S70$`'0``
M`'U=`0`+````FUT!`!H```"G70$`&@```,)=`0`)````W5T!`!H```#G70$`
M%0````)>`0`5````&%X!`!,````N7@$`'````$)>`0`(````7UX!``@```!H
M7@$`*@```'%>`0!!````G%X!`"(```#>7@$`"`````%?`0`4````"E\!``T`
M```?7P$`-````"U?`0`0````8E\!`!D```!S7P$`!P```(U?`0`1````E5\!
M``,```"G7P$`"0```*M?`0`)````M5\!`!<```"_7P$`#P```-=?`0`0````
MYU\!`!````#X7P$`%0````E@`0`2````'V`!`!(````R8`$`%0```$5@`0`'
M````6V`!``<```!C8`$`"@```&M@`0`,````=F`!``(```"#8`$`$0```(9@
M`0`1````F&`!`!\```"J8`$`(0```,I@`0`*````[&`!``X```#W8`$`$P``
M``9A`0`;````&F$!`#L````V80$`)@```')A`0`.````F6$!`!,```"H80$`
M<@```+QA`0`9````+V(!``\```!)8@$`$@```%EB`0`(````;&(!``8```!U
M8@$`#@```'QB`0`&````BV(!``@```"28@$`!P```)MB`0`&````HV(!``X`
M``"J8@$`#0```+EB`0`0````QV(!``T```#88@$`&P```.9B`0`.`````F,!
M``H````18P$`"P```!QC`0`'````*&,!``H````P8P$`#P```#MC`0`\````
M2V,!``X```"(8P$`"@```)=C`0`'````HF,!`!D```"J8P$`(````,1C`0`<
M````Y6,!``T````"9`$`'````!!D`0`=````+60!`#````!+9`$`'P```'QD
M`0`:````G&0!`!$```"W9`$`*````,ED`0`G````\F0!`!T````:90$`'```
M`#AE`0`B````564!`"4```!X90$`&0```)YE`0`=````N&4!``<```#690$`
M&@```-YE`0`,````^64!``8````&9@$`!P````UF`0`*````%68!``P````@
M9@$`$P```"UF`0`&````068!`!D```!(9@$`'````&)F`0`/````?V8!`!$`
M``"/9@$`$@```*%F`0`/````M&8!`"(```#$9@$`!P```.=F`0`%````[V8!
M``<```#U9@$`#````/UF`0`&````"F<!`!(````19P$`%P```"1G`0`+````
M/&<!``H```!(9P$`!0```%-G`0`9````66<!``T```!S9P$`!P```(%G`0`I
M````B6<!`!(```"S9P$`AP```,9G`0`:````3F@!``8```!I:`$`!0```'!H
M`0`,````=F@!``8```"#:`$`"````(IH`0`*````DV@!``P```">:`$`!0``
M`*MH`0`)````L6@!``H```"[:`$`%@```,9H`0`9````W6@!`!(```#W:`$`
M%@````II`0`@````(6D!``(```!":0$`!````$5I`0`0````2FD!``@```!;
M:0$`#0```&1I`0`'````<FD!`#4```!Z:0$`"0```+!I`0`'````NFD!`!<`
M``#":0$`$@```-II`0`'````[6D!``D```#U:0$`!````/]I`0`+````!&H!
M``8````0:@$`%@```!=J`0`&````+FH!``<````U:@$`#@```#UJ`0`+````
M3&H!``@```!8:@$`%@```&%J`0`+````>&H!``<```"$:@$`!0```(QJ`0`6
M````DFH!`"$```"I:@$`!@```,MJ`0`)````TFH!``4```#<:@$`"0```.)J
M`0`'````[&H!``T```#T:@$`#`````)K`0`'````#VL!``X````7:P$`!@``
M`"9K`0`$````+6L!`#,````R:P$`-P```&9K`0`V````GFL!`"````#5:P$`
M!@```/9K`0`/````_6L!``4````-;`$`"````!-L`0`>````'&P!`!8````[
M;`$`!P```%)L`0`'````6FP!`"````!B;`$`#0```(-L`0`)````D6P!`!L`
M``";;`$`!@```+=L`0`)````OFP!`"0```#(;`$`"````.UL`0`,````]FP!
M``P````#;0$`#0```!!M`0`)````'FT!`!`````H;0$`%P```#EM`0`(````
M46T!``D```!:;0$`"````&1M`0`S````;6T!`"\```"A;0$`,@```-%M`0`F
M````!&X!`$8````K;@$`.@```')N`0`J````K6X!`#(```#8;@$`,@````MO
M`0`S````/F\!`"4```!R;P$`$@```)AO`0`3````JV\!``X```"_;P$`(```
M`,YO`0`?````[V\!`!\````/<`$`'0```"]P`0`)````37`!``L```!7<`$`
M"@```&-P`0`(````;G`!`"<```!W<`$`*````)]P`0`P````R'`!``0```#Y
M<`$`"@```/YP`0`9````"7$!`",````C<0$`#@```$=Q`0`7````5G$!``D`
M``!N<0$`#P```'AQ`0`5````B'$!`!,```"><0$`*````+)Q`0!I````VW$!
M`!4```!%<@$`$````%MR`0`1````;'(!`!D```!^<@$`&@```)AR`0`5````
MLW(!``<```#)<@$`*````-%R`0`5````^G(!`!X````0<P$`$@```"]S`0`.
M````0G,!`!@```!1<P$`&@```&IS`0`Q````A7,!`*,```"W<P$`%0```%MT
M`0`&````<70!`!<```!X=`$`"@```)!T`0`+````FW0!``L```"G=`$`&P``
M`+-T`0`3````SW0!``\```#C=`$`#P```/-T`0`9`````W4!`"\````==0$`
M+@```$UU`0`L````?'4!`"L```"I=0$`(P```-5U`0`B````^74!`!L````<
M=@$`00```#AV`0`2````>G8!`!8```"-=@$`&0```*1V`0`8````OG8!``\`
M``#7=@$`%P```.=V`0`;````_W8!`!0````;=P$`&````#!W`0`O````27<!
M`!T```!Y=P$`&0```)=W`0`Q````L7<!`!(```#C=P$`"````/9W`0`/````
M_W<!``X````/>`$`)````!YX`0`9````0W@!`!0```!=>`$`#P```')X`0`;
M````@G@!`!0```">>`$`'````+-X`0`2````T'@!`!H```#C>`$`'0```/YX
M`0`5````''D!`!(````R>0$`%@```$5Y`0`=````7'D!`",```!Z>0$`'@``
M`)YY`0`7````O7D!`!0```#5>0$`'0```.IY`0`<````"'H!``L````E>@$`
M&@```#%Z`0`&````3'H!``8```!3>@$`"0```%IZ`0`3````9'H!``@```!X
M>@$`"0```(%Z`0`(````BWH!``<```"4>@$`!P```)QZ`0`&````I'H!``@`
M``"K>@$`%P```+1Z`0`'````S'H!``D```#4>@$`!0```-YZ`0`(````Y'H!
M``8```#M>@$`#P```/1Z`0`.````!'L!`!`````3>P$`$0```"1[`0`+````
M-GL!`!0```!">P$`!@```%=[`0`L````7GL!`!,```"+>P$`#0```)][`0`/
M````K7L!``L```"]>P$`"P```,E[`0`2````U7L!`"<```#H>P$`!@```!!\
M`0`)````%WP!`"<````A?`$`$@```$E\`0`5````7'P!``@```!R?`$`"0``
M`'M\`0!*````A7P!``L```#0?`$`!0```-Q\`0`E````XGP!``H````(?0$`
M&0```!-]`0`'````+7T!`!0````U?0$`"P```$I]`0`<````5GT!`"D```!S
M?0$`&````)U]`0`'````MGT!``4```"^?0$`"@```,1]`0`P````SWT!``<`
M````?@$`!P````A^`0`1````$'X!`!,````B?@$`!P```#9^`0`(````/GX!
M`!8```!'?@$`#@```%Y^`0`.````;7X!`!````!\?@$`%0```(U^`0`7````
MHWX!``\```"[?@$`'0```,M^`0`1````Z7X!`!(```#[?@$`"0````Y_`0`'
M````&'\!``H````@?P$`.0```"M_`0`(````97\!`!0```!N?P$`+P```(-_
M`0`;````LW\!`!4```#/?P$`%@```.5_`0`6````_'\!`!4````3@`$`$```
M`"F``0`8````.H`!`!4```!3@`$`'@```&F``0`<````B(`!`!T```"E@`$`
M"@```,.``0`'````SH`!``D```#6@`$`$0```."``0`0````\H`!``4````#
M@0$`"P````F!`0`*````%8$!`!,````@@0$`5````#2!`0`5````B8$!``T`
M``"?@0$`!0```*V!`0`(````LX$!`!H```"\@0$`&@```->!`0`:````\H$!
M``T````-@@$``@```!N"`0`$````'H(!`"@````C@@$``P```$R"`0`%````
M4((!``H```!6@@$`#````&&"`0`&````;H(!``8```!U@@$`#@```'R"`0`3
M````BX(!``<```"?@@$`"0```*>"`0`(````L8(!``4```"Z@@$`!0```,""
M`0!7````QH(!``\````>@P$`$@```"Z#`0`%````08,!``<```!'@P$`(P``
M`$^#`0`Q````<X,!``T```"E@P$`"0```+.#`0`(````O8,!``\```#&@P$`
M"P```-:#`0`*````XH,!`!0```#M@P$`*P````*$`0`:````+H0!`!D```!)
MA`$`$````&.$`0`<````=(0!``8```"1A`$`!@```)B$`0`(````GX0!``8`
M``"HA`$`#@```*^$`0`.````OH0!``8```#-A`$`3````-2$`0`2````(84!
M``T````TA0$`"P```$*%`0`6````3H4!`$0```!EA0$`!P```*J%`0`%````
MLH4!``<```"XA0$`(@```,"%`0`(````XX4!``H```#LA0$`&0```/>%`0`:
M````$88!``P````LA@$`"0```#F&`0`%````0X8!`"<```!)A@$`(P```'&&
M`0!)````E88!`!````#?A@$`)P```/"&`0`0````&(<!``4````IAP$`#@``
M`"^'`0`,````/H<!``D```!+AP$`#P```%6'`0`*````98<!`!L```!PAP$`
M!P```(R'`0`3````E(<!``<```"HAP$`"0```+"'`0`1````NH<!``H```#,
MAP$`"@```->'`0`-````XH<!`"````#PAP$`!P```!&(`0`1````&8@!`!0`
M```KB`$`$@```$"(`0`(````4X@!``\```!<B`$`$````&R(`0`1````?8@!
M`!$```"/B`$`$````*&(`0`/````LH@!`!````#"B`$`$@```-.(`0`*````
MYH@!`!<```#QB`$`)@````F)`0!,````,(D!`!,```!]B0$`#0```)&)`0`-
M````GXD!`!<```"MB0$`"0```,6)`0`-````SXD!``8```#=B0$`#@```.2)
M`0`(````\XD!``8```#\B0$`!P````.*`0`9````"XH!``L````EB@$`$@``
M`#&*`0`5````1(H!`"$```!:B@$`'P```'R*`0`8````G(H!`!8```"UB@$`
M'````,R*`0`>````Z8H!`!H````(BP$`!P```".+`0`'````*XL!`!(````S
MBP$`$````$:+`0`.````5XL!``X```!FBP$`(P```'6+`0`1````F8L!`!8`
M``"KBP$`"0```,*+`0`/````S(L!``@```#<BP$`$P```.6+`0`)````^8L!
M``L````#C`$`!P````^,`0`(````%XP!``8````@C`$`!0```">,`0`"````
M+8P!`!4````PC`$`%0```$:,`0`E````7(P!`"(```""C`$`%P```*6,`0`@
M````O8P!`#0```#>C`$`#@```!.-`0`C````(HT!`"@```!&C0$`+0```&^-
M`0`M````G8T!`#(```#+C0$`$P```/Z-`0`4````$HX!`!(````GC@$`$@``
M`#J.`0`4````38X!`!(```!BC@$`$````'6.`0`2````AHX!`!P```"9C@$`
M+0```+:.`0`M````Y(X!`#$````2CP$`+@```$2/`0`O````<X\!`"P```"C
MCP$`8````-"/`0`@````,9`!`!(```!2D`$`$0```&60`0`D````=Y`!`#$`
M``"<D`$`$P```,Z0`0`9````XI`!``T```#\D`$`0`````J1`0!`````2Y$!
M``4```",D0$`!````)*1`0`5````EY$!``X```"MD0$`$@```+R1`0`8````
MSY$!``D```#HD0$`"````/*1`0`,````^Y$!``P````(D@$`#0```!62`0`*
M````(Y(!``T````ND@$`"````#R2`0`A````19(!``D```!GD@$`!P```'&2
M`0`1````>9(!`!(```"+D@$`&@```)Z2`0`0````N9(!`#,```#*D@$``@``
M`/Z2`0`(`````9,!`!(````*DP$`$0```!V3`0`+````+Y,!``8````[DP$`
M$````$*3`0`&````4Y,!``8```!:DP$`+P```&&3`0`8````D9,!`"@```"J
MDP$`5@```-.3`0`7````*I0!`",```!"E`$`$@```&:4`0`*````>90!``T`
M``"$E`$`$P```)*4`0`,````II0!``D```"SE`$`#````+V4`0`?````RI0!
M`!<```#JE`$`!`````*5`0`0````!Y4!``\````8E0$`$0```"B5`0`E````
M.I4!`!@```!@E0$`&0```'F5`0`3````DY4!`"$```"GE0$`"0```,F5`0`'
M````TY4!`!$```#;E0$`"0```.V5`0`*````]Y4!``@````"E@$`#0````N6
M`0`*````&98!``4````DE@$`'@```"J6`0`&````298!`!4```!0E@$`"@``
M`&:6`0`1````<98!``L```"#E@$`%P```(^6`0`L````IY8!`!L```#4E@$`
M#````/"6`0`-````_98!`!L````+EP$`!@```">7`0`K````+I<!``8```!:
MEP$`'0```&&7`0`&````?Y<!``D```"&EP$`'P```)"7`0`U````L)<!``8`
M``#FEP$`"P```.V7`0`+````^9<!`!8````%F`$`%````!R8`0`$````,9@!
M``<````VF`$`"0```#Z8`0`)````2)@!``H```!2F`$`$P```%V8`0`)````
M<9@!``D```![F`$`"0```(68`0`;````CY@!`#4```"KF`$`/@```.&8`0`9
M````()D!`"<````ZF0$`'````&*9`0`\````?YD!`!@```"\F0$`%````-69
M`0`N````ZID!`"8````9F@$`!P```$":`0`)````2)H!``H```!2F@$`"P``
M`%V:`0`5````:9H!`!$```!_F@$`*0```)&:`0`@````NYH!`"X```#<F@$`
M,P````N;`0`&````/YL!`!4```!&FP$`"````%R;`0`(````99L!`"0```!N
MFP$`%````).;`0`6````J)L!`!<```"_FP$`$````->;`0`(````Z)L!`!,`
M``#QFP$`"0````6<`0`0````#YP!``\````@G`$`&````#"<`0`J````29P!
M``P```!TG`$`!P```(&<`0`'````B9P!`!H```"1G`$`$````*R<`0`>````
MO9P!`!0```#<G`$`!@```/&<`0`+````^)P!``T````$G0$`!@```!*=`0`1
M````&9T!``@````KG0$`"````#2=`0`;````/9T!`!,```!9G0$`,````&V=
M`0!#````GIT!``X```#BG0$`&P```/&=`0`D````#9X!`!H````RG@$`!0``
M`$V>`0`0````4YX!``@```!DG@$`$````&V>`0`L````?IX!``@```"KG@$`
M#P```+2>`0`3````Q)X!`!8```#8G@$`%P```.^>`0`-````!Y\!`#P````5
MGP$`"0```%*?`0`B````7)\!`!(```!_GP$`%@```)*?`0`L````J9\!`!X`
M``#6GP$`"````/6?`0`3````_I\!`!4````2H`$`"0```"B@`0`*````,J`!
M`!,````]H`$`"````%&@`0`7````6J`!`!P```!RH`$`!@```(^@`0`(````
MEJ`!`!(```"?H`$`%````+*@`0`6````QZ`!``0```#>H`$`"````..@`0`+
M````[*`!``X```#XH`$`#P````>A`0`2````%Z$!`!(````JH0$`"````#VA
M`0`)````1J$!`"@```!0H0$`'````'FA`0`:````EJ$!``<```"QH0$`$@``
M`+FA`0`&````S*$!``X```#3H0$`&0```.*A`0`<````_*$!`"8````9H@$`
M"P```$"B`0`'````3*(!``,```!4H@$`!@```%BB`0`(````7Z(!``4```!H
MH@$`#P```&ZB`0`7````?J(!``T```"6H@$`'0```*2B`0`=````PJ(!`!H`
M``#@H@$`!0```/NB`0`+`````:,!`!0````-HP$`"0```"*C`0`-````+*,!
M``D````ZHP$`#````$2C`0`4````4:,!`%8```!FHP$`&````+VC`0`'````
MUJ,!``<```#>HP$`!P```.:C`0`0````[J,!`!0```#_HP$`"@```!2D`0`2
M````'Z0!`!`````RI`$`$0```$.D`0`;````5:0!`!,```!QI`$`%0```(6D
M`0`D````FZ0!`!,```#`I`$`)0```-2D`0`D````^J0!`&(````?I0$`&P``
M`(*E`0`:````GJ4!`!T```"YI0$`&P```->E`0`D````\Z4!`!T````8I@$`
M*0```#:F`0`;````8*8!`!H```!\I@$`)````)>F`0`T````O*8!`!X```#Q
MI@$`&@```!"G`0`9````*Z<!`!H```!%IP$`"@```&"G`0`)````:Z<!``L`
M``!UIP$`"````(&G`0`6````BJ<!``\```"AIP$`%0```+&G`0`(````QZ<!
M`%````#0IP$`00```"&H`0`H````8Z@!`$\```",J`$`&P```-RH`0`K````
M^*@!``@````DJ0$`$````"VI`0`*````/JD!`!$```!)J0$`*0```%NI`0`&
M````A:D!``P```",J0$`#@```)FI`0`.````J*D!`$T```"WJ0$`)0````6J
M`0`A````*ZH!`!(```!-J@$`(````&"J`0`8````@:H!`!P```":J@$`'P``
M`+>J`0`>````UZH!`",```#VJ@$`%````!JK`0`&````+ZL!``L````VJP$`
M#0```$*K`0`)````4*L!`"H```!:JP$`"P```(6K`0`,````D:L!``<```">
MJP$`$0```*:K`0`*````N*L!``4```##JP$`%@```,FK`0`)````X*L!``D`
M``#JJP$`!````/2K`0`.````^:L!`!@````(K`$`#@```"&L`0`'````,*P!
M`!4````XK`$`$````$ZL`0`>````7ZP!`!````!^K`$`"0```(^L`0`,````
MF:P!`!H```"FK`$`*````,&L`0`1````ZJP!`!$```#\K`$`)@````ZM`0`&
M````-:T!`!$````\K0$`!@```$ZM`0`(````5:T!``8```!>K0$`'0```&6M
M`0`^````@ZT!``X```#"K0$`$@```-&M`0`0````Y*T!``<```#UK0$`"0``
M`/VM`0`*````!ZX!``P````2K@$`#P```!^N`0`7````+ZX!``8```!'K@$`
M$@```$ZN`0`.````8:X!``D```!PK@$`#@```'JN`0`8````B:X!``T```"B
MK@$`!0```+"N`0`$````MJX!``8```"[K@$`"````,*N`0`(````RZX!`!H`
M``#4K@$`5````.^N`0`T````1*\!`!D```!YKP$`!P```).O`0`'````FZ\!
M``H```"CKP$`"@```*ZO`0`'````N:\!``H```#!KP$`%0```,RO`0`,````
MXJ\!``H```#OKP$`#````/JO`0`(````![`!``P````0L`$`"0```!VP`0`'
M````)[`!`!@````OL`$`"P```$BP`0`'````5+`!``H```!<L`$`)0```&>P
M`0`8````C;`!``<```"FL`$`"````*ZP`0`#````M[`!``H```"[L`$`%@``
M`,:P`0`'````W;`!`!,```#EL`$`$P```/FP`0`(````#;$!`!P````6L0$`
M#0```#.Q`0`>````0;$!``D```!@L0$`!@```&JQ`0`0````<;$!`!4```""
ML0$`"P```)BQ`0`-````I+$!`!<```"RL0$`!P```,JQ`0`+````TK$!``\`
M``#>L0$`#@```.ZQ`0`%````_;$!`!@````#L@$`"0```!RR`0`<````)K(!
M`!$```!#L@$`,P```%6R`0`F````B;(!`",```"PL@$`)0```-2R`0![````
M^K(!`!0```!VLP$`/P```(NS`0`T````R[,!`"$`````M`$`10```"*T`0!#
M````:+0!`!\```"LM`$`9````,RT`0`F````,;4!`#,```!8M0$`*@```(RU
M`0`3````M[4!`!@```#+M0$`?0$``.2U`0`7````8K<!`!(```!ZMP$`.```
M`(VW`0"!````QK<!`#P```!(N`$`-P```(6X`0!)````O;@!`$0````'N0$`
M'@```$RY`0`3````:[D!`!@```!_N0$`&0```)BY`0`D````LKD!`!T```#7
MN0$`(P```/6Y`0`4````&;H!`!L````NN@$`(0```$JZ`0`7````;+H!`!4`
M``"$N@$`#P```)JZ`0`P````JKH!`)8```#;N@$`6P```'*[`0`L````SKL!
M`%(```#[NP$`.0```$Z\`0!#````B+P!`!P```#,O`$`&0```.F\`0`7````
M`[T!`",````;O0$`)@```#^]`0`<````9KT!`",```"#O0$`1P```*>]`0!'
M````[[T!`#T````WO@$`/````'6^`0`?````LKX!`!8```#2O@$`,````.F^
M`0`J````&K\!`"H```!%OP$`+0```'"_`0!G````GK\!`&4````&P`$`JP``
M`&S``0`6````&,$!`"T````OP0$`,0```%W!`0`P````C\$!`$D```#`P0$`
M'@````K"`0!.````*<(!`!P```!XP@$`%@```)7"`0`'````K,(!`+$```"T
MP@$`10```&;#`0`H````K,,!`"L```#5PP$`,P````'$`0`:````-<0!`!X`
M``!0Q`$`+@```&_$`0`)````GL0!``@```"HQ`$`!@```+'$`0`.````N,0!
M``X```#'Q`$`$@```-;$`0`*````Z<0!``@```#TQ`$`#````/W$`0`#````
M"L4!`&P````.Q0$`"````'O%`0`0````A,4!``4```"5Q0$`!P```)O%`0`%
M````H\4!``4```"IQ0$`!P```*_%`0`9````M\4!``@```#1Q0$`%0```-K%
M`0`,````\,4!``4```#]Q0$`!P````/&`0`'````"\8!`!4````3Q@$`"@``
M`"G&`0`7````-,8!``8```!,Q@$`&P```%/&`0`/````;\8!``,```!_Q@$`
M)@```(/&`0`$````JL8!``8```"OQ@$`!P```+;&`0`B````OL8!`$$```#A
MQ@$`*````"/'`0`J````3,<!`!8```!WQP$`)P```(['`0`@````ML<!`!\`
M``#7QP$`(P```/?'`0`>````&\@!`!L````ZR`$`(@```%;(`0`>````><@!
M`"L```"8R`$`*0```,3(`0`K````[L@!`!\````:R0$`(P```#K)`0`A````
M7LD!`!P```"`R0$`)@```)W)`0`G````Q,D!`",```#LR0$`'P```!#*`0`<
M````,,H!`"(```!-R@$`)0```'#*`0`=````ELH!`"4```"TR@$`)@```-K*
M`0`Z`````<L!`"$````\RP$`)0```%[+`0`C````A,L!`"0```"HRP$`'@``
M`,W+`0`<````[,L!`"0````)S`$`(````"[,`0`K````3\P!`",```![S`$`
M"0```)_,`0`3````J<P!`!H```"]S`$`&@```-C,`0`:````\\P!``H````.
MS0$`$````!G-`0`9````*LT!`!(```!$S0$`$P```%?-`0`B````:\T!``@`
M``".S0$`"0```)?-`0`D````H<T!`"<```#&S0$`+P```.[-`0`A````'LX!
M``P```!`S@$`^@```$W.`0`1````2,\!`!4```!:SP$`"@```'#/`0`-````
M>\\!`!0```")SP$`'P```)[/`0`(````OL\!`#$```#'SP$`'````/G/`0`:
M````%M`!``D````QT`$`%0```#O0`0`+````4=`!`$4```!=T`$`+P```*/0
M`0`9````T]`!`!0```#MT`$`%@````+1`0`@````&=$!`!`````ZT0$`$0``
M`$O1`0`2````7=$!`!L```!PT0$`#````(S1`0`;````F=$!``D```"UT0$`
M&P```+_1`0`*````V]$!`!P```#FT0$`"`````/2`0`C````#-(!``<````P
MT@$`"0```#C2`0`)````0M(!`#$```!,T@$`$@```'[2`0`'````D=(!`!``
M``"9T@$`%````*K2`0`1````O](!``L```#1T@$`#0```-W2`0`)````Z](!
M`!<```#UT@$`#0````W3`0`3````&],!`!8````OTP$`$@```$;3`0`9````
M6=,!`!<```!STP$`%0```(O3`0`)````H=,!``L```"KTP$`&0```+?3`0`$
M````T=,!`"H```#6TP$`#P````'4`0`'````$=0!``4````9U`$`#````!_4
M`0`2````+-0!``L````_U`$``P```$O4`0`,````3]0!``P```!<U`$`"P``
M`&G4`0`&````==0!`!(```!\U`$`"0```(_4`0`3````F=0!`!0```"MU`$`
M#@```,+4`0`K````T=0!`!<```#]U`$`%@```!75`0`,````+-4!`"0````Y
MU0$`!@```%[5`0`1````9=4!`$8```!WU0$`#P```+[5`0`,````SM4!``<`
M``#;U0$`!````./5`0`4````Z-4!``8```#]U0$`!P````36`0`(````#-8!
M``8````5U@$`#0```!S6`0`-````*M8!``X````XU@$`"@```$?6`0`1````
M4M8!`!@```!DU@$`!0```'W6`0`>````@]8!`"(```"BU@$`&@```,76`0`=
M````X-8!``\```#^U@$``@````[7`0`$````$=<!`!`````6UP$`!@```"?7
M`0`'````+M<!``0````VUP$`$````#O7`0!'````3-<!`!$```"4UP$`*0``
M`*;7`0`D````T-<!`$0```#UUP$`)P```#K8`0`F````8M@!`!````")V`$`
M90```)K8`0`;`````-D!`%@````<V0$`+@```'79`0`6````I-D!`#,```"[
MV0$`*P```._9`0`P````&]H!`"<```!,V@$`,P```'3:`0`D````J-H!`",`
M``#-V@$`)P```/':`0`3````&=L!`#`````MVP$`,0```%[;`0`P````D-L!
M`!<```#!VP$`$@```-G;`0`4````[-L!`$\````!W`$`$P```%'<`0!M````
M9=P!`%0```#3W`$`)P```"C=`0`2````4-T!`!H```!CW0$`%````'[=`0`B
M````D]T!`!L```"VW0$`&@```-+=`0!<````[=T!`!8```!*W@$`"P```&'>
M`0`&````;=X!``<```!TW@$`"````'S>`0`*````A=X!`!L```"0W@$`%@``
M`*S>`0`:````P]X!`"8```#>W@$`$0````7?`0`/````%]\!``D````GWP$`
M"P```#'?`0`$````/=\!``X```!"WP$`"0```%'?`0`0````6]\!``<```!L
MWP$`"````'3?`0`;````?=\!``\```"9WP$`#````*G?`0`+````MM\!`!$`
M``#"WP$`"P```-3?`0`'````X-\!`!0```#HWP$`%P```/W?`0`(````%>`!
M``X````>X`$`%P```"W@`0`+````1>`!``X```!1X`$`"P```&#@`0`%````
M;.`!``T```!RX`$`"P```(#@`0`+````C.`!``L```"8X`$`!@```*3@`0`&
M````J^`!`!$```"RX`$``@```,3@`0`*````Q^`!``@```#2X`$`"````-O@
M`0`F````Y.`!``8````+X0$`#````!+A`0`0````'^$!``X````PX0$`"0``
M`#_A`0`)````2>$!``0```!3X0$`$````%CA`0`2````:>$!``<```!\X0$`
M#0```(3A`0`C````DN$!``H```"VX0$`!0```,'A`0`6````Q^$!``4```#>
MX0$``@```.3A`0`+````Y^$!``$```!-````F`,``),```!L`````````%T$
M````````2`0``*P"`````````````$(%````````.P0``#`%````````#`$`
M`(<`````````````````````````"@8``&\#```/`0```````/4#``#9`@``
MW@```/X"``#!!0``>P8``'H$````````G0(``-<$``!B````E`(``'8"``#/
M!@``````````````````Z@4``%H#```.````.0````````"8````````````
M``",!```*@8``,X`````````D0```"(!``#9`0``L@$```<$``!7`0``#P8`
M`(0%``#$!0`````````````<`0``N08``%0!``!)`0``70,````&```D````
MW`0``/$#``"A!0```````#8```!L`0``\@0````````>!```<`````````"J
M`````````%L!``#X`P```````(,"``#4!0````(```````#L`P``O@,```T`
M``"S!0``VP8```````!U`P```````)\!``"U`@``U`,```````!2!```@@4`
M``````"S`0```````````````````````-L"```;`0```````/P!```K````
M`00``%P&```#!@``Q`$``',$````````EP$``-P&``")!```R`8```````"-
M`0``T0,``"X&``!(`0``=00``%D#```A`P``C@4``-("``!F`@```````$D%
M```(````=P```%4"``#%!````````),"````````;@$`````````````````
M`*X```"(!0``=`$```````!L`P```````',```#E!```/0(``%H%``"J`P``
MXP```.````"6`P``H@$``(T#`````````````!\&``"2!@``N0,``*X$```F
M!@````````````#(`@```````&,!``#S!0``R0$``%("```R`@``+00``)0`
M```5!0``(P8``````````````````#`#``#/!0``E0,``%4%``#F`@``V`(`
M`+T#``"@`@`````````````(!0``FP$``'D!``!;`P``\@8```````!.!```
MVP0```````![````K08````````L````_P```"@$``!3`0``\P```#`!``#Y
M!`````````4```#B`P``7`0```````"``0``-@8``'0```!U`@```````,$!
M```Q`0```````&@%````````4P4``/,#```H`@``1`8``"P#``"0`0``/`0`
M`,0$````````CP4``/\%````````.`````````"N!@```````"X"```F````
M,08```````!&````J0$``*0```"G`P```````/$&`````````````(T"``#+
M`@``9`$``+<$```2!```Q@,```````!/!0``<@$``-H$``#2!@``JP8`````
M``!]!```!@0``(0#``!@`P``KP```'X&``"+!```W@$``'<&``"D!```>P0`
M````````````$@$``-P%``"X`@``RP,```````#;`0```````,H&``"U`P``
MHP8````````W````S`,``(4!```/!P``O@0````````+!```808```````"T
M`@``&P```$,$``!\!@``Z`(```````"Z!0``*P(``,$```!M!0``0P$`````
M````````-@(``/(```"3!0``=`,``"8%```\````T0```,4%``!?`P``)`(`
M```````+!@``604``!$!``"W!@``>@8``.($``!#````=0```+H`````````
M/P4``.(!``!'`P``0@8``*<%``!'!`````````````!S!0``XP,```````!`
M!@``(P```"P$``!Y!0``U`$``#L%``"<!@``&@```*<!```@`@``$`,``%4#
M`````````````!T"`````````````#L!``!>`0``'08``,("``"[!```````
M`.D!``#D!@```````,L!`````````````*$!```/`@``<@,``+T&````````
M````````````````108``.T!``!?````UP(`````````````(0$``,P%``"O
M`P``<00``-\!``"A`@``WP4```4#`````````````!@"````````)@0``*,`
M``!,````,0,``-\#``!N!@``#@4``($"``"/`@``NP,``'\```#W!```$```
M`-\```#_!````````-D&``!M!````````)4%``!V!```$`<```````##````
MN0$``-P```"B````^`4``/,$```,!```8P8``,<%```P!@``9P,``*H!``#.
M!0``6P(```````!4`@``<`8``,T#``!\`P``7@,``%D!``!]!0```````"<"
M``#$````"0<``&8$``!'`@``_@,``+$````,`@```````)D$``!/`@``````
M```%```6`P```0,``#\```#A!@``UP````````!X````\`,``/<&````````
MV````/0!```I`P``A@(```````````````````````#M!@``8@$``%<"``!-
M`0```````"P!``"_`0``ZP8``#T&``"W`P``&08```````!L!@``/@4``-H&
M````````SP0``),#```Z!@``TP0``/4$``!J````]@,``/<!```D!@``^0,`
M`!<!``#K````B04``+L&```#````T`0``(,#``#U`@``H08``$\!```%`@``
MV@(``#@!````````*@```-$%``#V`0``EP(``.`!`````````````*D#```(
M!````````)X#``#D!````````"P%``!#`P``$00``/<#```(!@``:@,``!P&
M````````;P(``"<%```(!P``,P````````"4!0``B`$``-8$``"<`P``?@4`
M`(8#``"P`@```````+(````K!@```````"D!``"D`@``U`0``)8$``"&````
MGP8``/H#``#A!0```````&0%``#R`0``F0$```````"X!0``-P(``-`````@
M!0``5@4``.,$``#N`````````"@&```<!0``N0`````````!`@``AP(``#\$
M```A!@``^`8``*4#```A!0``3@4``/$```!\!````````.T"``!F`P``0@$`
M`+(#````````904``,<!``#T`@``Y@````````#F`0``G@4``*(&``#&`0``
M5`8``*T%```9`P``40$```````">`@``:00``+X%``#Z`0````````````"?
M`P``HP,``#4$``#1!```KP0```````#_`P````````````!Y`P``[P8``'`$
M``!5````KP8``'<%``"#!0```````%,`````````K0$``*L$```J`P``*0``
M`)P!``"2!```UP4``$T$```S`0``%P(``+$!``#P`@``-`,```````"R!```
M``````8#``"[`````````)````!Z`P```````)(```"L!```"@```/T"````
M````[`0```````#G````LP8``"`&```N`0``(````)<$```E!0``H@,`````
M````````#00``/`!````````5`````8```!R`@``E`,``(4````$!@``9P4`
M```````Q`@``00$``````````````````#D%```D`0``:04```D#````````
M<@```%8`````````````````````````SP$``*D&``"K!0``5@,``*8%```]
M````(`,``%$#``#E`````````+8&``!T!@``2P0``"\#``"*`@``:@4``*@"
M``"9!0``2P(``(D&``!Q````BP,``+P%``#@!@``(@,``#4!````````L@(`
M`/P%``!N!0``BP8``/8%```"`@``O04``+X"``"8!```^`0```H%``#6`0``
M`````#X&``#:`0```@0``(T%``#T!`````````0$``!.!@``30(``+H#``#G
M`P``$@```*($``!/!@```````!H#``"O`@``ZP$``-4!```E!```Z`8``$0`
M``"!!```C00``*`!``!P`0``G@0``%$```#A`0``/P,``#4%````````!`,`
M``D"``!M`P```@8``*,!```&!0````````````"`!```A08``%<&```<!```
MS@$``#T%``#D!0``=P$```````!W!```J0``````````````^04```````"`
M!0``5@8``(L```!K`P``V`,````````2!@```````(8!````````,P4``&X#
M``#%`P```````.@````1````W@4``,P$``""````VP4`````````````&P8`
M`,L&````````)P$````````L`@``+@0``,@!````````#P4``/T&````````
M`P$```````#E!0``#`<``,,!``!2````B@````````"H!```S00``*X!````
M`````````'D$```5`@``%`,```````"<`@``\00```````!<`@``#0,``.\!
M````````8P0``%4!``#B`@``D@(``/T$``#:`P``R00```````#M`P``M@``
M`/$%```B!0``U````*L#```^````>P,``)<&``#P!0``F`(``*0!``"1!```
M(@0``*$```"L`0``,@$````'``"]`0```````%D"``!,`@``^`$``-@$``#&
M!````````!0&``!Q`P````````````#]`0```````!X"```[`P``:@(``.\#
M````````@`,`````````````=@4``(<&``#E`0``-0(``-D`````````J`$`
M``````!@`@``10,``-`&``!Y`@```````"\"```5!@``^P,``),&``!^`@``
MI`8``$@````X!0``W04```````"1`@``+0(````````Z`0``W00``%`"````
M````708``*$#``"=!```7````+\`````````9P0``/,!````````O0(`````
M``",!0``Q@8``'@&````````N`$``%(!``!B`@``90,```8"```;!```/00`
M`)H!```A!````````,D&``#M!```00(`````````````.P(```$&``!F````
M`````!<&``!N!```?````$("``#P!```$P(``.<%````````[`(``&`!``#A
M`P```````$L#`````````````$D$````````````````````````DP$``$4!
M````````D08``.`"````````F`8```````"/`P``O0``````````````E@$`
M```````V!0`````````````'!P``V@4``#<&``!P`@``PP(``$,%```(`@``
M``````\#``!:````C````+$#``#3`0``,`(`````````````$P,``+4`````
M````[P4``.0`````````100``````````````````!,&````````.0(``$T#
M``"V`P``EP```&D&``#^````U04``-8#```>`0``:P$``/0&``#5`P``A0,`
M````````````+08``$($```1!P``PP8````$``!,`P```````,L$``#Z!@``
MMP```$(#`````````````%`#``!@!```+04```<!``````````````````"/
M!```^P4```@!``"+!0``W0```+4%````````WP(``.`#``"``@``D@4`````
M``#0`0```P<```````"$!```W@,``&0```````````````````!M````20(`
M`'<"`````````````*,$``!&!```#04``-`"`````````````,\"```J`@``
MP`,``)`&``!7!0``X00``,T&`````````````+0%``#O!```CP$``#<!``#U
M`0``````````````````````````````````GP(````````I!@``_04`````
M````````^@0``-\$``"H!@```````.4#```1!0``P`````````"*`P``80$`
M`"8!``#;`P``U@(``%@!```G````%@4``%D&``"Q!```%`0``-0"``#Q`@``
M6@$``"X```!M`0``I0(``(0`````````[04```D$```C`@```````&D"```8
M`P``800``)4"`````````````-8%```3``````````````#O`@``+P8`````
M```&`0``$0,``&X"``!K!0``Z@,``!H!``"\`@``>P$``&(&```7````P`(`
M`,4&```[!@``C@```/L!`````````````%8!``!+!0``*P$``!@%``"6````
M2P```$`%``!=````?`4``'@%```F`@```````(D#```H!0```````%X$``"V
M`0``VP```#H```"Z`0``D@$``$D#``"-````^P8``,@#``"V!0``RP```+T$
M````````^P`````````5`P``:`````$%`````````````*L```".`P``%P,`
M```````;`@``I00```````"R!@``U00``&X```!\`@``!P,```````!7!```
M"P```.(%```C`P``,@```/D!```^`@``!`(```4!````````````````````
M`0```````.0!```.!```%`4``$\#````````9@4``-<!````````````````
M``"5!```R@,``/X$``"=`P``#@$``````````````````+X!``#"!0``%@8`
M`)X&``!0````%@$``)$%````````P@0``&@&````````[P````````!3`P``
M7`,```````#!!`````````````#K!0``70(``(("``"Z!@````````````#\
M`P````````<`````````7P8``,0"````````0`0```````!!`P``-P0``.8#
M``!5!`````````````#<`P``W@(``#\"```>````\@4``%L```#J`0``U@8`
M`!@$````````$P0``#0"``#=`P``U@````````!U!0```````/T`````````
M``````````#M````J@8``&$#```*!```%00`````````````@@,````````\
M`0``LP,``*4!``!!!```<08```````!_`P````````````#/`P``K`8``.P&
M``"&!@```````)X!``#5`@``6P0``!T#````````5`4``,D"``"*!0``````
M`,0#``".`0``1P4``.4"``"\`P``(`$``%@%``!D!```J@(``'T#```N!0``
M1@$``/H%`````````````"L$```Y`P``"`,```4$``!!`````````$H$``!>
M`@``@0,``/H"``#/````+0$``/X%``":`@``[@(```````#P````L04``+0$
M````````>`$``&<`````````ZP0```````",!@``'P$```````"#`0``!04`
M`',&``#5````9`8``'\%````````^0(```T"````````(0(```````!C````
M`````'H"````````F`4````````?`P``(@```*T```")`0``YP$```````#^
M`0``3P```+\#``#@!````````/P&````````-08``(X$````````404``(,`
M````````A04``&L&``"W`0``^```````````````LP(``.@%``"'!```````
M`#,#`````````````/\"````````E`8``%@&```[````LP0```0'```&!@``
MDP0``$,&``"G!````````.8%``#7!@``"P$``#0&``#<`0``@P8``$8&```Z
M!```.@(`````````````J04``-4&``!I`0````````````"O!0``^P(```,#
M``!6!```>08``'0$````````M@(``($!``"X````T`,``#`````3!0``````
M`!@&``#H`0``2P$``'8!``!?`0``$P<``/8```#*!```FP4```````!E`0``
M@08``&<!``!B!```1@,``+\&``!`````]04`````````````0P(``&<&``!A
M`@``Z0,```````"H!0```````&\!``!<`0```````$H!``!Z````PP,```(`
M``#N!```)0(``"D"```D!```$`$``(D`````````.08```````"\````YP(`
M`,D```"$`0```````*H%```T!0``S0```*4```#)!0``4`4``%<````?!```
MI@,``%X&```.!P``?@0`````````````6`(``$H"````````-0```)D"``"M
M`P``X0```+P$```>!@``?@$````````^`P``=@8``#<%````````P@8`````
M``!@!@```````,`!````````S0(``(`&``!'`0``IP```"\$``":!0``H@4`
M`&T&````````Q@(``'(&```<`P````````````!X`P``[@,```````#-!0``
M`````-$!````````GP4``)X````Q!```2`4```('``#*``````````````"[
M`@``B@$``)D#````````9@8```````!.````"@$`````````````_P$```<"
M``#.`P``O@8````````\`P``G0$``*L"````````B`(``!D"````````0`$`
M```````,`````````+@#``";`````````#,$``!$!0``]P4``,P```!*````
M408``,X"``"%!```L`$``$H#``#J!@``QP(``+L%``"I`@``P@$``"<$``!Z
M`0``?0```$`#```>`P``````````````````(P0``%T!``!A````````````
M````````FP(``$X#````````%`<```,%``#R`P``<0$``.8$````````6@8`
M`$@"``"@````````````````````8`4``.D%```"`P``4`$``$$&``"0!0``
ME0$``+8$``#K`@``M0$``&0#``"Y`@``````````````````P0,`````````
M```````````````,!@``T@4````````3`0``.0$``(,$``"5!@``6P8``-P"
M``#T`P``-@0``,H%``!V````2@8``"P&`````````````",%````````7P(`
M`*D$````````E@(``(@#``#"`P``)0,``!H&```0`@``T@$``,,%``!]!@``
M"P(````````9!```Q0$``'8#``"E!0``?@```-\&``""!@``D0$``/,"````
M````'P4``.H```#-`0``M`$```````"4`0``?@,``%X%```_`0``````````
M````````)0`````````^`0``.@,``-D#```J!0``HP4``(D"``!6`@``$`4`
M`$4%``!3!@``1`,``+\$```:!0``.`,``)`#``!R!0```````-($```7!```
MI@$```````"F`@```````"T```"X!@````````H#``!0!@```````#$%````
M````[`$````````0!```=0$```D```!A!0``900``````````````````#8!
M``"\`0````````$!``"O`0``;P0``-T&````````````````````````1P8`
M`*,"````````T`4```````"W`@``%`$``.P````O`0```````(L!```)!@``
M`````.D"```^!```Q@4```````#V!@``9`(``-,"````````;0(``#4#``"4
M!```6@0``!8$``#,!@```````&H&````````?P$`````````````EP,``!0`
M```:!```GP0``,<&```;`P``_P8``/P$```6`@``S`(```(!``"F!```V`$`
M``8'````````[@$```````"=```````````````O!0``K`````X"``"W!0``
M$0(``/("``"R!0``1`(``)T&`````````````+4$``!_!@``L0(```````!W
M`P``W@8``&4"````````<P(``!4!``#Y````$@,``+````"&!0``#P```.,&
M``#F!@``GP```%D```"'!0``$08``-T!``"@!0``&0```&4&````````;`0`
M`%$$````````TP8``+D%``#\`@``10``````````````'P````4'``#'`P``
MO`8``)P$`````````````!X%``!\`0``RP4``+@$``"P!@``/0$``(T&``":
M`P``M`,``&<"``#B````[`4``#P%````````]````&@!`````````````$P&
M````````+0,```````"_!0``Q`8``+0`````````OP(```H"``#H`P``P`4`
M`!D%````````C@(`````````````208``/4&```-`0``B`0``#@"``!7`P``
M`````/4`````````XP4``#0!``":!````````+H"````````&`````````"!
M`````````*X"``!!!0```````!H"``#E!@```````!8```!-!0``E@8``"("
M``!,`0``D`(``*<"``#3!0```````*X#```F`P```````.L#```?`@``````
M``````#\``````````````"Y!``````````````K`P``&P4``)L&````````
M`````$(```!_!```'04```````#A`@``:P(``%H"``"M`@``[@4``&D#````
M````,`0````````V`P``%P4``.<&```.!@````````H'``#`!@```````.<$
M``!>````7P0``)`$````````J`````````"Z!```EP4``.X&``"=!0``````
M`'0"``!B`P``>`(``.D`````````;`4``'L"`````````````%0$````````
M)`,`````````````_@8``%,"``#&````2`,```4&``#P!@``8P4``.H"```0
M!@``1@4``,<$```=`````````%(%`````````````&D```#Q`0```````&\&
M```2!0``<`,``.D&````````40(``,X&``"'`0``:P0```L'```2`@``FP0`
M`#,"``#Y!@``+@,``/,&``!;!0``E0```(0&`````````````+,```":````
MI`,````````I!0``T0(````````J!````````#$```"L!0````````````#`
M!````````/@"````````20``````````````T@````````!8````B`8``(L"
M```.`P```````)P%``#%`@```````.,!``!=!0```````!4```#J!```````
M```````+`P``/`8```````#C`@``M`8``*L!`````````````$\$````````
M`````)@!``!L`@```````%@$``#9!0````````<%``"^````U`8``(X&```T
M````)08```T&``"'`P``2P8``,D#```$`0``<P$``((!```$````3@(``,@$
M``"<`````0<``$@&`````P```````$0!``!&`@```````(H$``#!`@``/0,`
M`)(#``"/`````````+4&```Z!0``,@4``&@#`````````````"@```!K````
M`````#P"````````:`0``-,```#.!```600```````#@!0``?P(``"<#````
M````A@0``-D$````````T08``!('``"Q!@```````"0%```X!```````````
M```=!````````"H!``#>!```"04``/T#`````````````*8```!F`0``=08`
M`````````````P(``````````````````+`#```+!0```````'L%```W`P``
M``````````#%````A0(``#($````````P08``%,$``":!@``*P4``'T!``#"
M`````````"@!```@!```]@(``(P"```=`0``#0<``*P#``````````````<&
M``#D`P``B````$P$``````````````\$``"H`P``3@$``'$%``!H`@``8P(`
M`````````````````.(&``!0!````````&4```#'`````````/H```!8`P``
M``````````"N!0``.`8``*("``#3`P```P0``'0%``#7`P``"0$``&\%``!]
M`@``10(``!@!````````Z`0``*$$``"@`P``<P,``-H`````````J@0`````
M```C`0```````"@#``!Y````F0```/L$``",`P``#`4``,P!``"@!```;P``
M``````!X!````````#D$```B!@```````"D$``"@!@``-`0```````##!```
M`````%\%````````B@8``+`$`````````````"$```!,!0``CP8``&``````
M````308``*4&``!B!0``I`4````````O`````@4``($%````````0`(``%4&
M``"F!@``<0(``'`%````````,@,``#(&```4`@``A`(``&,#``#(````````
M```````G!@``/P8``(($``#D`@````````````!2!@``Z00``$<```!4`P``
M2@4``/8$``",`0```````)8%``#W`@``:@$``*T$`````````````%(#```9
M`0```````-@%``#=`@``<@0````````<`@``:@0``)$#``#T!0``F08```P#
M``#W````)0$``(````"[`0``T@,``,H!`````````````%P%````````````
M`*<&``";`P``,P8``-@&````````1`0```````"P!0``>@4``!P```#*`@``
M`````,@%```$!0```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@
M*'1O9&%Y*0`@*'EE<W1E<F1A>2D`(&%T(``B1FER<W1N86UE($QA<W1N86UE
M(B`@*&EE+B!*;VAN($1O92D`(DQA<W1N86UE+"!&:7)S=&YA;64B("AI92X@
M1&]E+"!*;VAN*0`E9"`E<R!A;F0@)7,`)60M9&%Y(&9O<F5C87-T`"5S("T@
M3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M<R!O
M9B!!9W)E96UE;G0`)7,@861D960N`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A
M="`E<R`E<P`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I<R!R
M97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@
M)7,`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E
M<SH@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`
M,C0@:&]U<G,`02!B<F]W<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I<R!R
M97%U:7)E9`!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N`$%-(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%B;W9E('-E87)C:"!F;W)M`$%B<V)O='1O;0!!8G-M:61D
M;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D
M`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9"!#:&EL9"!'<F]U<`!!
M9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!
M9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`
M061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<@!!9&0@=&\`061D('1O(&%D9')E<W,@8F]O:SH`
M061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K($QI<W1I;F<`061D
M<F5S<R!B;V]K(&5N=')Y`$%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R
M9V5D+@!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<P!!9&UI;FES=')A=&EO;@!!9',`061V86YC960@4V5A<F-H`$%F9VAA
M;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z
M`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!0
M97)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR
M96%D>2!%>&ES=',`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G
M:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E
M<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L
M871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL
M80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A
M;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`
M07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7
M:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!
M<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@)7,_`$%R92!Y
M;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L96-T960@
M96YT<FEE<S\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N:6$`07)M
M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I
M;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T
M<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F
M86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A
M:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87)B861O<P!"87-E;&EN90!"87-I8R!396%R8V@`0F5L87)U<P!"
M96QG:75M`$)E;&EZ90!"96QO=R!S96%R8V@@9F]R;0!"96YI;@!"97)M=61A
M`$)H=71A;@!":6YD(&9A:6QE9#H@*"5S*2`E<P!":7)T:&1A>0!";&]C:R!3
M971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R
M9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z
M96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R
M87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A
M<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`
M0G5R=6YD:0!"=7-I;F5S<R!#871E9V]R>0!#35,`0U)#`$-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S`$-35@!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E
M;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E
M<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E
M;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`
M0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#
M96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@
M069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S`$-H
M860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E
M;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA
M:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H96-K(%]!;&PO3F]N90!#:&EL
M90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4
M<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@
M=7-E<FYA;64`0VAO;W-E(&%N(&%D9')E<W,@8F]O:P!#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O
M<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S
M`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T
M80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E
M(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S
M`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!/<'1I;VYS`$-O;'5M
M;B!T:71L97,`0V]M:6-S`$-O;6UA('-E<&%R871E9"!V86QU97,`0V]M;6$@
M<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI`$-O;6UA;F0`
M0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M
M<&%N>0!#;VUP86YY($%D9')E<W,`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!0
M87-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@
M`$-O;FYE8W1I;VX@9F%I;&5D.B`E<P!#;VYN96-T:6]N(&9A:6QU<F4`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYT86-T(')E;6]V960@9G)O;2!L:7-T+@!#;VYT86-T<R!I;B!L:7-T.B`E
M<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RX`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y
M`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`
M0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4@82!L:6YK
M`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T960`
M0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I
M80!#=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E
M871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S
M96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C
M:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T
M92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`
M1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A
M=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!S;W)T:6YG(&1I
M<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#;VYF:7)M871I
M;VX`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,`1&5L971E(&)U='1O;B!B96AA=FEO=7(`1&5L971E
M(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E`$1E;&5T92!F86EL960Z("@E<RD@)7,`1&5L971E(')O=P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T:6]N(&9A:6QE9`!$
M96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5P87)T;65N=`!$97-C96YD:6YG`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R
M96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@=&\@8V]N9FER
M;2!D96QE=&EN9R!E;G1R:65S/P!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O
M;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9"`E<P!$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$;W=N
M;&]A9"!V0V%R9`!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5C
M=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S
M:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`
M161I="!E;G1R>2!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M
M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L
M96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC
M;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`
M16YT<GD@9F]R("5S('5P9&%T960N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R
M96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<W1O;FEA`$5T
M:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R
M(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E
M<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE
M('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP96-T960@)RDG`$5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$
M871E`$5X<&]N96YT`$5X<&]R=`!%>'!O<G0@061D<F5S<R!";V]K`$5X<&]R
M="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T<RX`17AP;W)T('1H92!F;VQL
M;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN`$9'($-O;&]R`$944"!U
M<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,`1F%I;&5D
M('1O(&%D9"`E<R!T;R`E<SH@)7,`1F%I;&5D('1O(&)R;W=S92!L:7-T`$9A
M:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R>0!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E
M<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P
M>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I
M;VXN`$9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E9#H@)7,`1F%I
M;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O('-E87)C:"!T:&4@9&ER
M96-T;W)Y.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&
M87)O92!)<VQA;F1S`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI
M:V4Z(`!&97<@4VAO=V5R<P!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R<P!&:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!.
M86UE`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!
M1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@
M>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R
M='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R
M86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E8G5S>2!54DP`1G)E;F-H
M($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@
M36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`
M1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A
M<@!':79E;B!.86UE`$=L;V)A;"!!9&1R97-S($)O;VL`1V\`1V]E9&5L`$=O
M;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM
M-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7``1W)O=7`@061M:6YI<W1R871I
M;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!S`$=U861E
M;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO
M;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`
M2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG
M;W)I=&AM`$AA>F4`2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<P!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@0VET
M>0!(;VUE($-O=6YT<GD`2&]M92!0:&]N90!(;VUE(%!O<W1A;"!#;V1E`$AO
M;64@4W1A=&4O4')O=FEN8V4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N
M9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R
M871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS
M:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E
M92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N
M=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@
M=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M
M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T
M:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,`24U34`!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL
M86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C
M:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`
M26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S
M(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E
M(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L
M;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`
M26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9`!);7!O<G0L(%-T97`@)60`
M26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`
M26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA
M=&EO;@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T
M(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@
M8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`
M26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T
M(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A
M<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A
M9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@
M26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N
M="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@240`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A9&1R97-S
M(&)O;VL`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`
M26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+@!);G9A;&ED(&5M86EL`$EN=F%L:60@96YT<GD`26YV86QI9"!F
M:6QE(&9O<FUA=`!);G9A;&ED(&ME>2!S<&5C:69I960N`$EN=F%L:60@;7-G
M7W1Y<&4N`$EN=F%L:60@;F%M90!);G9A;&ED(&]B:F5C=$ED`$EN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R
M97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES
M;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA
M;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE
M<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`
M2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K
M:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E
M871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y
M(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M
M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$Q$05`@<W5P<&]R="!I<R!R97%U:7)E
M9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T
M(&QO861E9"X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!-;V1I9FEE9`!,87-T($YA
M;64`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`
M3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V
M:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N
M;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R
M:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT
M($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A
M:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU
M;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI
M;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@
M0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A
M=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C
M:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,
M:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`
M3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`
M3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I
M;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN
M9P!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L
M;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F('!A9V5S`$UA>0!-
M87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL
M<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D
M+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN
M:2!396%R8V@`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!$3B!I;B!,
M1$%0('-O=7)C92!C;VYF:6=U<F%T:6]N+@!-:7-S:6YG(%!%05(@<&%C:V%G
M92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`
M36\`36]B:6QE($UA:6P`36]B:6QE(%!H;VYE`$UO9&5R871E`$UO9&EF:65D
M($1A=&4`36]D:69Y(%523`!-;V1I9GD@9F%I;&5D.B`H)7,I("5S`$UO9'5L
M=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E
M('1H86X@,2!E;G1R>2!F;W5N9`!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T
M;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE
M9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E(&QE9G0`36]V
M92!R:6=H=`!-;W9E('5P`$UO>F%M8FEQ=64`375L8F5R<GD@061D<F5S<R!"
M;V]K`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!P97)S
M;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S
M72!A;')E861Y(&5X:7-T`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT
M`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@
M3D]4($%G<F5E`$YA;64`3F%M92!&;W)M870`3F%M:6)I80!.875R=0!.97!A
M;`!.971C96YT97(@365M8F5R($1I<F5C=&]R>0!.971H97)L86YD<P!.971H
M97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#
M02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C
M87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C
M87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.
M97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@0V]N=&%C=`!.97<@36]O
M;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN
M9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N
M<P!.:6-A<F%G=6$`3FEC:VYA;64`3FEG97(`3FEG97)I80!.:6=H=`!.:75E
M`$YO`$YO("5S(&5N=')Y(&9O=6YD(&9O<B`E<P!.;R!A9&1R97-S(&)O;VMS
M(&9O=6YD+@!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H
M;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R
M(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO
M8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD
M87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@
M8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M
M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8V]N=&%C
M=',@9F]U;F0`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E
M<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE
M($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I
M9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9#87)D
M(&1A=&$@=V%S(&9O=6YD+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.
M;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO
M="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T
M('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@
M9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S
M`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!I=&5M<R!P97(@<&%G90!.
M=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R
M96%T;W(`3V)J96-T(&YO="!F;W5N9`!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@
M9FEL=&5R`$]F9FEC90!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@
M;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I
M;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T
M`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`
M3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA
M=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I
M;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y
M<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO
M=V5R<P!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`
M4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`
M4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W
M;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@
M4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C
M:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I
M9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;B!D
M96YI960`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF
M;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0
M:6YE($%D9')E<W,@0F]O:P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0
M;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A
M(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H
M96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E
M;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O
M9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@
M=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U
M<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W
M`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O
M<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@061D<F5S<R!";V]K`%!R
M:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T
M<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM
M`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U97)Y(&9A:6QE9#H@
M*"5S*2`E<P!1=6EC:R!396%R8V@`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`
M4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I
M;B!3:&]W97(`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&9A:6QE
M9#H@*"5S*2`E<P!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@
M=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296-O<F1S(&1I<W!L87EE9#H`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E
M<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E
M;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E
M(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@9G)O;2!T:&ES(&QI
M<W0`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B``4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N`%)E
M<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S970@
M=&\@1&5F875L=',`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N
M`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N
M<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?
M=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T
M92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R
M=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP
M=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`
M4R]-24U%(%!U8FQI8R!#97)T:69I8V%T90!305-,(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-3
M2`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI
M='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI
M<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@
M9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0
M<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`
M4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!38VEE;F-E
M`%-E87)C:`!396%R8V@@16YG:6YE<P!396%R8V@@9F%I;&5D`%-E87)C:"!F
M86EL960Z("5S`%-E87)C:&EN9RXN+@!396QE8W0@1FEL97,`4V5L96-T(&$@
M9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R
M`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@
M=&AE(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3H`4V5L96-T('1H92!A
M9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.@!396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.@!396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I
M;&4Z`%-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SH`
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@=VAI8V@@9FEE
M;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N`%-E;&5C="!W
M:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RX`4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!3
M97!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`
M4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@
M>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T
M(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A
M8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S
M=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S
M:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7`@=7!G<F%D
M92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L
M92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H87)E9"!$:7)E
M8W1O<GD`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W($%L;`!3
M:&]W($-O;G1A8W1S`%-H;W<@3&ES=',`4VAO=R!D:69F97)E;F-E<R!B971W
M965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I
M;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K
M97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S
M`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H<FEN:P!3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!
M;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V
M86MI80!3;&]V96YI80!3;F]W(%-H;W=E<@!3;F]W(&1E<'1H.B``4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`
M4V]N9W,@)B!0;V5M<P!3;W)T($1I<F5C=&EO;@!3;W)T(&]R9&5R('-E;&5C
M=&EO;@!3;W5R8V4@861D<F5S<P!3;W5R8V5S`%-O=71H($%F<FEC80!3;W5T
M:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN
M9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V86YC960@<V5A<F-H(')E
M<W5L=',@=&\@87!P96%R+@!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI
M="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A
M<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M
M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3
M=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3
M=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M861D960@)7,@=&\@)7,`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A
M=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@=W)O=&4@
M)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I
M<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3
M=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y
M;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L
M:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8`5%-6(&9I;&4`5&%B('-E<&%R871E
M9"!V86QU97,`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T
M:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T
M86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS
M`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R
M871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!4
M97AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3
M+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M
M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+@!4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S
M`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!0
M97)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@
M240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A
M<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@
M8V]N=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+@!4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO
M="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES
M="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B
M;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<
M;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T
M+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B
M(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O
M=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H
M92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@
M=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P
M96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D
M871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@8G)O=W-E
M86)L92!A9&1R97-S(&)O;VMS+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O
M:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS(&%R92!C
M;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@
M=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R!I<R!A;B!E<G)O<BP@<&QE87-E
M(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T
M:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%D
M9&EN9R!T:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<B!F;W(@9G5R=&AE<B!H96QP+@!4:&5R92!W87,@86X@97)R
M;W(@8W)E871I;F<@82!N97<@;&ES="X`5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H:7,@;V)J96-T+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O
M=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,`5&AE<F4@=V5R92!N
M;R!A9&1R97-S97,@=&\@97AP;W)T+@!4:&ES($E-05`@<V5R=F5R(&1O97,@
M;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T
M('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@
M;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O
M9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E
M9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD
M('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O
M;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G
M(S$R,S1A9B<N`%1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"X`
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES
M("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T
M:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&
M;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('!E<G-O;B!A;')E861Y(&AA<R!A("5S
M(&5N=')Y(&EN('1H92!A9&1R97-S(&)O;VL`5&AI<R!S97)V97(@8V%N)W0@
M=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES
M(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P
M=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI
M;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET
M;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E
M;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA
M8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R
M8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@
M*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@
M;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM
M.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A
M;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A
M;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE
M('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E
M<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S
M+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET
M960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S
M`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5
M;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N('5S
M97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@
M0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R
M96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@
M;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C
M<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS
M=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S
M97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L
M;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E
M<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5
M<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P
M=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S
M(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`57-E<FYA
M;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A
M;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R
M;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N`%9E<FES:6=N($1I<F5C=&]R>0!697)S:6]N`%9E<G-I;VX@0V]N=')O
M;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!6
M97)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S
M`%9I97<@0V]N=&%C=`!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@
M87,@)7,`5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0Z`%9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`
M5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T
M:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E
M`%=E8G-I=&4@55),`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X
M-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI
M8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H
M(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@
M;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7
M:61T:#H`5VEK:0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7
M:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!#:71Y`%=O<FL@0V]U;G1R
M>0!7;W)K(%!H;VYE`%=O<FL@4&]S=&%L($-O9&4`5V]R:R!3=&%T92]0<F]V
M:6YC90!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.
M86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E
M;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE
M<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^
M72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N
M;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE
M;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I
M;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T
M;R!V:65W('1H:7,@8V]N=&%C="X`66]U(&1O(&YO="!H879E('!E<FUI<W-I
M;VX@=&\@=FEE=R!T:&ES(&]B:F5C="X`66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B
M;V]K+@!9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="X`66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S96QE
M8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F
M;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!O
M;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N
M93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M
M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E
M`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3
M:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UT`6VQI;F4@)7,@;V8@)7-=`%MN;R!V86QU95T`7T%D;6EN:7-T<F%T:6]N
M`%]"<F]W<V4`7T-,20!?1&%T851R964`7T1E;&5T90!?1&5L971E(%)O=P!?
M1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%]);7!O<G0O17AP
M;W)T`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS
M`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U)E;6]V92!F<F]M('1H
M:7,@;&ES=`!?4V5A<F-H`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?
M57-E<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!C
M;VYT86-T+G9C9@!C;VYT86-T<RYC<W8`8V]N=&%C=',N='-V`&9A;&QI;F<`
M9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z`&EM;65D:6%T90!I
M;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI
M;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N
M=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R
M96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!T87-K(&QI<W0`='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M
M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)
M9"U697)S:6]N.B!4=7)B82`R+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,BTP
M,2`Q-3HQ-BLP,C`P"DQA<W0M5')A;G-L871O<CH@5FEL:75S(%-U;7-K87,@
M/'9I;&EU<T!L;FLN;'0^"DQA;F=U86=E+51E86TZ($QI=&AU86YI86X@/'9I
M;&EU<T!L;FLN;'0^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ,PI#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@`@*'!R:67P("5S(&1I96YA<RD`("AM>6=T
M=6MA<R`E<RD`("CP:6%N9&EE;BD`("AV86MA<BD`(``B5F%R9&%S(%!A=F%R
M9.LB("AP=GHN($IO;F%S($IO;F%I=&ES*0`B5F%R9&%S+"!0879A<F3K(B`H
M<'9Z+B!*;VYA<RP@2F]N86ET:7,I`"5D("5S(&ER("5S`"5D+61I96[X('!R
M;V=N;WKK`"5S("T@<&%S=&%B80`E<R!A;G1S<&%U9&%S`"5S($M"`"5S('!R
M;V9I;&%K=&EK;W,@=F5I:W-M86D@+2!P871V:7)T:6YI;6%S`"5S(')E9VES
M=')A8VEJ80`E<R!N=6]S=&%T;W,`)7,@<')I9.MT87,N`"5S(&IA=2!E9WII
M<W1U;VIA+@`E<R`E<R`E<P`E<R!F86EL87,@<^MK;6EN9V%I(.%K96QT87,`
M)7,@>7)A('!R:79A;&]M87,`)7,@;6EN=73K<P`E<R!N97)A<W1A<RX`;G5O
M("5S(&EK:2`E<R!I\"`E<P`E<R!K86QE;F1O<FEU<P`E<R!U_G)A\/@@:VYY
M9V5LZP`E<R!D87)B^"!SX')A\&%S`"5S.B`E<P`L(&?[<VEA:2`E<R`E<P`L
M(&MI;G1A(&YU;R`E<R!I:VD@)7,`+2T@<&%S:7)I;FMI=&4@+2T`,3(@=F%L
M86YD^"!F;W)M871A<P`R-"!V86QA;F3X(&9O<FUA=&%S`#(T('9A;&%N9&]S
M`$K[<_@@;F%R\'EK;.L@;F5P86QA:6MO(&E&<F%M97,@;V)J96MT^`#0:6%M
M(&)L;VMU:2!R96EK86QI;F=A('9I971A(&1U;VUE;O@@8F%ZZVIE+@#!=GEK
M;R!R:6UT82!K;&%I9&$`3F]RZV1A;6D@=?YK;V1U;W1I(&QA:?!KX"!P<FEV
M86QO=&4@='5RZW1I('9I9?#@:N$@4$=0(')A:W3@+@!.;W+K9&%M:2!P871I
M:W)I;G1I('!A<VER8?!Y=.`@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE
M\.!JX2!01U`@<F%K=.`N`$YO<NMD86UI(&%T:V]D=6]T:2!L86GP:^`@<')I
M=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%!'4"!R86MT=7,L
M(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N`$YO<NMD86UI('!A<VER8?!Y
M=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!J
MX2!01U`@<F%K='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+@!.;W+K
M9&%M:2!A=&MO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!J
MX2!I<B!S;&%P=.!JX2!3+TU)344@<F%K='5S+"!B96D@_FEN;W1I('-L87!T
MX&K@(&9R87KF+@!.;W+K9&%M:2!P87-I<F'P>71I(&QA:?!KX"!P<FEV86QO
M=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%(')A:W1U<RP@
M8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@=?YK;V1U;W1I
M(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4R]-24U%(')A:W3@
M+@!!32!R;V1Y;6%S`$%-+U!-`$%022!)1`!!<&EE(/#A(')E9&%K=&]R:?@`
M07!I92XN+@!086EE\&MO<R!F;W)M;W,@=FER\'5J90!6:7-I\&MA:2!A<&'H
M:6]J90!6:7-I\&MA:2!P97(@=FED=7+A`%-I<W1E;6$@;F5T=7)I('1E:7-I
M^"!S=6MU<G1I(%9&4R!K871A;&]GX"X`4VES=&5M82!N971U<FD@=&5I<VGX
M('-U:W5R=&D@5D93(&9A:6S@+@!3;&%P=&'^;V1I<P!3X'-K86ET82!U_O!A
M;&1Y=&$N`$%P<VMA:71A`%-U:W5R=&D@<&]G<G5PX0!3=6MU<G1I('!O=&5I
M<V5S`$)L;VMO(.%T97)P:6UA<SH`4W5K=7)T:2!N875JX"!G<G5PY@!3=6MU
M<G1I(&YA=6IA<R!T96ES97,`3F%U:F\@=F%R=&]T;VIO('-U:_MR:6UA<SH`
M4')I9.MT:2!S='5L<&5LX0!.875J^"!N87)I^"!P<FEDZVII;6%S`%-U:W5R
M=&D@<&]RX`!0<FEDZW1I("5S(&UE;FEU('!R:64@36]Z:6QO<R#A<F%N:VGX
M(&IU;W-T;W,`P7)A\'ET:2#A`,%T<F%U:W1I(.$@861R97/X(&MN>6=E;.8Z
M`,%T<F%U:W1I(.$@;6%N;R!A9')E<_@@:VYY9V5LYCH`4W5K=7)T:2!V87)T
M;W1O:N``5F%R=&]T;VKX(&O[<FEM87,@:?!J=6YG=&%S+@!!9')E<V%S`$%D
M<F5S^"!P97+^:?MR80!!9')E<_@@:VYY9V5LZW,@X7)A\&%S`$%D<F5S^"!K
M;GEG96SK(&GP=F%L>71A('/K:VUI;F=A:2X`061M:6YI<W1R=6]T:2`M(&=A
M;&D@;G5S=&%T>71I('1E:7-E<R!K:71I96US('9A<G1O=&]J86US`%9A;&1Y
M;6%S`$)A;F5R:6%I`$1E=&%L:2!P86EE\&MA`$%F9V%N:7-T86YA<P!!;&)A
M;FEJ80!!;/YY<F%S`%!R879A<F3K`$QY9VEU;W1I`$QY9VEA=FEM87,Z`%9I
M<VO@`%9I<VD@<')I<VEJ=6YGYB!V87)T;W1O:F%I`%9I<V]S(&=R=7#K<P!6
M:7-O<R!T96ESZW,`5FES;W,@:V5T=7)I;W,@<'5SZW,`3&5I<W1I(&ME;&5T
MX"!A9')E<_@`3&5I<W1I(&YA=61O=&D@<W5R^_!I=6]TX"!SX')A\.`_`$IA
M=2!E9WII<W1U;VIA`$IA=2!E9WII<W1U;VIA`$%L=&5R;F%T>79U<R!)35-0
M('!R:7-I:G5N9VEM87,`06QT97)N871Y=G5S($E-4U`@<VQA<'1A_F]D:7,`
M06QT97)N871Y=G5S($E-4U`@=F%R=&]T;VIO('9A<F1A<P!!;'1E<FYA='EV
M=7,@96PN('!A\'1O(&%D<F5S87,`06QT97)N871Y=OMS(/!A8FQO;F%I`$%L
M=&5R;F%T>79U<R!T96MS=&%S`$%M97)I:V]S(%-A;6]A`,%V963K=&4@;F5L
M96ES=&ENX"!R96EK\&WF+@!!;F1O<F$`06YG;VQA`$%N9VEL86D`06YO;FEM
M:6YI<R!P<F]X>2!S97)V97)I<P!!='-A:WEM87,`06YT87)K=&ED80!!;G1I
M9W5A(&ER($)A<F)U9&$`36]D=6QI<P!-;V1U;&ES('9E:6MI82!G97)A:2X`
M4')I=&%I:WET:2!I<B!P;_!A:VEA;7,`4&%T=FER=&EN=&D`0F%L86YD:7,`
M07)A8FGP:V$@*%=I;F1O=W,M,3(U-BD`07)C:'EV;R!F86EL;R!D>61I<P!!
M<F-H>79O(&9A:6QO('!A=F%D:6YI;6%S`$%R('1I:W)A:2!N;W)I=&4@:?!T
M<FEN=&D@)7,_`$%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@<&%S:7)I;FMT
M=7,@X7)A\'5S/P!!<B!T:6MR86D@;F]R:71E(&GP=')I;G1I("5S(')E9VES
M=')A8VEJ;W,@<')A\'EMX#\`07)G96YT:6YA`$%R;>MN:6IA`$%R;>MN:?!K
M82`H05)-4T-)22TX*0!-96YA<P!!<G5B80!$:63K:FEM;R!T=F%R:V$`2W)I
M<W1A=7,@_F5N9VEM;R#A(&1A;F?X('-A;&$`06-S:6D@;65N87,`07II:F$O
M4F%M:6]J;R!V86YD96YY;F\@<F5G:6]N87,`07(@<')A\'ET:2!P871V:7)T
M:6YT:2!P<F]F:6QA:W1I:V]S('9E:6MS;75S/P!0<FES:WER:6UO('-T=6QP
M96QI86D`0F%N9&]T92!I\'1R:6YT:2!N965G>FES='5O:F%NZ&G@(&=R=7#F
M+@!"86YD;W1E(&GP=')I;G1I(&YE96=Z:7-T=6]J86[H:6%S('1E:7-E<RX`
M0F%N9&]T92!R961A9W5O=&D@;F5E9WII<W1U;VIA;NAI87,@=&5I<V5S+@!"
M86YD;W1E(')E9&%G=6]T:2!N965G>FES='5O:F%N=.$@96QE;65N=.`N`$%T
M<FEB=71A:0!2=6=P:OMT:7,`075S=')A;&EJ80!!=7-T<FEJ80!!=71H7V-Y
M<G-Q;#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+@!!=71H
M7V-Y<G5S.B!C>7)U<R!N971U<FD@<F5I:VEA;?@@9V%L:6UY8FGX+@!!=71H
M7V-Y<G5S.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0(&UO9'5L:7,N`$%U
M=&A?9G1P.B!N97)A<W1A<R!R96EK86QI;F=A<R!&5%`@;6]D=6QI<RX@4W5K
M;VUP:6QI=6]K:71E(%!(4"!S=2`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@
M;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+@!!=71H7VMR8C4Z
M(&YE<F%S=&%S(')E:6MA;&EN9V%S(&MR8C4@;6]D=6QI<RX`075T:%]L9&%P
M.B!N97)A<W1A<R!R96EK86QI;F=A<R!,1$%0(&UO9'5L:7,N`$%U=&A?;&1A
M<#H@<W5K=7)T:2!V87)T;W1O:N`@)7,@;F5P879Y:V\N(%-E<G9E<FEO('!R
M86YE\&EM87,Z(`!!=71H7VQD87`Z(&GP=')I;G1I('9A<G1O=&]JX"`E<R!N
M97!A=GEK;P!!=71H7VQD87`Z(&%T;F%U:FEN=&D@=F%R=&]T;VK@("5S(&YE
M<&%V>6MO`$%U=&A?;6-A;#H@;F5R87-T87,@<F5I:V%L:6YG87,@34-!3"!M
M;V1U;&ES+@!!=71H7W-M8F%U=&@Z(&YE<F%S=&%S(')E:6MA;&EN9V%S('-M
M8F%U=&@@;6]D=6QI<RX`4')I<VEJ=6YG=&D@;F5P879Y:V\`4')I<VEJ=6YG
M=&D@;F5P879Y:V\N("5S`%)!1$E54R!S97)V97)I<R!N96QE:63^:6$@875T
M96YT:69I:W5O=&ES+@!0<FES:6IU;F=T:2!P<FEE($944"!S97)V97)I;R!N
M97!A=GEK;RX`1V%L:6UI(&QA=6MA:3H`07IE<F)A:63^86YA<P!"3T9((&%T
M<VEP<F'P>6UA:0!&;VYA<P!&;VYO('-P86QV80!.971E:7-I;F=A<R!K97)B
M97)O<R!S;&%P=&'^;V1I<RX`3F5T96ES:6YG87,@:V5R8F5R;W,@=F%R=&]T
M;VIO('9A<F1A<RX`0F%H86UA:0!"86AR96EN87,`0F%L=&GP:V$@*$E33RTX
M.#4Y+3$S*0!"86=L861E\&%S`$)A<F)A9&]S87,`4&%G<BX@;&EN:6IO:F4`
M4&%P<F%S=&]J:2!P86EE\&MA`$)A;'1A<G5S:6IA`$)E;&=I:F$`0F5L:7IA
M<P!086EE\&MO<R!F;W)M;W,@87!AZ&EO:F4`0F5N:6YA<P!"97)M=61A:0!"
M=71A;F%S`%!R:7-I:G5N9W1I(&YE<&%V>6MO.B`H)7,I("5S`$=I;71A9&EE
M;FES`$)L;VMO('!A<F%M971R86D`0FQO:V\@=&EP87,`4&%S=&]R:6YT:0!"
M;VQI=FEJ80!!=/YY;6]S`$MR8?!T87,`2W)A\'1O('-T;W)U;6%S.@!+<F'P
M=&%I`$)O<VYI:F$@:7(@2&5R8V5G;W9I;F$`5FES;W,`0F]T<W9A;F$`07!A
MZ&EO:F4`0G5V970@<V%L80!"<F%Z:6QI:F$`0G)I=/@@26YD:6IO<R!V86YD
M96YY;F\@=&5R:71O:F$`0G)U;NMJ875S(&1A<G5S86QE;6%S`$)U;&=A<FEJ
M80!3=?YY;>MT87,@<^!R8?!A<P!"=7)K:6YA<R!&87-A<P!"=7)U;F1I:F$`
M1&%R8F\@:V%T96=O<FEJ80!45E,`0U)#`$-23"!P87-K:7)S='EM;R!P=6YK
M=&%I`$-35@!?0V5LZW,@;G5S=&%T>6UA:2XN+@!+86QE;F1O<FEU<P!286UU
M`$MA;6)O9/YA`$MA;65R^VYA<P!.979E:6MI82!A=71O;6%T:6YI<R!S;&%P
M=&'^;V3^:6\@<&%K96ET:6UA<RP@<W5S:7-I96MI=&4@<W4@861M:6YI<W1R
M871O<FEU;6DN`$YE9V%L:74@<')I<VEJ=6YG=&D@<')I92!)34%0('-E<G9E
M<FEO.B`E<P!+86YA9&$`073P875K=&D`073P875K=&D@<')O8FQE;6]S('!R
M86YE\&EMX`!.96=A;&EU(&GP=')I;G1I(&9A:6QO("(E<R(N`$YE9V%L:74@
M<F%S=&D@;&%I:VEN;VIO(&MA=&%L;V=O+@!.96=A;&EU(&%P9&]R;W1I("=T
M87)G971&:6QE)R!P87)A;65T<F\N`$YE9V%L:74@:?!T<FEN=&D@:V%T86QO
M9V\@(B5S(BX`3F5G86QI=2!I\'1R:6YT:2X@16=Z:7-T=6]J82`E9"!P;_!A
M:VEA:2X`3F5G86QI=2!P97)R^_!I=6]T:2X@P79E<W1A<R#A<F'P^"!S:V%I
MZ&EU<R!N97-U=&%M<&$@<W4@X7)A\/@@<VMA:>AI=6UI(&1U;VUE;O@@8F%Z
MZVIE+@!.96=A;&EU(&YU:W)E:7!T:2#^:6YU=.MS(.$@;G5R;V1Y=.`@;G5M
M97+A+@!+96EP=F5R9&ES`%!A=F%D:6YI;6%S`$MA=&5G;W)I:F]S`$MA:6UA
M;O@@<V%L;W,`36]B:6QU<R!T96QE9F]N87,`0V5LZW,@;G5S=&%T>6UA:0!4
M87)P86D@8V5LZW-E.@!#96SK<R!N=7-T871Y;6%I`%1A<G!A:2!T87)P(&-E
M;&GX.@!-;V)I;'5S:7,@=&5L969O;F%S`$ME;'3X("A)4T\M.#@U.2TQ-"D`
M0V5N=')E`$-E;G1R:6[K<R!!9G)I:V]S(%)E<W!U8FQI:V$`0V5N=')I;NMS
M($5U<F]P;W,@*$E33RTX.#4Y+3(I`%-E<G1I9FEK871O(&1E=&%LZW,`4V5R
M=&EF:6MA=&\@=&5I<^MS`,AA9&%S`%!A:V5I<W1I`$K[<_@@=F%R9&\@:7(@
M861R97-O+"!K=7)I=6]S(&UA='ES(/YM;V[K<RP@<VMA:71A;G1Y<R!I<B!A
M='-A:VENZVIA;G1Y<R#A($K[<_@@;&%I\&MU<RP@:V5I=&EM87,N`%-I;6)O
M;&ES`%!A7W1I:W)I;G1I(&YU;W)O9.`N+BX`4%]A_GEMZW1I('9I<W5S+VYI
M96MO`,AI;.L`2VEN:6IA`$MI;FEE=&GP:V$@<&%P<F%S=&$@*$=",C,Q,BD`
M2VEN:65T:?!K82!T<F%D:6-I;NL@*$)I9S4I`%!A<VER:6YK:71E('-L87!T
M8?YO9.$`4&%S:7)I;FMI=&4@=F%R=&]T;VIO('9A<F3@`%!A<VER:6YK:71E
M(&%D<F5S^"!K;GEG96SF`%!A<VER:6YK:71E(&MA:7`@=F%I>F1U;W1I(&1A
M=&%S.@!087-I<FEN:VET92!S=7+[\&EU;W1O('/@<F'P;R!S=&EL:?@`2V%L
MZV3X('-A;&$`2VQA<^MS("5S(&[K<F$N`$=I961R80!)\'1R:6YT:2!-4R!/
M9F9I8V4@_GEM97,`5F%R=&]T;VIO(&1U;VUE;O@@=F%L>6UA<SH@)7,`2?!V
M86QY=&D@=F%R=&]T;VIO(&1U;VUE;FES`$GP=F%L>71I('9A<G1O=&]J;R!D
M=6]M96YI<P!4YG-T:0!#;&EC:V%T96QL('!E<B!(5%10`%7^9&%R>71I(&QA
M;F?@`$1E8F5S=6]T80!$96)E<W5O=&$`2V]K;W-O("A+>6QI;F=O*2!S86QO
M<P!4=?#H:?@@8V5L:?@@:W)A\'3X(')O9'EM87,`2V]L=6UB:6IA`%-P86QV
M80!087-I<FEN:VET92!S<&%L=N``4W!A;'9O<R!P87-I<FEN:VEM87,`4W1U
M;'!E;&EA:3H`4W1U;'!E;&GX(&YU<W1A='EM86D`4W1U;'!E;&GX('!A=F%D
M:6YI;6%I`$MO;6EK<V%I`$MA8FQE;&EA:7,@871S:VER=&]S(')E:6OP;>MS
M`$MA8FQE;&EA:7,@871S:VER=&]S(')E:6OP;>MS("A-:6-R;W-O9G0@3W5T
M;&]O:RD`2V]M86YD80!+;VUA;F1I;NL@96EL=73K`$MO;65N=&%R87,`5F%R
M9&%S+W!A=F%R9.L`2V]M;W)A:0!+;VUP86YI:F$`2V]M<&%N:6IO<R!A9')E
M<V%S`$MO;7!I=71E<FEA:0!3X&QY9V]S`$YU<W1A='EM^"!P86ME:71I;6%I
M`$MO;F9I9_MR=6]T:2`E<P!3;&%P=&'^;V1I<R!D87(@:V%R=.``2V]N9V%S
M`$1E;6]K<F%T:6[K($MO;F=O(%)E<W!U8FQI:V$`4')I<VEJ=6YG=&D@;F5P
M879Y:V\N`%!R:7-I:G5N9W1I(&YE<&%V>6MO.B``4')I<VEJ=6YG=&D@;F5P
M879Y:V\Z("5S`%!R:7-I:G5N9W1I(&YE<&%V>6MO`%!R:7-I:G5N9W1I('!R
M:64@=FEE\/AJ^"!R86MT^"!S97)V97)I;R!N97!A=GEK;RX`4')I<VEJ=6YG
M=&D@<')I92!V:67P^&KX(')A:W3X('-E<G9E<FEO(&YE<&%V>6MO+"!N97,Z
M("5S("@E<RD`4')I<VEJ=6YG=&D@<')I92!&5%`@<V5R=F5R:6\@;F5P879Y
M:V\N`$%D<F5S87,@:?!T<FEN=&%S+@!!9')E<V%I('/@<F'P93H@)7,`2V]N
M:V%K=&%I('/K:VUI;F=A:2#A=')A=6MT:2#A($K[<_@@861R97/X(&MN>6=E
M;.8`5.9S=&D`2W5K;R!S86QO<P!,86EMZW,@_FEN=73K<P!+;W!I:G5O=&D`
M2V]P:6IU;W1I('!A<VER:6YK:6W@`$MO<W1A(%)I:V$`1')A;6)L:6\@2V%U
M;&\@2W)A;G1A<P!.97!A=GEK;R!U_FMO9'5O=&D@4$=0(&QA:?!K;RX`3F5P
M879Y:V\@<&%S:7)A\'ET:2!01U`@;&%I\&MO+@!.97!A=GEK;R!U_FMO9'5O
M=&D@4R]-24U%(&QA:?!K;RX`3F5P879Y:V\@<&%S:7)A\'ET:2!3+TU)344@
M;&%I\&MO+@!.97!A=GEK;R!P<FEDZW1I(&MO;G1A:W1O+B`E<P!.97!A=GEK
M;R!A=71E;G1I9FEK=6]T:7,@X2!,1$%0('-E<G9E<N$N`$YE<&%V>6MO('!A
M=&EK<FEN=&D@8F%L86YS;RX@)7,`3F5P879Y:V\@<W5K=7)T:2!D:7-T<FEB
M=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@871K;V1U;W1I(%!'4"!D=6]M
M96[X+@!.97!A=GEK;R!A=&MO9'5O=&D@4R]-24U%(&1U;VUE;O@N`$YE<&%V
M>6MO(&GP=')I;G1I(&MO;G1A:W1O+B`E<P!.97!A=GEK;R!I\'1R:6YT:2!D
M:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@;G5S=&%T>71I(&=A
M=NMJ;R!E;"X@<&'P=&\@861R97-O+@!0879Y:V\@9V%U=&D@=FES;W,@861R
M97/X(&MN>6=E;.MS+@!.97!A=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ
M;W,@<^!R8?!O+@!.97!A=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@
M<^!R8?#X('/@<F'P;RX`3F5P879Y:V\@9V%U=&D@=FEE\&]J;R!R86MT;R!I
M\"!R86MT^"!S97)V97)I;RX`3F5P879Y:V\@871I9&%R>71I("5S+@!.97!A
M=GEK;R!A=&ED87)Y=&D@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&EO("5S`$YE
M<&%V>6MO('-K86ET>71I("5S+@!.97!A=GEK;R!P86ME:7-T:2!S;&%P=&'^
M;V3^:6\@\&EA;2!V87)T;W1O:G5I+B!+86D@:W5R:2!A<F)A('9I<V$@:6YF
M;W)M86-I:F$@>7)A(&YE=&EK<VQI+B!086)A;F1Y:VET92!D87(@:V%R=.`@
M87)B82!S=7-I<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE
M:6=U(')E:6MA;&EN9V$@<&%G86QB82X`3F5P879Y:V\@9V%U=&D@04-,`$YE
M<&%V>6MO(&=A=71I(&%D<F5S^"!K;GEG96SK<RX@)7,`3F5P879Y:V\@9V%U
M=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO(&=A=71I(&1I
M<W1R:6)U8VEJ;W,@<^!R8?#X+B`E<P!.97!A=GEK;R!N=7-T871Y=&D@<V5R
M=F5R:6\@9V%L:6UY8FGX`$YE<&%V>6MO(&%T:V5I<W1I(&YU<W1A='EM^"X`
M3F5P879Y:V\@:?!S875G;W1I("5S(&YU<W1A='EM^"X`3F5P879Y:V\@<&%D
M87)Y=&D@871S87)G:6[K<R!N=7-T871Y;?@@:V]P:6IO<RX`3F5P879Y:V\@
M<&%I9?!K82!,1$%0('-E<G9E<GEJ92X`3F5P879Y:V\@871N875J:6YT:2!K
M;VYT86MT;RX@)7,`3F5P879Y:V\@871N875J:6YT:2!D:7-T<FEB=6-I:F]S
M('/@<F'P;RX@)7,`3F5P879Y:V\@<F%S=&D@36]Z:6QO<R#A<F%N:VGX(&IU
M;W-T;W,N(,%S:71I:VEN:VET92P@:V%D(&II(&%T:61A<GET82X`4FEB;W1A
M<R!T96MS=&%S`%9A;'-T>6+K`$MU<G-A:0!3=6MU<G1I(&YU;W)O9.``4W5K
M=7)T:2!N875JX"!A<')A\.``4W5K=7)T:2!P86MA=&%L;V=I=7,`4W5K=7)T
M80!3879I;FEN:V\@=&5I<^MS`$MR961I=&ENZW,@:V]R=&5LZW,@;G5M97)I
M<P!+<F]A=&EJ80!+=6)A`$1A8F%R=&EN:7,@;&%I:V%S`-!I=6\@;65T=2!5
M4DP@>7)A`$1A8F%R=&ENZW,@;W)O('/@;'EG;W,`1&%B87)T:6[K<R!SX&QY
M9V]S.B``1&%B87)T:6YI<R!S=&EL:75S`%9E:6MS;?@L(&%T;&EE:V%M^"!P
M<FES:6IU;F=U<R!P<FEE("5S+"!N=7-T871Y;6%S+@!097)K96QT:0!097)K
M96QT:2!P87-I<FEN:VEMX`!+:7!R87,`2VER:6QI8V$@*$M/23@M4BD`2VER
M:6QI8V$@*%=I;F1O=W,M,3(U,2D`2VER:6QI8V$O56MR86EN:65T:?!K82`H
M2T])."U5*0#(96MI:F]S(%)E<W!U8FQI:V$`1$0`2V%S9&EE;@!$=6]M96[X
M(&UE9/YI;R!N87+P>6MLZP!$871A`$=A=71A`$1A=&]S('!A<VER:6YK:6UA
M<P!$:65N80!)\'1R:6YT:2!?<W1U;'!E;.$`1W)U;V1I<P!$9?!I;71A:6YI
M86D@<VMA:>AI86D`4W5M8?YI;G1I(&%T:71R875K:6W@`%-T86YD87)T:6[K
M('-P86QV80!3=&%N9&%R=&EN:7,@87!R8?!A<P!3=&%N9&%R=&ENZR!R^_!I
M879I;6\@='9A<FMA.@!!<&EB<NO^:6UA:0!)\'1R:6YT:0!4<GEN:6UO('!A
M='9I<G1I;FEM87,`2?!T<FEN=&D@9W)U<.8`2?!T<FEN=&D@=&5I<^8`5FES
M:?!K86D@:?!T<FEN=&D@;&%I\&MU<P!4<GEN:6UO(&UY9W1U:V\@96QG97-Y
M<P!)\'1R:6YT:2!C96SF`$GP=')I;G1I('-T=6QP96SA`$GP=')I;G1I(&5G
M>FES='5O:F%N=.$@86QT97)N871Y=O@@\&%B;&]NX`!)\'1R:6YT:2!N97!A
M=GEK;SH@*"5S*2`E<P!)\'1R:6YT:2!E:6QU=.8`2?!T<FEN=&D@<&%S:7)I
M;FMTX"!A<')A\.``2?!T<FEN=&D@\.$@<W1U;'!E;.$`2?!T<FEN=&D@\&G@
M(&5I;'5TY@!)\'1R:6YT:2!N97!A=GEK;P!0<FES=&%T>6UO(&QA:6MA<P!$
M86YI:F$`1&5P87)T86UE;G1A<P!-8?[K:FEM;R!T=F%R:V$`4')O8FQE;6]S
M(&%P<F'P>6UA<P!$971A;&EA=2`H=&%I<"!P870@_FG[<NMK:71E($AO<F1E
M(&QO9R!F86EL92DZ`$%D;6EN:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L
M=7,@87!R8?!Y;6%S+@!6>7-T>6UA<P!$<NMG;G5M87,`1'+K9VYU;6%S('!A
M<VMU=&ENYB!V86QA;F3@.B``1'+K9VYU;6%S.B``2W)Y<'1I<R!I\"!K86ER
MZW,@X2!D9?!I;N8`2W)Y<'1I<R!I\"!D9?!I;NMS(.$@:V%I<N8`2V%T86QO
M9V%S`%)O9'ET:2`R-"UI^"!V86PN(&9O<FUA=.`_`%9A:7ID879I;6\@;G5S
M=&%T>6UA:0!2;V1Y=&D@<')O9W)O;N8@*%1!1BD`5F%I>F1A=FEM;R!F;W)M
M871A<P!,86GP:V\@<')I<W1A='EM;R!P<F%N9?!I;6%I`$3^:6)U=&ES`$YE
M=')I;G1I`$YE<VEK<F5I<&MI=&4@=&EE<VEO9VEA:2#A(&UA:6YT96YA;F-E
M+G!H<`!!<B!N;W)I=&4L(&MA9"!P<FEE\"!K:65K=FEE;N`@X7)A\/@@=')Y
M;FEMX"!P<F'P>73X('!A='9I<FET:6UO/P!!<B!P:7)M87,@X7)A\&%S('ER
M82!L875K;R!V87)D86D_`$1O;6EN:6MA`$1O;6EN:6MO<R!297-P=6)L:6MA
M`$%T<VES:?AS=&D@)7,`071S:7-I^'-T:2!S=6=E;F5R=6]T=7,@;G5S=&%T
M>6UU<R!K86EP(%!(4"!S:W)I<'3@+@!!='-I<VGX<W1I('9#87)D`$GP<VES
M:VQE:63^:6%N=&ES('/@<F'P87,`5F%I<W1A:0!%;"X@<&'P=&\@861R97-A
M<P!%4E(`16MV861O<F%S`%)E9&%G=6]T:0!+96ES=&D@8FQO:V\@<&%R86UE
M=')U<P!2961A9W5O=&D@9W)U<.8`4F5D86=U;W1I('1E:7-E<P!2961A9W5O
M=&D@=&5I<V5S`"5S('1E:7-I^"!R961A9V%V:6UA<P!2961A9W5O=&D@X7)A
M\.`@)7,`2V5I<W1I(&YU<W1A='EM=7,Z`"5S('1E:7-I^"!R961A9V%V:6UA
M<P!59V1Y;6%S`$5G:7!T87,`4V%L=F%D;W)A<P!%;&5M96YT87,N+BX`16T`
M16PN('!A\'1O(&%D<F5S87,`16PN('!A\'1O(&%D<F5S87,`16PN('!A\'1O
M(&%D<F5S86D@='5R:2!S=71A<'1I+@!%;"X@<&'P=&\@861R97-A<R!S=2!P
M871V:7)T:6YI;74`T'EP<V5NZVSK<P#>:6YU=.L@='7PZ&EA+@!297IU;'1A
M=&%S('1U\.AI87,N`$YE;G5R;V3K=&4@<&%I9?!K;W,@=&5R;6EN^`!,96ES
M=&D@=&5K<W1E(.%T97)P=&D@<&%V96EK<VSK;&EU<R!I\"!.=6]T<F%U:_@@
M9V%L97)I:F]S/P#!:G5N9W1I(&1E\&EN:6]J;R!P96SK<R!M>6=T=6MO(&UE
M;FEU/P!'86QI;FEA:2!M971A:0!)\'!LZW-T:2!R961A:W1O<FGX`,%R8?!Y
M:VET92!K;&%U<VEMX"P@:W5R:7,@:G5M<R!B=7,@=?YD=6]T87,@:F5I9W4@
M<&%M:7+P:71E('-A=F\@<VQA<'1A_F]DX2P@<'9Z+CH@)VMO:W,@>7)A($K[
M<_@@9WEV^VYO('9A<F1A<S\G.@#!=F5S:VET92!P879E:6MS;.ML:6\@55),
M`"5S(&%T;F%U:FEN=&%S+@!%:W9A=&]R:6[K($=V:6[K:F$`17)I='+K:F$`
M2VQA:61A`$ML86ED82!L86GP:V4N`$5S=&EJ80!%=&EO<&EJ80!%=&YI;NMS
M`$5U<F]P80!+87,@,34@;6EN=>AI^`!+87,@,B!M:6YU=&5S`$MA<R`S,"!S
M96MU;F3^:?@`2V%S(#4@;6EN=71E<P!+:65K=FEE;F\@<')I<VEJ=6YG:6UO
M(&UE='4`2V%S('!U<W9A;&%N9.$`2V%S(&UI;G5TY@!0879Y>F3^:75I.@!6
M>6MD>71I`$GP<VML96ES=&D`4F5I:V%L:6YG87,@)RDG`%)E:6MA;&EN9V%S
M(/YO9&ES(&%R8F$@:V%B=73K<V4@X7)A\'ET87,@<&%I9?!K;W,@:W)I=&5R
M:6IU<P!'86QI;VII;6\@9&%T80!%:W-P;VYE;G3K`$GP:V5L=&D`061R97/X
M(&MN>6=E;.MS(&GP:^ML:6UA<P!)\&ME;'1I('1I:R!P87-I<FEN:W1U<R!A
M9')E<W5S+@!)\&ME;'1I('9I<^`@861R97/X(&MN>6=E;.8N`%1E:W-T;R!S
M<&%L=F$`3G5S=&%T>6WX('-I=6YT:6UA<R!P97(@1E10+@!+;&%I9&$@;G5S
M:V%I=&%N="!N=7-T871Y;75S+@!.97!A=GEK;R!P87-I96MT:2!N=7)O9'ET
M;W,@861R97/X(&MN>6=E;.MS.B`E<RX`4')I9.MT:2`E<R!P<FEE("5S(&YE
M<&%V>6MO.B`E<P!.97!A=GEK;R!P97+^:?MRZW1I('/@<F'P;P!097+^:?MR
M82!N97!A=GEK;P!.97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE($Q$05`@<V5R
M=F5R:6\N`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4TU"('-E<G9E<FEO
M+@!.97!A=GEK;R!N=6MO<&EJ=6]T:2!I\"`B)7,B+@!.97!A=GEK;R!N=6MO
M<&EJ=6]T:2#A("(E<R(N`$YE<&%V>6MO('-U:W5R=&D@;F%U:F\@4T%33"!R
M>?!I;RX`3F5P879Y:V\@<F%S=&D@;V)J96MT;R!P<FEDZVII;75I.B`E<P!.
M97!A=GEK;R!P97)K96QT:2#A("(E<R(N`%!A:67P:V$@;F5P879Y:V\@:V%T
M86QO9V4Z("5S`-!V96QN=7,`1F]L:VQA;F3X('-A;&]S("A-86QV:6YA:2D`
M1F%R97+X('-A;&]S`$9A:W-A<P!687-A<FES`$%T<F]D;R!L>6<`071R;V1O
M(&QY9SH@`%1R=6UP86QA:6MI<R!L:65T=7,`1FED_FES`$9A:6SX('-K86GH
M:75S.B`E<R!F86EL87,`1F%I;/@@<VMA:>AI=7,Z("5S(&9A:6QA:2CX*0!&
M86EL^"!T=F%R:WEM87,`1F%I;&\@<&%V861I;FEM87,`1F%I;&\@<&%S:7)I
M;FMI;6%S`$9A:6QO('-I=6YT:6UA<P!.87+P>6MLZR!N97!A;&%I:V\@9F%I
M;/@@<VEU;G1I;6\N`$9I;'1R86D`4F%S=&D`4W5O;6EJ80!0:7)M;VII('!U
M<^L`5F%R9&%S`%!I<FUA<VES(&ME='9I<G1I<P!.=7-T871Y=&%S(&MO969I
M8VEE;G1A<P!!='9I<FOPZ&EA<P!)\&3K<W1Y;6%S`%+[:V%S`$MA=&%L;V=A
M<R`E<R!N965G>FES='5O:F$`5&5K<W1O('-P86QV80!-86ES=&%S`$YA<O!Y
M:VSK;7,L(&MU<FEO<R!N97!A;&%I:V\@<&%V96EK<VSK;&GX`$]R^"!P<F]G
M;F]ZZR`H5$%&*0!/<O@@<')O9VYO>NMS(&%P:6UT:7,@*.%S:63K;>MK:71E
M+"!K860@\&D@9G5N:V-I:F$@9W)A_FEN82!I<B!D:65N;W,@:7(@;F%K=&EE
M<R!P<F]G;F]ZYCL@<&5R(&1I9&5L:7,@<VMA:>AI=7,@9V%L:2!S=61A<FMY
M=&D@9&EZ86ENX"D`4&%M:7+P;W1E('-A=F\@<VQA<'1A_F]DX3\`1F]R;6]S
M`$9R87KK`$9R87II^"!T:7!A<P!&<F%ZZW,`1G)A>NMS(#(`1&ES:W5S:6IO
M<P!097)S:75N=&EM86D`4&5N:RX`2W)A\'1I;NMS`%!R86YC^WII:F$`4')A
M;F/[>FEJ82P@365T<F]P;VQI<P!5_FEM='5M;R!I;F9O<FUA8VEJ;W,@55),
M`%!R86YC^WII:F]S($=V:6%N80!0<F%N8_MZ:6IO<R!0;VQI;F5Z:6IA`%!R
M86YC^WII:F]S('!I971I;NMS('1E<FET;W)I:F]S`$GP`$YU;R``4&EL;F%S
M(&%P<F'P>6UA<P!0:6QN871I<P!0:6QN87,@=F%R9&%S`$=A8F]N87,`1V%L
M97)I:F$@:?`@:W5R:6]S(&GP(&MU<FEO<R!B=7,@<F]D;VUA<R!P879E:6MS
M;.ML:7,`1V%L97)I:F$Z`$=A;6)I:F$`1V5N97)U;W1I("5S(&YU<W1A='EM
M=7,`4W5G96YE<G5O=&%S(&MO9&%S`$=R=7II:F$`5F]K:65T:6IA`$=A;F$`
M1VEB<F%L=&%R87,`5F%R9&%S`$=L;V)A;&D@861R97/X(&MN>6=E;.L`4F]D
M>71I`$=A9&5L:7,`1V]O9VQE('!A:67P:V$`3F5S<&%L=F]T87,`1W)A:6MI
M:F$`1W)A:6MI\&MA("A)4T\M.#@U.2TW*0!'<F5N;&%N9&EJ80!'<F5N861A
M`$=R=7#K`$=R=7!I^"!A9&UI;FES=')A=FEM87,`1W)U<.MS('9A<F1A<R!T
M=7)I(&+[=&D@;F5T=?#H:6%S`$=R=7#K<P!'=F%D96QU<.L`1W5A;6$`1W9A
M=&5M86QA`$=E<FYS:7,`4W9EZ&GX('1E:7/K<P!3=F7H:?@@:VYY9V$`1W9I
M;NMJ80!":7-S874M1W9I;NMJ80!'86IA;F$`2%1-3`!(5$U,07)E82!N96=A
M;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!C96SK<R!E:6QU=.MJ92X`2%1-3$%R
M96$@;F5G86QI(&GP<FEN=&D@<&%S:W5T:6YI;R!S='5L<&5L:6\@;&5N=&5L
MZVIE+@!(5$U,07)E82!N96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!E:6QU
M=.MS(&QE;G1E;.MJ92X`4F5I:V%L:6YG82!(5%10(&%U=&5N=&EF:6MA8VEJ
M82X`2&%I=&ES`$AA<V@M06QG;W)I=&UA<P!-:6=L80!!;G1R8?!TZP!(97)D
M;R!S86QA(&ER($UA:V1O;F%L9&\@<V%L;W,`2&5B<F%J^"`H25-/+3@X-3DM
M."U)*0!!=6OP=&ES`%!A9V%L8F$`4F5D86MT;W)I875S(&YA=61O:FEM;W-I
M('!A9V%L8F$`4&%G86QB:6YI;FMA<P!(96UI<V9E<F$`T'1A:2#H:6$@>7)A
M(&9A:6QO('!R863^:6$Z`%-V87)B=0!?4&]R=&%L87,`T'9E;G1A<VES(%-O
M<W1A<R`H5F%T:6MA;F\@=F%L<W1I:F$I`%!O<G1A;&%S`$YA;?@@861R97-A
M<P!.86WX(&UI97-T87,`3F%M^"!V86QS='EBZP!.86WX('1E;"X`3F%M^"!P
M8?!T;R!K;V1A<P!.86WX(')A:F]N87,O<')O=FEN8VEJ80!(;VYD^W)A<P!(
M;VYK;VYG87,`4&]R=&%L87,`2&]R9&4O2V]L86(Z(&YE=&5I<VEN9VD@)7,@
M6$U,(&1U;VUE;GES(/YI;G5TZVIE("5S`$AO<F1E+TMO;&%B.B!O8FIE:W1O
M("5S(&YE871I=&EN:V$@:F]K:6$@_FEN=73K`$AO<F1E+TMO;&%B.B!O8FIE
M:W1O('1I<&%S("5S(&YE<F%S=&%S(/YI;G5TZVIE("5S`$AO<F1E+TMO;&%B
M.B`E<R`B)7,B('/K:VUI;F%I(&GP=')I;G1A`$AO<F1E+TMO;&%B.B!I;G1E
M9W)A8VEJ;W,@=F%R:6ML:75K=6D@<F5I:V%L:6YG87,@)V1O;7AM;"<@4$A0
M(&UO9'5L:7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U:W5R=&D@;F%U:F\@
M6$U,(&UE9/YI;R!O8FIE:W1U:2`E<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@
M:?!T<FEN=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO(&=A
M=71I($U)344@240@9&%L:6%I("5S('1I<&\`2&]R9&4O2V]L86(Z(&YE<&%V
M>6MO('-U<VEN8VAR;VYI>G5O=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O=&D@96QE;65N=/@Z("5S`$AO<F1E
M+TMO;&%B.B!N9?YI;F]M87,@96QE;65N=&%S("(E<R(`2&]R:7IO;G1A;&D@
M;&EN:6IA`$AO<FEZ;VYT86QU<R!T87)P87,`2&]R:7IO;G1A;&EA:3H`2V%I
M<"#H:6$@<&%T96MO=&4_("A0<F%N9?!K:71E(2D`2VEE:R!S='5L<&5L:?@@
M;F]R:71E('-U:G5N9W1I/P!+:65K(&QA=6OX("AS='5L<&5L:?@I('1E;B!Y
M<F$_`$MI96L@96EL=>AI^"!N;W)I=&4@<W5J=6YG=&D_`$1RZV=N=6UA<P!$
M<NMG;G5M87,Z(`!*=6UO<F5S:V]S`%9E;F=R:6IA`$YE<&%V>6MO('-U:W5R
M=&D@24U!4"!P8?!T;R!DZ_YU=.MS.B`E<P!.97!A=GEK;R!I\'1R:6YT:2!)
M34%0('!A\'1O(&3K_G5TZW,Z("5S`$YE<&%V>6MO(&YU<W1A='ET:2!)34%0
M('!A\'1O(&3K_G5TZW,@9'ED_FEO.B`E<P!)35-0`$E0(&%D<F5S87,`3F5P
M879Y:V\@9V%U=&D@25`@861R97-O+@!)4"!A9')E<V%S(&YE=&5I<VEN9V%M
M92!#2412(&)L;VME+@!)4"!U_G)A:VEN=&%S+@!?P71E<G!T:2!E:6QU=.8@
M=FER\'5J90!)<VQA;F1I:F$`5&EK('!I:W1O9W)A;6]S`%!I:W1O9W)A;6]S
M('-U('1E:W-T=0!!<')A\&\@<&%V861I;FEM87,Z`$IE:2!N96=A;&ET92!P
M97)S:V%I='ET:2#P:6\@;&%I\&MO+"`E<RX`2F5I9W4@;6%T;W1E(/!IX"#^
M:6YU=.8@=FEE=&]J('!A=F5I:W-LZVQI;RP@:W5RX2!N;W)I=&4@X6ME;'1I
M+"!T86D@2OMS^"!N87+P>6MLZR!N96=A;&D@:F\@871V86EZ9'5O=&DN`%!A
M=F5I:W-LZVQI;R!P97+^:?MR80!0879E:6MS;.ML:6\@55),`%!A=F5I:W-L
MZVQI;R!54DPZ`%!A=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,`4&%V96EK<VSK
M;&ES(&GP(&=A;&5R:6IO<SH`4&%V96EK<VSK;&EO(.%KZVQI;6%S`%9A:7ID
M86D`061R97/X(&MN>6=E;.MS(.%KZVQI;6%S+"`E9"UA<R#^:6YG<VYI<P#!
M:^ML:6UA<RP@)60@_FEN9W-N:7,`P6ME;'1I+TGP:V5L=&D@861R97/X(&MN
M>6=E;&5S`$QA=6MA<R#A:V5L=&%S.B`E<P#!:V5L=&D@;&%U:V%I.@#!7W1E
M<G!T:2!E:6QU=.8@87!AZ&EO:F4`3F5T96ES:6YG87,@=F5I:W-M;R!K;V1A
M<RX`3F5T96ES:6YG87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T
M8?YO9&ES+@!.96ET96ES:6YG87,@=F%R=&]T;VIO('9A<F1A<R!A<F)A(&%L
M=&5R;F%T>79U<R!E;"X@<&'P=&\@861R97-A<RX@0F%N9'EK:71E(&1A<B!K
M87)TX"!A<F)A('-U<VES:65K:71E('-U('-A=F\@861M:6YI<W1R871O<FEU
M;6D@:F5I9W4@<F5I:V%L:6YG82!T;VQE<V[K('!A9V%L8F$N`%!A9&ED:6YT
M:2!A=&ET<F%U:VEMX`!);F1I:F$`26YD:79I9'5A;/MS('9A<G1O=&]J86D`
M26YD;VYE>FEJ80!);F9O<FUA8VEJ80!);F9O<FUA8VEJ80#!=')A=6MT:2!S
M='5L<&5LX2!?9&7P:6[K:F4`P71E<G!T:2!P879E:6MS;.MLX0#!=&5R<'1I
M(&QE;G1E;.8`P71E<G!T:2!N=6]R;V3@`,%T97)P=&D@<W1U;'!E;.$@7VMA
M:7+K:F4`P71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L:6\@
M9&7P:6[K:F4`P71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L
M:6\@:V%I<NMJ90#!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K
M<R!A<&'H:6]J90#!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K
M<R!V:7+P=6IE`,%T97)P=&D@<&%R86=R86;@(&5L96UE;G1O(&%P8>AI;VIE
M`,%T97)P=&D@<&%R86=R86?@(&5L96UE;G1O('9I<O!U:F4`P71E<G!T:2!A
M;'1E<FYA='EV^"#P86)L;V[@`,%R8?!Y:VET92!E;"X@<&'P=&\@861R97/@
M+"#A(&MU<N$@;F]R:71E(&=A=71I(&YA=6K@('-L87!T8?YO9.$Z`,%T97)P
M=&D@8V5LYB!P;R!T;P#!=&5R<'1I(&-E;.8@<')I9?`@=&%I`,%T97)P=&D@
M<W1U;'!E;.$@9&7P:6[K:F4`P71E<G!T:2!S='5L<&5LX2!K86ERZVIE`,%T
M97)P=&D@;&%I\&MU<P#!=&5R<'1I('!A<F%G<F%FX"!P;R!T;P#!=&5R<'1I
M('!A<F%G<F%FX"!P<FEE\"!T86D`P71E<G!T:2!E:6QU=.8@<&\@=&\`P71E
M<G!T:2!E:6QU=.8@<')I9?`@=&%I`,%R8?!Y:VET92!R96EK:6%MX"!A='-A
M:WEMX"#A(&ML875S:6W@('9I<O!U:F4Z`,%T97)P=&DO<F5D86=U;W1I('!A
M=F5I:W-LZVSA`,%T97)P=&DO4F5D86=U;W1I(&YU;W)O9.``1&ES=')I8G5C
M:6IO<R!SX')A\'5I(&YU<VGX<W1I(&YE=?YT96YK82!K<F5D:71O+@!.977^
M=&5N:V$@:W)E9&ET;RX`4VMA:>AI=7,`4VMA:>AI^"!SX')A\&%S`$YE=&5I
M<VEN9V%S($E$`$YE=&5I<VEN9V%S(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+@!.971E:7-I;F=A(&%D<F5S^"!K;GEG96SK`$YE=&5I<VEN9V%S(&UO9'5L
M:7,N`$YE=&5I<VEN9V%S($E$+@#!=F5S=&D@;F5T96ES:6YG:2!D=6]M96YY
M<RX`3F5T96ES:6YG87,@861R97-A<RX`3F5T96ES:6YG87,@96PN<&'P=&\@
M861R97-A<P!.971E:7-I;F=A<R#A<F'P87,`3F5T96ES:6YG87,@9F%I;&\@
M9F]R;6%T87,`3G5R;V1Y=&%S(&YE=&5I<VEN9V%S(')A:W1A<RX`3F5T96ES
M:6YG87,@;7-G7W1Y<&4N`$YE=&5I<VEN9V%S('9A<F1A<P!.971E:7-I;F=A
M<R!O8FIE:W1O($E$`$YE=&5I<VEN9V%S(&%R8F$@;NMR82!A<&E?:60N`%!A
M<F%M971R86D@;F5T96ES:6YG:2!A<F)A(&KX(&[K<F$N`$YE=&5I<VEN9V]S
M('!A=F5L9&EM;W,@=&5I<^MS+@!.971E:7-I;F=A<R!P<F]T;VMO;&%S+@!.
M971E:7-I;F=A<R!O8FIE:W1A<P!.971E:7-I;F=A<R!S:75N=.MJ;R!A9')E
M<V%S+@!.971E:7-I;F=I('5N:6MO9&\@9'5O;65N>7,N`$EN=F5N=&]R:75S
M`$ES;&%M:?!K82!)<F%N;R!297-P=6)L:6MA`$ER86MA<P!!:7)I:F$`365N
M;R!S86QA`$EZ;VQI=6]T;W,@5"UA=61R;W,`27IR865L:7,`2?!D87;K:F%S
M`$MU<G-Y=F%S`$ET86QI:F$`2F%M86EK80!3875S:7,`2F%P;VYI:F$`2F%P
M;VYI\&MA("A)4T\M,C`R,BU*4"D`1/YE<G-I<P!*;W)D86YI:F$`3&EE<&$`
M0FER_F5L:7,`4&EL;F%I`$QY9VEU;W1I(&-E;G1R90!,>6=U;W1I('!I;&YA
M:0!,>6=I=6]T:2!K86ERZVIE`$QY9VEU;W1I(&1E\&ENZVIE`$MA>F%K<W1A
M;F%S`$GP<V%U9V]T:2!O<FEG:6YA;.`_`$ME;FEJ80!.97!A=GEK;R!P<FES
M:6IU;F=T:2!P<FEE($ME<F)E<F]S('-E<G9E<FEO+@!"<F%N9'5O;&EO(&YA
M=6IO:V%I`%)A:W1O(&O[<FEM87,`4F%K=&\@871S<&%U9&%S`%)A:W1O(&EL
M9VES`%)A:W1O('1I<&%S`%)A:W1O('!A;F%U9&]J:6UA<P!286MT87,@:F%U
M('ER82!V:67P^&KX(')A:W3X('-E<G9E<GEJ92X`5F%I:V%I`$MI<FEB871I
M<P!$96UO:W)A=&ENZR!+;W+K:F]S($QI875D:65S(%)E<W!U8FQI:V$`2V]R
MZVIO<R!297-P=6)L:6MA`$MO<NMJ:65T:?!K82`H155#+4M2*0!+=79E:71A
M<P!+:7)G:7II:F$`4F5I:V%L:6YG87,@3$1!4"!P86QA:6MY;6%S+"!T8>AI
M874@3$1!4"!M;V1U;&ES(&YE<F%S=&%S(&%R8F$@;F7A:W)A=71A<RX`7TGP
M9.MS='EM87,`2V%L8F$`3&%O<V\@1&5M;VMR871I;NL@3&EA=61I97,@4F5S
M<'5B;&EK80!!;G1R82!P=7/K`%!A<VMU=&ENX2!K87)TX"!R961A9W5O=&$`
M4&%V87)DZP!087-K=71I;FES(&ME='9I<G1I<P!!=&YA=6II;G1A.@!087-K
M=71I;FES('!R:7-I:G5N9VEM87,Z("5S`%!A<VMU=&EN:7,@<')I<VEJ=6YG
M:6UA<SH@)7,@:?`@861R97-O("5S`%!R:7-I:G5N9^MT92!P:7)MX"!K87)T
MX`!,871V:6IA`%1E:7/K`$GP9.MS='EM87,`2F5I9W4@;F5N;W)I=&4@;F5N
M875D;W1I(&MR8?!T^"P@<&%L:6MI=&4@='7PZ&G@`$QI8F%N87,`2V%I<NMJ
M90!+86ER:6]J:2!A;G1R8?!TZP!+86ER:6]S:6]S(')E:6OP;>MS`$QE<V]T
M87,`3&EB97)I:F$`3&EB:6IO<R!!<F%B^"!%;7ER871A:0!,:6-H=&5N\'1E
M:6YA<P!3;75L:W5S(&QI971U<P!.961I9&5L:7,@;&EE='5S`$YE9&ED96QI
M<R!L:65T=7,@<GET90!.961I9&5L:7,@;&EE='5S('9A:V%R90!.961I9&5L
MZR!L:?MT:7,`3F5D:61E;&ES(&QI971U<R!S=2!P97)K^VYI:F$`3F5D:61E
M;&ES('-N:65G87,`3F5D:61E;.L@\&QA<&1R:6)A`$QI;65R:6MA<P!.=6]R
M;V1A`$YU;W)O9&$@X3H`4&%D87)Y=&D@96PN('!A\'1O(&%D<F5SX"!N=6]R
M;V1A(.$@;&%I\&MO(')A\'EM;R!P=7-L87#A`$YU;W)O9&]S`$QI;G5X(&QA
M:6WK<R#^:6YU=.MS`%)O9'ET:2`M('9A<G1O=&]J87,@9V%L:2!M871Y=&D@
M:V%T86QO9V\@='5R:6[A`%)O9'ET:2!D=6]M96[X(&)A>FGX('/@<F'PX`!2
M;V1Y=&D@<&%G86QB;W,@=&5M87,`4F]D>71I(&QE;G1E;&GX('/@<F'PX`!+
M;VYF97)E;F-I:F]S(&%R8VAY=F%S`$MO;F9E<F5N8VEJ;W,@<&%G86QB80!+
M;VYF97)E;F-I:F]S($E$`$MO;F9E<F5N8VEJ;W,@<V%V:6YI;FMA<P!28?!Y
M=&D@X2!K;VYF97)E;F-I:N``4')I<VEJ=6YG=&D@<')I92!K;VYF97)E;F-I
M:F]S`$%T<VEJ=6YG=&D@;G5O(&MO;F9E<F5N8VEJ;W,`5F%R=&]T;VKX('/@
M<F'P87,@=?YD<F%U<W1A<RX`3&ET97)A=/MR80!,:65T=79A`$MR875N82XN
M+@!6:65T:6YI<R!L86EK87,Z(`!,;VMA;.L@:7(@;&%I:V%S`%9I971A`%!R
M:7-I:G5N9W1I`$%T<VEJ=6YG=&D`4')I<VEJ=6YG:6UO(&1A<F)A:0!0<FES
M:6IU;F=T:2!N97!A=GEK;RX@3F5T96ES:6YG87,@2OMS^"!N=7)O9'ET87,@
M=F%R=&]T;VIO('9A<F1A<R!I<B]A<B!S;&%P=&'^;V1I<RX`4')I<VEJ=6YG
M=&D@;F5P879Y:V\N`$EL9V%S('1E:W-T87,`365I;.L`3F5S=F%R8G4`36'^
M;W-I;W,@9W)A:6MI\&MO<R!R86EDZW,`36'^;W-I;W,@;&]T>6YI\&MO<R!R
M86EDZW,`36'^:65J:2!R;VWK;FGP:VD@<VMA:>AI86D`3&EU:W-E;6)U<F=A
M<P!-30!-3U1$`%!R:6MA8FEN=&%M92!-4RU43D5&(&9A:6QE(&[K<F$@9'5O
M;>MN^"X`35-'`$UA:V%O`$UA:V5D;VYI:F$`36%D86=A<VMA<F%S`$UA9VEJ
M80!08?!T87,`4&'P=&\@=F%L9'EM87,`4W5K=7)T:2!?;G5O<F]DX"XN+@!-
M86QA=FES`$UA;&%I>FEJ80!-86QD>79A:0!-86QI<P!-86QT80!+871E9V]R
M:6KX('/@<F'P;RP@:W5R:6]M<R!P<FES:VER:6%M:2!O8FIE:W1A:2P@:7(@
M<W4@:F]M:7,@<W5S:6IU<VGX('-P86QV^"!K96ET:6UA<RX`36%P,C0@_F5M
MZVQA<&ES`$UA<%%U97-T(/YE;>ML87!I<P!+;W9A<P!087)A\'3K`%!A_GEM
MZW1I(&MA:7`@<VMA:71Y='5S+VYE<VMA:71Y='5S`%!A_GEMZW1I(&MI=&%I
M<R!A=')I8G5T86ES("AP=GHN('-V87)B=2]A='-A:WET82D`36%R\&%L;R!S
M86QO<P!-87)T:6YI:V$`071I=&EN:V$`4W5J=6YG=&D@;&%U:V%I`$UA=7)I
M=&%N:6IA`$UA=7)I8VEJ=7,`36%K<VEM86QU<R!K<F5D:71A<RX`36%K<VEM
M86QU<R#^:6YUZ&GX(&1A;&GX(&MI96MI<R!I\&5I:W9O=&%S+@!-86MS+B!T
M96UP+B!P87-K+B`R-"!V86PZ(`!-86MS+B!T96UP+B!P87-K+B`V('9A;#H@
M`$UA:W-I;6%L=7,@:6QG:7,`36%K<VEM86QU<R!P=7-L87!I^"!S:V%IZ&EU
M<P!'96=U_NL`36]J;W3K`$UE9&EC:6YA`$YA<FEA:0!-96YI=2!R9?YI;6%S
M.@!3=6IU;F=T:2!C96QE<P#>:6YU=.L`3&%I\&MA<R!P879I<G1I;G1A<RP@
M=&'H:6%U(&YE<&%T=FER=&EN=&%S('!A<VER8?!I=7-I;R!A<VUE;G,@<V5R
M=&EF:6MA=&%S+@#>:6YU=.L@;F5I\'-I^'-T82X`WFEN=73K<R!T:7!A<P!/
M<F\@<V%L>6=O<P!/<F\@<^!L>6?X(&)L;VMO(&[K<F$N`$]R;R!SX&QY9_@@
M8FQO:V\@;NMR82X@061M:6YI<W1R871O<FEU:2!I\'-I^'-T87,@9&5T86QU
M<R!A<')A\'EM87,N`$UE=&]D87,`36%T86D`365K<VEK80!-:6MR;VYE>FEJ
M;W,@1F5D97)A8VENZW,@5F%L<W1I:F]S`%9I9'5R>6IE`$U)344@=&EP87,`
M36EN+B!T96UP+B!P87-K+B`R-"!V86PZ(`!-:6XN('1E;7`N('!A<VLN(#8@
M:&]U<G,Z(`!-:6YI('!A:67P:V$`071S<&EN9'ES`$MI=&]S`$Q$05`@:V]N
M9FEG^W)A8VEJ;VIE(&[K<F$@1$X@<&%R86UE=')O+@!.97)A<W1A<R!014%2
M($A45%!?4F5Q=65S="!P86ME=&%S+@!.=7-T871Y;?@@;NMR82X@2F5I9W4@
M;F]R:71E(&YA=61O=&D@\.$@;6]D=6SA+"!T=7)I=&4@:N$@<W5K;VYF:6?[
M<G5O=&DN`$[K<F$@_FEN=73K<R!)1"X`3F5R87-T87,@<F5I:V%L:6YG87,@
M4$5!4B!-86EL('!A:V5T87,N`$[K<F$@<V5S:6IO<R!)1"X`4&ER;2X`36]B
M:6QU<R!P8?!T87,`36]B:6QU<R!T96PN`%9I9'5T:6YI<P!2961A9V%V:6UO
M(&1A=&$`2V5I<W1I(%523`!2961A9W5O=&D@;F5P879Y:V\Z("@E<RD@)7,`
M36]D=6QI<P!-;VQD;W9O<R!297-P=6)L:6MA`$UO;F%K87,`36]N9V]L:6IA
M`$WK;F5S:6%I(&ER(&UE=&%I`$MA<R!MZVYE<^$`36]N<V5R871A<P!-ZVYU
M;&EO(&9A>NMS`%)A<W1A<R!D875G:6%U(&YE:2!V:65N87,@X7)A\&%S`$UA
M<F]K87,`1&%U9VEA=7-I82!G:65D<F$`1&%U9VEA=7-I82!A<'-I;F%U:^8`
M1&%U9VEA=7-I82!S875LZW1A`%!E<FME;'1I`%!E<FME;'1I(/YE;6EA=0!0
M97)K96QT:2!K86ER:6%U`%!E<FME;'1I(&1E\&EN:6%U`%!E<FME;'1I(&%U
M:_#H:6%U`%!E<FOK;&EM87,@_F5M>6X`4&5R:V5L=&D@:V%I<NMN`%!E<FME
M;'1I(&1E\&ENZVX`4&5R:^ML:6UA<R!A=6OP='EN`$UO>F%M8FEK87,`375L
M8F5R<GD@861R97/X(&MN>6=E;.L`2V5L971O(&QY9VGX(&GP<VES:VQE:63^
M:6%N=&ES('/@<F'P87,`061R97/X(&MN>6=E;.MJ92!Y<F$@:V5L971A<R!A
M<VUE;O@@<W4@861R97-U(%LE<UTL(&)E="!N96D@=FEE;F\@=F%R9'4@6R5S
M70!+96QE=&%S('!A<VER:6YK:6WX`$UA;F\@<^!S:V%I=&$`36%N;R!P;W)T
M86QA<P!-86YO('!O<G1A;&\@:?!DZW-T>6UA<P!-86EN;6%R87,`3D4L($Y%
M4U5424Y+50!687)D87,`5F%R9&\@9F]R;6%T87,`3F%M:6)I:F$`3F%U<F%S
M`$YE<&%L87,`3F5T8V5N=&5R(&YA<FGX(&MA=&%L;V=A<P!.>61E<FQA;F1A
M:0!.>61E<FQA;F3X($%N=&EL86D`3F5T<V-P87!E(&)A>FEN:7,@55),`$YE
M='-C<&%E('-E<FEF:6MA=&\@873P875K:6UO(%523`!.971S8W!A92!S97)T
M:69I:V%T;R!T96ES:?@@55),`$YE='-C87!E(&%T;F%U:FEN;VUO(%523`!.
M971S8V%P92!A=/!A=6MI;6\@55),`$YE='-C87!E(%-33"!S97)V97)I;R!V
M87)D87,`3F5T<V-A<&4@<V5R=&EF:6MA=&\@87!R8?!Y;6%S`$YE='-C87!E
M('-E<G1I9FEK871O('1I<&%S`%1I;FML87,`3FEE:V%D80!.875J;VII($MA
M;&5D;VYI:F$`3F%U:F$@:V%T96=O<FEJ80!.875J87,@861R97-A<P!.875J
M87,@;>MN=6QI<P!.875J87,@=F%R=&]T;VIO('9A<F1A<R`H;F5B^W1I;F%S
M*0!.875J;VII(%IE;&%N9&EJ80!.875J86UE(&QA;F=E("A?8FQA;FLI`$YA
M=6II96YO<P!.875J:65N^"!G<G5PZW,`4V5K86YT:7,`4V5K86YT>7,@;G5S
M=&%T>6UA:0!.:6MA<F%G=F$`4VQA<'EV87)D:7,`3FEG97)I<P!.:6=E<FEJ
M80!.86MT:7,`3FEU:NL`3F4`P7)A\&%S("5S(&YE<F%S=&%S("5S`$%D<F5S
M^"!K;GEG96QI^"!NZW)A+@!.977^=&5N:V$@9'5O;65N^"!S:VER='5M^"!P
M87)O9'EM=6DN`$YE;G5R;V1Y=&$@<W1R871E9VEJ82!)4T\@<F'P>6UU:2X`
M3NMR82!S=63K=&EN:6\@\&%B;&]N;RX`3G5R;V1Y=&]J92!P;WII8VEJ;VIE
M(&)L;VMO(&[K<F$`3F7A=F5DZW1E(&MA;&5N9&]R:6%U<R!V87)D;R!-0T%,
M(&%U=&5N=&EF:6MA8VEJ;VIE+@!3:VER='5M^"!NZW)A+@#0:6]S('1E:7/K
M<R!N96=A;&D@='5RZW1I('!O=&5I<VGX+@!.ZW)A(&EN9F]R;6%C:6IO<R!A
M<&EE("5S(&MO;F9I9_MR86-I:N`N`$[K<F$@:6YF;W)M86-I:F]S(&%P:64@
M1E10(%9&4R!K;VYF:6?[<F%C:6K@+@!.ZW)A(&EN9F]R;6%C:6IO<R!A<&EE
M(%-13"!61E,@:V]N9FEG^W)A8VEJX"X`3NMR82!I;F9O<FUA8VEJ;W,@87!I
M92!344PM1FEL92!61E,@:V]N9FEG^W)A8VEJX"X`5&]K:?@@:V]N=&%K=/@@
M;NMR80!+<F5D:71A<R!I\&5I:W9O=&%S+@!.9>%V97-T87,@9V%VZVIA<RX`
M1F%I;&%S(&YE;G5S:?AS=&%S`$YE;G5S=&%T>71A('9I971O=NLN`$YEX7)A
M\.MT92#^:6YU=.MS+@!.9>%R8?#K=&4@=F%R9&\N`$YEX7)A\.MT92!N=6UE
M<FEO+@!.97)O9'ET:2#A_F5I9/YI86[H:?@@9G)A>FGX`$YEX79E9.MT92!S
M;&%P=&'^;V3^:6\@2%144"!A=71E;G1I9FEK86-I:F%I+@!.9>%V963K=&4@
M<VQA<'1A_F]D_FEO($E-05`@875T96YT:69I:V%C:6IA:2X`3F7A=F5DZW1E
M('-L87!T8?YO9/YI;R!+97)B97)O<R!A=71E;G1I9FEK86-I:F%I+@!.9>%V
M963K=&4@<VQA<'1A_F]D_FEO($QO9VEN(&%U=&5N=&EF:6MA8VEJ86DN`$YE
MX79E9.MT92!S;&%P=&'^;V3^:6\@4$%34U=$(&%U=&5N=&EF:6MA8VEJ86DN
M`$YEX79E9.MT92!S;&%P=&'^;V3^:6\@4TU"(&%U=&5N=&EF:6MA8VEJ86DN
M`$YEX79E<W1A<R!K96QI87,@:6MI($]P96Y34TP@<&%G<FEN9&EN:?@@9F%I
M;/@N($]P96Y34TP@<F5I:V%L:6YG82!D87)B=6D@<W4@4$M#4R`Q,B!D=6]M
M96YI;6ES+@!.97!A='9I<G1I;G3X(')E9VES=')A8VEJ^"!NZW)A+@!.96YA
M=61O=&D@<VMI<G1U:_@`3NL@=FEE;F]J92!P=7/K:F4`4W!A<G1I;FEM=6D@
M;NMR82!L86EK:6YO:F\@:V%T86QO9V\N`%9A<G1O=&]J;R!V87)D87,@:7(O
M87)B82!S;&%P=&'^;V1I<R!N96YU<VGX<W1A<RX`=D-A<F0@9'5O;65N^"!N
MZW)A+@!496ES:6YG^"!834P@9'5O;65N^"!NZW)A`$[K<F$@<F5I:_!M:?@`
M2V]N9FEG^W)A8VEN:6%M92!F86EL92!NZW)A('9E<G-I:F]S+B!097)G96YE
M<G5O:VET92!N=7-T871Y;75S+@!+;VYF:6?[<F%C:6YI86UE(&9A:6QE(&[K
M<F$@=F5R<VEJ;W,N(%!E<F=E;F5R=6]K:71E(&YU<W1A='EM=7,N`$YI96MO
M`$[K<F$`T&EA=7+K<R`H25-/+3@X-3DM,3`I`$YO<F9O;&MO('-A;&]S`-!I
M875R:6[K(&AE;6ES9F5R80#0:6%U<FENZW,@36%R:6IA;O@@<V%L;W,`3F]R
M=F5G:6IA`$YE('!O('1O`$YE('!R:67P('1A:0!.92!K871A;&]G87,`3F5R
M96%L:7IU;W1A+@!.96YU<F]D>71A`$YE<&%L86EK;VUA<RX`4&%S=&%B;W,`
M3NMR82!KX"!P97+^:?MRZW1I+"!E:6MI=&4@871G86PN`$QA<&MR:71I<P!.
M=6UE<FES`%-I;6)O;&GX('-K86GH:75S`%-T=6QP96QI^"!S:V%IZ&EU<P!/
M8FIE:W3X('-K86GH:75S('!U<VQA<'EJ90!%:6QUZ&GX('-K86GH:75S`$YE
MX79E<W1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O(&%T;F%U:FEN:6UO('-K86GH
M:6%I+@!/2P!/8FIE:W1A<P!/8FIE:W1O('-A=FEN:6YK87,`3V)J96MT87,@
M;F5R87-T87,`0?!T=6YT86EN:7,`4W!A;&ES`-YI875R=6UO(&9I;'1R87,`
M3V9I<V%S`$]M86YA<P!+871A;&]G^"!D86QI:FEMX'-I('!A;&%I:V\@=&EK
M($E-05`@<V5R=F5R:6%I+@!4:6L@X?YE:63^:6%NZ&EO<R!F<F%ZZW,`3&5I
M9/YI86UA<R!T:6L@=FEE;F%S(&5L+B!P8?!T;R!A9')E<V%S+@!%;&5M96YT
M;R!S879I;FEN:V\@=&5I<V5S(&=A;&D@:V5I<W1I('1I:R!J;R!S879I;FEN
M:V%S(&%R8F$@<VES=&5M;W,@861M:6YI<W1R871O<FEU<P!!=&ED87)Y=&D@
M;F%U:F%M92!L86YG90!!=&ED87)Y=&D@\&G@(&YU;W)O9.`@;F%U:F%M92!L
M86YG90!/<')A8VENZW,@<VES=&5M;W,`3G5S=&%T>6UA:0`E<R!N=7-T871Y
M;6%I`%-U<OOP:75O=&%S('/@<F'P87,`3W)G86YI>F%C:6IA`%!A9&%L:6YY
M<P!3:7-T96UI;FEM87,`3W)I9VEN86QU<R!A<&QI:V%C:6IO<R#P86)L;VYA
M<P!/<FEG:6YA;/AS(/!A8FQO;F%I("5S.@!+:71A`$MI=&$@:6YF;W)M86-I
M:F$`2VET:2!N=7-T871Y;6%I`%-A=FEN:6YI:V\@=&5I<^MS`$[K<F$@4$%-
M(&%U=&5N=&EF:6MA8VEJ;W,@;65C:&%N:7IM;RX`4$=0('-K86ET;65N:6YI
M<R!P87)A\&%S`%!'4"!U_FMO9'5O=&$@:6YF;W)M86-I:F$`4$=0('9I9?!A
M<VES(')A:W1A<P!01U`@<&%S:7)A\'ET:2]U_FMO9'5O=&D@9'5O;65N>7,`
M4$A0(&MO9&%S`%!(4"!#3$D`4$T@;&5N9W9A<R!L:65T=7,`4$T@;&G[=&ES
M`%!-(%0M875D<F$`4%](4"!#3$D`5&%R<&%I(&-E;.MS90!086MI<W1A;F%S
M`%!A;&%U`%7^:6UT;VII(%!A;&5S=&EN;W,@=&5R:71O<FEJ80!086YA;6$`
M4&%P=6$@3F%U:F]J:2!'=FENZVIA`%!A<F%G=F%J=7,`1&%L:6YA:2!D96)E
M<W5O=&$`4VQA<'1A_F]D:7,`4VQA<'1A_F]D:7,@;F5T96ES:6YG87,`4D%$
M2553(&%U=&5N=&EF:6MA8VEJ86D@<F5I:VEA('-L87!T8?YO9/YI;RX`4VQA
M<'1A_F]D:7,@<W4@<&%T=FER=&EN:6UU`%-L87!T8?YO9&ES.@!3;&%P=&'^
M;V1I<SH@`%-L87!T8?YO9/YI86D@='5R:2!S=71A<'1I+@#!:V5L=&D`P6ME
M;'1I(&GP(&QA:6MI;F]S:6]S('-A=6=Y:VQO<R`H8VQI<&)O87)D*0!+96QI
M87,`3F5P871V:7)T:6YT;W,@<F5G:7-T<F%C:6IO<SH`WFUO;NMS`%!R;V-E
M;G1A:0!!=&QI:W1I('!R;V9I;&%K=&EN:75S('9E:6MS;75S`$%R(&%T;&EK
M=&D@<')O9FEL86MT:6YI=7,@=F5I:W-M=7,@<')I<VEJ=6YG:6UO(&UE='4_
M`%1E:7/K<P!.ZW)A('1E:7-I^`!.ZW)A('1E:7-I^`!496ES:?@@861M:6YI
M<W1R879I;6%S`$%S;65N:6[K(&EN9F]R;6%C:6IA`%!E<G4`1WEV^VYA:0!&
M:6QI<&EN86D`5&5L969O;F%S`$YU;W1R875K;W,`4&EN92!A9')E<_@@:VYY
M9V5LZP!0:71K<F%N87,`4&EK<V5L:6%I`$)A;F%L>6+K<P!)\'-I<FEN:VET
M92!K=7)IX"!N;W)S(&-E;.8`4&%T=FER=&EN:VET92P@87(@=&EK<F%I(&YO
M<FET92!I\'1R:6YT:2#PX2!E;&5M96YTX#H`4&%T=FER=&EN:VET92P@87(@
M=&EK<F%I(&YO<FET92!I\'1R:6YT:2#P:6\@96QE;65N=&\@;G5O<F]DX"X`
MP79E<VMI=&4@;>MN97/A(&ER(&UE='5S+@#!=F5S:VET92!N875J;W,@:V%T
M96=O<FEJ;W,@<&%V861I;FEMX#H`P79E<VMI=&4@=&5I<VEN9^`@25`@861R
M97/@+@#!=F5S:VET92!T96ES:6YGX"!D873@+"!P871I:W)I;FMI=&4@9&EE
M;O@@<VMA:>AI^"!MZVYE<WEJ92X`P79E<VMI=&4@=&5I<VEN9^`@;&%I:^`N
M`$%P<F'P>6MI=&4@<')O8FQE;>`N`$YU<F]D>6MI=&4@<V%V;R!V87)T;W1O
M:F\@=F%R9.`@8F5I('-L87!T8?YO9.$`P79E<VMI=&4@;F%U:N`@:V%T96=O
M<FEJ;W,@<&%V861I;FEMX#H`3&5N:VEJ80!0;VQI=&EK86D`0F%L<V%V:6UA
M:0!0;W)T=6=A;&EJ80!0879E:6MS;.ML:6\@<&]Z:6-I:F$`3&5N=&5LZW,@
M<&]Z:6-I:F$`2?!S875G;W1I(/!I86UE(&MA=&%L;V=E("AN96=A;&EO:F$@
M24U!4"D`2W)I='5L:6%I('!A<VLN("5S('9A;&%N9.`H87,I.B``4')E9G-?
M;&1A<#H@;F5R87-T87,@<F5I:V%L:6YG87,@3$1!4"!M;V1U;&ES+@!0<F5F
M<U]S97-S:6]N.B!N97)A<W1A<R!R96EK86QI;F=A<R!S97-I:O@@;6]D=6QI
M<RX`4VSK9VES`%-LZV=I<R!J^W)O<R!L>6=Y:F4Z(`!3;.MG:7,Z(`!097+^
M:?MR80!097+^:?MRZW1I('!A=F5I:W-LZVSA(&YA=6IA;64@;&%N9V4`06YK
M<W1E<VYI(&YU<W1A='EM86D`071S<&%U<V1I;G1I(&1O:W5M96YTX`!!<VUE
M;FENZR!A9')E<_@@:VYY9V5LZP!3;&%P=&%S:7,@<F%K=&%S`%!R;V)L96UA
M`%!R;V)L96UO<R!A<')A\'EM87,`4')O:F5K=&%I`%!R8?!Y;6%S('1E:W-T
M=6D`5FEE\&%S:7,@<F%K=&%S`%9I9?!O:F\@<F%K=&\@86QG;W)I=&UA<P!6
M:67P;VIO+W-L87!T;VIO(')A:W3X('!O<F$@;F5S=6=E;F5R=6]T82X`4'5E
M<G1O(%)I:V%S`$MA=&%R87,`4V%K:6YY<P!5_FML875S82!N97!A=GEK;SH@
M*"5S*2`E<P!'<F5I=&]J:2!P86EE\&MA`%)302!V:67P87-I<R!R86MT87,@
M*"5D(&)I=&%I*0`G4F%D:6\G('!A<VER:6YK:6UA<P!,:65T=7,`3&EE='5S
M(')Y=&4`3&EE='5S('9A:V%R90!,:?MT:7,`071S:71I:W1I;NL@9G)A>NL`
M4V%N='EK:7,`4VMA:71Y=&D`4VMA:71Y;6%S(&YE<&%V>6MO.B`H)7,I("5S
M`%!E<G-K86ET>71I(&QA:?!K86D`5&EK<F%I(&GP=')I;G1I("5S/R!'<F'^
M:6YT:2!A=&=A;"!N96)E9V%LZW-I=&4N`%1I:W)A:2!I\'1R:6YT:2!V87)T
M;W1O:F\@)7,@9'5O;65N:7,_($=R8?YI;G1I(&%T9V%L(&YE8F5G86SK<VET
M92X`4F]D;VUI(.%R8?!A:3H`4&%K87)T;W1I(&%N:W-T97-NX2!V96EK<VW@
M`$%T;F%U:FEN=&D@:V%I<FEO:F\@;65N:74@96QE;65N='5S.@!!=&YA=6II
M;G1I('!O<G1A;&\@=F%I>F3@.@!296=E>`!3X')Y\&GX(&YA<O!Y:VSK`%!A
M<W1A8F]S`$YU=&]LYB!S97)V97)I86D`3G5T;VSF<R!54DP@*&AT='`Z+R]W
M=W<N<&%V>7ID>7,N8V]M+VAO<F1E*3H`2?!T<FEN=&D`4&'P86QI;G1I(&)L
M;VO@`%!A;F%I:VEN=&D@<W1U;'!E;.$`4&%N86EK:6YT:2!F;W)M871A=FEM
MX`!08?!A;&EN=&D@:?`@\&EO('/@<F'P;P!)\'1R:6YT:2!P;W+@`$GP=')I
M;G1I(&%T;F%U:FEN:6UO('-K<FEP=.`@:?`@<V5R=F5R:6\@;&%I:VEN;VIO
M(&MA=&%L;V=O+@!08?!A;&EN=&D`4&'P86QI;G1I(/#A(&5L96UE;G3@(&GP
M(&1O:W5M96YT;P!)\'1R:6YT:2!V87)T;W1O:N``5F%R=&]T;VIO('1R>6YI
M;6%S.B`E<P!.96=A;&EU(&%T<V%K>71I(.$@=?YK;&%U<^`N($ML86ED;W,@
M:V]D87,Z(`!296EK86QI;F=A<R!O8FIE:W1A<R!N97)A<W1A<RX`2?`@;F%U
M:F\`4&%K96ES=&D@<VQA<'1A_F]DX0!3;&%P=&'^;V3^:6\@:V5I=&EM87,`
M071S=&%T>71I`%)E>G5L=&%T86D`1W+A_G1I(.$@;G5S=&%T>6UU<P!296K[
M;FEJ80!!='-T871Y=&D@:V]N9FEG^W)A8VEJX`!(5$U,(')E9&%K=&]R:6%U
M<R!N=7-T871Y;6%I`$WA<VSK<P!$9?!I;NMJ90!$9?!I;FEO:FD@86YT<F'P
M=.L`1&7P:6YI;W-I;W,@<F5I:_!MZW,`7T5I;'5TZW,@;G5S=&%T>6UA:2XN
M+@!2;VSK`%)U;75N:6IA`%!A<W5K=&D@,3@P`%!A<W5K=&D@:V%I<NMN`%!A
M<W5K=&D@9&7P:6[K;@!%:6QU=.MS(&YU<W1A='EM86D`16EL=73K<R!N=7-T
M871Y;6%I`$5I;'5TZW,Z`%-K:7)T=6MA:0!3:VER='5K86D@=&%R<"!V:7/X
M(&5I;'7H:?@@:7(@<W1U;'!E;&GX`%-K:7)T=6MA:2!T:6L@=&%R<"!S='5L
M<&5L:?@`4VMI<G1U:V%I('1I:R!T87)P(&5I;'7H:?@`5GEK9'ET:0!2=7-I
M:F]S($9E9&5R86-I:F$`4G5A;F1A`%,O34E-12!P87)A\&%S`%,O34E-12!U
M_FMO9'5O=&%S(&QA:?!K87,`4R]-24U%('9I9?!A<VES('-E<G1I9FEK871A
M<P!.ZW)A(%-!4TP@875T96YT:69I:V%C:6IO<R!M96-H86YI>FUO+@!335,@
M_FEN=73K<P!344P@0TQ)`%-32`!005992T\`4U]13"!#3$D`T&7P="X`T'9E
M;G1O:FD@2&5L96YA`%-A:6YT($MI='-A<R!I<B!.979I<V%S`%-A:6YT($QI
M=6-I:F$`T'9E;G1A<VES(%!E=')A<R!I<B!-:6=E;&]N87,`4V%I;G0@5FEN
M8V5N=&%S(&ER($=R96YA9&EN86D`5&%M92!P8>AI86UE(&QA;F=E("A?<V5L
M9BD`4V%M;V$`4V%N($UA<FEN87,`4V%O(%1O;64@:7(@4')I;F-I<.L`4&%L
M>61O=F%S`%-A=61O($%R86)I:F$`2?!S875G;W1I`$GP<V%U9V]T:2`E<P!)
M\'-A=6=O=&D@;G5S=&%T>6UU<P!)\'-A=6=O=&D@<W5G96YE<G5O='5S(&YU
M<W1A='EM=7,@:V%I<"!02%`@<VMR:7!TX"!J^W/X('-E<G9E<FEO(&QA:6MI
M;F%J86UE(&MA=&%L;V=E+@`E<R!N=7-T871Y;6%I(&GP<V%U9V]T:2X`36]K
M<VQA<P!)9?!K;W1I`%!A:67P:V$`4&%I9?!K82!N97!A=GEK;P!086EE\&MA
M(&YE<&%V>6MO.B`E<P!)9?!K;VUA+BXN`%!A<VER:6YK:71E(&9A:6QU<P!0
M87-I<FEN:VET92!D873@`%!A<VER:6YK:71E(&=R=7#F`%!A<VER:6YK:71E
M(&YA=6K@('-A=FEN:6YKX`!087-I<FEN:VET92!S97)V97+A`%!A<VER:6YK
M:71E('9A<G1O=&]JX`!087-I<FEN:VET92!V:7-U<R!D871O<R!K;VUP;VYE
M;G1U<RX`4&%S:7)I;FMI=&4@;V)J96MTX`!087-I<FEN:VET92!A9')E<_@@
M:VYY9V5LYB!I\&OK;&EM=6DZ`%!A<VER:6YK:71E(&%D<F5S=2!K;GEG96SF
M(.%KZVQI;75I.@!)\"#^96UI874@97-A;NAI^"!SX')A\/@@<&%S:7)I;FMI
M=&4@<F5I:VEA;75S('-I;6)O;&EU<RX@5NML:6%U(&=A;&ET92!J=6]S(&YU
M:V]P:6IU;W1I(.$@;&%I\&O@+@!087-I<FEN:VET92!D871O<R!S:VER='5K
MX#H`4&%S:7)I;FMI=&4@9&%T;W,@9F]R;6%TX#H`4&%S:7)I;FMI=&4@:?!K
MZVQI;6\@9F]R;6%TX#H`4&%S:7)I;FMI=&4@X6ME;&EA;>`@9F%I;.`Z`%!A
M<VER:6YK:71E(&GP:V5L:6%M;R!F86EL;R!F;W)M873@.@!087-I<FEN:VET
M92!V87)D^"!V86EZ9&%V:6W@.@!087-I<FEN:VET92!A<')A\.`@:W5RX2!N
M;W)I=&4@<F5D86=U;W1I.@!087-I<FEN:VET92!L86EK;R!S:VER='5KX#H`
M4&%S:7)I;FMI=&4@;&%I:V\@9F]R;6%TX#H`4&%S:7)I;FMI=&4@9'4@871I
M=&EN:V%NZ&EU<R!L875K=7,N`$QA=6OX+"!K=7)I92!B=7,@<F]D;VUI(&%D
M<F5S^"!SX')A\&4L('!A<VER:6YK:6UA<RX`5F%R9/@@=F%I>F1A=FEM;R!P
M87-I<FEN:VEM87,N`%!A<VER:6YK:71E('-P86QV^"!D97)I;N$N`%!A<VER
M:6YK:71E(&YO<FEMX"!K86QBX#H`4VGX<W1I('!R;V)L96UO<R!P<F%N9?!I
M;>``4VGX<W1I(%--4P!396YE9V%L87,`4V5N<V]R:75S.B``4G5G<^MJ:7,`
M4V5R8FEJ82!I<B!-;VYT96YE9W)A<P!397)I:F]S(&YU;65R:7,`4V5S:6IO
M<R!)1"!P87-I8F%I9^LN`%)I;FMI;GES`$YU<W1A='EM86D@;&5I9/YI86YT
M>7,@2G5M<R!P87-I:V5I<W1I('-L87!T8?YO9.$L(&IE:6=U(&KA(&MA9&$@
M;F]R<R!P86UI<O!I=&4N`$YU=&]L=7-I^"!S97)V97)I^"P@:W5R:75O<R!N
M;W)I=&4@;6%T>71I(&GP('!O<G1A;&\L(&YU<W1A='EM86DN`$MA;&)O<RP@
M;&%I:V\@>F]N;W,@:7(@9&%T;W,@;G5S=&%T>6UA:2X`4'5S;&%P:6\@<W!A
M;';X+"!A='-I;F%U:FEN:6UO(&1A_FYU;6\@:7(@:VET^"!V86EZ9&%V:6UO
M('!A<F%M971R^"!N=7-T871Y;6%I+@!287-T87,@871N875J:6YI;6\@<VMR
M:7!T87,`4W4@\&EU;R!P87)A;65T<G4@9V%L:6UO<R!K96QI;W,@=FEE=&]V
MZW,Z(`!396GP96QA:0!6:67P87,@:V%T86QO9V%S`%!A<F1U;W1U=NL`5')U
M;7!A<R!A<')A\'EM87,`07(@;F%U9&]T:2!K;&%V:6%T^W)O<R!M>6=T=6MU
M<R!V86QD>6UU:3\`4F]D>71I`%)O9'ET:2!V:7-U<P!2;V1Y=&D@861R97-U
M<P!2;V1Y=&D@<^!R8?!U<P!087)O9'ET:2!S:VER='5M=7,@=&%R<"!I\'-A
M=6=O=&\@:7(@:^`@=&EK('-U9V5N97)U;W1O(&MO;F9I9_MR86-I;FEO(&9A
M:6QO+@!2;V1Y=&D@<&%S:W5T:6YI;R!P<FES:6IU;F=I;6\@;&%I:^`_`%)O
M9'ET:2!G86QI;7EBYB!P86QI:W1I(&]R:6=I;F%LX`!2;V1Y=&D@<&%R:7-I
M;FMI;>``4F]D>71I(&QE;G1E;.MS(&]P97)A8VEJ^"!M96YI=3\`4F]D>71I
M("5S(&UE;FEU(&MA:7+K:F4_`%)O9'ET:2!C96SK<R!N=7-T871Y;?@@;&%N
M9^``4F]D>71I(&QE;G1E;.MS(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@96EL
M=73K<R!N=7-T871Y;?@@;&%N9^``4F]D>71I('!A=F5I:W-LZVQI;R!N=7-T
M871Y;?@@;&%N9^``4F]D>71I(&9A:6SX(.%KZVQI;>``3&G[=&ES`$QI^W1I
M<R!R>71E`$QI^W1I<R!V86MA<F4`4W5M8?YI;G1I`%-U;6'^:6YT:2!A<F)A
M('!A<W1U;71I(&MA:6UY;FEN:75S(&)L;VMU<P!3:65R82!,96]NZP!296=I
M<W1R86-I:F$`4&%R8?!A<P!087)A\&\@86QG;W)I=&UA<P!3:6YG87#[<F%S
M`$1Y9&ES`%!R86QE:7-T:2!P<F]F:6QA:W1I:^``4VQO=F%K:6IA`%-L;W;K
M;FEJ80!0^V=A`%-N:65G;R!G>6QI<SH@`%-N:65G;R!K:65K:7,@=F%N9&5N
M:74Z(`!3;VQO;6]N;R!S86QO<P!3;VUA;&EA`$1A:6YO<R!I<B!%:6SK<F'P
MZ&EA:0!2^_!I879I;6\@='9A<FMA`%+[\&EA=FEM;R!T=F%R:V]S('!A<VER
M:6YK:6UA<P!3:75N=.MJ;R!A9')E<V%S`-!A;'1I;FEA:0!0:65T^"!!9G)I
M:V$`4&EE=/@@175R;W!O<R`H25-/+3@X-3DM,RD`4&EE=/@@1/YO<F3^:6IO
M<R!I<B!0:65T^"!386YD=FGH;R!S86QO<P!0:65T:6[K(&AE;6ES9F5R80!4
M87)P87,@=&%R<"!C96QI^`!487)P87,@=&%R<"!C96SK<R!T=7)I;FEO(&ER
M(&MR8?!T:6[K<P!487)P87,`5&%R<&%I('1A<G`@8V5L:?@`5&%R<&%I`$ES
M<&%N:6IA`%-P86UA<P!3<&5C:69I;FGX('-I;6)O;&GX(.%T97)P:6UA<P!.
M=7)O9'EK:71E+"!K=7(@;F]R:71E(&UA='ET:2!I\'!LZW-T:6[K<R!P86EE
M\&MO<R!R97IU;'1A='5S+@!097)S:V5L=&D@8V5LY@!097)S:V5L=&D@<W1U
M;'!E;.$`4&5R<VME;'1I(&5I;'5TY@!3<&]R=&%S`-!R:2!,86YK80!3=&%N
M9&%R=&%S`%-T87(@5')E:R=A<P!0<F%D:6YI86D@;65T86D`4F%J;VYA<R!A
M<F)A('!R;W9I;F-I:F$`0OMS96YA`%-A=6=O:FEM;R!F;W)M871A<P!'871V
MZW,@861R97-A<P!5_F)R875K=&D`WF]D_FGX('/@<F'P87,`3G5I;71I(&1O
M;65NX"!N=6\@861R97-O`%-T:6QI=7,@6T-34UT`4V5K;2X`5&5M80#!=F5S
M=&D`26YD96MS87,`4^MK;6EN9V$`)7,@<^MK;6EN9V%I('!R:63K=&%S(.$@
M)7,`2V]N9FEG^W)A8VEJ82!A='-T871Y=&$@<^MK;6EN9V%I+B!097)K<F%U
M:VET92!P=7-L87#A+"!K860@<&%M871Y='5MZW1E('!A:V5I='5M=7,N`$%T
M<V%R9VENZR!K;VYF:6?[<F%C:6IO<R!K;W!I:F$@<^MK;6EN9V%I(&GP<V%U
M9V]T82X`)R5S)R!SZVMM:6YG86D@=?YR8?!Y=&%S+@!3=61A;F%S`%1U<FEN
M>7,`4V%U;.MT96MI<P!3875LZVQY9VES`%-A=6SK=&$`4V%U;.MT96MI<P!3
M875LZW1E:VES+U-A=6SK;'ED:7,`4V%U;.MT96MI<SH@`%-A=6SK;'EG:7,`
M4V%U;.ML>6=I<SH@`$QA:7!S;FES`$%P=&%R;F%V:6UA<P!3=7)I;F%M87,`
M4&%V87)DZP!3=F%L8F%R9&%S(&ER($3^86YM86EN87,`4W9A>FEL86YD87,`
MT'9E9&EJ80#0=F5I8V%R:6IA`%-I;G1A:W/K<R!K;&%I9&$@<&%I9?!K;W,@
M:W)I=&5R:6IU:F4`4VER:6IO<R!!<F%B^"!297-P=6)L:6MA`%0M875D<F$`
M5"UA=61R;W,`5%-6`%135B!F86EL87,`5&%B(&%T<VMI<G1O<R!R96EK\&WK
M<P!,96YT96SK`$QE;G1E;.MS(&YU<W1A='EM86D`3&5N=&5LZW,@;G5S=&%T
M>6UA:0!486EV86YA<P!486EV86YA<RP@2VEN:6IO<R!P<F]V:6YC:6IA`%1A
M9/YI:VES=&%N87,`2G5N9W1I;NL@5&%N>F%N:6IO<R!297-P=6)L:6MA`%1A
M:6MI;GES.@!$87)B86D`5&5L969O;F\@;G5M97)I<P!496UP+B!P87-K+B!V
M86QA;F3@.B``5&5M<&5R873[<F$`5&5M<&5R873[<F$Z(`#086)L;V[X(&%D
M;6EN:7-T<F%V:6UA<P!496MS=&%S`%1I:R!T96MS=&%S`$QY9VEU;W1I('1E
M:W-TX`!496MS=&\@=FER\'5J90!+971V+@!486EL86YD:65T:?!K82`H5$E3
M+38R,"D`5&%I;&%N9&%S`$'H:?L@:V%D(&YA=61O:F%TZW,@<VES=&5M82X`
M3NMR82!&5%`@;6]D=6QI;RX`2&]R9&4O2V]L86(@:6YT96=R86-I:F]S('9A
M<FEK;&EU:V%S(&YE<&%L86EK;R`B)7,B`$YE<&%V>6MO('7^:W)A=71I($UA
M:6YT96YA;F-E.CH@:VQA<^MS`$YU<W1A='EM^"!L86YG87,@=?YD87)Y=&%S
M+B!)\&5I;G4N`$YE<&%V>6MO(&GP=F%L>71I(&%D<F5S^"!K;GEG96SK<SH@
M)7,`2F5I9W4@;F]R:71E(&YA=61O=&D@;G5S=&%T>6UU<RP@<&%P<F'P>6MI
M=&4@:V%D(&%D;6EN:7-T<F%T;W)I=7,@<W5K;VYF:6?[<G5O=/@@<&%S=&]V
M:>`@9'5O;65N^"!B87KF(&YU<W1A='EM86US('-A=6=O=&DN`%1I:R!A<&%T
M:6[K:F4@<'5SZVIE`$YEX7)A\.MT92!C;VYT86MT;R!)1"!N=6UE<FEO(&%R
M8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+@!+;VYT86MT87,@<^MK
M;6EN9V%I(.%T<F%U:W1A<R#A($K[<_@@861R97/X(&MN>6=E;.8N`$YU<F]D
M>71A<R!K;VYT86MT87,@;F5E9WII<W1U;VIA+@!.;W+K9&%M:2!P871I:W)I
M;G1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I(&%T<VMI<N`@4$=0('!A<F'P
M;R!B;&]KX"X`3F7A<F'PZW1E(&1I<W1R:6)U8VEJ;W,@<^!R8?!O($E$(&%R
M8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+@!.9>%R8?#K=&4@9&ES
M=')I8G5C:6IO<R!SX')A\&\N`%!'4"!U_FMO9&%V:6UO(&=A;&EM>6+K(')E
M:6MA;&%U:F$@<V%U9V%U<R!P<FES:6IU;F=I;6\N($)A;F1Y:VET92!R8?!Y
M=&D@:'1T<',Z+R\@861R97-O('!R863^:6]J92X`1F%I;&%S("5S('!R:79A
M;&\@='5RZW1I("5S('!A<F%M971RX"X`1F%I;&%S("5S('!R:79A;&\@='5R
MZW1I(&MA:2!K=7)I=6]S("5S('!A<F%M971R=7,N`$9A:6QA<R!N96=A;&D@
M8OMT:2!N=6MO<&EJ=6]T87,@86YT('-A=N9S+@!&86EL92!NZW)A(&1U;VUE
M;O@N`%)&0S@X,B!L86GP:V\@86YT<F'P=.MS+@!*96EG=2!D:7)B871E($EN
M=&5R;F5T($5X<&QO<F5R(&YA<O!Y:VQE+"!P:6QN865K<F%N:7,@<F5D86MT
M;W)I875S(')E_FEM87,@9V%L:2!S=6ME;'1I('!R;V)L96WX+"!DZVP@\&EO
M<R!N87+P>6MLZW,@:VQA:63X+B!'86QI=&4@;F5M871Y=&D@:V%I(&MU<FGX
M(')E9&%K=&]R:6%U<R!E;&5M96YT^"X@2F5I9W4@;F%U9&]J871E(%=I;F1O
M=W,@.7@@3U,@9W)E:>AI875S:6%I(&K[<_@@:V]M<&EU=&5R:7,@<&%P<F'P
MZ&EA=7-I86D@;G5L=?`@<&%S:V5L8F1A;6%S(&%P:64@<&%G<FEN9&ENYB!K
M;&%I9.`N7&Y<;DK[<R!B=79O=&4@<&5R<W#K=&%S+B!*96EG=2!V:7-T:65K
M(&YO<FET92!I\&)A;F1Y=&D@<&EL;F%E:W)A;N$@<F7^:6W@('-P875S:VET
M92!/2RX`07!R8?!A<R`B)7,B(&GP=')I;G1A<RX`5&EK(&MA:7+K:F4@<'5S
MZVIE`$-R>7!T7W!Q<#HZ(&ML87-E:2!R96EK:6$@;G5R;V1Y=&D@:W5R('ER
M82!';G501R!F86EL86DN`$QA:?!K87,@:?!S:?AS=&%S("5S(&%D<F5S871U
M:2`E<R!T96UA("(E<R(@8G5V;R!P87)O9'ET87,N"E1AZ&EA=2!T86D@;F5G
M87)A;G1U;VIA(&MA9"!L86GP:V%S(&)U=F\@<&5R<VMA:71Y=&%S(&%R8F$@
M<W5P<F%S=&%S+@!0879A9&EN:6UA<R!K=7+A(&YA=61O<VET92!N=6]R;V1O
M:F4@X2!L86GP:V\@<F'P>6UO('!U<VQA<.$`2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!K;&%S96D@<F5I:V%L:6YG87,@3W!E;E-33"!M;V1U;&ES+@!.96=A;&EU
M(&GP<V%U9V]T:2!N=7-T871Y;6\@(B5S(BP@;F5S(&1U;VUE;O@@9'ED:7,@
M=FER\'EJ82!L96ES=&ENX"!R:6+@`%!R;V=R86UA+"!S:VER=&$@<&5R_FG[
M<NMT:2#PX2!D=6]M96[X('1I<.`@*"5S*2P@;F5R87-T82!S:7-T96UO:F4N
M`%1I:R!K86ERZVIE(&ER(&1E\&ENZVIE('!U<^MS90!4:6L@9&7P:6[K:F4@
M<'5SZVIE`%-E<G9E<FES("(E<R(@:?!T<FEN=&%S+@!397)V97)I<R`B)7,B
M(&GP<V%U9V]T87,N`"5S(')E9VES=')A8VEJ;W,@<')A\'EM87,@:?!T<FEN
M=&%S+@!.=7)O9'ET82!E:6QU=.L@;F5E9WII<W1U;VIA+@!4:6L@=FER\'5T
M:6[K:F4@:7(@87!A=&ENZVIE('!U<^MS90!4:6L@87!A=&ENZVIE('!U<^MJ
M90!.=7-I^'-T:2!D=6]M96YY<R!P<F%R87-T:2X`3F5G86QI=2!I\'-A=6=O
M=&D@;G5S:?AS=&\@9F%I;&\N`%=E871H97(N8V]M(&)L;VMO(&[K<F$N`$%D
M<F5S^"!K;GEG96QI^"!NZW)A+@!.=7-T871Y;?@@;NMR82X`1&%L:?@L(&MU
M<FEA<R!G86QI;6$@<F]D>71I(&QA:?!K;R!T96MS=&4L(&[K<F$N`$[K<F$@
M;F5I('9I96YO<R!P87)U;_!T;W,@861R97/X(&MN>6=E;.MS+"!L96ED_FEA
M;NAI;W,@<')I9.MT:2!N875JX"#A<F'PX"X@2F5I9W4@;6%N;W1E+"!J;V<@
M=&%I(&YE($K[<_@@:VQA:61A+"!P<F'P;VUE('!R86YE\'1I(&%D;6EN:7-T
M<F%T;W)I=6DN(`#0:6%M92!L875K92#A=F5S=&$@<&5R(&1A=6<@<VEM8F]L
M:?@N($K[<R#A=F5DZW1E("5S+"!O(&UA:W-I;6%L=7,@<VMA:>AI=7,@+2`E
M<R!S:6UB;VQI86DN`%!R;V)L96UO<R!S=2!F86EL^"!S:75N=&EM=3H@)7,@
M;F5N=7-I^'-T87,N`$YU<VGX<W1I(&9A:6QO(&YE<&%V>6MO+B!&86EL87,@
M)7,@>7)A(&1I9&5S;FES(&YE9W4@;&5I9/YI86UA<R!D>61I<R`H)60@8F%I
M=&%I*2X`3G5S:?AS=&D@9F%I;&\@;F5P879Y:V\N($9A:6QA<R`E<R!T:6L@
M9&%L:6YA:2!N=7-I^'-T87,N`$ML86ED82!P<FED961A;G0@:V]N=&%K=.`N
M(%-U<VEE:VET92!S=2!S:7-T96UO<R!A9&UI;FES=')A=&]R:75M:2X`2VQA
M:61A(&MU<FEA;G0@;F%U:N`@<^!R8?#@+@!+;&%I9&$@=')I;F%N="!A9')E
M<^`Z("5S`$ML86ED82!T<FEN86YT(&]B:F5K=.`N`$YE9V%L:74@<&%R;V1Y
M=&D@\&EO<R!L86GP:V\@9&%L:65S`$ML86ED82#A:V5L:6%N="!K;VYT86MT
M:6YI=7,@9'5O;65N:7,N`$ML86ED82#A:V5L:6%N="!D=6]M96YI<SH@)7,`
M2VQA:61A(.%K96QI86YT(&E#86QE;F1A<B!D=6]M96YI<RX`2VQA:61A(&MO
M;F9I9_MR86-I:F]S(&9O<FUO:F4N($=R96GH:6%U<VEA:2!N977^<&EL9.MT
M92!R96EK:6%M^"!L875K^"X`2VQA:61A(&%T;&EE:V%N="!N=7)O9'ETX"!A
M9')E<_@@:VYY9V5LZW,@9G5N:V-I:N`N(%!A8F%N9'EK:71E(';K;&EA=2X`
M2VQA:61A(&%T;F%U:FEN86YT(&MO;G1A:W1I;FEU<R!D=6]M96YI<RX@4&%B
M86YD>6MI=&4@=NML:6%U+@!+;&%I9&$@871N875J:6YA;G0@9&ES=')I8G5C
M:6IO<R!SX')A\.`N(%!A8F%N9'EK:71E(';K;&EA=2X`2VQA:61A(')E9&%G
M=6]J86YT(/#A(.%R8?#@.B`E<P!!9')E<_@@:?!KZVQI;75I(&[K<F$N`-!I
M<R!)34%0('-E<G9E<FES(&YE<&%L86EK;R!K871A;&]G^"!D86QI:FEM;W-I
M+@!!=')O9&\L(&MA9"!T86D@;F5T=F%R:VEN9V%S(%)!4B!A<F-H>79A<RX`
M071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!:25`@87)C:'EV87,N`$%T
M<F]D;RP@:V%D('1A:2!N971E:7-I;F=A<R!K;W)T96SK<R!N=6UE<FES+@#0
M:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!P97(@0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!P87-I;F%U9&]J86YT($A4
M5%`@<')O=&]K;VQU`-!I('1V87)K>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU
M=&5S('!E<B!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!P87-I
M;F%U9&]J86YT($A45%`@<')O=&]K;VQU`-!I('1V87)K>6MLZR!L96ED_FEA
M('-I^'-T:2#^:6YU=&5S(%--5%`@<')O=&]K;VQU('!E<B!6;V1A9F]N92!)
M=&%L:6IO<R!V87)T=7,L('1I:R!6;V1A9F]N92!N=6UE<FEA;7,N($II(')E
M:6MA;&%U:F$@96PN('!A\'1O(&%D<F5S;R!6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+@#0:7,@;&%U:V%S('!R:79A;&]M87,N`-!I86UE
M(&QA=6ME(&=A;&D@8OMT:2!T:6L@<W9E:6MI96II('-K86GH:6%I+@#0:6%M
M92!L875K92!G86QI(&+[=&D@=&EK('-K86GH:6%I(&ER(&1V:71A\&MI86DN
M`-!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@8?!T=6YT86EN:6%I('-K86GH
M:6%I+@#0:6%M92!L875K92!T=7)I(&+[=&D@:V%B;&5L:6%I<R!A<F)A('1A
M<G!A:7,@871S:VER=&D@<W9E:6MI96II('-K86GH:6%I`-!I(')E:6OP;>L@
M='5R:2!B^W1I('-K86GH:75S+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK
M('-P86QV;W,@:V]D87,@4D="($AE>"!F;W)M871E+"!P879Y>F3^:75I("<C
M,3(S-$%&)RX`1F%I;&\@9F]R;6%T87,@;F5P86QA:6MO;6%S+@#0:2!F;W)M
M82!J874@87!D;W)O=&$N`%1A:2`E<RX`5&%I($MO;&%B($=R;W5P=V%R92!O
M8FIE:W1A<RX@3F]RZV1A;6D@<&5R_FG[<NMT:2!O8FIE:W3@('!R:79A;&]T
M92!T=7+K=&D@96PN('!A\'1O(&ML:65N=.`L(&MU<FES('-U<')A;G3@(/#A
M(&9O<FUA=.`N(%1O:VGX(&5L+B!P8?!T;R!K;&EE;G3X('/@<F'PX"!G86QI
M=&4@<F%S=&D@87!S:6QA;FOF("5S`-!I<R!L86GP:V%S(&)U=F\@<&%R8?!Y
M=&%S("5S(&MO9'5O=&4N($K[<R!N875D;VIA=&4@:VET;VMIX"!K;V1U;W3F
M+@#0:7,@<VMA:>AI=7,@='5R:2!B^W1I(&1I9&5S;FES('7^(&YU;.$N`-!I
M<R!A<VUU;R!J874@>7)A("5S(&K[<_@@861R97/X(&MN>6=E;.MJ92X`T&ES
M('-E<G9E<FES(&YE9V%L:2!I\&%R8VAY=G5O=&D@>FEP(&ER(&=Z:7`@9F%I
M;/@N`-!I('-I<W1E;6$@9&%B87(@:?!J=6YG=&$N`-!I(')E:6OP;>L@='5R
M:2!B^W1I('-K86GH:75S+@#0X2!L86YGX"!R96EK:6$@871I9&%R:6[K=&D@
M:?`@;G5S=&%T>6WX(&QA;F=O`%!E<FO[;FEJ80!":6QI971A:0!,86EK87,`
M3&%I:V\@87!S:V%I=&$`3&%I:V\@9F]R;6%T87,`3&%I:V\@<&%S:7)I;FMI
M;6%S`%1I;6]R;&5S=.L`4&%R96EG;W,`4&%V861I;FEM87,Z`$MA;0!.;W+K
M9&%M:2!P87-I<FEN:W1I(&ME;&5TX"!E;&5M96YT^"P@;&%I:WEK:71E($-O
M;G1R;VP@*%!#*2!A<F)A($-O;6UN860@*$UA8RD@:VQA=FGPX"P@:7(@<&%S
M:7)I;FMI=&4@<&5L92X`T&EA;F1I96X`4F]D>71I($A434P@:V]DX`!4;V=A
M<P!4;VME;&%U`%)Y=&]J`%1O;F=A`%9I<O!U:F4`5FER\'5T:6YI86UE(&QA
M;F=E("A?=&]P*0!697)T:6UA:0!4<FEN:61A9&%S(&ER(%1O8F%G87,`5&%I
M<"!A<F)A(&YE`$%N='(N`%1U;FES87,`5'5R:VEJ80!4=7)K:?!K82`H25-/
M+3@X-3DM.2D`5'5R:VWK;FEJ80!4=7)K<V\@:7(@2V%I:V]S;R!S86QO<P!4
M=79A;'4`P79E<VMI=&4@<V%V;R!P87-I<FEN:VEMX#H@`%4N5BX@:6YD96MS
M87,Z(`!54DP`4VMR:7!T;R!P<FES=&%T>6UO('-T871U<V\@<F%P;W)T;R!5
M4DP`55),.@!59V%N9&$`56MR86EN80!.97!A=GEK;R!P97)S:V%I='ET:2!6
M1E,@:V%T86QO9V\N`$YE<&%V>6MO('!R:63K=&D@<&%P:6QD;VUO<R!V87)T
M;W1O:F\@<F5G:7-T<F%C:6IO<R!I;F9O<FUA8VEJ;W,N`$YE<&%V>6MO('!A
M:V5I<W1I(%9&4R!F86EL;R`B)7,B('1E:7-I^"X`3F5P879Y:V\@<&%K96ES
M=&D@=&5I<VGX(%9&4R!F86EL=6D@)7,O)7,N`$YE<&%V>6MO('!E<F5I=&D@
MX2`E<RX`3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!344P@<V5R=F5R:6\N
M`$YE<&%V>6MO('!R:7-I:G5N9W1I(%-33"!R9?YI;74N`$YE<&%V>6MO(&YU
M:V]P:6IU;W1I(%9&4R!F86EL;RX`3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T
M86QO9V\@(B5S(BX`3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO9V\N`$YE
M<&%V>6MO('-U:W5R=&D@5D93(&9A:6QO+@!.97!A=GEK;R!S=6MU<G1I('1U
M\.AI;R!61E,@9F%I;&\N`$YE<&%V>6MO(&GP87)C:'EV=6]T:2!D=6]M96[X
M+@!.97!A=GEK;R!I\'1R:6YT:2`B)7,B+"!K871A;&]G87,@;F5T=?#H:6%S
M`$YE<&%V>6MO(&GP=')I;G1I("5S+"!K871A;&]G87,@;F5T=?#H:6%S`$YE
M<&%V>6MO(')E:W5R<VGP:V%I(&GP=')I;G1I(%9&4R!K871A;&]G;RX`3F5P
M879Y:V\@:?!T<FEN=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!I\'1R:6YT
M:2!61E,@:V%T86QO9V\Z("5S+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I
M;&\@(B5S(BX`3F5P879Y:V\@:?!T<FEN=&D@5D93(&9A:6QO+@!.97!A=GEK
M;R!R96MU<G-I\&MA:2!I\'1R:6YT:2!61E,Z("5S+@!.97!A=GEK;R!N=7-T
M871Y=&D@9&%B87)T:6YI;R!K871A;&]G;RX`3F5P879Y:V\@9V%U=&D@<V5R
M=&EF:6MA=&\@87!R8?!Y;6\`3F7A;6%N;VUA('!A:W)A=71I("5S(&%P<F'P
M>6UO+@!.97!A=GEK;R!P97)K96QT:2!61E,@9F%I;&\N`$YE<&%V>6MO(&%T
M:61A<GET:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y:V\@871I9&%R>71I(%9&
M4R!F86EL;R!R8?!Y;75I+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO
M+@!.97!A=GEK;R!A=&ED87)Y=&D@<W5S<&%U<W1O(&%R8VAY=F\N`$YE<&%V
M>6MO('!E<G-K86ET>71I('9F<W)O;W0@:V%T86QO9V\N`$YE<&%V>6MO('!E
M<G9A9&EN=&D@)7,@X2`E<SH@=&]K<R!K871A;&]G87,@:F%U(&5G>FES='5O
M:F$`3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO
M('!E<G9A9&EN=&D@5D93(&MA=&%L;V=O.B`E<RX`3F5P879Y:V\@<&5R=F%D
M:6YT:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@
M9F%I;&\@)7,O)7,N`$YE<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO+@!.
M97!A=GEK;R!P86QE:7-T:2`G;6MI<V]F<R<N`$YE<&%V>6MO(&GP=F5R<W1I
M(/!I;R!7;W)D(&1O:W5M96YT;P!.97!A=GEK;R#A<F'P>71I(%9&4R!F86EL
M;R`B)7,B+@!.97!A=GEK;R#A<F'P>71I(%9&4R!F86EL;R`H8V]P>2@I(&ML
M86ED82DN`$YE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO(&1U;VUE;O@N`%!A
M8G)A=6MT:0!!=/!A=6MT:2!P86ME:71I;75S`$%T\&%U:W1I(&%N:W-T97-N
MX2!V96EK<VW@`$YE=&EKZW1A('-E<G9E<FEO(&ML86ED83H@`$YE=&EKZW1A
M('-E<G9E<FEO(&ML86ED83H@`$YE;G5R;V1Y=&$`56YI:V]D87,@*%541BTX
M*0!*=6YG=&EN:6%I($%R86+X($5M>7)A=&%I`$IU;F=T:6[K($MA<F%L>7-T
MZP!*=6YG=&ENZW,@5F%L<W1I:F]S`$IU;F=T:6YI^"!686QS='EJ^"!!=&]K
M97-NZW,@<V%L;W,`5FEE;F5T86D`3F7^:6YO;6%S`$YE_FEN;VUA<R!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+@!.9?YI;F]M87,@8VQI;7-G:60@*$-L
M:65N="!-97-S86=E($E$*2X`3F7^:6YO;6%S('9A<G1O=&]J;R!V87)D87,@
M:7(O87)B82!S;&%P=&'^;V1I<RX`4&%N86EK:6YT:2!N=6]R;V3@(/!I86T@
M96QE;65N='5I`$YEX79A<F1I;G1A<P!3875G=6UO('-U;65T:6UA:7,@;F5P
M<FEV:6QE9VEJ=6]T:2!S:W)I<'1A:2!N96=A;&D@871L:6MT:2!097)KZVQI
M;6\O2V]P:6IA=FEM;R_!:^ML:6UO('!R;V=R86UI\&MA:2X@3F]RZV1A;6D@
M<&5R_FG[<NMT:2!T96-H;FEN97,@9&5T86QE<R!M;WII;&QA+F]R9R!T:6YK
M;&%P>6IE+"!I<B!S=?YI;F]T:2!K86EP('-K<FEP=&%M<R!L96ES=&D@<')I
M96ET:2!P<FEE(&QA:6MI;F]S:6]S('-A=6=Y:VQO<RP@<&%S<&%U<VMI=&4@
M3TLN`$YE;F%U9&]T:2!S<&%L=F]S`%!LZW1I;GES(&YE<&%L86EK;VUA<P!!
M=&YA=6II;G1I`$%T;F%U:FEN=&D@)7,`071N875J:6YT:2!V87)T;W1O:N``
M071N875J:6YI;6\@<VMR:7!T87,@:?!T<FEN=&%S+@!.=7-I^'-T:0!6:7-I
M(&UO9'5L:?@@871N875J:6YI;6\@9F%I;&%I(.%K96QT:2#A('-E<G9E<N$N
M`$1I9/YI;W-I;W,@;&]T:6YI\&MO<R!R86EDZW,`1&ED:65J:2!R;VWK;FGP
M:VD@<VMA:>AI86D`57)U9W9A:G5S`$YA=61O=&D@9&%B87)T:6[F.B`E<P!.
M875D;W1I(%-33`!.875D;W1I(&IE:6=U('9A<G1O=&]J;R!V87)D87,O<VQA
M<'1A_F]D:7,@24U34"!S97)V97)I=6D@>7)A(&MI=&]K<RX`5F%R=&]T;VIA
M<R`E<R!N96%U=&]R:7IU;W1A<R!P<FGK:FEM=6D@<')I92`E<RX`5F%R=&]T
M;VKX(&%D;6EN:7-T<F%V:6UA<P!687)T;W1O:F\@;G5S=&%T>6UA:0!687)T
M;W1O:O@@<F5G:7-T<F%C:6IA`%9A<G1O=&]J^"!R96=I<W1R86-I:F$@:?!J
M=6YG=&$N`%9A<G1O=&]J;R!V87)D87,`5F%R=&]T;VIO('9A<F1A<SH`5F%R
M=&]T;VIO('9A<F1A<SH@`%9A<G1O=&]J86D@\&EO:F4@<VES=&5M;VIE.@!5
M>F)E:VES=&%N87,`5D93(&MA=&%L;V=A<R!N965G>FES='5O:F$N`$%T;W-T
M;V=O<P!287-T;W,@=&5I<VEN9V]S('9I971O=NMS.B``1V%L:6]J:6UA<P!2
M96EK\&WK(&UI;G5TZVUI<R!N=6\@9&%B87(N`%)E:6OP;>MS`%)E:6OP;>MS
M(&GP(&MU<FGX(&=A;&EM82!P87-I<FEN:W1I`%9A;G5A='4`2VEN=&%N=&ES
M`%9E;F5S=65L80!0871V:7)T:6YI;6%S(&YE8F%I9W1A<R`M(/!I<R!L86GP
M:V%S('-U9V%D:6YT87,N`%9E<FES:6=N(&MA=&%L;V=A<P!697)S:6IA`%9E
M<G-I:O@@:V]N=')O;.L`3'EG:75O=&D@=F5R=&EK86QI86D`5F5R=&EK86QU
M<R!T87)P87,`5F5R=&EK86QU<SH`3&%B86D@9&ED96QI<P!6:65T;F%M87,`
M5FEE=&YA;6EE=&GP:V$@*%9)4T-)22D`4&5R_FG[<NMT:2`E<P!097+^:?MR
MZW1I(&MO;G1A:W3@`%)O9'ET:2!I\&]R:6[A('!U<VQA<.$`4&5R_FG[<NMT
M:2!K86EP("5S`%-T86YD87)T:6YI<R!V86EZ9&%V:6UA<SH`0G)I=/@@5FER
M9/YI;FEJ;W,@<V%L;W,`2D%6(%9I<F3^:6YI:F]S('-A;&]S`$UA=&]M=6UA
M<P!-871O;75M87,Z(`!6;V1A9F]N92!)=&%L:6IA('!E<B!33510`%=!4DX`
M1,M-15-)3R$A(2!005194R!)T%1224Y+251%(%-+4DE05,`@2=`@)7,N`%9A
M;&ES(&ER($9U='5N80!$ZVUE<VEO`%1R9>@N`$]R^"!P<F]G;F]ZZP!/<O@@
M<')O9VYO>NL@<&%G86P`5V5A=&AE<BYC;VT`5U=7`%=75R!P=7-L87!I<P!7
M5U<@<'5S;&%P:7,`2V%S('-A=F%I=.8`4W9E:6MI`%-V96EK:2!A='9Y:^8@
MX2`E<P!,86)A<RP@)7,`5F%K87+X("A)4T\M.#@U.2TQ*0!686MA<O@@*$E3
M3RTX.#4Y+3$U*0!686MA<O@@4V%C:&%R80!+;VOA(&UO9'5LX2`E<R!T=7)I
M(')O9'ET:2!P;R!P<FES:6IU;F=I;6\_`$MO:W,@<VMI<G1U:V\@<VEM8F]L
M:7,_`$MO:W,@:V%B=>AI^"!S:6UB;VQI<S\`2W5R:6]S(&9A>NMS`$A434P@
M<F5D86MT;W)I875S(&UO9'5L:?@@X6IU;F=I;6%S+@!0;&]T:7,`4&QO=&ES
M($-34R!M871A:7,`)7,@:V%I<FEO:F\@;65N:74@<&QO=&ES("AP86ME:71I
M;6%I(&)U<R!M871Y=&D@<&\@:VET;R!P<FES:6IU;F=I;6\I.@!,96YT96SK
M<R!P;&]T:7,`4&QOZ&EO(&UA=&%S`%!L;W1I<SH`5VEK:0!6ZVIO(&=R96ET
M:7,@;6%Z9V%I<P!6ZVIA<SH`5NMJ87,Z(`!)\&UI;G1I<P!$87)B87,`1&%R
M8F\@861R97-A<P!$87)B;R!M:65S=&%S`$1A<F)O('9A;'-T>6+K`$1A<F)O
M('1E;"X`1&%R8F\@<&'P=&\@:V]D87,`1&%R8F\@<F%J;VYA<R]P<F]V:6YC
M:6IA`%@M4F5F`%@U,#EV,R!P86=R:6YD:6YI86D@;G5S=&%T>6UA:0!8-3`Y
M=C,@:?!P;.MS=&\@<F%K=&\@<&%N875D;VII;6%S`%@U,#EV,R!A;'1E<FYA
M='EV=7,@=F%R9&%S`%@U,#EV,R!R86MT;R!I9&5N=&EF:6MA=&]R:75S`%@U
M,#EV,R!M;V1U;&EA:0!960!965E9`%EA:&]O(2#^96WK;&%P:7,`2V%S;65T
M`$IE;65N87,`5&%I<`!486EP+"!A\"!S=71I;FMU`$K[<R!E<V%T92!414M3
M5$E.24%-12!21=Y)344N($YO<NMD86UI(&=RX?YT:2#A(%=94TE764<@<W!A
M=7-K:71E(%L\/ETN`$K[<R!N97!R:7-I:G5N9^8N`%-A=F\@=F%R9&4@;F5G
M86QI=&4@;F%U9&]T:2!S:6UB;VQI;R`G7"<N`,%V963K=&4@;F5T96ES:6YG
MX"!E;"X@<&'P=&\@861R97/@+@!.97!R:6IU;F?K=&4@:F]K:?@@;&%U:_@@
M:?`@X6ME;&EA;6\@9F%I;&\@<')I92`E<R!A=&ET:6YK86WX(&QA=6OX+@!.
M971U<FET92!T96ES:?@@<&5R_FG[<NMT:2#PX2!K;VYT86MTX"X`3F5T=7)I
M=&4@=&5I<VGX('!E<OYI^W+K=&D@\.$@;V)J96MTX"X`2OMS(&%T<VEJ=6YG
MZW1E+@!4=7)I=&4@X79E<W1I('1E:7-I;F?@('1E;&5F;VYO(&YU;65RX2`H
M=&EK('-K86GH:75S(&ER("<K)RP@:F5I9W4@;F]R:71E(&YU<F]D>71I('1A
M<G!T875T:6[A(&MO9.`I+@#!=F5DZW1E(&YE=&5I<VEN9^`@<F5I:_!MYBX`
M3F]RZV1A;6D@;F%U9V]T:7,@<F5G:7-T<F%C:6IO<R!S:7-T96UA+"!T=7)I
M=&4@<W5K;VYF:6?[<G5O=&D@9'5O;65N^"!M963^:6\@<&]S:7-T96WF+@!0
M<FEE\"!S:?AS9&%M:2!P<F%N9?!I;>`L(&%P<F'P>6MI=&4@<')O8FQE;>`N
M`,%R8?!Y:VET92!N=6]R;V1O<R!54DP`5FES^"!P:7)M82!R96EK:6$@;G5R
M;V1Y=&D@<F5I:VEA;>`@861R97/X(&MN>6=E;.8N`%!I<FUI875S:6$@<F5I
M:VEA(&YU<F]D>71I(')E:6MI86W@('/@<F'PX"X`5'5R:71E('!A<VER:6YK
M=&D@<V5R=F5RX2P@:W5RX2!N;W)I=&4@:?!T<FEN=&DN`$GP('!R863^:?@@
M<&'^>6WK:VET92!B96YT('9I96[@(.%R8?#@+@!.=7)O9'EK:71E('9A<G1O
M=&]J;R!V87)DX"P@:W5R:6\@9'5O;65N:7,@=')I;F%T92X`3G5R;V1Y:VET
M92!V87)T;W1O:F\@=F%R9.`@=')Y;FEM=6DN`$YU<F]D>6MI=&4@:W5R:6%M
M;R!V87)T;W1O:F\@=F%R9.`N`$YU<F]D>6MI=&4@871N875J:6YA;6\@=F%R
M=&]T;VIO('9A<F3@+@!.=7)O9'EK:71E('9E:6MS;>`N`$K[<R!T=7)I=&4@
MX79E<W1I(&YA=6IO<R!K871E9V]R:6IO<R!P879A9&EN:6W@+@!*^W,@='5R
M:71E('1I:R!P97+^:?MRZVII;6\@=&5I<V5S(.$@\.$@:V]N=&%K=.`N`"5S
M('-E<VEJ82!B86EGZW-I+B!0<F'P;VUE('!R:7-I:G5N9W1I(&GP(&YA=6IO
M+@!*^W/X(&5L+B!P8?!T;R!A9')E<V%S.@!%;"X@<&'P=&\@861R97-A<SH`
M26YF;W)M86-I:F$@87!I92!*=7,`3G5O("5S('-E<VEJ;W,@<')A9/YI;W,@
M:OMS^"!)4"!A9')E<V%S('!A<VEK96ETZRX@5'5R:71E('!R:7-I:G5N9W1I
M(&GP(&YA=6IO+@!*^W/X('9A<F1A<R]P879A<F3K`$K[<_@@875T96YT:69I
M:V%V:6UO('-I<W1E;6$@;F5P86QA:6MO('9A<G1O=&]J^"!SX')A\&\L(&%R
M8F$@\&D@9G5N:V-I:F$@=?YD<F%U<W1A(&3K;"!T86T@=&EK<O@@<')I9?YA
M<^AI^"X`3G5O("5S('-E<VEJ;W,@<')A9/YI;W,@:OMS^"!N87+P>6MLZW,@
M=&EP87,@<&%S:6ME:73K+B!4=7)I=&4@<')I<VEJ=6YG=&D@:?`@;F%U:F\N
M`$K[<_@@;F%R\'EK;.L@;F5P86QA:6MO(/!I;W,@9V%L:6UY8NMS+@!*^W/X
M(&QA:6MO(&IU;W-T83H`2OMS^"!S=&%N9&%R=&EN:7,@87!R8?!A<SH`2OMS
M^"!V87)D87,O<&%V87)DZSH`2OMS^"!N875J87,@)7,@<VQA<'1A_F]D:7,@
M>7)A.B`E<P!*^W/X(&YU<W1A='EM86D@871N875J:6YT:2X`2OMS^"!S;&%P
M=&'^;V1I<R!P86ME:7-T87,`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,N
M(%!A<VET:6MR:6YK:71E('-A=F\@<&'P=.`@:7(@<')I<VEJ=6YK:71E('-U
M(&YA=6IU('-L87!T8?YO9/YI=2X`2OMS^"!N=71O;.8@<V5R=F5R:6%I.@!*
M=6=O<VQA=FEJ80!:86ER87,`6F%M8FEJ80!::6UB86)VZP!%;F5R9VEN9V]S
M`%M087-LZW!T:2!C:71U;VIA;>`@=&5K<W3@70!;4')O8FQE;6]S('!R86YE
M\&EM87-=`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M`%M2;V1Y=&D@8VET
M=6]J86W@('1E:W-TX"`M("5S(&5I;'5T97-=`%ME:6QU=.L@)7,@:?`@)7-=
M`%MNZW)A(')E:6OP;>MS70!?5F%L9'EM87,`4%]E<OYI^W+K=&D`7T-,20!?
M1'5O;65N^"!M961I<P!?2?!T<FEN=&D`7TGP=')I;G1I(&5I;'5TY@!'7W)U
M<.MS`%!A7V=A;&)A`%]0879E:6MS;.ML:6\@;G5S=&%T>6UA:2XN+@!?P6ME
M;'1I+TGP:V5L=&D`4')I<VE?:G5N9W1I`$%T<VE?:G5N9W1I`%]+96ES=&D@
M;G5O<F]DX"XN`%].=7-T871Y;6%I`%]496ESZW,`7TGP=')I;G1I(&YU;W)O
M9.`N+BX`2?!?=')I;G1I(&GP(/!I;R!SX')A\&\`267P7VMO=&D`7TMO;F9I
M9_MR86-I:F$`7TQE;G1E;.MS(&YU<W1A='EM86DN+BX`5E]A<G1O=&]J86D`
M861R97/X(&MN>6=E;.L`2V%L96YD;W)I=7,`<F%M=7,`<W!A=7-K:71E(.AI
M80!A9')E<V%S+G9C9@!A9')E<V%I+F-S=@!A9')E<V%I+G1S=@!K<F5N=&$`
M9F%I;&%S`&YU;R`E<R`H)7,I("5S("5S`&$Z`'1U;VIA=2!P870`<&%P<F%S
M=&D`96EL=71E<UT`;6MI<V]F<R!K;&%I9&]S(&MO9&%S("5D(&)E9&%R86YT
M($E33RX`=F%R9&%S`&YE<F5A;&EZ=6]T80!D87(@;F5R96%L:7IU;W1A`'7^
M<F'P^"!K;GEG96SK`'!R;V-E;G1A:0!P:6MS96QI86D`:WEL80!R;V1Y=&D@
M<VMI<G1U;75S`'-M<S)E;6%I;"!P97(@2%144`!S=&%B:6QI`&1A<F+X('/@
M<F'P87,`<VQA<'1A_F]DX2!T=7)I=&4@X7)A\'ET:2!D=2!K87)T=7,`=6YI
M9FEK=6]T:0!D86QI<P!V87)T;W1O:F\@<&%S:7)I;FMI;6%S`'9#87)D`'`Z
M`'=E871H97(N8V]M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1U<F)A+VQO8V%L92]M:U]-2R\`````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-34`,#(P,#`P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+VUK7TU++TQ#
M7TU%4U-!1T53+P``````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<U-0`P,C$U-C4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B
M82]L;V-A;&4O;6M?34LO3$-?34534T%'15,O='5R8F$N;6\`````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$T,3`S`#$P-#$W,S8R-S4U`#`R,S(S,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#>$@25`````&4````<
M````1`,``(D```!L!@```````)`(```H````D0@``!T```"Z"```"````-@(
M```%````X0@```,```#G"```#P```.L(```(````^P@```@````$"0``&0``
M``T)```'````)PD```X````O"0``#P```#X)```%````3@D``!$```!4"0``
M%0```&8)```*````?`D```P```"'"0``!P```)0)```0````G`D``"D```"M
M"0```@```-<)```%````V@D``!````#@"0``!@```/$)```/````^`D``!0`
M```("@``"0```!T*```F````)PH```0```!."@``!0```%,*```-````60H`
M``4```!G"@``"P```&T*```/````>0H```8```")"@``(0```)`*```B````
ML@H```,```#5"@``!````-D*```$````W@H```0```#C"@``#````.@*```*
M````]0H```4`````"P``$@````8+```0````&0L``!`````J"P``&@```#L+
M```&````5@L```<```!="P```@```&4+```$````:`L```@```!M"P``#P``
M`'8+```'````A@L```<```"."P``!````)8+```%````FPL```@```"A"P``
M%0```*H+```>````P`L```4```#?"P``*````.4+```I````#@P``!,````X
M#```"P```$P,```%````6`P``!$```!>#```!````'`,```$````=0P```P`
M``!Z#```!@```(<,```:````C@P``!<```"I#```&@```,$,```7````W`P`
M`!L```#T#```$P```!`-```0````)`T``!<````U#0``!P```$T-```%````
M50T```,```!;#0``(````%\-```D````@`T``"8```"E#0``"````,P-```4
M````U0T```<```#J#0``!@```/(-```+````^0T```P````%#@``"@```!(.
M```"````'0X```8````@#@``10```"<.```F````;0X``"4```"4#@``<P``
M`+H.```0````+@\``'$!```_#P``(@```+$0```B````U!````<```#W$```
M!0```/\0```%````!1$``!0````+$0``"@```"`1```/````*Q$``"<````[
M$0``!@```&,1```.````:A$``!0```!Y$0``!0```(X1```0````E!$``!4`
M``"E$0``!P```+L1```5````PQ$```4```#9$0``#P```-\1```[````[Q$`
M``(````K$@``!@```"X2```4````-1(```<```!*$@``%@```%(2```1````
M:1(```L```![$@``*@```(<2```%````LA(```<```"X$@``$````,`2```&
M````T1(``!$```#8$@``!P```.H2```+````\A(``"4```#^$@``*@```"03
M```$````3Q,```4```!4$P```@```%H3```%````71,```X```!C$P``#P``
M`'(3```%````@A,``!0```"($P``$P```)T3```6````L1,``"8```#($P``
M"````.\3```%````^!,```(```#^$P``!0````$4```,````!Q0``!8````4
M%```!@```"L4```'````,A0```,````Z%```"0```#X4```'````2!0``!T`
M``!0%```'````&X4```'````BQ0``"````"3%```,````+04```1````Y10`
M``P```#W%```!0````05```1````"A4```4````<%0``!P```"(5```-````
M*A4```H````X%0``'````$,5```9````8!4``"D```!Z%0``&0```*05```>
M````OA4``!L```#=%0``$P```/D5```=````#18```<````K%@``!@```#,6
M```#````.A8``"H````^%@``*P```&D6```K````E18```X```#!%@``%@``
M`-`6```(````YQ8```<```#P%@``#@```/@6```0````!Q<``!$````8%P``
M`@```"H7```'````+1<``#`````U%P``*P```&87```I````DA<``&X```"\
M%P``%P```"L8```!````)P```````````````````%,````=````30````X`
M```L`````````!D``````````````%(```!E````(P```!8`````````$```
M`#@````F````-P```$P````J````3@```"4```!@````!P```$@```!8````
M``````H```!'````-````%H````)````00```!4`````````0@```$8`````
M````.0```!,````\````40````\````?````%````!X````M`````````#8`
M``!)`````````&0`````````/0```%0````#`````````#,```!/````60``
M`$L```!6````$@````````!B````1````#L``````````````!P`````````
M(0```!$````_``````````4````(`````````!<````I````&````"@```!;
M````,@```%X````K````5P```&,````-````"P```$,````Q`````````"``
M``!%````80`````````:````.@````````!0````,````%T```!<````````
M`"(`````````````````````````50```"0````N````-0````8`````````
M0````%\````````````````````,``````````0`````````2@```"\````^
M``````````(`````````&P`````E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N`"5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D
M`#(T(&AO=7)S`$%-+U!-`$%D9`!!9&0@82!N97<@=7-E<CH`061D('!A:7(`
M061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M;6EN:7-T<F%T:6]N`$%D=F%N8V5D(%-E87)C:`!!;&EA<P!!=F%I;&%B;&4@
M9FEE;&1S.@!#86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&]S
M92!7:6YD;W<`0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D`$-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U
M;'0@261E;G1I='D`1&5L971E`$1E;&5T:6]N(&9A:6QE9`!$97-C<FEB92!T
M:&4@4')O8FQE;0!$:7)E8W1O<GD`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'``161I=`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R
M`$5V97)Y($QO9VEN`$5X86UP;&4@=F%L=65S.@!%>'!O<G0`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!S96%R8V@@=&AE
M(&1I<F5C=&]R>3H@)7,`1F%X`$9I;F0`1G)O;0!(96QP`$AO;64@061D<F5S
M<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$QI<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-871C:&EN9P!-871C
M:&EN9R!F:65L9',`365S<V%G90!-;VYT:&QY`$YA;64`3F]T97,`4&%S<W=O
M<F0`4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5S
M970`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E`%-A=F4@3W!T:6]N<P!3
M96%R8V@`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D
M871E(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;F0@4')O8FQE;2!297!O<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1I=&QE`%523`!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0`57-E<FYA;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN
M9P!7965K;'D`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`
M65D`665A<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`6U!R;V)L96T@4F5P;W)T70!0<F]J96-T+4ED+59E<G-I;VXZ(&UK7TU+
M"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,RTP-BTR-B`Q-#HU.2LP,C`P"DQA<W0M5')A;G-L
M871O<CH@4W1O:F%N(%!E<V]V(#QS<W!`975R96MA+F-O;2YM:SX*3&%N9W5A
M9V4M5&5A;3H@36%C961O;FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TU"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*6"U'96YE<F%T;W(Z($M"86)E;"`Q+C`N,0H`)7,@OM_5X-#FV-@@U]`@
MWM3@UN/2T/K5("T@O][BTN#4T``E<R#4WMKCW-7=XM[B(-4@X^'?U>C=WB#8
MW-_>X.+8X-#=`#(T(.?0X=``04TO4$T`M-[4T/@`M-[4T-38(-W>TB#:WN#8
MX=W8VCH`M-[4T-38(-_0X`"TWM30U-@@VM[@V.'=V-H`M-[4T-+0^M7BWB#=
MT"#:WN#8X=W8YM@@U2#>W=72WM?<WM;5W=XN`+#4X-7AT`"PU-S8W=CAXN#0
MYMCXT`"]T-_@U=3=WB#?X-71T.#CTM#ZU0"PV]C0X0"TWN'BT-_=V"#?WMO8
M^M`Z`+[BVM#6V""_X-[1V]7<(,#5W][@X@"\WM'8V]7=`+?0XM+>X-@@T]X@
MW^#>U][@U>;>X@#$V.#<T`"_WN+2X-38(-O>U]C=VM``O-[4X]O>XB#=T"#7
MT-30Y]#BT"#7T"#>U.#6X]+0^M4@)7,@W=4@W-[6U2#4T"#1V-35(-[BTM[@
MU=T`1$0`M-W5TMW>`,'BT-W4T.#4U=T@V-35W>+8XM7B`+C7T>#8Z-@`M-[4
MT-+0^M7BWB#5(-W5X^'?U>C=W@"^W]CA(-W0(-_@WM';U=S>X@"TV.#5VN+>
MX-CCW`"]U2#?X-CAXM#?X]+0^"#4V.#5VN+=WB#4WB!M86EN=&5N86YC92YP
M:'``P^#5U-@`U2W?WNCBT`"_X-#7U=T@X-77X]OBT.(N`+/@U>C:T`#!U=K>
MU2#?X-CXT-+CTM#ZU0"_X-C<U>`Z`+7:X=_>X.+8X-#X`+W5X^'?U>C=T"#:
MWMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBX`O=4@W-[6T-P@U-`@W^#5T=#@
MX]+0W"#?WB#4V.#5VN+>X-CCW-[B("5S`,30VN$`L=#@T/@`OM0`O][<WN@`
MM-[<T.C=T"#0U.#5X=``M-[<T.C5W2#BU=O5Y-[=`$AO<F1E`+C<W][@XMC@
MT-W>(-_>V]4Z("5S`+C<W][@XMC@T-W8(-_>V]CZT#H`N-?;V.'BT/@@XM7<
MV"#7T"#?WMS>Z`"[V.'BT/K5XMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6
MU=W>+@"[WM/8X-#ZU0"XU]O5UP!-30"_WNCBT`#!U2#?WMK;WM_CTM``NM[@
MU>'?WMW4V.#0Y]K8(-_>V]CZT`"_WN#0VM``O-7AU>?=W@"XW-4`M]#1U=O5
MZ-K8`+O>U]C=VM``N][7V-W:V.+5(-S>X-`@U-`@T=C4T.(@V.'BV"X`N-?2
MX.C8(-[?U>#0YMC8(-?0(-[4X-;CTM#ZU0#"U=O5Y-[=`++5(-S>V]C<U2#=
MT-+5U-7BU2#3WB#?X-[1V]7<WN(N`++5(-S>V]C<U2#=T-+5U-7BU2#2T.C5
M(-K>X-CAW=CGVMX@V-S5(-@@V][7V-W:T`"^W]CA(-W0(-_@WM';U=S>X@"^
MU.'BX-#=V"#?T.``4F5S970`O=#7T-0@VM[=(-[?YMC8XM4`P]O>T]``M]#G
MX]+0^`"WT.?CTM#X(-[?YMC8`+_@U='0X./2T/@`N-?1U>#8(.'5W]#@T.+>
MX"#7T"#4T.+CW-[B.@"XU]'5X-@@Y-[@W-#B(-?0(-30XN/<WN(Z`+[1U>#8
M(-/>(-3>VN/<U=WBWN(@TMX@VM[X(/S5(-C<W][@XMC@T.@Z`+C7T=7@V"#D
MWN#<T.(@U]`@TN#5W-7BWCH`N-?1U>#8(-32U2#>U-/>TM#@T.?:V"#?WMO8
M^M`N`+_@T.+8(-C7TM7HXM#X(-?0(-_@WM';U=S>X@"_X-7AVM[:W=@@WM3@
MUN/2T/K5`++=U>'CTM#ZU2#=T"#AW]7FV/C0V]W8(-?=T.;8`,/AW]7HW=X`
MO=#AV][2`%523`"]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#A
MU>#2U>#>XBX`O=4@W-[6T-P@U-`@T]@@W^#>Y]CBT-P@V-WDWN#<T.;8V.+5
M(-?0("5S+@"]U2#<WM;5TB#4T"#3WB#?X-72U=30W"#>TM[X(%=O<F0@U-[:
MX]S5W>(N`+K>X-CAW=CGVMX@V-S5`+K>X-CAW=CFV"#2WB#AV.'BU=S>XCH`
MLMW8W-#=V-4`O=74U=O=W@"TWM'@U=3>^-35+"`E<P"PU.#5X=`@W=`@X-#1
MWN+0`,+5V]7DWMT@W=`@X-#1WN+0`+.S`+/>U-CHW=X`OM_8Z-7BU2#3WB#?
MX-[1V]7<WN(@W^#5U"#4T"#8X=_@T.+5XM4@V-?2U>CBT/@N`+W0TM74U>+5
M(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#>XN'BX-#=V"X`O=#2U=35XM4@
MVM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-3>U-#4U2X`LM#HV-[B(-#2XM[@
MV-?0YMC>W=7=(-_@WN+>VM[;(-W5(-_>U.#6X]+0(-O8X>+0^M4@VM[@V.'=
MV.;8+"#8V]@@XM#0(-S>UMW>X>(@U2#>W=72WM?<WM;5W=`@WM0@U.#CT]@@
MW^#8Y]C=V"X`6[C7TM7HXM#X(-?0(-_@WM';U=S>XET`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O;&]C86QE+VQV7TQ6+P``````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C`P
M,C0`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O;'9?3%8O
M3$-?34534T%'15,O````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4U`#`R,38Q,0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U
M<F)A+VQO8V%L92]L=E],5B],0U]-15-304=%4R]T=7)B82YM;P``````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,38P,C(`,3`T,3<S-C(W-34`,#(S,C8Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-X2!)4`````>```
M`!P```#<`P``HP```)P'````````*`H``"@````I"@``'0```%(*```(````
M<`H```4```!Y"@```P```'\*```(````@PH```<```","@``%````)0*```/
M````J0H```4```"Y"@``'P```+\*```1````WPH```8```#Q"@``"````/@*
M```5`````0L```H````7"P``#````"(+```.````+PL```<````^"P``*0``
M`$8+```"````<`L```4```!S"P``$````'D+```&````B@L```\```"1"P``
M%````*$+```O````M@L```D```#F"P``#P```/`+```F``````P```0````G
M#```!0```"P,```-````,@P```4```!`#```$````$8,```0````5PP```\`
M``!H#```"P```'@,```/````A`P```P```"4#```#P```*$,```&````L0P`
M`!X```"X#```(0```-<,```B````^0P```,````<#0``!````"`-```$````
M)0T```0````J#0``#````"\-```*````/`T```4```!'#0``$@```$T-```0
M````8`T```@```!Q#0``!````'H-```0````?PT```8```"0#0``!P```)<-
M```"````GPT```0```"B#0``"````*<-```/````L`T```<```#`#0``!P``
M`,@-```$````T`T```4```#5#0``!0```-L-```'````X0T``!$```#I#0``
M"````/L-```>````!`X```4````C#@``*````"D.```I````4@X``!,```!\
M#@``"P```)`.```1````G`X```0```"N#@``!````+,.```,````N`X```8`
M``#%#@``&@```,P.```7````YPX``!H```#_#@``%P```!H/```;````,@\`
M`#0```!.#P``'P```(,/```3````HP\``!````"W#P``%P```,@/```'````
MX`\```4```#H#P``)@```.X/```A````%1```!P````W$```!0```%00```#
M````6A```"````!>$```)````'\0```F````I!````P```#+$```"````-@0
M```;````X1````<```#]$```!@````41```-````#!$```L````:$0``#```
M`"81```*````,Q$```(````^$0``!@```$$1``!%````2!$``#````".$0``
M$````+\1```?````T!$``!````#P$0``#P````$2``!7`0``$1(``"H```!I
M$P``&P```)03```*````L!,```4```"[$P``"0```,$3```.````RQ,```8`
M``#:$P``%P```.$3```3````^1,```L````-%```&0```!D4```0````,Q0`
M``@```!$%```"0```$T4```;````5Q0``!$```!S%```#````(44```/````
MDA0```P```"B%```*P```*\4```"````VQ0```@```#>%```$@```.<4```%
M````^A0``!$`````%0``$P```!(5```O````)A4```@```!6%0``#@```%\5
M```B````;A4```<```"1%0``!P```)D5```0````H14```4```"R%0``$0``
M`+@5```2````RA4``!````#=%0``&````.X5```/````!Q8```P````7%@``
M#@```"06```)````,Q8``!X````]%@``)````%P6```@````@18```4```"B
M%@``!@```*@6```"````KQ8```D```"R%@``#````+P6```.````R18```4`
M``#8%@``%````-X6```0````\Q8```8````$%P``"`````L7```:````%!<`
M``L````O%P``!0```#L7```"````01<```4```!$%P``"@```$H7```0````
M51<```0```!F%P``#````&L7```%````>!<```4```!^%P``"````(07```'
M````C1<``!````"5%P``!@```*87```?````K1<```@```#-%P``(P```-87
M```M````^A<``!(````H&```#````#L8```7````2!@```0```!@&```"```
M`&48```0````;A@```D```!_&```'@```(D8```;````J!@``!\```#$&```
M&@```.08```C````_Q@``#`````C&0``$P```%09```<````:!D``!(```"%
M&0``%````)@9```'````K1D```@```"U&0``)````+X9```?````XQD``!\`
M```#&@``"@```",:```#````+AH``"<````R&@``'````%H:```K````=QH`
M`!$```"C&@``#P```+4:```G````Q1H```L```#M&@``#````/D:```0````
M!AL``!`````7&P``#````"@;```.````-1L```(```!$&P``"@```$<;```O
M````4AL``#P```""&P``$````+\;```;````T!L``!0```#L&P``$`````$<
M```!````)@```&0```!O````80```#T````+````:@````4````2````````
M`"<`````````=P```$\````6````;````&T```!+````4````$8````'````
M`````!4```!?````60```#\``````````````&X`````````,@```"H`````
M````6``````````-````*0```#X```!1`````````$X````O````$0```!P`
M````````<0```"X````W````````````````````.0```%<```!5````,```
M`!T````,`````````&L``````````````'4````M````90```$4`````````
M:0```$```````````````&````!R````2@````````!X````,0```!````!!
M````"0```!D```!S`````````$(````&````.P```%8```!4`````````'8`
M``!F````(P```%,````$`````````'`````A````4@```%T````V````````
M``H````H````.@``````````````=```````````````:````$P````#````
M&````&,````(````)0```$,```````````````````!$````(@```$<````K
M````+`````````!B`````````%P``````````````#4````\`````@```!L`
M````````9P```%H```!)`````````!H``````````````"0````.````.```
M```````4````,P```!X````7````30````````!;````'P```#0````/````
M(`````````!>````$P```$@``````````"5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP
M;W)T960`,C0@:&]U<G,`04TO4$T`061D`$%D9"!P86ER`$%D9')E<W,`061D
M<F5S<R!";V]K($QI<W1I;F<`061V86YC960@4V5A<F-H`$%L:6%S`$%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`079A:6QA8FQE(&9I96QD<SH`
M0G)O=W-E`$-A;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H
M;VYE`$-L;W-E(%=I;F1O=P!#;VQU;6X@3W!T:6]N<P!#;VUP86YY`$-O=6QD
M(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A:6QY
M`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T:6]N(&9A:6QE9`!$97-C
M<FEB92!T:&4@4')O8FQE;0!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES<&QA>2!/<'1I;VYS
M`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5D:70`
M16UA:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M<&]R=`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!S96%R8V@@=&AE
M(&1I<F5C=&]R>3H@)7,`1F%X`$9I;F0`1G)O;0!(96QP`$AO;64@061D<F5S
M<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$QA;F=U86=E`$QI<W0`3&ES="!(96QP(%1O<&EC<P!,;V<@
M:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG`$UA=&-H:6YG(&9I96QD<P!-
M97-S86=E`$UO;G1H;'D`3F%M90!.979E<@!.;W1E<P!/<'1I;VYS`$]T:&5R
M($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5T=7)N
M('1O($]P=&EO;G,`4F]L90!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!T:6UE
M(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!W
M:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RX`
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@
M4F5P;W)T`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP
M=70`4W5C8V5S<P!487-K<P!4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A9&1R
M97-S(&)O;VMS+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`
M5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:71L90!54DP`56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT`%5S97(@3W!T:6]N<P!5<V5R;F%M90!6:65W('1O(&1I
M<W!L87D@8GD@9&5F875L=#H`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E
M<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R
M;'D`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T
M:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@
M4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`4')O:F5C="U)9"U697)S:6]N.B!4
M=7)B82`Q+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P
M,`I03RU2979I<VEO;BU$871E.B`R,#`R+3$Q+3(Y(#$V.C`P*S`R,#`*3&%S
M="U4<F%N<VQA=&]R.B!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N
M;'8^"DQA;F=U86=E+51E86TZ($QA='9I86X@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]0U`Q,C4W"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#@M8FET"@`E<R!5>G1U<N?P86YA<R!O<&5RXF-I:F%S("T@87!S=&EP<FEN
MXFIU;7,`9F%I;',@)7,@=F5I:W-M[F=I(&EE;.)DYW1S`#(T('-T=6YD87,`
M04TO4$T`4&EE=FEE;F]T`%!I979I96YO="!PXG)I`$%D<F5S90!!9')E<W4@
M9W+B;6%T=2!S87)A:W-T<P!387)E_NSN=.(@;65K;.?P86YA`%-A[G-I;N)J
M=6US`$YO<N)D[G1A(&YE9&5R[F=A(';G<G3N8F$`4&EE96IA;6EE(&QA=6MI
M.@!0XG)L^VMO=`!+86QE;F3B<G,`071C96QT('!R;V)LYVUA<R!P:65T96EK
M=6UU`$UO8FEL86ES('3B;')U;FES`$%I>G;G<G0@;&]G=0!+;VQO;FYU(&]P
M8VEJ87,`3W)G86YI>N)C:6IA`$YE:7ID97;B<R!A=';G<G0@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&D@)7,`1$0`26MD:65N87,`4&%R87-TXB!I9&5N=&ET
MXG1E`$1ZYW-T`$EZ9'KG<W0@;F5I>F1E=N)S`$%P<F%K<W1I970@<')O8FSG
M;74`4^YKXFMA(&EN9F]R;>)C:6IA(&ER(&YO<_MT[G1A(&%D;6EN:7-T<F%T
M;W)A;2X`2V%T86QO9W,`16MRXFYA(&]P8VEJ87,`3F%V('1I9?!A<R!P:65E
M:F%S(&UA:6YT96YA;F-E+G!H<`!2961I[.=T`$4M<&%S=',`5'5K\',@<F5Z
M=6QTXG1S+@!+[_MD80!+871R87,@,34@;6EN^W1E<P!+871R87,@,S`@<V5K
M=6YD97,`2V%T<F%S(#4@;6EN^W1E<P!+871RXB!P:65S;.=G\&%NXG,@<F5I
M>N<`2V%T<G4@<'5S<W1U;F1U`$MA=')U(&UI;OMT:0!087)A=6=VYW)T[F)A
M<P!%:W-P;W)TYW0`3F5I>F1E=N)S('-A\F5M="!I97-T873N:G5M=7,N`$YE
M:7ID97;B<R!P:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+@!.96EZ9&5VXG,@
M;65K;.?P86YA(&MA=&%L;V?B.B`E<P!&86MS<P!-96MLYW0`3F\`4&%L[F1Z
M[F)A`$WB:F%S(&%D<F5S90!-XFIA<R!T96QE9F]N<P!(;W)D90!)96SB9.=T
M86ES(&QA=6MS.B`E<P!)96SB9.=T:64@;&%U:VDZ`%9A;&]D80!387)A:W-T
M<P!087+B9.YT('!A;.YD>NYB87,@=&5M871U<P!0:65S;.=G=&EE<P!)>FEE
M=`!-30!087-T<P!!=&)I;'-T;_!S`%-A<VMA;F_P:64@;&%U:VD`6FGR80!+
M871R=2!MYVYE<VD`5N)R9',`3F5K860`4&EE>NYM97,`3W!C:6IA<P!#:71A
M(&EN9F]R;>)C:6IA`%!A<F]L90!)>G!I;&3N="!U>G1U<N?P86YA<R!O<&5R
MXF-I:F%S`%3B;')U;FES`$S[9'IU(&YO<N)D:65T('!R;V)LYVUA<R!A;F]T
MXF-I:G4N`$S[9'IU(&YO<N)D:65T('-A=G4@;&EE=&]TXFIA(';B<F1U('5N
M('!A<F]L:0!0<F]B;.=M87,@87!R86MS=',`27ID>N=S="!PXG)I`$%T9W)I
M97IT:65S('!I92!O<&-I:N)M`$QO;6$`4V%G;&%BXG0`4V%G;&%BXG0@;W!C
M:6IA<P!-96MLY_!A;F$`27IVYVQI971I97,@9&%T=6UA(&%T9&%L[G3B:G4Z
M`$EZ=N=L:65T:65S(&1A='5M82!F;W)MXG1U.@!)>G;G;&EE=&EE<R!F86EL
M=2P@:V\@:6UP;W)TYW0Z`$EZ=N=L:65T:65S(&QA:6MA(&9O<FWB='4Z`$EZ
M=N=L:65T:65S(&1I=G5S('-A9&5R[F=U<R!L875K=7,N`$EZ=N=L:65T:65S
M(&MU<G5S(&QA=6MU<R!RXF3N="!A9')E<W4@<V%R86MS=&]S+@!)>G;G;&EE
M=&EE<R!V86QO9'4Z`$YO<_MT[G0@<')O8FSG;6%S('!I971E:6MU;74`27IL
M86ES="!U>G1U<N?P86YU`,YP8?!O('-I;6)O;'4@:65V861E`%9E:6MS;64`
M57ID979U;6D`T&5I="!N878@<.)R;/MK;VIA;74@861R97-U(&=RXFUA='4N
M`-!I;2!S:V%I=&QI;2!I<B!JXF+[="!V:7-M87H@,2X`T&%I(';G<G3N8F%I
M(&ER(&KB8OMT('-K86ET;&EM+@!6:7)S<F%K<W1S`%523`!.878@:65S<.=J
M86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2X`3F5V87(@:65LXF3G="`E
M<R!D969I;NYC:6IU+@!.878@:65S<.=J86US(&EN=&5R<')E=.=T(/!O(%=O
M<F0@9&]K=6UE;G1U`$QI971O=.)J82!O<&-I:F%S`$QI971O=.)J82!VXG)D
M<P!3:V%T[FIU;7,L(&MO('!A<N)D[G0@<.=C(&YO:VQU<^?P86YA<SH`0G+N
M9&ENXFIU;7,`2V%T<G4@;F5DY^]U`$QA:7!N:2!L^V1Z86T@)7,`3&%I<&YI
M(&S[9'IM+"`E<P!$87)B82!A9')E<V4`1&%R8F$@=&5L969O;G,`1T<`2V%T
M<G4@9V%D=0!!<')A:W-T:65T('!R;V)LYVUU('!I<FUS('!I971E:6MU;6$@
M<_MT[O!A;F%S+@!*^W-U("5S('-E<VEJ82!I<B!B96EG=7-I97,N($S[9'IU
M('!I97-LYV1Z:65T:65S(&%T:^)R=&]T:2X`2OMS=2!I;F9O<FWB8VEJ80!*
M^W-U(&]P8VEJ87,@:7(@<V%G;&%BXG1A<RX`6U!R;V)LYVUA<R!Z:?)O:G5M
M<UT`6W)I;F1A("5S(&YO("5S70``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M='5R8F$O;&]C86QE+VYB7TY/+P``````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,3<W-S4`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O;F)?3D\O3$-?34534T%'
M15,O````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S4U`#`R,34V,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L
M92]N8E].3R],0U]-15-304=%4R]T=7)B82YM;P``````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,C$W-C8`,3`T,3<S-C(W-34`,#(S,C0U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````I0```!P```!$!0``
MWP```&P*````````Z`T``"@```#I#0``'0```!(.```(````,`X```4````Y
M#@```P```#\.```(````0PX```8```!,#@``!P```%,.```4````6PX```\`
M``!P#@``!0```(`.```#````A@X``!\```"*#@``$0```*H.```,````O`X`
M``8```#)#@``"````-`.```5````V0X```H```#O#@``#````/H.```.````
M!P\```<````6#P``!````!X/```I````(P\```(```!-#P``!0```%`/```0
M````5@\```8```!G#P``#P```&X/```4````?@\``"\```"3#P``"0```,,/
M```/````S0\``"8```#=#P``#@````00```$````$Q````4````8$```#0``
M`!X0```%````+!```!`````R$```$````$,0```/````5!````L```!D$```
M#P```'`0```,````@!````\```"-$```!@```)T0```>````I!```"$```##
M$```(@```.40```#````"!$```<````,$0``!````!01```$````&1$```0`
M```>$0``!0```",1```,````*1$```H````V$0``!0```$$1```*````1Q$`
M``\```!2$0``'````&(1```2````?Q$``!````"2$0``!P```*,1```(````
MJQ$```D```"T$0``#````+X1```-````RQ$```X```#9$0``%@```.@1```1
M````_Q$```0````1$@``$````!82```&````)Q(```<````N$@```@```#82
M```$````.1(```@````^$@``#P```$<2```*````5Q(```<```!B$@``#```
M`&H2```'````=Q(```0```!_$@``!````(02```+````B1(```4```"5$@``
M"P```)L2```$````IQ(```0```"L$@``!````+$2```%````MA(```<```"\
M$@``"@```,02```1````SQ(```X```#A$@``"````/`2```>````^1(```4`
M```8$P``*````!X3```I````1Q,``!,```!Q$P``$@```(43```5````F!,`
M``L```"N$P``$0```+H3```1````S!,```0```#>$P``!````.,3```,````
MZ!,```8```#U$P``&@```/P3```7````%Q0``!D````O%```&@```$D4```E
M````9!0``"@```"*%```%P```+,4```;````RQ0``#0```#G%```)0```!P5
M```?````0A4``!,```!B%0``"````'85```-````?Q4```H```"-%0``$```
M`)@5```7````J14```<```#!%0``!0```,D5```)````SQ4``"8```#9%0``
M(0`````6```<````(A8```4````_%@```P```$46```@````218``"0```!J
M%@``)@```(\6```,````MA8```@```##%@``&P```,P6```'````Z!8```8`
M``#P%@``#0```/<6```+````!1<```P````1%P``"@```!X7```"````*1<`
M``8````L%P``10```#,7```P````>1<``!````"J%P``'P```+L7```0````
MVQ<```\```#L%P``!P```/P7```'````!!@```4````,&```#@```!(8```(
M````(1@```@````J&```!P```#,8``!Q`0``.Q@``"@```"M&0``(````-89
M```(````]QD```4`````&@``"`````8:```,````#QH```L````<&@``!P``
M`"@:```/````,!H```P```!`&@``!0```$T:```$````4QH``!T```!8&@``
M$P```'8:```,````BAH```4```"7&@``"````)T:```5````IAH```P```"\
M&@``"@```,D:```+````U!H```4```#@&@``!@```.8:```I````[1H```(`
M```7&P``!@```!H;```1````(1L```4````S&P``$0```#D;```1````2QL`
M`"X```!=&P``!P```(P;```-````E!L``!\```"B&P``#@```,(;```'````
MT1L```4```#9&P``#@```-\;```$````[AL``!````#S&P``$`````0<```/
M````%1P```\````E'```#0```#4<```,````0QP``!````!0'```"0```&$<
M```=````:QP``"(```")'```'P```*P<```(````S!P```8```#5'```!```
M`-P<```#````X1P```4```#E'```!````.L<```-````\!P```X```#^'```
M!0````T=```*````$QT``!`````>'0``'````"\=```3````3!T``!````!@
M'0``"````'$=```%````>AT```T```"`'0``#0```(X=```2````G!T``!0`
M``"O'0``&P```,0=```7````X!T```4```#X'0``#0```/X=```(````#!X`
M``<````5'@```@```!T>```$````(!X```<````E'@``$````"T>```*````
M/AX```<```!)'@``#````%$>```)````7AX```4```!H'@``!````&X>```+
M````<QX```4```!_'@``"@```(4>```'````D!X```4```"8'@``!0```)X>
M```'````I!X```0```"L'@``#````+$>```1````OAX``!0```#0'@``!P``
M`.4>```=````[1X```<````+'P``*````!,?```H````/!\``!(```!E'P``
M$````'@?```6````B1\```D```"@'P``"@```*H?```0````M1\```4```#&
M'P``!0```,P?```*````TA\```,```#='P``%````.$?```/````]A\``"0`
M```&(```'P```"L@```6````2R```"@```!B(```$````(L@```9````G"``
M`#,```"V(```*P```.H@```2````%B$``!,````I(0``"````#TA```-````
M1B$```H```!4(0``%0```%\A```5````=2$```<```"+(0``"````),A```)
M````G"$``"@```"F(0``'0```,\A```6````[2$```8````$(@```P````LB
M```?````#R(``",````O(@``*````%,B```*````?"(```H```"'(@``$```
M`)(B```(````HR(```@```"L(@``#0```+4B```-````PR(```P```#1(@``
M#@```-XB```"````[2(```4```#P(@``/````/8B```V````,R,```\```!J
M(P``'0```'HC```0````F",``!````"I(P``"P```+HC```%````QB,```4`
M``#,(P``$@```-(C```'````Y2,```0```#M(P```P```/(C```!````````
M`!4````>````G@```(H```"&````-0```#P````V````:P``````````````
M60```#<```````````````````!'````0````)\```",````*0````````"`
M`````@``````````````>0```#$````M````10```"<````,````$P```*(`
M`````````````)T```!L````1@```!H`````````D@```#(```!5````30``
M``````"%````*````"4```!"````?````!`````&````HP```*0```!*````
M8````%(````B````!````!8```!I````C0```',```"8````BP```"L```!7
M````8@```)H```!+````"@````````"6````8P````,````N````FP```"P`
M````````%P```%0`````````4````(X````9`````````)$```!R````)@``
M``@`````````F0````````!1````@P```(<```!V````%````%T```!T````
M.@```'H```!G````7P```````````````````(@```!Q````E0```&H````+
M````#P```#X```!M`````````'<`````````1`````````!A````'```````
M``!#````&P```````````````````&@````D````#@```#``````````G```
M`&4````O````3````"H``````````````!@`````````7@`````````A````
M20```'@````X````?0```%L```!/`````````!\````````````````````2
M````$0`````````S````5@```)0`````````<``````````Y````7````),`
M``"!````>P````4```!N````EP```#\```!O````H````%@````=````````
M````````````!P```(D``````````````%H```!3````#0```#0`````````
M"0```$X`````````=0````````!^``````````````````````````````!D
M````(P`````````[`````````$$```"0````H0```(\```!(````?P```(0`
M``"E````@@```"`````]``````````````!F`````"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@9FEL92!S=6-C97-S9G5L
M;'D@:6UP;W)T960`,C0@:&]U<G,`04TO4$T`061D`$%D9"!P86ER`$%D9"!T
M;P!!9&1R97-S`$%D9')E<W,@0F]O:R!,:7-T:6YG`$%D=F%N8V5D(%-E87)C
M:`!!;&EA<P!!;&P`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M=F%I;&%B;&4@9FEE;&1S.@!"87-I8R!396%R8V@`0G)O=W-E`$-A;&5N9&%R
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E(%=I;F1O
M=P!#;VQU;6X@3W!T:6]N<P!#;VUP86YY`$-O<'D`0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&5F875L="!)
M9&5N=&ET>0!$96QE=&4`1&5L971I;VX@9F%I;&5D`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1I<F5C=&]R>0!$:7-P;&%Y($]P=&EO;G,`1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]W;FQO860@=D-A<F0`
M161I=`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AP;W)T`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O('-E87)C
M:"!T:&4@9&ER96-T;W)Y.B`E<P!&87@`1FEL=&5R<P!&:6YD`$9R;VT`2&5L
M<`!(;U]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)8V]N<R!/
M;FQY`$EC;VYS('=I=&@@=&5X=`!);7!O<G0@061D<F5S<R!";V]K+"!3=&5P
M("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA7WEO
M=70`3&%N9W5A9V4`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T
M960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S
M="!L;V=I;CH@3F5V97(`3&ES=`!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,
M;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<`36%T8VAI;F<@9FEE;&1S`$UE;G4@
M;6]D93H`365S<V%G90!-;V)I;&4@4&AO;F4`36]N=&AL>0!-;W9E`$YA;64`
M3F%M92!&;W)M870`3F5V97(`3F5W($-O;G1A8W0`3F5W<P!.97AT`$YO;F4`
M3F]T97,`3W!T:6]N<P!/<F=A;FEZ:6YG`$]T:&5R($EN9F]R;6%T:6]N`%!'
M4"!0=6)L:6,@2V5Y`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5C;W)D<R!D:7-P;&%Y960Z
M`%)E;6]V92!F<F]M('1H:7,@;&ES=`!296UO=F4@<&%I<@!297-E="!T;R!$
M969A=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2;VQE`%-A=F4`4V%V92!/<'1I
M;VYS`%-E87)C:`!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E
M;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9F]R;6%T(&]F
M('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D
M:7-P;&%Y(&YA;65S.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('=H:6-H(&9I96QD<R!T;R!D
M:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+@!396QE8W0@=VAI8V@@9F]R
M;6%T('1O(&1I<W!L87D@;F%M97,N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3:&]W($%L;`!3:&]W($-O
M;G1A8W1S`%-H;W<@3&ES=',`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H
M87)A8W1E<B!);G!U=`!3=6-C97-S`%1A<VMS`%1E>'0@3VYL>0!4:&5R92!A
M<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+@!4:71L90!54DP`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BX`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5S97(@3W!T:6]N
M<P!5<V5R;F%M90!6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#H`5V%R;FEN
M9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E
M<W,`5V]R:R!0:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`
M7T)R;W=S90!?1&5L971E`%](96QP`%]);7!O<G0O17AP;W)T`%],;V<@;W5T
M`%]/<'1I;VYS`%]396%R8V@`4')O:F5C="U)9"U697)S:6]N.B!4=7)B82`Q
M+C(*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2
M979I<VEO;BU$871E.B`R,#`T+3`U+3$X(#(S.C,W*S`R,#`*3&%S="U4<F%N
M<VQA=&]R.B!!;F1R96%S($=U;FQE:6MS:V%A<R`\86YD<F5A<T!G=6YL96EK
M<VMA87,N;F\^"DQA;F=U86=E+51E86TZ($YO<G=E9VEA;B`H0F]K;6%L*2`\
M:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"5S('9E9&QI:V5H;VQD<V]P
M97)A<VIO;F5R("T@0F5K<F5F=&5L<V4`26UP;W)T(&%V("5S(&9I;&5N('9A
M<B!V96QL>6MK970`,C0@=&EM97(`04TO4$T`3&5G9R!T:6P`3&5G9R!T:6P@
M<&%R`$QE9V<@=&EL+BXN`$%D<F5S<V4`061R97-S96)O:VQI<W1E`$%V86YS
M97)T('/X:P!!;&EA<P!!;&QE`$5N('5L;W9L:6<@=F5R9&D@=F%R(&]P<&=I
M='0N`%1I;&=J96YG96QI9V4@9F5L=#H`4W1A;F1A<F0@<_AK`$QI<W1E`$MA
M;&5N9&5R`$%V8G)Y="!P<F]B;&5M<F%P<&]R=`!-;V)I;'1E;&5F;VX`3'5K
M:R!V:6YD=0!+;VQO;FYE=F%L9P!&:7)M80!+;W!I97(`2V%N(&EK:V4@Y7!N
M92!-86EN=&5N86YC95]487-K+6UO9'5L970@)7,`1$0`1&%G;&EG`%-T86YD
M87)D:61E;G1I=&5T`%-L971T`%-L971T:6YG96X@9F5I;&5T`$)E<VMR:78@
M<')O8FQE;65T`$1E=&%L:F5R(&AA<B!B;&ET="!L;V=G970@9F]R(&%D;6EN
M:7-T<F%T;W)E;BX`2V%T86QO9P!6:7-N:6YG<R!V86QG`$EK:V4@Y7!N(&UA
M:6YE;F%N8V4N<&AP(&1I<F5K=&4`3&%S="!N960@=D-A<F0`4F5D:6=E<@!%
M<&]S=`!4;VUT(')E<W5L=&%T+@!&96EL`$AV97)T(#$U+B!M:6YU='0`2'9E
M<G0@,S`N('-E:W5N9`!(=F5R="`U+B!M:6YU='0`2'9E<B!I;FYL;V=G:6YG
M`$AV97(@:&%L=G1I;64`2'9E<G0@;6EN=71T`$5K<V5M<&5L=F5R9&EE<CH`
M16MS<&]R=&5R`$MA;B!I:VME(&5N9')E(&EN<W1I;&QE:6YG97(N`%1I;&MO
M8FQI;F<@=&EL($Q$05`M<V5R=F5R(&9E:6QE="X`2W5N;F4@:6MK92!S^&ME
M(&D@:V%T86QO9V5N.B`E<P!496QE9F%K<P!&:6QT97(`1FEN;@!&<F$`2&IE
M;'``2&IE;0!(:F5M;65A9')E<W-E`%1E;&5F;VX@:&IE;6UE`$AO<F1E`$MU
M;B!I:V]N97(`26MO;F5R(&UE9"!T96MS=`!);7!O<G1E<B!A9')E<W-E8F]K
M+"!S=&5G("5D`$EM<&]R=&5R=&4@9F5L=#H@)7,`26UP;W)T97)T92!F96QT
M.@!5='-E96YD90!3<'+E:P!3:7-T92!H86QT:6UE`%-I<W1E(&MV87)T97(`
M4VES=&4@;W!P9&%T97)I;F<Z`%-I<W1E(&EN;FQO9V=I;F<Z("5S`%-I<W1E
M(&EN;FQO9V=I;F<Z("5S(&9R82`E<P!3:7-T92!I;FYL;V=G:6YG.B!!;&1R
M:0!,:7-T90!%;6YE<B!I($AJ96QP`$QO9V<@:6YN`$QO9V<@=70`34T`4&]S
M=`!+;V)L:6YG`%-A;7-V87)E;F1E(&9E;'0`365N>6UO9'5S.@!-96QD:6YG
M`$UO8FEL=&5L969O;@!-Y6YE9'1L:6<`1FQY='0`3F%V;@!.879N969O<FUA
M=`!!;&1R:0!.>2!K;VYT86MT`$YY:&5T97(`3F5S=&4`26YG96X`3F]T871E
M<@!686QG`$]R9V%N:7-E<FEN9P!!;FYE;B!I;F9O<FUA<VIO;@!01U`@;V9F
M96YT;&EG(&[X:VME;`!087-S;W)D`%5T9OAR('9E9&QI:V5H;VQD<V]P97)A
M<VIO;F5R`%1E;&5F;VX`5F5N;FQI9W-T(&=I(&5T('-A;6UE;F1R86<@878@
M<')O8FQE;65T+@!696YN;&ES="!S:W)I=B!I;FX@8G)U:V5R;F%V;B!O9R!P
M87-S;W)D`%!R;V)L96UB97-K<FEV96QS90!!;G1A;"!I('9I<VYI;F<Z`%-L
M971T(&9R82!D96YN92!L:7-T96X`1FIE<FX@<&%R`%3X;2!S:VIE;6$`5&EL
M8F%K92!T:6P@5F%L9P!2;VQL90!,86=R90!,86=R92!686QG`%/X:P!696QG
M(&1A=&]S:VEL;&5T96=N.@!696QG(&1A=&]F;W)M870`5F5L9R!F;W)M871E
M="!D=2!V:6P@96MS<&]R=&5R92!T:6PZ`%9E;&<@9FEL96X@<V]M('-K86P@
M:6UP;W)T97)E<SH`5F5L9R!F;W)M870@<.4@:VEL9&5N.@!696QG('9I<VYI
M;F=S9F]R;6%T970@<V]M('-K86P@8F5N>71T97,Z`%9E;&<@=&ED<V9O<FUA
M=#H`5F5L9R!T;R!S86US=F%R96YD92!F96QT+@!696QG(&AV:6QK92!F96QT
M97(@<V]M('-K86P@=FES97,@:2!A9')E<W-E(&QI<W1E;BX`5F5L9R!H=F$@
M<VQA9W,@=FES;FEN9W-F;W)M870@;F%V;B!S:V%L(&AA+@!696QG(/AN<VME
M="!S<'+E:SH`4V5N9"!P<F]B;&5M<F%P<&]R=`!6:7,@86QL90!6:7,@:V]N
M=&%K=&5R`%9I<R!L:7-T97(`2&]P<"!O=F5R('9E9&QI:V5H;VQD`%-P97-I
M86QT96=N:6YN=&%S=&EN9P!3=6MS97-S`$]P<&=A=F5R`$MU;B!T96MS=`!$
M970@9FEN;F5S(&EN9V5N('-K<FEV8F%R92!A9')E<W-E8OAK97(N`$1E='1E
M('1A;&QE="!MY2!VYG)E(&UI;G-T(#$N`$1E='1E(&WE(';F<F4@970@=&%L
M;"X`5&ET=&5L`%523`!+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN
M`$MA;B!I:VME(&QA<W1E(&1E=&9I;FES:F]N96X@878@)7,N`$MA;B!I:VME
M(&]V97)S971T92!D971T92!7;W)D+61O:W5M96YT970`3&%G<F4@5F%L9P!"
M<G5K97)N879N`%-T86YD87)D=FES;FEN9SH`061V87)S96P`56ME;G1L:6<`
M5F5L:V]M;65N+"`E<P!696QK;VUM96XL("5S`$9I<FUA861R97-S90!496QE
M9F]N($%R8F5I9`#EY0#E<FQI9P!$=2!MY2!B97-K<FEV92!P<F]B;&5M970@
M9OAR(&1U(&MA;B!S96YD92!E;B!P<F]B;&5M<F%P<&]R="X`1&EN("5S('1I
M;&MO8FEN9R!H87(@9^5T="!U="X@5F5N;FQI9W-T(&QO9R!I;FX@:6=J96XN
M`$1I;B!I;F9O<FUA<VIO;@!$:6YE('9A;&<@:&%R(&)L:71T(&]P<&1A=&5R
M=`!;4')O8FQE;7)A<'!O<G1=`%ML:6YJ92`E<R!A=B`E<UT`0FQA(&=J96YN
M;VT`4VQE='0`2&IE;'``26UP;W)T97(O16MS<&]R=&5R`$QO9V<@=70`5F%L
M9P!3^&L``````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R
M8F$O;&]C86QE+VYL7TY,+P``````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C`P,#0`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O;FQ?3DPO3$-?34534T%'15,O
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U
M`#`R,34W,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]N
M;%].3"],0U]-15-304=%4R]T=7)B82YM;P``````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S
M-C<T,3<`,3`T,3<S-C(W-34`,#(S,C8R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-X2!)4`````'`<``!P```#\.```A0D`
M`-QQ````````\)<```X```#QEP``#P````"8```(````$)@```P````9F```
M!````":8```D````*Y@``"4```!0F```#````':8```/````@Y@```L```"3
MF```#@```)^8```%````KI@``"@```"TF```"@```-V8```5````Z)@```D`
M``#^F```$@````B9```+````&YD``!T````GF0``#@```$69```*````5)D`
M``T```!?F0``#@```&V9```-````?)D```P```"*F0``#0```)>9```&````
MI9D```\```"LF0``&````+R9```,````U9D```X```#BF0``#@```/&9```(
M`````)H``"L````)F@``+@```#6:```:````9)H``#(```!_F@``.````+*:
M``!4````ZYH``%$```!`FP``6@```)*;``!7````[9L``#0```!%G```"@``
M`'J<```%````A9P```8```"+G```$0```)*<```(````I)P``!$```"MG```
M"0```+^<```)````R9P``"4```#3G```(````/F<```0````&IT```\````K
MG0``"@```#N=```/````1IT``!0```!6G0``"0```&N=```-````=9T``!(`
M``"#G0``#P```):=```*````IIT```\```"QG0``"````,&=```D````RIT`
M``8```#OG0``%````/:=```6````"YX```@````BG@``&0```"N>```'````
M19X``!0```!-G@``$@```&*>```A````=9X``"P```"7G@``#@```,2>```#
M````TYX```\```#7G@``"P```.>>```'````\YX```<```#[G@``!0````.?
M```%````"9\```H````/GP```P```!J?```7````'I\```H````VGP``#P``
M`$&?```.````49\``!@```!@GP``(P```'F?```.````G9\```X```"LGP``
M%````+N?```7````T)\``!<```#HGP``%P````"@```3````&*````\````L
MH```#@```#R@```?````2Z````<```!KH```!@```'.@```(````>J````\`
M``"#H```!@```).@```*````FJ```!,```"EH```"P```+F@```5````Q:``
M`!4```#;H```!P```/&@```%````^:```!4```#_H```$0```!6A```,````
M)Z$``"@````TH0``.@```%VA```[````F*$```D```#4H0``!P```-ZA```4
M````YJ$```,```#[H0``!0```/^A```)````!:(``!`````/H@``"0```""B
M```3````*J(``#D````^H@``$@```'BB```G````BZ(``"P```"SH@``*@``
M`."B```E````"Z,```H````QHP``!@```#RC```)````0Z,```<```!-HP``
M+P```%6C```W````A:,``"X```"]HP``50```.RC```M````0J0``"T```!P
MI```+0```)ZD``!`````S*0``",````-I0``(P```#&E```M````5:4``#,`
M``"#I0``%0```+>E```9````S:4``"D```#GI0``)````!&F```1````-J8`
M``H```!(I@``#````%.F```*````8*8``!````!KI@``%@```'RF```6````
MDZ8```<```"JI@``!P```+*F```4````NJ8```H```#/I@``"````-JF```(
M````XZ8```P```#LI@``!P```/FF```'`````:<```8````)IP``$0```!"G
M```%````(J<```<````HIP``!@```#"G```4````-Z<```@```!,IP``*0``
M`%6G```.````?Z<```H```".IP``!````)FG```'````GJ<```D```"FIP``
M!@```+"G```1````MZ<```<```#)IP``%@```-&G```$````Z*<```@```#M
MIP``!@```/:G```-````_:<```8````+J```'@```!*H```1````,:@```@`
M``!#J```#0```$RH```,````6J@```<```!GJ```$0```&^H```#````@:@`
M``,```"%J```%P```(FH```#````H:@``!,```"EJ```"````+FH```$````
MPJ@```@```#'J```"````-"H``!!````V:@``"`````;J0``!@```#RI```&
M````0ZD``!4```!*J0``&````&"I```B````>:D``"X```"<J0``'0```,NI
M```A````Z:D``%0````+J@``*0```&"J```*````BJH```<```"5J@``%0``
M`)VJ```.````LZH```H```#"J@``#P```,VJ```-````W:H```\```#KJ@``
M#0```/NJ```)````":L``!0````3JP``!@```"BK```8````+ZL``!T```!(
MJP``$P```&:K```4````>JL```0```"/JP``!@```)2K``!4````FZL```0`
M``#PJP``#@```/6K```/````!*P```4````4K```!0```!JL```;````(*P`
M`!H````\K```$0```%>L```1````::P``!8```![K```'````)*L```J````
MKZP``!````#:K```(0```.NL```%````#:T``!,````3K0``$@```">M```*
M````.JT```\```!%K0``$0```%6M```3````9ZT```P```![K0``!@```(BM
M```&````CZT``!<```"6K0``$0```*ZM```(````P*T```4```#)K0``#```
M`,^M```0````W*T```4```#MK0``#@```/.M```-`````JX```8````0K@``
M%@```!>N```J````+JX```<```!9K@``#0```&&N```'````;ZX```L```!W
MK@``!P```(.N```'````BZX```\```"3K@``"0```*.N```*````K:X``!D`
M``"XK@``#````-*N```0````WZX```4```#PK@``)0```/:N```2````'*\`
M`!,````OKP``%0```$.O```2````6:\``"L```!LKP``.P```)BO```@````
MU*\``!H```#UKP``%````!"P```V````);````@```!<L```#````&6P```&
M````<K````0```!YL```#@```'ZP```*````C;````T```"8L```'@```*:P
M```;````Q;```"$```#AL```'@````.Q```9````(K$``!X````\L0``&P``
M`%NQ```F````=[$``!L```">L0``'@```+JQ```<````V;$``"8```#VL0``
M,P```!VR```F````4;(``"L```!XL@``.````*2R```O````W;(``!(````-
MLP``*0```""S```2````2K,``*(```!=LP``%@````"T```C````%[0``"@`
M```[M```*0```&2T```H````CK0``!\```"WM```(````->T```E````^+0`
M`"$````>M0``'````$"U```F````7;4``$$```"$M0``#````,:U```'````
MT[4```<```#;M0``#0```..U```0````\;4``!(````"M@``!P```!6V```3
M````';8``!(````QM@``!P```$2V```$````3+8```P```!1M@``#@```%ZV
M```/````;;8``!,```!]M@``#0```)&V```H````G[8```,```#(M@``#0``
M`,RV```&````VK8``!$```#AM@``%P```/.V```;````"[<```X````GMP``
M`@```#:W```%````.;<``!`````_MP``!````%"W```-````5;<```X```!C
MMP```P```'*W```.````=K<```@```"%MP``#P```(ZW```/````GK<```T`
M``"NMP``$````+RW```:````S;<```L```#HMP``!@```/2W```3````^[<`
M``P````/N```$0```!RX```9````+K@``!<```!(N```"P```&"X```-````
M;+@``"(```!ZN```%@```)VX```*````M+@``!@```"_N```&0```-BX```6
M````\K@```\````)N0``#0```!FY```'````)[D```H````ON0``"@```#JY
M```4````1;D``"(```!:N0``+P```'VY```+````K;D```D```"YN0``&0``
M`,.Y```+````W;D``!<```#IN0``%P````&Z```)````&;H``!8````CN@``
M#P```#JZ```6````2KH```X```!AN@``&````'"Z```(````B;H```T```"2
MN@``)@```*"Z```H````Q[H``$,```#PN@``"````#2[```2````/;L```L`
M``!0NP``+P```%R[```.````C+L```X```";NP``!0```*J[```&````L+L`
M``,```"WNP``!P```+N[```$````P[L```H```#(NP``"@```-.[```/````
MWKL``!````#NNP``%P```/^[```1````%[P``!$````IO```%P```#N\```)
M````4[P```4```!=O```"P```&.\```*````;[P```(```!ZO```!0```'V\
M```-````@[P``!L```"1O```%P```*V\```)````Q;P```X```#/O```#0``
M`-Z\```2````[+P``#@```#_O```(````#B]```(````6;T```X```!BO0``
M>P```'&]```8````[;T``!4````&O@``$0```!R^```'````+KX```4````V
MO@``&0```#R^```'````5KX```@```!>O@``!@```&>^```&````;KX``!``
M``!UO@``#P```(:^```0````EKX```\```"GO@``"P```+>^```/````P[X`
M``P```#3O@``#P```."^```'````\+X```8```#XO@``#````/^^```H````
M#+\```\````UOP``"````$6_```&````3K\``!,```!5OP``(@```&F_```M
M````C+\```@```"ZOP``$P```,._```>````U[\``"4```#VOP``&@```!S`
M```5````-\```!X```!-P```(0```&S````@````CL```!D```"OP```%P``
M`,G````E````X<```"4````'P0``%P```"W!```B````1<$```0```!HP0``
M&P```&W!```-````B<$```,```"7P0``"````)O!```*````I,$```P```"O
MP0``"P```+S!```$````R,$``!,```#-P0``%````.'!```,````]L$```D`
M```#P@``#@````W"```+````',(``!L````HP@``!P```$3"```$````3,(`
M``<```!1P@``"@```%G"```*````9,(```T```!OP@``"0```'W"```$````
MA\(```4```",P@```P```)+"```8````EL(```H```"OP@``!````+K"```F
M````O\(```X```#FP@``?````/7"```5````<L,```4```"(PP``!P```([#
M```,````EL,```@```"CPP``"@```*S#```&````M\,```@```"^PP```@``
M`,?#```&````RL,```8```#1PP``%````-C#```,````[<,```T```#ZPP``
M$`````C$```;````&<0```0````UQ```"0```#K$```0````1,0```D```!5
MQ```"0```%_$```%````:<0``!H```!OQ```"````(K$```&````D\0``!D`
M``":Q```#@```+3$```'````P\0```<```#+Q```!0```-/$```)````V<0`
M``H```#CQ```$P```.[$```"`````L4```8````%Q0``#0````S%```)````
M&L4```8````DQ0``$@```"O%```)````/L4```<```!(Q0``!0```%#%```4
M````5L4``!T```!KQ0``!@```(G%```*````D,4```0```";Q0``"0```*#%
M```(````JL4``!$```"SQ0``"0```,7%```&````S\4```T```#6Q0``!@``
M`.3%```$````Z\4``#D```#PQ0``/0```"K&```Z````:,8``!X```"CQ@``
M!0```,+&```.````R,8```0```#7Q@``!@```-S&```A````X\8``!4````%
MQP``!@```!O'```$````(L<``!$````GQP``!@```#G'```*````0,<``"(`
M``!+QP``!````&['```%````<\<``!T```!YQP``!````)?'```,````G,<`
M``D```"IQP``#````+/'```*````P,<``!````#+QP``$P```-S'```(````
M\,<```D```#YQP``!0````/(```Z````"<@``#````!$R```-0```'7(```I
M````J\@``$<```#5R```.````!W)```I````5LD``#\```"`R0``+@```,#)
M```M````[\D``!\````=R@``#P```#W*```2````3<H```L```!@R@``)@``
M`&S*```I````D\H``"0```"]R@``)@```.+*```(````"<L```H````2RP``
M"0```!W+```'````)\L``"`````ORP``(````%#+```F````<<L```0```"8
MRP``"@```)W+```9````J,L``"D```#"RP``%@```.S+```2`````\P```<`
M```6S```"@```![,```/````*<P``!`````YS```0````$K,``!P````B\P`
M`&8```#\S```#@```&/-```)````<LT```H```!\S0``$@```(?-```3````
MFLT```P```"NS0``!@```+O-```<````PLT```\```#?S0``&P```._-```2
M````"\X``!`````>S@``$0```"_.```<````0<X``",```!>S@``:@```(+.
M```/````[<X```4```#]S@``$`````//```)````%,\```0````>SP``"P``
M`"//```4````+\\```P```!$SP``#````%'/```/````7L\``!4```!NSP``
M*0```(3/```J````KL\``"8```#9SP``)P````#0```I````*-```"H```!2
MT```&0```'W0``!"````E]```!$```#:T```$@```.S0```3````_]```!0`
M```3T0``#P```"C1```6````.-$``!<```!/T0``$````&?1```1````>-$`
M`#0```"*T0``$P```+_1```2````T]$``#4```#FT0``%````!S2```'````
M,=(```P````YT@``"@```$;2```@````4=(``!0```!RT@``%````(?2```1
M````G-(``!<```"NT@``'````,;2```-````X](```T```#QT@``$P```/_2
M```6````$],``!$````JTP``#````#S3```0````2=,``!H```!:TP``'@``
M`'73```:````E-,``!$```"OTP``%````,'3```7````UM,``!4```#NTP``
M"0````34```9````#M0```0````HU```!P```"W4```+````-=0``!$```!!
MU```!@```%/4```&````6M0```8```!AU```!0```&C4```'````;M0```<`
M``!VU```!0```'[4```6````A-0```8```";U```!@```*+4```$````J=0`
M``0```"NU```!P```+/4```.````N]0```P```#*U```#````-?4```-````
MY-0```H```#RU```#@```/W4```%````#-4``"@````2U0``#@```#O5```,
M````2M4```\```!7U0``"@```&?5```(````<M4```D```![U0``*P```(75
M```$````L=4```@```"VU0``)@```+_5```2````YM4```\```#YU0``!@``
M``G6```*````$-8``$P````;U@``!P```&C6```(````<-8``"````!YU@``
M"0```)K6```-````I-8```D```"RU@``#````+S6```-````R=8```X```#7
MU@``%@```.;6```1````_=8```8````/UP```P```!;7```&````&M<``!D`
M```AUP``!P```#O7```$````0]<```L```!(UP``"P```%37```'````8-<`
M``<```!HUP``%@```'#7```-````A]<```T```"5UP``"@```*/7```0````
MKM<```\```"_UP``$0```,_7```7````X=<```H```#YUP``$0````38```(
M````%M@```0````?V```#P```"38```Z````--@```4```!OV```#````'78
M```$````@M@``!X```"'V```#@```*;8```0````M=@```L```#&V```#```
M`-+8```)````W]@```<```#IV```"@```/'8```)````_-@```X````&V0``
M$````!79```:````)MD```H```!!V0``"0```$S9```*````5MD```P```!A
MV0``#P```&[9```(````?MD```8```"'V0``!P```([9```+````EMD``$<`
M``"BV0``#0```.K9```)````^-D```0````"V@```P````?:```3````"]H`
M`!,````?V@``$P```#/:```*````1]H```(```!2V@``!````%7:```E````
M6MH```,```"`V@``!0```(3:```J````BMH```H```"UV@``!0```,#:```$
M````QMH```H```#+V@``#0```-;:```&````Y-H```@```#KV@``"````/3:
M```$````_=H```4````"VP``:`````C;```)````<=L```P```![VP``!0``
M`(C;```&````CML``!L```"5VP``+P```+';```0````X=L```H```#RVP``
M"````/W;```/````!MP```H````6W```"0```"'<```3````*]P``!L````_
MW```&````%O<```7````=-P```X```",W```%P```)O<```#````L]P```<`
M``"WW```"````+_<```'````R-P```H```#0W```"P```-O<```'````Y]P`
M`%$```#OW```$````$'=```,````4MT```T```!?W0``&@```&W=``!*````
MB-T```8```#3W0``!@```-K=```&````X=T``!\```#HW0``!@````C>```)
M````#]X``!@````9W@``%P```#+>```+````2MX```8```!6W@``#0```%W>
M```H````:]X``"(```"4W@``5P```+?>```3````#]\``",````CWP``$P``
M`$??```"````6]\```L```!>WP``#````&K?```(````=]\```T```"`WP``
M"@```([?```6````F=\```<```"PWP``%````+C?```&````S=\```@```#4
MWP``#@```-W?```'````[-\```H```#TWP``"P```/_?```7````"^````<`
M```CX```#````"O@```-````..````P```!&X```!````%/@```)````6.``
M``D```!BX```"@```&S@```'````=^````D```!_X```"0```(G@```*````
MD^````<```">X```"@```*;@```5````L>```!L```#'X```20```./@```2
M````+>$```H```!`X0``"0```$OA```0````5>$```<```!FX0``$@```&[A
M```$````@>$```L```"&X0``!P```)+A```%````FN$```4```"@X0``&@``
M`*;A```+````P>$``!0```#-X0``$0```.+A```:````].$``!8````/X@``
M%````";B```7````.^(``!@```!3X@``'````&SB```9````B>(```<```"C
MX@``!0```*OB```-````L>(```P```"_X@``"P```,SB```(````V.(``!<`
M``#AX@``"P```/GB```3````!>,```0````9XP``"@```![C```$````*>,`
M``P````NXP``"0```#OC```(````1>,```4```!.XP``!P```%3C```%````
M7.,```0```!BXP```@```&?C```8````:N,``!<```"#XP``.````)OC```L
M````U.,``!(````!Y```*0```!3D```R````/N0```H```!QY```+````'SD
M```N````J>0``#,```#8Y```,P````SE```X````0.4``!$```!YY0``#P``
M`(OE```8````F^4``!````"TY0``$P```,7E```4````V>4``!(```#NY0``
M%`````'F```5````%N8``"T````LY@``+0```%KF```Q````B.8``"X```"Z
MY@``+P```.GF```L````&><``&(```!&YP``$P```*GG```(````O><```@`
M``#&YP``*P```,_G```A````^^<``!@````=Z```&@```#;H```)````4>@`
M`$4```!;Z```00```*'H```$````X^@``!,```#HZ```%````/SH```.````
M$>D``!,````@Z0``&````#3I```&````3>D```D```!4Z0``"@```%[I```/
M````:>D``!````!YZ0``!P```(KI```.````DND```4```"AZ0``&P```*?I
M```(````P^D```8```#,Z0``%````-/I```1````Z.D``!@```#ZZ0``#@``
M`!/J```X````(NH```(```!;Z@``!@```%[J```.````9>H``!````!TZ@``
M!0```(7J```'````B^H```X```"3Z@``!@```*+J```$````J>H``"D```"N
MZ@``%P```-CJ```?````\.H``%P````0ZP``%````&WK```^````@NL``!\`
M``#!ZP``$````.'K```'````\NL```X```#ZZP``#`````GL```,````%NP`
M`!,````C[```"@```#?L```=````0NP``!D```!@[```!0```'KL```1````
M@.P```T```"2[```$0```*#L```D````LNP``!4```#7[```$@```.WL```.
M`````.T``!D````/[0``"````"GM```)````,NT```T````\[0``"@```$KM
M```+````5>T```H```!A[0``!P```&SM```(````=.T```4```!][0``'P``
M`(/M```&````H^T``!````"J[0``"````+OM```-````Q.T```@```#2[0``
M$@```-OM```L````[NT``!H````;[@``"0```#;N```*````0.X``!4```!+
M[@``!0```&'N```4````9^X```0```!\[@``$````('N```&````DNX```<`
M``"9[@``'@```*'N```H````P.X```H```#I[@``$0```/3N```1````!N\`
M`!H````8[P``%````#/O```$````2.\```0```!-[P``"P```%+O```%````
M7N\```8```!D[P``$0```&OO```(````?>\```8```"&[P``"@```(WO```;
M````F.\``#0```"T[P``-````.GO```@````'O```"D````_\```(````&GP
M``!!````BO```!H```#,\```*````.?P```I````$/$``"(````Z\0``!@``
M`%WQ```(````9/$```4```!M\0``"````'/Q```9````?/$``!D```"6\0``
M*@```+#Q```C````V_$``"X```#_\0``-````"[R```(````8_(``!<```!L
M\@``"@```(3R```'````C_(``"$```"7\@``$````+GR```.````RO(``!0`
M``#9\@``"P```.[R```'````^O(``!,````"\P``"````!;S```+````'_,`
M``H````K\P``%````#;S```R````2_,```L```!^\P``!0```(KS```%````
MD/,``!4```"6\P``#````*SS```7````N?,```\```#1\P``!````.'S```*
M````YO,```D```#Q\P``"P```/OS```.````!_0```4````6]```!````!ST
M```4````(?0```T````V]```,@```$3T``!%````=_0``!(```"]]```%P``
M`-#T```>````Z/0``!0````']0``!0```!SU```4````(O4```<````W]0``
M#@```#_U```J````3O4```8```!Y]0``#````(#U```-````C?4``!$```";
M]0``%0```*WU```+````P_4``#8```#/]0``"@````;V```B````$?8```L`
M```T]@``#P```$#V```R````4/8``!L```"#]@``!0```)_V```.````I?8`
M`!,```"T]@``$0```,CV```'````VO8``!$```#B]@``!P```/3V```4````
M_/8``!@````1]P``!P```"KW```%````,O<```P````X]P``#````$7W```2
M````4O<```0```!E]P``!P```&KW```*````<O<```L```!]]P``#````(GW
M```.````EO<```X```"E]P``!0```+3W```%````NO<``"X```#`]P``)@``
M`._W```C````%O@```,````Z^```$@```#[X```&````4?@``!X```!8^```
M&````'?X```9````D/@``"4```"J^```#0```-#X```)````WO@```,```#H
M^```!P```.SX```*````]/@```(```#_^```#`````+Y```5````#_D```L`
M```E^0``&0```#'Y```@````2_D``!(```!L^0``!0```'_Y```*````A?D`
M`!4```"0^0``$@```*;Y```,````N?D```0```#&^0``!P```,OY```,````
MT_D``%(```#@^0``%P```#/Z```'````2_H```8```!3^@``#@```%KZ```-
M````:?H``!$```!W^@``#````(GZ```,````EOH```T```"C^@``%0```+'Z
M```2````Q_H```\```#:^@``%````.KZ```;````__H``!`````;^P``)P``
M`"S[```E````5/L``&D```!Z^P``&@```.3[```7````__L``!D````7_```
M&@```#'\```E````3/P``"@```!R_```)P```)O\```:````P_P``!<```#>
M_```&P```/;\```T````$OT``"4```!'_0``&0```&W]```?````A_T``!,`
M``"G_0``"````+O]```'````Q/T```@```#,_0``"0```-7]```5````W_T`
M``T```#U_0``$P````/^```#````%_X``$8````;_@``/P```&+^```W````
MHOX``%<```#:_@``'P```#+_```O````4O\```H```""_P``$````(W_```(
M````GO\```T```"G_P``+0```+7_```$````X_\```@```#H_P``#0```/'_
M```*````__\``$\````*``$`)0```%H``0`<````@``!``L```"=``$`'P``
M`*D``0`=````R0`!`"4```#G``$`(`````T!`0`D````+@$!`"````!3`0$`
M"P```'0!`0`'````@`$!``T```"(`0$`#````)8!`0`&````HP$!`#D```"J
M`0$`#````.0!`0`'````\0$!``D```#Y`0$`$P````,"`0`)````%P(!``0`
M```A`@$`$````"8"`0`(````-P(!``@```!``@$`!````$D"`0`+````3@(!
M``P```!:`@$`$0```&<"`0`,````>0(!`!H```"&`@$`#P```*$"`0`'````
ML0(!``T```"Y`@$`#@```,<"`0`4````U@(!``X```#K`@$`!P```/H"`0`,
M`````@,!`!L````/`P$`+````"L#`0`3````6`,!`!P```!L`P$`*````(D#
M`0`&````L@,!``<```"Y`P$`$P```,$#`0`%````U0,!``0```#;`P$`%P``
M`.`#`0`Y````^`,!``H````R!`$`#````#T$`0`)````2@0!``8```!4!`$`
M"0```%L$`0`(````900!``D```!N!`$`"@```'@$`0`1````@P0!``8```"5
M!`$`#@```)P$`0`.````JP0!``T```"Z!`$`"P```,@$`0`=````U`0!``L`
M``#R!`$``@```/X$`0`'`````04!``8````)!0$`"0```!`%`0`'````&@4!
M`!L````B!0$`.P```#X%`0`H````>@4!`!4```"C!0$`!0```+D%`0`'````
MOP4!``@```#'!0$`!P```-`%`0`%````V`4!``<```#>!0$`#@```.8%`0`)
M````]04!``8```#_!0$`"`````8&`0`+````#P8!``<````;!@$`"````",&
M`0`'````+`8!`!8````T!@$`"0```$L&`0`&````508!``L```!<!@$`'```
M`&@&`0`4````A08!``<```":!@$`"````*(&`0`#````JP8!``@```"O!@$`
M%````+@&`0`%````S08!`!````#3!@$`$````.0&`0`&````]08!`!D```#\
M!@$`"@```!8'`0`<````(0<!``<````^!P$`!0```$8'`0`0````3`<!`!0`
M``!=!P$`"P```'('`0`-````?@<!`!<```",!P$`!````*0'`0`)````J0<!
M``H```"S!P$`!P```+X'`0`"````Q@<!``X```#)!P$`"````-@'`0`?````
MX0<!`",````!"`$`.````"4(`0`Q````7@@!`"<```"0"`$`*````+@(`0!D
M````X0@!`!0```!&"0$`50```%L)`0`X````L0D!`"D```#J"0$`2@```!0*
M`0!;````7PH!`"@```"["@$`.````.0*`0`H````'0L!`"P```!&"P$`)P``
M`',+`0`;````FPL!`#X```"W"P$`J0$``/8+`0`C````H`T!`!<```#$#0$`
M2````-P-`0"%````)0X!`#````"K#@$`00```-P.`0!;````'@\!`$D```!Z
M#P$`'0```,0/`0`8````X@\!`"$```#[#P$`'P```!T0`0`K````/1`!`"$`
M``!I$`$`'0```(L0`0`1````J1`!`#,```"[$`$`)0```.\0`0`G````%1$!
M`"8````]$0$`'P```&01`0`P````A!$!`,P```"U$0$`:0```((2`0`]````
M[!(!`&4````J$P$`30```)`3`0!>````WA,!`"<````]%`$`+````&44`0`H
M````DA0!`"\```"[%`$`+@```.L4`0`I````&A4!`#````!$%0$`5````'45
M`0!:````RA4!`$@````E%@$`2@```&X6`0`J````N18!`"(```#D%@$`,@``
M``<7`0`O````.A<!`"P```!J%P$`+0```)<7`0!Q````Q1<!`&\````W&`$`
MLP```*<8`0`7````6QD!`"4```!S&0$`,@```)D9`0`I````S!D!`#X```#V
M&0$`(@```#4:`0!2````6!H!`"(```"K&@$`)0```,X:`0`+````]!H!`+$`
M````&P$`10```+(;`0`A````^!L!`#8````:'`$`,````%$<`0`E````@AP!
M`!P```"H'`$`,0```,4<`0`'````]QP!``<```#_'`$`!`````<=`0`-````
M#!T!``L````:'0$`#@```"8=`0`+````-1T!``4```!!'0$`$````$<=`0`"
M````6!T!`%D```!;'0$`!0```+4=`0`2````NQT!``0```#.'0$`!P```-,=
M`0`(````VQT!``4```#D'0$``P```.H=`0`0````[AT!``P```#_'0$`$P``
M``P>`0`-````(!X!``(````N'@$`!P```#$>`0`&````.1X!`!0```!`'@$`
M#````%4>`0`8````8AX!``8```!['@$`$@```((>`0`,````E1X!``,```"B
M'@$`*@```*8>`0`$````T1X!``8```#6'@$`!P```-T>`0`?````Y1X!`#4`
M```%'P$`+@```#L?`0`O````:A\!`!<```":'P$`(````+(?`0`;````TQ\!
M`!@```#O'P$`)`````@@`0`?````+2`!`!H```!-(`$`(````&@@`0`:````
MB2`!`#(```"D(`$`+P```-<@`0`K````!R$!`!\````S(0$`(P```%,A`0`?
M````=R$!`!H```"7(0$`)0```+(A`0`F````V"$!`"4```#_(0$`)````"4B
M`0`8````2B(!`!T```!C(@$`)````($B`0`8````IB(!`"(```"_(@$`)0``
M`.(B`0`\````"",!`!\```!%(P$`(P```&4C`0`?````B2,!`"````"I(P$`
M&@```,HC`0`8````Y2,!`"8```#^(P$`'@```"4D`0`I````1"0!`!X```!N
M)`$`"0```(TD`0`,````ER0!`!<```"D)`$`+P```+PD`0`D````["0!``<`
M```1)0$`#P```!DE`0`4````*24!``X````^)0$`#0```$TE`0`D````6R4!
M``4```"`)0$`!P```(8E`0`B````CB4!`"4```"Q)0$`'0```-<E`0`:````
M]24!``<````0)@$`QP```!@F`0`+````X"8!`!4```#L)@$`!@````(G`0`)
M````"2<!``L````3)P$`%P```!\G`0`&````-R<!`#,````^)P$`$P```'(G
M`0`3````AB<!``<```":)P$`#P```*(G`0`'````LB<!`#(```"Z)P$`(0``
M`.TG`0`3````#R@!``P````C*`$`$0```#`H`0`R````0B@!``@```!U*`$`
M"0```'XH`0`*````B"@!`!0```"3*`$`"@```*@H`0`=````LR@!``@```#1
M*`$`'P```-HH`0`(````^B@!`!H````#*0$`!@```!XI`0`5````)2D!``<`
M```[*0$`"````$,I`0`)````3"D!`#\```!6*0$`$@```)8I`0`'````J2D!
M``\```"Q*0$`#@```,$I`0`0````T"D!``D```#A*0$`"0```.LI`0`(````
M]2D!`!,```#^*0$`!P```!(J`0`,````&BH!`!D````G*@$`"@```$$J`0`;
M````3"H!`!<```!H*@$`%````(`J`0`*````E2H!``P```"@*@$`%P```*TJ
M`0`$````Q2H!`"H```#**@$`$0```/4J`0`'````!RL!``(````/*P$`$```
M`!(K`0`8````(RL!``L````\*P$``P```$@K`0`(````3"L!``L```!5*P$`
M!@```&$K`0`'````:"L!``T```!P*P$`"P```'XK`0`4````BBL!`!4```"?
M*P$`#@```+4K`0`O````Q"L!`"````#T*P$`'````!4L`0`,````,BP!`#$`
M```_+`$`!0```'$L`0`2````=RP!`#\```"*+`$`$@```,HL`0`*````W2P!
M``8```#H+`$`!````.\L`0`$````]"P!`!,```#Y+`$`!0````TM`0`&````
M$RT!``8````:+0$`!````"$M`0`,````)BT!``D````S+0$`#````#TM`0`*
M````2BT!`!````!5+0$`$P```&8M`0`%````>BT!`!@```"`+0$`&0```)DM
M`0`?````LRT!`!T```#3+0$`$0```/$M`0`"`````RX!``0````&+@$`"@``
M``LN`0`&````%BX!``4````=+@$``P```",N`0`,````)RX!`$4````T+@$`
M&@```'HN`0`U````E2X!`"@```#++@$`4P```/0N`0`P````2"\!`"\```!Y
M+P$`&0```*DO`0!R````PR\!`"`````V,`$`-0```%<P`0!%````C3`!`#``
M``#3,`$`)@````0Q`0`>````*S$!`"@```!*,0$`*0```',Q`0`I````G3$!
M`"8```#',0$`)0```.XQ`0`H````%#(!`"@````],@$`(@```&8R`0`N````
MB3(!`#````"X,@$`$@```.DR`0`3````_#(!`!`````0,P$`>0```"$S`0`)
M````FS,!`',```"E,P$`?````!DT`0`K````EC0!`!<```#"-`$`%@```-HT
M`0`/````\30!`!\````!-0$`'P```"$U`0`<````034!`%$```!>-0$`%```
M`+`U`0`*````Q34!``4```#0-0$`!@```-8U`0`(````W34!``4```#F-0$`
M$@```.PU`0`0````_S4!`!,````0-@$`'0```"0V`0`/````0C8!``H```!2
M-@$`#P```%TV`0`'````;38!``0```!U-@$`"0```'HV`0`'````A#8!``L`
M``",-@$`!P```)@V`0`%````H#8!`!0```"F-@$`#@```+LV`0`'````RC8!
M``@```#2-@$`#P```-LV`0`(````ZS8!``P```#T-@$`#P````$W`0`6````
M$3<!``<````H-P$`!@```#`W`0`4````-S<!``8```!,-P$`#````%,W`0`(
M````8#<!``0```!I-P$`"@```&XW`0`+````>3<!``P```"%-P$`#````)(W
M`0`'````GS<!``0```"G-P$`&0```*PW`0`"````QC<!``D```#)-P$`!@``
M`-,W`0`&````VC<!`"<```#A-P$`!`````DX`0`/````#C@!`!,````>.`$`
M!P```#(X`0`'````.C@!``8```!".`$`!@```$DX`0`0````4#@!`!(```!A
M.`$`!@```'0X`0`)````>S@!`"(```"%.`$`!P```*@X`0`'````L#@!``L`
M``"X.`$`!0```,0X`0`"````RC@!``L```#-.`$`8P$``-DX`0`3````/3H!
M``\```!1.@$`"@```&$Z`0`+````;#H!``0```!X.@$`)0```'TZ`0`G````
MHSH!``L```#+.@$`$P```-<Z`0`.````ZSH!``\```#Z.@$`!0````H[`0`H
M````$#L!``X````Y.P$`&0```$@[`0`.````8CL!``X```!Q.P$`"P```(`[
M`0`B````C#L!``T```"O.P$`"@```+T[`0`1````R#L!`!````#:.P$`"P``
M`.L[`0`0````]SL!``\````(/`$`!@```!@\`0`2````'SP!`!@````R/`$`
M$````$L\`0`/````7#P!``\```!L/`$`!P```'P\`0`O````A#P!`"X```"T
M/`$`*````.,\`0`^````##T!`$T```!+/0$`:````)D]`0!K`````CX!`&X`
M``!N/@$`<0```-T^`0!`````3S\!`!0```"0/P$`!0```*4_`0`&````JS\!
M`!````"R/P$`!P```,,_`0`3````RS\!``D```#?/P$`"0```.D_`0`R````
M\S\!`#`````F0`$`$0```%=``0`1````:4`!``X```![0`$`%0```(I``0`5
M````H$`!``\```"V0`$`%@```,9``0`5````W4`!`!L```#S0`$`#P````]!
M`0`6````'T$!``X````V00$`+0```$5!`0`-````<T$!`!<```"!00$`&P``
M`)E!`0`3````M4$!`"H```#)00$`!0```/1!`0`/````^D$!``\````*0@$`
M'0```!I"`0`Q````.$(!``8```!J0@$`#````'%"`0`1````?D(!``H```"0
M0@$`!P```)M"`0`(````HT(!``4```"L0@$`"0```+)"`0`+````O$(!``0`
M``#(0@$`(````,U"`0`,````[D(!``P```#[0@$`$`````A#`0`:````&4,!
M`"P````T0P$`"@```&%#`0`*````;$,!`!P```!W0P$`&P```)1#`0`@````
ML$,!`!<```#10P$`%@```.E#`0`3`````$0!`!`````41`$`'P```"5$`0`'
M````140!``8```!-1`$`"````%1$`0`.````740!``@```!L1`$`"@```'5$
M`0`2````@$0!``H```"31`$`%0```)Y$`0`8````M$0!``H```#-1`$`!0``
M`-A$`0`7````WD0!`!8```#V1`$`"P````U%`0`G````&44!`#P```!!10$`
M0@```'Y%`0`*````P44!``<```#,10$`$P```-1%`0`%````Z$4!``4```#N
M10$`"0```/1%`0`0````_D4!``L````/1@$`%0```!M&`0!%````,48!`!$`
M``!W1@$`,@```(E&`0`Q````O$8!`"X```#N1@$`+P```!U'`0`*````34<!
M``@```!81P$`"0```&%'`0`*````:T<!`#(```!V1P$`.````*E'`0`Q````
MXD<!`%<````42`$`,````&Q(`0`P````G4@!`#````#.2`$`1@```/](`0`T
M````1DD!`#,```![20$`,````*])`0`V````X$D!`!4````72@$`&0```"U*
M`0`N````1TH!`"0```!V2@$`$P```)M*`0`,````KTH!``P```"\2@$`"P``
M`,E*`0`0````U4H!`!@```#F2@$`'0```/]*`0`'````'4L!``<````E2P$`
M%@```"U+`0`*````1$L!``@```!/2P$`"0```%A+`0`0````8DL!``L```!S
M2P$`!@```']+`0`&````ADL!`!,```"-2P$`!0```*%+`0`'````ITL!``8`
M``"O2P$`&P```+9+`0`*````TDL!`"P```#=2P$`$`````I,`0`(````&TP!
M``,````D3`$`!P```"A,`0`)````,$P!``0````Z3`$`"@```#],`0`&````
M2DP!`!4```!13`$`!@```&=,`0`(````;DP!``D```!W3`$`#0```(%,`0`(
M````CTP!`"$```"83`$`$0```+I,`0`)````S$P!`!$```#63`$`#````.A,
M`0`'````]4P!`!,```#]3`$``P```!%-`0`#````%4T!`!4````930$``P``
M`"]-`0`4````,TT!``8```!(30$`!````$]-`0`(````5$T!``@```!=30$`
M4@```&9-`0`F````N4T!``8```#@30$`"````.=-`0`8````\$T!`"(````)
M3@$`)0```"Q.`0`P````4DX!`"0```"#3@$`*@```*A.`0!Z````TTX!`#4`
M``!.3P$`"@```(1/`0`)````CT\!`!4```"93P$`#P```*]/`0`-````OT\!
M`!````#-3P$`$0```-Y/`0`0````\$\!``X````!4`$`#0```!!0`0`6````
M'E`!``8````U4`$`'0```#Q0`0`>````6E`!`!(```!Y4`$`$0```(Q0`0`&
M````GE`!``@```"E4`$`80```*Y0`0`(````$%$!`!,````940$`%@```"U1
M`0`%````1%$!``4```!*40$`'@```%!1`0`;````;U$!`!,```"+40$`%P``
M`)]1`0`2````MU$!`!,```#*40$`+````-Y1`0`0````"U(!`"0````<4@$`
M!@```$%2`0`4````2%(!`!$```!=4@$`#0```&]2`0`2````?5(!`!8```"0
M4@$`$P```*=2`0`,````NU(!``8```#(4@$`!P```,]2`0`8````UU(!`!$`
M``#P4@$`"`````)3`0`%````"U,!``T````14P$`#0```!]3`0`)````+5,!
M``L````W4P$`"P```$-3`0`&````3U,!`!@```!64P$`+````&]3`0`(````
MG%,!``T```"E4P$`"0```+-3`0`-````O5,!``<```#+4P$`!P```--3`0`-
M````VU,!``D```#I4P$`"0```/-3`0`;````_5,!``\````95`$`$P```"E4
M`0`%````/50!`"@```!#5`$`$P```&Q4`0`4````@%0!`!8```"55`$`$@``
M`*Q4`0`X````OU0!`$<```#X5`$`(@```$!5`0`;````8U4!`!4```!_50$`
M-0```)55`0`(````RU4!``T```#450$`!@```.)5`0`(````Z54!`!````#R
M50$`"@````-6`0`)````#E8!`!T````85@$`(@```#96`0`@````658!`"4`
M``!Z5@$`'````*!6`0`M````O58!`!\```#K5@$`(P````M7`0`<````+U<!
M`!\```!,5P$`'@```&Q7`0`I````BU<!`#(```"U5P$`)````.A7`0`K````
M#5@!`#<````Y6`$`/0```'%8`0`3````KU@!`"@```##6`$`$@```.Q8`0#$
M````_U@!`!0```#$60$`'@```-E9`0`E````^%D!`"<````>6@$`(P```$9:
M`0`B````:EH!`"$```"-6@$`)````*]:`0`C````U%H!`!P```#X6@$`)P``
M`!5;`0!'````/5L!``T```"%6P$`!````)-;`0`)````F%L!``T```"B6P$`
M#P```+!;`0`.````P%L!``<```#/6P$`#P```-=;`0`0````YUL!``<```#X
M6P$`!`````!<`0`,````!5P!``X````27`$`"P```"%<`0`2````+5P!``T`
M``!`7`$`+@```$Y<`0`'````?5P!`!````"%7`$`!@```)9<`0`3````G5P!
M`!D```"Q7`$`&P```,M<`0`5````YUP!``(```#]7`$`"0````!=`0`0````
M"ET!``4````;70$`#P```"%=`0`.````,5T!``,```!`70$`$````$1=`0`(
M````55T!`!$```!>70$`%0```'!=`0`/````AET!`!0```"670$`&@```*M=
M`0`*````QET!``L```#170$`%````-U=`0`1````\ET!`!$````$7@$`&@``
M`!9>`0`3````,5X!``T```!%7@$`#P```%->`0`I````8UX!`!P```"-7@$`
M#0```*I>`0`D````N%X!`!H```#=7@$`&````/A>`0`3````$5\!``L````E
M7P$`"@```#%?`0`(````/%\!``@```!%7P$`%@```$Y?`0`D````95\!`"T`
M``"*7P$`#````+A?`0`(````Q5\!`"$```#.7P$`"@```/!?`0`9````^U\!
M`!H````58`$`"0```#!@`0`5````.F`!``X```!08`$`'0```%]@`0`/````
M?6`!`!D```"-8`$`"````*=@`0`0````L&`!`"8```#!8`$`+0```.A@`0`]
M````%F$!``@```!480$`%@```%UA`0`-````=&$!`#(```""80$`#@```+5A
M`0`/````Q&$!``4```#480$`!@```-IA`0`#````X6$!``<```#E80$`"```
M`.UA`0`-````]F$!``X````$8@$`#@```!-B`0`0````(F(!`!D````S8@$`
M%P```$UB`0`5````96(!`!<```![8@$`"0```)-B`0`&````G6(!``L```"D
M8@$`"@```+!B`0`"````NV(!``8```"^8@$`"P```,5B`0`C````T6(!`!8`
M``#U8@$`"0````QC`0`-````%F,!``\````D8P$`#P```#1C`0`^````1&,!
M`"8```"#8P$`"````*IC`0`/````LV,!`(L```##8P$`'@```$]D`0`:````
M;F0!`!(```")9`$`!P```)QD`0`$````I&0!`!<```"I9`$`!P```,%D`0`(
M````R60!``<```#29`$`!@```-ID`0`/````X60!``X```#Q9`$`$`````!E
M`0`.````$64!``\````@90$`#````#!E`0`+````/64!`!$```!)90$`"0``
M`%ME`0`*````964!``X```!P90$`+@```']E`0`+````KF4!``@```"Z90$`
M"@```,-E`0`4````SF4!`"P```#C90$`*P```!!F`0`.````/&8!`!0```!+
M9@$`)@```&!F`0`A````AV8!`",```"I9@$`&0```,UF`0`=````YV8!`"D`
M```%9P$`*````"]G`0`=````6&<!`!X```!V9P$`+````)5G`0`K````PF<!
M`"$```#N9P$`)````!!H`0`$````-6@!`!P````Z:`$`#P```%=H`0`#````
M9V@!``@```!K:`$`"0```'1H`0`+````?F@!``P```"*:`$`!````)=H`0`<
M````G&@!`!X```"Y:`$`#0```-AH`0`,````YF@!``X```#S:`$`#0````)I
M`0`G````$&D!``<````X:0$`!@```$!I`0`'````1VD!``P```!/:0$`"```
M`%QI`0`/````96D!`!4```!U:0$`!P```(MI`0`'````DVD!``0```";:0$`
M$P```*!I`0`)````M&D!``<```"^:0$`,````,9I`0`7````]VD!`((````/
M:@$`%P```))J`0`+````JFH!``<```"V:@$`"P```+YJ`0`(````RFH!``H`
M``#3:@$`!@```-YJ`0`*````Y6H!``(```#P:@$`!@```/-J`0`)````^FH!
M`!D````$:P$`#````!YK`0`,````*VL!``\````X:P$`'````$AK`0`#````
M96L!``<```!I:P$`%@```'%K`0`*````B&L!``X```"3:P$`!0```*)K`0`S
M````J&L!``8```#<:P$`!@```.-K`0`8````ZFL!`!$````#;`$`!P```!5L
M`0`)````'6P!``4````G;`$`"0```"UL`0`(````-VP!`!$```!`;`$``@``
M`%)L`0`&````56P!``T```!<;`$`"P```&IL`0`+````=FP!`!,```"";`$`
M"0```)9L`0`'````H&P!``4```"H;`$`#````*YL`0`?````NVP!``<```#;
M;`$`"@```.-L`0`$````[FP!``D```#S;`$`"````/UL`0`,````!FT!``H`
M```3;0$`!@```!YM`0`-````)6T!``8````S;0$`!````#IM`0!`````/VT!
M`$0```"`;0$`0@```,5M`0`A````"&X!``4````J;@$`#P```#!N`0`%````
M0&X!``,```!&;@$`(0```$IN`0`8````;&X!``8```"%;@$`!````(QN`0`;
M````D6X!``8```"M;@$`"````+1N`0`B````O6X!``0```#@;@$`!0```.5N
M`0`7````ZVX!``0````#;P$`#0````AO`0`2````%F\!``P````I;P$`#P``
M`#9O`0`0````1F\!`!H```!7;P$`"````')O`0`)````>V\!``4```"%;P$`
M/0```(MO`0`V````R6\!`#L`````<`$`*@```#QP`0`X````9W`!`#H```"@
M<`$`+0```-MP`0!2````"7$!`#````!<<0$`.0```(UQ`0`I````QW$!`!``
M``#Q<0$`&`````)R`0`,````&W(!`"0````H<@$`)````$UR`0`B````<G(!
M`"$```"5<@$`"P```+=R`0`-````PW(!``H```#1<@$`"0```-QR`0`B````
MYG(!`"@````)<P$`*````#)S`0`$````6W,!``@```!@<P$`&@```&ES`0`S
M````A',!`!@```"X<P$`$@```-%S`0`'````Y',!`!,```#L<P$`%@````!T
M`0`0````%W0!`%$````H=`$`D0```'IT`0"$````#'4!`!<```"1=0$`#@``
M`*EU`0`/````N'4!`!0```#(=0$`%0```-UU`0`1````\W4!``P````%=@$`
M'0```!)V`0`3````,'8!`"$```!$=@$`%0```&9V`0`5````?'8!``\```"2
M=@$`(@```*)V`0`I````Q78!`(T```#O=@$`%````'UW`0`%````DG<!`!8`
M``"8=P$`"0```*]W`0`$````N7<!``H```"^=P$`$0```,EW`0`3````VW<!
M``X```#O=P$`$````/YW`0`4````#W@!`"<````D>`$`*0```$QX`0`E````
M=G@!`"4```"<>`$`,````,)X`0`P````\W@!`!T````D>0$`10```$)Y`0`/
M````B'D!`!$```"8>0$`$0```*IY`0`3````O'D!`!(```#0>0$`%0```.-Y
M`0`7````^7D!``\````1>@$`$0```"%Z`0`Y````,WH!`!T```!M>@$`%P``
M`(MZ`0`Z````HWH!`!,```#>>@$`!P```/)Z`0`-````^GH!``L````(>P$`
M(@```!1[`0`2````-WL!`!4```!*>P$`$@```&![`0`9````<WL!`!D```"-
M>P$`$````*=[`0`0````N'L!`!0```#)>P$`'````-Y[`0`2````^WL!``X`
M```.?`$`$0```!U\`0`>````+WP!`"0```!.?`$`%@```'-\`0`2````BGP!
M`!<```"=?`$`$P```+5\`0`7````R7P!``H```#A?`$`(````.Q\`0`$````
M#7T!``<````2?0$`"@```!I]`0`8````)7T!``8````^?0$`"````$5]`0`'
M````3GT!``8```!6?0$`!P```%U]`0`'````97T!``4```!M?0$`%````'-]
M`0`&````B'T!``@```"/?0$`!````)A]`0`$````G7T!``D```"B?0$`%0``
M`*Q]`0`2````PGT!``\```#5?0$`$````.5]`0`*````]GT!`!,````!?@$`
M!0```!5^`0`G````&WX!``X```!#?@$`#0```%)^`0`3````8'X!``T```!T
M?@$`"P```()^`0`.````CGX!`#,```"=?@$`"````-%^`0`(````VGX!`"<`
M``#C?@$`%`````M_`0`1````('\!``<````R?P$`"0```#I_`0!7````1'\!
M``<```"<?P$`!````*1_`0`@````J7\!``T```#*?P$`$````-A_`0`*````
MZ7\!`!````#T?P$`$@````6``0`6````&(`!`!T````O@`$`&0```$V``0`'
M````9X`!``<```!O@`$`!@```'>``0`8````?H`!``<```"7@`$`!0```)^`
M`0`*````I8`!``X```"P@`$`!P```+^``0`'````QX`!`!T```#/@`$`#0``
M`.V``0`,````^X`!``P````(@0$`$@```!6!`0`,````*($!``\````U@0$`
M%P```$6!`0`-````78$!`!````!K@0$`"````'R!`0`$````A8$!`!````"*
M@0$`00```)N!`0`%````W8$!``P```#C@0$`!0```/"!`0`A````]H$!``T`
M```8@@$`&0```":"`0`*````0((!``T```!+@@$`"@```%F"`0`(````9((!
M``X```!M@@$`"@```'R"`0`1````AX(!`!(```"9@@$`+P```*R"`0`*````
MW((!``@```#G@@$`"````/""`0`,````^8(!`!8````&@P$`!P```!V#`0`)
M````)8,!``@````O@P$`#````#B#`0!.````18,!`!,```"4@P$`"P```*B#
M`0`&````M(,!``0```"[@P$`%@```,"#`0`7````UX,!`!@```#O@P$`"0``
M``B$`0`"````$H0!``0````5A`$`(@```!J$`0`#````/80!``4```!!A`$`
M,P```$>$`0`*````>X0!``4```"&A`$`!@```(R$`0`-````DX0!``T```"A
MA`$`!@```*^$`0`(````MH0!``D```"_A`$`!````,F$`0`%````SH0!`&(`
M``#4A`$`"P```#>%`0`-````0X4!``4```!1A0$`!0```%>%`0`F````784!
M`#<```"$A0$`$0```+R%`0`*````SH4!`!$```#9A0$`%0```.N%`0`*````
M`88!``D````,A@$`'````!:&`0`G````,X8!`"T```!;A@$`+````(F&`0`/
M````MH8!`!@```#&A@$``P```-^&`0`'````XX8!``L```#KA@$`!0```/>&
M`0`*````_88!`!(````(AP$`!P```!N'`0!I````(X<!`!$```"-AP$`"P``
M`)^'`0`*````JX<!`!\```"VAP$`30```-:'`0`'````)(@!``@````LB`$`
M!@```#6(`0`?````/(@!``8```!<B`$`"0```&.(`0`M````;8@!`"P```";
MB`$`"P```,B(`0`&````U(@!``H```#;B`$`*P```.:(`0`E````$HD!`&$`
M```XB0$`%@```)J)`0`H````L8D!`!4```#:B0$``@```/")`0`.````\XD!
M`!`````"B@$`"0```!.*`0`/````'8H!``H````MB@$`&0```#B*`0`'````
M4HH!`!<```!:B@$`!@```'**`0`(````>8H!``T```""B@$`"P```)"*`0`*
M````G(H!``D```"GB@$`&@```+&*`0`'````S(H!`!8```#4B@$`%````.N*
M`0`3`````(L!``L````4BP$`#````""+`0`*````+8L!``L````XBP$`"@``
M`$2+`0`,````3XL!``H```!<BP$`"P```&>+`0`*````<XL!``H```!^BP$`
M$@```(F+`0`=````G(L!`$@```"ZBP$`%`````.,`0`,````&(P!``P````E
MC`$`$@```#*,`0`%````18P!`"4```!+C`$`!````'&,`0`+````=HP!``<`
M``""C`$`!0```(J,`0`%````D(P!`!@```"6C`$`"0```*^,`0`3````N8P!
M`!(```#-C`$`&@```.",`0`6````^XP!`!@````2C0$`%P```"N-`0`7````
M0XT!`!X```!;C0$`&````'J-`0`'````DXT!``4```";C0$`#P```*&-`0`0
M````L8T!``L```#"C0$`"P```,Z-`0`A````VHT!``T```#\C0$`%0````J.
M`0`&````((X!``T````GC@$`"````#6.`0`/````/HX!``D```!.C@$`!P``
M`%B.`0`%````8(X!``<```!FC@$`!0```&Z.`0`$````=(X!``,```!YC@$`
M'P```'V.`0`:````G8X!`#\```"XC@$`.0```/B.`0`3````,H\!`"P```!&
MCP$`,@```'./`0`1````IH\!`#H```"XCP$`+@```/./`0`S````(I`!`#,`
M``!6D`$`.P```(J0`0`6````QI`!`!(```#=D`$`&@```/"0`0`5````"Y$!
M`!T````AD0$`%@```#^1`0`4````5I$!`!4```!KD0$`&0```(&1`0`R````
MFY$!`#(```#.D0$`-0````&2`0`S````-Y(!`#0```!KD@$`,0```*"2`0!K
M````TI(!`!T````^DP$`#@```%R3`0`+````:Y,!`#````!WDP$`+P```*B3
M`0`9````V),!`",```#RDP$`#````!:4`0!)````(Y0!`$(```!ME`$`!```
M`+"4`0`0````M90!`!P```#&E`$`#@```..4`0`3````\I0!``@````&E0$`
M"0````^5`0`'````&94!``D````AE0$`#@```"N5`0`5````.I4!``X```!0
ME0$`$0```%^5`0`(````<94!`!P```!ZE0$`"````)>5`0`%````H)4!`!``
M``"FE0$`#P```+>5`0`<````QY4!``P```#DE0$`/P```/&5`0`"````,98!
M``8````TE@$`#@```#N6`0`5````2I8!``8```!@E@$`!P```&>6`0`0````
M;Y8!``<```"`E@$`!````(B6`0`Q````C98!`!L```"_E@$`(@```-N6`0!8
M````_I8!`!@```!7EP$`2````'"7`0`C````N9<!`!````#=EP$`!@```.Z7
M`0`.````]9<!``\````$F`$`#````!28`0`3````(9@!``L````UF`$`'0``
M`$&8`0`:````7Y@!``8```!ZF`$`$0```(&8`0`-````DY@!``\```"AF`$`
M)@```+&8`0`9````V)@!`!,```#RF`$`%`````:9`0`@````&YD!``@````\
MF0$`"0```$69`0`9````3YD!`!(```!IF0$`&0```'R9`0`*````EID!``P`
M``"AF0$`"````*Z9`0`%````MYD!`!T```"]F0$`!@```-N9`0`2````XID!
M``@```#UF0$`%````/Z9`0`*````$YH!`!(````>F@$`,````#&:`0`:````
M8IH!``L```!]F@$`#````(F:`0`A````EIH!``<```"XF@$`%@```,":`0`#
M````UYH!`!@```#;F@$`!@```/2:`0`'````^YH!`"$````#FP$`,0```"6;
M`0`%````5YL!`!$```!=FP$`$0```&^;`0`-````@9L!`!<```"/FP$`!```
M`*>;`0`*````K)L!``P```"WFP$`"````,2;`0`&````S9L!``X```#4FP$`
M"````..;`0`&````[)L!``H```#SFP$`%P```/Z;`0`T````%IP!`#0```!+
MG`$`(@```("<`0`S````HYP!`"````#7G`$`1P```/B<`0`=````0)T!`"X`
M``!>G0$`+````(V=`0`E````NIT!``4```#@G0$`"````.:=`0`)````[YT!
M``@```#YG0$`(0````*>`0`<````))X!`#````!!G@$`(P```'*>`0`Q````
MEIX!`#8```#(G@$`"0```/^>`0`8````"9\!``L````BGP$`"@```"Z?`0`K
M````.9\!``T```!EGP$`$@```'.?`0`/````AI\!``T```"6GP$`"````*2?
M`0`4````K9\!``D```#"GP$`#````,R?`0`0````V9\!`!L```#JGP$`+```
M``:@`0`+````,Z`!``8````_H`$`!0```$:@`0`6````3*`!``L```!CH`$`
M'0```&^@`0`4````C:`!``4```"BH`$`"P```*B@`0`*````M*`!``@```"_
MH`$`#@```,B@`0`*````UZ`!``4```#BH`$`%@```.B@`0`.````_Z`!`$4`
M```.H0$`8@```%2A`0`4````MZ$!`!P```#,H0$`(P```.FA`0`9````#:(!
M``4````GH@$`%````"VB`0`+````0J(!`!(```!.H@$`+@```&&B`0`+````
MD*(!`!````"<H@$`$0```*VB`0`2````OZ(!`!L```#2H@$`$````.ZB`0!)
M````_Z(!``P```!)HP$`)````%:C`0`5````>Z,!`!<```"1HP$`/0```*FC
M`0`A````YZ,!``H````)I`$`$````!2D`0`3````):0!`!T````YI`$`"@``
M`%>D`0`1````8J0!``<```!TI`$`&````'RD`0`7````E:0!``@```"MI`$`
M!@```+:D`0`+````O:0!``\```#)I`$`%````-FD`0`#````[J0!``@```#R
MI`$`"P```/ND`0`2````!Z4!`!,````:I0$`$0```"ZE`0`1````0*4!``8`
M``!2I0$`"0```%FE`0`W````8Z4!`#````";I0$`+0```,RE`0`'````^J4!
M`!,````"I@$`!@```!:F`0`C````':8!`!@```!!I@$`&P```%JF`0`G````
M=J8!``T```">I@$`"0```*RF`0`#````MJ8!``8```"ZI@$`"@```,&F`0`"
M````S*8!``D```#/I@$`$0```-FF`0`(````ZZ8!`!4```#TI@$`&P````JG
M`0`4````)J<!``4````[IP$`"@```$&G`0`4````3*<!`!$```!AIP$`#```
M`'.G`0`'````@*<!``H```"(IP$`#@```).G`0!=````HJ<!`!H`````J`$`
M"@```!NH`0`&````)J@!``P````MJ`$`#@```#JH`0`2````2:@!``D```!<
MJ`$`#@```&:H`0`3````=:@!`"0```")J`$`'0```*ZH`0`4````S*@!`"@`
M``#AJ`$`(`````JI`0`4````*ZD!`#````!`J0$`*@```'&I`0!T````G*D!
M`",````1J@$`&P```#6J`0`<````4:H!`!P```!NJ@$`*@```(NJ`0`S````
MMJH!`"P```#JJ@$`(@```!>K`0`;````.JL!`"4```!6JP$`/0```'RK`0`S
M````NJL!`!D```#NJP$`&P````BL`0`9````)*P!``L````^K`$`!P```$JL
M`0`(````4JP!``D```!;K`$`%````&6L`0`+````>JP!`!,```"&K`$`"0``
M`)JL`0!>````I*P!`$<````#K0$`.````$NM`0!;````A*T!`"$```#@K0$`
M,@````*N`0`*````-:X!`!(```!`K@$`"````%.N`0`2````7*X!`#\```!O
MK@$`"0```*^N`0`.````N:X!`!(```#(K@$`$0```-NN`0!H````[:X!`#``
M``!6KP$`)P```(>O`0`0````KZ\!`"(```#`KP$`)````..O`0`N````"+`!
M`"L````WL`$`+@```&.P`0`Q````DK`!`!````#$L`$`!0```-6P`0`+````
MV[`!``H```#GL`$`"@```/*P`0`L````_;`!``P````JL0$`"0```#>Q`0`,
M````0;$!`!<```!.L0$`"0```&:Q`0`'````<+$!`!,```!XL0$`"0```(RQ
M`0`(````EK$!``8```"?L0$`"P```*:Q`0`+````LK$!`!````"^L0$`#@``
M`,^Q`0`;````WK$!`!````#ZL0$`!P````NR`0`5````$[(!``\````IL@$`
M&````#FR`0`)````4K(!``<```!<L@$`"P```&2R`0`:````<+(!`"D```"+
ML@$`$@```+6R`0`E````R+(!`"<```#NL@$`#P```!:S`0`*````)K,!`!H`
M```QLP$`!@```$RS`0`$````4[,!`!@```!8LP$`10```'&S`0`.````M[,!
M`!````#&LP$`#@```->S`0`%````YK,!``D```#LLP$`"0```/:S`0`)````
M`+0!``D````*M`$`$@```!2T`0`&````)[0!``T````NM`$`!0```#RT`0`)
M````0K0!``L```!,M`$`&@```%BT`0`+````<[0!``(```!_M`$`"0```(*T
M`0`*````C+0!``D```"7M`$`!@```*&T`0`?````J+0!`$0```#(M`$`*@``
M``VU`0`8````.+4!``8```!1M0$`#````%BU`0`*````9;4!``T```!PM0$`
M!@```'ZU`0`*````A;4!`!@```"0M0$`#````*FU`0`-````MK4!``\```#$
MM0$`"P```-2U`0`-````X+4!``@```#NM0$`"@```/>U`0`8`````K8!``D`
M```;M@$`!@```"6V`0`+````++8!`!@````XM@$`'````%&V`0`*````;K8!
M``P```!YM@$``P```(:V`0`+````BK8!`!8```"6M@$`!0```*VV`0`2````
ML[8!`!(```#&M@$`!@```-FV`0`;````X+8!``P```#\M@$`(0````FW`0`%
M````*[<!``4````QMP$`#@```#>W`0`C````1K<!``L```!JMP$`#0```':W
M`0`.````A+<!``4```"3MP$`#````)FW`0`/````IK<!``X```"VMP$``@``
M`,6W`0`/````R+<!``@```#8MP$`*P```.&W`0`D````#;@!`"\````RN`$`
M*````&*X`0`H````B[@!`"D```"TN`$`70```-ZX`0`3````/+D!`%D```!0
MN0$`-````*JY`0`A````W[D!`%X````!N@$`6P```&"Z`0`F````O+H!`#T`
M``#CN@$`,P```"&[`0`W````5;L!`#4```"-NP$`'@```,.[`0`[````XKL!
M`.0!```>O`$`(0````.^`0`4````);X!`%0````ZO@$`@@```(^^`0!"````
M$K\!`#\```!5OP$`<@```)6_`0!2````",`!`"````!;P`$`%0```'S``0`=
M````DL`!`!T```"PP`$`+0```,[``0`>````_,`!`!T````;P0$`$P```#G!
M`0`Z````3<$!`"@```"(P0$`*0```+'!`0`J````V\$!`!@````&P@$`0```
M`!_"`0#<````8,(!`&D````]PP$`.@```*?#`0!C````XL,!`$P```!&Q`$`
MA````)/$`0`L````&,4!`"X```!%Q0$`+````'3%`0`R````H<4!`"T```#4
MQ0$`*P````+&`0`Q````+L8!`%0```!@Q@$`6P```+7&`0!-````$<<!`%$`
M``!?QP$`+@```+''`0`H````X,<!`#0````)R`$`+@```#[(`0`N````;<@!
M`"X```"<R`$`B````,O(`0"&````5,D!`-````#;R0$`$P```*S*`0`F````
MP,H!`#D```#GR@$`+````"'+`0!(````3LL!`"L```"7RP$`3````,/+`0`K
M````$,P!`"`````\S`$`"@```%W,`0#!````:,P!`$<````JS0$`)@```'+-
M`0`W````F<T!`#4```#1S0$`)P````?.`0`D````+\X!`#X```!4S@$`!@``
M`)/.`0`'````FLX!``0```"BS@$`#````*?.`0`+````M,X!``P```#`S@$`
M"P```,W.`0`%````V<X!`!````#?S@$``P```/#.`0!G````],X!``<```!<
MSP$`%0```&3/`0`$````>L\!``<```!_SP$`!@```(?/`0`%````CL\!``D`
M``"4SP$`%0```)[/`0`+````M,\!`!(```#`SP$`#0```-//`0`"````X<\!
M``<```#DSP$`!P```.S/`0`2````],\!``P````'T`$`&````!30`0`&````
M+=`!``X````TT`$`#````$/0`0`#````4-`!`"L```!4T`$`!````(#0`0`'
M````A=`!``@```"-T`$`*P```);0`0!'````PM`!`#H````*T0$`.P```$71
M`0`B````@=$!`"T```"DT0$`(P```-+1`0`F````]M$!`"H````=T@$`)0``
M`$C2`0`C````;M(!`"P```"2T@$`(0```+_2`0`\````X=(!`#H````>TP$`
M-0```%G3`0`K````C],!`"X```"[TP$`+@```.K3`0`I````&=0!`"X```!#
MU`$`*P```'+4`0`P````GM0!`"X```#/U`$`*0```/[4`0`I````*-4!`#,`
M``!2U0$`)````(;5`0`N````J]4!`"H```#:U0$`0P````76`0`I````2=8!
M`"P```!SU@$`+````*#6`0`M````S=8!`"<```#[U@$`'0```"/7`0`K````
M0=<!`"P```!MUP$`-P```)K7`0`L````TM<!``P```#_UP$`$P````S8`0`@
M````(-@!`#$```!!V`$`)````'/8`0`)````F-@!``\```"BV`$`'````++8
M`0`4````S]@!`!````#DV`$`,0```/78`0`(````)]D!``@````PV0$`(P``
M`#G9`0`F````7=D!`"<```"$V0$`'P```*S9`0`)````S-D!`.$```#6V0$`
M$@```+C:`0`:````R]H!``D```#FV@$`#````/#:`0`4````_=H!`!H````2
MVP$`!@```"W;`0`W````--L!`!4```!LVP$`%P```(+;`0`'````FML!`!,`
M``"BVP$`"P```+;;`0`\````PML!`"L```#_VP$`$````"O<`0`0````/-P!
M`!4```!-W`$`-````&/<`0`.````F-P!``\```"GW`$`$````+?<`0`:````
MR-P!``L```#CW`$`&P```._<`0`+````"]T!`"0````7W0$`"@```#S=`0`;
M````1]T!``<```!CW0$`)P```&O=`0`'````D]T!``D```";W0$`"0```*7=
M`0`[````K]T!`!(```#KW0$`!@```/[=`0`.````!=X!`!,````4W@$`%@``
M`"C>`0`*````/]X!``@```!*W@$`!P```%/>`0`3````6]X!``L```!OW@$`
M#P```'O>`0`<````B]X!``\```"HW@$`$@```+C>`0`8````R]X!`!8```#D
MW@$`!0```/O>`0`'`````=\!`!<````)WP$`!````"'?`0`S````)M\!`!``
M``!:WP$`#````&O?`0`"````>-\!`!$```![WP$`(@```(W?`0`+````L-\!
M``,```"\WP$`!P```,#?`0`+````R-\!``D```#4WP$`!@```-[?`0`-````
MY=\!``H```#SWP$`%````/[?`0`5````$^`!`!$````IX`$`-@```#O@`0`>
M````<N`!`!H```"1X`$`"P```*S@`0`S````N.`!``<```#LX`$`%P```/3@
M`0!+````#.$!`!0```!8X0$`#P```&WA`0`(````?>$!``0```"&X0$`!```
M`(OA`0`6````D.$!``4```"GX0$`!@```*WA`0`(````M.$!``0```"]X0$`
M"0```,+A`0`1````S.$!``L```#>X0$`#@```.KA`0`.````^>$!`!D````(
MX@$`!0```"+B`0`7````*.(!`"````!`X@$`(0```&'B`0`E````@^(!`!``
M``"IX@$``@```+KB`0`$````O>(!``H```#"X@$`"0```,WB`0`%````U^(!
M``(```#=X@$`'P```.#B`0!.`````.,!`!X```!/XP$`,P```&[C`0`J````
MHN,!`&````#-XP$`+````"[D`0`M````6^0!`!````")Y`$`?````)KD`0`G
M````%^4!`%,````_Y0$`4@```)/E`0`X````YN4!`"@````?Y@$`)````$CF
M`0`S````;>8!`#$```"AY@$`-````-/F`0`Y````".<!`#@```!"YP$`/P``
M`'OG`0`_````N^<!`"T```#[YP$`+@```"GH`0`S````6.@!``X```",Z`$`
M#@```)OH`0`-````JN@!`(,```"XZ`$`"````#SI`0"-````1>D!`(@```#3
MZ0$`+@```%SJ`0`4````B^H!`!@```"@Z@$`$@```+GJ`0`C````S.H!`!H`
M``#PZ@$`&`````OK`0!6````).L!`!8```![ZP$`"P```)+K`0`%````GNL!
M``8```"DZP$`"````*OK`0`%````M.L!`!L```"ZZP$`$0```-;K`0`>````
MZ.L!`!\````'[`$`$0```"?L`0`-````.>P!``<```!'[`$`"0```$_L`0`$
M````6>P!``D```!>[`$`#````&CL`0`.````=>P!``@```"$[`$`!0```(WL
M`0`<````D^P!``X```"P[`$`"@```+_L`0`)````RNP!``\```#4[`$`!P``
M`.3L`0`(````[.P!`!(```#U[`$`'`````CM`0`'````)>T!``H````M[0$`
M%@```#CM`0`+````3^T!``D```!;[0$`"````&7M`0`$````;NT!``D```!S
M[0$`#````'WM`0`,````BNT!``P```"7[0$`!@```*3M`0`'````J^T!`!<`
M``"S[0$``@```,OM`0`+````SNT!``8```#:[0$`!P```.'M`0`M````Z>T!
M``0````7[@$`$P```!SN`0`7````,.X!``L```!([@$`!P```%3N`0`&````
M7.X!``@```!C[@$`$````&SN`0`2````?>X!``<```"0[@$`"@```)CN`0`R
M````H^X!``<```#6[@$`"0```-[N`0`1````Z.X!``4```#Z[@$``@````#O
M`0`+`````^\!``$```#^`P``HP(``"4%``"[`@``3`8``#0`````````:@,`
M``````"4!0``.`,``&8$```````````````````[!0```````*D&``#+`0``
M=00``)8#````````G@8```````#``P``R0(``&<%``#3!0```````.@"``"T
M!0``X@$``+4$```V`0``(`````````"E`@``P0$```````!9!0``D0,``/$"
M```$!0``904```````":!@``NP4``````````````````/T````Y!```%`8`
M`.T$``````````````````!#````104``%("``!Z!0`````````````F`0``
MN04``!4```#+!0``1@0``-L%````````"@,```X"``#7`0``````````````
M````9P0`````````````A````!(#``!Z````\P$``&\$```X!```C`8```,%
M``!4`P``>0$```,!```4!0``WP(``%,"`````````````/<!``#9````,0``
M`,$```"R````AP$```0$``#<`@``2`0```````!L`P``IP4``)(%```P`@``
MDP```*P#````````40(``)`$``"Z!```.P``````````````LP4`````````
M````2@,````````H`0``9P8``.\"``#3````PP(``(X$````````.P(`````
M``!5`0```````"T&```Q`0```````!0#``"F`P```````.$"````````````
M`.8````;`P``RP,``#T#``"]`@``=`,``%T````Z`0``500```````"?`0``
M`````%@&```0`P```````/\"`````````````(D!``#:`@``@0$```0&``#_
M````?0,```````!U`0````````````!6!0``TP(```````!.`P``````````
M``!0`@``Z@,``-H#``"F````"```````````````HP4````````F!```*00`
M```````M````O0,``/D&``!L!0``'@8``.H&``#%!@``900```D```"C`P``
M```````````0`@``\P,``+@```"5````J00``````````````````(H$````
M````.0```'L!```Q`@``;0```%`$````````R`(``-$%``#&`P``+@0``&$`
M``")`@```````````````````````.D#````````EP0`````````````````
M`'(&``"Y`P``]`4``!,#``!/`@````````````#@!```#00``$D"``!F````
MW0$``&T%``"A`0``$P0```````"&`@``8P,````'``#<`0``BP0````````J
M`P``T0,``,D&``##!0```````!X"```:`P```````',#`````````````(P$
M```K`P``3P,````````=`P``,P(``+X"````````>@$````````/!P``YP,`
M`"H!``#G````Q`4```````#%!0````````T'``!H`0`````````````8!```
ME@4```H%``````````````,#`````````````(,&````````IP$```````#(
M!```70$```T"``!\!@``G`,``(@!``#4`P````````<&``#0!0``Q`$``*<"
M``!<`P``EP,``&(`````````*P(``)$"````````^@4``!L%````````9@$`
M``````!1!@``*0$``'H#``#V!0``K@8`````````````/@8```````#P`P``
M<@,```````!.`@```````'X#``"G`P``T`$``+,#```E!```CP$```T&``#)
M`P``:0(``)L&````````OP4``+`"``!T`````````*T!``!,!```D`(``/<$
M```L`P``;`(``/\&``````````````T#```V````?04``&P!``#Y!```YP8`
M``````#3`P``6````.$&``!8!0```````+@%``"*`0``K04`````````````
MJP4``$H%``#W`@``$`8````````Y`@``;@4``)T!``":!0```````&X````H
M!0``\`$``"P"``!"````9@8``/,$````````6@$```````!I`P``_@$``+@!
M``"V`0``U0,``(@&``!3!0``+`$`````````````<P4``-@&````````G@0`
M`#T%``"L!0``IP8``````````````P0``&($``!)`P``@P0``,H%``!Z!@``
M``````T```#!!@``X`,``!<!``"!!0```````+8```"K!``````````````C
M!@``(P````````#1`@``'@4`````````````-P8``````````````````!@'
M``#2`@``D00``)T#````````1@,```````!)!0``%@8``.0$````````````
M`'(!``#J``````````````"O!@``\@(``"$&``#%`P``7P4``,H#``#;`P``
M1`(```````"@!0``E@```-,$`````````````+$&``#Q!```6`$``/@$``""
M`@``R`8``%$%``#H````=@(``/,"````````5@,``-T#``"_`@``]00`````
M``!P`P````````````#>!@``P@0``)0$``!D`P``BP,``+<&````````4P``
M`"H$``!``P```````&P$``"A!````````&T"``!#!```4P8``$@&````````
M!0,```````````````````@!``#O````K@$``(P#```B`P``7P$```D!``!$
M````+P0```````"V!0``800``$<```"O!0```````/(```#M`0``A@```/4%
M``!4````#`4``#,&``"(`````````$`!``"^!@``,@(``*0```!.!@``3`$`
M``````"`!@``0P,``"L$```6!P```````,$%``!W!0``,`4````````8!@``
MR04``(```````````````,$#```)`P``7P8``"\!``!D````0@0``#````!A
M`P``;0,``$H&``#>!0``Y@0```$%``!%````200``'("````````$0(``)\"
M````````=`(```````!J`0``B`0``!$#``!$!@```@```.($``"2!```KP(`
M``````!W`0```````!0```"M!@``1@4``(D%``!\`P```````"<!``!'`0``
MUP(````````5!P``&`$``.8#```7!@``+`4``&\#````````R`$``(4$``#Z
M`P```````-`#``#?!```L@8``/8!``"Z`P``@`0`````````````WP8`````
M```Q!```50```(P"````````FP,``+``````````S`````````#%`@``Z`8`
M`,P#``#T`0``%@(``#D!``"9!@``@`$``#X!```1!P````````````#4!0``
MY0$``($```"O`0``)P0```````!H`@``6P8``%P$````````3P$```````"_
M`0``8````-L!``!B!@```````)D``````````````"`&``#D````'P$``,X#
M```1````F@$``*`&``#C!@``)0$``/D#```"`@``#P$``*,$``"8`P``(P(`
M`'X"``"Q!0``J@$``,X"````````X`(``$0$``"N````[````+P```#@````
MKP0``!P%``!.!0``ZP$``$\%``!I`0``*`(``,H!````````U00``)8&```.
M````G`0```````#U!@``<@0``+8$``#'!```"`(``,8!``#*!```0P(`````
M``!G````.08``````````@``10,```````!%!@``<0```-P&````````\0``
M````````````C04``"@#``#9!@``F`````````!Z!```&P```'X&``!,````
MDP(``*,&```%!0``3P0``+T!``!"`@``?P$``/@!``":!```!00``"<&``#K
M`@``G04``"`"``"G````L`8``"8&````````>08``#0$```,`@``C08`````
M`````````````-($``#I````@00```L`````````!P(```````#"````H`$`
M`"0&````````E@0``.`!``````````````````"1!@``K0(``$$!``!<`0``
M``````````"C`0``L@,```````"A`@``,@8``-4!``#M!@``(@0``+$$``!^
M`0``30,``/H$`````````````+0!``"Q````P@,``.<%``#M`P``````````
M``!&`@``6P```$<#``!U!0``$`<```````!"`0``(`4``.L&``!0!@``````
M`)0!````````C@```$(&````````M@8`````````````?`$```````"W````
M]`,``'T$``!,`P``JP$``%8```!_!```M0(``*(&```J`@```````,`"``"]
M````>`8```````#(````608`````````````B@```/4```#8`P``"P$``),&
M```X`@`````````````,`````````-(#```````````````````5`0``Y`$`
M`"<"``!;!```"`4``/\%`````````````*<$``!>`0```````,P!``!K`P``
M``````@#``#V``````````````#%````@0(```$#``"'````B00```````#F
M!0``$@```&`%```X`0``AP,```````#'`@```````&4````'````(0(``+\&
M``#3!@``'0$``-X!```T`0``;08``#4```"T!@``5`8``.8!``"2````3@0`
M`-`$````````DP$``$4$``"M!```2@(``!L$````````LP$````````L!```
M5@0``(P%``!#!0```````%8"````````<0(``*0"```;!@``\08`````````
M````_P0```````!1`````````!8`````````Z@$``%$#```3`@``Q0$``*P"
M``!=`@``BP$```````!@`P``(`$``,<```"#`P``;```````````````2P,`
M`%<#``"S````I@4``/````"$!@```````!\"``"^````H0,``%L%````````
MEP$`````````````\04``!T$``!>````CP4``.P&``!&`````@4```````#R
M`P``7P0```````"P`0``R0````\%```0!```C0,```````#9!````````'$#
M``#(`P```````)T$``!J!0``\`(```````#C`P``@P4`````````````0P8`
M`"H&``````````````````"<!0``F`8``-T&```P!````````!H````U`P``
M]`(``!\```!D!0``1@8``!L'``"E!0``I@$```8%``!F`P``=P```$P"``!?
M`P``:0```,L"``!*`0``8`0``%(%``!`!0``T0$``#X"``";!```F0(``/0&
M````````D04``(L"``#F`@````````0'``!J!```80$``#X$``!`!```````
M`````````````````#<$``#G`@``-0$``+<%``"U`0``C0$`````````````
M!`$``,\`````````000````````T`@``^0(``'\#``````````````````#[
M`P``X`4`````````````M````"D"``!!`@``&0(``(8&``!;`P``Y08`````
M```=`@``!P<```````#Y````JP,````````I!0``(P$``/X```#9`0``:08`
M`/T#````````D0$``,X&``"X!@``[0``````````````C@8``(8!``":`@``
M%`(```````#?`0``&`````````"2`0``<````'P"``!9`0``QP4``,,$``"F
M!@``P@(``/$#```0`0``,@4```,&``!P`0``<`4``'\"``"%`````0<`````
M```X`````````"P``````````````````````````````#<%``#8!0``)@(`
M`$4"``!B!0```````&\%``#)`0``-P,``/4!````````^@$``/`$``#7!@``
M`````"D&```K````^@8``)(&``#=!0``?````+T&`````````````$<$``!N
M`0``K@,``#P#````````[@4``-`&``#`!0``70,``%T$``#\`0``^@``````
M``!U!@```````*@"``#`!```#@0``/L&``"#`0``>@(``'0$```S!0``;P$`
M`"L%``!X`P``M04``!<'```X!@``&P(```````!V!```4@$``-$&```)`@``
M`````'4```".`P``JP```)4&```/`@``^@(``'8&``#Q`0```````+(!``#&
M!````````(\"``!V````X@(``+<#````````O@$``)<"````````B`,``,T%
M``"[`0``*P8```4&``"S!@``\@0``'\&``#G`0``@@0``%D#``"I`@``````
M`'\%```M`P``J`0``%H#``!:!````````%,!````````5P4``(X%```I````
ML0(``.D!```&`@``MP(``#L$`````````````!H%```O!@``30(```````"N
M!0``-0(``-@$``#A!```[`,``%X$````````1P(``#,#``#O!@``PP,`````
M``"/!```X@,``/<````C!```-@,``+\```"%!0``W`4``/D!```<`@``!`,`
M`(L%````````:P0``!(!``"(`@``2P(``+X#````````2P8`````````````
M(04```````#<!````````````````````````%P&```N`0``````````````
M````7`(```````"M````J@,``$\````M`@``Q@4````````@`P```````*4`
M```1!0``504````````#!P``$P4``/T&``#8`0``+@8``!T%``"Y!@``@@$`
M`+P"```9`0``F`(``%<&``#^!0``8P0```````#4!@``)`0``#X#```>!```
M;`8``,<#````````@`4`````````````V@````````#D`P``F0$`````````
M````W0````````"#`@``)P4```````!4!0``[@``````````````B0```-L`
M``#"!0``"@$``-````!/!@``\@4``&X#``"S`@``AP4````````'`P``2P``
M`,\#```6!```O@4``#$&```T`P``50,``,\%```K`0```````!0'````````
M`````+P#``""!@``-@(``/@`````````*0,``'X```#S!0```````/L!``#4
M!```-00``'0&````````*`8``"P&`````````````"4#``"5!0``R00``#L&
M``!T!0```````#T"````````D`8``"`$``"%!@``PP8`````````````=0(`
M``````````````````````#*````=P,``'@```";`````````"\#````````
MGP,``"T!``!7````$@8``(P````?!```D````&X&``#&``````$``,T$````
M````908``)("````````M`(``*8$``#7````G`$``&("``!4!```2`4``!P'
M``!+`0````````````#[````HP```)8"``!J!@``E0,``#\"`````P``SP$`
M`'L$```5`P``:00``-\```#,`@``N@$``#<```!]`@``60(``.(&``#W!0``
M80(``/P%````````;00`````````````9`(``*(%```E!@``4@```)`%````
M````RP```)D$``"D`P``8P4``!````!V`0``B@8``#H&``#A`0``&0,`````
M````````"08``*4!````````(@$``&,!``#5````J0,``,T#``!$`P```@$`
M```&``#X!0``W@,``"\"```/`P``B@4``#`&``"L!```EP``````````````
M`````'T!``#-```````````````<`0``&04```````"L!@``%@4``$@`````
M````1P8``/P$``"D!@```````'T```!9!```!0<```````#E!```]@,```($
M````````C0(```````#&`@``B`4``-X"```A`P```````(,```"K!@``[`(`
M`-8!``"J!@``````````````````M0,``#H#``"_`P````````````#2!@``
M6@(``+($``"5!```[`$``&4!````````I`4``)P"``#I`@``ZP````````!:
M!@``G````*@%``"Z`@```````$X!```S!```SP0```8&``````````````X'
M``"X`P``P0(``-`"``"L`0````````````#$````#0$```````"B!```NP,`
M`%X#```_````,@0`````````````"@```*D%``!?````W`````````"%`P``
M?`0``*X"``#P!@``JP(``#(!``!0`0``O@0``'D"``#;!@``/`(`````````
M````1@$```````!_````C00``(<&```%`0``)0```(L```"J`@``<@4`````
M``!%`0``````````````````<`(```8#``!F`@``GP0``/P&```A`0``````
M`$T%````````#`,``.(%``!?`@``Y@8``'$!`````````````)@%``#O`P``
M@@```-D#```'`0``XP$``(0!``#D!@```````*4&``!S`@``@@,``.D%````
M````/@```)\&``"L````O`$```````#U`@``*`0```````!Y`````````)`!
M```(!@``(@8``!,```#2`0``_00``/<&```8`@```````"X"````````G@``
M`.@#````````!@0``&<"``!"!0```````,`!``":``````````X&``#7!```
M:P8````````.`P``"04``,\&``#9`@``+P```#8&```G`P`````````````?
M!0``_@(``/\!`````````````$@"``"W`0``<00`````````````2@0``&L!
M``!=!0```@8``)4"``!N!```KP,``#$%````````PP$```````"A````````
M`)0````)!P``4@8``"0!``!'!0``-`4``#\!``"?!0``^`,``/X$``#S````
M`````(\#``"'!```[04``&(#``"$`@``/`$``!($````````&`4``+0$```D
M!0```````%H```"[!@```````!<%```5!0``&0<``!X!`````````````%<!
M``!W!```708```````!S!```.`4``````````````````.0"````````/`0`
M`(D#``!`````O04``),$``"Y`@``Y0````````#&!@``M`,``&@&````````
MG`8``'$%````````'0```'L&``!I!0``)@,``&`&```A!```208``,X!``!#
M`0``"P(````````Z!```5@8```````!8`P``$00``"8%``#4`0``RP8``$`"
M``"H`````````"X#``"@`@``"P4``(4"``#-`@``:P4``.T"````!```````
M`#T$````````.@(``-$````,`0``]0,````````B!0``V04``(8$``!K````
M`````%,$```5`@````````8`````````X0,``!<$``"4`@```````$T$```/
M!@``M0```(8%``#N!```@0,`````````````#`<``)X!````````R@(``/L"
M``"4`P``RP0```````"R!0``'@,``%0!``#5`@```````+`$````````````
M`.X"```_`P````````````#.!0``#P0``%L"````````-04``.,$```S`0``
M"P8``,P$```A````L@(```````#;!```_`````````![`@`````````````M
M!0``J`$```L'````````G0(````````_!`````````````!8`@``)P``````
M``!-!@``9P,`````````````?@0``.`&``#P!0````````````![````N`(`
M``````!-`0``7@8``-4%```(!`````````H"```!`0``?`4``),%``"@`P``
M6P$```````#>````L`,``*`````!!@``D`,```````!]!@````````````"M
M`P``I`$``)@!````````DP,``/@"``!D!@``%P````````#O!0``Z@4``(X"
M``#K!`````````````!@`@``[@8``"X%```F````A`0```````#`!@``"@<`
M`!P#``""!0```````!D$````````,`,```T%```:!`````````X%``!C````
M``````````!!!0``%`0``/<#````````S@0``*H$``!(`P```````%4"``!$
M`0``00,`````````````A`,``)D%``#7`P``>`0``(X!```:`@``>00``!,!
M````````)````"0#``!S`0```````!("```*!```N@8```````"X!```U@(`
M`'4#``````````````````";`@``%@$``-@"```6`P``EP8``$$&``"J````
MQ`8``+D$``#J!```_@8``!`%``!J`````````',&``#=!```<`8``%8!````
M````>P,```````#=`@``V@0``+`%```=!@``8P8``"("``"*`@``=@4``'0!
M````````(P,``,\"``"[!````````-8```"7!0``$08``,(!```[`P``+P4`
M`,<!``!2`P``20$``",%```<````1`4``%<$````````9@4``&4"```&`0``
M`````-H!```W`0``W`,``*`$````````:`0```````"&`P``FP4`````````
M````Y0(``%X%``![!0````````````":`P``````````````````Q`0``*D`
M```3!@````````````#]!0````````````#.````7````*@#````````````
M````````````9P$``+T$``#[!0``&@<``+4&`````````````#P`````````
MU@8``'D%````````````````````````:P(``-8$````````4`````````#!
M!````````+8"````````\@8``-X$````````N0```*(!```P`0``U@,``%$$
M``"V`P``0`8``````````````````!L!````````4P,````````"`P``Q00`
M````````````MP0````````J!0``:`4```````!X`0``/P8```H&````!0``
M_0(````````<!@``4@0``&$%``#8````N@```!P$``#4`@``^P0``'$&```Y
M!0````````P$``#C`@``-@4```````#A!0``Z`$``&0$``"%`0``LP0``-0`
M```%````B08````````U!@``_`,``.\!``"6`0``A`4``#H```!E`P``````
M`+H%```7`@``-P(````````1`0``Q`(``/P"```4`0``30`````````T!@``
M5`(``/,&```8`P``4`,````````'!```>0,``"X```!!````'@```&,"``#A
M`````````!,'````````=P(``(P!``!0!0``G0```.X#``#_`P``:@(``(T`
M``!1`0``X@```.,```">`@``CP8``)D#````````T00````````)!```WP,`
M`!D`````````&@8```('``#'!@``S0$`````````````%00```````#D!0``
MU08```````#"!@``J`8``.X!```2!P``=@,``.H"````````G@,``#H%````
M````:`,``'@%```2!0``S`8````````M!```ZP4``)@$````````V@4`````
M``"?````-@0``*\````_!0``V@8``-\%``"4!@``7`4``.,%````````3`4`
M`-(`````````_0$``"0"```E`@````````````#E`P``PP``````````````
M,P```*4#``#L!```,@,```````"A!0``]@8```````!O`@``Z00``$H```"\
M!0```````.@$```9!@``UP4``*(#``"/````<P````0"```\!@```P(``&X"
M``"5`0``]@0``)T&``#,!0``#`8``%@$````````2P4``&(!```^!0``/0$`
M`#L!```]````3@````L$````````I00``'<&```R````!@<``!\#```J````
M<@```"@```#2!0``]`0`````````````VP(``)X%``#O!```20````\```"D
M!`````````````"N!```L0,```````"'`@``L0$```X!``"_!```!P4``&`!
M``#$`P````````L#``"A!@```````%<"````````FP$``'X%````````````
M``````#G!````````(`"``"B`@```````$(#``!D`0```````%4&````````
MN0$``.L#```Y`P``R`4``/@&``#H!0``B@,``#T&``!A!@``;0$```````!>
M`@```00``,T&```(!P```````%D`````````R@8```0`````````<`0``%H%
M``#V`@``&@$``.P%````````@08``-,!``"\!@``/`4```````"+!@``]```
M`'@"````````^04`````````````P````/(!``"J!0```0(`````````````
M;P8``+L``````````````&\```!(`0````````````"I`0``Y04```````#I
M!@``'P8``$L$``#6!0``@`,```````"\!```D@,``)$```"B````I@(``&@`
M```Q`P``(@```!<#````````%08```4"```#````````````````("@E<R!D
M87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H=&]D87DI`"`H>65S=&5R9&%Y
M*0`@870@`")&:7)S=&YA;64@3&%S=&YA;64B("`H:64N($IO:&X@1&]E*0`B
M3&%S=&YA;64L($9I<G-T;F%M92(@*&EE+B!$;V4L($IO:&XI`"5D("5S(&%N
M9"`E<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I
M;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A9&1E
M9"X`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&9I;&4@<W5C
M8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`
M)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($-A;&5N9&%R`"5S
M)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U<W1I;F<@)7,@
M)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(
M;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&)R;W=S97(@
M=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D`$$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@4VAO=V5R<P!!32]0
M30!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)O=F4@<V5A
M<F-H(&9O<FT`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C
M8V]U;G1I;F<`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N
M`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!
M9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;P!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B
M;V]K`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S
M<P!!9&1R97-S($)O;VL@3&ES=&EN9P!!9&1R97-S(&)O;VL@96YT<GD`061D
M<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N`$%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N
M`$%D<P!!9'9A;F-E9"!396%R8V@`069G:&%N:7-T86X`06QB86YI80!!;&=E
M<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A
M=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R
M('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y($5X:7-T<P!!;')E861Y
M(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!0
M87-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA
M:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT
M.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!
M;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T
M:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R
M97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!T:&%T('EO
M=2!W86YT('1O(&1E;&5T92`E<S\`07)E('EO=2!S=7)E('1H870@>6]U('=A
M;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/P!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!
M<G0`07)U8F$`07-C96YD:6YG`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T
M`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@
M8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB
M=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@
M0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!
M=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO
M;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"
M86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"
M86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V5L
M:6YE`$)A<VEC(%-E87)C:`!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;&]W
M('-E87)C:"!F;W)M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I;F0@9F%I;&5D
M.B`H)7,I("5S`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@
M(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L
M9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`
M0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`
M0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL
M971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$)U<VEN97-S($-A=&5G
M;W)Y`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL
M(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O
M;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T('1O($E-05`@
M<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E
M<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E
M(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T
M:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL
M(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O
M<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX
M.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`
M0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N
M86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H87(`0VAE8U]K($QI;FLN
M+BX`0VAE8VL@7T%L;"].;VYE`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O
M<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@861D
M<F5S<R!B;V]K`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E
M(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA
M<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L
M96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L
M96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L
M:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V5D(&)O<F1E<G,`0V]L
M;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L
M<SH`0V]L=6UN($]P=&EO;G,`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6$@
M<V5P87)A=&5D('9A;'5E<P!#;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R
M;W-O9G0@3W5T;&]O:RD`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`
M0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!A;GD@061D<F5S<P!#
M;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL
M960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!F86EL960Z("5S
M`$-O;FYE8W1I;VX@9F%I;'5R90!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W0@<F5M;W9E9"!F<F]M(&QI
M<W0N`$-O;G1A8W1S(&EN(&QI<W0Z("5S`$-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT:6YU90!#
M;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]S=&$@
M4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B
M:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@
M)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F
M971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N
M`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V
M97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`
M0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N=&5D('1E>'0`0V]U;G1R
M>0!#;W5R<V5S`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A
M=&4@<W5B(&9O;&1E<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R
M961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO
M;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL
M:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A
M=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T
M:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E
M<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N
M=&ET>0!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$969I;FET:6]N<P!$
M96QE=&4`1&5L971E($-O;F9I<FUA=&EO;@!$96QE=&4@1W)O=7``1&5L971E
M(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@
M8G5T=&]N(&)E:&%V:6]U<@!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E
M;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&9A:6QE
M9#H@*"5S*2`E<P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N
M="!R;W<`1&5L971I;VX@9F%I;&5D`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$
M97!A<G1M96YT`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N
M=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I
M;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P
M;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O
M<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T
M(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B
M;&EC`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N`$1O=VYL;V%D('9#87)D`$1R;W`@9&]W;B!L
M:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`
M161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&5N=')Y(&9O<B`E<P!%9&ET
M(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I
M;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I
M;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP
M='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO
M;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G
M92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@
M=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N
M=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1R>2!F;W(@)7,@=7!D871E9"X`
M17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%
M=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O
M;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO
M=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N
M9`!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T`$5X
M<&]R="!!9&1R97-S($)O;VL`17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O
M;G1A8W1S+@!%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M
M<&QE=&5L>2X`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&%C8V5S<R!T:&4@
M861D<F5S<R!B;V]K.B`E<P!&86EL960@=&\@861D("5S('1O("5S.B`E<P!&
M86EL960@=&\@8G)O=W-E(&QI<W0`1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER
M96-T;W)Y`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F
M<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&9I;F0@;V)J
M96-T('1O(&)E(&%D9&5D.B`E<P!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&
M86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S`$9A:7(`1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U
M87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9I:FD`
M1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE
M($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D
M`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;F0`1FEN
M;&%N9`!&:7)S="!(86QF`$9I<G-T($YA;64`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI
M=&%N`$9R965B=7-Y(%523`!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S
M:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@
M`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'
M86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA
M`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($%D
M9')E<W,@0F]O:P!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`
M1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'
M<F]U<`!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E
M(&YO;BUE;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'
M=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U
M:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X
M-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`
M2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!#:71Y`$AO;64@0V]U;G1R>0!(;VUE(%!H
M;VYE`$AO;64@4&]S=&%L($-O9&4`2&]M92!3=&%T92]0<F]V:6YC90!(;VYD
M=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`
M2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L
M.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N
M>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(
M=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)35-0`$E0($%D9')E
M<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W
M:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I
M;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O
M;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I
M<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN
M9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE
M="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G
M92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A
M;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S
M`$EM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60`26UP;W)T+"!3=&5P("5D
M`$EM<&]R="]%>'!O<G0@061D<F5S<R!";V]K<P!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT
M`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M
M871I;VX`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R
M="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E
M`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R
M`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R
M="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R
M87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@
M869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y
M($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE
M;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED($E$`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@861D<F5S
M<R!B;V]K`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N
M`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RX`26YV86QI9"!E;6%I;`!);G9A;&ED(&5N=')Y`$EN=F%L:60@
M9FEL92!F;W)M870`26YV86QI9"!K97D@<W!E8VEF:65D+@!);G9A;&ED(&US
M9U]T>7!E+@!);G9A;&ED(&YA;64`26YV86QI9"!O8FIE8W1)9`!);G9A;&ED
M(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T
M;V-O;"X`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D
M<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)
M<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*
M86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*
M97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R
M`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA
M:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R
M96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME
M>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE
M)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#
M+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,1$%0('-U<'!O<G0@:7,@<F5Q=6ER
M960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO
M="!L;V%D960N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S="!.
M86UE`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T
M=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A
M;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E
M<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H
M="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!2
M86EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,
M:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X
M($-O;VMI90!,:7-T`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,
M:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I
M;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S
M92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R
M<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E
M<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M
M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G
M:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y
M<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@
M;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-
M871C:&EN9P!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`
M36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F('!A9V5S
M`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G
M92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E
M<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!7
M96%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`365X:6-O`$UI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-
M:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S
M.B``36EN:2!396%R8V@`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!$
M3B!I;B!,1$%0('-O=7)C92!C;VYF:6=U<F%T:6]N+@!-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]B:6QE(%!H;VYE`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1I9GD@9F%I;&5D.B`H)7,I("5S
M`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA
M`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E
M<P!-;W)E('1H86X@,2!E;G1R>2!F;W5N9`!-;W)O8V-O`$UO<W1L>2!#;&5A
M<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-
M;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E(&QE
M9G0`36]V92!R:6=H=`!-;W9E('5P`$UO>F%M8FEQ=64`375L8F5R<GD@061D
M<F5S<R!";V]K`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L
M92!P97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA
M;64@6R5S72!A;')E861Y(&5X:7-T`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!
M8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L
M($D@1&\@3D]4($%G<F5E`$YA;64`3F%M92!&;W)M870`3F%M:6)I80!.875R
M=0!.97!A;`!.971C96YT97(@365M8F5R($1I<F5C=&]R>0!.971H97)L86YD
M<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),
M`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),
M`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.
M979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@0V]N=&%C=`!.
M97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.
M97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@
M;W!T:6]N<P!.:6-A<F%G=6$`3FEC:VYA;64`3FEG97(`3FEG97)I80!.:6=H
M=`!.:75E`$YO`$YO("5S(&5N=')Y(&9O=6YD(&9O<B`E<P!.;R!A9&1R97-S
M(&)O;VMS(&9O=6YD+@!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI
M<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@
M8V]N=&%C=',@9F]U;F0`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N
M('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%T:6]N(&ES('-E
M="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO
M(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E
M9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S
M`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO
M('9#87)D(&1A=&$@=V%S(&9O=6YD+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D
M:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI
M<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F
M=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E
M9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R
M;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R
M86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!I=&5M<R!P97(@
M<&%G90!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J
M96-T($-R96%T;W(`3V)J96-T(&YO="!F;W5N9`!/8W1A;`!/8W1O8F5R`$]F
M9F5N<V4@9FEL=&5R`$]F9FEC90!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S
M`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A
M(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@
M9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK
M(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T
M:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES
M871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@
M=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE
M<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I;VYS
M`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG
M:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@
M2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H
M96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C
M=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N
M+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O
M<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C
M;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT
M`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES
M<VEO;B!$96YI960`4&5R;6ES<VEO;B!D96YI960`4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H
M:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:6YE($%D9')E<W,@0F]O:P!0:71C
M86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE
M(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T
M96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE
M=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT
M`%!R:79A=&4@061D<F5S<R!";V]K`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O
M8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@
M2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A
M=&%R`%%U97)Y`%%U97)Y(&9A:6QE9#H@*"5S*2`E<P!1=6EC:R!396%R8V@`
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`
M4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%N9&]M($9O<G1U
M;F4`4F%T:6\`4F5A9`!296%D(&9A:6QE9#H@*"5S*2`E<P!296%D(&UE<W-A
M9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-O<F1S(&1I
M<W!L87EE9#H`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X
M`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E
M;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T
M=&EN9P!296UO=F4@9G)O;2!T:&ES(&QI<W0`4F5M;W9E('!A:7(`4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S
M=&5D(&]B:F5C="!N;W0@9F]U;F0N`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E
M<V5T(%EO=7(@4&%S<W=O<F0`4F5S970@=&\@1&5F875L=',`4F5S=6QT<P!2
M971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N
M`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT
M(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`
M4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2
M;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R
M871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3
M+TU)344@16YC<GEP=&5D($UE<W-A9V4`4R]-24U%(%!U8FQI8R!#97)T:69I
M8V%T90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--
M4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`
M4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,
M=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@
M86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!3
M86X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O
M=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`
M4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@
M=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+@!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE
M<P!396%R8V@@9F%I;&5D`%-E87)C:"!F86EL960Z("5S`%-E87)C:&EN9RXN
M+@!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T
M;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE
M8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`
M4V5L96-T(&%N(&]B:F5C=`!396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!E
M>'!O<G0@9G)O;3H`4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T
M('1O.@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!E>'!O<G0@
M9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.@!396QE8W0@=&AE
M(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@9F]R;6%T
M('5S960@=&\@9&ES<&QA>2!N86UE<SH`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE
M(&%D9')E<W,@;&ES=',N`%-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA
M>2!N86UE<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N
M9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-
M;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3
M970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RX`4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M(`!397EC:&5L;&5S`%-H87)E9"!$:7)E8W1O<GD`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W($%L;`!3:&]W($-O;G1A8W1S`%-H;W<@3&ES
M=',`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R
M<R!,871E`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@
M=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I
M>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N
M;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@3&%T90!3;F]W
M(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)
M<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T($1I<F5C=&EO;@!3
M;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5R8V5S`%-O
M=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@
M1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE
M<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P
M86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R
M`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V
M86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R+@!3<&QI="!C96QL`%-P
M;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R
M9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T
M=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G
M:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3
M='EL92!;0U-370!3=0!3=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S
M<P!3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,`4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`
M4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C
M97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@
M4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U
M;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U
M<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N
M`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER
M:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8`5%-6(&9I
M;&4`5&%B('-E<&%R871E9"!V86QU97,`5&%B;&4`5&%B;&4@4')O<&5R=&EE
M<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S
M="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!
M9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T
M;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U
M<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A
M:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO
M="!B92!P=7)G960Z("5S`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!4:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T
M(&5X:7-T+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER
M960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E
M9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D
M871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY
M`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U
M<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R
M92!A<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@;F\@=W)I=&5A
M8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R
M97-S(&)O;VMS(&%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@
M;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R!I<R!A
M;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BX`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@
M>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F;W(@9G5R=&AE<B!H96QP+@!4
M:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@;V)J96-T+@!4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S
M(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O
M;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@
M)7,`5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4:&ES($E-
M05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E
M<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I
M82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N
M;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@
M86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI
M="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU
M<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T
M+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F;W)M870@:7,@
M;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N
M(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U
M<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT
M<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('!E<G-O;B!A
M;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R97-S(&)O;VL`5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4
M:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`
M5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE
M8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I
M(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4
M;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A
M`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A
M;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R
M:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC
M;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD
M97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O
M9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O
M;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO
M=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`
M56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L
M;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T
M:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU
M;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES
M=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`
M57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y
M<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A
M;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU
M97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N`%9E<FES:6=N($1I<F5C=&]R>0!697)S:6]N
M`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D
M:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H
M5DE30TE)*0!6:65W("5S`%9I97<@0V]N=&%C=`!6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U
M;'0Z`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5
M+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I
M82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9
M($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE
M<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC
M;VT`5V5B`%=E8B!3:71E`%=E8G-I=&4@55),`%=E96ML>0!796QC;VUE`%=E
M;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`
M5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P
M;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@
M:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E
M(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA
M8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@
M0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B
M;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@<W!E960@:6X@
M:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7
M;W)K($-I='D`5V]R:R!#;W5N=')Y`%=O<FL@4&AO;F4`5V]R:R!0;W-T86P@
M0V]D90!7;W)K(%-T871E+U!R;W9I;F-E`%@M4F5F`%@U,#EV,R!"87-I8R!#
M;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED
M96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P
M`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$58
M5"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T
M;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N
M(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE
M+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO
M=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL
M92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+@!9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+@!9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C
M="!A('1A<F=E="!A9&1R97-S(&)O;VLN`%EO=2!M=7-T('-E;&5C="!A('1A
M<F=E="!L:7-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E
M;&5T960N`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@96YT<GD@9FER
M<W0N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@
M8V%T96=O<GD@;F%M92X`66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AI<R!C;VYT86-T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@
M1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T
M($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9
M;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:
M86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=
M`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`6VYO('9A
M;'5E70!?061M:6YI<W1R871I;VX`7T)R;W=S90!?0TQ)`%]$871A5')E90!?
M1&5L971E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E
M<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQO9R!I;@!?3&]G(&]U=`!?36]D
M:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN
M:RXN+@!?4F5M;W9E(&9R;VT@=&AI<R!L:7-T`%]396%R8V@`7U-E='5P`%]4
M86)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L96YD
M87(`8V%L;0!C;&EC:R!H97)E`&-O;G1A8W0N=F-F`&-O;G1A8W1S+F-S=@!C
M;VYT86-T<RYT<W8`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@
M)7,@)7,`:#H`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O
M<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N
M=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L
M<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``
M<W1E861Y`'1A<VL@;&ES=`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C
M;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W
M96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A(#(N,"UC=G,*
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I
M<VEO;BU$871E.B`R,#`T+3$R+3$Y(#$V.C0U*S`Q,#`*3&%S="U4<F%N<VQA
M=&]R.B!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL
M/@I,86YG=6%G92U496%M.B!$=71C:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*`"`H)7,@9&%G96X@9V5L961E;BD`("A3;F5L=&]E=',@)7,I`"`H
M=F%N9&%A9RD`("AG:7-T97)E;BD`(&]P(``B5F]O<FYA86T@06-H=&5R;F%A
M;2(@*&(N=BX@2F]H;B!$;V4I`")!8VAT97)N86%M+"!6;V]R;F%A;2(@*&(N
M=BX@1&]E+"!*;VAN*0`E9"`E<R!E;B`E<P`E9"UD86<@=F]O<G5I='II8VAT
M`"5S("T@3W!M97)K:6YG`"5S('9I;F=E<F%F9')U:P`E<R!+0@`E<R!/;F1E
M<FAO=61S=V5R:WIA86UH961E;B`M($)E=F5S=&EG:6YG`"5S(&EN<V-H<FEJ
M=F5N`"5S(&=E8G)U:6ME<G-O=F5R965N:V]M<W0`)7,@=&]E9V5V;V5G9"X`
M)7,@8F5S=&%A="!A;"X`)7,@;W`@)7,@)7,`)7,@8F5S=&%N9"!M970@<W5C
M8V5S(&=E:6UP;W)T965R9``E<R!I<R!V97)E:7-T`"5S(&UI;G5T96X`)7,@
M;FEE="!G979O;F1E;BX`)7,@=&]T("5S('9A;B`E<P`E<R=S(&%G96YD80`E
M<R=S(&YO=&ET:65B;V5K`"5S)W,@=&%K96YL:6IS=``E<SH@)7,`+"!W:6YD
M=FQA9V5N("5S("5S`"P@=F%R:6%B96P@=F%N("5S('1O="`E<P`M+2!S96QE
M8W1E<F5N("TM`#$R('5U<G-W965R9V%V90`R-"!U=7)S=V5E<F=A=F4`,C0@
M=75R<P!%96X@8G)O=W-E<B!M970@:49R86UE(&]N9&5R<W1E=6YI;F<@:7,@
M=F5R96ES=`!%96X@9&%T86)A<V4@8F%C:V5N9"!I<R!V97)E:7-T('9O;W(@
M9&ET(&)L;VLN`$5R(&AE969T('II8V@@965N(&9A=&%L92!F;W5T('9O;W)G
M961A86X`165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES('9E<F5I<W0@;VT@
M965N(&)E<FEC:'0@=&4@8V]D97)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U
M=&5L(&ES('9E<F5I<W0@;VT@965N(&]N9&5R=&5K96YD(&)E<FEC:'0@=&4@
M=F5R:69IZW)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!0
M1U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M
M(&5E;B!B97)I8VAT('1E(&1E8V]D97)E;BX`165N(&]P96YB87)E(%!'4"!S
M;&5U=&5L+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@
M>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BX`
M165N(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)344@<VQE
M=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B
M97)I8VAT('1E(&1E8V]D97)E;BX`165N(&]P96YB87)E(%,O34E-12!S;&5U
M=&5L+"!P<FEVZ2!3+TU)344@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@
M>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BX`
M165N(&]P96YB87)E(%--24U%('-L975T96P@:7,@=F5R96ES="!O;2!E96X@
M8F5R:6-H="!T92!C;V1E<F5N+@!"=6EE;B!V;V]R(#$R+C`P('5U<@!!32]0
M30!!4$D@240`3W9E<B!D97IE(&5D:71O<@!/=F5R+BXN`$)O=F5N('IO96MF
M;W)M=6QI97(`06)S8F]T=&]M`$%B<VUI9&1L90!4;V5G86YG(&=E=V5I9V5R
M9"!B:6H@:&5T(&UA:V5N('9A;B!61E,@9&ER96-T;W)Y+@!4;V5G86YG(&=E
M=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A;B!61E,@8F5S=&%N9"X`06-C;W5N
M='=A8VAT=V]O<F0`06-C;W5N="!B979R;W)E;BX`5F5R86YT=V]O<F1I;F<`
M0VAI;&0@9W)O97`@=&]E=F]E9V5N`$-H:6QD(')E8VAT('1O979O96=E;@!(
M:65R('1O979O96=E;CH`3FEE=7=E(&=R;V5P('1O979O96=E;@!.:65U=R!R
M96-H="!T;V5V;V5G96X`3FEE=7=E(&=E8G)U:6ME<B!T;V5V;V5G96XZ`$MO
M;&]M('1O979O96=E;@!.:65U=V4@;&5D96X@=&]E=F]E9V5N`%!A87(@=&]E
M=F]E9V5N`$AE="`E<R!M96YU('1O979O96=E;B!A;',@965N($UO>FEL;&$@
M4VED96)A<@!4;V5V;V5G96X@86%N`%9O96<@=&]E(&%A;B!A9')E<V)O96LZ
M`%9O96<@=&]E(&%A;B!M:6IN(&%D<F5S8F]E:P!'96)R=6EK97(@=&]E=F]E
M9V5N`%1O979O96=E;B!V86X@9V5B<G5I:V5R<R!I<R!U:71G97-C:&%K96QD
M+@!!9')E<P!!9')E<V)O96L@;&EJ<W0`061R97-B;V5K:6YV;V5R`$%D<F5S
M8F]E:R!M970@<W5C8V5S(&=E;&5E9V0N`$)E:&5E<B`M(')E8VAT96X@=F]O
M<B!A;F1E<F4@9V5B<G5I:V5R<R!I;G-T96QL96X`0F5H965R`$%D=F5R=&5N
M=&EE<P!5:71G96)R96ED('IO96ME;@!!9F=A;FES=&%N`$%L8F%N:>L`06QG
M97)I:F4`06QI87,`56ET;&EJ;F5N`%5I=&QI:FYI;F<Z`$%L;&4`06QL92!G
M96%U=&AE;G1I8V5E<F1E(&=E8G)U:6ME<G,`06QL92!G<F]E<&5N`$%L;&4@
M<F5C:'1E;@!!;&QE('9I97(@>FEJ9&5N`$UE97)D97)E(&%D<F5S<V5N('1O
M97-T86%N`$EN<W1E;&QE;B!V86X@9V5O<F1E;F1E(&QI:G-T('1Y<&4@=&]E
M<W1A86X_`$)E<W1A870@86P`0F5S=&%A="!A;`!!;'1E<FYA=&EE=F4@24U3
M4"!A86YM96QD:6YG`$%L=&5R;F%T:65F($E-4U`@=V%C:'1W;V]R9`!!;'1E
M<FYA=&EE=F4@24U34"!G96)R=6EK97)S;F%A;0!!;'1E<FYA=&EE9B!E+6UA
M:6QA9')E<P!!;'1E<FYA=&EE=F4@<VIA8FQO;F5N`$%L=&5R;F%T:65V92!T
M96MS=#H`06UE<FEK86%N<R!386UO80!%96X@;VYG96QD:6=E('=A87)D92!O
M<&=E9V5V96XN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI96UE('!R
M;WAY`$%N='=O;W)D`$%N=&%R8W1I8V$`06YT:6=U82!E;B!"87)B=61A`%1O
M97!A<W-I;F<`5&]E<&%S<VEN9R!I<R!G97)E960N`$]P(&-H:6QD<VAA<F5S
M('1O97!A<W-E;@!';V5D:V5U<F5N`$%P<FEL`$%R86)I<V-H("A7:6YD;W=S
M+3$R-38I`$%R8VAI969B97-T86YD<V=R;V]T=&4`07)C:&EE9FYA86T`5V5E
M="!U('IE:V5R(&1A="!U("5S('=I;'0@=F5R=VEJ9&5R96X_`%=E970@=2!Z
M96ME<B!D870@=2!D92!G97-E;&5C=&5E<F1E(&EN=F]E<B!W:6QT('9E<G=I
M:F1E<F5N/P!7965T('4@>F5K97(@9&%T('4@:&5T(&%A;FUE;&1I;F=S=F5R
M>F]E:R!V86X@)7,@=VEL="!V97)W:6ID97)E;C\`07)G96YT:6YIZP!!<FUE
M;FGK`$%R;65E;G,@*$%235-#24DM."D`2W5N<W0`07)U8F$`5&]E;F5M96YD
M`$%S8V5N<VEO;B!E:6QA;F0`07-C:6D@:W5N<W0`07IIZR]086-I9FES8VAE
M(%)E9VEO`$]M(&)E=F5S=&EG:6YG('9R86=E;B!V;V]R(&AE="!U:71V;V5R
M96X@=F%N(&]N9&5R:&]U9'-W97)K>F%A;6AE9&5N/P!/<&1R86-H="!K;VQO
M;6UE;@!0;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F1E(&=R;V5P('1E('9E
M<G=I:F1E<F5N+@!0;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@
M=&4@=F5R=VEJ9&5R96XN`%!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9"!R
M96-H="!T92!B97=E<FME;BX`4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD
M92!S:&%R92!T92!B97=E<FME;BX`071T<FEB=71E;@!!=6=U<W1U<P!!=7-T
M<F%L:>L`3V]S=&5N<FEJ:P!!=71H7V-Y<G-Q;#H@=F5R96ES=&4@:6UA<"!E
M>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7V-Y<G5S.B!B86-K96YD(&AE
M969T(&YI970@9&4@=F5R96ES=&4@8F5K=V%A;6AE9&5N+@!!=71H7V-Y<G5S
M.B!V97)E:7-T92!I;6%P(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?
M9G1P.B!V97)E:7-T92!&5%`@97AT96YT:64@;FEE="!G979O;F1E;BX@0V]M
M<&EL965R(%!(4"!M970@9&4@+2UE;F%B;&4M9G1P(&]P=&EE+@!!=71H7VEM
M87`Z('9E<F5I<W1E($E-05`@97AT96YT:64@;FEE="!G979O;F1E;BX`075T
M:%]K<F(U.B!V97)E:7-T92!K<F(U(&5X=&5N=&EE(&YI970@9V5V;VYD96XN
M`$%U=&A?;&1A<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N
M9&5N+@!!=71H7VQD87`Z($YI970@:6X@<W1A870@9V5B<G5I:V5R("5S('1O
M92!T92!V;V5G96XN($1E('-E<G9E<B!M96QD=#H@`$%U=&A?;&1A<#H@3FEE
M="!I;B!S=&%A="!G96)R=6EK97(@)7,@=&4@=F5R=VEJ9&5R96X`075T:%]L
M9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!B:6H@=&4@=V5R:V5N
M`$%U=&A?;6-A;#H@=F5R96ES=&4@34-!3"!E>'1E;G1I92!N:65T(&=E=F]N
M9&5N+@!!=71H7W-M8F%U=&@Z('9E<F5I<W1E('-M8F%U=&@@97AT96YT:64@
M;FEE="!G979O;F1E;BX`075T:&5N=&EC871I92!M:7-L=6MT`$%U=&AE;G1I
M8V%T:64@;6ES;'5K="X@)7,`075T:&5N=&EC871I92!G97=E:6=E<F0@9&]O
M<B!D92!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EE(&]P($944"!S97)V
M97(@;6ES;'5K="X`0F5S8VAI:V)A<F4@=F5L9&5N.@!!>F5R8F%I9'IJ86X`
M0D]&2"!%>&-U<V5S`$%C:'1E<F=R;VYD`$%C:'1E<F=R;VYD:VQE=7(`1F]U
M="!K97)B97)O<W=A8VAT=V]O<F0N`$9O=71E(&ME<F)E<F]S9V5B<G5I:V5R
M<VYA86TN`$)A:&%M87,`0F%H<F5I;@!"86QT:7-C:"`H25-/+3@X-3DM,3,I
M`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S:7-L:6IN`$5E;G9O=61I9R!Z;V5K
M96X`5VET(')U<VQA;F0`0F5L9VGK`$)E;&EZ90!/;F1E<B!Z;V5K9F]R;75L
M:65R`$)E;FEN`$)E<FUU9&$`0FAU=&%N`%9E<F)I;F1I;F<@;6ES;'5K=#H@
M*"5S*2`E<P!697)J86%R9&%G`$)L;VL@(B5S(B!V86X@=&]E<&%S<VEN9R`B
M)7,B(&YI970@9V5V;VYD96XN`$)L;VMI;G-T96QL:6YG96X`0FQO:W1Y<&4`
M5F5T`$)O;&EV:6$`0F]O:VUA<FMS`%)A;F0`4F%N9&1I:W1E.@!286YD96X`
M0F]S;FGK(&5N($AE<GIE9V]V:6YA`$)E:61E;@!";W1S=V%N80!/;F1E<FMA
M;G0`0F]U=F5T(&5I;&%N9`!"<F%Z:6QIZP!"<FET<R!);F1I<V-H92!/8V5A
M86X@5&5R<FET;W)I=6T`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6IE`$]N
M9V5O<F1E;F1E(&QI:G-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`%IA:V5L:6IK
M92!C871E9V]R:64`0TU3`$-20P!#4DP@1&ES=')I8G5T:65P=6YT96X`0U-6
M`$-?96QE:6=E;G-C:&%P<&5N+BXN`$%G96YD80!+86QM`$-A;6)O9&IA`$MA
M;65R;V5N`$MA;B!W86-H='=O;W)D(&YI970@875T;VUA=&ES8V@@<F5S971T
M96XL(&YE96T@8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E<BX`
M2V%N(&YI970@=F5R8FEN9&5N(&UE="!)34%0('-E<G9E<CH@)7,`0V%N861A
M`$%F8G)E:V5N`%!R;V)L965M<F%P<&]R="!A9F)R96ME;@!+86X@8F5S=&%N
M9"`B)7,B(&YI970@=F5R=VEJ9&5R96XN`$MA;B!G965N('1I:F1E;&EJ:V4@
M9&ER96-T;W)Y('9I;F1E;BX`2V%N(&YI970@9&]O<F=A86X@>F]N9&5R("=T
M87)G971&:6QE)R!P87)A;65T97(N`$MA;B!D:7)E8W1O<GD@(B5S(B!N:65T
M('9E<G=I:F1E<F5N+@!+86X@;FEE="!V97)W:6ID97)E;CL@)60@8VAI;&1R
M96X@8F5S=&%A;BX`2V%N(&YI970@;W!N:65U=R!R86YG<V-H:6MK96XL(&AE
M="!A86YT86P@:6YV;V5R96X@;VT@;W!N:65U=R!T92!R86YG<V-H:6MK96X@
M:V]M="!N:65T(&]V97)E96X@;65T(&AE="!O<&=E<VQA9V5N(&%A;G1A;"X`
M2V%N(&)E<FEC:'0@;FEE="!N86%R(&AE="!O<&=E9V5V96X@;G5M;65R('9E
M<G-T=7)E;BX`2V%A<"!697)D90!/<'-C:')I9G0`0V%T96=O<FEEZVX@96X@
M;&%B96QS`$-A>6UA;B!E:6QA;F1E;@!496PN;G(N;6]B:65L`$-E;&5I9V5N
M<V-H87!P96X`0V5L('9R:6IE(')U:6UT93H`0V5L96EG96YS8VAA<'!E;@!#
M96QS<&%T:>MR:6YG.@!496PN;G(N;6]B:65L`$ME;'1I<V-H("A)4T\M.#@U
M.2TQ-"D`36ED9&5N`$-E;G1R86%L($%F<FEK86%N<V4@4F5P=6)L:65K`$-E
M;G1R86%L($5U<F]P965S("A)4T\M.#@U.2TR*0!#97)T:69I8V%A=&1E=&%I
M;',`0V5R=&EF:6-A871B96QE:60`5'-J86%D`%=I:GII9V5N`%=I:GII9R!D
M92!N86%M+"!A9')E<R!E;B!O;F1E<G1E:V5N:6YG(&1I92!M96X@>FEE="!B
M:6H@:&5T(&QE>F5N(&5N(&)E86YT=V]O<F1E;B!V86X@=7<@92UM86EL<RX`
M2V%R86MT97(`0V]N=%]R;VQE97(@;&EN:RXN+@!#;VYT<F]L965R(%]!;&QE
M<R]'965N`$-H:6QI`$-H:6YA`$-H:6YE97,@=F5R965N=F]U9&EG9"`H1T(R
M,S$R*0!#:&EN965S('1R861I=&EO;F5E;"`H0FEG-2D`2VEE<R!E96X@=V%C
M:'1W;V]R9`!+:65S(&5E;B!G96)R=6EK97)S;F%A;0!+:65S(&5E;B!A9')E
M<V)O96L`2VEE<R!D871U;7=E97)G879E.@!+:65S(&QI:G-T<W1I:FQT>7!E
M("AV;V]R(&=E;W)D96YD92!L:6IS=&5N*0!#:')I<W1M87,@96EL86YD`$-L
M87-S9&5F:6YI=&EE('9A;B`E<R!N:65T(&=E=F]N9&5N+@!(96QD97(`35-/
M9F9I8V4@=&%G<R!W:7-S96X`5VES(&=E8G)U:6ME<CH@)7,`5VES(&=E8G)U
M:6ME<@!7:7,@9V5B<G5I:V5R<V1A=&$`2VQI:R!O;2!V97)D97(@=&4@9V%A
M;@!#;&EC:V%T96QL('9I82!(5%10`%-L=6ET('-C:&5R;0!7;VQK96X`0F5W
M;VQK=`!#;V-O<R`H2V5E;&EN9RD@96EL86YD96X`26YG96ML87!T92!R86YD
M96X`0V]L;VUB:6$`2VQE=7(`2VQE=7)E;FMI97IE<@!+;&5U<G-E;&5C=&EE
M`$MO;&]M;65N.@!+;VQO;6]P=&EE<P!+;VQO;71I=&5L<P!3=')I<',`2V]M
M;6$@9V5S8VAE:61E;B!W86%R9&5N`$MO;6UA(&=E<V-H96ED96X@=V%A<F1E
M;B`H36EC<F]S;V9T($]U=&QO;VLI`$]P9')A8VAT`$]P9')A8VAT<VAE;&P`
M3W!M97)K:6YG`$%L9V5M96YE(&YA86T`0V]M;W)E;@!"961R:6IF`$)E9')I
M:F9S861R97,`0V]M<'5T97)S`$-O;F1I=&EE<P!697)S8VAI;&QE;B!I;B!C
M;VYF:6=U<F%T:64`)7,@8V]N9FEG=7)E<F5N`$)E=F5S=&EG('=A8VAT=V]O
M<F0`2V]N9V\`2V]N9V\L($1E($1E;6]C<F%T:7-C:&4@4F5P=6)L:65K('9A
M;B!D90!697)B:6YD:6YG(&UI<VQU:W0N`%9E<F)I;F1I;F<@;6ES;'5K=#H@
M`%9E<F)I;F1I;F<@;6ES;'5K=#H@)7,`5F5R8FEN9&EN9R!M:7-L=6MT`%9E
M<F)I;F1I;F<L(&UE="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G
M97=E:6=E<F0N`%9E<F)I;F1I;F<L(&UE="!D92!O<&5N8F%R92!S;&5U=&5L
M<V5R=F5R+"!I<R!G97=E:6=E<F0N(%)E9&5N.B`E<R`H)7,I`%9E<F)I;F1I
M;F<@;65T($944"!S97)V97(@;6ES;'5K="X`061R97,@=F%N(&QI:G-T('9E
M<G=I:F1E<F0N`$%D<F5S<V5N(&EN(&QI:G-T.B`E<P!!9')E<W-E;B!Z:6IN
M(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E:R!T;V5G979O96=D+@!$;V]R
M9V%A;@!#;V]K(&5I;&%N9&5N`$-O;VMI90!+;W!IZW)E;@!+;W!I965R('-E
M;&5C=&EE`$-O<W1A(%)I8V$`279O;W)K=7-T`$MO;B!01U`@8F5R:6-H="!N
M:65T(&-O9&5R96XN`$MO;B!01U`@8F5R:6-H="!N:65T(&]N9&5R=&5K96YE
M;BX`2V]N(&)E<FEC:'0@;FEE="!3+TU)344@8V]D97)E;BX`2V]N(&)E<FEC
M:'0@;FEE="!3+TU)344@;VYD97)T96ME;F5N+@!+;VX@861R97,@)7,@;FEE
M="!T;V5V;V5G96XN`$MO;B!G965N('9E<F)I;F1I;F<@;65T(&1E($Q$05`M
M<V5R=F5R(&UA:V5N+@!+;VX@=&5G;V5D("5S(&YI970@8V]N=')O;&5R96XN
M`$MO;B!G965N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;6%K96XN`$MO;B!01U`@
M9&%T82!N:65T(&1E8V]D97)E;BX`2V]N(%,O34E-12!D871A(&YI970@9&5C
M;V1E<F5N+@!+;VX@861R97,@)7,@;FEE="!V97)W:6ID97)E;BX`2V]N(&1I
M<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!V97)W:6ID97)E;BX`2V]N(&AE="!E
M+6UA:6QA9')E<R!V86X@9&4@;VYT=F%N9V5R(&YI970@8F5P86QE;BX`2V]N
M(&-O;7!L971E(&%D<F5S8F]E:R!N:65T(&]P:&%L96XN`$MO;B!C;VUP;&5T
M92!D:7-T<FEB=71I96QI:G-T(&YI970@;W!H86QE;BX`2V]N(&-O;7!L971E
M(&QI:G-T('9A;B!D:7-T<FEB=71I96QI:G-T96X@;FEE="!O<&AA;&5N+@!+
M;VX@9&4@;W!E;F)A<F4@<VQE=71E;"!N:65T('9E<FMR:6IG96X@=F%N(&1E
M('-L975T96QS97)V97(N`$MO;B`E<R!N:65T(&]P96YE;BX`2V]N(&]N9&5R
M:&]U9'-T86ME;FUO9'5L92`E<R!N:65T(&]P96YE;@!+;VX@)7,@;FEE="!L
M97IE;BX`2V]N(&AE="!W86-H='=O;W)D('9A;B!D92!G97=E;G-T92!G96)R
M=6EK97(@;FEE="!R97-E='1E;BX@4V]M;6EG92!O9B!A;&QE(&1E=&%I;',@
M>FEJ;B!N:65T(&IU:7-T+B!0<F]B965R(&]P;FEE=7<@;V8@;F5E;2!C;VYT
M86-T(&]P(&UE="!D92!S>7-T965M8F5H965R9&5R+"!W86YN965R('4@=F5R
M9&5R92!H=6QP(&YO9&EG(&AE969T+@!+;VX@04-,(&YI970@;W!H86QE;@!+
M;VX@861R97-B;V5K("5S(&YI970@;W!H86QE;BX`2V]N(&1I<W1R:6)U=&EE
M;&EJ<W0@)7,@;FEE="!O<&AA;&5N+@!+;VX@9&ES=')I8G5T:65L:6IS=&5N
M("5S(&YI970@;W!H86QE;BX`2V]N('-E<G9E<F)E:W=A86UH961E;B!N:65T
M(&]P:&%L96X`2V]N(&-O;F9I9W5R871I92!N:65T('1E<G5G>F5T=&5N+@!+
M;VX@8V]N9FEG=7)A=&EE("5S(&YI970@;W!S;&%A;BX`2V]N(&=E96X@8F%C
M:W5P8V]N9FEG=7)A=&EE(&]P<VQA86XN`$MO;B!D92!,1$%0+7-E<G9E<B!N
M:65T(&1O;W)Z;V5K96XN`$MO;B!A9')E<R`E<R!N:65T(&)I:G=E<FME;BX`
M2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!B:6IW97)K96XN`$MO;B!D
M92!-;WII;&QA(%-I9&5B87(@;FEE="!V:6YD96XN(%IO<F<@97)V;V]R(&1A
M="!D92!S:61E8F%R(&]P96X@:7,N`$=E=&5L9&4@=&5K<W0`3&%N9`!#=7)S
M=7-S96X`36%A:R!E96X@;&EN:P!-86%K(&5E;B!N:65U=V4`36%A:R!S=6)M
M87!P96X`1V5M86%K=`!%:6=E;F%A<G)E8VAT96X`0W)E9&ET8V%R9&YU;6UE
M<@!+<F]A=&GK`$-U8F$`2'5I9&EG92!T:6ID`$AU:61I9V4@55),(&ES`$AU
M:61I9R!W965R`$AU:61I9V4@8V]N9&ET:64Z(`!(=6ED:6=E('-T:6IL`$%A
M;G!A<W-E;B!V86X@=&%K96X@=&EJ9&5N<R!A86YM96QD:6YG(&)I:B`E<RX`
M2VYI<'!E;@!396QE8W1I92!K;FEP<&5N`$-Y<')U<P!#>7)I;&QI<V-H("A+
M3TDX+5(I`$-Y<FEL;&ES8V@@*%=I;F1O=W,M,3(U,2D`0WER:6QL:7-C:"]5
M:W)A:6YS("A+3TDX+54I`%1S:F5C:&ES8VAE(%)E<'5B;&EE:P!$1`!$86=E
M;&EJ:W,`1&%T851R964@8G)O=W-E<@!$871U;0!$871U;2!/;G1V86YG96X`
M1&%T=6T@<V5L96-T:64`1&%G`%9E<E]W:6ID97(@:V]L;VT`1&5C96UB97(`
M1&5C:6UA;&4@9V5T86QL96X`26YS<')I;F=E;B!V97)K;&5I;F5N`%-T86YD
M86%R9"!K;&5U<@!3=&%N9&%A<F0@:61E;G1I=&5I=`!3=&%N9&%A<F0@<V]R
M=&5E<G9O;&=O<F1E.@!$969I;FET:65S`%9E<G=I:F1E<F5N`%9E<G=I:F1E
M<F)E=F5S=&EG:6YG`$=R;V5P('9E<G=I:F1E<F5N`%)E8VAT('9E<G=I:F1E
M<F5N`%9E<G=I:F1E<B!E;B!W:7,@8F5R:6-H=&5N`%9E<G=I:F1E<FMN;W!G
M961R86<`5F5R=VEJ9&5R(&-E;`!697)W:6ID97(@:V]L;VT`0F5S=&%A;F0@
M86QT97)N871I968@<VIA8FQO;VX@=F5R=VEJ9&5R96X`5F5R=VEJ9&5R96X@
M;6ES;'5K=#H@*"5S*2`E<P!697)W:6ID97(@<FEJ`$=E<V5L96-T965R9&4@
M:61E;G1I=&5I="!V97)W:6ID97)E;@!697)W:6ID97(@9&4@:'5I9&EG92!K
M;VQO;0!697)W:6ID97(@9&4@:'5I9&EG92!R:6H`5F5R=VEJ9&5R96X@;6ES
M;'5K=`!!9FQE=F5R=&EJ9`!$96YE;6%R:V5N`$%F9&5L:6YG`$%F;F5M96YD
M`$)E<V-H<FEJ9B!H970@<')O8FQE96T`1&5T86EL<R`H;V]K(&EN($AO<F1E
M)W,@;&]G8F5S=&%N9"DZ`$1E=&%I;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S
M>7-T965M8F5H965R9&5R+@!/;G1W:6MK96QI;F<`1&%U=W!U;G0`1&%U=W!U
M;G0@=F]O<B!H970@869G96QO<&5N('5U<CH@`$1A=7=P=6YT.B``4FEC:'1I
M;F<@;&EN:W,@;F%A<B!R96-H=`!2:6-H=&EN9R!R96-H=',@;F%A<B!L:6YK
M<P!$:7)E8W1O<GD`,C0M=75R<R!T:6ID=V5E<F=A=F4_`%=E97)G879E;W!T
M:65S`%=E97)S=F]O<G-P96QL:6YG('1O;F5N("A4048I`%=E97)G879E9F]R
M;6%A=`!6;V]R8F5R96ED:6YG<VYO=&EF:6-A=&EE`$1J:6)O=71I`$YI970@
M=F5R=VEJ9&5R96X`;6%I;G1E;F%N8V4N<&AP(&YI970@9&ER96-T(&%A;G-P
M<F5K96X`5VEL="!U(&AE="!V97)W:6ID97)E;B!V86X@:6YV;V5R(&)E=F5S
M=&EG96X_`$)E=F%T(&1E(&5E<G-T92!R:6H@9&4@=F5L9&YA;65N/R!:;R!J
M82P@9&ET(&AO:VIE(&%A;G9I;FME;CH`1&]M:6YI8V$`1&]M:6YI8V%A;G-E
M(%)E<'5B;&EE:P`E<R!D;W=N;&]A9&5N`$1O=VYL;V%D(&=E9V5N97)E97)D
M92!C;VYF:6=U<F%T:64@86QS(%!(4"!S8W)I<'0N`$1O=VYL;V%D('9#87)D
M`$1R;W`@9&]W;B!L:6IS=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`0F5W
M97)K96X`0FQO:R!B97=E<FME;@!'<F]E<"!B97=E<FME;@!296-H="!B97=E
M<FME;@!296-H=&5N(&)E=V5R:V5N`%)E8VAT96X@=F%N("<E<R<@8F5W97)K
M96X`26YV;V5R(&)E=V5R:V5N('9O;W(@)7,`3W!T:65S(&)E=V5R:V5N('9O
M;W(Z`%)E8VAT96X@=F%N("5S(&)E=V5R:V5N`$]N9&5R=VEJ<P!%9WEP=&4`
M16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%+6UA:6P`12UM86EL861R97,`
M12UM86EL861R97-S96X@;6]E=&5N(&]V97)E96YK;VUE;BX`12UM86EL(&UE
M="!B979E<W1I9VEN9P!%;6]T:6-O;G,`3&5E9R!B97)I8VAT+@!'965N(')E
M<W5L=&%A="X`3&5G92!Z;V5K=&5R;65N`$EN=F]E9V5N('9A;B!A9F)E96QD
M:6YG96X@=6ET(&9O=&]A;&)U;7,@:6X@=&5K<W0@:6YS8VAA:V5L96X_`%)E
M8VAT:VQI:VME;B!C;VYT97AT(&UE;G4@:6YS8VAA:V5L96X_`$5I;F1J86%R
M`%9E<F=R;V]T(&5D:71O<@!'965F(&5E;B!B979E:6QI9VEN9W-V<F%A9R!D
M:64@=2!G979R86%G9"!W;W)D="P@=V%N;F5E<B!H970@;F]D:6<@:7,@;VT@
M=7<@=V%C:'1W;V]R9"!T92!R97-E='1E;BP@8BYV+B`G=V%T(&ES(&1E(&YA
M86T@=F%N('5W(&AU:7-D:65R/R<Z`%9O97(@9&4@869B965L9&EN9R!54DP@
M:&EE<B!I;@!);G9O97(@=F]O<B`E<R!B:6IG97=E<FMT+@!%<75A=&]R:6%A
M;"!'=6EN964`17)I=')E80!&;W5T`$9O=70@;65T(&4M;6%I;&)E<FEC:'0N
M`$5S=&QA;F0`171H:6]P:>L`171N:7-C:`!%=7)O<&$`16QK92`Q-2!M:6YU
M=&5N`$5L:V4@,B!M:6YU=&5N`$5L:V4@,S`@<V5C;VYD96X`16QK92`U(&UI
M;G5T96X`16QK92!A86YM96QD:6YG`$5L:R!H86QF('5U<@!%;&ME(&UI;G5U
M=`!6;V]R8F5E;&1W86%R9&5N.@!5:71V;V5R96X`56ET:VQA<'!E;@!697)W
M86-H='1E("<I)P!697)W86-H='1E(&5N:V5L('=O;W)D(&]F(&%A;F=E:&%A
M;&1E('IO96MT97)M`%9E<G9A;&1A='5M`$5X<&]N96YT`$5X<&]R=&5R96X`
M061R97-B;V5K(&5X<&]R=&5R96X`06QL965N(&1E(&=E<V5L96-T965R9&4@
M861R97-S96X@97AP;W)T97)E;BX`2&5T('9O;&=E;F1E(&%D<F5S8F]E:R!V
M;VQL961I9R!E>'!O<G1E<F5N+@!6;V]R9W)O;F1K;&5U<@!&5%`@=7!L;V%D
M('9A;B!S971U<`!/<&AA;&5N('9O;W)K975R<VEN<W1E;&QI;F=E;B!M:7-L
M=6MT+@!4;V5G86YG('1O="!A9')E<V)O96L@;6ES;'5K=#H@)7,`5&]E=F]E
M9V5N('9A;B`E<R!A86X@)7,@;6ES;'5K=#H@)7,`0FQA9&5R96X@:6X@;&EJ
M<W0@;6ES;'5K=`!";&%D97)E;B!I;B!D:7)E8W1O<GD@;6ES;'5K=`!697)B
M:6YD:6YG(&UE="!D92!,1$%0+7-E<G9E<B!I<R!M:7-L=6MT+@!697)B:6YD
M:6YG(&UE="!D92!334(M<V5R=F5R(&ES(&UI<VQU:W0N`$MO<&GK<F5N('5I
M="`B)7,B(&ES(&UI<VQU:W0N`$MO<&GK<F5N(&YA87(@(B5S(B!I<R!M:7-L
M=6MT+@!-86ME;B!V86X@;FEE=7=E(%-!4TP@=F5R8FEN9&EN9R!I<R!M:7-L
M=6MT+@!6:6YD96X@=F%N('1O92!T92!V;V5G96X@;V)J96-T(&UI<VQU:W0Z
M("5S`%9E<G!L86%T<V5N(&YA87(@(B5S(B!I<R!M:7-L=6MT+@!$;V]R>F]E
M:V5N('9A;B!D:7)E8W1O<GD@)7,@;6ES;'5K="X`36]O:0!&86QK;&%N9"!E
M:6QA;F1E;B`H36%L=FEN87,I`$9A<F_K<B!E:6QA;F1E;@!&87@`1F5B<G5A
M<FD`5F]E;'0@86QS`%9O96QT(&%L<SH@`$5N:V5L92!B=6EE;@!&:6II`$%A
M;G1A;"!B97-T86YD96XZ("5S(&)E<W1A;F0`06%N=&%L(&)E<W1A;F1E;CH@
M)7,@8F5S=&%N9&5N`$)E<W1A;F1B96AE97(`0F5S=&%N9'-N86%M`$)E<W1A
M;F0@:VEE>F5N`$)E<W1A;F1U<&QO860`0F5S=&%N9'5P;&]A9',@=V]R9&5N
M(&YI970@;VYD97)S=&5U;F0N`$9I;'1E<G,`5FEN9&5N`$9I;FQA;F0`165R
M<W1E(&AE;&9T`%9O;W)N86%M`$5E<G-T92!K=V%R=&%A;`!697)H;W5D:6YG
M(&AE<G-T96QL96X`3VUK97)E;@!$<FEJ=F5N`$UI<W0`36%P("5S(&)E<W1A
M870@;FEE=`!&;VYT:VQE=7(`5F]E9'-E;`!6;V]R(&)R;W=S97)S(&1I92!G
M965N(&%F8F5E;&1I;F=E;B!O;F1E<G-T975N96X`5V5E<G-V;V]R<W!E;&QI
M;F<@*%1!1BD`5F]O<G5I='II8VAT9&%G96X@*&UE<FL@;W`@9&%T(&AE="!G
M96=E=F5N('9O;W)U:71Z:6-H="!D86=E;B!E;B!N86-H=&5N(&=E969T.R!E
M96X@9W)O;W0@86%N=&%L(&MA;B!R97-U;'1E<F5N(&EN(&5E;B!B<F5E9"!B
M;&]K*0!5=R!W86-H='=O;W)D('9E<F=E=&5N/P!&;W)M=6QI97)E;@!&;W)T
M=6YE`$9O<G1U;F5T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$1O
M;W)S='5R96X`5G(`1G)A;65S`$9R86YK<FEJ:P!&<F%N:W)I:FLL($AO;V9D
M<W1E9&5L:6IK`$9R965B=7-Y(%523`!&<F%N<R!'=7EA;F$`1G)A;G,@4&]L
M>6YE<VGK`$9R86YS92!:=6ED96QI:FME(%1E<G)I=&]R:6$`5F%N`%9A;B!D
M92``5F]L;&5D:6=E(&)E<V-H<FEJ=FEN9P!6;VQL92!M86%N`%9O;&QE9&EG
M92!N86%M`$=A8F]N`$%L8G5M('=A87)U:70@9&4@869B965L9&EN9R!G96AA
M86QD(&1I96YT('1E('=O<F1E;@!!;&)U;3H`1V%M8FEA`$=E;F5R965R("5S
M(&-O;F9I9W5R871I90!'96=E;F5R965R9&4@8V]D90!'96]R9VGK`$1U:71S
M;&%N9`!':&%N80!':6)R86QT87(`5F]O<FYA86T`1VQO8F%L92!A9')E<V)O
M96L`1V$`1V]E9&5L`$=O;V=L92!Z;V5K96X`1W)I:G-S8VAA86P`1W)I96ME
M;FQA;F0`1W)I96MS("A)4T\M.#@U.2TW*0!'<F]E;FQA;F0`1W)E;F%D80!'
M<F]E<`!'<F]E<'-B96AE97(`1W)O97!N86UE;B!M;V=E;B!N:65T(&QE96<@
M>FEJ;@!'<F]E<&5N`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS
M97D`1V%S="!R96-H=&5N`$=A<W1E;F)O96L`1W5I;F5E`$=U:6YE92U":7-S
M874`1W5Y86YA`$A434P`2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@;&%A
M='-T92!C96P@:6X@9&4@<FEJ('1E('9E<G=I:F1E<F5N+@!(5$U,07)E82!W
M96EG97)T(&QA9B!O;2!D92!L86%T<W1E(&MO;&]M(&EN(&1E('1A8F5L('1E
M('9E<G=I:F1E<F5N+@!(5$U,07)E82!W96EG97)T(&QA9B!O;2!D92!L86%T
M<W1E(')I:B!I;B!D92!T86)E;"!T92!V97)W:6ID97)E;BX`2%144"!A=71H
M96YT:6-A=&EE(&YI970@9V5V;VYD96XN`$AA:71I`$AA<V@M86QG;W)I=&AM
M90!.979E;`!+;W``2&5A<F0@96EL86YD(&5N($UC1&]N86QD(&5I;&%N9&5N
M`$AE8G)E975W<R`H25-/+3@X-3DM."U)*0!(;V]G=&4`2&5L<`!(96QP(&)I
M:B!G96)R=6EK('9A;B!E9&ET;W(`2&5L<&5R`$AA;&9R;VYD`$AI97(@:7,@
M:&5T(&)E9VEN('9A;B!H970@8F5S=&%N9#H`2&]O9P!(;U]M90!(;VQY(%-E
M92`H5F%T:6-A86YS=&%D*0!(;VUE`$%D<F5S("AP<FEVZ2D`5V]O;G!L86%T
M<R`H<')I=NDI`$QA;F0@*'!R:7;I*0!496PN;G(N("AP<FEVZ2D`4&]S=&-O
M9&4@*'!R:7;I*0!3=&%A="!O9B!P<F]V:6YC:64@*'!R:7;I*0!(;VYD=7)A
M<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($]N9V5L9&EG92`E<R!8
M34P@9&%T82!T96=E;F=E:V]M96X@:6X@8F5R:6-H="`E<P!(;W)D92]+;VQA
M8CH@1V5E;B!B97)I8VAT(&-O<G)E<W!O;F1E97)T(&UE="!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z($=E96X@;V)J96-T('9A;B!T>7!E("5S(&=E=F]N9&5N
M(&EN(&)E<FEC:'0@)7,`2&]R9&4O2V]L86(Z("5S(&UE="!S=6-C97,@=F5R
M=VEJ9&5R9"`B)7,B`$AO<F1E+TMO;&%B.B!$92!I;G1E<F=R871I92!V97)E
M:7-T(&1E("=D;VUX;6PG(&5X=&5N<VEE`$AO<F1E+TMO;&%B.B!+86X@9V5E
M;B!N:65U=V4@6$U,(&)O;VT@;6%K96X@=F]O<B!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($MA;B`E<R`B)7,B(&YI970@=F5R=VEJ9&5R96XZ("5S`$AO<F1E
M+TMO;&%B.B!.:65T(&EN('-T86%T(&AE="!-24U%($E$+"!V;V]R(&AE="!G
M961E96QT92!M970@='EP92`E<RP@;W`@=&4@:&%L96X`2&]R9&4O2V]L86(Z
M($MA;B`E<R`B)7,B(&YI970@<WEN8VAR;VYI<V5R96XZ("5S`$AO<F1E+TMO
M;&%B.B!+86X@9V5D965L9&4@8G)O;FYE;B!N:65T('-Y;F-H<F]N:7-E<F5N
M.B`E<P!(;W)D92]+;VQA8CH@3VYB96ME;F1E(&=E9&5E;&1E(&)R;VX@(B5S
M(@!(;W)I>F]N=&%L92!L:6IN`$AO<FEZ;VYT86QE('9R:6IE(')U:6UT90!(
M;W)I>F]N=&%A;#H`2&]E(&MW86T@=2!H:65R/R`H1W)A86<@<F%P<&]R=&%G
M92$I`$AO979E96P@:V]L;VUM96X@=VEL="!U('-A;65N=F]E9V5N/P!(;V5V
M965L('9E;&1E;B`H:V]L;VUM96XI('II:FX@97(_`$AO979E96P@<FEJ96X@
M=VEL="!U('-A;65N=F]E9V5N/P!6;V-H=&EG:&5I9`!6;V-H=&EG:&5I9#H@
M`$AU;6]R:7-T96X`2&]N9V%R:6IE`$UA:V5N('9A;B!)34%0(&UA:6QB;W@@
M;6ES;'5K=#H@)7,`5F5R=VEJ9&5R96X@=F%N($E-05`@;6%I;&)O>"!M:7-L
M=6MT.B`E<P!-86ME;B!V86X@24U!4"!M86EL8F]X('%U;W1A(&UI<VQU:W0Z
M("5S`$E-4U``25`@061R97,`25`@861R97,@;FEE="!B97-C:&EK8F%A<BX`
M25`@861R97,@=F%L="!N:65T(&)I;FYE;B!H970@=&]E9V5S=&%N92!#2412
M(&)L;VLN`$E0(&QO8VMD;W=N(&]V97)T<F5D:6YG+@!2:6H@:5]N=F]E9V5N
M('9O;W(`24IS;&%N9`!!;&QE96X@<&EC=&]G<F%M;65N`%!I8W1O9W)A;6UE
M;B!M970@=&5K<W0`261E;G1I=&5I='-N86%M.@!786YN965R(&AE="!N:65T
M(&=O960@=V]R9'0@=V5E<F=E9V5V96XL("5S(&]M(&AE="!I;B!E96X@;FEE
M=7<@<V-H97)M('1E(&]P96YE;BX`06QS('4@9V5E;B!P:6-T;V=R86UM96X@
M>FEE="P@8FEJ(&=E8G)U:6L@=F%N($EN=&5R;F5T($5X<&QO<F5R+"!K86X@
M:&5T(&YO9&EG('II:FX@9&ET('9A:VIE(&%A;B!T92!V:6YK96X@;VT@4$Y'
M('1R86YS<&%R871I92!U:70@=&4@<V-H86ME;&5N+@!786YN965R('4@9&ET
M(&)E<FEC:'0@>FEE="P@;6%A<B!G965N(&%F8F5E;&1I;F<L(&1A;B!K86X@
M9&4@869B965L9&EN9R!D:64@=2!W:6QT('5P;&]A9&5N(&YI970@9&]O<B!U
M=R!B<F]W<V5R('=O<F1E;B!W965R9V5G979E;BX`069B965L9&EN9W-B96]O
M<F1E;&EN9SH`069B965L9&EN9R!54DP`069B965L9&EN9R!54DPZ`$%F8F5E
M;&1I;F<@=6ET(&%L8G5M`$%F8F5E;&1I;F<@=6ET(&%L8G5M.@!!9F)E96QD
M:6YG<W5P;&]A9`!!9F)E96QD:6YG96X`061R97-B;V5K(&EM<&]R=&5R96XL
M('-T87`@)60`26UP;W)T97)E;BP@<W1A<"`E9`!!9')E<V)O96ME;B!I;7!O
M<G1E<F5N+V5X<&]R=&5R96X`1V5I;7!O<G1E97)D('9E;&0Z("5S`$=E:6UP
M;W)T965R9&4@=F5L9&5N.@!2:6H@:6YV;V5G96X@;F$`3VYJ=6ES=&4@8F5W
M97)K:6YG<V-O9&4@;W!G96=E=F5N+@!/;FIU:7-T92!G96)R=6EK97)S;F%A
M;2!E;B]O9B!W86-H='=O;W)D+@!/;FIU:7-T92!G96)R=6EK97)S;F%A;2!O
M9B!A;'1E<FYA=&EE9B!A9')E<RX@4')O8F5E<B!O<&YI975W(&]F(&YE96T@
M8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E<BP@=V%N;F5E<B!U
M('9E<F1E<F4@:'5L<"!N;V1I9R!H965F="X`5F5R9W)O;W0@:6YS<')I;F=I
M;F<`26YD:6$`26YD:79I9'5E;&4@9V5B<G5I:V5R<P!);F1O;F5S:>L`26YF
M;P!);F9O<FUA=&EE`$MO;&]M(&EN=F]E9V5N(&YA`$%F8F5E;&1I;F<@:6YV
M;V5G96X`5&%B96P@:6YV;V5G96X`5V5B;&EN:R!I;G9O96=E;@!?2V]L;VT@
M:6YV;V5G96X@=F]O<@!%96X@;FEE=7=E(&MO;&]M(&EN=F]E9V5N(&YA(&1E
M(&AU:61I9V4`165N(&YI975W92!K;VQO;2!I;G9O96=E;B!V;V]R(&1E(&AU
M:61I9V4`165N(&YI975W92!R:6H@:6YV;V5G96X@;F$@9&4@:'5I9&EG90!%
M96X@;FEE=7=E(')I:B!I;G9O96=E;B!N82!D92!H=6ED:6=E`$5E;B!N:65U
M=V4@<&%R86=R86%F(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4@;F]D90!%96X@
M;FEE=7=E('!A<F%G<F%A9B!I;G9O96=E;B!N82!D92!H=6ED:6=E(&YO9&4`
M06QT97)N871I968@<VIA8FQO;VX@:6YV;V5G96X`165N(&4M;6%I;&%D<F5S
M(&EN=F]E9V5N+"!W86%R('4@:&5T(&YI975W92!W86-H='=O;W)D(&MA;B!O
M;G1V86YG96XZ`$-E;"!I;G9O96=E;B!N80!#96P@:6YV;V5G96X@=F]O<@!+
M;VQO;2!I;G9O96=E;B!N80!+;VQO;2!I;G9O96=E;B!V;V]R`$)E<FEC:'1E
M;B!I;G9O96=E;@!087)A9W)A868@:6YV;V5G96X@;F$`4&%R86=R86%F(&EN
M=F]E9V5N('9O;W(`4FEJ(&EN=F]E9V5N(&YA`%)I:B!I;G9O96=E;B!V;V]R
M`$AE="!G97=E;G-T92!A;G1W;V]R9"!V;V]R(&1E(&)E=F5I;&EG:6YG<W9R
M86%G(&EN=F]E9V5N.@!!9F)E96QD:6YG(&EN=F]E9V5N+V%A;G!A<W-E;@!,
M:6YK(&EN=F]E9V5N+V%A;G!A<W-E;@!/;G9O;&1O96YD92!K<F5D:65T(&]M
M(&YA87(@9&4@9&ES=')I8G5T:65L:6IS="!T92!Z96YD96XN`$]N=F]L9&]E
M;F1E(&MR961I970`26YT96=E<@!);G1E9V5R(&QI:G-T`$]N9V5L9&EG($E$
M`$]N9V5L9&EG92!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`3VYG96QD:6<@
M861R97-B;V5K`$]N9V5L9&EG92!T;V5P87-S:6YG+@!/;F=E;&1I9R!B871C
M:"!)1"X`3VYG96QD:6=E(&1A=&$@;W!G96=E=F5N+@!/;F=E;&1I9R!B97-T
M96UM:6YG861R97,N`$]N9V5L9&EG92!E+6UA:6P`3VYG96QD:6=E(&EN=F]E
M<@!/;F=E;&1I9R!T:6ID9F]R;6%A=`!/;F=E;&1I9V4@<VQE=71E;"!O<&=E
M9V5V96XN`$]N9V5L9&EG(&US9U]T>7!E+@!/;F=E;&1I9V4@;F%A;0!/;F=E
M;&1I9R!O8FIE8W1)9`!/;F=E;&1I9R!O9B!O;G1B<F5K96YD(&%P:5]I9"X`
M3VYG96QD:6=E(&]F(&]N=&)R96ME;F1E('!A<F%M971E<G,N`$]N9V5L9&EG
M('!A<F5N="!R96-H="X`3VYG96QD:6<@<')O=&]C;VPN`$]N9V5L9&EG92!G
M961E96QD92!B<F]N`$]N9V5L9&EG(&)R;VYA9')E<RX`3VYG96QD:6=E('5N
M:6-O9&4@9&%T82X`26YV96YT87)I<P!)<F%N+"!)<VQA;6ET:7-C:&4@4F5P
M=6)L:65K('9A;@!)<F%K`$EE<FQA;F0`16EL86YD($UA;@!'96ES;VQE97)D
M92!O;G=E97)S8G5I96X`27-R8>ML`%5I=&=E=F5R`$-U<G-I968`271A;&GK
M`$IA;6%I8V$`2F%N=6%R:0!*87!A;@!*87!A;G,@*$E33RTR,#(R+4I0*0!*
M97)S97D`2F]R9&%N:>L`2G5L:0!*=6YI`'5I=&QI:FYE;@!'96-E;G1R965R
M9"!U:71L:6IN96X`5F]L;&5D:6<@=6ET;&EJ;F5N`$QI;FMS('5I=&QI:FYE
M;@!296-H=',@=6ET;&EJ;F5N`$MA>F%C:'-T86X`3W)I9VEN965L(&)E:&]U
M9&5N/P!+96YI80!+97)B97)O<R!S97)V97(@=V5I9V5R9&4@875T:&5N=&EC
M871I92X`2V5R;F5L($YE=V)I97,`4VQE=71E;"!M86ME;@!3;&5U=&5L=FEN
M9V5R869D<G5K`%-L975T96QL96YG=&4`4VQE=71E;'1Y<&4`4VQE=71E;&=E
M8G)U:6L`1&4@<VQE=71E;"!B97-T86%T(&%L(&]P(&1E(&]P96YB87)E('-L
M975T96QS97)V97(N`$MI;F1E<F5N`$MI<FEB871I`$MO<F5A+"!$96UO8W)A
M=&ES8VAE(%9O;&MS<F5P=6)L:65K('9A;@!+;W)E82P@4F5P=6)L:65K('9A
M;@!+;W)E86%N<R`H155#+4M2*0!+;V5W96ET`$MY<F=I97-IZP!,1$%0(&]N
M9&5R<W1E=6YI;F<@:7,@=F5R96ES="P@;6%A<B!D92!,1$%0(&UO9'5L92!I
M<R!N:65T(&)E<V-H:6MB86%R(&]F(&YI970@9V5L861E;BX`3U]P;6%A:P!4
M86%L`$1E;6]C<F%T:7-C:&4@5F]L:W-R97!U8FQI96L@3&%O`$QA871S=&4@
M:&5L9G0`3&%A='-T(&=E=VEJ>FEG9`!!8VAT97)N86%M`$QA871S=&4@:W=A
M<G1I97(`3&%A='-T(&)I:F=E=V5R:W0Z`$QA871S=&4@86%N;65L9&EN9SH@
M)7,`3&%A='-T92!A86YM96QD:6YG.B`E<R!V86X@)7,`3&%A='-T92!A86YM
M96QD:6YG.B!.;V]I=`!,971L86YD`%)E8VAT96X`3W!M86%K`$QA870@;&5E
M9R!V;V]R(&=E96X@<F%N9`!,:6)A;F]N`$QI;FMS`$QI;FMS92!K;W``3&EN
M:W-E('=A87)D96X`3&5S;W1H;P!,:6)E<FEA`$QI8FES8VAE($%R86)I<V-H
M92!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`6F%C:'0@8G5I=&IE`$QI8VAT
M92!R96=E;@!6<F]E9R!L:6-H=&4@<F5G96X`3&EC:'1E(')E9V5N`$QI8VAT
M92!R96=E;F)U:0!,:6-H=&4@<F5G96X@;65T(&]N=V5E<@!,:6-H=&4@<VYE
M975W`$QI8VAT92!S;F5E=7=B=6D`3&EM97)I8VL`3&EN:P!,:6YK('=I:G-T
M(&YA87(Z`$QI;FL@:&5T(&4M;6%I;&%D<F5S(&%A;B!D92!N:65U=R!B97)I
M8VAT('!A9VEN82!T:6ID96YS('=E97)G879E`$QI;FMS`$QI;G5X($-O;VMI
M90!,:6IS=`!,:6IS="`M(&=E8G)U:6ME<B!K86X@9&4@;6%P('II96X`1&%T
M86)A<V5L:6IS=`!,:6IS="!V86X@:&5L<"!O;F1E<F1E;&5N`%1A8F5L;&EJ
M<W0`3&EJ<W0M07)C:&EE9@!,:6IS="U(96QP`$QI:G-T+4ED`$QI:G-T+45I
M9V5N86%R`$QI:G-T+5!O<W0`3&EJ<W0M26YS8VAR:6IV96X`3&EJ<W0M56ET
M<V-H<FEJ=F5N`%=E97)G979E;B!V86X@9V5B<G5I:V5R<VQI:G-T(&ES('5I
M=&=E<V-H86ME;&0N`$QI=&5R871U=7(`3&ET;W5W96X`3&%D96XN+BX`3&]K
M86QE('1I:F0Z`$QA;F1I;G-T96QL:6YG(&5N('1I:F0`3&]C871I90!!86YM
M96QD96X`069M96QD96X`06%N;65L9'1A:V5N`$%A;FUE;&1I;F<@;6ES;'5K
M="!O;61A="!U=R!G96)R=6EK97)S;F%A;2!O9B!W86-H='=O;W)D(&]N:G5I
M<W0@:7,@:6YG979O97)D+@!!86YM96QD:6YG(&UI<VQU:W0N`$QA;F=E('1E
M:W-T`$QI969D90!,86%G`$=R:65K<V4@:VQE:6YE(&QE='1E<G,`3&%T:6IN
M<V4@:VQE:6YE(&QE='1E<G,`2VQE:6YE(%)O;65I;G-E(&=E=&%L;&5N`$QU
M>&5M8G5R9P!-30!-3U1$`$U3+51.148@8FEJ;&%G92!B979A='1E(&=E96X@
M9&%T82X`35-'`$UA8V%O`$UA8V5D;VYIZRP@1&4@=G)O96=E<F4@2F]E9V]S
M;&%V:7-C:&4@4F5P=6)L:65K('9A;@!-861A9V%S8V%R`$UA9VEE`$4M;6%I
M;`!-86EL8F5H965R9&5R`$UA86L@;&EN7VLN+BX`36%L87=I`$UA;&5I<VGK
M`$UA;&%D:79E;@!-86QI`$UA;'1A`$)E:&5E<B!U=R!L:6IS="!M970@8V%T
M96=O<FEEZVX@96X@9&4@8V]R<F5S<&]N9&5R96YD92!K;&5U<F5N+"!W86%R
M;65E(&]N9&5R9&5L96X@=V]R9&5N(&=E;&%B96QD`$UA<#(T(&MA87)T`$UA
M<%%U97-T:V%A<G0`36%A<G0`36%R9V4`36%R:V5E<B!M970@1V5Z:65N+TYI
M970@1V5Z:65N('9L86=G96X`36%R:V5E<B!M970@86YD97)E('9L86=G96X@
M*&(N=BX@0F5L86YG<FEJ:R]"96%N='=O;W)D*0!-87)C:&%L;"!E:6QA;F1E
M;@!-87)T:6YI<75E`&]V97)E96YK;VUE;F0@;65T`$]V97)E96YK;VUE;F1E
M('9E;&1E;@!-875R971A;FGK`$UA=7)I=&EU<P!-87AI;6%A;"!T;V5G97-T
M86%N(&MR961I970N`$UA>&EM=6T@8F5R:6-H=&]N9&5R9&5L96X@;W9E<G-C
M:')E9&5N+@!-87AI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@
M,C0@=75R.B``36%X:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N
M(#8@=75R.B``36%X:6UA;&4@;&5N9W1E`$UA>&EM=6T@86%N=&%L('!A9VEN
M82=S+@!-96D`36%Y;W1T90!'96YE97-K=6YD90!,961E;@!-96YU(&UO9&4Z
M`$-E;&QE;B!S86UE;G9O96=E;@!"97)I8VAT`$)E<FEC:'0@;65T('-U8V-E
M<R!G979E<FEF:65E<F0L(&UA87(@:&5T(&-E<G1I9FEC86%T('9A;B!D92!O
M;F1E<F=E=&5K96YD92!K;VX@;FEE="!W;W)D96X@9V5V97)I9FEE97)D+@!"
M97)I8VAT('9E<FQO<&5N+@!"97)I8VAT='EP90!-971A<B!7965R`$U%5$%2
M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX`345405(@8FQO:R!I<R!N:65T
M(&)E<V-H:6MB86%R+B!$971A:6QS('II:FX@9V5L;V=D('9O;W(@9&4@<WES
M=&5E;6)E:&5E<F1E<BX`365T:&]D90!-971R:7-C:`!-97AI8V\`36EC<F]N
M97-IZRP@1F5D97)A;&4@4W1A=&5N('9A;@!-:61D96X`36EM92!T>7!E`$UI
M;FEM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L;W!E;B`R-"!U=7(Z(`!-
M:6YI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@-B!U=7(Z(`!-
M:6YI('IO96ME;@!-:7)R;W(`06QL97)H86YD90!/;G1B<F5K96YD92!$3B!I
M;B!D92!,1$%0(&)R;VYC;VYF:6=U<F%T:64N`$]N=&)R96ME;F1E(%!%05(@
M;6]D=6QE($A45%!?4F5Q=65S="X`3VYT8G)E:V5N9&4@8V]N9FEG=7)A=&EE
M+B!5(&1I96YT(&1E>F4@;G4@=&4@9V5N97)E<F5N+"!W86YN965R('4@9&5Z
M92!T;V5P87-S:6YG('=I;'0@9V5B<G5I:V5N+@!/;G1B<F5K96YD(&)E<FEC
M:'0@240N`$]N=&)R96ME;F1E+"!V97)E:7-T92P@4$5!4B!M;V1U;&4@36%I
M;"X`3VYT8G)E:V5N9"!S97-S:64@240N`$UA`$UO8FEE;&4@92UM86EL`$UO
M8FEE;&4@=&5L969O;VX`1V5M:61D96QD`%=I:GII9VEN9W-D871U;0!7:6IZ
M:6<@55),`%=I:GII9V5N(&UI<VQU:W0Z("@E<RD@)7,`36]D=6QU<P!-;VQD
M879IZRP@4F5P=6)L:65K('9A;@!-;VYA8V\`36]N9V]L:>L`36%A;F0@96X@
M:F%A<@!-86%N9&5L:6IK<P!-;VYT<V5R<F%T`$UA86YF87-E;@!-965R(&1A
M;B`Q(&EN=F]E<B!G979O;F1E;@!-87)O:VMO`%9O;W)N86UE;&EJ:R!O;F)E
M=V]L:W0`5F]O<FYA;65L:6IK(&)E=V]L:W0`5F]O<FYA;65L:6IK('IO;FYI
M9P!697)P;&%A='-E;@!.86%R(&)E;F5D96X`3F%A<B!L:6YK<P!.86%R(')E
M8VAT<P!.86%R(&)O=F5N`$YA87(@8F5N961E;@!.86%R(&QI;FMS`$YA87(@
M<F5C:'1S`$YA87(@8F]V96X`36]Z86UB:7%U90!-=6QB97)R>2!A9')E<V)O
M96L`375L=&DM;&5V96P@9')O<"!D;W=N(&QI:G-T96X`365E<F1E<F4@<&5R
M<V]N96X@;65T(&%D<F5S(%LE<UTL(&UA87(@9V5E;B!M970@;F%A;2!;)7-=
M(&1I92!A;"!B97-T86%T`$UE97)V;W5D:6=E('-E;&5C=&EE`$UI:FX@86-C
M;W5N=`!-:6IN('!O<G1A86P`36EJ;B!P;W)T86%L;&%Y;W5T`$)I<FUA`$YE
M92P@:6L@86-C97!T965R(&1E('9O;W)W86%R9&5N($Y)150`3F%A;0!.86%M
M9F]R;6%A=`!.86UI8FGK`$YA=7)U`$YE<&%L`$YE=&-E;G1E<B!L961E;F1I
M<F5C=&]R>0!.961E<FQA;F0`3F5D97)L86YD<R!!;G1I;&QE;@!.971S8V%P
M92!"87-I<R!54DP`3F5T<V-A<&4@0T$@:6YT<F5K:VEN9R!54DP`3F5T<V-A
M<&4@0T$@8F5L96ED(%523`!.971S8V%P92!V97)N:65U=VEN9R!54DP`3F5T
M<V-A<&4@:6YT<F5K:VEN9R!54DP`3F5T<V-A<&4@4U-,('-E<G9E<FYA86T`
M3F5T<V-A<&4@8V5R=&EF:6-A871C;VUM96YT86%R`$YE='-C87!E(&-E<G1I
M9FEC86%T='EP90!.971W97)K`$YO;VET`$YI975W($-A;&5D;VYIZP!.:65U
M=V4@8V%T96=O<FEE`$YI975W(&%D<F5S`$YI975W92!M86%N`$YI975W92!G
M96)R=6EK97)S;F%A;2`H;W!T:6]N965L*0!.:65U=R!:965L86YD`$YI975W
M('-C:&5R;2`H7V)L86YK*0!.:65U=W,`3FEE=7=S9W)O97!E;@!6;VQG96YD
M90!6;VQG96YD92!O<'1I97,`3FEC87)A9W5A`$)I:FYA86T`3FEG97(`3FEG
M97)I80!.86-H=`!.:75E`$YE90!'965N("5S(&EN=F]E<B!G979O;F1E;B!V
M;V]R("5S`$=E96X@861R97-B;V5K96X@9V5V;VYD96XN`$=E96X@8F5S8VAI
M:V)A<F4@8V]N9FEG=7)A=&EE9&%T82!O;2!V97)S8VAI;&QE;B!T92!L871E
M;B!Z:65N+@!'965N(&)E<V-H:6MB87)E('-T<F%T96=I92!V;V]R(&AE="!M
M86ME;B!V86X@25-/(&EM86=E<RX`1V5E;B!B871C:'-J86)L;V]N+@!%<B!B
M97-T86%T(&=E96X@8FQO:R!O<"!D92!G979R86%G9&4@<&]S:71I90!'965N
M(&%G96YD86YA86T@;W!G96=E=F5N('9O;W(@34-!3"!A=71H96YT:6-A=&EE
M+@!'965N('=I:GII9VEN9V5N+@!!86X@9&ET(')E8VAT(&MU;FYE;B!G965N
M(&-H:6QD(')E8VAT96X@=V]R9&5N('1O96=E=F]E9V0N`$=E96X@8V]N9FEG
M=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B`E<RX`1V5E;B!C;VYF
M:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R($944"!61E,N`$=E
M96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!344P@
M5D93+@!'965N(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O
M;W(@4U%,+6)E<W1A;F0@5D93+@!'965N(&%D<F5S<V5N(&=E=F]N9&5N`$=E
M96X@:W)E9&EE="!M965R+@!'965N(&)E<W1E;6UI;F<@;W!G96=E=F5N+@!'
M965N(&)E<W1A;F0@=7!L;V%D960`17(@:7,@9V5E;B!L;V-A=&EE(&EN9V5S
M=&5L9"X`1V5E;B!B97)I8VAT(&=E;&5V97)D+@!'965N(&YA86T@;W!G96=E
M=F5N+@!'965N(&=E=&%L(&]P9V5G979E;BX`1V5E;B!B96QE9&EG96YD92!F
M;W)T=6YE<P!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@2%144"!A
M=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@
M24U!4"!A=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N
M('9A;B!+97)B97)O<R!A=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@
M;W!G96=E=F5N('9O;W(@3&]G:6X@875T:&5N=&EC871I92X`1V5E;B!W86-H
M='=O;W)D(&]P9V5G979E;B!V;V]R(%!!4U-71"!A=71H96YT:6-A=&EE+@!'
M965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@4TU"(&%U=&AE;G1I8V%T
M:64N`$=E96X@<&%D(&YA87(@9&4@3W!E;E-33"!B:6YA<GD@;W!G96=E=F5N
M+B!$92!/<&5N4U-,(&)I;F%R>2!I<R!N;V1I9R!O;2!T92!K=6YN96X@=V5R
M:V5N(&UE="!02T-3(#$R(&1A=&$N`$=E96X@:&%N9V5N9&4@:6YS8VAR:6IV
M:6YG96XN`$=E96X@;&EN:>MR:6YG`$=E96X@>FEJ9&5N`$=E96X@=&EJ9&5L
M:6IK(&1I<F5C=&]R>2!B97-C:&EK8F%A<B!V;V]R(&-A8VAE+@!'965N(&=E
M8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT=V]O<F0@=F5R>F]N9&5N+@!'965N
M('9#87)D(&1A=&$@9V5V;VYD96XN`$=E96X@9V5L9&EG92!834P@9&%T82!T
M97)U9V=E<W1U=7)D`$=E96X@=V%A<F1E;@!'965N('9E<G-I92!G979O;F1E
M;B!I;B!O<FEG:6YE;&4@8V]N9FEG=7)A=&EE+B!(97)G96YE<F5E<B!C;VYF
M:6=U<F%T:64N`$=E96X@=F5R<VEE(&=E=F]N9&5N(&EN('5W(&-O;F9I9W5R
M871I92X@2&5R9V5N97)E97(@8V]N9FEG=7)A=&EE+@!'965N`$=E96X@*'9E
M<G!L:6-H="D`3F]O<F0@175R;W!E97,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK
M(&5I;&%N9`!.;V]R9&5L:6IK(&AA;&9R;VYD`$UA<FEA;F5N`$YO;W)W96=E
M;@!.:65T(&YA`$YI970@=F]O<@!'965N(&1I<F5C=&]R>0!.:65T(&=E:6UP
M;&5M96YT965R9"X`3FEE="!I;F=E<W1E;&0`3FEE="!O;F1E<G-T975N9"X`
M3F]T:71I97,`3FEE=',@=&4@8FQA9&5R96XL(&=A('1E<G5G+@!.;W9E;6)E
M<@!'971A;`!!86YT86P@:V%R86MT97)S`$%A;G1A;"!K;VQO;6UE;@!!86YT
M86P@;VYD97)D96QE;B!P97(@<&%G:6YA`$%A;G1A;"!R:6IE;@!'971A;&QE
M;B!N:65T(&]P9V5G979E;B!V;V]R(&)I:G=E<FME;B!I;B!E96X@9&ES=')I
M8G5T:65L:6IS="X`3TL`3V)J96-T`$]B:F5C=&5I9V5N86%R`$]B:F5C="!N
M:65T(&=E=F]N9&5N+@!/8W1A86P`3VMT;V)E<@!"96QE9&EG:6YG9FEL=&5R
M`$MA;G1O;W(`3VUA;@!!;&QE96X@24U!4"!S97)V97)S(&]N9&5R<W1E=6YE
M;B!G961E96QD92!M87!P96XN`$%L;&5E;B!B96QE9&EG96YD92!F;W)T=6YE
M<P!3;&5C:'0@Z>EN(&4M;6%I;&%D<F5S('1O96=E<W1A86XN`$%L;&5E;B!D
M92!E:6=E;F%A<B!O9B!E96X@<WES=&5E;6)E:&5E<F1E<B!M86<@9&4@96EG
M96YA87)R96-H=&5N('9A;B!E96X@<VAA<F4@=VEJ>FEG96X`3W!E;B!I;B!E
M96X@;FEE=7<@<V-H97)M`$]P96Y34TP@9F]U=#H@:V]N(&=E96X@9&%T82!U
M:70@:&5T(&]N9&5R=&5K96YD92!3+TU)344@;VYD97)D965L(&AA;&5N+@!/
M<&5N="!D97IE(&QI;FL@:6X@965N(&YI975W('-C:&5R;0!"97-T=7)I;F=S
M<WET965M`$]P=&EE<P!/<'1I97,@=F]O<B`E<P!'96]R9&5N9&4@;&EJ<W0`
M3W)G86YI<W1A=&EE`$]R9V%N:7-A=&EE(&5E;FAE:60`3W)G86YI<V5R96X`
M3W)I9VEN965L('1O97!A<W-I;F=S<VIA8FQO;VX`3W)I9VEN96QE('-J86)L
M;VYE;B!I;B`E<SH`06YD97)E`$%N9&5R92!I;F9O<FUA=&EE`$%N9&5R92!O
M<'1I97,`16EG96YA87)R96-H=&5N`%!!32!A=71H96YT:6-A=&EE(&ES(&YI
M970@8F5S8VAI:V)A87(N`$1I9VET86QE(%!'4"!H86YD=&5K96YI;F<`1V5C
M;V1E97)D92!01U`@9&%T80!/<&5N8F%R92!01U`@<VQE=71E;`!/;F1E<G1E
M:V5N9&4O9V5C;V1E97)D92!01U`@9&%T80!02%`@8V]D90!02%`@<VAE;&P`
M3&EC:'1E(')E9V5N(&YA(#$R+C`P('5U<@!"=6EE;B!N82`Q,BXP,"!U=7(`
M3VYW965R<V)U:65N(&YA(#$R+C`P('5U<@!02%`@7U-H96QL`%9R:6IE(')U
M:6UT90!086MI<W1A;@!086QA=0!086QE<W1I:FYS(%1E<G)I=&]R:75M+"!"
M97IE=`!086YA;6$`4&%P=6$@3FEE=7<@1W5I;F5A`%!A<F%G=6%Y`$=E9&5E
M;'1E;&EJ:R!B97=O;&MT`%=A8VAT=V]O<F0`5V%C:'1W;V]R9"!O;FIU:7-T
M`%=A8VAT=V]O<F0@:7,@=F5R96ES="!V;V]R(%)!1$E54R!A=71H96YT:6-A
M=&EE+@!786-H='=O;W)D(&UE="!B979E<W1I9VEN9P!786-H='=O;W)D.@!7
M86-H='=O;W)D.B``5V%C:'1W;V]R9&5N(&UO971E;B!O=F5R965N:V]M96XN
M`%!L86MK96X`4&QA:VME;B!V86YA9B!P<FEK8F]R9`!0860`2&%N9V5N9&4@
M:6YS8VAR:6IV:6YG96XZ`$UE;G-E;@!0<F]C96YT`$]N9&5R:&]U9'-W97)K
M>F%A;6AE9&5N('5I='9O97)E;@!/;F1E<FAO=61S=V5R:WIA86UH961E;B!U
M:71V;V5R96X@8FEJ(&%A;FUE;&1I;F<_`%)E8VAT`%1O96=A;F<@9V5W96EG
M97)D`%1O96=A;F<@9V5W96EG97)D`%)E8VAT96YB96AE97(`4&5R<V]O;FQI
M:FME(&EN9F]R;6%T:64`4&5R=0!(=6ES9&EE<F5N`%!H:6QI<'!I:FYE;@!4
M96QE9F]O;@!&;W1O)W,`4&EN92!A9')E<V)O96L`4&ET8V%I<FX`4&EX96QS
M`%!L871I='5D97,`2VQI:R!I;B!E96X@8V5L+"!A+G4N8BX`0F5V97-T:6<L
M(&1A="!U(&1I="!E;&5M96YT('=I;'0@=F5R=VEJ9&5R96XL(&$N=2YB.@!"
M979E<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!L;W-K;W!P96QE;BP@
M82YU+F(N`$=E968@965N(&UA86YD(&5N(&5E;B!J86%R+"!A+G4N8BX`165N
M(&YA86T@=F]O<B!D92!N:65U=V4@8V%T96=O<FEE(&EN=F]E<F5N+"!A+G4N
M8BXZ`$=E968@965N(&=E;&1I9R!)4"!A9')E<RP@82YU+F(N`$=E968@965N
M(&=E;&1I9V4@9&%T=6T@82YU+F(N+"!C;VYT<F]L965R(&AE="!A86YT86P@
M9&%G96X@:6X@9&4@;6%A;F0N`$=E968@965N(&=E;&1I9V4@=&EJ9"P@82YU
M+F(N`$=E968@965N('-A;65N=F%T=&EN9R!V86X@:&5T('!R;V)L965M+"!A
M+G4N8BX`1V5E9B!U=R!G96)R=6EK97)S;F%A;2!E;B!W86-H='=O;W)D+"!A
M+G4N8BX`1V5E9B!D92!N:65U=V4@8V%T96=O<FEE;F%A;2P@82YU+F(N.@!0
M;VQE;@!0;VQI=&EE:P!096EL:6YG96X`4&]R='5G86P`4&]S:71I;VYE<FEN
M9R!V86X@9&5Z92!A9F)E96QD:6YG`%!O<VET:6]N97)I;F<@=F%N(&1E>F4@
M=&%B96P`4W1U=7(@;F%A<B!D97IE(&UA<"`H;FEE="!A9F=E9'=O;F=E;B!D
M;V]R($E-05`I`$YE97)S;&%G('9A;B!D92!A9F=E;&]P96X@)7,@=7)E;CH@
M`%!R969S7VQD87`Z('9E<F5I<W1E($Q$05`@97AT96YT:64@;FEE="!G979O
M;F1E;BX`4')E9G-?<V5S<VEO;CH@=F5R96ES=&4@<V5S<VEE(&5X=&5N=&EE
M(&YI970@9V5V;VYD96XN`$QU8VAT9')U:P!,=6-H=&1R=6L@;W`@>F5E;FEV
M96%U.B``3'5C:'1D<G5K.B``0F5O;W)D96QE;@!"96]O<F1E96P@9&4@869B
M965L9&EN9R!I;B!E96X@;FEE=7<@<V-H97)M`%9O<FEG92!O<'1I97,`1&]C
M=6UE;G0@869D<G5K:V5N`%!R:79E(&%D<F5S8F]E:P!0<FEV92!S;&5U=&5L
M`%!R;V)L965M`%!R;V)L965M8F5S8VAR:6IV:6YG`%!R;VIE8W1E;@!0<F]M
M<'0@=&5K<W0`3W!E;F)A<F4@<VQE=71E;`!/<&5N8F%R92!S;&5U=&5L(&%L
M9V]R:71H;64`3W!E;F)A87(O4')I=F4@<VQE=71E;'!A87(@;FEE="!G96=E
M;F5R965R9"X`4'5E<G1O(%)I8V\`475A=&%R`%%U97)Y`%%U97)Y(&UI<VQU
M:W0Z("@E<RD@)7,`4VYE;"!Z;V5K96X`4E-!(&]P96YB87)E('-L975T96P@
M*"5D(&)I="D`2V5U>F5R;VYD:F4@<V5L96-T:64`4F5G96X`5G)O96<@<F5G
M96X`3&%A="!R96=E;@!296=E;F)U:0!286YD;VT@1F]R='5N90!697)H;W5D
M:6YG`$QE>F5N`$QE>F5N(&UI<VQU:W0Z("@E<RD@)7,`3&5E<R!B97)I8VAT
M96X`)7,@96-H="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI
M970@;VYG961A86X@9V5M86%K="!W;W)D96XN`$=E8G)U:6ME<G-D871A('9A
M;B!G96)R=6EK97(@)7,@96-H="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI
M;F<@:V%N(&YI970@;VYG961A86X@9V5M86%K="!W;W)D96XN`%)E8V]R9',@
M=V5E<F=E9V5V96XZ`$AE<FAA86QT('5W('9O<FEG92!B97=E<FMI;F<`5F5R
M=F5R<R!D>6YA;6ES8VAE(&UE;G4@;VYD97)D96QE;CH`4&]R=&%L=V5E<F=A
M=F4@=F5R=F5R<V5N.@!296=E>`!"971R96MK:6YG96X@8G)O=W-E<@!/<&UE
M<FMI;F=E;@!397)V97)S(&]P(&%F<W1A;F0`55),(&]P(&%F<W1A;F0@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!697)W:6ID97)E;@!";&]K
M('9E<G=I:F1E<F5N`$MO;&]M('9E<G=I:F1E<F5N`$]P;6%A:R!V97)W:6ID
M97)E;@!5:70@9&5Z92!L:6IS="!V97)W:6ID97)E;BX`4&%A<B!V97)W:6ID
M97)E;@!697)W:6ID97(@:&5T(&]P9V5S;&%G96X@<V-R:7!T('5I="!D92!T
M:6ID96QI:FME(&1I<F5C=&]R>2!O<"!D92!S97)V97(N`%9E<G=I:F1E<B!D
M90!697)W:6ID97(@9&5Z92!N;V1E('5I="!H970@9&]C=6UE;G0`1V5B<G5I
M:V5R('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!G96)R=6EK97(Z("5S`%9E<GIO
M96L@:V]N(&YI970@=V]R9&5N(&)E86YT=V]O<F0N($=E<F5T;W5R;F5E<F1E
M(&9O=71C;V1E.B``06%N9V5V<F%A9V0@;V)J96-T(&YI970@9V5V;VYD96XN
M`$AE<G-T96QL96X`4F5S970@=V%C:'1W;V]R9`!297-E="!U=R!W86-H='=O
M;W)D`$AE<G-T96P@<W1A;F1A87)D:6YS=&5L;&EN9V5N`%)E<W5L=&%T96X`
M5&5R=6<@;F%A<B!O<'1I97,`4F5U;FEO;@!#;VYF:6=U<F%T:64@=&5R=6=Z
M971T96X`4FEC:"!497AT($5D:71O<B!O<'1I97,`4F%A9'-E;',`4F5C:'1S
M`%)E8VAT<V4@:V]P`%)E8VAT<V4@=V%A<F1E;@!2:5]J96EG96YS8VAA<'!E
M;BXN+@!2;VP`4F]E;65N:>L`,3@P(&1R86%I96X`3F%A<B!L:6YK<R!D<F%A
M:65N`$YA87(@<F5C:'1S(&1R86%I96X`4FEJ(&5I9V5N<V-H87!P96X`4FEJ
M(&5I9V5N<V-H87!P96X`4FEJ96XZ`$QI;FGK<FEN9P!,:6YIZW)I;F<@>F%L
M('9E<G-C:&EJ;F5N('1U<W-E;B!A;&QE(')I:F5N(&5N(&MO;&]M;65N`$QI
M;FGK<FEN9R!Z86P@86QL965N('1U<W-E;B!K;VQO;6UE;B!V97)S8VAI:FYE
M;@!,:6YIZW)I;F<@>F%L(&%L;&5E;B!T=7-S96X@<FEJ96X@=F5R<V-H:6IN
M96X`4W1A<G1E;@!2=7-S:7-C:&4@1F5D97)A=&EE`%)W86YD80!#<GEP=&]G
M<F%F:7-C:&4@4R]-24U%(&AA;F1T96ME;FEN9P!3+TU)344@9V5C;V1E97)D
M(&)E<FEC:'0`3W!E;F)A87(@4R]-24U%(&-E<G1I9FEC86%T`%-!4TP@875T
M:&5N=&EC871I92!I<R!N:65T(&)E<V-H:6MB86%R+@!335,@=F5R<W1U<F5N
M`%-13"!S:&5L;`!34T@`4U5#0T53`%-?44P@<VAE;&P`6F$`4W0@2&5L96YA
M`%-T($MI='1S(&5N($YE=FES`%-T($QU8VEA`%-T(%!I97)R92!E;B!-:7%U
M96QO;@!3="!6:6YC96YT(&5N(&1E($=R96YA9&EN97,`6F5L9F1E(&9R86UE
M("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!E;B!0<FEN8VEP
M90!3871E;&QI971P<F]V:61E<@!3875D:2!!<F%B:>L`3W!S;&%A;@`E<R!O
M<'-L86%N`$]P=&EE<R!O<'-L86%N`$=E9V5N97)E97)D92!C;VYF:6=U<F%T
M:64@86QS(%!(4"!S8W)I<'0@;W!G97-L86=E;B!I;B!D92!T:6ID96QI:FME
M(&1I<F5C=&]R>2!V86X@=7<@<V5R=F5R+@`E<R!C;VYF:6=U<F%T:64@;W!G
M97-L86=E;@!7971E;G-C:&%P`%IO96ME;@!:;V5K;6%C:&EN97,`6F]E:V5N
M(&UI<VQU:W0`6F]E:V5N(&UI<VQU:W0Z("5S`%IO96ME;BXN+@!+:65S(&)E
M<W1A;F1E;@!396QE8W1E97(@965N(&1A='5M`%-E;&5C=&5E<B!E96X@9W)O
M97`@;VT@=&]E('1E('9O96=E;@!396QE8W1E97(@965N(&YI975W92!E:6=E
M;F%A<@!396QE8W1E97(@965N('-E<G9E<@!396QE8W1E97(@965N(&=E8G)U
M:6ME<B!O;2!T;V4@=&4@=F]E9V5N`%-E;&5C=&5E<B!A;&QE(&1A='5M8V]M
M<&]N96YT96XN`%-E;&5C=&5E<B!E96X@;V)J96-T`%-E;&5C=&5E<B!H970@
M861R97-B;V5K(&]M('9A;G5I="!T92!E>'!O<G1E<F5N.@!396QE8W1E97(@
M9&4@86=E;F1A(&]M(&YA87(@=&4@:6UP;W)T97)E;CH`4V5L96-T965R(&1E
M(&)E;F]D:6=D92!K87)A:W1E<G,@=6ET(&1E(&]N9&5R<W1A86YD92!V86MJ
M97,N(%4@:W5N="!D97IE(&1A;B!K;W!IZW)E;B!E;B!P;&%K:V5N(&EN(&AE
M="!T96MS=&=E8FEE9"X`4V5L96-T965R(&AE="!D871U;7-C:&5I9&EN9W-T
M96ME;CH`4V5L96-T965R(&AE="!D871U;69O<FUA870Z`%-E;&5C=&5E<B!H
M970@97AP;W)T9F]R;6%A=#H`4V5L96-T965R(&AE="!I;7!O<G1B97-T86YD
M.@!396QE8W1E97(@:&5T(&9O<FUA870@=F%N(&AE="!B<F]N8F5S=&%N9#H`
M4V5L96-T965R(&AE="!F;W)M86%T('9O;W(@:&5T('=E97)G979E;B!V86X@
M;F%M96XZ`%-E;&5C=&5E<B!D92!I9&5N=&ET96ET(&1I92!U('=I;'0@=VEJ
M>FEG96XZ`%-E;&5C=&5E<B!H970@=&EJ9'-C:&5I9&EN9W-T96ME;CH`4V5L
M96-T965R(&AE="!T:6ID<V9O<FUA870Z`%-E;&5C=&5E<B!T=V5E(&]V97)E
M96YK;VUE;F1E('9E;&1E;BX`4V5L96-T965R('=E;&ME('9E;&1E;B!W;W)D
M96X@=V5E<F=E9V5V96X@:6X@9&4@861R97-L:6IS=&5N+@!396QE8W1E97(@
M:&5T(&9O<FUA870@=F]O<B!H970@=V5E<F=E=F5N('9A;B!N86UE;BX`4V5L
M96-T965R('5W(&ML975R<V-H96UA+@!396QE8W1E97(@=7<@9V5W96YS=&4@
M=&%A;#H`4')O8FQE96UR87!P;W)T('9E<GIE;F1E;@!697)Z96YD(%--4P!3
M96YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)V:>L@96X@36]N=&5N96=R
M;P!397)I96YU;6UE<@!397-S:64@240@=F5R;&]P96XN`$EN<W1E;&QE;@!)
M;G-T96QL96X@=F%N(&]P=&EE<R!O;2!U('1O92!T92!S=&%A;B!U=R!W86-H
M='=O;W)D('1E(')E<V5T=&5N+"!W86YN965R('4@9&ET(&)E;G0@=F5R9V5T
M96XN`$EN<W1E;&QE;B!V86X@<V5R=F5R<R!O<"!A9G-T86YD(&1I92!U('=I
M;'0@8F5N861E<F5N('9A;G5I="!U=R!P;W)T86PN`$EN<W1E;&QE;B!V86X@
M=7<@9V5W96YS=&4@=&%A;"P@=&EJ9'IO;F4@96X@9&%T=6UO<'1I97,N`$EN
M<W1E;&QE;B!V86X@=7<@;W!S=&%R='1O97!A<W-I;F<L(&ML975R<V-H96UA
M+"!P86=I;F%V97)V97)S:6YG(&5N(&%N9&5R92!W965R9V%V96]P=&EE<RX`
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&)E<V-H:6MB86%R`%9E<G-C:&EL;&5N
M9&4@;&]C871I97,@;6]G96QI:FL@;65T(&1E('!A<F%M871E<CH@`%-E>6-H
M96QL96X`1V5D965L9&4@9&ER96-T;W)Y`%=I;FME;&5N`$MO<G1E('-A;65N
M=F%T=&EN9P!$:65N96X@<VYE;'1O971S96X@=F]O<B!D92!M965S=&4@;&EN
M:W,@9V5D969I;FEE97)D('1E('=O<F1E;C\`5V5E<F=E=F5N`$%L;&4@=V5E
M<F=E=F5N`$%D<F5S<V5N('=E97)G979E;@!,:6IS=&5N('=E97)G979E;@!6
M97)S8VAI;&QE;B!L871E;B!Z:65N('1U<W-E;B!D92!H=6ED:6=E(&]P9V5S
M;&%G96X@8V]N9FEG=7)A=&EE(&5N(&1E(&YI975W92!G96=E;F5R965R9&4@
M8V]N9FEG=7)A=&EE+@!,86%T<W1E(&%A;FUE;&1I;F=S=&EJ9"!W965R9V5V
M96X@8FEJ(&%A;FUE;&1E;C\`3W!T:64@=V5E<F=E=F5N(&]M(&]R:6=I;F5E
M;"!T92!B97=A<F5N`$MI97IE<B!W965R9V5V96X`5&%B96QB97=E<FMI;F=S
M=&%A:V)A;&L@=V5E<F=E=F5N/P`E<R!M96YU(&%A;B!D92!L:6YK97)K86YT
M('=E97)G979E;C\`5&%B96QC96QE:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS
M=&5R('=E97)G979E;@!486)E;&5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T
M97(@=V5E<F=E=F5N`%1A8F5L<FEJ96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N
M<W1E<B!W965R9V5V96X`069B965L9&EN9W-E:6=E;G-C:&%P<&5N(&1I86QO
M;V=V96YS=&5R('=E97)G979E;@!5<&QO860@=V5E<F=E=F5N`$)U:65N`$)U
M:65N('9R;V5G`$)U:65N(&QA870`5F5R:VQE:6YE;@!697)K;&5I;B!O9B!V
M97)P;&%A=',@;F%B=7)I9V4@8FQO:VME;B!E97)S=`!3:65R<F$@3&5O;F4`
M26YT96ME;F5N`$AA;F1T96ME;FEN9P!(86YD=&5K96YI;F<@86QG;W)I=&AM
M90!3:6YG87!O<F4`1W)O;W1T90!/;F1E<FAO=60@;W9E<G-L86%N`%-L;W=A
M:VEJ90!3;&]V96YIZP!3;F5E=7<`4VYE975W=FQA86<`4VYE975W8G5I96X`
M4VYE975W8G5I96X@;&%A=`!3;F5E=7=D:65P=&4Z(`!3;F5E=7=E<75I=F%L
M96YT(&EN('=A=&5R.B``4V]L;VUO;B!E:6QA;F1E;@!3;VUA;&GK`$QI961E
M<F5N(&5N(&=E9&EC:'1E;@!3;W)T965R=F]L9V]R9&4`4V]R=&5E<G9O;&=O
M<F1E('-E;&5C=&EE`$)R;VYA9')E<P!"<F]N;F5N`%IU:60@069R:6MA`%IU
M:60@175R;W!E97,@*$E33RTX.#4Y+3,I`%IU:60@1V5O<F=IZR!E;B!D92!:
M=6ED(%-A;F1W:6-H(&5I;&%N9&5N`%IU:61E;&EJ:R!H86QF<F]N9`!3<&%T
M:>MR:6YG('1U<W-E;B!A86YG<F5N>F5N9&4@8V5L;&5N`%-P871IZW)I;F<@
M='5S<V5N(&EN:&]U9"!E;B!R86YD(&EN(&-E;`!38VAE:61I;F=S=&5K96X`
M4W!A=&GK<FEN9P!3<&%T:>MR:6YG(&5N('9R:6IE(')U:6UT90!3<&%N:F4`
M4W!A;0!3<&5C:6%A;"!K87)A:W1E<B!I;G9O97(`3W!G979E;B!W86%R('4@
M9&4@9V5A=F%N8V5E<F1E('IO96MR97-U;'1A=&5N('=I;'0@;&%T96X@=F5R
M<V-H:6IN96XN`$-E;"!O<'-P;&ET<V5N`$MO;&]M(&]P<W!L:71S96X`4FEJ
M(&]P<W!L:71S96X`4W!O<G0`4W)I($QA;FMA`%-T86YD86%R9`!3=&%R(%1R
M96L`4W1A<G1J86%R`%-T86%T(&]F('!R;W9I;F-I90!3=&%T=7,`3W!S;&%G
M9F]R;6%A=`!!9')E<P!$;V]R:&%L96X`4W1R:6YG;&EJ<W0`4W1R:7`@9&]M
M96EN('9A;B!H970@861R97,`4W1I:FP@6T-34UT`6F\`3VYD97)W97)P`$)E
M=F5S=&EG96X`4W5B<V-R:7!T`%-U8V-E<P`E<R!M970@<W5C8V5S('1O96=E
M=F]E9V0@86%N("5S`$-O;F9I9W5R871I92!M970@<W5C8V5S('1E<G5G9V5Z
M970N(%9E<FYI975W(&]M('=I:GII9VEN9V5N('1E('II96XN`$)A8VMU<&-O
M;F9I9W5R871I92!M970@<W5C8V5S<R!O<&=E<VQA9V5N+@`E<R!M970@<W5C
M8V5S(&=E<V-H<F5V96X`4V]E9&%N`%-A;65N=F%T=&EN9P!:;VYS;W!G86YG
M`%IO;G-O;F1E<F=A;F<`6F]N;FEG`%IO;G-O<&=A;F<`6F]N<V]P9V%N9R]:
M;VYS;VYD97)G86YG`%IO;G-O<&=A;F<Z(`!:;VYS;VYD97)G86YG`%IO;G-O
M;F1E<F=A;F<Z(`!3=7!E<G-C<FEP=`!/;F1E<G-T975N:6YG`%-U<FEN86UE
M`$%C:'1E<FYA86T`4W!I='-B97)G96X@96X@2F%N($UA>65N`%-W87II;&%N
M9`!:=V5D96X`6G=I='-E<FQA;F0`4WEN=&%X9F]U="!I;B!Z;V5K=&5R;65N
M`%-Y<FES8VAE($%R86)I<V-H92!297!U8FQI96L`3VYW965R<V)U:0!/;G=E
M97)S8G5I96X`5%-6`%135B!B97-T86YD`%1A8B!G97-C:&5I9&5N('=A87)D
M96X`5&%B96P`5&%B96QE:6=E;G-C:&%P<&5N`%1A8F5L96EG96YS8VAA<'!E
M;@!486EW86X`5&%I=V%N+"!0<F]V:6YC:64@=F%N($-H:6YA`%1A9'IJ:6MI
M<W1A;@!486YZ86YI82P@5F5R96YI9V1E(%)E<'5B;&EE:R!V86X`1&]E;#H`
M5&%K96X`5&5L969O;VYN=6UM97(`5&5M<&5R871U=7(@=F%N(&AE="!A9F=E
M;&]P96X@=75R.B``5&5M<&5R871U=7(`5&5M<&5R871U=7(Z(`!3:F%B;&]O
M;F)E:&5E<@!496MS=`!!;&QE96X@=&5K<W0`5&5K<W0@=6ET;&EJ;F5N`%1E
M:W-T8F]V96YK86YT`$1O`%1H86ES("A425,M-C(P*0!4:&%I;&%N9`!"961A
M;FMT('9O;W(@:&5T(&=E8G)U:6ME;B!V86X@:&5T('-Y<W1E96TN`$1E($94
M4"!E>'1E;G1I92!I<R!N:65T(&)E<V-H:6MB86%R+@!$92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EE(&]N9&5R<W1E=6YT("(E<R(@;FEE=`!$92!-86EN=&5N
M86YC93HZ(&-L87-S('=E<F0@;FEE="!G96QA9&5N`$AE="!/<'1I97-S8VAE
M<FT@:7,@9V5S;&]T96XN($%F<VQU:71E;BX`2&5T(&%D<F5S8F]E:R!K;VX@
M;FEE="!W;W)D96X@9V5L965G9#H@)7,`1&4@8F5H965R9&5R(&1I96YT(&5E
M;B!P97)M86YE;G0@<F5C:'1E;F)A8VME;F0@=&4@8V]N9FEG=7)E<F5N(&%L
M<R!U(')E8VAT96X@=VEL="!G96)R=6EK96XN`$%L;&5E;B!D92!O;F1E<FMA
M;G0`2&5T(&-O;G1A8W0@240@;G5M;65R(&ES(&YI970@;W!G96=E=F5N+"!L
M965G(&=E;&%T96X@;V8@:7,@;FEE="!G979O;F1E;B!I;B!D92!D871A8F%S
M92X`2&5T(&%D<F5S(&ES(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E:R!T
M;V5G979O96=D+@!(970@9V5V<F%A9V1E(&%D<F5S(&)E<W1A870@;FEE="X`
M2&5T(&QO<V=E:V]P<&5L9&4@4$=0(&]N9&5R=&5K96YI;F=S8FQO:R!I<R!V
M97)E:7-T(&]M(&AE="!O;F1E<G1E:V5N9&4@8F5R:6-H="!T92!V97)I9FGK
M<F5N+@!(970@9&ES=')U8G5T:65L:6IS="!)1"!I<R!N:65T(&]P9V5G979E
M;BP@;&5E9R!G96QA=&5N(&]F(&ES(&YI970@9V5V;VYD96X@:6X@9&4@9&%T
M86)A<V4N`$1E(&1I<W1R:6)U=&EE;&EJ<W0@:7,@;FEE="!O<&=E9V5V96XN
M`$1E(&-O9&5E<FUO9V5L:6IK:&5D96X@=F5R96ES96X@965N(&)E=F5I;&EG
M9&4@=V5B=F5R8FEN9&EN9RX`2&5T(&)E<W1A;F0@)7,@9&EE;G0@965N("5S
M(&EN<W1E;&QI;F<@=&4@8F5V871T96XN`$AE="!B97-T86YD("5S(&1I96YT
M(&5N:6=E("5S(&EN<W1E;&QI;F=E;B!T92!B979A='1E;BX`2&5T(&)E<W1A
M;F0@:V%N(&YI970@;F%A<B!Z:6-H>F5L9B!G96MO<&EE97)D('=O<F1E;BX`
M2&5T(&)E<W1A;F0@8F5V871T92!G965N(&1A=&$N`$AE="!V;VQG96YD92!Z
M:6IN(&1E(&MO<'!E;B!V86X@9&ET(&UE<W-A9V4O<F9C.#(R(&)E<FEC:'0N
M`%9A;B!D92!V;VQL961I9R!S8VAE<FT@;6]D92!I<R!B96ME;F0L(&1A="!D
M:70@<')O8FQE;65N(&MA;B!V97)O;W)Z86ME;B!M970@26YT97)N970@17AP
M;&]R97(L('9A;G=E9V4@8G)O=W-E<F)U9W,@=V%A<B!W:6H@;FEE="!O;6AE
M96X@:W5N;F5N+B!(970@:7,@;6]G96QI:FL@9&%T('4@<F]M;65L(&EN(&AE
M="!B965L9'-C:&5R;2P@9V5B<F5K(&%A;B!E9&ET;W)F=6YC=&EE<R!E;B]O
M9B!R86YD;VT@8G)O=W-E<BT@8W)A<VAE<R!E<G9A87)T+B!786YN965R('5W
M('-Y<W1E96T@5VEN9&]W<R`Y>"!I<RP@:7,@:&5T('=A87)S8VAI:FYL:6IK
M(&1A="!U(&5E;B`G06QG96UE;F4@0F5V96EL:6=I;F=S($9O=70G(&MR:6IG
M="P@96X@;W!N:65U=R!D:65N="!T92!H97)S=&%R=&5N+EQN7&Y5(&)E;G0@
M9V5W86%R<V-H=7=D+B!$<G5K(&]P($]+('=A;FYE97(@=2!T;V-H(&1E('9O
M;&QE9&EG('-C:&5R;2!E9&ET;W(@=VEL="!P<F]B97)E;BX`1&4@:61E;G1I
M=&5I="`B)7,B(&ES('9E<G=I:F1E<F0N`$%L;&5E;B!D92!L:6YK97)K86YT
M`$1E('!L86%T<R!V86X@:&5T($=N=5!'('!R;V=R86UM82!D:65N="!O<&=E
M9V5V96X@=&4@=V]R9&5N(&EN(&1E($-R>7!T7W!G<#HZ(&-L87-S+@!(970@
M8F5R:6-H="!V97)S='5U<F0@;W`@)7,@86%N("5S(&UE="!O;F1E<G=E<G`@
M(B5S(B!I<R!W965R9V5G979E;BX*1&ET(&ES(&=E96X@9V%R86YT:64@9&%T
M(&AE="!B97)I8VAT(&ES(&=E;&5Z96X@;V8@8F5G<F5P96XN`$1E(&YA86T@
M9&EE(&=E8G)U:6MT('=O<F1T(&)I:B!L:6YK96X@;F%A<B!D92!N:65U=R!B
M97)I8VAT('!A9VEN80!$92!O<&5N<W-L(&UO9'5L92!I<R!V97)E:7-T('9O
M;W(@9&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`1&4@=F]O<FME=7)S
M:6YS=&5L;&EN9R`B)7,B(&MO;B!N:65T('=O<F1E;B!O<&=E<VQA9V5N+"!O
M;61A="!D92!D871A(&1E(&UA>&EM=6T@=&]E;&%A=&)A<F4@9W)O;W1T92!O
M=F5R<V-H<FEJ9'0N`$AE="!P<F]G<F%M;6$@;VT@9&ET(&1A=&%T>7!E("@E
M<RD@=&4@8F5K:6IK96XL('=E<F0@;FEE="!O<"!H970@<WES=&5E;2!G979O
M;F1E;BX`06QL965N(&1E(')E8VAT97(M(&5N(&QI;FME<FMA;G0`06QL965N
M(&1E(')E8VAT97)K86YT`$1E('-E<G9E<B`B)7,B(&ES('9E<G=I:F1E<F0N
M`$1E('-E<G9E<B`B)7,B(&ES(&]P9V5S;&%G96XN`$AE="!A86YM96QD:6YG
M<W9E<GIO96L@=F]O<B`E<R!I<R!V97)W:6ID97)D+@!$92!O<&=E9V5V96X@
M<FEJ(&)E<W1A870@;FEE="X`06QL965N(&1E(&)O=F5N+2!E;B!O;F1E<FMA
M;G0`06QL965N(&1E(&)O=F5N:V%N=`!$92!U<&QO861E9"!D871A(&ES(&YA
M(&1E('9O;W)G86%N9&4@<W1A<"!V97)L;W)E;B!G96=A86XN`$AE="!U<&QO
M861E9"!B97-T86YD(&ES(&YI970@;W!G97-L86=E;BX`2&5T('=E871H97(N
M8V]M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX`17(@>FEJ;B!G965N(&1O
M;W(@=&4@8FQA9&5R96X@861R97-B;V5K96XN`$=E96X@;W!T:65S(&)E<V-H
M:6MB86%R+@!%<B!Z:6IN(&=E96X@;VYD97)D96QE;BP@=V5L:V4@:6YL:6YE
M('=E97)G96=E=F5N(&MU;FYE;B!W;W)D96XN`$5R('II:FX@9V5E;B!B97-C
M:')I:F9B87)E(&%D<F5S8F]E:V5N+B!'965N('9A;B!D92!B97-C:&EK8F%R
M92!A9')E<V)O96ME;B!Z:6IN(&=E8V]N9FEG=7)E97)D('9O;W(@:&5T('1O
M979O96=E;B!V86X@;FEE=7=E(&EN=F]E<BX@5V%N;F5E<B!U(&1E;FMT(&1A
M="!D:70@965N(&9O=70@8F5T<F5F="P@;F5E;2!D86X@8V]N=&%C="!O<"!M
M970@9&4@<WES=&5E;6)E:&5E<F1E<BX`17(@>FEJ;B!T92!V965L(&MA<F%K
M=&5R<R!I;B!D:70@=F5L9"X@52!H965F="`E<R!K87)A:W1E<G,@;W!G96=E
M=F5N.R!U(&1I96YT(&UI;F1E<B!D86X@)7,@;W`@=&4@9V5V96XN`$5E;B!P
M<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($=E96X@)7,@=V5R9"!G
M975P;&]A9"X`165N('!R;V)L965M(&UE="!D92!B97-T86YD<W5P;&]A9#H@
M2&5T("5S(&ES(&=R;W1E<B!D86X@9&4@;6%X:6UU;2!T;V5L86%T8F%R92!G
M<F]O='1E("@E9"!B>71E<RDN`$5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N
M9'-U<&QO860Z($AE="`E<R!I<R!S;&5C:'1S(&=E9&5E;'1E;&EJ:R!G975P
M;&]A9"X`17(@:&5E9G0@>FEC:"!E96X@9F]U="!V;V]R9V5D86%N(&)I:B!H
M970@=&]E=F]E9V5N('9A;B!H970@;FEE=7=E(&%D<F5S+B!.965M(&-O;G1A
M8W0@;W`@;65T('5W('-Y<W1E96UB96AE97)D97(@=F]O<B!V97)D97)E(&AU
M;'`N`$5E;B!F;W5T(&)I:B!H970@;6%K96X@=F%N(&5E;B!N:65U=V4@;&EJ
M<W0N`$5E;B!F;W5T(&)I:B!H970@=F5R=VEJ9&5R96X@=F%N(&1I="!A9')E
M<SH@)7,`165N(&9O=70@8FEJ(&AE="!V97)W:6ID97)E;B!V86X@9&ET(&]B
M:F5C="X`165N(&9O=70@8FEJ(&AE="!B96MI:FME;B!V86X@9&ET(&)E<FEC
M:'1O;F1E<F1E96P`165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D
M92!A9')E<V1A=&$N`$5E;B!F;W5T(&)I:B!H970@:6UP;W)T97)E;B!V86X@
M9&4@9&%T83H@)7,`165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D
M92!I0V%L96YD87)D871A+@!%96X@9F]U="!I;B!H970@8V]N9FEG=7)A=&EE
M9F]R;75L:65R+B!-:7-S8VAI96X@8F5N="!U(&5E;B!V97)P;&EC:'0@=F5L
M9"!V97)G971E;BX`165N(&9O=70@8FEJ(&AE="!U:71V;V5R96X@=F%N(&1E
M(&]P9V5G979E;B!A9')E<V)O96MF=6YC=&EE+B!0<F]B965R(&QA=&5R(&]P
M;FEE=7<L(&$N=2YB+@!%96X@9F]U="!M970@:&5T(&)I:G=E<FME;B!V86X@
M9&4@861R97-D971A:6QS+B!0<F]B965R(&QA=&5R(&]P;FEE=7<L(&$N=2YB
M+@!%96X@9F]U="!M970@:&5T(&)I:G=E<FME;B!V86X@9&4@9&ES=')I8G5T
M:65L:6IS="X@4')O8F5E<B!L871E<B!O<&YI975W+"!A+G4N8BX`165N(&9O
M=70@8FEJ(&AE="!B:6IW97)K96X@=F%N(&1E>F4@:6YV;V5R.B`E<P!%<B!W
M87)E;B!G965N(&%D<F5S<V5N(&]M('1E(&5X<&]R=&5R96XN`$1E>F4@24U!
M4"!S97)V97(@;VYD97)S=&5U;G0@9V5E;B!D96QI;F<@=F%N(&UA<'!E;BX`
M1&ET(&QI:FMT(&YI970@965N(&=E;&1I9R!R87(@8F5S=&%N9"!T92!Z:6IN
M+@!$:70@;&EJ:W0@;FEE="!E96X@9V5L9&EG('II<"!B97-T86YD('1E('II
M:FXN`$1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@:V%A<G1N=6UM97(@=&4@
M>FEJ;BX`1&ET('-T=75R<')O9W)A;6UA(&=E969T(&1E(&UO9V5L:6IK:&5I
M9"!O;2!B97)I8VAT96X@=FEA(&1E($-L:6-K871E;&P@*&AT='`Z+R]C;&EC
M:V%T96QL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD96XL(&0N;2YV+B!D92!(
M5%10($%020!$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH
M96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD96XL(&0N;2YV+B!D92!(
M5%10($%020!$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH
M96ED(&]M(&)E<FEC:'1E;B!V:6$@4TU44"!D+FTN=BX@9&4@5F]D869O;F4@
M271A;'D@9V%T97=A>2!T92!V97)Z96YD96X@;F%A<B!6;V1A9F]N92!N=6UM
M97)S+B!(:65R=F]O<B!I<R!E96X@5F]D869O;F4@271A;'D@92UM86EL861R
M97,@*&AT='`Z+R]W=W<N,3DP+FET*2!N;V]D>F%K96QI:FLN`$1I="!V96QD
M(&ES('9E<F5I<W0`1&ET('9E;&0@;6%G(&%L;&5E;B!I;G1E9V5R<R!B979A
M='1E;BX`1&ET('9E;&0@;6%G(&%L;&5E;B!G971A;&QE;B!E;B!D92!D=6)B
M96QE('!U;G0@8F5V871T96XN`$1I="!V96QD(&UA9R!A;&QE96X@;V-T86%L
M('=A87)D96X@8F5V871T96XN`$1I="!V96QD(&1I96YT(&5E;B!K;VUM82!O
M9B!S<&%T:64@9V5S8VAE:61E;B!L:6IS="!M970@:6YT96=E<G,@=&4@>FEJ
M;@!$97IE('=A87)D92!D:65N="!E96X@9V5L9&EG(&=E=&%L('1E('II:FXN
M`$1I="!V96QD(&1I96YT(&5E;B!K;&5U<F-O9&4@:6X@4D="($A%6"UF;W)M
M86%T('1E(&)E=F%T=&5N+"!B+G8N("<C,3(S-&%F)RX`1&ET(&)E<W1A;F1S
M9F]R;6%A="!W;W)D="!N:65T(&]N9&5R<W1E=6YD+@!$:70@9F]R;75L:65R
M(&ES(')E961S('9E<G=E<FMT+@!$:70@:7,@)7,N`$1I="!I<R!E96X@2V]L
M86(@1W)O=7!W87)E(&]B:F5C="X@3VT@9&ET(&]B:F5C="!W965R('1E(&=E
M=F5N(&AE969T('4@965N(&4M;6%I;"!C;&EE;G0@;F]D:6<@9&EE(&AE="!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%A="!B96=R:6IP="X@5F]O<B!E96X@;&EJ
M<W0@;65T(&1E>F4@92UM86EL8VQI96YT<RP@8F5Z;V5K("5S+"!A+G4N8BX`
M1&ET(&)E<FEC:'0@:7,@:6X@965N(&%N9&5R92!K87)A:W1E<G-E="`H)7,I
M(&=E<V-H<F5V96XL(&1A;B!U=R!E:6=E;BX`1&ET(&=E=&%L(&1I96YT('1E
M;FUI;G-T92#IZ6X@=&4@>FEJ;BX`1&5Z92!P97)S;V]N(&AE969T(')E961S
M(&5E;B`E<R!I;G9O97(@:6X@:&5T(&%D<F5S8F]E:P!$97IE('-E<G9E<B!K
M86X@9V5E;B!Z:7`@96X@9WII<"!B97-T86YD96X@=6ET<&%K:V5N+@!(970@
M<WES=&5E;2!I<R!M;VUE;G1E96P@=6ET9V5S8VAA:V5L9"X`1&5Z92!W86%R
M9&4@9&EE;G0@965N(&=E=&%L('1E('II:FXN`$1I="!S8VAE<FT@9&EE;G0@
M86%N9V5R;V5P96X@=&4@=V]R9&5N('9A;G5I="!E96X@3W!T:65S<V-H97)M
M`$]N=V5E<@!4:6-K971S`%1I:F0`5&EJ9'!L86YN:6YG`%1I:F1F;W)M86%T
M`%1I:F1S96QE8W1I90!4:6UO<BU,97-T90!4:71E;`!4:71E;"`H=&]O;'1I
M<"DZ`$%A;@!/;2!M965R9&5R92!O;F1E<F1E;&5N('1E('-E;&5C=&5R96XL
M(&AO=60@9&4@0V]N=')O;"`H4$,I(&]F($-O;6UA;F0@*$UA8RD@=&]E=',@
M=F%S="!T:6ID96YS(&ML:6MK96XN`%9A;F1A86<`2%1-3"!B<F]N(&]M<V-H
M86ME;&5N`%1O9V\`5&]K96QA=0!-;W)G96X`5&]N9V$`0F]V96YK86YT`$)O
M=F5N<W1E(&9R86UE("A?=&]P*0!697)T86QI;F=E;@!4<FEN:61A9"!E;B!4
M;V)A9V\`5')U92!O9B!F86QS90!$:0!4=6YE<VGK`%1U<FMI:F4`5'5R:W,@
M*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!E;B!#86EC;W,@96EL
M86YD96X`5'5V86QU`%1Y<"!U=R!K975Z93H@`%4N5BX@:6YD97@Z(`!54DP`
M55),('9O;W(@=7<@869L979E<FEN9W-S=&%T=7-R87!P;W)T('-C<FEP=`!5
M4DPZ`$]E9V%N9&$`3V5K<F'O;F4`3FEE="!I;B!S=&%A="!61E,@9&ER96-T
M;W)Y(&%A;B!T92!S<')E:V5N+@!.:65T(&EN('-T86%T(&5X=')A(&=E8G)U
M:6ME<G-I;F9O<FUA=&EE('1O92!T92!V;V5G96X@8FEJ(&EN<V-H<FEJ=F5N
M+@!.:65T(&EN('-T86%T(&1E(')E8VAT96X@=F%N(%9&4R!B97-T86YD("(E
M<R(@=&4@=VEJ>FEG96XN`$YI970@:6X@<W1A870@9&4@<F5C:'1E;B!V86X@
M5D93(&)E<W1A;F0@)7,O)7,@=&4@=VEJ>FEG96XN`$YI970@:6X@<W1A870@
M=&4@=VEJ>FEG96X@;F%A<B`E<RX`3FEE="!I;B!S=&%A="!M970@9&4@4U%,
M('-E<G9E<B!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@;65T(%-33"!T
M92!V97)B:6YD96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@:V]P
M:>MR96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`B)7,B('1E(&UA
M:V5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@;6%K96XN`$YI
M970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@:6X@<W1A
M870@965N(&QE96<@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@:6X@<W1A
M870@9&%T82!U:70@=&4@<&%K:V5N+@!.:65T(&EN('-T86%T("(E<R(@=&4@
M=F5R=VEJ9&5R96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE96<`3FEE="!I
M;B!S=&%A="`E<R!T92!V97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y(&ES(&YI
M970@;&5E9P!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@<F5C=7)S:65F
M('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@
M=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`E
M<R!T92!V97)W:6ID97)E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"`B
M)7,B('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD
M('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R`E<R!R96-U<G-I
M968@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@:'5I9&EG92!D:7)E
M8W1O<GD@=&4@8F5P86QE;BX`3FEE="!I;B!S=&%A="!C97)T:69I8V%A=&1E
M=&%I;',@=6ET('1E(&9I;'1E<F5N`$YI970@:6X@<W1A870@;VT@9&4@9&5F
M:6YI=&EE('9A;B`E<R!T92!L861E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S
M=&%N9"!T92!V97)P;&%A='-E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N
M9"`B)7,B('1E(&]P96YE;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T
M92!O<&5N96X@=F]O<B!S8VAR:6IV96XN`$YI970@:6X@<W1A870@5D93(&)E
M<W1A;F0@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&AE="!I;F=E<&%K=&4@
M8F5S=&%N9"!T92!O<&5N96XN`$YI970@:6X@<W1A870@=F9S<F]O="!D:7)E
M8W1O<GD@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&]M("5S('1E(&AE<FYO
M96UE;B!N86%R("5S.B!B97-T96UM:6YG<VUA<"!B97-T86%T(&%L`$YI970@
M:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!H97)N;V5M96XN`$YI970@:6X@
M<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!H97)N;V5M96XN`$YI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!H97)N;V5M96XN`$YI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@)7,O)7,@=&4@:&5R;F]E;65N+@!.:65T(&EN
M('-T86%T(%9&4R!B97-T86YD('1E(&AE<FYO96UE;BX`2V%N("=M:VES;V9S
M)R!N:65T('5I='9O97)E;BX`3FEE="!I;B!S=&%A="!D:70@5V]R9"!D;V-U
M;65N="!T92!V97)T86QE;@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD("(E
M<R(@=&4@<V-H<FEJ=F5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E
M('-C:')I:G9E;B`H8V]P>2@I(&9A:6QE9"DN`$YI970@:6X@<W1A870@5D93
M(&)E<W1A;F1S9&%T82!T92!S8VAR:6IV96XN`$]N9&5R<W1R97!E;@!(97)S
M=&5L('=I:GII9VEN9V5N`$1O970@=7<@;&%A='-T92!B97=E<FMI;F<@=&5N
M:65T`$]N=F5R=V%C:'0@86YT=V]O<F0@=F%N(&1E('-E<G9E<B!O<"!V97)B
M:6YD:6YG.B``3VYV97)W86-H="!A;G1W;V]R9"!V86X@<V5R=F5R(&%A;CH@
M`$]N8F5N;V5M9`!5;FEC;V1E("A55$8M."D`5F5R96YI9V1E($%R86)I<V-H
M92!%;6ER871E;@!697)E;FEG9"!+;VYI;F=K<FEJ:P!697)E;FEG9&4@4W1A
M=&5N`%9E<F5N:6=D92!3=&%T96XL(&ML96EN92!B=6ET96X@;&EG9V5N9&4@
M96EL86YD96X`165N:&5D96X`3VYB96ME;F0`3VYB96ME;F0@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`3VYB96ME;F0@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`3VYB96ME;F1E(&=E8G)U:6ME<G-N86%M(&]F('=A8VAT
M=V]O<F0N`$AE="!H=6ED:6=E(&5L96UE;G0@;&]S:V]P<&5L96X`3VYB96YO
M96UD`$YI970@9V5R96-H=&EG9&4@<V-R:7!T<R!K=6YN96X@<')O9W)A;6UA
M;6%T:6<@;FEE="!+;FEP<&5N+TMO<&GK<F5N+U!L86MK96XL('9A;G=E9V4@
M8F5V96EL:6=I;F=S<F5D96YE;BX@2VQI:R!O<"!/2R!O;2!E96X@=&5C:&YI
M<V-H92!O<&UE<FMI;F<@;W`@;6]Z:6QL82YO<F<@=&4@8F5K:6IK96X@:&]E
M('4@965N('-C<FEP="!T;V5S=&%A="!H970@<')I:V)O<F0@=&4@8F5N861E
M<F5N+@!+;&5U<B!T97)U9W-T96QL96X`3FEE="!O;F1E<G-T975N9&4@97AT
M96YT:64`0FEJ=V5R:V5N`"5S(&)I:G=E<FME;@!'96)R=6EK97(@8FEJ=V5R
M:V5N+@!5<&=R861E('-C<FEP="!V97)W:6ID97)D+@!5<&QO860`06QL92!T
M;V5P87-S:6YG('-E='5P8F5S=&%N9&5N(&YA87(@9&4@<V5R=F5R(&=E=7!L
M;V%D+@!,871I:FYS92!H;V]F9&QE='1E<G,`1W)O=&4@4F]M96EN<V4@9V5T
M86QL96X`57)U9W5A>0!'96)R=6EK(&AU:61I9V4Z("5S`$=E8G)U:6L@4U-,
M`$=E8G)U:6ME;B!W86YN965R(&YA86TO=V%C:'1W;V]R9"!V97)S8VAI;'0@
M;65T($E-4U`@<V5R=F5R+@!'96)R=6EK97(@)7,@:7,@;FEE="!G96%U=&]R
M:7-E97)D('9O;W(@)7,N`$=E8G)U:6ME<G-B96AE97(`1V5B<G5I:V5R<V]P
M=&EE<P!'96)R=6EK97)S<F5G:7-T<F%T:64`1V5B<G5I:V5R<W)E9VES=')A
M=&EE(&ES('5I=&=E<V-H86ME;&0@;W`@9&5Z92!S:71E+@!'96)R=6EK97)S
M;F%A;0!'96)R=6EK97)S;F%A;3H`1V5B<G5I:V5R<VYA86TZ(`!'96)R=6EK
M97)S(&EN(&AE="!S>7-T965M.@!/97IB96MI<W1A;@!61E,@9&ER96-T;W)Y
M(&)E<W1A870@;FEE="X`069W97II9VAE:60`1V5V;VYD96X@9V5L9&EG92!L
M;V-A=&EE<R!B979A='1E;CH@`$=E;&1I9VAE:60`5V%A<F1E(&EN(&UI;G5T
M96X@=F%N868@;G4N`%=A87)D96X`5V%A<F1E;B!W86%R=6ET(&=E<V5L96-T
M965R9"!K86X@=V]R9&5N`%9A;G5A='4`5F%R:6%B96QE`%9E;F5Z=65L80!6
M97)I9FEC871I92!M:7-L=6MT("T@97(@:V%N(&UE="!D:70@8F5R:6-H="!G
M96MN;V5I9"!Z:6IN+@!697)I<VEG;B!D:7)E8W1O<GD`5F5R<VEE`%9E<G-I
M96-O;G1R;VQE`%9E<G1I:V%A;"!U:71L:6IN96X`5F5R=&EK86QE('9R:6IE
M(')U:6UT90!697)T:6MA86PZ`$5R9R!H;V]G`%9I971N86T`5FEE=&YA;65E
M<R`H5DE30TE)*0`E<R!B96MI:FME;@!!9')E<R!W965R9V5V96X`0F5K:6IK
M(&5E;B!E>'1E<FYE('=E8G!A9VEN80!"96MI:FME;B!A;',@)7,`4W1A;F1A
M87)D=V5E<F=A=F4Z`$UA86=D96X@96EL86YD96XL($)R:71S90!-86%G9&5N
M(&5I;&%N9&5N+"!6+E,N`%II8VAT`%II8VAT.B``5F]D869O;F4@271A;'D@
M=FEA(%--5%``5T%23@!704%24T-(55=)3D<A(2$@(%9%4E=)2D1%4B!30U))
M4%0@2$%.1$U!5$E'(%5)5"`E<RX`5V%L;&ES(&5N($9U='5N80!786%R<V-H
M=7=I;F<`5V\`5V5E<G-V;V]R=6ET>FEC:'0`5V5E<F)E<FEC:'0@9V5G979E
M;G,@9V5L979E<F0@9&]O<@!796%T:&5R+F-O;0!796(`5V5B<VET90!796)S
M:71E(%523`!796ME;&EJ:W,`5V5L:V]M`%=E;&MO;2!B:6H@)7,`5V5L:V]M
M+"`E<P!797-T97)S("A)4T\M.#@U.2TQ*0!797-T97)S("A)4T\M.#@U.2TQ
M-2D`5V5S=&5L:6IK92!386AA<F$`5V5L:V4@=&]E<&%S<VEN9R!D:65N="`E
M<R!W965R('1E(&=E=F5N(&YA(&%A;FUE;&1I;F<_`%=A="!I<R!H970@<V-H
M96ED:6YG<VMA<F%K=&5R/P!7870@:7,@:&5T(&-I=&%A=&MA<F%K=&5R/P!7
M96QK92!F87-E;@!796QK92!P;'5G:6YS('9O;W(@9&4@4FEC:"!497AT(&5D
M:71O<B!I;G-C:&%K96QE;BX`0G)E961T90!"<F5E9'1E(&EN($-34R!E96YH
M961E;@!"<F5E9'1E('9A;B!H970@)7,@;65N=2!A86X@9&4@;&EN:V5R:V%N
M="`H86MT:65F(&)I:B!V;VQG96YD92!A86YM96QD:6YG*3H`0G)E961T92!V
M86X@9&4@=&%B96P`0G)E961T92!E96YH96ED`$)R965D=&4Z`%=I:VD`5VEN
M9`!7:6YD<VYE;&AE:60@:6X@:VYO<&5N`%=I;F0Z`%=I;F0Z(`!7:6IS:&5I
M9`!797)K`%=E<FMA9')E<P!7;V]N<&QA871S("AW97)K*0!,86YD("AW97)K
M*0!496PN;G(N("AW97)K*0!496PN;G(N("AW97)K*0!3=&%A="!O9B!P<F]V
M:6YC:64@*'=E<FLI`%@M4F5F`%@U,#EV,R!B87-I<V)E<&5R:VEN9V5N`%@U
M,#EV,R!U:71G96)R96ED('-L975T96QG96)R=6EK`%@U,#EV,R!A;'1E<FYA
M=&EE=F4@;VYD97)W97)P;F%A;0!8-3`Y=C,@;VYD97)W97)P('-L975T96QI
M9&5N=&EF:6-A=&]R`%@U,#EV,R!E>'1E;G1I97,`2DH`2DI*2@!986AO;R$@
M;6%P`$IA87)L:6IK<P!*96UE;@!*80!*82P@:6L@86-C97!T965R(&1E('9O
M;W)W86%R9&5N`%4@8F5N="!I;B!414M35"!-3T1%+B!'96)R=6EK(&1E(%L\
M/ET@:VYO<"!O;2!N86%R(%=94TE764<@=&5R=6<@=&4@<V-H86ME;&5N+@!5
M(&)E;G0@;FEE="!G96%U=&AE;G1I9FEC965R9"X`52!K=6YT(&=E96X@)UPG
M(&MA<F%K=&5R(&EN('5W('9O;&QE9V4@;F%A;2!H96)B96XN`%4@:&5E9G0@
M9V5E;B!G96QD:6<@92UM86EL861R97,@;W!G96=E=F5N+@!5(&AE969T(&=E
M96X@=F5L9&5N('5I="!H970@9V5I;7!O<G1E97)D92!B97-T86YD(&=E:V]P
M<&5L9"!M970@9&4@;W9E<F5E;FMO;7-T:6=E('9E;&1E;B!I;B`E<RX`52!H
M965F="!G965N(')E8VAT(&]M(&1I="!A9')E<R!T92!B96MI:FME;BX`52!H
M965F="!G965N(')E8VAT(&]M(&1I="!O8FIE8W0@=&4@8F5K:6IK96XN`%4@
M8F5N="!A9F=E;65L9"X`52!D:65N="!E96X@9V5L9&EG(&UO8FEE;"!N=6UM
M97(@:6X@=&4@=F]E<F5N+"!A;&QE96X@8VEJ9F5R<R!M970@965N(&]P=&EO
M;F5L92`G*R<@=F]O<B!H970@:6YT97)N871I;VYA;&4@:VEE<W9O;W)V;V5G
M<V5L+@!5(&1I96YT(&5E;B!G96QD:6=E('=A87)D92!O<"!T92!G979E;BX`
M52!D:65N="!E96X@1&%T851R964@8F%C:V5N9"!T92!C;VYF:6=U<F5R96X@
M;VT@:6YS8VAR:6IV:6YG96X@=&4@:W5N;F5N(&=E8G)U:6ME;BX`52!D:65N
M="!H970@<')O8FQE96T@=&4@8F5S8VAR:6IV96XL('9O;W)D870@=2!H970@
M<')O8FQE96UR87!P;W)T(&MU;G0@=F5R>F5N9&5N+@!5(&1I96YT(&5E;B!5
M4DP@:6X@=&4@=F]E<F5N('=A87)N86%R(&1E>F4@;&EN:R!V97)W:6IS=`!5
M(&1I96YT(&5E;B!D;V5L861R97-B;V5K('1E('-E;&5C=&5R96XN`%4@9&EE
M;G0@965N(&1O96QL:6IS="!T92!S96QE8W1E<F5N+@!5(&1I96YT(&5E;B!S
M97)V97(@=&4@<V5L96-T97)E;B!O;2!T92!V97)W:6ID97)E;BX`52!D:65N
M="!T96YM:6YS=&4@965R<W0@Z>EN(&EN=F]E<B!T92!S96QE8W1E<F5N+@!5
M(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!T92!W
M:7-S96XN`%4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N
M(&]M('1E('9E<G=I:F1E<F5N+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A
M;2!O<"!T92!G979E;B!O;2!T;V4@=&4@=F]E9V5N+@!5(&1I96YT(&5E;B!G
M96)R=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!B:6H@=&4@:W5N;F5N('=E
M<FME;BX`52!D:65N="!E96X@8F5W97)K:6YG(&]P('1E(&=E=F5N('=E;&ME
M('5I=&=E=F]E<F0@;6]E="!W;W)D96XN`%4@9&EE;G0@965N(&YI975W92!C
M871E9V]R:65N86%M(&]P('1E(&=E=F5N+@!5(&AE969T(&%L;&5E;B!R96-H
M="!O;2!D:70@861R97,@=&4@8F5K:6IK96XN`%5W("5S('-E<W-I92!I<R!V
M97)L;W!E;BX@3W!N:65U=R!A86YM96QD96XL(&$N=2YB+@!5=R!E+6UA:6QA
M9')E<P!5=R!686XZ(&%D<F5S.@!5=R!I;F9O<FUA=&EE`%5W(&EN=&5R;F5T
M861R97,@:7,@9V5W:6IZ:6=D('-I;F1S(&AE="!B96=I;B!V86X@=7<@)7,@
M<V5S<VEE+B!/;2!U=R!V96EL:6=H96ED('1E(&)E<V-H97)M96XL(&1I96YT
M('4@>FEC:"!O<&YI975W(&%A;B!T92!M96QD96XN`%5W(&YA86TZ`$AE="!W
M965R9V5V96X@=F%N(&5E;B!G96)R=6EK97)S;&EJ<W0@=V]R9'0@;FEE="!O
M;F1E<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T:64@8F%C:V5N9"P@;V8@
M9&5Z92!O<'1I92!I<R!O;2!A;F1E<F4@<F5D96YE;B!U:71G97-C:&%K96QD
M+@!5=R!B<F]W<V5R(&QI:FMT('1E('II:FX@9V5W:6IZ:6=D('-I;F1S(&AE
M="!B96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U=R!V96EL:6=H96ED('1E
M(&)E<V-H97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T92!M96QD
M96XN`%5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z92!M;V=E;&EJ:VAE:60@
M;FEE="X`57<@:'5I9&EG92!T:6ID>F]N93H`57<@<W1A;F1A87)D(&ED96YT
M:71E:70Z`%5W('9O;&QE9&EG92!N86%M.@!5=R!N:65U=V4@=V%C:'1W;V]R
M9"!V;V]R("5S(&ES.B`E<P!5=R!O<'1I97,@>FEJ;B!B:6IG97=E<FMT+@!5
M=R!W86-H='=O;W)D(&ES(&=E<F5S970`57<@=V%C:'1W;V]R9"!I<R!V97)N
M:65U=V0L(&-O;G1R;VQE97(@=7<@92UM86EL(&5N(&UE;&0@86%N(&UE="!U
M=R!N:65U=V4@=V%C:'1W;V]R9"X`57<@<V5R=F5R<R!O<"!A9G-T86YD.@!*
M;V5G;W-L879IZP!:8>]R90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6U9E<F)E
M<F<@86%N9V5H86%L9&4@=&5K<W1=`%M0<F]B;&5E;7)A<'!O<G1=`%M!86YG
M96AA86QD92!T96MS="!W965R9V5V96X@+0!;06%N9V5H86%L9&4@=&5K<W0@
M+2`E<R!R96=E;'-=`%MR96=E;"`E<R!V86X@)7-=`%MG965N('=A87)D95T`
M0E]E:&5E<@!?0FQA9&5R96X`7T-,20!?1&%T851R964`5F5R7W=I:F1E<F5N
M`%9E<E]W:6ID97(@<FEJ`%]'<F]E<&5N`%](96QP`%]!9F)E96QD:6YG<V5I
M9V5N<V-H87!P96XN+BX`7TEM<&]R="]%>'!O<G0`7T%A;FUE;&1E;@!?069M
M96QD96X`7U=I:GII9R!L:6YK+BXN`%]/<'1I97,`7U)E8VAT96X`7U9E<G=I
M:F1E<B!L:6YK+BXN`%]5:70@9&5Z92!L:6IS="!V97)W:6ID97)E;BX`7UIO
M96ME;@!?26YS=&5L;&5N`%]486)E;&5I9V5N<V-H87!P96XN+BX`1V5?8G)U
M:6ME<G,`061R97-B;V5K`$MA;&5N9&5R`$MA;&T`2VQI:R!H:65R`&-O;G1A
M8W1S+G9C9@!C;VYT86-T<RYC<W8`8V]N=&%C=',N='-V`&1A;&5N9`!B97-T
M86YD`'9A;B!D92`E<R`H)7,I(&]P("5S("5S`&@Z`&]N;6ED9&5L:6IK`&EN
M;&EN90!R96=E;'-=`&UK:7-O9G,@9F]U=&-O9&4@)60@8FEJ(&AE="!A86YM
M86ME;B!V86X@25-/+@!N86%M`&YI970@=F%N('1O97!A<W-I;F<`3F]G(&YI
M970@=F%N('1O97!A<W-I;F<`;F]T:71I96)O96L`<')O8V5N=`!P:7AE;',`
M<W1I:F=E;F0`=&]O;B!V97)S8VAI;&QE;@!S;7,R96UA:6P@=FEA($A45%``
M<W1A8FEE;`!T86ME;FQI:G-T`%9O97(L('1E<B!B979E<W1I9VEN9RP@:&5T
M('=A8VAT=V]O<F0@='=E92!M86%L(&EN`'5N:69I960`;VYB96YO96UD`$=E
M8G)U:6ME<G-E;&5C=&EE`'9#87)D`'<Z`'=E871H97(N8V]M````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L
M92]N;E].3R\`````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-34`,#(P,#$Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O='5R8F$O;&]C86QE+VYN7TY/+TQ#7TU%4U-!1T53+P``````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C$U-S8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O;FY?3D\O3$-?
M34534T%'15,O='5R8F$N;6\`````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U,C$P`#$P
M-#$W,S8R-S4U`#`R,S(T-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#>$@25`````*D````<````9`4``.,```"L"@``````
M`#@.```+````.0X``"@```!%#@``%0```&X.```=````A`X```@```"B#@``
M!0```*L.```#````L0X```\```"U#@``"````,4.```(````S@X``!D```#7
M#@``!P```/$.```4````^0X```X````.#P``#P```!T/```%````+0\``!\`
M```S#P``.0```%,/```G````C0\``"P```"U#P``*@```.(/```1````#1``
M``8````?$```"````"80```&````+Q```!4````V$```"@```$P0```1````
M5Q````P```!I$```#@```'80```'````A1```!````"-$```*P```)X0```>
M````RA```!L```#I$```&P````41```S````(1$``"\```!5$0``*0```(41
M```"````KQ$```4```"R$0``$````+@1```&````R1$```\```#0$0``%```
M`.`1```O````]1$```D````E$@``#P```"\2```F````/Q(```0```!F$@``
M!0```&L2```-````<1(```4```!_$@``$````(42```0````EA(```\```"G
M$@``"P```+<2```/````PQ(```P```#3$@``#P```.`2```&````\!(``!X`
M``#W$@``(0```!83```B````.!,```,```!;$P``#````%\3```$````;!,`
M``0```!Q$P``%````'83```&````BQ,```0```"2$P``#````)<3```*````
MI!,```4```"O$P``$@```+43```0````R!,```@```#9$P``!````.(3```0
M````YQ,``!H```#X$P``!@```!,4```'````&A0```(````B%```)0```"44
M```$````2Q0```@```!0%```#P```%D4```'````:10```<```!Q%```"0``
M`'D4```'````@Q0``!(```"+%```!````)X4```'````HQ0```4```"K%```
M,P```+$4```:````Y10```4`````%0``!P````85```1````#A4```X````@
M%0``"````"\5```5````.!4``!X```!.%0``*````&T5```:````EA4```4`
M``"Q%0``*````+<5```I````X!4``!,````*%@``,@```!X6```$````418`
M``8```!6%@``"P```%T6```%````:18``!$```!O%@``!````($6```$````
MAA8```P```"+%@``!@```)@6```:````GQ8``!<```"Z%@``&@```-(6```7
M````[18``!L````%%P``-````"$7```9````5A<``!\```!P%P``$P```)`7
M```$````I!<``!````"I%P``%P```+H7```'````TA<```4```#:%P``,0``
M`.`7```X````$A@``"8```!+&```(0```'(8```<````E!@```4```"Q&```
M`P```+<8```@````NQ@``"0```#<&```)@````$9```&````*!D``!,````O
M&0``#````$,9```(````4!D``!0```!9&0``&P```&X9```'````BAD```8`
M``"2&0``#0```)D9```+````IQD```P```"S&0``"@```,`9```"````RQD`
M``8```#.&0``#````-49``!%````XAD``"8````H&@``)0```$\:```P````
M=1H``!````"F&@``<P```+<:```?````*QL``!````!+&P``#P```%P;``!B
M`0``;!L```H```#/'```*````-H<```4`````QT``!8````8'0``"````"\=
M```%````.!T```@````^'0``$P```$<=```,````6QT```\```!H'0``'@``
M`'@=```'````EQT``!$```"?'0``#@```+$=```,````P!T```4```#-'0``
M(P```-,=```[````]QT``"T````S'@``+P```&$>```N````D1X``!,```#`
M'@``"P```-0>```(````X!X```8```#I'@``%0```/`>```,````!A\``!8`
M```3'P``#@```"H?```6````.1\```4```!0'P``$````%8?```K````9Q\`
M`!T```"3'P``(````+$?```<````TA\``#````#O'P``-@```"`@```L````
M5R````(```"$(```!@```(<@```1````CB````4```"@(```$@```*8@```1
M````N2```"8```#+(```!P```/(@```1````^B```",````,(0``!0```#`A
M```&````-B$```X````](0``!````$PA```0````42$``!````!B(0``#P``
M`',A```/````@R$```\```"3(0``#````*,A```0````L"$```<```#!(0``
M'P```,DA```C````Z2$``"`````-(@``!````"XB```-````,R(```0```!!
M(@```P```$8B```4````2B(```<```!?(@``!0```&<B```/````;2(```\`
M``!](@``!0```(TB```3````DR(``!````"G(@``!0```+@B```$````OB(`
M`!(```##(@``(````-8B```(````]R(```<`````(P```@````@C```E````
M"R,```8````Q(P``#P```#@C```0````2",```D```!9(P``!P```&,C```)
M````:R,```@```!U(P``%0```'XC```$````E",```@```"9(P``!0```*(C
M```X````J",``"````#A(P``!P````(D```*````"B0``!$````5)```%```
M`"<D```'````/"0``!4```!$)```'````%HD```L````=R0``!8```"D)```
M!P```+LD```E````PR0``"0```#I)```%@````XE```O````)24```,```!5
M)0``!0```%DE```)````7R4```D```!I)0``%@```',E```%````BB4```4`
M``"0)0``$````)8E```#````IR4``!D```"K)0``#P```,4E```=````U24`
M``\```#S)0``&`````,F```N````'"8``!````!+)@``$````%PF```3````
M;28```,```"!)@``%0```(4F```:````FR8```<```"V)@``"````+XF```I
M````QR8``#4```#Q)@``,@```"<G```>````6B<``!X```!Y)P``!@```)@G
M```#````GR<``!X```"C)P``*@```,(G```H````[2<```@````6*```%```
M`!\H```0````-"@```H```!%*```%````%`H```@````92@```@```"&*```
M"0```(\H```/````F2@```P```"I*```#P```+8H```/````QB@```(```#6
M*```!0```-DH```.````WR@``#H```#N*```*@```"DI```M````5"D``#(`
M``""*0``#P```+4I``!Y````Q2D``"8````_*@``$````&8J```0````=RH`
M``$`````````D0```#<````G`````````#H```!2````$P```!P`````````
M`````!H`````````C0```$$````)````A`````````!F`````````"D```!#
M````H@```"X```!M````F0```&0```!@````%0````````!B````!0```%<`
M````````)@```(L```![````20``````````````2``````````'````70``
M``````"C`````````%@`````````:```````````````````````````````
M'@``````````````/0```(H```"H````?0```!0````*````(````(,```!'
M````D````(@```!"````&`````````!.`````````!$````7````*P```"P`
M``!%````9P```(<```!``````````(4`````````3P````````">````/@``
M``````"@````6P```#\```!Y````:0```($````O````/````$P```"I````
M``````````"E````I@```*<```!>````'0````````"?````C```````````
M````#0```)8````,````60```)H```""``````````````"2````)````(\`
M```V````EP``````````````,@```#@`````````6@```!D```!N````````
M``````!1````I`````````"8`````````#`````U``````````0`````````
M%@```&4```"=````?````%4````Y`````````%````!-`````````'(````.
M````2P```#L````T````(@```!L```!6`````P```#,```"5````B0```$0`
M````````:@``````````````*@```%0```!<````1@```%,```!^````#P``
M``@```!S````A@```&$```!W````<````'$````M````7P````````!_````
M'P````````!V`````````&,````0````*````",```!Z````,0```(``````
M````;````)L`````````:P````````!X````!@````````"A````E````)P`
M`````````````"4````2`````@```"$```!O````C@````L```"3````=0``
M`'0```!*`````"5S("T@3F]T:6-E`"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&9I
M;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D`#(T(&AO=7)S`$%-+U!-`$%D9`!!
M9&0@82!N97<@=7-E<CH`061D('!A:7(`061D('5S97(`061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:R!,:7-T:6YG`$%D
M;6EN:7-T<F%T:6]N`$%D=F%N8V5D(%-E87)C:`!!;&EA<P!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%V86EL86)L92!F:65L9',Z
M`$)R;W=S90!#86QE;F1A<@!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-E;&P@4&AO;F4`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-O
M;'5M;B!/<'1I;VYS`$-O;7!A;GD`0V]N9FER;2!087-S=V]R9`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O=6QD(&YO
M="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S
M<V%G92X`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D
M971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L
M9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!$1`!$
M86EL>0!$969A=6QT($ED96YT:71Y`$1E;&5T90!$96QE=&EO;B!F86EL960`
M1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@3W!T
M:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%
M9&ET`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E
M<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I
M;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S
M.@!%>'!O<G0`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@<V5A<F-H
M('1H92!D:7)E8W1O<GDZ("5S`$9A>`!&:6QE($UA;F%G97(`1FEN9`!&<F]M
M`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P<P!(96QP`$AO;64@061D<F5S
M<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$QA;F=U86=E`$QI<W0`3&ES="!(96QP(%1O<&EC<P!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G(&]U=`!-30!-4RU4
M3D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$UA:6P`36%T8VAI
M;F<`36%T8VAI;F<@9FEE;&1S`$UE;6)E<G,`365S<V%G90!-:6UE(%1Y<&4`
M36]N=&AL>0!.3RP@22!$;R!.3U0@06=R964`3F%M90!.971W;W)K`$YE=F5R
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;W1E<P!/<'1I
M;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!'4"!0=6)L:6,@2V5Y`%!A<W-W;W)D
M`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN/P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0:&]N90!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2X`4F5A9`!296UO=F4`4F5M;W9E('!A:7(`4F5S970`4F5T
M=7)N('1O($]P=&EO;G,`4F]L90!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O
M<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4VAO=P!3:VEP
M($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`
M5&%S:W,`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U
M8V-E<W-F=6QL>0!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&5R92!A<F4@;F\@8G)O=W-E86)L
M92!A9&1R97-S(&)O;VMS+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:71L90!54DP`
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5P9&%T90!5<V5R($%D;6EN:7-T<F%T:6]N
M`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5<V5R<R!I;B!T:&4@<WES=&5M.@!6
M:65W('1O(&1I<W!L87D@8GD@9&5F875L=#H`5V%R;FEN9P!7965K;'D`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!960!996%R;'D`665S+"!)($%G<F5E`%EO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=`%ML
M:6YE("5S(&]F("5S70!0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A(#(N,"UC
M=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2
M979I<VEO;BU$871E.B`R,#`R+3`V+3`X(#(R.C0T*S`Q,#`*3&%S="U4<F%N
M<VQA=&]R.B!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^"DQA;F=U
M86=E+51E86TZ($YO<G=E9VEA;B!.>6YO<G-K(#QN>6YO<G-K0&]R<W1A+F]R
M9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=`H`)7,@+2!.;W1I<P`E<R!V961L:6ME:&%L9'-O<&5R87-J;VYA
M<B`M(%-T861F97-T:6YG`"5S(%9I;&OE<B!F;W(@879T86QE`$9I;&$@)7,@
M=F%R="!I;7!O<G1E<G0`,C0@=&EM87(`04TO4$T`3&5G9R!T:6P`3&5G9R!T
M:6P@;GD@8G)U:V%R.@!,96=G('1I;"!P87(`3&5G9R!T:6P@8G)U:V%R`$QE
M9V<@=&EL(&)R=6MA<F%R(&5R('-LY71T(&%V+@!!9')E<W-E`$%D<F5S<V5B
M;VML:7-T:6YG`$%D;6EN:7-T<F5R:6YG`$%V86YS97)T('/X:P!!;&EA<P!%
M:6X@=6QO=FQE9R!V97)D:2!V87)T('-P97-I9FES97)T+@!3</AR(&]M('-T
M861F97-T:6YG(&;X<B!K^'ER:6YG(&%V('9E9&QI:V5H86QD<V]P97)A<VIO
M;F%R/P!0<OAV9&4@Y2!S;&5T=&4@96D@:6MK:F4M96MS:7-T97)A;F1E(&=R
M=7!P92X`4'+X=F1E(.4@<VQE='1E(&5I;B!I:VMJ92UE:W-I<W1E<F%N9&4@
M=&EL9V%N9RX`4'+X=F1E(.4@96YD<F4@96EN(&EK:VIE+65K<VES=&5R86YD
M92!T:6QG86YG+@!4:6QG:F5N9V5L96=E(&9E;'0Z`$)L82!G:F5N;F]M`$MA
M;&5N9&5R`$%V8G)Y=`!!=F)R>70@<')O8FQE;7)A<'!O<G0`36]B:6QT96QE
M9F]N`$ML:6MK(&9O<B#E(&AA;&1E(&9R86T`3'5K:R!V:6YD875G970`06QT
M97)N871I=B!F;W(@:V]L;VYN90!&:7)M80!3=&%D9F5S="!P87-S;W)D`$]P
M<&MO<&QI;F<@;6]T(&]F9F5N=&QE9R!N^&MK96QT96YA<B!N96MT82X`2W5N
M;F4@:6MK:F4@4$=0+6MO9&4@;65L9&EN9RX`2W5N;F4@:6MK:F4@4$=0+7-I
M9VYE<F4@;65L9&EN9RX`2W5N;F4@:6MK:F4@9&5K;V1E(%!'4"UD871A+@!+
M=6YN92!I:VMJ92!A=F=J97)E(&UO='1A:V%R96X@<VD@92UP;W-T861R97-S
M92X`2W5N;F4@:6MK:F4@<VMA9F9E(&]F9F5N=&QE9R!N^&MK96P@9G+E(&[X
M:VME;'1E;F%R96XN`$MU;FYE(&EK:VIE(&]P;F4@36%I;G1E;F%N8V5?5&%S
M:RUM;V1U;&5N("5S`$1$`$1A9VQE9P!3=&%N9&%R9&ED96YT:71E=`!3;&5T
M=`!+=6YN92!I:VMJ92!S;&5T=&4`4VMI;&1R92!P<F]B;&5M970`1&5T86QJ
M87(@97(@;&]G9V$@9F]R(&%D;6EN:7-T<F%T;W)E;BX`2V%T86QO9P!6:7-I
M;F=S86QT97)N871I=@!):VMJ92!B<G5K(&UA:6YT96YA;F-E+G!H<"!D:7)E
M:W1E+@!%;F1R90!%+7!O<W0`5&]M="!R97-U;'1A="X`1F5I;`!+=F%R="`Q
M-2X@;6EN=71T`$MV87)T(#,P+B!S96MU;F0`2W9A<G0@-2X@;6EN=71T`$MV
M87(@:6YN;&]G9VEN9P!+=F%R(&AA;'9E('1I;64`2W9A<G0@;6EN=71T`$5K
M<V5M<&5L=F5R9&EA<CH`16MS<&]R=`!+=6YN92!I:VMJ92!H96YT92!I;FYS
M=&EL;&EN9V%R`$MU;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN
M`$MU;FYE(&EK:VIE('/X:V4@:2!K871A;&]G96XZ("5S`$9A:W,`1FEL:&%N
M9'-A;6EN9P!&:6YN`$9RY0!'<G5P<&5A9&UI;FES=')E<FEN9P!'<G5P<&5R
M`$AJ96QP`$%D<F5S<V4L('!R:79A=`!496QE9F]N+"!P<FEV870`2&]R9&4`
M26UP;W)T97)T92!F96QT.B`E<P!);7!O<G1E<G1E(&9E;'0Z`%-P<N5K`$QI
M<W0`5FES(&5M;F4@9G+E($AJ96QP`$QI<W1I;F<@878@8G)U:V%R87(@97(@
M<VSE='0@878N`$QO9V<@:6YN`$QO9V<@=70`34T`35,M5$Y%1BUV961L96=G
M(&EN;F5H96QD="!I;F=E;B!D871A+@!%+7!O<W0`<V%M<W9A<F%N9&4@;65D
M`%-A;7-V87)A;F1E(&9E;'0`365D;&5M;6%R`$UE;&1I;F<`34E-12UT>7!E
M`$WE;F%D;&5G`$Y%22P@96<@97(@24M+2D4@<V%M9`!.86UN`$YE='1V97)K
M`$%L9')I`$EN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@<W!E<VEF
M:7-E<G0@9F]R(%-13"!61E,N`$EN9V5N(&=Y;&1I9V4@6$U,+61A=&$@<F5T
M=7)N97)T`$YO=&%T87(`06QT97)N871I=@!!;FYA;B!I;F9O<FUA<VIO;@!0
M1U`@;V9F96YT;&5G(&[X:VME;`!087-S;W)D`%!A<W-O<F1A(&WE('-A;7-V
M87)E+@!+^'ER('9E9&QI:V5H86QD<V]P97)A<VIO;F%R`$OX>7(@=F5D;&EK
M96AA;&1S;W!E<F%S:F]N87(@=F5D(&EN;FQO9V=I;F<_`%1I;&=A;F=S861M
M:6YI<W1R97)I;F<`5&5L969O;@!3:W)I=B!I;FX@96ET('-A;6%N9')A9R!A
M=B!P<F]B;&5M970N`%-K<FEV(&EN;B!D:71T(&)R=6MA<FYA;6X@;V<@<&%S
M<V]R9`!3:VEL9')I;F<@878@<')O8FQE;65T`$]F9F5N=&QE9R]P<FEV870@
M;OAK:V5L<&%R('9A<G0@:6MK:F4@9V5N97)E<G0N`$QE<P!&:F5R;@!&:F5R
M;B!P87(`3G5L;'-T:6QL`%1I;&)A:V4@=&EL(&%L=&5R;F%T:78`4F]L;&4`
M3&%G<F4`3&%G<F4@86QT97)N871I=@!3^&L`5F5L('-K:6QJ971E:6MN(&9O
M<B!D871O.@!696P@9&%T;V9O<FUA=#H`5F5L(&9I;"!S;VT@<VMA;"!I;7!O
M<G1E<F%S=#H`5F5L('1I9'-F;W)M870Z`%9E;"!T;R!S86US=F%R86YD92!F
M96QT+@!696P@:W9A(&9E;'0@<V]M('-K86P@=FES87-T(&D@861R97-S96QI
M<W1E;F4N`%9E;"!F87)G97-K:F5M82X`5F5L(/AN<VMA('-P<N5K.@!396YD
M('!R;V)L96UR87!P;W)T`%9I<P!(;W!P(&]V97(@=F5D;&EK96AA;&0`26YN
M=&%S=&EN9R!A=B!S<&5S:6%L=&5I:VX`4W5K<V5S<P!/<'!GY79E<@!+;&%S
M<V$@36%I;G1E;F%N8V4Z.B!V87)T(&EK:VIE(&QA<W1A(&EN;@!+<GEP=&5R
M:6YG<V9U;FMS:F]N86YE(&MR978@96D@<VEK:V5R(&YE='1O<'!K;W!L:6YG
M+@!);F=E;B!A9')E<W-E8OAK97(@=&EL9VIE;F=E;&5G(&9O<B!G:F5N;F]M
M<WEN:6YG+@!$971T92!T86QE="!MY2!V97)E(&UI;G-T(&5I;BX`1&5N;F4@
M=F5R9&EE;B!MY2!V97)E(&5I="!T86PN`%1I='1E;`!54DP`2V%N(&EK:VIE
M(&MO<&QE('1I;"!344PM=&5N87(N`$MU;FYE(&EK:VIE(&QA<W1E(&EN;B!D
M969I;FES:F]N96X@=&EL("5S+@!+86X@:6MK:F4@;VUS971J92!D971T92!7
M;W)D+61O:W5M96YT970N`$]P<&1A=&5R`$)R=6MA<F%D;6EN:7-T<F5R:6YG
M`$)R=6MA<F%L=&5R;F%T:78`0G)U:V%R;F%M;@!"<G5K87)A<B!I('-Y<W1E
M;65T.@!"<G5K(&1E;FYE('9I<VEN9V$@<V]M('-T86YD87)D.@#%='9A<FEN
M9P!+=F%R('9E:V4`5F5L:V]M96X@=&EL("5S`%9E;&MO;65N+"`E<P!!9')E
M<W-E+"!A<F)E:60`5&5L969O;BP@87)B96ED`,7%`,5R;&5G`$IA+"!E9R!E
M<B!S86UD`$1U(&WE('-K:6QD<F4@<')O8FQE;65T(&;X<B!D=2!K86X@<V5N
M9&4@<')O8FQE;7)A<'!O<G1E;BX`1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R
M=6MA<FYA;6X@Y2!F:F5R;F4N`$1U(&WE('-P97-I9FES97)E(&5I="!B<G5K
M87)N86UN(.4@;&5G9V4@=&EL+@#8:W1A(&1I("@E<RD@:&%R(&?E='0@=70@
M<.4@=&ED+B!,;V=G(&EN;B!PY2!N>71T+@!$:6X@:6YF;W)M87-J;VX`3&ES
M=&EN9R!A=B!B<G5K87)A<B!E<B!I:VMJ92!S=/AT=&$@878@8F%K<F4@875T
M96YT:7-E<FEN9RP@96QL97(@9G5N:W-J;VYE;B!H87(@878@96EN(&5L;&5R
M(&%N;F%N(&=R=6YN(&)L:71T('-LY71T(&%V+@!!;'1E<FYA=&EV82!D:6YE
M(&AA<B!B;&ET="!O<'!D871E<G1E+@!;4')O8FQE;7)A<'!O<G1=`%ML:6YJ
M92`E<R!A=B`E<UT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O;&]C86QE+W!L7U!,+P``````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C`P
M,3``(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O<&Q?4$PO
M3$-?34534T%'15,O````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4U`#`R,34W-0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U
M<F)A+VQO8V%L92]P;%]03"],0U]-15-304=%4R]T=7)B82YM;P``````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`R,#`S-C4`,3`T,3<S-C(W-34`,#(S,C4R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-X2!)4`````%P0`
M`!P```#4(```=P4``(Q!````````:%<``$@```!I5P``#@```+)7```/````
MP5<```T```#15P``"````-]7```+````Z%<```P```#T5P``&P````%8```M
M````'5@``"0```!+6```*0```'!8```I````FE@``!D```#$6```*````-Y8
M```D````!UD``"4````L60``#````%)9```+````7UD``!$```!K60``#@``
M`'U9```%````C%D``"@```"260``"````+M9```*````Q%D```D```#/60``
M$@```-E9```=````[%D```X````*6@``"@```!E:```-````)%H```X````R
M6@``$0```$%:```-````4UH```P```!A6@``#0```&Y:```&````?%H```P`
M``"#6@``#@```)!:```.````GUH```@```"N6@``"0```+=:```K````P5H`
M`!H```#M6@``,@````A;```X````.UL``%0```!T6P``40```,E;``!:````
M&UP``%<```!V7```-````,Y<```%`````UT``!$````)70``"````!M=```1
M````)%T``!`````V70``#P```$==```*````5UT``!````!B70```P```'-=
M```)````=UT```T```"!70``$@```(]=```/````HET```H```"R70``#P``
M`+U=```(````S5T``"0```#670``!@```/M=```4`````EX``!8````77@``
M"````"Y>```M````-UX``!D```!E7@``!P```']>```,````AUX``!0```"4
M7@``$@```*E>```:````O%X``"$```#77@``#@```/E>```#````"%\```\`
M```,7P``"P```!Q?```'````*%\```<````P7P``!0```#A?```#````/E\`
M`!<```!"7P``"@```%I?```/````95\``!@```!U7P``#@```(Y?```.````
MG5\``!0```"L7P``%P```,%?```7````V5\``!<```#Q7P``#P````E@```?
M````&6````<````Y8```!@```$%@```(````2&````\```!18```!@```&%@
M```*````:&````L```!S8```%0```']@```'````E6````4```"=8```$0``
M`*-@```,````M6```"@```#"8```.@```.M@```)````)F$```<````P80``
M!0```#AA```)````/F$``#D```!(80``"@```()A```&````C6$```D```"4
M80``!P```)YA```O````IF$``"X```#680``50````5B```M````6V(``"T`
M``")8@``+0```+=B```C````Y6(``",````)8P``+0```"UC```S````6V,`
M`!4```"/8P``&0```*5C```I````OV,``"0```#I8P``$@````YD```1````
M(60```H````S9```#````#YD```+````2V0```H```!79```"@```&)D```0
M````;60``!8```!^9```%@```)5D```'````K&0```<```"T9```%````+QD
M```*````T60```T```#<9```#````.ID```'````]V0```<```#_9```!@``
M``=E```1````#F4```4````@90``!P```"9E```&````+F4``!0````U90``
M"````$IE```.````4V4```H```!B90``!P```&UE```)````=64``!8```!_
M90``!````)9E```&````FV4```@```"B90``$0```*ME```#````O64```,`
M``#!90```P```,5E```3````R64```T```#=90``"````.ME```(````]&4`
M``@```#]90``00````9F```@````2&8```8```!I9@``!@```'!F```5````
M=V8``!@```"-9@``(@```*9F```=````R68```H```#G9@``%0```/)F```*
M````"&<```\````39P``#P```"-G```)````,V<``!0````]9P``&````%)G
M```=````:V<``!,```")9P``$0```)UG```$````KV<```8```"T9P``5```
M`+MG```.````$&@```\````?:```1````"]H```%````=&@```4```!Z:```
M5@```(!H```1````UV@``!$```#I:```%@```/MH```<````$FD``#\````O
M:0``$````&]I```,````@&D``!$```"-:0``#````)]I```7````K&D``!``
M``#$:0``"````-5I```%````WFD```P```#D:0``$````/%I```.`````FH`
M``T````1:@``%@```!]J```J````-FH```<```!A:@``#0```&EJ```'````
M=VH```<```!_:@``!P```(=J```/````CVH``!0```"?:@``"0```+1J```*
M````OFH```P```#):@``$````-9J```%````YVH``"4```#M:@``$@```!-K
M```3````)FL``!4````Z:P``$@```%!K```K````8VL``#L```"/:P``(```
M`,MK```:````[&L``!0````';```-@```!QL```0````4VP```X```!D;```
M"````'-L```,````?&P```0```");```#@```(YL```>````G6P``!L```"\
M;```(0```-AL```>````^FP``!X````9;0``+@```#AM```;````9VT``!X`
M``"#;0``,P```*)M```O````UFT``"`````&;@``$@```"=N```I````.FX`
M`!X```!D;@``%@```(-N``!!````FFX```<```#<;@``!@```.1N```-````
MZVX``!````#Y;@``!P````IO```2````$F\```<````E;P``!````"UO```,
M````,F\``"@````_;P```P```&AO```&````;&\```X```!S;P```@```()O
M```%````A6\```0```"+;P``#@```)!O```(````GV\```T```"H;P``#P``
M`+9O```0````QF\``!,```#7;P``30```.MO```3````.7```!H```!-<```
M!@```&AP```3````;W````P```"#<```$0```)!P```9````HG```!<```"\
M<```"P```-1P```-````X'```!8```#N<```&P````5Q```T````(7$```H`
M``!6<0``&````&%Q```9````>G$``!8```"4<0``+P```*MQ```/````VW$`
M``<```#K<0``"@```/-Q```*````_G$``!0````)<@``+P```!YR```)````
M3G(``!8```!8<@``#P```&]R```(````?W(```T```"(<@``)@```)9R```H
M````O7(```@```#F<@``$@```.]R```(`````G,```L````+<P``#@```!=S
M```%````)G,```8````L<P``!P```#-S```$````.W,```D```!`<P``"@``
M`$IS```/````57,``!````!E<P``%P```'9S```1````CG,``!$```"@<P``
M%P```+)S```%````RG,```L```#0<P``!0```-QS```-````XG,``!L```#P
M<P``"0````QT```.````%G0```T````E=```(````#-T```5````5'0``!$`
M``!J=```!P```'QT```%````A'0``!,```"*=```!P```)YT```(````IG0`
M``8```"O=```$````+9T```/````QW0``!````#7=```#P```.AT```+````
M^'0```\````$=0``#````!1U```/````(74```<````Q=0``!@```#EU```.
M````0'4```8```!/=0``$P```%9U```B````:G4``"T```"-=0``)0```+MU
M```:````X74``!4```#\=0``'@```!)V``!#````,78``"$```!U=@``&0``
M`)=V```7````L78``"4```#)=@``%P```.]V```B````!W<``!L````J=P``
M#0```$9W```,````5'<```,```!A=P``"````&5W```$````;G<```P```!S
M=P``"0```(!W```.````BG<```L```"9=P``&P```*5W```'````P7<```0`
M``#)=P``!P```,YW```*````UG<```0```#A=P``%0```.9W```&````_'<`
M``P````#>```#0```!!X```0````'G@``!L````O>```!````$MX```%````
M4'@```8```!6>```!P```%UX```%````97@```D```!K>```$P```'5X```"
M````B7@```T```",>```!@```)IX```)````H7@```<```"K>```!0```+-X
M```&````N7@```H```#`>```!````,MX```)````T'@```@```#:>```!@``
M`.-X```-````ZG@```8```#X>```!````/]X```%````!'D``"$````*>0``
M!````"QY```$````,7D```4````V>0``'0```#QY```$````6GD```P```!?
M>0``"0```&QY```,````=GD```H```"#>0``$````(YY```3````GWD``!,`
M``"S>0``"````,=Y```)````T'D```4```#:>0``*0```.!Y```'````"GH`
M``0````2>@``!P```!=Z```*````'WH```\````J>@``$````#IZ```&````
M2WH``!P```!2>@``&P```&]Z```2````BWH``!````">>@``!0```*]Z```)
M````M7H```0```"_>@``#````,1Z```4````T7H```H```#F>@``%````/%Z
M```7````!GL``!P````>>P``#0```#M[```-````27L``!,```!7>P``%@``
M`&M[```4````@GL```P```"7>P``$````*1[```9````M7L```0```#/>P``
M!P```-1[```&````W'L```8```#C>P``!0```.I[```'````\'L```<```#X
M>P``!0````!\```&````!GP```0````-?```!````!)\```*````%WP```4`
M```B?```#````"A\```/````-7P```H```!%?```"````%!\```K````67P`
M``0```"%?```"````(I\```F````DWP``!(```"Z?```!@```,U\```*````
MU'P``$P```#??```!P```"Q]```(````-'T``"`````]?0``#0```%Y]```)
M````;'T```X```!V?0``%@```(5]```1````G'T```8```"N?0``!P```+5]
M```'````O7T``!8```#%?0``#0```-Q]```$````ZGT``!````#O?0``&@``
M``!^```)````&WX```H````E?@``#````#!^```/````/7X```8```!-?@``
M!P```%1^```+````7'X``$<```!H?@``#0```+!^```#````OGX```H```#"
M?@```@```,U^```$````T'X```,```#5?@``!0```-E^```J````WWX```H`
M```*?P``!````!5_```&````&G\```@````A?P``"````"I_```$````,W\`
M``4````X?P``:````#Y_```%````IW\```8```"M?P``$````+1_```*````
MQ7\```@```#0?P``#P```-E_```*````Z7\```D```#T?P``%P```/Y_```#
M````%H````<````:@```"@```"*````+````+8````<````Y@```&@```$&`
M``!*````7(````8```"G@```"0```*Z````+````N(```"@```#$@```#```
M`.V````-````^H````H````(@0``%@```!.!```'````*H$``!0````R@0``
M!@```$>!```(````3H$```<```!7@0``"@```%^!```+````:H$``!<```!V
M@0``!P```(Z!```$````EH$```D```";@0``"0```*6!```*````KX$```<`
M``"Z@0``"0```,*!```)````S($```H```#6@0``!P```.&!```*````Z8$`
M`!4```#T@0``20````J"```*````5((```\```!?@@``"0```&^"```'````
M>8(```0```"!@@``"P```(:"```'````DH(```4```":@@``!0```*""```:
M````IH(```L```#!@@``%````,V"```'````XH(```4```#J@@``#0```/""
M```,````_H(```L````+@P``"````!>#```+````((,```0````L@P``!```
M`#&#```,````-H,```D```!#@P``"````$V#```%````5H,```<```!<@P``
M!````&2#```8````:8,``!<```""@P``"@```)J#```N````I8,``!$```#4
M@P``$````.:#```M````]X,``"T````EA```,0```%.$```M````A80``"X`
M``"SA```+P```.*$```L````$H4``!@````_A0``!````%B%```.````784`
M``8```!LA0``$````'.%```'````A(4```X```",A0``!0```)N%```&````
MH84```@```"HA0``$0```+&%```8````PX4```X```#<A0```@```.N%```0
M````[H4```<```#_A0``!@````>&```$````#H8``!\````3A@``%````#.&
M```'````2(8```X```!0A@``#````%^&```3````;(8```H```"`A@``!0``
M`(N&```1````D88```T```"CA@``$0```+&&```D````PX8``!4```#HA@``
M$@```/Z&```.````$8<``!D````@AP``"````#J'```)````0X<```H```!-
MAP``"````%B'```%````88<```8```!GAP``$````&Z'```(````?X<```@`
M``"(AP``$@```)&'```:````I(<```D```"_AP``"@```,F'```5````U(<`
M``4```#JAP``%````/"'```>````!8@``"@````DB```"@```$V(```1````
M6(@``!$```!JB```#P```'R(```4````C(@```0```"AB```"P```*:(```%
M````LH@``!$```"XB```"````,J(```T````TX@``#0````(B0``(````#V)
M```:````7HD``"8```!YB0``*````*")```I````R8D``!H```#SB0``!@``
M``Z*```(````%8H```<````>B@``%````":*```+````.XH```<```!'B@``
M$P```$^*```*````8XH``!0```!NB@``#P```(.*```R````DXH```L```#&
MB@``!0```-**```%````V(H``!4```#>B@``#````/2*```7`````8L``!0`
M```9BP``$@```"Z+```>````08L``!0```!@BP``#@```'6+```&````A(L`
M``P```"+BP``#0```)B+```5````IHL```L```"\BP``"@```,B+```+````
MTXL```\```#?BP``>P```.^+```;````:XP```4```"'C```#@```(V,```3
M````G(P``!$```"PC```!P```,*,```1````RHP```<```#<C```&````.2,
M```$````_8P```<````"C0``"@````J-```+````%8T```P````AC0``#@``
M`"Z-```2````/8T```8```!0C0``&````%>-```9````<(T``"4```"*C0``
M"0```+"-```#````NHT``!@```"^C0``"@```->-```,````XHT``!4```#O
MC0``"P````6.```9````$8X``"`````KC@``!0```$R.```*````4HX```P`
M``!=C@``!````&J.```)````;XX```<```!YC@``#````(&.```&````CHX`
M``X```"5C@``#0```*2.```1````LHX``!$```#$C@``#````-:.```3````
MXXX```P```#WC@``"P````2/```G````$(\``"4````XCP``&@```%Z/```7
M````>8\``!D```"1CP``&@```*N/```E````QH\``"@```#LCP``)P```!60
M```:````/9```!<```!8D```&P```'"0```B````C)```#0```"OD```)0``
M`.20```9````"I$``!\````DD0``$0```$21```;````5I$``!,```!RD0``
M!P```(:1```)````CI$```T```"8D0```P```*:1```_````JI$``#<```#J
MD0``5P```"*2```%````>I(```H```"`D@``$````(N2```)````G)(```T`
M``"FD@``!````+22```(````N9(```T```#"D@``"@```-"2```.````VY(`
M``L```#JD@``)0```/:2```=````'),```P````ZDP``&0```$>3```)````
M89,``!,```!KDP``"0```'^3```$````B9,``!````".DP``"````)^3```(
M````J),```\```"QDP``!P```,&3```.````R9,```<```#8DP``#````."3
M```;````[9,``"P````)E```!0```#:4```$````/)0``!<```!!E```.0``
M`%F4```*````DY0```P```">E```"0```*N4```)````M90``!$```"_E```
M!@```-&4```.````V)0```<```#GE```!@```.^4```'````]I0``"8```#^
ME```&P```"65```X````094``!H```!ZE0``*@```)65```9````P)4```4`
M``#:E0``#@```."5```(````[Y4```D```#XE0``!@````*6```+````"98`
M`!0````5E@```P```"J6```4````+I8```8```!#E@``&0```$J6```*````
M9)8``!P```!OE@``!0```(R6```0````DI8```D```"CE@``"````*V6```?
M````MI8``"@```#6E@``*0```/^6```C````*9<``"$```!-EP``'P```&^7
M```G````CY<``"8```"WEP``'P```-Z7``#,````_I<``#$```#+F```00``
M`/V8```S````/YD``"4```!SF0``7@```)F9```G````^)D``#P````@F@``
M+````%V:```H````BIH``"T```"SF@``+P```.&:```I````$9L``#`````[
MFP``*````&R;```J````E9L``"(```#`FP``'@```..;```O`````IP``"P`
M```RG```%P```%^<```B````=YP``"(```":G```10```+V<```V`````YT`
M`#`````ZG0``!````&N=```+````<)T```4```!\G0```@```(*=``!9````
MA9T```4```#?G0``!````.6=```'````ZIT```@```#RG0``!0```/N=```3
M`````9X```T````5G@``!P```".>```&````*YX``!0````RG@``#````$>>
M```&````5)X```,```!;G@``!````%^>```&````9)X```<```!KG@``%P``
M`'.>```@````BYX``!H```"LG@``)````,>>```F````[)X```P````3GP``
M%````""?```.````-9\```T```!$GP``!P```%*?```'````6I\``!D```!B
MGP``%0```'R?```&````DI\```8```"9GP``!P```*"?```,````J)\``!$`
M``"UGP``"````,>?```=````T)\```D```#NGP``"@```/B?```4`````Z``
M``H````8H```"````".@```'````+*````D````TH```$@```#Z@```'````
M4:````@```!9H```"0```&*@```'````;*````P```!TH```&0```(&@```*
M````FZ```!L```"FH```%P```,*@```4````VJ```!$```#OH```!P````&A
M```#````":$```L````-H0``!@```!FA```'````(*$```T````HH0``"P``
M`#:A```4````0J$``!4```!7H0``#@```&VA```O````?*$``#$```"LH0``
M/P```-ZA```,````'J(```D````KH@``#````#6B```*````0J(``!````!-
MH@``$P```%ZB```3````<J(```(```"&H@``!````(FB```&````CJ(```4`
M``"5H@```P```)NB```,````GZ(``"4```"LH@``,````-*B```O`````Z,`
M`!D````SHP``10```$VC```F````DZ,``!X```"ZHP``*0```-FC```F````
M`Z0``"4````JI```+@```%"D```2````?Z0``!,```"2I```$````*:D``!Y
M````MZ0```D````QI0``<@```#NE``!S````KJ4``!<````BI@``*P```#JF
M```6````9J8```\```!]I@``'P```(VF``!`````K:8``!\```#NI@``%```
M``ZG```*````(Z<```4````NIP``!@```#2G```(````.Z<``!````!$IP``
M"@```%6G```$````8*<```\```!EIP``!P```'6G```$````?:<```<```""
MIP``"P```(JG```'````EJ<```4```">IP``#@```*2G```'````LZ<```@`
M``"[IP``#P```,2G```(````U*<```P```#=IP``#P```.JG```6````^J<`
M``<````1J```!@```!FH```&````(*@```P````GJ```"````#2H```+````
M/:@```P```!)J```#````%:H```$````8Z@```0```!HJ```!P```&VH```8
M````=:@```<```".J```!0```):H``!>`0``G*@``$,```#[J0``#@```#^J
M```2````3JH``!$```!AJ@``!P```'.J```(````>ZH```H```"$J@``(@``
M`(^J```O````LJH``!T```#BJ@``(@````"K```P````(ZL``!X```!4JP``
M,@```'.K```B````IJL``"0```#)JP``"@```.ZK```*````^:L``!`````$
MK```#P```!6L```%````):P``"<````KK```#P```%.L```.````8ZP```H`
M``!RK```$````'VL```<````CJP``!````"KK```"````+RL```1````Q:P`
M``T```#7K```$P```.6L```,````^:P```L````&K0``#@```!*M```&````
M(:T```T````HK0``$@```#:M```2````2:T```@```!<K0``"@```&6M``!#
M````<*T``!<```"TK0``/P```,RM``!(````#*X``%P```!5K@``60```+*N
M``!B````#*\``%\```!OKP``00```,^O```%````$;````X````7L```#@``
M`":P```4````-;````X```!*L```$@```%FP```%````;+```!H```!RL```
M!0```(VP```,````D[```!````"@L```%@```+&P```9````R+````T```#B
ML```%0```/"P```*````!K$``!X````1L0``"````#"Q```;````.;$``"``
M``!5L0``$0```':Q```M````B+$``"8```"VL0``!0```-VQ```0````X[$`
M`!@```#TL0``%@````VR```B````)+(``!X```!'L@``#0```&:R```'````
M=+(``!4```!\L@``"@```)*R```'````G;(```@```"EL@``!0```*ZR```(
M````M+(``",```"]L@``#P```.&R```5````\;(``!<````'LP``#````!^S
M```,````++,``!<````YLP``%P```%&S```C````:;,``!@```"-LP``$P``
M`*:S```E````NK,```8```#@LP``!@```.>S```(````[K,```\```#WLP``
M"0````>T```*````$;0```D````<M```$````":T```)````-[0```@```!!
MM```$0```$JT```.````7+0``!,```!KM```(0```'^T```)````H;0```<`
M``"KM```!0```+.T```+````N;0``#T```#%M```"`````.U```(````#+4`
M``D````5M0``!P```!^U```X````)[4``#@```!@M0``6P```)FU```W````
M];4``#<````MM@``-P```&6V```N````G;8``#(```#,M@``-P```/^V```]
M````-[<``"$```!UMP``)0```)>W```O````O;<``#$```#MMP``$@```!^X
M```.````,K@```L```!!N```#````$VX```/````6K@```H```!JN````P``
M`'6X```)````>;@``!0```"#N```'P```)BX```,````N+@```<```#%N```
M%@```,VX```*````Y+@``!@```#ON```$P````BY```(````'+D```8````E
MN0``!@```"RY```4````,[D```4```!(N0``!P```$ZY```&````5KD``!8`
M``!=N0``"````'2Y```0````?;D```D```".N0``!P```)BY```(````H+D`
M`!0```"IN0```P```+ZY```(````PKD```@```#+N0``$P```-2Y```#````
MZ+D```,```#LN0```P```/"Y```;````]+D``!4````0N@``"0```":Z```(
M````,+H```<````YN@``3P```$&Z```M````D;H```8```"_N@``!@```,:Z
M```9````S;H``!T```#GN@``+`````6[```@````,KL``!D```!3NP``%@``
M`&V[```)````A+L``!,```".NP``$P```**[```)````MKL``!8```#`NP``
M&@```->[```?````\KL``!4````2O```%@```"B\```$````/[P```4```!$
MO```1@```$J\```/````D;P``!4```"AO```,P```+>\```%````Z[P```4`
M``#QO```5````/>\```+````3+T``!<```!8O0``&````'"]```@````B;T`
M`$````"JO0``%P```.N]```0`````[X``!8````4O@``#````"N^```9````
M.+X```T```!2O@``"````&"^```%````:;X```T```!OO@``#````'V^```,
M````BKX```T```"7O@``&P```*6^```O````P;X```<```#QO@``!P```/F^
M```)`````;\```8````+OP``!0```!*_```+````&+\``!4````DOP``"0``
M`#J_```'````1+\```X```!,OP``#P```%N_```%````:[\``!T```!QOP``
M'````(^_```=````K+\``!\```#*OP``&P```.J_```L````!L```#L````S
MP```*0```&_````9````F<```!8```"SP```/@```,K````.````"<$```P`
M```8P0``"````"7!```+````+L$```8````ZP0``#0```$'!```K````3\$`
M`"@```![P0``+@```*3!```K````T\$``"H```#_P0``.0```"K"```E````
M9,(``"@```"*P@``+0```+/"```S````X<(``"8````5PP``%@```#S#```M
M````4\,``"````"!PP``(@```*+#``!%````Q<,```0````+Q```!@```!#$
M```+````%\0```L````CQ```"0```"_$```6````.<0```D```!0Q```!```
M`%K$```+````7\0``#<```!KQ```!@```*/$```$````JL0```\```"OQ```
M`@```+_$```*````PL0```0```#-Q```#0```-+$```(````X,0```X```#I
MQ```%0```/C$```2````#L4``!0````AQ0``6````#;%```4````C\4``!L`
M``"DQ0``!````,#%```6````Q<4```H```#<Q0``$````.?%```9````^,4`
M`!X````2Q@``#````#'&```,````/L8``!L```!+Q@``&P```&?&```Z````
M@\8```L```"^Q@``&````,K&```5````X\8``!0```#YQ@``-`````['```2
M````0\<```4```!6QP``!0```%S'```(````8L<```T```!KQP``,````'G'
M```'````JL<``"8```"RQP``$@```-G'```'````[,<```D```#TQP``+@``
M`/['```C````+<@``!T```!1R```(P```&_(```(````D\@```L```"<R```
M#@```*C(```)````M\@```8```#!R```!P```,C(```&````T,@```L```#7
MR```"@```./(```1````[L@``!$`````R0``&````!+)```0````*\D``!4`
M```\R0``&````%+)```%````:\D```@```!QR0``!0```'K)```+````@,D`
M`"4```",R0``"0```++)```0````O,D``!````#-R0``-@```-[)```;````
M%<H``!`````QR@``!P```$+*```$````2LH``!<```!/R@``!P```&?*```'
M````;\H```8```!WR@``$0```'[*```1````D,H``!(```"BR@``$````+7*
M```4````QLH``!0```#;R@``#P```/#*```5`````,L```<````6RP``!@``
M`![+```,````)<L```<````RRP``&0```#K+```D````5,L``#(```!YRP``
M*````*S+```=````U<L``!L```#SRP``'@````_,``!(````+LP``"H```!W
MS```'P```*+,```@````PLP``"8```#CS```(@````K-```>````+<T``!,`
M``!,S0``"P```&#-```0````;,T```0```!]S0``!````(+-```%````A\T`
M``\```"-S0``"P```)W-```+````J<T```\```"US0``)@```,7-```&````
M[,T```8```#SS0``"0```/K-```$````!,X```@````)S@``$@```!+.```'
M````)<X``!`````MS@``$````#[.```3````3\X``"X```!CS@```@```)+.
M```%````E<X```8```";S@``!@```*+.```%````J<X```D```"OS@``%P``
M`+G.```#````T<X``!,```#5S@``!@```.G.```*````\,X```<```#[S@``
M!0````//```0````"<\```D````:SP``!````"3/```)````*<\```@````S
MSP``!@```#S/```-````0\\```8```!1SP``!````%C/```%````7<\``!<`
M``!CSP``!0```'O/```&````@<\```8```"(SP``'````(_/```(````K,\`
M``P```"USP``!@```,+/```$````R<\```P```#.SP``#````-O/```+````
MZ,\```P```#TSP``"`````'0```(````"M````4````3T```)0```!G0```%
M````/]````0```!%T```"````$K0```+````4]````\```!?T```$0```&_0
M```'````@=```"$```")T```(````*O0```4````S-```!$```#AT```!0``
M`//0```)````^=````0````#T0``#0````C1```8````%M$```X````OT0``
M'````#[1```;````6]$``!T```!WT0``$0```)71```0````I]$``!H```"X
MT0``'0```-/1```=````\=$``!$````/T@``%````"'2```$````-M(```0`
M```[T@``"````$#2```&````2=(```<```!0T@``!@```%C2```'````7](`
M``<```!GT@``!P```&_2```&````=](```8```!^T@``"````(72```*````
MCM(```4```"9T@``$````)_2```-````L-(```X```"^T@``"@```,W2```Q
M````V-(```8````*TP``"````!'3```H````&M,```\```!#TP``!@```%/3
M```)````6M,``$X```!DTP``"P```+/3```%````O],```0```#%TP``%```
M`,K3```(````W],``!8```#HTP``&P```/_3```9````&]0```4````UU```
M!P```#O4```'````0]0```4```!+U```#0```%'4```%````7]0``!8```!E
MU```)P```'S4```%````I-0```P```"JU```#@```+?4```9````QM0```<`
M``#@U```!P```.C4```6````\-0``%<````'U0``&P```%_5```%````>]4`
M``H```"!U0```@```(S5```$````C]4```,```"4U0``!0```)C5```)````
MGM4```H```"HU0``!@```+/5```&````NM4```<```#!U0``"````,G5```$
M````TM4```4```#7U0``6P```-W5```&````.=8```@```!`U@``#P```$G6
M```)````6=8```4```!CU@``#0```&G6```*````=]8```D```""U@``&@``
M`(S6```#````I]8```<```"KU@``"@```+/6```.````OM8```D```#-U@``
M'P```-?6``!:````]]8```8```!2UP``"````%G7```1````8M<``",```!T
MUP``#````)C7```4````I=<```H```"ZUP``)````,77```(````ZM<``!(`
M``#SUP``!@````;8```(````#=@```H````6V```"@```"'8```-````+-@`
M`!P````ZV```!@```%?8```(````7M@```T```!GV```#@```'78```/````
MA-@```X```"4V```#@```*/8```/````LM@``!````#"V```#@```-/8```(
M````XM@``!D```#KV```.@````79```%````0-D``!4```!&V0``"@```%S9
M```%````9]D```4```!MV0``#````'/9```'````@-D```4```"(V0``!0``
M`([9```8````E-D```@```"MV0``$P```+;9```$````RMD```4```#/V0``
M#@```-79```.````Y-D```P```#SV0``"@````#:```-````"]H```H````9
MV@``"````"3:```.````+=H```D````\V@``"0```$;:```%````4-H```<`
M``!6V@``!````%[:```=````8]H``"$```"!V@``"@```*/:```9````KMH`
M`!@```#(V@``$````.':```K````\MH``"L````>VP``+P```$K;```K````
M>ML``"P```"FVP``+0```-/;```J`````=P``!P````LW```!0```$G<```'
M````3]P```@```!7W```%0```&#<```,````=MP```X```"#W```!P```)+<
M```%````FMP```@```"@W```#0```*G<```6````M]P```X```#.W````@``
M`-W<```4````X-P```L```#UW```!0````'=```$````!]T``"<````,W0``
M%````#3=```%````2=T```@```!/W0``"P```%C=```7````9-T```L```!\
MW0``!````(C=```/````C=T```H```"=W0``$````*C=```G````N=T``!(`
M``#AW0``&@```/3=```3````#]X``"P````CW@``!P```%#>```+````6-X`
M``P```!DW@``"````''>```%````>MX```8```"`W@``$0```(?>```(````
MF=X```4```"BW@``$P```*C>```6````O-X```8```#3W@``!P```-K>```3
M````XMX```4```#VW@``$````/S>```:````#=\``"T````HWP``"P```%;?
M```,````8M\```P```!OWP``#P```'S?```3````C-\```0```"@WP``"```
M`*7?```'````KM\``!4```"VWP``"````,S?```D````U=\``"````#ZWP``
M'P```!O@```;````.^```!P```!7X```%@```'3@```F````B^```!````"R
MX```!@```,/@```*````RN````<```#5X```&0```-W@```.````]^````<`
M```&X0``#0````[A```/````'.$``!L````LX0``'@```$CA```Z````9^$`
M``D```"BX0``!0```*SA```)````LN$``",```"\X0``$````.#A```>````
M\>$``"(````0X@``%````#/B```A````2.(``!8```!JX@``#@```('B```$
M````D.(```D```"5X@``#````)_B```0````K.(```D```"]X@``!````,?B
M```0````S.(``!8```#=X@``A0```/3B```<````>N,```4```"7XP``#0``
M`)WC```3````J^,``!$```"_XP``!@```-'C```/````V.,```<```#HXP``
M&0```/#C```*````"N0```<````5Y```$@```!WD```,````,.0```T````]
MY```'````$OD```%````:.0```8```!NY```'0```'7D```;````D^0``"@`
M``"OY```"P```-CD```#````Y.0``"L```#HY```#````!3E```-````(>4`
M`!,````OY0``"P```$/E```7````3^4``!D```!GY0``!0```('E```*````
MA^4``!````"2Y0``!@```*/E```+````JN4```D```"VY0``#````,#E```&
M````S>4``!,```#4Y0``'0```.CE```A````!N8``!(````HY@``"P```#OF
M```8````1^8```T```!@Y@``#0```&[F```J````?.8``"L```"GY@``&P``
M`-/F```4````[^8``!T````$YP``'P```"+G```@````0N<``"P```!CYP``
M'````)#G```;````K><``!4```#)YP``&@```-_G```E````^N<``#D````@
MZ```(@```%KH```8````?>@``!\```"6Z```$````+;H```>````Q^@``!D`
M``#FZ```!P````#I```(````".D```T````1Z0``!0```!_I```^````)>D`
M`#4```!DZ0``5@```)KI```,````\>D```@```#^Z0``%`````?J```0````
M'.H```L````MZ@``!0```#GJ```/````/^H```X```!/Z@``"P```%[J```3
M````:NH```P```!^Z@``,P```(OJ```7````O^H```P```#7Z@``,````.3J
M```&````%>L``!`````<ZP``"````"WK```(````-NL``!@````_ZP``"```
M`%CK```(````8>L```X```!JZP``!P```'GK```1````@>L```8```"3ZP``
M$0```)KK```A````K.L``!(```#.ZP``"0```.'K```$````Z^L``!D```#P
MZP``-`````KL```/````/^P```\```!/[```#@```%_L```)````;NP``!0`
M``!X[```!@```(WL```,````E.P```4```"A[```!@```*?L```*````KNP`
M`"````"Y[```&0```-KL```@````].P``!8````5[0``(````"SM```9````
M3>T```4```!G[0``%````&WM```'````@NT```4```"*[0``!P```)#M```*
M````F.T```4```"C[0```P```*GM```5````K>T```8```##[0``!@```,KM
M```+````T>T```@```#=[0``!P```.;M```.````[NT```L```#][0``"0``
M``GN```D````$^X``"\````X[@``)@```&CN```@````C^X``!P```"P[@``
M'````,WN```C````ZNX``#$````.[P``(````$#O``#>````8>\``#,```!`
M\```1P```'3P```N````O/```"P```#K\```>````!CQ```L````D?$``#X`
M``"^\0``,````/WQ```M````+O(``#(```!<\@``.````(_R```M````R/(`
M`#,```#V\@``+````"KS```Q````5_,``!X```")\P``*0```*CS```J````
MTO,``"H```#]\P``%@```"CT```A````/_0``"4```!A]```0@```(?T```K
M````RO0``#@```#V]```!````"_U```,````-/4```4```!!]0```@```$?U
M``!>````2O4```0```"I]0``!````*[U```'````L_4```4```"[]0``!0``
M`,'U```1````Q_4``!````#9]0``!P```.KU```&````\O4``!0```#Y]0``
M#`````[V```&````&_8```,````B]@``!````";V```&````*_8```<````R
M]@``&@```#KV```I````5?8``",```!_]@``'@```*/V```M````PO8```T`
M``#P]@``'````/[V```/````&_<```,````K]P``"````"_W```)````./<`
M`!P```!"]P``&P```%_W```*````>_<```<```"&]P``!P```([W```1````
MEO<``!<```"H]P``$0```,#W```F````TO<``!(```#Y]P``$P````SX```7
M````(/@```H````X^```!P```$/X```'````2_@```D```!3^```$````%WX
M```&````;O@```<```!U^```"@```'WX```(````B/@```X```"1^```$```
M`*#X```-````L?@``!4```"_^```&@```-7X```D````\/@```\````5^0``
M"P```"7Y```#````,?D```H````U^0``"@```$#Y```&````2_D```L```!2
M^0``"@```%[Y```5````:?D``!8```!_^0``$````);Y```S````I_D``#<`
M``#;^0``3P```!/Z```.````8_H```X```!R^@``#````('Z```/````COH`
M`!0```">^@``$P```+/Z```+````Q_H```(```#3^@``!````-;Z```&````
MV_H```4```#B^@```P```.CZ```0````[/H``!\```#]^@``)P```!W[```F
M````1?L``!````!L^P``)P```'W[```H````I?L``!T```#.^P``+P```.S[
M```S````'/P``#(```!0_```,0```(/\```1````M?P```X```#'_```$```
M`-;\``"!````Y_P```H```!I_0``70```'3]``!>````TOT``!P````Q_@``
M-@```$[^```3````A?X``!P```"9_@``(````+;^``!`````U_X``"8````8
M_P``%0```#__```*````5?\```0```!@_P``!@```&7_```(````;/\``!0`
M``!U_P``#P```(K_```&````FO\```X```"A_P``#P```+#_```$````P/\`
M``D```#%_P``#````,__```&````W/\```8```#C_P``#P```.K_```(````
M^O\```@````#``$`#0````P``0`&````&@`!``P````A``$`#````"X``0`5
M````.P`!``<```!1``$`#0```%D``0`,````9P`!`!````!T``$`"0```(4`
M`0`+````CP`!``P```";``$`#````*@``0`$````M0`!``@```"Z``$`"```
M`,,``0`8````S``!``D```#E``$`!0```.\``0`!````G@$``#X!```<`P``
M!0````````"%`0```````&(!``#0`@```````,L"````````[@,``&4"``!S
M`@``;`$``"T#``"[`0````````````#7`@``Z0,``!P"```X`0```````-X#
M``!(`P`````````````,`0`````````````)`````````*,```!^`0``````
M`-T#``!J````\0(``,,#``#+````H@(```````#[`````````#<```#^`P``
M?@(````````-`@``30(``+8"````````H````$8#``"?````#@,`````````
M````&`,``&<!``````````````D!``"&`P``V0````````!M`@```0,``+D#
M``!E````8@,``$D!`````````````,H"```N`P``L0(``$\!``#A`0``QP``
M`&0````A`0``H0(``%H```#9`P````````````#O`0````````````!X````
M`````-X`````````-`(``"@`````````C`(``&,```````````````(!````
M````J@(``"T```!6````J0$`````````````J`$``,X#``#4`P``MP```&`"
M``#7`0``90,``(,`````````V`$`````````````;P(```@!```2`@``^@$`
M``````#M`````````*L"````````!@0``/L"``"6`P```````.P!``";`P``
M%P```!0#``"?`P``B0(``!<"````````7@```*H!``!Q`P``%@(``$X#``#W
M````^0```.8"```\````]P,``)L"```5`````````%````".`0``]`$`````
M``"^`0```````$<```#R````'@,``+H"``!2````'0(```````">`P``#P$`
M`````````P```@(``"`"```3`0``9P,``)(#````````6`(```````#D`0``
M`````#("`````````````.(#``#/`@````````P$``"N`@``<0$``$4!````
M````;P$``$\"``"_`````````,,!```0````(0```.<!```>`@``K0,``*D`
M```;`0```````'<`````````80,``+P!``!Z`@``&0````````"8`0``)0(`
M``````"Q`P``(0(``!$"````````40(``.`#````````\@$``%,#```D`P``
M````````````````.`,``(0#``""`P``(P(``)T```#(`@``(`,```````"\
M````#`(``,8!``!H`0``/@(```````!3`@``!@,``#\#``!Q`@``P0```/<"
M``````````0```````!>`P```0$``!8!````````%00```L!``#,`P``F0$`
M`*(!``#"`@``J0,``.L!``!$`0``>`(``%$`````````Z@```.<#``!6`@``
M`````,`#``"T`0``OP,`````````````K````,T"``#C`0``/`,`````````
M````>P,`````````````6````*H`````````AP,```````#E`P``+@$``/T`
M```;`@```````"H!``#1`P``60```$4````K````,@$```````!*`P``?```
M``4"``!1`P``]```````````````8P,``+0"``````````````````"Y`0``
M+P$``#$"````````80$``#D```#?`0``Y`,``"H```#6`@``Q@,```````#L
M````````````````````4P```!\!````````X@````0!```1`P``#P0``#0!
M``#``@``@P,``*T```!,`0``H0```($!``"0````6P(``-0!```Z`@``(@(`
M`!T#`````````````-4```#3`P````````````"-````A`(````````?````
MKP```$H````#`````````%8#````````6`,``#D!``#=`@``L`,```````"Q
M`0``<@```,\```"S`0``K@```$`#``#,`````````)\"```W`P``Q0,``(T"
M``#3`0``)P```.H#``!C`0``=`(```8"``!H`P``)@``````````````%@,`
M`)D"``"\`@``)@(```````!U````(P,``+H!``#2`@``UP```%("``"E`P``
M)@$``$8"```G`@``^`(```L#``#/`P``:`(```````!+````O@,``.@#````
M`````````&L!````````2P(```````#+`0``KP(``%X"````````&`(``&X!
M````````]@````````!*`0```````.$`````````/0(```````#!`P``\0$`
M`%8!``!=`P``IP(```(#````````0P```#H```">`@``\P(``/T#``"%````
MJP$``)$"``!8`0``C`$``",`````````]0$``+<#``#R`@```````$P```!I
M````C0,```````#*`0``.P(``$@!``"<`0``A@```(\!```-`0``W@(``)H!
M````````,P$``-$```!0`@``!P$````````O````_`(```````!F`P``````
M`.L`````````:@$``)8!``!Y`@``;@(`````````````^`,```````#V`@``
M`````+0#```3`@`````````````'`P``G0(```````"S`P``````````````
M````0@,``)$#``!7`0```````)<"``!<`P``8`$``,D"``"X````#P```#8`
M````````X`$```H```#G`@``EP,``+T#````````I@,``/H```!M`0``B`,`
M``,$``!7`P``@`````````"[````C@,``!($``"Y`@``G0$```````#6````
MY0$```````"3````)P,``-0`````````BP$``.X!``!<`@``]`,``)<````.
M`@``Y@$``*8"``#E````"`(``'`#``!E`0``1`,``/T"``!+`P``*`(``)H`
M``#Y`0````````````!2`0``1P,``(H"``!5`````````-````";````````
M`)`#``"2`0``````````````````CP```*\!``!M````)0$``(<```!L`@``
MG````'$`````````?`,``+H```#*````.@,``#@````0`P``#0````$$``"X
M`P``+`(``(,"````````U0(``'X`````````&```````````````(@$`````
M``!.`@``7`$``$\`````````A0,```````#%`0``#P,``&8"````````K@$`
M`$T```#2````7````(<!```N`@``NP,``,@#````````Z````(D#````````
M.P,``.<````S`P```````%D!````````>P(`````````````````````````
M````VP,``"<!````````-@,``#X#``".`@``!P0``$T#````````BP````$"
M``"@`P```````*<!``#;````%P0``)4```#&``````````P`````````````
M```````0!```@P$``$P#``#^`0``'P,```H$```E`P``N@,``!D"``#)````
M;P```(D!``"D`0``G0,``.(!``"D`P``,0`````````1````BP,``!(!``"U
M`````````$8``````````````-@"``#Y`@``/@```%`!``#"`0``7P(``!H"
M```\`@``O0```$\#````````B@,```````"A`0``V````(`"```,`P``H`(`
M`#`#```E````,@`````````'````B@```!H#````````Q`,``!,#```&````
M`````(\"``!?````'````$`!``"R`0``.P$``!0```!"````=`````0"``!4
M`0``5P```/4"``"P`0``80```'4#``"$````PP(``,0!``#:`P```````+,"
M````````_P```!\"````````&`$``"@#`````0``JP```'0!````````K0$`
M`$0```"L`0``0P(``)@"```5`0``S0$``.T"```M`0``VP(`````````````
M`````/@!````````D`(``,D#``#2`P````````````"E`@``3@```#,`````
M`````````%\#``!G`@```````&H"````````E@(``````````````````%<"
M````````SP$``$@"````````\@,```````!&`0``H`$`````````````````
M`!H```#Y`P```````,H#``"D````FP$```````!"`0``2````!0"``!V`P``
MS@$``-`!````````V@$````````.`0``^@,```<"```K`P``UP,```````#%
M````&P```*4`````````\0```&$"``#,`@``\`,```\"````````*P(``,<"
M```Y`@``D0$```D#``!V`@``3@$```T$``"1``````````````"C`P``)`(`
M``,#``#F`P```````$4#``"U`@``H@,``+4#``#;`0```````$,#``#L`@``
M\P,``*@#``!'`0``G`(``&("``"!`@``W0$``!(#``#\`0``S0````````#_
M`P``+P,```````!Z`0``#0,``#@"```5`@``]0,`````````````````````
M``!``````````````````````````/,!``"[`@``S@(``&,"````````````
M`)X```"+`@``%0,``,X```"^`@``XP,``"D"```&`0``C`````````!=`0``
M7@$`````````````*`$``)0"``!9`@```````````````````````,`!```I
M`P``@@(``.,````V`0``*0$``&8!``#I`0``KP,``',#``#S````,`$``/P#
M``"]`0``C`,``.0"``!U`0``$0$``)H"``#K`@``7P$```````#:`@``````
M`-H```#X````I`(``/X"``#%`@``IP,``%`#``#2`0``D@`````````+````
MJP,```````#6`P``DP,``!H!``"B``````(``),"```B`P``K`,``)4#``!P
M`0``70```#<!``"^````6P$``*<``````````````&0"```V`@``50$``-T`
M``"(`0``\`$``)D```"V````WP,``/\"``#@`@``\`(``.4"````````ZP,`
M``````"R`P``U`(```4!``!;`P``-P(``,8"``#<`````````.8`````````
M"P0``'<!```_````B`(```````"5`0```````$D"``#8`P``R`$``-`#``!!
M`0``%@```$`"```@`````````"(`````````:0,```````"M`@``;````%0`
M````````X0(``($````=`````````````````````````)@#``!3`0``)@,`
M``````#C`@```````!<#````````;`,``*X#``````````````($``!*`@``
MJ`(``%0"``#L`P``W@$``$$#````````TP``````````````X````#\"``#O
M`@``50(``#H!````````@@````````!@````[0,``"0!``!S`0``Z@(``-\`
M```[````^P$``",!```4!```L@```!<!````````H0,```````!N`P``00``
M`+8#``"F`0``"@(``+`````#`@``V0$``+8!````````?0(```````!B````
M`````,(```````````````````#O`P``:@,````````.`````````.D"```4
M`0``GP$``+\!```D``````````````!-`0``C@`````````N````"`,`````
M``#3`@```````)("``#M`0``L0```#0#``!4`P``8`,``'L`````````Z`$`
M`)P#``!]`P``````````````````9@`````````L`P```````(8"``"4`P``
M"00```````#[`P```````*,!``!H``````````````#5`0``?`(``+@"````
M````E`$``/<!``"Y`````````/0"````````$`$``,P!``"``0``>0,```0$
M``!1`0```````"$#``!S````'0$```````#]`0``_P$``#$!``!V````M0$`
M`,``````````_`````````#"`P```````'0#``!P````RP,``)`!``"``P``
M-0(``(\#```Y`P``"@,``/X`````````O0(``/H"``!O`P``W`(``&0#````
M````20```#T```!W`P``60,``,0"``#A`P``>0$```````#O````/`$``"P!
M```6!```+0(``$0"``"\`P``<`(``'P!``!]````V0(``'\````J`P``Y```
M`'(!````````````````````````"0(``"P```"F`````````*P"``"E`0``
M,`(``$$"`````````````(H!``#N`@``&P,````````````````````````U
M````'`$`````````````-0,``&0!``!^`P``=P(``.@"``![`0```````-$"
M```_`0``!00```````"S````,0,```@```!+`0````````````#'`0``0P$`
M`.D`````````50,``-8!``":`P``W`$``)0`````````B0```(<"```3````
M``````,!````````>@,``)<!````````6@,``'D`````````:P```,,```"!
M`P````````````#1`0``#@0```````"J`P``!0,``.H!````````A0(``)8`
M```$`P``J0(``&L#``"C`@``&0$``),!```K`0````````````"9`P``0@(`
M`#4!``#V`P``-``````````"````L`(``!$$```@`0````````````#<`P``
M$`(````````$````?P,`````````````MP(``$D#``"&`0``U0,``%T"```S
M`@``\````'T!``!U`@``>`,```````"H`````````%L`````````C0$`````
M``!Z`````````!X`````````=@$```````!G````?P(``((!``#-`P``,```
M`$<"``!R`@``OP(```@$``#Q`P``<@,``'\!````````R````&T#```]`P``
M&0,```L"``"$`0``F````&X````2````MP$``#(#```3!```B```````````
M````L@(``#T!``#B`@````````````#N````P0$``/8!``#U`````````"D`
M``#?`@``'@$``,$"``#$````>`$``%H!``#)`0``4@,``)4"``!I`@``:P(`
M`"H"``!%`@``N`$``+0```#'`P``:0$``$P"```O`@``6@(````````*`0``
M`"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@
M*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R
M<F]W*0`@*'EE<W1E<F1A>2D`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N
M`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y
M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@
M;F]T(&-O<&EE9"!B96-A=7-E(&ET(&ES(&$@;&ES="X`(B5S(B!W87,@;F]T
M(&-R96%T960Z("5S+@`B)7,B('=A<R!N;W0@;6]V960@8F5C875S92!I="!I
M<R!A(&QI<W0N`")&:7)S=&YA;64@3&%S=&YA;64B("`H:64N($IO:&X@1&]E
M*0`B3&%S=&YA;64L($9I<G-T;F%M92(@*&EE+B!$;V4L($IO:&XI`"5D("5S
M(&%N9"`E<P`E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@861D960N`"5S(&%L
M<F5A9'D@97AI<W1S+@`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E
M<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@
M)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S
M($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+2T@<V5L96-T("TM`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U
M<P!!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-+U!-
M`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B;W9E('-E87)C:"!F;W)M
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`
M061?=F%N8V5D(%-E87)C:`!!9&0`061D($AE<F4Z`$%D9"!.97<@1W)O=7``
M061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN
M`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@
M82!-;WII;&QA(%-I9&5B87(`061D('1O`$%D9"!T;R!A9&1R97-S(&)O;VLZ
M`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061D<F5S<R!"
M;V]K($QI<W1I;F<`061D<F5S<R!B;V]K(&5N=')Y`$%D9')E<W,@8F]O:R!I
M<R!R96%D+6]N;'DN`$%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D
M+@!!9&UI;FES=')A=&EO;@!!9',`061V86YC960@4V5A<F-H`$%F9VAA;FES
M=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&P`06QL($%U=&AE;G1I8V%T
M960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S`$%L<F5A9'D@17AI<W1S`$%L<F5A9'D@97AI<W1S
M`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S`$%L=&5R;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X
M>0!!;G-W97(`06YT87)C=&EC80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I
M<R!R96%D>2X`07!P<F]V90!!<')I;`!!<F-H:79E($9I;&4@4VEZ90!!<F-H
M:79E($YA;64`07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E
M("5S/P!!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE
M('-E;&5C=&5D(&5N=')I97,_`$%R9V5N=&EN80!!<FUE;FEA`$%R=6)A`$%S
M8V5N9&EN9P!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T<FEB=71E<P!!=6=U<W0`075S=')A
M;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%V
M86EL86)L92!#;VQU;6YS.@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N
M`$)/1D@@17AC=7-E<P!"85]C:R!T;R`E<P!"86-K('1O("5S`$)A8VMG<F]U
M;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A
M9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%S:5]C(%-E87)C:`!"87-I8R!3
M96%R8V@`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96QO=R!S96%R8V@@9F]R
M;0!"96YI;@!"97)M=61A`$)H=71A;@!":6YD(&9A:6QE9#H@*"5S*2`E<P!"
M:7)T:&1A>0!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&EV:6$`0F]O
M:VUA<FMS`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!"<F%Z:6P`0G5L
M9V%R:6$`0G5S:6YE<W,@0V%T96=O<GD`0TU3`$-20P!#4U8`0U]E;&P@4')O
M<&5R=&EE<RXN+@!#7VQE87(@4V5A<F-H`$-A;&5N9&%R`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@
M24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M("(E<R(N`$-A<&4@5F5R9&4`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<')O<&5R=&EE<P!#96QL<&AO
M;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E
M($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0VAA9`!#:&%N9V4`0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H96-?:R!,:6YK
M+BXN`$-H96-K(%]!;&PO3F]N90!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#
M:&EL90!#:&EN80!#:&]O<V4@82!D969A=6QT(&1I<F5C=&]R>2!F;W(@>6]U
M<B!P97)S;VYA;"!A9&1R97-S8F]O:RP@8V]N=&%C="!L:7-T<RP@86YD('-E
M87)C:&5S+@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#
M:&]O<V4@86X@861D<F5S<R!B;V]K`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SH`0VAO;W-E('1H92!O<F1E<B!O9B!T:&4@8V]L=6UN<R!T;R!D:7-P
M;&%Y(&EN('1H92!A9&1R97-S(&QI<W0N`$-H<FES=&UA<R!)<VQA;F0`0VQE
M87(@4V5A<F-H`$-L:6-K('1O($-O;G1I;G5E`$-L;W-E(%=I;F1O=P!#;V-O
M<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&]M8FEA
M`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;'5M;B!/
M<'1I;VYS`$-O;'5M;B!T:71L97,`0V]M;6$@<V5P87)A=&5D('9A;'5E<P!#
M;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RD`0V]M
M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;W)O<P!#;VUP86YY`$-O
M;7!A;GD@061D<F5S<P!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`
M0V]N9&ET:6]N<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG
M;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE
M8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@
M9F%I;&5D.B`E<P!#;VYN96-T:6]N(&9A:6QU<F4`0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T(')E;6]V
M960@9G)O;2!L:7-T+@!#;VYT86-T<R!I;B!L:7-T.B`E<P!#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M0V]N=&5N=',@;V8@(B5S(@!#;VYT96YT<R!O9B`E<P!#;VYT:6YU90!#;V]K
M($ES;&%N9',`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@4$=0(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($94
M4#H@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&]B=&%I;B!P
M=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@
M(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO
M="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O
M<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O
M=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H
M92!S:61E8F%R(&ES(&]P96XN`$-O=6YT<GD`0W)E871E`$-R96%T92!A(&QI
M;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&5D`$-R961I="!C87)D(&YU;6)E
M<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-Y<')U<P!#>F5C:"!297!U
M8FQI8P!$1`!$86EL>0!$871E`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E
M9F%U;'0@0V]L;W(`1&5F875L="!$:7-P;&%Y`$1E9F%U;'0@261E;G1I='D`
M1&5F875L="!097)M:7-S:6]N<P!$969A=6QT(&1I<F5C=&]R>2!F;W(@>6]U
M<B!P97)S;VYA;"!A9&1R97-S8F]O:RP@8V]N=&%C="!L:7-T<RP@86YD('-E
M87)C:&5S+@!$969A=6QT('!E<FUI<W-I;VYS`$1E9F%U;'0@<V]R=&EN9R!D
M:7)E8W1I;VXZ`$1E;&5T90!$96QE=&4@0V]N9FER;6%T:6]N`$1E;&5T92!'
M<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S`$1E;&5T92!B=71T;VX@8F5H879I;W5R`$1E;&5T92!C96QL`$1E;&5T
M92!C;VQU;6X`1&5L971E(&9A:6QE9#H@*"5S*2`E<P!$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N
M9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T
M92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@
M86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971I;VX@9F%I;&5D`$1E;FUA<FL`
M1&5P87)T;65N=`!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T
M:6]N<P!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT('1O(&-O;F9I<FT@
M9&5L971I;F<@96YT<FEE<S\`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D('9#87)D`$1R=6=S`$4M
M36%I;`!%8W5A9&]R`$5D:70`161I="`B)7,B`$5D:70@1W)O=7``161I="!0
M97)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F
M;W(@)7,`161I="!E;G1R>2!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I
M="!P97)M:7-S:6]N<R!F;W(@)7,`16=Y<'0`16P@4V%L=F%D;W(`16UA:6P`
M16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UO
M=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YT<GD@9F]R("5S('5P9&%T960N
M`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=W)I=&EN
M9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED
M96)A<@!%>'!O<G0`17AP;W)T($%D9')E<W,@0F]O:P!%>'!O<G0@;VYL>2!T
M:&4@<V5L96-T960@8V]N=&%C=',N`$5X<&]R="!T:&4@9F]L;&]W:6YG(&%D
M9')E<W,@8F]O:R!C;VUP;&5T96QY+@!&86EL960@=&\@86-C97-S('1H92!A
M9&1R97-S(&)O;VLZ("5S`$9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S`$9A
M:6QE9"!T;R!B<F]W<V4@;&ES=`!&86EL960@=&\@8G)O=W-E('1H92!D:7)E
M8W1O<GD`1F%I;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@
M/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@/2`E<P!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&
M86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@9FEN9"!O8FIE8W0@
M=&\@8F4@861D960Z("5S`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE
M9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,`1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&
M96)R=6%R>0!&:6II`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE
M8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M`$9I;'1E<G,`1FEN9`!&:6YL86YD`$9I<G-T($YA;64`1F]O9`!&;W)G;W0@
M>6]U<B!P87-S=V]R9#\`1G)A;F-E`$9R965B=7-Y(%523`!&<F5N8V@@1W5I
M86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S`$9R;VT`1V%B;VX`1V%M8FEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=L;V)A;"!!9&1R97-S($)O;VL`1V\`1V]O9VQE(%-E87)C:`!'<F5E8V4`
M1W)E96YL86YD`$=R96YA9&$`1W)O=7``1W)O=7!S`$=U861E;&]U<&4`1W5A
M;0!'=6%T96UA;&$`1W5E<FYS97D`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y
M86YA`$A434P`2&%I=&D`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S`$AE;'``2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($-I='D`2&]M92!#;W5N=')Y
M`$AO;64@4&AO;F4`2&]M92!0;W-T86P@0V]D90!(;VUE(%-T871E+U!R;W9I
M;F-E`$AO;64@4W1R965T($%D9')E<W,`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B
M`$AU;F=A<GD`24U34`!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@=VET:"!T
M97AT`$ED96YT:71Y)W,@;F%M93H`26UA9V5S`$EM<&]R="!!9&1R97-S($)O
M;VLL(%-T97`@)60`26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS`$EM<&]R
M=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN9&EA`$EN9&]N97-I
M80!);F9O`$EN<V5R="!);6%G90!);G9A;&ED($-O;G1E;G0M5'EP90!);G9A
M;&ED($E$`$EN=F%L:60@861D<F5S<R!B;V]K`$EN=F%L:60@9&%T82!S=6)M
M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!E
M;6%I;`!);G9A;&ED(&5N=')Y`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI
M9"!K97D@<W!E8VEF:65D+@!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED
M(&YA;64`26YV86QI9"!O8FIE8W1)9`!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F`$ER87$`27)E;&%N9`!)<W)A96P`27-S=65R`$ET86QY`$IA;6%I8V$`
M2F%N=6%R>0!*87!A;@!*;W)D86X`2G5L>0!*=6YE`$MA>F%K:'-T86X`2V5N
M>6$`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME
M>2!4>7!E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2W5W86ET`$MY<F=Y
M>G-T86X`3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M
M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+@!,85]Y;W5T
M`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA
M<W0@36]D:69I960`3&%S="!.86UE`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QE<V]T
M:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E
M:6X`3&ES=`!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A
M;&4@86YD(%1I;64`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;W<`3'5X96UB
M;W5R9P!-30!-3U1$`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86EL`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M<F-H`$UA<F=I;@!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI
M;F<`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>&EM
M=6T@;G5M8F5R(&]F('!A9V5S`$UA>0!-87EO='1E`$UE;G4@;6]D93H`365R
M9V4@8V5L;',`365S<V%G90!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-97AI8V\`36EM92!4>7!E
M`$UI;FD@4V5A<F-H`$UI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG
M=7)A=&EO;BX`36]B:6QE(%!H;VYE`$UO9&EF:65D($1A=&4`36]D:69Y(%52
M3`!-;V1I9GD@9F%I;&5D.B`H)7,I("5S`$UO9'5L=7,`36]L9&]V82P@4F5P
M=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E('1H86X@,2!E;G1R>2!F;W5N9`!-;W)O8V-O`$UO
M=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V
M92!D;W=N`$UO=F4@;&5F=`!-;W9E(')I9VAT`$UO=F4@=7``36]Z86UB:7%U
M90!-=6QB97)R>2!!9&1R97-S($)O;VL`375L=&EP;&4@<&5R<V]N<R!W:71H
M(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@86QR96%D
M>2!E>&ES=`!->2!!8V-O=6YT`$UY($%D9')E<W,@0F]O:P!->2!0;W)T86P`
M37EA;FUA<@!.86UE`$YA;64@1F]R;6%T`$YA;6EB:6$`3F%U<G4`3F5P86P`
M3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GD`3F5T:&5R;&%N9',`3F5T:&5R
M;&%N9',@06YT:6QL97,`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE
M=R!#871E9V]R>0!.97<@0V]N=&%C=`!.97<@3&ES=`!.97<@6F5A;&%N9`!.
M97=S`$YE>'0`3F5X="!O<'1I;VYS`$YI8V%R86=U80!.:6-K;F%M90!.:6=E
M<@!.:6=E<FEA`$YI=64`3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S`$YO(&%D
M9')E<W,@8F]O:W,@9F]U;F0N`$YO(&-H86YG92X`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYT86-T<R!F
M;W5N9`!.;R!F:6QE('5P;&]A9&5D`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!V0V%R9"!D
M871A('=A<R!F;W5N9"X`3F]N90!.;W)F;VQK($ES;&%N9`!.;W)W87D`3F]T
M(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO
M=&EC90!.;W9E;6)E<@!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@:71E
M;7,@<&5R('!A9V4`3G5M8F5R(&]F(')O=W,`3TL`3V)J96-T(&YO="!F;W5N
M9`!/8W1O8F5R`$]F9FEC90!/;6%N`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@
M86QL;W=E9"X`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I;VYS
M(&9O<B`E<P!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A
M;FEZ:6YG`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`
M3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D
M($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M80!02%`@0V]D90!02%`@4VAE;&P`4%](4"!3:&5L;`!086MI<W1A;@!086QA
M=0!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087-S=V]R9`!0
M87-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`
M4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A
M<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO
M;B!D96YI960`4&5R;6ES<VEO;G,@9F]R`%!E<G-O;F%L($EN9F]R;6%T:6]N
M`%!E<G4`4&AI;&EP<&EN97,`4&AO;F4`4&EN92!!9&1R97-S($)O;VL`4&ET
M8V%I<FX`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!E
M;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&QI<W0Z`%!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('-E;&5C="!A(&1I<F5C
M=&]R>3H`4&]L86YD`%!O<G1U9V%L`%!R979I97<`4')I=F%T92!!9&1R97-S
M($)O;VL`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N
M`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!)
M;F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C
M97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U97)Y(&9A:6QE
M9#H@*"5S*2`E<P!1=6EC:R!396%R8V@`4E-!(%!U8FQI8R!+97D@*"5D(&)I
M="D`4F5A9"!F86EL960Z("@E<RD@)7,`4F5C;W)D<R!D:7-P;&%Y960Z`%)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6
M:65W.@!296UO=&4@4V5R=F5R<P!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!C;VQU;6X`4F5M;W9E(&9R;VT@=&AI<R!L:7-T`%)E;6]V92!P86ER`%)E
M;6]V92!T:&4`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<&QA8V4@
M97AI<W1I;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@
M/&(^5V%R;FEN9SH@5&AI<R!D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@
M8W5R<F5N="!A9&1R97-S(&)O;VLN/"]B/@!297%U97-T960@;V)J96-T(&YO
M="!F;W5N9"X`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-E="!T;R!$969A=6QT<P!297-U;'1S`%)E='5R;B!T;R!/<'1I
M;VYS`%)E=6YI;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)O;&4`4F]M
M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@
M<')O<&5R=&EE<P!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!%
M;F-R>7!T960@365S<V%G90!3+TU)344@4'5B;&EC($-E<G1I9FEC871E`%-!
M4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4U%,(%-H96QL
M`%-32`!35$%25%1,4R!F86EL960Z("@E<RD@)7,`4U]13"!3:&5L;`!386EN
M="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,`4V%M;V$`4V%N($UA<FEN;P!3875D:2!!<F%B:6$`4V%V
M90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V5A<F-H`%-E87)C
M:"!297-U;'1S`%-E87)C:"!F86EL960`4V5A<F-H(&9A:6QE9#H@)7,`4V5A
M<F-H:6YG($]P=&EO;G,`4V5A<F-H:6YG+BXN`%-E;&5C="!!9&1R97-S($)O
M;VL`4V5L96-T($9I;&5S`%-E;&5C="!,:7-T`%-E;&5C="!T:&4@861D<F5S
M<R!B;V]K('1O(&5X<&]R="!F<F]M.@!396QE8W0@=&AE(&%D9')E<W,@8F]O
M:R!T;R!I;7!O<G0@=&\Z`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA
M=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F;W)M
M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@=&AE(&9O<FUA="!U<V5D
M('1O(&1I<W!L87D@;F%M97,Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+@!396QE8W0@
M=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N
M`%-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RX`4V5L96-T
M('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z`%-E;&5C=&5D($-O;'5M;G,Z`%-E;&5C=&5D(&%D9')E<W,@8F]O
M:R`B)7,B+@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F5G86P`4V5P=&5M8F5R
M`%-E<FEA;"!.=6UB97(`4V5T`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO
M;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS
M+@!3971U<`!397EC:&5L;&5S`%-H87)E9"!$:7)E8W1O<GD`4VAO7W<@06QL
M`%-H;W)T(%-U;6UA<GD`4VAO=P!3:&]W($%L;`!3:&]W($-O;G1A8W1S`%-H
M;W<@3&ES=',`4VAO=R!?0V]N=&%C=',`4VAO=R!?3&ES=',`4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/P!3:65R<F$@3&5O;F4`4VEG;B!U<"!I9B!N;W0@<F5G
M:7-T97)E9`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O
M<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-O
M;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O<G0@1&ER96-T:6]N`%-O=7)C97,`
M4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T
M:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3<&%I
M;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P96-I9GD@=VAE<F4@
M>6]U('=A;G0@861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R+@!3
M<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W)I($QA;FMA`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=')E970@061D<F5S<P!3=6)J96-T
M`%-U8FUI=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<P!3=6-C97-S
M9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY('5P
M9&%T960@(B5S(@!3=61A;@!3=6YR:7-E+U-U;G-E=`!3=7)I;F%M90!3=V%Z
M:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y<FEA;B!!<F%B(%)E<'5B;&EC
M`%135@!486(@<V5P87)A=&5D('9A;'5E<P!486EW86X`5&%I=V%N+"!0<F]V
M:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!497AT($]N;'D`5&AA
M:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@861D
M<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S`%1H92!C;VYT86-T
M('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N`%1H92!I9&5N=&ET>2`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H
M92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A
M<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4:&5R92!A<F4@;F\@
M;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!W<FET96%B;&4@861D
M<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@879A:6QA8FQE(&%D9')E<W,@8F]O
M:W,@87)E(&-O;F9I9W5R960@=&\@86QL;W<@>6]U('1O(&%D9"!N97<@96YT
M<FEE<R!T;R!T:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES(&ES(&%N(&5R<F]R
M+"!P;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ
M("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!A
M9&1I;F<@=&AE(&YE=R!C;VYT86-T+B!#;VYT86-T('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@9F]R(&9U<G1H97(@:&5L<"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N`%1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R`E<R!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+@!4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<P!4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!O8FIE8W0N`%1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!S96QE8W0@3&ES=`!4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H:7,@;V)J96-T+@!4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,`5&AE<F4@=V5R
M92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4:&ES(&%D9')E<W,@8F]O:R!I
M<R!R96%D+6]N;'D`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!Z:7`@9FEL92X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F
M:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I;&4@9F]R;6%T
M(&ES(&YO="!S=7!P;W)T960N`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I
M;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4
M:&ES('!E<G-O;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R
M97-S(&)O;VL`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N`%1I;64`5&EM92!F;W)M870`5&ET;&4`5&\`5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`
M5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1R:6YI9&%D(&%N9"!4;V)A
M9V\`5')U92!O<B!F86QS90!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5V86QU`%523`!54DPZ`%5G86YD80!5
M:W)A:6YE`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`
M56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T
M871E<P!5;FMN;W=N`%5N;F%M960`56YS=7!P;W)T960@0V]N=&5N="U4>7!E
M+@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P;&]A9`!5<G5G=6%Y
M`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R;F%M90!5<V5R
M;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9A8V%T:6]N`%9A
M;G5A='4`5F5N97IU96QA`%9E<FES:6=N($1I<F5C=&]R>0!697)S:6]N`%9I
M970@3F%M`%9I97<@(B5S(@!6:65W("5S`%9I97<@0V]N=&%C=`!6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!T;R!D:7-P;&%Y
M(&)Y(&1E9F%U;'0Z`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)
M<VQA;F1S+"!5+E,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V5B`%=E
M8G-I=&4@55),`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M
M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM
M,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@@;V8@=&AE("5S(&UE
M;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ
M`%=O<FL@061D<F5S<P!7;W)K($-I='D`5V]R:R!#;W5N=')Y`%=O<FL@4&AO
M;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K(%-T871E+U!R;W9I;F-E`%=O<FL@
M4W1R965T($%D9')E<W,`65D`65E960!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&-R96%T:6YG(&$@9&ES=')I8G5T:6]N(&QI<W0N
M`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT
M86-T+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@
M;V)J96-T+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S
M<R!B;V]K+@!9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="X`66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;VYL>2!H879E('!E<FUI<W-I
M;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=7(@16UA:6P@061D<F5S<P!9
M;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!C
M=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&%D9')E<W-B;V]K(&ES
M(&YO="!B<F]W<V5A8FQE+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@
M9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!;4')O8FQE;2!297!O<G1=`%MN;R!V86QU95T`7T%D
M9`!?061M:6YI<W1R871I;VX`7T)R;W=S90!?0TQ)`%]$96QE=&4`7T1E;&5T
M92!2;W<`7T=R;W5P<P!?2&5L<`!?26UP;W)T+T5X<&]R=`!?3&]G(&EN`%],
M;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`
M7U)E;6]V92!,:6YK+BXN`%]296UO=F4@9G)O;2!T:&ES(&QI<W0`7U-E87)C
M:`!?4V5T=7``7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C;VYT86-T
M+G9C9@!C;VYT86-T<RYC<W8`8V]N=&%C=',N='-V`&9I;&4`;F%M90!N;W1E
M<&%D`'1O(%-E;&5C=&5D($%D9')E<W,@0F]O:P!U;FYA;65D`'9#87)D`%!R
M;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@:#,M,BXP+C,*4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#4M,3$M,C0@,C`Z-#<K,#$P,`I03RU2979I<VEO;BU$871E.B`R
M,#`U+3$Q+3(T(#(P.C0Y*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!+<GIY<WIT
M;V8@2V]Z;&]W<VMI(#QK;WII:S%`;S(N<&P^"DQA;F=U86=E+51E86TZ(%!O
M;&ES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP
M"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"5S("T@9V]T;W=Y
M(&1O('=Y:V]N86YI82!C>6ML:6-Z;GEC:"!O<&5R86-J:2!Z87IN86-Z;VYY
M8V@@<&]N:;]E:BX`("@E<R!D;FD@=&5M=2D`*&ML=6-Z(&1O<W3J<'4@)7,I
M`"`H=R!C:;%G=2`E<R!D;FDI`"`H9'IIMBD`("AJ=71R;RD`("AW8WIO<F%J
M*0`B)7,B(&YI92!J97-T('!R87=I9+-O=WEM('=Y8F]R96TN`"(E<R(@;FEE
M(&IE<W0@<VMO;F9I9W5R;W=A;GD@=R!R96IE<W1R>F4@2&]R9&4N`%5D8;-O
M('-IZB!D;V1AYB`B)7,B(&1O(&=R=7`N`%5D8;-O('-IZB!D;V1AYB`B)7,B
M(&1O('5P<F%W;FEE\2X`(B5S(B!N:64@>F]S=&&S('-K;W!I;W=A;GDL('!O
M;FEE=V&_(&IE<W0@;&ES=+$N`"(E<R(@;FEE('IO<W1ALR!U='=O<GIO;GDZ
M("5S+@`B)7,B(&YI92!Z;W-T8;,@<')Z96YI97-I;VYY+"!P;VYI97=AOR!J
M97-T(&QI<W2Q+@`B26UIZB!.87IW:7-K;R(@*&YP+B!*86X@2V]W86QS:VDI
M`").87IW:7-K;RP@26UIZB(@*&YP+B!+;W=A;'-K:2P@2F%N*0`E9"`E<R!I
M("5S`"5S("T@57=A9V$`061M:6YI<W1R86-J82`E<P`E<R!O9&-I<VL@<&%L
M8V$`)7,@:T(`)7,@+2!O<&5R86-J92!C>6ML:6-Z;F4@+2!P;W1W:65R9'IE
M;FEE`$MO;F9I9W5R86-J82`E<P!296IE<W1R86-J82`E<P`E<R!D;V1A;F4N
M`"5S(&IUOR!I<W1N:65J92X`4&QI:R`E<R!Z;W-T8;,@>F%I;7!O<G1O=V%N
M>0`E<R!J97-T('=Y;6%G86YY`"5S(&UI;G5T`"5S(&YI97IN86QE>FEO;GDN
M`"5S(&1O("5S('H@)7,`2W-IL;]K82!A9')E<V]W82`E<P!+86QE;F1A<GH@
M)7,`3F]T871N:6L@)7,`3&ES=&$@>F%D8?$@)7,`)7,Z("5S`"TM('=Y8FEE
M<GH@+2T`,3(M9V]D>FEN;GD@9F]R;6%T`#(T+6=O9'II;FYY(&9O<FUA=``R
M-"!G;V1Z+@`\4&]P<GIE9&YI`%=Y;6%G86YA(&IE<W0@;V)SLW5G82!I1G)A
M;65S*'"S>7=A:K%C>6-H(')A;65K*2!P<GIE>B!P<GIE9VRQ9&%R:^H`3F%S
M=+%P:;,@8K.Q9"!K<GET>6-Z;GD`4&]T<GIE8FYY(&IE<W0@:VQU8WH@<'5B
M;&EC>FYY(%!'4"!D;R!Z87-Z>69R;W=A;FEA('=I861O;6^V8VDN`%!O=')Z
M96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!01U`@9&\@<W!R87=D>F5N:6$@
M<&]D<&ES86YE:B!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@<[$@:VQU8WH@<'5B
M;&EC>FYY(%!'4"P@:VQU8WH@<')Y=V%T;GD@4$=0(&]R87H@:&%SLV\@9&\@
M;V1S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@<[$@:VQU8WH@
M<'5B;&EC>FYY(%!'4"P@:VQU8WH@<')Y=V%T;GD@4$=0(&]R87H@:&%SLV\@
M9&\@<&]D<&ES86YI82!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@<[$@:VQU8WH@
M<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T;GD@4R]-24U%(&]R87H@
M:&%SLV\@9&\@;V1S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@
M<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T;GD@4R]-
M24U%(&]R87H@:&%SLV\@9&\@<&]D<&ES86YI82!W:6%D;VUOMF-I+@!0;W1R
M>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4TU)344@9&\@>F%S>GEF<F]W
M86YI82!W:6%D;VUOMF-I+@!!32]030!/('1Y;2!E9'ET;W)Z90!/('!R;V=R
M86UI92XN+@!0;W=YOV5J('=Y<WIU:VEW87)K:0!(87.S;R!D;R!K;VYT80!+
M;VYT;R!Z86)L;VMO=V%N92X`2V]N=&$`6F%A=V%N<V]W86YE('-Z=6MA;FEE
M("A?=BD`1&]D86H`1&]D86H@='5T86HZ`$1O9&%J(&YO=[$@9W)U<.H`1&]D
M86H@;F]W92!U<')A=VYI96YI90!$;V1A:B!N;W=E9V\@=;]Y=&MO=VYI:V$Z
M`$1O9&%J(&MO;'5M;NH`1&]D86H@;F]W>6-H(&-ZLV]N:_-W`$1O9&%J('!A
M<NH`1&]D86H@;65N=2`E<R!D;R!P87-K82!-;WII;&QI`$1O9&%J(&1O`$1O
M9&%J(&1O(&MS:;&_:VD@861R97-O=V5J.@!$;V1A:B!D;R!M;VIE:B!K<VFQ
M>FMI(&%D<F5S;W=E:@!$;V1A:B!UOWET:V]W;FEK80!$;V1A;F\@(B5S(B!D
M;R!S>7-T96UU+B!-;[]E<WH@<VGJ('IA;&]G;W=AYBX`1&]D87=A;FEE('6_
M>71K;W=N:6OS=R!J97-T('=YLV%C>F]N92X`061R97,`2W-IL;]K82!A9')E
M<V]W80!,:7-T;W=A(&MS:;&_:V$@861R97-O=V$`5W!I<R!K<VFQOVMI(&%D
M<F5S;W=E:@!+<VFQOVMA(&%D<F5S;W=A('1Y;&MO(&1O(&]D8WIY='4N`$MS
M:;&_:V$@861R97-O=V$@=WEC>GES>F-Z;VYA+@!!9&UI;FES=')A8VIA`%)E
M:VQA;7D`6F%A=V%N<V]W86YE('-Z=6MA;FEE`$%F9V%N:7-T86X`06QB86YI
M80!!;&=I97)I80!!;&EA<P!7<WIY<W1K;P!7<WIY<V-Y('5W:65R>GET96QN
M:65N:2!UOWET:V]W;FEC>0!7<WIY<W1K:64@9W)U<'D`5W-Z>7-T:VEE('5P
M<F%W;FEE;FEA`%!O>G?S;"!N82!W:65L92!A9')E<_-W`$IUOR!I<W1N:65J
M90!*=;\@:7-T;FEE:F4`06QT97)N871Y=VYY(&QO9VEN($E-4U``06QT97)N
M871Y=VYY(&AA<[-O($E-4U``06QT97)N871Y=VYA(&YA>G=A('6_>71K;W=N
M:6MA($E-4U``06QT97)N871Y=VYY(&%D<F5S(&5M86EL`$%L=&5R;F%T>7=N
M>2!T96MS=#H`6F]S=&&S82!P;V1A;F$@;FEE<')A=VEDLV]W82!W87)T;[;F
M+@!!;F1O<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;6]W92!0<F]X>0!/9'!O
M=VEE9+P`06YT87)K='ED80!!<&QI:V%C:F$`07!L:6MA8VIA(&=O=&]W80!:
M871W:65R9+P`2W=I96-I9?$`5VEE;&MOMN8@87)C:&EW=6T`3F%Z=V$@87)C
M:&EW=6T`3F$@<&5W;F\@=7-U;K'F("5S/P!.82!P97=N;R!U<W5NL>8@=&5N
M('=Y8G)A;GD@=W!I<S\`07)G96YT>6YA`$%R;65N:6$`07)U8F$`5WIR87-T
M86JQ8V\`4&]P<F^V(&\@<&]T=VEE<F1Z96YI92!P<GIE9"!W>6MO;F%N:65M
M(&]P97)A8VII(&-Y:VQI8WIN>6-H/P!!=')Y8G5T>0!3:65R<&EE\0!!=7-T
M<F%L:6$`075S=')I80!!=71H7V-Y<G5S.B!.:64@>FYA;&5Z:6]N;R!W>6UA
M9V%N96=O(')O>G-Z97)Z96YI82!I;6%P+@!!=71H7V-Y<G5S.B!.:64@>FYA
M;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!I;6%P+@!!=71H7V9T
M<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@1E10
M+B!3:V]M<&EL=6H@4$A0('H@<&%R86UE=')E;2`M+65N86)L92`N`$%U=&A?
M:6UA<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@
M24U!4"X`075T:%]K<F(U.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O
M>G-Z97)Z96YI82!K<F(U+@!!=71H7VQD87`Z($YI92!Z;F%L97II;VYO('=Y
M;6%G86YE9V\@<F]Z<WIE<GIE;FEA($Q$05`N`$%U=&A?;&1A<#H@3FEE('5D
M8;-O('-IZB!U<W5NL>8@=;]Y=&MO=VYI:V$@)7,`075T:%]L9&%P.B!.:64@
M=61ALV\@<VGJ('5A:W1U86QN:>8@=;]Y=&MO=VYI:V$@)7,`075T:%]M8V%L
M.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!-0T%,
M+@!!=71H7W-M8F%U=&@Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z
M<WIE<GIE;FEA('-M8F%U=&@N`%5W:65R>GET96QN:65N:64@;FEE('!O=VEO
M9+-O('-IZ@!5=VEE<GIY=&5L;FEE;FEE(&YI92!P;W=I;V2S;R!S:>HN("5S
M`%5W:65R>GET96QN:65N:64@;V1R>G5C;VYE('!R>F5Z('-E<G=E<B!2041)
M55,N`%5W:65R>GET96QN:65N:64@9&\@<V5R=V5R82!&5%`@;FEE('!O=VEO
M9+-O('-IZBX`1&]S=.IP;F4@:V]L=6UU;GDZ`$1O<W3J<&YE('!O;&$Z`$%Z
M97)B96IDOV%N`%=Y;?-W:VD@0D]&2`!7<O/F(&1O("5S("A?8RD`5W+SYB!D
M;R`E<P!4LV\`2V]L;W(@=+-A`%JS92!H87.S;R!+97)B97)O<V$N`%JS82!N
M87IW82!UOWET:V]W;FEK82!+97)B97)O<V$`5WES<'D@0F%H86UA`$)A:')A
M:FX`0F&S='EC:VD@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-Z`%!O9'-T87=O
M=V4@<WIU:V%N:64@*%]C*0!0;V1S=&%W;W=E('-Z=6MA;FEE`$)I8;-O<G6V
M`$)E;&=I80!"96QI>F4`4&]N:;]E:B!W>7-Z=6MI=V%R:VD`0F5N:6X`0F5R
M;75D>0!":'5T86X`3FEE=61A;F4@0FEN9#H@*"5S*2`E<P!5<F]D>FEN>0!5
M<W1A=VEE;FEA(&)L;VMU`%1Y<"!B;&]K=0!";VQI=VEA`%IA:[-A9&MI`$)O
MMFYI82!I($AE<F-E9V]W:6YA`$]B80!"<F%Z>6QI80!"=;-G87)I80!+871E
M9V]R:6$@8FEZ;F5S;W=A`$--4P!#4D,`0U-6`%>S8;9C:7=OMF-I(&MO;?-R
M:VDN+BX@*%]C*0!7>6-Z>;;F('-Z=6MA;FEE("A?;"D`2V%L96YD87)Z`$MA
M;6)O9+]A`$MA;65R=6X`3FEE('5D8;-O('-IZB!Z<F5S971O=V'F(&AA<[-A
M(&%U=&]M871Y8WIN:64L('-K;VYT86MT=6H@<VGJ('H@861M:6YI<W1R871O
M<F5M+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@24U!
M4#H@)7,`2V%N861A`$%N=6QU:@!!;G5L=6H@<F%P;W)T(&\@<')O8FQE;6EE
M`$YI92!M;[]N82!S:V%S;W=AYB!P;&EK=2`B)7,B`$YI92!U9&&S;R!S:>H@
M>FYA;&6\YB!K871A;&]G=2!T>6UC>F%S;W=E9V\N`$YI92!M;[]N82!S:V%S
M;W=AYB!K871A;&]G=2`B)7,B`%=Y<W!Y(%II96QO;F5G;R!0<GIY;+%D:V$`
M2V%T96=O<FEE(&D@;WIN86-Z96YI80!496PN(&MO;2X`5[-AMF-I=V^V8VD@
M:V]M\W)K:0!7LV&V8VEW;[9C:2!K;VWS<FMI`%1E;"X@:V]M+@!#96QT>6-K
M:2`H25-/+3@X-3DM,30I`%)E<'5B;&EK82"F<F]D:V]W96H@069R>6MI`*9R
M;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,BD`4WIC>F5G\[-Y(&-E<G1Y
M9FEK871U`%>S8;9C:6-I96P@8V5R='EF:6MA='4`0WIA9`!:;6EE\0!:;6EE
M\2!I;6GJ+"!N87IW:7-K;R!I(&%D<F5S+"!K=/-R>2!I;FYI('=I9'JQ('<@
M5'=O:6-H(&QI<W1A8V@@96UA:6PN`%-P<F%W9+P@;&EN:RXN+@!:7V%Z;F%C
M>B!7<WIY<W1K;R].:6,`6F%Z;F%C>B!P;WIY8VKJ(&1L82!K=/-R96H@8VAC
M97-Z('=Y:V]N8>8@;W!E<F%C:NHN`$-H:6QE`$-H:6YY`%=Y8FEE<GH@9&]M
M>;9L;K$@:V%T86QO9R!D;&$@='=O:F5J(&MS:;&_:VD@861R97-O=V5J+"!L
M:7-T>2!K;VYT86MT\W<L('=Y<WIK:7=A;FEA+@!0;V1A:B!H87.S;P!0;V1A
M:B!N87IWZB!UOWET:V]W;FEK80!7>6)I97)Z(&MS:;&_:^H@861R97-O=[$`
M5WEB:65R>B!S<&]S\V(@=WFV=VEE=&QA;FEA(&1A=#H`5WEB:65R>B!K;VQU
M;6YY+"!K=/-R92!M86JQ(&)YYB!W>;9W:65T;&%N92!N82!L:;9C:64@:V]N
M=&%K=/-W+@!7>7-P82!";[]E9V\@3F%R;V1Z96YI80!7>6-Z>;;F('-Z=6MA
M;FEE`$ML:6MN:6H@8GD@:V]N='EN=6]W8>8`6F%M:VYI:B!O:VYO`%=Y<W!Y
M($MO:V]S;W=E("A+965L:6YG82D`4V-H;W=A:B!P87-E:P!+;VQU;6)I80!+
M;VQO<@!7>6)I97)Z(&MO;&]R`%=Y8O-R(&MO;&]R=0!/<&-J92!K;VQU;6X`
M5'ET=;-Y(&MO;'5M;@!0<GIE8VEN96L@;V1D>FEE;&$@=V%R=&^V8VD`4')Z
M96-I;F5K(&]D9'II96QA('=A<G1OMF-I("A-:6-R;W-O9G0@3W5T;&]O:RD`
M2V]M96YD80!0;W>S;VMA`$MO;65N=&%R>@!+;VUO<GD`1FER;6$`061R97,@
M9FER;7D`4W1W\W)Z('=I861O;6^VYB`H)7,I`$MO;7!U=&5R>0!787)U;FMI
M`%-K;VYF:6=U<G5J("5S`%!O='=I97)DO"!H87.S;P!+;VYG;P!$96UO:W)A
M='EC>FYA(%)E<'5B;&EK82!+;VYG;P!0;[.Q8WIE;FEE(&YI92!P;W=I;V2S
M;R!S:>HN`%!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-IZCH@`%!OL[%C>F5N
M:64@;FEE('!O=VEO9+-O('-IZCH@)7,`4&^SL6-Z96YI92!N:64@<&]W:6]D
MLV\@<VGJ`$]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E
M<G=E<F$N`$]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E
M<G=E<F$N(%!O=_-D.B`E<R`H)7,I`$*SL60@<&]D8WIA<R"SL6-Z96YI82!S
M:>H@>B!S97)W97)E;2!&5%`N`$MO;G1A:W0@=7-U;FGJ='D@>B!L:7-T>2X`
M2V]N=&%K='D@;F$@;&FV8VEE.B`E<P!+;VYT86MT>2!Z;W-T8;-Y('!O;7FV
M;&YI92!D;V1A;F4@9&\@5'=O:F5J(&MS:;&_:VD@861R97-O=V5J+@!:87=A
M<G1OMN8@(B5S(@!:87=A<G1OMN8@)7,`2V]N>6YU=6H`5WES<'D@0V]O:V$`
M2V]P:75J`%-K;W!I=6H@=WEB\W(`3FEE('5D8;-O('-IZB!Z87-Z>69R;W=A
MYB`H4$=0*2!W:6%D;VUOMF-I+@!.:64@=61ALV\@<VGJ('!O9'!I<V'F("A0
M1U`I('=I861O;6^V8VDN`$YI92!U9&&S;R!S:>H@>F%S>GEF<F]W8>8@*%,O
M34E-12D@=VEA9&]M;[9C:2X`3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4R]-
M24U%*2!W:6%D;VUOMF-I+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@3$1!4"X`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E
M<G=E<F5M("(E<R(@<&]P<GIE>B!&5%`Z("5S`$YI92!U9&&S;R!S:>H@;V1S
M>GEF<F]W8>8@9&%N>6-H(%!'4"X`3FEE('5D8;-O('-IZB!O9'-Z>69R;W=A
MYB!D86YY8V@@4R]-24U%+@!.:64@=61ALV\@<VGJ('5S=&%L:>8@861R97-U
M(&4M;6%I;"!O9&)I;W)C>2X`3FEE('5D8;-O('-IZB!U>GES:V'F('H@<V5R
M=V5R82!K;'5C>F$@<&)U;&EC>FYE9V\N`$YI92!U9&&S;R!S:>H@;W1W;W)Z
M>>8@(B5S(B!D;R!Z87!I<W4N`$YI92!M;[]N82!O='=O<GIYYB`E<RX`3FEE
M(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S`$YI
M92!M;[]N82!O='=O<GIYYB!K871A;&]G=2`B)7,B`$YI92!U9&&S;R!S:>H@
M<VMA<V]W8>8@<&QI:W4@(B5S(BX`3FEE('5D8;-O('-IZB!Z;F%L9;SF('!A
M<VMA($UO>FEL;&DN(%5P97=N:6H@<VGJ+""_92!J97-T(&]N(&]T=V%R='DN
M`$MR86H`4W1W\W)Z`%-T=_-R>B!L:6YK`%-T=_-R>B!N;W>Q`%5T=V]R>F]N
M>0!.=6UE<B!K87)T>2!K<F5D>71O=V5J`$-H;W)W86-J80!+=6)A`$]B96-N
M>2!C>F%S`%-P97)S;VYA;&EZ=6H@>F%D86YI82!U<G5C:&%M:6%N92!P<GIY
M(&QO9V]W86YI=2!D;R`E<RX`5WET;FEJ`$-Y<'(`4F5P=6)L:6MA($-Z96-H
M`$1$`$-O9'II96YN:64`1&%T80!?57-U\2!K;VQU;6[J`$=R=61Z:67Q`$1O
M;7FV;&YY(&MO;&]R`$1O;7FV;&YE('=YMG=I971L86YI90!$;VUYMFQN82!T
M;[]S86UOMN8`1&]M>;9L;F4@=7!R87=N:65N:6$`1&]M>;9L;GD@:V%T86QO
M9R!D;&$@='=O:F5J(&]S;V)I<W1E:B!K<VFQOVMI(&%D<F5S;W=E:BP@;&ES
M='D@:V]N=&%K=/-W(&D@=WES>G5K:7=A;FEA+@!$;VUYMFQN92!U<')A=VYI
M96YI80!$;VUYMFQN>2!S<&]S\V(@<V]R=&]W86YI83H`57-U\0!0;W1W:65R
M9'IE;FEE('5S=7=A;FEA`%5S=?$@1W)U<.H`57-U\2!U<')A=VYI96YI80!5
M<W7Q(&D@=WEC>GFVYB!W:6%D;VUOMF-I`%IM:67Q('!O=VEA9&%M:6%N:64@
M;R!U<W5W86YI=0!5<W7Q(&MO;?-R:^H`57-U\2!K;VQU;6[J`%5S=6YIZF-I
M92!N:65U9&%N93H@*"5S*2`E<P!3:V%S=6H@=7!R87=N:65N:6$@9&QA("(E
M<R(`4VMA<V]W8>8@=7!R87=N:65N:6$@9&QA("(E<R(@:2!W<WIY<W1K:64@
M<&]D+75P<F%W;FEE;FEA/P!5<W7Q('=I97)S>@!3:V%S=6H@=WEB<F%NL2!T
M;[]S86UOMN8`57-U\2!A:W1U86QNL2!K;VQU;6[J`%5S=?$@86MT=6%L;GD@
M=VEE<G-Z`%-K87-O=V'F('1O('5P<F%W;FEE;FEE(&D@=W-Z>7-T:VEE('!O
M9"UU<')A=VYI96YI83\`57-U;FGJ8VEE(&YI975D86YE`$1A;FEA`$1Z:6&S
M`$UA;&5JL6-O`$]P:7-Z('!R;V)L96T`4WIC>F5G\[-Y('IO<W1ALWD@>F%L
M;V=O=V%N92!D;&$@861M:6YI<W1R871O<F$N`$MA=&%L;V<`5WFV=VEE=&P@
M8WIA<R!W(&9O<FUA8VEE(#(T+6=O9'II;FYY;3\`3W!C:F4@=WFV=VEE=&QA
M;FEA`$2_:6)U=&D`3FEE(&MA<W5J`$)R86L@8F5Z<&^V<F5D;FEE9V\@9&]S
M=.IP=2!D;R!M86EN=&5N86YC92YP:'``0VAC97-Z('!O='=I97)D>F'F('5S
M=7=A;FEE('=P:7/S=S\`1&]M:6YI:V$@*%=S</-L;F]T82!$;VUI;FEK:2D`
M1&]M:6YI:V%N82`H4F5P=6)L:6MA($1O;6EN:6MA\7-K82D`IF-IL6=N:6H`
MIF-IL6=N:6H@)7,`IF-IL6=N:6H@=D-A<F0`3F%R:V]T>6MI`$4M;6%I;`!%
M:W=A9&]R`$5D>71U:@!%9'ET=6H@(B5S(@!5<W7Q($=R=7#J`%IM:67Q('5P
M<F%W;FEE;FEE`%IM:67Q('5P<F%W;FEE;FEA`%IM:67Q('5P<F%W;FEE;FEA
M(&1L82`E<P!%9'EC:F$@=W!I<W4Z("5S`%IM:67Q('5S=&%W:65N:6$@9&QA
M.@!:;6EE\2!U<')A=VYI96YI82!D;&$@)7,`16=I<'0`4V%L=V%D;W(`16UA
M:6P`061R97,@96UA:6P`061R97-Y(&5M86EL(&UU<WJQ(&1O('-I96)I92!P
M87-O=V'F+@!%;6]T:6MO;GD`4'5S=&$@=VEA9&]M;[;F+@!"<F%K(')E>G5L
M=&%T\W<N`%>SL6-Z>>8@;65N=2!K;VYT96MS=&]W92!P;V0@<')A=WEM('!R
M>GEC:7-K:65M(&UY<WIY/P!7<&ES(&1L82`E<R!Z86MT=6%L:7IO=V%N>2X`
M1W=I;F5A(%+S=VYI:V]W80!%<GET<F5A`$*SL60`0K.Q9"!P<GIY('IA<&ES
M:64@(B5S(BX`17-T;VYI80!%=&EO<&EA`$5U<F]P80!#;R!K8;]D92`Q-2!M
M:6YU=`!#;R!K8;]D92`R(&UI;G5T>0!#;R!K8;]D92`S,"!S96MU;F0`0V\@
M:V&_9&4@-2!M:6YU=`!#;R!K8;]D92!Z86QO9V]W86YI90!#;R!K8;]D92!P
M\[,@9V]D>FEN>0!#;R!K8;]DL2!M:6YU=.H`4')Z>6NS861O=V4@=V%R=&^V
M8VDZ`%=Y:V]N86H`4F]Z=VGQ`%)O>G=I\2!P87-E:P!%:W-P;W)T`$5K<W!O
M<G0@:W-IL;]K:2!A9')E<V]W96H`16MS<&]R='5J('1Y;&MO('IA>FYA8WIO
M;F4@:V]N=&%K='DN`$5K<W!O<G0@;F%S=.IP=6JQ8V5J(&MS:;&_:VD@861R
M97-O=V5J('IA:V_Q8WIO;GDN`$YI975D86YY(&1O<W3J<"!D;R!K<VFQOVMI
M(&%D<F5S;W=E:CH@)7,`3FEE=61A;F4@9&]D86YI92`E<R!D;R`E<SH@)7,`
M3FEE=61A;F4@<')Z96=LL61A;FEE(&QI<W1Y`$YI975D86YE('!R>F5G;+%D
M86YI92!K871A;&]G=0!.:65U9&%N82!Z;6EA;F$@;F%Z=WDZ("@E<RD@)7,[
M(%-T87)Y($1.(#T@)7,L($YO=WD@1$X@/2`E<RP@2V]R>F7Q(#T@)7,`0K.Q
M9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`N`$*SL60@
M<&]D8WIA<R!K;W!I;W=A;FEA('H@(B5S(BX`0K.Q9"!P;V1C>F%S(&MO<&EO
M=V%N:6$@9&\@(B5S(BX`3FEE=61A;GD@<WIU:V%N>2!O8FEE:W0@9&\@9&]D
M86YI83H@)7,`0K.Q9"!P;V1C>F%S('!R>F5N;W-Z96YI82!D;R`B)7,B+@!.
M:65U9&%N92!S>G5K86YI92!K871A;&]G=3H@)7,`1F%L:VQA;F1Y("A-86QW
M:6YY*0!7>7-P>2!/=V-Z90!"L[%D(&MR>71Y8WIN>3H@`$9A:W,`3'5T>0!&
M:62_:0!-96YE9+]E<B!P;&EK\W<`3F%Z=V$@<&QI:W4`5WEB\W(@<&QI:W4`
M5V=R>7=A;FEE('!L:6MU`%=G<GEW86YI92!P;&EK\W<@;FEE(&IE<W0@;V)S
MLW5G:7=A;F4N`$9I;'1R>0!:;F%J9+P`1FEN;&%N9&EA`$EM:>H`2F5D>F5N
M:64`6F%P;VUN:6&S9;8@:&%SLV$_`$9R86YC:F$`55),(%=O;&YY+UIA:NIT
M>0!'=6IA;F$@1G)A;F-U<VMA`%!O;&EN97IJ82!&<F%N8W5S:V$`1G)A;F-U
M<VMI92!497)Y=&]R:6$@4&^S=61N:6]W92!I($%N=&%R:W1Y8WIN90!/9`!'
M86)O;@!'86UB:6$`3FEE;6-Y`$=H86YA`$=I8G)A;'1A<@!/9_-L;F$@:W-I
ML;]K82!A9')E<V]W80!)9+P`5WES>G5K:7=A<FMA($=O;V=L90!'<F5C:F$`
M1W)E;FQA;F1I80!'<F5N861A`$=R=7!A`$=R=7!Y(&1Y<VMU<WEJ;F4`1W=A
M9&5L=7!A`$=U86T`1W=A=&5M86QA`$=U97)N<V5Y`$=W:6YE80!'=VEN96$@
M0FES<V%U`$=U:F%N80!(5$U,`$AA:71I`%=Y<W!Y($AE87)D(&D@36-$;VYA
M;&1A`%!O;6]C`%=Y<V]K:0!?4W1A<G0`5V%T>6MA;B`H4W1O;&EC82!!<&]S
M=&]L<VMA*0!0;V-ZL71E:P!!9')E<R!D;VUO=WD`36EA<W1O`$MR86H`5&5L
M969O;B!D;VTN`$MO9"!P;V-Z=&]W>0!7;VIE=_-DO'1W;P!!9')E<R!D;VUO
M=WD`2&]N9'5R87,`2&]N9TMO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%5D8;-O
M('-IZB!U<W5NL>8@)7,@(B5S(@!7ZF=R>0!)35-0`$ES;&%N9&EA`%1Y;&MO
M(&EK;VYY`$EK;VYY('H@=&5K<W1E;0!.87IW82!T;[]S86UOMF-I.@!'<F%F
M:6MA`$EM<&]R="!K<VFQOVMI(&%D<F5S;W=E:BP@:W)O:R`E9`!);7!O<G0O
M16MS<&]R="!K<VFQOVMI(&%D<F5S;W=E:@!);7!O<G1O=V%N92!P;VQE.B`E
M<P!);7!O<G1O=V%N92!P;VQA.@!);F1I90!);F1O;F5Z:F$`26YF;P!7:VQE
M:B!O8G)A>F5K`$YI97!O<')A=VYY($-O;G1E;G0M5'EP90!.:65P;W!R87=N
M>2!)1`!.:65P;W!R87=N82!K<VFQOVMA(&%D<F5S;W=A`%=Y<[-A;F4@;FEE
M<')A=VEDLV]W92!D86YE+@!.:65P<F%W:62S;W=Y(&%D<F5S(&1O8V5L;W=Y
M+@!.:65P;W!R87=N>2!E;6%I;`!.:65P;W!R87=N>2!W<&ES`$YI97!R87=I
M9+-O=WD@9F]R;6%T('!L:6MU`$YI97!O<')A=VYA(&1E9FEN:6-J82!K;'5C
M>F$N`$YI97!R87=I9+-O=WD@:VQU8WH@;&EC96YC:FDN`$YI97!O<')A=VYA
M(&YA>G=A`$YI97!O<')A=VYY(&]B:F5C=$ED`$ER86X`27)A:P!)<FQA;F1I
M80!)>G)A96P`5WED87=C80!7LV]C:'D`2F%M86IK80!3='EC>F7Q`$IA<&]N
M:6$`2F]R9&%N`$QI<&EE8P!#>F5R=VEE8P!+87IA8VAS=&%N`$ME;FEA`%1W
M;W)Z96YI92!K;'5C>F$`3V1C:7-K(&ML=6-Z80!$LW5G;[;F(&ML=6-Z80!4
M>7`@:VQU8WIA`$ML=6-Z(&IUOR!I<W1N:65J92!N82!P=6)L:6-Z;GEM('-E
M<G=E<GIE(&ML=6-Z>2X`1'II96-I`$MI<FEB871I`$MO<F5A\7-K82!297!U
M8FQI:V$@3'5D;W=O+41E;6]K<F%T>6-Z;F$`4F5P=6)L:6MA($MO<F5I`$MU
M=V5J=`!+:7)G:7-T86X`3V)SLW5G82!,1$%0(&IE<W0@=WEM86=A;F$L(&%L
M92!M;V1ULR!,1$%0(&IE<W0@;FEE9&]S=.IP;GD@;'5B(&YI97IALV%D;W=A
M;GDN`%=Y9VRQ9"`H7WDI`$KJ>GEK`$QA;W,`3W-T871N:6$@;6]D>69I:V%C
M:F$`3F%Z=VES:V\`3W-T871N:64@;&]G;W=A;FEE.B`E<P!/<W1A=&YI92!L
M;V=O=V%N:64Z("5S('H@)7,`3W-T871N:64@;&]G;W=A;FEE.B!N:6=D>0"C
M;W1W80!,97-O=&AO`$QI8F5R:6$`3&EB:6$`3&EE8VAT96YS=&5I;@!,:7-T
M80!7>;9W:65T;"!T96UA='D@<&]M;V-Y`$QI<W1O=V%N:64@=;]Y=&MO=VYI
M:_-W(&IE<W0@=WFSL6-Z;VYE+@!,:71W80"C861O=V%N:64N+BX`0WIA<R!L
M;VMA;&YY.B``57-T87=I96YI82!L;VMA;&YE(&D@8WIA<P!:86QO9W5J`%=Y
M;&]G=6H`6F%D86YI82!P<GIY(&QO9V]W86YI=0!,;V=O=V%N:64@;FEE('!O
M=VEO9+-O('-IZBP@<&]N:65W8;\@<&]D8;-EMB!N:65P<F%W:62S;W=E(&AA
M<[-O(&QU8B!N87IWZB!UOWET:V]W;FEK82X`3&]G;W=A;FEE(&YI92!P;W=I
M;V2S;R!S:>HN`$YI<VMI`$QU:W-E;6)U<F<`34T`34]41`!-4T<`36%K874`
M36%C961O;FEA`$UA9&%G87-K87(`4&]C>G1A`$UA;&%W:0!-86QE>FIA`$UA
M;&5D:7=Y`$UA;&D`36%L=&$`6F%R>K%D>F%J(&QI<W2Q(&MA=&5G;W)I:2P@
M:W3S<GEM:2!BZF1Z:65S>B!O>FYA8WIALR!P;WIY8VIE+"!I(&MO;&]R86UI
M('H@;FEM:2!Z=VFQ>F%N>6UI+@!-87)Z96,`36%R9VEN97,`5WES<'D@36%R
M<VAA;&QA`$UA<G1Y;FEK80!&<F%Z80!087-U:K%C92!P;VQA`$UA=7)E=&%N
M:6$`36%U<FET:75S`$UA:W-Y;6%L;F$@:6QOMN8@;F$@<W1R;V[J`$UA:@!-
M86IO='1A`%1R>6(@;65N=3H`4&^SL6-Z(&MO;?-R:VD`5VEA9&]M;[;F`$)L
M;VL@(DUE=&%R(B!N:64@:F5S="!D;W-TZG!N>2X`0FQO:R`B365T87(B(&YI
M92!J97-T(&1O<W3J<&YY+B!3>F-Z96?SLWD@>F1A<GIE;FEA('IO<W1ALWD@
M>F%L;V=O=V%N92!D;&$@861M:6YI<W1R871O<F$N`$UE:W-Y:P!4>7`@36EM
M90!-:6YI('=Y<WIU:VEW87)K80!"<F%K($1.('<@:V]N9FEG=7)A8VII(+QR
M\V2S82!,1$%0+@!496QE9F]N(&MO;2X`3W-T871N:6$@;6]D>69I:V%C:F$`
M6FUI9?$@;&EN:P!-;V1Y9FEK86-J82!N:65P;W=I862S82!S:>HZ("@E<RD@
M)7,`36^S9&%W:6$`4F5P=6)L:6MA($UOLV1A=VEI`$UO;F%K;P!-;VYG;VQI
M80!#;R!M:65S:;%C`$UO;G1S97)R870`1F%Z>2!K<VGJOWEC80!7:>IC96H@
M;FF_(#$@=W!I<R!Z;F%L97II;VYY`$UA<F]K;P!0<GIE;FEEM@!0<GIE<W7Q
M('<@9/.S`%!R>F5S=?$@=R!L97=O`%!R>F5S=?$@=R!P<F%W;P!0<GIE<W7Q
M('<@9_-RZ@!0<GIE;FEEMB!W(&3SLP!0<GIE;FEEMB!W(&QE=V\`4')Z96YI
M9;8@=R!P<F%W;P!0<GIE<W7Q('<@9_-RZ@!-;WIA;6)I:P!+<VFQ>FMA(&%D
M<F5S;W=A($UU;&)E<G)Y`$ES=&YI96IE('=I96QE(&]S\V(@>B!A9')E<V5M
M(%LE<UTL(&%L92"_861N82!Z(&YA>G>Q(%LE<UT`2V]N=&\`36]J82!K<VFQ
MOVMA(&%D<F5S;W=A`$WS:B!P;W)T86P`0FER;6$`3F%Z=V$`1F]R;6%T(&YA
M>G=Y`$YA;6EB:6$`3F%U<G4`3F5P86P`2V%T86QO9R!.971C96YT97(@365M
M8F5R`$AO;&%N9&EA`$%N='EL92!(;VQE;F1E<G-K:64`4VEEY@!.:6=D>0!.
M;W=A($MA;&5D;VYI80!.;W=A(&MA=&5G;W)I80!.;W=Y(&MO;G1A:W0`3F]W
M82!L:7-T80!.;W=A(%IE;&%N9&EA`%=I861O;6^V8VD`3F%S=.IP;F4`3F%S
M=.IP;F4@;W!C:F4`3FEK87)A9W5A`%!S975D;VYI;0!.:6=E<@!.:6=E<FEA
M`$YI=64`3FEE('IN86QE>FEO;GD@=W!I<R`E<R!D;&$@)7,`3FEE('IN86QE
M>FEO;F\@:W-IL;]K:2!A9')E<V]W96HN`$)E>B!Z;6EA;BX`0G)A:R!K;VYF
M:6=U<F%C:FD@9&QA("5S+@!.:64@>FYA;&5Z:6]N;R!K;VYT86MT\W<`3FEE
M('=G<F%N;R!P;&EK=0!.:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L
M;FEE;FEA($A45%`N`$YI92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN
M:65N:6$@24U!4"X`3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI
M96YI82!+97)B97)O<RX`3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E
M;&YI96YI82!,1$%0+@!.:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L
M;FEE;FEA($Q/1TE.+@!.:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L
M;FEE;FEA(%!!4U-71"X`3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E
M;&YI96YI82!334(N`$YI92!Z;F%L97II;VYO(&1A;GEC:"!V0V%R9"X`KV%D
M96X`3F]R9F]L:P!.;W)W96=I80!.:64@>F%I;7!L96UE;G1O=V%N;RX`3FEE
M=7-T87=I;VYE`$YI96]B<[-U9VEW86YE`$YO=&%T:VD`57=A9V$`3&ES=&]P
M860`3&EC>F)A(&MO;'5M;@!);&^VYB!W<&ES\W<@;F$@<W1R;V[J`$QI8WIB
M82!W:65R<WIY`$]+`$]B:F5K="!N:65Z;F%L97II;VYY`%!AO&1Z:65R;FEK
M`$)I=7)O`$]M86X`5'?S:B!J961E;B!A9')E<R!E+6UA:6P@:F5S="!D;WIW
M;VQO;GDN`$]T=_-R>B!W(&YO=WEM(&]K;FEE`$]P8VIE`$]P8VIE("5S`$]R
M9V%N:7IA8VIA`$IE9&YO<W1K82!O<F=A;FEZ86-Y:FYA`$]R9V%N:7IA=&]R
M`$EN;F4`26YN92!I;F9O<FUA8VIE`$EN;F4@;W!C:F4`26YN92!U<')A=VYI
M96YI80!5=VEE<GIY=&5L;FEE;FEE(%!!32!N:64@:F5S="!D;W-TZG!N92X`
M0WEF<F]W>2!P;V1P:7,@4$=0`%=I861O;6^VYB!Z87-Z>69R;W=A;F$@4$=0
M`$ML=6-Z('!U8FQI8WIN>2!01U``5VEA9&]M;[;F('IA<WIY9G)O=V%N82]P
M;V1P:7-A;F$@:VQU8WIE;2!01U``2V]D(%!(4`!0;W>S;VMA(%!(4`!0;W>S
M;VMA(%!?2%``4&%K:7-T86X`4&%L874`4&%N86UA`%!A<'5A+4YO=V$@1W=I
M;F5A`%!A<F%G=V%J`$AA<[-O`$AA<[-O(&YI97!R87=I9+-O=V4`2&%SLV\@
M>B!P;W1W:65R9'IE;FEE;0!(87.S;SH`2&%SLV\Z(`!(87.S;R!M=7-I('!A
M<V]W8>8N`%=K;&5J`%=K;&5J('IE('-C:&]W:V$`5WEK;VYA:B!C>6ML:6-Z
M;F4@;W!E<F%C:F4`5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4@<&]D8WIA
M<R!L;V=O=V%N:6$_`%5P<F%W;FEE;FEE`$)R86L@9&]S=.IP=0!"<F%K(&1O
M<W3J<'4`57!R87=N:65N:6$@9&QA`$EN9F]R;6%C:F4@;W-O8FES=&4`4&5R
M=0!&:6QI<&EN>0!496QE9F]N`$MS:;&_:V$@861R97-O=V$@4&EN90!0:71C
M86ER;@!.82!P97=N;R!U<W5NL>8@=&5N('=Y8G)A;GD@96QE;65N=#H`3F$@
M<&5W;F\@=7-U;K'F('=Y8G)A;GD@96QE;65N=#H`4')O<WKJ('!O9&'F('!O
M<')A=VYY(&%D<F5S($E0+@!0<F]S>NH@<&]D8>8@<&]P<F%W;GD@8WIA<RX`
M4&]D86H@;F%Z=^H@9&QA(&YO=V5J(&QI<W1Y.@!0<F]S>NH@;W!I<V'F('!R
M;V)L96TN`%!R;W-ZZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O
M`%=Y8FEE<GH@:V%T86QO9SH`4&]L<VMA`%!O<G1U9V%L:6$`4&]D9VRQ9`!0
M<GEW871N82!K<VFQOVMA(&%D<F5S;W=A`$ML=6-Z('!R>7=A=&YY`%!R;V)L
M96T`3W!I<R!P<F]B;&5M=0!+;'5C>B!P=6)L:6-Z;GD`06QG;W)Y=&T@:VQU
M8WIA('!U8FQI8WIN96=O`$EN9F]R;6%C:F4@;R!K;'5C>G4@<'5B;&EC>FYY
M;0!087)A(&ML=6-Z>2!O<V]B:7-T>6-H(&YI92!Z;W-T8;-A('=Y9V5N97)O
M=V%N82!P;VUYMFQN:64N`%!O<G1O<GEK;P!+871A<@!:87!Y=&%N:64`6F%P
M>71A;FEE(&YI92!P;W=I;V2S;R!S:>HZ("@E<RD@)7,`4WIY8FMI92!S>G5K
M86YI90!+;'5C>B!P=6)L:6-Z;GD@4E-!("@E9"!B:73S=RD`0WIY=&%N:64@
M;FEE('!O=VEO9+-O('-IZCH@*"5S*2`E<P!7>;9W:65T;&]N92!R96MO<F1Y
M.@!/9+9W:66_(&1Y;F%M:6-Z;F4@96QE;65N='D@;65N=3H`3V2V=VEEOR!W
M:61O:R!S97)W:7-U.@!:9&%L;F4@<V5R=V5R>0!5<W7Q`%5S=?$@8FQO:P!5
M<W7Q(&MO;'5M;NH`57-U\2!Z('1E:B!L:7-T>0!5<W7Q('!A<NH`57-U\0!5
M<W7Q('6_>71K;W=N:6MA`%ID86QN92!UOWET:V]W;FEK83H@)7,`6F%S=+%P
M:>8@;V)E8VZQ(&MS:;&_:^H@861R97-O=[$@:6UP;W)T;W=A;K$_(#QB/D]S
M=')Z9;]E;FEE.B!482!O<&5R86-J82!U<W5N:64@9&]T>6-H8WIA<V]W92!W
M<&ES>2!W(&]B96-N96H@:W-IL;]C92!A9')E<V]W96HN/"]B/@"O861A;GD@
M;V)J96MT(&YI97IN86QE>FEO;GDN`$MA<W5J`%=Y8WIYMN8@:&%SLV\`5WEC
M>GFVYB!4=V]J92!H87.S;P!0<GIY=W+S8R!D;VUYMFQN90!7>6YI:VD`4&]W
M<O-T(&1O(&]P8VII`%)E=6YI;VX`4F]Z8G5D;W=A;GD@961Y=&]R('1E:W-T
M=0!3=&%N;W=I<VMO`%)U;75N:6$`3V)R\^8@;R`Q.#`@<W1O<&YI`$]B<O/F
M('<@;&5W;P!/8G+SYB!W('!R87=O`%>S8;9C:7=OMF-I(')ZZF1U(%!R;W!E
M<G1I97,`4F]S:F$`4G5A;F1A`%=I861O;6^VYB!Z87-Z>69R;W=A;F$@4R]-
M24U%`%!U8FQI8WIN>2!C97)T>69I:V%T(%,O34E-10!5=VEE<GIY=&5L;FEE
M;FEE(%-!4TP@;FEE(&IE<W0@9&]S=.IP;F4N`%!O=VQO:V$@4U%,`%-32`!/
M<&5R86-J82!35$%25%1,4R!N:64@<&]W:6]DLV$@<VGJ.B`H)7,I("5S`%!O
M=[-O:V$@4U]13`"F=VGJ=&$@2&5L96YA`%-A:6YT($MI='1S(&D@3F5V:7,`
M4V%I;G0@3'5C:6$`4V%I;G0M4&EE<G)E(&D@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="!I($=R96YA9'EN>0!386UO80!386X@36%R:6YO`$%R86)I82!3875D
M>6IS:V$`6F%P:7-Z`%IA<&ES>B`B)7,B`%IA<&ES>B`E<P!:87!I<WH@;W!C
M:F4`4WIU:V%J`%=Y;FEK:2!W>7-Z=6MI=V%N:6$`5WES>G5K:7=A;FEE(&YI
M92!P;W=I;V2S;R!S:>H`5WES>G5K:7=A;FEE(&YI92!P;W=I;V2S;R!S:64Z
M("5S`$]P8VIE('=Y<WIU:VEW86YI80!3>G5K86YI92XN+@!7>6)I97)Z(&MS
M:;&_:^H@861R97-O=[$`5WEB:65R>B!P;&EK:0!7>6)I97)Z(&QI<W3J`%=Y
M8FEE<GH@:W-IL;]KZB!A9')E<V]WL2!D;R!E:W-P;W)T;W=A;FEA.@!7>6)I
M97)Z(&MS:;&_:^H@861R97-O=[$@9&\@>F%I;7!O<G1O=V%N:6$Z`%=Y8FEE
M<GH@>FYA:R!P;V1Z:6&S=2!D871Y.@!7>6)I97)Z(&9O<FUA="!D871Y.@!7
M>6)I97)Z(&9O<FUA="!E:W-P;W)T;W=A;FEA.@!7>6)I97)Z('!L:6L@9&\@
M>F%I;7!O<G1O=V%N:6$Z`%=Y8FEE<GH@9F]R;6%T('!L:6MU(+QR\V2S;W=E
M9V\Z`%=Y8FEE<GH@9F]R;6%T('6_>7=A;GD@9&\@=WFV=VEE=&QA;FEA(&YA
M>G<Z`%=Y8FEE<GH@=&^_<V%M;[;F(&1O('IM:6%N>3H`5WEB:65R>B!Z;F%K
M('!O9'II8;-U(&1A='DZ`%=Y8FEE<GH@9F]R;6%T(&-Z87-U.@!7>6)I97)Z
M(&1W82!P87-U:K%C92!P;VQA+@!7>6)I97)Z(&1O;7FV;&YY('-P;W/S8B!W
M>;9W:65T;&%N:6$N`%=Y8FEE<GH@<&]L82P@:W3S<F4@8NIDL2!W>;9W:65T
M;&%N92!N82!L:;9C:64@861R97-O=V5J+@!7>6)I97)Z(&9O<FUA="!W>;9W
M:65T;&%N>6-H(&YA>G<N`%=Y8FEE<GH@<V-H96UA="!K;VQO<O-W+@!7>6)I
M97)Z('1W\VH@<')E9F5R;W=A;GD@:NIZ>6LZ`%=Y8G)A;F4@:V]L=6UN>3H`
M5WEB<F%N82!K<VFQOVMA(&%D<F5S;W=A("(E<R(N`%=YMFQI:B!R87!O<G0@
M;R!P<F]B;&5M:64`4V5N96=A;`!7<GIE<VEE\0!.=6UE<B!S97)Y:FYY`%5S
M=&%W`%5S=&%W('ID86QN92!S97)W97)Y+"!D;R!K=/-R>6-H(&-H8V5S>B!M
M:67F(&1O<W3J<"!Z('-E<G=I<W4N`%5S=&%W('!R969E<F]W86YY(&KJ>GEK
M+"!S=')E9NH@8WIA<V]WL2!I(&]P8VIE(&1A='DN`%5S=&%W('5SLW5GZB!P
M;V-ZL71K;W>Q+"!S8VAE;6%T(&MO;&]R\W<L(&]DMG=I9;]A;FEE('-T<F]N
M>2!I(&EN;F4@;W!C:F4@=WFV=VEE=&QA;FEA`$MO;F9I9W5R86-J80!3>F5S
M>F5L90!59&]S=.IP;FEO;GD@:V%T86QO9P!0;VMAOR!?=W-Z>7-T:VEE`$MR
M\W1K:2!O<&ES`%!O:V&_`%!O:V&_('=S>GES=&MI90!0;VMAOR!K;VYT86MT
M>0!0;VMAOR!L:7-T>0!0;VMAOR!K;VYT86MT>2`H7V,I`%!O:V&_(%]L:7-T
M>0!0;VMA>GEW8>8@8WIA<R!O<W1A=&YI96=O('IA;&]G;W=A;FEA('!O(&QO
M9V]W86YI=3\`4&]K8;\@;65N=2`E<R!P;R!L97=E:C\`4VEE<G)A($QE;VYE
M`%IA<F5J97-T<G5J('-IZBP@:F6V;&D@:F5S>F-Z92!T96=O(&YI92!Z<F]B
M:;-EM@!0;V1P:7,`06QG;W)Y=&T@<&]D<&ES=0!3:6YG87!U<@!7:65L:V^V
MY@!0;VUI\2!O<&5R86-J92!C>6ML:6-Z;F4`4[-O=V%C:F$`4[-O=V5N:6$`
M5WES<'D@4V%L;VUO;F$`4V]M86QI80!3<&]S\V(@<V]R=&]W86YI80"L<O-D
MLV$`4&^S=61N:6]W82!!9G)Y:V$`4&^S=61N:6]W;V5U<F]P96IS:VD@*$E3
M3RTX.#4Y+3,I`$=E;W)G:6$@4&^S=61N:6]W80!(:7-Z<&%N:6$`4W!A;0!%
M9'EC:F$@>FYA:_-W('-P96-J86QN>6-H`$]K<F6V;"!G9'II92!M86JQ(&)Y
MYB!W>6YI:VD@>F%A=VYS;W=A;F5G;R!S>G5K86YI82X`4&]D>FEE;"!K;VWS
M<FOJ`%!O9'II96P@:V]L=6UNZ@!0;V1Z:65L('=I97)S>@!3<FD@3&%N:V$`
M5V]J97?S9+QT=V\@;'5B('-T86X`4W1A='5S`$%D<F5S(&1O;6]W>0!496UA
M=`!7>;9L:6H`4&]W;V1Z96YI90!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!S
M>7-T96UU+@!0;VUYMFQN:64@9&]D86YE("5S(&1O("5S`%5D8;-O('-IZB!U
M<W5NL>8@(B5S(B!Z('-Y<W1E;74N`%5D8;-O('-IZB!U<W5NL>8@(B5S(BX`
M561ALV\@<VGJ('5S=6ZQYB`B)7,B('H@<WES=&5M=2X`561ALV\@<VGJ('5A
M:W1U86QN:>8@(B5S(@!3=61A;@!7<V-H\V0O>F%C:/-D('.S;_%C80!3=7)I
M;F%M`%-U87II`%-Z=V5C:F$`4WIW86IC87)I80!3>7)I80!44U8`5&%B(&]D
M9'II96QA('=A<G1OMF-I`%1A:G=A;@!486IW86X`5&%DOWEK:7-T86X`5&%N
M>F%N:6$`6F%D86YI80!.=6UE<B!T96QE9F]N=0!4>6QK;R!T96MS=`!486IL
M86YD:6$`1'IIZFMU:F5M>2!Z82!K;W)Z>7-T86YI92!Z('-E<G=I<W4N`$MS
M:;&_:V$@861R97-O=V$@;FEE(&UO9[-A(&)YYB!W>6-Z>7-Z8WIO;F$Z("5S
M`$MO;G1A:W0L(&MT\W)E9V\@<WIU:V%S>B!N:64@:7-T;FEE:F4N`%1OOW-A
M;6^VYB`B)7,B('IO<W1ALV$@=7-U;FGJ=&$N`%-E<G=E<B`B)7,B('IO<W1A
MLR!U<W5N:>IT>2X`4V5R=V5R("(E<R(@>F]S=&&S('IA<&ES86YY+@!";&]K
M('=E871H97(N8V]M(&YI92!J97-T(&1O<W3J<&YY+@!"<F%K(&MS:;&_:VD@
M861R97-O=V5J('H@;6^_;&EW;[9C:;$@<')Z96=LL61A;FEA`$YI92!M82"_
M861N>6-H(&1O<W3J<&YY8V@@;W!C:FDN`$)R86L@:W-IL;]K:2!A9')E<V]W
M96H@>B!M;[]L:7=OMF-IL2!Z87!I<W5J+B"O861N82!Z(&1O<W3J<&YY8V@@
M:W-IL;]E:R!A9')E<V]W>6-H(&YI92!Z;W-T8;-A('-K;VYF:6=U<F]W86YA
M('H@;6^_;&EW;[9C:;$@9&]D87=A;FEA(&YO=WEC:"!W<&ES\W<N($IEMFQI
M('.Q9'II<WHL(+]E('1O(&IE<W0@8K.Q9"P@<VMO;G1A:W1U:B!S:>H@>B!A
M9&UI;FES=&%T;W)E;2!S>7-T96UU+@!7>7-TL7!ILR!P<F]B;&5M('!R>GD@
M9&]D87=A;FEU("(E<R(@9&\@<WES=&5M=3H@)7,`5WES=+%P:;,@<')O8FQE
M;2!P<GIY('5S=7=A;FEU(&1A;GEC:"!D;&$@=;]Y=&MO=VYI:V$@(B5S(B!W
M('-Y<W1E;6EE.B``5WES=+%P:;,@<')O8FQE;2!P<GIY('5S=7=A;FEU("(E
M<R(@>B!S>7-T96UU+@!7>7-TL7!ILR!P<F]B;&5M('!R>GD@=6%K='5A;&YI
M86YI=2`B)7,B.B`E<P!7>7-TL7!ILR!BL[%D('!O9&-Z87,@9&]D87=A;FEA
M(&YO=V5G;R!K;VYT86MT=2X@4VMO;G1A:W1U:B!S:>H@>B!T=V]I;2!A9&UI
M;FES=')A=&]R96T@<WES=&5M=2!W(&-E;'4@=7IY<VMA;FEA('!O;6]C>2X`
M5WES=+%P:;,@8K.Q9"!P;V1C>F%S('1W;W)Z96YI82!N;W=E:B!L:7-T>2X`
M5WES=+%P:;,@8K.Q9"!P;V1C>F%S('5S=7=A;FEA("5S('IE(+QR\V2S82!K
M<VFQOVMI(&%D<F5S;W=E:BX`5WES=+%P:;,@8K.Q9"!P;V1C>F%S('5S=7=A
M;FEA('1E9V\@:V]N=&%K='4Z("5S`%=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!K
M87-O=V%N:6$@=&5G;R!O8FIE:W1U+@!7>7-TL7!ILR!BLV%D('!O9&-Z87,@
M=WFV=VEE=&QA;FEA('=Y8G)A:FYE:B!L:7-T>0!7>7-TL7!ILR!BL[%D('!O
M9&-Z87,@=WFV=VEE=&QA;FEA('1E:B!C>NJV8VD@=VEA9&]M;[9C:0!7>7-T
ML7!ILR!BL[%D('!O9&-Z87,@:6UP;W)T;W=A;FEA(&1A;GEC:#H@)7,`5WES
M=+%P:;,@8K.Q9"!P;V-Z87,@:6UP;W)T;W=A;FEA(&1A;GEC:"!I0V%L96YD
M87(N`%=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!U<W5W86YI82!T96=O(&]B:F5K
M='4N`%=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!A:W1U86QI>F%C:FD@=&5G;R!W
M<&ES=3H@)7,`0G)A:R!A9')E<_-W(&1O(&5K<W!O<G1O=V%N:6$N`%1A(&MS
M:;&_:V$@861R97-O=V$@:F5S="!T>6QK;R!D;R!O9&-Z>71U`%!L:6L@;FEE
M('=Y9VRQ9&$@;F$@<&]P<F%W;F4@87)C:&EW=6T@4D%2+@!0;&EK(&YI92!W
M>6=LL61A(&YA('!O<')A=VYE(&%R8VAI=W5M(%I)4"X`5&\@<&]L92!J97-T
M('=Y;6%G86YE+@!4;R!P;VQE(&UU<VD@8GGF('!O<')A=VZQ(&QI8WIBL2X`
M5&5N(&9O<FUA="!P;&EK=2!J97-T(&YI96]B<[-U9VEW86YY+@!7:6%D;VUO
MMN8@>F]S=&&S82!N87!I<V%N82!W(&EN;F5J(&YIOR!T=V]J82!S=')O;FEE
M(&MO9&]W96H@*"5S*2X`5&$@;W-O8F$@:G6_(&UA('=P:7,@)7,@=R!K<VFQ
MOV-E(&%D<F5S;W=E:@!496X@<V5R=V5R(&YI92!P;W1R869I(')O>G!A:V]W
M>7=AYB!A<F-H:7?S=R!Z:7`@:2!G>FEP+@!#>F%S`$9O<FUA="!C>F%S=0!4
M>71ULP!$;P!!8GD@=WEB<F'F('=I96QO:W)O=&YE('!O;&$@<')Z>71R>GEM
M86H@<')Z>6-I<VL@0W1R;"`H4$,I(&QU8B!#;VUM86YD("A-86,I('!O9&-Z
M87,@:VQI:V%N:6$N`$1Z:;8`5&]G;P!4;VME;&%U`$IU=')O`%1O;F=A`%1R
M>6YI9&%D(&D@5&]B86=O`%!R87=D82!L=6(@9F&S<WH`5'5N97IJ80!4=7)C
M:F$`5'5R96-K:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U=F%L=0!5
M4DP`55),.@!59V%N9&$`56MR86EN80!"L[%D('!O9&-Z87,@>FUI86YY(&1O
M("5S+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,
M+@!"L[%D('!O9&-Z87,@<F]Z<&%K;W=Y=V%N:6$@9&%N>6-H+@!.:64@;6]G
MZB!W8WIY=&'F(&1E9FEN:6-J:2`E<RX`3FEE(&UOOVYA('!R>F5TLW5M86-Z
M>>8@=&5G;R!D;VMU;65N='4@5V]R9"UA`$-O9FYI:B!Z;6EA;GD`6FIE9&YO
M8WIO;F4@16UI<F%T>2!!<F%B<VMI90!7:65L:V$@0G)Y=&%N:6$`55-!`$YI
M97IN86YE`$)E>B!N87IW>0!.:65O8G.S=6=I=V%N>2!#;VYT96YT+51Y<&4N
M`$YI96]B<[-U9VEW86YE(')O>G-Z97)Z96YI90!586MT=6%L;FEJ`%IALV%D
M=6H`57)U9W=A:@!/<&-J92!UOWET:V]W;FEK80!296IE<W1R86-J82!UOWET
M:V]W;FEK80!.87IW82!UOWET:V]W;FEK80!5OWET:V]W;FEK(&\@;F%Z=VEE
M("(E<R(@:G6_(&ES=&YI96IE+@!.87IW82!UOWET:V]W;FEK83H`3F%Z=V$@
M=;]Y=&MO=VYI:V$Z(`!5OWET:V]W;FEC>2!W('-Y<W1E;6EE.@!5>F)E:VES
M=&%N`%=A:V%C:F4`5F%N=6%T=0!796YE>G5E;&$`2V%T86QO9R!697)I<VEG
M;@!797)S:F$`5VEE=&YA;0!7:61O:R`B)7,B`%=I9&]K("5S`%IO8F%C>B!K
M;VYT86MT`%!O:V&_('-T<F]NZB!75U<`4&]K8;\@:F%K;R`E<P!$;VUYMFQN
M:64@=WFV=VEE=&QA:CH`0G)Y='EJ<VMI92!7>7-P>2!$>FEE=VEC>F4`5WES
M<'D@1'II97=I8WIE(%-T86[S=R!::F5D;F]C>F]N>6-H`%=A;&QI<R!I($9U
M='5N80!/<W1R>F6_96YI90!75U<`55),('-T<F]N>0!#;R!T>61Z:67Q`%=I
M=&%M>0!7:71A;7D@=R`E<P!7:71A;7DL("5S`%IA8VAO9&YI("A)4T\M.#@U
M.2TQ*0!:86-H;V1N:2`H25-/+3@X-3DM,34I`%-A:&%R82!:86-H;V1N:6$`
M2F%KL2!A<&QI:V%C:NH@;6$@)7,@=WFV=VEE=&QAYB!P;R!Z86QO9V]W86YI
M=2!S:>H_`$IA:VEE('=T>6-Z:VD@86MT>7=O=V'F('<@4F]Z8G5D;W=A;GEM
M(&5D>71O<GIE('1E:W-T=2X`4WIE<F]K;[;F(&QE=V5G;R!M96YU("5S("AZ
M;6EA;F$@>F%C>FYI92!O8F]W:;%Z>7=AYB!P<GIY(&YA<W3J<&YY;2!L;V=O
M=V%N:74I.@!!9')E<R!D;R!P<F%C>0!-:6%S=&\@*'!R86-A*0!+<F%J("AP
M<F%C82D`5&5L969O;B`H<')A8V$I`$MO9"!P;V-Z=&]W>2`H<')A8V$I`%=O
M:F5W\V2\='=O("AP<F%C82D`061R97,@<')A8WD`4E(`4E)24@!#;R!R;VL`
M2F5M96X`5&%K`%1A:RP@>F=A9'IA;2!S:>H`4W1W;W)Z>;-EMB!L:7-TZB!D
M>7-T<GEB=6-Y:FZQ+@!.:64@;6%S>B!P<F%W(&%B>2!Z;V)A8WIYYB!T96X@
M:V]N=&%K="X`3FEE(&UA<WH@<')A=R!A8GD@>F]B86-Z>>8@=&5N(&]B:F5K
M="X`5WEL;V=O=V&S9;8@<VGJ+@!-=7-I<WH@;W!I<V'F('!R;V)L96T@>F%N
M:6T@9V\@=WFV;&5S>BX`375S:7-Z('=Y8G)AYB!D;V-E;&]WL2!K<VFQOVOJ
M(&%D<F5S;W>Q+@!-=7-I<WH@=WEB<F'F(&1O8V5L;W>Q(&QI<W3J+@!-=7-I
M<WH@=V)Y<F'F(&YA:G!I97)W('!R>GEN86IM;FEE:B!J961E;B!W<&ES+@!-
M=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z('5S
M=6ZQYBX`375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H
M8V5S>B!D;V1AYBX`36%S>B!U<')A=VYI96YI82!T>6QK;R!D;R!P;V1G;+%D
M=2!T96=O(&MO;G1A:W1U+@!4=_-J(&%D<F5S(&4M;6%I;`!4=_-J(&%D<F5S
M($]D.@!4=V]J92!I;F9O<FUA8VIE`%1W\VH@861R97,@:6YT97)N971O=WD@
M<VGJ('IM:65N:;,@;V0@<&]C>K%T:W4@<V5S:FD@)7,N(%<@>G=IL7IK=2!Z
M(&)E>G!I96-Z9?%S='=E;2!4=V]J96=O(&MO;G1A(&UU<VES>B!Z86QO9V]W
M8>8@<VGJ('!O;F]W;FEE+@!4=V]J92!I;6GJ`%1E;B!S>7-T96T@875T96YT
M>6MA8VII(&YI92!O8G.S=6=U:F4@9&]D87=A;FEA('6_>71K;W=N:6OS=RP@
M;'5B('1A(&]P8VIA('IO<W1ALV$@=WFSL6-Z;VYA+@!496X@<WES=&5M(&%U
M=&5N='EK86-J:2!N:64@;V)SLW5G=6IE(&QI<W1O=V%N:6$@=;]Y=&MO=VYI
M:_-W+"!L=6(@=&$@;W!C:F$@>F]S=&&S82!W>;.Q8WIO;F$N`%1W;VIA(&]B
M96-N82!S=')E9F$@8WIA<V]W83H`5'=O:F$@9&]M>;9L;F$@:W-IL;]K82!A
M9')E<V]W82!N:64@:F5S="!P<GIE9VRQ9&%L;F$N`$1O;7FV;&YA('1OOW-A
M;6^VYCH`5'=O:F4@<&6S;F4@:6UIZB!I(&YA>G=I<VMO.@!4=V]I;2!N;W=Y
M;2!H87.S96T@=R`E<R!J97-T.B`E<P!4=V]J92!U<W1A=VEE;FEA('IO<W1A
MLWD@=6%K='5A;&YI;VYE(&YA(&-Z87,@=')W86YI82!T96H@<V5S:FDN`%1W
M;VIE('5S=&%W:65N:6$@>F]S=&&S>2!U86MT=6%L;FEO;F4N`%1W;VIE('ID
M86QN92!S97)W97)Y.@!*=6=O<[-A=VEA`%IA:7(`6F%M8FEA`%II;6)A8G=E
M`%M287!O<G0@;R!P<F]B;&5M:65=`%MB<F%K('=A<G1OMF-I70!$;V1?86H`
M7T%D;6EN:7-T<F%C:F$`4')Z96=LL61A:B`H7V(I`%]#3$D`57-U\2`H7V0I
M`%]5<W7Q('=I97)S>@!?1W)U<'D`7U!O;6]C`%]);7!O<G0O16MS<&]R=`!?
M6F%L;V=U:@!?5WEL;V=U:@!:;6EE\2!L:6YK+BXN`%]/<&-J90!?57!R87=N
M:65N:6$`57-U\2!L:6YK+BXN`%5S=?$@>B!T96H@;&ES='D@*%]R*0!?4WIU
M:V%J`%]+;VYF:6=U<F%C:F$`7U6_>71K;W=N:6-Y`&MS:;&_:V$@861R97-O
M=V$`:V%L96YD87)Z`&MO;G1A:W0N=F-F`&MO;G1A:W1Y+F-S=@!K;VYT86MT
M>2YT<W8`<&QI:P!.87IW:7-K;P!N;W1A=&YI:P!W>6)R86YA(&MS:;&_:V$@
M861R97-O=V$`8F5Z(&YA>G=Y`'9#87)D````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O='5R8F$O;&]C86QE+W!T7T)2+P``````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C`P,3``(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O<'1?0E(O3$-?3453
M4T%'15,O````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8R-S4U`#`R,34W-0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO
M8V%L92]P=%]"4B],0U]-15-304=%4R]T=7)B82YM;P``````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`T-S`Q-S4`,3`T,3<S-C(W-34`,#(S,C8R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-X2!)4`````C0@``!P```"$
M1```;PL``.R(````````J+8```X```"IM@``#P```+BV```-````R+8```@`
M``#6M@``"P```-^V```,````Z[8``!D```#XM@``&0```!*W```$````++<`
M`"D````QMP``&````%NW```;````=+<``"T```"0MP``'0```+ZW```D````
MW+<``"D````!N```*0```"NX```9````5;@``"@```!ON```)````)BX```E
M````O;@``"8```#CN```#`````JY```D````%[D```\````\N0``"P```$RY
M```.````6+D```4```!GN0``*````&VY```(````EKD```H```"?N0``%0``
M`*JY```)````P+D``!(```#*N0``"P```-VY```=````Z;D``(4````'N@``
M#@```(VZ```*````G+H```T```"GN@``#@```+6Z```1````Q+H```T```#6
MN@``#````.2Z```-````\;H```8```#_N@``E`````:[```*````F[L```\`
M``"FNP``&````+:[```,````S[L```X```#<NP``#@```.N[```(````^KL`
M``D````#O```*P````V\```N````.;P``!H```!HO```,@```(.\```X````
MMKP``%0```#OO```40```$2]``!:````EKT``%<```#QO0``-````$F^```)
M````?KX```T```"(O@``!P```):^```*````GKX```\```"IO@``!0```+F^
M```&````O[X``!$```#&O@``"````-B^```1````X;X```D```#SO@``"0``
M`/V^```E````![\``"`````MOP``$P```$Z_```3````8K\``!````!VOP``
M#P```(>_```*````E[\```,```"BOP``#P```*:_```4````MK\```D```#+
MOP``#0```-6_```2````X[\``!D```#VOP``'@```!#````/````+\```!``
M```_P```(0```%#````*````<L````@```!]P```#P```(;````(````EL``
M`"0```"?P```!@```,3````4````R\```!8```#@P```"````/?```!.````
M`,$``"T```!/P0``(0```'W!```9````G\$```<```"YP0``#````,'!```4
M````SL$```T```#CP0``$@```/'!```A````!,(``!<````FP@``*0```#["
M```L````:,(```X```"5P@```P```*3"```/````J,(```L```"XP@``!P``
M`,3"```'````S,(```4```#4P@``!0```-K"```*````X,(```,```#KP@``
M%P```._"```*````!\,```\````2PP``#@```"+#```8````,<,``",```!*
MPP``#@```&[#```.````?<,``!0```",PP``%P```*'#```7````N<,``!<`
M``#1PP``$P```.G#```/````_<,```X````-Q```'P```!S$```=````/,0`
M``<```!:Q```!@```&+$```(````:<0```\```!RQ```!@```(+$```*````
MB<0``!,```"4Q```"P```*C$```0````M,0``!4```#%Q```%0```-O$```'
M````\<0``!````#YQ```!0````K%```5````$,4``!$````FQ0``#````#C%
M```H````1<4``#H```!NQ0``.P```*G%```X````Y<4```D````>Q@``!P``
M`"C&```4````,,8```,```!%Q@``!0```$G&```)````3\8``!````!9Q@``
M"0```&K&```3````=,8``#D```"(Q@``$@```,+&```G````U<8``"P```#]
MQ@``*@```"K'```E````5<<```H```![QP``!@```(;'```)````C<<```<`
M``"7QP``+P```)_'```W````S\<``"X````'R```50```#;(```M````C,@`
M`"T```"ZR```/0```.C(```_````)LD``"T```!FR0``0````)3)```C````
MU<D``",```#YR0``0````!W*```M````7LH``#,```",R@``)0```,#*```5
M````YLH``!D```#\R@``*0```!;+```D````0,L``"@```!ERP``$0```([+
M```*````H,L```P```"KRP``"@```+C+```0````P\L``!8```#4RP``%@``
M`.O+```'`````LP```<````*S```%````!+,```*````)\P```@````RS```
M)P```#O,```(````8\P```P```!LS```!P```'G,```'````@<P```8```")
MS```$0```)#,```%````HLP```<```"HS```!@```+#,```4````M\P```@`
M``#,S```*0```-7,```.````_\P```H````.S0``!````!G-```'````'LT`
M``D````FS0``!@```##-```1````-\T```<```!)S0``%@```%'-```$````
M:,T```@```!MS0``!@```';-```-````?<T```8```"+S0``'@```)+-```&
M````L<T``!$```"XS0``"````,K-```-````T\T```P```#AS0``!P```.[-
M```1````]LT```,````(S@```P````S.```7````$,X```,````HS@``$P``
M`"S.```=````0,X```@```!>S@``!````&?.```(````;,X```@```!US@``
M00```'[.```:````P,X``!P```#;S@``*P```/C.```@````),\``!4```!%
MSP``!@```%O/```&````8L\``!4```!ISP``&````'_/```B````F,\``"X`
M``"[SP``'0```.K/```A````"-```%0````JT```*0```'_0```*````J=``
M``<```"TT```!P```+S0```5````Q-````X```#:T```"@```.G0```/````
M]-````T````$T0``#P```!+1```-````(M$```D````PT0``%````#K1```&
M````3]$``!@```!6T0``'0```&_1```3````C=$``!$```"AT0``%````+/1
M```$````R-$```8```#-T0``%````-31``!4````Z=$``&0````^T@``!```
M`*/2```.````J-(```\```"WT@``!0```,?2```%````S=(``!L```#3T@``
M&@```._2```3````"M,```T````>TP``$0```"S3```1````/M,``!8```!0
MTP``%P```&?3```<````?],``"H```"<TP``.0```,?3```B`````=0``#(`
M```DU```$````%?4```A````:-0```4```"*U```$P```)#4```+````I-0`
M`!(```"PU```"@```,/4```/````SM0```T```#>U```$0```.S4```3````
M_M0```P````2U0``!@```!_5```,````)M4```8````SU0``%P```#K5```0
M````4M4``!$```!CU0``"````'75```%````?M4```P```"$U0``$````)'5
M```%````HM4```X```"HU0``#0```+?5```C````Q=4```8```#IU0``%@``
M`/#5```J````!]8```<````RU@``#0```#K6```'````2-8```L```!0U@``
M!P```%S6```'````9-8```\```!LU@``"0```'S6```)````AM8```H```"0
MU@``&0```)O6```]````M=8``!T```#SU@``#````!'7```0````'M<```4`
M```OUP``)0```#77```2````6]<``!,```!NUP``%0```(+7```2````F-<`
M`"L```"KUP``.P```-?7```@````$]@```X````TV```"````$/8```4````
M3-@``#8```!AV```(0```)C8```0````NM@```@```#+V```#````-38```&
M````X=@```0```#HV```#P```.W8```.````_=@```<````,V0``"@```!39
M```-````']D``!\````MV0``'````$W9```A````:MD``!X```",V0``&0``
M`*O9```>````Q=D``!L```#DV0``(0````#:```N````(MH``"8```!1V@``
M'````'C:```>````E=H``!P```"TV@``)@```-':```K````^-H``#,````D
MVP``)@```%C;```K````?]L``#@```"KVP``'0```.3;```5`````MP``"\`
M```8W```(````$C<```2````:=P``"D```!\W```'@```*;<```@````Q=P`
M`!(```#FW```H@```/G<```6````G-T``",```"SW0``*````-?=```I````
M`-X``"@````JW@``'P```%/>```5````<]X``"````")W@``)0```*K>```H
M````T-X``"T```#YW@``,````"??``"2````6-\``"$```#KWP``%@````W@
M```<````).```"8```!!X```*@```&C@``!!````D^```$0```#5X```#```
M`!KA```'````)^$```<````OX0``!@```#?A```3````/N$```T```!2X0``
M'0```&#A```0````?N$``!(```"/X0``!P```*+A```3````JN$``!(```"^
MX0``!P```-'A```$````V>$``!````#>X0``$````._A```,`````.(```X`
M```-X@``#0```!SB```/````*N(``!,````ZX@``#0```$[B```H````7.(`
M``,```"%X@``#0```(GB```&````E^(``!$```">X@``%P```+#B```;````
MR.(```X```#DX@```@```//B``!)````]N(```4```!`XP``$````$;C```/
M````5^,```0```!GXP``#0```&SC```.````>N,```,```")XP``#@```(WC
M```(````G.,```\```"EXP``#P```+7C```'````Q>,```T```#-XP``$```
M`-OC```-````[.,``!H```#ZXP``"P```!7D```&````(>0``!,````HY```
M"P```#SD```3````2.0```P```!<Y```"@```&GD```1````=.0``!D```"&
MY```%P```*#D```+````N.0```T```#$Y```(@```-+D```6````]>0``!L`
M```,Y0``-````"CE```*````7>4``!@```!HY0``&0```('E```6````F^4`
M`"(```"RY0``(P```-7E```/````^>4```T````)Y@``!P```!?F```*````
M'^8```H````JY@``%````#7F```+````2N8``"(```!6Y@``+P```'GF```+
M````J>8```D```"UY@``&0```+_F```+````V>8``!<```#EY@``%P```/WF
M```)````%><```<````?YP``%@```"?G```/````/N<``!D```!.YP``%@``
M`&CG```.````?^<``!@```".YP``"````*?G```-````L.<``"8```"^YP``
M*````.7G``!#````#N@```@```!2Z```$@```%OH```?````;N@```@```".
MZ```"P```)?H```O````H^@```X```#3Z```#@```.+H```%````\>@```8`
M``#WZ```10```/[H```#````1.D```<```!(Z0``!````%#I```)````5>D`
M`!(```!?Z0``"@```'+I```*````?>D```\```"(Z0``$````)CI```7````
MJ>D``!$```#!Z0``$0```-/I```9````Y>D``!<```#_Z0``"0```!?J```%
M````(>H```L````GZ@``"@```#/J```"````/NH```4```!!Z@``#0```$?J
M```;````5>H``!<```!QZ@``%````(GJ```)````GNH```X```"HZ@``#0``
M`+?J```2````Q>H``#@```#8Z@``(````!'K```(````,NL```X````[ZP``
M>P```$KK```8````QNL``!@```#?ZP``/0```/CK```5````-NP``!$```!,
M[```!P```%[L```%````9NP``",```!L[```,P```)#L```8````Q.P``!T`
M``#=[```+@```/OL```>````*NT``!L```!)[0``&0```&7M```G````?^T`
M`#<```"G[0``)````-_M```;````!.X``!D````@[@``$P```#KN```'````
M3NX```@```!6[@``!@```%_N```&````9NX``!````!M[@``#P```'[N```0
M````CNX```\```"?[@``"P```*_N```/````N^X```P```#+[@``#P```-CN
M```'````Z.X```8```#P[@``#@```/?N```,````!N\``"@````3[P``#P``
M`#SO```(````3.\```8```!5[P``$P```%SO```B````<.\``"T```"3[P``
M"````,'O```3````RN\``!X```#>[P``)0```/WO```:````(_```!4````^
M\```'@```%3P``!#````<_```"$```"W\```(````-GP```9````^O```!<`
M```4\0``)0```"SQ```E````4O$``!<```!X\0``%@```)#Q```A````I_$`
M`"(```#)\0``!````.SQ```;````\?$```T````-\@``#````!OR```#````
M*/(```4````L\@``"````#+R```*````._(```P```!&\@``"P```%/R```0
M````7_(```P```!P\@``#@```'WR```+````C/(```0```"8\@``!````)WR
M```3````HO(``!0```"V\@``#````,OR```)````V/(```X```#B\@``"P``
M`/'R```;````_?(```4````9\P``!P```!_S```$````)_,```8````L\P``
M!P```#/S```*````._,```H```!&\P``#0```%'S```)````7_,```0```!I
M\P``!0```&[S```#````=/,``!@```!X\P``"@```)'S```$````G/,``"8`
M``"A\P``#@```,CS``!\````U_,``!4```!4]```!0```&KT```'````</0`
M``P```!X]```"````(7T```*````CO0```8```"9]```"````*#T```"````
MJ?0```8```"L]```!@```+/T```4````NO0```P```#/]```#0```-ST```0
M````ZO0``!L```#[]```!````!?U```)````'/4``!`````F]0``"0```#?U
M```)````0?4```4```!+]0``&@```%'U```(````;/4```8```!U]0``&0``
M`'SU```.````EO4```<```"E]0``!P```*WU```%````M?4```D```"[]0``
M"@```,7U```3````T/4```X```#D]0```@```//U```&````]O4```L```#]
M]0``#0````GV```)````%_8```8````A]@``$@```"CV```)````._8```<`
M``!%]@``!0```$WV```4````4_8``!T```!H]@``0@```(;V```E````R?8`
M`"4```#O]@``!@```!7W```*````'/<```0````G]P``"0```"SW```(````
M-O<``!$````_]P``"0```%'W```&````6_<```T```!B]P``!@```'#W```$
M````=_<``#D```!\]P``/0```+;W```Z````]/<``!X````O^```!0```$[X
M```.````5/@```0```!C^```!@```&CX```'````;_@``"$```!W^```#0``
M`)GX```5````I_@```8```"]^```!````,3X```1````R?@```8```#;^```
M"@```.+X```B````[?@```0````0^0``!0```!7Y```=````&_D```0````Y
M^0``#````#[Y```)````2_D```P```!5^0``#@```&+Y```*````<?D``!``
M``!\^0``$P```(WY```3````H?D```@```"U^0``"0```+[Y```%````R/D`
M`#H```#.^0``,`````GZ```U````.OH``"D```!P^@``1P```)KZ```X````
MXOH``"D````;^P``/P```$7[```N````A?L``"T```"T^P``'P```.+[```/
M`````OP``!(````2_```"P```"7\```F````,?P``"D```!8_```)````(+\
M```F````I_P```@```#._```"@```-?\```)````XOP```<```#L_```(```
M`/3\```@````%?T``"8````V_0``!````%W]```@````8OT```H```"#_0``
M&0```([]```I````J/T``!8```#2_0``$@```.G]```'````_/T```H````$
M_@``#`````_^```/````'/X``!`````L_@``0````#W^``!P````?OX``&8`
M``#O_@``#@```%;_```)````9?\```H```!O_P``$@```'K_```3````C?\`
M``P```"A_P``!@```*[_```<````M?\```\```#2_P``&P```.+_```2````
M_O\``!`````1``$`$0```"(``0`<````-``!`",```!1``$`:@```'4``0`/
M````X``!``4```#P``$`$````/8``0`)````!P$!``0````1`0$`"P```!8!
M`0`@````(@$!`!0```!#`0$`#````%@!`0`,````90$!``\```!R`0$`%0``
M`((!`0`I````F`$!`"H```#"`0$`)@```.T!`0`G````%`(!`"D````\`@$`
M*@```&8"`0`9````D0(!`$(```"K`@$`$0```.X"`0`2``````,!`!,````3
M`P$`%````"<#`0`/````/`,!`!8```!,`P$`%P```&,#`0`0````>P,!`!$`
M``",`P$`-````)X#`0`3````TP,!`!(```#G`P$`-0```/H#`0`4````,`0!
M``<```!%!`$`#````$T$`0`*````6@0!`"````!E!`$`$````(8$`0`4````
MEP0!`!0```"L!`$`$0```,$$`0`7````TP0!`!P```#K!`$`#0````@%`0`-
M````%@4!`!,````D!0$`%@```#@%`0`4````3P4!`!H```!D!0$`$0```'\%
M`0`,````D04!`!````">!0$`&@```*\%`0`>````R@4!`!H```#I!0$`$P``
M``0&`0`5````&`8!`!$````N!@$`%P```$`&`0`4````6`8!`!<```!M!@$`
M%0```(4&`0`)````FP8!`!````"E!@$`&0```+8&`0`$````T`8!``<```#5
M!@$`"P```-T&`0`1````Z08!``8```#[!@$`!@````('`0`&````"0<!``4`
M```0!P$`!P```!8'`0`'````'@<!``4````F!P$`%@```"P'`0`&````0P<!
M``8```!*!P$`!````%$'`0`$````5@<!``<```!;!P$`#@```&,'`0`,````
M<@<!``P```!_!P$`#0```(P'`0`*````F@<!``X```"E!P$`!0```+0'`0`H
M````N@<!``X```#C!P$`#````/('`0`/````_P<!``H````/"`$`"````!H(
M`0`)````(P@!`"L````M"`$`!````%D(`0`(````7@@!`"8```!G"`$`$@``
M`(X(`0`/````H0@!``8```"Q"`$`"@```+@(`0!,````PP@!``<````0"0$`
M"````!@)`0`@````(0D!``D```!""0$`#0```$P)`0`)````6@D!`!0```!D
M"0$`#````'D)`0`-````A@D!``X```"4"0$`%@```*,)`0`1````N@D!``8`
M``#,"0$``P```-,)`0`&````UPD!`!D```#>"0$`!P```/@)`0`$``````H!
M``L````%"@$`"P```!$*`0`'````'0H!``4````E"@$`!P```"L*`0`6````
M,PH!``T```!*"@$`#0```%@*`0`*````9@H!`!````!Q"@$`#P```((*`0`1
M````D@H!`!<```"D"@$`"@```+P*`0`1````QPH!``@```#9"@$`!````.(*
M`0`/````YPH!`#H```#W"@$`!0```#(+`0`,````.`L!``0```!%"P$`'@``
M`$H+`0`.````:0L!`!````!X"P$`"P```(D+`0`,````E0L!``D```"B"P$`
M!P```*P+`0`*````M`L!``D```"_"P$`#@```,D+`0`0````V`L!`!L```#I
M"P$`&`````4,`0`:````'@P!``H````Y#`$`"0```$0,`0`*````3@P!``P`
M``!9#`$`#P```&8,`0`(````=@P!``8```!_#`$`'````(8,`0`'````HPP!
M``4```"K#`$`"P```+$,`0!'````O0P!``T````%#0$`"0```!,-`0`$````
M'0T!``,````B#0$`$P```"8-`0`3````.@T!`!,```!.#0$`"@```&(-`0`"
M````;0T!``0```!P#0$`)0```'4-`0`#````FPT!``4```"?#0$`*@```*4-
M`0`*````T`T!``4```#;#0$`!````.$-`0`*````Y@T!``T```#Q#0$`!@``
M`/\-`0`(````!@X!``@````/#@$`!````!@.`0`%````'0X!`&@````C#@$`
M"0```(P.`0`,````E@X!`!````"C#@$`!0```+0.`0`&````N@X!`!L```#!
M#@$`+P```-T.`0`0````#0\!``H````>#P$`"````"D/`0`/````,@\!``H`
M``!"#P$`"0```$T/`0`3````5P\!`!L```!K#P$`&````(</`0`7````H`\!
M`!H```"X#P$`'P```-,/`0`.````\P\!`!<````"$`$``P```!H0`0`'````
M'A`!``@````F$`$`!P```"\0`0`)````-Q`!``H```!!$`$`"P```$P0`0`'
M````6!`!`%$```!@$`$`$````+(0`0`,````PQ`!``T```#0$`$`&@```-X0
M`0!*````^1`!`!D```!$$0$`!@```%X1`0`:````91$!`"4```"`$0$`!@``
M`*81`0`&````K1$!`!\```"T$0$`!@```-01`0`)````VQ$!`!@```#E$0$`
M%P```/X1`0`H````%A(!``8````_$@$`#0```$82`0`H````5!(!`"(```!]
M$@$`5P```*`2`0`3````^!(!`",````,$P$`$P```#`3`0`"````1!,!``L`
M``!'$P$`#````%,3`0`(````8!,!``T```!I$P$`"@```'<3`0`6````@A,!
M``<```"9$P$`%````*$3`0`&````MA,!``@```"]$P$`#@```,83`0`'````
MU1,!``H```#=$P$`"P```.@3`0`R````]!,!`!<````G%`$`!P```#\4`0`,
M````1Q0!``T```!4%`$`#````&(4`0`$````;Q0!``D```!T%`$`"0```'X4
M`0`*````B!0!``<```"3%`$`"0```)L4`0`)````I10!``H```"O%`$`!P``
M`+H4`0`*````PA0!`!4```#-%`$`&P```.,4`0`/````_Q0!`$D````/%0$`
M$@```%D5`0`*````;!4!`!8```!W%0$`#P```(X5`0`0````GA4!``D```"O
M%0$`$````+D5`0`'````RA4!`!(```#2%0$`!````.45`0`+````ZA4!``<`
M``#V%0$`!0```/X5`0`%````!!8!`!H````*%@$`"P```"46`0`4````,18!
M`!$```!&%@$`&@```%@6`0`6````<Q8!`!0```"*%@$`%P```)\6`0`8````
MMQ8!`!P```#0%@$`&0```.T6`0`'````!Q<!``4````/%P$`#0```!47`0`,
M````(Q<!``L````P%P$`$0```#P7`0`(````3A<!`!<```!7%P$`"P```&\7
M`0`,````>Q<!`!\```"(%P$`&@```*@7`0`3````PQ<!``0```#7%P$`"@``
M`-P7`0`$````YQ<!``T```#L%P$`#````/H7`0`%````!Q@!``D````-&`$`
M"````!<8`0`%````(!@!``<````F&`$`!0```"X8`0`$````-!@!``(````Y
M&`$`&````#P8`0`7````51@!`#@```!M&`$`+````*88`0`2````TQ@!`"D`
M``#F&`$`,@```!`9`0`*````0QD!`"P```!.&0$`+@```'L9`0`S````JAD!
M`#,```#>&0$`.````!(:`0`1````2QH!``\```!=&@$`&````&T:`0`0````
MAAH!``\```"7&@$`$P```*<:`0`5````NQH!`!0```#1&@$`$@```.8:`0`4
M````^1H!`!4````.&P$`+0```"0;`0`M````4AL!`#$```"`&P$`+@```+(;
M`0`O````X1L!`"P````1'`$`8@```#X<`0`3````H1P!``T```"U'`$`"```
M`,,<`0`7````S!P!``@```#D'`$`#````.T<`0`K````^AP!`"$````F'0$`
M&````$@=`0`:````81T!``D```!\'0$`10```(8=`0!!````S!T!``0````.
M'@$`$P```!,>`0`4````)QX!``X````\'@$`$P```$L>`0`8````7QX!``8`
M``!X'@$`"0```'\>`0`*````B1X!``\```"4'@$`$````*0>`0`'````M1X!
M``X```"]'@$`!0```,P>`0`;````TAX!``@```#N'@$`!@```/<>`0`4````
M_AX!`!$````3'P$`&````"4?`0`.````/A\!`#@```!-'P$``@```(8?`0`&
M````B1\!``X```"0'P$`$````)\?`0`%````L!\!``<```"V'P$`#@```+X?
M`0`&````S1\!`"@```#4'P$`#````/T?`0`<````"B`!``0````G(`$`F@``
M`"P@`0`I````QR`!`!<```#Q(`$`'P````DA`0`9````*2$!`%P```!#(0$`
M%````*`A`0`^````M2$!`!\```#T(0$`$````!0B`0`'````)2(!``X````M
M(@$`#````#PB`0`,````22(!`!,```!6(@$`"@```&HB`0`=````=2(!`!D`
M``"3(@$`!0```*TB`0`1````LR(!``T```#%(@$`$0```-,B`0`D````Y2(!
M`!(````*(P$`%0```!TC`0`2````,R,!``X```!&(P$`&0```%4C`0`(````
M;R,!``D```!X(P$`#0```((C`0`'````D",!``H```"8(P$`!P```*,C`0`/
M````JR,!``8```"[(P$`"P```,(C`0`:````SB,!``H```#I(P$`!P```/0C
M`0`(````_",!``4````%)`$`'P````LD`0`&````*R0!`!`````R)`$`"```
M`$,D`0`-````3"0!``@```!:)`$`'@```&,D`0`2````@B0!`"P```"5)`$`
M&@```,(D`0`)````W20!``H```#G)`$`%0```/(D`0`%````""4!`!0````.
M)0$`!````",E`0`0````*"4!``8````Y)0$`!P```$`E`0`>````2"4!`"@`
M``!G)0$`"@```)`E`0`<````FR4!`!$```"X)0$`$0```,HE`0`+````W"4!
M`!H```#H)0$`%`````,F`0`$````&"8!``0````=)@$`"P```"(F`0`%````
M+B8!``8````T)@$`$0```#LF`0`(````328!``8```!6)@$`"@```%TF`0`;
M````:"8!`#0```"$)@$`-````+DF`0`@````[B8!`"D````/)P$`(````#DG
M`0!!````6B<!`!H```"<)P$`(0```+<G`0`H````V2<!`"D````"*`$`4```
M`"PH`0`B````?2@!``8```"@*`$`"````*<H`0`%````L"@!``@```"V*`$`
M&0```+\H`0`9````V2@!`"H```#S*`$`(P```!XI`0`9````0BD!`"X```!<
M*0$`-````(LI`0`(````P"D!`!<```#)*0$`"@```.$I`0`'````["D!`"$`
M``#T*0$`"````!8J`0`0````'RH!``X````P*@$`%````#\J`0`+````5"H!
M``<```!@*@$`$P```&@J`0`(````?"H!``L```"%*@$`"@```)$J`0`4````
MG"H!``\```"Q*@$`,@```,$J`0`+````]"H!``4`````*P$`!0````8K`0`5
M````#"L!``P````B*P$`!0```"\K`0`7````-2L!``\```!-*P$`!````%TK
M`0`*````8BL!``D```!M*P$`"P```'<K`0`-````@RL!``P```"1*P$`#@``
M`)XK`0`%````K2L!``0```"S*P$`%````+@K`0`-````S2L!`"(```#;*P$`
M,@```/XK`0`;````,2P!`$4```!-+`$`$@```),L`0`7````IBP!``<```"^
M+`$`'@```,8L`0`4````Y2P!``4```#Z+`$`%``````M`0`&````%2T!``<`
M```<+0$`#@```"0M`0`J````,RT!``8```!>+0$`#````&4M`0`3````<BT!
M``T```"&+0$`$0```)0M`0`5````IBT!``L```"\+0$`-@```,@M`0`*````
M_RT!`"(````*+@$`"P```"TN`0`/````.2X!`(4```!)+@$`,@```,\N`0`;
M`````B\!`"4````>+P$`,````$0O`0`Q````=2\!`"T```"G+P$`#@```-4O
M`0`%````Y"\!``X```#J+P$`$P```/DO`0`1````#3`!`!(````?,`$`!P``
M`#(P`0`1````.C`!`!,```!,,`$`!P```&`P`0`4````:#`!`!@```!],`$`
M!P```)8P`0`%````GC`!``P```"D,`$`#````+$P`0`2````OC`!``0```#1
M,`$`!P```-8P`0`*````WC`!``L```#I,`$`#````/4P`0`.`````C$!``X`
M```1,0$`!0```"`Q`0`%````)C$!`"X````L,0$`)@```%LQ`0`C````@C$!
M``,```"F,0$`$@```*HQ`0`&````O3$!`!X```#$,0$`&````.,Q`0`9````
M_#$!`"4````6,@$`#0```#PR`0`)````2C(!`!\```!4,@$``P```'0R`0`8
M````>#(!``<```"1,@$`"@```)DR`0`"````I#(!``P```"G,@$`%0```+0R
M`0`+````RC(!`!D```#6,@$`(````/`R`0`2````$3,!``4````D,P$`"@``
M`"HS`0`5````-3,!`!(```!+,P$`#````%XS`0`$````:S,!``D```!P,P$`
M!P```'HS`0`,````@C,!`%(```"/,P$`%P```.(S`0`D````^C,!`"$````?
M-`$`$@```$$T`0`'````5#0!``8```!<-`$`#@```&,T`0`-````<C0!`!$`
M``"`-`$`&P```)(T`0`,````KC0!``P```"[-`$`#0```,@T`0`5````UC0!
M`!(```#L-`$`#P```/\T`0`4````#S4!``H````D-0$`&P```"\U`0`@````
M2S4!`!X```!L-0$`$````(LU`0`+````G#4!`"<```"H-0$`)0```-`U`0!I
M````]C4!`"8```!@-@$`&@```(<V`0`7````HC8!`!D```"Z-@$`&@```-0V
M`0`E````[S8!`"@````5-P$`)P```#XW`0`:````9C<!`!<```"!-P$`&P``
M`)DW`0!$````M3<!`#0```#Z-P$`)0```"\X`0`9````53@!`!\```!O.`$`
M&P```(\X`0`3````JS@!``@```"_.`$`!P```,@X`0`(````T#@!``D```#9
M.`$`%0```.,X`0`-````^3@!`",````'.0$`#0```"LY`0`3````.3D!``@`
M``!-.0$``P```%8Y`0!&````6CD!`#\```"A.0$`-P```.$Y`0!7````&3H!
M``4```!Q.@$`'P```'<Z`0`O````ESH!``H```#'.@$`$````-(Z`0`(````
MXSH!``T```#L.@$`+0```/HZ`0`$````*#L!``<````M.P$`"````#4[`0`-
M````/CL!``H```!,.P$`3P```%<[`0`E````ISL!`!P```#-.P$`"P```.H[
M`0`?````]CL!`!T````6/`$`)0```#0\`0`@````6CP!`"0```![/`$`(```
M`*`\`0`+````P3P!``<```#-/`$`#0```-4\`0`,````XSP!`!<```#P/`$`
M!@````@]`0`Y````#ST!``P```!)/0$`!P```%8]`0`)````7CT!`!,```!H
M/0$`"0```'P]`0`$````ACT!`!````"+/0$`"````)P]`0`(````I3T!``0`
M``"N/0$`"P```+,]`0`,````OST!`!(```#,/0$`$0```-\]`0`,````\3T!
M`!H```#^/0$`#P```!D^`0`'````*3X!``T````Q/@$`#@```#\^`0`4````
M3CX!``X```!C/@$`!P```'(^`0`,````>CX!`!L```"'/@$`+````*,^`0`3
M````T#X!`!P```#D/@$`*`````$_`0`&````*C\!``<````Q/P$`$P```#D_
M`0`%````33\!``0```!3/P$`%P```%@_`0`Y````<#\!``H```"J/P$`#```
M`+4_`0`)````PC\!``8```#,/P$`"0```-,_`0`(````W3\!``D```#F/P$`
M"@```/`_`0`1````^S\!``8````-0`$`#@```!1``0`.````(T`!``T````R
M0`$`"P```$!``0`=````3$`!``L```!J0`$``@```'9``0`<````>4`!``<`
M``"60`$`!@```)Y``0!D````I4`!``D````*00$`!P```!1!`0`F````'$$!
M`"D```!#00$`&P```&U!`0`X````B4$!`"L```#"00$`&@```.Y!`0`C````
M"4(!`"H````M0@$`+0```%A"`0`[````AD(!`"@```#"0@$`-````.M"`0`9
M````($,!`!4````Z0P$`!0```%!#`0`'````5D,!``@```!>0P$`!P```&=#
M`0`%````;T,!``<```!U0P$`#@```'U#`0`)````C$,!``8```"60P$`"```
M`)U#`0`+````ID,!``<```"R0P$`"````+I#`0`'````PT,!`!8```#+0P$`
M"0```.)#`0`&````[$,!``L```#S0P$`$````/]#`0`&````$$0!`!P````7
M1`$`%````#1$`0`'````240!`!$```!11`$`"````&-$`0`.````;$0!``,`
M``![1`$`"````']$`0`4````B$0!``4```"=1`$`$````*-$`0`)````M$0!
M`!````"^1`$`!@```,]$`0`9````UD0!``H```#P1`$`'````/M$`0`'````
M&$4!``4````@10$`$````"9%`0`4````-T4!``L```!,10$`#0```%A%`0`H
M````9D4!`!@```"/10$`%P```*A%`0`$````P$4!``D```#%10$`"@```,]%
M`0`'````VD4!``(```#B10$`#@```.5%`0`(````]$4!`",```#]10$`'P``
M`"%&`0`X````048!`"8```!Z1@$`,0```*%&`0`G````TT8!`$0```#[1@$`
M)0```$!'`0`O````9D<!`"\```"61P$`+P```,9'`0`H````]D<!`&0````?
M2`$`%````(1(`0!5````F4@!`#@```#O2`$`*0```"A)`0!*````4DD!`%L`
M``"=20$`*````/E)`0`X````(DH!`"P```!;2@$`*````(A*`0`L````L4H!
M`"8```#>2@$`&P````5+`0`^````(4L!`*D!``!@2P$`(P````I-`0`P````
M+DT!`!<```!?30$`2````'=-`0"%````P$T!`#````!&3@$`)0```'=.`0!!
M````G4X!`%L```#?3@$`20```#M/`0`Q````A4\!`!T```"W3P$`&````-5/
M`0`K````[D\!`"$````:4`$`'P```#Q0`0`K````7%`!`"8```"(4`$`)P``
M`*]0`0`Z````UU`!`!T````240$`$0```#!1`0`S````0E$!`"4```!V40$`
M)P```)Q1`0`@````Q%$!`"8```#E40$`'P````Q2`0`P````+%(!`,P```!=
M4@$`:0```"I3`0`Q````E%,!`$$```#&4P$`,P````A4`0`E````/%0!`#T`
M``!B5`$`90```*!4`0!-````!E4!`%X```!450$`)P```+-5`0`Q````VU4!
M`#X````-5@$`+````$Q6`0`F````>58!`"\```"@5@$`+@```-!6`0`I````
M_U8!`#`````I5P$`5````%I7`0!:````KU<!`#$````*6`$`2````#Q8`0!*
M````A5@!`#$```#06`$`*@````)9`0`B````+5D!`"\```!060$`*0```(!9
M`0`R````JED!`"\```#=60$`+`````U:`0`M````.EH!`'$```!H6@$`9@``
M`-I:`0!O````05L!`+,```"Q6P$`%P```&5<`0`E````?5P!`#(```"C7`$`
M*0```-9<`0`^`````%T!`"(````_70$`4@```&)=`0`B````M5T!`"4```#8
M70$`"P```/Y=`0"Q````"EX!`$4```"\7@$`(0````)?`0`V````)%\!`#``
M``!;7P$`)0```(Q?`0`<````LE\!`$@```#/7P$`,0```!A@`0`'````2F`!
M``<```!28`$`!````%I@`0`-````7V`!``L```!M8`$`#@```'E@`0`+````
MB&`!``4```"48`$`$````)I@`0`"````JV`!`%D```"N8`$`!0````AA`0`2
M````#F$!``0````A80$`!P```"9A`0`(````+F$!``4````W80$``P```#UA
M`0`0````06$!``P```!280$`$P```%]A`0`-````<V$!``(```"!80$`!P``
M`(1A`0`&````C&$!`!0```"380$`#````*AA`0`8````M6$!``8```#.80$`
M$@```-5A`0`,````Z&$!``,```#U80$`*@```/EA`0`$````)&(!``8````I
M8@$`!P```#!B`0`?````.&(!`#4```!88@$`+@```(YB`0`O````O6(!`!<`
M``#M8@$`(@````5C`0`E````*&,!`"````!.8P$`&P```&]C`0`8````BV,!
M`"0```"D8P$`'P```,EC`0`:````Z6,!`"$````$9`$`(````"9D`0`P````
M1V0!`!H```!X9`$`,@```)-D`0`:````QF0!`"\```#A9`$`*P```!%E`0`?
M````/64!`",```!=90$`'P```(%E`0`:````H64!`"$```"\90$`)0```-YE
M`0`F````!&8!`"4````K9@$`)````%%F`0`8````=F8!`!T```"/9@$`)```
M`*UF`0`8````TF8!`"(```#K9@$`+`````YG`0`O````.V<!`!4```!K9P$`
M)0```(%G`0`\````IV<!`!\```#D9P$`(P````1H`0`?````*&@!`"````!(
M:`$`&@```&EH`0`8````A&@!`"8```"=:`$`'@```,1H`0`I````XV@!`!X`
M```-:0$`,0```"QI`0`)````7FD!``P```!H:0$`%P```'5I`0`O````C6D!
M`"0```"]:0$`!P```.)I`0`/````ZFD!`!0```#Z:0$`#@````]J`0`-````
M'FH!`"0````L:@$`!0```%%J`0`'````5VH!`"(```!?:@$`)0```()J`0`:
M````J&H!`!T```##:@$`&@```.%J`0`'````_&H!`,<````$:P$`"P```,QK
M`0`<````V&L!`!4```#U:P$`!@````ML`0`)````$FP!``L````<;`$`#0``
M`"AL`0`7````-FP!``8```!.;`$`,P```%5L`0`3````B6P!`!,```"=;`$`
M!P```+%L`0`/````N6P!``<```#);`$`,@```-%L`0`$````!&T!`"$````)
M;0$`$P```"MM`0`,````/VT!`!$```!,;0$`,@```%YM`0`6````D6T!``@`
M``"H;0$`'0```+%M`0`)````SVT!``H```#9;0$`%````.1M`0`*````^6T!
M`!T````$;@$`"````")N`0`?````*VX!``@```!+;@$`&@```%1N`0`G````
M;VX!``8```"7;@$`%0```)YN`0`'````M&X!``@```"\;@$`"0```,5N`0`_
M````SVX!`!(````/;P$`!P```")O`0`/````*F\!``X````Z;P$`$````$EO
M`0`)````6F\!``D```!D;P$`"````&YO`0`3````=V\!``D```"+;P$`!P``
M`)5O`0`,````G6\!`!D```"J;P$`"@```,1O`0`;````SV\!`!<```#K;P$`
M%`````-P`0`*````&'`!``P````C<`$`%P```#!P`0`$````2'`!`"H```!-
M<`$`#````'AP`0`1````A7`!``<```"7<`$``@```)]P`0`0````HG`!`!@`
M``"S<`$`"P```,QP`0`#````V'`!``@```#<<`$`"P```.5P`0`&````\7`!
M``<```#X<`$`#0````!Q`0`+````#G$!`!0````:<0$`%0```"]Q`0`.````
M17$!`"\```!4<0$`(````(1Q`0`<````I7$!`!4```#"<0$`#````-AQ`0`Q
M````Y7$!``4````7<@$`$@```!UR`0`_````,'(!`!(```!P<@$`"@```(-R
M`0`&````CG(!``0```"5<@$`!````)IR`0`*````GW(!`!,```"J<@$`!0``
M`+YR`0`&````Q'(!``8```#+<@$`"````-)R`0`$````VW(!``P```#@<@$`
M"0```.UR`0`,````]W(!``H````$<P$`$`````]S`0`3````(',!`!,````T
M<P$`.0```$AS`0`N````@G,!`"D```"Q<P$`!0```-MS`0`8````X7,!`!D`
M``#Z<P$`'P```!1T`0`=````-'0!`!$```!2=`$``@```&1T`0`$````9W0!
M``H```!L=`$`!@```'=T`0`%````?G0!``,```"$=`$`#````(AT`0!%````
ME70!`#(```#;=`$`/`````YU`0`:````2W4!`#0```!F=0$`*````)MU`0!3
M````Q'4!`#`````8=@$`+P```$EV`0`R````>78!`!D```"L=@$`<@```,9V
M`0`@````.7<!`#4```!:=P$`(0```)!W`0!%````LG<!`#````#X=P$`)@``
M`"EX`0`>````4'@!`"@```!O>`$`*P```)AX`0`I````Q'@!`"D```#N>`$`
M)@```!AY`0`E````/WD!`"@```!E>0$`*````(YY`0`B````MWD!`"L```#:
M>0$`+@````9Z`0`P````-7H!`!(```!F>@$`$P```'EZ`0`0````C7H!`'D`
M``">>@$`"0```!A[`0"A````(GL!`',```#$>P$`?````#A\`0`K````M7P!
M`%0```#A?`$`%P```#9]`0`L````3GT!`"<```![?0$`%@```*-]`0`/````
MNGT!`!<```#*?0$`'P```.)]`0!``````GX!`!\```!#?@$`'````&-^`0!1
M````@'X!`!H```#2?@$`%````.U^`0`*`````G\!``4````-?P$`!@```!-_
M`0`(````&G\!``4````C?P$`$@```"E_`0`0````/'\!`!,```!-?P$`'0``
M`&%_`0`/````?W\!``H```"/?P$`#P```)I_`0`'````JG\!``0```"R?P$`
M"0```+=_`0`)````P7\!``<```#+?P$`"P```--_`0`'````WW\!``4```#G
M?P$`%````.U_`0`.`````H`!``8````1@`$`!P```!B``0`(````((`!``\`
M```I@`$`$0```#F``0`,````2X`!``@```!8@`$`#````&&``0`/````;H`!
M`!8```!^@`$`!P```)6``0`&````G8`!`!0```"D@`$`!@```+F``0`,````
MP(`!`!$```#-@`$`"````-^``0`$````Z(`!`!D```#M@`$`$0````>!`0`*
M````&8$!`!@````D@0$`$P```#V!`0`+````48$!``P```!=@0$`#````&J!
M`0`,````=X$!`!P```"$@0$`$0```*&!`0`$````LX$!``\```"X@0$`!P``
M`,B!`0`$````T($!`!D```#5@0$`!P```.^!`0`"````]X$!``(```#Z@0$`
M$0```/V!`0`)````#X(!``8````9@@$`$@```"""`0`7````,X(!``8```!+
M@@$`)P```%*"`0`"````>H(!``0```!]@@$`#0```(*"`0`$````D((!``\`
M``"5@@$`$P```*6"`0`'````N8(!``<```#!@@$`$0```,F"`0`&````VX(!
M`!@```#B@@$`!@```/N"`0`3`````H,!`!`````6@P$`$@```">#`0`"````
M.H,!``8````]@P$`#````$2#`0`)````48,!`!$```!;@P$`$0```&V#`0`;
M````?X,!`"(```";@P$`!P```+Z#`0`'````QH,!``L```#.@P$`!0```-J#
M`0`"````X(,!``L```#C@P$`I0$``.^#`0`0````E84!`!4```"FA0$`#0``
M`+R%`0`'````RH4!``D```#2A0$`"````-R%`0`H````Y84!`"0````.A@$`
M`P```#.&`0`C````-X8!`!@```!;A@$`'@```'2&`0`O````DX8!`"L```##
MA@$`*0```.^&`0`M````&8<!`"@```!'AP$`&0```'"'`0`G````BH<!`"0`
M``"RAP$`)0```->'`0`J````_8<!``H````HB`$`'@```#.(`0`2````4H@!
M``H```!EB`$`%P```'"(`0`%````B(@!`"@```".B`$`$@```+>(`0`.````
MRH@!`!,```#9B`$`#@```.V(`0`-````_(@!``H````*B0$`(````!6)`0"2
M````-HD!`!````#)B0$`"@```-J)`0`2````Y8D!``T```#XB0$`&P````:*
M`0`,````(HH!``\````OB@$`%@```#^*`0`&````5HH!`)D```!=B@$`"```
M`/>*`0`-`````(L!`!@````.BP$`#P```">+`0`0````-XL!`!````!(BP$`
M"````%F+`0`0````8HL!`"X```!SBP$`/````**+`0`5````WXL!`$,```#U
MBP$`20```#F,`0!5````@XP!`$T```#9C`$`<@```">-`0!J````FHT!`$8`
M```%C@$`$````$R.`0`6````78X!``X```!TC@$`$````(..`0`2````E(X!
M``4```"GC@$`!@```*V.`0`1````M(X!``@```#&C@$`'````,^.`0`)````
M[(X!``D```#VC@$`)0````"/`0`C````)H\!`!(```!*CP$`$````%V/`0`.
M````;H\!`!$```!]CP$`!@```(^/`0`)````EH\!`!L```"@CP$`(0```+R/
M`0`.````WH\!`!0```#MCP$`&`````*0`0`E````&Y`!`"H```!!D`$`&@``
M`&R0`0`?````AY`!`"X```"GD`$`$````-:0`0`1````YY`!`!<```#YD`$`
M#0```!&1`0`U````'Y$!``P```!5D0$`(P```&*1`0`F````AI$!`!$```"M
MD0$`6````+^1`0`V````&)(!`"<```!/D@$`)0```'>2`0`(````G9(!`!4`
M``"FD@$`(@```+R2`0`6````WY(!`"$```#VD@$`+@```!B3`0`B````1Y,!
M`"T```!JDP$`-P```)B3`0`-````T),!``@```#>DP$`$0```.>3`0`+````
M^9,!``<````%E`$`!P````V4`0`'````%90!``<````=E`$`#````"64`0`%
M````,I0!`!L````XE`$`#````%24`0`0````890!`!(```!RE`$`'````(64
M`0`O````HI0!``D```#2E`$`"0```-R4`0`6````YI0!`!8```#]E`$`&```
M`!25`0`>````+94!`!0```!,E0$`$@```&&5`0`/````=)4!`"$```"$E0$`
M'0```*:5`0`'````Q)4!``8```#,E0$`"````-.5`0`-````W)4!``@```#J
ME0$`"0```/.5`0`2````_94!``D````0E@$`$P```!J6`0`8````+I8!`"H`
M``!'E@$`!P```'*6`0`2````>I8!``4```"-E@$`%@```).6`0`2````JI8!
M``\```"]E@$`)0```,V6`0`\````\Y8!`$(````PEP$`.@```'.7`0`)````
MKI<!``<```"XEP$`$P```,"7`0`$````U)<!``4```#9EP$`"@```-^7`0`-
M````ZI<!``H```#XEP$`%P````.8`0!#````&Y@!`!4```!?F`$`)````'68
M`0`K````FI@!`"H```#&F`$`,````/&8`0`)````(ID!``8````LF0$`"0``
M`#.9`0`'````/9D!`#L```!%F0$`/0```(&9`0`Z````OYD!`%\```#ZF0$`
M.0```%J:`0`Y````E)H!`$4```#.F@$`10```!2;`0`Y````6IL!`%(```"4
MFP$`*@```.>;`0`L````$IP!`$D````_G`$`.0```(F<`0`_````PYP!`"4`
M```#G0$`%0```"F=`0`9````/YT!`"P```!9G0$`)@```(:=`0`F````K9T!
M`!,```#4G0$`"@```.B=`0`1````\YT!``4````%G@$`#`````N>`0`9````
M&)X!`!L````RG@$`!P```$Z>`0`'````5IX!`!4```!>G@$`"@```'2>`0`(
M````?YX!`#0```"(G@$`$````+V>`0`0````SIX!``H```#?G@$`!P```.J>
M`0`&````\IX!`!T```#YG@$`!0```!>?`0`(````'9\!``4````FGP$`&0``
M`"R?`0`+````1I\!`#(```!2GP$`%@```(6?`0`-````G)\!``<```"JGP$`
M!P```+*?`0`)````NI\!``4```#$GP$`$0```,J?`0`&````W)\!`!0```#C
MGP$`!0```/B?`0`(````_I\!``8````'H`$`"P````Z@`0`&````&J`!`"(`
M```AH`$`!P```$2@`0`&````3*`!``@```!3H`$`%````%R@`0`,````<:`!
M``<```!^H`$`%0```(:@`0`#````G*`!``,```"@H`$`&@```*2@`0`#````
MOZ`!`!H```##H`$`+0```-Z@`0`&````#*$!``4````3H0$`"````!FA`0`(
M````(J$!`%H````KH0$`(0```(:A`0`I````J*$!`#P```#2H0$`+`````^B
M`0`A````/*(!``8```!>H@$`"````&6B`0`>````;J(!`"8```"-H@$`,0``
M`+2B`0`V````YJ(!`"@````=HP$`+P```$:C`0!M````=J,!`#H```#DHP$`
M"@```!^D`0`&````*J0!``D````QI`$`$@```#ND`0`,````3J0!`!````!;
MI`$`%@```&RD`0`1````@Z0!`!8```"5I`$`%@```*RD`0`0````PZ0!`!4`
M``#4I`$`!@```.JD`0`;````\:0!`!L````-I0$`%P```"FE`0`;````0:4!
M`!@```!=I0$`!@```':E`0`'````?:4!`!````"%I0$`7````):E`0!@````
M\Z4!``0```!4I@$`$@```%FF`0`5````;*8!``4```""I@$`!0```(BF`0`<
M````CJ8!`!D```"KI@$`%````,6F`0`/````VJ8!`!$```#JI@$`$@```/RF
M`0`@````#Z<!`"$````PIP$`&@```%*G`0`Z````;:<!`#L```"HIP$`+```
M`.2G`0`M````$:@!``\````_J`$`+P```$^H`0`&````?Z@!`!0```"&J`$`
M#P```)NH`0`3````JZ@!``\```"_J`$`&````,^H`0`2````Z*@!`!4```#[
MJ`$`$P```!&I`0`-````):D!``8````SJ0$`$@```#JI`0`'````3:D!``X`
M``!5J0$`%@```&2I`0`/````>ZD!``@```"+J0$``P```)2I`0`0````F*D!
M``X```"IJ0$`!0```+BI`0`0````OJD!`!,```#/J0$`'P```..I`0`*````
M`ZH!`!T````.J@$`,@```"RJ`0`'````7ZH!`!````!GJ@$`"````'BJ`0`$
M````@:H!``<```"&J@$`!P```(ZJ`0`3````EJH!``P```"JJ@$`"````+>J
M`0`)````P*H!`!H```#*J@$`/@```.6J`0`F````)*L!``T```!+JP$`$```
M`%FK`0`%````:JL!`!\```!PJP$`$0```)"K`0`2````HJL!`!0```"UJP$`
M$````,JK`0`R````VZL!`$(````.K`$`(0```%&L`0`1````<ZP!``@```"%
MK`$`%0```(ZL`0!'````I*P!`"@```#LK`$`$````!6M`0`)````)JT!``H`
M```PK0$`!@```#NM`0`&````0JT!`!(```!)K0$`#@```%RM`0`+````:ZT!
M``H```!WK0$`#P```(*M`0`L````DJT!`"<```"_K0$`-````.>M`0`O````
M'*X!`"8```!,K@$`*P```'.N`0`F````GZX!`"4```#&K@$`/0```.RN`0`R
M````*J\!`"D```!=KP$`+P```(>O`0`F````MZ\!`#0```#>KP$`1@```!.P
M`0!!````6K`!`#T```"<L`$`/0```-JP`0!'````&+$!`"P```!@L0$`*```
M`(VQ`0!&````MK$!`"H```#]L0$`&@```"BR`0`U````0[(!`"@```!YL@$`
M+````**R`0`8````S[(!`,D```#HL@$`'````+*S`0`R````S[,!`#(````"
MM`$`-````#6T`0`Q````:K0!`"D```"<M`$`*@```,:T`0`J````\;0!`#(`
M```<M0$`-0```$^U`0!)````A;4!`#L```#/M0$`J0````NV`0`L````M;8!
M`"4```#BM@$`*`````BW`0`V````,;<!`#(```!HMP$`60```)NW`0!.````
M];<!``T```!$N`$`!````%*X`0`&````5[@!``4```!>N`$`&P```&2X`0`-
M````@+@!`"0```".N`$`#@```+.X`0`0````PK@!``8```#3N`$`%0```-JX
M`0`;````\+@!``<````,N0$`!````!2Y`0`.````&;D!``X````HN0$`"@``
M`#>Y`0`-````0KD!`!,```!0N0$`"P```&2Y`0`0````<+D!``P```"!N0$`
M-@```(ZY`0`&````Q;D!``X```#,N0$`!@```-NY`0`1````XKD!`!<```#T
MN0$`&P````RZ`0`0````*+H!``(````YN@$`2@```#RZ`0`+````A[H!`!4`
M``"3N@$`&@```*FZ`0`$````Q+H!`!,```#)N@$`#P```-VZ`0`#````[;H!
M``\```#QN@$`"`````&[`0`0````"KL!`!`````;NP$`!@```"R[`0`*````
M,[L!`!$````^NP$`#````%"[`0`<````7;L!``H```!ZNP$`!P```(6[`0`?
M````C;L!``X```"MNP$`%P```+R[`0`-````U+L!``L```#BNP$`$0```.Z[
M`0`:`````+P!`"(````;O`$`#@```#Z\`0`.````3;P!`",```!<O`$`&@``
M`("\`0`<````F[P!`#P```"XO`$`#0```/6\`0`>`````[T!`!8````BO0$`
M%0```#F]`0`T````3[T!`"D```"$O0$`$0```*Z]`0`/````P+T!``D```#0
MO0$`#````-J]`0`+````Y[T!`!,```#SO0$`"0````>^`0`U````$;X!`#<`
M``!'O@$`#P```'^^`0`0````C[X!`"4```"@O@$`$@```,:^`0`@````V;X!
M`"````#ZO@$`"0```!N_`0`&````);\!`!L````LOP$`$@```$B_`0`9````
M6[\!`!4```!UOP$`#@```(N_`0`9````FK\!``<```"TOP$`"P```+R_`0`F
M````R+\!`"X```#OOP$`2````![``0`*````9\`!`!0```!RP`$`'P```(?`
M`0`&````I\`!``D```"NP`$`,````+C``0`,````Z<`!`!````#VP`$`!@``
M``?!`0`'````#L$!`%0````6P0$``P```&O!`0`'````;\$!``8```!WP0$`
M"P```'[!`0`>````BL$!``P```"IP0$`#````+;!`0`0````P\$!`!$```#4
MP0$`&0```.;!`0`5`````,(!`!$````6P@$`&0```"C"`0`9````0L(!``@`
M``!<P@$`!0```&7"`0`+````:\(!``L```!WP@$``@```(/"`0`&````AL(!
M`!(```"-P@$`)P```*#"`0`8````R,(!`!D```#AP@$`"0```/O"`0`3````
M!<,!`!0````9PP$`'````"[#`0!&````2\,!`"\```"2PP$`#````,+#`0`/
M````S\,!`(H```#?PP$`'````&K$`0`8````A\0!`#X```"@Q`$`'@```-_$
M`0`0````_L0!``@````/Q0$`!````!C%`0`H````'<4!`#P```!&Q0$`%P``
M`(/%`0`>````F\4!`#(```"ZQ0$`*P```.W%`0`H````&<8!`!H```!"Q@$`
M)P```%W&`0`M````A<8!`"\```"SQ@$`'0```./&`0`1`````<<!`!,````3
MQP$`!P```"?'`0`'````+\<!``8````WQP$`!@```#['`0`/````1<<!``X`
M``!5QP$`$````&3'`0`.````=<<!``P```"$QP$`#@```)''`0`+````H,<!
M`!,```"LQP$`"````,#'`0`(````R<<!`!8```#2QP$`#````.G'`0`U````
M]L<!`!$````LR`$`"````#[(`0`(````1\@!`!X```!0R`$`*@```&_(`0`[
M````FL@!`!4```#6R`$`)0```.S(`0`;````$LD!`"P````NR0$`'P```%O)
M`0`:````>\D!`!L```"6R0$`20```++)`0`C````_,D!`"(````@R@$`&```
M`$/*`0`:````7,H!`"4```!WR@$`,0```)W*`0`9````S\H!`!(```#IR@$`
M*P```/S*`0`D````*,L!``4```!-RP$`&0```%/+`0`+````;<L!``L```!Y
MRP$``P```(7+`0`%````B<L!``D```"/RP$`$````)G+`0`2````JLL!`!$`
M``"]RP$`"@```,_+`0`/````VLL!``X```#JRP$`#````/G+`0`$````!LP!
M``<````+S`$`(````!/,`0`A````-,P!`!<```!6S`$`#P```&[,`0`2````
M?LP!`!````"1S`$`(@```*+,`0`(````Q<P!``<```#.S`$`"0```-;,`0`)
M````X,P!``D```#JS`$`#P```/3,`0`-````!,T!``\````2S0$`"0```"+-
M`0`%````+,T!``H````RS0$`!0```#W-`0`3````0\T!``P```!7S0$`!@``
M`&3-`0`I````:\T!``X```"5S0$`@P```*3-`0`1````*,X!``L````ZS@$`
M!0```$;.`0`-````3,X!``8```!:S@$`"````&'.`0`&````:LX!`!$```!Q
MS@$``P```(/.`0`'````A\X!``8```"/S@$`%````);.`0`1````J\X!``\`
M``"]S@$`$@```,W.`0`<````X,X!``(```#]S@$`!0````#/`0`2````!L\!
M``D````9SP$`#0```"//`0`%````,<\!`"`````WSP$`"````%C/`0`&````
M8<\!`!H```!HSP$`#0```(//`0`'````D<\!``@```"9SP$`!````*+/`0`)
M````I\\!``T```"QSP$`'````+_/`0`.````W,\!``(```#KSP$`!@```.[/
M`0`,````]<\!`!,````"T`$`$````!;0`0`&````)]`!`!(````NT`$`"@``
M`$'0`0`'````3-`!``4```!4T`$`%P```%K0`0`I````<M`!`$H```"<T`$`
M)P```.?0`0`I````#]$!``8````YT0$`"0```$#1`0`$````2M$!``D```!/
MT0$`"````%G1`0`7````8M$!`!````!ZT0$`!0```(O1`0`,````D=$!``8`
M``">T0$`!````*71`0!!````JM$!`$(```#LT0$`00```"_2`0`A````<=(!
M``4```"3T@$`#@```)G2`0`'````J-(!``D```"PT@$`"0```+K2`0`;````
MQ-(!`!````#@T@$`%0```/'2`0`&````!],!``4````.TP$`#P```!33`0`*
M````)-,!``H````OTP$`'@```#K3`0`$````6=,!``<```!>TP$`)````&;3
M`0`&````B],!`!0```"2TP$`%````*?3`0`2````O-,!`!$```#/TP$`$```
M`.'3`0`/````\M,!`!0````"U`$`%````!?4`0`(````+-0!``D````UU`$`
M!0```#_4`0`[````1=0!`#8```"!U`$`0P```+C4`0`I````_-0!`$(````F
MU0$`0@```&G5`0`K````K-4!`$H```#8U0$`+P```"/6`0`Y````4]8!`"\`
M``"-U@$`$````+W6`0`1````SM8!``L```#@U@$`+0```.S6`0`I````&M<!
M`"$```!$UP$`*````&;7`0`'````C]<!``D```"7UP$`"@```*'7`0`'````
MK-<!`"0```"TUP$`)@```-G7`0`M`````-@!``0````NV`$`*P```#/8`0`+
M````7]@!`!L```!KV`$`+0```(?8`0`8````M=@!`!,```#.V`$`"````.+8
M`0`.````Z]@!``X```#ZV`$`#@````G9`0`3````&-D!`$0````LV0$`?@``
M`''9`0!Q````\-D!`!L```!BV@$`#0```'[:`0`.````C-H!`!$```";V@$`
M$@```*W:`0`/````P-H!``<```#0V@$`*````-C:`0`2`````=L!`"<````4
MVP$`$P```#S;`0`2````4-L!`!,```!CVP$`*````'?;`0`>````H-L!`(0`
M``"_VP$`$@```$3<`0`%````5]P!`!0```!=W`$`"0```'+<`0`*````?-P!
M``H```"'W`$`'P```)+<`0`4````LMP!``X```#'W`$`#@```-;<`0`3````
MY=P!`!4```#YW`$`)`````_=`0`F````--T!`",```!;W0$`)0```'_=`0`A
M````I=T!`",```#'W0$`'0```.O=`0!%````"=X!`!,```!/W@$`%````&/>
M`0`3````>-X!`!0```",W@$`$0```*'>`0`6````L]X!`!<```#*W@$`$@``
M`.+>`0`3````]=X!`#P````)WP$`%@```$;?`0`4````7=\!`#X```!RWP$`
M%0```+'?`0`.````Q]\!`!$```#6WP$`"P```.C?`0`M````]-\!`!,````B
MX`$`'@```#;@`0`3````5>`!`"````!IX`$`'0```(K@`0`?````J.`!``\`
M``#(X`$`$0```-C@`0`=````ZN`!`!P````(X0$`&P```"7A`0`A````0>$!
M`!P```!CX0$`#0```(#A`0`1````CN$!`",```"@X0$`(0```,3A`0`@````
MYN$!`"`````'X@$`'0```"CB`0`3````1N(!`!L```!:X@$`'0```';B`0`;
M````E.(!`!@```"PX@$`"@```,GB`0`0````U.(!`!H```#EX@$`!@````#C
M`0`'````!^,!``T````/XP$`%````!WC`0`&````,N,!``<````YXP$`!P``
M`$'C`0`&````2>,!``<```!0XP$`!P```%CC`0`%````8.,!`!4```!FXP$`
M!@```'SC`0`(````@^,!``4```",XP$`!0```)+C`0`*````F.,!`!$```"C
MXP$`"@```+7C`0`2````P.,!`!$```#3XP$`"P```.7C`0`2````\>,!``8`
M```$Y`$`*@````OD`0`1````-N0!`!````!(Y`$`&@```%GD`0`0````=.0!
M``T```"%Y`$`#````)/D`0`O````H.0!``@```#0Y`$`"````-GD`0`H````
MXN0!`!0````+Y0$`$````"#E`0`&````,>4!``L````XY0$`6````$3E`0`'
M````G>4!``8```"EY0$`(0```*SE`0`-````SN4!`!(```#<Y0$`"0```._E
M`0`0````^>4!``T````*Y@$`$P```!CF`0`0````+.8!`!\````]Y@$`$P``
M`%WF`0`'````<>8!``,```!YY@$`!@```'WF`0`?````A.8!``8```"DY@$`
M"````*OF`0`2````M.8!`!,```#'Y@$`!@```-OF`0`$````XN8!``<```#G
MY@$`%@```._F`0`-````!N<!``T````4YP$`"P```"+G`0`4````+N<!`!8`
M``!#YP$`%P```%KG`0`9````<N<!``H```",YP$`#0```)?G`0`&````I><!
M``0```"LYP$`$0```+'G`0`[````P^<!``4```#_YP$`#P````7H`0`%````
M%>@!`"$````;Z`$`%@```#WH`0`7````5.@!``X```!LZ`$`#````'OH`0`)
M````B.@!``<```"2Z`$`"@```)KH`0`)````I>@!``X```"OZ`$`$````+[H
M`0`@````S^@!`"$```#PZ`$`)P```!+I`0`*````.ND!``@```!%Z0$`#0``
M`$[I`0`,````7.D!`!(```!IZ0$`!@```'SI`0`(````@^D!`"<```",Z0$`
M"P```+3I`0`(````P.D!`!(```#)Z0$`/````-SI`0`/````&>H!``L````I
MZ@$`!````#7J`0`%````.NH!`!L```!`Z@$`'````%SJ`0`<````>>H!``H`
M``"6Z@$``@```*'J`0`$````I.H!`"$```"IZ@$``P```,OJ`0`%````S^H!
M`"D```#5Z@$`"@```/_J`0`&````"NL!``<````1ZP$`&````!GK`0`.````
M,NL!``8```!!ZP$`!P```$CK`0`(````4.L!``0```!9ZP$`!0```%[K`0`\
M````9.L!`!````"AZP$`$P```++K`0`5````QNL!``4```#<ZP$`!@```.+K
M`0`>````Z>L!`#,````([`$`#@```#SL`0`)````2^P!``H```!5[`$`%@``
M`&#L`0`*````=^P!``@```""[`$`&0```(OL`0`L````I>P!`"D```#2[`$`
M*````/SL`0`9````)>T!`"$````_[0$`#@```&'M`0`8````<.T!``0```")
M[0$`!P```([M`0`(````ENT!``<```"?[0$`#0```*?M`0`-````M>T!``\`
M``##[0$`"````-/M`0!7````W.T!`!(````T[@$`$````$?N`0`+````6.X!
M`!L```!D[@$`4````(#N`0`=````T>X!``8```#O[@$`'0```/;N`0`G````
M%.\!``<````\[P$`!@```$3O`0`@````2^\!``0```!L[P$`"0```''O`0`I
M````>^\!`"@```"E[P$`)P```,[O`0`'````]N\!``@```#^[P$`+0````?P
M`0`B````-?`!`%D```!8\`$`&````++P`0`F````R_`!`!8```#R\`$``P``
M``GQ`0`-````#?$!`!`````;\0$`!P```"SQ`0`/````-/$!``L```!$\0$`
M&P```%#Q`0`&````;/$!`!4```!S\0$`!@```(GQ`0`(````D/$!``D```"9
M\0$`"P```*/Q`0`*````K_$!``P```"Z\0$`/0```,?Q`0`=````!?(!``@`
M```C\@$`$@```"SR`0`4````/_(!`!<```!4\@$`!0```&SR`0`,````<O(!
M`!````!_\@$`#P```)#R`0`+````H/(!``8```"L\@$`$````+/R`0`/````
MQ/(!``4```#4\@$`"@```-KR`0`>````Y?(!`"4````$\P$`%P```"KS`0!*
M````0O,!`!````"-\P$`"P```)[S`0`0````JO,!`!D```"[\P$`&P```-7S
M`0`*````\?,!`!0```#\\P$`"````!'T`0`4````&O0!``0````O]`$`#P``
M`#3T`0`'````1/0!``4```!,]`$`!0```%+T`0`>````6/0!``<```!W]`$`
M$P```'_T`0`4````D_0!`"(```"H]`$`(@```,OT`0`<````[O0!`!P````+
M]0$`(````"CU`0`E````2?4!`!\```!O]0$`!````(_U`0`%````E/4!``X`
M``":]0$`#@```*GU`0`,````N/4!`!4```#%]0$`"````-OU`0`7````Y/4!
M``T```#\]0$`"@````KV`0`:````%?8!`!\````P]@$`%````%#V`0`(````
M9?8!`!(```!N]@$`!P```('V`0`0````B?8!``\```":]@$`"````*KV`0`)
M````L_8!``<```"]]@$`!0```,7V`0`'````R_8!``4```#3]@$`!````-GV
M`0`#````WO8!`"D```#B]@$`*`````SW`0!!````-?<!`#4```!W]P$`%P``
M`*WW`0`I````Q?<!`#D```#O]P$`$@```"GX`0`X````//@!`#@```!U^`$`
M/0```*[X`0`]````[/@!`$(````J^0$`&0```&WY`0`8````A_D!`!D```"@
M^0$`%@```+KY`0`8````T?D!`"````#J^0$`(`````OZ`0`;````+/H!`!D`
M``!(^@$`&P```&+Z`0`4````?OH!`#$```"3^@$`,0```,7Z`0`U````]_H!
M`#(````M^P$`,P```&#[`0`P````E/L!`'<```#%^P$`&0```#W\`0`6````
M5_P!``H```!N_`$`(@```'G\`0`)````G/P!`!,```"F_`$`-````+K\`0`E
M````[_P!`"$````5_0$`(````#?]`0`+````6/T!`%$```!D_0$`30```+;]
M`0`'````!/X!`!<````,_@$`%0```"3^`0`,````.OX!`!````!'_@$`%@``
M`%C^`0`'````;_X!``@```!W_@$`"0```(#^`0`2````BOX!`!$```"=_@$`
M#P```*_^`0`.````O_X!``D```#._@$`&````-C^`0`(````\?X!``8```#Z
M_@$`%`````'_`0`1````%O\!`!H````H_P$`$````$/_`0!"````5/\!``(`
M``"7_P$`!@```)K_`0`1````H?\!`!4```"S_P$`!0```,G_`0`'````S_\!
M``\```#7_P$`"@```.?_`0`J````\O\!``P````=``(`'@```"H``@`#````
M20`"`+8```!-``(`-P````0!`@`8````/`$"`"@```!5`0(`'0```'X!`@"&
M````G`$"`!@````C`@(`00```#P"`@`A````?@("`!,```"@`@(`!@```+0"
M`@`,````NP("``X```#(`@(`"P```-<"`@`6````XP("``L```#Z`@(`'```
M``8#`@`6````(P,"``4````Z`P(`$@```$`#`@`-````4P,"`!H```!A`P(`
M)0```'P#`@`3````H@,"`!8```"V`P(`'````,T#`@`1````Z@,"`"8```#\
M`P(`"@```",$`@`4````+@0"`!8```!#!`(`$````%H$`@`2````:P0"``\`
M``!^!`(`$@```(X$`@`/````H00"`!4```"Q!`(`'@```,<$`@`5````Y@0"
M``8```#\!`(`"0````,%`@`%````#04"`!T````3!0(`!@```#$%`@`0````
M.`4"``@```!)!0(`%````%(%`@`%````9P4"`!L```!M!0(`#P```(D%`@`M
M````F04"`!4```#'!0(`!@```-T%`@`'````Y`4"`!@```#L!0(`!0````4&
M`@`>````"P8"``0````J!@(`%````"\&`@`'````1`8"``L```!,!@(`(```
M`%@&`@`M````>08"``D```"G!@(`'````+$&`@`0````S@8"`!````#?!@(`
M"@```/`&`@`;````^P8"`!0````7!P(`!````"P'`@`4````,0<"``D```!&
M!P(`"````%`'`@`%````60<"`!T```!?!P(`"````'T'`@`&````A@<"``8`
M``"-!P(`(0```)0'`@`W````M@<"`#\```#N!P(`(@```"X(`@`P````40@"
M`"@```"""`(`10```*L(`@`B````\0@"`#@````4"0(`*````$T)`@`E````
M=@D"`%4```"<"0(`*@```/()`@`'````'0H"``@````E"@(`!P```"X*`@`(
M````-@H"`!0````_"@(`%````%0*`@`P````:0H"`"T```":"@(`&````,@*
M`@`U````X0H"`#T````7"P(`!P```%4+`@`9````70L"``D```!W"P(`$```
M`($+`@`B````D@L"``@```"U"P(`$0```+X+`@`2````T`L"`!T```#C"P(`
M#0````$,`@`(````#PP"`!4````8#`(`"````"X,`@`+````-PP"``T```!#
M#`(`&@```%$,`@`-````;`P"`#P```!Z#`(`"@```+<,`@`%````P@P"``D`
M``#(#`(`&@```-(,`@`/````[0P"``4```#]#`(`&@````,-`@`1````'@T"
M``4````P#0(`#@```#8-`@`0````10T"`!$```!6#0(`#````&@-`@`/````
M=0T"``\```"%#0(`!P```)4-`@`#````G0T"`!D```"A#0(`#0```+L-`@`J
M````R0T"`#H```#T#0(`)@```"\.`@!.````5@X"`!,```"E#@(`%0```+D.
M`@`)````SPX"`"8```#9#@(`'0`````/`@`%````'@\"`!4````D#P(``P``
M`#H/`@`+````/@\"`!(```!*#P(`*@```%T/`@`'````B`\"``T```"0#P(`
M(````)X/`@`.````OP\"`!(```#.#P(`$P```.$/`@`+````]0\"`#L````!
M$`(`"0```#T0`@`<````1Q`"``\```!D$`(`$P```'00`@"1````B!`"`#\`
M```:$0(`)P```%H1`@`N````@A$"`#D```"Q$0(`.@```.L1`@`V````)A("
M`!$```!=$@(`!@```&\2`@`0````=A("`!````"'$@(`&````)@2`@`-````
ML1("``H```"_$@(`$0```,H2`@`=````W!("``<```#Z$@(`%0````(3`@`:
M````&!,"``@````S$P(`!P```#P3`@`1````1!,"`!(```!6$P(`&0```&D3
M`@`&````@Q,"``<```"*$P(`#P```)(3`@`5````HA,"`!0```"X$P(`%0``
M`,T3`@`5````XQ,"``<```#Y$P(`!@````$4`@`Q````"!0"`"<````Z%`(`
M)@```&(4`@`(````B10"``\```"2%`(`!@```*(4`@`?````J10"`"$```#)
M%`(`&@```.L4`@`F````!A4"``L````M%0(`%````#D5`@`F````3A4"``,`
M``!U%0(`&@```'D5`@`'````E!4"`!4```"<%0(``P```+(5`@`,````MA4"
M`!$```##%0(`"P```-45`@`4````X14"`!@```#V%0(`%`````\6`@`%````
M)!8"``H````J%@(`$P```#46`@`4````218"``X```!>%@(`!@```&T6`@`)
M````=!8"``D```!^%@(`#0```(@6`@!:````EA8"`!8```#Q%@(`-0````@7
M`@`M````/A<"`!0```!L%P(`!P```($7`@`)````B1<"`!0```"3%P(`$0``
M`*@7`@`5````NA<"`!T```#0%P(`#@```.X7`@`5````_1<"`!(````3&`(`
M(0```"88`@`8````2!@"`!4```!A&`(`(P```'<8`@`0````FQ@"`"<```"L
M&`(`+P```-08`@`N````!!D"`!,````S&0(`%0```$<9`@`P````71D"`#``
M``".&0(`<````+\9`@`X````,!H"`"$```!I&@(`'````(L:`@`B````J!H"
M`"(```#+&@(`*0```.X:`@`S````&!L"`"T```!,&P(`(0```'H;`@`<````
MG!L"`"8```"Y&P(`6P```.`;`@`V````/!P"`"<```!S'`(`'P```)L<`@`?
M````NQP"`"<```#;'`(`'`````,=`@`*````(!T"``<````K'0(`"````#,=
M`@`(````/!T"`!,```!%'0(`#P```%D=`@`M````:1T"`!<```"7'0(`%0``
M`*\=`@`'````Q1T"``<```#-'0(`3P```-4=`@!)````)1X"`#X```!O'@(`
M9@```*X>`@`,````%1\"`#(````B'P(`,````%4?`@`)````AA\"`!<```"0
M'P(`!P```*@?`@`&````L!\"`$````"W'P(`!@```/@?`@`)````_Q\"``P`
M```)(`(`#P```!8@`@`-````)B`"`$`````T(`(`-````'4@`@`C````JB`"
M``X```#.(`(`+0```-T@`@`<````"R$"`#,````H(0(`*````%PA`@`R````
MA2$"`"@```"X(0(`#0```.$A`@`&````[R$"``\```#V(0(`$@````8B`@`5
M````&2("``<````O(@(`0@```#<B`@`*````>B("``D```"%(@(`"@```(\B
M`@`7````FB("``D```"R(@(`!P```+PB`@`2````Q"("``H```#7(@(`"0``
M`.(B`@`$````["("``<```#Q(@(`"````/DB`@`/`````B,"`!0````2(P(`
M%@```"<C`@`=````/B,"``T```!<(P(`!P```&HC`@`0````<B,"`!0```"#
M(P(`#P```)@C`@`2````J","``8```"[(P(`#0```,(C`@`8````T","`"@`
M``#I(P(`#@```!(D`@`?````(20"`"D```!!)`(`"0```&LD`@`+````=20"
M`!0```"!)`(`!P```)8D`@`$````GB0"`!\```"C)`(`2P```,,D`@`.````
M#R4"``X````>)0(`#0```"TE`@`(````.R4"``D```!$)0(`!@```$XE`@`)
M````524"``L```!?)0(`$P```&LE`@`(````?R4"`!@```"()0(`"P```*$E
M`@`'````K24"`!X```"U)0(`)@```-0E`@`,````^R4"``,````()@(`(0``
M``PF`@`'````+B8"``8````V)@(`=````#TF`@`*````LB8"``<```"])@(`
M)P```,4F`@`N````[28"`!X````<)P(`0````#LG`@`J````?"<"`!H```"G
M)P(`)@```,(G`@`E````Z2<"`"T````/*`(`1````#TH`@`I````@B@"`#T`
M``"L*`(`&P```.HH`@`6````!BD"``4````=*0(`!@```",I`@`)````*BD"
M``H````T*0(`"@```#\I`@`)````2BD"`!0```!4*0(`"P```&DI`@`*````
M=2D"``P```"`*0(`#````(TI`@`'````FBD"``@```"B*0(`"0```*LI`@`4
M````M2D"``L```#**0(`!@```-8I`@`%````W2D"``L```#C*0(`!@```.\I
M`@`F````]BD"`!@````=*@(`"@```#8J`@`6````02H"``L```!8*@(`%```
M`&0J`@`#````>2H"``L```!]*@(`(````(DJ`@`&````JBH"`!8```"Q*@(`
M!@```,@J`@`6````SRH"``8```#F*@(`&@```.TJ`@`+````""L"`!8````4
M*P(`!0```"LK`@`'````,2L"`!(````Y*P(`(````$PK`@`+````;2L"``T`
M``!Y*P(`+0```(<K`@`;````M2L"`!@```#1*P(`!0```.HK`@`-````\"L"
M`!0```#^*P(`%P```!,L`@`#````*RP"`!,````O+`(`"0```$,L`@`C````
M32P"`"D```!Q+`(`,P```)LL`@`E````SRP"`#0```#U+`(`)P```"HM`@!*
M````4BT"`"@```"=+0(`-````,8M`@`V````^RT"`#@````R+@(`+@```&LN
M`@!I````FBX"`!<````$+P(`9P```!PO`@!"````A"\"`"@```#'+P(`5```
M`/`O`@!N````13`"`"T```"T,`(`.P```.(P`@`H````'C$"`#,```!',0(`
M.````'LQ`@`N````M#$"`!L```#C,0(`-````/\Q`@#7`0``-#("`!\````,
M-`(`.0```"PT`@`7````9C0"`$H```!^-`(`=P```,DT`@`S````034"`"4`
M``!U-0(`00```)LU`@!<````W34"`%H````Z-@(`*@```)4V`@`C````P#8"
M`!8```#D-@(`*````/LV`@`=````)#<"`!H```!"-P(`+0```%TW`@`E````
MBS<"`"4```"Q-P(`.@```-<W`@`C````$C@"`!8````V.`(`.````$TX`@`E
M````AC@"`"H```"L.`(`+0```-<X`@`[````!3D"`!\```!!.0(`.````&$Y
M`@`!`0``FCD"`&T```"<.@(`,0````H[`@!"````/#L"`"X```!_.P(`)P``
M`*X[`@!`````UCL"`&,````7/`(`2````'L\`@!Q````Q#P"`"8````V/0(`
M-0```%T]`@`_````DST"`"D```#3/0(`'P```/T]`@`N````'3X"`"X```!,
M/@(`)@```'L^`@`P````HCX"`%\```#3/@(`;P```#,_`@`W````HS\"`%@`
M``#;/P(`60```#1``@`L````CD`"`"P```"[0`(`)0```.A``@`^````#D$"
M`"\```!-00(`-0```'U!`@`J````LT$"`"H```#>00(`+P````E"`@!K````
M.4("`'$```"E0@(`<0```!=#`@"Y````B4,"`!D```!#1`(`+P```%U$`@`P
M````C40"`"T```"^1`(`4@```.Q$`@`E````/T4"`%,```!E10(`*````+E%
M`@`B````XD4"``H````%1@(`V````!!&`@!8````Z48"`",```!"1P(`.@``
M`&9'`@`X````H4<"`"@```#:1P(`'@````-(`@!,````(D@"`#D```!O2`(`
M!````*E(`@`(````KD@"``0```"W2`(`&0```+Q(`@`/````UD@"``\```#F
M2`(`"P```/9(`@`&`````DD"``\````)20(`!````!E)`@!8````'DD"``0`
M``!W20(`%P```'Q)`@`$````E$D"``<```"920(`!@```*%)`@`%````J$D"
M``0```"N20(`%0```+-)`@`)````R4D"`!$```#320(`$P```.5)`@`#````
M^4D"``<```#]20(`!P````5*`@`2````#4H"``T````@2@(`%````"Y*`@`&
M````0TH"`!H```!*2@(`#0```&5*`@`#````<TH"`"L```!W2@(`!````*-*
M`@`&````J$H"``<```"O2@(`(0```+=*`@!`````V4H"`#$````:2P(`,@``
M`$Q+`@`;````?TL"`#(```";2P(`-0```,Y+`@`D````!$P"`",````I3`(`
M'@```$U,`@`D````;$P"`!\```"13`(`'0```+%,`@`E````STP"`",```#U
M3`(`0P```!E-`@`>````74T"`#0```!\30(`'````+%-`@`Q````SDT"`#(`
M````3@(`(0```#-.`@`E````54X"`"0```![3@(`'P```*!.`@`D````P$X"
M`"H```#E3@(`*````!!/`@`J````.4\"`"8```!D3P(`'P```(M/`@`B````
MJT\"`"L```#.3P(`'0```/I/`@`D````&%`"`"\````]4`(`,@```&U0`@`:
M````H%`"`"<```"[4`(`/````.-0`@`D````(%$"`"8```!%40(`)0```&Q1
M`@`F````DE$"`"````"Y40(`'@```-I1`@`G````^5$"`",````A4@(`+@``
M`$52`@`G````=%("`"X```"<4@(`"@```,M2`@`3````UE("`!8```#J4@(`
M,P````%3`@`F````-5,"``T```!<4P(`#P```&I3`@`6````>E,"``L```"1
M4P(`#@```)U3`@`L````K%,"``@```#94P(`#````.)3`@`G````[U,"`"H`
M```75`(`(````$)4`@`?````8U0"`!P```"#5`(`"````*!4`@#4````J50"
M``T```!^50(`'@```(Q5`@`6````JU4"``D```#"50(`#0```,Q5`@`1````
MVE4"`!````#L50(`'P```/U5`@`&````'58"`$L````D5@(`'````'!6`@`<
M````C58"``<```"J5@(`$@```+)6`@`,````Q58"`#8```#25@(`"`````E7
M`@`G````$E<"`!D````Z5P(`$@```%17`@`4````9U<"`#(```!\5P(`'P``
M`*]7`@`'````SU<"`!<```#75P(`"````.]7`@`)````^%<"`!0````"6`(`
M"P```!=8`@`;````(U@"``8````_6`(`*@```$98`@`(````<5@"`",```!Z
M6`(`*P```)Y8`@`'````RE@"`!<```#26`(`!P```.I8`@`(````\E@"``D`
M``#[6`(`/@````59`@`2````1%D"``8```!760(`$@```%Y9`@`4````<5D"
M``\```"&60(`"0```)99`@`*````H%D"``8```"K60(`$P```+)9`@`/````
MQED"``8```#660(`$@```-U9`@`A````\%D"`!(````26@(`)````"5:`@`9
M````2EH"`!4```!D6@(`#````'I:`@`.````AUH"`!H```"66@(`!P```+%:
M`@`M````N5H"``P```#G6@(`#P```/1:`@`'````!%L"``,````,6P(`$0``
M`!!;`@`<````(EL"``L````_6P(``P```$M;`@`(````3UL"``X```!86P(`
M#````&=;`@`)````=%L"``\```!^6P(`#0```(Y;`@`6````G%L"`!<```"S
M6P(`$````,M;`@`O````W%L"`!T````,7`(`'````"I<`@`:````1UP"``L`
M``!B7`(`,````&Y<`@`'````GUP"`!<```"G7`(`10```+]<`@`1````!5T"
M`!(````770(`"````"I=`@`$````,UT"``4````X70(`$0```#Y=`@`:````
M4%T"``8```!K70(`!P```')=`@`)````>ET"`!````"$70(`"````)5=`@`2
M````GET"`!(```"Q70(`$````,1=`@`.````U5T"``T```#D70(`$@```/)=
M`@`2````!5X"`$4````87@(`-@```%Y>`@`I````E5X"``4```"_7@(`&0``
M`,5>`@`D````WUX"`"(````$7P(`*````"=?`@`0````4%\"``(```!A7P(`
M!````&1?`@`+````:5\"``H```!U7P(`!0```(!?`@`#````AE\"`!````"*
M7P(`3P```)M?`@`S````ZU\"`#T````?8`(`&@```%U@`@`K````>&`"`"\`
M``"D8`(`4P```-1@`@`T````*&$"`#,```!=80(`+P```)%A`@`6````P6$"
M`(4```#880(`)````%YB`@!"````@V("`"4```#&8@(`1P```.QB`@`K````
M-&,"`#8```!@8P(`*@```)=C`@`S````PF,"`#0```#V8P(`+````"MD`@`N
M````6&0"`"X```"'9`(`,````+9D`@`P````YV0"`"T````890(`,@```$9E
M`@`T````>64"`#8```"N90(`-P```.5E`@`6````'68"`"`````T9@(`$```
M`%5F`@!\````9F8"``@```#C9@(`<````.QF`@!R````76<"`(````#09P(`
M)@```%%H`@!>````>&@"`!<```#7:`(`,0```.]H`@`C````(6D"`!8```!%
M:0(`$@```%QI`@`4````;VD"`!P```"$:0(`0````*%I`@`>````XFD"`!D`
M```!:@(`4````!MJ`@`2````;&H"`!@```!_:@(`"@```)AJ`@`%````HVH"
M``8```"I:@(`"````+!J`@`%````N6H"`!8```"_:@(`%P```-9J`@`6````
M[FH"`"$````%:P(`$````"=K`@`+````.&L"``X```!$:P(`!P```%-K`@`$
M````6VL"`!````!@:P(`"0```'%K`@`(````>VL"``\```"$:P(`!P```)1K
M`@`&````G&L"`!H```"C:P(`$@```+YK`@`%````T6L"``D```#7:P(`#```
M`.%K`@`0````[FL"`!L```#_:P(`#0```!ML`@`'````*6P"``L````Q;`(`
M$````#UL`@`4````3FP"``H```!C;`(`"P```&YL`@`:````>FP"``D```"5
M;`(`%0```)]L`@`5````M6P"``8```#+;`(`!0```-)L`@`C````V&P"`!D`
M``#\;`(`"P```!9M`@`C````(FT"`!0```!&;0(`#````%MM`@`,````:&T"
M``P```!U;0(`#````()M`@`K````CVT"`!D```"[;0(`!@```-5M`@`7````
MW&T"``4```#T;0(`!P```/IM`@`;`````FX"``4````>;@(``@```"1N`@`"
M````)VX"`!L````J;@(`"````$9N`@`+````3VX"`!4```!;;@(`&````'%N
M`@`'````BFX"`#,```"2;@(``@```,9N`@`$````R6X"``X```#.;@(`!P``
M`-UN`@`0````Y6X"`!8```#V;@(`#@````UO`@`+````'&\"``D````H;P(`
M!@```#)O`@`8````.6\"``@```!2;P(`%````%MO`@`1````<&\"`!(```""
M;P(``@```)5O`@`'````F&\"``\```"@;P(`$````+!O`@`0````P6\"`!H`
M``#2;P(`)P```.UO`@`L````%7`"``D```!"<`(`"````$QP`@`2````57`"
M``4```!H<`(``@```&YP`@`+````<7`"``$`````````=08``(@&````````
M``````````#+`P``<`<``&@'``#J!````````.H!``![!```2@0``!D!``#*
M`0``-@@```````#L!@``.`0``)\"``"@!```,P```````````````08``/P!
M``#X`P``O`0``%T!````````N@0``)@&``#W!````````.@$``#0`0``Y08`
M`-H&```5`0``I`````@```"Y````H@(``/$$`````````````(L(``"9`0``
M`````,$````6`0``?@,``"X'`````````````,(#``!!!```"P8``-``````
M````KP(``&D(``#'!```:`8``&(!```J`@``4@8``(P(```R"````````-H#
M``#`!````````$T(``"*`0``````````````````<P(``.0```#+!0``6`4`
M`"8$```[`P``>@8``%0%```&`P``3`<``,0#``"O!0``:0$``"`$````````
MK@(``%X(`````````````#L$``#<`P``)`4``'8$````````8`4``($"``!!
M`@`````````````F````6@(``-@&```:`@```````#T$```&"```Z0<`````
M``!`"```4@$``-8%``!Z`P``\P4```H&``#]!0``P@4``#`(``#B`P``RP(`
M``0!````````J@4``"\%``!U`@``W08``)(#``!R"```.@$```````#D`0``
M[P$``"\```"3!0``50(``$\%```/"```800```0$```M"```1@4``,,$````
M``````````````!$!0``BP,``$D&``!_`@``=`@```````#_!0``````````
M``!Z`@``C@8```````"8!0``8P,```X'```[!P``G@```&P'````````````
M`"(#````````H`4``+D&````````(08``.0&``#^`P``````````````````
MCP````````"L`0``-@4``/H'``"R`0``F08``'8&````````\@$``(D"````
M````2@(```("``"'!0``)P(```\$``!K!```P`,``#`#```0`P```````'H%
M```W!0``?@(``+`&`````````````((%`````````````+X$``!<!```ZP,`
M`/H#``#"`0``]@8`````````````&@@``(<!```1!P``(0```!P```!I!0``
MW0<``&D#``!D!@````````8'``!T!0``O0(``#D#```5!```8`$``!`%```_
M!@``F0,``#T(``!L!0```````)T%``"U````DP<```0```!\`@``S`4``/T&
M``#6`0`````````````8!`````````````#(!P``F@$``%<'``"X````/P@`
M``````#X`@```````(4'``!Q!@``,@<```````#)!P``*04````````.`0``
MR````/P"```D`@````````````#*!@``N0,`````````````%@<``%D"``"#
M"```4@4``#4#``#&`@``6@@````````I`0```````'P#``"0!```%@@`````
M``#)````O@```!0$```;"```A04``&4!````````&04``,4```#C`P``^0<`
M`"H%````````0P<``#$"``!["````````#@```"T`P``?0(``"0&````````
M4P8```````!)`@``J`8``-(&``!/!@``XP$``#````#F!P``````````````
M````Q`4``#@%````````G`<````````H!```T@0``%\&``#*!P``````````
M`````````````(0&``!]`0``RP0``%D$````````XP<``*8#```#`0``?P$`
M`'<```#0`@``9P(``*T```"A`@``1@@```\&````````A0@``&T%```#`@``
M/````!$"```J!@``UP,``-\#````````!`8``/<&```S`P``@P,``#`'``",
M`@```P8``````````````````($(````````]00``$,%``"F!0``\P8``#$`
M``!"`0``ZP<``+0!``!J!0``5P@``,,```"B!```QP`````````R!```(0@`
M``````!U!P``O@4```````"Z`````````(<"````````<`8``%H#``![!0``
M`````%$$``"*!```(`4``+D"``"7````0@0``'P$``#V!0``:P,``%D!```B
M!@``(P,``!4```"U!P``O@(```4%``"<!0``KP,```(```!0`0``Q08``%\%
M``!7`@``M@4``/(&``!V`````````"D$``!*`0``0P,````````2"```R`$`
M`&X!``!1!0```````#H```"3````9@<``(T!```C!@``7`@``+\"````````
MT@```#D%`````````````)P```#Q`P``C0@``&\```!6"```EP8``'P```#@
M!0```````,H#```?`@`````````$``#H!@``SP8````#``"[!@```````/@%
M``!_!``````````````<`0```P4```D(``!(!@``X04```<#``"%`P``0P``
M```````;````````````````````:P$```````"8`@``TP,`````````````
MS00```````"8`0``HP,``!@#``!3````\`$``%8%````````/`8``#(```#,
M`P``FP8``%L```#>`P```````*4"```L!P``0`$```````#.`0``````````
M``"&`P``6````"$!``"G`0````````````"&````$P,`````````````````
M`),!````````@00```````"D!@```````.T````+`P``]@<`````````````
M:@,``(8%````````E@0```````"Q````Y@$``(\#``"Z`P````````````#<
M!```Y@``````````````.00``(X#``!2````9@```&("``"0`0``B@(``'D(
M``".!P``A`4``,,'````````90@````````W`P``OP$``+($``!9!P``Y`(`
M`!D(``#?!@```````#(&``"+!P```````+X!``"7`P``_@8``!H'``!I!@``
M7P@```````#6!P``SP0``$P%``#.`@``!@```%T'```U`0``M`<``-$#````
M````[`0``&4%```7!@``+P@``!0%``!N`````````!8%``">!```<0<``-4%
M````````0P8``%H$``#H!0```````.0#``"N`0``B@8``&,$``"S`0``=00`
M`&D$``#&````90<``!@'``#+!@``I00``#T#````````#0@`````````````
MUP8``+T$```[````]`(```((``!)!````````"($```7"```$@(``,(&``"Y
M`0``708```\"``!9!@``H08``.("``#[!0``M04``-@```"J`@``=04``$D(
M```F"```!P@``-0'``""!````````)X"```P`@``\0<``'("``"Z`@``<P4`
M``````""!P``;0<``(H```!)!P``M@8``*$`````````;P4```````#8`0``
M`````"X(`````````````%D#````````D@4```````"F!```'P8``%<$``"1
M`0````````````"5````'`<```````!3"```Z@(`````````````;`8``'X(
M````````60````L!```Z`P``,@,``-L%``!6!```>08``#D"``![!@``3P``
M``````"-````U0(``$L&```<"````````(@$``!A!@``L`4```P```#H`@``
MMP0```````#3!```K`(``&T&``"`!````````*\'````````3@8``)\%``!Q
M````'0@``/0'`````````````"P````Z!````````(4"```3`@``G00`````
M``#5!```B04```````!<`0```````````````````````)T'``#\!0``CP<`
M``````#?`0``;`$```````![`````````/T'``"Z!0``2P<``.`"``#<!@``
M5P```"X!``![`@````(``+L!```F`P``R@4```````!6````:`0``'$(``!]
M!P``,@4``-T"``!Q`0``M`(``!L$``!.````$`$``)0```"M!P```````-@'
M``!X````U0<``%L(``!)!0``Z0(``)L```!B!0``]P(`````````````*`8`
M`$D!``#L`P``;@0``$P#``!,"```!`@``&(&``#0!```O0````\!``!^````
MY0$```````#Q`@````````````!1````0@<``)4#````````[`4```````"8
M!``````````````[`@```````)D"``!T!```B@,``,8!``"0!P``````````
M````````P00``*P#```'!0``(@$``+$!````````4`0``"X$````````````
M`&\#```3!```)0<``*X#```````````````````R`@``U08```````!S!@``
M``````````#O`P``H0<```0#````````V@```/\"````````P`4``&$`````
M````80$```<!``#G!P```````*\&``"*!P``'@<``"@!``"]!P```````&<`
M```.````>`<`````````````:P(``#0```!C!P``%0,``'(&````````````
M`,X&````````IP(```````#^`@``&@8``/T!``""`@``.0<``%<%````````
M_@```/(%``"C````8`8``-D!``!8!````````)("``#;````@````"0$```8
M!@```````!4%```V!```%P(``$\$``"C`0``9`0``.,"``#6`P``H00`````
M``"@!P``*`4```````"4`@``)`@`````````````X0<```````"P`@``\0$`
M`.(```"/!0```````!L!```O`@``C`0``($!```4```````````````2!```
M;0(``!<#``!H`@``2`@``*<`````````C````/8````D`0```````!D`````
M````<@$``-8$``"'`P```````&8!```8````*P```/\```#!!0``C@4`````
M``#[`@``.0```!T$````````P`8``"`(``!8`0```````),"``#R!```OP8`
M`.<$``"!!0``T@4``%L$``#Z!```80,``#0%``!6!P``O`8``'``````````
M`````$T"````````.P@``&0%``#N!0```````&H``````````0$``$L```!U
M`0```````&@#``!T````>`@``$@"``"F````300```````#$!P``0@@``/`&
M``"J``````````````````````````$#`````````````$,$````````7`(`
M`&D'```G`P``&0<``"L"``!4!P``50$``$8#``"Z!@``[@0```````"I!P``
M\P,``)<!``!)````%@8```````#&`P``)P@``!\(```W!P``PP8``-X&``!Q
M`@``;0```'`(``#8!0``]@,``/L'``#]`@```````!$&```4!P``X`$``+\`
M``"W!@```````*@'``#I`P```````!(```#]!```]`8``(8'````````^P0`
M`*H!```X!@```````/4#``#N!P``'@0``'P(```W````PP,``*@"```(!@``
M(0,``$L$``!$`P``S@<``(0#``"$!```(P4```````!_"````````-T```#K
M!0``N`$``!4&``#W!P```````&\!``!G!@``FP,``"((``"@`0``.@8``)$&
M``"P!P``;P<``','``"2`0```````-D#``!_!@``:@0``#X!``!%`P``-0<`
M`&$(``!E`@``#0,``'X&```;!0``:P@``'X'````````$P@````'``"<!@``
M`````$X!````````T0$``-\$``"?!```(`8```````!8`P``W@(```````#?
M!P``"@4``)D%``!1`@``E0(``/8"```G!P``F0``````````````J`4``'<(
M````````!@8```````!$`0``;00```````"^!@``>0````````#_!```U0``
M`-X'```0"```508``!@%``#[`P``>`(``"4(````````3`````````#,!```
MVP0``!`"````````.`(```````"+`@``2@@``$`%``#,!P``E@,``)`%``!(
M!P````````````#4`P```````*@!``#(`P```````$<"``#Y````,`$``,D!
M```A!```>`,``#H'````````70@``*,$``",!@``^0$`````````````N`<`
M``P!``"E`0``=P,````````U`@```````.H#```2`0``9`<```````"""```
MI`4``$(`````````WP````````!_`P``T00``"H!``"V!P````````````!$
M!P```````'<"``"S`@```````)\&``"W!P``'0<``/,"````````+P$``"P&
M``#"!```-08``/`"``#M!0``S0(`````````````AP@```````!W`0``````
M``````!S`P``H04```````!1"```!0,``/("```0!@`````````````1!```
M```````````=`0``"`@```````#&!P``X````$4"````````[@8``/,```"D
M!P``````````````````E`$``````````````````,D"``"O!```<@<``!4'
M`````````````!(&``"W`P````````,```"'!P```0@``+4#``"(!0``M00`
M`&,(````````W00``(,$``"1````X0$``)0%```L"````````-$```#T`P``
M)@4``-("``!%!P``4`8```````!R`P``O04```````"T!@```````',(```"
M`0``N@$``#,(``"`!P``FP4`````````````MP```.$"``#J`````````.\'
M```M!@``T`,````````(`P``'@$```````#4!```)P4``#<&``!]"```/`0`
M``````"Q!@``^`<``'(%```?`P``S0```-('````````4@0``(L!``"W!0``
MS08``-T#``#%!P```````)$$```L`@``!P(``!(%``"G`P``@@,``.0%```6
M!````````+T#```G````D@0`````````````LP```.L!``#R````1@(``#T'
M``!5````.`$``-<```"]!@``H@4``&`$``#[````B00``*$#````````````
M`#$&``!6!@``)0````````!U`P``>04``$H`````````(@(``(X`````````
M`````&(`````````%`8`````````````<@0```````"L!0``#0(```````!?
M`@```````&<%``!*!0``Z`<``+8```#8`P``XP4````````R`0```````"('
M``#P`P``2`,``$`"``!1!@``E@(``&,````````````````````J!```````
M`'8!``#=!0```````&@%````````)P8```````````````````````"O````
M5P8``(P!```+"```,P$``"@'``#"`@``304``.@`````````I0```!L'````
M`````````(,`````````FP<``'T%``#"!P```````)H$```,!0``9`$``'0"
M``!Y`P``,P4```T`````````[`(``/H%`````````````+@$```?`0``9@,`
M``L'``!7`P``#P<``"H'``!A`@``0`,```$"`````````````,T'```"!P``
M`````/4`````````_`8```````!_!P``(P(``*P$````````1`8``+P'``#L
M`0```````&`#````````5@,``%0&```<!0``A`@``#\#`````````````*0$
M``#R!P``-@8``%0"``!#"```'@,```````#<`0``+0```#$$````````/@8`
M````````````$P````````#X````#@,```H!``````````````````#P!0``
M)`<``)(&```<!@``K@0``/0$``#L!P``V@$```````#,````6@8``$8&``"6
M!@``70(``/P'``"M!0````````````#E!P``1P0``+\'```'````@P$`````
M```^!P``&@```*0"``!>!````````(H(``#,!@``'@4``&D"````````J@<`
M`,$&``!_````YP$``+8#````````^0(``'<$``![!P```````,T!```)````
M!00``$T!``#*`````````'T$``#F!@```````$\!```&`0``E`8``%H'````
M````1P@``.T$```%!@``R@0``.D$``!K````+`,``%0`````````>@0``#D(
M```V````*08````````V`@``C`<``.8"``"#!0``.P8``,4$``#9!P``````
M```````1`P``R04``%T%``"Q!0```````"4$``#-`P``8````#,"```S!P``
M``````(%``#[!@``C04``&\&```)!0``JP4``*T$``#S!````````.,$``!K
M!0``````````````````D@```,,!``!H`````````.X#``"E`P``$P4``&L'
M```,"```J0$``&@!``!4`0``T0(``#,$```N````'`,``%('```8`0``,0@`
M`%<!```!!0``B`@```P&`````````````-X$````````*P@``/D&````````
M`````"P!``"0````NP(```````#\!```6`(```````#'!0``>`8``$T#``#\
M````<@`````````V`P``J`,``,$"````````R0,````````A!P``4P,``"`'
M```@`P````````X(```O`P````````X$`````````````,0&```H`P``4`<`
M``````#(!0``WP4```<$```W`@``G0$``%T#```_`@``3`(``-H"``#O!0``
M#P4```````"J!@``1P$``"8!````````700``&@(``!0"```O`4````````U
M"```_P$````````*`P``F`<``````````````````!\$``!?!P``````````
M``#'!@``X00``!8"``!W!0``<`4``)X!``!*`P``5@(``!T```"-!P``1P<`
M`%((``!P!```HP4``!(#``"R!@``?0``````````````*`(```````#``0``
M8P4```````"7`@````````````"[!P``H@8``-L'```"`P``#@4```````!$
M!```J`````````"M!@```````)H%``````````````````!J!P``S@,``*H$
M````````@08``%\#``#'`P``/P$``&P(``"7!P```````/X$``!3!```IP8`
M`)8````U!`````````````#W`0``N`(``+$$``!F!```UP$```T%```_!0``
M>`$```````#6`@```````#D!```8"```Y`0``%(#``"I`@```````#X%```N
M`P```````!D$``"F!P``#`<``.\````\!P```````-L!````````*0@```@'
M````````7`,``$0(`````````````&$'```G`0```````&<$``!/!P``=@@`
M```````H````%@,````````=`@``-P$```@"``!3`0``4@(``,\%````````
MD@<``)<$``"<`0``#`(```````"K`@``X0,``-(#``#U!@``)04```````"B
M!P``-`,``,\'```)`@``7@```-4!``#X!`````$```````!S`0``````````
M``#^`0``L0<``,L```!:`````````)0#````````\`0``)T```"?!P``EP4`
M``````!N`@``;@8``)P$``#V!```@0,````````&!0``%P$``(\"```*`@``
M/@(``/<#``#D!P``O`````````!X!0```````"@(```Y!@``40,``.,````F
M!P``6@4``+0%``",!0``:@$``"``````````$@<``!T#``!M`P```````$4&
M``"?`0``DP8````````L!0```P,```````#``@``````````````````;`(`
M`!<````D````;0@``-D%``````````````````"@!@``-@<``$8!````!0``
M``````````#S`0`````````````E`P```````)4'```1!0``ZP```&8"``!!
M````VP,``"T!```<`@``@`@``#T"````````@P(````````N!0``L````#0"
M````````S@```$<#``"T````00@``'L!````````GP```!X`````````````
M`'P'``".`0```````(4$``")!P```````)4!```]`0``0P$``#P"````````
M3@<`````````````$`<``*4&``"3!```:@8``!T%``#7`@``AP0```````!Y
M!```MP(``)8!````````#00``$@!``#/````N0<``'`#``#'`0``ZP(``+$"
M`````````P<```````!@"```2```````````````H@$`````````````=@<`
M`.D&```7!0``NP4``/4'```G!```P````+T!``"K`````````(H%````````
MA@(```````!M`0``8@,````````Z"```:P8```$$``!+"```%P<``$X%``";
M!```8@@`````````````00<````````Z!0``Y@4``%\$````````^00``/4!
M``!W!P````````````!T`P``C0,``.8#``#E`P``XP8```\#``!*!@``Z@4`
M`.L&``"\`@```````%4#``!6`0```````(`"````````9P,````````B!0``
M<04``#P!```?````(P$``,4%``!Z`0```````(<&````````?`8```````#=
M`0``?`4``+0$```9`@```````*8&```B````N`8``&<(````````````````
M``"\`0``%`,````````(`0``````````````````/P<``)@`````````````
M`&8(`````````````/4%```M`@```````.4%``"C`@``H@,``%`"``#`!P``
M`````",(``#<!0``1`````````!'!0``7@$``)P"``#^!0``T@$```````"$
M`0`````````````.!@``S04``+8!``#B!0``@@8``#X#```%"```+0<`````
M``!;!P``<P```(L$``#6```````````````+!````````*T"````````<`$`
M`.(!``":!@``JP$``#L!``#Q````Q`0``%@'``"?`P``Z`,``(`!``!-````
M``````H(``":`@``R@(```\```!%!0````````````#,`@``[@``````````
M`````````"D#````````.`@``$X$``!-!@``-`<````````^"```'P<```T'
M````````!0(``)4&````````A@0````````5"````````.\$``""`0``````
M``````#Q!0```````"4!````````$0$``*(`````````LP8``*L&````````
M0`0``$L#``"0`@````````4```"'`````````#X```"H!```'08``*<%``#]
M`P``DP,``$X(``#Y!0``#0$``%L"``#Q!@``5`@``.<```!O!```H````$4!
M``#3!P``"0,``-0%``"1!0``!`(``(D`````````D0(```````"L````F0<`
M`*H#``#>````00,``*P&``"F`@``900```````````````````````!Y!P``
MA08``&X%`````````````!0(````````7@4``"T$```,`P````````(&```,
M!````````!$```!=`````````)L"``!.`@``$P<``/L!``!!!@``^`$``",$
M``!(!`````````````##`@```````#4```!0!0``TP````````#Z````M0(`
M``````".!```9````,<"```J`````````+L#````````>@<```L%``"+!0``
ME`0``!4"``"I!@```0<````````K`0``'P4``$8$````````YP8``*L$``"+
M`````````-0!``!E`P``-`0```D!``#3`0``[0,`````````````_P8`````
M`````````````#0(``"(`P```````,0``````````````)T#``#3!@``Z@8`
M`(`&````````&P,``&H(```+`@``20,``)H'```K!@````````4'````````
M`````"\&``"M`P``E00``/4"``!/`@```````"0#````````>0(``+\%``"R
M!0``B08``$L"```'!P``C0(``)H#``#T````Z`$``$P!``!@!P``*0``````
M```)!```NP```,X$````````0P(``(L&``!`!P```````'0!``#B!@``````
M`#$%``!,!@``!`<``/D#``"W`0``VP(``%,"``"8`P``7@,``$8'``"#!P``
M`````$``````````X`8```X"````````````````````````K@<``.4$``"R
M`@``+P<``#@#``!`!@``.@(``#$'````````K`<``/8!``")`0``I`,`````
M`````````````*L#````````5`0``.`'``"&"```)@8``/\#```W"```&`(`
M`(4``````````````%L%``#<````A@8``-,%``!D"``````````````P!@``
M-@$``)X'``#/`P``'@8``&8&``#_!P``+0,``-D`````````%@```,D$````
M````E@<``%````#F!```;@,``&P```!U`````````-X!``!^!```````````
M```>`@```````'<&````````^`8``&,&``#:!P``SP$```````"V`@``X`,`
M`````````````````$$%``!A!0``LP4``!`$````````\P<``-@$``"#!@``
M_`,```````!"!0``6`8```8"```M!0``;@@``$H'```(!0``[P(``*X&````
M!@``0@(``*D#````````6@$``/X'```_````7````"X&``!O`@```````#T`
M``#G!0```````````````````````%L!````````S@4``)8%``"I!```@@``
M`-$'````````Z04``(@"``#A!@``]`$``-L&``#M!P``K@```#0&````````
M`@0``&4```!$`@``CP8``,4!````````(`$```````"$````J0```)X%``"$
M`@``2P$``$4```#M`0````````````!N!P``E04``%4(``#9!`````````4!
M```-!@``(04``(D(`````````````,0!``!_!0``1@```#0!``#4````YP,`
M`,$#``!/`P``LP0``+\$```J`P``\````-\"``!P`@``$0@````````*!P``
M`````!L&````````.`<``/T`````````A`<```````!"!@``X0```&,"``##
M!0``>@```-,"``#%`P``Y0```%@(``"R````R`8``&\(``#$`@``=0@`````
M``!\`0``+@(``,$'``"R`P````````````"(!P```````+`#````````````
M`/(#``!!`0```````/<```!]!@``6P8``-0"``#N`0``UP4``+L$````````
M@0<``#L%````````U@8```````````````````,$```@`@``E`<``&`"``"S
M!P``RP<``,$!```P!````````'H(````````OP,`````````````"P```'D!
M```#"```4`,```````#G`@``R08``#T&``!5!0```````,@"``!E!@``X`0`
M`)T"``#P!P``L`0``+('``"Z!P```````&<!`````````````*<$``!9!0``
M*P<```H`````"```^@8````````4`@``O@,``+X'``"@`P``M@0```````"&
M`0`````````````9!@````````````!(!0``U`8``,4"````````[P8``*T!
M``"0`P``W`(``"4"``!>!@``>`0``%X'``!B!P``"0<`````````````*0<`
M```````K!0``LP,``!H#``#<!P``````````````````G@,``#\$``#7!P``
M,`4```````"1`P``)@(```````")`P``9`,``+P#````````*P,````````\
M"````````!H$``#>!0```````'T#``!?`0``,P8```0%``!^!0``<0,``&,!
M``#8`@```````.P```!<!@``&@$``!P$``#M!@```````.4"``"Q`P``*@@`
M`%P%``#,`0``X@0```````"P`0``````````````````]`4```@$``"`!0``
M^@(``"L$``"C!P```````.T"````````?@$``)H`````````C08````````3
M!@``UP0``%4$``!F!0``3`0``&0"``!9"```T08``)T&``"/`0``]P4``#4%
M``#1!0``R`0``+4!````````[@(``$(#````````@`,``($`````````Q@8`
M`)$'`````````````.D`````````=`<``.D!````````(0(``"\$``#5`P``
M/04``)`&``"9!```QP<```````#0!0```````*,&````````V0(``#$#```I
M`@```````+4&````````Q@4`````````````40$``%P'``!V!0``7P``````
M````````=`8``&H"``#Z`0``"@0```````!'````'@@``%L#``#/`@``/`4`
M``````!Q!```&@4``(T$``!B!```K@4``!0!``!4`P``%P0``.('``"@`@``
M50<``$<&`````````````!,!``"E!0``J04``(4!``!3!P```````+@%``"Y
M!0``V@4```````"(`0``3@,``(P#````````G`,``"4&``#0!P``"08``-`&
M``#+`0``I`$``$\(``!1!P``4P4``*4'``".`@``<P0``$4$````````P@``
M`$4(````````JP<``#<$```\`P```````$L%``!>`@``CP0`````````````
M=@(``!L"```````````````````0````V08``&D```![`P``ZP0```````!-
M!P``G@8```<&``!G!P``&0,``"P$``!V`P``(P<```````#J!P``(P``````
M````````N`,``*<'``"(````N00``*$!``!L!````````#$!``";`0``/@0`
M``````!L`P``KP$```````"F`0``!@0``,8$``#:!````"`H)7,@9&%Y<R!A
M9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H
M=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@061D(&%N($E-4U`@061D<F5S<R!"
M;V]K`"!$96QE=&4@24U34"!!9&1R97-S($)O;VL`(&%T(``B)7,B(&%L<F5A
M9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM<&]R=&5D+@`B)7,B(&ES(&YO="!A
M(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@
M:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B
M('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET
M(&ES(&$@;&ES="X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`B)7,B('=A
M<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI<W0N`")&:7)S=&YA;64@
M3&%S=&YA;64B("`H:64N($IO:&X@1&]E*0`B3&%S=&YA;64L($9I<G-T;F%M
M92(@*&EE+B!$;V4L($IO:&XI`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO
M=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@
M<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E
M`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M
M<R!O9B!!9W)E96UE;G0`)7,@861D960N`"5S(&%L<F5A9'D@97AI<W1S+@`E
M<R!A="`E<R`E<P`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES
M(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O
M9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T
M97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA
M>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F
M(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H
M92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S
M=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`
M,C0@:&]U<G,`/%!R979I;W5S`$$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&
M<F%M97,@:7,@<F5Q=6ER960`02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E
M9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF
M>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S
M<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN
M`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U
M="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8F]V92!S96%R8V@@9F]R;0!!8G-B
M;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I
M<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C
M97-S(&1E;FEE9"!T;R`E<P!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@
M4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#
M:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D
M($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O
M=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D
M(&$@;F5W('5S97(Z`$%D9"!A9&1R97-S(&)O;VL`061D(&%N9"!$96QE=&4@
M24U34"!A9&1R97-S(&)O;VMS`$%D9"!C;VQU;6X`061D(&9I;&4`061D(&YE
M=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<@!!9&0@=&\`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O
M(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S
M>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN
M9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA
M8FQE+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S
M<R!";V]K`$%D9')E<W,@0F]O:R!,:7-T:6YG`$%D9')E<W,@0F]O:W,`061D
M<F5S<R!B;V]K(&5N=')Y`$%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R
M9V5D+@!!9&1R97-S(&)O;VL@=&\@9&5L971E(`!!9&1R97-S(&)O;VMS('1H
M870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.@!!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`
M061V86YC960@4V5A<F-H`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!
M;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5
M<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E
M<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!%>&ES=',`06QR96%D>2!E>&ES
M=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O
M<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D
M9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE
M<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!
M;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT
M:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T
M`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`
M07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W
M<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO
M=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/P!!<F4@>6]U('-U
M<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N=')I
M97,_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D
M96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE
M;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;F1I;F<`
M07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO
M;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L
M:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA
M=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K
M<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E
M<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE
M;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z
M`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N
M9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U
M<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I
M`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)A<VEC(%-E87)C:`!"96QA<G5S
M`$)E;&=I=6T`0F5L:7IE`$)E;&]W('-E87)C:"!F;W)M`$)E;FEN`$)E<FUU
M9&$`0FAU=&%N`$)I;F0@9F%I;&5D.B`H)7,I("5S`$)I<G1H9&%Y`$)L;V-K
M("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E
M='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D
M97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE
M9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A
M>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<F]W<V4`0G)U
M;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA
M($9A<V\`0G5R=6YD:0!"=7-I;F5S<R!#871E9V]R>0!#35,`0U)#`$-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S`$-35@!#7V5L;"!0<F]P97)T:65S+BXN`$-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M
M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W
M<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF
M+@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N
M`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@
M9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E
M<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E
M(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T
M:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA
M;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`
M0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I
M8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@
M1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE
M<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R
M`$-H96-?:R!,:6YK+BXN`$-H96-K(%]!;&PO3F]N90!#:&EL90!#:&EN80!#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!N86UE`$-H
M;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A
M9&1R97-S(&)O;VL`0VAO;W-E(&%N(&%D9')E<W,@8F]O:SH`0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF
M;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@
M=&\@9&ES<&QA>2P@86YD(&EN('=H870@;W)D97(Z`$-H;V]S92!W:&EC:"!A
M9&1R97-S(&)O;VMS('1O('5S92X`0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@
M9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CH`0VAR:7-T;6%S($ES;&%N9`!#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@
M35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`
M0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC
M:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O
M=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@
M27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O
M;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O
M;',Z`$-O;'5M;B!/<'1I;VYS`$-O;'5M;B!T:71L97,`0V]L=6UN<R!T:&%T
M('=I;&P@;F]T(&)E(&1I<W!L87EE9#H`0V]M:6-S`$-O;6UA('-E<&%R871E
M9"!V86QU97,`0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U
M=&QO;VLI`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP86YY($%D9')E<W,`0V]M<'5T97)S
M`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC
M97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T
M<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@
M9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@9F%I;&5D
M.B`E<P!#;VYN96-T:6]N(&9A:6QU<F4`0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T(%-E87)C:`!#;VYT
M86-T<P!#;VYT86-T<R!I;B!L:7-T.B`E<P!#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T
M>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N
M=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E
M<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV
M;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O
M('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T
M(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@
M<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES
M="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T
M86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@
M;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@
M;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N
M;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V
M97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P
M9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U
M<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`
M0W)E871E($%D9')E<W,@0F]O:P!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE
M=R!#;VYT86-T($QI<W0@:6XZ`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U
M8B!F;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@
M8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R
M<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R
M<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ
M(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L
M;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC
M("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E
M+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T
M86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO
M;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S
M`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L
M="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9F%U;'0@<V]R=&EN9R!D:7)E
M8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@061D<F5S<R!";V]K
M`$1E;&5T92!#96QL`$1E;&5T92!#;VYF:7)M871I;VX`1&5L971E($=R;W5P
M`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G
M92!M97-S86=E<P!$96QE=&4@8G5T=&]N(&)E:&%V:6]U<@!$96QE=&4@8V5L
M;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4`1&5L971E(&9A:6QE9#H@*"5S*2`E<P!$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T
M:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B
M)7,B+@!$96QE=&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+@!$96QE
M=&EO;B!F86EL960`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<&%R=&UE;G0`
M1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M
M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P
M;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H
M="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y;W4@
M=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@=&AE(&9I
M<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C
M:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T
M(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@
M)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="X`1&]W;FQO860@=D-A<F0`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-
M86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S
M('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET
M`$5D:70@(B5S(@!%9&ET($%D9')E<W,@0F]O:W,`161I="!";&]C:P!%9&ET
M($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@96YT<GD@9F]R("5S`$5D:70@;W!T
M:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M
M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L
M96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM
M=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y
M(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@
M161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I
M;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E
M<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z
M`$5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E
M9"!F:6QE(&9A:6QE9#H@)7,`16YT<GD@9F]R("5S('5P9&%T960N`$5Q=6%T
M;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@861D:6YG("5D(&-O
M;G1A8W0H<RD@=&\@;&ES="X`17)R;W(@861D:6YG("5D(&]F("5D(')E<75E
M<W1E9"!C;VYT86-T*',I('1O(&QI<W0N`$5R<F]R(&-R96%T:6YG(&)L;V-K
M.B`E<P!%<G)O<B!D96QE=&EN9R`E9"!C;VYT86-T*',I+@!%<G)O<B!D96QE
M=&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C=',H<RDN`$5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO
M9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!R96UO=FEN
M9R`E9"!C;VYT86-T*',I(&9R;VT@;&ES="X`17)R;W(@<F5M;W9I;F<@)60@
M;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+@!%<G)O<B!S
M96%R8VAI;F<@=&AE(&%D9')E<W,@8F]O:SH@)7,`17)R;W(@=7!D871I;F<@
M<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@
M=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`
M179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C
M;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A
M;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@
M=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X
M<&]N96YT`$5X<&]R=`!%>'!O<G0@061D<F5S<R!";V]K`$5X<&]R="!O;FQY
M('1H92!S96QE8W1E9"!C;VYT86-T<RX`17AP;W)T('1H92!F;VQL;W=I;F<@
M861D<F5S<R!B;V]K(&-O;7!L971E;'DN`$9'($-O;&]R`$944"!U<&QO860@
M;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE
M9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,`1F%I;&5D('1O(&%D
M9"`E<R!T;R`E<SH@)7,`1F%I;&5D('1O(&)R;W=S92!L:7-T`$9A:6QE9"!T
M;R!B<F]W<V4@=&AE(&1I<F5C=&]R>0!&86EL960@=&\@8VAA;F=E(&YA;64Z
M("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@/2`E<RP@4F]O="`]("5S
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E
M<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&9I;F0@;V)J96-T('1O
M(&)E(&%D9&5D.B`E<P!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@
M=&\@<F5T<FEE=F4Z("5S`$9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@
M8F]O:P!&86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S`$9A:7(`
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T
M86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS
M(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA
M=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA
M;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QE<P!&:6QT97)S`$9I;F0`
M1FEN:7-H`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!.86UE`$9I<G-T(%%U
M87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S
M(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@
M1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS
M(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L
M9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R
M9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N
M97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L
M($UE=')O<&]L:71A;@!&<F5E8G5S>2!54DP`1G)E;F-H($=U:6%N80!&<F5N
M8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M
M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA
M;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`
M1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O
M9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE
M`$=L;V)A;"!!9&1R97-S($)O;VL`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L
M`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'
M<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7``1W)O
M=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'
M=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U
M:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A
M9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@
M5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@0VET
M>0!(;VUE($-O=6YT<GD`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VUE
M(%!O<W1A;"!#;V1E`$AO;64@4W1A=&4O4')O=FEN8V4`2&]M92!3=')E970@
M061D<F5S<P!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`
M2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M35-0`$E-4U`@061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N`$E0($%D9')E
M<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W
M:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I
M;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O
M;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@
M8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`
M26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@
M=7!L;V%D`$EM86=E<P!);7!O<G0@061D<F5S<R!";V]K+"!3=&5P("5D`$EM
M<&]R="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($%D9')E<W,@0F]O:W,`26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@
M069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN
M8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I
M80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I
M;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E
M<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R
M90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E
M;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E
M<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E
M<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G
M<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W
M(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF
M>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I
M="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I
M96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!)1`!)
M;G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D
M871A`$EN=F%L:60@861D<F5S<R!B;V]K`$EN=F%L:60@87!P;&EC871I;VXN
M`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!E;6%I;`!);G9A
M;&ED(&5N=')Y`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!K97D@<W!E
M8VEF:65D+@!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&YA;64`26YV
M86QI9"!O8FIE8W1)9`!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A
M;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R
M;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@
M8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E
M<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S
M<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L
M96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD
M`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`
M271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H
M25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`
M2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T
M:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@
M3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG
M=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@
M;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$Q$05`@<W5P
M<&]R="!I<R!R97%U:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A
M=F%I;&%B;&4@;W(@;F]T(&QO861E9"X`3&%?>6]U=`!,86YG=6%G90!,86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!-
M;V1I9FEE9`!,87-T($YA;64`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1
M=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA
M>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,
M969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`
M3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R
M:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@
M3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E
M<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`
M3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE
M(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O
M:VEE`$QI<W0`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,
M;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I
M;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U
M=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I
M;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-
M87)T:6YI<75E`$UA=&-H:6YG`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA
M`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A
M<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E
M;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',`
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T
M:`!-87AI;75M(&YU;6)E<B!O9B!P86=E<P!-87D`36%Y;W1T90!-961I8VEN
M90!-96UB97)S`$UE;G4@3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE
M<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE
M<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T
M:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#
M86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU
M;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES
M8V5L;&%N96]U<P!-:7-S:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R
M871I;VXN`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES
M<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N
M;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I
M;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@
M36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V)I
M;&4@4&AO;F4`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO
M9&EF>2!F86EL960Z("@E<RD@)7,`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI
M8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-
M;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI
M;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F4@=&AA;B`Q(&5N=')Y
M(&9O=6YD`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S
M=&QY(%-U;FYY`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@;&5F=`!-;W9E(')I9VAT`$UO=F4@
M=7``36]Z86UB:7%U90!-=6QB97)R>2!!9&1R97-S($)O;VL`375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!P
M97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@
M6R5S72!A;')E861Y(&5X:7-T`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O
M=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@061D<F5S<R!";V]K`$UY
M($%D9')E<W,@0F]O:W,`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA
M;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UE($9O<FUA=`!.86UI
M8FEA`$YA=7)U`$YE<&%L`$YE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y`$YE
M=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@
M55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O
M;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.
M971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!#
M;VYT86-T`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M
M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE
M>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A
M`$YI8VMN86UE`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R`E<R!E
M;G1R>2!F;W5N9"!F;W(@)7,`3F\@861D<F5S<R!B;V]K<R!F;W5N9"X`3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/
M(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-O;G1A8W1S(&9O=6YD`$YO
M(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL
M92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T
M+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`
M3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F
M9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%14
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD
M:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A
M=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9#87)D(&1A=&$@=V%S(&9O
M=6YD+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U
M<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.
M;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA
M<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T
M(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P
M<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V
M96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C
M;VQU;6YS`$YU;6)E<B!O9B!I=&5M<R!P97(@<&%G90!.=6UB97(@;V8@<F]W
M<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V)J96-T
M(&YO="!F;W5N9`!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC
M90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L
M9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`
M3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D<F5S<R!B
M;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E9"X@268@=&AI<R!I<R!N
M;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N9V4@>6]U<B!S
M96QE8W1I;VX@=&\@(DYO;F4B+@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE('9C87)D('-U
M<'!O<G1E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@
M9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I
M;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T
M`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`
M3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA
M=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I
M;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@
M4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!0
M32!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N
M;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N
M(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U
M`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A
M($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!0
M87-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R
M96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S
M=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M
M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E
M;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M
M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E
M<FUI<W-I;VX@9&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL
M:7!P:6YE<P!0:&]N90!0:&]T;W,`4&EN92!!9&1R97-S($)O;VL`4&ET8V%I
M<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C
M96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A
M<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@;&ES=#H`4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\
M8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E
M82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,`4')E=FEO=7,@;W!T:6]N<P!0
M<FEN="!D;V-U;65N=`!0<FEV871E($%D9')E<W,@0F]O:P!0<FEV871E($ME
M>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T
M('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@
M2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`475E<GD@
M9F%I;&5D.B`H)7,I("5S`%%U:6-K(%-E87)C:`!1=6]T80!24T$@4'5B;&EC
M($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY
M`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@
M4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@9F%I;&5D.B`H
M)7,I("5S`%)E860@;65S<V%G97,`4F5A9&EN9R!C;VYT86-T<R!I<R!N;W0@
M879A:6QA8FQE+@!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+@!296%L;'D@9&5L971E('1H:7,@8V]N=&%C=#\`
M4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8V]R9',@9&ES<&QA>65D.@!2
M961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!2
M96QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R
M=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@861D<F5S<R!B;V]K`%)E
M;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E(&9R;VT@=&AI
M<R!L:7-T`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M
M;W9E('5S97(Z("5S`%)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K('=I
M=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES(&1E
M;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@8F]O
M:RX\+W-T<F]N9SX`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T
M=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N
M`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T
M(%EO=7(@4&%S<W=O<F0`4F5S970@=&\@1&5F875L=',`4F5S=&]R92!,87-T
M(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P
M87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X
M="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2
M:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2
M;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R
M=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A
M;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4`4R]-24U%(%!U8FQI8R!#97)T:69I8V%T90!305-,
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I
M;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`
M4U-(`%-405)45$Q3(&9A:6QE9#H@*"5S*2`E<P!354-#15-3`%-?44P@4VAE
M;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN
M="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E
M;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO
M80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@
M4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`
M4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-A=FEN9R!C;VYT86-T<R!I<R!N;W0@
M879A:6QA8FQE+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`
M4V5A<F-H($5N9VEN97,`4V5A<F-H(&9A:6QE9`!396%R8V@@9F%I;&5D.B`E
M<P!396%R8VAI;F<@:7,@;F]T(&%V86EL86)L92X`4V5A<F-H:6YG+BXN`%-E
M;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D
M9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A
M('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O
M;F5N=',N`%-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@9&5L971E`%-E;&5C
M="!A;B!A9&1R97-S(&)O;VL@=&\@961I=`!396QE8W0@86X@;V)J96-T`%-E
M;&5C="!N;VYE`%-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F
M<F]M.@!396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z`%-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&-H87)S970@;V8@=&AE('-O=7)C
M92!F:6QE.@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE
M(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E;&5C
M="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9F]R;6%T(&]F('1H
M92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P
M;&%Y(&YA;65S.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!V:65W('1O(&1I<W!L87D@8GD@9&5F875L="P@<V]R="!O<'1I;VYS+"!A
M;F0@<&%G:6YG(&]P=&EO;G,N`%-E;&5C="!W:&EC:"!F:65L9',@=&\@9&ES
M<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RX`4V5L96-T('=H:6-H(&9O<FUA
M="!T;R!D:7-P;&%Y(&YA;65S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@861D
M<F5S<R!B;V]K("(E<R(N`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`
M4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE
M9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E
M<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F5D($1I<F5C=&]R>0!3
M:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@)7,`4VAO=R!!;&P`
M4VAO=R!#;VYT86-T<P!3:&]W($QI<W1S`%-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G
M:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC
M:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R
M<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6
M:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L
M;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N
M('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3
M:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3
M;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N
M;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@
M:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O
M96US`%-O<G0@1&ER96-T:6]N`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C
M92!A9&1R97-S`%-O=7)C97,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N
M("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E
M96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D
M:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!E8VEF
M>2!W:&5R92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A
M<'!E87(N`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R
M=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E
M<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L
M;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3
M=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@861D960@)60@8V]N=&%C="AS*2!T
M;R!L:7-T+@!3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,`4W5C8V5S<V9U
M;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A8W0@;&ES="`B)7,B
M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@9&5L
M971E9"`E9"!C;VYT86-T*',I+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E;6]V960@)60@8V]N
M=&%C="AS*2!F<F]M(&QI<W0N`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A
M=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S
M9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A
M;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR
M:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R
M:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@
M9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3
M>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y
M`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135@!44U8@9FEL90!486(@<V5P
M87)A=&5D('9A;'5E<P!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E
M=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S
M="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@
M;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@
M3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA
M:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE
M($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@
M24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E
M;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/
M<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@5D93(&)A
M8VME;F0@;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@871T86-H
M;65N="!U<&QO861S+@!4:&4@861D<F5S<R!B;V]K("(E<R(@9&]E<R!N;W0@
M97AI<W0N`%1H92!A9&1R97-S(&)O;VL@(B5S(B!W87,@8W)E871E9"!S=6-C
M97-S9G5L;'DN`%1H92!A9&1R97-S(&)O;VL@(B5S(B!W87,@<F5M;W9E9"!S
M=6-C97-S9G5L;'DN`%1H92!A9&1R97-S(&)O;VL@(B5S(B!W87,@<W5C8V5S
M<V9U;&QY('5P9&%T960N`%1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E
M('!U<F=E9#H@)7,`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG
M=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4
M:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN`%1H92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI
M<W0N`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4
M:&4@9FEL92`B)7,B(&AA<R!S=6-C97-S9G5L;'D@8F5E;B!D96QE=&5D+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F
M:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O
M;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R
M<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S
M8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN
M=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@
M=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I
M96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N
M<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES
M=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L
M;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T
M;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R
M97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E
M96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D
M+@!4:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W87)N
M:6YG<RX`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F
M('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET
M:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO
M(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@
M=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T
M:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@
M;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@
M(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E
M961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U
M<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD
M(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S
M879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P
M('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T
M(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL
M86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@
M87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO('=R:71E86)L
M92!A9&1R97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S
M<R!B;V]K<R!A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE
M=R!E;G1R:65S('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@:7,@86X@
M97)R;W(L('!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@
M8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@
M`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T
M:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<B!F;W(@9G5R=&AE<B!H96QP+@!4:&5R92!W87,@86X@97)R;W(@8W)E
M871I;F<@82!N97<@;&ES="X`5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG
M('1H:7,@861D<F5S<R!B;V]K.B`E<P!4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@(B5S(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+@!4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<P!4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES=`!4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S
M(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O
M;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,`5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D
M9')E<W,@8F]O:SH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M:7,@96YT<GDZ("5S`%1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R
M="X`5&AE<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O
M<F1E<CH`5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E
M<CH`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F
M)RX`5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H
M:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@
M;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES
M(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@
M;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L
M96%S="!O;F4N`%1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@
M:6X@=&AE(&%D9')E<W,@8F]O:P!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1H:7,@=VEL;"!B92!T:&4@9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A
M9&1I;F<@;W(@:6UP;W)T:6YG(&-O;G1A8W1S+@!4:&ES('=I;F1O=R!M=7-T
M(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC
M:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE
M8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4
M;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4
M;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W
M`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN
M:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K
M97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N
M9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N
M5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S
M=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S
M(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R
M92X@36ES<VEN9R!S;W5R8V4@='EP92X`56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O
M97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D
M($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK
M;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O
M('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O;G1E;G0M5'EP
M93H@)7,`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`
M57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N
M86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R
M:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)I<VEG;B!$
M:7)E8W1O<GD`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI
M9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@
M3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`B)7,B`%9I97<@)7,`5FEE
M=R!#;VYT86-T`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E
M<P!6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#H`5FER9VEN($ES;&%N9',L
M($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I
M8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(
M5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E
M8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B
M`%=E8B!3:71E`%=E8G-I=&4@55),`%=E96ML>0!796QC;VUE`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R
M;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K($-I='D`
M5V]R:R!#;W5N=')Y`%=O<FL@4&AO;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K
M(%-T871E+U!R;W9I;F-E`%=O<FL@4W1R965T($%D9')E<W,`5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS
M:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L
M($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T
M<R!I;B`B)7,B+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N
M;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N`%EO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N<R!T;R!D96QE=&4@=&AI<R!S;W5R
M8V4N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A('1A
M<F=E="!A9&1R97-S(&)O;VLN`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!L
M:7-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="X`
M66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R`%EO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@
M8V]N=&%C="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES
M:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N
M9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N`%EO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I
M<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!;;F\@=F%L=65=`%]!9&UI
M;FES=')A=&EO;@!?0G)O=W-E`%]#3$D`7T-O;G1A8W1S`%]$871A5')E90!?
M1&5L971E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E
M<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`7TQI<W1S`%],;V<@:6X`7TQO9R!O
M=70`7TUO9&EF>2!,:6YK+BXN`%]->2!!9&1R97-S($)O;VMS`%].97<@0V]N
M=&%C=`!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]2
M96UO=F4@9G)O;2!T:&ES(&QI<W0`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK
M;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`
M8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A
M9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C;VYT86-T+G9C9@!C;VYT
M86-T<RYC<W8`8V]N=&%C=',N='-V`&-O;G1A8W1S+G9C9@!C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT
M<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I
M871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A
M<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!M;0!N86UE`&YO(&9O<FUA='1I;F<`;F]N90!N;W0@:6UP
M;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`
M<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N
M8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R
M`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T;R!A($-O;G1A8W0@3&ES
M=`!T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VL`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE
M8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!4
M=7)B80I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,38@,3<Z-#DM,#(P,`I,87-T+51R
M86YS;&%T;W(Z($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB<CX*3&%N
M9W5A9V4M5&5A;3H@0G)A>FEL:6%N(%!O<G1U9W5E<V4@/&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET"E@M1V5N97)A=&]R.B!+0F%B96P@,2XS+C$*4&QU
M<F%L+49O<FUS.B`@;G!L=7)A;',],CL@<&QU<F%L/2AN(#X@,2D["@`@*"5S
M(&1I87,@871RX7,I`"`H5&5C;&$@9&4@071A;&AO("5S*0`@*&5M("5S(&1I
M87,I`"`H:&]J92D`("AA;6%N:.,I`"`H;VYT96TI`"!!9&EC:6]N87(@=6T@
M0V%TX6QO9V\@9&4@96YD97)EYV]S($E-4U``17AC;'5I<B!O($-A=.%L;V=O
M(&1E($5N9&5R9>=O<R!)35-0`"!A(``B)7,B(&KA(&5X:7-T92!E(&[C;R!F
M;VD@:6UP;W)T861O+@`B)7,B($[C;R#I('5M(&1I<F5T\W)I;RX`)R5S)R!N
MXV\@Z2!U;6$@97-C;VQH82!VX6QI9&$N`"<E<R<@;N-O(&5S=.$@8V]N9FEG
M=7)A9&\@;F\@4F5G:7-T<F\@9&\@2&]R9&4N`')E;F1E<FEZ861O<B!D92#A
M<G9O<F4@(B5S(B!NXV\@96YC;VYT<F%D;RX`(B5S(B!F;VD@861I8VEO;F%D
M;R!A;R!S:7-T96UA(&1E(&=R=7!O<RX`(B5S(B!F;VD@861I8VEO;F%D;R!A
M;R!S:7-T96UA(&1E('!E<FUI<W/U97,N`"<E<R<@;N-O(&9O:2!C;W!I861O
M('!O<G%U92#I('5M82!L:7-T82X`(B<E<R(@;N-O(&9O:2!C<FEA9&\Z("5S
M+@`G)7,G(&[C;R!F;VD@;6]V:61O('!O<G%U92#I('5M82!L:7-T82X`(DYO
M;64@4V]B<F5N;VUE(B`@*&5X+B!*;^-O($YI;F=UZ6TI`")3;V)R96YO;64L
M($YO;64B("AE>"X@3FEN9W7I;2P@2F_C;RD`)2XR9DU"('5S861O<R!D924N
M,F9-0B!P97)M:71I9&]S("@E+C)F)24I`"5D("5S(&4@)7,`)60@9&EA<R!A
M=.D@<W5A('-E;FAA(&5X<&ER87(N`"5D('!R979I<^-O(&1O(&1I80`E<R`M
M($%V:7-O`$EM<')E<W/C;R!$:6=I=&%L(&1E("5S`"5S($M"`"5S($]P97)A
MY_5E<R!D92!-86YU=&5NY^-O("T@0V]N9FER;6'GXV\`0V]N9FEG=7)AY^-O
M(&1E("5S`$-A9&%S=')O(&1E("5S`"5S(%1E<FUO<R!D;R!!8V]R9&\`)7,@
M861I8VEO;F%D;RX`)7,@:N$@97AI<W1E+@`E<R!A("5S("5S`$%R<75I=F\@
M)7,@:6UP;W)T861O(&-O;2!S=6-E<W-O`"5S(&5S=.$@<')O;G1O('!A<F$@
M97AE8W5T87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\@;6%R8V%D87,@
M86)A:7AO+B!-87)Q=64@82!C86EX82!P87)A('%U86QQ=65R(&]P97)AY^-O
M('%U92!V;V/J('%U96ER82!E>&5C=71A<B!D97-T82!V97HN`"5S(.D@;V)R
M:6=A=/-R:6\`)7,@;6EN=71O<P`E<R!NXV\@96YC;VYT<F%D;RX`)7,@82`E
M<R!D92`E<P!#873A;&]G;R!D92!%;F1E<F7G;W,@9&4@)7,`06=E;F1A(&1E
M("5S`$%N;W1AY_5E<R!D92`E<P!,:7-T82!D92!487)E9F%S(&1E("5S`"5S
M.B`E<P`E<SH@17-T82!M96YS86=E;2!P;V1E(&[C;R!S97(@9&4@<75E;2!E
M;&$@9&EZ('-E<BX@5&]M92!C=6ED861O(&-O;2!Q=6%L<75E<B!L:6YK('!R
M97-E;G1E(&YE;&$@;W4@96T@9F]R;F5C97(@86\@<F5M971E;G1E('%U86QQ
M=65R(&EN9F]R;6'GXV\@<&5S<V]A;"X`+"!B<FES82``+"!B<FES82`E<R`E
M<P`L('9A<FGA=F5L(&1E("5S('!A<F$@)7,`+2T@<V5L96-I;VYE("TM`$9O
M<FUA=&\@,3(@2&]R87,`1F]R;6%T;R`R-"!(;W)A<P`R-"!H;W)A<P`\4.%G
M:6YA($%N=&5R:6]R`,D@;V)R:6=A=/-R:6\@=6T@;F%V96=A9&]R('%U92!S
M=7!O<G1E(&E&<F%M97,`56T@8V]N96-T;W(@9&4@8F%N8V\@9&4@9&%D;W,@
MZ2!O8G)I9V%T\W)I;R!P87)A(&5S=&4@8FQO8V\N`%5M(&5R<F\@9F%T86P@
M;V-O<G)E=0!5;6$@8VAA=F4@</IB;&EC82!01U`@Z2!O8G)I9V%T\W)I82!P
M87)A(&-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P^F)L
M:6-A(%!'4"#I(&]B<FEG873S<FEA('!A<F$@=F5R:69I8V%R('5M82!M96YS
M86=E;2!A<W-I;F%D82X`56UA(&-H879E('!R:79A9&$@4$=0(&4@=6UA('-E
M;FAA('/C;R!O8G)I9V%T\W)I87,@<&%R82!D97-C<FEP=&]G<F%F87(@=6UA
M(&UE;G-A9V5M+@!5;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@<V5N:&$@
M<^-O(&]B<FEG873S<FEA<R!P87)A(&%S<VEN87(@=6UA(&UE;G-A9V5M+@!5
M;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O
M34E-12!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@9&5S8W)I
M<'1O9W)A9F%R('5M82!M96YS86=E;2X`56UA(&-H879E('#Z8FQI8V$@4R]-
M24U%+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@<V5N:&$@<^-O
M(&]B<FEG873S<FEA<R!P87)A(&%S<VEN87(@=6UA(&UE;G-A9V5M+@!5;6$@
M8VAA=F4@</IB;&EC82!3+TU)344@Z2!O8G)I9V%T\W)I82!P87)A(&-R:7!T
M;V=R869A<B!U;6$@;65N<V%G96TN`$YU=F5N<R!M871U=&EN87,`0VAU=F$@
M1G)A8V$@5F5S<&5R=&EN80!#:'5V82!M871U=&EN80!#:'5V87,@;6%T=71I
M;F%S`$YE=F%S8V%S($UA='5T:6YA<P!!32]030!!4$D@240`4V]B<F4@97-T
M92!E9&ET;W(`4V]B<F4N+BX`1F]R;75LX7)I;R!D92!P97-Q=6ES82!A8VEM
M80!!8G-B;W1T;VT`06)S;6ED9&QE`$%C97-S;R!N96=A9&\@86\@8W)I87(@
M9&ER973S<FEO(%9&4RX`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O
M(%9&4RX`06-E<W-O(&YE9V%D;R!A("5S`%-U87,@26YF;W)M8>?U97,`4V5N
M:&$@9&$@0V]N=&$`0V]N=&$@9&5S871I=F%D82X`0V]N=&%S`$%D:6-I;VYA
M<@!!9&EC:6]N87(@1W)U<&\@4W5B;W)D:6YA9&\`061I8VEO;F%R(%!E<FUI
M<W/U97,@4W5B;W)D:6YA9&%S`$%D:6-I;VYE($%Q=6DZ`$%D:6-I;VYA<B!.
M;W9O($=R=7!O`$%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C;P!!9&EC:6]N87(@
M=6T@9W)U<&\@<W5B;W)D:6YA9&\@82`G)7,G`$%D:6-I;VYA<B!U;6$@<&5R
M;6ES<^-O('-U8F]R9&EN861A(&$@)R5S)P!!9&EC:6]N87(@=6T@;F]V;R!U
M<W7A<FEO.@!!9&EC:6]N87(@8V%TX6QO9V\@9&4@96YD97)EYV]S`$%D:6-I
M;VYA<B!E($5X8VQU:7(@8V%TX6QO9V\@9&4@96YD97)EYV]S($E-4U``061I
M8VEO;F%R(&-O;'5N80!!9&EC:6]N87(@87)Q=6EV;P!!9&EC:6]N87(@;F]V
M;W,@;65M8G)O<P!!9&EC:6]N87(@<&%R`$%D:6-I;VYA<B!O($UE;G4@)7,@
M8V]M;R!U;6$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA`$%D:6-I;VYA<B!E
M;0!!9&EC:6]N87(@86\@8V%TX6QO9V\@9&4@96YD97)EYV]S.@!!9&EC:6]N
M87(@86\@;65U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!!9&EC:6]N87(@=7-U
MX7)I;P`G)7,G(&%D:6-I;VYA9&\@86\@<VES=&5M82P@;6%S(&[C;R!P=61E
M(&EN8VQU:7(@:6YF;W)M8>?U97,@861I8VEO;F%I<R!D;R!C861A<W1R;SH@
M)7,N`"5S(&%D:6-I;VYA9&\@86\@<VES=&5M82X@5F]CZB!P;V1E('-E(&-O
M;F5C=&%R(&%G;W)A+@!!9&GGXV\@9&4@8V]N=&%T;W,@;N-O(&5S=.$@9&ES
M<&]N[79E;"X`061IY^-O(&1E('5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861A
M+@!%;F1E<F7G;P!#873A;&]G;R!D92!%;F1E<F7G;W,`3&ES=&%G96T@9&4@
M0V%TX6QO9V]S(&1E($5N9&5R9>=O<P!#873A;&]G;W,@9&4@16YD97)EYV]S
M`%)E9VES=')O(&1O(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!/(&-A=.%L;V=O
M(&1E(&5N9&5R9>=O<R!F;VD@;&EM<&\@8V]M('-U8V5S<V\N`$-A=.%L;V=O
M(&1E(&5N9&5R9>=O<R!P87)A(&5X8VQU:7(`0V%TX6QO9V\@9&4@96YD97)E
MYV]S('%U92!NXV\@<V5RXV\@97AI8FED;W,Z`$%D;6EN:7-T<F%R("T@8V]N
M9FEG=7)A('!E<FUI<W/U97,@<&%R82!O=71R;W,@=7-UX7)I;W,`061M:6YI
M<W1R8>?C;P!!;OIN8VEO<P!097-Q=6ES82!!=F%NYV%D80!!9F5G86YI<W3C
M;P!!;&+B;FEA`$%R9^ER:6$`07!E;&ED;P!!;&EN:&%R`$%L:6YH86UE;G1O
M.@!4;V1O<P!4;V1O<R!5<W7A<FEO<R!!=71E;G1I8V%D;W,`5&]D;W,@1W)U
M<&]S`%1O9&%S(%!E<FUI<W/U97,`5&]D;W,@<75A=')O(&QA9&]S`%!E<FUI
M=&ER(&WZ;'1I<&QO<R!E;F1E<F7G;W,`4&5R;6ET:7(@8V]N9FEG=7)A<B!O
M('1I<&\@9&4@;&ES=&%S(&]R9&5N861A<S\`2N$@17AI<W1E`$KA(&5X:7-T
M90!,;V=I;B!)35-0($%L=&5R;F%T:79O`%-E;FAA($E-4U`@06QT97)N871I
M=F$`57-UX7)I;R!)35-0($%L=&5R;F%T:79O`$5N9&5R9>=O(&1E(&4M;6%I
M;"!A;'1E<FYA=&EV;P!-;V1E;&]S(&%L=&5R;F%T:79O<P!497AT;R!A;'1E
M<FYA=&EV;SH`4V%M;V$@06UE<FEC86YA`%5M('9A;&]R(&EL96=A;"!F;VD@
M97-P96-I9FEC861O+@!/8V]R<F5U('5M(&5R<F\@9&5S8V]N:&5C:61O+@!!
M;F1O<G)A`$%N9V]L80!!;F=U:6QL80!0<F]X>2!A;O1N:6UO`%)E<W!O<W1A
M`$%N=.%R=&ED80!!;G1I9W5A(&4@0F%R8F%D;W,`07!L:6-AY^-O`$QI<W1A
M(&1E($%P;&EC8>?U97,`02!A<&QI8V'GXV\@97-TX2!P<F]N=&$N`$%P;&EC
M87(@86]S($-O;7!A<G1I;&AA;65N=&]S(%-U8F]R9&EN861O<P!!<')O=F%R
M`%1A;6%N:&\@07!R;WAI;6%D;P!!8G)I;`!!<N%B:6-O("A7:6YD;W=S+3$R
M-38I`%1A;6%N:&\@9&\@07)Q=6EV;P!.;VUE(&1O($%R<75I=F\`5F]CZB!T
M96T@8V5R=&5Z82!Q=64@<75E<B!E>&-L=6ER("5S/P!6;V/J('1E;2!C97)T
M97IA('%U92!Q=65R(&5X8VQU:7(@;W,@<F5G:7-T<F]S('-E;&5C:6]N861O
M<S\`5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(&$@<V]L:6-I
M=&'GXV\@9&4@8V%D87-T<F\@9&4@)7,_`%9O8^H@=&5M(&-E<G1E>F$@<75E
M(&1E<V5J82!E>&-L=6ER("<E<R<@92!S975S('-U8F=R=7!O<S\`07)G96YT
M:6YA`$%R;>IN:6$`07)MZFYI;R`H05)-4T-)22TX*0!!<G1E`$%R=6)A`$%S
M8V5N9&5N=&4`26QH82!!<V-E;G/C;P!!<G1E($%S8VEI`,%S:6$O4F5G:>-O
M(&1O(%!A8^UF:6-O`%-O;&EC:71A<B!C;VYF:7)M8>?C;R!A;G1E<R!D92!E
M>&5C=71A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;S\`0V]L=6YA<R!D
M92!D97-I9VYAY^-O`%1E;G1O=2!E>&-L=6ER('5M(&=R=7!O(&EN97AI<W1E
M;G1E+@!496YT;W4@97AC;'5I<B!U;6$@<&5R;6ES<^-O(&[C;R!E>&ES=&5N
M=&4N`%1E;G1O=2!E9&ET87(@=6UA('!E<FUI<W/C;R!NXV\@97AI<W1E;G1E
M+@!496YT;W4@961I=&%R('5M(&-O;7!A<G1I;&AA;65N=&\@;N-O(&5X:7-T
M96YT92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<N%L:6$`P75S=')I80!!=71H
M7V-Y<G-Q;#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:6UA<"!N
M96-E<W/A<FEA+@!!=71H7V-Y<G5S.B!/(&-O;F5C=&]R(&[C;R!P;W-S=6D@
M87,@8V%P86-I9&%D97,@;F5C97-SX7)I87,N`$%U=&A?8WER=7,Z($[C;R!F
M;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82X`075T
M:%]F='`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($944"!N96-E
M<W/A<FEA+B!#;VUP:6QE(&\@4$A0(&-O;2!A(&]PY^-O("TM96YA8FQE+69T
M<"X`075T:%]I;6%P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I
M;6%P(&YE8V5S<^%R:6$N`$%U=&A?:W)B-3H@3N-O(&9O:2!E;F-O;G1R861A
M(&$@97AT96YSXV\@:W)B-2!N96-E<W/A<FEA+@!!=71H7VQD87`Z($EN8VQU
M<^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!%>&-L=7/C;R!D92!U<W7A<FEO<R!NXV\@
MZ2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA
M+@!!=71H7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R(&\@=7-UX7)I;R`E
M<RX@27-T;R!F;VD@;R!Q=64@;R!S97)V:61O<B!R97!O<G1O=3H@`$%U=&A?
M;&1A<#H@26UP;W-S[79E;"!R96UO=F5R(&\@=7-UX7)I;R`E<P!!=71H7VQD
M87`Z($EM<&]S<^UV96P@871U86QI>F%R(&\@=7-UX7)I;R`E<P!!=71H7VQD
M87`Z($%T=6%L:7IAY^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P
M87)A($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@3N-O(&9O:2!E;F-O
M;G1R861A(&$@97AT96YSXV\@34-!3"!N96-E<W/A<FEA+@!!=71H7W-M8F%U
M=&@Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O('-M8F%U=&@@;F5C
M97-SX7)I82X`075T96YT:6-AY^-O(&YO('-E<G9I9&]R($E-05`@9F%L:&]U
M+@!&86QH82!N82!A=71E;G1I8V'GXV\`1F%L:&$@;F$@875T96YT:6-AY^-O
M.B`E<P!!=71E;G1I8V'GXV\@<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$
M2553+@!!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U+@!!
M(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!334(@9F%L:&]U+@!#86UP;W,@
M9&ES<&]N[79E:7,Z`$%Z97)B86EJXV\`1&5S8W5L<&%S(&1O($)/1D@`1G5N
M9&\`0V]R(&1E($9U;F1O`%-E;FAA(&ME<F)E<F]S(&EN8V]R<F5T82X`57-U
MX7)I;R!K97)B97)O<R!I;F-O<G)E=&\N`$)A:&%M87,`0F%H<F%I;@!"X6QT
M:6-O("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!.XV\@9F]I
M(&5N8V]N=')A9&\@;R!D:7)E=/-R:6\@8F%S92!D92!I;6%G96YS("<E<R<N
M`$QI;FAA(&1E(%!A<G1I9&$`4&5S<75I<V$@4VEM<&QE<P!"96QO<OIS<VEA
M`$+I;&=I8V$`0F5L:7IE`$9O<FUU;.%R:6\@9&4@<&5S<75I<V$@86)A:7AO
M`$)E;FEN`$)E<FUU9&%S`$)U=.-O`$$@8V]N97CC;R!F86QH;W4Z("@E<RD@
M)7,`06YI=F5R<^%R:6\`3N-O(&9O:2!E;F-O;G1R861O(&\@8FQO8V\@(B5S
M(B!D82!A<&QI8V'GXV\@(B5S(BX`0V]N9FEG=7)AY_5E<R!D;R!";&]C;P!4
M:7!O(&1E($)L;V-O`$YE9W)I=&\`0F]L[79I80!&879O<FET;W,`0F]R9&$`
M3&%R9W5R82!D82!B;W)D83H`0F]R9&%S`$+S<VYI82!E($AE<GIE9V]V:6YA
M`$%M8F]S`$)O='-U86YA`%)O9&%PZ0!);&AA($)O=79E=`!"<F%S:6P`5&5R
M<FET\W)I;R!D;R!/8V5A;F\@S6YD:6-O($EN9VSJ<P!?17AI8FER`$)R=6YE
M:0!"=6QGX7)I80!,:7-T82!C;VT@36%R8V%D;W)E<P!"=7)K:6YA($9A<V\`
M0G5R=6YD:0!#871E9V]R:6$@9&4@3F5G\V-I;W,`0TU3`$-20P!0;VYT;W,@
M9&4@1&ES=')I8G5IY^-O($-23`!#4U8`4')O<')I961A9&5S(&1A($/I7VQU
M;&$N+BX`02!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF
M:6-A9&$N`$%G96YD80!#86QM;P!#86UB;V1J80!#86UA<O5E<P!.XV\@Z2!P
M;W-S[79E;"!G97)A<B!U;6$@;F]V82!S96YH82!A=71O;6%T:6-A;65N=&4L
M(&5N=')E(&5M(&-O;G1A=&\@8V]M(&\@861M:6YI<W1R861O<BX`3N-O(&-O
M;G-I9V\@9W)A=F%R(&\@87)Q=6EV;R`B)7,B`$EM<&]S<^UV96P@861I8VEO
M;F%R('5M(&=R=7!O(&YE;&4@;65S;6\N`$[C;R#I('!O<W/M=F5L(&%D;6EN
M:7-T<F%R(&=E<F5N8VEA9&]R97,@97AT97)N;W,@9&4@<V5S<^-O+@!.XV\@
MZ2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!)34%0.B`E<P!.XV\@
M8V]N<VEG;R!A8G)I<B!O(&%R<75I=F\@(B5S(BX`0V%N863A`$-A;F-E;&%R
M`$-A;F-E;&%R(%)E;&%T\W)I;R!D92!0<F]B;&5M80!.XV\@Z2!P;W-S[79E
M;"!E>&-L=6ER(&\@87)Q=6EV;R`B)7,B+@!.XV\@Z2!P;W-S[79E;"!E;F-O
M;G1R87(@=6T@9&ER973S<FEO('1E;7!O<N%R:6\N`$[C;R#I('!O<W/M=F5L
M(&-O;G1I;G5A<B!S96T@;R!P87+B;65T<F\@)W1A<F=E=$9I;&4G+@!.XV\@
MZ2!P;W-S[79E;"!E>&-L=6ER(&\@9&ER973S<FEO("(E<R(N`$[C;R#I('!O
M<W/M=F5L(&5X8VQU:7(L("5D('!O<W-U:2!S=6)O<F1I;F%D;W,N`$[C;R#I
M('!O<W/M=F5L(')E;W)D96YA<BP@;OIM97)O(&1E(')E9VES=')O<R!F;W)N
M96-I9&]S('!A<F$@<F5O<F1E;F%R(&[C;R!C;W)R97-P;VYD92!A;R!N^FUE
M<F\@87)M87IE;F%D;RX`3N-O(.D@<&]S<^UV96P@<F]T96%R(&UE;G-A9V5M
M('!A<F$@;R!N^FUE<F\@97-P96-I9FEC861O+@!#86)O(%9E<F1E`%3M='5L
M;P!/<&5R861O<F$`0V%T96=O<FEA<R!E($YO;65S`$EL:&%S($-A>6UA;@!4
M96QE9F]N92!#96QU;&%R`%!R;W!R:65D861E<R!D82!#Z6QU;&$`36%R9V5M
M(&1A(&/I;'5L83H`4')O<')I961A9&5S(&1A($/I;'5L80!%<W!AYV%M96YT
M;R!D82!CZ6QU;&$Z`%1E;&5F;VYE(&-E;'5L87(`0^EL=&EC;R`H25-/+3@X
M-3DM,30I`$-E;G1R;P!297#Z8FQI8V$@9&$@P69R:6-A($-E;G1R86P`175R
M;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I`$1E=&%L:&5S(&1O($-E<G1I9FEC
M861O`%!R;W!R:65TX7)I;R!D;R!#97)T:69I8V%D;P!0;VSM=&EC87,@9&\@
M0V5R=&EF:6-A9&\`5&-H861E`$%L=&5R87(`06QT97)E(%-U82!396YH80!!
M;'1E<F%R(&\@;F]M92!E(&\@96YD97)EYV\@<75E(&%S('!E<W-O87,@=NIE
M;2!Q=6%N9&\@96QA<R!LZF5M(&4@<F5S<&]N9&5M('-U87,@;65N<V%G96YS
M+@!!;'1E<F'GXV\@9&4@<V5N:&$@;N-O(.D@<W5P;W)T861A(&YA(&-O;F9I
M9W5R8>?C;R!A='5A;"X@($5N=')E(&5M(&-O;G1A=&\@8V]M(&\@861M:6YI
M<W1R861O<BX`0VAA<@!697)I9FEC87(@3&EN7VLN+BX`36%R8V%R(%1O9&%S
M+U].96YH=6UA`$-H:6QE`$-H:6YA`$-H:6[J<R!3:6UP;&EF:6-A9&\@*$="
M,C,Q,BD`0VAI;NIS(%1R861I8VEO;F%L("A":6<U*0!%<V-O;&AA(&$@07!L
M:6-AY^-O.@!%<V-O;&AA('5M(&YO;64`17-C;VQH82!U;6$@<V5N:&$`17-C
M;VQH82!U;2!U<W7A<FEO`$5S8V]L:&$@=6T@8V%TX6QO9V\@9&4@96YD97)E
MYV]S`$5S8V]L:&$@=6T@8V%TX6QO9V\@9&4@96YD97)EYV]S.@!%<V-O;&AA
M(&-O;6\@97AI8FER(&1A=&%S.@!%<V-O;&AA(&\@=&EP;R!D92!E<W1I;&\@
M9&4@;&ES=&%S("AP87)A(&QI<W1A<R!O<F1E;F%D87,I`$5S8V]L:&$@<75A
M:7,@8V%TX6QO9V]S(&1E(&5N9&5R9>=O(&5X:6)I<B!E(&5M('%U86P@;W)D
M96TZ`$5S8V]L:&$@<75A;"!C873A;&]G;R!D92!E;F1E<F7G;W,@=71I;&EZ
M87(N`$5S8V]L:&$@<75A:7,@8V]L=6YA<R!E>&EB:7(@92!E;2!Q=6%L(&]R
M9&5M.@!);&AA<R!#:')I<W1M87,`3N-O(&9O:2!E;F-O;G1R861A(&$@9&5F
M:6YIY^-O(&1E(&-L87-S92!D92`E<RX`3&EM<&%R`$QI;7!A<B!T86=S($U3
M3V9F:6-E`$5X8VQU:7(@=7-UX7)I;P!%>&-L=6ER('5S=>%R:6\Z("5S`$5X
M8VQU:7(@=7-UX7)I;P!%>&-L=6ER(&1A9&]S(&1O('5S=>%R:6\`0^EU(&%B
M97)T;R!A(%1A<F1E`$-L:7%U92!P87)A($-O;G1I;G5A<@!#;&EC:V%T96QL
M('9I82!(5%10`$9E8VAA<B!*86YE;&$`3G5V96YS`$YU8FQA9&\@<&5L82!-
M86YHXP!.=6)L861O`$EL:&%S(&1E($-O8V]S`$-O;G1R86ER($)A<G)A($QA
M=&5R86P`0V]N=')A:7(@8F]R9&%S`$-O;/1M8FEA`$-O<@!086QH971A(&1E
M($-O<F5S`%-E;&7GXV\@9&4@0V]R`$-O;',Z`$]PY_5E<R!D92!#;VQU;F$`
M5.UT=6QO<R!D87,@0V]L=6YA<P!#;VQU;F%S('%U92!NXV\@<V5RXV\@97AI
M8FED87,Z`%%U861R:6YH;W,`5F%L;W)E<R!S97!A<F%D;W,@<&]R(';M<F=U
M;&$`5F%L;W)E<R!S97!A<F%D;W,@<&]R(';M<F=U;&%S("A-:6-R;W-O9G0@
M3W5T;&]O:RD`0V]M86YD;P!,:6YH82!D92!#;VUA;F1O`$-O;65N=&%R`$YO
M;64`0V]M;W)O<P!%;7!R97-A`$5N9&5R9>=O(&1A($5M<')E<V$`0V]M<'5T
M861O<F5S`$-O;F1IY^-O`$-O;F1IY_5E<P!$:69E<F5NYV%S(&1E($-O;F9I
M9W5R8>?C;P!#;VYF:6=U<F'GXV\@9&4@<VEN8W)O;FEZ8>?C;R!C;VT@4$1!
M<RP@4VUA<G1P:&]N97,@92!/=71L;V]K+@!#;VYF:6=U<F'GXV\@;F5C97-S
M:71A(&1E(&%T=6%L:7IAY^-O+@!#;VYF:6=U<F%R("5S`$-O;F9I<FUE(&$@
M4V5N:&$`0V]N9V\`0V]N9V\L(%)E</IB;&EC82!$96UO8W+A=&EC82!D;P!&
M86QH82!N82!C;VYE>.-O+@!&86QH82!N82!C;VYE>.-O.B``02!C;VYE>.-O
M(&9A;&AO=3H@)7,`1F%L:&$@9&4@8V]N97CC;P!#;VYE>.-O(')E8W5S861A
M('!E;&\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!#;VYE>.-O(')E
M8W5S861A('!E;&\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+B!-;W1I
M=F\Z("5S("@E<RD`02!C;VYE>.-O(&%O('-E<G9I9&]R($944"!F86QH;W4N
M`%!E<W%U:7-A<B!#;VYT871O`$-O;G1A=&]S`$-O;G1A=&]S(&YA(&QI<W1A
M.B`E<P!/<R!C;VYT871O<R!F;W)A;2!A9&EC:6]N861O<R!C;VT@<W5C97-S
M;R!A;R!S974@8V%TX6QO9V\@9&4@96YD97)EYV]S+@!4:7!E(&1E(&-O;G1E
M^F1O(&1O(&%R<75I=F\@8V]M<')I;6ED;SH@`$-O;G1E^F1O(&1E("<E<R<`
M0V]N=&EN=6%R`$EL:&%S($-O;VL`0V]O:VEE`$-O<&EA<@!&86QH82!N82!C
M\W!I83H@)7,`0V]P:6%R('-E;&7GXV\`240@9&4@0W5S=&\`0V]S=&$@4FEC
M80!#;W-T82!D;R!-87)F:6T`26UP;W-S[79E;"!C<FEP=&]G<F%F87(@82!M
M96YS86=E;2!C;VT@4$=0.B``26UP;W-S[79E;"!A<W-I;F%R(&$@;65N<V%G
M96T@8V]M(%!'4#H@`$[C;R!F;VD@<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@
M;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A<W-I;F%R
M(&$@;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A9&EC
M:6]N87(@8V]N=&%T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A
M;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L('9E<FEF:6-A<B!O
M('-A;&1O+B`E<P!);7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R($Q$
M05`N`$[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@)R5S
M)R!U=&EL:7IA;F1O($944#H@)7,`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`26UP;W-S[79E;"!D97-C<FEP
M=&]G<F%F87(@;W,@9&%D;W,@4$=0.B``3N-O(&9O:2!P;W-S[79E;"!D97-C
M<FEP=&]G<F%F87(@;R!D861O(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!E
M>&-L=6ER(&\@8V]N=&%T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER
M(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L
M(&5X8VQU:7(@;R!S8W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)A
MY^-O("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@9&5T97)M:6YA<B!O(&5N9&5R
M9>=O(&1E(&4M;6%I;"!D;R!D97-T:6YA=.%R:6\N`$[C;R!F;VD@<&]S<^UV
M96P@;V)T97(@8V]M<&QE=&%M96YT92!O(&-A=.%L;V=O(&1E(&5N9&5R9>=O
M<RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&-O
M;7!L971A;65N=&4@82!L:7-T82!D92!L:7-T87,@9&4@9&ES=')I8G5IY^-O
M+@!.XV\@9F]I('!O<W/M=F5L(&-A<G)E9V%R(&$@97-T<F%TZ6=I82`G)7,G
M+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&\@9&ER973S<FEO("<E<R<N`$[C
M;R!F;VD@<&]S<^UV96P@;V)T97(@82!C:&%V92!P^F)L:6-A(&$@<&%R=&ER
M(&1O('-E<G9I9&]R(&1E(&-H879E<RX`3N-O(&9O:2!P;W-S[79E;"!A8G)I
M<B`G)7,G('!A<F$@9W)A=F'GXV\N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@
M)7,N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!M\V1U;&\@)TUA:6YT96YA
M;F-E7U1A<VLG("5S`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!D:7)E=/-R
M:6\@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@;F\@<V5R=FED
M;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!L97(@)7,N`$[C;R!F;VD@<&]S
M<^UV96P@9V5R87(@=6UA(&YO=F$@<V5N:&$@<&%R82!O('5S=>%R:6\@<V]L
M:6-I=&%D;RX@06QG=6YS(&]U('1O9&]S(&]S(&1E=&%L:&5S(&[C;R!E<W3C
M;R!C;W)R971O<RX@5&5N=&4@;F]V86UE;G1E(&]U(&5N=')E(&5M(&-O;G1A
M=&\@8V]M(&\@861M:6YI<W1R861O<B!S92!V;V/J(&YE8V5S<VET82!D92!M
M86ES(&%J=61A+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@04-,`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@;R!C873A;&]G;R!D92!E;F1E<F7G;W,N("5S
M`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GG
MXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@;&ES=&%S(&1E(&1I
M<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A<R!C87!A
M8VED861E<R!D;R!S97)V:61O<@!.XV\@9F]I('!O<W/M=F5L(')E=F5R=&5R
M(&$@8V]N9FEG=7)AY^-O+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!D
M:7)E=/-R:6\@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!S86QV87(@82!C;VYF
M:6=U<F'GXV\@)7,N`$[C;R!F;VD@<&]S<^UV96P@<V%L=F%R('5M(&)A8VMU
M<"!D82!C;VYF:6=U<F'GXV\N`$[C;R!F;VD@<&]S<^UV96P@<V%L=F%R('5M
M(&)A8VMU<"!D82!C;VYF:6=U<F'GXV\Z("5S`$[C;R!F;VD@<&]S<^UV96P@
M<V%L=F%R(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C
M;R!E;3H@)R5S)RX`3N-O(&-O;G-E9W5I('-A;'9A<B!O(&)A8VMU<"!D;R!A
M<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX`3N-O(&-O;G-E9W5I('-A;'9A
M<B!O(&%R<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+B!6;V/J('!O9&4@;W4@
M=71I;&EZ87(@=6UA(&1A<R!O<.?U97,@<&%R82!S86QV87(@;R!C\V1I9V\@
M9&4@=F]L=&$@96T@)7,@;W4@8V]P:6%R(&UA;G5A;&UE;G1E(&\@8_-D:6=O
M(&%B86EX;R!P87)A("5S+@!.XV\@9F]I('!O<W/M=F5L('!E<W%U:7-A<B!N
M;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!L
M:6YK("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@871U86QI>F%R(&\@8V]N=&%T
M;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!A='5A;&EZ87(@82!L:7-T82!D92!D
M:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@9W)A=F%R(&$@8V]N
M9FEG=7)AY^-O(&1E("<E<R<Z("5S`$[C;R!F;VD@<&]S<^UV96P@96YC;VYT
M<F%R(&$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA+B!#97)T:69I<75E+7-E
M('%U92!E;&$@97-TX2!A8F5R=&$N`$[C;R!F;VD@<&]S<^UV96P@9&%R(&%O
M('5S=>%R:6\@)7,@;W,@<V5G=6EN=&5S(&1I<F5I=&]S('!A<F$@82!P87-T
M82`G)7,G.B`E<P!497AT;R!C;VYT861O`%!A[7,`0W5R<V]S`$-R:6%R`$-R
M:6%R($-A=.%L;V=O(&1E($5N9&5R9>=O<P!#<FEA<B!U;2!L:6YK`$-R:6%R
M('5M82!N;W9A($QI<W1A(&1E($-O;G1A=&]S(&5M.@!#<FEA<B!U;6$@;F]V
M80!#<FEA<B!S=6(@<&%S=&%S`$-R:6%D;P!097)M:7-S]65S(&1O(&-R:6%D
M;W(`3OIM97)O(&1O(&-A<G3C;R!D92!C<NED:71O`$-R;^%C:6$`0W5B80`T
M($9A<V5S($%T=6%I<P!397-S]65S($%T=6%I<P!(;W)A($%T=6%L`$$@55),
M(&%T=6%L(.D`57-UX7)I;W,@;F\@;6]M96YT;P!#;&EM82!!='5A;`!#;VYD
M:>?C;R!A='5A;#H@`$5S=&EL;R!A='5A;`!#=7-T;VUI>F$@=&%R969A<R!A
M('-E<F5M(&5X96-U=&%D87,@86\@8V]N96-T87(@82`E<RX`0V]R=&%R`$-O
M<G1A<B!S96QEY^-O`$-H:7!R90!#:7+M;&EC;R`H2T])."U2*0!#:7+M;&EC
M;R`H5VEN9&]W<RTQ,C4Q*0!#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52D`
M4F5P^F)L:6-A(%1C:&5C80!$1`!$4TX@*'9E:F$@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!$:6%R:6%M96YT90!.879E9V%D;W(@9&4@1&%T851R964`4&5S<75I
M<V$@;F\@0F%N8V\@9&4@1&%D;W,`1&%T80!$871A(&1E(%)E8V5B:6UE;G1O
M`%-E;&7GXV\@9&4@9&%T80!$:6$`15]X8VQU:7(@0V]L=6YA`$1E>F5M8G)O
M`$[Z;65R;W,@9&5C:6UA:7,`4F5C=6%R($ED96YT8>?C;P!0861RXV\`0V]R
M(%!A9'+C;P!)9&5N=&ED861E(%!A9'+C;P!3:&5L;"!0861RXV\`1&ER9>?C
M;R!D92!O<F1E;F'GXV\@<&%D<N-O.@!$969I;FGG]65S`$5X8VQU:7(`17AC
M;'5I<B!O($-A=.%L;V=O(&1E($5N9&5R9>=O<P!%>&-L=6ER(&/I;'5L80!#
M;VYF:7)M8>?C;R!D92!%>&-L=7/C;P!%>&-L=6ER($=R=7!O`$5X8VQU:7(@
M3&]G`$5X8VQU:7(@4&5R;6ES<^-O`$5X8VQU:7(@92!P=7)G87(@;65N<V%G
M96YS`$-O;7!O<G1A;65N=&\@9&\@8F]TXV\@9&4@97AC;'5SXV\`17AC;'5I
M<B!CZ6QU;&$`17AC;'5I<B!C;VQU;F$`17AC;'5I<B!M;V1E;&\@<W5B<W1I
M='5T;R!E>&ES=&5N=&4`02!E>&-L=7/C;R!F86QH;W4Z("@E<RD@)7,`17AC
M;'5I<B!P97)M:7-S]65S('!A<F$@)R5S)P!%>&-L=6ER('!E<FUI<W/U97,@
M<&%R82`G)7,G(&4@<75A;'%U97(@;W5T<F$@<W5B+7!E<FUI<W/C;S\`17AC
M;'5I<B!L:6YH80!%>&-L=6ER(&ED96YT:61A9&4@<V5L96-I;VYA9&$`17AC
M;'5I<B!A(&-O;'5N82!A='5A;`!%>&-L=6ER(&$@;&EN:&$@871U86P`4V-R
M:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R`G)7,G(&5X8VQU
M[61O+@!%>&-L=7/C;R!D92!C;VYT871O<R!NXV\@97-TX2!D:7-P;V[M=F5L
M+@!!(&5X8VQU<^-O(&9A;&AO=0!(;W)A(&1E(&5N=')E9V$`1&EN86UA<F-A
M`$1E<&%R=&%M96YT;P!$97-C96YD96YT90!$97-C<F5V82!O('!R;V)L96UA
M`$1E<V-R:>?C;P!$971A;&AE<R`H=&%M8NEM(&YO(')E9VES=')O(&1E(&%T
M:79I9&%D97,@9&\@2&]R9&4I.@!/<R!D971A;&AE<R!F;W)A;2!G<F%V861O
M<R!E;2!L;V<@<&%R82!O(&%D;6EN:7-T<F%D;W(N`$1E<V5N=F]L=FEM96YT
M;P!0;VYT;R!D92!/<G9A;&AO`%!O;G1O(&1E($]R=F%L:&\@<&%R82!A(/IL
M=&EM82!H;W)A.B``4&]N=&\@9&4@3W)V86QH;SH@`$1I<F7GXV\@9&$@97-Q
M=65R9&$@<&%R82!D:7)E:71A`$1I<F7GXV\@9&$@9&ER96ET82!P87)A(&5S
M<75E<F1A`$1I<F5T\W)I;P!%>&EB:7(`17AI8FER(&5M(&9O<FUA=&\@,C0@
M:&]R87,_`$]PY_5E<R!D92!%>&EB:>?C;P!%>&EB:7(@<')E=FESXV\@9&5T
M86QH861A`$5X:6)I<B!P<F5V:7/C;R`H5$%&*0!%>&EB:7(@9F]R;6%T;P!.
M;W1I9FEC8>?C;R!D92!$:7-P;W-IY^-O`$1J:6)U=&D`3N-O(&5X8VQU:7(`
M3N-O(&%C97-S92!D:7)E=&%M96YT92!M86EN=&5N86YC92YP:'``5F]CZB!D
M97-E:F$@8V]N9FER;6%R(&$@97AC;'5SXV\@9&4@<F5G:7-T<F]S/P!!('!R
M:6UE:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S/R!392!S
M:6TL(&-L:7%U92!N97-T82!C86EX83H`1&]M:6YI8V%N80!297#Z8FQI8V$@
M1&]M:6YI8V%N80!.XV\@=&5M('5M82!C;VYT83\@0V%D87-T<F4M<V4N`$)A
M:7AA<@!"86EX87(@)7,`0F%I>&%R(&$@8V]N9FEG=7)AY^-O(&=E<F%D82!C
M;VUO('5M('-C<FEP="!02%`N`$)A:7AA<B!V0V%R9`!,:7-T82!D92!S96QE
MY^-O`$1R;V=A<P!#;W)R96EO`$-O;F5C=&]R(&1O(&=A=&5W87D@14UA:6PM
M<&%R82U335,L('!A<F$@;W!E<F%D;W)A<R!Q=64@9&ES<&]N:6)I;&EZ86T@
M97-T92!S97)V:>=O+@!%4E(`17%U861O<@!%9&ET87(`161I=&%R("<E<R<`
M17AP;W)T87(@0V%TX6QO9V\@9&4@16YD97)EYV]S`$5D:71A<B!";&]C;P!%
M9&ET87(@1W)U<&\`161I=&%R(%!E<FUI<W/C;P!%9&ET87(@4&5R;6ES<_5E
M<P!%9&ET87(@4&5R;6ES<_5E<R!P87)A("5S`$5D:71A<B!R96=I<W1R;R!D
M92`E<P!%9&ET87(@;W#G]65S(&1E.@!%9&ET87(@<&5R;6ES<_5E<R!P87)A
M("5S`$5D:71A<B!P97)M:7-S]65S('!A<F$@)7,`161U8V'GXV\`16=I=&\`
M16P@4V%L=F%D;W(`16QE;65N=&\N+BX`16T`12UM86EL`$5N9&5R9>=O(&1E
M($4M36%I;`!/(&5N9&5R9>=O(&1E(&4M;6%I;"!D979E(&-O<G)E<W!O;F1E
M<BX`365N<V%G96T@8V]M(&-O;F9I<FUAY^-O`$=A=&5W87D@9&4@14UA:6PM
M<&%R82U335,`16UO=&EC;VYS`$UE;G-A9V5M(&5M(&)R86YC;RX`4F5S=6QT
M861O(&5M(&)R86YC;RX`5&5R;6]S(&1E('!E<W%U:7-A(&5M(&)R86YC;P!(
M86)I;&ET87(@:6YS97+GXV\@9&4@:6UA9V5N<R!A('!A<G1I<B!D82!'86QE
M<FEA(&1E($EM86=E;G,@;F\@=&5X=&\_`$AA8FEL:71A<B!M96YU(&1E(&-O
M;G1E>'1O(&-O;2!O(&)O=.-O(&1I<F5I=&\_`$9I;F%L(&1O(&%N;P!!=6UE
M;G1A<B!%9&ET;W(`1F]R;F7G82!U;6$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A
M(&$@<75A;"!V;V/J('-E<N$@<&5R9W5N=&%D;R!S92!V;V/J(&YE8V5S<VET
M87(@9V5R87(@=6UA(&YO=F$@<V5N:&$L(&5X+B`G<75A;"!O(&YO;64@9&\@
M<V5U(&-A8VAO<G)O/R<Z`$9O<FYEYV$@82!54DP@9&$@:6UA9V5M(&%Q=6D`
M1&EG:71E(&%S(&QE=')A<R!A8F%I>&\Z`$\@<F5G:7-T<F\@9&4@)7,@9F]I
M(&%T=6%L:7IA9&\L(&UA<R!F86QH;W4@86\@<V5R(&5N=FEA9&\Z("5S`%)E
M9VES=')O(&1E("5S(&9O:2!A='5A;&EZ861O+@!'=6ENZ2!%<75A=&]R:6%L
M`$5R:71RZ6EA`$5R<F\`17)R;R!A;R!A9&EC:6]N87(@)60@8V]N=&%T;RAS
M*2#@(&QI<W1A+@!%<G)O(&%O(&%D:6-I;VYA<B`E9"!D92`E9"!C;VYT871O
M*',I('-O;&EC:71A9&\H<RD@X"!L:7-T82X`17)R;R!A;R!C<FEA<B!B;&]C
M;SH@)7,`17)R;R!A;R!E>&-L=6ER("5D(&-O;G1A=&\H<RDN`$5R<F\@86\@
M97AC;'5I<B`E9"!D92`E9"!C;VYT871O*',I('-O;&EC:71A9&\H<RDN`$5R
M<F\@86\@97AC;'5I<B#B;F-O<F$@9&4@<VEN8W)O;FEZ8>?C;SH@)7,`17)R
M;R!A;R!E>&-L=6ER(&QO9R!D92!S:6YC<F]N:7IAY^-O.B`E<P!%<G)O(&%O
M(&]B=&5R(&-O;G1E^F1O.B`E<P!%<G)O(&%O(&5X8VQU:7(@)60@8V]N=&%T
M;RAS*2!D82!L:7-T82X`17)R;R!A;R!E>&-L=6ER("5D(&1E("5D(&-O;G1A
M=&\H<RD@9&$@;&ES=&$N`$9A;&AA(&%O('!E<W%U:7-A<B!N;R!C873A;&]G
M;R!D92!E;F1E<F7G;W,Z("5S`$5R<F\@86\@871U86QI>F%R(&$@<V5N:&$Z
M("5S`$5R<F\@;F$@;65N<V%G96TN`$5R<F\@9W)A=F%N9&\@)R5S)RX`17-T
M]&YI80!%=&GS<&EA`,ET;FEC;P!%=7)O<&$`0V%D82`Q-2!M:6YU=&]S`$-A
M9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI;G5T;W,`
M0V%D82!#;VYE>.-O`$-A9&$@;65I82!H;W)A`$-A9&$@;6EN=71O`%9A;&]R
M97,@9&4@97AE;7!L;SH`17AE8W5T87(`17AP86YD:7(`17AP86YD:7(@0F%R
M<F$@3&%T97)A;`!%<W!E<F%D;R`G*2<`17-P97)A9&\@=6UA('!A;&%V<F$@
M;W4@=&5R;6\@9&4@<&5S<75I<V$@96YT<F4@87-P87,`1&%T82!D92!%>'!I
M<F'GXV\`17AP;V5N=&4`17AP;W)T87(`17AP;W)T87(@0V%TX6QO9V\@9&4@
M16YD97)EYV]S`$5X<&]R=&%R('-O;65N=&4@;W,@8V]N=&%T;W,@<V5L96-I
M;VYA9&]S+@!%>'!O<G1A<B!O<R!S96=U:6YT97,@8V%TX6QO9V]S(&1E(&5N
M9&5R9>=O<R!C;VUP;&5T86UE;G1E+@!#;W(@9&\@<')I;65I<F\@<&QA;F\`
M0V]N9FEG=7)AY^-O(&1E(&5N=FEO(&1E(&%R<75I=F]S($944`!&86QH82!O
M8G1E;F1O('!R969E<NIN8VEA<RX`1F%L:&$@86\@86-E<W-A<B!O(&-A=.%L
M;V=O(&1E(&5N9&5R9>=O<SH@)7,`1F%L:&$@86\@861I8VEO;F%R("5S(&5M
M("5S.B`E<P!&86QH82!A;R!E>&EB:7(@82!L:7-T86=E;0!&86QH82!A;R!E
M>&EB:7(@;R!D:7)E=/-R:6\`1F%L:&$@86\@86QT97)A<B!O(&YO;64Z("@E
M<RD@)7,[($%N=&EG;R!$3B`]("5S+"!.;W9O($1.(#T@)7,L(%)A:7H@/2`E
M<P!&86QH82!A;R!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+@!&86QH82!A
M;R!C;VYE8W1A<B!A;R!S97)V:61O<B!334(N`$9A;&AA(&%O(&-O<&EA<B!D
M92`B)7,B+@!&86QH82!A;R!C;W!I87(@<&%R82`B)7,B+@!&86QH82!A;R!C
M<FEA<B!U;6$@;F]V82!C;VYE>.-O(%-!4TPN`$9A;&AO=2!E;2!E;F-O;G1R
M87(@;R!O8FIE=&\@82!S97(@861I8VEO;F%D;SH@)7,`1F%L:&$@86\@;6]V
M97(@<&%R82`B)7,B+@!&86QH82!A;R!O8G1E<CH@)7,`1F%L:&$@86\@<&5S
M<75I<V%R(&YO(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!&86QH;W4@96T@<&5S
M<75I<V%R(&YO(&1I<F5T\W)I;SH@)7,`2G5S=&\`26QH87,@1F%L:VQA;F0@
M*$UA;'9I;F%S*0!);&AA<R!&87)O90!%<G)O($9A=&%L.@!&87@`1F%X97,`
M1F5V97)E:7)O`%-E;G-AY^-O(%3I<FUI8V$`4V5N<V'GXV\@=.ER;6EC83H@
M`%!A;F-A9&%S(&1E($-H=79A`$YE=F4@1G)A8V$`36%T<FEZ(&1O(&-A;7!O
M`$9I9VQE="!#05!40TA!`$9O;G1E($9I9VQE=`!&:6II`&%R<75I=F\`0V]N
M=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\`0V]N=&%G96T@9&4@07)Q
M=6EV;W,Z("5S(&%R<75I=F]S`$=E<F5N8VEA9&]R(&1E($%R<75I=F]S`$YO
M;64@9&\@07)Q=6EV;P!396QEY^-O(&1E(&%R<75I=F\`16YV:6\@9&4@87)Q
M=6EV;P!%;G9I;R!D92!A<G%U:79O<R!NXV\@Z2!S=7!O<G1A9&\N`$%R<75I
M=F]S`$9I;'1R;W,`16YC;VYT<F%R`$9I;F%L:7IA<@!&:6YLXFYD:6$`4')I
M;65I<F$@365T861E`%!R:6UE:7)O($YO;64`4')I;65I<F\@475A<G1O`%1A
M>&$@9FEX80!':7)A<@!$:7-P;W-IY^-O`$[I=F]A`%!A<W1A("5S(&[C;R!E
M>&ES=&4`0V]R(&1A($9O;G1E`$-O;6ED80!087)A(&YA=F5G861O<F5S('%U
M92!NXV\@<W5P;W)T86T@:6UA9V5N<P!0<F5V:7/C;R`H5$%&*0!$:6%S(%!R
M979I<W1O<R`H3F]T92!Q=64@82!P<F5V:7/C;R!R971O<FYA9&$@97AI8F4@
M86UB;W,@9&EA(&4@;F]I=&4[('5M(&[Z;65R;R!M=6ET;R!A;'1O(&%Q=6D@
M<&]D92!R97-U;'1A<B!E;2!U;2!B;&]C;R!E>'1E;G-O*0!%<W%U96-E=2!A
M('-E;FAA/P!&;W)M=6SA<FEO<P!3;W)T90!4:7!O(&1E(%-O<G1E`%-O<G1E
M<P!3;W)T97,@,@!&\W)U;G,`4F5D:7)E8VEO;F%M96YT;W,`4V5X`%%U861R
M;W,`1G)A;N=A`$9R86[G82!-971R;W!O;&ET86YA`%523"!,:79R92]/8W5P
M861O`$=U:6%N82!&<F%N8V5S80!0;VQI;NES:6$@1G)A;F-E<V$`5&5R<FET
M\W)I;W,@1G)A;F-E<V5S(&1O(%-U;`!$90!$;RAA*0!$97-C<FGGXV\@0V]M
M<&QE=&$`3'5A($-H96EA`$YO;64@0V]M<&QE=&\`1V%BXV\`1V%L97)I82!D
M92!O;F1E(&]B=&5R(&%S(&EM86=E;G,`1V%L97)I83H`1^)M8FEA`$=E<F%R
M(&$@0V]N9FEG=7)AY^-O(&1E("5S`$/S9&EG;R!'97)A9&\`1V7S<F=I80!!
M;&5M86YH80!'86YA`$=I8G)A;'1A<@!0<FEM96ER;R!.;VUE`$-A=.%L;V=O
M(&1E($5N9&5R9>=O<R!';&]B86P`3W#G]65S($=L;V)A:7,`27(`1V]E9&5L
M`$=O;V=L92!-87!A<P!097-Q=6ES87(@;F\@1V]O9VQE`$5S8V%L82!D92!#
M:6YZ87,`1W+I8VEA`$=R96=O("A)4T\M.#@U.2TW*0!'<F]E;.)N9&EA`$=R
M86YA9&$`1W)U<&\`061M:6YI<W1R8>?C;R!D92!'<G5P;W,`3F]M97,@9&4@
M9W)U<&]S(&[C;R!D979E;2!E<W1A<B!E;2!B<F%N8V\`1W)O=7!?;&1A<#H@
M26UP;W-S[79E;"!A9&EC:6]N87(@9W)U<&\@)7,N($ES=&\@Z2!O('%U92!O
M('-E<G9I9&]R(&1I<W-E.B``1W)O=7!?;&1A<#H@26UP;W-S[79E;"!E>&-L
M=6ER(&=R=7!O("5S`$=R;W5P7VQD87`Z($EM<&]S<^UV96P@871U86QI>F%R
M(&=R=7!O("5S`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!'=6%T96QA;6$`1W5E
M<FYS97D`4&5R;6ES<_5E<R!D92!#;VYV:61A9&\`3&EV<F\@9&4@5FES:71A
M<P!'=6ENZ0!'=6ENZ2U":7-S874`1W5I86YA`$A434P`2%1-3$%R96$@<V4@
M;F5G82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA(&/I;'5L82!D
M82!L:6YH82X`2%1-3$%R96$@<V4@;F5G82!C;W9A<F1E;65N=&4@82!E>&-L
M=6ER(&$@^FQT:6UA(&-O;'5N82!D82!T86)E;&$N`$A434Q!<F5A('-E(&YE
M9V$@8V]V87)D96UE;G1E(&$@97AC;'5I<B!A(/IL=&EM82!L:6YH82!D82!T
M86)E;&$N`$%U=&5N=&EC8>?C;R!(5%10(&[C;R!E;F-O;G1R861A+@!(86ET
M:0!!;&=O<FET;6\@2&%S:`!.96)L:6YA`$-A8F7G86QH;P!#86)EYV%L:&\`
M26QH82!(96%R9"!E($EL:&%S($UC1&]N86QD`%1E;7!E<W1A9&4@1F]R=&4`
M2&5B<F5U("A)4T\M.#@U.2TX+4DI`$%L='5R80!!:G5D80!!:G5D82!D;R!E
M9&ET;W(`07-S:7-T96YT90!(96UI<V;I<FEO`$%Q=6D@97-TX2!O(&EN[6-I
M;R!D;R!A<G%U:79O.@!!;'1A`$E?;NUC:6\`4V%N=&$@4^D@*$-I9&%D92U%
M<W1A9&\@9&\@5F%T:6-A;F\I`$EN[6-I;P!%;F1E<F7G;R!297-I9&5N8VEA
M;`!#:61A9&4@9&4@4F5S:63J;F-I80!08>US(&1E(%)E<VEDZFYC:6$`1&ER
M973S<FEO(%!E<W-O86P`1F]N92!297-I9&5N8VEA;`!#15`@4F5S:61E;F-I
M86P`17-T861O(&1E(%)E<VEDZFYC:6$`16YD97)EYV\@4F5S:61E;F-I86P`
M2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!$861O(%A-
M3"`E<R!I;G;A;&ED;R!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S`$AO<F1E
M+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E<W!O;F1E(&%O(&]B:F5T
M;R`E<P!(;W)D92]+;VQA8CH@3F5N:'5M(&]B:F5T;R!D;R!T:7!O("5S(&9O
M:2!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!296UO
M=FED;R!C;VT@<W5C97-S;R`E<R`B)7,B`$AO<F1E+TMO;&%B.B!!(&5N9VEN
M92!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N<^-O(%!(4"`G9&]M>&UL
M)P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A<G9O
M<F4@6$U,('!A<F$@;R!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z($EM<&]S<^UV
M96P@<F5M;W9E<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E
M;"!O8G1E<B!A(&ED96YT:69I8V'GXV\@34E-12!P87)A(&$@<&%R=&4@9&\@
M=&EP;R`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA<B`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA
M<B!C;VUP87)T:6QH86UE;G1O<SH@)7,`2&]R9&4O2V]L86(Z($-O;7!A<G1I
M;&AA;65N=&\@9&5S8V]N:&5C:61O("(E<R(`3&EN:&$@2&]R:7IO;G1A;`!-
M87)G96T@:&]R:7IO;G1A;`!(;W)I>F]N=&%L.@!#;VUO('9O8^H@8VAE9V]U
M(&%Q=6D_("A0;W(@9F%V;W(@8V]M=6YI<75E(2D`475A;G1A<R!C;VQU;F%S
M('9O8^H@9V]S=&%R:6$@9&4@;65S8VQA<C\`475A;G1O<R!C86UP;W,@*&-O
M;'5N87,I(&5X:7-T96T_`%%U86YT87,@;&EN:&%S('9O8^H@9V]S=&%R:6$@
M9&4@;65S8VQA<C\`56UI9&%D90!5;6ED861E.B``2'5M;W)I<W1A<P!(=6YG
M<NUA`$9A;&AA(&%O(&-R:6%R(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&86QH
M82!A;R!E>&-L=6ER(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&86QH82!A;R!C
M<FEA<B!Q=6]T82!D82!C86EX82!P;W-T86P@24U!4#H@)7,`24U34`!!9&UI
M;FES=')AY^-O(&1E($-A=.%L;V=O(&1E($5N9&5R9>=O<R!)35-0`$5N9&5R
M9>=O($E0`$5N9&5R9>=O($E0(&[C;R!D:7-P;V[M=F5L+@!%;F1E<F7G;R!)
M4"!NXV\@97-TX2!N;R!B;&]C;R!P97)M:71I9&\@0TE$4BX`5FEO;&'GXV\@
M9&\@8FQO<75E:6\@25`N`$E?;G-I<F$@3&EN:&$@06YT97,`27-LXFYD:6$`
M4V]M96YT92#-8V]N97,`S6-O;F5S('!A<F$@)7,`S6-O;F5S(&4@=&5X=&\`
M3F]M92!D82!I9&5N=&ED861E.@!392!NXV\@9F]R(&5X:6)I9&\@8V]R<F5T
M86UE;G1E+"`E<R!P87)A(&%B<NTM;&\@96T@=6UA(&YO=F$@:F%N96QA+@!3
M92!V;V/J(&[C;R!VZB!N96YH=6T@[6-O;F4@86\@=71I;&EZ87(@;R!);G1E
M<FYE="!%>'!L;W)E<BP@=F]CZB!P;V1E(&-H96-A<B!E<W1A(&-A:7AA('!A
M<F$@9&5S86)I;&ET87(@82!T<F%N<W!A<NIN8VEA(%!.1RX`4V4@=F]CZB!V
MZB!E<W1A(&UE;G-A9V5M(&UA<R!NXV\@82!I;6%G96TL(&$@:6UA9V5M('%U
M92!V;V/J('%U97(@96YV:6%R(&[C;R!P;V1E('-E<B!E>&EB:61A('!E;&\@
M<V5U(&YA=F5G861O<BX`4'+I+79I<W5A;&EZ8>?C;R!D82!);6%G96TZ`%52
M3"!D82!);6%G96T`55),(&1A($EM86=E;3H`26UA9V5M(&1A(&=A;&5R:6$`
M26UA9V5M(&1A(&=A;&5R:6$Z`$5N=FEO(&1E($EM86=E;0!);6%G96YS`$EM
M<&]R=&%R($-A=.%L;V=O(&1E($5N9&5R9>=O<RP@4&%S<V\@)60`26UP;W)T
M87(L(%!A<W-O("5D`$EM<&]R=&%R+T5X<&]R=&%R($-A=.%L;V=O(&1E($5N
M9&5R9>=O<P!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O<R!I;7!O<G1A9&]S
M.@!);E]S97)I<B!,:6YH82!!</-S`$/S9&EG;R!D92!AY^-O(&9O<FYE8VED
M;R!E<W3A(&EN8V]R<F5T;RX`57-UX7)I;R!E+V]U('-E;FAA(&EN8V]R<F5T
M;W,N`%5S=>%R:6\@;W4@96YD97)EYV\@86QT97)N871I=F\@:6YC;W)R971O
M<RX@5&5N=&4@;F]V86UE;G1E(&]U(&5N=')E(&5M(&-O;G1A=&\@8V]M(&\@
M861M:6YI<W1R861O<B!S92!V;V/J(&YE8V5S<VET82!D92!M86ES(&%J=61A
M+@!!=6UE;G1A<B!)9&5N=&'GXV\`S6YD:6$`57-UX7)I;W,@:6YD:79I9'5A
M:7,`26YD;V[I<VEA`$EN9F]R;6'GXV\`26YF;W)M8>?C;P!.XV\@97AI<W1E
M;2!O<.?U97,@9&ES<&]N[79E:7,N`$EN<V5R:7(@0U]O;'5N82!!</-S`$EN
M<V5R:7(@26UA9V5M`$EN<V5R:7(@5&%B96QA`$EN<V5R:7(@3&EN:R!D82!7
M96(`26YS97)I<B!?0V]L=6YA($%N=&5S`$EN<V5R:7(@=6UA(&YO=F$@8V]L
M=6YA(&%P\W,@82!A='5A;`!);G-E<FER('5M82!N;W9A(&-O;'5N82!A;G1E
M<R!D82!A='5A;`!);G-E<FER('5M82!N;W9A(&QI;FAA(&%P\W,@82!A='5A
M;`!);G-E<FER('5M82!N;W9A(&QI;FAA(&%N=&5S(&1A(&%T=6%L`$EN<V5R
M:7(@=6T@<&%RX6=R869O(&%P\W,@;R!A='5A;`!);G-E<FER('5M('!A<N%G
M<F%F;R!A;G1E<R!D;R!A='5A;`!);G-E<FER('5M(&UO9&5L;R!A;'1E<FYA
M=&EV;P!&;W)N9>=A('5M(&5N9&5R9>=O(&1E(&4M;6%I;"!N;R!Q=6%L('9O
M8^H@<&]D92!R96-E8F5R(&$@;F]V82!S96YH83H`26YS97)I<B!CZ6QU;&$@
M87#S<P!);G-E<FER(&/I;'5L82!A;G1E<P!);G-E<FER(&-O;'5N82!A</-S
M`$EN<V5R:7(@8V]L=6YA(&%N=&5S`$EN<V5R:7(@;65N<V%G96YS`$EN<V5R
M:7(@<&%RX6=R869O(&%P\W,`26YS97)I<B!P87+A9W)A9F\@86YT97,`26YS
M97)I<B!L:6YH82!A</-S`$EN<V5R:7(@;&EN:&$@86YT97,`1F]R;F7G82!A
M(')E<W!O<W1A(&]B<FEG873S<FEA('!A<F$@82!P97)G=6YT82!D92!S96=U
M<F%NYV$Z`$EN<V5R:7(O06QT97)A<B!);6%G96T`26YS97)I<B]!;'1E<F%R
M($QI;FL`0W+I9&ET;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I87(@<&%R82!A
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX`0W+I9&ET;R!I;G-U9FEC:65N=&4N
M`$[Z;65R;R!);G1E:7)O`$QI<W1A(&1E($EN=&5I<F]S`$E$($EN=N%L:61O
M`$-$52`H0V%B9>=A;&AO(&1E($1A9&]S(&1E(%5S=>%R:6\I(&EN=N%L:61O
M+@!$861O<R!:25`@:6YVX6QI9&]S`$-A=.%L;V=O(&1E(&5N9&5R9>=O<R!I
M;G;A;&ED;P!!<&QI8V'GXV\@:6YVX6QI9&$N`$ED96YT:69I8V'GXV\@9&\@
M8F%T8V@@:6YVX6QI9&$N`$1A9&]S(&5N=FEA9&]S('/C;R!I;G;A;&ED;W,N
M`$5N9&5R9>=O(&1E(&1E<W1I;F\@Z2!I;G;A;&ED;RX`12UM86EL(&EN=N%L
M:61O`%)E9VES=')O(&EN=N%L:61O`$9O<FUA=&\@9&\@87)Q=6EV;R#I(&EN
M=N%L:61O`$-H879E(&5S<&5C:69I8V%D82!I;G;A;&ED82X`3OIM97)O(&1E
M(&QI8V5NYV$@:6YVX6QI9&\N`$QO8V%L:7IAY^-O(&9O<FYE8VED82#I(&EN
M=N%L:61A+@!4:7!O(&1A(&UE;G-A9V5M(.D@:6YVX6QI9&\N`$YO;64@:6YV
MX6QI9&\`3V)J96-T260@:6YVX6QI9&\`07!I7VED(.D@:6YVX6QI9&\@;W4@
M97-TX2!F86QT86YD;RX`4&%RXFUE=')O<R!I;G;A;&ED;W,@;W4@9F%L=&%N
M9&\N`%!E<FUI<W/U97,@9&\@<&%I('/C;R!I;G;A;&ED87,N`%!E<FUI<W/U
M97,@9&\@<&%I('/C;R!I;G;A;&ED87,N`$/S9&EG;R!D;R!P<F]D=71O(.D@
M:6YVX6QI9&\N`%!R;W1O8V]L;R!I;G;A;&ED;RX`1&5S=&EN873A<FEO(&EN
M=N%L:61O.B`G)7,G`$]B:F5T;R!C;VUP87)T:6QH861O(&EN=N%L:61O`$9O
M;G1E(&1O(&5N9&5R9>=O(&EN=N%L:61A+@!$861O<R!U;FEC;V1E(&EN=N%L
M:61O<RX`26YV96YTX7)I;P!);G9E<G1E<B!S96QEY^-O`$ERXRP@4F5P^F)L
M:6-A($ES;.)M:6-A(&1O`$ER87%U90!)<FQA;F1A`$EL:&$@9&\@2&]M96T`
M5&5M<&5S=&%D97,@27-O;&%D87,`27-R865L`$5M:7-S;W(`273A;&EC;P!)
M=.%L:6$`2F%M86EC80!*86YE:7)O`$IA<.-O`$IA<&]NZG,@*$E33RTR,#(R
M+4I0*0!*97)S97D`2F]R9.)N:6$`2G5L:&\`2G5N:&\`2G5S=&EF:6-A<@!!
M;&EN:&%R(&%O($-E;G1R;P!*=7-T:69I8V%R`$%L:6YH87(@X"!%<W%U97)D
M80!!;&EN:&%R(.`@1&ER96ET80!#87IA<75I<W3C;P!-86YT97(@;R!O<FEG
M:6YA;#\`477J;FEA`%-E<G9I9&]R(&ME<F)E<F]S(')E:F5I=&]U(&$@875T
M96YT:6-AY^-O+@!.;W9A=&]S(&1E($ME<FYE;`!#<FEAY^-O(&1E($-H879E
M`$EM<')E<W/C;R!$:6=I=&%L(&1A($-H879E`%1A;6%N:&\@9&$@0VAA=F4`
M5&EP;R!D82!#:&%V90!5<V\@9&$@0VAA=F4`0VAA=F4@:N$@97AI<W1E(&YO
M('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RX`0W)I86[G87,`2VER:6)A
M=&D`0V]RZ6EA+"!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D80!#
M;W+I:6$L(%)E</IB;&EC82!D80!#;W)E86YO("A%54,M2U(I`$MU=V%I=`!1
M=6ER9W5I<W3C;P#)(&]B<FEG873S<FEO('-U<&]R=&4@82!,1$%0(&UA<R!O
M(&WS9'5L;R!,1$%0(&[C;R!E<W3A(&1I<W!O;NUV96P@;W4@;N-O(&9O:2!C
M87)R96=A9&\N`$QA7WEO=70`261I;VUA`$QA;R!297#Z8FQI8V$@1&5M;V-R
MX71I8V$@4&]P=6QA<@#:;'1I;6$@365T861E`-IL=&EM82!-;V1I9FEC8>?C
M;P!3;V)R96YO;64`1V5R87(@3F]V82!396YH80#:;'1I;6\@475A<G1O`-IL
M=&EM82!!='5A;&EZ8>?C;SH`VFQT:6UO(&QO9VEN.B`E<P#:;'1I;6\@;&]G
M:6XZ("5S(.`@<&%R=&ER(&1E("5S`-IL=&EM;R!L;V=I;CH@3G5N8V$`3&5T
M]&YI80!,96D`3&%Y;W5T`$1E:7AA('9A>FEO('-E('%U:7-E<B!S96T@8F]R
M9&$`3.UB86YO`$5S<75E<F1A`$-A8F7G86QH;R!E<W%U97)D;P!686QO<F5S
M(&1A(&5S<75E<F1A`$QE<V]T;P!!;6]R`$QI8NER:6$`3.UB:6$@P7)A8F4@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$-H:79I<V-O1G)A8V\`0VAU=F$@
M1G)A8V$`0VAU=F$@1G)A8V$@36%T=71I;F$`0VAU=F$@1G)A8V$@5F5S<&5R
M=&EN80!,979E<R!086YC861A<R!D92!#:'5V80!#:'5V87,@1G)A8V%S(&-O
M;2!4<F]V]65S`$YE=F4@1G)A8V$`0G)E=F4@3F5V87-C80!0;^IM87,`3&EN
M:P!,:6YK(&%P;VYT82!P87)A.@!,:6=A<B!O(&5N9&5R9>=O(&1E(&4M;6%I
M;"#@('#A9VEN82!D92!C;VUP;W-IY^-O(&%O(&5X:6)I<@!,:6YK<P!#;V]K
M:64@9&\@3&EN=7@`3&ES=&$`3&ES=&%R("T@=7-UX7)I;R!P;V1E('9E<B!A
M('!A<W1A`$QI<W1A<B!"86YC;W,@9&4@1&%D;W,`3&ES=&%R(%3S<&EC;W,@
M9&4@06IU9&$`3&ES=&%R(%1A8F5L87,`3&ES="U!<F-H:79E`$QI<W0M2&5L
M<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E
M`$QI<W0M56YS=6)S8W)I8F4`02!L:7-T86=E;2!D92!S97-S]65S(&9A;&AO
M=3H@)7,`02!L:7-T86=E;2!D92!U<W7A<FEO<R!F86QH;W4Z("5S`$QI<W1A
M9V5M(&1E('5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861A+@!,:71E<F%T=7)A
M`$QI='7B;FEA`$-A<G)E9V%N9&\N+BX`2&]R82!L;V-A;#H@`$QO8V%L:7IA
MY^-O(&4@2&]R80!296=IXV\`0V]N96-T87(`3&]G(&1A('-E<W/C;R!D92!S
M:6YC<F]N:7IAY^-O(&%N=&5R:6]R`$1E<V-O;F5C=&%R`$-O;F5C=&%R`%1A
M<F5F87,@9&4@0V]N97CC;P!/(&QO9VEN(&9A;&AO=2!P;W)Q=64@<V5U('5S
M=>%R:6\@;W4@<V5N:&$@97-T879A(&EN8V]R<F5T82X`1F%L:&$@9&4@3&]G
M:6XN`%1E>'1O(&QO;F=O`$%M;W(`0F%I>&$`06QF86)E=&\@9W)E9V\@96T@
M;6EN^G-C=6QO`$%L9F%B971O(&QA=&EN;R!E;2!M:6[Z<V-U;&\`3OIM97)O
M<R!R;VUA;F]S(&5M(&UI;OIS8W5L;P!,=7AE;6)U<F=O`$U-`$U/5$0`3R!A
M;F5X;R!-4RU43D5&(&[C;R!C;VYTZ6T@9&%D;W,N`$U31P!-86-A;P!-86-E
M9&]N:6$L($%N=&EG82!297#Z8FQI8V$@275G;W-LX79I82!D80!-861A9V%S
M8V%R`$WA9VEC;P!#;W)R96EO`$%D;6EN:7-T<F%D;W(@9&\@0V]R<F5I;P!#
M<FEA<B!L:6Y?:RXN+@!-86QA=VD`36%LX7-I80!-86QD:79A<P!-86QI`$UA
M;'1A`$=E<F5N8VEA(&$@;&ES=&$@9&4@8V%T96=O<FEA<R!E(&%S(&-O<F5S
M(&%S<V]C:6%D87,@82!E;&%S+@!-87!E86UE;G1O($UA<#(T`$UA<&5A;65N
M=&\@36%P475E<W0`36%P96%M96YT;W,@9W)A=F%D;W,N`$UA<N=O`$UA<F=E
M;0!-87)C87(@8V]M(&9L86=S($QI9&$O3N-O($QI9&$`36%R8V%R(&-O;2!O
M=71R;W,@9FQA9W,@*&5X+B!);7!O<G1A;G1E+U)E<W!O;F1I9&$I`$EL:&%S
M($UA<G-H86QL`$UA<G1I;FEC80!#;VUP87)A;F1O`$-A;7!O<R!C;W)R97-P
M;VYD96YT97,`36%U<FETXFYI80!-875R[6-I;P!#<NED:71O(&WA>&EM;R!P
M97)M:71I9&\N`$[Z;65R;R!MX7AI;6\@9&4@<&%R=&5S(&1A(&UE;G-A9V5M
M(&5X8V5D974N`%1E;7!E<F%T=7)A(&WA>&EM82!N87,@^FQT:6UA<R`R-"!H
M;W)A<SH@`%1E;7!E<F%T=7)A(&WA>&EM82!N87,@^FQT:6UA<R`V(&AO<F%S
M.B``3OIM97)O($WA>&EM;R!D92!#;VYT871O<P!.^FUE<F\@3>%X:6UO(&1E
M($)L;V-O<R!D92!0;W)T86P`5&%M86YH;R!MX7AI;6\`3OIM97)O(&WA>&EM
M;R!D92!PX6=I;F%S`$UA:6\`36%Y;W1T90!-961I8VEN80!-96UB<F]S`$QI
M<W1A(&1E($UE;G4`36]D;R!D;R!M96YU.@!-97-C;&%R(&/I;'5L87,`365N
M<V%G96T`365N<V%G96T@5F5R:69I8V%D82!C;VT@4W5C97-S;R!M87,@;R!C
M97)T:69I8V%D;R!D;R!A<W-I;F%N=&4@;N-O('#T9&4@<V5R('9E<FEF:6-A
M9&\N`$UE;G-A9V5M(&5X<&ER861A+@!4:7!O(&1E(&UE;G-A9V5M`$-L:6UA
M($UE=&%R`$)L;V-O($UE=&%R(&[C;R!D:7-P;V[M=F5L+@!";&]C;R!-971A
M<B!NXV\@9&ES<&]N[79E;"X@1&5T86QH97,@9F]R86T@9W)A=F%D;W,@96T@
M;&]G('!A<F$@;R!A9&UI;FES=')A9&]R+@!/($UE=&%R1$(@;N-O(&5S=.$@
M8V]N96-T861O+@!-Z71O9&\`3>ET;V1O("<E<R<@;N-O(&5S=.$@9&5F:6YI
M9&\`3>ET;V1O(&[C;R!D969I;FED;RX@3>ET;V1O(&-H86UA9&\Z("5S`$WI
M=')I8V$`3>EX:6-O`$UI8W)O;NES:6$L($5S=&%D;W,@1F5D97)A9&]S(&1A
M`$UE:6\`5&EP;R!-:6UE`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA
M<R`R-"!H;W)A<SH@`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`V
M(&AO<F%S.B``261A9&4@;>UN:6UA(&1A('-E;FAA(&%I;F1A(&[C;R!E>'!I
M<F]U`$5S<&5L:&\`1&EV97)S;W,`1$X@9F%L=&%N9&\@;F$@9F]N=&4@9&4@
M8V]N9FEG=7)AY^-O(&1E($Q$05`N`%!A8V]T92!014%2($A45%!?4F5Q=65S
M="!F86QT86YD;RX`0V]N9FEG=7)AY^-O(&9A;'1A;F1O+B!6;V/J('1E;2!Q
M=64@9V5R87(@96QA(&%G;W)A('-E('9O8^H@<75E<B!U=&EL:7IA<B!E<W1A
M(&%P;&EC8>?C;RX`240@9&$@;65N<V%G96T@9F%L=&%N9&\N`%!A8V]T92!O
M8G)I9V%T\W)I;R!014%2($UA:6P@9F%L=&%N9&\N`$E$(&1A('-E<W/C;R!F
M86QT86YD;RX`4V5G`$-O<G)E:6\@3?-V96P`5&5L969O;F4@0V5L=6QA<@!-
M;V1E<F%R`$1A=&$@36]D:69I8V%D80!!;'1E<F%R(%523`!!(&%L=&5R8>?C
M;R!F86QH;W4Z("@E<RD@)7,`3?-D=6QO`$UO;&1O=F$L(%)E</IB;&EC82!D
M80!-]&YA8V\`36]N9_-L:6$`3>IS(&4@86YO`$UE;G-A;&UE;G1E`$UO;G1S
M97)R870`1F%S97,@9&$@3'5A`$UA:7,@8V%M<&]S(&5N8V]N=')A9&]S(&YA
M(&QI;FAA("5D('%U92!O(&[Z;65R;R!E<W!E<F%D;R`E9"X`36%I<R!D92`Q
M(')E9VES=')O(&5N8V]N=')A9&\`36%R<F]C;W,`1W)A;F1E(%!A<G1E($QI
M;7!A`$=R86YD92!087)T92!.=6)L861O`$=R86YD92!087)T92!%;G-O;&%R
M861O`$UO=F5R`$UO=F5R($%B86EX;P!-;W9E<B#@($5S<75E<F1A`$UO=F5R
M(.`@1&ER96ET80!-;W9E<B!!8VEM80!!8F%I>&\`36]V97(@X"!E<W%U97)D
M80!-;W9E<B#@(&1I<F5I=&$`06-I;6$`36_G86UB:7%U90!#873A;&]G;R!D
M92!%;F1E<F7G;W,@375L8F5R<GD`3&ES=&%S(&1E('-E;&7GXV\@9&4@;?IL
M=&EP;&]S(&[M=F5I<P!-87!A<R!);F=L97-E<R!-=6QT:6UA<`!-^FQT:7!L
M87,@<&5S<V]A<R!C;VT@;R!E;F1E<F7G;R!;)7-=+"!M87,@;F5N:'5M82!C
M;VT@;F]M92!;)7-=(&KA(&5X:7-T90!396QEY^-O(&WZ;'1I<&QA`$UI;FAA
M($-O;G1A`%-U87,@26YF;W)M8>?U97,`365U($-A=.%L;V=O(&1E($5N9&5R
M9>=O<P!-975S($-A=.%L;V=O<R!D92!%;F1E<F7G;W,`365U(%!O<G1A;`!-
M974@3&%Y;W5T(&1E(%!O<G1A;`!":7)MXFYI80!.PT\L($5U($[#3R!#;VYC
M;W)D;P!.;VUE`$9O<FUA=&\@9&\@3F]M90!.86WM8FEA`$YA=7)U`$YE<&%L
M`$1I<F5T\W)I;R!D92!-96UB<F]S($YE=&-E;G1E<@!(;VQA;F1A`$%N=&EL
M:&%S($AO;&%N9&5S87,`55),($)A<V4@9&\@3F5T<V-A<&4`55),(&1E(%)E
M=F]G8>?C;R!D92!#02!D;R!.971S8V%P90!54DP@9&4@<&]L[71I8V%S(&1E
M($-!(&1O($YE='-C87!E`%523"!D92!296YO=F'GXV\@9&\@3F5T<V-A<&4`
M55),(&1E(%)E=F]G8>?C;R!D;R!.971S8V%P90!.;VUE(&1O('-E<G9I9&]R
M(%-33"!D;R!.971S8V%P90!#;VUE;G3A<FEO(&1O(&-E<G1I9FEC861O(&1O
M($YE='-C87!E`%1I<&\@9&4@8V5R=&EF:6-A9&\@9&\@3F5T<V-A<&4`4F5D
M90!.=6YC80!.;W9A($-A;&5D]&YI80!.;W9A($-A=&5G;W)I80!.;W9O($-O
M;G1A=&\`3F]V82!-96YS86=E;2!P87)A("5S`$QU82!.;W9A`$YO=F\@57-U
MX7)I;R`H;W!C:6]N86PI`$YO=F$@6F5LXFYD:6$`3F]V82!S96YH80!.;W9A
M('-E;FAA(&5X<&ER87+A(&5M("5X+@!!<R!N;W9A<R!S96YH87,@;N-O('/C
M;R!I9W5A:7,N`$YO=F$@:F%N96QA("A?8FQA;FLI`$YO=.UC:6%S`$=R=7!O
M<R!D92!.;W3M8VEA<P!0<O-X:6UA`%!R\WAI;6%S(#0@1F%S97,`4'+S>&EM
M87,@;W#G]65S`%!R\WAI;6$^`$YI8V%RX6=U80!!<&5L:61O`$YI9V5R`$YI
M9^ER:6$`3F]I=&4`3FEU90!.XV\`3F5N:'5M(')E9VES=')O("5S(&9O:2!E
M;F-O;G1R861O('!A<F$@)7,`3F5N:'5M(&-A=.%L;V=O(&1E(&5N9&5R9>=O
M<R!E;F-O;G1R861O+@!.96YH=6T@9&%D;R!D92!C;VYF:6=U<F'GXV\@9&ES
M<&]N[79E;"!P87)A(&5X:6)I<B!A<R!D:69E<F5NYV%S+@!.96YH=6UA(&5S
M=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(&-R:6%R(&EM86=E;G,@25-/+@!.
M96YH=6T@;6]D96QO(&1E(&)A=&-H+@!.96YH=6T@8FQO8V\@97AI<W1E(&YA
M('!O<VGGXV\@<V]L:6-I=&%D80!.96YH=6T@;F]M92!D92!A9V5N9&$@9F]R
M;F5C:61O('!A<F$@82!A=71E;G1I8V'GXV\@34-!3"X`3F5N:'5M82!A;'1E
M<F'GXV\N`$YE;FAU;2!S=6)O<F1I;F%D;R!P;V1E('-E<B!A9&EC:6]N861O
M(&$@97-T82!P97)M:7-SXV\N`$YE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF
M:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@)7,N`$YE;FAU;6$@:6YF;W)M
M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@1E10(%9&
M4RX`3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF
M:6-A9&$@<&%R82!344P@5D93+@!.96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N
M9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A(%-13"U&:6QE(%9&4RX`3F5N
M:'5M(&-O;G1A=&\@96YC;VYT<F%D;P!.96YH=6T@8W+I9&ET;R!R97-T86YT
M92X`3F5N:'5M(&1E<W1I;F\@9F]R;F5C:61O+@!.96YH=6T@87)Q=6EV;R!E
M;G9I861O`$YE;FAU;2#M8V]N92!E;F-O;G1R861O+@!.96YH=6UA(&QO8V%L
M:7IAY^-O(&-O;F9I9W5R861A+@!.96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I
M9W5R861A+@!.96YH=6UA(&UE;G-A9V5M(&9O<FYE8VED82X`3F5N:'5M(&YO
M;64@97-P96-I9FEC861O+@!.96YH=6T@;OIM97)O(&5S<&5C:69I8V%D;RX`
M4V5M('-O<G1E<R!O9F5N<VEV87,`3F5N:'5M82!S96YH82!F;W)N96-I9&$@
M<&%R82!A(&%U=&5N=&EC8>?C;R!(5%10+@!.96YH=6UA('-E;FAA(&9O<FYE
M8VED82!P87)A(&$@875T96YT:6-AY^-O($E-05`N`$YE;FAU;6$@<V5N:&$@
M9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@2V5R8F5R;W,N`$YE;FAU
M;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@3&]G:6XN
M`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@
M4$%34U=$+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT
M:6-AY^-O(%--0BX`3F5N:'5M('!A=&@@<&%R82!O(&)I;N%R:6\@9&\@3W!E
M;E-33"!F;VD@9F]R;F5C:61O+B!/(&)I;N%R:6\@9&\@3W!E;E-33"#I(&YE
M8V5S<^%R:6\@<&%R82!M86YI<'5L87(@;W,@9&%D;W,@4$M#4R`Q,BX`3F5N
M:'5M(&-A9&%S=')O('!E;F1E;G1E+@!1=6]T82!NXV\@8V]N9FEG=7)A9&$N
M`%-E;2!L:6YH87,`3F5N:'5M('-E<&%R861O<B!F;VD@97-P96-I9FEC861O
M+@!396T@;&%D;W,`07)Q=6EV;R!I;F5X:7-T96YT90!.96YH=6T@9&ER973S
M<FEO('1E;7!O<N%R:6\@9&ES<&]N[79E;"!P87)A(&\@8V%C:&4N`$YE;FAU
M;2!U<W7A<FEO(&4O;W4@<V5N:&$@9F]R;F5C:61O<RX`3F5N:'5M(&1A9&\@
M=D-A<F0@9F]I(&5N8V]N=')A9&\N`$YE;FAU;2!D861O(%A-3"!VX6QI9&\@
M<F5T;W)N861O`%-E;2!V86QO<F5S`$YE;FAU;2!V97)SXV\@96YC;VYT<F%D
M82!N82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN($=E<F4@;F]V86UE;G1E(&$@
M8V]N9FEG=7)AY^-O+@!.96YH=6UA('9E<G/C;R!E;F-O;G1R861A(&YA('-U
M82!C;VYF:6=U<F'GXV\N($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O
M+@!.96YH=6UA`$YE;FAU;6$@*'5S;R!I;7!L[6-I=&\I`$[S<F1I8V\@*$E3
M3RTX.#4Y+3$P*0!);&AA($YO<F9O;&L`2&5M:7-FZ7)I;R!.;W)T90!);&AA
M<R!-87)I86YA(&1O($YO<G1E`$YO<G5E9V$`3N-O($%P\W,`3N-O($%N=&5S
M`$[C;R#I('5M(&1I<F5T\W)I;P!.XV\@26UP;&5M96YT861O+@!.XV\@8V]N
M9FEG=7)A9&\`3N-O('-U<&]R=&%D;RX`06YO=&'G]65S`$YA9&$@<&%R82!E
M>&EB:7(L('9O;'1E+@!.;W9E;6)R;P!.^FUE<F\`3OIM97)O(&1E(&-A<F%C
M=&5R97,`3OIM97)O(&1E(&-O;'5N87,`3OIM97)O(&1E(.UT96YS('!O<B!P
MX6=I;F$`3OIM97)O(&1E(&QI;FAA<P!.^FUE<F\@;N-O(&5S<&5C:69I8V%D
M;R!P87)A(&%T=6%L:7IAY^-O(&YA(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX`
M3TL`3V)J971O`$-R:6%D;W(@9&\@3V)J971O`$]B:F5T;R!NXV\@96YC;VYT
M<F%D;P!/8W1A;`!/=71U8G)O`$9I;'1R;R!O9F5N<VEV;P!%<V-R:73S<FEO
M`%-E;FAA<R!A;G1I9V$@92!N;W9A(&1E=F5M('-E<B!D:69E<F5N=&5S+@!3
M96YH82!A;G1I9V$`4V5N:&$@86YT:6=A(&[C;R!E<W3A(&-O<G)E=&$N`$]M
MXP!5;6$@=F5Z('%U92!V;V/J('-A;'9E(&5S=&$@<.%G:6YA(&1E(&]PY_5E
M<RP@;R!C873A;&]G;R!D92!E;F1E<F7G;W,@<V5RX2!P97)M86YE;G1E;65N
M=&4@97AC;'7M9&\N(%-E(&ES=&\@;N-O(.D@;R!Q=64@=F]CZB!Q=65R+"!E
M;G3C;R!V;V/J(&1E=F4@86QT97)A<B!S=6$@<V5L9>?C;R!P87)A(").96YH
M=6TB+@!3;VUE;G1E('-E<G9I9&]R97,@24U!4"!S=7!O<G1A;2!P87-T87,@
M8V]M<&%R=&EL:&%D87,N`%-O;65N=&4@<V]R=&5S(&]F96YS:79A<P!3;VUE
M;G1E('5M(&5N9&5R9>=O(&1E(&4M;6%I;"!P97)M:71I9&\N`%-O;65N=&4@
M=6T@=F-A<F0@Z2!S=7!O<G1A9&\N`%-O;65N=&4@;R!P<F]P<FEE=.%R:6\@
M;W4@;R!A9&UI;FES=')A9&]R(&1O('-I<W1E;6$@<&]D96T@86QT97)A<B!A
M<R!P97)M:7-S]65S(&1E('!R;W!R:65D861E(&]U('!R;W!R:65TX7)I;R!D
M92!U;2!C;VUP87)T:6QH86UE;G1O`$%B<FER(&5M('5M82!N;W9A(&IA;F5L
M80!%<G)O(&1O($]P96Y34TPZ($[C;R!P=61E(&5X=')A:7(@9&%D;W,@9&$@
M<&%R=&4@87-S:6YA9&$@4R]-24U%+@!!8G)E(&5S=&4@;&EN:R!E;2!U;6$@
M;F]V82!J86YE;&$`4VES=&5M82!/<&5R86-I;VYA;`!/<.?U97,`3W#G]65S
M(&1E("5S`$QI<W1A($]R9&5N861A`$]R9V%N:7IAY^-O`%5N:61A9&4@3W)G
M86YI>F%C:6]N86P`3W)G86YI>F%N9&\`36]D96QO(&]R:6=I;F%L(&1E(&%P
M;&EC8>?C;P!-;V1E;&\@;W)I9VEN86P@96T@)7,Z`$]U=')O`$]U=')A<R!)
M;F9O<FUAY_5E<P!/=71R87,@3W#G]65S`%!E<FUI<W/U97,@9&\@4')O<')I
M973A<FEO`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E;"X`
M0V]N96-T;W(@4$5!4CHZ36%I;`!!<W-I;F%T=7)A($1I9VET86P@4$=0`$1A
M9&]S($-R:7!T;V=R869A9&]S(&-O;2!01U``0VAA=F4@4/IB;&EC82!01U``
M1&%D;W,@07-S:6YA9&]S+T-R:7!T;V=R869A9&]S(&-O;2!01U``0_-D:6=O
M(%!(4`!,:6YH82!D92!#;VUA;F1O(%!(4`!#:'5V82!&<F%C82!697-P97)T
M:6YA`$-H=79A(%9E<W!E<G1I;F$`0VAU=F%S(%9E<W!E<G1I;F%S`$YE=F4@
M5F5S<&5R=&EN80!.979A<V-A(%9E<W!E<G1I;F$`3F5V92!697-P97)T:6YA
M`%1R;W9O861A<R!697-P97)T:6YA<P!%<W3A(&9A;'1A;F1O(&$@97AT96YS
MXV\@4$]325@`3&EN:&$@9&4@0V]M86YD;R!07TA0`$UA<F=E;0!087%U:7-T
MXV\`4&%L874`4&%L97-T:6YO+"!497)R:73S<FEO($]C=7!A9&\`4&%N86WA
M`%#A<'5A($YO=F$@1W5I;ND`4&%R86=U86D`4&%R8VEA;&UE;G1E($YU8FQA
M9&\`4V5N:&$`4V5N:&$@86QT97)A9&$@8V]M('-U8V5S<V\N`%-E;FAA(&EN
M8V]R<F5T80!396YH82!O8G)I9V%T\W)I82!P87)A(&$@875T96YT:6-AY^-O
M(%)!1$E54RX`4V5N:&$@8V]M(&-O;F9I<FUAY^-O`%-E;FAA.@!396YH83H@
M`%-E;FAA<R!D979E;2!S97(@:6=U86ES+@!#;VQA<@!#;VQA<B!D82#A<F5A
M(&1E('1R86YS9F5RZFYC:6$`4&%T:`!#861A<W1R;W,@4&5N9&5N=&5S.@!0
M97-S;V%S`%!O<F-E;G1A9V5M`$5X96-U=&%R($]P97)AY_5E<R!D92!-86YU
M=&5NY^-O`$5X96-U=&%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%O(&-O
M;F5C=&%R/P!097)M:7-SXV\`4&5R;6ES<^-O("(E<R(@;N-O(&5X8VQU[61A
M+@!097)M:7-SXV\@3F5G861A`%!E<FUI<W/C;R!N96=A9&$`4&5R;6ES<_5E
M<P!!9&UI;FES=')AY^-O(&1E(%!E<FUI<W/U97,`26YF;W)M8>?U97,@4&5S
M<V]A:7,`4&5R=0!!;FEM86ES(&1E($5S=&EM8>?C;P!&:6QI<&EN87,`5&5L
M969O;F4`1F]T;W,`0V%TX6QO9V\@9&4@16YD97)EYV]S(&1O(%!I;F4`4&ET
M8V%I<FX`4&EX96QS`$-L:6-HZ0!0;W(@9F%V;W(@8VQI<75E(&5M(&%L9W5M
M82!CZ6QU;&$`4&]R(&9A=F]R(&-O;F9I<FUE('%U92!V;V/J('%U97(@<F5M
M;W9E<B!E<W1E(&5L96UE;G1O.@!0;W(@9F%V;W(@8V]N9FER;64@<75E('9O
M8^H@<75E<B!R96UO=F5R(&\@;&EN:R!D97-T92!E;&5M96YT;RX`4&]R(&9A
M=F]R(&9O<FYEYV$@=6T@;>IS(&4@=6T@86YO+@!0;W(@9F%V;W(@9F]R;F7G
M82!U;2!N;VUE('!A<F$@82!N;W9A(&-A=&5G;W)I83H`4&]R(&9A=F]R(&9O
M<FYEYV$@=6T@96YD97)EYV\@25`@=N%L:61O+@!0;W(@9F%V;W(@9F]R;F7G
M82!U;6$@9&%T82!VX6QI9&$L('9E<FEF:7%U92!O(&[Z;65R;R!D92!D:6%S
M(&YO(&WJ<RX`4&]R(&9A=F]R(&9O<FYEYV$@=6UA(&AO<F$@=N%L:61A+@!0
M;W(@9F%V;W(@9F]R;F7G82!U;2!N;VUE('!A<F$@82!N;W9A(&QI<W1A(&1E
M(&-O;G1A=&]S.@!0;W(@9F%V;W(@9F]R;F7G82!U;2!R97-U;6\@9&\@<')O
M8FQE;6$N`%!O<B!F879O<B!F;W)N9>=A('-E=2!U<W7A<FEO(&4@<V5N:&$`
M4&]R(&9A=F]R(&QE:6$@;R!T97AT;R!A('-E9W5I<BX@5F]CZB!$159%(&-O
M;F-O<F1A<B!C;VT@;W,@=&5R;6]S(&1E('5S;R!D;R!S:7-T96UA+@!0;W(@
M9F%V;W(@9&EG:71E(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83H`4&]L]&YI
M80!0;VSM=&EC80!%;G%U971E`%!O<G1U9V%L`%!O<VGGXV\@9&5S=&$@:6UA
M9V5M`%!O<VGGXV\@9&5S=&$@=&%B96QA`$5N=FEE('!A<F$@97-T82!P87-T
M82`H;N-O(.D@;V)R:6=A9&\@<&5L;R!)34%0*0!0<F5C:7!I=&'GXV\@<&%R
M82!A*',I(/IL=&EM82AS*2`E<R!H;W)A*',I.B``4')E8VEP:71AY^-O/&)R
M("\^8VAA;F-E`%!R969S7VQD87`Z($5X=&5N<^-O($Q$05`@;V)R:6=A=/-R
M:6$@;N-O(&5N8V]N=')A9&$N`%!R969S7W-E<W-I;VXZ($5X=&5N<^-O(&1E
M('-E<W/C;R!O8G)I9V%T\W)I82!NXV\@96YC;VYT<F%D82X`4')E<W/C;P!0
M<F5S<^-O(&5M(&[M=F5L(&1O(&UA<CH@`%!R97-SXV\Z(`!0<NDM=FES=6%L
M:7IAY^-O`%!R979E<B!A(&EM86=E;2!E;2!U;6$@;F]V82!J86YE;&$`06YT
M97)I;W(`3W#G]65S(&%N=&5R:6]R97,`26UP<FEM:7(@9&]C=6UE;G1O`$-A
M=.%L;V=O(&1E($5N9&5R9>=O<R!0<FEV861O`$-H879E(%!R:79A9&$`4')O
M8FQE;6$`1&5S8W)IY^-O(&1O(%!R;V)L96UA`%!R;VIE=&]S`%1E>'1O(&)R
M979E`$-H879E(%#Z8FQI8V$`06QG;W)I=&UO(&1A($-H879E(%#Z8FQI8V$`
M0VAA=F4@4/IB;&EC80!087(@9&4@8VAA=F5S(%#Z8FQI8V$O4')I=F%D82!N
MXV\@9F]R86T@9V5R861O<R!C;VT@<W5C97-S;RX`4&]R=&\@4FEC;P!1871A
M<@!#;VYS=6QT87(`02!C;VYS=6QT82!F86QH;W4Z("@E<RD@)7,`4&5S<75I
M<V$@4N%P:61A`%%A=&%R`$-H879E(%#Z8FQI8V$@4E-!("@E9"!B:70I`$)O
M=/5E<R!D92!S96QEY^-O`$-H=79A`$-H=79A($UA='5T:6YA`$-H=79A(%9E
M<W!E<G1I;F$`4&%N8V%D87,@9&4@0VAU=F$`0VAU=F$@92!.979E`$-H=79A
M('!A<F$@3F5V90!3;W)T92!!;&5A=/-R:6$`4F5L8>?C;P!,97(`02!L96ET
M=7)A(&9A;&AO=3H@*"5S*2`E<P!,97(@;65N<V%G96YS`$$@;&5I='5R82!D
M92!C;VYT871O<R!NXV\@97-TX2!D:7-P;V[M=F5L+@!%>&-L=6ER(')E86QM
M96YT92`E<S\@17-T82!O<&5R8>?C;R!NXV\@<&]D92!S97(@9&5S9F5I=&$N
M`$1E<V5J82!R96%L;65N=&4@97AC;'5I<B!E<W1E(&-O;G1A=&\_`%)E;6]V
M97(@<F5A;&UE;G1E(&]S(&1A9&]S(&1O('5S=>%R:6\@)7,_($5S=&$@;W!E
M<F'GXV\@;N-O('!O9&4@<V5R(&1E<V9E:71A+@!296=I<W1R;W,@97AI8FED
M;W,Z`%)E9F%Z('-U82#Z;'1I;6$@8>?C;P!!='5A;&EZ87(`071U86QI>F%R
M($UE;G4@9&4@16QE;65N=&]S($1I;N)M:6-O<SH`071U86QI>F%R($5X:6)I
MY^-O(&1O(%!O<G1A;#H`4F5G97@`3F%V96=A9&]R(&1E(%)E;&'G]65S`$QE
M<@!/8G-E<G9AY_5E<P!397)V:61O<F5S(%)E;6]T;W,`55),(%)E;6]T82`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V97(`4F5M;W9E
M<B!";&]C;P!%<V-O;&AA('5M(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!296UO
M=F5R(&-O;'5N80!296UO=F5R(&9O<FUA=&'GXV\`4F5M;W9E<B!D97-T82!L
M:7-T80!296UO=F5R('!A<@!296UO=F5R('-C<FEP="!G<F%V861O(&YO(&1I
M<F5T\W)I;R!T96UP;W+A<FEO(&1O('-E<G9I9&]R+@!296UO=F5R(&\`4F5M
M;W9E<B!E<W1E(&[S(&1O(&1O8W5M96YT;P!296UO=F5R('5S=>%R:6\`4F5M
M;W9E<B!U<W7A<FEO.B`E<P!3=6)S=&ET=6ER(&\@8V%TX6QO9V\@9&4@96YD
M97)EYV]S('!E;&\@:6UP;W)T861O/R`\<W1R;VYG/D%T96[GXV\Z($ES=&\@
M97AC;'5I<N$@=&]D;W,@;W,@<F5G:7-T<F]S(&1O('-E=2!C873A;&]G;R!D
M92!E;F1E<F7G;W,@871U86PN/"]S=')O;F<^`%-O;&EC:71AY^-O(&[C;R!P
M]&1E('-E<B!R97-P;VYD:61A+B!#\V1I9V\@9&4@97)R;R!R971O<FYA9&\Z
M(`!/(&]B:F5T;R!S;VQI8VET861O(&[C;R!F;VD@96YC;VYT<F%D;RX`3R!S
M97)V:>=O(')E<75I<VET861O(&[C;R!P;V1E('-E<B!E;F-O;G1R861O+@`G
M)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I
M9W5R8>?C;R`E<RX`)R5S)R!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I
M8V%D;R!N82!C;VYF:6=U<F'GXV\@5D93+@`G)7,G(&]B<FEG873S<FEO(&[C
M;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;RX`0V%M<&\@3V)R
M:6=A=/-R:6\`3&EM<&%R`$=E<F%R($YO=F$@4V5N:&$`1V5R87(@3F]V82!3
M96YH80!2971O<FYA<B!P87)A(&]S('!A9'+U97,`VFQT:6UO(%%U87)T;P!2
M97-U;'1A9&]S`%)E=&]R;F%R(.`@3W#G]65S`$1I9VET92!A(&YO=F$@<V5N
M:&$@;F]V86UE;G1E`%)E=6YIXV\`4F5V97)T97(@0V]N9FEG=7)AY^-O`$]P
MY_5E<R!D;R!%9&ET;W(@4FEC:"!497AT`$-H87)A9&%S`$1I<F5I=&$`0V%B
M9>=A;&AO(&1I<F5I=&\`5F%L;W)E<R!D82!D:7)E:71A`%!R;W!R:65D861E
M<R!D82!?3&EN:&$N+BX`1G5NY^-O`%)O;>IN:6$`1VER87(@,3@P(&=R875S
M`$=I<F%R('!A<F$@82!%<W%U97)D80!':7)A<B!P87)A(&$@1&ER96ET80!0
M<F]P<FEE9&%D97,@9&$@3&EN:&$`4')O<')I961A9&5S(&1A(&QI;FAA`$QI
M;FAA<SH`3&EN:&%S`$QI;FAA<R!A<&%R96-E<N-O(&5N=')E('1O9&%S(&%S
M(&QI;FAA<R!E(&-O;'5N87,`3&EN:&%S(&%P87)E8V5RXV\@<V]M96YT92!E
M;G1R92!C;VQU;F%S`$QI;FAA<R!A<&%R96-E<N-O('-O;65N=&4@96YT<F4@
M;&EN:&%S`$5X96-U=&%R`$9E9&5R8>?C;R!2=7-S80!2=6%N9&$`07-S:6YA
M='5R82!#<FEP=&]G<N%F:6-A(%,O34E-10!-96YS86=E;2!#<FEP=&]G<F%F
M861A(&-O;2!3+TU)344`0V5R=&EF:6-A9&\@4/IB;&EC;R!3+TU)344`075T
M96YT:6-AY^-O(%-!4TP@;N-O(&5S=.$@9&ES<&]N[79E;"X`0V]R<F5I;R!3
M35,`3&EN:&$@9&4@8V]M86YD;R!344P`4V5N=&5NYV$@4U%,('!A<F$@<&5S
M<75I<V%S(&1E('9A;&]R97,`4U-(`$\@4U1!4E143%,@9F%L:&]U.B`H)7,I
M("5S`%-50T534T\`3&EN:&$@9&4@8V]M86YD;R!37U%,`%-A8@!386YT82!(
M96QE;F$`4^-O($MI='1S(&4@3F5V:7,`4V%N=&$@3'5Z:6$`4^-O(%!E9')O
M(&4@36EQ=65L;VX`4^-O(%9I8V5N=&4@92!'<F%N861I;F%S`$UE<VUO('%U
M861R;R`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4^-O(%1O;>D@92!0<NUN
M8VEP90!0<F]V961O<B!D92!3873I;&ET90!!<N%B:6$@4V%U9&ET80!386QV
M87(`4V%L=F%R("5S`%-A;'9A<B`E<P!386QV87(@3W#G]65S`%-A;'9A<B!C
M;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@<V-R:7!T(%!(4"!P87)A(&\@
M9&ER973S<FEO('1E;7!O<N%R:6\@9&\@<V5U('-E<G9I9&]R+@!#;VYF:6=U
M<F'GXV\@)7,@<V%L=F$N`%-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF
M:6=U<F'GXV\@<V%L=F\@96TZ("<E<R<N`$\@<V%L=F%M96YT;R!D92!C;VYT
M871O<R!NXV\@97-TX2!D:7-P;V[M=F5L+@!496UP97-T861E<R!)<V]L861A
M<P!#:>IN8VEA`%!E<W%U:7-A<@!%;F=I;F5S(&1E(%!E<W%U:7-A(`!!('!E
M<W%U:7-A(&9A;&AO=0!!('!E<W%U:7-A(&9A;&AO=3H@)7,`4&5S<75I<V$@
M;N-O(&5S=.$@9&ES<&]N[79E;"X`4&5S<75I<V%N9&\N+BX`4V5L96-I;VYE
M(&]S($%R<75I=F]S`%-E;&5C:6]N92!U;6$@9&%T80!396QE8VEO;F4@=6T@
M9W)U<&\@<&%R82!A9&EC:6]N87(`4V5L96-I;VYE('5M(&YO=F\@;65M8G)O
M`%-E;&5C:6]N92!U;2!S97)V:61O<@!396QE8VEO;F4@=6T@=7-UX7)I;R!P
M87)A(&%D:6-I;VYA<@!396QE8VEO;F%R('1O9&]S`%-E;&5C:6]N92!T;V1O
M<R!O<R!C;VUP;VYE;G1E<R!D92!D871A+@!396QE8VEO;F4@=6T@8V%TX6QO
M9V\@9&4@96YD97)EYV]S('!A<F$@97AC;'5I<@!396QE8VEO;F4@=6T@8V%T
MX6QO9V\@9&4@96YD97)EYV]S('!A<F$@961I=&%R`%-E;&5C:6]N92!U;2!O
M8FIE=&\`3N-O('-E;&5C:6]N87(@;F5N:'5M`%-E;&5C:6]N92!O(&-A=.%L
M;V=O(&1E(&5N9&5R9>=O<R!P87)A(&5X<&]R=&%R.@!396QE8VEO;F4@;R!C
M873A;&]G;R!D92!E;F1E<F7G;W,@<&%R82!I;7!O<G1A<CH`4V5L96-I;VYE
M(&]S(&-A<F%C=&5R97,@<75E('9O8^H@<')E8VES82!N82!C86EX82!A8F%I
M>&\N(%9O8^H@<&]D92!E;G3C;R!C;W!IX2UL;W,@92!C;VSA+6QO<R!N82#A
M<F5A(&1E('1E>'1O+@!396QE8VEO;F4@;R!C;VYJ=6YT;R!D92!C87)A8W1E
M<F5S(&1O(&%R<75I=F\@9&4@;W)I9V5M.@!396QE8VEO;F4@=6T@9&5L:6UI
M=&%D;W(@9&4@9&%T83H`4V5L96-I;VYE(&\@9F]R;6%T;R!D92!D871A.@!3
M96QE8VEO;F4@;R!F;W)M871O('!A<F$@97AP;W)T87(Z`%-E;&5C:6]N92!O
M(&%R<75I=F\@<&%R82!I;7!O<G1A<CH`4V5L96-I;VYE(&\@9F]R;6%T;R!D
M;R!A<G%U:79O(&1E(&]R:6=E;3H`4V5L96-I;VYE(&\@9F]R;6%T;R!U=&EL
M:7IA9&\@<&%R82!E>&EB:7(@;W,@;F]M97,Z`%-E;&5C:6]N92!A(&ED96YT
M:61A9&4@<75E('9O8^H@<75E<B!A;'1E<F%R.@!396QE8VEO;F4@=6T@9&5L
M:6UI=&%D;W(@9&4@:&]R83H`4V5L96-I;VYE(&\@9F]R;6%T;R!D92!H;W)A
M.@!396QE8VEO;F4@9&]I<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S+@!396QE
M8VEO;F4@82!V:7-U86QI>F'GXV\@<&%R82!E>&EB:7(@<&]R('!A9'+C;RP@
M;W#G]65S(&1E(&]R9&5N8>?C;R!E(&]PY_5E<R!D92!P86=I;F'GXV\N`%-E
M;&5C:6]N92!Q=6%I<R!C86UP;W,@97AI8FER(&YA<R!L:7-T87,@9&4@96YD
M97)EYV]S+@!396QE8VEO;F4@96T@<75A;"!F;W)M871O(&5X:6)I<B!N;VUE
M<RX`4V5L96-I;VYE('-E=2!E<W%U96UA(&1E(&-O<F5S+@!396QE8VEO;F4@
M<V5U(&ED:6]M82!P<F5F97)I9&\Z`$-A=.%L;V=O(&1E(&5N9&5R9>=O<R!S
M96QE8VEO;F%D;R`G)7,G+@!%;G9I87(@4F5L873S<FEO(&1E(%!R;V)L96UA
M`$5N=FEA<B!335,`4V5N96=A;`!396YS;W(Z(`!3971E;6)R;P!397)V:6$@
M92!-;VYT96YE9W)O`$[Z;65R;R!D92!3Z7)I90!$861O<R!D;R!S97)V:61O
M<B!E<G)A9&]S(&]U(&[C;R!D:7-P;V[M=F5I<RX`061M:6YI<W1R861O<B!D
M92!397-SXV\`240@9&$@4V5S<^-O(&5X<&ER;W4N`%-E<W/U97,`06IU<W1A
M<@!#;VYF:6=U<F$@87,@;W#G]65S('!A<F$@<&5R;6ET:7(@=F]CZB!G97)A
M<B!U;6$@;F]V82!S96YH82!S92!V;V/J(&5S<75E8^HM;&$N`$-O;F9I9W5R
M82!O<R!S97)V:61O<F5S(')E;6]T;W,@<75E('9O8^H@<75E<B!A8V5S<V%R
M(.`@<&%R=&ER(&1O('!O<G1A;"X`0V]N9FEG=7)A('-E=2!I9&EO;6$@<')E
M9F5R:61O+"!F=7-O(&AO<N%R:6\@92!O<.?U97,@9&4@9&%T82X`0V]N9FEG
M=7)A('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@97-Q=65M82!D92!C;W)E<RP@
M871U86QI>F'GXV\@9&4@<.%G:6YA<R!E(&]U=')A<R!O<.?U97,@9&4@97AI
M8FGGXV\N`$-O;F9I9W5R8>?C;P!38W)I<'1S(&1E(&%T=6%L:7IAY^-O(&1E
M(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<P!$:79E<G-A<R!L;V-A;&ED861E
M<R!P;W-S[79E:7,@8V]M(&\@<&%RXFUE=')O.B``4V5I8VAE;&5S`$1I<F5T
M\W)I;R!#;VUP87)T:6QH861O`$-O;7!R87,`4F5S=6UO`%1E8VQA<R!D92!A
M=&%L:&\@9&5V97+C;R!S97(@9&5F:6YI9&%S('!A<F$@82!M86EO<FEA(&1O
M<R!L:6YK<S\`17AI8FER`$5X:6)I<B`E<P!%>&EB:7(@5&]D87,`17AI8FER
M($-O;G1A=&]S`$5X:6)I<B!,:7-T87,`17AI8FER(&%S(&1I9F5R96[G87,@
M96YT<F4@82!C;VYF:6=U<F'GXV\@871U86P@92!A(&YO=F$@9V5R861A+@!%
M>&EB:7(@9&%T82!E(&AO<F$@9&$@^FQT:6UA(&-O;F5XXV\@86\@<V4@8V]N
M96-T87(_`$5X:6)I<B!A(&]PY^-O(&1E(&UA;G1E<B!O(&]R:6=I;F%L`$5X
M:6)I<B!S96QE=&]R`$5X:6)I<B!B87)R82!D92!M96YU(&-O;2!O<&5R8>?U
M97,@9&4@=&%B96QA/P!%>&EB:7(@;R!-96YU("5S(.`@97-Q=65R9&$_`$5X
M:6)I<B!D:>%L;V=O(&1E(%!R;W!R:65D861E<R!D92!#Z6QU;&%S(&1A(%1A
M8F5L80!%>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&$@5&%B96QA
M`$5X:6)I<B!D:>%L;V=O(&1E(%!R;W!R:65D861E<R!D92!,:6YH87,@9&$@
M5&%B96QA`$5X:6)I<B!D:>%L;V=O(&1E('!R;W!R:65D861E<R!D92!I;6%G
M96T`17AI8FER('5P;&]A9`!#:'5V87,`0VAU=F%S(&UA=&EN86ES`$-H=79A
M<R!697-P97)T:6YA<P!#:'5V87,@;F%S(')E9&]N9&5Z87,`4F5D=7II<@!0
M<FEM96ER86UE;G1E(')E9'5Z82!O=2!T:7)E(&1O(&-A;6EN:&\@;RAS*2!B
M;&]C;RAS*2!A9&IA8V5N=&4H<RD`4V5R<F$@3&5O80!296=I<W1R87(`07-S
M:6YA='5R80!!;&=O<FET;6\@9&$@07-S:6YA='5R80!#:6YG87!U<F$`5&%M
M86YH;P!)9VYO<F%R($UA;G5T96[GXV\`17-L;W;A<75I80!%<VQO=F5N:6$`
M3F5V90!.979A<V-A`$YE=F%S8V%S`$-H=79A<R!M871I;F%I<P!.979A<V-A
M<R!697-P97)T:6YA<P!0<F]F=6YD:61A9&4@9&$@3F5V93H@`$5Q=6EV86QE
M;G1E(&1E(&YE=F4@96T@X6=U83H@`$EL:&%S(%-A;&]MXV\`4V]MX6QI80!#
M86[G]65S("8@4&]E;6%S`$1I<F7GXV\@9&4@3W)D96YAY^-O`$]R9&5N87(@
M<V5L9>?C;P!%;F1E<F7G;R!D92!O<FEG96T`1F]N=&5S`,%F<FEC82!D;R!3
M=6P`4W5L($5U<F]P974@*$E33RTX.#4Y+3,I`%-U;"!D82!'96]R9VEA(&4@
M4W5L(&1A<R!);&AA<R!386YD=>UC:&4`2&5M:7-FZ7)I;R!3=6P`17-P8>=O
M(&5N=')E(&/I;'5L87,@861J86-E;G1E<P!%<W!AYV\@96YT<F4@;R!C;VYT
M9?ID;R!E(&)O<F1A(&1A(&/I;'5L80!%<W!AYV%D;W(`17-P8>=A;65N=&\`
M17-P8>=A;65N=&\@92!M87)G96T`17-P86YH80!3<&%M`$5N=')A9&$@9&4@
M0V%R86-T97)E<R!%<W!E8VEA:7,`17-P96-I9FEQ=64@;VYD92!V;V/J('%U
M97(@<75E(&]S(')E<W5L=&%D;W,@9&$@<&5S<75I<V$@879A;N=A9&$@87!A
M<F7G86TN`$1I=FED:7(@8^EL=6QA`$1I=FED:7(@8V]L=6YA`$1I=FED:7(@
M;&EN:&$`17-P;W)T97,`4W)I($QA;FMA`%!A9'+C;P!3=&%R(%1R96L`06YO
M(&EN:6-I86P`17-T861O(&]U(%!R;W;M;F-I80!3:71U8>?C;P!&;W)M871O
M(&1O(&%R;6%Z96YA;65N=&\`3F]M92!D82!2=6$`5')AYV%D;P!,:7-T82!D
M92!C861E:6%S(&1E(&-A<F%C=&5R97,`4F5T:7)A<B!A('!A<G1E(&1O(&1O
M;>UN:6\@9&\@96YD97)EYV\`17-T:6QO(%M#4U-=`$1O;0!3=6)D:7)E=/-R
M:6\@)R5S)R!NXV\@96YC;VYT<F%D;RX`07-S=6YT;P!%;G9I87(`16YV:6%D
M82!A('-O;&EC:71AY^-O(&1E(&%D:6-I;VYA<B`B)7,B(&%O('-I<W1E;6$N
M(%9O8^H@;N-O('!O9&4@8V]N96-T87(M<V4@873I('%U92!S=6$@<V]L:6-I
M=&'GXV\@<V5J82!A<')O=F%D82X`4W5B<V-R979E<@!3=6-E<W-O`"<E<R<@
M861I8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S:7-T96UA+@`E9"!C;VYT871O
M*',I(&%D:6-I;VYA9&]S(&-O;2!S=6-E<W-O(.`@;&ES=&$N`"5S(&%D:6-I
M;VYA9&\@8V]M('-U8V5S<V\@X"`E<P!/<R!D861O<R!D;R!U<W7A<FEO("<E
M<R<@9F]R86T@<F5M;W9I9&]S(&1O('-I<W1E;6$@8V]M('-U8V5S<V\N`$QI
M<W1A(&1E(&-O;G1A=&]S("(E<R(@8W)I861A(&-O;2!S=6-E<W-O+@`G)7,G
M(&5X8VQU[61O(&-O;2!S=6-E<W-O+@`E9"!C;VYT871O*',I(&5X8VQU[61O
M*',I(&-O;2!S=6-E<W-O+@!%>&-L=>UD;R`G)7,G(&1O('-I<W1E;6$@8V]M
M('-U8V5S<V\N`"5D(&-O;G1A=&\H<RD@97AC;'7M9&]S(&-O;2!S=6-E<W-O
M(&1A(&QI<W1A+@!#;VYF:6=U<F'GXV\@<F5V97)T:61A(&-O;2!S=6-E<W-O
M+B!!='5A;&EZ92!P87)A('9E<B!A<R!A;'1E<F'G]65S+@!"86-K=7`@9&$@
M8V]N9FEG=7)AY^-O('-A;'9A(&-O;2!S=6-E<W-O+@!/(&)A8VMU<"!D;R!A
M<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<R!F;VD@<V%L=F\@8V]M('-U8V5S
M<V\N`"<E<R<@871U86QI>F%D;R!C;VT@<W5C97-S;P`E<R!G<F%V861O(&-O
M;2!S=6-E<W-O`%-U9.-O`%)E<W5M;P!!;6%N:&5C97(`4/1R+61O+5-O;`!%
M;G-O;&%R861O`$%M86YH96-E<@!!;6%N:&5C97(O4/1R+61O+5-O;`!!;6%N
M:&5C97(Z(`!0]'(M9&\M4V]L`%#T<BUD;RU3;VPZ(`!3;V)R97-C<F5V97(`
M4W5P;W)T90!3=7)I;F%M90!3;V)R96YO;64`4W9A;&)A<F0@92!*86X@36%Y
M96X`4W5A>FELXFYD:6$`4W7I8VEA`%-U[>=A`$[C;R!E>&-L=6ER`%-Y;F--
M3`!%<G)O(&1E('-I;G1A>&4@;F]S('1E<FUO<R!D82!P97-Q=6ES80!297#Z
M8FQI8V$@P7)A8F4@9&$@4^UR:6$`5&5M<&5S=&%D90!496UP97-T861E<R!E
M(%9E;G1A;FEA`%1E;7!E<W1A9&5S`%1E;7!E<W1A9&5S($UA=&EN86ES`%13
M5@!!<G%U:79O(%135@!686QO<F5S('-E<&%R861O<R!P;W(@=&%B=6QAY_5E
M<P!486)E;&$`4')O<')I961A9&5S(&1A(%1A8F5L80!486)E;&$`4')O<')I
M961A9&5S(&1A('1A8F5L80!486EW86X`5&%I=V%N+"!0<F]V[6YC:6$@9&$@
M0VAI;F$`5&%J:7%U:7-TXV\`5&%N>N)N:6$L(%)E</IB;&EC82!D80!!;'9O
M.@!487)E9F%S`$[Z;65R;R!D92!496QE9F]N90!496UP97)A='5R82!P87)A
M(&$@^FQT:6UA(&AO<F$Z(`!496UP97)A='5R80!496UP97)A='5R83H@`%1E
M;7!E<F%T=7)A/&)R("\^*"5S06QT825S+R5S0F%I>&$E<RD@)F1E9SLE<P!-
M;V1E;&\@)R5S)R!NXV\@96YC;VYT<F%D;RX`061M:6YI<W1R8>?C;R!D92!-
M;V1E;&]S`%1E>'1O`%-O;65N=&4@5&5X=&\`06QI;FAA;65N=&\@9&4@5&5X
M=&\`0F]R9&$@<W5P97)I;W(@9&\@5&5X=&\`475I`%1A:6QA;F3J<R`H5$E3
M+38R,"D`5&%I;.)N9&EA`$$@97AT96YSXV\@1E10(&[C;R!E<W3A(&1I<W!O
M;NUV96PN`$\@:&ES=/-R:6-O(&1O('-I<W1E;6$@97-TX2!D97-A8FEL:71A
M9&\N`$$@96YG:6YE(&1E(&EN=&5G<F'GXV\@2&]R9&4O2V]L86(@;N-O('-U
M<&]R=&$@(B5S(@!/(&QO9R!)35-0(&[C;R!P;V1E('-E<B!I;FEC:6%L:7IA
M9&\N`$$@8VQA<W-E(")-86EN=&5N86YC92(@;N-O(&9O:2!C87)R96=A9&$@
M8V]M('-U8V5S<V\`02!J86YE;&$@9&4@3W#G]65S(&9O:2!F96-H861A+B!3
M86EN9&\N`$\@8V]N96-T;W(@5D93(&YE8V5S<VET82!S97(@8V]N9FEG=7)A
M9&\@<&%R82!H86)I;&ET87(@;R!E;G9I;R!D92!A;F5X;W,N`$\@8V%TX6QO
M9V\@9&4@96YD97)EYV]S("(E<R(@;N-O(&5X:7-T92X`3R!C873A;&]G;R!D
M92!E;F1E<F7G;W,@(B5S(B!F;VD@8W)I861O(&-O;2!S=6-E<W-O+@!/(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<R`B)7,B(&9O:2!E>&-L=>UD;R!C;VT@<W5C
M97-S;RX`3R!C873A;&]G;R!D92!E;F1E<F7G;W,@(B5S(B!F;VD@871U86QI
M>F%D;R!C;VT@<W5C97-S;RX`3R!C873A;&]G;R!D92!E;F1E<F7G;W,@;N-O
M('#T9&4@<V5R(&QI;7!O.B`E<P!/(&%D;6EN:7-T<F%D;W(@<')E8VES82!C
M;VYF:6=U<F%R('5M(&-O;F5C=&]R('!E<FUA;F5N=&4@9&4@4&5R;6ES<_5E
M<R!S92!V;V/J('%U97(@=71I;&EZ87(@4&5R;6ES<_5E<RX`4V]M96YT92!O
M(&QA9&\@9&4@8F%I>&\`3R!N^FUE<F\@240@9&\@8V]N=&%T;R!NXV\@9F]I
M(&5S<&5C:69I8V%D;RP@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E
M;F-O;G1R861O(&YO(&)A;F-O(&1E(&1A9&]S+@!/(&-O;G1A=&\@9F]I(&%D
M:6-I;VYA9&\@8V]M('-U8V5S<V\@86\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R
M9>=O<RX`3R!C;VYT871O('%U92!V;V/J('-O;&EC:71O=2!NXV\@97AI<W1E
M+@!087)A('9E<FEF:6-A<B!A(&UE;G-A9V5M(&%S<VEN861A(.D@;F5C97-S
MX7)I;R!U;2!B;&]C;R!S97!A<F%D;R!D82!A<W-I;F%T=7)A(%!'4"X`3R!)
M1"!D82!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF:6-A
M9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@96YC;VYT<F%D;R!N
M;R!B86YC;R!D92!D861O<RX`02!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O
M(&9O:2!E<W!E8VEF:6-A9&$N`$%S(&9U;N?U97,@9&4@8W)I<'1O9W)A9FEA
M(')E<75E<F5M('5M82!C;VYE>.-O('=E8B!S96=U<F$N`$\@87)Q=6EV;R`B
M)7,B(&9O:2!E>&-L=>UD;R!C;VT@<W5C97-S;RX`3R!A<G%U:79O("5S(&1E
M=F5R:6$@8V]N=&5R('5M82!C;VYF:6=U<F'GXV\@9&4@)7,N`$\@87)Q=6EV
M;R`E<R!D979E<FEA(&-O;G1E<B!A;&=U;6%S(&-O;F9I9W5R8>?U97,@9&4@
M)7,N`$\@87)Q=6EV;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A(&5L92!M
M97-M;RX`3R!A<G%U:79O(&[C;R!C;VYTZ6T@9&%D;W,N`%-E9W5E;2!O<R!C
M86)EYV%L:&]S(&1E<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F8S@R,BX`R2!S
M86)I9&\@<75E(&\@;6]D;R!T96QA(&-H96EA(&-A=7-A('!R;V)L96UA<R!C
M;VT@;R!);G1E<FYE="!%>'!L;W)E<BP@96T@=FER='5D92!D92!B=6=S(&1O
M(&YA=F5G861O<B!Q=64@;O-S(&[C;R!E<W1A;6]S(&%P=&]S(&$@8V]N=&]R
M;F%R+B!6;V/J('!O9&4@;V)S97)V87(@97)R;W,@9&4@97AI8FGGXV\L(&9A
M;'1A(&1E(&9U;N?U97,@9&\@961I=&]R(&4O;W4@=')A=F%M96YT;W,@86QE
M873S<FEO<R!D;R!N879E9V%D;W(N(%-E('-E=2!S:7-T96UA(.D@5VEN9&]W
M<R`Y>"#I(&UU:71O('!R;W;A=F5L('%U92!V;V/J(')E8V5B82!U;2!E<G)O
M(&1E("=&86QH82!'97)A;"!D92!0<F]T9>?C;R<@92!P<F5C:7-A<N$@<F5I
M;FEC:6%R+B!<;EQN(%9O8^H@9F]I(&%V:7-A9&\N(%!O<B!F879O<B!P<F5S
M<VEO;F4@3TL@<V4@=F]CZB!A:6YD82!Q=65R('1E;G1A<B!U<V%R(&\@961I
M=&]R(&1E('1E;&$@8VAE:6$N`$$@:61E;G1I9&%D92`B)7,B(&9O:2!E>&-L
M=>UD82X`02!I;7!O<G1AY^-O('!O9&4@<V5R(&9I;F%L:7IA9&$@:6YD97!E
M;F1E;G1E(&1O<R!A=FES;W,N`%-O;65N=&4@;R!L861O(&5S<75E<F1O`$$@
M;&]C86QI>F'GXV\@9&\@8FENX7)I;R!D;R!';G501R!D979E('-E<B!F;W)N
M96-I9&$@X"!C;&%S<V4@(D-R>7!T7W!G<"(N`$$@;65N<V%G96T@96YV:6%D
M82!E;2`E<R!P87)A("5S(&-O;2!O(&%S<W5N=&\@(B5S(B!F;VD@97AI8FED
M82X*27-T;R!NXV\@9V%R86YT92!Q=64@82!M96YS86=E;2!F;VD@;&ED82!O
M=2!E;G1E;F1I9&$N`$\@;F]M92!U=&EL:7IA9&\@86\@=FEN8W5L87(@82!P
MX6=I;F$@9&4@8V]M<&]S:>?C;P!/(&[Z;65R;R!D92!C86UP;W,@9&5V92!S
M97(@;G5MZ7)I8V\N`$\@;?-D=6QO(&]P96YS<VP@Z2!O8G)I9V%T\W)I;R!P
M87)A(&$@8VQA<W-E(")(;W)D95]#<GEP=%]S;6EM92(N`$$@<')E9F5RZFYC
M:6$@(B5S(B!NXV\@<&]D92!S97(@<V%L=F$@<&]R<75E('-E=7,@9&%D;W,@
M97AC961E<F%M(&\@=&%M86YH;R!MX7AI;6\@<&5R;6ET:61O`$\@<')O9W)A
M;6$@=71I;&EZ861O('!A<F$@=FES=6%L:7IA<B!E<W1E('1I<&\@9&4@9&%D
M;R`H)7,I(&[C;R!F;VD@96YC;VYT<F%D;R!N;R!S:7-T96UA+@!/(&-A<F%C
M=&5R92!P87)A(&-I=&'GXV\@9&4@<V5R(&%P96YA<R!U;2X`4V]M96YT92!O
M<R!L861O<R!D:7)E:71O(&4@97-Q=65R9&\`4V]M96YT92!O(&QA9&\@9&ER
M96ET;P!/('-E<&%R861O<B!D979E('-E<B!U;2#Z;FEC;R!C87)A8W1E<F4N
M`$\@<V5R=FED;W(@(B5S(B!F;VD@97AC;'7M9&\N`$\@<V5R=FED;W(@(B5S
M(B!F;VD@<V%L=F\N`$$@<V]L:6-I=&'GXV\@9&4@8V%D87-T<F\@9&4@)7,@
M9F]I(&5X8VQU[61A+@!!(&QI;FAA(&5S<&5C:69I8V%D82`H)60I(&[C;R!E
M>&ES=&4N`$\@87)Q=6EV;R!T96UP;W+A<FEO("(E<R(@;N-O(&5X:7-T92X`
M3R!T97AT;R!Q=64@=F]CZB!D:6=I=&]U(&[C;R!C;W)R97-P;VYD92!A;R!T
M97AT;R!N82!T96QA+@!3;VUE;G1E(&]S(&QA9&]S(&1E(&-I;6$@92!D92!B
M86EX;P!3;VUE;G1E(&\@;&%D;R!D92!C:6UA`$]S(&1A9&]S(&5N=FEA9&]S
M(&9O<F%M('!E<F1I9&]S(&1E<V1E(&\@<&%S<V\@86YT97)I;W(N`$\@87)Q
M=6EV;R!E;G9I861O(&[C;R!P]&1E('-E<B!S86QV;RX`3R!B;&]C;R`B=V5A
M=&AE<BYC;VTB(&[C;R!E<W3A(&1I<W!O;NUV96PN`$\@9&ER973S<FEO(&1E
M('1E;6%S("<E<R<@;N-O(&9O:2!E;F-O;G1R861O+@!.XV\@97AI<W1E;2!C
M873A;&]G;W,@9&4@96YD97)EYV]S('%U92!P;W-S86T@<V5R(&5X:6)I9&]S
M+@!.XV\@97AI<W1E;2!O<.?U97,@9&ES<&]N[79E:7,N`$[C;R!E>&ES=&5M
M('!A<G1E<R!Q=64@<&]S<V%M('-E<B!E>&EB:61A<R!I;F-O<G!O<F%D87,N
M`$[C;R!E>&ES=&5M(&-A=.%L;V=O<R!D92!E;F1E<F7G;W,@8V]M('!E<FUI
M<W/U97,@9&4@9W)A=F'GXV\N($YE;FAU;2!D;W,@8V%TX6QO9V]S(&1E(&5N
M9&5R9>=O<R!E<W3C;R!C;VYF:6=U<F%D;W,@<&%R82!P97)M:71I<B!V;V/J
M(&%D:6-I;VYA<B!N;W9O<R!R96=I<W1R;W,N(%-E('9O8^H@86-R961I=&$@
M<75E(&ES=&\@Z2!U;2!E<G)O+"!P;W(@9F%V;W(@96YT<F4@96T@8V]N=&%T
M;R!C;VT@;R!A9&UI;FES=')A9&]R(&1O('-I<W1E;6$N`$5X:7-T96T@;75I
M=&]S(&-A<F%C=&5R97,@;F5S=&4@8V%M<&\N(%9O8^H@<')E96YC:&5U(&-O
M;2`E<R!C87)A8W1E<F5S.R!V;V/J(&1E=F4@<')E96YC:&5R(&-O;2`E<R!O
M=2!M96YO<RX`2&]U=F4@=6T@<')O8FQE;6$@861I8VEO;F%N9&\@)R5S)R!A
M;R!S:7-T96UA.B`E<P!(;W5V92!U;2!P<F]B;&5M82!A;R!E>&-L=6ER(&1O
M('-I<W1E;6$@;W,@9&%D;W,@9&\@=7-UX7)I;R`G)7,G.B``2&]U=F4@=6T@
M<')O8FQE;6$@86\@97AC;'5I<B`G)7,G(&1O('-I<W1E;6$Z(`!(;W5V92!U
M;2!P<F]B;&5M82!A;R!A='5A;&EZ87(@)R5S)SH@)7,`2&]U=F4@=6T@<')O
M8FQE;6$@8V]M(&\@96YV:6\@9&\@87)Q=6EV;SH@3F5N:'5M("5S(&9O:2!E
M;G9I861O+@!(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A<G%U
M:79O+B!/("5S(&5R82!M86EO<B!Q=64@;R!T86UA;FAO(&WA>&EM;R!P97)M
M:71I9&\@*"5D(&)Y=&5S*2X`2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@96YV
M:6\@9&\@87)Q=6EV;RX@3R`E<R!F;VD@96YV:6%D;R!P87)C:6%L;65N=&4N
M`$AO=79E('5M(&5R<F\@86\@861I8VEO;F%R(&\@;F]V;R!C;VYT871O+B!%
M;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M
M82!P87)A(&UA:6]R97,@9&5T86QH97,N`$AO=79E('5M(&5R<F\@86\@8W)I
M87(@=6UA(&YO=F$@;&ES=&$N`$AO=79E('5M(&5R<F\@86\@8W)I87(@97-T
M92!C873A;&]G;R!D92!E;F1E<F7G;W,Z("5S`$AO=79E('5M(&5R<F\@86\@
M97AC;'5I<B`E<R!D;R!C873A;&]G;R!D92!E;F1E<F7G;W,@9&4@;W)I9V5M
M+@!(;W5V92!U;2!E<G)O(&%O(&5X8VQU:7(@97-T92!C;VYT871O.B`E<P!(
M;W5V92!U;2!E<G)O(&%O(&5X:6)I<B!A(&QI<W1A`$AO=79E('5M(&5R<F\@
M86\@97AI8FER(&5S=&$@<&%R=&4@9&$@;65N<V%G96T`2&]U=F4@=6T@97)R
M;R!A;R!I;7!O<G1A<B!O<R!D861O<R!D;R!C;VYT871O+@!(;W5V92!U;2!E
M<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S.B`E<P!(;W5V92!U;2!E<G)O(&%O
M(&EM<&]R=&%R(&]S(&1A9&]S(&1O(&E#86QE;F1A<BX`2&]U=F4@=6T@97)R
M;R!N;R!F;W)M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('9O8^H@
M9&5I>&]U('5M(&-A;7!O(&]B<FEG873S<FEO(&5M(&)R86YC;RX`2&]U=F4@
M=6T@97)R;R!A;R!E>&5C=71A<B!A(&9U;N?C;R!D92!C873A;&]G;R!D92!E
M;F1E<F7G;W,@97-P96-I9FEC861A+B!0;W(@9F%V;W(@=&5N=&4@;F]V86UE
M;G1E(&UA:7,@=&%R9&4N`$AO=79E('5M(&5R<F\@86\@97AC;'5I<B!E<W1E
M(&-A=.%L;V=O(&1E(&5N9&5R9>=O<SH@)7,`2&]U=F4@=6T@97)R;R!A;R!A
M='5A;&EZ87(@;W,@9&5T86QH97,@9&\@8V]N=&%T;RX@4&]R(&9A=F]R('1E
M;G1E(&YO=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T
M=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E
M;G1E(&YO=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T
M=6%L:7IA<B!E<W1E(')E9VES=')O.B`E<P!(;W5V92!U;2!E<G)O(&%O(&%T
M=6%L:7IA<B!E<W1E(')E9VES=')O.B`E<P!.XV\@97AI<W1I86T@96YD97)E
MYV]S('!A<F$@97AP;W)T87(N`$5S=&5S(&-A=.%L;V=O<R!D92!E;F1E<F7G
M;W,@<V5RXV\@97AI8FED;W,@;F$@<V5G=6EN=&4@;W)D96TZ`$5S=&%S(&-O
M;'5N87,@<V5RXV\@97AI8FED87,@;F$@<V5G=6EN=&4@;W)D96TZ`$5S=&4@
M<V5R=FED;W(@24U!4"!NXV\@<W5P;W)T82!P87-T87,@8V]M<&%R=&EL:&%D
M87,N`$5S=&4@;N-O('!A<F5C92!S97(@=6T@87)Q=6EV;R!R87(@=N%L:61O
M+@!%<W1E(&[C;R!P87)E8V4@<V5R('5M(&%R<75I=F\@>FEP(';A;&ED;RX`
M17-T92!NXV\@<&%R96-E('-E<B!U;2!N^FUE<F\@9&4@8V%R=.-O(';A;&ED
M;RX`17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R
M87;I<R!D;R!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI+"!U
M=&EL:7IA;F1O(&$@05!)($A45%``17-T92!C;VYE8W1O<B!P97)M:71E(&5N
M=FEA<B!M96YS86=E;G,@871R87;I<R!D;R!G871E=V%Y('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!U=&EL:7IA;F1O(&\@05!)($A45%``
M17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R87;I
M<R!D;R!G871E=V%Y('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M+"!U=&EL:7IA;F1O(&\@05!)($A45%``17-T92!C;VYE8W1O<B!P97)M:71E
M(&5N=FEA<B!U;6$@;65N<V%G96T@=FEA(%--5%`@871R87;I<R!D;R!6;V1A
M9F]N92!)=&%L:6%N;RP@<V]M96YT92!P87)A(&[Z;65R;W,@5F]D869O;F4N
M(,D@;V)R:6=A=/-R:6\@<&]S<W5I<B!U;6$@8V]N=&$@;F\@5F]D869O;F4@
M271A;&EA;F\@*&AT='`Z+R]W=W<N,3DP+FET*2X`17-T92!C86UP;R#I(&]B
M<FEG873S<FEO+@!%<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!N^FUE
M<F]S(&EN=&5I<F]S+@!%<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!N
M^FUE<F]S(&4@=NUR9W5L82X`17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N
M87,@=F%L;W)E<R!O8W1A:7,N`$5S=&4@8V%M<&\@9&5V92!S97(@=6UA(&QI
M<W1A(&1E(&[Z;65R;W,@:6YT96ER;W,@<V5P87)A9&$@<&]R(';M<F=U;&%S
M(&]U(&5S<&'G;W,`17-T92!C86UP;R!D979E('-E<B!U;2!N^FUE<F\@=N%L
M:61O+@!%<W1E(&-A;7!O(&1E=F4@8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@
M96T@9F]R;6%T;R!21T(@2&5X82P@<&]R(&5X96UP;&\@)R,Q,C,T868G+@!%
M<W1E(&9O<FUA=&\@9&4@87)Q=6EV;R!NXV\@Z2!S=7!O<G1A9&\N`$5S=&4@
M9F]R;75LX7)I;R!JX2!F;VD@<')O8V5S<V%D;RX`27-T;R#I("5S+@!%<W1E
M(.D@=6T@;V)J971O($MO;&%B($=R;W5P=V%R92X@4&%R82!V:7-U86QI>F%R
M(&5S=&4@;V)J971O('9O8^H@<')E8VES87+A(&1E('5M(&-L:65N=&4@9&4@
M8V]R<F5I;R!Q=64@96YT96YD82!O(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E
M+B!087)A('5M82!L:7-T82!D92!C;&EE;G1E<R!D92!C;W)R96EO(&-O;2!E
M<W1A<R!F=6[G]65S('!O<B!F879O<B!V:7-I=&4@)7,`17-T82!M96YS86=E
M;2!F;VD@97-C<FET82!E;2!U;2!C;VYJ=6YT;R!D92!C87)A8W1E<F5S("@E
M<RD@<75E(&[C;R#I(&\@;65S;6\@<75E(&\@<V5U+@!%<W1E(&[Z;65R;R!D
M979E('-E<B!P96QO(&UE;F]S('5M+@!%<W1A('!E<W-O82!JX2!T96T@=6T@
M<F5G:7-T<F\@)7,@;F\@8V%TX6QO9V\@9&4@96YD97)EYV]S`$5S=&4@<V5R
M=FED;W(@;N-O('!O9&4@9&5S8V]M<')I;6ER(&%R<75I=F]S('II<"!E(&=Z
M:7`N`$5S=&4@<VES=&5M82!E<W3A(&%T=6%L;65N=&4@9&5S871I=F%D;RX`
M17-T92!V86QO<B!D979E('-E<B!U;2!N^FUE<F\N`$5S=&4@<V5RX2!O(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<R!P861RXV\@<&%R82!A9&EC:6]N87(@92!I
M;7!O<G1A<B!C;VYT871O<RX`17-T82!J86YE;&$@9&5V92!S97(@8VAA;6%D
M82!A('!A<G1I<B!D82!J86YE;&$@9&4@3W#G]65S`%)A:6\`0FEL:&5T97,`
M2&]R80!!8V]M<&%N:&%M96YT;R!D92!(;W+A<FEO`$9O<FUA=&\@9&4@:&]R
M80!396QEY^-O(&1E(&AO<F$`5&EM;W(@3&5S=&4`5.UT=6QO`$%S<W5N=&\@
M*&1I8V$I.@!087)A`%!A<F$@<V5L96-I;VYA<B!M^FQT:7!L;W,@[71E;G,L
M('-E9W5R92!A('1E8VQA($-O;G1R;VP@*%!#*2!O=2!#;VUM86YD("A-86,I
M(&%O(&-L:6-A<BX`2&]J90!4<F]C87(@<&%R82!C\V1I9V\@2%1-3`!4;V=O
M`%1O:V5L874`06UA;FCC`%1O;F=A`%1O<&\`475A9')O(&1O(%1O<&\@*%]T
M;W`I`%1R861UY_5E<P!4<FEN9&%D92!E(%1O8F%G;P!697)D861E:7)O(&]U
M(&9A;'-O`%1E<@!4=6[M<VEA`%1U<G%U:6$`5'5R8V\@*$E33RTX.#4Y+3DI
M`%1U<F-O;65N:7-TXV\`26QH87,@5'5R:W,@92!#86EC;W,`5'5V86QU`%!R
M965N8VAA(&-O;2!S=6$@97-C;VQH83H@`,UN9&EC92!5+E8N.B``55),`%52
M3"!D;R!S974@<F5L873S<FEO(&1E('-I='5AY^-O(&1E(&5N=')E9V$`55),
M.@!59V%N9&$`56-RXFYI80!);7!O<W/M=F5L(&%C97-S87(@9&ER973S<FEO
M(%9&4RX`26UP;W-S[79E;"!A9&EC:6]N87(@:6YF;W)M8>?U97,@97AT<F%S
M(&1E('5S=>%R:6\@86\@<F5G:7-T<F%R+@!);7!O<W/M=F5L(&%L=&5R87(@
M<&5R;6ES<^-O(&1O(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@86QT
M97)A<B!P97)M:7-SXV\@9&\@87)Q=6EV;R!61E,@)7,O)7,N`$EM<&]S<^UV
M96P@86QT97)A<B!P87)A("5S+@!);7!O<W/M=F5L('9E<FEF:6-A<B!O('1A
M;6%N:&\@9&\@87)Q=6EV;R!D92`B)7,B+@!);7!O<W/M=F5L('9E<FEF:6-A
M<B!O('1A;6%N:&\@9&\@87)Q=6EV;R!D92`B)7,O)7,B+@!);7!O<W/M=F5L
M(&-O;F5C=&%R(&%O('-E<G9I9&]R(%-13"X`26UP;W-S[79E;"!C;VYE8W1A
M<B!U=&EL:7IA;F1O(%-33"X`26UP;W-S[79E;"!C;W!I87(@87)Q=6EV;R!6
M1E,N`$EM<&]S<^UV96P@8W)I87(@9&ER973S<FEO(%9&4R`B)7,B+@!);7!O
M<W/M=F5L(&-R:6%R(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@8W)I87(@
M87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,@
M(B5S(BX`26UP;W-S[79E;"!C<FEA<B!A<G%U:79O(%9&4R!V87II;RX`26UP
M;W-S[79E;"!C<FEA<B!U;2!N;W9O(&-O;7!A<G1I;&AA;65N=&\N(%1I<&\@
M9&4@;W)I9V5M(&9A;'1A;F1O+@!);7!O<W/M=F5L(&1E<V-O;7!R:6UI<B!D
M861O<RX`26UP;W-S[79E;"!E>&-L=6ER("(E<R(L(&\@9&ER973S<FEO(&[C
M;R!E<W3A('9A>FEO+@!);7!O<W/M=F5L(&5X8VQU:7(@(B5S(CH@)7,N`$EM
M<&]S<^UV96P@97AC;'5I<B`E<RP@;R!D:7)E=/-R:6\@;N-O(&5S=.$@=F%Z
M:6\`26UP;W-S[79E;"!E>&-L=6ER(')E8W5R<VEV86UE;G1E(&\@9&ER973S
M<FEO(%9&4RX`26UP;W-S[79E;"!E>&-L=6ER(&1I<F5T\W)I;R!61E,N`$EM
M<&]S<^UV96P@97AC;'5I<B!D:7)E=/-R:6\@5D93.B`E<RX`26UP;W-S[79E
M;"!E>&-L=6ER(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@97AC;'5I
M<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!E>&-L=6ER(&%R<75I=F\@5D93
M("(E<R(N`$EM<&]S<^UV96P@97AC;'5I<B!61E,@<F5C=7)S:79A;65N=&4Z
M("5S+@!);7!O<W/M=F5L(&1E=&5R;6EN87(@;R!D:7)E=/-R:6\@871U86PN
M`$EM<&]S<^UV96P@97AT<F%I<B!D971A;&AE<R!D;R!C97)T:69I8V%D;P!)
M;7!O<W/M=F5L(&-A<G)E9V%R(&$@9&5F:6YIY^-O(&1E("5S+@!);7!O<W/M
M=F5L(&UO=F5R(&\@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@86)R:7(@87)Q
M=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!A8G)I<B!A<G%U:79O(%9&4R!P
M87)A(&=R879AY^-O+@!);7!O<W/M=F5L(&%B<FER(&%R<75I=F\@5D93+@!)
M;7!O<W/M=F5L(&%B<FER(&%R<75I=F\@8V]M<')I;6ED;RX`26UP;W-S[79E
M;"!L97(@87)Q=6EV;R!61E,@*&9I;&5S:7IE*"D@9F%L:&]U*2X`26UP;W-S
M[79E;"!L97(@87)Q=6EV;R!61E,@*&=E=$9I;&53:7IE*"D@9F%L:&]U*2X`
M26UP;W-S[79E;"!L97(@;R!A<G%U:79O.B``26UP;W-S[79E;"!L97(@82!R
M86EZ(&1O(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@<F5N;VUE87(@)7,@
M<&%R82`E<SH@82!P87-T82!D92!D97-T:6YO(&KA(&5X:7-T90!);7!O<W/M
M=F5L(')E;F]M96%R(&\@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!R96YO
M;65A<B!D:7)E=/-R:6\@5D93.B`E<RX`26UP;W-S[79E;"!R96YO;65A<B!A
M<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@
M5D93("5S+R5S+@!);7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93+@!)
M;7!O<W/M=F5L(&5X96-U=&%R("=M:VES;V9S)RX`26UP;W-S[79E;"!T<F%D
M=7II<B!E<W1E(&1O8W5M96YT;R!7;W)D`$EM<&]S<^UV96P@9W)A=F%R(&%R
M<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@9W)A=F%R(&%R<75I=F\@5D93
M("AC;W!Y*"D@9F%L:&]U*2X`26UP;W-S[79E;"!G<F%V87(@9&%D;W,@9&\@
M87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@9W)A=F%R(&%R<75I=F\@5D93+"!Q
M=6]T82!E>&-E9&5RX2X`4W5B;&EN:&%D;P!$97-F87IE<B!!;'1E<F'G]65S
M`$1E<V9A>B!S=6$@^FQT:6UA(&'GXV\`4F5S<&]S=&$@:6YE<W!E<F%D82!D
M;R!S97)V:61O<B!D=7)A;G1E(&$@8V]N97CC;SH@`%)E<W!O<W1A(&EN97-P
M97)A9&$@9&\@<V5R=FED;W(@<&%R83H@`%-E;2!C871E9V]R:6$`56YI8V]D
M92`H551&+3@I`$5M:7)A9&]S(,%R86)E<R!5;FED;W,`4F5I;F\@56YI9&\`
M17-T861O<R!5;FED;W,`26QH87,@4&5R:6;I<FEC87,@365N;W)E<R!D;W,@
M17-T861O<R!5;FED;W,`56YI9&%D97,`1&5S8V]N:&5C:61O`&%P:6US9VED
M(&1E<V-O;FAE8VED;R`H05!)($UE<W-A9V4@240I+@!C;&EM<V=I9"!D97-C
M;VYH96-I9&\@*$-L:65N="!-97-S86=E($E$*2X`3F5N:'5M82!L;V-A;&EZ
M8>?C;R!C;VYF:6=U<F%D82X`57-UX7)I;R!O=2!S96YH82!D97-C;VYH96-I
M9&]S+@!$97-V:6YC=6QA<B!O(&5L96UE;G1O(&%T=6%L`%-E;2!.;VUE`%-C
M<FEP=',@;N-O('!R:79I;&5G:6%D;W,@;N-O('!O9&5M('5T:6QI>F%R($-O
M<G1A<B]#;W!I87(O0V]L87(@<&]R(')A>O5E<R!D92!S96=U<F%NYV$N($-L
M:7%U92!E;2!/2R!P87)A('9E<B!A(&YO=&$@=.EC;FEC82!E;2!M;WII;&QA
M+F]R9R!A('%U86P@96YS:6YA(&-O;6\@<&5R;6ET:7(@<V-R:7!T<R!A8V5S
M<V%R96T@82#A<F5A(&1E('1R86YS9F5RZFYC:6$N`$1E<VUA<F-A<B!C;W(`
M0V]N=&5N="U4>7!E(&[C;R!S=7!O<G1A9&\Z("5S`$5X=&5N<^-O($[C;R!3
M=7!O<G1A9&$`071U86QI>F%R`"5S(&%T=6%L:7IA9&\`071U86QI>F%R('5S
M=>%R:6\`)R5S)R!A='5A;&EZ861O+@!38W)I<'0@9&4@871U86QI>F'GXV\@
M<F5M;W9I9&\N`$5N=FEA<@!4;V1O<R!A<G%U:79O<R!D92`@8V]N9FEG=7)A
MY_5E<R!D87,@87!L:6-AY_5E<R!F;W)A;2!E;G9I861O<R!A;R!S97)V:61O
M<BX`06QF86)E=&\@;&%T:6YO(&5M(&UA:?IS8W5L;P!.^FUE<F]S(')O;6%N
M;W,@96T@;6%I^G-C=6QO`%5R=6=U86D`571I;&EZ87(@071U86PZ("5S`%5T
M:6QI>F%R(%-33`!5=&EL:7IA<B!S92!O(&YO;64O<V5N:&$@Z2!D:69E<F5N
M=&4@;F\@<V5R=FED;W(@24U34"X`57-UX7)I;W,`57-UX7)I;R`E<R!NXV\@
M97-TX2!A=71O<FEZ861O('!A<F$@)7,N`$%D;6EN:7-T<F'GXV\@9&4@57-U
MX7)I;W,`3W#G]65S(&1E(%5S=>%R:6]S`%)E9VES=')O(&1E(%5S=>%R:6]S
M`%)E9VES=')O(&1E(%5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861O(&YE<W1E
M('-I=&4N`$-O;G1A(&1E('5S=>%R:6\@;N-O(&5N8V]N=')A9&$`57-UX7)I
M;P!5<W7A<FEO("<E<R<@:N$@97AI<W1E+@!5<W7A<FEO.@!5<W7A<FEO.B``
M57-UX7)I;W,@;F\@<VES=&5M83H`57IB97%U:7-TXV\`3R!D:7)E=/-R:6\@
M5D93(&[C;R!E>&ES=&4N`$;I<FEA<P!,;V-A;&EZ8>?U97,@=N%L:61A<R!E
M;F-O;G1R861A<R!I;F-L=65M.B``5F%L:61A9&4`5F%L;W(@96T@;6EN=71O
M<R!A('!A<G1I<B!D92!A9V]R82X`3R!V86QO<B!E<W3A(&%C:6UA(&1O('1A
M;6%N:&\@;>%X:6UO(&1E("5S+@!686QO<F5S`%9A;&]R97,@<&%R82!S96QE
M8VEO;F%R`%9A;G5A='4`5F%R:>%V96P`5F5N97IU96QA`$9A;&AA(&YA('9E
M<FEF:6-AY^-O("T@97-T82!M96YS86=E;2!P;V1E('1E<B!S:61O(&%D=6QT
M97)A9&$N`$1I<F5T\W)I;R!697)I<VEG;@!697)SXV\`0V]N=')O;&4@9&4@
M5F5R<^-O`$%L:6YH86UE;G1O('9E<G1I8V%L`$UA<F=E;2!V97)T:6-A;`!6
M97)T:6-A;#H`375I=&\@06QT80!6:65T;N,`5FEE=&YA;6ET82`H5DE30TE)
M*0!6:7-U86QI>F%R("(E<R(`5F5R("5S`%9I<W5A;&EZ87(@0V]N=&%T;P!6
M:7-U86QI>F%R('5M82!PX6=I;F$@=V5B(&5X=&5R;F$`5FES=6%L:7IA<B!C
M;VUO("5S`%9I<W5A;&EZ8>?C;R!P87)A(&5X:6)I<B!P;W(@<&%D<N-O.@!)
M;&AA<R!6:7)G96YS+"!"<FETXFYI8V%S`$EL:&%S(%9I<F=E;G,L($4N52Y!
M+@!6:7-I8FEL:61A9&4`5FES:6)I;&ED861E.B``5F]D869O;F4@271A;&EA
M;F\@=FEA(%--5%``051%3L?#3P!!5$5.Q\-/(2$A(%)%34]602!/(%-#4DE0
M5"!-04Y504Q-14Y412!$12`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!E($9U
M='5N80!!=&5NY^-O`%%U80!0<F5V:7/C;R!D;R!496UP;P!$861O<R!D;R!#
M;&EM82!F;W)N96-I9&\@<&]R`%=E871H97(N8V]M`%=E8@!3:71E(%=E8@!5
M4DP@9&\@5V5B<VET90!396UA;F%L;65N=&4`0F5M+79I;F1O`$)E;2UV:6YD
M;R!A;R`E<P!"96TM=FEN9&\L("5S`$]C:61E;G1A;"`H25-/+3@X-3DM,2D`
M3V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4V%H87)A($]C:61E;G1A;`!1=64@
M87!L:6-AY^-O("5S(&1E=F5R:6$@97AI8FER(&%P\W,@82!C;VYE>.-O/P!1
M=6%L(&\@8V%R86-T97)E(&1E;&EM:71A9&]R/P!1=6%L(&\@8V%R86-T97)E
M(&1E(&-I=&'GXV\_`$UA<&%S($%U<W1R86QI86YO<R!7:&5R96ES`%%U86ES
M(&9A<V5S`%%U86ES('!L=6=I;G,@:&%B:6QI=&%R('!A<F$@;R!E9&ET;W(@
M4FEC:"!497AT+@!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D97,@0U-3`$QA
M<F=U<F$@9&\@;65N=2`E<R!D;R!L861O(&5S<75E<F1O("AT97+A(&5F96ET
M;R!N82!P<O-X:6UA(&-O;F5XXV\I.@!,87)G=7)A(&1A('1A8F5L80!5;FED
M861E(&1E($QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT;P!696YT;W,@<&5L
M82!M86YHXP!696QO8VED861E(&1O('9E;G1O(&5M(&[S<P!696YT;SH`5F5N
M=&\Z(`!386)E9&]R:6$`3&ES=&$@9&4@<&5D:61O<P!4<F%B86QH;P!%;F1E
M<F7G;R!#;VUE<F-I86P`0VED861E(&1E(%1R86)A;&AO`%!A[7,@9&4@5')A
M8F%L:&\`1F]N92!#;VUE<F-I86P`0T50($-O;65R8VEA;`!%<W1A9&\@9&4@
M5')A8F%L:&\`16YD97)EYV\@0V]M97)C:6%L`$[Z;65R;R!I;F-O<G)E=&\@
M9&4@8V%M<&]S(&YA(&QI;FAA("5D+B!%<W!E<F%D;W,@)60L(&5N8V]N=')A
M9&]S("5D+@!.^FUE<F\@97)R861O(&1E(&-A;7!O<RX@17-P97)A9&]S("5D
M+"!E;F-O;G1R861O<R`E9"X`3V9F<V5T("5D(&EN8V]R<F5T;R!A;R!L97(@
M;R!A<G%U:79O(%9&4RX`6"U2968`4F5S=')IY_5E<R!"X7-I8V%S(%@U,#EV
M,P!5=&EL:7IAY^-O(&1E($-H879E($5X=&5N9&ED82!8-3`Y=C,`3F]M92!!
M;'1E<FYA=&EV;R!D92!!<W-U;G1O(%@U,#EV,P!)9&5N=&EF:6-A9&]R(&1A
M($-H879E(&1E($%S<W5N=&\@6#4P.78S`$5X=&5N<_5E<R!8-3`Y=C,`04$`
M04%!00!-87!A(%EA:&]O(0!!;G5A;&UE;G1E`$SJ;65N`%-I;0!3:6TL($5U
M($-O;F-O<F1O`%9O8^H@97-TX2!E;2!-3T1/(%1%6%1/+B`@571I;&EZ82!O
M(&)O=.-O(%L\/ET@<&%R82!V;VQT87(@<&%R82!O(&UO9&\@5UE325=91RX`
M5F]CZB!NXV\@97-TX2!A=71O<FEZ861O(&$@8W)I87(@;6%I<R!D92`E9"!B
M;&]C;W,N`%9O8^H@;N-O(&5S=.$@875T;W)I>F%D;R!A(&-R:6%R(&UA:7,@
M9&4@)60@8V]N=&%T;W,@96T@(B5S(BX`5F]CZB!NXV\@97-TX2!A=71E;G1I
M8V%D;RX`5F]CZB!NXV\@<&]D92!T97(@;R!C87)A8W1E<B!<(&YO('-E=2!N
M;VUE+@!6;V/J(&[C;R!F;W)N96-E=2!U;2!E;F1E<F7G;R!D92!E+6UA:6P@
M=N%L:61O+@!6;V/J(&[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R<75I
M=F\@:6UP;W)T861O(&%O<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S(&5M("5S
M+@!6;V/J(&[C;R!T96T@<&5R;6ES<^-O('!A<F$@=FES=6%L:7IA<B!E<W1E
M(&-O;G1A=&\N`%9O8^H@;N-O('1E;2!P97)M:7-SXV\@<&%R82!V:7-U86QI
M>F%R(&5S=&4@;V)J971O+@!6;V/J(&[C;R!T96T@<&5R;6ES<^-O('!A<F$@
M97AC;'5I<B!E<W1A(&9O;G1E+@!6;V/J(&9O:2!D97-C;VYE8W1A9&\N`%9O
M8^H@9&5V92!P<F5E;F-H97(@=6T@;OIM97)O(&1E('1E;&5F;VYE(&-E;'5L
M87(@=N%L:61O+"!S;VUE;G1E(&3M9VET;W,@8V]M('5M(&]P8VEO;F%L("<K
M)R!P87)A(&1I<V-A9V5M(&1E('!R969I>&\@:6YT97)N86-I;VYA;"X`5F]C
MZB!D979E('!R965N8VAE<B!U;2!V86QO<B!VX6QI9&\N`%9O8^H@9&5V92!C
M;VYF:6=U<F%R('5M(&-O;F5C=&]R($1A=&%4<F5E('!A<F$@=71I;&EZ87(@
M0V%D87-T<F]S+@!6;V/J(&1E=F4@8V]N9FEG=7)A<B!U;2!C;VYE8W1O<B!6
M1E,N`%9O8^H@9&5V92!D97-C<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D92!E
M;G9I87(@;R!R96QA=/-R:6\@9&4@<')O8FQE;6$N`%9O8^H@9&5V92!F;W)N
M96-E<B!A(%523"!O;F1E(&\@;&EN:R!A<&]N=&$`5F]CZB!D979E('-E;&5C
M:6]N87(@=6T@8V%TX6QO9V\@9&4@96YD97)EYV]S(&1E<W1I;F\N`%9O8^H@
M9&5V92!S96QE8VEO;F%R('5M82!L:7-T82!D92!D97-T:6YO+@!6;V/J(&1E
M=F4@<V5L96-I;VYA<B!U;2!S97)V:61O<B!P87)A('-E<B!E>&-L=>UD;RX`
M5F]CZB!D979E('-E;&5C:6]N87(@<&5L;R!M96YO<R!U;2!C;VYT871O('!R
M:6UE:7)O+@!6;V/J(&1E=F4@<V5L96-I;VYA<B!P96QO(&UE;F]S('5M(')E
M9VES=')O+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A
M(&5X8VQU:7(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A
M<F$@<F5M;W9E<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@
M<&%R82!A9&EC:6]N87(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A
M<FEO('!A<F$@871U86QI>F%R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6UA
M(&'GXV\@<&%R82!E>&5C=71A<BX`5F]CZB!D979E('!R965N8VAE<B!U;2!N
M;VUE('!A<F$@82!N;W9A(&-A=&5G;W)I82X`5F]CZB!P<F5C:7-A(&9O<FYE
M8V5R('5M(&[Z;65R;R!D92!T96QE9F]N92!I=&%L:6%N;P!6;V/J('-O;65N
M=&4@=&5M('!E<FUI<W/C;R!D92!V:7-U86QI>F%R(&5S=&4@8V]N=&%T;RX`
M4W5A('-E<W/C;R`E<R!E>'!I<F]U+B!0;W(@9F%V;W(L(&-O;F5C=&4M<V4@
M;F]V86UE;G1E+@!3974@16YD97)EYV\@9&4@12UM86EL`%-E=2!%;F1E<F7G
M;R!D92!296UE=&5N=&4@*$1E.BDZ`%-U87,@26YF;W)M8>?U97,`4V5U($5N
M9&5R9>=O(&1E($EN=&5R;F5T(&UU9&]U(&1E<V1E(&\@:6[M8VEO(&1E('-U
M82!S97-SXV\@)7,N(%!A<F$@<')O=&5G97(@<W5A('-E9W5R86[G82!V;V/J
M(&1E=F4@8V]N96-T87(M<V4@;F]V86UE;G1E+@!3974@3F]M90!3974@8F%C
M:V5N9"!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@861IY^-O(&1E('5S
M=>%R:6]S+"!O=2!A(&9U;N?C;R!F;VD@9&5S86)I;&ET861A('!O<B!A;&=U
M;6$@;W5T<F$@<F%ZXV\N`%-E=2!B86-K96YD(&1E(&%U=&5N=&EC8>?C;R!N
MXV\@<W5P;W)T82!L:7-T86=E;2!D92!U<W7A<FEO<RP@;W4@82!F=6[GXV\@
M9F]I(&1E<V%B:6QI=&%D82!P;W(@86QG=6UA(&]U=')A(')A>N-O+@!3974@
M;F%V96=A9&]R('!A<F5C92!T97(@86QT97)A9&\@9&5S9&4@;R!I;NUC:6\@
M9&4@<W5A('-E<W/C;R`E<RX@4&%R82!P<F]T96=E<B!S=6$@<V5G=7)A;N=A
M+"!V;V/J(&1E=F4@8V]N96-T87(M<V4@;F]V86UE;G1E+@!3974@;F%V96=A
M9&]R(&[C;R!S=7!O<G1A(&5S=&$@9G5NY^-O+@!3974@;F%V96=A9&]R(&[C
M;R!S=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O+B!0<F5S<VEO;F4@
M0V]N=')O;"]/<'1I;VX@*R!0('!A<F$@:6UP<FEM:7(N`%-E=2!F=7-O(&AO
M<N%R:6\@871U86PZ`%-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,@<&%D<N-O
M(&[C;R#I(&YA=F5GX79E;"X`4W5A(&ED96YT:61A9&4@<&%D<N-O(&9O:2!A
M;'1E<F%D82X`4W5A(&ED96YT:61A9&4@<&%D<N-O.@!3974@;F]M92!C;VUP
M;&5T;SH`4W5A(&-O;F5XXV\@97AP:7)O=2X`4W5A(&YO=F$@<V5N:&$@<&%R
M82`E<R#I.B`E<P!3=6%S(&]PY_5E<R!F;W)A;2!A='5A;&EZ861A<R!P;W(@
M8V%U<V$@9&$@9'5R8>?C;R!D97-T82!S97-SXV\N`%-U87,@;W#G]65S(&9O
M<F%M(&%T=6%L:7IA9&%S+@!3=6$@;F]V82!S96YH82!F;VD@9V5R861A`%-U
M82!N;W9A('-E;FAA(&9O:2!G97)A9&$L('9E<FEF:7%U92!S974@92UM86EL
M(&4@8V]N96-T92US92!C;VT@<W5A(&YO=F$@<V5N:&$N`%-U82!S96YH82!E
M>'!I<F]U+@!3975S('-E<G9I9&]R97,@<F5M;W1O<SH`275G;W-LX79I80!:
M86ER90!:XFUB:6$`6FEM8F%B=V4`6FEP<'D`6T]C=6QT87(@5&5X=&\@0VET
M861O70!;4F5L873S<FEO(&1E(%!R;V)L96UA70!;17AI8FER(%1E>'1O($-I
M=&%D;R`M`%M%>&EB:7(@5&5X=&\@0VET861O("T@)7,@;&EN:&%S70!;;&EN
M:&$@)7,@9&4@)7-=`%MS96T@=F%L;W)=`%]!9&UI;FES=')AY^-O`%]%>&EB
M:7(`7T-,20!%>&EB:7(@7T-O;G1A=&]S`$1A=&%?5')E90!%>&-?;'5I<@!%
M7WAC;'5I<B!#;VQU;F$`7T=R=7!O<P!!7VIU9&$`4')O<')I961A9&5S(&1A
M(%]);6%G96TN+BX`26UP;W)T87(O15]X<&]R=&%R`$QI<W1A`%]#;VYE8W1A
M<@!?1&5S8V]N96-T87(`05]L=&5R87(@3&EN:RXN+@!-975S($-A=.%L;V=O
M<R!D92!%;F1E<F7G;W,`3E]O=F\@0V]N=&%T;P!?3W#G]65S`%]097)M:7-S
M]65S`%]296UO=F5R($QI;FLN+BX`7U)E;6]V97(@9&5S=&$@;&ES=&$`7U!E
M<W%U:7-A<@!#;VYF:6=U<F%?<@!0<F]P<FEE9&%D97,@9&$@7U1A8F5L82XN
M+@!?57-UX7)I;W,`8V%TX6QO9V\@9&4@96YD97)EYV]S`&-A=.%L;V=O(&1E
M(&5N9&5R9>=O<P!A9V5N9&$`8V%L;6\`:6UP;W-S[79E;"!C<FEA<B!A<G%U
M:79O(&1E(&1E<W1I;F\`:6UP;W-S[79E;"!A8G)I<B!A(&]R:6=E;0!C;&EQ
M=64@87%U:0!E<G)O(&1E('-I;G1A>&4@9&$@;&EN:&$@9&4@8V]M86YD;P!E
M<G)O(&1E(&-O;F9I9W5R8>?C;P!C;VYT871O<RYV8V8`8V]N=&%T;W,N8W-V
M`&-O;G1A=&]S+G1S=@!C;VYT871O<RYV8V8`=6T@87)Q=6EV;R!C<NUT:6-O
M(&1O('-I<W1E;6$@97-TX2!F86QT86YD;P!E<G)O(&YO(&9O<FUA=&\@9&]S
M(&1A9&]S`&5D:71A<@!R96=I<W1R;R!NXV\@96YC;VYT<F%D;P!Q=65D80!A
M<G%U:79O`&$@<&%R=&ER(&1E("5S("@E<RD@X"`E<R`E<P!B<FES80!H.@!H
M:`!N;VUE(&1O(&AO<W0@Z2!D97-C;VYH96-I9&\`:6UE9&EA=&\`:6YC;W)P
M;W)A9&\`97)R;R!D92!E;G1R861A+W-A[61A`&5R<F\@:6YT97)N;R!D;R!P
M<F]G<F%M80!L:6YH87-=`&/S9&EG;R!D92!E<G)O("5D(&1O(&UK:7-O9G,@
M96YQ=6%N=&\@9V5R879A(&$@25-/+@!M;0!N;VUE`'-E;2!F;W)M871AY^-O
M`&YE;FAU;6$`;N-O(&EM<&QE;65N=&%D;P!NXV\@:6UP;&5M96YT861O(&%I
M;F1A`&)L;V-O(&1E(&YO=&%S`'!O<F-E;G1A9V5M`%!E<FUI<W/C;P!P:7AE
M;',`97)R;R!R96UO=&\@;F\@<')O=&]C;VQO`&YA<V-E;G1E`'-E<G9IYV\@
M:6YD:7-P;V[M=F5L`&5X:6)I<B!D:69E<F5NYV%S`'-M<S)E;6%I;"!V:6$@
M2%144`!S<P!E<W3A=F5L`&5R<F\@9&4@<VES=&5M80!L:7-T82!D92!T87)E
M9F%S`&9A;&AA('1E;7!O<N%R:6$`<&%R82!U;6$@3&ES=&$@9&4@0V]N=&%T
M;W,`<&%R82!U;2!#873A;&]G;R!D92!%;F1E<F7G;W,@9&EF97)E;G1E`'!R
M965N8VAA('-U82!S96YH82!D=6%S('9E>F5S('!A<F$@8V]N9FER;6%R`'5N
M:69I8V%D;P!S96T@;F]M90!S96QEY^-O(&1E('5S=>%R:6\`=D-A<F0`=SH`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O<'1?0E(O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S-#$P`#$P-#$W
M,S8R-S4U`#`R,30U-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M
M.#@U.2TQ(C\^"CPA+2T@)$AO<F1E.B!T=7)B82]L;V-A;&4O<'1?0E(O:&5L
M<"YX;6PL=B`Q+C$@,C`P-"\Q,2\P-"`R,#HQ.3HR-B!J86X@17AP("0@+2T^
M"CQH96QP/@H@(#QE;G1R>2!I9#TB3W9E<G9I97<B('-T871E/2)U;FMN;W=N
M(CX*("`@(#QT:71L93Y+<F]N;VQI=&@Z(%9I<^-O($=E<F%L/"]T:71L93X*
M("`@(#QH96%D:6YG/D\@<75E(.D@:W)O;F]L:71H/SPO:&5A9&EN9SX*("`@
M(#QP87)A/@I+<F]N;VQI=&@@Z2!U;2!C86QE;F3A<FEO(&1E(&EN=&5R9F%C
M92!796(N($5M(&%D:>?C;R!A<R!F=6[G]65S(&YE8V5S<^%R:6%S(&1E(&-R
M:6'GXV\L(&UO9&EF:6-AY^-O(&4@<F5M;^?C;R!D92!E=F5N=&]S+"!E;&4@
M871U86QM96YT92!S=7!O<G1A(')E<&5T:>?C;R!D92!E=F5N=&]S("AC;VT@
M97AC97-S]65S(&4@=N%R:6%S(&]PY_5E<R!D92!R96UOY^-O*2P@86QA<FUE
M<RP@9G5NY_5E<R!D92!I;7!O<G1AY^-O(&4@97AP;W)T8>?C;RP@=FES=6%L
M:7IAY^-O(&1A($QI<W1A(&1E(%1A<F5F87,@*$YA9RP@<V4@97-T:79E<B!I
M;G-T86QA9&\I+"!E(&$@<&]S<VEB:6QI9&%D92!D92!M;W-T<F%R(&]S(&5V
M96YT;W,@;F$@=&5L82!D92!S=6WA<FEO(&1O($AO<F1E+@H@("`@/"]P87)A
M/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB3W9E<G9I97<B/@H@
M("`@/'1I=&QE/D]V97)V:65W/"]T:71L93X*("`@(#QH96%D:6YG/DEN=')O
M9'5C=&EO;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE($%D9')E<W,@
M0F]O:R!P<F]V:61E<R!A(&-O;G9E;FEE;G0@;65T:&]D(&%N9"!P;&%C92!T
M;R!S=&]R92!C;VYT86-T(&EN9F]R;6%T:6]N(&9O<B!E87-Y(')E=')I979A
M;"!A;F0@=7-E+B!$97!E;F1I;F<@;VX@:&]W('EO=7(@861M:6YI<W1R871O
M<B!H87,@<V5T('5P('1H92!S>7-T96T@:70@8V%N('!R;W9I9&4@82!P<FEV
M871E(&%D9')E<W,@8F]O:R!A<R!W96QL(&%S(&%C8V5S<R!T;R!P=6)L:6,@
M;F5T=V]R:R!D:7)E8W1O<GD@<V5R=FEC97,N($ET(&%L<V\@<W5P<&]R=',@
M9&ES=')I8G5T:6]N(&QI<W1S('-O('EO=2!C86X@8W)E871E('EO=7(@;W=N
M(")M86EL:6YG(&QI<W1S+B(*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UA9&0B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/DUE;G4Z($%D9#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!9&0\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($%D9"!A('5S97(@=&\@86X@861D<F5S
M<R!B;V]K+B!9;W4@8V%N(&]N;'D@861D('5S97)S('1O('1H92!A9&1R97-S
M(&)O;VMS('1O('=H:6-H('EO=2!H879E('=R:71E(&%C8V5S<RX@268@<VAA
M<F5D(&]R('!U8FQI8R!A9&1R97-S(&)O;VMS(&AA=F4@8F5E;B!E;F%B;&5D
M('1H97D@87)E(&]F=&5N(')E860M;VYL>2!A;F0@>6]U('=I;&P@;F]T(&)E
M(&%B;&4@=&\@861D(&-O;G1A8W1S('1O('1H96TN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)M96YU+7-E87)C:"(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^365N=3H@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG
M/E-E87)C:#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5A<F-H(&%N(&%D
M9')E<W,@8F]O:R!T;R!L;V-A=&4@:6YF;W)M871I;VXN(%1H:7,@:7,@:6YT
M96YD960@87,@82!Q=6EC:R!S96%R8V@@86YD(&]N;'D@86QL;W=S('EO=2!T
M;R!S96%R8V@@;VX@82!F97<@8F%S:6,@9FEE;&1S+B!5<W5A;&QY('1H:7,@
M:7,@=&AE(&YA;64@86YD(&5M86EL(&%D9')E<W,@9FEE;&1S+"!B=70@8V]U
M;&0@=F%R>2!D97!E;F1I;F<@;VX@:&]W('EO=7(@861M:6YI<W1R871O<B!S
M970@=7`@=&AE(&%D9')E<W,@8F]O:RX*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@1F]R(&$@;6]R92!C;VUP;&5X('-E87)C:"!Y;W4@8V%N('5S92!T
M:&4@(CQR968@;6]D=6QE/2)T=7)B82(@96YT<GD](FUE;G4M861V86YC960M
M<V5A<F-H(CY!9'9A;F-E9"!396%R8V@\+W)E9CXB('=H:6-H('!E<FUI=',@
M<V5A<F-H:6YG(&]N(&]T:&5R(&9I96QD<RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](FUE;G4M861V86YC960M<V5A<F-H(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y-96YU.B!!9'9A;F-E9"!396%R8V@\+W1I=&QE
M/@H@("`@/&AE861I;F<^061V86YC960@4V5A<F-H/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!396%R8V@@86X@861D<F5S<R!B;V]K('1O(&QO8V%T92!I
M;F9O<FUA=&EO;BX@5&AI<R!S96%R8V@@86QL;W=S('EO=2!T;R!S96%R8V@@
M;VX@;75L=&EP;&4@9FEE;&1S+B!7:&EC:"!F:65L9',@87)E(&%V86EL86)L
M92!F;W(@<V5A<F-H:6YG(&1E<&5N9',@;VX@=&AE(&%D9')E<W,@8F]O:R!B
M96EN9R!S96%R8VAE9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](FUE;G4M:6UP;W)T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-96YU
M.B!);7!O<G0O17AP;W)T/"]T:71L93X*("`@(#QH96%D:6YG/DEM<&]R="]%
M>'!O<G0\+VAE861I;F<^"@H@("`@/'!A<F$^"B`@("!4:&ES(&UE;G4@86QL
M;W=S(&EM<&]R=&EN9R!T;R!A;F0@97AP;W)T:6YG(&9R;VT@>6]U<B!P97)S
M;VYA;"!A9&1R97-S(&)O;VLN($ET('-U<'!O<G1S(&)O=&@@0U-6("A#;VUM
M82!397!A<F%T960@5F%R:6%B;&4I+"!/=71L;V]K+"!A;F0@=D-A<F0@9F]R
M;6%T<RP@87,@=V5L;"!A<R!S;VUE(&]T:&5R('!O<'5L87(@9F]R;6%T<RX*
M("`@(#PO<&%R83X*"B`@("`\:&5A9&EN9SY);7!O<G1I;F<\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1O(&EM<&]R="!A;B!A9&1R97-S(&)O;VLL('EO
M=2!N965D('1O(&AA=F4@=&AE(&%D9')E<W,@8F]O:R!D871A('1O(&EM<&]R
M="!O;B!Y;W5R(&QO8V%L(&UA8VAI;F4@*&]N('=H:6-H('1H92!W96(@8G)O
M=W-E<B!I<R!R=6YN:6YG*2X@5&\@9&\@=&AI<RP@>6]U('=I;&P@;F5E9"!T
M;R!F:7)S="!E>'!O<G0@=&AE(&%D9')E<W,@8F]O:R!I;F9O<FUA=&EO;B!F
M<F]M('EO=7(@8W5R<F5N="!E;6%I;"!C;&EE;G0N"B`@("`\+W!A<F$^"@H@
M("`@/'!A<F$^"B`@("!)9B!Y;W4@=7-E($]U=&QO;VL@17AP<F5S<SH*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@,2D@0VQI8VL@;VX@1FEL92`F9W0[
M($5X<&]R="`F9W0[($%D9')E<W,@0F]O:PH@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("`R*2!396QE8W0@(E1E>'0@1FEL92(@*$-O;6UA(%-E<&%R871E
M9"!686QU97,I(&EN('1H92`B061D<F5S<R!";V]K($5X<&]R="!4;V]L(BX@
M0VQI8VL@;VX@(D5X<&]R="(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M(#,I($EN('1H92`B4V%V92!E>'!O<G1E9"!F:6QE<R!A<R(@9FEE;&0L('1Y
M<&4@:6X@82!N86UE(&9O<B!Y;W5R(&%D9')E<W,@8F]O:RX@0VQI8VL@(DYE
M>'0B+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`T*2!0=70@82!C:&5C
M:VUA<FL@:6X@=&AE(&)O>"!T;R!T:&4@;&5F="!O9B!E86-H(&]F('1H92!F
M:65L9',@=&AA="!Y;W4@=VES:"!T;R!E>'!O<G0N($-L:6-K(")&:6YI<V@B
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`U*2!9;W4@<VAO=6QD(')E
M8V5I=F4@82!M97-S86=E('1H870@<W1A=&5S("=!9&1R97-S(&)O;VL@97AP
M;W)T('!R;V-E<W,@:&%S(&-O;7!L971E9"<N($-L:6-K("=/2R<N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@(#8I($-L:6-K("=#;&]S92<@;VX@=&AE
M("=!9&1R97-S($)O;VL@17AP;W)T(%1O;VPG(&%N9"!C;&]S92!/=71L;V]K
M($5X<')E<W,N"B`@("`\+W!A<F$^"@H@("`@/'1I<#X*("`@($EF('1H92!E
M>'!O<G1E9"!A9&1R97-S(&)O;VL@9FEL92!I<R!N;W0@;&]C871E9"!O;B!Y
M;W5R(&1E<VMT;W`L(&%N9"!Y;W4G<F4@=7-I;F<@82!7:6YD;W=S(&]P97)A
M=&EN9R!S>7-T96TL(&-L:6-K(&]N(%-T87)T("9G=#L@1FEN9"!O<B!396%R
M8V@@)F=T.R!&:6QE<R!O<B!&;VQD97)S(&%N9"!S96%R8V@@>6]U<B!M86EN
M(&AA<F0@9')I=F4@9F]R('1H92!F:6QE(&YA;64@=&AA="!Y;W4@=7-E9"!I
M;B!S=&5P(#,N($UA:V4@82!N;W1E(&]F('1H92!F:6QE)W,@;&]C871I;VXN
M"B`@("`\+W1I<#X*"B`@("`\<&%R83X*("`@(%1O(&EM<&]R="!A;B!A9&1R
M97-S(&)O;VLL(&]P96X@=&AE(&%D9')E<W,@8F]O:R!Y;W4@=V%N="!T;R!I
M;7!O<G0@=&AE(&EN9F]R;6%T:6]N(&EN=&\N($-L:6-K(&]N('1H92`B26UP
M;W)T+T5X<&]R="(@26-O;BX@4V5L96-T('1H92!T>7!E(&]F(&%D9')E<W,@
M:6YF;W)M871I;VX@9&%T82!F:6QE('EO=2!W86YT('1O(&EM<&]R="!F<F]M
M('1H92!S96QE8W1I;VX@;&ES="X@0VQI8VL@;VX@=&AE(")B<F]W<V4B(&)U
M='1O;B!T;R!L;V]K(&9O<B!T:&4@861D<F5S<R!D871A(&9I;&4@;VX@>6]U
M<B!C;VUP=71E<BX@4V5L96-T('1H92!F:6QE+"!A;F0@8VQI8VL@;VX@=&AE
M("));7!O<G0B(&)U='1O;BX@5&AE(&EN9F]R;6%T:6]N(&EN('1H92!F:6QE
M('=I;&P@8F4@:6UP;W)T960@:6YT;R!Y;W5R(&%D9')E<W,@8F]O:RX*("`@
M(#PO<&%R83X*("`@(#QT:7`^"B`@("!3;VUE(&-O;7!L97@@96YT<FEE<RP@
M;W(@96YT<FEE<R!W:71H(&9I96QD<R!T:&%T(&1O(&YO="!M871C:"!Y;W5R
M(&%D9')E<W,@8F]O:R!F:65L9',L(&UA>2!N;W0@:6UP;W)T(&-O<G)E8W1L
M>2X@66]U('-H;W5L9"!V97)I9GD@=&AE(&EM<&]R=&5D(&1A=&$@869T97(@
M86X@:6UP;W)T+@H@("`@/"]T:7`^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S
M96%R8VAI;F<M<V5A<F-H7W)E<W5L=',B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E-E87)C:&EN9SH@4V5A<F-H(%)E<W5L=',\+W1I=&QE/@H@("`@/&AE
M861I;F<^4V5A<F-H(%)E<W5L=',\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($EF(&$@<V5A<F-H(&ES('-U8V-E<W-F=6PL('1H92!R97-U;'1S('=I;&P@
M<VAO=R!U<"!I;B!T:&4@(E-E87)C:"!297-U;'1S(B!A<F5A+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:VEN9R!O;B!A;B`B16UA:6PB(&9I
M96QD(&5N=')Y('=I;&P@;W!E;B!A(&YE=R!#;VUP;W-E('=I;F1O=R!T;R!S
M96YD(&UA:6P@=&\@=&AA="!A9&1R97-S+B!#;&EC:VEN9R!O;B!A(").86UE
M(B!F:65L9"!E;G1R>2!W:6QL(&1I<W!L87D@=&AE(&%D9')E<W,@8F]O:R!R
M96-O<F0@9F]R('1H870@;F%M92P@86QL;W=I;F<@>6]U('1O('1H96X@961I
M="!O<B!D96QE=&4@=&AE(&5N=')Y+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("!$97!E;F1I;F<@;VX@:&]W('EO=7(@<WES=&5M(&AA<R!B965N('-E
M="!U<"!B>2!T:&4@861M:6YI<W1R871O<B!S96%R8V@@<F5S=6QT<R!C86X@
M8F4@8W5M=6QA=&EV92X@16%C:"!S96%R8V@@=VEL;"!A9&0@86YY(&YE=R!R
M97-U;'1S('1O('EO=7(@97AI<W1I;F<@<F5S=6QT<RX@5&AI<R!I<R!H96QP
M9G5L('=H96X@8G5I;&1I;F<@;&ES=',N(%1O(')E;6]V92!T:&4@<F5S=6QT
M<R!O9B!C=6UU;&%T:79E('-E87)C:&5S(&%N9"!S=&%R="!A(&YE=R!S96%R
M8V@L(&-L:6-K(&]N('1H92`B0VQE87(@4V5A<F-H(B!L:6YK+@H@("`@/"]P
M87)A/@H*("`@(#QT:7`^"B`@("!7:&5N('9I97=I;F<@82!L:7-T(&]F(&5N
M=')I97,L('EO=2!C86X@<V]R="!T:&4@96YT<FEE<R!B>2!E86-H(&9I96QD
M('-H;W=N(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T92!C;VQU;6X@
M:&5A9&EN9RX@5&\@<W=I=&-H(&-O;'5M;G,@8F5T=V5E;B!A<V-E;F1I;F<@
M86YD(&1E<V-E;F1I;F<@<V]R="!O<F1E<BP@8VQI8VL@;VX@=&AE(&%R<F]W
M(&EC;VX@:6X@=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@/"]T:7`^"CPO96YT
M<GD^"CPO:&5L<#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]P=%]05"\`````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-34`,#(P,#,P`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE
M+W!T7U!4+TQ#7TU%4U-!1T53+P``````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C$V,34`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T=7)B82]L;V-A;&4O<'1?4%0O3$-?34534T%'15,O='5R8F$N;6\`
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P-#8W,C8R`#$P-#$W,S8R-S4U`#`R,S,P-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#>$@25
M`````$@(```<````7$(``!$+``"<A````````."P``!-````X;```+\````O
ML0``9````.^Q``"^````5+(``)`````3LP``0P```*2S```\````Z+,``"L`
M```EM```+@```%&T```I````@+0``"@```"JM```10```-.T``!'````&;4`
M`$H```!AM0``1P```*RU``!%````]+4``$@````ZM@``.0```(.V``!&````
MO;8``$@````$MP``,````$VW``!%````?K<``$8```#$MP``3`````NX```T
M````6+@``#(```"-N```:0```,"X```P````*KD``"4```!;N0``B````(&Y
M``!`````"KH``/8```!+N@``2@```$*[```L````C;L``(4```"ZNP``2```
M`$"\```.````B;P```\```"8O```#0```*B\```(````MKP```L```"_O```
M#````,N\```$````V+P``!L```#=O```+0```/F\```=````)[T``"0```!%
MO0``*0```&J]```I````E+T``!D```"^O0``*````-B]```D`````;X``"4`
M```FO@``#````$R^```1````6;X``"4```!KO@``#P```)&^```+````H;X`
M`!$```"MO@``#@```+^^```%````SKX``"@```#4O@``"````/V^```*````
M!K\``!4````1OP``"0```">_```2````,;\```L```!$OP``'0```%"_```3
M````;K\```X```""OP``"@```)&_```-````G+\``"X```"JOP``#@```-F_
M```1````Z+\```T```#ZOP``#`````C````-````%<````8````CP```"@``
M`"K````/````-<```!@```!%P```#````%[````;````:\````X```"'P```
M#@```);````(````I<````D```"NP```0@```+C````K````^\```"X````G
MP0``&@```%;!```R````<<$``#@```"DP0``5````-W!``!1````,L(``%H`
M``"$P@``5P```-_"```T````-\,```D```!LPP``#0```';#```'````A,,`
M``H```",PP``#P```)?#```%````I\,```8```"MPP``$0```+3#```(````
MQL,``!$```#/PP``"0```.'#```)````Z\,``"4```#UPP``(````!O$```0
M````/,0```\```!-Q```"@```%W$```0````:,0```,```!YQ```#P```'W$
M```4````C<0```D```"BQ```#0```*S$```2````NL0``!D```#-Q```'@``
M`.?$```/````!L4```H````6Q0``#P```"'%```(````,<4``"0````ZQ0``
M!@```%_%```4````9L4``!8```![Q0``"````)+%``!.````F\4``"T```#J
MQ0``'P```!C&```9````.,8```<```!2Q@``#````%K&```4````9\8``!(`
M``!\Q@``&@```(_&```A````JL8``"P```#,Q@``#@```/G&```#````",<`
M``\````,QP``"P```!S'```'````*,<```<````PQP``!0```#C'```%````
M/L<```H```!$QP```P```$_'```7````4\<```H```!KQP``#P```';'```.
M````AL<``!@```"5QP``(P```*['```.````TL<```X```#AQP``%````/#'
M```7````!<@``!<````=R```%P```#7(```3````3<@```\```!AR```#@``
M`''(```?````@,@``!T```"@R```!P```+[(```&````QL@```@```#-R```
M#P```-;(```&````YL@```H```#MR```$P```/C(```+````#,D``!4````8
MR0``%0```"[)```'````1,D``!````!,R0``!0```%W)```5````8\D``!$`
M``!YR0``#````(O)```H````F,D``#H```#!R0``.P```/S)```X````.,H`
M``D```!QR@``!P```'O*```4````@\H```,```"8R@``!0```)S*```)````
MHLH``!````"LR@``"0```+W*```3````Q\H``#D```#;R@``$@```!7+```G
M````*,L``"P```!0RP``*@```'W+```E````J,L```H```#.RP``!@```-G+
M```)````X,L```<```#JRP``+P```/++```W````(LP``"X```!:S```50``
M`(G,```M````W\P``"T````-S0``+0```#O-``!`````:<T``",```"JS0``
M(P```,[-```M````\LT``#,````@S@``%0```%3.```9````:LX``"D```"$
MS@``)````*[.```2````T\X``!$```#FS@``"@```/C.```,`````\\```L`
M```0SP``"@```!S/```*````)\\``!`````RSP``%@```$//```6````6L\`
M``<```!QSP``!P```'G/```4````@<\```H```"6SP``"````*'/```(````
MJL\```T```"SSP``#````,'/```'````SL\```<```#6SP``!@```-[/```1
M````Y<\```4```#WSP``!P```/W/```&````!=```!0````,T```"````"'0
M```I````*M````X```!4T```"@```&/0```$````;M````<```!ST```"0``
M`'O0```&````A=```!$```",T```!P```)[0```6````IM````0```"]T```
M"````,+0```&````R]````T```#2T```!@```.#0```>````Y]```!$````&
MT0``(@```!C1```6````.]$```@```!2T0``#0```%O1```,````:=$```<`
M``!VT0``$0```'[1```#````D-$```,```"4T0``%P```)C1```#````L-$`
M`!,```"TT0``#0```,C1```=````UM$```@```#TT0``!````/W1```(````
M`M(```@````+T@``00```!32```@````5M(```8```!WT@``!@```'[2```5
M````A=(``!@```";T@``(@```+32```N````U](``!T````&TP``(0```"33
M``!4````1M,``"D```";TP``"@```,73```'````T-,``!4```#8TP``#@``
M`.[3```*````_=,```\````(U```#0```!C4```/````)M0```T````VU```
M"0```$34```4````3M0```8```!CU```&````&K4```=````@]0``!,```"A
MU```$0```+74```4````Q]0```0```#<U```!@```.'4``!4````Z-0```0`
M```]U0``#@```$+5```/````4=4``$0```!AU0``!0```*;5```%````K-4`
M`!L```"RU0``&@```,[5``!6````Z=4``!$```!`U@``$0```%+6```6````
M9-8``!P```![U@``*@```)C6```_````P]8``!`````#UP``(0```!37```E
M````-M<``!D```!<UP``!0```';7```3````?-<```P```"0UP``$@```)W7
M```*````L-<```\```"[UP``#0```,O7```1````V=<``!,```#KUP``#```
M`/_7```&````#-@```P````3V```!@```"#8```7````)]@``!`````_V```
M$0```%#8```(````8M@```4```!KV```#````''8```0````?M@```4```"/
MV```#@```)78```-````I-@```8```"RV```%@```+G8```J````T-@```<`
M``#[V```#0````/9```0````$=D```D````BV0``!P```"S9```+````--D`
M``L```!`V0``!P```$S9```'````5-D```\```!<V0``%````&S9```)````
M@=D```D```"+V0``"@```)79```9````H-D``!T```"ZV0``#````-C9```0
M````Y=D```4```#VV0``)0```/S9```2````(MH``!,````UV@``%0```$G:
M```2````7]H``"L```!RV@``.P```)[:```@````VMH``!H```#[V@``%```
M`!;;```V````*]L``"$```!BVP``$````(3;```.````E=L```@```"DVP``
M#````*W;```&````NML```0```#!VP``#@```,;;```0````U=L```H```#F
MVP``#0```/';```>````_]L``!L````>W```(0```#K<```>````7-P``!D`
M``![W```'@```)7<```;````M-P``"X```#0W```%P```/_<```F````%]T`
M`#`````^W0``&P```&_=```>````B]T``!P```"JW0``)@```,?=```K````
M[MT``#,````:W@``)@```$[>```K````==X``#@```"AW@``'0```-K>```5
M````^-X``"\````.WP``(````#[?```2````7]\``"D```!RWP``'@```)S?
M```2````N]\``*(```#.WP``%@```''@```C````B.```"@```"LX```*0``
M`-7@```H````_^```!\````HX0``%0```$CA```@````7N$``"4```!_X0``
M*````*7A```M````SN$``#````#\X0``D@```"WB```A````P.(``!8```#B
MX@``'````/GB```F````%N,``"H````]XP``00```&CC``!$````JN,```P`
M``#OXP``!P```/SC```'````!.0```8````,Y```#0```!/D```0````(>0`
M`!(````RY```!P```$7D```3````3>0``!(```!AY```!P```'3D```$````
M?.0``!````"!Y```#````)+D```.````G^0```\```"NY```$P```+[D```-
M````TN0``"@```#@Y````P````GE```-````#>4```8````;Y0``$0```"+E
M```7````-.4``!L```!,Y0``#@```&CE```"````=^4```4```!ZY0``$```
M`(#E```$````D>4```T```"6Y0``#@```*3E```#````L^4```X```"WY0``
M"````,;E```/````S^4```\```#?Y0``!P```._E```-````]^4```\````%
MY@``$````!7F```3````)N8``$T````ZY@``$P```(CF```:````G.8```L`
M``"WY@``!@```,/F```3````RN8```P```#>Y@``$0```.OF```9````_>8`
M`!<````7YP``"P```"_G```-````.^<``"(```!)YP``%@```&SG```;````
M@^<``#0```"?YP``"@```-3G```8````W^<``!D```#XYP``%@```!+H```O
M````*>@``"(```!9Z```#P```'SH```-````C.@```<```":Z```"@```*+H
M```*````K>@``!0```"XZ```"P```,WH```B````V>@``"\```#\Z```"P``
M`"SI```)````..D``!D```!"Z0``"P```%SI```7````:.D``!<```"`Z0``
M"0```)CI```6````HND```\```"YZ0``&0```,GI```6````X^D```X```#Z
MZ0``&`````GJ```(````(NH```T````KZ@``)@```#GJ```H````8.H``$,`
M``")Z@``"````,WJ```2````UNH```@```#IZ@``"P```/+J```O````_NH`
M``X````NZP``#@```#WK```%````3.L```8```!2ZP```P```%GK```'````
M7>L```0```!EZP``"0```&KK```*````=.L```H```!_ZP``#P```(KK```0
M````FNL``!<```"KZP``$0```,/K```1````U>L``!D```#GZP``%P````'L
M```)````&>P```4````C[```"P```"GL```*````->P```(```!`[```!0``
M`$/L```-````2>P``!L```!7[```%P```'/L```)````B^P```X```"5[```
M#0```*3L```2````LNP``#@```#%[```(````/[L```(````'^T```X````H
M[0``>P```#?M```8````L^T``$````#,[0``%0````WN```1````(^X```<`
M```U[@``!0```#WN```9````0^X``!,```!=[@``!P```''N```'````>>X`
M``@```"![@``!@```(KN```&````D>X``!````"8[@``#P```*GN```0````
MN>X```\```#*[@``"P```-KN```/````YNX```P```#V[@``#P````/O```'
M````$^\```H````;[P``!@```";O```.````+>\```P````\[P``*````$GO
M```/````<N\```@```""[P``!@```(OO```3````DN\``"(```"F[P``+0``
M`,GO```6````]^\```@````.\```$P```!?P```>````*_```"4```!*\```
M&@```'#P```5````B_```!X```"A\```0P```,#P```A````!/$``"`````F
M\0``&0```$?Q```7````8?$``"4```!Y\0``)0```)_Q```7````Q?$``"(`
M``#=\0``!`````#R```;````!?(```T````A\@``#````"_R```#````//(`
M``@```!`\@``"@```$GR```,````5/(```L```!A\@``$````&WR```,````
M?O(```0```"+\@``$P```)#R```4````I/(```P```"Y\@``"0```,;R```.
M````T/(```L```#?\@``&P```.OR```'````!_,```0````/\P``!P```!3S
M```*````'/,```H````G\P``#0```#+S```)````0/,```0```!*\P``!0``
M`$_S```#````5?,``!@```!9\P``"@```'+S```$````??,``"8```""\P``
M#@```*GS``!\````N/,``!4````U]```!0```$OT```'````4?0```P```!9
M]```"````&;T```*````;_0```8```!Z]```"````('T```6````BO0``!(`
M``"A]````@```+3T```&````M_0```8```"^]```%````,7T```,````VO0`
M``T```#G]```$````/7T```;````!O4```0````B]0``"0```"?U```0````
M,?4```D```!"]0``"0```$SU```%````5O4```4```!<]0``&@```&+U```(
M````??4```8```"&]0``&0```(WU```.````I_4``"(```"V]0``!P```-GU
M```'````X?4```X```#I]0``!0```/CU```)````_O4```H````(]@``$P``
M`!/V```"````)_8```8````J]@``#0```#'V```)````/_8```8```!)]@``
M$@```%#V```)````8_8```<```!M]@``!0```'7V```4````>_8``!T```"0
M]@``$0```*[V```&````P/8```H```#']@``!````-+V```)````U_8```@`
M``#A]@``$0```.KV```1````_/8```D````.]P``!@```!CW```-````'_<`
M``8````M]P``!````#3W```Y````.?<``#T```!S]P``.@```+'W```>````
M[/<```4````+^```#@```!'X```$````(/@```8````E^```(0```"SX```-
M````3O@``!4```!<^```!@```'+X```$````>?@``!$```!^^```!@```)#X
M``"@````E_@```H````X^0``(@```$/Y```$````9OD``"4```!K^0``!0``
M`)'Y```=````E_D```0```"U^0``#````+KY```)````Q_D```P```#1^0``
M"@```-[Y```0````Z?D``!,```#Z^0``$P````[Z```(````(OH```D````K
M^@``!0```#7Z```;````._H``#H```!7^@``,````)+Z```U````P_H``"D`
M``#Y^@``+@```"/[``!'````4OL``#@```":^P``*0```-/[```_````_?L`
M`"X````]_```+0```&S\```?````FOP```\```"Z_```$@```,K\```+````
MW?P``"8```#I_```*0```!#]```D````.OT``"8```!?_0``"````(;]```*
M````C_T```D```":_0``!P```*3]```@````K/T``"````#-_0``)@```.[]
M```$````%?X```H````:_@``&0```"7^```I````/_X``!8```!I_@``$@``
M`(#^```'````D_X```H```";_@``#P```*;^```0````MOX``$````#'_@``
M<`````C_``!F````>?\```X```#@_P``"0```.__```*````^?\``!(````$
M``$`$P```!<``0`,````*P`!``8````X``$`'````#\``0`/````7``!`!L`
M``!L``$`$@```(@``0`0````FP`!`!$```"L``$`'````+X``0`C````VP`!
M`&H```#_``$`#P```&H!`0`%````>@$!`!````"``0$`"0```)$!`0`$````
MFP$!``L```"@`0$`(````*P!`0`:````S0$!`!0```#H`0$`#````/T!`0`,
M````"@(!``\````7`@$`%0```"<"`0`I````/0(!`"H```!G`@$`)@```)("
M`0`G````N0(!`"D```#A`@$`*@````L#`0`9````-@,!`$(```!0`P$`$0``
M`),#`0`2````I0,!`!,```"X`P$`%````,P#`0`/````X0,!`!8```#Q`P$`
M%P````@$`0`0````(`0!`!$````Q!`$`-````$,$`0`3````>`0!`!(```",
M!`$`-0```)\$`0`4````U00!``<```#J!`$`#````/($`0`4````_P0!``H`
M```4!0$`(````!\%`0`0````0`4!`!0```!1!0$`%````&8%`0`1````>P4!
M`!<```"-!0$`'````*4%`0`-````P@4!``T```#0!0$`$P```-X%`0`6````
M\@4!`!0````)!@$`&@```!X&`0`1````.08!``P```!+!@$`$````%@&`0`:
M````:08!`!X```"$!@$`&@```*,&`0`3````O@8!`!4```#2!@$`$0```.@&
M`0`7````^@8!`!0````2!P$`%P```"<'`0`5````/P<!``D```!5!P$`&0``
M`%\'`0`$````>0<!``<```!^!P$`"P```(8'`0`1````D@<!``8```"D!P$`
M!@```*L'`0`&````L@<!``4```"Y!P$`!P```+\'`0`'````QP<!``4```#/
M!P$`%@```-4'`0`&````[`<!``8```#S!P$`!````/H'`0`$````_P<!``<`
M```$"`$`#@````P(`0`,````&P@!``P````H"`$`#0```#4(`0`*````0P@!
M``X```!."`$`!0```%T(`0`H````8P@!``X```","`$`#````)L(`0`/````
MJ`@!``H```"X"`$`"````,,(`0`)````S`@!`"L```#6"`$`!`````()`0`(
M````!PD!`"8````0"0$`$@```#<)`0`/````2@D!``8```!:"0$`"@```&$)
M`0!,````;`D!``<```"Y"0$`"````,$)`0`@````R@D!``D```#K"0$`#0``
M`/4)`0`)`````PH!``P````-"@$`#0```!H*`0`.````*`H!`!8````W"@$`
M$0```$X*`0`&````8`H!``,```!G"@$`!@```&L*`0`9````<@H!``<```",
M"@$`!````)0*`0`+````F0H!``L```"E"@$`!P```+$*`0`'````N0H!`!8`
M``#!"@$`#0```-@*`0`-````Y@H!``H```#T"@$`$````/\*`0`/````$`L!
M`!$````@"P$`%P```#(+`0`*````2@L!`!$```!5"P$`"````&<+`0`$````
M<`L!``\```!U"P$`.@```(4+`0`%````P`L!``P```#&"P$`!````-,+`0`>
M````V`L!``X```#W"P$`$`````8,`0`+````%PP!``P````C#`$`"0```#`,
M`0`'````.@P!``H```!"#`$`"0```$T,`0`.````5PP!`!````!F#`$`&@``
M`'<,`0`*````D@P!``D```"=#`$`%````*<,`0`*````O`P!``P```#'#`$`
M#P```-0,`0`(````Y`P!``8```#M#`$`!P```/0,`0`+````_`P!`$<````(
M#0$`#0```%`-`0`)````7@T!``0```!H#0$``P```&T-`0`3````<0T!`!,`
M``"%#0$`$P```)D-`0`*````K0T!``(```"X#0$`!````+L-`0`E````P`T!
M``,```#F#0$`!0```.H-`0`J````\`T!``H````;#@$`!0```"8.`0`$````
M+`X!``H````Q#@$`#0```#P.`0!`````2@X!`!,```"+#@$`!@```)\.`0`(
M````I@X!``@```"O#@$`!````+@.`0`%````O0X!`&@```###@$`"0```"P/
M`0`,````-@\!``4```!##P$`!@```$D/`0`;````4`\!`"\```!L#P$`$```
M`)P/`0`*````K0\!``@```"X#P$`#P```,$/`0`*````T0\!``D```#<#P$`
M$P```.8/`0`;````^@\!`!@````6$`$`%P```"\0`0`.````1Q`!`!<```!6
M$`$``P```&X0`0`'````<A`!``@```!Z$`$`!P```(,0`0`*````BQ`!``L`
M``"6$`$`+0```*(0`0`5````T!`!`#````#F$`$`)````!<1`0`'````/!$!
M`%$```!$$0$`$````)81`0`,````IQ$!``T```"T$0$`&@```,(1`0!*````
MW1$!`!D````H$@$`!@```$(2`0`:````21(!``8```!D$@$`!@```&L2`0`?
M````<A(!``8```"2$@$`"0```)D2`0`8````HQ(!`!<```"\$@$`"P```-02
M`0`&````X!(!``T```#G$@$`*````/42`0`B````'A,!`%<```!!$P$`$P``
M`)D3`0`C````K1,!`!,```#1$P$``@```.43`0`+````Z!,!``P```#T$P$`
M"`````$4`0`-````"A0!``H````8%`$`%@```",4`0`&````.A0!``<```!!
M%`$`%````$D4`0`&````7A0!``@```!E%`$`#@```&X4`0`'````?10!``H`
M``"%%`$`"P```)`4`0`7````G!0!``<```"T%`$`#````+P4`0`-````R10!
M``P```#7%`$`!````.04`0`)````Z10!``D```#S%`$`"@```/T4`0`'````
M"!4!``D````0%0$`"0```!H5`0`*````)!4!``<````O%0$`"@```#<5`0`5
M````0A4!`!L```!8%0$`20```'05`0`2````OA4!``H```#1%0$`#P```-P5
M`0`)````[!4!`!````#V%0$`!P````<6`0`2````#Q8!``0````B%@$`"P``
M`"<6`0`'````,Q8!``4````[%@$`!0```$$6`0`:````1Q8!``L```!B%@$`
M%````&X6`0`1````@Q8!`!H```"5%@$`%@```+`6`0`4````QQ8!`!<```#<
M%@$`&````/06`0`<````#1<!`!D````J%P$`!P```$07`0`%````3!<!``T`
M``!2%P$`#````&`7`0`+````;1<!``@```!Y%P$`"````((7`0`7````BQ<!
M``L```"C%P$`$P```*\7`0`$````PQ<!``H```#(%P$`!````-,7`0`-````
MV!<!``P```#F%P$`!0```/,7`0`)````^1<!``@````#&`$`!0````P8`0`'
M````$A@!``4````:&`$`!````"`8`0`"````)1@!`!@````H&`$`%P```$$8
M`0`X````61@!`"P```"2&`$`$@```+\8`0`I````TA@!`#(```#\&`$`"@``
M`"\9`0`V````.AD!`"P```!Q&0$`%0```)X9`0`N````M!D!`#,```#C&0$`
M,P```!<:`0`X````2QH!`!$```"$&@$`#P```)8:`0`8````IAH!`#L```"_
M&@$`$````/L:`0`4````#!L!`!,````A&P$`%0```#4;`0`4````2QL!`!(`
M``!@&P$`%````',;`0`5````B!L!`"T```">&P$`+0```,P;`0`Q````^AL!
M`"T````L'`$`+@```%H<`0`O````B1P!`"P```"Y'`$`8@```.8<`0`3````
M21T!``@```!='0$`"````&8=`0`K````;QT!`"$```";'0$`&````+T=`0`:
M````UAT!``D```#Q'0$`10```/L=`0!!````01X!``0```"#'@$`$P```(@>
M`0`4````G!X!``X```"Q'@$`$P```,`>`0`8````U!X!``8```#M'@$`"0``
M`/0>`0`*````_AX!``\````)'P$`$````!D?`0`'````*A\!``X````R'P$`
M!0```$$?`0`;````1Q\!``8```!C'P$`"````&H?`0`&````<Q\!`!0```!Z
M'P$`$0```(\?`0`8````H1\!``X```"Z'P$`.````,D?`0`"`````B`!``8`
M```%(`$`#@````P@`0`:````&R`!`!`````V(`$`!0```$<@`0`'````32`!
M``X```!5(`$`!@```&0@`0`$````:R`!`"D```!P(`$`%P```)H@`0`?````
MLB`!`%P```#2(`$`%````"\A`0`^````1"$!`!\```"#(0$`$````*,A`0`'
M````M"$!``X```"\(0$`"````,LA`0`,````U"$!``P```#A(0$`$P```.XA
M`0`*`````B(!`!T````-(@$`&0```"LB`0`%````12(!`!$```!+(@$`#0``
M`%TB`0`1````:R(!`"0```!](@$`%0```*(B`0`2````N"(!``X```#+(@$`
M&0```-HB`0`(````]"(!``D```#](@$`#0````<C`0`*````%2,!``<````@
M(P$`#P```"@C`0`&````.",!``L````_(P$`"@```$LC`0`'````5B,!``@`
M``!>(P$`!0```&<C`0`?````;2,!``8```"-(P$`$````)0C`0`(````I2,!
M``T```"N(P$`"````+PC`0`2````Q2,!`"P```#8(P$`&@````4D`0`)````
M("0!``H````J)`$`%0```#4D`0`%````2R0!`!0```!1)`$`!````&8D`0`0
M````:R0!``8```!\)`$`!P```(,D`0`>````BR0!`"@```"J)`$`"@```-,D
M`0`<````WB0!`!$```#[)`$`$0````TE`0`:````'R4!``\````Z)0$`%```
M`$HE`0`$````7R4!``0```!D)0$`"P```&DE`0`%````=24!``8```![)0$`
M$0```((E`0`(````E"4!``8```"=)0$`"@```*0E`0`;````KR4!`#0```#+
M)0$`-``````F`0`@````-28!`"D```!6)@$`(````(`F`0!!````H28!`!H`
M``#C)@$`)@```/XF`0`H````)2<!`"D```!.)P$`40```'@G`0`O````RB<!
M`!H```#Z)P$`(@```!4H`0`&````."@!``@````_*`$`!0```$@H`0`(````
M3B@!`!D```!7*`$`&0```'$H`0`J````BR@!`",```"V*`$`&0```-HH`0`N
M````]"@!`#0````C*0$`"````%@I`0`7````82D!``H```!Y*0$`!P```(0I
M`0`A````C"D!`!````"N*0$`#@```+\I`0`4````SBD!``L```#C*0$`!P``
M`.\I`0`3````]RD!``@````+*@$`"P```!0J`0`*````("H!`!0````K*@$`
M#P```$`J`0`R````4"H!``L```"#*@$`!0```(\J`0`%````E2H!`!4```";
M*@$`#````+$J`0`7````OBH!``\```#6*@$`!````.8J`0`*````ZRH!``D`
M``#V*@$`"P`````K`0`-````#"L!``P````:*P$`#@```"<K`0`%````-BL!
M``0````\*P$`%````$$K`0`-````5BL!`#(```!D*P$`10```)<K`0`2````
MW2L!`!<```#P*P$`'@````@L`0`4````)RP!``4````\+`$`%````$(L`0`'
M````5RP!``X```!?+`$`*@```&XL`0`&````F2P!``P```"@+`$`#0```*TL
M`0`1````NRP!`!4```#-+`$`"P```.,L`0`V````[RP!``H````F+0$`(@``
M`#$M`0`+````5"T!``\```!@+0$`>P```'`M`0`R````["T!`!L````?+@$`
M)0```#LN`0`P````82X!`#$```"2+@$`+0```,0N`0`.````\BX!``4````!
M+P$`#@````<O`0`3````%B\!`!$````J+P$`!P```#PO`0`:````1"\!``@`
M``!?+P$`$0```&@O`0`'````>B\!`!0```""+P$`&````)<O`0`'````L"\!
M``4```"X+P$`#````+XO`0`,````RR\!`!(```#8+P$`!````.LO`0`'````
M\"\!``H```#X+P$`"P````,P`0`,````#S`!``X````<,`$`#@```"LP`0`%
M````.C`!``4```!`,`$`+@```$8P`0`F````=3`!`",```"<,`$``P```,`P
M`0`2````Q#`!``8```#7,`$`'@```-XP`0`8````_3`!`!D````6,0$`)0``
M`#`Q`0`-````5C$!``D```!D,0$``P```&XQ`0`8````<C$!``<```"+,0$`
M"@```),Q`0`"````GC$!``P```"A,0$`%0```*XQ`0`+````Q#$!`!D```#0
M,0$`(````.HQ`0`2````"S(!``4````>,@$`"@```"0R`0`5````+S(!`!(`
M``!%,@$`#````%@R`0`$````93(!``<```!J,@$`"0```'(R`0`,````?#(!
M`%(```"),@$`%P```-PR`0`D````]#(!`!(````9,P$`!P```"PS`0`&````
M-#,!``X````[,P$`#@```$HS`0`-````63,!`!$```!G,P$`(@```'DS`0`1
M````G#,!`!T```"N,P$`#````,PS`0`3````V3,!``P```#M,P$`"P```/HS
M`0`-````!C0!`!4````4-`$`$@```"HT`0`/````/30!`!0```!--`$`&P``
M`&(T`0`0````?C0!`"<```"/-`$`)0```+<T`0!I````W30!`!H```!'-0$`
M%P```&(U`0`9````>C4!`!H```"4-0$`)0```*\U`0`H````U34!`"<```#^
M-0$`&@```"8V`0`7````038!`!L```!9-@$`(@```'4V`0`T````F#8!`"4`
M``#--@$`&0```/,V`0`?````#3<!`!$````M-P$`&P```#\W`0`3````6S<!
M``@```!O-P$`!P```'@W`0`(````@#<!``D```")-P$`%0```),W`0`-````
MJ3<!`",```"W-P$`$P```-LW`0`#````[S<!`$8```#S-P$`/P```#HX`0`W
M````>C@!`%<```"R.`$`!0````HY`0`?````$#D!`"\````P.0$`"@```&`Y
M`0`0````:SD!``D```!\.0$`"````(8Y`0`-````CSD!`"T```"=.0$`!```
M`,LY`0`(````T#D!``T```#9.0$`"@```.<Y`0`.````\CD!``L````!.@$`
M3P````TZ`0`E````73H!`!P```"#.@$`"P```*`Z`0`?````K#H!`!T```#,
M.@$`)0```.HZ`0`@````$#L!`"0````Q.P$`(````%8[`0`+````=SL!``<`
M``"#.P$`#0```(L[`0`,````F3L!`!<```"F.P$`!@```+X[`0`Y````Q3L!
M``P```#_.P$`!P````P\`0`9````%#P!``D````N/`$`$P```#@\`0`)````
M3#P!``0```!6/`$`$````%L\`0`*````;#P!``@```!W/`$`"````(`\`0`$
M````B3P!``L```"./`$`#````)H\`0`2````ISP!`!$```"Z/`$`#````,P\
M`0`:````V3P!``\```#T/`$`!P````0]`0`-````##T!``X````:/0$`%```
M`"D]`0`.````/CT!``<```!-/0$`#````%4]`0`;````8CT!`"P```!^/0$`
M$P```*L]`0`<````OST!`"@```#</0$`!@````4^`0`'````##X!`!,````4
M/@$`!0```"@^`0`$````+CX!`!<````S/@$`.0```$L^`0`*````A3X!``P`
M``"0/@$`"0```)T^`0`&````ISX!``D```"N/@$`"````+@^`0`)````P3X!
M``H```#+/@$`$0```-8^`0`&````Z#X!`!@```#O/@$`#@````@_`0`.````
M%S\!``T````F/P$`"P```#0_`0`=````0#\!``L```!>/P$``@```&H_`0`'
M````;3\!``8```!U/P$`90```'P_`0`)````XC\!``<```#L/P$`)@```/0_
M`0`;````&T`!`#@````W0`$`&@```'!``0`J````BT`!`#L```"V0`$`*```
M`/)``0`T````&T$!`!D```!000$`%0```&I!`0`%````@$$!``<```"&00$`
M"````(Y!`0`'````ET$!``4```"?00$`!P```*5!`0`.````K4$!``D```"\
M00$`!@```,9!`0`(````S4$!``L```#600$`!P```.)!`0`(````ZD$!``<`
M``#S00$`%@```/M!`0`)````$D(!``8````<0@$`"P```"-"`0`<````+T(!
M`!0```!,0@$`!P```&%"`0`1````:4(!``@```![0@$`#@```(1"`0`#````
MDT(!``@```"70@$`%````*!"`0`%````M4(!`!````"[0@$`$````,Q"`0`&
M````W4(!`!D```#D0@$`"@```/Y"`0`<````"4,!``<````F0P$`!0```"Y#
M`0`0````-$,!`!0```!%0P$`"P```%I#`0`-````9D,!`"@```!T0P$`&```
M`)U#`0`7````MD,!``0```#.0P$`"0```--#`0`*````W4,!``<```#H0P$`
M`@```/!#`0`.````\T,!``@````"1`$`'P````M$`0`^````*T0!`",```!J
M1`$`.````(Y$`0`F````QT0!`#$```#N1`$`)P```"!%`0`H````2$4!`&0`
M``!Q10$`%````-9%`0!5````ZT4!`#@```!!1@$`*0```'I&`0!*````I$8!
M`%L```#O1@$`*````$M'`0`X````=$<!`"@```"M1P$`+````-9'`0`G````
M`T@!`!L````K2`$`/@```$=(`0"I`0``AD@!`"@````P2@$`(P```%E*`0`7
M````?4H!`$@```"52@$`A0```-Y*`0`P````9$L!`$$```"52P$`6P```-=+
M`0!)````,TP!`!T```!]3`$`&````)M,`0`A````M$P!`!\```#63`$`*P``
M`/9,`0`A````(DT!`"<```!$30$`'0```&Q-`0`1````BDT!`#,```"<30$`
M)0```-!-`0`G````]DT!`"8````>3@$`'P```$5.`0`P````94X!`,P```"6
M3@$`:0```&-/`0`K````S4\!`#$```#Y3P$`00```"M0`0`S````;5`!`"4`
M``"A4`$`/0```,=0`0!E````!5$!`$T```!K40$`7@```+E1`0`G````&%(!
M`#P```!`4@$`+````'U2`0`H````JE(!`"T```#34@$`+P````%3`0`N````
M,5,!`"D```!@4P$`,````(I3`0!4````NU,!`(,````05`$`6@```)14`0`H
M````[U0!`$@````850$`2@```&%5`0`J````K%4!`"(```#750$`,@```/I5
M`0`>````+58!`"\```!,5@$`+````'Q6`0`M````J58!`'$```#75@$`;P``
M`$E7`0"S````N5<!`!<```!M6`$`)0```(58`0`R````JU@!`"D```#>6`$`
M/@````A9`0`B````1UD!`%(```!J60$`(@```+U9`0`E````X%D!``L````&
M6@$`L0```!):`0!%````Q%H!`"$````*6P$`-@```"Q;`0`N````8UL!`#``
M``"26P$`)0```,-;`0`<````Z5L!`#$````&7`$`!P```#A<`0`'````0%P!
M``0```!(7`$`#0```$U<`0`+````6UP!``X```!G7`$`"P```'9<`0`%````
M@EP!`!````"(7`$``@```)E<`0!9````G%P!``4```#V7`$`$@```/Q<`0`$
M````#UT!``<````470$`"````!Q=`0`%````)5T!``,````K70$`$````"]=
M`0`*````0%T!``P```!+70$`$P```%A=`0`-````;%T!``(```!Z70$`!P``
M`'U=`0`&````A5T!`!0```",70$`#````*%=`0`8````KET!``8```#'70$`
M$@```,Y=`0`,````X5T!``,```#N70$`*@```/)=`0`$````'5X!``8````B
M7@$`!P```"E>`0`?````,5X!`#4```!17@$`+@```(=>`0`O````MEX!`!<`
M``#F7@$`(````/Y>`0`;````'U\!`!@````[7P$`)````%1?`0`?````>5\!
M`!H```"97P$`(````+1?`0`:````U5\!`#(```#P7P$`&@```"-@`0`O````
M/F`!`"L```!N8`$`'P```)I@`0`C````NF`!`!\```#>8`$`&@```/Y@`0`E
M````&6$!`"8````_80$`)0```&9A`0`D````C&$!`!@```"Q80$`'0```,IA
M`0`D````Z&$!`!@````-8@$`(@```"9B`0`5````26(!`"4```!?8@$`/```
M`(5B`0`?````PF(!`",```#B8@$`'P````9C`0`@````)F,!`!H```!'8P$`
M&````&)C`0`F````>V,!`!X```"B8P$`*0```,%C`0`>````ZV,!``D````*
M9`$`#````!1D`0`7````(60!`"\````Y9`$`)````&ED`0`'````CF0!``\`
M``"69`$`%````*9D`0`.````NV0!``T```#*9`$`)````-AD`0`%````_60!
M``<````#90$`(@````ME`0`E````+F4!`!,```!490$`&@```&AE`0`=````
M@V4!`!H```"A90$`!P```+QE`0#'````Q&4!``L```",9@$`&0```)AF`0`5
M````LF8!``P```#(9@$`!@```-5F`0`)````W&8!``L```#F9@$`#0```/)F
M`0`=`````&<!`!<````>9P$`!@```#9G`0`S````/6<!`!,```!Q9P$`$P``
M`(5G`0`'````F6<!``8```"A9P$`#P```*AG`0`'````N&<!`#(```#`9P$`
M(0```/-G`0`3````%6@!``P````I:`$`$0```#9H`0`R````2&@!`!````![
M:`$`"````(QH`0`=````E6@!``D```"S:`$`"@```+UH`0`%````R&@!`!0`
M``#.:`$`"@```.-H`0`=````[F@!``@````,:0$`'P```!5I`0`(````-6D!
M`!H````^:0$`)P```%EI`0`&````@6D!`!4```"(:0$`!P```)YI`0`(````
MIFD!``D```"O:0$`/P```+EI`0`2````^6D!``<````,:@$`#P```!1J`0`.
M````)&H!`!`````S:@$`"0```$1J`0`)````3FH!``@```!8:@$`$P```&%J
M`0`)````=6H!``<```!_:@$`#````(=J`0`9````E&H!``H```"N:@$`&P``
M`+EJ`0`7````U6H!`!0```#M:@$`"@````)K`0`,````#6L!`!<````::P$`
M!````#)K`0`J````-VL!`!$```!B:P$`!P```'1K`0`)````?&L!``(```"&
M:P$`$````(EK`0`8````FFL!``L```"S:P$``P```+]K`0`(````PVL!``L`
M``#,:P$`!@```-AK`0`'````WVL!``T```#G:P$`"P```/5K`0`4`````6P!
M`!4````6;`$`#@```"QL`0`O````.VP!`"````!K;`$`'````(QL`0`,````
MJ6P!`#$```"V;`$`!0```.AL`0`2````[FP!`#\````!;0$`$@```$%M`0`*
M````5&T!``8```!?;0$`!````&9M`0`$````:VT!``H```!P;0$`$P```'MM
M`0`%````CVT!``8```"5;0$`!@```)QM`0`)````HVT!``0```"M;0$`#```
M`+)M`0`)````OVT!``P```#);0$`"@```-9M`0`0````X6T!`!,```#R;0$`
M$P````9N`0`@````&FX!``4````[;@$`&````$%N`0`9````6FX!`!\```!T
M;@$`'0```)1N`0`1````LFX!``(```#$;@$`!````,=N`0`*````S&X!``8`
M``#7;@$`!0```-YN`0`#````Y&X!``P```#H;@$`)0```/5N`0!%````&V\!
M`!H```!A;P$`-0```'QO`0`H````LF\!`%,```#;;P$`,````"]P`0`O````
M8'`!`!D```"0<`$`<@```*IP`0`@````'7$!`#4````^<0$`(0```'1Q`0!%
M````EG$!`#````#<<0$`)@````UR`0`>````-'(!`"@```!3<@$`*0```'QR
M`0`I````IG(!`"8```#0<@$`)0```/=R`0`H````'7,!`"@```!&<P$`(@``
M`&]S`0`K````DG,!`"X```"^<P$`,````.US`0`2````'G0!`!,````Q=`$`
M$````$5T`0!Y````5G0!``D```#0=`$`<@```-IT`0!S````374!`'P```#!
M=0$`*P```#YV`0!4````:G8!`!<```"_=@$`*P```-=V`0`6`````W<!``\`
M```:=P$`90```"IW`0`?````D'<!`$````"P=P$`'P```/%W`0`<````$7@!
M`%$````N>`$`%````(!X`0`*````E7@!``4```"@>`$`!@```*9X`0`(````
MK7@!``4```"V>`$`$@```+QX`0`0````SW@!`!,```#@>`$`'0```/1X`0`/
M````$GD!``H````B>0$`!````"UY`0`/````,GD!``<```!">0$`!````$IY
M`0`)````3WD!``<```!9>0$`"P```&%Y`0`'````;7D!``4```!U>0$`%```
M`'MY`0`.````D'D!``<```"?>0$`"````*=Y`0`/````L'D!``@```#`>0$`
M#````,EY`0`/````UGD!`!8```#F>0$`!P```/UY`0`&````!7H!`!0````,
M>@$`!@```"%Z`0`,````*'H!`!4````U>@$`"````$MZ`0`$````5'H!``H`
M``!9>@$`"P```&1Z`0`,````<'H!``P```!]>@$`!````(IZ`0`&````CWH!
M``<```"6>@$`!````)YZ`0`'````HWH!`!D```"K>@$`!P```,5Z`0`"````
MS7H!``(```#0>@$`"0```--Z`0`&````W7H!``8```#D>@$`)P```.MZ`0`"
M````$WL!``0````6>P$`"P```!M[`0`)````)WL!``\````Q>P$`$P```$%[
M`0`'````57L!``<```!=>P$`!@```&5[`0`&````;'L!`!````!S>P$`$@``
M`(1[`0`"````EWL!``8```":>P$`"0```*%[`0`S````JWL!`!@```#?>P$`
M(@```/A[`0`'````&WP!``<````C?`$`!P```"M\`0`+````,WP!``4````_
M?`$``@```$5\`0`+````2'P!`%H!``!4?`$`<P```*]]`0"X````(WX!`$(`
M``#<?@$`P````!]_`0"0````X'\!`$8```!Q@`$`-P```+B``0`S````\(`!
M`#8````D@0$`+P```%N!`0`N````BX$!`&@```"Z@0$`90```"."`0!G````
MB8(!`&4```#Q@@$`9P```%>#`0!O````OX,!`#\````OA`$`9````&^$`0!#
M````U(0!`"\````8A0$`30```$B%`0!$````EH4!`$H```#;A0$`,P```":&
M`0`X````6H8!`&X```"3A@$`+@````*'`0`M````,8<!`(@```!?AP$`8@``
M`.B'`0`/`0``2X@!`$X```!;B0$`-````*J)`0"+````WXD!`%````!KB@$`
M$````+R*`0`5````S8H!`!0```#CB@$`!P```/B*`0`)`````(L!``@````*
MBP$`!0```!.+`0`>````&8L!`"X````XBP$`+````&>+`0`I````E(L!`"X`
M``"^BP$`)P```.V+`0`8````%8P!`"8````NC`$`)````%6,`0`F````>HP!
M``H```"AC`$`$0```*R,`0`K````OHP!`!,```#JC`$`$````/Z,`0`0````
M#XT!`!0````@C0$`!0```#6-`0`H````.XT!``T```!DC0$`#0```'*-`0`3
M````@(T!``X```"4C0$`#0```*.-`0`+````L8T!`"$```"]C0$`&P```-^-
M`0`0````^XT!``H````,C@$`%@```!>.`0`_````+HX!``T```!NC@$`#P``
M`'R.`0`0````C(X!``L```"=C@$`#0```*F.`0`&````MXX!``T```"^C@$`
M$P```,R.`0`5````X(X!``T```#VC@$`&P````2/`0`;````((\!`!,````\
MCP$`"````%"/`0`)````68\!`%@```!CCP$`+0```+R/`0`T````ZH\!`!4`
M```?D`$`/0```#60`0!.````<Y`!`&H```#"D`$`:0```"V1`0!P````EY$!
M`&\````(D@$`0@```'B2`0`/````NY(!`!(```#+D@$`#@```-Z2`0`3````
M[9(!``\````!DP$`!0```!&3`0`&````%Y,!`!,````>DP$`"0```#*3`0`=
M````/),!``\```!:DP$`$0```&J3`0`A````?),!`",```">DP$`%@```,*3
M`0`0````V9,!``T```#JDP$`$@```/B3`0`)````"Y0!`!4````5E`$`&0``
M`"N4`0`1````190!`!4```!7E`$`&````&V4`0`?````AI0!`"0```"FE`$`
M&@```,N4`0`0````YI0!`!<```#WE`$`$@````^5`0`N````(I4!``L```!1
ME0$`&````%V5`0`<````=I4!`!0```"3E0$`60```*B5`0`J`````I8!`"H`
M```ME@$`*@```%B6`0`(````@Y8!``D```",E@$`%@```):6`0`(````K98!
M`"0```"VE@$`)P```-N6`0`W`````Y<!``T````[EP$`"````$F7`0`1````
M4I<!``L```!DEP$`!P```'"7`0`'````>)<!``<```"`EP$`!P```(B7`0`,
M````D)<!``0```"=EP$`(@```**7`0`/````Q9<!`!,```#5EP$`%P```.F7
M`0`<`````9@!`#`````>F`$`"0```$^8`0`)````69@!`!@```!CF`$`'@``
M`'R8`0`C````FY@!`!$```"_F`$`%````-&8`0`2````YI@!``\```#YF`$`
M(P````F9`0`=````+9D!``<```!+F0$`!@```%.9`0`'````6ID!`!H```!B
MF0$`"````'V9`0`*````AID!`!$```"1F0$`"0```*.9`0`1````K9D!`!H`
M``"_F0$`!P```-J9`0`2````XID!``4```#UF0$`%@```/N9`0`>````$IH!
M``\````QF@$`%@```$&:`0`M````6)H!`#\```"&F@$`.P```,::`0`)````
M`IL!``<````,FP$`$P```!2;`0`$````*)L!``4````MFP$`"0```#.;`0`0
M````/9L!``H```!.FP$`%````%F;`0`\````;IL!`!4```"KFP$`+0```,&;
M`0`R````[YL!`#$````BG`$`,````%2<`0`)````A9P!``8```"/G`$`"0``
M`):<`0`'````H)P!`#L```"HG`$`.P```.2<`0`Z````()T!`%\```!;G0$`
M.0```+N=`0`Y````]9T!`#D````OG@$`2P```&F>`0`M````M9X!`#````#C
MG@$`.0```!2?`0`_````3I\!`!4```".GP$`&0```*2?`0`R````OI\!`"8`
M``#QGP$`%````!B@`0`3````+:`!``H```!!H`$`$````$R@`0`,````7:`!
M``L```!JH`$`!0```':@`0`,````?*`!`!X```")H`$`(P```*B@`0`&````
MS*`!``4```#3H`$`%0```-F@`0`+````[Z`!``@```#[H`$`"@````2A`0`/
M````#Z$!``X````?H0$`#````"ZA`0`'````.Z$!``8```!#H0$`&P```$JA
M`0`%````9J$!``<```!LH0$`!0```'2A`0`7````>J$!``L```"2H0$`,@``
M`)ZA`0`7````T:$!``T```#IH0$`!P```/>A`0`'````_Z$!``H````'H@$`
M!0```!*B`0`3````&*(!``8````LH@$`$@```#.B`0`%````1J(!``@```!,
MH@$`!````%6B`0`+````6J(!``8```!FH@$`)0```&VB`0`1````DZ(!`"L`
M``"EH@$`'@```-&B`0`(````\*(!``X```#YH@$`#0````BC`0`'````%J,!
M`!0````>HP$``P```#.C`0`#````-Z,!`!H````[HP$``P```%:C`0`@````
M6J,!`!````![HP$`*P```(RC`0`*````N*,!``4```##HP$`"````,FC`0`(
M````TJ,!`%X```#;HP$`*````#JD`0`&````8Z0!``@```!JI`$`'P```'.D
M`0`D````DZ0!`"\```"XI`$`,@```.BD`0`F````&Z4!`"8```!"I0$`70``
M`&FE`0`^````QZ4!`!<````&I@$`!P```!ZF`0`2````)J8!``P````YI@$`
M$````$:F`0`8````5Z8!`!<```!PI@$`&````(BF`0`8````H:8!``D```"Z
MI@$`%0```,2F`0`'````VJ8!`!D```#BI@$`&P```/RF`0`9````&*<!`!,`
M```RIP$`&````$:G`0`2````7Z<!``<```!RIP$`6P```'JG`0`)````UJ<!
M`!4```#@IP$`$0```/:G`0`V````"*@!`!(````_J`$`&@```%*H`0`=````
M;:@!`!D```"+J`$`=@```*6H`0`7````'*D!`!T````TJ0$`'````%*I`0`>
M````;ZD!`#(```".J0$`/````,&I`0`-````_JD!`"P````,J@$`)P```#FJ
M`0`=````8:H!``8```!_J@$`'````(:J`0`/````HZH!`!X```"SJ@$`&@``
M`-*J`0`:````[:H!``L````(JP$`%0```!2K`0`3````*JL!``T````^JP$`
M!@```$RK`0`/````4ZL!``@```!CJP$`%0```&RK`0`6````@JL!`!$```"9
MJP$`%0```*NK`0`%````P:L!``8```#'JP$`$0```,ZK`0`(````X*L!`!``
M``#IJP$`$P```/JK`0`"````#JP!`!X````1K`$`,@```#"L`0`'````8ZP!
M`!,```!KK`$`$@```'^L`0`)````DJP!``H```"<K`$`"0```*>L`0`*````
ML:P!``<```"\K`$`!P```,2L`0`1````S*P!``T```#>K`$`#````.RL`0`(
M````^:P!``D````"K0$`&@````RM`0`B````)ZT!``T```!*K0$`&````%BM
M`0`>````<:T!`!X```"0K0$`#P```*^M`0`0````OZT!`!(```#0K0$`$```
M`..M`0`P````]*T!`#\````EK@$`(0```&6N`0`;````AZX!`!8```"CK@$`
M/````+JN`0`H````]ZX!``X````@KP$`#@```"^O`0`)````/J\!``H```!(
MKP$`#@```%.O`0`&````8J\!``\```!IKP$`%@```'FO`0`7````D*\!`!P`
M``"HKP$`+@```,6O`0`L````]*\!`#`````AL`$`+P```%*P`0`I````@K`!
M`"D```"LL`$`)@```-:P`0`Y````_;`!`"(````WL0$`,````%JQ`0!"````
MB[$!`#$```#.L0$`,@````"R`0`E````,[(!`#(```!9L@$`.0```(RR`0!.
M````QK(!`#4````5LP$`.````$NS`0!#````A+,!`"0```#(LP$`%@```.VS
M`0!/````!+0!`"D```!4M`$`&@```'ZT`0`[````F;0!`"(```#5M`$`&```
M`/BT`0#5````$;4!`!H```#GM0$`+0````*V`0`P````,+8!`#$```!AM@$`
M,@```).V`0`I````QK8!`!8```#PM@$`+@````>W`0`W````-K<!`#H```!N
MMP$`/0```*FW`0`Z````Y[<!`)H````BN`$`*P```+VX`0`?````Z;@!`"@`
M```)N0$`-P```#*Y`0`V````:KD!`%8```"AN0$`60```/BY`0`-````4KH!
M``0```!@N@$`!@```&6Z`0`%````;+H!`!$```!RN@$`#@```(2Z`0`0````
MD[H!``8```"DN@$`%0```*NZ`0`;````P;H!`!0```#=N@$`$0```/*Z`0`6
M````!+L!``D````;NP$`#@```"6[`0`/````-+L!`!$```!$NP$`#0```%:[
M`0!#````9+L!``8```"HNP$`$0```*^[`0`3````P;L!`!$```#5NP$`%P``
M`.>[`0`;````_[L!``\````;O`$``@```"N\`0`+````+KP!`!P````ZO`$`
M!````%>\`0`0````7+P!`!````!MO`$``P```'Z\`0`/````@KP!``@```"2
MO`$`$````)N\`0`2````K+P!``L```"_O`$`#P```,N\`0`8````V[P!`!$`
M``#TO`$`%@````:]`0!H````';T!`!8```"&O0$`(@```)V]`0`*````P+T!
M``<```#+O0$`%@```-.]`0`-````ZKT!`!$```#XO0$`&@````J^`0`?````
M);X!``X```!%O@$`#@```%2^`0`D````8[X!`!<```"(O@$`&@```*"^`0`X
M````N[X!``T```#TO@$`'P````*_`0`9````(K\!`!@````\OP$`-@```%6_
M`0`G````C+\!``X```"TOP$`$@```,._`0`)````UK\!``P```#@OP$`"P``
M`.V_`0`3````^;\!``D````-P`$`,````!?``0`[````2,`!``\```"$P`$`
M$````)3``0`A````I<`!`!(```#'P`$`(P```-K``0`C````_L`!``H````B
MP0$`'````"W!`0`6````2L$!`!X```!AP0$`%@```(#!`0`7````E\$!`!D`
M``"OP0$`!P```,G!`0`+````T<$!`"H```#=P0$`)P````C"`0!*````,,(!
M``@```![P@$`%````(3"`0`'````F<(!``H```"AP@$`-P```*S"`0`1````
MY,(!`!,```#VP@$`!@````K#`0`3````$<,!``,````EPP$`%````"G#`0`&
M````/L,!``L```!%PP$`#````%'#`0`,````7L,!`!$```!KPP$`$0```'W#
M`0`7````C\,!`!0```"GPP$`$0```+S#`0`9````SL,!`!<```#HPP$`"```
M``#$`0`&````"<0!`!@````0Q`$`"P```"G$`0`"````-<0!`!,````XQ`$`
M'P```$S$`0`?````;,0!`!@```",Q`$`$@```*7$`0`/````N,0!``\```#(
MQ`$`%0```-C$`0`^````[L0!`#(````MQ0$`"@```&#%`0`/````:\4!`*(`
M``![Q0$`'@```![&`0!-````/<8!`!H```"+Q@$`$````*;&`0`2````M\8!
M``0```#*Q@$`*````,_&`0`6````^,8!``8````/QP$`%````!;'`0`H````
M*\<!``4```!4QP$`!@```%K'`0`/````8<<!``X```!QQP$`$````(#'`0`.
M````D<<!``P```"@QP$`#@```*W'`0`+````O,<!`!````#(QP$`"````-G'
M`0`+````XL<!``@```#NQP$`%0```/?'`0`,````#<@!`#\````:R`$`$0``
M`%K(`0`(````;,@!``@```!UR`$`&P```'[(`0`J````FL@!`#<```#%R`$`
M$P```/W(`0`5````$<D!`"L````GR0$`)P```%/)`0`G````>\D!`!P```"C
MR0$`&0```,#)`0`>````VLD!`$8```#YR0$`(@```$#*`0`A````8\H!`!@`
M``"%R@$`&@```)[*`0`E````N<H!`"D```#?R@$`&0````G+`0`A````(\L!
M``,```!%RP$`&0```$G+`0`+````8\L!``L```!ORP$``P```'O+`0`)````
M?\L!``@```")RP$`"@```)++`0`1````G<L!``T```"ORP$`$````+W+`0`$
M````SLL!`"````#3RP$`(0```/3+`0`3````%LP!``\````JS`$`$P```#K,
M`0`7````3LP!`"X```!FS`$`!P```)7,`0`(````G<P!``D```"FS`$`$```
M`+#,`0`,````P<P!`!````#.S`$`"P```-_,`0`(````Z\P!``D```#TS`$`
M"````/[,`0`6````!\T!``P````>S0$`!@```"O-`0`I````,LT!``X```!<
MS0$`B0```&O-`0`=````]<T!``<````3S@$`!0```!O.`0`-````(<X!``4`
M```OS@$`!P```#7.`0`&````/<X!``@```!$S@$`)````$W.`0`3````<LX!
M``(```"&S@$`"````(G.`0`2````DLX!`!4```"ES@$`%````+O.`0`/````
MT,X!`!(```#@S@$`)P```//.`0`"````&\\!``,````>SP$`$@```"+/`0`)
M````-<\!``T````_SP$`!P```$W/`0`2````5<\!`"````!HSP$`"````(G/
M`0`3````DL\!`!4```"FSP$`#0```+S/`0`@````RL\!``<```#KSP$`'0``
M`///`0`/````$=`!`!$````AT`$`"0```#/0`0`,````/=`!`!D```!*T`$`
M`@```&30`0`%````9]`!``\```!MT`$`$@```'W0`0`&````D-`!`!(```"7
MT`$`"P```*K0`0`'````MM`!``4```"^T`$`%P```,30`0`F````W-`!`!,`
M```#T0$`!@```!?1`0`)````'M$!``0````HT0$`%@```"W1`0`(````1-$!
M`!8```!-T0$`%@```&31`0`0````>]$!``4```",T0$`#````)+1`0`@````
MG]$!``0```#`T0$`10```,71`0!&````"](!`$4```!2T@$`)0```)C2`0`2
M````OM(!`!,```#1T@$`!P```.72`0`)````[=(!`!8```#WT@$`$`````[3
M`0`5````'],!``8````UTP$`!0```#S3`0`4````0M,!``4```!7TP$`G```
M`%W3`0`*````^M,!`!X````%U`$`!````"34`0`S````*=0!``4```!=U`$`
M'````&/4`0`$````@-0!``X```"%U`$`#@```)34`0`,````H]0!`!$```"P
MU`$`%0```,+4`0`8````V-0!``L```#QU`$`%@```/W4`0`,````%-4!``4`
M```AU0$`&@```"?5`0`R````0M4!`#<```!UU0$`0````*W5`0`L````[M4!
M`#(````;U@$`00```$[6`0!*````D-8!`#$```#;U@$`10````W7`0`U````
M4]<!`#<```")UP$`)P```,'7`0`0````Z=<!`!4```#ZUP$`"P```!#8`0`H
M````'-@!`"````!%V`$`(0```&;8`0`?````B-@!``@```"HV`$`"@```+'8
M`0`*````O-@!`!0```#'V`$`*0```-S8`0`G````!MD!`#`````NV0$`!```
M`%_9`0`+````9-D!`!D```!PV0$`*0```(K9`0`:````M-D!`!0```#/V0$`
M%````.39`0`-````^=D!`!`````'V@$`$P```!C:`0!$````+-H!`'T```!Q
MV@$`@@```._:`0`3````<ML!``T```"&VP$`#@```)3;`0`1````H]L!`!(`
M``"UVP$`%@```,C;`0`'````W]L!`"4```#GVP$`$@````W<`0`E````(-P!
M`!,```!&W`$`$@```%K<`0`5````;=P!`"P```"#W`$`+````+#<`0!M````
MW=P!`!4```!+W0$`$@```&'=`0`8````=-T!`!8```"-W0$`"@```*3=`0`*
M````K]T!`"$```"ZW0$`'0```-S=`0`6````^MT!``X````1W@$`#@```"#>
M`0`5````+]X!`!4```!%W@$`*@```%O>`0`I````AMX!`"D```"PW@$`*```
M`-K>`0`G`````]\!`"D````KWP$`&@```%7?`0!5````<-\!`!,```#&WP$`
M%0```-K?`0`5````\-\!`!0````&X`$`$0```!O@`0`7````+>`!`!<```!%
MX`$`%````%W@`0`3````<N`!`#H```"&X`$`&````,'@`0`9````VN`!`#X`
M``#TX`$`%0```#/A`0`'````2>$!`!$```!1X0$`&````&/A`0`,````?.$!
M`"````")X0$`$P```*KA`0`<````ON$!`!,```#;X0$`'@```._A`0`B````
M#N(!`!T````QX@$`*0```$_B`0`1````>>(!`!L```"+X@$`'````*?B`0`:
M````Q.(!`"(```#?X@$`$@````+C`0`.````%>,!`!(````DXP$`'````#?C
M`0`A````5.,!`!P```!VXP$`&````)/C`0`;````K.,!`!,```#(XP$`&P``
M`-SC`0`<````^.,!`!P````5Y`$`&````#+D`0`*````2^0!`!H```!6Y`$`
M$P```''D`0`4````A>0!``L```":Y`$`%````*;D`0`0````N^0!``<```#,
MY`$`!P```-3D`0`2````W.0!``<```#OY`$`!P```/?D`0`%````_^0!`!4`
M```%Y0$`!@```!OE`0`;````(N4!``4````^Y0$`!0```$3E`0`*````2N4!
M``<```!5Y0$`"@```%WE`0`5````:.4!`!0```!^Y0$`&````)/E`0`5````
MK.4!`!,```#"Y0$`+````-;E`0`3`````^8!`!`````7Y@$`&@```"CF`0`4
M````0^8!``T```!8Y@$`$P```&;F`0`Q````>N8!``8```"LY@$`"0```+/F
M`0`G````O>8!`!,```#EY@$`$````/GF`0`&````"N<!`!,````1YP$`5@``
M`"7G`0`+````?.<!``8```"(YP$`(0```(_G`0`2````L><!``H```#$YP$`
M"P```,_G`0`2````V^<!`!0```#NYP$`$@````/H`0`8````%N@!`!4````O
MZ`$`%````$7H`0`#````6N@!``H```!>Z`$`(0```&GH`0`&````B^@!``@`
M``"2Z`$`%0```)OH`0`2````L>@!``8```#$Z`$`!P```,OH`0`S````T^@!
M``P````'Z0$`$P```!3I`0`)````*.D!`!(````RZ0$`%0```$7I`0`1````
M6^D!`!4```!MZ0$`#0```(/I`0`$````D>D!``H```"6Z0$`!P```*'I`0`4
M````J>D!`$D```"^Z0$`"`````CJ`0`/````$>H!``4````AZ@$`)0```"?J
M`0`5````3>H!`!@```!CZ@$`#@```'SJ`0`0````B^H!``X```"<Z@$`"P``
M`*OJ`0`-````M^H!`!,```#%Z@$`$P```-GJ`0`7````[>H!`"P````%ZP$`
M"P```#+K`0`5````/NL!`!D```!4ZP$`#0```&[K`0`,````?.L!`!H```")
MZP$`"P```*3K`0`&````L.L!``0```"WZP$`$@```+SK`0!6````S^L!`!8`
M```F[`$`"P```#WL`0`$````2>P!``4```!.[`$`&````%3L`0`9````;>P!
M`!H```"'[`$`"@```*+L`0`"````K>P!``0```"P[`$`(P```+7L`0`#````
MV>P!``4```#=[`$`*````./L`0`*````#.T!``4````7[0$`!P```!WM`0`8
M````)>T!`!$````^[0$`40```%#M`0`2````HNT!``8```"U[0$`!P```+SM
M`0`(````Q.T!``0```#-[0$`!0```-+M`0!D````V.T!``H````][@$`#0``
M`$CN`0`%````5NX!``8```!<[@$`&0```&/N`0`X````?>X!``X```"V[@$`
M"0```,7N`0`.````S^X!`!<```#>[@$`"@```/;N`0`(`````>\!`!D````*
M[P$`+P```"3O`0`I````5.\!`"@```!^[P$`$@```*?O`0`8````NN\!``0`
M``#3[P$`!P```-CO`0`(````X.\!``<```#I[P$`#0```/'O`0`,````_^\!
M`#8````,\`$`'P```$/P`0`Q````8_`!`"4```"5\`$`"````+OP`0!9````
MQ/`!`!$````>\0$`$````##Q`0`2````0?$!`!D```!4\0$`3@```&[Q`0`=
M````O?$!``8```#;\0$`'P```.+Q`0`'`````O(!``8````*\@$`(````!'R
M`0`&````,O(!``D````Y\@$`)P```$/R`0`F````:_(!``P```"2\@$`!P``
M`)_R`0`*````I_(!`"8```"R\@$`)0```-GR`0!+````__(!`!@```!+\P$`
M'0```&3S`0`6````@O,!``(```"9\P$`#0```)SS`0`)````JO,!``@```"T
M\P$`$P```+WS`0`-````T?,!`!L```#?\P$`!@```/OS`0`&`````O0!`!0`
M```)]`$`%````![T`0`(````,_0!``D````\]`$`"P```$;T`0`*````4O0!
M``L```!=]`$`(````&GT`0`1````BO0!``\```"<]`$`$@```*ST`0`3````
MO_0!``4```#3]`$`!@```-GT`0`5````X/0!`!0```#V]`$`!0````OU`0`&
M````$?4!`!`````8]0$`#P```"GU`0`%````.?4!`!<````_]0$`&P```%?U
M`0`@````<_4!`$(```"4]0$`$0```-?U`0`-````Z?4!`!@```#W]0$`#```
M`!#V`0`4````'?8!`!`````R]@$`$0```$/V`0`$````5?8!``\```!:]@$`
M%````&KV`0`%````?_8!``4```"%]@$`(@```(OV`0`7````KO8!`!,```#&
M]@$`%````-KV`0`<````[_8!`"$````,]P$`&0```"[W`0`9````2/<!`!T`
M``!B]P$`(@```(#W`0`<````H_<!``0```#`]P$`!0```,7W`0`.````R_<!
M``X```#:]P$`#0```.GW`0`*````]_<!``@````"^`$`(@````OX`0`-````
M+O@!`!0````\^`$`"````%'X`0`2````6O@!``<```!M^`$`$````'7X`0`/
M````AO@!``@```"6^`$`%@```)_X`0`'````MO@!`!(```"^^`$`'````-'X
M`0`%````[O@!``0```#T^`$``P```/GX`0`C````_?@!`"4````A^0$`40``
M`$?Y`0`_````F?D!`!X```#9^0$`)````/CY`0!!````'?H!`!$```!?^@$`
M/@```''Z`0`N````L/H!`!P```#?^@$`.@```/SZ`0!*````-_L!`%<```""
M^P$`7````-K[`0`:````-_P!`!````!2_`$`(@```&/\`0!'````AOP!`!4`
M``#._`$`(0```.3\`0`>````!OT!`",````E_0$`'P```$G]`0`9````:?T!
M`!L```"#_0$`$P```)_]`0`Y````L_T!`#D```#M_0$`/0```"?^`0`Y````
M9?X!`#H```"?_@$`.P```-K^`0`X````%O\!`'$```!/_P$`'0```,'_`0`*
M````W_\!``D```#J_P$`,````/3_`0`[````)0`"`!T```!A``(`*0```'\`
M`@`+````J0`"`$L```"U``(`1@````$!`@`'````2`$"`!<```!0`0(`%0``
M`&@!`@`/````?@$"`!````".`0(`%P```)\!`@`0````MP$"``\```#(`0(`
M#@```-@!`@`3````YP$"`!$```#[`0(`#`````T"`@`.````&@("``4````I
M`@(`(P```"\"`@`$````4P("``@```!8`@(`!@```&$"`@`4````:`("`!$`
M``!]`@(`&@```(\"`@`0````J@("`%(```"[`@(``@````X#`@`'````$0,"
M`!(````9`P(`(````"P#`@`7````30,"``4```!E`P(`!P```&L#`@`;````
M<P,"``H```"/`P(`$````)H#`@`R````JP,"`!8```#>`P(`,@```/4#`@!V
M````*`0"`!4```"?!`(`3@```+4$`@`B````!`4"`!$````G!0(`!@```#D%
M`@`,````0`4"``<```!-!0(`#@```%4%`@`+````9`4"`!8```!P!0(`"P``
M`(<%`@`<````DP4"`!@```"P!0(`!0```,D%`@`2````SP4"``T```#B!0(`
M$@```/`%`@`E`````P8"`!8````I!@(`%0```$`&`@`1````5@8"`",```!H
M!@(`"@```(P&`@`,````EP8"`!0```"D!@(`$P```+D&`@`,````S08"``X`
M``#:!@(`"P```.D&`@`3````]08"``T````)!P(`"@```!<'`@`?````(@<"
M`!(```!"!P(`%P```%4'`@`&````;0<"`!````!T!P(`%0```(4'`@`6````
MFP<"``T```"R!P(`&````,`'`@`Q````V0<"`!T````+"`(`#@```"D(`@`/
M````.`@"`"0```!("`(`!0```&T(`@`1````<P@"``<```"%"`(`%@```(T(
M`@`'````I`@"``L```"L"`(`(````+@(`@`T````V0@"``D````."0(`(@``
M`!@)`@`0````.PD"`!````!,"0(`&P```%T)`@`-````>0D"`!0```"'"0(`
M!````)P)`@`4````H0D"``D```"V"0(`"````,`)`@`+````R0D"`!<```#5
M"0(`#@```.T)`@`&````_`D"``H````#"@(`(0````X*`@`_````,`H"`$``
M``!P"@(`)````+$*`@`M````U@H"`"H````$"P(`1P```"\+`@`D````=PL"
M`"D```"<"P(`,P```,8+`@!#````^@L"`&$````^#`(`-````*`,`@`@````
MU0P"`"T```#V#`(`!P```"0-`@`(````+`T"``D````U#0(`%````#\-`@`;
M````5`T"`!L```!P#0(`,````(P-`@`E````O0T"`"(```#C#0(`.@````8.
M`@!"````00X"``<```"$#@(`&0```(P.`@`)````I@X"``@```"P#@(`(```
M`+D.`@`1````V@X"`!0```#L#@(`&@````$/`@`-````'`\"``@````J#P(`
M%0```#,/`@`)````20\"``\```!3#P(`#0```&,/`@`:````<0\"`!@```",
M#P(`.P```*4/`@`*````X0\"``\```#L#P(`!@```/P/`@`>`````Q`"``X`
M```B$`(`&@```#$0`@`0````3!`"``4```!=$`(`#0```&,0`@`0````<1`"
M``D```""$`(`#````(P0`@`,````F1`"``X```"F$`(`!P```+40`@`#````
MO1`"`!D```#!$`(`#0```-L0`@`V````Z1`"`$@````@$0(`$P```&D1`@`8
M````?1$"`"4```"6$0(`(0```+P1`@`1````WA$"`!4```#P$0(`"P````82
M`@`2````$A("`"D````E$@(`!P```$\2`@`-````5Q("``X```!E$@(`$@``
M`'02`@`3````AQ("``L```";$@(`/````*<2`@`)````Y!("`!P```#N$@(`
M$@````L3`@`6````'A,"`(D````U$P(`0````+\3`@`>`````!0"`"0````?
M%`(`/````$04`@`Z````@10"`#8```"\%`(`$0```/,4`@`&````!14"`!<`
M```,%0(`'````"05`@`<````014"``H```!>%0(`'0```&D5`@`+````AQ4"
M`!````"3%0(`!P```*05`@`5````K!4"`!4```#"%0(`"0```-@5`@`'````
MXA4"`!0```#J%0(`$0```/\5`@`9````$18"``4````K%@(`!P```#$6`@`)
M````.18"`!````!#%@(`#P```%06`@`5````9!8"`!4```!Z%@(`!P```)`6
M`@`&````F!8"`#$```"?%@(`*0```-$6`@`E````^Q8"``@````A%P(`#P``
M`"H7`@`3````.A<"`!\```!.%P(`'@```&X7`@`:````C1<"`!\```"H%P(`
M#0```,@7`@`,````UA<"``,```#C%P(`%P```.<7`@`'````_Q<"``T````'
M&`(``@```!48`@`,````&!@"`!$````E&`(`"P```#<8`@`4````0Q@"`!@`
M``!8&`(`%0```'$8`@`<````AQ@"`",```"D&`(`$P```,@8`@`6````W!@"
M``X```#S&`(`!P````(9`@`*````"AD"``P````5&0(`#@```"(9`@!:````
M,1D"`!@```",&0(`+````*49`@`5````TAD"``<```#H&0(`"````/`9`@`2
M````^1D"`!4````,&@(`#@```"(:`@`2````,1H"`"L```!$&@(`$0```'`:
M`@`D````@AH"``T```"G&@(`'@```+4:`@`4````U!H"`!$```#I&@(`$P``
M`/L:`@`A````#QL"`!@````Q&P(`%@```$H;`@`D````81L"`"@```"&&P(`
M%0```*\;`@`Q````Q1L"`#4```#W&P(`7P```"T<`@`A````C1P"`!T```"O
M'`(`(P```,T<`@`A````\1P"`"<````3'0(`+@```#L=`@`M````:AT"`",`
M``"8'0(`'0```+P=`@`D````VAT"`"X```#_'0(`-````"X>`@`J````8QX"
M`"````".'@(`(@```*\>`@`6````TAX"`"<```#I'@(`'0```!$?`@`*````
M+Q\"`!0````Z'P(`"0```$\?`@`(````61\"`!,```!B'P(`#P```'8?`@`K
M````AA\"`!4```"R'P(`"````,@?`@!@````T1\"`#\````R(`(`4````'(@
M`@!P````PR`"``H````T(0(`)0```#\A`@`O````92$"``D```"5(0(`%0``
M`)\A`@`-````M2$"``<```##(0(`#0```,LA`@`^````V2$"``<````8(@(`
M#````"`B`@`1````+2("``X````_(@(`$@```$XB`@`/````82("`$D```!Q
M(@(`+0```+LB`@`G````Z2("``X````1(P(`-P```"`C`@`=````6","`$$`
M``!V(P(`-@```+@C`@`_````[R,"`#4````O)`(`%````&4D`@`*````>B0"
M`!,```"%)`(`%@```)DD`@`8````L"0"``@```#))`(`,0```-(D`@`*````
M!"4"``H````/)0(`)@```!HE`@`*````024"`!<```!,)0(`%@```&0E`@`'
M````>R4"`!$```"#)0(`$0```)4E`@`*````IR4"`!8```"R)0(`!````,DE
M`@`%````SB4"``8```#4)0(`#P```-LE`@`2````ZR4"`!````#^)0(`'0``
M``\F`@`-````+28"``<````[)@(`$````$,F`@`5````5"8"`"````!J)@(`
M$@```(LF`@`&````GB8"``T```"E)@(`&@```+,F`@`F````SB8"``X```#U
M)@(`'P````0G`@`O````)"<"``D```!4)P(`"P```%XG`@`8````:B<"`!``
M``"#)P(`%@```)0G`@`9````JR<"`$````#%)P(`#@````8H`@`0````%2@"
M``T````F*`(`"0```#0H`@`M````/B@"``8```!L*`(`"0```',H`@`-````
M?2@"`!,```"+*`(`!@```)\H`@`<````IB@"`!@```##*`(`#P```-PH`@`(
M````["@"`!X```#U*`(`&P```!0I`@`,````,"D"``(````]*0(`!P```$`I
M`@`(````2"D"`&X```!1*0(`$````,`I`@`'````T2D"`"<```#9*0(`(```
M``$J`@!&````(BH"`!P```!I*@(`)P```(8J`@!$````KBH"`#$```#S*@(`
M0````"4K`@`<````9BL"`!8```"#*P(`$@```)HK`@`&````K2L"``T```"T
M*P(`"@```,(K`@`)````S2L"``T```#7*P(`$0```.4K`@`/````]RL"``H`
M```'+`(`#````!(L`@`0````'RP"``<````P+`(`"````#@L`@`'````02P"
M`!0```!)+`(`%````%XL`@`/````<RP"``4```"#+`(`)0```(DL`@`5````
MKRP"``H```#%+`(`%````-`L`@`+````Y2P"`!0```#Q+`(``P````8M`@`+
M````"BT"`"`````6+0(`!@```#<M`@`6````/BT"`!8```!5+0(`!P```&PM
M`@`'````="T"`!D```!\+0(`"````)8M`@`%````GRT"``<```"E+0(`$@``
M`*TM`@`;````P"T"``L```#<+0(`#0```.@M`@`M````]BT"`"$````D+@(`
M&````$8N`@`%````7RX"``P```!E+@(`%````'(N`@`-````ARX"``(```"5
M+@(`$P```)@N`@`2````K"X"`!\```"_+@(`0````-\N`@`C````("\"`#0`
M``!$+P(`,0```'DO`@`T````JR\"`"(```#@+P(`+0````,P`@!B````,3`"
M`!8```"4,`(`;@```*LP`@`[````&C$"`!T```!6,0(`5@```'0Q`@!Q````
MRS$"`"T````],@(`/````&LR`@`K````J#("`#````#4,@(`,`````4S`@`<
M````-C,"`#H```!3,P(`OP$``(XS`@`K````3C4"`!\```!Z-0(`%@```)HU
M`@!6````L34"`(P````(-@(`,P```)4V`@!`````R38"`%H````*-P(`4```
M`&4W`@`B````MC<"`!4```#9-P(`'0```.\W`@`=````#3@"`"H````K.`(`
M'````%8X`@`E````<S@"`",```"9.`(`%@```+TX`@`W````U#@"`"H````,
M.0(`*````#<Y`@`F````8#D"`!H```"'.0(`,````*(Y`@#8````TSD"`&(`
M``"L.@(`+0````\[`@`T````/3L"`$4```!R.P(`,@```+@[`@`K````ZSL"
M`$<````7/`(`90```%\\`@!:````Q3P"`&4````@/0(`*````(8]`@`]````
MKST"`"P```#M/0(`)P```!H^`@`P````0CX"`#$```!S/@(`+@```*4^`@`J
M````U#X"`#$```#_/@(`60```#$_`@"5````BS\"`&P````A0`(`*0```(Y`
M`@!<````N$`"`%H````500(`+@```'!!`@`?````GT$"`#(```"_00(`)P``
M`/)!`@`E````&D("`"4```!`0@(`*P```&9"`@!N````DD("`&L````!0P(`
MP````&U#`@`9````+D0"`"<```!(1`(`/@```'!$`@`M````KT0"`%$```#=
M1`(`)P```"]%`@!<````5T4"`"D```"T10(`'@```-Y%`@`*````_44"`-X`
M```(1@(`.P```.=&`@`I````(T<"`#P```!-1P(`0@```(I'`@`]````S4<"
M`"4````+2`(`(````#%(`@`_````4D@"``@```"22`(`"````)M(`@`)````
MI$@"`!,```"N2`(`$````,)(`@`2````TT@"``L```#F2`(`!@```/)(`@`.
M````^4@"``0````(20(`7`````U)`@`$````:DD"`!$```!O20(`$@```(%)
M`@`(````E$D"``8```"=20(`#@```*1)`@`$````LTD"`!8```"X20(`"@``
M`,])`@`)````VDD"`!$```#D20(`$P```/9)`@`"````"DH"`!0````-2@(`
M%````")*`@`2````-TH"``X```!*2@(`%0```%E*`@`&````;TH"`!8```!V
M2@(`#0```(U*`@`#````FTH"`#0```"?2@(`!````-1*`@`3````V4H"``<`
M``#M2@(`)````/5*`@!0````&DL"`#D```!K2P(`.@```*5+`@`?````X$L"
M`"<`````3`(`(@```"A,`@`F````2TP"`"@```!R3`(`(P```)M,`@`E````
MOTP"`"P```#E3`(`)P```!)-`@`[````.DT"`"(```!V30(`.````)E-`@`T
M````TDT"`"4````'3@(`*0```"U.`@`L````5TX"`"<```"$3@(`+````*Q.
M`@`M````V4X"`#4````'3P(`(0```#U/`@`E````7T\"`"H```"%3P(`,@``
M`+!/`@`E````XT\"`"P````)4`(`&P```#90`@`E````4E`"`$(```!X4`(`
M)@```+M0`@`J````XE`"`"T````-40(`+@```#M1`@`F````:E$"`"0```"1
M40(`+@```+91`@`K````Y5$"`#@````14@(`'0```$I2`@`*````:%("`!L`
M``!S4@(`&0```(]2`@`L````J5("`",```#64@(`#0```/I2`@`/````"%,"
M`!8````84P(`"P```"]3`@`9````.U,"`"H```!54P(`"````(!3`@`,````
MB5,"`"$```"64P(`,@```+A3`@`8````ZU,"`"L````$5`(`*P```#!4`@`D
M````7%0"``@```"!5`(`Y@```(I4`@`1````<54"`#````"#50(`%@```+15
M`@`,````RU4"``D```#850(`#0```.)5`@`5````\%4"`!$````&5@(`*0``
M`!A6`@`B````0E8"``8```!E5@(`10```&Q6`@`<````LE8"`!T```#/5@(`
M'0```.U6`@`+````"U<"`!,````75P(`"0```"M7`@!2````-5<"`"H```"(
M5P(`'0```+-7`@`4````T5<"`!<```#F5P(`*````/Y7`@`8````)U@"`!(`
M``!`6`(`)````%-8`@`3````>%@"`!0```",6`(`#````*%8`@`8````KE@"
M`!@```#'6`(`%P```.!8`@`(````^%@"`"P````!60(`"0```"Y9`@`I````
M.%D"`"@```!B60(`!P```(M9`@`;````DUD"``<```"O60(`"````+=9`@`)
M````P%D"`#P```#*60(`$P````=:`@`&````&UH"`!,````B6@(`%````#9:
M`@`.````2UH"``D```!:6@(`"@```&1:`@`@````;UH"`!,```"06@(`"```
M`*1:`@`-````K5H"``P```"[6@(`%@```,A:`@`2````WUH"`",```#R6@(`
M&````!9;`@`8````+UL"``P```!(6P(`#@```%5;`@`8````9%L"``0```!]
M6P(`+P```();`@`/````LEL"``4```#"6P(`!P```,A;`@`"````T%L"`!$`
M``#36P(`(P```.5;`@`+````"5P"``,````57`(`!@```!E<`@`1````(%P"
M``P````R7`(`#````#]<`@`1````3%P"`!````!>7`(`%@```&]<`@`7````
MAEP"``4```">7`(`+P```*1<`@`?````U%P"`!X```#T7`(`"0```!-=`@`I
M````'5T"``<```!'70(`%P```$]=`@`^````9UT"`!$```"F70(`$@```+A=
M`@`(````RUT"``0```#470(`!0```-E=`@`-````WUT"`!H```#M70(`!@``
M``A>`@`'````#UX"``D````77@(`$0```"%>`@`(````,UX"`!,````\7@(`
M$0```%!>`@`/````8EX"`!,```!R7@(`&````(9>`@`;````GUX"``X```"[
M7@(`,````,I>`@`4````^UX"`!D````07P(`)````"I?`@`B````3U\"`"4`
M``!R7P(`$````)A?`@`"````J5\"``0```"L7P(`"P```+%?`@`*````O5\"
M``4```#(7P(``P```,Y?`@`-````TE\"`"<```#@7P(`1P````A@`@`5````
M4&`"`#(```!F8`(`.0```)E@`@!2````TV`"`"D````F80(`*````%!A`@`/
M````>6$"`'8```")80(`(@````!B`@!.````(V("`"\```!R8@(`-@```*)B
M`@`]````V6("`"X````78P(`(@```$9C`@`I````:6,"`#,```"38P(`)P``
M`,=C`@`P````[V,"`#0````@9`(`+0```%5D`@`I````@V0"`"P```"M9`(`
M+@```-ID`@`H````"64"`#$````R90(`)@```&1E`@`4````BV4"`!````"@
M90(`>P```+%E`@`*````+68"`'@````X9@(`>@```+%F`@!Y````+&<"`#``
M``"F9P(`80```-=G`@`4````.6@"`#4```!.:`(`$@```(1H`@`-````EV@"
M`(,```"E:`(`)@```"EI`@`Y````4&D"`"(```"*:0(`(````*UI`@!K````
MSFD"`!L````Z:@(`"@```%9J`@`%````86H"``8```!G:@(`"````&YJ`@`%
M````=VH"`!<```!]:@(`&0```)5J`@`7````KVH"`"(```#':@(`$````.IJ
M`@`+````^VH"``H````':P(`#@```!)K`@`(````(6L"``@````J:P(`!P``
M`#-K`@`(````.VL"``X```!$:P(`!P```%-K`@`&````6VL"`!<```!B:P(`
M$@```'IK`@`'````C6L"``4```"5:P(`$@```)MK`@`'````KFL"``L```"V
M:P(`$P```,)K`@`4````UFL"``D```#K:P(`#0```/5K`@`7`````VP"``T`
M```;;`(`"0```"EL`@`0````,VP"``H```!$;`(`!0```$]L`@`+````56P"
M``P```!A;`(`#0```&YL`@`-````?&P"``4```"*;`(`!@```)!L`@`*````
MEVP"``@```"B;`(`#````*ML`@`3````N&P"``<```#,;`(``@```-1L`@`"
M````UVP"``@```#:;`(`"````.-L`@`'````[&P"`"P```#T;`(``@```"%M
M`@`$````)&T"``X````I;0(`#@```#AM`@`0````1VT"`!4```!8;0(`$```
M`&YM`@`+````?VT"``8```"+;0(`!P```))M`@`2````FFT"`!(```"M;0(`
M`@```,!M`@`'````PVT"`!````#+;0(`*@```-QM`@`>````!VX"`#8````F
M;@(`"0```%UN`@`(````9VX"``L```!P;@(`'````'QN`@`%````F6X"``8`
M``"?;@(`"P```*9N`@`!````W0<``%X```#3!0``S@8````````;``````0`
M`$$$``#'`P``X`$``#8"``!Q`@``7P(````````D````6@(``.4"``!"!P``
MR@``````````````.@(``)D#``````````$``$4(``!K!0``K0<``/('``!3
M!```JP8```````!1`P``T`<``$4%``"$`P``U`$```H%``#@!P``+`@`````
M```O!@``M@0```````!Z!P```````"L#```>!@``.00``)4%``!0`P``#0(`
M`!4&``#Q!P``Q`,``"H#``!/!```>@4`````````````=@(``.`&```@`@``
M?P8````````B`P```````'4#```;`0```````&\$```7!@``Q@4```````"(
M!@```````%$%``#K!@``KP0``(,&``"/!````````,4#```>!```U@$``#\'
M``!5!P``0@,``-4!``"K!0``)P,``-X#``!V!P``;@(```````!=`@``_P``
M`$P$``"Q!```;0(```````!4`0``RP4```````!T`P``$00```\%``#.`@``
MA@<``&<!````````B@(``'$!``#C````$`<``$L"``#L!0```````!,&``!C
M```````````````#`0``N`(``.T%```I!0``90```'\!``!"!0``)P```#8$
M``".!``````````````<````*0,```````!'!@````````X#````````````
M`.$"```[!```)`8```L(````````$`4``.X`````````9P```-T#````````
M`0<``"D$````````*`<```````!B!```P@4```````#:!```2P$``','````
M````LP(``"\%```.!P`````````````)`0``M@,`````````````RP8``*@"
M``#V`@``E@$``$$&```I`@``,`(``!,%``#0`@```````!L"``!_!```60$`
M`#`%````````+0(````````V`````````,('``!R!P``B0<``/0"````````
MR00``.\%``#T!@``00````````!5!@```````*(#````````KP````````!L
M`P``U0(``````````````````-X"````````[P,``)X$```G!P``20(``"H`
M``#E`P``-`@````````=`P``.`$``%D%``#V!0``````````````````-P4`
M`%$```";`@``&`$```(!````````I`<``%0"``!G!```V@<```$!``"M!@``
M````````````````20```*8#```*!@``G`8``,4!`````````````&@&```Q
M`P``^@0```D#````````UP<``)H%``#-`@``J0$``!\!````````@`$``-0%
M```B`@``L@0``'(!``![`@```````/\&```(`0``3`,``"4!``"!!@``W0(`
M```````M"```,`,````````$`0``/@,``!`(```3`@```P0``%$'```E!P``
M4`<``.P```#Q!````````(4#``#U`0````````````"[`0```````-\&````
M````YP0``+D%``#5````SP0``-D'```]````BP```'X$``!N`0``D@4``)`"
M```&`````````)H!``"N`@``Y`4``$D%``!'!````````.4$``#`!```P0,`
M`&`$````````E08``.H%```(!0``_P4```````"E!P``MP$```````#[`0``
MA0(``-@%``#2````C````!`$``!8`P``PP````````"_!0``1@@```````#=
M!```!0$``#T$````````G`,``(0```!:`P``WP4``+\&`````````````$T&
M``#M!```+P```#<(````````V`,``"@%``"Q!@``B00``*0!```7`@``````
M`'\'``!:!@``V`<`````````````Q`8``(`#```_`@``SP$``&0'``"Y!```
MXP,``-,#``!&!0```````'`&``!=!@``MP0``.,"``"6`P``L`4``/`#``"+
M!0```````+P$``#1!```PP4``/("``!F````-@4``($$``".!@``_0```#L&
M``!D!0``*0$```````!A`@``G0,`````````````\0$``.0&```7`0``AP,`
M`,P#```+`0``4P4``&<"``!&`@```````#L(``"O!0````````````#3````
M`````%D#```U!@``@@```.`"```4!0``0`$``#X$````````,P8``)4"``".
M`0```````&`!``"B`0``K@0``,`%````````20,``.(`````````Z```````
M``"^`@``.0```"<!````````HP$````````$!0``#0$````````C!P``;@<`
M`%L!``#T`0``:@0```````"J`P``C@```&T!``!6!P```````%D$``!)!@``
M`````.4'``!$`@```````.4%``"`!0```````%X$````````<P```.<#````
M`````````%X%```;!```7P8``.<!````````%`@``+X'``!!`@``$04``),$
M```O!```M0(``-P#``!Y!P``U`8```````!-!P``#0,``,L"``"7`@``````
M`"X&`````````````%<```#[!```$08``(0&``!5`0``3@0``$4!``#4`P``
MG@<`````````````S0<``(4$``"Q!P``EP$````````F!```Y@4``!T(``!F
M`0``H`,```H"``#3`@``@@,``.X%```,!0```````*D$`````````````,0'
M```G!```%P```%P$``"[!0``]````/D!``"[!P``/0<``&`'````````@@(`
M`/@"``##!``````````````````````````````<`@````````````!F!0``
M`````,4&```<!P``'08``.8$``"B!0``2`@``%,"```=!P```P@``/@'````
M````ZP0``&@'```6`@```````"H%``"G!```A`<``&P"```:`@``:````*H&
M``#'`@``2`,````````,`P``>@0``,L!`````````````(H'``!%!P``````
M`(8$``!W`0```````/````!@!@```````'4'``````````@```````"4!0``
M``````````"[`@``-````````````````````(L#``"2`P``W0$``'\%````
M````_`4``(\&```I!@```@<``'<$````````DP```(P#````````AP$`````
M```H`````````*$```#J!```!08`````````````[@$```````"-`@``Q@<`
M```````B!0``)@4``"H"````````*0@```````!*!@``YP8``-`!```;!P``
M.P$``!P$``!Z!@```00``'8&``#(!```\@4```````"Z`@``UP,```````"&
M!0```````$<"``#%`@```````#`&```O"```$P<```````!.````90(``"$$
M``!E!P``Y@<``+$%```2!@``]@0```(%``#M!P``X0,``/T&````````3P(`
M`#P%```(!@``A@8``'L$``"/`0``6P,``(P$`````````````/L#``!O!@``
M2P8```````"T````>@,``'L'``#\`0```````!$"`````````````"L(``#`
M!@``4@<``(H%``!7`P``G`<``,$&```>````0P0``/8&``!^`P``R0$`````
M```!"````````"0!``!.`0````````P&``!.!0``D`8``'X'```M!P``Q@0`
M`'P`````````D`<``.8```"Q`0```````-H&``#K!0``A08```((``!G`P``
ML0(``)($``"H!P``J@<``%,!``"B!```L`<``'4"``!<`P``G@(``"@(````
M`````P8```````#K````N0,```````!5!0```````&8#```X````[0``````
M``"R!P``I0```/<!``";`0```````%0%````````$@@``)X```"/`P``9P8`
M`%D```!2``````````````#!!0``%@8`````````````-`(```````#:!0``
M``````L&```&!0``K@````````!G!0```````*('```5!P``P@,``"8```!&
M`0``5P8``"L'``"'!````````&<'`````````````"$!``!9`@``?04`````
M````````-P,``,4%``````````````````"K`````````.P'``"U!@``````
M`-$"````````9`$``)$'``#8`@```````*@&``!L!0``9`,`````````````
M6@4``.X$``#U!@```````'L&``!""```V@(``&(```````````````````"@
M!0``J@(``$(!``````````````````#D`0``1@8``&4!``![!0```````"@$
M``"L!@```````&H%``#:`0``]`4``"T&``!5`@``Q0<```4$``"]!@``.`4`
M```````>`@````````````````````````````````````````````#H!```
M,`@``'<"````````S0```,X!``"9!````````#((``#Y`@``=P,``'P&``#7
M!```#@0``($"```2`P``A@$``#<````Z"``````````````4!@``0@``````
M``!_`P``&`<```L$```S!0```````%@```#]`@``#00```L#``"#`0``'P``
M`$,"``"?`0``-@,```````"(`@```````&,&````````G08``,@&``#Z!P``
M`````'@$``")`@``XP<``),%``!K!@````````````#?`0``Y@,``#@#``#Z
M````/`,``)$#````````\@8``!D`````````5@4``-P````>`0``#`@`````
M````````-04```H```"T!```MP<````````V"```U@0```````#Z!0``&@0`
M`%8```!V!0``5@(``$X'````````+00``$0%``"V````00,``)D&````````
M&0,````````_!0``U@,``/4```!`````S`$``-P!````````0P$``",%``!<
M!P```````)8````,!```-0$`````````````````````````````"`<``%0#
M```$!P```````*H!`````````````$\%``#^!```'`@``'D#````````E`(`
M`,H#``#(!P```08``'\"``!\`@``2`0```0$``#,!P``````````````````
M]P<``$0$```R`0``]00``$<#``"<`0``.@$``&D'``#6`@`````````````#
M!0```````#X!``#$`@``40(``.,&````````2P<``.X&``"Q````\@0``+<&
M```-!@``%0$``+@```"?````2@4``*$!``#N`@```````.@%````````````
M`!<%````````D0(```````#(`@``C0<```````!C!P``P0```/0'````````
MN0````4````?"```$`,``*T!```K!@``IP$`````````````+@4```````#G
M!P``&0@```````!Q!P```````(<`````````N@<``'P%``#2`P``X04``$L`
M``!O!P``\`$``+@!````````(P,```````#\`````````.H'``!,````NP0`
M`'H!```8"```>0$```P!``"8`@``"P4```````"-!0``A@(``*L!````````
M`````/\#``#[!P``@`8``,H&``"5!P```````-P"``#Z`P``MP```&H'````
M````E@0``*0%```C`@```````'<%``#I`@``L@$``"@#``#.!P``"`0``#H#
M`````````````(8#``!O`@``:0$``$$%``"_`@``]P8``+P%```0`@``````
M`$P&````````=0`````````L`@```````#4'``#A!P``L@,``-\'``"D````
MP`<``+4%``"=!0```````"0#`````````````#$```!]!P``=0$``%4#``"?
M!@``G@$````````=`0```````/8'````````[`$`````````````7@<`````
M``"6!P``[@,```````",!0``[`,```````#1!0``I@$``$@!``!S!0``8@8`
M```````V!@``[`0``%0`````````<08``#L#``">!@``80```*<"```-"```
MK00```````#V`0``AP8```````"X!0``IP,``"\!````````,P0```````#^
M`P``3P$```````!)`0```````````````````````/$#````````,P(``,\#
M````````0`(``&8"``"_`0``O````-T%```\!````````"P$``#X`P``P`$`
M`#$"``!Q`P``*@@`````````````"08``'T#``#F`0````````<```!X`0``
MK0(``!,$``#7!0``E`````````#I`0``^P4`````````````I0$``)T"````
M````@@0``,D"`````````````(T!````````R0```.,!```^!@``C@4``,P&
M````````XP0``%`$```%!P``^@8```\'``",!@``X@$``"`!````````Y`<`
M`-0$`````````````,@%``"_````X@,``!H#``!$"```````````````````
M`````.T#```0````CP````X%`````````````(,````K`@```````*P$``"B
M!@``'P8````````Q"```&P4```````!C`@``S`4```````"@`@``T`4``',&
M``#4`@``P@8``*,&```\````L`0``*T`````````Z@,```$"```T!0``,04`
M```````'!0``1P@`````````````W@````````!-`0``0@8``-$````M````
M`````%\%```[`````````(0$`````````````$P!```4`P`````````````+
M!P```````$4&``!_````QP0``*P!``"X!```>````'0"``#`````*P4`````
M``!.`@``@P4``,H%```%`P``&@```!(%``#A`````````!0!```P`0``E0``
M``L````6`P``.@```"8(``#P!P```````(@!````````IP4``$8#``"H`P``
MJ@```&D#`````````````-X%``""!@```````'X"`````````````"P'``"R
M!@``)P8``+D"```8!```O@8``'`!```6"```EP8```````"L`P```````+<%
M``#]`0``\P(```````!F!P````````````"%`0``90,```````#!!P``?0$`
M`,8"```^!P``*`8``'X&``"=!```6P(``*D'``"C!```LP<``.D&```;!@``
M@P,``!('``#.!```^`8``.`%``#R`0``=@,``',!``"%!0``;`<``,\```"?
M!0``UP$```````"*!`````````````"[!@``B@8``-P'``",`@``;@,`````
M``"6!@```````*L#```I````1@```.\!``#(`P```````$`&``"L`@``+`4`
M`+H#````````````````````````.0$```````#Q!@``NP``````````````
M:`,```````"'`@``U`<````%```8`P``<@0````"``!!"```IP8``!D!```Z
M!```2P4``!4"``!\!````````+8'```#````#`(``)T`````````;08``.P&
M```\"```#P8````````)`@``````````````````LP$``"4(````````````
M`+8%`````````````#L'``#3!@````````````!^````:P(``,D%````````
MSP<``#X```!7!```;0<``#P!````````H`$``/`&``#R`P``80,``'(#```W
M!@``VP8````````J!P``6@<``((!``!3!P```````,<!````````1`<`````
M``"4`0``+@0``,D&````````I`0``.\'```:`0``E00``/4'```A`@``````
M`-@$``"S!0``Q@$``*X'```T!@``!04``-8````6`0````````````!B`P``
M*@0``,0%````````=04``),!``#O````L`$``!<'``#T!````````)8"``"_
M!```FP<``#`$``!'!P```````.\$``#H!P``&`8``!P!``#*!P```````#0$
M``#_!```:@````````!R`@```````%8$````````"P(```,'```K`0``Q@``
M`,P"````````0`0``.@&```A!@````````````"@!````````%L````@`P``
MT@(``(L&```1"```%@<```````"E`P``ZP(```````"N`P``GP,``%\'````
M````1P```%8&```N!P``N@4``+D!``"9!P``VP0``%P!``#L`@``$0<``,,!
M``!#!0```````"X(````````$@```,`"`````````````,L$``#P`@``/@4`
M``\#```&!P``E0$``/$%````````I@<```````#A`0``_P<``$H'````````
M`````$T#``!#!P```````)$```#U`P``T`,``"X````!!0``D@<``(L'``!J
M!@``9`8````````9!0``TP<```````"#!P```````+T'``#;`P``[@<`````
M````````ZP<``-,$``#[!@``Z@8```````#G`@``(0@``'``````````?08`
M`'@'```1`P``#P(``&(!``!P`P``-@<``&X```!6`0``A`4``-(%```Q!```
MD@8``(@#```$`@``=@```/X````R!```:P<```\!``#2!@``&`4``#X"``#.
M`P```````)H"``#F`@``0P@``&@"``!$`P``@P0``,\"````````L@(``)4#
M`````````````&@%```B!`````````````!Y!0```````,,'``"``@``````
M`.H!``!X!@``C@(``+(%```Y`@``!@0```````!Y!@````````H!``"2`0``
M`````/8`````````F0$``#<!``!J`P``(P8``#P'``!V!````````*@!```6
M````Y`,``$`(``#R````E@4``)$$``#*`@``M`<``"((````````1P4``$T"
M```B`````````!4````C````H@```%``````````6`8```($````````[P(`
M`'L!``"@!P``^00```````"_`P``O`<```(&``!Q````V04``&````"U`P``
MX`0``(,"```N`@``O0```/$"``"8!0``2````'`'````````L````-8%````
M````_`(``)@&``!,`@``Z0<```````":!```-P<``"$```#'````Z`(``*$'
M```9!@```````#0!````````.@<``#D'````````9@0```H(```(`@``````
M`+P"``"9!0``?`$``#(&``#5!@```````$P%````````,P````````"`!```
M$P@```````!6`P``M`,``%4```!^`0``=00``-$!`````````````*$$``"8
M!```KP8``.0```!Y````:04``&,#``#*!```0`4``&\````<!@``KP$`````
M```B`0```````$\#````````C`<``!0"```'!@``G`4``,T#``#'!P``````
M`+X$````````+@,``-D&````````T`0```\$``"P`@``H04``/L```!L!@``
MC`$``$,#``""!0``C08``%<"``"I````F0```,4$````````N`,```````#/
M!@``_00``+`&```D!0``P`,``'(&`````````````!H(```W`@``3P8``)0#
M``#!`0``>`,```````!=!P``5P4``.<`````````LP````(```!2!```:@(`
M``````#A!@``O04```````")````H`8````````$`P````````H#``")!@``
MHP(````````3````!@8``/,%```R`P``^P(```````"+`0``P@0``'0%````
M``````````@(````````_`,``%("``"3!P`````````&``!M!```808`````
M``#"`@``U00``,8&```S`0``D````/D``````````````+@&``#V`P``%@0`
M`',"``"F!````````,L#````````]P4````````O!P``S@```,,"````````
M`````,,&````````1P$```````!A`0``:P0``,(!``#.!0``G`0```\```!C
M`0``/0@```````#Y!P``^`4``(D%``"0`P```````&$$``!=`P``&@4``$4$
M```L````%04``/@$``````````````````!>`P``)`(``"4`````````!P@`
M`"4$```_!@``EP,```````#Q`````````&L```!;!```S04``*@$```9!P``
M`````/P'````````IP```+4`````````O`8``"8"``"Y!@``/0(```````#-
M!@``+`8```````"T`@``HP<``%P&``!W!@``F0(``"L$````````7````+X#
M``"O!P``:0``````````````I`,`````````````)P@``(\"``#,!```G0$`
M`#@(``!R!0``.0,``,D'``![````0@0````````2`@````````````#<!0``
M[P8``$8'``"N`0``@@<``'D$``"/!0``AP<``+T"``#2`0``!`8``%@$``#E
M!@``Q@,``+(```#(````80<``"\"``!]!```'@4``-($``#@`P``6`(``%H`
M``#9`````````%@'``"&`````````*D%``"P`P``K`4``$@'````````````
M`#`'```B!P``F@,````#```L`P``ZP$`````````````'04``-@```!C!```
M.P4``.,%````````=P````````"(!0``-`,```````#^`0``V00``(L"````
M````*@$``"H&```\`@```````)0$``!;!P```````-X'``#W````V0$`````
M```]!@``'P(``-\$````````#@@``-<&````````(04``(\'```_`0``````
M`,\%``"J!0``5`0```````#+!P``T`8``!H'``"1!0``_`0```````!(!0``
M`````#("```*!P``\P,``/,'``!0`@````````````#>`0``N@```-$'```S
M"```#04``*H$``!\!P``I`(``$T````G`@```````-\#````````_0<``&\%
M```N`0``2P0``$X#```M`P``)P4``!L(````````4`8``$,&``#5!P``````
M``<'````````Z00``/D%``![`P``_@4``#4"```-!P``!P$```4"``#(`0``
MEP4``!$!``!7`0``X@8`````````````U0,``.@!``#:`P```````#D%````
M``````````(#```9!```10,``'@"``":!@``;`0``-4%``!I!@```````"8'
M``!5!```'@,``"`&``#<!```6@$``/@```!>!@```````&0"``#W`@``N@8`
M````````````B@$```````"U!```^08``($'````````(P@``+8!``#;````
M7P$``#X(``!D```````````````C`0``:@$``$4````8`@``_04```,#````
M````/0$``%`%``!0`0``HP````````!;!@````````\(``">!0``I08``"8&
M```Y!@```````/<#``!R````$P$``'$$``"O`P````````````"V`@``````
M`/P&````````$0`````````_`````````#L"``"[`P``N0<``*8%``#Z`@``
MT0,``)`$````````:0(``(T$```<`P``K````(X'```\!@```````,<%````
M````F`,``*L"``"'!0``F`<``/4%```U!```<P,``%T```!$!@``7@(`````
M``!$````/04``%0&``"-`P``%@4``,0$``#^`@``MP(``-<"```?!0``BP0`
M`!<$```5"```D@````````!T`0``I@(```````"U`0```````-L%``#E`0``
M*`(`````````````B`<```````#]`P``WP```)X#````````^0,``!<(``##
M`P``<P0``-\"`````````````.0"``"=!P`````````'``!M`P``J0,`````
M```)!```5`<`````````````!0@```````!P`@``%P,``)0'``!H`0``%`0`
M`(D#``#J`@``OP<```,"``";!```LP,``.``````````O@$``+X`````````
M)@,````````(````8@(`````````````I0(``!0```"T!0``B0$````````0
M!@``7P,``$\'```Q`0````````P'``"\`P``N@$``-@&``!)!```P00``*0&
M````````X@(``%T$``"1!@``10(``$H!``"1`0``>`4``'`%``"4!@``````
M`#@$``!:!```W@8``/,$````````"04```````!O`0``EP0``&8&```I!P``
M:P,``#<$``#"````[08``)@```#E````00$````````A`P``$P,```8(````
M````K04``$`'`````````````!0'````````4P,``/0#``!$`0``GP<``$("
M``#G!0``U@8```````#_`@``\P8``$,```!M!0``^@$```("``"E!```````
M`-0`````````5P<``&X%```C!````````"`'```:!@``S````(X#```>"```
MT`````P```#+````=P<``%L%````````J0(````````E`@```````.D%````
M````K@8``````````````````%@%```2!````````/\!```?!P```````,0`
M``"%`````````,<&```.`0````````````":````[0(```<"````````*P``
M``X```#9`P``GP0``*D&``!K`0````````````!=!0````````````";`P``
M.0@``#@&``!)!P``U@<``%\$```O`P``&P,``)`!``"\`0``3@8```D```!2
M!0``408`````````````M0<`````````````VP(``&(%```=````T@<``),"
M``!-!```X@0``.D```"T!@``=@$``-P&``````````````T```!Z````X@4`
M`````````````````*8```"A`@``)`@```0(````````H@(`````````````
M'`4``!`!``"H!0````````D'``!@`P```````%P"``#1!@``'@<``)\"````
M````F@<```````!T````Y`0``)<'``#U`@``.`<```````!L`0``I04``-D"
M`````````````(`'```A!P``O@4```D(``!@!0``FP```#4```"*`P``S00`
M``````!3!@``.`(`````````````D`4``*L$``!``P``;@8```8#``"N!0``
M,P<``'0&``"M`P``,@4``)@!``!(!@``/P0``,T!````````!@$``(0"``!L
M`````````"`%```@!````````'X%``"3!@``%00``"``````````(`@``&$%
M``"Q`P```````*@```!B!P``+0$```````#^!P```````"(&``!U!@``^`$`
M`,0!````````;0```,$"````````\P``````````````#@8``$P'```(`P``
M'0(``#\(``!I!````````($!``````````````<$``"L!P``W08``!(!``"@
M````=`<``&,%``!/````/0,```````````````````8"```U`P``%0,``%(#
M````````2@(``"4%``#)`P```````````````````````%D'``!*`P``R@$`
M`+<#````````````````````````@04``.8&``!E!```904`````````````
MW@0```````#%````-0@``*<'`````````````"0'``#3`0`````````````H
M`0``VP<``+0!``"Z!```H0,``/X&`````````````'0$``!2`0``<04``'D"
M``#W!```4P```.D#``!2!@``<`0``.T!``!]`@``?`,```````!O`P``O0$`
M`(0!``"-````````````````````@0````````#S`0``O00``#H&````````
M'P0```````"7````X00```````!>`0``V`$``#H%``#7`````````+@'```?
M`P``VP$``#$'``"(````ZP,``(````"C!0````````````!<!0```````"T%
M``!Z`@``)@$``(4'```!`P``W0```+,&``"C`P``,```````````````````
M`&`"````````H08``"0$```=!```;@0``'T```!&!````````/`$```R!P``
MZ`,```X"````````@0,``#(`````````/P,``&4&``"]`P```````*8&````
M````2@````````!1`0``G````%D&``"(!````````"4#```S`P``70$`````
M``!!!P``2`(``-H```!+`P```````&@$``#P!0``9`0``+,$```*!```!P,`
M`*L'````````!````)P"`````````````%$$```V`0```````!D"````````
M`````%@!```Q!@``-`<``*\"``!*!```D@(```````";!0```````"4&``#J
M`````````"P!``";!@``&````.('````````7P````````"3`P``304``+8&
M``"*`````"`@+4TL("TM;65S<V%G93U-15-304=%("!5<V4@=&AI<R!C;VUM
M:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N97,N`"`@+6$L
M("TM861D/49)3$4@("`@("`@($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O
M;7!E;F1I=6TN(%5S969U;"!T;PH@("`@("`@("`@("`@("`@("`@("`@("!I
M;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T
M;PH@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V5N97)A=&5D(&-O;7!E
M;F1I=6TN`"`@+6(L("TM8F%S93TO4$%42"`@1G5L;"!P871H('1O('1H92`H
M2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H870@<VAO=6QD(&)E"B`@("`@("`@
M("`@("`@("`@("`@=7-E9"X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@($UE
M<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI<R!C;VUP96YD:75M(&9I;&4*
M("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0@;VYE("AC;VUP96YD:75M+G!O(&EN('1H90H@("`@("`@("`@("`@("`@
M("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+@`@("UC+"`M+6-O;7!E;F1I
M=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@
M=&AE(&1E9F%U;'0*("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M
M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2X`("`M9"P@
M+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE(&5X
M96-U=&5D(&)I;F%R:65S+@`@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A
M=&4@8V]M<&5N9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2X`("`M:"P@+2UH96QP
M("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+@`@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C
M86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C86QE
M/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92X`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($)U:6QD($U/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M
M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P(%!/(&9I
M;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#
M<F5A=&4@82!03R!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F:6QE<R!O;FQY
M(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I
M(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!O;FQY
M('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T
M<F%N<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN`"`@+6XL("TM;F\M8V]M
M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M+@`@("US+"`M+7-T
M871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN
M(&$@;&]C86P@9FEL92X`("`M="P@+2UT97-T("`@("`@("!3:&]W('1H92!E
M>&5C=71E9"!C;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+@`@(&-L
M96%N=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS
M;&%T960@86YD(&]B<V]L971E(&5N=')I97,N`"`@8V]M;6ET("`@("`@0V]M
M;6ET('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BX`("!C;VUM:70M
M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E<BX`("!C
M;VUP96YD:75M("!296)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI
M;F<Z(%1H:7,@;W9E<G=R:71E<R!T:&4*("`@("`@("`@("`@("!C=7)R96YT
M(&-O;7!E;F1I=6TN`"`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA
M=&4@*"YP;W0I(&9I;&5S+@`@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP
M(&UE<W-A9V4N`"`@:6YI="`@("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/
M(&9I;&5S(&9O<B!A(&YE=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7,*("`@("`@
M("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T
M:&ES(&QO8V%L92X`("!M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@9FEL
M97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I;&5S+@`@(&UA:V4M:&5L<"`@
M($UA<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@
M=7`M=&\M9&%T92!A;F0*("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE
M(&9O<B!T:&4@;F5X="!E>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=0H@
M("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@049415(@
M=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H90H@("`@("`@("`@("`@(&AE
M;'`@9FEL92X`("!M97)G92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F
M:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL92X`("!U<&1A
M=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N="X`("!U<&1A
M=&4M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F
M<F]M('1H92!%;F=L:7-H(%A-3"!H96QP"B`@("`@("`@("`@("`@9FEL92!A
M;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+@`@)B,Q-3$[
M("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E
M<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B
M)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E
M(&ET(&ES(&$@;&ES="X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`B)7,B
M('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI<W0N`")&:7)S=&YA
M;64@3&%S=&YA;64B("`H:64N($IO:&X@1&]E*0`B3&%S=&YA;64L($9I<G-T
M;F%M92(@*&EE+B!$;V4L($IO:&XI`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W
M<FET=&5N+@`E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E
M`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO
M;@`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R
M;7,@;V8@06=R965M96YT`"5S(&%D9&5D+@`E<R!A;')E861Y(&5X:7-T<RX`
M)7,@870@)7,@)7,`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@
M:7,@;F]T('=R:71A8FQE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S
M(&YO="!F;W5N9"X`)7,@;F]T(&9O=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X
M=')A8W0G(&9I<G-T+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O
M:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S
M.B`E<P`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R
M<P`\4')E=FEO=7,`/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@
M)7,N"D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N`$$@8G)O=W-E<B!T
M:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960`02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R
M<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG
M:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-
M+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8F]V92!S
M96%R8V@@9F]R;0!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`
M06-C;W5N=&EN9P!!9%]V86YC960@4V5A<F-H`$%D9`!!9&0@0VAI;&0@1W)O
M=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O
M=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E
M<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U
M<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@
M=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O`$%D9"!T
M;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S
M97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E
M<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@
M;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061D<F5S<R!";V]K($QI<W1I
M;F<`061D<F5S<R!B;V]K(&5N=')Y`$%D9')E<W,@8F]O:R!I<R!R96%D+6]N
M;'DN`$%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+@!!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES
M=')A=&EO;@!!9',`061V86YC960@4V5A<F-H`$%F9VAA;FES=&%N`$%L8F%N
M:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T
M:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!
M;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!%>&ES=',`
M06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E
M($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N
M871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA
M=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O
M<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N
M=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L
M:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O
M=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U
M-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R
M92!T:&%T('EO=2!W86YT('1O(&1E;&5T92`E<S\`07)E('EO=2!S=7)E('1H
M870@>6]U('=A;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/P!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!
M<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YD:6YG`$%S8V5N
M<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U
M<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E
M<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N
M(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@0V]L=6UN<SH`079A
M:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%?8VL@
M=&\@)7,`0F%C:R!T;R`E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N
M`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&]S`$)A<V5L:6YE`$)A<VE?8R!396%R8V@`0F%S:6,@4V5A
M<F-H`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5L;W<@<V5A<F-H(&9O<FT`
M0F5N:6X`0F5R;75D80!":'5T86X`0FEN9"!F86EL960Z("@E<RD@)7,`0FER
M=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N
M9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O
M:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T
M($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M`$)R=6YE:2!$87)U<W-A;&%M`$)U:6QD:6YG($U/(&9I;&5S(&9O<B!M;V1U
M;&4@)7,N+BX`0G5I;&1I;F<@;&]C86QE("5S+BXN(`!"=6QG87)I80!"=6QL
M971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$)U<VEN97-S($-A=&5G
M;W)Y`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL
M(%!R;W!E<G1I97,N+BX`0U]L96%R(%-E87)C:`!#86-H92!I;FET('=A<R!N
M;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N
M`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E
M=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S
M(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@
M;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I
M;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H
M86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`
M0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!?06QL+TYO;F4`0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D
M("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A
M(&1E9F%U;'0@9&ER96-T;W)Y(&9O<B!Y;W5R('!E<G-O;F%L(&%D9')E<W-B
M;V]K+"!C;VYT86-T(&QI<W1S+"!A;F0@<V5A<F-H97,N`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A9&1R97-S(&)O
M;VL`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('1H92!O<F1E
M<B!O9B!T:&4@8V]L=6UN<R!T;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI
M<W0N`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N`$-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N
M+BX`0VQE86YI;F<@=7`@;&]C86QE("5S+BXN(`!#;&5A<@!#;&5A<B!-4T]F
M9FEC92!T86=S`$-L96%R(%-E87)C:`!#;&5A<B!O=70@=7-E<CH@)7,`0VQE
M87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T
M;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#
M;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M
M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z
M`$-O;'5M;B!/<'1I;VYS`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA('-E
M<&%R871E9"!V86QU97,`0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S
M;V9T($]U=&QO;VLI`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM86YD(&]P
M=&EO;G,Z`$-O;6UA;F1S.@!#;VUM96YT`$-O;6UI='1I;F<Z`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP86YY($%D9')E<W,`0V]M<&]S92!-
M97-S86=E("@E<RD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T
M:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(&9A
M:6QE9#H@)7,`0V]N;F5C=&EO;B!F86EL=7)E`$-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N
M;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C="!R96UO=F5D
M(&9R;VT@;&ES="X`0V]N=&%C=',@:6X@;&ES=#H@)7,`0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O
M;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B
M)7,B`$-O;G1E;G1S(&]F("5S`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K
M:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W!Y:6YG("5S('1O("5S`$-O<W1A
M(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@
M;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N
M("5S`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($94
M4#H@)7,`0V]U;&0@;F]T(&-O<'D@)7,@=&\@)7,`0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&-R96%T92!L;V-A
M;&4@9&ER96-T;W)Y(&9O<B!L;V-A;&4@)7,Z`$-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P
M9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L
M9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E
M<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`
M0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%D
M("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@
M(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@
M8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R;6ES
M<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT
M(#0@4&AA<V5S`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT
M(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U
M="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#
M>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`
M1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU
M;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$
M969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!$:7-P;&%Y`$1E9F%U;'0@
M261E;G1I='D`1&5F875L="!097)M:7-S:6]N<P!$969A=6QT(&1I<F5C=&]R
M>2!F;W(@>6]U<B!P97)S;VYA;"!A9&1R97-S8F]O:RP@8V]N=&%C="!L:7-T
M<RP@86YD('-E87)C:&5S+@!$969A=6QT('!E<FUI<W-I;VYS`$1E9F%U;'0@
M<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@
M0V]N9FER;6%T:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!B=71T;VX@8F5H879I
M;W5R`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG
M(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@9F%I;&5D.B`H)7,I("5S`$1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!P97)M
M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&5T:6]N(&9A:6QE9`!$96QI=F5R
M>2!T:6UE`$1E;FUA<FL`1&5P87)T;65N=`!$97-C96YD:6YG`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y
M`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$
M:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U
M=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N
M=')I97,_`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI
M8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O=VYL;V%D
M('9#87)D`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O
M<@!%9&ET`$5D:70@(B5S(@!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!0
M97)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F
M;W(@)7,`161I="!E;G1R>2!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I
M="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%
M;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S
M<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE
M(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@
M=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE
M87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@
M<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1R:65S.B`E9"!T
M;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E9"!C:&%N9V5D+"`E9"!U
M;FMN;W=N`$5N=')Y(&9O<B`E<R!U<&1A=&5D+@!%<75A=&]R:6%L($=U:6YE
M80!%<FET<F5A`$5R<F]R`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R
M;W(@=W)I=&EN9R`B)7,B+@!%<G)O<CH@`$5S=&]N:6$`171H:6]P:6$`171H
M;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%
M=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%
M=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%
M>&5C=71E`$5X96-U=&EN9SH`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C
M=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T
M97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!%>'!O<G0`17AP;W)T($%D
M9')E<W,@0F]O:P!%>'!O<G0@;VYL>2!T:&4@<V5L96-T960@8V]N=&%C=',N
M`$5X<&]R="!T:&4@9F]L;&]W:6YG(&%D9')E<W,@8F]O:R!C;VUP;&5T96QY
M+@!%>'1R86-T:6YG(&9R;VT@)7,N+BX@`$9'($-O;&]R`$944"!U<&QO860@
M;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE
M9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,`1F%I;&5D('1O(&%D
M9"`E<R!T;R`E<SH@)7,`1F%I;&5D('1O(&)R;W=S92!L:7-T`$9A:6QE9"!T
M;R!B<F]W<V4@=&AE(&1I<F5C=&]R>0!&86EL960@=&\@8VAA;F=E(&YA;64Z
M("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@/2`E<RP@4F]O="`]("5S
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E
M<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&9I;F0@;V)J96-T('1O
M(&)E(&%D9&5D.B`E<P!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@
M=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S`$9A:7(`1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A
M>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R
M<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@0V]U
M;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R
M`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YD`$9I;FQA;F0`1FER
M<W0@2&%L9@!&:7)S="!.86UE`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L
M:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O
M;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H
M92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H
M=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&
M;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R
M9',`1F]U;F0@87!P;&EC871I;VYS.B`E<P!&;W5N9"!D:7)E8W1O<FEE<SH`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E8G5S
M>2!54DP`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R
M:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1G5Z>GD`1V%B;VX`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E
M("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5N97)A=&EN9R!S
M=&%T=7,@9F]R(&UO9'5L92`E<RXN+@!'96]R9VEA`$=E<FUA;GD`1V5T;W!T
M($5R<F]R.B``1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($%D
M9')E<W,@0F]O:P!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`
M1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'
M<F]U<`!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E
M(&YO;BUE;7!T>0!'<F]U<"!P97)M:7-S:6]N<P!'<F]U<',`1W5A9&5L;W5P
M90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'
M=65S="!P97)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S
M874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`
M2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;'!E<@!(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I
M;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D90IF<F%M97=O<FL@86YD(&ET
M<R!A<'!L:6-A=&EO;G,N"D9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@
M9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O<GDN`$AE;6ES<&AE<F4`2&5R
M92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AI<W1O<GD@
M96YT<GD@;F%M97,@;75S="!B92!N;VXM96UP='D`2&]?;64`2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!#
M:71Y`$AO;64@0V]U;G1R>0!(;VUE(%!H;VYE`$AO;64@4&]S=&%L($-O9&4`
M2&]M92!3=&%T92]0<F]V:6YC90!(;VUE(%-T<F5E="!!9&1R97-S`$AO;F1U
M<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T
M;W(`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R
M97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O
M9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U
M8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%-U8V-E
M<W-F=6QL>2!S>6YC:')O;FES960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE
M(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0
M(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`
M2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E
M="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y
M`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S`$E-4U``25`@061D<F5S<P!)4"!!9&1R97-S(&YO
M="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@
M0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E
M;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R
M86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E
M(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M
M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T($%D9')E<W,@
M0F]O:RP@4W1E<"`E9`!);7!O<G0L(%-T97`@)60`26UP;W)T+T5X<&]R="!!
M9&1R97-S($)O;VMS`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L
M9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A
M;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO
M;B!N;R!L;VYG97(@879A:6QA8FQE+@!);FET:6%L:7II;F<@;6]D=6QE("5S
M+BXN(`!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T
M(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@
M8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`
M26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T
M(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A
M<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A
M9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@
M26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N
M="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@0V]N=&5N
M="U4>7!E`$EN=F%L:60@240`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%D9')E<W,@8F]O:P!)
M;G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N
M`$EN=F%L:60@96UA:6P`26YV86QI9"!E;G1R>0!);G9A;&ED(&9I;&4@9F]R
M;6%T`$EN=F%L:60@:V5Y('-P96-I9FEE9"X`26YV86QI9"!L:6-E;G-E(&ME
M>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP
M92X`26YV86QI9"!N86UE`$EN=F%L:60@;V)J96-T260`26YV86QI9"!O<B!M
M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N
M`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I
M9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN
M=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN
M=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!)
M;G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA
M;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E
M<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E
M("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF
M>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU
M<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE
M;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE
M;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI
M8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3$1!4"!S
M=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T
M(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+@!,85]Y;W5T`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T
M($UO9&EF:65D`$QA<W0@3F%M90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D
M.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@
M;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L
M=65S`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI
M96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A
M:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3
M:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES=`!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E
M`$QI=&AU86YI80!,;V%D:6YG(&QI8G)A<FEE<RXN+@!,;V%D:6YG+BXN`$QO
M8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO
M9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U
M<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`
M3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@
M;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E
M<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`
M36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA:V4@<W5R92!T:&%T('EO=2!H
M879E(%!%05(@:6YS=&%L;&5D(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"X`
M36%K:6YG(&1I<F5C=&]R>2`E<P!-86QA=VD`36%L87ES:6$`36%L9&EV97,`
M36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@
M:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@
M;6%P`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG`$UA=&-H
M:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C
M<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU
M;2!L96YG=&@`36%X:6UU;2!N=6UB97(@;V8@<&%G97,`36%Y`$UA>6]T=&4`
M365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<F=I
M;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G
M:6YG(&QO8V%L92`E<RXN+B``365R9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@
M=&\@=&AE(&-O;7!E;F1I=6TN+BX@`$UE<F=I;F<@=')A;G-L871I;VX@9F]R
M(&UO9'5L92`E<RXN+@!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-
M971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=')I
M8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D
M;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z(`!-:6YI(%-E87)C:`!-:7)R;W(`36ES8V5L;&%N
M96]U<P!-:7-S:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R871I;VXN
M`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S
M<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`
M36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V)I;&4@4&AO
M;F4`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9&EF>2!F
M86EL960Z("@E<RD@)7,`36]D=6QE`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L
M:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`
M36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E('1H86X@,2!E;G1R>2!F;W5N
M9`!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3
M=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E
M(%5P`$UO=F4@9&]W;@!-;W9E(&QE9G0`36]V92!R:6=H=`!-;W9E('5P`$UO
M>F%M8FEQ=64`375L8F5R<GD@061D<F5S<R!";V]K`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;
M)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T`$UU
M;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%D9')E<W,@0F]O:P!-
M>2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/
M5"!!9W)E90!.86UE`$YA;64@1F]R;6%T`$YA;6EB:6$`3F%U<G4`3F5P86P`
M3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GD`3F5T:&5R;&%N9',`3F5T:&5R
M;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P
M92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P
M92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N
M=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W
M($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($-O;G1A8W0`3F5W($QI<W0`
M3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`
M3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT
M(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEC:VYA
M;64`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO("5S(&5N=')Y(&9O
M=6YD(&9O<B`E<P!.;R!A9&1R97-S(&)O;VMS(&9O=6YD+@!.;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P
M97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X`
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`
M3F\@8V]M;6%N9"!S<&5C:69I960N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+@!.;R!C;VYT86-T<R!F;W5N9`!.;R!C<F5D:70@;&5F="X`3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N`$YO(&5N=')Y('=I=&@@=&AE(&ED("(E<R(@
M97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N`$YO(&9I;&4@=7!L
M;V%D960`3F\@;&]C86QE('-P96-I9FEE9"X`3F\@;&]C871I;VX@:7,@<V5T
M+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`
M3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F
M9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%14
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($Q$05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@
M3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I
M<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N
M9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V0V%R9"!D871A('=A<R!F;W5N9"X`
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO
M;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L
M:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA
M($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I
M<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E
M9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EC90!.
M;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F
M(&-O;'5M;G,`3G5M8F5R(&]F(&ET96US('!E<B!P86=E`$YU;6)E<B!O9B!R
M;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES
M=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8FIE
M8W0@8W)E871O<B!P97)M:7-S:6]N<P!/8FIE8W0@;F]T(&9O=6YD`$]C=&%L
M`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]M86X`3VYL>2!)34%0
M('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R
M90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N
M<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<'1I;VYS.@!/<F1E<F5D($QI<W0`
M3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T
M97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO
M;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP
M=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W
M97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M
M<P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE
M80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN
M8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`
M4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@
M9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!0
M97)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`
M4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE
M9`!097)M:7-S:6]N(&1E;FEE9`!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;@!097)M:7-S:6]N<R!F;W(`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:6YE($%D9')E<W,@0F]O
M:P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N`%!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&QI<W0Z`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E
M860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R97!O<G0@86YY
M(&)U9W,@=&\@:3$X;D!L:7-T<RYH;W)D92YO<F<N`%!L96%S92!S96QE8W0@
M82!D:7)E8W1O<GDZ`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M
M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG
M(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB
M<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@
M97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A
M(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E
M(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M
M96YT`%!R:79A=&4@061D<F5S<R!";V]K`%!R:79A=&4@2V5Y`%!R;V)L96T`
M4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L
M:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!1=65R>2!F86EL960Z("@E
M<RD@)7,`475I8VL@4V5A<F-H`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A
M9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@
M4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T
M=6YE`%)A=&EO`%)E860`4F5A9"!F86EL960Z("@E<RD@)7,`4F5A9"!M97-S
M86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C;W)D<R!D
M:7-P;&%Y960Z`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN
M86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E
M>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S
M`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!2
M96UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA
M='1I;F<`4F5M;W9E(&9R;VT@=&AI<R!L:7-T`%)E;6]V92!P86ER`%)E;6]V
M92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<&QA8V4@97AI
M<W1I;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/&(^
M5V%R;FEN9SH@5&AI<R!D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R
M<F5N="!A9&1R97-S(&)O;VLN/"]B/@!297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@;V)J96-T
M(&YO="!F;W5N9"X`4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S
M<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-E="!T;R!$969A=6QT<P!2
M97-U;'1S`%)E<W5L=',@*&EN8VQU9&EN9R!(;W)D92DZ`%)E<W5L=',Z`%)E
M='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@
M:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2
M;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A
M=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!3+TU)344@4'5B;&EC($-E<G1I9FEC
M871E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3
M($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-405)45$Q3(&9A:6QE9#H@*"5S
M*2`E<P!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT
M($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD
M($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A
M;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N
M9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A
M=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C
M871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE
M<P!396%R8V@@4F5S=6QT<P!396%R8V@@9F%I;&5D`%-E87)C:"!F86EL960Z
M("5S`%-E87)C:&EN9R!(;W)D92!A<'!L:6-A=&EO;G,@:6X@)7,`4V5A<F-H
M:6YG($]P=&EO;G,`4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N+BX`4V5A
M<F-H:6YG+BXN`%-E;&5C="!!9&1R97-S($)O;VL`4V5L96-T($9I;&5S`%-E
M;&5C="!,:7-T`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D
M`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@
M=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C
M="!A;B!O8FIE8W0`4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@97AP;W)T
M(&9R;VTZ`%-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SH`
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA
M=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F;W)M
M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@=&AE(&9O<FUA="!U<V5D
M('1O(&1I<W!L87D@;F%M97,Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+@!396QE8W0@
M=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N
M`%-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RX`4V5L96-T
M('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z`%-E;&5C=&5D($-O;'5M;G,Z`%-E;&5C=&5D(&%D9')E<W,@8F]O
M:R`B)7,B+@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I
M86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&%R
M960@1&ER96-T;W)Y`%-H;U]W($%L;`!3:&]P<&EN9P!3:&]R="!3=6UM87)Y
M`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS
M/P!3:&]W`%-H;W<@06QL`%-H;W<@0V]N=&%C=',`4VAO=R!,:7-T<P!3:&]W
M(%]#;VYT86-T<P!3:&]W(%],:7-T<P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME
M<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`
M4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC
M:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U
M<`!3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U
M<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`
M4VMI<'!E9"XN+@!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R
M`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S
M($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!$
M:7)E8W1I;VX`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`
M4V]U<F-E<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y
M+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C
M96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`
M4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&5C:69Y('=H97)E('EO
M=2!W86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BX`4W!L
M:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N
M:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O
M=FEN8V4`4W1A='5S`%-T871U<R!F;W(@;&]C86QE("5S+BXN(`!3=&]R86=E
M(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L
M:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=
M`%-U`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B
M)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C
M97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<P!3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I
M9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY
M('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F
M=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N
M`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I
M<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I
M<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@
M36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R
M;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O
M<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`
M5%-6`%135B!F:6QE`%1A8B!S97!A<F%T960@=F%L=65S`%1A8FQE`%1A8FQE
M(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E
M;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``
M5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP
M;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`
M5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)
M4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E
M;2X`5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VXG="!Y970@97AI<W0N
M($-R96%T:6YG(&$@;F5W(&]N92X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO
M="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@
M8F4@<'5R9V5D.B`E<P!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY
M`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`5&AE(&-O;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E
M>&ES="X`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE
M(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+@!4:&4@:&5L<"!F:6QE("5S(&1I9&XG="!S=&%R="!W
M:71H(#P_>&UL`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N
M`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@
M1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ
M(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B
M:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O
M;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC
M92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M
M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U
M;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V
M960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP
M;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&)R
M;W=S96%B;&4@861D<F5S<R!B;V]K<RX`5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S
M(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R!A
M<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S
M('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@:7,@86X@97)R;W(L('!L
M96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H97)E
M(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H
M879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S
M<R!T:&%N("5S+@!4:&5R92!D;V5S;B=T('EE="!E>&ES="!A(&AE;'`@9FEL
M92!F;W(@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@
M=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W
M960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N97<@8V]N
M=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R(&9O<B!F
M=7)T:&5R(&AE;'`N`%1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!A(&YE
M=R!L:7-T+@!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@)7,@9G)O;2!T
M:&4@<V]U<F-E(&%D9')E<W,@8F]O:RX`5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H:7,@;V)J96-T+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&4@<V5L96-T($QI<W0`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!D871A.B`E<P!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!O<&5N
M:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP:'`@
M=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S(&9R
M;VT@=&AE('AM;"!P87)S97(N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@<F5M;W9I
M;F<@=&AI<R!O8FIE8W0N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,`5&AE<F4@=V5R92!N;R!A9&1R
M97-S97,@=&\@97AP;W)T+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&%D9')E<W,@8F]O:R!I<R!R
M96%D+6]N;'D`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M
M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9I;&4@
M9F]R;6%T(&ES(&YO="!S=7!P;W)T960N`%1H:7,@9F]R;2!H87,@86QR96%D
M>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B
M($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I
M;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@
M2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M
M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI
M<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S
M<R!B;V]K`%1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA
M;F0@;&EN92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD
M97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM
M92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I
M.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K
M:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O
M;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T960`
M5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS
M90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K
M;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E
M('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M
M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@
M07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN
M;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&-O;6UA
M;F0Z("5S`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E
M<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U
M<'!O<G1E9"!#;VYT96YT+51Y<&4N`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5
M;G1R86YS;&%T960`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A
M=&5D("(E<R(N`%5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N`%5P9W)A
M9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@
M;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-A9V4Z`%5S
M92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T
M:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R('!E<FUI<W-I;VYS
M`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N
M86UE.@!5<V5R;F%M93H@`%5S97)S`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z
M8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I
M;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@
M9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"X`5F5R:7-I9VX@1&ER96-T;W)Y`%9E<G-I;VX`5F5R<VEO;B!#;VYT
M<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ
M`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@
M(B5S(@!6:65W("5S`%9I97<@0V]N=&%C=`!6:65W(&%N(&5X=&5R;F%L('=E
M8B!P86=E`%9I97<@87,@)7,`5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0Z
M`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N
M`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!3
M3510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V%R;FEN9SH@`%=E
M`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E
M871H97(N8V]M`%=E8@!796(@4VET90!796)S:71E(%523`!7965K;'D`5V5L
M8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX
M.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I
M9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@
M=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A
M<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7
M:7-H;&ES=',`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!#:71Y`%=O<FL@0V]U
M;G1R>0!7;W)K(%!H;VYE`%=O<FL@4&]S=&%L($-O9&4`5V]R:R!3=&%T92]0
M<F]V:6YC90!7;W)K(%-T<F5E="!!9&1R97-S`%=R:71I;F<@=7!D871E9"!H
M96QP(&9I;&4@=&\@)7,N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L
M=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`
M6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!9
M96UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@8W)E871I;F<@82!D:7-T
M<FEB=71I;VX@;&ES="X`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE
M(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY
M(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P
M;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I
M;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=2!D;R!N;W0@:&%V92!P97)M
M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N`%EO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@
M=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I
M9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O
M8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN`%EO
M=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+@!9;W4@;75S="!S96QE8W0@
M86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A="!L
M96%S="!O;F4@96YT<GD@9FER<W0N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@
M<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@;VYL>2!H879E
M('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M
M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T
M:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@
M4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R
M96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&%D9')E<W-B;V]K(&ES(&YO
M="!B<F]W<V5A8FQE+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L
M;"!N86UE.@!9;W5R(&=E='1E>'0@=F5R<VEO;B!I<R!T;V\@;VQD(&%N9"!D
M;V5S(&YO="!S=7!P;W)T(%!(4"!N871I=F5L>2X*3F]T(&%L;"!S=')I;F=S
M('=I;&P@8F4@97AT<F%C=&5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@
M:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE
M(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T
M92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!:
M:7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO
M=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=
M`%ML:6YE("5S(&]F("5S70!;;F\@=F%L=65=`%]!9&0`7T%D;6EN:7-T<F%T
M:6]N`%]"<F]W<V4`7T-,20!?1&%T851R964`7T1E;&5T90!?1&5L971E(%)O
M=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%]);7!O<G0O
M17AP;W)T`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I
M;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U)E;6]V92!F<F]M
M('1H:7,@;&ES=`!?4V5A<F-H`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN
M+@!?57-E<G,`861D<F5S<R!B;V]K`&%N(&5R<F]R(&AA<R!O8V-U<F5D.@!C
M86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`8V]N=&%C="YV8V8`8V]N=&%C=',N
M8W-V`&-O;G1A8W1S+G1S=@!D;VYE`&9A:6QE9`!F86QL:6YG`&9I;&4`9F]U
M;F0Z(`!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`
M:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D
M('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&-H86YG960`;F]T(&9O
M=6YD`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P
M860`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS
M,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!T87-K(&QI<W0`=&AE($AO<F1E
M(%!/(&9I;&4@9F]R('1H92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z`'1O
M(%-E;&5C=&5D($%D9')E<W,@0F]O:P!T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<&1A=&5D`'5S97(@<V5L
M96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@
M5'5R8F$@,BXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ,R`Q-SHQ
M,RLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#(M,C$@,3@Z,S$K,#`P
M,`I,87-T+51R86YS;&%T;W(Z($YU;F\@3&]U<F5I<F\@/&YU;F]`971H+G!T
M/@I,86YG=6%G92U496%M.B!0;W)T=6=U97-E(#QD979`;&ES=',N:&]R9&4N
M;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X+6)I=`H`("`M32P@+2UM97-S86=E/4U%3E-!1T5-(%5S87(@97-T
M82!M96YS86=E;2!D92!C;VUE=&EM96YT;R!E;2!V97H@9&$*("`@("`@("`@
M("`@("`@("`@("`@("`@(&UE;G-A9V5M('!O<B!O;6ES<^-O+@`@("UA+"`M
M+6%D9#U!4E%5259/("`@("!!9&EC:6]N87(@97-T92!A<G%U:79O(%!/(&%O
M(&-O;7#J;F1I;RX@571I;"!P87)A"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EN8VQU:7(@=6T@8V]M<.IN9&EO(&1E('5M(')A;6\@9&EF97)E;G1E(&YO
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;7#J;F1I;R!G97)A9&\N`"`@
M+6(L("TM8F%S93TO0T%-22`@0V%M:6YH;R!P87)A(&\@9&ER96-T\W)I;R!B
M87-E("A(;W)D92D@82!U<V%R+@`@("UC+"`M+6-O;7!E;F1I=6T]05)152`@
M26YT96=R87(@;F]V87,@=')A9'7G]65S(&$@97-T92!A<G%U:79O(&1E(&-O
M;7#J;F1I;PH@("`@("`@("`@("`@("`@("`@("`@("`@92!NXV\@86\@8V]M
M<.IN9&EO('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O(&YA"B`@("`@("`@
M("`@("`@("`@("`@("`@("!P87-T82!H;W)D92]P;RX`("`M8RP@+2UC;VUP
M96YD:75M/4%2454@(%5S87(@97-T92!A<G%U:79O(&1E(&-O;7#J;F1I;R!E
M;2!V97H@9&\@87)Q=6EV;PH@("`@("`@("`@("`@("`@("`@("`@("`@<&]R
M(&]M:7-SXV\@*&-O;7!E;F1I=6TN<&\@;F$@<&%S=&$@:&]R9&4O<&\N`"`@
M+60L("TM9&5B=6<@("`@("`@36]S=')A<B!M96YS86=E;G,@9&4@97)R;R!D
M;W,@8FENX7)I;W,@97AE8W5T861O<RX`("`M9"P@+2UD:7)E8W1O<GD]4$%3
M5$$@0W)I87(@=6T@8V]M<.IN9&EO(&YE<W1A('!A<W1A+@`@("UH+"`M+6AE
M;'`@("`@("`@($UO<W1R87(@97-T82!M96YS86=E;2!D92!A:G5D82X`("`M
M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S87(@87!E;F%S(&5S=&$@;&]C86QI
M>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V%R(&5S=&$@;&]C
M86QI>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@(%5S87(@97-T82!L
M;V-A;&EZ8>?C;RX`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-O;G-T<G5I
M<B!A<G%U:79O<R!-3R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;PH@("`@("`@
M("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$
M54Q/("`@($QI;7!A<B!A<G%U:79O<R!03R!A<&5N87,@<&%R82!E<W1E(&WS
M9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@
M+2UM;V1U;&4]3=-$54Q/("`@($-O;65T97(@87,@=')A9'7G]65S(&%P96YA
M<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H
M2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@0W)I87(@;R!A<G%U
M:79O(%!/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@
M("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@
M26YT96=R87(@87)Q=6EV;W,@4$\@87!E;F%S('!A<F$@97-T92!M\V1U;&\*
M("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN`"`@+6TL("TM;6]D
M=6QE/4W31%5,3R`@("!!8W1U86QI>F%R(&%R<75I=F]S(&1E(&%J=61A(&%P
M96YA<R!P87)A(&5S=&4*("`@("`@("`@("`@("`@("`@("`@("`@(&WS9'5L
M;R`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@06-T=6%L:7IA
M<B!A<&5N87,@97-T92!M\V1U;&\@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@($=E<F%R(&%R8VAI=F\@4$]4(&%P96YA<R!P87)A(&5S=&4@
M;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@("UN
M+"`M+6YO+6-O;7!E;F1I=6T@("`@3N-O(&EN=&5G<F%R(&YO=F%S('1R861U
MY_5E<R!N;R!C;VUPZFYD:6\N`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!.
MXV\@=7-A<B!U;2!C;VUPZFYD:6\N`"`@+7,L("TM<W1A=&ES=&EC<R`@("`@
M("!'=6%R9&%R(&5S=&%T[7-T:6-A<R!D92!T<F%D=>?C;R!N=6T@9FEC:&5I
M<F\@;&]C86PN`"`@+70L("TM=&5S="`@("`@("`@36]S=')A<B!O<R!P<F]G
M<F%M87,@82!E>&5C=71A<B!M87,@;N-O(&\@9F%Z97(N`"`@8VQE86YU<"`@
M("`@3&EM<&%R(&]F(&%R<75I=F]S(%!/(&1E(&5N=')A9&%S('!O<B!T<F%D
M=7II<B!O=2!O8G-O;&5T87,N`"`@8V]M;6ET("`@("`@0V]M971E<B!A<R!T
M<F%D=>?U97,@;F\@<V5R=FED;W(@0U93+@`@(&-O;6UI="UH96QP($-O;65T
M97(@87)Q=6EV;W,@9&4@86IU9&$@;F\@<V5R=FED;W(@0U93+@`@(&-O;7!E
M;F1I=6T@(%)E8V]N<W1R=6ER(&\@87)Q=6EV;R!D92!C;VUPZFYD:6\N($%T
M96[GXV\Z($\@;F]V;R!A<G%U:79O"B`@("`@("`@("`@("`@<V]B<F5P]64M
M<V4@86\@86YT:6=O+@`@(&5X=')A8W0@("`@($=E<F%R(&%R<75I=F]S(&UO
M9&5L;R!03R`H+G!O="DN`"`@:&5L<"`@("`@("`@36]S=')A<B!E<W1A(&UE
M;G-A9V5M(&1E(&%J=61A+@`@(&EN:70@("`@("`@($-R:6%R('5M(&]U(&UA
M:7,@87)Q=6EV;W,@4$\@<&%R82!U;6$@;F]V82!L;V-A;&EZ8>?C;RX*("`@
M("`@("`@("`@("!!=&5NY^-O.B!/<R!N;W9O<R!A<G%U:79O<R!S;W!R97#U
M96TM<V4@86]S(&%N=&EG;W,N`"`@;6%K92`@("`@("`@0V]N<W1R=6ER(&%R
M<75I=F]S(&)I;N%R:6]S($U/(&$@<&%R=&ER(&1O<R!A<G%U:79O<PH@("`@
M("`@("`@("`@(%!/(&5S<&5C:69I8V%D;W,N`"`@;6%K92UH96QP("`@36%R
M8V%R('1O9&%S(&%S(&5N=')A9&%S(&YO(&%R<75I=F\@6$U,(&1E(&%J=61A
M(&-O;6\@97-T86YD;PH@("`@("`@("`@("`@(&%C='5A;&EZ861A<R!E('!R
M97!A<F%R(&\@87)Q=6EV;R!P87)A(&$@<'+S>&EM82!E>&5C=>?C;PH@("`@
M("`@("`@("`@(&1E('5P9&%T92UH96QP+B!$979E+7-E(&5X96-U=&%R(&UA
M:V4M:&5L<"!$15!/25,@9&4*("`@("`@("`@("`@("!U<&1A=&4M:&5L<"!E
M(&1E(')E=F5R(&\@87)Q=6EV;R!D92!A:G5D82X`("!M97)G92`@("`@("!)
M;G1E9W)A<B!O(&%R<75I=F\@4$\@8V]R<F5N=&4@8V]M(&\@87)Q=6EV;R!M
M;V1E;&\@4$\@8V]R<F5N=&4N`"`@=7!D871E("`@("`@17AE8W5T87(@97AT
M<F%C="!E(&UE<F=E(&5M('-E<77J;F-I82X`("!U<&1A=&4M:&5L<"!%>'1R
M86ER('1O9&%S(&%S(&5N=')A9&%S(&YO=F%S(&4@;6]D:69I8V%D87,@9&\@
M87)Q=6EV;R!D90H@("`@("`@("`@("`@(&%J=61A(%A-3"!E;2!I;F=LZG,@
M92!I;G1E9W+A+6QA<R!C;VT@87,@97AI<W1E;G1E+@`@)B,Q-3$[("5S(&5S
M=.$@<')O;G1O('!A<F$@969E8W1U87(@87,@;W!E<F'G]65S(&1E(&UA;G5T
M96[GXV\@;6%R8V%D87,@86)A:7AO+@`@*"5S(&1I87,@871RX7,I`"`H0VAA
M=F4@9&4@86-E<W-O("5S*0`@*&1E;G1R;R!D92`E<R!D:6%S*0`@*&AO:F4I
M`"`H86UA;FCC*0`@*&]N=&5M*0`@8V]M(``B)7,B(&[C;R#I('5M82!E<V-O
M;&AA(';A;&ED82X`(B5S(B!NXV\@97-TX2!C;VYF:6=U<F%D;R!N;R!296=I
M<W1O(&1O($AO<F1E+@`B)7,B(')E<')E<V5N=&%D;W(@9&4@X7)V;W)E(&[C
M;R!E;F-O;G1R861O+@`B)7,B(&9O:2!A9&EC:6]N861O(&%O('-I<W1E;6$@
M9&4@9W)U<&]S+@`B)7,B)R!F;VD@861I8VEO;F%D;R!A;R!S:7-T96UA(&1E
M('!E<FUI<W/U97,N`"(E<R(@;N-O(&9O:2!C;W!I861O('!O<B!S97(@=6UA
M(&QI<W1A+@`B)7,B(&[C;R!F;VD@8W)I861O.B`E<RX`(B5S(B!NXV\@9F]I
M(&UO=FED;R!P;W(@<V5R('5M82!L:7-T82X`(E!R\W!R:6\@07!E;&ED;R(@
M*&4N9RXL($IO<^D@4VEL=F$I`")!<&5L:61O+"!0<O-P<FEO(B`H92YG+BP@
M4VEL=F$L($IO<^DI`"5D("5S(&4@)7,`)60@8GET97,@97-C<FET;W,`)60@
M9&4@)60@96YT<F%D82!M87)C861A<R!C;VUO(&%C='5A;&EZ861A<P!P<F5V
M:7/C;R!D92`E9"!D:6%S`"5S("T@3F]T:69I8V'GXV\`)7,@061M:6YI<W1R
M8>?C;P`E<R!);7!R97-SXV\@1&EG:71A;``E<R!+0@`E<R!/<&5R8>?U97,@
M9&4@36%N=71E;N?C;R`M($-O;F9I<FUAY^-O`$-O;F9I9W5R87(@)7,`)7,@
M4W5B<V-R979E<@`E<R!497)M;W,@9&\@06-O<F1O`"5S(&%D:6-I;VYA9&\N
M`"5S(&KA(&5X:7-T92X`)7,@96T@)7,@)7,`1FEC:&5I<F\@)7,@:6UP;W)T
M861O(&-O;2!S=6-E<W-O`&[C;R!S92!P;V1E(&5S8W)E=F5R(&5M("5S+@`E
M<R#I(&]B<FEG873S<FEO`"5S(&UI;G5T;W,`)7,@;N-O(&9O:2!E;F-O;G1R
M861O+@`E<R!NXV\@9F]I(&5N8V]N=')A9&\N($5X96-U=&%R("=T<F%N<VQA
M=&EO;B!E>'1R86-T)R!P<FEM96ER;RX`)7,@82`E<R!D92`E<P!#;VYT86-T
M;W,@9&4@)7,`0V%L96YDX7)I;R!D92`E<P!.;W1A<R!D92`E<P!487)E9F%S
M(&1E("5S`"5S.B`E<P`L(&-O;2!R86IA9&%S`"P@8V]M(')A:F%D87,@)7,@
M)7,`+"!V87)IX79E;"!D92`E<R!A("5S`"TM(&5S8V]L:&$@+2T`+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM`$9O<FUA=&\@9&4@,3(@:&]R87,@*$%-
M+U!-*0!&;W)M871O(&1E(#(T(&AO<F%S`#(T(&AO<F%S`#Q!;G1E<FEO<@!E
M=&EQ=65T82`\9V5T=&5X=#X@<&]R(&9E8VAA<B!N;R!F:6-H96ER;R`E<RX*
M06)R:6YD;R!A(&5T:7%U971A(&5N8V]N=')A9&$@;F$@;&EN:&$@)60N`,D@
M;F5C97-SX7)I;R!U;2!N879E9V%D;W(@<75E('-U<&]R=&4@:49R86UE<P!%
M<W1E(&)L;V-O(&5X:6=E('5M(&UE8V%N:7-M;R!U<V%N9&\@8F%S97,@9&4@
M9&%D;W,N`$]C;W)R974@=6T@97)R;R!F871A;`#)(&YE8V5S<^%R:6$@=6UA
M(&-H879E('#Z8FQI8V$@4$=0('!A<F$@96YC<FEP=&%R(&$@;65N<V%G96TN
M`,D@;F5C97-SX7)I82!U;6$@8VAA=F4@</IB;&EC82!01U`@<&%R82!V97)I
M9FEC87(@82!A<W-I;F%T=7)A(&1E('5M82!M96YS86=E;0!087)A(&1E8VEF
M<F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z
M8FQI8V$@4$=0+"!U;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@9G)A<V4M
M<&%S<V4N`%!A<F$@87-S:6YA<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R
M:6%S('5M82!C:&%V92!P^F)L:6-A(%!'4"P@=6UA(&-H879E('!R:79A9&$@
M4$=0(&4@=6UA(&9R87-E+7!A<W-E+@!087)A(&1E8VEF<F%R('5M82!M96YS
M86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%
M+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@9G)A<V4M<&%S<V4N
M`%!A<F$@87-S:6YA<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M
M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-
M24U%(&4@=6UA(&9R87-E+7!A<W-E+@#)(&YE8V5S<^%R:6$@=6UA(&-H879E
M('#Z8FQI8V$@4R]-24U%('!A<F$@96YC<FEP=&%R('5M82!M96YS86=E;2X`
M3OIV96YS(&1E(&UA;FCC`$-H=79I<V-O<R!D92!-86YHXP!#:'5V82!D92!M
M86YHXP!!9W5A8V5I<F]S(&1E(&UA;FCC`$YE=O5E<R!D92!M86YHXP!!32]0
M30!!4$D@240`06-E<F-A(&1E<W1E(&5D:71O<@!!8V5R8V$N+BX`4V]B<F4@
M;R!F;W)M=6SA<FEO(&1E('!R;V-U<F$`0F%S97,@86QI;FAA9&%S`$-E;G1R
M;W,@86QI;FAA9&]S`$%C97-S;R!N96=A9&\@86\@8W)I87(@<&%S=&$@5D93
M+@!!8V5S<V\@;F5G861O(&%O(&-R:6%R(&%R<75I=F\@5D93+@!086QA=G)A
M+5!A<W-E(&1A($-O;G1A`$-O;G1A(&-O;F=E;&%D82X`0V]N=&%B:6QI9&%D
M90!097-?<75I<V$@079A;N=A9&$`061I8VEO;F%R`$%D:6-I;VYA<B!'<G5P
M;R!&:6QH;P!!9&EC:6]N87(@4&5R;6ES<^-O($9I;&AA`$%C<F5S8V5N=&%R
M($%Q=6DZ`$%D9&EC:6]N87(@3F]V;R!'<G5P;P!!9&EC:6]N87(@3F]V82!0
M97)M:7-SXV\`061I8VEO;F%R('5M(&=R=7!O(&9I;&AO(&$@(B5S(@!!9&EC
M:6]N87(@=6UA('!E<FUI<W/C;R!F:6QH82!A("(E<R(`061I8VEO;F%R(&YO
M=F\@=71I;&EZ861O<CH`061I8VEO;F%R(&-O;'5N80!!9&EC:6]N87(@;F]V
M;W,@;65M8G)O<P!!9&EC:6]N87(@<&%R8V5I<F\`061I8VEO;F%R(&\@365N
M=2`E<R!C;VUO($)A<G)A($QA=&5R86P@36]Z:6QL80!!9&EC:6]N87(@80!!
M9&EC:6]N87(@86]S($-O;G1A8W1O<SH`061I8VEO;F%R(&%O<R!M975S(&-O
M;G1A8W1O<P!!9&EC:6]N87(@=71I;&EZ861O<@!!9&EC:6]N96D@(B5S(B!A
M;R!S:7-T96UA+"!M87,@;N-O('!U9&4@861I8VEO;F%R(&EN9F]R;6'GXV\@
M9&4@<W5B<V-R:>?C;R!A9&EC:6]N86PZ("5S+@!!9&EC:6]N96D@(B5S(B!A
M;R!S:7-T96UA+B!*X2!P;V1E(&5N=')A<BX`061I8VEO;F%N9&\@;F]V;W,@
M87)Q=6EV;W,@86\@<F5P;W-I=/-R:6\Z`$$@861IY^-O(&1E('5T:6QI>F%D
M;W)E<R!E<W3A(&1E<V%C=&EV861A+@!%;F1E<F7G;P!#;VYT86-T;W,`3&ES
M=&%G96T@9&]S($-O;G1A8W1O<P!#;VYT86-T;P!,:79R;R!D92!E;F1E<F7G
M;W,@<_,@<&]D92!S97(@;&ED;RX`3&EV<F\@9&4@96YD97)EYV]S('!U<F=A
M9&\@8V]M('-U8V5S<V\N`$%D;6EN:7-T<F%R("T@871R:6)U:7(@<&5R;6ES
M<_5E<R!A(&]U=')O<R!U=&EL:7IA9&]R97,`061M:6YI<W1R8>?C;P!!;OIN
M8VEO<P!097-Q=6ES82!!=F%NYV%D80!!9F5G86YI<W3C;P!!;&+B;FEA`$%R
M9^EL:6$`06QC=6YH80!!;&EN:&%R`$%L:6YH86UE;G1O.@!4=61O`%1O9&]S
M(&]S(%5T:6QI>F%D;W)E<R!!=71E;G1I8V%D;W,`5&]D;W,@;W,@1W)U<&]S
M`%1O9&%S(&%S(%!E<FUI<W/U97,`5&]D;W,@;W,@*'%U871R;RD@;&%D;W,`
M4&5R;6ET:7(@;?IL=&EP;&]S(&5N9&5R9>=O<P!097)M:71I<B!A=')I8G5I
MY^-O(&1O('1I<&\@9&4@;&ES=&%S(&]R9&5N861A<S\`2N$@17AI<W1E`$KA
M(&5X:7-T90!%;G1R861A($E-4U`@06QT97)N871I=F$`4&%L879R82U087-S
M92!)35-0($%L=&5R;F%T:79A`$YO;64@9&4@571I;&EZ861O<B!)35-0($%L
M=&5R;F%T:79O`$5N9&5R9>=O(&EN=N%L:61O`$UO9&5L;W,@86QT97)N871I
M=F]S`%1E>'1O(&%L=&5R;F%T:79O.@!386UO82!!;65R:6-A;F$`1F]I(&5S
M<&5C:69I8V%D;R!U;2!V86QO<B!I;G;A;&ED;RX`3V-O<G)E=2!U;2!E<G)O
M(&1E<V-O;FAE8VED;RX`06YD;W)R80!!;F=O;&$`06YG=6EL80!%;G1R97!O
M<W1O("AP<F]X>2D@06[S;FEM;P!297-P;W-T80!!;G3A<F-T:6-O`$%N=.UG
M=6$@92!"87)B=61A`$%P;&EC8>?C;P!!<&QI8V'GXV\@<')O;G1A+@!!<&QI
M8V%R(&$@4&%R=&EL:&%S($9I;&AA<P!!<')O=F%R`%1A;6%N:&\@07!R;WAI
M;6%D;P!!8G)I;`!!<N%B:6-O("A7:6YD;W=S+3$R-38I`%1A;6%N:&\@9&\@
M1FEC:&5I<F\@9&4@07)Q=6EV;P!.;VUE(&1O($%R<75I=F\`475E<B!M97-M
M;R!R96UO=F5R("5S/P!1=65R(&UE<VUO(')E;6]V97(@87,@96YT<F%D87,@
M<V5L96-C:6]N861A<S\`5&5M(&$@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R
M(&\@<&5D:61O(&1E('-U8G-C<FGGXV\@<&%R82`E<R`_`%1E;2!A(&-E<G1E
M>F$@<75E('%U97(@<F5M;W9E<B`B)7,B(&4@<75A:7-Q=65R('-U8BUG<G5P
M;W,_`$%R9V5N=&EN80!!<FWI;FEA`$%R;>EN:6\@*$%235-#24DM."D`07)T
M90!!<G5B80!#<F5S8V5N=&4`26QH82!D92!!<V-E;G/C;P!!<G1E($%30TE)
M`%)E9VGC;R#!<VEA+U!A8^UF:6-O`%!E9&ER(&-O;F9I<FUAY^-O(&%N=&5S
M(&1E(')E86QI>F%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O/P!#;VQU;F%S
M(&1E(&%T<FEB=6GGXV\`5&5N=&%T:79A(&1E(')E;6_GXV\@9&4@=6T@9W)U
M<&\@:6YE>&ES=&5N=&4N`%1E;G1A=&EV82!D92!R96UOY^-O(&1E('5M82!P
M97)M:7-SXV\@:6YE>&ES=&5N=&4N`%1E;G1A=&EV82!D92!E9&GGXV\@9&4@
M=6UA('!E<FUI<W/C;R!I;F5X:7-T96YT92X`5&5N=&%T:79A(&1E(&5D:>?C
M;R!D92!U;6$@<&%R=&EL:&$@:6YE>&ES=&5N=&4N`$%T<FEB=71O<P!!9V]S
M=&\`075S='+A;&EA`,%U<W1R:6$`075T:%]C>7)S<6PZ($$@97AT96YSXV\@
M:6UA<"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]C>7)U
M<SH@3R!M96-A;FES;6\@;N-O('1E;2!A<R!C87!A8VED861E<R!N96-E<W/A
M<FEA<RX`075T:%]C>7)U<SH@02!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@
M;N-O(&9O:2!E;F-O;G1R861A+@!!=71H7V9T<#H@02!E>'1E;G/C;R!&5%`@
M;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N($-O;7!I;&4@;R!02%`@
M8V]M(&$@;W#GXV\@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z($$@97AT96YS
MXV\@24U!4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]K
M<F(U.B!!(&5X=&5N<^-O(&MR8C4@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N
M=')A9&$N`$%U=&A?;&1A<#H@02!E>'1E;G/C;R!,1$%0(&YE8V5S<^%R:6$@
M;N-O(&9O:2!E;F-O;G1R861A+@!!=71H7VQD87`Z($EM<&]S<^UV96P@861I
M8VEO;F%R('5T:6QI>F%D;W(@)7,N($5I<R!O('%U92!O('-E<G9I9&]R(&1I
M<W-E.B``075T:%]L9&%P.B!);7!O<W/M=F5L(')E;6]V97(@;R!U=&EL:7IA
M9&]R("5S`$%U=&A?;&1A<#H@26UP;W-S[79E;"!A8W1U86QI>F%R(&\@=71I
M;&EZ861O<B`E<P!!=71H7VUC86PZ($$@97AT96YSXV\@34-!3"!N96-E<W/A
M<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]S;6)A=71H.B!!(&5X=&5N
M<^-O('-M8F%U=&@@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`$$@
M875T96YT:6-AY^-O(&9A;&AO=0!!(&%U=&5N=&EC8>?C;R!F86QH;W4N("5S
M`$$@875T96YT:6-AY^-O(&9O:2!R96IE:71A9&$@<&5L;R!S97)V:61O<B!2
M041)55,N`$$@875T96YT:6-AY^-O(&YO('-E<G9I9&]R($944"!F86QH;W4N
M`$-O;'5N87,@9&ES<&]N[79E:7,Z`$-A;7!O<R!D:7-P;V[M=F5I<SH`07IE
M<F)A:6KC;P!$97-C=6QP87,@(D)/1D@B`%]6;VQT87(@82`E<P!6;VQT87(@
M82`E<P!&=6YD;P!#;W(@9&\@1G5N9&\`4&%L879R82U087-S92!K97)B97)O
M<R!E<G)A9&$N`$YO;64@9&4@571I;&EZ861O<B!K97)B97)O<R!E<G)A9&\N
M`$)A86UA<P!"87+I;0!"X6QT:6-O("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5C
M:&4`0F%R8F%D;W,`3&EN:&$@8F%S90!0<F]C=7)A($+A<VE?8V$`4')O8W5R
M82!"X7-I8V$`0FEE;&]R<OIS<VEA`$+I;&=I8V$`0F5L:7IE`%-O8B!O(&9O
M<FUU;.%R:6\@9&4@<')O8W5R80!"96YI;0!"97)M=61A`$)U=.-O`$QI9V'G
MXV\@9F%L:&]U.B`H)7,I("5S`$%N:79E<G/A<FEO`$\@8FQO8V\@(B5S(B!D
M82!A<&QI8V'GXV\@(B5S(B!NXV\@9F]I(&5N8V]N=')A9&\N`$-O;F9I9W5R
M8>?U97,@9&4@0FQO8V]S`%1I<&\@9&4@0FQO8V\`3F5G<FET;P!";VSM=FEA
M`$UA<F-A9&]R97,`0F]R9&$`17-P97-S=7)A(&1A(&)O<F1A.@!";W)D87,`
M0O-S;FEA+4AE<GIE9V]V:6YA`$%M8F%S`$)O='-U86YA`$)A<V4`26QH82!"
M;W5V970`0G)A<VEL`%1E<G)I=/-R:6\@0G)I=.)N:6-O(&1O($]C96%N;R#-
M;F1I8V\`0G)U;F5I($1A<G5S<V%L86T`0V]N<W1R=6EN9&\@87)Q=6EV;W,@
M34\@<&%R82!O(&WS9'5L;R`E<RXN+@!#;VYS=')U:6YD;R!L;V-A;&EZ8>?C
M;R`E<RXN+B``0G5L9^%R:6$`3&ES="!)=&5M:7IA9&$`0G5R<75I;F$@1F%S
M;P!"=7+Z;F1I`$-A=&5G;W)I82!D92!.96?S8VEO`$--4P!#4D,`4&]N=&]S
M(&1E($1I<W1R:6)U:>?C;R!#4DP`0U-6`%!R;W!R:65D861E<R!D82AS*2!#
MZ5]L=6QA*',I+BXN`%],:6UP87(@4&5S<75I<V$`26YI8VEA;&EZ8>?C;R!D
M82`B8V%C:&4B(&[C;R!F;VD@8V]N8VQU[61A+@!#86QE;F3A<FEO`$-A;&UO
M`$-A;6)O9&IA`$-A;6%R]65S`$[C;R!P;W-S;R!R96EN:6-I87(@82!P86QA
M=G)A+7!A<W-E(&%U=&]M871I8V%M96YT92P@8V]N=&%C=&4@;R!S974@861M
M:6YI<W1R861O<B!D92!S:7-T96UA<RX`26UP;W-S[79E;"!C;VYE8W1A<B!A
M;R!S97)V:61O<B!)34%0.B`E<P!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@
M4F5L873S<FEO(&1E(%!R;V)L96UA<P!.XV\@8V]N<VEG;R!R96UO=F5R(&\@
M9FEC:&5I<F\@(B5S(BX`3N-O(&-O;G-I9V\@96YC;VYT<F%R('5M(&1I<F5C
M=/-R:6\@=&5M<&]RX7)I;RX`26UP;W-S[79E;"!C;VYT:6YU87(@<V5M(&\@
M<&%RXFUE=')O("=T87)G971&:6QE)RX`3N-O(&9O:2!P;W-S[79E;"!R96UO
M=F5R(&$@<&%S=&$@(B5S(BX`26UP;W-S[79E;"!R96UO=F5R+"!E>&ES=&5M
M("5D(&9I;&AO<RX`3N-O(.D@<&]S<^UV96P@<F5O<F1E;F%R.B!O(&[Z;65R
M;R!D92!E;G1R861A<R!F;W)N96-I9&%S(&[C;R!C;W)R97-P;VYD92!A;R!N
M^FUE<F\@9W5A<F1A9&\N`$[C;R!F;VD@<&]S<^UV96P@96YC86UI;FAA<B!A
M(&UE;G-A9V5M('!A<F$@;R!N^FUE<F\@:6YD:6-A9&\N`%)E</IB;&EC82!D
M92!#86)O(%9E<F1E`$QE9V5N9&$`0V%T96=O<FEA<R!E($-O<F5S`$EL:&%S
M($-A:6WC;P!496QE9F]N92!#96QU;&%R`%!R;W!R:65D861E<R!D87,@0^EL
M=6QA<P!%;F-H:6UE;G1O(&1A<R!#Z6QU;&%S.@!0<F]P<FEE9&%D97,@9&%S
M(&/I;'5L87,`17-P8>=A;65N=&\@9&%S(&/I;'5L87,Z`%1E;&5M\W9E;`!#
MZ6QT:6-O("A)4T\M.#@U.2TQ-"D`0V5N=')A<@!297#Z8FQI8V$@0V5N=')O
M($%F<FEC86YA`$5U<F]P82!#96YT<F%L("A)4T\M.#@U.2TR*0!0;W)M96YO
M<F5S(&1O($-E<G1I9FEC861O`$1O;F\@9&\@0V5R=&EF:6-A9&\`4&]L[71I
M8V%S(&1E($-E<G1I9FEC861O`%)E</IB;&EC82!D;R!#:&%D90!!;'1E<F%R
M`$%L=&5R92!O(&YO;64@92!E;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!V97+C
M;R!Q=6%N9&\@;&5R96T@92!R97-P;VYD97)E;2#@<R!S=6%S(&UE;G-A9V5N
M<RX`0V%R86-T97)E`%9E<FE?9FEC87(@3&EG8>?C;RXN+@!-87)C87(@7U1U
M9&\O3F%D80!-87)Q=64@87,@;W!E<F'G]65S('%U92!D97-E:F$@97AE8W5T
M87(@;F5S=&4@;6]M96YT;RX`4F5P^F)L:6-A(&1O($-H:6QE`%)E</IB;&EC
M82!0;W!U;&%R(&1A($-H:6YA`$-H:6[J<R!3:6UP;&EF:6-A9&]S("A'0C(S
M,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2D`17-C;VQH82!U;6$@<&%S
M=&$@<&]R(&]M:7-SXV\@<&%R82!O<R!S975S(&QI=G)O(&1E(&5N9&5R9>=O
M<R!P97-S;V%L+"!A<R!S=6%S(&QI<W1A<R!D92!C;VYT86-T;W,@92!A<R!S
M=6%S('!R;V-U<F%S+@!%<V-O;&AA(&$@<&%L879R82UP87-S90!%<V-O;&AA
M('5M($YO;64@9&4@571I;&EZ861O<@!%<V-O;&AA(&\@;&EV<F\@9&4@96YD
M97)EYV]S`$5S8V]L:&$@8V]M;R!M;W-T<F%R(&%S(&1A=&%S.@!%<V-O;&AA
M(&\@97-T:6QO(&1A<R!L:7-T82`H<&%R82!L:7-T87,@;W)D96YA9&%S*0!%
M<V-O;&AA(&$@;W)D96T@9&%S(&-O;'5N87,@82!M;W-T<F%R(&YA(&QI<W1A
M(&1E(&-O;G1A8W1O<RX`26QH82!D;R!.871A;`!.XV\@9F]I(&5N8V]N=')A
M9&$@82!D969I;FGGXV\@9&$@8VQA<W-E("5S+@!,:6UP86YD;R!O<R!A<G%U
M:79O<R!03R!D;R!M\V1U;&\@)7,N+BX`3&EM<&%N9&\@82!L;V-A;&EZ8>?C
M;R`E<RXN+B``3&EM<&%R`$QI;7!A<B!E=&EQ=65T87,@9&\@35-/9F9I8V4`
M3&EM<&%R(%!E<W%U:7-A`$QI;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R.B`E
M<P!,:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<@!,:6UP87(@9&%D;W,@9&\@
M=71I;&EZ861O<@!,:6UP82!487)D90!#;&EQ=64@<&%R82!#;VYT:6YU87(`
M0VQI8VMA=&5L;"!V:6$@2%144`!&96-H87(@:F%N96QA`$[Z=F5N<P!.^G9E
M;G,@36%T:6YA:7,`16YE=F]A9&\`26QH87,@0V]C;W,@*$ME96QI;F<I`$-O
M;&%P<V%R($)A<G)A($QA=&5R86P`0F]R9&%S($-O;&%P<V%D87,`4F5P^F)L
M:6-A(&1A($-O;/1M8FEA`$-O<F5S`%!A;&5T90!396QE8^?C;R!D92!C;W)E
M<@!#;VQU;F%S.@!/<.?U97,@9&4@0V]L=6YA`%3M='5L;W,@9&%S(&-O;'5N
M87,`0D0`5F%L;W)E<R!S97!A<F%D;W,@<&]R(';M<F=U;&%S`%9A;&]R97,@
M<V5P87)A9&]S('!O<B!V[7)G=6QA<R`H36EC<F]S;V9T($]U=&QO;VLI`$-O
M;6%N9&\`0V]N<V]L82!D92!#;VUA;F1O<P!/<.?U97,@9&\@8V]M86YD;SH`
M0V]M86YD;W,Z`$-O;65N=.%R:6\`0V]M971E;F1O`$YO;64@0V]M=6T`0V]M
M;W)O<P!%;7!R97-A`$UO<F%D82!N82!%;7!R97-A`$5S8W)E=F5R("@E<RD`
M0V]M<'5T861O<F5S`$-O;F1IY^-O`$-O;F1IY_5E<P!$:69E<F5NYV%S(&1E
M($-O;F9I9W5R8>?C;P!!(&-O;F9I9W5R8>?C;R!E<W3A(&1E<V%C='5A;&EZ
M861A`$-O;F9I9W5R87(@)7,`0V]N9FER;64@82!086QA=G)A+5!A<W-E`%)E
M</IB;&EC82!$96UO8W+A=&EC82!D;R!#;VYG;P!297#Z8FQI8V$@1&5M;V-R
MX71I8V$@9&\@0V]N9V\`0V]N97CC;R!F86QH;W4N`$-O;F5XXV\@9F%L:&]U
M.B``3&EG8>?C;R!F86QH;W4Z("5S`$9A;&AA(&1E(&QI9V'GXV\`0V]N97CC
M;R!A;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,@<F5C=7-A9&$N`$-O
M;F5XXV\@86\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S(')E8W5S861A
M+B!287KC;SH@)7,@*"5S*0!#;VYE>.-O(&%O('-E<G9I9&]R($944"!R96-U
M<V%D82X`0V]N=&%C=&\@<F5M;W9I9&\@9&$@;&ES=&$N`$-O;G1A8W1O<R!N
M82!L:7-T83H@)7,`0V]N=&%C=&]S(&%D:6-I;VYA9&]S(&-O;2!S=6-E<W-O
M(&%O('-E=2!L:79R;R!D92!E;F1E<F7G;W,N`%1I<&\@9&4@8V]N=&7Z9&\@
M9&\@87)Q=6EV;R!C;VUP<FEM:61O.B``0V]N=&7Z9&\@9&4@)7,`0V]N=&7Z
M9&\@9&4@)7,`0V]N=&EN=6%R`$EL:&%S($-O;VL`0F]L:6YH;R!C:&ENZG,`
M0V]P:6%R`$-O<&EA<B!S96QE8^?C;P!#;W!I86YD;R!D92`E<R!P87)A("5S
M`%)E</IB;&EC82!D82!#;W-T82!2:6-A`%)E</IB;&EC82!D82!#;W-T82!D
M;R!-87)F:6T`3N-O(&9O:2!P;W-S[79E;"!E;F-R:7!T87(@82!M96YS86=E
M;2!C;VT@4$=0+@!.XV\@9F]I('!O<W/M=F5L(&%S<VEN87(@82!M96YS86=E
M;2!C;VT@4$=0+@!.XV\@9F]I('!O<W/M=F5L(&5N8W)I<&%R(&$@;65N<V%G
M96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A<W-I;F%R(&$@;65N
M<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A9&EC:6]N87(@
M;R!C;VYT86-T;RX@)7,`1F%L:&$@;F$@;&EG8>?C;R`H8FEN9"D@86\@<V5R
M=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!V97)I9FEC87(@;R!S86QD
M;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B`B
M)7,B('5S86YD;R!&5%`Z("5S`$[C;R!F;VD@<&]S<^UV96P@8V]P:6%R("5S
M('!A<F$@)7,`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!L:7-T82!D92!D:7-T
M<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@<&%S=&$@9&4@
M;&]C86QI>F'GXV\@<&%R82!A(&QO8V%L:7IAY^-O("5S.@!.XV\@9F]I('!O
M<W/M=F5L(&1E<V5N8W)I<'1A<B!O<R!D861O<R!C;VT@;R!01U`N`$[C;R!F
M;VD@<&]S<^UV96P@9&5S96YC<FEP=&%R(&]S(&1A9&]S(&-O;2!3+TU)344N
M`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!C;VYT86-T;RX@)7,`3N-O(&9O
M:2!P;W-S[79E;"!R96UO=F5R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`
M3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@(G-C<FEP="(@9&4@86-T=6%L
M:7IAY^-O("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@9&5T97)M:6YA<B!O(&5N
M9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@9&\@9&5S=&EN873A<FEO
M+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@;&EV<F\@9&4@96YD97)EYV]S
M(&-O;7!L971O+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O(&-O;7!L971A+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R
M(&$@;&ES=&$@8V]M<&QE=&$@9&%S(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N
M`$EM<&]S<^UV96P@8V%R<F5G87(@97-T<F%TZ6=I82`B)7,B+@!);7!O<W/M
M=F5L(&UK9&ER("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!C:&%V
M92!P^F)L:6-A(&$@<&%R=&ER(&1O('-E<G9I9&]R(&1E(&-H879E<R!P^F)L
M:6-A<RX`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B`B)7,B('!A<F$@97-C<FET
M82X`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B`E<RX`3N-O(&9O:2!P;W-S[79E
M;"!A8G)I<B!O(&WS9'5L;R!D92!-86YU=&5NY^-O(&1E(%1A<F5F87,@)7,`
M3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!P87-T82`B)7,B+@!.XV\@9F]I('!O
M<W/M=F5L(&QE<B`E<RX`3N-O(&9O:2!P;W-S[79E;"!R96EN:6-I87(@82!P
M86QA=G)A+7!A<W-E(&1O('5T:6QI>F%D;W(@:6YD:6-A9&\N($%L9W5M(&]U
M('1O9&]S(&]S('!O<FUE;F]R97,@;N-O(&5S=&%V86T@8V]R<F5C=&]S+B!0
M;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!O=2!C;VYT86-T92!O('-E=2!A9&UI
M;FES=')A9&]R(&1E('-I<W1E;6%S('-E('!R96-I<V%R(&1E(&UA:7,@86IU
M9&$N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@04-,`$[C;R!F;VD@<&]S<^UV
M96P@;V)T97(@;&EV<F\@9&4@96YD97)EYV]S+B`E<P!.XV\@9F]I('!O<W/M
M=F5L(&]B=&5R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!L:7-T87,@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@
M9F]I('!O<W/M=F5L(&]B=&5R(&%S(&-O;7!E=.IN8VEA<R!D;R!S97)V:61O
M<@!.XV\@9F]I('!O<W/M=F5L(')E=F5R=&5R(&$@8V]N9FEG=7)AY^-O+@!)
M;7!O<W/M=F5L(')M9&ER("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A
M<B!A(&-O;F9I9W5R8>?C;R!D92`E<RX`3N-O(&9O:2!P;W-S[79E;"!G=6%R
M9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A+@!.XV\@9F]I('!O
M<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R9&$Z
M("5S`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!O(")S8W)I<'0B(&1E(&%C
M='5A;&EZ8>?C;R!E;3H@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R
M(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A("5S+@!.XV\@9F]I('!O
M<W/M=F5L(&=U87)D87(@;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX@
M4&]D92!U<V%R('5M82!D87,@;W#G]65S('!A<F$@9W5A<F1A<B!O(&/S9&EG
M;R!E;2`E<R!O=2!C;W!I87(@;6%N=6%L;65N=&4@;R!C\V1I9V\@86)A:7AO
M('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV96P@<')O8W5R87(@;F\@<V5R=FED
M;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!D97-L:6=A<B`B)7,B+@!.XV\@
M9F]I('!O<W/M=F5L(&%C='5A;&EZ87(@8V]N=&%C=&\N("5S`$[C;R!F;VD@
M<&]S<^UV96P@86-T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@
M)7,`3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!A(&-O;F9I9W5R8>?C;R!P
M87)A("(E<R(Z("5S`$[C;R!E;F-O;G1R96D@82!"87)R82!,871E<F%L(&1O
M($UO>FEL;&$N($%S<V5G=7)E+7-E('%U92!A(&)A<G)A(&QA=&5R86P@97-T
MX2!A8F5R=&$N`$[C;R!F;VD@<&]S<^UV96P@871R:6)U:7(@86\@=71I;&EZ
M861O<B`B)7,B(&]S('-E9W5I;G1E<R!D:7)E:71O<R!S;V)R92!A('!A<W1A
M("(E<R(Z("5S`%1E>'1O($-O;G1A9&\`4&'M<P!#=7)S;W,`0W)I87(`0W)I
M87(@=6UA(&QI9V'GXV\`0W)I87(@=6UA(&YO=F$`0W)I87(@<W5B+7!A<W1A
M<P!#<FEA9&\`4&5R;6ES<_5E<R!D;R!#<FEA9&]R`$[Z;65R;R!D;R!C87)T
MXV\@9&4@8W+I9&ET;P!297#Z8FQI8V$@9&$@0W)OX6-I80!297#Z8FQI8V$@
M9&4@0W5B80!1=6%T<F\@9F%S97,@8V]R<F5N=&5S`$1A=&$O2&]R80!54DP@
M8V]R<F5N=&4@Z0!%<W1A9&\@9&\@5&5M<&\`4VET=6'GXV\@86-T=6%L.B``
M17-T:6QO(&%C='5A;`!097)S;VYA;&EZ87(@87,@=&%R969A<R!Q=64@<V5R
MXV\@97AE8W5T861A<R!A<75A;F1O(&\@;&]G:6X@;F\@)7,N`$-O<G1A<@!#
M;W)T87(@82!S96QE8^?C;P!297#Z8FQI8V$@9&4@0VAI<')E`$-I<NUL:6-O
M("A+3TDX+5(I`$-I<NUL:6-O("A7:6YD;W=S+3$R-38I`$-I<NUL:6-O+U5C
M<F%N:6%N;R`H2T])."U5*0!297#Z8FQI8V$@0VAE8V$`1$0`1&EA<FEA;65N
M=&4`3F%V96=A9&]R(&1E(,%R=F]R92!D92!$861O<P!$871A`$1A=&$@9&4@
M4F5C97#GXV\`4V5L96/GXV\@9&4@9&%T80!$:6$`4F5M;W9E<B!#;U]L=6YA
M`$1E>F5M8G)O`$[Z;65R;W,@9&5C:6UA:7,`4F5D=7II<B!I;F1E;G1AY^-O
M`%!O<B!/;6ES<^-O`$-O<B!0;W(@3VUI<W/C;P!6:7-U86QI>F'GXV\@<&]R
M($]M:7-SXV\`261E;G1I9&%D92!0861RXV\`4&5R;6ES<_5E<R!0;W(@3VUI
M<W/C;P!087-T82!P;W(@;VUI<W/C;R!P87)A(&\@<V5U(&QI=G)O(&1E(&5N
M9&5R9>=O<R!P97-S;V%L+"!A<R!S=6%S(&QI<W1A<R!D92!C;VYT86-T;W,@
M92!A<R!S=6%S('!R;V-U<F%S+@!097)M:7-S]65S('!O<B!O;6ES<^-O`$1I
M<F5CY^-O(&1E(&]R9&5N8>?C;R!P;W(@;VUI<W/C;SH`1&5F:6YIY_5E<P!2
M96UO=F5R`$-O;F9I<FUAY^-O(&1E(%)E;6_GXV\`4F5M;W9E<B!'<G5P;P!2
M96UO=F5R(%!E<FUI<W/C;P!296UO=F5R(&4@<'5R9V%R(&UE;G-A9V5N<P!#
M;VUP;W)T86UE;G1O(&1O(&)U=.-O(")D96QE=&4B`%)E;6]V97(@8^EL=6QA
M`%)E;6]V97(@8V]L=6YA`%)E;6]V97(@;6]D96QO(&%L=&5R;F%T:79O(&5X
M:7-T96YT90!296UOY^-O(&9A;&AO=3H@*"5S*2`E<P!296UO=F5R('!E<FUI
M<W/U97,@9&4@(B5S(@!296UO=F5R('!E<FUI<W/U97,@<&%R82`G)7,G(&4@
M<75A:7-Q=65R('-U8BUP97)M:7-S]65S/P!296UO=F5R(&QI;FAA`%)E;6]V
M97(@:61E;G1I9&%D92!S96QE8V-I;VYA9&$`4F5M;W9E<B!A(&-O;'5N82!C
M;W)R96YT90!296UO=F5R(&$@;&EN:&$@8V]R<F5N=&4`4F5M;W9E<B!E<W1A
M('!E<FUI<W/C;R!E('1O9&%S(&%S('-U87,@<W5B+7!E<FUI<W/U97,_`")3
M8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R`B)7,B(')E;6]V:61O+@!296UOY^-O
M(&9A;&AO=0!-;VUE;G1O(&1E(&5N=')E9V$`1&EN86UA<F-A`$1E<&%R=&%M
M96YT;P!$96-R97-C96YT90!$97-C<F5V82!O(%!R;V)L96UA`$1E<V-R:>?C
M;P!0;W)M96YO<F5S("AT86UBZ6T@;F\@<F5G:7-T;RP@(FQO9R(L(&1O($AO
M<F1E*3H`3W,@9&5T86QH97,@9F]R86T@96YV:6%D;W,@<&%R82!O(&%D;6EN
M:7-T<F%D;W(@9&\@<VES=&5M82X`1&5S96YV;VQV:6UE;G1O`%!O;G1O(&1E
M($]R=F%L:&\`4&]N=&\@9&4@3W)V86QH;R!N82#Z;'1I;6$@:&]R83H@`%!O
M;G1O(&1E(&]R=F%L:&\Z(`!$:7)E8^?C;R!D82!E<W%U97)D82!P87)A(&$@
M9&ER96ET80!$:7)E8^?C;R!D82!D:7)E:71A('!A<F$@82!E<W%U97)D80!$
M:7)E8W3S<FEO`$UO<W1R87(@=&5M<&]S(&-O;2`R-"!H;W)A<S\`3W#G]65S
M(&1E(%9I<W5A;&EZ8>?C;P!-;W-T<F%R('!R979I<^-O('!O<FUE;F]R:7IA
M9&$`36]S=')A<B!P<F5V:7/C;R`H5$%&*0!&;W)M871O(&1E('9I<W5A;&EZ
M8>?C;P!.;W1I9FEC8>?C;R!D92!$:7-P;W-IY^-O`$1J:6)U=&D`3N-O(')E
M;6]V97(`3N-O('5T:6QI>F4@;R!M86EN=&5N86YC92YP:'`@9&ER96-T86UE
M;G1E`$1E<V5J82!C;VYF:7)M87(@82!R96UOY^-O(&1E(&5N=')A9&%S/P!!
M('!R:6UE:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S/R!3
M92!S:6TL(&%S<VEN86QA<B!E<W1A(&-A:7AA.@!$;VUI;FEC80!297#Z8FQI
M8V$@1&]M:6YI8V%N80!296-E8F5R`%)E8V5B97(@)7,`1&5S8V%R<F5G87(@
M82!C;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@(G-C<FEP="(@4$A0+@!$
M97-C87)R96=A<B!V0V%R9`!,:7-T82!D92!D97-E;G)O;&%R`$1R;V=A<P!#
M;W)R96EO(&5L96-T<O-N:6-O`$524@!297#Z8FQI8V$@9&\@17%U861O<@!%
M9&ET87(`161I=&%R("(E<R(`161I=&%R($)L;V-O`$5D:71A<B!'<G5P;P!%
M9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@<&5R
M;6ES<_5E<R!D92`E<P!%9&ET87(@96YT<F%D82!D92`E<P!%9&ET87(@;W#G
M]65S(&1E.@!%9&ET87(@<&5R;6ES<_5E<R!D92`B)7,B`$5D:71A<B!P97)M
M:7-S]65S(&1E("5S`$5D=6-AY^-O`$5G:7!T;P!297#Z8FQI8V$@9&4@16P@
M4V%L=F%D;W(`16QE;65N=&\N+BX`16T`0V]R<F5I;R!%;&5C='+S;FEC;P!%
M;F1E<F7G;R!D92!#;W)R96EO($5L96-T<O-N:6-O`$]S(&5N9&5R9>=O<R!T
MZFT@<75E(&-O:6YC:61I<BX`365N<V%G96T@8V]M(&-O;F9I<FUAY^-O`%/M
M;6)O;&]S(&1E($5M;^?C;P!-96YS86=E;2!V87II82X`4V5M(')E<W5L=&%D
M;W,N`%-E;2!T97)M;W,@9&4@<')O8W5R80!!8W1I=F%R(&EN<V5RY^-O(&1E
M(&EM86=E;G,@9&4@1V%L97)I87,@1F]T;V=RX69I8V%S(&YO('1E>'1O/P!!
M8W1I=F%R(&UE;G4@9&4@8V]N=&5X=&\@;F\@8F]TXV\@9&ER96ET;R!D;R!R
M871O/P!!;F\@9&4@9FEM`$%U;65N=&%R($5D:71O<@!);G1R;V1U>F$@=6UA
M('!E<F=U;G1A(&1E('-E9W5R86[G82!Q=64@<V5RX2!C;VYV:61A9&\@82!R
M97-P;VYD97(@<V4@<')E8VES87(@9&4@<F5I;FEC:6%R(&$@<W5A('!A;&%V
M<F$M<&%S<V4L(&4N9RXL("=C;VUO('-E(&-H86UA(&\@<V5U(&%N:6UA;"!D
M92!E<W1I;6'GXV\_)SH`26YT<F]D=7IA(&\@55),(&1A(&EM86=E;2!A<75I
M`$5N=')A9&%S.B`E9"!T;W1A;"P@)60@86-T=6%L:7IA9&%S+"`E9"!N;W9A
M<RP@)60@86QT97)A9&%S+"`E9"!D97-C;VYH96-I9&%S`$5N=')A9&$@9&4@
M)7,@86-T=6%L:7IA9&$N`$=U:6[I($5Q=6%T;W)I86P`17-T861O(&1A($5R
M:71R96EA`$5R<F\`17)R;R!N82!M96YS86=E;2!D92!C;W)R96EO(&5L96-T
M<O-N:6-O+@!%<G)O(&%O(&5S8W)E=F5R("(E<R(N`$5R<F\Z(`!297#Z8FQI
M8V$@9&$@17-T\VYI80!297#Z8FQI8V$@1&5M;V-RX71I8V$@1F5D97)A;"!D
M82!%=&GS<&EA`,ET:6-O`$5U<F]P80!#861A(#$U(&UI;G5T;W,`0V%D82`R
M(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@;6EN=71O<P!#861A
M($5N=')A9&$`0V%D82!M96EA(&AO<F$`0V%D82!M:6YU=&\`5F%L;W)E<R!E
M>&5M<&QO.@!%>&5C=71A<@!%>&5C=71A;F1O.@!%>'!A;F1I<@!-;W-T<F%R
M($)A<G)A($QA=&5R86P`)RDG(&5S<&5R861O`$5S<&5R879A('5M82!S:6UP
M;&5S('!A;&%V<F$@;W4@=6T@=&5R;6\@9&4@<')O8W5R82!E;G1R92!A<W!A
M<P!$871A(&1E($5X<&ER8>?C;P!%>'!O96YT90!%>'!O<G1A<@!%>'!O<G1A
M<B!,:79R;R!D92!%;F1E<F7G;W,`17AP;W)T87(@87!E;F%S(&]S(&-O;G1A
M8W1O<R!S96QE8V-I;VYA9&]S`$5X<&]R=&%R(&YA(.UN=&5G<F%R(&\@;&EV
M<F\@9&4@96YD97)EYV]S('%U92!S92!S96=U92X`17AT<F%I;F1O(&1E("5S
M+BXN(`!#;W(@9&\@4')I;65I<F\@4&QA;F\`0V%R<F5G87(@8V]N9FEG=7)A
MY^-O(&1E(&EN<W1A;&'GXV\@<&]R($944`!.XV\@9F]I('!O<W/M=F5L('!U
M>&%R(&%S('!R969E<NIN8VEA<RX`1F%L:&]U(&%C97-S;R!A;R!L:79R;R!D
M92!E;F1E<F7G;W,Z("5S`$9A;&AO=2!A9&GGXV\@9&4@)7,@82`E<SH@)7,`
M1F%L:&]U(&YA=F5G8>?C;R!D82!L:7-T80!&86QH;W4@;F%V96=AY^-O(&1O
M(&1I<F5C=/-R:6\`1F%L:&]U(&$@;75D86[G82!D;R!N;VUE.B`H)7,I("5S
M.R!/;&0@1$X@/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@/2`E<P!&86QH82!N
M82!L:6=AY^-O(&%O('-E<G9I9&]R($Q$05`N`$9A;&AA(&YA(&QI9V'GXV\@
M86\@<V5R=FED;W(@4TU"+@!&86QH82!A;R!C;W!I87(@9&4@(B5S(BX`1F%L
M:&$@86\@8V]P:6%R('!A<F$@(B5S(BX`1F%L:&$@86\@8W)I87(@=6UA(&YO
M=F$@8V]N97CC;R!305-,+@!0<F]C=7)A(&1O(&]B:F5C=&\@82!A9&EC:6]N
M87(@9F%L:&]U.B`E<P!&86QH82!A;R!M;W9E<B!P87)A("(E<R(N`%!E<W%U
M:7-A(&YO(&1I<F5C=/-R:6\@9F%L:&]U.B`E<P!";VT`26QH87,@1F%L:VQA
M;F0@*$UA;'9I;F%S*0!);&AA<R!&87)O90!%<G)O($9A=&%L.@!&87@`1F5V
M97)E:7)O`$%P87)E;G1A`$%P87)E;G1A.B``06QG=6YS($%G=6%C96ER;W,`
M06QG=6YS($YE=O5E<P!-871R:7H@9&4@8V%M<&]S`$9I:FD`0V]N=&%G96T@
M9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\`0V]N=&%G96T@9&4@07)Q=6EV;W,Z
M("5S(&%R<75I=F]S`$=E<W3C;R!D92!&:6-H96ER;W,`3F]M92!D;R!!<G%U
M:79O`%-E;&5CY^-O(&1O(&%R<75I=F\`0V%R<F5G86UE;G1O(&1E(&%R<75I
M=F\`0V%R<F5G86UE;G1O<R!D92!F:6-H96ER;W,@;N-O('/C;R!S=7!O<G1A
M9&]S+@!&:6QT<F]S`%!R;V-U<F%R`$9I;FSB;F1I80!1=6%R=&\@0W)E<V-E
M;G1E`$YO;64@4'+S<')I;P!1=6%R=&\@0W)E<V-E;G1E`$9I>&%R('+A8VEO
M`$EN=F5R=&5R`$9L=71U86YT90!.979O96ER;P!!('!A<W1A("5S(&[C;R!E
M>&ES=&4N`$-O<B!D;R!497AT;P!#;VUI9&$`4&%R82!N879E9V%D;W)E<R!Q
M=64@;N-O('-U<&]R=&%M(&EM86=E;G,`4')E=FESXV\@*%1!1BD`1&EA<R!D
M92!0<F5V:7/C;R`H;F]T92US92!Q=64@87,@<')E=FES]65S(&EN8VQU96T@
M=&%N=&\@9&EA<R!C;VUO(&YO:71E<SL@=6T@=F%L;W(@9&5M87-I861O(&=R
M86YD92!P;V1E(')E<W5L=&%R(&YU;2!B;&]C;R!M=6ET;R!L87)G;RD`17-Q
M=65C974M<V4@9&$@<&%L879R82UP87-S93\`36]D96QO<P!$:71O<P!4:7!O
M(&1E(&1I=&]S`$1I=&]S`$1I=&]S(#(`1O-R=6YS`%)E96YV:6]S`$%P;&EC
M8>?U97,@*&WS9'5L;W,I(&5N8V]N=')A9&%S.B`E<P!087-T87,@96YC;VYT
M<F%D87,Z`#:J`$UO;&1U<F%S`%)E</IB;&EC82!&<F%N8V5S80!&<F%NYV$L
M($UE=')O<&]L:71A;F$`55),(&1E(&QI=G)E+V]C=7!A9&\`1W5I86YA($9R
M86YC97-A`%!O;&ENZ7-I82!&<F%N8V5S80!497)R87,@075S=')A:7,@92!!
M;G3A<F-T:6-A<R!&<F%N8V5S87,`1&4`1&4@`$1E<V-R:>?C;R!#;VUP;&5T
M80!,=6$@0VAE:6$`3F]M92!#;VUP;&5T;P!$:69U<V%S`%)E</IB;&EC82!'
M86)O;F5S80!'86QE<FEA(&1E(&]N9&4@<F5T:7)A<B!A(&EM86=E;0!'86QE
M<FEA.@!297#Z8FQI8V$@9&$@1^)M8FEA`$=E<F%R($-O;F9I9W5R8>?C;R`E
M<P!#\V1I9V\@1V5R861O`$=E<F%N9&\@;R!E<W1A9&\@9&\@;?-D=6QO("5S
M+BXN`$=E\W)G:6$`4F5P^F)L:6-A($9E9&5R86P@9&$@06QE;6%N:&$`17)R
M;R!E;2!G971O<'0Z`%)E</IB;&EC82!D;R!'86YA`$=I8G)A;'1A<@!.;VUE
M(%!R\W!R:6\`3&ES=&$@9&4@16YD97)EYV]S($=L;V)A;`!)<@!']F1E;`!0
M97-Q=6ES82!';V]G;&4`3NUV96ES(&1E(&-I;GIE;G1O`$=RZ6-I80!'<F5G
M;R`H25-/+3@X-3DM-RD`1W)O;F5LXFYD:6$`1W)A;F%D80!'<G5P;P!!9&UI
M;FES=')AY^-O(&1E($=R=7!O<P!.;VUE<R!D92!G<G5P;W,@;N-O('!O9&5M
M(&5S=&%R('9A>FEO<P!097)M:7-S]65S(&1E(&=R=7!O`$=R=7!O<P!'=6%D
M86QU<&4`1W5A;0!297#Z8FQI8V$@9&$@1W5A=&5M86QA`$=U97)N<V5Y`%!E
M<FUI<W/U97,@9&%S(%9I<VET87,`4&5R;6ES<_5E<R!D87,@5FES:71A<P!,
M:79R;R!D92!6:7-I=&%S`$=U:6[I`$=U:6[I+4)I<W-A=0!297#Z8FQI8V$@
M0V\M;W!E<F%T:79A(&1A($=U:6%N80!(5$U,`$\@2%1-3$%R96$@<F5C=7-A
M+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@82#Z;'1I;6$@8^EL=6QA(&1A
M(&QI;FAA+@!/($A434Q!<F5A(')E8W5S82US92!C;V)A<F1E;65N=&4@82!R
M96UO=F5R(&$@^FQT:6UA(&-O;'5N82!D82!T86)E;&$N`$\@2%1-3$%R96$@
M<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@82#Z;'1I;6$@;&EN
M:&$@9&$@=&%B96QA+@!!=71E;G1I8V'GXV\@2%104"!NXV\@9F]I(&5N8V]N
M=')A9&$N`%)E</IB;&EC82!D;R!(86ET:0!!;&=O<FET;6\@9&4@(DAA<V@B
M`$YE8FQI;F$`0V%B9>=A;&AO`$EL:&%S($AE87)D(&4@36-$;VYA;&0`5&5M
M<&]R86PM5"!&;W)T90!(96)R974@*$E33RTX.#4Y+3@M22D`06QT=7)A`$%J
M=61A`$%J=61A('-O8G)E(&\@961I=&]R`$%J=61A`$%P;&EC8>?C;R!A=7AI
M;&EA<B!P87)A(&-R:6%R(&4@;6%N=&5R('1R861UY_5E<R!D82!P;&%T869O
M<FUA"DAO<F1E(&4@9&%S('-U87,@87!L:6-AY_5E<R`H;?-D=6QO<RDN"E!A
M<F$@=6UA(&EN=')O9'7GXV\@;&5R(&\@9FEC:&5I<F\@4D5!1$U%(&YE<W1A
M('!A<W1A+@!(96UI<V;I<FEO`$%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A<G%U
M:79O.@!!;'1A`$YO;65S(&1A<R!E;G1R861A<R!H:7-T\W)I87,@;N-O('!O
M9&5M(&5S=&%R('9A>FEO<P!#85]S80!%<W1A9&\@9&$@0VED861E(&1O(%9A
M=&EC86YO`$-A<V$`36]R861A(&1E($-A<V$`0VED861E(&1E($-A<V$`4&'M
M<R!D92!#87-A`%1E;&5F;VYE:2!D92!#87-A`$/S9&EG;R!0;W-T86P@9&4@
M0V%S80!%<W1A9&\O4')O=NUN8VEA(&1E($-A<V$`4G5A(&1E($-A<V$`4F5P
M^F)L:6-A(&1A<R!(;VYD=7)A<P!(;VYG=65C;VYG=64`2&]R9&4`1V5R861O
M<B!D92!T<F%D=>?U97,@2&]R9&4`2&]R9&4O2V]L86(Z($1A9&]S(%A-3"`E
M<R!I;G;A;&ED;W,@;F$@;65N<V%G96T@)7,`2&]R9&4O2V]L86(Z($YE;FAU
M;6$@;65N<V%G96T@8V]R<F5S<&]N9&4@86\@;V)J96-T;R`E<P!(;W)D92]+
M;VQA8CH@3F5N:'5M(&]B:F5C=&\@9&\@=&EP;R`E<R!E;F-O;G1R861O(&YA
M(&UE;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!296UOY^-O(&1E("5S("(E<R(@
M=&5V92!S=6-E<W-O`$AO<F1E+TMO;&%B.B!3:6YC<F]N:7IAY^-O(&1E("5S
M("(E<R(@=&5V92!S=6-E<W-O`$AO<F1E+TMO;&%B.B!/(&UO=&]R(&1E(&EN
M=&5G<F'GXV\@<F5Q=65R(&$@97AT96YSXV\@4$A0("=D;VUX;6PG`$AO<F1E
M+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L(&-R:6%R('5M82!N;W9A(.%R=F]R
M97,@6$U,('!A<F$@;R!O8FIE8W1O("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I
M('!O<W/M=F5L(')E;6]V97(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($[C
M;R!F;VD@<&]S<^UV96P@;V)T97(@;R!)1"!-24U%('!A<F$@82!P87)T92!D
M92!T:7!O("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L('-I;F-R
M;VYI>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M
M=F5L('-I;F-R;VYI>F%R('!A<G1I;&AA<SH@)7,`2&]R9&4O2V]L86(Z(%!A
M<G1I;&AA("(E<R(@9&5S8V]N:&5C:61A`%1R8>=O($AO<FEZ;VYT86P`16YC
M:&EM96YT;R!H;W)I>F]N=&%L`$AO<FEZ;VYT86PZ`$-O;6\@8VAE9V]U(&%Q
M=6D_("A0;W(@9F%V;W(@<F5P;W)T92UO(2D`475A;G1A<R!C;VQU;F%S('!R
M971E;F1E(&IU;G1A<C\`475A;G1O<R!C86UP;W,@*&-O;'5N87,I(&5X:7-T
M96T_`%%U86YT87,@;&EN:&%S('!R971E;F1E(&IU;G1A<C\`2'5M:61A9&4`
M2'5M:61A9&4Z(`!(=6UO<FES=&%S`%)E</IB;&EC82!D82!(=6YG<FEA`$$@
M8W)I8>?C;R!D82!C86EX82!P;W-T86P@24U!4"!F86QH;W4Z("5S`%)E;6_G
MXV\@9&$@8V%I>&$@<&]S=&%L($E-05`@9F%L:&]U.B`E<P!#<FEAY^-O(&1E
M('%U;W1A(&1E(&-A:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,`24U34`!%
M;F1E<F7G;R!)4`!%;F1E<F7G;R!)4"!I;F1I<W!O;NUV96PN`$5N9&5R9>=O
M($E0(&9O<F$@9&\@8FQO8V\@0TE$4B!P97)M:71I9&\N`%9I;VQAY^-O(&1E
M(&)L;W%U96EO(&1E($E0`$E?;G-E<FER($QI;FAA($%N=&5S`%)E</IB;&EC
M82!D82!)<VSB;F1I`$%P96YA<R#-8V]N97,`S6-O;F5S(&-O;2!497AT;P!.
M;VUE(&1A(&ED96YT:61A9&4Z`%-E(&[C;R!F;W(@;6]S=')A9&\@8V]R<F5C
M=&%M96YT92P@)7,@<&%R82!O(&%B<FER(&YU;6$@;F]V82!J86YE;&$N`%-E
M(&[C;R!V:7(@<75A;'%U97(@[6-O;F4@86\@=7-A<B!O($EN=&5R;F5T($5X
M<&QO<F5R+"!P;V1E('!R96-I<V%R(&1E('-E;&5C8VEO;F%R(&5S=&$@8V%I
M>&$@<&%R82!D97-L:6=A<B!A('1R86YS<&%RZFYC:6$N`%-E('9I<B!E<W1A
M(&UE;G-A9V5M(&YM87,@;N-O(&$@:6UA9V5M('!R;W!R:6%M96YT92!D:71A
M+"!A(&EM86=E;2!Q=64@<')E=&5N9&4@8V%R<F5G87(@;N-O('!O9&4@<V5R
M(&UO<W1R861A('!E;&\@<V5U(&YA=F5G861O<BX`4')E=FESXV\@9&$@26UA
M9V5M.@!54DP@9&$@:6UA9V5M`%523"!D82!I;6%G96TZ`$EM86=E;2!D92!G
M86QE<FEA`$EM86=E;2!D92!G86QE<FEA.@!#87)R96=A;65N=&\@9&$@:6UA
M9V5M`$EM86=E;G,`26UP;W)T87(@3&ES=&$@9&4@16YD97)EYV]S+"!087-S
M;R`E9`!);7!O<G1A<BP@4&%S<V\@)60`26UP;W)T87(O17AP;W)T87(@3&ES
M=&%S(&1E($5N9&5R9>=O<P!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O<R!I
M;7!O<G1A9&]S.@!);E]S97)I<B!,:6YH82!$97!O:7,`0_-D:6=O(&1E(&%C
MY^-O(&EN=')O9'5Z:61O(&5S=.$@:6YC;W)R96-T;RX`3F]M92!D92!U=&EL
M:7IA9&]R(&]U('!A;&%V<F$M<&%S<V4@97)R861O<RX`3F]M92!D92!U=&EL
M:7IA9&]R(&]U(&5N9&5R9>=O(&%L=&5R;F%T:79O(&5R<F%D;W,N($-O;G1A
M8W1E(&\@<V5U(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M82!P87)A(&]B=&5R
M(&%J=61A+@!!=6UE;G1A<B!A($EN9&5N=&'GXV\`4F5P^F)L:6-A(&1A(,UN
M9&EA`%5T:6QI>F%D;W)E<R!);F1I=FED=6%I<P!297#Z8FQI8V$@9&$@26YD
M;V[I<VEA`$EN9F]R;6'GXV\`26YF;W)M8>?C;P!);F9O<FUAY^-O(&KA(&[C
M;R!E<W3A(&1I<W!O;NUV96P`26YI8VEA;&EZ86YD;R!O(&WS9'5L;R`E<RXN
M+B``26YS97)I<B!#7V]L=6YA($1E<&]I<P!);G-E<FER($EM86=E;0!);G-E
M<FER(%1A8F5L80!);G-E<FER($QI9V'GXV\@X"!796(`26YS97)I<B!?0V]L
M=6YA($%N=&5S`$EN<VER:7(@=6UA(&YO=F$@8V]L=6YA(&1E<&]I<R!D82!C
M;W)R96YT90!);G-I<FER('5M82!N;W9A(&-O;'5N82!A;G1E<R!D82!C;W)R
M96YT90!);G-I<FER('5M82!N;W9A(&QI;FAA(&1E<&]I<R!D82!C;W)R96YT
M90!);G-I<FER('5M82!N;W9A(&QI;FAA(&%N=&5S(&1A(&-O<G)E;G1E`$EN
M<V5R:7(@=6T@<&%RX6=R869O(&%P\W,@;R!N\R!C;W)R96YT90!);G-E<FER
M('5M('!A<N%G<F%F;R!A;G1E<R!D;R!N\R!C;W)R96YT90!);G-I<FER(&UO
M9&5L;R!A;'1E<FYA=&EV;P!);G1R;V1U>F$@=6T@96YD97)EYV\@9&4@8V]R
M<F5I;R!E;&5C='+S;FEC;R!O;F1E('!O<W-A(')E8V5B97(@82!N;W9A('!A
M;&%V<F$M<&%S<V4Z`$EN<VER:7(@8^EL=6QA(&%P\W,`26YS97)I<B!CZ6QU
M;&%S(&%N=&5S`$EN<V5R:7(@8^EL=6QA(&1E<&]I<P!);G-E<FER(&-O;'5N
M82!A;G1E<P!);G-E<FER(&UE;G-A9V5N<P!);G-E<FER('!A<N%G<F%F;R!A
M;G1E<P!);G-E<FER('!A<N%G<F%F;R!A;G1E<P!);G-E<FER(&QI;FAA(&1E
M<&]I<P!);G-E<FER(&QI;FAA(&%N=&5S`$EN=')O9'5Z82!A(')E<W!O<W1A
M(&5X:6=I9&$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R86[G83H`26YS97)I
M<B]-;V1I9FEC87(@26UA9V5M`$EN<V5R:7(O36]D:69I8V%R($QI9V'GXV\`
M0W+I9&ET;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I87(@<&%R82!A(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RX`0W+I9&ET;R!I;G-U9FEC:65N=&4N`$EN=&5I
M<F\`3&ES=&$@9&4@:6YT96ER;W,`(D-O;G1E;G0M5'EP92(@26YVX6QI9&\N
M`$E$($EN=N%L:61O+@!51$@@*%5S97(@1&%T82!(96%D97(I(&EN=N%L:61O
M+@!$861O<R!:25`@:6YVX6QI9&]S`$QI=G)O(&1E(&5N9&5R9>=O<R!I;G;A
M;&ED;RX`07!L:6-AY^-O(&EN=N%L:61A+@!)1"!D92!L;W1E("@B8F%T8V@B
M*2!I;G;A;&ED;RX`3W,@9&%D;W,@<W5B;65T:61O<R!SXV\@:6YVX6QI9&]S
M+@!%;F1E<F7G;R!D92!D97-T:6YO(&EN=N%L:61O+@!%;F1E<F7G;R!D92!C
M;W)R96EO(&5L96-T<O-N:6-O(&EN=N%L:61O+@!%;G1R861A($EN=N%L:61A
M+@!&;W)M871O(&1O(&%R<75I=F\@:6YVX6QI9&\`0VAA=F4@:6YVX6QI9&$@
M97-P96-I9FEC861A+@!#:&%V92!D82!L:6-E;N=A(&EN=N%L:61A+@!,;V-A
M;&EZ8>?C;R!I;G;A;&ED82!E<W!E8VEF:6-A9&$N`&US9U]T>7!E(&EN=N%L
M:61O+@!.;VUE($EN=N%L:61O+@!O8FIE8W1)1"!);G;A;&ED;RX`87!I7VED
M(&EN=N%L:61O(&]U(&5M(&9A;'1A+@!087+B;65T<F]S(&EN=N%L:61O<R!O
M=2!E;2!F86QT82X`4&5R;6ES<^-O('!A<F5N=&%L(&EN=N%L:61A+@!)1"!D
M92!P87)C96ER;R!I;G;A;&ED;RX`0_-D:6=O(&1E('!R;V1U=&\@:6YVX6QI
M9&\N`%!R;W1O8V]L;R!I;G;A;&ED;RX`1&5S=&EN873A<FEO(&EN=N%L:61O
M.B`B)7,B`$]B:F5C=&\@9&4@<&%R=&EL:&$@:6YVX6QI9&\`16YD97)EYV\@
M9&$@;W)I9V5M(&EN=N%L:61O+@!$861O<R!U;FEC;V1E(&EN=N%L:61O<RX`
M26YV96YTX7)I;P!297#Z8FQI8V$@27-LXFUI8V$@9&\@27+C;P!297#Z8FQI
M8V$@9&\@27)A<75E`%)E</IB;&EC82!D82!)<FQA;F1A`$EL:&$@9&4@36%N
M`%1E;7!O<F%I<RU4($ES;VQA9&]S`$5S=&%D;R!D92!)<W)A96P`16UI<W-O
M<@!)=.%L:6-O`%)E</IB;&EC82!)=&%L:6%N80!*86UA:6-A`$IA;F5I<F\`
M2F%PXV\`2F%P;V[J<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!296EN;R!(87-H
M96UI=&$@9&$@2F]R9.)N:6$`2G5L:&\`2G5N:&\`2G5S=&EF:6-A<@!#96YT
M<F%R`$IU<W1I9FEC87(`2G5S=&EF:6-A<B#@($5S<75E<F1A`$IU<W1I9FEC
M87(@X"!$:7)E:71A`%)E</IB;&EC82!D;R!#87IA<75I<W3C;P!0<F5S97)V
M87(@;R!O<FEG:6YA;#\`4F5P^F)L:6-A(&1O(%%UZ6YI80!/('-E<G9I9&]R
M($ME<F)E<F]S(')E:F5I=&]U(&$@875T96YT:6-AY^-O+@!.;W9A=&]S(&YO
M(")+97)N96PB`$-R:6'GXV\@9&$@0VAA=F4`26UP<F5S<^-O(&1I9VET86P@
M9&$@8VAA=F4`0V]M<')I;65N=&\@9&$@8VAA=F4`5&EP;R!D82!#:&%V90!5
M=&EL:7IAY^-O(&1A($-H879E`$$@8VAA=F4@:N$@97AI<W1E(&YO('-E<G9I
M9&]R(&1E(&-H879E<R!P^F)L:6-A<RX`36GZ9&]S`%%U:7)I8F%T:0!297#Z
M8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D82!#;W)E:6$`4F5P^F)L:6-A
M(&1A($-O<F5I80!#;W)E86YO("A%54,M2U(I`$MU=V%I=`!297#Z8FQI8V$@
M475I<F=U:7IE`%-U<&]R=&4@3$1!4"#I(&YE8V5S<^%R:6\@;6%S(&\@;?-D
M=6QO($Q$05`@;N-O(&5S=.$@9&ES<&]N[79E;"!O=2!NXV\@97-TX2!C87)R
M96=A9&\N`%]$:7-P;W-IY^-O`$ED:6]M80!297#Z8FQI8V$@4&]P=6QA<B!$
M96UO8W+A=&EC82!,86\`475A<G1O($1E8W)E<V-E;G1E`$UO9&EF:6-A9&\`
MVFQT:6UO($YO;64`475A<G1O($1E8W)E<V-E;G1E`-IL=&EM82!!8W1U86QI
M>F'GXV\Z`-IL=&EM82!E;G1R861A.B`E<P#:;'1I;6$@96YT<F%D83H@)7,@
M9&4@)7,`VFQT:6UA(&5N=')A9&$Z($YU;F-A`%)E</IB;&EC82!D82!,973S
M;FEA`$QE:0!$:7-P;W-IY^-O`$1E:7AA<B!V87II;R!P87)A(&9I8V%R('-E
M;2!B;W)D80!,[6)A;F\`17-Q=65R9&$`0V%B9>=A;&AO(&1A(&5S<75E<F1A
M`%9A;&]R97,@X"!E<W%U97)D80!,97-O=&\`3&EBZ7)I80!'<F%N9&4@2F%M
M86AI<FEY82!3;V-I86QI<W1A(%!O<'5L87(@P7)A8F4@9&$@3.UB:6$`3&ES
M=&5N<W1A:6YE`$-H=79A(")-;VQH82U4;VQO<R(`0VAU=FES8V]S`$-H=79I
M<V-O<R!-871I;F%I<P!#:'5V:7-C;W,@5F5S<&5R=&EN;W,`4&5Q=65N;R!!
M9W5A8V5I<F\`0VAU=FES8V\@8V]M(%1R;W9O861A`%%U961A(&1E($YE=F4`
M3F5V90`B3&EM97)I8VLB`$QI9V'GXV\`3&EG8>?C;R!A<&]N=&$@<&%R83H`
M3&EG87(@;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(.`@<.%G
M:6YA(&1E(&-O;7!O<VGGXV\@86\@;6]S=')A<@!,:6=AY_5E<P!";VQI;FAO
M(&QI;G5XZG,`3&ES=&$`3&ES=&$@+2!O('5T:6QI>F%D;W(@<&]D92!V97(@
M82!P87-T80!,:7-T87(@0F%S97,@9&4@1&%D;W,`36]S=')A<B!4\W!I8V]S
M(&1E($%J=61A`$QI<W1A<B!486)E;&%S`$QI<W1A9V5M+4%R<75I=F\`3&ES
M=&%G96TM06IU9&$`240@9&$@3&ES=&$`3&ES=&%G96TM1&]N;P!,:7-T86=E
M;2U3=6)M:7-S]65S`$QI<W1A9V5M+5-U8G-C<FET87,`3&ES=&%G96TM3N-O
M('-U8G-C<FET87,`02!L:7-T86=E;2!D92!U=&EL:7IA9&]R97,@97-TX2!D
M97-A8W1I=F%D82X`3&ET97)A='5R83H`4F5P^F)L:6-A(&1A($QI='7B;FEA
M`$-A<G)E9V%N9&\@8FEB;&EO=&5C87,N+BX`0V%R<F5G86YD;RXN+@!496UP
M;R!L;V-A;#H`3&]C86QI>F'GXV\@92!&=7-O($AO<N%R:6\`3&]C86QI>F'G
MXV\`16YT<F%R`%-A:7(`5&%R969A<R!D92!%;G1R861A`$$@875T96YT:6-A
MY^-O(&9A;&AO=2!P;W(@;R!.;VUE(&1E(%5T:6QI>F%D;W(@;W4@82!086QA
M=G)A+5!A<W-E(&5S=&%R96T@:6YC;W)R96-T;W,N`$$@875T96YT:6-AY^-O
M(&9A;&AO=2X`5&5X=&\@;&]N9V\`06UO<@!"86EX;P!,971R87,@9W)E9V%S
M(&UI;OIS8W5L87,`3&5T<F%S(&QA=&EN87,@;6EN^G-C=6QA<P!.^FUE<F]S
M(')O;6%N;W,@;6EN^G-C=6QO<P!,=7AE;6)U<F=O`$U-`$U/5$0`3R!A;F5X
M;R!-4RU43D5&(&[C;R!C;VYT:6YH82!D861O<RX`35-'`$UA8V%U`$UA8V5D
M\VYI82P@06YT:6=A(%)E</IB;&EC82!*=6=O<VQA=F$@9&$`36%D86?A<V-A
M<@!-86=I80!#;W)R96EO`$%D;6EN:7-T<F'GXV\@9&4@0V]R<F5I;P!&87IE
M<B!L:5]G8>?C;RXN+@!!<W-E9W5R92US92!D92!Q=64@=&5M(&\@4$5!4B!I
M;G-T86QA9&\@92!N;R!C86UI;FAO(&1E(&EN8VQU<_5E<R`H:6YC;'5D92!P
M871H*2X`0W)I86YD;R!A('!A<W1A("5S`$UA;&%U:0!-86SA<VEA`$UA;&1I
M=F%S`$UA;&D`36%L=&$`1VER82!A(&QI<W1A(&1E(&-A=&5G;W)I87,@<75E
M('!O9&4@871R:6)U:7(@86]S(&ET96YS+"!B96T@8V]M;R!A<R!C;W)E<R!Q
M=64@;&AE<R!E<W3C;R!A<W-O8VEA9&%S+@!-87!A($UA<#(T`$UA<&$@36%P
M475E<W0`36%RYV\`36%R9V5M`$UA<F-A<B!C;VUO($QI9&$O3N-O(&QI9&$`
M36%R8V%R(&1E(&]U=')A<R!F;W)M87,@*&4N9RXL($EM<&]R=&%N=&4O4&]R
M(')E<W!O;F1E<BD`26QH87,@36%R<VAA;&P`36%R=&EN:6-A`$-O<G)E<W!O
M;F1E;G1E`$-A;7!O<R!Q=64@8V]R<F5S<&]N9&5M`$UA=7)I=.)N:6$`36%U
M<NUC:6\`3>%X:6UO(&-RZ61I=&\@<&5R;6ET:61O+@!-X7AI;6\@;OIM97)O
M(&1E('!A<G1E<R!N=6UA(&UE;G-A9V5M(&5X8V5D:61O+@!496UP97)A='5R
M82!MX7AI;6$@;F%S(/IL=&EM87,@,C0@:&]R87,Z(`!496UP97)A='5R82!M
MX7AI;6$@;F%S(/IL=&EM87,@-B!H;W)A<SH@`$-O;7!R:6UE;G1O(&WA>&EM
M;P!.^FUE<F\@;>%X:6UO(&1E('#A9VEN87,`36%I;P!-87EO='1E`$UE9&EC
M:6YA`$UE;6)R;W,`36]D;R!D;R!M96YU.@!5;FER(&/I;'5L87,`26YT96=R
M86YD;R!T;V1O<R!O<R!F:6-H96ER;W,@)7,N<&\@8V]M(&\@8V]M<.IN9&EO
M+BXN`$EN=&5G<F%N9&\@82!L;V-A;&EZ8>?C;R`E<RXN+B``26YT96=R86YD
M;R!O(&%R<75I=F\@4$\@9&4@)7,@8V]M(&\@8V]M<.IN9&EO+BXN(`!);G1E
M9W)A;F1O(&$@=')A9'7GXV\@9&\@;?-D=6QO("5S+BXN`$UE;G-A9V5M`$UE
M;G-A9V5N(%9E<FEF:6-A9&$@8V]M(%-U8V5S<V\L(&UA<R!O(&-E<G1I9FEC
M861O(&1O('-U8G-C<FET;W(@;N-O('#T9&4@<V5R('9E<FEF:6-A9&\N`$UE
M;G-A9V5M(&5X<&ER;W4N`%1I<&\@9&4@;65N<V%G96T`365T96]R;VQO9VEA
M($U%5$%2`$)L;V-O($U%5$%2(&EN9&ES<&]N[79E;"X`0FQO8V\@345405(@
M:6YD:7-P;V[M=F5L+B!/<R!P;W)M96YO<F5S(&9O<F%M(')E9VES=&%D;W,@
M<&%R82!O(&%D;6EN:7-T<F%D;W(N`$$@365T87)$0B!NXV\@97-TX2!C;VYE
M8W1A9&$N`$WI=&]D;P!/(&WI=&]D;R`B)7,B(&[C;R!E<W3A(&1E9FEN:61O
M`$WI=')I8V\`3>EX:6-O`$UI8W)O;NES:6$L($5S=&%D;W,@1F5D97)A9&]S
M(&1A`$-E;G1R;P!4:7!O($U)344`5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z
M;'1I;6%S(#(T(&AO<F%S`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA
M<R`V(&AO<F%S`$UI;FDM<')O8W5R80!%<W!E;&AO`$UI<V-E;.)N96$`1F%L
M=&$@1$X@;F$@8V]N9FEG=7)AY^-O(&1O($Q$05`@9F]N=&4`4&%C;W1E($A4
M5%!?4F5Q=65S="!D;R!014%2(&5M(&9A;'1A+@!#;VYF:6=U<F'GXV\@96T@
M9F%L=&$N(%1E<N$@9&4@82!G97)A<B!A9V]R82!S92!Q=6ES97(@=7-A<B!E
M<W1A(&%P;&EC8>?C;RX`240@9&$@;65N<V%G96T@96T@9F%L=&$N`%!A8V]T
M92!-86EL(&1O(%!%05(@96T@9F%L=&$N`$E$(&1A('-E<W/C;R!E;2!F86QT
M82X`,JH`0V]R<F5I;R!-\W9E;`!496QE;?-V96P`36]D97)A9&\`1&%T82!D
M92!-;V1I9FEC8>?C;P!-;V1I9FEC87(@55),`$UO9&EF:6-AY^-O(&9A;&AO
M=3H@*"5S*2`E<P!-\V1U;&\`3?-D=6QO`%)E</IB;&EC82!D82!-;VQD;W9A
M`%!R:6YC:7!A9&\@9&\@3?-N86-O`$UO;F?S;&EA`$WJ<R!E(&%N;P!-96YS
M86QM96YT90!-;VYT<V5R<F%T`$9A<V4@9&$@3'5A`$5N8V]N=')A9&$@;6%I
M<R!Q=64@=6UA(&5N=')A9&$N`%)E:6YO(&1E($UA<G)O8V]S`%-O8G)E='5D
M;R!,:6UP;P!3;V)R971U9&\@16YE=F]A9&\`4V]B<F5T=61O(%-O;&%R96YG
M;P!-;W9E<@!$97-C97(`36]V97(@<&%R82!A($5S<75E<F1A`$UO=F5R('!A
M<F$@82!$:7)E:71A`%-U8FER`$1E<V-E<@!-;W9E<B#@(&5S<75E<F1A`$UO
M=F5R(.`@9&ER96ET80!3=6)I<@!297#Z8FQI8V$@9&4@36_G86UB:7%U90!,
M:79R;R!D92!%;F1E<F7G;W,@375L8F5R<GD`3&ES=&%S(&1E(&1E<V5N<F]L
M87(@;75L=&DM;NUV96P`2.$@=N%R:6%S('!E<W-O87,@8V]M(&\@96YD97)E
MYV\@6R5S72P@;6%S(&YE;FAU;6$@8V]M(&\@;F]M92!;)7-=`%-E;&5CY^-O
M(&WZ;'1I<&QA`$$@36EN:&$@0V]N=&$`3R!-974@3&EV<F\@9&4@16YD97)E
MYV]S`$\@365U(%!O<G1A;`!$:7-P;W-IY^-O(&1O(%!O<G1A;`!5;FGC;R!D
M92!->6%N;6%R`$[C;RP@;N-O(&-O;F-O<F1O`$YO;64`1F]R;6%T;R!D;R!.
M;VUE`%)E</IB;&EC82!D82!.86WM8FEA`$YA=7)U`$YE<&%L`$1I<F5C=/-R
M:6\@9&4@365M8G)O<R!D;R!.971C96YT97(`4F5I;F\@9&]S(%!A[7-E<R!"
M86EX;W,`06YT:6QH87,@2&]L86YD97-A<P!54DP@9&4@0F%S92!.971S8V%P
M90!54DP@9&4@4F5V;V=AY^-O($-!($YE='-C87!E`%523"!C;VT@82!P;VSM
M=&EC82!D92!#02!.971S8V%P90!54DP@9&4@4F5N;W9AY^-O($YE='-C87!E
M`%523"!D92!2979O9V'GXV\@3F5T<V-A<&4`3F]M92!D;R!S97)V:61O<B!3
M4TP@3F5T<V-A<&4`0V]M96YTX7)I;R!D92!C97)T:69I8V%D;R!.971S8V%P
M90!4:7!O(&1E(&-E<G1I9FEC861O($YE='-C87!E`%)E9&4`3G5N8V$`3F]V
M82!#86QE9/-N:6$`3F]V82!#871E9V]R:6$`3F]V;R!#;VYT86-T;P!.;W9A
M($QI<W1A`$QU82!.;W9A`$YO=F\@3F]M92!D92!5=&EL:7IA9&]R("AO<&-I
M;VYA;"D`3F]V82!:96SB;F1I80!.;W9A(&IA;F5L82`H7V)L86YK*0!.;W3M
M8VEA<P!'<G5P;W,@9&4@3F]T[6-I87,`4'+S>&EM80!0<O-X:6UA<R`T($9A
M<V5S`%!R\WAI;6%S(&]PY_5E<P!0<O-X:6UA/@!297#Z8FQI8V$@9&$@3FEC
M87+A9W5A`$%L8W5N:&$`4F5P^F)L:6-A(&1O($[M9V5R`%)E</IB;&EC82!&
M961E<F%L(&1A($YI9V5R:6$`3F]I=&4`3FEU90!.XV\`3N-O('-E(&5N8V]N
M=')O=2!E;G1R861A("5S('!A<F$@)7,`3N-O('-E(&5N8V]N=')O=2!L:79R
M;W,@9&4@96YD97)EYV]S+@!.XV\@:.$@9&%D;W,@9&4@8V]N9FEG=7)AY^-O
M(&1I<W!O;NUV96ES(&5M(')E;&'GXV\@86]S('%U86ES(&UO<W1R87(@9&EF
M97)E;N=A<RX`3N-O(&CA(&YE;FAU;6$@97-T<F%TZ6=I82!D:7-P;V[M=F5L
M('!A<F$@<F5A;&EZ87(@:6UA9V5N<R!)4T\N`$[C;R!HX2!M;V1E;&\@9&4@
M;&]T92`B8F%T8V@B+@!.XV\@97AI<W1E(&)L;V-O(&YA('!O<VGGXV\@:6YD
M:6-A9&$`3N-O(&9O:2!F;W)N96-I9&\@=6T@;F]M92!D92!C86QE;F3A<FEO
M('!A<F$@82!A=71E;G1I8V'GXV\@34-!3"X`4V5M(&UO9&EF:6-AY_5E<RX`
M3N-O('-E('!O9&4@861I8VEO;F%R('!E<FUI<W/U97,@9&4@9FEL:&]S(&%B
M86EX;R!D97-T92!N[79E;"X`3N-O('-E('!O9&4@861I8VEO;F%R(&9I;&AO
M<R!A(&5S=&$@<&5R;6ES<^-O+@!.96YH=6T@8V]M86YD;R!E<W!E8VEF:6-A
M9&\N`$[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF
M:6=U<F'GXV\@<&%R82`E<RX`3N-O(&9O:2!E<W!E8VEF:6-A9&$@82!I;F9O
M<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!P87)A(%9&4R!B87-E861O(&5M($94
M4"X`3N-O(&9O:2!E<W!E8VEF:6-A9&$@82!I;F9O<FUAY^-O(&1E(&-O;F9I
M9W5R8>?C;R!N96-E<W/A<FEA('!A<F$@;R!61E,@8F%S96%D;R!E;2!344PN
M`$[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U
M<F'GXV\@;F5C97-SX7)I82!P87)A(&\@5D93(&)A<V5A9&\@96T@4U%,+49I
M;&4N`$[C;R!S92!E;F-O;G1R;W4@8V]N=&%C=&]S`$-RZ61I=&\@97-G;W1O
M=2X`3F5N:'5M(&1E<W1I;F%TX7)I;R!F;VD@9F]R;F5C:61O+@!.XV\@97AI
M<W1E('%U86QQ=65R(&5N=')A9&$@8V]M(&\@:60@(B5S(B!N;R!A<G%U:79O
M(&1E(&%J=61A(&]R:6=I;F%L+@!.XV\@<V4@8V%R<F5G;W4@;F%D82X`3F5N
M:'5M82!L;V-A;&EZ8>?C;R!E<W!E8VEF:6-A9&$N`$9A;'1A(&EN9&EC87(@
M=6UA(&QO8V%L:7IAY^-O+@!!(&QO8V%L:7IAY^-O(&[C;R!F;VD@97-P96-I
M9FEC861A+@!.96YH=6UA(&UE;G-A9V5M(&9O:2!F;W)N96-I9&$N`$YE;FAU
M;2!N;VUE(&5S<&5C:69I8V%D;RX`3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A
M9&\N`%-E;2!D:71O<R!O9F5N<VEV;W,`3N-O(&9O:2!F;W)N96-I9&$@<&%L
M879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($A45%`N`$[C;R!F;VD@
M9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!)
M34%0+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A
M=71E;G1I8V'GXV\@2V5R8F5R;W,N`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V
M<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!,1$%0+@!.XV\@9F]I(&9O
M<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@3&]G
M:6XN`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U
M=&5N=&EC8>?C;R!005-35T0N`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M
M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!334(N`$[C;R!F;VD@:6YD:6-A
M9&\@8V%M:6YH;R!P87)A(&\@8FENX7)I;R!/<&5N4U-,+B!/(&)I;N%R:6\@
M3W!E;E-33"#I(&YE8V5S<^%R:6\@<&%R82!T<F%B86QH87(@8V]M(&1A9&]S
M(%!+0U,@,3(N`$[C;R!HX2!S=6)S8W)IY_5E<R!P96YD96YT97,N`%-E;2!T
M<F'G;W,`4V5M(&QA9&]S`$[C;R!HX2!P87-T82!T96UP;W+A<FEA(&1I<W!O
M;NUV96P@<&%R82`B8V%C:&4B+@!.XV\@9F]R86T@96YV:6%D;W,@;R!N;VUE
M(&1O('5T:6QI>F%D;W(@;W4@82!P86QA=G)A+7!A<W-E+@!.XV\@<V4@96YC
M;VYT<F]U(&1A9&]S('9#87)D+@!.XV\@9F]R86T@<F5T;W)N861O<R!D861O
M<R!E;2!834P@=N%L:61O<P!396T@=F%L;W)E<P!.XV\@9F]I(&5N8V]N=')A
M9&$@=F5R<^-O(&YA(&-O;F9I9W5R8>?C;R!O<FEG:6YA;"X@4F5G96YE<F%R
M(&-O;F9I9W5R8>?C;RX`3N-O(&9O:2!E;F-O;G1R861A('9E<G/C;R!N82!S
M=6$@8V]N9FEG=7)AY^-O+B!296=E;F5R87(@8V]N9FEG=7)AY^-O+@!.96YH
M=6UA`$YE;FAU;2`H=7-A<B!I;7!L[6-I=&\I`$[S<F1I8V\@*$E33RTX.#4Y
M+3$P*0!);&AA(&1E($YO<F9O;&L`2&5M:7-FZ7)I;R!.;W)T90!);&AA<R!-
M87)I86YA<R!D;R!.;W)T90!296EN;R!D82!.;W)U96=A`$YU;F-A($1E<&]I
M<R!D90!.=6YC82!!;G1E<R!D90!.XV\@Z2!U;2!D:7)E8W3S<FEO`$[C;R!I
M;7!L96UE;G1A9&$N`%!O<B!A=')I8G5I<@!.XV\@<W5P;W)T861O+@!.;W1A
M<P!.861A('!A<F$@;F%V96=A<BP@=F]L=&4@<&%R82!T<N%S+@!.;W1A`$YO
M=F5M8G)O`$[Z;65R;P!.^FUE<F\@9&4@8V%R86-T97)E<P!.^FUE<F\@9&4@
M8V]L=6YA<P!.^FUE<F\@9&4@:71E;G,@<&]R('#A9VEN80!.^FUE<F\@9&4@
M;&EN:&%S`$YA(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!HX2!N^FUE<F]S('%U
M92!NXV\@9F]R86T@97-P96-I9FEC861O<R!P87)A(&%C='5A;&EZ8>?C;RX`
M3TL`3V)J96-T;P!#<FEA9&]R(&1O($]B:F5C=&\`4&5R;6ES<_5E<R!D;R!C
M<FEA9&]R(&1O(&]B:F5C=&\`3V)J96-T;R!NXV\@96YC;VYT<F%D;RX`3V-T
M86P`3W5T=6)R;P!&:6QT<F\@9&4@;6%T97)I86P@;V9E;G-I=F\`17-C<FET
M\W)I;P!3=6QT86YA=&\@9&\@3VWC`%/S(&]S('-E<G9I9&]R97,@24U!4"!S
M=7!O<G1A;2!P87-T87,@<&%R=&EL:&%D87,N`$%P96YA<R!D:71O<R!O9F5N
M<VEV;W,`4_,@Z2!P97)M:71I9&\@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;RX`07!E;F%S(&\@9&]N;R!O=2!U;2!A9&UI;FES=')A9&]R
M(&1E('-I<W1E;6%S('!O9&4@86QT97)A<B!A('1I='5L87)I9&%D92!D92!U
M;6$@<&%R=&EL:&$@;W4@87,@<&5R;6ES<_5E<R!D;R!S974@9&]N;P!!8G)E
M(&YU;6$@;F]V82!J86YE;&$`17)R;R!/<&5N4U-,.B!.XV\@9F]I('!O<W/M
M=F5L(&5X=')A:7(@9&%D;W,@9&4@=6UA('!A<G1E(&%S<VEN861A(&-O;2!3
M+TU)344N`$%B<F4@97-T82!L:6=AY^-O(&YU;6$@;F]V82!J86YE;&$`4VES
M=&5M82!/<&5R871I=F\`3W#G]65S`$]PY_5E<R!D;R`E<P!/<.?U97,Z`$QI
M<W1A($]R9&5N861A`$]R9V%N:7IAY^-O`%5N:61A9&4@3W)G86YI>F%C:6]N
M86P`3W)G86YI>F'GXV\`36]D96QO(&]R:6=I;F%L(&1A(&%P;&EC8>?C;P!-
M;V1E;&]S(&]R:6=I;F%I<R!E;2`E<SH`3W5T<F\`3W5T<F%S($EN9F]R;6'G
M]65S`$]U=')A<R!/<.?U97,`4&5R;6ES<_5E<R!D;R!$;VYO`$%U=&5N=&EC
M8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E;"X`07-S:6YA='5R82!$:6=I
M=&%L(%!'4`!$861O<R!E;F-R:7!T861O<R!01U``0VAA=F4@4/IB;&EC82!0
M1U``1&%D;W,@07-S:6YA9&]S+T5N8W)I<'1A9&]S(&-O;2!01U``0_-D:6=O
M(%!(4`!#;VUA;F1O<R!02%``0VAU=FES8V]S('!E;&$@5&%R9&4`06=U86-E
M:7)O<R!D92!487)D90!.979E(.`@5&%R9&4`3F5V]65S(.`@5&%R9&4`4V]L
M(.`@5&%R9&4`5&5M<&]R86ES+50@X"!487)D90!#;VUA;F1O<R!07TA0`$5N
M8VAI;65N=&\`4F5P^F)L:6-A($ES;.)M:6-A(&1O(%!A<75I<W3C;P!297#Z
M8FQI8V$@9&4@4&%L874`5&5R<FET\W)I;R!086QE<W1I;FEA;F\`4&%N86WA
M`%!A<'5A($YO=F$@1W5I;ND`4F5P^F)L:6-A(&1O(%!A<F%G=6%I`%!A<F-I
M86QM96YT92!%;F-O8F5R=&\`4&%L879R82U087-S90!086QA=G)A+5!A<W-E
M(&EN8V]R<F5C=&$`4&%L879R82U087-S92!N96-E<W/A<FEA('!A<F$@875T
M96YT:6-AY^-O(%)!1$E54P!086QA=G)A+5!A<W-E(&-O;2!C;VYF:7)M8>?C
M;P!086QA=G)A+5!A<W-E.@!086QA=G)A+5!A<W-E.B``07,@<&%L879R87,M
M<&%S<V4@=.IM(&1E('-E<B!I9W5A:7,N`$-O;&%R`$-O;&%R(&1E(')E8V]R
M=&5S`$-A;6EN:&\`4W5B<V-R:>?U97,@4&5N9&5N=&5S.@!097-S;V%S`%!E
M<F-E;G1A9V5M`$5X96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O`$5X
M96-U=&%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%Q=6%N9&\@9&$@96YT
M<F%D83\`4&5R;6ES<^-O`$$@<&5R;6ES<^-O("(E<R(@;N-O(&9O:2!R96UO
M=FED82X`4&5R;6ES<^-O($YE9V%D80!097)M:7-SXV\@3F5G861A`$%D;6EN
M:7-T<F'GXV\@9&4@4&5R;6ES<_5E<P!097)M:7-S]65S(&1E`$EN9F]R;6'G
M]65S(%!E<W-O86ES`%!E<OH`06YI;6%I<R!D92!%<W1I;6'GXV\`1FEL:7!I
M;F%S`%1E;&5F;VYE`$9O=&]G<F%F:6%S`$QI=G)O(&1E($5N9&5R9>=O<R!0
M:6YE`$EL:&%S(%!I=&-A:7)N`%#M>&5I<P!0;&%T:71U9&5S`%!O<B!F879O
M<B!C;&EQ=64@<V]B<F4@=6UA(&/I;'5L80!0;W(@9F%V;W(@8V]N9FER;64@
M<V4@<F5A;&UE;G1E('!R971E;F1E(')E;6]V97(@97-T92!E;&5M96YT;SH`
M4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E86QM96YT92!P<F5T96YD92!D97-L
M:6=A<B!E<W1E(&5L96UE;G1O+@!0;W(@9F%V;W(@:6YT<F]D=7IA('5M(&WJ
M<R!E('5M(&%N;RX`4&]R(&9A=F]R(&EN=')O9'5Z82!O(&YO;64@9&$@;F]V
M82!C871E9V]R:6$Z`%!O<B!F879O<B!I;G1R;V1U>F$@=6T@96YD97)EYV\@
M25`@=N%L:61O+@!0;W(@9F%V;W(@:6YT<F]D=7IA('5M82!D871A(';A;&ED
M83L@=F5R:69I<75E(&\@;OIM97)O(&1E(&1I87,@9&\@;>IS+@!0;W(@9F%V
M;W(@:6YT<F]D=7IA('5M82!H;W)A(';A;&ED82X`4&]R(&9A=F]R(&EN=')O
M9'5Z82!O(&YO;64@9&$@;F]V82!P87-T83H`4&]R(&9A=F]R+"!F;W)N9>=A
M('5M82!B<F5V92!D97-C<FGGXV\@9&\@<')O8FQE;6$N`%!O<B!F879O<BP@
M:6YT<F]D=7IA(&\@<V5U($YO;64@9&4@571I;&EZ861O<B!E(&$@<W5A(%!A
M;&%V<F$M4&%S<V4`4&]R(&9A=F]R(&QE:6$@;R!T97AT;R!S96=U:6YT92X@
M5&5M(&1E($-/3D-/4D1!4B!C;VT@;W,@=&5R;6]S(&1E<W1E(&%C;W)D;R!P
M87)A('5S87(@;R!S:7-T96UA+@!0;W(@9F%V;W(@<F5P;W)T92!O<R!E<G)O
M<R!P87)A(&DQ.&Y`;&ES=',N:&]R9&4N;W)G`%!O<B!F879O<B!E<V-O;&AA
M('5M(&1I<F5C=/-R:6\Z`%!O<B!F879O<B!I;G1R;V1U>F$@;R!N;VUE(&1A
M(&YO=F$@8V%T96=O<FEA.@!0;VSS;FEA`%!O;.UT:6-A`%-O;F1A9V5N<P!2
M97#Z8FQI8V$@4&]R='5G=65S80!0;W-I8VEO;F%M96YT;R!D97-T82!I;6%G
M96T`4&]S:6-I;VYA;65N=&\@9&5S=&$@=&%B96QA`")0;W-T(B!P87)A(&5S
M=&$@<&%S=&$@*&[C;R#I(')E<75I<VET;R!D;R!)34%0*0!0<F5C:7!I=&'G
MXV\@;F%S(/IL=&EM87,@)7,@:&]R82AS*3H@`%!R;V)A8FEL:61A9&4@9&4\
M8G(@+SY0<F5C:7!I=&'GXV\`4')E9G-?;&1A<#H@02!E>'1E;G/C;R!,1$%0
M(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!0<F5F<U]S97-S:6]N
M.B!!(&5X=&5N<^-O(&1E('-E<W/C;R!N96-E<W/A<FEA(&[C;R!F;VD@96YC
M;VYT<F%D82X`4')E<W/C;P!0<F5S<^-O(&%O(&[M=F5L(&1O(&UA<CH@`%!R
M97-SXV\Z(`!0<F5V:7/C;P!0<F5V97(@82!I;6%G96T@;G5M82!N;W9A(&IA
M;F5L80!/<.?U97,@86YT97)I;W)E<P!);7!R:6UI<B!O(&1O8W5M96YT;P!,
M:79R;R!D92!%;F1E<F7G;W,@4')I=F%D;P!#:&%V92!0<FEV861A`%!R;V)L
M96UA`$1E<V-R:>?C;R!D;R!0<F]B;&5M80!0<F]J96-T;W,`365N<V%G96TM
M<')O;G1O`$-H879E(%#Z8FQI8V$`06QG;W)I=&UO(&1E($-H879E(%#Z8FQI
M8V$`26YF;W)M8>?C;R!3;V)R92!A($-H879E`$\@<&%R(&1E(&-H879E<R!0
M=6)L:6-A+U!R:79A9&$@;N-O(&9O:2!G97)A9&$@8V]M('-U8V5S<V\N`%!O
M<G1O(%)I8V\`17-T861O(&1O(%%A=&%R`%!E9&ED;P!!(&EN=&5R<F]G8>?C
M;R!F86QH;W4Z("@E<RD@)7,`4')O8W5R82!2X7!I9&$`0VAA=F4@4/IB;&EC
M82!24T$@*"5D(&)I="D`4V5L96/GXV\@(G+A9&EO(@!#:'5V80!#:'5V82!-
M871I;F%L`$-H=79A(%9E<W!E<G1I;F$`06=U86-E:7)O`$-H=79A(&4@3F5V
M90!#:'5V82!A($YE=F4`1&ET;R!!;&5A=/-R:6\`4F5L8>?C;P!,97(`02!L
M96ET=7)A(&9A;&AO=3H@*"5S*2`E<P!,97(@;65N<V%G96YS`%%U97(@;65S
M;6\@<F5M;W9E<B`E<S\@17-T82!O<&5R8>?C;R!NXV\@=&5M(')E9W)E<W-O
M+@!296UO=F5R(&UE<VUO(&]S(&1A9&]S(&1O('5T:6QI>F%D;W(@)7,_($5S
M=&$@;W!E<F'GXV\@;N-O('1E;2!R96=R97-S;RX`4F5G:7-T;W,@;6]S=')A
M9&]S.@!2969A>B!A('-U82#Z;'1I;6$@86/GXV\`4F5F<F5S8V%R($5L96UE
M;G1O<R!D92!-96YU($1I;N)M:6-O.@!2969R97-C87(@5FES=6%L:7IAY^-O
M(&1O(%!O<G1A;#H`17AP<F5S<^-O(%)E9W5L87(`3F%V96=A9&]R(&1E(%)E
M;&'G]65S`$]B<V5R=F'G]65S`%-E<G9I9&]R97,@4F5M;W1O<P!54DP@4F5M
M;W1O("AH='1P.B\O=W=W+F5X96UP;&\N<'0O:&]R9&4I.@!296UO=F5R`%)E
M;6]V97(@0FQO8V\`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!F;W)M871AY^-O
M`%)E;6]V97(@9&5S=&$@;&ES=&$`4F5M;W9E<B!P87(`4F5M;W9E<B!O(")S
M8W)I<'0B(&=U87)D861O(&1A('!A<W1A('1E;7!O<N%R:6$@9&\@<V5R=FED
M;W(N`%)E;6]V97(@;P!296UO=F5R(&5S=&4@;O,@9&\@9&]C=6UE;G1O`%)E
M;6]V97(@571I;&EZ861O<@!296UO=F5R('5T:6QI>F%D;W(Z("5S`%-U8G-T
M:71U:7(@;&EV<F\@9&4@96YD97)EYV]S(&5X:7-T96YT92!P96QO(&EM<&]R
M=&%D;S\@/&(^079I<V\Z($ES<V\@<F5M;W9E<N$@=&]D87,@87,@96YT<F%D
M87,@;F\@<V5U(&QI=G)O(&1E(&5N9&5R9>=O<R!C;W)R96YT92X\+V(^`$[C
M;R!F;VD@<&]S<^UV96P@<F5S<&]N9&5R(&%O('!E9&ED;RX@0_-D:6=O(&1E
M(&5R<F\@9&5V;VQV:61O.B``3V)J96-T;R!P961I9&\@;N-O(&5N8V]N=')A
M9&\N`$\@<V5R=FGG;R!P961I9&\@;N-O(&9O:2!E;F-O;G1R861A+@`B)7,B
M(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R
M8>?C;R!D92`E<RX`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I
M8V%D;R!N82!C;VYF:6=U<F'GXV\@5D93+@`B)7,B(&]B<FEG873S<FEO(&[C
M;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;RX`0V%M<&\@3V)R
M:6=A=/-R:6\`3&EM<&%R`%)E:6YI8VEA<B!086QA=G)A+5!A<W-E`%)E:6YI
M8VEE(&$@4W5A(%!A;&%V<F$M4&%S<V4`5F]L=&%R(&$@5F%L;W)E<R!P;W(@
M3VUI<W/C;P!297-U;'1A9&]S`%)E<W5L=&%D;W,@*&EN8VQU:6YD;R!(;W)D
M92DZ`%)E<W5L=&%D;W,Z`%9O;'1A<B#@<R!/<.?U97,`4F5U;FGC;P!2179E
M<G1E<B!#;VYF:6=U<F'GXV\`3W#G]65S(&1E($5D:>?C;R!2:6-A`$%D:79I
M;FAA<P!$:7)E:71A`$-A8F7G86QH;R!D82!D:7)E:71A`%9A;&]R97,@X"!D
M:7)E:71A`%!R;W!R:65D861E<R!D82!,:6Y?:&$N+BX`4F5G<F$`4F]MZ6YI
M80!2;V1A<B`Q.#``4F]D87(@X"!%<W%U97)D80!2;V1A<B#@(&1I<F5I=&$`
M4')O<')I961A9&5S(&1A($QI;FAA`%!R;W!R:65D861E<R!D82!L:6YH80!,
M:6YH87,Z`%1R8>=O<P!4<F'G;W,@87!A<F5C97+C;R!E;G1R92!T;V1A<R!A
M<R!L:6YH87,@92!C;VQU;F%S`%1R8>=O<R!A<&%R96-E<N-O(&%P96YA<R!E
M;G1R92!A<R!C;VQU;F%S`%1R8>=O<R!A<&%R96-E<N-O(&%P96YA<R!E;G1R
M92!L:6YH87,`17AE8W5T87(`1F5D97)AY^-O(%)U<W-A`%)E</IB;&EC82!D
M;R!2=6%N9&$`07-S:6YA='5R82!#<FEP=&]G<N%F:6-A(%,O34E-10!-96YS
M86=E;2!%;F-R:7!T861A(&-O;2!3+TU)344`0V5R=&EF:6-A9&\@4/IB;&EC
M;R!3+TU)344`075T96YT:6-AY^-O(%-!4TP@:6YD:7-P;V[M=F5L+@!-96YS
M86=E;G,@4TU3`$-O;6%N9&]S(%-13`!34T@`4U1!4E1,4R!F86QH;W4Z("@E
M<RD@)7,`4U5#15-33P!#;VUA;F1O<R!37U%,`'/A`%-A;G1A($AE;&5N80!3
MXV\@2VET=',@92!.979I<P!386YT82!,^F-I80!3XV\@4&5D<F\@92!-:7%U
M96QO;@!3XV\@5FEC96YT92!E($=R96YA9&EN97,`365S;6$@;6]L9'5R82`H
M7W-E;&8I`$5S=&%D;R!);F1E<&5N9&5N=&4@9&$@4V%M;V$`4F5P^F)L:6-A
M(%-E<F5N[7-S:6UA(&1E(%/C;R!-87)I;F\`4^-O(%1O;>D@92!0<NUN8VEP
M90!&;W)N96-E9&]R(&1O(%-A=.EL:71E`$%RX6)I82!3875D:71A`$=U87)D
M87(`1W5A<F1A<B`E<P!'=6%R9&%R("<E<R<`1W5A<F1A<B!/<.?U97,`1W5A
M<F1A<B!C;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@(G-C<FEP="(@4$A0
M(&YO(&1I<F5C=/-R:6\@=&5M<&]RX7)I;R!D;R!S974@<V5R=FED;W(N`$=U
M87)D96D@8V]N9FEG=7)AY^-O("5S+@!'=6%R9&5I(&\@(G-C<FEP="(@9&4@
M86-T=6%L:7IAY^-O(&5M.B`B)7,B+@!496UP;W)A:7,M5"!$:7-P97)S;W,`
M0VGJ;F-I80!0<F]C=7)A<@!-;W1O<F5S(&1E(%!R;V-U<F$`4F5S=6QT861O
M<R!D82!0<F]C=7)A`%!R;V-U<F$@9F%L:&]U`%!R;V-U<F$@9F%L:&]U.B`E
M<P!0<F]C=7)A;F1O(&%P;&EC8>?U97,@*&WS9'5L;W,I($AO<F1E(&5M("5S
M`$]PY_5E<R!D92!0<F]C=7)A`%!R;V-U<F%N9&\@;W,@8FENX7)I;W,@9&4@
M9V5T=&5X="XN+@!0<F]C=7)A;F1O+BXN`%-E;&5C8VEO;F%R($QI=G)O(&1E
M($5N9&5R9>=O<P!396QE8V-I;VYA<B!!<G%U:79O<P!396QE8V-I;VYA<B!,
M:7-T80!396QE8V-I;VYE('5M82!D871A`%-E;&5C8VEO;F4@=6T@9W)U<&\@
M82!A8W)E<V-E;G1A<@!396QE8V-I;VYA<B!U;2!N;W9O(&1O;F\`4V5L96-C
M:6]N92!U;2!S97)V:61O<@!396QE8V-I;VYE('5M('5T:6QI>F%D;W(@82!A
M9&EC:6]N87(`4V5L96-C:6]N92!T;V1O<R!O<R!C;VUP;VYE;G1E<R!D82!D
M871A+@!396QE8V-I;VYE('5M(&]B:F5C=&\`4V5L96-C:6]N92!O(&QI=G)O
M(&1E(&5N9&5R9>=O<R!D;R!Q=6%L(&5X<&]R=&%R.@!396QE8V-I;VYE(&\@
M;&EV<F\@9&4@96YD97)EYV]S('!A<F$@;R!Q=6%L(&EM<&]R=&%R.@!396QE
M8V-I;VYE(&]S(&-A<F%C=&5R97,@;F%S(&-A:7AA<R!A8F%I>&\N(%!O9&5R
MX2!E;G3C;R!C;W!IX2UL;W,@92!C;VSA+6QO<R!N82#A<F5A(&1E('1E>'1O
M+@!396QE8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&$@9&%T83H`4V5L96-C:6]N
M92!O(&9O<FUA=&\@9&$@9&%T83H`4V5L96-C:6]N92!O(&9O<FUA=&\@9&4@
M97AP;W)T8>?C;SH`4V5L96-C:6]N92!O(&9I8VAE:7)O(&$@:6UP;W)T87(Z
M`%-E;&5C8VEO;F4@;R!F;W)M871O(&1O(&9I8VAE:7)O(&9O;G1E.@!396QE
M8V-I;VYE(&\@9F]R;6%T;R!U<V%D;R!P87)A(&UO<W1R87(@;F]M97,Z`%-E
M;&5C8VEO;F4@82!I9&5N=&ED861E('%U92!P<F5T96YD92!A;'1E<F%R.@!3
M96QE8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&%S(&AO<F%S.@!396QE8V-I;VYE
M(&\@9F]R;6%T;R!D82!H;W)A.@!396QE8V-I;VYE(&1O:7,@8V%M<&]S(')E
M;&%C:6]N861O<RX`17-C;VQH97(@82!V:7IU86QI>F'GXV\@82!M;W-T<F%R
M('!O<B!O;6ES<^-O+@!%<V-O;&AE<B!O<R!C86UP;W,@=FES[79E:7,@;F%S
M(&QI<W1A<R!D92!C;VYT86-T;W,N`$5S8V]L:&5R(&-O;2!Q=64@9F]R;6%T
M;R!M;W-T<F%R(&]S(&YO;65S+@!%<V-O;&AA(&\@<V5U(&-O;FIU;G1O(&1E
M(&-O<F5S+@!396QE8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F97)I9&\Z`$-O
M;'5N87,@4V5L96-C:6]N861A<SH`4V5L96-C:6]N861O(&\@;&EV<F\@9&4@
M96YD97)EYV]S("(E<R(N`$5N=FEA<B!296QA=/-R:6\@9&4@4')O8FQE;6%S
M`$5N=FEA<B!335,`4F5P^F)L:6-A(&1O(%-E;F5G86P`(%-E;G-O<CH@`%-E
M=&5M8G)O`%/I<G9I82!E($UO;G1E;F5G<F\`3OIM97)O(&1E(%/I<FEE`$1A
M9&]S(&1O('-E<G9I9&]R(&5R<F%D;W,@;W4@:6YD:7-P;V[M=F5I<RX`240@
M9&4@<V5S<^-O(&5X<&ER;W4N`$%T<FEB=6ER`$5S=&%B96QEYV$@;W#G]65S
M('%U92!L:&4@<&5R;6ET86T@<F5I;FEC:6%R(&$@<W5A('!A;&%V<F$M<&%S
M<V4@<V4@86QG=6UA('9E>B!D96QA('-E(&5S<75E8V5R+@!%<W!E8VEF:6-A
M<B!S97)V:61O<F5S(')E;6]T;W,@<75E(&1E<V5J82!A8V5D97(@;F\@<V5U
M('!O<G1A;"X`4V5L96-C:6]N92!O('-E=2!I9&EO;6$@<')E9F5R:61O+"!O
M('-E=2!F=7-O(&AO<N%R:6\@92!A<R!S=6%S(&]PY_5E<R!D92!D871A<RX`
M17-C;VQH82!A('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@;R!E<W%U96UA(&1E
M(&-O<F5S+"!O(')E9G)E<V-A;65N=&\@9&4@<.%G:6YA<R!E(&]U=')A<R!O
M<.?U97,@9&4@=FES=6%L:7IAY^-O+@!#;VYF:6=U<F%R`")38W)I<'1S(B!D
M92!A8W1U86QI>F'GXV\@9&ES<&]N[79E:7,`5N%R:6%S(&QO8V%L:7IAY_5E
M<R!P;W-S[79E:7,@8V]M(&\@<&%RXFUE=')O.B``4V5I8VAE;&5S`$1I<F5C
M=/-R:6\@4&%R=&EL:&%D;P!-;W-T<F%R(%1?=61O`$-O;7!R87,`0G)E=F4@
M4W5MX7)I;P!$979E;2US92!D969I;FER('1E8VQA<R!D92!A8V5S<V\@<&%R
M82!A(&UA:6]R:6$@9&%S(&QI9V'G]65S/P!-;W-T<F%R`$UO<W1R87(@5'5D
M;P!-;W-T<F%R($-O;G1A8W1O<P!-;W-T<F%R($QI<W1A<P!-;W-T<F%R(%]#
M;VYT86-T;W,`36]S=')A<B!?3&ES=&%S`$UO<W1R87(@9&EF97)E;N=A<R!E
M;G1R92!A(&-O;F9I9W5R8>?C;R!G=6%R9&%D82!E(&%Q=64@9F]I(&%G;W)A
M(&=E<F%D82X`36]S=')A<B!M;VUE;G1O(&1A(/IL=&EM82!E;G1R861A(&YO
M('-I<W1E;6$_`$UO<W1R87(@;W#GXV\@<&%R82!P<F5S97)V87(@;R!O<FEG
M:6YA;`!-;W-T<F%R('!A;&5T90!-;W-T<F%R(&$@8F%R<F$@9&4@;65N=2!C
M;VT@87,@;W!E<F'G]65S('-O8G)E('1A8F5L87,_`$UO<W1R87(@;R!-96YU
M("5S(.`@97-Q=65R9&$_`$UO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A
M<R!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D92!486)E;&$_`$UO<W1R87(@
M82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@5&%B96QA
M<P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I961A9&5S
M(&1E($QI;FAA<R!D92!486)E;&$`36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO
M9V\@9&%S(%!R;W!R:65D861E<R!D92!);6%G96T`36]S=')A<B!C87)R96=A
M;65N=&\`06=U86-E:7)O<P!!9W5A8V5I<F]S($UA=&EN86ES`$%G=6%C96ER
M;W,@5F5S<&5R=&EN;W,`06=U86-E:7)O<R!N82!6:7II;FAA;N=A`$5N8V]L
M:&5R`$5N8V]L:&$@;W4@;6]V82!O*',I(&)L;V-O*',I('9I>FEN:&\H<RD@
M<')I;65I<F\`4V5R<F$@3&7C;P!3=6)S8W)E=F5R`%-U8G-C<F5V82P@<V4@
M86EN9&$@;N-O(&5S=.$@<F5G:7-T861O`$%S<VEN871U<F$`06QG;W)I=&UO
M(&1E($%S<VEN871U<F$`4F5P^F)L:6-A(&1E(%-I;F=A<'5R80!486UA;FAO
M`%-A;'1A<B!-86YU=&5NY^-O`$[C;R!P<F]C97-S861O+BXN`$5S;&]VX7%U
M:6$`4F5P^F)L:6-A(&1A($5S;&]VZ6YI80!.979E`$YE=N-O`$YE=O5E<P!.
M97;U97,@36%T:6YA:7,`3F5V]65S(%9E<W!E<G1I;F]S`$%L='5R82!D92!N
M979E.B``36]S=')A<B!E<75I=F%L96YT92!N82#A9W5A.B``26QH87,@4V%L
M;VWC;P!3;VWA;&EA`$-A;N?U97,@92!0;V5M87,`1&ER96/GXV\@9&4@3W)D
M96YAY^-O`%-E;&5CY^-O(&1O('-E;G1I9&\@9&$@;W)D96YAY^-O`$5N9&5R
M9>=O(&1E(&]R:6=E;0!&;VYT97,`P69R:6-A(&1O(%-U;`!%=7)O<&$@9&\@
M4W5L("A)4T\M.#@U.2TS*0!'9?-R9VEA(&1O(%-U;"!E($EL:&%S(%-A;F1W
M:6-H(&1O(%-U;`!(96UI<V;I<FEO(%-U;`!%<W!AYV\@96YT<F4@8^EL=6QA
M<R!A9&IA8V5N=&5S`$5S<&'G;R!E;G1R92!O(&-O;G1E^F1O(&4@82!B;W)D
M82!D92!U;6$@8^EL=6QA`$5S<&'G861O<@!%<W!AYV%M96YT;P!%<W!AYV%M
M96YT;R!E(&5N8VAI;65N=&\`4F5I;F\@9&4@17-P86YH80!#;W)R96EO(&[C
M;R!S;VQI8VET861O`$EN<V5R:7(@0V%R86-T97(@17-P96-I86P`17-P96-I
M9FEQ=64@;VYD92!P<F5T96YD92!Q=64@87!A<F7G86T@;W,@<F5S=6QT861O
M<R!D82!P<F]C=7)A+@!$:79I9&ER(&/I;'5L80!!9&EC:6]N87(@8V]L=6YA
M`$1I=FED:7(@;&EN:&$`1&5S<&]R=&]S`%)E</IB;&EC82!$96UO8W+A=&EC
M82!3;V-I86QI<W1A(&1O(%-R:2!,86YK80!0861RXV\`4W1A<B!4<F5K`$%N
M;R!D92!I;NUC:6\`17-T861O(&]U(%!R;W;M;F-I80!3=&%T=7,`17-T861O
M(&1A(&QO8V%L:7IAY^-O("5S+BXN(`!&;W)M871O(&1E(&%R;6%Z96YA;65N
M=&\`16YD97)EYV\@9&4@4G5A`%)A<W5R861O`$QI<W1A(&1E(&-A9&5I87,@
M9&4@8V%R86-T97)E<P!2971I<F%R(&1O;>UN:6\@9&\@96YD97)EYV\`17-T
M:6QO(%M#4U-=`&1O`$%S<W5N=&\`4W5B;65T97(`1F]I('-U8FUE=&ED;R!P
M961I9&\@<&%R82!A9&EC:6]N87(@(B5S(B!A;R!S:7-T96UA+B!.XV\@<&]D
M97+A(&5N=')A<B!E;G%U86YT;R!O('-E=2!P961I9&\@;N-O(&9O<B!A<')O
M=F%D;RX`26YF97)I;W(@X"!L:6YH80!3=6-E<W-O`"(E<R(@861I8VEO;F%D
M;R!C;VT@<W5C97-S;R!A;R!S:7-T96UA+@!!9&EC8>?C;R!D92`E<R!A("5S
M('1E=F4@<W5C97-S;P!,:6UP97IA(&1O('-I<W1E;6$@9&]S(&1A9&]S(&1O
M('5T:6QI>F%D;W(@(B5S(B!R96%L:7IA9&$@8V]M('-U8V5S<V\N`%)E;6_G
MXV\@9&4@(B5S(B!C;VT@<W5C97-S;RX`4F5M;^?C;R!D92`B)7,B(&1O('-I
M<W1E;6$@8V]M('-U8V5S<V\N`$-O;F9I9W5R8>?C;R!R979E<G1I9&$@8V]M
M('-U8V5S<V\N(%)E8V%R<F5G=64@<&%R82!V97(@87,@;75D86[G87,N`$-O
M;F9I9W5R8>?C;R!D92!S86QV86=U87)D82!G=6%R9&%D82!C;VT@<W5C97-S
M;RX`1FEC:&5I<F\@9&4@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A("5S
M(&=U87)D861O(&-O;2!S=6-E<W-O+@`B)7,B(&%C='5A;&EZ861O(&-O;2!S
M=6-E<W-O`"5S(&5S8W)I=&\@8V]M('-U8V5S<V\`4F5P^F)L:6-A(&1O(%-U
M9.-O`%)E<W5M;P!.87-C97(@9&\@4V]L`%#T<B!D;R!3;VP`4V]L87)E;F=O
M`$YA<V-E<B!D;R!3;VP`3F%S8V5R+U#T<B!D;R!3;VP`3F%S8V5R(&1O(%-O
M;#H@`%#T<B!D;R!3;VP`4/1R(&1O(%-O;#H@`%-U<&5R:6]R(.`@;&EN:&$`
M4W5P;W)T90!3=7)I;F%M90!!<&5L:61O`%-V86QB87)D(&4@2F%N($UA>65N
M`%)E:6YO(&1A(%-U87II;.)N9&EA`%)E:6YO(&1A(%-UZ6-I80!3=>WG80!%
M<G)O(&1E('-I;G1A>&4@;F]S('1E<FUO<R!D92!P<F]C=7)A`%)E</IB;&EC
M82#!<F%B92!3[7)I80!496UP;W)A;"U4`%1E;7!O<F%L+50@92!696YT;W-O
M`%1E;7!O<F%I<RU4`%1E;7!O<F%I<RU4($UA=&EN86ES`%135@!!<G%U:79O
M(%135@!686QO<F5S('-E<&%R861O<R!P;W(@=&%B=6QAY_5E<P!486)E;&$`
M4')O<')I961A9&5S(&1A(%1A8F5L80!0<F]P<FEE9&%D97,@9&$@=&%B96QA
M`$9O<FUO<V$`1F]R;6]S80!297#Z8FQI8V$@9&\@5&%D:FEQ=6ES=.-O`%1A
M;GKB;FEA`$%L=F\Z`%1A<F5F87,`3OIM97)O(&1E(%1E;&5F;VYE`%1E;7!E
M<F%T=7)A(&1A(/IL=&EM82!H;W)A.@!496UP97)A='5R80!496UP97)A='5R
M83H@`%1E;7!E<F%T=7)A/&)R("\^*"5S06QT825S+R5S0F%I>&$E<RD@)F1E
M9SLE<P!/(&UO9&5L;R`B)7,B(&[C;R!F;VD@96YC;VYT<F%D;RX`061M:6YI
M<W1R8>?C;R!D92!-;V1E;&]S`%1E>'1O`$%P96YA<R!497AT;P!!;&EN:&%M
M96YT;R!D;R!T97AT;P!4;W!O(&1O('1E>'1O`#6J`%1A:6QA;F3J<R`H5$E3
M+38R,"D`4F5I;F\@9&$@5&%I;.)N9&EA`$]B<FEG861O('!O<B!U<V%R(&5S
M=&4@<VES=&5M82X`3R!A<G%U:79O(&1E(&%J=61A("5S('!A<F$@)7,@;N-O
M(&5X:7-T92!A:6YD82X@0W)I86YD;R!U;2!N;W9O+@!!(&5X=&5N<^-O($94
M4"!NXV\@97-TX2!D:7-P;V[M=F5L+@!/(&5N9V5N:&\@9&4@:6YT96=R8>?C
M;R!(;W)D92]+;VQA8B!NXV\@<W5P;W)T82`B)7,B`$\@<F5G:7-T;R`H(FQO
M9R(I($E-4U`@;N-O('#T9&4@<V5R(&EN:6-I86QI>F%D;RX`02!C;&%S<V4@
M36%I;G1E;F%N8V4Z.B!NXV\@9F]I(&-A<G)E9V%D82!C;VT@<W5C97-S;P!!
M(&IA;F5L82!D92!/<.?U97,@9F5C:&]U+B!38>UN9&\N`$\@;&EV<F\@9&4@
M96YD97)EYV]S(&[C;R!P]&1E('-E<B!P=7)G861O.B`E<P!/(&%D;6EN:7-T
M<F%D;W(@=&5M(&1E(&-O;F9I9W5R87(@=6T@;65C86YI<VUO(&1E('!E<FUI
M<W/U97,@<&5R;6%N96YT92!S92!Q=6ES97(@=7-A<B!097)M:7-S]65S+@!!
M<&5N87,@;R!L861O(&EN9F5R:6]R`$\@;OIM97)O(&1E($E$(&1O(&-O;G1A
M8W1O(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E;2!B<F%N
M8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@9&%D;W,N`$\@
M8V]N=&%C=&\@9F]I(&%D:6-I;VYA9&\@X"!L:7-T82!D92!C;VYT86-T;W,@
M8V]M('-U8V5S<V\N`$\@8V]N=&%C=&\@<&5D:61O(&[C;R!E>&ES=&4N`$\@
M8FQO8V\@9&4@87-S:6YA='5R82!01U`@9&5S=&%C861O(.D@;F5C97-SX7)I
M;R!P87)A('9E<FEF:6-A<B!U;6$@;65N<V%G96T@87-S:6YA9&$N`$\@240@
M9&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861O
M+"!F;VD@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O
M(&YA(&)A<V4@9&4@9&%D;W,N`$$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C
M;R!F;VD@97-P96-I9FEC861A+@!!<R!F=6YC:6]N86QI9&%D97,@9&4@96YC
M<FEP=&'GXV\@97AI9V5M('5M82!L:6=AY^-O('-E9W5R82X`3R!A<G%U:79O
M("5S(&1E=F5R:6$@8V]N=&5R('5M(&%T<FEB=71O("5S+@!/(&%R<75I=F\@
M)7,@9&5V97)I82!C;VYT97(@86QG=6YS(&%T<FEB=71O<R`E<RX`3R!F:6-H
M96ER;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A('-I('!R\W!R:6\N`$\@
M9FEC:&5I<F\@;N-O(&-O;G3I;2!D861O<RX`06)A:7AO(&5S=.-O(&]S(&-A
M8F7G86QH;W,@9&5S=&$@;65N<V%G96TO;65N<V%G96T@<F9C.#(R+@!/(&UO
M9&\@9&4@96-RXR!I;G1E:7)O(&-A=7-A('!R;V)L96UA<R!N;R!);G1E<FYE
M="!%>'!L;W)E<BP@9&5V:61O(&$@97)R;W,@;F\@;F%V96=A9&]R('%U92!N
MXV\@8V]N<V5G=6EM;W,@=6QT<F%P87-S87(N("!0;V1E('-U<F=I<B!L:7AO
M+"!P;V1E;2!D97-A<&%R96-E<B!F=6YC:6]N86QI9&%D97,@9&\@961I=&]R
M(&4O;W4@;R!S974@;F%V96=A9&]R('!O9&4@86)O<G1A<BX@4V4@;R!S974@
M<VES=&5M82#I('5M(%=I;F1O=W,@.7@L(.D@;75I=&\@<')O=N%V96P@<75E
M(&]B=&5N:&$@=6T@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@92!P<F5C
M:7-E(&1E(')E:6YI8VEA<B!O('-I<W1E;6$N7&Y<;D9O:2!A=FES861O+B`@
M4&]R(&9A=F]R('!R97-S:6]N92!/2R!S92!A:6YD82!A<W-I;2!Q=6ES97(@
M97AP97)I;65N=&%R(&\@961I=&]R(&1E(&5C<N,@:6YT96ER;RX`3R!F:6-H
M96ER;R!D92!A:G5D82`E<R!NXV\@8V]M9>=A(&-O;2`\/WAM;`!!(&ED96YT
M:61A9&4@(B5S(B!F;VD@<F5M;W9I9&$N`$%P96YA<R!O(&QA9&\@97-Q=65R
M9&\`02!L;V-A;&EZ8>?C;R!D;R!A<G%U:79O(&5X96-U=.%V96P@9&4@1VYU
M4$<@=&5M(&1E('-E<B!I;F1I8V%D82#@(&-L87-S92!#<GEP=%]P9W`Z.BX`
M02!M96YS86=E;2!E;G9I861A(&5M("5S('!A<F$@)7,@8V]M(&%S<W5N=&\@
M(B5S(B!F;VD@;6]S=')A9&$N"D[C;R!HX2!G87)A;G1I82!D92!Q=64@82!M
M96YS86=E;2!T96YH82!S:61O(')E86QM96YT92!L:61A(&]U(&-O;7!R965N
M9&ED82X`3R!N;VUE(&$@=7-A<B!Q=6%N9&\@;&EG86YD;R#@('#A9VEN82!D
M92!C;VUP;W-IY^-O`$\@;?-D=6QO(&]P96YS<VP@Z2!N96-E<W/A<FEO('!A
M<F$@82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BX`02!O<.?C;R`B)7,B
M(&[C;R!P]&1E('-E<B!G=6%R9&%D82P@<&]I<R!O<R!S975S(&1A9&]S(&5X
M8V5D96T@82!D:6UE;G/C;R!MX7AI;6$@<&5R;6ET:61A`$\@<')O9W)A;6$@
M=7-A9&\@<&%R82!V97(@97-T92!T:7!O(&1E(&1A9&]S("@E<RD@;N-O(&9O
M:2!E;F-O;G1R861O(&YO('-I<W1E;6$N`$%P96YA<R!O<R!L861O<R!E<W%U
M97)D;R!E(&1I<F5I=&\`07!E;F%S(&\@;&%D;R!D:7)E:71O`$\@<V5R=FED
M;W(@(B5S(B!F;VD@<F5M;W9I9&\N`$\@<V5R=FED;W(@(B5S(B!F;VD@9W5A
M<F1A9&\N`$\@<&5D:61O(&1E('-U8G-C<FGGXV\@9&4@)7,@9F]I(')E;6]V
M:61O+@!!(&QI;FAA(&EN9&EC861A(&[C;R!E>&ES=&4N`$\@87)Q=6EV;R!T
M96UP;W+A<FEO("(E<R(@;N-O(&5X:7-T92X`07!E;F%S(&]S(&QA9&]S('-U
M<&5R:6]R(&4@:6YF97)I;W(`07!E;F%S(&\@;&%D;R!S=7!E<FEO<@!/<R!D
M861O<R!C87)R96=A9&]S('!E<F1E<F%M+7-E(&1E<V1E(&\@<&%S<V\@86YT
M97)I;W(N`$\@87)Q=6EV;R!C87)R96=A9&\@;N-O('#T9&4@<V5R(&=U87)D
M861O+@!/(&)L;V-O('=E871H97(N8V]M(&[C;R!E<W3A(&1I<W!O;NUV96PN
M`$[C;R!HX2!L:79R;W,@9&4@96YD97)EYV]S(&YA=F5GX79E:7,N`$[C;R!H
MX2!O<.?U97,@9&ES<&]N[79E:7,N`$[C;R!HX2!P87)T97,@<75E('!O<W-A
M;2!S97(@;6]S=')A9&%S(&5M(&QI;FAA+@!.XV\@:.$@;&EV<F]S(&1E(&5N
M9&5R9>=O<R!A;'1E<N%V96ES+B!.96YH=6T@9&]S(&QI=G)O<R!D92!E;F1E
M<F7G;W,@9&ES<&]N[79E:7,@97-TX2!C;VYF:6=U<F%D;R!P87)A('!E<FUI
M=&ER(&$@861IY^-O(&1E(&YO=F%S(&5N=')A9&%S+B!392!A8VAA<B!Q=64@
M:7-T;R#I('5M(&5R<F\L('!O<B!F879O<B!C;VYT86-T92!O(&%D;6EN:7-T
M<F%D;W(@9&\@<VES=&5M82X`2.$@9&5M87-I861O<R!C87)A8W1E<F5S(&YE
M<W1E(&-A;7!O+B!);G1R;V1U>FEU("5S(&-A<F%C=&5R97,[('1E;2!D92!I
M;G1R;V1U>FER(&UE;F]S(&1O('%U92`E<RX`3N-O(&5X:7-T92!A:6YD82!U
M;2!A<G%U:79O(&1E(&%J=61A('!A<F$@)7,N`$]C;W)R974@=6T@<')O8FQE
M;6$@;F$@861IY^-O(&1E("(E<R(@86\@<VES=&5M83H@)7,`3V-O<G)E=2!U
M;2!P<F]B;&5M82!A;R!L:6UP87(@;W,@9&%D;W,@9&\@=71I;&EZ861O<B`B
M)7,B(&1O('-I<W1E;6$N`$]C;W)R974@=6T@<')O8FQE;6$@;F$@<F5M;^?C
M;R!D92`B)7,B(&1O('-I<W1E;6$N`$]C;W)R974@=6T@<')O8FQE;6$@86\@
M86-T=6%L:7IA<B`B)7,B.B`E<RX`2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@
M8V%R<F5G86UE;G1O(&1O(&9I8VAE:7)O.B`E<R!NXV\@9F]I(&-A<G)E9V%D
M;RX`3V-O<G)E=2!U;2!P<F]B;&5M82!C;VT@;R!C87)R96=A;65N=&\@9&\@
M87)Q=6EV;SH@3R`E<R!E>&-E9&4@;R!T86UA;FAO(&WA>&EM;R!P97)M:71I
M9&\@*"5D(&)Y=&5S*2X`3V-O<G)E=2!U;2!P<F]B;&5M82!C;VT@;R!C87)R
M96=A;65N=&\@9&\@87)Q=6EV;SH@3R`E<R!F;VD@87!E;F%S('!A<F-I86QM
M96YT92!C87)R96=A9&\N`$]C;W)R974@=6T@97)R;R!A;R!A9&EC:6]N87(@
M97-T92!C;VYT86-T;RX@0V]N=&%C=&4@;R!S974@861M:6YI<W1R861O<B!D
M92!S:7-T96UA('!A<F$@;V)T97(@86IU9&$N`$]C;W)R974@=6T@97)R;R!A
M;R!C<FEA<B!U;6$@;F]V82!L:7-T82X`3V-O<G)E=2!U;2!E<G)O(')E;6]V
M96YD;R`E<R!D;R!L:79R;R!D92!E;F1E<F7G;W,@9&4@;W)I9V5M+@!/8V]R
M<F5U('5M(&5R<F\@86\@<F5M;W9E<B!E<W1E(&-O;G1A8W1O.B`E<P!/8V]R
M<F5U('5M(&5R<F\@<F5M;W9E;F1O(&5S=&4@;V)J96-T;RX`3V-O<G)E=2!U
M;2!E<G)O(&%O(&UO<W1R87(@82!,:7-T82!S96QE8V-I;VYA9&$N`$]C;W)R
M974@=6T@97)R;R!A;R!M;W-T<F%R(&5S=&$@<&%R=&4@9&$@;65N<V%G96T`
M3V-O<G)E=2!U;2!E<G)O(&%O(&EM<&]R=&%R(&1A9&]S(&1E(&-O;G1A8W1O
M+@!/8V]R<F5U('5M(&5R<F\@;F$@:6UP;W)T8>?C;R!D92!D861O<SH@)7,`
M3V-O<G)E=2!U;2!E<G)O(&YA(&EM<&]R=&'GXV\@9&4@9&%D;W,@:4-A;&5N
M9&%R+@!/8V]R<F5U('5M(&5R<F\@;F\@9F]R;75LX7)I;R!D92!C;VYF:6=U
M<F'GXV\N(%1A;'9E>B!T96YH82!O;6ET:61O('5M(&-A;7!O(&]B<FEG873S
M<FEO+@!/8V]R<F5U('5M(&5R<F\@86\@86)R:7(@;R!A<G%U:79O("5S+B!%
M>'!E<FEM96YT92!E>&5C=71A<B!T<F%N<VQA=&EO;BYP:'`@8V]M(&$@;W#G
MXV\@+60@<&%R82!C;VYS96=U:7(@=F5R(&%S(&UE;G-A9V5N<R!D92!E<G)O
M(&1O(&%N86QI<V%D;W(@6$U,+@!/8V]R<F5U('5M(&5R<F\@86\@<F5A;&EZ
M87(@82!F=6[GXV\@9&4@;&EV<F\@9&4@96YD97)EYV]S(&5S<&5C:69I8V%D
M82X@4&]R(&9A=F]R('1E;G1E(&1E(&YO=F\@;6%I<R!T87)D92X`3V-O<G)E
M=2!U;2!E<G)O(&YA(')E;6_GXV\@9&5S=&4@;V)J96-T;RX`3V-O<G)E=2!U
M;2!E<G)O(&%O(&%C='5A;&EZ87(@;W,@<&]R;65N;W)E<R!D;R!C;VYT86-T
M;RX@4&]R(&9A=F]R('1E;G1E(&1E(&YO=F\@;6%I<R!T87)D92X`3V-O<G)E
M=2!U;2!E<G)O(&%O(&%C='5A;&EZ87(@82!L:7-T82!D92!D:7-T<FEB=6GG
MXV\N(%!O<B!F879O<B!T96YT92!D92!N;W9O(&UA:7,@=&%R9&4N`$]C;W)R
M974@=6T@97)R;R!A;R!A8W1U86QI>F%R(&5S=&$@96YT<F%D83H@)7,`3N-O
M(&AA=FEA(&5N9&5R9>=O<R!A(&5X<&]R=&%R+@!%<W1E('-E<G9I9&]R($E-
M05`@;N-O('-U<&]R=&$@<&%R=&EL:&$@9&4@<&%S=&%S+@!/(&QI=G)O(&1E
M(&5N9&5R9>=O<R!S\R!P97)M:71E(&QE:71U<F$`3N-O('!A<F5C92!S97(@
M=6T@87)Q=6EV;R!R87(@=N%L:61O+@!.XV\@<&%R96-E('-E<B!U;2!A<G%U
M:79O('II<"!VX6QI9&\N`$[C;R!P87)E8V4@<V5R('5M82!N^FUE<F\@9&4@
M8V%R=.-O(';A;&ED;RX`17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV
M:6\@9&4@;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2P@=7-A;F1O(&$@05!)($A45%``17-T92!C;VYT
M<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@;65N<V%G96YS(&%T<F%VZ7,@
M9&\@<VUS,FUA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=7-A;F1O(&$@
M05!)($A45%``17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@
M;65N<V%G96YS('9I82!33510(&%T<F%VZ7,@9&$@5F]D869O;F4@273A;&EA
M(&4@87!E;F%S('!A<F$@;OIM97)O<R!6;V1A9F]N92X@17AI9V4@=6UA(&-O
M;G1A(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@;F$@5F]D869O;F4@273A;&EA
M("AH='1P.B\O=W=W+C$Y,"YI="DN`$5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I
M;RX`17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@:6YT96ER;W,N`$5S
M=&4@8V%M<&\@<&]D92!A<&5N87,@8V]N=&5R(&[Z;65R;W,@92!O('/M;6)O
M;&\@9&]I<RUP;VYT;W,N`$5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S
M('9A;&]R97,@;V-T86ES+@!%<W1E(&-A;7!O('1E;2!D92!C;VYT97(@=6UA
M(&QI<W1A(&1E(&EN=&5I<F]S('-E<&%R861O<R!P;W(@97-P8>=O<R!O=2!V
M[7)G=6QA<RX`17-T92!C86UP;R!T96T@9&4@<V5R('5M(&[Z;65R;R!VX6QI
M9&\N`$5S=&4@8V%M<&\@=&5M(&1E(&-O;G1E<B!U;2!C\V1I9V\@9&4@8V]R
M(&YO(&9O<FUA=&\@4D="(&AE>&%D96-I;6%L+"!P;W(@97AE;7!L;R`G(S$R
M,S1A9B<N`$5S=&4@9F]R;6%T;R!D92!F:6-H96ER;R!NXV\@Z2!S=7!O<G1A
M9&\N`$5S=&4@;6]D96QO(&KA(&9O:2!P<F]C97-S861O+@!)<W1O(.D@)7,N
M`$5S=&4@Z2!U;2!O8FIE8W1O($MO;&%B($=R;W5P=V%R92X@4&%R82!V97(@
M97-T92!O8FIE8W1O('!R96-I<V$@9&4@=6T@8VQI96YT92!D92!C;W)R96EO
M(&5L96-T<O-N:6-O('%U92!C;VYH9>=A(&\@9F]R;6%T;R!+;VQA8B!'<F]U
M<'=A<F4N(%!A<F$@=6UA(&QI<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@
M96QE8W1R\VYI8V\@;F5S<V%S(&-I<F-U;G-TXFYC:6%S('9I<VET92`E<P!%
M<W1A(&UE;G-A9V5M(&9O:2!E<V-R:71A(&YU;2!C\V1I9V\@*"5S*2!D:69E
M<F5N=&4@9&\@<V5U+@!%<W1E(&[Z;65R;R!P<F5C:7-A(&1E('-E<B!P96QO
M(&UE;F]S('5M+@!%<W1A('!E<W-O82!JX2!T96T@=6UA(&5N=')A9&$@)7,@
M;F\@<V5U(&QI=G)O(&1E(&5N9&5R9>=O<RX`17-T92`B<V-R:7!T(B!T96T@
M<V5R(&5X96-U=&%D;R!A('!A<G1I<B!D92!U;6$@;&EN:&$@9&4@8V]M86YD
M;W,N`$5S=&4@<V5R=FED;W(@;N-O(&-O;G-E9W5E(&1E<V-O;7!R:6UI<B!A
M<G%U:79O<R!Z:7`@;W4@9WII<"X`17-T92!S:7-T96UA(&5N8V]N=')A+7-E
M(&1E<V%C=&EV861O+@!%<W1A('9A;&]R('1E;2!D92!S97(@=6T@;OIM97)O
M+@!%<W1A(&IA;F5L82!T96T@9&4@<V5R(&-H86UA9&$@82!P87)T:7(@9&4@
M=6UA(&IA;F5L82!D92!/<.?U97,`5')O=F]A9&$`0FEL:&5T97,`1&%T82](
M;W)A`%-E9W5I;65N=&\@5&5M<&]R86P`1F]R;6%T;R!D;R!T96UP;P!396QE
M8^?C;R!D871A+VAO<F$`5&EM;W(M3&5S=&4`5.UT=6QO`%3M='5L;R`H9&EC
M82DZ`%!A<F$`4&%R82!S96QE8V-I;VYA<B!M^FQT:7!L;W,@:71E;G,L(&-A
M<G)E9W5E(&5M($-O;G1R;VP@*%!#*2!O=2!#;VUM86YD("A-86,I(&5N<75A
M;G1O(&-L:6-A<BX`2&]J90!4<F]C87(@1F]N=&4@2%1-3`!297#Z8FQI8V$@
M5&]G;VQE<V$`5&]Q=65L874`06UA;FCC`%)E:6YO(&1O(%1O;F=A`%1O<&\`
M36]L9'5R82!D92!T;W!O("A?=&]P*0!4<F%D=7II9&%S`%1R861UY_5E<P!4
M<FEN9&%D92!E(%1O8F%G;P!697)D861E:7)O(&]U(&9A;'-O`#.J`%)E</IB
M;&EC82!D82!4=6[M<VEA`%)E</IB;&EC82!D82!4=7)Q=6EA`%1U<F-O("A)
M4T\M.#@U.2TY*0!4=7)Q=65M96YI<W3C;P!);&AA<R!4=7)C87,@92!#86EC
M;W,`5'5V86QU`$5S8W)E=F$@82!S=6$@97-C;VQH83H`S6YD:6-E(%4N5BXZ
M(`!54DP`55),(&1O('-E=2!R96QA=/-R:6\@9&4@97-T861O(&1O(&5N=FEO
M(&1E(")S8W)I<'1S(@!54DPZ`%)E</IB;&EC82!D;R!59V%N9&$`56-RXFYI
M80!.XV\@9F]I('!O<W/M=F5L(&%C961E<B#@('!A<W1A(%9&4RX`3N-O(&9O
M:2!P;W-S[79E;"!A9&EC:6]N87(@:6YF;W)M8>?C;R!D92!U=&EL:7IA9&]R
M(&5X=')A(&%Q=6%N9&\@9&$@<W5B<V-R:>?C;RX`3N-O(&9O:2!P;W-S[79E
M;"!M=61A<B!A<R!P97)M:7-S]65S(&1O(&%R<75I=F\@5D93("(E<R(N`$[C
M;R!F;VD@<&]S<^UV96P@;75D87(@87,@<&5R;6ES<_5E<R!D;R!A<G%U:79O
M(%9&4R`E<R\E<RX`3N-O(&9O:2!P;W-S[79E;"!M=61A<B!P87)A("5S+@!.
MXV\@9F]I('!O<W/M=F5L(&QI9V%R(&%O('-E<G9I9&]R(%-13"X`3N-O(&9O
M:2!P;W-S[79E;"!L:6=A<B!U<V%N9&\@4U-,+@!.XV\@9F]I('!O<W/M=F5L
M(&-O<&EA<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R
M(&$@<&%S=&$@5D93("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!P
M87-T82!61E,N`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@;R!A<G%U:79O(%9&
M4RX`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!U;2!A<G%U:79O(%9&4R!V87II
M;RX`3N-O(&9O:2!P;W-S[79E;"!D97-C;VUP<FEM:7(@;W,@9&%D;W,N`$[C
M;R!F;VD@<&]S<^UV96P@<F5M;W9E<B`B)7,B+"!P;VES(&$@<&%S=&$@;N-O
M(&5S=.$@=F%Z:6$N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B`B)7,B.B`E
M<RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R("5S+"!P;VES(&$@<&%S=&$@
M;N-O(&5S=.$@=F%Z:6$`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S
M=&$@5D93(')E8W5R<VEV86UE;G1E+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V
M97(@82!P87-T82!61E,N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A
M<W1A(%9&4SH@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&%R<75I
M=F\@5D93("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&%R<75I
M=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@<F5C=7)S:79A;65N
M=&4Z("5S+@!.XV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@82!P87-T82!C
M;W)R96YT92X`3N-O(&9O:2!P;W-S[79E;"!E>'1R86ER(&]S('!O<FUE;F]R
M97,@9&\@8V5R=&EF:6-A9&\`26UP;W-S[79E;"!L97(@82!D969I;FGGXV\@
M9&4@)7,N`$[C;R!F;VD@<&]S<^UV96P@;6]V97(@;R!A<G%U:79O(%9&4RX`
M3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@5D93("(E<R(N`$[C
M;R!F;VD@<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(%9&4R!P87)A(&5S8W)I
M=&$N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(%9&4RX`3N-O
M(&9O:2!P;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@8V]M<')I;6ED;RX`3N-O
M(&-O;G-I9V\@;&5R(&\@87)Q=6EV;SH@`$[C;R!F;VD@<&]S<^UV96P@;&5R
M(&$@<&%S=&$@=F9S<F]O="X`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B`E
M<R!C;VUO("5S.B!A('!A<W1A(&1E(&1E<W1I;F\@:N$@97AI<W1E`$[C;R!F
M;VD@<&]S<^UV96P@<F5N;VUE87(@82!P87-T82!61E,N`$[C;R!F;VD@<&]S
M<^UV96P@<F5N;VUE87(@82!P87-T82!61E,Z("5S+@!.XV\@9F]I('!O<W/M
M=F5L(')E;F]M96%R(&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S
M[79E;"!R96YO;65A<B!O(&%R<75I=F\@5D93("5S+R5S+@!.XV\@9F]I('!O
M<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L
M(&5X96-U=&%R("=M:VES;V9S)RX`3N-O(&9O:2!P;W-S[79E;"!C;VYV97)T
M97(@97-T92!D;V-U;65N=&\@5V]R9`!.XV\@9F]I('!O<W/M=F5L(&5S8W)E
M=F5R(&%R<75I=F\@5D93("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V
M97(@;R!A<G%U:79O(%9&4R`H8V]P>2@I(&9A;&AO=2DN`$[C;R!C;VYS:6=O
M(')E;6]V97(@)R5S)SH@)7,N`%-U8FQI;FAA9&\`5F]L=&%R(&%T<N%S(&YA
M<R!A;'1E<F'G]65S`$1E<V9A>B!A('-U82#Z;'1I;6$@86/GXV\`4F5S<&]S
M=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!N82!C;VYE>.-O.B``4F5S<&]S
M=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!A.B``4V5M(&-A=&5G;W)I80!5
M;FEC;V1E("A55$8M."D`16UI<F%D;W,@P7)A8F5S(%5N:61O<P!296EN;R!5
M;FED;P!%<W1A9&]S(%5N:61O<R!D82!!;>ER:6-A`$EL:&%S($UE;F]R97,@
M1&ES=&%N=&5S(&1O<R!%<W1A9&]S(%5N:61O<P!5;FED861E<P!$97-C;VYH
M96-I9&\`87!I;7-G:60@*$E$(&1E($UE;G-A9V5M(&1E($%022DN`&-L:6US
M9VED(&1E<V-O;FAE8VED;R`H240@9&4@365N<V%G96T@9&4@0VQI96YT92DN
M`$-O;6%N9&\@9&5S8V]N:&5C:61O.B`E<P!&;VD@9F]R;F5C:61A('5M82!L
M;V-A;&EZ8>?C;R!D97-C;VYH96-I9&$N`$YO;64@9&4@=71I;&EZ861O<B!O
M=2!P86QA=G)A+7!A<W-E(&5R<F%D;W,`4F5M;W9E<B!L:6=AY^-O(&1O(&5L
M96UE;G1O(&-O<G)E;G1E`%-E;2!N;VUE`%!O<B!R87KU97,@9&4@<V5G=7)A
M;N=A+"`B<V-R:7!T<R(@<V5M('!R:79I;.EG:6\@;N-O('!O9&5M(&%C961E
M<B!A($-O<G1A<B]#;W!I87(O0V]L87(@<')O9W)A;6%T:6-A;65N=&4N($-A
M<G)E9W5E(&5M($]+('!A<F$@=F5R('5M82!N;W1A('3I8VYI8V$@96T@;6]Z
M:6QL82YO<F<@<75E(&QH92!M;W-T<F%RX2!C;VUO(&%U=&]R:7IA<B!U;2`B
M<V-R:7!T(B!A(&%C961E<B!A;W,@<F5C;W)T97,N`%)E;6]V97(@8V]L;W)A
MY^-O`%1I<&\@9&4@8V]N=&7Z9&\@*$-O;G1E;G0M5'EP92D@;N-O(.D@<W5P
M;W)T861O+@!%>'1E;G/C;R!NXV\@4W5P;W)T861A`%!O<B!T<F%D=7II<@!-
M;V1I9FEC87(`06-T=6%L:7IA<B`E<P!!8W1U86QI>F%R('5T:6QI>F%D;W(`
M(B5S(B!A8W1U86QI>F%D;RX`06-T=6%L:7IA;F1O(&%R<75I=F\@9&4@86IU
M9&$@)7,@<&%R82`E<RX`(E-C<FEP="(@9&4@86-T=6%L:7IAY^-O(')E;6]V
M:61O+@!5<&QO860`0V%R<F5G861O<R!N;R!S97)V:61O<B!T;V1O<R!O<R!A
M<G%U:79O<R!D92!I;G-T86QAY^-O(&1E(&%P;&EC8>?U97,N`$QE=')A<R!L
M871I;F%S(&5M(&UA:?IS8W5L87,`3OIM97)O<R!R;VUA;F]S(&5M(&UA:?IS
M8W5L87,`4F5P^F)L:6-A($]R:65N=&%L(&1O(%5R=6=U86D`571I;&EZ8>?C
M;SH`57-A<B!O($-O<G)E;G1E.B`E<P!5<V%R(%-33"X`57-A<B!S92!O(&YO
M;64@9&4@=71I;&EZ861O<B!O=2!A('!A;&%V<F$M<&%S<V4@9F]R96T@9&EF
M97)E;G1E<R!N;R!S97)V:61O<B!)35-0+@!5=&EL:7IA9&]R("5S(&[C;R!E
M<W3A(&%U=&]R:7-A9&\@<&%R82`E<RX`061M:6YI<W1R8>?C;R!D92!5=&EL
M:7IA9&]R97,`3W#G]65S(&1O(%5T:6QI>F%D;W(`4F5G:7-T;R!D92!5=&EL
M:7IA9&]R97,`3R!296=I<W1O(&1E(%5T:6QI>F%D;W)E<R!E<W3A(&EN86-T
M:79O+@!097)M:7-S]65S(&1O('5T:6QI>F%D;W(`3F]M92!D92!5=&EL:7IA
M9&]R`$\@3F]M92!D92!5=&EL:7IA9&]R("(E<R(@:N$@97AI<W1E+@!.;VUE
M(&1E(%5T:6QI>F%D;W(Z`$YO;64@9&4@571I;&EZ861O<CH@`%5T:6QI>F%D
M;W)E<P!5=&EL:7IA9&]R97,@9&\@<VES=&5M83H`4F5P^F)L:6-A(&1O(%5Z
M8F5Q=6ES=.-O`$$@<&%S=&$@5D93(&[C;R!E>&ES=&4N`$%U<^IN8VEA`$%S
M(&QO8V%L:7IAY_5E<R!VX6QI9&%S(&5N8V]N=')A9&%S(&EN8VQU96TZ`%9A
M;&ED861E+@!686QO<B!E;2!M:6YU=&]S(&$@<&%R=&ER(&1E<W1E(&EN<W1A
M;G1E+@!686QO<B!E>&-E9&4@;R!C;VUP<FEM96YT;R!MX7AI;6\@9&4@)7,N
M`%9A;&]R97,`4&]S<^UV96P@=F%L;W)E<R!A(&5S8V]L:&5R`%9A;G5A='4`
M5F%R:>%V96P`5F5N97IU96QA`%9E<FEF:6-AY^-O(&9A;&AO=2`M(&5S=&$@
M;65N<V%G96T@<&]D92!T97(@<VED;R!A9'5L=&5R861A+@!$:7)E8W3S<FEO
M(%9E<FES:6=N`%9E<G/C;P!#;VYT<F]L;R!D92!697)S]65S`$%L:6YH86UE
M;G1O(%9E<G1I8V%L`$-A;.=O(%9E<G1I8V%L`%9E<G1I8V%L.@!-=6ET;R!!
M;'1O`%)E</IB;&EC82!3;V-I86QI<W1A(&1O(%9I971N86UE`%9I971N86UI
M=&$@*%9)4T-)22D`5F5R("(E<R(`5FES=6%L:7IA<B`E<P!697(@0V]N=&%C
M=&\`5F5R('5M82!PX6=I;F$@97AT97)N80!6:7-U86QI>F%R(&-O;6\@)7,`
M5FES=6%L:7IAY^-O(&$@;6]S=')A<B!P;W(@9&5F96ET;SH`26QH87,@5FER
M9V5N<R!"<FETXFYI8V%S`$EL:&%S(%9I<F=E;G,@06UE<FEC86YA<P!6:7-I
M8FEL:61A9&4`5FES:6)I;&ED861E.B``5F]D869O;F4@273A;&EA('9I82!3
M3510`$%625,`051%3L?#3R$A(2!214U/5D$@3R`B4T-225!4(B!-04Y504Q-
M14Y412!$12`E<RX`5V%L;&ES(&4@1G5T=6YA`$%V:7-O`$%V:7-O.B``-*H`
M4')E=FESXV\@9&\@5&5M<&\`1&%D;W,@;65T96]R;VSS9VEC;W,@9F]R;F5C
M:61O<R!P;W(`5V5A=&AE<BYC;VT`5V5B`%#A9VEN80!54DP@9&$@<.%G:6YA
M(%=E8@!396UA;F%L;65N=&4`0F5M+79I;F1A*&\I`$)E;2UV:6YD82AO*2!A
M("5S`$)E;2UV:6YD82AO*2P@)7,`3V-I9&5N=&%L("A)4T\M.#@U.2TQ*0!/
M8VED96YT86P@*$E33RTX.#4Y+3$U*0!386%R80!1=64@87!L:6-AY^-O(&1E
M=F4@;R`E<R!M;W-T<F%R(&%P\W,@82!E;G1R861A/P!1=6%L(.D@;R!C87)A
M8W1E<F4@9&5L:6UI=&%D;W(_`%%U86P@Z2!O(&-A<F%C=&5R92!D92!C:71A
MY^-O/P!1=64@9F%S97,`475E(")P;'5G:6YS(B!A8W1I=F%R('!A<F$@82!%
M9&GGXV\@4FEC82X`3&%R9W5R80!,87)G=7)A(&5M('5N:61A9&5S($-34P!,
M87)G=7)A(&1O($UE;G4@)7,@X"!E<W%U97)D82`H=&5M(&5F96ET;R!N82!P
M<O-X:6UA(&5N=')A9&$I.@!,87)G=7)A(&1A('1A8F5L80!5;FED861E(&1E
M(&QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT;P!696YT;R!-871I;F%L`%9E
M;&]C:61A9&4@9&\@=F5N=&\@96T@;O-S`%9E;G1O.@!696YT;SH@`%-A8F5D
M;W)I80!,:7-T87,@9&4@1&5S96IO<P!4<F%B86QH;P!%;F1E<F7G;R!D;R!%
M;7!R96=O`$-I9&%D92!D;R!%;7!R96=O`%!A[7,@9&\@16UP<F5G;P!496QE
M9F]N92!D;R!%;7!R96=O`$/S9&EG;R!0;W-T86P@9&\@16UP<F5G;P!%<W1A
M9&\O4')O=NUN8VEA(&1O($5M<')E9V\`4G5A(&1O($5M<')E9V\`17-C<F5V
M96YD;R!A<G%U:79O(&1E(&%J=61A(&%C='5A;&EZ861O('!A<F$@)7,N`%)E
M9F5RZFYC:6%S(&-R=7IA9&%S`%)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y=C,`
M571I;&EZ8>?C;R!D92!#:&%V92!%>'1E;F1I9&$@6#4P.78S`$YO;64@06QT
M97)N871I=F\@9&4@4W5J96ET;R!8-3`Y=C,`261E;G1I9FEC861O<B!#:&%V
M92!D92!3=6IE:71O(%@U,#EV,P!%>'1E;G/U97,@6#4P.78S`$%!`$%!04$`
M36%P82!986AO;R$`06YU86QM96YT90!)Z6UE;@!3:6T`4VEM+"!#;VYC;W)D
M;P!%<W3A(&$@8W)I87(@=6UA(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX`17-T
MX2!E;2!-3T1/(&1E(%1%6%0N("!5<V4@;R!B;W3C;R!;/#Y=('!A<F$@=')O
M8V%R('!A<F$@;R!M;V1O(%9)4U5!3"X`3N-O(&5S=.$@875T96YT:6-A9&\N
M`$[C;R!P;V1E('1E<B!O(&-A<F%C=&5R92`G7"<@;F\@<V5U(&YO;64@8V]M
M<&QE=&\N`$[C;R!I;G1R;V1U>FEU('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@
M96QE8W1R\VYI8V\@=N%L:61O+@!.XV\@;6%P96]U(&YE;FAU;2!C86UP;R!D
M;R!A<G%U:79O(&EM<&]R=&%D;R!P87)A(&]S(&-A;7!O<R!C;W)R97-P;VYD
M96YT97,@96T@)7,N`$[C;R!T96T@<&5R;6ES<^-O('!A<F$@=F5R(&5S=&4@
M8V]N=&%C=&\N`$[C;R!T96T@<&5R;6ES<^-O('!A<F$@=F5R(&5S=&4@;V)J
M96-T;RX`06-A8F]U(&1E('-A:7(N`%1E;2!D92!I;G1R;V1U>FER('5M(&[Z
M;65R;R!D92!T96QE;?-V96P@=N%L:61O+"!S\R!C;VT@9.UG:71O<RP@;6%S
M(&-O;2!U;2`G*R<@;W!C:6]N86P@<&%R82!O('!R969I>&\@:6YT97)N86-I
M;VYA;"X`5&5M(&1E(&EN=')O9'5Z:7(@=6T@=F%L;W(@=N%L:61O+@!496T@
M9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@8N%S:6-O('!A<F$@1&%T851R
M964@<V4@<75I<V5R('5S87(@4W5B<V-R:>?U97,`5&5M(&1E(&-O;F9I9W5R
M87(@=6T@;65C86YI<VUO(&)A<V4@<&%R82!O(%9&4RX`1&5V92!D97-C<F5V
M97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R:6\N`%1E
M;2!D92!I;G1R;V1U>FER(&\@55),(&1O(')E8W5R<V\@<75E(&5S=&$@;&EG
M8>?C;R!S92!R969E<F4`5&5M(&1E('-E;&5C8VEO;F%R('5M(&QI=G)O(&1E
M(&5N9&5R9>=O<R!A;'9O+@!496T@9&4@<V5L96-C:6]N87(@=6UA(&QI<W1A
M(&%L=F\N`%1E;2!D92!S96QE8V-I;VYA<B!U;2!S97)V:61O<B!A(')E;6]V
M97(N`%1E;2!D92!S96QE8V-I;VYA<B!P<FEM96ER;R!P96QO(&UE;F]S('5M
M82!E;G1R861A+@!$979E(&5S<&5C:69I8V%R(&\@=71I;&EZ861O<B!A(&QI
M;7!A<BX`1&5V92!E<W!E8VEF:6-A<B!O(&YO;64@9&\@=71I;&EZ861O<B!A
M(')E;6]V97(N`%1E;2!D92!E<W!E8VEF:6-A<B!O(&YO;64@9&\@=71I;&EZ
M861O<B!A(&%D:6-I;VYA<BX`5&5M(&1E(&5S<&5C:69I8V%R(&\@=71I;&EZ
M861O<B!A(&%C='5A;&EZ87(N`%1E;2!D92!E<W!E8VEF:6-A<B!A(&%CY^-O
M(&$@9&5S96UP96YH87(N`%1E;2!D92!I;G1R;V1U>FER('5M(&YO=F\@;F]M
M92!D92!C871E9V]R:6$N`%1E;2!D92!F;W)N96-E<B!U;2!N^FUE<F\@9&4@
M=&5L969O;F4@:71A;&EA;F\`4_,@=&5M('!E<FUI<W/C;R!P87)A('9E<B!E
M<W1E(&-O;G1A8W1O+@!!('-U82!S97-SXV\@)7,@97AP:7)O=2X@4&]R(&9A
M=F]R(&5N=')E(&1E(&YO=F\N`$\@<V5U($5N9&5R9>=O(&1E($-O<G)E:6\@
M16QE8W1R\VYI8V\Z`$\@<V5U(&5N9&5R9>=O(")$93HB`$$@<W5A($EN9F]R
M;6'GXV\`3R!S974@96YD97)EYV\@25`@<&%R96-E('1E<B!M=61A9&\@9&5S
M9&4@;R!I;NUC:6\@9&$@<V5S<^-O("5S+B!087)A(&=A<F%N=&ER(&$@<W5A
M('-E9W5R86[G82P@9&5V92!A=71E;G1I8V%R+7-E(&1E(&YO=F\N`$\@4V5U
M($YO;64`3R!S974@;65C86YI<VUO(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P
M;W)T82!A9&GGXV\@9&4@=71I;&EZ861O<F5S(&]U(&5S=&$@;W#GXV\@9F]I
M(&1E<V%C=&EV861A('!O<B!A;&=U;2!O=71R;R!M;W1I=F\N`$\@<V5U(&UE
M8V%N:7-M;R!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@;&ES=&%G96T@
M9&4@=71I;&EZ861O<F5S(&]U(&5S=&$@;W#GXV\@9F]I(&1E<V%C=&EV861A
M('!O<B!A;&=U;2!O=71R;R!M;W1I=F\N`$\@<V5U(&YA=F5G861O<B!P87)E
M8V4@=&5R(&UU9&%D;R!D97-D92!O(&EN[6-I;R!D82!S97-SXV\@)7,N(%!A
M<F$@9V%R86YT:7(@82!S=6$@<V5G=7)A;N=A+"!D979E(&%U=&5N=&EC87(M
M<V4@9&4@;F]V;RX`3R!S974@;F%V96=A9&]R(&[C;R!S=7!O<G1A(&5S=&$@
M9G5N8VEO;F%L:61A9&4N`$\@<V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E
M<W1A(&]PY^-O(&1E(&EM<')E<W/C;RX@4')E<W-I;VYE($-O;G1R;VPO0V]M
M;6%N9"`K(%`@<&%R82!I;7!R:6UI<BX`1G5S;R!H;W+A<FEO(&%C='5A;#H`
M3R!S974@;&EV<F\@9&4@96YD97)EYV]S('!O<B!O;6ES<^-O(&[C;R#I(&YA
M=F5GX79E;"X`261E;G1I9&%D92!P861RXV\Z`$YO;64@8V]M<&QE=&\`02!S
M=6$@=F5R<^-O(&1O(&=E='1E>'0@Z2!D96UA<VEA9&\@86YT:6=A+"!NXV\@
M<W5P;W)T86YD;R!02%`@9&4@9F]R;6$@;F%T:79A+B!.96T@=&]D87,@87,@
M8V%D96EA<R!D92!C87)A8W1E<F5S('-E<N-O(&5X=')A[61A<RX`02!S=6$@
M;F]V82!P86QA=G)A+7!A<W-E('!A<F$@)7,@Z3H@)7,`07,@<W5A<R!O<.?U
M97,@9F]R86T@86QT97)A9&%S(&%TZ2!A;R!F:6YA;"!D97-T82!S97-SXV\N
M`$%S('-U87,@;W#G]65S(&9O<F%M(&%C='5A;&EZ861A<RX`02!S=6$@<&%L
M879R82UP87-S92!F;VD@<F5C<FEA9&$`02!S=6$@<&%L879R82UP87-S92!F
M;VD@<F5C<FEA9&$L('9E<FEF:7%U92!O('-E=2!C;W)R96EO(&5L96-T<O-N
M:6-O(&4@96YT<F4@8V]M(&$@<W5A(&YO=F$@<&%L879R82UP87-S92X`3W,@
M<V5U<R!S97)V:61O<F5S(')E;6]T;W,Z`$IU9V]S;.%V:6$`6F%I<F4`6N)M
M8FEA`%II;6)A8G7I`%II<'!Y`%M%<V-O;F1E<B!497AT;R!#:71A9&]=`%M2
M96QA=/-R:6\@9&4@4')O8FQE;6%S72``6TUO<W1R87(@5&5X=&\@0VET861O
M("T`6TUO<W1R87(@5&5X=&\@0VET861O("T@)7,@;&EN:&%S70!;;&EN:&$@
M)7,@9&4@)7-=`%MS96T@=F%L;W)=`%]!9&EC:6]N87(`7T%D;6EN:7-T<F'G
MXV\`7TYA=F5G87(`7T-O;G-O;&$`P7)?=F]R90!?4F5M;W9E<@!?4F5M;W9E
M<B!,:6YH80!?1W)U<&]S`$%?:G5D80!0<F]P<FEE9&%D97,@9&$@7TEM86=E
M;0!?26UP;W)T87(O17AP;W)T87(`7T5N=')A<@!?4V%I<@!?36]D:69I8V%R
M($QI9V'GXV\`7T]PY_5E<P!?4&5R;6ES<_5E<P!?4F5M;W9E<B!,:6=AY^-O
M+BXN`%)E;6]V7V5R(&1E<W1A(&QI<W1A`%]0<F]C=7)A<@!?0V]N9FEG=7)A
MY^-O`%!R;W!R:65D861E<R!D82!?5&%B96QA`%]5=&EL:7IA9&]R97,`8V]N
M=&%C=&]S`&]C;W)R974@=6T@97)R;SH`8V%L96YDX7)I;P!C86QM;P!C;&EQ
M=64@87%U:0!C;VYT86-T;RYV8V8`8V]N=&%C=&]S+F-S=@!C;VYT86-T;W,N
M='-V`&9E:71O`&9A;&AO=0!D:6UI;G5I;F1O`&9I8VAE:7)O`&5N8V]N=')A
M9&\Z(`!D;R`E<R`H)7,I(.!S("5S("5S`')A:F%D87,`:#H`:&@`:6UE9&EA
M=&\`96T@;&EN:&$`;&EN:&%S70!%<G)O(&UK:7-O9G,@8V]M(&/S9&EG;R`E
M9"!A;R!C;VYS=')U:7(@25-/+@!M;0!N;VUE`'-E;2!A;'1E<F'G]65S`&[C
M;R!E;F-O;G1R861O`&[C;R!I;7!L96UE;G1A9&$`86EN9&$@<&]R(&EM<&QE
M;65N=&%R`&-A9&5R;F\@9&4@;F]T87,`<&5R8V5N=&%G96T`<.UX96ES`'-U
M8FEN9&\`;6]S=')A<B!D:69E<F5NYV%S`'-M<S)E;6%I;"!V:6$@2%144`!S
M<P!E<W3A=F5L`&QI<W1A(&1E('1A<F5F87,`3R!F:6-H96ER;R!03R!P87)A
M(&\@;&]C86QE("5S(&[C;R!E>&ES=&4N`%-E;&5C8VEO;F%R($QI=G)O(&1E
M($5N9&5R9>=O<P!I;G1R;V1U>F$@82!P86QA=G)A+7!A<W-E(&1U87,@=F5Z
M97,L('!A<F$@8V]N9FER;6'GXV\`=6YI9FEC861O`'-E;2!N;VUE`&%C='5A
M;&EZ861O`'-E;&5C8VEO;F%D82!P96QO('5T:6QI>F%D;W(`=D-A<F0`4F5E
M;F,Z`'=E871H97(N8V]M````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]P=%]05"]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<S,3(`,3`T,3<S-C(W
M-34`,#(Q-3`S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y
M+3$B/SX*/"$M+2`D2&]R9&4Z('1U<F)A+VQO8V%L92]P=%]05"]H96QP+GAM
M;"QV(#$N,R`R,#`T+S$P+S(W(#$P.C4R.C`V(&IA;B!%>'`@)"`M+3X*/&AE
M;'`^"B`@/&5N=')Y(&ED/2)/=F5R=FEE=R(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/D%P<F5S96YT8>?C;SPO=&ET;&4^"B`@("`\:&5A9&EN9SY)
M;G1R;V1UY^-O/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!($QI<W1A(&1E
M($-O;G1A8W1O<R!F;W)N96-E('5M(&WI=&]D;R!E(&QO8V%L(&-O;G9E;FEE
M;G1E('!A<F$@9W5A<F1A<B!I;F9O<FUAY^-O(&1E(&-O;G1A8W1O<R!P87)A
M('5M82!U=&EL:7IAY^-O(&;A8VEL+B!0;V1E(&9O<FYE8V5R(&%C97-S;R!A
M('5M(&QI=G)O(&1E(&5N9&5R9>=O<R!P<FEV861O(&)E;2!C;VUO(&%C97-S
M;R!A('-E<G9IYV]S('#Z8FQI8V]S(&1E(&5N9&5R9>=A;65N=&]S+B!486UB
MZ6T@<W5P;W)T82!L:7-T87,@9&4@9&ES=')I8G5IY^-O('!A<F$@<75E('!O
M<W-A(&-R:6%R(&$@<W5A<R!P<O-P<FEA<R!L:7-T87,@9&ES=')I8G7M9&%S
M+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB
M3W9E<G9I97<B/@H@("`@/'1I=&QE/D]V97)V:65W/"]T:71L93X*("`@(#QH
M96%D:6YG/DEN=')O9'5C=&EO;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5&AE($%D9')E<W,@0F]O:R!P<F]V:61E<R!A(&-O;G9E;FEE;G0@;65T:&]D
M(&%N9"!P;&%C92!T;R!S=&]R92!C;VYT86-T(&EN9F]R;6%T:6]N(&9O<B!E
M87-Y(')E=')I979A;"!A;F0@=7-E+B!$97!E;F1I;F<@;VX@:&]W('EO=7(@
M861M:6YI<W1R871O<B!H87,@<V5T('5P('1H92!S>7-T96T@:70@8V%N('!R
M;W9I9&4@82!P<FEV871E(&%D9')E<W,@8F]O:R!A<R!W96QL(&%S(&%C8V5S
M<R!T;R!P=6)L:6,@;F5T=V]R:R!D:7)E8W1O<GD@<V5R=FEC97,N($ET(&%L
M<V\@<W5P<&]R=',@9&ES=')I8G5T:6]N(&QI<W1S('-O('EO=2!C86X@8W)E
M871E('EO=7(@;W=N(")M86EL:6YG(&QI<W1S+B(*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UA9&0B('-T871E
M/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-96YU.B!!9&EC:6]N87(\+W1I=&QE
M/@H@("`@/&AE861I;F<^061I8VEO;F%R/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!!9&EC:6]N87(@=6T@=71I;&EZ861O<B!N;R!L:79R;R!D92!E;F1E
M<F7G;W,N(%!O9&5RX2!A<&5N87,@861I8VEO;F%R(&%O(&QI=G)O(")->2!!
M9&1R97-S8F]O:R(@:N$@<75E(&]S(')E<W1A;G1E<R!SXV\@87!E;F%S('!A
M<F$@86-E<W-O(&1E(&QE:71U<F$N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES
M:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU+6%D9"(^"B`@("`\=&ET;&4^365N
M=3H@061D/"]T:71L93X*("`@(#QH96%D:6YG/D%D9#PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@061D(&$@=7-E<B!T;R!A;B!A9&1R97-S(&)O;VLN(%EO
M=2!C86X@;VYL>2!A9&0@=7-E<G,@=&\@=&AE(&%D9')E<W,@8F]O:W,@=&\@
M=VAI8V@@>6]U(&AA=F4@=W)I=&4@86-C97-S+B!)9B!S:&%R960@;W(@<'5B
M;&EC(&%D9')E<W,@8F]O:W,@:&%V92!B965N(&5N86)L960@=&AE>2!A<F4@
M;V9T96X@<F5A9"UO;FQY(&%N9"!Y;W4@=VEL;"!N;W0@8F4@86)L92!T;R!A
M9&0@8V]N=&%C=',@=&\@=&AE;2X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2US96%R8V@B('-T871E/2)U;FMN
M;W=N(CX*("`@(#QT:71L93Y-96YU.B!097-Q=6ES87(\+W1I=&QE/@H@("`@
M/&AE861I;F<^4&5S<75I<V%R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!0
M97-Q=6ES92!U;2!L:79R;R!D92!E;F1E<F7G;W,@<&%R82!E;F-O;G1R87(@
M:6YF;W)M8>?C;RX@17-T82!P97-Q=6ES82!P97)M:71E(&%P96YA<R!U=&EL
M:7IA<B!A;&=U;G,@8V%M<&]S(&+A<VEC;W,N(%9E:F$@(E!E<W%U:7-A($%V
M86[G861A(B!P87)A('5T:6QI>F%R(&]U=')O<R!C86UP;W,N"B`@("`\+W!A
M<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU+7-E87)C
M:"(^"B`@("`\=&ET;&4^365N=3H@4V5A<F-H/"]T:71L93X*("`@(#QH96%D
M:6YG/E-E87)C:#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5A<F-H(&%N
M(&%D9')E<W,@8F]O:R!T;R!L;V-A=&4@:6YF;W)M871I;VXN(%1H:7,@:7,@
M:6YT96YD960@87,@82!Q=6EC:R!S96%R8V@@86YD(&]N;'D@86QL;W=S('EO
M=2!T;R!S96%R8V@@;VX@82!F97<@8F%S:6,@9FEE;&1S+B!5<W5A;&QY('1H
M:7,@:7,@=&AE(&YA;64@86YD(&5M86EL(&%D9')E<W,@9FEE;&1S+"!B=70@
M8V]U;&0@=F%R>2!D97!E;F1I;F<@;VX@:&]W('EO=7(@861M:6YI<W1R871O
M<B!S970@=7`@=&AE(&%D9')E<W,@8F]O:RX*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@1F]R(&$@;6]R92!C;VUP;&5X('-E87)C:"!Y;W4@8V%N('5S
M92!T:&4@(CQR968@;6]D=6QE/2)T=7)B82(@96YT<GD](FUE;G4M861V86YC
M960M<V5A<F-H(CY!9'9A;F-E9"!396%R8V@\+W)E9CXB('=H:6-H('!E<FUI
M=',@<V5A<F-H:6YG(&]N(&]T:&5R(&9I96QD<RX*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UA9'9A;F-E9"US
M96%R8V@B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-96YU.B!097-Q
M=6ES82!!=F%NYV%D83PO=&ET;&4^"B`@("`\:&5A9&EN9SY097-Q=6ES82!!
M=F%NYV%D83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4&5S<75I<V4@=6T@
M;&EV<F\@9&4@96YD97)EYV]S('!A<F$@96YC;VYT<F%R(&EN9F]R;6'GXV\N
M($5S=&$@<&5S<75I<V$@<&5R;6ET92!U=&EL:7IA<B!VX7)I;W,@8V%M<&]S
M+B!/<R!C86UP;W,@9&ES<&]N[79E:7,@<&%R82!A('!E<W%U:7-A(&1E<&5N
M9&5M(&1O(&QI=G)O(&1E(&5N9&5R9>=O<R!A('-E<B!U=&EL:7IA9&\N"B`@
M("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU
M+6%D=F%N8V5D+7-E87)C:"(^"B`@("`\=&ET;&4^365N=3H@061V86YC960@
M4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG/D%D=F%N8V5D(%-E87)C:#PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5A<F-H(&%N(&%D9')E<W,@8F]O
M:R!T;R!L;V-A=&4@:6YF;W)M871I;VXN(%1H:7,@<V5A<F-H(&%L;&]W<R!Y
M;W4@=&\@<V5A<F-H(&]N(&UU;'1I<&QE(&9I96QD<RX@5VAI8V@@9FEE;&1S
M(&%R92!A=F%I;&%B;&4@9F]R('-E87)C:&EN9R!D97!E;F1S(&]N('1H92!A
M9&1R97-S(&)O;VL@8F5I;F<@<V5A<F-H960N"B`@("`\+W!A<F$^"CPO96YT
M<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](FUE;G4M:6UP;W)T(B!S=&%T
M93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365N=3H@26UP;W)T87(O17AP;W)T
M87(\+W1I=&QE/@H@("`@/&AE861I;F<^26UP;W)T87(O17AP;W)T87(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($5S=&4@;65N=2!P97)M:71E(&EM<&]R
M=&%R('!A<F$@;W4@97AP;W)T87(@(&1O('-E=2!L:79R;R!P97-S;V%L(&1E
M"F5N9&5R9>=O<R`H(DUY($%D9')E<W-B;V]K(BDN(%-U<&]R=&$@;W,@9F]R
M;6%T;W,@0U-6("A#;VUM82!397!E<F%T960*5F%R:6%B;&4I+"!/=71L;V]K
M+"!E('9#87)D+"!B96T@8V]M;R!O=71R;W,@9F]R;6%T;W,@<&]P=6QA<F5S
M+B!087)A(&EM<&]R=&%R('5M(&QI=G)O(&1E(&5N9&5R9>=O<RP@=&5RX2!Q
M=64@=&5R('5M(&9I8VAE:7)O(&-O;2!A(&EN9F]R;6'GXV\@;F\@8V]M<'5T
M861O<B!O;F1E(&5S=.$@82!A8V5D97(@86\@=V5B;6%I;"X*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@4&%R82!I;7!O<G1A<B!U;2!L:79R;R!D92!E
M;F1E<F7G;W,L(&%B<F$@;R!L:79R;R!D92!E;F1E<F7G;W,@9&$@3&ES=&$@
M9&4@0V]N=&%C=&]S+B!0<FEM82!O(.UC;VYE("));7!O<G1A<B]%>'!O<G1A
M<B(N(%-E;&5C8VEO;F4@;R!T:7!O(&1E(&EN9F]R;6'GXV\@<75E('1E;2!P
M87)A(&EM<&]R=&%R(&1A(&QI<W1A(&%P<F5S96YT861A+B!0<FEM82!N;R!B
M;W3C;R`B0G)O=W-E(B!E(&YA=F5G=64@873I(&%O(&9I8VAE:7)O(&$@:6UP
M;W)T87(N(%-E;&5C8VEO;F4@97-S92!F:6-H96ER;RP@92!P<FEM82!O(&)O
M=.-O(&1E($EM<&]R=&%R+B!!(&EN9F]R;6'GXV\@;F\@9FEC:&5I<F\@<V5R
MX2!I;7!O<G1A9&$@<&%R82!O('-E=2!L:79R;R!D92!E;F1E<F7G;W,N($1E
M=F5RX2!S96UP<F4@=F5R:69I8V%R(&$@:6YF;W)M8>?C;R!A</-S('5M82!I
M;7!O<G1AY^-O(&KA('%U92!P;V1E<N$@:&%V97(@:6YF;W)M8>?C;R!M86ES
M(&-O;7!L97AA('%U92!NXV\@=&5N:&$@<VED;R!I;7!O<G1A9&$@8V]R<F5C
M=&%M96YT92X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT
M<GD@:60](FUE;G4M:6UP;W)T(CX*("`@(#QT:71L93Y-96YU.B!);7!O<G0O
M17AP;W)T/"]T:71L93X*("`@(#QH96%D:6YG/DEM<&]R="]%>'!O<G0\+VAE
M861I;F<^"@H@("`@/'!A<F$^"B`@("!4:&ES(&UE;G4@86QL;W=S(&EM<&]R
M=&EN9R!T;R!A;F0@97AP;W)T:6YG(&9R;VT@>6]U<B!P97)S;VYA;"!A9&1R
M97-S(&)O;VLN($ET('-U<'!O<G1S(&)O=&@@0U-6("A#;VUM82!397!A<F%T
M960@5F%R:6%B;&4I+"!/=71L;V]K+"!A;F0@=D-A<F0@9F]R;6%T<RP@87,@
M=V5L;"!A<R!S;VUE(&]T:&5R('!O<'5L87(@9F]R;6%T<RX*("`@(#PO<&%R
M83X*"B`@("`\:&5A9&EN9SY);7!O<G1I;F<\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%1O(&EM<&]R="!A;B!A9&1R97-S(&)O;VLL('EO=2!N965D('1O
M(&AA=F4@=&AE(&%D9')E<W,@8F]O:R!D871A('1O(&EM<&]R="!O;B!Y;W5R
M(&QO8V%L(&UA8VAI;F4@*&]N('=H:6-H('1H92!W96(@8G)O=W-E<B!I<R!R
M=6YN:6YG*2X@5&\@9&\@=&AI<RP@>6]U('=I;&P@;F5E9"!T;R!F:7)S="!E
M>'!O<G0@=&AE(&%D9')E<W,@8F]O:R!I;F9O<FUA=&EO;B!F<F]M('EO=7(@
M8W5R<F5N="!E;6%I;"!C;&EE;G0N"B`@("`\+W!A<F$^"@H@("`@/'!A<F$^
M"B`@("!)9B!Y;W4@=7-E($]U=&QO;VL@17AP<F5S<SH*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@,2D@0VQI8VL@;VX@1FEL92`F9W0[($5X<&]R="`F
M9W0[($%D9')E<W,@0F]O:PH@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`R
M*2!396QE8W0@(E1E>'0@1FEL92(@*$-O;6UA(%-E<&%R871E9"!686QU97,I
M(&EN('1H92`B061D<F5S<R!";V]K($5X<&]R="!4;V]L(BX@0VQI8VL@;VX@
M(D5X<&]R="(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#,I($EN('1H
M92`B4V%V92!E>'!O<G1E9"!F:6QE<R!A<R(@9FEE;&0L('1Y<&4@:6X@82!N
M86UE(&9O<B!Y;W5R(&%D9')E<W,@8F]O:RX@0VQI8VL@(DYE>'0B+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("`T*2!0=70@82!C:&5C:VUA<FL@:6X@
M=&AE(&)O>"!T;R!T:&4@;&5F="!O9B!E86-H(&]F('1H92!F:65L9',@=&AA
M="!Y;W4@=VES:"!T;R!E>'!O<G0N($-L:6-K(")&:6YI<V@B+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("`U*2!9;W4@<VAO=6QD(')E8V5I=F4@82!M
M97-S86=E('1H870@<W1A=&5S("=!9&1R97-S(&)O;VL@97AP;W)T('!R;V-E
M<W,@:&%S(&-O;7!L971E9"<N($-L:6-K("=/2R<N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@(#8I($-L:6-K("=#;&]S92<@;VX@=&AE("=!9&1R97-S
M($)O;VL@17AP;W)T(%1O;VPG(&%N9"!C;&]S92!/=71L;V]K($5X<')E<W,N
M"B`@("`\+W!A<F$^"@H@("`@/'1I<#X*("`@($EF('1H92!E>'!O<G1E9"!A
M9&1R97-S(&)O;VL@9FEL92!I<R!N;W0@;&]C871E9"!O;B!Y;W5R(&1E<VMT
M;W`L(&%N9"!Y;W4G<F4@=7-I;F<@82!7:6YD;W=S(&]P97)A=&EN9R!S>7-T
M96TL(&-L:6-K(&]N(%-T87)T("9G=#L@1FEN9"!O<B!396%R8V@@)F=T.R!&
M:6QE<R!O<B!&;VQD97)S(&%N9"!S96%R8V@@>6]U<B!M86EN(&AA<F0@9')I
M=F4@9F]R('1H92!F:6QE(&YA;64@=&AA="!Y;W4@=7-E9"!I;B!S=&5P(#,N
M($UA:V4@82!N;W1E(&]F('1H92!F:6QE)W,@;&]C871I;VXN"B`@("`\+W1I
M<#X*"B`@("`\<&%R83X*("`@(%1O(&EM<&]R="!A;B!A9&1R97-S(&)O;VLL
M(&]P96X@=&AE(&%D9')E<W,@8F]O:R!Y;W4@=V%N="!T;R!I;7!O<G0@=&AE
M(&EN9F]R;6%T:6]N(&EN=&\N($-L:6-K(&]N('1H92`B26UP;W)T+T5X<&]R
M="(@26-O;BX@4V5L96-T('1H92!T>7!E(&]F(&%D9')E<W,@:6YF;W)M871I
M;VX@9&%T82!F:6QE('EO=2!W86YT('1O(&EM<&]R="!F<F]M('1H92!S96QE
M8W1I;VX@;&ES="X@0VQI8VL@;VX@=&AE(")B<F]W<V4B(&)U='1O;B!T;R!L
M;V]K(&9O<B!T:&4@861D<F5S<R!D871A(&9I;&4@;VX@>6]U<B!C;VUP=71E
M<BX@4V5L96-T('1H92!F:6QE+"!A;F0@8VQI8VL@;VX@=&AE("));7!O<G0B
M(&)U='1O;BX@5&AE(&EN9F]R;6%T:6]N(&EN('1H92!F:6QE('=I;&P@8F4@
M:6UP;W)T960@:6YT;R!Y;W5R(&%D9')E<W,@8F]O:RX*("`@(#PO<&%R83X*
M("`@(#QT:7`^"B`@("!3;VUE(&-O;7!L97@@96YT<FEE<RP@;W(@96YT<FEE
M<R!W:71H(&9I96QD<R!T:&%T(&1O(&YO="!M871C:"!Y;W5R(&%D9')E<W,@
M8F]O:R!F:65L9',L(&UA>2!N;W0@:6UP;W)T(&-O<G)E8W1L>2X@66]U('-H
M;W5L9"!V97)I9GD@=&AE(&EM<&]R=&5D(&1A=&$@869T97(@86X@:6UP;W)T
M+@H@("`@/"]T:7`^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60]
M(G-E87)C:&EN9RUS96%R8VA?<F5S=6QT<R(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4V5A<F-H:6YG.B!396%R8V@@4F5S=6QT<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY396%R8V@@4F5S=6QT<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@268@82!S96%R8V@@:7,@<W5C8V5S<V9U;"P@=&AE(')E<W5L=',@=VEL
M;"!S:&]W('5P(&EN('1H92`B4V5A<F-H(%)E<W5L=',B(&%R96$N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@($-L:6-K:6YG(&]N(&%N(")%;6%I;"(@
M9FEE;&0@96YT<GD@=VEL;"!O<&5N(&$@;F5W($-O;7!O<V4@=VEN9&]W('1O
M('-E;F0@;6%I;"!T;R!T:&%T(&%D9')E<W,N($-L:6-K:6YG(&]N(&$@(DYA
M;64B(&9I96QD(&5N=')Y('=I;&P@9&ES<&QA>2!T:&4@861D<F5S<R!B;V]K
M(')E8V]R9"!F;W(@=&AA="!N86UE+"!A;&QO=VEN9R!Y;W4@=&\@=&AE;B!E
M9&ET(&]R(&1E;&5T92!T:&4@96YT<GDN"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@($1E<&5N9&EN9R!O;B!H;W<@>6]U<B!S>7-T96T@:&%S(&)E96X@
M<V5T('5P(&)Y('1H92!A9&UI;FES=')A=&]R('-E87)C:"!R97-U;'1S(&-A
M;B!B92!C=6UU;&%T:79E+B!%86-H('-E87)C:"!W:6QL(&%D9"!A;GD@;F5W
M(')E<W5L=',@=&\@>6]U<B!E>&ES=&EN9R!R97-U;'1S+B!4:&ES(&ES(&AE
M;'!F=6P@=VAE;B!B=6EL9&EN9R!L:7-T<RX@5&\@<F5M;W9E('1H92!R97-U
M;'1S(&]F(&-U;75L871I=F4@<V5A<F-H97,@86YD('-T87)T(&$@;F5W('-E
M87)C:"P@8VQI8VL@;VX@=&AE(")#;&5A<B!396%R8V@B(&QI;FLN"B`@("`\
M+W!A<F$^"@H@("`@/'1I<#X*("`@(%=H96X@=FEE=VEN9R!A(&QI<W0@;V8@
M96YT<FEE<RP@>6]U(&-A;B!S;W)T('1H92!E;G1R:65S(&)Y(&5A8V@@9FEE
M;&0@<VAO=VX@8GD@8VQI8VMI;F<@;VX@=&AE(&%P<')O<')I871E(&-O;'5M
M;B!H96%D:6YG+B!4;R!S=VET8V@@8V]L=6UN<R!B971W965N(&%S8V5N9&EN
M9R!A;F0@9&5S8V5N9&EN9R!S;W)T(&]R9&5R+"!C;&EC:R!O;B!T:&4@87)R
M;W<@:6-O;B!I;B!T:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W1I<#X*/"]E
M;G1R>3X*/"]H96QP/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A
M;&4O<F]?4D\O````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`R,#`R,@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1U<F)A+VQO8V%L92]R;U]23R],0U]-15-304=%4R\`````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-34`,#(Q-C`W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+W)O7U)/+TQ#
M7TU%4U-!1T53+W1U<F)A+FUO````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C$P-@`Q
M,#0Q-S,V,C<U-0`P,C,R-C(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````WA($E0````!X````'````-P#``"C````G`<`````
M```H"@``*````"D*```=````4@H```@```!P"@``!0```'D*```#````?PH`
M``@```"#"@``!P```(P*```4````E`H```\```"I"@``!0```+D*```?````
MOPH``!$```#?"@``!@```/$*```(````^`H``!4````!"P``"@```!<+```,
M````(@L```X````O"P``!P```#X+```I````1@L```(```!P"P``!0```',+
M```0````>0L```8```"*"P``#P```)$+```4````H0L``"\```"V"P``"0``
M`.8+```/````\`L``"8`````#```!````"<,```%````+`P```T````R#```
M!0```$`,```0````1@P``!````!7#```#P```&@,```+````>`P```\```"$
M#```#````)0,```/````H0P```8```"Q#```'@```+@,```A````UPP``"(`
M``#Y#````P```!P-```$````(`T```0````E#0``!````"H-```,````+PT`
M``H````\#0``!0```$<-```2````30T``!````!@#0``"````'$-```$````
M>@T``!````!_#0``!@```)`-```'````EPT```(```"?#0``!````*(-```(
M````IPT```\```"P#0``!P```,`-```'````R`T```0```#0#0``!0```-4-
M```%````VPT```<```#A#0``$0```.D-```(````^PT``!X````$#@``!0``
M`",.```H````*0X``"D```!2#@``$P```'P.```+````D`X``!$```"<#@``
M!````*X.```$````LPX```P```"X#@``!@```,4.```:````S`X``!<```#G
M#@``&@```/\.```7````&@\``!L````R#P``-````$X/```?````@P\``!,`
M``"C#P``$````+</```7````R`\```<```#@#P``!0```.@/```F````[@\`
M`"$````5$```'````#<0```%````5!````,```!:$```(````%X0```D````
M?Q```"8```"D$```#````,L0```(````V!```!L```#A$```!P```/T0```&
M````!1$```T````,$0``"P```!H1```,````)A$```H````S$0```@```#X1
M```&````01$``$4```!($0``,````(X1```0````OQ$``!\```#0$0``$```
M`/`1```/`````1(``%T!```1$@``*````&\3```E````F!,```D```"^$P``
M!0```,@3```(````SA,```\```#7$P``!@```.<3```.````[A,``!````#]
M$P``!0````X4```C````%!0``!0````X%```"````$T4```(````5A0``!$`
M``!?%```#0```'$4```1````?Q0```\```"1%```"````*$4```H````JA0`
M``(```#3%```!@```-84```4````W10```@```#R%```#P```/L4```0````
M"Q4``#$````<%0``"````$X5```/````5Q4``"<```!G%0``!P```(\5```&
M````EQ4``!D```">%0``!@```+@5```3````OQ4``!0```#3%0``$P```.@5
M```4````_!4``!,````1%@``$````"46```2````-A8```D```!)%@``&0``
M`%,6```F````;18``"````"4%@```P```+46```'````N18```4```#!%@``
M!````,<6```,````S!8```T```#9%@``!0```.<6```1````[18``!(```#_
M%@``!0```!(7```%````&!<``!H````>%P``"0```#D7```+````0Q<```(`
M``!/%P``#0```%(7```3````8!<``!T```!T%P``!0```)(7```%````F!<`
M``0```">%P``"0```*,7```&````K1<```<```"T%P``#P```+P7```&````
MS!<``"(```#3%P``!P```/87```G````_A<``#`````F&```%````%<8```/
M````;!@``!$```!\&```$````(X8```'````GQ@```\```"G&```!P```+<8
M```4````OQ@``!P```#4&```)````/$8```;````%AD``"(````R&0``/```
M`%49```;````DAD``!@```"N&0``%0```,<9```6````W1D```8```#T&0``
M!P```/L9```@`````QH``!8````D&@``*````#L:```%````9!H```,```!J
M&@``(@```&X:```A````D1H``"X```"S&@``$@```.(:```*````]1H``!(`
M````&P``!P```!,;```*````&QL``!P````F&P``$0```$,;```,````51L`
M``T```!B&P```@```'`;```%````<QL``#H```!Y&P``.P```+0;```6````
M\!L``!H````''```$0```"(<```1````-!P```$````F````9````&\```!A
M````/0````L```!J````!0```!(`````````)P````````!W````3P```!8`
M``!L````;0```$L```!0````1@````<`````````%0```%\```!9````/P``
M````````````;@`````````R````*@````````!8``````````T````I````
M/@```%$`````````3@```"\````1````'`````````!Q````+@```#<`````
M```````````````Y````5P```%4````P````'0````P`````````:P``````
M````````=0```"T```!E````10````````!I````0```````````````8```
M`'(```!*`````````'@````Q````$````$$````)````&0```',`````````
M0@````8````[````5@```%0`````````=@```&8````C````4P````0`````
M````<````"$```!2````70```#8`````````"@```"@````Z````````````
M``!T``````````````!H````3`````,````8````8P````@````E````0P``
M`````````````````$0````B````1P```"L````L`````````&(`````````
M7```````````````-0```#P````"````&P````````!G````6@```$D`````
M````&@``````````````)`````X````X`````````!0````S````'@```!<`
M``!-`````````%L````?````-`````\````@`````````%X````3````2```
M````````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9``R-"!H;W5R<P!!32]0
M30!!9&0`061D('!A:7(`061D<F5S<P!!9&1R97-S($)O;VL@3&ES=&EN9P!!
M9'9A;F-E9"!396%R8V@`06QI87,`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!=F%I;&%B;&4@9FEE;&1S.@!"<F]W<V4`0V%L96YD87(`0V%N
M8V5L(%!R;V)L96T@4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O
M;'5M;B!/<'1I;VYS`$-O;7!A;GD`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&5F875L="!)9&5N=&ET>0!$
M96QE=&4`1&5L971I;VX@9F%I;&5D`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$1I<F5C=&]R>0!$:7-P;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'``161I=`!%;6%I;`!%;7!T>2!R97-U;'0N
M`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AP;W)T`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E<P!&87@`
M1FEN9`!&<F]M`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N9W5A9V4`
M3&ES=`!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`
M36%T8VAI;F<`36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`36]N=&AL>0!.86UE
M`$YE=F5R`$YO=&5S`$]P=&EO;G,`3W1H97(@26YF;W)M871I;VX`4&%S<W=O
M<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!H;VYE`%!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4')O8FQE;2!$97-C
M<FEP=&EO;@!296UO=F4@<&%I<@!2971U<FX@=&\@3W!T:6]N<P!2;VQE`%-A
M=F4`4V%V92!/<'1I;VYS`%-E87)C:`!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P
M;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4VMI<"!-86EN=&5N
M86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1A<VMS`%1H
M97)E(&%R92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O:W,N`%1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N`%1I=&QE`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+@!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`57-E<B!/
M<'1I;VYS`%5S97)N86UE`%9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.@!7
M87)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=O<FL@
M061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@26YF;W)M871I;VX`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F
M("5S70!0<F]J96-T+4ED+59E<G-I;VXZ(%154D)!(#$N,0I297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#,M,#,M,#$@,3(Z,#`K,#(P,`I,87-T+51R86YS;&%T;W(Z($5U9V5N
M($AO86YC82`\975G96YH0'5R8F%N+6=R869X+G)O/@I,86YG=6%G92U496%M
M.B!2;VUA;FEA;B`\=3$X;4!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO
M;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M
M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"5S($]P
M97)A=&EU;FD@9&4@;65N=&5N86YT82`M($-O;F9I<FUA<F4`1FES:65R=6P@
M)7,@82!F;W-T(&EM<&]R=&%T(&-U('-U8V-E<P`R-"!D92!O<F4`04TO4$T`
M061A=6=A<F4`061A=6=A('!E<F5C:&5A`$%D<F5S80!,:7-T87)E(&%G96YD
M80!#875T87)E(&%V86YS871A`$%L:6%S`%,M82!S<&5C:69I8V%T(&\@=F%L
M;V%R92!I;F-O<F5C=&$N`$-I;7!U<FD@9&ES<&]N:6)I;&4Z`%)A<V9O:7)E
M`$-A;&5N9&%R`%)E;G5N=&$@;&$@4F%P;W)T`%1E;&5F;VX@36]B:6P`26YC
M:&ED92!F97)E87-T<F$`3W!T:75N:2!C;VQO86YA`$-O;7!A;FEE`$YU('!O
M="!D97-C:&ED92!M;V1U;'5L(&1E($UE;G1E;F%N=&$@)7,`6EH`6FEL;FEC
M`$ED96YT:71A=&4@26UP;&EC:71A`%-T97)G97)E`%-T97)G97)E(&5S=6%T
M80!$97-C<FEE('!R;V)L96UA`$1E=&%L:6D@:6YR96=I<W1R871E(&EN($Q/
M1R!P96YT<G4@861M:6YI<W1R871O<BX`1&ER96-T;W(`3W!T:75N:2!A9FES
M86H@`%1E(')O9R!N=2!A8V-E<V$@9&ER96-T(&UA:6YT96YA;F-E+G!H<`!%
M9&ET87)E`$4M;6%I;`!%;7!T>2!R97-U;'0N("T@9&4@=')A9'5S`$5R;V%R
M90!/(&1A=&$@;&$@,34@;6EN=71E`$\@9&%T82!L82`S,"!S96-U;F1E`$QA
M(&9I96-A<F4@-2!M:6YU=&4`3&$@9FEE8V%R92!#;VYE8W1A<F4`3R!D871A
M(&QA(#,P(&UI;G5T90!);B!F:65C87)E(&UI;G5T`$5X96UP;&4@9&4@=F%L
M;W)I.@!%>'!O<G1A<F4`3G4@<&]T(&-I=&D@<')E9F5R:6YT96QE+@!.=2!M
M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0+@!#875T87)E(&5S
M=6%T82!I;B!D:7)E8W1O<G5L.B`E<P!&87@`0V%U=&%R90!$92!L80!(96QP
M`$%D<F5S82!A8V%S80!496QE9F]N(&%C87-A`$AO<F1E`$-I;7`@:6UP;W)T
M870Z("5S`$-I;7!U<FD@:6UP;W)T871E.@!,:6UB80!,:7-T80!,:7-T82!S
M=6)I96-T96QO<B!D:6X@2&5L<`!#;VYE8W1A<F4`1&5C;VYE8W1A<F4`3$P`
M0V]R97-P;VYD96YT80!#;W)E<W!U;GIA=&]R*&]A<F4I`$-I;7!U<FD@<&]T
M<FEV:71E("T@9&4@=')A9'5S`$UE<V%J`$QU;F%R`$YU;64`3FEC:6]D871A
M`$YO=&ET90!/<'1I=6YI`$%L=&4@:6YF;W)M871I:0!087)O;&$`17AE8W5T
M82!/<&5R871I=6YI;&4@9&4@365N=&5N86YT80!496QE9F]N`%1E(')O9R!S
M<&5C:69I8V$@=6X@<W5M87(@86P@<')O8FQE;65I+@!492!R;V<@:6YT<F]D
M=2!U;B!N=6UE(&1E('5T:6QI>F%T;W(@<VD@;R!P87)O;&$`1&5S8W)I97)E
M82!P<F]B;&5M96D`4W1E<F=E('!E<F5C:&5A`$EN87!O:2!L82!O<'1I=6YI
M`%)O;&4@+2!D92!T<F%D=7,`4V%L=F%R90!386QV87IA($]P=&EU;FD`0V%U
M=&%R90!$96QI;6ET871O<B!D92!D871A.@!&;W)M871U;"!D92!A9FES87)E
M(&$@9&%T96DZ`%-E;&5C=&5A>F$@9FES:65R=6P@8V%R92!S92!I;7!O<G1A
M.@!&;W)M871U;"!D92!A9FES87)E(&$@;W)E:3H`4V5L96-T96%Z82!D;W5A
M(&-I;7!U<FD@<&]T<FEV:71E+@!396QE8W1E87IA(&-A;7!U<FEL92!C92!V
M;W(@9FD@869I<V%T92!I;B!L:7-T96QE(&1E(&%D<F5S92X`4V5L96-T96%Z
M82!L:6UB82!P<F5F97)A=&$Z`%1R:6UI=&4@4F%P;W)T(&1E($5R;V%R90!3
M87)I('!E<W1E($UE;G1E;F%N=&$`0V%R86-T97)E(%-P96-I86QE("XN+@!3
M=6-C97,`4V%R8VEN:0!.=2!E>&ES=&$@86=E;F1E('!E;G1R=2!R87-F;VET
M+@!686QO87)E82!M:6YI;6$@97-T92`Q`$%C96%S=&$@=F%L;V%R92!T<F5B
M=6EE('-A(&9I92!N=6UE<FEC82X`5&ET;'4`55),`$YU(&UA('!O="!C;VYE
M8W1A(&QA('-E<G9E<G5L(%-13"X`3G4@<V4@<&]T(&EN8V%R8V$@9&5F:6YI
M=&EI;&4@)7,N`$YU('!O="!T<F%D=6-E(&%C97-T(&1O8W5M96YT(%=O<F0@
M+2!D92!T<F%D=7,`3W!T:75N:2!5=&EL:7IA=&]R`%5T:6QI>F%T;W(`069I
M<V%R92!I;7!L:6-I=&$Z`$%T96YT:64`4V%P=&%M:6YA;`!":6YE(&%I('9E
M;FET(&EN('-I<W1E;75L("5S`$)I;F4@86D@=F5N:70L("5S`$%D<F5S82!B
M:7)O=0!496QE9F]N(&)I<F]U`$%!`$%N=6%L`%1R96)U:64@<V$@9&5S8W)I
M:2!P<F]B;&5M82!I;F%I;G1E(&1E(&$@=')I;6ET92!R87!O<G1U;"X`4V5S
M:75N96$@=&$@9&4@)7,@82!E>'!I<F%T+B!492!R;V<@<V$@9F%C:2!,;V<@
M26X@9&EN(&YO=2X`26YF;W)M871I:2!D97-P<F4@=&EN90!/<'1I=6YI;&4@
M874@9F]S="!S86QV871E+@!;4F%P;W)T(%!R;V)L96UA70!;;&EN:6$@)7,@
M9&EN("5S70``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O<G5?4E4O
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4U`#`R,#`S-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U
M<F)A+VQO8V%L92]R=5]252],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-34`,#(Q-C(S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+W)U7U)5+TQ#7TU%4U-!1T53
M+W1U<F)A+FUO```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,3<P,@`Q,#0Q-S,V,C<U
M-0`P,C,S,#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````"2`0``'````*P,```=`@``/!D```````"P(0``)```
M`+$A```E````UB$``"@```#\(0``'0```"4B```.````0R(```X```!2(@``
M"````&$B```%````:B(``!$```!P(@``$P```((B```3````EB(```,```"J
M(@``"0```*XB```(````N"(```@```#!(@``)````,HB```&````[R(```<`
M``#V(@``#````/XB```4````"R,```T````@(P``+````"XC```.````6R,`
M``\```!J(P``!0```'HC```#````@",``!<```"$(P``"@```)PC```/````
MIR,``",```"W(P``%````-LC```7````\",``!<````()```'P```"`D```+
M````0"0``!4```!,)```*````&(D```Z````BR0```D```#&)```.0```-`D
M```L````"B4``"H````W)0``$0```&(E```,````="4``!$```"!)0``"```
M`),E```.````G"4```H```"K)0```P```+8E```(````NB4```8```##)0``
M%0```,HE```5````X"4```H```#V)0``5`````$F```/````5B8``$0```!F
M)@``$P```*LF``!6````OR8``!P````6)P``/P```#,G```R````<R<```P`
M``"F)P``#````+,G```0````P"<```X```#1)P``(P```.`G```6````!"@`
M`"H````;*```!P```$8H```=````3B@```X```!L*```%````'LH```.````
MD"@``"D```"?*```!@```,DH```=````T"@``!````#N*```$P```/\H```,
M````$RD``"@````@*0```@```$DI```%````3"D```0```!2*0``#0```%<I
M```/````92D``!````!U*0``30```(8I```:````U"D```8```#O*0``$P``
M`/8I```7````"BH``!@````B*@``#P```#LJ```*````2RH``!0```!6*@``
M"P```&LJ```O````=RH```D```"G*@``!P```+$J```6````N2H```\```#0
M*@``)@```.`J```H````!RL``$,````P*P``"````'0K```+````?2L```0`
M``")*P``"@```(XK```7````F2L``!$```"Q*P``!0```,,K```-````R2L`
M`"````#7*P``%0```/@K```%````#BP``!`````4+```#P```"4L```0````
M-2P```\```!&+```"P```%8L```/````8BP```P```!R+```#P```'\L```&
M````CRP```8```"6+```$P```)TL```>````L2P``"$```#0+```(@```/(L
M```#````%2T```0````9+0``#````!XM```%````*RT```<````Q+0``!```
M`#DM```$````/BT``!````!#+0``#@```%0M```"````8RT```T```!F+0``
M!@```'0M```1````>RT```<```"-+0``!````)4M```*````FBT``"(```"E
M+0``!0```,@M```$````SBT```P```#3+0``"@```.`M```%````ZRT```H`
M``#Q+0``#P```/PM```0````#"X```8````=+@``'````"0N```/````02X`
M`!L```!1+@``$@```&TN```0````@"X``!````"1+@``"@```*(N```4````
MK2X```T```#"+@``#0```-`N```,````WBX```<```#K+@``"````/,N```.
M````_"X``!8````++P``$0```"(O```&````-"\```0````[+P``$````$`O
M```/````42\```@```!A+P``!@```&HO```'````<2\```4```!Y+P``"P``
M`'\O```"````BR\```0```".+P``:````),O```(````_"\```\````%,```
M%P```!4P```*````+3````<````X,```#````$`P```'````33````L```!5
M,```!````&$P```)````9C````D```!P,```"@```'HP```'````A3````D`
M``"-,```!P```)<P```5````GS````H```"U,```%@```,`P```/````US``
M``0```#G,```"P```.PP```%````^#````P```#^,```"P````LQ```$````
M%S$```0````<,0``#````"$Q```"````+C$```D````Q,0``$P```#LQ```%
M````3S$``!@```!5,0```@```&XQ```'````<3$```X```!Y,0``"@```(@Q
M```1````DS$```T```"E,0``"````+,Q```)````O#$```H```#&,0``'@``
M`-$Q```H````\#$```H````9,@``"P```"0R```4````,#(```4```!%,@``
M$0```$LR```I````73(``"$```"',@``*````*DR```I````TC(``!H```#\
M,@``$````!<S```'````*#,``!,````P,P``#````$0S```$````43,```<`
M``!6,P``'@```%XS```4````?3,```X```"2,P``*@```*$S```&````S#,`
M``P```#3,P``%0```.`S```+````]C,``'L````"-```A0```'XT```%````
M!#4``!$````*-0``$0```!PU```8````+C4```0```!'-0``!````$PU```,
M````434```8```!>-0``#@```&4U```1````=#4```L```"&-0``#P```)(U
M```*````HC4```L```"M-0``)P```+DU```E````X34``"8````'-@``&@``
M`"XV```7````238``!D```!A-@``&@```'LV```E````EC8``"@```"\-@``
M)P```.4V```7````#3<``!L````E-P``1````$$W```B````AC<``#0```"I
M-P``)0```-XW```9````!#@``!\````>.```$0```#XX```3````4#@``#\`
M``!D.```-P```*0X``!7````W#@```4````T.0``"0```#HY```-````1#D`
M`"T```!2.0``"````(`Y```-````B3D```H```"7.0``#@```*(Y```+````
ML3D``"4```"].0``'P```.,Y```=`````SH```8````A.@``!````"@Z```0
M````+3H``!,````^.@``%P```%(Z```Y````:CH```8```"D.@``!P```*LZ
M```&````LSH```<```"Z.@``*0```,(Z```;````[#H``"L````(.P``(P``
M`#0[```M````6#L``#0```"&.P``%0```+L[```.````T3L``!0```#@.P``
M!0```/4[```)````^SL``"\````%/```(0```#4\```?````5SP``"8```!W
M/```'P```)X\```P````OCP``"\```#O/```*0```!\]```A````23T``!P`
M``!K/0``!P```(@]```+````D#T```4```"</0```@```*(]``!9````I3T`
M``,```#_/0``(`````,^```D````)#X``"8```!)/@``#````'`^```'````
M?3X```8```"%/@``,@```(P^```$````OSX```P```#$/@``"````-$^```)
M````VCX```H```#D/@``"0```.\^```'````^3X``!D````!/P``&P```!L_
M```'````-S\```,````_/P``!@```$,_```-````2C\```L```!8/P``+P``
M`&0_```,````E#\``#$```"A/P``/P```-,_```,````$T````H````@0```
M`@```"M````&````+D````,````U0```&0```#E```!%````4T```#````"9
M0```$@```,I````3````W4```!````#Q0```"0````)!```7````#$$``!8`
M```D00``#P```#M!```?````2T$``!0```!K00``$````(!!```/````D4$`
M``\```"A00``!P```+%!```'````N4$```<```#!00``!0```,E!```.````
MST$```@```#>00``#````.=!```(````]$$```P```#]00``!P````I"```&
M````$D(```8````90@``!````"!"```$````)4(``!$````J0@``!P```#Q"
M```%````1$(``%L!``!*0@``&P```*9#```=````PD,``"4```#@0P``'```
M``9$```*````(T0```H````N1```!P```#E$```%````040``!$```!'1```
M%@```%E$```.````<$0```@```!_1```"0```(A$```)````DD0```T```"<
M1```&````*I$```(````PT0```4```#,1```#@```-)$```9````X40```X`
M``#[1```,P````I%```*````/D4``!$```!)10``"0```%M%```#````944`
M``P```!I10``"@```'9%```)````@44``!X```"+10``$P```*I%```'````
MOD4``!8```#&10``(P```-U%```*`````48```D````,1@``(P```!9&```C
M````.D8```X```!>1@``0@```&U&```D````L$8``"H```#51@``#P````!'
M```%````$$<``!$````61P``#0```"A'```*````-D<```H```!!1P``"```
M`$Q'```)````54<```8```!?1P``&````&9'```1````?T<``!0```"11P``
M(0```*9'```,````R$<``#X```#51P``%````!1(```G````*4@``!@```!1
M2```-P```&I(```K````HD@```@```#.2```#````-=(```+````Y$@```<`
M``#P2```&````/A(```?````$4D``",````Q20``"````%5)```5````7DD`
M``T```!T20``%0```())```-````F$D``"H```"F20``!P```-%)```7````
MV4D``!4```#Q20``"0````=*```-````$4H``"(````?2@```@```$)*```)
M````14H```0```!/2@``$0```%1*```4````9DH``!0```![2@``&P```)!*
M```2````K$H```<```"_2@``"````,=*```?````T$H``!D```#P2@``$P``
M``I+```+````'DL``!`````J2P``"````#M+```V````1$L```<```![2P``
M"````(-+```F````C$L``!(```"S2P``+````,9+```O````\TL``$$````C
M3```"0```&5,```,````;TP```X```!\3```#0```(M,```5````F4P```D`
M``"O3```!@```+E,```2````P$P``"X```#33```%`````)-```&````%TT`
M``\````>30``#P```"Y-```0````/DT```X```!/30``%````%Y-```.````
M<TT```T```""30``$````)!-```)````H4T```<```"K30``%@```+--```C
M````RDT``"4```#N30``(````!1.```$````-4X```0````Z3@``"0```#].
M```%````24X```<```!/3@``!0```%=.```"````74X``!D```!@3@``!@``
M`'I.```'````@4X```X```")3@``!@```)A.```%````GTX```D```"E3@``
M"0```*].```)````N4X``#0```##3@``!@```/A.```&````_TX```X````&
M3P``$````!5/```&````)D\```T````M3P``$````#M/```,````3$\```@`
M``!93P``'0```&)/```.````@$\``!T```"/3P``%@```*U/```3````Q$\`
M``P```#83P``$0```.5/```<````]T\``!0````44```$0```"E0```1````
M.U````D```!-4```!````%=0```7````7%```"<```!T4```'P```)Q0```%
M````O%````8```#"4```&0```,E0```+````XU````P```#O4```!````/Q0
M```%`````5$```X````'40``!````!91```"````&U$```4````>40``,@``
M`"11```*````5U$``!````!B40``'P```'-1```+````DU$```D```"?40``
M$0```*E1```*````NU$```D```#&40``"P```-!1```0````W%$``!$```#M
M40``$@```/]1```1````$E(``!`````D4@``$0```#52```7````1U(```X`
M``!?4@``#P```&Y2```.````?E(```,```"-4@``!0```)%2```'````EU(`
M``\```"?4@``%0```*]2```'````Q5(```4```#-4@``$@```--2```#````
MYE(```T```#J4@``$@```/A2```'````"U,``!H````34P```@```"Y3```)
M````,5,``!$````[4P``"@```$U3```1````6%,``!````!J4P``!@```'M3
M```&````@E,```8```")4P``(````)!3```T````L5,```4```#F4P``#0``
M`.Q3```&````^E,```<````!5```$P````E4```A````'50``!T````_5```
M(P```%U4```R````@50``!T```"T5```$P```-)4```)````YE0``!$```#P
M5```#0````)5```&````$%4```@````750``(P```"!5```5````1%4``!``
M``!:50``)P```&M5```'````DU4```P```";50``$0```*A5```,````NE4`
M`'(```#'50``<@```#I6```(````K58```@```"V5@``%@```+]6```?````
MUE8```@```#V5@``"0```/]6```3````"5<```4````=5P``$0```"-7```%
M````-5<```\````[5P``#P```$M7```+````6U<```X```!G5P``)0```'97
M```=````G%<``"<```"Z5P``(````.)7```5`````U@``"8````96```$P``
M`$!8```E````5%@``"$```!Z6```'P```)Q8```D````O%@``!X```#A6```
M*0````!9```I````*ED``#0```!460``'@```(E9```3````J%D``!````"\
M60``$@```,U9```<````X%D``$T```#]60``10```$M:``!,````D5H```H`
M``#>6@```P```.E:```2````[5H``"8`````6P``#````"=;```1````-%L`
M``\```!&6P``"````%9;```&````7UL``"D```!F6P``(@```)!;```9````
MLUL```8```#-6P``!@```-1;```4````VUL```\```#P6P``$P````!<```M
M````%%P```8```!"7```!````$E<```&````3EP```<```!57```%P```%U<
M```6````=5P``!,```",7```%````*!<```>````M5P``"@```#47```(@``
M`/U<```4````(%T``"$````U70``!@```%==```,````7ET``"````!K70``
M%````(Q=```4````H5T``"@```"V70``%P```-]=```W````]UT``"L````O
M7@``'0```%M>```G````>5X``"````"A7@``!P```,)>```2````REX```D`
M``#=7@``!````.=>``!#````[%X```,````P7P``)@```#1?```D````6U\`
M`"L```"`7P``$@```*Q?```&````OU\```D```#&7P``2````-!?```,````
M&6```!8````F8```$````#U@```0````3F```!````!?8```"P```'!@```+
M````?&```!4```"(8```$P```)Y@```(````LF````,```"[8```"P```+]@
M```5````RV```!0```#A8```)0```/9@```$````'&$``#$````A80``.@``
M`%-A```-````CF$```\```"<80```@```*QA```(````KV$```(```"X80``
M%````+MA``!(````T&$``$$````98@``"@```%MB```6````9F(```\```!]
M8@``"0```(UB```,````EV(``!D```"D8@``"0```+YB```>````R&(``!$`
M``#G8@``%@```/EB```1````$&,```H````B8P``!P```"UC```'````-6,`
M``8````]8P``!@```$1C```.````2V,```4```!:8P``"````&!C```)````
M:6,```4```!S8P``!0```'EC```*````?V,```P```"*8P``!P```)=C```#
M````GV,```@```"C8P``#P```*QC```%````O&,```$`````````>`$`````
M``"1````*P$``',`````````)0```"\````U`0``1P```"(!``#@````%P$`
M`'$`````````>P$``-4`````````<@````P!`````````````,P```#L````
M70```&T```#X````(`$```,`````````E@`````````T`0``#0$``!T!````
M````C@````````"K````T@```$8!````````$P$``"8```````````````D!
M``!E````*P````````#Y`````````"0``````````````(D```#3````5@``
M`````````````````&<`````````'@$```````!<`````````"$!```N`0``
M`````&D!``!3`0``4P```.,````N````V0`````````I`````````'8````;
M````90$``',!````````E```````````````7`$``"H`````````BP$``+X`
M``!D`0``L0```$D!``#\````P@```%@!``"X````8P$``#\`````````````
M`($!```E`0``(0```'L```"`````````````````````OP```-`````(````
M-0``````````````]@````````":````.0````````!!`0``GP```&H!```8
M````;@````````"&````;`$```````"S````30$``&,```#R````"P$``/X`
M``!W````3P```(4```#I`````````(T!``!T`0``EP```"@!``"2`0``[0``
M`((!```\`0``(@`````````1`0``-P$``.L```"!````8@```(P`````````
M5@$``(8!``!*````V````(T```!1````$`$``-X`````````<@$``#`````R
M`````````"T!```+````-@```(X!`````````````-T```"N````+P$``&8`
M``"Y````1P$```````"[````<````&T!```$`````````$X!```>````````
M`(\```#+``````````````"C````>0$```````!U`0``G0```"T```"2````
M:0```$0````F`0```````$X``````````````$8```##`````````%H!``#F
M````'P$``+P`````````0@```(H````]`0``J@```+8```!>````MP``````
M``!L````(````$H!``!``0``%`````<!````````?0$``'P!``#.````K```
M`$4!``!$`0``BP```/<`````````&P$``#L!``#H`````````"H!````````
M&@```%`!```9`0``F0```!@!``#Q````V@`````````.`0``)P```#H```#4
M`````````!4!``"0`0``IP```#\!``!>`0``!0```)X`````````6````$``
M``"(`0``R`````4!``"8````X0```$L``````````````*8```!2````H@``
M`,0```!O`````````%L`````````SP```(`!``"0````UP```(H!````````
M;@$```$!``!5`0``/@```(D!````````.@$``&L!``#&````A````%L!````
M````,P$``*T````&`0``=````",!``!@````3P$``!T`````````?0```!D`
M``"I``````````````"]````U@```)P````*`0``@P$``-P```"E````0@$`
M`/``````````,0```'8!```?``````````````!-````?P$``&@!````````
M`````",````/`0``7P````````#B````L@`````````,````8`$`````````
M```````````````````````````````*````=0````````"#````80```&@`
M``#'````_P```!8```"D````*0$``/,`````````2`$```````!2`0``]0``
M```````7````B``````````&````;P$```````!D````$`````<`````````
M-P```&<!``#O````8@$``````````````````%\!```/````#@```%0!````
M`````````/0````)`````P$```````"5````^P`````````4`0``)`$``((`
M```:`0```````"@````5`````````"P```!_````N@```#`!``#N````<0$`
M`%H````]````Y`````(!``!Y`````````*@`````````?@$``(\!```X````
M<`$``*\````^`0``$P````````!#````50```#8!````````.0$``(P!````
M````H````)L```"3````.P````````#J````70$``$P!``#?````VP```&8!
M```L`0``?````$,!````````R@````(```!W`0``%@$``+``````````````
M``````#-````_0`````````X`0``````````````````D0$``/H````R`0``
MY0```,D`````````'````#$!``!1`0``A0$``$4```!(````00```!(!```-
M`````````$L!``#%````>@$``!P!``"$`0``:P```&H`````````M````%D!
M```T````````````````````/`````````!4````$@``````````````3```
M`*$```#!````"`$``.<`````````4`````````!X````60`````!```S````
M$0```,```````````````'H`````````)P$```````"'`0``!`$``(<```"U
M`````````$D```!A`0``5P$```````!^````5P```-$`````(D9I<G-T;F%M
M92!,87-T;F%M92(@("AI92X@2F]H;B!$;V4I`"),87-T;F%M92P@1FER<W1N
M86UE(B`H:64N($1O92P@2F]H;BD`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E
M9``Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!32]0
M30!!8F]V92!S96%R8V@@9F]R;0!!8V-E<W,@9&5N:65D('1O("5S`$%C8V]U
M;G0@26YF;W)M871I;VX`061D`$%D9"!(97)E.@!!9&0@9FEL90!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O
M`$%D9')E<W,`061D<F5S<R!";V]K`$%D9')E<W,@0F]O:R!,:7-T:6YG`$%D
M9')E<W,@0F]O:W,`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@
M;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061V86YC960@4V5A<F-H`$%L
M:6%S`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L
M;"!097)M:7-S:6]N<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T
M>7!E/P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S
M=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E
M861Y+@!!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@)7,_
M`$%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L
M96-T960@96YT<FEE<S\`07-C96YD:6YG`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`079A:6QA8FQE
M(&9I96QD<SH`0F%S:6,@4V5A<F-H`$)E;&]W('-E87)C:"!F;W)M`$)I<G1H
M9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0U-6`$-A;&5N9&%R`$-A
M;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%T96=O<FEE<R!A;F0@3&%B
M96QS`$-E;&P@4&AO;F4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B!E;6%I;',N`$-H96-K(%]!;&PO3F]N90!#:&5C:R!T:&4@8F]X(&9O<B!A
M;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T
M:6UE+@!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A(&1E9F%U;'0@9&ER
M96-T;W)Y(&9O<B!Y;W5R('!E<G-O;F%L(&%D9')E<W-B;V]K+"!C;VYT86-T
M(&QI<W1S+"!A;F0@<V5A<F-H97,N`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SH`0VAO;W-E('1H92!O<F1E<B!O9B!T:&4@8V]L=6UN<R!T;R!D:7-P
M;&%Y(&EN('1H92!A9&1R97-S(&QI<W0N`$-H;V]S92!W:&EC:"!C;VQU;6YS
M('1O(&1I<W!L87D@86YD(&EN('=H870@;W)D97(Z`$-L96%R(%-E87)C:`!#
M;&]S92!7:6YD;W<`0V]L;&%P<V4@4VED96)A<@!#;VQU;6X@3W!T:6]N<P!#
M;VQU;6YS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.@!#;VUM82!S97!A
M<F%T960@=F%L=65S`$-O;6UA('-E<&%R871E9"!V86QU97,@*$UI8W)O<V]F
M="!/=71L;V]K*0!#;VUP86YY`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N`$-O;G1A8W0@4V5A<F-H`$-O;G1A8W1S(&EN(&QI<W0Z("5S`$-O;G1E
M;G1S(&]F("5S`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S`$-R96%T90!#<F5A=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.@!#
M<F5A=&4@82!N97<@;VYE`$-R96%T;W(@4&5R;6ES<VEO;G,`0W5R<F5N="!4
M:6UE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`
M1$0`1&%I;'D`1&%T90!$969A=6QT($-O;&]R`$1E9F%U;'0@1&ES<&QA>0!$
M969A=6QT($ED96YT:71Y`$1E9F%U;'0@9&ER96-T;W)Y(&9O<B!Y;W5R('!E
M<G-O;F%L(&%D9')E<W-B;V]K+"!C;VYT86-T(&QI<W1S+"!A;F0@<V5A<F-H
M97,N`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T90!$96QE=&4@
M0V]N9FER;6%T:6]N`$1E;&5T92!B=71T;VX@8F5H879I;W5R`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&EO;B!F86EL960`1&5S8V5N9&EN9P!$
M97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7)E8W1O<GD`
M1&ES<&QA>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N
M<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y
M;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@)7,`161I=`!%9&ET
M($)L;V-K`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F
M;W(Z`$5M86EL`$5M<'1Y(')E<W5L="X`16YA8FQE(')I9VAT(&-L:6-K(&-O
M;G1E>'0@;65N=3\`16YT<GD@9F]R("5S('5P9&%T960N`$5R<F]R`$5V97)Y
M(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`
M179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X<&%N9`!%>'!O<G0`17AP
M;W)T($%D9')E<W,@0F]O:P!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,`1F%X`$9I;&4`1FEL92!-86YA
M9V5R`$9I;&5S`$9I;'1E<G,`1FEN9`!&<F]M`$9U;&P@1&5S8W)I<'1I;VX`
M1VQO8F%L($]P=&EO;G,`1V\`1V]O9VQE(%-E87)C:`!'<F]U<',`1W5E<W0@
M4&5R;6ES<VEO;G,`2&5A9&5R<P!(96QP`$AE;6ES<&AE<F4`2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(;U]M90!(;VUE`$AO;64@061D
M<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T
M97AT`$ED96YT:71Y)W,@;F%M93H`26UA9V5S`$EM<&]R="!!9&1R97-S($)O
M;VLL(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@061D
M<F5S<R!";V]K<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);F1I=FED=6%L(%5S97)S`$EN=F%L:60@240`26YV86QI9"!A9&1R97-S
M(&)O;VL`26YV86QI9"!E;6%I;`!);G9A;&ED(&5N=')Y`$EN=F%L:60@;F%M
M90!,85]Y;W5T`$QA;F=U86=E`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%Y;W5T`$QI<W0`3&ES
M="!(96QP(%1O<&EC<P!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN
M`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`34T`36%I;`!-86YA9V4@=&AE
M(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W
M:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R
M:65S+@!-871C:&EN9P!-871C:&EN9R!F:65L9',`36%X:6UU;2!N=6UB97(@
M;V8@<&%G97,`365N=2!M;V1E.@!-97-S86=E`$UO8FEL92!0:&]N90!-;VYT
M:&QY`$UO;VX@4&AA<V5S`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E
M(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``375L8F5R<GD@061D
M<F5S<R!";V]K`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!-
M>2!!9&1R97-S($)O;VL`3F%M90!.86UE($9O<FUA=`!.979E<@!.97<@0V%T
M96=O<GD`3F5W($-O;G1A8W0`3F5W<P!.97AT`$YE>'0@;W!T:6]N<P!.;P!.
M;R!V86QU97,`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W1E<P!.=6UB97(@;V8@
M:71E;7,@<&5R('!A9V4`3TL`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A
M;FEZ:6YG`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`4&%S<W=O
M<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&5R9F]R;2!-86EN=&5N86YC92!/
M<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<P!097)S;VYA;"!);F9O<FUA
M=&EO;@!0:&]N90!0:6YE($%D9')E<W,@0F]O:P!0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@;F%M92!T:&4@;F5W
M(&-O;G1A8W0@;&ES=#H`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H
M92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P
M87-S=V]R9`!0;&5A<V4@<V5L96-T(&$@9&ER96-T;W)Y.@!0<F5V:6]U<R!O
M<'1I;VYS`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!1=6EC:R!396%R
M8V@`4F5A9`!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H(%!O<G1A;"!6:65W.@!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@9G)O;2!T:&ES(&QI<W0`4F5M;W9E('!A:7(`
M4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@:6UP;W)T
M960@;VYE/R`\8CY787)N:6YG.B!4:&ES(&1E;&5T97,@86QL(&5N=')I97,@
M:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@8F]O:RX\+V(^`%)E<&QA8V4@97AI
M<W1I;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T
M<F]N9SY787)N:6YG.B!4:&ES(&1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U
M<B!C=7)R96YT(&%D9')E<W,@8F]O:RX\+W-T<F]N9SX`4F5S970`4F5S970@
M=&\@1&5F875L=',`4F5T=7)N('1O($]P=&EO;G,`4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS`%)O;&4`4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E87)C
M:"!297-U;'1S`%-E87)C:&EN9R!/<'1I;VYS`%-E;&5C="!,:7-T`%-E;&5C
M="!A('-E<G9E<@!396QE8W0@86QL`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@
M861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.@!396QE8W0@=&AE(&%D9')E
M<W,@8F]O:R!T;R!I;7!O<G0@=&\Z`%-E;&5C="!T:&4@8VAA<G-E="!O9B!T
M:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA
M=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F;W)M
M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@=&AE(&9O<FUA="!U<V5D
M('1O(&1I<W!L87D@;F%M97,Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('9I97<@=&\@9&ES<&QA>2!B
M>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RX`
M4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+@!396QE8W0@=VAI
M8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N`%-E
M;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RX`4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z`%-E;&5C=&5D($-O;'5M;G,Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-H;U]W($%L;`!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W($%L;`!3:&]W($-O;G1A8W1S`%-H;W<@3&ES=',`
M4VAO=R!?0V]N=&%C=',`4VAO=R!?3&ES=',`4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N
M=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H<FEN:P!3
M:7IE`%-K:7`@36%I;G1E;F%N8V4`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&5C
M:6%L($-H87)A8W1E<B!);G!U=`!3<&5C:69Y('=H97)E('EO=2!W86YT(&%D
M=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BX`4W1A='5S`%-U8FIE
M8W0`4W5B;6ET`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("5D(&-O;G1A
M8W0H<RD@=&\@;&ES="X`4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S`%-U
M8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@(B5S(BX`4W5C
M8V5S<V9U;&QY(&1E;&5T960@)60@8V]N=&%C="AS*2X`4W5C8V5S<V9U;&QY
M(')E;6]V960@)60@8V]N=&%C="AS*2!F<F]M(&QI<W0N`%-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C
M8V5S<V9U;&QY('=R;W1E("5S`%-U;G)I<V4O4W5N<V5T`%1A8B!S97!A<F%T
M960@=F%L=65S`%1A<VMS`%1E>'0@3VYL>0!4:&4@861D<F5S<R!B;V]K("(E
M<R(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5S92!C
M;VQU;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+@!4:6-K971S`%1I;64@9F]R;6%T`%1I=&QE`%1O`%1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%523`!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5N9FEL960`57!D871E`%5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N`%5S97(`57-E<B!/<'1I;VYS`%5S97)N86UE`%5S97)N86UE.@!5<V5R
M;F%M93H@`%9I97<@(B5S(@!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B
M('!A9V4`5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0Z`%=A<FYI;F<`5V5B
M`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H:6-H('!H
M87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!960!996%R;'D`665S`%EO=2!H879E(&)E96X@;&]G9V5D(&]U
M="X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D
M9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO
M=7(@3F%M90!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M0<F]B;&5M(%)E
M<&]R=%T`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0G)O=W-E
M`%]$96QE=&4`7T=R;W5P<P!?2&5L<`!?26UP;W)T+T5X<&]R=`!?3&]G(&]U
M=`!?3F5W($-O;G1A8W0`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]396%R8V@`
M7U-E='5P`%]5<V5R<P!E9&ET`&YO;F4`=&\@82!#;VYT86-T($QI<W0`=6YN
M86UE9`!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A($@S('8R+C`N
M-`I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI0
M3U0M0W)E871I;VXM1&%T93H@,C`P-BTP,2TQ-2`Q-3HT,BLP,C`P"E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#8M,#$M,3<@,3DZ-#`K,#(P,`I,87-T+51R86YS
M;&%T;W(Z($%L97AE>2!:86MH87)O=B`\8F%B97)`;6]S9V$N;F5T/@I,86YG
M=6%G92U496%M.B!2=7-S:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-
M12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/4-0,3(U,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`B
MR.S_(-3@[.CKZ/\B("C"X/'_(,_S[^KH[2D`(M3@[.CKZ/\L(,CL_R(@*,_S
M[^KH[2P@PN#Q_RD`SN_E\.#VZ/\@[^[DY.7PYNKH("5S("T@S^[D\N+E\.;D
MY>WHY0#4X.GK("5S(//Q[^7X[>X@Z.SO[O#RZ/#NXN#M`#$R+??@\>[B[ND`
M,C0M]^#Q[N+NZ0`R-"#WX/'@`$%-+U!-`,W@Y"#T[O#L[ND@[^[H\>K@`,3N
M\?+S[R#GX._PY?GE[2#DZ_\@)7,`T_?E\NW@_R#GX._H\?P`Q.[AX.+H\OP`
MQ.[AX.+H\OPZ`.?@X_#SY^CR_`#$[N'@XNCR_"#OX/#S`,3NX>#BZ/+\($UO
M>FEL;&$@4VED96)A<@#$[N'@XNCR_`#`Y/#E\0#`Y/#E\>W@_R#J[>CCX`#1
M[N3E\.;@[>CE(.#D\.7Q[>[I(.KMZ./H`,#D\.7Q[?OE(.KMZ./H`,W@\?+P
M[NGJZ"`M(//Q\N#M[N+JX"#O\.#B(.3K_R#D\//CZ/4@[^[K_.?NXN#RY>OE
MZ0#3[_#@XNOE[>CE`-#@\?CH\.7M[?OI(,_NZ/'J`,_QY>+D[NWH[`#"\>4`
MPO'E(.+N^.7D^.CE`,+QY2#C\//O[_L`PO'E(._PX.+@`-#@Y_#E^.CR_"#N
M[^7PX/;HZ"#Q[B#Q[^CQZN#LZ`#`Z_SRY?#MX/+HXNW[Z2!)4TU0`,_@\.[K
M_#H`R.S_(._NZ_SG[N+@\N7K_R!)4TU0.@#!^^ON(//JX.?@[>X@[>7J[O#P
MY>KR[>[E(.?MX/?E[>CE+@#/\.CK[N;E[>CE`,W@\?+P[N7M[@#"^R#SXN7P
MY>W[+"#W\NX@]>[RZ/+E(/'DY>O@\OP@_?+N/P#"^R#SXN7PY>W[+"#W\NX@
M]>[RZ/+E(/'DY>O@\OP@_?+N/P#/[B#B[N?PX/'RX.WH_@#'X._PX/CHXN#R
M_"#O[N3RXN7PYN3E[>CE(._E\.7D(.+[[^[K[>7MZ.7L(.[OY?#@]NCI(.[A
M\>OSYNCBX.WH_S\`S^[O^_+JX"#SY.#KZ/+\(.WE\?/YY?'RXO/^^>CE(._P
MX.+@`,_N[_ORZN`@\.7DX.KRZ/#NXN#R_"#MY?'S^>7Q\N+S_OGHY2#O\.#B
MX`#$[O'R\^_M^^4@[^[K_SH`S^[H\>H`S^[D(/3N\.SNZ2#O[NCQZN``Q.7M
M_"#P[N;DY>WH_P#-X/'R\.[IZN`Z`-#@\?CH\.7MZ.4`0U-6+?3@Z>L`RN#K
MY>WDX/#\`,[R[.7MX`#.\NSE[>`@[O+WY?+@(.X@[_#NX>OE[.4`RN#RY>/N
M\.CH(.@@[.7RZN@`RNOE\N[W[>#_(/#@Y.CN\>+_Y_P`S>#Q\O#NZ>KH(.CL
MY>WH+"#@Y/#E\>`L(._NY._H\>@N`,+[Y.7KZ/+\(.+QY0#.\NSE\OSRY2#T
MZ^#FZN#LZ"#N[^7PX/;H_BCHZ"DL(.KN\N[P^^4@POL@]>[RZ/+E(.[Q\_GE
M\?+BZ/+\+@#"^^'E\.CRY2#O\.CK[N;E[>CE.@#"^^'N\"#@Y/#E\>WNZ2#J
M[>CCZ"#H(.[O]NCI(.3K_R#O[NCQZN``U.[P[.#R(.[R[N'PX.;E[>C_(.3@
M\OLZ`,+[X>7PZ/+E(._N\/_D[NH@[O+NX?#@YN7MZ/\@\?+NZ^'V[N(@XB#Q
M[^CQZN4@X.3PY?'NXBX`POOAY?#H\N4@\>+NZ?'RXN`L(.KN\N[P^^D@X?/D
M\_(@[O+NX?#@YN7M^P#.]^CQ\NCR_`#'X.KP^_+\(.[J[>X`T^'PX/+\(.SE
M[?X`T?+NZ^'V^P#-Y>[R[N'PX.;@Y>S[Y2#QXN[I\?+BX#H`0U-6+?3@Z>L@
M*/#@Y^3EZ^7M[?OI(.?@[__R^^SH*0!#4U8M].#IZR`H].[P[.#R($UI8W)O
M<V]F="!/=71L;V]K*0#*[NSOX.WH_P#*[NWTZ./S\.#VZ/\@\_'RX/#EZ^``
MS>#I\N@@ZN[M\N#J\@#*[NWRX.KR^R#B(./P\^_OY3H@)7,`T>[DY?#FX.WH
MY2`E<P#-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@
M)7,`T>[GY.#R_`#1[N?DX/+\(.WNXO/^(./P\^_O\R#B.@#1[N?DX/+\(.WN
MXOOI(._P[O3HZ_P`T>[GY.#RY>O\`-+EZO/YY>4@XO#E[/\`Q^#DX/?H+"#G
MX._S\>K@Y>S[Y2#O\.@@XO7NY.4@XB`E<P#$Q`#%YN7D[>7B[>X`Q.#RX`#6
MXN7R(._N(//L[NOWX.WH_@#/\.[TZ.O\(._N(//L[NOWX.WH_@#/\.[TZ.O\
M(._N(//L[NOWX.WH_@#`Y/#E\>W@_R#J[>CCX"#O[B#S[.[K]^#MZ/X`S^[P
M_^3NZB#Q[O#RZ/#NXNKH`-/DX.OH\OP`T^3@Z^7MZ.4`S^[D\N+E\.;DY>WH
MY2#N[^7PX/;HZ"#SY.#KY>WH_P#3Y.#KZ/+\(.+[X?#@[>W[Z2#O\.[TZ.O\
M`,[XZ.'JX"#O\.@@\^3@Z^7MZ.@`S^X@\^'[XN#MZ/X`SN_H^.CRY2#O\.[A
MZ^7L\P#.[^CQX.WHY0#/[N3P[N'M[O'RZ"#A^^OH(.?@[^CQX.W[(.(@YO/P
M[>#K(.3K_R#@Y.SH[>CQ\O#@\N[PX"X`RN#RX.ONXP#.X>[K[O?JX`#.\N[A
M\.#FX/+\(.+PY>S_(.(@,C0M]^#Q[N+N["#T[O#LX/+E/P#.\>WNXNW[Y2#M
MX/'R\.[IZN@`S>4@XOOG^^+@Z?+E(&UA:6YT96YA;F-E+G!H<"#MY>_N\?#E
MY/'RXN7M[>X`Q^#O\.#XZ.+@\OP@[^[D\N+E\.;DY>WHY2#O\.@@\^3@Z^7M
MZ.@@Y^#OZ/'EZ3\`PB#OY?#B[ND@\?+P[NKE(//JX.?@[?L@Z.SE[>`@[^[K
MY>D_(,7QZ^@@Y.`L(._N\?+@XOSRY2#CX.ON]^KS.B``Q^#C\//GZ/+\`,?@
MX_#SY^CR_"`E<P#0Y>3@ZO+H\.[BX.WHY0#0Y>3@ZO+H\.[BX/+\`-/Q\N#M
M[N+JX"#O\.#B(.3K_R`E<P#-X/'R\.[IZN@`12UM86EL`,WSZ^7B[ND@\.7G
M\^O\\N#R+@#*[NWRY>KQ\NWNY2#LY>W^(._N(.W@YN#RZ.@@[_#@XN[I(.KM
M[N_JZ"#L^_CH`,?@[^CQ_"`E<R#NX>WNXNOE[>`N`,[XZ.'JX`#*X.;D^^4@
M,34@[.CM\_(`RN#FY/OE(#(@[.CM\_+[`,K@YN3[Y2`S,"#QY>KS[>0`RN#F
MY/OE(#4@[.CM\_(`RN#FY/OI(/#@YR#O\.@@XO7NY.4`RN#FY/OE(._NZ_?@
M\>``RN#FY//^(.SH[?/R\P#/\.CLY?`@Y^W@]^7MZ.DZ`-#@\?CH\.CR_`#=
MZO'O[O#R`-WJ\>_N\/(@X.3PY?'M[ND@ZNWHX^@`PN[Q\?+@[>[BZ^7MZ.4@
M[>#Q\O#NY>H@[>4@\^3@Z^[Q_"X`S>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#Q
MY?#BY?#N["!,1$%0+@#.^.CAZN`@[_#H(._NZ/'JY2#B(.K@\N#K[N/E.B`E
M<P#4X.KQ`-3@Z>L`U?#@[>CKZ/G@`-3@Z>O[`-3HZ_SR\/L`S>#I\N@`SO(`
MS^[K[>[E(.[OZ/'@[>CE(._P[N'KY>S[.@#/[O#RX.L`S^7PY>GRZ`#/[NCQ
MZB#B($=O;V=L90##\//O[_L`P^[Q\OP`Q^#C[NONXNKH`,_NY/'JX.?JX`#/
M[NOS^.#PZ.4`S>CFY2#O\.7D\?+@XNOE[>`@Z.WT[O#LX/;H_R#HYR#QX.SN
MX^X@[>#WX.O@(/3@Z>O@.@#/[O#RX.L`S^[P\N#K`,3N[.#X[>CI(.#D\.7Q
M`,3N[.#X[>CI(/+EZ^7T[NT`S^[P\N#K`-+NZ_SJ[B#HZN[MZN@`R.KN[>KH
M(/$@\N7J\?+N[`#([/\@[_#N].CK_SH`RN#P\NCMZN@`R.SO[O#R(.#D\.7Q
M[>[I(.KMZ./H+"#8X.,@)60`R.SO[O#R+"#XX.,@)60`R.SO[O#R+]WJ\>_N
M\/(@X.3PY?'M[ND@ZNWHX^@`R.SO[O#RZ/#NXN#M[B#O[NOE.B`E<P#([._N
M\/+H\.[BX.W[(._NZ_\Z`,_NZ_SG[N+@\N7KZ`#-Y>KN\/#EZO+M[N4@Z.S_
M+@#-Y>KN\/#EZO+MX/\@X.3PY?'MX/\@ZNWHX^`N`,WEZN[P\.7J\NW[Z2!E
M+6UA:6PN`,WEZN[P\.7J\NWNY2#H[/\N`,WEZN[P\.7J\NWNY2#H[/\N`-#@
M\>KKX.3JX`#?Y_OJ`,_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S`,_PY>3[Y//Y
MZ.D@XO7NY"#A^^LZ("5S(/$@ZN[L[_S^\N7PX"`E<P#/\.7D^^3S^>CI(.+U
M[N0@[>4@Y^#TZ.KQZ/#NXN#M`,+[]>[D`-'OZ/'NZ@#1[^CQ[NH@\.#GY.7K
M[N(@[^[D\>K@Y^KH`,ONZN#KZ.?@]NC_`-#@\>_NZ^[FY>WHY0#"]>[D`,+[
M]>[D`-/WY?+MX/\@Y^#OZ/'\`,+U[N0`S,P`S^[W\N``S>#Q\O#NZ>K@(/'O
MZ/'JX"#JX/+EX^[PZ.D@Z"#VXN7R[N(@Z/4@[O+NX?#@YN7MZ/\`T>[B[^#D
MY>WHY0#1[N+OX.3@_OGHY2#O[NO_`,S@ZO'H[.#K_.WNY2#J[NOH]^7Q\N+N
M(/'R\.#MZ/8`T.7FZ.P@[.7M_CH`T>[NX?GE[>CE`,SNX>CK_.W[Z2#RY>OE
M].[M`,7FY>SE\?_W[>X`U.#G^R#+\^W[`,_E\.7LY?'RZ/+\`._E\.7LY?'R
MZ/+\(.+MZ.<`[^7PY>SE\?+H\OP@XNOEXNX`[^7PY>SE\?+H\OP@XN_PX.+N
M`._E\.7LY?'RZ/+\(.+BY?#U`._E\.7LY?'RZ/+\(.+MZ.<`[^7PY>SE\?+H
M\OP@XN+E\/4`P.3PY?'MX/\@ZNWHX^`@375L8F5R<GD`T_?E\NW@_R#GX._H
M\?P`PN#XX"#H[?3N\.S@]NC_`,#D\.7Q[>#_(.KMZ./@`,CL_P#([.7MX`#-
MZ.KNX^3@`,WNXN#_(.K@\N7C[O#H_P#$[N'@XNCR_"#M[N+S_B#GX._H\?P`
MS>[B[O'RZ`#$X.OEY0#1Z^7D\_[YX/\@\?+PX.WH]N``S>7R`,WE(.[O\.7D
MY>OE[>X`T>7BY?#M[N4@[^[K\_C@\.CE`,?@[.7RZN@`RN[K+>+N(.?@[^CQ
MY>D@[>`@\?+PX.WH]N4`3TL`S>#Q\O#NZ>KH`,W@\?+P[NGJZ"#DZ_\Z("5S
M`,[PX^#MX.GGY?``S_#N]^#_(.CM].[P[.#VZ/\`Q/#SX^CE(.W@\?+P[NGJ
MZ`#/X/#NZ_P`S^#P[NO\`,_@\.[K_`#.\?/YY?'RXNOE[>CE(.[OY?#@]NCI
M(._NY.3E\.;JZ`#"^^_NZ^WH\OP@[N_E\.#VZ.@@[N'QZ_/FZ.+@[>C_(._P
MZ"#B]>[DY2#B(/'H\?+E[/,_`,_PX.+@`,_PX.+@(.3N\?+S[^``R^CW[?OE
M`-+EZ^7T[NT`P.3PY?'MX/\@ZNWHX^`@4&EN90#"XN7DZ/+E(.W@Y^+@[>CE
M(.WNXN[I(.K@\N7C[O#HZ#H`S^[FX.OSZ?'RX"#BXN7DZ/+E(.WNXN[E(.CL
M_SH`S^[FX.OSZ?'RX"P@\>[NX?GH\N4@\?/R_"#O\.[AZ^7L^RX`S^[FX.OS
MZ?'RX"P@XN+EY.CRY2#"X/CH(.CL_R#O[NO\Y^[BX/+EZ_\@Z"#OX/#NZ_P`
MS^[FX.OSZ?'RX"P@XOOAY?#H\N4@ZN#RX.ONXSH`S_#EY/OD\_G@_R#Q\O#@
M[>CVX`#/\.[AZ^7LX#\`SN_H\>#MZ.4@[_#NX>OE[/L`P?OQ\O#[Z2#O[NCQ
MZ@#7Z/+@\OP`SN'M[N+H\OP`SN'M[N+K__+\(.3H[>#LZ/?E\>KHY2#O\^WJ
M\OL@[.7M_CH`SN'M[N+K__+\(.CM].[P[.#VZ/XZ`,_N]_+NXOOE(/'E\.+E
M\.``P.3PY?$@\>7PXN7PX"`H[>#O\.CLY?`@:'1T<#HO+VUA:6PN<G4I`-/D
MX.OH\OP`T^3@Z^CR_"#AZ^[J`-/DX.OH\OP@Z.<@X_#S[^_[`-/DX.OH\OP@
M[^#P\P#/[NOM[O'R_/X@Y^#LY>WH\OP@\?/YY?'RXO/^^?/^(.#D\.7Q[?/^
M(.KMZ./S+B`\8C[/\.@@_?+N["#A\^3S\B#SY.#KY>W[(,+1Q2#GX._H\>@@
MZ.<@\N7J\_GEZ2#@Y/#E\>WNZ2#J[>CCZ#PO8CX`S^[K[>[Q\OS^(.?@[.7M
MZ/+\(/'S^>7Q\N+S_OGS_B#@Y/#E\>WS_B#J[>CC\RX@/&(^S_#H(/WR[NP@
MX?/D\_(@\^3@Z^7M^R#"T<4@Y^#OZ/'H(.CG(/+EZO/YY>D@X.3PY?'M[ND@
MZNWHX^@\+V(^`-'A\.[QZ/+\`-'A\.[QZ/+\`,+E\.WS\OSQ_R#J(.W@\?+P
M[NGJX.P`S>#Q\O#NZ>KH(.+HY_/@Z_SM[N/N(/#EY.#J\N[PX`#1]N7MX/#H
MZ0#1[O7PX.WH\OP`T>[U\.#MZ/+\(.W@\?+P[NGJZ`#/[NCQZ@#0Y>?SZ_SR
MX/+[(._NZ/'JX`#/[NCQZ@#"^^'E\.CRY2#C\//O[_,`POOAY?#H\N4@\>7P
MXN7P`,+[X?#@\OP@XO'E`,[R[.7MZ/+\(.+[X>[P`,+[X>7PZ/+E(.#D\.7Q
M[?/^(.KMZ./S(.3K_R#]ZO'O[O#RX#H`RO/DX"#"^R#U[O+H\N4@Z.SO[O#R
MZ/#NXN#R_#H`T^K@YNCRY2#J[N3H\.[BZO,@Z.SO[O#RZ/#SY>SNX^X@].#I
MZ^`Z`,+[X>7PZ/+E(/#@Y^3EZ^CRY>O\(._NZ^7I(.3@\OLZ`,+[X>7PZ/+E
M(/3N\.S@\B#DX/+[.@#"^^'E\.CRY2#T[O#LX/(@_>KQ[^[P\NCP\^7L[N/N
M(/3@Z>O@.@#([._N\/+H\//E[/OI(/3@Z>LZ`,+[X>7PZ/+E(/3N\.S@\B#H
M[._N\/+H\//E[.[C[B#TX.GKX#H`POOAY?#H\N4@].[P[.#R(.[R[N'PX.;E
M[>C_(.CLY>TZ`,+[X>7PZ/+E(._P[O3HZ_P@Y.O_(.W@\?+P[NGJZ#H`POOA
MY?#H\N4@[O+NX?#@YN7MZ/\@].[P[.#R(.+PY>SE[>@Z`,+[X>7PZ/+E(.3B
MX"#Q[N+OX.3@_OGH]2#O[NO_+@#-X/'R\.[IZN`@\.7FZ.S@(.[R[N'PX.;E
M[>C_(._N(//L[NOWX.WH_@#-X/'R\.[IZN`@\.7FZ.S@(.[R[N'PX.;E[>C_
M(._N(//L[NOWX.WH_@#"^^'N\"#O[O#_Y.K@(.[R[N'PX.;E[>C_(/'R[NOA
M]N[B(.(@\>_H\>KE(.#D\.7Q[N(N`,+[X>[P(/3N\.S@\N`@[O+NX?#@YN7M
MZ/\@Z.SE[0#"X/C@(/;BY?+NXN#_(/'UY>S@`-_G^^H@[O+NX?#@YN7MZ/\`
MPOOA\.#M[?OE(/'R[NOA]OLZ`,_N\>O@\OP@\>[NX?GE[>CE(.X@[_#NX>OE
M[.4`Q.[O[NOMZ/+EZ_SM^^4@[^[W\N[B^^4@\>7PXN7PX"P@ZB#J[O+N\/OL
M(.+[(/7N\NCRY2#H[.7R_"#D[O'R\^\@Z.<@S^[P\N#KX"X`T_'RX.WNXNK@
M(/_G^^K@(.+[XN[DX"P@XO#E[.7M[>[I(.?N[?L@Z"#T[O#LX/+@(.[R[N'P
MX.;E[>C_(.+PY>SE[>@N`-/Q\N#M[N+JX"#O\.CK[N;E[>C_(._N(//L[NOW
MX.WH_BP@]N+E\N[B[ND@\?7E[/L@Z"#O\.[WZ/4@[N_VZ.D@[O+NX?#@YN7M
MZ/\`S_#HZ^[FY>WH_P#"\>4`RO#@\NKNY2#NX>[A^>7MZ.4Z`,[O\.7DY>OH
M\OP@X?OQ\O#[Y2#JZ^#BZ/CH(.3K_R#Q\?OK[NH_`,_NZN#GX/+\(.+QY0#/
M[NK@Y^#R_"#*[NWRX.KR^P#/[NK@Y^#R_"##\//O[_L`RN[M\N#J\OL`P_#S
M[^_[`,_NZN#G^^+@\OP@Z.WT[O#LX/;H_B#N(._PY>3[Y//YY>P@XO7NY.4_
M`,_NZN#GX/+\(.SE[?X@[N_E\.#VZ.D@\2#RX.'KZ/;@[.@`SO+NX?#@YN#R
M_"#LY>W^("5S(/'KY>+@/P#1\^?H\OP`T.#G[.7P`,_P[N_S\?+H\OP@[^[D
MY.7PYNKS`-[F[>[E(._NZ_/XX/#HY0#1[^7VZ.#K_.W[Y2#QZ.SB[NO[`,/D
MY2#N\N[A\.#FX/+\(/#EY_/K_/+@\OL@\.#Q^.CPY>WM[N/N(._NZ/'JX`#1
M\N#R\_$`TN7LX`#(\>K@\OP`T_'OY?CM[@`E9"#A^^L@\_'OY?CM[B#D[N'@
MXNOE[0#$[N'@XNOE[>X@(B5S(B#B("(E<R(N`-'NY^3@[>`@X_#S[^_@("<E
M<R<`T^3@Z^7M[B`E9"#J[NWRX.KR[N(`T^3@Z^7M[B`E9"#J[NWRX.KR[N(@
MZ.<@X_#S[^_[`-'RX/#@_R#J[NWTZ./S\.#VZ/\@\>[U\.#MY>W@(.(@].#I
MZSH@)7,`S>[BX/\@ZN[M].CC\_#@]NC_(/'N]?#@[>7MX"#B.B`E<P#"\.7L
M_R#B[O'U[N3@+^?@ZN#RX`!44U8M].#IZR`H\.#GY.7KY>WM^^D@\N#A\^O_
M]NCEZ2D`Q^#DX/?H`-+NZ_SJ[B#RY>KQ\@#/X._JX"`B)7,B(.'[Z^`@\_'O
MY?CM[B#SY.#KY>W@+@#1Y?#BY?`@)7,@X?OK(//DX.OE[0#1Y?#BY?`@)7,@
MX?OK(/'NY^3@[0#-Y?(@X.3PY?'M^_4@ZNWHXRP@Y.[Q\O/O[?OU(.3K_R#B
M^^'N\.`N`,WE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN`-'N[N'YY>WHY2#B(.WE
MXN7P[>[L(/3N\.S@\N4@Z"#MY2#L[N;E\B#A^_+\(.[R[N'PX.;E[>X`SOCH
MX>K@(._PZ"#N\N[A\.#FY>WHZ"#]\N[I(/?@\?+H(/'N[N'YY>WH_P#=\N@@
M\>+NZ?'RXN`@X?/D\_(@[O+NX?#@YN7M^P#=\NX@]^CQZ^X@[>4@[.[FY?(@
MX?OR_"#LY>W\^.4@Y>3H[>CV^RX`W?+N(.?MX/?E[>CE(.3NZ^;M[B#A^_+\
M(/?H\>ON["X`Q^#O\.[Q^P#4[O#LX/(@[O+NX?#@YN7MZ/\`Q^#C[NONXN[J
M`,KN[/,`U_+NX?L@XOOA\.#R_"#MY?'J[NO\ZNX@_>OE[.7M\N[B+"#SY.7P
MYNCBX.GRY2#MX.;@\N[I(.KKX.+HYO,@0W1R;`!54DP`S>7B[N?L[N;M[B#Q
M[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["X`S>7B[N?L[N;M[B#GX./P\^?H
M\OP@[N_PY>3EZ^7MZ.4@)7,N`-WR[O(@Y.[J\^SE[?(@5V]R9"#MY2#L[N;E
M\B#A^_+\(._E\.7BY>3E[2X`SO+LY>WH\OP@Z.?LY>WE[>C_`,_S\?+NZ0#/
M\.CLY>WH\OP`R/'O[NO\Y_/E\O'_(.7QZ^@@XN#XZ"#H[/\O[^#P[NO\(.3K
M_R!)35-0(/'E\.+E\.`@[O+KZ/?@_O+Q_R#N\B#RY>KS^>CU`,_NZ_SG[N+@
M\N7K_`#-X/'R\.[IZN@@[^[K_.?NXN#RY>O_`,CL_R#O[NO\Y^[BX/+EZ_\`
MR.S_(._NZ_SG[N+@\N7K_P#([/\@[^[K_.?NXN#RY>O_`,_P[O'L[O+P("5S
M`,_P[O'L[O+P("5S`,_NZN#GX/+\(.+EX2WQ\O#@[>CV\P#0Y>;H["#O[B#S
M[.[K]^#MZ/XZ`,+MZ.S@[>CE`,+EX0#%YN7MY>3EZ_SM[@#$[N'P[B#O[N;@
MZ^[BX/+\(.(@)7,`Q.[A\.X@[^[FX.ONXN#R_"P@)7,`U_+N(.[R[N'PX.;@
M\OP@[^[QZ^4@XO7NY.`@XB#QZ/'RY>SS.@#4X.?@`,K@ZNCE(.[O]NCH(.'S
MY//R(.3N\?+S[^W[(.(@XNCG\^#K_.WN["#PY>3@ZO+N\.4`V.CPZ.W@(.SE
M[?X@)7,@\>OEXN`@*.'SY.7R(._PZ.SE[>7MX"#O\.@@\>OEY//^^>7L(.+U
M[N3E*0#0X.'N]^CI(.#D\.7Q`-#@X>[WZ.D@\N7KY?3N[0##PP#%YN7C[N3M
M[@#$X`#"^R#B^_CKZ"#HYR#QZ/'RY>S[+@#"^R#D[NOF[?L@[N_H\>#R_"#O
M\.[AZ^7L^RP@[_#EYN3E(/?E["#Q[.[FY?+E(.[R[O'KX/+\(/'N[N'YY>WH
MY2#N(.WEZ2X`PN#XX"`E<R#QY?'QZ/\@Y^#J[NWWZ.O@\?PN(,_NYN#K\^GQ
M\N`L(.+NZ>3H\N4@XB#QZ/'RY>SS(.?@[>[B[BX`PN#X($5M86EL.@#"X/@@
MX.3PY?$@[O+O\.#BZ/+EZ_\Z`,+@^.`@Z.WT[O#LX/;H_P#"X/CE(.CL_SH`
MU^#Q[N+NZ2#O[O_Q`,+@^"#O\.[TZ.O\(._N(//L[NOWX.WH_CH`PN#XY2#H
M[/\Z`,+@^.@@[>#Q\O#NZ>KH(.'[Z^@@[N'M[N+KY>W[+@#1\N[P[NWMZ.D@
M\>7PXN7P.@!;T>[NX?GE[>CE(.X@[_#NX>OE[.5=`%OQ\O#NZN`@)7,@Z.<@
M)7-=`-/O\.#BZ^7MZ.4`POOA\.#R_`#3Y.#KZ/+\`,/P\^_O^P#/[NSN^?P`
MR.SO[O#R+]WJ\>_N\/(`POOU[N0`Q.[AX.+H\OP`S>#Q\O#NZ>KH`,_PX.+@
M`,_NZ/'J`,_PZ.ONYN7MZ/\`S^[K_.?NXN#RY>OH`,_PX.+H\OP`[>7R`.(@
MX_#S[^_S`/+EZO'R(/'N[N'YY>WH_P!V0V%R9```````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+W-K7U-+
M+P``````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<U-0`P,C`P,30`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M=7)B82]L;V-A;&4O<VM?4TLO3$-?34534T%'15,O````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4U`#`R,38P,0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]S:U]32R],0U]-15-304=%
M4R]T=7)B82YM;P``````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-34Q,S$`,3`T,3<S-C(W
M-34`,#(S,C8Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-X2!)4`````:@@``!P```!L0P``/PL``+R&````````N+,```X`
M``"YLP``#P```,BS```-````V+,```@```#FLP``"P```.^S```,````^[,`
M`!D````(M```&0```"*T```$````/+0``"D```!!M```&````&NT```;````
MA+0``"T```"@M```'0```,ZT```D````[+0``"D````1M0``*0```#NU```9
M````9;4``"@```!_M0``)````*BU```E````S;4``"8```#SM0``#````!JV
M```D````)[8```\```!,M@``"P```%RV```.````:+8```4```!WM@``*```
M`'VV```(````IK8```H```"OM@``%0```+JV```)````T+8``!(```#:M@``
M"P```.VV```=````^;8``(4````7MP``#@```)VW```*````K+<```T```"W
MMP``#@```,6W```1````U+<```T```#FMP``#````/2W```-`````;@```8`
M```/N```E````!:X```*````J[@```\```"VN```&````,:X```,````W[@`
M``X```#LN```#@```/NX```(````"KD```D````3N0``*P```!VY```N````
M2;D``!H```!XN0``,@```).Y```X````QKD``%0```#_N0``40```%2Z``!:
M````IKH``%<````!NP``-````%F[```)````CKL```T```"8NP``!P```*:[
M```*````KKL```\```"YNP``!0```,F[```&````S[L``!$```#6NP``"```
M`.B[```1````\;L```D````#O```"0````V\```E````%[P``"`````]O```
M$P```%Z\```3````<KP``!````"&O```#P```)>\```*````I[P```,```"R
MO```#P```+:\```4````QKP```D```#;O```#0```.6\```2````\[P``!D`
M```&O0``'@```""]```/````/[T``!````!/O0``(0```&"]```*````@KT`
M``@```"-O0``#P```):]```(````IKT``"0```"OO0``!@```-2]```4````
MV[T``!8```#PO0``"`````>^``!.````$+X``"T```!?O@``(0```(V^```9
M````K[X```<```#)O@``#````-&^```4````WKX```T```#SO@``$@````&_
M```A````%+\``!<````VOP``*0```$Z_```L````>+\```X```"EOP```P``
M`+2_```/````N+\```L```#(OP``!P```-2_```'````W+\```4```#DOP``
M!0```.J_```*````\+\```,```#[OP``%P```/^_```*````%\````\````B
MP```#@```#+````8````0<```",```!:P```#@```'[````.````C<```!0`
M``"<P```%P```+'````7````R<```!<```#AP```$P```/G````/````#<$`
M``X````=P0``'P```"S!```=````3,$```<```!JP0``!@```'+!```(````
M><$```\```""P0``!@```)+!```*````F<$``!,```"DP0``"P```+C!```0
M````Q,$``!4```#5P0``%0```.O!```'`````<(``!`````)P@``!0```!K"
M```1````(,(```P````RP@``*````#_"```Z````:,(``#L```"CP@``.```
M`-_"```)````&,,```<````BPP```P```"K#```%````+L,```D````TPP``
M$````#[#```)````3\,``!,```!9PP``.0```&W#```G````I\,``"P```#/
MPP``*@```/S#```E````)\0```H```!-Q```!@```%C$```)````7\0```<`
M``!IQ```+P```''$```W````H<0``"X```#9Q```50````C%```M````7L4`
M`"T```",Q0``/0```+K%```_````^,4``"T````XQ@``0````&;&```C````
MI\8``",```#+Q@``0````._&```M````,,<``#,```!>QP``)0```)+'```5
M````N,<``!D```#.QP``*0```.C'```D````$L@``"@````WR```$0```&#(
M```*````<L@```P```!]R```"@```(K(```0````E<@``!8```"FR```%@``
M`+W(```'````U,@```<```#<R```"@```.3(```(````[\@``"<```#XR```
M"````"#)```,````*<D```<````VR0``!P```#[)```&````1LD``!$```!-
MR0``!0```%_)```'````9<D```8```!MR0``%````'3)```(````B<D``"D`
M``"2R0``#@```+S)```*````R\D```0```#6R0``!P```-O)```)````X\D`
M``8```#MR0``$0```/3)```'````!LH``!8````.R@``!````"7*```(````
M*LH```8````SR@``#0```#K*```&````2,H``!X```!/R@``!@```&[*```1
M````=<H```@```"'R@``#0```)#*```,````GLH```<```"KR@``$0```+/*
M```#````Q<H```,```#)R@``%P```,W*```#````Y<H``!,```#IR@``'0``
M`/W*```(````&\L```0````DRP``"````"G+```(````,LL``$$````[RP``
M&@```'W+```<````F,L``"L```"URP``(````.'+```5`````LP```8````8
MS```!@```!_,```5````)LP``!@````\S```(@```%7,```N````>,P``!T`
M``"GS```(0```,7,``!4````Y\P``"D````\S0``"@```&;-```'````<<T`
M`!4```!YS0``#@```(_-```*````GLT```\```"IS0``#0```+G-```/````
MQ\T```T```#7S0``"0```.7-```&````[\T``!@```#VS0``$P````_.```1
M````(\X``!0````US@``!````$K.```&````3\X``!0```!6S@``5````&O.
M``!D````P,X```0````ESP``#@```"K/```/````.<\```4```!)SP``!0``
M`$_/```3````5<\```T```!ISP``$0```'?/```1````B<\``!8```";SP``
M%P```++/```<````RL\``"H```#GSP``.0```!+0```B````3-```#(```!O
MT```$````*+0```A````L]````4```#5T```$P```-O0```+````[]```!(`
M``#[T```"@````[1```/````&=$```T````IT0``$0```#?1```3````2=$`
M``P```!=T0``!@```&K1```,````<=$```8```!^T0``%P```(71```0````
MG=$``!$```"NT0``"````,#1```%````R=$```P```#/T0``$````-S1```%
M````[=$```X```#ST0``#0````+2```C````$-(```8````TT@``%@```#O2
M```J````4M(```<```!]T@``#0```(72```'````D](```L```";T@``!P``
M`*?2```'````K](```\```"WT@``"0```,?2```)````T=(```H```#;T@``
M&0```.;2```]`````-,``!T````^TP``#````%S3```0````:=,```4```!Z
MTP``)0```(#3```2````IM,``!,```"YTP``%0```,W3```2````X],``"L`
M``#VTP``.P```"+4```@````7M0```X```!_U```"````([4```4````E]0`
M`#8```"LU```(0```./4```0````!=4```@````6U0``#````!_5```&````
M+-4```0````SU0``#P```#C5```.````2-4```H```!7U0``#0```&+5```?
M````<-4``!P```"0U0``(0```*W5```>````S]4``!D```#NU0``'@````C6
M```=````)]8``!L```!%U@``(````&'6```N````@M8``"8```"QU@``'```
M`-C6```>````]=8``!P````4UP``)@```#'7```K````6-<``#,```"$UP``
M)@```+C7```K````W]<``#@````+V```'0```$38```5````8M@``"\```!X
MV```(````*C8```2````R=@``"D```#<V```'@````;9```@````)=D``!(`
M``!&V0``H@```%G9```6````_-D``",````3V@``*````#?:```I````8-H`
M`"@```"*V@``'P```+/:```5````T]H``"````#IV@``)0````K;```H````
M,-L``"T```!9VP``,````(?;``"2````N-L``"$```!+W```%@```&W<```<
M````A-P``"8```"AW```*@```,C<``!!````\]P``$0````UW0``#````'K=
M```'````A]T```<```"/W0``!@```)?=```3````GMT```T```"RW0``'0``
M`,#=```0````WMT``!(```#OW0``!P````+>```3````"MX``!(````>W@``
M!P```#'>```$````.=X``!`````^W@``$````$_>```,````8-X```X```!M
MW@``#0```'S>```/````BMX``!,```":W@``#0```*[>```H````O-X```,`
M``#EW@``#0```.G>```&````]]X```X```#^W@```@````W?``!)````$-\`
M``4```!:WP``$````&#?```/````<=\```0```"!WP``#0```(;?```.````
ME-\```,```"CWP``#@```*??```(````MM\```\```"_WP``#P```,_?```'
M````W]\```T```#GWP``$````/7?```-````!N```!H````4X```"P```"_@
M```&````.^```!,```!"X```"P```%;@```3````8N````P```!VX```"@``
M`(/@```1````CN```!D```"@X```%P```+K@```+````TN````T```#>X```
M(@```.S@```6````#^$``!L````FX0``-````$+A```*````=^$``!@```""
MX0``&0```)OA```6````M>$``"(```#,X0``(P```._A```/````$^(```T`
M```CX@``!P```#'B```*````.>(```H```!$X@``%````$_B```+````9.(`
M`"(```!PX@``+P```)/B```+````P^(```D```#/X@``&0```-GB```+````
M\^(``!<```#_X@``%P```!?C```)````+^,```<````YXP``%@```$'C```/
M````6.,``!D```!HXP``%@```(+C```.````F>,``!@```"HXP``"````,'C
M```-````RN,``"8```#8XP``*````/_C``!#````*.0```@```!LY```$@``
M`'7D```?````B.0```@```"HY```"P```+'D```O````O>0```X```#MY```
M#@```/SD```%````"^4```8````1Y0```P```!CE```'````'.4```0````D
MY0``"0```"GE```2````,^4```H```!&Y0``"@```%'E```/````7.4``!``
M``!LY0``%P```'WE```1````E>4``!$```"GY0``&0```+GE```7````T^4`
M``D```#KY0``!0```/7E```+````^^4```H````'Y@```@```!+F```%````
M%>8```T````;Y@``&P```"GF```7````1>8``!0```!=Y@``"0```'+F```.
M````?.8```T```"+Y@``$@```)GF```X````K.8``"````#EY@``"`````;G
M```.````#^<``'L````>YP``&````)KG```8````L^<``#T```#,YP``%0``
M``KH```1````(.@```<````RZ```!0```#KH```C````0.@``#,```!DZ```
M&````)CH```=````L>@``"X```#/Z```'@```/[H```;````'>D``!D````Y
MZ0``)P```%/I```W````>^D``"0```"SZ0``&P```-CI```9````].D``!,`
M```.Z@``!P```"+J```(````*NH```8````SZ@``!@```#KJ```0````0>H`
M``\```!2Z@``$````&+J```/````<^H```L```"#Z@``#P```(_J```,````
MG^H```\```"LZ@``!P```+SJ```&````Q.H```X```#+Z@``#````-KJ```H
M````Y^H```\````0ZP``"````"#K```&````*>L``!,````PZP``(@```$3K
M```M````9^L```@```"5ZP``$P```)[K```>````LNL``"4```#1ZP``&@``
M`/?K```5````$NP``!X````H[```0P```$?L```A````B^P``"````"M[```
M&0```,[L```7````Z.P``"4`````[0``)0```";M```7````3.T``!8```!D
M[0``(0```'OM```B````G>T```0```#`[0``&P```,7M```-````X>T```P`
M``#O[0```P```/SM```%`````.X```@````&[@``"@````_N```,````&NX`
M``L````G[@``$````#/N```,````1.X```0```!1[@``!````%;N```3````
M6^X``!0```!O[@``#````(3N```)````D>X```X```";[@``"P```*KN```;
M````MNX```4```#2[@``!P```-CN```$````X.X```8```#E[@``!P```.SN
M```*````].X```H```#_[@``#0````KO```)````&.\```0````B[P``!0``
M`"?O```#````+>\``!@````Q[P``"@```$KO```$````5>\``"8```!:[P``
M#@```('O``!\````D.\``!4````-\```!0```"/P```'````*?````P````Q
M\```"````#[P```*````1_````8```!2\```"````%GP```"````8O````8`
M``!E\```!@```&SP```4````<_````P```"(\```#0```)7P```0````H_``
M`!L```"T\```!````-#P```)````U?```!````#?\```"0```/#P```)````
M^O````4````$\0``&@````KQ```(````)?$```8````N\0``&0```#7Q```.
M````3_$```<```!>\0``!P```&;Q```%````;O$```D```!T\0``"@```'[Q
M```3````B?$```(```"=\0``!@```*#Q```+````I_$```T```"S\0``"0``
M`,'Q```&````R_$```D```#2\0``!P```-SQ```%````Y/$``!0```#J\0``
M'0```/_Q``!"````'?(``"4```!@\@``)0```(;R```&````K/(```H```"S
M\@``!````+[R```)````P_(```@```#-\@``$0```-;R```)````Z/(```8`
M``#R\@``#0```/GR```&````!_,```0````.\P``.0```!/S```]````3?,`
M`#H```"+\P``'@```,;S```%````Y?,```X```#K\P``!````/KS```&````
M__,```<````&]```(0````[T```-````,/0```8````^]```!````$7T```1
M````2O0```8```!<]```"@```&/T```B````;O0```0```"1]```!0```);T
M```=````G/0```0```"Z]```#````+_T```)````S/0```P```#6]```#@``
M`./T```*````\O0``!````#]]```$P````[U```3````(O4```@````V]0``
M"0```#_U```%````2?4``#H```!/]0``,````(KU```U````N_4``"D```#Q
M]0``1P```!OV```X````8_8``"D```"<]@``/P```,;V```N````!O<``"T`
M```U]P``'P```&/W```/````@_<``!(```"3]P``"P```*;W```F````LO<`
M`"D```#9]P``)`````/X```F````*/@```@```!/^```"@```%CX```)````
M8_@```<```!M^```(````'7X```@````EO@``"8```"W^```!````-[X```@
M````X_@```H````$^0``&0````_Y```I````*?D``!8```!3^0``$@```&KY
M```'````??D```H```"%^0``#````)#Y```/````G?D``!````"M^0``0```
M`+[Y``!P````__D``&8```!P^@``#@```-?Z```)````YOH```H```#P^@``
M$@```/OZ```3````#OL```P````B^P``!@```"_[```<````-OL```\```!3
M^P``&P```&/[```2````?_L``!````"2^P``$0```*/[```<````M?L``",`
M``#2^P``:@```/;[```/````8?P```4```!Q_```$````'?\```)````B/P`
M``0```"2_```"P```)?\```@````H_P``!0```#$_```#````-G\```,````
MYOP```\```#S_```%0````/]```I````&?T``"H```!#_0``)@```&[]```G
M````E?T``"D```"]_0``*@```.?]```9````$OX``$(````L_@``$0```&_^
M```2````@?X``!,```"4_@``%````*C^```/````O?X``!8```#-_@``%P``
M`.3^```0````_/X``!$````-_P``-````!__```3````5/\``!(```!H_P``
M-0```'O_```4````L?\```<```#&_P``#````,[_```*````V_\``"````#F
M_P``$`````<``0`4````&``!`!0````M``$`$0```$(``0`7````5``!`!P`
M``!L``$`#0```(D``0`-````EP`!`!,```"E``$`%@```+D``0`4````T``!
M`!H```#E``$`$0`````!`0`,````$@$!`!`````?`0$`&@```#`!`0`>````
M2P$!`!H```!J`0$`$P```(4!`0`5````F0$!`!$```"O`0$`%P```,$!`0`4
M````V0$!`!<```#N`0$`%0````8"`0`)````'`(!`!`````F`@$`&0```#<"
M`0`$````40(!``<```!6`@$`"P```%X"`0`1````:@(!``8```!\`@$`!@``
M`(,"`0`&````B@(!``4```"1`@$`!P```)<"`0`'````GP(!``4```"G`@$`
M!@```*T"`0`&````M`(!``0```"[`@$`!````,`"`0`'````Q0(!``X```#-
M`@$`#````-P"`0`,````Z0(!``T```#V`@$`"@````0#`0`.````#P,!``4`
M```>`P$`*````"0#`0`.````30,!``P```!<`P$`#P```&D#`0`*````>0,!
M``@```"$`P$`"0```(T#`0`K````EP,!``0```##`P$`"````,@#`0`F````
MT0,!`!(```#X`P$`!@````L$`0`*````$@0!`$P````=!`$`!P```&H$`0`(
M````<@0!`"````![!`$`"0```)P$`0`-````I@0!``D```"T!`$`%````+X$
M`0`,````TP0!``T```#@!`$`#@```.X$`0`6````_00!`!$````4!0$`!@``
M`"8%`0`#````+04!``8````Q!0$`&0```#@%`0`'````4@4!``0```!:!0$`
M"P```%\%`0`+````:P4!``<```!W!0$`!0```'\%`0`'````A04!`!8```"-
M!0$`#0```*0%`0`-````L@4!``H```#`!0$`$````,L%`0`/````W`4!`!$`
M``#L!0$`%P```/X%`0`*````%@8!`!$````A!@$`"````#,&`0`$````/`8!
M``\```!!!@$`.@```%$&`0`%````C`8!``P```"2!@$`!````)\&`0`>````
MI`8!``X```##!@$`$````-(&`0`+````XP8!``P```#O!@$`"0```/P&`0`'
M````!@<!``H````.!P$`"0```!D'`0`.````(P<!`!`````R!P$`&P```$,'
M`0`8````7P<!`!H```!X!P$`"@```),'`0`)````G@<!``H```"H!P$`#```
M`+,'`0`/````P`<!``@```#0!P$`!@```-D'`0`<````X`<!``<```#]!P$`
M!0````4(`0`+````"P@!`$<````7"`$`#0```%\(`0`)````;0@!``0```!W
M"`$``P```'P(`0`3````@`@!`!,```"4"`$`$P```*@(`0`*````O`@!``(`
M``#'"`$`!````,H(`0`E````SP@!``,```#U"`$`!0```/D(`0`J````_P@!
M``H````J"0$`!0```#4)`0`$````.PD!``H```!`"0$`#0```$L)`0`&````
M60D!``@```!@"0$`"````&D)`0`$````<@D!``4```!W"0$`:````'T)`0`)
M````Y@D!``P```#P"0$`$````/T)`0`%````#@H!``8````4"@$`&P```!L*
M`0`O````-PH!`!````!G"@$`"@```'@*`0`(````@PH!``\```","@$`"@``
M`)P*`0`)````IPH!`!,```"Q"@$`&P```,4*`0`8````X0H!`!<```#Z"@$`
M&@```!(+`0`?````+0L!``X```!-"P$`%P```%P+`0`#````=`L!``<```!X
M"P$`"````(`+`0`'````B0L!``D```"1"P$`"@```)L+`0`+````I@L!``<`
M``"R"P$`40```+H+`0`0````#`P!``P````=#`$`#0```"H,`0`:````.`P!
M`$H```!3#`$`&0```)X,`0`&````N`P!`!H```"_#`$`)0```-H,`0`&````
M``T!``8````'#0$`'P````X-`0`&````+@T!``D````U#0$`&````#\-`0`7
M````6`T!`"@```!P#0$`!@```)D-`0`-````H`T!`"@```"N#0$`(@```-<-
M`0!7````^@T!`!,```!2#@$`(P```&8.`0`3````B@X!``(```">#@$`"P``
M`*$.`0`,````K0X!``@```"Z#@$`#0```,,.`0`*````T0X!`!8```#<#@$`
M!P```/,.`0`4````^PX!``8````0#P$`"````!</`0`.````(`\!``<````O
M#P$`"@```#</`0`+````0@\!`#(```!.#P$`%P```($/`0`'````F0\!``P`
M``"A#P$`#0```*X/`0`,````O`\!``0```#)#P$`"0```,X/`0`)````V`\!
M``H```#B#P$`!P```.T/`0`)````]0\!``D```#_#P$`"@````D0`0`'````
M%!`!``H````<$`$`%0```"<0`0`;````/1`!`$D```!9$`$`$@```*,0`0`*
M````MA`!`!8```#!$`$`#P```-@0`0`0````Z!`!``D```#Y$`$`$`````,1
M`0`'````%!$!`!(````<$0$`!````"\1`0`+````-!$!``<```!`$0$`!0``
M`$@1`0`%````3A$!`!H```!4$0$`"P```&\1`0`4````>Q$!`!$```"0$0$`
M&@```*(1`0`6````O1$!`!0```#4$0$`%P```.D1`0`8`````1(!`!P````:
M$@$`&0```#<2`0`'````41(!``4```!9$@$`#0```%\2`0`,````;1(!``L`
M``!Z$@$`$0```(82`0`(````F!(!`!<```"A$@$`"P```+D2`0`,````Q1(!
M`!\```#2$@$`&@```/(2`0`3````#1,!``0````A$P$`"@```"83`0`$````
M,1,!``T````V$P$`#````$03`0`%````41,!``D```!7$P$`"````&$3`0`%
M````:A,!``<```!P$P$`!0```'@3`0`$````?A,!``(```"#$P$`&````(83
M`0`7````GQ,!`#@```"W$P$`+````/`3`0`2````'10!`"D````P%`$`,@``
M`%H4`0`*````C10!`"P```"8%`$`+@```,44`0`S````]!0!`#,````H%0$`
M.````%P5`0`1````E14!``\```"G%0$`&````+<5`0`0````T!4!``\```#A
M%0$`$P```/$5`0`5````!18!`!0````;%@$`$@```#`6`0`4````0Q8!`!4`
M``!8%@$`+0```&X6`0`M````G!8!`#$```#*%@$`+@```/P6`0`O````*Q<!
M`"P```!;%P$`8@```(@7`0`3````ZQ<!``T```#_%P$`"`````T8`0`7````
M%A@!``@````N&`$`#````#<8`0`K````1!@!`"$```!P&`$`&````)(8`0`:
M````JQ@!``D```#&&`$`10```-`8`0!!````%AD!``0```!8&0$`$P```%T9
M`0`.````<1D!`!,```"`&0$`&````)09`0`&````K1D!``D```"T&0$`"@``
M`+X9`0`/````R1D!`!````#9&0$`!P```.H9`0`.````\AD!``4````!&@$`
M&P````<:`0`(````(QH!``8````L&@$`%````#,:`0`1````2!H!`!@```!:
M&@$`#@```',:`0`X````@AH!``(```"[&@$`!@```+X:`0`.````Q1H!`!``
M``#4&@$`!0```.4:`0`'````ZQH!``X```#S&@$`!@````(;`0`H````"1L!
M``P````R&P$`'````#\;`0`$````7!L!`)H```!A&P$`*0```/P;`0`7````
M)AP!`!\````^'`$`&0```%X<`0!<````>!P!`!0```#5'`$`/@```.H<`0`?
M````*1T!`!````!)'0$`!P```%H=`0`.````8AT!``P```!Q'0$`#````'X=
M`0`3````BQT!``H```"?'0$`'0```*H=`0`9````R!T!``4```#B'0$`$0``
M`.@=`0`-````^AT!`!$````('@$`)````!H>`0`2````/QX!`!4```!2'@$`
M$@```&@>`0`.````>QX!`!D```"*'@$`"````*0>`0`)````K1X!``T```"W
M'@$`"@```,4>`0`'````T!X!``\```#8'@$`!@```.@>`0`+````[QX!`!H`
M``#['@$`"@```!8?`0`'````(1\!``@````I'P$`!0```#(?`0`?````.!\!
M``8```!8'P$`$````%\?`0`(````<!\!``T```!Y'P$`"````(<?`0`>````
MD!\!`!(```"O'P$`+````,(?`0`:````[Q\!``D````*(`$`"@```!0@`0`5
M````'R`!``4````U(`$`%````#L@`0`$````4"`!`!````!5(`$`!@```&8@
M`0`'````;2`!`!X```!U(`$`*````)0@`0`*````O2`!`!P```#((`$`$0``
M`.4@`0`1````]R`!``L````)(0$`&@```!4A`0`4````,"$!``0```!%(0$`
M!````$HA`0`+````3R$!``4```!;(0$`!@```&$A`0`1````:"$!``@```!Z
M(0$`!@```(,A`0`;````BB$!`#0```"F(0$`-````-LA`0`@````$"(!`"D`
M```Q(@$`(````%LB`0!!````?"(!`!H```"^(@$`(0```-DB`0`H````^R(!
M`"D````D(P$`4````$XC`0`B````GR,!``8```#"(P$`"````,DC`0`%````
MTB,!``@```#8(P$`&0```.$C`0`9````^R,!`"H````5)`$`(P```$`D`0`9
M````9"0!`"X```!^)`$`-````*TD`0`(````XB0!`!<```#K)`$`"@````,E
M`0`'````#B4!`"$````6)0$`"````#@E`0`0````024!``X```!2)0$`%```
M`&$E`0`+````=B4!``<```"")0$`$P```(HE`0`(````GB4!``L```"G)0$`
M"@```+,E`0`4````OB4!``\```#3)0$`,@```.,E`0`+````%B8!``4````B
M)@$`!0```"@F`0`5````+B8!``P```!$)@$`!0```%$F`0`7````5R8!``\`
M``!O)@$`!````'\F`0`*````A"8!``D```"/)@$`"P```)DF`0`-````I28!
M``P```"S)@$`#@```,`F`0`%````SR8!``0```#5)@$`%````-HF`0`-````
M[R8!`"(```#])@$`,@```"`G`0`;````4R<!`$4```!O)P$`$@```+4G`0`7
M````R"<!``<```#@)P$`'@```.@G`0`4````!R@!``4````<*`$`%````"(H
M`0`&````-R@!``<````^*`$`#@```$8H`0`J````52@!``8```"`*`$`#```
M`(<H`0`3````E"@!``T```"H*`$`$0```+8H`0`5````R"@!``L```#>*`$`
M-@```.HH`0`*````(2D!`"(````L*0$`"P```$\I`0`/````6RD!`(4```!K
M*0$`,@```/$I`0`;````)"H!`"4```!`*@$`,````&8J`0`Q````ERH!`"T`
M``#)*@$`#@```/<J`0`%````!BL!``X````,*P$`$P```!LK`0`1````+RL!
M`!(```!!*P$`!P```%0K`0`1````7"L!`!,```!N*P$`!P```((K`0`4````
MBBL!`!@```"?*P$`!P```+@K`0`%````P"L!``P```#&*P$`#````-,K`0`2
M````X"L!``0```#S*P$`!P```/@K`0`*`````"P!``L````++`$`#````!<L
M`0`.````)"P!``X````S+`$`!0```$(L`0`%````2"P!`"X```!.+`$`)@``
M`'TL`0`C````I"P!``,```#(+`$`$@```,PL`0`&````WRP!`!X```#F+`$`
M&`````4M`0`9````'BT!`"4````X+0$`#0```%XM`0`)````;"T!`!\```!V
M+0$``P```)8M`0`8````FBT!``<```"S+0$`"@```+LM`0`"````QBT!``P`
M``#)+0$`%0```-8M`0`+````["T!`!D```#X+0$`(````!(N`0`2````,RX!
M``4```!&+@$`"@```$PN`0`5````5RX!`!(```!M+@$`#````(`N`0`$````
MC2X!``D```"2+@$`!P```)PN`0`,````I"X!`%(```"Q+@$`%P````0O`0`D
M````'"\!`"$```!!+P$`$@```&,O`0`'````=B\!``8```!^+P$`#@```(4O
M`0`-````E"\!`!$```"B+P$`&P```+0O`0`,````T"\!``P```#=+P$`#0``
M`.HO`0`5````^"\!`!(````.,`$`#P```"$P`0`4````,3`!``H```!&,`$`
M&P```%$P`0`@````;3`!`!X```".,`$`$````*TP`0`+````OC`!`"<```#*
M,`$`)0```/(P`0!I````&#$!`"8```"",0$`&@```*DQ`0`7````Q#$!`!D`
M``#<,0$`&@```/8Q`0`E````$3(!`"@````W,@$`)P```&`R`0`:````B#(!
M`!<```"C,@$`&P```+LR`0!$````US(!`#0````<,P$`)0```%$S`0`9````
M=S,!`!\```"1,P$`&P```+$S`0`3````S3,!``@```#A,P$`!P```.HS`0`(
M````\C,!``D```#[,P$`%0````4T`0`-````&S0!`",````I-`$`#0```$TT
M`0`3````6S0!``@```!O-`$``P```'@T`0!&````?#0!`#\```##-`$`-P``
M``,U`0!7````.S4!``4```"3-0$`'P```)DU`0`O````N34!``H```#I-0$`
M$````/0U`0`(````!38!``T````.-@$`+0```!PV`0`$````2C8!``<```!/
M-@$`"````%<V`0`-````8#8!``H```!N-@$`3P```'DV`0`E````R38!`!P`
M``#O-@$`"P````PW`0`?````&#<!`!T````X-P$`)0```%8W`0`@````?#<!
M`"0```"=-P$`(````,(W`0`+````XS<!``<```#O-P$`#0```/<W`0`,````
M!3@!`!<````2.`$`!@```"HX`0`Y````,3@!``P```!K.`$`!P```'@X`0`)
M````@#@!`!,```"*.`$`"0```)XX`0`$````J#@!`!````"M.`$`"````+XX
M`0`(````QS@!``0```#0.`$`"P```-4X`0`,````X3@!`!(```#N.`$`$0``
M``$Y`0`,````$SD!`!H````@.0$`#P```#LY`0`'````2SD!``T```!3.0$`
M#@```&$Y`0`4````<#D!``X```"%.0$`!P```)0Y`0`,````G#D!`"P```"I
M.0$`$P```-8Y`0`<````ZCD!`"@````'.@$`!@```#`Z`0`'````-SH!`!,`
M```_.@$`!0```%,Z`0`$````63H!`!<```!>.@$`.0```'8Z`0`*````L#H!
M``P```"[.@$`"0```,@Z`0`&````TCH!``D```#9.@$`"````.,Z`0`)````
M[#H!``H```#V.@$`$0````$[`0`&````$SL!``X````:.P$`#@```"D[`0`-
M````.#L!``L```!&.P$`'0```%([`0`+````<#L!``(```!\.P$`'````'\[
M`0`'````G#L!``8```"D.P$`9````*L[`0`)````$#P!``<````:/`$`)@``
M`"(\`0`I````23P!`!L```!S/`$`.````(\\`0`K````R#P!`!H```#T/`$`
M(P````\]`0`J````,ST!`"T```!>/0$`.P```(P]`0`H````R#T!`#0```#Q
M/0$`&0```"8^`0`5````0#X!``4```!6/@$`!P```%P^`0`(````9#X!``<`
M``!M/@$`!0```'4^`0`'````>SX!``X```"#/@$`"0```)(^`0`&````G#X!
M``@```"C/@$`"P```*P^`0`'````N#X!``@```#`/@$`!P```,D^`0`6````
MT3X!``D```#H/@$`!@```/(^`0`+````^3X!`!`````%/P$`!@```!8_`0`<
M````'3\!`!0````Z/P$`!P```$\_`0`1````5S\!``@```!I/P$`#@```'(_
M`0`#````@3\!``@```"%/P$`%````(X_`0`%````HS\!`!````"I/P$`$```
M`+H_`0`&````RS\!`!D```#2/P$`"@```.P_`0`<````]S\!``<````40`$`
M!0```!Q``0`0````(D`!`!0````S0`$`"P```$A``0`-````5$`!`"@```!B
M0`$`&````(M``0`7````I$`!``0```"\0`$`"0```,%``0`*````RT`!``<`
M``#60`$``@```-Y``0`(````X4`!`",```#J0`$`.`````Y!`0`F````1T$!
M`#$```!N00$`)P```*!!`0!$````R$$!`"4````-0@$`+P```#-"`0`O````
M8T(!`"\```"30@$`*````,-"`0!D````[$(!`!0```!10P$`50```&9#`0`X
M````O$,!`"D```#U0P$`2@```!]$`0!;````:D0!`"@```#&1`$`.````.]$
M`0`L````*$4!`"@```!510$`+````'Y%`0`F````JT4!`!L```#210$`/@``
M`.Y%`0"I`0``+48!`",```#71P$`,````/M'`0`7````+$@!`$@```!$2`$`
MA0```(U(`0`P````$TD!`"4```!$20$`00```&I)`0!;````K$D!`$D````(
M2@$`,0```%)*`0`=````A$H!`!@```"B2@$`*P```+M*`0`A````YTH!`!\`
M```)2P$`*P```"E+`0`A````54L!`"<```!W2P$`.@```)]+`0`=````VDL!
M`!$```#X2P$`,P````I,`0`E````/DP!`"<```!D3`$`(````(Q,`0`F````
MK4P!`!\```#43`$`,````/1,`0#,````)4T!`&D```#R30$`,0```%Q.`0!!
M````CDX!`#,```#03@$`)0````1/`0`]````*D\!`&4```!H3P$`30```,Y/
M`0!>````'%`!`"<```![4`$`,0```*-0`0`^````U5`!`"P````440$`)@``
M`$%1`0`O````:%$!`"X```"840$`*0```,=1`0`P````\5$!`%0````B4@$`
M6@```'=2`0`Q````TE(!`$@````$4P$`2@```$U3`0`Q````F%,!`"H```#*
M4P$`(@```/53`0`O````&%0!`"D```!(5`$`,@```')4`0`O````I50!`"P`
M``#55`$`+0````)5`0!Q````,%4!`&8```"B50$`;P````E6`0"S````>58!
M`!<````M5P$`)0```$57`0`R````:U<!`"D```">5P$`/@```,A7`0`B````
M!U@!`%(````J6`$`(@```'U8`0`E````H%@!``L```#&6`$`L0```-)8`0!%
M````A%D!`"$```#*60$`-@```.Q9`0`P````(UH!`"4```!46@$`'````'I:
M`0!(````EUH!`#$```#@6@$`!P```!);`0`'````&EL!``0````B6P$`#0``
M`"=;`0`+````-5L!``X```!!6P$`"P```%!;`0`%````7%L!`!````!B6P$`
M`@```'-;`0!9````=EL!``4```#06P$`$@```-9;`0`$````Z5L!``<```#N
M6P$`"````/9;`0`%````_UL!``,````%7`$`$`````E<`0`,````&EP!`!,`
M```G7`$`#0```#M<`0`"````25P!``<```!,7`$`!@```%1<`0`,````6UP!
M`!@```!H7`$`!@```(%<`0`2````B%P!``P```";7`$``P```*A<`0`J````
MK%P!``0```#77`$`!@```-Q<`0`'````XUP!`!\```#K7`$`-0````M=`0`N
M````05T!`"\```!P70$`%P```*!=`0`B````N%T!`"4```#;70$`(`````%>
M`0`;````(EX!`!@````^7@$`)````%=>`0`?````?%X!`!H```"<7@$`(0``
M`+=>`0`@````V5X!`#````#Z7@$`&@```"M?`0`R````1E\!`!H```!Y7P$`
M+P```)1?`0`K````Q%\!`!\```#P7P$`(P```!!@`0`?````-&`!`!H```!4
M8`$`(0```&]@`0`E````D6`!`"8```"W8`$`)0```-Y@`0`D````!&$!`!@`
M```I80$`'0```$)A`0`D````8&$!`!@```"%80$`(@```)YA`0`L````P6$!
M`"\```#N80$`%0```!YB`0`E````-&(!`#P```!:8@$`'P```)=B`0`C````
MMV(!`!\```#;8@$`(````/MB`0`:````'&,!`!@````W8P$`)@```%!C`0`>
M````=V,!`"D```"68P$`'@```,!C`0`Q````WV,!``D````19`$`#````!MD
M`0`7````*&0!`"\```!`9`$`)````'!D`0`'````E60!`!0```"=9`$`#@``
M`+)D`0`-````P60!``4```#/9`$`!P```-5D`0`B````W60!`"4`````90$`
M&@```"9E`0`=````064!`!H```!?90$`!P```'IE`0#'````@F4!``L```!*
M9@$`'````%9F`0`5````<V8!``8```")9@$`"0```)!F`0`+````FF8!``T`
M``"F9@$`%P```+1F`0`&````S&8!`#,```#39@$`$P````=G`0`3````&V<!
M``<````O9P$`#P```#=G`0`'````1V<!`#(```!/9P$`!````()G`0`A````
MAV<!`!,```"I9P$`#````+UG`0`1````RF<!`#(```#<9P$`%@````]H`0`(
M````)F@!`!T````O:`$`"0```$UH`0`*````5V@!`!0```!B:`$`"@```'=H
M`0`=````@F@!``@```"@:`$`'P```*EH`0`(````R6@!`!H```#2:`$`)P``
M`.UH`0`&````%6D!`!4````<:0$`!P```#)I`0`(````.FD!``D```!#:0$`
M/P```$UI`0`2````C6D!``<```"@:0$`#P```*AI`0`.````N&D!`!````#'
M:0$`"0```-AI`0`)````XFD!``@```#L:0$`"0```/5I`0`'````_VD!``P`
M```':@$`&0```!1J`0`*````+FH!`!L````Y:@$`%P```%5J`0`4````;6H!
M``H```"":@$`#````(UJ`0`7````FFH!``0```"R:@$`*@```+=J`0`,````
MXFH!`!$```#O:@$`!P````%K`0`"````"6L!`!`````,:P$`&````!UK`0`+
M````-FL!``,```!":P$`"````$9K`0`+````3VL!``8```!;:P$`!P```&)K
M`0`-````:FL!``L```!X:P$`#@```(1K`0`O````DVL!`"````##:P$`'```
M`.1K`0`5`````6P!``P````7;`$`,0```"1L`0`%````5FP!`!(```!<;`$`
M/P```&]L`0`2````KVP!``H```#";`$`!@```,UL`0`$````U&P!``0```#9
M;`$`"@```-YL`0`3````Z6P!``4```#];`$`!@````-M`0`&````"FT!``@`
M```1;0$`!````!IM`0`,````'VT!``D````L;0$`#````#9M`0`*````0VT!
M`!````!.;0$`$P```%]M`0`3````<VT!`#D```"';0$`+@```,%M`0`I````
M\&T!``4````:;@$`&````"!N`0`9````.6X!`!\```!3;@$`'0```'-N`0`1
M````D6X!``(```"C;@$`!````*9N`0`*````JVX!``8```"V;@$`!0```+UN
M`0`#````PVX!``P```#';@$`10```-1N`0`R````&F\!`#P```!-;P$`&@``
M`(IO`0`T````I6\!`"@```#:;P$`4P````-P`0`P````5W`!`"\```"(<`$`
M,@```+AP`0`9````ZW`!`'(````%<0$`(````'AQ`0`U````F7$!`"$```#/
M<0$`10```/%Q`0`P````-W(!`"8```!H<@$`'@```(]R`0`H````KG(!`"L`
M``#7<@$`*0````-S`0`I````+7,!`"8```!7<P$`)0```'YS`0`H````I',!
M`"@```#-<P$`(@```/9S`0`K````&70!`"X```!%=`$`,````'1T`0`2````
MI70!`!,```"X=`$`$````,QT`0!Y````W70!``D```!7=0$`H0```&%U`0!S
M`````W8!`'P```!W=@$`*P```/1V`0!4````('<!`!<```!U=P$`+````(UW
M`0`G````NG<!`!8```#B=P$`#P```/EW`0`7````"7@!`!\````A>`$`0```
M`$%X`0`?````@G@!`!P```"B>`$`40```+]X`0`:````$7D!`!0````L>0$`
M"@```$%Y`0`%````3'D!``8```!2>0$`"````%EY`0`%````8GD!`!(```!H
M>0$`$````'MY`0`3````C'D!`!T```"@>0$`#P```+YY`0`*````SGD!``\`
M``#9>0$`!P```.EY`0`$````\7D!``D```#V>0$`"0````!Z`0`'````"GH!
M``L````2>@$`!P```!YZ`0`%````)GH!`!0````L>@$`#@```$%Z`0`&````
M4'H!``<```!7>@$`"````%]Z`0`/````:'H!`!$```!X>@$`#````(IZ`0`(
M````EWH!``P```"@>@$`#P```*UZ`0`6````O7H!``<```#4>@$`!@```-QZ
M`0`4````XWH!``8```#X>@$`#````/]Z`0`1````#'L!``@````>>P$`!```
M`"=[`0`9````+'L!`!$```!&>P$`"@```%A[`0`8````8WL!`!,```!\>P$`
M"P```)![`0`,````G'L!``P```"I>P$`#````+9[`0`<````PWL!`!$```#@
M>P$`#P```/)[`0`'`````GP!``0````*?`$`&0````]\`0`'````*7P!``(`
M```Q?`$``@```#1\`0`1````-WP!``D```!)?`$`!@```%-\`0`2````6GP!
M`!<```!M?`$`!@```(5\`0`G````C'P!``(```"T?`$`!````+=\`0`-````
MO'P!``0```#*?`$`#P```,]\`0`3````WWP!``<```#S?`$`!P```/M\`0`1
M`````WT!``8````5?0$`&````!Q]`0`&````-7T!`!,````\?0$`$````%!]
M`0`2````87T!``(```!T?0$`!@```'=]`0`,````?GT!``D```"+?0$`$0``
M`)5]`0`1````IWT!`!L```"Y?0$`(@```-5]`0`'````^'T!``<`````?@$`
M"P````A^`0`%````%'X!``(````:?@$`"P```!U^`0!)`0``*7X!`!````!S
M?P$`%P```(1_`0`+````G'\!``8```"H?P$`"0```*]_`0`(````N7\!`!0`
M``#"?P$`%0```-=_`0`*````[7\!`"4```#X?P$`%````!Z``0`9````,X`!
M`"T```!-@`$`)0```'N``0`E````H8`!`",```#'@`$`+0```.N``0`?````
M&8$!`"L````Y@0$`(P```&6!`0`D````B8$!`"T```"N@0$`"@```-R!`0`J
M````YX$!`!,````2@@$`#0```":"`0`+````-((!``4```!`@@$`+0```$:"
M`0`-````=((!`!T```""@@$`%0```*""`0`5````MH(!``\```#,@@$`$0``
M`-R"`0`A````[H(!`'0````0@P$`#@```(6#`0`(````E(,!`!$```"=@P$`
M#0```*^#`0`*````O8,!`!<```#(@P$`%P```."#`0`:````^(,!``8````3
MA`$`OP```!J$`0`+````VH0!`!(```#FA`$`'0```/F$`0`0````%X4!`!(`
M```HA0$`$@```#N%`0`(````3H4!``\```!7A0$`(@```&>%`0`P````BH4!
M`!D```"[A0$`-@```-6%`0`]````#(8!`%````!*A@$`3P```)N&`0!8````
MZX8!`%8```!$AP$`.````)N'`0`4````U(<!`!<```#IAP$`$0````&(`0`5
M````$X@!`!T````IB`$`"````$>(`0`&````4(@!``\```!7B`$`!````&>(
M`0`7````;(@!`!````"$B`$`#P```)6(`0`R````I8@!`#````#8B`$`&@``
M``F)`0`1````)(D!``X````VB0$`$0```$6)`0`)````5XD!``8```!AB0$`
M&0```&B)`0`7````@HD!``<```":B0$`#@```**)`0`1````L8D!`!X```##
MB0$`'````.*)`0`3````_XD!``X````3B@$`'@```"**`0`-````08H!``P`
M``!/B@$`#0```%R*`0`*````:HH!`"8```!UB@$`"0```)R*`0`3````IHH!
M`!@```"ZB@$`$@```-.*`0!4````YHH!`#<````[BP$`)0```'.+`0`D````
MF8L!``8```"^BP$`!P```,6+`0`0````S8L!``@```#>BP$`$````.>+`0`=
M````^(L!`!4````6C`$`)0```"R,`0`V````4HP!``T```")C`$`!P```)>,
M`0`6````GXP!``H```"VC`$`"````,&,`0`(````RHP!``4```#3C`$`"```
M`-F,`0`+````XHP!``8```#NC`$`(P```/6,`0`.````&8T!``P````HC0$`
M$P```#6-`0`6````28T!`"L```!@C0$`"P```(R-`0`+````F(T!`"0```"D
MC0$`%P```,F-`0`D````X8T!`!T````&C@$`%````"2.`0`2````.8X!``X`
M``!,C@$`'````%N.`0`6````>(X!``<```"/C@$`!@```)>.`0`(````GHX!
M``X```"GC@$`!P```+:.`0`*````OHX!`!$```#)C@$`"0```-N.`0`0````
MY8X!`!@```#VC@$`*@````^/`0`(````.H\!`!$```!#CP$`!0```%6/`0`/
M````6X\!``P```!KCP$`&````'B/`0`E````D8\!`#$```"WCP$`+P```.F/
M`0`)````&9`!``@````CD`$`!@```"R0`0`%````,Y`!``D````YD`$`$```
M`$.0`0`,````5)`!`!4```!AD`$`-````'>0`0`H````K)`!`"<```#5D`$`
M)````/V0`0`Q````(I$!``@```!4D0$`!@```%V1`0`)````9)$!``<```!N
MD0$`-P```':1`0`O````KI$!`#8```#>D0$`7@```!62`0`U````=)(!`#4`
M``"JD@$`2@```."2`0!+````*Y,!`#4```!WDP$`0@```*V3`0`Q````\),!
M`#0````BE`$`3````%>4`0`U````I)0!`#L```#:E`$`+````!:5`0`6````
M0Y4!`!H```!:E0$`)@```'65`0`K````G)4!`"L```#(E0$`$0```/25`0`+
M````!I8!``P````2E@$`!P```!^6`0`-````)Y8!`!<````UE@$`)````$V6
M`0`&````<I8!``<```!YE@$`"0```(&6`0`(````BY8!`"@```"4E@$`#P``
M`+V6`0`1````S98!``H```#?E@$`"````.J6`0`&````\Y8!`!<```#ZE@$`
M!0```!*7`0`'````&)<!``4````@EP$`(@```":7`0`*````29<!`"<```!4
MEP$`$````'R7`0`)````C9<!``4```"7EP$`!P```)V7`0`'````I9<!``4`
M``"MEP$`#0```+.7`0`&````P9<!`!,```#(EP$``P```-R7`0`(````X)<!
M``8```#IEP$`#0```/"7`0`(````_I<!`"`````'F`$`"````"B8`0`1````
M,9@!``D```!#F`$`$@```$V8`0`,````8)@!``<```!MF`$`$@```'68`0`#
M````B)@!``,```",F`$`%````)"8`0`>````I9@!`!0```#$F`$`,@```-F8
M`0`(````#)D!``D````5F0$`"````!^9`0`'````*)D!`$L````PF0$`)```
M`'R9`0`E````H9D!`"T```#'F0$`*````/69`0`A````'IH!``8```!`F@$`
M!@```$>:`0`8````3IH!`"$```!GF@$`)````(F:`0`N````KIH!`"4```#=
MF@$`+0````.;`0!@````,9L!`"X```"2FP$`$@```,&;`0`'````U)L!`!,`
M``#<FP$`$0```/";`0`/`````IP!`!`````2G`$`$````".<`0`0````-)P!
M`!````!%G`$`#P```%:<`0`)````9IP!`!<```!PG`$`(0```(B<`0`4````
MJIP!`!@```"_G`$``P```-B<`0`&````W)P!`!$```#CG`$`50```/6<`0!<
M````2YT!``0```"HG0$`%@```*V=`0`5````Q)T!``4```#:G0$`!````."=
M`0`2````Y9T!``\```#XG0$`#P````B>`0`<````&)X!`!(````UG@$`$P``
M`$B>`0`D````7)X!`#````"!G@$`.0```+*>`0`I````[)X!`#0````6GP$`
M#P```$N?`0`C````6Y\!``4```!_GP$`&@```(6?`0`-````H)\!`!D```"N
MGP$`%0```,B?`0`;````WI\!`!$```#ZGP$`&0````R@`0`3````)J`!``T`
M```ZH`$`!@```$B@`0`,````3Z`!``<```!<H`$`%P```&2@`0`2````?*`!
M``X```"/H`$`"````)Z@`0`%````IZ`!``L```"MH`$`"P```+F@`0`'````
MQ:`!`!(```#-H`$`#P```."@`0`C````\*`!``8````4H0$`&````!NA`0`L
M````-*$!``8```!AH0$`%0```&BA`0`(````?J$!``H```"'H0$`!@```)*A
M`0`*````F:$!`!(```"DH0$`"````+>A`0`$````P*$!``0```#%H0$`%P``
M`,JA`0!,````XJ$!`"0````OH@$`#P```%2B`0`.````9*(!``4```!SH@$`
M'````'FB`0`1````EJ(!`!(```"HH@$`&P```+NB`0`C````UZ(!`"X```#[
MH@$`/0```"JC`0`@````:*,!`!$```")HP$`"````)NC`0`6````I*,!`#``
M``"[HP$`&@```.RC`0`*````!Z0!``H````2I`$`#P```!VD`0`&````+:0!
M``D````TI`$`%P```#ZD`0`/````5J0!``D```!FI`$`$@```'"D`0`M````
M@Z0!`"L```"QI`$`+P```-VD`0`M````#:4!`"$````[I0$`)@```%VE`0`E
M````A*4!`"D```"JI0$`*0```-2E`0`U````_J4!`"L````TI@$`)````&"F
M`0`F````A:8!`"$```"LI@$`*@```,ZF`0`Z````^:8!`"X````TIP$`)```
M`&.G`0`P````B*<!`#D```"YIP$`)0```/.G`0`A````&:@!`#0````[J`$`
M)0```'"H`0`9````EJ@!`"\```"PJ`$`(P```."H`0`F````!*D!`!H````K
MJ0$`L0```$:I`0`2````^*D!`"`````+J@$`*0```"RJ`0`I````5JH!`#$`
M``"`J@$`(@```+*J`0`A````U:H!`"4```#WJ@$`*0```!VK`0`L````1ZL!
M`#H```!TJP$`+````*^K`0"3````W*L!`"4```!PK`$`&P```):L`0`F````
MLJP!`"\```#9K`$`+P````FM`0!&````.:T!`$0```"`K0$`#0```,6M`0`'
M````TZT!``4```#;K0$`"````.&M`0`0````ZJT!``X```#[K0$`(0````JN
M`0`-````+*X!`!4````ZK@$`"0```%"N`0`,````6JX!`!4```!GK@$`"@``
M`'VN`0`$````B*X!``\```"-K@$`$````)VN`0`,````KJX!``\```"[K@$`
M%0```,NN`0`0````X:X!`!0```#RK@$`#0````>O`0!"````%:\!``H```!8
MKP$`$````&.O`0`&````=*\!``\```![KP$``@```(NO`0!+````CJ\!``4`
M``#:KP$`(P```."O`0`7````!+`!``4````<L`$`#@```"*P`0`,````,;`!
M``,````^L`$`$0```$*P`0`(````5+`!`!````!=L`$`$0```&ZP`0`-````
M@+`!`!,```".L`$`&P```**P`0`C````OK`!`!T```#BL`$`"0````"Q`0`'
M````"K$!``\````2L0$`#0```"*Q`0`7````,+$!``\```!(L0$`#@```%BQ
M`0`-````9[$!`!H```!UL0$`(@```)"Q`0`-````L[$!``X```#!L0$`)P``
M`-"Q`0`<````^+$!`!8````5L@$`*P```"RR`0`.````6+(!`!@```!GL@$`
M%P```("R`0`7````F+(!`#$```"PL@$`)@```.*R`0`3````";,!``T````=
MLP$`!@```"NS`0`)````,K,!``@````\LP$`#P```$6S`0`%````5;,!`"L`
M``!;LP$`+````(>S`0`%````M+,!``D```"ZLP$`'@```,2S`0`+````X[,!
M`!(```#OLP$`$@````*T`0`'````%;0!``H````=M`$`)@```"BT`0`5````
M3[0!`!L```!EM`$`&````(&T`0`1````FK0!`!4```"LM`$`"0```,*T`0`)
M````S+0!`",```#6M`$`*````/JT`0`]````([4!``@```!AM0$`%@```&JU
M`0`>````@;4!``@```"@M0$`"P```*FU`0`R````M;4!``X```#HM0$`$```
M`/>U`0`%````"+8!``8````.M@$``P```!6V`0`'````&;8!``<````AM@$`
M#````"FV`0`0````-K8!``P```!'M@$`#P```%2V`0`-````9+8!``T```!R
MM@$`%````("V`0`6````E;8!`!<```"LM@$`%@```,2V`0`4````V[8!``L`
M``#PM@$`!0```/RV`0`(`````K<!``H````+MP$``@```!:W`0`%````&;<!
M`!`````?MP$`(P```#"W`0`3````5+<!`!(```!HMP$`"0```'NW`0`/````
MA;<!`!$```"5MP$`&@```*>W`0`M````PK<!`"L```#PMP$`"P```!RX`0`.
M````*+@!`'8````WN`$`$P```*ZX`0`?````PK@!`%,```#BN`$`(0```#:Y
M`0`0````6+D!``<```!IN0$`!0```'&Y`0`T````=[D!`$8```"LN0$`'0``
M`/.Y`0`J````$;H!`#P````\N@$`,0```'FZ`0`O````J[H!`!X```#;N@$`
M-0```/JZ`0!'````,+L!`"@```!XNP$`(````*&[`0`:````PKL!`!H```#=
MNP$`"````/B[`0`'`````;P!``<````)O`$`!@```!&\`0`0````&+P!``X`
M```IO`$`$0```#B\`0`/````2KP!`!4```!:O`$`#P```'"\`0`,````@+P!
M``H```"-O`$`!P```)B\`0`(````H+P!`!0```"IO`$`#@```+Z\`0`W````
MS;P!``\````%O0$`"````!6]`0`&````'KT!`!(````EO0$`(````#B]`0`D
M````6;T!``L```!^O0$`&@```(J]`0`@````I;T!`"D```#&O0$`*````/"]
M`0`7````&;X!`"@````QO@$`2P```%J^`0`J````IKX!`"D```#1O@$`'P``
M`/N^`0`@````&[\!`"H````\OP$`)````&>_`0`?````C+\!`!@```"LOP$`
M'P```,6_`0`K````Y;\!``4````1P`$`'0```!?``0`/````-<`!``X```!%
MP`$``P```%3``0`$````6,`!``<```!=P`$`#0```&7``0`/````<\`!``L`
M``"#P`$`%0```(_``0`+````I<`!``4```"QP`$`!0```+?``0`7````O<`!
M`!D```#5P`$`#P```._``0`+````_\`!``P````+P0$`#P```!C!`0`F````
M*,$!``8```!/P0$`!@```%;!`0`%````7<$!``<```!CP0$`!@```&O!`0`-
M````<L$!``L```"`P0$`"@```(S!`0`+````E\$!``8```"CP0$`#@```*K!
M`0`$````N<$!`!<```"^P0$`"P```-;!`0`'````XL$!`"H```#JP0$`#P``
M`!7"`0"#````)<(!`!(```"IP@$`"0```+S"`0`'````QL(!``L```#.P@$`
M!P```-K"`0`)````XL(!``0```#LP@$`#0```/'"`0`#````_\(!``4````#
MPP$`"@````G#`0`3````%,,!`"0````HPP$`$@```$W#`0`4````8,,!`!H`
M``!UPP$``0```)##`0`)````DL,!``L```"<PP$`!````*C#`0`*````K<,!
M``4```"XPP$`)@```+[#`0`(````Y<,!``8```#NPP$`)P```/7#`0`.````
M'<0!``<````LQ`$`!P```#3$`0`%````/,0!``D```!"Q`$`"P```$S$`0`0
M````6,0!``<```!IQ`$`!@```''$`0`+````>,0!`!````"$Q`$`#0```)7$
M`0`&````H\0!``<```"JQ`$`!P```++$`0`'````NL0!`!0```#"Q`$`'0``
M`-?$`0`_````]<0!`"P````UQ0$`,0```&+%`0`'````E,4!``H```"<Q0$`
M!````*?%`0`)````K,4!``@```"VQ0$`'0```+_%`0`)````W<4!``8```#G
MQ0$`#0```.[%`0`&````_,4!``0````#Q@$`,@````C&`0`T````.\8!`#0`
M``!PQ@$`(P```*7&`0`%````R<8!`!T```#/Q@$`!````.W&`0`(````\L8!
M``@```#[Q@$`)`````3'`0`+````*<<!``4````UQP$`"````#O'`0`?````
M1,<!``@```!DQP$`"````&W'`0`6````=L<!``8```"-QP$`!@```)3'`0`'
M````F\<!``4```"CQP$`#0```*G'`0`-````M\<!``\```#%QP$`$````-7'
M`0`-````YL<!`!@```#TQP$`%@````W(`0`-````),@!``@````RR`$`"0``
M`#O(`0`%````1<@!`#L```!+R`$`.````(?(`0`\````P,@!`"<```#]R`$`
M.````"7)`0!`````7LD!`#````"?R0$`.@```-#)`0`U````"\H!`#X```!!
MR@$`*0```(#*`0`2````JLH!`!8```"]R@$`#0```-3*`0`J````XLH!`!P`
M```-RP$`'0```"K+`0`<````2,L!``<```!ERP$`"0```&W+`0`)````=\L!
M``@```"!RP$`*````(K+`0`G````L\L!`"4```#;RP$`!`````',`0`4````
M!LP!``D````;S`$`&@```"7,`0`O````0,P!`"8```!PS`$`$0```)?,`0`&
M````J<P!``D```"PS`$`#````+K,`0`,````Q\P!``\```#4S`$`-@```.3,
M`0""````&\T!`'8```">S0$`#P```!7.`0`+````)<X!``P````QS@$`$0``
M`#[.`0`2````4,X!`!````!CS@$`!P```'3.`0`;````?,X!``\```"8S@$`
M'@```*C.`0`4````Q\X!`!(```#<S@$`#P```._.`0`?````_\X!`"H````?
MSP$`A@```$K/`0`1````T<\!``4```#CSP$`%P```.G/`0`)`````=`!``0`
M```+T`$`"@```!#0`0`>````&]`!`!$````ZT`$`#@```$S0`0`.````6]`!
M``P```!JT`$`$P```'?0`0`>````B]`!`"````"JT`$`'@```,O0`0`@````
MZM`!`!\````+T0$`(0```"O1`0`;````3=$!`#@```!IT0$`#P```*+1`0`1
M````LM$!`!````#$T0$`$@```-71`0`-````Z-$!`!(```#VT0$`%`````G2
M`0`0````'M(!`!(````OT@$`,@```$+2`0`6````==(!`!0```",T@$`/0``
M`*'2`0`4````W](!``H```#TT@$`$P```/_2`0`+````$],!`$$````?TP$`
M&P```&'3`0`0````?=,!`!,```".TP$`$@```*+3`0`=````M=,!`!@```#3
MTP$`&0```.S3`0`0````!M0!`!8````7U`$`&0```"[4`0`7````2-0!`!X`
M``!@U`$`&@```'_4`0`-````FM0!`!$```"HU`$`*````+K4`0`C````X]0!
M`!H````'U0$`%0```"+5`0`6````.-4!`!$```!/U0$`%P```&'5`0`9````
M>=4!`!D```"3U0$`%P```*W5`0`(````Q=4!`!````#.U0$`!````-_5`0`$
M````Y-4!``4```#IU0$`"P```._5`0`/````^]4!``8````+U@$`"0```!+6
M`0`'````'-8!``D````DU@$`!P```"[6`0`&````-M8!``@````]U@$`!@``
M`$;6`0`&````3=8!``,```!4U@$``P```%C6`0`(````7-8!`!(```!EU@$`
M$0```'C6`0`.````BM8!``\```"9U@$`"@```*G6`0`2````M-8!``0```#'
MU@$`*````,S6`0`2````]=8!`!`````(UP$`&````!G7`0`+````,M<!``D`
M```^UP$`#@```$C7`0`M````5]<!``0```"%UP$`"````(K7`0`B````D]<!
M`!(```"VUP$`!@```,G7`0`)````T-<!`$D```#:UP$`!P```"38`0`%````
M+-@!``0````RV`$`$0```#?8`0`5````2=@!``H```!?V`$`%````&K8`0`.
M````?]@!`!8```".V`$`&````*78`0`=````OM@!`!L```#<V`$`"````/C8
M`0`%`````=D!``8````'V0$`(0````[9`0`'````,-D!``4````XV0$`#@``
M`#[9`0`-````3=D!``<```!;V0$`!@```&/9`0`'````:MD!``4```!RV0$`
M#P```'C9`0`/````B-D!``H```"8V0$`#P```*/9`0`1````L]D!`!8```#%
MV0$`%````-S9`0`.````\=D!`!8`````V@$`"````!?:`0`%````(-H!`!$`
M```FV@$`-@```#C:`0`%````;]H!``P```!UV@$`!@```(+:`0`C````B=H!
M`!8```"MV@$`%````,3:`0`7````V=H!``P```#QV@$`"0```/[:`0`'````
M"-L!``H````0VP$`"0```!O;`0`.````)=L!`!`````TVP$`'0```$7;`0`C
M````8]L!`"X```"'VP$`"@```+;;`0`%````P=L!``X```#'VP$`#0```-;;
M`0`1````Y-L!``@```#VVP$`"P```/_;`0`F````"]P!``@````RW`$`"P``
M`#O<`0`4````1]P!`%$```!<W`$`%````*[<`0`)````P]P!``4```#-W`$`
M!0```-/<`0`3````V=P!`!4```#MW`$`$P````/=`0`+````%]T!``(````C
MW0$`"@```";=`0`J````,=T!``,```!<W0$`!0```&#=`0`*````9MT!``H`
M``!QW0$`!0```'S=`0`%````@MT!`!X```"(W0$`$@```*?=`0`&````NMT!
M``@```#!W0$`"````,K=`0`$````T]T!``4```#8W0$`80```-[=`0`*````
M0-X!``T```!+W@$`$@```%G>`0`%````;-X!``4```!RW@$`)P```'C>`0`T
M````H-X!`!,```#5W@$`"````.G>`0`*````\MX!``P```#]W@$`"@````K?
M`0`)````%=\!`!H````?WP$`+````#K?`0`J````9]\!`"D```"2WP$`&0``
M`+S?`0`>````UM\!``\```#UWP$`%0````7@`0`#````&^`!``<````?X`$`
M"````"?@`0`(````,.`!``0````YX`$`$````#[@`0`,````3^`!``8```!<
MX`$`20```&/@`0`9````K>`!``H```#'X`$`#0```-+@`0`<````X.`!`$T`
M``#]X`$`(````$OA`0`&````;.$!`!T```!SX0$`*````)'A`0`(````NN$!
M``8```##X0$`'0```,KA`0`%````Z.$!``@```#NX0$`*@```/?A`0`I````
M(N(!`"X```!,X@$`$0```'OB`0`%````C>(!`"0```"3X@$`'@```+CB`0!=
M````U^(!`!`````UXP$`(0```$;C`0`1````:.,!``,```!ZXP$`#````'[C
M`0`/````B^,!``8```";XP$`%0```*+C`0`+````N.,!`!<```#$XP$`!P``
M`-SC`0`)````Y.,!``8```#NXP$`"0```/7C`0`,````_^,!``<````,Y`$`
M"@```!3D`0`,````'^0!`#D````LY`$`&P```&;D`0`&````@N0!``X```")
MY`$`$````)CD`0`0````J>0!``@```"ZY`$`#0```,/D`0`.````T>0!``\`
M``#@Y`$`#0```/#D`0`-````_N0!``X````,Y0$`#P```!OE`0`-````*^4!
M``@````YY0$`$@```$+E`0`>````5>4!`#T```!TY0$`$0```++E`0`*````
MQ.4!`!<```#/Y0$`"P```.?E`0`-````\^4!``H````!Y@$`%`````SF`0`'
M````(>8!`!`````IY@$`!````#KF`0`+````/^8!``<```!+Y@$`!0```%/F
M`0`%````6>8!`!@```!?Y@$`"0```'CF`0`0````@N8!`!4```"3Y@$`+0``
M`*GF`0`<````U^8!`#$```#TY@$`*@```";G`0`9````4><!`!T```!KYP$`
M&````(GG`0`$````HN<!``4```"GYP$`#@```*WG`0`.````O.<!``P```#+
MYP$`$@```-CG`0`#````Z^<!`",```#OYP$`"P```!/H`0`*````'^@!`"``
M```JZ`$`&@```$OH`0`2````9N@!``0```!YZ`$`$````'[H`0`%````C^@!
M`!(```"5Z`$`$0```*CH`0`,````NN@!``D```#'Z`$`"````-'H`0`%````
MVN@!``<```#@Z`$``P```.CH`0`$````[.@!``,```#QZ`$`(P```/7H`0`?
M````&>D!`%(````YZ0$`0````(SI`0`=````S>D!`"X```#KZ0$`-0```!KJ
M`0`-````4.H!`#8```!>Z@$`(@```)7J`0`G````N.H!`"<```#@Z@$`+```
M``CK`0`>````->L!``X```!4ZP$`)````&/K`0`4````B.L!`!P```"=ZP$`
M&@```+KK`0`7````U>L!`!P```#MZP$`(0````KL`0`;````+.P!`!<```!(
M[`$`+````&#L`0`L````C>P!`#````"Z[`$`+0```.OL`0`N````&>T!`"L`
M``!([0$`7@```'3M`0`@````T^T!`!<```#T[0$`"`````SN`0`>````%>X!
M``D````T[@$`#P```#[N`0!`````3NX!`#$```"/[@$`&P```,'N`0`?````
MW>X!``X```#][@$`50````SO`0!,````8N\!``8```"O[P$`(@```+;O`0`.
M````V>\!`!````#H[P$`&0```/GO`0`&````$_`!``H````:\`$`#````"7P
M`0`.````,O`!`!8```!!\`$`"P```%CP`0`3````9/`!``@```!X\`$`(@``
M`('P`0`(````I/`!``4```"M\`$`#````+/P`0`-````P/`!`!D```#.\`$`
M#0```.CP`0`^````]O`!``(````U\0$`!@```#CQ`0`-````/_$!`!0```!-
M\0$`"0```&+Q`0`'````;/$!`!$```!T\0$`"@```(;Q`0`E````D?$!``L`
M``"W\0$`(@```,/Q`0`$````YO$!`'(```#K\0$`+@```%[R`0`4````C?(!
M`"@```"B\@$`'P```,OR`0!J````Z_(!`!0```!6\P$`1````&OS`0`?````
ML/,!``\```#0\P$`"@```.#S`0`-````Z_,!``\```#Y\P$`"P````GT`0`4
M````%?0!``T````J]`$`&0```#CT`0`5````4O0!``,```!H]`$`$0```&ST
M`0`.````?O0!``\```"-]`$`(P```)WT`0`1````P?0!`!0```#3]`$`'0``
M`.CT`0`0````!O4!`"<````7]0$`!P```#_U`0`)````1_4!`!0```!1]0$`
M$@```&;U`0`2````>?4!`!H```",]0$`$@```*?U`0`/````NO4!`!8```#*
M]0$`"@```.'U`0`)````[/4!``@```#V]0$`$````/_U`0`2````$/8!``8`
M```C]@$`$0```"KV`0`(````//8!`!$```!%]@$`!0```%?V`0`;````7?8!
M``\```!Y]@$`+@```(GV`0`2````N/8!``8```#+]@$`!P```-+V`0`8````
MVO8!``8```#S]@$`$@```/KV`0`%````#?<!`!D````3]P$`!0```"WW`0`'
M````,_<!`!<````[]P$`)P```%/W`0`%````>_<!`!L```"!]P$`$@```)WW
M`0`2````L/<!``4```##]P$`$@```,GW`0`1````W/<!``0```#N]P$`#P``
M`//W`0`(`````_@!``<````,^`$`"@```!3X`0`.````'_@!``@````N^`$`
M!0```#?X`0`@````/?@!`#,```!>^`$`/````)+X`0`<````S_@!`"<```#L
M^`$`(````!3Y`0`^````-?D!`!H```!T^0$`)P```(_Y`0`@````M_D!`"\`
M``#8^0$`6`````CZ`0`G````8?H!``8```")^@$`"````)#Z`0`&````F?H!
M``L```"@^@$`&0```*SZ`0`9````QOH!`"P```#@^@$`'P````W[`0`;````
M+?L!`#8```!)^P$`/````(#[`0`$````O?L!`!4```#"^P$`!@```-C[`0`&
M````W_L!`"0```#F^P$`#@````O\`0`9````&OP!`!$````T_`$`$````$;\
M`0`-````5_P!``<```!E_`$`#@```&W\`0`(````?/P!`!8```"%_`$`#```
M`)S\`0`:````J?P!`!L```#$_`$`.````.#\`0`)````&?T!``4````C_0$`
M!0```"G]`0`:````+_T!``\```!*_0$`!0```%K]`0`;````8/T!`!(```!\
M_0$`!````(_]`0`)````E/T!``L```">_0$`$````*K]`0`.````N_T!`!T`
M``#*_0$`#P```.C]`0`%````^/T!``4```#^_0$`&0````3^`0`,````'OX!
M`"(````K_@$`-0```$[^`0`G````A/X!`%D```"L_@$`$@````;_`0`>````
M&?\!``<````X_P$`(@```$#_`0`;````8_\!``\```!__P$`$@```(__`0`-
M````HO\!``@```"P_P$`$0```+G_`0`M````R_\!``D```#Y_P$`#@````,`
M`@`/````$@`"`!`````B``(`%@```#,``@`4````2@`"``T```!?``(`.@``
M`&T``@`)````J``"`!\```"R``(`%0```-(``@`9````Z``"`(<````"`0(`
M.P```(H!`@`?````Q@$"`"8```#F`0(`/@````T"`@`_````3`("`#L```",
M`@(`#````,@"`@`0````U0("``T```#F`@(`$@```/0"`@`@````!P,"`!8`
M```H`P(`"````#\#`@`4````2`,"`!(```!=`P(`!P```'`#`@`3````>`,"
M`"@```",`P(`!P```+4#`@`&````O0,"``\```#$`P(`#@```-0#`@`5````
MXP,"``0```#Y`P(`"````/X#`@`,````!P0"``P````4!`(`#0```"$$`@`1
M````+P0"`!$```!!!`(`!P```%,$`@`%````6P0"`#0```!A!`(`)````)8$
M`@`D````NP0"``<```#@!`(`#P```.@$`@`&````^`0"`!P```#_!`(`(0``
M`!P%`@`9````/@4"`"0```!8!0(`#@```'T%`@`)````C`4"`!X```"6!0(`
M`P```+4%`@`;````N04"``8```#5!0(`"@```-P%`@`"````YP4"``P```#J
M!0(`$P```/<%`@`+````"P8"`!4````7!@(`&0```"T&`@`6````1P8"``4`
M``!>!@(`"@```&0&`@`3````;P8"`!8```"#!@(`#@```)H&`@`&````J08"
M``L```"P!@(`"0```+P&`@`1````Q@8"`%4```#8!@(`'0```"X'`@`Q````
M3`<"`"0```!^!P(`#P```*,'`@`$````LP<"``8```"X!P(`"P```+\'`@`0
M````RP<"`!0```#<!P(`&0```/$'`@`)````"P@"``X````5"`(`#0```"0(
M`@`;````,@@"`!@```!."`(`#@```&<(`@`?````=@@"``X```"6"`(`(```
M`*4(`@`D````Q@@"`"0```#K"`(`#@```!`)`@`,````'PD"`"P````L"0(`
M+0```%D)`@!J````APD"`"8```#R"0(`)````!D*`@`6````/@H"`!<```!5
M"@(`&````&T*`@`6````A@H"`"````"="@(`)@```+X*`@`B````Y0H"`!0`
M```("P(`&0```!T+`@!%````-PL"`#L```!]"P(`)0```+D+`@`9````WPL"
M``X```#Y"P(`&0````@,`@`8````(@P"``H````[#`(`!P```$8,`@`(````
M3@P"``D```!7#`(`%````&$,`@`-````=@P"`#0```"$#`(`%````+D,`@`=
M````S@P"``<```#L#`(`#@```/0,`@`[`````PT"`$X````_#0(`+P```(X-
M`@!X````O@T"``H````W#@(`*````$(.`@`W````:PX"``@```"C#@(`$```
M`*P.`@`(````O0X"``P```#&#@(`-@```-,.`@`(````"@\"``L````3#P(`
M#P```!\/`@`1````+P\"`!````!!#P(`20```%(/`@`Y````G`\"`"@```#6
M#P(`(````/\/`@`G````(!`"`"$```!($`(`+````&H0`@`F````EQ`"`"T`
M``"^$`(`)@```.P0`@`0````$Q$"``@````D$0(`#0```"T1`@`/````.Q$"
M``X```!+$0(`!P```%H1`@`T````8A$"``P```"7$0(`$````*01`@`&````
MM1$"`!(```"\$0(`"````,\1`@`'````V!$"`!````#@$0(`"0```/$1`@`)
M````^Q$"``@````%$@(`$`````X2`@`0````'Q("`!4````P$@(`%P```$82
M`@`-````7A("`"(```!L$@(`$@```(\2`@`(````HA("``X```"K$@(`#@``
M`+H2`@`5````R1("``\```#?$@(`!@```.\2`@`,````]A("`"8````#$P(`
M#@```"H3`@`?````.1,"`"4```!9$P(`"0```'\3`@`&````B1,"`!(```"0
M$P(`"@```*,3`@`$````KA,"`!L```"S$P(`/@```,\3`@`.````#A0"``\`
M```=%`(`#P```"T4`@`&````/10"``D```!$%`(`"@```$X4`@`)````610"
M``X```!C%`(`%````'(4`@`$````AQ0"``\```",%`(`"````)P4`@`+````
MI10"``\```"Q%`(`&0```,$4`@`*````VQ0"``(```#F%`(`(````.D4`@`'
M````"A4"``<````2%0(`<@```!H5`@`+````C14"``8```"9%0(`)@```*`5
M`@`N````QQ4"`!X```#V%0(`/@```!46`@`O````5!8"`!P```"$%@(`)```
M`*$6`@`G````QA8"`"\```#N%@(`40```!X7`@`A````<!<"`#(```"2%P(`
M'P```,47`@`4````Y1<"``4```#Z%P(`!0`````8`@`,````!A@"``L````3
M&`(`!P```!\8`@`,````)Q@"`!(````T&`(`#@```$<8`@`+````5A@"``T`
M``!B&`(`"P```'`8`@`'````?!@"``<```"$&`(`"@```(P8`@`4````EQ@"
M``D```"L&`(`!P```+88`@`+````OA@"`"$```#*&`(`!@```.P8`@`H````
M\Q@"``4````<&0(`!0```"(9`@`/````*!D"``4````X&0(`"@```#X9`@`B
M````21D"``D```!L&0(`'````'89`@`'````DQD"`!(```";&0(`$@```*X9
M`@`&````P1D"`!8```#(&0(`"P```-\9`@`(````ZQD"``4```#T&0(`!0``
M`/H9`@`/`````!H"`!P````0&@(`!P```"T:`@`)````-1H"`"8````_&@(`
M'````&8:`@`-````@QH"``0```"1&@(`"````)8:`@`0````GQH"``D```"P
M&@(``@```+H:`@`'````O1H"`!\```#%&@(`)P```.4:`@`A````#1L"`"H`
M```O&P(`*0```%H;`@!%````A!L"`!@```#*&P(`(P```.,;`@`B````!QP"
M`"<````J'`(`(0```%(<`@!:````=!P"`!$```#/'`(`7P```.$<`@`N````
M01T"`!X```!P'0(`20```(\=`@!L````V1T"`!X```!&'@(`,````&4>`@`@
M````EAX"`"@```"W'@(`,0```.`>`@`K````$A\"`!\````^'P(`.@```%X?
M`@#+`0``F1\"`!P```!E(0(`*0```((A`@`/````K"$"`#\```"\(0(`?```
M`/PA`@!#````>2("`!H```"](@(`,@```-@B`@!>````"R,"`$@```!J(P(`
M(0```+,C`@`7````U2,"`!````#M(P(`'@```/XC`@`9````'20"`!@````W
M)`(`)P```%`D`@`@````>"0"`!X```"9)`(`,0```+@D`@`9````ZB0"`!``
M```$)0(`-````!4E`@`C````2B4"`"$```!N)0(`(0```)`E`@`O````LB4"
M`"(```#B)0(`.0````4F`@"/````/R8"`%0```#/)@(`+P```"0G`@!'````
M5"<"`#````"<)P(`)P```,TG`@!!````]2<"`%X````W*`(`10```)8H`@!5
M````W"@"`"L````R*0(`+@```%XI`@`Y````C2D"`#````#'*0(`)0```/@I
M`@`P````'BH"`"P```!/*@(`)````'PJ`@`K````H2H"`%8```#-*@(`3P``
M`"0K`@`P````="L"`$H```"E*P(`20```/`K`@`Q````.BP"`#````!L+`(`
M)0```)TL`@`D````PRP"`"(```#H+`(`,P````LM`@`L````/RT"`"P```!L
M+0(`+0```)DM`@!E````QRT"`%H````M+@(`8P```(@N`@"=````["X"`!4`
M``"*+P(`(P```*`O`@`O````Q"\"`"\```#T+P(`00```"0P`@`@````9C`"
M`%0```"',`(`)P```-PP`@`A````!#$"``L````F,0(`M0```#(Q`@!(````
MZ#$"`!\````Q,@(`)@```%$R`@`V````>#("`"(```"O,@(`'@```-(R`@!*
M````\3("`"P````\,P(`!P```&DS`@`'````<3,"``,```!Y,P(`#0```'TS
M`@`+````BS,"``H```"7,P(`"P```*(S`@`%````KC,"`!D```"T,P(``P``
M`,XS`@!;````TC,"``0````N-`(`)P```#,T`@`$````6S0"``<```!@-`(`
M!@```&@T`@`%````;S0"``0```!U-`(`$P```'HT`@`(````CC0"`!$```"7
M-`(`%0```*DT`@`"````OS0"``<```#"-`(`!P```,HT`@`,````TC0"``X`
M``#?-`(`!@```.XT`@`4````]30"``P````*-0(``P```!<U`@`G````&S4"
M``0```!#-0(`!@```$@U`@`(````3S4"`#````!8-0(`1P```(DU`@`N````
MT34"`"\`````-@(`&P```#`V`@`O````3#8"`#(```!\-@(`)````*\V`@`A
M````U#8"`",```#V-@(`*````!HW`@`C````0S<"`"$```!G-P(`*@```(DW
M`@`I````M#<"`#@```#>-P(`(@```!<X`@`S````.C@"`!\```!N.`(`,```
M`(XX`@`M````OS@"`"(```#M.`(`)@```!`Y`@`E````-SD"`"````!=.0(`
M*0```'XY`@`I````J#D"`"4```#2.0(`+P```/@Y`@`<````*#H"`"$```!%
M.@(`)0```&<Z`@`I````C3H"`"````"W.@(`*@```-@Z`@`^`````SL"`$$`
M``!".P(`'0```(0[`@`D````HCL"`$````#'.P(`)0````@\`@`I````+CP"
M`"@```!8/`(`*0```($\`@`C````JSP"`"````#//`(`*@```/`\`@`E````
M&ST"`#D```!!/0(`)P```'L]`@`U````HST"``P```#9/0(`#````.8]`@`4
M````\ST"`"\````(/@(`(P```#@^`@`+````7#X"`!<```!H/@(`#@```(`^
M`@`6````CSX"``@```"F/@(`!P```*\^`@`B````MSX"`"4```#:/@(`'@``
M```_`@`G````'S\"`"4```!'/P(`#````&T_`@#K````>C\"``\```!F0`(`
M*P```'9``@`8````HD`"``P```"[0`(`#P```,A``@`8````V$`"`!\```#Q
M0`(`'P```!%!`@`&````,4$"`#4````X00(`%@```&Y!`@`4````A4$"``<`
M``":00(`$P```*)!`@`*````MD$"`#P```#!00(`"@```/Y!`@`H````"4("
M`!,````R0@(`&````$9"`@`7````7T("`#@```!W0@(`(````+!"`@`2````
MT4("`"0```#D0@(`$P````E#`@`4````'4,"`!4````R0P(`"@```$A#`@`7
M````4T,"``D```!K0P(`'0```'5#`@`(````DT,"`!P```"<0P(`)@```+E#
M`@`'````X$,"`",```#H0P(`!P````Q$`@`(````%$0"``D````=1`(`-```
M`"=$`@`0````7$0"``8```!M1`(`$````'1$`@`5````A40"`!0```";1`(`
M"P```+!$`@`,````O$0"``<```#)1`(`#0```-%$`@`+````WT0"`!````#K
M1`(`'````/Q$`@`/````&44"`"`````I10(`&````$I%`@`9````8T4"``L`
M``!]10(`#0```(E%`@`7````ET4"``D```"O10(`*P```+E%`@`,````Y44"
M``\```#R10(`"0````)&`@`"````#$8"`!$````/1@(`&````"%&`@`+````
M.D8"``,```!&1@(`"P```$I&`@`/````5D8"``@```!F1@(`!P```&]&`@`+
M````=T8"``L```"#1@(`#@```(]&`@`M````GD8"`!H```#,1@(`&@```.=&
M`@`A`````D<"``H````D1P(`.@```"]'`@`%````:D<"`!8```!P1P(`-P``
M`(='`@`-````OT<"``X```#-1P(`!@```-Q'`@`$````XT<"``8```#H1P(`
M"P```.]'`@`7````^T<"``<````32`(`"````!M(`@`'````)$@"``@````L
M2`(`!0```#5(`@`/````.T@"``T```!+2`(`#P```%E(`@`0````:4@"`!@`
M``!Z2`(`%@```)-(`@`/````JD@"`#X```"Z2`(`,0```/E(`@`D````*TD"
M``4```!020(`&@```%9)`@`A````<4D"`"$```"320(`(P```+5)`@`1````
MV4D"``(```#K20(`!````.Y)`@`*````\TD"``4```#^20(`!0````1*`@`#
M````"DH"``D````.2@(`3````!A*`@`E````94H"`"\```"+2@(`&````+M*
M`@`M````U$H"`"4````"2P(`7P```"A+`@`J````B$L"`"D```"S2P(`)P``
M`-U+`@`3````!4P"`'D````93`(`'````)-,`@!3````L$P"`"(````$30(`
M/P```"=-`@`T````9TT"`!X```"<30(`'0```+M-`@`L````V4T"`"(````&
M3@(`(@```"E.`@`V````3$X"`#8```"#3@(`-0```+I.`@`S````\$X"`"@`
M```D3P(`(@```$U/`@`F````<$\"`"P```"73P(`3````,1/`@`4````$5`"
M`#0````F4`(`#P```%M0`@!O````:U`"``D```#;4`(`H@```.50`@![````
MB%$"`'`````$4@(`*````'52`@!4````GE("`!H```#S4@(`*P````Y3`@`I
M````.E,"`!<```!D4P(`"@```'Q3`@`=````AU,"`!T```"E4P(`-````,-3
M`@`C````^%,"`!@````<5`(`5````#54`@`>````BE0"`!<```"I5`(`"@``
M`,%4`@`$````S%0"``8```#15`(`"````-A4`@`%````X50"`!4```#G5`(`
M$P```/U4`@`9````$54"`"4````K50(`$````%%5`@`0````8E4"``X```!S
M50(`"0```()5`@`$````C%4"``D```"150(`"0```)M5`@`(````I54"``\`
M``"N50(`"````+Y5`@`)````QU4"`!8```#150(`#@```.A5`@`(````]U4"
M``T`````5@(`#`````Y6`@`1````&U8"``X````M5@(`#0```#Q6`@`+````
M2E8"``8```!65@(`$P```%U6`@`:````<58"``<```",5@(`"P```)16`@`6
M````H%8"``T```"W5@(`!P```,56`@`/````S58"``@```#=5@(`"0```.96
M`@`E````\%8"`!L````65P(`#````#)7`@`D````/U<"`!(```!D5P(`#```
M`'=7`@`,````A%<"``P```"15P(`#````)Y7`@`>````JU<"`!0```#*5P(`
M$0```-]7`@`%````\5<"``4```#W5P(`(0```/U7`@`(````'U@"``(````H
M6`(``@```"M8`@`6````+E@"``@```!%6`(`"````$Y8`@`4````5U@"`!8`
M``!L6`(`"````(-8`@`M````C%@"``(```"Z6`(`!````+U8`@`3````PE@"
M``8```#66`(`$````-U8`@`7````[E@"``\````&60(`!P```!99`@`2````
M'ED"``4````Q60(`&P```#=9`@`%````4UD"`!8```!960(`$0```'!9`@`2
M````@ED"``(```"560(`"````)A9`@`/````H5D"``L```"Q60(`#0```+U9
M`@`4````RUD"`!$```#@60(`)````/)9`@`+````%UH"``P````C6@(`$P``
M`#!:`@`%````1%H"``(```!*6@(`"P```$U:`@`!`````````+X'```I`@``
M)@$```````"N`P``F@$``!L(``#_!0``O`,``.0'```A````[@$```````#&
M!P``L04``%8&``"S!0``/04``.D'``##!P``DP,``!\$````````U`(``&8&
M```.`@``9P$````````5`@``AP```$(&````````00<````````9"```A`8`
M`$T(``#B!0``H@8``!D'``#]`0````````P!``!3`P```````"X&````````
M/@$``)@!``":!```I`$```````!7!P``````````````````UP```"`#````
M````?P```!$#``"0````DP```'P'``!7!```A`<````````X`P``9```````
M``!(`@``]`$``-P```#\`0``````````````````N04``)<#````````(`(`
M``T$````````(P```"D%```:`@```````',%``#3!````````(H"``#:`0``
M:0,``#4&````````@P(``#`(``"A````8`$``'<#````````>@,``(4`````
M````JP$```````"?!P``,`8``#D#``"F`0``,00``/P&``"!`P````````4`
M````````SP<```````!@!P``"P(```$%````````40,``)D#``":`@``30$`
M`(X$```^!P``:0@``.L"``````````````````#^!```]`0``#0'``#6!```
M`````%L&```?````U@4``,T!````````[@8``'<!```D!```$`4```````#=
M!@```````"0```"Y````P@0``*<&``""!```^0<``%,%````````X@(`````
M``!R!P``````````````````H@(``+P!```!!```6@$``-$!``"6!0``704`
M`/$$``#L`P```````&D%``#'`0```````)8"```W!````````%@(``"J!```
MH`4``.X"``#<`P``S0(``*T"``")!@``"`````````#+`0``1P@``-L!``#F
M!```.````!4```"6!P``K`,``&P`````````(P8``($```!P`0``&P4``.\#
M``#D!``````````````?`@``1P```-8#``````````````````"_!@``$00`
M``8&```=`P``A`(``%$```"N`0``+04``(@&``#5!P```````&((``!^!P``
MR`4``,D'``#+````&`4``$P'````````2P8``'X!```T`@```````!<#```<
M`@```````*,!``"C````P0,``)`"``!``0```````"L!```(!P```````$,!
M```_!P```````'L!````````0@@``%,"``#9!@``60(``&D'``"W`0``(P0`
M`&0'``#R`@```````!L#``!&`P``+@(``.4'``!"!P``7`(``!$%```+!P``
M#0@```8'```8````U`8``!\'``#M`0````````````"2`P```````%<"```8
M!@````$`````````````500``#0```#`````W04```````![`P``"0@``,H#
M``#6````P@8`````````````:@8``.\&```"`@``4@(````````N!```DP<`
M`)0$``!V!P```````-@#`````````````*X'``"Y`@```````#T$``!^!```
MC@,``-T"``"X`P``F`(``%T&```3`P``\P(``+H%``##````U`0``"8&````
M````X08`````````````CP```!`!``"7`0``30,``)T#``#2`P``]08``/\!
M``"V`@```````(@```#2````I0$``)T&```L````"@,``',$```E````````
M`%(%``!U!P```@4````````M!```!@,``#$&```'!P``=P4``"D!``!J!P``
MAP0``!X$``#E````@@8``/L#````````````````````````90```-<!````
M````M@8``$@(````````\````+0"``#:!@``%`<``%H$``!1!0``UP0``.($
M``!8`@``NP(``!`&``!U`P``"0(``.(#```_````'P4``*0$````````MP,`
M``````"Z!@``G@,``#0!```)````C@<``````````````````)`$````````
MK0<``+T#````````(08``",!```3!```9@```%<!``!]!@```````!T`````
M````G0(``,D&```:!@``0P,``)<'``#1!@``*`$``!@!``!W`````````+0#
M```@!0```````.8'```K````K0```'``````````[@4``,4"``"%!@``````
M`#$'``!G`P``^P$```````"<!@`````````````E!@```````,@"``"$````
M`````+`#```["```Q@0``*,$````````-@```#((```K!```'04``"T!``!?
M"```G`<```````#)!```408``$$!``!8!0````````@(```K"```]`<`````
M``"/`0``#`,``,P'``````````````((```4````I`,``(P```".`@``*@``
M`,H'``!E"```5P,``.0#```A!P``!@4``!,```#2!0``>0````````!(!@``
M&`,``','`````````````)\&``!9"```4@$```````"&`P``<@````````"`
M`P```````,H"``#`!P```````!@$``",!```,@8``+4#``!2"```VP8```X%
M``"O!@```````+$`````````%04``.D#````````JP`````````?`P``````
M`'@"``!4!0``]0```,H$``!-`````````.,```!Z!@``]`8```````"U`0``
M`````&4"````````W@4```````"C!0``L@4```````#S`P``````````````
M````]0<``(@#``!]````#P,``$(#```*!@``*@(```````"$!0``@`8``$4(
M``#<!```T`,```H!``!J`@``V`<``&X```"F`P``$`@```````#Q!@``E@0`
M``````#S!```2`,``)D"``!\!0```P0```T"`````````````$4'````````
ML@8``)H'````````90$``%P'```2`P``M@```+\```!A!0``20````````"R
M`0``F`8``#\"``"%`@```````-D"```?!@``.P8``+\$``"E!P``````````
M``"&`@``*0,```D!```G`P```````%L%````````6````.T$```,`@``%`@`
M`-$'````````6P0``"(!``"9!```_`0``$P!````````O@(``%4````+!@``
MRP4``"0!``!/`P``300``,4$````````E`4``&8%``#.``````````8!``"^
M!@``&P<``'\&````````?@```.8!``#!!@``QP(```````!U`0``?04``)T!
M``"2````,`4``%@!```````````````````K!P```````%4"```1"```?0$`
M`*$"```K`P```````)P!`````````````($'````````8P@```````";!0``
MZP$``-4`````````5````*H'``"]!0``4P0``#@&```%!0``/08```````#B
M!@``BP,``)X&```````````````````F!0``M08``#@!````````0`<``#,"
M```F"```D0<```````!S`0``R@```,$'``#Q!P`````````````H`P``I00`
M`*,&````````O0`````````J`P```````"X!````````````````````````
M.0(```````"[!```-P,```````"#`P``KP<``&(%``"V`P``RP8``-`$```\
M!@``80```+\"````````0`,``````````````````'L'```O`@``````````
M``!<````````````````````?@8``"T(``#T!0``VP(``%<%``!2`P``-0``
M`/($````````2@$```````"7!0```````,T&```L!0``CP4``#L'``!Q!@``
M.04``,H%``#B`0```````&,!````````E@8```4&``"2!P``004```````!/
M````````````````````&0,``+,#``!_`P``-04````````L!@``U@<`````
M```T`P``^04```````"[!P``,`0```````#F!@``-0<```````"1!0``[0,`
M```````4!0```````)L#``#8`@```````'@#```G`0``B@````0'``!E!@``
M`````,0&``"G````=`(````````1`0``XP8``*(%``!-!P``/P$``*H%````
M````<00``/D"````````1`0``$4%``!K!```#04``#(```!9!```<@$`````
M````````'@(```D%``"/!P``80(``#D`````````Z0$``%\#``#:!```B04`
M``````"=!P``7P8``,4!``!*"```1`@``-`%```X"`````````````!,!0``
MYP(``&L&``!```````````````!!!````````$8(``#7!P``]00```(&``#V
M`@``7`0``(<&``#W`0``900``+H!```Q`0``P`(````````C`P``^`4`````
M````````C@8`````````````_04``(`!````````7@,```8"``#5!@``H`8`
M`.T"``"P!@``$P@``%P(``"4`@``RP(``-($`````````````&4#````````
M,P<```````!N`@```````+0!``!'!0``````````````````OP<```T!``"K
M!@``Q0```,X!````````]P```-X"``!V`@````````````#8!```?P0`````
M``"X`@``K@4``+`'``"R`@``00```,$"`````````````(L$````````+08`
M`#T#````````:P(``'T#``"W!````````)8#````````IP(``#0(``#U`0``
M````````````````"`0``'X#``"C!P``F`0```````#G`0``XP,``$L!````
M````.0$`````````````-0@``-0%````````3@$``````````````````%,`
M``#L`0``UP,``'H```#``0``?`,``/T#``#0!@``0P```*4#````````````
M`+,&``!:!@``$`<``%T"```9!```V04``-D!```Z!P````````````"I!P``
MH0$```````!%````B`0`````````````*@0``&\````N!0``3`@``.0!```T
M!@```````%X%``"<!0``(@0``#4#```;!```A@<``$D#```A`P``TP<``*H`
M``````````````````!T!```,P0``(H'``!K!P``-P```.$#``!;"```````
M`),&``!*`P``!P(``&D&``"-!P```````-4"````````K0,``/H"````````
M<P,```````""!P``P0```-P'``!?`@```````'<$```R!P```````!$'```Z
M`0````````````#U`P```````#\%```\````C04``/\'``!=!P``%`0`````
M``!&!```O@4``!D!````````5@```.$!``#2`0``1````"T'``#K`P``````
M`$D"``"2`0``!P8```````!*`@``+P````````!:`@``>`````````#"````
M`````(L'``!:!0``G`(``&<$````````#P0``,8%``">`````````(4#````
M````R0`````````)`P``K`(```````"Q`@``Z`8``&D```"`!P```````#H"
M``"*!0``"P$``#@'````````'@```'8&``!Z`0``B@8``+4$````````-P$`
M````````````80<```````!`"```@P$``#$(```O!P``40<``,4%``!P!```
MY0,``.<&````````)`(````````P`0``8`8`````````````[`8```````!$
M`P``S`(``"<$```Z!@``IP0```````"M`0``U04```````#O!```_0(```X$
M`````````````&T```!M`0``R`$``%D!```'````SP$``%D%```T!0``KP,`
M`)L!``#F````F````!X'``!C!0``A04``*4"``#"!0``F08`````````````
M`````$P````O!0````````````!+!P``S@<``%$(```\`P``XP$````````=
M!```^P0``/\```#(!@```````*X$````````50<``/H`````````9P(``#\&
M```=`0``,P$``-L'``#6`0``\@8``(````!-`@``H@<``*0&``#K!```````
M```````S!0``-@@```````"2!0``4`$```<#``"R`````````,@$````````
MW@,``/8&``![!@```````/,`````````QP0``'0%```2`0```P$``#<'````
M````1P<```8$``#O!P``&@````,%``!_!0``^`(````````!`P``Y04`````
M``#Z!0```````#\(``!5!@```````+T"``````````````````!8!```K`4`
M``````"T!0```````&`(``#[`````````,@'````````MP<``%`````F````
M[@0``/H!``!2!P``/@4``%`(````````$@(``*P!```G!P``ZP4``&T%```E
M"```0@0````````R!``````````````/`0``*@4``.$$````````AP,``%X'
M``!F!```\@$```````!Q`P```````/T``````````````!P'``#M````````
M`+$#``#?`0``<0(``&@"``!*`````````"P(````````J````$4&```\"```
M[`(``+4'``!D!@``5`<``-\"```]`0``B0<``,P#``"H`@``%@@```````"2
M!@``0P8``'L"``#8`0``:@0```<%``#I!@``;`8``,0%``")!```8P0``+`!
M```R!0``40$``$\%```B"```=08```8(``!6!P``O@0``&0!``"?`P```0<`
M`"@$`````````````+@````G!@```````!$&``!N`P`````````````_`P``
M-P4``!4'````````MP```",'``!@!```#P4``*@!````````\`8``/`$````
M`````@$`````````````2`<``-4!```5`P``"`,```````#3````$`0`````
M``!.!P```````*8"``#V!P``6@```#X(```+!```RP,``/`'``"N````$@0`
M`)@'```E`@``H@$```````!Z!0```````$8````U`@``X0```-D```#>````
M%`$``"('````````C`8``"L%````````]P<``*D$``!0!0``7@$``#0$```Z
M`P``EP(`````````````V`4```````#L!P```````/(`````````W`$`````
M```/!@``6P(```````"A!0```````.@$````````_@(``/P'````````````
M`)4```!%`P``8@```+@&````````F0<``!((```.`0``L`0``%0"``#V`P``
MSP0``#X&```^`P```````,<`````````D`$``(`$``!D"```$P<```````#V
M!0```````&X&````````=@,``'T'``#@`0````````<(``#2!@``J@,`````
M```E!0``J04`````````````GP$```````#]!P``>04````````?"```]`,`
M`+@$``!>`@``J@(``.H'``#$`@``FP(``&$&``!$!P````````````#_!@``
ME04``-$#``"!`0````````\'```6!0``PP$``),!```9`@```````!T'``#J
M!```Y@,``"<%`````````````"@````,!P``+0,``"X(``#)`@``3P@``!0&
M```U!```T`<````````:!P`````````````M`@``/P0``+X#``#Q!0``>0$`
M`#@$``#$````S@8``+4````R`0````````````"@`0``3P<``'H'``"'`@``
M/@````````"5`P``F0$```````!J!0``H0<``,\&```,!0``=0```&\'``!B
M`@``!`8``%8!````````2@0```````#/````,`````0$````````LP``````
M``"5!```2`$``*T&``#"!P``Y@4``$@%``!P!0``C`<```````#Q`0``N0$`
M`&8'```#`@``JP(``.`&```A!```V0<```````!+"```7@@``"4#````````
M.0<``-T`````````:`4``*`$``!D!0``/0@``)@#``!*!0``[04``)H#``"!
M`@``&@0``````````````````%H#```[!```0P0````````#!@``$@4``-\%
M````````?P(``*X"``"W`@``7@8```````"R!P``'@,``(,'````````ZP<`
M`*\!``"J!@``0@$`````````````@@(```T``````````````!H(``#1````
MMP4``/,%``""`P```````.4$``!I`0``\0(``.<#````````H@,```4'``!0
M`P``T04`````````````,@,``*D&``!8!@``G@0``)T$``#%`P``OP$``!H%
M``#L!0``^@<``(P"``!C````<`,``%$$``"Q!@```````$<&````````````
M`+(#`````````````'\!`````````````*8```!&`@``B0,``"````!<!@``
M<0$`````````````=00`````````````_`(``(0#`````````08``(8```#?
M!P``Z04````$``"V`0``P@(```$!```X`@```````,,%``!`!0``B@,```H$
M``#F`@``:`<``"\&``"G!P```````!P!```L`P``%@```+\#``"H!P``````
M``````#^`0``K00``$<#``##!@``9P```)P#```I!@``Q@```-0```#R!P``
M%0@``&X!``"S!P``TP4``+$!```P`@``^00```````!6!0``=@0``+@!````
M`````````!,%`````````````.X```!O!0```````,8"``!+`P``A`$`````
M``#-`````````,T#````````"P,``````````````````)H&``!#!P``````
M`-H'``"Y!```8`(`````````````'`@``````````````````*D#``#R`P``
M3`,```T&``#)!0``H08````````;!@````````````!\`@``80,``)X!``!Y
M`@``W0,``(8&``#A!P``'`,``(D!```S`P``^`0```````!5!0``]0(``&('
M````````9P4``!8"``!E!P````````````!H`0``*P8``````````P``````
M`$D'``#@!0````````````"\!```70$``&@$``!Y!@``N@(``!4$``#3`P``
M`````$8'``"`!0``T`$``"P!```Q`@``,P8`````````````5P@```````!F
M"```T````%8$`````````````!P$``!5"```'0@``'`"````````W`8`````
M``!H"````````/<#``!_!P``CP,``"X```#X!@``%@$``)0`````````````
M`)@%```D"```G`0```````#I````1P$``*P```"[`0``SP(``/H&````````
MTP8``$$(```*`@``(0@``$X(``#<!0```````-H%`````````````-@```"4
M!@``A@0``"H!````````9@$``"\$``#$`0```````$L"``#"`0``B`4``/H#
M``!X!0``A0$``($&``"O!```T00``,D#``!$!@```````,P```";!@``_P,`
M`+4"```<!@``4P@``*\"``##!```E08``%L```!9!@````````````#D!0``
M`````-8&``!]!```"`8``$$"``!C!@``<@0``/P#``#7!0``Z0(``*<!```]
M`@``#P```%0&``#X`P````@``&P#````````5`,``$T&```6!P``J`,``&<&
M``#V````!@```#X"``"E!@``S@0``&$(````````7`4``.@`````````.P(`
M`/,&``#3`0``Z00``&P$```Q````9P<``)L'``!#!0``P0$``"<"````````
M`````-L%```N`P``8@0``(L&``">`@``M@0``$H'``!)!@```````.,%```$
M!0``=P<``!0#````````00,```<!``"!!````````#H%``!6"```<P```"$!
M``"'!0``HP,``-L````.!P``'@8``!@"``!;`0```````&4%``!``@``;00`
M`/$#``#&`P``W00``'0```"I`@``*`4``-H#```(`0``(@4``+0&``!3!P``
M<P8````````[`P``D`4``,H&````````%@8``-("``!M!P``$0(``'T"````
M````F04```````!H`P``7P$``/X#``"6`0````````````#O!0``9`0``&``
M````````$P$``-T'``"\!0``PP,````````[!0``G`````(```"S!```]`(`
M```````D`P``&`@``````````````````%D#```)!```]P(``$T%```<!0``
M3P0``,@#```%`0``!00``*`#````````<@(``(@!`````````````(T$````
M`````````(D"``#G!P``^0,``*L%```V`@```````*L$````````;P$``'L%
M`````````````*@%````````^0```*<#```.````J`0``/T&```Z"```````
M`#H`````````>@(``#,````F!P``X`0``/`#``!=!```>`<``+8'```7`0``
M\0```+@'``#W!```<0<``.<````,"```[````)<$``#.!0``50,``&$$``"X
M!0```````-4#``!.!0```P```(<!```Y!@``F@4``)\```!M`@```````)<`
M```@!```CP8```````!K````Y`8``"`&``"B````/`(````````7!```[`0`
M`.\!```L!```8P(`````````````NP````0!```;`0```````'8%``"4`P``
M`````"H&````````N@,```````!2!@``%0$``*($```$`````````!P`````
M````_@```"\#``!/!@```````"8#````````^P<```````!;`P````(``/P%
M``"W!@``X@````````!<`P``@P8``*4%``!D`P``*0<``&P%``#,!@``H0,`
M`%`&``!1`@``C0(``.4"``!/`0``C0```"`(````````D0,``,$%``"+!0``
MC`$``+D'``#>!P``;`(``$D!````````C0,````````````````````````0
M`P``%`(``.H!````````)P````````!L`0``%P(````````U`0``Z@8``$`&
M``#M!@``D`,```H'```0````)P@```````#^!P``W@0``%0(```H!@``````
M`'0'````````008``+($``"/!```#`8``%\'``"#!0``?`````````#^!0``
MI````-\```!W`@```````)$"``"?!0``>@0```````!J`P```````,T%````
M``````````````"D!P``]@$``)`'``"6`````````-P"````````>`0`````
M```````````````````B`P``X@<``.$"````````>00``.L`````````S@(`
M````````````T0(``$X``````````````*8%``#D`````````$X"``"V!0``
M"P@``%4!```J!P``T`(`````````````.P$```````!\!@``Q@8```````"P
M`@```````(,````F`@``RP<``",(``#C`@``2P4```````#A!0``A0<``-<&
M``#9`P``CP(``!8$``!R!0``N0,``.,'``#M!P```````%T(````````\P<`
M`'$%````!P``Z`,``"(&``#Y`0``J0````````##`@``@P0``(L"``!?````
M`````!H!``#X!P``SP,``)$$``#(````\`$``)T`````````U`$``&,'``"O
M`````````$0!````````&`<````````A!0``_P0``$8!```X!0``1`4``/`"
M``"\!@``L`````````!6`P``"@````````"K`P``Y08``*`"```9!@``````
M`%@#``#'`P``[@,``#L`````````3@0````````%`P``"@@`````````````
M8@,```````#Y!@``Y0$``$<"``"3`@``A`0`````````````^@0`````````
M````````````````````,@(``.`#``````````````````#?!```V00``#$%
M``"'!P``<@,``!<%````````F0```+L#````````2````&L%```3`@``-@,`
M``````#J````^P4```X#```H"```+0```.0"```V!```U`,``!T&``"\````
M`````&L#```+!0```````(D```#?`P``$`(``,\%````````BP$``*``````
M````C`,``,`%``!9!P``<0```&X%````````0P@``.H#````````K@8``-L#
M````````;P,``'4"```,!```2@8``*,"````````C`4```````"F!P``+P$`
M`"(````W!@``XP0``),$```H`@``P@,``'`'``"2!```3`8```\(``!T`0``
MN@<```````";!```1@4``#D(``"A!```9@(``*\%````````7P0``"4$```N
M!P``&0````P`````````S`4``&X'``!K`0``80$```D'````````3`(``"`'
M``#$!````````,0'``">!P```````)("``#.`P````````````!V`0``U00`
M``````"D`@````````````!&!@``TP(``,<'``!"!0``_````"@'``!G"```
MI@0``,T'``".`0````````````!O!```O08``*0%``!W!@``````````````
M````P`0``%\%``""`0``Q`,``)T%``#H!P``200``$4$````````````````
M```V`0```````,4&``"!!0``L00``/<%`````````P@``'(&``":````T@<`
M``````"(!P```````*`'````````!P0``$(```"S`0``W0$``/8$``!U!0``
MI0```)4"``!6`@```````$0"``#N!P``N08``-@&````````4`(``-X!``"7
M!@```````)X%``!O`@``:@$```````#>!@```````"4'````````````````
M``"``@``%P<```````!B!@``Q0<``````````````````$@$``#G!0``0P(`
M``````!;!P``?`$``$4!``#W!@``3`0`````````````4@```*T%``!V````
M$0```&`#``!J"```:00``!<````2````^`$``"8$``!.`P``A@$``(@"``#,
M!```D0```"0%``!)"```R@$``#H$``#]!````````#`#````````'P$``/X&
M``"L!P````````````!/`@```````!L```![````B@0``.@!``!)!0``V@``
M```````5!@````````0#````````O`<```($``#+!```#@8```D&``!8!P``
M*0`````````$`@```````)$&```#`P``\@4``*H!````````P`8```````!+
M````\P$``"0&``!0!P```````"P"```-`P``:@```.`"````````;P8``%X$
M````````/@0``"$"````````:`8``)4'````````"P```(H!````````````
M`%H'````````/`0```@%````````(@(``!8#``!=`P````````````"4`0``
M`````$L$````````N@```,T$``"]!P``K`8``&T&````````3@8``*<%````
M````+`<````````````````````````V!0``0@(``(L````2!P````````\"
M```Y!```I@8``'0#``!Y!P``7@```!<&``#J!0``O`(``'0&````````DP4`
M`&8#````````>`$``((```````````````````"-`0``+P@``&@`````````
M"@4``,D!````````C@```*D!````````-P(``"D(``!3`0``FP```!H#``!3
M!@```````*P$``#[!@``?`0``&,#````````M````)\$````````Z@(``!X(
M``".!0``\`4```````!L!P``A00```4(``!^`@```````%($```@`0``M`0`
M`.L&````````O00````````>`0``,P@```````"^````60```"D$```]````
M`````%<&``#7`@````````(#````````-P@``/0`````````A@4``/\"``#[
M`@```````!X%``!N!````````#P!``"Z!```,`<```````#O````1P0`````
M``#@``````````0(```7"```(P(``+L&``#O`@```````+T!````````````
M`+L%``"4!P``#@@``&(!```!"```5P``````````````-@<``+X!```\!P``
M5`0``"4!``!Y`P``JP<``%T```#?!@``9`(``'`&````````OP4``!D%```%
M`@````````('``#X````LP(``+4%``!4`0``L0<``"0'``"T!P```````&T#
M``#&`0``Z`(``-0'``"P!0```0(``!,&``"0!@```````)4!```(`@``Z`4`
M`#$#```2!@``0`0``#T'``!0!```:0(``,$$`````````````#P%````!0``
M&P(`````````````'0(``%P!````````10(```````!^!0```P<``%H(``"-
M!@``V@(``*@&``!@!0``]04``.`'````````GP(```````""!0``*P(``'L$
M```J"```>`8``#8&````````D0$``,<&````!@``<P(``,`#```C!0``QP4`
M`,P!````````U@(```T'``#G!```VP0````@*"5S(&1A>7,@86=O*0`@*$%C
M8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W
M*0`@*'EE<W1E<F1A>2D`($%D9"!A;B!)35-0($%D9')E<W,@0F]O:P`@1&5L
M971E($E-4U`@061D<F5S<R!";V]K`"!A="``(B5S(B!A;')E861Y(&5X:7-T
M<R!A;F0@=V%S(&YO="!I;7!O<G1E9"X`(B5S(B!I<R!N;W0@82!D:7)E8W1O
M<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C
M;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E
M;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P
M<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S
M>7-T96TN`"(E<R(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A(&QI
M<W0N`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`(B5S(B!W87,@;F]T(&UO
M=F5D(&)E8V%U<V4@:70@:7,@82!L:7-T+@`B1FER<W1N86UE($QA<W1N86UE
M(B`@*&EE+B!*;VAN($1O92D`(DQA<W1N86UE+"!&:7)S=&YA;64B("AI92X@
M1&]E+"!*;VAN*0`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%D9&5D+@`E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E
M9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G
M<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G
M<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E
M(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I
M;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R
M('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@
M9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L
M96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S
M`#Q0<F5V:6]U<P!!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES
M(')E<75I<F5D`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@
M=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W
M97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)O=F4@<V5A<F-H(&9O<FT`06)S8F]T=&]M`$%B
M<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D96YI
M960@=&\@)7,`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D
M`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O
M=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O
M=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E
M<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U
M<V5R.@!!9&0@861D<F5S<R!B;V]K`$%D9"!A;F0@1&5L971E($E-4U`@861D
M<F5S<R!B;V]K<P!!9&0@8V]L=6UN`$%D9"!F:6QE`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1O`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R
M97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B
M=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO
M;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+@!!9&1I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92X`061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!
M9&1R97-S($)O;VL@3&ES=&EN9P!!9&1R97-S($)O;VMS`$%D9')E<W,@8F]O
M:R!E;G1R>0!!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"X`061D
M<F5S<R!B;V]K('1O(&1E;&5T92``061D<F5S<R!B;V]K<R!T:&%T('=I;&P@
M;F]T(&)E(&1I<W!L87EE9#H`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%D=F%N8V5D
M(%-E87)C:`!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI
M9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL
M($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@
M;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_`$%L<F5A9'D@17AI<W1S`$%L<F5A9'D@97AI<W1S`$%L=&5R
M;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R
M;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L
M=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A
M;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD
M($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A
M=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`
M07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F-H:79E($9I;&4@4VEZ90!!<F-H
M:79E($YA;64`07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E
M("5S/P!!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE
M('-E;&5C=&5D(&5N=')I97,_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_
M`$%R9V5N=&EN80!!<FUE;FEA`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS
M:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I
M8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@
M<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE
M9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`
M0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S
M=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`
M0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B
M)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R=7,`
M0F5L9VEU;0!"96QI>F4`0F5L;W<@<V5A<F-H(&9O<FT`0F5N:6X`0F5R;75D
M80!":'5T86X`0FEN9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`0FQO8VL@
M(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T
M=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E
M<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z
M:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R;W=S90!"<G5N
M96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@
M1F%S;P!"=7)U;F1I`$)U<VEN97-S($-A=&5G;W)Y`$--4P!#4D,`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C
M:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB
M;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R
M:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&0@82!G<F]U<"!T;R!I='-E;&8N
M`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RX`
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F
M:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E
M=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S
M(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@
M;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I
M;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;G1E<@!#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#
M:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN
M`$-H96-K(%]!;&PO3F]N90!#:&EL90!#:&EN80!#:&]O<V4@07!P;&EC871I
M;VXZ`$-H;V]S92!A(&YA;64`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@
M=7-E<FYA;64`0VAO;W-E(&%N(&%D9')E<W,@8F]O:P!#:&]O<V4@86X@861D
M<F5S<R!B;V]K.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S
M92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@
M=VAI8V@@861D<F5S<R!B;V]K<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O
M<F1E<CH`0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E+@!#:&]O
M<V4@=VAI8V@@8V]L=6UN<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R
M.@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y
M`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T
M80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@
M=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO
M=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`
M0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R
M`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN($]P=&EO;G,`0V]L=6UN
M('1I=&QE<P!#;VQU;6YS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.@!#
M;VUI8W,`0V]M;6$@<V5P87)A=&5D('9A;'5E<P!#;VUM82!S97!A<F%T960@
M=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RD`0V]M;6%N9`!#;VUM86YD(%-H
M96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!A
M;GD@061D<F5S<P!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC
M:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I
M9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M
M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D
M.B``0V]N;F5C=&EO;B!F86EL960Z("5S`$-O;FYE8W1I;VX@9F%I;'5R90!#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A
M<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M`$-O;G1A8W0@4V5A<F-H`$-O;G1A8W1S`$-O;G1A8W1S(&EN(&QI<W0Z("5S
M`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``
M0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE
M`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I
M8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O
M34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B
M:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E
M<G9E<@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R
M=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@
M`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L
M971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R
M97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N
M("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N
M`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B
M.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@
M(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B
M.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A
M=&4@061D<F5S<R!";V]K`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W($-O
M;G1A8W0@3&ES="!I;CH`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O
M;&1E<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D
M(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT
M(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT
M(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U
M<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WIE8V@@4F5P=6)L
M:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A
M5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV
M960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R
M`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A
M=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969A
M=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$969I;FET:6]N<P!$96QE=&4`1&5L
M971E($%D9')E<W,@0F]O:P!$96QE=&4@0V5L;`!$96QE=&4@0V]N9FER;6%T
M:6]N`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N
M`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&)U='1O;B!B96AA
M=FEO=7(`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!F86EL960Z("@E<RD@)7,`
M1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O
M=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L971I;F<@8V]N=&%C=',@:7,@;F]T
M(&%V86EL86)L92X`1&5L971I;VX@9F%I;&5D`$1E;&EV97)Y('1I;64`1&5N
M;6%R:P!$97!A<G1M96YT`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L
M96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I
M;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>0!$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES
M<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I
M`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'``1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R
M:65S/P!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M
M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A
M;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O
M=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O=VYL;V%D('9#87)D`$1R;W`@9&]W
M;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@(B5S
M(@!%9&ET($%D9')E<W,@0F]O:W,`161I="!";&]C:P!%9&ET($=R;W5P`$5D
M:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@96YT<GD@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z
M`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F
M;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`
M16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A
M=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`
M16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5N=')Y(&9O
M<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE(&9A
M:6QE9#H@)7,`16YT<GD@9F]R("5S('5P9&%T960N`$5Q=6%T;W)I86P@1W5I
M;F5A`$5R:71R96$`17)R;W(`17)R;W(@861D:6YG("5D(&-O;G1A8W0H<RD@
M=&\@;&ES="X`17)R;W(@861D:6YG("5D(&]F("5D(')E<75E<W1E9"!C;VYT
M86-T*',I('1O(&QI<W0N`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O
M<B!D96QE=&EN9R`E9"!C;VYT86-T*',I+@!%<G)O<B!D96QE=&EN9R`E9"!O
M9B`E9"!R97%U97-T960@8V]N=&%C=',H<RDN`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R
M;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!R96UO=FEN9R`E9"!C;VYT
M86-T*',I(&9R;VT@;&ES="X`17)R;W(@<F5M;W9I;F<@)60@;V8@)60@<F5Q
M=65S=&5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+@!%<G)O<B!S96%R8VAI;F<@
M=&AE(&%D9')E<W,@8F]O:SH@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z
M("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B
M)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD
M(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q
M=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X
M<&]R=`!%>'!O<G0@061D<F5S<R!";V]K`$5X<&]R="!O;FQY('1H92!S96QE
M8W1E9"!C;VYT86-T<RX`17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B
M;V]K(&-O;7!L971E;'DN`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!A8V-E
M<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,`1F%I;&5D('1O(&%D9"`E<R!T;R`E
M<SH@)7,`1F%I;&5D('1O(&)R;W=S92!L:7-T`$9A:6QE9"!T;R!B<F]W<V4@
M=&AE(&1I<F5C=&]R>0!&86EL960@=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[
M($]L9"!$3B`]("5S+"!.97<@1$X@/2`E<RP@4F]O="`]("5S`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE
M9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BX`1F%I;&5D('1O(&9I;F0@;V)J96-T('1O(&)E(&%D9&5D
M.B`E<P!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE
M=F4Z("5S`$9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:P!&86EL
M960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S`$9A:7(`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z
M`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&
M97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II
M`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE
M<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@
M=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QE<P!&:6QT
M97)S`$9I;F0`1FEN:7-H`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!.86UE
M`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U
M<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N
M97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC
M90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E8G5S>2!54DP`1G)E;F-H($=U
M:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O
M;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`
M1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N
M97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!'
M:79E;B!.86UE`$=L;V)A;"!!9&1R97-S($)O;VL`1V\`1V]E9&5L`$=O;V=L
M92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E;FQA
M;F0`1W)E;F%D80!'<F]U<`!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R
M:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE:6=H=`!(96QP`$AE;'`@
M=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($-I='D`
M2&]M92!#;W5N=')Y`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]M92!0
M;W-T86P@0V]D90!(;VUE(%-T871E+U!R;W9I;F-E`$AO;64@4W1R965T($%D
M9')E<W,`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!)
M;G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE
M(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@
M=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S
M:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`
M2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P
M;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M
M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU
M;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@
M)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`24U3
M4`!)35-0($%D9')E<W,@0F]O:R!!9&UI;FES=')A=&EO;@!)4"!!9&1R97-S
M`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N
M+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS
M(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM
M86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P
M;&]A9`!);6%G97,`26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9`!);7!O
M<G0L(%-T97`@)60`26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS`$EM<&]R
M=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F
M=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R
M96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`
M26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T
M(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@
M8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`
M26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T
M(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A
M<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A
M9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@
M26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N
M="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@240`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T
M80!);G9A;&ED(&%D9')E<W,@8F]O:P!);G9A;&ED(&%P<&QI8V%T:6]N+@!)
M;G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A
M;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@96UA:6P`26YV86QI
M9"!E;G1R>0!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@:V5Y('-P96-I
M9FEE9"X`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P
M<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!N86UE`$EN=F%L
M:60@;V)J96-T260`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI
M9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI
M<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O
M9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B
M`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N
M`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C
M=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)
M<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET
M86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F5R<V5Y`$IO<F1A
M;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U
M;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P
M(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@
M1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S
M`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC
M(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+=7=A:70`2WER9WEZ<W1A;@!,1$%0
M('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N
M;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N`$QA7WEO=70`3&%N9W5A9V4`
M3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA
M<W0@36]D:69I960`3&%S="!.86UE`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA
M<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@
M;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA
M=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE
M9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E
M<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H
M="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!2
M86EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,
M:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X
M($-O;VMI90!,:7-T`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,
M:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N
M:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO
M8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO
M9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@
M9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N
M(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC
M`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I
M80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA
M<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N
M9',`36%R=&EN:7%U90!-871C:&EN9P!-871C:&EN9R!F:65L9',`36%U<FET
M86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F($-O;G1A
M8W1S`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L
M96YG=&@`36%X:6UU;2!N=6UB97(@;V8@<&%G97,`36%Y`$UA>6]T=&4`365D
M:6-I;F4`365M8F5R<P!-96YU($QI<W0`365N=2!M;V1E.@!-97)G92!C96QL
M<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D
M+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D
M`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI
M;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R
M`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!$3B!I;B!,1$%0('-O=7)C92!C;VYF
M:6=U<F%T:6]N+@!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-
M:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K
M86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`
M36]B:6QE(%!H;VYE`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%52
M3`!-;V1I9GD@9F%I;&5D.B`H)7,I("5S`$UO9'5L=7,`36]L9&]V82P@4F5P
M=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H
M;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I
M;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)E('1H86X@,2!E
M;G1R>2!F;W5N9`!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y
M`$UO<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2
M:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E(&QE9G0`36]V92!R:6=H=`!-
M;W9E('5P`$UO>F%M8FEQ=64`375L8F5R<GD@061D<F5S<R!";V]K`$UU;'1I
M+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!P97)S;VYS('=I=&@@
M861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y
M(&5X:7-T`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U
M;G0@26YF;W)M871I;VX`37D@061D<F5S<R!";V]K`$UY($%D9')E<W,@0F]O
M:W,`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$
M;R!.3U0@06=R964`3F%M90!.86UE($9O<FUA=`!.86UI8FEA`$YA=7)U`$YE
M<&%L`$YE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y`$YE=&AE<FQA;F1S`$YE
M=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E
M($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T
M<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R
M`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!#;VYT86-T`$YE=R!-
M97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI
M`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E
M>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W
M:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H
M87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI8VMN86UE`$YI
M9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R`E<R!E;G1R>2!F;W5N9"!F
M;W(@)7,`3F\@861D<F5S<R!B;V]K<R!F;W5N9"X`3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@
M8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N`$YO(&-O;G1A8W1S(&9O=6YD`$YO(&-R961I="!L969T
M+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.
M;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO
M;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C
M:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T
M=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R
M>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T
M;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N
M`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE
M9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O
M<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D('-E;G0N`$YO('9#87)D(&1A=&$@=V%S(&9O=6YD+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E
M(&EM<&QI8VET*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO
M="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T
M('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@
M9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S
M`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!I=&5M<R!P97(@<&%G90!.
M=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R
M96%T;W(`3V)J96-T(&YO="!F;W5N9`!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@
M9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N`$]M86X`3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T
M:&4@861D<F5S<R!B;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E9"X@
M268@=&AI<R!I<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C
M:&%N9V4@>6]U<B!S96QE8W1I;VX@=&\@(DYO;F4B+@!/;FQY($E-05`@<V5R
M=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F
M;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@
M;VYE('9C87)D('-U<'!O<G1E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`
M3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I
M9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`
M3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET
M`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO
M;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`
M4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@
M4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E
M`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!0
M32!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N
M<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!0
M86QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!0
M87!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O
M<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN
M8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`
M4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@
M9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!0
M97)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`
M4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE
M9`!097)M:7-S:6]N(&1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`
M4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I;F4@061D<F5S<R!";V]K`%!I
M=&-A:7)N`%!I>&5L<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!N86UE
M('1H92!N97<@8V]N=&%C="!L:7-T.@!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X
M="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S
M>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L
M86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O
M8W5M96YT`%!R:79A=&4@061D<F5S<R!";V]K`%!R:79A=&4@2V5Y`%!R;V)L
M96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0
M=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF
M;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!1=65R>2!F86EL960Z
M("@E<RD@)7,`475I8VL@4V5A<F-H`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E
M9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,
M871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A
M;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!F86EL960Z("@E<RD@)7,`
M4F5A9"!M97-S86=E<P!296%D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B
M;&4N`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E86QL>2!D96QE=&4@=&AI<R!C;VYT86-T/P!296%L;'D@
M<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5C;W)D<R!D:7-P;&%Y960Z`%)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!A9&1R97-S(&)O;VL`4F5M;W9E(&-O
M;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@9G)O;2!T:&ES(&QI<W0`
M4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E
M<CH@)7,`4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@
M:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@9&5L971E<R!A
M;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R
M;VYG/@!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E
M<G)O<F-O9&4Z(`!297%U97-T960@;V)J96-T(&YO="!F;W5N9"X`4F5Q=65S
M=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!0
M87-S=V]R9`!297-E="!T;R!$969A=6QT<P!297-T;W)E($QA<W0@475E<GD`
M4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D
M`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A
M;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q
M.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O
M=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@
M365S<V%G90!3+TU)344@4'5B;&EC($-E<G1I9FEC871E`%-!4TP@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@
M4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U1!
M4E143%,@9F%I;&5D.B`H)7,I("5S`%-50T-%4U,`4U]13"!3:&5L;`!380!3
M86EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA
M`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-
M87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E
M<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P
M=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`4V%V:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B
M;&4N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@
M16YG:6YE<P!396%R8V@@9F%I;&5D`%-E87)C:"!F86EL960Z("5S`%-E87)C
M:&EN9R!I<R!N;W0@879A:6QA8FQE+@!396%R8VAI;F<N+BX`4V5L96-T($9I
M;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C
M="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T
M;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`
M4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4`4V5L96-T(&%N(&%D
M9')E<W,@8F]O:R!T;R!E9&ET`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO
M;F4`4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ`%-E
M;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SH`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F
M:6QE('1O(&EM<&]R=#H`4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C
M92!F:6QE.@!396QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@;F%M
M97,Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!3
M96QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R
M;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('9I97<@
M=&\@9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I
M;F<@;W!T:6]N<RX`4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P;&%Y(&EN
M('1H92!A9&1R97-S(&QI<W1S+@!396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I
M<W!L87D@;F%M97,N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396QE8W1E9"!A9&1R97-S(&)O
M;VL@(B5S(BX`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L
M`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R
M:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE
M+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`
M4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P
M;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I
M;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R
M86UE=&5R.B``4V5Y8VAE;&QE<P!3:&%R960@1&ER96-T;W)Y`%-H;W!P:6YG
M`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R`E<P!3:&]W($%L;`!3:&]W($-O
M;G1A8W1S`%-H;W<@3&ES=',`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U
M<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E
M<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y
M`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG
M;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO
M=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W
M97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R
M="!$:7)E8W1I;VX`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E
M<W,`4V]U<F-E<P!3;W5T:"!!9G)I8V$`4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN
M9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V86YC960@<V5A<F-H(')E
M<W5L=',@=&\@87!P96%R+@!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI
M="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A
M<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M
M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3
M=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3
M=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U
M8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO
M=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A
M<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&%D9&5D("5D(&-O
M;G1A8W0H<RD@=&\@;&ES="X`4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S
M`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T
M(&QI<W0@(B5S(BX`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S
M<V9U;&QY(&1E;&5T960@)60@8V]N=&%C="AS*2X`4W5C8V5S<V9U;&QY(')E
M;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+@!3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O
M=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U
M;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z
M(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A
M<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD
M`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M
M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8`5%-6(&9I
M;&4`5&%B('-E<&%R871E9"!V86QU97,`5&%B;&4`5&%B;&4@4')O<&5R=&EE
M<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S
M="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@
M;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@
M3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:6QA;F0`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-
M4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(%9&4R!B86-K
M96YD(&YE961S('1O(&)E(&-O;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE
M;G0@=7!L;V%D<RX`5&AE(&%D9')E<W,@8F]O:R`B)7,B(&1O97,@;F]T(&5X
M:7-T+@!4:&4@861D<F5S<R!B;V]K("(E<R(@=V%S(&-R96%T960@<W5C8V5S
M<V9U;&QY+@!4:&4@861D<F5S<R!B;V]K("(E<R(@=V%S(')E;6]V960@<W5C
M8V5S<V9U;&QY+@!4:&4@861D<F5S<R!B;V]K("(E<R(@=V%S('-U8V-E<W-F
M=6QL>2!U<&1A=&5D+@!4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P
M=7)G960Z("5S`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R
M92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT
M('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE
M(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N
M=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+@!4:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T
M+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&9I;&4@(B5S(B!H87,@<W5C8V5S<V9U;&QY(&)E96X@9&5L971E9"X`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL
M92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E
M<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N
M8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE(&EM<&]R="!C86X@8F4@9FEN:7-H960@9&5S<&ET92!T:&4@=V%R;FEN
M9W,N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E
M<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V
M960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP
M;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O
M;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V
M:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V
M960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4
M:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@
M8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E
M<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS
M(&%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I
M97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R!I<R!A;B!E<G)O<BP@
M<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@
M=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN
M9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@
M=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@
M`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L
M;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY
M('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N97<@
M8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R(&9O
M<B!F=7)T:&5R(&AE;'`N`%1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!A
M(&YE=R!L:7-T+@!4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A
M9&1R97-S(&)O;VLZ("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R`B
M)7,B(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O;VLN`%1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!L:7-T`%1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<P!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@861D<F5S<R!B
M;V]K.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R
M>3H@)7,`5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4:&5S
M92!A9&1R97-S(&)O;VMS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4
M:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F
M:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES
M(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N`%1H:7,@9F]R;2!H87,@
M86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A
M($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@
M>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G
M92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T
M:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92X`5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@
M861D<F5S<R!B;V]K`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP
M(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W
M:6QL(&)E('1H92!D969A=6QT(&%D9')E<W,@8F]O:R!W:&5N(&%D9&EN9R!O
M<B!I;7!O<G1I;F<@8V]N=&%C=',N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I
M;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4
M:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O
M9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`
M5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N
M9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K
M;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E
M('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E
M<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@;F5W('-H87)E+B!-:7-S:6YG('-O=7)C92!T>7!E+@!5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E
M("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE
M('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D
M(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN
M`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L
M:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G
M('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($-O
M;G1E;G0M5'EP93H@)7,`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5
M<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C
M<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E
M<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E
M<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E
M9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S
M97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`
M57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA
M;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A
M;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@
M;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A
M;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!6
M97)I<VEG;B!$:7)E8W1O<GD`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R
M=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(
M:6=H`%9I970@3F%M`%9I97<@(B5S(@!6:65W("5S`%9I97<@0V]N=&%C=`!6
M:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!T;R!D
M:7-P;&%Y(&)Y(&1E9F%U;'0Z`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I
M<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O
M9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@
M86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7
M96)S:71E(%523`!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE
M<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I
M9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@
M=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A
M<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7
M:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K($-I='D`5V]R:R!#;W5N
M=')Y`%=O<FL@4&AO;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K(%-T871E+U!R
M;W9I;F-E`%=O<FL@4W1R965T($%D9')E<W,`5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!9
M65E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B`B)7,B
M+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@
M=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N`%EO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N<R!T;R!D96QE=&4@=&AI<R!S;W5R8V4N`%EO=2!H
M879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO
M;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N
M`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C
M<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B
M;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R
M97-S(&)O;VLN`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+@!9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T
M('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="X`66]U(&UU<W0@
M<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO
M=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO
M=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@
M2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U
M<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I
M;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!A9&1R
M97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N`%EO=7(@9&5F875L="!I9&5N
M=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R
M(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E
M;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W
M90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;
M4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN
M97-=`%ML:6YE("5S(&]F("5S70!;;F\@=F%L=65=`%]!9&UI;FES=')A=&EO
M;@!?0G)O=W-E`%]#3$D`7T-O;G1A8W1S`%]$871A5')E90!?1&5L971E`%]$
M96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TEM<&]R="]%>'!O<G0`7TQI<W1S`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF
M>2!,:6YK+BXN`%]->2!!9&1R97-S($)O;VMS`%].97<@0V]N=&%C=`!?3W!T
M:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]296UO=F4@9G)O
M;2!T:&ES(&QI<W0`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N
M+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE
M;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P
M96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`
M8V]N9FEG=7)A=&EO;B!E<G)O<@!C;VYT86-T+G9C9@!C;VYT86-T<RYC<W8`
M8V]N=&%C=',N='-V`&-O;G1A8W1S+G9C9@!C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5N=')Y(&YO="!F;W5N9`!F
M86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG
M`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP
M=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S
M70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`
M;F%M90!N;R!F;W)M871T:6YG`&YO;F4`;F]T(&EM<&QE;65N=&5D`&YO="!Y
M970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N
M:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E
M<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@
M=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M
M<&]R87)Y(&9A:6QU<F4`=&\@82!#;VYT86-T($QI<W0`=&\@82!D:69F97)E
M;G0@061D<F5S<R!";V]K`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O
M;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E
M871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@,BXQ"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`V+3`Q+3,P(#(Q.C,P*S`Q,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-BTP,2TS,"`R,3HU-RLP,3`P"DQA<W0M5')A;G-L871O<CH@
M279A;B!.;W)I<R`\=FEX0'9A>FMA+G-K/@I,86YG=6%G92U496%M.B!3;&]V
M86L@/'9I>$!V87IK82YS:SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"`H<')E9"`E<R!D\F%M:2D`("A+
M;.%V97-O=N$@<VMR871K82`E<RD`("AO("5S(&1N[2D`*&1N97,I`"`H>F%J
M=')A*0`@*';H97)A*0`@4')I9&&[($E-4U`@861R97/A<@`@5GEM87IANR!)
M35-0(&%D<F5SX7(`('+]8VAL;W.[(``B)7,B('6^(&5X:7-T=6IE(&$@;F5B
M;VP@:6UP;W)T;W9A;OTN`"(E<R(@;FEE(&IE(&%D<F5SX7(N`"(E<R(@;FEE
M(&IE('!L871NX2!V;[5B82X`(B5S(B!N:64@:F4@;F%K;VYF:6=U<F]V86[I
M('8@<F5G:7-T<FD@2&]R9&4N`'IO8G)A>F]V8>@@<W1R;VUU("(E<R(@;F5B
M;VP@;N%J9&5N_2X`4VMU<&EN82`B)7,B(&)O;&$@<')I9&%NX2!D;R!S>7-T
MZ6UU+@!0<N%V;R`B)7,B(&)O;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+@`B)7,B
M(&YE8F]L('-K;W#M<F]V86[]+"!P<F5T;[YE(&IE('1O('IO>FYA;2X`(B5S
M(B!N96)O;&\@;6^^;ND@=GET=F]R:;LZ("5S+@`B)7,B(&YE8F]L('!R97-U
M;G5T_2P@<')E=&^^92!J92!T;R!Z;WIN86TN`")-96YO+"!0<FEE>G9I<VMO
M(B`H;F%P<BX@2F]H;B!$;V4I`")0<FEE>G9I<VMO+"!-96YO(B`H;F%P<BX@
M1&]E+"!*;VAN*0!0;W6^:73]8V@@)2XR9DU"('H@9&]V;VQE;OUC:"`E+C)F
M34(@*"4N,F8E)2D`)60@)7,@82`E<P`E9"!D;NT@9&\@=GEP<KEA;FEA('!L
M871N;W-T:2!6X;EH;R!H97-L82X`<')E9'!O=F7O(&YA("5D(&1N[0`E<R`M
M(%!O>F[A;6MA`$]D=&QAZ&]K("5S`"5S($M"`$]P97+A8VEE(/ID<KYB>2!P
M<F4@87!L:6OA8VEU("5S("T@4&]T=G)D96YI90!.87-T879E;FEE("5S`%)E
M9VES=')O=F%N:64@9&\@87!L:6OA8VEE("5S`%!O9&UI96YK>2!P;W6^:71I
M82`E<P`E<R!B;VPH82D@<')I9&%N_2CA*2X`)7,@=;X@97AI<W1U:F4N`"5S
M('9O(';]N6ME("5S("5S`%/Z8F]R("5S(&)O;"#Z<W!EN6YE(&EM<&]R=&]V
M86[]+@!!<&QI:^%C:6$@)7,@:F4@<')I<')A=F5NX2!N82!V>6MO;F%N:64@
M;W!E<N%C:>T@^F1ROF)Y+D]Z;F'H=&4@N71V;W+H96L@<')I(&]P97+A8VGA
M8V@L(&MT;W+I(&-H8V5T92!V>6MO;F&[('1E<F%Z+@!0;[YA9'5J92!S82`E
M<P`E<R!M:6[Z=``E<R!N96)O;"!NX6ID96[]+@`E<R!AOB`E<R!Z("5S`$%D
M<F5SX7(@)7,`2V%L96YDX7(@<&]UONUV871EM6$@)7,`4&]Z;N%M:WD@<&]U
MONUV871EM6$@)7,`6F]Z;F%M(/IL;V@@<&]UONUV871EM6$@)7,`)7,Z("5S
M`"5S.B!4X71O('-P<N%V82!N96UU<^T@8GF[(&]D(&]D;W-I96QA=&6U82P@
M:W1O<OT@<V$@>F]B<F%Z=6IE(&%K;R!O9&]S:65L871EM2!S<'+A=GDN(%IA
M8VAO=F%J=&4@;W!A=')N;W.[('!R:2!K;&EK86[M(&YA(&QI;FMY('8@<W!R
MX79E(&%L96)O('!O<VMY=&]V86[M(&]S;V)N_6-H(&EN9F]R;>%C:>T@;V1O
M<VEE;&%T9;5O=FDN`"P@;N%R87IO=OT@`"P@=B!NX7)A>F]C:"`E<R`E<P`L
M('!R96UE;F[A('8@<F]Z<V%H=2`E<R!AOB`E<P`M+2!V>6)E<G1E('-I("TM
M`#$R+6AO9&EN;W;](&9O<FWA=``R-"UH;V1I;F]V_2!F;W)MX70`,C0@:&]D
M[6X`/%!R961C:.%D>F%J^F-A`%!R96AL:6%D8>@@;75S[2!P;V1P;W)O=F&[
M(&E&<F%M97,`4')E('1E;G1O(&)L;VL@:F4@<&^^861O=F%N_2!D871A8N%Z
M;W;](&)A8VME;F0N`%9Y<VMY=&QA('-A('KA=F&^;N$@8VAY8F$`3F$@>F&Y
M:69R;W9A;FEE('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J;OT@4$A0(&NU
M^N@N`$YA(&]V97)E;FEE('!O9'#M<V%N96H@<W!RX79Y(&IE('!OOF%D;W9A
M;OT@=F5R96IN_2!01U`@:[7ZZ"X`3F$@9&6Y:69R;W9A;FEE('-P<N%V>2!S
M^B!P;W1R96)NZ3H@=F5R96IN_2!01U`@:[7ZZ"P@<')I=N%T;GD@4$=0(&NU
M^N@@82!H97-L;RX`3F$@<&]D<.US86YI92!S<'+A=GD@<_H@<&^^861O=F%N
MZ3H@=G)E:F[](%!'4"!KM?KH+"!P<FEVX71N>2!01U`@:[7ZZ"!A(&AE<VQO
M+@!.82!D9;EI9G)O=F%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J
M;OT@4R]-24U%(&NU^N@L('!R:7;A=&YY(%,O34E-12!KM?KH(&$@:&5S;&\N
M`$YA('!O9'#M<V%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@
M4R]-24U%(&NU^N@L('!R:7;A=&YY(%,O34E-12!KM?KH(&$@:&5S;&\N`$YA
M('IAN6EF<F]V86YI92!S<'+A=GD@:F4@<&^^861O=F%N_2!V97)E:F[](%--
M24U%(&NU^N@N`%!R961P;VQU9&[M;2!O8FQAZ&YO`%!R961P;VQU9&[M;2"U
M86AK_2!DX;[O`%!R961P;VQU9&[M;2!DX;[O`%!R961P;VQU9&[M;2!P<F5H
MX6YK>0!0<F5D<&]L=61N[6T@<VYE:&]VZ2!P<F5HX6YK>0`Q,B!H;V3M;@!!
M4$D@240`3R!T;VUT;R!E9&ET;W)E`$\N+BX`3F%D(&9O<FUU;.%R;VT@:+5A
M9&%N:6$`06)S;VSZ=&YY('-P;V1O:P!!8G-O;/IT;GD@<W1R960`4')I('9Y
M=';A<F%N[2!61E,@861R97/A<F$@8F]L('IA;6EE=&YU=/T@<'+M<W1U<"X`
M4')I('9Y=';A<F%N[2!61E,@<_IB;W)U(&)O;"!Z86UI971N=73]('!R[7-T
M=7`N`%!R[7-T=7`@:R`E<R!J92!Z86UI971N=73]`$EN9F]R;>%C:64@;R#Z
MZ'1E`$AE<VQO('!R92#ZZ&5T`-KH970@>F%B;&]K;W9A;OTN`-KH=&]V86YI
M90!0<FED8;L`4')I9&&[('!O9')I861E;OH@<VMU<&EN=0!0<FED8;L@<&]D
M<FEA9&5NZ2!P<N%V;P!0<FED8;LZ`%!R:61ANR!S:W5P:6YU`%!R:61ANR!N
M;W;I('!RX79O`%!R:61ANR!D8^ER<VMU('-K=7!I;G4@9&\@(B5S(@!0<FED
M8;L@9&/I<G-K92!P<N%V;R!D;R`B)7,B`%!R:61ANR!P;W6^[79A=&6U83H`
M4')I9&&[(&%D<F5SX7(`4')I9&&[(&$@=GEM87IANR!)35-0(&%D<F5SX7)E
M`%!R:61ANR!S=.5P96,`4')I9&&[('/Z8F]R`%!R:61ANR#H;&5N;W8`4')I
M9&&[('#A<@!0<FED8;L@;65N=2`E<R!A:V\@0F_H;OT@<&%N96P@36]Z:6QL
M>0!0<FED8;L@9&\`4')I9&&[(&1O(&%D<F5SX7)A.@!0<FED8;L@9&\@;?1J
M:&\@861R97/A<F$`4')I9&&[('!O=;[M=F%T9;5A`"(E<R(@8F]L('!R:61A
M;OT@9&\@<WES=.EM=2P@86QE(&YE;6^^;F\@<')I9&&[(.]A;+EI92!P<FEH
M;&%S;W9A8VEE(&EN9F]R;>%C:64Z("5S+@`B)7,B(&)O;"!P<FED86[](&1O
M('-Y<W3I;74N(%1E<F%Z('-A(&WTOF5T92!P<FEH;.%S:;LN`%!R:63A=F%N
M:64@:V]N=&%K=&]V(&YI92!J92!D;W-T=7!NZ2X`4')I9.%V86YI92!P;W6^
M[79A=&6U;W8@:F4@>F%KX7IA;NDN`$%D<F5S80!!9')E<^%R`%IO8G)A>FF[
M(&%D<F5SX7(`061R97/A<F4`4&]L;[YK82!A9')E<^%R80!!9')E<^%R(&)O
M;"#Z<W!EN6YE('9Y;6%Z86[]+@!!9')E<^%R92!N82!V>6UA>F%N:64`061R
M97/A<F4L(&MT;W+I('-A(&YE8G5D^B!Z;V)R87IO=F&[.@!!9&UI;FES='+A
M8VEA("T@;F%S=&%V96YI92!P<N%V('!R92!I;OUC:"!P;W6^[79A=&6U;W8`
M061M:6YI<W1RX6-I80!296ML86UY`%)O>KGM<F5NZ2!V>6BU863A=F%N:64`
M069G86YI<W1A;@!!;&+A;G-K;P!!;+[M<G-K;P!!;&EA<P!:87)O=FYANP!:
M87)O=FYA;FEE.@!6N65T:WD`5KEE=&-I(&%U=&5N=&EF:6MO=F%N[2!P;W6^
M[79A=&5L:6$`5KEE=&MY('-K=7!I;GD`5KEE=&MY('!RX79A`%:Y971K>2"Y
M='ER:2!S=')A;GD`4&]V;VQINR!V:6%C97+I(&%D<F5S>0!0;W9O;&F[(&YA
M<W1A=F5N:64@='EP=2!Z;W)A9&5NZ6AO('IO>FYA;74_`%6^(&5X:7-T=6IE
M`%6^(&5X:7-T=6IE`$%L=&5R;F%T[79N92!P<FEH;&%S;W9A8VEE(&UE;F\@
M24U34`!!;'1E<FYA=.UV;F4@:&5S;&\@24U34`!!;'1E<FYA=.UV;F4@<&]U
MONUV871EM7-KZ2!M96YO($E-4U``06QT97)N873M=FYA(&4M;6%I;&]VX2!A
M9')E<V$`06QT97)N873M=FYE(+EA8FSS;GD`06QT97)N873M=FYY('1E>'0Z
M`$%M97)I8VOA(%-A;6]A`$)O;&$@>F%D86[A(&YE<&QA=&[A(&AO9&YO=&$`
M3F%S=&%L82!N97INX6UA(&-H>6)A+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL
M80!!;F]N>6UNZ2!P<F]X>0!/9'!O=F7O`$%N=&%R:W1I:V$`06YT:6=U82!A
M($)A<F)U9&$`07!L:6OA8VEA`%IO>FYA;2!A<&QI:^%C:>T`07!L:6OA8VEA
M(&IE('!R:7!R879E;N$N`$%P;&EK;W9ANR!N82!P;V1R:6%D96[I('ID:66U
M86[I('!R:67H:6YK>0!38VAVX6QINP!0<FEB;&F^;N$@=F6U:V]SNP!!<'+M
M;`!69;5K;W.[(&%R8VCM=G4`365N;R!A<F-H[79U`$YA;WIA:B!C:&-E=&4@
M>FUA>F&[("5S/P!.86]Z86H@8VAC971E('9Y;6%Z8;L@=GEB<F%NZ2!A9')E
M<WD_`$YA;WIA:B!C:&-E=&4@=GEM87IANR"^:6%D;W.[(&\@<')I:&SA<V5N
M:64@)R5S)S\`3F%O>F%J(&-H8V5T92!V>6UA>F&[("(E<R(@82!VN65T:WD@
M<&]D<VMU<&EN>3\`07)G96YT[6YA`$%R;>EN<VMO`%5M96YI90!!<G5B80!6
M>F]S='5P;F4`3W-T<F]V($%S8V5N<VEO;@!!<V-I:2!U;65N:64`P7II82]0
M86-I9FEC:_T@<F5G:?-N`%9YOF%D;W9ANR!P;W1V<F1E;FEE('!R960@=GEK
M;VYA;NUM(&]P97+A8VGM(/ID<KYB>3\`4&]K=7,@;R!V>6UA>F%N:64@;F5E
M>&ES='5J^F-E:B!S:W5P:6YY+@!0;VMU<R!O('9Y;6%Z86YI92!N965X:7-T
M=6KZ8V5H;R!P<N%V82X`4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J^F-E:&\@
M<'+A=F$N`%!O:W5S(&\@^G!R879U(&YE97AI<W1U:OIC96AO('ID:66U86[I
M:&\@;V)J96MT=2X`071R:6+Z='D`075G=7-T`$%U<W1RX6QI80!286OZ<VMO
M`$%U=&A?8WER<W%L.B!0;[YA9&]V86[I(')O>KGM<F5N:64@:6UA<"!N96)O
M;&\@;N%J9&5NZ2X`075T:%]C>7)U<SH@8F%C:V5N9"!N96WA('!OOF%D;W9A
M;ND@<V-H;W!N;W-T:2X`075T:%]C>7)U<SH@<&^^861O=F%NZ2!R;WJY[7)E
M;FEE(&EM87`@;F5B;VQO(&[A:F1E;NDN`$%U=&A?9G1P.B!P;[YA9&]V86[I
M(')O>KGM<F5N:64@1E10(&YE8F]L;R!NX6ID96[I+B!3:V]M<&EL=6IT92!0
M2%`@<R!P<F5P[6YAZ&]M("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!P;[YA
M9&]V86[I(')O>KGM<F5N:64@24U!4"!N96)O;&\@;N%J9&5NZ2X`075T:%]K
M<F(U.B!P;[YA9&]V86[I(')O>KGM<F5N:64@:W)B-2!N96)O;&\@;N%J9&5N
MZ2X`075T:%]L9&%P.B!P<FEDX79A;FEE('!O=;[M=F%T9;5O=B!N:64@:F4@
M<&]D<&]R;W9A;ND@<')E($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!V
M>6UA>N%V86YI92!P;W6^[79A=&6U;W8@;FEE(&IE('!O9'!O<F]V86[I('!R
M92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@<&^^861O=F%NZ2!R;WJY
M[7)E;FEE($Q$05`@;F5B;VQO(&[A:F1E;NDN`$%U=&A?;&1A<#H@3F5P;V1A
M<FEL;R!S82!P<FED8;L@<&]UONUV871EM6$@)7,N(%-E<G9E<B!O9'!O=F5D
M86PZ(`!!=71H7VQD87`Z(&YE<&]D87)I;&\@<V$@;V1S='+A;FF[('!O=;[M
M=F%T9;5A("5S`$%U=&A?;&1A<#H@;F5P;V1A<FEL;R!S82!A:W1U86QI>F]V
M8;L@<&]UONUV871EM6$@)7,`075T:%]L9&%P.B!A:W1U86QI>N%C:6$@<&]U
MONUV871EM6]V(&YI92!J92!P;V1P;W)O=F%NX2!P<F4@06-T:79E($1I<F5C
M=&]R>0!!=71H7VUC86PZ('!OOF%D;W9A;ND@<F]ZN>UR96YI92!-0T%,(&YE
M8F]L;R!NX6ID96[I+@!!=71H7W-M8F%U=&@Z('!OOF%D;W9A;ND@<F]ZN>UR
M96YI92!S;6)A=71H(&YE8F]L;R!NX6ID96[I+@!!=71E;G1I9FEKX6-I82!P
M;VUO8V]U($E-05`@<V5R=F5R82!Z;'EH86QA+@!!=71E;G1I9FEKX6-I82!Z
M;'EH86QA`$%U=&5N=&EF:6OA8VEA('IL>6AA;&$N("5S`%-E<G9E<B!2041)
M55,@>F%M:65T;VP@875T96YT:69I:^%C:74N`$%U=&5N=&EF:6OA8VEA('!O
M;6]C;W4@1E10('-E<G9E<F$@>FQY:&%L82X`075T96YT:69I:^%C:6$@<&]M
M;V-O=2!334(@<V5R=F5R82!Z;'EH86QA+@!$;W-T=7!NZ2!P;VQOOFMY.@!!
M>F5R8F%J9+YA;@!"3T9(($5X8W5S97,`4&]Z861I90!&87)B82!P;WIA9&EA
M`%ILZ2!H97-L;R!P<F4@:V5R8F5R;W,N`%ILZ2!P;W6^[79A=&6U<VOI(&UE
M;F\@<')E(&ME<F)E<F]S+@!"86AA;7D`0F%H<F%J;@!"86YG;&%DZ;D`0F%R
M8F%D;W,`4')I9>AI;F]K(',@9W)A9FEK;W4@(B5S(B!N96)O;"!NX6ID96[]
M+@!:X6ML861N_2!R:6%D;VL`6N%K;&%D;ND@:+5A9&%N:64`0FEE;&]R=7-K
M;P!"96QG:6-K;P!"96QI>F4`4&]D(&9O<FUU;.%R;VT@:+5A9&%N:6$`0F5N
M:6X`0F5R;75D>0!"=73A;@!0<FEP;VIE;FEE("AB:6YD*2!Z;'EH86QO.B`H
M)7,I("5S`$YA<F]D96YI;GD`0FQO:R`B)7,B(&%P;&EKX6-I92`B)7,B(&YE
M8F]L(&[A:F1E;OTN`$YA<W1A=F5N:6$@8FQO:W4`5'EP(&)L;VMU`%1UZ&[I
M`$)O;.UV:6$`6N%L;[YK>0!/:W)A:@"I[7)K82!O:W)A:F$Z`$]K<F%J90!"
M;W-N82!A($AE<F-E9V]V:6YA`$]B90!";W1S=V%N80!";W1T;VT`0F]U=F5T
M($ES;&%N9`!"<F%Z[6QI80!"<FET<VOI(/IZ96UI92!V($EN9&EC:V]M(&]C
M9>%N90!0<F5Z97)ANP!"<G5N96D@1&%R=7-S86QA;0!"=6QH87)S:V\`6F]Z
M;F%M(',@;V1RX;YK86UI`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$]B8VAO9&[I
M('IA;65R86YI90!#35,`0U)#`$1I<W1R:6)UZ&[I(&)O9'D@0U),`$-35B`H
M:&]D;F]T>2!O9&1E;&5NZ2#H:6%R:V]U*0!6;&%S=&YO<W1I(%]B=6YK>2XN
M+@!);F-I86QI>N%C:6$@=GER;W9NX79A8V5J('!A;>1T:2!N96)O;&$@9&]K
M;V[H96[A+@!+86QE;F3A<@!"97IV971R:64`2V%M8F]DOF$`2V%M97)U;@!.
M97!O9&%R:6QO('-A(&%U=&]M871I8VMY(&]B;F]V:;L@:&5S;&\L(&MO;G1A
M:W1U:G1E('-V;VIH;R!A9&UI;FES='+A=&]R82X`3F5P;V1A<FEL;R!S82!Z
M87#M<V&[(&1O('/Z8F]R=2`B)7,B`$YE;6^^;F\@<')I9&&[('-K=7!I;G4@
M9&\@<V%M96H@<V5B82X`3F5M;[YN;R!A9&UI:7-T<F]V8;L@97AT97)NZ2!O
M=FSA9&'H92!S961E;NTN`$YE<&]D87)I;&\@<V$@<W!O:FF[(',@24U!4"!S
M97)V97)O;3H@)7,`3F5P;V1A<FEL;R!S82!O='9O<FF[('/Z8F]R("(E<R(N
M`$MA;F%D80!:<G6Y:;L`6G)UN6F[('-P<N%V=2!O('!R;V)LZ6UE`$YE<&]D
M87)I;&\@<V$@=GEM87IANR!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A(&[A
M:G.[(&1OZ&%S;OT@861R97/A<BX`3F5M;[YN;R!P;VMR8>AO=F&[(&)E>B!P
M87)A;65T<F$@)W1A<F=E=$9I;&4G+@!.97!O9&%R:6QO('-A(&]D<W1RX6YI
MNR!A9')E<^%R("(E<R(N`$YE;6^^;F\@;V1S='+A;FF[+"!E>&ES='5J92`E
M9"!N87-L961O=F[M:V]V+@!.96UOOFYO('!R975S<&]R:6%D8;LL('!OZ&5T
M('!O;&^^:65K('!R92!P<F5U<W!O<FEA9&%N:64@;F5S^FAL87/M(',@<&_H
M=&]M('5L;[YE;OUC:"!P;VQOOFEE:RX`3F5P;V1A<FEL;R!S82!S;65R;W9A
MNR!S<'+A=G4@;F$@=7+H96[I(.CM<VQO+@!+87!V97)D<VOI(&]S=')O=GD`
M5&ET=6QO:P!+871E9_-R:64@82!P;W!I<VMY`$MA:FUA;G-KZ2!O<W1R;W9Y
M`$UO8FEL;OT@=&5L96;S;@!6;&%S=&YO<W1I(&)U;FMY`%9Y<&QN96YI92!B
M=6YK>3H`5FQA<W1N;W-T:2!B=6YK>0!2;WIO<W1U<"!B=6YI96LZ`$UO8FEL
M;OT@=&5L96;S;@!$;R!S=')E9'4`4W1R961O869R:6-KX2!R97!U8FQI:V$`
M4&]D<F]B;ND@:6YF;W)MX6-I92!O(&-E<G1I9FEKX71E`%9L87-T;NUK(&-E
M<G1I9FEKX71U`%!O;&ET:6MY('!R92!C97)T:69I:^%T>0#(860`6FUE;FF[
M`%IM96YINR!68;EE(&AE<VQO`$YA<W1A=F5N:64@;65N82!A(&%D<FEE<RP@
M:W1O<ND@=FED:6$@M75D:6$L(&ME[R#H[71A:OH@82!O9'!O=F5D86KZ(&YA
M(%9AN64@92UM86EL>2X`6FUE;F$@:&5S;&$@;FEE(&IE('8@86MT=>%L;F5J
M(&MO;F9I9W5RX6-I:2!P;V1P;W)O=F%NX2X@($MO;G1A:W1U:G1E('-V;VIH
M;R!A9&UI;FES='+A=&]R82X`6FYA:P!37VMO;G1R;VQO=F&[(&QI;FMU+BXN
M`%9Y8G)ANR!?=KEE=&MY+[YI861N90!#:&EL90#([6YA`%9Y8F5R=&4@87!L
M:6OA8VEU.@!6>6)E<G1E('-I(&UE;F\`6G9OM71E('-I(&AE<VQO`%IV;[5T
M92!S:2!P;W6^[79A=&6U<VOI(&UE;F\`5GEB97)T92!S:2!A9')E<^%R`%9Y
M8F5R=&4@<VD@861R97/A<CH`5GEB97)T92!S</1S;V(@>F]B<F%Z;W9A;FEA
M(&3A='5M;W8Z`%9Y8F5R=&4@='EP(+ET_6QU('IO>FYA;74@*'!R92!Z;W)A
M9&5NZ2!Z;WIN86UY*0!6>6)E<G1E('-I(&%D<F5SX7)E+"!K=&]RZ2!C:&-E
M=&4@>F]B<F%Z:;L@82!I8V@@<&]R861I93H`5GEB97)T92!S:2!A9')E<^%R
M92P@:W1O<ND@8VAC971E('!O=;YINRX`5GEB97)T92!S=.5P8V4L(&MT;W+I
M(&-H8V5T92!Z;V)R87IINR!A(&EC:"!P;W)A9&EE.@!6:6%N;^AN_2!O<W1R
M;W8`1&5F:6[M8VEA('1R:65D>2`E<R!N96)O;&$@;N%J9&5NX2X`2F%S;F\`
M3V1S='+A;FF[('!R[6MA>GD@35-/9F9I8V4`5GEM87IANR!D;W1A>@!/9'-T
M<N%N:;L@<&]UONUV871EM6$Z("5S`$]D<W1RX6YINR!P;W6^[79A=&6U80!6
M>6UA>F&[('!O=;[M=F%T9;5S:^D@^F1A:F4`3F5S:_1R('9Y:F%S;F5N:64`
M2VQI:VYI=&4@<')E('!O:W)AZ&]V86YI90!#;&EC:V%T96QL(&-E>B!(5%10
M`%IA='9O<FF[(&]K;F\`3V)L86MY`%+A;F\@;V)L8>AN;P!/8FQAZ&YO`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`%IB86QINR!";^AN_2!P86YE;`!:8F%L
M96[I(&]K<F%J90!+;VQU;6)I80!&87)B80!6_6)E<B!F87)B>0!6_6)E<B!F
M87)B>0!3=.5P8V4Z`$YA<W1A=F5N:6$@<W3E<&-O=@!.861P:7-Y('-TY7!C
M;W8`4W3E<&-E+"!K=&]RZ2!S82!N96)U9/H@>F]B<F%Z;W9ANSH`2V]M:6MS
M`$AO9&YO='D@;V1D96QE;ND@Z&EA<FMO=0!(;V1N;W1Y(&]D9&5L96[I(.AI
M87)K;W4@*$UI8W)O<V]F="!/=71L;V]K*0!0<NUK87H`4'+M:V%Z;W;](&EN
M=&5R<')E=&5R`$MO;65N=.%R`$)EOF[I(&UE;F\`2V]M;W)Y`%-P;VQOZ&YO
M<[L`061R97-A('-P;VQOZ&YO<W1I`%!OZ.UT8>AE`%-T878`4W1A=@!2;WID
M:65L>2!V(&MO;F9I9W5RX6-I:0!+;VYF:6=U<N%C:6$@<')E('-Y;F-H<F]N
M:7KA8VEU(',@4$1!+"!I;G1E;&EG96YT;OUM:2!T96QE9O-N;6D@82!/=71L
M;V]K;VTN`$MO;F9I9W5RX6-I82!P;W1R96)U:F4@86MT=6%L:7KA8VEU+@!+
M;VYF:6=U<F]V8;L@)7,`4&]T=G+O=&4@:&5S;&\`2V]N9V\`1&5M;VMR871I
M8VOA(')E<'5B;&EK82!+;VYG;P!3<&]J96YI92!Z;'EH86QO+@!3<&]J96YI
M92!Z;'EH86QO.B``4&]K=7,@;R!S<&]J96YI92!Z;'EH86PZ("5S`$YA<W1A
M;&$@8VAY8F$@<')I('!O:W5S92!O('-P;VIE;FEE`$NU^N@@8F]L('IA;6EE
M=&YU=/T@<V5R=F5R;VT@=F5R96IN_6-H(&NU^NAO=BX`2[7ZZ"!B;VP@>F%M
M:65T;G5T_2!S97)V97)O;2!V97)E:F[]8V@@:[7ZZ&]V+B!$]'9O9#H@)7,@
M*"5S*0!3<&]J96YI92!S($944"!S97)V97)O;2!Z;'EH86QO+@!(M6%D86YI
M92!K;VYT86MT=0!+;VYT86MT>0!+;VYT86MT>2!V('IO>FYA;64Z("5S`$MO
M;G1A:W1Y(&)O;&D@^G-P9;EN92!V;&^^96[A(&1O(%;AN6AO(&%D<F5SX7)A
M+@!4>7`@:V]M<')I;6]V86[I:&\@<_IB;W)U.@!/8G-A:"`B)7,B`%!O:W)A
MZ&]V8;L`0V]O:V]V92!O<W1R;W9Y`$-O;VMI90!+;W#M<F]V8;L`2V]P[7)O
M=F%N:64@>FQY:&%L;SH@)7,`2V]P[7)O=F&[(';]8F5R`$MO<W1A<FEK80!0
M;V)R9;YI92!S;&]N;W9I;GD`3F5P;V1A<FEL;R!S82!Z8;EI9G)O=F&[('-P
M<N%V=2!P;VUO8V]U(%!'4#H@`$YE<&]D87)I;&\@<V$@<&]D<.US8;L@<W!R
MX79U('!O;6]C;W4@4$=0.B``3F5P;V1A<FEL;R!S82!Z8;EI9G)O=F&[('-P
M<N%V=2!P;VUO8V]U(%,O34E-12X`3F5P;V1A<FEL;R!S82!P;V1P[7-ANR!S
M<'+A=G4@<&]M;V-O=2!3+TU)344N`$YE<&]D87)I;&\@<V$@<')I9&&[(&MO
M;G1A:W0N("5S+@!.97!O9&%R:6QO('-A('!R:7!O:FF[(&L@3$1!4"!S97)V
M97)U+@!.97!O9&%R:6QO('-A('!R:7!O:FF[(&L@3$1!4"!S97)V97)U`$YE
M<&]D87)I;&\@<V$@;W9E<FF[('IO<W1A=&]K(&YA(/KH=&4N("5S`$YA<W1A
M;&$@8VAY8F$@<')I('!R[7-T=7!E(&L@3$1!4"!S97)V97)U`$YE<&]D87)I
M;&\@<V$@<')I<&]J:;L@:R!S97)V97)U("(E<R(@<&]M;V-O=2!&5%`Z("5S
M`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,`
M3F5P;V1A<FEL;R!S82!D9;EI9G)O=F&[(%!'4"#Z9&%J93H@`$YE<&]D87)I
M;&\@<V$@9&6Y:69R;W9ANR!3+TU)344@^F1A:F4N`$YE<&]D87)I;&\@<V$@
M=GEM87IANR!K;VYT86MT+B`E<P!.97!O9&%R:6QO('-A('9Y;6%Z8;L@>F]Z
M;F%M('!R[6IE;6-O=BX@)7,`3F5P;V1A<FEL;R!S82!V>6UA>F&[('-K<FEP
M="!N82!U<&=R861E(&MO;F9I9W5RX6-I92`B)7,B+@!.97!O9&%R:6QO('-A
M('5RZ&F[(&4M;6%I;&]V^B!A9')E<W4@<'+M:F5M8W4N`$YE<&]D87)I;&\@
M<V$@<W1I86AN=;L@8V5L_2!A9')E<^%R+@!.97!O9&%R:6QO('-A('KM<VMA
MNR!K;VUP;&5T;OT@>F]Z;F%M('!R[6IE;6-O=BX`3F5P;V1A<FEL;R!S82!Z
M[7-K8;L@:V]M<&QE=&[]('IO>FYA;2!Z;WIN86UO=B!P<NUJ96UC;W8N`$YE
M<&]D87)I;&\@<V$@;F'H[71ANR!S=')A=.EG:74@(B5S(BX`3F5P;V1A<FEL
M;R!S82!S<'5S=&F[(&UK9&ER("(E<R(N`$YE<&]D87)I;&\@<V$@>NUS:V&[
M('9E<F5J;OT@:[7ZZ"!Z;R!S97)V97)A(&NU^NAO=BX`3F5P;V1A<FEL;R!S
M82!O='9O<FF[("(E<R(@<')E('KA<&ES+@!.97!O9&%R:6QO('-A(&]T=F]R
M:;L@)7,N`$YE<&]D87)I;&\@<V$@;W1V;W)INR!M;V1U;"!-86EN=&5N86YC
M95]487-K("5S`$YE<&]D87)I;&\@<V$@;W1V;W)INR!A9')E<^%R("(E<R(N
M`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@;F$@3$1!4"!S97)V97(N`$YE<&]D
M87)I;&\@<V$@<')EZ.UT8;L@)7,N`$YE<&]D87)I;&\@<V$@;V)N;W9INR!H
M97-L;R!Z861A;NEH;R!P;W6^[79A=&6U82X@3FEE:W1O<ND@86QE8F\@=KEE
M=&MY('!O9')O8FYO<W1I(&YI92!S^B!S<'+A=FYE+B!3:_IS=&4@=&\@>FYO
M=G4@86QE8F\@:V]N=&%K='5J=&4@5N&Y:&\@861M:6YI<W1RX71O<F$L(&%K
M('!O=')E8G5J971E('!O;6]C+@!.96UOOFYO('KM<VMANR!!0TP`3F5P;V1A
M<FEL;R!S82!Z[7-K8;L@861R97/A<BX@)7,`3F5P;V1A<FEL;R!S82!Z[7-K
M8;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,`3F5P;V1A<FEL;R!S82!Z[7-K8;L@
M>F]Z;F%M>2!P<NUJ96UC;W8@)7,`3F5M;[YN;R!Z[7-K8;L@:6YF;W)MX6-I
M92!O('9L87-T;F]S=&EA8V@@<V5R=F5R80!.97!O9&%R:6QO('-A('9RX71I
MNR!K;VYF:6=U<N%C:74N`$YE<&]D87)I;&\@<V$@<W!U<W1INR!R;61I<B`B
M)7,B+@!.97!O9&%R:6QO('-A('5L;[YINR!K;VYF:6=U<N%C:74@)7,N`$YE
M<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K;VYF:6=U<N%C:64N`$YE<&]D
M87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K;VYF:6=U<N%C:64Z("5S`$YE<&]D
M87)I;&\@<V$@=6QOOFF[('-K<FEP="!N82!U<&=R861E(&YA<W1A=F5N[2!D
M;SH@(B5S(BX`3F5P;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5R
MX6-I92`E<RX`3F5P;V1A<FEL;R!S82!Z87#M<V&[(&MO;F9I9W5R8>AN_2!S
M^F)O<B`E<RX@3?2^971E('!O=;YINR!N:65K=&]R^B!Z(&UOOFYO<W3M(&YA
M('KA<&ES(&OS9'4@;F$@)7,@86QE8F\@<VMO<.UR;W9ANR!R=>AN92!K\V0@
M=79E9&5N_2!N:;ZY:64@9&\@)7,N`$YE<&]D87)I;&\@<V$@:+5A9&&[(&YA
M($Q$05`@<V5R=F5R:2X`3F5P;V1A<FEL;R!S82!V>6UA>F&[("(E<R(N`$YE
M<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[(&MO;G1A:W0N("5S`$YE<&]D87)I
M;&\@<V$@86MT=6%L:7IO=F&[('IO>FYA;2!P<NUJ96UC;W8N("5S`$YE<&]D
M87)I;&\@<V$@>F%P[7-ANR!K;VYF:6=U<N%C:74@<')E("(E<R(Z("5S`$YE
M;6^^;F\@;N%J<[L@0F_H;OT@<&%N96P@36]Z:6QL>2X@4VMO;G1R;VQU:G1E
M+""^92!J92!P86YE;"!O='9O<F5N_2X`4&]UONUV871EM6]V:2`B)7,B('-A
M(&YE<&]D87)I;&\@<')I9&&[('!RX79A('!R92!P<FEEZ&EN;VL@(B5S(CH@
M)7,`4&_H[71A;OT@=&5X=`!+<F%J:6YA`$MU<GIY`%9Y='9O<FF[`%9Y='9O
M<FF[(&%D<F5SX7(`5GET=F]R:;L@;&EN:W4`5GET=F]R:;L@;F]V_2!Z;WIN
M86T@:V]N=&%K=&]V('8Z`%9Y='9O<FF[(&YO=OT`5GET=F]R:;L@<&]D<')I
M9>AI;F]K`%9Y='9O<F5NZ0!0<N%V82!T=F]R8W4`R.US;&\@:W)E9&ET;F5J
M(&MA<G1Y`$-H;W)VX71S:V\`2W5B80!!:W1UX6QN92`T(&;A>GD`06MT=>%L
M;F4@<V5D96YI80!!:W1UX6QN>2#H87,`06MT=>%L;F$@55),(&IE`$%K='7A
M;&YI('!O=;[M=F%T96QI80!!:W1UX6QN92!P;^AA<VEE`$%K='7A;&YE('!O
M9&UI96YK>3H@`$%K='7A;&YY(+ET_6P`3F%S=&%V96YI92#Z;&]H+"!K=&]R
MZ2!S82!S</JYNV%J^B!P<FD@<')I:&SA<V5N[2!D;R!A<&QI:^%C:64@)7,N
M`%9Y<W1R:6AN^KL`5GES=')I:&[ZNR!V_6)E<@!#>7!R=7,`R&5S:^$@<F5P
M=6)L:6MA`$1$`$133B`H<&]Z<FD@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$96YN
M90!0<F5Z97)AZ"!DX71O=NEH;R!S=')O;74@*$1A=&%4<F5E*0!6>6BU863A
M=F%N:64@=B!D871A8N%Z90!$X71U;0!$X71U;2!P<FEJ871I80!6_6)E<B!D
MX71U;74`1&7R`$]?9'-T<N%N:;L@<W3E<&5C`$1E8V5M8F5R`$1E<VEA=&MO
M=ND@Z.US;&$`6FUE;KEINR!O9'-A9&5N:64`4')E9&YA<W1A=F5NZ0!0<F5D
M;F%S=&%V96[A(&9A<F)A`%9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET80!0
M<F5D;F%S=&%V96[]('!R[6MA>F]V_2!I;G1E<G!R971E<@!0<F5D;F%S=&%V
M96[]('-M97(@=')I961E;FEA.@!$969I;NUC:64`5GEM87IANP!6>6UA>F&[
M(&%D<F5SX7(`5GEM87IANR!B=6YK=0!0;W1V<F1E;FEE('!R:2!V>6UA>F%N
M[0!6>6UA>F&[('-K=7!I;G4`5GEM87IANR!ZX7IN86T`5GEM87IANR!P<N%V
M;P!6>6UA>F&[(&$@;V1S='+A;FF[('-P<N%V>0!3<'+A=F%N:64@<V$@=&QA
MZ&ED;&$@;F$@=GEM87IA;FEE`%9Y;6%Z8;L@8G5N:W4`5GEM87IANR!S=.5P
M96,`5GEM87IANR!E>&ES='5J^F-U(&%L=&5R;F%T[79N=2"Y86)L\VYU`%9Y
M;6%ZX79A;FEE('IL>6AA;&\Z("@E<RD@)7,`5GEM87IANR!P<N%V82!P<F4@
M(B5S(@!#:&-E=&4@=GEM87IANR`B)7,B(&$@=KEE=&MY(&IE:&\@<&]D<'+A
M=F$_`%9Y;6%Z8;L@<FEA9&]K`%9Y;6%Z8;L@=GEB<F%N^B!I9&5N=&ET=0!6
M>6UA>F&[(&%K='7A;&YY('-TY7!E8P!6>6UA>F&[(&%K='7A;&YY(')I861O
M:P!3:W)I<'0@;F$@=7!G<F%D92!K;VYF:6=U<N%C:64@(B5S(B!B;VP@=GEM
M87IA;OTN`%9Y;6%ZX79A;FEE(&MO;G1A:W1O=B!N:64@:F4@9&]S='5P;NDN
M`%9Y;6%ZX79A;FEE('IL>6AA;&\`R&%S(&1O<G7H96YI80!$X6YS:V\`3V1D
M96QE;FEE`%IO<W1U<&YE`%!O<.VY=&4@<')O8FSI;0!0;W!I<P!0;V1R;V)N
M;W-T:2`H=&EEOB!V(&QO9V]V86-O;2!S^F)O<F4@2&]R9&4I`$1E=&%I;'D@
M8F]L:2!Z87IN86UE;F%NZ2!P<F4@861M:6YI<W1RX71O<F$N`%;]=F]J`%)O
M<V[](&)O9`!2;W-N_2!B;V0@>F$@<&]S;&5D;OH@:&]D:6YU.B``4F]S;OT@
M8F]D.B``4VUE<B!ZM6%V82!D;W!R879A`%-M97(@<W!R879A(&1OM6%V80!!
M9')E<^%R`%IO8G)A>F5N:64`6F]B<F%Z;W9ANR#H87,@=B`R-"UH;V1I;F]V
M;VT@9F]R;>%T93\`3F%S=&%V96YI92!Z;V)R87IE;FEA`%IO8G)A>FF[('!O
M9')O8F[Z('!R961P;W9E[P!:;V)R87IINR!P<F5D<&]V9>\@*%1!1BD`1F]R
M;>%T('IO8G)A>F5N:6$`4&]T=G)D96YI92!O(&1O<G7H96[M`$2^:6)U='-K
M;P!.979Y;6%Z8;L`3F5P;W6^[79A:G1E('!R:6%M;R!M86EN=&5N86YC92YP
M:'``0VAC971E('!O='9R9'IO=F&[('9Y;6%ZX79A;FEE('!O;&^^:65K/P!/
M8G-A:'5J92!P<G;](')I861O:R!NX7IV>2!P;VSM/R!!:R#A;F\L('IAN6MR
M=&YI=&4@<&]L[>AK;SH@`$1O;6EN:6-A`$1O;6EN:6OA;G-K82!R97!U8FQI
M:V$`3F5MX71E(/KH970_(%IA<F5G:7-T<G5J=&4@<V$N`%-T:6%H;G6[`%-T
M:6%H;G6[("5S`%-T:6%H;G6[('9Y9V5N97)O=F%N^B!K;VYF:6=U<N%C:74@
M86MO(%!(4"!S:W)I<'0N`%-T:6%H;G6[('9#87)D`%IO>FYA;2!S(';]8F5R
M;VT`1')O9WD`12UM86EL`$524@!%:W;A9&]R`%5P<F%V:;L`57!R879INR`B
M)7,B`%5P<F%V:;L@861R97/A<F4`57!R879INR!B;&]K`%5P<F%V:;L@<VMU
M<&EN=0!5<')A=FF[('!RX79O`%5P<F%V:;L@<'+A=F$`57!R879INR!P<N%V
M82!P<F4@)7,`57!R879INR!P;VQOOFMU('!R92`E<P!5<')A=FF[(&YA<W1A
M=F5N:6$@<')E.@!5<')A=FF[('!RX79A('!R92`B)7,B`%5P<F%V:;L@<'+A
M=F$@<')E("5S`%9Z9&5LX79A;FEE`$5G>7!T`%-A;';A9&]R`$5L96UE;G0N
M+BX`16T`16UA:6P`16UA:6QO=N$@861R97-A.@!%+6UA:6QO=ND@861R97-Y
M(&UU<VEA(&)YNR!R;W9N86OI+@!%+6UA:6P@<R!P;W1V<F1E;NUM`$)RX6YA
M($5M86EL+6YA+5--4P!%;6]T:6MO;GD`4'+A>F1N82!S<'+A=F$N`%!RX7ID
M;GD@=OUS;&5D;VLN`%!RX7ID;F4@<&]D;6EE;FMY(&BU861A;FEA`%!O=F]L
M:;L@=FQOOF5N:64@;V)RX7IK;W8@>B!'86SI<FGM(&1O('1E>'1U/P!0;W9O
M;&F[(&MO;G1E>'1O=ND@;65N=2!P<F4@<')A=ND@=&QAZ&ED;&\_`$MO;FEE
M8R!R;VMA`%IVY.BY:;L@961I=&]R`%IA9&%J=&4@8F5Z<&7H;F]S=&[Z(&]T
MX7IK=2P@;F$@:W1O<OH@8G5D971E(&UU<VEENR!O9'!O=F5D8;L@86L@>F%B
M=61N971E(&AE<VQO+"!N87!R+B`G86MO('-A('9O;.$@;6]J92!Z=FEE<F%T
M:V\_)SH`6F%D86IT92!54DP@;V)RX7IK80!:861A:G1E('#M<VUE;N$@=79E
M9&5NZ2!N:;ZY:64Z`%!O;&^^:V$@<')E("5S(&)O;&$@86MT=6%L:7IO=F%N
MX2P@86QE('5K;&%D86YI92!A:W1U86QI>F]V86[I:&\@<_IB;W)U('IL>6AA
M;&\Z("5S`%!O;&^^:V$@<')E("5S(&)O;&$@86MT=6%L:7IO=F%NX0!2;W9N
M[6MO=N$@1W5I;F5A`$5R:71R96$`0VAY8F$`3F%S=&%L82!C:'EB82!P<FD@
M<')I9.%V86[M("5D(&MO;G1A:W1O=B!D;R!Z;WIN86UU+@!.87-T86QA(&-H
M>6)A('!R:2!P<FEDX79A;NT@)60@>B`E9"!P;[YA9&]V86[]8V@@:V]N=&%K
M=&]V(&1O('IO>FYA;74N`$-H>6)A('!R:2!V>71VX7)A;NT@8FQO:W4Z("5S
M`$YA<W1A;&$@8VAY8F$@<')I('9Y;6%ZX79A;NT@)60@:V]N=&%K=&]V+@!.
M87-T86QA(&-H>6)A('!R:2!V>6UA>N%V86YI("5D('H@)60@<&^^861O=F%N
M_6-H(&MO;G1A:W1O=BX`0VAY8F$@<')I('9Y;6%ZX79A;NT@=6MO='9E;FEA
M('-Y;F-H<F]N:7KA8VEE.B`E<P!#:'EB82!P<FD@=GEM87KA=F%N[2!ZX7IN
M86UU('-Y;F-H<F]N:7KA8VEE.B`E<P!#:'EB82!P<FD@>NUS:V%V86[M(&]B
M<V%H=3H@)7,`3F%S=&%L82!C:'EB82!P<FD@=GEM87KA=F%N[2`E9"!K;VYT
M86MT;W8@>F\@>F]Z;F%M=2X`3F%S=&%L82!C:'EB82!P<FD@=GEM87KA=F%N
M[2`E9"!Z("5D('!OOF%D;W9A;OUC:"!K;VYT86MT;W8@>F\@>F]Z;F%M=2X`
M3F%S=&%L82!C:'EB82!P<FD@:+5A9&%N[2!V(&%D<F5SX7)I.B`E<P!#:'EB
M82!P<FD@86MT=6%L:7KA8VEI(&AE<VQA.B`E<P!#:'EB82!V(&4M;6%I;&]V
M96H@<W!RX79E+@!#:'EB82!P<FD@>F%P:7-O=F%N[2`B)7,B+@!%<W3S;G-K
M;P!%=&GS<&EA`$5T;FEC:^D`175R\W!A`$MAOF3]8V@@,34@;6EN^G0`2V&^
M9.D@,B!M:6[Z='D`2V&^9/UC:"`S,"!S96OZ;F0`2V&^9/UC:"`U(&UI;OIT
M`%!R:2!K8;YD;VT@<')I:&SA<V5N[0!+8;YD^B!P;VQH;V1I;G4`2V&^9/H@
M;6EN^G1U`$YA<'+M:VQA9#H`4W!U<W1INP!2;WIB86QINP!2;WIB86QINR!"
M;^AN_2!P86YE;`!/Z&%KX79A('-A("<I)P!/Z&%KX79A('-A('-L;W9O(&%L
M96)O('!O9&UI96YK82!HM6%D86YI82!V(/IV;V1Z;W9KX6-H`$3A='5M(&5X
M<&ERX6-I90!%>'!O;F5N=`!%>'!O<G0`17AP;W)T;W9ANR!A9')E<^%R`$5X
M<&]R=&]V8;L@:6)A('9Y8G)A;ND@:V]N=&%K='DN`$5X<&]R=&]V8;L@8V5L
M_2!N87-L961U:OIC:2!A9')E<^%R+@!&87)B82!T97AT=0!.86AR8;L@:V]N
M9FEG=7+A8VEU(&YA($944`!.97!O9&%R:6QO('-A('KM<VMANR!N87-T879E
M;FEA+@!.87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K(&%D<F5SX7)U.B`E
M<P!.87-T86QA(&-H>6)A('!R:2!P<FEDX79A;NT@)7,@9&\@)7,Z("5S`$YE
M;6^^;F\@>F]B<F%Z:;L@>F]Z;F%M`$YA<W1A;&$@8VAY8F$@<')I('!R96BU
M863A=F%N[2!A9')E<^%R82X`3F5P;V1A<FEL;R!S82!Z;65N:;L@;65N;SH@
M*"5S*2`E<SL@<W1A<ND@1$X@/2`E<RP@;F]VZ2!$3B`]("5S+"!K;W)E\B`]
M("5S`$YA<W1A;&$@8VAY8F$@<')I('-P;VIE;NT@<R!,1$%0('-E<G9E<F]M
M+@!.87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K(%--0B!S97)V97)U+@!.
M97!O9&%R:6QO('-A(&MO<.UR;W9ANR!Z("(E<R(N`$YE<&]D87)I;&\@<V$@
M:V]P[7)O=F&[(&1O("(E<R(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@;F]V
MZ2!305-,('-P;VIE;FEE+@!.96UOOFYO(&[A:G.[(&]B:F5K="!N82!P<FED
M86YI93H@)7,`3F5P;V1A<FEL;R!S82!P<F5S=6[ZNR!D;R`B)7,B+@!.97!O
M9&%R:6QO('-A('KM<VMANSH@)7,`3F5P;V1A<FEL;R!S82!HM6%D8;L@=B!A
M9')E<^%R:0!.87-T86QA(&-H>6)A('!R:2!P<F5HM6%DX79A;NT@861R97/A
M<F$Z("5S`$1O8G+I`$9A;&ML86YD<VOI(&]S=')O=GD@*$UA;';M;GDI`$9A
M97)S:^D@;W-T<F]V>0!:X79AOF[A(&-H>6)A.@!&87@`1F%X>0!&96)R=>%R
M`%!O8VET('1E<&QO='D`4&]C:70@=&5P;&]T>3H@`$UA;.D@>G+AOFMY`$UA
M;.D@<VYE:&]VZ2!P<F5HX6YK>0!-871I8V$@<&]L[0!&:62^:0!3^F)O<@!0
M;^AE="!S^F)O<F]V.B`E<R!S^F)O<@!0;^AE="!S^F)O<F]V.B`E<R!S^F)O
M<F]V`%-P<N%V8V$@<_IB;W)O=@!-96YO('/Z8F]R=0!6_6)E<B!S^F)O<G4`
M3F%H<F%T:64@<_IB;W)U`$YA:'+A=F%N:64@<_IB;W)O=B!N:64@:F4@<&]D
M<&]R;W9A;NDN`%/Z8F]R>0!&:6QT<F4`3N%J<[L`4VMO;NAINP!&[6YS:V\`
M4')VX2!P;VQO=FEC80!+<G-T;ND@;65N;P!0<G;A(+ET=G*[`%!E=F[]('!O
M;65R`$]T;^AINP!0;.%V86KZ8VD@=&5X=`!(;6QA`%!R:67H:6YO:R`E<R!N
M965X:7-T=6IE`$9A<F)A('#M<VUA`%!O=')A=F$`4')E('!R96AL:6%D8>AE
M+"!K=&]RZ2!N97!O9'!O<G5J^B!O8G+A>FMY`%!R961P;W9E[R`H5$%&*0!0
M<F5D<&]V9>\@;F$@=79E9&5N_2!P;^AE="!D;NT@*'!A;>1T86IT92!N82!T
M;RP@OF4@<')E9'!O=F7O(&IE('!R92!D;FD@86H@;F]C:2!A('1A:R!M]+YE
M('9EM6OI(.CM<VQO('9Y='9O<FF[('9EM6UI(+EI<F]K_2!B;&]K*0!:86)U
M9&QI('-T92!H97-L;S\`1F]R;75LX7)E`$9O<G1U;F$`5'EP(&9O<G1U;GD`
M1F]R='5N>0!&;W)T=6YY(#(`1O-R80!0<F5S;65R;W9A;FEA`%!I80!2X6UC
M90!&<F%N8_IZ<VMO`$9R86YC^GIS:V\@*$5U<O-P82D`55),(',@:6YF;W)M
MX6-I;W4@;R!Z86YE<'+A>F1N96YO<W1I`$9R86YC^GIS:V$@1W5A>6%N80!&
M<F%N8_IZ<VMA(%!O;'ENZ7II80!&<F%N8_IZ<VME(&IUOF[I('1E<FET\W)I
MX0!:`%IO('-M97)U(`#:<&QN_2!P;W!I<P!3<&QN`$-E;.D@;65N;SH`1V%B
M=6X`1V%LZ7)I82P@>B!K=&]R96H@8VAC971E('9Z:6&[(&]B<N%Z;VL`1V%L
MZ7)I83H`1V%M8FEA`$=E;F5R;W9ANR!K;VYF:6=U<N%C:74@<')E(&%P;&EK
MX6-I=2`E<P!'96YE<F]V86[](&OS9`!'96]R9VEA`$YE;65C:V\`1VAA;F$`
M1VEB<F%L=.%R`$MR<W1NZ2!M96YO`$=L;V+A;&YY(&%D<F5SX7(`3V1O<VQA
MNP!';V5D96P`1V]O9VQE($UA<',`2+5A9&&[(&YA($=O;V=L90!/9'1I96YE
M(+EE9&5J`$=RZ6-K;P!'<O-N<VMO`$=R96YA9&$`4VMU<&EN80!!9&UI;FES
M='+A8VEA('-K=7#M;@!-96[A('-K=7#M;B!N97-M^B!B>;L@<'+A>F1N90!'
M<F]U<%]L9&%P.B!.97!O9&%R:6QO('-A('!R:61ANR!S:W5P:6YU("5S+B!3
M97)V97(@;V1P;W9E9&%L.B``1W)O=7!?;&1A<#H@;F5P;V1A<FEL;R!S82!V
M>6UA>F&[('-K=7!I;G4@)7,`1W)O=7!?;&1A<#H@;F5P;V1A<FEL;R!S82!A
M:W1U86QI>F]V8;L@<VMU<&EN=2`E<P!3:W5P:6YY`$=U861E;&]U<&4`1W5A
M;0!'=6%T96UA;&$`1W5E<FYS97D`4'+A=F$@86YO;GEM;OUC:"!P;W6^[79A
M=&6U;W8`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(
M5$U,`$A434Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@<&]S;&5D;OH@8G5N:W4@
M=B!R:6%D:W4N`$A434Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@<&]S;&5D;OT@
M<W3E<&5C('8@=&%B=;5K92X`2%1-3$%R96$@;F5D;W9O;.T@=GEM87IANR!P
M;W-L961N_2!R:6%D;VL@=B!T86)UM6ME+@!(5%10(&%U=&5N=&EF:6OA8VEA
M(&YE8F]L82!NX6ID96[A+@!(86ET:0!!;&=O<FET;75S(&AA<VAO=F%C96H@
M9G5N:V-I90!/<&%R`$AL879IZ&MA`$AL879IZ&MY`$AE87)D;W8@;W-T<F]V
M(&$@36-$;VYA;&1O=F4@;W-T<F]V>0!3:6QNX2!B^G)K80!6_;EK80!0;VUO
M8V[M:P!0;VUO8V[M:R!P<F4@<&]UONUV86YI92!E9&ET;W)A`%!O;6]C;NUK
M`%!O;&]G=;5A`%1U(&IE('IAZ&EA=&]K('/Z8F]R=3H`5GES;VOA`$1O7VUO
M=@!6871I:^%N`$1O;6]V`$1O;>%C82!A9')E<V$`365S=&\@*&1O;6]V*0!+
M<F%J:6YA("AD;VUO=BD`1&]MX6-I('!R:67H:6YO:P!496QE9O-N(&1O;6]V
M`%-M97)O=F%C:64@Z.US;&\@*&1O;6]V*0"I=.%T+W!R;W9I;F-I82`H9&]M
M;W8I`$1O;>%C82!A9')E<V$`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!V('-P<N%V92`E<R!B;VQI(&[A:F1E;ND@;F5P;&%T;ND@
M)7,@6$U,(/ID86IE`$AO<F1E+TMO;&%B.B!S(&]B:F5K=&]M("5S(&YE:V]R
M9;EP;VYD=6IE(+YI861N82!S<'+A=F$N`$AO<F1E+TMO;&%B.B!V('-P<N%V
M92`E<R!N96)O;"!NX6ID96[](+YI861E;B!O8FIE:W0@='EP=2`E<P!(;W)D
M92]+;VQA8CH@^G-P9;EN92!O9'-T<N%N96[I("5S("(E<R(`2&]R9&4O2V]L
M86(Z(&EN=&5G<N%C:6$@=GF^861U:F4@4$A0(')O>KGM<F5N:64@)V1O;7AM
M;"<`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@=GET=F]R:;L@;F]V_2!8
M34P@<W1R;VT@<')E(&]B:F5K="`E<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL
M;R!S82!O9'-T<N%N:;L@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&]D
M87)I;&\@<V$@>NUS:V&[($U)344@240@<')E(.AA<[L@='EP=2`E<P!(;W)D
M92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O;FEZ;W9ANR`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O;FEZ;W9A
MNR!Z9&EEM6%NZ2!O8FIE:W1Y.B`E<P!(;W)D92]+;VQA8CH@;F5Z;N%M>2!Z
M9&EEM6%N_2!O8FIE:W0@(B5S(@!(;W)I>F]N=.%L;F$@Z&EA<F$`2&]R:7IO
M;G3A;&YE('9Y<&QN96YI90!(;W)I>F]N=.%L;F4Z`$%K;R!S=&4@<V$@<V5M
M(&1O<W1A;&D_("A0<F]S[6T@;F%H;.%S=&4A*0!+;[5K;R!S=.5P8V]V(&-H
M8V5T92!Z;/KH:;L_`%IA9&%J=&4@<&_H970@<&]L[2`H<W3E<&-O=BD_`$MO
MM6MO(')I861K;W8@8VAC971E('IL^NAINS\`5FQH:V]SNP!6;&AK;W.[.B``
M2'5M;W)I<W1I`$UA[V%R<VMO`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@24U!
M4"!S8VARX6YK=3H@)7,`3F5P;V1A<FEL;R!S82!V>6UA>F&[($E-05`@<V-H
M<N%N:W4Z("5S`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@24U!4"!K=O-T=3H@
M)7,`24U34`!3<'+A=F$@24U34"!A9')E<^%R80!)4"!A9')E<V$`25`@861R
M97-A(&YI92!J92!D;W-T=7!NX2X`25`@861R97-A(&YI92!J92!V('+A;6-I
M(&1O=F]L96[I:&\@0TE$4B!B;&]K=2X`4&]R=;EE;FEE('!R879I9&QA(&\@
M<&5V;F5J($E0(&%D<F5S92X`5FQOOFF[(&NU^N@@7W!R960`27-L86YD`$EB
M82!I:V]N>0!):V]N>2!P<F4@)7,`26MO;GD@82!T97AT`$[A>F]V(&ED96YT
M:71Y.@!!:R!S82!N97IO8G)A>NT@:V]R96MT;F4L("5S(&$@;W1V;W+M('-A
M('8@;F]V;VT@;VMN92X`06L@;F5V:63M=&4@<')I('!O=;YI=.T@26YT97)N
M970@17AP;&]R97)A(+YI861N92!I:V]N>2P@<&]T<F5B=6IE=&4@>F&Y:W)T
M;OJ[('3Z=&\@=F^U8G4@<')E('9Y<&YU=&EE('!R:65S=FET;F]S=&D@4$Y'
M(&]B<N%Z:V]V+@!!:R!V:63M=&4@=/IT;R!S<'+A=G4@82!N979I9.UT92!O
M8G+A>F]K+"!O8G+A>F]K+"!K=&]R_2!S=&4@8VAC96QI(&YA:')ANRP@;F5M
M]+YE(&)YNR!Z;V)R87IE;OT@=F\@5F&Y;VT@<')E:&QI861AZ&DN`%5KX;YK
M82!O8G+A>FMA.@!54DP@;V)RX7IK80!54DP@;V)RX7IK83H`3V)RX7IO:R!Z
M(&=A;.ER:64`3V)RX7IO:R!Z(&=A;.ER:64Z`$YA:')A=&EE(&]B<N%Z:W4`
M3V)RX7IK>0!);7!O<G1O=F&[(&%D<F5SX7(L(&MR;VL@)60`26UP;W)T+"!K
M<F]K("5D`$EM<&]R=&]V8;LO17AP;W)T;W9ANR!A9')E<^%R90!);7!O<G1O
M=F%NZ2!P;VQE.B`E<P!);7!O<G1O=F%NZ2!P;VQI83H`5FQOOFF[(&NU^N@@
M7WIA`$)O;"!Z861A;OT@;F5S<'+A=FYY(&OS9"!A:V-I92X`3F5S<'+A=FYE
M('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L96)O(&AE<VQO`$YE<W!RX79N92!P
M;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@86QT97)N873M=FYA(&%D<F5S82X@
M4VOZ<W1E('1O('IN;W9U(&%L96)O(&MO;G1A:W1U:G1E('-P<N%V8W4@5N&Y
M:&\@<WES=.EM=2P@86L@<&]T<F5B=6IE=&4@<&]M;V,N`%IVY.BY:;L@;V1S
M861E;FEE`$EN9&EA`$IE9&YO=&QI=NT@<&]UONUV871E;&EA`$EN9&]NZ7II
M80!);F9O`$EN9F]R;>%C:64`26YF;W)MX6-I92!UOB!N:64@<_H@9&]S='5P
M;NDN`%9L;[YINR!?<W3E<&5C('IA`%9L;[YINR!O8G+A>F]K`%9L;[YINR!T
M86)UM6MU`%9L;[YINR!L:6YK=0!6;&^^:;L@7W-TY7!E8R!P<F5D`%9L;[YI
MNR!N;W;]('-TY7!E8R!Z82!A:W1UX6QN>0!6;&^^:;L@;F]V_2!S=.5P96,@
M<')E9"!A:W1UX6QN>0!6;&^^:;L@;F]V_2!R:6%D;VL@>F$@86MT=>%L;GD`
M5FQOOFF[(&YO=OT@<FEA9&]K('!R960@86MT=>%L;GD`5FQOOFF[(&]D<W1A
M=F5C('IA(&%K='7A;&YY(&)O9`!6;&^^:;L@;V1S=&%V96,@<')E9"!A:W1U
MX6QN>2!B;V0`5FQOOFF[(&%L=&5R;F%T[79N=2"Y86)L\VYU`%IA9&%J=&4@
M92UM86EL;W;Z(&%D<F5S=2P@;F$@:W1O<OH@9&]S=&%N971E(&YO=ND@:&5S
M;&\Z`%9L;[YINR!B=6YK=2!Z80!6;&^^:;L@8G5N:W4@<')E9`!6;&^^:;L@
M<W3E<&5C('IA`%9L;[YINR!S=.5P96,@<')E9`!6;&^^=&4@<W!RX79Y`%9L
M;[YINR!O9'-T879E8R!Z80!6;&^^:;L@;V1S=&%V96,@<')E9`!6;&^^:;L@
M<FEA9&]K('IA`%9L;[YINR!R:6%D;VL@<')E9`!:861A:G1E('!OOF%D;W9A
M;OH@;V1P;W9E[R!N82!B97IP9>AN;W-T;OH@;W3A>FMU.@!6;&^^:;LO=7!R
M879INR!O8G+A>F]K`%9L;[YINR]U<')A=FF[(&QI;FMU`$YA(&]D;W-I96QA
M;FEE('!R92!Z;WIN86T@<'+M:F5M8V]V(&YE;>%T92!D;W-T871OZ&[](&MR
M961I="X`3F5D;W-T871OZ&[](&MR961I="X`0V5LZ2#H[7-L;P!:;WIN86T@
M8V5L_6-H(.AI<V5L`$YE<&QA=&[I($E$`$YE<&QA9&[I(%5$2"`H57-E<B!$
M871A($AE861E<BP@2&QA=FGH:V$@<&]UONUV871EM7-K_6-H(/ID86IO=BDN
M`$YE<&QA=&[I(/ID86IE(&9O<FWA='4@6DE0+@!.97!L871N_2!A9')E<^%R
M`$YE<&QA=&[A(&%P;&EKX6-I82X`3F5P;&%T;ND@240@9.%V:WDN`$)O;&D@
M;V1O<VQA;ND@;F5P;&%T;ND@^F1A:F4N`$YE<&QA=&[A(&-I9;5O=N$@861R
M97-A+@!.97!L871NX2!E+6UA:6QO=N$@861R97-A`$YE<&QA=&[A('!O;&^^
M:V$`3F5P;&%T;OT@9F]R;>%T('/Z8F]R=0!";VP@>F%D86[](&YE<&QA=&[]
M(&NU^N@N`$YE<&QA=&[](&QI8V5NZ&[](&NU^N@N`$)O;&$@>F%D86[A(&YE
M<&QA=&[A(&QO:V%L:71A+@!.97!L871NX2!H;V1N;W1A(&US9U]T>7!E+@!.
M97!L871NZ2!M96YO`$YE<&QA=&[I(&]B:F5C=$ED`$YE<&QA=&[A(&%L96)O
M(&-H_6)A:OIC82!H;V1N;W1A(&%P:5]I9"X`3F5P;&%T;ND@86QE8F\@8VC]
M8F%J^F-E('!A<F%M971R92X`3F5P;&%T;ND@<F]D:>AO=G-KZ2!P<N%V;RX`
M3F5P;&%T;ND@:60@<&%R=&YE<F$N`$YE<&QA=&[](&OS9"!P<F]D=6MT=2X`
M3F5P;&%T;OT@<')O=&]K;VP`3F5P;&%T;OT@<'+M:F5M8V$Z("(E<R(`3F5P
M;&%T;OT@;V)J96MT('ID:66U86YI80!.97!L871NX2!Z9')O:F]VX2!A9')E
M<V$N`$YE<&QA=&[I(/ID86IE('5N:6-O9&4N`$EN=F5N=.%R`$EN=F5R=&]V
M8;L@=OUB97(`27+A;@!)<F%K`,UR<VMO`$ES;&4@;V8@36%N`$]J961I;F5L
MZ2!B^G)K>0!)>G)A96P`5GED879A=&6U`$MU<GKM=F$`5&%L:6%N<VMO`$IA
M;6%J:V$`2F%N=>%R`$IA<&]N<VMO`$IE<G-E>0!*;W)DX6X`2OIL`$KZ;@!:
M87)O=FYANP!:87)O=FYANR!D;R!S=')E9'4`6F%R;W9N8;L@9&\@8FQO:W4`
M6F%R;W9N8;L@=K5A=F\`6F%R;W9N8;L@=G!R879O`$MA>F%C:'-T86X`4&]N
M96-H8;L@;W)I9VENX6P_`$ME\F$`2V5R8F5R;W,@<V5R=F5R('IA;6EE=&]L
M(&%U=&5N=&EF:6OA8VEU+@!+97)N96PM;F]VX>AI:V]V:6$`5GET=F]R96YI
M92!KM?KH80!$:6=I=.%L;GD@;V1T;&'H;VL@:[7ZZ&$`1.6^:V$@:[7ZZ&$`
M5'EP(&NU^NAA`%!O=;YI=&EE(&NU^NAA`$NU^N@@=;X@97AI<W1U:F4@;F$@
M<V5R=F5R:2!V97)E:F[]8V@@:[7ZZ&]V+@!$971I`$MI<FEB871I`*5U9&]V
M;V1E;6]K<F%T:6-KX2!R97!U8FQI:V$@2_-R96$`2_-R96IS:^$@<F5P=6)L
M:6MA`$MU=F%J=`!+:7)G:;ES:V\`2F4@<&^^861O=F%NX2!P;V1P;W)A($Q$
M05`L(&%L92!,1$%0(&UO9'5L(&YI92!J92!D;W-T=7!N_2!A;&5B;R!N86AR
M873]+@!6>E]HM6%D`$IA>GEK`$QA;W,`4&]S;&5D;N$@<&]L;W9I8V$`4&]S
M;&5D;N$@86MT=6%L:7KA8VEA`%!R:65Z=FES:V\`4&]S;&5D;N$@>FUE;F$@
M:&5S;&$`4&]S;&5D;N$@N71V<KL`4&]S;&5D;N$@86MT=6%L:7KA8VEA.@!0
M;W-L961NZ2!P<FEH;.%S96YI93H@)7,`4&]S;&5D;ND@<')I:&SA<V5N:64Z
M("5S('H@)7,`4&]S;&5D;ND@<')I:&SA<V5N:64Z(&YI:V1Y`$QO='FY<VMO
M`%!RX79O`%9Z:+5A9`!.96-H86IT92!P<N%Z9&YE('!R92"^:6%D96X@;VMR
M86H`3&EB86YO;@!6M6%V;P!(;&%V:>AK82!VM6%V;P!(;V1N;W1Y(':U879O
M`$QE<V]T:&\`VG)O=F7R`$QI8NER:6$`3.UB>6$`3&EC:'1E;KET86IN<VMO
M`*5A:&OI(&UR:&]L96YI90"E86AK_2!DX;[O`%+A;F\@M6%H:_T@9.&^[P!.
M97-K]'(@M6%H:_T@9.&^[P"E86AKZ2!D8;[O;W;I('!R96CA;FMY`*5A:&O]
M(&3AON\@<R!H<FUE;NUM`*5A:&OI('-N9;YE;FEE`*5A:&OI('-N96AO=ND@
M<')E:.%N:WD`3&EM97)I8VL`3&EN:V$`3&EN:V$@=6MA>G5J92!N83H`4')E
M<&]J:;L@92UM86EL;W;Z(&%D<F5S=2!S;R!S='+A;FMO=2!N82!P[7-A;FEE
M('!ON71Y`$QI;FMY`$QI;G5X($-O;VMI90!:;WIN86T`6F]Z;F%M("T@<&]U
MONUV871EM2!U=FED[2!P<FEEZ&EN;VL`5GEP[7-ANR!Z;WIN86T@9&%T86+A
M>@!:;WIN86T@=.EM(%!O;6]C;NUK80!6>7#M<V&[('IO>FYA;2!T86)U;&EE
M:P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,
M:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!:;V)R
M87IE;FEE('-E9&5N[2!Z;'EH86QO.B`E<P!:;V)R87IE;FEE('!O=;[M=F%T
M9;5O=B!Z;'EH86QO.B`E<P!:;V)R87IO=F%N:64@>F]Z;F%M=2!P;W6^[79A
M=&6U;W8@:F4@>F%KX7IA;NDN`$QI=&5R873Z<F$`3&ET=F$`3F'H[71A=F$@
M<V$N+BX`36EE<W1N>2#H87,Z(`!,;VMA;&EZX6-I82!A(.AA<P!,;VMA;&ET
M80!0<FEH;.%S96YI90!:X7IN86UY('!R961C:.%D>F%J^F-E:B!S>6YC:')O
M;FEZX6-I90!/9&ALX7-INP!0<FEH;.%S96YI90#:;&]H>2!P<FD@<')I:&SA
M<V5N[0!0<FEH;.%S96YI92!Z;'EH86QO+"!P<F5T;[YE('-T92!Z861A;&D@
M;F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!H97-L;RX`4')I
M:&SA<V5N:64@>FQY:&%L;RX`1&QH_2!T97AT`$SA<VMA`$[M>FMA`$UA;.D@
M9W+I8VME('#M<VUE;N$`36%LZ2!L871I;G-KZ2!P[7-M96[A`$UA;.D@<NUM
M<VME(.CM<VQI8V4`3'5X96UB=7)S:V\`34T`4W!RX79A(&3R80!0<NUL;VAA
M($U3+51.148@;F5O8G-A:&]V86QA(+YI861N92#Z9&%J92X`35-'`$UA8V%O
M`$UA8V5D\VYS:V\`36%D86=A<VMA<@!-X6=I80!0;[ET80!0;W-L8;L@92UM
M86EL(&%D;6EN:7-T<N%T;W)O=FD`5GET=F]R:;L@;&EN7VMU+BXN`$UA;&%W
M:0!-86QA:GII80!-86QE9&EV>0!-86QI`$UA;'1A`%-P<F%V;W9ANR!Z;WIN
M86T@:V%T96?S<FGM+"!S(&MT;W+];6D@;WIN8>AU:F5T92!P;VQOOFMY(&$@
M9F%R8GD@87-O8VEO=F%NZ2!S('3];6ET;R!K871E9_-R:6%M:2X`36%P82!-
M87`R-`!-87!A($UA<%%U97-T`$UA<&]V86YI82!U;&^^96[I+@!-87)E8P!/
M:W)A:@!/>FYAZ&F[('!R[7IN86MM:2!0<F7H[71A;NDO3F5P<F7H[71A;ND`
M3WIN8>AINR!I;OUM:2!P<NUZ;F%K;6D@*&YA<'(N($3T;&6^:73I+UIO9'!O
M=F5D86[I*0!-87)S:&%L;&]V92!O<W1R;W9Y`$UA<G1I;FEK`$]B<V%H=6KZ
M8V4`6FAO9&[I('!O;&EA`$UA=7)E=.%N:6$`36%U<NUT:75S`$UA>&EMX6QN
M>2!P;W9O;&5N_2!K<F5D:70N`$)O;"!P<F5K<F_H96[](&UA>&EMX6QN>2!P
M;^AE="#H87-T[2!S<'+A=GDN`$YA:G9YN;EI82!T97!L;W1A('IA('!O<VQE
M9&[]8V@@,C0@:&]D[6XZ(`!.86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N
M_6-H(#8@:&]D[6XZ(`!-87AI;>%L;GD@<&_H970@:V]N=&%K=&]V`$UA>&EM
MX6QN>2!P;^AE="!B;&]K;W8@<&]R=.%L=0!-87AI;>%L;F$@9.6^:V$`36%X
M:6WA;&YY('!OZ&5T('-T<N%N`$WA:@!-87EO='1E`$UE9&EC[6YA`,AL96YO
M=FEA`$UE;G4`6F]B<F%Z96YI92!M96YU.@!:;/KH:;L@8G5N:WD`4W!RX79A
M`%-P<N%V82!B;VQA(/IS<&6Y;F4@;W9E<F5NX2P@86QE(&-E<G1I9FEKX70@
M<&]D<&ES=2!S82!N97!O9&%R:6QO(&]V97)INRX`4&QA=&YO<[L@<W!RX79Y
M('9Y<'*Y86QA+@!4>7`@<W!RX79Y`%!OZ&%S:64@365T87(`VF1A:F4@365T
M87(@;FEE('/Z(&1O<W1U<&[I+@#:9&%J92!-971A<B!N:64@<_H@:R!D:7-P
M;WKM8VEI+B!$971A:6QY(&)O;&D@>F%Z;F%M96YA;ND@<')E(&%D;6EN:7-T
M<N%T;W)A+@!3>7-TZ6T@365T87)$0B!N:64@:F4@<')I<&]J96[]+@!-973S
M9&$`365T\V1A("(E<R(@;FEE(&IE(&1E9FEN;W9A;N$`3F5D969I;F]V86[A
M(&UE=/-D82X@5F]L86[I('H@;65T\V1Y.B`E<P!-971R:6-KZ0!-97AI8V\`
M36EK<F]NZ7IS:V4@9F5D97)A=.UV;F4@N73A='D`4W1R960`5'EP($UI;64`
M3F%J;FF^N6EA('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`R-"!H;V3M;CH@`$YA
M:FYIOKEI82!T97!L;W1A('IA('!O<VQE9&[]8V@@-B!H;V3M;CH@`$UI;FEM
MX6QN82!D;V)A('!L871N;W-T:2!H97-L82!EN71E(&YE=GEP<KEA;&$`6G)K
M861L;W9O(&]B<N%T:;L`4O1Z;F4`0VC]8F$@1$X@=B!K;VYF:6=U<N%C:6D@
M3$1!4"!Z9')O:F$N`$-H_6)A(&)A;.UK(%!%05(@2%144%]297%U97-T+@!#
M:/UB82!K;VYF:6=U<N%C:6$N($%K(&-H8V5T92!P;W6^[79ANR!T^G1O(&%P
M;&EKX6-I=2P@;75S[71E('1E<F%Z('9Y9V5N97)O=F&[(&MO;F9I9W5RX6-I
M=2X`0VC]8F$@240@<W!RX79Y+@!#:/UB82!P;[YA9&]V86[](%!%05(@8F%L
M[6L@36%I;"X`0VC]8F$@240@<F5LX6-I92X`4&]N`$UO8FEL;OT@;6%I;`!-
M;V)I;&[]('1E;&5F\VX`36EE<FYY`$3A='5M('!O<VQE9&YE:B!Z;65N>0!5
M<')A=FF[(%523`#:<')A=F$@>FQY:&%L83H@*"5S*2`E<P!-;V1U;'5S`$UO
M;&1A=G-K;P!-;VYA:V\`36]N9V]L<VMO`$UE<VEA8R!A(')O:P!-97-AZ&YE
M`$UO;G1S97)R870`365S8>ANZ2!FX7IY`$YA(')I861K=2`E9"!B;VQO(&[A
M:F1E;OUC:"!V:6%C('!O;.T@86MO(&_H86OA=F%N_6-H("5D+@!6>6AO=G5J
M92!V:6%C(&%K;R`Q('!O;&^^:V$`36%R;VMO`%!R979AOFYE(&IA<VYO`%!R
M979AOFYE(&]B;&'H;F\`4')E=F&^;F4@<VQN9>AN;P!0<F5S=6[ZNP!0<F5S
M=6[ZNR!D;VQU`%!R97-U;OJ[(':U879O`%!R97-U;OJ[('9P<F%V;P!0<F5S
M=6[ZNR!H;W)E`%!R97-U;OJ[(&1O;'4`4')E<W5N^KL@=K5A=F\`4')E<W5N
M^KL@=G!R879O`%!R97-U;OJ[(&AO<F4`36]Z86)M:6L`061R97/A<B!Z($UU
M;&)E<G)Y`%9I86/Z<F]V\F]VZ2!V>6)E<F%C:64@>F]Z;F%M>0!%>&ES='5J
M92!V:6%C97)O(&]S]&(@<R!A9')E<V]U(%LE<UTL(&%L92"^:6%D;F$@<R!M
M96YO;2!;)7-=`%9I86-NX7-O8F[](';]8F5R`$UO:F4@:V]N=&\`26YF;W)M
MX6-I92!O(&UO:F]M(/KH=&4`3?1J(&%D<F5SX7(`36]J92!A9')E<^%R90!-
M]&H@<&]R=.%L`%9Z:+5A9"!M]&IH;R!P;W)TX6QU`$UY86YM87(`3FEE+"!.
M15/:2$Q!4\U-+@!-96YO`$9O<FWA="!M96YA`$YA;>UB:6$`3F%U<G4`3F5P
MX6P`061R97/A<B#H;&5N;W8@3F5T8V5N=&5R`$AO;&%N9'-K;P!(;VQA;F1S
M:^D@06YT:6QY`%KA:VQA9&[A(%523"!.971S8V%P90!54DP@<')E('IN97!L
M871N96YI92!C97)T:69I:^%T;W8@0T$@3F5T<V-A<&4`55),('!R92!P;VQI
M=&EK=2!#02!.971S8V%P90!54DP@<')E(&]B;F]V96YI92!P;&%T;F]S=&D@
M8V5R=&EF:6OA=&]V($YE='-C87!E`%523"!P<F4@>FYE<&QA=&YE;FEE(&-E
M<G1I9FEKX71O=B!.971S8V%P90!-96YO(%-33"!S97)V97)A($YE='-C87!E
M`$MO;65N=.%R(&-E<G1I9FEKX71U($YE='-C87!E`%1Y<"!C97)T:69I:^%T
M=2!.971S8V%P90!3:66[`$YI:V1Y`$YO=N$@2V%L963S;FEA`$YO=N$@:V%T
M96?S<FEA`$YO=OT@:V]N=&%K=`!.;W;A('-P<N%V82!P<F4@)7,`3F]V`$YO
M=ND@<&]UONUV871EM7-KZ2!M96YO("AN97!O=FEN;NDI`$YO=OT@6NEL86YD
M`$YO=ND@:&5S;&\`4&QA=&YO<[L@;F]VZ6AO(&AE<VQA('9Y<'*Y[2`E>"X`
M3F]VZ2!H97-LX2!N:64@<_H@<F]V;F%KZ2X`3F]VZ2!O:VYO("A?8FQA;FLI
M`$YE=W,`1&ES:W5S;ND@<VMU<&EN>0#/86QE:@!.87-L961U:OIC92`T(&;A
M>GD`SV%LN6EE(&YA<W1A=F5N:6$`3F%S;&5D=6KZ8V$^`$YI:V%R86=U80!0
M<F5Z_79K80!.:6=E<@!.:6?I<FEA`$YO8P!.:75E`$YI90!0<F4@)7,@;F5E
M>&ES='5J92!N:6IA:^$@<&]L;[YK82`E<P!.96)O;&D@;N%J9&5NZ2"^:6%D
M;F4@861R97/A<F4N`$YI92!S^B!D;W-T=7!NZ2"^:6%D;F4@:V]N9FEG=7)A
MZ&[I(/ID86IE+"!P<F4@:W1O<ND@8GD@<V$@9&%L:2!Z;V)R87IINR!R;WID
M:65L>2X`4')E('9Y=';A<F%N:64@25-/(&]B<F%Z;W8@;FEE(&IE(&L@9&ES
M<&]Z[6-I:2"^:6%D;F$@<W1R873I9VEA+@!.965X:7-T=6IE(+EA8FSS;F$@
M<')E(&3A=FMU+@!.82!P;[YA9&]V86YE:B!P;WKM8VEI(&YE97AI<W1U:F4@
MOFEA9&5N(&)L;VLN`%!R92!-0T%,(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z
M861A;ND@;65N;R!K86QE;F3A<F$N`*YI861N82!Z;65N82X`2R!T;VUU=&\@
M<'+A=G4@;F5M;[YN;R!P<FED8;L@OFEA9&YE('!O9')I861E;ND@<'+A=F$N
M`%!R92`E<R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I82X`4')E($944"!6
M1E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N`%!R92!344P@5D93(&YE
M8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@!0<F4@4U%,+49I;&4@5D93(&YE
M8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@!.96)O;&D@;N%J9&5NZ2"^:6%D
M;F4@:V]N=&%K='D`KFEA9&5N(&MR961I="X`3F5B;VQO(+EP96-I9FEK;W9A
M;ND@;6EE<W1O('5RZ&5N:6$N`%/Z8F]R(&YE8F]L(&YA:')A;OTN`$YE8F]L
M:2!NX6ID96[I(+YI861N92!I:V]N>2X`3FEE(&IE(&YA<W1A=F5NX2!L;VMA
M;&ET82X`3F5B;VQA('IA9&%NX2!L;VMA;&ET82X`3F5B;VQA('IA9&%NX2"^
M:6%D;F$@<W!RX79A+@!.96)O;&\@N7!E8VEF:6MO=F%NZ2"^:6%D;F4@;65N
M;RX`3F5B;VQO(+EP96-I9FEK;W9A;ND@Z.US;&\N`*YI861N92!U<N&^;&EV
MZ2!F;W)T=6YY`%!R92!(5%10(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A
M;ND@:&5S;&\N`%!R92!)34%0(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A
M;ND@:&5S;&\N`%!R92!+97)B97)O<R!A=71E;G1I9FEKX6-I=2!N96)O;&\@
M>F%D86[I(&AE<VQO+@!0<F4@3&]G:6X@875T96YT:69I:^%C:74@;F5B;VQO
M('IA9&%NZ2!H97-L;RX`4')E(%!!4U-71"!A=71E;G1I9FEKX6-I=2!N96)O
M;&\@>F%D86[I(&AE<VQO+@!0<F4@4TU"(&%U=&5N=&EF:6OA8VEU(&YE8F]L
M;R!Z861A;ND@:&5S;&\N`$YE8F]L82!Z861A;N$@8V5S=&$@:R!P<F]G<F%M
M=2!/<&5N4U-,+B!0<F]G<F%M($]P96Y34TP@:F4@<&]T<F5B;OT@;F$@<'+A
M8W4@<R#Z9&%J;6D@4$M#4R`Q,BX`KFEA9&YE('!R96)I96AA:OIC92!P<FEH
M;.%S96YI82X`2W;S=&$@;FEE(&IE(&YA<W1A=F5NX2X`0F5Z(.AI87(`3F5B
M;VP@N7!E8VEF:6MO=F%N_2!O9&1EM6]V8>@N`$)E>B!S='+A;@!3^F)O<B!N
M96[A:F1E;OT`4')E('9Y<F]V;N%V86-I=2!P86WDNR!N:64@:F4@9&]S='5P
M;OT@OFEA9&5N(&1OZ&%S;OT@<')I9>AI;F]K+@!.96)O;&\@;V1O<VQA;ND@
M<&]UONUV871EM7-KZ2!M96YO(&$O86QE8F\@:&5S;&\N`$YE8F]L:2!NX6ID
M96[I(/ID86IE('9#87)D+@!.96)O;&D@=G+A=&5NZ2!P;&%T;ND@6$U,(/ID
M86IE`*YI861N92!H;V1N;W1Y`%8@</1V;V1N96H@:V]N9FEG=7+A8VEI(&YE
M8F]L82!NX6ID96[A(+YI861N82!V97)Z:6$N(%9Y9V5N97)U:G1E('IN;W9U
M(&MO;F9I9W5RX6-I=2X`5B!K;VYF:6=U<N%C:6D@;F5B;VQA(&[A:F1E;N$@
MOFEA9&YA('9E<GII82X@5GEG96YE<G5J=&4@>FYO=G4@:V]N9FEG=7+A8VEU
M+@"N:6%D;F4`KFEA9&YE("AP;W6^:;L@:6UP;&EC:71N^B!H;V1N;W1U*0!/
M<W1R;W8@3F]R9F]L:P!3979E<F[A('!O;&]G=;5A`%-E=F5R;ND@36%R:>%N
M<VME(&]S=')O=GD`3O-R<VMO`$YE<&QA=.T@<&\`3F5P;&%T[2!P<F5D`$YI
M92!J92!A9')E<^%R`$YI92!J92!I;7!L96UE;G1O=F%NZ2X`3F5N87-T879E
M;ND`3FEE(&IE('!O9'!O<F]V86[I+@!0;WINX6UK>0!.:>@@;F$@<')E>F5R
M86YI92P@=G+ANW1E('-A('-PY+LN`$YO=F5M8F5R`,CM<VQO`%!OZ&5T('IN
M86MO=@!0;^AE="!S=.5P8V]V`%!OZ&5T('!O;&^^:65K(&YA('-T<N%N:W4`
M4&_H970@<FEA9&MO=@!0<F4@86MT=6%L:7KA8VEU('IO>FYA;74@<'+M:F5M
M8V]V(&YE8F]L:2"Y<&5C:69I:V]V86[I(.CM<VQA+@!/2P!/8FIE:W0`075T
M;W(@;V)J96MT=0!/8FIE:W0@;F5B;VP@;N%J9&5N_0!/<VUIZ&MO=OT`3VMT
M\V)E<@!&:6QT97(@;F$@;F%DX79K>0!0<F%C;W9I<VMO`%-T87+I(&$@;F]V
MZ2!H97-L;R!M=7-I82!B>;L@;V1L:;ENZ2X`4W1A<ND@:&5S;&\`4W1A<ND@
M:&5S;&\@;F5B;VQO('IA9&%NZ2!S<'+A=FYE+@!/;>%N`$ME[R!U;&^^[71E
M('3Z=&\@<W1RX6YK=2!S(&UOOFYO<[MA;6DL(&%D<F5SX7(@8G5D92!V>6UA
M>F%N_2X@06L@=&\@;F5C:&-E=&4L(&UU<^UT92!Z;65N:;L@;F%S=&%V96YI
M92!N82`BKFEA9&YE(@!)8F$@24U!4"!S97)V97)Y('!O9'!O<G5J^B!Z9&EE
MM6%NZ2!P<FEEZ&EN:WDN`$EB82!U<N&^;&EVZ2!F;W)T=6YY`$IE('!R[7!U
M<W1NX2!I8F$@:F5D;F$@92UM86EL;W;A(&%D<F5S82X`2F4@<&]D<&]R;W9A
M;N$@:6)A(&IE9&YA('9C87)D+@!6;&%S=&[M:V$@86QE8F\@<'+A=F$@=FQA
M<W1N[6MA('!R92!Z9&EEM6%N_2!O8FIE:W0@;?2^92!Z;65N:;L@:6)A('9L
M87-T;NUK(&%L96)O('-Y<W3I;6]V_2!A9&UI;FES='+A=&]R`$]T=F]R:;L@
M=B!N;W9O;2!O:VYE`$-H>6)A($]P96Y34TPZ(&YE<&]D87)I;&\@<V$@>NUS
M:V&[(/ID86IE('H@<&]D<.US86YE:B#H87-T:2!3+TU)344N`$]T=F]R:;L@
M=/IT;R!L:6YK=2!V(&YO=F]M(&]K;F4`3W!E<F'H;OT@<WES=.EM`$YA<W1A
M=F5N:6$`3F%S=&%V96YI82`E<P!:;W)A9&5N_2!Z;WIN86T`3W)G86YI>N%C
M:6$`3W)G86YI>F'H;N$@:F5D;F]T:V$`3W)G86YI>F]V86YI90!0]'9O9&[A
M(+EA8FSS;F$@87!L:6OA8VEE`%#T=F]D;ND@N6%B;/-N>2!V("5S.@!);ND`
MSV%LN6EE(&EN9F]R;>%C:64`26[I(&YA<W1A=F5N:6$`4'+A=F$@=FQA<W1N
M[6MA`%!!32!A=71E;G1I9FEKX6-I82!N:64@:F4@9&]S='5P;N$N`%!%05(Z
M36%I;"!B86-K96YD`$1I9VETX6QN>2!P;V1P:7,@4$=0`-ID86IE('IAN6EF
M<F]V86[I('!O;6]C;W4@4$=0`%!'4"!V97)E:F[](&NU^N@`VF1A:F4@<&]D
M<.US86[I+WIAN6EF<F]V86[I('!O;6]C;W4@4$=0`%!(4"!K\V0`4$A0(%-H
M96QL`%!O<&]L=61N[2"U86AK_2!DX;[O`%!O<&]L=61N[2!P<F5HX6YK>0!0
M;W!O;'5D;NT@<VYEOF5N:64`4&]P;VQU9&[M('-N96AO=ND@<')E:.%N:WD`
M4&]P;VQU9&[M('-N9;YE;FEE`%!O<&]L=61N[2!B^G)K>0!#:/UB82!R;WJY
M[7)E;FEE(%!/4TE8`%!?2%`@4VAE;&P`5GEP;&YE;FEE`%!A:VES=&%N`%!A
M;&%U<VOI(&]S=')O=GD`4&%L97-T[6YS:V4@^GIE;6EE`%!A;F%M80!087!U
M82!.;W;A($=U:6YE80!087)A9W5A>0#(:6%S=&_H;F4@;V)L8>AN;P!(97-L
M;P!(97-L;R!B;VQO(/IS<&6Y;F4@>FUE;F5NZ2X`3F5S<'+A=FYE(&AE<VQO
M`%!R92!A=71E;G1I9FEKX6-I=2!2041)55,@:F4@=GF^861O=F%NZ2!H97-L
M;RX`2&5S;&\@<R!P;W1V<F1E;NUM`$AE<VQO.@!(97-L;SH@`$AE<VSA(&UU
M<VEA(&)YNR!R;W9N86OI+@!6;&^^:;L`5FQOOFF[('IO('-C:'+A;FMY`$-E
M<W1A`%!R96)I96AA:OIC92!R96=I<W1RX6-I93H`I75D:6$`4&5R8V5N=`!6
M>6MO;F&[(&]P97+A8VEE(/ID<KYB>0!6>6MO;F&[(&]P97+A8VEE(/ID<KYB
M>2!P<FD@<')I:&SA<V5N[3\`4'+A=F\`4'+A=F\@(B5S(B!N96)O;&\@=GEM
M87IA;NDN`%!R[7-T=7`@>F%M:65T;G5T_0!0<NUS='5P('IA;6EE=&YU=/T`
M4'+A=F$`061M:6YI<W1RX6-I82!P<N%V`$]S;V)NZ2!I;F9O<FWA8VEE`%!E
M<G4`1&]MX6-E('IV:65R873A`$9I;&EP[6YY`%1E;&5F\VX`1F]T;V=R869I
M90!!9')E<^%R('H@4&EN90!0:71C86ER;@!";V1O=@!+;&EK;FET92!P<F]S
M[6T@9&\@;F5J86ME:B!B=6YK>0!0;W1V<N]T92!P<F]S[6TL(+YE(&-H8V5T
M92!O9'-T<N%N:;L@=&5N=&\@96QE;65N=#H`4&]T=G+O=&4@<')O<^UM+""^
M92!C:&-E=&4@;V1S='+A;FF[(&QI;FMU('H@=&]H=&\@96QE;65N='4N`%IA
M9&%J=&4@<')O<^UM(&UE<VEA8R!A(')O:RX`6F%D86IT92!P<F]S[6T@;65N
M;R!P<F4@;F]V^B!K871E9_-R:74Z`%IA9&%J=&4@<')O<^UM('!L871N^B!)
M4"!A9')E<W4N`%IA9&%J=&4@<')O<^UM('!L871N_2!DX71U;2P@<VMO;G1R
M;VQU:G1E('!OZ&5T(&1N[2!V(&UE<VEA8VDN`%IA9&%J=&4@<')O<^UM('!L
M871N_2#H87,N`%!O;65N=6IT92!P<F]S[6T@;F]V_2!Z;WIN86T@:V]N=&%K
M=&]V.@!0<F]S[6T@=79E[W1E('IH<FYU=&EE('!R;V)LZ6UU+@!0<F]S[6T@
M>F%D86IT92!S=F]J92!P;W6^[79A=&6U<VOI(&UE;F\@82!H97-L;P!0<F7H
M[71A:G1E('-I('!R;W/M;2!N87-L961U:OIC:2!T97AT+B!-55/-5$4@<_IH
M;&%S:;L@<R!P;V1M:65N:V%M:2!P;W6^[79A;FEA('-Y<W3I;74N`%IA9&%J
M=&4@<')O<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S<FEU.@!0;[5S:V\`4&]L
M:71I:V$`06YK971Y`%!O<G1U9V%L<VMO`%5M:65S=&YE;FEE('1O:'1O(&]B
M<N%Z:W4`56UI97-T;F5N:64@=&5J=&\@=&%B=;5K>0!/9&]S;&&[(&1O('1O
M:'1O('!R:67H:6YK82`H;F5V>6YU8W5J92!)34%0*0!:<N&^:WD@>F$@<&]S
M;&5D;OUC:"`E<R!H;V3M;CH@`%!R879D97!O9&]B;F]SNSQB<B`O/GIRX;YO
M:P!0<F5F<U]L9&%P.B!P;[YA9&]V86[I(')O>KGM<F5N:64@3$1!4"!N96)O
M;&\@;N%J9&5NZ2X`4')E9G-?<V5S<VEO;CH@<&^^861O=F%NZ2!R;WJY[7)E
M;FEE('-E<W-I;VX@;F5B;VQO(&[A:F1E;NDN`%1L86L`5&QA:R!N82#Z<F]V
M;FD@;6]R83H@`%1L86LZ(`!5:^&^:V$`6F]B<F%Z:;L@=6OAOFMU(&]B<N%Z
M:W4@=B!N;W9O;2!O:VYE`%!R961C:.%D>F%J^F-A`%!R961C:.%D>F%J^F-E
M(&YA<W1A=F5N:6$`5GET;&'H:;L@9&]K=6UE;G0`4')I=N%T;GD@861R97/A
M<@!0<FEVX71N>2!KM?KH`%!R;V)LZ6T`4&]P:7,@<')O8FSI;74`4')O:F5K
M='D`5OUZ=F$@;F$@>F%D86YI92!T97AT=0!697)E:F[](&NU^N@`06QG;W)I
M=&UU<R!V97)E:F[I:&\@:[7ZZ&$`26YF;W)MX6-I92!O('9E<F5J;F]M(&NU
M^NAI`%9E<F5J;OTO<')I=N%T;GD@:[7ZZ&]V_2!PX7(@;F5B;VP@^G-P9;EN
M92!V>6=E;F5R;W9A;OTN`%!O<G1O<FEK;P!+871A<@!$;W1A>@!#:'EB;N$@
M<&^^:6%D879K83H@*"5S*2`E<P!2_6-H;&4@:+5A9&%N:64`2W;S=&$`4E-!
M('9E<F5J;OT@:[7ZZ"`H)60@8FET;W8I`%!R97#M;F'H(',@=OUB97)O;0!$
MX;[O`%+A;F\@9.&^[P!.97-K]'(@9.&^[P!$8;[O;W;I('!R96CA;FMY`$3A
MON\@<V\@<VYE:&]M`$3AON\@<')E8VCA9'IA:OIC:2!V('-N9;YE;FEE`$[A
M:&]D;N$@9F]R='5N80!0;VUE<@#([71ANP!#:'EB82!P<FD@Z.UT86[M.B`H
M)7,I("5S`,CM=&&[('-P<N%V>0#([71A;FEE(&MO;G1A:W1O=B!N:64@:F4@
M9&]S='5P;NDN`$YA;WIA:B!V>6UA>F&[("5S/R!4^G1O(&]P97+A8VEU(&YE
M;6^^;F\@=G+A=&F[('-PY+LN`$YA;WIA:B!S:2"^96SA=&4@=GEM87IANR!T
M96YT;R!K;VYT86MT/P!.86]Z86H@=GEM87IANR!P;W6^[79A=&6U<VOI(/ID
M86IE('!R92!P;W6^[79A=&6U82`E<S\@5/IT;R!O<&5RX6-I=2!N96UOOFYO
M('9RX71INR!S<.2[+@!:;V)R87IE;ND@<&]L;[YK>3H`5G+A=&D@<W#DNR!6
M8;EU('!O<VQE9&[Z(&%K8VEU`$]B;F]V:;L`3V)N;W9INR!E;&5M96YT>2!D
M>6YA;6EC:^EH;R!M96YU.@!/8FYO=FF[('IO8G)A>F5N:64@<&]R=.%L=3H`
M4F5G=6SA<FYY(';]<F%Z`%!R96AL:6%D8>@@=GJ[86AO=@!:;F]V=2!N8>CM
M=&&[`%!O<W1R96AY`%9Z9&EA;&5NZ2!S97)V97)Y`%9Z9&EA;&5NX2!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!/9'-T<N%N:;L`3V1S
M='+A;FF[(&)L;VL`5GEM87IANR!A9')E<^%R`$]D<W1RX6YINR!S=.5P96,`
M3V1S='+A;FF[(&9O<FWA=&]V86YI90!/9'-T<N%N:;L@>F\@>F]Z;F%M=0!/
M9'-T<N%N:;L@<.%R`$]D<W1RX6YINR!U;&^^96[]('-K<FEP="!Z(&1OZ&%S
M;NEH;R!P<FEEZ&EN:V$@;F$@<V5R=F5R:2X`3V1S='+A;FF[`$]D<W1RX6YI
MNR!T96YT;R!B;V0@>B!D;VMU;65N='4`3V1S='+A;FF[('!O=;[M=F%T9;5A
M`$]D<W1RX6YINR!P;W6^[79A=&6U83H@)7,`4')E<.US8;L@97AI<W1U:OIC
M:2!A9')E<^%R(&EM<&]R=&]V86[];2!A9')E<^%R;VT_(#QS=')O;F<^5F%R
M;W9A;FEE.B!T;W1O('9Y;6&^92!VN65T:WD@<&]L;[YK>2!V;R!68;EO;2!A
M:W1UX6QN;VT@861R97/A<FDN/"]S=')O;F<^`$YA('!OOFEA9&%V:W4@;F5B
M;VQO(&UOOF[I(&]D<&]V961ANRX@3N%V<F%T;W;](&OS9"!C:'EB>3H@`%!O
MOF%D;W9A;OT@;V)J96MT(&YE8F]L(&[A:F1E;OT`4&^^861O=F%N^B!S;'6^
M8G4@<V$@;F5P;V1A<FEL;R!NX6ISNRX`5B!K;VYF:6=U<N%C:6D@)7,@;FEE
M(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA("(E<R(`5B!K
M;VYF:6=U<N%C:6D@5D93(&YI92!J92"Y<&5C:69I:V]V86[A('!OOF%D;W9A
M;N$@<&]L;[YK82`B)7,B`%8@:V]N9FEG=7+A8VEI(&YI92!J92"Y<&5C:69I
M:V]V86[A('!OOF%D;W9A;N$@<&]L;[YK82`B)7,B`%!O=FEN;ND@<&]L90!6
M>6UA>F&[(&9O<FUU;.%R`$]B;F]V:;L@:&5S;&\`3V)N;W9INR!68;EE(&AE
M<VQO`$]B;F]V:;L@;F$@<')E9&YA<W1A=F5NZ2!H;V1N;W1Y`$]B;F]V:;L@
M<&]S;&5D;OT@9&]T87H`5OUS;&5D:WD`3N%V<F%T(&YA(&YA<W1A=F5N:6$`
M6F%D86IT92!N;W;I(&AE<VQO`%)E=6YI;VX`5G+A=&F[(&MO;F9I9W5RX6-I
M=0!.87-T879E;FEA(')O>KGM<F5NZ6AO('1E>'1O=NEH;R!E9&ET;W)U`$CA
M9&%N:WD`5G!R879O`$AL879IZ&MA('9P<F%V;P!(;V1N;W1Y('9P<F%V;P!6
M;&%S=&YO<W1I(%]R:6%D:V$N+BX`4F]L80!2=6UU;G-K;P!/=&_H:;L@;R`Q
M.#``3W1OZ&F[(':U879O`$]T;^AINR!V<')A=F\`5FQA<W1N;W-T:2!R:6%D
M:V$`5FQA<W1N;W-T:2!R:6%D:V$`4FEA9&MY.@#(:6%R>0#(:6%R>2!S82!Z
M;V)R87II82!M961Z:2!VN65T:_UM:2!R:6%D:V%M:2!A('-TY7!C86UI`,AI
M87)Y('-A('IO8G)A>FEA(&EB82!M961Z:2!S=.5P8V%M:0#(:6%R>2!S82!Z
M;V)R87II82!I8F$@;65D>FD@<FEA9&MA;6D`4W!U<W1INP!2=7-KX2!F961E
M<N%C:6$`4G=A;F1A`%,O34E-12!K<GEP=&]G<F%F:6-K_2!P;V1P:7,`4W!R
MX79A('IAN6EF<F]V86[A('!O;6]C;W4@4R]-24U%`%9E<F5J;OT@4R]-24U%
M(&-E<G1I9FEKX70`4T%33"!A=71E;G1I9FEKX6-I82!N:64@:F4@9&]S='5P
M;N$N`%!O<VEE;&%N:64@4TU3`%-13"!3:&5L;`!344P@<'+M:V%Z('!R92!H
MM6%D86YI92!H;V1N]'0`4U-(`$-H>6)A('!R:2!35$%25%1,4SH@*"5S*2`E
M<P#:4U!%0T@`4U]13"!3:&5L;`!3;P!3=N1TX2!(96QE;F$`4W;D=/T@2VET
M=',@82!.979I<P!3=N1TX2!,=6-I80!3=BX@4&EE<G)E(&$@36EQ=65L;VX`
M4W;D=/T@5FEN8V5N="!A($=R96YA9&EN>0!496X@:7-T_2!RX6UE8R`H7W-E
M;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@82!0<FEN8VEP90!3871E
M;&ET;OT@<&]S:WET;W9A=&6U`%-A=61S:^$@07+A8FEA`%5L;[YINP!5;&^^
M:;L@(B5S(@!5;&^^:;L@)7,`56QOOFF[(&YA<W1A=F5N:6$`56QOOFF[('9Y
M9V5N97)O=F%N^B!K;VYF:6=U<N%C:74@86MO(%!(4"!S:W)I<'0@9&\@9&_H
M87-NZ6AO('!R:67H:6YK82!6X;EH;R!S97)V97)A+@!+;VYF:6=U<N%C:6$@
M)7,@8F]L82!U;&^^96[A+@!3:W)I<'0@;F$@=7!G<F%D92!N87-T879E;NT@
M8F]L('5L;[YE;OT@9&\Z("(E<R(N`%5K;&%D86YI92!K;VYT86MT;W8@;FEE
M(&IE(&1O<W1U<&[I+@!/:F5D:6YE;.D@8OIR:WD`5F5D80!(M6%D8;L`5GEH
MM6%DX79AZ&4`2+5A9&%N:64@>FQY:&%L;P!(M6%D86YI92!Z;'EH86QO.B`E
M<P!(M6%D86YI92!N:64@:F4@9&]S='5P;NDN`$BU863A;2XN+@!6>6)E<G1E
M('/Z8F]R>0!6>6)E<G1E(&3A='5M`%9Y8F5R=&4@<VMU<&EN=2!N82!P<FED
M86YI90!6>6)E<G1E(&YO=NEH;R!V;&%S=&[M:V$`5GEB97)T92!S97)V97(`
M5GEB97)T92!P;W6^[79A=&6U82!N82!P<FED86YI90!6>6)E<G1E(':Y971K
M>0!6>6)E<G1E(':Y971K>2!K;VUP;VYE;G1Y(&3A='5M=0!:=F^U=&4@861R
M97/A<BP@:W1O<OT@8VAC971E('9Y;6%Z8;L`6G9OM71E(&%D<F5SX7(L(&MT
M;W+](&-H8V5T92!U<')A=FF[`%9Y8F5R=&4@;V)J96MT`%IR=;EINR!V_6)E
M<@!:=F^U=&4@861R97/A<BP@>B!K=&]RZ6AO(&-H8V5T92!E>'!O<G1O=F&[
M.@!:=F^U=&4@861R97/A<BP@9&\@:W1O<NEH;R!C:&-E=&4@:6UP;W)T;W9A
MNSH`5GEB97)T92!Z;F%K>2P@:W1O<ND@<&]T<F5B=6IE=&4L('H@;VMI96YO
M:R!N:;ZY:64N(%!O=&]M(&EC:"!M]+YE=&4@<VMO<.UR;W9ANR!A('9L;[YI
MNR!Z('1E>'1O=NEH;R!P;[5A+@!:=F^U=&4@>FYA:V]V^B!S861U('ID<F]J
M;W;I:&\@<_IB;W)U.@!6>6)E<G1E(&]D9&6U;W9AZ"!V;R!F;W)MX71E(&3A
M='5M=3H`5GEB97)T92!F;W)MX70@9.%T=6UU.@!6>6)E<G1E(&9O<FWA="!E
M>'!O<G1U.@!:=F^U=&4@<_IB;W(@<')E(&EM<&]R=#H`6G9OM71E(&9O<FWA
M="!E>'!O<G1U.@!:=F^U=&4@9F]R;>%T('IO8G)A>F]V86YI82!M:65N.@!6
M>6)E<G1E(&ED96YT:71U+"!K=&]R^B!C:&-E=&4@>FUE;FF[.@!6>6)E<G1E
M(&]D9&6U;W9AZ"!V;R!F;W)MX71E(.AA<W4Z`%9Y8F5R=&4@9F]R;>%T(.AA
M<W4Z`%9Y8F5R=&4@9'9E('IH;V1NZ2!P;VQI82X`3F%S=&%V96YI92"Y=&%N
M9&%R9&[I:&\@<W#T<V]B=2!Z;V)R87IE;FEA+"!T<FEE9&5N:6$@82!S='+A
M;FMO=F%N:6$N`$YA<W1A=F5N:64@<&]L[2P@:W1O<ND@<V$@8G5D^B!Z;V)R
M87IO=F&[('8@>F]Z;F%M92!A9')I97,N`$YA<W1A=F5N:64@9F]R;>%T=2!Z
M;V)R87IO=F%N:6$@;6EE;BX`5GEB97)T92!S:2!F87)E8F[Z('-C:.EM=0!6
M>6)E<G1E(&IA>GEK.@!";VP@=GEB<F%N_2!A9')E<^%R("(E<R(N`%!O<VQA
MNR!S<'+A=G4@;R!P<F]B;.EM90!0;W-L8;L@4TU3`%-E;F5G86P`4V5N>F]R
M.B``4V5P=&5M8F5R`%-R8G-K;R!A(,AI97)N82!H;W)A`%/I<FEO=ND@Z.US
M;&\`VF1A:F4@>F\@<V5R=F5R82!S^B!N97-P<N%V;F4@86QE8F\@;FEE('/Z
M(&1O<W1U<&[I+@!!9&UI;FES='+A8VEA('-E9&5N[0!0;&%T;F]SNR!)1"!S
M961E;FEA('9Y<'*Y86QA+@!3961E;FEA`$UN;[YI;F$@:&]D;O1T`$YA<W1A
M=G1E(&UOOFYO<W1I(&YA(&]B;F]V96YI92!6X;EH;R!H97-L82!A:R!H;R!Z
M86)U9&YE=&4N`$YA<W1A=F5N:64@=GID:6%L96[]8V@@<V5R=F5R;W8L(&MU
M(&MT;W+];2!C:&-E=&4@<')I<W1U<&]V8;L@>B!6X;EH;R!P;W)TX6QU+@!6
M>6)E<G1E(&IA>GEK+"#H87-O=OH@>O-N=2!A(&YA<W1A=F5N:6$@9.%T=6UU
M+@!.87-T879E;FEE(&%P;&EKX6-I92!S</JYNV%N96H@<')I(+ET87)T92P@
M9F%R96)N96H@<V-HZ6UY+"!I;G1E<G9A;'4@;V)N;W9O=F%N:6$@<W1RX6YK
M>2!A(&EN_6-H('9L87-T;F]S=.T@>F]B<F%Z96YI82X`3F%S=&%V96YI90!3
M^B!D;W-T=7!NZ2!S:W)I<'1Y(&YA('5P9W)A9&4@;F%S=&%V96[M`$1O(/IV
M86AY('!R:6-HX61Z82!N:65K;[5K;R!L;VMA;.UT('!O;6]C;W4@<&%R86UE
M=')A.B``4V5Y8VAE;'D`6F1I9;5A;OT@861R97/A<@!3:&]P<&EN9P!+<N%T
M:WD@<_IH<FX`36%J^B!S82!P<F4@=N3HN6EN=2!L:6YI96L@=GET=F]R:;L@
M<VMR871K;W;I(&MLX79E<WD_`%IO8G)A>FF[`%IO8G)A>FF[("5S`%IO8G)A
M>FF[(':Y971K;P!:;V)R87IINR!K;VYT86MT>0!:;V)R87IINR!Z;WIN86UY
M`%IO8G)A>FF[(')O>F1I96QY(&UE9'II('!RX79E('5L;[YE;F]U(&$@;F]V
M;W9Y9V5N97)O=F%N;W4@:V]N9FEG=7+A8VEO=2X`3>$@<V$@<')I('!R:6AL
MX7-E;NT@>F]B<F%Z:;L@Z&%S('!O<VQE9&[I:&\@<')I:&SA<V5N:6$_`%IO
M8G)A>FF[(&UOOFYO<[L@;F$@<&]N96-H86YI92!O<FEG:6[A;'4`6F]B<F%Z
M:;L@;N%S=')O:B!N82!V_6)E<B!F87)I96(`6F]B<F%Z:;L@;65N=2!P<F4@
M;W!E<N%C:64@<R!T86)UM6MA;6D_`%IO8G)A>FF[(&UE;G4@)7,@;F$@M6%V
M96H@<W1R86YE/P!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@8G5N
M:WD@=&%B=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@=&%B
M=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@<FEA9&MU('1A
M8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI(&]B<N%Z:W4`
M6F]B<F%Z:;L@;F%H<F%NZ0!0<F5HX6YK>0!2X6YO('!R96CA;FMY`$YE<VOT
M<B!P<F5HX6YK>0!:<N&^:WD@=B!O:V]L[0!:;65NN6F[`$YA:G!R=B!M=7/M
M=&4@>FUE;KEINR!A;&5B;R!P<F5S=6[ZNR!S=7-E9&[](&)L;VLH>2D`4VEE
M<G)A($QE;VYE`%IA<F5G:7-T<F]V8;L@<V$`4&]D<&ES`$%L9V]R:71M=7,@
M<&]D<&ES=0!3:6YG87!U<@!69;5K;W.[`%!R97-K;^AINR#Z9'*^8G4`4VQO
M=F5N<VMO`%-L;W9I;G-K;P!3;F6^96YI90!3;F5H;W;A('!R96CA;FMA`%-N
M96AO=ND@<')E:.%N:WD`4N%N;R!S;F5H;W;I('!R96CA;FMY`$YE<VOT<B!S
M;F5H;W;I('!R96CA;FMY`$CE8FMA('-N96AU.B``36YOOG-T=F\@=F]D>2!E
M:W9I=F%L96YT;ND@<VYE:'4Z(`"I86QA;?IN;W9E(&]S=')O=GD`4V]MX6QS
M:V\`4&EE<VYE(&$@8N%S;F4`4VUE<B!T<FEE9&5N:6$`5OUB97(@<VUE<G4@
M=')I961E;FEA`%ID<F]J;W;A(&%D<F5S80!:9')O:F4`2G6^;N$@069R:6MA
M`$IUOF[A($=E;W)G:6$@82!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$IUOF[A
M('!O;&]G=;5A`$UE9'IE<F$@;65D>FD@<W5S961N_6UI(&)U;FMA;6D`365D
M>F5R82!M961Z:2!O8G-A:&]M(&$@;VMR86IO;2!B=6YK>0!/9&1EM6]V8>@`
M3V1S='5P`$]D<W1U<"!A('9Y<&QN96YI90"I<&%N:65L<VMO`%-P86T`5FQO
MOF5N:64@N7!E8VGA;&YY8V@@>FYA:V]V`*EP96-I9FEK=6IT92P@:V1E('-A
M(&UA:OH@;V)J879INR!R;WJY[7)E;ND@=OUS;&5D:WD@:+5A9&%N:6$N`%)O
M>F1E;&F[(&)U;FMU`%)O>F1E;&F[('-TY7!E8P!2;WID96QINR!R:6%D;VL`
MJ7!O<G1Y`%-R[2!,86YK80"I=&%N9&%R9&[I`%-T87(@5')E:P!0;^AI871O
MZ&[](')O:P"I=.%T(&%L96)O('!R;W9I;F-I80!3=&%V`$9O<FWA="!U;&^^
M96YI80!">61L:7-K;P!0<F6Y:W)T;G5TZ0!:;WIN86T@<F6[87IC;W8`3V1S
M='+A;FF[(&1O;>EN=2!Z(&%D<F5S>0"I=/UL(%M#4U-=`$YE`%!O9'!R:67H
M:6YO:R`B)7,B(&YE8F]L(&[A:F1E;OTN`%!R961M970`3V1O<VQANP!0;[YI
M861A=FMA(&YA('!R:61A;FEE("(E<R(@9&\@<WES=.EM=2!B;VQA(&]D;W-L
M86[A+B!.96WTOF5T92!S82!P<FEH;.%S:;LL(&O];2!N96)U9&4@5F&Y82!P
M;[YI861A=FMA('-C:';A;&5NX2X`1&]L;OT@:6YD97@`VG-P96-H`%!R:61A
M;FEE("(E<R(@9&\@<WES=.EM=2!B;VQO(/IS<&6Y;NDN`%!R:61A;FEE("5D
M(&MO;G1A:W1O=B!D;R!Z;WIN86UU(&)O;&\@^G-P9;ENZ2X`4')I9&%N:64@
M)7,@9&\@)7,@8F]L;R#Z<W!EN6[I`%9Y;6%Z86YI92#Z9&%J;W8@>F\@<WES
M=.EM=2!P<F4@<&]UONUV871EM6$@(B5S(B!B;VQO(/IS<&6Y;NDN`%9Y='9O
M<F5N:64@>F]Z;F%M=2!K;VYT86MT;W8@(B5S(B!B;VQO(/IS<&6Y;NDN`%9Y
M;6%Z86YI92`B)7,B(&)O;&\@^G-P9;ENZ2X`5GEM87IA;FEE("5D(&MO;G1A
M:W1O=B!B;VQO(/IS<&6Y;NDN`%9Y;6%Z86YI92`B)7,B('IO('-Y<W3I;74@
M8F]L;R#Z<W!EN6[I+@!6>6UA>F%N:64@)60@:V]N=&%K=&]V('IO('IO>FYA
M;74@8F]L;R#Z<W!EN6[I+@!.X79R870@:W4@:V]N9FEG=7+A8VEI(&)O;"#Z
M<W!EN6[]+B!0<F4@>F]B<F%Z96YI92!Z;6EE;B!Z;F]V=2!N8>CM=&%J=&4@
M<W1RX6YK=2X`6N%L;VAA(&MO;F9I9W5RX6-I92!B;VQA('5L;[YE;N$N`%KA
M;&^^;OT@:V]N9FEG=7)AZ&[]('/Z8F]R("5S(&)O;"#Z<W!EN6YE('5L;[YE
M;OTN`$%K='5A;&EZX6-I82`B)7,B(&)O;&$@^G-P9;ENX2X`6N%P:7,@)7,@
M8F]L(/IS<&6Y;OT`4W5DX6X`4_IH<FX`5OUC:&]D('-L;FMA`%KA<&%D('-L
M;FMA`%-L;F7H;F\`5OUC:&]D('-L;FMA`%;]8VAO9"]ZX7!A9"!S;&YK80!6
M_6-H;V0@<VQN:V$Z(`!:X7!A9"!S;&YK80!:X7!A9"!S;&YK83H@`$AO<F[]
M(&EN9&5X`%!O9'!O<F$`4W5R:6YA;0!0<FEE>G9I<VMO`%-V86QB87)D(&$@
M2F%N($UA>65N`%-V87II:G-K;P"I=NED<VMO`*EV86KH:6%R<VMO`%KA>FYA
M;7D@;R!S>6YC:')O;FEZX6-I:2!V>6UA>F%NZ0!3>6YC34P`4WEN=&%K=&EC
M:^$@8VAY8F$@=B!P;V1M:65N:V%C:"!HM6%D86YI80!3_7)I80!"^G)K80!"
M^G)K82!A('9E=&5R;F\`0OIR:WD`4N%N;R!B^G)K>0!44U8@*&AO9&YO='D@
M;V1D96QE;ND@=&%B=6SA=&]R;VTI`%135B!S^F)O<@!(;V1N;W1Y(&]D9&5L
M96[I('1A8G5LX71O<F]M`%1A8G6U:V$`5FQA<W1N;W-T:2!T86)UM6MY`%9L
M87-T;F]S=&D@=&%B=;5K>0!486EW86X`5&%I=V%N+"!P<F]V:6YC:6$@R.UN
M>0!4862^:6MI<W1A;@!486YZX6YI80!#:66U.@#:;&]H>0!496QE9O-N;F4@
MZ.US;&\`5&5P;&]T82!Z82!P;W-L961N^B!H;V1I;G4Z(`!497!L;W1A`%1E
M<&QO=&$Z(`!497!L;W1A/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE
M<P"I86)L\VYA("(E<R(@;F5B;VQA(&[A:F1E;N$N`%-P<N%V82"Y86)L\VX`
M5&5X=`!)8F$@=&5X=`!:87)O=FYA;FEE('1E>'1U`%1E>'0@:&]R90"I=`!4
M:&%J<VMO`%)O>KGM<F5N:64@1E10(&YI92!J92!D;W-T=7!NZ2X`26YT96=R
MX6-I82!(;W)D92]+;VQA8B!N97!O9'!O<G5J92`B)7,B`$E-4U`@>N%Z;F%M
M('-A(&YE<&]D87)I;&\@=6QOOFF[+@!4<FEE9&$@36%I;G1E;F%N8V4Z.B!S
M82!N96YAZ.UT86QA(/IS<&6Y;F4`3VMN;R!S(&YA<W1A=F5N:6%M:2!S82!Z
M871V;W)I;&\N($MO;FEE8RX`06)Y('-T92!M;VAL:2!N86ARX79ANR!P<NUL
M;VAY+"!M=7/M(&)YNR!N86MO;F9I9W5R;W9A;OT@5D93(&)A8VME;F0N`$%D
M<F5SX7(@(B5S(B!N965X:7-T=6IE+@!!9')E<^%R("(E<R(@8F]L(/IS<&6Y
M;F4@=GET=F]R96[]+@!!9')E<^%R("(E<R(@8F]L(/IS<&6Y;F4@=GEM87IA
M;OTN`$%D<F5SX7(@(B5S(B!B;VP@^G-P9;EN92!A:W1U86QI>F]V86[]+@!!
M9')E<^%R('-A(&YE<&]D87)I;&\@=GEM87IANSH@)7,`061M:6YI<W1RX71O
M<B!M=7/M(&YA:V]N9FEG=7)O=F&[('!E<FUA;F5N=&[](&)A8VME;F0@<')E
M(%!RX79A+"!A:R!C:&-E=&4@<&]UONUV8;L@4'+A=F$N`$EB82!S<&]D;N$@
M<W1R86YA`$E$(.CM<VQO(&MO;G1A:W1U(&YE8F]L;R"Y<&5C:69I:V]V86[I
M+"!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE(&%L96)O(&YE8F]L;R!NX6ID96[I
M('8@9&%T86+A>F4N`$MO;G1A:W0@8F]L(/IS<&6Y;F4@=FQOOF5N_2!D;R!6
MX;EH;R!A9')E<^%R82X`4&^^861O=F%N_2!K;VYT86MT(&YE97AI<W1U:F4N
M`$YA(&]V97)E;FEE('!O9'#M<V%N96H@<W!RX79Y(&IE('!OOF%D;W9A;OT@
M;V1D96QE;OT@8FQO:R!S(%!'4"!P;V1P:7-O;2X`240@>F]Z;F%M=2!P<NUJ
M96UC;W8@8G7O(&YE8F]L;R"Y<&5C:69I:V]V86[I+"!A;&5B;R!B;VQO('!O
M;F5C:&%NZ2!P<N%Z9&YE(&%L96)O(&YE8F]L;R!NX6ID96[I('8@9&%T86+A
M>F4N`$YE8F]L('5RZ&5N_2!Z;WIN86T@<'+M:F5M8V]V+@"I:69R;W9A;FEE
M('9YOF%D=6IE(&)E>G!EZ&[I('!R:7!O:F5N:64@*&AT='!S*2X`4_IB;W(@
M(B5S(B!B;VP@^G-P9;EN92!V>6UA>F%N_2X`4_IB;W(@)7,@8GD@;6%L(&]B
M<V%H;W9ANR!N87-T879E;FEE("5S+@!3^F)O<B`E<R!B>2!M86P@;V)S86AO
M=F&[(&YI96MT;W+I(&YA<W1A=F5N:6$@)7,N`%ID<F]J;W;](&$@8VEEM6]V
M_2!S^F)O<B!M=7-I82!B>;L@;V1L:;ENZ2X`4_IB;W(@;F5O8G-A:&]V86P@
MOFEA9&YE(/ID86IE+@!.87-L961U:OH@:&QA=FGH:WD@=&5J=&\@<W!RX79Y
M('9O(&9O<FWA=&4@;65S<V%G92]R9F,X,C(N`$-E;&]O8G)A>F]V:V]V_2!R
M9;YI;2!S</1S;V)U:F4@<')O8FSI;7D@=B!);G1E<FYE="!%>'!L;W)E<FD@
M:W;T;&D@8VAY8N%M('!R96AL:6%D8>AA+"!K=&]RZ2!S82!NX6T@;F5P;V1A
M<FEL;R!O8NUSNRX@3?2^=2!S82!P<F5J879INR!N97-P<N%V;GEM('IO8G)A
M>F5N[6TL(&-H_6)A:OIC:6UI(&9U;FMC:6%M:2!E9&ET;W)A(&$O86QE8F\@
M;N%H;V1N_6UI('#A9&UI('!R96AL:6%D8>AA+B!!:R!J92!6X;D@<WES=.EM
M(%=I;F1O=W,@.7@L(&IE('9EM6UI('!R879D97!O9&]B;NDL(+YE('-A('IO
M8G)A>NT@8VAY8F$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@82!B=61E
M=&4@;75S:66[(')EN71A<G1O=F&[('!OZ.UT8>@N7&Y<;E9A<F]V86QI('-M
M92!6X7,N(%-T;&'H=&4@<')O<^UM($]+(&%K(&YA;WIA:B!C:&-E=&4@<&]U
MOFF[(&5D:71O<B!V(&-E;&]O8G)A>F]V:V]V;VT@<F6^:6UE+@!)9&5N=&ET
M82`B)7,B(&)O;&$@=GEM87IA;N$N`$EM<&]R="!S82!DX2!D;VMO;NAINR!N
M87!R:65K('9A<F]V86YI86TN`$EB82"U87;A('-T<F%N80!4<FEE9&$@0W)Y
M<'1?<&=P.CH@<&]T<F5B=6IE('!O>FYANR!U;6EE<W1N96YI92!P<F]G<F%M
M=2!';G501RX`4W!RX79A(&]D;W-L86[A("5S('!R92`E<R!S('!R961M971O
M;2`B)7,B(&)O;&$@>F]B<F%Z96[A+@I.965X:7-T=6IE(':Y86L@>N%R=6MA
M+""^92!S<'+A=F$@8F]L82!P<F7H[71A;N$@86QE8F\@<&]C:&]P96[A+@!-
M96YO+"!K=&]RZ2!S82!MX2!P;W6^:;L@<')I(&QI;FMO=F%N[2!N82!S='+A
M;FMU(&YA('#M<V%N:64@<W!RX78@`%!OZ&5T('!O;.T@;75S[2!B>;L@Z.US
M;&\N`%1R:65D82!(;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L
M(&]P96YS<VPN`$YA<W1A=F5N:64@(B5S(B!S82!N97!O9&%R:6QO('5L;[YI
MNRP@<')E=&^^92!J96AO(/ID86IE('!R96MR8>AU:OH@;6%X:6WA;&YU('!O
M=F]L96[Z('9EM6MO<[L`4')O9W)A;2!P;W6^[79A;OT@;F$@>F]B<F%Z96YI
M92!T;VAT;R#Z9&%J;W;I:&\@='EP=2`H)7,I(&YE8F]L(&[A:F1E;OTN`%IN
M86L@8VETX6-I92!M=7/M(&)YNR!J961E;B!Z;F%K+@!)8F$@<')A=N$@82"U
M87;A('-T<F%N80!)8F$@<')A=N$@<W1R86YA`$]D9&6U;W9AZ"!M=7/M(&)Y
MNR!J961E;B!Z;F%K+@!397)V97(@(B5S(B!B;VP@=GEM87IA;OTN`%-E<G9E
M<B`B)7,B(&)O;"!U;&^^96[]+@"N:6%D;W.[(&\@<')I:&SA<V5N:64@)7,@
M8F]L82!V>6UA>F%NX2X`J7!E8VEF:6MO=F%N_2!R:6%D;VL@;F5E>&ES='5J
M92X`1&_H87-N_2!S^F)O<B`B)7,B(&YE97AI<W1U:F4N`%IA9&%N_2!T97AT
M(&YI92!J92!R;W9N86O](&%K;R!T97AT(&YA(&]B<F%Z;W9K92X`26)A(&AO
M<F[A(&$@<W!O9&[A('-T<F%N80!)8F$@:&]R;N$@<W1R86YA`$YA:')A;ND@
M^F1A:F4@<V$@;V0@<')E9&-HX61Z86KZ8V5H;R!K<F]K=2!S=')A=&EL:2X`
M3F%H<F%N_2!S^F)O<B!S82!N97!O9&%R:6QO('5L;[YINRX`0FQO:R!W96%T
M:&5R+F-O;2!N:64@:F4@9&]S='5P;OTN`%!R:67H:6YO:R!TZ6T@(B5S(B!N
M96)O;"!NX6ID96[]+@"N:6%D;F4@861R97/A<F4@;FEE('/Z('!R[7-T=7!N
MZ2!N82!P<F5Z97)A;FEE+@"N:6%D;F4@;F%S=&%V96YI82!N:64@<_H@9&]S
M='5P;NDN`*YI861N92!A;'1E<FYA=.UV;F4@Z&%S=&D@;F5M;[YN;R!Z;V)R
M87IINR!V('1E;&4@<W!RX79Y+@"N:6%D96X@>B!D;W-T=7!N_6-H(&%D<F5S
MX7)O=B!N975M;[[R=6IE('9K;&%D86YI92!N;W;]8V@@<&]L;[YI96LN($%K
M('!R961P;VML863A=&4L(+YE(&ED92!O(&-H>6)U+"!K;VYT86MT=6IT92!P
M<F]S[6T@<W!RX79C=2!6X;EH;R!S>7-TZ6UU+@!6('1O;71O('!O;&D@:F4@
M<'+M;&FY('9EM6$@>FYA:V]V+B!:861A;&D@<W1E("5S('IN86MO=CL@;75S
M[71E('IA9&&[(&UE;F5J(&%K;R`E<RX`3F%S=&%L82!C:'EB82!P<FD@<')I
M9.%V86[M("(E<R(@9&\@<WES=.EM=3H@)7,`3F%S=&%L82!C:'EB82!P<FD@
M;V1S=')A\F]V86[M('!O=;[M=F%T9;5S:_UC:"#Z9&%J;W8@(B5S(B!Z;R!S
M>7-TZ6UU.B``3F%S=&%L82!C:'EB82!P<FD@;V1S=')A\F]V86[M("(E<R(@
M>F\@<WES=.EM=3H@`$YA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2`B
M)7,B.B`E<P!6>7-K>71O;"!S82!P<F]B;.EM(',@;F%H<N%V86[M;2!S^F)O
M<G4Z(*YI861E;B`E<R!N96)O;"!N86AR86[]+@!6>7-K>71O;"!S82!P<F]B
M;.EM(',@;F%H<N%V86[M;2!S^F)O<G4Z("5S(&)O;"!VY.BY[2!A:V\@;F%J
M=N3HN>T@<&]V;VQE;OT@;&EM:70@*"5D(&)A:G1O=BDN`%9Y<VMY=&]L('-A
M('!R;V)LZ6T@<R!U:VQA9&%N[6T@<_IB;W)U.B`E<R!B;VP@;F%H<F%N_2!L
M96X@Z&EA<W1OZ&YE+@!.87-T86QA(&-H>6)A('!R:2!P<FEDX79A;NT@=&]H
M=&\@:V]N=&%K='4N(%!R;W/M;2!K;VYT86MT=6IT92!S<'+A=F-U(%;AN6AO
M('-Y<W3I;74N`$YA<W1A;&$@8VAY8F$@<')I('9Y=';A<F%N[2!N;W;I:&\@
M>F]Z;F%M=2X`3F%S=&%L82!C:'EB82!P<FD@=GET=N%R86[M('1O:'1O(&%D
M<F5SX7)A.B`E<P!.87-T86QA(&-H>6)A('!R:2!V>6UA>N%V86[M("(E<R(@
M>F\@>F1R;VIO=NEH;R!A9')E<^%R82X`3F%S=&%L82!C:'EB82!P<FD@=GEM
M87KA=F%N[2!T;VAT;R!K;VYT86MT=3H@)7,N`$YA<W1A;&$@8VAY8F$@<')I
M('IO8G)A>F]V86[M('IO>FYA;74`3F%S=&%L82!C:'EB82!P<FD@>F]B<F%Z
M;W9A;NT@=&5J=&\@Z&%S=&D@<W!RX79Y`$YA<W1A;&$@8VAY8F$@<')I(&EM
M<&]R=&4@^F1A:F]V(&\@:V]N=&%K=&4N`$YA<W1A;&$@8VAY8F$@<')I(&EM
M<&]R=&4@^F1A:F]V.B`E<P!.87-T86QA(&-H>6)A('!R:2!I;7!O<G1E(/ID
M86IO=B!I0V%L96YD87(N`$YA<W1A;&$@8VAY8F$@=B!K;VYF:6=U<F'H;F]M
M(&9O<FUU;.%R:2X@4')A=F1E<&]D;V)N92!S=&4@;F5V>7!L;FEL:2!P;[YA
M9&]V86[I('!O;&4N`$YA<W1A;&$@8VAY8F$@<')I('9Y:V]NX79A;NT@=7+H
M96YE:B!F=6YK8VEE(&%D<F5SX7)A+B!0<F]S[6T@<VOZ<W1E('1O(&YE<VOT
M<BX`3F%S=&%L82!C:'EB82!P<FD@=GEM87KA=F%N[2!T;VAT;R!A9')E<^%R
M83H@)7,N`$YA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2!D971A:6QO
M=B!K;VYT86MT=2X@4')O<^UM('-K^G-T92!T;R!N97-K]'(N`$YA<W1A;&$@
M8VAY8F$@<')I(&%K='5A;&EZX6-I:2!Z;WIN86UU('!R[6IE;6-O=BX@4')O
M<^UM('-K^G-T92!T;R!Z;F]V=2X`3F%S=&%L82!C:'EB82!P<FD@86MT=6%L
M:7KA8VEI('1O:'1O(&%D<F5SX7)A.B`E<P!.87-T86QA(&-H>6)A('!R:2!A
M:W1U86QI>N%C:6D@=&5J=&\@<&]L;[YK>3H@)7,`3F5E>&ES='5J^B"^:6%D
M;F4@861R97/A<F4@;F$@97AP;W)T+@!!9')E<^%R92!S82!Z;V)R87II82!V
M('1O;71O('!O<F%D[3H`4W3E<&-E('-A('IO8G)A>FEA('8@=&]M=&\@<&]R
M863M.@!496YT;R!)34%0('-E<G9E<B!N97!O9'!O<G5J92!Z9&EEM6%N:64@
M<')I9>AI;FMO=BX`5&]T;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@
M87)C:.UV(')A<BX`5&]T;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@
M87)C:.UV('II<"X`5&]T;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;ND@
MZ.US;&\@:V%R='DN`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L86YI
M92!S<'+A=B!C97H@8G+A;G4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2!P;VUO8V]U($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U
M:F4@<&]S:65L86YI92!S<'+A=B!C97H@8G+A;G4@5TE.("AH='1P.B\O=VEN
M<&QC+F-O;2D@<&]M;V-O=2!(5%10($%020!496YT;R!O=FSA9&'H('5M;[[R
M=6IE('!O<VEE;&%N:64@<W!RX78@8V5Z(&)RX6YU('-M<S)E;6%I;"`H:'1T
M<#HO+W-M<S)E;6%I;"YC;VTI('!O;6]C;W4@2%144"!!4$D`5&5N=&\@;W9L
MX61AZ"!U;6^^\G5J92!P;W-I96QANR!S<'+A=GD@8V5Z(%--5%`@8V5Z(&)R
MX6YU(%9O9&%F;VYE($ET86QY("AI8F$@;F$@Z.US;&$@5F]D869O;F4I+B!6
M>;YA9'5J92!E+6UA:6QO=OT@^NAE="!6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+@!4;W1O('!O;&4@:F4@<&]V:6YNZ2X`5&]T;R!P;VQE
M(&WTOF4@;V)S86AO=F&[(&EB82#H[7-L82X`5&]T;R!P;VQE(&WTOF4@;V)S
M86AO=F&[(&EB82#H[7-L82!A(&1V;VIB;V1K=2X`5&]T;R!P;VQE(&WTOF4@
M;V)S86AO=F&[(&EB82!O<VUIZ&MO=ND@:&]D;F]T>2X`5&]T;R!P;VQE(&UU
M<^T@8GF[('IO>FYA;2#H[7-E;"!O9&1E;&5N_6-H(.AI87)K;W4@86QE8F\@
M;65D>F5R;W4`5&]T;R!P;VQE(&UU<^T@8GF[('!L871NZ2#H[7-L;RX`5&]T
M;R!P;VQE(&UU<^T@;V)S86AO=F&[(&OS9"!F87)B>2!V(+EE<W1NX7-T:V]V
M;VT@9F]R;>%T92!21T(L(&YA<'+M:VQA9"`G(S$R,S1A9B<N`%1E;G1O(&9O
M<FWA="!S^F)O<G4@;FEE(&IE('!O9'!O<F]V86[]+@!496YT;R!F;W)M=6SA
M<B!UOB!B;VP@<W!R86-O=F%N_2X`5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE
M:W0@2V]L86(@1W)O=7!W87)E+B!0<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE
M:W1U('!O=')E8G5J971E(&4M;6%I;&]VZ6AO(&ML:65N=&$L(&MT;W+](')O
M>G5M:64@9F]R;>%T=2!+;VQA8B!'<F]U<'=A<F4N(%!R92!Z;WIN86T@=&%K
M_6-H=&\@:VQI96YT;W8@;F%VN73M=G1E('!R;W/M;2`E<P!4X71O('-P<N%V
M82!B;VQA(&YA<.US86[A('8@:6YE:B!A:V\@5F%M:2!P;W6^[79A;F5J('IN
M86MO=F5J('-A9&4@*"5S*2X`5&]T;R#H[7-L;R!M=7/M(&)YNR!N86IM96YE
M:B`Q+@!4X71O(&]S;V)A('6^(&WA('KA>FYA;2`E<R!V(&%D<F5SX7)I+@!4
M96YT;R!S97)V97(@;F5D;VOAOF4@9&5K;VUP<FEM;W9ANR!S^F)O<GD@>FEP
M(&$@9WII<"X`4WES=.EM(&IE(&UO;65N=.%L;F4@9&5A:W1I=F]V86[]+@!4
MX71O(&AO9&YO=&$@;75S[2!B>;L@Z.US96QNX2X`5&]T;R!B=61E('!R961N
M87-T879E;OT@861R97/A<B!P<FD@<')I9.%V86[M(&%L96)O(&EM<&]R=&]V
M86[M(&MO;G1A:W1O=BX`5&]T;R!O:VYO(&UU<^T@8GF[('IA=F]L86[I('H@
M;VMN82!.87-T879E;NT`2')M96YI90!4:6-K971S`,AA<P!4:6UE(%1R86-K
M:6YG`$9O<FWA="#H87-U`%;]8F5R(.AA<W4`5&EM;W(M3&5S=&4`5&ET=6P`
M3F%D<&ES("AB=6)L:6YO=OT@=OUP:7,I.@!0<F4`4')E(';]8F5R('9I86-E
M<OUC:"!P;VQOOFEE:R!D<KYT92!P;^AA<R!K;&EK86YI82!K;.%V97-U($-O
M;G1R;VP@*%!#*2!A;&5B;R!#;VUM86YD("A-86,I+@!$;F5S`%!R97!N^KL@
M>F]B<F%Z96YI92!Z9')O:F]VZ6AO(&OS9'4@2%1-3`!4;V=O`%1O:V5L874`
M6F%J=')A`%1O;F=A`%9R8V@`5G)C:&[]('+A;65C("A?=&]P*0!0<F5K;&%D
M>0!4<FEN:61A9"!A(%1O8F%G;P!0<F%V9&$@86QE8F\@;F5P<F%V9&$`570`
M5'5N:7-K;P!4=7)E8VMO`%1U<FMM96YI<W1A;@!4=7)K<R!A($-A:6-O<P!4
M=79A;'4`6F%D86IT92!68;EU('9OM6)U.B``52Y6+B!I;F1E>#H@`%523`!5
M4DP@5N&Y:&\@<VMR:7!T=2!P<F4@<W!RX79U(&\@9&]R=>AE;NT`55),.@!5
M9V%N9&$`56MR86II;F$`3F5P;V1A<FEL;R!S82!U<VMU=&_H;FF[('!R[7-T
M=7`@:R!61E,@861R97/A<G4N`$YE<&]D87)I;&\@<V$@<')I9&&[(.]A;+EI
M92!I;F9O<FWA8VEE(&\@<&]UONUV871EM6]V:2!P<FD@<F5G:7-T<N%C:6DN
M`$YE<&]D87)I;&\@<V$@>FUE;FF[('!RX79O('!R92!61E,@<_IB;W(@(B5S
M(BX`3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@<')E(%9&4R!S^F)O<B`E
M<R\E<RX`3F5P;V1A<FEL;R!S82!Z;65N:;L@;F$@)7,N`$YE<&]D87)I;&\@
M<V$@<VMO;G1R;VQO=F&[('9EM6MO<[L@<_IB;W)U("(E<R(N`$YE<&]D87)I
M;&\@<V$@<VMO;G1R;VQO=F&[('9EM6MO<[L@<_IB;W)U("(E<R\E<R(N`$YE
M<&]D87)I;&\@<V$@<W!O:FF[(',@4U%,('-E<G9E<F]M+@!.97!O9&%R:6QO
M('-A('-P;VIINR!P;VUO8V]U(%-33"X`3F5P;V1A<FEL;R!S82!S:V]P[7)O
M=F&[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@861R
M97/A<B`B)7,B+@!.97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!A9')E<^%R
M+@!.97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!S^F)O<BX`3F5P;V1A<FEL
M;R!S82!V>71V;W)INR!61E,@<')I9>AI;F]K("(E<R(N`$YE<&]D87)I;&\@
M<V$@=GET=F]R:;L@<'+A>F1N>2!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@
M=GET=F]R:;L@;F]VZ2!Z9&EEM6%N:64N($-H_6)A('1Y<"!Z9')O:F$N`$YE
M<&]D87)I;&\@<V$@9&5K;VUP<FEM;W9ANR#Z9&%J92X`3F5P;V1A<FEL;R!S
M82!V>6UA>F&[("(E<R(L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GDN`$YE<&]D
M87)I;&\@<V$@=GEM87IANR`B)7,B.B`E<RX`3F5P;V1A<FEL;R!S82!V>6UA
M>F&[("5S+"!A9')E<^%R(&YI92!J92!P<N%Z9&YY`$YE<&]D87)I;&\@<V$@
M<F5K=7)Z[79N92!V>6UA>F&[(%9&4R!A9')E<^%R+@!.97!O9&%R:6QO('-A
M('9Y;6%Z8;L@5D93(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@=GEM87IANR!6
M1E,@861R97/A<CH@)7,N`$YE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<_IB
M;W(@(B5S(BX`3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!S^F)O<BX`3F5P
M;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!P<FEEZ&EN;VL@(B5S(BX`3F5P;V1A
M<FEL;R!S82!R96MU<GKM=FYE('9Y;6%Z8;L@5D93.B`E<RX`3F5P;V1A<FEL
M;R!S82!U<NAINR!A:W1UX6QN>2!A9')E<^%R+@!.97!O9&%R:6QO('-A('II
M<W1INR!P;V1R;V)N;W-T:2!O(&-E<G1I9FEKX71E+@!.96UOOF[I(&YA:')A
MNR!D969I;NUC:74@)7,N`$YE<&]D87)I;&\@<V$@<')E<W5N^KL@5D93('/Z
M8F]R+@!.97!O9&%R:6QO('-A(&]T=F]R:;L@5D93('/Z8F]R("(E<R(N`$YE
M<&]D87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(@;F$@>N%P:7,N`$YE<&]D
M87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@;W1V
M;W)INR!K;VUP<FEM;W9A;OT@87)C:.UV+@!.97!O9&%R:6QO('-A('!R9>CM
M=&&[(%9&4R!S^F)O<B`H9G5N:V-I82!F:6QE<VEZ92@I('IL>6AA;&$I+@!.
M97!O9&%R:6QO('-A('!R9>CM=&&[(%9&4R!S^F)O<B`H9G5N:V-I82!G971&
M:6QE4VEZ92@I('IL>6AA;&$I+@!.97!O9&%R:6QO('-A('!R9>CM=&&[('/Z
M8F]R.@!.97!O9&%R:6QO('-A(.CM=&&[(&%D<F5SX7(@=F9S<F]O="X`3F5P
M;V1A<FEL;R!S82!P<F5M96YO=F&[("5S(&YA("5S.B!C:66U;W;]('!R:67H
M:6YO:R!UOB!E>&ES='5J90!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93
M(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@861R97/A
M<CH@)7,N`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(@(B5S
M(BX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<B`E<R\E<RX`
M3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<BX`3F5P;V1A<FEL
M;R!S82!S<'5S=&F[("=M:VES;V9S)RX`3F5P;V1A<FEL;R!S82!P<F5L;[YI
MNR!T96YT;R!D;VMU;65N="!7;W)D`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!6
M1E,@<_IB;W(@(B5S(BX`3F5P;V1A<FEL;R!S82!Z87#M<V&[(%9&4R!S^F)O
M<B`H9G5N:V-I82!C;W!Y*"D@>FQY:&%L82DN`$YE<&]D87)I;&\@<V$@>F%P
M[7-ANR#Z9&%J92!61E,@<_IB;W)U+@!.97!O9&%R:6QO('-A('IA<.US8;L@
M5D93('/Z8F]R+"!K=O-T82!J92!P<F5K<F_H96[A+@!0;V3H:6%R:VYU=.D`
M6G)UN6F[('IM96YY`%IR=;GM('!O<VQE9&[Z(&%K8VEU`$YE;^AA:^%V86[A
M(&]D<&]V9>\@;V0@<V5R=F5R82!P;^AA<R!S<&]J96YI83H@`$YE;^AA:^%V
M86[A(&]D<&]V9>\@;V0@<V5R=F5R82!N83H@`$YE;F%S=&%V96[A`%-P;VIE
M;ND@87)A8G-KZ2!E;6ERX71Y`%9EM6OA($)R:73A;FEA`%-P;VIE;ND@N73A
M='D@06UE<FEC:^D`2F5D;F]T:WD`3F5Z;N%M90!.97INX6UE(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN`$YE>F[A;64@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`0F]L82!Z861A;N$@;F5P;&%T;N$@;&]K86QI=&$N`$YE
M>F[A;64@<&]UONUV871EM7-KZ2!M96YO(&%L96)O(&AE<VQO+@!/9'-T<N%N
M:;L@;&EN:W4@>B!A:W1UX6QN96AO(&5L96UE;G1U`$YE<&]M96YO=F%NX0!.
M97!R:79I;&5G;W9A;ND@<VMR:7!T>2!N96UA:OH@>B!B97IP9>AN;W-T;OUC
M:"!D]'9O9&]V('!R[7-T=7`@:R!V;[5BX6T@5GES=')I:&[ZNR]+;W#M<F]V
M8;LO5FQOOFF[+B!+;&EK;FET92!N82!/2R!A('IO8G)A>NT@<V$@=&5C:&YI
M8VOA(&EN9F]R;>%C:6$@;F$@<W1RX6YK92!M;WII;&QA+F]R9RP@:W1O<N$@
M5N%S(&EN9F]R;75J92P@86MO('5M;[YN:;L@<VMR:7!T=2!P<NUS='5P(&L@
M<V-H<N%N:V4N`$]D<W1RX6YINR!F87)B=0!.97!O9'!O<F]V86[]('1Y<"!O
M8G-A:'4@*$-O;G1E;G0M5'EP92DZ("5S`$YE<&]D<&]R;W9A;ND@<F]ZN>UR
M96YI90!!:W1U86QI>N%C:6$`06MT=6%L:7IO=F&[("5S`$%K='5A;&EZ;W9A
MNR!P;W6^[79A=&6U80!!:W1U86QI>N%C:6$@(B5S(B!B;VQA(/IS<&6Y;N$N
M`%-K<FEP="!N82!U<&=R861E(&)O;"!V>6UA>F%N_2X`3F%H<F&[`%:Y971K
M>2!S^F)O<GD@<R!K;VYF:6=U<N%C:6]U(&)O;&D@;F%H<F%NZ2!N82!S97)V
M97(N`%9EM6OI(&QA=&EN<VOI('#M<VUE;N$`5F6U:^D@<NUM<VME(.CM<VQI
M8V4`57)U9W5A>0!0;W6^:;L@86MT=>%L;F4Z("5S`%!O=;YINR!34TP`4&]U
MOFET92!V('!R[7!A9&4L(+YE(&IE(&UE;F\O:&5S;&\@;V1L:;ENZ2!P<F4@
M24U34"!S97)V97(N`%!O=;[M=F%T9;4`4&]UONUV871EM2`E<R!N:64@:F4@
M875T;W)I>F]V86[](&YA("5S+@!3<'+A=F$@<&]UONUV871EM6]V`%!O=;[M
M=F%T9;5S:^D@;F%S=&%V96YI80!296=I<W1RX6-I82!P;W6^[79A=&6U80!2
M96=I<W1RX6-I82!P;W6^[79A=&6U;W8@8F]L82!P<F4@=&5N=&\@<WES=.EM
M('IA:^%Z86[A+@!0;W6^[79A=&6U<VO](/KH970@;F5B;VP@;N%J9&5N_0!0
M;W6^[79A=&6U<VOI(&UE;F\`4&]UONUV871EM7-KZ2!M96YO("(E<R(@=;X@
M97AI<W1U:F4N`%!O=;[M=F%T9;5S:^D@;65N;SH`4&]UONUV871EM7-KZ2!M
M96YO.B``4&]UONUV871E;&EA('-Y<W3I;74Z`%5Z8F5K:7-T86X`5D93(&%D
M<F5SX7(@;F5E>&ES='5J92X`1&]V;VQE;FMA`%!L871NZ2!U;6EE<W1N96YI
M82!Z86C@\F%J^CH@`%!L871N;W.[`%!L871N;W.[('8@;6EN^G1A8V@@;V1T
M97)A>BX`2&]D;F]T82!P<F5K<F_H:6QA(&UA>&EMX6QN=2!DY;YK=2`E<RX`
M2&]D;F]T>0!(;V1N;W1Y+"!Z(&MT;W+]8V@@<VD@;?2^971E('9Y8G)ANP!6
M86YU871U`%!R96UE;F[A`%9E;F5Z=65L80!/=F5R96YI92!Z;'EH86QO("T@
M=.%T;R!S<'+A=F$@;6]H;&$@8GF[('-F86RY;W9A;N$N`$%D<F5SX7(@5F5R
M:7-I9VX`5F5R>FEA`$UA;F&^;65N="!V97)Z:>T`5F5R=&EKX6QN92!Z87)O
M=FYA;FEE`%9E<G1I:^%L;F4@=GEP;&YE;FEE`%9E<G1I:^%L;F4Z`%9EM6UI
M('9Y<V]KX0!6:65T;F%M`%IO8G)A>FF[("(E<R(`6F]B<F%Z:;L@)7,`6F]B
M<F%Z:;L@:V]N=&%K=`!:;V)R87IINR!E>'1E<F[Z('=W=R!S='+A;FMU`%IO
M8G)A>FF[(&%K;R`E<P!0<F5D;F%S=&%V96[]('-P]'-O8B!Z;V)R87IE;FEA
M.@!"<FET<VOI(%!A;F5N<VOI(&]S=')O=GD`06UE<FEC:^D@4&%N96YS:^D@
M;W-T<F]V>0!6:61I=&6U;F]SNP!6:61I=&6U;F]SNSH@`%9O9&%F;VYE($ET
M86QY(&-E>B!33510`%9!4D]604Y)10!54$]:3U).14Y)12$A(2!/1%-44L'2
M5$4@4TM225!4(%H@)7,@4E7(3D4N`%=)3B!C97H@2%144`!786QL:7,@82!&
M=71U;F$`5F%R;W9A;FEE`%-T`%!R961P;W9E[R!P;^AA<VEA`-ID86IE(&\@
M<&_H87/M('!O<VMY='5J90!796%T:&5R+F-O;0!796(`5U=7('-T<N%N:V$`
M55),(%=75R!S='+A;FMY`%3]OF1E;FYE`%9I=&%J=&4`5NUT82!6X7,@)7,`
M5FET86IT92P@)7,`6N%P861NX2!386AA<F$`2W1O<OH@87!L:6OA8VEU(&WA
M("5S('IO8G)A>FF[('!O('!R:6ALX7-E;NT_`$%K_2!J92!Z;F%K('!R92!O
M9&1EM6]V8>@_`$%K_2!J92!Z;F%K('!R92#Z=F]D>F]V:W4_`$UA<&$@075S
M='+A;&EE('!R92!S;'6^8G4@5VAE<F5I<P!+=&]RZ2!FX7IY`$MT;W+I('KA
M<W5V;ND@;6]D=6QY('!O=F]L:;L@<')E(')O>KGM<F5N_2!T97AT;W;](&5D
M:71O<BX`J>UR:V$`J>UR:V$@=B!J961N;W1KX6-H($-34P"I[7)K82!M96YU
M("5S(':U879O("AP<F5J87;M('-A('!R:2#O86RY;VT@<')I:&SA<V5N[2DZ
M`*GM<FMA('1A8G6U:WD`2F5D;F]T:V$@N>UR:WD`J>UR:V$Z`%=I:VD`5FEE
M=&]R`%+A;F\@=FEE=&]R`%+]8VAL;W.[('9E=')A('8@=7IL;V-H`%9I971O
M<CH`5FEE=&]R.B``3?ID<F]SNP!7:7-H;&ES=`!0<N%C80!!9')E<V$@9&\@
M<'+A8V4`365S=&\@*'!RX6-A*0!+<F%J:6YA("AP<N%C82D`5&5L96;S;B!D
M;R!P<N%C90!3;65R;W9A8VEE(.CM<VQO("AP<N%C82D`J73A="]P<FEV:6YC
M:6$@*'!RX6-A*0!!9')E<V$@9&\@<'+A8V4`3F5S<'+A=FYY('!OZ&5T('!O
M;.T@;F$@<FEA9&MU("5D+B!/Z&%KX79A('-A("5D+"!N8;EL;R!S82`E9"X`
M3F5S<'+A=FYY('!OZ&5T('!O;.TN($_H86OA=F$@<V$@)60L(&YAN6QO('-A
M("5D+@!:;/T@;V9F<V5T("5D('!R:2#H[71A;NT@5D93('/Z8F]R=2X`6"U2
M968`6N%K;&%D;ND@;V)M961Z96YI82!8-3`Y=C,`4&]UOFET:64@<F]ZN>UR
M96[I:&\@:[7ZZ&$@6#4P.78S`$%L=&5R;F%T[79N92!M96YO('-U8FIE:W1U
M(%@U,#EV,P!)9&5N=&EF:6OA=&]R(&NU^NAA('-U8FIE:W1U(%@U,#EV,P!8
M-3`Y=C,@<F]ZN>UR96YI80!960!965E9`%EA:&]O(2!M87``4F_H;F4`2F5M
M96X`06YO`%/Z:&QA<^UM+@!3=&4@=B!415A43U9/32!21:Y)344N(%!O=;YI
M=&4@=&QAZ&ED;&\@6SP^72!N82!P<F5P;G5T:64@;F%S<.2[(&1O(%=94TE7
M64<N`$YE;?2^971E('9Y='9O<FF[('9I86,@86MO("5D(&)L;VMO=BX`3F5M
M]+YE=&4@=GET=F]R:;L@=FEA8R!A:V\@)60@:V]N=&%K=&]V('8@(B5S(BX`
M3FEE('-T92!A=71E;G1I9FEK;W9A;OTN`%9O(%9AN6]M('!L;F]M(&UE;F4@
M;F5M]+YE=&4@<&]UOFF[('IN86L@)UPG+@!.97IA9&%L:2!S=&4@<&QA=&[Z
M(&4M;6%I;&]V^B!A9')E<W4N`$YE=7+H:6QI('-T92!V>KMA:"!M961Z:2"^
M:6%D;GEM:2!P;VQI86UI('H@:6UP;W)T;W9A;NEH;R!S^F)O<G4@82!Z;V1P
M;W9E9&%J^F-I;6D@<&^U86UI('8@)7,N`$YE;>%T92!P<N%V;R!N82!Z;V)R
M87IE;FEE('1O:'1O(&MO;G1A:W1U+@!.96WA=&4@<'+A=F\@;F$@>F]B<F%Z
M96YI92!T;VAT;R!O8FIE:W1U+@!.96WA=&4@<'+A=F\@;F$@=GEM87IA;FEE
M('1O:'1O('ID<F]J82X`0F]L:2!S=&4@;V1H;.%S96[]+@!-=7/M=&4@>F%D
M8;L@<&QA=&[I(.CM<VQO(&UO8FEL;NEH;R!T96QE9O-N=2P@:W1O<ND@;V)S
M86AU:F4@:6)A(.CM<VQA(',@=F]L:71EM6[];2!P<F5F:7AO;2`G*R<@<')E
M(&UE9'II;N%R;V1N_2!F;W)MX70N`$UU<^UT92!Z861ANR!P;&%T;OH@:&]D
M;F]T=2X`06)Y('-T92!M;VAL:2!P;W6^[79ANR!296=I<W1RX6-I92P@;75S
M[71E(&YA:G-K]'(@;F%K;VYF:6=U<F]V8;L@1&%T851R964@8F%C:V5N9"X`
M375S[71E(&YA:V]N9FEG=7)O=F&[(%9&4R!B86-K96YD+@!-=7/M=&4@<&]P
M[7-ANR!P<F]B;.EM('!R961T_6TL(&%K;R!O9&^Y;&5T92!S<'+A=G4@;R!P
M<F]B;.EM92X`375S[71E('IA9&&[(%523"!A9')E<W4L(&YA(&MT;W+Z('3A
M=&\@;&EN:V$@=6MA>G5J90!-=7/M=&4@=GEB<F&[(&-I9;5O=OT@861R97/A
M<BX`375S[71E('9Y8G)ANR!C:66U;W;]('IO>FYA;2X`375S[71E('9Y8G)A
MNR!S97)V97(L(&MT;W+](&WA(&)YNR!V>6UA>F%N_2X`375S[71E('9Y8G)A
MNR!A<W!O\B!J961E;B!K;VYT86MT+@!-=7/M=&4@=GEB<F&[(&%S<&_R(&IE
M9&YU('!O;&^^:W4N`$UU<^UT92!U<NAINR!M96YO('!O=;[M=F%T9;5A+"!K
M=&]RZ6AO(&-H8V5T92!V>6UA>F&[+@!-=7/M=&4@=7+H:;L@;65N;R!P;W6^
M[79A=&6U82P@:W1O<NEH;R!C:&-E=&4@=GEM87IANRX`375S[71E('5RZ&F[
M(&UE;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC971E('!R:61ANRX`375S
M[71E('5RZ&F[('!O=;[M=F%T9;5A+"!K=&]R_2!S82!MX2!A:W1U86QI>F]V
M8;LN`$UU<^UT92!U<NAINR!A:V-I=2P@:W1O<N$@<V$@;>$@=GEK;VYANRX`
M375S[71E('IA9&&[(&UE;F\@;F]V96H@:V%T96?S<FEE+@!-=7/M=&4@>F%D
M8;L@=&%L:6%N<VME('1E;&5F\VYN92#H[7-L;P!-X71E('!RX79O(&EB82!N
M82!Z;V)R87IE;FEE('1O:'1O(&MO;G1A:W1U+@!0;&%T;F]SNR!68;EE:B!R
M96SA8VEE('!R92!A<&QI:^%C:74@)7,@=GEP<KEA;&$N(%!R;W/M;2!P<FEH
M;.%S=&4@<V$@>FYO=G4N`%9AN6$@16UA:6QO=N$@861R97-A`%9AN6$@16UA
M:6QO=N$@861R97-A('!O=;YI=.$@<')E(&]D8VCA9'IA:OIC=2!P;[ET=3H`
M5F&Y92!I;F9O<FWA8VEE`%9AN6$@:6YT97)N971O=N$@861R97-A('-A('IM
M96YI;&$@;V0@>F'H:6%T:W4@5F&Y96H@<F5LX6-I92`E<RX@4')E(%9AN74@
M8F5Z<&7H;F]SNR!S82!M=7/M=&4@>FYO=G4@<')I:&SA<VF[+@!68;EE(&UE
M;F\`5N&Y(&%U=&5N=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('!R:63A
M=F%N:64@<&]UONUV871EM6]V+B!!:R!S:2"^96SA=&4@<&]UOFF[($AO<F1E
M(&YA('-P<N%V=2!P;W6^[79A=&6U<VO]8V@@^NAT;W8L(&UU<^UT92!P;W6^
M:;L@:6[](&%U=&5N=&EF:6MAZ&[](&)A8VME;F0N`%;AN2!A=71E;G1I9FEK
M8>AN_2!M;V1U;"!N97!O9'!O<G5J92!Z;V)R87IO=F%N:64@>F]Z;F%M=2!P
M;W6^[79A=&6U;W8L(&%L96)O(&)O;&$@=.%T;R!M;[YN;W.[('H@;F5J86OI
M:&\@9/1V;V1U('IA:^%Z86[A+@!:9.$@<V$L(+YE(%;AN2!P<F5H;&EA9&'H
M('-A('IM96YI;"!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0<F4@
M5F&Y=2!B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN`%;A
MN2!P<F5H;&EA9&'H(&YE<&]D<&]R=6IE('3Z=&\@9G5N:V-I=2X`5N&Y('!R
M96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU('1L8>AE+B!3=&QA
MZ'1E($-O;G1R;VPO0V]M;6%N9"`K(%`@<')E('1L8>@N`%9AN6$@86MT=>%L
M;F$@Z&%S;W;A('KS;F$Z`%;AN2!P<F5D;F%S=&%V96[](&%D<F5SX7(@<V$@
M;F5DX2!P<F5Z97)ANRX`5F&Y82!P<F5D;F%S=&%V96[A(&ED96YT:71A(&)O
M;&$@>FUE;F5NX2X`4')E9&YA<W1A=F5NX2!I9&5N=&ET83H`5F&Y92!M96YO
M.@!0;&%T;F]SNR!6X;EH;R#ZZ'1U('9Y<'*Y86QA+@!68;EE(&YO=ND@:&5S
M;&\@<')E("5S(&IE.B`E<P!68;EE(&YA<W1A=F5N:6$@8F]L:2!A:W1U86QI
M>F]V86[I('!R92!T;W1O('-E9&5N:64N`%9AN64@;F%S=&%V96YI82!B;VQI
M(&%K='5A;&EZ;W9A;NDN`%9AN64@:&5S;&\@8F]L;R!O8FYO=F5NZ0!68;EE
M(&AE<VQO(&)O;&\@;V)N;W9E;NDL('-K;VYT<F]L=6IT92!S:2!P;[ET=2!A
M('!R:6ALX7-T92!S82!S(%9AN>UM(&YO=OUM(&AE<VQO;2X`4&QA=&YO<[L@
M5N&Y:&\@:&5S;&$@=GEP<KEA;&$N`%9AN64@=GID:6%L96[I('-E<G9E<GDZ
M`$IU:&]S;.%V:6$`6F%I<@!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6U-K<GF[
M(&-I=&]V86[]('1E>'1=`%M3<'+A=F$@;R!P<F]B;.EM95T`6UIO8G)A>FF[
M(&-I=&]V86[]('1E>'0@+0!;6F]B<F%Z:;L@8VET;W9A;OT@=&5X="`M("5S
M(')I861K;W9=`%MR:6%D;VL@)7,@>B`E<UT`6[YI861N82!H;V1N;W1A70!?
M061M:6YI<W1RX6-I80!?4')E>F5R8;L`7T-,20!?2V]N=&%K='D`7T1A=&%4
M<F5E`%]6>6UA>F&[`%]6>6UA>F&[(')I861O:P!?4VMU<&EN>0!?4&]M;V-N
M[6L`5FQA<W1N;W-T:2!?;V)RX7IK=2XN+@!?26UP;W)T+T5X<&]R=`!?6F]Z
M;F%M>0!?4')I:&SA<VF[('-A`%]/9&ALX7-INR!S80!?57!R879INR!L:6YK
M=2XN+@!?36]J92!A9')E<^%R90!?3F]V_2!K;VYT86MT`%].87-T879E;FEA
M`%]0<N%V80!/9'-T7W+A;FF[(&QI;FMU+BXN`$]D<W1?<N%N:;L@>B!T;VAT
M;R!Z;WIN86UU`%](M6%D8;L`3F%?<W1A=F5N:64`5FQA<W1N;W-T:2!?=&%B
M=;5K>2XN+@!0;U]UONUV871E;&EA`&%D<F5SX7(`861R97/A="!N97INX6UY
M`&MA;&5N9.%R`&)E>G9E=')I90!N97!O9&%R:6QO('-A('9Y='9O<FF[(';]
M<W1U<&[]('/Z8F]R`&YE<&]D87)I;&\@<V$@;W1V;W)INR!V<W1U<`!K;&EK
M;FET92!S96T`8VAY8F$@<')I('!O=;YI=.T@<'+M:V%Z;W;I:&\@<FEA9&MU
M`&-H>6)A(&MO;F9I9W5RX6-I90!C;VYT86-T<RYV8V8`8V]N=&%C=',N8W-V
M`&-O;G1A8W1S+G1S=@!C;VYT86-T<RYV8V8`8VC]8F$@9/1L9;YI=/T@<WES
M=.EM;W;]('/Z8F]R`&-H>6)A(&9O<FWA='4@^F1A:F]V`'!O;&^^:V$@;F5N
MX6ID96[A`&ML97/A`'/Z8F]R`'IO('-M97)U("5S("@E<RD@<OUC:&QO<[MO
M=2`E<R`E<P!NX7)A>F]V_0!V.@!H:`!N97INX6UE(&UE;F\@:&]S=&ET9;5A
M`&]K86V^:71E`'8@<W!RX79E`&-H>6)A('9S='5P=2]V_7-T=7!U`&EN=&5R
M;N$@8VAY8F$@<V]F=';I<G4`<FEA9&MO=ET`<&_H87,@=GET=N%R86YI82!)
M4T\@;F%S=&%L82!C:'EB82!M:VES;V9S("5D`&UM`&UE;F\`OFEA9&YE(&9O
M<FWA=&]V86YI90"^:6%D;F4`;F5I;7!L96UE;G1O=F%NZ0!Z871I8;4@;F5I
M;7!L96UE;G1O=F%NZ0!P;WINX6UK;W;](&)L;VL`<&5R8V5N=`!P<NUS='5P
M('IA;6EE=&YU=/T`8F]D;W8`=GID:6%L96[A(&-H>6)A('8@<')O=&]K;VQE
M`'-T^G!A`'-L=;YB82!N:64@:F4@9&]S='5P;N$`>F]B<F%Z:;L@<F]Z9&EE
M;'D`<VUS,F5M86EL(&-E>B!(5%10`'-S`'5S=.%L96[]`'-Y<W3I;6]VX2!C
M:'EB80!Z;WIN86T@^FQO:`!D;^AA<V[A(&-H>6)A`&1O('IO>FYA;74@:V]N
M=&%K=&]V`&1O(&ENZ6AO(&%D<F5SX7)A`'!R92!P;W1V<F1E;FEE('IA9&%J
M=&4@:&5S;&\@9'9A:W+A=`!U;FEF:6MO=F%NZ0!N97!O;65N;W9A;N$`9&5F
M:6YU:F4@<&]UONUV871EM0!V0V%R9`"Y.@!W96%T:&5R+F-O;0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO
M8V%L92]S:U]32R]H96QP+GAM;```````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,38S-3,`,3`T,3<S-C(W-34`,#(Q-#<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_>&UL('9E<G-I;VX](C$N
M,"(@96YC;V1I;F<](FES;RTX.#4Y+3(B/SX*/"$M+2`D2&]R9&4Z('1U<F)A
M+VQO8V%L92]S:U]32R]H96QP+GAM;"QV(#$N-"`R,#`T+S$P+S(W(#$P.C4R
M.C`V(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)/=F5R=FEE
M=R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E!R96BU860\+W1I=&QE
M/@H@("`@/&AE861I;F<^VG9O9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M2VYI:&$@861R:65S('5M;[[R=6IE('5C:&]VX79ANR!K;VYT86MT;ND@:6YF
M;W)MX6-I92P@:W1O<ND@;6^^;F\@:F5D;F]D=6-H('-P<NUS='5P;FF[(&$@
M<&]UOFF[+B!0;V[Z:V$@;6^^;F]SNR!V>71V;W)E;FEA('/Z:W)O;6YE:B!K
M;FEH>2!A9')I97,@86MO(&%J('9Y=;YI=&EA('9E<F5J;OUC:"!A9')E<^%R
M;W;]8V@@<VQUOFEE8BX@3VMR96T@:F5D;F]D=6-H_6-H(&MO;G1A:W1O=B!M
M]+YE=&4@=6-H;W;A=F&[(&%J('IO>FYA;7D@861R:65S(&$@=&%K('-I(&WT
MOF5T92!V>71VX7)ANR!V;&%S=&[I(")M86EL:6YG(&QI<W1Y(BX*("`@(#PO
M<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](D]V97)V:65W
M(CX*("`@(#QT:71L93Y/=F5R=FEE=SPO=&ET;&4^"B`@("`\:&5A9&EN9SY)
M;G1R;V1U8W1I;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!!9&1R
M97-S($)O;VL@<')O=FED97,@82!C;VYV96YI96YT(&UE=&AO9"!A;F0@<&QA
M8V4@=&\@<W1O<F4@8V]N=&%C="!I;F9O<FUA=&EO;B!F;W(@96%S>2!R971R
M:65V86P@86YD('5S92X@($ET(&-A;B!P<F]V:61E(&$@<')I=F%T92!A9&1R
M97-S(&)O;VL@87,@=V5L;"!A<R!A8V-E<W,@=&\@<'5B;&EC(&YE='=O<FL@
M9&ER96-T;W)Y('-E<G9I8V5S+B`@270@86QS;R!S=7!P;W)T<R!D:7-T<FEB
M=71I;VX@;&ES=',@<V\@>6]U(&-A;B!C<F5A=&4@>6]U<B!O=VX@)G%U;W0[
M;6%I;&EN9R!L:7-T<RXF<75O=#L*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB;65N=2UA9&0B('-T871E/2)U;FMN;W=N
M(CX*("`@(#QT:71L93Y-96YU.B!0<FED8;L\+W1I=&QE/@H@("`@/&AE861I
M;F<^4')I9&&[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!5;6^^;NT@<')I
M9&&[('!O=;[M=F%T9;5A(&1O(&MN:6AY(&%D<FEE<RX@4&]UONUV871EM6]V
M(&WTOF5T92!P<FEDX79ANR!I8F$@9&\@:VYI:'D@861R:65S(',@;65N;VT@
M(DUO:F$@:VYI:&$@861R:65S(BP@<')E=&^^92!O<W1A=&[I('/Z('!R[7-T
M=7!NZ2!I8F$@;F$@Z.UT86YI92X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H
M(&5N=')Y.@H\96YT<GD@:60](FUE;G4M861D(CX*("`@(#QT:71L93Y-96YU
M.B!!9&0\+W1I=&QE/@H@("`@/&AE861I;F<^061D/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!!9&0@82!U<V5R('1O(&%N(&%D9')E<W,@8F]O:RX@66]U
M(&-A;B!O;FQY(&%D9"!U<V5R<R!T;R!T:&4@861D<F5S<R!B;V]K(&-A;&QE
M9"`F<75O=#M->2!!9&1R97-S8F]O:R9Q=6]T.R!S:6YC92!T:&4@;W1H97)S
M(&%R92!R96%D+6]N;'DN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R
M>3X*("`\96YT<GD@:60](FUE;G4M<V5A<F-H(B!S=&%T93TB=6YK;F]W;B(^
M"B`@("`\=&ET;&4^365N=3H@2+5A9&&[/"]T:71L93X*("`@(#QH96%D:6YG
M/DBU861ANSPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@56UOOF[M('!R96BU
M863A=F&[(&MN:6AU(&%D<FEE<R!A(&[A:G.[('!OOF%D;W9A;ND@:6YF;W)M
MX6-I92X@5&]T;R!HM6%D86YI92!P;V1P;W)U:F4@:6)A(&YI96MOM6MO('KA
M:VQA9&[]8V@@<&]L[2`M(&%K(&-H8V5T92!HM6%D8;L@86H@=B!O<W1A=&[]
M8V@L('!O=;[M=&4@(E)O>KGM<F5NZ2!V>6BU863A=F%N:64B+@H@("`@/"]P
M87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB;65N=2US96%R
M8V@B/@H@("`@/'1I=&QE/DUE;G4Z(%-E87)C:#PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY396%R8V@\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E87)C:"!A
M;B!A9&1R97-S(&)O;VL@=&\@;&]C871E(&EN9F]R;6%T:6]N+B!4:&ES('-E
M87)C:"!O;FQY(&%L;&]W<R!Y;W4@=&\@<V5A<F-H(&]N('-O;64@=F5R>2!B
M87-I8R!F:65L9',N("!3964@)G%U;W0[061V86YC960@4V5A<F-H)G%U;W0[
M('1O('-E87)C:"!O;B!O=&AE<B!F:65L9',N"B`@("`\+W!A<F$^"CPO96YT
M<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](FUE;G4M861V86YC960M<V5A
M<F-H(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365N=3H@4F]ZN>UR
M96[I('9Y:+5A9.%V86YI93PO=&ET;&4^"B`@("`\:&5A9&EN9SY2;WJY[7)E
M;ND@=GEHM6%DX79A;FEE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!5;6^^
M;NT@<')E:+5A9&&[(&MN:6AU(&%D<FEE<R!A(&[A:G.[('!OOF%D;W9A;ND@
M:6YF;W)MX6-I92X@5&]T;R!HM6%D86YI92!U;6^^\G5J92!HM6%D8;L@=F\@
M=FEA8V5R_6-H('!O;&EA8V@N($1O<W1U<&YO<[L@<&]L[2!ZX79I<^T@;V0@
M:V]N:W+I=&YE:B!K;FEH>2!A9')I97,N"B`@("`\+W!A<F$^"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU+6%D=F%N8V5D+7-E87)C:"(^
M"B`@("`\=&ET;&4^365N=3H@061V86YC960@4V5A<F-H/"]T:71L93X*("`@
M(#QH96%D:6YG/D%D=F%N8V5D(%-E87)C:#PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@4V5A<F-H(&%N(&%D9')E<W,@8F]O:R!T;R!L;V-A=&EO;B!I;F9O
M<FUA=&EO;BX@5&AI<R!S96%R8V@@86QL;W=S('EO=2!T;R!S96%R8V@@;VX@
M;75L=&EP;&4@9FEE;&1S+B`@5VAI8V@@9FEE;&1S(&%R92!A=F%I;&%B;&4@
M=&\@=&AE('-E87)C:"!D97!E;F1S(&]N('1H92!A9&1R97-S(&)O;VL@8F5I
M;F<@<V5A<F-H960N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*
M("`\96YT<GD@:60](FUE;G4M:6UP;W)T(B!S=&%T93TB=6YK;F]W;B(^"B`@
M("`\=&ET;&4^365N=3H@26UP;W)T+T5X<&]R=#PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY);7!O<G0O17AP;W)T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!0
M;VUO8V]U('1O:'1O(&UE;G4@;?2^971E(&EM<&]R=&]V8;L@86QE8F\@97AP
M;W)T;W9ANR#Z9&%J92!D;R]Z(%9AN65J('/Z:W)O;6YE:B!K;FEH>2!A9')I
M97,@*$UO:F$@:VYI:&$@861R:65S*2X@4&]D<&]R;W9A;ND@<_H@9F]R;>%T
M>2!#4U8@*/ID86IE(&]D9&5L96[I(.AI87)K;W4I+"!/=71L;V]K+"!V0V%R
M9"!A:V\@86H@;FEE:W1O<ND@[V%LN6EE('!O<'5LX7)N92!F;W)MX71Y+B!0
M<F4@:6UP;W)T(&MN:6AY(&%D<FEE<R!M=7/M=&4@;6&[(/ID86IE('5L;[YE
M;ND@;F$@<&_H[71AZ&DL('H@:W1O<NEH;R!S=&4@<W!U<W1I;&D@<')E:&QI
M861AZ"!S='+A;F]K+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!:R!C
M:&-E=&4@:6UP;W)T;W9ANR!K;FEH=2!A9')I97,L(&]T=F]R=&4@2VYI:'4@
M861R:65S+"!D;R!K=&]R96H@8VAC971E('5L;[YINR!I;7!O<G1O=F%NZ2#Z
M9&%J92X@2VQI:VYI=&4@;F$@:6MO;G4@17AP;W)T+TEM<&]R="P@=GEB97)T
M92!F;W)MX70@>F1R;VIO=F5J(&MN:6AY(&%D<FEE<R!A('9Y8F5R=&4@<_IB
M;W(@<R#Z9&%J;6D@:VYI:'D@861R:65S+B!0;W1O;2!K;&EK;FET92!N82!T
M;&'H:61L;R!);7!O<G0N($EN9F]R;>%C:64@>B!K;FEH>2!A9')I97,@8G5D
M^B!I;7!O<G1O=F%NZ2!D;R!68;EE:B!K;FEH>2!A9')I97,N($YI96MT;W+I
M('IL;[YI=&5JN6EE('!O;&^^:WD@86QE8F\@<&]L;[YK>2!S('!OM6%M:2P@
M:W1O<ND@;F5S^FAL87-I82!S('!OM6%M:2!+;FEH>2!A9')I97,@5'5R8F$L
M('-A(&WTOG4@:6UP;W)T;W9ANR!N97-P<N%V;F4L('!R971O(&)Y('-T92!P
M;R!I;7!O<G1E(&UA;&D@^F1A:F4@=B!+;FEH92!A9')I97,@<VMO;G1R;VQO
M=F&[+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I
M9#TB;65N=2UI;7!O<G0B/@H@("`@/'1I=&QE/DUE;G4Z($EM<&]R="]%>'!O
M<G0\+W1I=&QE/@H@("`@/&AE861I;F<^26UP;W)T+T5X<&]R=#PO:&5A9&EN
M9SX*"B`@("`\<&%R83Y4:&ES(&UE;G4@86QL;W=S('EO=2!T;R!I;7!O<G0@
M=&\@86YD(&5X<&]R="!F<F]M('EO=7(@<&5R<V]N86P*("`@(&%D9')E<W,@
M8F]O:R`H)G%U;W0[37D@061D<F5S<V)O;VLF<75O=#LI+B!)="!S=7!P;W)T
M<R!B;W1H($-35B`H0V]M;6$@4V5P87)A=&5D"B`@("!687)I86)L92DL($]U
M=&QO;VLL(&%N9"!V0V%R9"!F;W)M871S+"!A<R!W96QL(&%S('-O;64@;W1H
M97(@<&]P=6QA<@H@("`@9F]R;6%T<RX@5&\@:6UP;W)T(&%N(&%D9')E<W,@
M8F]O:RP@>6]U(&YE960@=&\@:&%V92!T:&4@861D<F5S<R!B;V]K"B`@("!I
M;F9O<FUA=&EO;B!T;R!I;7!O<G0@;VX@>6]U<B!L;V-A;"!M86-H:6YE("AO
M;B!W:&EC:"!T:&4@=V5B(&)R;W=S97(@:7,*("`@(')U;FYI;F<I+B`@5&\@
M9&\@=&AI<RP@>6]U)VQL(&YE960@=&\@9FER<W0@97AP;W)T('1H92!A9&1R
M97-S(&)O;VL*("`@(&EN9F]R;6%T:6]N(&9R;VT@>6]U<B!C=7)R96YT(&5M
M86EL(&-L:65N="X\+W!A<F$^"@H@("`@/'!A<F$^268@>6]U('5S92!/=71L
M;V]K($5X<')E<W,Z/"]P87)A/@H@("`@/'!A<F$^,2D@0VQI8VL@;VX@1FEL
M92`F9W0[($5X<&]R="`F9W0[($%D9')E<W,@0F]O:SPO<&%R83X*("`@(#QP
M87)A/C(I(%-E;&5C="`G5&5X="!&:6QE)R`H0V]M;6$@4V5P87)A=&5D(%9A
M;'5E<RD@:6X@=&AE("=!9&1R97-S"B`@("!";V]K($5X<&]R="!4;V]L)RX@
M($-L:6-K("=%>'!O<G0G+CPO<&%R83X*("`@(#QP87)A/C,I($EN('1H92`G
M4V%V92!E>'!O<G1E9"!F:6QE<R!A<R<@9FEE;&0L('1Y<&4@:6X@82!N86UE
M(&9O<B!Y;W5R"B`@("!A9&1R97-S(&)O;VLN("!#;&EC:R`G3F5X="<N/"]P
M87)A/@H@("`@/'!A<F$^-"D@4'5T(&$@8VAE8VMM87)K(&EN('1H92!B;W@@
M=&\@=&AE(&QE9G0@;V8@96%C:"!O9B!T:&4@9FEE;&1S"B`@("!T:&%T('EO
M=2!W:7-H('1O(&5X<&]R="X@($-L:6-K("=&:6YI<V@G+CPO<&%R83X*("`@
M(#QP87)A/C4I(%EO=2!S:&]U;&0@<F5C96EV92!A(&UE<W-A9V4@=&AA="!S
M=&%T97,@)T%D9')E<W,@8F]O:R!E>'!O<G0*("`@('!R;V-E<W,@:&%S(&-O
M;7!L971E9"<N("!#;&EC:R`G3TLG+CPO<&%R83X*("`@(#QP87)A/C8I($-L
M:6-K("=#;&]S92<@;VX@=&AE("=!9&1R97-S($)O;VL@17AP;W)T(%1O;VPG
M(&%N9"!C;&]S90H@("`@3W5T;&]O:R!%>'!R97-S+CPO<&%R83X*"B`@("`\
M<&%R83Y)9B!T:&4@97AP;W)T960@861D<F5S<R!B;V]K(&9I;&4@:7,@;F]T
M(&QO8V%T960@;VX@>6]U<B!D97-K=&]P+`H@("`@86YD('EO=2=R92!U<VEN
M9R!A(%=I;F1O=W,@;W!E<F%T:6YG('-Y<W1E;2P@8VQI8VL@;VX@4W1A<G0@
M)F=T.R!&:6YD(&]R"B`@("!396%R8V@@)F=T.R!&:6QE<R!O<B!&;VQD97)S
M(&%N9"!S96%R8V@@>6]U<B!M86EN(&AA<F0@9')I=F4@9F]R('1H92!F:6QE
M"B`@("!N86UE('1H870@>6]U('5S960@:6X@<W1E<"`S+B`@36%K92!N;W1E
M(&]F('1H92!F:6QE)W,@;&]C871I;VXN/"]P87)A/@H*("`@(#QP87)A/E1O
M(&EM<&]R="!A;B!A9&1R97-S(&)O;VLL(&]P96X@=&AE(&%D9')E<W,@8F]O
M:R!Y;W4@=V%N="!T;PH@("`@:6UP;W)T('1H92!I;F9O<FUA=&EO;B!I;G1O
M+B!#;&EC:R!O;B!T:&4@26UP;W)T+T5X<&]R="!)8V]N+B!396QE8W0@=&AE
M"B`@("!T>7!E(&]F(&%D9')E<W,@:6YF;W)M871I;VX@9&%T82!F:6QE('EO
M=2!W86YT('1O(&EM<&]R="!F<F]M('1H90H@("`@<V5L96-T:6]N(&QI<W0N
M("!#;&EC:R!O;B!T:&4@8G)O=W-E(&)U='1O;B!T;R!O<&5N(&$@9FEL92!B
M<F]W<V5R('1O"B`@("!N879I9V%T92!A;6]N9R!T:&4@9FEL97,@;VX@>6]U
M<B!C;VUP=71E<B!I;B!O<F1E<B!T;R!L;V-A=&4@=&AE(&%D9')E<W,*("`@
M(&1A=&$@9FEL92X@4V5L96-T('1H92!F:6QE+"!A;F0@8VQI8VL@;VX@=&AE
M($EM<&]R="!B=71T;VXN(%1H90H@("`@:6YF;W)M871I;VX@:6X@=&AE(&9I
M;&4@=VEL;"!B92!I;7!O<G1E9"!I;G1O('EO=7(@861D<F5S<R!B;V]K+B!3
M;VUE"B`@("!C;VUP;&5X(&5N=')I97,L(&]R(&5N=')I97,@=VET:"!F:65L
M9',@=&AA="!D;VXG="!M871C:"!!9&1R97-S($)O;VLG<PH@("`@9FEE;&1S
M+"!M87D@;F]T(&EM<&]R="!C;W)R96-T;'DL('-O('EO=2!S:&]U;&0@=F5R
M:69Y('1H92!I;7!O<G1E9"!D871A"B`@("!A9G1E<B!A;B!I;7!O<G0N/"]P
M87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S96%R8VAI
M;F<M<V5A<F-H7W)E<W5L=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E-E
M87)C:&EN9SH@4V5A<F-H(%)E<W5L=',\+W1I=&QE/@H@("`@/&AE861I;F<^
M4V5A<F-H(%)E<W5L=',\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF(&$@
M<V5A<F-H(&ES('-U8V-E<W-F=6PL('1H92!R97-U;'1S('=I;&P@<VAO=R!U
M<"!I;B!T:&4@(E-E87)C:"!297-U;'1S(B!A<F5A+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!#;&EC:VEN9R!O;B!A;B`B16UA:6PB(&9I96QD(&5N
M=')Y('=I;&P@;W!E;B!A(&YE=R!#;VUP;W-E('=I;F1O=R!T;R!S96YD(&UA
M:6P@=&\@=&AA="!A9&1R97-S+B!#;&EC:VEN9R!O;B!A(").86UE(B!F:65L
M9"!E;G1R>2!W:6QL(&1I<W!L87D@=&AE(&%D9')E<W,@8F]O:R!R96-O<F0@
M9F]R('1H870@;F%M92P@86QL;W=I;F<@>6]U('1O('1H96X@961I="!O<B!D
M96QE=&4@=&AE(&5N=')Y+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!$
M97!E;F1I;F<@;VX@:&]W('EO=7(@<WES=&5M(&AA<R!B965N('-E="!U<"!B
M>2!T:&4@861M:6YI<W1R871O<B!S96%R8V@@<F5S=6QT<R!C86X@8F4@8W5M
M=6QA=&EV92X@16%C:"!S96%R8V@@=VEL;"!A9&0@86YY(&YE=R!R97-U;'1S
M('1O('EO=7(@97AI<W1I;F<@<F5S=6QT<RX@5&AI<R!I<R!H96QP9G5L('=H
M96X@8G5I;&1I;F<@;&ES=',N(%1O(')E;6]V92!T:&4@<F5S=6QT<R!O9B!C
M=6UU;&%T:79E('-E87)C:&5S(&%N9"!S=&%R="!A(&YE=R!S96%R8V@L(&-L
M:6-K(&]N('1H92`B0VQE87(@4V5A<F-H(B!L:6YK+@H@("`@/"]P87)A/@H*
M("`@(#QT:7`^"B`@("!7:&5N('9I97=I;F<@82!L:7-T(&]F(&5N=')I97,L
M('EO=2!C86X@<V]R="!T:&4@96YT<FEE<R!B>2!E86-H(&9I96QD('-H;W=N
M(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T92!C;VQU;6X@:&5A9&EN
M9RX@5&\@<W=I=&-H(&-O;'5M;G,@8F5T=V5E;B!A<V-E;F1I;F<@86YD(&1E
M<V-E;F1I;F<@<V]R="!O<F1E<BP@8VQI8VL@;VX@=&AE(&%R<F]W(&EC;VX@
M:6X@=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@/"]T:7`^"CPO96YT<GD^"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O
M;&]C86QE+W-L7U-)+P``````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-0`P,C`P,3,`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T=7)B82]L;V-A;&4O<VQ?4TDO3$-?34534T%'15,O````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4V`#`R
M,38P,0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]S;%]3
M22],0U]-15-304=%4R]T=7)B82YM;P``````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S-C(P
M-S8`,3`T,3<S-C(W-38`,#(S,C8V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-X2!)4`````)0<``!P```!$.0``B0D``&QR
M````````D)@```X```"1F```#P```*"8```-````L)@```@```"^F```"P``
M`,>8```,````TY@```0```#@F```)````.68```E````"ID```P````PF0``
M#P```#V9```+````39D```X```!9F0``!0```&B9```H````;ID```H```"7
MF0``%0```**9```)````N)D``!(```#"F0``"P```-69```=````X9D```X`
M``#_F0``"@````Z:```-````&9H```X````GF@``#0```#::```,````1)H`
M``T```!1F@``!@```%^:```/````9IH``!@```!VF@``#````(^:```.````
MG)H```X```"KF@``"````+J:```K````PYH``"X```#OF@``&@```!Z;```R
M````.9L``#@```!LFP``5````*6;``!1````^IL``%H```!,G```5P```*><
M```T````_YP```H````TG0``!0```#^=```&````19T``!$```!,G0``"```
M`%Z=```1````9YT```D```!YG0``"0```(.=```E````C9T``"````"SG0``
M$````-2=```/````Y9T```H```#UG0``#P````">```4````$)X```D````E
MG@``#0```"^>```2````/9X```\```!0G@``"@```&">```/````:YX```@`
M``![G@``)````(2>```&````J9X``!0```"PG@``%@```,6>```(````W)X`
M`!D```#EG@``!P```/^>```4````!Y\``!(````<GP``(0```"^?```L````
M49\```X```!^GP```P```(V?```/````D9\```L```"AGP``!P```*V?```'
M````M9\```4```"]GP``!0```,.?```*````R9\```,```#4GP``%P```-B?
M```*````\)\```\```#[GP``#@````N@```8````&J```",````SH```#@``
M`%>@```.````9J```!0```!UH```%P```(J@```7````HJ```!<```"ZH```
M$P```-*@```/````YJ````X```#VH```'P````6A```'````):$```8````M
MH0``"````#2A```/````/:$```8```!-H0``"@```%2A```3````7Z$```L`
M``!SH0``$````'^A```5````D*$``!4```"FH0``!P```+RA```%````Q*$`
M`!4```#*H0``$0```."A```,````\J$``"@```#_H0``.@```"BB```[````
M8Z(```D```"?H@``!P```*FB```4````L:(```,```#&H@``!0```,JB```)
M````T*(``!````#:H@``"0```.NB```3````]:(``#D````)HP``$@```$.C
M```G````5J,``"P```!^HP``*@```*NC```E````UJ,```H```#\HP``!@``
M``>D```)````#J0```<````8I```+P```""D```W````4*0``"X```"(I```
M50```+>D```M````#:4``"T````[I0``+0```&FE``!`````EZ4``",```#8
MI0``(P```/RE```M````(*8``#,```!.I@``%0```(*F```9````F*8``"D`
M``"RI@``)````-RF```1`````:<```H````3IP``#````!ZG```*````*Z<`
M`!`````VIP``%@```$>G```6````7J<```<```!UIP``!P```'VG```4````
MA:<```H```":IP``"````*6G```(````KJ<```P```"WIP``!P```,2G```'
M````S*<```8```#4IP``$0```-NG```%````[:<```<```#SIP``!@```/NG
M```4`````J@```@````7J```*0```""H```.````2J@```H```!9J```!```
M`&2H```'````::@```D```!QJ```!@```'NH```1````@J@```<```"4J```
M%@```)RH```$````LZ@```@```"XJ```!@```,&H```-````R*@```8```#6
MJ```'@```-VH```1````_*@```@````.J0``#0```!>I```,````):D```<`
M```RJ0``$0```#JI```#````3*D```,```!0J0``%P```%2I```#````;*D`
M`!,```!PJ0``"````(2I```$````C:D```@```"2J0``"````)NI``!!````
MI*D``"````#FJ0``!@````>J```&````#JH``!4````5J@``&````"NJ```B
M````1*H``"X```!GJ@``'0```):J```A````M*H``%0```#6J@``*0```"NK
M```*````5:L```<```!@JP``%0```&BK```.````?JL```H```"-JP``#P``
M`)BK```-````J*L```\```"VJP``#0```,:K```)````U*L``!0```#>JP``
M!@```/.K```8````^JL``!T````3K```$P```#&L```4````1:P```0```!:
MK```!@```%^L``!4````9JP```0```"[K```#@```,"L```/````SZP```4`
M``#?K```!0```.6L```;````ZZP``!H````'K0``$0```"*M```1````-*T`
M`!8```!&K0``'````%VM```J````>JT``!````"EK0``(0```+:M```%````
MV*T``!,```#>K0``$@```/*M```*````!:X```\````0K@``$0```""N```3
M````,JX```P```!&K@``!@```%.N```&````6JX``!<```!AK@``$````'FN
M```1````BJX```@```"<K@``!0```*6N```,````JZX``!````"XK@``!0``
M`,FN```.````SZX```T```#>K@``!@```.RN```6````\ZX``"H````*KP``
M!P```#6O```-````/:\```<```!+KP``"P```%.O```'````7Z\```<```!G
MKP``#P```&^O```)````?Z\```H```")KP``&0```)2O```,````KJ\``!``
M``"[KP``!0```,RO```E````TJ\``!(```#XKP``$P````NP```5````'[``
M`!(````UL```*P```$BP```[````=+```"````"PL```&@```-&P```4````
M[+```#8````!L0``"````#BQ```,````0;$```8```!.L0``!````%6Q```.
M````6K$```H```!IL0``#0```'2Q```>````@K$``!L```"AL0``(0```+VQ
M```>````W[$``!D```#^L0``'@```!BR```;````-[(``"8```!3L@``&P``
M`'JR```>````EK(``!P```"UL@``)@```-*R```S````^;(``"8````MLP``
M*P```%2S```X````@+,``"\```"YLP``$@```.FS```I````_+,``!(````F
MM```H@```#FT```6````W+0``",```#SM```*````!>U```I````0+4``"@`
M``!JM0``'P```).U```@````L[4``"4```#4M0``*````/JU```A````([8`
M`!P```!%M@``)@```&*V``!!````B;8```P```#+M@``!P```-BV```'````
MX+8```T```#HM@``$````/:V```2````![<```<````:MP``$P```"*W```2
M````-K<```<```!)MP``!````%&W```,````5K<```X```!CMP``#P```'*W
M```3````@K<```T```"6MP``*````*2W```#````S;<```T```#1MP``!@``
M`-^W```1````YK<``!<```#XMP``&P```!"X```.````++@```(````[N```
M!0```#ZX```0````1+@```0```!5N```#0```%JX```.````:+@```,```!W
MN```#@```'NX```(````BK@```\```"3N```#P```*.X```-````L[@``!``
M``#!N```&@```-*X```+````[;@```8```#YN```$P````"Y```,````%+D`
M`!$````AN0``&0```#.Y```7````3;D```L```!EN0``#0```'&Y```B````
M?[D``!8```"BN0``"@```+FY```8````Q+D``!D```#=N0``%@```/>Y```/
M````#KH```T````>N@``!P```"RZ```*````-+H```H````_N@``%````$JZ
M```B````7[H``"\```""N@``"P```+*Z```)````OKH``!D```#(N@``"P``
M`.*Z```7````[KH``!<````&NP``"0```!Z[```6````*+L```\````_NP``
M%@```$^[```.````9KL``!@```!UNP``"````(Z[```-````E[L``"8```"E
MNP``*````,R[``!#````];L```@````YO```$@```$*\```+````5;P``"\`
M``!AO```#@```)&\```.````H+P```4```"OO```!@```+6\```#````O+P`
M``<```#`O```!````,B\```*````S;P```H```#8O```#P```..\```0````
M\[P``!<````$O0``$0```!R]```1````+KT``!<```!`O0``"0```%B]```%
M````8KT```L```!HO0``"@```'2]```"````?[T```4```""O0``#0```(B]
M```;````EKT``!<```"RO0``"0```,J]```.````U+T```T```#CO0``$@``
M`/&]```X````!+X``"`````]O@``"````%Z^```.````9[X``'L```!VO@``
M&````/*^```5````"[\``!$````AOP``!P```#._```%````.[\``!D```!!
MOP``!P```%N_```(````8[\```8```!LOP``!@```'._```0````>K\```\`
M``"+OP``$````)N_```/````K+\```L```"\OP``#P```,B_```,````V+\`
M``\```#EOP``!P```/6_```&````_;\```X````$P```#````!/````H````
M(,````\```!)P```"````%G````&````8L```!,```!IP```(@```'W````M
M````H,````@```#.P```$P```-?````>````Z\```"4````*P0``&@```##!
M```5````2\$``!X```!AP0``(0```(#!```@````HL$``!D```##P0``%P``
M`-W!```E````]<$``"4````;P@``%P```$'"```B````6<(```0```!\P@``
M&P```('"```-````G<(```,```"KP@``"````*_"```*````N,(```P```##
MP@``"P```-#"```$````W,(``!,```#AP@``%````/7"```,````"L,```D`
M```7PP``#@```"'#```+````,,,``!L````\PP``!P```%C#```$````8,,`
M``<```!EPP``"@```&W#```*````>,,```T```"#PP``"0```)'#```$````
MF\,```4```"@PP```P```*;#```8````JL,```H```##PP``!````,[#```F
M````T\,```X```#ZPP``?`````G$```5````AL0```4```"<Q```!P```*+$
M```,````JL0```@```"WQ```"@```,#$```&````R\0```@```#2Q````@``
M`-O$```&````WL0```8```#EQ```%````.S$```,`````<4```T````.Q0``
M$````!S%```;````+<4```0```!)Q0``"0```$[%```0````6,4```D```!I
MQ0``"0```'/%```%````?<4``!H```"#Q0``"````)[%```&````I\4``!D`
M``"NQ0``#@```,C%```'````U\4```<```#?Q0``!0```.?%```)````[<4`
M``H```#WQ0``$P````+&```"````%L8```8````9Q@``#0```"#&```)````
M+L8```8````XQ@``$@```#_&```)````4L8```<```!<Q@``!0```&3&```4
M````:L8``!T```!_Q@``!@```)W&```*````I,8```0```"OQ@``"0```+3&
M```(````OL8``!$```#'Q@``"0```-G&```&````X\8```T```#JQ@``!@``
M`/C&```$````_\8``#D````$QP``/0```#['```Z````?,<``!X```"WQP``
M!0```-;'```.````W,<```0```#KQP``!@```/#'```A````]\<``!4````9
MR```!@```"_(```$````-L@``!$````[R```!@```$W(```*````5,@``"(`
M``!?R```!````(+(```%````A\@``!T```"-R```!````*O(```,````L,@`
M``D```"]R```#````,?(```*````U,@``!````#?R```$P```/#(```(````
M!,D```D````-R0``!0```!?)```Z````'<D``#````!8R0``-0```(G)```I
M````O\D``$<```#IR0``.````#'*```I````:LH``#\```"4R@``+@```-3*
M```M`````\L``!\````QRP``#P```%'+```2````8<L```L```!TRP``)@``
M`(#+```I````I\L``"0```#1RP``)@```/;+```(````'<P```H````FS```
M"0```#',```'````.\P``"````!#S```(````&3,```F````A<P```0```"L
MS```"@```+',```9````O,P``"D```#6S```%@````#-```2````%\T```<`
M```JS0``"@```#+-```,````/<T```\```!*S0``$````%K-``!`````:\T`
M`'````"LS0``9@```!W.```.````A,X```D```"3S@``"@```)W.```2````
MJ,X``!,```"[S@``#````,_.```&````W,X``!P```#CS@``#P````#/```;
M````$,\``!(````LSP``$````#_/```1````4,\``!P```!BSP``(P```'_/
M``!J````H\\```\````.T```!0```![0```0````)-````D````UT```!```
M`#_0```+````1-```!0```!0T```#````&70```,````<M````\```!_T```
M%0```(_0```I````I=```"H```#/T```)@```/K0```G````(=$``"D```!)
MT0``*@```'/1```9````GM$``$(```"XT0``$0```/O1```2````#=(``!,`
M```@T@``%````#32```/````2=(``!8```!9T@``%P```'#2```0````B-(`
M`!$```"9T@``-````*O2```3````X-(``!(```#TT@``-0````?3```4````
M/=,```<```!2TP``#````%K3```*````9],``"````!RTP``%````)/3```4
M````J-,``!$```"]TP``%P```,_3```<````Y],```T````$U```#0```!+4
M```3````(-0``!8````TU```$0```$O4```,````7=0``!````!JU```&@``
M`'O4```>````EM0``!H```"UU```$0```-#4```4````XM0``!<```#WU```
M%0````_5```)````)=4``!D````OU0``!````$G5```'````3M4```L```!6
MU0``$0```&+5```&````=-4```8```![U0``!@```(+5```%````B=4```<`
M``"/U0``!P```)?5```%````G]4``!8```"EU0``!@```+S5```&````P]4`
M``0```#*U0``!````,_5```'````U-4```X```#<U0``#````.O5```,````
M^-4```T````%U@``"@```!/6```.````'M8```4````MU@``*````#/6```.
M````7-8```P```!KU@``#P```'C6```*````B-8```@```"3U@``"0```)S6
M```K````IM8```0```#2U@``"````-?6```F````X-8``!(````'UP``#P``
M`!K7```&````*M<```H````QUP``3````#S7```'````B=<```@```"1UP``
M(````)K7```)````N]<```T```#%UP``"0```-/7```,````W=<```T```#J
MUP``#@```/C7```6````!]@``!$````>V```!@```##8```#````-]@```8`
M```[V```&0```$+8```'````7-@```0```!DV```"P```&G8```+````==@`
M``<```"!V```!P```(G8```6````D=@```T```"HV```#0```+;8```*````
MQ-@``!````#/V```#P```.#8```1````\-@``!<````"V0``"@```!K9```1
M````)=D```@````WV0``!````$#9```/````1=D``#H```!5V0``!0```)#9
M```,````EMD```0```"CV0``'@```*C9```.````Q]D``!````#6V0``"P``
M`.?9```,````\]D```D`````V@``!P````K:```*````$MH```D````=V@``
M#@```"?:```0````-MH``!H```!'V@``"@```&+:```)````;=H```H```!W
MV@``#````(+:```/````C]H```@```"?V@``!@```*C:```'````K]H```L`
M``"WV@``1P```,/:```-````"]L```D````9VP``!````"/;```#````*-L`
M`!,````LVP``$P```$#;```3````5-L```H```!HVP```@```'/;```$````
M=ML``"4```![VP```P```*';```%````I=L``"H```"KVP``"@```-;;```%
M````X=L```0```#GVP``"@```.S;```-````]]L```8````%W```"`````S<
M```(````%=P```0````>W```!0```"/<``!H````*=P```D```"2W```#```
M`)S<```%````J=P```8```"OW```&P```+;<```O````TMP``!`````"W0``
M"@```!/=```(````'MT```\````GW0``"@```#?=```)````0MT``!,```!,
MW0``&P```&#=```8````?-T``!<```"5W0``#@```*W=```7````O-T```,`
M``#4W0``!P```-C=```(````X-T```<```#IW0``"@```/'=```+````_-T`
M``<````(W@``40```!#>```0````8MX```P```!SW@``#0```(#>```:````
MCMX``$H```"IW@``!@```/3>```&````^]X```8````"WP``'P````G?```&
M````*=\```D````PWP``&````#K?```7````4]\```L```!KWP``!@```'??
M```-````?M\``"@```",WP``(@```+7?``!7````V-\``!,````PX```(P``
M`$3@```3````:.````(```!\X```"P```'_@```,````B^````@```"8X```
M#0```*'@```*````K^```!8```"ZX```!P```-'@```4````V>````8```#N
MX```"````/7@```.````_N````<````-X0``"@```!7A```+````(.$``!<`
M```LX0``!P```$3A```,````3.$```T```!9X0``#````&?A```$````=.$`
M``D```!YX0``"0```(/A```*````C>$```<```"8X0``"0```*#A```)````
MJN$```H```"TX0``!P```+_A```*````Q^$``!4```#2X0``&P```.CA``!)
M````!.(``!(```!.X@``"@```&'B```)````;.(``!````!VX@``!P```(?B
M```2````C^(```0```"BX@``"P```*?B```'````L^(```4```"[X@``!0``
M`,'B```:````Q^(```L```#BX@``%````.[B```1`````^,``!H````5XP``
M%@```##C```4````1^,``!<```!<XP``&````'3C```<````C>,``!D```"J
MXP``!P```,3C```%````S.,```T```#2XP``#````.#C```+````[>,```@`
M``#YXP``%P````+D```+````&N0``!,````FY```!````#KD```*````/^0`
M``0```!*Y```#````$_D```)````7.0```@```!FY```!0```&_D```'````
M=>0```4```!]Y```!````(/D```"````B.0``!@```"+Y```%P```*3D```X
M````O.0``"P```#UY```$@```"+E```I````->4``#(```!?Y0``"@```)+E
M```L````G>4``"X```#*Y0``,P```/GE```S````+>8``#@```!AY@``$0``
M`)KF```/````K.8``!@```"\Y@``$````-7F```/````YN8``!,```#VY@``
M%`````KG```2````'^<``!0````RYP``%0```$?G```M````7><``"T```"+
MYP``,0```+GG```N````Z^<``"\````:Z```+````$KH``!B````=^@``!,`
M``#:Z```"````.[H```(````]^@``"L`````Z0``(0```"SI```8````3ND`
M`!H```!GZ0``"0```(+I``!%````C.D``$$```#2Z0``!````!3J```3````
M&>H``!0````MZ@``#@```$+J```3````4>H``!@```!EZ@``!@```'[J```)
M````A>H```H```"/Z@``#P```)KJ```0````JNH```<```"[Z@``#@```,/J
M```%````TNH``!L```#8Z@``"````/3J```&````_>H``!0````$ZP``$0``
M`!GK```8````*^L```X```!$ZP``.````%/K```"````C.L```8```"/ZP``
M#@```);K```0````I>L```4```"VZP``!P```+SK```.````Q.L```8```#3
MZP``!````-KK```I````W^L``!<````)[```'P```"'L``!<````0>P``!0`
M``">[```/@```+/L```?````\NP``!`````2[0``!P```"/M```.````*^T`
M``P````Z[0``#````$?M```3````5.T```H```!H[0``'0```'/M```9````
MD>T```4```"K[0``$0```+'M```-````P^T``!$```#1[0``)````./M```5
M````".X``!(````>[@``#@```#'N```9````0.X```@```!:[@``"0```&/N
M```-````;>X```H```![[@``"P```(;N```*````DNX```<```"=[@``"```
M`*7N```%````KNX``!\```"T[@``!@```-3N```0````V^X```@```#L[@``
M#0```/7N```(`````^\``!(````,[P``+````!_O```:````3.\```D```!G
M[P``"@```''O```5````?.\```4```"2[P``%````)CO```$````K>\``!``
M``"R[P``!@```,/O```'````RN\``!X```#2[P``*````/'O```*````&O``
M`!$````E\```$0```#?P```:````2?```!0```!D\```!````'GP```$````
M?O````L```"#\```!0```(_P```&````E?```!$```"<\```"````*[P```&
M````M_````H```"^\```&P```,GP```T````Y?```#0````:\0``(````$_Q
M```I````</$``"````":\0``00```+OQ```:````_?$``"@````8\@``*0``
M`$'R```B````:_(```8```".\@``"````)7R```%````GO(```@```"D\@``
M&0```*WR```9````Q_(``"H```#A\@``(P````SS```N````,/,``#0```!?
M\P``"````)3S```7````G?,```H```"U\P``!P```,#S```A````R/,``!``
M``#J\P``#@```/OS```4````"O0```L````?]```!P```"OT```3````,_0`
M``@```!']```"P```%#T```*````7/0``!0```!G]```,@```'ST```+````
MK_0```4```"[]```!0```,'T```5````Q_0```P```#=]```%P```.KT```/
M`````O4```0````2]0``"@```!?U```)````(O4```L````L]0``#@```#CU
M```%````1_4```0```!-]0``%````%+U```-````9_4``#(```!U]0``10``
M`*CU```2````[O4``!<````!]@``'@```!GV```4````./8```4```!-]@``
M%````%/V```'````:/8```X```!P]@``*@```'_V```&````JO8```P```"Q
M]@``#0```+[V```1````S/8``!4```#>]@``"P```/3V```V`````/<```H`
M```W]P``(@```$+W```+````9?<```\```!Q]P``,@```('W```;````M/<`
M``4```#0]P``#@```-;W```3````Y?<``!$```#Y]P``!P````OX```1````
M$_@```<````E^```%````"WX```8````0O@```<```!;^```!0```&/X```,
M````:?@```P```!V^```$@```(/X```$````EO@```<```";^```"@```*/X
M```+````KO@```P```"Z^```#@```,?X```.````UO@```4```#E^```!0``
M`.OX```N````\?@``"8````@^0``(P```$?Y```#````:_D``!(```!O^0``
M!@```(+Y```>````B?D``!@```"H^0``&0```,'Y```E````V_D```T````!
M^@``"0````_Z```#````&?H```<````=^@``"@```"7Z```"````,/H```P`
M```S^@``%0```$#Z```+````5OH``!D```!B^@``(````'SZ```2````G?H`
M``4```"P^@``"@```+;Z```5````P?H``!(```#7^@``#````.KZ```$````
M]_H```<```#\^@``#`````3[``!2````$?L``!<```!D^P``!P```'S[```&
M````A/L```X```"+^P``#0```)K[```1````J/L```P```"Z^P``#````,?[
M```-````U/L``!4```#B^P``$@```/C[```/````"_P``!0````;_```&P``
M`##\```0````3/P``"<```!=_```)0```(7\``!I````J_P``!H````5_0``
M%P```##]```9````2/T``!H```!B_0``)0```'W]```H````H_T``"<```#,
M_0``&@```/3]```7````#_X``!L````G_@``-````$/^```E````>/X``!D`
M``">_@``'P```+C^```3````V/X```@```#L_@``!P```/7^```(````_?X`
M``D````&_P``%0```!#_```-````)O\``!,````T_P```P```$C_``!&````
M3/\``#\```"3_P``-P```-/_``!7````"P`!`!\```!C``$`+P```(,``0`*
M````LP`!`!````"^``$`"````,\``0`-````V``!`"T```#F``$`!````!0!
M`0`(````&0$!``T````B`0$`"@```#`!`0!/````.P$!`"4```"+`0$`'```
M`+$!`0`+````S@$!`!\```#:`0$`'0```/H!`0`E````&`(!`"`````^`@$`
M)````%\"`0`@````A`(!``L```"E`@$`!P```+$"`0`-````N0(!``P```#'
M`@$`!@```-0"`0`Y````VP(!``P````5`P$`!P```"(#`0`)````*@,!`!,`
M```T`P$`"0```$@#`0`$````4@,!`!````!7`P$`"````&@#`0`(````<0,!
M``0```!Z`P$`"P```'\#`0`,````BP,!`!$```"8`P$`#````*H#`0`:````
MMP,!``\```#2`P$`!P```.(#`0`-````Z@,!``X```#X`P$`%`````<$`0`.
M````'`0!``<````K!`$`#````#,$`0`;````0`0!`"P```!<!`$`$P```(D$
M`0`<````G00!`"@```"Z!`$`!@```.,$`0`'````Z@0!`!,```#R!`$`!0``
M``8%`0`$````#`4!`!<````1!0$`.0```"D%`0`*````8P4!``P```!N!0$`
M"0```'L%`0`&````A04!``D```",!0$`"````)8%`0`)````GP4!``H```"I
M!0$`$0```+0%`0`&````Q@4!``X```#-!0$`#@```-P%`0`-````ZP4!``L`
M``#Y!0$`'0````4&`0`+````(P8!``(````O!@$`!P```#(&`0`&````.@8!
M``D```!!!@$`!P```$L&`0`;````4P8!`#L```!O!@$`*````*L&`0`5````
MU`8!``4```#J!@$`!P```/`&`0`(````^`8!``<````!!P$`!0````D'`0`'
M````#P<!``X````7!P$`"0```"8'`0`&````,`<!``@````W!P$`"P```$`'
M`0`'````3`<!``@```!4!P$`!P```%T'`0`6````90<!``D```!\!P$`!@``
M`(8'`0`+````C0<!`!P```"9!P$`%````+8'`0`'````RP<!``@```#3!P$`
M`P```-P'`0`(````X`<!`!0```#I!P$`!0```/X'`0`0````!`@!`!`````5
M"`$`!@```"8(`0`9````+0@!``H```!'"`$`'````%((`0`'````;P@!``4`
M``!W"`$`$````'T(`0`4````C@@!``L```"C"`$`#0```*\(`0`7````O0@!
M``0```#5"`$`"0```-H(`0`*````Y`@!``<```#O"`$``@```/<(`0`.````
M^@@!``@````)"0$`'P```!()`0`C````,@D!`#@```!6"0$`,0```(\)`0`G
M````P0D!`"@```#I"0$`9````!(*`0`4````=PH!`%4```","@$`.````.(*
M`0`I````&PL!`$H```!%"P$`6P```)`+`0`H````[`L!`#@````5#`$`*```
M`$X,`0`L````=PP!`"<```"D#`$`&P```,P,`0`^````Z`P!`*D!```G#0$`
M(P```-$.`0`7````]0X!`$@````-#P$`A0```%8/`0`P````W`\!`$$````-
M$`$`6P```$\0`0!)````JQ`!`!T```#U$`$`&````!,1`0`A````+!$!`!\`
M``!.$0$`*P```&X1`0`A````FA$!`!T```"\$0$`$0```-H1`0`S````[!$!
M`"4````@$@$`)P```$82`0`F````;A(!`!\```"5$@$`,````+42`0#,````
MYA(!`&D```"S$P$`/0```!T4`0!E````6Q0!`$T```#!%`$`7@````\5`0`G
M````;A4!`"P```"6%0$`*````,,5`0`O````[!4!`"X````<%@$`*0```$L6
M`0`P````=18!`%0```"F%@$`6@```/L6`0!(````5A<!`$H```"?%P$`*@``
M`.H7`0`B````%1@!`#(````X&`$`+P```&L8`0`L````FQ@!`"T```#(&`$`
M<0```/88`0!O````:!D!`+,```#8&0$`%P```(P:`0`E````I!H!`#(```#*
M&@$`*0```/T:`0`^````)QL!`"(```!F&P$`4@```(D;`0`B````W!L!`"4`
M``#_&P$`"P```"4<`0"Q````,1P!`$4```#C'`$`(0```"D=`0`V````2QT!
M`#````""'0$`)0```+,=`0`<````V1T!`#$```#V'0$`!P```"@>`0`'````
M,!X!``0````X'@$`#0```#T>`0`+````2QX!``X```!7'@$`"P```&8>`0`%
M````<AX!`!````!X'@$``@```(D>`0!9````C!X!``4```#F'@$`$@```.P>
M`0`$````_QX!``<````$'P$`"`````P?`0`%````%1\!``,````;'P$`$```
M`!\?`0`,````,!\!`!,````]'P$`#0```%$?`0`"````7Q\!``<```!B'P$`
M!@```&H?`0`4````<1\!``P```"&'P$`&````),?`0`&````K!\!`!(```"S
M'P$`#````,8?`0`#````TQ\!`"H```#7'P$`!`````(@`0`&````!R`!``<`
M```.(`$`'P```!8@`0`U````-B`!`"X```!L(`$`+P```)L@`0`7````RR`!
M`"````#C(`$`&P````0A`0`8````("$!`"0````Y(0$`'P```%XA`0`:````
M?B$!`"````"9(0$`&@```+HA`0`R````U2$!`"\````((@$`*P```#@B`0`?
M````9"(!`",```"$(@$`'P```*@B`0`:````R"(!`"4```#C(@$`)@````DC
M`0`E````,",!`"0```!6(P$`&````'LC`0`=````E",!`"0```"R(P$`&```
M`-<C`0`B````\",!`"4````3)`$`/````#DD`0`?````=B0!`",```"6)`$`
M'P```+HD`0`@````VB0!`!H```#[)`$`&````!8E`0`F````+R4!`!X```!6
M)0$`*0```'4E`0`>````GR4!``D```"^)0$`#````,@E`0`7````U24!`"\`
M``#M)0$`)````!TF`0`'````0B8!``\```!*)@$`%````%HF`0`.````;R8!
M``T```!^)@$`)````(PF`0`%````L28!``<```"W)@$`(@```+\F`0`E````
MXB8!`!T````()P$`&@```"8G`0`'````02<!`,<```!))P$`"P```!$H`0`5
M````'2@!``8````S*`$`"0```#HH`0`+````1"@!`!<```!0*`$`!@```&@H
M`0`S````;R@!`!,```"C*`$`$P```+<H`0`'````RR@!``\```#3*`$`!P``
M`.,H`0`R````ZR@!`"$````>*0$`$P```$`I`0`,````5"D!`!$```!A*0$`
M,@```',I`0`(````IBD!``D```"O*0$`"@```+DI`0`4````Q"D!``H```#9
M*0$`'0```.0I`0`(`````BH!`!\````+*@$`"````"LJ`0`:````-"H!``8`
M``!/*@$`%0```%8J`0`'````;"H!``@```!T*@$`"0```'TJ`0`_````ARH!
M`!(```#'*@$`!P```-HJ`0`/````XBH!``X```#R*@$`$`````$K`0`)````
M$BL!``D````<*P$`"````"8K`0`3````+RL!``<```!#*P$`#````$LK`0`9
M````6"L!``H```!R*P$`&P```'TK`0`7````F2L!`!0```"Q*P$`"@```,8K
M`0`,````T2L!`!<```#>*P$`!````/8K`0`J````^RL!`!$````F+`$`!P``
M`#@L`0`"````0"P!`!````!#+`$`&````%0L`0`+````;2P!``,```!Y+`$`
M"````'TL`0`+````ABP!``8```"2+`$`!P```)DL`0`-````H2P!``L```"O
M+`$`%````+LL`0`5````T"P!``X```#F+`$`+P```/4L`0`@````)2T!`!P`
M``!&+0$`#````&,M`0`Q````<"T!``4```"B+0$`$@```*@M`0`_````NRT!
M`!(```#[+0$`"@````XN`0`&````&2X!``0````@+@$`!````"4N`0`3````
M*BX!``4````^+@$`!@```$0N`0`&````2RX!``0```!2+@$`#````%<N`0`)
M````9"X!``P```!N+@$`"@```'LN`0`0````ABX!`!,```"7+@$`!0```*LN
M`0`8````L2X!`!D```#*+@$`'P```.0N`0`=````!"\!`!$````B+P$``@``
M`#0O`0`$````-R\!``H````\+P$`!@```$<O`0`%````3B\!``,```!4+P$`
M#````%@O`0!%````92\!`!H```"K+P$`-0```,8O`0`H````_"\!`%,````E
M,`$`,````'DP`0`O````JC`!`!D```#:,`$`<@```/0P`0`@````9S$!`#4`
M``"(,0$`(0```+XQ`0!%````X#$!`#`````F,@$`)@```%<R`0`>````?C(!
M`"@```"=,@$`*0```,8R`0`I````\#(!`"8````:,P$`)0```$$S`0`H````
M9S,!`"@```"0,P$`(@```+DS`0`N````W#,!`#`````+-`$`$@```#PT`0`3
M````3S0!`!````!C-`$`>0```'0T`0`)````[C0!`',```#X-`$`?````&PU
M`0`K````Z34!`!<````5-@$`%@```"TV`0`/````1#8!`!\```!4-@$`'P``
M`'0V`0`<````E#8!`%$```"Q-@$`%`````,W`0`*````&#<!``4````C-P$`
M!@```"DW`0`(````,#<!``4````Y-P$`$@```#\W`0`0````4C<!`!,```!C
M-P$`'0```'<W`0`/````E3<!``H```"E-P$`#P```+`W`0`'````P#<!``0`
M``#(-P$`"0```,TW`0`'````US<!``L```#?-P$`!P```.LW`0`%````\S<!
M`!0```#Y-P$`#@````XX`0`'````'3@!``@````E.`$`#P```"XX`0`(````
M/C@!``P```!'.`$`#P```%0X`0`6````9#@!``<```![.`$`!@```(,X`0`4
M````BC@!``8```"?.`$`#````*8X`0`(````LS@!``0```"\.`$`"@```,$X
M`0`+````S#@!``P```#8.`$`#````.4X`0`'````\C@!``0```#Z.`$`&0``
M`/\X`0`"````&3D!``D````<.0$`!@```"8Y`0`&````+3D!`"<````T.0$`
M!````%PY`0`/````83D!`!,```!Q.0$`!P```(4Y`0`'````C3D!``8```"5
M.0$`!@```)PY`0`0````HSD!`!(```"T.0$`!@```,<Y`0`)````SCD!`"(`
M``#8.0$`!P```/LY`0`'`````SH!``L````+.@$`!0```!<Z`0`"````'3H!
M``L````@.@$`20$``"PZ`0`/````=CL!``\```"&.P$`#````)8[`0`(````
MHSL!``@```"L.P$`"0```+4[`0`%````OSL!`"0```#%.P$`)0```.H[`0`+
M````$#P!`!$````</`$`#@```"X\`0`/````/3P!``4```!-/`$`&@```%,\
M`0`*````;CP!`!$```!Y/`$`"0```(L\`0`.````E3P!``P```"D/`$`&P``
M`+$\`0`.````S3P!``@```#</`$`$P```.4\`0`-````^3P!``T````'/0$`
M$````!4]`0`4````)CT!``8````[/0$`#P```$(]`0`:````4CT!``P```!M
M/0$`#@```'H]`0`.````B3T!``4```"8/0$`*````)X]`0`N````QST!`!H`
M``#V/0$`-````!$^`0`^````1CX!`%(```"%/@$`3````-@^`0!8````)3\!
M`%(```!^/P$`-P```-$_`0`(````"4`!``4````20`$`!@```!A``0`2````
M'T`!``0````R0`$`%P```#=``0`)````3T`!``D```!90`$`*0```&-``0`M
M````C4`!``P```"[0`$`$````,A``0`-````V4`!`!````#G0`$`&````/A`
M`0`,````$4$!`!(````>00$`%0```#%!`0`8````1T$!``T```!@00$`$```
M`&Y!`0`)````?T$!`"$```")00$`!P```*M!`0`0````LT$!`!,```#$00$`
M$````-A!`0`E````Z4$!``<````/0@$`$0```!="`0`.````*4(!`!D````X
M0@$`-````%)"`0`.````AT(!``<```"60@$`$````)Y"`0`*````KT(!``@`
M``"Z0@$`"````,-"`0`)````S$(!``@```#60@$`"@```-]"`0`#````ZD(!
M`!<```#N0@$`"P````9#`0`.````$D,!`!`````A0P$`$P```#)#`0`I````
M1D,!``H```!P0P$`"@```'M#`0`9````AD,!`!<```"@0P$`(0```+A#`0`<
M````VD,!`!4```#W0P$`%@````U$`0`.````)$0!`"$````S1`$`!@```%5$
M`0`&````7$0!``<```!C1`$`#@```&M$`0`'````>D0!``H```""1`$`$@``
M`(U$`0`*````H$0!`!````"K1`$`&P```+Q$`0`J````V$0!``8````#10$`
M!0````I%`0`6````$$4!`!H````G10$`"@```$)%`0`G````344!`#(```!U
M10$`0````*A%`0`)````Z44!``@```#S10$`%@```/Q%`0`(````$T8!``4`
M```<1@$`"@```")&`0`.````+48!``L````\1@$`&````$A&`0`W````848!
M`!0```"91@$`)````*Y&`0`I````TT8!`"D```#]1@$`*````"='`0`(````
M4$<!``8```!91P$`"@```&!'`0`(````:T<!`#4```!T1P$`.````*I'`0`T
M````XT<!`%H````82`$`,P```'-(`0`S````IT@!`#,```#;2`$`/0````])
M`0`M````34D!`"T```![20$`,P```*E)`0`Y````W4D!`!,````72@$`%P``
M`"M*`0`H````0TH!`"4```!L2@$`%0```))*`0`+````J$H!``T```"T2@$`
M!@```,)*`0`,````R4H!`!H```#62@$`)````/%*`0`&````%DL!``<````=
M2P$`%@```"5+`0`)````/$L!``@```!&2P$`!@```$]+`0`/````5DL!``H`
M``!F2P$`!P```'%+`0`&````>4L!`!<```"`2P$`!0```)A+`0`'````GDL!
M``4```"F2P$`&@```*Q+`0`+````QTL!`"L```#32P$`$````/]+`0`+````
M$$P!``8````<3`$`"````"-,`0`,````+$P!``,````Y3`$`#@```#U,`0`&
M````3$P!`!0```!33`$`!0```&A,`0`'````;DP!``8```!V3`$`"P```'U,
M`0`)````B4P!`",```"33`$`$0```+=,`0`)````R4P!``\```#33`$`#```
M`.-,`0`'````\$P!`!````#X3`$``P````E-`0`#````#4T!`!8````130$`
M`P```"A-`0`4````+$T!``<```!!30$`!0```$E-`0`(````3TT!``<```!8
M30$`3P```&!-`0`T````L$T!``8```#E30$`"````.Q-`0`7````]4T!`"(`
M```-3@$`'0```#!.`0`R````3DX!`!\```"!3@$`-0```*%.`0!S````UTX!
M`"\```!+3P$`"@```'M/`0`&````AD\!`!0```"-3P$`#P```*)/`0`/````
MLD\!`!````#"3P$`&````--/`0`0````[$\!`!P```#]3P$`#P```!I0`0`5
M````*E`!``<```!`4`$`&````$A0`0`<````85`!`!0```!^4`$`$0```)-0
M`0`#````I5`!``@```"I4`$`5````+)0`0`$````!U$!`!0````,40$`%0``
M`"%1`0`$````-U$!``@````\40$`(````$51`0`=````9E$!``X```"$40$`
M&````)-1`0`0````K%$!`!\```"]40$`+````-U1`0`0````"E(!`"8````;
M4@$`!0```$)2`0`8````2%(!`!8```!A4@$`$@```'A2`0`<````BU(!`!8`
M``"H4@$`%0```+]2`0`*````U5(!``8```#@4@$`!P```.=2`0`0````[U(!
M`!,`````4P$`#````!13`0`)````(5,!``4````K4P$`#0```#%3`0`,````
M/U,!``@```!,4P$`$0```%53`0`0````9U,!``8```!X4P$`&````']3`0`L
M````F%,!``0```#%4P$`#0```,I3`0`(````V%,!``,```#A4P$`!@```.53
M`0`(````[%,!``\```#U4P$`"P````54`0`&````$50!`!4````85`$`"@``
M`"Y4`0`,````.50!``4```!&5`$`&P```$Q4`0`3````:%0!`!,```!\5`$`
M%P```)!4`0`3````J%0!`"X```"\5`$`/@```.M4`0`C````*E4!`!H```!.
M50$`%````&E5`0`G````?E4!``8```"F50$`#0```*U5`0`(````NU4!``<`
M``#$50$`#P```,Q5`0`)````W%4!`!(```#F50$`)P```/E5`0`G````(58!
M`"P```!)5@$`+````'96`0`?````HU8!`"D```##5@$`(P```.U6`0`N````
M$5<!`"@```!`5P$`*P```&E7`0`B````E5<!`"\```"X5P$`.P```.A7`0`G
M````)%@!`#````!,6`$`.0```'U8`0`Z````MU@!`!4```#R6`$`+`````A9
M`0`6````-5D!`+L```!,60$`&P````A:`0`@````)%H!`"D```!%6@$`*@``
M`&]:`0`L````FEH!`#(```#'6@$`)@```/I:`0`T````(5L!`#<```!66P$`
M(0```(Y;`0`C````L%L!`#````#46P$`20````5<`0`3````3UP!``8```!C
M7`$`!@```&I<`0`0````<5P!``P```""7`$`#P```(]<`0`*````GUP!`!``
M``"J7`$`&0```+M<`0`'````U5P!``0```#=7`$`#````.)<`0`/````[UP!
M``X```#_7`$`$`````Y=`0`-````'UT!`#,````M70$`!@```&%=`0`.````
M:%T!``4```!W70$`$0```'U=`0`7````CUT!`!H```"G70$`!0```,)=`0`"
M````R%T!``8```#+70$`$@```-)=`0`%````Y5T!``T```#K70$`#0```/E=
M`0`#````!UX!``\````+7@$`"````!M>`0`)````)%X!``X````N7@$`#@``
M`#U>`0`3````3%X!`!H```!@7@$`"@```'M>`0`'````AEX!`!$```".7@$`
M#P```*!>`0`/````L%X!`!P```#`7@$`&P```-U>`0`.````^5X!``\````(
M7P$`)P```!A?`0`<````0%\!``\```!=7P$`&@```&U?`0`8````B%\!`!@`
M``"A7P$`$P```+I?`0`+````SE\!``8```#:7P$`!P```.%?`0`'````Z5\!
M``T```#Q7P$`*````/]?`0`I````*&`!``8```!28`$`!````%E@`0`2````
M7F`!``8```!Q8`$`&````'A@`0`8````D6`!``0```"J8`$`'````*]@`0`0
M````S&`!`!4```#=8`$`#@```/-@`0`7`````F$!``<````:80$`"@```")A
M`0`Q````+6$!`"````!?80$`.````(!A`0`(````N6$!`!8```#"80$`"@``
M`-EA`0`Q````Y&$!``X````68@$`#P```"5B`0`%````-6(!``<````[8@$`
M`P```$-B`0`'````1V(!``4```!/8@$`"@```%5B`0`-````8&(!``T```!N
M8@$`#0```'QB`0`3````BF(!`!````">8@$`$@```*]B`0`3````PF(!``D`
M``#68@$`!0```.!B`0`(````YF(!``H```#O8@$``@```/IB`0`'````_6(!
M``\````%8P$`(P```!5C`0`5````.6,!``8```!/8P$`$0```%9C`0`0````
M:&,!`!0```!Y8P$`-0```(YC`0`:````Q&,!``H```#?8P$`$P```.IC`0!Z
M````_F,!`!4```!Y9`$`%P```(]D`0`4````IV0!``@```"\9`$`!@```,5D
M`0`>````S&0!``@```#K9`$`"````/1D`0`$````_60!``8````"90$`#P``
M``EE`0`.````&64!`!`````H90$`#@```#EE`0`0````2&4!``T```!990$`
M#````&=E`0`(````=&4!``8```!]90$`!P```(1E`0`5````C&4!``X```"B
M90$`/@```+%E`0`1````\&4!``D````"9@$`!@````QF`0`.````$V8!`!H`
M```B9@$`'P```#UF`0`.````768!`!4```!L9@$`&P```()F`0`@````GF8!
M`!\```"_9@$`'0```-]F`0`:````_68!`"0````89P$`(P```#UG`0`<````
M86<!`!L```!^9P$`+````)IG`0`K````QV<!`!P```#S9P$`'0```!!H`0`$
M````+F@!`!$````S:`$`"P```$5H`0`$````46@!``<```!6:`$`"0```%YH
M`0`+````:&@!``H```!T:`$`!0```']H`0`<````A6@!`!L```"B:`$`$@``
M`+YH`0`,````T6@!``\```#>:`$`&P```.YH`0`I````"FD!``8````T:0$`
M!````#MI`0`&````0&D!``T```!':0$``P```%5I`0`-````66D!``\```!G
M:0$`"0```'=I`0`&````@6D!``4```"(:0$`$@```(YI`0`.````H6D!``4`
M``"P:0$`(P```+9I`0`-````VFD!`&(```#H:0$`$P```$MJ`0`'````7VH!
M``<```!G:@$`#@```&]J`0`'````?FH!``D```"&:@$`!P```)!J`0`,````
MF&H!``(```"E:@$`!P```*AJ`0`(````L&H!``\```"Y:@$`#````,EJ`0`0
M````UFH!`!0```#G:@$`%P```/QJ`0`"````%&L!``,````7:P$`"@```!MK
M`0`*````)FL!``D````Q:P$`!0```#MK`0`7````06L!``D```!9:P$`!P``
M`&-K`0`:````:VL!`!<```"&:P$`!P```)YK`0`'````IFL!``0```"N:P$`
M"0```+-K`0`*````O6L!`!````#(:P$`!0```-EK`0`&````WVL!``X```#F
M:P$`$0```/5K`0`&````!VP!`!(````.;`$`#````"%L`0`'````+FP!``<`
M```V;`$`%0```#YL`0`A````5&P!``<```!V;`$`"@```'YL`0`$````B6P!
M``D```".;`$`"````)AL`0`-````H6P!``T```"O;`$`!P```+UL`0`.````
MQ6P!``<```#4;`$`!````-QL`0`\````X6P!`#X````>;0$`/````%UM`0`?
M````FFT!``4```"Z;0$`#@```,!M`0`&````SVT!``4```#6;0$`'0```-QM
M`0`8````^FT!``8````3;@$`!0```!IN`0`>````(&X!``@````_;@$`!P``
M`$AN`0`7````4&X!``8```!H;@$`!@```&]N`0`F````=FX!``4```"=;@$`
M#0```*-N`0`,````L6X!``T```"^;@$`#0```,QN`0`6````VFX!`!,```#Q
M;@$`"`````5O`0`)````#F\!``4````8;P$`.@```!YO`0`T````66\!`#@`
M``".;P$`)@```,=O`0`W````[F\!`#\````F<`$`+0```&9P`0`W````E'`!
M`#$```#,<`$`-0```/YP`0`G````-'$!``X```!<<0$`#P```&MQ`0`*````
M>W$!`"L```"&<0$`'P```+)Q`0`?````TG$!`!T```#R<0$`"````!!R`0`)
M````&7(!``D````C<@$`"0```"UR`0`J````-W(!`"<```!B<@$`+0```(IR
M`0`$````N'(!``D```"]<@$`%@```,=R`0`C````WG(!`!X````"<P$`%```
M`"%S`0`)````-G,!``H```!`<P$`"P```$MS`0`/````5W,!``\```!G<P$`
M,@```'=S`0!O````JG,!`&L````:=`$`$````(9T`0`)````EW0!``H```"A
M=`$`$0```*QT`0`2````OG0!`!@```#1=`$`!0```.IT`0`7````\'0!``X`
M```(=0$`%0```!=U`0`1````+74!``X````_=0$`%0```$YU`0`?````9'4!
M`"@```"$=0$`>P```*UU`0`-````*78!``8````W=@$`%````#YV`0`*````
M4W8!``0```!>=@$`"P```&-V`0`5````;W8!``P```"%=@$`#0```))V`0`7
M````H'8!`!<```"X=@$`'P```-!V`0`A````\'8!`!X````2=P$`(0```#%W
M`0`F````4W<!`"@```!Z=P$`'````*-W`0`X````P'<!`!,```#Y=P$`%0``
M``UX`0`4````(W@!`!8````X>`$`$````$]X`0`7````8'@!`!4```!X>`$`
M%````(YX`0`6````HW@!`#$```"Z>`$`$@```.QX`0`5````_W@!`#D````5
M>0$`$@```$]Y`0`'````8GD!``T```!J>0$`#0```'AY`0`@````AGD!`!(`
M``"G>0$`$P```+IY`0`2````SGD!`!<```#A>0$`'````/EY`0`2````%GH!
M``\````I>@$`%P```#EZ`0`7````47H!`!$```!I>@$`#@```'MZ`0`3````
MBGH!`!P```">>@$`(````+MZ`0`G````W'H!`!$````$>P$`'P```!9[`0`:
M````-GL!`!@```!1>P$`"0```&I[`0`$````='L!``0```!Y>P$`!0```'Y[
M`0`*````A'L!`!$```"/>P$`!@```*%[`0`*````J'L!``<```"S>P$`!P``
M`+M[`0`'````PWL!``8```#+>P$`"````-)[`0`6````VWL!``8```#R>P$`
M!@```/E[`0`%`````'P!``4````&?`$`"0````Q\`0`3````%GP!`!<````J
M?`$`#@```$)\`0`/````47P!``D```!A?`$`$0```&M\`0`&````?7P!`"8`
M``"$?`$`#P```*M\`0`/````NWP!`!,```#+?`$`#@```-]\`0`,````[GP!
M``X```#[?`$`+@````I]`0`&````.7T!``@```!`?0$`)@```$E]`0`1````
M<'T!`!$```""?0$`!@```)1]`0`+````FWT!`$<```"G?0$`"P```.]]`0`%
M````^WT!``0````!?@$`#P````9^`0`0````%GX!``<````G?@$`#P```"]^
M`0`5````/WX!`!(```!5?@$`%P```&A^`0`6````@'X!``<```"7?@$`!0``
M`)]^`0`*````I7X!`!L```"P?@$`!P```,Q^`0`$````U'X!``H```#9?@$`
M#@```.1^`0`&````\WX!``@```#Z?@$`!@````-_`0`+````"G\!``T````6
M?P$`"0```"1_`0`0````+G\!``\````_?P$`$P```$]_`0`4````8W\!``X`
M``!X?P$`$@```(=_`0`(````FG\!``@```"C?P$`$0```*Q_`0`X````OG\!
M``@```#W?P$`#@````"``0`&````#X`!`"(````6@`$`%0```#F``0`3````
M3X`!``X```!C@`$`#````'*``0`,````?X`!``D```",@`$`#@```):``0`,
M````I8`!``T```"R@`$`#@```,"``0`H````SX`!``H```#X@`$`!0````.!
M`0`*````"8$!``T````4@0$`#````"*!`0`(````+X$!``<````X@0$`!@``
M`$"!`0`3````1X$!`$D```!;@0$`$@```*6!`0`.````N($!``@```#'@0$`
M!0```-"!`0`/````UH$!`!(```#F@0$`%````/F!`0`*````#H(!``(````9
M@@$`!````!R"`0`G````(8(!``,```!)@@$`!0```$V"`0`*````4X(!``H`
M``!>@@$`!@```&F"`0`%````<((!`!````!V@@$`$0```(>"`0`&````F8(!
M``@```"@@@$`!P```*F"`0`$````L8(!``4```"V@@$`8P```+R"`0`/````
M((,!`!(````P@P$`!0```$.#`0`%````28,!`"````!/@P$`-0```'"#`0`1
M````IH,!``H```"X@P$`"````,.#`0`/````S(,!``L```#<@P$`"0```.B#
M`0`;````\H,!`"\````.A`$`)````#Z$`0`C````8X0!`!(```"'A`$`%P``
M`)J$`0`#````LH0!``<```"VA`$`"0```+Z$`0`%````R(0!``T```#.A`$`
M#````-R$`0`)````Z80!`%@```#SA`$`%@```$R%`0`/````8X4!``L```!S
MA0$`%P```'^%`0!(````EX4!``8```#@A0$`#@```.>%`0`'````]H4!``L`
M``#^A0$`!P````J&`0`(````$H8!`"0````;A@$`(P```$"&`0`,````9(8!
M``8```!QA@$`!0```'B&`0`F````?H8!`!\```"EA@$`50```,6&`0`4````
M&X<!`"`````PAP$`#P```%&'`0`"````88<!``T```!DAP$`#P```'*'`0`&
M````@H<!``\```")AP$`#````)F'`0`?````IH<!``8```#&AP$`"0```,V'
M`0`&````UX<!``D```#>AP$`#0```.B'`0`'````]H<!``@```#^AP$`"P``
M``>(`0`5````$X@!``8````IB`$`#@```#"(`0`0````/X@!``\```!0B`$`
M"````&"(`0`,````:8@!``T```!VB`$`#@```(2(`0`,````DX@!``P```"@
MB`$`#0```*V(`0`.````NX@!``P```#*B`$`"````->(`0`0````X(@!`!T`
M``#QB`$`/0````^)`0`0````38D!``D```!>B0$`"@```&B)`0`5````<XD!
M``<```")B0$`$@```)&)`0`#````I(D!``P```"HB0$`!P```+6)`0`%````
MO8D!``4```##B0$`(````,F)`0`*````ZHD!`!$```#UB0$`%`````>*`0`C
M````'(H!`!@```!`B@$`'P```%F*`0`@````>8H!`!H```":B@$`&@```+6*
M`0`7````T(H!``<```#HB@$`!@```/"*`0`/````]XH!``\````'BP$`"```
M`!>+`0`$````((L!`!\````EBP$`#@```$6+`0`2````5(L!``8```!GBP$`
M$P```&Z+`0`&````@HL!`!(```")BP$`"0```)R+`0`'````IHL!``4```"N
MBP$`"````+2+`0`#````O8L!``0```#!BP$``@```,:+`0`A````R8L!`!P`
M``#KBP$`/P````B,`0`V````2(P!`!L```!_C`$`)````)N,`0`T````P(P!
M``\```#UC`$`+@````6-`0`S````-(T!`#@```!HC0$`.````*&-`0`]````
MVHT!`!@````8C@$`#P```#&.`0`;````08X!`"````!=C@$`%0```'Z.`0`8
M````E(X!`!D```"MC@$`$P```,>.`0`8````VXX!`!\```#TC@$`*P```!2/
M`0`K````0(\!`"\```!LCP$`+````)R/`0`M````R8\!`"H```#WCP$`7@``
M`"*0`0`3````@9`!``@```"5D`$`#````)Z0`0`B````JY`!`"T```#.D`$`
M(````/R0`0`F````'9$!``X```!$D0$`1````%.1`0`^````F)$!``4```#7
MD0$`&0```-V1`0`7````]Y$!``X````/D@$`#P```!Z2`0`5````+I(!``@`
M``!$D@$`!0```$V2`0`'````4Y(!``<```!;D@$`$@```&.2`0`-````=I(!
M``L```"$D@$`!P```)"2`0`?````F)(!``@```"XD@$`!P```,&2`0`.````
MR9(!`!````#8D@$`&0```.F2`0`.`````Y,!`#<````2DP$`!@```$J3`0`&
M````49,!``X```!8DP$`%````&>3`0`'````?),!``<```"$DP$`#@```(R3
M`0`'````FY,!``0```"CDP$`,0```*B3`0`6````VI,!`"0```#QDP$`6@``
M`!:4`0`2````<90!`$8```"$E`$`'@```,N4`0`2````ZI0!``@```#]E`$`
M#@````:5`0`-````%94!``P````CE0$`$@```#"5`0`,````0Y4!`!X```!0
ME0$`&0```&^5`0`%````B94!`!$```"/E0$`#P```*&5`0`0````L94!`!X`
M``#"E0$`%````.&5`0`5````]I4!``\````,E@$`'P```!R6`0`(````/)8!
M`!$```!%E@$`$@```%>6`0`1````:I8!`!,```!\E@$`$@```)"6`0`&````
MHY8!``@```"JE@$`!0```+.6`0`3````N98!``8```#-E@$`$@```-26`0`(
M````YY8!``T```#PE@$`!0```/Z6`0`0````!)<!`"<````5EP$`$0```#V7
M`0`&````3Y<!``<```!6EP$`&````%Z7`0`'````=Y<!`!,```!_EP$``P``
M`).7`0`/````EY<!``8```"GEP$`"````*Z7`0`<````MY<!`"@```#4EP$`
M!P```/V7`0`/````!9@!``\````5F`$`%0```"68`0`2````.Y@!``0```!.
MF`$`#0```%.8`0`(````89@!``<```!JF`$`"P```'*8`0`,````?I@!``@`
M``"+F`$`!@```)28`0`)````FY@!`!@```"EF`$`*@```+Z8`0`M````Z9@!
M`!T````7F0$`)@```#69`0`B````7)D!`#X```!_F0$`'````+Z9`0`A````
MVYD!`"P```#]F0$`(P```"J:`0`'````3IH!``@```!6F@$`!@```%^:`0`+
M````9IH!`!````!RF@$`$0```(.:`0`G````E9H!`"0```"]F@$`+````.*:
M`0`R````#YL!``<```!"FP$`&@```$J;`0`)````99L!``D```!OFP$`'```
M`'F;`0`1````EIL!`!````"HFP$`#P```+F;`0`-````R9L!``<```#7FP$`
M#0```-^;`0`(````[9L!`!(```#VFP$`"P````F<`0`8````%9P!`"\````N
MG`$`"0```%Z<`0`%````:)P!``D```!NG`$`(````'B<`0`-````F9P!`!D`
M``"GG`$`!@```,&<`0`#````R)P!``H```#,G`$`"0```-><`0`-````X9P!
M`!$```#OG`$`"`````&=`0`'````"IT!`!H````2G0$`$0```"V=`0`R````
M/YT!`$L```!RG0$`$0```+Z=`0`=````T)T!`"$```#NG0$`%@```!">`0`%
M````)YX!`!$````MG@$`"````#^>`0`3````2)X!`"P```!<G@$`"````(F>
M`0`-````DIX!`!````"@G@$`%````+&>`0`7````QIX!``P```#>G@$`-P``
M`.N>`0`(````(Y\!`"$````LGP$`$P```$Z?`0`7````8I\!`"X```!ZGP$`
M'@```*F?`0`)````R)\!``\```#2GP$`%@```.*?`0`5````^9\!``D````/
MH`$`$0```!F@`0`'````*Z`!`!H````SH`$`*@```$Z@`0`&````>:`!``4`
M``"`H`$`"P```(:@`0`/````DJ`!`!(```"BH`$`!0```+6@`0`(````NZ`!
M``T```#$H`$`"P```-*@`0`,````WJ`!`!$```#KH`$`$0```/V@`0`(````
M#Z$!``0````8H0$`,@```!VA`0`D````4*$!`"8```!UH0$`!@```)RA`0`&
M````HZ$!``8```"JH0$`&P```+&A`0`:````S:$!`!4```#HH0$`&P```/ZA
M`0`.````&J(!``H````IH@$``P```#2B`0`&````.*(!``L````_H@$``@``
M`$NB`0`*````3J(!`!0```!9H@$`"P```&ZB`0`8````>J(!`!H```"3H@$`
M$@```*ZB`0`%````P:(!``H```#'H@$`%````-*B`0`=````YZ(!``\````%
MHP$`!@```!6C`0`)````'*,!``\````FHP$`4@```#:C`0`;````B:,!``<`
M``"EHP$`!````*VC`0`.````LJ,!`!(```#!HP$`%@```-2C`0`(````ZZ,!
M`!$```#THP$`#@````:D`0`D````%:0!`!@````ZI`$`$0```%.D`0`G````
M9:0!`!\```"-I`$`#0```*VD`0`:````NZ0!`!D```#6I`$`90```/"D`0`;
M````5J4!`!P```!RI0$`%P```(^E`0`:````IZ4!`"$```#"I0$`'P```.2E
M`0`M````!*8!`!L````RI@$`'@```$ZF`0`=````;:8!`#T```"+I@$`'P``
M`,FF`0`<````Z:8!`!8````&IP$`&````!VG`0`*````-J<!``<```!!IP$`
M"````$FG`0`)````4J<!`!,```!<IP$`$0```'"G`0`3````@J<!``<```"6
MIP$`00```)ZG`0!#````X*<!`#,````DJ`$`60```%BH`0`L````LJ@!`"@`
M``#?J`$`!P````BI`0`2````$*D!``L````CJ0$`#P```"^I`0`E````/ZD!
M``<```!EJ0$`"P```&VI`0`-````>:D!``\```"'J0$`2````)>I`0`L````
MX*D!`"8````-J@$`%P```#2J`0`A````3*H!`!D```!NJ@$`+@```(BJ`0`G
M````MZH!`"\```#?J@$`)@````^K`0`@````-JL!``4```!7JP$`#````%VK
M`0`+````:JL!``4```!VJP$`*````'RK`0`,````I:L!``<```"RJP$`!@``
M`+JK`0`1````P:L!``@```#3JP$`"````-RK`0`4````Y:L!``@```#ZJP$`
M"0````.L`0`$````#:P!``P````2K`$`#````!^L`0`2````+*P!`!<````_
MK`$`%0```%>L`0`0````;:P!``@```!^K`$`#P```(>L`0`0````EZP!`!``
M``"HK`$`#@```+FL`0`&````R*P!``P```#/K`$`&P```-RL`0`E````^*P!
M``T````>K0$`'P```"RM`0`C````3*T!``H```!PK0$`!@```'NM`0`1````
M@JT!``<```"4K0$`!````)RM`0`4````H:T!`#\```"VK0$`#@```/:M`0`/
M````!:X!``\````5K@$`!0```"6N`0`(````*ZX!``@````TK@$`#0```#VN
M`0`,````2ZX!`!,```!8K@$`!@```&RN`0`3````<ZX!``8```"'K@$`"0``
M`(ZN`0`/````F*X!`!H```"HK@$`"@```,.N`0`"````SJX!``8```#1K@$`
M!@```-BN`0`)````WZX!``<```#IK@$`%0```/&N`0`S````!Z\!`"\````[
MKP$`$@```&NO`0`%````?J\!``@```"$KP$`#````(VO`0`,````FJ\!``8`
M``"GKP$`#````*ZO`0`2````NZ\!``X```#.KP$`#````-VO`0`-````ZJ\!
M``D```#XKP$`!P````*P`0`'````"K`!``<````2L`$`%0```!JP`0`%````
M,+`!``<````VL`$`!0```#ZP`0`?````1+`!`!H```!DL`$`!P```'^P`0`'
M````A[`!``,```"/L`$`#````).P`0`8````H+`!``8```"YL`$`$````,"P
M`0`0````T;`!``8```#BL`$`&0```.FP`0`+`````[$!``D````/L0$`!0``
M`!FQ`0`(````'[$!`!,````HL0$`%P```#RQ`0`+````5+$!``T```!@L0$`
M$P```&ZQ`0`(````@K$!``P```"+L0$`$@```)BQ`0`,````J[$!``(```"X
ML0$`$````+NQ`0`&````S+$!`!D```#3L0$`&````.VQ`0`G````!K(!`"H`
M```NL@$`)````%FR`0`F````?K(!`%X```"EL@$`$@````2S`0!5````%[,!
M`"@```!MLP$`&0```):S`0!.````L+,!`&(```#_LP$`'P```&*T`0`U````
M@K0!`"X```"XM`$`+@```.>T`0`F````%K4!`!T````]M0$`+````%NU`0#)
M`0``B+4!`"(```!2MP$`#P```'6W`0!%````A;<!`'L```#+MP$`.0```$>X
M`0`Q````@;@!`%(```"SN`$`2`````:Y`0`9````3[D!`!````!IN0$`'@``
M`'JY`0`>````F;D!`"H```"XN0$`'0```..Y`0`@`````;H!`!4````BN@$`
M0````#BZ`0`I````>;H!`!T```"CN@$`,````,&Z`0`=````\KH!`#X````0
MNP$`W````$^[`0!1````++P!`$8```!^O`$`;@```,6\`0!/````-+T!`&(`
M``"$O0$`,P```.>]`0`J````&[X!`"D```!&O@$`.````'"^`0`R````J;X!
M`"T```#<O@$`-`````J_`0!:````/[\!`&$```":OP$`2P```/R_`0!*````
M2,`!`"\```"3P`$`%0```,/``0`U````V<`!`"@````/P0$`*````#C!`0`W
M````8<$!`&L```"9P0$`:0````7"`0"R````;\(!`!0````BPP$`)0```#?#
M`0`Q````7<,!`"X```"/PP$`1````+[#`0`J`````\0!`$@````NQ`$`&P``
M`'?$`0`=````D\0!``D```"QQ`$`F````+O$`0!$````5,4!`!X```"9Q0$`
M(````+C%`0`W````V<4!`!\````1Q@$`'@```#'&`0`L````4,8!``8```!]
MQ@$`"0```(3&`0`#````CL8!``T```"2Q@$`$@```*#&`0`+````L\8!``L`
M``"_Q@$`!@```,O&`0`2````TL8!``(```#EQ@$`:````.C&`0`%````4<<!
M`!D```!7QP$`!````'''`0`'````=L<!``4```!^QP$`!0```(3'`0`&````
MBL<!`!0```"1QP$`!P```*;'`0`2````KL<!`!````#!QP$``@```-+'`0`(
M````U<<!``<```#>QP$`$P```.;'`0`,````^L<!`!4````'R`$`!@```!W(
M`0`0````),@!``T````UR`$``P```$/(`0`>````1\@!``0```!FR`$`!@``
M`&O(`0`(````<L@!`!P```![R`$`0P```)C(`0`Q````W,@!`#(````.R0$`
M&````$')`0`C````6LD!`!D```!^R0$`(0```)C)`0`A````NLD!`!P```#<
MR0$`(````/G)`0`G````&LH!`"(```!"R@$`*0```&7*`0`F````C\H!`"@`
M``"VR@$`'0```-_*`0`A````_<H!`"8````?RP$`(0```$;+`0`G````:,L!
M`"<```"0RP$`+@```+C+`0`F````Y\L!`"(````.S`$`)````#',`0`I````
M5LP!`!\```"`S`$`*````*#,`0`@````R<P!`"\```#JS`$`(````!K-`0`D
M````.\T!`"D```!@S0$`*@```(K-`0`D````M<T!`"(```#:S0$`)````/W-
M`0`E````(LX!`#L```!(S@$`*P```(3.`0`)````L,X!`!(```"ZS@$`&0``
M`,W.`0`J````Y\X!`"$````2SP$`#````#3/`0`/````0<\!`!@```!1SP$`
M$P```&K/`0`/````?L\!`"L```".SP$`!0```+K/`0`&````P,\!`",```#'
MSP$`+0```.O/`0`B````&=`!`"4````\T`$`"@```&+0`0#(````;=`!`!,`
M```VT0$`$````$K1`0`(````6]$!``L```!DT0$`$P```'#1`0`@````A-$!
M`!(```"ET0$`,````+C1`0`4````Z=$!`!8```#^T0$`!P```!72`0`4````
M'=(!``L````RT@$`-0```#[2`0`A````=-(!`!H```"6T@$`%````+'2`0`8
M````QM(!`#P```#?T@$`#P```!S3`0`0````+-,!`!$````]TP$`%0```$_3
M`0`*````9=,!`!0```!PTP$`!@```(73`0`G````C-,!``H```"TTP$`)```
M`+_3`0`)````Y-,!`!,```#NTP$`!P````+4`0`,````"M0!``D````7U`$`
M-0```"'4`0`/````5]0!``<```!GU`$`#0```&_4`0`2````?=0!``X```"0
MU`$`"0```)_4`0`+````J=0!``<```"UU`$`$P```+W4`0`*````T=0!``L`
M``#<U`$`'0```.C4`0`.````!M4!`!<````5U0$`%P```"W5`0`6````1=4!
M``H```!<U0$`#````&?5`0`;````=-4!``<```"0U0$`+````)C5`0`0````
MQ=4!``D```#6U0$``@```.#5`0`1````X]4!`!L```#UU0$`"P```!'6`0`%
M````'=8!``T````CU@$`#0```#'6`0`(````/]8!``H```!(U@$`#P```%/6
M`0`.````8]8!`!0```!RU@$`%0```(?6`0`.````G=8!`"P```"LU@$`'```
M`-G6`0`G````]M8!``L````>UP$`1P```"K7`0`&````<M<!`!,```!YUP$`
M-@```(W7`0`-````Q-<!``P```#2UP$`!P```-_7`0`$````Y]<!``4```#L
MUP$`%@```/+7`0`&````"=@!``<````0V`$`!P```!C8`0`$````(-@!``\`
M```EV`$`#````#78`0`-````0M@!`!````!0V`$`%@```&'8`0`3````>-@!
M``4```",V`$`%P```)+8`0`@````JM@!`"````#+V`$`)0```.S8`0`.````
M$MD!``(````AV0$`!````"39`0`0````*=D!``4````ZV0$`!0```$#9`0`"
M````1MD!``\```!)V0$`2````%G9`0`4````HMD!`"H```"WV0$`*0```.+9
M`0!*````#-H!`"$```!7V@$`(P```'G:`0`0````G=H!`&L```"NV@$`(0``
M`!K;`0`Q````/-L!`!D```!NVP$`.0```(C;`0`M````PML!`!X```#PVP$`
M'0````_<`0`P````+=P!`"0```!>W`$`-P```(/<`0`X````N]P!`#0```#T
MW`$`.````"G=`0`I````8MT!`",```",W0$`(P```+#=`0`N````U-T!`!0`
M```#W@$`#P```!C>`0`,````*-X!`&T````UW@$`"````*/>`0!Y````K-X!
M`&H````FWP$`)0```)'?`0`9````M]\!`!D```#1WP$`#P```.O?`0`<````
M^]\!`"4````8X`$`(````#[@`0!7````7^`!`!D```"WX`$`"P```-'@`0`%
M````W>`!``<```#CX`$`"````.O@`0`%````].`!`!D```#ZX`$`$P```!3A
M`0`<````*.$!`"<```!%X0$`$@```&WA`0`0````@.$!``\```"1X0$`!P``
M`*'A`0`$````J>$!``D```"NX0$`"````+CA`0`0````P>$!``@```#2X0$`
M!@```-OA`0`3````XN$!``T```#VX0$`"`````3B`0`'````#>(!`!4````5
MX@$`"0```"OB`0`(````->(!`!4````^X@$`$P```%3B`0`%````:.(!``L`
M``!NX@$`%````'KB`0`+````C^(!``<```";X@$`!P```*/B`0`%````J^(!
M``P```"QX@$`"P```+[B`0`,````RN(!``P```#7X@$`!P```.3B`0`(````
M[.(!`!0```#UX@$``@````KC`0`(````#>,!``@````6XP$`"````!_C`0`U
M````*.,!``,```!>XP$`$````&+C`0`3````<^,!``D```"'XP$`"````)'C
M`0`&````FN,!``8```"AXP$`#@```*CC`0`4````M^,!``4```#,XP$`#@``
M`-+C`0`B````X>,!``<````$Y`$`"@````SD`0`1````%^0!``4````IY`$`
M`@```"_D`0`+````,N0!``$```#/!@``208``)`$``!G!0``+08``!4&```,
M!0```````+H%````````T`0``*\$``"S`0```````"($````````R@0``"L%
M``#5````<`(``!0#````````504``/(```!O`@``G00``'$#``!$`0``````
M``````#7!0``A@$``.T%``#+````.P$````````$`P``]0```+H$``"&`@``
M0P```#L$```F!0``;04``-8%``!N!0``HP``````````````TP$```````":
M!````````$<&````````D`(``*$$``"I````]08``((#``"H`0``+P(``+T&
M``#]`0```````(@#````````BP8``&4&`````````````-H%``#1`0``"P8`
M``````#W`@``D@0``.`$``"=````?`4`````````````8@(``+$&````````
MK08``$$```"5`0``B@$```\!``")`````````/H%```Y`0``&04``'(!``!6
M``````````````#I!@``8@$```````!2!0```````%$"````````SP4`````
M``""!0``N@8``),#``!.!@``[`8``!L%````````!P<``.0!``!*!0``E@(`
M`+<#``!A!0``^@`````````````````````````L`0``F0(``,0$```@!```
MK@4``!0&``!E`P```````"4'````````G@8``)$$``"-````G@$``'D`````
M`````````````````````````&T&``#E`0``"@```````````````````$,%
M``"E`@``=0$`````````````H`4```````#-`P``NP0``)L%``#_`0``ZP0`
M`'L%``".`0```````.,&```>!0``3`,```````!=!0``[0,``"<&``!%!@``
MN04``*0!``!+`P``^P0``)T%``#:!```*`4```X!````````]@8``/@#```;
M`0``5P```(<%``!F`@```````'8!``!H!@``:@4``````````````````/H$
M``````````````8#````````6P$``),%``";!```7P$`````````````````
M`#@"``"W`@``*`(``(,%````````GP4``$`%``!(`@``4````+@&``#X````
M`````"$$``"S!0``(P0```````!5`P``=P$``'<&``"H!0```````+D&``#W
M````&P0````````*!@````````````"!`0```````)@$``#\````7P,``(\&
M``#1!0``GP,``.L&```S`0``^0```%,````)!@``WP,``$`"``#<!0``G`8`
M`/@&````````2@,``-T!``#Z!@``NP```,\````)`P``A0$````````1````
M@08````#````````AP0``,<&```3`@``4P,``/0#``!3`@```````!<'````
M````UP0``%L#``#C!0``3P```+`&````````:P$``*X!```/!P``BP$`````
M````````8P$``,L&``"]````]P$``%8&```@!@``8@0``!\'````````@`,`
M`#X!``#:````=`4``$X!``!J`P``6P8```````!"`P``=@(``/,#``!/`P``
MW0```+L%``!I`P``_P```.X%``!3!@``60,``+4%````````,0```%P!``#?
M`@``>@0``-<!``#`!@``-04``!X"``"=!@``PP$``/,!``"Y`0``````````
M````````900``*,#``"Z``````````````"S````2P4``.@$``"_````````
M`*L&``!A````C``````````T`P`````````````\`@``_`0```````"R!@``
M/@8``(<"``"@!@``$@<``!$"````````E`$``+4&````````P0(``&,"````
M````%@0``$X"``````````````````!R````B@(``.<#``!!`0``I08``"D"
M``"!`P``(`$``&8```!K!@``M`$``'4#````````6@0``/0%``#Q!```$0,`
M```````<!0``,@,```````!0`@``=P4``%P"`````````````&@!``!T!```
M``````````#H`@``\P0``!X#`````````````(0%``!\!```;@0```````#R
M!@```````'@%```````````````````6`P``E00``.,"```&!@```````-X&
M``#M````^00``$`$````````P````!$!``#U`P```````.X!````````*@,`
M`-4$``#/`@``%`$```X"```<`0```````&\$`````````````$@$````````
MI`8``$`#````````U@```&`%``!$!````````$````#9`@``4P4````````C
M!0``>08``"H"`````````````!,````.````FP(``!T'```&!P```````,X!
M``#!````$@,```````"H!```F0```.$&```.!0``X0,``*8&````!```CP,`
M`&T#````````9@0``*<%````````.@,```@$``#H````80(``'0!```3!@``
M``````````"7`0``Q@(``````````````````.("``"5!0``[@(```L$``!B
M`P``T`8``-$"````````,P8``-X"````````V`0``)4&``!C!0``]@```#H"
M``!-`0``9@,``)`&``#8`@``-@$``",'``#C`0``C@(``+8&``"T`@``VP``
M````````````3@0``#(```#J!0``PP`````````M`P``6@,``$@&``!$`P``
MF08``)<#```X````904```\````G!0```````*\#``#P````7P8``(@&``#G
M!```#P4``-0"````````%0(```````!1!@```````$P%``#>!```L````"(`
M``!5`0``5@,``!\%````````]````-(```!!!0`````````````^!```U`4`
M`(0#```+`@``Y0`````````&!0````````P'``!K!```/P,`````````````
MJ@8``!,'``!8`P``7@(``(P"```!!0``````````````````5`$``!T&``"U
M!```\0(``+H"``"V!```'`0``%<$``"\!```````````````````K@,``"P"
M````````3`(``,X"```4!0``)`,``,P```"=`@``#@0``,D$```-!```2@``
M````````````-@8``.P`````````\`4``+<%``#-!@``700```````!'!```
MC`0``"X$``!W!```FP8``)<%``#<````.`$````````=!```H`$``%\````H
M`P``.@$``.$$````````P@4``-`%``#>`P``:00``"\#```G`@``=0(```0$
M``#Z`@```````&@#````````J@,````````D!```'P8```````"-!@``-```
M``T"```_`0``%P0``$8!````````3````%H```"/!````````*<#``"L!@``
M``````````"R!0```P0``%D%``````````````P$``#2!````````"P$``#(
M`P```````+,"```6!@``9@4``#$#``!;`@``\P`````!``#\!0``'0```)0#
M```8!P``Z0$```````"+`@``9`0``-,"``#B`P``'0$``/\#````````````
M````````````;`4``'``````````3P0``)8```#6`@``W0,``(D!```P`@``
M,P(``*4$`````````````/P"````````PP(``)L#``!L`````````*4#``!-
M!0``D````$4!````````(`,```````"&!@```````,0"````````5`4``/D"
M``#N!@``B`0``,P#``!!!@```````/4"``!>!```%@<``-X%``#8!@``)@``
M`$(&``!H!```<P`````````O!0``"@4``"<!``"?!```!0$``'4$``"E`0``
M`````.($``!1`P``!P8```````!I`````````-@!```#!P``0P0```,!```>
M!@``>0,``/(!``#"`0```````!`"````````*P````````!2!@``P0$`````
M````````X04```````"H!@``@P(````````B!@``,`,``&``````````_@``
M``````!&`@````<``,\$``"6!@``$P4``'H%```;````E0,``&L#``"(`0``
MY@```````````````````"8!```J!```<@8``#8#```^`P``6`$``(H&````
M``````````````!B!@``&P(```````"K`0``I@$```L#````````X`8``*,$
M``!R`P``YP$```````!Z`P``+`,```````"A!0``@@0`````````````"04`
M`)T#````````A@0``.@#```"!P``U0,``*X"````````@04``-P#``!9`@``
M`````+4"``!4!@``^`$``)(```!)`0```````-,``````````@0``,\!``#6
M`0``*08```````"3!```(P(``````````````````%X%`````````````(0&
M```$`0``1P4``+<````G`````````&$!```J`0``L0,``,,%``""!@``4`4`
M``````"&`P``NP,``#D#```5!P``?````%L```"!````:@$``&T!``!?!```
M&`,``/0$``#Z`0```````"H%````````(0```&0&````````\P(``$4"``"C
M`0``UP(``"(!```V`````````%L$``!N````600``!<```!J`@``````````
M```1!```:08``&T$```^!0``,@4``&4!````````>`8``.H"``#,!````@4`
M`!4%``#!`P``A0,```\#``"K!```S@4``.\%`````````````#X"``"L!0``
M;@$``#H$````````B`4``"D%``"R`@``404``!D'``!_!0``MP0``(X#``#=
M!@``)P0`````````````VP8```````"P!````````'X$````````R@4`````
M``"%!@``+04``+P!``#[!@``````````````````=@0````````D````CP``
M```````5`P``&@```#D&``!O!@````````````"?`0``I@,``!8```#6!```
M=04``(D$```"`0```````)P!``"Q!```X`,````````P!@``)0,``'L"``!N
M!@``-`$``"$"``!8!````````.$"``"8`P``[P0``$H$``!/`@``V@,``)X#
M``````````````,%```@!P``)`4``/<&````````1`4`````````````'P,`
M`",````(!@``\@0```````#H!@```````#\%````````WP$```````!+!```
M1P(``&H````+!0``)@,``/D!``#)`@``Y`8``$L```!T`@```````#H```#*
M`P``N0`````````Q!0``@`(``*0`````````0`$``'4```#S!0``>P``````
M````````A`(``/,&````````6P4``'T%``"4``````````````#J`0``P`4`
M`$4$``!X`P``K`0```````!K`````````*X&`````````````+8%``!]!@``
M)`(``-,&```'````````````````````20(``/\$````````500``/P&``!0
M`0``0P$``)4`````````O@````````"\`P``]@(``(L$```Z!@``$08````&
M``"Z`0``B04```````#^!```@@```$T&```]!```5`,``/@%``":`0``C`4`
M`(L#``"U`0``E`8``,\#``#R!0``ZP$``!L&``#-`@``[0$``%(#``"B`0``
M!`<```````````````````````#>````<08``+@$```U!@``>0$``'0#````
M````,00```<#``!:!@```````$$"``"I!0``#@<``,H"```M`0``?0,```<"
M``#%````.`,``$P$``"C!0``1`(```````"$`0``(P$`````````````JP``
M`$@!``!S`0``=08``'X&``!M`````````(8%``#&`0``N00``!X$```_!@``
MF00``"L!``"P`0``_@8`````````````4`,``/4!``#+`0``F@4``)P"``#+
M!0``L`,```T&``#F`@``[@```"8$``!?`@``\`,```````!%!0``V`,`````
M`````````````.<"``"M!0``[`$```T`````````J`,``/$```#'`0``N@,`
M````````````I`,``#H%````````ZP,``!@"````````<P,``.0$`````@``
M]00```````#``0```````!$'````````LP8``$<!````````>04```L'``"#
M!```V0,``*L#````````C@0```````#[`@```````/X!``"8`0``JP(``/T%
M```B`@``*P,``$8&````````X`4``$(!```R`@``2P$```H'``!A!@``L`4`
M``````"N!```.P(``-4"``#@`0``@`4``.T"``!1!```I`(```````"<`P``
M+@```!X```!F`0``%`<```````#J!@``%````'H```!<````"`4``!("````
M````40```-(&``!.!0``N````&@"```V`@``L@,``'$"``!1`0``2@8``+X!
M`````````````)(%```H````,0$``)<"``#]`````````),!``!Z!@``7@8`
M`,@"``#&!@```````)X"``"U`P``GP(``'T"``"A`@``R`$```0"````````
M?`$``*$!````````O@(```````#2`0``9`(``&<&``"F````4P0``$T````S
M!0``WP4``+$%````````0@(``%8%````````@`$``+T#``#Q!@``Z0,`````
M````````(`4```````"4`@``````````````````W`$``!D"``!^!0``````
M```````6`0```````(L%```5!`````````````"`!```C`,``*,&````````
M`````.P%`````````````,4%````````M@(``*L%`````````````/8%``"%
M!0```````-8#``!(`````````!(&```,!@``6````*(%````````*`0`````
M````````QP0````````C!@``[@0`````````````KP$```D"``"V````?@(`
M`,T```"=`0```````'$```"'`P``5````,0`````````20,``%D````\````
M[P```+@!```I!```+`4``%\%``"T!0````````````"S!```;P```#<&```8
M!````````,L#```&`@``&08``````````````````)X%````````W04`````
M``#V`P``*`8```````"G`@```````+\#``"#`P``?`8```````#7````T`,`
M`*T$``#B`0``0P8``!P&```%`P``K0$````````M!```````````````````
M`````/("````````'P```#<$````````:P(``$\!``#.````OP(``'$$```]
M````E`4```$'``"Q```````````````8````70,``/<%``!V!@``?@,``$T$
M``#"````4@0``%T!``#9!```E@0``/L!```X!0``H@0``"X&``"A`P``O```
M`"D#``";````KP(``"T```#4`P``V`4``+@#``#G!@``5P4``-````"_!@``
MM`0```````"J!``````````````B`P```````"$%``!)!```C0$``!`%``#)
M!0``@````*("````````$`0``,D```"A!@```````'("``!!!```*@``````
M``````````````````!]`0``R0,``-H!``"J!0``1`8``'<"``!_!@``^P``
M`)H````$````@`8``````````````````%@&``"9`P````````P"``"7!```
M9P,``*0$``"7!@```````,@&``"%`@``>P$``%8"````````*P0``/8!````
M````_0(``.\!``!=````J0$``"X"```?`0``^0,``&D%````````&@4``(0$
M``````````````````````````````````!<`P``[`(```````!5`@``````
M``````#+`@``8@```'<#```0!@``QP4``#$"``!R!0``"`````````!7`@``
MS`(```@#``"A`````P,``"\$````````S@8``"P``````````````"$&```[
M!0``3@,``*(&```F!@``Z@```)P$``#;`@``/`0``!(!``"8!@``WP0```4'
M``##!```4`8```T#````````-P(``!,#``")`P```````'T```#+!```!P0`
M`)@"```!`0``/0,``*`"``"X!0``WP```(\%``",!@``;P$``#\$````````
MH`,``````````````````#D"```#````J`````````!7`P```````+P&```0
M`0``K@```.D%`````````````$T#``#P!@`````````````#`@``5P$``(@"
M```2`````````#,#``!S!@``>@(``/(#``!G`0``>@$``#,$``"$````````
M```````:`P``E@$``)\&```L!@``E@,``%X!``#,`0``]P0`````````````
M9P(``)`!````````J@$``,8#``!Q`0``````````````````/04``&,```"^
M!`````````````!X`0``O`(``,4!````````#0$``&P!```+````Q@4``/D%
M``",`0``@@(``&D"``#O`P``P@,``",#``!<!0``T0,````````N`0``````
M`$<```!V!0``Z00```````#]!@``Y00``$8```!6!```K0```+$"````````
MF`4```D$```/!```IP$``*8"```8!0``_@,``$X```!_````#```````````
M````G@```$H!```*!````````)$```!2`@``Y@,``*(#``#$`P``/@```/4%
M``"'`0```````&@%````````;P,``%X#``!P`P``(0<````````!`P``KP8`
M`#$&```O!@````````````#=`@``708``'8#````````K````+(```!&!```
M`````&,&```D`0```````+<!````````S04```````"%`````````#P%````
M````*0```)$#``##`P``:P4``"<#``#X`@``>P0``"`"````````G`4``#T!
M````````'````.P#``#_!@``HP(``(X```!Q!0``,P````````!9`0``"0``
M``<!``"!!```P00```````!^`````````',%``!\`P``U0$``-T$``#B````
M%`(``/T$```W!0``B@,``!`'``#.`P```````-0!````````9`,``"$!``"1
M!@``R`0``!X!``"S`P``8`8``/X%````````_0,```D'```%!0``J0(``%(!
M``!V````&@$``#\````U````1@,``/$!```P!```KP4`````````````````
M``````!C`P``T0```$,#``!A`P``#P8```4````?!```NP$``/L%``!X!```
M``````````"3!@``EP```!H$``"'````7`0``!$%````````S0$``!,!``"0
M`P```````%0$``"#!@```````&X#``!E`````````!X'`````````08`````
M`````````````/\%``"'!@``C00```````!X`@``NP8`````````````G```
M`.@%```E````/0(````````T!0````````````#4!```L@0``&H$````````
MX@8````````5`0``6`(``.,```#2`@```````-@```!S`@``DP```$P&```_
M`@``N0,```````#[`P``[08`````````````?@$```4"````````_@(``.P$
M``"/`@``````````````````I@4``)H&`````````````!T"```J!@``-P$`
M`)H#``!G````X````"0&``"T`P```````"(%```Y!````````,<"``"1!0``
MS`8``.H#```E!0``[P8```````!$````6@(``*D#````````XP0``&0```#$
M!@``L`(``/`$``"U````OP4``+\!```2!```YP4``-$$``#O`@``?P$``#<`
M````````"`(```````"\!0``Y04``!0$````````IP8``"0'``#%`@``I`4`
M````````````'`<``,4#``"-`P```````+$!``"M`P``B@4`````````````
M%P$``-8&``!,`0```````!L#````````,`````````!D`0``,@8``#@&````
M````*P(```````!&!0``00,```8!``!/!@``5@$``'<```!P!@``T`(``+T!
M`````````00``%,!``"2!@``!@0``,8```!/!0``=`8``+X#``#``P``@0(`
M`*H```!G!```W@$```````#9!@``@P$``.T$``#F!`````````````"]!0``
M`````'`$``")`@```````)$"``#;`0``?P,``#(!``!)````,`4``,@%``#3
M!```5P8``,4&````````Y0(``-\&```!`@```````-L%```-!0``%P,``*P"
M``!)!0``?P0```````"]`@``X0$``&@```````````````````"O`````@(`
M`.(%```9`````````%X`````````90(````````7!0```````&P$``#2`P``
MR08``#<#````````J@(``,$&``"/`0```````/$%``"L`P``<@0```D!```U
M`0``-@4`````````````^@,```````#1!@``VP,````````0`````````,P%
M```&``````````H"``"-`@``.P```(T%```T!```.P8```````!0!```+P``
M`+0&``#3!0``B08``,$%``#``@``C@4```````!:`0``#0<`````````````
M_`,``)0$``!C!````````/`!```K!@``%@4``+0```#7`P```````-P&``!8
M!0``%@(```H#``#H`0```````-4&````````!P4``/0!``">!````````!<"
M`````````````)4"``"&`````````#P!```````````````````*`0``````
M`+\$````````800``.D```!*`@``J08``-L$``!(!0``D`4``!\"``#T`@``
M``````````#K!0``#@8``(H$``#Y!@```````!T%``!"````<P0````````%
M!@``,@0``),"```,`0```````/`"``"(````-0,``-H&``"9!0``>````.0`
M``!@`@``2P8``(X&``#G````T@4``-D%```X!```PP8```````!I`0``>00`
M````````````#@,```````#%!````````&\%````````Y@8````````P`0``
MS@0```````"6!0``'0,``"D!```B!P```````"4&``#4!@``[@,``((!``!]
M!```W`(``#D````%!````````(L```#X!```M@$```@!``!F!@``H`0``.H$
M`````````````!H&```T!@```````*(`````````NP(``$($````````"P$`
M``````#E!@``<`4```````"1`0``GP```.8!``"%!```_P(````````$!0``
M`````"4!````````8`$``!`#```A`P```````'P"``!J!@``@P```!P#``"H
M`@``Q`$``,`$``"M`@``I@0```````!"!0``&0$```````"2`0``L@$``,T$
M``"I!````````&X"```(!P```````/0&```````````````````H`0``#P(`
M``````!=`@``V0$``&P&``#0`0``X`(``'`!````````8@4``.$```";`0``
MIP0``%4```````````4``%P&```````````````````8!@```````.L`````
M````R0$``*<````,`P```@8`````````````Z0(``"T"````````-`(``!P"
M```"````8`0``.0#````````4@```.0"``"W!@``+P$````````E`@``````
M`"8"``!+`@``5`(``-,#```U`@``10```$,"````````>0(``.,#``"2`@``
M;`(``"4$``#"!```9`4``,8$````````QP,``!H'````````&00``#4$```9
M`P```````$`&``#'````F``````````@````N`(``.0%``"^!@``U```````
M``![`P```````)D!``!M`@````````,&``!'`P```````*4```#*````Y@4`
M`#T&````````&@(```````#Q`P`````````````"`P``K`$``-H"````````
MP@8``&P#``#\`0``M@,``/8$```2!0``508``#P&``#$!0``R````'L&``#K
M`@``&`$````````;!P``UP8``/<#``"Y`@`````````````3!```10,``$@#
M```N`P``H````%H%``"2`P``O00```````````````````````!-`@``?P(`
M`!<&``"E!0``P@(``%D&```\`P``W`0``#L#``#5!0``+@4``(H```!@`P``
MY0,```0&``!T````%0``````````````V0````````#*`0``O@4``)H"``#*
M!@```````#D%```V!````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S
M*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R
M9&%Y*0`@870@`")&:7)S=&YA;64@3&%S=&YA;64B("`H:64N($IO:&X@1&]E
M*0`B3&%S=&YA;64L($9I<G-T;F%M92(@*&EE+B!$;V4L($IO:&XI`"5D("5S
M(&%N9"`E<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R
M<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A
M9&1E9"X`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&9I;&4@
M<W5C8V5S<V9U;&QY(&EM<&]R=&5D`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($-A;&5N9&%R
M`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U<W1I;F<@
M)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q
M,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&)R;W=S
M97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D`$$@9&%T86)A
M<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A
M;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@4VAO=V5R<P!!
M32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)O=F4@
M<V5A<F-H(&9O<FT`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN
M`$%C8V]U;G1I;F<`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S
M:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO
M;@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`
M061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M`$%D9"!T;P!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M<F5S<P!!9&1R97-S($)O;VL@3&ES=&EN9P!!9&1R97-S(&)O;VL@96YT<GD`
M061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N`$%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T
M:6]N`$%D<P!!9'9A;F-E9"!396%R8V@`069G:&%N:7-T86X`06QB86YI80!!
M;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT
M:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F
M;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y($5X:7-T<P!!;')E
M861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U3
M4"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@
M96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T
M97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X
M>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI
M8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN
M`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<FEL`$%R86)I8R`H
M5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`
M07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/P!!<F4@
M>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C=&5D
M(&5N=')I97,_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R
M;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS
M:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S
M=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!
M3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D
M('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@
M9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B
M86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO
M<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M
M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R=7,`
M0F5L9VEU;0!"96QI>F4`0F5L;W<@<V5A<F-H(&9O<FT`0F5N:6X`0F5R;75D
M80!":'5T86X`0FEN9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`0FQO8VL@
M(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T
M=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E
M<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z
M:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U
M<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U
M<G5N9&D`0G5S:6YE<W,@0V%T96=O<GD`0TU3`$-20P!#4DP@1&ES=')I8G5T
M:6]N(%!O:6YT<P!#4U8`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#
M86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`
M0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B
M+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T
M(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M
M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS
M`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E
M;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L
M;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`
M0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D
M`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P
M;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL
M<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!?06QL+TYO;F4`0VAI;&4`
M0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!A;B!A9&1R97-S(&)O;VL`0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#
M;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`
M0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7
M:6YD;W<`0VQO=61S`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#
M;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O
M;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M
M;B!/<'1I;VYS`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA('-E<&%R871E
M9"!V86QU97,`0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U
M=&QO;VLI`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP86YY($%D9')E<W,`0V]M<'5T97)S
M`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U
M<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN
M96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@9F%I;&5D.B`E<P!#;VYN96-T
M:6]N(&9A:6QU<F4`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+@!#;VYT86-T(')E;6]V960@9G)O;2!L:7-T+@!#;VYT
M86-T<R!I;B!L:7-T.B`E<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&EN=64`0V]O:R!)<VQA
M;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T
M92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L
M9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+@!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R
M96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871E9`!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES
M`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@
M<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S
M97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L
M971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@
M26YD96YT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT
M('-O<G1I;F<@9&ER96-T:6]N.@!$969I;FET:6]N<P!$96QE=&4`1&5L971E
M($-O;F9I<FUA=&EO;@!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8G5T=&]N(&)E:&%V
M:6]U<@!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&9A:6QE9#H@*"5S*2`E<P!$
M96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971I
M;VX@9F%I;&5D`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97!A<G1M96YT`$1E
M<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E
M8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`
M1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y;W4@=V%N
M="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D
M("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N`$1O=VYL;V%D('9#87)D`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M
M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%
M9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<P!%9&ET(&5N=')Y(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@
M4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M
M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%
M;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L
M:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT
M97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME
M9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G
M92!54DP@:&5R90!%;G1R>2!F;W(@)7,@=7!D871E9"X`17%U871O<FEA;"!'
M=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED
M96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T
M`$5X<&]R="!!9&1R97-S($)O;VL`17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D
M(&-O;G1A8W1S+@!%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@
M8V]M<&QE=&5L>2X`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&%C8V5S<R!T
M:&4@861D<F5S<R!B;V]K.B`E<P!&86EL960@=&\@861D("5S('1O("5S.B`E
M<P!&86EL960@=&\@8G)O=W-E(&QI<W0`1F%I;&5D('1O(&)R;W=S92!T:&4@
M9&ER96-T;W)Y`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&
M86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P
M>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T
M;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&9I;F0@
M;V)J96-T('1O(&)E(&%D9&5D.B`E<P!&86EL960@=&\@;6]V92!T;R`B)7,B
M+@!&86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S`$9A:7(`1F%L
M:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9I
M:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&
M:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L
M;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;F0`
M1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T($YA;64`1FER<W0@475A<G1E<@!&
M:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M
M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O
M<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P
M;VQI=&%N`$9R965B=7-Y(%523`!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY
M;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T
M:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O
M;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R
M9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L
M($%D9')E<W,@0F]O:P!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A
M;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D
M80!'<F]U<`!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L
M80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A
M`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M
M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N
M(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/
M+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP
M97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`
M2&]M90!(;VUE($%D9')E<W,`2&]M92!#:71Y`$AO;64@0V]U;G1R>0!(;VUE
M(%!H;VYE`$AO;64@4&]S=&%L($-O9&4`2&]M92!3=&%T92]0<F]V:6YC90!(
M;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E
M<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E
M<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N
M=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(
M;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ
M(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)35-0`$E0($%D
M9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L
M871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`
M26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z
M`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N
M(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)
M9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G
M92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO
M=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%52
M3#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA
M9V4@=7!L;V%D`$EM86=E<P!);7!O<G0@061D<F5S<R!";V]K+"!3=&5P("5D
M`$EM<&]R="P@4W1E<"`E9`!);7!O<G0O17AP;W)T($%D9')E<W,@0F]O:W,`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2
M;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E
M8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N
M97-I80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN
M<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R
M="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!)
M;G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O
M;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G
M97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E
M9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI
M<W0`26YV86QI9"!)1`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+@!);G9A;&ED(&%D9')E<W,@8F]O:P!);G9A;&ED(&%P<&QI8V%T:6]N+@!)
M;G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A
M;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@96UA:6P`26YV86QI
M9"!E;G1R>0!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@:V5Y('-P96-I
M9FEE9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!N86UE`$EN=F%L:60@
M;V)J96-T260`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN
M=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!)
M;G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA
M;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E
M<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E
M("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF
M>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU
M<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE
M;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE
M;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI
M8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3$1!4"!S
M=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T
M(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+@!,85]Y;W5T`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T
M($UO9&EF:65D`$QA<W0@3F%M90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D
M.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@
M;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L
M=65S`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI
M96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A
M:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3
M:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES=`!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E
M`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD
M(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G
M:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W
M87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E
M>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L
M971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$
M`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA
M8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O
M9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K
M+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`36%R9VEN
M`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA
M;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<`36%T8VAI;F<@9FEE;&1S`$UA=7)I
M=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A
M9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-
M87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87AI;75M
M(&YU;6)E<B!O9B!P86=E<P!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S
M`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S
M86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T
M<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI
M9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UI;FD@4V5A<F-H`$UI<G)O<@!-:7-C96QL
M86YE;W5S`$UI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO
M;BX`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG
M(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I
M9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M
M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL
M+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO8FEL92!0
M:&]N90!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D:69Y
M(&9A:6QE9#H@*"5S*2`E<P!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F
M`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S
M97)R870`36]O;B!0:&%S97,`36]R92!T:&%N(#$@96YT<GD@9F]U;F0`36]R
M;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`
M36]V90!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-
M;W9E(&1O=VX`36]V92!L969T`$UO=F4@<FEG:'0`36]V92!U<`!-;WIA;6)I
M<75E`$UU;&)E<G)Y($%D9')E<W,@0F]O:P!-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',`375L=&EP;&4@<&5R<V]N<R!W:71H(&%D9')E<W,@6R5S72P@
M8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@86QR96%D>2!E>&ES=`!-=6QT:7!L
M92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;64@1F]R
M;6%T`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T8V5N=&5R($UE;6)E<B!$:7)E
M8W1O<GD`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A
M<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P
M92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T
M92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O
M<GD`3F5W($-O;G1A8W0`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA
M;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G
M<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI8VMN86UE`$YI
M9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R`E<R!E;G1R>2!F;W5N9"!F
M;W(@)7,`3F\@861D<F5S<R!B;V]K<R!F;W5N9"X`3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@
M8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N`$YO(&-O;G1A8W1S(&9O=6YD`$YO(&-R961I="!L969T
M+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.
M;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E
M('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I
M9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A
M=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-3
M3"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A
M=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=D-A<F0@9&%T82!W
M87,@9F]U;F0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E
M<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I
M;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM
M,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE
M<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R
M90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO
M="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(&ET96US('!E<B!P86=E`$YU;6)E<B!O
M9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/
M8FIE8W0@;F]T(&9O=6YD`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`
M3V9F:6-E`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P
M97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@
M4F%I;@!032!3:&]W97)S`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`4&%D9&EN
M9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P
M:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#
M;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E
M<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D
M<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H
M`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N($1E;FEE9`!0
M97)M:7-S:6]N(&1E;FEE9`!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0
M97)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO
M;F4`4&AO=&]S`%!I;F4@061D<F5S<R!";V]K`%!I=&-A:7)N`%!I>&5L<P!0
M;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R
M93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!!9&1R
M97-S($)O;VL`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`475E
M<GD@9F%I;&5D.B`H)7,I("5S`%%U:6-K(%-E87)C:`!24T$@4'5B;&EC($ME
M>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A
M:6X@3&%T90!286EN(%-H;W=E<@!286YD;VT@1F]R='5N90!2871I;P!296%D
M`%)E860@9F%I;&5D.B`H)7,I("5S`%)E860@;65S<V%G97,`4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A
M;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8V]R9',@9&ES<&QA>65D.@!2961O
M97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M
M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP
M($)R;W=S97(`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!"
M;&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F
M<F]M('1H:7,@;&ES=`!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H
M90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U
M<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@;V)J96-T(&YO
M="!F;W5N9"X`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-E="!T;R!$969A=6QT<P!297-U;'1S`%)E='5R;B!T;R!/<'1I
M;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT
M('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T
M92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S
M`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!3+TU)344@4'5B;&EC($-E<G1I9FEC871E`%-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!3
M44P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE
M;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!
M<F%B:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I
M;VXN`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!F86EL
M960`4V5A<F-H(&9A:6QE9#H@)7,`4V5A<F-H:6YG+BXN`%-E;&5C="!&:6QE
M<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@
M82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@
M861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J
M96-T`%-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.@!3
M96QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z`%-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE
M(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F;W)M870Z`%-E;&5C
M="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@9F]R;6%T(&]F('1H
M92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P
M;&%Y(&YA;65S.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T
M<RX`4V5L96-T('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+@!396QE
M8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L
M`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R
M:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N
M<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@
M979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N
M`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@
M<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3
M971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`
M4VAA<F5D($1I<F5C=&]R>0!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W
M`%-H;W<@06QL`%-H;W<@0V]N=&%C=',`4VAO=R!,:7-T<P!3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L
M;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAR:6YK
M`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`
M4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT
M96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO
M=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W
M(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI
M80!3;VYG<R`F(%!O96US`%-O<G0@1&ER96-T:6]N`%-O<G0@;W)D97(@<V5L
M96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=7)C97,`4V]U=&@@069R:6-A`%-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E
M`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C
M:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W!E8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@
M<F5S=6QT<R!T;R!A<'!E87(N`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P
M;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3
M=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O
M<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T
M`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U
M`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL
M>2!A9&1E9"`E<R!T;R`E<P!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!W<F]T
M92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N
M<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@
M`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R
M9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U
M8FQI8P!4+5-T;W)M`%0M4W1O<FUS`%135@!44U8@9FEL90!486(@<V5P87)A
M=&5D('9A;'5E<P!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E
M<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI
M<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S
M:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP
M97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N
M`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A4
M25,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T
M96TN`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N`%1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@
M)7,`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C
M="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H
M92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N`%1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES
M="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E
M<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@
M86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R
M8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R
M(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7
M:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@
M)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E
M<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@
M8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@
M=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T
M;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@
M<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U
M<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!B<F]W
M<V5A8FQE(&%D9')E<W,@8F]O:W,N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N`%1H97)E(&%R92!N;R!W<FET96%B;&4@861D<F5S<R!B
M;V]K<RX@3F]N92!O9B!T:&4@879A:6QA8FQE(&%D9')E<W,@8F]O:W,@87)E
M(&-O;F9I9W5R960@=&\@86QL;W<@>6]U('1O(&%D9"!N97<@96YT<FEE<R!T
M;R!T:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES(&ES(&%N(&5R<F]R+"!P;&5A
M<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4:&5R92!A
M<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V
M92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@
M=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N
M('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@
M861D:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&9O<B!F=7)T:&5R(&AE;'`N`%1H97)E('=A<R!A;B!E
M<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+@!4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<P!4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@=&AI<R!O8FIE8W0N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R
M9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y.B`E<P!4:&5R92!W97)E
M(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N`%1H:7,@24U!4"!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC
M:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G
M:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N
M92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T
M86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@
M8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE
M("<C,3(S-&%F)RX`5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D
M+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@
M:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V
M:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT
M('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N
M($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I
M="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@
M)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:P!4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@
M3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C
M:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4
M:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O
M=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M
M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U
M92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U
M.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U
M=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!5
M9V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I
M9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP
M<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@
M)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`
M56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D
M>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R
M=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`
M56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@
M=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5
M;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@
M=7-E<@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y
M`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D
M(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T
M(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@
M3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R;F%M90!5<V5R
M;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES
M=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@
M:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@
M9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"X`5F5R:7-I9VX@1&ER96-T;W)Y`%9E<G-I;VX`5F5R<VEO;B!#;VYT
M<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ
M`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@
M)7,`5FEE=R!#;VYT86-T`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE
M=R!A<R`E<P!6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#H`5FER9VEN($ES
M;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET
M>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%L
M;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E
M871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I
M=&4`5V5B<VET92!54DP`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!7
M96QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M
M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7
M:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET
M`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7
M:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@0VET>0!7;W)K
M($-O=6YT<GD`5V]R:R!0:&]N90!7;W)K(%!O<W1A;"!#;V1E`%=O<FL@4W1A
M=&4O4')O=FEN8V4`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N
M871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y
M=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N
M`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@
M=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO
M=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE
M("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E<FUI
M<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN
M`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+@!9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A
M="!L96%S="!O;F4@96YT<GD@9FER<W0N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&]N;'D@
M:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+@!9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U
M<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O
M<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@
M3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A
M<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE
M=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@
M<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;
M;&EN92`E<R!O9B`E<UT`6VYO('9A;'5E70!?061M:6YI<W1R871I;VX`7T)R
M;W=S90!?0TQ)`%]$871A5')E90!?1&5L971E`%]$96QE=&4@4F]W`%]'<F]U
M<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R="]%>'!O<G0`
M7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E
M<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4F5M;W9E(&9R;VT@=&AI<R!L
M:7-T`%]396%R8V@`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R
M<P!A9&1R97-S(&)O;VL`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E`&-O;G1A
M8W0N=F-F`&-O;G1A8W1S+F-S=@!C;VYT86-T<RYT<W8`9F%L;&EN9P!F:6QE
M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`:6UM961I871E`&EN;&EN
M90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)
M4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`
M;F]T97!A9`!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E
M<P!S;7,R96UA:6P@=FEA($A45%``<W1E861Y`'1A<VL@;&ES=`!T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U
M<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E
M<G-I;VXZ("!4=7)B82!(,R`H,BXP*0I297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#(M,C$@
M,34Z,C4K,#$P,`I,87-T+51R86YS;&%T;W(Z($UA=&EC($1O;&%R(#QS;65S
M;FE`;65D:75M+G-I/@I,86YG=6%G92U496%M.B!3;&]V96ZYZ&EN80I-24U%
M+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]:7-O+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M"@`@*"5S(&1N:2!N87IA:BD`("A";&F^;FII8V$@)7,I`"`H=B`E<R!D;F5H
M*0`@*&1A;F5S*0`@*&IU=')I*0`@*';H97)A:BD`('!R:2``(DEM92!0<FEI
M;65K(B`@*&YP<BX@2F%N97H@2W)A;FIS:VDI`")0<FEI;65K+"!);64B("AN
M<'(N($MR86YJ<VMI+"!*86YE>BD`)60@)7,@:6X@)7,`)60M9&YE=FYA(&YA
M<&]V960`)7,@+2!/8G9E<W1I;&\`)7,@4')S=&YI(&]D=&ES`"5S($M"`"5S
M(%9Z9'*^979A;FIE("T@4&]T<F1I=&5V`"5S(%!R:6IA=F$`)7,@4&]G;VII
M('5P;W)A8F4`)7,@9&]D86XN`"5S(+YE(&]B<W1A:F$N`"5S('!R:2`E<R`E
M<P!$871O=&5K82`E<R!U<W!EN6YO('5V;[YE;F$`)7,@:F4@>F%H=&5V86X`
M)7,@;6EN=70`)7,@;FD@;6]G;^AE(&YA:G1I+@`E<R!K("5S(&]D("5S`"5S
M+6]V($MO;&5D87(`)7,M;W9A($)E;&6^;FEC80`E<RUO=B!397IN86T@;W!R
M879I;``E<SH@)7,`+"!P:6AA:F_H("5S("5S`"P@<W!R96UE;FQJ:79O(&]D
M("5S(&1O("5S`"TM(&EZ8F5R:2`M+0`Q,B!5<FYA(&]B;&EK80`R-"!5<FYA
M(&]B;&EK80`R-"!U<@!:86AT979A;B!J92!B<G-K86QN:6L@:VD@<&]D<&ER
M82!I1G)A;65S`%IA('1A(&)L;VL@:F4@>F%H=&5V86YA('5P;W)A8F$@8F%Z
M92!P;V1A=&MO=BX`4')IN6QO(&IE(&1O('5S;V1N92!N87!A:V4`6F$@N6EF
M<FER86YJ92!S<&]R;^AI;&$@:F4@<&]T<F5B96X@:F%V;FD@4$=0(&ML:G7H
M+@!:82!O=F5R:71E=B!P;V1P:7-A;F5G82!S<&]R;^AI;&$@:F4@>F%H=&5V
M86X@:F%V;FD@4$=0(&ML:G7H+@!:82!D9;EI9G)I<F%N:F4@<W!O<F_H:6QA
M('-O('!O=')E8FYI(&IA=FYI(%!'4"!K;&IUZ"P@>F%S96)N:2!01U`@:VQJ
M=>@@:6X@9V5S;&\N`%IA('!O9'!I<R!S<&]R;^AI;&$@<V\@<&]T<F5B;FD@
M:F%V;FD@4$=0(&ML:G7H+"!Z87-E8FYI(%!'4"!K;&IUZ"!I;B!G97-L;RX`
M6F$@9&6Y:69R:7)A;FIE('-P;W)OZ&EL82!S;R!P;W1R96)N:2!J879N:2!3
M+TU)344@:VQJ=>@L('IA<V5B;FD@4R]-24U%(&ML:G7H(&EN(&=E<VQO+@!:
M82!P;V1P:7,@<W!O<F_H:6QA('-O('!O=')E8FYI(&IA=FYI(%,O34E-12!K
M;&IUZ"P@>F%S96)N:2!3+TU)344@:VQJ=>@@:6X@9V5S;&\N`%IA(+EI9G)I
M<F%N:F4@<W!O<F_H:6QA(&IE('!O=')E8F5N(&IA=FYI(%,O34E-12!K;&IU
MZ"X`04T@4&QO:&4`04TO4$T`05!)($E$`$\@=&5M('5R96IE=F%L;FEK=0!/
M+BXN`$YA9"!O8G)A>F-E;2!Z82!I<VMA;FIE`$%B<V)O='1O;0!!8G-M:61D
M;&4`1&]S=&]P('!R:2!I>F1E;&]V86YJ=2!61E,@;6%P92!Z879R;FIE;BX`
M1&]S=&]P('!R:2!I>F1E;&]V86YJ=2!61E,@9&%T;W1E:V4@>F%V<FYJ96XN
M`$=E<VQO(')AZ'5N80!28>AU;B!Z86UR>FYJ96XN`%)AZ'5N;W9O9'-T=F\`
M1&]D86H@<&]D<VMU<&EN;P!$;V1A:B!P<F%V:6-E('!O9'-K=7!I;F4`1&]D
M86H@='5K86HZ`$1O9&%J(&YO=F\@<VMU<&EN;P!$;V1A:B!N;W9O(&1O=F]L
M:F5N:F4`1&]D86H@;F]V96=A('5P;W)A8FYI:V$Z`$1O9&%J('-T;VQP96,`
M1&]D86H@;F]V92#H;&%N90!$;V1A:B!P87(`1&]D86H@)7,@;65N=2!K;W0@
M36]Z:6QL82!3:61E8F%R`$1O9&%J('8`1&]D86H@=B!A9')E<V%R.@!$;V1A
M:B!V(&UO:B!A9')E<V%R`$1O9&%J('5P;W)A8FYI:V$`1&]D86IA;FIE('5P
M;W)A8FYI:V]V(&IE(&]N96UO9V_H96YO+@!.87-L;W9I`%-E>FYA;2!!9')E
M<V%R:F5V`%9N;W,@=B!A9')E<V%R`$%D<F5S87(@=7-P9;EN;R!P;^AIN>AE
M;BX`061M:6YI<W1R86-I:F$@+2!N87-T879I('!R879I8V4@;W-T86QI:"!U
M<&]R86)N:6MO=@!!9&UI;FES=')A8VEJ80!296ML86UE`$YA<')E9&YO($ES
M:V%N:F4`069G86YI<W1A;@!!;&)A;FEJ80!!;+YI<FEJ80!0<V5V9&]N:6T`
M4&]R879N86H`4&]R879N879A.@!6<V4`5G-I($]V97)J96YI('5P;W)A8FYI
M:VD`5G-E(%-K=7!I;F4`5G-A($1O=F]L:F5N:F$`5G-E(+ET:7)I('-T<F%N
M:0!$;W9O;&D@=F7H(&YA<VQO=F]V`$1O=F]L:2!N87-T879I=&5V('5R96IE
M;F5G82!T:7!A('-E>FYA;6$_`*YE(&]B<W1A:F$`KF4@;V)S=&%J80!!;'1E
M<FYA=&EV;F$@24U34"!P<FEJ879A`$%L=&5R;F%T:79N;R!)35-0(&=E<VQO
M`$%L=&5R;F%T:79N;R!)35-0('5P;W)A8FYIN6MO(&EM90!!;'1E<FYA=&EV
M96X@92UP;[ET;FD@;F%S;&]V`$%L=&5R;F%T:79N92!P<F5D;&]G90!!;'1E
M<FYA=&EV;F\@8F5S961I;&\Z`$%M97)IN6MA(%-A;6]A`%9N9;EE;F$@:F4@
M8FEL82!N87!AZ&YA('9R961N;W-T+@!!;F1O<F$`06YG;VQA`$%N9W5I;&$`
M06YO;FEM96X@<')O>'D`3V1G;W9O<@!!;FMT87)T:6MA`$%N=&EG=F$@:6X@
M0F%R8G5D80!!<&QI:V%C:6IA`%-E>FYA;2!A<&QI:V%C:6H`07!L:6MA8VEJ
M82!J92!P<FEP<F%V;&IE;F$N`%5P;W)A8FD@>F$@<&]D<F5J96YE(&]B:F5K
M=&4@=B!S:W5P;FD@<F%B:0!/9&]B<FD`07!R:6P`07)A8G-K;R`H5VEN9&]W
M<RTQ,C4V*0!696QI:V]S="!A<FAI=G-K92!D871O=&5K90!);64@87)H:79A
M`%-T92!P<F5P<FGH86YI+"!D82"^96QI=&4@:7IB<FES871I("5S/P!3=&4@
M<')E<')IZ&%N:2P@9&$@OF5L:71E(&EZ8G)I<V%T:2!I>F)R86YE('9N;W-E
M/P!!;&D@<W1E('!R97!R:>AA;FD@9&$@OF5L:71E(&]D<W1R86YI=&D@<')I
M:F%V;F\@>F%H=&5V;R!Z82`E<R`_`$%R9V5N=&EN80!!<FUE;FEJ80!!<FUE
M;FEJ<VMO("A!4DU30TE)+3@I`%5M971N;W-T`$%R=6)A`$YA<F&YZ&%J;^@`
M3W1O:R!!<V-E;G-I;VX`07-C:6D@<VQI:V4`07II:G-K82]086-I9FFY:V$@
M<F5G:6IA`%9P<F&Y86T@>F$@<&]T<F1I=&5V('!R960@:7IV961B;R!O<&5R
M86-I:B!V>F1ROF5V86YJ83\`4W1O;'!C:2!Z82!D;VQOZ&ET978`4&]S:W5S
M(&)R:7-A;FIA(&YE;V)S=&]J9>AE('-K=7!I;F4N`%!O<VMU<R!B<FES86YJ
M82!N96]B<W1O:F7H96=A(&1O=F]L:F5N:F$N`%!O<VMU<R!U<F5J86YJ82!N
M96]B<W1O:F7H96=A(&1O=F]L:F5N:F$N`%!O<VMU<R!U<F5J86YJ82!N96]B
M<W1O:F7H92!S:W5P;F4@<F%B92X`071R:6)U=&D`079G=7-T`$%V<W1R86QI
M:F$`079S=')I:F$`075T:%]C>7)S<6PZ(%!O=')E8FYE9V$@24U!4"!D;V1A
M=&MA(&YI(&UO9V_H92!N86IT:2X`075T:%]C>7)U<SH@2')B=&5N:6-A('!R
M;V=R86UA(&YI;6$@<&]T<F5B;FEH('IM;[YN;W-T:2X`075T:%]C>7)U<SH@
M4&]T<F5B;F5G82!)34%0(&1O9&%T:V$@;FD@;6]G;^AE(&YA:G1I+@!!=71H
M7V9T<#H@4&]T<F5B;F5G82!&5%`@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN
M($-O;7!I;&%J=&4@4$A0('H@;6^^;F]S=&IO("TM96YA8FQE+69T<"X`075T
M:%]I;6%P.B!0;W1R96)N96=A($E-05`@9&]D871K82!N:2!M;V=OZ&4@;F%J
M=&DN`$%U=&A?:W)B-3H@4&]T<F5B;F5G82!K<F(U(&1O9&%T:V$@;FD@;6]G
M;^AE(&YA:G1I+@!!=71H7VQD87`Z(%!O=')E8FYE9V$@3$1!4"!D;V1A=&MA
M(&YI(&UO9V_H92!N86IT:2X`075T:%]L9&%P.B!5<&]R86)N:6MA("5S(&YI
M(&UO9V_H92!D;V1A=&DN(%-T<F6^;FEK(&IE(&IA=FEL.@!!=71H7VQD87`Z
M(%5P;W)A8FYI:V$@)7,@;FD@;6]G;^AE(&]D<W1R86YI=&D`075T:%]L9&%P
M.B!5<&]R86)N:6MA("5S(&YI(&UO9V_H92!P;W-O9&]B:71I`$%U=&A?;6-A
M;#H@4&]T<F5B;F5G82!-0T%,(&1O9&%T:V$@;FD@;6]G;^AE(&YA:G1I+@!!
M=71H7W-M8F%U=&@Z(%!O=')E8FYE9V$@<VUB875T:"!D;V1A=&MA(&YI(&UO
M9V_H92!N86IT:2X`3W9E<FIA;FIE(&YI('5S<&5L;P!/=F5R:F%N:F4@;FD@
M=7-P96QO+B`E<P!/=F5R:F%N:F4@>F%V<FYJ96YO(&YA(%)!1$E54R!S=')E
MOFYI:W4N`$]V97)J86YJ92!N82!&5%`@<W1R9;YN:6MU(&YI('5S<&5L;RX`
M4&]L:F$@:VD@<V\@;F$@=F]L:F\Z`$%Z97)B86IDOF%N`$)/1D@@27IG;W9O
M<FD`3WIA9&IE`$)A<G9A(&]Z861J80!.97!R879I;&YO(&ME<F)E<F]S(&=E
M<VQO+@!.97!R879I;&YO(&ME<F)E<F]S('5P;W)A8FYIN6MO(&EM92X`0F%H
M86UI`$)A:')A:FX`0F%L=&FY:V\@*$E33RTX.#4Y+3$S*0!"86YG;&%D9;D`
M0F%R8F%D;W,`3W-N;W9A`$]S;F]V;F\@27-K86YJ90!"96QO<G5S:6IA`$)E
M;&=I:F$`0F5L:7IE`%!O9"!O8G)A>F-E;2!Z82!I<VMA;FIE`$)E;FEN`$)E
M<FUU9&$`0G5T86X`5F5Z879A('-P;V1L971E;&$Z("@E<RD@)7,`4F]J<W1N
M:2!D86X`0FQO:V$@(B5S(B!A<&QI:V%C:6IE("(E<R(@;FD@;6]G;^AE(&YA
M:G1I+@!.87-T879I='9E(&)L;VMA`%9R<W1A(&)L;VMA`$MR97!K;P!";VQI
M=FEJ80!0<FEL:G5B;&IE;F4`4F]B`$1E8F5L:6YA(')O8G4Z`%)O8F]V:0!"
M;W-N82!I;B!(97)C96=O=FEN80!/8F]J90!";V-V86YA`%-P;V1A:@!/=&]K
M($)O=79E=`!"<F%Z:6QI:F$`0G)I=&%N<VMO(&]Z96UL:F4@26YD:6IS:V5G
M82!O8V5A;F$`0G)U;F5J($1A<G5S<V%L86T`0G5L9V%R:6IA`$]Z;F'H96YI
M('-E>FYA;0!"=7)K:6YA($9A<V\`0G5R=6YD:0!+871E9V]R:6IA(%!O<VQA
M`$--4P!#4D,`5&_H:V4@9&ES=')I8G5C:6IE($-23`!#4U8`3&%S=&YO<W1I
M(&-?96QI8V4N+BX`2V]L961A<@!-:7)N;P!+86UB;V2^80!+86UE<G5N`$=E
M<VQA(&YI(&UO9V_H92!P;VYA<W1A=FET:2!A=G1O;6%T:>AN;RP@:V]N=&%K
M=&ER86IT92!S=F]J96=A(&%D;6EN:7-T<F%T;W)J82X`4&]V97IA=F4@>B!)
M34%0('-T<F6^;FEK;VT@;FD@;6]G;^AE('9Z<&]S=&%V:71I.B`E<P!+86YA
M9&$`4')E:VQIZ&D`4')E:VQIZ&D@<')I:F%V;R!N87!A:V4`1&%T;W1E:V4@
M(B5S(B!N:2!M;V=OZ&4@:7IB<FES871I+@!:8>AA<VYE(&UA<&4@;FD@;6]G
M;^AE(&YA:G1I+@!"<F5Z("=T87)G971&:6QE)R!P87)A;65T<F$@;FD@;6]G
M;^AE(&YA9&%L:F5V871I+@!-87!E("(E<R(@;FD@;6]G;^AE(&]D<W1R86YI
M=&DN`$]B:F5K=&$@;FD@;6]G;^AE(&]D<W1R86YI=&DL(&]B<W1A:F$@)60@
M<&]D;V)J96MT;W8N`%!O;F]V;F$@<F%Z=G)S=&ET978@;FD@;6]G;^AA+""Y
M=&5V:6QO('!O9&%N:6@@=G!I<V]V(&YE('5S=')E>F$@<VAR86YJ96YE;74@
MN71E=FEL=2!V<&ES;W8@>F$@<&]N;W9N;R!R87IV<G-T:71E=BX`4W!O<F_H
M:6QA(&YI(&UO9V_H92!U<VUE<FET:2!N82!P;V1A;F\@N71E=FEL;RX`0V%P
M92!697)D90!.87-L;W8`2V%T96=O<FEJ92!I;B!O>FYA:V4`2V%J;6%N<VMI
M(&]T;VMI`$UO8FEL;FD@=&5L969O;@!,87-T;F]S=&D@8V5L:6-E`%!R87IE
M;B!P<F]S=&]R('8@8V5L:6-I.@!,87-T;F]S=&D@8V5L:6-E`%!R87IE;B!P
M<F]S=&]R(&UE9"!C96QI8V%M:3H`36]B:6QN:2!T96QE9F]N`$ME;'1S:V\@
M*$E33RTX.#4Y+3$T*0!3<F5D:6YA`%-R961N:F5A9G)IN6MA(%)E<'5B;&EK
M80!3<F5D;FIE979R;W!S:V\@*$E33RTX.#4Y+3(I`%!O9')O8FYO<W1I('!O
M=')D:6QA`%!O;&ET:6MA('!O=')D:6QA`,AA9`!3<')E;65N:0!.87-T879I
M(&EM92!I;B!N87-L;W8L(&MI(&=A(&]S96)E('9I9&EJ;RP@:V\@8F5R96IO
M(&EN(&]D9V]V87)J86IO(&YA('9AN6\@92UP;[ET;RX`6FYA:P!0<F5V7V5R
M:2!P;W9E>F%V;RXN+@!0<F5V97)I(%]6<V4O3F]B96YE9V$`R&EL90!+:71A
M:G-K80!0;V5N;W-T879L:F5N;R!+:71A:G-K;R`H1T(R,S$R*0!4<F%D:6-I
M;VYA;&YO($MI=&%J<VMO("A":6<U*0!)>F)E<FET92!G97-L;P!)>F)E<FET
M92!U<&]R86)N:;EK;R!I;64`27IB97)I=&4@861R97-A<@!)>F)E<FET92!N
M8>AI;B!P<FEK87IA(&1A='5M;W8Z`$EZ8F5R:71E(&EZ9VQE9"!S97IN86UA
M("AZ82!U<F5J96YE('-E>FYA;64I`%9E;&EK;VYOZ&YI(&]T;VL`1&5F:6YI
M8VEJ92!R87IR961A("5S(&YI(&UO9V_H92!N86IT:2X`2F%S;F\`4&_H:7-T
M:2!-4T]F9FEC92!O>FYAZ&)E`%!OZ&ES=&D@=7!O<F%B;FEK83H@)7,`4&_H
M:7-T:2!U<&]R86)N:6MA`%!OZ&ES=&D@<&]D871K92!O('5P;W)A8FYI:W4`
M2VQI:VYI('IA(&YA9&%L:F5V86YJ90!#;&EC:V%T96QL('!R96MO($A45%``
M6F%P<FD@;VMN;P!/8FQA:VD`3V)L8>AN;P!+965L:6YG;W9I(&]T;VMI`%-K
M<FEJ('-T<F%N<VMI(&UE;G4`4VMR:6H@<F]B;W9E`$MO;'5M8FEJ80!"87)V
M80!"87)V;F$@=&%B96QA`$EZ8FER82!B87)V90!3=&]L<&-I.@!-;[YN;W-T
M:2!S=&]L<&-E=@!.87-L;W9I('-T;VQP8V5V`%-T<FEP:0!6<F5D;F]S=&D@
M;&_H96YE('H@>FYA:VD`5G)E9&YO<W1I(&QOZ&5N92!Z('IN86MI("A-:6-R
M;W-O9G0@3W5T;&]O:RD`56MA>@!5:V%Z;F$@;'5P:6YA`$MO;65N=&%R`$EM
M90!+;VUO<FD`4&]D:F5T:F4`3F%S;&]V(%!O9&IE=&IA`%)AZ'5N86QN:6MI
M`%!O9V]J:0!287IL:6ME('8@;F%S=&%V:71V86@`3F%S=&%V:2`E<P!0;W1R
M9&D@9V5S;&\`2V]N9V\`1&5M;VMR871S:V$@4F5P=6)L:6MA($MO;F=O`%!O
M=F5Z879A(&YI('5S<&5L82X`4&]V97IA=F$@;FD@=7-P96QA.@!0;W9E>F%V
M82!S<&]D;&5T96QA.B`E<P!0;W9E>F%V82!S<&]D;&5T96QA`%!O=F5Z879A
M(&YA(&IA=FYI('-T<F6^;FEK(',@:VQJ=>AI('IA=G)N:F5N82X`4&]V97IA
M=F$@;F$@:F%V;FD@<W1R9;YN:6L@<R!K;&IUZ&D@>F%V<FYJ96YA+B!287IL
M;V<Z("5S("@E<RD`4&]V97IA=F$@;F$@1E10('-T<F6^;FEK(&YI('5S<&5L
M82X`4W1I:R!O9'-T<F%N:F5N(',@<V5Z;F%M82X`4W1I:VD@;F$@<V5Z;F%M
M=3H@)7,`4W1I:VD@<V\@8FEL:2!U<W!EN6YO(&1O9&%N:2!V(&%D<F5S87(N
M`$YA<')E:@!#;V]K;W9I(&]T;VMI`%!IN6MO=&5K`$MO<&ER86H`2V]P:7)A
M:B!I>F)R86YO`$MO<W1A<FEK80!3;&]N;VMON>AE;F$@;V)A;&$`4$=0('-P
M;W)OZ&EL82!N:2!B:6QO(&UO9V_H92"Y:69R:7)A=&DN`%!'4"!S<&]R;^AI
M;&$@;FD@8FEL;R!M;V=OZ&4@<&]D<&ES871I+@!3<&]R;^AI;&$@;FD@8FEL
M;R!M;V=OZ&4@N6EF<FER871I(',@4R]-24U%+@!3<&]R;^AI;&$@;FD@8FEL
M;R!M;V=OZ&4@<&]D<&ES871I(',@4R]-24U%+@!3=&EK82!N:2!B:6QO(&UO
M9V_H92!D;V1A=&DN("5S`%!O=F5Z879A(&YA($Q$05`@<W1R9;YN:6L@;FD@
M8FEL82!M;V=OZ&$N`%-T86YJ82!N:2!B:6QO(&UO9V_H92!P<F5V97)I=&DN
M("5S`%-E>FYA;6$@<F%Z9&5L:71V92!N:2!B:6QO(&UO9V_H92!I>F1E;&%T
M:2X@)7,`4$=0('!O9&%T:V]V(&YI(&)I;&\@;6]G;^AE(&1EN6EF<FER871I
M+@!3+TU)344@<&]D871K;W8@;FD@8FEL;R!M;V=OZ&4@9&6Y:69R:7)A=&DN
M`%-T:6MA(&YI(&)I;&\@;6]G;^AE('!O8G)I<V%T:2X@)7,`4V5Z;F%M82!R
M87ID96QI='9E(&YI(&)I;&\@;6]G;^AE('!O8G)I<V%T:2X@)7,`4')E:F5M
M;FEK;W9E9V$@92UP;[ET;F5G82!N87-L;W9A(&YI(&)I;&\@;6]G;^AE('5G
M;W1O=FET:2X`0V5L;W1N96=A(&%D<F5S87)J82!N:2!M;V=OZ&4@<')E8G)A
M=&DN`$-E;&]T;F5G82!S97IN86UA(')A>F1E;&ET=F4@;FD@;6]G;^AE('!R
M96)R871I+@!#96QO=&YE9V$@<V5Z;F%M82!S97IN86UO=B!R87ID96QI='9E
M(&YI(&UO9V_H92!P<F5B<F%T:2X`4R!S=')EOFYI:V$@<R!K;&IUZ&D@;FD@
M8FEL;R!M;V=OZ&4@9&]B:71I(&IA=FYE9V$@:VQJ=>AA+@`E<R!N:2!M;V=O
MZ&4@;V1P<F5T:2X`36]D=6QA($UA:6YT96YA;F-E7U1A<VL@;FD@;6]G;^AE
M(&]D<')E=&D@)7,`)7,@;FD@;6]G;^AE('!R96)R871I+@!:82!Z86AT979A
M;F5G82!U<&]R86)N:6MA(&YI(&)I;&\@;6]G;^AE('!O;F%S=&%V:71I(&=E
M<VQA+B!.96MA=&5R:2!A;&D@=G-I('!O9&%T:VD@;FES;R!P<F%V:6QN:2X@
M4&]S:W5S:71E('!O;F]V;F\L(&%L:2!P82!S92!O8G)N:71E(&YA('-V;VIE
M9V$@<VMR8FYI:V$@Z&4@<&]T<F5B=6IE=&4@;F%D86QJ;F\@<&]M;^@N`$%#
M3"!N:2!B:6QO(&UO9V_H92!P<F5B<F%T:0!!9')E<V%R:F$@;FD@;6]G;^AE
M('!R96)R871I+B`E<P!397IN86UA(')A>F1E;&ET=F4@;FD@;6]G;^AE('!R
M96)R871I+B`E<P!397IN86UO=B!R87ID96QI='9E(&YI(&UO9V_H92!P<F5B
M<F%T:2X@)7,`6FUOOFYO<W1I('-T<F6^;FEK82!N:2!B:6QO(&UO9V_H92!U
M9V]T;W9I=&D`3F%S=&%V:71E=B!N:2!B:6QO(&UO9V_H92!V<FYI=&D@;F$@
M<')V;W1N;R!S=&%N:F4`3F%S=&%V:71E=B`E<R!N:2!B:6QO(&UO9V_H92!S
M:')A;FET:2X`5F%R;F]S=&YE(&MO<&EJ92!N87-T879I=&5V(&YI(&)I;&\@
M;6]G;^AE('-H<F%N:71I+@!687)N;W-T;F4@:V]P:6IE(&YA<W1A=FET978@
M;FD@8FEL;R!M;V=OZ&4@<VAR86YI=&DZ("5S`$ES:V%N:F4@3$1!4"!S=')E
MOFYI:V$@;FD@=7-P96QO+@!3=&EK82!N:2!B:6QO(&UO9V_H92!P;W-O9&]B
M:71I+B`E<P!397IN86UA(')A>F1E;&ET=F4@;FD@8FEL;R!M;V=OZ&4@<&]S
M;V1O8FET:2X@)7,`365N=6IA($UO>FEL;&$@4VED96)A<B!N:2!B:6QO(&UO
M9V_H92!N86IT:2X@4')E<')IZ&%J=&4@<V4L(&1A(&IE(&]D<')T+@!5<&^Y
M=&5V86YO(&)E<V5D:6QO`$1ROF%V80!49>AA:FD`57-T=F%R:2!P;W9E>F%V
M;P!5<W1V87)I(&YO=F\`57-T=F%R:2!P;V1M87!O`%5S='9A<FIE;F\`4')A
M=FEC92!L87-T;FEK80"I=&5V:6QK82!K<F5D:71N92!K87)T:6-E`$AR=F&Y
M:V$`2W5B80!4<F5N=71E;B#H87,`5')E;G5T96X@55),(&IE`%1R96YU=&YO
M('9R96UE`%1R96YU=&YO('-T86YJ93H`5')E;G5T96X@<W1I;`!0<FEL86=O
M9&D@;W!R879I;&$L(&MI('-E('IAOF5N96IO(&]B('!R:6IA=FD@=B`E<RX`
M27IR9;YI`$EZ<F6^:2!I>F)R86YO`$-I<&5R`$-I<FEL:6-A("A+3TDX+5(I
M`$-I<FEL:6-A("A7:6YD;W=S+3$R-3$I`$-I<FEL:6-A+U5K<F%J:6YA("A+
M3TDX+54I`,AEN6MA`$1$`$1N979N;P!"<G-K86QN:6L@1&%T851R964`1&%T
M=6T`1&%T=6T@<')E:F5M80!)>F)I<F$@9&%T=6UA`$1A;@!)>F)R:;EI('-T
M;VQP96,`1&5C96UB97(`1&5C:6UA;&ME`%IM86YJN6%J('IA;6EK`%!R:79Z
M971A(&)A<G9A`%!R:79Z971A(&ED96YT:71E=&$`4')I=GIE=&$@<VUE<B!R
M87IV<G-T:71V93H`1&5F:6YI8VEJ90!)>F)R:;EI`%!O=')D:71E=B!I>F)R
M:7-A`$EZ8G)IN6D@<VMU<&EN;P!)>F)R:;EI('!R879I8V\`27IB<FFY:2!I
M;B!P;^AI<W1I('-P;W)OZ&EL80!/8FYAN6%N:F4@9W5M8F$@>F$@8G)I<V%N
M:F4`27IB<FFY:2!C96QI8V\`27IB<FFY:2!S=&]L<&5C`$EZ8G)IN6D@;V)S
M=&]J9>AO(&%L=&5R;F%T:79N;R!P<F5D;&]G;P!"<FES86YJ92!S<&]D;&5T
M96QO.B`H)7,I("5S`$EZ8G)IN6D@=G)S=&EC;P!)>F)R:;EI(&EZ8G)A;F\@
M:61E;G1I=&5T;P!)>F)R:;EI('1R96YU=&5N('-T;VQP96,`27IB<FFY:2!T
M<F5N=71N;R!V<G-T:6-O`$)R:7-A;FIE('-P;V1L971E;&\`R&%S(&1O<W1A
M=F4`1&%N<VMA`$]D9&5L96L`4&%D86IOZ`!/<&FY:2!P<F]B;&5M`%!O9')O
M8FYO<W1I("AT=61I('8@2&]R9&4@;&]G(&1A=&]T96MI*3H`4&]D<F]B;F]S
M=&D@<V\@8FEL92!Z87!I<V%N92!Z82!S:W)B;FEK82X`4F%Z=F]J`%)O<V$`
M4F]S82!V('IA9&YJ:2!U<FDZ`%)O<V$Z(`!3;65R(&]D(&QE=F4@<')O=&D@
M9&5S;FD`4VUE<B!O9"!D97-N92!P<F]T:2!L979I`$UA<&$`4')I:V&^96T@
MZ&%S('8@;V)L:6MI(#(T('5R/P!-;[YN;W-T:2!P<FEK87IA`%!R:6MAOFD@
M;F%P;W9E9"`H5$%&*0!/8FQI:V$@<')I:V%Z80!/8G9E<W1I;&\@;R!D:7-P
M;WII8VEJ:0!$OFEB=71I`$YE('!O8G)IN6D`3F4@9&]S=&]P86IT92!D871O
M=&5K92!M86EN=&5N86YC92YP:'`@;F5P;W-R961N;P"N96QI=&4@<&]T<FIE
M=F%T:2!I>F)R:7,@=FYO<V]V/P!!;&D@<')V82!V<G-T:6-A('9S96)U:F4@
M:6UE;F$@<&]L:C\@R&4@9&$L(&]D:VQJ=6MA:G1E.@!$;VUI;FEC80!$;VUI
M;FEK86YS:V$@<F5P=6)L:6MA`%!R96YE<VD@)7,`4')E;F5S:2!G96YE<FER
M86YO(&MO;F9I9W5R86-I:F\@:V]T(%!(4"!S:W)I<'1O+@!0<F5S;F5M:2!V
M0V%R9`!397IN86T@>B!I>F)I<F\`1')O9V4`12UP;[ET80!%4E(`16MV861O
M<@!5<F5D:0!5<F5D:2!B;&]K`%5R961I('-K=7!I;F\`57)E9&D@<')A=FEC
M;P!5<F5D:2!P<F%V:6-E`%5R961I('!R879I8V4@>F$@)7,`57)E9&D@=G!I
M<R!Z82`E<P!5<F5D:2!M;[YN;W-T:2!Z83H`57)E9&D@<')A=FEC92!Z82`E
M<P!)>F]B<F%Z8F$`16=I<'0`4V%L=F%D;W(`16QE;65N="XN+@!%;0!%+7!O
MN71A`$4M<&^Y=&YI(&YA<VQO=@!%+7!ON71N:2!N87-L;W9I('-E(&UO<F%J
M;R!U:F5M871I+@!%+7!ON71A(',@<&]T<F1I='9I:F\`4VUEN6MI`%!R87IN
M;R!S<&]R;^AI;&\N`%!R87IE;B!R97IU;'1A="X`4')A>FYA(&ES:V%L;F$@
M<&]L:F$`3VUO9V_H:2!V<W1A=FQJ86YJ92!S;&EK(&EZ($9O=&\@9V%L97)I
M:F4@=B!B97-E9&EL;S\`3VUO9V_H:2!D97-N:2!K;&EK('IA(&UE;G4`3&5T
M;R!K;VYC80!0;W9EZ&%J('5R96IE=F%L;FEK`%9N97-I=&4@=G!R8;EA;FIE
M+"!K:2!V86T@8F\@>F%S=&%V;&IE;F\L(.AE(&)O<W1E(+YE;&5L:2!P;VYA
M<W1A=FET:2!S=F]J92!G97-L;RP@;G!R+B`G2V%K;R!J92!I;64@=F&Y:2!D
M;VUAZ&D@OFEV86QI/R<Z`%1U:V%J('9P:;EI(%523"!S;&EK90!6<&ES('IA
M("5S('!O<V]D;V)L:F5N+@!%:W9A=&]R:6%L;F$@1W9I;F5J80!%<FET<F5J
M80!.87!A:V$`3F%P86MA('H@92UP;[ET;FEM('-P;W)OZ&EL;VTN`$5S=&]N
M:6IA`$5T:6]P:6IA`$5T;F\`179R;W!A`%9S86MI:"`Q-2!M:6YU=`!6<V%K
M:2`R(&UI;G5T:0!6<V%K:6@@,S`@<V5K=6YD`%9S86MI:"`U(&UI;G5T`$]B
M('9S86MI('!R:6IA=FD`5G-A:V4@<&]L('5R90!6<V%K;R!M:6YU=&\`4')I
M;65R:3H`27IV961I`%)A>KEI<FD`4F%ZN6ER:2!S=')A;G-K:2!M96YU`%!R
M:>AA:V]V86P@)RDG`%!R:>AA:V]V86YA(&IE(&)I;&$@8F5S961A(&%L:2!S
M=&%V96L@>F$@:7-K86YJ92!V(&YA<F5K;W9A:FEH`$1A='5M('9E;&IA=FYO
M<W1I`$5K<W!O;F5N=`!)>G9O>FD`27IV;WII($%D<F5S87(`27IV;WII('-A
M;6\@:7IB<F%N92!S=&EK92X`27IV;WII(&EZ8G)A;B!A9')E<V%R('8@8V5L
M;W1I+@!"87)V82!O<W!R961J80!&5%`@<')E;F]S(&YA;65S=&ET=F4`4')E
M;F]S(&YA<W1A=FET978@;FD@=7-P96PN`$1O<W1O<"!D;R!A9')E<V%R:F$@
M;FD@=7-P96PZ("5S`$1O9&%J86YJ92`E<R!V("5S(&YI('5S<&5L;SH@)7,`
M0G)S:V%N:F4@<&\@<V5Z;F%M=2!N:2!U<W!E;&\`0G)S:V%N:F4@<&\@;6%P
M:2!N:2!U<W!E;&\`4&]V97IA=F$@;F$@3$1!4"!S=')EOFYI:R!N:2!U<W!E
M;&$N`%!O=F5Z879A(&YA(%--0B!S=')EOFYI:R!N:2!U<W!E;&$N`$MO<&ER
M86YJ92!I>B`B)7,B(&YI('5S<&5L;RX`2V]P:7)A;FIE('8@(B5S(B!N:2!U
M<W!E;&\N`%9Z<&]S=&%V;&IA;FIE(&YO=F4@4T%33"!P;W9E>F%V92!N:2!U
M<W!E;&\N`$ES:V%N:F4@;V)J96MT;W8@>F$@9&]D86IA;FIE(&YI('5S<&5L
M;SH@)7,`4')E;6EK86YJ92!V("(E<R(@;FD@=7-P96QO+@!)<VMA;FIE('!O
M(&UA<&D@;FD@=7-P96QO.B`E<P!,97!O`$9A;&ML86YD<VMI(&]T;VMI`$9A
M<F]E(&]T;VMI`$9A:W,`1F5B<G5A<@#(=71I=&D@:F4`R'5T:71I(&IE.B``
M3F5K86H@<&QO:`!&:62^:0"I=&5V:6QO(&1A=&]T96LZ("5S(&1A=&]T96MA
M`*ET979I;&\@9&%T;W1E:SH@)7,@9&%T;W1E:P!5<')A=FET96QJ(&1A=&]T
M96L`26UE(&1A=&]T96ME`$EZ8FER82!D871O=&5K90!0<F5N;W,@9&%T;W1E
M:V4@;F$@<W1R9;YN:6L`4')E;F]S:2!D871O=&5K(&YA('-T<F6^;FEK(&YI
M<V\@<&]D<')T:2X`1FEL=')I`$FYZ&D`1FEN<VMA`%!R=F$@<&]L;W9I8V$`
M26UE`%!R=F$@Z&5T<G1I;F$`1FEK<VYO(')A>FUE<FIE`%!R97IR8V%L:0!,
M96)D9>@`365G;&$`36%P82`E<R!N92!O8G-T86IA`$)A<G9A(&)E<V5D:6QA
M`$AR86YA`%IA(&)R<VMA;&YI:V4L(&MI(&YE('!O9'!I<F%J;R!S;&EK`$YA
M<&]V960@*%1!1BD`1&YE=FD@;F%P;W9E9&D@*&YA<&]V960@8F\@=G)N:F5N
M82!Z82!O8F]J92!D86X@:6X@;F_H.R!V:7-O:V$@N71E=FEL:V$@;&%H:V\@
M<&]V>G)OZ&D@N6ER;VL@8FQO:RD`4W1E('!O>F%B:6QI(&=E<VQO/P!/8G)A
M>F-I`$9O<G1U;FD`5G)S=&$@1F]R='5N;W8`1F]R='5N:0!&;W)T=6YI(#(`
M3V)R87IC:0!0;W-R961O=F%N:F$`4&4`3VMV:7)J:0!&<F%N8VEJ80!&<F%N
M8VEJ82P@365S=&\`1G)E96)U<WD@55),`$9R86YC;W-K82!'=6EA;F$`1G)A
M;F-O<VMA(%!O;&EN97II:F$`2G6^;F$@1G)A;F-O<VMA(&]Z96UL:F$`3V0`
M3V0@`%!O;&YI(&]P:7,`4&]L;F$@;'5N80!0;VQN;R!I;64`1V%B;VT`5GIE
M;6D@<VQI:V\@:7H@9V%L97)I:F4`1V%L97)I:F$Z`$=A;6)I:F$`1V5N97)I
M<F%J("5S(&MO;F9I9W5R86-I:F\`1V5N97)I<F%N82!I>G9O<FYA(&MO9&$`
M1V5O<F=I80!.96WH:6IA`$=A;F$`1VEB<F%L=&%R`$QA<W1N;R!I;64`1VQO
M8F%L;FD@061R97-A<@!0;VID:0!';V5D96P`1V]O9VQE(&ES:V%N:F4`4VEV
M:6YS:V$@;&5S='9I8V$`1W+H:6IA`$=RN6MO("A)4T\M.#@U.2TW*0!'<F5E
M;FQA;F1I:F$`1W)E;F%D80!3:W5P:6YA`$%D;6EN:7-T<F%C:6IA('-K=7!I
M;@!);65N82!S:W5P:6X@;F4@<VUE:F\@8FET:2!P<F%Z;F$`4VMU<&EN90!'
M=6%D96QO=7!E`$=U86T`1W9A=&5M86QA`$=U97)N<V5Y`%!R879I8V4@1V]S
M=&$`2VYJ:6=A(&=O<W1O=@!'=FEN96IA`$=V:6YE:F$@0FES<V%U`$=V86IA
M;F$`2%1-3`!(5$U,07)E82!S=')A:&]P971N;R!N;^AE('!O8G)I<V%T:2!Z
M861N:F4@8V5L:6-E('8@=G)S=&EC:2X`2%1-3$%R96$@<W1R86AO<&5T;F\@
M;F_H92!P;V)R:7-A=&D@>F%D;FIE9V$@<W1O;'!C82!V('1A8F5L:2X`2%1-
M3$%R96$@<W1R86AO<&5T;F\@;F_H92!P;V)R:7-A=&D@>F%D;FIE('9R<W1I
M8V4@=B!T86)E;&DN`$A45%`@;W9E<FIA;FIE(&YI(&)I;&\@;F%J9&5N;RX`
M2&%I=&D`2&%S:"U!;&=O<FET96T`4V]P87)A`$=L879A`$AE87)D(&]T;VMI
M(&EN($UC1&]N86QD(&]T;VMI`$AE8G)E=G-K;R`H25-/+3@X-3DM."U)*0!6
M:;EI;F$`4&]M;^@`4&]M;^@@<')I('5P;W)A8FD@=7)E:F5V86QN:6MA`%!O
M;6_H;FEK`%!O;&]B;&$`4VQE9&D@>F'H971E:R!D871O=&5K93H`5FES;VMO
M`$1O7VUO=@!3=F5T:2!S961EOB`H5F%T:6MA;G-K82!M97-T;F$@9'*^879A
M*0!$;VUO=@!$;VUAZ&D@;F%S;&]V`$1O;6%L92!M97-T;P!$;VUAZ&$@9'*^
M879A`$1O;6'H('1E;&5F;VX`1&]M8>AA('!ON71N82"Y=&5V:6QK80!$;VUA
MZ&$@9'*^879A+V]K<F%J`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@3F%P8>AN:2`E<R!834P@<&]D871K:2!N86ID96YI('8@<W!O
M<F_H:6QU("5S`$AO<F1E+TMO;&%B.B!.;V)E;F\@<W!O<F_H:6QO(&YE('5S
M=')E>F$@;V)J96MT=2`E<R``2&]R9&4O2V]L86(Z($]B:F5K="!T:7!A("5S
M(&YI(&)I;"!N86ID96X@=B!S<&]R;^AI;'4@)7,`2&]R9&4O2V]L86(Z(%5S
M<&6Y;F\@;V1S=')A;FEL("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F%C
M:6IA('!O=')E8G5J92!02%`@9&]D871E:R`G9&]M>&UL)P!(;W)D92]+;VQA
M8CH@3FD@;6]G;^AE(&EZ9&5L871I(&YO=F5G82!834P@9')E=F5S82!Z82!O
M8FIE:W0@)7,`2&]R9&4O2V]L86(Z($YI(&UO9V_H92!O9'-T<F%N:71I("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.:2!M;V=OZ&4@<')I9&]B:71I($U)
M344@240@>F$@9&5L('1I<&$@)7,`2&]R9&4O2V]L86(Z($YI(&UO9V_H92!S
M:6YH<F]N:7II<F%T:2`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@3FD@;6]G
M;^AE('-I;FAR;VYI>FER871I('-K=7!N92!R86)E.B`E<P!(;W)D92]+;VQA
M8CH@3F5P;WIN86YA('-K=7!N82!R86)A("(E<R(`5F]D;W)A=FYA(.AR=&$`
M5F]D;W)A=FYI(&]D;6EK`%9O9&]R879N;SH`2V%K;R!S=&4@<')IN6QI(&1O
M('-E;3\@*%!R;W-I;2!O8G9E<W1I=&4A*0!+;VQI:V\@<W1O;'!C978@OF5L
M:71E('-P;VII=&D_`$MO;&EK;R!P;VQJ("AS=&]L<&-E=BD@;V)S=&%J83\`
M2V]L:6MO('9R<W1I8R"^96QI=&4@<W!O:FET:3\`5FQAOFYO<W0`5FQAOFYO
M<W0Z`$AU;6]R:7-T:0!-862^87)S:V$`57-T=F%R:F%N:F4@24U!4"!N86)I
M<F%L;FEK82!N:2!U<W!E;&\Z("5S`$)R:7-A;FIE($E-05`@;F%B:7)A;&YI
M:V$@;FD@=7-P96QO.B`E<P!)>F1E;&%V82!K=F]T92!)34%0(&YA8FER86QN
M:6MA(&YI('5S<&5L;SH@)7,`24U34`!)4"!N87-L;W8`25`@;F%S;&]V(&YI
M(&YA('9O;&IO+@!)4"!N87-L;W8@;FD@9&]V;VQJ96X@=B!#2412(&)L;VMU
M+@!+<KEI=&5V('IA:VQE;FET=F4@25`@;F%S;&]V82X`5E]S=&%V:2!V<G-T
M:6-E('!R960`27-L86YD:6IA`%-A;6\@:6MO;F4`26MO;F4@>F$@)7,`26MO
M;F4@<R!T96MS=&]M`$EM92!I9&5N=&ET971E.@#(92!P<FEK87H@;FD@<')A
M=FEL96XL("5S('IA(&]D<')T:F4@=B!N;W9E;2!O:VYU+@#(92!P<FD@=7!O
M<F%B:2!);G1E<FYE="!%>'!L;W)E<FIA(&YE('9I9&ET92!I:V]N+"!O9&ML
M:G5K86IT92!T;R!M;[YN;W-T('IA(&]N96UO9V_H96YJ92!P<F]Z;W)N;W-T
M:2!S;&EK(%!.1RX`R&4@=FED:71E('1O('-P;W)OZ&EL;RP@<VQI:V4@<&$@
M;F4L('-L:6MA(&MI(&IO(+YE;&ET92!P<F5N97-T:2!N92!M;W)E(&)I=&D@
M<')I:V%Z86YA('8@=F&Y96T@8G)S:V%L;FEK=2X`4')E9&]G;&5D('-L:6ME
M.@!54DP@<VQI:V4`55),('-L:6ME.@!3;&EK82!I>B!G86QE<FEJ90!3;&EK
M82!I>B!G86QE<FEJ93H`4')E;F]S('-L:6ME(&YA('-T<F6^;FEK`%-L:6ME
M`%5V;WII($%D<F5D87(L(&MO<F%K("5D`%5V;WHL(&MO<F%K("5D`%5V;WHO
M27IV;WH@061R97-A<FIE=@!5=F^^96YO('!O;&IE.B`E<P!5=F^^96YA('!O
M;&IA.@!67W-T879I('9R<W1I8V4@>F%D86H`4&]D86YA(&YE<')A=FEL;F$@
M:V]D82!D96IA;FIA+@!.97!R879I;&YO('5P;W)A8FYIN6MO(&EM92!I;B]A
M;&D@9V5S;&\N`$YE<')A=FEL;F\@=7!O<F%B;FFY:V\@:6UE(&%L:2!N87-L
M;W8N(%!O<VMU<VET92!P;VYO=FYO(&%L:2!K;VYT86MT:7)A:G1E('-V;VIE
M9V$@<VMR8FYI:V$L(.AE('!O=')E8G5J971E(&YA9&%L:FYO('!O;6_H+@!0
M;W9EZ&%J('IA;6EK`$EN9&EJ80!0;W-A;65Z;FD@=7!O<F%B;FEK:0!);F1O
M;F5Z:6IA`$EN9F\`26YF;W)M86-I:F4`5G-T879I('-T7V]L<&5C('IA9&%J
M`%9S=&%V:2!S;&EK;P!6<W1A=FD@=&%B96QO`%9S=&%V:2!S<&QE=&YO('!O
M=F5Z879O`%9S=&%V:2!S=&]?;'!E8R!S<')E9&%J`%9S=&%V:2!N;W8@<W1O
M;'!E8R!Z82!T<F5N=71N:6T`5G-T879I(&YO=B!S=&]L<&5C('!R960@=')E
M;G5T;FEM`%9S879I(&YO=F\@=G)S=&EC;R!Z82!T<F5N=71N;P!6<W1A=FD@
M;F]V;R!V<G-T:6-O('!R960@=')E;G5T;F\`5G-T879I(&]D<W1A=F5K('IA
M('1R96YU=&YI;2!V;WIL:;GH96T`5G-T879I(&]D<W1A=F5K('!R960@=')E
M;G5T;FEM('9O>FQIN>AE;0!6<W1A=FD@86QT97)N871I=FYO('!R961L;V=O
M`%9P:;EI=&4@92UP;[ET;FD@;F%S;&]V(&MA;6]R(+YE;&ET92!P<F5J971I
M(&YO=F\@9V5S;&\Z`%9S=&%V:2!C96QI8V\@>F%D86H`5G-T879I(&-E;&EC
M;R!S<')E9&%J`%9S=&%V:2!S=&]L<&5C('IA9&%J`%9S=&%V:2!S=&]L<&5C
M('-P<F5D86H`5G-T879I('-P;W)OZ&EL80!6<W1A=FD@;V1S=&%V96L@<W!R
M961A:@!6<W1A=FD@;V1S=&%V96L@>F%D86H`5G-T879I('9R<W1I8V\@>F%D
M86H`5G-T879I('9R<W1I8V\@<W!R961A:@!6<&FY:71E(&]D9V]V;W(@;F$@
M>F%H=&5V86YO('9A<FYO<W1N;R!V<')AN6%N:F4Z`%9S=&%V:2]5<F5D:2!S
M;&EK;P!6<W1A=FDO57)E9&D@<&]V97IA=F\`3F5Z861O<W1E;B!K<F5D:70@
M>F$@<&^Y:6QJ86YJ92!N82!S97IN86UA(')A>G!ON6EL:F%N:F$N`$YE>F%D
M;W-T96X@:W)E9&ET+@"I=&5V:6QO`%-E>FYA;2"Y=&5V:6P`3F5V96QJ879N
M82!)1`!.87!AZ&5N(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!.979E;&IA
M=F5N(&%D<F5S87(`3F%P8>AN82!A<&QI:V%C:6IA+@!.87!AZ&5N($E$('!A
M:V5T82X`3V1D86YI(&YA<&'H;FD@<&]D871K:2X`3F%P8>AN96X@;F%S;&]V
M(&1E<W1I;F%C:6IE+@!.979E;&IA=FYA(&4M<&^Y=&$`3F5V96QJ879E;B!V
M<&ES`$YA<&'H;F$@;V)L:6MA(&1A=&]T96ME`%!O9&%N(&YE=F5L:F%V96X@
M:VQJ=>@N`$YA<&'H96X@;7-G7W1Y<&4N`$YE=F5L:F%V;F\@:6UE`$YE=F5L
M:F%V96X@;V)J96-T260`3F%P8>AE;B!A;&D@;6%N:V%J;^@@87!I7VED+@!.
M87!AZ&YI(&%L:2!M86YK86IOZ&D@<&%R86UE=')I+@!.87!AZ&YA(&1O=F]L
M:F5N:F$@;F%D<F5J96YE9V$@;V)J96MT82X`3F%P8>AE;B!P<F]T;VMO;"X`
M3F5V96QJ879E;B!O8FIE:W0@=B!S:W5P;FD@<F%B:0!.979E;&IA=F5N(&EZ
M=F]R;FD@;F%S;&]V+@!.87!AZ&YI('5N:6-O9&4@<&]D871K:2X`26YV96YT
M=7)A`$ER86X`27)A:P!)<G-K80!-86YO=B!O=&]K`$EZ;VQI<F%N92!N979I
M:'1E`$EZ<F%E;`!)>F1A:F%T96QJ`%!ON65V;F\`271A;&EJ80!*86UA:FMA
M`$IA;G5A<@!*87!O;G-K80!*87!O;G-K;R`H25-/+3(P,C(M2E`I`$IE<G-E
M>0!*;W)D86X`2G5L:6H`2G5N:6H`4&]R879N879A`%-R961I;G-K82!P;W)A
M=FYA=F$`3V)O:F5S=')A;G-K82!P;W)A=FYA=F$`3&5V82!P;W)A=FYA=F$`
M1&5S;F$@<&]R879N879A`$MA>F%H<W1A;@!/8F1ROFEM(&]R:6=I;F%L/P!+
M96YI:F$`2V5R8F5R;W,@<W1R9;YN:6L@:F4@>F%V<FYI;"!O=F5R:71E=BX`
M3F]V:6YC:2!K97)N96QA`$EZ9&5L879A(&ML:G7H80!0<G-T;FD@;V1T:7,@
M:VQJ=>AA`$1O;+YI;F$@:VQJ=>AA`%9R<W1A(&ML:G7H80!5<&]R86)A(&ML
M:G7H80!+;&IUZ""^92!O8G-T86IA(&YA(&IA=FYE;2!S=')EOFYI:W4@<R!K
M;&IUZ&DN`$]T<F]C:0!+:7)I8F%T:0!+;W)E:F$L($QJ=61S:V$@9&5M;VMR
M871IZ&YA(')E<'5B;&EK80!+;W)E:F$L(')E<'5B;&EK80!+;W)E:G-K;R`H
M155#+4M2*0!+=79A:G0`2VER9VEZ:7-T86X`4&]T<F5B;F$@:F4@<&]D<&]R
M82!,1$%0+"!V96YD87(@3$1!4"!M;V1U;"!N:2!N82!V;VQJ;R!A;&D@;FD@
M;F%L;[YE;BX`4&]S=%]A=FET978`2F5Z:6L`3&%O<P!:861N:F$@<&]L;W9I
M8V$`6F%D;FIA('-P<F5M96UB80!0<FEI;65K`%IA9&YJ82#H971R=&EN80!:
M861N:FGH('!O<V]D;V)L:F5N;SH`6F%D;FIA('!R:6IA=F$Z("5S`%IA9&YJ
M82!P<FEJ879A.B`E<R!Z("5S`%IA9&YJ82!P<FEJ879A.B!.:6MO;&D`3&%T
M=FEJ80!:86MO;@!0;W-T879I=&5V`%!U<W1I=&4@<')A>FYO('IA(&)R97H@
M<F]B=0!,:6)A;F]N`$QE=F\`3&5V82!G;&%V80!,979E('9R961N;W-T:0!,
M97-O=&\`3&EB97)I:F$`3&EB:6IA`$QI:'1E;KET86IN`%)A:&QO(')O<V5N
M:F4`4F%H96P@9&6^`%)A:&5L(&1EOB!Z9V]D86H`4F%H96P@9&6^('!O>FYO
M`%)A:&QA(&1EOF5V;F$@<&QO:&$`4F%H96P@9&6^(',@<W1R96QA;6D`4F%H
M;&\@<VYEOF5N:F4`4F%H;&$@<VYEOFYA('!L;VAA`$QI;65R:6-K`%!O=F5Z
M879A`%!O=F5Z879A(&MAOF4@;F$Z`%!O=F6^:2!E+7!ON71N:2!N87-L;W8@
M;F$@<W1R86X@>F$@<V5S=&%V;&IA;FIE('-P;W)OZ&EL`%!O=F5Z879E`$QI
M;G5X('!IN6MO=&5K`%-E>FYA;0!397IN86T@+2!U<&]R86)N:6L@;&%H:V\@
M=FED:2!M87!O`%!R:6MAOFD@8F%Z92!P;V1A=&MO=@!0<FEK8;YI('1E;64@
M<&]M;^AI`%!R:6MAOFD@=&%B96QE`%-E>FYA;2U!<FAI=@!397IN86TM4&]M
M;^@`4V5Z;F%M+4ED`%-E>FYA;2U,87-T;FEK`%-E>FYA;2U-97-T;P!397IN
M86TM3F%R;^AI`%-E>FYA;2U/9'!O=F5J`%!R:6MA>F]V86YJ92!U<&]R86)N
M:6MO=B!J92!O;F5M;V=OZ&5N;RX`3&ET97)A='5R80!,:71V80!.86QA9V%M
M+BXN`$QO:V%L96X@Z&%S.B``2F5Z:6L@:6X@Z&%S`$QO:V%C:6IA`%!R:6IA
M=F$`3V1J879A`$]P<F%V:6QA(&]B('!R:6IA=FD`4')I:F%V82!N:2!U<W!E
M;&$@>F%R861I(&YA<&'H;F\@=G!I<V%N96=A('5P;W)A8FYIN6ME9V$@:6UE
M;F$@86QI(&=E<VQA+@!0<FEJ879A(&YI('5S<&5L82X`1&]L9V\@8F5S961I
M;&\`3&IU8F5Z96X`3FEZ:V\`36%L92!G<KEK92#H<FME`$UA;&4@;&%T:6YS
M:V4@Z')K90!-86QE(')I;7-K92"Y=&5V:6QK90!,=6MS96UB=7)G`$U-`$U/
M5$0`35,M5$Y%1B!P<FEP;VYK82!N:2!V<V5B;W9A;&$@<&]D871K;W8N`$U3
M1P!-86MA;P!-86ME9&]N:6IA`$UA9&%G87-K87(`36%G:6IA`%!ON71A`%5P
M<F%V:71E;&H@<&^Y=&4`57-T=F%R:2!P;W9E7WIA=F\`36%L879I`$UA;&5Z
M:6IA`$UA;&1I=FD`36%L:0!-86QT80!5<F5D:71E('-E>FYA;2!K871E9V]R
M:6HL(',@:V%T97)I;6D@OF5L:71E(&]Z;F'H:71I(&]B:F5K=&4@:6X@8F%R
M=F4@<&]V97IA;F4@<R!T96UI(&MA=&5G;W)I:F%M:2X`6F5M;&IE=FED($UA
M<#(T`%IE;6QJ979I9"!-87!1=65S=`!-87)E8P!/9&UI:P!/>FYAZ&D@>B!O
M>FYA:V\@5FED96YO+TYE('9I9&5N;P!/>FYAZ&D@>B!D<G5G:6UI(&]Z;F%K
M86UI("AN<'(N(%!O;65M8FYO+T]D9V]V;W)J96YO*0!-87)S:&%L;&]V:2!O
M=&]K:0!-87)T:6YI<75E`%5J96UA;FIE`%5J96UA:F_H82!P;VQJ80!-879R
M971A;FEJ80!-875R:71I=7,`36%K<VEM86QN:2!D;W9O;&IE;B!K<F5D:70N
M`$UA:W-I;6%L;F\@N71E=FEL;R!D96QO=B!S<&]R;^AI;&$@<')E:V]R8>AE
M;F\N`$YA:G9IN6IA('1E;7!E<F%T=7)A('IA9&YJ:6@@,C0@=7(Z(`!.86IV
M:;EJ82!T96UP97)A='5R82!Z861N:FEH(#8@=7(Z(`!-86MS:6UA;&YA(&1O
M;+YI;F$`3F%J=F7H:F4@N71E=FEL;R!S=')A;FD`36%J`$UA>6]T=&4`6F1R
M879S='9O`,AL86YI`%9R<W1A(&UE;G5J83H`4W!O:FD@8V5L:6-E`%-P;W)O
MZ&EL;P!3<&]R;^AI;&\@:F4@8FEL;R!U<W!EN6YO('!R979E<FIE;F\L('!O
M9'!I<VYI:V]V96=A('!O=')D:6QA('!A(&YI(&)I;&\@;6]G;^AE(&]V97)I
M=&DN`%-P;W)OZ&EL;R!J92!P<F5T96ML;RX`5G)S=&$@<W!O<F_H:6QA`$UE
M=&%R(%9R96UE`$UE=&%R(&)L;VL@;FD@;F$@=F]L:F\N`$UE=&%R(&)L;VL@
M;FD@;F$@=F]L:F\N(%!O9')O8FYO<W1I('-O(&)I;&4@;&]G:7)A;F4@>F$@
M861M:6YI<W1R871O<FIA+@!-971O9&$`365T<FGH;F$@<VMA;&$`365K<VEK
M80!-:6MR;VYE>FEJ80!3<F5D:6YA`%1I<"!-:6UE`$YA:FYIOFIA('1E;7!E
M<F%T=7)A('IA9&YJ:6@@,C0@=7(Z(`!.86IN:;YJ82!T96UP97)A='5R82!Z
M861N:FEH(#8@=7(Z(`!-:6YI(&ES:V%N:F4`6G)C86QI`%)A>FYO`%8@:V]N
M9FEG=7)A8VEJ:2!,1$%0(&EZ=F]R82!M86YJ:V$@1$XN`$UA;FIK82!014%2
M('!A:V5T($A45%!?4F5Q=65S="X`2V]N9FEG=7)A8VEJ82!M86YJ:V$N(,AE
M(+YE;&ET92!U<&]R86)L:F%T:2!T;R!A<&QI:V%C:6IO+"!J;R!M;W)A=&4@
M>F1A:B!G96YE<FER871I+@!-86YJ:V$@240@<W!O<F_H:6QA+@!-86YJ:V$@
M>F%H=&5V86X@4$5!4B!P86ME="!-86EL+@!-86YJ:V$@240@<V5J92X`4&\`
M36]B:6QN82!P;[ET80!-;V)I;&YI('1E;&5F;VX`6FUE<FYO`$1A='5M('-P
M<F5M96UB90!3<')E;65N:2!54DP`4W!R96UI;FIA;FIE(&YI('5S<&5L;SH@
M*"5S*2`E<P!-;V1U;&D`36]L9&%V:6IA`$UO;F%K;P!-;VYG;VQI:F$`365S
M96,@:6X@;&5T;P!-97-EZ&YO`$UO;G-E<F%T`$QU;FEN92!M96YE`%9EZ"!K
M;W0@,2!V<&ES(&YA:F1E;@!-87)O:V\`4')E=&6^;F\@:F%S;F\`4')E=&6^
M;F\@;V)L8>AN;P!0<F5T9;YN;R!S;V[H;F\`4')E;6%K;FD`4')E;6%K;FD@
M9&]L`%!R96UA:VYI(&QE=F\`4')E;6%K;FD@9&5S;F\`4')E;6%K;FD@9V]R
M`%!R96UA:VYI(&1O;`!0<F5M86MN:2!L979O`%!R96UA:VYI(&1E<VYO`%!R
M96UA:VYI(&=O<@!-;WIA;6)I:P!-=6QB97)R>2!!9')E<V%R`%9EZ"UN:79O
M:G-K:2!S97IN86UI('H@:7IB:7)O`$]B<W1A:F$@=F7H(&]S96(@>B!N87-L
M;W9O;2!;)7-=+"!V96YD87(@;F]B96YA('H@:6UE;F]M(%LE<UT`5F7H:W)A
M=&YA(&EZ8FER80!-;VH@<F'H=6X`36]J('!O<G1A;`!/8FQI:V$@;6]J96=A
M('!O<G1A;&$`36%J;FUA<@!.12P@;F4@<W1R:6YJ86T@<V4`26UE`$]B;&EK
M82!I;65N80!.86UB:6IA`$YA=7)U`$YE<&%L`$EM96YI:R#H;&%N;W8@<W1O
M<FET=F4@3F5T8V5N=&5R`$YI>F]Z96US:V$`3FEZ;WIE;7-K:2!!;G1I;&D`
M3W-N;W9N:2!.971S8V%P92!54DP`55),('IA('!R96ML:6,@<&]T<F1I;&$@
M3F5T<V-A<&4@0T$`55),('!O;&ET:6ME($YE='-C87!E($-!`%523"!Z82!O
M8FYO=F\@<&]T<F1I;&$@3F5T<V-A<&4`55),('IA('!R96ML:6,@<&]T<F1I
M;&$@3F5T<V-A<&4`26UE('-T<F6^;FEK82!.971S8V%P92!34TP`2V]M96YT
M87(@<&]T<F1I;&$@3F5T<V-A<&4`5G)S=&$@<&]T<F1I;&$@3F5T<V-A<&4`
M3VUR9;YJ90!.:6MO;&D`3F]V82!+86QE9&]N:6IA`$YO=F$@:V%T96=O<FEJ
M80!.;W8@4W1I:P!-;&%J`$YO=F\@=7!O<F%B;FFY:V\@:6UE("AO<&-I:G-K
M;RD`3F]V82!:96QA;F1I:F$`3F]V;R!O:VYO("A?8FQA;FLI`$YO=FEC90!.
M;W9IZ&MA<G-K92!S:W5P:6YE`$YA<')E:@!.87-L961N:F4@;6^^;F]S=&D`
M3FEK87)A9W9A`$YA9&EM96L`3FEG97(`3FEG97)I:F$`3F_H`$YI=64`3F4`
M3F]B96X@=G!I<R`E<R!N:2!B:6P@;F%J9&5N('IA("5S`$YO8F5N(&%D<F5S
M87(@;FD@8FEL(&YA:F1E;BX`4&]D871K:2!K;VYF:6=U<F%C:6IE(&YI<V\@
M;F$@=F]L:F\L(')A>FQI:R!N:2!M;V=OZ&4@<&]K87IA=&DN`$YA('9O;&IO
M(&YI(&YO8F5N96=A(&YAZ&EN82!Z82!I>F1E;&%V;R!)4T\@<&]S;F5T:V]V
M+@!0<F5D;&]G82!P86ME=&$@;F4@;V)S=&%J82X`3F$@OF5L:F5N96T@<&]L
M;[YA:G4@8FQO:R!N92!O8G-T86IA`%IA($U#04P@879T96YT:6MA8VEJ;R!N
M:2!B:6QO('!O9&%T;F\@:6UE(&MO;&5D87)J82X`0G)E>B!S<')E;65M8F4N
M`%!O9')E:F5N92!P<F%V:6-E('-E('1E:B!P<F%V:6-I(&QA:&MO(&1O9&%J
M;RX`26YF;W)M86-I:F4@;R!K;VYF:6=U<F%C:6II('IA("5S(&YI<V\@8FEL
M92!P;V1A;F4N`$EN9F]R;6%C:6IE(&\@:V]N9FEG=7)A8VEJ:2!Z82!&5%`@
M5D93(&YI<V\@8FEL92!P;V1A;F4N`$EN9F]R;6%C:6IE(&\@:V]N9FEG=7)A
M8VEJ:2!Z82!344P@5D93(&YI<V\@8FEL92!P;V1A;F4N`$EN9F]R;6%C:6IE
M(&\@:V]N9FEG=7)A8VEJ:2!Z82!344PM1FEL92!61E,@;FES;R!B:6QE('!O
M9&%N92X`3F]B96X@<W1I:R!N:2!B:6P@;F%J9&5N`$MR961I=&$@;FD@=F7H
M+@!$97-T:6YA8VEJ82!N:2!B:6QA('!O9&%N82X`1&%T;W1E:V$@;FD@<')E
M;F6Y96YA;F$@<W1R9;YN:6L`26MO;B!N:2!M;V=OZ&4@;F%J=&DN`$QO:V%C
M:6IA(&YI(&YA<W1A=FQJ96YA+@!3<&]R;^AI;&\@;FD@8FEL;R!P;V1A;F\N
M`$EM92!N:2!B:6QO('!O9&%N;RX`J71E=FEL:V$@;FD@8FEL82!P;V1A;F$N
M`$YE('!R:6MA>G5J(+YA;&II=FEH(&9O<G1U;F4M;W8`1V5S;&\@>F$@2%14
M4"!A=G1E;G1I:V%C:6IO(&YI(&)I;&\@<&]D86YO+@!'97-L;R!Z82!)34%0
M(&%V=&5N=&EK86-I:F\@;FD@8FEL;R!P;V1A;F\N`$=E<VQO('IA($ME<F)E
M<F]S(&%V=&5N=&EK86-I:F\@;FD@8FEL;R!P;V1A;F\N`$=E<VQO('IA($QO
M9VEN(&%V=&5N=&EK86-I:F\@;FD@8FEL;R!P;V1A;F\N`$=E<VQO('IA(%!!
M4U-71"!A=G1E;G1I:V%C:6IO(&YI(&)I;&\@<&]D86YO+@!'97-L;R!Z82!3
M34(@879T96YT:6MA8VEJ;R!N:2!B:6QO('!O9&%N;RX`4&]T(&1O($]P96Y3
M4TP@:7IV<KEI;&YE(&1A=&]T96ME(&YI(&)I;&$@<&]D86YA+B!,92UT82!J
M92!P;W1R96)N82!Z82!D96QO(',@<&]D871K:2!02T-3(#$R+@!.;V)E;B!V
M<&ES(&YE(.AA:V$N`$)R97H@Z')T`$)R97H@<W1R86YI8P!.82!V;VQJ;R!N
M:2!Z8>AA<VYE(&UA<&4@>F$@8V%C:&4N`%5P;W)A8FYIN6MO(&EM92!I;B]A
M;&D@9V5S;&\@;FD@8FEL;R!P;W-L86YO+@!0;V1A=&MI('9#87)D(&YI<V\@
M8FEL:2!N86ID96YI+@!.:7-O(&)I;&D@=G)N:F5N:2!V96QJ879N:2!834P@
M<&]D871K:0!"<F5Z('9R961N;W-T:0!6(&]R:6=I;F%L;FD@:V]N9FEG=7)A
M8VEJ:2!V97)Z:6IA(&YI(&YA:F1E;F$N(%IN;W9A(&IO(&=E;F5R:7)A:G1E
M+@!6('9AN6D@:V]N9FEG=7)A8VEJ:2!V97)Z:6IA(&YI(&YA:F1E;F$N(%IN
M;W9A(&IO(&=E;F5R:7)A:G1E+@!.;V)E;@!"<F5Z("AU<&]R86)I(&EM<&QI
M8VET;F\I`$YO<F1I:G-K;R`H25-/+3@X-3DM,3`I`$YO<F9O;+EK:2!O=&]K
M`%-E=F5R;F$@<&]L;V)L80!3979E<FYI($UA<FEA;F$@;W1O:VD`3F]R=F6Y
M:V$`3F4@<&\`3F4@<')E9`!.:2!M87!A`$YI(&EM<&QE;65N=&ER86YO+@!.
M:2!N87-T879L:F5N`$YI('!O9'!R=&\N`$)E;&6^:V4`3FGH97-A<B!Z82!P
M<F5B<G-K871I+"!V<FYI('-E+@!.;W9E;6)E<@"I=&5V:6QO`*ET979I;&\@
M>FYA:V]V`*ET979I;&\@<W1O;'!C978`J71E=FEL;R!O8FIE:W1O=B!N82!S
M=')A;@"I=&5V:6QO('9R<W1I8P"I=&5V:6QK92!Z82!P;W-O9&]B:71E=B!S
M97IN86UA(')A>F1E;&ET=F4@;FES;R!P;V1A;F4N`%8@<F5D=0!/8FIE:W0`
M5'9O<F5C(&]B:F5K=&$`3V)J96MT(&YI(&)I;"!N86ID96X`3VMT86QN;P!/
M:W1O8F5R`$9I;'1E<B"^86QJ:79K`%!I<V%R;F$`3VUA;@!386UO($E-05`@
M<W1R9;YN:6MI('!O9'!I<F%J;R!M87!E('8@<VMU<&YI(')A8FDN`%-A;6\@
MOF%L:FEV:2!F;W)T=6YE+6D`1&]V;VQJ96X@:F4@<V%M;R!E;B!E+7!ON71N
M:2!N87-L;W8N`%-A;6\@;&%S=&YI:R!A;&D@<VMR8FYI:R!S:7-T96UA(&QA
M:&MO('-P<F5M96YI(&QA<W1N:;ET=F\@86QI(&QA<W1N:6MA('!R879I8R!S
M:W5P;F4@<F%B90!/9'!R:2!V(&YO=F5M(&]K;G4`3W!E;E-33"!N87!A:V$Z
M(%!O9&%T:V]V(&EZ(%,O34E-12!P;V1P:7-A;F5G82!D96QA(&YI(&UO9V_H
M92!I>G9L9>AI+@!/9'!R92!T;R!P;W9E>F%V;R!V(&YO=F5M(&]K;G4`3W!E
M<F%C:6IS:VD@<VES=&5M`$UOOFYO<W1I`$UOOFYO<W1I('IA("5S`%5R96IE
M;B!S97IN86T`3W)G86YI>F%C:6IA`$5N;W1A(&]R9V%N:7IA8VEJ90!/<F=A
M;FEZ86-I:F$`3W)I9VEN86QN82!P<F5D;&]G82!A<&QI:V%C:6IE`$]R:6=I
M;F%L;F4@<')E9&QO9V4@=B`E<SH`1')U9V\`1')U9V4@:6YF;W)M86-I:F4`
M3W-T86QE(&UOOFYO<W1I`%!R879I8V4@;&%S=&YI:V$`4$%-(&%V=&5N=&EK
M86-I:F$@;FD@;F$@=F]L:F\N`%!'4"!D:6=I=&%L;FD@<&]D<&ES`%!'4""Y
M:69R:7)A;FD@<&]D871K:0!*879N:2!01U`@:VQJ=>@`4$=0('!O9'!I<V%N
M:2^Y:7)F:7)A;FD@<&]D871K:0!02%`@:V]D80!02%`@=6MA>FYA(&QU<&EN
M80!0;W!O;&1A;B!R86AE;"!D9;X`4&]P;VQD86YS:V4@<&QO:&4`4&]P;VQD
M86YS:V4@;F5V:6AT90!07TA0('5K87IN82!L=7!I;F$`3V)R;V)A`%!A:VES
M=&%N`%!A;&%U`%!A;&5S=&EN<VMO(&]Z96UL:F4`4&%N86UA`%!A<'5A($YO
M=F$@1W9I;F5J80!087)A9W9A:@!$96QN;R!O8FQAZ&YO`$=E<VQO`$YE<')A
M=FEL;F\@9V5S;&\`1V5S;&\@<&]T<F5B;F\@>F$@4D%$2553(&%V=&5N=&EK
M86-I:F\N`$=E<VQO(',@<&]T<F1I;&]M`$=E<VQO.@!'97-L;SH@`$=E<VQI
M('-E(&UO<F%T82!U:F5M871I+@!0<FEL97!I`%!R:6QE<&D@>B!O9&QOOFFY
MZ&$`4&]T`,AA:V%J;^AI('9P:7-I.@!,:G5D:F4`3V1S=&]T96L`27IV961I
M(&]P97)A8VEJ92!V>F1ROF5V86YJ80!)>G9E9&D@;W!E<F%C:6IE('9Z9'*^
M979A;FIA(&]B('!R:6IA=FD_`%!R879I8V$`1&]S=&]P('IA=G)N:F5N`$1O
M<W1O<"!Z879R;FIE;@!!9&UI;FES=')A8VEJ82!P<F%V:6,`3W-E8FYE(&EN
M9F]R;6%C:6IE`%!E<G4`1&]M8>AE(+YI=F%L:0!&:6QI<&EN:0!496QE9F]N
M`$9O=&]G<F%F:6IE`%!I;F4@061R97-A<@!0:71C86ER;@!0:6MS;&D`4&QA
M=&ET=61E`%!R;W-I;2!K;&EK;FET92!V(&-E;&EC;P!0<F]S:6T@<&]T<F1I
M=&4@;V1S=')A;FET978@=&5G82!E;&5M96YT83H`4')O<VEM('!O=')D:71E
M(&]D<W1A;FET978@<&]V97IA=F4@96QE;65N=&$Z`%!R;W-I;2!V<&FY:71E
M(&UE<V5C(&EN(&QE=&\N`%!R;W-I;2!V<&FY:71E(&EM92!Z82!N;W9O(&MA
M=&5G;W)I:F\Z`%!R;W-I;2!V<&FY:71E('9E;&IA=F5N($E0(&YA<VQO=BX`
M4')O<VEM('9P:;EI=&4@=F5L:F%V96X@9&%T=6TL('!R979E<FET92"Y=&5V
M:6QO(&1N:2!V(&UE<V5C=2X`4')O<VEM('9P:;EI=&4@=F5L:F%V96X@Z&%S
M+@!0<F]S:6T@=G!IN6ET92!P;W9Z971E:R!P<F]B;&5M82X`4')O<VEM('9P
M:;EI=&4@=F&Y92!U<&]R86)N:;EK;R!I;64@:6X@9V5S;&\`4')O<VEM('9P
M:;EI=&4@:6UE(&YO=F4@:V%T96=O<FEJ93H`4&]L:G-K80!0;VQI=&EK80!!
M;FME=&4`4&]R='5G86QS:V$`4&]S=&%V:71E=B!S;&EK90!0;W-T879I=&5V
M('1A8F5L90!3:')A;FD@=B!T;R!M87!O("A)34%0('1E9V$@;F4@>F%H=&5V
M82D`2V]L:>AI;F$@<&%D879I;B!V('IA9&YJ:6@@)7,@=7)A:#H@`%!R969S
M7VQD87`Z(%!O=')E8F5N($Q$05`@9&]D871E:R!N:2!N86ID96XN`%!R969S
M7W-E<W-I;VXZ(%!O=')E8F5N('-E<W-I;VX@9&]D871E:R!N:2!N86ID96XN
M`%!R:71I<VL`4')I=&ES:R!N82!M;W)S:VD@=FFY:6YI.B``4')I=&ES:SH@
M`%!R961O9VQE9`!0<F5D;V=L960@<VQI:V4@=B!N;W9E;2!O:VYU`%!R96JY
M;FIE(&UOOFYO<W1I`$YA=&ES;FD@9&]K=6UE;G0`6F%S96)N:2!!9')E<V%R
M`%IA<V5B;FD@:VQJ=>@`4')O8FQE;0!/<&ES('!R;V)L96UA`%!R;VIE:W1I
M`$)E<V5D:6QO('!O>FEV;FEK80!*879N:2!K;&IUZ`!!;&=O<FET96T@:F%V
M;F5G82!K;&IUZ&$`1V5N97)I<F%N:F4@<&%R82!*879N:2]:87-E8FYI(&ML
M:G7H(&YI('5S<&5L;RX`4&]R=&]R:6MO`%%A=&%R`%!O:7IV961B80!0;VEZ
M=F5D8F$@:F4@<W!O9&QE=&5L83H@*"5S*2`E<P!(:71R;R!)<VMA;FIE`%)3
M02!J879N:2!K;&IUZ"`H)2!B:71E;BD`27IB:7)A`$1EO@!$9;X@>F=O9&%J
M`$1EOB!P;WIN;P!$9;YE=FYA('!L;VAA`$YA:VQJ=>AE;B!F;W)T=6YE`%)A
M>FUE<FIE`%!R96)E<FD`0G)A;FIE('-P;V1L971E;&\Z("@E<RD@)7,`4')E
M8F5R:2!S<&]R;^AI;&$`4F5S('!O8G)IN65M("5S/R!/<&5R86-I:F4@;FD@
M;6]G;^AE(')A>G9E;&IA=FET:2X`4F5S(&]D<W1R86YI;2!U<&]R86)N:6MO
M=F4@<&]D871K92!Z82`E<S\@3W!E<F%C:6IE(&YI(&UO9V_H92!R87IV96QJ
M879I=&DN`%!R:6MA>F%N:2!Z87!I<VDZ`%!O;F]V;F\@:7IV961I('IA9&YJ
M92!D96IA;FIE`$]S=F6^:2!D:6YA;6GH;F4@96QE;65N=&4@;65N=6IA.@!/
M<W9EOFD@<&]G;&5D('!O<G1A;&$Z`%)E9V5X`$)R<VMA;&YI:R!O9&YO<V]V
M`%!R:7!O;6)E`$]D9&%L:F5N:2!S=')EOFYI:VD`3V1D86QJ96X@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`3V1S=')A;FD`3V1S=')A
M;FD@8FQO:P!/9'-T<F%N:2!S=&]L<&5C`$]D<W1R86YI(&]B;&EK;W9A;FIE
M`$]D<W1R86YI(',@=&5G82!S97IN86UA`$]D<W1R86YI('!A<@!/9'-T<F%N
M:2!S:')A;FIE;F\@<VMR:7!T;R!I>B!S=')EOFYI:V]V92!Z8>AA<VYE(&UA
M<&4N`$]D<W1R86YI`$]D<W1R86YI('1O('9O>FQIN>AE(&EZ(&1O:W5M96YT
M80!/9'-T<F%N:2!U<&]R86)N:6MA`$]D<W1R86YI('5P;W)A8FYI:V$Z("5S
M`$YA('IA:'1E=F\@;FD@8FEL;R!M;V=OZ&4@;V1G;W9O<FET:2X@3F%P86MA
M.B``6F%H=&5V86X@;V)J96MT(&YI(&)I;"!N86ID96XN`%!O;F%S=&%V:0!0
M;VYA<W1A=FD@9V5S;&\`4&]N87-T879I=&4@=F&Y92!G97-L;P!0;VYA<W1A
M=FD@;F$@4')I=GIE=&\`4F5Z=6QT871I`$YA>F%J(&YA($UOOFYO<W1I`%)E
M=6YI;VX`3V)N;W9I('!R96JY;FIE(&YA<W1A=FET=F4`36^^;F]S=&D@=7)E
M:F5V86QN:6MA(&]B;V=A=&5N96=A(&)E<V5D:6QA`%5G86YK90!$97-N;P!$
M97-N82!G;&%V80!$97-N92!V<F5D;F]S=&D`3&%S7W1N;W-T:2!V<G-T:6-E
M`%9L;V=A`%)O;75N:6IA`%IA<W7H:2!Z82`Q.#``6F%S=>AI(&QE=F\`6F%S
M=>AI(&1E<VYO`$QA<W1N;W-T:2!V<G-T:6-E`$QA<W1N;W-T:2!V<G-T:6-E
M`%9R<W1I8V4Z`,AR=&4`R')T92!B;V1O('!R:6MA>F%N92!M960@=G-E;6D@
M=G)S=&EC86UI(&EN('-T;VQP8VD`R')T92!B;V1O('!R:6MA>F%N92!S86UO
M(&UE9"!S=&]L<&-I`,AR=&4@8F]D;R!P<FEK87IA;F4@<V%M;R!M960@=G)S
M=&EC86UI`%!OOF5N:0!2=7-I:F$`4G5A;F1A`%,O34E-12!K<FEP=&]G<F%F
M<VMI('!O9'!I<P!3+TU)344@N6EF<FER86YO('-P;W)OZ&EL;P!*879N;R!3
M+TU)344@4&]T<F1I;&\`4T%33"!O=F5R:F%N:F4@;FD@;F$@=F]L:F\N`%--
M4R!S<&]R;^AA;FIE`%-13"!L=7!I;F$`4U-(`%534$5,3P!37U%,(&QU<&EN
M80!3;P!3=BX@2&5L96YA`%-A:6YT($MI='1S(&EN($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!I;B!-:7%U96QO;@!386EN="!6:6YC96YT(&EN
M($=R96YA9&EN90!)<W1I(&]K=FER("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN
M;P!386\@5&]M92!I;B!0<FEN8VEP90!0;VYU9&YI:R!S871E;&ET<VME9V$@
M9&]S=&]P80!3875D;W9A($%R86)I:F$`4VAR86YI`%-H<F%N:2`E<P!3:')A
M;FD@;6^^;F]S=&D`4VAR86YI(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;R!K
M;W0@4$A0('-K<FEP=&\@=B!Z8>AA<VYO(&UA<&\@;F$@=F&Y96T@<W1R9;YN
M:6MU+@!+;VYF:6=U<F%C:6IA("5S('-H<F%N:F5N82X`6FYA;F]S=`!)N>AI
M`$ES:V%L;F$@;W)O9&IA`$ES:V%N:F4@<W!O9&QE=&5L;P!)<VMA;FIE('-P
M;V1L971E;&\Z("5S`$FYZ&5M+BXN`$EZ8F5R:71E(&1A=&]T96ME`$EZ8F5R
M:71E(&1A='5M`$EZ8F5R:71E('-K=7!I;F\@:VD@:F\@OF5L:71E(&1O9&%T
M:0!)>F)E<FET92!N;W9E9V$@;&%S=&YI:V$`27IB97)I=&4@<W1R9;YN:6L`
M27IB97)I=&4@=7!O<F%B;FEK82!K:2!G82"^96QI=&4@9&]D871I`$EZ8F5R
M:2!V<V4@9&%T=6US:V4@:V]M<&]N96YT92X`27IB97)I(&]B:F5K=`!)>F)E
M<FET92!A9')E<V%R('IA(&EZ=F]Z.@!)>F)E<FET92!A9')E<V%R('IA('5V
M;WHZ`$EZ8F5R:71E('IN86ME+"!K:2!J:6@@<&]T<F5B=6IE=&4@:7H@<W!O
M9&YJ:6@@<&]L:BX@3F%T;R!J:6@@;&%H:V\@:V]P:7)A=&4@:6X@<')I;&5P
M:71E(&EZ(&]B<F%Z8V$N`$EZ8F5R:2!R87IM96II=&5V('IA(&1A='5M.@!)
M>F)E<FD@;V)L:6MO('IA<&ES82!D871U;6$Z`$EZ8F5R:71E(&]B;&EK;R!I
M>G9O>F$Z`$EZ8F5R:71E(&1A=&]T96MO('IA('5V;WHZ`$EZ8F5R:71O(&]B
M;&EK;R!I>G9O<FYE(&1A=&]T96ME.@!)>F)E<FET92!O8FQI:V\@>F$@<')I
M:V%Z(&EM96XZ`$EZ8F5R:71E(&ED96YT:71E=&\L(&MI(&IO(+YE;&ET92!S
M<')E;65N:71I.@!)>F)E<FET92!R87IM96II=&5V('IA(.AA<SH`27IB97)I
M=&4@;V)L:6MO('IA<&ES82!Z82#H87,Z`$EZ8F5R:71E(&1V92!U:F5M86IA
MZ&D@<&]L:FDN`$EZ8F5R:71E(&MA=&5R82!P;VQJ82!N86H@8F]D;R!P<FEK
M87IA;F$@=B!S97IN86UI:"!N87-L;W9O=BX`27IB97)I=&4@;V)L:6MO('IA
M('!R:6MA>B!I;65N+@!)>F)E<FET92!S=F]J;R!B87)V;F\@<VAE;6\N`$EZ
M8F5R:71E(+YE;&IE;B!J97II:SH`4&^Y;&II('!O<F_H:6QO(&\@;F%P86MI
M`%!ON6QJ:2!335,`4V5N96=A;`!396YZ;W(Z(`!397!T96UB97(`4W)B:6IA
M(&EN(,AR;F$@1V]R80!397)I:G-K82"Y=&5V:6QK80!)1"!S96IE(&IE('!O
M=&5K;&$N`$YA<W1A=FD`3F%S=&%V:2!M;[YN;W-T:2!Z82!P;VYA<W1A=FET
M978@9V5S;&$L('8@<')I;65R=2!D82!G82!P;WIA8FET92X`3F%S=&%V:2!O
M9&1A;&IE;F4@<W1R9;YN:6ME+"!D;R!K871E<FEH(+YE;&ET92!D;W-T;W!A
M=&D@<R!P;W)T86QA+@!.87-T879I(+YE;&IE;B!J97II:RP@Z&%S;W9N:2!P
M87,@:6X@<')I:V%Z(&1A='5M82X`3F%S=&%V:2!Z8>AE=&YO(&%P;&EK86-I
M:F\L(&)A<G9N;R!S:&5M;RP@;W-V9;YE=F%N:F4@<W1R86YI+"!I;B!O<W1A
M;&4@;6^^;F]S=&D@<')I:V%Z82X`3F%M97-T:71E=B!S:W)I<'0@>F$@<&]S
M;V1O8FET978@:F4@;F$@=F]L:F\`4&]D86YI;2!P87)A;65T<F]M('5S=')E
M>F$@=F7H(&QO:V%C:6HZ(`!396JY96QI`$UA<&$@=B!3:W5P;FD@<F%B:0!.
M86MU<&]V86YJ90!+<F%T96L@<&]V>F5T96L`3F%S=&%V:6T@8FQIOFYJ:6-E
M('IA('9EZ&EN;R!P;W9E>F%V/P!0<FEK8;YI`%!R:6MAOFD@5G-E`%!R:6MA
MOFD@4W1I:V4`4')I:V&^:2!397IN86UE`%!R:6MAOFD@<F%Z;&EK92!M960@
M=')E;G5T;F\@<VAR86YJ96YO(&EN(&YO=F\@9V5N97)I<F%N;R!K;VYF:6=U
M<F%C:6IO+@!0<FEK8;YE;2#H87,@>F%D;FIE('!R:6IA=F4@;V(@<')I:F%V
M;&IA;FIU/P!0<FEK8;YI(&UOOFYO<W0@>F$@;VAR86YI=&5V(&]R:6=I;F%L
M80!0;VMAOFD@;W)O9&IE('IA(&EZ8FER;P!0<FEK8;YE;2!M96YU('IA('5R
M96IA;FIE('1A8F5L93\`4')I:V&^96T@)7,@365N=2!N82!L979I/P!0<FEK
M8;YI('!O9V]V;W)N;R!O:VYO($QA<W1N;W-T:2!C96QI8V4@=&%B96QE`%!R
M:6MAOFD@<&]G;W9O<FYO(&]K;F\@3&%S=&YO<W1I('1A8F5L90!0<FEK8;YI
M('!O9V]V;W)N;R!O:VYO($QA<W1N;W-T:2!V<G-T:6-E('1A8F5L90!0<FEK
M8;YI('!O9V]V;W)N;R!O:VYO($QA<W1N;W-T:2!S;&EK90!0<FEK8;YI('-H
M<F%N:F5V86YJ92!N82!S=')EOFYI:P!0;&]H90!0;&]H92!Z9V]D86H`4&QO
M:&4@<&]Z;F\`4VMRZ&D`3F%J<')E:B!S:W+H:2!A;&D@;V1M86MN:2!S;W-E
M9&YJ92!B;&]K90!3:65R<F$@3&5O;F4`4')I:F%V80!0;V1P:7,`06QG;W)I
M=&5M('!O9'!I<V$`4VEN9V%P=7(`5F5L:6MO<W0`4')E<VMOZ&D@=GID<KYE
M=F%N:F4`4VQO=F&Y:V$`4VQO=F5N:6IA`%-N96<`4VYEOFYA('!L;VAA`%-N
M9;YN92!P;&]H90!3;F6^;F4@<&QO:&4@<&]Z;F\`1&5B96QI;F$@<VYEOFYE
M(&]D96IE.B``16YA:V$@:V]L:>AI;F$@=F]D93H@`%-A;&]M;VYO=FD@;W1O
M:VD`4V]M86QI:F$`4&5S;6D@)B!0;V5Z:6IA`%-M97(@<F%Z=G)S=&ET=F4`
M4F%Z=G)S=&D@:7IB<F%N;P!)>G9O<FYI(&YA<VQO=@!)>G9O<FD`2G6^;F$@
M069R:6MA`$IUOFYO($5V<F]P<VMO("A)4T\M.#@U.2TS*0!*=;YN82!'96]R
M9VEA(&EN($IUOFYI(%-A;F1W:6-H(&]T;VMI`$IUOFYA('!O;&]B;&$`4')O
M<W1O<B!M960@<V]S961N:FEM82!C96QI8V%M80!0<F]S=&]R(&UE9"!V<V5B
M:6YO(&EN(')O8F]M(&-E;&EC90!0<F5S;&5D;FEK`%)A>FUA:P!287IM86MI
M(&EN(&]D;6EK:0"I<&%N:6IA`%-P86T`5FYO<R!P;W-E8FYI:"!Z;F%K;W8`
M1&]L;^AI=&4L(&MJ92!N86H@8F]D;R!P<FEK87IA;FD@(')E>G5L=&%T:2!N
M87!R961N96=A(&ES:V%N:F$N`%)A>F1E;&D@8V5L:6-O`%)A>F1E;&D@<W1O
M;'!E8P!287ID96QI('9R<W1I8V\`J7!O<G0`J7)I;&%N:V$`4W1A;F1A<F0`
M6G9E>F1N92!S=&5Z90!,971O('IAZ&5T:V$`1'*^879A(&%L:2!P<F]V:6YC
M80!3=&%N:F4`3V)L:6MA('-H<F%N:F5V86YJ80!.87-L;W8`4')EZ')T86YO
M`%-E>FYA;2!B97-E9&EL80!/9'-T<F%N:2!D;VUE;F\@:7H@;F%S;&]V80!3
M=&EL(%M#4U-=`$YE`%IA9&5V80!0;[EL:FD`4&]D<&ES86YO`%5S<&6Y;F\`
M57-P9;EN;R!D;V1A;"`E<R!V("5S`%5S<&6Y;F\@<&]V<FYI;"!N87-T879I
M='9E+B!0;VYO=FYO(&YA;&^^:71E('-T<F%N+@!5<W!EN6YO('-H<F%N:6P@
M=F%R;F]S=&YO(&MO<&EJ;R!K;VYF:6=U<F%C:6IE+@!5<W!EN6YO('IA<&ES
M86P@)7,`4W5D86X`4&]V>F5T96L`4V]NZ&YI('9Z:&]D`%-O;NAN:2!Z86AO
M9`!3;V[H;F\`4V]NZ&YI('9Z:&]D`%-O;NAN:2!V>FAO9"]Z86AO9`!3;V[H
M;FD@=GIH;V0Z(`!3;V[H;FD@>F%H;V0`4V]NZ&YI('IA:&]D.@!.861P:7-A
M;F\`4&]D<&]R80!3=7)I;F%M`%!R:6EM96L`4W9A;&)A<F0@:6X@2F%N($UA
M>65N`%-V87II`*EV961S:V$`J79I8V$`3F%P8>AN82!S:6YT86MS82!I<VMA
M;FEH('!O:FUO=@!3:7)I:G-K82!!<F%B<VMA(%)E<'5B;&EK80!.979I:'1A
M`$YE=FEH=&4`5%-6`%135B!D871O=&5K80!6<F5D;F]S=&D@;&_H96YE(',@
M5&%B+6D`5&%B96QA`$QA<W1N;W-T:2!T86)E;&4`3&%S=&YO<W1I('1A8F5L
M90!486IV86X`5&%J=F%N+"!+:71A:G-K82!P<F]V:6YC80!4862^:6MI<W1A
M;@!486YZ86YI:F$`0VEL:CH`3W!R879I;&$`5&5L969O;G-K82"Y=&5V:6QK
M80!496UE<F%T=7)A('IA9&YJ;R!U<F\Z(`!496UP97)A='5R80!496UP97)A
M='5R83H@`%5P<F%V;&IA;FIE('!R961L;V<`0F5S961I;&\`4V%M;R!B97-E
M9&EO`%!O<F%V;F%V82!B97-E9&EL80!6<F@@8F5S961I;&$`R&4`5&%J<VMO
M("A425,M-C(P*0!486IS:V$`2'9A;&$@>F$@=7!O<F%B;R!S:7-T96UA+@!&
M5%`@9&]D871E:R!N:2!N82!V;VQJ;RX`2&]R9&4O2V]L86(@:6YT96=R86-I
M:F$@;F4@<&]D<&ER82`B)7,B`%)A>G)E9"!-86EN=&5N86YC93HZ('-E(&YI
M('5S<&6Y;F\@;F%L;[YI;`!/:VYO(&UOOFYO<W1I('-E(&IE('IA<')L;RX@
M6F%P:7)A;2X`061R97-A<FIA(&YI(&)I;&\@;6]G;^AE('!OZ&ES=&ET:3H@
M)7,`4VMR8FYI:R!M;W)A(&YA;65S=&ET:2!S=&%L;F\@:')B=&5N:6-O('IA
M(&1O9&5L:F5V86YJ92!P<F%V:6,L(.AE(+YE;&ET92!U<&]R86)L:F%T:2!0
M<F%V:6-E+@!386UO('-P;V1N:F$@<W1R86X`240@N71E=FEL:V$@<W1I:V$@
M;FD@8FEL82!P;V1A;F$L('!UN>AE;F$@<')A>FYA(&%L:2!N:2!B:6QA(&YA
M:F1E;F$@=B!B87II('!O9&%T:V]V+@!3=&EK(&IE(&)I;"!U<W!EN6YO(&1O
M9&%N('8@=F&Y(&%D<F5S87(N`%IA:'1E=F%N('-T:6L@;F4@;V)S=&%J82X`
M3V1D=F]J96X@4$=0('!O9'!I<VYI(&)L;VL@:F4@<&]T<F5B96X@>F$@879T
M96YT:6MA8VEJ;R!P;V1P:7-A;F5G82!S<&]R;^AI;&$N`$E$(+ET979I;&MA
M('-E>FYA;6$@<F%Z9&5L:71V92!N:2!B:6QA('!O9&%N82P@<'6YZ&5N82!P
M<F%Z;F$@86QI(&YI(&)I;&$@;F%J9&5N82!V(&)A>FD@<&]D871K;W8N`%-E
M>FYA;2!R87ID96QI='9E(&YI(&)I;"!P;V1A;BX`36^^;F]S=&D@N6EF<FER
M86YJ82!Z86AT979A:F\@=F%R;F\@<W!L971N;R!P;W9E>F%V;RX`1&%T;W1E
M:V$@)7,@8FD@;6]R86QA('9S96)O=F%T:2!N87-T879I=&5V("5S+@!$871O
M=&5K82`E<R!B:2!M;W)A;&$@=G-E8F]V871I(&YA<W1A=FET=F4@)7,N`$1A
M=&]T96ME(&YI(&UO9V_H92!P<F5S;F5T:2!S86UE('9A<V4N`$1A=&]T96MA
M(&YE('9S96)U:F4@<&]D871K;W8N`%-L961I(&=L879A('IA('1O('-P;W)O
MZ&EL;R]R9F,X,C(@<W!O<F_H:6QO`$YAZ&EN(&1E;&]V86YJ82#H97H@8V5L
M('IA<VQO;B!L86AK;R!P;W9Z<F_H:2!P<F]B;&5M92!V(&1E;&]V86YJ=2!)
M;G1E<FYE="!%>'!L;W)E<FIA('IA<F%D:2!H<F^YZ&5V(&)R<VMA;&YI:V$L
M(&MI('-E(&II;2!N:7-M;R!U<W!E;&D@;V=N:71I+B!/<&%Z:71E(&QA:&MO
M(.AU9&5N('!R:6MA>BP@;6%N:FMA:F_H92!M;[YN;W-T:2!U<F5J979A;&YI
M:V$@:6XO86QI(&YA:VQJ=>AN82!S97-U=&IA(&)R<VMA;&YI:V$N(,AE('5P
M;W)A8FQJ871E(%=I;F1O=W,@.7@L(&)O(&YA<&%K82!V97)J971N;R`G1V5N
M97)A;"!0<F]T96-T:6]N($9A=6QT)R!K:2!B;R!Z86AT979A;&$@<&]N;W9N
M:2!Z86=O;BY<;EQN0FEL:2!S=&4@;W!O>F]R:F5N:2X@4')O<VEM(&EZ8F5R
M:71E($]+(.AE(+EE('9E9&YO(+YE;&ET92!P;W-K=7-I=&D@=7!O<F%B;&IA
M=&D@8V5L;WIA<VQO;G-K:2!U<F5J979A;&YI:RX`261E;G1I=&5T82`B)7,B
M(&IE(&)I;&$@:7IB<FES86YA+@!386UO(&QE=F$@<W1R86X`4F%Z<F5D=2!#
M<GEP=%]P9W`Z.B!M;W)A(&)I=&D@<&]D86YA('!O="!D;R!';G501R!I>G9R
MN6EL;F4@9&%T;W1E:V4N`%-P;W)OZ&EL;R!P;W-L86YO("5S('IA("5S('H@
M>F%D979O("(E<R(@:F4@8FEL;R!P<FEK87IA;F\N"E1O(&YI('IA9V]T;W9I
M;&\L(&1A(&IE(&)I;&\@<W!O<F_H:6QO('!R96)R86YO(&%L:2!R87IU;6QJ
M96YO+@!);64L('5P;W)A8FQJ96YO('!R:2!P;W9E>F]V86YJ=2!N82!S=')A
M;B!Z82!S97-T879L:F%N:F4`4F%Z<F5D($AO<F1E7T-R>7!T7W-M:6UE.CH@
M>F%H=&5V82!M;V1U;"!O<&5N<W-L+@!.87-T879I='9E("(E<R(@;FD@8FEL
M;R!M;V=OZ&4@<VAR86YI=&DL(&ME<B!P<F5S96=A(&UA:W-I;6%L;F\@9&]V
M;VQJ96YO('9E;&EK;W-T`%!R;V=R86TL(&MI('-E('5P;W)A8FQJ82!Z82!P
M<FEK87H@=&4@=G)S=&4@<&]D871K;W8@*"5S*2!N:2!B:6P@;F%J9&5N+@!3
M86UO(&1E<VYE(&EN(&QE=F4@<W1R86YI`%-A;6\@9&5S;F$@<W1R86X`4W1R
M9;YN:6L@(B5S(B!J92!B:6P@:7IB<FES86XN`%-T<F6^;FEK("(E<R(@:F4@
M8FEL('-H<F%N:F5N+@!:86AT979A('IA('!R:6IA=F\@)7,@:F4@8FEL82!O
M9'-T<F%N:F5N82X`26UE;F]V86YA('9R<W1I8V$@;F4@;V)S=&%J82X`4V%M
M;R!Z9V]R;FIA(&EN('-P;V1N:F$@<W1R86YI8V$`4V%M;R!Z9V]R;FIA('-T
M<F%N:6-A`%!O9&%T:VD@<&]S;F5T:2!N82!S=')EOFYI:R!S;R!S92!O9"!P
M<F5JN6YJ96=A(&MO<F%K82!I>F=U8FEL:2X`4&]S;F5T92!D871O=&5K92!N
M:2!B:6QO(&UO9V_H92!S:')A;FET:2X`0FQO:R!W96%T:&5R+F-O;2!N:2!N
M82!V;VQJ;RX`3FD@861R97-A<FIE=B!P;R!K871E<FEH(&)I(&)I;&\@;6]G
M;^AE(&)R<VMA=&DN`$YO8F5N82!M;[YN;W-T(&YI<V\@;F$@=F]L:F\N`$YO
M8F5N96=A(&1E;&$@<W!O<F_H:6QA(&YI(&UO9V_H92!P<FEK87IA=&D@>FYO
M=')A:B!T96=A(&]K;F$N`$YI(&%D<F5S87)J978L('8@:V%T97)E(&)I(&)I
M;&\@;6]G;^AE('!I<V%T:2X@3F]B96X@:7IM960@861R97-A<FIE=BP@:VD@
M<V]N82!V;VQJ;R!N:2!N87-T879L:F5N('1A:V\L(&1A(&)I('9A;2!D;W9O
M;&IE=F%L(&1O9&%J86YJ92!V<&ES;W8N(,AE('-M871R871E(&1A(&=R92!Z
M82!N87!A:V\L('!R;W-I;2!K;VYT86MT:7)A:G1E('-V;VIE9V$@<VMR8FYI
M:V$@<VES=&5M82X`4&]L:F4@=G-E8G5J92!P<F5V9>@@>FYA:V]V+B!6;F5S
M;&D@<W1E("5S('IN86MO=CL@=FYE<W1I(&II:"!M;W)A=&4@;6%N:B!K;W0@
M)7,N`%!R:2!S;F5M86YJ=2!D871O=&5K92!N82!S=')EOFYI:R!J92!P<FFY
M;&\@9&\@;F%P86ME.B`E<R!N:2!S:')A;FIE;BX`4')I('-N96UA;FIU(&1A
M=&]T96ME(&YA('-T<F6^;FEK(&IE('!R:;EL;R!D;R!N87!A:V4Z("5S(&IE
M('9EZ&IA(&]D(&YA:G9EZ&IE(&1O=F]L:F5N92!V96QI:V]S=&D@*"5D(&)Y
M=&]V*2X`4')I('-N96UA;FIU(&1A=&]T96ME(&YA('-T<F6^;FEK(&IE('!R
M:;EL;R!D;R!N87!A:V4Z("5S(&IE('!O<VYE="!S86UO(&1E;&YO+@!0<FD@
M9&]D86IA;FIU('-T:6MA(&IE('!R:;EL;R!D;R!N87!A:V4N(%IA(&YA9&%L
M:FYO('!O;6_H(&MO;G1A:W1I<F%J=&4@<W9O:F5G82!S:W)B;FEK82!S:7-T
M96UA+@!0<FD@=7-T=F%R:F%N:G4@;F]V96=A('-E>FYA;6$@:F4@<')IN6QO
M(&1O(&YA<&%K92X`4')I(&)R:7-A;FIU('-T:6MA(&IE('!R:;EL;R!D;R!N
M87!A:V4Z("5S`%!R:2!B<FES86YJ=2!O8FIE:W1A(&IE('!R:;EL;R!D;R!N
M87!A:V4N`%!R:2!P<FEK87IO=F%N:G4@=&5G82!D96QA('-P;W)OZ&EL82!J
M92!P<FFY;&\@9&\@;F%P86ME`%!R:2!U=F&^86YJ=2!P;V1A=&MO=B!O('-T
M:6MU(&IE('!R:;EL;R!D;R!N87!A:V4N`%!R:2!U=F&^86YJ=2!P;V1A=&MO
M=B!J92!P<FFY;&\@9&\@;F%P86ME.B`E<P!0<FD@=79AOF%N:G4@:4-A;&5N
M9&%R('!O9&%T:V]V(&IE('!R:;EL;R!D;R!N87!A:V4N`$1O(&YA<&%K92!J
M92!P<FFY;&\@=B!O8G)A>F-U('IA(&MO;F9I9W5R86-I:F\N($UO9V_H92!S
M=&4@<'5S=&EL:2!P<F%Z;F\@>F%H=&5V86YO('!O;&IE+@!0<FFY;&\@:F4@
M9&\@;F%P86ME('!R:2!I>G9A:F%N:G4@>F%H=&5V86YE(&9U;FMC:6IE(&%D
M<F5S87)J82X@4')O<VEM('!O<VMU<VET92!P;VYO=FYO(&MA<VYE:F4N`%!R
M:;EL;R!J92!D;R!N87!A:V4@<')I(&]S=F6^979A;FIU('!O9')O8FYO<W1I
M(&\@<W1I:W4N(%!O<VMU<VET92!K87-N96IE+@!0<FFY;&\@:F4@9&\@;F%P
M86ME('!R:2!O<W9EOF5V86YJ=2!S97IN86UA(')A>F1E;&ET=F4N(%!O<VMU
M<VET92!K87-N96IE+@!0<FD@<&]S;V1O8FQJ86YJ=2!V<&ES82!J92!P<FFY
M;&\@9&\@;F%P86ME.B`E<P!.:2!N87-L;W9O=B!Z82!I>G9O>BX`5&$@24U!
M4"!S=')EOFYI:R!N92!P;V1P:7)A('-K=7!N92!R86)E(&YA8FER86QN:6MO
M=BX`1&%T;W1E:V$@=F5R:F5T;F\@;FD@=F5L:F%V96X@<F%R(&%R:&EV+@!$
M871O=&5K82!V97)J971N;R!N:2!V96QJ879E;B!Z:7`@87)H:78N`%9P:7-A
M;F$@N71E=FEL:V$@;FD@=F5L:F%V;F$@N71E=FEL:V$@:W)E9&ET;F4@:V%R
M=&EC92X`5&$@9V]N:6QN:6L@;VUO9V_H82!P;[EI;&IA;FIE('-P;W)OZ&EL
M('!R96MO($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<')E
M:&]D82!Z('5P;W)A8F\@2%144"!!4$D`5&$@9V]N:6QN:6L@;VUO9V_H82!P
M;[EI;&IA;FIE('-P;W)OZ&EL('!R96MO('-M<S)E;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"YC;VTI('!R96AO9&$@>B!U<&]R86)O($A45%`@05!)`%1A(&=O
M;FEL;FEK(&]M;V=OZ&$@<&^Y:6QJ86YJ92!S<&]R;^AI;"!P<F5K;R!33510
M('!R96AO9&$@5F]D869O;F4@271A;&EJ87-A;6\@5F]D869O;F4@N71E=FEL
M:V%M+B!:86AT979A;B!J92!O8G-T;VIEZ"!E+7!ON71N:2!N87-L;W8@<')I
M(%9O9&%F;VYE($ET86QI:F$@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&\@<&]L
M:F4@:F4@;V)V97IN;RX`5&\@<&]L:F4@;&%H:V\@=G-E8G5J92!S86UO(+ET
M979I;&ME+@!4;R!P;VQJ92!L86AK;R!V<V5B=6IE('-A;6\@N71E=FEL:V4@
M:6X@9'9O<&GH:F4N`%1O('!O;&IE(&QA:&MO('9S96)U:F4@<V%M;R!O:W1A
M;&YE('9R961N;W-T:2X`5&\@<&]L:F4@;6]R82!V<V5B;W9A=&D@<V5Z;F%M
M(+ET979I;"!L;^AE;B!Z(&1V;W!IZ&II(&%L:2!P<F5S;&5D:VD`5&\@<&]L
M:F4@;6]R82!V<V5B;W9A=&D@=F5L:F%V;F\@N71E=FEL:V\N`%1O('!O;&IE
M(&UO<F$@=G-E8F]V871I(&MO9&\@8F%R=F4@=B!O8FQI:VD@4D="($AE>"P@
M;F%P<FEM97(@)R,Q,C,T868G+@!/8FQI:V$@9&%T;W1E:V4@;FD@<&]D<')T
M82X`5&$@;V)R87IE8R!J92!B:6P@OF4@;V)D96QA;BX`5&\@:F4@)7,N`%1A
M(&]B:F5K="!J92!I>B!+;VQA8B!'<F]U<'=A<F4N(,AE(&=A(+YE;&ET92!P
M<FEK87IA=&DL('!O=')E8G5J971E('!R;V=R86UZ82!E+7!ON71O+"!K:2!P
M;WIN82!F;W)M870@2V]L86(@1W)O=7!W87)E+B!:82!S97IN86T@<')O9W)A
M;6]V(&]B:;GH:71E("5S`%1O('-P;W)OZ&EL;R!J92!B:6QO(&YA<&ES86YO
M('8@9')U9VD@:V]D;FD@=&%B96QI("@E<RD@:V]T(&IE('9AN6$N`%1O(+ET
M979I;&\@;6]R82!B:71I('9S86H@96YA+@!/<V5B82"^92!I;6$@)7,@=G!I
M<R!V(&%D<F5S87)J=0!482!S=')EOFYI:R!N92!M;W)E(&]D:V]M<')E<VER
M871I('II<"!I;B!G>FEP(&1A=&]T96LN`%-I<W1E;2!J92!T<F5N=71N;R!D
M96%K=&EV:7)A;BX`5&$@=G)E9&YO<W0@;6]R82!B:71I(+ET979I;&\N`%1O
M(&]K;F\@:F4@<&]T<F5B;F\@;V1P<F5T:2!I>B!O:VYA($UOOFYO<W1I`%-T
M<F5L80!6<W1O<&YI8V4`R&%S`%-L961E;FIE(.AA<V$`3V)L:6MA('IA<&ES
M82#H87-A`$EZ8FER82#H87-A`%1I;6]R+4QE<W1E`$YA<VQO=@!.87-L;W8@
M*&]K=FERZ&5K*3H`6F$`6F$@:7IB:7)O('9EZ&EH(&UOOFYO<W1I+"!D<KYI
M=&4@=&EP:V\@0V]N=')O;"`H4$,I(&%L:2!#;VUM86YD("A-86,I(&UE9"!K
M;&EK86YJ96T@;F$@OF5L:F5N92!M;[YN;W-T:2X`1&%N97,`4')I:V&^:2!(
M5$U,(&EZ=F]R;F\@:V]D;P!4;V=O`%1O:V5L874`2G5T<FD`5&]N9V$`6F=O
M<F%J`%IG;W)N:FD@;VMV:7(@*%]T;W`I`%!R979O9&D`5')I;FED860@:6X@
M5&]B86=O`$1ROFD@86QI(&YE(&1ROFD`5&\`5'5N:7II:F$`5'5RZ&EJ80!4
M=7*Y:V\@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!I;B!#86EC
M;W,@;W1O:VD`5'5V86QI`%9P:;EI=&4@:7IB:7)O.B``52Y6+B!I;F1E:W,Z
M(`!54DP`55),('IA(&1O<W1A=F\@<W1A='5S82!S:W)I<'1E`%523#H`56=A
M;F1A`%5K<F%J:6YA`$1O<W1O<"!D;R!61E,@;6%P92!N:2!M;V=OZ"X`4')I
M('!R:6IA=FQJ86YJ=2!N:2!M;V=OZ&4@9&]D871I(&1O9&%T;FEH(&EN9F]R
M;6%C:6H@;R!U<&]R86)N:6MU+@!.:2!M;V=OZ&4@<W!R96UE;FET:2!P<F%V
M:6,@>F$@5D93(&1A=&]T96MO("(E<R(N`$YI(&UO9V_H92!S<')E;65N:71I
M('!R879I8R!Z82!61E,@9&%T;W1E:V\@)7,O)7,N`"5S(&YI(&UO9V_H92!S
M<')E;65N:71I+@!0;W9E>F%V82!N82!344P@<W1R9;YN:6L@;FD@;6]G;^AA
M+@!0;W9E>F%V82!S(%-33"!N:2!M;V=OZ&$N`$MO<&ER86YJ92!61E,@9&%T
M;W1E:V4@;FD@;6]G;^AE+@!)>F1E;&%V82!61E,@;6%P92`B)7,B(&YI(&UO
M9V_H82X`27ID96QA=F$@5D93(&UA<&4@;FD@;6]G;^AA+@!)>F1E;&%V82!6
M1E,@9&%T;W1E:V4@;FD@;6]G;^AA+@!)>F1E;&%V82!P<F%Z;F4@5D93(&1A
M=&]T96ME(&YI(&UO9V_H82X`4&]D871K;W8@;FD@;6]G;^AE(&]D:V]M<')E
M<VER871I+@`B)7,B(&YI(&UO9V_H92!P;V)R:7-A=&DL(&UA<&$@;FD@<')A
M>FYA+@`E<R!N:2!M;V=OZ&4@<&]B<FES871I+"!M87!A(&YI('!R87IN80!6
M1E,@;6%P92!N:2!M;V=OZ&4@<F5K=7)Z:79N;R!P;V)R:7-A=&DN`%9&4R!M
M87!E(&YI(&UO9V_H92!P;V)R:7-A=&DN`%9&4R!M87!E(&YI(&UO9V_H92!P
M;V)R:7-A=&DZ("5S+@!61E,@9&%T;W1E:V4@;FD@;6]G;^AE('!O8G)I<V%T
M:2`B)7,B+@!61E,@9&%T;W1E:V4@;FD@;6]G;^AE('!O8G)I<V%T:2X`5D93
M(&YI(&UO9V_H92!R96MU<GII=FYO('!O8G)I<V%T:3H@)7,N`%1R96YU=&YE
M(&UA<&4@;FD@8FEL;R!M;V=OZ&4@=6=O=&]V:71I+@!0;V1R;V)N;W-T:2!O
M('!O=')D:6QU(&YI(&)I;&\@;6]G;^AE(&EZ=FQEZ&DN`$1E9FEN:6-I:F4@
M)7,@;FD@8FEL;R!M;V=OZ&4@;F%L;[YI=&DN`%9&4R!D871O=&5K92!N:2!M
M;V=OZ&4@<')E;6%K;FET:2X`5D93(&1A=&]T96ME("(E<R(@;FD@;6]G;^AE
M(&]D<')E=&DN`%9&4R!D871O=&5K92!N:2!M;V=OZ&4@;V1P<F5T:2!Z82!B
M<F%N:F4N`%9&4R!D871O=&5K92!N:2!M;V=OZ&4@;V1P<F5T:2X`2V]M<')E
M<VER86YE9V$@87)H:79A(&YI(&UO9V_H92!O9'!R971I+@!V9G-R;V]T(&UA
M<&4@;FD@;6]G;^AE('!R96)R871I+@`E<R!N:2!M;V=OZ&4@<')E:6UE;F]V
M871I('8@)7,Z(&UA<&$@OF4@;V)S=&%J80!61E,@;6%P92!N:2!M;V=OZ&4@
M<')E:6UE;F]V871I+@!61E,@;6%P92!N:2!M;V=OZ&4@<')E:6UE;F]V871I
M.B`E<RX`5D93(&1A=&]T96ME("(E<R(@;FD@;6]G;^AE('!R96EM96YO=F%T
M:2X`5D93(&1A=&]T96ME("5S+R5S(&YO(&UO9V_H92!P<F5I;65N;W9A=&DN
M`%9&4R!D871O=&5K92!N:2!M;V=OZ&4@<')E:6UE;F]V871I+@!5:V%Z82`G
M;6MI<V]F<R<@;FD@;6]G;^AE('IA9VYA=&DN`%=O<F1O=F4@9&%T;W1E:V4@
M;FD@;6]G;^AE('!R979E<W1I+@!61E,@9&%T;W1E:V4@(B5S(B!N:2!M;V=O
MZ&4@>F%P:7-A=&DN`%9&4R!D871O=&5K92!N:2!M;V=OZ&4@>F%P:7-A=&D@
M*'5K87H@8V]P>2@I(&IE('-P;V1L971E;"DN`%!O9&%T:V]V(&\@5D93(&1A
M=&]T96MI(&YI(&UO9V_H92!Z87!I<V%T:2X`4&]DZ')T86YO`%!R96ML:>AI
M('-P<F5M96UB90!287IV96QJ879I('IA9&YJ92!D96IA;FIE`$YE<')IZ&%K
M;W9A;B!O9'II=B!S=')EOFYI:V$@;V(@<&]V97IA=FDZ(`!.97!R:>AA:V]V
M86X@;V1Z:78@<W1R9;YN:6MA(&YA.B``3F5N87!O;&YJ96YO`%5N:6-O9&4@
M*%541BTX*0!:9')UOF5N:2!!<F%B<VMI($5M:7)A=&D`6F1R=;YE;F\@:W)A
M;&IE<W1V;P!:9')UOF5N92!D<KYA=F4`6F1R=;YE;F4@9'*^879E("T@;6%N
M:KEI(&EZ=F5N+6QEOF7H:2!O=&]K:0!%;F]T90!.97IN86X`3F5Z;F%N(&%P
M:6US9VED("A)1"!!4$D@<W!O<F_H:6QA*2X`3F5Z;F%N(&-L:6US9VED("A)
M1"!O9&IE;6%LZ&5V96=A('-P;W)OZ&EL82DN`$YE>FYA;F\@=7!O<F%B;FFY
M:V\@:6UE(&%L:2!G97-L;RX`3V1S=')A;FD@<&]V97IA=F\@=')E;G5T;F5G
M82!E;&5M96YT80!.96EM96YO=F%N`%-K<FEP=&4@8G)E>B!P<F%V:6,@;F4@
M;6]R86IO('5P;W)A8FQJ871I('5K87IO=B!)>G)EOFDO2V]P:7)A:B]0<FEL
M97!I(&EZ('9A<FYO<W1N:6@@<F%Z;&]G;W8N($ML:6MN:71E($]+('IA('1E
M:&YIZ&YO(')A>FQA9V\@;F$@;6]Z:6QL82YO<F<@:VD@<&]N87IA<FIA+"!K
M86MO(&]M;V=OZ&ET:2!S:W)I<'1I(&1O<W1O<"!D;R!O9&QOOFFYZ&$N`$YE
M;F%S=&%V;&IE;F$@8F%R=F$`3F5P;V1P<G0@9&]D871E:P!0;W-O9&]B:0!0
M;W-O9&]B:2`E<P!0;W-O9&]B:2!U<&]R86)N:6MA`%-K<FEP=&$@>F$@;F%D
M9W)A9&YJ;R!P;V)R:7-A;F$N`%-H<F%N:2!N82!S=')EOFYI:P!6<V4@;F%M
M97-T:71V96YE(&1A=&]T96ME('-H<F%N:F5N92!N82!S=')EOFYI:RX`5F5L
M:6ME(&QA=&EN<VME(.AR:V4`5F5L:6ME(')I;7-K92"Y=&5V:6QK90!5<F%G
M=F%J`%5P;W)A8FD@=')E;G5T;F\Z("5S`%5P;W)A8FD@4U-,`%5P;W)A8FD@
MZ&4@<V4@:6UE+V=E<VQO(')A>FQI:W5J971A('IA($E-4U`@<W1R9;YN:6LN
M`%5P;W)A8FYI:R`E<R!N:2!P;V]B;&&YZ&5N('IA("5S+@!!9&UI;FES=')A
M8VEJ82!U<&]R86)N:6MO=@!-;[YN;W-T:2!U<&]R86)N:6MO=@!296=I<W1R
M86-I:F$@=7!O<F%B;FEK;W8`4F5G:7-T<F%C:6IA('5P;W)A8FYI:V]V(&IE
M('IA('1O('-P;&5T;F\@;65S=&\@;VYE;6]G;^AE;F$N`%5P;W)A8FYIN6MO
M(&EM90!5<&]R86)N:;EK;R!I;64Z`%5P;W)A8FYIN6MO(&EM93H@`%5P;W)A
M8FYI:VD@=B!S:7-T96UU.@!5>F)E:VES=&%N`%9&4R!M87!A(&YE(&]B<W1A
M:F$N`$1O<'5S=`!5<W1R97IN92!N86ID96YE(&QO:V%C:6IE('9K;&IUZ'5J
M96IO.B``5F5L:F%V;F]S=`!6<F5D;F]S="!V(&UI;G5T86@@;V0@=&5G82!T
M<F5N=71K82X`5G)E9&YO<W1I`%9R961N;W-T:2!Z82!I>F)I<F\`5F%N=6%T
M=0!3<')E;65N;&II=F\`5F5N97IU96QA`$]V97)J86YJ92!S<&]D;&5T96QO
M("T@<W!O<F_H:6QO(&IE(&)I;&\@<W!R96UE;FIE;F\N`%9E<FES:6=N($EM
M96YI:P!697)Z:6IA`$YA9'IO<B!V97)Z:6H`3F%V<&GH;F$@<&]R879N879A
M`$YA=G!IZ&5N(&]D;6EK`$YA=G!IZ&YO.@!:96QO('9I<V]K;P!6:65T;F%M
M`%9I971N86US:V\@*%9)4T-)22D`4')I:V&^:2`E<P!0;V=L96H@4W1I:P!0
M<FEK8;YI('IU;F%N:F\@<W!L971N;R!S=')A;@!0<FEK8;YI(&MO="`E<P!0
M<FEV>F5T:2!N8>AI;B!P<FEK87IA.@!"<FET86YS:VD@1&5V:;EK:2!O=&]K
M:0!!;65R:;EK:2!$979IN6MI(&]T;VMI`%9I9&QJ:79O<W0`5FED;&II=F]S
M=#H@`%9O9&%F;VYE($ET86QI:F$@<')E:V\@4TU44`!/4$]:3U))`$]03UI/
M4DE,3R$A(2!23\A.3R!/1%-44D%.251%(%-+4DE05$\@25H@)7,N`%=A;&QI
M<R!I;B!&=71U;F$`3W!O>F]R:6QO`%-R`%9R96UE;G-K82!N87!O=F5D`%9R
M96UE;G-K;R!N87!O=F5D('!R:7-K<F)E;`!796%T:&5R+F-O;0!3<&QE=`!3
M<&QE=&YO(&UE<W1O`%-P;&5T;F$@<W1R86X`5&5D96YS:V\`1&]B<F]D;[EL
M:0!$;V)R;V1ON6QI('8@)7,`1&]B<F]D;[EE;"P@)7,`6F%H;V1N;R`H25-/
M+3@X-3DM,2D`6F%H;V1N;R`H25-/+3@X-3DM,34I`%IA:&]D;F$@4V%H87)A
M`$MA=&5R;R!A<&QI:V%C:6IO(&YA:B`E<R!P<FEK8;YE('!O('!R:6IA=FD_
M`$MA=&5R:2!Z;F%K(')A>FUE:G5J92!P;VQJ83\`2V%T97)I('IN86L@:F4@
M=7!O<F%B;&IE;B!Z82!C:71I<F%N:F4_`$MA=&5R92!M96YE`$MA=&5R:2!P
M;'5G:6YI+2!N86H@8F]D;R!O;6]G;^AE;FD@>F$@=7)E:F5V86QN:6L@;V)O
M9V%T96YE9V$@8F5S961I;&$N`*EI<FEN80"I:7)I;F$@=B!#4U,@96YO=&%H
M`*EI<FEN82`E<R!M96YU:F$@;F$@;&5V:2`H=F5L:F$@;V(@;F%S;&5D;FII
M('!R:6IA=FDI.@"I:7)I;F$@=&%B96QE`$5N;W1A(+EI<FEN90"I:7)I;F$Z
M`%=I:VD`5F5T97(`2&ET<F]S="!V971R82!V('9O>FQI:`!6971E<CH`5F5T
M97(Z(`!-;V1R;W-T`$1E;&\`4VQUOF)E;FD@;F%S;&]V`$UE<W1O('-L=;YB
M90!$<KYA=F$@<VQUOF)E`%-L=;YB96YI('1E;&5F;VX`4&^Y=&YA(+ET979I
M;&MA('-L=;YB90!$<KYA=F$O3VMR86H@<VQUOF)E`%@M4F5F`%@U,#EV,R!/
M<VYO=FYE(&]M96II='9E`%@U,#EV,R!0;V1A;&JY86YA('5P;W)A8F$@:VQJ
M=>AA`%@U,#EV,R!!;'1E<FYA=&EV;F\@:6UE('-U8FIE:W1A`%@U,#EV,R!)
M9&5N=&EF:6MA8VEJ82!K;&IUZ&$@<W5B:F5K=&$`6#4P.78S(&1O9&%T:VD`
M3$P`3$Q,3`!986AO;R$@>F5M;&IE=FED`$QE=&YO`$IE;65N`$1A`$1A+"!S
M=')I;FIA;2!S90!3=&4@=B!"15-%1$E,3D5-($Y!R$E.52X@57!O<F%B:71E
M(%L\/ET@9W5M8B!Z82!P<F5K;&]P(&YA>F%J('8@5UE325=91RX`3FES=&4@
M8FEL:2!O=F5R:F5N:2X`5F&Y92!P;VQN;R!I;64@;F4@<VUE('9S96)O=F%T
M:2!Z;F%K82`G7"<N`$YI<W1E('9P:7-A;&D@=F5L:F%V;F5G82!N87-L;W9A
M(&4M<&^Y=&4N`$YI<W1E('!O=F5Z86QI(&YO8F5N96=A('!O;&IA(&EZ('5V
M;[YE;F4@9&%T;W1E:V4@>B!U<W1R97IN:6UI('!O;&II('8@)7,N`%IA(&]G
M;&5D('-T:6MA(&YI;6%T92!D;W9O;&IE;FIA+@!:82!O9VQE9"!O8FIE:W1A
M(&YI;6%T92!D;W9O;&IE;FIA+@!/9&IA=FEL:2!S=&4@<V4N`%9P:7-A=&D@
M;6]R871E('9E;&IA=FYO(+ET979I;&MO(&UO8FEL;F5G82!T96QE9F]N82`M
M('-A;6\@N71E=FEL:V4@>B!O<&-I:G-K:6T@)RLG('IA(&UE9&YA<F]D;F\@
M<')E9'!O;F\N`%9P:7-A=&D@;6]R871E('9E;&IA=FYO('9R961N;W-T+@!$
M871A=')E92!M;W)A=&4@:V]N9FEG=7)I<F%T:2!Z82!U<&]R86)O(%-I9VYU
M<',N`%9&4R!M;W)A=&4@:V]N9FEG=7)I<F%T:2X`4')E9&5N('!ON6QJ971E
M('!O<F_H:6QO(&\@;F%P86MI+"!M;W)A=&4@;F%P86MO(&]P:7-A=&DN`%9P
M:7-A=&D@;6]R871E(%523"!K86UO<B!N86H@=&$@<&]V97IA=F$@:V&^90!)
M>F)R871I(&UO<F%T92!C:6QJ;FD@861R97-A<BX`27IB<F%T:2!M;W)A=&4@
M8VEL:FYI('-E>FYA;2X`27IB<F%T:2!M;W)A=&4@<W1R9;YN:6LL(&MI(&=A
M(+YE;&ET92!I>F)R:7-A=&DN`$YA:G!R96H@;6]R871E(&EZ8G)A=&D@=G-A
M:B!E;B!V<&ES+@!.879E<W1I(&UO<F%T92!U<&]R86)N:;EK;R!I;64L(&MI
M(&=A(+YE;&ET92!P;^AI<W1I=&DN`$YA=F5S=&D@;6]R871E('5P;W)A8FYI
MN6MO(&EM92P@:VD@9V$@OF5L:71E(&]D<W1R86YI=&DN`$YA=F5S=&D@;6]R
M871E('5P;W)A8FYIN6MO(&EM92P@:VD@9V$@OF5L:71E(&1O9&%T:2X`3F%V
M97-T:2!M;W)A=&4@=7!O<F%B;FFY:V\@:6UE+"!K:2!G82"^96QI=&4@<&]S
M;V1O8FET:2X`3F%V97-T:2!M;W)A=&4@9&5J86YJ92P@:VD@;F%J('-E(&EZ
M=F5D92X`5G!I<V%T:2!M;W)A=&4@:6UE(&YO=F4@:V%T96=O<FEJ92X`6F$@
M;V=L960@<W1I:V$@<&]T<F5B=6IE=&4@<')A=FEC92X`5F&Y82`E<R!S96IA
M(&IE('!O=&5K;&$N(%!O;F]V;F\@<V4@<')I:F%V:71E+@!68;EA(&4M<&^Y
M=&YI(&YA<VQO=@!68;D@3V0Z(&YA<VQO=CH`5F&Y:2!P;V1A=&MI`%9AN2!I
M;G1E<FYE=&YI(&YA<VQO=B!S92!J92!S<')E;65N:6P@;V0@>F'H971K82`E
M<R!S96IE+B!)>B!V87)N;W-T;FEH(')A>FQO9V]V('-E(&UO<F%T92!P;VYO
M=FYO('!R:6IA=FET:2X`5F&Y92!I;64`5F&Y82!H<F)T96YI8V$@>F$@;W9E
M<FIA;FIE(&YE('!O9'!I<F$@<')I:V%Z;W9A;FIA('5P;W)A8FYI:V]V+"!A
M;&D@<&$@:F4@8FEL82!T82!M;[YN;W-T(&EZ(&YE:V5G82!R87IL;V=A(&]N
M96UO9V_H96YA+@!68;D@8G)S:V%L;FEK('-E(&IE('-P<F5M96YI;"!O9"!Z
M8>AE=&MA('9AN64@)7,@<V5J92X@27H@=F%R;F]S=&YI:"!R87IL;V=O=B!S
M92!M;W)A=&4@<&]N;W9N;R!P<FEJ879I=&DN`%9AN2!B<G-K86QN:6L@;F4@
M<&]D<&ER82!T92!M;[YN;W-T:2X`5F&Y('1R96YU=&5N(.AA<V]V;FD@<&%S
M.@!68;EA('!R:79Z971A(&ED96YT:71E=&$Z`%9AN64@<&]L;F\@:6UE.@!6
M8;EE(&YO=F\@9V5S;&\@>F$@)7,@:F4Z("5S`%9AN64@;F%S=&%V:71V92!S
M;R!B:6QE('!O<V]D;V)L:F5N92X`5F&Y92!G97-L;R!J92!B:6QO('!O;F%S
M=&%V;&IE;F\`5F&Y92!G97-L;R!J92!B:6QO('!O;F%S=&%V;&IE;F\N(%!O
M9VQE:G1E('9AN6\@92UP;[ET;R!I;B!S92!P<FEJ879I=&4@>B!N;W9I;2!G
M97-L;VTN`%9AN6D@;V1D86QJ96YI('-T<F6^;FEK:3H`2G5G;W-L879I:F$`
M6F%I<F4`6F%M8FEJ80!::6UB86)V90!::7!P:0!;4VMR:6H@8VET:7)A;F\@
M8F5S961I;&]=`%M0;W)OZ&EL;R!O(&YA<&%K:5T`6U!R:6MAOFD@8VET:7)A
M;F\@8F5S961I;&\@+0!;4')I:V&^:2!C:71I<F%N;R!B97-E9&EL;R`M("5S
M('9R<W1I8UT`6W9R<W1I8V$@)7,@;V0@)7-=`%MB<F5Z('9R961N;W-T:5T`
M7T%D;6EN:7-T<F%C:6IA`%]"<G-K86H`7T-,20!?1&%T851R964`7TEZ8G)I
MN6D`7TEZ8G)IN6D@=G)S=&EC;P!?4VMU<&EN90!?4&]M;^@`7TQA<W1N;W-T
M:2!S;&EK92XN+@!?579O>FDO27IV;WII`%]0<FEJ879A`%]/9&IA=F$`7U-P
M<F5M96YI('!O=F5Z879O+BXN`%]-;[YN;W-T:0!?4')A=FEC90!?3V1S=')A
M;FD@<&]V97IA=F\N+BX`7T]D<W1R86YI(',@<V5Z;F%M80!?2;GH:0!?3F%M
M97-T:71E=@!?3&%S=&YO<W1I('1A8F5L92XN+@!?57!O<F%B;FEK:0!A9')E
M<V%R`&MO;&5D87(`;6ER;F\`:VQI:VYI=&4@<V5M`&-O;G1A8W0N=F-F`&-O
M;G1A8W1S+F-S=@!C;VYT86-T<RYT<W8`<&%D86IOZ`!D871O=&5K80!O9"`E
M<R`H)7,I('!R:2`E<R`E<P!V.@!T86MO:KEN:0!N;W1R86YJ:0!V<G-T:6-E
M70!M:VES;V9S(&YA<&%K82"Y=&5V:6QK82`E9"!M960@:7ID96QA=F\@25-/
M('!O<VYE=&MA+@!I;64`;FD@:6UP;&5M96YT:7)A;@"Y92!N:2!I;7!L96UE
M;G1I<F%N`&)E;&6^;FEC80!O9'-T;W1E:P!P:7AL;W8`<F%S=&_H`'!O:V&^
M:2!R87IL:6ME`'-M<S)E;6%I;"!P<F5K;R!(5%10`&UI<FYO`'-E>FYA;2!O
M<')A=FEL`'9P:;EI=&4@9V5S;&\@9'9A:W)A="!Z82!P;W1R9&ET978`>F1R
M=;YE;@!N96EM96YO=F%N`&EZ8FER82!U<&]R86)N:6MA`'9#87)D`+DZ`'=E
M871H97(N8V]M````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C
M86QE+W-V7U-%+P``````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-@`P,C`P,C(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T=7)B82]L;V-A;&4O<W9?4T4O3$-?34534T%'15,O````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4V`#`R,38P
M-P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]S=E]312],
M0U]-15-304=%4R]T=7)B82YM;P``````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-C0W,S,`
M,3`T,3<S-C(W-38`,#(S,C<W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````]@@``!P```#,1P``]0L``'R/````
M````4+\``$@```!1OP``#@```)J_```/````J;\```P```"YOP``#0```,:_
M```(````U+\```L```#=OP``#````.F_```9````]K\``!D````0P```!```
M`"K````I````+\```!@```!9P```&P```'+````M````CL```!T```"\P```
M)````-K````I````_\```"D````IP0``&0```%/!```H````;<$``"0```"6
MP0``)0```+O!```F````X<$```P````(P@``)````!7"```/````.L(```L`
M``!*P@``#@```%;"```%````9<(``"@```!KP@``"````)3"```*````G<(`
M`!4```"HP@``"0```+["```2````R,(```L```#;P@``'0```.?"```4````
M!<,``"8````:PP``)P```$'#```F````:<,``(4```"0PP``#@```!;$```*
M````)<0```T````PQ```)P```#[$```@````9L0```X```"'Q```%P```);$
M```B````KL0``#4```#1Q```$0````?%```-````&<4```P````GQ0``#0``
M`#3%```&````0L4``)0```!)Q0``"@```-[%```/````Z<4``!@```#YQ0``
M#````!+&```.````'\8```X````NQ@``"````#W&```)````1L8``"L```!0
MQ@``+@```'S&```:````J\8``#(```#&Q@``.````/G&``!4````,L<``%$`
M``"'QP``6@```-G'``!7````-,@``#0```",R```"0```,'(```-````R\@`
M``<```#9R```"@```.'(```/````[,@```4```#\R```!@````+)```1````
M"<D```@````;R0``$0```"3)```)````-LD```D```!`R0``#@```$K)```(
M````6<D``"4```!BR0``(````(C)```3````J<D``!,```"]R0``$````-')
M```/````XLD```H```#RR0``!P```/W)```#````!<H```8````)R@``#P``
M`!#*```4````(,H```D````UR@``#0```#_*```2````3<H``!D```!@R@``
M'@```'K*```/````F<H``!````"IR@``(0```+K*```*````W,H```@```#G
MR@``#P```/#*```(`````,L``"0````)RP``%P```"[+```&````1LL``!0`
M``!-RP``%@```&++```(````><L``$X```""RP``+0```-'+```6````_\L`
M`"$````6S```&0```#C,```'````4LP```P```!:S```%````&?,```-````
M?,P``!(```"*S```&@```)W,```A````N,P``!<```#:S```*0```/+,```L
M````',T```X```!)S0```P```%C-```/````7,T```L```!LS0``!P```'C-
M```'````@,T```4```"(S0``!0```([-```*````E,T```,```"?S0``%P``
M`*/-```*````N\T```\```#&S0``#@```-;-```8````Y<T``",```#^S0``
M#@```"+.```.````,<X``!0```!`S@``%P```%7.```7````;<X``!<```"%
MS@``$P```)W.```/````L<X```X```#!S@``*0```-#.```?````^LX``!T`
M```:SP``!P```#C/```&````0,\```@```!'SP``#P```%#/```&````8,\`
M``H```!GSP``$P```'+/```+````AL\``!````"2SP``%0```*//```5````
MN<\```<```#/SP``$````-?/```%````Z,\``!4```#NSP``$0````30```,
M````%M```"@````CT```.@```$S0```[````A]```#@```##T```"0```/S0
M```'````!M$``!0````.T0```P```"/1```%````)]$```D````MT0``$```
M`#?1```)````2-$``!,```!2T0``.0```&;1```2````H-$``#D```"ST0``
M)P```.W1```L````%=(``"H```!"T@``)0```&W2```)````D](```H```"=
MT@``!@```*C2```)````K](```<```"YT@``+P```,'2```W````\=(``"X`
M```ITP``50```%C3```M````KM,``"T```#<TP``/0````K4```_````2-0`
M`"T```"(U```0````+;4```C````]]0``",````;U0``0````#_5```M````
M@-4``#,```"NU0``)0```.+5```5````"-8``!D````>U@``*0```#C6```D
M````8M8``"@```"'U@``$0```+#6```1````PM8```H```#4U@``!````-_6
M```,````Y-8```H```#QU@``$````/S6```6````#=<``!8````DUP``!P``
M`#O7```'````0]<``!0```!+UP``"@```&#7```(````:]<```@```!TUP``
M"````'W7```&````AM<``"<```"-UP``"````+77```,````OM<```<```#+
MUP``!P```-/7```&````V]<``!$```#BUP``!0```/37```'````^M<```8`
M```"V```%`````G8```(````'M@``"D````GV```#@```%'8```*````8-@`
M``D```!KV```#@```'78```$````A-@```<```")V```"0```)'8```&````
MF]@``!$```"BV```!P```+38```6````O-@```0```#3V```"````-C8```&
M````X=@```T```#HV```!@```/;8```>````_=@```4````<V0``!@```"+9
M```1````*=D```@````[V0``#0```$39```,````4MD```P```!?V0``!P``
M`&S9```1````=-D```,```"&V0```P```(K9```7````CMD```,```"FV0``
M$P```*K9```=````OMD```@```#<V0``!````.79```(````ZMD```@```#S
MV0``"@```/S9``!!````!]H``!H```!)V@``'````&3:```K````@=H``"``
M``"MV@``%0```,[:```&````Y-H```8```#KV@``%0```/+:```8````"-L`
M`"(````AVP``+@```$3;```=````<]L``"$```"1VP``*0```+/;```*````
MW=L```<```#HVP``!P```/#;```5````^-L```X````.W```"@```!W<```/
M````*-P```T````XW```#P```$;<```-````5MP```D```!DW```%````&[<
M```&````@]P``!@```"*W```'0```*/<```3````P=P``!$```#5W```%```
M`.?<```$````_-P```P````!W0``!@````[=```4````%=T``!<````JW0``
M5````$+=``!D````E]T```0```#\W0``#@````'>```/````$-X``$0````@
MW@``!0```&7>```%````:]X``!L```!QW@``&@```(W>```3````J-X```T`
M``"\W@``$0```,K>```1````W-X``!$```#NW@``%@````#?```7````%]\`
M`!P````OWP``*@```$S?```Y````=]\``"(```"QWP``,@```-3?```0````
M!^```"$````8X```!0```#K@```3````0.````L```!4X```$@```&#@```*
M````<^````\```!^X```#0```([@```1````G.```!,```"NX```#````,+@
M```&````S^````P```#6X```!@```./@```7````ZN```!`````"X0``$0``
M`!/A```(````)>$```4````NX0``#````#3A```0````0>$```4```!2X0``
M#@```%CA```-````9^$``",```!UX0``!@```)GA```6````H.$``"H```"W
MX0``!P```.+A```-````ZN$```<```#XX0``"P````#B```'````#.(```<`
M```4X@``#P```!SB```)````+.(``!0````VX@``"0```$OB```)````5>(`
M``H```!?X@``&0```&KB```]````A.(``!T```#"X@``#````.#B```0````
M[>(```4```#^X@``)0````3C```2````*N,``!,````]XP``%0```%'C```2
M````9^,``"L```!ZXP``.P```*;C```@````XN,```P````#Y```#@```!#D
M```(````'^0``!0````HY```-@```#WD```A````=.0``!````"6Y```"```
M`*?D```,````L.0```8```"]Y```!````,3D```/````R>0```X```#9Y```
M"@```.CD```'````\^0```H```#[Y```#0````;E```>````%.4``!\````S
MY0``&P```%/E```<````;^4``"$```",Y0``'@```*[E```9````S>4``!X`
M``#GY0``&P````;F```A````(N8``"X```!$Y@``)@```'/F```;````FN8`
M`!P```"VY@``'@```-/F```<````\N8``"8````/YP``*P```#;G```S````
M8N<``"8```"6YP``*P```+WG```X````Z><``!T````BZ```'0```$#H```5
M````7N@``!4```!TZ```+P```(KH```@````NN@``!(```#;Z```(````.[H
M```I````#^D``!X````YZ0``'@```%CI```@````=^D``!(```"8Z0``H@``
M`*OI```6````3NH``",```!EZ@``*````(GJ```I````LNH``"@```#<Z@``
M'P````7K```5````)>L``!4````[ZP``(````%'K```E````<NL``"@```"8
MZP``+0```,'K```P````[^L``)(````@[```(0```+/L```6````U>P``!8`
M``#L[```'`````/M```F````(.T``"H```!'[0``00```'+M``!$````M.T`
M``P```#Y[0``!P````;N```'````#NX```8````6[@``$P```!WN```-````
M,>X``!T````_[@``$````%WN```2````;NX```<```"![@``$P```(GN```2
M````G>X```<```"P[@``!````+CN```0````O>X``!````#.[@``#````-_N
M```.````[.X```T```#[[@``#P````GO```3````&>\```T````M[P``*```
M`#OO```#````9.\```T```!H[P``!@```';O```1````?>\``!<```"/[P``
M&P```*?O```.````P^\```(```#2[P``!0```-7O```0````V^\```\```#L
M[P``!````/SO```-`````?````X````/\````P```![P```.````(O````@`
M```Q\```#P```#KP```(````2O````\```!3\```!P```&/P```-````:_``
M`!````!Y\```#0```(KP```:````F/````L```"S\```$0```+_P```)````
MT?````8```#;\```$P```.+P```+````]O```!,````"\0``#````!;Q```*
M````(_$``!$````N\0``&0```$#Q```7````6O$```L```!R\0``#0```'[Q
M```B````C/$``!8```"O\0``#P```,;Q```;````UO$``#0```#R\0``"@``
M`"?R```8````,O(``!(```!+\@``&0```%[R```6````>/(``!````"/\@``
M(@```*#R```C````P_(```\```#G\@``#0```/?R```'````!?,```P````-
M\P``)@```!KS```*````0?,```H```!,\P``%````%?S```+````;/,``"(`
M``!X\P``+P```)OS```+````R_,```D```#7\P``&0```.'S```+````^_,`
M`!<````']```%P```!_T```)````-_0```<```!!]```%@```$GT```/````
M8/0``!D```!P]```%@```(KT```.````H?0```<```"P]```"````+CT```-
M````P?0``"8```#/]```*````/;T``!#````'_4``!(```!C]0``'P```';U
M```(````EO4```L```"?]0``+P```*OU```.````V_4```X```#J]0``!0``
M`/GU```&````__4``$4````&]@```P```$SV```'````4/8```0```!8]@``
M"0```%WV```2````9_8```H```!Z]@``"@```(7V```/````D/8``!````"@
M]@``%P```+'V```1````R?8``!$```#;]@``&0```.WV```7````!_<```D`
M```?]P``!0```"GW```+````+_<```H````[]P```@```$;W```%````2?<`
M``T```!/]P``&P```%WW```7````>?<``!0```"1]P``"0```*;W```.````
ML/<```T```"_]P``$@```,WW```#````X/<```@```#D]P``#@```.WW```8
M````_/<``!@````5^```/0```"[X```5````;/@```4```""^```(P```(CX
M```S````K/@``!@```#@^```'0```/GX```N````%_D``!X```!&^0``&P``
M`&7Y```9````@?D``"<```";^0``-P```,/Y```D````^_D``!@````@^@``
M&P```#GZ```3````5?H``!,```!I^@``!P```'WZ```(````A?H```8```".
M^@``!@```)7Z```0````G/H```\```"M^@``$````+WZ```/````SOH```L`
M``#>^@``#P```.KZ```,````^OH```\````'^P``!P```!?[```1````'_L`
M``8````Q^P``#@```#C[```,````1_L``"@```!4^P``#P```'W[```(````
MC?L```8```"6^P``$P```)W[```B````L?L``"T```#4^P``"`````+\```3
M````"_P``!X````?_```)0```#[\```:````9/P``!4```!__```'@```)7\
M``!#````M/P``"$```#X_```(````!K]```9````._T``!<```!5_0``)0``
M`&W]```E````D_T``!<```"Y_0``%@```-']```A````Z/T``"(````*_@``
M!````"W^```;````,OX```T```!._@``#````%S^```#````:?X```4```!M
M_@``"````'/^```*````?/X```P```"'_@``"P```)3^```0````H/X```P`
M``"Q_@``#@```+[^```+````S?X```0```#9_@``!````-[^```3````X_X`
M`!0```#W_@``#`````S_```)````&?\```X````C_P``"P```#+_```;````
M/O\```4```!:_P``!P```&#_```$````:/\```8```!M_P``!P```'3_```*
M````?/\```H```"'_P``#0```)+_```8````H/\```H```"Y_P``!````,3_
M```F````R?\```X```#P_P``?````/__```5````?``!``4```"2``$`!P``
M`)@``0`,````H``!``@```"M``$`"@```+8``0`&````P0`!``@```#(``$`
M`@```-$``0`&````U``!``8```#;``$`%````.(``0`5````]P`!``\````-
M`0$`$0```!T!`0`:````+P$!``P```!*`0$`#0```%<!`0`0````90$!`!L`
M``!V`0$`!````)(!`0`)````EP$!`!````"A`0$`"0```+(!`0`)````O`$!
M``4```#&`0$`&@```,P!`0`(````YP$!``8```#P`0$`&0```/<!`0`.````
M$0(!``<````@`@$`!P```"@"`0`%````,`(!``D````V`@$`"@```$`"`0`3
M````2P(!``X```!?`@$``@```&X"`0`&````<0(!``L```!X`@$`#0```(0"
M`0`)````D@(!``8```"<`@$`!0```*,"`0`)````J0(!``<```"S`@$`!```
M`+L"`0`%````P`(!`!0```#&`@$`0@```-L"`0`E````'@,!`"4```!$`P$`
M!@```&H#`0`$````<0,!``D```!V`P$`"````(`#`0`1````B0,!``X```";
M`P$`"0```*H#`0`&````M`,!``T```"[`P$`!@```,D#`0`$````T`,!`#D`
M``#5`P$`/0````\$`0`Z````300!`!X```"(!`$`!0```*<$`0`.````K00!
M``0```"\!`$`!@```,$$`0`'````R`0!`"$```#0!`$`#0```/($`0`5````
M``4!``8````6!0$`$@```!T%`0`$````,`4!`!$````U!0$`!@```$<%`0`*
M````3@4!`"(```!9!0$`!````'P%`0`%````@04!``0```"'!0$`#````(P%
M`0`)````F04!``P```"C!0$`#@```+`%`0`*````OP4!`!````#*!0$`$P``
M`-L%`0`3````[P4!``@````#!@$`"0````P&`0`%````%@8!`#H````<!@$`
M,````%<&`0`U````B`8!`"D```"^!@$`1P```.@&`0`X````,`<!`"D```!I
M!P$`/P```),'`0`N````TP<!`"T````""`$`'P```#`(`0`/````4`@!`!(`
M``!@"`$`"P```',(`0`F````?P@!`"D```"F"`$`)````-`(`0`F````]0@!
M``@````<"0$`"@```"4)`0`)````,`D!``<````Z"0$`(````$()`0`@````
M8PD!`"8```"$"0$`!````*L)`0`@````L`D!``H```#1"0$`&0```-P)`0`I
M````]@D!`!8````@"@$`$@```#<*`0`'````2@H!``H```!2"@$`#````%T*
M`0`/````:@H!`!````!Z"@$`0````(L*`0!P````S`H!`&8````]"P$`#@``
M`*0+`0`)````LPL!``H```"]"P$`$@```,@+`0`3````VPL!``P```#O"P$`
M!@```/P+`0`<`````PP!``\````@#`$`&P```#`,`0`2````3`P!`!````!?
M#`$`"@```'`,`0`1````>PP!`!P```"-#`$`(P```*H,`0!J````S@P!``\`
M```Y#0$`!0```$D-`0`0````3PT!``D```!@#0$`!````&H-`0`+````;PT!
M`"````![#0$`%````)P-`0`,````L0T!``P```"^#0$`#P```,L-`0`5````
MVPT!`"D```#Q#0$`*@```!L.`0`F````1@X!`"<```!M#@$`*0```)4.`0`J
M````OPX!`!D```#J#@$`$0````0/`0`2````%@\!`!,````I#P$`%````#T/
M`0`/````4@\!`!8```!B#P$`%P```'D/`0`0````D0\!`!$```"B#P$`-```
M`+0/`0`3````Z0\!`!(```#]#P$`-0```!`0`0`4````1A`!``<```!;$`$`
M#````&,0`0`K````<!`!``H```"<$`$`(````*<0`0`0````R!`!`!0```#9
M$`$`%````.X0`0`1`````Q$!`!<````5$0$`'````"T1`0`-````2A$!``T`
M``!8$0$`$P```&81`0`6````>A$!`!0```"1$0$`&@```*81`0`1````P1$!
M``P```#3$0$`$````.`1`0`:````\1$!`!X````,$@$`&@```"L2`0`3````
M1A(!`!4```!:$@$`$0```'`2`0`7````@A(!`!0```":$@$`%P```*\2`0`5
M````QQ(!``D```#=$@$`$````.<2`0`9````^!(!``0````2$P$`!P```!<3
M`0`+````'Q,!`!$````K$P$`!@```#T3`0`&````1!,!``8```!+$P$`!0``
M`%(3`0`'````6!,!``<```!@$P$`!0```&@3`0`6````;A,!``8```"%$P$`
M!@```(P3`0`$````DQ,!``0```"8$P$`!P```)T3`0`.````I1,!``P```"T
M$P$`#````,$3`0`-````SA,!``4```#<$P$`*````.(3`0`,````"Q0!``\`
M```8%`$`"@```"@4`0`(````,Q0!``D````\%`$`*P```$84`0`$````<A0!
M``@```!W%`$`!0```(`4`0`F````AA0!`!(```"M%`$`#P```,`4`0`&````
MT!0!``H```#7%`$`3````.(4`0`'````+Q4!``@````W%0$`(````$`5`0`)
M````814!``T```!K%0$`"0```'D5`0`4````@Q4!``P```"8%0$`#0```*45
M`0`.````LQ4!`!8```#"%0$`$0```-D5`0`&````ZQ4!``@```#R%0$``P``
M`/L5`0`&````_Q4!`!D````&%@$`!P```"`6`0`$````*!8!``L````M%@$`
M"P```#D6`0`'````118!``4```!-%@$`!P```%,6`0`6````6Q8!``T```!R
M%@$`"@```(`6`0`-````BQ8!``H```"9%@$`$````*06`0`/````M18!`!$`
M``#%%@$`%P```-<6`0`*````[Q8!`!$```#Z%@$`"`````P7`0`$````%1<!
M``L````:%P$`#@```"87`0`/````-1<!`#H```!%%P$`!0```(`7`0`,````
MAA<!``0```"3%P$`'@```)@7`0`.````MQ<!`!````#&%P$`"P```-<7`0`,
M````XQ<!``D```#P%P$`!P```/H7`0`*`````A@!``D````-&`$`#@```!<8
M`0`0````)A@!`!L````W&`$`&````%,8`0`:````;!@!``H```"'&`$`"0``
M`)(8`0`*````G!@!``P```"G&`$`#P```+08`0`(````Q!@!``8```#-&`$`
M!P```-08`0`%````W!@!``L```#B&`$`1P```.X8`0`-````-AD!``D```!$
M&0$`!````$X9`0`#````4QD!`!,```!7&0$`$P```&L9`0`3````?QD!``8`
M``"3&0$`"P```)H9`0`*````IAD!``(```"Q&0$`!````+09`0`E````N1D!
M``,```#?&0$`!0```.,9`0`J````Z1D!``H````4&@$`!0```!\:`0`$````
M)1H!``H````J&@$`#0```#4:`0`&````0QH!``@```!*&@$`"````%,:`0`$
M````7!H!``4```!A&@$`:````&<:`0`)````T!H!``P```#:&@$`$````.<:
M`0`%````^!H!``8```#^&@$`&P````4;`0`O````(1L!`!````!1&P$`"@``
M`&(;`0`(````;1L!``\```!V&P$`"@```(8;`0`)````D1L!`!,```";&P$`
M&P```*\;`0`8````RQL!`!<```#D&P$`&@```/P;`0`?````%QP!``X````W
M'`$`%P```$8<`0`#````7AP!``<```!B'`$`"````&H<`0`4````<QP!`!,`
M``"('`$`$````)P<`0`-````K1P!``X```"['`$`%@```,H<`0`'````X1P!
M``D```#I'`$`"@```/,<`0`+````_AP!``<````*'0$`40```!(=`0`0````
M9!T!``P```!U'0$`#0```((=`0`:````D!T!`$H```"K'0$`&0```/8=`0`&
M````$!X!`!H````7'@$`)0```#(>`0`&````6!X!``8```!?'@$`'P```&8>
M`0`&````AAX!``D```"-'@$`&````)<>`0`7````L!X!`"@```#('@$`!@``
M`/$>`0`-````^!X!`"@````&'P$`(@```"\?`0!7````4A\!`!,```"J'P$`
M(P```+X?`0`3````XA\!``(```#V'P$`"P```/D?`0`,````!2`!``@````2
M(`$`#0```!L@`0`*````*2`!`!8````T(`$`!P```$L@`0`4````4R`!``8`
M``!H(`$`"````&\@`0`.````>"`!``<```"'(`$`"@```(\@`0`+````FB`!
M`#(```"F(`$`%P```-D@`0`'````\2`!``P```#Y(`$`#0````8A`0`,````
M%"$!``0````A(0$`"0```"8A`0`)````,"$!``H````Z(0$`!P```$4A`0`)
M````32$!``D```!7(0$`"@```&$A`0`'````;"$!``H```!T(0$`!P```'\A
M`0`5````AR$!`!L```"=(0$`#P```+DA`0!)````R2$!`!(````3(@$`"@``
M`"8B`0`6````,2(!``\```!((@$`$````%@B`0`)````:2(!`!````!S(@$`
M!P```(0B`0`2````C"(!``0```"?(@$`"P```*0B`0`'````L"(!``4```"X
M(@$`!````+XB`0`,````PR(!``4```#0(@$`&@```-8B`0`+````\2(!`!0`
M``#](@$`$0```!(C`0`4````)",!`!<````Y(P$`&````%$C`0`<````:B,!
M`!D```"'(P$`!P```*$C`0`%````J2,!``T```"O(P$`#````+TC`0`+````
MRB,!`!$```#6(P$`"````.@C`0`7````\2,!``L````))`$`#````!4D`0`?
M````(B0!`!H```!")`$`$P```%TD`0`$````<20!``H```!V)`$`!````($D
M`0`-````AB0!``P```"4)`$`!0```*$D`0`)````IR0!``@```"Q)`$`!0``
M`+HD`0`'````P"0!``4```#()`$`!````,XD`0`"````TR0!`!@```#6)`$`
M%P```.\D`0`X````!R4!`"P```!`)0$`$@```&TE`0`I````@"4!`#(```"J
M)0$`"@```-TE`0`L````Z"4!`"X````5)@$`,P```$0F`0`S````>"8!`#@`
M``"L)@$`$0```.4F`0`/````]R8!`!0````')P$`&````!PG`0`0````-2<!
M``\```!&)P$`$P```%8G`0`5````:B<!`!0```"`)P$`$@```)4G`0`4````
MJ"<!`!4```"])P$`+0```-,G`0`M`````2@!`#$````O*`$`+@```&$H`0`O
M````D"@!`"P```#`*`$`$P```.TH`0`,`````2D!``T````.*0$`"````!PI
M`0`7````)2D!``@````]*0$`#````$8I`0`K````4RD!`"$```!_*0$`&```
M`*$I`0`:````NBD!``D```#5*0$`10```-\I`0!!````)2H!``\```!G*@$`
M!````'<J`0`3````?"H!``X```"0*@$`$P```)\J`0`8````LRH!``8```#,
M*@$`"0```-,J`0`*````W2H!``\```#H*@$`$````/@J`0`'````"2L!``X`
M```1*P$`!0```"`K`0`;````)BL!``8```!"*P$`"````$DK`0`&````4BL!
M`!0```!9*P$`$0```&XK`0`8````@"L!``X```"9*P$`.````*@K`0`"````
MX2L!``8```#D*P$`#@```.LK`0`0````^BL!``4````++`$`!P```!$L`0`.
M````&2P!``8````H+`$`*````"\L`0`,````6"P!`!P```!E+`$`!````((L
M`0":````ARP!`"D````B+0$`%P```$PM`0`?````9"T!`!D```"$+0$`7```
M`)XM`0`4````^RT!`#X````0+@$`'P```$\N`0`0````;RX!`!0```"`+@$`
M!P```)4N`0`.````G2X!``P```"L+@$`#````+DN`0`3````QBX!``H```#:
M+@$`'0```.4N`0`9`````R\!``4````=+P$`$0```",O`0`-````-2\!`!$`
M``!#+P$`)````%4O`0`2````>B\!`!4```"-+P$`$@```*,O`0`.````MB\!
M`!D```#%+P$`"````-\O`0`)````Z"\!``T```#R+P$`!P`````P`0`*````
M"#`!``<````3,`$`#P```!LP`0`&````*S`!``L````R,`$`&@```#XP`0`*
M````63`!``<```!D,`$`"````&PP`0`%````=3`!`!\```![,`$`!@```)LP
M`0`0````HC`!``@```"S,`$`#0```+PP`0`(````RC`!`!X```#3,`$`$@``
M`/(P`0`L````!3$!`!H````R,0$`"0```$TQ`0`*````5S$!`!4```!B,0$`
M!0```'@Q`0`4````?C$!``0```"3,0$`$````)@Q`0`&````J3$!``<```"P
M,0$`'@```+@Q`0`H````US$!``H`````,@$`'`````LR`0`1````*#(!`!$`
M```Z,@$`"P```$PR`0`:````6#(!`!0```!S,@$`!````(@R`0`$````C3(!
M``L```"2,@$`!0```)XR`0`&````I#(!`!$```"K,@$`"````+TR`0`&````
MQC(!``H```#-,@$`&P```-@R`0`T````]#(!`#0````I,P$`(````%XS`0`I
M````?S,!`"````"I,P$`00```,HS`0`:````##0!`"$````G-`$`*````$DT
M`0`I````<C0!`%$```"<-`$`4````.XT`0!7````/S4!`"P```"7-0$`%0``
M`,0U`0`B````VC4!``8```#]-0$`"`````0V`0`%````#38!``@````3-@$`
M&0```!PV`0`9````-C8!`"H```!0-@$`"````'LV`0`C````A#8!`!D```"H
M-@$`+@```,(V`0`T````\38!``@````F-P$`%P```"\W`0`*````1S<!``<`
M``!2-P$`(0```%HW`0`(````?#<!`!````"%-P$`#@```)8W`0`4````I3<!
M``L```"Z-P$`!P```,8W`0`3````SC<!``@```#B-P$`"P```.LW`0`*````
M]S<!`!0````".`$`#P```!<X`0`R````)S@!``L```!:.`$`#@```&8X`0`%
M````=3@!``4```![.`$`%0```($X`0`,````ES@!``4```"D.`$`%P```*HX
M`0`/````PC@!``0```#2.`$`"@```-<X`0`)````XC@!``L```#L.`$`#0``
M`/@X`0`,````!CD!``X````3.0$`!0```"(Y`0`$````*#D!`!0````M.0$`
M#0```$(Y`0`B````4#D!`#(```!S.0$`&P```*8Y`0!%````PCD!`!(````(
M.@$`%P```!LZ`0`'````,SH!`!X````[.@$`%````%HZ`0`%````;SH!`!0`
M``!U.@$`!@```(HZ`0`'````D3H!`",```"9.@$`#@```+TZ`0`J````S#H!
M``8```#W.@$`#````/XZ`0`3````"SL!``T````?.P$`$0```"T[`0`7````
M/SL!`!4```!7.P$`"P```&T[`0`V````>3L!``H```"P.P$`(@```+L[`0`+
M````WCL!``\```#J.P$`A0```/H[`0`+````@#P!`"````",/`$`)P```*T\
M`0`K````U3P!``D````!/0$`,@````L]`0`;````/CT!`"4```!:/0$`,```
M`(`]`0`Q````L3T!`"T```#C/0$`#@```!$^`0`4````(#X!``4````U/@$`
M#@```#L^`0`3````2CX!`!$```!>/@$`$@```'`^`0`'````@SX!`!$```"+
M/@$`$P```)T^`0`'````L3X!`!0```"Y/@$`&````,X^`0`'````YSX!``4`
M``#O/@$`#````/4^`0`,`````C\!`!(````//P$`!````"(_`0`'````)S\!
M``H````O/P$`"P```#H_`0`,````1C\!``X```!3/P$`#@```&(_`0`%````
M<3\!``4```!W/P$`+@```'T_`0`F````K#\!`",```#3/P$``P```/<_`0`2
M````^S\!``8````.0`$`'@```!5``0`8````-$`!`!D```!-0`$`)0```&=`
M`0`-````C4`!``D```";0`$`'P```*5``0`#````Q4`!`!@```#)0`$`!P``
M`.)``0`*````ZD`!``(```#U0`$`#````/A``0`5````!4$!``L````;00$`
M&0```"=!`0`@````04$!`!(```!B00$`!0```'5!`0`*````>T$!`!4```"&
M00$`$@```)Q!`0`,````KT$!``0```"\00$`"0```,%!`0`'````RT$!``P`
M``#300$`4@```.!!`0`7````,T(!`"0```!+0@$`(0```'!"`0`2````DD(!
M``<```"E0@$`!@```*U"`0`.````M$(!``T```##0@$`$0```-%"`0`;````
MXT(!``P```#_0@$`!@````Q#`0`3````$T,!``P````G0P$`#0```#1#`0`5
M````0D,!`!(```!80P$`#P```&M#`0`4````>T,!``H```"00P$`&P```)M#
M`0`@````MT,!`!X```#80P$`$````/=#`0`+````"$0!`"<````41`$`)0``
M`#Q$`0!I````8D0!`"8```#,1`$`&@```/-$`0`7````#D4!`!D````F10$`
M&@```$!%`0`E````6T4!`"@```"!10$`)P```*I%`0`:````TD4!`!<```#M
M10$`&P````5&`0!$````(48!`#0```!F1@$`)0```)M&`0`9````P48!`!\`
M``#;1@$`&P```/M&`0`7````%T<!`!,````O1P$`"````$-'`0`'````3$<!
M``@```!41P$`"0```%U'`0`5````9T<!``T```!]1P$`(P```(M'`0`-````
MKT<!`!,```"]1P$`"````-%'`0`#````VD<!`$8```#>1P$`/P```"5(`0`W
M````94@!`%<```"=2`$`!0```/5(`0`?````^T@!`"\````;20$`"@```$M)
M`0`0````5DD!``@```!G20$`#0```'!)`0`M````?DD!``0```"L20$`!P``
M`+%)`0`(````N4D!``T```#"20$`"@```-!)`0!/````VTD!`"4````K2@$`
M'````%%*`0`+````;DH!`!\```!Z2@$`'0```)I*`0`E````N$H!`"````#>
M2@$`)````/]*`0`@````)$L!``L```!%2P$`!P```%%+`0`-````64L!``P`
M``!G2P$`%P```'1+`0`&````C$L!`#D```"32P$`#````,U+`0`'````VDL!
M``D```#B2P$`$P```.Q+`0`'`````$P!``D````(3`$`!````!),`0`0````
M%TP!``@````H3`$`"````#%,`0`$````.DP!``L````_3`$`#````$M,`0`2
M````6$P!`!$```!K3`$`#````'U,`0`:````BDP!``\```"E3`$`!P```+5,
M`0`-````O4P!``X```#+3`$`%````-I,`0`.````[TP!``<```#^3`$`#```
M``9-`0`L````$TT!`!,```!`30$`'````%1-`0`H````<4T!``8```":30$`
M!P```*%-`0`3````J4T!``4```"]30$`!````,--`0`7````R$T!`#D```#@
M30$`"@```!I.`0`,````)4X!``D````R3@$`!@```#Q.`0`)````0TX!``@`
M``!-3@$`"0```%9.`0`%````8$X!``H```!F3@$`$0```'%.`0`&````@TX!
M``X```"*3@$`#@```)E.`0`-````J$X!``L```"V3@$`'0```,).`0`+````
MX$X!``(```#L3@$`'````.].`0`'````#$\!``8````43P$`9````!M/`0`)
M````@$\!``<```"*3P$`)@```))/`0`I````N4\!`!L```#C3P$`.````/]/
M`0`K````.%`!`!H```!D4`$`(P```']0`0`J````HU`!`"T```#.4`$`.P``
M`/Q0`0`H````.%$!`#0```!A40$`&0```)91`0`5````L%$!``4```#&40$`
M!P```,Q1`0`(````U%$!``<```#=40$`!0```.51`0`'````ZU$!``X```#S
M40$`"0````)2`0`&````#%(!``@````34@$`"P```!Q2`0`'````*%(!``@`
M```P4@$`!P```#E2`0`6````05(!``D```!84@$`!@```&)2`0`+````:5(!
M`!````!U4@$`!@```(92`0`<````C5(!`!0```"J4@$`!P```+]2`0`1````
MQU(!``@```#94@$`#@```.)2`0`#````\5(!``@```#U4@$`%````/Y2`0`%
M````$U,!`!`````94P$`"0```"I3`0`0````-%,!``8```!%4P$`&0```$Q3
M`0`*````9E,!`!P```!Q4P$`!P```(Y3`0`%````EE,!``0```"<4P$`$```
M`*%3`0`4````LE,!``L```#'4P$`#0```--3`0`H````X5,!`!@````*5`$`
M%P```"-4`0`:````.U0!`!0```!65`$`!````&M4`0`)````<%0!``H```!Z
M5`$`!P```(54`0`"````C50!``X```"05`$`"````)]4`0`?````J%0!`",`
M``#(5`$`(P```.Q4`0`?````$%4!`#@````P50$`)@```&E5`0`Q````D%4!
M`"<```#"50$`1````.I5`0`E````+U8!`"\```!55@$`+P```(56`0`O````
MM58!`"@```#E5@$`9`````Y7`0`4````<U<!`!P```"(5P$`50```*57`0`X
M````^U<!`"D````T6`$`2@```%Y8`0!;````J5@!`"@````%60$`.````"Y9
M`0`J````9UD!`"P```"260$`*````+]9`0`L````Z%D!`"<````56@$`)@``
M`#U:`0`;````9%H!`#X```"`6@$`(P```+]:`0`P````XUH!`!<````46P$`
M&0```"Q;`0!(````1EL!`(4```"/6P$`,````!5<`0`E````1EP!`$$```!L
M7`$`6P```*Y<`0!)````"ET!`#$```!470$`'0```(9=`0`8````I%T!`"L`
M``"]70$`(0```.E=`0`?````"UX!`"L````K7@$`)@```%=>`0`A````?EX!
M`"D```"@7@$`)P```,I>`0`Z````\EX!`!T````M7P$`$0```$M?`0`S````
M75\!`"4```"17P$`.````+=?`0`G````\%\!`"`````88`$`)@```#E@`0`?
M````8&`!`#````"`8`$`S````+%@`0!I````?F$!`#$```#H80$`00```!IB
M`0`S````7&(!`"4```"08@$`/0```+9B`0!E````]&(!`$T```!:8P$`7@``
M`*AC`0`G````!V0!`#$````O9`$`/@```&%D`0`L````H&0!`"8```#-9`$`
M+P```/1D`0`N````)&4!`"D```!390$`*P```'UE`0`P````J64!`"H```#:
M90$`/@````5F`0!4````1&8!`%H```"99@$`,0```/1F`0!(````)F<!`$H`
M``!O9P$`,0```+IG`0`J````[&<!`"(````7:`$`+P```#IH`0`I````:F@!
M`#(```"4:`$`'0```,=H`0`C````Y6@!`"\````):0$`+````#EI`0`M````
M9FD!`'$```"4:0$`9@````9J`0!O````;6H!`+,```#=:@$`%P```)%K`0`E
M````J6L!`#(```#/:P$`*0````)L`0`^````+&P!`"(```!K;`$`4@```(YL
M`0`B````X6P!`"4````$;0$`"P```"IM`0!%````-FT!`"$```!\;0$`-@``
M`)YM`0`P````U6T!`"4````&;@$`'````"QN`0!(````26X!`#$```"2;@$`
M!P```,1N`0`'````S&X!``0```#4;@$`#0```-EN`0`+````YVX!``X```#S
M;@$`"P````)O`0`%````#F\!`!`````4;P$``@```"5O`0!9````*&\!``4`
M``"";P$`$@```(AO`0`$````FV\!``<```"@;P$`"````*AO`0`%````L6\!
M``,```"W;P$`$````+MO`0`,````S&\!`!,```#9;P$`#0```.UO`0`"````
M^V\!``<```#^;P$`!@````9P`0`4````#7`!``P````B<`$`&````"]P`0`&
M````2'`!`!(```!/<`$`#````&)P`0`#````;W`!`"H```!S<`$`!````)YP
M`0`&````HW`!``<```"J<`$`'P```+)P`0`U````TG`!`"X````(<0$`+P``
M`#=Q`0`7````9W$!`!\```!_<0$`(@```)]Q`0`E````PG$!`"````#H<0$`
M&P````ER`0`8````)7(!`"0````^<@$`'P```&-R`0`:````@W(!`"$```">
M<@$`(````,!R`0`P````X7(!`!H````2<P$`,@```"US`0`:````8',!`"\`
M``![<P$`*P```*MS`0`?````UW,!`",```#W<P$`'P```!MT`0`:````.W0!
M`"$```!6=`$`)0```'AT`0`F````GG0!`"4```#%=`$`)````.MT`0`8````
M$'4!`!T````I=0$`)````$=U`0`8````;'4!`"(```"%=0$`+````*AU`0`O
M````U74!`!4````%=@$`)0```!MV`0`\````078!`!\```!^=@$`(P```)YV
M`0`?````PG8!`"````#B=@$`&@````-W`0`8````'G<!`"8````W=P$`'@``
M`%YW`0`I````?7<!`!X```"G=P$`,0```,9W`0`)````^'<!``P````">`$`
M%P````]X`0`O````)W@!`"0```!7>`$`!P```'QX`0`?````A'@!``\```"D
M>`$`%````+1X`0`.````R7@!``T```#8>`$`)````.9X`0`%````"WD!``<`
M```1>0$`(@```!EY`0`E````/'D!`!H```!B>0$`'0```'UY`0`:````FWD!
M``<```"V>0$`QP```+YY`0`+````AGH!`!P```"2>@$`%0```*]Z`0`&````
MQ7H!``D```#,>@$`&````-9Z`0`+````[WH!``T```#[>@$`%P````E[`0`&
M````(7L!`#,````H>P$`$P```%Q[`0`3````<'L!``<```"$>P$`#P```(Q[
M`0`'````G'L!`#(```"D>P$`!````-=[`0`A````W'L!`!,```#^>P$`#```
M`!)\`0`1````'WP!`#(````Q?`$`%@```&1\`0`(````>WP!`!T```"$?`$`
M"0```*)\`0`*````K'P!`!0```"W?`$`"@```,Q\`0`=````UWP!``@```#U
M?`$`'P```/Y\`0`(````'GT!`!H````G?0$`)P```$)]`0`&````:GT!`!4`
M``!Q?0$`!P```(=]`0`(````CWT!``D```"8?0$`/P```*)]`0`2````XGT!
M``<```#U?0$`#P```/U]`0`.````#7X!`!`````<?@$`"0```"U^`0`)````
M-WX!``@```!!?@$`$P```$I^`0`)````7GX!``<```!H?@$`#````'!^`0`9
M````?7X!``H```"7?@$`"@```*)^`0`)````K7X!`!L```"W?@$`%P```--^
M`0`4````ZWX!``H`````?P$`#`````M_`0`7````&'\!``0````P?P$`*@``
M`#5_`0`,````8'\!`!$```!M?P$`!P```']_`0`"````AW\!`!````"*?P$`
M&````)M_`0`+````M'\!``,```#`?P$`"````,1_`0`3````S7\!`!<```#A
M?P$`"P```/E_`0`&````!8`!``<````,@`$`#0```!2``0`+````(H`!`!0`
M```N@`$`%0```$.``0`.````68`!`"\```!H@`$`(````)B``0`<````N8`!
M`!4```#6@`$`#````.R``0`Q````^8`!``4````K@0$`$@```#&!`0`_````
M1($!`!(```"$@0$`"@```)>!`0`&````HH$!``0```"I@0$`!````*Z!`0`*
M````LX$!`!,```"^@0$`!0```-*!`0`&````V($!``8```#?@0$`"````.:!
M`0`$````[X$!``P```#T@0$`"0````&"`0`,````"X(!``H````8@@$`$```
M`"."`0`3````-((!`!,```!(@@$`.0```%R"`0`N````EH(!`"D```#%@@$`
M!0```.^"`0`9````]8(!`!$````/@P$``@```"&#`0`$````)(,!``H````I
M@P$`!@```#2#`0`%````.X,!``,```!!@P$`#````$6#`0!%````4H,!`#(`
M``"8@P$`/````,N#`0`:````"(0!`#4````CA`$`-````%F$`0`H````CH0!
M`#````"WA`$`+P```.B$`0`R````&(4!`!D```!+A0$`<@```&6%`0`@````
MV(4!`#4```#YA0$`(0```"^&`0!%````488!`#````"7A@$`)@```,B&`0`>
M````[X8!`"$````.AP$`*````#"'`0`K````68<!`"D```"%AP$`*0```*^'
M`0`F````V8<!`"4`````B`$`*````":(`0`H````3X@!`"(```!XB`$`*P``
M`)N(`0`N````QX@!`#````#VB`$`$@```">)`0`3````.HD!`!````!.B0$`
M>0```%^)`0`)````V8D!`*$```#CB0$`<P```(6*`0!\````^8H!`"L```!V
MBP$`5````**+`0`7````]XL!`"P````/C`$`)P```#R,`0`6````9(P!``\`
M``![C`$`%P```(N,`0`?````HXP!`$````##C`$`'P````2-`0`<````)(T!
M`%$```!!C0$`&@```).-`0`4````KHT!``H```##C0$`!0```,Z-`0`&````
MU(T!``@```#;C0$`!0```.2-`0`2````ZHT!`!````#]C0$`$P````Z.`0`=
M````(HX!``\```!`C@$`"@```%".`0`/````6XX!``<```!KC@$`!````'..
M`0`)````>(X!``D```""C@$`!P```(R.`0`+````E(X!``<```"@C@$`!0``
M`*B.`0`4````KHX!``X```##C@$`!@```-*.`0`'````V8X!``@```#AC@$`
M#P```.J.`0`1````^HX!``P````,CP$`"````!F/`0`,````(H\!``\````O
MCP$`%@```#^/`0`'````5H\!``8```!>CP$`%````&6/`0`&````>H\!``P`
M``"!CP$`$0```(Z/`0`(````H(\!``0```"ICP$`&0```*Z/`0`1````R(\!
M``H```#:CP$`!0```.6/`0`8````ZX\!`!,````$D`$`"P```!B0`0`,````
M))`!``P````QD`$`#````#Z0`0`<````2Y`!`!$```!HD`$`!````'J0`0`/
M````?Y`!``<```"/D`$`!````)>0`0`$````G)`!`!D```"AD`$`!P```+N0
M`0`"````PY`!``(```#&D`$`$0```,F0`0`)````VY`!``8```#ED`$`$@``
M`.R0`0`7````_Y`!``8````7D0$`)P```!Z1`0`"````1I$!``0```!)D0$`
M#0```$Z1`0`$````7)$!``\```!AD0$`$P```'&1`0`'````A9$!``<```"-
MD0$`$0```)61`0`&````IY$!`!@```"ND0$`!@```,>1`0`3````SI$!`!``
M``#BD0$`$@```/.1`0`"````!I(!``8````)D@$`#````!"2`0`)````'9(!
M`!$````GD@$`$0```#F2`0`;````2Y(!`"(```!GD@$`!P```(J2`0`'````
MDI(!``L```":D@$`!0```*:2`0`"````K)(!``L```"OD@$`C0$``+N2`0!,
M````290!`!$```"6E`$`$@```*B4`0`/````NY0!``X```#+E`$`!P```-J4
M`0`*````XI0!``<```#ME`$`'````/64`0`6````$I4!``0````IE0$`)P``
M`"Z5`0`8````5I4!`!T```!OE0$`+````(V5`0`=````NI4!`"````#8E0$`
M)@```/F5`0`N````()8!`!<```!/E@$`+0```&>6`0`?````E98!`"````"U
ME@$`*````-:6`0`,````_Y8!`"L````,EP$`#@```#B7`0`1````1Y<!`!(`
M``!9EP$`!0```&R7`0`C````<I<!``@```"6EP$`"@```)^7`0`3````JI<!
M``X```"^EP$`#P```,V7`0`+````W9<!`!8```#IEP$`%0````"8`0!#````
M%I@!`"(```!:F`$`,0```'V8`0!O````KY@!``@````?F0$`"@```"B9`0`*
M````,YD!`#<````^F0$`(@```':9`0`0````F9D!`!L```"JF0$`(````,:9
M`0`P````YYD!``T````8F@$`#P```"::`0`3````-IH!`!````!*F@$`!@``
M`%N:`0")````8IH!``L```#LF@$`$0```/B:`0`=````"IL!``H````HFP$`
M$````#.;`0`0````1)L!``D```!5FP$`"P```%^;`0`F````:YL!`"P```"2
MFP$`'````+^;`0`[````W)L!`$4````8G`$`5@```%Z<`0!3````M9P!`%D`
M```)G0$`5@```&.=`0`^````NIT!``X```#YG0$`$P````B>`0`.````')X!
M`!`````KG@$`&````#R>`0`%````59X!``8```!;G@$`"@```&*>`0`%````
M;9X!`!,```!SG@$`!@```(>>`0`&````CIX!`!$```"5G@$`"@```*>>`0`E
M````LIX!`"0```#8G@$`%P```/V>`0`0````%9\!`!(````FGP$`#````#F?
M`0`&````1I\!``@```!-GP$`"0```%:?`0`,````8)\!`!0```!MGP$`&0``
M`(*?`0`.````G)\!`!(```"KGP$`%P```+Z?`0`>````UI\!`",```#UGP$`
M&@```!F@`0`,````-*`!`"8```!!H`$`$````&B@`0`-````>:`!`!<```"'
MH`$`#0```)^@`0`J````K:`!`!@```#8H`$`"0```/&@`0`6````^Z`!`!D`
M```2H0$`$P```"RA`0!/````0*$!`#$```"0H0$`'0```,*A`0`F````X*$!
M`"0````'H@$`!@```"RB`0`)````,Z(!``\````]H@$`#````$VB`0`.````
M6J(!`!L```!IH@$`%0```(6B`0`<````FZ(!`!P```"XH@$`-````-6B`0`.
M````"J,!``8````9HP$`$0```""C`0`*````,J,!``@````]HP$`"````$:C
M`0`%````3Z,!``<```!5HP$`"@```%VC`0`$````:*,!`!P```!MHP$`#```
M`(JC`0`1````EZ,!``\```"IHP$`%0```+FC`0`F````SZ,!``L```#VHP$`
M"P````*D`0`:````#J0!`!T````II`$`(0```$>D`0`8````::0!``\```""
MI`$`$````)*D`0`1````HZ0!`"\```"UI`$`&P```.6D`0`;`````:4!``<`
M```=I0$`!@```"6E`0`(````+*4!``P````UI0$`!````$*E`0`)````1Z4!
M`!,```!1I0$`"P```&6E`0`1````<:4!`!8```"#I0$`'P```)JE`0`'````
MNJ4!`!(```#"I0$`!0```-6E`0`6````VZ4!``\```#RI0$`#`````*F`0`D
M````#Z8!`#,````TI@$`,0```&BF`0!"````FJ8!``D```#=I@$`"````.>F
M`0`4````\*8!``4````%IP$`!0````NG`0`(````$:<!`!`````:IP$`"P``
M`"NG`0`9````-Z<!`#L```!1IP$`$@```(VG`0!&````H*<!`"\```#GIP$`
M-````!>H`0`N````3*@!`"T```![J`$`"0```*FH`0`(````LZ@!``<```"\
MJ`$`"@```,2H`0`)````SZ@!`",```#9J`$`-````/VH`0`B````,JD!`$8`
M``!5J0$`(0```)RI`0`A````OJD!`$,```#@J0$`0@```"2J`0`?````9ZH!
M`$````"'J@$`)P```,BJ`0`J````\*H!`$,````;JP$`(0```%^K`0`G````
M@:L!`"P```"IJP$`&@```-:K`0`>````\:L!`"H````0K`$`*P```#NL`0`K
M````9ZP!`!(```"3K`$`#@```*:L`0`*````M:P!``<```#`K`$`#0```,BL
M`0`(````UJP!``T```#?K`$`'P```.VL`0`C````#:T!``<````QK0$`!P``
M`#FM`0`5````0:T!``H```!7K0$`!@```&*M`0`&````::T!``@```!PK0$`
M!@```'FM`0`I````@*T!``@```"JK0$`!P```+.M`0`+````NZT!``<```#'
MK0$`!@```,^M`0`6````UJT!``4```#MK0$`!P```/.M`0`&````^ZT!`!H`
M```"K@$`"@```!VN`0`G````**X!`!(```!0K@$`"````&.N`0`(````;*X!
M``X```!UK@$``P```(2N`0`'````B*X!``D```"0K@$``P```)JN`0`)````
MGJX!``4```"HK@$`%P```*ZN`0`$````QJX!``@```#+K@$`!@```-2N`0`-
M````VZX!``D```#IK@$`)P```/.N`0`$````&Z\!``4````@KP$`!@```":O
M`0`)````+:\!``H````WKP$`#````$*O`0`,````3Z\!``<```!<KP$`#@``
M`&2O`0`#````<Z\!``,```!WKP$`%P```'NO`0`#````DZ\!`!8```"7KP$`
M)````*ZO`0`(````TZ\!``4```#<KP$`"````.*O`0`'````ZZ\!``H```#S
MKP$`10```/ZO`0`=````1+`!`"D```!BL`$`.````(RP`0`B````Q;`!`!<`
M``#HL`$`!@````"Q`0`&````![$!`!4````.L0$`%0```"2Q`0`?````.K$!
M`"L```!:L0$`&@```(:Q`0`C````H;$!`#$```#%L0$`"0```/>Q`0`&````
M`;(!``@````(L@$`%P```!&R`0`.````*;(!``P````XL@$`$0```$6R`0`.
M````5[(!`!$```!FL@$`#@```'BR`0`,````A[(!`!4```"4L@$`"0```*JR
M`0`<````M+(!`!T```#1L@$`$@```.^R`0`/`````K,!`!(````2LP$`!0``
M`"6S`0`*````*[,!``4````VLP$`$P```#RS`0`7````4+,!`%4```!HLP$`
M8@```+ZS`0`#````(;0!`!,````EM`$`$P```#FT`0`I````3;0!``4```!W
MM`$`!````'VT`0`<````@K0!`!X```"?M`$`$0```+ZT`0`-````T+0!``T`
M``#>M`$`$0```.RT`0`,````_K0!`!$````+M0$`$@```!VU`0`;````,+4!
M`"0```!,M0$`-P```'&U`0`E````J;4!`"T```#/M0$`!0```/VU`0`>````
M`[8!``4````BM@$`%0```"BV`0`+````/K8!`!,```!*M@$`#P```%ZV`0`2
M````;K8!`!,```"!M@$`&````)6V`0`3````KK8!``T```#"M@$`!````-"V
M`0`+````U;8!``@```#AM@$`%P```.JV`0`5`````K<!`!(````8MP$`"```
M`"NW`0`$````-+<!``T````YMP$`!P```$>W`0`)````3[<!`!,```!9MP$`
M#P```&VW`0`8````?;<!``L```"6MP$`%@```**W`0`J````N;<!``@```#D
MMP$`#P```.VW`0`)````_;<!``0````'N`$`!P````RX`0`'````%+@!``\`
M```<N`$`"````"RX`0`5````-;@!``<```!+N`$`!0```%.X`0`%````6;@!
M`!@```!?N`$`4````'BX`0`A````R;@!``X```#KN`$`$0```/JX`0`%````
M#+D!``4````2N0$`&0```!BY`0`:````,KD!`"<```!-N0$`(P```'6Y`0`L
M````F;D!`#0```#&N0$`*````/NY`0`,````)+H!``L````QN@$`"0```#VZ
M`0`6````1[H!`"4```!>N@$`(@```(2Z`0`/````I[H!``@```"WN@$`#```
M`,"Z`0`&````S;H!``<```#4N@$`&@```-RZ`0`1````][H!``H````)NP$`
M"P```!2[`0`*````(+L!``\````KNP$`(0```#N[`0`B````7;L!`"````"`
MNP$`(0```*&[`0`D````P[L!`",```#HNP$`'P````R\`0`F````++P!`"$`
M``!3O`$`)````'6\`0`I````FKP!`"4```#$O`$`'0```.J\`0`>````"+T!
M`"`````GO0$`&P```$B]`0`F````9+T!`"T```"+O0$`*P```+F]`0`B````
MY;T!`"L````(O@$`-P```#2^`0`=````;+X!`!T```"*O@$`&0```*B^`0`9
M````PKX!`#````#<O@$`(0````V_`0`2````+[\!`"$```!"OP$`*````&2_
M`0`:````C;\!`!@```"HOP$`'@```,&_`0`1````X+\!`+8```#ROP$`$@``
M`*G``0`<````O,`!`"4```#9P`$`)@```/_``0`@````)L$!`"0```!'P0$`
M&@```&S!`0`:````A\$!`"0```"BP0$`)````,?!`0`K````[,$!`"P````8
MP@$`)P```$7"`0",````;<(!`!\```#ZP@$`%0```!K#`0`5````,,,!`!X`
M``!&PP$`*0```&7#`0`I````C\,!`$0```"YPP$`1````/[#`0`+````0\0!
M``0```!/Q`$`!@```%3$`0`%````6\0!``\```!AQ`$`"@```''$`0`8````
M?,0!``@```"5Q`$`#P```)[$`0`&````KL0!`!8```"UQ`$`$0```,S$`0`(
M````WL0!``0```#GQ`$`$````.S$`0`/````_<0!``L````-Q0$`#@```!G%
M`0`0````*,4!``X````YQ0$`$@```$C%`0`,````6\4!`#8```!HQ0$`"```
M`)_%`0`+````J,4!``8```"TQ0$`$@```+O%`0`8````SL4!`!L```#GQ0$`
M"`````/&`0`"````#,8!``8````/Q@$`$@```!;&`0`.````*<8!``4````X
MQ@$`#@```#[&`0`(````3<8!``,```!6Q@$`#@```%K&`0`(````:<8!``D`
M``!RQ@$`!@```'S&`0`-````@\8!``<```"1Q@$`#````)G&`0`1````IL8!
M``P```"XQ@$`&P```,7&`0`,````X<8!`!$```#NQ@$`"0````#'`0`&````
M"L<!`!`````1QP$`"P```"+'`0`2````+L<!``P```!!QP$`"P```$['`0`1
M````6L<!`!P```!LQP$`&P```(G'`0`+````I<<!``T```"QQP$`'P```+_'
M`0`>````W\<!`!0```#^QP$`&@```!/(`0`Q````+L@!``H```!@R`$`%0``
M`&O(`0`2````@<@!`!4```"4R`$`$@```*K(`0`5````O<@!`"0```#3R`$`
M,````/C(`0`5````*<D!``L````_R0$`!P```$O)`0`-````4\D!`"L```!A
MR0$`"0```(W)`0`(````E\D!`!$```"@R0$`"P```++)`0`B````OLD!`"\`
M``#AR0$`"@```!'*`0`)````',H!`!X````FR@$`"P```$7*`0`;````4<H!
M`!L```!MR@$`!P```(G*`0`$````D<H!`!<```"6R@$`%0```*[*`0`<````
MQ,H!`!<```#AR@$`#@```/G*`0`*````",L!``@````3RP$`"P```!S+`0`B
M````*,L!`"0```!+RP$`.0```'#+`0`7````JLL!`",```#"RP$`!0```.;+
M`0`(````[,L!`"T```#URP$`#P```"/,`0`*````,\P!``8````^S`$`!@``
M`$7,`0!6````3,P!``,```"CS`$`!P```*?,`0`%````K\P!``H```"US`$`
M%0```,#,`0`+````ULP!``L```#BS`$`$````.[,`0`2````_\P!`!D````2
MS0$`$0```"S-`0`8````/LT!`!L```!7S0$`&P```'/-`0`*````C\T!``<`
M``":S0$`"P```*+-`0`*````KLT!``(```"YS0$`!@```+S-`0`,````P\T!
M`"4```#0S0$`(````/;-`0`6````%\X!``P````NS@$`$````#O.`0`.````
M3,X!`!````!;S@$`!````&S.`0`'````<<X!``\```!YS@$`(0```(G.`0`8
M````J\X!`$P```#$S@$`&0```!'/`0`#````*\\!`#@````OSP$`1````&C/
M`0`=````K<\!`",```#+SP$`+P```._/`0`L````']`!`"L```!,T`$`'```
M`'C0`0`O````E=`!`#,```#%T`$`(0```/G0`0`I````&]$!`",```!%T0$`
M%P```&G1`0`:````@=$!``<```"<T0$`"````*31`0`&````K=$!``8```"T
MT0$`#@```+O1`0`.````RM$!``\```#9T0$`#0```.G1`0`0````]]$!``\`
M```(T@$`"P```!C2`0`2````)-(!``,````WT@$`#P```#O2`0`)````2](!
M`!(```!5T@$`#@```&C2`0`O````=](!``T```"GT@$`"````+72`0`)````
MOM(!`!,```#(T@$`)0```-S2`0`G`````M,!``T````JTP$`(````#C3`0`E
M````6=,!`"(```!_TP$`*@```*+3`0`<````S=,!`!\```#JTP$`3@````K4
M`0`F````6=0!`"4```"`U`$`(P```*;4`0`C````RM0!`"L```#NU`$`+@``
M`!K5`0`B````2=4!`!H```!LU0$`'0```(?5`0`E````I=4!``,```#+U0$`
M#@```,_5`0`(````WM4!``L```#GU0$``P```//5`0`%````]]4!``@```#]
MU0$`"0````;6`0`+````$-8!``\````<U@$`$@```"S6`0`*````/]8!``X`
M``!*U@$`#@```%G6`0`$````:-8!``,```!MU@$`$P```''6`0`5````A=8!
M``P```";U@$`!P```*C6`0`&````L-8!``X```"WU@$`&@```,;6`0`%````
MX=8!``8```#GU@$``P```.[6`0`'````\M8!``<```#ZU@$`#0````+7`0`'
M````$-<!``X````8UP$`%P```"?7`0`(````/]<!``,```!(UP$`)0```$S7
M`0`-````<M<!`$X```"`UP$`%````,_7`0`(````Y-<!``H```#MUP$`$0``
M`/C7`0`*````"M@!``P````5V`$`!0```"+8`0`.````*-@!``(````WV`$`
M!0```#K8`0`)````0-@!`!,```!*V`$`&@```%[8`0`3````>=@!`!@```"-
MV`$`(````*;8`0`2````Q]@!``X```#:V`$`$@```.G8`0`9````_-@!``0`
M```6V0$`"0```!O9`0`7````)=D!``@````]V0$`$0```$;9`0`%````6-D!
M`!@```!>V0$`"````'?9`0`&````@-D!`!T```"'V0$`#0```*79`0`(````
ML]D!``@```"\V0$`!0```,79`0`)````R]D!``<```#5V0$`$````-W9`0`5
M````[MD!``(````$V@$`!@````?:`0`,````#MH!``T````;V@$`"````"G:
M`0`4````,MH!``0```!'V@$`"````$S:`0`'````5=H!``,```!=V@$`!0``
M`&':`0`3````9]H!`#T```![V@$`)@```+G:`0`I````X-H!``<````*VP$`
M!````!+;`0`)````%]L!``@````AVP$`$````"K;`0`3````.]L!``<```!/
MVP$`!@```%?;`0`-````7ML!``8```!LVP$`!````'/;`0`Q````>-L!`#8`
M``"JVP$`,P```.';`0`:````%=P!``4````PW`$`#````#;<`0`%````0]P!
M``8```!)W`$`"````%#<`0`8````6=P!`!(```!RW`$`%P```(7<`0`$````
MG=P!``T```"BW`$`!0```+#<`0`1````MMP!``T```#(W`$`"````-;<`0`7
M````W]P!``,```#WW`$`!````/O<`0`#`````-T!``L````$W0$`"````!#=
M`0`)````&=T!``H````CW0$`#````"[=`0`+````.]T!``L```!'W0$`#P``
M`%/=`0`(````8]T!``D```!LW0$`!0```';=`0`]````?-T!`#$```"ZW0$`
M/P```.S=`0`=````+-X!`$$```!*W@$`-P```(S>`0`H````Q-X!`#D```#M
MW@$`+@```"??`0`R````5M\!`"$```")WP$`$0```*O?`0`5````O=\!``P`
M``#3WP$`+P```.#?`0`D````$.`!`"0````UX`$`(P```%K@`0`)````?N`!
M``H```"(X`$`"@```)/@`0`&````GN`!`"4```"EX`$`)@```,O@`0`P````
M\N`!``0````CX0$`(````"CA`0`)````2>$!`!X```!3X0$`*@```'+A`0`:
M````G>$!`!````"XX0$`!@```,GA`0`-````T.$!``T```#>X0$`#P```.SA
M`0`2````_.$!`#L````/X@$`D0```$OB`0!D````W>(!`!4```!"XP$`"@``
M`%CC`0`+````8^,!`!$```!OXP$`$@```('C`0`.````E.,!``8```"CXP$`
M'````*KC`0`2````Q^,!`"````#:XP$`%````/OC`0`1````$.0!``@````B
MY`$`$0```"OD`0`D````/>0!`"H```!BY`$`;@```(WD`0`*````_.0!``8`
M```'Y0$`%@````[E`0`*````)>4!``0````PY0$`"P```#7E`0`G````0>4!
M`!0```!IY0$`"P```'[E`0`-````BN4!``\```"8Y0$`$P```*CE`0`E````
MO.4!`"0```#BY0$`'`````?F`0`>````).8!`"$```!#Y@$`(````&7F`0`6
M````AN8!`!$```"=Y@$`$````*_F`0`3````P.8!`!(```#4Y@$`$@```.?F
M`0`5````^N8!`!0````0YP$`$````"7G`0`/````-N<!`"D```!&YP$`$0``
M`'#G`0`1````@N<!`#L```"4YP$`%````-#G`0`&````Y><!``P```#LYP$`
M)P```/GG`0`,````(>@!`"$````NZ`$`%@```%#H`0`2````9^@!`!4```!Z
MZ`$`$@```)#H`0`6````H^@!`!P```"ZZ`$`%````-?H`0`/````[.@!`!,`
M``#\Z`$`&````!#I`0`5````*>D!`!H````_Z0$`&````%KI`0`.````<^D!
M`!(```""Z0$`'0```)7I`0`A````L^D!`"$```#5Z0$`%0```/?I`0`4````
M#>H!`!0````BZ@$`&````#?J`0`:````4.H!`!@```!KZ@$`%@```(3J`0`+
M````F^H!``\```"GZ@$`!````+?J`0`$````O.H!``8```#!Z@$`"P```,CJ
M`0`1````U.H!``8```#FZ@$`"P```.WJ`0`&````^>H!``<`````ZP$`!P``
M``CK`0`'````$.L!``4````8ZP$`%0```![K`0`&````-.L!``D````[ZP$`
M!````$7K`0`$````2NL!``<```!/ZP$`#0```%?K`0`,````9>L!``X```!R
MZP$`#````('K`0`%````CNL!`"D```"4ZP$`#0```+[K`0`+````S.L!``L`
M``#8ZP$`"0```.3K`0`0````[NL!`#````#_ZP$`!````##L`0`(````->P!
M``4````^[`$`"0```$3L`0`(````3NP!`!$```!7[`$`!@```&GL`0`)````
M<.P!`$,```!Z[`$`!P```+[L`0`%````QNP!``0```#,[`$`#````-'L`0`-
M````WNP!``D```#L[`$`$0```/;L`0`/````".T!`!(````8[0$`%@```"OM
M`0`>````0NT!`!H```!A[0$`"````'SM`0`(````A>T!``,```".[0$`!@``
M`)+M`0`E````F>T!``<```"_[0$`!P```,?M`0`-````S^T!``T```#=[0$`
M!P```.OM`0`$````\^T!``<```#X[0$`!@````#N`0`-````!^X!``<````5
M[@$`"````!WN`0`)````)NX!`!,````P[@$`%0```$3N`0`-````6NX!`!(`
M``!H[@$`"````'ON`0`,````A.X!``@```"1[@$`!````)KN`0`0````G^X!
M``X```"P[@$`$````+_N`0!"````T.X!``8````3[P$`!````!KO`0`%````
M'^\!`!\````E[P$`#@```$7O`0`/````5.\!``X```!D[P$`#````'/O`0`)
M````@.\!``<```"*[P$`"@```)+O`0`)````G>\!``X```"G[P$`$````+;O
M`0`E````Q^\!`"4```#M[P$`(@```!/P`0`*````-O`!``<```!!\`$`"0``
M`$GP`0`+````4_`!``D```!?\`$`!0```&GP`0`(````;_`!``@```!X\`$`
M!0```('P`0`0````A_`!`$X```"8\`$`&````.?P`0`)`````/$!``8````*
M\0$``P```!'Q`0`0````%?$!`!`````F\0$`%````#?Q`0`&````3/$!``H`
M``!3\0$`"0```%[Q`0`"````:/$!``0```!K\0$`(P```'#Q`0`#````E/$!
M``4```"8\0$`"@```)[Q`0`*````J?$!``8```"T\0$`!@```+OQ`0`+````
MPO$!``T```#.\0$`!@```-SQ`0`(````X_$!``H```#L\0$`!````/?Q`0`%
M````_/$!`'8````"\@$`"P```'GR`0`.````A?(!`!<```"4\@$`!````*SR
M`0`(````L?(!`!4```"Z\@$`+P```-#R`0`-`````/,!``H````.\P$`!P``
M`!GS`0`.````(?,!``L````P\P$`"0```#SS`0`4````1O,!`#,```!;\P$`
M*````(_S`0`G````N/,!`!@```#@\P$`&@```/GS`0`-````%/0!`!0````B
M]`$``P```#?T`0`'````._0!``<```!#]`$`"P```$OT`0`0````5_0!``X`
M``!H]`$`"0```'?T`0`0````@?0!`!L```"2]`$`"0```*[T`0`)````N/0!
M``D```#"]`$`#P```,ST`0`*````W/0!`$T```#G]`$`'@```#7U`0`-````
M5/4!``H```!B]0$`(0```&WU`0!,````C_4!`!D```#<]0$`!0```/;U`0`?
M````_/4!`"X````<]@$`!P```$OV`0`&````4_8!``L```!:]@$`!@```&;V
M`0`'````;?8!`"<```!U]@$`)@```)WV`0`J````Q/8!``8```#O]@$`!P``
M`/;V`0`A````_O8!`"\````@]P$`50```%#W`0`5````IO<!`"<```"\]P$`
M$P```.3W`0`"````^/<!``P```#[]P$`#`````CX`0`(````%?@!``P````>
M^`$`"@```"OX`0`=````-O@!``<```!4^`$`"0```%SX`0`&````9O@!``D`
M``!M^`$`#````'?X`0`(````A/@!``D```"-^`$`"````)?X`0`R````H/@!
M`!8```#3^`$`!P```.KX`0`/````\O@!`!$````"^0$`$````!3Y`0`&````
M)?D!``H````L^0$`#@```#?Y`0`,````1OD!``H```!3^0$`"@```%[Y`0`.
M````:?D!``P```!X^0$`"@```(7Y`0`*````D/D!``<```";^0$`"````*/Y
M`0`.````K/D!`!P```"[^0$`10```-CY`0`'````'OH!``H````F^@$`%```
M`#'Z`0`-````1OH!`!$```!4^@$`"@```&;Z`0`0````<?H!``<```""^@$`
M&````(KZ`0`$````H_H!``\```"H^@$`!P```+CZ`0`%````P/H!``0```#&
M^@$`#@```,OZ`0`%````VOH!`!@```#@^@$`#0```/GZ`0`7````!_L!``\`
M```?^P$`%@```"_[`0`9````1OL!`!<```!@^P$`'````'C[`0`6````E?L!
M``<```"L^P$`!@```+3[`0`.````N_L!``L```#*^P$`"@```-;[`0`7````
MX?L!``8```#Y^P$`'`````#\`0`+````'?P!``T````I_`$`(@```#?\`0`:
M````6OP!`!4```!U_`$`!P```(O\`0`-````D_P!``4```"A_`$`$````*?\
M`0`3````N/P!``8```#,_`$`"0```-/\`0`(````W?P!``4```#F_`$`!P``
M`.S\`0`$````]/P!``0```#Y_`$``P```/[\`0`5`````OT!`!D````8_0$`
M.P```#+]`0`S````;OT!`!(```"B_0$`+P```+7]`0`R````Y?T!``X````8
M_@$`/````"?^`0`O````9/X!`#0```"4_@$`-````,G^`0`X````_OX!`!@`
M```W_P$`$@```%#_`0`3````8_\!`!@```!W_P$`$P```)#_`0`5````I/\!
M`!(```"Z_P$`$@```,W_`0`;````X/\!`!,```#\_P$`%0```!```@`:````
M)@`"`"X```!!``(`+@```'```@`R````GP`"`"\```#2``(`,`````(!`@`M
M````,P$"`!T```!A`0(`$P```'\!`@`4````DP$"``L```"H`0(`&0```+0!
M`@`*````S@$"``\```#9`0(`+````.D!`@`N````%@("`"$```!%`@(`(@``
M`&<"`@`+````B@("`%4```"6`@(`1@```.P"`@`.````,P,"``0```!"`P(`
M'````$<#`@`,````9`,"`!````!Q`P(`$@```((#`@`%````E0,"``H```";
M`P(`"0```*8#`@`/````L`,"`!$```#``P(`"@```-(#`@`+````W0,"``P`
M``#I`P(`(````/8#`@`#````%P0"``@````;!`(`!@```"0$`@`,````*P0"
M``X````X!`(`%0```$<$`@`+````700"`$(```!I!`(``@```*P$`@`&````
MKP0"``T```"V!`(`%@```,0$`@`%````VP0"``<```#A!`(`&0```.D$`@`&
M`````P4"`"X````*!0(`$````#D%`@`=````2@4"``0```!H!0(`G@```&T%
M`@`J````#`8"`!P````W!@(`(````%0&`@`7````=08"`%D```"-!@(`%```
M`.<&`@!'````_`8"`!D```!$!P(`#@```%X'`@`<````;0<"``T```"*!P(`
M%````)@'`@`.````K0<"``P```"\!P(`$@```,D'`@`*````W`<"`!P```#G
M!P(`&0````0(`@`%````'@@"`!,````D"`(`$P```#@(`@`0````3`@"`"8`
M``!="`(`$P```(0(`@`5````F`@"`!(```"N"`(`$0```,$(`@`9````TP@"
M``<```#M"`(`"````/4(`@`3````_@@"``X````2"0(`$@```"$)`@`/````
M-`D"`!H```!$"0(`#P```%\)`@`:````;PD"`!0```"*"0(`"0```)\)`@`*
M````J0D"``@```"T"0(`!0```+T)`@`)````PPD"``8```#-"0(`$````-0)
M`@`(````Y0D"``X```#N"0(`"````/T)`@`2````!@H"`!(````9"@(`*```
M`"P*`@`8````50H"``D```!N"@(`"@```'@*`@`9````@PH"``H```"="@(`
M(@```*@*`@`&````RPH"`!@```#2"@(`"0```.L*`@`'````]0H"`!H```#]
M"@(`*P```!@+`@`*````1`L"`!\```!/"P(`#0```&\+`@`-````?0L"``P`
M``"+"P(`&0```)@+`@`5````L@L"``0```#("P(`!P```,T+`@`,````U0L"
M``<```#B"P(`!0```.H+`@`.````\`L"``@```#_"P(`!@````@,`@`(````
M#PP"`!@````8#`(`)@```#$,`@`M````6`P"`!H```"&#`(`(````*$,`@`?
M````P@P"`$0```#B#`(`'````"<-`@`K````1`T"`!T```!P#0(`)````(X-
M`@!;````LPT"`%L````/#@(`2@```&L.`@`B````M@X"`!0```#9#@(`%P``
M`.X.`@`%````!@\"``<````,#P(`#@```!0/`@`(````(P\"`!<````L#P(`
M&0```$0/`@`N````7@\"``@```"-#P(`(@```)8/`@`8````N0\"`!\```#2
M#P(`.P```/(/`@`%````+A`"`!4````T$`(`"P```$H0`@`/````5A`"`",`
M``!F$`(`"@```(H0`@`8````E1`"`!$```"N$`(`$````,`0`@`.````T1`"
M``<```#@$`(`$@```.@0`@`'````^Q`"``0````#$0(`#0````@1`@`5````
M%A$"`!@````L$0(`+P```$41`@`+````=1$"`!$```"!$0(`!0```),1`@`%
M````F1$"`!T```"?$0(`"````+T1`@`%````QA$"`!P```#,$0(`"P```.D1
M`@`$````]1$"``L```#Z$0(`"0````82`@`*````$!("``P````;$@(`#0``
M`"@2`@`7````-A("``L```!.$@(``P```%H2`@`=````7A("``\```!\$@(`
M,@```(P2`@`Y````OQ("`!D```#Y$@(`2@```!,3`@`.````7A,"`!P```!M
M$P(`"0```(H3`@`@````E!,"`!,```"U$P(`!0```,D3`@`1````SQ,"``@`
M``#A$P(`"P```.H3`@`G````]A,"``P````>%`(`(P```"L4`@`'````3Q0"
M``T```!7%`(`$````&44`@`.````=A0"`!,```"%%`(`&0```)D4`@`:````
MLQ0"``L```#.%`(`,P```-H4`@`'````#A4"`"`````6%0(`$0```#<5`@`5
M````214"`'T```!?%0(`#0```-T5`@`<````ZQ4"`$$````(%@(`,P```$H6
M`@`(````?A8"`#````"'%@(`&@```+@6`@`L````TQ8"`#8`````%P(`-P``
M`#<7`@`P````;Q<"`!,```"@%P(`%@```+07`@`)````RQ<"`!(```#5%P(`
M$@```.@7`@`A````^Q<"`!@````=&`(`"````#88`@`;````/Q@"`!(```!;
M&`(`!P```&X8`@`7````=A@"`"(```".&`(`!0```+$8`@`%````MQ@"``L`
M``"]&`(`"P```,D8`@`4````U1@"``0```#J&`(`"````.\8`@`*````^!@"
M``X````#&0(`#````!(9`@`0````'QD"`!`````P&0(`!@```$$9`@`&````
M2!D"`"L```!/&0(`(P```'L9`@`@````GQD"``,```#`&0(`"````,09`@`&
M````S1D"``\```#4&0(`&P```.09`@`9`````!H"`"<````:&@(`#P```$(:
M`@`(````4AH"`"$```!;&@(``P```'T:`@`>````@1H"``8```"@&@(`"0``
M`*<:`@`"````L1H"``P```"T&@(`%0```,$:`@`+````UQH"`!D```#C&@(`
M'@```/T:`@`1````'!L"``4````N&P(`"@```#0;`@`5````/QL"`!(```!5
M&P(`#````&@;`@`%````=1L"``H```![&P(`"````(8;`@`3````CQL"`$P`
M``"C&P(`'0```/`;`@`E````#AP"`#,````T'`(`$0```&@<`@`)````>AP"
M``,```"$'`(`"@```(@<`@`4````DQP"`!@```"H'`(`*````,$<`@`(````
MZAP"``0```#S'`(`#@```/@<`@`*````!QT"``X````2'0(`&0```"$=`@`-
M````.QT"``L```!)'0(`'0```%4=`@`)````<QT"`!8```!]'0(`(````)0=
M`@`;````M1T"``\```#1'0(`"@```.$=`@`B````[!T"`"(````/'@(`8```
M`#(>`@`F````DQX"`!H```"Z'@(`$0```-4>`@`2````YQX"`!X```#Z'@(`
M&P```!D?`@`@````-1\"`!T```!6'P(`&````'0?`@`0````C1\"`!@```">
M'P(`,@```+<?`@`I````ZA\"`!0````4(`(`%0```"D@`@`9````/R`"`!0`
M``!9(`(`'````&X@`@`5````BR`"``H```"A(`(`!P```*P@`@`(````M"`"
M``D```"](`(`%@```,<@`@`+````WB`"`#,```#J(`(`%@```!XA`@`8````
M-2$"``D```!.(0(`!````%@A`@!)````72$"`#X```"G(0(`.0```.8A`@!;
M````("("``4```!\(@(`-````((B`@`E````MR("``P```#=(@(`#0```.HB
M`@`&````^"("``X```#_(@(`-@````XC`@`$````12,"``<```!*(P(`"0``
M`%(C`@`.````7","``L```!K(P(`3````'<C`@`K````Q","`"D```#P(P(`
M"P```!HD`@`A````)B0"`!X```!()`(`%P```&<D`@`3````?R0"`!,```"3
M)`(`(@```*<D`@`0````RB0"``8```#;)`(`#0```.(D`@`+````\"0"`!$`
M``#\)`(`"0````XE`@`O````&"4"``P```!()0(`"@```%4E`@`(````8"4"
M`!````!I)0(`!P```'HE`@`)````@B4"``<```",)0(`$````)0E`@`)````
MI24"``D```"O)0(``P```+DE`@`'````O24"``D```#%)0(`$````,\E`@`.
M````X"4"``D```#O)0(`&@```/DE`@`,````%"8"``<````A)@(`$0```"DF
M`@`2````.R8"`!8```!.)@(`"@```&4F`@`&````<"8"``D```!W)@(`(@``
M`($F`@`0````I"8"`",```"U)@(`*P```-DF`@`)````!2<"``D````/)P(`
M%P```!DG`@`'````,2<"``0````Y)P(`'0```#XG`@`U````7"<"``D```"2
M)P(`"P```)PG`@`(````J"<"``<```"Q)P(`"0```+DG`@`(````PR<"``D`
M``#,)P(`!0```-8G`@`'````W"<"`!$```#D)P(`!@```/8G`@`.````_2<"
M``H````,*`(`#````!<H`@`+````)"@"`!L````P*`(`"@```$PH`@`"````
M5R@"`"$```!:*`(`!@```'PH`@`&````@R@"`',```"**`(`"````/XH`@`&
M````!RD"`!L````.*0(`)0```"HI`@`2````4"D"`"<```!C*0(`&P```(LI
M`@`/````IRD"`!@```"W*0(`'0```-`I`@`D````[BD"`$@````3*@(`'```
M`%PJ`@`?````>2H"`!(```"9*@(`"````*PJ`@`%````M2H"``\```"[*@(`
M"@```,LJ`@`*````UBH"``8```#A*@(`"@```.@J`@`2````\RH"``P````&
M*P(`"@```!,K`@`,````'BL"``<````K*P(`!P```#,K`@`(````.RL"``D`
M``!$*P(`%@```$XK`@`)````92L"``<```!O*P(`!P```'<K`@`:````?RL"
M``8```":*P(`%P```*$K`@`&````N2L"``<```#`*P(`%0```,@K`@`)````
MWBL"`!````#H*P(``P```/DK`@`'````_2L"`!0````%+`(`!@```!HL`@`3
M````(2P"`!$````U+`(`$P```$<L`@`&````6RP"``8```!B+`(`"@```&DL
M`@`(````="P"``0```!]+`(`"0```((L`@`$````C"P"``T```"1+`(`(@``
M`)\L`@`*````PBP"``P```#-+`(`*0```-HL`@`7````!"T"`!8````<+0(`
M&P```#,M`@`6````3RT"``0```!F+0(`"P```&LM`@`-````=RT"``<```"%
M+0(``@```(TM`@`.````D"T"``@```"?+0(`(@```*@M`@`?````RRT"`",`
M``#K+0(`(`````\N`@`U````,"X"`"$```!F+@(`)P```(@N`@`K````L"X"
M`$D```#<+@(`&@```"8O`@`:````02\"`!L```!<+P(`'@```'@O`@`A````
MER\"`&0```"Y+P(`$@```!XP`@`A````,3`"`#X```!3,`(`(P```)(P`@`>
M````MC`"`$\```#5,`(`2````"4Q`@`F````;C$"`#\```"5,0(`(0```-4Q
M`@`5````]S$"`"\````-,@(`+@```#TR`@`G````;#("`"<```"4,@(`(0``
M`+PR`@`V````WC("`!L````5,P(`)@```#$S`@`1````6#,"`!8```!J,P(`
M2P```($S`@!P````S3,"`#@````^-`(`*@```'<T`@`U````HC0"`&(```#8
M-`(`5````#LU`@`K````D#4"`!P```"\-0(`#P```-DU`@`A````Z34"`!8`
M```+-@(`%0```"(V`@`M````.#8"`!P```!F-@(`&P```(,V`@`M````GS8"
M`!T```#--@(`/0```.LV`@`9````*3<"``T```!#-P(`+@```%$W`@`G````
M@#<"`#8```"H-P(`*0```-\W`@`<````"3@"`"4````F.`(`(````$PX`@`V
M````;3@"`*0```"D.`(`4````$DY`@`Q````FCD"`$,```#,.0(`+````!`Z
M`@`C````/3H"`#<```!A.@(`8P```)DZ`@!,````_3H"`&X```!*.P(`*0``
M`+D[`@`O````XSL"`#0````3/`(`+0```$@\`@`E````=CP"`#,```"</`(`
M'@```-`\`@`G````[SP"`"`````7/0(`(0```#@]`@`@````6CT"`#0```![
M/0(`7P```+`]`@!1````$#X"`"\```!B/@(`/````)(^`@`_````SSX"`#,`
M```//P(`+@```$,_`@`<````<C\"`"D```"//P(`)0```+D_`@`J````WS\"
M`!H````*0`(`*````"5``@`M````3D`"`"T```!\0`(`%0```*I``@"#````
MP$`"`'<```!$00(`@````+Q!`@#(````/4("`!D````&0P(`(P```"!#`@`N
M````1$,"`"<```!S0P(`1P```)M#`@`B````XT,"`%`````&1`(`%P```%=$
M`@`D````;T0"``X```"41`(`00```*-$`@`D````Y40"`#$````*10(`+@``
M`#Q%`@`G````:T4"`"0```"310(`-````+A%`@`Z````[44"``0````H1@(`
M!P```"U&`@`#````-48"``\````Y1@(`"@```$E&`@`'````5$8"``@```!<
M1@(`!0```&5&`@`1````:T8"``0```!]1@(`6P```()&`@`$````WD8"``\`
M``#C1@(`!````/-&`@`'````^$8"``<`````1P(`!0````A'`@`#````#D<"
M`!`````21P(`#@```"-'`@`3````,D<"`!$```!&1P(``@```%A'`@`(````
M6T<"``<```!D1P(`%````&Q'`@`,````@4<"`!8```".1P(`!@```*5'`@`/
M````K$<"``H```"\1P(``P```,='`@`H````RT<"``0```#T1P(`!@```/E'
M`@`'`````$@"`!<````(2`(`2````"!(`@`I````:4@"`"P```"32`(`%P``
M`,!(`@`E````V$@"`"8```#^2`(`*0```"5)`@`=````3TD"`!H```!M20(`
M&0```(A)`@`;````HDD"`!@```"^20(`%P```-=)`@`=````[TD"`!L````-
M2@(`+````"E*`@`8````5DH"`"<```!O2@(`&````)=*`@`G````L$H"`",`
M``#82@(`&0```/Q*`@`=````%DL"`!L````T2P(`&````%!+`@`>````:4L"
M`"(```"(2P(`'0```*M+`@`F````R4L"`"(```#P2P(`&````!-,`@`:````
M+$P"`"4```!'3`(`%P```&U,`@`A````A4P"`#````"G3`(`,P```-A,`@`3
M````#$T"`"8````@30(`/@```$=-`@`?````ADT"`",```"F30(`(0```,I-
M`@`D````[$T"`!X````13@(`&````#!.`@`A````24X"`"````!K3@(`,P``
M`(Q.`@`B````P$X"`#<```#C3@(`#````!M/`@`/````*$\"`!D````X3P(`
M*0```%)/`@`?````?$\"`!````"<3P(`(@```*U/`@`/````T$\"`!4```#@
M3P(`#@```/9/`@`0````!5`"`!L````64`(`!P```#)0`@`%````.E`"`"D`
M``!`4`(`)````&I0`@`7````CU`"`"(```"G4`(`)````,I0`@`'````[U`"
M`-0```#W4`(`#````,Q1`@`;````V5$"`!0```#U40(`"0````I2`@`,````
M%%("`!P````A4@(`$P```#Y2`@`1````4E("`!L```!D4@(`"0```(!2`@`R
M````BE("``@```"]4@(`$````,92`@`'````UU("`!(```#?4@(`"@```/)2
M`@`V````_5("``D````T4P(`)````#Y3`@`6````8U,"`!4```!Z4P(`%```
M`)!3`@`F````I5,"`!P```#,4P(`#````.E3`@`<````]E,"``T````35`(`
M#@```"%4`@`5````,%0"``H```!&5`(`&````%%4`@`(````:E0"`"D```!S
M5`(`"0```)U4`@`/````IU0"`"H```"W5`(`!@```.)4`@`5````Z50"``<`
M``#_5`(`"`````=5`@`)````$%4"`#L````:50(`$````%95`@`'````9U4"
M`!````!O50(`$@```(!5`@`2````DU4"``D```"F50(`"P```+!5`@`'````
MO%4"`!4```#$50(`"0```-I5`@`'````Y%4"``P```#L50(`%P```/E5`@`+
M````$58"``T````=5@(`#````"M6`@`?````.%8"`!<```!85@(`&0```'!6
M`@`$````BE8"``4```"/5@(`&0```)56`@`$````KU8"`"P```"T5@(`#```
M`.%6`@`1````[E8"``<`````5P(``@````A7`@`,````"U<"``X````85P(`
M"P```"=7`@`$````,U<"``D````X5P(`$P```$)7`@`6````5E<"``H```!M
M5P(`"````'A7`@`)````@5<"`!$```"+5P(`#0```)U7`@`9````JU<"`!H`
M``#%5P(`#0```.!7`@`R````[E<"`!X````A6`(`(P```$!8`@`7````9%@"
M``L```!\6`(`,P```(A8`@`%````O%@"`!$```#"6`(`0@```-18`@`+````
M%UD"``H````C60(`!@```"Y9`@`$````-5D"``0````Z60(`"@```#]9`@`4
M````2ED"``4```!?60(`!@```&59`@`&````;%D"``H```!S60(`!@```'Y9
M`@`.````A5D"``P```"460(`#````*%9`@`/````KED"``X```"^60(`#@``
M`,U9`@`2````W%D"`#0```#O60(`*@```"1:`@`G````3UH"``4```!W6@(`
M'@```'U:`@`.````G%H"``(```"K6@(`!````*Y:`@`*````LUH"``4```"^
M6@(`!0```,1:`@`"````REH"`!$```#-6@(`0P```-]:`@`N````(UL"`#@`
M``!26P(`&````(M;`@`C````I%L"`",```#(6P(`)@```.Q;`@`M````$UP"
M`"D```!!7`(`+@```&M<`@`/````FEP"`%X```"J7`(`(`````E=`@!'````
M*ET"`"0```!R70(`00```)==`@`H````V5T"`!P````"7@(`&````!]>`@`>
M````.%X"`"H```!77@(`'````()>`@`9````GUX"`#````"Y7@(`,0```.I>
M`@`U````'%\"`#0```!27P(`*@```(=?`@`D````LE\"`"H```#77P(`,@``
M``)@`@`R````-6`"`!````!H8`(`$0```'E@`@`/````BV`"`&P```";8`(`
M"0````AA`@"I````$F$"`%\```"\80(`=P```!QB`@`N````E&("`%@```##
M8@(`%0```!QC`@`F````,F,"`",```!98P(`%P```'UC`@`7````E6,"`!L`
M``"M8P(`'P```,EC`@`Y````Z6,"`",````C9`(`(P```$=D`@!8````:V0"
M`!H```#$9`(`$@```-]D`@`+````\F0"``4```#^9`(`!@````1E`@`(````
M"V4"``4````490(`$@```!IE`@`,````+64"`!0````Z90(`'@```$]E`@`.
M````;F4"``T```!]90(`#P```(ME`@`&````FV4"``0```"B90(`"@```*=E
M`@`)````LF4"``<```"\90(`"P```,1E`@`(````T&4"``8```#990(`%0``
M`.!E`@`.````]F4"``<````%9@(`"0````UF`@`)````%V8"``X````A9@(`
M#````#!F`@`+````/68"``X```!)9@(`#0```%AF`@`0````9F8"`!0```!W
M9@(`!````(QF`@`&````D68"`!<```"89@(`"@```+!F`@`)````NV8"``\`
M``#%9@(`"````-5F`@`%````WF8"`!0```#D9@(`%0```/EF`@`*````#V<"
M``8````:9P(`#P```"%G`@`1````,6<"``L```!#9P(`#0```$]G`@`-````
M76<"``T```!K9P(`&````'EG`@`-````DF<"``4```"@9P(`&````*9G`@`(
M````OV<"``,```#(9P(`!````,QG`@`9````T6<"``D```#K9P(``@```/5G
M`@`"````^&<"``\```#[9P(`!@````MH`@`&````$F@"``\````9:`(`%P``
M`"EH`@`&````06@"`!8```!(:`(``@```%]H`@`$````8F@"`!$```!G:`(`
M!0```'EH`@`2````?V@"`!(```"2:`(`$````*5H`@`'````MF@"``T```"^
M:`(`!@```,QH`@`,````TV@"``@```#@:`(`&@```.EH`@`/````!&D"`!(`
M```4:0(``@```"=I`@`'````*FD"``D````R:0(`#0```#QI`@`/````2FD"
M`!$```!::0(`%````&QI`@`K````@6D"``0```"M:0(`!P```+)I`@`+````
MNFD"``4```#&:0(``@```,QI`@`+````SVD"``$```">!0```````+4#```?
M"````````-D!``#D!0``'@4``$D%``!M`P``2@$````````=!0```````.@$
M``!O`@``/@(```\!````````$0(``"<$``!Q!P``'0```-0````_`0``7`,`
M`"X"``"=`0``W@<``&X"````````HP,``$P'```L`P``Q04``&H(``"8`P``
M`@8``-`#``"5!0``^@<``%,!``!#`````````$H$``"$`P```````/H%```V
M`````````"@(````````9@4````````0`0``6@$`````````````;@0``"X`
M``!^`0``P`<````````T"```&0<``$L#``#=!P```````*4'``#?````0P4`
M`+L'``#I````>0```-,&``!'`P``$00```````"'`P``)@8```````#-!0``
M.`@```````"B`@``,`<``)<!````````^0```+\&``"9!0``#0,``'`$``!9
M"```LP```((```#U`@``T@$``+L"``#K"```'`$``-P!````````I`4``+T%
M``##!```=@,``,\&``"B`P``D@```%@'``"7````F`@``'X'``!="```00,`
M`'T#``##`@``T`4``#P!``"L!````````#T!``"+`@``M`,```('``!G!P``
M40$`````````````>0@````````H!@``OP0``%(&``!I`@``=0```,X!``"\
M!```6@<```````!_"```Q@(```````!Q`@``Q`(`````````````.@<``$T`
M``!L"```=````&L%``#T````G`<``+0(``"P`````````$\%`````0``!@4`
M`.0```#7!```@`,``!T!``!>`P``UP8``%@%``"E"```U00```````"=`@``
MD08```````!P!0``,0<``,X"``!S!```V@8``&8$````````4P```*`#``#&
M!@```````(H#``````````````````````````````````#,!P``!`(`````
M```7`P``Q`@``*X$````````'P$```````!^!````````/X"````````=0,`
M`&L'```2!@``Z`<``-D"```!`0```````&8(``"]`````````%L$``#<!```
M`````%H%````````:`8`````````````S@,``',%````````:@```!4&``">
M!@``O`@``*$'``")!```H`@```````!7`P```````)H$````````SP@``.X#
M````````.@$``.8%``#/`0``ZP0```T$``!P`@``D0```',#````````J04`
M`.((``!N"```_@,``$,$``#L`P``QP$````````I!P``W0@``"0`````````
MN0```-@!``"Q"```5P(``#L#``#Q!P``%@0``&@!``"C`0````0``)D"``#S
M`0``^P```(L&````````VP8``$H"``"7!0```````/,'``!6!0``JP@``*L'
M```T`0```````#8&``"M!@``_08```````#N````(0`````````5!```,P,`
M`&,!``!]`0``;`(```````"C!P``2P@``$<%``"Z`@```````&8"````````
MR@@``",&```(!P``1P(``&$&```F!P```````)0'``!"!0```````"P$```@
M!@``&0````````"E!```7`0``)P%``"'!@``5P0``)\%``"T`0``3`@``!@%
M``",!@``"0,``,,%````````\00``,`&````````>@8``#("``#T`P``)@``
M`#4```"Z`0``)`@`````````````008``,H&```9!```MP$``,D'```N"```
M`````)8$``!E`````````#L"``#W`@`````````````'!```````````````
M`````````#D'````````P@<``'H````B!```B0``````````````Q0@``&P!
M``#O`@`````````````<`@``@P8```8`````````4@<``/D%``!H!```_0(`
M`*D!``!X!```$P(``-("``!%````(`,``/,```!K!@``:0$``+T"```P`0``
M4P,```D&````````X@````````"O`P``]0$```````#-`0``KP(``,T#``#,
M`0``,@```'(`````````_P4``#@$``#$````'P<`````````````U08`````
M```U`P``B`<``)4```"P`P```````%0!```0!P```````%,&````````:`4`
M`!0"```Z`P``00(```````"9`P````````8(``!7`0``[0```!\`````````
M`````%0(``!?````Z0(```````"C"```+0$``'H(``#0!@```````(T(``#L
M!```&0@``+0&````````#`8``*@&``!(`P``1@<```4!```O!P``D@@`````
M``!.!0``80@``,T"``#4`@``'`0```X```"X`@``3`8``.(&``"A`0``$`0`
M````````````@P````````"7"```P08``(`(``#V`@``Z`$``'(#``"K````
ML`<``&8`````````_`,``+$"``#O`````````!<!``````````````````!]
M!0``````````````````5`0``(\!````````;P0``.`#`````````````"$'
M````````B04``"P'``#6`0````````L!```W!P``"0(``/\'````````C`4`
M`(T`````````.@(``.L#```V!```UP4````````/!@``3`4``%<'``!*````
M`````%T```!%`0``T@<``"H"``"?!P``H0@``"P```"#`P```````'`#``"A
M`@``PP$``#X&```_!P``0@8``/X!``!3!0```````/L%``"?!```K0(``!0(
M``#P!````````"H$````````(`(```````!@!P``HP8``-L'````````L@$`
M`,,(````````5@0``*\(``#4`0``O0@``+<'````````"P@```````!4`@``
M```````````G`@```````+,(```\`@``'0,``/\"``!P`0``U0$`````````
M````9P8``%T$```O!0``6P```!`%``#5!0```````&T"``#[!````````.T%
M```&!```!@$``/\#``#6`@```````%4%``!F`0``G`$`````````````G`(`
M``````"*!0```````#D#````````3@(``$4'``#N`0``I@```(P"``#-!P``
M``````````````````````````#(`0``4@(``&4&```E!0``#`,``+$'``#6
M!P``G0````D$``!(!P``-`0`````````````[`8``$@&``"3!@``J@<``#,"
M``"J"```/@<``/@!```Q`@``U0(``%4!```9`0``&P<````````."```````
M`"(&```E`````````/,%```V"``````````````)!P```````.X(````````
M]0```(`"``#3`0```````)8'``!."```R0@```````````````````````!S
M````J`,```````#``P``&`0``*X"````````S08````&``"/!P``Z@<``.\(
M````````7P$``$P`````````\@```"0"``!;`0``6P8```````#B!```8`$`
M`$4&``#8!P``M0<``.\$```6`@``+P,``,`%``!/`@``KP8``#<"````````
M`````&4#```*`@``IP`````````)!0```````#<#``!6`0``S0``````````
M``````````````"L"`````````````"(!@``DP```","``"'!0``#0$``)@'
M``"=!```H@@``&P````E!@``*0`````````B`0``VP```'\#``#<`@``B0@`
M`!L#``!$`0``W@```"H(````````.@0``#P'````````0@0``*````#[`0``
MN@,``/0(```\!0``G@,``#X(``!=`0``?`$``+<&``#O`0``0@(``!<(```K
M!@```````(H!`````````````/P!```!"```S`,``+$&````````@P<``*L%
M``!R`0``W`<``)(#``#:`@``F`(``+,#``!S!@``LP(``.4$``#<`P``#P@`
M`&4%```5!0``Y@0``/($````````/0,``#D%``"P`0``W````&8&````````
M&@(```$$``!M!@```````(@$```8!@``@0$```````#^!```3`(``/H!``"@
M!@``30$```P'``"C!```W`@``*4````[!```U`@``.D!``".!0```````#P`
M``"Q!````````'8$``````````(`````````````FP8``!L!``"I"```Y@(`
M`/\&```*!P``Y04`````````````"P<``%8(``#Q"```@`$``"@'````````
M>0,``"@%``!+!````````!T&``!H`P``Y`8``+<(``#;!````````/$!``#&
M`````````,<&```1`0``U`0``'T(```D!P```````)D$```'`0``$@<``$P!
M``#I!P``F0<``)0!```Q````9`0``+L(``"\`0``QP@``!8'````````````
M``````"^`0```````%(!``!(!```.0@```````#1!@``,`(``*T```!'!P``
M``````````#6`P``KP$```````#J!@```````+0'``"?`0````````````#9
M"```I04``(@"````````>P4``)4'``"%`0``"P4``-0%````````T`0`````
M````````0P(``&$'``#O`P``8`0```````"2`@``4P0``-,"```Q!0``LP4`
M`)P#``!+!P``CP,````````@`0````````````#7````+`$``(X"``#Y!@``
M&P@````````A"```M0@``*<%``"L`P```````+P"``!:`P``60<``-T&``!8
M!@``=P<``,X(```R`P``0P8````````%`@``RP$``!D%``!!!P``L@(`````
M````````[P4````````!!P``-`(``'@```"#"```JP(```L```#Q`@``````
M`*,%``!_`0``\`$``.H%``"7`@```````/D$```J!P``XP8``%P'````````
ME08``-$$``"Z!P``T`$``%4"```N`0``"0$``)H```#@!P```````)(&``!^
M!@``B````#H&``#E`0```````+\"``#W``````````````!S"```+0(``$<(
M``#3!0``%`<``-P&````````9`8``.T&````````>@<``.4&``!C````VP$`
M`(0(``"6`````````%`(````````Y@8``','```0`P``00$``,0%```D`P``
M^@```.H!````````=@(````````1!0```P0``&<%````````;@4``)P`````
M````J`0``!8(````````N0@```````!2!0``6@8``#<$``!Q"```L@0```$#
M````````R`,``$\'``#_`0```````,P$``#T!P``4P(```````#A!0``2P8`
M`,H#```#!P```````-X%```3!```!`$``*`'``!U!P``````````````````
MAP$```````"$!```;@```'($````````:P````````"T`@``60$``$L!``".
M"````````#(%````````8P<``/`"````````"P,``%$&``````````````H&
M```5`````````"4'````````N`@``(8%``"G!@``_P``````````````=0@`
M`*,`````````^@,``$D!``#O!@``1P$```````#(!0``L@4````````,`0``
M````````````````,P<``&<#```C`0``>0(``"$!``"'!```W@(``-D'``!>
M!```^@8````````]!@``D`$``-(%```?!0``LP0``)T#``"H"```9`<``#4%
M``!N!@``VP(``"8$``#`!```>`$``-<#```````````````````7!0``YP,`
M`$$$``!Q`P``]@```"<!```#`@````````("````````(04``,D!```7!P``
M`````%P"``#7`@```````(H"``#\`@``"@@```````"G"```-`,``(D'``":
M!P``4P@``(0!````````E0(``%D`````````Q0,``#H```!"`0``#@(``"4"
M``!%`@``70,``(8&````````````````````````1P8``!P(````````/0(`
M`(L`````````Z04``.(%``#I!@``NP```"@#```B`@``:`@``+X#```P"```
MF@@``"T&``"8````H`(``.(!``!J`@``D00``"\!``"1`@``BP,```````##
M`P``]`4``+L$`````````````+4&``!\!P``N0(```````#^````!`@``!@'
M````````.````!4!``#B`@```````(X&``!W`P``1@4````````D!@``&`,`
M`.0$``"F`P``DP@``(,$``#Q``````,``&4(````````70<``/,&``!1`@``
M`````$L````1"```EP,```(```````````````````"P`@``X```````````
M``````````````#4!P``=0(``%\#```W`````````.,"```)````7P4`````
M````````/0<``!`"````````C@<`````````````%````.X&````````````
M`)X"``!;"```50,``*H``````````````-H(````````Z`,``),"``#A"```
MM@4``(H(```F`P``J`4``.4(````````E0$``!T'``!N!P``E`8````````K
M!`````````````#]````,````(T!``!W`````````)H%``"L`0``````````
M``!^!0``4`4``-\(```R!@````````````",`0```````%$#``!<````G@<`
M`/P$````````#P,`````````````P0$``'L#```4!0``@0(``#,(````````
MT````*H%``````````````````!`"```K`8``/T!``"P!```6````-H%````
M````[0$``*8(``!(`@``F@,``,\$``#$!P````````````#A`0``I`(`````
M``#&"`````````T%``#6!@```````#`&```K`@``R@0``$D&``!8`0``-@,`
M``````!$!@```````````````````````*\```!X`P``(0,``&$#``#>`0``
M/P0``'\%``"8!```````````````````@@@```````#S`P``6`(```4```!-
M!@``=`$``#L&``"N!@``&`$``(T"``#&`P``!00``"P&```(````8`4`````
M``#I!```]@$``&T!``"U!0``?@,```````"H`0``_P0``(4(``!]````````
M`+<#``"_`````````,D%``!W!@``?`@``-0#``"\!P``LP<``,`"``#5!P``
M/04``($```"H````$`@``&D```"+"```^0$``*($``!*!P``\08``)P&``#3
M!```J@8``!(%````````:@$``%4$``#P`P``;`4``-<(``"X!0``D`4``'T'
M```%!@``1@,```````#*`@``(P@``$8!``#.!P``<P(``$`&``#/!P``4@@`
M`+X$````````6`,``#,!````````YP<``/8$```.!`````````````#'`@``
MD@<``#T```!Y!P``*P,``.0"`````````````$('``#M`P``Q00``"@!``#^
M!0``G08``-D&````````)@@``%0&````````A@$``+D$``"&`@``!`0`````
M`````````````.P!`````````````%`$``!R!P``1P0```````"/````;P``
M``````!8"`````````````#K!@``;04``!<&```Q`P``"`(``(`'````````
M`````.8'```&!@``^0(``````````````````#0```!Q`````````%``````
M````2`4```````">"```P@$``(`$``!'````]`(```````"1`P``&@,``'T"
M``!P"```H`0``"T$```5`@``T@0``%D%````````&@```!X"```,!```````
M`.0!``#&`0````````T'```:`0``L@@```````!.`P```````!X'``")`P``
M!04``'P&``!@`P``E@,``(H&``#R!0``:04``/`&````````(@4``#<(``#L
M!P``E`@``+@````\!@```````+,!``"=!P``N`,```````!?"```^0<`````
M````````8P(``#@'```$!P``ZP<``-8%``````````````@$``#?!```D```
M`+\!```;`````````(<`````````O@```.<%```_"```=`(``(`&``#W`P``
M`````%H(``!V````[````%8&``":`@``=P(``$8$``"I!P``5P8``-,'```3
M`P````````````!3!P``&```````````````#0(``"P"````````O`4``,0!
M``"D!```\`<``$X```";!0``-`<``(4````R!P``````````````````(P,`
M`,L(``#J"````````)L#``!E`@``AP@``+0%``"U!``````````````G"```
M`````'<(`````````````,$`````````:0,``#L'`````````````-@#````
M`````````#L%``"V"```/@,````````3`0``XP@``#X%```Q"```<00``#8!
M```,`````````-H#```O!```K`(``-@```"E`P```````*L#``!@````@00`
M`.8!```H```````````````?`P``F0```/L'````````H`4``%<`````````
M`````*X(``!U!0```````*(!``!1!P```````"D%``!-!```WP8``*T#``"X
M!@``#`(```````"$````+@8``,X&``!K`0``404``*0!``#6!```,@0``!,(
M```_`P``MP0```P(``"'`@``FP(``)@&````````K0$``.(#````````C@,`
M`*$````_````M0```-\%```S````L`8``#4&````````^@(``*8%``"="```
M]P<```X#``"/!@``K@<``(P(``!^`@``20<``'P```#=!````````.,#``"6
M"```1`,``!X```"R!@``A0(```((``"R!P```````,(#``"I!```I@0``%X&
M````````8@$``#H%`````````````+X(``#[!@``1@(``'$&``!J`P``?@``
M``````#:!P``XP$``#$!``#F`P``^`8`````````````[0<``%X!``#H!@``
M9`@``&D(``!R"````````*$&```*`P``NP,```````"0!@``@@,``+<"``!J
M!@``J@,``/X&`````````0(``#H(```#!0``.08``#4"``"&"```D@$```\$
M``#E!P``30@``(L%``#J!```7@@``$0'``"B!P```````$`'``"U`0``'```
M`%`!``!>`@``$`````````````````````````!:!```+@,``/8(````````
M"P0``&\&``"_"````````)(%````````N0,```````#)!@``.`,```````"V
M!@```P$`````````````JP$``)`#```U!P``?P````````#N!0``XP0``&8'
M````````!`,```````!)````FP$``-8````#`P``!`8```P%```_!@``````
M`$(`````````Y0(``/@"```["```P0<`````````!P``%@,``.P"``""!P``
M`````$,!``""`0``2P(`````````````S````%0'```E`0``Q@0``)@!````
M````D`<``$$%``#=`P``E00```````!/!```80(```````"7!P```````#L!
M```M"```GP(```````#@!```@`4```````""!0``5`4```4'```J````````
M```````O`@``)@$```````!:`@``=`4``%(```!Y!0``DP$``.0(````````
MG@$````````C!```50```+T&```@`````````+P````>!@```````$`%````
M````:P,``"T'``"4!0``=P0``+$!````````4@,``%P&``!6!P``````````
M```6````00@``+(```#C!0``_`<`````````````Y0,``(@(````````````
M`+\%``"G`P```````(4'``!J!````P@```````#/!0``804```4#``!)"```
MX`(```````!$`@``F0@``)$'``#(!P``\`4``#4$`````````````*\%```H
M`@```````#<%``!M"```608``*,"``!)`P```````$X$``!`!```=@$`````
M````````/`@```````!;!0``]@8``*8!``!Y`0```````%4&````````100`
M`%D#``"#`@```````'4$``"8!0``M@<``($%`````````````+,&``!*!@``
M#08``'L```"<!```BP$``.<(````````=`<``-X&``#>`P``RP0`````````
M`````````),#``#C!P``B`,```````"V`@``\0,``%4(``"^!0``````````
M```&`P```````-,`````````V00``'P"````````````````````````````
M`,@(````````E@$``.`%``!]!@`````````````K````I````&\!````````
MIP0```````#5"```1@8``'$!``!(````[@0``,0&``#`"```4`<````````/
M!0``DP4``*\$``#-!````````!,```!X`@``L04``#`%```'`P``6@``````
M````````/P4``````````````````",%``!_!P``30<``'("``"4`@``%0<`
M`(\"```5`P```````&P&``!L!```W0$````````K!0```````/T'``#1"```
M````````````````-`8``%<%``"J!```"@0``$X'````````O0$``',!```<
M!0``'P(``+$#````````6P,```````#1`@``3P,``,L%````````K04``#4!
M```B````I`8``(0%``#7!P``?`0```````!%!0``2`@``"T#``#B!P``]04`
M`#8%```6`0``X`$```````#3`P``QP0``%P%```]"```````````````````
M(P<``&\%``"F!@``N@````@!``#"````D0@``"4#`````````````(T%``![
M!@``'0(``$`#``!H````=`,``%<(``"/!```P@0```````#G`0``%P0``.$$
M````````-P$```````"^`@```````!4(``"P!0``^`````````"?````````
M`.H#``!>````]00``$T"``!W`0`````````````!!0```````$\`````````
MJ@$``($(``"X!P``RP<``-X(````````\P(````````P`P``B08``$H%``"B
M`````````+X&```*````T0<``(T&````````@P4``,H%````````<````.@`
M````````#P``````````````/@0`````````````K@```.$&```S!@``30,`
M`+(#``#K!0``9`,``'H$```E!```&0(``"`'````````*0(``#,$``"A!0``
MYP0```X%``#K````````````````````EP8``/(&````````Z@(``(4&````
M````!P<```````!6`P``I@(``-T```!6````'`8``((&``!=!@```````!X#
M````````ZP$``($&``"$!P``#@$``%$(``#R`P```````(P$````````````
M`&($```'`@``%`,``&<(``!O"``````````````I`0``.0$``#D$``!>!0``
M,@$``$\(``!H!P```````)($``````````````D(``!@!@``]P0``"`(````
M````$@,``-D%``!M`````````)\#````````N`$``,<#``"5`P``PP8``"X%
M````````JP8``````````````P```#8"``#!`P``&`(```````![!P``S`@`
M``````"G`@``EP0```````#8!0```08``!\&``"V````M@,``,4!``"Q````
M3@$``.,`````````R0,``,P&``#'!P``RP,`````````````$P8``,4'````
M````'P0``*X%``"[!@``/`,``/,(``!;!P``;`,`````````````C```````
M``#;!0``R`8``)L(````````10,``/4(``!!``````````````!+!0``)@4`
M````````````I0(``'$%``!$!0``H@8```````"<"```D0$````````<`P``
M`````/P%``#;`P```````/8%```*!0``T@@``)8"``"D"````````/D#````
M````=08```````"Z!0``9P(``+D!```(`P``600```T````(!0``[0(``.X'
M````````3P8``"`$```$````````````````````=@<``,\`````````T@``
M``````#8`@```````*$$``!N`0````````````"9!@``1@```,$%````````
MG04``$((``!L!P```````,@$```%"```P@8`````````````"P8``+L%``!)
M`@``(0(``!H'``#8"```A0,``%P!``!B`@``&0,`````````````[00`````
M```/!P```````,X$``!,!```'@@``,P"``#0!P``M0(``.H`````````704`
M`#\"``"F!P``N@8``.`&```X`0``[P<``.<"```:!`````````````!#"```
M4`(``+\'```J`P``>`<``/("```="```H`$`````````````+0```(H$``"K
M!```#@<``*P'```Y``````````````#F````*@4``/@#``#:````````````
M````````<@8``!0!``#!`@``7@<``'D&````````X`@``!H&``">````````
M`"L!````````(@@``%8"``#N`@````````($```G!0```````(T'``##````
M```````````L!0``MP````````#X!```A`8``*T$``#S!````````)0#``#&
M!P```````,@"````````C`,``"H!```4!@```````+`(``!V!@``W04``%\"
M```O"```FP0````````7`@``\`@``.<```#-"```DP<`````````````J`<`
M``````!$````,@@``,D`````````D04``'T$````````$0<```````#U!P``
MN@0``!H%````````T0,``&X#``#A!P```````&L(```2!```$`8``%L"``"&
M````#0@````````F`@``]P8```````!?!@``P@(``&L"``"I!@``B`4``'X(
M``#%````!@<``+T'```C`````````"\&``"E`0```````)`(``#!!```?P(`
M`#4(``#:`0``O`,``(8#``!`````)P<```````#"!0````````````">!```
M.`8`````````````$@@``&,%````````P`$``,````#5`P``9P$``*H"```3
M!0```````'@%```D!0``+P```.<&``!J!0``K````#D"``!K!```>@,`````
M```K!P``*`0``!T$``!A!```/@$``/``````````W@0````````:"```````
M``````"^!P``@`````````#X!0``"`8``&D$``#1!0``80$```<```!$"```
M`````.$"``#0`@``Y@@```````#?`P``_00``$`!```]!```_0,```````"]
M`P``Z`4``"4(``"Z"```R@<``(8'``"M!P``RP8``%$```!T"```J0(``(($
M``!P!@``GP8````````'!0``304``````````````````$D$``#8!@``U0``
M`,L```!?!P``>@(```0%``!B"```>00````````I!````````'8(```'"```
M;P,```````!*"```8`(``)4(``#T!```H0,``,@```!0`P```````'\&```9
M!@```````!("`````````````%0#``#H`@```````.0#````````,00``-0&
M``#3"```#P(``/L#``!*`P``ZP(``*P%``!#!P``*0@``'L!``#*`0``'@0`
M`!L&``#\!@``QP```$@!``#$`P``V0```)8%``!D`0``!P8``%@$``!X"```
M`````&T'```<!P```````+D'```V!P``3P$``"X$```I!@``B`$``($#``"I
M`````````!<````A!@``.`(``/<%``!C`P``X0,`````````````(`4``-D#
M```G````-P8``(0"``"+!```90<`````````````M@$```````"M"```?P0`
M`!(``````````````"P(```6!0````4``(X```!X!@``V`0``(D"``!@"```
M`````*@"``!E!```B@<``.P(````````8P8``"(#``!R!0``WP(``(4%``!\
M!0``]@,``+L!````````1@@```````#%!@``\04```@(``!B!P``A@0``(4$
M``#I"````````'`'``"\!@``:0<```````#X!P``GP@``+T$``!C"```S@4`
M`(("``!B`P```````(\(``!#`P``S`4```````#V!P``DP0``&@"```>`0``
M`````#X```#:!`````````````!B!@``R00``&<`````````:08``*0#``!=
M`@``UP$``'8%``"I`P````````````".`0```````"('````````=P4``-L(
M```2`0``-`4``+<%```8"`````````````!B!0````````(#``"V!```C0,`
M`*0'````````1`0``,0$```D`0``N04``$(#```\!````````*X#``#?`0``
MBP<``,X```!U`0``U@@``!8&`````````````&(```"!!P``C`<`````````
M`````````,$(``#T`0``[0@```````#+`@```````````````````````%($
M```"!0``]`8``+@$```1````P@@``*(%``![!```%`0``)H&``"Y!@``R0(`
M``````"G!P````````````!\`P``_@<``)D!``"O!P``=`0``$`"``"/!0``
M9@,```````#/`P``(00``/4#``"T````AP<``#L```";``````````````"-
M!`````````````#R!P``60(``)0````N!P```````%0`````````````````
M````````_04```````!?!```;P<``%P(``#/`@````````(!````````,P4`
M`&$`````````Q0(``-`(```K"```D`0``$P#````````Y`<``%$$```&`@``
M``````````".!```$0,``!L%``#L!0```````.$`````````*0,``)`"``"E
M!@``:@<``.@(``";!P``T0$``,H````;!```E@8```````!M!```T0```"0$
M``!C!````````+0$``!T!@``Y0````````#&!0``>@$```L"``!E`0``&P(`
M``````!5!P``E`0``-\'``#W`0``)P8``'H%````````T@,``/H$````````
M\@@```````#R`0``OP,``#`$````````PP<``#@%``!G!````````-(&```G
M`P``,08``,<%````````>P(``!$&``":`0``K@$````````J!@```P8`````
M``"G`0````````````")`0``9````$4(``!0!@``#@8````````M!0``Z0,`
M`/L"``!["`````@``/P```!D!0````````````"#`0``B@```-P%```3!P``
M"@$``-T"``!D`@``3@8`````````````]08`````````("8C,34Q.R`E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S
M*0`@*%)E860@;VYL>2D`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R
M<F]W*0`@*'EE<W1E<F1A>2D`($%D9"!A;B!)35-0($%D9')E<W,@0F]O:P`@
M1&5L971E($E-4U`@061D<F5S<R!";V]K`"!A="``(B5S(B!A;')E861Y(&5X
M:7-T<R!A;F0@=V%S(&YO="!I;7!O<G1E9"X`(B5S(B!I<R!N;W0@82!D:7)E
M8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A
M(&QI<W0N`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`(B5S(B!W87,@;F]T
M(&UO=F5D(&)E8V%U<V4@:70@:7,@82!L:7-T+@`B1FER<W1N86UE($QA<W1N
M86UE(B`@*&EE+B!*;VAN($1O92D`(DQA<W1N86UE+"!&:7)S=&YA;64B("AI
M92X@1&]E+"!*;VAN*0`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H
M)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W
M;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&
M:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@
M06=R965M96YT`"5S(&%D9&5D+@`E<R!A;')E861Y(&5X:7-T<RX`)7,@870@
M)7,@)7,`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:&%S(&-A
M;F-E;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q
M=65S="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N
M`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(&ES
M(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@
M<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(')E<75E<W1S
M('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R
M('!R97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@=&\@
M861D('1O("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N
M`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@
M86)O=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G
M<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A
M9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A
M<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I
M;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`
M+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S
M('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O
M<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!B<F]W<V5R('1H870@<W5P<&]R
M=',@:49R86UE<R!I<R!R97%U:7)E9`!!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-
M(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$
M`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B;W9E('-E87)C:"!F;W)M
M`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97!T(')E<75E<W0`06-C97!T960`
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-E<W,@9&5N:65D('1O("5S
M`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT
M(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@)7,`061D($-H
M:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@
M3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U
M<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@
M82!N97<@=7-E<CH`061D(&%D9')E<W,@8F]O:P!!9&0@86YD($1E;&5T92!)
M35-0(&%D9')E<W,@8F]O:W,`061D(&-O;'5M;@!!9&0@9FEL90!!9&0@;F5W
M(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;P!!9&0@
M=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U
M<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B
M)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D960@
M82`E<R!L:6YK('1O("5S+@!!9&1I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL
M86)L92X`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!9&1R97-S($)O;VL@3&ES=&EN9P!!9&1R97-S($)O;VMS`$%D
M9')E<W,@8F]O:R!E;G1R>0!!9&1R97-S(&)O;VL@:7,@<F5A9"UO;FQY+@!!
M9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"X`061D<F5S<R!B;V]K
M('1O(&1E;&5T92``061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I
M<W!L87EE9#H`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%D=F%N8V5D(%-E87)C:`!!
M9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM
M96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!
M;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_
M`$%L<F5A9'D@17AI<W1S`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0
M($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0
M(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T
M96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&5R
M<F]R(&]C8W5R<F5D(&9O;&QO=VEN9R!T:&ES(&QI;FLZ("5S`$%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@
M;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R
M;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P
M;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D
M>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@
M4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE
M(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT
M('1O(&1E;&5T92`E<S\`07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@
M9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/P!!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S
M=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)
M22TX*0!!<G0`07)U8F$`07-C96YD:6YG`$%S8V5N<VEO;B!)<VQA;F0`07-C
M:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG
M;FUE;G0@8V]L=6UN<P!!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!R
M97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1R:6)U=&5S`$%U9W5S=`!!=7-T
M<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I
M<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H
M('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S
M`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A
M=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L
M9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`07IU<@!"3T9(($5X
M8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O
M<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A
M:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87(@5&EM
M90!"87(@=&EM90!"87)B861O<P!"87)B:64`0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)A<VEC(%-E87)C:`!"
M96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;&]W('-E87)C:"!F;W)M`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`$)I;F0@9F%I;&5D.B`H)7,I("5S`$)I<G1H9&%Y
M`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L
M;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQU92!-;V]N`$)L=64@86YD(%=H
M:71E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC
M:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O
M='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN
M9&EA;B!/8V5A;B!497)R:71O<GD`0G)O=VX`0G)O=W-E`$)R=6YE:2!$87)U
M<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U
M<FYT($]R86YG90!"=7)U;F1I`$)U<VEN97-S($-A=&5G;W)Y`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL(%!R;W!E<G1I97,N
M+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L
M;0!#86UB;V1I80!#86UE<F]O;@!#86UO=69L86=E`$-A;B!N;W0@<F5S970@
M<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D9"!A
M(&=R;W5P('1O(&ET<V5L9BX`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S
M97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC
M96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A
M;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E
M960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M
M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E
M;B!E>&ES="X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A
M8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE
M<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86ER(%!E<G-O;@!#:&%N
M9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E(&1E9F%U;'0@:61E;G1I
M='D`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H
M86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H
M92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!?06QL+TYO;F4`
M0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T
M;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAI;F5S92!3
M:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I
M`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@;F%M90!#:&]O<V4@82!P
M87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@86-T:6]N.@!#
M:&]O<V4@86X@861D<F5S<R!B;V]K`$-H;V]S92!A;B!A9&1R97-S(&)O;VLZ
M`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!W:&EC:"!A9&1R
M97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.@!#:&]O
M<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N`$-H;V]S92!W:&EC:"!C
M;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H870@;W)D97(Z`$-H<FES=&UA
M<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L
M96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T
M('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG
M($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#
M;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@
M*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@
M8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E
M;&5C=&EO;@!#;VQS.@!#;VQU;6X@3W!T:6]N<P!#;VQU;6X@=&ET;&5S`$-O
M;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z`$-O;6EC<P!#;VUM
M82!S97!A<F%T960@=F%L=65S`$-O;6UA('-E<&%R871E9"!V86QU97,@*$UI
M8W)O<V]F="!/=71L;V]K*0!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N
M=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&%N>2!!9&1R97-S
M`$-O;7!L971E9`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N
M9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#
M;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N
M97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL
M960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!F86EL960Z("5S
M`$-O;FYE8W1I;VX@9F%I;'5R90!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W0@3&ES=`!#;VYT86-T(%-E
M87)C:`!#;VYT86-T<P!#;VYT86-T<R!I;B!L:7-T.B`E<P!#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F
M("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@
M9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W)N9FQO=V5R`$-O<W0@240`
M0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E+@!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S
M(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@)R5S)RX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!M
M:V1I<B`G)7,G+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG
M+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@)R5S)R!F;W(@
M=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO
M="!O<&5N(&1I<F5C=&]R>2`G)7,G+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T
M(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R
M)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!R;61I<B`G)7,G
M+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L
M9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN
M:R`B)7,B+@!#;W5L9"!N;W0@=6YL:6YK("<E<R<N`$-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E
M<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E
M<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E
M<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R
M96%T92!!9&1R97-S($)O;VL`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M0V]N=&%C="!,:7-T(&EN.@!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@
M9F]L9&5R<P!#<F5A=&5D`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A
M<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E
M;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E
M;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``
M0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H
M2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R
M964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D
M`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$
M96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U
M;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE
M;&P`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L
M96=A=&4@<&]S:71I;VX`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@061D<F5S
M<R!";V]K`$1E;&5T92!#96QL`$1E;&5T92!#;VYF:7)M871I;VX`1&5L971E
M($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N
M9"!P=7)G92!M97-S86=E<P!$96QE=&4@8G5T=&]N(&)E:&%V:6]U<@!$96QE
M=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4`1&5L971E(&9A:6QE9#H@*"5S*2`E<P!$96QE=&4@;65S
M<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L
M971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F
M;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C
M=7)R96YT(')O=P!$96QE=&4@=&AI<R!L:6YK`$1E;&5T960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@(B5S(BX`1&5L971I;F<@8V]N=&%C=',@:7,@;F]T(&%V
M86EL86)L92X`1&5L971I;VX@9F%I;&5D`$1E;&EV97)Y('1I;64`1&5N;6%R
M:P!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF
M;W)M871I;VX`1&5P87)T;65N=`!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L
M87D`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I
M`$1I<W!L87D@9F]R;6%T`$1I=FED97(`1&II8F]U=&D`1&\@;F]T(&1E;&5T
M90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y
M;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`
M1&]W;FQO860@=D-A<F0`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@
M(B5S(@!%9&ET($%D9')E<W,@0F]O:W,`161I="!";&]C:P!%9&ET($=R;W5P
M`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S`$5D:70@96YT<GD@9F]R("5S`$5D:70@;W!T:6]N<R!F
M;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N
M<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N
M+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3
M($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L
M="X`16UP='D@<V5A<F-H('1E<FUS`$5N9`!%;F0@>65A<@!%;FQA<F=E($5D
M:71O<@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E
M<G,@8F5L;W<Z`$5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H
M92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,`16YT<GD@9F]R("5S('5P9&%T
M960N`$5R<F]R`$5R<F]R(&%D9&EN9R`E9"!C;VYT86-T*',I('1O(&QI<W0N
M`$5R<F]R(&%D9&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C="AS*2!T
M;R!L:7-T+@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I
M;F<@)60@8V]N=&%C="AS*2X`17)R;W(@9&5L971I;F<@)60@;V8@)60@<F5Q
M=65S=&5D(&-O;G1A8W1S*',I+@!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO
M<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I
M;F<@8V]N=&5N=#H@)7,`17)R;W(@<F5M;W9I;F<@)60@8V]N=&%C="AS*2!F
M<F]M(&QI<W0N`$5R<F]R(')E;6]V:6YG("5D(&]F("5D(')E<75E<W1E9"!C
M;VYT86-T*',I(&9R;VT@;&ES="X`17)R;W(@<V5A<F-H:6YG('1H92!A9&1R
M97-S(&)O;VLZ("5S`$5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+@!%<G)O<B!U
M<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=W)I=&EN9R`B)7,B+@!%<G)O
M<B!W<FET:6YG("<E<R<N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P
M90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M:70@061D<F5S<R!";V]K`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E
M9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R="!!9&1R
M97-S($)O;VL`17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+@!%
M>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2X`
M1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B
M;V]K.B`E<P!&86EL960@=&\@861D("5S('1O("5S.B`E<P!&86EL960@=&\@
M8G)O=W-E(&QI<W0`1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y`$9A
M:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE
M=R!$3B`]("5S+"!2;V]T(#T@)7,`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A
M:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S
M(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL
M960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S`$9A:6QE9"!T;R!M
M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I;&5D('1O
M('-E87)C:"!T:&4@861D<F5S<R!B;V]K`$9A:6QE9"!T;R!S96%R8V@@=&AE
M(&1I<F5C=&]R>3H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U
M87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3
M;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE
M="!F;VYT`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U
M;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE
M8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M`$9I;&5S`$9I;'1E<G,`1FEN9`!&:6YI<V@`1FEN;&%N9`!&:7)S="!(86QF
M`$9I<G-T($YA;64`1FER<W0@475A<G1E<@!&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O
M<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`
M1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R
M;W!O;&ET86X`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O0G5S>2!297!L
M>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS
M90!&<F5E8G5S>2!54DP`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA
M`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&
M=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R
M871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'
M97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!!9&1R
M97-S($)O;VL`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S
M`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E;@!'<F5E;FQA
M;F0`1W)E;F%D80!'<F5Y`$=R;W5P`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R
M;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L
M971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,`1W)O=7!S`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E
M<FUI<W-I;VYS`$=U97-T(%-E<G9I8V5S`$=U97-T8F]O:P!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T
M(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D
M97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4
M+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5I9VAT("AI
M;B!P:7AE;',I`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES
M<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H
M`$AO7VUE`$AO;64`2&]M92!!9&1R97-S`$AO;64@0VET>0!(;VUE($-O=6YT
M<GD`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VUE(%!O<W1A;"!#;V1E
M`$AO;64@4W1A=&4O4')O=FEN8V4`2&]M92!3=')E970@061D<F5S<P!(;VYD
M=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`
M2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L
M.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N
M>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(
M=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)35-0`$E-4U`@061D
M<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N`$E0($%D9')E<W,`25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E
M9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@
M4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC
M;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D
M:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I
M;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N
M970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T
M;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA
M9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G
M86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E
M<P!);7!O<G0@061D<F5S<R!";V]K+"!3=&5P("5D`$EM<&]R="P@4W1E<"`E
M9`!);7!O<G0O17AP;W)T($%D9')E<W,@0F]O:W,`26UP;W)T960@9FEE;&0Z
M("5S`$EM<&]R=&5D(&9I96QD<SH`26X@4')O8V5S<P!);E]S97)T(%)O=R!!
M9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC
M<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA
M`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL
M86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R
M="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E
M`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O
M;7!O;F5N="X`26YV86QI9"!)1`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@861D<F5S<R!B;V]K
M`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L
M:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RX`26YV86QI9"!E;6%I;`!);G9A;&ED(&5N=')Y`$EN=F%L:60@9FEL92!F
M;W)M870`26YV86QI9"!K97D@<W!E8VEF:65D+@!);G9A;&ED(&QI8V5N<V4@
M:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T
M>7!E+@!);G9A;&ED(&YA;64`26YV86QI9"!O8FIE8W1)9`!);G9A;&ED(&]R
M(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R
M<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R
M(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`
M26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`
M26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N
M`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M
M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N
M=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D
M86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&
M=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$ME;GEA`$ME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N
M`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G
M90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M`$MI9',`2VER:6)A=&D`2V]L86(`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE
M)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#
M+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,1$%0('-U<'!O<G0@:7,@<F5Q=6ER
M960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO
M="!L;V%D960N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@36]D:69I960`3&%S="!.
M86UE`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P
M9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`
M3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=F5N9&5R`$QA=P!,87EO=70`
M3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H
M96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA
M;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!";'5E`$QI
M9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT
M(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@
M5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K
M`$QI;FL`3&EN:R!A9&1E9"X`3&EN:R!C86YC96QE9"X`3&EN:R!P;VEN=',@
M=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0`3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI
M<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M
M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R
M:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z
M("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO
M8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO
M9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@
M9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N
M(&YU;6)E<G,`3&]Y;VQA`$QO>6]L82!";'5E`$QU>&5M8F]U<F<`34T`34]4
M1`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-
M86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?
M:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C
M871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T
M;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G
M<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<`36%T
M8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D
M(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI
M;75M($YU;6)E<B!O9B!#;VYT86-T<P!-87AI;75M($YU;6)E<B!O9B!0;W)T
M86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F('!A
M9V5S`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE971I;F<@0V%N8V5L;&%T:6]N
M`$UE971I;F<@26YF;W)M871I;VX`365E=&EN9R!0<F]P;W-A;`!-965T:6YG
M(%)E<&QY`$UE971I;F<@57!D871E`$UE971I;F<@57!D871E(%)E<75E<W0`
M365M8F5R<P!-96YU($QI<W0`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S
M86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG
M;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S
M86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO
M9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L
M;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@
M<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E
M;&QA;F5O=7,`36ES<VEN9R!$3B!I;B!,1$%0('-O=7)C92!C;VYF:6=U<F%T
M:6]N+@!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I
M;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W
M(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG
M(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]B:6QE
M(%!H;VYE`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1I
M9GD@9F%I;&5D.B`H)7,I("5S`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@
M;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N
M='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE
M("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)E('1H86X@,2!E;G1R>2!F
M;W5N9`!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L
M>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-
M;W9E(%5P`$UO=F4@9&]W;@!-;W9E(&QE9G0`36]V92!R:6=H=`!-;W9E('5P
M`$UO>F%M8FEQ=64`36]Z:6QL80!-=6QB97)R>2!!9&1R97-S($)O;VL`375L
M=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT
M:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H
M(&YA;64@6R5S72!A;')E861Y(&5X:7-T`$UU;'1I<&QE('-E;&5C=&EO;@!-
M>2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@061D<F5S<R!"
M;V]K`$UY($%D9')E<W,@0F]O:W,`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO
M=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UE($9O<FUA
M=`!.86UI8FEA`$YA=7)U`$YE6%0`3F5E9',@06-T:6]N`$YE<&%L`$YE=&-E
M;G1E<B!-96UB97(@1&ER96-T;W)Y`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S
M($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E(%)E;F5W86P@
M55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V
M97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E
M(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA
M`$YE=R!#871E9V]R>0!.97<@0V]N=&%C=`!.97<@365S<V%G92!T;R`E<P!.
M97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.
M97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.
M97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI
M`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I
M;VYS`$YE>'0^`$YI8V%R86=U80!.:6-K;F%M90!.:6=E<@!.:6=E<FEA`$YI
M9VAT`$YI=64`3F\`3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S`$YO(&%D9')E
M<W,@8F]O:W,@9F]U;F0N`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E
M+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.
M;R!C;VYT86-T<R!F;W5N9`!.;R!C<F5D:70@;&5F="X`3F\@9&5S8W)I<'1I
M;VX@9F]U;F0`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L
M;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA
M;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I
M=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&5N9&EN9R!S:6=N=7!S+@!.
M;R!Q=6]T82!S970`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T
M;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R
M87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=D-A<F0@9&%T82!W87,@9F]U
M;F0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N
M(%!A<G1I8VEP86YT`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)F;VQK
M($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@
M27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER
M96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D
M+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E`$YO
M=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@
M8V]L=6UN<P!.=6UB97(@;V8@:71E;7,@<&5R('!A9V4`3G5M8F5R(&]F(')O
M=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T
M<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]B:F5C
M="!N;W0@9F]U;F0`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I
M8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/
M;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N
M`$]N8V4@>6]U('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@
M8F]O:R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N($EF('1H:7,@:7,@
M;F]T('=H870@>6]U('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@
M<V5L96-T:6]N('1O(").;VYE(BX`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY(&]N92!V8V%R9"!S
M=7!P;W)T960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS
M(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T
M:6YG(%-Y<W1E;0!/<'1I;VYA;"!087)T:6-I<&%N=`!/<'1I;VYS`$]P=&EO
M;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T
M:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@
M26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N<P!0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I
M;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D
M($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-
M(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M
M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`
M4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL
M($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A
M<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I
M<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M
M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG
M(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D
M+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N(&1E;FEE9`!097)M:7-S
M:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O
M<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I
M;F4@061D<F5S<R!";V]K`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&YA;64@=&AE(&YE=R!C;VYT86-T
M(&QI<W0Z`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R979I97<@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T(&-O;G1A
M8W0`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`
M4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F
M;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0;W-T;G5K90!0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R
M("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@
M;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W`%!R979I;W5S`%!R979I;W5S(&]P=&EO;G,`4')I
M;G0@9&]C=6UE;G0`4')I=F%T92!!9&1R97-S($)O;VL`4')I=F%T92!+97D`
M4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T
M97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME
M>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R
M`%%U97)Y`%%U97)Y(&9A:6QE9#H@*"5S*2`E<P!1=6EC:R!396%R8V@`475O
M=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A
M:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@
M4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!2
M96%D(&9A:6QE9#H@*"5S*2`E<P!296%D(&UE<W-A9V5S`%)E861I;F<@8V]N
M=&%C=',@:7,@;F]T(&%V86EL86)L92X`4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(&1E;&5T92!T
M:&ES(&-O;G1A8W0_`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-O<F1S
M(&1I<W!L87EE9#H`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@
M5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R
M:W,`4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M;W1E
M(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&%D9')E<W,@8F]O
M:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M
M(&UY(&-A;&5N9&%R`%)E;6]V92!F<F]M('1H:7,@;&ES=`!296UO=F4@<&%I
M<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297!L
M86-E(&5X:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I;7!O<G1E9"!O
M;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R!D96QE=&5S(&%L;"!E;G1R:65S
M(&EN('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN/"]S=')O;F<^`%)E<&QY
M(%-E;G0N`%)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E`%)E<&QY
M('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+@!297!L>2!W:71H
M(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E<&QY.B`E<P!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z(`!297%U97-T960@;V)J96-T(&YO="!F;W5N9"X`4F5Q=65S=&5D('-E
M<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S
M<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M1FEE;&0`4F5Q=6ER960@4&%R=&EC:7!A;G0`4F5S970`4F5S970@4&%S<W=O
M<F0`4F5S970@66]U<B!087-S=V]R9`!297-E="!T;R!$969A=6QT<P!297-T
M;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y
M<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@
M:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2
M;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A
M=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!3+TU)344@4'5B;&EC($-E<G1I9FEC
M871E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3
M($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<P!34T@`4U1!4E143%,@9F%I;&5D.B`H)7,I("5S`%-50T-%4U,`
M4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE
M=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E
M;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A
M=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`
M4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V%V:6YG(&-O;G1A8W1S
M(&ES(&YO="!A=F%I;&%B;&4N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E
M`%-E87)C:`!396%R8V@@16YG:6YE<P!396%R8V@@9F%I;&5D`%-E87)C:"!F
M86EL960Z("5S`%-E87)C:&EN9R!I<R!N;W0@879A:6QA8FQE+@!396%R8VAI
M;F<N+BX`4V5L96-T`%-E;&5C="!!9&1R97-S($)O;VL`4V5L96-T($9I;&5S
M`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A
M(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A
M9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L
M96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4`4V5L96-T(&%N(&%D9')E
M<W,@8F]O:R!T;R!E9&ET`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`
M4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ`%-E;&5C
M="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SH`4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R
M96$N`%-E;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M
M870Z`%-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F:6QE
M('1O(&EM<&]R=#H`4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F
M:6QE.@!396QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@;F%M97,Z
M`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('9I97<@=&\@
M9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@
M;W!T:6]N<RX`4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P;&%Y(&EN('1H
M92!A9&1R97-S(&QI<W1S+@!396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L
M87D@;F%M97,N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396QE8W1E9"!A9&1R97-S(&)O;VL@
M(B5S(BX`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B
M:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W
M<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@
M240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&%R
M960@1&ER96-T;W)Y`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO
M=R`E<P!3:&]W($%L;`!3:&]W($-O;G1A8W1S`%-H;W<@3&ES=',`4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I
M9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@
M8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W
M('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H
M;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE
M<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET
M:&T`4VEM<&QE>`!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L
M;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S
M`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E
M<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA
M;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T($1I<F5C=&EO;@!3;W)T
M(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5R8V5S`%-O=71H
M($%F<FEC80!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!E8VEF>2!W:&5R
M92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I
M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!Y96%R`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E
M<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L
M;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3
M=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@861D960@)60@8V]N=&%C="AS*2!T
M;R!L:7-T+@!3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,`4W5C8V5S<V9U
M;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A8W0@;&ES="`B)7,B
M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@9&5L
M971E9"`E9"!C;VYT86-T*',I+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E;6]V960@)60@8V]N
M=&%C="AS*2!F<F]M(&QI<W0N`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A
M=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S
M9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A
M;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR
M:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R
M:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@
M9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3
M>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y
M`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135@!44U8@9FEL90!486(@<V5P
M87)A=&5D('9A;'5E<P!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E
M=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E86P`5&5L97!H;VYE($YU;6)E<@!496UP(&9O
M<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E
M<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@
M(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E;G1A
M=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E
M>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M
M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN
M`%1H92`E<R!L:6YK('1O("5S(&AA<R!B965N(')E;6]V960N`%1H92!&5%`@
M97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E
M;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N
M9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@
M:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(%9&4R!B86-K96YD(&YE961S('1O
M(&)E(&-O;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RX`
M5&AE(&%D9')E<W,@8F]O:R`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@861D
M<F5S<R!B;V]K("(E<R(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+@!4:&4@
M861D<F5S<R!B;V]K("(E<R(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+@!4
M:&4@861D<F5S<R!B;V]K("(E<R(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D
M+@!4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S`%1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M
M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R(&1A
M=&$@:7,@:6YV86QI9`!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!C;VYT86-T('EO=2!R97%U97-T
M960@9&]E<R!N;W0@97AI<W0N`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E
M(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A
M9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+@!4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U
M<B!C86QE;F1A<BX`5&AE(&9I;&4@(B5S(B!H87,@<W5C8V5S<V9U;&QY(&)E
M96X@9&5L971E9"X`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H
M92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!I;7!O<G0@
M8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S+@!4:&4@;&5F
M="UH86YD('-I9&4@;VYL>0!4:&4@;&EN:R!H87,@8F5E;B!R96UO=F5D`%1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N
M("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE
M9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I
M96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H
M92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@
M:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C
M=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4
M:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H
M92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S
M(&YO="!E>&ES="X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M`%1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H
M92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X
M="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S
M8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@
M<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N`%1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A
M<R!S=6-E<W-F=6QL>2!S=&]R960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@
M;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL
M86)L92!A9&1R97-S(&)O;VMS(&%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO
M=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@
M=&AI<R!I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BX`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T
M:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B
M(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I
M;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R
M;W(@861D:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&9O<B!F=7)T:&5R(&AE;'`N`%1H97)E('=A<R!A
M;B!E<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+@!4:&5R92!W87,@86X@97)R
M;W(@8W)E871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R`B)7,B(&9R;VT@=&AE('-O=7)C92!A9&1R97-S
M(&)O;VLN`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A
M8W0Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!L:7-T
M`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P
M87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@
M9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@
M)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S
M+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@
M)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T
M:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A
M(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN
M9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG
M('1H:7,@861D<F5S<R!B;V]K.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<P!4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,`5&AE<F4@
M=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4:&5S92!A9&1R97-S(&)O
M;VMS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4:&5S92!C;VQU;6YS
M('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&%C=&EO
M;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM
M<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI
M9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K
M871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6
M;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E
M<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R
M871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T
M868G+@!4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N`%1H:7,@
M9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('!E<G-O;B!A;')E861Y(&AA<R!A("5S(&5N
M=')Y(&EN('1H92!A9&1R97-S(&)O;VL`5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+@!4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K('=H
M96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RX`5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R
M`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@
M<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`
M5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN
M9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO
M<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`
M5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`
M5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z
M(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE("5S
M+R5S`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R92X@36ES<VEN
M9R!S;W5R8V4@='EP92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B``56YF:6QE9`!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S
M`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@
M2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E
M<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`
M56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<P!5;G-U<'!O<G1E9"!%>'1E
M;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T
M=7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D
M96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P
M(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P
M97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@
M4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G
M:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA
M;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S
M97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T
M97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`
M5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)I<VEG
M;B!$:7)E8W1O<GD`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@
M86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I
M970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`B)7,B`%9I97<@)7,`
M5FEE=R!#;VYT86-T`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A
M<R`E<P!6:65W(&5V96YT`%9I97<@=&%S:P!6:65W('1O(&1I<W!L87D@8GD@
M9&5F875L=#H`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N
M9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A
M;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.
M54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA
M`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O
M=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E8F)P;&%T<V5N
M("T@4V]B97(`5V5B8G!L871S96X@+2!3;V)E<B!.15<`5V5B<VET92!54DP`
M5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T
M97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R
M;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A
M9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`
M5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI
M82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N
M:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED
M=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E
M9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`
M5V]R:R!!9&1R97-S`%=O<FL@0VET>0!7;W)K($-O=6YT<GD`5V]R:R!0:&]N
M90!7;W)K(%!O<W1A;"!#;V1E`%=O<FL@4W1A=&4O4')O=FEN8V4`5V]R:R!3
M=')E970@061D<F5S<P!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@
M=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A
M(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN
M(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A
M8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S(&EN("(E<R(N`%EO=2!A<F4@
M;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C
M:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!C86YN;W0@:&%V92!T
M:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N
M;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="X`66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VYS('1O(&1E;&5T92!T:&ES('-O=7)C92X`
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R
M969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T
M(&%D9')E<W,@8F]O:RX`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N
M`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C
M="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="X`66]U(&UU<W0@<V5L96-T
M(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=2!O;FQY
M(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U<B`E
M<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO
M=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF
M;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R
M($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@
M=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D
M:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O
M<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!A9&1R97-S(&)O
M;VL@:7,@;F]T(&)R;W=S96%B;&4N`%EO=7(@9&5F875L="!I9&5N=&ET>2!H
M87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@
M9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W
M;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S
M97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P
M>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1
M=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML
M:6YE("5S(&]F("5S70!;;F\@=F%L=65=`%]!9&UI;FES=')A=&EO;@!?0G)O
M=W-E`%]#3$D`7T-O;G1A8W1S`%]$871A5')E90!?1&5L971E`%]$96QE=&4@
M4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TEM<&]R
M="]%>'!O<G0`7TQI<W1S`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK
M+BXN`%]->2!!9&1R97-S($)O;VMS`%].97<@0V]N=&%C=`!?3W!T:6]N<P!?
M4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]296UO=F4@9G)O;2!T:&ES
M(&QI<W0`7U-E87)C:`!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S
M97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C
M86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP
M=70`8VQI8VL@:&5R90!C;&]C:P!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`
M8V]N9FEG=7)A=&EO;B!E<G)O<@!C;VYT86-T+G9C9@!C;VYT86-T<RYC<W8`
M8V]N=&%C=',N='-V`&-O;G1A8W1S+G9C9@!C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O
M=6YD`&9A;&QI;F<`9FEL90!F<F]M`&9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`
M:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N`&UM`&YA;64`;F\@9F]R;6%T=&EN9P!N;VYE`&YO="!I;7!L96UE
M;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M
M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L
M`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`
M<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S
M:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1O(&$@0V]N=&%C="!,:7-T`'1O
M(&$@9&EF9F5R96YT($%D9')E<W,@0F]O:P!T>7!E('1H92!P87-S=V]R9"!T
M=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V
M0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A
M(#(N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ-2`Q,#HP-RLP,3`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,34@,3$Z,34K,#$P,`I,87-T+51R
M86YS;&%T;W(Z($IO87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T
M<V5N+G-E/@I,86YG=6%G92U496%M.B!3=V5D:7-H(#QI,3AN0&QI<W1S+FAO
M<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A
M;#TH;B`A/2`Q*3L*`"`F(S$U,3L@)7,@:V]M;65R(&%T="!U=&;V<F$@9&4@
M=6YD97)HY6QL<V%K=&EV:71E=&5R;F$@<V]M(&UA<FME<F%T<R!N961A;BX`
M("@E<R!D86=A<B!S961A;BD`("AS;F%B8G1A;F=E;G0@)7,I`"`H4VMR:79S
M:WED9&%D*0`@*&]M("5S(&1A9V%R*0`@*&ED86<I`"`H:6UO<F=O;BD`("AI
M9^5R*0`@3.1G9R!T:6QL(&5N($E-4U`M861R97-S8F]K`"!2861E<F$@24U3
M4"UA9')E<W-B;VL`(&ML(``G)7,G(&9I;FYS(')E9&%N(&]C:"!I;7!O<G1E
M<F%D97,@:6YT92X`)R5S)R#D<B!I;G1E(&5N(&MA=&%L;V<N`"<E<R<@Y'(@
M:6YT92!E='0@9V]D:^1N="!V86PN`"<E<R<@Y'(@:6YT92!K;VYF:6=U<F5R
M870@:2!(;W)D97)E9VES=')E<G0N`%1RY&1H86YT97)A<F5N(&;V<B`E<R!S
M86MN87,N`"<E<R<@;&%D97,@=&EL;"!I(&=R=7!P<WES=&5M970N`"<E<R<@
M;&%D97,@=&EL;"!I(&)E:/9R:6=H971S<WES=&5M970N`"<E<R<@:V]P:65R
M861E<R!I;G1E(&5F=&5R<V]M(&1E="#D<B!E;B!L:7-T82X`)R5S)R!S:V%P
M861E<R!I;G1E.B`E<RX`)R5S)R!F;'ET=&%D97,@:6YT92!E9G1E<G-O;2!D
M970@Y'(@96X@;&ES=&$N`")&]G)N86UN($5F=&5R;F%M;B(@("A*;VAN($1O
M92D`(D5F=&5R;F%M;BP@1O9R;F%M;B(@*$1O92P@2F]H;BD`)2XR9DU"(&%N
M=N1N="!A=B`E+C)F34(@=&EL;.5T970@*"4R9B4E*0`E9"`E<R!O8V@@)7,`
M1&ET="!L]G-E;F]R9"!U<'!H]G(@871T(&?D;&QA(&]M("5D(&1A9V%R+@`E
M9"UD86=S<')O9VYO<P`E<R`M($;V<B!KY&YN961O;0!&:6YG97)P<FEN="!F
M]G(@)7,`)7,@2T(`)7,@56YD97)HY6QL<V9U;FMT:6]N("T@0F5K<N1F=&5L
M<V4`)7,@4V5T=7``)7,@86YMY&QA;@!4:N1N<W1E879T86P@9O9R("5S`"5S
M(&QA9&5S('1I;&PN`"5S(&9I;FYS(')E9&%N+@`E<R!K;"`E<R`E<P`E<RUF
M:6QE;B#D<B!I;7!O<G1E<F%D`"5S(&AA<B!A;FYU;&QE<F%T("5S+@`E<R!H
M87(@<W9A<F%T('#E(&5N(&)E9^1R86X@;VT@:6YF;W)M871I;VX@86YGY65N
M9&4@;&5D:6<O=7!P=&%G96XN`"5S(&AA<B!S=F%R870@<.4@:6YB:G5D86X@
M=&EL;"`E<RX`)7,@:&%R('-K:6-K870@9&EG(&EN9F]R;6%T:6]N(&]M(&QE
M9&EG+W5P<'1A9V5N+@`E<R!K;VUM97(@871T('5T9O9R82!D92!U;F1E<FCE
M;&QS86MT:79I=&5T97)N82!S;VT@;6%R:V5R871S(&YE9&%N+B!-87)K97)A
M(&1E(&%K=&EV:71E=&5R('-O;2!D=2!V:6QL('5T9O9R82X`)7,@:W+D=G,`
M)7,@;6EN=71E<@`E<R!S86MN87,N`"5S(&5F=&5R9G+E9V%R(&EN9F]R;6%T
M:6]N(&]M(&[D<B!D=2#D<B!L961I9R]U<'!T86=E;BX`)7,@969T97)F<N5G
M87(@9&EN(&[D<G9A<F\@=FED("5S+@`E<R!T:6QL("5S(&%V("5S`"5S('9I
M;&P@;.1G9V$@=&EL;"!T:6QL("5S+@`E<R!V:6QL(&?V<F$@9&EG(&UE9'9E
M=&5N(&]M("5S+@`E<R!V:6QL(&5R:.5L;&$@9&5N('-E;F%S=&4@:6YF;W)M
M871I;VYE;B!O;2`E<RX`)7-S(&%D<F5S<V)O:P!+86QE;F1E<B!F]G(@)7,`
M06YT96-K;FEN9V%R(&;V<B`E<P!5<'!G:69T97(@9O9R("5S`"5S.B`E<P`E
M<SH@365D9&5L86YD970@:V%N<VME(&EN=&4@Y'(@9G+E;B!D96X@<V]M(&1E
M="!V97)K87(N(%9A<B!F]G)S:6MT:6<@;65D(&%T="!F]FQJ82!LY&YK87(@
M96QL97(@<VMI8VMA(&%V<^1N9&%R96X@<&5R<V]N;&EG(&EN9F]R;6%T:6]N
M+@`L('-T;W)M8GEA<@`L('-T;W)M8GEA<B`E<R`E<P`L('9A<FEE<F%N9&4@
M;65L;&%N("5S(&]C:"`E<P`M+2!VY&QJ("TM`#$R+71I;6UA<G-F;W)M870`
M,C0M=&EM;6%R<V9O<FUA=``R-"!T:6UM87(`/$;V<F5GY65N9&4`16X@=V5B
M;.1S87)E('-O;2!S=/9D:F5R(&E&<F%M97,@:W+D=G,`16X@9&%T86)A<VMO
M<'!L:6YG(&MRY'9S(&;V<B!A:W1U96QL="!B;&]C:RX`171T(&9A=&%L="!F
M96P@:&%R(&EN='+D9F9A=`!%;B!P=6)L:6L@4$=0+6YY8VME;"!K<N1V<R!F
M]G(@871T(&MR>7!T97)A(&5T="!M961D96QA;F1E+@!%;B!P=6)L:6L@4$=0
M+6YY8VME;"!K<N1V<R!F]G(@871T('9E<FEF:65R82!E='0@<VEG;F5R870@
M;65D9&5L86YD92X`16X@<'5B;&EK(&]C:"!P<FEV870@4$=0+6YY8VME;"!S
M86UT(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@9&5K<GEP=&5R82!E='0@;65D
M9&5L86YD92X`16X@<'5B;&EK(&]C:"!P<FEV870@4$=0+6YY8VME;"!S86UT
M(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@<VEG;F5R82!E='0@;65D9&5L86YD
M92X`16X@<'5B;&EK(&]C:"!P<FEV870@4R]-24U%+6YY8VME;"!S86UT(&SV
M<V5N;W)D(&MRY'9S(&;V<B!A='0@9&5K<GEP=&5R82!E='0@;65D9&5L86YD
M92X`16X@<'5B;&EK(&]C:"!P<FEV870@4R]-24U%+6YY8VME;"!S86UT(&SV
M<V5N;W)D(&MRY'9S(&;V<B!A='0@<VEG;F5R82!E='0@;65D9&5L86YD92X`
M16X@<'5B;&EK(%,O34E-12UN>6-K96P@:W+D=G,@9O9R(&%T="!K<GEP=&5R
M82!E='0@;65D9&5L86YD92X`1O9R;6ED9&%G<VUO;&X`3.1T="!F]G)M:61D
M86=S<F5G;@!&]G)M:61D86=S<F5G;@!&]G)M:61D86=S<VMU<F%R`$;V<FUI
M9&1A9W-S:W5R87(@;65D('-N]@!!32]030!!4$D@240`3VT@961I=&]R;@!/
M;2XN+@!/=F%N9O9R('/V:V9O<FUU;.1R`$)O='1E;@!-:71T96X`06-C97!T
M97)A(&)E9^1R86X`06-C97!T97)A9`!"96CV<FEG:&5T('-A:VYA<R!A='0@
M<VMA<&$@5D93+6UA<'`N`$)E:/9R:6=H970@<V%K;F%S(&%T="!S:V%P82!6
M1E,M9FEL+@#%=&MO;7-T(&YE:V%D97,@=&EL;"`E<P!+;VYT;VEN9F]R;6%T
M:6]N`$SV<V5N;W)D(&;V<B!K;VYT;P!+;VYT;W0@9G)Y<W0`0G5D9V5T`,5T
M9^1R9&5R`$SD9V<@=&EL;`!,Y&=G('1I;&P@)7,`3.1G9R!T:6QL('5N9&5R
M9W)U<'``;.1G9R!T:6QL('5N9&5R8F5H]G)I9VAE=`!,Y&=G('1I;&P@:.1R
M.@!,Y&=G('1I;&P@;GD@9W)U<'``3.1G9R!T:6QL(&YY(&)E:/9R:6=H970`
M3.1G9R!T:6QL('5N9&5R9W)U<'`@=&EL;"`G)7,G`$SD9V<@=&EL;"!U;F1E
M<F)E:/9R:6=H970@=&EL;"`G)7,G`$SD9V<@=&EL;"!E;B!N>2!A;G;D;F1A
M<F4Z`$YY(&%D<F5S<V)O:P!,Y&=G('1I;&P@;V-H(')A9&5R82!)35-0+6%D
M<F5S<V+V8VME<@!,Y&=G('1I;&P@:V]L=6UN`$SD9V<@=&EL;"!F:6P`3.1G
M9R!T:6QL(&YY82!M961L96UM87(`3.1G9R!T:6QL('!A<@!,Y&=G('1I;&P@
M;65N>6X@9O9R("5S('-O;2!-;WII;&QA(%-I9&5B87(`3.1G9R!T:6QL(&D@
M;6EN(&MA;&5N9&5R`$SD9V<@=&EL;`!,Y&=G('1I;&P@:2!A9')E<W-B;VLZ
M`$SD9V<@=&EL;"!I(&UI;B!A9')E<W-B;VL`3.1G9R!T:6QL(&%N=N1N9&%R
M90!,861E('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+"!M96X@:W5N9&4@:6YT
M92!LY&=G82!T:6QL(&5X=')A("!I;F9O<FUA=&EO;CH@)7,N`$QA9&4@=&EL
M;"`G)7,G('1I;&P@<WES=&5M970N($1U(&MA;B!L;V=G82!I;B!N=2X`3&%D
M92!T:6QL(&5N("5S+6SD;FL@=&EL;"`E<RX`1&5T(&?E<B!I;G1E(&%T="!L
MY&=G82!T:6QL(&MO;G1A:W1E<BX`57!P;.1G9R!A=B!A;G;D;F1A<F4@Y'(@
M:6YA:W1I=F5R870N`$%D<F5S<P!!9')E<W-B;VL`061R97-S8F]K<VQI<W1A
M`$%D<F5S<V+V8VME<@!!9')E<W-B;VMS<&]S=`!!9')E<W-B;VL@:V%N(&5N
M9&%S="!LY'-A<RX`061R97-S8F]O:V5N(.1R('3V;60N`$%D<F5S<V)O:R!S
M;VT@<VMA;&P@<F%D97)A<R``061R97-S8O9C:V5R('-O;2!I;G1E('9I<V%S
M.@!!9&UI;FES=')A=&EO;B`M(&%N9V4@8F5H]G)I9VAE="!F]G(@86YD<F$@
M86YVY&YD87)E`$%D;6EN:7-T<F%T:6]N`%)E:VQA;0!!=F%N8V5R860@<_9K
M;FEN9P!!9F=A;FES=&%N`$%L8F%N:65N`$%L9V5R:65T`$%L:6%S`$IU<W1E
M<F$`2G5S=&5R:6YG.@!!;&QA`$%L;&$@875T96YT:7-E<F%D92!A;G;D;F1A
M<F4`06QL82!G<G5P<&5R`$%L;&$@8F5H]G)I9VAE=&5R`$%L;&$@9GER82!S
M:61O<@!4:6QLY70@9FQE<F$@861R97-S97(`5&EL;.5T(&EN<W3D;&QN:6YG
M(&;V<B!S;W)T97)A9"!L:7-T83\`1FEN;G,@<F5D86X`1FEN;G,@<F5D86X`
M06QT97)N871I=B!)35-0+6EN;&]G9VYI;F<`06QT97)N871I=G0@;/9S96YO
M<F0@9O9R($E-4U``06QT97)N871I=G0@86YVY&YD87)N86UN(&;V<B!)35-0
M`$%L=&5R;F%T:78@92UP;W-T(&%D<F5S<P!!;'1E<FYA=&EV(&UA;&P`06QT
M97)N871I=B!T97AT.@!!;65R:6MA;G-K82!386UO80!%='0@9F5L('5P<'-T
M;V0@;N1R(&SD;FME;B`H)7,I('-K=6QL92!A;G;D;F1A<P!%='0@9F5L86MT
M:6=T(';D<F1E(&%N9V%V<RX`171T(&]KY&YT(&9E;"!H87(@:6YT<N1F9F%T
M`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;2!P<F]X>0!3=F%R`$%N
M=&%R:W1I<P!!;G1I9W5A(&]C:"!"87)B=61A`$%P<&QI:V%T:6]N`$%P<&QI
M:V%T:6]N<VQI<W1A`$%P<&QI:V%T:6]N96X@Y'(@:VQA<BX`5F5R:W-TY&QL
M('1I;&P@=6YD97)U=&1E;&YI;F=A<@!';V1KY&YN`%5N9V5FY')L:6<@<W1O
M<FQE:P!A<')I;`!!<F%B:7-K("A7:6YD;W=S+3$R-38I`$%R:VEV9FEL<W1O
M<FQE:P!!<FMI=F9I;&YA;6X`Q'(@9&5T('/D:V5R="!A='0@9'4@=FEL;"!R
M861E<F$@)7,_`,1R(&1U('/D:V5R('#E(&%T="!D=2!V:6QL(')A9&5R82!M
M87)K97)A9&4@<&]S=&5R/P#$<B!D970@<^1K97)T(&%T="!D=2!V:6QL('1A
M(&)O<G0@8F5GY')A;B!F]G(@)7,_`,1R(&1E="!SY&ME<G0@871T(&1U('9I
M;&P@<F%D97)A("<E<R<@;V-H(&5V96YT=65L;&$@=6YD97)G<G5P<&5R/P!!
M<F=E;G1I;F$`07)M86YI96X`07)M96YI<VL@*$%235-#24DM."D`2V]N<W0`
M07)U8F$`4W1I9V%N9&4`07-C96YS:6]N($ES;&%N9`!!<V-I:2!K;VYS=`!!
M<VEE;B]3=&EL;&$@:&%V<W)E9VEO;F5N`$9RY6=A(&5F=&5R(&)E:W+D9G1E
M;'-E(&EN;F%N('5N9&5R:.5L;'-A:W1I=FET971E<B!U=&;V<G,_`%1I;&QD
M96QN:6YG<VMO;'5M;@!":69O9V%D(.1R(&5N(&E#86QE;F1E<B!F:6P@;65D
M(&5T="!S=F%R('#E(&5N(&)E9^1R86X@<V]M(&1U('-K:6-K870L`$;V<G/V
M:R!T:6QL(&%T="!R861E<F$@96X@9W)U<'`@<V]M(&EN=&4@9FEN;G,N`$;V
M<G/V:R!T:6QL(&%T="!R861E<F$@96X@8F5H]G)I9VAE="!S;VT@:6YT92!F
M:6YN<RX`1O9R<_9K(&%T="#D;F1R82!E;B!B96CV<FEG:&5T('-O;2!I;G1E
M(&9I;FYS+@!&]G)S]FL@871T(.1N9')A(&5N('5T9&5L;FEN9R!S;VT@:6YT
M92!F:6YN<RX`1&5L=&%G87)E`$%T=')I8G5T`&%U9W5S=&D`075S=')A;&EE
M;@#6<W1E<G)I:V4`075T:%]C>7)S<6PZ($E-05`M97AT96YS:6]N('-A:VYA
M<RX`075T:%]C>7)S<6PZ($MO<'!L:6YG96X@<V%K;F%R(&9U;FMT:6]N97(@
M<V]M(&MRY'9S+@!!=71H7V-Y<G5S.B!)34%0+65X=&5N<VEO;B!S86MN87,N
M`$%U=&A?9G1P.B!&5%`M=&EL;.1G9R!S86MN87,N($MO;7!I;&5R82!02%`@
M;65D('-W:71C:&5N("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!)34%0+65X
M=&5N<VEO;B!S86MN87,N`$%U=&A?:W)B-3H@:W)B-2UE>'1E;G-I;VX@<V%K
M;F%S+@!!=71H7VQD87`Z($1E="!GY7(@:6YT92!A='0@;.1G9V$@=&EL;"!A
M;G;D;F1A<F4@:2!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@1&5T(&?E
M<B!I;G1E(&%T="!R861E<F$@86YVY&YD87)E(&9RY6X@06-T:79E($1I<F5C
M=&]R>0!!=71H7VQD87`Z($Q$05`M=&EL;.1G9R!S86MN87,N`$%U=&A?;&1A
M<#H@2V%N(&EN=&4@;.1G9V$@=&EL;"!A;G;D;F1A<F4@)R5S)RX@4V5R=F5R
M;B!S=F%R861E.B``075T:%]L9&%P.B!+86X@:6YT92!R861E<F$@86YVY&YD
M87)E("5S`$%U=&A?;&1A<#H@2V%N(&EN=&4@=7!P9&%T97)A(&%N=N1N9&%R
M92`E<P!!=71H7VQD87`Z($1E="!GY7(@:6YT92!A='0@=7!P9&%T97)A(&%N
M=N1N9&%R92!I($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@34-!3"UE
M>'1E;G-I;VX@<V%K;F%S+@!!=71H7W-M8F%U=&@Z('-M8F%U=&@M97AT96YS
M:6]N('-A:VYA<RX`075T96YT:7-E<FEN9R!T:6QL($E-05`M<V5R=F5R(&UI
M<W-L>6-K861E<RX`075T96YT:7-E<FEN9R!M:7-S;'EC:V%D97,`075T96YT
M:7-E<FEN9R!M:7-S;'EC:V%D97,N("5S`$%U=&5N=&ES97)I;F<@879V:7-A
M9&5S(&%V(%)!1$E54RUS97)V97)N+@!!=71E;G1I<V5R:6YG('1I;&P@1E10
M+7-E<G9E<B!M:7-S;'EC:V%D97,N`$%U=&5N=&ES97)I;F<@=&EL;"!334(M
M<V5R=F5R(&UI<W-L>6-K861E<RX`5&EL;&?D;F=L:6=A(&;D;'0Z`%;D;G1A
M<B!PY2!S=F%R`$%Z97)B86EJ86X`07IU<F)LY0!"3T9(+75R<^1K=&5R`$)A
M:V=R=6YD`$)A:V=R=6YD<V;D<F<`1F5L86MT:6=T(&SV<V5N;W)D(&;V<B!+
M97)B97)O<P!&96QA:W1I9W0@86YVY&YD87)N86UN(&;V<B!+97)B97)O<P!"
M86AA;6%S`$)A:')A:6X`0F%L=&ES:R`H25-/+3@X-3DM,3,I`$)A;F=L861E
M<V@`0F%R=&ED`%)A9'1I9`!"87)B861O<P!"87)B:64`0F%S:V%T86QO9R`G
M)7,G(&;V<B!B:6QD97(@:&ET=&%D97,@:6YT92X`0F%S;&EN:F4`4_9K;FEN
M9P!6:71R>7-S;&%N9`!"96QG:65N`$)E;&EZ90!.961A;F;V<B!S]FMF;W)M
M=6SD<F5T`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I;F0@;6ES<VQY8VMA9&5S
M.B`H)7,I("5S`$;V9&5L<V5D86<`0FQO8VL@)R5S)R!F]G(@87!P;&EK871I
M;VX@)R5S)R!S86MN87,N`$)L;V-K:6YS=.1L;&YI;F=A<@!";&]C:W1Y<`!"
M;.4@;>5N90!";.5T="!O8V@@=FET=`!&970`0F]L:79I80!";VMMY')K96X`
M4F%M`%)A;6)R961D.@!286UA<@!";W-N:65N(&]C:"!(97)Z96=O=FEN80!"
MY61A`$)O='-W86YA`$)O='1E;@!";W5V970@27-L86YD`$)R87-I;&EE;@!"
M<FET=&ES:V$@=&5R<FET;W)I970@:2!);F1I<VMA(&]C96%N96X`0G)U;@!,
M:7-T80!"<G5N96D`0G5L9V%R:65N`%!U;FMT;&ES=&$`0G5R:VEN82!&87-O
M`$)RY&YD($]R86YG90!"=7)U;F1I`$%F9N1R<VMA=&5G;W)I`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U-6`$-?96QL(&EN<W3D;&QN:6YG
M87(N+BX`0V%C:&5I;FET:65R:6YG(.1R(&EN=&4@9G5L;'-TY&YD:6<N`$MA
M;&5N9&5R`$QU9VYT`$MA;6)O9&IA`$MA;65R=6X`2V%M;W5F;&%G90!+86X@
M:6YT92!N;VQL<W3D;&QA(&SV<V5N;W)D(&%U=&]M871I<VMT+"!K;VYT86MT
M82!D:6X@861M:6YI<W1R873V<BX`2V%N(&EN=&4@<VMR:79A('1I;&P@9FEL
M("<E<R<`2V%N(&EN=&4@;.1G9V$@=&EL;"!G<G5P<"!T:6QL('-I9R!S:N1L
M=BX`1&5T(&?E<B!I;G1E(&%T="!A9&UI;FES=')E<F$@97AT97)N82!S97-S
M:6]N<VAA;G1E<F%R92X`2V%N(&EN=&4@:V]N=&%K=&$@24U!4"US97)V97)N
M.B`E<P!+86X@:6YT92#V<'!N82!F:6P@)R5S)P!+86YA9&$`079B<GET`$%V
M8G)Y="!P<F]B;&5M<F%P<&]R=`!+86X@:6YT92!R861E<F$@)R5S)RX`2V%N
M(&EN=&4@:&ET=&$@96X@=&5M<'+D<B!M87!P+@!+86X@:6YT92!F;W)T<^1T
M=&$@=71A;B`G;>5L9FEL)RUP87)A;65T97(N`$MA;B!I;G1E(')A9&5R82!M
M87!P("<E<R<N`$MA;B!I;G1E(')A9&5R83L@)60@8F%R;B!E>&ES=&5R87(N
M`$MA;B!I;G1E(&1I<FEG97)A(&UE9&1E;&%N9&4@=&EL;"!A;F=I=F5T(&YU
M;6UE<BX`2V%P(%9E<F1E`%)U8G)I:P!/<&5R873V<@!+871E9V]R:65R(&]C
M:"!R=6)R:6ME<@!#87EM86X@27-L86YD<P!-;V)I;'1E;&5F;VX`0V5L;&EN
M<W3D;&QN:6YG87(`0V5L;'5T9GEL;&YA9#H`0V5L;&EN<W3D;&QN:6YG87(`
M0V5L;&UE;&QA;G)U;3H`36]B:6QT96QE9F]N`$-E;'1I<VL@*$E33RTX.#4Y
M+3$T*0!#96YT<F5R860`0V5N=')A;&%F<FEK86YS:V$@<F5P=6)L:6ME;@!#
M96YT<F%L975R;W!E:7-K("A)4T\M.#@U.2TR*0!#97)T:69I:V%T9&5T86QJ
M97(`0V5R=&EF:6MA=.1G87)E`$-E<G1I9FEK871P;VQI8VEE<P!48VAA9`!/
M<F1F]G)A;F1E`,1N9')A`,1N9')A(&1I='0@;/9S96YO<F0`Q&YD<F$@9O9R
M=F%L9"!I9&5N=&ET970`Q&YD<F$@;F%M;B!O8V@@861R97-S('-O;2!M;W1T
M86=A<FYA('-E<B!NY'(@9&4@;.1S97(@;V-H('-V87)A<B!PY2!D:6YA(&UE
M9&1E;&%N9&5N+@!!='0@8GET82!L]G-E;F]R9"!S=/9D<R!I;G1E(&UE9"!D
M96X@;G5V87)A;F1E(&MO;F9I9W5R871I;VYE;BX@(%9A<B!G;V0@:V]N=&%K
M=&$@861M:6YI<W1R873V<F5N+@!4:VX`2V]N=')O;&QE<F$@;.1N:RXN+@!-
M87)K97)A(%]!;&QA+TEN9V5N`$UA<FME<F$@9&4@86MT:79I=&5T97(@9'4@
M=FEL;"!U=&;V<F$@;G4N`$-H:6QE`$MI;F$`2VEN97-I<VMT(&;V<F5N:VQA
M="`H1T(R,S$R*0!+:6YE<VES:W0@=')A9&ET:6]N96QL="`H0FEG-2D`5N1L
M:B!A<'!L:6MA=&EO;CH`5N1L:B!E='0@;F%M;@!6Y&QJ(&SV<V5N;W)D`%;D
M;&H@86YVY&YD87)N86UN`%;D;&H@Y71GY')D.@!6Y&QJ(&5N(&%D<F5S<V)O
M:P!6Y&QJ(&5N(&%D<F5S<V)O:SH`5N1L:B!H=7(@9&%T=6T@<VMA;&P@=FES
M87,Z`%;D;&H@;&ES='-T:6P@*&;V<B!S;W)T97)A9&4@;&ES=&]R*0!6Y&QJ
M(&%D<F5S<V+V8VME<B!S;VT@<VMA;&P@=FES87,@;V-H(&D@=FEL:V5N(&]R
M9&YI;F<Z`%;D;&H@861R97-S8O9C:V5R('-O;2!S:V%L;"!A;G;D;F1A<RX`
M5N1L:B!K;VQU;6YE<B!S;VT@=FES87,@;V-H(&D@=FEL:V5N(&]R9&YI;F<Z
M`$IU;/9N`$ML87-S9&5F:6YI=&EO;B!F]G(@)7,@<V%K;F%S+@!296YS80!2
M96YS82!-4T]F9FEC92UT86=G87(`4F5N<V$@9G+E9V$`4F5N<V$@86YVY&YD
M87)E.B`E<P!296YS82!A;G;D9&YA<F4`4F5N<V$@86YVY&YD87)D871A`%-E
M;F%R92!U<'!K;&%R;F%N9&4`2VQI8VMA(&;V<B!A='0@9F]R='/D='1A`$-L
M:6-K871E;&P@=FEA($A45%``4W3D;F<@9O9N<W1E<@!-;VQN`%1I9&EG82!M
M;VQN`$UO;&YI;F=T`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$MO;7!R:6UE
M<F$@<VED;V;D;'1E=`!+;VUP<FEM97)A9&4@<F%M87(`2V]L;VUB:6$`1N1R
M9P!&Y')G:&%N=&5R87)E`$;D<F=V86P`2V]L=6UN97(Z`$MO;'5M;FEN<W3D
M;&QN:6YG87(`2V]L=6UN(')U8G)I:V5R`$MO;'5M;F5R('-O;2!I;G1E('9I
M<V%S.@!,=7-T:6=H971E<@!+;VUM87-E<&%R97)A9&4@=N1R9&5N`$MO;6UA
M<V5P87)E<F%D92!VY')D96X@*$UI8W)O<V]F="!/=71L;V]K*0!+;VUM86YD
M;P!+;VUM86YD;V;V;G-T97(`2V]M;65N=&%R`$YA;6X`0V]M;W)O<P!&]G)E
M=&%G`$%D<F5S<RP@9O9R971A9P!3;'5T9O9R9`!3:W)I=B!M961D96QA;F1E
M("@E<RD`1&%T;W)E<@!6Y&1E<@!6Y&1E<@!+;VYF:6=U<F%T:6]N<W-K:6QL
M;F%D97(`26YS=.1L;&YI;F=A<B!F]G(@871T('-Y;FMR;VYI<V5R82!M960@
M:&%N9&1A=&]R97(L('-M87)T82!T96QE9F]N97(@;V-H($]U=&QO;VL`2V]N
M9FEG=7)A=&EO;B!B96CV=F5R('5P<&1A=&5R87,N`$MO;F9I9W5R97)A("5S
M`$)E:W+D9G1A(&SV<V5N;W)D`$MO;F=O`$MO;F=O`$;V<F)I;F1E;'-E(&UI
M<W-L>6-K861E<RX`1O9R8FEN9&5L<V4@;6ES<VQY8VMA9&5S.B``06YS;'5T
M;FEN9R!T:6QL('-E<G9E<B!M:7-S;'EC:V%D97,Z("5S`$%N<VQU=&YI;F<@
M=&EL;"!S97)V97(@;6ES<VQY8VMA9&5S`$;V<F)I;F1E;'-E(&UE9"!P=6)L
M:6L@;GEC:V5L<V5R=F5R(&YE:V%D97,N`$;V<F)I;F1E;'-E(&UE9"!P=6)L
M:6L@;GEC:V5L<V5R=F5R(&YE:V%D97,Z("5S("@E<RD`1O9R8FEN9&5L<V4@
M;65D($944"US97)V97(@;6ES<VQY8VMA9&5S+@!+;VYT86MT;&ES=&$`4_9K
M(&MO;G1A:W0`2V]N=&%K=&5R`$MO;G1A:W1E<B!I(&QI<W1A;CH@)7,`2V]N
M=&%K=&5R(&QA9&5S('1I;&P@:2!D:6X@861R97-S8F]K+@!);FYE:.5L;'-T
M>7`@9O9R(&MO;7!R:6UE<F%D(&9I;#H@`$EN;F5HY6QL(&D@)R5S)P!&;W)T
M<^1T=`!#;V]K($ES;&%N9',`0V]O:VEE`$MO<&EE<F$`2V]P:65R:6YG(&UI
M<W-L>6-K861E<SH@)7,`2V]P:65R82!M87)K97)I;F<`36%J<V)L;VUM80!+
M;W-T;F%D<RU)1`!#;W-T82!2:6-A`$5L9F5N8F5N<VMU<W1E;@!+86X@:6YT
M92!01U`M:W)Y<'1E<F$@;65D9&5L86YD92X`2V%N(&EN=&4@4$=0+6MR>7!T
M97)A(&UE9&1E;&%N9&4Z(`!+86X@:6YT92!01U`M<VEG;F5R82!M961D96QA
M;F1E+@!+86X@:6YT92!01U`M<VEG;F5R82!M961D96QA;F1E.B``2V%N(&EN
M=&4@4R]-24U%+6MR>7!T97)A(&UE9&1E;&%N9&4N`$MA;B!I;G1E(%,O34E-
M12US:6=N97)A(&UE9&1E;&%N9&4N`$MA;B!I;G1E(&SD9V=A('1I;&P@:V]N
M=&%K="X@)7,`36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!,1$%0('-E<G9E
M<BX`2V%N(&EN=&4@=F5R:69I97)A(&MO;G1O<V%L9&\N("5S`$MU;F1E(&EN
M=&4@86YS;'5T82!T:6QL($Q$05`M<V5R=F5R+@!+86X@:6YT92!K;VYT86MT
M82!S97)V97(@)R5S)R!V:6$@1E10.B`E<P!+86X@:6YT92!S:V%P82!D:7-T
M<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I;G1E(&1E:W)Y<'1E<F$@4$=0+61A
M=&$N`$MA;B!I;G1E(&1E:W)Y<'1E<F$@4$=0+61A=&$Z(`!+86X@:6YT92!D
M96MR>7!T97)A(%,O34E-12UD871A+@!+86X@:6YT92!R861E<F$@:V]N=&%K
M="X@)7,`2V%N(&EN=&4@<F%D97)A(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,`
M2V%N(&EN=&4@<F%D97)A('5P<&=R861E<FEN9W-S8W)I<'0@=&EL;#H@)7,N
M`$MA;B!I;G1E(&)E<W3D;6UA(&UO='1A9V%R96YS(&50;W-T+6%D<F5S<RX`
M2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@861R97-S8F]K+@!+86X@:6YT92!H
MY&UT82!K;VUP;&5T="!D:7-T<FEB=71I;VYS;&ES=&$N`$MA;B!I;G1E(&CD
M;71A(&MO;7!L971T(&QI<W1A(/9V97(@9&ES=')I8G5T:6]N<VQI<W1O<BX`
M2V%N(&EN=&4@;&%D9&$@<W1R871E9VD@)R5S)RX`2V%N(&EN=&4@;&%D9&$@
M<W1R871E9VD@)R5S)RX`2V%N(&EN=&4@<VMA<&$@;6%P<"`G)7,G+@!+86X@
M:6YT92!S:V%P82!M87!P("<E<R<N`$MA;B!I;G1E(&CD;71A('!U8FQI:R!N
M>6-K96P@9G+E;B!N>6-K96QS97)V97)N+@!+86X@:6YT92#V<'!N82`G)7,G
M(&;V<B!S:W)I=FEN9RX`2V%N(&EN=&4@]G!P;F$@)7,N`$MA;B!I;G1E(/9P
M<&YA("<E<R<@9O9R('-K<FEV:6YG+@!+86X@:6YT92#V<'!N82!-86EN=&5N
M86YC95]487-K(&UO9'5L("5S`$MA;B!I;G1E(/9P<&YA(&UA<'!E;B`G)7,G
M`$MA;B!I;G1E(/9P<&YA(&UA<'`@)R5S)P!+86X@:6YT92!K;VYT86MT82!,
M1$%0('-E<G9E<BX`2V%N(&EN=&4@;.1S82`E<RX`1&5T(&=I8VL@:6YT92!A
M='0@Y71E<G-TY&QL82!L]G-E;F]R9&5T(&;V<B!D96X@86YG:79N82!A;G;D
M;F1A<F5N+B!.Y6=O;B!E;&QE<B!NY6=R82!A=B!U<'!G:69T97)N82#D<B!I
M;G1E(&MO<G)E:W1A+B!&]G)S]FL@:6=E;B!E;&QE<B!K;VYT86MT82!A9&UI
M;FES=')A=/9R96X@;VT@9'4@8F5H]G9E<B!H:N1L<"X`2V%N(&EN=&4@:.1M
M=&$@04-,`$MA;B!I;G1E(&CD;71A(&%D<F5S<V)O:RX@)7,`2V%N(&EN=&4@
M:.1M=&$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<P!+86X@:6YT92!HY&UT82!D
M:7-T<FEB=71I;VYS;&ES=&]R+B`E<P!+86X@:6YT92!HY&UT82!D<V5R=F5R
M9G5N:W1I;VYE<@!+86X@:6YT92#E=&5R<W3D;&QA(&MO;F9I9W5R871I;VYE
M;BX`2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RX`2V%N(&EN=&4@<F%D97)A
M(&UA<'`@)R5S)RX`2V%N(&EN=&4@<W!A<F$@:V]N9FEG=7)A=&EO;B!F]G(@
M)7,N`$MA;B!I;G1E('-P87)A(&)A8VMU<"UK;VYF:6=U<F%T:6]N+@!+86X@
M:6YT92!S<&%R82!E;B!B86-K=7`M:V]N9FEG=7)A=&EO;CH@)7,N`$MA;B!I
M;G1E('-P87)A('5P<&=R861E<FEN9W-S8W)I<'0@=&EL;#H@)7,N`$MA;B!I
M;G1E('-P87)A(&)A8VMU<"UK;VYF:6=U<F%T:6]N("5S+@!+86X@:6YT92!S
M<&%R82!K;VYF:6=U<F%T:6]N<V9I;&5N("5S+B!$=2!K86X@86YT:6YG96X@
M86YVY&YD82!E;B!A=B!A;'1E<FYA=&EV96X@871T('-P87)A(&MO9&5N('1I
M;&P@)7,@96QL97(@:V]P:65R82!K;V1E;B!N961A;B!T:6QL("5S+@!+86X@
M:6YT92!S]FMA(&D@3$1!4"UK871A;&]G96XN`$MA;B!I;G1E(')A9&5R82`G
M)7,G+@!+86X@:6YT92!R861E<F$@)R5S)RX`2V%N(&EN=&4@=7!P9&%T97)A
M(&MO;G1A:W0N("5S`$MA;B!I;G1E('5P<&1A=&5R82!D:7-T<FEB=71I;VYS
M;&ES=&$N("5S`$MA;B!I;G1A('-P87)A(&MO;F9I9W5R871I;VX@9O9R("<E
M<R<Z("5S`$MA;B!I;G1E(&AI='1A($UO>FEL;&%S('-I9&]FY&QT+B!697)I
M9FEE<F$@871T('-I9&]FY&QT970@Y'(@]G!P970N`$MA;B!I;G1E(&=E(&%N
M=N1N9&%R96X@)R5S)R!A;F=I=FYA('+D='1I9VAE=&5R('1I;&P@;6%P<&5N
M("<E<R<Z("5S`%+D:VYA9"!T97AT`$QA;F0`2W5R<V5R`%-K87!A`%-K87!A
M(&%D<F5S<V)O:P!3:V%P82!LY&YK`%-K87!A(&YY(&MO;G1A:W1L:7-T82!I
M.@!3:V%P82!N>0!3:V%P82!U;F1E<FUA<'``4VMA<&%D`$)E:/9R:6=H971E
M<B!F]G(@Y&=A<F$`2W)E9&ET:V]R='-N=6UM97(`2W)O871I96X`2W5B80!!
M:W1U96QL82`T(&9A<V5R`$%K='5E;&P@<V5S<VEO;@!!:W1U96QL('1I9`!!
M:W1U96QL(%523"#D<@!!:W1I=F$@86YVY&YD87)E`$%K='5E;&QT(';D9&5R
M`$%K='5E;&QA('9I;&QK;W(Z(`!!:W1U96QL('-T:6P`4VMRY&1D87)S>2!A
M:W1I=FET971E<B!S;VT@:_9R<R!V:60@:6YL;V=N:6YG('1I;&P@)7,N`$ML
M:7!P('5T`$ML:7!P('5R=F%L`$-Y<&5R;@!+>7)I;&QI<VL@*$M/23@M4BD`
M2WER:6QL:7-K("A7:6YD;W=S+3$R-3$I`$MY<FEL;&ES:R]5:W)A:6YS:R`H
M2T])."U5*0!4:F5C:VEE;@!$1`!$86=L:6<`1&%T851R964@8FSD9&1R87)E
M`$1A=&%B87-U<'!S;&%G`$1A='5M`$1A='5M(&UO='1A9V5T`$1A='5M=F%L
M`$1A9P!?4F%D97)A(&MO;'5M;@!D96-E;6)E<@!$96-I;6%L97(`079B]FIT
M`$UI;G-K82!I;F1R86<`1O9R=F%L=`!&]G)V86QD(&;D<F<`1O9R=F%L9"!I
M9&5N=&ET970`1O9R=F%L="!S:V%L`$;V<G9A;&0@<V]R=&5R:6YG<W)I:W1N
M:6YG.@!$969I;FET:6]N97(`1&5L96=E<F$@<&]S:71I;VX`1&5L96=E<F%D
M`%)A9&5R80!2861E<F$@861R97-S8F]K`%)A9&5R82!C96QL`%)A9&5R82!B
M96MRY&9T96QS90!2861E<F$@9W)U<'``4F%D97)A(&QO9V<`4F%D97)A(&)E
M:/9R:6=H970`4F%D97)A(&]C:"!R96YS82!M961D96QA;F1E;@!&=6YK=&EO
M;B!F]G(@:VYA<'!E;B!2861E<F$`4F%D97)A(&-E;&P`4F%D97)A(&MO;'5M
M;@!2861E<F$@8F5F:6YT;&EG(&%L=&5R;F%T:79M86QL`%)A9&5R:6YG(&UI
M<W-L>6-K861E<SH@*"5S*2`E<P!2861E<F%D92!M961D96QA;F1E;@!2861E
M<F$@8F5H]G)I9VAE="!F]G(@)R5S)P!2861E<F$@8F5H]G)I9VAE="!F]G(@
M)R5S)R!O8V@@=6YD97)B96CV<FEG:&5T97(_`%)A9&5R82!R860`4F%D97)A
M('9A;&0@:61E;G1I=&5T`%)A9&5R82!U;F1E<FUA<'!A<@!2861E<F$@86MT
M=65L;"!K;VQU;6X`4F%D97)A(&%K='5E;&P@<F%D`%)A9&5R82!D96X@:.1R
M(&SD;FME;@!2861E<F%D92!U<'!G<F%D97)I;F=S<V-R:7!T970@)R5S)RX`
M1G5N:W1I;VYE;B!R861E<F$@:V]N=&%K=&5R(.1R(&EN=&4@=&EL;&?D;F=L
M:6<N`%)A9&5R:6YG(&UI<W-L>6-K861E<P!,979E<F%N<W1I9`!$86YM87)K
M`$%V<VSE(&)E9^1R86X`079S;.4@8F5GY')A;B!O;2!L961I9R]U<'!T86=E
M;BUI;F9O<FUA=&EO;@!!=F1E;&YI;F<`1F%L;&%N9&4`0F5S:W)I=B!P<F]B
M;&5M970`0F5S:W)I=FYI;F<`1&5T86QJ97(@*&]C:W/E(&D@2&]R9&5S(&QO
M9V=F:6PI.@!$971A;&IE<B!H87(@;&]G9V%T<R!F]G(@<WES=&5M861M:6YI
M<W1R873V<F5N+@!5='9E8VML:6YG`$1A9V=P=6YK=`!$86=G<'5N:W0@9O9R
M('-E;F%S=&4@=&EM;65N.B``1&%G9W!U;FMT.B``4FEK=&YI;F<@=N1N<W1E
M<B!T:6QL(&CV9V5R`%)I:W1N:6YG(&CV9V5R('1I;&P@=N1N<W1E<@!+871A
M;&]G`%9I<V$`5FES82`R-"UT:6UM87)S(&ML;V-K83\`5FES;FEN9W-I;G-T
MY&QL;FEN9V%R`%9I<V$@9&5T86QJ97)A9"!F]G)U='/D9V5L<V4`5FES82!F
M]G)U='/D9V5L<V4@*%1!1BD`5FES;FEN9W-F;W)M870`079S:VEL:F%R90!$
M:FEB;W5T:0!2861E<F$@:6YT90!!;G;D;F0@:6YT92!M86EN=&5N86YC92YP
M:'`@9&ER96MT`%9I;&P@9'4@8F5K<N1F=&$@<F%D97)I;F<@878@<&]S=&5R
M/P!);FYE:.5L;&5R(&;V<G-T82!R861E;B!FY&QT;F%M;F5N/R!/;2`G:F$G
M+"!M87)K97)A(&CD<CH`1&]M:6YI:V%N<VMA(')E<'5B;&EK96X`2&%R(&1U
M(&EN9V5T(&MO;G1O/R!296=I<W1R97)A(&1I9RX`2.1M=&$`2.1M=&$@)7,`
M2.1M=&$@9V5N97)E<F%D(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I<'0N
M`$QA9&1A(&YE9"!V0V%R9`!$<F]P<&QI<W1A`$1R;V=E<@!%+7!O<W0`1')I
M=G)U=&EN(&;V<B!%+7!O<W0@=&EL;"!335,M8G)Y9V=A.R!F]G(@;W!E<F%T
M]G)E<B!S;VT@=&EL;&AA;F1A:.5L;&5R(&1E;FYA('1JY&YS="X`1D5,`$5K
M=6%D;W(`Q&YD<F$`Q&YD<F$@)R5S)P!2961I9V5R82!A9')E<W-B]F-K97(`
MQ&YD<F$@8FQO8VL`Q&YD<F$@9W)U<'``Q&YD<F$@8F5H]G)I9VAE=`#$;F1R
M82!B96CV<FEG:&5T97(`Q&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`E<P#$;F1R
M82!P;W-T(&;V<B`E<P#$;F1R82!I;G-TY&QL;FEN9V%R(&;V<CH`Q&YD<F$@
M8F5H]G)I9VAE=&5R(&;V<B`G)7,G`,1N9')A(&)E:/9R:6=H971E<B!F]G(@
M)R5S)P!5=&)I;&1N:6YG`$5G>7!T96X`16P@4V%L=F%D;W(`16QE;65N="XN
M+@!%;0!%+7!O<W0`12UP;W-T861R97-S`$4M<&]S=&%D<F5S<V5R(&WE<W1E
M('-TY&UM82#V=F5R<F5N<RX`12UP;W-T;65D9&5L86YD92!M960@8F5K<N1F
M=&5L<V4`12UP;W-T('1I;&P@4TU3+6)R>6=G80!+Y&YS;&]I:V]N97(`5&]M
M="!M961D96QA;F1E+@!4;VUT(')E<W5L=&%T+@!4;VUT('/V:VMR:71E<FEA
M`%-L=70`4VQU="#E<@!&]G)S=&]R82!E9&ET;W(`06YG92!S]FMVY&<@*%52
M3"D@=&EL;"!B:6QD96X@:.1R`%-+<FEV(&)O:W-TY'9E<FYA(&YE9&%N.@!0
M;W-T96X@9O9R("<E<R<@=7!P9&%T97)A9&5S+"!M96X@9&5N('5P<&QA9&1A
M9&4@9FEL96X@:W5N9&4@:6YT92!S<&%R87,Z("5S`%!O<W1E;B!F]G(@)7,@
M=7!P9&%T97)A9"X`1F5L`$1E="!G:6-K(&EN=&4@871T(&SD9V=A('1I;&P@
M)60@:V]N=&%K="AE<BD@=&EL;"!L:7-T86XN`$1E="!G:6-K(&EN=&4@871T
M(&SD9V=A('1I;&P@)60@878@)60@8F5GY')D82!K;VYT86MT97(@=&EL;"!L
M:7-T86XN`$9E;"!V:60@<VMA<&%N9&4@878@8FQO8VLZ("5S`$9E;"!V:60@
M<F%D97)I;F<@878@)60@:V]N=&%K="AE<BDN`$9E;"!V:60@<F%D97)I;F<@
M878@)60@878@)60@8F5GY')D82!K;VYT86MT97(N`$9E;"!V:60@<F%D97)I
M;F<@878@<WEN:W)O;FES97)I;F=S;>1R:V4Z("5S`$9E;"!V:60@<F%D97)I
M;F<@878@<WEN:W)O;FES97)I;F=S;&]G9SH@)7,`1F5L(&[D<B!I;FYE:.5L
M(&CD;71A9&5S.B`E<P!&96P@=FED(')A9&5R:6YG(&%V("5D(&MO;G1A:W0H
M97(I(&9RY6X@;&ES=&%N+@!&96P@=FED(')A9&5R:6YG(&%V("5D(&%V("5D
M(&MO;G1A:W1E<B!F<N5N(&QI<W1A;BX`1F5L('9I9"!S]FMN:6YG(&D@861R
M97-S8F]K96XZ("5S`$9E;"!U;F1E<B!SY&YD;FEN9R!A=B!S=F%R<VUE9&1E
M;&%N9&4Z("5S`$9E;"!V:60@=7!P9&%T97)I;F<@878@;/9S96YO<F0Z("5S
M`$9E;"!V:60@<VMR:79N:6YG("<E<R<N`$9E;"!V:60@<VMR:79N:6YG(&%V
M("<E<R<N`$5S=&QA;F0`171I;W!I96X`171N:7-K`$5U<F]P80!687(@,34Z
M92!M:6YU=`!687)A;FYA;B!M:6YU=`!687(@,S`Z92!S96MU;F0`5F%R(#4Z
M92!M:6YU=`!687)J92!I;FQO9V=N:6YG`%9A<FIE(&AA;'9T:6UM90!687)J
M92!M:6YU=`!%>&5M<&5L('#E(';D<F1E;CH`2_9R`$SD;6YA(&%D<F5S<V)O
M:P!%>'!A;F1E<F$`17AP86YD97)A('-I9&]FY&QT`$;V<G;D;G1A9&4@)RDG
M`$;V<G;D;G1A9&4@96YS:VEL="!O<F0@96QL97(@8VET97)A="!S]FMB96=R
M97!P`$;V<F9A;&QO9&%T=6T`17AP;VYE;G0`17AP;W)T97)A`$5X<&]R=&5R
M82!A9')E<W-B;VL`17AP;W)T97)A(&5N9&%S="!M87)K97)A9&4@:V]N=&%K
M=&5R+@!%>'!O<G1E<F$@86QL82!K;VYT86MT97(@:2!A9')E<W-B;VME;BX`
M1O9R9W)U;F1S9N1R9P!,861D82!U<'`@:V]N9FEG=7)A=&EO;B!V:6$@1E10
M+@!-:7-S;'EC:V%D97,@871T(&CD;71A(&EN<W3D;&QN:6YG87(N`$9E;"!V
M:60@Y71K;VUS="!A=B!A9')E<W-B;VME;CH@)7,`36ES<VQY8VMA9&5S(&%T
M="!LY&=G82!T:6QL("5S('1I;&P@)7,Z("5S`$UI<W-L>6-K861E<R!A='0@
M=FES82!L:7-T86X`36ES<VQY8VMA9&5S(&%T="!V:7-A(&MA=&%L;V=E;@!-
M:7-S;'EC:V%D97,@871T(.1N9')A(&YA;6XZ("@E<RD@)7,[($=A;6UA;'0@
M1$X@/2`E<RP@3GET="!$3B`]("5S+"!2;V]T(#T@)7,`36ES<VQY8VMA9&5S
M(&%T="!K;VYT86MT82!,1$%0('-E<G9E<BX`36ES<VQY8VMA9&5S(&%T="!K
M;VYT86MT82!334(@<V5R=F5R+@!-:7-S;'EC:V%D97,@871T(&MO<&EE<F$@
M9G+E;B`G)7,G+@!-:7-S;'EC:V%D97,@871T(&MO<&EE<F$@=&EL;"`G)7,G
M+@!-:7-S;'EC:V%D97,@871T('-K87!A(&YY(%-!4TPM9O9R8FEN9&5L<V4N
M`$AI='1A9&4@:6YT92!O8FIE:W0@<V]M('-K=6QL92!LY&=G87,@=&EL;#H@
M)7,`36ES<VQY8VMA9&5S(&%T="!F;'ET=&$@=&EL;"`G)7,G+@!-:7-S;'EC
M:V%D97,@871T(&CD;71A.B`E<P!&96P@=FED('/V:VYI;F<@:2!A9')E<W-B
M;VME;@!-:7-S;'EC:V%D97,@871T('/V:V$@:2!K871A;&]G96XZ("5S`$)R
M80!&86QK;&%N9'/V87)N80!&Y'+V87)N80!&871A;'0@9F5L.@!&87@`1F%X
M87(`9F5B<G5A<FD`2^1N;G,@<V]M`$OD;FYS('-O;3H@`$;E=&%L:6=A('-K
M=7)A<@!&Y71A;&EG82!S;O9S:W5R87(`1N1L=&UA=')I<P!&:6=L970@0T%0
M5$-(00!&:6=L971T>7!S;FET=`!&:6II`$9I;`!!;G1A;"!F:6QE<CH@)7,@
M9FEL`$%N=&%L(&9I;&5R.B`E<R!F:6QE<@!&:6QH86YT97)A<F4`1FEL;F%M
M;@!&:6QV86P`1FEL=7!P;&%D9&YI;F<`1FEL=7!P;&%D9&YI;F<@<W3V9',@
M:6YT92X`1FEL97(`1FEL=&5R`%/V:P!3;'5T9O9R`$9I;FQA;F0`1O9R<W1A
M(&AA;'9A;@!&]G)N86UN`$;V<G-T82!K=F%R=&5N`$UA<'`@)7,@97AI<W1E
M<F%R(&EN=&4N`$9O;G1FY')G`$UA=`!&]G(@=V5B8FSD<V%R92!S;VT@:6YT
M92!S=/9D97(@8FEL9&5R`%!R;V=N;W,@*%1!1BD`06YT86P@9&%G87(@9O9R
M('!R;V=N;W,@*'9A<FIE(&1A9R!B971Y9&5R(&5N('!R;V=N;W,@9O9R(&1A
M9R!O8V@@96X@9O9R(&YA='0I`$=L]FUT(&1I='0@;/9S96YO<F0_`$9O<FUU
M;.1R`%9I<VAE='-O<F0`5'EP(&%V('9I<VAE='-O<F0`5FES:&5T<V]R9`!6
M:7-H971S;W)D(#(`1F]R=6T`5FED87)B969O<F1R87(`1G(`4F%M87(`1G)A
M;FMR:6ME`$9R86YK<FEK92P@365T<F]P;VP`3&5D:6<O57!P=&%G96X@:6YF
M;W)M871I;VX`3&5D:6<O57!P=&%G96X@<W9A<@!,961I9R]U<'!T86=E;BUF
M]G)F<N5G86X`4W9A<B!PY2!L961I9R]U<'!T86=E;BUF]G)F<N5G86X`3&5D
M:6<O=7!P=&%G96XM55),`$9R86YS:V$@1W5I86YA`$9R86YS:V$@4&]L>6YE
M<VEE;@!&<F%N<VMA('/V9')A('1E<G)I=&]R:65R`$9RY6X`1G+E;B!D96X@
M`$9U;&QS=.1N9&EG(&)E<VMR:79N:6YG`$9U;&QMY6YE`$9U;&QS=.1N9&EG
M="!N86UN`$=A8F]N`$=A;&QE<FD@871T('1A(&)I;&0@9G+E;@!'86QL97)I
M.@!'86UB:6$`1V5N97)E<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,`1V5N97)E
M<F%D(&MO9`!'96]R9VEE;@!4>7-K;&%N9`!':&%N80!':6)R86QT87(`1O9R
M;F%M;@!';&]B86P@861R97-S8F]K`$=L;V)A;&$@:6YS=.1L;&YI;F=A<@!/
M2P!';V5D96P`1V]O9VQE:V%R=&]R`$=O;V=L97/V:VYI;F<`1W+E<VMA;&$`
M1W)E:VES:R`H25-/+3@X-3DM-RD`1W+V;@!'<O9N;&%N9`!'<F%N861A`$=R
MY0!'<G5P<`!'<G5P<&%D;6EN:7-T<F%T:6]N`$=R;W5P7VQD87`Z($MA;B!I
M;G1E(&SD9V=A('1I;&P@9W)U<'`@)R5S)RX@4V5R=F5R;B!S=F%R861E.B``
M1W)O=7!?;&1A<#H@2V%N(&EN=&4@<F%D97)A(&=R=7!P("<E<R<`1W)O=7!?
M;&1A<#H@2V%N(&EN=&4@=7!P9&%T97)A(&=R=7!P("<E<R<`1W)U<'!E<@!'
M=6%M`$=U871E;6%L80!'=65R;G-E>0!'Y'-T8F5H]G)I9VAE=&5R`%1JY&YS
M=&5R(&;V<B!GY'-T97(`1^1S=&)O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'
M=6EN96$`2%1-3`!(5$U,07)E82!VY&=R87(@871T(')A9&5R82!S:7-T82!C
M96QL96X@:2!E;B!R860N`$A434Q!<F5A(';D9W)A<B!A='0@<F%D97)A('-I
M<W1A(&MO;'5M;F5N(&D@96X@=&%B96QL+@!(5$U,07)E82!VY&=R87(@871T
M(')A9&5R82!S:7-T82!R861E;B!I(&5N('1A8F5L;"X`2%144"!!=71E;G1I
M<V5R:6YG('-A:VYA<RX`2&%I=&D`2&%S:&%L9V]R:71M`$1I;6UA`%)U8G)I
M:P!2=6)R:6ME<@!(96%R9"T@;V-H($UC1&]N86QD]F%R;F$`2W)A9G1I9V$@
MY7-K<VMU<F%R`$AE8G)E:7-K("A)4T\M.#@U.2TX+4DI`$CV:F0`2/9J9"`H
M<&EX;&%R*0!(:N1L<`!(:N1L<"!M960@961I=&]R;@!(:N1L<&9U;FMT:6]N
M`$AE;6ES9N1R`$CD<B#D<B!B]G)J86X@878@9FEL96XZ`$CV9P!(95]M`$AE
M;0!!9')E<W,L(&AE;0!/<G0L(&AE;0!,86YD+"!H96T`2&5M:V%T86QO9P!4
M96QE9F]N+"!H96T`4&]S=&YR+"!H96T`4F5G:6]N+"!H96T`1V%T=6%D<F5S
M<RP@:&5M`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@
M3V=I;'1I9W0@)7,@6$U,+61A=&$@<.5T<N1F9F%D97,@:2!M961D96QA;F1E
M("5S`$AO<F1E+TMO;&%B.B!);F=E="!M961D96QA;F1E(&UA=&-H87(@;V)J
M96MT970@)7,`2&]R9&4O2V]L86XZ($EN9V5T(&]B:F5K="!A=B!T>7!E;B`E
M<R!H:71T861E<R!I(&UE9&1E;&%N9&5T("5S`$AO<F1E+TMO;&%B.B!2861E
M<F%D92`E<R`G)7,G`$AO<F1E+TMO;&%B.B!);G1E9W)A=&EO;G-M;W1O<FX@
M:W+D=F5R("=D;VUX;6PG+71I;&SD9V=E="!F]G(@4$A0`$AO<F1E+TMO;&%B
M.B!+86X@:6YT92!S:V%P82!N>71T(%A-3"UT<N1D(&;V<B!O8FIE:W0@)7,`
M2&]R9&4O2V]L86(Z($MA;B!I;G1E(')A9&5R82`E<R`G)7,G.B`E<P!(;W)D
M92]+;VQA8CH@2V%N(&EN=&4@:.1M=&$@34E-1$4M240@9O9R(&1E;&5N(&UE
M9"!T>7`@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E('-Y;FMR;VYI<V5R82`E
M<R`G)7,G.B`E<P!(;W)D92]+;VQA8CH@2V%N(&EN=&4@<WEN:W)O;FES97)A
M('5T9&5L;FEN9V%R.B`E<P!(;W)D92]+;VQA8CH@3VOD;F0@=71D96QN:6YG
M("<E<R<`2&]R:7-O;G1E;&P@;&EN:F4`2&]R:7-O;G1E;&P@=71F>6QL;F%D
M`$AO<FES;VYT96QL.@!(=7(@:&%M;F%D92!D=2!HY'(_("A687(@9V]D(')A
M<'!O<G1E<F$@9&5T=&$A*0!(=7(@;>5N9V$@:V]L=6UN97(@=FEL;"!D=2!S
M;.4@:6AO<#\`2'5R(&WE;F=A(&;D;'0@*&MO;'5M;F5R*2!F:6YN<R!D970_
M`$AU<B!MY6YG82!R861E<B!V:6QL(&1U('-LY2!S86UM86X_`$9U:W1I9VAE
M=`!&=6MT:6=H970Z`$AU;6]R:7-T97(`56YG97)N`%-K87!A;F1E(&%V($E-
M05`M;6%P<"!M:7-S;'EC:V%D93H@)7,`4F%D97)I;F<@878@24U!4"UM87!P
M(&UI<W-L>6-K861E<SH@)7,`4VMA<&%N9&4@878@<75O=&$@9O9R($E-05`M
M;6%P<"!M:7-S;'EC:V%D97,Z("5S`$E-4U``061M:6YI<W1R871I;VX@878@
M24U34"UA9')E<W-B;VL`25`M861R97-S`$E0+6%D<F5S<R#D<B!I;G1E('1I
M;&QGY&YG;&EG+@!)4"UA9')E<W,@Y'(@:6YT92!I;F]M(&=O9&OD;G0@0TE$
M4BUB;&]C:RX`1O9R<_9K(&%T="!K<FEN9V?E($E0+6SE<RX`25]N9F]G82!R
M860@9O9R90!)<VQA;F0`16YB87)T(&EK;VYE<@!):V]N97(@9O9R("5S`$EK
M;VYE<B!M960@=&5X=`!)9&5N=&ET971E;G,@;F%M;CH`3VT@9&5T(&EN=&4@
M=FES87,@:V]R<F5K="P@)7,@9O9R(&%T="#V<'!N82!I(&YY='0@9O9N<W1E
M<BX`3VT@9'4@:6YT92!S97(@;N5G<F$@:6MO;F5R(&[D<B!D=2!A;G;D;F1E
M<B!);G1E<FYE="!%>'!L;W)E<BP@<^4@:V%N(&1U(&)E:/9V82!M87)K97)A
M(&1E;FYA(')U=&$@9O9R(&%T="!S=.1N9V$@878@9V5N;VUS:VEN;&EG82!0
M3D<M8FEL9&9I;&5R+@!/;2!D=2!S97(@9&5N;F$@=&5X="!M96X@:6YG96X@
M8FEL9"P@<^4@:V%N(&EN=&4@9&EN('=E8F)LY'-A<F4@=FES82!D96X@8FEL
M9"!D=2!F]G)S]FME<B!L861D82!U<'`N`$;V<FAA;F1S9W)A;G-K82!B:6QD
M.@!":6QD861R97-S`$)I;&1A9')E<W,Z`$)I;&0@9G+E;B!G86QL97)I`$)I
M;&0@9G+E;B!G86QL97)I.@!,861D82!U<'`@8FEL9`!":6QD97(`26UP;W)T
M97)A(&%D<F5S<V)O:RP@<W1E9R`E9`!);7!O<G1E<F$L('-T96<@)60`26UP
M;W)T97)A+T5X<&]R=&5R82!A9')E<W-B]F-K97(`26UP;W)T97)A9&4@9N1L
M=#H@)7,`26UP;W)T97)A9&4@9N1L=#H`4.5GY65N9&4`26Y?9F]G82!R860@
M969T97(`1F5L86MT:78@86MT:79I=&5T<VMO9"!S<&5C:69I8V5R860N`$9E
M;&%K=&EG="!A;G;D;F1A<FYA;6X@;V-H+V5L;&5R(&SV<V5N;W)D+@!/9VEL
M=&EG="!A;G;D;F1A<FYA;6X@96QL97(@86QT97)N871I=B!A9')E<W,N($;V
M<G/V:R!I9V5N(&5L;&5R(&MO;G1A:W1A(&%D;6EN:7-T<F%T]G)E;B!O;2!D
M=2!B96CV=F5R(&AJY&QP+@#6:V$@:6YD<F%G`$EN9&EE;@!);F1I=FED=65L
M;&$@86YVY&YD87)E`$EN9&]N97-I96X`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B#D<B!I;G1E('1I;&QGY&YG;&EG(&SD;F=R92X`26YF;V=A(&M?
M;VQU;6X@969T97(`26YF;V=A(&)I;&0`26YF;V=A('1A8F5L;`!);F9O9V$@
M=V5B8FSD;FL`26YF;V=A(%]K;VQU;6X@9O9R90!);F9O9V$@;GD@:V]L=6UN
M(&5F=&5R(&%K='5E;&P@:V]L=6UN`$EN9F]G82!N>2!K;VQU;6X@9O9R92!A
M:W1U96QL(&MO;'5M;@!);F9O9V$@<F%D(&5F=&5R(&%K='5E;&P@<F%D`$EN
M9F]G82!N>2!R860@9O9R92!E:W1U96QL(')A9`!);F9O9V$@<&%R86=R868@
M969T97(@86MT=65L;"!N;V0`26YF;V=A('!A<F%G<F%F(&;V<F4@86MT=65L
M;"!N;V0`26YF;V=A(&%L=&5R;F%T:78@;6%L;`!);F9O9V$@8V5L;"!E9G1E
M<@!);F9O9V$@8V5L;"!F]G)E`$EN9F]G82!K;VQU;6X@969T97(`26YF;V=A
M(&MO;'5M;B!F]G)E`$EN9F]G82!M961D96QA;F1E;@!);F9O9V$@<&%R86=R
M868@969T97(`26YF;V=A('!A<F%G<F%F(&;V<F4`26YF;V=A(')A9"!E9G1E
M<@!);F9O9V$@<F%D(&;V<F4`06YG92!E<F9O<F1R870@<W9A<B!T:6QL('/D
M:V5R:&5T<V9RY6=A;CH`26YF;V=A+\1N9')A(&)I;&0`26YF;V=A+\1N9')A
M(&SD;FL`3W1I;&QRY&-K;&EG(&MR961I="!F]G(@871T('-K:6-K82!T:6QL
M(&1I<W1R:6)U=&EO;G-L:7-T82X`3W1I;&QRY&-K;&EG(&MR961I="X`2&5L
M=&%L`$AE;'1A;'-L:7-T80!/9VEL=&EG(.5T9^1R9"!F]G(@9&5N(&CD<B!K
M;VUP;VYE;G1E;BX`1F5L86MT:6=T($E$`$]G:6QT:6<@541(("@G=7-E<B!D
M871A(&AE861E<B<I+@!/9VEL=&EG="!:25`M87)K:79D871A`$9E;&%K=&EG
M(&%D<F5S<V)O:P!&96QA:W1I9R!A<'!L:6MA=&EO;BX`1F5L86MT:6=T(&)A
M=&-H+4E$`$9E;&%K=&EG(&1A=&$@<VMI8VMA9"X`1F5L86MT:6<@9&5S=&EN
M871I;VYS861R97-S+@!/9VEL=&EG(&4M<&]S=&%D<F5S<P!&96QA:W1I9W0@
M=N1R9&4`1F5L86MT:6=T(&9I;&9O<FUA=`!&96QA:W1I9R!N>6-K96P@86YG
M:79E;BX`3V=I;'1I9R!L:6-E;G-N>6-K96PN`$9E;&%K=&EG(&]R="!S<&5C
M:69I8V5R860N`$9E;&%K=&EG(&UE9&1E;&%N9&5?='EP+@!&96QA:W1I9W0@
M;F%M;@!&96QA:W1I9W0@;V)J96MT260`1F5L86MT:6<@96QL97(@<V%K;F%D
M(&%P:5]I9"X`1F5L86MT:6=T(&5L;&5R('-A:VYA9"!P87)A;65T97(N`$9E
M;&%K=&EG(/9V97)L:6=G86YD92!B96CV<FEG:&5T+@!&96QA:W1I9W0@<&%R
M=&YE<BUI9"X`1F5L86MT:6<@<')O9'5K=&MO9"X`1F5L86MT:6=T('!R;W1O
M:V]L;"X`1F5L86MT:6<@;6]T=&%G87)E.B`G)7,G`$9E;&%K=&EG="!U=&1E
M;&YI;F=S;V)J96MT`$9E;&%K=&EG(&%V<^1N9&%R861R97-S+@!&96QA:W1I
M9W0@=6YI8V]D92UD871A`$EN=F5N=&%R:65R`$EN=F5R=&5R82!U<G9A;`!)
M<F%N`$ER86L`27)L86YD`$ES;&4@;V8@36%N`$5N<W1A:V$@Y7-K<VMU<F%R
M`$ES<F%E;`!5=&;D<F1A="!A=@!+=7)S:78`271A;&EE;@!*86UA:6-A`&IA
M;G5A<FD`2F%P86X`2F%P86YS:R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D
M86YI96X`:G5L:0!J=6YI`$IU<W1E<F$`0V5N=&5R:G5S=&5R80!*=7-T97)A
M(&KD;70`5N1N<W1E<FIU<W1E<F$`2/9G97)J=7-T97)A`$ME;GEA`$ME<F)E
M<F]S<V5R=F5R;B!A=G9I<V%D92!A=71E;G1I<V5R:6YG96XN`$YY8VME;"!S
M:V%P860`1FEN9V5R<')I;G0`3GEC:V5L;.1N9V0`3GEC:V5L='EP`$YY8VME
M;&%N=N1N9&%N9&4`3GEC:V5L(&9I;FYS(')E9&%N('#E(&1E;B!P=6)L:6MA
M(&YY8VME;'-E<G9E<FXN`$)A<FX`2VER:6)A=&D`2V]L86(`3F]R9&MO<F5A
M`%-Y9&MO<F5A`$MO<F5A;G-K("A%54,M2U(I`$MU=V%I=`!+:7)G:7-T86X`
M3$1!4"US=/9D(&MRY'9S+"!M96X@3$1!4"UM;V1U;&5N(.1R(&EN=&4@=&EL
M;&?D;F=L:6<@96QL97(@;&%D9&%D+@!,85]Y;W5T`%-P<N5K`$QA;W,`4VES
M=&$@:&%L=F%N`%-E;F%S="#D;F1R860`169T97)N86UN`$SV<V5N;W)D(.1N
M9')A9&5S`%-I<W1A(&MV87)T86QE=`!396YA<W0@=7!P9&%T97)A9#H`4V5N
M87-T92!I;FQO9V=N:6YG.B`E<P!396YA<W1E(&EN;&]G9VYI;F<Z("5S(&9R
MY6X@)7,`4V5N87-T92!I;FQO9V=N:6YG.B!!;&1R:6<`3&5T=&QA;F0`3&%V
M96YD97(`3&%G`$QA>6]U=`!,Y&UN82!T;VT@9O9R(&%T="!S=.1N9V$@878@
M:V%N=&QI;FIE`$QI8F%N;VX`5N1N<W1E<@!6Y&YS=&5R<G5B<FEK`%;D;G-T
M97)VY')D96X`3&5S;W1H;P!.:7;E`$QI8F5R:6$`3&EB>65N`$QI96-H=&5N
M<W1E:6X`3&IU<V)LY0!$=6=G<F5G;@!,Y'1T(')E9VX`3.1T="!F]G)M:61D
M86=S<F5G;@!,Y'1T(&5F=&5R;6ED9&%G<W)E9VX`3.1T="!R96=N<VMU<@!,
MY'1T(')E9VX@;65D(.5S:V$`3.1T="!S;O8`3.1T="!S;O9S:W5R`$QI;65R
M:6-K`$SD;FL`3.1N:R!L861E<R!T:6QL+@!,Y&YK(&%V8G)U=&5N+@!,Y&YK
M96X@<&5K87(@<.4Z`$SD;FMA(&4M<&]S=&%D<F5S<V5N('1I;&P@9G5N:W1I
M;VYE;B!F]G(@871T('-K87!A(&YY='0@;65D9&5L86YD90!,Y&YK87(`2V%K
M80!,:7-T80!,:7-T82`M(&%N=N1N9&%R92!K86X@<V4@;6%P<&5N`%9I<V$@
M9&%T86)A<V5R`%9I<V$@:&KD;'#D;6YE;@!,:7-T82!T86)E;&QE<@!,:7-T
M+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O
M<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!$970@9VEC:R!I
M;G1E(&%T="!L:7-T82!S97-S:6]N97(Z("5S`$1E="!G:6-K(&EN=&4@871T
M(&QI<W1A(&%N=N1N9&%R93H@)7,`3&ES=&YI;F<@878@86YVY&YD87)E(&%V
M86MT:79E<F%D+@!,:71T97)A='5R`$QI=&%U96X`3&%D9&%R+BXN`$QO:V%L
M('1I9#H@`%)E9VEO;F%L=`!0;&%T<P!,;V=G82!I;@!,;V=G82!U=`!,;V=I
M;@!,;V=I;F%K=&EV:71E=&5R`$EN;&]G9VYI;F<@;6ES<VQY8VMA9&5S+B!4
M<F]L:6=T=FES('9A<B!A;G;D;F1A<FYA;6X@96QL97(@;/9S96YO<F0@9F5L
M86MT:6=T+@!);FQO9V=N:6YG(&UI<W-L>6-K861E<RX`3.5N9R!T97AT`$OD
M<FQE:P!,Y6<`1W)E:VES:V$@9V5M96YE<@!,871I;G-K82!G96UE;F5R`%-M
MY2!R;VUE<G-K82!S:69F<F]R`$QO>6]L80!,;WEO;&$@0FSE`$QU>&5M8G5R
M9P!-30!-3U1$`$U3+51.148@8FEL86=A(&EN;F5H]FQL(&EN9V5N(&1A=&$N
M`$U31P!-86-A;P!-86-E9&]N:65N`$UA9V%G87-K87(`36%G:7-K`$4M<&]S
M=`!%+7!O<W1A9&UI;@!3:V%P82!LY&YK+BXN`$UA;&%W:0!-86QA>7-I80!-
M86QD:79E<FYA`$UA;&D`36%L=&$`56YD97)HY6QL(&QI<W1A;B!M960@:V%T
M96=O<FEE<B!D=2!A;G;D;F1E<B!F]G(@871T(&MA=&5G;W)I<V5R82!P;W-T
M97(@;65D(&]C:"!FY')G97)N82!S;VT@=&EL;&CV<B!D97-S82!K871E9V]R
M:65R+@!-87`R-"UK87)T80!-87!1=65S="UK87)T80#6=F5R<^1T=&YI;F=A
M<B!S<&%R861E+@!M87)S`$UA<F=I;F%L`$9L86=G82!S;VT@;.1S="]O;.1S
M=`!&;&%G9V$@;65D(&%N;F%N('-T871U<R`H="!E>"!V:6MT:6=T+V)E<W9A
M<F%T*0!-87)S:&%L;/9A<FYA`$UA<G1I;FEQ=64`36%T8VAA<@!-871C:&%N
M9&4@9N1L=`!-875R:71A;FEE;@!-875R:71I=7,`36%X('1I;&SE=&5N(&MR
M961I="X`1W+D;G,@9O9R(&UA>"!A;G1A;"!D96QA<B!I(&UE9&1E;&%N9&4@
M]G9E<G-K<FED96XN`$CV9W-T82!T96UP97)A='5R92!S96YA<W1E(#(T('1I
M;6UA<FYA.B``2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S=&4@-B!T:6UM87)N
M83H@`$UA>&EM86QT(&%N=&%L(&MO;G1A:W1E<@!-87AI;6%L="!A;G1A;"!P
M;W)T86QB;&]C:P!-87AI;6%L(&SD;F=D`$UA>&EM86QT(&%N=&%L('-I9&]R
M`&UA:@!-87EO='1E`$UE9&EC:6X`079B;VMA(&WV=&4`3?9T97-I;F9O<FUA
M=&EO;@!-]G1E<V;V<F9RY6=A;@!-]G1E<W-V87(`3?9T97-U<'!D871E<FEN
M9P!5<'!D871E<FEN9W-B96?D<F%N(&]M(&WV=&4`365D;&5M;6%R`$UE;GEL
M:7-T80!-96YY;.1G93H`4VSE(&EH;W`@8V5L;&5R`$UE9&1E;&%N9&4`365D
M9&5L86YD970@=F5R:69I97)A9&5S(&UE;B!D96X@<VEG;F5R861E<R!C97)T
M:69I:V%T(&MU;F1E(&EN=&4@=F5R:69I97)A<RX`365D9&5L86YD92!GY&QL
M97(@:6YT92!LY&YG<F4N`$UE9&1E;&%N9&5T>7``365T87)VY&1E<@!-971A
M<F)L;V-K970@Y'(@:6YT92!T:6QL9^1N9VQI="X`365T87(M8FQO8VL@96H@
M=&EL;&?D;F=L:6=T+B!$971A;&IE<B!H87(@;&]G9V%T<R!F]G(@<WES=&5M
M861M:6YI<W1R873V<F5N+@!-971A<D1"(.1R(&EN=&4@86YS;'5T96XN`$UE
M=&]D`$UE=&]D96X@)R5S)R#D<B!I;G1E(&1E9FEN:65R860`365T;V1E;B!H
M87(@:6YT92!D969I;F5R871S+B!!;G)O<&%D(&UE=&]D.B`E<P!-971R:7-K
M`$UE>&EK;P!-:6MR;VYE<VEE;@!-:71T96X`36EM971Y<`!,Y&=S=&$@=&5M
M<&5R871U<B!S96YA<W1E(#(T('1I;6UA<FYA.B``3.1G<W1A('1E;7!E<F%T
M=7(@<V5N87-T92`V('1I;6UA<FYA.B``36EN<W1A(&SV<V5N;W)D<^5L9&5R
M(&AA<B!I;G1E('5P<&[E='1S(.1N`%-P96=L80!$:79E<G-E`%-A:VYA<B!$
M3B!I($Q$05`M:V]N9FEG=7)A=&EO;F5N+@!/8FQI9V%T;W)I<VMT('!A:V5T
M('-A:VYA<R`H4$5!4B!(5%107U)E<75E<W0I+@!+;VYF:6=U<F%T:6]N('-A
M:VYA<RX@1'4@;>5S=&4@<VMA<&$@9&5N(&YU(&]M(&1U('9I;&P@86YVY&YD
M82!D96X@:.1R(&%P<&QI:V%T:6]N96XN`%-A:VYA<B!M961D96QA;F1E+4E$
M+@!/8FQI9V%T;W)I<VMT('!A:V5T('-A:VYA<R`H4$5!4B!-86EL*2X`4V%K
M;F%R('-E<W-I;VYS+4E$+@!-Y0!-;V)I;"!E+7!O<W0`36]B:6QT96QE9F]N
M`$UO9&5R97)A`,1N9')A9"!D871U;0#$;F1R82!LY&YK`,1N9')I;F<@;6ES
M<VQY8VMA9&5S.B`H)7,I("5S`$UO9'5L=7,`36]L9&%V:65N`$UO;F%C;P!-
M;VYG;VQI970`3>5N860@;V-H(.5R`$WE;F%T;&EG`$UO='-E<G)A=`!-Y6YF
M87-E<@!&;&5R(&;D;'0@:&ET=&%D97,@<.4@<F%D("5D(.1N(&1E="!F]G)V
MY&YT861E("5D+@!-97(@Y&X@,2!P;W-T(&AI='1A9&5S`$UA<F]C:V\`365S
M=&%D96QS(&ML87)T`$UE<W1A9&5L<R!M;VQN:6=T`$UE<W1A9&5L<R!S;VQI
M9W0`1FQY='1A`$9L>71T82!N960`1FQY='1A(';D;G-T97(`1FQY='1A(&CV
M9V5R`$9L>71T82!U<'``1FQY='1A(&YE9`!&;'ET=&$@=N1N<W1E<@!&;'ET
M=&$@:/9G97(`1FQY='1A('5P<`!-;^=A;6)I<75E`$UO>FEL;&$`375L8F5R
M<GD`1FQE<FYI=N5S;&ES=&$`375L=&EM87`@4W1O<F)R:71A;FYI96YK87)T
M80!&;&5R82!P97)S;VYE<B!M960@861R97-S96X@6R5S72P@;65N(&EN9V5N
M(&UE9"!N86UN970@6R5S72!E>&ES=&5R87(`1FQE<G9A;`!-:71T(&MO;G1O
M`$UI;B!K;VYT;VEN9F]R;6%T:6]N`$UI;B!A9')E<W-B;VL`36EN82!A9')E
M<W-B]F-K97(`36EN('!O<G1A;`!-:6X@<&]R=&%L;&%Y;W5T`$UY86YM87(`
M3D5*+"!*86<@86-C97!T97)A<B!I;G1E`$YA;6X`3F%M;F9O<FUA=&5R:6YG
M`$YA;6EB:6$`3F%U<G4`3F585`!"96CV=F5R(.5T9^1R9`!.97!A;`!.971C
M96YT97(@;65D;&5M<VMA=&%L;V<`3F5D97)LY&YD97)N80!.961E<FSD;F1S
M:V$@06YT:6QL97)N80!.97-C87!E(&)A<RU54DP`3F5T<V-A<&4@9O9R;GEE
M;'-E+5523`!.971S8V%P92#E=&5R:V%L;&5L<V4M55),`$YE='-C87!E(%-3
M3"US97)V97)N86UN`$YE='-A<&4@8V5R=&EF:6MA='-K;VUM96YT87(`3F5T
M<V%P92!C97)T:69I:V%T<W1Y<`!.Y'1V97)K`$%L9')I9P!.>6$@2V%L961O
M;FEE;@!.>2!K871E9V]R:0!.>2!K;VYT86MT`$YY='0@;65D9&5L86YD92!T
M:6QL("5S`$YY;>5N90!.>71T(&%N=N1N9&%R;F%M;B`H=F%L9G)I='0I`$YY
M82!:965L86YD`$YY='0@;/9S96YO<F0`3GET="!L]G-E;F]R9"!K;VUM97(@
M871T(&?E('5T("5X+@!,]G-E;F]R9"!MY7-T92!V87)A('-A;6UA+@!.>71T
M(&;V;G-T97(@*%]B;&%N:RD`3GEH971E<@!.>6AE='-G<G5P<&5R`$[D<W1A
M`$MO;6UA;F1E(#0@9F%S97(`3N1S=&$@:6YS=.1L;&YI;F=A<@!.Y'-T83X`
M3FEC87)A9W5A`%-M96MN86UN`$YI9V5R`$YI9V5R:6$`3F%T=`!.:75E`$YE
M:@!0;W-T("5S('-A:VYA<R!F]G(@)7,`26YG96X@861R97-S8F]K(&AI='1A
M9&5S+@!$970@9FEN;G,@:6YG970@:V]N9FEG=7)A=&EO;G-D871A(&%T="!V
M:7-A('-K:6QL;F%D97(@9O9R+@!);F=E;B!T:6QL9^1N9VQI9R!S=')A=&5G
M:2!F]G(@871T('-K87!A($E33RUI;6%G92X`26YT92!E;B!B871C:&UA;&PN
M`$1E="!F:6YN<R!I;F=E="!B;&]C:R!PY2!D96X@8F5GY')D82!P;W-I=&EO
M;F5N`$EN9V5T(&MA;&5N9&5R;F%M;B!F]G(@34-!3"!A=71E;G1I<V5R:6YG
M(&%N9VEV970N`$EN9V5N(.1N9')I;F<N`$EN9V$@=6YD97)B96CV<FEG:&5T
M97(@:V%N(&SD9V=A<R!T:6QL(&1E;B!HY'(@8F5H]G)I9VAE=&5N+@!);F=E
M;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R("5S+@!)
M;F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R($94
M4"!61E,N`$EN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG:79E
M;B!F]G(@4U%,(%9&4RX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO
M;B!A;F=I=F5N(&;V<B!344PM9FEL(%9&4RX`26YG82!K;VYT86MT97(@:&ET
M=&%D97,N`$EN9V5N(&MR961I="!K=F%R+@!"97-K<FEV;FEN9R!S86MN87,N
M`$EN9V5N(&UO='1A9V%R92!A;F=I=F5N+@!);F=E;B!F:6P@=7!P;&%D9&%D
M`$EN9V$@:6MO;F5R(&AI='1A9&5S+@!);F=E;B!O<G0@86YG:79E;BX`26YG
M96X@;W)T(&%N9VEV96XN`$EN9V5T(&UE9&1E;&%N9&4@8FEF;V=A9&5S+@!)
M;F=E="!N86UN(&%N9VEV970N`$EN9V5N(&YU;6UE<B!A;F=I=F5T+@!);F=A
M(&]F]G)S:^1M9&$@=FES:&5T<V]R9`!);F=E="!L]G-E;F]R9"!F]G(@2%14
M4"UA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!)
M34%0+6%U=&5N=&ES97)I;F<@86YG:79E="X`26YG970@;/9S96YO<F0@9O9R
M($ME<F)E<F]S+6%U=&5N=&ES97)I;F<@86YG:79E="X`26YG970@;/9S96YO
M<F0@9O9R($QO9VEN+6%U=&5N=&ES97)I;F<@86YG:79E="X`26YG970@;/9S
M96YO<F0@9O9R(%!!4U-71"UA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T
M(&SV<V5N;W)D(&;V<B!334(M875T96YT:7-E<FEN9R!A;F=I=F5T+@!);F=A
M(';D;G1A;F1E(')E9VES=')E<FEN9V%R+@!);F=E;B!K=F]T82!A;F=I=F5N
M`$EN9V5N(&MV;W1A(&%N9VEV96XN`$EN9V$@<F5G;&5R`$EN9V5N(&%V9W+D
M;G-A<F4@86YG:79E;BX`26YG82!S:61O<@!);F=E;B!SY61A;B!F:6P`26YG
M96X@=&5M<&]RY')K871A;&]G('1I;&QGY&YG;&EG(&;V<B!C86-H92X`26YG
M970@86YVY&YD87)N86UN(&]C:"]E;&QE<B!L]G-E;F]R9"!S:VEC:V%T+@!)
M;F=E;B!V0V%R9"UI;F9O<FUA=&EO;B!H:71T861E<RX`26YG970@9VEL=&EG
M(%A-3"UD871A(')E='5R;F5R861E<P!);F=A(';D<F1E;@!);F=E;B!V97)S
M:6]N(&AI='1A9&5S(&D@9&5N('5R<W!R=6YG;&EG82!K;VYF:6=U<F%T:6]N
M96XN(,5T97)S:V%P82!K;VYF:6=U<F%T:6]N96XN`$EN9V5N('9E<G-I;VX@
M:&ET=&%D97,@:2!D:6X@:V]N9FEG=7)A=&EO;BX@Q71E<G-K87!A(&MO;F9I
M9W5R871I;VYE;BX`26-K92UD96QT86=A<F4`26YG80!);F=E;B`H86YVY&YD
M('5N9&5R9O9R<W3E9&0I`$YO<F9O;&OV87)N80!.;W)R82!H96UI<V;D<F5N
M`$YO<G)A($UA<FEA;F'V87)N80!.;W)G90!);G1E(&5F=&5R`$EN=&4@9O9R
M90!);G1E(&5N(&MA=&%L;V<`16H@:6UP;&5M96YT97)A9"X`16H@86YG:79E
M;@!3=/9D<R!I;G1E+@!!;G1E8VMN:6YG87(`26YG96YT:6YG(&%T="!V:7-A
M+"!GY2!T:6QL8F%K82X`3T)3`&YO=F5M8F5R`$YU;6UE<@!!;G1A;"!T96-K
M96X`06YT86P@:V]L=6UN97(`06YT86P@<&]S=&5R('!E<B!S:61A`$%N=&%L
M(')A9&5R`$YU;6UE<B!I;G1E('-P96-I9FEC97)A9&4@9O9R(&%T="!U<'!D
M871E<F$@:2!D:7-T<FEB=71I;VYS;&ES=&%N+@!/2P!/8FIE:W0`3V)J96MT
M<VMA<&%R90!/8FIE:W1E="!H:71T861E<R!I;G1E`$]K=&%L`&]K=&]B97(`
M1FEL=&5R(&;V<B!O9O9R<VOD;61H971E<@!+;VYT;W(`1V%M;6%L="!O8V@@
M;GET="!L]G-E;F]R9"!FY7(@:6YT92!V87)A('-A;6UA+@!'86UM86QT(&SV
M<V5N;W)D`$=A;6UA;'0@;/9S96YO<F0@Y'(@9F5L86MT:6=T`$]M86X`3N1R
M(&1U('-P87)A<B!D96YN82!S:61A(&UE9"!I;G-TY&QL;FEN9V%R+"!SY2!K
M;VUM97(@861R97-S8F]K96X@871T(')A9&5R87,N($]M(&1E='1A(&EN=&4@
MY'(@=F%D(&1U('9I;&P@Y7-T86MO;6UA('/E(&WE<W1E(&1U(.1N9')A(&1I
M='0@=F%L('1I;&P@)TEN9V5N)RX`1&5L861E(&UA<'!A<B!S=/9D<R!E;F)A
M<G0@878@24U!4"US97)V<F%R`$5N8F%R="!O9O9R<VOD;61A('9I<VAE='-O
M<F0`16YD87-T(&5N(&4M<&]S=&%D<F5S<R!T:6QLY71E;BX`16YD87-T(&5T
M="!V0V%R9"!S=/9D<RX`16YD87-T(.1G87)E(&5L;&5R('-Y<W1E;6%D;6EN
M:7-T<F%T]G(@:V%N(.1N9')A(.1G87)E(&5L;&5R(&)E:/9R:6=H971E<B!P
MY2!E;B!U=&1E;&YI;F<`UG!P;F$@:2!N>71T(&;V;G-T97(`3W!E;E-33"UF
M96PZ($1E="!G:6-K(&EN=&4@871T(&5X=')A:&5R82!D871A(&9RY6X@<VEG
M;F5R860@4R]-24U%+61E;"X`UG!P;F$@;.1N:R!I(&YY='0@9O9N<W1E<@!/
M<&5R871I=G-Y<W1E;0!)8VME(&]B;&EG871O<FES:V$@9&5L=&%G87)E`$EN
M<W3D;&QN:6YG87(`26YS=.1L;&YI;F=A<B!F]G(@)7,`4V]R=&5R860@;&ES
M=&$`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;G-E;FAE=`!/<F=A;FES97)A
M`%5R<W!R=6YG;&EG(&%P<&QI:V%T:6]N<VUA;&P`57)S<')U;F=L:6=A(&UA
M;&QA<B!I("5S.@!!;FYA;@!!;F1R82!I;G-TY&QL;FEN9V%R`$%N9')A(&EN
M<W3D;&QN:6YG87(`Q&=A<F)E:/9R:6=H971E<@!004TM075T96YT:7-E<FEN
M9R#D<B!I;G1E('1I;&QGY&YG;&EG+@!014%2.CI-86EL+6MO<'!L:6YG`%!'
M4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4'5B;&EK
M(%!'4"UN>6-K96P`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`M:V]D
M`%!(4"US:V%L`$SD='0@9O9R;6ED9&%G<W)E9VX`1O9R;6ED9&%G<W)E9VX`
M169T97)M:61D86=S<VMU<F%R`$5F=&5R;6ED9&%G<W-N]@!%9G1E<FUI9&1A
M9W-S:W5R87(@;65D('-N]@!%9G1E<FUI9&1A9W-S;VP`Q7-K<VMU<F%R('#E
M(&5F=&5R;6ED9&%G96X`4$]325@M=&EL;.1G9R!S86MN87,`4%](4"US:V%L
M`%5T9GEL;&YA9#H`4&%K:7-T86X`4&%L874`4&%L97-T:6YA`%!A;F%M80!0
M87!U82U.>6$@1W5I;F5A`%!A<F%G=6%Y`$1E;'9I<R!M;VQN:6=T`$SV<V5N
M;W)D`$SV<V5N;W)D(.1N9')A9&5S+@!,]G-E;F]R9"!F96QA:W1I9W0`3/9S
M96YO<F0@:W+D=G,@9O9R(%)!1$E54R!A=71E;G1I<V5R:6YG+@!,]G-E;F]R
M9"!M960@8F5K<N1F=&5L<V4`3/9S96YO<F0Z`$SV<V5N;W)D.B``3/9S96YO
M<F0@;>5S=&4@=F%R82!L:6MA+@!+;&ES=')A(&EN`$ML:7-T<F$@:6X@9G+E
M;B!U<FML:7!P<VAA;G1E<F%R96X`4_9K=N1G`%;D;G1A;F1E(')E9VES=')E
M<FEN9V%R.@!-Y&YN:7-K;W(`4')O8V5N=`!5=&;V<B!U;F1E<FCE;&QS9G5N
M:W1I;VYE<@!5=&;V<B!U;F1E<FCE;&QS86MT:79I=&5T97(@=FED(&EN;&]G
M9VYI;F<_`$)E:/9R:6=H970`0F5H]G)I9VAE="`G)7,G(')A9&5R861E<R!I
M;G1E+@#%=&MO;7-T(&YE:V%D`,5T:V]M<W0@;F5K860`0F5H]G)I9VAE=&5R
M`$)E:/9R:6=H971S861M:6YI<W1R871I;VX`4&5R<V]N;&EG(&EN9F]R;6%T
M:6]N`%!E<G4`2'5S9&IU<@!&:6QI<'!I;F5R;F$`5&5L969O;@!&;W1O;@!0
M:6YE(&%D<F5S<V)O:P!0:71C86ER;@!0:7AL87(`2VQI8VCI97(`5F%R(&=O
M9"!K;&EC:V$@:2!E;B!C96QL`$)E:W+D9G1A(&%T="!D=2!V:6QL(')A9&5R
M82!V86QD('!O<W0_`$)E:W+D9G1A(&%T="!D=2!V:6QL(')A9&5R82!A:W1U
M96QL="!E;&5M96YT+@!687(@9V]D(&%N9V4@;>5N860@;V-H(.5R+@!687(@
M9V]D(&%N9V4@;F%M;B!F]G(@:V%T96=O<FEN.@!687(@9V]D(&%N9V4@9V]D
M:^1N9"!)4"UA9')E<W,N`%9A<B!G;V0@86YG92!E='0@9VEL=&EG="!D871U
M;3L@:V]N=')O;&QE<F$@86YT86QE="!D86=A<B!I(&WE;F%D96XN`%9A<B!G
M;V0@86YG92!E;B!G;V1KY&YD('1I9"X`4VMR:78@:6X@971T(&YA;6X@<.4@
M9&5N(&YY82!K;VYT86MT;&ES=&%N.@!687(@9V]D('-U;6UE<F$@9&ET="!P
M<F]B;&5M+@!!;F=E(&1I='0@86YVY&YD87)N86UN(&]C:"!L]G-E;F]R9"X`
M5F%R(&=O9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E>'0N($1U($W%4U1%('-A
M;71Y8VMA(&UE9"!V:6QL:V]R96X@9O9R(&%T="!A;G;D;F1A('-Y<W1E;65T
M+@!687(@9V]D(&SD<R!I9V5N;VT@9O9L:F%N9&4@=&5X="X@1'4@3<535$4@
M<V%M='EC:V$@;65D('9I;&QK;W)E;B!F]G(@871T(&%N=N1N9&$@<WES=&5M
M970N`$MO;G1R;VQL97)A(&;V;&IA;F1E(&EN9F]R;6%T:6]N(&]C:"!VY&QJ
M('-E9&%N(&5N(&AA;F1L:6YG(&D@;65N>6X*;F5D86XN`%;D;&H@96X@:&%N
M9&QI;F<@9G+E;B!M96YY;B!N961A;BX`5F%R(&=O9"!VY&QJ(&MO;G1A:W0`
M06YG92!N>71T(&MA=&5G;W)I;F%M;CH`4&]L96X`4&]L:71I:P!5;F1E<G/V
M:VYI;F=A<@!0;W)T=6=A;`!0;W-I=&EO;F5R:6YG(&%V(&)I;&1E;@!0;W-I
M=&EO;F5R:6YG(&%V('1A8F5L;&5N`%-K<FEV('1I;&P@9&5N(&CD<B!M87!P
M96X@*&5J('1V:6YG870@878@24U!4"D`4&]S=&YU:V4`3F5D97)B]G)D(&1E
M('-E;F%S=&4@)7,@=&EM;6%R;F$Z(`!#:&%N<R!T:6QL/&)R+SYN961E<F+V
M<F0`075T:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K;F%S+@!0<F5F<U]S97-S
M:6]N.B!/8FQI9V%T;W)I<VMT('-E<W-I;VYS=&EL;.1G9R!H:71T861E<R!I
M;G1E+@!4<GEC:P!,=69T=')Y8VL@=FED(&AA=F5T.B``3'5F='1R>6-K.B``
M1O9R:&%N9'-V:7-N:6YG`$;V<FAA;F1S9W)A;G-K82!B:6QD(&D@;GET="!F
M]FYS=&5R`$;V<F5GY65N9&4`1O9R96?E96YD92!I;G-TY&QL;FEN9V%R`%-K
M<FEV('5T(&1O:W5M96YT`%!R:79A="!A9')E<W-B;VL`4')I=F%T82!N>6-K
M96P`4')O8FQE;0!0<F]B;&5M8F5S:W)I=FYI;F<`4')O:F5K=`!497AT`%!U
M8FQI:R!N>6-K96P`4'5B;&EK(&YY8VME;&%L9V]R:71M`%!U8FQI:R!N>6-K
M96QI;F9O<FUA=&EO;@!&96P@=FED(&=E;F5R97)I;F<@878@<'5B;&EK="]P
M<FEV870@;GEC:V5L<&%R+@!0=65R=&\@4FEC;P!296YS82!M961D96QA;F1E
M;@!1871A<@!&<N5G80!3]FMN:6YG(&UI<W-L>6-K861E<SH@*"5S*2`E<P!3
M;F%B8G/V:P!+=F]T80!0=6)L:6L@4E-!+6YY8VME;"`H)60@8FET87(I`$5N
M<VMI;'0@=F%L`%)E9VX`5&ED:6=T(')E9VX`4V5N="!R96=N`%)E9VYS:W5R
M87(`4F5G;B!O8V@@<V[V`%)E9VX@=&EL;"!S;O8`4VQU;7!MY'-S:6=T('9I
M<VAE='-O<F0`1O9R:.5L;&%N9&4`3.1S`$SD<VYI;F<@;6ES<VQY8VMA9&5S
M.B`H)7,I("5S`$SD<R!M961D96QA;F1E;@!&=6YK=&EO;F5N(&%T="!LY'-A
M(&MO;G1A:W1E<B#D<B!I;G1E('1I;&QGY&YG;&EG+@!3Y&ME<G0@871T(&1U
M('9I;&P@<F%D97)A("5S/R!2861E<FEN9V5N(&MA;B!I;G1E(.5N9W)A<RX`
M4F%D97)A(&1E;B!HY'(@:V]N=&%K=&5N/P!3Y&ME<G0@871T(&1U('9I;&P@
M<F%D97)A(&%N=N1N9&%R9&%T82!F]G(@)7,_(%)A9&5R:6YG96X@:V%N(&EN
M=&4@Y6YG<F%S+@!0;W-T97(@=FES861E.@!']G(@;VT@9&EN('-E;F%S=&4@
M:6YM871N:6YG`%5P<&1A=&5R80!5<'!D871E<F$@9'EN86UI<VMA(&UE;GEE
M;&5M96YT.@!5<'!D871E<F$@<&]R=&%L=GDZ`%)E9V5X`%9I<V$@9O9R:.5L
M;&%N9&5N`$QA9&1A(&]M`$MO;6UE;G1A<F5R`$MO;2!I:.5G(&EN9F]R;6%T
M:6]N(&]M(&QE9&EG+W5P<'1A9V5N+@!&:N1R<G-E<G9R87(`55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`5&$@8F]R=`!482!B;W)T(&)L
M;V-K`%)A9&5R82!A9')E<W-B;VL`5&$@8F]R="!K;VQU;6X`5&$@8F]R="!F
M;W)M871E<FEN9P!482!B;W)T(&9RY6X@;6EN(&MA;&5N9&5R`%1A(&)O<G0@
M9G+E;B!A:W1U96QL(&QI<W1A`%1A(&)O<G0@<&%R`%)A9&5R82!S<&%R870@
M<VMR:7!T(&9RY6X@<V5R=F5R;G,@=&5M<&]RY')K871A;&]G+@!482!B;W)T
M`%)A9&5R82!D96YN82!N;V0@9G+E;B!D;VMU;65N=&5T`%1A(&)O<G0@86YV
MY&YD87)E`%1A(&)O<G0@86YVY&YD87)E.B`E<P!%<G/D='0@8F5F:6YT;&EG
M(&%D<F5S<V)O:R!M960@9&5N(&EM<&]R=&5R861E/R`\<W1R;VYG/E9A<FYI
M;F<Z($%L;&$@<&]S=&5R(&D@86MT=65L;"!A9')E<W-B;VL@:V]M;65R(&%T
M="!R861E<F%S+CPO<W1R;VYG/@!3=F%R('-K:6-K870N`%-V87)A(&%T="!B
M96?D<F%N(&EN=&4@<W3V9',`4W9A<F$@;65D(&EN9F]R;6%T:6]N(&]M(&QE
M9&EG+W5P<'1A9V5N(&;V<B!K;VUM86YD92!T=N4@;>5N861E<BX`4W9A<F$@
M;65D(&1E;B!B96?D<F1A(&QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N96XN
M`%-V87(Z("5S`$)E9^1R86X@:W5N9&4@:6YT92!B97-V87)A<RX@4F5T=7)N
M97)A9"!F96QK;V0Z(`!%9G1E<F9RY6=A="!O8FIE:W0@<V%K;F%S+@!$96X@
M969T97)F<N5G861E('1JY&YS=&5N(&MU;F1E(&EN=&4@:&ET=&%S+@!%<F9O
M9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R871I;VYE;B!A
M=B`E<RX`17)F;V1R860@)R5S)R#D<B!I;G1E(&%N9VEV96X@:2!K;VYF:6=U
M<F5R:6YG96X@878@5D93+@!%<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E
M;B!I(&MO;F9I9W5R97)I;F=E;BX`3V)L:6=A=&]R:7-K='0@9N1L=`!/8FQI
M9V%T;W)I<VL@9&5L=&%G87)E`,5T97)S=.1L;`#%=&5R<W3D;&P@;/9S96YO
M<F0`Q71E<G-TY&QL(&SV<V5N;W)D`,5T97)S=.1L;"!T:6QL(&=R=6YD:6YS
M=.1L;&YI;F=A<@#%<W1E<G3D;&P@<V5N87-T92!F<N5G86X`4F5S=6QT870`
MQ71E<G;D;F0@=&EL;"!I;G-TY&QL;FEN9V%R`$%N9V4@;GET="!L]G-E;F]R
M9`!2Z75N:6]N`,5T97)S=.1L;"!K;VYF:6=U<F%T:6]N`$EN<W3D;&QN:6YG
M87(@9O9R(%)I8V@@5&5X="!%9&ET;W(`1^5T;W(`2/9G97(`2/9G97)R=6)R
M:6L`2/9G97)VY')D96X`4F%?9&EN<W3D;&QN:6YG87(N+BX`4F]L;`!2=6WD
M;FEE;@!2;W1E<F$@,3@P`%)O=&5R82!VY&YS=&5R`%)O=&5R82!H]F=E<@!2
M861I;G-TY&QL;FEN9V%R`%)A9&EN<W3D;&QN:6YG87(`4F%D97(Z`$QI;FIE
M<@!,:6YJ97(@=FES87,@;65L;&%N(&%L;&$@<F%D97(@;V-H(&MO;'5M;F5R
M`$QI;FIE<B!V:7-A<R!E;F)A<G0@;65L;&%N(&MO;'5M;F5R`$QI;FIE<B!V
M:7-A<R!E;F)A<G0@;65L;&%N(')A9&5R`$OV<@!2>7-S;&%N9`!2=V%N9&$`
M4R]-24U%('-I9VYA='5R`%,O34E-12UK<GEP=&5R870@;65D9&5L86YD90!0
M=6)L:6MT(%,O34E-12UC97)T:69I:V%T`%-!4TPM875T96YT:7-E<FEN9R#D
M<B!I;G1E('1I;&QGY&YG;&EG+@!335,@;65D9&5L86YD96X`4U%,+7-K86P`
M4U%,+7-E:W9E;G,@9O9R('5P<'-L86<@878@=N1R9&5N`%-32`!35$%25%1,
M4R!M:7-S;'EC:V%D97,Z("@E<RD@)7,`3%E#2T%4`%-?44PM<VMA;`!,]@!3
M86EN="!(96QE;F$`4V%I;G0@2VET=',@;V-H($YE=FES`%-A:6YT($QU8VEA
M`%-A:6YT+5!I97)R92!O8V@@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!O8V@@
M1W)E;F%D:6YE<FYA`%-A;6UA(')A;2`H7W-E;&8I`%-A;6]A`%-A;B!-87)I
M;F\`4V%O(%1O;64@;V-H(%!R:6YC:7!E`%-A='1E;&ET;&5V97)A;G3V<@!3
M875D:6%R86)I96X`4W!A<F$`4W!A<F$@)R5S)P!3<&%R82`E<P!3<&%R82!I
M;G-TY&QL;FEN9V%R`%-P87)A(&=E;F5R97)A9"!K;VYF:6=U<F%T:6]N('-O
M;2!02%`M<VMR:7!T('1I;&P@9&EN('-E<G9E<G,@('1E;7`M:V%T86QO9RX`
M4W!A<F%D92!K;VYF:6=U<F%T:6]N(&;V<B`E<RX`4W!A<F%D92!U<'!G<F%D
M97)I;F=S<V-R:7!T('1I;&PZ("5S+@!&=6YK=&EO;F5N(&%T="!S<&%R82!K
M;VYT86MT97(@Y'(@:6YT92!T:6QL9^1N9VQI9RX`4W!R:61D82#E<VMS:W5R
M87(`5F5T96YS:V%P`%/V:P!3]FMM;W1O<F5R`%/V:VYI;F<@;6ES<VQY8VMA
M9&5S`%/V:VYI;F<@;6ES<VQY8VMA9&5S.B`E<P!&=6YK=&EO;F5N(&%T="!S
M]FMA(.1R(&EN=&4@=&EL;&?D;F=L:6<N`%/V:V5R+BXN`%;D;&H`5N1L:B!A
M9')E<W-B;VL`5N1L:B!F:6QE<@!6Y&QJ(&5T="!D871U;0!6Y&QJ(&=R=7!P
M(&%T="!LY&=G82!T:6QL`%;D;&H@;GD@Y&=A<F4`5N1L:B!S97)V97(`5N1L
M:B!A;G;D;F1A<F4@871T(&SD9V=A('1I;&P`5N1L:B!A;&QA`%;D;&H@9&%T
M=6UK;VUP;VYE;G1E<BX`5N1L:B!A9')E<W-B;VL@<V]M('-K86QL(')A9&5R
M87,`5N1L:B!A9')E<W-B;VL@871T(')E9&EG97)A`%;D;&H@971T(&]B:F5K
M=`!6Y&QJ(&EN9V5N`%;D;&H@861R97-S8F]K(&%T="!E>'!O<G1E<F$@9G+E
M;CH`5N1L:B!A9')E<W-B;VL@871T(&EM<&]R=&5R82!T:6QL.@!!;F=E(&1E
M('1E8VME;B!D=2!B96CV=F5R(&D@<G5T;W)N82!N961A;BX@1'4@:V%N('-E
M9&%N(&MO<&EE<F$@;V-H(&ML:7-T<F$@:6X@9&5M(&D@=&5X=&%R=71A;BX`
M5N1L:B!T96-K96YU<'!SY'1T;FEN9R!PY2!I;7!O<G1F:6QE;CH`5N1L:B!A
M=F=RY&YS87)E(&;V<B!D871U;3H`5N1L:B!D871U;69O<FUA=#H`5N1L:B!E
M>'!O<G1F;W)M870Z`%;D;&H@9FEL('-O;2!S:V%L;"!I;7!O<G1E<F%S.@!6
MY&QJ(&9O<FUA="!PY2!I;7!O<G1F:6QE;CH`5N1L:B!F;W)M870@9O9R('9I
M<VYI;F<@878@;F%M;CH`5N1L:B!I9&5N=&ET970@9'4@=FEL;"#D;F1R83H`
M5N1L:B!A=F=RY&YS87)E(&;V<B!T:60Z`%;D;&H@=&ED<V9O<FUA=#H`5N1L
M:B!T=N4@;6%T8VAA;F1E(&;D;'0Z`%;D;&H@<W1A;F1A<F1V>2P@<V]R=&5R
M:6YG<RT@;V-H('-I9&EN<W3D;&QN:6YG87(N`%;D;&H@=FEL:V$@9N1L="!S
M;VT@=FES87,@:2!A9')E<W-L:7-T86XN`%;D;&H@:'5R(&YA;6X@=FES87,N
M`%;D;&H@9&ET="!FY')G<V-H96UA+@!!;F=E(&1I='0@9O9R=F%L9&$@<W!R
MY6LZ`%9A;&0@861R97-S8F]K("<E<R<N`%-K:6-K82!S96YA<W1E(&EN9F]R
M;6%T:6]N96X`4VMI8VMA('!R;V)L96UR87!P;W)T`%-K:6-K82!335,`4V5N
M96=A;`!396YS;W(Z(`!S97!T96UB97(`4V5R8FEE;B!O8V@@36]N=&5N96=R
M;P!397)I96YU;6UE<@!397)V97)I;G-TY&QL;FEN9V%R(&9E;&%K=&EG82!E
M;&QE<B!I;F%K=&EV('-E<G9E<BX`4V5S<VEO;G-A9&UI;FES=')A=&EO;@!3
M97-S:6]N<RU)1"!H87(@9^5T="!U="X`4V5S<VEO;F5R`%/D='0`2V]N9FEG
M=7)E<F$@86QT97)N871I=B!S;VT@;?9J;&EG9_9R(.5T97)S=.1L;&YI;F<@
M878@8F]R=&=L]FUT(&SV<V5N;W)D+@!+;VYF:6=U<F5R82!F:N1R<G-E<G9R
M87(@<V]M(&1U('9I;&P@:V]M;6$@Y70@9G+E;B!D:6X@<&]R=&%L+@!!;F=E
M(&1I='0@9O9R=F%L9&$@<W!RY6LL('1I9'-Z;VX@8V]H(&1A='5M:6YS=.1L
M;&YI;F=A<BX`4^1T="!D:71T(&EN:71I86QA(&%P<&QI:V%T:6]N+"!FY')G
M<V-H96UA+"!S:61U<'!D871E<FEN9R!O8V@@86YD<F$@=FES;FEN9W-I;G-T
MY&QL;FEN9V%R+@!3971U<`!+;VYF:6=U<F%T:6]N<W5P<&=R861E<FEN9W-S
M:W)I<'0@9FEN;G,@=&EL;&?D;F=L:6=A`$1E="!F:6YN<R!F;&5R82!O<G1E
M<B!M960@<&%R86UE=&5R;CH`4V5Y8VAE;&QE<FYA`$1E;&%D(&MA=&%L;V<`
M2&%N9&5L`$MO<G0@<W5M;65R:6YG`%-K86QL(&=E;G;D9W-T86YG96YT97(@
M9&5F:6YE<F%S(&;V<B!D92!F;&5S=&$@;.1N:V%R/P!6:7-A`%9I<V$@)7,`
M5FES82!A;&QA`%9I<V$@:V]N=&%K=&5R`%9I<V$@;&ES=&]R`%9I<V$@<VMI
M;&QN861E<B!M96QL86X@9&5N(&%K='5E;&QA(&]C:"!D96X@;GEL:6=E;B!S
M:V%P861E(&MO;F9I9W5R871I;VYE;BX`5FES82!S96YA<W1E(&EN;&]G9VYI
M;F=S=&ED('9I9"!I;FQO9V=N:6YG/P!6:7-A(&EN<W3D;&QN:6YG(&;V<B!A
M='0@8F5HY6QL82!O<FEG:6YA;`!6:7-A('!A;&5T=`!6:7-A("=T86)E;&QA
M:W1I=FET971E<B<@:2!M96YY;C\`5FES82!M96YY(&;V<B`E<R!T:6QL(';D
M;G-T97(_`%1A8F5L;&-E;&QI;G-TY&QL;FEN9V%R`%1A8F5L;&EN<W3D;&QN
M:6YG87(`5&%B96QL:6YS=.1L;&YI;F=A<@!6:7-A(&1I86QO9W)U=&$@9O9R
M(&)I;&1E9V5N<VMA<&5R`%9I<V$@=7!P;&%D9&YI;F<`4VMU<F%R`%1I9&EG
M82!S:W5R87(`4V5N82!S:W5R87(`4VMU<F%R(&D@;N1R:&5T96X`1O9R;6EN
M<VMA`$MR>6UP(&5L;&5R(&9L>71T82!B;W)T(&[D<FQI9V=A;F1E(&)L;V-K
M(&;V<G-T`%-I97)R82!,96]N90!296=I<W1R97)A`%-I9VYA='5R`%-I9VYA
M='5R86QG;W)I=&T`4VEM<&QE>`!3:6YG87!O<F4`4W1O<FQE:P!!=F)R>70@
M=6YD97)HY6QL`%-L;W9A:VEE;@!3;&]V96YI96X`4V[V`%-N]G-K=7(`4V[V
M<VMU<F%R`%1I9&EG82!S;O9S:W5R87(`4V5N82!S;O9S:W5R87(`4V[V9&IU
M<#H@`$UO='-V87)A;F1E('-N]B!I('9A='1E;CH@`%-A;&]M;V[V87)N80!3
M;VUA;&EA`%/E;F=E<B!O8V@@9&EK=&5R`%-O<G1E<FEN9W-R:6MT;FEN9P!3
M;W)T97)I;F=S:6]R9&YI;F=S=F%L`&OD;&QA9')E<W,`2^1L;&]R`%-Y9&%F
M<FEK80!3]F1R82!'96]R9VEA(&]C:"!3>7-S86YD=VEC:/9A<FYA`%/D9')A
M(&AE;6ES9N1R96X`571R>6UM92!M96QL86X@:6YT:6QL:6=G86YD92!C96QL
M97(`571R>6UM92!M96QL86X@:6YN96CE;&P@;V-H(&MA;G1E;B!I(&-E;&QE
M;@!-96QL86YR=6T`365L;&%N<G5M`$UE;&QA;G)U;2!O8V@@=71JY&UN:6YG
M`%-P86YI96X`4W!A;0!);FUA=&YI;F<@878@<W!E8VEE;&QA('1E8VME;@!!
M;F=E('9A<B!R97-U;'1A="!F<N5N(&%V86YC97)A9"!S]FMN:6YG('-K86QL
M('9I<V%S+@!$96QA(&-E;&P`1&5L82!K;VQU;6X`1&5L82!R860`4W!O<G1E
M<@!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T`%-T87)TY7(`
M4W1A="!E;&QE<B!R96=I;VX`4W1A='5S`$QA9W)I;F=S9F]R;6%T`$=A='5A
M9')E<W,`1V5N;VUS=')U:V5N`%-T<N1N9VQI<W1A`%1A(&)O<G0@9&]MY&X@
M9G+E;B!A9')E<W-E;@!3=&EL(%M#4U-=`%/V`$MA;B!I;G1E(&AI='1A('5N
M9&5R:V%T86QO9R`G)7,G+@#$<F5N9&4`4VMI8VMA`$1I;B!B96?D<F%N(&%T
M="!LY&=G82!T:6QL("(E<R(@=&EL;"!S>7-T96UE="!H87(@<VMI8VMA=',N
M($1U(&MA;B!I;G1E(&QO9V=A(&EN(&EN;F%N(&1I;B!B96?D<F%N(&AA<B!A
M8V-E<'1E<F%T<RX`3F5D<^1N:W0`3'EC:V%T`"<E<R<@;&%D97,@=&EL;"!I
M('-Y<W1E;65T+@!,861E('1I;&P@)60@:V]N=&%K="AE<BD@=&EL;"!L:7-T
M86XN`"5S(&QA9&5S('1I;&P@:2`E<P!2861E<F%D92!I;F9O<FUA=&EO;B!O
M;2!A;G;D;F1A<F4@)R5S)RX`4VMA<&%D92!K;VYT86MT;&ES=&%N("<E<R<N
M`"<E<R<@<F%D97)A9&5S+@!2861E<F%D92`E9"!K;VYT86MT*&5R*2X`)R5S
M)R!T;V=S(&)O<G0@9G+E;B!S>7-T96UE="X`4F%D97)A9&4@)60@:V]N=&%K
M="AE<BD@9G+E;B!L:7-T86XN`$MO;F9I9W5R871I;VYE;B!H87(@Y71E<G-T
MY&QL=',N($QA9&1A(&]M('-I9&%N(&;V<B!A='0@<V4@9O9RY&YD<FEN9V%R
M+@!3<&%R861E(&)A8VMU<&MO;F9I9W5R871I;VXN`%-P87)A9&4@8F%C:W5P
M:V]N9FEG=7)A=&EO;B`E<RX`)R5S)R!U<'!D871E<F%D97,N`%-K<F5V("5S
M`%-U9&%N`%-A;6UA;G-TY&QL;FEN9P!3;VQU<'!GY6YG`%-O;&YE9&?E;F<`
M4V]L:6=T`%-O;'5P<&?E;F<`4V]L=7!P9^5N9R]N961GY6YG`%-O;'5P<&?E
M;F<Z(`!3;VQN961GY6YG`%-O;&YE9&?E;F<Z(`!5<'!H]FID`%-U<'!O<G0`
M4W5R:6YA;64`169T97)N86UN`%-V86QB87)D(&]C:"!*86X@36%Y96X`4W=A
M>FEL86YD`%-V97)I9V4`4V-H=V5I>@!3>6MR;VYI<V5R:6YG<VQO9V<@<F%D
M97)A9`!3>6YC34P`4WEN=&%X9F5L(&D@<_9K:W)I=&5R:6$`4WER:65N`,5S
M:W-K=7(`Q7-K<VMU<F%R(&]C:"!B;.5S:6=T`,5S:W-K=7)A<@!4:61I9V$@
MY7-K<VMU<F%R`%135@!44U8M9FEL`%1A8G-E<&%R97)A9&4@=N1R9&5N`%1A
M8F5L;`!486)E;&QI;G-TY&QL;FEN9V%R`%1A8F5L;'5P<'/D='1N:6YG`%1A
M8F5L;&EN<W3D;&QN:6YG87(`5&%I=V%N`%1A:7=A;@!486II:VES=&%N`%1A
M;GIA;FEA`$WE;#H`57!P9VEF=&5R`%1E86P`5&5L969O;FYU;6UE<@!(]F=S
M=&$@=&5M<&5R871U<B!S96YA<W1E('1I;6UE;CH@`%1E;7!E<F%T=7(`5&5M
M<&5R871U<CH@`%1E;7!E<F%T=7(\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F
M9&5G.R5S`$MA;B!I;G1E(&AI='1A(&UA;&P@)7,N`$%N=N1N9&%R861M:6YI
M<W1R871I;VX`1V]D:^1N;B!B96?D<F%N('!R96QI;6ENY')T`%!R96QI;6EN
MY')T(&%C8V5P=&5R870`5&5X=`!%;F)A<G0@=&5X=`!497AT:G5S=&5R:6YG
M`%1E>'1T;W``5&\`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&%C:R!F]G(@
M871T(&1U(&%N=N1N9&5R('-Y<W1E;65T+@!,Y&YK96X@)7,@=&EL;"`E<R!H
M87(@<F%D97)A=',N`$944"UT:6QLY&=G970@Y'(@:6YT92!T:6QL9^1N9VQI
M9W0N`$AI<W1O<FEK<WES=&5M970@Y'(@879A:W1I=F5R870N`$AO<F1E+TMO
M;&%B+6EN=&5G<F%T:6]N<V=RY&YS<VYI='1E="!S=/9D97(@:6YT92`B)7,B
M`$E-4U`M;&]G9V5N(&MU;F1E(&EN=&4@:6YI=&EE<F%S+@!+;&%S<V5N($UA
M:6YT96YA;F-E.CH@:W5N9&4@:6YT92!L861D87,`26YS=.1L;&YI;F=S9O9N
M<W1R970@:&%R('-TY&YG=',N($%V<VQU=&%R+@!61E,M8F%C:V5N9"!B96CV
M=F5R(&MO;F9I9W5R97)A<R!F]G(@871T(&%K=&EV97)A('5P<&QA9&1N:6YG
M(&%V(&)I;&%G;W(N`$%D<F5S<V)O:R`G)7,G(&9I;FYS(&EN=&4N`$%D<F5S
M<V)O:V5N("<E<R<@<VMA<&%D97,N`$%D<F5S<V)O:V5N("<E<R<@<F%D97)A
M9&5S+@!!9')E<W-B;VME;B`G)7,G('5P<&1A=&5R861E<RX`061R97-S8F]K
M96X@:W5N9&4@:6YT92!T]FUM87,Z("5S`$%D;6EN:7-T<F%T]G)E;B!MY7-T
M92!K;VYF:6=U<F5R82!E;B!P97)M86YE;G0@0F5H]G)I9VAE=',M:V]P<&QI
M;F<@;VT@9'4@=FEL;"!A;G;D;F1A($)E:/9R:6=H971E<BX`16YB87)T(&YE
M9')E('-I9&%N`$MA;&5N9&5R:6YF;W)M871I;VYE;B#D<B!F96QA:W1I9P!+
M;VYT86MT96YS($E$(&%N9V%V<R!I;G1E(&5L;&5R(&MU;F1E(&EN=&4@:&ET
M=&%S(&D@9&%T86)A<V5N+@!+;VYT86MT96X@;&%D97,@=&EL;"!I(&%D<F5S
M<V)O:V5N+@!+;VYT86MT96X@9'4@<_9K97(@9FEN;G,@:6YT92X`1&5N(&SV
M<V=J;W)D82!01U`M<VEG;F%T=7)E;B!K<N1V<R!F]G(@871T('9E<FEF:65R
M82!D970@<VEG;F5R861E(&UE9&1E;&%N9&5T+@!$:7-T<FEB=71I;VYS;&ES
M=&%N<R!)1"!A;F=A=G,@:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I
M(&1A=&%B87-E;BX`1&ES=')I8G5T:6]N<VQI<W1A;B!H87(@:6YT92!A;F=I
M=FET<RX`2W)Y<'1E<FEN9W-F=6YK=&EO;F5R;F$@:W+D=F5R(&5N('/D:V5R
M('=E8F;V<F)I;F1E;'-E("A(5%104RDN`$CD;F1E;'-E;B!L861E<R!T:6QL
M(&D@:V%L96YD97)N+@!&:6QE;B`G)7,G(')A9&5R861E<RX`1FEL96X@)7,@
M<VMA;&P@:6YN96CE;&QA(&5N(&EN<W3D;&QN:6YG(&;V<B`E<RX`1FEL96X@
M)7,@<VMA;&P@:6YN96CE;&QA(&EN<W3D;&QN:6YG87(@9O9R("5S+@!&:6QE
M;B!K86X@:6YT92!K;W!I97)A<R!T:6QL('-I9R!S:N1L=BX`1FEL96X@:V%N
M(&EN=&4@:V]P:65R87,@=&EL;"!S:6<@<VKD;'8N`$9I;&5N(&EN;F5H]FQL
M(&EN9V5N(&EN9F]R;6%T:6]N+@!(=79U9&;D;'0@9O9R(&1E='1A(&UE9&1E
M;&%N9&4O<F9C.#(R;65D9&5L86YD92!F]FQJ97(`261E;G1I=&5T96X@)R5S
M)R!R861E<F%D97,N`$EM<&]R=&5N(&MA;B!A=G-L=71A<R!T<F]T<R!V87)N
M:6YG87(N`$)A<F$@=N1N<W1E<B!S:61A`$SD;FME;B!H87(@=&%G:71S(&)O
M<G0`4_9K=N1G96X@=&EL;"!';G501RUP<F]G<F%M;65T(&WE<W1E('9A<F$@
M86YG:79E;B!T:6QL(&ML87-S96X@0W)Y<'1?<&=P.CHN`$UE9&1E;&%N9&5T
M('-K:6-K870@)7,@=&EL;"`E<R!M960@Y')E;F1E("(E<R(@:&%R('9I<V%T
M<RX*1&5T=&$@Y'(@:6YG96X@9V%R86YT:2!F]G(@871T(&UE9&1E;&%N9&5T
M(&AA<B!LY'-T<RX`3F%M;F5T('-O;2!S:V%L;"!A;G;D;F1A<R!F]G(@871T
M(&SD;FMA('1I;&P@<VMA<&$M<VED86X`06YT86P@9N1L="!MY7-T92!V87)A
M(&5T="!N=6UE<FES:W0@=N1R9&4N`$UO9'5L96X@;W!E;G-S;"!K<N1V<R!A
M=B!K;&%S<V5N($AO<F1E7T-R>7!T7W-M:6UE.CHN`$EN<W3D;&QN:6YG96X@
M(B5S(B!K=6YD92!I;G1E('-P87)A<R!PY2!G<G5N9"!A=B!A='0@9&%T86WD
M;F=D96X@]G9E<G-K<FEV97(@9&5N(&UA>&EM86QT('1I;&SE=&YA`%!R;V=R
M86UM970@<V]M(&%N=N1N9',@9O9R(&%T="!V:7-A(&1E;B!HY'(@;65D9&5L
M86YD971Y<&5N("@E<RD@<V%K;F%S('#E('-Y<W1E;65T+@!496-K;F5T(&;V
M<B!C:71E<FEN9R!MY7-T92!V87)A(&5T="!T96-K96XN`$)A<F$@:/9G97(@
M;V-H(';D;G-T97(@<VED;W(`0F%R82!H]F=E<B!S:61A`%-E<&%R871O<FX@
M;>5S=&4@=F%R82!E='0@=&5C:V5N+@!397)V97(@)R5S)R!R861E<F%D97,N
M`%-E<G9E<B`G)7,G('-P87)A9&5S+@!0<F5N=6UE<F%T:6]N<V)E9^1R86X@
M9O9R("5S(&AA<B!T86=I=',@8F]R="X`06YG:79E;B!R860@*"5D*2!F:6YN
M<R!I;G1E+@!!;F=I=F5N(')A9"!E>&ES=&5R87(@:6YT92X`57!P9VEF=&5N
M(&AA<B!L86=T<R!T:6QL(&D@9&EN('5P<&=I9G1S;&ES=&$N`%1E;7!O<N1R
M(&9I;"`G)7,G(&9I;FYS(&EN=&4N`%1E>'1E;B!D=2!M871A="!I;B!S=.1M
M;65R(&EN=&4@]G9E<F5N<R!M960@=&5X=&5N('#E('-KY')M96X`0F%R82!T
M;W!P(&]C:"!B;W1T96X@<VED80!"87)A('1O<'!S:61A`%5P<&QA9&1A="!D
M871A(&;V<G-V86YN('-E9&%N(&;V<F5GY65N9&4@<W1E9RX`1&5N('5P<&QA
M9&1A9&4@9FEL96X@:W5N9&4@:6YT92!S<&%R87,N`$QE9&EG+W5P<'1A9V5N
M+6EN9F]R;6%T:6]N(&;V<B!A;G;D;F1A<F5N(&AA<B!S<&%R871S+@!796%T
M:&5R+F-O;2UB;&]C:V5T(.1R(&EN=&4@=&EL;&?D;F=L:6=T+@!496UA:V%T
M86QO9R`G)7,G(&9I;FYS(&EN=&4N`$1E="!F:6YN<R!I;F=A(&%D<F5S<V+V
M8VME<B!A='0@=FES82X`26YG82!I;G-TY&QL;FEN9V%R('1I;&QGY&YG;&EG
M82X`1&5T(&9I;FYS(&EN9V$@86QT97)N871I=F$@9&5L87(@<V]M(&MA;B!V
M:7-A<R!I;FQI;F4N`$EN9V5N(&%V(&1E('1I;&QGY&YG;&EG82!A9')E<W-B
M]F-K97)N82#D<B!K;VYF:6=U<F5R861E('/E(&%T="!D=2!FY7(@;.1G9V$@
M=&EL;"!K;VYT86MT97(@:2!D96TL($]M(&1U('1R;W(@871T(&1E="#D<B!E
M='0@9F5L+"!K;VYT86MT82!D:6X@<WES=&5M(&%D;6EN:7-T<F%T]G(N`$;V
M<B!MY6YG82!T96-K96X@:2!FY&QT970N($1U(&AA<B!A;F=E='0@)7,@=&5C
M:V5N.R!M87AI;6%L="!A;G1A;"!T96-K96X@Y'(@)7,N`%!R;V)L96T@;65D
M(&%T="!LY&=G82!T:6QL("<E<R<@=&EL;"!S>7-T96UE=#H@)7,`4')O8FQE
M;2!M960@871T(')E;G-A(&EN9F]R;6%T:6]N(&]M(&%N=N1N9&%R92`G)7,G
M(&9RY6X@<WES=&5M970Z(`!0<F]B;&5M(&UE9"!A='0@=&$@8F]R="`G)7,G
M(&9RY6X@<WES=&5M970Z(`!0<F]B;&5M('9I9"!U<'!D871E<FEN9R!A=B`G
M)7,G.B`E<P!0<F]B;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;BX@26YG
M82`E<R!L861D861E<R!U<'`N`$1E="!U<'!S=&]D('!R;V)L96T@=FED('5P
M<&QA9&1N:6YG(&%V(&9I;&5N.B`E<R#D<B!S=/9R<F4@Y&X@;6%X:6UA;'0@
M=&EL;.5T96X@<W1O<FQE:R`H)60@8GET97,I+@!$970@=7!P<W1O9"!P<F]B
M;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;CH@)7,@;&%D9&%D97,@96YB
M87)T('5P<"!D96QV:7,N`$1E="!U<'!S=&]D('!R;V)L96T@(&[D<B!K;VYT
M86MT96X@<VMU;&QE(&SD9V=A<R!T:6QL+B!+;VYT86MT82!D:6X@<WES=&5M
M861M:6YI<W1R873V<B!F]G(@>71T97)L:6=A<F4@:&KD;'`N`$1E="!U<'!S
M=&]D(&9E;"!V:60@<VMA<&%N9&4@878@;GD@;&ES=&$N`$9E;"!U<'!S=&]D
M(&[D<B!A9')E<W-B;VME;B`G)7,G('-K=6QL92!S:V%P87,N`$1E="!U<'!S
M=&]D(&9E;"!V:60@<F%D97)I;F<@878@)7,@9G+E;B!A9')E<W-B;VME;BX`
M1&5T('5P<'-T;V0@9F5L('9I9"!R861E<FEN9R!A=B!K;VYT86MT96XZ("5S
M`$1E="!U<'!S=&]D(&9E;"!V:60@=FES;FEN9R!A=B!L:7-T86X`1&5T('5P
M<'-T;V0@971T(&9E;"!V:60@=FES;FEN9R!A=B!M961D96QA;F1E9&5L96XN
M`$9E;"!V:60@:6UP;W)T(&%V(&MO;G1A:W1D871A+@!$970@=7!P<W1O9"!F
M96P@=FED(&EM<&]R="!A=B!D871A.B`E<RX`1F5L('9I9"!I;7!O<G0@878@
M:.1N9&5L<V5N.B`E<RX`1F5L('9I9"!I;7!O<G0@878@:4-A;&5N9&%R+61A
M=&$N`$9E;"!V:60@:6UP;W)T(&%V('5P<&=I9G1E;CH@)7,N`$9E;"!V:60@
M:6UP;W)T(&%V(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N.B`E<RX`
M171T(&9E;"!PY71RY&9F861E<R!I(&9O<FUU;.1R970N($MO;G1R;VQL97)A
M(&%T="!D=2!I;G1E(&=L]FUT(&9Y;&QA(&D@971T(&]B;&EG871O<FES:W0@
M9N1L="X`1&5T(&=I8VL@:6YT92!A='0@=71F]G)A(&1E;B!B96?D<F1A(&%D
M<F5S<V)O:W-F=6YK=&EO;F5N+B!687(@9V]D(&;V<G/V:R!S96YA<F4N`$1E
M="!U<'!S=&]D(&9E;"!V:60@<F%D97)I;F<@878@861R97-S8F]K96XZ("5S
M`$9E;"!V:60@=7!P9&%T97)I;F<@878@:V]N=&%K='5P<&=I9G1E<BX@1O9R
M<_9K(&EG96X@<V5N87)E+@!&96P@=FED('5P<&1A=&5R:6YG(&%V(&1I<W1R
M:6)U=&EO;G-L:7-T86XN($;V<G/V:R!I9V5N('-E;F%R92X`1&5T('5P<'-T
M;V0@9F5L('9I9"!U<'!D871E<FEN9R!A=B!A9')E<W-B;VME;CH@)7,N`$1E
M="!U<'!S=&]D(&9E;"!V:60@=7!P9&%T97)I;F<@878@<&]S=&5N.B`E<RX`
M26YG82!A9')E<W-E<B!A='0@97AP;W)T97)A+@!!9')E<W-B]F-K97)N82!V
M:7-A<R!I(&1E;B!HY'(@;W)D;FEN9V5N.@!+;VQU;6YE<FYA('9I<V%S(&D@
M9&5N(&CD<B!O<F1N:6YG96XZ`$1I;B!)34%0+7-E<G9E<B!S=/9D97(@:6YT
M92!D96QA9&4@;6%P<&%R+@!$96YN82!H86YD;&EN9R!S=/9D<R!I;G1E+@!$
M96YN82!F=6YK=&EO;B#D<B!I;G1E(&EM<&QE;65N=&5R860@Y&XN`$9I;&5N
M('9E<FMA<B!I;G1E('9A<F$@971T(&=I;'1I9W0@4D%2+6%R:VEV+@!&:6QE
M;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%I)4"UA<FMI=BX`1F5L
M86MT:6=T(&MO<G1N=6UM97(N`$1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV
M:FQI9W0@871T('-K:6-K82!M961D96QA;F1E;B!V:6$@0VQI8VMA=&5L;"UB
M<GEG9V%N("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=E;F]M(&%T="!A;G;D
M;F1A($A45%`@05!).G0N`$1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI
M9W0@871T('-K:6-K82!M961D96QA;F1E;B!V:6$@5TE.+6)R>6=G86X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT
M`$1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K:6-K82!M
M961D96QA;F1E;B!V:6$@<VUS,F5M86EL+6)R>6=G86X@*&AT='`Z+R]S;7,R
M96UA:6PN8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT`$1E;FYA
M(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K:6-K82!M961D96QA
M;F1E;B!V:6$@4TU44"!G96YO;2!6;V1A9F]N92!)=&%L:65N+6)R>6=G86X@
M*&5N8F%R="!T:6QL(%9O9&%F;VYN=6UM97(I+B!$<FEV<G5T:6YE;B!K<N1V
M97(@971T(&4M<&]S=&MO;G1O(&AO<R!6;V1A9F]N92!)=&%L:65N("AH='1P
M.B\O=W=W+C$Y,"YI="DN`$;D;'1E="!MY7-T92!V87)A(&EF>6QL="X`1N1L
M=&5T(&;E<B!E;F)A<G0@:6YN96CE;&QA(&AE;'1A;"X`1N1L=&5T(&;E<B!E
M;F)A<G0@:6YN96CE;&QA('-I9F9R;W(@;V-H(&MO;&]N+@!&Y&QT970@9N5R
M(&5N8F%R="!I;FYE:.5L;&$@;VMT86QA('1A;"X`1N1L=&5T('-K86QL('9A
M<F$@96X@:V]M;6$M(&5L;&5R(&UE;&QA;G-L86=S<V5P87)A<F%D(&QI<W1A
M(&UE9"!H96QT86P`1N1L=&5T(&WE<W1E('9A<F$@971T(&=O9&OD;G0@=&%L
M+@!$971T82!FY&QT(&WE<W1E(&EN;F5HY6QL82!E;B!21T(M9N1R9VMO9"!I
M(&AE>&%D96-I;6%L="!F;W)M870L('0@97@@)R,Q,C,T868G+@!&:6QF;W)M
M871E="!S=/9D<R!I;G1E+@!$971T82!F;W)M=6SD<B!H87(@<F5D86X@8F5A
M<F)E=&%T<RX`1&5T(&CD<B#D<B`E<RX`365D9&5L86YD970@<VMR979S(&D@
M96X@86YN86X@=&5C:V5N=7!P<^1T=&YI;F<@*"5S*2#D;B!D:6X@96=E;BX`
M1&5T(&CD<B!N=6UR970@;>5S=&4@=F%R82!M:6YS="!E='0N`%!E<G-O;F5N
M(&AA<B!R961A;B!E='0@=N1R9&4@9O9R("5S(&D@861R97-S8F]K96X`4V5R
M=F5R;B!K86X@:6YT92!P86-K82!U<'`@>FEP(&]C:"!G>FEP(&9I;&5R+@!3
M>7-T96UE="#D<B!F]G(@=&EL;&;D;&QE="!A=F%K=&EV97)A="X`1&5T(&CD
M<B!VY')D970@;>5S=&4@=F%R82!N=6UE<FES:W0N`$;V<G9A;&0@861R97-S
M8F]K(&;V<B!N>6$@;V-H(&EM<&]R=&5R861E(&MO;G1A:W1E<BX`1&5T=&$@
M9O9N<W1E<B!MY7-T92!A;G)O<&%S(&9RY6X@971T(&MO;F9I9W5R871I;VYS
M9O9N<W1E<@#%<VMA`,1R96YD96X`5&ED`%1I9'-R961O=FES;FEN9P!4:61S
M9F]R;6%T`%1I9'-V86P`UG-T=&EM;W(`5&ET96P`4G5B<FEK("AT;V]L=&EP
M*3H`5&EL;`!&]G(@871T(&UA<FME<F$@9FQE<F$@=F%L+"!HY6QL(&YE9"!#
M=')L("A00RD@96QL97(@0V]M;6%N9"`H36%C*2!T86YG96YT96X@;N1R(&1U
M(&ML:6-K87(N`$ED86<`5FES82!(5$U,+6OD;&QA`%1O9V\`5&]K96QA=0!)
M;6]R9V]N`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`-9V97)SY'1T;FEN
M9V%R`%1R:6YI9&%D(&]C:"!4;V)A9V\`4V%N="!E;&QE<B!F86QS:W0`5&D`
M5'5N:7-I96X`5'5R:VEE=`!4=7)K:7-K("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,M(&]C:"!#86EC;W/V87)N80!4=79A;'4`06YG92!D:71T
M('9A;#H@`%56+6EN9&5X.B``55),`%523"!F]G(@9&ET="!L979E<F%N<W)A
M<'!O<G1E<FEN9W-S:W)I<'0`55),.@!59V%N9&$`56MR86EN80!+86X@:6YT
M92!LY'-A(%9&4RUM87!P+@!$970@9VEC:R!I;G1E(&%T="!LY&=G82!T:6QL
M('5T]FMA9"!A;G;D;F1A<FEN9F]R;6%T:6]N('9I9"!R96=I<W1E<FEN9RX`
M2V%N(&EN=&4@Y&YD<F$@8F5H]G)I9VAE="!F]G(@5D93+69I;"`E<RX`2V%N
M(&EN=&4@Y&YD<F$@8F5H]G)I9VAE="!F]G(@5D93+69I;"`E<R\E<RX`2V%N
M(&EN=&4@Y&YD<F$@=&EL;"`E<RX`2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL
M<W1O<FQE:R`E<R\E<P!+86X@:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R;&5K
M('#E("5S+@!+86X@:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R;&5K('#E("5S
M+R5S+@!+86X@:6YT92!K;VYT86MT82!344PM<V5R=F5R+@!+86X@:6YT92!K
M;VYT86MT82!V:6$@4U-,+@!+86X@:6YT92!K;W!I97)A(%9&4RUF:6PN`$MA
M;B!I;G1E('-K87!A(%9&4RUM87!P("5S+@!+86X@:6YT92!S:V%P82!61E,M
M;6%P<"X`2V%N(&EN=&4@<VMA<&$@5D93+69I;"X`2V%N(&EN=&4@<VMA<&$@
M5D93+6UA<'`@)R5S)RX`2V%N(&EN=&4@<VMA<&$@=&]M(%9&4RUF:6PN`$MA
M;B!I;G1E('-K87!A(&YY('5T9&5L;FEN9RX@2^1L;'1Y<"!S86MN87,N`$MA
M;B!I;G1E('!A8VMA('5P<"!D871A+@!+86X@:6YT92!R861E<F$@)7,L(&UA
M<'!E;B#D<B!I;G1E('1O;2X`2V%N(&EN=&4@<F%D97)A("<E<R<Z("5S`$MA
M;B!I;G1E(')A9&5R82`E<RP@;6%P<&5N(.1R(&EN=&4@=&]M+@!+86X@:6YT
M92!R861E<F$@5D93+6UA<'`@<F5K=7)S:79T+@!+86X@:6YT92!R861E<F$@
M5D93+6UA<'`N`$MA;B!I;G1E(')A9&5R82!61E,M;6%P<#H@)7,N`$MA;B!I
M;G1E(')A9&5R82!61E,M9FEL("5S+@!+86X@:6YT92!R861E<F$@5D93+69I
M;"X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P("<E<R<N`$MA;B!I;G1E(')A
M9&5R82!61E,@<F5K=7)S:79T.B`E<RX`2V%N(&EN=&4@879G]G)A(&%K='5E
M;&P@;6%P<"X`2V%N(&EN=&4@97AT<F%H97)A($-E<G1I9FEK871S9&5T86QJ
M97(`2V%N(&EN=&4@;&%D9&$@9&5F:6YI=&EO;F5N(&%V("5S+@!+86X@:6YT
M92!F;'ET=&$@5D93+69I;"X`2V%N(&EN=&4@]G!P;F$@5D93+69I;"`E<RX`
M2V%N(&EN=&4@]G!P;F$@5D93+69I;"!F]G(@<VMR:79N:6YG+@!+86X@:6YT
M92#V<'!N82!61E,M9FEL+@!+86X@:6YT92#V<'!N82!K;VUP<FEM97)A="!A
M<FMI=BX`2V%N(&EN=&4@;.1S82!61E,M9FEL("AF:6QE<VEZ92@I(&UI<W-L
M>6-K861E<RDN`$MA;B!I;G1E(&SD<V$@5D93+69I;"`H9V5T1FEL95-I>F4H
M*2!M:7-S;'EC:V%D97,I+@!+86X@:6YT92!LY'-A(&9I;#H@`$MA;B!I;G1E
M(&SD<V$@:V%T86QO9V5N(&;V<B`G=F9S<F]O="<N`$MA;B!I;G1E(&)Y=&$@
M;F%M;B!PY2`E<R!T:6QL("5S.B!D97-T:6YA=&EO;G-M87!P(&9I;FYS(')E
M9&%N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M;6%P<"X`2V%N(&EN=&4@
M8GET82!N86UN('#E(%9&4RUM87!P.B`E<RX`2V%N(&EN=&4@8GET82!N86UN
M('#E(%9&4RUF:6P@)7,N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL
M("5S+R5S+@!+86X@:6YT92!B>71A(&YA;6X@<.4@5D93+69I;"X`2V%N(&EN
M=&4@:_9R82`G;6MI<V]F<R<N`$MA;B!I;G1E(/9V97)SY'1T82!7;W)D9&]K
M=6UE;G1E=`!+86X@:6YT92!S:W)I=F$@=&EL;"!61E,M9FEL("5S+@!+86X@
M:6YT92!S:W)I=F$@=&EL;"!61E,M9FEL("AC;W!Y*"D@;6ES<VQY8VMA9&5S
M*2X`2V%N(&EN=&4@<VMR:79A(&1A=&$@=&EL;"!61E,M9FEL+@!+86X@:6YT
M92!S:W)I=F$@=&EL;"!61E,M9FEL+"!K=F]T82!S:W5L;&4@]G9E<G-K<FED
M87,N`%5N9&5R<W1R=6ME;@#%;F=R82#D;F1R:6YG87(`Q6YG<F%R(&1I;B!S
M96YA<W1E(.5T9^1R9`!/=N1N=&%T('-V87(@9G+E;B!S97)V97(@<.4@9O9R
M8FEN9&5L<V4Z(`!/=N1N=&%T('-V87(@9G+E;B!S97)V97(@=&EL;#H@`$5J
M(&MA=&5G;W)I<V5R860`26-K92!H86YT97)A9"!K;VUP;VYE;G0@878@='EP
M.B`E<P!5;FEC;V1E("A55$8M."D`1O9R96YA9&4@07)A8F5M:7)A=&5N`%-T
M;W)B<FET86YN:65N`$;V<F5N=&$@4W1A=&5R;F$`06UE<FEK86YS:V$@4W1I
M;&QA:&%V<_9A<FYA`$5N:&5T97(`3VOD;F0`3VOD;G0@9W+D;G-S;FET='-M
M961D96QA;F1E:60@*&%P:6US9VED*2X`3VOD;G0@:VQI96YT;65D9&5L86YD
M96ED("AC;&EM<V=I9"DN`$]KY&YD(&]R="!S<&5C:69I8V5R860N`$]KY&YT
M(&%N=N1N9&%R;F%M;B!E;&QE<B!L]G-E;F]R9"X`5&$@8F]R="!LY&YK96X@
M9G+E;B!N=79R86YD92!E;&5M96YT`$YA;6YL]G,`26-K92UP<FEV:6QI9V5R
M861E('-K<FEP="!K86X@:6YT92!K;VUM82#E="!+;&EP<"!U="]+;W!I97)A
M+TML:7-T<F$M9G5N:W1I;VYE<FYA(&%V('/D:V5R:&5T<W-KY&PN($ML:6-K
M82!/2R!F]G(@871T('-E(&5N('1E:VYI<VL@8F5S:W)I=FYI;F<@9G+E;B!M
M;WII;&QA+F]R9R!O;2!H=7(@9'4@:V%N('1I;&SE=&$@871T('-K<FEP="!K
M;VUM97(@Y70@=7)K;&EP<"X`5&$@8F]R="!FY')G`$-O;G1E;G0M5'EP92!S
M=/9D<R!I;G1E.B`E<P!4:6QLY&=G970@<W3V9',@:6YT90!5<'!D871E<F$`
M57!P9&%T97)A("5S`%5P<&1A=&5R82!S=&%T=7,@<.4@<W9A<F%N9&4`57!P
M9&%T97)A(&%N=N1N9&%R90!5<'!D871E<F%D92`G)7,G+@!5<'!D871E<FEN
M9W-S8W)I<'0@<F%D97)A="X`3&%D9&$@=7!P`$QA9&1A9&4@=7!P(&%L;&$@
M:V]N9FEG=7)A=&EO;G-F:6QE<B!T:6QL('-E<G9E<FXN`%9E<G-A;&5R`%)O
M;65R<VMA('-I9F9R;W(`57)U9W5A>0!!;G;D;F0@86MT=65L;#H@)7,`06YV
MY&YD(%-33`!!;G;D;F0@;VT@;F%M;B]L]G-E;F]R9"#D<B!A;FYO<FQU;F1A
M(&;V<B!)35-0+7-E<G9E<BX`06YVY&YD87)E`$%N=N1N9&%R92`E<R#D<B!I
M;G1E(&)E:/9R:6<@9O9R("5S+@!!;G;D;F1A<F%D;6EN:7-T<F%T:6]N`$%N
M=N1N9&%R:6YS=.1L;&YI;F=A<@!!;G;D;F1A<G)E9VES=')E<FEN9P!!;G;D
M;F1A<G)E9VES=')E<FEN9R!H87(@879A:W1I=F5R871S+@!!;G;D;F1A<FMO
M;G1O="!H:71T861E<R!I;G1E`$%N=N1N9&%R;F%M;@!!;G;D;F1A<FYA;6X@
M)7,@9FEN;G,@<F5D86XN`$%N=N1N9&%R;F%M;CH`06YVY&YD87)N86UN.B``
M06YVY&YD87)E(&D@<WES=&5M970Z`%5Z8F5K:7-T86X`5D93+6UA<'`@97AI
M<W1E<F%R(&EN=&4N`%-E;65S=&5R`$=I;'1I9V$@<&QA='-E<B!S;VT@:&ET
M=&%D97,@:6YK;'5D97)A<CH@`$=I;'1I9VAE=`!-:6YU=&5R(&9RY6X@;G4`
M5N1R9&5T(/9V97)S=&EG97(@9&5T(&CV9W-T82!T:6QLY71N82`H)7,I`%;D
M<F1E;@!6Y')D96X@871T(';D;&IA(&9RY6X`5F%N=71A=0!687)I86)E;`!6
M96YE>G5E;&$`5F5R:69I97)I;F<@;6ES<VQY8VMA9&5S("T@;65D9&5L86YD
M970@:V%N(&AA(&UA;FEP=6QE<F%T<RX`5F5R:7-I9VX@:V%T86QO9P!697)S
M:6]N`%9E<G-I;VYH86YT97)I;F<`5F5R=&EK86P@:G5S=&5R:6YG`%9E<G1I
M:V%L('5T9GEL;&YA9`!697)T:6MA;#H`5N1L9&EG="!H]F<`5FEE=&YA;0!6
M:65T;F%M97-I<VL@*%9)4T-)22D`5FES82`G)7,G`%9I<V$@)7,`5FES82!K
M;VYT86MT`%9I<V$@96X@97AT97)N('=E8F)S:61A`%9I<V$@<V]M("5S`%9I
M<V$@:.1N9&5L<V4`5FES82!U<'!G:69T`%9Y('-O;2!S:V%L;"!V:7-A<R!S
M;VT@9&5F875L=#H`2G5N9V9R=?9A<FYA+"!"<FET=&ES:V$`2G5N9V9R=?9A
M<FYA+"!!;65R:6MA;G-K80!3:6MT`%-I:W0Z`%9O9&%F;VYE($ET86QI96X@
M=FEA(%--5%``5D%23@!605).24Y'(2$A(%)!1$5202!32U))4%1%5"!-04Y5
M14Q,5"!&4L5.("5S+@!724X@=FEA($A45%``5V%L;&ES(&]C:"!&=71U;F$`
M5F%R;FEN9P!/;@!6Y&1E<G!R;V=N;W,`5N1D97)D871A(&9RY6X`=V5A=&AE
M<BYC;VT`5V5B8@!796)B<&QA=',`5V5B8G!L871S96X@+2!3;V)E<@!796)B
M<&QA='-E;B`M(%-O8F5R($Y9`%=E8F)A9')E<W,`5F5C:V]V:7,`5N1L:V]M
M;65N`%;D;&MO;6UE;B!T:6QL("5S`%;D;&MO;6UE;BP@)7,`5N1S=&5R;.1N
M9'-K("A)4T\M.#@U.2TQ*0!6Y'-T97)LY&YD<VL@*$E33RTX.#4Y+3$U*0!6
MY'-T<F$@4V%H87)A`%9I;&ME;B!A<'!L:6MA=&EO;B!S:V%L;"`E<R!V:7-A
M(&5F=&5R(&EN;&]G9VYI;F<_`%9I;&ME;B#D<B!A=F=RY&YS;FEN9W-T96-K
M;F5T/P!6:6QK970@Y'(@=&5C:VYE="!F]G(@8VET97)A9"!T97AT/P!7:&5R
M96ES($%U<W1R86QI96YK87)T80!6:6QK82!F87-E<@!6:6QK82!P;'5G:6X@
M<VMA;&P@86MT:79E<F%S(&;V<B!2:6-H(%1E>'0@961I=&]R;BX`0G)E9&0`
M0G)E9&0@:2!#4U,M=6YI=',`0G)E9&0@<.4@;65N>6X@9O9R("<E<R<@=&EL
M;"!VY&YS=&5R("AGY&QL97(@9G+E;B!NY'-T82!I;FQO9V=N:6YG`%1A8F5L
M;&)R961D`$)R961D96YH970`0G)E9&0Z`%=I:VD`5FEN9`!4:61I9R!V:6YD
M`%9I;F1H87-T:6=H970@:2!K;F]P`%9I;F0Z`%9I;F0Z(`!6:7-D;VT`UFYS
M:V5L:7-T80!!<F)E=&4`061R97-S+"!A<F)E=&4`4W1A9"P@87)B971E`$QA
M;F0L(&%R8F5T90!496QE9F]N+"!A<F)E=&4`4&]S=&YR+"!A<F)E=&4`4F5G
M:6]N+"!A<F)E=&4`1V%T=6%D<F5S<RP@87)B971E`$9E;"!A;G1A;"!FY&QT
M('#E(')A9"`E9"X@1O9R=N1N=&%D92`E9"P@:&ET=&%D92`E9"X`1F5L(&%N
M=&%L(&;D;'0N($;V<G;D;G1A9&4@)60L(&AI='1A9&4@)60N`$9E;"!P;W-I
M=&EO;B`E9"!V:60@;.1S;FEN9R!A=B!61E,M9FEL+@!8+5)E9@!8-3`Y5C,@
M573V:V%D(&YY8VME;&%N=N1N9&YI;F<`6#4P.58S+71I;&SD9V<`65D`65E9
M60!986AO;R$@;6%P`,5R;&EG`%EE;65N`$IA`$IA+"!J86<@<V%M='EC:V5R
M`$1U(&AA<B!A:W1I=F5R870@=&5X=&SD9V4N($%N=N1N9"!;/#Y=(&;V<B!A
M='0@Y71E<F?E('1I;&P@5UE325=91RX`1'4@:&%R(&EN=&4@8F5H]G)I9VAE
M="!S:V%P82!F;&5R(.1N("5D(&)L;V-K+@!$=2!H87(@:6YT92!B96CV<FEG
M:&5T('-K87!A(&UE<B#D;B`E9"!K;VYT86MT97(@:2`G)7,G+@!$=2#D<B!I
M;G1E(&%U=&5N=&ES97)A9"X`1'4@:V%N(&EN=&4@86YVY&YD82`G7"<@:2!D
M:71T(&YA;6X`1'4@:V%N(&EN=&4@86YVY&YD82`G7"<@:2!D:71T(&YA;6X`
M1'4@86YG878@:6YT92!E;B!G;V1KY&YD(&4M<&]S=&%D<F5S<RX`1'4@:&%R
M(&EN=&4@8F5H]G)I9R!A='0@=FES82!A:W1U96QL(&MO;G1A:W0N`$1U(&AA
M<B!I;G1E(&)E:/9R:6=H970@871T('9I<V$@;V)J96MT970N`$1U(&AA<B!I
M;G1E(&)E:/9R:6=H970@871T(')A9&5R82!D96YN82!KY&QL82X`1'4@Y'(@
M=71L;V=G860N`$1U(&WE<W1E(&%N9V4@971T(&=I;'1I9W0@;6]B:6QN=6UM
M97([(&5N8F%R="!S:69F<F]R(&]C:"!E='0@)RLG(&;V<F4@:6YT97)N871I
M;VYE;&QT('!R969I>"X`1'4@86YG878@:6YT92!E='0@9V]D:^1N="!VY')D
M92X`1'4@;>5S=&4@:V]N9FEG=7)E<F$@96X@1&%T851RY&1S+6MO<'!L:6YG
M(&;V<B!A='0@86YVY&YD82!R96=I<W1R97)I;F<`1'4@;>5S=&4@:V]N9FEG
M=7)E<F$@96X@5D93+6MO<'!L:6YG`$1U(&WE<W1E(&)E<VMR:79A('!R;V)L
M96UE;BP@:6YN86X@9'4@:V%N(')A<'!O<G1E<F$@971T('!R;V)L96TN`$1U
M(&WE<W1E(&%N9V4@96X@55),('-O;2!LY&YK96X@<&5K87(@<.4`1'4@;>5S
M=&4@=N1L:F$@96X@861R97-S8F]K+@!$=2!MY7-T92!VY&QJ82!E;B!L:7-T
M82X`1'4@;>5S=&4@86YG92!E;B!A9')E<W,@9O9R<W0N`$1U(&WE<W1E(&%N
M9V4@96X@<V5R=F5R('-O;2!S:V%L;"!R861E<F%S+@!6Y&QJ(&UI;G-T(&5N
M(&MO;G1A:W0@9O9R<W0N`%;D;&H@;6EN<W0@96X@<&]S="!F]G)S="X`1'4@
M;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L;"!R96YS87,N
M`$1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@<F%D
M97)A<RX`1'4@;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L
M;"!LY&=G87,@=&EL;"X`1'4@;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN
M('-O;2!S:V%L;"!U<'!D871E<F%S+@!$=2!MY7-T92!A;F=E(&5N(.5T9^1R
M9"!S;VT@<VMA;&P@=71F]G)A<RX`1'4@;>5S=&4@86YG92!E='0@;GET="!K
M871E9V]R:6YA;6XN`$1U(&WE<W1E(&%N9V4@971T(&ET86QI96YS:W0@=&5L
M969O;FYU;6UE<@!$=2!H87(@96YB87)T(&)E:/9R:6=H970@871T('9I<V$@
M86MT=65L;"!K;VYT86MT+@!$:6X@)7,@<V5S<VEO;B!H87(@=7!P:/9R="X@
M5F%R(&=O9"!L;V=G82!I;B!I9V5N+@!$:6X@92UP;W-T861R97-S`$1I;B!&
M<N5N.B!A9')E<W,Z`$1I;B!I;F9O<FUA=&EO;@!$:6X@:6YT97)N971A9')E
M<W,@:&%R(.1N9')A=',@969T97(@871T(&1U(&QO9V=A="!I;B!T:6QL("<E
M<R<N($;V<B!A='0@<VMY9&1A(&1I9RP@;>5S=&4@9'4@;&]G9V$@:6X@:6=E
M;BX`1&ET="!N86UN`$1I;B!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E
M<B!I;G1E('5P<&SD9V<@878@86YVY&YD87)E+B!/;2!D=2!V:6QL(&%N=N1N
M9&$@2&]R9&4@9O9R(&%T="!A9&UI;FES=')E<F$@86YVY&YD87)E('/E(&WE
M<W1E(&1U(&%N=N1N9&$@96X@86YN86X@875T96YT:7-E<FEN9W-K;W!P;&EN
M9RX`1&ET="!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E<B!I;G1E(&QI
M<W1N:6YG(&%V(&%N=N1N9&%R92P@96QL97(@<^4@Y'(@9G5N:W1I;VYE;B!A
M=G-TY&YG9"X`1&EN('=E8F)LY'-A<F4O:6YT97)N971A9')E<W,@:&%R(.1N
M9')A=',@969T97(@871T(&1U(&QO9V=A="!I;B!T:6QL("<E<R<N($;V<B!A
M='0@<VMY9&1A(&1I9RP@;>5S=&4@9'4@;&]G9V$@:6X@:6=E;BX`1&EN('=E
M8F)LY'-A<F4@<W3V9&5R(&EN=&4@9&5N(&CD<B!F=6YK=&EO;F5N+@!$:6X@
M=V5B8FSD<V%R92!S=/9D97(@:6YT92!U='-K<FEF='-F=6YK=&EO;F5N+B!4
M<GEC:R!#=')L+T]P=&EO;B`K(%`@9O9R(&%T="!S:W)I=F$@=70N`$1I;B!A
M:W1U96QL82!T:61S>F]N.@!$:6X@9O9R=F%L9&$@861R97-S8F]K(.1R(&EN
M=&4@;.1S8F%R+@!$:6X@9O9R=F%L9&$@:61E;G1I=&5T(&AA<B#D;F1R871S
M+@!$:6X@9O9R=F%L9&$@:61E;G1I=&5T.@!$:71T(&9U;&QS=.1N9&EG82!N
M86UN.@!$:6X@:6YL;V=G;FEN9R!H87(@9^5T="!U="X`1&ET="!N>6$@;/9S
M96YO<F0@9O9R("5S(.1R.B`E<P!$:6YA(&EN<W3D;&QN:6YG87(@:&%R('5P
M<&1A=&5R871S(&;V<B!D96X@:.1R('-E<W-I;VYE;BX`1&EN82!I;G-TY&QL
M;FEN9V%R(&AA<B!U<'!D871E<F%T<RX`1&ET="!L]G-E;F]R9"!H87(@8FQI
M=FET(.5T97)S=.1L;'0`1&ET="!L]G-N;W)D(&AA<B#E=&5R<W3D;&QT<RP@
M:V]N=')O;&QE<F$@9&EN(&4M<&]S="!O8V@@;&]G9V$@:6X@;65D(&1I='0@
M;GEA(&SV<V5N;W)D+@!$:71T(&SV<V5N;W)D(&AA<B!GY71T('5T+@!$:6YA
M(&9JY')R<V5R=G)A<CH`2G5G;W-L879I96X`6F%I<F4`6F%M8FEA`%II;6)A
M8G=E`%II<'!Y`%M']FT@8VET97)A9"!T97AT70!;1F5L<F%P<&]R=%T`6U9I
M<V$@8VET97)A9"!T97AT("T`6U9I<V$@8VET97)A9"!T97AT("T@)7,@<F%D
M97)=`%MR860@)7,@878@)7-=`%M);F=E="!VY')D95T`7T%D;6EN:7-T<F%T
M:6]N`%],:7-T80!?0TQ)`%]+;VYT86MT97(`7T1A=&%4<N1D`%]2861E<F$`
M7U)A9&5R82!R860`7T=R=7!P97(`7TAJY&QP`%]":6QD:6YS=.1L;&YI;F=A
M<BXN+@!?26UP;W)T+T5X<&]R=`!?3&ES=&]R`%],;V=G82!I;@!?3&]G9V$@
M=70`Q%]N9')A(&SD;FLN+BX`061R97-S8O9C:V5R`%].>2!K;VYT86MT`%])
M;G-TY&QL;FEN9V%R`%]"96CV<FEG:&5T97(`7U1A(&)O<G0@;.1N:RXN+@!?
M4F%D97)A(&9RY6X@;&ES=&%N+@!?4_9K`%]3971U<`!?5&%B96QL:6YS=.1L
M;&YI;F=A<BXN+@!?06YVY&YD87)E`&%D<F5S<V)O:P!O:^1N9"!M;W1T86=A
M<F4`:V%L96YD97(`;'5G;G0`:V%N(&EN=&4@<VMA<&$@=71F:6P`:V%N(&EN
M=&4@]G!P;F$@:6YD871A`&ML:6-K82!HY'(`:VQO8VMA`&MO;6UA;F1O<F%D
M<V9E;`!K;VYF:6=U<F%T:6]N<V9E;`!K;VYT86MT+G9C9@!K;VYT86MT97(N
M8W-V`&MO;G1A:W1E<BYT<W8`:V]N=&%K=&5R+G9C9@!K<FET:7-K('-Y<W1E
M;69I;"!S86MN87,`9&%T869O<FUA=&9E;`#D;F1R80!P;W-T96X@:W5N9&4@
M:6YT92!H:71T87,`9F%L;&%N9&4`9FEL`&9RY6X`9G+E;B!D96X@)7,@*"5S
M*2!K;"`E<R`E<P!S=&]R;6)Y87(`:#H`:&@`;VOD;F0@=N1R9&1A=&]R`&=E
M;F%S=`!I;FQI;F4`8F5A<F)E=&YI;F=S9F5L`$EN=&5R;G0@87!P;&EK871I
M;VYS9F5L`')A9&5R70!F96QK;V0@)60@9G+E;B!M:VES;V9S`&UM`&YA;6X`
M:6YG96X@9F]R;6%T97)I;F<`:6YG96X`:6YT92!I;7!L96UE;G1E<F%D`&EN
M=&4@:6UP;&5M96YT97)A9`!A;G1E8VMN:6YG<V)L;V-K`'!R;V-E;G0`Y71K
M;VUS="!N96MA9`!P:7AL87(`<')O=&]K;VQL9F5L`'-T:6=A;F1E`%1JY&YS
M=&5N(.1R(&5J('1I;&QGY&YG;&EG`'9I<V$@<VMI;&QN861E<@!S;7,R96UA
M:6P@=FEA($A45%``<W,`<W1A9&EG=`!S>7-T96UF96P`=7!P9VEF='-L:7-T
M80!T:6QL9N1L;&EG="!F96P`=&EL;"!K;VYT86MT;&ES=&$`=&EL;"!A;FYA
M;B!A9')E<W-B;VL`86YG92!L]G-E;F]R9&5T('1VY2!GY6YG97(@9O9R(&%T
M="!B96MRY&9T80!E;F%D`&YA;6YL]G,`86YVY&YD87)V86P`=D-A<F0`=SH`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+W1R
M7U12+P``````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<U-@`P,C`P,S4`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T=7)B82]L;V-A;&4O=')?5%(O3$-?34534T%'15,O````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4V`#`R,38R,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]T<E]44B],0U]-15-3
M04=%4R]T=7)B82YM;P``````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S-C4S-S,`,3`T,3<S
M-C(W-38`,#(S,S$R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````0`<``!P````<.@``K0D``!QT````````T)H`
M``X```#1F@``#P```.":```-````\)H```@```#^F@``"P````>;```,````
M$YL```0````@FP``)````"6;```E````2IL```P```!PFP``#P```'V;```+
M````C9L```X```"9FP``!0```*B;```H````KIL```@```#7FP``"@```.";
M```5````ZYL```D````!G```$@````N<```+````'IP``!T````JG```#@``
M`$B<```*````5YP```T```!BG```#@```'"<```-````?YP```P```"-G```
M#0```)J<```&````J)P```\```"OG```&````+^<```,````V)P```X```#E
MG```#@```/2<```(`````YT``"L````,G0``+@```#B=```:````9YT``#(`
M``""G0``.````+6=``!4````[IT``%$```!#G@``6@```)6>``!7````\)X`
M`#0```!(GP``!P```'V?```*````A9\```\```"0GP``!0```*"?```&````
MII\``!$```"MGP``"````+^?```1````R)\```D```#:GP``"0```.2?```E
M````[I\``"`````4H```$````#6@```/````1J````H```!6H````P```&&@
M```/````9:```!0```!UH```"0```(J@```-````E*```!(```"BH```#P``
M`+6@```*````Q:````\```#0H```"````."@```D````Z:````8````.H0``
M%````!6A```6````*J$```@```!!H0``&0```$JA```'````9*$``!0```!L
MH0``$@```(&A```A````E*$``"P```"VH0``#@```..A```#````\J$```\`
M``#VH0``"P````:B```'````$J(```<````:H@``!0```"*B```%````**(`
M``H````NH@```P```#FB```7````/:(```H```!5H@``#P```&"B```.````
M<*(``!@```!_H@``(P```)BB```.````O*(```X```#+H@``%````-JB```7
M````[Z(``!<````'HP``%P```!^C```3````-Z,```\```!+HP``#@```%NC
M```?````:J,```<```"*HP``!@```)*C```(````F:,```\```"BHP``!@``
M`+*C```*````N:,``!,```#$HP``"P```-BC```0````Y*,``!4```#UHP``
M%0````ND```'````(:0``!`````II```!0```#JD```5````0*0``!$```!6
MI```#````&BD```H````=:0``#H```">I```.P```-FD```)````%:4```<`
M```?I0``%````">E```#````/*4```4```!`I0``"0```$:E```0````4*4`
M``D```!AI0``$P```&NE```Y````?Z4``!(```"YI0``)P```,RE```L````
M]*4``"H````AI@``)0```$RF```*````<J8```8```!]I@``"0```(2F```'
M````CJ8``"\```"6I@``-P```,:F```N````_J8``%4````MIP``+0```(.G
M```M````L:<``"T```#?IP``0`````VH```C````3J@``",```!RJ```+0``
M`):H```S````Q*@``!4```#XJ```&0````ZI```I````**D``"0```!2J0``
M$0```'>I```*````B:D```P```"4J0``"@```*&I```0````K*D``!8```"]
MJ0``%@```-2I```'````ZZD```<```#SJ0``%````/NI```*````$*H```@`
M```;J@``"````"2J```,````+:H```<````ZJ@``!P```$*J```&````2JH`
M`!$```!1J@``!0```&.J```'````::H```8```!QJ@``%````'BJ```(````
MC:H``"D```"6J@``#@```,"J```*````SZH```0```#:J@``!P```-^J```)
M````YZH```8```#QJ@``$0```/BJ```'````"JL``!8````2JP``!````"FK
M```(````+JL```8````WJP``#0```#ZK```&````3*L``!X```!3JP``$0``
M`'*K```(````A*L```T```"-JP``#````)NK```'````J*L``!$```"PJP``
M`P```,*K```#````QJL``!<```#*JP```P```.*K```3````YJL```@```#Z
MJP``!`````.L```(````"*P```@````1K```00```!JL```@````7*P```8`
M``!]K```!@```(2L```5````BZP``!@```"AK```(@```+JL```N````W:P`
M`!T````,K0``(0```"JM``!4````3*T``"D```"AK0``"@```,NM```'````
MUJT``!4```#>K0``#@```/2M```*`````ZX```\````.K@``#0```!ZN```/
M````+*X```T````\K@``"0```$JN```4````5*X```8```!IK@``&````'"N
M```=````B:X``!,```"GK@``%````+NN```$````T*X```8```#5K@``5```
M`-RN```$````,:\```X````VKP``#P```$6O```%````5:\```4```!;KP``
M&P```&&O```:````?:\``!$```"8KP``$0```*JO```6````O*\``!P```#3
MKP``*@```/"O```0````&[```"$````LL```!0```$ZP```3````5+```!(`
M``!HL```"@```'NP```/````AK```!$```"6L```$P```*BP```,````O+``
M``8```#)L```!@```-"P```7````U[```!````#OL```$0````"Q```(````
M$K$```4````;L0``#````"&Q```0````+K$```4````_L0``#@```$6Q```-
M````5+$```8```!BL0``%@```&FQ```J````@+$```<```"KL0``#0```+.Q
M```'````P;$```L```#)L0``!P```-6Q```'````W;$```\```#EL0``"0``
M`/6Q```*````_[$``!D````*L@``#````"2R```0````,;(```4```!"L@``
M)0```$BR```2````;K(``!,```"!L@``%0```)6R```2````J[(``"L```"^
ML@``.P```.JR```@````)K,``!H```!'LP``%````&*S```V````=[,```@`
M``"NLP``#````+>S```&````Q+,```0```#+LP``#@```-"S```*````W[,`
M``T```#JLP``'@```/BS```;````%[0``"$````SM```'@```%6T```9````
M=+0``!X```".M```&P```*VT```F````R;0``!L```#PM```'@````RU```<
M````*[4``"8```!(M0``,P```&^U```F````H[4``"L```#*M0``.````/:U
M```O````+[8``!(```!?M@``*0```'*V```2````G+8``*(```"OM@``%@``
M`%*W```C````:;<``"@```"-MP``*0```+:W```H````X+<``!\````)N```
M(````"FX```E````2K@``"@```!PN```,````)FX``"2````RK@``"$```!=
MN0``'````'^Y```F````G+D``$$```##N0``#`````6Z```'````$KH```<`
M```:N@``#0```"*Z```0````,+H``!(```!!N@``!P```%2Z```3````7+H`
M`!(```!PN@``!P```(.Z```$````B[H```P```"0N@``#@```)VZ```/````
MK+H``!,```"\N@``#0```-"Z```H````WKH```,````'NP``#0````N[```&
M````&;L``!$````@NP``%P```#*[```;````2KL```X```!FNP```@```'6[
M```%````>+L``!````!^NP``!````(^[```-````E+L```X```"BNP```P``
M`+&[```.````M;L```@```#$NP``#P```,V[```/````W;L```<```#MNP``
M#0```/6[```0`````[P``!H````4O```"P```"^\```&````.[P``!,```!"
MO```#````%:\```1````8[P``!D```!UO```%P```(^\```+````I[P```T`
M``"SO```(@```,&\```6````Y+P```H```#[O```&`````:]```9````'[T`
M`!8````YO0``#P```%"]```-````8+T```<```!NO0``"@```':]```*````
M@;T``!0```",O0``(@```*&]```O````Q+T```L```#TO0``"0````"^```9
M````"KX```L````DO@``%P```#"^```7````2+X```D```!@O@``%@```&J^
M```/````@;X``!8```"1O@``#@```*B^```8````M[X```@```#0O@``#0``
M`-F^```F````Y[X``"@````.OP``0P```#>_```(````>[\``!(```"$OP``
M"P```)>_```O````H[\```X```#3OP``#@```.*_```%````\;\```8```#W
MOP```P```/Z_```'`````L````0````*P```"@````_````*````&L````\`
M```EP```$````#7````7````1L```!$```!>P```$0```'#````7````@L``
M``D```":P```!0```*3````+````JL````H```"VP````@```,'````%````
MQ,````T```#*P```&P```-C````7````],````D````,P0``#@```!;!```-
M````)<$``!(````SP0``.````$;!```@````?\$```@```"@P0``#@```*G!
M``![````N,$``!@````TP@``%0```$W"```1````8\(```<```!UP@``!0``
M`'W"```9````@\(```<```"=P@``"````*7"```&````KL(```8```"UP@``
M$````+S"```/````S<(``!````#=P@``#P```.["```+````_L(```\````*
MPP``#````!K#```/````)\,```<````WPP``!@```#_#```.````1L,```P`
M``!5PP``*````&+#```/````B\,```@```";PP``!@```*3#```3````J\,`
M`"(```"_PP``+0```.+#```(````$,0``!,````9Q```'@```"W$```E````
M3,0``!H```!RQ```%0```(W$```>````H\0``$,```#"Q```(0````;%```@
M````*,4``!D```!)Q0``%P```&/%```E````>\4``"4```"AQ0``%P```,?%
M```B````W\4```0````"Q@``&P````?&```-````(\8```P````QQ@```P``
M`#[&```(````0L8```H```!+Q@``#````%;&```+````8\8``!````!OQ@``
M#````(#&```$````C<8``!,```"2Q@``%````*;&```,````N\8```D```#(
MQ@``#@```-+&```+````X<8``!L```#MQ@``!P````G'```$````$<<```<`
M```6QP``"@```!['```*````*<<```T````TQP``"0```$+'```$````3,<`
M``4```!1QP```P```%?'```8````6\<```H```!TQP``!````'_'```F````
MA,<```X```"KQP``?````+K'```5````-\@```4```!-R```!P```%/(```,
M````6\@```@```!HR```"@```''(```&````?,@```@```"#R````@```(S(
M```&````C\@```8```"6R```%````)W(```,````LL@```T```"_R```$```
M`,W(```;````WL@```0```#ZR```"0```/_(```0````"<D```D````:R0``
M"0```"3)```%````+LD``!H````TR0``"````$_)```&````6,D``!D```!?
MR0``#@```'G)```'````B,D```<```"0R0``!0```)C)```)````GLD```H`
M``"HR0``$P```+/)```"````Q\D```8```#*R0``#0```-')```)````W\D`
M``8```#IR0``$@```/#)```)`````\H```<````-R@``!0```!7*```4````
M&\H``!T````PR@``!@```$[*```*````5<H```0```!@R@``"0```&7*```(
M````;\H``!$```!XR@``"0```(K*```&````E,H```T```";R@``!@```*G*
M```$````L,H``#D```"UR@``/0```._*```Z````+<L``!X```!HRP``!0``
M`(?+```.````C<L```0```"<RP``!@```*'+```A````J,L``!4```#*RP``
M!@```.#+```$````Y\L``!$```#LRP``!@```/[+```*````!<P``"(````0
MS```!````#/,```%````.,P``!T````^S```!````%S,```,````8<P```D`
M``!NS```#````'C,```*````A<P``!````"0S```$P```*',```3````M<P`
M``@```#)S```"0```-+,```%````W,P``#H```#BS```,````!W-```U````
M3LT``"D```"$S0``1P```*[-```X````]LT``"D````OS@``/P```%G.```N
M````F<X``"T```#(S@``'P```/;.```/````%L\``!(````FSP``"P```#G/
M```F````1<\``"D```!LSP``)````);/```F````N\\```@```#BSP``"@``
M`.O/```)````]L\```<`````T```(`````C0```@````*=```"8```!*T```
M!````''0```*````=M```!D```"!T```*0```)O0```6````Q=```!(```#<
MT```!P```._0```*````]]````P````"T0``#P````_1```0````']$``$``
M```PT0``<````''1``!F````XM$```X```!)T@``"0```%C2```*````8M(`
M`!(```!MT@``$P```(#2```,````E-(```8```"AT@``'````*C2```/````
MQ=(``!L```#5T@``$@```/'2```0````!-,``!$````5TP``'````"?3```C
M````1-,``&H```!HTP``#P```-/3```%````X],``!````#ITP``"0```/K3
M```$````!-0```L````)U```%````!74```,````*M0```P````WU```#P``
M`$34```5````5-0``"D```!JU```*@```)34```F````O]0``"<```#FU```
M*0````[5```J````.-4``!D```!CU0``0@```'W5```1````P-4``!(```#2
MU0``$P```.75```4````^=4```\````.U@``%@```![6```7````-=8``!``
M``!-U@``$0```%[6```T````<-8``!,```"EU@``$@```+G6```U````S-8`
M`!0````"UP``!P```!?7```,````']<```H````LUP``(````#?7```4````
M6-<``!0```!MUP``$0```(+7```7````E-<``!P```"LUP``#0```,G7```-
M````U]<``!,```#EUP``%@```/G7```1````$-@```P````BV```$````"_8
M```:````0-@``!X```!;V```&@```'K8```1````E=@``!0```"GV```%P``
M`+S8```5````U-@```D```#JV```&0```/38```$````#MD```<````3V0``
M"P```!O9```1````)]D```8````YV0``!@```$#9```&````1]D```4```!.
MV0``!P```%39```'````7-D```4```!DV0``%@```&K9```&````@=D```8`
M``"(V0``!````(_9```$````E-D```<```"9V0``#@```*'9```,````L-D`
M``P```"]V0``#0```,K9```*````V-D```X```#CV0``!0```/+9```H````
M^-D```X````AV@``#````##:```/````/=H```H```!-V@``"````%C:```)
M````8=H``"L```!KV@``!````)?:```(````G-H``"8```"EV@``$@```,S:
M```/````W]H```8```#OV@``"@```/;:``!,`````=L```<```!.VP``"```
M`%;;```@````7]L```D```"`VP``#0```(K;```)````F-L```P```"BVP``
M#0```*_;```.````O=L``!8```#,VP``$0```./;```&````]=L```,```#\
MVP``!@````#<```9````!]P```<````AW```!````"G<```+````+MP```L`
M```ZW```!P```$;<```'````3MP``!8```!6W```#0```&W<```-````>]P`
M``H```")W```$````)3<```/````I=P``!$```"UW```%P```,?<```*````
MW]P``!$```#JW```"````/S<```$````!=T```\````*W0``.@```!K=```%
M````5=T```P```!;W0``!````&C=```>````;=T```X```",W0``$````)O=
M```+````K-T```P```"XW0``"0```,7=```'````S]T```H```#7W0``"0``
M`.+=```.````[-T``!````#[W0``&@````S>```*````)]X```D````RW@``
M"@```#S>```,````1]X```\```!4W@``"````&3>```&````;=X```<```!T
MW@``"P```'S>``!'````B-X```T```#0W@``"0```-[>```$````Z-X```,`
M``#MW@``$P```/'>```3````!=\``!,````9WP``"@```"W?```"````.-\`
M``0````[WP``)0```$#?```#````9M\```4```!JWP``*@```'#?```*````
MF]\```4```"FWP``!````*S?```*````L=\```T```"\WP``!@```,K?```(
M````T=\```@```#:WP``!````./?```%````Z-\``&@```#NWP``"0```%?@
M```,````8>````4```!NX```!@```'3@```;````>^```"\```"7X```$```
M`,?@```*````V.````@```#CX```#P```.S@```*````_.````D````'X0``
M$P```!'A```;````)>$``!@```!!X0``%P```%KA```.````<N$``!<```"!
MX0```P```)GA```'````G>$```@```"EX0``!P```*[A```*````MN$```L`
M``#!X0``!P```,WA``!1````U>$``!`````GX@``#````#CB```-````1>(`
M`!H```!3X@``2@```&[B```&````N>(```8```#`X@``!@```,?B```?````
MSN(```8```#NX@``"0```/7B```8````_^(``!<````8XP``"P```##C```&
M````/.,```T```!#XP``*````%'C```B````>N,``%<```"=XP``$P```/7C
M```C````">0``!,````MY````@```$'D```+````1.0```P```!0Y```"```
M`%WD```-````9N0```H```!TY```%@```'_D```'````EN0``!0```">Y```
M!@```+/D```(````NN0```X```##Y```!P```-+D```*````VN0```L```#E
MY```%P```/'D```'````">4```P````1Y0``#0```![E```,````+.4```0`
M```YY0``"0```#[E```)````2.4```H```!2Y0``!P```%WE```)````9>4`
M``D```!OY0``"@```'GE```'````A.4```H```",Y0``%0```)?E```;````
MK>4``$D```#)Y0``$@```!/F```*````)N8```D````QY@``$````#OF```'
M````3.8``!(```!4Y@``!````&?F```+````;.8```<```!XY@``!0```(#F
M```%````AN8``!H```",Y@``"P```*?F```4````L^8``!$```#(Y@``&@``
M`-KF```6````]>8``!0````,YP``%P```"'G```8````.><``!P```!2YP``
M&0```&_G```'````B><```4```"1YP``#0```)?G```,````I><```L```"R
MYP``"````+[G```7````Q^<```L```#?YP``$P```.OG```$````_^<```H`
M```$Z```!`````_H```,````%.@```D````AZ```"````"OH```%````-.@`
M``<````ZZ```!0```$+H```$````2.@```(```!-Z```&````%#H```7````
M:>@``#@```"!Z```+````+KH```2````Y^@``"D```#ZZ```,@```"3I```*
M````5^D``"P```!BZ0``+@```(_I```S````OND``#,```#RZ0``.````";J
M```1````7^H```\```!QZ@``&````('J```0````FNH```\```"KZ@``$P``
M`+OJ```4````S^H``!(```#DZ@``%````/?J```5````#.L``"T````BZP``
M+0```%#K```Q````?NL``"X```"PZP``+P```-_K```L````#^P``&(````\
M[```$P```)_L```(````L^P```@```"\[```*P```,7L```A````\>P``!@`
M```3[0``&@```"SM```)````1^T``$4```!1[0``00```)?M```$````V>T`
M`!,```#>[0``%````/+M```.````!^X``!,````6[@``&````"KN```&````
M0^X```D```!*[@``"@```%3N```/````7^X``!````!O[@``!P```(#N```.
M````B.X```4```"7[@``&P```)WN```(````N>X```8```#"[@``%````,GN
M```1````WNX``!@```#P[@``#@````GO```X````&.\```(```!1[P``!@``
M`%3O```.````6^\``!````!J[P``!0```'OO```'````@>\```X```")[P``
M!@```)CO```$````G^\``"D```"D[P``%P```,[O```?````YN\``%P````&
M\```%````&/P```^````>/```!\```"W\```$````-?P```'````Z/````X`
M``#P\```#````/_P```,````#/$``!,````9\0``"@```"WQ```=````./$`
M`!D```!6\0``!0```'#Q```1````=O$```T```"(\0``$0```);Q```D````
MJ/$``!4```#-\0``$@```./Q```.````]O$``!D````%\@``"````!_R```)
M````*/(```T````R\@``"@```$#R```'````2_(```\```!3\@``"P```&/R
M```*````;_(```<```!Z\@``"````(+R```%````B_(``!\```"1\@``!@``
M`+'R```0````N/(```@```#)\@``#0```-+R```(````X/(``!(```#I\@``
M+````/SR```:````*?,```D```!$\P``"@```$[S```5````6?,```4```!O
M\P``%````'7S```$````BO,``!````"/\P``!@```*#S```'````I_,``!X`
M``"O\P``*````,[S```*````]_,``!$````"]```$0```!3T```:````)O0`
M`!0```!!]```!````%;T```$````6_0```L```!@]```!0```&ST```&````
M<O0``!$```!Y]```"````(OT```&````E/0```H```";]```&P```*;T```T
M````PO0``#0```#W]```(````"SU```I````3?4``"````!W]0``00```)CU
M```:````VO4``"@```#U]0``*0```![V```B````2/8```8```!K]@``"```
M`'+V```%````>_8```@```"!]@``&0```(KV```9````I/8``"H```"^]@``
M(P```.GV```N````#?<``#0````\]P``"````''W```7````>O<```H```"2
M]P``!P```)WW```A````I?<``!````#']P``#@```-CW```4````Y_<```L`
M``#\]P``!P````CX```3````$/@```@````D^```"P```"WX```*````.?@`
M`!0```!$^```,@```%GX```+````C/@```4```"8^```!0```)[X```5````
MI/@```P```"Z^```%P```,?X```/````W_@```0```#O^```"@```/3X```)
M````__@```L````)^0``#0```!7Y```,````(_D```X````P^0``!0```#_Y
M```$````1?D``!0```!*^0``#0```%_Y```R````;?D``$4```"@^0``$@``
M`.;Y```7````^?D``!X````1^@``%````##Z```%````1?H``!0```!+^@``
M!P```&#Z```.````:/H``"H```!W^@``!@```*+Z```,````J?H```T```"V
M^@``$0```,3Z```5````UOH```L```#L^@``-@```/CZ```*````+_L``"(`
M```Z^P``"P```%W[```/````:?L``#(```!Y^P``&P```*S[```.````R/L`
M``4```#7^P``#@```-W[```3````[/L``!$`````_```!P```!+\```1````
M&OP```<````L_```%````#3\```8````2?P```<```!B_```!0```&K\```,
M````</P```P```!]_```$@```(K\```$````G?P```<```"B_```"@```*K\
M```+````M?P```P```#!_```#@```,[\```.````W?P```4```#L_```!0``
M`/+\```N````^/P``"8````G_0``(P```$[]```#````<OT``!(```!V_0``
M!@```(G]```>````D/T``!@```"O_0``&0```,C]```E````XOT```T````(
M_@``"0```!;^```#````(/X``!@````D_@``!P```#W^```*````1?X```(`
M``!0_@``#````%/^```5````8/X```L```!V_@``&0```(+^```@````G/X`
M`!(```"]_@``!0```-#^```*````UOX``!4```#A_@``$@```/?^```,````
M"O\```0````7_P``!P```!S_```,````)/\``%(````Q_P``%P```(3_```'
M````G/\```8```"D_P``#@```*O_```-````NO\``!$```#(_P``#````-K_
M```,````Y_\```T```#T_P``%0````(``0`2````&``!``\````K``$`%```
M`#L``0`;````4``!`!````!L``$`)P```'T``0`E````I0`!`&D```#+``$`
M&@```#4!`0`7````4`$!`!D```!H`0$`&@```((!`0`E````G0$!`"@```##
M`0$`)P```.P!`0`:````%`(!`!<````O`@$`&P```$<"`0`T````8P(!`"4`
M``"8`@$`&0```+X"`0`?````V`(!`!,```#X`@$`"`````P#`0`'````%0,!
M``@````=`P$`"0```"8#`0`5````,`,!``T```!&`P$`$P```%0#`0`#````
M:`,!`$8```!L`P$`/P```+,#`0`W````\P,!`%<````K!`$`!0```(,$`0`?
M````B00!`"\```"I!`$`"@```-D$`0`0````Y`0!``@```#U!`$`#0```/X$
M`0`M````#`4!``0````Z!0$`"````#\%`0`-````2`4!``H```!6!0$`3P``
M`&$%`0`E````L04!`!P```#7!0$`"P```/0%`0`?``````8!`!T````@!@$`
M)0```#X&`0`@````9`8!`"0```"%!@$`(````*H&`0`+````RP8!``<```#7
M!@$`#0```-\&`0`,````[08!`!<```#Z!@$`!@```!('`0`Y````&0<!``P`
M``!3!P$`!P```&`'`0`)````:`<!`!,```!R!P$`"0```(8'`0`$````D`<!
M`!````"5!P$`"````*8'`0`(````KP<!``0```"X!P$`"P```+T'`0`,````
MR0<!`!(```#6!P$`$0```.D'`0`,````^P<!`!H````("`$`#P```",(`0`'
M````,P@!``T````["`$`#@```$D(`0`4````6`@!``X```!M"`$`!P```'P(
M`0`,````A`@!`!L```"1"`$`+````*T(`0`3````V@@!`!P```#N"`$`*```
M``L)`0`&````-`D!``<````["0$`$P```$,)`0`%````5PD!``0```!="0$`
M%P```&()`0`Y````>@D!``H```"T"0$`#````+\)`0`)````S`D!``8```#6
M"0$`"0```-T)`0`(````YPD!``D```#P"0$`"@```/H)`0`1````!0H!``8`
M```7"@$`#@```!X*`0`.````+0H!``T````\"@$`"P```$H*`0`=````5@H!
M``L```!T"@$``@```(`*`0`'````@PH!``8```"+"@$`"0```)(*`0`'````
MG`H!`!L```"D"@$`.P```,`*`0`H````_`H!`#0````E"P$`%0```%H+`0`%
M````<`L!``<```!V"P$`"````'X+`0`'````APL!``4```"/"P$`!P```)4+
M`0`.````G0L!``D```"L"P$`!@```+8+`0`(````O0L!``L```#&"P$`!P``
M`-(+`0`(````V@L!``<```#C"P$`%@```.L+`0`)`````@P!``8````,#`$`
M"P```!,,`0`<````'PP!`!0````\#`$`!P```%$,`0`(````60P!``,```!B
M#`$`"````&8,`0`4````;PP!``4```"$#`$`$````(H,`0`0````FPP!``8`
M``"L#`$`&0```+,,`0`*````S0P!`!P```#8#`$`!P```/4,`0`%````_0P!
M`!`````##0$`%````!0-`0`+````*0T!``T````U#0$`%P```$,-`0`$````
M6PT!``D```!@#0$`"@```&H-`0`'````=0T!``(```!]#0$`#@```(`-`0`(
M````CPT!`!\```"8#0$`(P```+@-`0`X````W`T!`#$````5#@$`)P```$<.
M`0`H````;PX!`&0```"8#@$`%````/T.`0!5````$@\!`#@```!H#P$`*0``
M`*$/`0!*````RP\!`%L````6$`$`*````'(0`0`X````FQ`!`"@```#4$`$`
M+````/T0`0`G````*A$!`!L```!2$0$`/@```&X1`0"I`0``K1$!`",```!7
M$P$`%P```'L3`0!(````DQ,!`(4```#<$P$`,````&(4`0!!````DQ0!`%L`
M``#5%`$`20```#$5`0`=````>Q4!`!@```"9%0$`(0```+(5`0`?````U!4!
M`"L```#T%0$`(0```"`6`0`G````0A8!`!T```!J%@$`$0```(@6`0`S````
MFA8!`"4```#.%@$`)P```/06`0`F````'!<!`!\```!#%P$`,````&,7`0#,
M````E!<!`&D```!A&`$`/0```,L8`0!E````"1D!`$T```!O&0$`7@```+T9
M`0`G````'!H!`"P```!$&@$`*````'$:`0`O````FAH!`"X```#*&@$`*0``
M`/D:`0`P````(QL!`%0```!4&P$`6@```*D;`0!(````!!P!`$H```!-'`$`
M*@```)@<`0`B````PQP!`#(```#F'`$`+P```!D=`0`L````21T!`"T```!V
M'0$`<0```*0=`0!O````%AX!`+,```"&'@$`%P```#H?`0`E````4A\!`#(`
M``!X'P$`*0```*L?`0`^````U1\!`"(````4(`$`4@```#<@`0`B````BB`!
M`"4```"M(`$`"P```-,@`0"Q````WR`!`$4```"1(0$`(0```-<A`0`V````
M^2$!`#`````P(@$`)0```&$B`0`<````AR(!`#$```"D(@$`!P```-8B`0`'
M````WB(!``0```#F(@$`#0```.LB`0`+````^2(!``X````%(P$`"P```!0C
M`0`%````(",!`!`````F(P$``@```#<C`0!9````.B,!``4```"4(P$`$@``
M`)HC`0`$````K2,!``<```"R(P$`"````+HC`0`%````PR,!``,```#)(P$`
M$````,TC`0`,````WB,!`!,```#K(P$`#0```/\C`0`"````#20!``<````0
M)`$`!@```!@D`0`4````'R0!``P````T)`$`&````$$D`0`&````6B0!`!(`
M``!A)`$`#````'0D`0`#````@20!`"H```"%)`$`!````+`D`0`&````M20!
M``<```"\)`$`'P```,0D`0`U````Y"0!`"X````:)0$`+P```$DE`0`7````
M>24!`"````"1)0$`&P```+(E`0`8````SB4!`"0```#G)0$`'P````PF`0`:
M````+"8!`"````!')@$`&@```&@F`0`R````@R8!`"\```"V)@$`*P```.8F
M`0`?````$B<!`",````R)P$`'P```%8G`0`:````=B<!`"4```"1)P$`)@``
M`+<G`0`E````WB<!`"0````$*`$`&````"DH`0`=````0B@!`"0```!@*`$`
M&````(4H`0`B````GB@!`"4```#!*`$`/````.<H`0`?````)"D!`",```!$
M*0$`'P```&@I`0`@````B"D!`!H```"I*0$`&````,0I`0`F````W2D!`!X`
M```$*@$`*0```",J`0`>````32H!``D```!L*@$`#````'8J`0`7````@RH!
M`"\```";*@$`)````,LJ`0`'````\"H!``\```#X*@$`%`````@K`0`.````
M'2L!``T````L*P$`)````#HK`0`%````7RL!``<```!E*P$`(@```&TK`0`E
M````D"L!`!T```"V*P$`&@```-0K`0`'````[RL!`,<```#W*P$`"P```+\L
M`0`5````RRP!``8```#A+`$`"0```.@L`0`+````\BP!`!<```#^+`$`!@``
M`!8M`0`S````'2T!`!,```!1+0$`$P```&4M`0`'````>2T!``\```"!+0$`
M!P```)$M`0`R````F2T!`"$```#,+0$`$P```.XM`0`,`````BX!`!$````/
M+@$`,@```"$N`0`(````5"X!``D```!=+@$`"@```&<N`0`4````<BX!``H`
M``"'+@$`'0```)(N`0`(````L"X!`!\```"Y+@$`"````-DN`0`:````XBX!
M``8```#]+@$`%0````0O`0`'````&B\!``@````B+P$`"0```"LO`0`_````
M-2\!`!(```!U+P$`!P```(@O`0`/````D"\!``X```"@+P$`$````*\O`0`)
M````P"\!``D```#*+P$`"````-0O`0`3````W2\!``<```#Q+P$`#````/DO
M`0`9````!C`!``H````@,`$`&P```"LP`0`7````1S`!`!0```!?,`$`"@``
M`'0P`0`,````?S`!`!<```",,`$`!````*0P`0`J````J3`!`!$```#4,`$`
M!P```.8P`0`"````[C`!`!````#Q,`$`&`````(Q`0`+````&S$!``,````G
M,0$`"````"LQ`0`+````-#$!``8```!`,0$`!P```$<Q`0`-````3S$!``L`
M``!=,0$`%````&DQ`0`5````?C$!``X```"4,0$`+P```*,Q`0`@````TS$!
M`!P```#T,0$`#````!$R`0`Q````'C(!``4```!0,@$`$@```%8R`0`_````
M:3(!`!(```"I,@$`"@```+PR`0`&````QS(!``0```#.,@$`!````-,R`0`*
M````V#(!`!,```#C,@$`!0```/<R`0`&````_3(!``8````$,P$`!`````LS
M`0`,````$#,!``D````=,P$`#````"<S`0`*````-#,!`!`````_,P$`$P``
M`%`S`0`3````9#,!``4```!X,P$`&````'XS`0`9````ES,!`!\```"Q,P$`
M'0```-$S`0`1````[S,!``(````!-`$`!`````0T`0`*````"30!``8````4
M-`$`!0```!LT`0`#````(30!``P````E-`$`10```#(T`0`:````>#0!`#4`
M``"3-`$`*````,DT`0!3````\C0!`#````!&-0$`+P```'<U`0`9````IS4!
M`'(```#!-0$`(````#0V`0`U````538!`"$```"+-@$`10```*TV`0`P````
M\S8!`"8````D-P$`'@```$LW`0`H````:C<!`"D```"3-P$`*0```+TW`0`F
M````YS<!`"4````..`$`*````#0X`0`H````73@!`"(```"&.`$`+@```*DX
M`0`P````V#@!`!(````).0$`$P```!PY`0`0````,#D!`'D```!!.0$`"0``
M`+LY`0!S````Q3D!`'P````Y.@$`*P```+8Z`0`7````XCH!`!8```#Z.@$`
M#P```!$[`0`?````(3L!`$````!!.P$`'P```(([`0`<````HCL!`%$```"_
M.P$`%````!$\`0`*````)CP!``4````Q/`$`!@```#<\`0`(````/CP!``4`
M``!'/`$`$@```$T\`0`0````8#P!`!,```!Q/`$`'0```(4\`0`/````HSP!
M``H```"S/`$`#P```+X\`0`'````SCP!``0```#6/`$`"0```-L\`0`'````
MY3P!``L```#M/`$`!P```/D\`0`%`````3T!`!0````'/0$`#@```!P]`0`'
M````*ST!``@````S/0$`#P```#P]`0`(````3#T!``P```!5/0$`#P```&(]
M`0`6````<CT!``<```")/0$`!@```)$]`0`4````F#T!``8```"M/0$`#```
M`+0]`0`(````P3T!``0```#*/0$`"@```,\]`0`+````VCT!``P```#F/0$`
M#````/,]`0`'`````#X!``0````(/@$`&0````T^`0`"````)SX!``D````J
M/@$`!@```#0^`0`&````.SX!`"<```!"/@$`!````&H^`0`/````;SX!`!,`
M``!_/@$`!P```),^`0`'````FSX!``8```"C/@$`!@```*H^`0`0````L3X!
M`!(```#"/@$`!@```-4^`0`)````W#X!`"(```#F/@$`!P````D_`0`'````
M$3\!``L````9/P$`!0```"4_`0`"````*S\!``L````N/P$`:P$``#H_`0`.
M````ID`!`!0```"U0`$`"P```,I``0`(````UD`!``@```#?0`$`!@```.A`
M`0`(````[T`!`!L```#X0`$`'0```!1!`0`+````,D$!`!8````^00$`#0``
M`%5!`0`-````8T$!``4```!Q00$`'0```'=!`0`*````E4$!``@```"@00$`
M%````*E!`0`*````OD$!``T```#)00$`"P```-=!`0`F````XT$!`!$````*
M0@$`"0```!Q"`0`.````)D(!`!0````U0@$`"0```$I"`0`.````5$(!`!``
M``!C0@$`!@```'1"`0`1````>T(!`!(```"-0@$`"0```*!"`0`7````JD(!
M`!<```#"0@$`!P```-I"`0`N````XD(!`#,````10P$`%P```$5#`0`]````
M74,!`$T```";0P$`9````.E#`0!<````3D0!`&L```"K1`$`8P```!=%`0`_
M````>T4!``D```"[10$`"0```,5%`0`,````ST4!``4```#<10$`!@```.)%
M`0`4````Z44!``P```#^10$`$@````M&`0`%````'D8!``8````D1@$`*```
M`"M&`0`J````5$8!``X```!_1@$`$0```(Y&`0`,````H$8!``0```"M1@$`
M#0```+)&`0`-````P$8!``P```#.1@$`#@```-M&`0`.````ZD8!`!0```#Y
M1@$`"@````Y'`0`-````&4<!``H````G1P$`+````#)'`0`$````7T<!`!4`
M``!D1P$`%````'I'`0`.````CT<!`",```">1P$`!0```,)'`0`7````R$<!
M`!,```#@1P$`(P```/1'`0`R````&$@!``<```!+2`$``P```%-(`0`.````
M5T@!``H```!F2`$`"@```'%(`0`'````?$@!``@```"$2`$`!@```(U(`0`*
M````E$@!``0```"?2`$`'````*1(`0`+````P4@!``L```#-2`$`#````-E(
M`0`8````YD@!`#0```#_2`$`"0```#1)`0`)````/DD!`!$```!(20$`$P``
M`%I)`0`8````;DD!`!T```"'20$`#P```*5)`0`,````M4D!``X```#"20$`
M&@```-%)`0`&````[$D!``8```#S20$`"````/I)`0`,`````TH!``4````0
M2@$`"0```!9*`0`2````($H!``@````S2@$`$````#Q*`0`.````34H!`!<`
M``!<2@$`!@```'1*`0`.````>TH!``4```"*2@$`%0```)!*`0`5````IDH!
M``P```"\2@$`)@```,E*`0`U````\$H!`#H````F2P$`"````&%+`0`*````
M:DL!`!0```!U2P$`!0```(I+`0`%````D$L!``4```"62P$`$0```)Q+`0`,
M````KDL!`!0```"[2P$`+P```-!+`0`/`````$P!`"4````03`$`)````#9,
M`0`I````6TP!`"T```"%3`$`#````+-,`0`'````P$P!``L```#(3`$`"0``
M`-1,`0`O````WDP!`"P````.30$`+0```#M-`0!?````:4T!`"P```#)30$`
M+````/9-`0`L````(TX!`"X```!03@$`)````'].`0`H````I$X!`"P```#-
M3@$`,@```/I.`0`9````+4\!`!P```!'3P$`,P```&1/`0`H````F$\!`!,`
M``#!3P$`"@```-5/`0`1````X$\!``<```#R3P$`#0```/I/`0`7````"%`!
M`!P````@4`$`"0```#U0`0`'````1U`!`!0```!/4`$`"0```&10`0`(````
M;E`!``T```!W4`$`"P```(50`0`+````D5`!``<```"=4`$`!@```*50`0`1
M````K%`!``4```"^4`$`!P```,10`0`&````S%`!`!L```#34`$`"@```.]0
M`0`Q````^E`!``T````L40$`"0```#I1`0`$````1%$!``<```!)40$`"@``
M`%%1`0`%````7%$!`!````!B40$`"````'-1`0`,````?%$!``D```")40$`
M"````)-1`0`#````G%$!``X```"@40$`"````*]1`0`>````N%$!``8```#7
M40$`"P```-Y1`0`0````ZE$!``P```#[40$`!P````A2`0`)````$%(!``,`
M```:4@$``P```!Y2`0`5````(E(!``,````X4@$`%0```#Q2`0`&````4E(!
M``8```!94@$`"````&!2`0`'````:5(!`$P```!Q4@$`'P```+Y2`0`&````
MWE(!``4```#E4@$`%P```.M2`0`8`````U,!`!@````<4P$`,0```#53`0`:
M````9U,!`!\```""4P$`=P```*)3`0`L````&E0!``H```!'5`$`!@```%)4
M`0`8````650!``X```!R5`$`#````(%4`0`1````CE0!`!,```"@5`$`$0``
M`+14`0`1````QE0!``P```#85`$`%````.54`0`$````^E0!`!<```#_5`$`
M&````!=5`0`8````,%4!`!8```!)50$``P```&!5`0`(````9%4!`&L```!M
M50$`"````-E5`0`6````XE4!`!L```#Y50$`!````!56`0`#````&E8!`!\`
M```>5@$`%P```#Y6`0`,````5E8!`!,```!C5@$`%P```'=6`0`G````CU8!
M`#,```"W5@$`$0```.M6`0`:````_58!``<````85P$`'P```"!7`0`7````
M0%<!`!$```!85P$`&````&I7`0`9````@U<!`!<```"=5P$`#P```+57`0`(
M````Q5<!``<```#.5P$`#0```-97`0`5````Y%<!`!0```#Z5P$`"0````]8
M`0`$````&5@!``L````>6`$`"P```"I8`0`)````-E@!`!$```!`6`$`$```
M`%)8`0`%````8U@!`!P```!I6`$`,````(98`0`%````MU@!``P```"]6`$`
M"````,I8`0`)````TU@!``<```#=6`$`!0```.58`0`,````ZU@!``T```#X
M6`$`"`````99`0`5````#UD!``T````E60$`$````#-9`0`%````1%D!`!P`
M``!*60$`&````&=9`0`8````@%D!`!8```"960$`$@```+!9`0`L````PUD!
M`#L```#P60$`)0```"Q:`0`B````4EH!`"````!U6@$`-P```)9:`0`%````
MSEH!``P```#46@$`!0```.%:`0`'````YUH!``X```#O6@$`"@```/Y:`0`-
M````"5L!`!P````76P$`&P```#1;`0`?````4%L!`!X```!P6P$`'P```(];
M`0`>````KUL!`!@```#.6P$`(````.=;`0`A````"%P!`"0````J7`$`'P``
M`$]<`0`>````;UP!`"\```".7`$`(P```+Y<`0`E````XEP!`#$````(70$`
M+@```#I=`0`-````:5T!`"4```!W70$`#0```)U=`0"9````JUT!`!````!%
M7@$`'P```%9>`0`A````=EX!`",```"87@$`)````+Q>`0`A````X5X!`!X`
M```#7P$`)0```")?`0`H````2%\!`"P```!Q7P$`HP```)Y?`0`8````0F`!
M`",```!;8`$`(@```']@`0!+````HF`!``X```#N8`$`!````/U@`0`'````
M`F$!``X````*80$`"@```!EA`0`/````)&$!``L````T80$`$0```$!A`0`3
M````4F$!``L```!F80$`!````')A`0`/````=V$!``T```"'80$`%0```)5A
M`0`2````JV$!`!(```"^80$`,````-%A`0`#`````F(!`!,````&8@$`!@``
M`!IB`0`.````(6(!`!0````P8@$`%@```$5B`0`/````7&(!``(```!L8@$`
M!@```&]B`0`5````=F(!``4```",8@$`#````))B`0`,````GV(!``,```"L
M8@$`"P```+!B`0`&````O&(!``\```##8@$`#P```--B`0`*````XV(!``\`
M``#N8@$`$0```/YB`0`8````$&,!``@````I8P$``P```#)C`0`+````-F,!
M``@```!"8P$`"````$MC`0`8````5&,!`!<```!M8P$`"0```(5C`0`)````
MCV,!`!D```"98P$`&````+-C`0`*````S&,!`!0```#78P$`%````.QC`0`4
M`````60!``\````69`$`#0```"9D`0`)````-&0!``4````^9`$`!@```$1D
M`0`1````2V0!`#P```!=9`$`,@```)ID`0`'````S60!``L```#59`$`&@``
M`.%D`0`-````_&0!`!$````*90$`$0```!QE`0`%````+F4!`"`````T90$`
M$P```%5E`0`>````:64!`!(```"(90$`#P```)ME`0`&````JV4!``@```"R
M90$`+0```+ME`0`L````Z64!`#X````69@$`!P```%5F`0`3````768!``@`
M``!Q9@$`,P```'IF`0`+````KF8!`!(```"Z9@$`!P```,UF`0`'````U68!
M``,```#=9@$`!P```.%F`0`'````Z68!``P```#Q9@$`#````/YF`0`,````
M"V<!`!`````89P$`&````"EG`0`3````0F<!`!0```!69P$`&````&MG`0`&
M````A&<!``4```"+9P$`"P```)%G`0`&````G6<!``(```"D9P$`!P```*=G
M`0`7````KV<!`"4```#'9P$`%P```.UG`0`0````!6@!``H````6:`$`"@``
M`"%H`0`3````+&@!`$X```!`:`$`*@```(]H`0`*````NF@!`!8```#%:`$`
M<@```-QH`0`=````3VD!`!4```!M:0$`#@```(-I`0`&````DFD!``0```"9
M:0$`(````)YI`0`'````OVD!``@```#':0$`!0```-!I`0`&````UFD!``T`
M``#=:0$`#````.MI`0`-````^&D!``P````&:@$`"P```!-J`0`.````'VH!
M``H````N:@$`#P```#EJ`0`(````26H!``@```!2:@$`%P```%MJ`0`.````
M<VH!`"\```"":@$`%0```+)J`0`#````R&H!``P```#,:@$`'````-EJ`0`Q
M````]FH!`"@````H:P$`#0```%%K`0`:````7VL!`"````!Z:P$`)````)MK
M`0`>````P&L!`!L```#?:P$`&P```/MK`0!(````%VP!`",```!@;`$`(@``
M`(1L`0`D````IVP!`"(```#,;`$`)````.]L`0`>````%&T!`!\````S;0$`
M&0```%-M`0`*````;6T!`!H```!X;0$`#0```)-M`0`-````H6T!``0```"O
M;0$`!0```+1M`0`,````NFT!``X```#';0$`#0```-9M`0`2````Y&T!``P`
M``#W;0$`!`````1N`0`6````"6X!`!8````@;@$`$````#=N`0`)````2&X!
M``P```!2;@$`#0```%]N`0`=````;6X!``D```"+;@$``P```)5N`0`*````
MF6X!``@```"D;@$``@```*UN`0`*````L&X!``T```"[;@$`!0```,EN`0`%
M````SVX!``,```#5;@$`#0```-EN`0`*````YVX!``4```#R;@$`*@```/AN
M`0`,````(V\!`'L````P;P$`%P```*QO`0`'````Q&\!``4```#,;P$`"@``
M`-)O`0`(````W6\!``H```#F;P$`"````/%O`0`.````^F\!``(````)<`$`
M"@````QP`0`&````%W`!`!0````><`$`#P```#-P`0`0````0W`!`!,```!4
M<`$`%0```&AP`0`&````?G`!``8```"%<`$`#0```(QP`0`'````FG`!``<`
M``"B<`$`!0```*IP`0`=````L'`!``<```#.<`$`!P```-9P`0`;````WG`!
M``\```#Z<`$`"0````IQ`0`'````%'$!``0````<<0$`"P```"%Q`0`*````
M+7$!`!,````X<0$``P```$QQ`0`&````4'$!``P```!7<0$`"P```&1Q`0`*
M````<'$!`!0```![<0$`"````)!Q`0`'````F7$!``0```"A<0$`#0```*9Q
M`0`<````M'$!``<```#1<0$`"````-EQ`0`$````XG$!``D```#G<0$`"```
M`/%Q`0`.````^G$!``T````)<@$`!````!=R`0`,````''(!``8````I<@$`
M!````#!R`0`R````-7(!`#,```!H<@$`,P```)QR`0`@````T'(!``4```#Q
M<@$`$````/=R`0`)````"',!``8````2<P$`'P```!ES`0`7````.7,!``D`
M``!1<P$`!@```%MS`0`;````8G,!``@```!^<P$`"````(=S`0`5````D',!
M``8```"F<P$`"0```*US`0`'````MW,!``@```"_<P$`"0```,AS`0`%````
MTG,!``0```#8<P$`"P```-US`0`*````Z7,!``4```#T<P$`"0```/IS`0`(
M````!'0!``D````-=`$`!0```!=T`0!(````'70!`#<```!F=`$`.P```)YT
M`0`G````VG0!`$D````"=0$`.P```$QU`0`C````B'4!`#<```"L=0$`(P``
M`.1U`0`:````"'8!`!@````C=@$`"P```#QV`0`0````2'8!``8```!9=@$`
M*P```&!V`0`J````C'8!`!4```"W=@$`*@```,UV`0`#````^'8!``4```#\
M=@$`"@````)W`0`*````#7<!`"0````8=P$`(````#UW`0`K````7G<!``0`
M``"*=P$`"0```(]W`0`8````F7<!`"\```"R=P$`%````.)W`0`7````]W<!
M``<````/>`$`#P```!=X`0`0````)W@!`!L````X>`$`#0```%1X`0!%````
M8G@!`&H```"H>`$`@0```!-Y`0`0````E7D!``L```"F>0$`#````+)Y`0`0
M````OWD!`!$```#0>0$`$````.)Y`0`*````\WD!`"0```#^>0$`%````"-Z
M`0`E````.'H!`!@```!>>@$`&````'=Z`0`3````D'H!`!H```"D>@$`)```
M`+]Z`0!H````Y'H!`!````!->P$`"0```%Y[`0`5````:'L!``D```!^>P$`
M!0```(A[`0`%````CGL!`!,```"4>P$`$0```*A[`0`1````NGL!`!@```#,
M>P$`$@```.5[`0`N````^'L!`"\````G?`$`,````%=\`0`O````B'P!`#,`
M``"X?`$`,@```.Q\`0`6````'WT!`$,````V?0$`&P```'I]`0`:````EGT!
M`!H```"Q?0$`&0```,Q]`0`)````YGT!`!T```#P?0$`'`````Y^`0`:````
M*WX!`!D```!&?@$`&@```&!^`0`<````>WX!`!L```"8?@$`+@```+1^`0`.
M````XWX!``<```#R?@$`#P```/I^`0`/````"G\!`"T````:?P$`%@```$A_
M`0`2````7W\!`!<```!R?P$`&0```(I_`0`6````I'\!`!````"[?P$`#@``
M`,Q_`0`5````VW\!`!P```#Q?P$`$0````Z``0`+````((`!`!8````L@`$`
M'0```$.``0`D````88`!`!(```"&@`$`&P```)F``0`9````M8`!`!<```#/
M@`$`&````.>``0`$`````($!`!8````%@0$`!````!R!`0`'````(8$!``\`
M```I@0$`(````#F!`0`&````6H$!``<```!A@0$`!@```&F!`0`&````<($!
M``<```!W@0$`!````'^!`0`'````A($!`!4```",@0$`!@```**!`0`%````
MJ8$!``8```"O@0$`!P```+:!`0`%````OH$!``P```#$@0$`#0```-&!`0`*
M````WX$!``H```#J@0$`"@```/6!`0`8`````((!``4````9@@$`)0```!^"
M`0`2````18(!``T```!8@@$`$0```&:"`0`0````>((!``P```")@@$`$0``
M`):"`0`K````J((!``@```#4@@$`"````-V"`0`*````YH(!``H```#Q@@$`
M#P```/R"`0`&````#(,!``L````3@P$`3P```!^#`0`-````;X,!``,```!]
M@P$`'P```(&#`0`*````H8,!``X```"L@P$`!0```+N#`0`)````P8,!``\`
M``#+@P$`#0```-N#`0`:````Z8,!``\````$A`$`!P```!2$`0`$````'(0!
M``4````AA`$`'0```">$`0`&````180!``,```!,A`$`$@```%"$`0`0````
M8X0!``<```!TA`$`!P```'R$`0`%````A(0!``T```"*A`$`"0```)B$`0`,
M````HH0!`!P```"OA`$`&@```,R$`0`5````YX0!`!H```#]A`$`"0```!B%
M`0`2````(H4!``P````UA0$`"````$*%`0`1````2X4!`$$```!=A0$`"P``
M`)^%`0`,````JX4!``4```"XA0$`)````+Z%`0`8````XX4!`!D```#\A0$`
M$P```!:&`0`-````*H8!``X````XA@$`"@```$>&`0`-````4H8!`!H```!@
MA@$`%0```'N&`0`=````D88!`"8```"OA@$`"````-:&`0`(````WX8!``T`
M``#HA@$`#````/:&`0`,`````X<!``,````0AP$`!0```!2'`0`%````&H<!
M``\````@AP$`0P```#"'`0`5````=(<!``H```"*AP$``P```)6'`0`%````
MF8<!`!0```"?AP$`%````+2'`0`4````R8<!``H```#>AP$``@```.F'`0`$
M````[(<!`"````#QAP$``P```!*(`0`%````%H@!``D````<B`$`"@```":(
M`0`$````,8@!``4````VB`$`$````#R(`0`2````38@!``8```!@B`$`!P``
M`&>(`0`)````;X@!``0```!YB`$`!0```'Z(`0!C````A(@!``X```#HB`$`
M$0```/>(`0`$````"8D!``T````.B0$`(0```!R)`0`_````/HD!`!````!^
MB0$`"````(^)`0`'````F(D!``\```"@B0$`"0```+")`0`(````NHD!`!T`
M``##B0$`)@```.&)`0`D````"(H!`",````MB@$`$0```%&*`0`2````8XH!
M``4```!VB@$`!P```'R*`0`#````A(H!``8```"(B@$`"@```(^*`0`3````
MFHH!``4```"NB@$`2````+2*`0`5````_8H!``H````3BP$`"P```!Z+`0`G
M````*HL!`$P```!2BP$`!@```)^+`0`&````IHL!``<```"MBP$`"@```+6+
M`0`$````P(L!``D```#%BP$`(P```,^+`0`B````\XL!``L````6C`$`!0``
M`"*,`0`(````*(P!`"<````QC`$`)@```%F,`0!@````@(P!`!(```#AC`$`
M)P```/2,`0`8````'(T!``,````UC0$`#````#F-`0`-````1HT!``4```!4
MC0$`#@```%J-`0`,````:8T!`!T```!VC0$`"@```)2-`0`(````GXT!``8`
M``"HC0$`"@```*^-`0`)````NHT!``4```#$C0$`"@```,J-`0`+````U8T!
M`!H```#AC0$``P```/R-`0`/`````(X!`!(````0C@$`$@```"..`0`$````
M-HX!``H````[C@$`"0```$:.`0`)````4(X!``L```!:C@$`"@```&:.`0`)
M````<8X!``D```![C@$`"P```(6.`0`(````D8X!`!8```":C@$`(0```+&.
M`0!%````TXX!``L````9CP$`!P```"6/`0`(````+8\!``X````VCP$`!P``
M`$6/`0`/````38\!``(```!=CP$`"0```&"/`0`'````:H\!``4```!RCP$`
M!0```'B/`0`4````?H\!``@```"3CP$`$@```)R/`0`2````KX\!`!4```#"
MCP$`%0```-B/`0`4````[H\!`!(````#D`$`%P```!:0`0`@````+I`!`!H`
M``!/D`$``@```&J0`0`$````;9`!``X```!RD`$`#0```(&0`0`5````CY`!
M``<```"ED`$`'````*V0`0`-````RI`!`!,```#8D`$`"````.R0`0`.````
M]9`!``4````$D0$`$@````J1`0`)````'9$!``@````GD0$`!P```#"1`0`'
M````.)$!``0```!`D0$`!````$61`0`%````2I$!`!@```!0D0$`'0```&F1
M`0!#````AY$!`#H```#+D0$`$@````:2`0`K````&9(!`#@```!%D@$`#@``
M`'Z2`0`I````C9(!`#$```"WD@$`-@```.F2`0`V````(),!`#L```!7DP$`
M'P```).3`0`*````LY,!`"<```"^DP$`&````.:3`0`8````_Y,!`!@````8
ME`$`&````#&4`0`0````2I0!`!0```!;E`$`&````'"4`0`G````B90!`"<`
M``"QE`$`*P```-F4`0`H````!94!`"D````NE0$`)@```%B5`0!@````?Y4!
M`!P```#@E0$`"0```/V5`0`'````!Y8!`"8````/E@$`*@```#:6`0`<````
M898!`"````!^E@$`"0```)^6`0!#````J98!`$8```#ME@$`!P```#27`0`9
M````/)<!`!P```!6EP$`#0```'.7`0`/````@9<!`!4```"1EP$`!@```*>7
M`0`0````KI<!``\```"_EP$`"P```,^7`0`3````VY<!``T```#OEP$`#P``
M`/V7`0`&````#9@!`"0````4F`$`!0```#F8`0`$````/Y@!``\```!$F`$`
M#````%28`0`7````89@!``P```!YF`$`0````(:8`0`$````QY@!``4```#,
MF`$`$````-*8`0`0````XY@!``\```#TF`$`!`````29`0`4````"9D!``0`
M```>F0$`!0```".9`0`]````*9D!`!D```!GF0$`.````(&9`0!=````NID!
M`!$````8F@$`10```"J:`0`?````<)H!``\```"0F@$`"@```*":`0`2````
MJYH!`!````"^F@$`!P```,^:`0`.````UYH!``D```#FF@$`%@```/":`0`<
M````!YL!``4````DFP$`#@```"J;`0`0````.9L!``X```!*FP$`'0```%F;
M`0`0````=YL!`!0```"(FP$`$0```)V;`0`C````KYL!``@```#3FP$`"@``
M`-R;`0`/````YYL!``X```#WFP$`!@````:<`0`2````#9P!`!@````@G`$`
M"P```#F<`0`*````19P!``@```!0G`$`!0```%F<`0`>````7YP!``8```!^
MG`$`#P```(6<`0`(````E9P!``X```">G`$`!@```*V<`0`-````M)P!`"T`
M``#"G`$`#0```/"<`0`'````_IP!``<````&G0$`'@````Z=`0`(````+9T!
M`!`````VG0$``P```$>=`0`3````2YT!``@```!?G0$`!0```&B=`0`>````
M;IT!`"T```"-G0$`!````+N=`0`1````P)T!`!$```#2G0$`#0```.2=`0`0
M````\IT!``0````#G@$`#P````B>`0`*````&)X!``<````CG@$`"P```"N>
M`0`2````-YX!``@```!*G@$`#````%.>`0`-````8)X!`!X```!NG@$`,0``
M`(V>`0`V````OYX!`!\```#VG@$`)````!:?`0`C````.Y\!`#\```!?GP$`
M'P```)^?`0`A````OY\!`"@```#AGP$`(0````J@`0`'````+*`!``@````T
MH`$`"0```#V@`0`(````1Z`!`!D```!0H`$`&0```&J@`0`S````A*`!`"H`
M``"XH`$`+0```..@`0`R````$:$!``8```!$H0$`&P```$NA`0`'````9Z$!
M``@```!OH0$`'P```'BA`0`1````F*$!``X```"JH0$`$@```+FA`0`,````
MS*$!``4```#9H0$`$0```-^A`0`(````\:$!`!(```#ZH0$`#`````VB`0`8
M````&J(!`#$````SH@$`"@```&6B`0`%````<*(!``4```!VH@$`&````'RB
M`0`+````E:(!`!H```"AH@$`#````+RB`0`&````R:(!`!8```#0H@$`%```
M`.>B`0`-````_*(!``T````*HP$`%0```!BC`0`.````+J,!``0````]HP$`
M!0```$*C`0`8````2*,!``T```!AHP$`2````&^C`0!C````N*,!`!8````<
MI`$`$P```#.D`0`?````1Z0!`!D```!GI`$`#0```(&D`0`/````CZ0!``L`
M``"?I`$`$@```*ND`0`L````OJ0!``,```#KI`$`"0```.^D`0`*````^:0!
M``\````$I0$`#P```!2E`0`+````)*4!`#(````PI0$``P```&.E`0`:````
M9Z4!``T```""I0$`$P```)"E`0`G````I*4!`!P```#,I0$`#````.FE`0`'
M````]J4!`!````#^I0$`%0````^F`0`7````):8!``@````]I@$`$0```$:F
M`0`'````6*8!`!H```!@I@$`)@```'NF`0`*````HJ8!``,```"MI@$`$@``
M`+&F`0`.````Q*8!`!4```#3I@$`!0```.FF`0`'````[Z8!`!$```#WI@$`
M"P````FG`0`+````%:<!`!$````AIP$`$0```#.G`0`)````1:<!``@```!/
MIP$`-````%BG`0`N````C:<!`"X```"\IP$`"````.NG`0`1````]*<!``8`
M```&J`$`%P````VH`0`<````):@!`!<```!"J`$`'@```%JH`0`.````>:@!
M``H```"(J`$``P```).H`0`;````EZ@!``@```"SJ`$`"P```+RH`0`#````
MR*@!``P```#,J`$`%````-FH`0`+````[J@!`!@```#ZJ`$`&P```!.I`0`7
M````+ZD!``4```!'J0$`"@```$VI`0`4````6*D!``X```!MJ0$`#P```'RI
M`0`&````C*D!``D```"3J0$`$@```)VI`0!.````L*D!`!T```#_J0$`!0``
M`!VJ`0`#````(ZH!``\````GJ@$`#P```#>J`0`3````1ZH!``D```!;J@$`
M#0```&6J`0`/````<ZH!`!L```"#J@$`$0```)^J`0`0````L:H!`"````#"
MJ@$`'P```..J`0`/`````ZL!`#0````3JP$`,P```$BK`0!N````?*L!`!P`
M``#KJP$`%0````BL`0`>````'JP!`"`````]K`$`'P```%ZL`0`G````?JP!
M`"8```"FK`$`&P```,VL`0`4````Z:P!`!@```#^K`$`.P```!>M`0`G````
M4ZT!`!8```![K0$`'````)*M`0`3````KZT!``H```##K0$`!P```,ZM`0`+
M````UJT!``4```#BK0$`%P```.BM`0`-`````*X!`!\````.K@$`!@```"ZN
M`0!*````-:X!`#$```"`K@$`1````+*N`0!C````]ZX!``<```!;KP$`-```
M`&.O`0`H````F*\!``8```#!KP$`$````,BO`0`*````V:\!``D```#DKP$`
M,@```.ZO`0`&````(;`!``T````HL`$`&P```#:P`0`0````4K`!`%L```!C
ML`$`*P```+^P`0`E````Z[`!``\````1L0$`,````"&Q`0`?````4K$!`"<`
M``!RL0$`(0```)JQ`0`G````O+$!`",```#DL0$`$`````BR`0`'````&;(!
M`!<````AL@$`%0```#FR`0`/````3[(!``8```!?L@$`+P```&:R`0`,````
MEK(!``8```"CL@$`!````*JR`0`0````K[(!``@```#`L@$`!0```,FR`0`+
M````S[(!``@```#;L@$`"````.2R`0`#````[;(!``P```#QL@$`#P```/ZR
M`0`?````#K,!`!T````NLP$`#P```$RS`0`6````7+,!``\```!SLP$`!@``
M`(.S`0`2````BK,!``T```"=LP$`%@```*NS`0`-````PK,!``D```#0LP$`
M#````-JS`0`9````Y[,!`"<````!M`$`#P```"FT`0`B````.;0!`"L```!<
MM`$`$0```(BT`0`.````FK0!`!P```"IM`$`!P```,:T`0`0````SK0!`!0`
M``#?M`$`/@```/2T`0`+````,[4!``H````_M0$`"@```$JU`0`'````5;4!
M``D```!=M0$`"````&>U`0`)````<+4!``X```!ZM0$`#@```(FU`0`%````
MF+4!``\```">M0$`#````*ZU`0`,````N[4!``T```#(M0$`&@```-:U`0`+
M````\;4!``,```#]M0$`!`````&V`0`&````!K8!``@````-M@$`!@```!:V
M`0`9````';8!`%0````WM@$`*````(RV`0`S````M;8!`!4```#IM@$`!0``
M`/^V`0`$````!;<!``H````*MP$`"@```!6W`0`'````(+<!``H````HMP$`
M%0```#.W`0`,````2;<!``H```!6MP$`#````&&W`0`(````;K<!``8```!W
MMP$`!P```'ZW`0`&````AK<!`!4```"-MP$`"0```*.W`0`%````K;<!``<`
M``"SMP$`(@```+NW`0`&````WK<!`!4```#EMP$`&````/NW`0`#````%+@!
M``L````8N`$`&0```"2X`0`'````/K@!`!,```!&N`$`$P```%JX`0`&````
M;K@!`!,```!UN`$`"@```(FX`0`(````E+@!``8```"=N`$`"````*2X`0`0
M````K;@!`!@```"^N`$`"````->X`0`*````X+@!``\```#KN`$`!0```/NX
M`0`,`````;D!`!`````.N0$`"P```!^Y`0`#````*[D!``T````ON0$`!P``
M`#VY`0`L````1;D!`"H```!RN0$`.0```)VY`0`D````U[D!`"T```#\N0$`
M'P```"JZ`0!?````2KH!`!````"JN@$`5P```+NZ`0`U````$[L!`",```!)
MNP$`6@```&V[`0!3````R+L!`!X````<O`$`0@```#N\`0`@````?KP!`",`
M``"?O`$`(0```,.\`0`5````Y;P!`#\```#[O`$`T@$``#N]`0`4````#K\!
M`!`````COP$`00```#2_`0!Y````=K\!`#$```#POP$`/````"+``0!3````
M7\`!`$\```"SP`$`&@````/!`0`0````'L$!`!8````OP0$`&0```$;!`0`C
M````8,$!`"$```"$P0$`(@```*;!`0`:````R<$!`!````#DP0$`,P```/7!
M`0`=````*<(!`"$```!'P@$`)0```&G"`0`<````C\(!`"X```"LP@$`V0``
M`-O"`0!=````M<,!`#D````3Q`$`6P```$W$`0!$````J<0!`$\```#NQ`$`
M(P```#[%`0`N````8L4!`"````"1Q0$`,@```++%`0`^````Y<4!`"<````D
MQ@$`,````$S&`0!0````?<8!`&\```#.Q@$`70```#['`0!1````G,<!`"8`
M``#NQP$`(0```!7(`0`T````-\@!`"````!LR`$`(0```(W(`0`C````K\@!
M`&\```#3R`$`:0```$/)`0"_````K<D!`!<```!MR@$`(````(7*`0`\````
MILH!`#P```#CR@$`.P```"#+`0`E````7,L!`$4```""RP$`'P```,C+`0`6
M````Z,L!``8```#_RP$`Q0````;,`0!!````S,P!`",````.S0$`,````#+-
M`0`P````8\T!`"(```"4S0$`'````+?-`0`R````U,T!``T````'S@$`"```
M`!7.`0`%````'LX!``P````DS@$`#````#'.`0`,````/LX!``L```!+S@$`
M!0```%?.`0`2````7<X!``0```!PS@$`3@```'7.`0`%````Q,X!`!0```#*
MS@$`!````-_.`0`'````Y,X!``4```#LS@$`!0```/+.`0`#````^,X!`!(`
M``#\S@$`"0````_/`0`2````&<\!`!$````LSP$``@```#[/`0`%````0<\!
M``<```!'SP$`$P```$_/`0`,````8\\!`!<```!PSP$`!@```(C/`0`1````
MC\\!``T```"ASP$``P```*_/`0`R````L\\!``0```#FSP$`!@```.O/`0`'
M````\L\!`!P```#ZSP$`+0```!?0`0`N````1=`!`"\```!TT`$`$P```*30
M`0`>````N-`!`!<```#7T`$`&P```._0`0`>````"]$!`!D````JT0$`&@``
M`$31`0`>````7]$!`!8```!^T0$`*0```)71`0`?````O]$!`"<```#?T0$`
M%P````?2`0`;````'](!`!T````[T@$`&````%G2`0`D````<M(!`"8```"7
MT@$`)P```+[2`0`7````YM(!`!@```#^T@$`'````!?3`0`B````--,!`!<`
M``!7TP$`'@```&_3`0`:````CM,!`#X```"ITP$`)````.C3`0`G````#=0!
M`"H````UU`$`*P```&#4`0`E````C-0!`!L```"RU`$`(````,[4`0`=````
M[]0!`#`````-U0$`'0```#[5`0`*````7-4!`!8```!GU0$`$@```'[5`0`H
M````D=4!`!T```"ZU0$`#0```-C5`0`/````YM4!`!D```#VU0$`$````!#6
M`0`;````(=8!`#$````]U@$`"````&_6`0`*````>-8!`"(```"#U@$`)@``
M`*;6`0`E````S=8!`!D```#SU@$`!P````W7`0#"````%=<!`!H```#8UP$`
M%0```//7`0`(````"=@!``P````2V`$`%````!_8`0`:````--@!``4```!/
MV`$`-0```%78`0`4````B]@!`!0```"@V`$`!P```+78`0`*````O=@!``H`
M``#(V`$`0````-/8`0`E````%-D!`!(````ZV0$`%0```$W9`0`/````8]D!
M`#(```!SV0$`#0```*;9`0`.````M-D!``\```##V0$`&````-/9`0`*````
M[-D!``\```#WV0$`!0````?:`0`?````#=H!``H````MV@$`'P```#C:`0`(
M````6-H!`!4```!AV@$`!P```'?:`0`(````?]H!``H```"(V@$`.P```)/:
M`0`/````S]H!``4```#?V@$`#0```.7:`0`*````\]H!`!````#^V@$`!@``
M``_;`0`*````%ML!``<````AVP$`$@```"G;`0`,````/-L!`!P```!)VP$`
M'0```&;;`0`3````A-L!`!$```"8VP$`'@```*K;`0`R````R=L!``4```#\
MVP$`!@````+<`0`<````"=P!``0````FW`$`*@```"O<`0`0````5MP!``4`
M``!GW`$``P```&W<`0`,````<=P!`!<```!^W`$`"P```);<`0`#````HMP!
M``H```"FW`$`$@```+'<`0`(````Q-P!``L```#-W`$`#@```-G<`0`/````
MZ-P!`!$```#XW`$`$@````K=`0`*````'=T!`#`````HW0$`&P```%G=`0`8
M````==T!``H```".W0$`2````)G=`0`(````XMT!`!8```#KW0$`0@````+>
M`0`4````1=X!``\```!:W@$`"0```&K>`0`$````=-X!``8```!YW@$`%@``
M`(#>`0`:````E]X!``<```"RW@$`"````+K>`0`(````P]X!``(```#,W@$`
M"0```,_>`0`%````V=X!``0```#?W@$`"P```.3>`0`*````\-X!``4```#[
MW@$`"0````'?`0`%````"]\!`!H````1WP$`)@```"S?`0`5````4]\!`!X`
M``!IWP$`$0```(C?`0`"````FM\!``0```"=WP$`#P```*+?`0`&````LM\!
M``4```"YWP$`!````+_?`0`4````Q-\!`$D```#9WP$`$0```"/@`0`E````
M->`!`"\```!;X`$`6````(O@`0`P````Y.`!`"4````5X0$`$0```#OA`0!I
M````3>$!`!\```"WX0$`/````-?A`0`F````%.(!`#D````[X@$`+@```'7B
M`0`E````I.(!`!T```#*X@$`)P```.CB`0`B````$.,!`#4````SXP$`,0``
M`&GC`0`Q````F^,!`#4```#-XP$`+0````/D`0`?````,>0!`#4```!1Y`$`
M-@```(?D`0`:````ON0!``X```#9Y`$`#````.CD`0!S````]>0!``8```!I
MY0$`=0```'#E`0!J````YN4!`"L```!1Y@$`$````'WF`0`6````CN8!``L`
M``"EY@$`&@```+'F`0`U````S.8!`!L````"YP$`%0```![G`0!7````-.<!
M`!<```",YP$`"@```*3G`0`%````K^<!``8```"UYP$`"````+SG`0`%````
MQ><!`!0```#+YP$`$````.#G`0`6````\><!`"`````(Z`$`"P```"GH`0`+
M````->@!``@```!!Z`$`!@```$KH`0`$````4>@!``H```!6Z`$`!````&'H
M`0`+````9N@!``@```!RZ`$`!P```'OH`0`7````@^@!`!,```";Z`$`!@``
M`*_H`0`&````MN@!`!<```"]Z`$`"P```-7H`0`'````X>@!`!(```#IZ`$`
M$````/SH`0`&````#>D!``@````4Z0$`%P```!WI`0`-````->D!``T```!#
MZ0$`!@```%'I`0`&````6.D!``\```!?Z0$`"P```&_I`0`,````>^D!``P`
M``"(Z0$`!P```)7I`0`%````G>D!`!0```"CZ0$``@```+CI`0`$````N^D!
M``P```#`Z0$`"0```,WI`0`B````U^D!``(```#ZZ0$`$@```/WI`0`8````
M$.H!``L````IZ@$`!0```#7J`0`,````.^H!``H```!(Z@$`#P```%/J`0`6
M````8^H!``4```!ZZ@$`#0```(#J`0`G````CNH!``X```"VZ@$`#P```,7J
M`0`0````U>H!``4```#FZ@$``@```.SJ`0`+````[^H!``$```!I`0``"`,`
M`),$``#,!0``````````````````'P0```````"R`0``$@0``*D$``"=!@``
M(P(``-P$``#X````V`8``-X```"X!@``Z@4````````$!```+0$``)P```"X
M!0``*@8``"H"````````^@8``"8%```&`P``ZP4``/X!````````@@4``&\`
M```[`0``7P,``)@#```K!0```````/4&```E`@``$08``+T&``#&`P``#@,`
M``,`````````[`$```````!<````W0$``*@$``"4!@``&`(``'@!``#K`0``
M8@(```````"I!@``KP0``)8#``!6!@```````-T#``"1`0```````'$#````
M````=`4````````4````]`$``.X#``!L`@```````/\%````````E@4``)H$
M``"+`P``R@8``(8```!K````0`(``&\!``"U`P```````)\`````````````
M`$\#``#9!@``2`0``'`!`````````````.4"```*!@``#0```)@"``#_`@``
M"0(``,$&````````S0(``(P#``````````````<```!0`P``T@(``"L&``#?
M!```.00``(\"`````````````'T&``"7````O`8`````````````"`<``$$&
M````````H0(``$X!```!`P``%@4``)D``````````````"L```#[!0``OP4`
M`%````#V!0``'0<``)H!``#A`0``G@```%@"```*`0``<P0``,L&``"Z!@``
M3`$```L```!N!```=08``$<&````````&0,``%D#``#G!@``E`$``$`&``#J
M`@```````!T#```$``````````````"$!```I@(``)\#```N!0```````+X"
M````````````````````````=00```````#.!```9`(``%`$``"?`0``X00`
M`(@!``"J!@``N@```&`#``![!0``LP,```````!N`@``^@0``-0!``#T!```
ML````!T$``#%`@```````*D%``#@`P``7@(``%0#``#I````?@0```````!.
M````[0```'H$````````RP$``)D#``!F````[@0``"H#````````S@$``-<#
M``!Y`@```````,\&``";!0``%P4``'`#``!%!```W`$``-8!``"6!@``+P``
M`!@#`````````````&8#```S!P`````````````-`P``&04```````"'`0``
M0@$```````"N!@``X`$```````#J!```-P```*T"```*!P``*`(```````"X
M`0``-P8``!,"`````````````%\$``"V`0````````L$``#'!@``,0,``%T$
M```3`P```````&T!``"M!0``QP0``(X#``!W!@``^P0````````>````C@``
M``````"[````\@(``-H$```N!P``&@0``+T!```/!P```@(``'X"``"?!0``
MP@0``(X"``!K`P``L`(``)@&``#R!@``,@8```````!T`P``H00```P&````
M````,@,```````"T`@``%04``)L!````````$@(``!$$````````,@4``#\%
M``![`@``V@,``.X`````````;P4```````!?`@``4P(``"L"````````-@4`
M``````!=!0``IP8```````![`0``"@(````````S!```F`0``#P&````````
M?P$```````#Y`P``(@$``+L&``#>`P`````````````!!0``\`4``"8"``#&
M`@``5@4``&@$```!!@```````!0%````````D`(`````````````NP4`````
M````````.P,``",```#D!```_`8```L%```T`0``Y`````\#``#:`@``[P(`
M``````#>!@```````!T`````````.0<``)@````6`0``#@4``,T%``"Y!```
MZ`0``)$#```E`0``RP4``!D!`````````````/($````````%0$``/`#```[
M!0``XP8```\!``#6!```B@$```````"M!```N0,``#0$````````NP$`````
M``"O`P``D@(``+(#``#+````K`0``&H!```:`0``)`<```````""`@``@P4`
M`)0```#1!0``$0(```````!8!```4`4``*4#``!@!@``[`(``!P%``#9!0``
M5`(``-``````````WP(``,D%``">!0``7@````4'```Z`0``B`0``!(&````
M````&@4````````?!P``'P````````!G````@0$``/0"``#O!@``EP0``&$`
M```4`@``P00``$T$````````\P,``(0#````````40$``$T%```:`@``?`0`
M``````!>!0```````'<#```6!@```@0``+X%```7`0```````*`!``#%`0``
M2P0``````````````````&<&``"1````UP8``,X"``"R`@``90```"D"``!O
M!@``,`````8$`````````````*<!``"Y````20,``*4"``#-`P``C0```%<#
M`````````````$($``#P`@``Q`4``)P!``!U!0```````'(%````````"P(`
M```````.`@``/0$``*($```]````P0```)$%`````````````.X%```,!```
M0`0``/H"``"!!```,0```&8"``#W````_@0``%\&````````[````"L'```'
M`0```````/L"``#>!```F@8``+`$```.!@``I`8``/H```"+````````````
M``":!0``004``(P$````````\P(````````M`P``W00````````L`0``````
M`$4&``"W`P``@P(```````#_`0``,@```*`&``#.`P`````````'``#%````
M1@```*8`````````P`4``(,```"2!```@08````````)!@``&P````````#%
M!@``````````````````S08``-,&`````````````%P&``!_````B04```$'
M``"*`P``S@`````````&!P`````````````X`@``[0(``#P%``#S!0``.@4`
M`!H&``!V!@``````````````````_0```-H```#U`0```````&(!``!H`@``
MU`,``-L#````````````````````````1P0``)`%``!K`@``3P```#T"```[
M`@```````!T!```.!```IP,``'$!``#$!```^@4``/<&````````R@,``/X`
M``#D`@``\0(``.<!``#\`0``(`$```````!!`0`````````````Q`@``0P(`
M`.\```!$`0``````````````````X`(````````J!```\`$``+\#``#@!@``
M`````+8%``!]`0``%P0`````````````PP$```````!#`P``L0$``/8!```F
M!```;@,````````U!0``(0```!X&``#:!@```````'X&``#D`P```````$,$
M```T````7`(`````````````K@$```````#]`@````0``,0```"F`P``````
M`/`&````````EP8``)8````R!P``````````````````<`(``/<#```-!0``
MSP```"T$``#E````*`$````````T`P```````"$&``"[`@``-@0`````````
M````0`$``)P"````````(```````````````#P0``+4!``"0````W0(`````
M``"H```````````````6!````````$\"``"6`0````````````!;`0``-P<`
M`(`&````````N@$``$0#```3!@```````$X%``````````````````"=`0``
MJ`$``(H$````````*@4``"`$``"5`0````````````!%`````````#`"````
M````=@0``'\%``!Q````Z0(````````K`0```````$L#```O`@``<`0`````
M``"+`0``G`4``"`&```W!```D`,``&0!````````:@4`````````````XP(`
M```````&!0``N04``.D$``!L`P````````````!E`P``'P4``'P!````````
M```````````5`@``5P(``#D#``"!````^@,``-0&```;`@``O0,``)<"``!,
M!0``>0,``.,```!.`@``'`<``(8&``#:!0``MP```'P%``"\`@``[@$`````
M``!K!0``KP$``!`$````````VP(``````````````````(P!````````(0(`
M```````*````+`,``%D!``#'!0``A08``%X!``#^!@```````&`````D!```
M,P4``'T"``#A!@```````+P$```(`0``TP$`````````````````````````
M````U00````````Q!@```````#X&```U`@``FP,```````#2!`````8``#P`
M``#5`P``Z0$```````!1`P``V`0``)T$``!L`````````#\$````````````
M`!<&``#'````"0$``$0&```G!P``OP````````".!0``````````````````
M10(`````````````*`4``$(%````````%`<````````N`P``508`````````
M````%P(``+(`````````*P,```````!&!@``P`8``````````````````.(!
M```K!```M@```*(```#?!0``-0$``&<$```R!````````,8&````````````
M``````!&`@``$`(``#,!``#T`P``2@,``+4&```V`0``H`(``$H`````````
M````````````````CP$``#X#``#*````VP$```````!/!@``K`4``!P!``"1
M!@```````%@%```Z````X```````````````<@0```L!``!V````_P,``&D%
M``!]!0```````/8&``"(!0``L@8`````````````=`0``',"``#^`@``_`4`
M``````"H`P``2P4```````#Y`@``=0(``#8````]!````````$(#``#X`@``
MJP8```````"/!@``(P,````````!`@``$04``&P&````````*@<``%@!``#2
M`P``;`4````````X!P``0P```+P#`````````````(L&````````;@$``!L&
M``!B`P```````*H%``##!````````$L"``#&!0``9`8``&8%``#S`0``A@,`
M````````````Q@```-T%``#<`P``?0```*D!``#K`@``(@``````````````
MYP(``$0"````````4P8``(\#``"%`P``G`,``%<!``"]`@``G`8``(`#``"K
M````50````````"[!````````$T```"'!@``I0$````````3!0``$````!@!
M``#$!@``UP(``%T"``!"`@``XP0``',&``#2!@``C00```````!E!```)`4`
M`/D&``!#!0```````)`$``#D`0```````$T"``"-`P``U0$`````````````
M90(``'@&``!=!@``VP8``/(%````````/0<``"T&```Q`0``NP,``(0```#+
M`@``E`,``/$!````````6@0```````#)!@``/`<``"\#``#B`@``````````
M``#O`P``#0(``,````#`!```;04```0'````````C0$```````#1!@``)@$`
M`*X"``"*````\`0````````G!```000``)X"``!!````+0<``-`#``"N!0``
M`````)$"``!^`P```````.P$``#Y`````````!L!```%`@``/`0````````F
M!P``6P8``+<!``"A````%P```-D```"I`@```````!P#``#-!```/P$`````
M``!J`P``%`$``),"``"Q!```-`4````````"!0``:`8``.@&```C!0``````
M`-(````3````"00``(8%````````LP(``)4&``#*`@``!P0``%T`````````
M;0```(``````````N````"H!```[!P``D00``"@$``#L!@``5P8``$X#````
M````R@$```````!2!@``2@8``'L```!Z`0``X`0``.0&``"L`P``$0,``"$#
M``"%!0```````%8#````````H@8``(@```![!@```````%,!```2!P``7`0`
M`.(```#0!0``.@(``$0%````````L`4``*H````U!P``]`4``(`%``!H`P``
M208``'H#```0!P```````"H````#!@``/0,``'`&``#3`````````"P%``#D
M!0``AP(``,D#`````````````#P#``#B!0``1P,``#T&````````U@,``'@`
M``"I`````````&<!```Z`P```````-8"``#(`0``O0``````````````,P``
M`$H$```!!`````````4```!5`@``*00``'("``#?!@``)P```-4````9!```
MO`$```4$``#^`P``20````$!```N`@```````,P$``"D`P``7`4``%L"``"-
M!0``A0```'P&``!2`0```P(``,@&````````1P(``#X!````````YP```%,%
M``!)`@```````,@#````````:P0``,H$``#-````?P,``%0%``#K!```=@(`
M`!\&```Q!P``M`0``#D````=!0``L@4``/@!``"P`0```````-$$````````
M`````*H$``!+`0``S`8``$H"``"Q!@``2`,`````````````$0``````````
M````-`(```,$````````R`4``'@%``!(`0``I00``#0'``!T`0``6P,``&D$
M``")!@``P@4```````#V`@``?P8``*0!``!3````)0,``/4#````````TP0`
M``````#?````@P0``"`#``!5`0```````#$$``")`0```````'\$``#F!@``
MN@0``/P$````````#@$``$@```"4!0``[0$``(P&```F`P``"0````````!&
M!```&P<``'T$```D`0``.`8``/<!``"W!0``!P8``,<!```<````O00`````
M```I!0``+0```%$"``"Z`P``A@(``"`'```/`@``FP```&@%``!T````U@``
M`&L!``##!0``)P8``$T&``"+`@``$P0``.,#```D````X@0```(!```F!@``
M#`$``&<%``#&!```F@(``.,%``#$`@``.`,``!`!``#A!0``-0,```````!<
M`P```P$``!$!``!L`0``;@4``&H&``#;!```MP0``-@!``#8````%`,`````
M````````M@,````````/!0``AP0````````@!0``G0,``'D!````````#0<`
M`)X&``!Y!0``#`,````%`````````````"4```#Z`0``T0(```````"3`0``
M'P$```````"3!@```````#`%````````/04``#X"``!>`P```````(($``!&
M`P``Q`$```````"_`@```````(X!``"9!```ZP8`````````````3@8``#8'
M``"K!````````!`#``"G!```#````-P"````````V00``!(%```9!P``C```
M```#``"%`0``=@4```````#1`0``+0(``)0"``"S!@``:0,``+@"``"V!@``
M_`````\&````````90$``````````````````#`!````````9```````````
M`````````.<$````````W@$```````"'````<0(```````!9`@``P`$`````
M``"^!@``$@,```8"````````\@```($%```O!```A`4```````!-`P``N08`
M`.$```#S!```7P4```0!``!G`P``,@(``*T#``"Q`P``<P4``"$'````````
M`````!P"``"_!@``10$`````````````#08```````#E!`````````<%````
M`````````*@&``#.!@``2`8``%`!``````````````````!B!@``E00```D'
M```Z!P```````%L%```^!P``A`8``)L&``#-`0``V0(``)4```#1`P``FP0`
M`$D!``!M`@``4P,`````````````;@8``%(%``!,!@```````"($``#7!0``
M``````````#/`@``M04``%@```#F!0``4`8``+,````9``````````,%``#H
M`P``E@0```````"O`````````#<"``#B`P``.@8``"D'``!P````OP$`````
M``"!`@``9@8``'L#``#]!0``O@0``'D```"E!@````````````"Y`@``+P4`
M`.8````A!```6@4``!T"```"````@P,``!8````R`0``O`4``/$#``#>!0``
MZP```(8$````````````````````````6`,``+$``````````````",!``#:
M`0``<@```"T%````````V0$````````$!0````(``*P&````````YP,``"X!
M``````````````````!Y!@``P@,``*0$```P!P``````````````````````
M`)T"````````>P0``!<#``#W!```408```````"/!0``_@4``'`%``"*!0``
M`````%(```!;!```[08``%D$````````>@(``$<```#)`@``7@0``%<%``!4
M`````````'@"````````EP4```````!&`0``M````"\'```5!```````````
M```,!0``"0,``%H&````````X0(``$D$``"D!0``;P,``"@#````````H`,`
M``````!,`@``QP(``!@%``#,`@``E@(``'H&``"@!```+`<```8&``#U`@``
M*`````````!,!```M@(``$$#``"K`P`````````````D`@```````'P#``#?
M`P``800``'D$``#L`P``````````````````K08``&\$```H!P``%08``%\!
M``!D`P``P@$``*$#```\`0``H`4``)@%````````;08```````##````80(`
M`*\"``!(!0````````````":````)04``+D!``"3`P```````-(%```V`@``
M70$``,\#``"``@``)0<``"<%```E!@``Z@,```````#8!0```````"(#``!U
M````C0(``%8```!X!```U@8``.$#```(````@`$```````!`!0``0@```"('
M``#Q!````````-`"```*!0``Y0,``'0"``!$!```1@4``.<%````````"`(`
M`)X!```P`P``]04``(D```#;`````````,8!``#[!@``F08``.8!``!V`0``
M/@0``'H```!B````]@,``-4%``"F!@```````'(#``"B`P``LP$``$D%```@
M`@````````````"N````W````,`"``#]!```'`8``!8#```;!0``I@4``"$%
M``"9!0``\P8``#8#``!]`P``J@$``'<!``"A!0``\08```````!S`0``T@$`
M`(8!``"9`0``8P4````````_`@``8P```&D"````````C@0``#0&``#W!0``
M`````&8!````````]00``/D$````````IP4````````:````40```-\!```,
M!P``@0,```````"#!@```````(P%````````U`0`````````````"04`````
M``!`````_P`````````B!0````````@&``"Q`@``104`````````````J0,`
M`%0!```"!P``J@(``"8```!D!```1P$``+X!````````S`$``!L#``#W`@``
M9@0```````!R!@``P`,```````"+!0```````,D$``"L`0``80$``.\$``"_
M!````````/\&``"7`0``!0$``',#``!>!@```````#,"``!J````+````"(&
M``#3`P``2P8``*@%``"5!0``G`0``((&`````````````)D"``!<`0``6@,`
M`#,&```E!```Q00``,("````````HP,```P"``#L!0````````````"U!```
M`````#D&````````K0```/(#``#E!@```````&<"``"2`P``%0````````!5
M!0``O@```````````````````(4"``!U`P``K`(``((#````````.0(``.D#
M````````PP,``.`%``"2`0``0@8``#@$````````Y04```````"$`0``````
M`!X"```:`P``P@8``.D&```%`P``'@,```<#``!W`@``+P$``"D!``!5`P``
MK0$```````"Q!0``H@(``%T#```*`P``R0$``-T```!*!0``KP4`````````
M`````````#\'``!\`````````*L!``!:`0```````!(!```-`0``TP(`````
M````````IP(````````+`P``CP0``%D&``"(!@```````!X%````````,P,`
M`#P"``!2`@``\04``/@$``#6!0``HP```)T````5`P```````#@````Q!0``
MZ````````````0``RP,``,\$``"A!@```````%8$```&````G04``-$````9
M`@``400``!X'``#.!0``UP```,4#``#"`````````(@"``#,`````````.H&
M```_````<@$``&H$```8!@``!P<`````````````%`0`````````````````
M`"0#````````_`(```````#*!0``8P8``$\!``#O`0``3P4```@$````````
M^`8````````Z!````````/0&```'`@```````*H#````````U```````````
M`````````-P&```#`P``T`0``+<&``")`P``_0$``/0`````````+`0``+H"
M````````%@(``+`&```W`P``D@4``&\"``##`@``R````)X$```%!@``````
M`!$'``!7````8@0``.X&````````'P,```8!````````0P8``(@#``!#`0``
M(P8```````""````P04``*0```#]!@``$P$```````#3!0`````````````+
M!P``P0$``%8"````````&`0`````````````P0(``*L"``#[`0``<04`````
M``#C`0``@`0``.@%````````I@0``.@!``#%!0```````-L%```W!0``````
M`-`&````````,`8``.L#`````````````((!``";`@``8P,```````#U````
M:P8``-4"`````````````$X$````````CP```"X&```V!@``%P<``+4"``"0
M`0``;@`````````````````````````[!```&@<```4%````````P0,``$P#
M``!W!```SP$``.8$````````/@```$`'``"C`0```````&`!````````6@``
M`#D%``!^````UP0``)\$``````````````````#X!0``^P,``-4&```8````
M`````-0%```0!0```````*(!``!1!0``'@$```````````````````````!2
M!````````,\%``"+!```HP8``"@&``#J`0``[04```````!@!````````#4$
M````````)`8``-@"```[!@``00(`````````````+@0```````#F`@``````
M``X````I````D@`````````+!@```P<```````#O!0```````-<!``!D!0``
M`````,<#``"W`@``%`8``+0&````````-08``(P"``"C`@```````!(```!$
M````K`````````"N!```[0,``+0!````````4P0``),```"2!@``N`0`````
M``"@````/P,`````````````30$``,P#``"E!0```````/``````````````
M`%L````G`P``/P8``&@```!0`@````````````!E!@``C08``#@!``"Z!0``
M8P(``'H%``!L!```^`,``"<"``#8`P``M@0``,@$`````````````)X#````
M`````````(X&````````.0$``%8!```L`@``*08``&4%``"O!@``0`,```\`
M````````\@$```````"K!0```````'0&``#)`````````/D%``"7`P``[00`
M``````#(`@``IP```'<%````````604``'P"``!'!0``!`(``'@#``"%!```
M8`4``#4```#9`P``\0````````!Q!```8P$``'8#```8!P``;00```T$````
M````\P```$@"``````````````````"T!0``!`,``+,%````````````````
M``!/!```60```%<$``"4!```L@0```````"?`@``W@(``,,&``#_!```$P<`
M`!D&``"$`@``X@8``(D$```C!```:@(``%@&``!@`@``*0,``%(#```(!0``
M)P$``&(%``!Q!@``LP0```````"N`P```@,`````````````?P(```(&````
M````D`8````````;!```W`4``&$&``!M`P``7P````````!U`0``:0```+4`
M````````B@8``(,!````````I@$``*$!``!^!0``500``+`#``"?!@``/@4`
M``````"]!0``_`,``)@!```````````````````5!P``8P0``$4#````````
M<P````0&```.!P``Q`,``,L$````````I0```/T#```W`0``+`8``*,%``"T
M`P``%@<``&$%``"'!0``[@(````````[````HP0``)4"``!4!@``(P<``#@%
M``":`P``DP4``-`!``"'`P``5`0````````P!```=P````````"D`@``6@(`
M`"("`````````````(H"```<!```'08``-T&``"\````Y0$``.D%```*!```
M^P````````#V````^0$``&$#```A`0``+P8``$L`````````E0,``/8$``#H
M`@``N`,``!X$``"H`@``?@$``!\"``")`@```````$P`````````:`$`````
M``#4`@``:08``$H!````````Z@```*(%```N````Y@,``!`&``"^`P```"`H
M)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H
M=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`")&:7)S=&YA
M;64@3&%S=&YA;64B("`H:64N($IO:&X@1&]E*0`B3&%S=&YA;64L($9I<G-T
M;F%M92(@*&EE+B!$;V4L($IO:&XI`"5D("5S(&%N9"`E<P`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E
M<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A9&1E9"X`)7,@
M86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&9I;&4@<W5C8V5S<V9U
M;&QY(&EM<&]R=&5D`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T
M(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T
M97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U<W1I;F<@)7,@)7,`+"!V
M87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O
M<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&)R;W=S97(@=&AA="!S
M=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D`$$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@4F%I;@!!32!3:&]W97)S`$%-
M(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`
M06)O=70N+BX`06)O=F4@<V5A<F-H(&9O<FT`06)S8F]T=&]M`$%B<VUI9&1L
M90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`
M06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U
M<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U
M<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU
M;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\`061D('1O(&%D9')E<W,@8F]O
M:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K($QI<W1I;F<`
M061D<F5S<R!B;V]K(&5N=')Y`$%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@
M<'5R9V5D+@!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`061V86YC960@4V5A<F-H`$%F
M9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE
M;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L
M;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`
M06QR96%D>2!%>&ES=',`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@
M3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@
M57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E
M;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U
M:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U
M82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P
M<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P
M<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ
M,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S
M=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/P!!<F4@>6]U('-U<F4@
M=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N=')I97,_
M`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!
M4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N
M9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`
M07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@
M<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&
M2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R
M8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA
M<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R
M8F%D;W,`0F%S96QI;F4`0F%S:6,@4V5A<F-H`$)E;&%R=7,`0F5L9VEU;0!"
M96QI>F4`0F5L;W<@<V5A<F-H(&9O<FT`0F5N:6X`0F5R;75D80!":'5T86X`
M0FEN9"!F86EL960Z("@E<RD@)7,`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A
M<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO
M8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@
M=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T
M:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U
M;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0G5S
M:6YE<W,@0V%T96=O<GD`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<P!#4U8`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A;6)O
M9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E
M(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)
M<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E
M;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A
M=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#
M:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H
M96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA<@!#
M:&5C7VL@3&EN:RXN+@!#:&5C:R!?06QL+TYO;F4`0VAI;&4`0VAI;F$`0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H
M;V]S92!A;B!A9&1R97-S(&)O;VL`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@
M=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@
M0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO
M=61S`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3
M:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R
M(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!/<'1I;VYS
M`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA('-E<&%R871E9"!V86QU97,`
M0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI`$-O
M;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R
M;W,`0V]M<&%N>0!#;VUP86YY($%D9')E<W,`0V]M<'5T97)S`$-O;F1I=&EO
M;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N
M9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P
M=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A
M:6QE9#H@`$-O;FYE8W1I;VX@9F%I;&5D.B`E<P!#;VYN96-T:6]N(&9A:6QU
M<F4`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!#;VYT86-T(')E;6]V960@9G)O;2!L:7-T+@!#;VYT86-T<R!I;B!L
M:7-T.B`E<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI
M90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER
M90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'
M4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'
M4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@
M;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I
M<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN
M('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E
M;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S
M<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@
M=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V
M92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B
M:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD
M(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U
M<G-E<P!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U
M8B!F;VQD97)S`$-R96%T960`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@
M8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT
M(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#
M=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+
M3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I
M;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E
M92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$
M87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E
M8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)
M9&5N=&ET>0!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$969I;FET:6]N
M<P!$96QE=&4`1&5L971E($-O;F9I<FUA=&EO;@!$96QE=&4@1W)O=7``1&5L
M971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@8G5T=&]N(&)E:&%V:6]U<@!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&9A
M:6QE9#H@*"5S*2`E<P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R
M<F5N="!R;W<`1&5L971I;VX@9F%I;&5D`$1E;&EV97)Y('1I;64`1&5N;6%R
M:P!$97!A<G1M96YT`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P
M;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@
M<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$
M:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y
M(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@
M;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_
M`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E
M<'5B;&EC`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O=VYL;V%D('9#87)D`$1R;W`@9&]W
M;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO
M8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N
M<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&5N=')Y(&9O<B`E<P!%
M9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C
M871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%
M;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`
M16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R
M=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL
M87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z
M`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1R>2!F;W(@)7,@=7!D871E
M9"X`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!W:71H
M(&5M86EL(&UE<W-A9V4N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P
M90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R
M92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`
M17AP;VYE;G0`17AP;W)T`$5X<&]R="!!9&1R97-S($)O;VL`17AP;W)T(&]N
M;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+@!%>'!O<G0@=&AE(&9O;&QO=VEN
M9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2X`1D<@0V]L;W(`1E10('5P;&]A
M9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E<P!&86EL960@=&\@
M861D("5S('1O("5S.B`E<P!&86EL960@=&\@8G)O=W-E(&QI<W0`1F%I;&5D
M('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y`$9A:6QE9"!T;R!C:&%N9V4@;F%M
M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T(#T@
M)7,`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@
M(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@9FEN9"!O8FIE8W0@
M=&\@8F4@861D960Z("5S`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE
M9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,`1F%I<@!&86QK;&%N9"!)
M<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`
M1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W
M97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL92!#
M;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G
M97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@
M=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;F0`1FEN;&%N9`!&
M:7)S="!(86QF`$9I<G-T($YA;64`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`
M1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@
M0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE
M`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W
M87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R
M965B=7-Y(%523`!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E
M;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@
M1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA
M;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($%D9')E<W,@
M0F]O:P!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E
M`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<`!'
M<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U"
M:7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L
M92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N
M9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)
M*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P
M:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`
M2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE
M($%D9')E<W,`2&]M92!#:71Y`$AO;64@0V]U;G1R>0!(;VUE(%!H;VYE`$AO
M;64@4&]S=&%L($-O9&4`2&]M92!3=&%T92]0<F]V:6YC90!(;VUE(%-T<F5E
M="!!9&1R97-S`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA
M8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E
M("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D
M:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET
M>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL
M960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S
M`$E-4U``25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO
M8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`
M26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT
M:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL
M("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@
M<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA
M>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N
M<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G
M92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P
M;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!5
M4DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G
M86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="!!9&1R97-S($)O
M;VLL(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O<G0@061D
M<F5S<R!";V]K<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R
M<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@
M57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YS97)T($-?;VQU
M;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B
M($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R
M96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M
M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@
M<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R
M90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN
M<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P
M87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B
M969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I
M9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R
M`$EN=&5G97(@;&ES=`!);G9A;&ED($E$`$EN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN`$EN=F%L:60@861D<F5S<R!B;V]K`$EN=F%L:60@87!P
M;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M
M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!E
M;6%I;`!);G9A;&ED(&5N=')Y`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI
M9"!K97D@<W!E8VEF:65D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&YA
M;64`26YV86QI9"!O8FIE8W1)9`!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED
M+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!S:&%R
M92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC
M;V1E(&1A=&$N`$EN=F5N=&]R>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)
M<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P
M86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`
M2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T
M:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN
M86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A
M=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P
M<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A
M=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R
M96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ
M<W1A;@!,1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO
M9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N`$QA7WEO=70`
M3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S
M="!(86QF`$QA<W0@36]D:69I960`3&%S="!.86UE`$QA<W0@475A<G1E<@!,
M87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R
M;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A
M=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D
M97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA
M;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A
M:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I
M;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,
M:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O
M.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@
M=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T`$QI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T
M($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE
M;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB
M90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@
M`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I
M;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R
M('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL
M960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO
M=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O
M=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V
M(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN
M`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`
M36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-
M87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA
M<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9P!-871C:&EN9R!F
M:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET
M+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N
M9W1H`$UA>&EM=6T@;G5M8F5R(&]F('!A9V5S`$UA>0!-87EO='1E`$UE9&EC
M:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X
M<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$UE=&AO9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO
M=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:2!396%R8V@`36ER
M<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!$3B!I;B!,1$%0('-O=7)C92!C
M;VYF:6=U<F%T:6]N+@!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N
M+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA
M:6P`36]B:6QE(%!H;VYE`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y
M(%523`!-;V1I9GD@9F%I;&5D.B`H)7,I("5S`$UO9'5L=7,`36]L9&]V82P@
M4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO
M;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E('1H86X@,2!E;G1R
M>2!F;W5N9`!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO
M<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H
M=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E(&QE9G0`36]V92!R:6=H=`!-;W9E
M('5P`$UO>F%M8FEQ=64`375L8F5R<GD@061D<F5S<R!";V]K`$UU;'1I+6QE
M=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!P97)S;VYS('=I=&@@861D
M<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X
M:7-T`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!-
M>2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA
M;64`3F%M92!&;W)M870`3F%M:6)I80!.875R=0!.97!A;`!.971C96YT97(@
M365M8F5R($1I<F5C=&]R>0!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I
M;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N
M(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@
M55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V
M97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E
M(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA
M`$YE=R!#871E9V]R>0!.97<@0V]N=&%C=`!.97<@36]O;@!.97<@57-E<FYA
M;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI
M`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`
M3FEC:VYA;64`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO("5S(&5N
M=')Y(&9O=6YD(&9O<B`E<P!.;R!A9&1R97-S(&)O;VMS(&9O=6YD+@!.;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@
M:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T
M('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V
M:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C
M:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8V]N=&%C=',@9F]U;F0`3F\@
M8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE
M('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N
M`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N
M=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.
M;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@
M8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V
M0V%R9"!D871A('=A<R!F;W5N9"X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N
M960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S
M:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC
M("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P
M:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E
M<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N
M`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C
M=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@:71E;7,@<&5R('!A
M9V4`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C
M="!#<F5A=&]R`$]B:F5C="!N;W0@9F]U;F0`3V-T86P`3V-T;V)E<@!/9F9E
M;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P
M;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO
M;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T
M:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@
M26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N<P!0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET
M86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME
M>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L
M;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H
M;W=E<G,`4$T@5"U3=&]R;7,`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N
M`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA
M`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S
M=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3
M:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VX@
M9&5N:65D`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`
M4&EN92!!9&1R97-S($)O;VL`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M
M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG
M(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S
M=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE
M=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@
M;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($%D9')E<W,@0F]O:P!0
M<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C
M=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H
M;0!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!1=65R>2!F86EL960Z
M("@E<RD@)7,`475I8VL@4V5A<F-H`%)302!0=6)L:6,@2V5Y("@E9"!B:70I
M`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A
M:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&
M;W)T=6YE`%)A=&EO`%)E860`4F5A9"!F86EL960Z("@E<RD@)7,`4F5A9"!M
M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C;W)D
M<R!D:7-P;&%Y960Z`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!2
M96=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V
M97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E(&9R;VT@=&AI<R!L:7-T`%)E;6]V92!P86ER`%)E
M;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@
M9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@
M8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E
M<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+@!297%U:7)E9"!&:65L9`!297-E
M=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<V5T('1O
M($1E9F%U;'1S`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2
M979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`
M4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@
M4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@
M3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I
M97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%,O
M34E-12!0=6)L:6,@0V5R=&EF:6-A=&4`4T%33"!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`
M4U1!4E143%,@9F%I;&5D.B`H)7,I("5S`%-50T-%4U,`4U]13"!3:&5L;`!3
M80!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A
M;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V
M:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S
M(&-O;F9I9W5R871I;VXN`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S
M`%-E87)C:"!F86EL960`4V5A<F-H(&9A:6QE9#H@)7,`4V5A<F-H:6YG+BXN
M`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O
M(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C
M="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!3
M96QE8W0@86X@;V)J96-T`%-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X
M<&]R="!F<F]M.@!396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@
M=&\Z`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&5X<&]R="!F
M;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E;&5C="!T:&4@
M9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93H`4V5L96-T('1H92!F;W)M870@
M=7-E9"!T;R!D:7-P;&%Y(&YA;65S.@!396QE8W0@=&AE(&ED96YT:71Y('EO
M=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`
M4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N`%-E;&5C="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@
M861D<F5S<R!L:7-T<RX`4V5L96-T('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y
M(&YA;65S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD
M(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E
M=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA
M>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@`%-E>6-H96QL97,`4VAA<F5D($1I<F5C=&]R>0!3:&]P<&EN9P!3
M:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@06QL`%-H;W<@0V]N=&%C=',`4VAO
M=R!,:7-T<P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3
M:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3
M:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3
M;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO
M;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T($1I<F5C=&EO
M;@!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5R8V5S
M`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U
M=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A
M8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-P96-I9GD@=VAE<F4@>6]U('=A;G0@
M861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R+@!3<&QI="!C96QL
M`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N
M9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR
M;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<P!3='EL92!;0U-370!3=0!3=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C
M8V5S<P!3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,`4W5C8V5S<V9U;&QY
M(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E
M<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U
M;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3
M=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`
M4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II
M;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C
M:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FUS
M`%135@!44U8@9FEL90!486(@<V5P87)A=&5D('9A;'5E<P!486)L90!486)L
M92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!4
M96UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@
M`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@
M86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N
M:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC
M93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&1R97-S(&)O
M;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,`5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T
M=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!C;VYT86-T('EO=2!R97%U97-T
M960@9&]E<R!N;W0@97AI<W0N`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E
M(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A
M9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S
M('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@
M<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN
M9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S
M<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@
M<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S
M97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@
M66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F
M(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H
M97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L
M:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A
M<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@
M)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D
M+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@
M;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L(&UO9'5L
M92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA
M<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE
M('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@
M86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO
M="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI
M<W0N`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED
M92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P
M<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+@!4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@;F\@
M=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L
M92!A9&1R97-S(&)O;VMS(&%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T
M;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI
M<R!I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BX`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A8W0N($-O
M;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F;W(@9G5R=&AE<B!H
M96QP+@!4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@;V)J96-T+@!4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R
M97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E
M;G1R>3H@)7,`5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II
M<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W
M87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@
M96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W
M+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I
M96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@
M9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!F;W)M
M870@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E
M96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA
M8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@
M8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET
M=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O
M=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('!E
M<G-O;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R97-S(&)O
M;VL`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@
M9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`
M5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T
M(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC
M:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE
M8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4
M;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4
M;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W
M`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN
M:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K
M97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N
M9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N
M5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S
M=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL
M92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T
M92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O
M(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S
M+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R
M86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I
M(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E
M<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D
M`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@
M2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E
M(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T
M90!5<&1A=&4@)7,`57!D871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E
M9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O
M;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!
M9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92X`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@
M=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E
M<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE
M>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@
M:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<FES:6=N($1I<F5C=&]R>0!6
M97)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A
M;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA
M;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@0V]N=&%C=`!6:65W(&%N(&5X
M=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!T;R!D:7-P;&%Y(&)Y
M(&1E9F%U;'0Z`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`
M5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A
M=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E8G-I=&4@55),`%=E96ML>0!796QC
M;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X
M-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED
M=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T
M:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R
M;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O
M<FL`5V]R:R!!9&1R97-S`%=O<FL@0VET>0!7;W)K($-O=6YT<GD`5V]R:R!0
M:&]N90!7;W)K(%!O<W1A;"!#;V1E`%=O<FL@4W1A=&4O4')O=FEN8V4`5V]R
M:R!3=')E970@061D<F5S<P!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`
M665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V
M92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="X`66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E
M;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@
M)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG
M=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E
M('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@
M<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@
M8F]O:RX`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N`%EO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L
M96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R
M9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@
M;VYL>2!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO
M;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S
M:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`
M6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT
M70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%MN;R!V
M86QU95T`7T%D;6EN:7-T<F%T:6]N`%]"<F]W<V4`7T-,20!?1&%T851R964`
M7T1E;&5T90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P
M97)T:65S+BXN`%]);7!O<G0O17AP;W)T`%],;V<@:6X`7TQO9R!O=70`7TUO
M9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI
M;FLN+BX`7U)E;6]V92!F<F]M('1H:7,@;&ES=`!?4V5A<F-H`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&-A;&5N
M9&%R`&-A;&T`8VQI8VL@:&5R90!C;VYT86-T+G9C9@!C;VYT86-T<RYC<W8`
M8V]N=&%C=',N='-V`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S`&@Z`&EM;65D:6%T90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE
M;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE
M;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10
M`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@
M8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`
M=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!4=7)B82TR+C`N,@I2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,#(M,3`@,#(Z,#@K,#$P,`I,87-T+51R86YS;&%T
M;W(Z($%U=&]M871I8V%L;'D@9V5N97)A=&5D"DQA;F=U86=E+51E86TZ(&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TY"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L
M<STQ.R!P;'5R86P],#L*`"`H)7,@9_QN(/9N8V4I`"A%<FG^:6T@06YA:'1A
M<OT@)7,I`"`H)7,@9_QN9&4I`"`H8G5G_&XI`"`H>6%R_6XI`"`H9/QN*0`@
M9&4H9&$I(``B060@4V]Y860B("C6<BX@06QI(%G];&UA>BD`(E-O>6%D+"!!
M9"(@*-9R+B!9_6QM87HL($%L:2D`)60@)7,@=F4@)7,`)60M9_QN;/QK(&AA
M=F$@=&%H;6EN:0`E<R`M($)I;&1I<FEM`"5S(%!A<FUA:R#=>FD`)7,@2T(`
M)7,@0F%K_6T@W?YL96UL97)I("T@3VYA>6QA;6$`)7,@07EA<FQA<@`E<R!'
M:7)I_@`E<R!!;FQA_FUA($MO_G5L;&%R_0`E<R!E:VQE;F1I`"5S('IA=&5N
M('9A<BX`)7,@9&4@)7,@)7,`)7,@9&]S>6%S_2!B8?YA<OUY;&$@*&GG97)I
M*2!A:W1A<OUL9/T`)7,@:7-T96YM96MT961I<BX`)7,@9&%K:6MA`"5S(&)U
M;'5N86UA9/TN`"5S(&EL92`E<RP@=&]P;&%M("5S`"5S(%1A:W9I;0`E<R!.
M;W0@1&5F=&5R:0`E<R!']G)E=B!,:7-T97-I`"5S.B`E<P`L(&;]<G3];F%L
M_2`E<R`E<P`L(&1E\&G^:6T@)7,@+3X@)7,`+2T@4V7G("TM`#$R(%-A871L
M:6L@6F%M86X@0FGG:6UI`#(T(%-A871L:6L@6F%M86X@0FGG:6UI`#(T('-A
M870`:49R86UE<R!D97-T96ML97EE;B!B:7(@=&%R87G]8_T@9V5R96MM96MT
M961I<@!"=2#V8F5K(&GG:6X@=F5R:71A8F%N_2!S;VX@=7IA;G3]<_T@9V5R
M96MM96MT961I<BX`3VYU;&UA>B!B:7(@:&%T82!O;'7^='4`W6QE=&EY:2#^
M:69R96QE>65B:6QM96L@:>=I;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E:VUE
M:W1E9&ER+@#=;7IA;&%N;?W^(&EL971I>6D@9&_P<G5L=?!U;G4@<V'P;&%M
M86L@:>=I;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E:VUE:W1E9&ER+@#=;&5T
M:6YI;B#^:69R97-I;FD@Y_9Z;65K(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL
M]GIE;"!01U`@86YA:'1A<OT@=F4@9V7G:?X@=/QM8V5C:?!I(&=E<F5K;65K
M=&5D:7(N`-UL971I>6D@:6UZ86QA;6%K(&GG:6X@8>?]:R!01U`@86YA:'1A
M<OTL]GIE;"!01U`@86YA:'1A<OT@=F4@9V7G:?X@=/QM8V5C:?!I(&=E<F5K
M;65K=&5D:7(N`-UL971I;FEN(/YI9G)E<VEN:2#G]GIM96L@:>=I;B!AY_UK
M(%,O34E-12!A;F%H=&%R_2P@]GIE;"!3+TU)344@86YA:'1A<OT@=F4@9V7G
M:?X@=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N`-UL971I>6D@:6UZ86QA;6%K
M(&GG:6X@8>?]:R!3+TU)344@86YA:'1A<OTL(/9Z96P@4R]-24U%(&%N86AT
M87+]('9E(&=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=;&5T:7EI
M(/YI9G)E;&5Y96)I;&UE:R!IYVEN(&'G_6L@4TU)344@86YA:'1A<OT@9V5R
M96MM96MT961I<BX`UM8@66'P;75R`-;6(%-A\&YA:P#6UB!(869I9B!+87(`
MUM8OUE,`05!)($E$`$3\>F5N;&5Y:6-I(&AA:VO];F1A`$AA:VO];F1A+BXN
M+@!9=6MA<OT@87)A;6$@9F]R;74`16YA;'0`3W)T87EA`%9&4R!D:7II;FD@
M>6%R873]<FME;B!E<FG^:6T@96YG96QL96YD:2X`5D93(&1I>FEN:2!Y87)A
M=/UL_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN`$AE<V%P(%!A<F%L;W/]`$AE
M<V%P($1O;F1U<G5L9'4N`$AE<V%P;&%N_7EO<@!%:VQE`$%L="!'<G5P($5+
M;&4`06QT(-UZ:6X@14ML90!"=7)A>6$@16ML93H`665N:2!'<G5P($5K;&4`
M665N:2#=>FEN($5K;&4`665N:2!K=6QL86[]8_T@96ML93H`2V]L;VX@96ML
M90!996YI(/QY92!E:VQE`-UK:6QI($5K;&4`)7,@365N_'/\;OP@36]Z:6QL
M82!+96YA<B#'=6)U\'4@3VQA<F%K($5K;&4`16ML90!!9')E<R!D969T97)I
M;F4@96ML93H`061R97,@9&5F=&5R:6UE(&5K;&4`2W5L;&%N_6/]($5K;&4`
M2W5L;&%N_6/](&5K;&5M92!S9>=I;&5M97H@:_UL_6YD_2X`061R97,`061R
M97,@1&5F=&5R:2!,:7-T96QE;64`061R97,@9&5F=&5R:2!K87ED_0!!9')E
M<R!D969T97)I(&)A_F%R_7EL82!B;_YA;'3];&3]+@!9]FYE=&EM+2U$:?!E
M<B!K=6QL86[];&%R(&GG:6X@:7II;FQE<FD@8F5L:7)L97EI;@!9]FYE=&EM
M`$%D<P!'96QI_FUI_B!!<F%M80!!9F=A;FES=&%N`$%R;F%V=71L=6L`0V5Z
M87EI<@#6=&5K:2!!9`!(:7IA;&$`2&EZ86QA;6%K.@!4_&W\`%3\;2!$;_!R
M=6QA;FW]_B!+=6QL86[]8_UL87(`5/QM($=R=7!L87(`5/QM(-UZ:6YL97(`
M5/QM(&3V<G0@>?QZ`,=O:VQU(&%D<F5S;&5R92!I>FEN('9E<@!3_7)A;&%N
M;?W^(&QI<W1E('3\<OQN_"!A>6%R;&%M87EA(&EZ:6X@=F5R:6QS:6X@;6D_
M`%IA=&5N(%9A<@!:871E;B!V87(`UG1E:VD@24U34"!':7)I_FD`UG1E:VD@
M24U34"!087)O;&%S_0#6=&5K:2!)35-0($MU;&QA;OUC_2!!9/T`UG1E:VD@
M96QE:W1R;VYI:R!P;W-T82!A9')E<VD`UG1E:VD@=&%S;&%K;&%R`-9T96MI
M(&UE=&EN.@!!;65R:6MA;B!386UO80!'9>=E<G-I>B!D9?!E<B!B96QI<G1I
M;&1I+@!!;F1O<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;2!0<F]X>0!#979A
M<`!!;G1A<G1I:V$`06YT:6=U82!V92!"87)B=61A`%5Y9W5L86UA`%5Y9W5L
M86UA($QI<W1E<VD`57EG=6QA;6$@2&%Z_7(`06QT('!A>6QA_OUM;&%R82!U
M>6=U;&$`3VYA>6QA`%EA:VQA_OUK($)O>75T`$YI<V%N`$%R87#G82`H5VEN
M9&]W<RTQ,C4V*0!"96QG96QI:R!$;W-Y82!"=7EU='4`0F5L9V5L:6L@063]
M`"5S('-I;&UE:R!I<W1E9&GP:6YI>F1E;B!E;6EN(&UI<VEN:7H_`%-EYVEL
M96X@9VER:?YL97)I('-I;&UE:R!I<W1E9&GP:6YI>F1E;B!E;6EN(&UI<VEN
M:7H_`"5S(&GG:6X@9VER:?X@:7-T9?!I;FD@:V%L9/UR;6%K(&ES=&5D:?!I
M;GIE(&5M:6X@;6ES:6YI>C\`07)J86YT:6X`17)M96YI<W1A;@!%<FUE;FEC
M92`H05)-4T-)22TX*0!386YA=`!!<G5B80!!<G1A;@!!<V-E;G-I;VX@061A
M;&%R_0!!<V-I:2!386YA=/T`07-Y82]087-I9FEK($+V;&=E<VD`0F%K_6T@
M:?YL96UL97)I;F1E;B#V;F-E(&1O\')U;&%M82!S;W)U;'-U;B!M=3\`071A
M;6$@2V]L;VYL87+]`%9A<B!O;&UA>6%N(&)I<B!G<G5B=2!S:6QM92!G:7)I
M_FEM:2X`5F%R(&]L;6%Y86X@8FER(&EZ;FD@<VEL;64@9VER:?YI;6DN`%9A
M<B!O;&UA>6%N(&)I<B!G<G5B=2!D_'IE;FQE;64@9VER:?YI;6DN`%9A<B!O
M;&UA>6%N(&)I<B!P87EL8?[];?T@9/QZ96YL96UE(&=I<FG^:6UI+@#6>FYI
M=&5L:6ML97(`0?!U<W1O<P!!=G5S='5R86QY80!!=G5S='5R>6$`075T:%]C
M>7)S<6PZ(-US=&5N96X@:6UA<"!U>F%T873]<_T@8G5L=6YA;6%D_2X`075T
M:%]C>7)U<SH@W7-T96YE;B!Y971E;F5K;&5R92!S86AI<"!D9?!I;"X`075T
M:%]C>7)U<SH@W7-T96YE;B!I;6%P('5Z86YT_7/](&)U;'5N86UA9/TN`$%U
M=&A?9G1P.B#=<W1E;F5N($944"!U>F%N=/US_2!B=6QU;F%M863]+B!02%`G
M>6D@+2UE;F%B;&4M9G1P('-W:71C:"!D9?!I_G1I<F=E<VEY;&4@9&5R;&5Y
M:6XN`$%U=&A?:6UA<#H@W7-T96YE;B!)34%0('5Z86YT_7/](&)U;'5N86UA
M9/TN`$%U=&A?:W)B-3H@W7-T96YE;B!K<F(U('5Z86YT_7/](&)U;'5N86UA
M9/TN`$%U=&A?;&1A<#H@W7-T96YE;B!,1$%0('5Z86YT_7/](&)U;'5N86UA
M9/TN`$%U=&A?:6UA<#H@)7,@:W5L;&%N_6/]<_T@96ML96YE;65D:2X@4W5N
M=6-U.B``075T:%]L9&%P.B`E<R!K=6QL86[]8_US_2!S:6QI;F5M961I`$%U
M=&A?;&1A<#H@)7,@:W5L;&%N_6/]<_T@9_QN8V5L;&5N96UE9&D`075T:%]M
M8V%L.B#=<W1E;F5N($U#04P@=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]S
M;6)A=71H.B#=<W1E;F5N('-M8F%U=&@@=7IA;G3]<_T@8G5L=6YA;6%D_2X`
M1&_P<G5L86UA(&)A_F%R_7/]>B!O;&1U+@!$;_!R=6QA;6$@8F'^87+]<_UZ
M(&]L9'4N("5S`$1O\')U;&%M82!2041)55,@<W5N=6-U<W4@=&%R86;];F1A
M;B!G97)I(.=E=G)I;&1I+@!&5%`@<W5N=6-U<W5N82!D;_!R=6QA;6$@8F'^
M87+]<_UZ(&]L9'4N`$MU;&QA;OUL_7(@86QA;FQA<CH`07IE<F)A>6-A;@!"
M3T9(($'G_6ML86UA;&%R_0!!<G1A;&%N`$%R=&%L86X@4F5N9VD`2_9T_"!K
M97)B97)O<R!P87)O;&%S_2X`2_9T_"!K97)B97)O<R!K=6QL86[]8_T@863]
M+@!"86AA;6%L87(`0F%H<F5Y;@!"86QT_6L@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D9?X`0F%R8F%D;W,`5&%B86X@YVEZ9VES:0!"87-I="!!<F%M80!"97EA
M>B!2=7-Y80!"96SG:6MA`$)E;&EZ90!!_F'P_2!A<F%M82!F;W)M=0!"96YI
M;@!"97)M=61A`$)H=71A;@!"8?!L86YT_2!K=7)U;&%M863]("@E<RD@)7,`
M1&_P=6T@9_QN_`!5>6=U;&%M82`B)7,B('-A:&EP(&]L9'7P=2`B)7,B(/9B
M9?!I(&)U;'5N86UA9/TN`-9B96L@07EA<FQA<OT`UF)E:R!4_'+\`$MO>74`
M0F]L:79Y80!997(@W6UL97)I`%/];OUR`%/];OUR($MA;/UN;/WP_3H`4_UN
M_7)L87(`0F]S;F$@2&5R<V5K`$AE<B!):VES:0!";W1S=F%N80!!;'0`0F]U
M=F5T($%D86QA<OT`0G)E>FEL>6$`0G)I=&%N>6$@2&EN="!/:WEA;G5S=2!"
M]FQG97-I`$)R=6YE:0!"=6QG87)I<W1A;@!-861D92#=;6QI($QI<W1E`$)U
M<FMI;F$@1F%S;P!"=7)U;F1I`-W^(%/];OUF_0!#35,`0U)3`$-23"!$8?#]
M=/UM($YO:W1A;&%R_0!#4U8`7TC\8W)E(-9Z96QL:6ML97)I+BXN`%1A:W9I
M;0!$=7)G=6X`2V%M8F_G>6$`2V%M97)U;@!087)O;&$@]GID979I;FEM;&D@
M;VQA<F%K('/]9OUR;&%N86UA;6%K=&%D_7(L(&S\=&9E;B!Y]FYE=&EC:6YI
M>FQE(&?V<OS^_&XN`$E-05`@<W5N=6-U<W5N82!B8?!L86[];&%D_3H@)7,`
M2V%N861A`-UP=&%L`%-O<G5N(%)A<&]R=6YU(-UP=&%L($5T`"(E<R(@9&]S
M>6%S_2!S:6QI;F5M961I+@!'9>=I8VD@9&EZ:6X@8G5L=6YA;6%D_2X`)W1A
M<F=E=$9I;&4G(&1E\&G^=&ER9V5S:2!O;&UA9&%N(&1E=F%M(&5D:6QE;65Z
M+@`B)7,B(&1I>FEN:2!K86QD_7+];&%M863]+@!+86QD_7+];&%M863]("PE
M9"!A;'0@>6%P_2!V87(N`%EE;FED96X@9/QZ96YL96UE9&DL('EE;FED96X@
M9/QZ96YL96UE(&GG:6X@<V'P;&%N86X@:V%Y_71L87+];B!S87G]<_T@:6QE
M(&1E<&]L86YM_?X@;VQA;FQA<OUN('-A>?US_2!E_FQE_FUE;65K=&5D:7(N
M`$)E;&ER=&EL;6G^(&YU;6%R87EA(&EL971I('GV;FQE;F1I<FEL96UE9&DN
M`$-A<&4@5F5R9&4`0F'^;/UK`$MA=&5G;W)I;&5R('9E($5T:6ME=&QE<@!#
M87EM86X@061A;&%R_0!#97`@5&5L969O;G4`2/QC<F4@UGIE;&QI:VQE<FD`
M2/QC<F4@>6%S=/UK;&%M87/].@!(_&-R92#6>F5L;&EK;&5R:0!(_&-R92!"
M;_YL=6ML87+].@!#97`@5&5L969O;G4`2V5L=&EK("A)4T\M.#@U.2TQ-"D`
M3W)T80!/<G1A($%F<FEK82!#=6UH=7)I>65T:0!/<G1A($%V<G5P82`H25-/
M+3@X-3DM,BD`3VYA>2!"96QG97-I($%Y<OUN=/UL87+]`$]N87D@0F5L9V5S
M:2!+=7)A;&QA<OT`QV%D`$1E\&G^=&ER`-UN<V%N;&%R_6X@<VEZ9&5N(&=E
M;&5N(&5L96MT<F]N:6L@<&]S=&%L87+](&]K=7)K96X@=F4@8V5V87!L87)K
M96X@9_9R9/QK;&5R:2!A9"!V92!A9')E<VEN:7II(&1E\&G^=&ER:6XN`$MA
M<F%K=&5R`$)A\&QA;G3]>?T@1&5?;F5T;&4N+BX`5/QM_%]N_"#=_F%R971L
M92_=_F%R971L96UE`-YI;&D`QVEN`$)A<VET;&7^=&ER:6QM:?X@QVEN8V4@
M*$=",C,Q,BD`1V5L96YE:W-E;"#':6YC92`H0FEG-2D`4&%R;VQA('-EYVEN
M`$MU;&QA;OUC_2!A9/T@<V7G:6X`0FER(&%D<F5S(&1E9G1E<FD@<V7G:6X`
M5&%R:6AL97)I;B!N87/];"!G]G-T97)I;&5C9?!I;FD@<V7G:6XZ`$QI<W1E
M($)IYV5M(%3\<OQN_"!39>=I;B`H<_UR86QA;FW]_B!L:7-T96QE<B!IYVEN
M*0!#:')I<W1M87,@061A;&%S_0!3_6[]9B!T86[];?T@8G5L=6YA;6%D_3HE
M<P!496UI>FQE`$U33V9F:6-E(&)IYVEM(&EM;&5R:6YI('1E;6EZ;&4`2W5L
M;&%N_6/]>?T@=&5M:7IL93H@)7,`2W5L;&%N_6/]('1E;6EZ;&4`2W5L;&%N
M_6/]('9E<FES:2!T96UI>FQE`$1E=F%M(&5T;65K(&GG:6X@=/UK;&%Y_6X`
M2%144"!Y;VQU>6QA($-L:6-K871E;&P`4&5N8V5R97EI($MA<&%T`$)U;'5T
M;&%R`$)U;'5T;'4`0V]C;W,@061A;&%R_0!+96YA<B#'=6)U\'5N=2!$87)A
M;'0`1&%R86QT_6QM_?X@4_UN_7)L87(`2V]L;VUB:7EA`%)E;FL`4F5N:R!3
M9>=I8VD`4F5N:R!39>=I;6D`2V]L;VYL87(Z`$MO;&]N(%-EYV5N96ML97)I
M`$MO;&]N($)A_FS]:VQA<OT`2V]M:6L`5FER9_QL(&EL92!A>7+];&W]_B!D
M9?!E<FQE<@!6:7)G_&P@:6QE(&%Y<OUL;?W^(&1E\&5R;&5R("A-:6-R;W-O
M9G0@3W5T;&]O:RD`2V]M=70`2V]M=70@2V%B=?!U`$'G_6ML86UA`$]R=&%K
M($%D_0!#;VUO<F]S`$9I<FUA`$9I<FUA($%D<F5S:0!":6QG:7-A>6%R;&%R
M`$MO_G5L;&%R`%EA</UL86YD_7)M82!&87)K;&%R_0!987#];&%N9/UR.B5S
M`%!A<F%L;WG]($1O\')U;&$`2V]N9V\`1&5M;VMR871I:R!+;VYG;R!#=6UH
M=7)I>65T:0!"8?!L86YT_2!B8?YA<OUS_7H@;VQD=2X`0F'P;&%N=/T@8F'^
M87+]<_UZ(&]L9'4Z`$)A\&QA;G3](&)A_F%R_7/]>CH@)7,`0F'P;&%N=/T@
M8F'^87+]<_UZ`$'G_6L@86YA:'1A<B!S=6YU8W5S=6YA(&)A\&QA;G3](')E
M9&1E9&EL9&DN`$'G_6L@86YA:'1A<B!S=6YU8W5S=6YA(&)A\&QA;G3](')E
M9&1E9&EL9&DN(%-E8F5B.B`E<R`H)7,I`$944"!S=6YU8W5N82!B8?!L86YT
M_2!B8?YA<OUS_7H@;VQD=2X`W6QE=&G^:6T@;F]K=&%S_2!L:7-T961E;B!S
M:6QI;F1I+@!,:7-T961E:VD@:6QE=&G^:6T@;F]K=&%L87+].B`E<P#=;&5T
M:?YI;2!N;VMT86QA<OT@8F'^87+]>6QA(&%D<F5S(&1E9G1E<FEN:7IE(&5K
M;&5N9&DN`$1E=F%M`$-O;VL@061A;&%R_0#'97)E>@!+;W!Y86QA`%-EYVEM
M:2!+;W!Y86QA`$MO<W1A(%)I:V$`0V]T92!D)TEV;VER90#=;&5T:2!01U`@
M:6QE(/YI9G)E;&5N96UE9&DN`-UL971I(%!'4"!I;&4@:6UZ86QA;F%M863]
M+@#=;&5T:2!3+TU)344@:6QE('-I9G)E;&5N96UE9&DN`-UL971I(%,O34E-
M12!I;&4@:6UZ86QA;F%M863]+@#=;&5T:?YI;2!N;VMT87/](&5K;&5N96UE
M9&DN("5S`$Q$05`@<W5N=6-U<W5N82!B8?!L86[];&%M863]+@!"86MI>64@
M9&5N971L96YE;65D:2X@)7,`1&'P_73];2!L:7-T97-I('EA<F%T_6QA;6%D
M_2X@)7,`4$=0('9E<FES:6YI;B#^:69R97-I(.?V>OQL96UE9&DN`%,O34E-
M12!V97)I<VEN:6X@_FEF<F5S:2#G]GK\;&5M961I+@#=;&5T:?YI;2!N;VMT
M87/]('-I;&EN96UE9&DN("5S`$1A\/UT_6T@;&ES=&5S:2!S:6QI;F5M961I
M+B`E<P!!;/UC_6[];B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!B96QI<FQE
M;F5M961I+@!!9')E<R!D969T97)I('1A;6%M96X@9V5T:7)I;&5M961I+@!$
M8?#]=/UM(&QI<W1E<VD@=&%M86UE;B!G971I<FEL96UE9&DN`$1A\/UT_6T@
M;&ES=&5L97)I;FEN(&QI<W1E<VD@=&%M86UE;B!G971I<FQE;65D:2X`06YA
M:'1A<B!S=6YU8W5S=6YD86X@8>?]:R!A;F%H=&%R(&5D:6YI;&5M961I+@`E
M<R!AY_UL86UA9/TN`$UA:6YT96YA;F-E7U1A<VL@8FER:6UI("5S(&'G_6QA
M;6%D_2X`)7,@;VMU;F%M863]+@#=<W1E;F5N(&MU;&QA;F/](&GG:6X@<&%R
M;VQA('/]9OUR;&%N86UA9/TN($)A>OT@>6%D82!T_&T@87ER_6YT_6QA<B!D
M;_!R=2!D9?!I;"X@665N:61E;B!D96YE>6EN('EA9&$@9&%H82!F87IL82!Y
M87)D_6T@:>=I;B!S:7-T96T@>?9N971I;FEZ;&4@9_9R_/[\;BX`04-,(&5R
M:?YI;&5M961I+@!!9')E<R!D969T97)I;F4@97)I_FEL96UE9&DN("5S`$1A
M\/UT_6T@;&ES=&5S:6YE(&5R:?YI;&5M961I+B`E<P!$8?#]=/UM(&QI<W1E
M;&5R:6YE(&5R:?YI;&5M961I+B`E<P!3=6YU8W5N=6X@>65T96YE:VQE<FEN
M92!E<FG^:6QE;65D:2X`66%P_6QA;F3]<FUA(&=E<FD@9/9N9/QR_&QE;65D
M:2XN`"5S('EA</UL86YD_7)M82!K87ED961I;&5M961I+@!9961E:R!B:7(@
M>6%P_6QA;F3]<FUA(&MA>61E9&EL96UE9&DN`%EE9&5K(&)I<B!Y87#];&%N
M9/UR;6$@:V%Y9&5D:6QE;65D:3H@)7,`665D96L@>6%P_6QA;F3]<FUA(&1O
M<WEA<_T@)7,@:V%Y9&5D:6QE;65D:2X`66%P_6QA;F3]<FUA(&1O<WEA<_T@
M)7,@:V%Y9&5D:6QE;65D:2X@0G4@9'5R=6UD82P@:V]D=2!T96MR87(@)7,@
M:>=I;F4@:V%Y9&5T;65K('EA9&$@=&%K:7`@961E;B!K;V1U(&5L(&EL92`E
M<R!IYVEN92!K;W!Y86QA;6%K+"!S9>=E;F5K;&5R:6YI(&MU;&QA;F%B:6QI
M<G-I;FEZ+@!,1$%0('-U;G5C=7-U(&%R86YA;6%D_2X`W6QE=&G^:6T@;F]K
M=&%S_2!G_&YC96QL96YE;65D:2X@)7,`1&'P_73];2!L:7-T97-I(&?\;F-E
M;&QE;F5M961I+B`E<P!-;WII;&QA(&ME;F%R(.=U8G7P=2!B=6QU;F%M863]
M+B!+96YA<B#G=6)U\'5N=6X@8>?]:R!O;&1U\'5N9&%N(&5M:6X@;VQU;BX`
M4V%Y_6QM_?X@;65T:6X`W&QK90!$97)S;&5R`$)A\&QA;G3]('EA<F%T`%EE
M;FD@66%R870`06QT(&1I>FEN('EA<F%T`$]L=?YT=7)U;&1U`%EA<F%T_6/]
M(-UZ:6YL97)I`$MR961I(&MA<G0@;G5M87)A<_T`2/UR=F%T:7-T86X`2_QB
M80#>=2!!;F1A:VD@6F%M86X`WG4@86YD86MI(%523`#>=2!!;F1A:VD@2&%V
M82!$=7)U;74`WG4@06YD86MI(-YA<G1L87(Z`%G\<OQR;/QK=&5K:2!S:71I
M;``E<R!E(&=I<FG^=&4@YV%L_?YA8V%K(&?V<F5V;&5R:2!K:?YI<V5L;&7^
M=&ER:6X`2V5S`-YEYVEL:2!O;&%N;&%R_2!K97,`2_UB<OUS`$MI<FEL("A+
M3TDX+5(I`$MI<FEL("A7:6YD;W=S+3$R-3$I`$MI<FEL+U5K<F%Y;F$@*$M/
M23@M52D`QV5K($-U;6AU<FEY971I`$='`$?\;FS\:P!697)I($'P86/](%1A
M<F%Y_6/]<_T`5&%R:6@`1V5L:?X@5&%R:6AI`%1A<FEH(%-EYVEM:0!'_&X`
M2U]O;&]N=2!3:6P`07)A;/UK`$]N9&%L_6L@<V%Y_6QA<@!':7)I;G1I>6D@
M07IA;'0`UFX@=&%N_6UL_0#6;B!486[];6S](%)E;FL`UFX@5&%N_6UL_2!+
M:6UL:6L`UFYT86[];6S]('/]<F%L86UA('GV;OPZ`%1A;OUM;&%R`%-I;`!3
M:6QM92!/;F%Y_0!'<G5P(%-I;`#=>FEN(%-I;`#=;&5T:6QE<FD@<VEL('9E
M('1E;6EZ;&4`4VEL;64@9/SP;65S:2!D879R86[]_OT`2/QC<F4@4VEL`$MO
M;&]N(%-I;`!687)O;&%N(/9T96MI('1A<VQA\/T@<VEL`%-I;&UE(&)A_F%R
M_7/]>CH@*"5S*2`E<P!3873]<OT@<VEL`%-EYVEL;6G^(&MI;6QI\&D@<VEL
M`-YU(&%N9&%K:2!K;VQO;G4@<VEL`-YU(&%N9&%K:2!S873]<OT@<VEL`%-I
M;&UE(&)A_F%R_7/]>@!497-L:6T@>F%M86[]`$1A;FEM87)K80!"]FS\;0!!
M>F%L86X`4V]R=6YU(%1A;OUM;&%Y_6X`07ER_6YT_6QA<B`H07EN_2!Z86UA
M;F1A($AO<F1E)W5N(&?\;FS\:R!D;W-Y87/];OUN(&GG:6YD92DZ`$%Y<OUN
M=/UL87(@>?9N971I8VD@:>=I;B!G_&YL_&L@;VQA<F%K(&MA>61E9&EL9&DN
M`$=E;&G^:6T`3F5M($UI:W1A<OT`4V]N('-A871T96MI(&YE;2!M:6MT87+]
M.B``3F5M(&UI:W1A<OTZ(`!3;VQD86X@<V'P82!Y]FYL_`!38?!D86X@<V]L
M82!Y]FYL_`!$:7II;@`R-"!S86%T;&EK('IA;6%N(&W](&?V<W1E<FEL<VEN
M/P!']G+\;OQM(%-EYV5N96ML97)I`$AA=F$@=&%H;6EN:6YI(&?V<OQN=/QL
M92`H5$%&*0!']G+\;G3\;&5M92!":>=I;6D`1/QZ96X@0FEL9&ER:6UI`$-I
M8G5T:0!3:6QM97EI;@!M86EN=&5N86YC92YP:'`@9&]S>6%S_6YA(&1O\')U
M9&%N(&5R:?YM97EI;BX`1VER:?YL97)I('-I;&UE>6D@;VYA>6QA;6%K(&ES
M=&EY;W(@;75S=6YU>C\`W6QK('-A=/UR(&%L86X@861L87+];OT@:>=E<FEY
M;W(@;74_($5V970@:7-E(&)U(&MU='5Y=2!S9>=I;CH`1&]M:6YI:P!$;VUI
M;FEK($-U;6AU<FEY971I`"5S(-UN9&ER`$]L=?YT=7)U;&%N('EA</UL86YD
M_7)M87G](%!(4"!B971I\&D@;VQA<F%K(&EN9&ER+@!V0V%R9"!I;F1I<@!!
M_F'P_2!AY_UL_7(@;&ES=&4`W6QAYVQA<@!%+5!O<W1A`$524@!%:W9A=&]R
M`$3\>F5N;&4`0FQO:R!$_'IE;FQE`$=R=7`@1/QZ96YL90#=>FEN($3\>F5N
M;&4`W7II;FQE<FD@1/QZ96YL90`E<R#=YVEN(-UZ:6YL97)I($3\>F5N;&4`
M)7,@9VER:?YI;FD@9/QZ96YL90!39>=E;F5K;&5R:2!D_'IE;FQE.@`E<R!I
MYVEN(&EZ:6YL97)I(&3\>F5N;&4`1?!I=&EM`$W]<_UR`$5L(%-A;'9A9&]R
M`-;P92XN+@!%;0!%+7!O<W1A`$5L96MT<F]N:6L@4&]S=&$@061R97-I`$5L
M96MT<F]N:6L@<&]S=&$@87-R97-L97)I(&7^;&7^;65L:2X`3VYA>6S](&5L
M96MT<F]N:6L@<&]S=&$`1'5Y9W4@<VEM9V5R;&5R:0!";_X@:6QE=&DN`$)O
M_B!S;VYUYRX`0F_^(&%R86UA('1E<FEM;&5R:0!&;W1O\')A9B!'86QE<FES
M:6YD96X@;65T:6YL97)I;B!IYV5R:7-I;F4@9_9R_&YT_"!E:VQE;64@971K
M:6YL9?YT:7)I;'-I;B!M:3\`4V'P('3]:R!IYV5R:6L@;65N_'/\(&5T:VEN
M;&7^=&ER:6QS:6X@;6D_`$)I=&G^('G];/T`1/QZ96YL97EI8VEY:2!'96YI
M_FQE=`!087)O;&%N_7K]('/]9OUR;&%M86L@:7-T961I\&EN:7ID92!S;W)U
M;&UA:R#\>F5R92!B:7(@9_QV96YL:6L@<V]R=7-U(&=I<FEN+"#6<BX@)T5V
M8VEL(&AA>79A;OUN_7K];B!A9/T@;F5D:7(_)SH`1_9R_&YT_"!A9')E<VEN
M:2!B=7)A>6$@9VER:6X`)7,@:V%Y9'4@9_QN8V5L;&5N9&DN`$5K=F%T;W(@
M1VEN97-I`$5R:71R90!(871A`$5L971R;VYI:R!P;W-T82!D]FYD97)M961E
M(&AA=&$N`$5S=&]N>6$`171I>6]P>6$`171N:6L`079R=7!A`$AE<B`Q-2!D
M86MI:V$`2&5R(#(@9&%K:6MA`$AE<B`S,"!S86YI>64`2&5R(#4@9&%K:6MA
M`$AE<B!':7)I_G1E`$AE<B!Y87+];2!S86%T`$AE<B!D86MI:V$`UG)N96L@
M9&7P97)L97(Z`,=A;/W^=/UR`$=E;FG^;&5T`$ME;F%R(,=U8G7P=6YU($=E
M;FG^;&5T`"<I)R!"96ML96YI>6]R`%-A9&4@:V5L:6UE('9E>6$@86S];G3]
M(&%R86UA('1E<FEM:2!B96ML96YI>6]R`$=EYV5R;&EL:6L@4V]N(%1A<FEH
M:0#<<W0`1/W^87+]($%K=&%R`$%D<F5S($1E9G1E<FEN:2!$_?YA<OT@06MT
M87(`4V%D96-E('-EYVEL96X@:6QE=&G^:6T@;F]K=&%L87+];OT@9/W^87+]
M(&%K=&%R+@!"=2!A9')E<R!D969T97)I;FD@=/QM_'EL92!D_?YA<OT@86MT
M87(N`-9N($%L86X@4F5N9VD`07EA<FQA<B!IYVEN($944"!Y_&ML96UE<VD`
M5&5R8VEH;&5R:6X@9V5T:6QM97-I(&)A_F%R_7/]>BX`061R97,@9&5F=&5R
M:6YE(&5R:?YI;2!B8?YA<OUS_7HZ("5S`"5S(&D@)7,@92!E:VQE;64@8F'^
M87+]<_UZ.B`E<P!,:7-T92!G]G+\;G3\;&5M92!B8?YA<OUS_7H`1&EZ:6X@
M9_9R_&YT_&QE;64@8F'^87+]<_UZ`-US:6T@9&7P:?YT:7)M92!B8?YA<OUS
M_7HZ("@E<RD@)7,[($5S:VD@1$X@/2`E<RP@665N:2!$3B`]("5S+"!+]FL@
M/2`E<P!,1$%0('-U;G5C=7-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ+@!334(@
M<W5N=6-U<W5N82!B8?!L86YT_2!B8?YA<OUS_7HN`"(E<R(@:V]N=6UU;F1A
M;B!K;W!Y86QA;6$@8F'^87+]<_UZ+@`B)7,B(&MO;G5M=6YA(&MO<'EA;&%M
M82!B8?YA<OUS_7HN`%EE;FD@4T%33"!B8?!L86YT_7/](&]L=?YT=7)U;&%M
M863]+@!%:VQE;F5C96L@;F5S;F4@8G5L=6YA;6%D_3H@)7,`(B5S(B!K;VYU
M;75N82!T8?[];6$@8F'^87+]<_UZ+@!$:7II;B!A<F%M82!B8?YA<OUS_7HZ
M("5S`%5Y9W5N($AA=F$`1F%L:VQA;F0@061A;&%R_2`H36%L=FEN82D`1F%R
M;V4@061A;&%R_0!/;G5L;6%Z($AA=&$Z`$9A:W,`WG5B870`2&ES<V5D:6QI
M>6]R`$AI<W-E9&EL:7EO<CH@`$AA9FEF(%-A\&%N86L`2&%F:68@2V%R(%-A
M\&%N8?#]`$%L86X@;6%T<FES:0!&:6II`$1O<WEA(%-A>?US_3H@)7,@9&]S
M>6$`1&]S>6$@4V%Y_7/].B`E<R!D;W-Y80!$;W-Y82!9]FYE=&EC:7-I`$1O
M<WEA($%D_0!$;W-Y82!S9>=I;6D`1&]S>6$@>?QK;&5M90!$;W-Y82!Y_&ML
M96UE(&1E<W1E:VQE;FUI>6]R+@!3_'IG9>=L97(`0G5L`$9I;FQA;F1I>6$`
MW6QK(%EA<OT`060`W6QK(,=E>7)E:P!/<F%N_2!S86)I=&QE`,=E=FER`$MA
M>6%N`%-I<P`E<R!D:7II;FD@>6]K`%EA>OT@4F5N9VD`665M96L`1_9R_&YT
M_&QE<FD@9&5S=&5K;&5M97EE;B!T87)A>?UC_6QA<B!IYVEN`%1A:&UI;B`H
M5$%&*0!486AM:6X@1_QN;&5R:2`H3F]T.B!'97)I(&3V;OQL96-E:VQE<B!H
M96T@9_QN(&AE;2!G96-E(&]L87)A:R!D]F[\;&5C96L[("EB_'G\:R!B:7(@
M<V%Y_2!G96YI_B!B:7(@]F)E:VQE('-O;G7G;&%N86-A:W3]<BD`4&%R;VQA
M;OUZ_2!M_2!U;G1T=6YU>C\`1F]R;6QA<@!$97EI_@!$97EI_B!T_'+\`$1E
M>6G^;&5R`$1E>6G^;&5R(#(`1F]R=6UL87(`6?9N;&5N9&ER;65L97(`0W4`
MQV5RYV5V96QE<@!&<F%N<V$`1G)A;G-A+"!-97)T;W!O;&ET86X`1G)E96)U
M<WD@061R97-I`$9R86YS_7H@1W5Y86YA<_T`1G)A;G/]>B!0;VQI;F5Z>6%S
M_0!&<F%N<_UZ($?\;F5Y($+V;&=E<VD`W>=I;F1E`$MI;61E;@!486T@0F5T
M:6UL96UE`$1O;'5N87D`0>?]:R!!9`!'86)O;@!']G+\;G3\;&5R:6X@86S]
M;F%C8?#](&=A;&5R:0!'86QE<FDZ`$=A;6)I>6$`)7,@66%P_6QA;F3]<FUA
M<_UN_2!/;'7^='5R`$]L=?YT=7)U;&%N($MO9`!'_')C:7-T86X`06QM86YY
M80!'86YA`$-E8F5L:71A<OUK`%9E<FEL96X@060`1V5N96P@061R97,@1&5F
M=&5R:0!':70`1V]E9&5L`$=O;V=L92!!<F%M80!3:7EA:"!"97EA>@!9=6YA
M;FES=&%N`%EU;F%N8V$@*$E33RTX.#4Y+3<I`$=R]FYL86YD`$=R96YA9&$`
M1W)U<`!'<G5P(%GV;F5T:6UI`$=R=7`@:7-I;6QE<FD@9&]L=2!O;&UA;/UD
M_7(`1W)U<&QA<@!'=6%D86QU<`!'=6%M`$=U871E;6%L80!'=65R;G-E>0!+
M;VYU:R#=>FEN;&5R:0!+;VYU:R!$969T97)I`$=I;F4`1W5I;F4@0FES<V%U
M`$=U>6%N80!(5$U,`$A434Q!<F5A('-A=/UR9&%K:2!S;VX@:/QC<F5Y:2!S
M:6QM97EI(')E9&1E9&EY;W(N`$A434Q!<F5A(.=I>F5L9V5D96MI('-O;B!K
M;VQO;G4@<VEL;65Y:2!R961D961I>6]R+@!(5$U,07)E82#G:7IE;&=E9&5K
M:2!S;VX@<V%T_7+]('-I;&UE>6D@<F5D9&5D:7EO<BX`2%144"!+:6UL:6L@
M1&5N971I;6D@8G5L86YA;6%D_2X`2&%I=&D`2&%S:"!!;&=O<FET;6%S_0!(
M869I9B!3:7,`0F'^;/UK`$AE87)D($%D87/]('9E($UC1&]N86QD($%D86QA
M<OT`W6)R86YI8V4@*$E33RTX.#4Y+3@M22D`6?QK<V5K;&EK`%EA<F3];0!$
M_'IE;FQE>6EC:2!K=6QL87)A:R!Y87)D_6T`66%R9/UM8_T`66%R_6O\<F4`
M1&]S>6%N_6X@8F'^;&%N9_UC_3H@`%G\:W-E:P!?06YA<V%Y9F$`5F%T:6MA
M;@!!;F%S87EF80!%=B!!9')E<VD`WF5H:7(`W&QK90#=_B!496QE9F]N=0!0
M;W-T82!+;V1U`$+V;&=E`$5V($%D<F5S:0!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z($)U(&UE<V%J(&GG:6YD92!G9>=E<G-I>B`E
M<R!834P@=F5R:7-I(&EL92!K87+^_6QA_OUL9/TZ("5S`$AO<F1E+TMO;&%B
M.B`E<R!N97-N97-I(&EL92!I;&=I;&D@8FER(&EL971I(&)U;'5N86UA9/T`
M2&]R9&4O2V]L86(Z("5S('3\<OQN9&4@:&GG(&)I<B!N97-N92`E<R!M97-A
M:OT@:>=I;F1E('EO:RX`2&]R9&4O2V]L86(Z("5S("(E<R(@8F'^87+](&EL
M92!S:6QI;F1I`$AO<F1E+TMO;&%B.B!"_'3\;FQE;64@;6]T;W)U("=D;VUX
M;6PG(%!(4"!U>F%N=/US_6YA(&EH=&EY8><@9'5Y;6%K=&%D_7(`2&]R9&4O
M2V]L86(Z("5S(&YE<VYE<VD@:>=I;B!Y96YI(%A-3"!A\&%C_2!O;'7^='5R
M=6QA;?UY;W(`2&]R9&4O2V]L86(Z(%-I;&EN96UE9&D@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z("5S('3\<OQN9&5K:2!K_7/];2!IYVEN($U)344@240@
M8G5L=6YA;6%D_0!(;W)D92]+;VQA8CH@1?YL96YE;65D:2`E<R`B)7,B.B`E
M<P!087EL8?[];6QA<B!E_FQE;F5M961I.B`E<P!":6QI;FUE>65N('!A>6QA
M_OUM("(E<R(`66%T87D@QVEZ9VD`66%T87D@>6%S=/UK;&%M80!9871A>3H`
M0G5R87EA(&YA<_UL(&=E;&1I;FEZ/R`H3/QT9F5N(')A<&]R(&5D:6XA*0!+
M8><@861E="!K;VQO;G4@8FER;&7^=&ER;65K(&ES=&EY;W)S=6YU>C\`2V'G
M(&%L86X@*&MO;&]N*2!V87(_`$MAYR!A9&5T('-A=/UR_2!B:7)L9?YT:7)M
M96L@:7-T:7EO<G-U;G5Z/P!.96T`3F5M.B``36EZ86CG_6QA<@!-86-A<FES
M=&%N`$E-05`@<&]S=&$@:W5T=7-U(&]L=?YT=7)U;&%M863].B`E<P!)34%0
M('!O<W1A(&MU='5S=2!S:6QI;F5M961I.B`E<P!)34%0('!O<W1A(&MU='5S
M=2!K;W1A<_T@;VQU_G1U<G5L86UA9/TZ("5S`$E-4U``25`@061R97-I`$E0
M(&%D<F5S:2!M979C=70@9&7P:6PN(`!)4"!!9')E<VD@:7II;B!V97)I;&5N
M($-)1%(@8FQO\'4@:>=I;F1E(&1E\&EL+@!)4"!K:6QI=&QE;64@:6AL86QI
M+@#6;E]C97EE(%-A=/UR(%EE<FQE_G1I<@#=>FQA;F1A`%-A9&5C92!3:6UG
M96QE<@`E<R!IYVEN('-I;6=E;&5R`$UE=&EN(&EL92!B:7)L:6MT92!S:6UG
M96QE<@!+:6UL:?!I;B!A9/TZ`$7P97(@9&_P<G4@9_9R_&YT_&QE;F5M:7EO
M<G-A+"!Y96YI('!E;F-E<F5D92!AYVUA:R!IYVEN('3]:VQA>?UN("5S+@!%
M\&5R($EN=&5R;F5T($5X<&QO<F5R(&EL92!S:6UG96QE<FD@9_9R96UI>6]R
M<V%N_7H@8G4@:W5T=7EU('-EYV5R96L@4$Y'('-A>61A;6S]\/UN_2!K87!A
M=&UA;OUZ(&=E<F5K:7(N`$?V<OQN=/QL97)I(&?V<F5M:7EO<B!F86MA="!B
M=2!M97-A:OT@9_9R96)I;&ER>6]R<V%N_7HL('G\:VQE;65K(&ES=&5D:?!I
M;FEZ(&?V<OQN=/P@=&%R87G]8_UN_7H@=&%R86;];F1A;B!G]G-T97)I;&5M
M96UE:W1E9&ER+@!']G+\;G3\(-9N:7IL96UE`$?V<OQN=/P@55),`$?V<OQN
M=/P@55),.@!397)G:61E;B!G]G+\;G3\`%-E<F=I9&5N(&?V<OQN=/PZ`$?V
M<OQN=/P@>?QK;&5M96L`1_9R_&YT_&QE<@!!9')E<R!$969T97)I(-WG97)I
M($%K=&%R;6$L($%D_6T@)60`W>=E<FD@06MT87(L($%D_6T@)60`061R97,@
M1&5F=&5R;&5R:6YI(-WG97)I+T3]_F%R_2!!:W1A<@#=YV5R:2!A:W1A<OUL
M86X@86QA;CH@)7,`W>=E<FD@86MT87+];&%N(&%L86YL87(Z`%-O;E]R87EA
M(%-A=/UR($5K;&4`66%N;/W^(&5Y;&5M(&MO9'4@9VER:6QD:2X`66%N;/W^
M(&MU;&QA;OUC_2!A9/T@=F4O=F5Y82!P87)O;&$N`%EA;FS]_B!K=6QL86[]
M8_T@863]('9E>6$@]G1E:VD@861R97,N665N:61E;B!D96YE>6EN('9E>6$@
M9&%H82!F87IL82!Y87)D_6T@:>=I;B!Y]FYE=&EC:6YI>FQE(&?V<OS^_&XN
M`$=I<FEN=&EY:2!!<G1T_7(`2&EN9&ES=&%N`$)I<F5Y<V5L($MU;&QA;OUC
M_6QA<@!%;F1O;F5Z>6$`0FEL9VD`0FEL9VD`4V]N<F%Y82!+;U]L;VX@16ML
M90!']G+\;G3\(%EE<FQE_G1I<@#':7IE;&=E(%EE<FQE_G1I<@!796(@0F'P
M;&%N=/US_2!997)L9?YT:7(`UFYC97EE($MO;&]?;B!%:VQE`%EE;FD@:V]L
M;VYU(/YU(&%N9&%K:2!K;VQO;F1A;B!S;VYR82!Y97)L9?YT:7(`665N:2!K
M;VQO;G4@_G4@86YD86MI(&MO;&]N9&%N(/9N8V5Y92!Y97)L9?YT:7(`665N
M:2!S873]<OT@_G4@86YD86MI('-A=/UR9&%N('-O;G)A>6$@>65R;&7^=&ER
M`%EE;FD@<V%T_7+](/YU(&%N9&%K:2!S873]<F1A;B#V;F-E>64@>65R;&7^
M=&ER`%EE;FD@<&%R86=R86;](/YU(&%N9&%K:2!D_/#\;61E;B!S;VYR87EA
M('EE<FQE_G1I<@!996YI('!A<F%G<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@
M]FYC97EE('EE<FQE_G1I<@#6=&5K:2!T87-L86L@>65R;&7^=&ER`%EE;FD@
M8FER('!A<F%L;WG](&%L86)I;&5C9?!I;FEZ(&)I<B!E;&5K=')O;FEK('!O
M<W1A(&%D<F5S:2!G:7)I;CH`2/QC<F5Y:2!S;VYR87/];F$@>65R;&7^=&ER
M`$C\8W)E>6D@]FYC97-I;F4@>65R;&7^=&ER`$MO;&]N=2!S;VYR87/];F$@
M>65R;&7^=&ER`$MO;&]N=2#V;F-E<VEN92!Y97)L9?YT:7(`365S86H@9VER
M`%!A<F%G<F%F_2!S;VYR87/];F$@>65R;&7^=&ER`%!A<F%G<F%F_2#V;F-E
M<VEN92!Y97)L9?YT:7(`4V%T_7+]('-O;G)A<_UN82!Y97)L9?YT:7(`4V%T
M_7+](/9N8V5S:6YE('EE<FQE_G1I<@!'_'9E;FQI:R!S;W)U<W5N=6X@8V5V
M86+].@!']G+\;G3\>?P@665R;&7^=&ER+T1E\&G^=&ER`$)A\&QA;G3](%EE
M<FQE_G1I<B]$9?!I_G1I<@!$8?#]=/UM(&QI<W1E<VD@9_9N9&5R;65K(&GG
M:6X@>65T97)S:7H@:W)E9&DN`%EE=&5R<VEZ(&MR961I`%1A;7-A>?T`5&%M
M<V%Y_2!L:7-T97-I`$=EYV5R<VEZ(&MI;6QI:P!'9>=E<G-I>B!51$@N("A+
M=6QL86[]8_T@5F5R:2!"8?YL_6L@0FEL9VES:2D`1V7G97)S:7H@861R97,@
M9&5F=&5R:0!'9>=E<G-I>B!U>6=U;&%M82X`1V7G97)S:7H@>?WP_6X@:VEM
M;&GP:2X`1V7G97)S:7H@=F5R:2!G]FYD97)I;&1I+@!'9>=E<G-I>B!T97-L
M:6T@861R97-I`$=EYV5R<VEZ(&4M<&]S=&$`1V7G97)S:7H@:V%Y_70`1V7G
M97)S:7H@9&]S>6$@8FGG:6UI`$=EYV5R<VEZ(&%N86AT87(@8F5L:7)T:6QD
M:2X`1V7G97)S:7H@;7-G7W1Y<&4`1V7G97)S:7H@860`1V7G97)S:7H@;F5S
M;F4@:VEM;&GP:0!'9>=E<G-I>B!Y861A(&%T;&%N;?W^(&%P:5]I9`!'9>=E
M<G-I>B!Y861A(&%T;&%N;?W^(&1E\&G^=&ER9V5L97(`1V7G97)S:7H@_'-T
M(&EZ:6XN`$=EYV5R<VEZ(&EL971I_FEM(&MU<F%L;&%R_0!'9>=E<G-I>B!P
M87EL8?[];&%N(&YE<VYE`$=EYV5R<VEZ(&MA>6YA:R!A9')E<VDN`$=EYV5R
M<VEZ('5N:6-O9&4@=F5R:7-I+@!3=&]K`-UR86X@W7-L86T@0W5M:'5R:7EE
M=&D`27)A:P#=<FQA;F1A`$UA;B!!9&$@1&5V;&5T:0!986S]=/UL;?W^(&?V
M:R!G_'+\;'3\;/P@9OUR=/UN80#=<W)A:6P`Q_UK87)A;@#==&%L:6L`W71A
M;'EA`$IA;6%I:V$`3V-A:P!*87!O;GEA`$IA<&]N8V$@*$E33RTR,#(R+4I0
M*0!*97)S97D`W')D_&X`5&5M;75Z`$AA>FER86X`66%S;&$`3W)T87EA(%EA
M<VQA`%1A;6%M96X@66%S;&$`4V]L82!987-L80!38?!A(%EA<VQA`$MA>F%K
M:7-T86X`UGIG_&X@;VQA;B!S86ML86YS_6X@;?T_`$ME;GEA`$ME<F)E<F]S
M('-U;G5C=2!D;_!R=6QA;6%Y_2!R961D971T:2X`QV5K:7)D96L@06-E;6EL
M97)I`$%N86AT87(@66%R870`06YA:'1A<B!087)M86MI>FD`06YA:'1A<B!5
M>G5N;'7P=0!!;F%H=&%R(%1I<&D`06YA:'1A<B!+=6QL86[];?T`0>?]:R!A
M;F%H=&%R('-U;G5C=7-U;F1A(&%N86AT87(@>F%T96X@=F%R+@#';V-U:VQA
M<@!+:7)I8F%T:0!+=7IE>2!+;W)E`$?\;F5Y($MO<F4`2V]R96-E("AE=6,M
M2U(I`$MU=F5Y=`!+_7)G_7II<W1A;@!,1$%0(&1E<W1E\&D@9V5R96MI>6]R
M(&%N8V%K($Q$05`@;6]D_&S\(&MU;&QA;OUL86)I;&ER(&1E\&EL('EA(&1A
M('G\:VQE;FUE9&DN`%-A>69A(%]$_'IE;FD`1&EL`$QA;R!$96UO:W)A=&EC
M($AA;&L@0W5M:'5R:7EE=&D`4V]N($3V<F3\;@!3;VX@1_QN8V5L;&5M90!3
M;WEA9`#>:?YK:6X@07D`4V]N($?\;F-E;&QE;64Z`%-O;B!':7)I_CH@)7,`
M4V]N($=I<FG^.B`E<R#\>F5R:6YD96X@)7,`4V]N($=I<FG^.B!!<VQA`$QE
M=&]N>6$`66%S80!$_'IE;@!(:>=B:7(@<_UN_7(@:>=I;B!B;_X@8OUR86MM
M80!,_&)N86X`4V]L`%-O;"!B8?YL_6L@8FEL9VES:0!3;VQD86MI(&1E\&5R
M;&5R`$QE<V]T:&\`3&EB97)Y80!,:6)Y80!,:65C:'1E;G-T96EN`,=I<V5L
M:7EO<@!(869I9B!98?!M=7(`17)K96X@4V%A=&QE<F1E($AA9FEF(%EA\&UU
M<@!'9><@4V%A=&QE<F1E($AA9FEF(%EA\&UU<@!(869I9B!98?!M=7(@4V'P
M86YA\/T`1_9K(&?\<OQL=/QL_"!H869I9B!Y8?!M=7(`2&%F:68@2V%R`$AA
M9FEF($MA<B!38?!A;F'P_0!._&MT96QI(-YI:7(`0F'P;&%N=/T`0F'P;&%N
M=/T@;F]K=&%S_3H`1_9R_&YT_&QE<FME;B!E;&5K=')O;FEK('!O<W1A(&%D
M<F5S:6YI(&]L=?YT=7)M82!S87EF87/];F$@8F'P;&$`0F'P;&%N=/UL87(`
M3&EN=7@@QV5R97II`$QI<W1E`$QI<W1E;&4@+2!K=6QL86[]8_T@9&EZ:6YI
M(&?V<F5B:6QI<@!697)I(%1A8F%N;&%R_6[]($QI<W1E;&4`66%R9/UM($MO
M;G5L87+];OT@3&ES=&5L90#':7IE;&=E;&5R:2!,:7-T96QE`$QI<W1E;&4M
M07+^:78`3&ES=&5L92U987)D_6T`3&ES=&5L92U)9`!,:7-T96QE+5-A:&EP
M`$QI<W1E;&4M1_9N9&5R:6QM:?X@UO!E;&5R`$QI<W1E;&4M4_QR9/QR_&UC
M_&QE<@!,:7-T96QE+5/\<F3\<OQM8_P@3VQM87EA;FQA<@!+=6QL86[]8_T@
M;&ES=&5L96UE('-EYVEL96UE>B!K_6S];F3]+@!%9&5B:7EA=`!,:71V86YY
M80!9_&ML96YI>6]R+BXN`%EE<F5L('IA;6%N.@!997(@=F4@6F%M86X`665R
M`$=I<FG^`,?]:_W^`$=I<FG^($?V<F5V;&5R:0!+=6QL86[]8_T@863]('9E
M>6$@<&]R;VQA(&1O\')U(&]L;6%D_?#](&GG:6X@9VER:?X@8F'^87+]<_UZ
M(&]L9'4N`$=I<FG^(&)A_F%R_7/]>B!O;&1U+@!5>G5N(&UE=&EN`$'^:P!$
M_/[\:P!+_.?\:R!Y=6YA;B!H87)F;&5R:0!+_.?\:R!L871I;B!H87)F;&5R
M:0!+_.?\:R!R;VUA(')A:V%M;&%R_0!,_&MS96UB=7)G`$%!`$U/5$0`35,M
M5$Y%1B!%:VD@=F5R:2!IYV5R;65M96MT961I<BX`35-'`$UA8V%O`$UA:V5D
M;VYY80!-861A9V%S:V%R`$+\>?P`4&]S=&$`4&]S=&$@6?9N971I8VES:0!"
M8?!L85]N=/T@66%R870N+BX`36%L879I`$UA;&5Z>6$`36%L9&EV;&5R`$UA
M;&D`36%L=&$`UO!E;&5R:2!E=&EK971L97EE8V7P:6YI>B!K871E9V]R:2!L
M:7-T97-I;FD@=F4@:V%T96=O<FEL97)I(&EL:?YK:6QE;F1I<F5C9?!I;FEZ
M(')E;FML97)I('GV;F5T:6XN`$UA<#(T(&AA<FET87/]`$UA<%%U97-T(&AA
M<FET87/]`$UA<G0`2V5N87(@8F_^;'7P=0!/:W5N;77^+T]K=6YM86W]_B!O
M;&%R86L@:?YA<F5T;&4`1&GP97(@:6QE=&D@:?YA<F5T;&5R:7EL92!I_F%R
M971L92`H]G)N96LZ(-9N96UL:2]#979A<&QA;FW]_BD@`$UA<G-H86QL($%D
M86QA<OT`36%R=&EN:6L`1?YL9?YE;@!%_FQE;&5N(&%L86YL87(`36]R:71A
M;GEA`$UA=7)I='5S`-UZ:6X@=F5R:6QE;B!E;B!Y_&MS96L@:W)E9&DN`$5N
M('G\:W-E:R!M97-A:B!P87+G87/]('-A>?US_2!A_OUL9/TN`%-O;B`R-"!S
M86%T=&5K:2!E;B!Y_&MS96L@<_UC86ML_6LZ(`!3;VX@-B!S86%T=&5K:2!E
M;B!Y_&MS96L@<_UC86ML_6LZ(`!%;B!Y_&MS96L@=7IU;FQU:P!!>F%M:2!S
M87EF82!S87G]<_T`36%Y_7,`36%Y;W1T90!4_7``W'EE;&5R`$UE;OP@2VEP
M:3H`2/QC<F5L97)I(&)I<FQE_G1I<@#=;&5T:0#=;&5R:2!B8?YA<OUY;&$@
M9&_P<G5L86YD_2!A;6$@:6UZ86QA>?UC_6[];B!O;F%Y(&)E;&=E<VD@9&_P
M<G5L86YA;6%D_2X`365S86K];B!S_')E<VD@8FET=&DN`$UE<V%J('1I<&D`
M2&%V82!287!O<G4`2&%V82!R87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@
M9&7P:6PN`$AA=F$@<F%P;W)U(/9B9?!I(&MU;&QA;OUL86)I;&ER(&1E\&EL
M+B!!>7+];G3];&%R('GV;F5T:6-I(&GG:6X@9_QN;/QK;&5N9&D`6?9N=&5M
M`$UE=')I:P!-96MS:6MA`$UI:W)O;F5S>6$`3W)T80!-:6UE(%3\<OP`4V]N
M(#(T('-A871T96MI(&5N(&3\_OQK('/]8V%K;/UK.B``4V]N(#8@<V%A='1E
M:VD@96X@9/S^_&L@<_UC86ML_6LZ(`!-:6YI:R!!<F%M80!986YS_0!-=6AT
M96QI9@!,1$%0(&MA>6YA:R!Y87#];&%N9/UR;6%S_6YD82!E:W-I:R!$3BX`
M0G5L=6YA;6%Y86X@4$5!4B!P86ME=&DZ($A45%!?4F5Q=65S="X`071L86YM
M_?X@>6%P_6QA;F3]<FUA+B!"=2!U>6=U;&%M87G](&MU;&QA;FUA:R!I<W1I
M>6]R<V%N_7H@>6%P_6QA;F3]<FUA>?T@_')E=&UE:R!Z;W)U;F1A<_UN_7HN
M`$%T;&%N;?W^(&UE<V%J($E$+@!!=&QA;FW]_B!O;&%N(&=E<F5K;&D@4$5!
M4B!P86ME=&D@36%I;"X`071L86YM_?X@;W1U<G5M82!A:70@240N`%!Z=`!'
M97II8VD@4&]S=&$`36]B:6P@5&5L969O;@!386MI;@!$9?!I_FEM(%1A<FEH
M:0!$9?!I_G1I<CI54DP`1&7P:?YI:VQI:R!B8?YA<OUS_7HZ("@E<RD@)7,`
M36]D(%1A8F%N_0!-;VQD;W9Y80!-;VYA8V\`36_P;VQI<W1A;@!!>2!V92!Y
M_6P`07EL_6L`36]N='-E<G)A=`!!>2!%=G)E;&5R:0!":7)D96X@9F%Z;&$@
M:V%Y_70@8G5L=6YD=0!&87,`1V5N96QL:6ML92!!Y_UK`$=E;F5L;&EK;&4@
M0G5L=71L=0!'96YE;&QI:VQE($?\;F7^;&D`5&'^_0!!_F'P_2!48?[]`%-O
M;&$@5&'^_0!38?!A(%1A_OT`675K87+](%1A_OT`0?YA\/T@=&'^_0!3;VQA
M('1A_OT`4V'P82!T8?[]`%EU:V%R_2!T8?[]`$UO>F%M8FEK`$UU;&)E<G)Y
M($%D<F5S($1E9G1E<FD`QV]K;'4@9/QZ97D@8?YA\/T@8>?];/UR(&QI<W1E
M;&5R`%LE<UT@861R97-I(&EL92!B:7)D96X@9F%Z;&$@:VG^:2!B=6QU;F1U
M(&%N8V%K(%LE<UT@:7-M:6YD92!B:7)I('EO:P#';VML=2!39>=I;0!(97-A
M8OUM`%!O<G1A;/UM`%!O<G1A;"!$_'IE;FEM`$UY86YM87(`2V%B=6P@151-
M25E/4E5-`$%D`$%D($)IYVEM:0!.86UI8GEA`$YA=7)U`$YE<&%L`$YE=&-E
M;G1E<B#<>64@1&EZ:6YI`$AO;&QA;F1A`$AO;&QA;F1A($%N=&EL;&5R:0!.
M971S8V%P92!486)A;B!54DP`3F5T<V-A<&4@0T$@W7!T86P@55),`$YE='-C
M87!E($-!(&MU<F%L(%523`!.971S8V%P92!996YI;&5M92!23`!.971S8V%P
M92#=<'1A;"!54DP`3F5T<V-A<&4@4U-,('-U;G5C=2!A9/T`3F5T<V-A<&4@
M;VYA>2!B96QG97-I(&'G_6ML86UA<_T`3F5T<V-A<&4@;VYA>2!B96QG97-I
M('3\<OP`0?``07-L80!996YI($MA;&5D;VYY80!996YI($MA=&5G;W)I`%EE
M;FD@W6QE=&G^:6T@3F]K=&%S_0!996YI($%Y`%EE;FD@2W5L;&%N_6/]($%D
M_2`H4V7G:6UL:2D`665N:2!:96QL86YD80!996YI(%!E;F-E<F4@*%]B;_XI
M`$AA8F5R;&5R`$AA8F5R($=R=7!L87+]`$1E=F%M`%-O;G)A:VD@4V7G96YE
M:VQE<@!.:6MA<F%G=6$`5&%K;6$@060`3FEJ97)Y80!.:6IE<GEA`$=E8V4`
M3FEU90!(87G]<@`E<R!G:7)I_FD@8G5L=6YA;6%D_3H@)7,`2&GG(&%D<F5S
M(&1E9G1E<FD@8G5L=6YA;6%D_2X`1F%R:VQA<OUN(&?V<W1E<FEL96)I;&5C
M9?!I(&MU;&QA;OUL86)I;&ER('EA</UL86YD_7)M82!V97)I<VD@>6]K+@!)
M4T\@:6UA:FQA<OT@;W7^='5R;6%K(&GG:6X@:W5L;&%N_6QA8FEL:7(@8FER
M('GV;G1E;2!Y;VLN`%G]\/UN('1A<VQA\/T@>6]K+@#=<W1E;F5N(&MO;G5M
M9&$@:&GG8FER(/9B96L@8G5L=6YM86UA:W1A9/UR`$U#04P@9&_P<G5L86UA
M<_T@:>=I;B!H:>=B:7(@=&%K=FEM(&%D_2!S8?!L86YM86W]_G3]<BX@`$1E
M\&G^:6ML:6L@66]K`$)U(&EZ;F4@:&GG8FER(&%L="!I>FEN(&5K;&5N96UE
M>65C96MT:7(N`"5S(&GG:6X@:&GG8FER('EA</UL86YD_7)M82!B:6QG:7-I
M(&)E;&ER=&EL;65D:2X`1E10(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR
M;6$@8FEL9VES:2!B96QI<G1I;&UE9&DN`%-13"!61E,@:>=I;B!H:>=B:7(@
M>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+@!344PM1FEL92!6
M1E,@:>=I;B!H:>=B:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM
M961I+@!(:><@:6QE=&G^:6T@;F]K=&%S_2!B=6QU;F%M863]`$MR961I('EO
M:RX`2&GG8FER('1E<VQI;2!N;VMT87/](&)E;&ER=&EL;65M:?YT:7(N`$AI
MYV)I<B!D;W-Y82!Y_&ML96YE;65D:0!(:>=B:7(@<VEM9V4@8G5L=6YA;6%D
M_2X`2&GG8FER('EE<B!B96QI<G1I;&UE9&DN`$AIYV)I<B!M97-A:B!S8?!L
M86YM863]+@!!9"!B96QI<G1I;&UE9&DN`$YU;6%R82!B96QI<G1I;&UE9&DN
M`%-A;&3]<F=A;B!D97EI_B!K=6QL86YM80!(5%10(&1O\')U;&%M87/](&GG
M:6X@<&%R;VQA(&=I<FEL;65D:2X`24U!4"!D;_!R=6QA;6%S_2!IYVEN('!A
M<F]L82!G:7)I;&UE9&DN`$ME<F)E<F]S(&1O\')U;&%M87/](&GG:6X@<&%R
M;VQA(&=I<FEL;65D:2X`3&]G:6X@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@
M9VER:6QM961I+@!005-35T0@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER
M:6QM961I+@!334(@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I
M+@!/<&5N4U-,(&EK:6QI<VEN92!H:>=B:7(@>6]L(&)U;'5N86UA9/TN3W!E
M;E-33"!I:VEL:7-I(%!+0U,@,3(@=F5R:7-I>6QE(&-A;/W^;6%K(&GG:6X@
M9V5R96ML:2X`W'EE(&]L;6%K(&GG:6X@8F5K;&5Y96X@>6]K+@!+=7)A;"!Y
M;VL`66%N('EO:P#6;F)E;&QE:R!IYVEN(&=EYVEC:2!D:7II;B!B=6QU;F%M
M863]+@!+=6QL86[]8_T@863]('9E+W9E>6$@<&%R;VQA(&?V;F1E<FEL;65D
M:2X`2&GG('9#87)D('9E<FES:2!B=6QU;F%M863]+@!'9>=E<FQI(%A-3"!V
M97)I<VD@9V5R:2!D]FYM961I+@!$9?!E<B!Y;VL`UGIG_&X@>6%P_6QA;F3]
M<FUA9&$@<_QR_&T@8G5L=6YA;6%D_2Y987#];&%N9/UR;6%Y_2!T96MR87(@
M_')E=&EN+@#6>F?\;B!Y87#];&%N9/UR;6%N_7ID82!S_'+\;2!B=6QU;F%M
M863]+EEA</UL86YD_7)M87G]('1E:W)A<B#\<F5T:6XN`$AIYV)I<FD`2&GG
M8FER:2`HUG)T_&S\(&MU;&QA;OUN*0!+=7IE>2!!=G)U<&%L_2`H25-/+3@X
M-3DM,3`I`$YO<F9O;&L@061A<_T`2W5Z97D@66%R_6UK_')E`$MU>F5Y($UA
M<FEA;F$@061A;&%R_0!.;W)V9><`4V]N<F%S_6YD82!$9?!I;`#6;F-E<VEN
M9&4@1&7P:6P`1&EZ:6X@9&7P:6P`1V5RYV5K;&7^=&ER:6QM96UI_@!"96QI
M<G1I;&UE;6G^`$1E<W1E:VQE;FUI>6]R+@!.;W1L87(`1_9Z(&%T_6QA8V%K
M(&)I<OYE>2!Y;VLL(&=E<FD@9/9N_&XN`$MA<_UM`%-A>?T`2V%R86MT97(@
M<V%Y_7/]`$MO;&]N('-A>?US_0!387EF82!B8?[];F$@]O!E('-A>?US_0!3
M873]<B!S87G]<_T`1&'P_73];2!L:7-T96QE<FEN:6X@9_QN8V5L;&5N;65S
M:2!IYVEN(&YU;6%R86QA<B!B96QI<G1I;&UE;6G^+@!%=F5T`$YE<VYE`$YE
M<VYE(%EA<F%T_6/]<_T`3F5S;F4@8G5L=6YA;6%D_0!396MI>FQI:R!3:7-T
M96T`16MI;0!386QD_7)G86YL_6L@<_QZ9V5C:0!/9FES`%5M;6%N`%-A9&5C
M92!)34%0('-U;G5C=6QA<OT@<&%Y;&'^_6QA;B!D:7II;FQE<FD@9&5S=&5K
M;&5M96MT961I<BX`4V%D96-E('-A;&3]<F=A;B!D97EI_FQE<@!3861E8V4@
M8FER(&5L96MT<F]N:6L@<&]S=&$@861R97-I;F4@:7II;B!V97)I;&UE:W1E
M9&ER+@!":7(@<&%Y;&'^_6W];B!S86AI<&QI\&EN:2!V97EA('-A:&EB:6YI
M('-A9&5C92!S:7-Y96T@>?9N971I8VES:2!V97EA('-A:&EB:2!D9?!I_G1I
M<F5B:6QI<BX`665N:2!P96YC97)E9&4@8><`3W!E;E-33"!H871A<_TZW6UZ
M86QA;FW]_B!3+TU)344@<&%RYV%S_6YD86X@=F5R:2!S9>=I<"#G_6MA=/UL
M86UA9/TN`$)U(&)A\&QA;G3]>?T@>65N:2!P96YC97)E9&4@8><`W?YL971I
M;2!3:7-T96UI`%-EYV5N96ML97(`)7,@:>=I;B!S9>=E;F5K;&5R`%/]<F%L
M86YM_?X@3&ES=&4`2W5R=6QU_@!+=7)U;7-A;"!":7)I;0!$_'IE;FQE;64`
MUGIG_&X@=7EG=6QA;6$@=&%S;&'P_0`E<R!IYVEN9&5K:2#V>F?\;B!T87-L
M86ML87(Z`$1I\&5R`$1I\&5R($)I;&=I;&5R`$1I\&5R(%-EYV5N96ML97(`
M4V%H:7`@:7II;FQE<FD`4$%-(&1O\')U;&%M87/](&UE=F-U="!D9?!I;"X`
M4$=0(%-A>?US86P@W6UZ80!01U`@WFEF<F5L96YM:?X@5F5R:0!01U`@0>?]
M:R!!;F%H=&%R_0!01U`@:6QE(-UM>F%L86YM_?XOWFEF<F5L96YM:?X@5F5R
M:0!02%`@2V]D=0!02%`@2V%B=?!U`-93($AA9FEF(%EA\&UU<@#64R!38?!A
M;F%K;&%R_0#64R!+87(`UE,@2V%R(%-A\&%N86ML87+]`-93($?V:R!G_'+\
M;'3\;/P@9OUR=/UN80!07TA0($MA8G7P=0!987-T_6ML86UA`%!A:VES=&%N
M`%!A;&%U`-W^9V%L($5D:6QM:?X@1FEL:7-T:6X@0O9L9V5S:0!086YA;6$`
M4&%P=6$@665N:2!':6YE`%!A<F%G=6%Y`$O]<VUE;B!"=6QU=&QU`%!A<F]L
M80!986YL_?X@<&%R;VQA`%)!1$E54R!D;_!R=6QA;6%S_2!IYVEN('!A<F]L
M82!G97)E:VUE:W1E9&ER+@!/;F%Y;/T@4&%R;VQA`%!A<F]L83H`4&%R;VQA
M.@!087)O;&%L87(@9?YL9?YM96L@>F]R=6YD863]<BX`66%P_?YT_7(`4&%N
M;V1A;B!Y87#]_G3]<@!9;VP`0F5K;&5Y96X@W'EE;&EK;&5R.@#=;G-A;FQA
M<@!9_'ID90!"86O];2#=_FQE;6QE<FEN:2!'97+G96ML9?YT:7(`0F%K_6T@
M:?YL96UL97)I(&=I<FG^=&4@9V5RYV5K;&7^=&ER:6QS:6X@;6D_`-UZ:6X`
M17)I_FEM($5N9V5L;&5N9&D`17)I_FEM(&5N9V5L;&5N9&D`W7II;B!9]FYE
M=&EM:0!+:?YI<V5L($)I;&=I;&5R`%!E<G4`179C:6P@2&%Y=F%N;&%R`$9I
M;&EP:6YL97(`5&5L969O;@!&;W1O\')A9FQA<@!0:6YE($%D<F5S($1E9G1E
M<FD`4&ET8V%I<FX`4F5S:6T@0FER:6UI`$)E>6QI:R!3]GIL97(`3/QT9F5N
M(&)I<FMAYR!H_&-R97EE('3]:VQA>?UN`$S\=&9E;B!B=2#V\&5Y:2#G_6MA
M<FUA:R!I<W1E9&GP:6YI>FD@9&_P<G5L87G];CH`3/QT9F5N(&)U(/;P96YI
M;B!B8?#];OT@Y_9Z;65K(&ES=&5D:?!I;FEZ(&1O\')U;&%Y_6XN`$S\=&9E
M;B!B:7(@87D@=F4@8FER('G];"!G:7)I;BX`3/QT9F5N('EE;FD@:V%T96=O
M<FEN:6X@863];OT@9VER:6XZ`$S\=&9E;B!G9>=E<FQI(&)I<B!)4"!A9')E
M<VD@9VER:6XN`$S\=&9E;B!G9>=E<FQI(&)I<B!G_&X@9VER:6XL(&%Y9&%K
M:2!G_&X@<V%Y_7/];OT@:V]N=')O;"!E9&EN+@!,_'1F96X@9V7G97)L:2!B
M:7(@>F%M86X@9VER:6XN`$S\=&9E;B!S;W)U;G5N(&)I<B#V>F5T:6YI('EA
M</UN+@!,_'1F96X@:W5L;&%N_6/](&%D_2!V92!P87)O;&%N_7K](&=I<FEN
M`$S\=&9E;B!Y96YI(&MA=&5G;W)I;FD@863](&=I<FEN.@!0;VQO;GEA`%!O
M;&ET:6MA`$]Y;&%M86QA<@!0;W)T96MI>@!']G+\;G3\(&MO;G5M;&%N9/UR
M_6S]>6]R`,=I>F5L9V4@:V]N=6UL86YD_7+];/UY;W(`0G4@9&EZ:6YE(&?V
M;F1E<B`H24U!4"!T87)A9OUN9&%N('IO<FQA;FUA;6%K=&%D_7(I`%-O;B`E
M<R!S86%T=&4@9/S^96X@>6'P;75R('9E(&MA<B!M:6MT87+].@!0<F5F<U]L
M9&%P.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`4')E9G-?
M<V5S<VEO;CH@W7-T96YE;B!O='5R=6T@=7IA;G3]<_T@8G5L=6YA;6%D_2X`
M0F%S_6[G`$1E;FEZ('-E=FEY97-I;F1E:VD@8F%S_6[G.@!"87/];N<Z`-9N
M:7IL96UE`$?V<OQN=/QY_"!Y96YI('!E;F-E<F5D92#V;FEZ;&4`UFYC96MI
M('-EYV5N96ML97(`0F5L9V5Y:2!Y87ID_7(`UGIE;"!!9')E<R!$969T97)I
M`-9Z96P@06YA:'1A<@!3;W)U;@!3;W)U;B!486[];6QA;6%S_0!0<F]J96QE
M<@!-971I;B!B:6QG:2!I<W1E;6D`0>?]:R!!;F%H=&%R`$'G_6L@06YA:'1A
M<B!A;&=O<FET;6%S_0!!Y_UK+]9Z96P@86YA:'1A<B!I:VEL:7-I(&)A_F%R
M_7EL82!Y87)A=/UL86UA9/TN`%!O<G1O(%)I:V\`2V%T87(`4V]R9W4`4V]R
M9W4@8F'^87+]<_UZ.B`H)7,I("5S`$C]>FS]($%R86UA`%)302!!Y_UK($%N
M86AT87+]("@E9"!B:70I`%)A9'EO(%-EYVEM:0!98?!M=7(`17)K96X@4V%A
M=&QE<F1E(%EA\&UU<@!'9><@4V%A=&QE<F1E(%EA\&UU<@!38?!A;F%K(%EA
M\/W^`%EA\&UU<B!V92!+87(`2V%R82!D]F[\_F5C96L@>6'P;75R`%)A<W1G
M96QE($1E>6G^`$]R86X`3VMU;6$`3VMU;6$@8F'^87+]<_UZ.B`H)7,I("5S
M`-UL971I;&5R:2!/:W4`4VEL;65K(&ES=&5D:?!I;FEZ92!G97+G96MT96X@
M96UI;B!M:7-I;FEZ/RA"=2!I_FQE;2!G97)I(.=E=G)I;&5M97HI.B5S`$MU
M;&QA;OUC_2`E<R!E(&%I="!K=6QL86[]8_T@=F5R:6QE<FEN:2!S:6QM96L@
M:7-T961I\&EN:7IE(&5M:6X@;6ES:6YI>BX@0G4@:?YL96T@9V5R:2#G979R
M:6QE;65Z+@!']G+\;G3\;&5N96X@:V%Y_71L87(Z`%-O;B!E>6QE;6D@=&5K
M<F%R;&$`1&5V:6YG96X@365N_"#6\&5L97)I;FD@5&%Z96QE.@!0;W)T86P@
M1_9R_&[\;?QN_"!487IE;&4Z`$3\>F5N;&D@W69A9&4`W6QI_FMI(%1A<F%Y
M_6/]`$'G_6ML86UA;&%R`%5Z86MT86MI(%-U;G5C=6QA<@!5>F%K=&%K:2!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!3:6P`UF)E\&D@
M4VEL`$MO;&]N=2!S:6P`0FGG:6UL96UE>6D@4VEL`$)U(&QI<W1E9&5N('-I
M;`!):VEL:7EI(%-I;`!+87ED961I;&UI_B!B971I\&D@<W5N=6-U;G4@9V7G
M:6-I(&1I>FEN:6YD96X@<VEL+@!3:6P`0G4@<&%RYV%Y_2!B96QG961E;B#G
M_6MA<G0`2W5L;&%N_6/](%-I;`!+=6QL86[]8_UY_2!S:6PZ("5S`-US=&5K
M(&-E=F%P;&%N86UA9/TN1/9N_&QE;B!H871A(&MO9'4Z(`!"96QI<G1I;&5N
M(&YE<VYE(&)U;'5N86UA9/TN`$=E<F5K96X@06QA;@!496UI>FQE`%!A<F]L
M87G]('/]9OUR;&$`4&%R;VQA;OUZ_2!S_6;]<FQA>?UN`-9N=&%N_6UL_2!D
M9?!E<FQE<FD@871A`%-O;G7G;&%R`%-EYV5N96ML97)E($3V;OQN`%)E=6YI
M;VX`66%P_6QA;F3]<FUA>?T@1V5R:2!$]FYD_'(`6F5N9VEN($UE=&EN($3\
M>F5N;&5Y:6-I<VD@4V7G96YE:VQE<FD`0FEL;65C96QE<@!38?``4V'P(&)A
M_FS]:R!B:6QG:7-I`$1O\')U(&1E\&5R;&5R`%-A7W3]<B#6>F5L;&EK;&5R
M:2XN+@!']G)E=@!2;VUA;GEA`#$X,"!D97)E8V4@9/9N9/QR`%-O;&$@1/9N
M9/QR`%-A\&$@1/9N9/QR`%-A=/UR(-9Z96QL:6ML97)I`%-A=/UR(/9Z96QL
M:6ML97)I`%-A=/UR;&%R.@#':7IG:6QE<@#':7IG:6QE<B!T_&T@<V%T_7(@
M=F4@:V]L;VYL87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER`,=I>F=I;&5R('-A
M9&5C92!K;VQO;FQA<B!A<F%S_6YD82!B96QI<F5C96MT:7(`QVEZ9VEL97(@
M<V%D96-E('-A=/UR;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<@#'86S]_G3]
M<@!2=7-Y82!&961E<F%S>6]N=0!2=6%N9&$`4R]-24U%(-YI9G)E;&5M92#=
M;7IA<_T`4R]-24U%(&EL92#>:69R96QE;FUI_B#=;&5T:0!3+TU)344@0>?]
M:R!397)T:69I:V%S_0!305-,(&1O\')U;&%M87/](&UE=F-U="!D9?!I;"X`
M4TU3($UE<V%J;&'^;6$`4U%,($MA8G7P=0!34T@`4U1!4E143%,@8F'^87+]
M<_UZ.B`H)7,I("5S`$)!WD%224Q)`%-?44P@2V%B=?!U`$-T<P!386EN="!(
M96QE;F$`4V%I;G0@2VET=',@=F4@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E('9E($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@=F4@1W)E;F%D:6YE
M<P!!>6[](.=E<N=E=F4@*&ME;E]D:7-I*0!386UO80!386X@36%R:6YO`%-A
M;R!4;VUE('9E(%!R:6YC:7!E`%5Y9'4@4V'P;&%Y_6/]`%-U=61I($%R86)I
M<W1A;@!+87ED970`2V%Y9&5T("5S`%-EYV5N96ML97)I($MA>61E=`!/;'7^
M='5R=6QA;B!Y87#];&%N9/UR;6%Y_2!02%`@8F5T:?!I(&]L87)A:R!S=6YU
M8W5N=6X@9V7G:6-I(&1I>FEN:6YE(&MA>61E="X`)7,@>6%P_6QA;F3]<FUA
M<_T@:V%Y9&5D:6QD:2X`0FEL:6T`07)A`$%R86UA($UO=&]R;&%R_0!!<F%M
M82!B8?YA<OUS_7H`07)A;6$@8F'^87+]<_UZ.B`E<P!!<OUY;W(N+BX`1&]S
M>6%L87+](%-EYP!":7(@=&%R:6@@<V7G:6X`16ML96UE:R!IYVEN(&)I<B!G
M<G5P('-EYVEN`%EE;FD@<V%H:6)I('-EYVEN`$)I<B!S=6YU8W4@<V7G:6X`
M16ML96UE:R!IYVEN(&)I<B!K=6QL86[]8_T@<V7G:6X`0OQT_&X@=&%R:6@@
M8FEL9?YE;FQE<FEN:2!S9>=I;@!":7(@;F5S;F4@<V7G:6X`5F5R:6QE<FEN
M(&3]_F%R_2!A:W1A<OUL86-A\/T@861R97,@9&5F=&5R:6YI('-EYVEN.@!6
M97)I;&5R:6X@:>=I;F4@86MT87+];&%C8?#](&%D<F5S(&1E9G1E<FEN:2!S
M9>=I;CH`W7-T961I\&YI>B!K87)A:W1E<FQE<FD@8?YA\/UD86MI(&MU='5L
M87)D86X@<V7G:6XN($1A:&$@<V]N<F$@;65T:6X@86QA;OUN9&%N(&MO<'EA
M;&%Y_7`@>6%P_?YT_7)A8FEL:7)S:6YI>BX`5&%R:6@@<_UN_7)L87G]8_US
M_6[]('-EY_UN.@!487)I:"!B:>=I;6EN:2!S9>=I;CH`1/W^87+](&%K=&%R
M;6$@8FGG:6UI;FD@<V7G:6XZ`-WG97)I(&%K=&%R_6QA8V%K(&1O<WEA>?T@
M<V7G:6XZ`$MA>6YA:R!D;W-Y86[];B!B:>=I;6EN:2!S9>=I;CH`W7-I;6QE
M<FEN(&?V<OQN=/QL96YE8V7P:2!B:>=I;6D@<V7G:6XZ`$1E\&G^=&ER;65K
M(&ES=&5D:?!I;FEZ(&MI;6QI\&D@<V7G:6XZ`%-A870@<_UN_7)L87G]8_US
M_6[]('-EYVEN.@!386%T(&)IYVEM:6YI('-EYVEN.@!%_FQE_F5N(&EK:2!A
M;&%N_2!S9>=I;BX`061R97,@;&ES=&5L97)I;F1E(&AA;F=I(&%L86YL87+]
M;B!G]G+\;G3\;&5N96-E\&EN:2!S9>=I;BX`W7-I;6QE<FEN(&?V<OQN=/QL
M96YE8V7P:2!B:>=I;6D@<V7G:6XN`%)E;FL@9/QZ96YI;FEZ:2!S9>=I;BX`
M5&5R8VEH(&5T=&GP:6YI>B!D:6QI('-EYVEN.@!3;W)U;B!287!O<G4@1_9N
M9&5R`%--4R!']FYD97(`4V5N96=A;`!!;&?];&%Y_6/].@!%>6S\;`!3_7)B
M:7-T86X@=F4@36]N=&5N96=R;P!397)I($YU;6%R87/]`$]T=7)U;2!K:6UL
M:?!I;FEN('/\<F5S:2!D;VQD=2X`0F5L:7)T`%!A<F]L86[]>OUN_2!U;G5T
M=7)S86[]>B!S_6;]<FQA;6%N_7IA(&EZ:6X@=F5R96-E:R!S9>=E;F5K;&5R
M:2!B96QI<G1I;BX@`%5L8?YM86L@:7-T9?!I;FEZ('5Z86MT86MI('-U;G5C
M=6QA<OT@8F5L:7)L97EI;BX`5&5R8VEH(&5T=&GP:6YI>B!D:6PL('-A870@
M9&EL:6UI('9E('1A<FEH('-EYV5N96ML97)I;FD@8F5L:7)L97EI;BX`0F'^
M;&%N9_WG('5Y9W5L86UA;OUZ_2P@<F5N:R!D_'IE;FEN:7II+"!S87EF82!T
M87IE;&5M92P@=F4@9&GP97(@9_9R_&YT_"!S9>=E;F5K;&5R:6YI(&)E;&ER
M;&5Y:6XN`$%Y87)L87(`2W5R=6QU;2!G_&YC96QL96UE(&)E=&EK;&5R:2!K
M=6QL86[];&%B:6QI<B!D=7)U;61A+@!$9?!I_G1I<F=E(&EL92!B:7)D96X@
M9F%Z;&$@>65R(&W\;6O\;CH@`%-E>?YE;`!087EL8?[];&%N($1I>FEN`$%L
M_?X@=F5R:?X`2_US82#6>F5T`,=O\'4@8F'P;&%N=/T@:>=I;B!E<FG^:6T@
M86YA:'1A<OT@=&%N_6UL86YS_6X@;?T_`$?V<W1E<@!4_&W\;OP@1_9S=&5R
M`-UL971I_FEM($YO:W1A;&%R_6[]($?V<W1E<@!,:7-T96QE<FD@1_9S=&5R
M`$AA;&5N(&MA>?UT;/T@;VQA;B!Y87#];&%N9/UR;6$@:6QE('EE;FD@>6%R
M873];&%N('EA</UL86YD_7)M82!A<F%S_6YD86MI(&9A<FML87+](&?V<W1E
M<BX`1VER:?YT92!E;B!S;VX@9VER:?X@=&%R:6AI(&?V<W1E<FEL<VEN(&UI
M/P#6>F?\;B!O;&%N_2!S86ML86UA('-EYV5N9?!I;FD@9_9S=&5R`%-EYVEC
M:7EI(&?V<W1E<@#':7IE;&=E(&G^;&5M;&5R:2!M96[\(.=U8G7P=6YD82!G
M]G-T97)I;'-I;B!M:3\`)7,@365N_'/\('-O;&1A(&?V<W1E<FEL<VEN(&UI
M/P!486)L;R!(_&-R92#6>F5L;&EK;&5R:2!+=71U<W5N=2!G]G-T97(`5&%B
M;&\@UGIE;&QI:VQE<FD@2W5T=7-U;G4@9_9S=&5R`%1A8FQO(%-A=/UR(-9Z
M96QL:6ML97)I($MU='5S=6YU(&?V<W1E<@!']G+\;G3\(/9Z96QL:6ML97)I
M(&MU='5S=6YU(&?V<W1E<@!9_&ML96UE>6D@9_9S=&5R`%-A\&%N86L`17)K
M96X@4V%A=&QE<F1E(%-A\&%N86L`1V7G(%-A871L97)D92!38?!A;F%K`,=E
M=G)E9&4@4V'P86YA:P!+_.?\;'0`W6QK(&]L87)A:R!K;VW^=2#V\&5L97(@
M:_SG_&QT<_QN('EA9&$@=&'^_6YS_6X`4VEE<G)A($QE;VYE`-QY92!O;`#=
M;7IA`-UM>F$@06QG;W)I=&UA<_T`4VEN9V%P=7(`0F]Y=70`0F%K_6W]($%T
M;&$`4VQO=F%K>6$`4VQO=F5N>6$`2V%R`$MA<B!38?!A;F'P_0!+87(@4V'P
M86YA:VQA<OT`17)K96X@4V%A=&QE<F1E($MA<B!38?!A;F%K;&%R_0!'9><@
M4V%A=&QE<F1E($MA<B!38?!A;F%K;&%R_0!+87(@1&5R:6YL:?!I.B``66'P
M86X@:V%R_6X@<W4@9?YI=&DZ(`!3;VQO;6]N($%D86QA<OT`4V]M86QI`-YA
M<FO];&%R("8@WFEI<FQE<@!3_7)A;&%M82!9]F[\`%/]<F%L86UA(&3\>F5N
M:2!S9>=I;6D`2V%Y;F%K(&%D<F5S:0!+87EN86ML87(`1_QN97D@069R:6MA
M`$?\;F5Y($%V<G5P82`H25-/+3@X-3DM,RD`1_QN97D@1V5O<F=I82!V92!'
M_&YE>2!386YD=VEC:"!!9&%L87+]`$?\;F5Y(%EA<OUM:_QR90!":71I_FEK
M(&C\8W)E;&5R(&%R87/];F1A:VD@8F_^;'5K`$C\8W)E9&5K:2!S_6[]<B!V
M92!IYV5R:6L@87)A<_UN9&%K:2!B;_YL=6L`0F_^;'5K($%Y87)L87G]8_T`
M07)A;/UK(&+]<F%K;6$`07)A;/UK(&+]<F%K;6$@=F4@>6%S=/UK;&%M80#=
M<W!A;GEA`-US=&5N;65Y96X@W6QE=&D`UGIE;"!+87)A:W1E<B!':7)I_FD`
M1V5L:?YM:?X@87)A;6$@<V]N=>=L87+];OUN(&YE<F5D92!G]G+\;G3\;&5N
M96-E\&EN:2!B96QI<G1I;BX`2/QC<F5Y:2!B]FP`2V]L;VYU(&+V;`!3873]
M<OT@8O9L`%-P;W)L87(`4W)I($QA;FMA`%-T86YD87)T`%5Z87D@66]L=0!"
M8?YL86YG_><@>?UL_0!%>6%L970@=F5Y82#=;`!$=7)U;0!$97!O;&%M82!B
M:>=I;6D`4V]K86L@061R97-I`-QS=/P@YVEZ9VEL:0!$:7IG:2!L:7-T97-I
M`$%D<F5S=&5N(&%L86X@863];OT@Y_UK87)T`%-I=&EL(%M#4U-=`%!Z<@!+
M;VYU`$?V;F1E<@!!;'1S:6UG90!"8?YA<OT`)7,@)7,@92!B8?YA<OUY;&$@
M96ML96YD:0!987#];&%N9/UR;6$@8F'^87+]>6QA(&=E<FD@9/9N9/QR_&QD
M_"X@1&7P:?YI:VQI:VQE<FD@9_9R;65K(&GG:6X@>65N:61E;B!Y_&ML97EI
M;BX`665D96L@>6%P_6QA;F3]<FUA(&)A_F%R_7EL82!K87ED961I;&1I+@!9
M961E:R!Y87#];&%N9/UR;6$@9&]S>6%S_2`E<R!B8?YA<OUY;&$@:V%Y9&5D
M:6QD:2X`)7,@8F'^87+]>6QA('EA>OUL9/TN`%-U9&%N`-9Z970`1_QN($1O
M\'5M=0!'_&X@8F%T_6W]`$?\;F7^;&D`1_QN(&1O\'5M=0!'_&X@9&_P=6UU
M+T?\;B!B873];?T`1_QN(&1O\'5M=3H@`$?\;B!B873];?T`1_QN(&)A=/UM
M_3H@`-QS='-I;6=E`$1E<W1E:P!3=7)I;F%M`%-O>6%D_0!3=F%L8F%R9"!V
M92!*86X@36%Y96X`4W9A>FEL86YD`-US=F7G`-US=FGG<F4`07)A;6$@=&5R
M:6UL97)I;F1E('/V>F1I>FEM(&AA=&%S_0!3=7)I>64`1_9K(&?\<OQL=/QL
M_"!F_7)T_6YA`$?V:R!G_'+\;'3\;/P@9OUR=/UN86QA<@!44U8`5%-6(&1O
M<WEA<_T`5&%B(&EL92!A>7+];&W]_B!D9?!E<FQE<@#':7IE;&=E`,=)>F5L
M9V4@UGIE;&QI:VQE<FD`QVEZ96QG92#V>F5L;&EK;&5R:0!487EV86X`5&%Y
M=F%N+"#':6X@97EA;&5T:0!486-I:VES=&%N`%1A;GIA;GEA`$AE9&5F.@!'
M]G)E=FQE<@!496QE9F]N($YU;6%R87/]`%-O;B!S86%T(&GG:6X@<_UC86ML
M_6LZ(`!3_6-A:VS]:P!3_6-A:VS]:SH@`%1A<VQA:R!9]FYE=&EM:0!-971I
M;@!3861E8V4@365T:6X`365T:6X@:&EZ86QA;6%S_0!-971N:6X@W'-T_`!0
M<OX`5&%I("A425,M-C(P*0!487EL86YD`%-I<W1E;6D@:W5L;&%N_63]\/UN
M_7H@:>=I;B!T9?YE:VO\<B!E9&5R:7HN`$944"!U>F%N=/US_2!K=6QL86[]
M;&%B:6QI<B!D=7)U;61A(&1E\&EL+@!(;W)D92]+;VQA8B!B_'3\;FQE_G1I
M<FUE(&UO=&]R=2!D97-T96ML96UE;65K=&5D:7(Z("(E<R(`0F%K_6TZ.B!S
M_6[]9B!B8?YA<OUY;&$@>?QK;&5N96UE9&DN`-YEYV5N96ML97(@<&5N8V5R
M97-I(&MA<&%N9/TNQ_UK_?X@>6%P_6S]>6]R+@!!9')E<R!D969T97)I(&)O
M_F%L=/UL86UA9/TZ("5S`$7P97(@:7II;FQE<FD@:W5L;&%N;6%K(&ES=&EY
M;W)S86[]>B!Y]FYE=&EC:6YI>FEN(-UZ:6X@<VES=&5M:6YI('EA</UL86YD
M_7)M87/](&=E<F5K;65K=&5D:7(N`%-A9&5C92!A;'0@=&%R868`W6QE=&G^
M:6T@;F]K=&%S_6[];B!)1"=S:2!B96QI<FQE;F5M961I+"!B;_X@8OUR86O]
M;&W]_B!V97EA('9E<FD@=&%B86[];F1A(&)U;'5N86UA9/TN`-UL971I_FEM
M(&YO:W1A<_T@8F'^87+]>6QA(&%D<F5S(&1E9G1E<FEN:7IE(&5K;&5N9&DN
M`$)E;&ER='1I\&EN:7H@:6QE=&G^:6T@;F]K=&%S_2!Y;VLN`,?]:V%R=/UL
M;?W^(%!'4"!I;7IA(/9B9?!I(&EM>F%L86YM_?X@:6QE=&EN:6X@9&_P<G5L
M=?!U;G5N('-A\&QA;FUA<_T@:>=I;B!G97)E:VUE:W1E9&ER+@!$8?#]=/UM
M(&QI<W1E<VD@240G<VD@8F5L:7)L96YE;65D:2P@8F_^(&+]<F%K_6QM_?X@
M=F5Y82!V97)I('1A8F%N_6YD82!B=6QU;F%M863]+@!$8?#]=/UM(&QI<W1E
M<VD@8F5L:7)L96YE;65D:2X`WFEF<F5L96UE(/9Z96QL:6ML97)I(&?\=F5N
M;&D@8FER('=E8B!B8?!L86YT_7/](&=E<F5K=&ER;65K=&5D:7(N`"5S(&1O
M<WEA<_T@)7,@87EA<OT@:>=E<FUE;&ED:7(N`"5S(&1O<WEA<_T@)7,@87EA
M<FQA<OT@:>=E<FUE;&ED:7(N`$1O<WEA(&ME;F1I(/QZ97)I;F4@:V]P>6%L
M86YA;6%Z+@!$;W-Y82!V97)I(&GG97)M:7EO<BX`5&%K:7`@961E;FQE<B!B
M=2!I;&5T:2]R9F,X,C(@:6QE=&ES:2!IYVEN(&)A_FS]:R!B:6QG:6QE<FED
M:7(N`$'^86UA9/WP_6W]>B!T87)A>?UC_2!H871A;&%R_2!S96)E8FEY;&4@
M=&%M(&5K<F%N(&MI<&EN:6X@26YT97)N970@17AP;&]R97(G;&$@8FER;&EK
M=&4@<V]R=6X@Y_UK87)D_?#](&)I;&EN;65K=&5D:7(N($%N;&%M<_UZ(&?V
M<OQN=/QL97)L92P@YV%L_?YM87EA;B!M971I;B!D_'IE;FQE>6EC:2!I_FQE
M<FEY;&4@=F4O=F5Y82!T87)A>?UC_6[];B!R87-T9V5L92#G]FMM97-I>6QE
M(&MA<O[];&'^86)I;&ER<VEN:7HN($7P97(@<VES=&5M:6YI>B!7:6YD;W=S
M(#EX(&ES92!Y_&MS96L@:6AT:6UA;"`G1V5N97)A;"!0<F]T96-T:6]N($9A
M=6QT)R!H871A<_T@86S]<"!S:7-T96UI('EE;FED96X@8F'^;&%T;6%N_7H@
M9V5R96ME8V5K+EQN7&Y"=2!B:7(@=7EA<OUY9/TN($7P97(@:&%L82!T86T@
M96MR86X@;65T:6X@9/QZ96YL97EI8VES:6YI(&1E;F5M96L@:7-T:7EO<G-A
M;OUZ($5V970G:2!T_6ML87G];BX`2VEM;&EK("(E<R(@<VEL:6YD:2X`4V%D
M96-E('-O;"!T87)A9@!#<GEP=%]P9W`Z.B!S_6[]9OUN82!';G501R!I:VEL
M:7-I;FEN(&MO;G5M=2!V97)I;&UE:R!Z;W)U;F1A9/UR+@`E<R!T87)I:&EN
M9&4@)7,@92!G]FYD97)I;&5N("(E<R(@:V]N=6QU(&EL971I(&?V<OQN=/QL
M96YD:2X*0G4@:6QE=&EN:6X@;VMU;F1U\'4@=F5Y82!A;FQA_OUL9/WP_6[]
M(&=A<F%N=&EL96UE;65K=&5D:7(N`$]L=?YT=7(@<&5N8V5R97-I;F4@8F'P
M;&%N_7)K96X@:W5L;&%N_6QA8V%K(&ES:6T`2&]R9&5?0W)Y<'1?<VEM93HZ
M('/];OUF_2!O<&5N<W-L(&)I<FEM:2!IYVEN(&=E<F5K;65K=&5D:7(N`"(E
M<R(@=&5R8VEH:2!V97)I<VD@:7II;B!V97)I;&5N(&5N('G\:W-E:R!B;WEU
M='4@9V7G=&GP:2!IYVEN(&MA>61E9&EL96UE;65K=&5D:7(N`$)U('9E<FD@
M>6%P<_UN_2@E<RD@9_9S=&5R;65K(&GG:6X@:W5L;&%N_6QA;B!P<F]G<F%M
M('-I<W1E;61E(&)U;'5N;6%M86MT863]<BX`4V%D96-E('-O;"!V92!S8?`@
M=&%R869L87(`4V%D96-E('-A\"!T87)A9@`B)7,B('-U;G5C=7-U('-I;&EN
M9&DN`"(E<R(@<W5N=6-U<W4@:V%Y9&5D:6QD:2X`)7,@:>=I;B!O;&%N(/QY
M96QI:R!I<W1E\&D@<VEL:6YD:2X`0F5L:7)T:6QE;B!S873]<B!B=6QU;FUA
M;6%K=&%D_7(N`$=EYVEC:2!D;W-Y82`B)7,B(&)U;'5N;6%M86MT863]<BX`
M4V%D96-E(/QS="!V92!A;'0@=&%R869L87(`4V%D96-E(/QS="!T87)A9@!"
M:7(@]FYC96MI(&%D_6T@<_UR87/];F1A('G\:VQE;F5N('9E<FD@:V%Y8F5D
M:6QD:2X`6?QK;&5N96X@9&]S>6$@:V%Y9&5D:6QE;65D:2X`=V5A=&AE<BYC
M;VT@:W5L;&%N_6QA8FEL:7(@9&7P:6PN`$?V>F%T_6QA8FEL96-E:R!B:7(@
M861R97,@9&5F=&5R:2!Y;VL`2&GG8FER('-EYV5N96L@;65V8W5T(&1E\&EL
M+@!-971N92!G]FW\;/P@;VQA<F%K(&?V<W1E<FEL96)I;&5C96L@:_US_6T@
M>6]K`%EA>OUL86)I;&ER(&)I<B!A9')E<R!D969T97)I('EO:RX@5F%R;VQA
M;B!A9')E<R!D969T97)L97)I;FEN(&AIYV)I<FD@>65N:2!G:7)I_FQE<B!E
M:VQE>65B:6QE8V7P:6YI>B#^96MI;&1E('EA</UL86YD_7+];&UA;?W^+B!%
M\&5R(&)U;G5N(&)I<B!H871A(&1U<G5M=2!O;&1U\'5N=2!D_/[\;OQY;W)S
M86[]>B!L_&9T96X@<VES=&5M('GV;F5T:6-I;FEZ92!B8?YV=7)U;BX`0G4@
M86QA;F1A(.=O:R!F87IL82!K87)A:W1E<B!V87(N)7,@=&%N92!K87)A:W1E
M<B!G:7)D:6YI>CL@)7,@=&%N961E;B!A>B!G:7)M96YI>B!G97)E:VER9&DN
M`$1O<WEA("AK87+^_61A;BD@>?QK;&5N;65S:6YD92!S;W)U;B!V87(Z("5S
M('G\:VQE;F5M961I+@!$;W-Y82!Y_&ML96YI<FME;B!B:7(@<V]R=6X@;VQU
M_G1U.B`E<R!E;B!B_'G\:R!I>FEN('9E<FEL96X@8F]Y=71T86X@*"5D(&)Y
M=&4I(&1A:&$@8OQY_&LN`$1O<WEA('G\:VQE;FER:V5N(&)I<B!S;W)U;B!O
M;'7^='4Z("5S('-A9&5C92!K_7-M:2!O;&%R86L@>?QK;&5N9&DN`%EE;FD@
M:6QE=&G^:6T@;F]K=&%S_2!E:VQE<FME;B!H871A(&]L=?YT=2X@3/QF=&5N
M('-I<W1E;2!Y]FYE=&EC:6YI>F5B8?YV=7)U;BX`665N:2!L:7-T92#\<F5T
M:6QI<FME;B!H871A(&]L=?YT=2X`0G4@:6QE=&G^:6T@;F]K=&%S_6[]('-I
M;&5R:V5N(&AA=&$@;VQU_G1U.B`E<P!"=2!N97-N97EI('-I;&5R:V5N(&AA
M=&$@;VQU_G1U+@!);&5T:6YI;B!B=2!K_7-M_6[](&?V<OQN=/QL96YM97-I
M;F1E(&AA=&$@;VQU_G1U+@#=;&5T:?YI;2!N;VMT87/];OUN('9E<FEL97)I
M("AIYV5R:2D@86MT87+];/UR:V5N(&AA=&$@;VQU_G1U+@!697)I>6D@:>=E
M<FD@86MT87+]<FME;B!H871A(&]L=?YT=3H@)7,`:4-A;&5N9&%R('9E<FES
M:6YI(&GG97)I(&%K=&%R_7)K96X@:&%T82!O;'7^='4N`%EA</UL86YD_7)M
M82!F;W)M=6YD82!B:7(@:&%T82!V87(N($=E<F5K;&D@8FER(&%L86[](&1O
M;&1U<FUA;?W^(&]L86)I;&ER<VEN:7HN`$)E;&ER=&EL96X@861R97,@9&5F
M=&5R:2!I_FQE=FEN:6X@9V5RYV5K;&7^=&ER:6QM97-I('/]<F%S_6YD82!S
M;W)U;B!O;'7^='4N($S\=&9E;B!D86AA('-O;G)A('1E:W)A<B!D96YE>6EN
M+@#=;&5T:?YI;2!N;VMT87/];OUN(&%Y<OUN=/UL87+];OT@9_QN8V5L;&5R
M:V5N(&AA=&$@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@9&5N
M97EI;BX`1&'P_73];2!L:7-T97-I;FD@9_QN8V5L;&5R:V5N(&)I<B!H871A
M(&]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K<F%R(&1E;F5Y:6XN`$)U
M(&MA>?UT_2!G_&YC96QL97)K96X@:&%T82!O;'7^='4Z("5S`$3]_F%R_2!A
M:W1A<OUL86-A:R!H:><@861R97,@>6]K+@!"=2!)34%0('-U;G5C=7-U('!A
M>6QA_OUL86X@9&EZ:6YL97)I(&1E<W1E:VQE;6EY;W(N`$)U(&=EYV5R;&D@
M8FER(')A<B!A<OYI=FD@9&7P:6PN`$)U(&=EYV5R;&D@8FER('II<"!D;W-Y
M87/](&1E\&EL+@!"=2!G9>=E<FQI(&)I<B!K87)T(&YU;6%R87/](&1E\&EL
M+@!"=2!S_'+\8_P@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!A\"!G9>=I9&D@_'IE<FEN9&5N($A45%`@05!)(&MU;&QA;F%R86L@;65S
M86H@871M86[]>F$@:7II;B!V97)I<BX`0G4@<_QR_&/\('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"D@8?`@9V7G:61I(/QZ97)I;F1E;B!(5%10($%0
M22!K=6QL86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N`$)U('/\
M<OQC_"!33510('EO;'5Y;&$@5F]D869O;F4@271A;'D@8?`@9V7G:61I(/QZ
M97)I;F1E;BP@<V%D96-E(%9O9&5F;VYE(&YU;6%R86QA<OUN82!M97-A:B!A
M=&UA;OUZ82!I>FEN('9E<FER+B!6;V1E9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I(&5L96MT<F]N:6L@<&]S=&$@861R97-I(&=E<F5K=&ER;65K
M=&5D:7(N`$)U(&=E<F5K;&D@8FER(&%L86YD_7(N`$)U(&%L86X@<V%D96-E
M('-A>?T@:>=E<FUE;&ED:7(N`$)U(&%L86X@<V%D96-E('-A>?T@=F4@:6MI
M(&YO:W1A(/QS=/QS=&4@:?YA<F5T:2!IYV5R96)I;&ER+@!"=2!A;&%N('-A
M9&5C92!S96MI>FQI:R!S87G]('-I<W1E;6EN9&5N(&1E\&5R;&4@:>=E<F5B
M:6QI<BX`0G4@86QA;B!V:7)G_&P@=F5Y82!B;_YL=6ML82!A>7+];&W]_B!S
M87G](&QI<W1E(&]L;6%L_63]<BX`0G4@86QA;B!G9>=E<FQI(&)I<B!N=6UA
M<F$@;VQM86S]9/UR+@!"=2!A;&%N(%)'0B!(97@@8FGG:6UI;F1E(&)I<B!R
M96YK(&MO9'4@:>=E<FUE;&ED:7(L(/9R;F5K.B`G(S$R,S1A9B<`0G4@9&]S
M>6$@8FGG:6UI(&1E<W1E:VQE;FUI>6]R+@!"=2!F;W)M('IA=&5N(&G^;&5N
M9&DN`$)U("5S+@!"=2!B:7(@2V]L86(@1W)O=7!W87)E(&YE<VYE<VED:7(N
M($)U(&YE<VYE>6D@9_9R96)I;&UE:R!IYVEN($MO;&%B($=R;W5P=V%R92!B
M:>=I;6EN:2!A;FQA>6%B:6QE;B!B:7(@96QE:W1R;VYI:R!P;W-T82!I<W1E
M;6-I<VEN92!G97)E:R!V87(N0G4@96QE:W1R;VYI:R!I<W1E;6-I(&QI<W1E
M<VD@:>=I;B`E<R!A9')E<VEN92!U\')A>?UN+@!"=2!I;&5T:2!S:7II;B!K
M87)A:W1E<B!K_&UE;FEZ9&5N(&9A<FML_2!O;&%R86LH)7,I('EA>OUL;?W^
M=/UR+@!"=2!N=6UA<F$@96X@87K];F1A;B!B:7(@;VQM86S]9/UR+@!"=2!K
M:?YI>64@86ET("5S(&MA>?UT_2!A9')E<R!D969T97)I;F1E(&UE=F-U="X`
M0G4@<W5N=6-U('II<"!V92!G>FEP(&1O<WEA;&%R_6[](&'G86UA;6%K=&%D
M_7(N`%-I<W1E;6EN(&5T:VEN;&GP:2!K86QD_7+];&W]_G3]<BX`0G4@9&7P
M97(@8FER('-A>?T@;VQM86S]9/UR+@!"=2!P96YC97)E(%-EYV5N96ML97(@
M<&5N8V5R97-I;F1E;B#G8?!R_6QM86S]9/UR+@!']FL@9_QR_&QT_'/\`$)I
M;&5T;&5R`%IA;6%N`%IA;6%N(-UZ;&5M90!:86UA;B!":>=I;6D`6F%M86X@
M4V7G:6UI`%1I;6]R+4QE<W1E`-QN=F%N`$)A_FS]:R`H8>?]:VQA;6$I.@!+
M:6UE`,=O:VQU(/;P92!S9>=I;6D@:>=I;BP@=/UK;&%R:V5N($-O;G1R;VP@
M*%!#*2!V97EA($-O;6UA;F0@*$UA8RD@='7^=6YA(&)A<_UN+@!"=6?\;@!(
M5$U,($MA>6YA\/UN82!'9>=I;@!4;V=O`%1O:V5L874`66%R_6X`5&]N9V$`
MW'-T`-QS="#'97+G979E("C<7W-T*0#'979I<FEL97(`5')I;FED860@=F4@
M5&]B86=O`$1O\')U('9E>6$@66%N;/W^`%-A`%1U;G5S`%3\<FMI>64`5/QR
M:^=E("A)4T\M.#@U.2TY*0!4_')K;65N:7-T86X`5'5R:W,@=F4@0V%I8V]S
M($%D86QA<OT`5'5V86QU`%-EYVEM:6YI>FD@9VER:6XZ`%4N5BX@96YD96MS
M.B``55),`$)E=&EK;&5R:6X@9'5R=6T@<F%P;W)L87+];OUN('1E<VQI;2!E
M9&EL96-E\&D@55),`%523#H`56=A;F1A`%5K<F%Y;F$`5D93(&1I>FEN:6YE
M(&5R:?YI;&5M96UI>6]R+@#<>64@;VQU<FME;B!E:R!K=6QL86[]8_T@8FEL
M9VES:2!E:VQE;F5M:7EO<BX`(B5S(B!61E,@9&]S>6%S_6[];B!I>FEN;&5R
M:2!D9?!I_G1I<FEL96UI>6]R+@`E<R\E<R!61E,@9&]S>6%S_6[];B!I>FEN
M;&5R:2!D9?!I_G1I<FEL96UI>6]R+@`E<R!D9?!I_G1I<FEL96UE9&DN`%-1
M3"!S=6YU8W5S=6YA(&)A\&QA;OUL86W]>6]R+@!34TP@:6QE(&)A\&QA;OUL
M86W]>6]R+@!61E,@9&]S>6%S_2!K;W!Y86QA;F%M_7EO<BX`(B5S(B!61E,@
M9&EZ:6YI('EA<F%T_6QA;?UY;W(N`%9&4R!D:7II;FD@>6%R873];&%M_7EO
M<BX`5D93(&1O<WEA<_T@>6%R873];&%M_7EO<BX`0F_^(%9&4R!D;W-Y87/]
M('EA<F%T_6QA;?UY;W(N`%9E<FD@<_UK_?YT_7+];&%M_7EO<BX`(B5S(B!D
M:7II;FD@<VEL:6YE;6EY;W(L(&1I>FEN(&)O_B!D9?!I;"X`)7,@<VEL:6YE
M;6EY;W(L(&1I>FEN(&)O_B!D9?!I;`!61E,@9&EZ:6YI(/9Z>6EN96QI(&]L
M87)A:R!S:6QI;F5M:7EO<BX`5D93(&1I>FEN:2!S:6QI;F5M:7EO<BX`5D93
M(&1I>FEN:2!S:6QI;F5M:7EO<CH@)7,N`%9&4R!D;W-Y87/]("(E<R(@<VEL
M:6YE;6EY;W(N`%9&4R!D;W-Y87/]('-I;&EN96UI>6]R+@!61E,@]GIY:6YE
M;&D@;VQA<F%K('-I;&EN96UI>6]R.B`E<RX`6?QR_')L_&MT96MI(&1I>FEN
M92!K87)A<B!V97)I;&5M:7EO<BX`3VYA>2!B96QG97-I(&%Y<OUN=/UL87+]
M(.?]:V%R=/UL86W]>6]R`"5S('1A;OUM_2!Y_&ML96YE;6EY;W(N`%9&4R!D
M;W-Y87/]('1A_OUN86W]>6]R+@!61E,@9&]S>6%S_2`B)7,B(&'G_6QA;?UY
M;W(N`%9&4R!D;W-Y87/]('EA;6%K(&GG:6X@8>?];&%M_7EO<BX`5D93(&1O
M<WEA<_T@8>?];&%M_7EO<BX`4_UK_?YT_6S];?W^(&%R_FEV(&'G_6QA;?UY
M;W(N`%9F<W)O;W0@9&EZ:6YI(&]K=6YA;?UY;W(N`"5S+3XE<R!O;&%R86L@
M>65N:61E;B!A9&QA;F3]<OUL86W]>6]R.B!H961E9B!D:7II;B!Z871E;B!V
M87(N`%9&4R!D:7II;FD@>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+@!61E,@
M9&EZ:6YI('EE;FED96X@861L86YD_7+];&%M_7EO<CH@)7,`5D93(&1O<WEA
M<_T@(B5S(B!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N`"5S+R5S(%9&4R!D
M;W-Y87/]('EE;FED96X@861L86YD_7+];&%M_7EO<BX`5D93(&1O<WEA<_T@
M>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+@`G;6MI<V]F<R<@YV%L_?YT_7+]
M;&%M_7EO<BX`0G4@5V]R9"!B96QG97-I(.=E=FER:6QI;&5M:7EO<BX`5D93
M(&1O<WEA<_T@(B5S(B!Y87K];&%M_7EO<BX`5D93(&1O<WEA<_T@>6%Z_6QA
M;?UY;W(@*&-O<'DH*2!B8?YA<OUS_7H@;VQD=2DN`%9&4R!D;W-Y82!V97)I
M<VD@>6%Z_6QA;?UY;W(N`$%L=/UN_2#G:7H`1&7P:?YI:VQI:VQE<FD@1V5R
M:2!!;`!3;VX@97EL96UI(&=E<FD@86P`0F'P;&%N=/UD82!S=6YU8W5D86X@
M8F5K;&5N;65Y96X@>6%N_70Z(`!3=6YU8W5D86X@8F5K;&5N;65Y96X@>6%N
M_70Z(`!$;VQD=7)U;&UA;?W^`%5N:6-O9&4@*%541BTX*0!":7)L9?YI:R!!
M<F%P($5M:7)L:6ML97)I`$)I<FQE_FEK($MR86QL_6L`06UE<FEK82!":7)L
M9?YI:R!$979L971L97)I`$%M97)I:V$@0FER;&7^:6L@1&5V;&5T;&5R:6YI
M;B!+_.?\:R!5>F%K($%D86QA<OT`0FER:6UL97(`0FEL:6YM97EE;@!":6QI
M;FUE>65N(&%P:6US9VED("A!4$D@365S86H@240I`$)I;&EN;65Y96X@8VQI
M;7-G:60@*-US=&5M8VD@;65S86H@240I`$)I;&EN;65Y96X@:W5L;&%N_6/]
M(&%D_2!V97EA('!A<F]L82X`WG4@86YK:2#V\&5N:6X@8F'P_6[](.?V>@#=
M<VEM<VEZ`$%Y<OUC86S]:W/]>B!B971I:VQE<B!P<F]G<F%M<V%L(&]L87)A
M:R!+97,O2V]P>6%L82]987#]_G3]<B=A(&?\=F5N;&EK(&YE9&5N:7EL92!E
M<FG^96UE>FQE<BX@0F5T:6ML97)I;B!P86YO>6$@;F%S_6P@=6QA_F%C8?#]
M;OT@9_9S=&5R96X@;6]Z:6QL82YO<F<@=&5K;FEK(&YO='5N=2!G]G)M96L@
M:>=I;B!%5D54(&D@=/UK;&%Y_6XN`$)E;&ER=&EL;6G^(')E;FMT96X@=F%Z
M9V7G`$1E<W1E:VQE;FUE>65N(%5Z86YT_0!'_&YC96QL90!'_&YC96QL93H@
M)7,`2W5L;&%N_6/]>?T@9_QN8V5L;&4`6?QK<V5L=&UE(&)E=&GP:2!S:6QI
M;&YD:2X`6?QK;&4`0OQT_&X@=7EG=6QA;6%L87+];B!A>6%R(&1O<WEA;&%R
M_2!S=6YU8W5Y82!Y_&ML96YD:2X`0OQY_&L@;&%T:6X@:&%R9FQE<FD`0OQY
M_&L@<F]M82!R86MA;6QA<OT`57)U9W5A>0!+=6QL86XZ("5S`%-33"!K=6QL
M86X`2W5L;&%N_6/](&%D_6[]>B]P87)O;&%N_7H@24U34"!S=6YU8W4@:>=I
M;B!F87)K;/T@:7-E(&MU;&QA;OUN+@`E<R!K=6QL86[]8_US_2`E<R!IYVEN
M(&1O\')U;&%N86UA9/TN`$MU;&QA;OUC_2!9]FYE=&EM:0!+=6QL86[]8_T@
M4V7G96YE:VQE<FD`2W5L;&%N_6/]($MA>?UT`$)U('-I=&4@:>=I;B!K=6QL
M86[]8_T@:V%Y9/T@<V7G:6QM97H@:_UL_6YM_?YT_7(N`$MU;&QA;OUC_2!!
M9/T`2W5L;&%N_6/]($%D_3H`2W5L;&%N_6/](&%D_3H@`%-I<W1E;61E:VD@
M:W5L;&%N_6/];&%R.@#6>F)E:VES=&%N`%9&4R!D:7II;FD@>6]K+@!4871I
M;`!'9>=E<FQI(&MO;G5M;&%R_6X@:>=E<F1I:VQE<FDZ`$=EYV5R;&EL:6L`
MWG4@86YD86X@:71I8F%R96X@9&%K:6MA(&1E\&5R:0!$9?!E<FQE<@!$9?!E
M<FQE<FEN('-EYVEL96-E\&D`5F%N=6%T=0!$9?!I_FME;@!696YE>G5E;&QA
M`$1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2`M(&)U(&EL971I(&MU<F-A;&%N
M;?W^(&]L86)I;&ER+B`@`%9E<FES:6=N($1I>FEN:0!3_'+\;0!3_'+\;2!+
M;VYT;VS\`$3\_F5Y($AI>F$`1/S^97D@>6%S=/UK;&%M80!$_/YE>3H`QV]K
M(%G\:W-E:P!6:65T;F%M`%9I971N86UC82`H5DE30TE)*0!']G+\;G3\;&4@
M)7,`W6QE=&G^:6T@3F]K=&%S_6[]($?V<OQN=/QL90!":7(@9/W^('=E8B!S
M87EF87/](&?V<OQN=/QL90`E<R!O;&%R86L@9_9R_&YT_&QE`-9N=&%N_6UL
M_2!G]G+\;OQM`$)R:71A;GEA)WEA(&%I="!6:7)G:6X@061A;&%R_0!!;65R
M:6MA($)I<FQE<OYI:R!$979L971L97)I)VYE(&%I="!6:7)G:6X@061A;&%R
M_0!']G+\_@!']G+\_CH`4TU44"!Y;VQU>6QA(%9O9&%F;VYE(-UT86QY80!7
M05).`%5905))(2$A)7,@W<?=3D1%3B!"153=T-T@14P@W4Q%(,=)2T%25$E.
M+@!786QL:7,@=F4@1G5T=6YA`%5Y87+]`,=R_@!(879A(%1A:&UI;FD`2&%V
M82!V97)I<VD@<V'P;&%Y_6/]<_T`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E
M<VD`5V5B('-A>69A<_T@861R97-I`$AA9G1A;/UK`$AO_F=E;&1I;FEZ`"5S
M($AO_F=E;&1I;FEZ`$AO_F=E;&1I;FEZ+"`E<P!"873]("A)4T\M.#@U.2TQ
M*0!"873]("A)4T\M.#@U.2TQ-2D`0F%T_2!386AR80`E<R!G:7)I_G1E;B!S
M;VYR82!H86YG:2!U>6=U;&%M87G](&?V<OQN=/QL97-I;C\`4_UN_7)L87G]
M8_T@:V%R86MT97(@;F5D:7(_`$%K=&%R_6T@:V%R86MT97)I(&YE9&ER/P!(
M86YG:2!%=G)E`%IE;F=I;B!-971I;B!D_'IE;FQE>6EC:7-I(&GG:6X@:&%N
M9VD@=7EU;6QU(&5K;&5R('-EYVEL96)I;&ER(&O];/UN<_UN+@!'96YI_FQI
M:P!#4U,@8FER:6UI>6QE(&=E;FG^;&EK`%-O;&1A:VD@)7,@;65N_'/\;OQN
M(&=E;FG^;&GP:2`H8FER('-O;G)A:VD@9VER:?YT92!E=&MI;B!O;&%C86LI
M.@#':7IE;&=E;FEN(&=E;FG^;&GP:0!'96YI_FQI:R!B:7)I;6D`1V5N:?YL
M:6LZ`%=I:VD`4OQZ9V%R`$5R:V5N(%-A871L97)D92!2_'IG87(`2VYO="!B
M:7)I;6EN9&4@<OQZ9V%R(&C]>OT`4OQZ9V%R.@!2_'IG87(Z(`!":6QG96QI
M:P#=_@#=_B!!9')E<VD`WF5H:7(`W&QK90#=_B!496QE9F]N=0!0;W-T82!+
M;V1U`$+V;&=E`-W^($%D<F5S:0!8+5)E9@!8-3`Y=C,@5&5M96P@2_US_71L
M86UA;&%R_0!8-3`Y=C,@1V5N:?YL971I;&UI_B!!;F%H=&%R($MU;&QA;OUM
M_0!8-3`Y=C,@UG1E:VD@2V]N=2!!9/T`6#4P.78S($MO;G4@06YA:'1A<B!4
M86[]=/UC_7/]`%@U,#EV,R!U>F%N=/UL87+]`%E9`%E965D`66%H;V\A(&AA
M<FET87/]`%G];&S]:P!996UE;@!%=F5T`$5V970L($MA8G5L($5D:7EO<G5M
M`$U%5-U.($U/1%5.1$%324Y)6BX@6SP^72!D_/!M96QE<FEN:2!K=6QL86YA
M<F%K(%=94TE764<@9_9R_&[\;?QN92!D]F[\;BX`1&_P<G5L86YA;6%D_6[]
M>BX`)UPG(&MA<F%K=&5R:2!T86T@863];OUZ9&$@8G5L=6YA;6%Z+@!'9>=E
M<FQI(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!G:7)M961I;FEZ+@`E
M<R!IYVEN9&4@:V%R_OUL_6L@9V5L96X@86QA;FQA<FQA("AIYV5R:2D@86MT
M87+];&%N(&1O<WEA9&%K:2!A;&%N;&%R_2!E_FQE_G1I<FUE9&EN:7HN`$)U
M(&EL971I_FEM(&YO:W1A<_UN_2!G]G+\;G3\;&5M97EE(&EZ;FEN:7H@>6]K
M+@!"=2!N97-N97EI(&?V<OQN=/QL96UE>64@:7IN:6YI>B!Y;VLN`,?]:_W^
M('EA<&UA9/UN_7HN`$=EYV5R;&D@8FER(&-E<"!T96QE9F]N=2!N=6UA<F%S
M_2!G:7)M96QI<VEN:7HL('-A>?UL87(@=F4@<V7G96YE:VQI(&]L87)A:R!U
M;'5S;&%R87)A<_T@87)A;6$@]FYE:VD@)RLG(`!'9>=E<FQI(&)I<B!D9?!E
M<B!G:7)M96QI<VEN:7HN`-QY92!K87ED_2!Y87!A8FEL;65K(&GG:6X@8FER
M(%9E<FE!\&%C_2!Y87#];&%N9/UR;6%L_7/];OUZ+@!61E,@<V]N(&'^86UA
M<_UN_2!Y87#];&%N9/UR;6%L_7/];OUZ+@!0<F]B;&5M(')A<&]R=2!G]FYD
M97)M961E;B#V;F-E('-O<G5N=2!T87)F:2!E=&UE;&ES:6YI>BX`0G4@8F'P
M;&%N=/UN_6X@9_9S=&5R9&GP:2!B:7(@55),(&=I<FUE;&ES:6YI>@!":7(@
M:&5D968@861R97,@9&5F=&5R:2!S9>=M96QI<VEN:7HN`$)I<B!H961E9B!L
M:7-T92!S9>=M96QI<VEN:7HN`%-I;&EN;65S:2!IYVEN(&)I<B!S=6YU8W4@
M<V7G;65L:7-I;FEZ+@#6;F-E(&5N(&%Z(&)I<B!K<WG]="!S9>=M96QI<VEN
M:7HN`%1E;6EZ;&5N;65S:6X@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI
M<G1M96QI<VEN:7HN`%-I;&EN;65S:2!IYVEN(&)I<B!K=6QL86[]8_T@863]
M(&)E;&ER=&UE;&ES:6YI>BX`16ML96YM97-I(&GG:6X@8FER(&MU;&QA;OUC
M_2!A9/T@8F5L:7)T;65L:7-I;FEZ+@!'_&YC96QL96YM97-I(&GG:6X@8FER
M(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ+@!'97+G96ML9?YT:7)I
M;&5C96L@8FER(&5Y;&5M(&)E;&ER=&UE;&ES:6YI>BX`665N:2!K871E9V]R
M>2!A9/T@9VER;65L:7-I;FEZ+@!"=2!I;&5T:?YI;2!N;VMT87/];OT@<V%D
M96-E(&?V<OQN=/QL96UE(&EZ;FEN:7H@=F%R+@`E<R!O='5R=6UU;G5N('/\
M<F5S:2!D;VQD=2X@3/QT9F5N('1E:W)A<B!G:7)I_B!Y87#];BX`16QE:W1R
M;VYI:R!0;W-T82!!9')E<VEN:7H`2VEM9&5N.B!A9')E<SH`0FEL9VEL97)I
M;FEZ`"5S(&]T=7)U;75N=7IU;B!B8?YL86YG_6/];F1A(-UN=&5R;F5T($%D
M<F5S:6YI;FEZ(&1E\&G^=&DN($?\=F5N;&GP:6YI>FD@:V]R=6UA:R!IYVEN
M+"!Y96YI9&5N(&=I<FG^('EA<&UA;/US_6[]>BX`063];OUZ`$MI;6QI:R!D
M96YE=&EM:6YI>B!K=6QL86[]8_T@;&ES=&5L96UE>6D@9&5S=&5K;&5M96UE
M:W1E9&ER('9E>6$@8G4@]GIE;&QI:R!B:7(@;F5D96X@>?QZ_&YD96X@<V7G
M:6QE;65Z(&O];/UN;?W^=/UR+@`E<R!O='5R=6UU;G5Z=6X@8F'^;&%N9_UC
M_6YD82!T87)A>?UC_6[]>B!D9?!I_G1I+B!'_'9E;FQI\&EN:7II(&MO<G5M
M86L@:>=I;BP@>65N:61E;B!G:7)I_B!Y87!M86S]<_UN_7HN`%1A<F%Y_6/]
M;OUZ(&)U(/9Z96QL:?!I(&1E<W1E:VQE;65M96MT961I<BX`6F%M86X@1&EL
M:6UI;FEZ.@#6;B!T86[];6S](&MI;6QI\&EN:7HZ`%1A;2!!9/UN_7HZ`"5S
M(&GG:6X@>65N:2!P87)O;&%N_7HZ("5S`%-EYV5N96ML97)I;FEZ(&)U(&]T
M=7)U;75N('/\<F5S:2!IYVEN9&4@9_QN8V5L;&5N9&DN`%-EYV5N96ML97)I
M;FEZ(&?\;F-E;&QE;F1I+@!087)O;&%N_7H@<_UF_7)L86YD_2X`4&%R;VQA
M;OUZ('/]9OUR;&%N9/TL(&5L96MT<F]N:6L@<&]S=&%N_7K](&MO;G1O;"!E
M9&EN('9E('EE;FD@<&%R;VQA;OUZ;&$@9VER:?X@>6%P_6XN`%5Z86MT86MI
M('-U;G5C=6QA<OUN_7HZ`%EU9V]S;&%V>6$`6F%I<F4`6F%M8FEA`%II;6)A
M8G9E`$C]>FS]`%M!;/UN=/T@365T;FD@4V%K;&%=`%M0<F]B;&5M(%)A<&]R
M=5T`6T%L_6YT_2!-971N:2!']G-T97(@+0!;06S];G3]($UE=&YI($?V<W1E
M<B`M("5S('-A=/UR70`E<R\E<R!S873]<@!;9&7P97(@>6]K70!?6?9N971I
M;0!?1_9Z870`7T-,20!?5F5R:4'P86/]`%-?:6P`4V%T_7+](%]3:6P`7T=R
M=7!L87(`66%R7V3];0!']G+\;G3\(-9?>F5L;&EK;&5R:2XN+@#=YV5R:2]?
M1/W^87+]($%K=&%R`$=I7W)I_@#'_5]K_?X`7T)A\&QA;G3]>?T@1&7P:?YT
M:7(N+BX`7U-EYV5N96ML97(`7TAA:VQA<@!"8?!L85]N=/UY_2!3:6PN+BX`
M0E]U(&QI<W1E9&5N('-I;`!?07)A;6$`7T%Y87)L87(`QVEZ95]L9V4@UGIE
M;&QI:VQE<FDN+BX`2U]U;&QA;OUC_6QA<@!A9')E<R!D969T97)I`'1A:W9I
M;0#];/UM;/T`8G5R87EA('3]:VQA>?UN`&-O;G1A8W0N=F-F`&-O;G1A8W1S
M+F-S=@!C;VYT86-T<RYT<W8`9/S^_'EO<@!D;W-Y80`E<R`H)7,I(&1E;B`E
M<R`E<R!D90!H.@!!8VEL`$UE=&YE(&?V;?QL_`!S873]<FQA<ET`;6MI<V]F
M<R!)4T\@>6%P87)K96X@:&%T82!K;V1U.B5D+@!A9`!G97+G96ML9?YT:7)I
M;&UE9&D`:&5N_'H@9V5RYV5K;&7^=&ER:6QM961I`&YO="!D969T97)I`'G\
M>F1E`')E<VEM(&)I<FEM:0!Y_&MS96QI>6]R`&9A<FML87+](&?V<W1E<@!(
M5%10('EO;'5Y;&$@<VUS,F5M86EL`'-A8FET`&?V<F5V(&QI<W1E<VD`<&%R
M;VQA>?T@9&_P<G5L86UA:R!IYVEN(&EK:2!D969A(&=I<FEN`&)I<FQE_G1I
M<FEL;6G^`&%D;&%N9/UR_6QM86W]_@!K=6QL86[]8_T@<V7G:6UI`'9#87)D
M`'<Z`'=E871H97(N8V]M````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE
M+W1R7U12+VAE;'`N>&UL````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R,S0S,``Q,#0Q-S,V,C<U-@`P,C$U,#8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E
M;F-O9&EN9STB:7-O+3@X-3DM.2(_/@H\(2TM("1(;W)D93H@='5R8F$O;&]C
M86QE+W1R7U12+VAE;'`N>&UL+'8@,2XQ+C(N,2`R,#`U+S$P+S$X(#$R.C4P
M.C$T(&IA;B!%>'`@)"`M+3X*/&AE;'`^"@H\(2TM($5N9VQI<V@@96YT<GDZ
M"CQE;G1R>2!I9#TB3W9E<G9I97<B/@H@("`@/'1I=&QE/D]V97)V:65W/"]T
M:71L93X*("`@(#QH96%D:6YG/DEN=')O9'5C=&EO;CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AE($%D9')E<W,@0F]O:R!P<F]V:61E<R!A(&-O;G9E
M;FEE;G0@;65T:&]D(&%N9"!P;&%C92!T;R!S=&]R92!C;VYT86-T(&EN9F]R
M;6%T:6]N(&9O<B!E87-Y(')E=')I979A;"!A;F0@=7-E+B!$97!E;F1I;F<@
M;VX@:&]W('EO=7(@861M:6YI<W1R871O<B!H87,@<V5T('5P('1H92!S>7-T
M96T@:70@8V%N('!R;W9I9&4@82!P<FEV871E(&%D9')E<W,@8F]O:R!A<R!W
M96QL(&%S(&%C8V5S<R!T;R!P=6)L:6,@;F5T=V]R:R!D:7)E8W1O<GD@<V5R
M=FEC97,N($ET(&%L<V\@<W5P<&]R=',@9&ES=')I8G5T:6]N(&QI<W1S('-O
M('EO=2!C86X@8W)E871E('EO=7(@;W=N(")M86EL:6YG(&QI<W1S+B(*("`@
M(#PO<&%R83X*/"]E;G1R>3X*+2T^"@H\96YT<GD@:60](D]V97)V:65W(B!M
M9#4](C(Y,#4P-F%D931E-F8W-#DR-#9F-S=B8F4U9#0X.#,U(B!S=&%T93TB
M=7!T;V1A=&4B/@H\=&ET;&4^1V5N96P@0F%K_?X\+W1I=&QE/@H\:&5A9&EN
M9SY486[]=/UM/"]H96%D:6YG/@H\<&%R83X*061R97,@1&5F=&5R:2!E<FG^
M:6T@;&ES=&5N:7II('-A:VQA;6%K('9E(&C]>FS]('-O<F=U;&%M86L@:>=I
M;B!I9&5A;"!B:7(@>6%P_63]<BX@4VES=&5M('GV;F5T:6-I;FEZ:6X@87EA
M<FQA;6%S_6YA(&)A\&S](&]L87)A:R!H97)K97-E(&'G_6L@=F5Y82!G:7IL
M:2!L:7-T96QE<B!Y87#];&%B:6QI<BX@07ER_6-A(&1A\/UT_6T@;&ES=&5L
M97)I(&EL92!K96YD:2!E+7!O<W1A(&QI<W1E;FEZ:2!Y87)A=&%B:6QI<G-I
M;FEZ+@H\+W!A<F$^"CPO96YT<GD^"@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB;65N=2UA9&0B/@H@("`@/'1I=&QE/DUE;G4Z($%D9#PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY!9&0\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($%D9"!A('5S97(@=&\@86X@861D<F5S<R!B;V]K+B!9;W4@8V%N(&]N;'D@
M861D('5S97)S('1O('1H92!A9&1R97-S(&)O;VMS('1O('=H:6-H('EO=2!H
M879E('=R:71E(&%C8V5S<RX@268@<VAA<F5D(&]R('!U8FQI8R!A9&1R97-S
M(&)O;VMS(&AA=F4@8F5E;B!E;F%B;&5D('1H97D@87)E(&]F=&5N(')E860M
M;VYL>2!A;F0@>6]U('=I;&P@;F]T(&)E(&%B;&4@=&\@861D(&-O;G1A8W1S
M('1O('1H96TN"B`@("`\+W!A<F$^"CPO96YT<GD^"BTM/@H*/&5N=')Y(&ED
M/2)M96YU+6%D9"(@;60U/2(S8S%F.3)E8C%A.#(X,SDT,#1D,3%D.6(P83(P
M8C-C92(@<W1A=&4](G5P=&]D871E(CX*/'1I=&QE/DUE;OPZ($5K;&4\+W1I
M=&QE/@H\:&5A9&EN9SY%:VQE/"]H96%D:6YG/@H\<&%R83X*061R97,@9&5F
M=&5R:6YI>F4@:W5L;&%N_6/];&%R_2!E:VQE>65B:6QI<G-I;FEZ+B!987IM
M82!I>FYI;FEZ(&]L86X@9&5F=&5R;&5R92!E:VQE;64@>6%P86)I;&ER<VEN
M:7HN($]R=&%K(&MU;&QA;OUL86X@=F5Y82!H97)K97-E(&'G_6L@9&5F=&5R
M;&5R(&GG:6X@<V%D96-E(&]K=6UA(&EZ;FD@;VQD=?!U;F1A;B!B=7)A;&%R
M82!K87ED961E;65Z<VEN:7HN"CPO<&%R83X*/"]E;G1R>3X*"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU+7-E87)C:"(^"B`@("`\=&ET
M;&4^365N=3H@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG/E-E87)C:#PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5A<F-H(&%N(&%D9')E<W,@8F]O
M:R!T;R!L;V-A=&4@:6YF;W)M871I;VXN(%1H:7,@:7,@:6YT96YD960@87,@
M82!Q=6EC:R!S96%R8V@@86YD(&]N;'D@86QL;W=S('EO=2!T;R!S96%R8V@@
M;VX@82!F97<@8F%S:6,@9FEE;&1S+B!5<W5A;&QY('1H:7,@:7,@=&AE(&YA
M;64@86YD(&5M86EL(&%D9')E<W,@9FEE;&1S+"!B=70@8V]U;&0@=F%R>2!D
M97!E;F1I;F<@;VX@:&]W('EO=7(@861M:6YI<W1R871O<B!S970@=7`@=&AE
M(&%D9')E<W,@8F]O:RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@1F]R
M(&$@;6]R92!C;VUP;&5X('-E87)C:"!Y;W4@8V%N('5S92!T:&4@)G%U;W0[
M/')E9B!M;V1U;&4](G1U<F)A(B!E;G1R>3TB;65N=2UA9'9A;F-E9"US96%R
M8V@B/D%D=F%N8V5D(%-E87)C:#PO<F5F/B9Q=6]T.R!W:&EC:"!P97)M:71S
M('-E87)C:&EN9R!O;B!O=&AE<B!F:65L9',N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"BTM/@H*/&5N=')Y(&ED/2)M96YU+7-E87)C:"(@;60U/2(X9&%F.#%A
M8C(X-C`R9#<W,C,U.&$Q-S0U-S%F.6%D,B(@<W1A=&4](G5P=&]D871E(CX*
M/'1I=&QE/DUE;G4Z($%R86UA/"]T:71L93X*/&AE861I;F<^07)A;6$\+VAE
M861I;F<^"CQP87)A/@I!<F%M82#V>F5L;&GP:2!B:7(@8FEL9VEN:6X@>65R
M:6YI(&)U;&UA:R!IYVEN9&ER+MUS:6TL92UP;W-T82!A9')E<VD@9VEB:2!T
M96UE;"#V>F5L;&EK;&5R(&AA:VO];F1A(&C]>FS]8V$@87)A;6$@>6%P86)I
M;&ER:V5N("P@8F'^:V$@]GIE;&QI:VQE<F4@9_9R92!A<F%M82!Y87!A8FEL
M:7`@>6%P86UA;6%N_7H@>?9N971I8VEN:6X@87EA<FQA;6%S_6YA(&)A\&S]
M9/UR+@H\+W!A<F$^"CQP87)A/@I$86AA(&=E;&G^:VEN(/9Z96QL:6ML97)I
M('-O<F=U;&%Y86)I;&UE:R!IYVEN("(\<F5F(&UO9'5L93TB='5R8F$B(&5N
M=')Y/2)M96YU+6%D=F%N8V5D+7-E87)C:"(^1V5L:?YM:?X@07)A;6$\+W)E
M9CXB(&UE;OQS_&[\(&MU;&QA;FUA;OUZ(&=E<F5K;65K=&5D:7(N"CPO<&%R
M83X*/"]E;G1R>3X*"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M
M96YU+6%D=F%N8V5D+7-E87)C:"(^"B`@("`\=&ET;&4^365N=3H@061V86YC
M960@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG/D%D=F%N8V5D(%-E87)C
M:#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5A<F-H(&%N(&%D9')E<W,@
M8F]O:R!T;R!L;V-A=&4@:6YF;W)M871I;VXN(%1H:7,@<V5A<F-H(&%L;&]W
M<R!Y;W4@=&\@<V5A<F-H(&]N(&UU;'1I<&QE(&9I96QD<RX@5VAI8V@@9FEE
M;&1S(&%R92!A=F%I;&%B;&4@9F]R('-E87)C:&EN9R!D97!E;F1S(&]N('1H
M92!A9&1R97-S(&)O;VL@8F5I;F<@<V5A<F-H960N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"BTM/@H*/&5N=')Y(&ED/2)M96YU+6%D=F%N8V5D+7-E87)C:"(@
M;60U/2(V8F4W,#-F9F5B838Q-&8V861A,34Q-S0Y9F$T-&%B-2(@<W1A=&4]
M(G5P=&]D871E(CX*/'1I=&QE/DUE;OPZ($=E;&G^;6G^($%R86UA/"]T:71L
M93X*/&AE861I;F<^1V5L:?YM:?X@07)A;6$\+VAE861I;F<^"CQP87)A/@I"
M=7)A9&$@8FER9&5N(&9A>FQA(&%L86X@:&%K:_UN9&$@87)A;6$@>6%P_6QA
M8FEL:7(N2&%N9VD@86QA;FQA<B#\>F5R:6YD92!A<F%M82!Y87#];&%B:6QE
M8V7P:2!H86YG:2!A9')E<R!D969T97)I;FEN(&AA;F=I(&%L86YL87+](&GG
M97)D:?!I;F4@8F'P;/UD_7(N"CPO<&%R83X*/"]E;G1R>3X*"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)M96YU+6EM<&]R="(^"B`@("`\=&ET
M;&4^365N=3H@26UP;W)T+T5X<&]R=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY)
M;7!O<G0O17AP;W)T/"]H96%D:6YG/@H*("`@(#QP87)A/@H@("`@5&AI<R!M
M96YU(&%L;&]W<R!I;7!O<G1I;F<@=&\@86YD(&5X<&]R=&EN9R!F<F]M('EO
M=7(@<&5R<V]N86P@861D<F5S<R!B;V]K+B!)="!S=7!P;W)T<R!B;W1H($-3
M5B`H0V]M;6$@4V5P87)A=&5D(%9A<FEA8FQE*2P@3W5T;&]O:RP@86YD('9#
M87)D(&9O<FUA=',L(&%S('=E;&P@87,@<V]M92!O=&AE<B!P;W!U;&%R(&9O
M<FUA=',N"B`@("`\+W!A<F$^"@H@("`@/&AE861I;F<^26UP;W)T:6YG/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!4;R!I;7!O<G0@86X@861D<F5S<R!B
M;V]K+"!Y;W4@;F5E9"!T;R!H879E('1H92!A9&1R97-S(&)O;VL@9&%T82!T
M;R!I;7!O<G0@;VX@>6]U<B!L;V-A;"!M86-H:6YE("AO;B!W:&EC:"!T:&4@
M=V5B(&)R;W=S97(@:7,@<G5N;FEN9RDN(%1O(&1O('1H:7,L('EO=2!W:6QL
M(&YE960@=&\@9FER<W0@97AP;W)T('1H92!A9&1R97-S(&)O;VL@:6YF;W)M
M871I;VX@9G)O;2!Y;W5R(&-U<G)E;G0@96UA:6P@8VQI96YT+@H@("`@/"]P
M87)A/@H*("`@(#QP87)A/@H@("`@268@>6]U('5S92!/=71L;V]K($5X<')E
M<W,Z"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(#$I($-L:6-K(&]N($9I
M;&4@/B!%>'!O<G0@/B!!9&1R97-S($)O;VL*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@,BD@4V5L96-T("9Q=6]T.U1E>'0@1FEL929Q=6]T.R`H0V]M
M;6$@4V5P87)A=&5D(%9A;'5E<RD@:6X@=&AE("9Q=6]T.T%D9')E<W,@0F]O
M:R!%>'!O<G0@5&]O;"9Q=6]T.RX@0VQI8VL@;VX@)G%U;W0[17AP;W)T)G%U
M;W0[+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`S*2!);B!T:&4@)G%U
M;W0[4V%V92!E>'!O<G1E9"!F:6QE<R!A<R9Q=6]T.R!F:65L9"P@='EP92!I
M;B!A(&YA;64@9F]R('EO=7(@861D<F5S<R!B;V]K+B!#;&EC:R`F<75O=#M.
M97AT)G%U;W0[+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`T*2!0=70@
M82!C:&5C:VUA<FL@:6X@=&AE(&)O>"!T;R!T:&4@;&5F="!O9B!E86-H(&]F
M('1H92!F:65L9',@=&AA="!Y;W4@=VES:"!T;R!E>'!O<G0N($-L:6-K("9Q
M=6]T.T9I;FES:"9Q=6]T.RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M-2D@66]U('-H;W5L9"!R96-E:79E(&$@;65S<V%G92!T:&%T('-T871E<R`G
M061D<F5S<R!B;V]K(&5X<&]R="!P<F]C97-S(&AA<R!C;VUP;&5T960G+B!#
M;&EC:R`G3TLG+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`V*2!#;&EC
M:R`G0VQO<V4G(&]N('1H92`G061D<F5S<R!";V]K($5X<&]R="!4;V]L)R!A
M;F0@8VQO<V4@3W5T;&]O:R!%>'!R97-S+@H@("`@/"]P87)A/@H*("`@(#QT
M:7`^"B`@("!)9B!T:&4@97AP;W)T960@861D<F5S<R!B;V]K(&9I;&4@:7,@
M;F]T(&QO8V%T960@;VX@>6]U<B!D97-K=&]P+"!A;F0@>6]U)W)E('5S:6YG
M(&$@5VEN9&]W<R!O<&5R871I;F<@<WES=&5M+"!C;&EC:R!O;B!3=&%R="`^
M($9I;F0@;W(@4V5A<F-H(#X@1FEL97,@;W(@1F]L9&5R<R!A;F0@<V5A<F-H
M('EO=7(@;6%I;B!H87)D(&1R:79E(&9O<B!T:&4@9FEL92!N86UE('1H870@
M>6]U('5S960@:6X@<W1E<"`S+B!-86ME(&$@;F]T92!O9B!T:&4@9FEL92=S
M(&QO8V%T:6]N+@H@("`@/"]T:7`^"@H@("`@/'!A<F$^"B`@("!4;R!I;7!O
M<G0@86X@861D<F5S<R!B;V]K+"!O<&5N('1H92!A9&1R97-S(&)O;VL@>6]U
M('=A;G0@=&\@:6UP;W)T('1H92!I;F9O<FUA=&EO;B!I;G1O+B!#;&EC:R!O
M;B!T:&4@)G%U;W0[26UP;W)T+T5X<&]R="9Q=6]T.R!)8V]N+B!396QE8W0@
M=&AE('1Y<&4@;V8@861D<F5S<R!I;F9O<FUA=&EO;B!D871A(&9I;&4@>6]U
M('=A;G0@=&\@:6UP;W)T(&9R;VT@=&AE('-E;&5C=&EO;B!L:7-T+B!#;&EC
M:R!O;B!T:&4@)G%U;W0[8G)O=W-E)G%U;W0[(&)U='1O;B!T;R!L;V]K(&9O
M<B!T:&4@861D<F5S<R!D871A(&9I;&4@;VX@>6]U<B!C;VUP=71E<BX@4V5L
M96-T('1H92!F:6QE+"!A;F0@8VQI8VL@;VX@=&AE("9Q=6]T.TEM<&]R="9Q
M=6]T.R!B=71T;VXN(%1H92!I;F9O<FUA=&EO;B!I;B!T:&4@9FEL92!W:6QL
M(&)E(&EM<&]R=&5D(&EN=&\@>6]U<B!A9&1R97-S(&)O;VLN"B`@("`\+W!A
M<F$^"B`@("`\=&EP/@H@("`@4V]M92!C;VUP;&5X(&5N=')I97,L(&]R(&5N
M=')I97,@=VET:"!F:65L9',@=&AA="!D;R!N;W0@;6%T8V@@>6]U<B!A9&1R
M97-S(&)O;VL@9FEE;&1S+"!M87D@;F]T(&EM<&]R="!C;W)R96-T;'DN(%EO
M=2!S:&]U;&0@=F5R:69Y('1H92!I;7!O<G1E9"!D871A(&%F=&5R(&%N(&EM
M<&]R="X*("`@(#PO=&EP/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB;65N
M=2UI;7!O<G0B(&UD-3TB,V,V8S0P9C)A-C(Q,V4Y9F,Q9CEA-S<X,C=B9F(U
M9#0B('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y-96YU.D%L_6T@=F4@1_9N
M9&5R:6T\+W1I=&QE/@H\:&5A9&EN9SY!;/UM('9E($?V;F1E<FEM/"]H96%D
M:6YG/@H\<&%R83X*0G4@;65N_"!A<F%C_6S]\/UY;&$@861R97,@9&5F=&5R
M:6YI>FD@8F'^:V$@8FER(&MA>6YA\&$@86QA8FEL:7(@=F5Y82!B8?YK82!B
M:7(@:V%Y;F%K=&%N(&%D<F5S(&1E9G1E<FEN:7IE(&1A:&EL(&5D96)I;&ER
M<VEN:7HN0U-6+$]U=&QO;VLL('9E('9#87)D(&=I8FD@9&%H82!P96L@YV]K
M('!O</QL97(@8FGG:6UL97(@9&5S=&5K;&5N;65K=&5D:7(N"CPO<&%R83X*
M/&AE861I;F<^06S];3PO:&5A9&EN9SX*/'!A<F$^"D)A_FMA(&)I<B!K87EN
M86MT86X@;&ES=&4@86S];?T@]FYC97-I;F1E("P@86QM86L@:7-T961I\&EN
M:7H@;&ES=&4@8FEL9VES:6YI(&)U;'5N9'7P=2!E+7!O<W1A(&ES=&5M8VES
M:6YD96X@87ER_2!B:7(@9&]S>6%Y82#G_6MA<FUA;/US_6[]>BX*/"]P87)A
M/@I/=71L;V]K($5X<')E<W,@:W5L;&%N_7EO<G-A;OUZ.PH\<&%R83X*(D9I
M;&4@)F=T.R!%>'!O<G0@)F=T.R!!9&1R97-S($)O;VLB(&UE;OQS_&YE('3]
M:VQA>?UN_7HN"CPO<&%R83X*/'!A<F$^"B)!9&1R97-S($)O;VL@17AP;W)T
M(%1O;VPB(&1A;B`B5&5X="!&:6QE(B`H0V]M;6$@4V5P87)A=&5D(%9A;'5E
M<RD@:2!S9>=I;FEZ+D)U<F%D82!D82`B17AP;W)T(B!I('-EYVEN:7HN"CPO
M<&%R83X*/'!A<F$^"B)3879E(&5X<&]R=&5D(&9I;&5S(&%S(B`@86QA;OUN
M82#G_6MA<OUL86-A:R!L:7-T92!D;W-Y87/];OUN(&MA>61E9&EL96-E\&D@
M863](&=I<FEN:7H@=F4@(DYE>'0B(&$@8F%S_6[]>BX*/"]P87)A/@H\<&%R
M83X*Q_UK87+];&UA<_UN_2!I<W1E9&GP:6YI>B!A;&%N;&%R_2!S9>=M96L@
M:>=I;B!S;VP@>6%N;&%R_6YD86MI(&MU='5C=6ML87+](&G^87)E=&QE>6EP
M(")&:6YI<V@B(&$@8F%S_6[]>BX*/"]P87)A/@H\<&%R83X*W?YL96T@8FET
M:6YC92`G061D<F5S<R!B;V]K(&5X<&]R="!P<F]C97-S(&AA<R!C;VUP;&5T
M960G(&UE<V%J_2!A;&%C86MS_6[]>BY"=7)A9&$@)T]+)R!D:7EE<F5K(&G^
M;&5M:2!B:71I<F5B:6QI<G-I;FEZ+@H\+W!A<F$^"CQP87)A/@HG061D<F5S
M<R!";V]K($5X<&]R="!4;V]L)R!M96[\<_QN_"!K87!A=/UN_7H@<V]N<F$@
M9&$@3W5T;&]O:R!%>'!R97-S('1E;B#G_6O];OUZ+@H\+W!A<F$^"CQP87)A
M/@K'_6MA<OUL86X@9&]S>6%Y_2!B=6QA;6%M86[]>B!D=7)U;75N9&$@5VEN
M9&]W<R!I_FQE=&EM('-I<W1E;6D@:W5L;&%N_7EO<G-A;OUZ(%-T87)T("9G
M=#L@1FEN9"!M96[\<_QN9&5N(%-E87)C:"`F9W0[($9I;&5S(&]R($9O;&1E
M<G,@:2!S9>=E<F5K('EU:V%R9&$@9VER9&GP:6YI>B!D;W-Y82!A9/UN_2!A
M<F%T_7`@8G5N=2!N;W0@971M96YI>B!T879S:7EE(&5D:6QI<BX*/"]P87)A
M/@H\=&EP/@K'_6MA<OUL86X@9&]S>6%Y_2!Y_&ML96UE:R!IYVEN(")!;/UM
M+\?]:V%R_6TB(&UE;OQS_&YE(&=I<FEN:7HN(F?V>F%T(B!I;&4@9&]S>6%N
M_7K](&)U;&1U:W1A;B!S;VYR82`B06S];2(@<V7G96YE\&D@:6QE(&1O<WEA
M;OUZ_2!L:7-T96YI>F4@9&%H:6P@961E8FEL:7)S:6YI>BX*/"]T:7`^"CQT
M:7`^"D5K;&5N96X@9&]S>6$@:>=I;F1E:VD@:VEM:2!A;&%N(&)I;&=I;&5R
M:2!M979C=70@861R97,@9&5F=&5R:6YD96X@9F%R:VS];/UK(&?V<W1E<FEY
M;W)S82!V8BXN(&MA<FUA_OUK(&1U<G5M;&%R9&$@96ML96UE('-O;G5C=6YD
M82!S;W)U;FQA<B!O;'7^86)I;&ER+B!"=2!N961E;FQE(&G^;&5M:6X@87)D
M_6YD86X@861R97,@9&5F=&5R:6YI>FD@:V]N=')O;"!E=&UE;FEZ('1A=G-I
M>64@;VQU;G5R+@H\+W1I<#X*/"]E;G1R>3X*"@H\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB<V5A<F-H:6YG+7-E87)C:%]R97-U;'1S(CX*("`@
M(#QT:71L93Y396%R8VAI;F<Z(%-E87)C:"!297-U;'1S/"]T:71L93X*("`@
M(#QH96%D:6YG/E-E87)C:"!297-U;'1S/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!)9B!A('-E87)C:"!I<R!S=6-C97-S9G5L+"!T:&4@<F5S=6QT<R!W
M:6QL('-H;W<@=7`@:6X@=&AE("9Q=6]T.U-E87)C:"!297-U;'1S)G%U;W0[
M(&%R96$N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-L:6-K:6YG(&]N
M(&%N("9Q=6]T.T5M86EL)G%U;W0[(&9I96QD(&5N=')Y('=I;&P@;W!E;B!A
M(&YE=R!#;VUP;W-E('=I;F1O=R!T;R!S96YD(&UA:6P@=&\@=&AA="!A9&1R
M97-S+B!#;&EC:VEN9R!O;B!A("9Q=6]T.TYA;64F<75O=#L@9FEE;&0@96YT
M<GD@=VEL;"!D:7-P;&%Y('1H92!A9&1R97-S(&)O;VL@<F5C;W)D(&9O<B!T
M:&%T(&YA;64L(&%L;&]W:6YG('EO=2!T;R!T:&5N(&5D:70@;W(@9&5L971E
M('1H92!E;G1R>2X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@1&5P96YD
M:6YG(&]N(&AO=R!Y;W5R('-Y<W1E;2!H87,@8F5E;B!S970@=7`@8GD@=&AE
M(&%D;6EN:7-T<F%T;W(@<V5A<F-H(')E<W5L=',@8V%N(&)E(&-U;75L871I
M=F4N($5A8V@@<V5A<F-H('=I;&P@861D(&%N>2!N97<@<F5S=6QT<R!T;R!Y
M;W5R(&5X:7-T:6YG(')E<W5L=',N(%1H:7,@:7,@:&5L<&9U;"!W:&5N(&)U
M:6QD:6YG(&QI<W1S+B!4;R!R96UO=F4@=&AE(')E<W5L=',@;V8@8W5M=6QA
M=&EV92!S96%R8VAE<R!A;F0@<W1A<G0@82!N97<@<V5A<F-H+"!C;&EC:R!O
M;B!T:&4@)G%U;W0[0VQE87(@4V5A<F-H)G%U;W0[(&QI;FLN"B`@("`\+W!A
M<F$^"@H@("`@/'1I<#X*("`@(%=H96X@=FEE=VEN9R!A(&QI<W0@;V8@96YT
M<FEE<RP@>6]U(&-A;B!S;W)T('1H92!E;G1R:65S(&)Y(&5A8V@@9FEE;&0@
M<VAO=VX@8GD@8VQI8VMI;F<@;VX@=&AE(&%P<')O<')I871E(&-O;'5M;B!H
M96%D:6YG+B!4;R!S=VET8V@@8V]L=6UN<R!B971W965N(&%S8V5N9&EN9R!A
M;F0@9&5S8V5N9&EN9R!S;W)T(&]R9&5R+"!C;&EC:R!O;B!T:&4@87)R;W<@
M:6-O;B!I;B!T:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W1I<#X*/"]E;G1R
M>3X*+2T^"@H\96YT<GD@:60](G-E87)C:&EN9RUS96%R8VA?<F5S=6QT<R(@
M;60U/2)F9F5D.&0W,F9A,V(W,3!D9CAE.3`R8S(T.3-B,C4T9B(@<W1A=&4]
M(G5P=&]D871E(CX*/'1I=&QE/D%R86UA.B!!<F%M82!3;VYUYVQA<OT\+W1I
M=&QE/@H\:&5A9&EN9SY!<F%M82!3;VYUYVQA<OT\+VAE861I;F<^"CQP87)A
M/@I"8?YA<OUL_2!A<F%M82!S;VYUYVQA<OUN_6X@;&ES=&5S:2`B07)A;6$@
M4V]N=>=L87+](B!M96[\<_QN9&5N(&?V<OQN=/QL96YE8FEL96-E:W1I<BX*
M/"]P87)A/@H\<&%R83X*(D5P;W-T82(@;65N_'/\;OQN('-EYVEM:2!I;&4@
M8G5L=6YA;B!S;VYUYR!A9')E<V4@92UP;W-T82!A=/UL86)I;&ER+B+=<VEM
M(B!A;&%N_6YD86X@87)A;6$@<V]N=6-U;F1A:VD@:7-I;2!A;&%N_2!D_'IE
M;FQE;F5B:6QI<BX*/"]P87)A/@H\<&%R83X*07)A;6$@<V]N=>=L87+](/9N
M8V5K:2!A<F%M82!S;VYUYVQA<OUN82!I;&%V971E;B!G]G-T97)I;&EY;W(@
M;VQA8FEL:7(N0G4@<VES=&5M('GV;F5T:6-I<VEN:6X@87EA<OUN82!B8?!L
M_63]<BY"=2!D=7)U;61A(/9N8V5K:2!A<F%M82!S;VYUYVQA<OUN_2`B07)A
M;6%Y_2!3:6PB(&UE;OQS_"!I;&4@<VEL96)I;&ER<VEN:7HN"CPO<&%R83X*
M/'1I<#X*1VER:?YL97)I;B!L:7-T97-I;FD@9_9R_&YT_&QE<FME;BP@9VER
M:?YL97)I(&AE<FAA;F=I(&)I<B!S_'1U;F$@9_9R92!O('/\='5N=6X@8F'^
M;/WP_6YA('3]:VQA>6%R86L@<_UN_69L86YD_7)A8FEL:7)S:6YI>BX@4_QT
M=6YU('G\:W-E;&5N('9E(&%LYV%L86X@<_UN_69L86YD_7)M82!A<F%S_6YD
M82!D9?!I_G1I<FUE:R!IYVEN+"!S_'1U;B!B8?YL_?#];F1A:VD@;VL@<VEM
M9V5S:6YI('3]:VQA>?UN+@H\+W1I<#X*/"]E;G1R>3X*"CPO:&5L<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+W5K
M7U5!+P``````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<U-@`P,C`P,#<`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T=7)B82]L;V-A;&4O=6M?54$O3$-?34534T%'15,O````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4V`#`R,34W-``@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92]U:U]502],0U]-15-3
M04=%4R]T=7)B82YM;P``````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(T,#(`,3`T,3<S
M-C(W-38`,#(S,C0R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````70```!P````$`P``?P```.P%````````Z`<`
M`"@```#I!P``'0```!((```(````,`@```,````Y"```#P```#T(```(````
M30@```@```!6"```&0```%\(```'````>0@```X```"!"```#P```)`(```%
M````H`@``!$```"F"```%0```+@(```*````S@@```P```#9"```!P```.8(
M```0````[@@```(```#_"```!0````()```0````"`D```8````9"0``#P``
M`"`)```4````,`D```D```!%"0``!````$\)```%````5`D```T```!:"0``
M!0```&@)```+````;@D```\```!Z"0``!@```(H)```B````D0D```,```"T
M"0``!````+@)```$````O0D```0```#""0``#````,<)```*````U`D```4`
M``#?"0``$@```.4)```0````^`D``!`````)"@``&@```!H*```&````-0H`
M``<````\"@```@```$0*```$````1PH```@```!,"@``#P```%4*```'````
M90H```<```!M"@``!````'4*```%````>@H```@```"`"@``%0```(D*```>
M````GPH```4```"^"@``*````,0*```I````[0H``!,````7"P``"P```"L+
M```%````-PL``!$````]"P``!````$\+```$````5`L```P```!9"P``!@``
M`&8+```:````;0L``!<```"("P``&@```*`+```7````NPL``!,```#3"P``
M$````.<+```7````^`L```<````0#```!0```!@,```#````'@P``"0````B
M#```"````$<,```4````4`P```<```!E#```!@```&T,```+````=`P```P`
M``"`#```"@```(T,```"````F`P```8```";#```10```*(,```F````Z`P`
M`"4````/#0``$````#4-``!I`0``1@T``#H```"P#@``'0```.L.```)````
M"0\```8````3#P``&@```!H/```+````-0\``!(```!!#P``(@```%0/```&
M````=P\```\```!^#P``$````(X/```)````GP\```X```"I#P``'P```+@/
M```4````V`\```T```#M#P``"P```/L/```4````!Q````(````<$```!P``
M`!\0```0````)Q````<````X$```$@```$`0```0````4Q````H```!D$```
M"@```&\0```'````>A```!,```""$```!P```)80```-````GA```!(```"L
M$```!P```+\0```?````QQ````0```#G$```!@```.P0```!````\Q````@`
M``#U$```#@```/X0```0````#1$```4````>$0``%````"01```1````.1$`
M`!D```!+$0``*0```&41```&````CQ$```4```"6$0```@```)P1```*````
MGQ$```T```"J$0``#P```+@1```$````R!$```@```#-$0``!````-81```'
M````VQ$```8```#C$0``&````.H1```?`````Q(```<````C$@``*0```"L2
M```N````51(```T```"$$@``#````)(2```(````GQ(``!0```"H$@``!```
M`+T2```(````PA(```X```#+$@``!0```-H2```9````X!(``!4```#Z$@``
M&@```!`3```5````*Q,``",```!!$P``%P```&43```9````?1,```<```"7
M$P``!0```)\3```#````I1,``"@```"I$P``$0```-(3```6````Y!,```4`
M``#[$P``!P````$4```-````"10```T````7%```#P```"44```"````-10`
M``<````X%```10```$`4```Q````AA0``#$```"X%```%P```.H4```!````
M(@```"\`````````2`````T```!0````&0``````````````3````"T```!7
M````%````#$`````````.P````8``````````@````0```!!````(0```!,`
M```R````5````$8````Y````)@```#@```!2````'``````````U````&P``
M`"4```!)`````````!8````P``````````````!.````5@````<````_````
M&```````````````"P```$H````L````!0```$,````I````#`````X```!3
M````3P```",`````````0````"X```!1`````P```"@``````````````$4`
M``!9````&@```"`````Z````'@`````````?`````````$L````2````````
M``````!'```````````````7`````````!````!5````*@`````````V````
M"``````````/````0@```!$```!=``````````````!-`````````!4```!<
M````'0````H````)`````````#P````G`````````"L`````````-P```#X`
M``!$````6P```%@````S`````````"0``````````````#T`````````-```
M`%H``````````"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VX`)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`,C0@:&]U<G,`
M061D`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E<@!!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061M:6YI<W1R871I;VX`061V
M86YC960@4V5A<F-H`$%L:6%S`$%V86EL86)L92!F:65L9',Z`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E(%=I;F1O=P!#;VUP86YY
M`$-O;F9I<FT@4&%S<W=O<F0`1$0`1&%I;'D`1&5F875L="!)9&5N=&ET>0!$
M96QE=&4`1&5L971I;VX@9F%I;&5D`$1E<V-R:6)E('1H92!0<F]B;&5M`$1I
M<F5C=&]R>0!%9&ET`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@
M3&]G:6X`17AA;7!L92!V86QU97,Z`$5X<&]R=`!&86EL960@=&\@<V5A<F-H
M('1H92!D:7)E8W1O<GDZ("5S`$9A>`!&:6YD`$9R;VT`2&5L<`!(;VUE($%D
M9')E<W,`2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<`
M36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`36]N=&AL>0!.86UE`$YO=&5S`%!A
M<W-W;W)D`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER
M`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V90!3879E($]P=&EO
M;G,`4V5A<F-H`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;F0@4')O8FQE;2!297!O<G0`4VMI
M<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S
M`%1I=&QE`%523`!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E
M<RX`57-E<FYA;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN9P!7965K
M;'D`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A
M<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@
M8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N`%M0<F]B;&5M(%)E<&]R=%T`4')O:F5C="U)9"U6
M97)S:6]N.B!4=7)B82!V,2XP+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`Q+3`U(#$U
M.C,U*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!!;F1R:7D@2V]P>7-T>6%N<VMY
M(#QA;G)I0'!O;'EN970N;'9I=BYU83X*3&%N9W5A9V4M5&5A;3H@56MR86EN
M:6%N(#QW96)M87-T97)`<&]L>6YE="YL=FEV+G5A/@I-24U%+59E<G-I;VXZ
M(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]2T])."U5
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@#OT,72P<.FT2#0
MTL_&ILS!R]3)WL[/Q\\@S\+3S-7'S]?5U\'.SM$@)7,@+2#PIL34U\72Q-;%
MSL[1`"`E<R#&P<K,(-73T*;;SL\@ILW0S]+4S]?!SLG*`#(T(,?/Q,G.R0#D
MS\3!U,D`Y,_$P=3)(,[/U\_'SR#+S]+)T]35U\'>P3H`Y,_$P=3)(-#!TM4`
MY,_$P=3)(,O/TLG3U-77P=[!`.3/Q,'7P<[.T2#+S]+)T]35U\'>IM<@VL'"
MS]+/SL7.Q2X`X<32Q=/!`.'$S:;.IM/4TM77P<[.T0#RS]K;R=+%SLG*(/#/
MV]7+`/#3Q=?$S\ZFS0#DS]/4U=#.IB#0S\S1.@#WIL3-IL[)U,D@T,_7IL3/
MS<S%SL[1(-#2S\+,Q<W)`//4ILS8SLG+S]?)RB#4Q<S%QL_.`/K!R]+)U,D@
MUZ;+SL\`[]+'P<ZFVL'#IM$`\*;$U-?%TL36Q<[.T2#0P=+/S,``Y.0`_<_$
MQ<[.SP#OT\[/U\[!(*;0S]/4P=/8`/?)U,72U,D`[L4@U\3!S,_3T2#WR=3%
MTM3)`._0R=NFU-@@T-+/PLS%S=4`Y,G2Q<O4S]*FT0#RQ<3!Q]77P=3)`.4M
MT,_;U,$`\,_2S];.ILH@TL7:U<S8U,'4+@#PS\W)S,O!`.O/UL[/Q\\@U\C/
MQ-4`Y,'.IB#$S-$@T-+)R\S!Q-4Z`.7+T]#/TM0`[L77Q,'>P2#0S]O5R]4@
MUR#$R=+%R]3/TJ:G.B`E<P#FP<O3`/K.P<K4R0#7`.3/T,_-S\?!`.3/S<';
MSM$@P<32Q=/!`.3/S<';SJ;*(-3%S,7&S\X`2&]R9&4`MLW0S]+4S]?!SL4@
MT,_,Q3H@)7,`MLW0S]+4S]?!SJ8@T,_,T3H`\,72Q<RFRR#2S]K$ILRFUR#D
MS]#/S<_'R0#PQ=+%Q\S1Q"#3T,G3R]4@R\_2R=/4U=?!WJ;7(-K!PL_2S\[%
MSLG*+@#WUZ;*U,D`]\G*U,D`[>T`24U0+=#/TM3!S`#=SR#7IL30S]>FQ,&D
M`/>FQ-#/UZ;$SJ8@T,_,T0#LR=/4`/W/S:;3T</1`$G-8-$`[L_4P=3+R0#P
MP=+/S-@`\,'2S\S8(,W5T\G4V"#3T*;7T,'3U,DN`/?)R\_.P=3)(-#2S\:F
MS,'+U,G>SJ8@S]#%TL'#IJ<`],7,Q<;/S@#BU<38+<S!T\O!+"#$P<K4Q2#+
MS]+/U,O)RB#/T,G3(-#2S\+,Q<W)+@#BU<38+<S!T\O!+"#7R\'6IM38(,[!
MVM?5(,O/TLG3U-77P=[!(*8@T,'2S\S8`._0R=,@T-+/PLS%S<D`]\G4Q=+4
MR2#0P=+5`._>R=/4R=3)`/#/U\72SM74R=/1(,3/(._0PZ;*`/+/S-@`^L+%
MTL7'U,D`^L+%TL7'U,D@S]##IJ<`\,_;U<L`]\G"Q=*FU-@@TL_:Q*;,P-?!
MWB#$P=3).@#WR<+%TJ;4V"#&S]+-P=0@Q,'4R3H`]\G"Q=*FU-@@QL'*S"#$
MS-$@ILW0S]+4U3H`]\G"Q=*FU-@@QL_2S<'4(-[!T]4Z`/>FQ*;3S,'4R2#0
MS]>FQ,_-S,7.SM$@T-+/(-#2S\+,Q<W5`/#2S]#5T]3)U,D@T-+/QJ;,P<O4
MR<O5`/?7IL0@\]#%PZ;!S-C.R<@@T\G-U\_,IM<`]=/0IMO.SP#TR=35S`!5
M4DP`[L7-S];,R=?/(-K!U\'.U,'6R=3)(-?)VL[!WL7.SM$@Q,S1("5S+@#N
MP=K7P2#+S]+)T]35U\'>P0#KS]+)T]35U\'>IB#7(-/)T]3%S:8Z`/77P<?!
M`/W/U,G6SM$`]Z;4P<`@]\'3+"`E<P#RS\+/WL$@P<32Q=/!`/+/PL_>R<H@
MU,7,Q<;/S@#R\@#]S]*FWL[/`/?)(-#/U\G.SJ8@S]#)T\'4R2#0TL_"S,7-
MU2P@T,72VR#.IM8@UZ;$T\G,P=3)(-#/UZ;$S\W,Q<[.T2#0TL\@SL6G+@#W
MP<T@T\RFQ"#7R\':P=3)(,[!VM?5(,O/TLG3U-77P=[!(,3,T2#7R<3!S,7.
MSM$N`/?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(,3/
MQ,'7P<[.T2X`6_#/UZ;$S\W,Q<[.T2#PTL_"S,7-R5T`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U
M<F)A+VQO8V%L92]Z:%]#3B\`````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-38`,#(P,#`T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O='5R8F$O;&]C86QE+WIH7T-.+TQ#7TU%4U-!1T53
M+P`````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U
M-@`P,C$U-S$`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O
M>FA?0TXO3$-?34534T%'15,O='5R8F$N;6\`````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,3<V-C8V`#$P-#$W,S8R-S4V`#`R,S(V-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````&\$```<````E",``/,%
M```,1P```````-A>```.````V5X```\```#H7@``"````/A>```,`````5\`
M``0````.7P``#P```!-?```+````(U\```X````O7P``!0```#Y?```H````
M1%\```H```!M7P``%0```'A?```2````CE\```L```"A7P``'0```*U?```.
M````RU\```H```#:7P``#0```.5?```&````\U\```\```#Z7P``&`````I@
M```,````(V````@````P8```+@```#E@```:````:&```#(```"#8```.```
M`+9@``!4````[V```%$```!$80``6@```)9A``!7````\6$``#0```!)8@``
M!0```'YB```&````A&(``!$```"+8@``"````)UB```E````IF(``"````#,
M8@``#P```.UB```*````_6(```,````(8P``#P````QC```4````'&,```D`
M```Q8P``#0```#MC```2````26,```\```!<8P``#P```&QC```(````?&,`
M`"0```"%8P``"````*IC```9````LV,```<```#-8P``+````-5C```.````
M`F0```,````19```#P```!5D```+````)60```<````Q9```!P```#ED```%
M````060``!<```!'9```"@```%]D```/````:F0``!@```!Z9```#@```)-D
M```4````HF0``!<```"W9```%P```,]D```3````YV0```X```#[9```'P``
M``IE```'````*F4```8````R90``"````#EE```/````0F4```H```!290``
M$P```%UE```+````<64``!4```!]90``%0```)-E```'````J64```4```"Q
M90``%0```+=E```1````S64```P```#?90``.P```.QE```)````*&8```<`
M```R9@``%````#IF```%````3V8``!````!59@``$P```&9F```Y````>F8`
M`"<```"T9@``+````-QF```J````"6<``"4````T9P``"@```%IG```&````
M96<```D```!L9P``!P```'9G```O````?F<``#<```"N9P``+@```.9G``!5
M````%6@``"T```!K:```+0```)EH```M````QV@``$````#U:```(P```#9I
M```C````6FD``"T```!^:0``,P```*QI```5````X&D``!D```#V:0``*0``
M`!!J```D````.FH``!$```!?:@``"@```'%J```0````?&H``!8```"-:@``
M%@```*1J```'````NVH```<```##:@``%````,MJ```*````X&H```@```#K
M:@``!P```/1J```'````_&H```8````$:P``!0````MK```'````$6L```8`
M```9:P``#@```"!K```*````+VL```0````Z:P``!P```#]K```)````1VL`
M`!8```!1:P``"````&AK```-````<6L```8```!_:P``'@```(9K```1````
MI6L```@```"W:P``#0```,!K```,````SFL```<```#;:P```P```.-K```#
M````YVL``!<```#K:P``"`````-L```$````#&P```@````1;```"````!IL
M```@````(VP```8```!$;```!@```$ML```5````4FP``!@```!H;```'0``
M`(%L``!4````GVP``"D```#T;```"@```!YM```.````*6T```H````X;0``
M%````$-M```8````6&T``!T```!Q;0``$P```(]M```4````HVT```0```"X
M;0``!@```+UM```%````Q&T```4```#*;0``&P```-!M```:````[&T``!$`
M```';@``$0```!EN```<````*VX``!````!(;@``(0```%EN```1````>VX`
M``P```"-;@``!@```)IN```7````H6X```@```"Y;@``!0```,)N```,````
MR&X```8```#5;@``!P```-QN```-````Y&X```<```#R;@``"P```/IN```'
M````!F\```<````.;P``"@```!9O```,````(6\``!`````N;P``!0```#]O
M```E````16\``!,```!K;P``.P```']O```@````NV\```P```#<;P``#@``
M`.EO```*````^&\```T````#<```'@```!%P```;````,'```"$```!,<```
M'@```&YP```>````C7```!L```"L<```'@```,AP```S````YW```"\````;
M<0``$@```$MQ```I````7G$``!(```"(<0``%@```)MQ```H````LG$``"``
M``#;<0``(0```/QQ``!!````'G(```<```!@<@``$@```&AR```3````>W(`
M`!(```"/<@``!P```*)R```$````JG(```P```"O<@``#P```+QR```3````
MS'(```T```#@<@``#0```.YR```&````_'(``!$````#<P``%P```!5S```;
M````+7,```X```!)<P```@```%AS```%````6W,```0```!A<P``#0```&9S
M```.````=',```,```"#<P``"````(=S```/````D',``!````"@<P``!@``
M`+%S```,````N',``!$```#%<P``&0```-=S```/````\7,```T````!=```
M!P````]T```4````%W0``"(````L=```+P```$]T```+````?W0```D```"+
M=```&0```)5T```+````KW0``!<```"[=```%P```--T```)````ZW0``!8`
M``#U=```#@````QU```(````&W4```T````D=0``)@```#)U``!#````674`
M``@```"==0``$@```*9U```+````N74``"\```#%=0``#@```/5U```&````
M!'8```,````+=@``!P````]V```$````%W8```H````<=@``"@```"=V```/
M````,G8``!````!"=@``%P```%-V```1````:W8``!<```!]=@``!0```)5V
M```+````FW8```T```"G=@``&P```+5V```7````T78```D```#I=@``#@``
M`/-V```-`````G<```@````0=P``#@```!EW```1````*'<```<````Z=P``
M!0```$)W```'````2'<```@```!0=P``!@```%EW```0````8'<``!````!Q
M=P``#P```()W```+````DG<```\```">=P``#````*YW```/````NW<```<`
M``#+=P``!@```--W```/````VG<```@```#J=P``!@```/-W```3````^G<`
M`!X````.>```(0```"UX```@````3W@``!D```!P>```%P```(IX```E````
MHG@``!<```#(>```(@```.!X```;`````WD```T````?>0```P```"UY```(
M````,7D```H````Z>0``#````$5Y```$````4GD``!,```!7>0``%````&MY
M```,````@'D```D```"->0``"P```)=Y```;````HWD```<```"_>0``!```
M`,=Y```'````S'D```H```#4>0``#0```-]Y```)````[7D```0```#W>0``
M&````/QY```*````%7H``'P````@>@``!0```)UZ```'````HWH```P```"K
M>@``"````+AZ```&````P7H```@```#(>@```@```-%Z```&````U'H```T`
M``#;>@``$````.EZ```)````^GH``!`````$>P``"0```!5[```)````'WL`
M``4````I>P``!@```"][```9````-GL```<```!0>P``!P```%A[```%````
M8'L```D```!F>P``"@```'![```"````>WL```T```!^>P``"0```(Q[```&
M````EGL``!(```"=>P``"0```+![```'````NGL``!0```#">P``'0```-=[
M```&````]7L```H```#\>P``!`````=\```)````#'P```@````6?```$0``
M`!]\```)````,7P```8````[?```#0```$)\```&````4'P```0```!7?```
M'@```%Q\```%````>WP```X```"!?```!@```)!\```A````EWP``!4```"Y
M?```!````,]\```1````U'P```8```#F?```(@```.U\```=````$'T```0`
M```N?0``#````#-]```*````0'T```@```!+?0``"0```%1]```%````7GT`
M``\```!D?0``)````'1]```(````F7T```H```"B?0``!P```*U]```@````
MM7T``"````#6?0``)@```/=]```9````'GX``"D````X?@``!P```&)^```*
M````:GX```\```!U?@``#````(5^```&````DGX```\```"9?@``$@```*E^
M```0````O'X``!P```#-?@``#P```.I^```%````^GX``!``````?P``"0``
M`!%_```$````&W\```L````@?P``#````"Q_```/````.7\``!D```!)?P``
M#P```&-_```3````<W\``!(```"'?P``!P```)I_```,````HG\``"````"O
M?P``%````-!_```1````Y7\``!<```#W?P``'`````^````3````+(```!$`
M``!`@```&@```%*````>````;8```!H```",@```$0```*>````7````N8``
M`!4```#1@```&0```.>````$`````8$```<````&@0``"P````Z!```&````
M&H$```8````A@0``!@```"B!```%````+X$```<````U@0``!P```#V!```%
M````18$``!8```!+@0``!@```&*!```&````:8$```0```!P@0``!````'6!
M```.````>H$```P```")@0``#````):!```-````HX$```H```"Q@0``#@``
M`+R!```%````RX$``"@```#1@0``#````/J!```/````!X(```H````7@@``
M"````"*"```)````*X(``"L````U@@``"````&&"```F````:H(``!(```"1
M@@``#P```*2"```&````M((```H```"[@@``"````,:"```@````SX(```D`
M``#P@@``#````/J"```-````!X,```X````5@P``%@```"2#```1````.X,`
M``8```!-@P``!@```%2#```'````6X,```<```!C@P``!P```&N#```6````
M<X,```T```"*@P``!````)B#```%````G8,``!X```"C@P``$````,*#```,
M````TX,```D```#@@P``!P```.J#```*````\H,```D```#]@P``#@````>$
M```0````%H0``!H````GA```"@```$*$```)````380```P```!7A```#P``
M`&2$```(````=(0```8```!]A```!P```(2$```%````C(0``$<```"2A```
M#0```-J$```*````Z(0```(```#SA```!````/:$```E````^X0```,````A
MA0``!0```"6%```J````*X4```H```!6A0``!````&&%```*````9H4```8`
M``!QA0``"````'B%```(````@84```0```"*A0``!0```(^%```%````E84`
M`!L```";A0``+P```+>%```0````YX4```H```#XA0``#P````.&```*````
M$X8```D````>A@``&P```"B&```8````1(8``!<```!=A@``#@```'6&```#
M````A(8```<```"(A@``!P```)"&```*````F(8```<```"CA@``40```*N&
M```0````_88```P````.AP``&@```!N'``!*````-H<```8```"!AP``!@``
M`(B'```&````CX<``!\```"6AP``"0```+:'```8````P(<``!<```#9AP``
M!@```/&'``!7````^(<``!,```!0B```$P```&2(```"````>(@```L```![
MB```#0```(>(```'````E8@``!0```"=B```!@```+*(```(````N8@```X`
M``#"B```!P```-&(```*````V8@```L```#DB```!P```/"(```)````^(@`
M``D````"B0``"@````R)```'````%XD```D````?B0``!P```"F)```*````
M,8D``!(````\B0``"@```$^)```)````6HD``!````!DB0``!P```'6)```2
M````?8D```0```"0B0``!P```)6)```%````G8D```4```"CB0``"P```*F)
M```4````M8D``!$```#*B0``&````-R)```<````]8D``!D````2B@``!P``
M`"R*```%````-(H```T````ZB@``"````$B*```7````48H```L```!IB@``
M$P```'6*```$````B8H```P```".B@``"0```)N*```%````I8H```<```"K
MB@``!0```+.*```$````N8H``"D```"^B@``,@```.B*```N````&XL``#,`
M``!*BP``,P```'Z+```X````LHL``!````#KBP``$P```/R+```M````$(P`
M`"T````^C```,0```&R,```N````GHP``"\```#-C```+````/V,```3````
M*HT``"L````^C0``&@```&J-```)````A8T``$4```"/C0``00```-6-```4
M````%XX```X````LC@``$P```#N.```8````3XX```8```!HC@``"0```&^.
M```*````>8X```\```"$C@``#@```)2.```%````HXX```@```"IC@``!@``
M`+*.```4````N8X``!$```#.C@``#@```.".```"````[XX```X```#RC@``
M!0````&/```'````!X\```0````/CP``*0```!2/```?````/H\``%P```!>
MCP``%````+N/```'````T(\```X```#8CP``#````.>/```,````](\``!,`
M```!D```'0```!60```9````,Y````4```!-D```$0```%.0```1````99``
M`"0```!WD```%0```)R0```2````LI```!D```#%D```"````-^0```)````
MZ)````@```#RD```!0```/N0```?`````9$```8````AD0``$````"B1```(
M````.9$```@```!"D0``+````$N1```:````>)$```D```"3D0``"@```)V1
M```5````J)$```4```"^D0``%````,21```$````V9$``!````#>D0``'@``
M`.^1```H````#I(```H````WD@``&@```$*2```4````79(```0```!RD@``
M"P```'>2```%````@Y(```8```")D@``"````)"2```@````F9(``$$```"Z
MD@``&@```/R2```H````%Y,``"D```!`DP``!@```&J3```%````<9,```@`
M``!WDP``*@```("3```C````JY,``"X```#/DP``-````/Z3```(````,Y0`
M`!<````\E```"@```%24```'````7Y0``!````!GE```"P```'B4```3````
MA)0```@```"8E```"P```*&4```*````K90``!0```"XE```,@```,V4```+
M`````)4```4````,E0``%P```!*5```/````*I4```4````ZE0``!````$"5
M```-````194``#(```!3E0``%P```(:5```4````GI4```4```"SE0``!P``
M`+F5```.````P94``"H```#0E0``!@```/N5```,`````I8```L````/E@``
M-@```!N6```+````4I8```\```!>E@``,@```&Z6```%````H98```<```"G
ME@``$0```*^6```'````P98```0```#)E@``!P```,Z6```*````UI8```L`
M``#AE@``#````.V6```#````^I8``!(```#^E@``!@```!&7```>````&)<`
M`!@````WEP``)0```%"7```-````=I<```D```"$EP```P```(Z7```'````
MDI<```(```":EP``#````)V7```5````JI<```L```#`EP``&0```,R7```@
M````YI<``!(````'F```!0```!J8```*````()@``!4````KF```$@```$&8
M```,````5)@```0```!AF```!P```&:8```,````;I@``%(```![F```%P``
M`,Z8```&````YI@```T```#MF```%0```/N8```2````$9D```\````DF0``
M%````#29```;````29D``&D```!EF0``&@```,^9```7````ZID``!H````"
MF@``%P```!V:```;````-9H``!D```!1F@``'P```&N:```3````BYH```<`
M``"?F@``"````*>:```)````L)H``!4```"ZF@``#0```-":```3````WIH`
M``,```#RF@``/P```/::```W````-IL``%<```!NFP``+P```,:;```*````
M]IL```@````!G```#0````J<```M````&)P```0```!&G```)0```$N<```+
M````<9P``!T```!]G```!@```)N<```,````HIP```<```"OG```"0```+><
M```3````P9P```D```#5G```!````-^<```0````Y)P```@```#UG```"```
M`/Z<```,````!YT```\````4G0``!P```"2=```4````+)T```X```!!G0``
M#````%"=```;````79T``"P```!YG0``$P```*:=```%````NIT```0```#`
MG0``%P```,6=```)````W9T```@```#GG0``"@```/"=```1````^YT```8`
M```-G@``#@```!2>```.````(YX```T````RG@``"P```$">```"````3)X`
M``<```!/G@``!@```%>>```)````7IX```<```!HG@``%0```'">```%````
MAIX```<```",G@``"````)2>```'````G9X```<```"EG@``#@```*V>```)
M````O)X```8```#&G@``"````,V>```+````UIX```<```#BG@``"````.J>
M```'````\YX``!8```#[G@``"0```!*?```&````')\```L````CGP``%```
M`"^?```(````1)\```8```!-GP``&0```%2?```*````;I\``!P```!YGP``
M!P```):?```%````GI\``!````"DGP``%````+6?```+````RI\```T```#6
MGP``%P```.2?```$````_)\```D````!H````@````N@```.````#J````@`
M```=H```'P```":@```C````1J```#$```!JH```)P```)R@``!*````Q*``
M`#@````/H0``*````$BA```L````<:$``!L```">H0``/@```+JA``!(````
M^:$``$$```!"H@``6P```(2B``!)````X*(``"$````JHP``'P```$RC```K
M````;*,``"$```"8HP``,P```+JC```E````[J,``"<````4I```,````#RD
M``!I````;:0``#T```#7I```90```!6E``!-````>Z4``"\```#)I0``+@``
M`/FE``!4````**8``#(```!]I@``+P```+"F```L````X*8``"T````-IP``
M%P```#NG```E````4Z<``#(```!YIP``*0```*RG```^````UJ<``"(````5
MJ```4@```#BH```E````BZ@```L```"QJ```(0```+VH```P````WZ@``"4`
M```0J0``'````#:I```Q````4ZD```0```"%J0``#0```(JI```+````F*D`
M``X```"DJ0``"P```+.I```%````OZD```(```#%J0``60```,BI```%````
M(JH``!(````HJ@``!````#NJ```'````0*H```@```!(J@``!0```%&J```3
M````5ZH```T```!KJ@```@```'FJ```'````?*H```8```"$J@``%````(NJ
M```,````H*H``!@```"MJ@``!@```,:J```2````S:H```P```#@J@```P``
M`.VJ```$````\:H```8```#VJ@``!P```/VJ```?````!:L``#4````EJP``
M+@```%NK```O````BJL``!<```"ZJP``(````-*K```;````\ZL``!@````/
MK```)````"BL```?````3:P``!H```!MK```&@```(BL```O````HZP``"L`
M``#3K```'P```/^L```C````'ZT``!\```!#K0``&@```&.M```E````?JT`
M`"8```"DK0``)0```,NM```8````\:T``!T````*K@``)````"BN```8````
M3:X``"(```!FK@``)0```(FN```?````KZX``",```#/K@``'P```/.N```@
M````$Z\``!H````TKP``)@```$^O```>````=J\``!X```"5KP``"0```+2O
M```7````OJ\``"\```#6KP``)`````:P```/````*[```!0````[L```#@``
M`%"P```-````7[```"0```!ML```!0```)*P```'````F+```!T```"@L```
M%0```+ZP```&````U+````D```#;L```"P```.6P```7````\;````8````)
ML0``,P```!"Q```'````1+$``"$```!,L0``$P```&ZQ```,````@K$``!$`
M``"/L0``,@```*&Q```(````U+$```D```#=L0``"@```.>Q```4````\K$`
M``H````'L@``'0```!*R```(````,+(``!\````YL@``"````%FR```:````
M8K(```8```!]L@``!P```(2R```(````C+(```D```"5L@``/P```)^R```'
M````W[(```\```#GL@``"````/>R```3`````+,```<````4LP``&0```!RS
M```*````-K,``!<```!!LP``%````%FS```*````;K,```P```!YLP``%P``
M`(:S```$````GK,``"H```"CLP``$0```,ZS```'````X+,```(```#HLP``
M$````.NS```#````_+,```@`````M```!@````FT```'````$+0```T````8
MM```"P```":T```4````,K0``!4```!'M```#@```%VT```O````;+0``"``
M``"<M```'````+VT```3````VK0```4```#NM```!@```/2T```,````^[0`
M``H````(M0``$0```!.U```"````);4```0````HM0``"@```"VU```&````
M.+4```4````_M0``#````$6U``!%````4K4``"@```"8M0``4P```,&U```9
M````%;8``"`````OM@``-0```%"V``!%````AK8``#````#,M@``*````/VV
M```F````)K<``"4```!-MP``*````'.W```H````G+<``#````#%MP``$@``
M`/:W```0````";@``'D````:N```"0```)2X``!S````GK@``'P````2N0``
M*P```(^Y```7````N[D``!\```#3N0``%````/.Y```*````"+H```4````3
MN@``!@```!FZ```(````(+H``!`````IN@``#P```#JZ```$````2KH``!D`
M``!/N@```@```&FZ```)````;+H```0```!VN@``#P```'NZ```3````B[H`
M`"(```"?N@``!P```,*Z```+````RKH```(```#6N@``"P```-FZ``!)`0``
MY;H```H````OO```#````#J\```'````1[P```<```!/O````@```%>\```2
M````6KP```L```!MO```!P```'F\```%````@;P``!(```"'O```!P```)J\
M```+````HKP```D```"NO```"P```+B\```3````Q+P```D```#8O```!0``
M`.*\```*````Z+P```8```#SO```#````/J\```2````![T```H````:O0``
M"0```"6]```=````+[T``!0```!-O0``)0```&*]```M````B+T``#P```"V
MO0``0````/.]``!`````-+X``$8```!UO@``)P```+R^```%````Y+X```@`
M``#JO@``#@```/.^```'`````K\``!L````*OP``&P```":_```+````0K\`
M``0```!.OP``!````%._```*````6+\```P```!COP``"@```'"_```*````
M>[\```@```"&OP``#0```(^_```-````G;\```8```"KOP``'P```+*_```(
M````TK\``!D```#;OP``!````/6_```?````^K\```0````:P```"````!_`
M```(````*,````8````QP```"@```#C````*````0\````0```!.P```$```
M`%/````*````9,````@```!OP```%````'C````&````C<````X```"4P```
M#@```*/````.````LL````@```#!P```"@```,K````5````U<````8```#K
MP```!@```/+````&````^<````@`````P0``!@````G!```0````$,$```@`
M```AP0``#@```"K!```2````.<$```0```!,P0``!````%'!```7````5L$`
M``P```!NP0``#````'O!```:````B,$```8```"CP0``"````*K!```6````
ML\$```8```#*P0``"@```-'!```/````W,$``!T```#LP0``&P````K"```9
M````)L(``!L```!`P@``&0```%S"```$````=L(```0```![P@``"````(#"
M```&````B<(``"H```"0P@``(P```+O"```I````W\(``&L````)PP``*```
M`'7#```H````GL,``"@```#'PP``)P```/##```:````&,0``!H````SQ```
M*````$[$```N````=\0```D```"FQ```#````+#$```0````O<0```T```#.
MQ```"P```-S$```(````Z,0```@```#QQ```$@```/K$```4````#<4```H`
M```BQ0``!````"W%```8````,L4```@```!+Q0``"````%3%```(````7<4`
M``8```!FQ0``!@```&W%```$````=,4```H```!YQ0``!````(3%```(````
MB<4```@```"2Q0``!````)O%```(````H,4```0```"IQ0``%````*[%```(
M````P\4```@```#,Q0``!````-7%```.````VL4```0```#IQ0``"````.[%
M```(````]\4```H`````Q@``!@````O&```,````$L8```,````?Q@``"@``
M`"/&```$````+L8```8````SQ@``!@```#K&```&````0<8``!H```!(Q@``
M!@```&/&```$````:L8```P```!OQ@``$@```'S&```2````C\8``#$```"B
MQ@``&0```-3&```&````[L8```@```#UQ@``"````/[&```6````!\<```H`
M```>QP``$0```"G'```(````.\<```@```!$QP``!````$W'```$````4L<`
M``0```!7QP``!````%S'```1````8<<```\```!SQP``"````(/'```.````
MC,<```T```";QP``!@```*G'```5````L,<```P```#&QP``"````-/'```$
M````W,<```H```#AQP``"````.S'```$````]<<```8```#ZQP``!`````'(
M```$````!L@```@````+R```!````!3(```&````&<@```8````@R```!```
M`"?(```$````+,@```<````QR```"````#G(```$````0L@```H```!'R```
M"@```%+(```K````7<@``!H```")R```"````*3(```(````K<@```H```"V
MR```"````,'(```4````RL@``!@```#?R```%P```/C(```7````$,D``!0`
M```HR0``$@```#W)```5````4,D``!T```!FR0``'0```(3)```,````HLD`
M`!<```"OR0``#````,?)```7````U,D``!@```#LR0``$P````7*```6````
M&<H``#`````PR@``!````&'*```,````9LH```P```!SR@``"@```(#*```(
M````B\H```0```"4R@``"````)G*```(````HLH```H```"KR@``"````+;*
M```(````O\H```@```#(R@``$0```-'*```7````X\H``!H```#[R@``"@``
M`!;+```"````(<L```0````DRP``!````"G+```(````+LL```@````WRP``
M!````$#+```&````1<L```@```!,RP``#````%7+```$````8LL```H```!G
MRP``"````'++```.````>\L```P```"*RP``"````)?+```$````H,L```@`
M``"ERP``'0```*[+```7````S,L```0```#DRP``"````.G+```6````\LL`
M``H````)S```"````!3,```(````'<P```0````FS```$0```"O,```(````
M/<P```8```!&S```!@```$W,```<````5,P``"D```!QS```"````)O,```.
M````I,P```<```"SS```'@```+O,```(````VLP```@```#CS```!````.S,
M```(````\<P```0```#ZS```"````/_,```*````",T```@````3S0``"```
M`!S-```.````)<T```@````TS0``#@```#W-```$````3,T```@```!1S0``
M#````%K-```5````9\T```P```!]S0``"````(K-```)````D\T```D```"=
MS0``!````*?-```*````K,T```H```"WS0``"@```,+-```$````S<T```@`
M``#2S0``"@```-O-```$````YLT```H```#KS0``"@```/;-```)`````<X`
M``@````+S@``"@```!3.```)````'\X```<````IS@``!````#'.```$````
M-LX```8````[S@``!@```$+.```$````2<X```T```!.S@``$````%S.```5
M````;<X``!0```"#S@``$````)C.```0````J<X``!L```"ZS@``$````-;.
M```0````Y\X``!T```#XS@``"````!;/```$````'\\```0````DSP``"```
M`"G/```*````,L\```0````]SP``$P```$+/```1````5L\```H```!HSP``
M"````'//```(````?,\``!4```"%SP``!@```)O/```$````HL\```0```"G
MSP``!@```*S/```&````L\\```@```"ZSP``!````,//```.````R,\```@`
M``#7SP``3@```.#/```$````+]````0````TT```"````#G0```$````0M``
M``0```!'T```"````$S0```&````5=````0```!<T```"@```&'0```.````
M;-````(```![T```"````'[0```$````A]````0```",T```!````)'0```&
M````EM```!(```"=T```"````+#0```$````N=````0```"^T```"````,/0
M```"````S-````0```#/T```"P```-30```$````X-````0```#ET```$P``
M`.K0```&````_M````@````%T0``"@````[1```2````&=$```8````LT0``
M"@```#/1```$````/M$```@```!#T0``"````$S1```(````5=$```@```!>
MT0``!@```&?1```0````;M$```8```!_T0``!````(;1```1````B]$```0`
M``"=T0``"0```*+1```$````K-$``!````"QT0``%P```,+1```$````VM$`
M``X```#?T0``!````.[1```1````\]$```8````%T@``!`````S2```(````
M$=(```@````:T@``"````"/2```(````+-(```4````UT@``!@```#O2```-
M````0M(```0```!0T@``!@```%72```&````7-(``!4```!CT@``%0```'G2
M```=````C](``!````"MT@``(````+[2```$````W](```@```#DT@``"@``
M`.W2```(````^-(```0````!TP``#0````;3```,````%-,```D````ATP``
M$P```"O3```(````/],```0```!(TP``"````$W3```*````5M,```0```!A
MTP``!````&;3```(````:],```P```!TTP``#@```('3```(````D-,```T`
M``"9TP``$0```*?3```$````N=,```8```"^TP``&0```,73```/````W],`
M``\```#OTP``#P```/_3```.````#]0``!`````>U```$````"_4```6````
M0-0``!,```!7U```#P```&O4```/````>]0```\```"+U```$0```)O4```0
M````K=0```8```"^U```!@```,74```$````S-0```8```#1U```!@```-C4
M```$````W]0```8```#DU```!@```.O4```$````\M0```P```#WU```$@``
M``35```&````%]4```0````>U0``!````"/5```$````*-4```0````MU0``
M"````#+5```(````.]4```@```!$U0``"@```$W5```*````6-4```8```!C
MU0``$@```&K5```(````?=4```@```"&U0``"````(_5```(````F-4```@`
M``"AU0``*````*K5```.````T]4```0```#BU0``!````.?5```-````[-4`
M``8```#ZU0``"@````'6```$````#-8```0````1U@``!@```!;6```&````
M'=8```D````DU@``#@```"[6```4````/=8``!8```!2U@``"````&G6```(
M````<M8```8```![U@``!@```(+6```(````B=8```8```"2U@``"@```)G6
M```$````I-8```0```"IU@``'0```*[6```,````S-8``!$```#9U@``#P``
M`.O6```3````^]8``!$````/UP``$0```"'7```/````,]<``!,```!#UP``
M%````%?7```$````;-<```8```!QUP``"@```'C7```*````@]<```0```".
MUP``!````)/7```$````F-<```0```"=UP``*P```*+7```)````SM<```8`
M``#8UP```@```-_7```(````XM<``!L```#KUP```P````?8```(````"]@`
M``P````4V```#````"'8```$````+M@```@````SV```!@```#S8```(````
M0]@```@```!,V```!````%78```&````6M@```0```!AV```$@```&;8```D
M````>=@```H```">V```"@```*G8```,````M-@```H```#!V```"````,S8
M```7````U=@``!@```#MV```%P````;9```,````'MD```0````KV0``"@``
M`##9```$````.]D```D```!`V0``!````$K9```L````3]D```L```!\V0``
M"````(C9```3````D=D``"L```"EV0``!````-'9```$````UMD```8```#;
MV0``$@```.+9```)````]=D``!@```#_V0``%P```!C:```$````,-H``#<`
M```UV@``$````&W:```0````?MH```8```"/V@``"````);:```(````G]H`
M``0```"HV@``"````*W:```&````MMH```0```"]V@``!@```,+:```$````
MR=H```H```#.V@``"````-G:```&````XMH```0```#IV@``!````.[:```$
M````\]H```0```#XV@``!````/W:```$`````ML```@````'VP``!````!#;
M```(````%=L```@````>VP``$````"?;```$````.-L```L````]VP``!```
M`$G;```(````3ML```0```!7VP``!@```%S;```$````8]L```P```!HVP``
M$P```'7;```7````B=L``!,```"AVP``$0```+7;```$````Q]L```0```#,
MVP``#````-';```$````WML``!$```#CVP``!@```/7;```/````_-L```0`
M```,W```"@```!'<```(````'-P```8````EW```"````"S<```$````-=P`
M``8````ZW```&@```$'<```?````7-P``!<```!\W```'````)3<```;````
ML=P``"````#-W```"@```.[<```0````^=P``!L````*W0``&P```";=```?
M````0MT``!P```!BW0``'0```'_=```:````G=T``!,```"XW0``$P```,S=
M```9````X-T```8```#ZW0``+P````'>```Q````,=X``!8```!CW@``"```
M`'K>```&````@]X```X```"*W@``!````)G>```&````GMX```8```"EW@``
M#````*S>```(````N=X```0```#"W@``!@```,?>```$````SMX```8```#3
MW@``"````-K>```$````X]X```(```#HW@``"@```.O>```&````]MX```0`
M``#]W@``!`````+?```C````!]\``!,````KWP``)@```#_?```.````9M\`
M``0```!UWP``"0```'K?```(````A-\```0```"-WP``"````)+?```0````
MF]\``!0```"LWP``!````,'?```(````QM\```H```#/WP``#0```-K?```,
M````Z-\```P```#UWP``%@````+@```,````&>````@````FX```"````"_@
M```$````..```!`````]X```!@```$[@```.````5>````8```!DX```!```
M`&O@```=````<.````@```".X```!0```)?@```&````G>````T```"DX```
M!````++@```$````M^````0```"\X```"@```,'@```,````S.```!,```#9
MX```!````.W@```(````\N````0```#[X```!`````#A```&````!>$```0`
M```,X0``!````!'A```(````%N$``!4````?X0``)@```#7A```1````7.$`
M`!$```!NX0``%@```(#A```$````E^$```0```"<X0``!@```*'A```K````
MJ.$``!8```#4X0``*0```.OA```O````%>(```0```!%X@``#````$KB```&
M````5^(```0```!>X@``"@```&/B```(````;N(```@```!WX@``!````(#B
M```(````A>(```@```".X@``#````)?B```:````I.(```@```"_X@``!@``
M`,CB```4````S^(```0```#DX@``!````.GB```$````[N(```@```#SX@``
M)0```/SB```(````(N,```T````KXP``"@```#GC```$````1.,```H```!)
MXP``*````%3C```$````?>,```@```""XP``!@```(OC```G````DN,```@`
M``"ZXP``#````,/C```7````T.,```0```#HXP``!````.WC```(````\N,`
M`!(```#[XP``!`````[D```2````$^0```L````FY```"````#+D```(````
M.^0```0```!$Y```&P```$GD```/````9>0```\```!UY```%@```(7D```.
M````G.0```0```"KY```"@```+#D```*````N^0```0```#&Y```!@```,OD
M```*````TN0```X```#=Y```"@```.SD```4````]^0``!(````,Y0``$@``
M`!_E```&````,N4```@````YY0``$````$+E```*````4^4```H```!>Y0``
M!````&GE```'````;N4```@```!VY0``.@```'_E```/````NN4```0```#*
MY0``#````,_E```6````W.4``!(```#SY0``#@````;F```4````%>8``!$`
M```JY@``0P```#SF```-````@.8``!$```".Y@``#0```*#F```1````KN8`
M`!<```#`Y@``$````-CF```-````Z>8```P```#WY@``$@````3G```(````
M%^<```0````@YP``+````"7G```$````4N<```\```!7YP``!````&?G```A
M````;.<``",```".YP``.@```++G```<````[><``!,````*Z```!````![H
M```(````(^@``"$````LZ```!````$[H```@````4^@```H```!TZ```$P``
M`'_H```$````D^@``!<```"8Z```!````+#H```$````M>@```@```"ZZ```
M$@```,/H```$````UN@```@```#;Z```$P```.3H```5````^.@```H````.
MZ0``'````!GI```2````-ND```P```!)Z0``"````%;I```3````7^D``!$`
M``!SZ0``+````(7I```&````LND```X```"YZ0``"````,CI```,````T>D`
M`!0```#>Z0``!````//I```(````^.D```(````!Z@``!`````3J```(````
M">H```0````2Z@``!@```!?J```(````'NH```8````GZ@``!````"[J```$
M````,^H```0````XZ@``!````#WJ```-````0NH```P```!0Z@``!````%WJ
M```$````8NH```0```!GZ@``!````&SJ```)````<>H```8```![Z@``!```
M`(+J```&````A^H```0```".Z@``!````)/J```1````F.H```0```"JZ@``
M%@```*_J```4````QNH```T```#;Z@``$@```.GJ```=````_.H``!`````:
MZP``!````"OK```$````,.L``!4````UZP``)P```$OK```%````<^L```@`
M``!YZP``"````(+K```2````B^L```0```">ZP``!@```*/K```(````JNL`
M``0```"SZP``!@```+CK```&````O^L```X```#&ZP``#P```-7K```1````
MY>L``!@```#WZP``'````!#L```6````+>P``"@```!$[```&P```&WL```=
M````B>P``!T```"G[```$0```,7L```9````U^P``#(```#Q[```+P```"3M
M```Q````5.T``"\```"&[0``%P```+;M```7````SNT``!8```#F[0``$P``
M`/WM```?````$>X``!,````Q[@``&0```$7N```1````7^X``$(```!Q[@``
M)````+3N```Y````V>X``"\````3[P``%P```$/O```;````6^\``#@```!W
M[P``)0```+#O```>````UN\``!X```#U[P``&P```!3P```1````,/```!D`
M``!"\```&P```%SP```;````>/```"0```"4\```#P```+GP```]````R?``
M`!,````'\0``"````!OQ```3````)/$``"T````X\0``%P```&;Q```/````
M?O$``"0```".\0``!````+/Q```(````N/$```@```#!\0``"````,KQ```+
M````T_$```0```#?\0``!@```.3Q``!/````Z_$```0````[\@``#0```$#R
M```$````3O(```H```!3\@``!````%[R```$````8_(``!````!H\@``!@``
M`'GR```&````@/(```8```"'\@``!@```([R```5````E?(```H```"K\@``
M$@```+;R```&````R?(```X```#0\@``#````-_R```$````[/(```4```#Q
M\@``!@```/?R```&````_O(``!(````%\P``'0```!CS```>````-O,``!\`
M``!5\P``#@```'7S```6````A/,``!(```";\P``$@```*[S```7````P?,`
M`!(```#9\P``$@```.SS```1````__,``!H````1]```$0```"ST```2````
M/O0``!8```!1]```%P```&CT```2````@/0``!4```"3]```$P```*GT```0
M````O?0``!(```#.]```%P```.'T```2````^?0``!(````,]0``$0```!_U
M```6````,?4``!@```!(]0``%@```&'U```>````>/4``!\```"7]0``&```
M`+?U```2````T/4``!<```#C]0``%@```/OU```&````$O8```0````9]@``
M'@```![V```;````/?8```X```!9]@``$````&CV```$````>?8```0```!^
M]@``)````(/V```$````J/8```8```"M]@``$P```+3V```.````R/8```0`
M``#7]@``!P```-SV```(````Y/8```\```#M]@``!````/WV```E`````O<`
M``8````H]P``'0```"_W```(````3?<```@```!6]P``"````%_W```;````
M:/<```8```"$]P``!P```(OW```&````D_<```T```":]P``#````*CW```1
M````M?<```0```#']P``$@```,SW```&````W_<``!@```#F]P```@```/_W
M```(`````O@```0````+^```"````!#X```D````&?@```0````^^```"```
M`$/X```$````3/@```\```!1^```!P```&'X```,````:?@```H```!V^```
M#@```('X```,````D/@```8```"=^```"````*3X```=````K?@```0```#+
M^```&P```-#X```0````[/@```0```#]^```!@````+Y```(````"?D```0`
M```2^0``!````!?Y```$````'/D```0````A^0``"0```";Y```(````,/D`
M`!$````Y^0``$@```$OY```(````7OD``",```!G^0``#P```(OY```-````
MF_D```@```"I^0``!0```++Y```&````N/D```@```"_^0``"````,CY```-
M````T?D```(```#?^0```@```.+Y```,````Y?D```0```#R^0``!````/?Y
M```+````_/D``#T````(^@``(0```$;Z```E````:/H```L```".^@``%P``
M`)KZ```_````LOH``"$```#R^@``'````!3[```5````,?L``!,```!'^P``
M$P```%O[```3````;_L``!,```"#^P``'@```)?[```0````MOL```@```#'
M^P``40```-#[```(````(OP``"L````K_```40```%?\```;````J?P``!,`
M``#%_```#P```-G\```/````Z?P```@```#Y_```!@````+]```&````"?T`
M``@````0_0``"@```!G]```4````)/T```0````Y_0``$P```#[]```#````
M4OT```0```!6_0``!````%O]```)````8/T```D```!J_0``&@```'3]```&
M````C_T```@```"6_0``!0```)_]```0````I?T```$`````````GP$`````
M``#^````C`$``.<"```4`0``?`$```````"#````#`(```````"M````$@$`
M`&8"``!D`````````#\#````````A0(```````!)`P``L0(```````!`````
MHP```,L#``"1````<P,``&`"``!_`0```````.(!``#&`0``&0$``+@#```[
M`P``9`$``.8#``"\`P``*@(``)H!``#8````I@(```````"A````4P(``/@"
M`````````````(L!````````S`$``,(!````````Y0$`````````````)@,`
M`-D!```G!```!`0``"T"```=````+@(``*4!``"6`P``L@,``"P#``"1`@``
M-P0``(H#```K`0``:0,``,8"``#V`P``AP```.P````Y````80$````````\
M`P``#`$``*X"``#W`P``)````,L!``"U`@``X@,``/P#``#<`````````.X`
M```7`0``D0$``$L#``!$`P``,@````````"O`0``C0(``!H`````````&`,`
M``````!@`0``"0``````````````O0,``.,"``#9`P``"@0``!,$``#3`0``
M)`0`````````````;`(``$L"``"G`@``#P$```$$``"8`0``(P````````!`
M`@``,P,``/\"``#,`@``[@$``-(#``"B`@``00$``#`#````````````````
M```O`P``3P$``&`#````````:P0``(X!``#A`0``````````````````E`$`
M`&X!``"<`0``^@(``"H```#G`P``[0````````#C`P``6`0````````>`P``
MKP,``-````!I`@``2`$```````!$!```HP$```8$```"`@``@@$``)(#``!9
M`P```````(("``#E`P``(P$``#L!``"J````#P```,0"```6`0``````````
M``#0`@``Z0,``+T!`````````````-L!``"S`0``EP`````````=`0``,`$`
M`.\!``##`@``$0$``$8"``!7`0``>`$``'`"``!K`0``D`$``#@!``",````
M!0,``!<#````````-0,```````#Z`P``.`,``/(#``"-````V@,``'<````?
M`0````(``$4#``"L`@````````````!#`@``*0$````````S!```````````
M````````9@````````"6`0``]0(``)$#```0!````````*<```!?`0``;```
M````````````A@```$<!``"M`0``A````#(#``#1`@```````"T$``#2````
MT@$``%X$``!,````<0```)@````.`P``ZP$``+`!``!=!```:````.P#``!"
M`0``[`$`````````````*0```"@!```S`0``-0$``,0!``!H!```5`,``.L`
M````````O@(``.`````0`0``A0$``.$````E````&@,````````<!```PP``
M`"8$``#Q``````````````##`0``C@,````````````````````````@`P``
MS0```'D````L`0`````````````D`P````````L"``!1````8````!X"````
M````2@(``$0!``#G`0```````$4$````````M````/("``"?`@``/@````<#
M``"R`0``F0$``&0#``!/````T0,``,$"`````````````#D#```;`@``````
M`"`$```;````P@(``#8!``!@!```0P,``!4!``!J`P``K@,``%T"````````
M```````````Z````LP```%0$```#!`````````````!Q`P``TP,``!("``!6
M!```R0(```\$``!U`0```````+D"``"V`@``-00`````````````?0```(T!
M``#*````YP````8#``!R`P``F0````0!``#*`@``M`$``)H"``#J`@``L`,`
M`+P````K`@``&@0`````````````_````.$#``!&!```6P0``$,$``#K`@``
M``````````#7`P```````+@```!!!```4`,``(,!``!*!```Y0(``#8```#`
M`P```````#`"````````WP,`````````````LP,```````#5`P`````````$
M````````-`0``/`"``"4`P``SP(``/P!``!N```````````````2`P``````
M``4$````````+P(```````!-`P``,@$``)@"`````````````,<!``!6`P``
M3`$``"D#``#V`@``?P,`````````````9`0````````N!```60$``#D!``"+
M````>0$``%L"``!*`````````&\#``#T`@``4P$``&<!`````````````&0"
M`````````````"0"`````````````'H!``!O`@``@@```,X#```W`0``G0(`
M`*L````````````````````Z!```C@````````!2````9P````````!I!```
MZ`$```````#0`P```````"$!``!Y`@``20````````#M`P```````,X`````
M````V`,```````"J`P``6P$``.P"```O!```/0`````````=`P``.@(``),"
M``#P`0``.P```/,#``#A`@``NP$```````"?````K0(``"\!``#*`P``A0``
M`'(!``"5`P``)P```#0#```^`P``50```*T#``#(`P``W@$`````````````
M``````````!9`@``+P```/L"````````:`(``%4!```"````/@$``,(```!,
M!`````,``%@#```0````O`$``!X$``#W`0``#P,``-4"`````````````$L`
M```G`@``>@(``!@$``"R`@```````%P`````````]P(`````````````&P0`
M``````"3`0```````!P```#<`0``"0(`````````````#````'P#``![````
M`````-L#````````;@,```````"V`````````'0!````````"P,````````.
M`@``I@$``)X#```_`@```````.4```#)`0``Z0````P#````````"P```'`#
M``!_```````````````S`@````````````"<`@``&0(``+T````K!```````
M`$`#``"H`0``1@$``*@```!?`````````*P#```>````&P,`````````````
M;@(``"H!``#]`@``E@```/T#`````````````*`!``!(`@```````'D#``"0
M`P````````````!(`P```````*$!``#-`@``_0```$,`````````=P,``',!
M``#T`0``E0````H"``#R`0```````/\#``#`````ZP,```$"```\!```````
M````````````MP````D$``!:!```:@$````````V!```>`,``,\```#Q`0``
M8@(```X!```"`P``!`,``'X#``#:`@``*`,``%P"``#M`@``0@,``#`$``#1
M````#P(```````!5`P``4@$``'H```#\`@``(````+4```!:`@``C0,`````
M```L`@``^````,,#```?````I````%X#``!K`P``:P```&<$````````*@0`
M``````#N`P``=P(````````2````<0(``-0#``#H`@```````-8!```#`@``
MV0````````#'`````````)(`````````O@$```````#O`P``!0```(0#````
M```````````````1`P``U@```/8`````````W@```!D`````````!0$`````
M``````````````````")`@```````&T````<`P``4``````````9`P``D@$`
M``$!``#T`P````````````"/`````````.(````'``````````````#P`P``
M:0````T"``!H`0```````(`"````````/00``/4!``````````````````!B
M````P0$``&($``#O````B0,``/X"``!-````I`(``-<````-````P0```$$#
M``"K`@```````,P#```(`P``U`(``)4!``#%`@`````````````5````<`$`
M`&4!``!4`@``&@$````````\`0``V`(``#$```#1`0`````````````C!```
M5P````````")````(0(``,(#````````^P,``'8````Q!```%`,``,P```"=
M`0``=0(``#$!``#Y````Y`,``.@#``!E!````````````````````````#0!
M`````````````#($`````````````.`!``"7`P``1`(``*@"``!;`P``+@,`
M```````U`@``.P0``/H!``!0`0``>`(```8!````````1P```/T!``!U````
M``````````#?````+`````,#``!C`````````/8!``!H`P``5P,```````"+
M`@``B@(```````!4````'`$``"($```0`@``1P,``````````````````+P"
M````````&@(``%\$``"(`````````,@!``"(`@``#0$``!($``"/`P``@P,`
M````````````)0(``(@!````````4@,``&T$``!3!```X`,````````N`0``
MY`$``"8````?!```#@```%\"```(`0```````%@!``#*`0``UP(```````#&
M`````````"D$``````````````<$``#J`P``7`$``#@$``"U`P``3`(``+`"
M``"F````'P(``.8"``!;````J@$``#X"````````40,```````#Q`P``NP,`
M`'0"``!7!```20(````````V`@``?0,``'(```#^`P``!@```&$$``!=````
M`````/(```!>`````````!T"```A!````````!@`````````A0,`````````
M````?0(```$#``")`0``$00``+```````````````#<`````````I`,``*(#
M````````.````*\"``#-`0``J@(``/D!``#/`P```P$```````!A````<0$`
M`/X!``#4`0``0@0``',"````````BP,```````#``0``G0,```H```"Q````
M.0(``'8!``#9`@``B@$``!8`````````H0,``+H!``"Q`P``$P$```````"_
M`P``6`````````!"`@``80(``!0````.!````````-T"````````3`,`````
M``"G`0``H`,```H!``":`P``FP,``%,#``!K`@``\P(``-,```#S`0``JP,`
M``````!/!```<P```)`````8`0``10$``$(`````````RP```)D"````````
M90```$\#``!W`0```````$`!``"W`P``$0```&<"``"&`0``"P0``$X!``!6
M````?`(``$X````A````Z@```-X#```3````X`(``#T!``#.`0``%@,``+D#
M``":````5@(``,<"``#F`0```````*````!+!```(`(``*<#````````I0``
M`.T!```-!```K@$``+H#```I`@``V@$``&,#``!#`0``40(``*,#````````
M``````````#X`P``10(```````!'`@``(`$``.D"````````FP```'X!``#>
M`@``^0,``$X#``!9!```@0$``%X"```7````50(`````````````"`(``-P"
M```\`@`````````````)`0``U0```"$#`````````````.\"````````%P0`
M``````"/`@``^P$``-4!`````````````+0"`````````````#$"``#3`@``
M`````)4"``!U`P````````````"=````#`0```````!\````)`$``*D!``!M
M`P``NP````````",`@``E```````````````R`(```````!N!```/````-T!
M```6!```<@(``#@"``"I`@``-@,```````#0`0``O0(`````````````/P0`
M`+<"``"F`P``A`$``.,!````````;0(``"@```!A`P``'@$``,$#```^!```
M-````"("``#?`@``K@```",#``#T`````````,4````4!````````/L```!?
M`P````````0`````````-P,``#4`````````VP(``+@!```K`P``````````
M``"_`@``WP$``*@#``"``P``Y````%`$```Y!```N@(``.X"``#)````4@0`
M`#T#```&`@``Z0$``````````````````(P#``!.!```1`````````"4`@``
MEP(```````!(````DP``````````````\P````````#<`P```````$T$```N
M````'`(``&8$``!J`@````````````!1!```7`,```````"_`0```````%H`
M```_````!P$```````!&`P````````````"O````@@,```````!]`0``J0``
M`,8#```)`P``2@$``-T#``!F`0```````"<#``!'!```C@(``+L"````````
M`````````````````````&4"````````V@```'@```#J`0``SP$```````"Q
M`0``(P(``#<"``"Z````G````"@"````````6@$```````"Y````````````
M``!)!`````````````!*`P``30$``!4#``"'`P``=@,``%@"``!T`P``]0``
M`&P#``!O`0``@P(``,0#``";`@``.@$```````">`````````'\"``#P````
M`````%8!``"V`0``70,``+(````K````T@(``(`!````````)00``!,#``#(
M``````````0"``!&````M0$``(8"``!=`0``Q0,``,T#``!C`0``;P````@`
M```3`@```````&8#```6`@``QP,```H#``"9`P``2P$`````````````^@``
M`'L#``#F````M`,```($``!4`0``H0(``/<```"I`P``HP(``"T`````````
M3@(```L!```4`@``@````!L!``!M`0``W0```$\"``"6`@``500``)("``";
M`0``!0(``(<"```B````\0(```<"``"D`0``:0$``%X!````````I0(`````
M``"(`P``_P$````````5!```MP$``#,````B`P``$0(```````"!````````
M`,`"````````@0(``-<!``````````````````!B`P``6@,``"<!``!7`@``
M00```"4#``"S`@``60```-@!```-`P```````!\#``#6`@``VP```*`"``#.
M`@``?@(``#L"``#H````,``````````#````RP(``*P```"L`0``````````
M````````O@,````````_`0````````````"E`P``<``````````(!```````
M`#H#``!T````)0$``'L!``"&`P``````````````````JP$````````B`0``
M`````#$#``"B````:@0``%("``!(!```30(``'X`````````)@(``(0"``"3
M`P``M@,``)P#```L!``````````````9!```8P0``)X"````````````````
M```J`P``OP``````````````+0$``&H```!1`0``F`,``/D"````````````
M`,4!``!L`0````$``+@"```=!```8P(``$4```"7`0``CP$``"@$````````
M_P```(<!``!O!```>P(``%P$```"`0``X@(``,0`````````@0,```````!`
M!```D`(``````````````````)X!``"?`P``]0,``#T"``!0`@``-`(``/@!
M``#6`P```````$D!``"B`0``B@````````!V`@``;`0``.0"```7`@``90,`
M```````F`0``U````"T#```0`P```````+X``````````````#("````````
MR0,``+D!``!G`P``8@$``$$"```8`@``4P```'H#````````%0(```````#C
M`````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@
M*'EE<W1E<F1A>2D`(&%T(``E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`
M)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E
M;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@9FEL92!S
M=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E
M<P`E<R!N;W0@9F]U;F0N`"5S.B`E<P`L(&=U<W1I;F<@)7,@)7,`+"!V87)I
M86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`R-"!H;W5R<P!!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-+U!-`$%0
M22!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!
M9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z
M`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U
M<V5R.@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU
M(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`061D<F5S<P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`061V86YC
M960@4V5A<F-H`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!
M;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S
M:6]N<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QR96%D>2!E>&ES=',`
M06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`
M06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E('1E;7!L871E<P!!
M;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G1A
M<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E
M`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N
M:6$`07)M96YI86X@*$%235-#24DM."D`07)U8F$`07-C96YS:6]N($ES;&%N
M9`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A
M;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@
M=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I
M<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!2
M97%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S
M.@!!>F5R8F%I:F%N`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I
M;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)E
M;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FQO
M8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS
M`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T<W=A;F$`0F]U=F5T($ES;&%N
M9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE
M:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&
M87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#
M86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B=T(&-O;FYE8W0@
M=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@<F5M
M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F
M(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@
M;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BX`0V%P92!697)D90!#87EM86X@27-L86YD<P!#96QL(%!H
M;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1R86P@069R:6-A;B!297!U
M8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T
M92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H
M:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@
M82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H<FES
M=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M`$-L:6-K('1O($-O;G1I;G5E`$-L;W-E(%=I;F1O=P!#;&]U9',`0V]C;W,@
M*$ME96QI;F<I($ES;&%N9',`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R
M`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@
M3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]N9&ET:6]N<P!#;VYF:6=U<F4@)7,`
M0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]O:R!)
M<VQA;F1S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER
M90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'
M4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D
M871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T
M(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5N=')Y`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E
M<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R
M<F5N="!4:6UE`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@
M`$-U<G)E;G0@<W1Y;&4`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@
M*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR
M86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&4`
M1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5C96UB97(`1&5C
M<F5A<V4@26YD96YT`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T92!'
M<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S`$1E;&5T:6]N(&9A:6QE9`!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO
M9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA
M>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y(&9O<FUA=`!$:FEB;W5T:0!$;R!N
M;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N
M(%)E<'5B;&EC`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$4M36%I
M;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET
M(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS
M(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O
M<B`E<P!%9WEP=`!%;"!386QV861O<@!%;6%I;"!!9&1R97-S`$5M86EL(&%D
M9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%
M;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;F0@>65A
M<@!%;FQA<F=E($5D:71O<@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5S=&]N:6$`171H:6]P:6$`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`
M179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`
M17AE8W5T90!%>'!A;F0`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$5X<&]R
M=`!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@
M9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O
M("(E<R(N`$9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,`1F%L
M:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9I:FD`1FEL92!#;W5N
M=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`
M1FEL92!.86UE`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+@!&:6QT97)S`$9I;F0`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U
M87)T97(`1FEX(')A=&EO`$9L:7``1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L
M87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K
M*0!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)U;7,`
M1F]R=V%R9',`1G(`1G)A;F-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN
M97-I80!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L
M;"!.86UE`$=A8F]N`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!'
M;P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX
M.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N
M`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(
M5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O
M<FET:&T`2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<P!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5L<`!(96QP('5S:6YG(&5D:71O
M<@!(96QP97(`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S
M<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)I>F]N
M=&%L(%)U;&4`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_
M`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N
M<R!W:71H('1E>'0`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@
M)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-R96%S92!);F1E;G0`26YD:6$`
M26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!)
M;G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4`26YS97)T(&UE<W-A9V5S`$EN<V5R="]-;V1I9GD@26UA9V4`
M26YS97)T+TUO9&EF>2!,:6YK`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I
M;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!S
M;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$ER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES
M<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A
M;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*
M=6YE`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`
M2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA
M`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y
M($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E
M`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+
M4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T
M(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA>6]U=`!,96)A;F]N`$QE
M<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N
M<W1E:6X`3&EN:P!,:6YK<P!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD
M97(`3&ES="!(96QP(%1O<&EC<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI
M<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES
M="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE
M`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN(&9A:6QE9"!B
M96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@
M:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3'5X96UB;W5R9P!-30!-3U1$
M`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA
M8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O
M9@!-861A9V%S8V%R`$UA:6P`36%I;"!!9&UI;@!-86QA=VD`36%L87ES:6$`
M36%L9&EV97,`36%L:0!-86QT80!-87)C:`!-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H
M:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E
M`$UE;6)E<G,`365N=2!M;V1E.@!-97-S86=E`$UE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@
M='EP90!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI;64@5'EP90!-:6X@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R
M`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-
M:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B
M:6QE($UA:6P`36]D:69I960@1&%T90!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B
M;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY
M`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-;W9E($1O=VX`36]V
M92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-
M;WIA;6)I<75E`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O
M<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G
M<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H
M97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!3
M4TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.
M971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A
M;&5D;VYI80!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@
M6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5X="!O<'1I;VYS
M`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\@8FQO8VL@
M97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@
M;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&
M4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N`$YO(&9I;&4@=7!L;V%D960`3F\@;&]C
M871I;VX@:7,@<V5T+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P96YD:6YG('-I9VYU<',N
M`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;W)D:6,@
M*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H
M97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R
M`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!S=7!P;W)T960N`$YO
M=&5S`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB
M97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!/2P!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RX`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M
M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@
M82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<'1I;VYS`$]P=&EO;G,@
M9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N
M86P@56YI=`!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W
M;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$
M871A`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H
M96QL`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%S<W=O
M<F0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`
M4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4&]L86YD`%!O;&QS`%!O<G1U9V%L`%!O<W0@=&\@=&AI<R!F;VQD
M97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L
M87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E
M<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@
M870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I;W5S(&]P
M=&EO;G,`4')I=F%T92!+97D`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T
M<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM
M`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)A9&EO('-E;&5C=&EO;@!2871I;P!296%D`%)E860@;65S<V%G97,`
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!0;W)T86P@
M5FEE=SH`4F5G97@`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V
M92!";&]C:P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('5S97(`4F5M
M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@`%)E<V5T`%)E<W5L=',`4F5T=7)N('1O($]P
M=&EO;G,`4F5U;FEO;@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@
M3&5F=`!2;W1A=&4@4FEG:'0`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N
M9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R
M>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-A
M`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N
M9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I
M9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BX`4V5A<F-H`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@
M9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V
M97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O;7!O
M;F5N=',N`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H
M92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!2
M97!O<G0`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-
M;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3
M970`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`
M4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@<&EC:V5R`%-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_`%-H<FEN:P!3:65R<F$@3&5O;F4`4VEG;B!U
M<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ
M90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<@9&5P
M=&@Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;W)T(&]R9&5R('-E;&5C
M=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A:6X`4W!A
M;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<FD@3&%N:V$`4W1A;F1A<F0`
M4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F
M;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES
M=`!3=0!3=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S
M9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T
M`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS
M970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A
M;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L
M86YD`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%135B!F:6QE`%1A:7=A;@!486EW
M86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB
M97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U
M<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!4
M:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG
M('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;W!E;G-S;"!M;V1U;&4@
M:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S
M+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A
M=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S
M:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H
M)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R
M96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU
M<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN
M(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M
M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1I;64`
M5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO
M<BU,97-T90!4:71L90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1R:6YI9&%D(&%N9"!4;V)A9V\`
M5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S
M`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!5
M4DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5
M;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82X`56YD97)L:6YE`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;FEC;V1E("A55$8M
M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D
M(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`
M56YI=',`56YK;F]W;@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5
M;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@
M=7-E<@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5R
M=6=U87D`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN
M('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU
M97,`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9I970@3F%M`%9I971N86UE
M<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES
M;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@
M271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@
M34%.54%,3%D@1E)/32`E<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!7
M90!796%T:&5R($9O<F5C87-T`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M
M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y
M+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T
M(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q
M=6]T92!C:&%R86-T97(_`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN
M9#H@`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%@U,#EV,R!E>'1E;G-I;VYS
M`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S+"!)($%G<F5E
M`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T
M;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@9&ED(&YO="!E;G1E<B!A
M('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG
M=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M
M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V
M:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%M0<F]B;&5M(%)E<&]R=%T`6VQI
M;F4@)7,@;V8@)7-=`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H
M.@!I;6UE9&EA=&4`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L
M96UE;G1E9`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N
M;F%M960`=7-E<B!S96QE8W0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U6
M97)S:6]N.B!4=7)B82`Q+C`*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@
M,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`Q+3`V+3$Y(#`Y.C0V
M*S`X,#`*3&%S="U4<F%N<VQA=&]R.B!786YG2&5N9U=E;B`\=VAW0&UY,38Y
M+F-O;3X*3&%N9W5A9V4M5&5A;3H@0VAI;F5S92`\=VAW0&UY,38Y+F-O;3X*
M34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/4=",C,Q,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I
M=`H`("@E<R#,[,>P*0`@*+_LO=V\_"`E<RD`("B]\<SL*0`@*-?RS.PI`-/:
M`-?NO?P@)60@S.S&^,_SU*2QJ``E<R`M(+&XS?S"O``E<R#6N,[&`"5S($M"
M`"5S(,ZLNZ2RV=?W("T@R+?(SP`E<R#7HK+A`"5S(,VLTN+/[L2_`"5S(-+1
MM.;4V@`E<R#4VB`E<R`E<P`E<R#.Q+S^TM&^K;/)N::UO,CK`+'8T.C2JB`E
M<P`E<R"WU@#5TK*[M;T@)7,N`"5S.B`E<P`L(-7SM^<@)7,@)7,`++'DNZ_!
MO[33("5S(+6]("5S`"TM(-&AU/$@+2T`,C0@T*'*L=;&`+3+Q_B_Z;'8T.O2
MJM:XMJC*_;[=O^*W_L[QMLLN`+>BR?K!R]*[N/;1S];8M<2T[<[S`-/[O-/#
MW-/*O/XLN[G0Z-*JT]#2N[CV(%!'4""YJ[^JP]S4ORX`T_O1Z=:DTM''J</[
MM<33RKS^++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<U+\N`-/[O>+#W-/*O/XL
MN[G0Z-*JT]#2N[CVN:N_JB!01U`@P]S4ORS+O</<(%!'4"##W-2_+-+4O+"_
MVL'N+@#3^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J(%!'4"##W-2_
M+,N]P]P@4$=0(,/<U+\LTM2\L+_:P>XN`-/[O>+#W-/*O/XLN[G0Z-*JT]#2
MN[CVN:N_JB!334E-12##W-2_+,N]P]P@4TU)344@P]S4ORS2U+RPO]K![BX`
MT_O6M-#0T\J\_L>IP_LLN[G0Z-*JT]#2N[CVN:N_JB!3+TU)344@P]S4ORS+
MO</<(%,O34E-12##W-2_+-+4O+"_VL'N+@#3^[S3P]S3RKS^++NYT.C2JM/0
MTKNX]B!334E-12"YJ[^JP]S4ORX`04TO4$T`05!)(+'@NL4`N=C3VM7BN/:Q
MX+RMQO<`N=C3VBXN+@#(J,_>LKO7XRS.WK>HO:C!HB!61E,@Q+_"O"X`R*C/
MWK*[U^,LSMZWJ+VHP:(@5D93(,[$O/XN`-7+NL72T;:SO>$N`+WAU<H`U/:\
MTP#0PM3VS\*\MM?I`-#"U/;/PKRVR*C/W@#4VK3+T,+4]J.Z`-#"U/;3P[NG
MU^D`T,+4]LBHS]X`T,+4]M*[N/;3P[NG.@#0PM3VTKNX]K/)U+$Z`-#"U/:V
MU`#0PM3V("5S(,ZJ($UO>FEL;&$@4VED96)A<B"RR[6E`-#"U/;3P[NG`-#"
MU/;3P[NGM<2YIL3<M;''L+&[N=BQU2X`M=C6MP"SR<ZJN=S`[=2Q("T@SJK&
MY,O\T\.[I\7DUL/(J,_>`+G<P.T`N>.XYKG<P.T`N-^\MLO1R_<`L**XN[JY
M`+"BMONPS<3AT<<`L**V^[RPP/O1QP"Q\,/[`,OYT]#2T='IUJ2UQ-/#NZ<`
MR_G3T-/#NZ?7Z0#+^=/0R*C/W@#4RM#MMN"X]K7GU]/3RKS^M=C6MP#2T;3F
MU-H`L>2X_"!)35-0(+7'PKP`L>2X_"!)35-0(,/<PNL`L>2X_"!)35-0(-/#
MNZ<`L>2X_,2CL.8`P\#*],CXQ*;1QP#2N[CVLKNZS[>HM<36M;&[RKG3PRX`
ML+*UP+;[`+"RN.?`K0"PLKGGP*T`Q.3#^[3ZP.T`Q,^\J];>`+"RS.&YS[RP
ML,VV^[*\M.\`TZ;3P[/,T/(`TZ;3P[/,T/+2T;[-T/<`TZ;3P[6]R_G3T,_"
MO+:YLL_M`,7ZU[P`R\34P@"PHL"MLJ[.Q"`H5VEN9&]W<RTQ,C4V*0#1N<OU
MSL2\_K3ST*$`T;G+]<[$O/[#^[/&`,3ZR+>VJ-*JR;ZS_2`E<R"UQ->BLN'"
M\"`_`+"BN/G-H@#1Q\/`Q.'1QP#1Q\/`Q.'1Q\[$("A!4DU30TE)+3@I`+"B
MPK.PS0"PHLFMR\G(NK6Z`-''UMXOS*O&O='SM=C'^`#6M-#0SJR[I++9U_?'
ML,_4RK[(M\C/MM2[L+_R/P#*U,V\R;ZS_=*[N/:RN[3FU-JUQ-/#NZ?7Z2X`
MRM3-O,F^L_W2N[CVLKNTYM3:M<3(J,_>+@#*U,V\L>"\K=*[N/:RN[3FU-JU
MQ-/#NZ?7Z2X`RM3-O+'@O*W2N[CVLKNTYM3:M<2YLL_M+@#*]-#4`+#+U,(`
ML,2T\\#[T<<`L,*UV,#[`$%U=&A?8W)Y<W%L.B#5TK*[M;W+^=#HTJJUQ"!I
M;6%P(,"IU;G7Z;S^+@!!=71H7V-Y<G5S.B"W_L[QMLNRHLZTS.&YJ;C#S^[6
MI[/6+@!!=71H7V-R>75S.B#5TK*[M;W+^=#HTJJUQ"!I;6%P(,"IU;G7Z;S^
M+@!!=71H7V9T<#H@U=*RN[6]R_G0Z-*JM<0@1E10(,"IU;G7Z;S^+L?KUMC0
MPK'@TNL@4$A0(+*BQ]*\T\CK("TM96YA8FQE+69T<"#1H<_N+,#]R.<@8V]N
M9FEG=7)E("TM96YA8FQE+69T<`!!=71H7VEM87`Z(-72LKNUO<OYT.C2JK7$
M($E-05`@P*G5N=?IO/XN`$%U=&A?:W)B-3H@U=*RN[6]R_G0Z-*JM<0@:W)B
M-2#`J=6YU^F\_BX`075T:%]L9&%P.B#5TK*[M;W+^=#HTJJUQ"!,1$%0(,"I
MU;G7Z;S^+@!!=71H7VQD87`Z(,[>MZC0PM3VT\.[IR`E<RX@M_[.\<;WN]C3
MICH`075T:%]L9&%P.B#.WK>HR;ZS_=/#NZ<@)7,`075T:%]L9&%P.B#.WK>H
MN/S0PM/#NZ<@)7,`075T:%]M8V%L.B#5TK*[M;W+^=#HTJJUQ"!-0T%,(,"I
MU;G7Z;S^+@!!=71H7W-M8F%U=&@Z(-72LKNUO<OYT.C2JK7$('-M8F%U=&@@
MP*G5N=?IO/XN`-'IUJ3*I[#<+@#1Z=:DRJ>PW"X@)7,`4D%$2553(-'IUJ2T
M[<[S+@!&5%`@T>G6I+3MSO,N`+_)T\.UQ-?6MLXZ`+"BR/NPW;VN`+&SOK#1
MU<FK`&ME<F)E<F]S(,/<PNNT[<[S+@!K97)B97)O<R#3P[NGP_NT[<[S+@"P
MS;G^PNW(NK6Z`+#-P=8`LJC"WK7$NJ/.Q"`H25-/+3@X-3DM,3,I`,//O-/`
MK;GZ`+#-L,VVX,NY`+#7MNW"WLNY`+'(P/O*L0"RKL#[U\@`L;3$_@"PV<2]
MM//(NK6Z`+*[M:0`Q_B_Z<7DUL,`Q_B_Z<#@T,T`M-;,Y0"RH\#[SJS1QP#*
MZ<>I`+*HR[G$X=''NLVZVLC[N.?.K,3'`+*IM,3-W\3)`+*HSJS,V+6Z`+#-
MSO<`TZ+*]-.AMLC1\\'LM=@`SL3`LP"QH[S3P/O1QP#/[L2_M_NZQ0"RO+RJ
MQ,FWJ,OW`+*\PJ&USP#$VLC=N=S`[<^US;,`0U)#`$-23""WUK*\M>,`R-7`
M^@#!X[RVM^<`O.W&TM6O`+^FPO/"H0#.WK>HP:J[^M;!($E-05`@M_[.\<;W
M.B`E<P"\T\3#M/,`R*'/^P#(H<_[SLK,XK&HN.8`SMZWJ,F^L_W.Q+S^("(E
M<R(N`,[>MZC)OK/]Q+_"O"`B)7,B+@#.WK>HUMC7Z:&CR_G,X;FIM<2\Q\*\
MROW$O]/KS\C'L,OYL:.TYK7$ROV^W;*[M_LN`,[>MZBTJ\O-T,7/HK6]UKBV
MJ+7$NL7"ZRX`M_"UP[W'`+^JPOS(NK6Z`-+&MJ^UY[NP`,C[MOO,V,[$("A)
M4T\M.#@U.2TQ-"D`UM"WQ[FRNLVY^@#6T,6W("A)4T\M.#@U.2TR*0#&OM:D
MS[B]V@#&OM:DLM_"U`#5I[7#`+C\N,0`UL?`^P#6T+GZ`+SRS.76T,[$("A'
M0C(S,3(I`+>QS.76T,[$("A":6<U*0#1H=3QP]S"ZP#1H=3QTKNX]M/#NZ?#
M^P#(U<;:S]3*OK>]RKTZ`,JEM:ZUN@#5TK*[M;T@)7,@M<3`X+'PMJC2Y2X`
ML+3*\['JO/R\S-#X`+G8L=6TL+_:`-3&P;\`O\:_QLNYR+JUN@"XY\+7L<C1
MQP#1U<FK`+7WR:O%S`"_J,VH`,/\P>X`P_S![KW%L;X`QL#"VP#-J-/#P_L`
MO\;$IL+>`+FKR[X`S/6\_@#%Y-;#("5S`,BWR,_#W,+K`+C5N?L`N-6Y^[FR
MNLVY^@#!K+W3RJ>PW#H@`,&LO=/6P;FKOZK#W-2_M_[.\<;WRK'4XK[<OO@N
M(-2MTO(Z("5S("@E<RD`P:R]T];!($944"#.Q+S^M_[.\<;WRJ>PW"X`O^*_
MR\BZM;H`N+36QM&AU/$`N.?+N;3OP.B\TP"_QLS8M<_-WP#.WK>HTM0@4$=0
M(+S3P]S3RKS^+@#.WK>HSJH@4$=0(-:TT-#3RKS^QZG#^RX`SMZWJ-+4(%,O
M34E-12"\T\/<T\J\_BX`SMZWJ,ZJ(%,O34E-12#3RKS^QZG#^RX`SMZWJ+#S
MMJ@@3$1!4""W_L[QQO<`SMZWJ+WBP]P@4$=0(,K]OMTN`,[>MZB]XL/<(%,O
M34E-12#*_;[=+@#.WK>HOO:VJ,K5O/[(R[7$M>?7T]/*O/ZUV-:W+@#.WK>H
MU]3#W-2_M_[.\<;WR*&UP[FKOZK#W-2_+@#.WK>HM/*_JB`E<RX`SMZWJ+3R
MOZK.K+NDN:37]\2CO^D@)7,`SMZWJ+;!R*$@)7,N`,[>MZBVP<BAM.;(H;_8
MUL:Q[2A!0TPI`,[>MZBVP<BAM_[.\<;WM<3/X+G8S-C0U`#.WK>HL:.TYB`E
M<R"UQ,7DUL,N`,[>MZBRZ=72($Q$05`@(+?^SO'&]RX`U=*RN[6]($UO>FEL
M;&$@4VED96)A<BX@Q^O(M\C/('-I9&5B87(@RL>W\;3ROZHN`+GZO-(`O:C!
MHM?3SL2\_KS0`+VHP:+5W[7$R*C/W@#0Q=/#OZBZQ<+K`+_+PMZUV-''`+G%
ML,T`M;''L,JQO.0`M;''L,SLQO@`M;''L->TO_8Z(`"UL<>PM^>X\0"\],?0
MT:'4\0#(^\;6PK?+N0#.]\#OMOO.Q"`H2T])."U2*0#.]\#OMOO.Q"`H5VEN
M9&]W<RTQ,C4Q*0#.]\#OMOO.Q"_.VK_+P+S.Q"`H2T])."U5*0"]W;_+N;*Z
MS;GZ`,C5`,._R-4`R-7&V@#*U;6]R-7&V@#1H=3QR-7&V@"PU\SL`,JNMO[4
MP@"\]<G9R_7%Q0#$K,C/R>VWW<JVL?``R;ZS_0#)OK/]T\.[I]?I`,F^L_W(
MJ,_>`,F^L_VAHL?EO]73RKS^`,F^L_VRV=?WRJ>PW`"UW<O-RK&\Y`"UI,+S
M`,[*S.+#Z,KV`,^XO=H@*,?KLLZ_O"!(;W)D92"\Q\*\SL2\_BDZ`,^XO=K'
MZ[+.O[S/M<VSN=S`[;7'PKPN`-'0MZ(`PK:UX\["ML@`U^ZZ\]*[T*'*L;7$
MPK:UX\["ML@Z(`#"MK7CSL*VR#H@`+33U_/6P=/2`+33T]+6P=?S`,2_PKP`
MTM0@,C0@T*'*L=;&S]3*OC\`S]3*OKCQRKT`O*JRO,SA`+*[R;ZS_0"RN]*J
MUK&]T[3FR*$@;6%I;G1E;F%N8V4N<&AP`+7:TKNQRKS'PKS*Q[?QL/RZK-?6
MML[#^[/&/R#(Y[G[RL?'Z]&AU/$N`+;@P]?$X;S3`+;@P]?$X;S3N;*ZS;GZ
M`,_"U-@@)7,`S\+4V,GZL\FUQ,7DUL/.Q+S^SJH@4$A0(+/,T/(N`,_"P*VR
MR[6E`+7GU]/3RKS^`+3MSO,`MO*YS[;@MOL`L>"\K0"QX+RMQ_B_Z0"QX+RM
MT\.[I]?I`+'@O*W(J,_>`+'@O*W(J,_>`+'@O*T@)7,@M<3(J,_>`+'@O*W1
MH<_N`+'@O*T@)7,@M<3(J,_>`+"CO+``R/BV^\W?MN``M>?7T]/*O/ZUV-:W
M`+7GU]/3RKS^M=C6M['8T.O.Q[K/+@"UY]?3T\J\_LBWR,\`L>W'Z;?[NL4`
MO]6PU]#%O/XN`+_5L->]X;G[+@#$ZK77`+?%M/.QX+RMQO<`L^"UP+RXQ-K1
MQP"V\L&BS-C`[]''`+3MSO,`L*[)L\3AT<<`L*/(^[;ML<C1QP#%M];>`,._
M(#$U(+?6UM,`P[\@,S`@P^O6TP##OR`U(+?6UM,`P[^TSK7'PKP`P[\@,S`@
MM];6TP##OR`Q(+?6UM,`M[;`_=:U.@#6M-#0`-6YOZH`M;W&VLC5`+WBR[74
ML0"UO+/V`$944"#)S[2KQ>36PRX`ML'(H<:KNL/%Y-;#RJ>PW`#.WK>HP:R]
MTR!,1$%0(+?^SO'&]RX`SMZWJ,&LO=,@4TU"(+?^SO'&]RX`N+36QLJGL-S7
MU"`B)7,B+@"XM-;&RJ>PW+6]("(E<R(N`,[>MZB]J,&BTKNX]M#"M<0@4T%3
M3"#!K+W3+@#2QK:OM;T@(B5S(LJGL-PN`,2_PKS+T<OWRJ>PW#H@)7,`MZC`
MO+_+N*/(NK6Z("C"[;;[SJS$R<NYR+JUNBD`MZC"WLBZM;H`M*O5Y@"V_M3"
M`+C0OO7/\<K'`+C0OO7/\<K'.B``[+.\PP#.Q+S^ROW$OSH@)7,@N/;.Q+S^
M`,[$O/[*_<2_.B`E<R#.Q+S^`,[$O/ZYW,#MQO<`SL2\_L/[L\8`SL2\_LG/
MM*L`SL2\_LG/M*NYIL3<SK2QN]:GL]8N`+G]PLO&]P"RZ=72`+?2P+P`R<^P
MZ]3"`,G/S]+4P@"YS+:HL<C`_0"WK=>J`,2_PKP@)7,@LKNTYM3:`-?6T,W1
MU<FK`-2DL:C,[,K]("C4I+&HS.S*_;#\P*BPU\SLTM2\L-*YO.2UQ,K]OMT[
MR.>Y^]2DL:C,[,K]O<^SI+VKU;S3P['(O<^_[;?YM<2PYL/F*0"TL,SE`,OC
MP_P`R^/#_,#@T,T`R^/#_`#"V\RS`-?4MJ_7JM#%`-#'QMK.Y0"WJ+GZ`+>H
MRO2YY]''Q,<`MZC*]+*CP/O$X<[WT<<`M-,`S>K5^\/HRO8`POK4P@#(J\/[
M`+S3Q>X`N-2QR-''`++ZR?H@)7,@M<3/M<VSQ>36PP"X\<*SO*K1QP"UPKGZ
M`.7(Q,D`UK&RO,+>S=,`P_L`UZJUO0!';V]G;&4@R]'+]P"[TK;(`,^CP+``
MSZ/`L,[$("A)4T\M.#@U.2TW*0"X\<'JP+P`N/'!UL3)M.\`T\.[I]?IN=S`
M[0#3P[NGU^G#^[/&LKNUP[_5L-<`T\.[I]?I`+G/M<+"WL;5M;H`N=BUN@#.
MH[78PNW`K0"X\;;WSO>UN@"WP[_-R*C/W@"WP[_-P?31U`"\N,3:T<<`O+C$
MVM''L<C)W+FRNLVY^@"YY]''Q,<`2%1-3`#5TK*[M;T@2%144"#1Z=:D+@"Z
MH[78`-33M-4MR^.WJ`"Q[<VW`+K5M<*ZS<+TM;'`S<BZM;H`SZ.RKL"TSL0@
M*$E33RTX.#4Y+3@M22D`L._6^@"QX+RMQO?*N=/#L._6^@"P[];Z`-7BP._*
MQ\[$O/ZUQ+^JRKPZ`.CSM=FXU`#*U]*S`+S2S:6UV-:W`+S2S:6UY[NP`+KI
MMKS`K<NY`-;0N?K/X[C;`$AO<F1E`,NNQKW/WP#7UK;.ROW$O[FRO,8_`,JJ
MML@`RJJVR#H@`-#9T<#`^P!)34%0(-/*S^2]J,&BRJ>PW#H@)7,`24U!4"#3
MRL_DR;ZS_<JGL-PZ("5S`$E-05`@T\K/Y+3%Q<S%Y-;#O:C!HLJGL-PZ("5S
M`$E0(+78UK?.WK>HRKG3PRX`25`@M=C6M[*BLKO4VB!#2412(+7$O=/*W,?X
MO^G6T"X`L?FUN@#6N]/0S;RQZ@#-O+'JO+#.Q-?6`,G/M*O-O,:L`,V\QJP`
MN^/(ZRP@LKW6Z"`E9`"[X\CKU]:VSCH@)7,`N^/(Z]?6MLXZ`,KDR.NRN]7]
MR+>UQ-?WT\/"ZRX`U/:\T\OUQ<4`TZ&VR`"X]K'PT\.[IP#3H;;(Q.'.]]''
M`-#%SZ(`T,7/H@"RY<CKL>VX\0"RY<CKS?C"Y\&LO=,`LN7(Z[_)S.:T^L2C
ML.8`LN7(Z]/*O/X`LN7(ZR^QY+C\S;S&K`"RY<CK+['DN/S-^,+GP:R]TP#5
M^\K]`-7[ROW!T`#.WM"GM<0@541(*-/#NZ?*_;[=L>W-MRDN`,[>T*>UQ-.F
MT\.SS-#R+@#.WM"GM<3%^K3.NL7"ZRX`S.&]N[7$ROV^W<[>T*<N`,[>T*>U
MQ,2_L>K7H=:W`+*[NL^WJ+7$SL2\_KCQRKT`SM[0I[7$(&US9U]T>7!E+@#.
MWM"GM<2[\M72LKNUO2!A<&E?:60N`,[>T*>UQ+ORU=*RN[6]LL[*_2X`LKNZ
MS[>HM<2XN,BHS]XN`,[>T*>UQ,VHT;;0K=+I+@#.WM"GM<3`M-2TUZ'6MRX`
MSM[0I[7$S?+3P\+KROV^W2X`TL'`RM+!R[G`O+FRNLVY^@#2P<"MO\L`L*ZV
M^\"\`,+\M;H`TM3)J\'0`,>IMZ+5WP#0L<SE`-+BM//`^P#1P,+RO-,`TKO4
MP@!*87!A;B`HR-6QOBD`R-7.Q"`H25-/+3(P,C(M2E`I`-3SSO>UN@#4O+6I
M`,;?U,(`P?G4P@#6P];0`-?ST]*VU,;K`+^_U_.VU,;K`+^_T]*VU,;K`+G^
MR/B_R\NYS+D`L:/!]-2MT?D@/P"_S\3AT<<`2V5R8F5R;W,@R,_6I+3MSO,N
M`,/<U+^]J,&B`,/<U+_,V-7W`,/<U+^SI+;(`,/<U+_`X-#-`,/<U+_3[[>H
M`+6QQ["UQ+FKOZK#W-2_M_[.\<;WUM`LTM&^K;3FU-K$^K7$P]S4ORX`N_G`
M[[#-R[FYLKK-N?H`LZ_/R@"ZJ[GZ`+JKSL0@*$550RU+4BD`O\;-_LS8`+RJ
MMON\JLNYS+D`T^_1U`#`S\[.`,_"L.O4P@#/PL_2U,(`R<^TSKC\T,(Z`,G/
MTKNTSK7'PKPZ("5S`,G/TKNTSK7'PKPZ("5S(-?4("5S`,G/TKNTSK7'PKPZ
M(+7:TKNTSK7'PKP`P*W-T<ZLT<<`L.;#YL7DUL,`P.BPS<3;`,"SR_?-T`#`
M^['(P._1QP#`^['(T<<`P=#6I[;8RK^UQP#!K+W3`,&LO=,`P="S]B`M(-/#
MNZ>_R=+4O[2UO=7BN/;.Q+S^O-``P="S]LNUP_>QZLSB`,S6PMO3P[NGU^DM
MSL2\_KGQ`,S6PMO3P[NGU^DMQ_/6^@#,UL+;T\.[I]?I+<JVL?"ZQ<+K`,S6
MPMO3P[NGU^DMT[73T-7?`,S6PMO3P[NGU^DMO,2\_LC+`,S6PMO3P[NGU^DM
MMJG4Q`#,UL+;T\.[I]?I+<BAS_NVJ=3$`,'0L_;3P[NGM<2YIL3<L;NYV+'5
M`,[$T:<`P:+,U<WP`+6QM=C*L;SD.B``M=C'^-/KRK&\Y`"UV,?X`+7'PKP`
MUZ+/^@"UQ\*\`+7'PKS*I[#<+"#'Z[SLLNG$^K7$T\.[I\/[NLW#W,+K+"#(
MN[KSUMC*U"X`M<?"O,JGL-PN`,*LR:VQI`#4P@##O\C5T,7/H@!-4RU43D5&
M(+B]O-/.Q+S^UM##N]/0ROV^W2X`35-'`-;0N?JPQ,/%`,+MQN2VV;FRNLVY
M^@#"[;3OO-/+N;S3M;H`T\J\_@#3RKS^N=S`[0#"[<"MS?X`PNW`M,[WT<<`
MPNVV^[3ZM_(`PNW`^P#"[;;ZR_L`R/W4P@"QZKS'L\D@O[2Y_2_.M+^TN?T`
ML>J\Q[/)QN3+_+7$RK:Q\"`HP/W(YRX@UMC2JB_2T;O8N+0I`,+MR=RV^\BZ
MM;H`PNW,X<3AO\NUN@#5_=3:QJ7%Y-?6MLX`PZO`[\O^Q.'1QP##J\#OQ_/+
MN0"XO;S^ROW$O]+1LZRS]KW3RMS)S\_>+@#7[KW\(#(T(-"ARK&UQ-?NN-_.
MPK;(.B``U^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B``O=/*W-?NM/.SI+;(`,[E
MU,(`PNW4O,S8R+JUN@"SR=2Q`-&AM:7$H\J].@#3RKS^`-/*O/[1Z=:DTM'-
MZK/)++6KRL?3P[NGM<3'J</[R+3.WK>HS:BY_='IUJ0N`-#%SZ+2T;G]QMHN
M`-#%SZ+`X-#-`$UE=&%R(,?XO^G.WK>HRKG3PRX`365T87(@Q_B_Z<[>MZC*
MN=/#+B#/N+W:Q^NRSK^\S[7-L[G<P.VUQ\*\+@"WO;>H`+FKUL8`Q*O.][CG
M`,/<O\O"WL3ASO?1Q\&JL.ZY^@!-:6UE(,#@T,T`U^Z]_"`R-"#0H<JQM<37
M[K7-SL*VR#H@`-?NO?P@-B#0H<JQM<37[KC?SL*VR#H@`-.SR>0`Q>36P\[$
MO/[2Q<JG+B#(Y[G[TJK*N=/#U>*X]M.FT\.SS-#RQ/JQV-#KS];4VK[-LOK)
M^LO[+@#5TK*[M;W0Q<^BM<0@240N`-72LKNUO;OAQMJUQ"!)1"X`T,?&VM*[
M`-#0MJ_3RKS^`+C\T,+(U<;:`,2CO^D`Q*:V^[;@S=\`Q*;$R;CG`,/)N<4`
MU,*ZS<3J`,._U,(`P\G,V,C[P*W,V`#4PL'!TZ^_]P#$IL+EN.<`S\+2Q@#7
M\]+&`-/2TL8`R<_2Q@#/PM+&`,G/TL8`Q*K)H['(O\L`N+31H0#.TK7$U<NZ
MQ0#.TK7$P\6[IP#.TK7$P\6[I]*SP^;%Y-;#`,/EM>D`LKLLSM*RN\VLTN(`
MP_NSQ@#$R</7L<C1QP#HI\*S`,3ALK2V^P"ZR<"\`+K)RO2PLK78P=#+N0"[
M^=/:3F5T<V-A<&4@M<3-^-:W`$YE='-C87!E(%-33""W_L[QQO?#^[/&`$YE
M='-C87!E(,C/UJ2UQ,7ZUZ(`3F5T<V-A<&4@R,_6I,#@T,T`S?C"YP"TT\ZT
M`-#"OZ;`[[;@Q.'1QP#0PM3"`-#"T\.[I\/[("BWQ['8TJHI`-#"SO?`O`#0
MPK2PO]H@*%]B;&%N:RD`T,+.Q0#/PM*[N/;1H<_N`,3AO-/`K;G/`,3AR-6V
M^P#$X<C5P/O1QP#-[<G/`,6FL*.UN@#+^=:XMJBUQ,Z[UL/)S\.[T]#'^+_I
MM.;4V@##N]/0S.&YJ<C5P/K#^[/&TM2YJ2!-0T%,(-'IUJ0N`,.[T]#6N+:H
MM<0@)7,@Q>36P]#%SZ(N`,.[T]#6N+:HM<0@1E10(%9&4R#%Y-;#T,7/HBX`
MP[O3T-:XMJBUQ"!344P@5D93Q>36P]#%SZ(N`,.[T]#6N+:HM<0@4U%,+49I
M;&4@5D93Q>36P]#%SZ(N`,[$O/[.M,G/M*L`SKO6P]#%SZ+)T,ZTQ>36PP##
MN]/0UKBVJ,/<PNO2U+FI($A45%`@T>G6I"X`P[O3T-:XMJC#W,+KTM2YJ2!)
M34%0(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4N:D@2V5R8F5R;W,@T>G6I"X`P[O3
MT-:XMJC#W,+KTM2YJ2!,;V=I;B#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI(%!!
M4U-71"#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI(%--0B#1Z=:D+@##N]/0M/W)
M\[7$UZ*RX<GJQ^LN`,[>U-VTYL2_PKR_R;FIO^S(H2X`P[O3T+K/MZBUQ"!8
M34P@ROV^W;&[M*N[V`"_U;#7UK4`U*W*O,7DUL/.Q+S^UM#5TK*[M;VPYK&^
MT,7/HBX@UMC0PK+ZR?K%Y-;#SL2\_BX`U-K$^K7$Q>36P\[$O/[6T-72LKNU
MO;#FL;[0Q<^B+B#6V-#"LOK)^L7DUL/.Q+S^+@#(U;;ZPOS.Q"`H25-/+3@X
M-3DM,3`I`,6UN*._R[6Z`+&QL.O'\@"QL<+MP._1Q\3)R+JUN@#%LLW^`+?'
MUJZZ\P"WQ]:NQ[``LKO*Q]*[N/;$O\*\`,ZTL;O6I[/6`+&XUZ(`RJ[2N]3"
M`,K]U]8`U]:W^\K]`-?6ML[*_<2_`+'*ROT`3TL`MM3/\[VHP:+5WP"PR[WX
MSKL`RJ[4P@"PHL+\`-:[T]`@24U!4""W_L[QQO?6I[/6SL2\_KS0N;+/[;FF
MQ-PN`-:[O=/*W-*[N/;3RKS^M=C6MRX`UKO3T-.UT]#5W]/KS[7-L[G<P.W4
ML;_)TM2QY+C\N;+/[<BHS]X`U-K0PK2PO]K6T+3ROZH`T:'/[@`E<R"UQ-&A
MS^X`S^[$O['@NL4`U^G6KP#7Z=:OM:7.NP#4K<J\TZ;3P[/,T/+$H[#F`-3:
M("5S.B#6T+7$U*W*O,2CL.8N`,;DR_P`QN3+_-#%SZ(`T[73T-7?R*C/W@!0
M04T@T>G6I,[>T*<N`%!'4"#*_=?6QZG#^P!01U`@O-/#W-?*P<\`4$=0(-+1
MQZG#^R_2T;S3P]P@U\K!SP!02%`@L\S0\K3ZPNL`4$A0(+W%L;X`L,V[^<NY
MS+D`Q<'`S0"PS<#5R[G,N;&[U;S![,?X`+#-Q,/"[0"PS;*\T<?0PKRXQ-K1
MQP"PS<"MN><`P]S"ZP##N]/0UKBVJ,/<PNO2U+FI(%)!1$E54R#1Z=:D+@##
MW,+KR+?(SP##W,+K.@##W,+K.B``P]S"Z['8T.O.Q[K/+@#,^<G/`,SYR<\`
MPK>^M@"T_<GSM<?"O*.Z`-:TT-#.K+NDLMG7]P"UQ\*\NO/6M-#0SJR[I++9
MU_<_`,BHS]X`R*C/WKG<P.T`SM*UQ`##V,*S`+?&PLFQ]@"UY[NP`-75QJP`
MQJ3,V+^UM;H`Q^O*Y,CKTKNX]M3"M]V\L,3JM]TN`,?KRN3(Z]*[N/:ZS[>H
MM<3(U<;:.]&AU/&TR]3"M]VUQ,C5QMHN`,?KRN3(Z[K/MZBUQ,JQO.0N`,?K
MS.&YJ<[*S.*UQ-6JTJHN`,?KRN3(Z\3ZM<33P[NGP_N\L,/<PNL`LJC`O`#-
MML:Q`,;/S-'1P`"UW<O-T\J\_K6]U>*X]L[$O/Z\T"`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I`-?NO?P@)7,@T*'*L;7$O;73ZL&_.B``4')E9G-?;&1A<#H@
MU=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\_BX`4')E9G-?<V5S<VEO;CH@
MU=*RN[6]R_G0Z-*JM<0@<V5S<VEO;B#`J=6YU^F\_BX`QOC1N0"ZH\:]P^;&
M^-&Y.B``QOC1N3H@`-2DP,``R<_2N[CVT:'/[@#+O</<P]S4OP#.RLSBP^C*
M]@#7J+"X`,SARK[$VLC=`+FKOZK#W-2_`+FKOZK#W-2_T=W+XP"YJ[^J+\N]
MP]S#W-2_MM2RHLZTL;NR^LGZ+@"RJ+;@P.BX]P"_J,O^MOL`4E-!(+FKOZK#
MW-2_("@E9"#.NRD`M:71H0"QR,+*`+;!R*$`ML'(H=/*O/X`U>:UQ-*JR;ZS
M_2`E<R#"\#\@U>+/[K+9U_>]J\[>MZB[UKBT+@#(H<_[N+34K0#+HM#"P\6[
MI\K3S;PZ`+GFU/*Q[;3ORKT`QL#"VP#4MK/,M_[.\<;W`-2VL\S-^-:W("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`R;ZS_0#)OK/]Q_B_Z0#)
MOK/]MM0`U]2W_L[QQO?4W;3FQ+_"O-;0R;ZS_=+1L:.TYK7$Q>36P[/,T/(N
M`,F^L_W3P[NG`,F^L_W3P[NG.B`E<P#0Z,?SSK2QN\_LTZ8Z(+3MSO.ZQ<+K
M.@#6V,GH`+WAN?L`M[6[V-&AS^X`4F5U;FEO;B`HP?3$X<WZM;HI`+W'R:L`
M4F]M86YI82`HPM["[<3AT<<I`-#]UZH@,3@P(+;(`,_RU_/0_=>J`,_RT]+0
M_=>J`-:TT-``4G5S<VEA;B!&961E<F%T:6]N("BV[<+>R[DI`%)W86YD82`H
MPJRPLK3O*0!3+TU)344@O-/#W,>IP_L`T\J\_M+1RKG3PR!3+TU)344@O-/#
MW`!305-,(-'IUJ3.WM"G+@#0Q<^B`,K]OMV_XKW%L;X`O-/#W-;5MLN[^@"S
MR;FF`-#'QMK!^0#*I;K5P-7$P[6Z`,JEN_FUPKK-P=#.K,NY`,JEPJS.]]''
MM;H`RJ7&I+"CMONZS<+SO\O"U\BZM;H`RJ7.Q,FMS-BZS;CQP=;$R;3O`,VL
MTKNX]K2PO]H@*%]S96QF*0#(^,2FT<<`RJ7"[<&FQ;4`RJ6VX,/`NLW&U<'6
MSO>QR`#.P-#'S.&YJ=7?`,FSS-BPHL"MLJX`L:.TY@"QH[3F("5S`+&CM.;1
MH<_N`+VKLOK)^K7$Q>36P\[$O/[2U"!02%`@T^_1U+CQRKVQH[3FM;W$^K7$
MM_[.\<;WU-VTYL2_PKS6T"X`Q>36PR`E<R#2T;&CM.8N`++IU=(`T:'4\=*[
MN/;(U<;:`-&AU/'2N[CVT\.[I]?IT\/2U-#"U/8`T:'4\=*[SKO0PK7$T[73
MT-7?`-&AU/'2N[*_M_[.\<;W`-&AU/'2N\Z[T\.[I]/#TM30PM3V`-&AU/'+
M^=/0R-7&VM?IO/XN`-/:TM3/PK7$M+"_VM;0T:'(H<3ZTJJUQ-?6M_LNTM3*
M\['JN+36QLOYT:'.Q-?6+,B[NO/,^<G/SL2\_K'@O*W'^"X`T:'4\<C5QMJW
MUKCT.@#1H=3QR-7&VLC5QMJX\<J].@#1H=3QRK&\Y+?6N/0Z`-&AU/'(U<;:
MRK&\Y+CQRKTZ`-&AU/'/X+NEQJ7%Y+7$MOZX]M?6MLXN`-&AU/'$^K7$T=7)
MJ\7DUL,`T:'4\<:KNL/3[]'4.@"TJ\O-SLK,XK>TTZ8`4V5N96=A;"`HR/O$
MVKS3MOLI`+2KN-#&]SH@`+[%U,(`4V5R8FEA(&%N9"!-;VYT96YE9W)O("C(
M^[;[SJS1Q]/KP\G,V,3AN.?"WBD`T/*ZQ0"[X<;:($E$(-+1N?W&VBX`Q>36
MPP#%Y-;#U+:SS+?^SO'&]\G/RO33VL3ZM<2X]LC+U;[,J"X`Q>36P\3ZM<3&
MJ[K#T^_1U"P@RK''^-+4O+#(U<;:N/'*O2X`Q>36P\3ZM<3&],J\TZ;3P[/,
MT/(LT=7)J\7DUL,LTK/#YKC\T,+&M<+*++RPQN3+_,_4RK[1H<_N+@#3T+K#
MO+BX]K78M>.ZS=7BN/:RSLK]T]"YV#H@`%-E>6-H96QL97,@*,C[SO2V^RD`
MN;K.[P"\\K;,U:K2J@#*Q[?QSJJT\[*_M]VUQ,&LO=.VJ-+EO^R]W;FFQ-R\
M_#\`S]3*O@##O[3.M<?"O+KSS]3*OLG/TKNTSK7$M<?"O,JQO.0@/P#/U,J^
MM>/1H<;W`-/:U_.QW\_4RKX@)7,@LLNUI3\`RM7+]0!3:65R<F$@3&5O;F4@
M*,JHU]/)O;GZ*0#7HK+A`,>IP_L`QZG#^]'=R^,`4VEN9V%P;W)E("C0PKS3
MQL(I`+3ST*$`PM2Y_<ZLNZ0`4VQO=F%K:6$@*,NYPN6WI;_+*0!3;&]V96YI
M82`HR[G"Y;>EQ.'1QRD`N_W1J<GNML@Z(`!3;VQO;6]N($ES;&%N9',@*,OW
MPM[#Q<BZM;HI`%-O;6%L:6$@*,OWPNW`^]''*0#%Q<'0M[W/\M&AU/$`P+34
MM+78UK<`4V]U=&@@069R:6-A("C$S[?'*0#$S\6W("A)4T\M.#@U.2TS*0!3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P#$
MS[#KQ_(`4W!A:6X@*,[WL.#1P"D`P*R[^-/*O/X`S-C*XM?6M_O*Y,CK`%-R
M:2!,86YK82`HR[G`[\"\OZ@I`+'JU[P`QO3*O,3JM]T`RJ$`U[3,K`"QH[3F
MN/'*O0"]UK7``,F^L_W/WP#7UK?[M*[!T`#0Q\;:S.P`UO?6O`#,X;V[`,_"
ML>H`L\FYI@#2T;/)N::XLKC'("5S`%-U9&%N("C+U;6D*0#5JM*J`,C5L_8`
MR-7"Y`#(U;/V`,C5L_8OR-7"Y`#(U;/V.B``R-7"Y`#(U<+D.B``R<^QZ@#6
MI[/6`%-U<FEN86UE("C+U<#[Q,\I`+3"NL4`4W9A;&)A<F0@86YD($IA;B!-
M87EE;@!3=V%Z:6QA;F0@*,JWS=^\P\"\*0!3=V5D96X@*,CPM>0I`%-W:71Z
M97)L86YD("C(\,J_*0!3>7)I86X@07)A8B!297!U8FQI8R`HT/#`^]''*0!4
M04(@M]:X]+CQRKW.Q+S^`,RHS>4`S*C-Y0!486II:VES=&%N("C+_KRJR[G,
MN2D`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B`HS+G)T,3AT<<I`,2_
ML>HZ`+3]L.S*PL_N`+7GN["ZQ<+K`-?NO?S2N]"ARK&UQ,["ML@Z(`#.PK;(
M`,["ML@Z(`#$H[#FN=S`[0#$VLC=`+2_SL37U@#0Q\;:R\0`S*G.Q"`H5$E3
M+38R,"D`5&AA:6QA;F0@*,RIN?HI`-"[T+O$^LJYT\.QOL^US;,N`$944"#1
MT\GL*&5X=&5N<VEO;BG.WM"G+@!-86EN=&5N86YC92#`X+'PLJ+.M+/)N:;4
MV,CK`-&AS^ZTL+_:TM2YV+'5+L#KOZK6T"X`T>G6I-/*O/['J</[T.C2JM/0
MTKNX]M+1O>*_JK7$(%!'4"#'^+_I+@#0Z-*JTKNX]KZMN?V\T\/<M<3-^,+G
MP:R]TRX`SL2\_B`E<R#3IKC#L/RZK-*[N/8@)7,@Q>36PRX`SL2\_B`E<R#3
MIKC#L/RZK-*[T*D@)7,@Q>36PRX`M,O.Q+S^UM##N]/0ROV^W2X`TM3/PLK'
M(')F8S@R,B#3RKS^M<2Q[<VW+@!';G501R"V_M2JSL2\_K7$PK>^MK'8T.NV
MJ-+EU-H@0W)Y<'1?<&=P.CH@P."Q\-;0+@!(;W)D95]#<GEP=%]S;6EM93HZ
M(,#@L?`LL=C0Z-*JT]`@;W!E;G-S;"#$H[_I+@"TR\:KNL,@(B5S(B#*_;[=
MTO+.JK.LN?W7[K3SO=/*W-:U+,OYTM3.WK>HL;NQH[3F`-/#TM2\[,K3M,O*
M_;[=P.#0S2`H)7,I(+7$L\S0\K*BLKNTYM3:T]K/M<VSR<\N`+3+M_[.\<;W
M("(E<R(@TM&QN\F^L_TN`+3+M_[.\<;W("(E<R(@TM&QN[&CM.8N`"5S(+7$
MUZ*RX=#HQ_/2T;&[R;ZS_2X`UKBVJ+7$O,?"O+*BLKNTYM3:+@"TT\G/TKNX
M]K*]UNC6KKKSR<^TJ[7$ROV^W=+%RJ<N`,G/M*O.Q+S^LJ+.M+&[L:.TYBX`
M=V5A=&AE<BYC;VT@Q_B_Z<[>MZC*N=/#+@#.WKB]O/Z_R=:QO=.T\K^J+@"T
MR]?6ML[6T+#\NJS,J[;@M<37ULK]+L3ZTM'*Y,CK("5S(+CVU];*_3O$^LKD
MR.NUQ-?6ROVQV-#KT*'3VB`E<RX`R<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@
M)7,@SK2QN\G/M*LN`,G/M*O.Q+S^RK&WHLGZTKNX]L[*S.(Z("5S(+3ST*&S
MK+G]O=/*W-?NM//6M2`H)60@8GET97,I+@#)S[2KSL2\_LJQMZ+)^M*[N/;.
MRLSB.B"]]K*_M]:UQ"`E<R#.Q+S^L;O)S[2K+@"\[,K3T\J\_LJQMZ+)^M*[
MN/:T[<[S+@"[X\CKM,O-J-&VLK[*_;[=RK&WHLGZM.W.\RX`U-K%Y-;#M+#,
MY=;0MZ+)^L'+TKNX]K3MSO,NT]"_R<3<Q/K2Q<*IP<NQV-#KS.[0M+7$U]:V
MSBX`M,L@24U!4""W_L[QQO>RHLZTUJ>SUL[$O/Z\T+?6S^VYIL3<+@#5XLO&
MNO6RN\K'U?W(M[7$(')A<B#1N<OUSL2\_BX`U>++QKKULKO*Q]7]R+>UQ"!Z
M:7`@T;G+]<[$O/XN`-7BR\:Z];*[RL?5_<BWM<30Q=/#OZBZQ<+K+@"TR]?6
MML[*Q['8T.C2JK7$+@"TR]?6ML[$VLC=UKN]T\K<U?O*_<K]U]8N`+3+U]:V
MSL3:R-W6N[W3RMS*_=?6O+##L+K%+@"TR]?6ML[$VLC=UKN]T\K<L,N]^-;&
MROW6M2X`M,O7UK;.Q-K(W;'8T.O.JK:ZNL6[\K_5L->WUKCTM<3*_=?6`+'8
MT.O*Q]*[N/;*_=?6+@"TR]?6ML[$VLC=L=C0Z[#\NJS2N]?IRJ[!^;WXUL:U
MQ"!21T(@T=7)J[3ZPNLLP/W(YR`G(S$R,S1A9B<N`-7BN/:TL,SETM&QN[2F
MP.VY_2X`U>+*QR`E<RX`M,O*_=:UU^[)V;'8T.O*QR`Q+@"TR[?^SO'&]\[>
MMZBVU"!Z:7`@O+`@9WII<""X\<J]SL2\_KWXT-"]XM&YR_4`M,O/M<VSM;''
ML,K'S:/3P[7$U[3,K"X`L=C0Z\K'TKNX]LK]U]8N`+3+M+"_VK'8T.O2JM/)
MT:'/[K2PO]HH3W!T:6]N*<OYNO2]T`#*L;SD`,JQO.37M]?9`,JQO.2X\<J]
M`,JQQ_C1H=3Q`%1I;6]R+4QE<W1E`+'JS.(`RM6\_LC+`,CGN?O2JKBTT:$L
MQ^O4VK7CT:'*\['JM<3-K,JQL+0@0V]N=')O;+S\*+CVR,N\QLOCN_HI(+OR
M($-O;6UA;F2\_"C&N[G[O,;+X[OZ*2X`O?',[`!(5$U,(-2MRKS.Q+S^`+;@
MN.<`S="_R\#-R+JUN@##]\SL`,S`O-,`S-C!HL3AM.^ZS;;@L,VXYP#5YKOR
MO-D`T,?&VK;^`,V[Q.'+N0#-P;;ZQN0`S<&V^L;DSL0@*$E33RTX.#4Y+3DI
M`,W!O^+"_,NYS+D`S-B_R\NYNLV_K;_&R[G(NK6Z`,V\S=_"K`#*Y,CKQ/JU
MQ-&AU/$Z(`#7S\WBS]_6N,K].B``S?C6MP#-^-:W.@#.VKC)M.\`SMJ_R\"\
M`,[>MZBTYLBA(%9&4R#$O\*\+@#7HK+ARK'.WK>HU/:\T[;NS>*UQ-/#NZ?0
MQ<^B+@#.WK>HN,2QY"!61E,@SL2\_B`B)7,B(+7$R*C/WBX`SMZWJ+'DN/P@
M5D93(,[$O/X@)7,O)7,@M<3(J,_>+@#.WK>HL>2X_,ZJ("5S+@#.WK>HP:R]
MT];!(%-13""W_L[QQO<N`,[>MZC*N=/#(%-33"#!K+W3+@#.WK>HN+36QB!6
M1E,@SL2\_BX`SMZWJ+VHP:(@5D93(,2_PKP@(B5S(BX`SMZWJ+VHP:(@5D93
M(,2_PKPN`,[>MZB]J,&B(%9&4R#.Q+S^+@#.WK>HO:O*_;[=O>+1N<OU+@#.
MWK>HR;ZS_2`E<RRTR\2_PKRRHK?'O]6PUP#.WK>HM=VYZ<F^L_W$O\*\+@#.
MWK>HR;ZS_2!61E,@Q+_"O"X`SMZWJ,F^L_T@5D93(,2_PKPZ("5S+@#.WK>H
MR;ZS_2!61E,@SL2\_B`B)7,B+@#.WK>HR;ZS_2!61E,@SL2\_BX`SMZWJ+7=
MN>G)OK/](%9&4SH@)7,N`,[>MZC%T+;/M;''L+7$Q+_"O"X`SMZWJ+WBOZK&
MOM:DS[B]V@#.WK>HTL:VKR!61E,@SL2\_BX`SMZWJ+3ROZH@5D93(,[$O/X@
M(B5S(BX`SMZWJ-"TR.L@5D93(,[$O/XN`,[>MZBT\K^J(%9&4R#.Q+S^+@#.
MWK>HM/*_JM&YR_7.Q+S^+@#.WK>HML'(H2!V9G-R;V]T(,2_PKPN`,[>MZBQ
MY+C\(%9&4R#$O\*\M<3#^[/&+@#.WK>HR;ZS_2!61E,@Q+_"O#H@)7,N`,[>
MMZBQY+C\(%9&4R#.Q+S^("(E<R(@M<3#^[/&+@#.WK>HL>2X_"!61E,@SL2\
M_B`E<R\E<R"UQ,/[L\8N`,[>MZBQY+C\(%9&4R#.Q+S^M<3#^[/&+@#.WK>H
MUZJ[NR!7;W)D(,[$O/X`SMZWJ-"TR.L@5D93("(E<R(@SL2\_BX`SMZWJ-"T
MR.L@5D93(,[$O/[*_;[=+@#/PKNNS]\`N+34K0"W_L[QQO?!K+W3RK&WHLGZ
MSK34I,;:M<2[V-.F.B``MZ+)^LZTU*3&VK7$N]C3IBS3R;?^SO'&]SH@`,WR
MT\/"ZR`H551&+3@I`+"BP*VRKL&JNL_'];.DN?H`TZ*Y^@##P+GZ`%5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P"UI=2J`,ZTUJJUQ`#.
MM-:JM<33P[NGP_N[\L/<PNLN`,ZTUJ>SUK7$P*G5N</[`+'DN/P`N/S0PB`E
M<P"X_-#"T\.[IP"X_-#"L\S0\M+1R;ZS_2X`R<^TJP#2T<G/M*O+^=/0TZ;3
MP[/,T/*UQ,7DUL/.Q+S^M;VW_L[QQO<N`,[:P*VYYP#3P[NG("5S(,ZTS:BY
M_2`E<R"UQ,K:R*C1Z=:D+@#3P[NGN=S`[0#3P[NGT:'/[@#3P[NGUZ*RX0"T
MR]6^S*BUQ-/#NZ?7HK+AS[7-L]+1S:/3PRX`T\.[I\/[`-/#NZ?#^SH`T\.[
MISH@`,^US;/6T+7$T\.[ISH`SMK7R+'PO\O+N<RY`%9&4R#$O\*\LJ*RN[3F
MU-HN`+S9QMH`TM'5TK6]T]#0I[7$M=BUXSH@`-/0T*?0U`#2U+?6UM/.JK6E
MSKLHM-//UM3:QO#+XRD`UK4`S=_"L["BS;P`L>2[KP#.K\3:R/#`K0#1Z=:D
MRJ>PW"`M(+3+T\J\_K_)Q-S2T=3BR,O)P]?4M-NXQ"X`L.:QO@"PYK&^O]C6
MQ@#4O<3/`-2]Q,_.Q"`H5DE30TE)*0"\[,K3("5S`-3:T,*TL+_:M/*_J@#2
MU"`E<R"RZ;^T`-.BRO3.K+;[OJG(NK6Z`,/`RO3.K+ZIR+JUN@#$W+S[ML@`
MQ-R\^[;(.B``TN*T\\#[M_RUPK?GM>?0Q;FKR[[-N+G](%--5%``OJ^XY@"^
MK[CF(2$A(+33("5S(,K6MJ_)OK/]L\S0\BX`S=_`^\NYNLVXN\V\R+JUN@"^
MK[CF`-#'QMK(_0#,[,;XU*2RX@#-^-6^`,WXU;X`P[_6W`"[MM.M`+NVTZVU
MO2`E<P"[MM.M+"`E<P#.]\6W("A)4T\M.#@U.2TQ*0#.]\6W("A)4T\M.#@U
M.2TQ-2D`SO?(]KG^P*T`M<?"O+KSTZ:XP\_(S]3*OB`E<R#$Q-*[N/;3IM/#
ML\S0\C\`U]:VSK7$M]:X]-?6M_L_`-+]RO:UQ,>PM;RW^S\`M^?+V2B]VBD`
MM^?+V3H`M^?+V3H@`+FDU_>UV-:W`+FDU_>UY[NP`%@U,#EV,R#`J=6YP_L`
MQ.H`Q.H`66%H;V\@(2"UV,V\`,._Q.H`TK+#Q0#*Q[7$+,[2S:S2X@#$^K6Q
MQ[#*N=/#M+_.Q-?6L>#0M,2CRKTN(,JYT\,@6SP^72"PM,6EO\G'T+N[SJK-
M^-*SL>#0M,2CRKTN`,3ZLJ+.M,KDR.O2N[CVNL^WJ+7$M>?7T]/*O/ZUV-:W
M+@#$^K*BSK33R;6\R.NUQ,[$O/[6T+;4T[/(SKK.U]:VSK6]("5S`,3ZTM&^
MK=>BS_HN`,3ZL=C0Z\KDR.O2N[CVNL^WJ+7$UK4N`,3ZL=C0Z\_(N>:[KKK#
MROV^W<KW*$1A=&%4<F5E*;?^SO&VR[+%Q-R\S-#XRKG3P]#"T\.[I]>BLN&W
M_L[Q+@#'Z\/HRO;.RLSBHZS4VL3ZM*O+S<[*S.*QJ+CFUJ['L"X`Q/JQV-#K
MRN3(Z[3+P:R]T\OYUKC/\K7$S?C6MP#'Z]:XMJC2JLF^L_VUQ+?^SO'&]RX`
MQ^O6N+:HTJK)OK/]M<33P[NG+@#'Z]:XMJC2JM#"U/:UQ-/#NZ<N`,?KUKBV
MJ-*JN/S0PK7$T\.[IRX`Q^O6N+:HTJK6M-#0M<37]]/#+@#$^K7$("5S(+OA
MQMK2T;G]RK$NQ^O6V-#"M<?"O"X`Q/JUQ+7GU]/3RKS^M=C6MP#$^K7$T,7/
MH@#7U+33Q/JUQ"`E<R"[X<;:OZK*O-+4P+3$^K7$TO+,V,WXM=C6M]+1L>2X
M_"X@SJJQH[NDQ/JUQ+"RR*O&\+S[HZS$^K'8T.O6V-#"M<?"O"X`Q/JUQ-#5
MP_L`Q/JUQ-'IUJ2VR[*BSK36I[/6P="S]M/#NZ>[\KC#N:;$W-+1L;NYV+'5
M+@#7U+33Q/JUQ"`E<R"[X<;:OZK*O-+4P+3$^K7$Y*_`P,;WR\:Z]=+1L>2X
M_"X@SJJQH[NDQ/JUQ+"RR*O&\+S[HZS$^K'8T.O6V-#"M<?"O"X`Q/JUQ.2O
MP,#&][*BSK36I[/6U>*X]KFFQ-PN`,3ZM;''L,OYQ>36P[7$RK''^#H`Q/JU
MQ-&AS^[2T;C\T,(N`,3ZM<34MK/,M_[.\<;W.@#$S\NYP*VW\@#4^M+!MOL`
MU-ZQR-''`+WRL,VRO,ZD`%O.RLSBL:BXYET`6\Z[T]K0T"`E<R"YLB`E<R#0
MT%T`SL2\_@"TTR`E<R`H)7,I(-/:("5S("5S`,JQ.@#!HKRT`,/[L\8`R=#.
MM,JUS]8N`,G0SK3*M<_6+@#4V;3.RN3(Z\3ZM<3#W,+KTM3(M\C/SM[.\P#.
MM,/\P_L`T\.[I]&AU/$`T,?&VCH`=V5A=&AE<BYC;VT@S?C5O@``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O='5R8F$O;&]C86QE+WIH7U17+P``````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-@`P,C`P,S8`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L;V-A;&4O>FA?5%<O3$-?3453
M4T%'15,O````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8R-S4V`#`R,38R,P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO
M8V%L92]Z:%]45R],0U]-15-304=%4R]T=7)B82YM;P``````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`T,#,W,S``,3`T,3<S-C(W-38`,#(S,S`Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-X2!)4`````5@@``!P```#,
M0@``(PL``'R%````````"+(```X````)L@``#P```!BR```-````*+(```@`
M```VL@``"P```#^R```,````2[(``!D```!8L@``&0```'*R```$````C+(`
M`"D```"1L@``&````+NR```;````U+(``"T```#PL@``'0```!ZS```D````
M/+,``"D```!ALP``*0```(NS```9````M;,``"@```#/LP``)````/BS```E
M````';0``"8```!#M```#````&JT```D````=[0```\```"<M```"P```*RT
M```.````N+0```4```#'M```*````,VT```(````]K0```H```#_M```%0``
M``JU```)````(+4``!(````JM0``"P```#VU```=````2;4``(4```!GM0``
M#@```.VU```*````_+4```T````'M@``#@```!6V```1````)+8```T````V
MM@``#````$2V```-````4;8```8```!?M@``E````&:V```*````^[8```\`
M```&MP``&````!:W```,````+[<```X````\MP``#@```$NW```(````6K<`
M``D```!CMP``*P```&VW```N````F;<``!H```#(MP``,@```..W```X````
M%K@``%0```!/N```40```*2X``!:````]K@``%<```!1N0``-````*FY```)
M````WKD```T```#HN0``!P```/:Y```*````_KD```\````)N@``!0```!FZ
M```&````'[H``!$````FN@``"````#BZ```1````0;H```D```!3N@``"0``
M`%VZ```E````9[H``"````"-N@``$P```*ZZ```3````PKH``!````#6N@``
M#P```.>Z```*````][H```,````"NP``#P````:[```4````%KL```D````K
MNP``#0```#6[```2````0[L``!D```!6NP``'@```'"[```/````C[L``!``
M``"?NP``(0```+"[```*````TKL```@```#=NP``#P```.:[```(````]KL`
M`"0```#_NP``!@```"2\```4````*[P``!8```!`O```"````%>\``!.````
M8+P``"T```"OO```(0```-V\```9````_[P```<````9O0``#````"&]```4
M````+KT```T```!#O0``$@```%&]```A````9+T``!<```"&O0``*0```)Z]
M```L````R+T```X```#UO0```P````2^```/````"+X```L````8O@``!P``
M`"2^```'````++X```4````TO@``!0```#J^```*````0+X```,```!+O@``
M%P```$^^```*````9[X```\```!RO@``#@```(*^```8````D;X``",```"J
MO@``#@```,Z^```.````W;X``!0```#LO@``%P````&_```7````&;\``!<`
M```QOP``$P```$F_```/````7;\```X```!MOP``'P```'R_```=````G+\`
M``<```"ZOP``!@```,*_```(````R;\```\```#2OP``!@```.*_```*````
MZ;\``!,```#TOP``"P````C````0````%,```!4````EP```%0```#O````'
M````4<```!````!9P```!0```&K````5````<,```!$```"&P```#````)C`
M```H````I<```#H```#.P```.P````G!```X````1<$```D```!^P0``!P``
M`(C!```4````D,$```,```"EP0``!0```*G!```)````K\$``!````"YP0``
M"0```,K!```3````U,$``#D```#HP0``$@```"+"```G````-<(``"P```!=
MP@``*@```(K"```E````M<(```H```#;P@``!@```.;"```)````[<(```<`
M``#WP@``+P```/_"```W````+\,``"X```!GPP``50```);#```M````[,,`
M`"T````:Q```/0```$C$```_````AL0``"T```#&Q```0````/3$```C````
M-<4``",```!9Q0``0````'W%```M````OL4``#,```#LQ0``)0```"#&```5
M````1L8``!D```!<Q@``*0```';&```D````H,8``"@```#%Q@``$0```.[&
M```*`````,<```H````+QP``$````!;'```6````)\<``!8````^QP``!P``
M`%7'```'````7<<``!0```!EQP``"@```'K'```(````A<<``"<```".QP``
M"````+;'```,````O\<```<```#,QP``!P```-3'```&````W,<``!$```#C
MQP``!0```/7'```'````^\<```8````#R```%`````K(```(````'\@``"D`
M```HR```#@```%+(```*````8<@```0```!LR```!P```''(```)````><@`
M``8```"#R```$0```(K(```'````G,@``!8```"DR```!````+O(```(````
MP,@```8```#)R```#0```-#(```&````WL@``!X```#ER```!@````3)```1
M````"\D```@````=R0``#0```";)```,````-,D```<```!!R0``$0```$G)
M```#````6\D```,```!?R0``%P```&/)```#````>\D``!,```!_R0``'0``
M`)/)```(````L<D```0```"ZR0``"````+_)```(````R,D``$$```#1R0``
M&@```!/*```<````+LH``"````!+R@``%0```&S*```&````@LH```8```")
MR@``%0```)#*```8````ILH``"(```"_R@``+@```.+*```=````$<L``"$`
M```ORP``5````%'+```I````ILL```H```#0RP``!P```-O+```5````X\L`
M``X```#YRP``"@````C,```/````$\P```T````CS```#P```#',```-````
M0<P```D```!/S```%````%G,```&````;LP``!@```!US```'0```([,```3
M````K,P``!$```#`S```%````-+,```$````Y\P```8```#LS```%````//,
M``!4````",T``&0```!=S0``!````,+-```.````Q\T```\```#6S0``!0``
M`.;-```%````[,T``!L```#RS0``&@````[.```3````*<X```T````]S@``
M$0```$O.```1````7<X``!8```!OS@``%P```(;.```<````GLX``"H```"[
MS@``.0```.;.```B````(,\``#(```!#SP``$````';/```A````A\\```4`
M``"ISP``$P```*_/```+````P\\``!(```#/SP``"@```.+/```/````[<\`
M``T```#]SP``$0````O0```3````'=````P````QT```!@```#[0```,````
M1=````8```!2T```%P```%G0```0````<=```!$```""T```"````)30```%
M````G=````P```"CT```$````+#0```%````P=````X```#'T```#0```-;0
M```C````Y-````8````(T0``%@````_1```J````)M$```<```!1T0``#0``
M`%G1```'````9]$```L```!OT0``!P```'O1```'````@]$```\```"+T0``
M"0```)O1```)````I=$```H```"OT0``&0```+K1```]````U-$``!T````2
MT@``#````##2```0````/=(```4```!.T@``)0```%32```2````>M(``!,`
M``"-T@``%0```*'2```2````M](``"L```#*T@``.P```/;2```@````,M,`
M``X```!3TP``"````&+3```4````:],``#8```"`TP``(0```+?3```0````
MV=,```@```#JTP``#````//3```$`````-0```\````%U```#@```!74```*
M````)-0```T````OU```'P```#W4```<````7=0``"$```!ZU```'@```)S4
M```9````N]0``!X```#5U```'0```/34```;````$M4``"`````NU0``+@``
M`$_5```F````?M4``!P```"EU0``'@```,+5```<````X=4``"8```#^U0``
M*P```"76```S````4=8``"8```"%U@``*P```*S6```X````V-8``!T````1
MUP``%0```"_7```O````1=<``"````!UUP``$@```);7```I````J=<``!X`
M``#3UP``(````/+7```2````$]@``*(````FV```%@```,G8```C````X-@`
M`"@````$V0``*0```"W9```H````5]D``!\```"`V0``%0```*#9```@````
MMMD``"4```#7V0``*````/W9```M````)MH``#````!4V@``D@```(7:```A
M````&-L``!8````ZVP``'````%';```F````;ML``"H```"5VP``00```,#;
M``!$`````MP```P```!'W```!P```%3<```'````7-P```8```!DW```$P``
M`&O<```-````?]P``!T```"-W```$````*O<```2````O-P```<```#/W```
M$P```-?<```2````Z]P```<```#^W```!`````;=```0````"]T```P````<
MW0``#@```"G=```-````.-T```\```!&W0``$P```%;=```-````:MT``"@`
M``!XW0```P```*'=```-````I=T```8```"SW0``$0```+K=```7````S-T`
M`!L```#DW0``#@````#>```"````#]X``$D````2W@``!0```%S>```0````
M8MX```\```!SW@``!````(/>```-````B-X```X```"6W@```P```*7>```.
M````J=X```@```"XW@``#P```,'>```/````T=X```<```#AW@``#0```.G>
M```0````]]X```T````(WP``&@```!;?```+````,=\```8````]WP``$P``
M`$3?```+````6-\``!,```!DWP``#````'C?```*````A=\``!$```"0WP``
M&0```*+?```7````O-\```L```#4WP``#0```.#?```B````[M\``!8````1
MX```&P```"C@```T````1.````H```!YX```&````(3@```9````G>```!8`
M``"WX```(@```,[@```C````\>````\````5X0``#0```"7A```'````,^$`
M``H````[X0``"@```$;A```4````4>$```L```!FX0``(@```'+A```O````
ME>$```L```#%X0``"0```-'A```9````V^$```L```#UX0``%P````'B```7
M````&>(```D````QX@``!P```#OB```6````0^(```\```!:X@``&0```&KB
M```6````A.(```X```";X@``&````*KB```(````P^(```T```#,X@``)@``
M`-KB```H`````>,``$,````JXP``"````&[C```2````=^,``!\```"*XP``
M"````*KC```+````L^,``"\```"_XP``#@```._C```.````_N,```4````-
MY```!@```!/D```#````&N0```<````>Y```!````";D```)````*^0``!(`
M```UY```"@```$CD```*````4^0```\```!>Y```$````&[D```7````?^0`
M`!$```"7Y```$0```*GD```9````N^0``!<```#5Y```"0```.WD```%````
M]^0```L```#]Y```"@````GE```%````%.4```T````:Y0``&P```"CE```7
M````1.4``!0```!<Y0``"0```''E```.````>^4```T```"*Y0``$@```)CE
M```X````J^4``"````#DY0``"`````7F```.````#N8``'L````=Y@``&```
M`)GF```]````LN8``!4```#PY@``$0````;G```'````&.<```4````@YP``
M(P```";G```S````2N<``!@```!^YP``'0```)?G```N````M><``!X```#D
MYP``&P````/H```9````'^@``"<````YZ```-P```&'H```D````F>@``!L`
M``"^Z```$P```-KH```'````[N@```@```#VZ```!@```/_H```&````!ND`
M`!`````-Z0``#P```![I```0````+ND```\````_Z0``"P```$_I```/````
M6^D```P```!KZ0``#P```'CI```'````B.D```8```"0Z0``#@```)?I```,
M````IND```\```"SZ0``"````,/I```&````S.D``!,```#3Z0``(@```.?I
M```M````"NH```@````XZ@``$P```$'J```>````5>H``"4```!TZ@``&@``
M`)KJ```5````M>H``!X```#+Z@``0P```.KJ```A````+NL``"````!0ZP``
M&0```''K```7````B^L``"4```"CZP``)0```,GK```7````[^L``!8````'
M[```(0```![L```B````0.P```0```!C[```&P```&CL```-````A.P```P`
M``"2[````P```)_L```%````H^P```@```"I[```"@```++L```,````O>P`
M``L```#*[```$````-;L```,````Y^P```0```#T[```$P```/GL```4````
M#>T```P````B[0``"0```"_M```.````.>T```L```!([0``&P```%3M```%
M````<.T```<```!V[0``!````'[M```&````@^T```<```"*[0``"@```)+M
M```*````G>T```T```"H[0``"0```+;M```$````P.T```4```#%[0```P``
M`,OM```8````S^T```H```#H[0``!````//M```F````^.T```X````?[@``
M?````"[N```5````J^X```4```#![@``!P```,?N```,````S^X```@```#<
M[@``"@```.7N```&````\.X```@```#W[@```@````#O```&`````^\```8`
M```*[P``%````!'O```,````)N\```T````S[P``$````$'O```;````4N\`
M``0```!N[P``"0```'/O```0````?>\```D```".[P``"0```)CO```%````
MHN\```@```"H[P``!@```+'O```9````N.\```X```#2[P``!P```.'O```'
M````Z>\```4```#Q[P``"0```/?O```*`````?```!,````,\````@```"#P
M```&````(_````L````J\```#0```#;P```)````1/````8```!.\```$@``
M`%7P```)````:/````<```!R\```!0```'KP```4````@/```!T```"5\```
M0@```+/P```E````]O```"4````<\0``!@```$+Q```*````2?$```0```!4
M\0``"0```%GQ```(````8_$``!$```!L\0``"0```'[Q```&````B/$```T`
M``"/\0``!@```)WQ```$````I/$``!X```"I\0``!0```,CQ```.````SO$`
M``0```#=\0``!@```.+Q```'````Z?$``"$```#Q\0``#0```!/R```5````
M(?(```8````W\@``!````#[R```1````0_(```8```!5\@``"@```%SR```B
M````9_(```0```"*\@``!0```(_R```=````E?(```0```"S\@``#````+CR
M```)````Q?(```P```#/\@``#@```-SR```*````Z_(``!````#V\@``$P``
M``?S```3````&_,```@````O\P``"0```#CS```%````0O,``#H```!(\P``
M,````(/S```U````M/,``"D```#J\P``1P```!3T```X````7/0``"D```"5
M]```/P```+_T```N````__0``"T````N]0``'P```%SU```/````?/4``!(`
M``",]0``"P```)_U```F````J_4``"D```#2]0``)````/SU```F````(?8`
M``@```!(]@``"@```%'V```)````7/8```<```!F]@``(````&[V```@````
MC_8``"8```"P]@``!````-?V```@````W/8```H```#]]@``&0````CW```I
M````(O<``!(```!,]P``!P```%_W```*````9_<```P```!R]P``#P```'_W
M```"````C_<``!````"2]P``0````*/W``!P````Y/<``&8```!5^```#@``
M`+SX```)````R_@```H```#5^```$@```.#X```3````\_@```P````'^0``
M!@```!3Y```<````&_D```\````X^0``&P```$CY```2````9/D``!````!W
M^0``$0```(CY```<````FOD``",```"W^0``:@```-OY```/````1OH```4`
M``!6^@``$````%SZ```)````;?H```0```!W^@``"P```'SZ```@````B/H`
M`!0```"I^@``#````+[Z```,````R_H```\```#8^@``%0```.CZ```I````
M_OH``"H````H^P``)@```%/[```G````>OL``"D```"B^P``*@```,S[```9
M````]_L``$(````1_```$0```%3\```2````9OP``!,```!Y_```%````(W\
M```/````HOP``!8```"R_```%P```,G\```0````X?P``!$```#R_```-```
M``3]```3````.?T``!(```!-_0``-0```&#]```4````EOT```<```"K_0``
M#````+/]```*````P/T``"````#+_0``$````.S]```4````_?T``!0````2
M_@``$0```"?^```7````.?X``!P```!1_@``#0```&[^```-````?/X``!,`
M``"*_@``%@```)[^```4````M?X``!H```#*_@``$0```.7^```,````]_X`
M`!`````$_P``&@```!7_```>````,/\``!H```!/_P``$P```&K_```5````
M?O\``!$```"4_P``%P```*;_```4````OO\``!<```#3_P``%0```.O_```)
M`````0`!`!`````+``$`&0```!P``0`$````-@`!``<````[``$`"P```$,`
M`0`1````3P`!``8```!A``$`!@```&@``0`&````;P`!``4```!V``$`!P``
M`'P``0`'````A``!``4```",``$`%@```)(``0`&````J0`!``8```"P``$`
M!````+<``0`$````O``!``<```#!``$`#@```,D``0`,````V``!``P```#E
M``$`#0```/(``0`*``````$!``X````+`0$`!0```!H!`0`H````(`$!``X`
M``!)`0$`#````%@!`0`/````90$!``H```!U`0$`"````(`!`0`)````B0$!
M`"L```"3`0$`!````+\!`0`(````Q`$!`"8```#-`0$`$@```/0!`0`/````
M!P(!``8````7`@$`"@```!X"`0!,````*0(!``<```!V`@$`"````'X"`0`@
M````AP(!``D```"H`@$`#0```+("`0`)````P`(!`!0```#*`@$`#````-\"
M`0`-````[`(!``X```#Z`@$`%@````D#`0`1````(`,!``8````R`P$``P``
M`#D#`0`&````/0,!``<```!$`P$`!````$P#`0`+````40,!``L```!=`P$`
M!P```&D#`0`'````<0,!`!8```!Y`P$`#0```)`#`0`-````G@,!``H```"L
M`P$`$````+<#`0`/````R`,!`!$```#8`P$`%P```.H#`0`*`````@0!`!$`
M```-!`$`"````!\$`0`$````*`0!``\````M!`$`.@```#T$`0`%````>`0!
M``0```!^!`$`'@```(,$`0`.````H@0!`!````"Q!`$`"P```,($`0`,````
MS@0!``D```#;!`$`!P```.4$`0`*````[00!``D```#X!`$`#@````(%`0`0
M````$04!`!L````B!0$`&````#X%`0`:````5P4!``H```!R!0$`"0```'T%
M`0`*````AP4!``P```"2!0$`#P```)\%`0`(````KP4!``8```"X!0$`!P``
M`+\%`0`%````QP4!``L```#-!0$`1P```-D%`0`-````(08!``D````O!@$`
M!````#D&`0`#````/@8!`!,```!"!@$`$P```%8&`0`3````:@8!``H```!^
M!@$``@```(D&`0`$````C`8!`"4```"1!@$``P```+<&`0`%````NP8!`"H`
M``#!!@$`"@```.P&`0`%````]P8!``0```#]!@$`"@````('`0`-````#0<!
M``8````;!P$`"````"('`0`(````*P<!``0````T!P$`!0```#D'`0!H````
M/P<!``D```"H!P$`#````+('`0`%````OP<!``8```#%!P$`&P```,P'`0`O
M````Z`<!`!`````8"`$`"@```"D(`0`(````-`@!``\````]"`$`"@```$T(
M`0`)````6`@!`!,```!B"`$`&P```'8(`0`8````D@@!`!<```"K"`$`&@``
M`,,(`0`?````W@@!``X```#^"`$`%P````T)`0`#````)0D!``<````I"0$`
M"````#$)`0`'````.@D!``D```!""0$`"@```$P)`0`+````5PD!``<```!C
M"0$`40```&L)`0`0````O0D!``P```#."0$`&@```-L)`0!*````]@D!`!D`
M``!!"@$`!@```%L*`0`:````8@H!`"4```!]"@$`!@```*,*`0`&````J@H!
M`!\```"Q"@$`!@```-$*`0`)````V`H!`!@```#B"@$`%P```/L*`0`H````
M$PL!``8````\"P$`#0```$,+`0`H````40L!`"(```!Z"P$`5P```)T+`0`3
M````]0L!`",````)#`$`$P```"T,`0`"````00P!``L```!$#`$`#````%`,
M`0`(````70P!``T```!F#`$`"@```'0,`0`6````?PP!``<```"6#`$`%```
M`)X,`0`&````LPP!``@```"Z#`$`#@```,,,`0`'````T@P!``H```#:#`$`
M"P```.4,`0`R````\0P!`!<````D#0$`!P```#P-`0`,````1`T!``T```!1
M#0$`#````%\-`0`$````;`T!``D```!Q#0$`"0```'L-`0`*````A0T!``<`
M``"0#0$`"0```)@-`0`)````H@T!``H```"L#0$`!P```+<-`0`*````OPT!
M`!4```#*#0$`&P```.`-`0!)````_`T!`!(```!&#@$`"@```%D.`0`6````
M9`X!``\```![#@$`$````(L.`0`)````G`X!`!````"F#@$`!P```+<.`0`2
M````OPX!``0```#2#@$`"P```-<.`0`'````XPX!``4```#K#@$`!0```/$.
M`0`:````]PX!``L````2#P$`%````!X/`0`1````,P\!`!H```!%#P$`%@``
M`&`/`0`4````=P\!`!<```",#P$`&````*0/`0`<````O0\!`!D```#:#P$`
M!P```/0/`0`%````_`\!``T````"$`$`#````!`0`0`+````'1`!`!$````I
M$`$`"````#L0`0`7````1!`!``L```!<$`$`#````&@0`0`?````=1`!`!H`
M``"5$`$`$P```+`0`0`$````Q!`!``H```#)$`$`!````-00`0`,````V1`!
M``4```#F$`$`"0```.P0`0`(````]A`!``4```#_$`$`!P````41`0`%````
M#1$!``0````3$0$``@```!@1`0`8````&Q$!`!<````T$0$`.````$P1`0`L
M````A1$!`!(```"R$0$`*0```,41`0`R````[Q$!``H````B$@$`+````"T2
M`0`N````6A(!`#,```")$@$`,P```+T2`0`X````\1(!`!$````J$P$`#P``
M`#P3`0`8````3!,!`!````!E$P$`#P```'83`0`3````AA,!`!4```":$P$`
M%````+`3`0`2````Q1,!`!0```#8$P$`+0```.T3`0`M````&Q0!`#$```!)
M%`$`+@```'L4`0`O````JA0!`"P```#:%`$`8@````<5`0`3````:A4!``T`
M``!^%0$`"````(P5`0`7````E14!``@```"M%0$`#````+85`0`K````PQ4!
M`"$```#O%0$`&````!$6`0`:````*A8!``D```!%%@$`10```$\6`0!!````
ME18!``0```#7%@$`$P```-P6`0`4````\!8!``X````%%P$`$P```!07`0`8
M````*!<!``8```!!%P$`"0```$@7`0`*````4A<!``\```!=%P$`$````&T7
M`0`'````?A<!``X```"&%P$`!0```)47`0`;````FQ<!``@```"W%P$`!@``
M`,`7`0`4````QQ<!`!$```#<%P$`&````.X7`0`.````!Q@!`#@````6&`$`
M`@```$\8`0`&````4A@!``X```!9&`$`$````&@8`0`%````>1@!``<```!_
M&`$`!@```(<8`0`H````CA@!``P```"W&`$`'````,08`0`$````X1@!`"D`
M``#F&`$`'P```!`9`0`9````,!D!`%P```!*&0$`%````*<9`0`^````O!D!
M`!\```#[&0$`$````!L:`0`'````+!H!``X````T&@$`#````$,:`0`,````
M4!H!`!,```!=&@$`"@```'$:`0`=````?!H!`!D```":&@$`!0```+0:`0`1
M````NAH!``T```#,&@$`$0```-H:`0`D````[!H!`!(````1&P$`%0```"0;
M`0`2````.AL!``X```!-&P$`&0```%P;`0`(````=AL!``D```!_&P$`#0``
M`(D;`0`*````EQL!``<```"B&P$`#P```*H;`0`&````NAL!``L```#!&P$`
M&@```,T;`0`*````Z!L!``<```#S&P$`"````/L;`0`%````!!P!`!\````*
M'`$`!@```"H<`0`0````,1P!``@```!"'`$`#0```$L<`0`(````61P!`!X`
M``!B'`$`$@```($<`0`L````E!P!`!H```#!'`$`"0```-P<`0`*````YAP!
M`!4```#Q'`$`!0````<=`0`4````#1T!``0````B'0$`$````"<=`0`&````
M.!T!``<````_'0$`'@```$<=`0`H````9AT!``H```"/'0$`'````)H=`0`1
M````MQT!`!$```#)'0$`"P```-L=`0`:````YQT!`!0````"'@$`!````!<>
M`0`$````'!X!``L````A'@$`!0```"T>`0`&````,QX!`!$````Z'@$`"```
M`$P>`0`&````51X!`!L```!<'@$`-````'@>`0`T````K1X!`"````#B'@$`
M*0````,?`0`@````+1\!`$$```!.'P$`&@```)`?`0`A````JQ\!`"@```#-
M'P$`*0```/8?`0!0````("`!`"(```!Q(`$`!@```)0@`0`(````FR`!``4`
M``"D(`$`"````*H@`0`9````LR`!`!D```#-(`$`*@```.<@`0`C````$B$!
M`!D````V(0$`+@```%`A`0`T````?R$!``@```"T(0$`%P```+TA`0`*````
MU2$!``<```#@(0$`(0```.@A`0`(````"B(!`!`````3(@$`#@```"0B`0`4
M````,R(!``L```!((@$`!P```%0B`0`3````7"(!``@```!P(@$`"P```'DB
M`0`*````A2(!`!0```"0(@$`#P```*4B`0`R````M2(!``L```#H(@$`!0``
M`/0B`0`%````^B(!`!4`````(P$`#````!8C`0`%````(R,!`!<````I(P$`
M#P```$$C`0`$````42,!``H```!6(P$`"0```&$C`0`+````:R,!``T```!W
M(P$`#````(4C`0`.````DB,!``4```"A(P$`!````*<C`0`4````K",!``T`
M``#!(P$`(@```,\C`0`R````\B,!`!L````E)`$`10```$$D`0`2````AR0!
M`!<```":)`$`!P```+(D`0`>````NB0!`!0```#9)`$`!0```.XD`0`4````
M]"0!``8````))0$`!P```!`E`0`.````&"4!`"H````G)0$`!@```%(E`0`,
M````624!`!,```!F)0$`#0```'HE`0`1````B"4!`!4```":)0$`"P```+`E
M`0`V````O"4!``H```#S)0$`(@```/XE`0`+````(28!``\````M)@$`A0``
M`#TF`0`R````PR8!`!L```#V)@$`)0```!(G`0`P````."<!`#$```!I)P$`
M+0```)LG`0`.````R2<!``4```#8)P$`#@```-XG`0`3````[2<!`!$````!
M*`$`$@```!,H`0`'````)B@!`!$````N*`$`$P```$`H`0`'````5"@!`!0`
M``!<*`$`&````'$H`0`'````BB@!``4```"2*`$`#````)@H`0`,````I2@!
M`!(```"R*`$`!````,4H`0`'````RB@!``H```#2*`$`"P```-TH`0`,````
MZ2@!``X```#V*`$`#@````4I`0`%````%"D!``4````:*0$`+@```"`I`0`F
M````3RD!`",```!V*0$``P```)HI`0`2````GBD!``8```"Q*0$`'@```+@I
M`0`8````URD!`!D```#P*0$`)0````HJ`0`-````,"H!``D````^*@$``P``
M`$@J`0`8````3"H!``<```!E*@$`"@```&TJ`0`"````>"H!``P```![*@$`
M%0```(@J`0`+````GBH!`!D```"J*@$`(````,0J`0`2````Y2H!``4```#X
M*@$`"@```/XJ`0`5````"2L!`!(````?*P$`#````#(K`0`$````/RL!``D`
M``!$*P$`!P```$XK`0`,````5BL!`%(```!C*P$`%P```+8K`0`D````SBL!
M`"$```#S*P$`$@```!4L`0`'````*"P!``8````P+`$`#@```#<L`0`-````
M1BP!`!$```!4+`$`&P```&8L`0`,````@BP!``P```"/+`$`#0```)PL`0`5
M````JBP!`!(```#`+`$`#P```-,L`0`4````XRP!``H```#X+`$`&P````,M
M`0`@````'RT!`!X```!`+0$`$````%\M`0`+````<"T!`"<```!\+0$`)0``
M`*0M`0!I````RBT!`"8````T+@$`&@```%LN`0`7````=BX!`!D```".+@$`
M&@```*@N`0`E````PRX!`"@```#I+@$`)P```!(O`0`:````.B\!`!<```!5
M+P$`&P```&TO`0!$````B2\!`#0```#.+P$`)0````,P`0`9````*3`!`!\`
M``!#,`$`&P```&,P`0`3````?S`!``@```"3,`$`!P```)PP`0`(````I#`!
M``D```"M,`$`%0```+<P`0`-````S3`!`",```#;,`$`#0```/\P`0`3````
M#3$!``@````A,0$``P```"HQ`0!&````+C$!`#\```!U,0$`-P```+4Q`0!7
M````[3$!``4```!%,@$`'P```$LR`0`O````:S(!``H```";,@$`$````*8R
M`0`(````MS(!``T```#`,@$`+0```,XR`0`$````_#(!``<````!,P$`"```
M``DS`0`-````$C,!``H````@,P$`3P```"LS`0`E````>S,!``L```"A,P$`
M'P```*TS`0`=````S3,!`"4```#K,P$`(````!$T`0`D````,C0!`"````!7
M-`$`"P```'@T`0`'````A#0!``T```",-`$`#````)HT`0`7````IS0!``8`
M``"_-`$`#````,8T`0`'````TS0!``D```#;-`$`$P```.4T`0`)````^30!
M``0````#-0$`$`````@U`0`(````&34!``@````B-0$`!````"LU`0`+````
M,#4!``P````\-0$`$@```$DU`0`1````7#4!``P```!N-0$`#P```'LU`0`'
M````BS4!``T```"3-0$`#@```*$U`0`4````L#4!``X```#%-0$`!P```-0U
M`0`,````W#4!`!L```#I-0$`+`````4V`0`3````,C8!``8```!&-@$`!P``
M`$TV`0`3````538!``4```!I-@$`!````&\V`0`7````=#8!`#D```",-@$`
M"@```,8V`0`,````T38!``D```#>-@$`!@```.@V`0`)````[S8!``@```#Y
M-@$`"0````(W`0`*````##<!`!$````7-P$`!@```"DW`0`.````,#<!``X`
M```_-P$`#0```$XW`0`+````7#<!`!T```!H-P$`"P```(8W`0`"````DC<!
M`!P```"5-P$`!P```+(W`0`&````NC<!`&0```#!-P$`"0```"8X`0`'````
M,#@!`"8````X.`$`*0```%\X`0`;````B3@!`#@```"E.`$`*P```-XX`0`:
M````"CD!`",````E.0$`*@```$DY`0`M````=#D!`#L```"B.0$`*````-XY
M`0`T````!SH!`!D````\.@$`%0```%8Z`0`%````;#H!``<```!R.@$`"```
M`'HZ`0`'````@SH!``4```"+.@$`!P```)$Z`0`.````F3H!``D```"H.@$`
M!@```+(Z`0`(````N3H!``L```#".@$`!P```,XZ`0`(````UCH!``<```#?
M.@$`%@```.<Z`0`)````_CH!``8````(.P$`"P````\[`0`0````&SL!``8`
M```L.P$`'````#,[`0`4````4#L!``<```!E.P$`$0```&T[`0`(````?SL!
M``X```"(.P$``P```)<[`0`(````FSL!`!0```"D.P$`!0```+D[`0`0````
MOSL!`!````#0.P$`!@```.$[`0`9````Z#L!``H````"/`$`'`````T\`0`'
M````*CP!``4````R/`$`$````#@\`0`4````23P!``L```!>/`$`#0```&H\
M`0`H````>#P!`!@```"A/`$`%P```+H\`0`$````TCP!``D```#7/`$`"@``
M`.$\`0`'````[#P!``(```#T/`$`#@```/<\`0`(````!CT!`",````//0$`
M.````#,]`0`F````;#T!`#$```"3/0$`)P```,4]`0!$````[3T!`"4````R
M/@$`+P```%@^`0`O````B#X!`"\```"X/@$`*````.@^`0!D````$3\!`!0`
M``!V/P$`50```(L_`0`X````X3\!`"D````:0`$`2@```$1``0!;````CT`!
M`"@```#K0`$`.````!1!`0`L````34$!`"@```!Z00$`+````*-!`0`F````
MT$$!`!L```#W00$`/@```!-"`0`C````4D(!`#````!V0@$`%P```*="`0!(
M````OT(!`(4````(0P$`,````(Y#`0`E````OT,!`$$```#E0P$`6P```"=$
M`0!)````@T0!`#$```#-1`$`'0```/]$`0`8````'44!`"L````V10$`(0``
M`&)%`0`?````A$4!`"L```"D10$`(0```-!%`0`G````\D4!`#H````:1@$`
M'0```%5&`0`1````<T8!`#,```"%1@$`)0```+E&`0`G````WT8!`"`````'
M1P$`)@```"A'`0`?````3T<!`#````!O1P$`S````*!'`0!I````;4@!`#$`
M``#72`$`00````E)`0`S````2TD!`"4```!_20$`/0```*5)`0!E````XTD!
M`$T```!)2@$`7@```)=*`0`G````]DH!`#$````>2P$`/@```%!+`0`L````
MCTL!`"8```"\2P$`+P```.-+`0`N````$TP!`"D```!"3`$`,````&Q,`0!4
M````G4P!`%H```#R3`$`,0```$U-`0!(````?TT!`$H```#(30$`,0```!-.
M`0`J````14X!`"(```!P3@$`+P```)-.`0`I````PTX!`#(```#M3@$`+P``
M`"!/`0`L````4$\!`"T```!]3P$`%P```*M/`0`E````PT\!`#(```#I3P$`
M*0```!Q0`0`^````1E`!`"(```"%4`$`4@```*A0`0`B````^U`!`"4````>
M40$`"P```$11`0"Q````4%$!`$4````"4@$`(0```$A2`0`V````:E(!`#``
M``"A4@$`)0```-)2`0`<````^%(!`$@````54P$`,0```%Y3`0`'````D%,!
M``<```"84P$`!````*!3`0`-````I5,!``L```"S4P$`#@```+]3`0`+````
MSE,!``4```#:4P$`$````.!3`0`"````\5,!`%D```#T4P$`!0```$Y4`0`2
M````5%0!``0```!G5`$`!P```&Q4`0`(````=%0!``4```!]5`$``P```(-4
M`0`0````AU0!`!,```"85`$`#0```*Q4`0`"````NE0!``<```"]5`$`!@``
M`,54`0`4````S%0!``P```#A5`$`&````.Y4`0`&````!U4!`!(````.50$`
M#````"%5`0`#````+E4!``0````R50$`!@```#=5`0`'````/E4!`!\```!&
M50$`-0```&95`0`N````G%4!`"\```#+50$`%P```/M5`0`B````$U8!`"4`
M```V5@$`(````%Q6`0`;````?58!`!@```"95@$`)````+)6`0`?````UU8!
M`!H```#W5@$`(0```!)7`0`@````-%<!`#````!55P$`&@```(97`0`R````
MH5<!`!H```#45P$`+P```.]7`0`K````'U@!`!\```!+6`$`(P```&M8`0`?
M````CU@!`!H```"O6`$`(0```,I8`0`E````[%@!`"8````260$`)0```#E9
M`0`D````7UD!`!@```"$60$`'0```)U9`0`D````NUD!`!@```#@60$`(@``
M`/E9`0`L````'%H!`"\```!)6@$`%0```'E:`0`E````CUH!`#P```"U6@$`
M'P```/):`0`C````$EL!`!\````V6P$`(````%9;`0`:````=UL!`!@```"2
M6P$`)@```*M;`0`>````TEL!`"D```#Q6P$`'@```!M<`0`Q````.EP!``D`
M``!L7`$`#````'9<`0`7````@UP!`"\```";7`$`)````,M<`0`'````\%P!
M``\```#X7`$`!`````A=`0`4````#5T!``X````B70$`#0```#%=`0`D````
M/UT!``4```!D70$`!P```&I=`0`B````<ET!`"4```"570$`&@```+M=`0`=
M````UET!`!H```#T70$`!P````]>`0#'````%UX!``L```#?7@$`'````.M>
M`0`5````"%\!``8````>7P$`"0```"5?`0`+````+U\!``T````[7P$`%P``
M`$E?`0`&````85\!`#,```!H7P$`$P```)Q?`0`3````L%\!``,```#$7P$`
M!P```,A?`0`/````T%\!``<```#@7P$`,@```.A?`0`$````&V`!`"$````@
M8`$`$P```$)@`0`,````5F`!`!$```!C8`$`,@```'5@`0`6````J&`!``@`
M``"_8`$`'0```,A@`0`)````YF`!``H```#P8`$`%````/M@`0`*````$&$!
M`!T````;80$`"````#EA`0`?````0F$!``@```!B80$`&@```&MA`0`&````
MAF$!`!4```"-80$`!P```*-A`0`(````JV$!``D```"T80$`/P```+YA`0`2
M````_F$!``<````18@$`#P```!EB`0`.````*6(!`!`````X8@$`"0```$EB
M`0`)````4V(!``@```!=8@$`$P```&9B`0`)````>F(!``<```"$8@$`#```
M`(QB`0`9````F6(!``H```"S8@$`&P```+YB`0`7````VF(!`!0```#R8@$`
M"@````=C`0`,````$F,!`!<````?8P$`!````#=C`0`J````/&,!``P```!G
M8P$`$0```'1C`0`'````AF,!``(```".8P$`$````)%C`0`8````HF,!``L`
M``"[8P$``P```,=C`0`(````RV,!``L```#48P$`!@```.!C`0`'````YV,!
M``T```#O8P$`"P```/UC`0`4````"60!`!4````>9`$`#@```#1D`0`O````
M0V0!`"````!S9`$`'````)1D`0`5````L60!``P```#'9`$`,0```-1D`0`%
M````!F4!`!(````,90$`/P```!]E`0`2````7V4!``H```!R90$`!@```'UE
M`0`$````A&4!``0```")90$`"@```(YE`0`3````F64!``4```"M90$`!@``
M`+-E`0`&````NF4!``@```#!90$`!````,IE`0`,````SV4!``D```#<90$`
M#````.9E`0`*````\V4!`!````#^90$`$P````]F`0`3````(V8!`#D````W
M9@$`+@```'%F`0`9````H&8!`!\```"Z9@$`'0```-IF`0`1````^&8!``(`
M```*9P$`!`````UG`0`*````$F<!``8````=9P$`!0```"1G`0`#````*F<!
M``P````N9P$`10```#MG`0`R````@6<!`#P```"T9P$`&@```/%G`0`T````
M#&@!`"@```!!:`$`4P```&IH`0`P````OF@!`"\```#O:`$`,@```!]I`0`9
M````4FD!`'(```!L:0$`(````-]I`0`U`````&H!`"$````V:@$`10```%AJ
M`0`P````GFH!`"8```#/:@$`'@```/9J`0`H````%6L!`"L````^:P$`*0``
M`&IK`0`I````E&L!`"8```"^:P$`)0```.5K`0`H````"VP!`"@````T;`$`
M(@```%UL`0`K````@&P!`"X```"L;`$`,````-ML`0`2````#&T!`!,````?
M;0$`$````#-M`0!Y````1&T!``D```"^;0$`H0```,AM`0!S````:FX!`'P`
M``#>;@$`*P```%MO`0!4````AV\!`!<```#<;P$`+````/1O`0`G````(7`!
M`!8```!)<`$`#P```&!P`0`7````<'`!`!\```"(<`$`0````*AP`0`?````
MZ7`!`!P````)<0$`40```"9Q`0`:````>'$!`!0```"3<0$`"@```*AQ`0`%
M````LW$!``8```"Y<0$`"````,!Q`0`2````R7$!`!````#<<0$`$P```.UQ
M`0`=`````7(!``\````?<@$`"@```"]R`0`/````.G(!``<```!*<@$`!```
M`%)R`0`)````5W(!``D```!A<@$`!P```&MR`0`+````<W(!``<```!_<@$`
M!0```(=R`0`4````C7(!``X```"B<@$`!@```+%R`0`'````N'(!``@```#`
M<@$`#P```,ER`0`1````V7(!``P```#K<@$`"````/AR`0`,`````7,!``\`
M```.<P$`%@```!YS`0`'````-7,!``8````]<P$`%````$1S`0`&````67,!
M``P```!@<P$`"````&US`0`9````=G,!`!$```"0<P$`"@```*)S`0`8````
MK7,!`!,```#&<P$`"P```-IS`0`,````YG,!``P```#S<P$`#`````!T`0`<
M````#70!`!$````J=`$`#P```#QT`0`$````3'0!`!D```!1=`$`!P```&MT
M`0`"````<W0!``(```!V=`$`$0```'ET`0`)````BW0!``8```"5=`$`$@``
M`)QT`0`7````KW0!``8```#'=`$``@```,YT`0`$````T70!``T```#6=`$`
M!````.1T`0`/````Z70!`!,```#Y=`$`!P````UU`0`'````%74!`!$````=
M=0$`!@```"]U`0`8````-G4!``8```!/=0$`$P```%9U`0`0````:G4!`!(`
M``![=0$``@```(YU`0`&````D74!``P```"8=0$`"0```*5U`0`1````KW4!
M`!$```#!=0$`&P```--U`0`B````[W4!``<````2=@$`!P```!IV`0`+````
M(G8!``4````N=@$``@```#1V`0`+````-W8!`&$!``!#=@$`"@```*5W`0`,
M````L'<!``H```"]=P$`!P```,AW`0`'````T'<!``<```#8=P$`%````.!W
M`0`1````]7<!``(````'>`$`'`````IX`0`1````)W@!`!@````Y>`$`*P``
M`%)X`0`:````?G@!`!T```"9>`$`$P```+=X`0`C````RW@!`!$```#O>`$`
M(P````%Y`0`;````)7D!`!L```!!>0$`*0```%UY`0`-````AWD!`!L```"5
M>0$`$@```+%Y`0`+````Q'D!``<```#0>0$`!0```-AY`0`2````WGD!``<`
M``#Q>0$`!P```/EY`0`+`````7H!``H````->@$`"0```!AZ`0`+````(GH!
M`!(````N>@$`/````$%Z`0`)````?GH!``4```"(>@$`"@```(YZ`0`/````
MF7H!``L```"I>@$`"@```+5Z`0`*````P'H!``H```#+>@$`!@```-9Z`0!9
M````W7H!``<````W>P$`#````#][`0`2````3'L!``H```!?>P$`"0```&I[
M`0`)````='L!``D```!^>P$`!@```(A[`0`6````CWL!`!T```"F>P$`%```
M`,1[`0`E````V7L!`"T```#_>P$`0````"U\`0!$````;GP!`$0```"S?`$`
M2@```/A\`0`G````0WT!``@```!K?0$`"````'1]`0`(````?7T!``@```"&
M?0$`"````(]]`0`)````F'T!``@```"B?0$`#@```*M]`0`'````NGT!``P`
M``#"?0$`!@```,]]`0`&````UGT!`!L```#=?0$`&P```/E]`0`,````%7X!
M``@````B?@$`"@```"M^`0`+````-GX!``0```!"?@$`!````$=^`0`*````
M3'X!``H```!7?@$`"0```&)^`0`(````;'X!``@```!U?@$`$0```'Y^`0`0
M````D'X!``\```"A?@$`"@```+%^`0`6````O'X!``@```#3?@$`"````-Q^
M`0`-````Y7X!``8```#S?@$`&0```/I^`0`&````%'\!``\````;?P$`$```
M`"M_`0`*````/'\!`#,```!'?P$`*P```'M_`0`3````IW\!`!L```"[?P$`
M!````-=_`0`&````W'\!``0```#C?P$`!@```.A_`0`+````[W\!`!$```#[
M?P$`"P````V``0`/````&8`!`"$````I@`$`!````$N``0`$````4(`!``@`
M``!5@`$`%````%Z``0`4````<X`!`!0```"(@`$`"````)V``0`$````IH`!
M``D```"K@`$`!````+6``0`2````NH`!``@```#-@`$`"````-:``0`&````
MWX`!`!8```#F@`$`%P```/V``0`&````%8$!``8````<@0$`#@```".!`0`.
M````,H$!`!````!!@0$`$````%*!`0`(````8X$!``@```!L@0$`'0```'6!
M`0`3````DX$!`!4```"G@0$`$````+V!`0`/````SH$!`!,```#>@0$`#```
M`/*!`0`$````_X$!`!4````$@@$`*@```!J"`0`(````18(!``P```!.@@$`
M#@```%N"`0`2````:H(!``0```!]@@$`"````(*"`0`$````BX(!`!<```"0
M@@$`"@```*B"`0`*````LX(!`!$```"^@@$`'````-""`0`:````[8(!`"0`
M```(@P$`$@```"V#`0`2````0(,!`!8```!3@P$`!````&J#`0`0````;X,!
M``0```"`@P$`$````(6#`0`(````EH,!``\```"?@P$`&P```*^#`0`(````
MRX,!`!D```#4@P$`&0```.Z#`0`9````"(0!`!D````BA`$`!````#R$`0`$
M````080!`!0```!&A`$`$````%N$`0`J````;(0!`",```"7A`$`*0```+N$
M`0!K````Y80!`"@```!1A0$`*````'J%`0`Q````HX4!`#$```#5A0$`*```
M``>&`0`I````,(8!`!P```!:A@$`'````'>&`0`Q````E(8!`"@```#&A@$`
M+@```.^&`0`4````'H<!``D````SAP$`#````#V'`0`0````2H<!``T```!;
MAP$`#0```&F'`0`+````=X<!`!4```"#AP$`!````)F'`0`(````GH<!`!(`
M``"GAP$`&````+J'`0`0````TX<!``X```#DAP$`&````/.'`0`3````#(@!
M`!$````@B`$`%````#*(`0`$````1X@!``@```!,B`$`!P```%6(`0`0````
M78@!``\```!NB`$`#````'Z(`0`,````BX@!`!````"8B`$`#0```*F(`0`1
M````MX@!``0```#)B`$`(0```,Z(`0`(````\(@!``@```#YB`$`!`````*)
M`0`2````!XD!``0````:B0$`!````!^)`0`(````)(D!``0````MB0$`+0``
M`#*)`0`$````8(D!`!$```!EB0$`!````'>)`0`-````?(D!``T```"*B0$`
M'@```)B)`0`$````MXD!`!@```"\B0$`$P```-6)`0`(````Z8D!`!D```#R
MB0$`$`````R*`0`(````'8H!``@````FB@$``P```"^*`0`*````,XH!`!$`
M```^B@$`#P```%"*`0`3````8(H!``8```!TB@$`!@```'N*`0`1````@HH!
M`!$```"4B@$`)@```*:*`0`1````S8H!`!$```#?B@$`&@```/&*`0`2````
M#(L!``\````?BP$`!````"^+`0`,````-(L!`!(```!!BP$`#P```%2+`0`C
M````9(L!`!(```"(BP$`&@```)N+`0`Q````MHL!`!D```#HBP$`$P````*,
M`0`(````%HP!``H````?C`$`&0```"J,`0`(````1(P!``H```!-C`$`"P``
M`%B,`0`*````9(P!``L```!OC`$`"````'N,`0`6````A(P!``0```";C`$`
M)0```*",`0`1````QHP!``@```#8C`$`"@```.&,`0`(````[(P!``L```#U
MC`$`!`````&-`0`,````!HT!`!L````3C0$`+0```"^-`0`$````78T!``T`
M``!BC0$`#@```'"-`0`,````?XT!``P```",C0$`$0```)F-`0`/````JXT!
M``T```"[C0$`#````,F-`0`(````UHT!`!(```#?C0$`#@```/*-`0`/````
M`8X!``T````1C@$`$@```!^.`0`<````,HX!`!,```!/C@$`'@```&..`0`9
M````@HX!`!4```"<C@$``@```+*.`0`4````M8X!``@```#*C@$`#@```-..
M`0`*````XHX!`!````#MC@$`!@```/Z.`0`.````!8\!`!0````4CP$`"```
M`"F/`0`$````,H\!``8````WCP$``@```#Z/`0`7````08\!``H```!9CP$`
M"````&2/`0`3````;8\!``0```"!CP$`!@```(:/`0`.````C8\!``,```"<
MCP$`"````*"/`0`(````J8\!`!$```"RCP$`!````,2/`0`2````R8\!`"0`
M``#<CP$`!`````&0`0`(````!I`!``0````/D`$`!````!20`0`0````&9`!
M``0````JD`$`"````"^0`0`$````.)`!``0````]D`$`!````$*0`0`$````
M1Y`!`#0```!,D`$`#0```(&0`0`'````CY`!``@```"7D`$`#````*"0`0`R
M````K9`!``D```#@D`$`"@```.J0`0`,````]9`!``@````"D0$`&P````N1
M`0`I````)Y$!`!H```!1D0$`"@```&R1`0`&````=Y$!`!,```!^D0$`'P``
M`)*1`0`4````LI$!``T```#'D0$`!````-61`0`7````VI$!``0```#RD0$`
M#````/>1`0`$````!)(!`!<````)D@$`&````"&2`0`5````.I(!`!D```!0
MD@$`%P```&J2`0`7````@I(!`!(```":D@$`%````*V2`0`4````PI(!`!``
M``#7D@$`%@```.B2`0`B````_Y(!`!0````BDP$`$P```#>3`0`5````2Y,!
M`!(```!ADP$`%````'23`0`6````B9,!`!T```"@DP$`%0```+Z3`0`7````
MU),!`!D```#LDP$`$@````:4`0`2````&90!`!T````LE`$`%0```$J4`0`,
M````8)0!`!<```!ME`$`$@```(64`0`6````F)0!``P```"OE`$`2P```+R4
M`0`G````")4!`!(````PE0$`%````$.5`0`4````6)4!`!@```!ME0$`#0``
M`(:5`0`2````E)4!`!,```"GE0$`$0```+N5`0`5````S94!`!D```#CE0$`
M%````/V5`0!,````$I8!`!8```!?E@$`#@```':6`0`2````A98!`!0```"8
ME@$`&0```*V6`0`J````QY8!`"T```#RE@$`!@```""7`0`$````)Y<!``0`
M```LEP$`!````#&7`0`*````-I<!``P```!!EP$`%P```$Z7`0`,````9I<!
M``P```!SEP$`!````("7`0`,````A9<!``H```"2EP$`$@```)V7`0`+````
ML)<!``@```"\EP$`"````,67`0`(````SI<!``P```#7EP$`"````.27`0`,
M````[9<!``H```#ZEP$`'P````68`0`$````)9@!``0````JF`$`$0```"^8
M`0`1````09@!`!<```!3F`$`&@```&N8`0`;````AI@!``(```"BF`$`50``
M`*68`0`$````^Y@!``P`````F0$`"@````V9`0`$````&)D!``@````=F0$`
M"````":9`0`$````+YD!``H````TF0$`!@```#^9`0`*````1ID!``@```!1
MF0$`!````%J9`0`(````7YD!``X```!HF0$`%0```'>9`0`-````C9D!``0`
M``";F0$`!````*"9`0`+````I9D!``H```"QF0$`"````+R9`0`(````Q9D!
M``@```#.F0$`"````->9`0`.````X)D!``X```#OF0$`"@```/Z9`0`(````
M"9H!`!(````2F@$`$0```"6:`0`.````-YH!`"````!&F@$`!@```&>:`0`8
M````;IH!``X```"'F@$`#````)::`0`5````HYH!`!,```"YF@$`"````,V:
M`0`(````UIH!``X```#?F@$`!````.Z:`0`$````\YH!``@```#XF@$`!```
M``&;`0`=````!IL!`!<````DFP$`!````#R;`0`(````09L!`!8```!*FP$`
M"@```&&;`0`(````;)L!``@```!UFP$`!````'Z;`0`$````@YL!`!$```"(
MFP$`"````)J;`0`.````HYL!``X```"RFP$`"````,&;`0`(````RIL!`!$`
M``#3FP$`!@```.6;`0`<````[)L!`!@````)G`$`*0```"*<`0`3````3)P!
M`",```!@G`$`$P```(2<`0`$````F)P!``<```"=G`$`'````*6<`0`*````
MPIP!``H```#-G`$`!````-B<`0`(````W9P!``0```#FG`$`$@```.N<`0`$
M````_IP!``D````#G0$`"@````V=`0`(````&)T!``@````AG0$`"````"J=
M`0`(````,YT!``P````\G0$`"P```$F=`0`(````59T!``X```!>G0$`#```
M`&V=`0`$````>IT!``P```!_G0$`%@```(R=`0`'````HYT!``@```"KG0$`
M#````+2=`0`5````P9T!``P```#7G0$`$P```.2=`0`(````^)T!``D````!
MG@$`"0````N>`0`,````%9X!`"H````BG@$`$P```$V>`0`(````89X!``H`
M``!JG@$`/````'6>`0`2````LIX!`"8```#%G@$`$````.R>`0`>````_9X!
M`!0````<GP$`!````#&?`0`C````-I\!`"T```!:GP$`%````(B?`0`;````
MG9\!`"4```"YGP$`&P```-^?`0`;````^Y\!`!8````7H`$`(P```"Z@`0`M
M````4J`!`!,```"`H`$`%P```)2@`0`5````K*`!`!(```#"H`$`$P```-6@
M`0`$````Z:`!``T```#NH`$`"@```/R@`0`)````!Z$!``H````1H0$`"0``
M`!RA`0`(````)J$!``H````OH0$`"0```#JA`0`'````1*$!``0```!,H0$`
M!````%&A`0`*````5J$!``@```!AH0$`!@```&JA`0`&````<:$!``0```!X
MH0$`"@```'VA`0`5````B*$!`!,```">H0$`"````+*A`0`-````NZ$!`!``
M``#)H0$`%````-JA`0`1````[Z$!``P````!H@$`#`````ZB`0`Y````&Z(!
M`!<```!5H@$`%@```&VB`0`0````A*(!`!````"5H@$`&P```*:B`0`7````
MPJ(!`!````#:H@$`#````.NB`0`.````^*(!`!$````'HP$`!````!FC`0`N
M````'J,!``T```!-HP$`"0```%NC`0`$````9:,!``0```!JHP$`!````&^C
M`0`$````=*,!``8```!YHP$`!@```("C`0`(````AZ,!``@```"0HP$`"P``
M`)FC`0`3````I:,!`!$```"YHP$`"````,NC`0`(````U*,!``@```#=HP$`
M"````.:C`0`5````[Z,!``0````%I`$`!@````JD`0`$````$:0!``0````6
MI`$`#@```!ND`0`&````*J0!``0````QI`$`!````#:D`0`(````.Z0!``@`
M``!$I`$`!````$VD`0`"````4J0!``X```!5I`$`"````&2D`0`$````;:0!
M`!L```!RI`$`#@```(ZD`0!.````G:0!``H```#LI`$`!````/>D`0`$````
M_*0!``@````!I0$`!`````JE`0`&````#Z4!``0````6I0$`"````!NE`0`&
M````)*4!``0````KI0$`#0```#"E`0`4````/J4!``T```!3I0$`&@```&&E
M`0`A````?*4!`!L```">I0$``@```+JE`0`"````O:4!``@```#`I0$`!```
M`,FE`0`$````SJ4!``P```#3I0$`!0```."E`0`/````YJ4!`!(```#VI0$`
M$`````FF`0`6````&J8!``X````QI@$`#````$"F`0`4````3:8!``0```!B
MI@$`"@```&>F`0`$````<J8!``8```!WI@$`"P```'ZF`0`+````BJ8!``0`
M``"6I@$`#0```)NF`0`3````J:8!`!0```"]I@$`$@```-*F`0`$````Y:8!
M``@```#JI@$`$````/.F`0`I````!*<!`!L````NIP$`&P```$JG`0`$````
M9J<!`!4```!KIP$`"P```(&G`0`4````C:<!``@```"BIP$`"````*NG`0`(
M````M*<!``\```"]IP$`(````,VG`0`/````[J<!``P```#^IP$`$0````NH
M`0`,````':@!``D````JJ`$``@```#2H`0`$````-Z@!``0````\J`$`(0``
M`$&H`0`&````8Z@!`!<```!JJ`$`!````(*H`0`$````AZ@!``X```",J`$`
M!````)NH`0`$````H*@!`!$```"EJ`$``@```+>H`0`$````NJ@!`!$```"_
MJ`$``@```-&H`0`(````U*@!``P```#=J`$`#````.JH`0`&````]Z@!``@`
M``#^J`$`#`````>I`0`,````%*D!``@````AJ0$`$P```"JI`0`0````/JD!
M``4```!/J0$`,````%6I`0`>````AJD!`"P```"EJ0$`(0```-*I`0`N````
M]*D!`"8````CJ@$`(0```$JJ`0`Q````;*H!`"$```">J@$`'0```,"J`0`<
M````WJH!``8```#[J@$`"`````*K`0`%````"ZL!`!8````1JP$`%0```"BK
M`0`-````/JL!`!$```!,JP$`!````%ZK`0`&````8ZL!``@```!JJP$`$```
M`'.K`0`5````A*L!`!4```":JP$`'0```+"K`0`$````SJL!``\```#3JP$`
M!P```..K`0`0````ZZL!`"````#\JP$`#@```!VL`0`.````+*P!``8````[
MK`$`"````$*L`0`*````2ZP!``@```!6K`$`#P```%^L`0`P````;ZP!`&D`
M``"@K`$`/@````JM`0`)````2:T!``@```!3K0$`"0```%RM`0`,````9JT!
M``T```!SK0$`"````(&M`0`$````BJT!`!,```"/K0$`#0```*.M`0`0````
ML:T!``P```#"K0$`"0```,^M`0`.````V:T!`!,```#HK0$`&@```/RM`0!&
M````%ZX!``@```!>K@$`#````&>N`0`*````=*X!`!````!_K@$`!````)"N
M`0`$````E:X!``T```":K@$`$````*BN`0`(````N:X!``@```#"K@$`#```
M`,NN`0`0````V*X!`!P```#IK@$`'`````:O`0`8````(Z\!`!@````\KP$`
M&@```%6O`0`:````<*\!``X```"+KP$`&P```)JO`0`0````MJ\!`!````#'
MKP$`#@```-BO`0`.````YZ\!``@```#VKP$`#@```/^O`0`.````#K`!``P`
M```=L`$`#````"JP`0`/````-[`!``T```!'L`$`$0```%6P`0`A````9[`!
M``D```")L`$`!````).P`0`&````F+`!``H```"?L`$`&P```*JP`0`0````
MQK`!``T```#7L`$`#P```.6P`0`/````];`!``\````%L0$`#@```!6Q`0`/
M````)+$!``H````TL0$`#@```#^Q`0`.````3K$!``T```!=L0$`"P```&NQ
M`0`0````=[$!``H```"(L0$`#P```).Q`0`6````H[$!`!,```"ZL0$`#0``
M`,ZQ`0`1````W+$!``T```#NL0$`#P```/RQ`0`1````#+(!``\````>L@$`
M#P```"ZR`0`1````/K(!``0```!0L@$`"````%6R`0`@````7K(!``T```!_
ML@$`$````(VR`0`2````GK(!``@```"QL@$`#P```+JR`0`&````RK(!``0`
M``#1L@$`#@```-:R`0`0````Y;(!``0```#VL@$`#````/NR`0`2````"+,!
M``8````;LP$`#0```"*S`0`$````,+,!``0````ULP$`!````#JS`0`$````
M/[,!``@```!$LP$`"````$VS`0`(````5K,!``H```!?LP$`"@```&JS`0`,
M````=;,!`!(```""LP$`"````)6S`0`(````GK,!``@```"GLP$`"````+"S
M`0`(````N;,!``@```#"LP$`*````,NS`0`$````]+,!`!,```#YLP$`+0``
M``VT`0`9````.[0!``T```!5M`$`#P```&.T`0`*````<[0!`#H```!^M`$`
M"@```+FT`0`$````Q+0!`"<```#)M`$`!@```/&T`0`,````^+0!``(````%
MM0$`$@````BU`0`&````&[4!``D````BM0$`#@```"RU`0`4````.[4!`!8`
M``!0M0$`$0```&>U`0`$````>;4!``@```!^M0$`$````(>U`0`$````F+4!
M``@```"=M0$`!@```*:U`0`0````K;4!`!(```"^M0$`'P```-&U`0`:````
M\;4!``0````,M@$`!````!&V`0`(````%K8!``@````?M@$`!@```"BV`0`(
M````+[8!``0````XM@$`!@```#VV`0`&````1+8!``0```!+M@$`"0```%"V
M`0`@````6K8!``0```![M@$`!````("V`0`?````A;8!``H```"EM@$`#```
M`+"V`0`(````O;8!``\```#&M@$`#0```-:V`0`1````Y+8!``\```#VM@$`
M#P````:W`0`-````%K<!`!$````DMP$`$````#:W`0`2````1[<!`!8```!:
MMP$`!````'&W`0`2````=K<!``D```")MP$`"@```).W`0`*````GK<!``0`
M``"IMP$`!````*ZW`0`$````L[<!``0```"XMP$`"````+VW`0`M````QK<!
M``D```#TMP$`!````/ZW`0`$`````[@!``(````(N`$`#`````NX`0`,````
M&+@!``P````EN`$`$P```#*X`0`"````1K@!``@```!)N`$`&P```%*X`0`#
M````;K@!``P```!RN`$`.0```'^X`0`7````N;@!``0```#1N`$`!````-:X
M`0`(````V[@!``T```#DN`$`#P```/*X`0`3`````KD!`!,````6N0$`"P``
M`"JY`0`.````-KD!`"````!%N0$`"@```&:Y`0`-````<;D!``0```!_N0$`
M!````(2Y`0`2````B;D!`"0```"<N0$`'0```,&Y`0`7````W[D!``0```#W
MN0$`"@```/RY`0`7````![H!`!0````?N@$`#P```#2Z`0`7````1+H!`!@`
M``!<N@$`%P```'6Z`0`.````C;H!``P```"<N@$`#````*FZ`0`(````MKH!
M``0```"_N@$`$@```,2Z`0`$````U[H!``0```#<N@$`!@```.&Z`0`)````
MZ+H!``H```#RN@$`!````/VZ`0`N`````KL!``L````QNP$`"````#V[`0`3
M````1KL!`"L```!:NP$`$0```(:[`0`$````F+L!`!(```"=NP$`&@```+"[
M`0`$````R[L!``\```#0NP$`+@```."[`0`$````#[P!``D````4O`$`&```
M`!Z\`0`7````-[P!`!0```!/O`$`!````&2\`0`$````:;P!`!\```!NO`$`
M'@```(Z\`0`U````K;P!`!````#CO`$`'````/2\`0`0````$;T!``8````B
MO0$`"````"F]`0`(````,KT!``0````[O0$`"````$"]`0`(````2;T!`!$`
M``!2O0$`!````&2]`0`?````:;T!``\```")O0$`#P```)F]`0`&````J;T!
M``0```"PO0$`"````+6]`0`$````OKT!`",```##O0$`$P```.>]`0`&````
M^[T!``@````"O@$`"`````N^`0`(````%+X!``0````=O@$`!````"*^`0`$
M````)[X!``0````LO@$`!````#&^`0`$````-KX!``0````[O@$`!````$"^
M`0`$````1;X!`!4```!*O@$`#P```&"^`0`0````<+X!`$\```"!O@$`!```
M`-&^`0`(````UKX!``P```#?O@$`"@```.R^`0`*````][X!``@````"OP$`
M$`````N_`0`.````'+\!``L````KOP$`!````#>_`0`(````/+\!`!(```!%
MOP$`#````%B_`0`.````9;\!`!$```!TOP$`$@```(:_`0`C````F;\!`!4`
M``"]OP$`%0```-._`0`5````Z;\!`!$```#_OP$`$0```!'``0`7````(\`!
M`!,````[P`$`$0```$_``0`(````8<`!``0```!JP`$`'````&_``0`(````
MC,`!``H```"5P`$`"0```*#``0`$````JL`!`!4```"OP`$`%````,7``0`&
M````VL`!`!$```#AP`$`#0```//``0`/`````<$!``0````1P0$`"````!;!
M`0`&````'\$!``H````FP0$`!@```#'!`0`4````.,$!``0```!-P0$`#```
M`%+!`0`2````7\$!``0```!RP0$`#0```'?!`0`"````A<$!`!@```"(P0$`
M#0```*'!`0`9````K\$!`!H```#)P0$`#0```.3!`0`:````\L$!`"$````-
MP@$`"0```"_"`0`;````.<(!`!<```!5P@$`'````&W"`0`;````BL(!`"``
M``"FP@$`#````,?"`0`+````U,(!``L```#@P@$`"@```.S"`0`+````]\(!
M`!`````#PP$`$0```!3#`0`+````)L,!``L````RPP$`"P```#[#`0`;````
M2L,!`!L```!FPP$`'P```(+#`0`<````HL,!`!T```"_PP$`&@```-W#`0!(
M````^,,!`!,```!!Q`$`#@```%7$`0`&````9,0!`!4```!KQ`$`!@```('$
M`0`(````B,0!`!,```"1Q`$`%P```*7$`0`2````O<0!`!<```#0Q`$`!@``
M`.C$`0`K````[\0!`"T````;Q0$``@```$G%`0`1````3,4!`!8```!>Q0$`
M&0```'7%`0`&````C\4!`!@```"6Q0$`#0```*_%`0`&````O<4!``8```#$
MQ0$`#````,O%`0`-````V,4!``8```#FQ0$`"````.W%`0`$````]L4!`!(`
M``#[Q0$`!@````[&`0`$````%<8!``8````:Q@$`"````"'&`0`(````*L8!
M``0````SQ@$`&0```#C&`0`"````4L8!``0```!5Q@$`"@```%K&`0`*````
M9<8!``8```!PQ@$`!````'?&`0`&````?,8!`!<```"#Q@$`!@```)O&`0`,
M````HL8!``L```"OQ@$`(P```+O&`0`3````W\8!`!````#SQ@$`)@````3'
M`0`.````*\<!`"T````ZQP$`$@```&C'`0`(````>\<!``0```"$QP$`!@``
M`(G'`0`(````D,<!``0```"9QP$`"````)['`0`$````I\<!`!````"LQP$`
M%````+W'`0`$````TL<!``@```#7QP$`"````.#'`0`*````Z<<!``T```#T
MQP$`$`````+(`0`,````$\@!``P````@R`$`#````"W(`0`6````.L@!``H`
M``!1R`$`"````%S(`0`(````9<@!``@```!NR`$`"````'?(`0`(````@,@!
M``8```")R`$`"````)#(`0`4````F<@!``H```"NR`$`!````+G(`0`3````
MOL@!``P```#2R`$`,````-_(`0`/````$,D!`"$````@R0$`$0```$+)`0`$
M````5,D!``0```!9R0$`#0```%[)`0`*````;,D!`!T```!WR0$`"````)7)
M`0`%````GLD!``8```"DR0$`#0```*O)`0`$````N<D!``0```"^R0$`!```
M`,/)`0`*````R,D!``0```#3R0$`!@```-C)`0`,````W\D!`!,```#LR0$`
M!`````#*`0`3````!<H!``@````9R@$`"````"+*`0`$````*\H!``@````P
MR@$`!````#G*`0`+````/LH!``0```!*R@$`%````$_*`0`$````9,H!``0`
M``!IR@$`"P```&[*`0`(````>LH!``0```"#R@$`$````(C*`0`3````F<H!
M`!L```"MR@$`%0```,G*`0`5````W\H!`!@```#UR@$`)@````[+`0`5````
M-<L!`!,```!+RP$`$0```%_+`0`:````<<L!`"X```",RP$`$P```+O+`0`-
M````S\L!``0```#=RP$`!````.++`0`1````Y\L!``@```#YRP$`"`````+,
M`0`K````"\P!`!8````WS`$`#@```$[,`0`I````7<P!`"\```"'S`$`!```
M`+?,`0`,````O,P!``8```#)S`$`!````-#,`0`2````U<P!``8```#HS`$`
M"@```._,`0`(````^LP!``H````#S0$`"`````[-`0`$````%\T!``@````<
MS0$`!````"7-`0`(````*LT!``@````SS0$`#````#S-`0`,````2<T!`!H`
M``!6S0$`%@```''-`0`,````B,T!``0```"5S0$`$0```)K-`0`(````K,T!
M``@```"US0$`%@```+[-`0`&````U<T!``(```#<S0$`!@```-_-`0`&````
MYLT!``0```#MS0$`!@```/+-`0`&````^<T!``@`````S@$`!`````G.`0`$
M````#LX!`!$````3S@$`"````"7.`0`3````+LX!`"4```!"S@$`$0```&C.
M`0`R````>LX!``L```"MS@$`"````+G.`0`(````PLX!`!4```#+S@$`%0``
M`.'.`0`*````]\X!``H````"SP$`!`````W/`0`$````$L\!``H````7SP$`
M*````"+/`0`$````2\\!``@```!0SP$`"@```%G/`0`(````9,\!``@```!M
MSP$`$````';/`0`&````A\\!`"<```".SP$`!````+;/`0`4````N\\!``H`
M``#0SP$`#@```-O/`0!9````ZL\!`!<```!$T`$`$0```%S0`0`1````;M`!
M`!H```"`T`$`%P```)O0`0`5````L]`!``@```#)T`$`!````-+0`0`(````
MU]`!``T```#@T`$`#````.[0`0`0````^]`!``0````,T0$`"````!'1`0`.
M````&M$!`!(````IT0$`"````#S1`0`.````1=$!``0```!4T0$`!````%G1
M`0`(````7M$!``8```!GT0$`"P```&[1`0`$````>M$!`!(```!_T0$`"P``
M`)+1`0`0````GM$!`!````"OT0$`!@```,#1`0`&````Q]$!``(```#.T0$`
M!````-'1`0`,````UM$!``@```#CT0$`!@```.S1`0`$````\]$!`!L```#X
MT0$`#P```!32`0`/````)-(!`!8````TT@$`#P```$O2`0`.````6](!``0`
M``!JT@$`"@```&_2`0`*````>M(!`!8```"%T@$`!````)S2`0`,````H=(!
M``8```"NT@$`%P```+72`0`L````S=(!`!8```#ZT@$`&0```!'3`0`S````
M*],!`!(```!?TP$`$@```'+3`0`5````A=,!`"@```";TP$`"@```,33`0`;
M````S],!``0```#KTP$`"0```/#3`0`'````^M,!``@````"U`$`.`````O4
M`0`/````1-0!`!<```!4U`$`$P```&S4`0`(````@-0!``0```")U`$`!```
M`([4`0`(````D]0!``@```"<U`$`#````*74`0`-````LM0!``D```#`U`$`
M"````,K4`0`,````T]0!`!0```#@U`$`$@```/74`0`.````"-4!`!8````7
MU0$`"````"[5`0`1````-]4!`!8```!)U0$`%@```&#5`0`,````=]4!``8`
M``"$U0$`$P```(O5`0`3````G]4!`$,```"SU0$`&P```/?5`0`-````$]8!
M`!$````AU@$`#0```#/6`0`/````0=8!`!,```!1U@$`%P```&76`0`5````
M?=8!``T```"3U@$`$0```*'6`0`7````L]8!`"D```#+U@$`&0```/76`0`7
M````#]<!`!`````GUP$`#0```#C7`0`4````1M<!``P```!;UP$`"````&C7
M`0`2````<=<!``@```"$UP$`!````(W7`0`L````DM<!``0```"_UP$`&P``
M`,37`0`(````X-<!``\```#IUP$`!````/G7`0`(````_M<!`"@````'V`$`
M(0```##8`0`C````4M@!`#H```!VV`$`!````+'8`0`,````MM@!`!P```##
MV`$`$P```.#8`0`(````]-@!``0```#]V`$`"`````+9`0`A````"]D!``0`
M```MV0$`!P```#+9`0`(````.MD!``H```!#V0$`"````$[9`0`?````5]D!
M`"````!WV0$`"@```)C9`0`4````H]D!`!4```"XV0$`%@```,[9`0`4````
MY=D!`!(```#ZV0$`%`````W:`0`(````(MH!``@````KV@$`"````#3:`0`(
M````/=H!``H```!&V@$`!````%':`0`7````5MH!``0```!NV@$`!````'/:
M`0`(````>-H!`!(```"!V@$`!````)3:`0`(````F=H!`!,```"BV@$`%0``
M`+;:`0`"````S-H!``0```#/V@$`!````-3:`0`(````V=H!``@```#BV@$`
M"@```.O:`0`<````]MH!`!(````3VP$`!@```";;`0`(````+=L!``P````V
MVP$`"````$/;`0`$````3-L!`!,```!1VP$`$0```&7;`0`L````=]L!``8`
M``"DVP$`!@```*O;`0`$````LML!``H```"WVP$`#@```,+;`0`(````T=L!
M``P```#:VP$`'P```.?;`0`(````!]P!``@````0W`$`!@```!G<`0`$````
M(-P!`!0````EW`$`!````#K<`0`*````/]P!``@```!*W`$``@```%/<`0`$
M````5MP!``@```!;W`$`!````&3<`0`&````:=P!``8```!PW`$`&````'?<
M`0`*````D-P!``8```";W`$`$0```*+<`0`$````M-P!``0```"YW`$`/P``
M`+[<`0`$````_MP!``0````#W0$`&0````C=`0`A````(MT!`!P```!$W0$`
M)0```&'=`0`6````A]T!``\```">W0$`%@```*[=`0`8````Q=T!`!\```#>
MW0$`)0```/[=`0`5````)-X!`!@````ZW@$`#P```%/>`0`/````8]X!``P`
M``!SW@$`!````(#>`0`$````A=X!``0```"*W@$``@```(_>`0`$````DMX!
M``D```"7W@$`!@```*'>`0`$````J-X!``8```"MW@$`!````+3>`0`$````
MN=X!`!$```"^W@$`!````-#>`0`6````U=X!`!0```#LW@$`#0````'?`0`2
M````#]\!``X````BWP$`#````#'?`0`4````/M\!`!T```!3WP$`!````''?
M`0`(````=M\!``0```!_WP$`#````(3?`0`,````D=\!`!````">WP$`$@``
M`*_?`0`$````PM\!``@```#'WP$`"````-#?`0`$````V=\!``0```#>WP$`
M%0```./?`0`G````^=\!``4````AX`$`"````"?@`0`(````,.`!`!(````Y
MX`$`!````$S@`0`&````4>`!`"$```!8X`$`$````'K@`0`(````B^`!``0`
M``"4X`$`!@```)G@`0`(````H.`!``P```"IX`$`!@```+;@`0`.````O>`!
M``\```#,X`$`&````-S@`0`A````]>`!`!0````7X0$`'````"SA`0`6````
M2>$!`#D```!@X0$`$P```)KA`0`5````KN$!`!4```#$X0$`%0```-KA`0`6
M````\.$!`#L````'X@$`!@```$/B`0`F````2N(!`!\```!QX@$`#P```)'B
M`0`H````H>(!`#H```#*X@$`#P````7C`0`;````%>,!`!4````QXP$`'0``
M`$?C`0`=````9>,!`!,```"#XP$`$0```)?C`0`9````J>,!`!4```##XP$`
M)P```-GC`0`&`````>0!`#`````(Y`$`90```#GD`0`>````G^0!``\```"^
MY`$`+P```,[D`0`Q````_N0!`"\````PY0$`%0```&#E`0`(````=N4!``8`
M``!_Y0$`&0```(;E`0`7````H.4!`!<```"XY0$`%@```-#E`0`3````Y^4!
M`!,```#[Y0$`'0````_F`0`(````+>8!``8````VY@$`'P```#WF`0`3````
M7>8!`!D```!QY@$`&````(OF`0`3````I.8!``T```"XY@$`$0```,;F`0!+
M````V.8!`$(````DYP$`)````&?G`0`E````C.<!`!\```"RYP$`'````-+G
M`0`D````[^<!`#D````4Z`$`+P```$[H`0`X````?N@!`!4```"WZ`$`'@``
M`,WH`0`G````[.@!`!X````4Z0$`%@```#/I`0`7````2ND!`!L```!BZ0$`
M&@```'[I`0`B````F>D!`#@```"\Z0$`,0```/7I`0`=````)^H!`"L```!%
MZ@$`*0```''J`0`=````F^H!`!\```"YZ@$`&P```-GJ`0`3````]>H!`!4`
M```)ZP$`)0```!_K`0`>````1>L!`!X```!DZP$`&P```(/K`0`1````G^L!
M`!D```"QZP$`&P```,OK`0`;````Y^L!`"0````#[`$`#P```"CL`0`]````
M..P!`!<```!V[`$`$P```([L`0`(````HNP!`&H```"K[`$`,P```!;M`0`3
M````2NT!`"$```!>[0$`+0```(#M`0`7````KNT!``\```#&[0$`'0```-;M
M`0`D````].T!``(````9[@$`"````!SN`0`$````)>X!``@````J[@$`"```
M`#/N`0`(````/.X!``L```!%[@$`!````%'N`0`/````5NX!``8```!F[@$`
M2P```&WN`0`$````N>X!``L```"^[@$`"P```,KN`0`'````UNX!``0```#>
M[@$`#````./N`0`$````\.X!`!$```#U[@$`#@````?O`0`&````%N\!``8`
M```=[P$`$@```"3O`0`/````-^\!`!4```!'[P$`#````%WO`0`8````:N\!
M``\```"#[P$`#@```)/O`0`,````HN\!``0```"O[P$`!0```+3O`0`/````
MNN\!`!````#*[P$`$@```-OO`0`?````[N\!`!X````.\`$`'P```"WP`0`.
M````3?`!`!8```!<\`$`&0```'/P`0`4````C?`!`!(```"B\`$`$@```+7P
M`0`7````R/`!`!(```#@\`$`$@```//P`0`7````!O$!`!@````>\0$`'P``
M`#?Q`0`1````5_$!`!T```!I\0$`$0```(?Q`0`:````F?$!`!$```"T\0$`
M$@```,;Q`0`6````V?$!`!<```#P\0$`$@````CR`0`7````&_(!`!4````S
M\@$`$P```$GR`0`0````7?(!`!<```!N\@$`$@```(;R`0`7````F?(!`!(`
M``"Q\@$`$@```,3R`0`/````U_(!`"8```#G\@$`*0````[S`0`.````./,!
M`!8```!'\P$`)P```%[S`0`8````AO,!`!8```"?\P$`'@```+;S`0`?````
MU?,!`!@```#U\P$`$P````[T`0`2````(O0!`!<````U]`$`(@```$WT`0`6
M````</0!`"````"']`$`!````*CT`0`(````K?0!``0```"V]`$`'@```+OT
M`0`;````VO0!``8```#V]`$`#@```/WT`0`$````#/4!`"<````1]0$`%0``
M`#GU`0`4````3_4!`"0```!D]0$`!````(GU`0`&````CO4!`"4```"5]0$`
M)````+OU`0`/````X/4!`!<```#P]0$`$@````CV`0`&````&_8!`(T````B
M]@$`"````+#V`0`4````N?8!``X```#.]@$`!````-WV`0`'````XO8!``H`
M``#J]@$`"P```/7V`0`/`````?<!``0````1]P$`(P```!;W`0`,````.O<!
M``P```!']P$`!````%3W`0`0````6?<!``X```!J]P$`"````'GW`0`U````
M@O<!``8```"X]P$`'P```+_W`0`*````W_<!``H```#J]P$`"@```/7W`0`=
M`````/@!`!`````>^`$`"@```"_X`0`7````.O@!``L```!2^`$`"````%[X
M`0`/````9_@!`!4```!W^`$`$0```(WX`0`$````G_@!`!(```"D^`$`!@``
M`+?X`0`8````OO@!``(```#7^`$`"````-KX`0`2````X_@!``0```#V^`$`
M%````/OX`0`D````$/D!``T````U^0$`!````$/Y`0`(````2/D!``@```!1
M^0$`"````%KY`0`%````8_D!``8```!I^0$`#P```'#Y`0`/````@/D!``D`
M``"0^0$`!P```)KY`0`*````HOD!``P```"M^0$`"@```+KY`0`)````Q?D!
M`"8```#/^0$`(P```/;Y`0`&````&OH!``@````A^@$`'0```"KZ`0`$````
M2/H!`!L```!-^@$`#0```&GZ`0`1````=_H!``0```")^@$`!@```([Z`0`(
M````E?H!``P```">^@$`$````*OZ`0`$````O/H!``0```#!^@$`!````,;Z
M`0`$````R_H!``0```#0^@$`"0```-7Z`0`(````W_H!`!$```#H^@$`$@``
M`/KZ`0`9````#?L!`",````G^P$`#P```$O[`0`/````6_L!`!8```!K^P$`
M"````(+[`0`B````B_L!``0```"N^P$`$P```+/[`0`C````Q_L!``@```#K
M^P$`"````/3[`0`%````_?L!``@````#_`$``@````S\`0`&````#_P!``@`
M```6_`$`!0```!_\`0`&````)?P!``0````L_`$`"````#'\`0`$````.OP!
M``H````__`$`#@```$K\`0`.````6?P!``H```!H_`$`#@```'/\`0`.````
M@OP!``H```"1_`$`.````)S\`0`P````U?P!`!,````&_0$`$P```!K]`0`5
M````+OT!``T```!$_0$``@```%+]`0`"````5?T!``P```!8_0$`!````&7]
M`0`,````:OT!``(```!W_0$`"P```'K]`0`]````AOT!`!D```#$_0$`+0``
M`-[]`0`+````#/X!`"$````8_@$`(0```#K^`0`E````7/X!`!L```""_@$`
M%P```)[^`0`7````MOX!``L```#._@$`4P```-K^`0`7````+O\!`$$```!&
M_P$`*````(C_`0`A````L?\!`!P```#3_P$`&P```/#_`0`7````#``"`!4`
M```D``(`&0```#H``@`<````5``"`!4```!Q``(`%0```(<``@`5````G0`"
M`!4```"S``(`$P```,D``@`7````W0`"`"(```#U``(`&P```!@!`@`>````
M-`$"`!````!3`0(`%P```&0!`@`(````?`$"`%,```"%`0(`"````-D!`@!6
M````X@$"`"T````Y`@(`40```&<"`@`;````N0("`#8```#5`@(`$P````P#
M`@`7````(`,"`!D````X`P(`$P```%(#`@`)````9@,"``\```!P`P(`&```
M`(`#`@`;````F0,"``\```"U`P(`$@```,4#`@`Z````V`,"``\````3!`(`
M#P```",$`@`5````,P0"``P```!)!`(`#P```%8$`@`1````9@0"``H```!X
M!`(`"@```(,$`@`+````C@0"`!(```":!`(`%````*T$`@`&````P@0"``8`
M``#)!`(`!@```-`$`@`(````UP0"``@```#@!`(`"@```.D$`@`&````]`0"
M``@```#[!`(`!@````0%`@`&````"P4"``T````2!0(`"P```"`%`@`&````
M+`4"``8````S!0(`!@```#H%`@`-````004"``P```!/!0(`#````%P%`@`&
M````:04"``8```!P!0(`#P```'<%`@`2````AP4"``8```":!0(`!@```*$%
M`@`-````J`4"``@```"V!0(`!@```+\%`@`&````Q@4"`!````#-!0(`#```
M`-X%`@`$````ZP4"``X```#P!0(`"````/\%`@`*````"`8"``H````3!@(`
M"@```!X&`@`,````*08"`!(````V!@(`#````$D&`@`*````5@8"``0```!A
M!@(`$P```&8&`@`$````>@8"``,```!_!@(``@```(,&`@`2````A@8"``0`
M``"9!@(`$````)X&`@`-````KP8"``P```"]!@(``P```,H&`@`"````S@8"
M``0```#1!@(``@```-8&`@`$````V08"``D```#>!@(`"0```.@&`@`&````
M\@8"``8```#Y!@(`"``````'`@`$````"0<"`!`````.!P(`!````!\'`@`,
M````)`<"``@````Q!P(`$P```#H'`@`"````3@<"``0```!1!P(`"````%8'
M`@`&````7P<"``P```!F!P(`!@```','`@`.````>@<"`!H```")!P(`!```
M`*0'`@`&````J0<"``H```"P!P(`!0```+L'`@`%````P0<"`!````#'!P(`
M`0```*$'```?!```,0,````````_!@``S@8````````Q!0```````$D%```;
M!@````````````#$``````````````#&!@``@@8``*H$``!Q!P``D`0`````
M```X`P``/P,``,4'``!G`P``S`0```````"&!P``"0@```````"U!@``5`0`
M`.(#`````````````#8(``"*!P```````!D&````````M@```&H'``!'"```
M`````'<&````````=@,``)D!```[!0```````-`'``"&````R00````````J
M!P``V@0``+4"````````R04```````"P!0``!P@``)L%``"1`P```````)0#
M````````&P(``/H!````````^@8``!D!``!Z`0```````&X"````````S@<`
M`)@$``#G!P``.@4``*L```"=`@``*```````````````GP0````(``#!!0``
M1```````````````D@,```````"Q!0``A`<``/`'``#J`P``)`@``(H&``!7
M!`````````````!&"```T0,``.,`````````@`,``'H#``!E`0``G@``````
M````````2P@``-,"```8````-P(``$4"``#[`0````````````"[!@``7```
M`*@%```Q````"`4``$(!``!!!```900```\$`````````````(X#````````
M+0@``,0!````````YP(``'D&```9!0``-@```'8!``"-!```N``````````&
M!@``8`<```````!&!P``[@(``',%``##!@``SP0```H$```_!```!0,``.L`
M```=!@``Z@(``)H$```=````*@0``((```#G````O`8``(L%``#<!0```P@`
M`+L"````````10,``-\%``#)`0``5P8```````#!!P``2@0``,T!``#X!```
MV`$``*4```#,!0``[`(``,4$````````/`8``,T'`````````````#8'``!W
M`P``(````.T%``!0!@``%`0``#8"``#4`@``R@(``)$$``"?`0```````(8#
M``!8`P```````#,%``#W`0``3P````('``#T!P``UP```(X%``#B!```````
M`"L'````````O`,``)<`````````S00``-T%``#O`````````(T&``#N!0``
M&@,``'8%`````````````#L$``!J!@`````````````5````=P`````````_
M"```8`8``)$%``!2`@````````````"`!`````````````";!P```````.L%
M```C`@``O`4``+8#````````<0(```````#>!@``TP4``)4'``!!"```````
M`"L$``#4`0```````-4#````````"P,``&4```#/`@``20<`````````````
M``````\%``````````````````!6!P``6`0``&H!```D!0``0P4```````!)
M`@```````#L!````````D`$````````K`0``*`8```````":`P``,P@`````
M```7"```\@0````````A!```+P0``"`$````````WP,``"0!``#>````F00`
M`/X'````````PP,``+L#``!#!@``+`@``.P&``"1`@````````````"U`0``
M6`(``&T#````````VP$```````#1`@``;`,```````"8!@``_P0```````#@
M!@``AP4``.D"``!/`@``#@(``"D!``!5`@``"@@``)L!``!,`@``L@$`````
M``!-!`````````,'``!R!```W@$``,`$```G`P```````!0&```R`@``/`0`
M`+`'````````40@`````````````L08``,8"```B"```NP<``",#```5!```
MV@8``"0&``!3!0``3P<``"L"``!Q!```U0$````````N`0``8@4``#P```!3
M`P``4`0```$%```\"````````(P!``"K`0``A0`````````I!@``*04``$X'
M```%````H@0````````9`@``*`<``.0!``!`!@``#00```````"V!@``=P<`
M`)P&````````/0,```````#9`````````,T"``!$!P``.08``-P#```&!```
M!00``-,&````````.`8``*D!```.!0``/@,``+0#````````?`<``/L&````
M````004```````"4`0``8@8``%D"```U!P``7P4```($``#O`@``"P@``(P#
M``"/`0``$`$``"$(``!>!@``P@8``*P#```T!```IP```/@`````````2@@`
M`#,#```X"```1`4``+0```"W````C@````4!```"!@``7`4``*P!``!Q!0``
MB`4```H&```<!P``DP,``+0!``#X!@``V`0```````"#````.@````````#Q
M!```ZP$``-0```#)`P``)@4``',#``!6!```LP8``#($``"&!0``Y00``/<&
M````!``````````````:!@``S@````8(````````@P8``'T'``#)````````
M``P!``#_`0``,P<```````!A!@``^P```$0$```0!```4`,``"4#```.`P``
M`````````````````````&X```#E!0```````"<!```F!```T`8```````"4
M`@``G`(```((````````#@$``,8$``!9!````````+<&```-`@``+`$``(P`
M``!#`P``=@0``/D#```3"```NP0``,$!``#R!0``V04`````````````````
M`$0"``#@!0``(@,```````#@!```/P```$L!``#Q`P```````$,$``"T`@``
M`````!,'``"'!@````````````##````?@8```4"``!3`0``B00``%X"``":
M`@``V@4``#T%``!*!0``T`(``'<"``"M!```I@<``%\#``!]`0``IP8`````
M``#\!@``#`<`````````````"@4``"<%``!$`0```````$`"````````A0,`
M``````!4"```J`$``"$&````````,P0```D'`````````````#`&``!]!@``
M`@$``/P#``!F!@``]@0``+X$``!2"```I`8``+L````!!```>`8`````````
M``````````````"7!P``>@(``-,!```O!0``>@4```````"F!`````````L`
M``#A!```K`4``)4#``!X!`````````````#6!````P8``,<```!.!@``/0$`
M````````````)@(``/4&``!T`0```````)<$````````Z0,``"`#``"J`@``
M`````%L"``#]!0``V`4`````````````BP,``.P`````````D@(``$X"``!<
M!````````*@$``"5!0```````-\&``"C!0``RP8``&0&``#_`````````/$&
M````````K0,```<%``!0````J0(`````````````+0<``%`%``#E`P``HP``
M`'P%``#$`P```````````````````````*````#:`0``#P8``'D"````````
M:04`````````````M04``+D"````````MP<`````````````BP```*P'``!:
M!````````$T&```````````````````W!@``-0(```````#2!0```````.0&
M``"%!P``O0(````````=`0``0@```%`"```I`P``2P```%X#``"/`@``FP``
M`(P"``"`!0``)@$``,D&``#<`0```````,@'``#=````/08``!\'``!D!0``
M`````/4!``````````````````#V`@```````(D!``"N!0```````.L#````
M````M@4``-4$`````````````%L'``!D`0```````+$!``!W`0``C04``.D&
M```9!```Q@```$,!```'`0``S@$``/0$```R`P``9@$``/X"``#!`P``````
M`'D````G````;08``.L$``!*`0``H0(``$4(`````````````.X```!,`0``
MU`<```````"T!@```````'<%``#;!@``6`$``+\#````````N`,``!L!``!0
M"```HP$``#(&``!K`P```````"\```"9`P`````````````?!@``V00``.,$
M``#V`0```````*$```!E!P```````*L'``"Z!```;04``*\'``"*!```````
M`(D"``"H!P```````($"```?````5`4``&$%``"!!```@08``/<$````````
M`````(H#``!R`P``]`4``(0#``"_````#P,``*`'``!'!0```````-,'``#)
M!P``<`4``&@%``"-`@``V@,``#D$``"\`@``(@0``-0#``#6!P``'@(``*H%
M```U`0````````````!K!0``BP0````````Z`@``SP,``,<&``#?````8`0`
M`$D!``"^`0``L@<```<#```J`0``&`,```````!G!@```````)L"````````
M[`$``$X$``"J!@``M0,``*("````````(P8```````"Z````_0$```````!,
M"```Y@```((!`````````````-(!````````R@,`````````````(P0``!("
M``!T````:P(``'D$```%!P```````/@"``#_`@``T`4``#X&``!K!```+P(`
M`"P``````````````(T`````````(0,``%$$``!>`0``"0(``*L$```1`@``
M`````(8!``#W`@```````/@!````````````````````````JP,``%T'``#Y
M`0``IP$``/D%``"<`0``FP0``*L&`````````````&D#````````/`,``,X"
M````````_08``)4&``#2````[P<````````@!P```````-H'```>````````
M`/$'``#_`P``208``!P!``"+`0``K@$``*`"``!Z!P``'`0``!D(````````
M4@8``'T`````````^0(``)0````)`0``)0<``"\(``#X!P``$`````````!<
M`P``)0$``%8#````````````````````````00```*0'``"'!```S@0`````
M```]`````````/(&```("```90(``-@```#,!P```````)L&``#B!@``````
M`#0&``"#!0```````!X%``"T!0``/0<``-0%````````"@````````!-!P``
MA`8```````"_`0``S`8``+8"````````6`<``!\!````````H`0```````#;
M`P```````-@"````````V0<``!$$``"!`P``(@<``/0#``"``0``"P<``.@$
M``##!0``F@4``,H$````````3@,``"<'``````````````\"``!S!P``#0$`
M`!`&````````R@$``)P````%!0```````*X#``#G`P```````&`#``#3`P``
M,0<``%H&``!^`````````"X$``!5!@``G@4``&X%``"0!P``CP0```````"/
M`````````+,'``"?!@```````&8'```.!@``P`<``"8'```2"```=`8`````
M``#U`@``_@,``````````````````````````````````(X!```@`0``-P0`
M`+8!````````"P8```````"X!0``40```&8%``"O`0``,0$``-X#``"F`0``
M"`$```````"?`P``````````````````Y0``````````````$04`````````
M``````````````"Y`````0,``,@%`````P```````"0'``"D!```BP8``%T"
M``"'````<@8``,('``"N!P``L````)D'``!T!0```````/,```"E!P``\@,`
M`-8!``!O!P``B`,``%P!``!;`P``G0```#L(``!.````IP0``%<!``"6`0``
MX`,``'4```!E!@``%0<```````"6!P``;0(```````!%````1@$``,$&``#T
M`@``_`4``"4(````````!@4```````#/!P```````.`"``"8`P``````````
M```W!0``JP4````````!"```X`$``'(%``#A`P```````,\!``!C!P``W0$`
M`.T$````````1`,``.\$````````;@$``"X&````````$0$``!(%``#P!0``
MI0,```````"R!0``H`$``,`%```U!````````!,%``#C`0```````#\!```6
M"```RP4``#('````````3`4``)D&``!A`P``VP```'\%``#Z!0``J00``!H`
M```5!0``3P0``$4!``!/`P```````-8&```(````9`(``+T!``#5`@``````
M``````"*!0```````#H!``!P``````````````"M````O`<``.4!``!+!```
M-P,``.8'``!Z````'@0```````"D`0``-0@``#<(``"^!@``$0,``.D```"^
M!P``,P8``"<(```\!P```````&H#``"]!P``<@<``%8````I````3`0`````
M``"X!```"`0``*,'```2`0``3P$``"`"``#W`````````-8%``!F````708`
M`'@```"0````T@<````````$!````````(,!``!(!```;`<``*`&```=`@``
MO`$``'0$```:!```%P(``````````````````#`!```S`0```````&\!``!G
M`````````'0#```>!P``N08`````````````S08``"0````)!0``D@0``+L!
M````````F0(``/,"````````\@<```````![`@``GP(``'8"````````KP,`
M`(0!```1"```:08```P&``!F`@``SP````````#=!P``8````+("``#&`0``
M70,```````#_!@``$`@``&0````8!```[P4``-H````L`@``5`8`````````
M````R`(``"`(``"L`````````%<"``"F`P``X0(``!`%``!(!@``<P8`````
M``"N`@``,`0```@"`````````````!T$````````<@$``,@#``#U!```?@,`
M`*0`````````7P<``#@$```$`@``B@```.4'```K!0``'`4``,(%``")`P``
M?P,```````"L`@```````!P(``"I````RP(``/````!Q````=P0``#$$``#]
M````2````(H!``"#!```;P```/,!``#]!```^P(``'X'``"`````0P<`````
M```!!@``W`8```<&```K!@``A00``+`$``#>!0``D0$``,4"``!!`P``````
M``8```!@!0``X````)H!``!0!P``X@$``+,#`````````````'H$``#9`P``
MMP0``/P"``#2!```E@4``!,$````````-@,``"L(````````S`$``/P!``!N
M!@````````````#H!@```````!0%```Z!@``````````````````7@``````
M``````````4``)8&```3`0```````,($````````_@```)@%``!5`P```P0`
M`+P``````````````)T&```(`P``]@4```````!\`0``F`(```````!:`0``
MBP(```````!$!@``OP(``"D(``!(`0``X`<``"P#```\`0```````.0```#D
M!P``B08`````````````:@0``,L!``"5````Y`,``#<!`````0``YP4``+H&
M``"-`P```````"(!``!G!````````,<%```R````````````````````*00`
M`*H`````````_`````````"4!```%@,``.$%``!$"```8@<````````B!@``
M[`0``#$&``"Z`0``VP4``````````````````'$!``"1!P``QP(``*T'``!D
M!P``=@```-(#``"V!P``,`<``+$```"W`@``[@,`````````````````````
M``#?!````````"$"```"`@``)04``-\!````````$P8``.X&```7!P``````
M`&L!``!2!```)@,``),!````````&`@``+P$```!!P``:@(``+$$````````
M`````!,#``!"!P``_@8```````!]`P````````````#A!@```````(<"``#9
M`@``CP4``'`$``!8!0``Z`,``,P#```L!0``^@,``,,"``"B!@``0P(``%(`
M````````L0<``!(&```<!@``5P,``&\$``!2`0``%`@``&P!````````````
M`.(```"&`@```````-<'````````-`````````#Q`0``6`````D$````````
MDP(````'``#1`0``L`$```````"G!P``@@,```````"2!0``G`<``"L#````
M````_0,``````````````````!L```````````````````"-`0``\P<``'4&
M```Z`P``;0<```````!`!```I08``*X$```6`@```````%@&````````G@0`
M``````#D`@``704``,D"```F````L`,``-P````J!0``-`4``%,"``#"`@``
M(P<``%4!``#U!P``Z`<``(D%``"F!0``DP8````````$!@``````````````
M````&P<```````#"``````````````"2!P``Q0```$L"``!L`````````-0$
M```````````````````2`P``1@8```````#A`0``^08```$"````````%0(`
M`&,!```?!0``QP$``"H`````````?@4``(8&````````I@8``.@!````````
M"@,```````"R!@``;P(``'L$``#!````60,``&0$``"6````D08``"@!``#R
M`````````%<```#J!@``5`(```````"#!P``"P4``*D#``"M!@``@0$``)0'
M``#Z!```K@8````````;`P``````````````````Z@4```L$````````F@<`
M```````_`@``\P,``)P#```\!0``-P<```````#F!@``Q@<``%H'````````
M/P<```X$```6!0``.@@``$($```=`P``<P(``&(#``!?````D`8```````#J
M!```,@@``$,(``!+!0``[`4``%<'``!G`@```````*,#``!<`@``=0<``/@%
M``!^!````````#0'``#:`@```````%(%```^!P``)@8````````8!0``!`4`
M`*4%``#7!0``!`$```````````````````P#```#!0```````+<!``#C!@``
M)P(``"\!````````LP4``%P'``#5`````0$``'$&``!C!```[0```,@```#>
M`@``&`(``.$'``!A!P````````,``````````````+,!``!*!@``1P``````
M``#3````6@,```````#+!P````````````"U````B0```"(`````````6P8`
M`.("```M````A`(``,L#``!K!@````````L!``!X!0```````-T"````````
M!P(``&@'``"5`0``9P<``"T#``!K!P``408``'\&``"E`@``8@0``$`%``!6
M"```R@<``/0!```M`@``40,``+L%``!P`0``PP<``.,#``#;!```&0```"D"
M``"_!P```````(0```"3!0``3P@``$@%``"B````S````*\%````````2`(`
M``````!5!```#`4``*\"`````````````%T```!A`0``G@8``*\&``#3!```
M`````+0'``!N`P``<P$``!H"``".`@``_`<```````!)````@`<``$`(``#-
M````[0$```````!+!P``.`<``*0%```````````````````^"```]@```.@%
M``"H!@``(P4``/D$``!X!P``00<`````````````Z04```````!9!@``O08`
M`$((``"2!@``"0,``%<%```Y`P``-P```'L%``"3`````````((%```5`0``
M[P$```````#O`P``%`<``+T#```L!P```````+`"````````LP```#0(``"=
M!````````!`#```'!````````%,&``!A!````````"@(``#W!P``Y@0``&D!
M``#[!P``Q`0``&("``#=`P``F@```&@"``!]!```+@(``&,"````````EP8`
M``````#5!@``/P4``,8#```1`````````%X%```O`P``?P0``/`$````````
MB````$T````&`P``R@```+4'``"_!0``PP$``'4#``"C!```,`,```````!/
M!0``,0@```H'``#<`@``I00``'X"``"8`0``'`````````!)"```````````
M```M!@```````$\&``"=!0``50@``"4```#*!0``9@,```````#S!@``]0,`
M```````7`0``5@(``````````````````-<!``#P`0``/@4``(('```Y````
M]P,```````!C!0``<P0``,P"```[`@``T00``.L"``!3````O04`````````
M````<`,``,4&````````=`<``-<#``````````````0#`````````````$<!
M``!V!@``KP0```````#K!@``K04``'("``"Z!P```````!0```#U````_@$`
M```````[!@```P(``(4!`````````````!(```">`P``Y0(```````!C!@``
MN`8``%\&```````````````````#`P``D`(``%8!``#Y````R`$```````!.
M"````````+X#```7````Z`(````````%"```7@<``%T$```P"````````-\'
M``#I`0````````````!2!P`````````&``#]`@``0```````````````1P,`
M``````"'`P``.`4``#`"``!\!```,````(P'``#>!P``LP0``*,"````````
MGP4``!P"````````.`$``&@```#J`0``%08``(@!````````^P4``(($```;
M!```Z00``($'``#/!0``N`$``"H&``!"!@``4P0``,H&```Z!P``%0,`````
M````````"@(``,$"`````````````",(```````````````````?"```UP0`
M`&@&``"_!@``IP(``-4%````````^0<```````"Q`@``'P(```````"U!```
MT`0``.T#````````;@<````````C`````````"X'````````(@(```````#(
M!@``H@,``&P&``````````````````!C`P``````````````````0P```$@'
M`````````````(@'``"(!```]@,`````````````:P```-8#``#'`P``````
M``````#A````S@,``(4%````````````````````````]````/,%``#G!@``
M(`8```````#!!```+@````````"7`0`````````````>"````````"P&``#Q
M````*@,``/$"``">`0```````&P$````````.`````````"6!```X@<`````
M``!O!@``%@8``/0&``#=!```&`<`````````````A`4``%L```!'`@``;`(`
M```"``"/`P``5`<```````#1!@``>`,``#8$`````````````&8$``!.!0``
M&P@``,L``````````````/,$``!%!P```````&@$``"``@``,P``````````
M`````````,`&```[`P``!@(``.(%``"@!0``1@0``$T"```-"```A@0``%`!
M``"0`P``?P```-P'````````J``````````"`P``C@8``#D!```7!@``````
M`.H'``#E!@``^@<``$("``!E`P``"08``$P#````````T0<```\!```-````
MD`4``$8```#8`P``Q04``"$'````````40<``!8'``!:`````````+T$``"3
M!P``D0```/`&````````K`8```````"J`0``#0<````````,`@``9`,`````
M```/````$`<``'4$``#%`0``'@$``#4#``"R````\`,``$P&``!B````O@4`
M`&,```"O`````````(L'````````[`<````````````````````````>`P``
MK0$``%\$``!'!```E@(``+\$``#C!0``/`(```````#N`0``L0,```````#0
M`P``2@<```````":!@``0@4```````"5!```[0<```````#M`@``J`(``'4%
M```T`@```````-@'``"9!0```````$$!``!1`@``P`$``*$#````````````
M`'L```"3!```Y@(``&`"````````(04``#8%```8`0``F````/L#``!9`0``
M$@<```````#R`@``RP0```````"6`P```````*$$``!!!@``@P,``,,$```&
M`0``^@(``+`&``"]````8`$```````!%!0``Y@4```D```#-`P``$P```"<&
M```O!P``Q`(``!D'```;!0``/@(``"4&``!\!@````````````!X`0``(P$`
M`'T"``"X`@```````#X$````````P````*0#``#F`0``(0$```````!9!0``
M+0$``'0"``#V!@```````#0#```-!0``:`,``&(!``!^`0``1P<``%H%``"J
M!P``A08``,<$`````````````)0%```=!0``K@```(@"``!<!@``@`8``$8#
M``#0````;@0```````!:`@``(0```#L'```%!@```````*P$``#9!@``0`,`
M``````"@`P``[@0````````:`0``(`4``#X!````````7P(``-D!``",!0``
M!@<```````"B`0`````````````6`0``'0<```````!,````N@(`````````
M````````````````````J04``'P```#G!```>P8``#`%``!&!0``.@0``$D$
M```#`0``XP<``/\%````````$08``#4`````````108````````-!@``````
M```````Y!P```````#T$````````I@(``'D#``"*`@``<`8``!@&````````
MU0<``(\'``!A`@``R`0``$$"``"^````*`(``*@#``"!!0```````-L"``!\
M`@````````(%``"C!@``70$```T#``#2`@``.04``-T&``"^`@``30@`````
M````````Q@4```````!I!P```````%$%`````````````,0&``";`P``3`<`
M`'L'``#0`0```````/4%````````#`0``#0!```O!@``AP<``/X%```?`P``
M[@<``#(%```>!@``&@@``"D'``!+`P``EP,``*H#``!3!P````````````#W
M!0``N0<``/`"````````G0$````````9`P``W`0``-L'``#4!@``J0<``#T"
M``#2!@``)`(``"4$``"M`@``:@4`````````````E0(``"P$``!Y!P``#P<`
M``````![`0```````(("```G!```,0(````````Y`@``LP(``%4%``"!````
M`````#8&``!]!0``A0(``/P$``!-`0``*@(```````!E!0``-08``&\#```"
M```````````````H!```<P```*4!````````V`8````````6````*`,``'@"
M````````Y`4``(,"``!9````=@<```````!I````'`,``"@%```M!```5@8`
M`&D"```4`@``C`8``)(!````````<0,``%L$``!4`P``:00``*<#``"<!```
M+@4```````"D`@``AP$``!`"````````#@<``$H#``!M````4@,``%4'``!?
M`0``!````-\"````````:@```+8$``#1!0``%@0``"8(```7`P``80```/8'
M```4`0``S@4````````1!P``)0(``'\!``"G!0``6P4````````7!0``E`8`
M`,`#``#X`P````````0'````````GP````````"Y!0````````````!*`@``
M`````(T'``"A!0``3@$`````````````N@,``)\'``!H`0```````'\'``!M
M!```_@0```````#/!@```````$L&``!Y!0``5@4``#L````7!```P@,```P(
M``#6`@``N00``)X"``!Z!@```````'P#``#]!P```````'`"```D!```C`0`
M`)T'````````D@````````"7`@``6P$``+(#````````C@<``$`!````````
ML@0```````!5`````````"L```!'!@``0@,``(D'``!(`P``H@<``.,"``#K
M!P``G0,```\(```R`0````````H!``!_`@``Q`<``.H````,````P@$``'`'
M```M!0``YP$``#8!``#'!P``H0$``/H`````````0`<``.0$````````W@0`
M`$T#````````Q0,``(X$````````9P4````````.````U@```.8#```+`@``
MT0````````!1`0``!P<``-<"``"Y`0```````$D#``!%!````````%0!``!G
M`0``=0(``)P%```:!0``B`8``+@'```S`@``JP(``"H(``#$!0``1@(`````
M``"Z!0``G@<```````"W`P``&@<````````U!0``7@0``"(%``"B!0``I@``
M``<```!O!0``^P0```X(`````````````#T(``#-!0```````.P#``!L!0``
M304``#@"````````MP4````````4`P``2@```!4(```3`@``Z0<``'D!```(
M!P``M`0``$@(````````CP8``.T&``#H````J08```````!M`0``F`<``!($
M``![`P``\04``'(```"Y`P``EP4``'4!````````!`@````````(!@``````
M``````````````````````#``@``/@```"X#````````H08``"X(````````
M.0@``)D`````````)`,`````````````4P@``/\'``#R`0``[P8``!T(``!9
M!P``A`0```````#7!@``5``````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME
M>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE
M<W1E<F1A>2D`($%D9"!A;B!)35-0($%D9')E<W,@0F]O:P`@1&5L971E($E-
M4U`@061D<F5S<R!";V]K`"!A="``(B5S(B!A;')E861Y(&5X:7-T<R!A;F0@
M=V%S(&YO="!I;7!O<G1E9"X`(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E
M<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U
M<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R
M(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M`"(E<R(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N`"(E
M<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`(B5S(B!W87,@;F]T(&UO=F5D(&)E
M8V%U<V4@:70@:7,@82!L:7-T+@`B1FER<W1N86UE($QA<W1N86UE(B`@*&EE
M+B!*;VAN($1O92D`(DQA<W1N86UE+"!&:7)S=&YA;64B("AI92X@1&]E+"!*
M;VAN*0`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E
M9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER
M97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN
M=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T
M:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT
M`"5S(&%D9&5D+@`E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@
M9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960`)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT
M('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M
M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R
M97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K
M;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@
M=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY
M(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@
M86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN
M9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM
M`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V
M:6]U<P!!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I
M<F5D`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-
M(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`
M06)O=70N+BX`06)O=F4@<V5A<F-H(&9O<FT`06)S8F]T=&]M`$%B<VUI9&1L
M90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V5S<R!D96YI960@=&\@
M)7,`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U
M;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D
M($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D
M($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!
M9&0@861D<F5S<R!B;V]K`$%D9"!A;F0@1&5L971E($E-4U`@861D<F5S<R!B
M;V]K<P!!9&0@8V]L=6UN`$%D9"!F:6QE`$%D9"!N97<@;65M8F5R<P!!9&0@
M<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D
M('1O`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O
M;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N
M`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W
M+@!!9&1I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92X`061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&1R97-S
M($)O;VL@3&ES=&EN9P!!9&1R97-S($)O;VMS`$%D9')E<W,@8F]O:R!E;G1R
M>0!!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"X`061D<F5S<R!B
M;V]K('1O(&1E;&5T92``061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E
M(&1I<W!L87EE9#H`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@
M;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%D=F%N8V5D(%-E87)C
M:`!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI
M9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P
M<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_`$%L<F5A9'D@17AI<W1S`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)
M35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)
M35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T
M92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM
M;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U
M9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I
M<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X
M:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!T:&%T('EO
M=2!W86YT('1O(&1E;&5T92`E<S\`07)E('EO=2!S=7)E('1H870@>6]U('=A
M;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/P!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD
M(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H
M05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YD:6YG`$%S8V5N<VEO;B!)<VQA
M;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF
M:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_
M`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S
M:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T
M:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A
M<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P
M('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R
M96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E
M<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@
M34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I
M<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I
M;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL
M960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)A
M8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O
M<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A
M;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)A
M<VEC(%-E87)C:`!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;&]W('-E87)C
M:"!F;W)M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I;F0@9F%I;&5D.B`H)7,I
M("5S`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N
M;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI
M=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M
M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>0!"<F]W<V4`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L
M;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!"=7-I;F5S<R!#871E
M9V]R>0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-35@!#7V5L
M;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N
M`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E
M="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861D
M(&$@9W)O=7`@=&\@:71S96QF+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#
M86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S
M=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`
M0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L
M;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL
M<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R
M:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#
M97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC
M871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D
M`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@7T%L;"].;VYE`$-H
M:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S
M92!A(&YA;64`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`
M0VAO;W-E(&%N(&%D9')E<W,@8F]O:P!#:&]O<V4@86X@861D<F5S<R!B;V]K
M.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=VAI8V@@861D
M<F5S<R!B;V]K<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CH`0VAO
M;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E+@!#:&]O<V4@=VAI8V@@
M8V]L=6UN<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.@!#:')I<W1M
M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#
M;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U
M="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN
M9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``
M0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S
M("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D
M(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S
M96QE8W1I;VX`0V]L<SH`0V]L=6UN($]P=&EO;G,`0V]L=6UN('1I=&QE<P!#
M;VQU;6YS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.@!#;VUI8W,`0V]M
M;6$@<V5P87)A=&5D('9A;'5E<P!#;VUM82!S97!A<F%T960@=F%L=65S("A-
M:6-R;W-O9G0@3W5T;&]O:RD`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE
M;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!A;GD@061D<F5S
M<P!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@
M4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`
M0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C
M=&EO;B!F86EL960Z("5S`$-O;FYE8W1I;VX@9F%I;'5R90!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W0@
M4V5A<F-H`$-O;G1A8W1S`$-O;G1A8W1S(&EN(&QI<W0Z("5S`$-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@
M;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]P>0!#;W!Y(&9A:6QE
M9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E
M`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'
M4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO
M="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C
M:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E
M<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&
M5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@
M;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN
M9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B
M)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@
M=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD
M(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O
M=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER
M("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K
M(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N
M`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I
M;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X
M=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!!9&1R97-S($)O;VL`
M0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.@!#
M<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&5D`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%52
M3"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O
M;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`
M0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O
M=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@
M<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L
M(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO
M<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F875L="!S;W)T
M:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!!9&1R
M97-S($)O;VL`1&5L971E($-E;&P`1&5L971E($-O;F9I<FUA=&EO;@!$96QE
M=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!B=71T;VX@8F5H879I;W5R`$1E
M;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R
M;F%T92!T96UP;&%T90!$96QE=&4@9F%I;&5D.B`H)7,I("5S`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E
M<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`
M1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@
M<V-R:7!T("(E<R(N`$1E;&5T:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B
M;&4N`$1E;&5T:6]N(&9A:6QE9`!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5P
M87)T;65N=`!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R
M:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D`1&ES<&QA>2`R
M-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE
M9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R
M;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@
M9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M`$1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\`1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L
M:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$
M;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+@!$;W=N;&]A9"!V0V%R9`!$<F]P(&1O=VX@;&ES=`!$
M<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET("(E<R(`161I="!!
M9&1R97-S($)O;VMS`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI
M<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET(&5N=')Y(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E
M<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D
M=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I
M8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C
M:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O
M($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E
M`$5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E
M9"!F:6QE(&9A:6QE9#H@)7,`16YT<GD@9F]R("5S('5P9&%T960N`$5Q=6%T
M;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@861D:6YG("5D(&-O
M;G1A8W0H<RD@=&\@;&ES="X`17)R;W(@861D:6YG("5D(&]F("5D(')E<75E
M<W1E9"!C;VYT86-T*',I('1O(&QI<W0N`$5R<F]R(&-R96%T:6YG(&)L;V-K
M.B`E<P!%<G)O<B!D96QE=&EN9R`E9"!C;VYT86-T*',I+@!%<G)O<B!D96QE
M=&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C=',H<RDN`$5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO
M9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!R96UO=FEN
M9R`E9"!C;VYT86-T*',I(&9R;VT@;&ES="X`17)R;W(@<F5M;W9I;F<@)60@
M;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+@!%<G)O<B!S
M96%R8VAI;F<@=&AE(&%D9')E<W,@8F]O:SH@)7,`17)R;W(@=7!D871I;F<@
M<&%S<W=O<F0Z("5S`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI
M;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M
M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y
M($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V
M86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D
M("<I)P!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AP;W)T`$5X<&]R="!!
M9&1R97-S($)O;VL`17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S
M+@!%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L
M>2X`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S
M<R!B;V]K.B`E<P!&86EL960@=&\@861D("5S('1O("5S.B`E<P!&86EL960@
M=&\@8G)O=W-E(&QI<W0`1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y
M`$9A:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L
M($YE=R!$3B`]("5S+"!2;V]T(#T@)7,`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@
M(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&
M86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I;&5D
M('1O('-E87)C:"!T:&4@861D<F5S<R!B;V]K`$9A:6QE9"!T;R!S96%R8V@@
M=&AE(&1I<F5C=&]R>3H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E
M=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL92!#;W5N=#H@
M)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL
M92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+@!&:6QE<P!&:6QT97)S`$9I;F0`1FEN:7-H`$9I
M;FQA;F0`1FER<W0@2&%L9@!&:7)S="!.86UE`$9I<G-T(%%U87)T97(`1FEX
M(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@
M:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`
M1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U
M;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L
M:71A;@!&<F5E8G5S>2!54DP`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE
M<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE
M(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`
M1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N
M97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!'
M:79E;B!.86UE`$=L;V)A;"!!9&1R97-S($)O;VL`1V\`1V]E9&5L`$=O;V=L
M92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H
M25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7``1W)O=7`@061M
M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U
M<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U"
M:7-S874`1W5Y86YA`$A434P`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O
M<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I
M;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A
M;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($-I='D`2&]M
M92!#;W5N=')Y`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]M92!0;W-T
M86P@0V]D90!(;VUE(%-T871E+U!R;W9I;F-E`$AO;64@4W1R965T($%D9')E
M<W,`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E
M<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R
M:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED
M:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`24U34`!)
M35-0($%D9')E<W,@0F]O:R!!9&UI;FES=')A=&EO;@!)4"!!9&1R97-S`$E0
M($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA
M;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED
M`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!)
M;6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@
M9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="!!9&1R
M97-S($)O;VLL(%-T97`@)60`26UP;W)T+"!3=&5P("5D`$EM<&]R="]%>'!O
M<G0@061D<F5S<R!";V]K<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@
M9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV
M:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M
M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T
M97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`
M26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T
M97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D
M9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O
M<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E
M<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M
M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A
M<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN
M:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G
M97(@;&ES=`!);G9A;&ED($E$`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A9&1R97-S(&)O;VL`
M26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI
M9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S
M+@!);G9A;&ED(&5M86EL`$EN=F%L:60@96YT<GD`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&ME>2!S<&5C:69I960N`$EN=F%L:60@;&EC96YS92!K
M97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y
M<&4N`$EN=F%L:60@;F%M90!);G9A;&ED(&]B:F5C=$ED`$EN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@
M:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!)
M;G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!)
M;G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`
M26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3
M=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU
M87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A
M;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U
M;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P
M(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@
M1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S
M`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC
M(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET
M`$MY<F=Y>G-T86X`3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@
M3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+@!,
M85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC`$QA<W0@2&%L9@!,87-T($UO9&EF:65D`$QA<W0@3F%M90!,87-T(%!A
M<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T
M(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ
M($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE8F%N;VX`3&5F=`!,969T(&AE
M861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@
M4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!2
M86EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W
M`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@
M=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&ES=`!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI
M=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,
M;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F
M86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S
M`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE
M;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D
M;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA
M;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA
M<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9P!-871C:&EN
M9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E
M9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@
M3G5M8F5R(&]F($-O;G1A8W1S`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!"
M;&]C:W,`36%X:6UU;2!L96YG=&@`36%X:6UU;2!N=6UB97(@;V8@<&%G97,`
M36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU($QI<W0`365N=2!M
M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP
M90!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO
M9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN
M960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I
M82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O
M<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N
M9FEG=7)A=&EO;BX`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`
M36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C
M:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL
M`$UO8FEL92!0:&]N90!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!5
M4DP`36]D:69Y(&9A:6QE9#H@*"5S*2`E<P!-;V1U;'5S`$UO;&1O=F$L(%)E
M<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT
M:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@
M:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R92!T:&%N(#$@
M96YT<GD@9F]U;F0`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D
M>0!-;W-T;'D@4W5N;GD`36]V90!-;W9E($1O=VX`36]V92!,969T`$UO=F4@
M4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!L969T`$UO=F4@<FEG:'0`
M36]V92!U<`!-;WIA;6)I<75E`$UU;&)E<G)Y($%D9')E<W,@0F]O:P!-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<&5R<V]N<R!W:71H
M(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@86QR96%D
M>2!E>&ES=`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O
M=6YT($EN9F]R;6%T:6]N`$UY($%D9')E<W,@0F]O:P!->2!!9&1R97-S($)O
M;VMS`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@
M1&\@3D]4($%G<F5E`$YA;64`3F%M92!&;W)M870`3F%M:6)I80!.875R=0!.
M97!A;`!.971C96YT97(@365M8F5R($1I<F5C=&]R>0!.971H97)L86YD<P!.
M971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P
M92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE
M='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE
M='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E
M<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@0V]N=&%C=`!.97<@
M365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L
M*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@
M97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@
M=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T
M:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEC:VYA;64`3FEG97(`3FEG97)I80!.
M:6=H=`!.:75E`$YO`$YO("5S(&5N=')Y(&9O=6YD(&9O<B`E<P!.;R!A9&1R
M97-S(&)O;VMS(&9O=6YD+@!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T
M92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@
M=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`
M3F\@8V]N=&%C=',@9F]U;F0`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD
M+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.
M;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M
M8F5R('-P96-I9FEE9"X`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN
M9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O
M<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V0V%R9"!D871A('=A<R!F;W5N
M9"X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E
M<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE
M`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R
M9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I
M86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A
M(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O
M<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M
M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L
M=6UN<P!.=6UB97(@;V8@:71E;7,@<&5R('!A9V4`3G5M8F5R(&]F(')O=W,`
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]B:F5C="!N
M;W0@9F]U;F0`3V-T86P`3V-T;V)E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S
M<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S
M('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;VYE(&5M86EL(&%D9')E
M<W,@86QL;W=E9"X`3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D+@!/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N
M(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT
M<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N
M<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R
M9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A
M=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R
M`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES
M<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%
M05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N
M8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@
M4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3
M=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0
M861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R
M=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F
M=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA
M=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@
M4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/
M<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N
M`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VX@9&5N:65D`%!E<FUI<W-I
M;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R
M;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&EN
M92!!9&1R97-S($)O;VL`4&ET8V%I<FX`4&EX96QS`%!L96%S92!C;&EC:R!I
M;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@
M;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S
M<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E
M<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@
M=&EM92X`4&QE87-E(&YA;64@=&AE(&YE=R!C;VYT86-T(&QI<W0Z`%!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C
M:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S
M<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S`%!R979I;W5S
M(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!!9&1R97-S($)O;VL`
M4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE
M8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U
M97)Y`%%U97)Y(&9A:6QE9#H@*"5S*2`E<P!1=6EC:R!396%R8V@`475O=&$`
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`
M4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO
M=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D
M(&9A:6QE9#H@*"5S*2`E<P!296%D(&UE<W-A9V5S`%)E861I;F<@8V]N=&%C
M=',@:7,@;F]T(&%V86EL86)L92X`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(&1E;&5T92!T:&ES
M(&-O;G1A8W0_`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-O<F1S(&1I
M<W!L87EE9#H`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE
M=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`
M4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&%D9')E
M<W,@8F]O:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V
M92!F<F]M('1H:7,@;&ES=`!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E
M('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V
M92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297!L86-E(&5X:7-T:6YG(&%D9')E
M<W,@8F]O:R!W:71H('1H92!I;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN
M9SH@5&AI<R!D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!A
M9&1R97-S(&)O;VLN/"]S=')O;F<^`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS
M=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!O8FIE8W0@
M;F]T(&9O=6YD+@!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S
M=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<V5T('1O($1E9F%U;'1S`%)E
M<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E
M='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO
M;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H
M="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE
M`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`
M4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E
M<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%,O34E-12!0=6)L:6,@0V5R=&EF
M:6-A=&4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!3
M35,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U1!4E143%,@9F%I;&5D.B`H
M)7,I("5S`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I
M;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A
M;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`
M4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@
M86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`
M4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`
M4V%V:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N`%-C871T97)E9"!4
M+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396%R8V@@
M9F%I;&5D`%-E87)C:"!F86EL960Z("5S`%-E87)C:&EN9R!I<R!N;W0@879A
M:6QA8FQE+@!396%R8VAI;F<N+BX`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A
M=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!3
M96QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L
M;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&%D9')E
M<W,@8F]O:R!T;R!D96QE=&4`4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E
M9&ET`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!A
M9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ`%-E;&5C="!T:&4@861D<F5S
M<R!B;V]K('1O(&EM<&]R="!T;SH`4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T
M:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@97AP;W)T(&9O<FUA=#H`4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#H`
M4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.@!396QE8W0@
M=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@;F%M97,Z`%-E;&5C="!T:&4@
M:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D
M969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RX`4V5L
M96-T('=H:6-H(&9I96QD<R!T;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI
M<W1S+@!396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@;F%M97,N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396QE8W1E9"!A9&1R97-S(&)O;VL@(B5S(BX`4V5N9"!0
M<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE
M;&QE<P!3:&%R960@1&ER96-T;W)Y`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M`%-H;W<`4VAO=R`E<P!3:&]W($%L;`!3:&]W($-O;G1A8W1S`%-H;W<@3&ES
M=',`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@<&EC:V5R`%-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W
M97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET
M>0!3:')I;FL`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA
M='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC
M90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO
M=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO
M=R!D97!T:#H@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E
M;7,`4V]R="!$:7)E8W1I;VX`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E
M(&%D9')E<W,`4V]U<F-E<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V5R`%-P86-I
M;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V86YC960@
M<V5A<F-H(')E<W5L=',@=&\@87!P96%R+@!3<&QI="!C96QL`%-P;&ET(&-O
M;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R
M(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O
M<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I
M;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;
M0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`
M4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S
M>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U
M;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&%D
M9&5D("5D(&-O;G1A8W0H<RD@=&\@;&ES="X`4W5C8V5S<V9U;&QY(&%D9&5D
M("5S('1O("5S`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C<F5A=&5D('1H
M92!C;VYT86-T(&QI<W0@(B5S(BX`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S
M(BX`4W5C8V5S<V9U;&QY(&1E;&5T960@)60@8V]N=&%C="AS*2X`4W5C8V5S
M<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!R96UO=F5D("5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+@!3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S
M9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T
M`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E
M=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA
M;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W
M:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R
M;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!4
M4U8`5%-6(&9I;&4`5&%B('-E<&%R871E9"!V86QU97,`5&%B;&4`5&%B;&4@
M4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M
M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!4
M96UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L
M871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!4
M97AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3
M+38R,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL
M86)L92X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I
M;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E
M9"X@17AI=&EN9RX`5&AE(%9&4R!B86-K96YD(&YE961S('1O(&)E(&-O;F9I
M9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RX`5&AE(&%D9')E
M<W,@8F]O:R`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@861D<F5S<R!B;V]K
M("(E<R(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+@!4:&4@861D<F5S<R!B
M;V]K("(E<R(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+@!4:&4@861D<F5S
M<R!B;V]K("(E<R(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!4:&4@861D
M<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S`%1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`
M5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@8V]N=&%C="!Y;W4@
M<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+@!4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE
M<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T
M:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P
M96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@(B5S(B!H87,@<W5C8V5S
M<V9U;&QY(&)E96X@9&5L971E9"X`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92X`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE(&EM<&]R="!C86X@8F4@9FEN:7-H960@9&5S<&ET92!T:&4@=V%R
M;FEN9W,N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E
M(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E
M("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M
M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T
M96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y
M;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E
M96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED
M92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P
M<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@
M;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+@!4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D
M9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O
M;VMS(&%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N
M=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R!I<R!A;B!E<G)O
M<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`
M5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@
M66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E
M<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N
M97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&9O<B!F=7)T:&5R(&AE;'`N`%1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN
M9R!A(&YE=R!L:7-T+@!4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI
M<R!A9&1R97-S(&)O;VLZ("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R`B)7,B(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O;VLN`%1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S`%1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!L:7-T`%1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<P!4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE
M87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@861D<F5S
M<R!B;V]K.B`E<P!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E
M;G1R>3H@)7,`5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+@!4
M:&5S92!A9&1R97-S(&)O;VMS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R
M.@!4:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.@!4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II
M<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F:6QE(&9O<FUA
M="!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C
M;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<&5R
M<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O
M:P!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEL;"!B92!T:&4@
M9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG
M(&-O;G1A8W1S+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N
M($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A
M8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`
M5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@
M:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@
M*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3
M;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A
M;64@*%]T;W`I`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4
M=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO
M=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DPZ`%5G86YD80!5:W)A
M:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`
M56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S
M(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!N97<@<VAA<F4N($UI<W-I;F<@<V]U<F-E('1Y<&4N`%5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@
M(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F
M;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@
M9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5
M;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D
M92`H551&+3@I`%5N:70`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U
M<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@
M<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T
M(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N
M<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,`56YS=7!P;W)T960@17AT96YS
M:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B
M+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL
M(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R
M(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<FP`57)U9W5A
M>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R
M9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N
M`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C
M8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D
M>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S
M>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!6
M86QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L
M=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA
M`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+@!697)I<VEG;B!$:7)E8W1O<GD`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@
M*%9)4T-)22D`5FEE=R`B)7,B`%9I97<@)7,`5FEE=R!#;VYT86-T`%9I97<@
M86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W('1O(&1I<W!L
M87D@8GD@9&5F875L=#H`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN
M($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O
M;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))
M4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@
M1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A
M=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E8G-I
M=&4@55),`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I
M`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I
M;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES
M=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K($-I='D`5V]R:R!#;W5N=')Y`%=O
M<FL@4&AO;F4`5V]R:R!0;W-T86P@0V]D90!7;W)K(%-T871E+U!R;W9I;F-E
M`%=O<FL@4W1R965T($%D9')E<W,`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.
M86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E
M;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE
M<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^
M72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U
M(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A
M8W1S(&EN("(E<R(N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C
M86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="X`66]U
M(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="X`
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VYS('1O(&1E;&5T92!T:&ES('-O
M=7)C92X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I
M=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),
M('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&$@
M=&%R9V5T(&%D9')E<W,@8F]O:RX`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T
M(&QI<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T
M+@!9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(`66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI
M<R!C;VYT86-T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S
M92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@
M861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E
M<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W
M:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L
M('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K
M96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A
M<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD
M("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D
M969A=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E86)L92X`66]U<B!D
M969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X
M<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@
M=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I
M=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M
M8FEA`%II;6)A8G=E`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%MN;R!V86QU95T`7T%D;6EN:7-T
M<F%T:6]N`%]"<F]W<V4`7T-,20!?0V]N=&%C=',`7T1A=&%4<F5E`%]$96QE
M=&4`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?26UP;W)T+T5X<&]R=`!?3&ES=',`7TQO9R!I;@!?3&]G(&]U=`!?
M36]D:69Y($QI;FLN+BX`7TUY($%D9')E<W,@0F]O:W,`7TYE=R!#;VYT86-T
M`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U)E;6]V
M92!F<F]M('1H:7,@;&ES=`!?4V5A<F-H`%]3971U<`!?5&%B;&4@4')O<&5R
M=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R`&-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R
M90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O
M<@!C;VYT86-T+G9C9@!C;VYT86-T<RYC<W8`8V]N=&%C=',N='-V`&-O;G1A
M8W1S+G9C9@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R
M;6%T(&5R<F]R`&5N=')Y(&YO="!F;W5N9`!F:6QE`&9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I
M;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<@!L:6YE<UT`;6T`;F%M90!N;R!F;W)M871T:6YG`&YO
M;F4`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A
M9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R
M;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO
M=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y
M<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`=&\@82!#
M;VYT86-T($QI<W0`=&\@82!D:69F97)E;G0@061D<F5S<R!";V]K`'1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D
M`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M
M5F5R<VEO;CH@5'5R8F$@,BXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP
M,2TP-2`Q-3HP-"LP.#`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#$M,#@@
M,3`Z-3,K,#$P,`I,87-T+51R86YS;&%T;W(Z($1A=FED($-A:&YG(#QD879I
M9$!T;78N9V]V+G1W/@I,86YG=6%G92U496%M.B!4<F%D:71I;VYA;"!#:&EN
M97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4))1S4*0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"`H)7,@I-&K92D`("BGUK&V
MP>0@)7,I`"`H)7,@I-&DNBD`("BDM:31*0`@**GZI-$I`"`HK%&DT2D`MW.\
M5Z1`I;L@24U34""S<;!4O_T`IU*PHR!)35-0(+-QL%2__3H`J?,`(B5S(B"D
M=Z9SIF*FTZ5"J%.FL[;7I$JXZJ[&+@`B)7,B(*2CK$^D0*W3I=B__0`B)7,B
M(*2CK$^D0*W3IK.NQ*JZO^^^W"X`(B5S(B"I?*6\IF(@2$]21$4@JKJU^:55
MP,DH4F5G:7-T<GDII*2S7:EW+@"GY*2CJ.P@(B5S(B!T<F5E(')E;F1E<F5R
M+@`B)7,BI'>FJ*5<JKJE6Z1*J.RX<[+5J'2RSJ2D+@`B)7,BI'>E6Z1*Q7:M
MK:ATLLXN`*71J?,@(B5S(B"L3Z1`K=.X<[+5IEVFN;5,JFNS4;W&NW,N`"(E
M<R*HPZ6\J]BEWSH@)7,N`*71J?,@(B5S(B"L3Z1`K=.X<[+5IEVFN;5,JFNS
M4;=HLKXN`"*F5Z9R(*EMI/,B("BHTJ9P+B"D]*OS(+.O*0`BJ6VD\R"F5Z9R
M(B`HJ-*F<"X@LZ\@I/2K\RD`I'>HSZ7.("4N,F9-0B`LKF6V<2`E+C)F34(@
M++/1OFP@*"4N,F8E)2D`)60@)7,@I4BDSB`E<P"SS*KQI$"FN+%+O5C%W*?S
MJ?,@)60@I-&K92X`L\RJ\2`E9""DT:[PMDBY=[/X`"5S("T@L\:GT;_]`"5S
M(*O\K[X`)7,@2T(`)7,@NOO%0+[>IT`@+2"]5+M[`"5S(+-=J7<`)7,@M?FE
M50`E<R"F4+=.MK6EV``E<R"D=[=SO%<N`"5S(*1WIG.F8@`E<R"F8B`E<R`E
M<P#`R:[7("5S(*1WMM>D2J>YIJ@`)7,@I'>T3J15ID.HQK:UJKJZ^\5`OMZG
M0+1.NOPN(+W0J?.FN:[)I,2_[Z=!MU&M;K[>IT"JNK:UI=@N`*6RN]VM;B`E
M<P`E<R"DP`"GY*2CJ.P@)7,N`"`E<R"H["`E<R"F0"`E<P`E<R"JNK-QL%2_
M_0`E<ZJZIN:HQK[D`"5SJKJSQJ?1O_T`)7.JNJO=O^S#KP`E<SH@)7,`)7,Z
M(+-OJ\JK2*7SI*.D0*EWKW6ET:M(I*2JNK%(I?.D2*G2L4BU;RX@O="J8+=.
MI%6F0ZG2IK.JNKKTN/2S<[6RIK.E::_@K*JZ?*=!JKJMTZ1(N.JNQBX`+""P
M?:VW(``L(+!]K;<@)7,@)7,`+,7<I,:V<;%Q("5S(*CL("5S`"TM(+_OOMP@
M+2T`,3(@I'"NR:CN`#(T(*1PKLFH[@`R-""D<*[)J.X`I%>D0*VV`,)SQ/V^
MN:6RMK>DY+2I(&E&<F%M97,`IKFPS[;TI;*VMZUNJ_RI=[CJKL:N=Z;XJD&Z
MW2X`M6^ES:1&I$"MT\19K:NJNK_YNWX`L?VE6[%+MFRE\RS!V;O=K6ZFLZ1`
MK=,@4$=0(*2]MGVJ]\9?+@"Q_<7GP]*D=\.QL[FJNK9LI?,LP=F[W:UNIK.D
M0*W3(%!'4""DO;9]JO?&7RX`L?VXT;%+MFRE\RS!V;O=K6ZFLZ1`K=.DO;9]
M(%!'4""J]\9?+*APL4L@4$=0(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_;#UIN:V
M;*7SP[&SN2S!V;O=K6ZFLZ1`K=.DO;9](%!'4""J]\9?+*APL4L@4$=0(*KW
MQE\LI4BDSK-QP_:D9J5/+@"Q_;C1L4NV;*7S+,'9N]VM;J:SI$"MTZ2]MGT@
M4TU)344@JO?&7RRH<+%+(%--24U%(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_;#U
MIN:V;*7SP[&SN2S!V;O=K6ZFLZ1`K=.DO;9](%,O34E-12"J]\9?+*APL4L@
M4R]-24U%(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_:5;L4NV;*7S+,'9N]VM;J:S
MI$"MTR!334E-12"DO;9]JO?&7RX`I,BK9::SMK,`I,BK9:1PJT(`I,BK9::S
MJT(`I,BK9;!]JT(`I,BK9;!]L[<`I,BK92^DR*OA`$%022"]<[BY`,/VJ?.S
M;ZW3O7._Z+ZY`,/VJ?,N+BX`MVJT3:KML^:D5ZVQ`*6_I%6DZ`"EOZ2DI:$`
MQ7:MK:2CJ*PLM4RJ:ZO8I=\@5D93(*78O_TN`,5VK:VDHZBL++5,JFNKV*7?
M(%9&4R#`R:[7+@"F<ZCZ("5S(+Y$J=H`L6*XN;CJL%0`L6*XN;M0L4N]6`"Q
M8KBYI'>MX;6R+@"ULK%B`+=SO%<`MW.\5Z:XN'.RU0"W<[Q7I&S%=JVM`*9B
MIKFW<[Q7.@"W<[Q7N'.RU0"W<[Q7Q7:MK0"W<[Q7IKBX<[+5J.P@(B5S(@"W
M<[Q7IKC%=JVMIMPB)7,B`+=SO%>D0*W3J,^ESJK,.@"W<[Q7LW&P5+_]`+=S
MO%>[4*=2L*,@24U34""S<;!4O_T`MW.\5\3FINP`MW.\5\#)KM<`MW.\5Z1`
MK=.FJ*W[.@"W<[Q7N>\`MW.\5R`E<R"LL"!-;WII;&QA(*JZI,"MM@"W<[Q7
MJ.P`MW.\5ZCLJKJS<;!4O_TZ`+=SO%>H[*?:JKJS<;!4O_T`MW.\5ZC/I<ZJ
MS`"D=[=SO%<@(B5S(B"H[*ATLLZDI"X@IOVU3*IKMW.\5\-"I7ZJNK7YI56X
MZK!4.B`E<RX`I'>W<[Q7("(E<R(@J.RH=++.I*0N(*=!LGNF8J5II4BV::;F
MM6ZD2J1&+@"ITK=SO%>JNK-SM;BD2+5,KL0N`+=SO%>HSZ7.JLRJNJ5<K^"E
MV*MELU'#]K.L+@"F8:=]`+-QL%2__0#"<\3]`+-QL%2__0"S<;!4O_VXZJ[&
M+@"S<;!4O_VD=Z>YIJBR3:K%+@"G4K"CLW&P5+_](`"DH\7CI=RJNK-QL%2_
M_3H`IJBLL+K>LGJM^R`M(*RPJ.2E3*C/I<ZJS+-=J7?%=JVM`+K>LGH`O'.G
M:0"V:;:EMVJT30!!9F=H86YI<W1A;B`HJORT2::]*0!!;&)A;FEA("BJ_+JX
MI-JEIZC(*0!!;&=E<FEA("BJ_+JXI,ZG4:C(*0"V;*7SIT^F5P"Y[[OT`+GO
MN_2DZ*:A.@"ITJ:S`*G2IK.D=\7GP]*JNJC/I<ZJS`"ITJ:SN'.RU0"ITJ:S
MQ7:MK0"E?J[8O74`I+FS7*9NM%BMT[EQI&RV;*7SIF&G?0"DN;-<Q=RG\[:U
MI=B]<[BYJKJKK+I!/P"D=Z9SIF(`I'>F<Z9B`,7<I_,@24U34""U;J1*`,7<
MI_,@24U34""Q2[U8`,7<I_,@24U34""HSZ7.JLP`Q=RG\[EQI&RV;*7SINVG
M?0#%W*?SO,NJ3P"TP*5.I.6F<@!!;65R:6-A;B!386UO82`HK/S$4K#MPL2\
MKZC(*0"D0*W3M4RNQ*JZK<BS4:C/I<XN`+5OI<VD1J1`K=.EO*J^JKJ_^;M^
M+@!!;F1O<G)A("BF=[E$IM4I`$%N9V]L82`HIG>M]*G4*0!!;F=U:6QL82`H
MIG>F8ZG4KG$I`+#.IE>E3K)ZIG.H^@"UJJ[7`$%N=&%R8W1I8V$@**MNMZ6D
M:K.P*0!!;G1I9W5A(&%N9"!"87)B=61A("BF=[2CI<JN<:3.I-JZN*6LN4:N
M<2D`P+.ESK5[IJ$`P+.ESK5[IJ&R3;/F`,"SI<ZU>Z:AI'>T3KK\`*Y-I<ZH
M[*G2IK.JNJ:XID"HR0"GY:WC`+EWIO2D:J1P`*5\I.L`JORIU*="I.4@*%=I
M;F1O=W,M,3(U-BD`P*/!6<#)I&JD<`#`H\%9P,FF5[K9`*=!O52I=ZUNIU*P
MHR`E<R`_`*=!O52I=ZUNIU*PHZG2O^^^W*JZN.JNQK;<(#\`IT&]5*EWK6ZG
M4K"C("5S(*JZM?FE5;;<(#\`IT&]5*EWK6ZG4K"C("(E<R(@I4BDSJ7TIO.J
MNJ:XN'.RU2`_`$%R9V5N=&EN82`HJORNVJ?**0!!<FUE;FEA("BHR*S\I:>H
MR"D`J,BL_*6GJ,BDY2`H05)-4T-)22TX*0##P+-.`$%R=6)A("BJ_+Y\I-JN
M<2D`I,F^K0!!<V-E;G-I;VX@27-L86YD`*3EIG+#P+-.`*C(K'<OI-.EK:QV
MIF&PSP"P]:;FOMZG0+K[Q4"K9<7CI=R]5+M[N>^XW#\`I,"P=,3FINP`P'RX
MU:=2L*.D0*W3I*.F<Z9BJKJX<[+5+@#`?+C5IU*PHZ1`K=.DHZ9SIF*JNL5V
MK:TN`,!\N-6]<[_HI$"MTZ2CIG.F8JJZN'.RU2X`P'RXU;USO^BD0*W3I*.F
M<Z9BJKJF0*C)+@#$W:G*`*1+I.L`075S=')A;&EA("B_1*1JIU&HR"D`075S
M=')I82`HMOBF8:=1*0!!=71H7V-R>7-Q;#H@I^2DHZCLJ=*[W:UNJKH@:6UA
M<""IM:;YKDVE\RX`075T:%]C>7)U<SH@IOBJ0;K=J,.EO+2CJ-&XT[:UI.2T
MJ2X`075T:%]C<GEU<SH@I^2DHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RX`
M075T:%]F='`Z(*?DI*.H[*G2N]VM;JJZ($944""IM:;YKDVE\RZ]T*VKMW.]
M<\2V(%!(4""HPZ5"I5ND2B`M+65N86)L92UF='`@O^^VM2RHTJ9P(&-O;F9I
M9W5R92`M+65N86)L92UF='``075T:%]I;6%P.B"GY*2CJ.RITKO=K6ZJNB!)
M34%0(*FUIOFN3:7S+@!!=71H7VMR8C4Z(*?DI*.H[*G2N]VM;JJZ(&MR8C4@
MJ;6F^:Y-I?,N`$%U=&A?;&1A<#H@MW.\5ZC/I<ZJS+-OMK6E7*_@I=BK9:C#
MI*.DY+2II=B__:I!L,@`075T:%]L9&%P.B"G4K"CJ,^ESJK,LV^VM:5<K^"E
MV*MEJ,.DHZ3DM*FEV+_]JD&PR`!!=71H7VQD87`Z(*?DI*.H[*G2N]VM;JJZ
M($Q$05`@J;6F^:Y-I?,N`$%U=&A?;&1A<#H@M4RJ:[=SO%>HSZ7.JLP@)7,N
M(*;XJD&^N:9>P+,Z`$%U=&A?;&1A<#H@M4RJ:[*^L*.HSZ7.JLP@)7,`075T
M:%]L9&%P.B"U3*IKI_.W<ZC/I<ZJS"`E<P!!=71H7VQD87`Z(*?SMW.HSZ7.
MJLRS;[:UI5ROX*78JV6HPZ2CI.2TJ:78O_VJ0;#(`$%U=&A?;6-A;#H@I^2D
MHZCLJ=*[W:UNJKH@34-!3""IM:;YKDVE\RX`075T:%]S;6)A=71H.B"GY*2C
MJ.RITKO=K6ZJNB!S;6)A=71H(*FUIOFN3:7S+@!)34%0(*;XJD&^N<7GP]*_
M^;M^+@#%Y\/2I:*QT2X`Q>?#TJ6BL=$N("5S`%)!1$E54R#%Y\/2O_F[?BX`
M1E10(,7GP]*_^;M^+@!334(@Q>?#TK_YNWXN`*5II<ZJNL3FINPZ`$%Z97)B
M86EJ86X@**C(MNNK]+5-*0"M2;2Z`*U)M+K#0Z;B`&ME<F)E<F]S(+%+O5B_
M^;M^+@!K97)B97)O<R"HSZ7.JLRF5[K9O_F[?BX`0F%H86UA<R`HI-JKHK"H
M*0!"86AR86EN("BDVJI,*0"J:<.YJKJN_*3E("A)4T\M.#@U.2TQ,RD`0F%N
M9VQA9&5S:"`HJ7.E6ZG4*0!"87)B861O<R`HI-JHJ:9H*0"GY*2CJ.RYSZ7<
MI=B__2`B)7,B+@"P\KUU`+#RI;NW:K1-`$)E;&%R=7,`0F5L9VEU;2`HI/&G
M4:[)*0!"96QI>F4@**BIJ+VTM2D`MVJT3:KML^:D5:VQ`$)E;FEN("BHJ;GG
M*0!"97)M=61A("BFRKQ]N48I`$)H=71A;B`HI*.DIBD`LW.ULJ6BL=$Z("@E
M<RD@)7,`I<VDZ0"GY*2CJ.S`LZ7.M7NFH2(E,B1S(JJZL,^V]"(E,21S(BX`
ML,^V]+-=J7<`L,^V]*NLND$`LLK%Z0!";VQI=FEA("BLP:=1NONHR"D`KM'%
MT@"NV+UU`*[8O76D:J1P`*[8O74`0F]S;FEA(&%N9"!(97)Z96=O=FEN82`H
MJFFD:*6GJ,BDSK;"P<FM]+K[J+HI`*7^LZ$`0F]T<W=A;F$@**III;ZHNBD`
MJ;.SH0!";W5V970@27-L86YD`$)R87II;"`HI-JFZ"D`0G)I=&ES:"!);F1I
M86X@3V-E86X@5&5R<FET;W)Y`,)SQ/T`0G)U;F5I($1A<G5S<V%L86T@**A:
MM=PI`$)U;&=A<FEA("BK3Z5;IU&HR"D`MK6EV++%N+D`0G5R:VEN82!&87-O
M("BEK+18K\>J:Z_!*0!"=7)U;F1I("B[6K:IIF$I`+#3MWZDP,/^`*JIK;&Z
MWK)Z`$-20P!#4DP@I,"SH<))`+-RPDFDP+EJKN:FH2`N8W-V`,!XIG.NYJ2Z
MKF4N+BY?90"GUJCZJNRI;*3&J7REO*>YIJ@N`*;FJ,:^Y`"Y<Z_%K;<`0V%M
M8F]D:6$@**Q:KDBYZRD`0V%M97)O;VX@*+/8L\&VJ2D`M4RJ:Z;;L,JMJ[AM
ML4N]6"R]T,%PM;BG0:JZJ'2RSKK>LGJM^RX`M4RJ:[QGI$K`R:[7("(E<R(`
MM4RJ:[%.N'.RU:CLI;NHK2X`M4RJ:[-SO76FW"!)34%0(*;XJD&^N3H@)7,`
MM4RJ:[9]L=+`R:[7("(E<R(N`$-A;F%D82`HI5NNLZ1J*0"H^J[X`*CZKOBP
MW<-$IEZS^`"U3*IKIU*PH\#)KM<@(B5S(BX`I^2DHZCLO,BF<Z78O_TN`*_*
MI-8@)W1A<F=E=$9I;&4G(+#1O,:U3*IKQ'[$\K-"LGHN`+5,JFNROK"CI=B_
M_2`B)7,B+@"U3*IKLKZPHSL@)60@K=.D;+:PI'>F<Z9B+@"U3*IKK:NRU:%#
MJ=*THZC1JKJP3[_]O,:EV+M0I?VK9:G2P'BF<ZJZN.JNQJ2CLL4N`+5,JFNV
MQ[!EPK*P5*CLJ_RI=ZJZN+F]6"X`0V%P92!697)D92`HNON\=ZBD*0"[H:GZ
MI.6F<@"DP,/^NU"\T,72`$-A>6UA;B!)<VQA;F1S("BV?;#2N'.N<2D`IN:P
MRKEQN-P`P'BF<Z[FI+JN90#`>*9SKN:YU*52.@#`>*9SKN:DNJYE`,!XIG.N
MYK:AMEHZ`*;FL,JY<;C<`+;KNKBO4Z3E("A)4T\M.#@U.2TQ-"D`N&VDI`!#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,@**2DJT2F0*E-L.HI`*2DO-H@*$E3
M3RTX.#4Y+3(P`+[,P]*RT[A@`+[,P]*^UJ:SJLP`OLS#TJQ&M:8`0VAA9"`H
MK&2\=RD`I_.G[P"G\Z?OIT&JNK%+O5@`I_.G[Z=!JKJJNJ7^IE>E2*3.IEZV
M;*9AIWTN`*78JV6JNK-=J7>HPZ6\I.2TJ;%+O5C%W*?S+B"]T,%PM;BG0:JZ
MNMZR>JW[+@"F<J2X`,#+K&2S<[6R+BXN7VL`P,NL9""E_K.A+[5,7T$`0VAI
M;&4@*+2\IU$I`$-H:6YA("BDI+#J*0#"LL7II*2DY2`H1T(R,S$R*0"EO\7I
MI*2DY2`H0FEG-2D`O^^^W,"SI<ZU>Z:A.@"_[[[<I$"MTZ97NMD`O^^^W+%+
MO5@`O^^^W*1`K=.HSZ7.JLRF5[K9`+_OOMRD0*6[LW&P5+_]`+_OOMRD0*6[
MLW&P5+_].@"DZ;3!Q>.EW*3HIJ$Z`+_OOMRVM:78JZRZ0:JZK;>NY@"_[[[<
MK6[%XZ7<JKJS<;!4O_TLI,ZHY+:VI\<Z`+_OOMRM;JC/I<ZJNK-QL%2__2X`
MO^^^W*UNQ>.EW*JZQ.:F[*97NMDLI,ZHY+:VI\<Z`$-H<FES=&UA<R!)<VQA
M;F0@*+ATO<^N<2D`I^2DHZCL("5S(*JZP_ZG3ZEWN'$N`+2X`+)-L*.W3+-N
M($]F9FEC92"\T,72`+)-L*.L9+C?`+)-L*.HSZ7.JLPZ("5S`+)-L*.HSZ7.
MJLP`LDVPHZC/I<ZJS*JZN.JNQ@"QW\+@M+@`J_:WQKFKP>2E2,1^Q/(`0VQI
M8VMA=&5L;""S>KE,($A45%``P_:SK+7XM:$`MK.V<0"FK:9HMK,`L[$`0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',`I^G%?+CJKL:GJ`"GZ<5\P^2LR0!#;VQO
M;6)I82`HK?2MVZ3QJ,@I`,-#IN(`O=6FXKU,`#$VMFFF[,-#IN*E3KU8`,3F
M.@#$YJ;LO^^VM0#$YJ;LO-##1`"DH\7CI=RJNL3FINRF5[K9.@"E9+-Q`+-R
MPDFDP+EJK<@@*"HN8W-V*0"S<L))I,"Y:JW(("A-:6-R;W-O9G0@3W5T;&]O
M:R`J+F-S=BD`J5*E3P"GY::XJ5*E3P"U^[W7`+K9J4D`0V]M;W)O<R`HK.R\
MK\.Y*0"DO:5Q`*2]I7&F8:=]`+EQN*,`P/2YT@"Q^*7S`*YTLJ<`NU`@4$1!
M(+1XI%>KK+EQN*,LM+R\>JNLI.*^]Z5(I,X@3W5T;&]O:R"JNJ90J$*S7:EW
M+@"S7:EWN.JNQKE,M,$N`+-=J7<@)7,`O52[>[%+O5@`0V]N9V\@**WHJD<I
M`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4@**WHJD>F
M0*E-L.HI`+-SM;*EHK'1+@"S<[6RI:*QT3H@`+-SM;*EHK'1.B`E<P"S<[6R
MI:*QT0"S<[6RIMRDO;9]JO?&7Z;XJD&^N:[)OD2IVBX`LW.ULJ;<I+VV?:KW
MQE^F^*I!OKFNR;Y$J=HN(*WLIETZ("5S("@E<RD`LW.ULJ;<($944"#`R:[7
MIOBJ0;ZYI:*QT2X`LW.UN*1(MVJT30"S<[6XI$@`N'.RU3H@)7,@I*2JNK-S
MM;BD2`"P3[_]I'>FJ*5<IF&W<[Q7IMRG0:JZLW&P5+_]I*0N`,"CP5G`R:[7
MJKJDNJYEJZRZ03H@`"(E<R(@P,FNUZ2ZKF4`Q'[$\@!#;V]K($ES;&%N9',@
M**SLITJX<ZYQ*0"]QKMS`+W&NW.EHK'1.B`E<P"]QKMS`$-O<W1A(%)I8V$@
M**WTM+6D:KZDI5LI`$-O=&4@9"=)=F]I<F4@*+9(I/JN_*FD*0"U3*IKI4@@
M4$=0(*5;L4NV;*7S.B``M4RJ:Z5((%!'4""P]:;FMFRE\\.QL[DZ(`"U3*IK
MI4@@4R]-24U%(*5;L4NV;*7S+@"U3*IKK+`@4R]-24U%(+9LI?/#L;.Y+@"U
M3*IKMW.\5[-SM;BD2"X@)7,`M4RJ:\.TM;(@3$1!4""F^*I!OKD`M4RJ:\.T
MM;(@;&1A<""F^*I!OKD`M4RJ:\#+K&2W;*]Q+B`E<P"U3*IKLW.ULJ;<(&QD
M87`@IOBJ0;ZY`+5,JFNS<[6RIMRF^*I!OKD@(B5S(B"HSZ7.($944#H@)7,`
MM4RJ:ZO8I=^P=+AMN'.RU2X@)7,`M4RJ:[C1L4L@4$=0(+CJKL8Z(`"U3*IK
MN-&Q2R!3+TU)344@N.JNQBX`M4RJ:Z=2L*.S<[6XI$@N("5S`+5,JFNG4K"C
ML'2X;;)-L^8N("5S`+5,JFNG4K"CI_.W<[5[IJ$@(B5S(BX`M4RJ:ZA-J7>F
MK*7SI$BJNKEQI&RV;*7SINRG?2X`M4RJ:\#RJ/JGN;[CJKJS<;!4O_TN`+5,
MJFO`\JCZI[F^XZJZL'2X;;)-L^8N`+5,JFO`\JCZL'2X;;)-L^:DI*JZN'.R
MU2X`M4RJ:[C\I$JUIK*D("(E<R(N`+5,JFNKV*7?I=B__2`B)7,B+@"U3*IK
MIMNJ]\9?IOBJ0;ZYJ/JQ;Z2]MGVJ]\9?+@"U3*IKMGVQTB`B)7,B(*5(O&>D
M2BX`M4RJ:[9]L=(@)7,N`+5,JFNV?;'2NOO%0*1UIT"\TK+5("5S`+5,JFNV
M?;'2I=B__2`B)7,B+@"U3*IKLW.QM2!,1$%0(""F^*I!OKDN`+5,JFO%JJCZ
M("5S+@"U3*IKK:NW<[-=J7>HSZ7.JLRJNK%+O5@N(+.AI,"JNK+3N&"DHZ6_
MO50N(+W0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BX`M4RJ:\6JJ/JF
M<ZCZL;&H[JKM*$%C8V5S<R!#;VYT<F]L($QI<W0I`+5,JFO%JJCZLW&P5+_]
M+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E
M<P"U3*IKQ:JH^J;XJD&^N:JZK-O#]J]3J<H`M4RJ:Z9>M%^S7:EW+@"U3*IK
MIU*PHZ78O_T@(B5S(BX`M4RJ:\!XIG,@)7,@JKJS7:EW+@"U3*IKP'BF<[/&
MI?>S7:EW+@"U3*IKP'BF<[/&I?>S7:EW.B`E<RX`M4RJ:\!XIG.G\[=SM7NF
MH:CL.B`B)7,B+@"U3*IKP'BF<[/&I?>S7:EW("5S+@"U3*IKP'BF<[-=J7?`
MR25S+B"G0:5II4BHSZ7.)7.DI*JZJ.2E3*5<K^#`>*9SLUVI=ZG.I.*PRKW&
MNW.D5:VQM7NFH;U8J.P@)7,N`+5,JFNW:K1-($Q$05`@(*;XJD&^N2X`M4RJ
M:Z=2L*,@(B5S(BX`M4RJ:Z?SMW.S<[6XI$@N("5S`+5,JFNG\[=SL'2X;;)-
MI54N("5S`+5,JFO"T+QG("(E<R(Z("5S(*JZLUVI=RX`I^2DHZCL($UO>FEL
M;&$@JKJDP*VV+B"]T+U4NWNDP*VVK$^G7[9]L=(N`+5,JFN]X:2IJ,^ESJK,
M("(E<R(@I%6F0\5VK:VH[*M(I?.G6"`B)7,B.B`E<P"GWK-.I7D`L.JN80"]
MTJKM`*O8I=\`J]BEW[-QL%2__0"KV*7?I$"MT[-SM;(`IF*D5:9#LW&P5+_]
MJ]BEW[=SN'.RU3H`J]BEWZ1`K=.W<ZJZ`*O8I=^FN*M(I?.G6`"KV*7?`*O8
MI=^JS*JZQ7:MK0"K2*7.I62XN;U8`$-R;V%T:6$@**=*P[FFZ*C(*0!#=6)A
M("BE:J3:*0"EV*MEMWRTP0"EV*MEKLFVH0"EV*MENO2G?0"EV*MEJKJHSZ7.
MJLP`I=BK9:31KO``I=BK9:JZJJRJ<#H@`*78JV6JNJVWKN8`IMNM<:1`J,>U
M;J1*)7.KX:G2K6ZP]:;FJKJD=:=`+@"PQ:15`+#%I%4`0WEP<G5S("C!R;2V
ML,>TM2D`INBHO;JXI.4@*$M/23@M4BD`INBHO;JXI.4@*%=I;F1O=W,M,3(U
M,2D`INBHO;JXI.4OKU&G2L3UI.4@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,@
M*+&VITJF0*E-L.HI`*3I`+CJKL:HT[>]IE>ZV2`HO="PT:;2(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT
M<F\M9'-N+G!H<"D`J$.DZ0"^\*JLN.JNQL)SQ/T`N.JNQJYWMVJT30"DZ;3!
M`*:LJ.RDZ;3!`+_OOMRDZ;3!`*75I-$`IU*PH\3FINQ?;`"D4:1'I.L`I%&V
M::;LO,:F<@"T[J36P5FQQ@"Y=[-=`+EWLUW#0Z;B`+EWLUVJNJBMI??#T:=/
M`+EWLUVI4J5/N-&J4KZY*%-H96QL*0"Y=[-=L<:GQZ3HIE8Z`*EWN'$`IU*P
MHP"G4K"CLW&P5+_].@"G4K"CP'BF<Z[F`*=2L*.]5+M[`*=2L*.X<[+5`*=2
ML*.L]K_]`*=2L*/%=JVM`*=2L*.A0K)-JL6V;*7S`*=2L*.K]K9SJKJFYJRP
M`*=2L*/`>*9SKN8`IU*PH\3FINP`IU*PH[)[IG.JNK3`I4Z\RZI/`*=2L*.E
MHK'1.B`H)7,I("5S`*=2L*,B)7,BJKK%=JVM`+U4J7>M;J=2L*,B)7,BJKK%
M=JVMI4BDSJ:XQ7:MK2`_`*=2L*.F0P"G4K"CJ=*_[[[<JKJHK:7WP]&G3[CJ
MKL8`IU*PHZ78JV6JNL3FINP`IU*PHZ78JV6JNJ9#`*?SMW.U>Z:A("(E<R(@
MI'>G4K"C+@"ITJ=2L*.JNK-SM;BD2+5,KL0N`*=2L*.EHK'1`+N\L&6NR;:A
M`$1E;FUA<FL@**2FL\$I`+.AJOD`K;"^K0"PW<-$M'FM>@"T>:UZ`++3N&`@
M*+W0L-&FTB!(;W)D92"P3[_]P,FNURDZ`++3N&"]T+#1IM*H=++.NMZR>K5N
MO_TN`*SCM6\`Q5/"2;?%J]<`L\RKX:1`I'"NR:JZQ5/"2;?%J]<Z(`#%4\))
MM\6KUSH@`+%QI:JFW*5K`+%QI6NFW*6J`*78O_T`Q>.EW`"E2"`R-""D<*[)
MJ.[%XZ7</P#%XZ7<O^^VM0#%XZ7<N-2RTZJZN7>S^`#%XZ7<N7>S^"`H5$%&
M*0#%XZ7<KN:FH0"VQ[!EIEZQ^`!$:FEB;W5T:2`HIDZEK*9A*0"DHZ=2L*,`
MI*.M;JJ]L;6F<ZCZ(&UA:6YT96YA;F-E+G!H<`"G4K"CL$^__:[)K$^G7[O=
MK6Z]5+M[(#\`LL2D0+6GL$^__:Q/IU^E7:=TQ.:F[*97NMD_(*9PJD>L3[W0
MI,2_[RX`1&]M:6YI8V$@**9HJ?JEIZ5;*0!$;VUI;FEC86X@4F5P=6)L:6,@
M**9HJ?JEIZ5;ID"I3;#J*0#!V:A3IK.Q8KBYMMP_(+7YI54N`*15N/P`I%6X
M_"`E<P"D5;C\LUVI=\#)KM>E=*9SK+`@4$A0(+5[IJ$N`*15N/P@=D-A<F0`
MI%6IU*5<K^"J[0##Q*M^`+EQI&RV;*7S`+_YNWX`16-U861O<B`HI,RERJ9H
MNK@I`+USO^@`O7._Z"`B)7,B`+USO^BS<;!4O_T`O7._Z+#/MO0`O7._Z+AS
MLM4`O7._Z,5VK:T`O7._Z,5VK:T`O7._Z"5SJKK%=JVM`+USO^BP3[_]("5S
M`+USO^B_[[:U`+USO^@B)7,BJKK%=JVM`+USO^@E<ZJZQ7:MK0"QT*A\`$5G
M>7!T("BN2J3.*0!%;"!386QV861O<B`HPL2ZN*7+IF@I`*2XI?,N+BX`N7&D
M;+9LI?,`N7&D;+9LI?.F[:=]`+EQI&RV;*7SINVG?:6RMK>G:Z98+@"Y<:1L
MMFRE\[U4NWL`16UA:6PM=&\M4TU3(+EHN42^N0"J[;&ALL6XN0"JQ:75JTBE
M\RX`JL6EU;6RJD<N`*K%I=6W:K1-MK6EV`"DN;-<IMO#P+19M*&D2K?3I/FH
M[*M(I?.DI"BZ]*VVO7.\9[S2IJ$I(#\`L=*PRK?&N:NE:\'DI5ROX*KM/P"U
MLJ?TIGZE]P"I\:1JO7._Z+ZY`*9PJD>G0;O=K6ZMJ[-=L4N]6"R]T+_II$JD
M0*W3IG>E_K#=I7DLJ-*F<"`GIT'#9*JKJKJF5[K9(#\G.@"F8J:YO^FD2KQV
MN;.JNKKTIWT`)7.JNK!/O_VD=Z?SMW,LIOW`>*9SI%>VQ\#)KM>NR:6BL=$Z
M)7,`)7,@JKJP3[_]I'>G\[=S+@!%<75A=&]R:6%L($=U:6YE82`HJ*JY1+18
MI+JHR"D`17)I=')E82`HI,REWZ]3J+VF=RD`O_F[?@"W<[Q7("5D(*W3LW.U
MN*1(J.RX<[+5I*2NR;5OI<V_^;M^+@"W<[Q7LL0@)60@K=.F0"`E9""MT[-S
MM;BD2*CLN'.RU:2DKLFU;Z7-O_F[?BX`J]BEW[#/MO0E<Z[)M6^ES;_YNWX`
MIU*PHR`E9""MT[-SM;BD2*[)M6^ES;_YNWXN`*=2L*.RQ"`E9""MTZ9`("5D
M(*W3LW.UN*1(KLFU;Z7-O_F[?BX`IU*PHZ90J$+!X\)).B`E<R"NR;5OI<V_
M^;M^`*=2L*.F4*A"L$^__3H@)7,@KLFU;Z7-O_F[?@#%JJCZI+JN93HE<R"N
MR;5OI<V_^;M^`*;;N'.RU:2DLKZPHR`E9""MT[-SM;BD2*[)M6^ES;_YNWXN
M`*;;N'.RU:2DLKZPH[+$("5D(*W3ID`@)60@K=.S<[6XI$BNR;5OI<V_^;M^
M+@"W:K1-LW&P5+_].B`E<R"EHK'1`*?SMW.Q2[U8.B`E<R"NR;5OI<V_^;M^
M`+QGI$H@(B5S(B"NR;5OI<V_^;M^+@!%<W1O;FEA("BW4JA&I:>HR"D`171H
M:6]P:6$@**;GK\&D\:C(*0"ZV+':`$5U<F]P92`HO-JL=RD`J$,@,34@I,#$
MP0"H0R`R(*3`Q,$`J$,@,S`@K.W$P0"H0R`U(*3`Q,$`J$.FN+5NI$H`J$,@
M,S`@I,#$P0"H0R`Q(*3`Q,$`O62HTJW(.@"P]:;F`*YIMGT`KFFV?;CJKL:G
MJ`"M;JA$("<I)P"H[+3!I.D`N-&[H:W[`+;7I5@`MM>E6+-QL%2__0"E=;;7
MI5BD=[_OJ/JJNK-SM;BD2"X`I[F^X[;7I5BD5:9#LW&P5+_]+@"K9;2ZPT.F
MX@!&5%`@I%>VQ[-=J7<N`,6JJ/JPOJ9NLUVI=Z6BL=$`IG.H^K-QL%2__3H@
M)7,@I:*QT2X`MW.\5R`E<R"H["`E<SH@)7,`PG/$_;ASLM6EHK'1`+=JM$VE
MV+_]I:*QT0#%W*?SIE>ZV:6BL=$Z*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE
M=R!$3B`]("5S+"!2;V]T(#T@)7,`M4RJ:[-SO76FW"!,1$%0(*;XJD&^N2X`
MM4RJ:[-SO76FW"!334(@IOBJ0;ZY+@"]QKMSI:*QT:;;("(E<R(N`+W&NW.E
MHK'1J.P@(B5S(BX`M4RJ:ZO8I=^D0*W3MW.JNB!305-,(+-SL;4N`*?DM$VJ
MJZ7SI4BW<[Q7J.PZ)7.EHK'1`+=HLKZEHK'1J.P@(B5S(BX`PEZH^J6BL=$Z
M("5S`+=JM$VS<;!4O_VEHK'1`+=JM$VEV+_].B`E<R"EHK'1`+2VLW$`1F%L
M:VQA;F0@27-L86YD<R"J:\3UITJZUKASKG$@*+"HNKBZ^Z_'M+6X<ZYQ*0!&
M87)O92!)<VQA;F1S`,19K:N_^;M^.@"VQZ]U`+;'KW4`I$>DZP"W4,2Q`+=0
MQ+$Z(`"D\J3RJT(`M76\R+!]L[<`Q.:F[+!]ID,`1FEJ:2`HM+3`V2D`P,FN
MU[S&I=@Z("5S(*W3P,FNUP#`R:[7O,:EV#H@)7,@P,FNUP#`R:[7P6"ZW@#`
MR:[7IE>ZV0#`R:[7O^^^W`#`R:[7I%>VQP#`R:[7I%>VQZ5<K^"EO+-1I.2T
MJ2X`JOZE\P"Y3,)OOKD`M$VGY`"GN::H`$9I;FQA;F0@**KBQ/4I`*17I6*D
MZP"F5Z9R`*17J;8`J52I=Z3QJ-(`I%>D5<1!K<L`KT*PR@##^@"EV+_]("5S
M(*2CIG.F8@"F<JNLPT.FX@"MN:JK`*9=K+#"<\3]OKFHPZ6\I.2TJ;QVN;.E
M7*_@+@"N\+9(N7>S^"`H5$%&*0"Y=[/XI-&\QB`HN7>S^*31O,:E7:Q!I=6D
MT:5(I,ZI7;:AJKJXZJ[&.Z9PJD>Y=[/XI-&\QKC[JOBQ3J;[I<ZD\;C[O&6T
M5*JZJJFML2D`I]&P3[%+O5@@/P"J[;/F`*1PNWD`I'"[></^JZP`I'"[>0"D
M<+MY(#(`O=>^P@"FV[#*PN"K2`"L4+3!I*T`KMBL6P!&<F%N8V4@**IKL.HI
M`$9R86YC92P@365T<F]P;VQI=&%N`$9R965B=7-Y(+KTIWT`1G)E;F-H($=U
M:6%N82`HJFO$W;M<J,BHNBD`1G)E;F-H(%!O;'EN97-I82`HJFO$W:S!IU&E
MIZ;HJ,@I`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P"Q<0"Q<0"GN;[C
MM'FM>@"ZH:3K`*7^IE<`1V%B;VX@**5;M%XI`,/`M%DZ`$=A;6)I82`HI<RD
M\:C(*0"RHZ7-("5S(*W3J'2RSK-=J7<`I'>RHZ7-JKJS7:EWN.JNQ@!'96]R
M9VEA("BS[*IVJ,BF0*E-L.HI`$=E<FUA;GD@*+QWL.HI`$=H86YA("BM>Z_'
M*0!':6)R86QT87(@**J]I:S#N:K[*0"F5[K9`*7^L.RS<;!4O_T`JV6IN0"M
M]+QWNK@`1V]O9VQE(*9AN<\`1V]O9VQE(+=JM$T`IL>VI0!'<F5E8V4@**?&
MP[XI`*?&P[ZDY2`H25-/+3@X-3DM-RD`1W)E96YL86YD("BNYK.NQ/6N<2D`
M9W)E;F%D82`HKN:WYZ_'N48I`+ASLM4`N'.RU;K>LGH`N'.RU:97NMFDH[%O
MJL6EU0!'<F]U<%]L9&%P.B"U3*IKMW.\5[ASLM4@)7,N(*;XJD&^N:9>P+,Z
M(`!'<F]U<%]L9&%P.B"U3*IKIU*PH[ASLM4@)7,`1W)O=7!?;&1A<#H@M4RJ
M:Z?SMW.X<[+5("5S`+ASLM4`1W5A9&5L;W5P92`HK?2\=ZREM+8I`$=U86T@
M*,/VKG$I`$=U871E;6%L82`HI<JF8;"HJ=0I`*[FKJ:FZ*YQ`*C3NZO%=JVM
M`+-8J\BO9*BE`$=U:6YE82`HM%BDNJC(*0!'=6EN96$M0FES<V%U("BT6*2Z
MJ,BD\:_!ID"I3;#J*0!'=7EA;F$@*+M<J,BHNBD`ME>DY;-SM;*[>:BE`*?D
MI*.H["!(5%10(,7GP](N`$AA:71I("BN_*9A*0#"^+3J+;ITNN(`QD<`JNW`
M60"J[<!9`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P"D:KEP
MJT(`I\:G0JC3I.4@*$E33RTX.#4Y+3@M22D`L*JKUP"[H:GZ`+USO^B^N:C/
MI<Z[H:GZ`+NAJ?H`I6*R>0"S;[C,K$_`R:[7JKJV?:EL.@"PJ@"N85]M`$AO
M;'D@4V5E("BQZ[_-J:,I`*YA`*;MKF&F8:=]`*;MKF&ITL3=J["EJP"F[:YA
MJ=+$W;#JKF$`KF&EV+_]`*;MKF&Y<;C<`*;MKF&V;+N\L,^XN0"F[:YAJ=+$
MW:S9I?<`INVN8:;MIWT`2&]N9'5R87,@**>[LZ.IU+2U*0!(;VYG($MO;F<@
M**V[M.0I`$AO<F1E`$AO<F1E+TMO;&%B.B"V;*7S("4R)',@I*2Y2JCLM4RN
MQ*JZ("4Q)',@6$U,N.JNQ@!(;W)D92]+;VQA8CH@M4RV;*7SOD&F6*JKI?,@
M)7,`2&]R9&4O2V]L86(Z(+9LI?,@)3(D<R"DI*?DI*.H[*JKI?.KK+I!("4Q
M)',`2&]R9&4O2V]L86(Z(*1WIJBE7*JZLKZPHR`E<R`B)7,B`$AO<F1E+TMO
M;&%B.B"^XZ98I'6U>[O=K6X@)V1O;7AM;"<@JKH@4$A0(*FUIOD`2&]R9&4O
M2V]L86(Z(+5,JFNKV*7?("5S(*JKI?.JNB!834P@OO``2&]R9&4O2V]L86(Z
M(+5,JFNROK"C("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B"U3*IKP/*H^K.A
MI?<@)7,@JZRZ0:JZ($U)344@P]&G3[BYO5@`2&]R9&4O2V]L86(Z(+5,JFNF
M4*A"("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B"U3*IKIE"H0J3`J,DZ("5S
M`$AO<F1E+TMO;&%B.B"EO*J^JKJDP*C)("(E<R(`I/2EK;UU`*3TI:VYU*52
M`*3TI:TZ`*=!IG"F\ZCLIKD@/R`HO="QU*UZ(2D`IT&M;J98J-:F:*36K=/$
MYJ;LJ4\_`,3FINR\QJ78ID"M<#\`IT&M;J98J-:F:*36ID.I3S\`M\.KUP"W
MPZO7.B``M\:]7:1JKG8`2'5N9V%R>2`HIDFD^J=1*0!)34%0(+9LO6.KV*7?
MI:*QT3H@)7,`24U!4""V;+UCIU*PHZ6BL=$Z("5S`$E-05`@MFR]8[K/NM"P
M=+AMJ]BEWZ6BL=$Z("5S`$E-4U``24U34""S<;!4O_VZWK)Z`$E0(*;LIWT`
M25`@INRG?;5,JFNHSZ7.+@!)4""F[*=]J,.DHZ9B($-)1%(@JKJDN;-<L,^V
M]*2D+@"F8JOAK;&TH:1*ID-?;@!)8V5L86YD("BF0JYQ*0"OPKG/I=P`)7.J
MNKG/I=P`N<^EW*3.I.6F<@##T:=/N+F]6`"HK:7WP]&G3ZJZIE>ZV3H`IG"J
M1[5,JFNEO[U4IF'%XZ7<+"`E<R"E2*5TMGVQTK9LI?.I\[=SM?BUH;?MI*0N
M`*C/I<X@26YT97)N970@17AP;&]R97(@PG/$_;ZYKLFF<*I'J%.FLZS=J.RE
M]*;SJKJD<+G/I=PL(*=!I6FOX+O=K6ZDQ+_OLV^MT[:UI=BE2,/VLZP@4$Y'
M(+QVN;.JNL'TPL.NQ*I'+@"F<*I'K-VH[+-OJVBH4Z:SO':YLZJZL%2NIRRS
M;ZKMI=RG0:JZPG/$_;ZYM4RJ:\7CI=RD5[;'JKJ\=KFS+@"\=KFSN7?$_3H`
MO':YL[KTIWT`O':YL[KTIWTZ`+QVN;.HTZ;;P\"T60"\=KFSJ-.FV\/`M%DZ
M`*17ML>\=KFS`+QVN;,`MM>D2K-QL%2__2P@J$+&2B`E9`"VUZ1*+""H0L9*
M("5D`+;7I$HOMM>E6""S<;!4O_T`MM>D2L3FINPZ("5S`+;7I$K$YJ;L.@"F
M8JOAK;&TH:1*ID-?<P"_Z:1*I*.EO[U4JKJG0*7.O5@N`+W0P,NL9*=!JKJH
MSZ7.JLRF5[K9I,ZQ2[U8`*C/I<ZJS*97NMFDHZ6_O52ISJK,N7&D;+9LI?.F
M[:=]I'?%W*?S+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BX`O%>E
M6\%9L<8`26YD:6$@**9,J]<I`*W3IT^HSZ7.JLP`26YD;VYE<VEA("BF3*6G
M*0"XZK!4`+CJL%0`M4RE::7.JKJXZK!4+@"F8JOAK;&TH:1*Q.:F[%]O`+2A
MI$JYSZ3Y`+2AI$JJ[:[F`+2AI$JZ]+CTLW.UL@"F8JMEK;&TH:1*Q.:F[%]#
M`*9BI=BK9<3FINRKX:VQM*&D2J1`K=.W<\3FINP`IF*EV*MEQ.:F[*MEK;&T
MH:1*I$"MT[=SQ.:F[`"F8J78JV6F0ZOAK;&TH:1*I$"MT[=SID,`IF*EV*ME
MID.K9:VQM*&D2J1`K=.W<Z9#`*9BI=BK9;A@PDFKX:VQM*&D2J1`K=.L<;BH
M`*9BI=BK9;A@PDFK9:VQM*&D2J1`K=.L<;BH`+2AI$JE:;3`I4Z\RZI/`+=S
ML4N]6+%.L4BU;ZCLLV^MT[9LI?.F8:=].@"F8JOAK;&TH:1*P'BF<Z[F`*9B
MJV6ML;2AI$K`>*9SKN8`IF*KX:VQM*&D2L3FINP`IF*K9:VQM*&D2L3FINP`
MM*&D2K9LI?,`IF*KX:VQM*&D2JQQN*@`IF*K9:VQM*&D2JQQN*@`IF*KX:VQ
MM*&D2J9#`*9BJV6ML;2AI$JF0P"F=Z7^L-VE>:JZM:JNUSH`M*&D2B_%W*?S
MO':YLP"TH:1*+\7<I_.Z]+CTLW.UL@#"2;S&I*.HK*5(IMRI\[5,JFNVQ[!E
MM;FP=+AMN'.RU2X`PDF\QJ2CJ*PN`+[CO,8`ON.\QJ9#`+5,KL2JNKUSN+D`
MM4RNQ*JZ(%5$2"BHSZ7.JLRXZJ[&JNW`62DN`+5,KL2JNB!:25`@N.JNQBX`
MM4RNQ*JZLW&P5+_]+@"U3*[$JKK`LZ7.M7NFH2X`M4RNQ*JZI^6FN+BYO5@N
M`+!EI5BJNKCJKL:U3*[$+@"U3*[$JKJEV+S0INVG?0"U3*[$JKJY<:1LINVG
M?2X`M4RNQ*JZL$^__0"U3*[$JKK`R:[7KN:FH0"K_*EWJKJJ]\9?M4RNQ`"U
M3*[$JKJQPL5VO5@N`+5,KL2JNJ9AL,\N`+5,KL2JNB!M<V=?='EP92X`M4RN
MQ*JZIE>ZV0"U3*[$JKJDP*C)JJNE\RX`M4RNQ*JZJ<ZGY*2CJ.P@87!I7VED
M+@"U3*[$JKJISJ?DI*.H[+#1O,8N`+5,KL2JNJ3WQ7:MK2X`M4RNQ*JZN=FF
M\</1IT^]6"X`M4RNQ*JZLJ.K?KU8+@"U3*[$JKJS<;!4J/.I=RX`M4RNQ*JZ
MIJRE\Z1(.B(E<R(`M4RNQ*JZI,"HR:JKI?,N`+5,KL2JNJC3M[VF[:=]+@"U
M3*[$JKJX5;#JO5BXZJ[&+@"XZK*C`*9>M%^_[[[<`$ER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8@**7LKM0I`$ER87$@**7LJ=2G2BD`27)E;&%N9"`HMU*Z
MN,3U*0!)<VQE(&]F($UA;B`HL-*N<2D`I[VSH;EPJT(`27-R865L("BE2*;B
MID,I`,.QM6^JS`"QU\7I`$ET86QY("BX<:1JIU$I`$IA;6%I8V$@**3ZME*E
M6RD`I$"DZP!*87!A;B`HI.FENRD`I.FDY2`H25-/+3(P,C(M2E`I`+]!INBN
M<0!*;W)D86X@**SYI;DI`*1#I.L`I+NDZP"Y[[OT`+AMI*0`I:JE:[GON_0`
MOF&EJKGON_0`OF&E:[GON_0`2V%Z86MH<W1A;@"K3Z]DK>R\RR`_`$ME;GEA
M("BJUJC(*0!+97)B97)O<R"[>\/2O_F[?BX`KM:DW[=SI.(`JO?&7ZO8I=\`
MJO?&7Z]3O'@`JO?&7ZKXJ]<`JO?&7ZNLND$`JO?&7[MYJFL`I=BK9:JZI+VV
M?:KWQE^F^*I!OKFDI"RD=[AGIG.F8J=!JKJJ]\9?+@"HX+6C`$MI<FEB871I
M("BP\JB]I-JTM2D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8@**5?P?HI`$MO<F5A+"!297!U8FQI8R!O9B`HJV[!^BD`P?JDY2`H
M155#+4M2*0!+=7=A:70@**SLJ\*O4RD`2WER9WEZ<W1A;@"ELK:WK6ZFLR!,
M1$%0(*JZI.2TJ2RF_:Q/($Q$05`@O-*RU:2CK$^EO*9WN,NT3JQ/J%.FL[C\
MI$HN`*JIK;&P=+AM7WD`NWFHI0!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8R`HO&2PZBD`I%6E8J3K`+/,JO&D0*:XI_.W<P"I;0"SS*KQI$"F
MN+%+O5C%W*?SJ?,`I%6IMJ3K`*17IKBG\[=S.@"D5Z1`IKBU;J1*.B`E<P"D
M5Z1`IKBU;J1*.B`E<R"FVR`E<P"D5Z1`IKBU;J1*.B"RQ*1`IKBU;J1*`$QA
M='9I82`HJ=2RYKK[J,@I`*IKJ]\`JJFML;!TN&T`3&5B86YO;B`HOJ2DVKG@
M*0"EJL/D`*6JP^2J[<!9`*6JP^2MR`!,97-O=&AO("B_X*_!IJLI`$QI8F5R
M:6$@*+_@I/&WYZC(*0!,:6)Y86X@07)A8B!*86UA:&ER:7EA("BG4:3QJ,@I
M`$QI96-H=&5N<W1E:6X@**9#I.2TL+2UM6XI`+=,JT(`I'"K0@"FK::SI'"K
M0@"QWZ:SI'"K0@"D<+!]JT(`I'"K0J:SN7``I'"SMP"D<+!]L[<`I;2J;[C6
M`+-SM;(`LW.ULL))J.PZ`,7CI=RNR;-SM;*V;*7SINVG?:CLO7.\9[9LI?.M
MMJVQ`+-SM;(`LDVSY@"F0Z58("T@J,^ESJK,I6FE2*S=J.RS;ZW3JTBE\Z=8
M`*9#I5BXZJ[&KG<`ID.E6+NAJ?J\T,-$`*9#I5BJ[:[F`+!1O=>X<[+5+<#)
MKM?"9`"P4;W7N'.RU2VH1*=5`+!1O=>X<[+5+</1IT^XN;U8`+!1O=>X<[+5
M+;[6IK.JS`"P4;W7N'.RU2VQ2*7SI$@`L%&]U[ASLM4MK7&^7`"P4;W7N'.R
MU2VH^J[XK7&^7`"F0Z58MWRTP:6BL=$Z("5S`*9#I5BHSZ7.JLREHK'1.B`E
M<P"F0Z58J,^ESJK,JKJE7*_@LU'#]K.L`*3EOL<`3&ET:'5A;FEA("BEW[.S
MJ7LI`+C\I$JDI"XN+@"W[:9AKLFVH3H@`*9AL,^[4*[)MJ$`IF&PSP"U;J1*
M`+5NI5@`M6ZD2@"U;J1*I'6G0`"U;J1*I:*QT2P@O=#`RZQDN]6D5:JZI<ZD
MX:97J4VQ2[U8+""U3:OAK:NXU2X`M6ZD2J6BL=$N`*KXI7D`MU*QH0"G0P"D
M<+QGI\;#OKS&IG(`I'"\9ZG4I$*\QJ9R`*1PO&?#N;"HO,:F<@!,=7AE;6)O
M=7)G("B_8[3+L_DI`*3K`*A#I.FP5*ZG`$U3+51.148@JOZE6\#)KM>DI*A3
MIK.XZJ[&+@!-4T<`36%C86\@*+]$JODI`$UA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9B`HL*BHY+EYID"I3;#J*0!-861A9V%S
M8V%R("BPJ+E&I5NTM:5;*0#%7;-.`+9LI?,`MFRE\[K>LGH`J]BEW[-SM;)?
M:RXN+@!-86QA=VD@*+"HJ=2KPBD`36%L87ES:6$@*+"HJ-.FZ*C(*0!-86QD
M:79E<R`HL*BZN*9AI-(I`$UA;&D@*+"HIU$I`$UA;'1A("BPJ+JXI4PI`+K>
MLGJG0:JZI,##_BRHPZ5"K+"DP,/^LUVI=\-#IN(N`$UA<#(T(*9AN<\`36%P
M475E<W0@IF&YSP"D5*3K`,/DK,D`O-"P3Z:H(*S=N4POI;RLW;E,`+S0L$^F
MJ*CDI4RJNL/1IT\@**C2IG`N(*VKK6XOI'>F7L+0*0!-87)S:&%L;"!)<VQA
M;F1S("BPJ*Y,NKBX<ZYQ*0!-87)T:6YI<75E("BPJ+2CI:>G2JYQ*0"DQ[!T
M`*3'L'3$YJ;LI*0`36%U<FET86YI82`HK52G4;;PI:>HR"D`36%U<FET:75S
M("B\KZB]INBTM2D`I+FS7*JZL\RD:L))O,8N`*K^I?.\QJ78I'>V5Z58I+FS
M7*17K:TN`+/,JO$@,C0@I'"NR:JZL\RPJK?%J]<Z(`"SS*KQ(#8@I'"NR:JZ
ML\RPJK?%J]<Z(`"S<[6XI$BD5ZVMO,:EV`"PS[;TI%>MK;S&I=@`I+FS7+/,
MI&JJ^*O7`*VVO,:D5ZVM`*2MI.L`36%Y;W1T92`HL*BL^:]3KG$I`,+EOL<`
MIJBM^P"E7*_@JNT`O^^SYKS2IJ$Z`*98J-;`>*9SKN8`MFRE\P"V;*7SQ>?#
MTJ1WI[FFJ"RF_:Q/J,^ESJK,JKK#L;.YJV^U3*IKLW&Y3,7GP](N`,*RL%2D
M=[E,M,$N`,*RL%2KK+I!`$UE=&%R(+#/MO2U3*IKJ,^ESBX`365T87(@L,^V
M]+5,JFNHSZ7.+B"RT[A@O="PT:;2J'2RSKK>LGJU;K_]+@!-971A<D1"(*E\
MI;RS<[&U+@"DZ*IK`*3HJFL@(B5S(B"EO+-1J7>X<0"DZ*IKI;RI=[AQ+B"E
M2*E)I7.DZ*IK.B`E<P"DO:CN`$UE>&EC;R`HOJ6FZ*WT*0!-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F("BQ2Z=*P[FEIZ;HJ,@I`*2DMJ$`36EM
M92"KK+I!`+/,JO$@,C0@I'"NR:JZL\RG0[?%J]<Z(`"SS*KQ(#8@I'"NR:JZ
ML\RPJK?%J]<Z(`"SS+5UL4N]6*[$M,&I?*6\J.RTP0"L3:YG`,+XMK4`I^2D
MHZCL($Q$05`@LUVI=ZG2N]VM;JJZ($1.(*W(+@"GY*2CJ.P@4$5!4B"E7;C+
M($A45%!?4F5Q=65S="X`LUVI=\#)O_*EHBX@IG"J1ZUNJ,^ESK-OK=/`LZ7.
MM7NFH:=!I;*VM[)[IF*T3K*CI<VE3"X`I^2DHZCLPK*P5*JZ($E$+@"GY*2C
MJ.RELK:WJKH@4$5!4B"E7;C+($UA:6PN`*?DI*.H[+=\M,&JNB!)1"X`K%"T
MP:1``*;FL,JV;*7S`*;FL,JY<;C<`+?%J4T`I_.W<Z3IM,$`K=>G[[KTIWT`
MQ=RG\Z6BL=$Z("@E<RD@)7,`O-*RU0!-;VQD;W9A+"!297!U8FQI8R!O9B`H
MO*^ZN*9HI<LI`$UO;F%C;R`HO*^OQZWT*0!-;VYG;VQI82`HNUBE:BD`I.ND
MSJ9^`*A#I.L`NUBVZZG4KU,`I.NLVP"F8K+$)62FYJ?DJ.RJNL3FINR\QJ78
MI'>V5Z58N7>TP25D+@"V5[E,(#$@M:>P3[_]LU&VQZ9>`+ROK*6M]`"F:+:S
MKLFTN`"F:+:SKLFSL0"TN*[)IFBVLP"W:+*^`*15LKX`I:JRO@"E:[*^`*17
MLKX`I%6RO@"]U:I``+W5K;``I%>RO@!-;WIA;6)I<75E("BR]J14I/&G2BD`
M375L8F5R<GD@LW&P5+_]`+W&O^^FH:15J=2E7*_@JNT`IF*S<;!4O_VDI*:S
MIFZT6*;LLW.UN*1(JKJV;*7SINVG?;.CK$\@6R5S72RF_;-OJ,>S<[6XI$BH
M4Z:SI$"MTZQ/I7.PM2!;)7-=(*JZ+@"]QK_O`*?:JKJQ8KBY`*?:JKJQ8KBY
MN.JP5`"GVJJZLW&P5+_]`*?:JKJS<;!4O_T`K=.D2*^XI7@`K=.D2*^XI7BM
MMJVQL'2X;0!->6%N;6%R("B]<:AL*0"DHRRGVJ2CIE"W3@"F5[K9`*97NMFN
MYJ:A`$YA;6EB:6$@**BZILRD\:C(*0!.875R=2`HO]6^?"D`3F5P86P@**6G
MJGFZN"D`3F5T<V-A<&4@MWRM^Z78O_T`3F5T:&5R;&%N9',@*++\Q/4I`$YE
M=&AE<FQA;F1S($%N=&EL;&5S("BR_,3=IG>F8:9#M+4I`$YE='-C87!E(*RP
ML/+"IJJZNO2G?0!.971S8V%P92"^S,/2IT"\;[KTIWT`3F5T<V-A<&4@OLS#
MTJQ&M::Z]*=]`$YE='-C87!E(*?SMW.Z]*=]`$YE='-C87!E(*=`O&^Z]*=]
M`$YE='-C87!E(%-33""F^*I!OKFF5[K9`$YE='-C87!E(+[,P]*JNK7YN-$`
M3F5T<V-A<&4@OLS#TJNLND$`NO2X]*1UJ.,`L7&EO`!.97<@0V%L961O;FEA
M("BW<[/8J+VF:*6GJ,@I`+=SO%>DP,/^`+=SO%>S<[6XI$@`O&>K2+6Y("5S
M`+=SI.L`MW.HSZ7.JLRF5[K9("BK1*6RK6XI`$YE=R!:96%L86YD("BOPZ;H
MQ/4I`+=SL4N]6`"W<[%+O5BQ3JGS)7BH[+3!+@"W<[%+O5BDH[+%IE@N`+=S
MM?BUH2`H7V)L86YK*0"W<[M$`+=SNT2X<[+5`*15I$"H0@"D5:1`K=._[[:U
M`*15I$"MM@!.:6-A<F%G=6$@**6GI5NIU*7**0"\RKK9`$YI9V5R("BEIZ3I
M*0!.:6=E<FEA("BI8*3.IU&HR"D`L=^D5P!.:75E("BOPZY*KG$I`*=?`*?D
MI*.H["`E,B1S(*JZ("4Q)',@L$^__0"GY*2CJ.RS<;!4O_TN`+5,I6FHT<7C
MI=RN=+*GJKJS7:EWN.JNQBX`M4RE::7.JKJUIK*DJ]BS>2!)4T\@O':YLRX`
MJ%.FLZ?EIKB\RZ:A+@"ITJO\J7>JNJ;LN&VD5ZA3IK.PS[;TIG.F8@"H4Z:S
MM*.HT:;FJ,:^Y*97NMFE2*C1($U#04P@Q>?#TBX`J%.FL\7<I_,N`+5,JFNF
M8J78JV7%=JVMI*2\5Z5;IKC%=JVM+@"H4Z:SJ_RI=ZJZ("5S(+-=J7>XZK!4
M+@"H4Z:SJ_RI=ZJZ($944"!61E,@LUVI=[CJL%0N`*A3IK.K_*EWJKH@4U%,
M(%9&4[-=J7>XZK!4+@"H4Z:SJ_RI=ZJZ(%-13"U&:6QE(%9&4[-=J7>XZK!4
M+@"GY*2CJ.RS<[6XI$@`M4RST;YLPDF\QBX`I;RTHZC1I=BJNBX`P,FNUZ6\
MI%>VQP"GY*2CJ.RYSZ7<+@"F[+AMN.JP5*E\I;RS7:EW`*E\I;RTHZC1INRX
M;;CJL%0N`*6\M*.HT<*RL%0N`*6\J_RI=Z97NMDN`*6\J_RI=[BYO5@N`*A3
MIK.K_*EWL4N]6*5(J-$@2%144"#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1($E-
M05`@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!+97)B97)O<R#%Y\/2+@"H4Z:S
MJ_RI=[%+O5BE2*C1($QO9VEN(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@4$%3
M4U=$(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@4TU"(,7GP](N`*6\O^FD2B!/
M<&5N4U-,(*1'I+BP]:;FP,FJNJ7^N/2N?"X@4$M#4R`Q,B"S5Z[FJKJE6[%+
MN.JNQKO=K6ZESJCLN-.U>Z:A+@"H4Z:SJ]V\9JJZM?FE5:73O=`N`+K/NM"P
M=,-"I;RS7:EW`+5,KN:]=0"I?*6\J_RI=\3FINRDP+EJIG*DN"X`M4RNV+UU
M`+5,IKG`R:[7`+5,O,BF<Z78O_VE::C1I]:H^BX`I;RVQ[!EJ,^ESJK,IE>Z
MV:G.L4N]6"X`I^2DHZCL('9#87)D(+CJKL8N`+5,I6FESJJZ(%A-3""XZJ[&
MLU&VQZ9>`*K%I=6MR`"M[*ELLUVI=\#)I*2GY*2CJ.RJJ:6[N.JP5"X@K:NW
M<[*CI<VS7:EWP,DN`*9BIT&JNK-=J7?`R:2DI^2DHZCLJJFEN[CJL%0N(*VK
MMW.RHZ7-LUVI=\#)+@"U3`"U3"`H=7-E(&EM<&QI8VET*0"DZ:;5L-*DY2`H
M25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD("B_U;K6ITJN<2D`I5^E8K)Y
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D@**Z_J\(I`*M$I*>K
MX0"K1*2GJV4`I*.L3Z1`K=.EV+_]`+5[IJ&I?*6\I[FFJ"X`I*.S7:EW`*6\
MLU&DY+2I`+/&M?D`J%.FLZ5IPG/$_:JZ+*9>I6@N`*11I$"DZP"\QJ9R`*9R
MI+B\Q@"F<J2XO&6KUP"H0ZVVO,:EV`"FYKS&`*?SMW.P=+AMN'.RU:[)I;RK
M_*EWO,:EV"X`3TL`JJNE\P"JJZ7SJ]BEWZK,`*?DI*.H[*JKI?,`I$NV::;L
M`*11I.L`O^RDO:O'`+=SL4N]6*6RMK>[4,+"L4N]6*2CIE`N`,+"L4N]6`#"
MPK%+O5BDHZ6_O50`3VUA;B`HJORPTBD`I76FLR!)34%0(*;XJD&^N:3DM*FK
M2*7SIUBDP*C)I5ROX"X`I76DN;-<I$"MT[9LI?.F[:=]+@"VR*3DM*FSYJ1`
M5D-!4D0N`*5UIK.^UJ:SJLR[4*ATLLZZWK)ZK?NE::5(Q=RG\Z9`J,G%=JVM
M`*9BMW.JNK7XM:&V?;'2`$]P96Y34TP@O_F[?CH@M4RJ:[%Q(%,O34E-12##
ML;.YJOZE\[C1MGVXZJ[&+@"F8K=SJKJU^+6AMGVQTK-SM;(`IT"W?JATLLX`
MO^^VM0`E<[_OMK4`MK6EV+USN+D`LM7"M`"RU<*TL^:F[`"RU<*T`*WLJ6S`
MLZ7.M7NFH;S+JD\`IF(@)7,Z(*2DJKJM[*ELO,NJ3RX`J.2E3`"HY*5,N.JP
M5`"HY*5,O^^VM0"^UJ:SJLS%=JVM`%!!32#%Y\/2M4RNQ"X`4$5!4CHZMFRE
M\Z;XJD&ZW0!01U`@O,:F[,.QL[D`4$=0(*5;L4NXZJ[&`%!'4""DO;9]JO?&
M7P!01U`@I'?#L;.Y+Z1WI5NQ2R"XZJ[&`%!(4""U>Z:AO5@`4$A0(*_SO5H`
MI,BKX:1PJT(`I,BKX;!]JT(`I,BKX::SL[<`I,BKX;!]L[<`I,BKX;2X`*3(
MJ^&Y<*M"`%!/4TE8(&5X=&5N<VEO;B"_\J6B`%!(4""O\[U:7T@`N=2E4@!0
M86MI<W1A;B`HI-JP\K2UJ5HI`%!A;&%U("BIK:];*0!086QE<W1I;FEA;B!4
M97)R:71O<GDL($]C8W5P:65D("BDVK#'M+6I6J;[N^*PSRD`4&%N86UA("BD
MVJZSL*@I`%!A<'5A($YE=R!'=6EN96$@**3:I:RHR+=SM%BDNJC(*0!087)A
M9W5A>2`HI-JIU*9C*0"F:+:S`+%+O5@`L4N]6,7<I_.GN::H+@"Q2[U8I*.E
MO[U4`*A3IK.K_*EWL4N]6*5(J-$@4D%$2553(,7GP](N`+%+O5B]5+M[`+%+
MO5@Z`+%+O5@Z(`"Q2[U8I;*VMZ=KIE@N`+9+I%<`MDND5P"X]*Y\`*O=O&:U
M;K_]H4<`IJBM^P"FRJ3`I/$`L/6FYKK[Q4"^WJ=``+5NI$JKX;#UIN:Z^\5`
MOMZG0#\`Q7:MK0`B)7,BJKK%=JVMI;RS4:=2L*,N`*9SJ/J^1*G:`*9SJ/J^
M1*G:`,5VK:T`Q7:MK;K>LGH`I]JJN@!097)U("BOM;Y\*0##9*JK`%!H:6QI
M<'!I;F5S("BUX:O?NZLI`+EQN-P`P\"T60!0:6YE(+-QL%2__0!0:71C86ER
M;@"YLZ_``+W0MFFD2L!XIG.NYL))O^\`O="]5*EWK6ZROK"CIKFDN*7S.@"]
MT+U4J7>G0:UNI*3"7Z:YI+BE\ZJZLW.ULBX`O="_Z:1*I$"MTZ3KI?>DSJ9^
MI?<N`+W0O^FD2K=SO%>DP,/^JKJF5[K9.@"]T+_II$JD0*W3IK.NQ*JZ($E0
M(*;LIWT`O="_Z:1*I$"MTZ:SKL2JNJ3IM,$[I,2_[Z:YI.NE]ZJZI.FTP2X`
MO="_Z:1*I$"MTZ:SKL2JNJ[)MJ$N`+W0O^FD2K=SN'.RU:JZIE>ZV3H`O="T
MHZC1L-W#1*JZNDNM;BX`O="_Z:1*IT&JNJC/I<ZJS*97NMFDSK%+O5@`O="^
M7,6JI%6F0Z2ZKF4NIT&ELK:WIE"W3K-OJ,>HQK:UI'ZOX*C/I<ZH=++.+@"]
MT+_II$JW<ZJZI,##_J97NMDZ`%!O;&%N9"`HJFG$]2D`K$:J=@"GZ[*\`%!O
M<G1U9V%L("BXLK7EI/HI`+QVN;.F[+AM`*KMKN:F[+AM`+N\L&6V;*7SJ.RS
M;ZW3JTBE\Z=8("AN;W0@96YF;W)C960@8GD@24U!4"D`L\RJ\2`E<R"D<*[)
MJKJML*M"MG$Z(`"ML*M"/&)R("\^OO>R=@!0<F5F<U]L9&%P.B"GY*2CJ.RI
MTKO=K6ZJNB!,1$%0(*FUIOFN3:7S+@!0<F5F<U]S97-S:6]N.B"GY*2CJ.RI
MTKO=K6ZJNB!S97-S:6]N(*FUIOFN3:7S+@"N\,"C`*[\I:VML:[PP*,Z(`"N
M\,"C.B``N7?$_0"F8K=SJKJU^+6AN7?$_;QVN;,`I%>D0+%I`*17I$"MT[_O
MMK4`ID.F3*3EI?,`J'"D2+-QL%2__0"H<+%+JO?&7P"PW<-$`+#=PT2T>:UZ
M`+%-KM<`M*.EW*2ZKF4`I+VV?:KWQE\`I+VV?:KWQE^Z=+KB`*2]MGVJ]\9?
MN.JP5`"DO;9]+ZAPL4NJ]\9?N>^HPZ6\LU&RHZ7-+@!0=65R=&\@4FEC;R`H
MJFFF:+ZDIE4I`%%A=&%R("BE9+E&*0"L9+C?`*QDN-^EHK'1.B`H)7,I("5S
M`*?6LW2W:K1-`+K/NM"P=+AM`%)302"DO;9]JO?&7R`H)60@INRDN"D`O^^^
MW+9S`*M"`*:MIK.K0@"QWZ:SJT(`L'VK0@"K0J:SL[<`JT+"X+.W`,!(OO>D
M<+MY`*3QLG8`Q:JH^@#%JJCZI:*QT3H@*"5S*2`E<P#%JJCZMFRE\P"ITL6J
MJ/JJNK-SM;BD2+5,KL0N`*]UJKJM;J=2L*,@)7,@MMP_(+-OMK6^WJ=`L4ZU
M3*IKJ^RT7RX`O52I=Z=2L*.FN;-SM;BD2#\`KW6JNJUNLDVPHZC/I<ZJS"`E
M<R"JNKCJKL:VW"`_(+-OMK6^WJ=`L4ZU3*IKJ^RT7RX`I'?%XZ7<L$^__3H`
MJ/JN^+1?K>P`K:NW<[[CLGH`K:NW<[[CLGJPRKI!I=B__:2XI?,Z`*VKMW.^
MX[)ZK=.D2*^XI7BDNJYE.@"Q8+-7JNVEW*:A`,/VP7#"<\3]OKD`K:O%J@"U
M^[W7`+NWNMVF^*I!OKD`N[>ZW;KTIWT@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.@"ROK"C`+*^L*.PS[;T`+*^L*.S<;!4O_T`LKZPH\3FINP`
MI6BPHZ[FIJ$`L7&S;ZW3N'.RU:2DLKZPHP"ROK"CN>\`IMNF^*I!OKF\R*9S
MI=B__:2DLKZPHZ1WP'BF<ZJZLUVI=[5[IJ$N`+*^L*,`IMNDY:7SI*2ROK"C
MIKFD0+A@PDD`LKZPHZC/I<ZJS`"ROK"CJ,^ESJK,.B`E<P"E2+;7I$JJNK-Q
ML%2__;AMM*NF<Z9BJKJS<;!4O_T@/R`\<W1R;VYG/L2UIVDZ(+-OL4ZW?*=2
ML*.EV*MELW&P5+_]I*2JNJG2IK.L]K_]+CPO<W1R;VYG/@"[W:A$I;RS4:9>
MP+,Z(+_YNWZXN;U8.@"GY*2CJ.RITKO=JKJJJZ7S+@"GY*2CJ.RITKO=JKJJ
M0;#(+@`E,B1S(*JZLUVI=Z6RMK>K_*EW("(E,21S(@!61E,@JKJS7:EWI;*V
MMZO\J7<@(B5S(@"S7:EWN.JNQJ6RMK>K_*EW("(E<R(`I;*VM\3FINP`K:NS
M70"MJ[-=L4N]6`"MJ[-=IT&JNK%+O5@Z`*VKLUVF7J2ZJ7>MR`"F7J9SL\RK
MX:1`K=.L9+C?`+6RJD<`JO"F7K_OMK4`ID&FN+_II$JW<[%+O5@`4F5U;FEO
M;B`HKV2EIZGTKG$I`*9>M%^S7:EW`+KTK;:]<[_HOKF_[[:U`,&\NWD`I6O#
MY`"E:\/DJNW`60"E:\/DK<@`ID.DNJYE7W<N+BX`J*2FX@!2;VUA;FEA("C#
MN;"HI:>HR"D`L=O"X"`Q.#`@J]<`L&:NR;!W(#DP(*O7L=O"X`"VMJ[)L'<@
M.3`@J]>QV\+@`*9#I+JN90"F0Z2ZKF4`ID,`KN:]=0#$YJ;LNU"F0Z[FO74`
MQ.:F[*[FO74`ID.NYKUU`+#UIN8`4G5S<VEA;B!&961E<F%T:6]N("BK6,.Y
MM+4I`%)W86YD82`HOV.F=[E&*0!3+TU)344@I5NQ2\.QL[D`MFRE\Z1WJ,^E
MSB!3+TU)344@I5NQ2P!3+TU)344@I+VV?;[,P](`4T%33"#%Y\/2M4RNQ"X`
MPK*P5`"XZJ[&KG>O\[U:`*5;L4NRU[K=OO<`4U1!4E143%,@I:*QT3H@*"5S
M*2`E<P"FJ*5<`+CJKL:N=Z_SO5I?40"L4+3!I+L`4V%I;G0@2&5L96YA("BX
M=+NNL,>OQRD`4V%I;G0@2VET=',@86YD($YE=FES("BX=*=*J+VTM:9HNM:D
MSJ6GNONTM2D`4V%I;G0@3'5C:6$@*+ATQ5.FZ*C(*0!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M("BX=*3EM,NDSJ[FM^>HNJ1"*0"F4*1`K=.U^+6A("A?<V5L9BD`4V%M;V$@
M*,+$O*^HR+ASKG$I`%-A;B!-87)I;F\@*+ATL*BG4;_5*0!386\@5&]M92!A
M;F0@4')I;F-I<&4@*+ATIFBL_*3.M+:J3*;HI/$I`+W#K%"THZC1JLP`4V%U
M9&D@07)A8FEA("BH1J]1IF&J_*G4IT(I`,!XIG,`P'BF<R`B)7,B`,!XIG,@
M)7,`P'BF<[_OMK4`L4ZRHZ7-JKJS7:EWP,FE2"!02%`@NWFHI:[FIJ'`>*9S
MJ.RG0:JZIOBJ0;ZYO,BF<Z78O_VDI"X`LUVI=R`E<R"D=\!XIG,N`*?SMW.U
M>Z:AI'?`>*9SJ.PZ("(E<R(N`*G2P'BF<ZJZLW.UN*1(M4RNQ"X`N7.L4+EP
MJT(`K.R^QP"W:K1-`+=JM$VDWL"Z`+=JM$VEHK'1`+=JM$VEHK'1.B`E<P"W
M:K1-I5ROX+5,KL0N`+=JM$VDI"XN+@"_[[[<P,FNUP"_[[[<I$"MTZ3IM,$`
MO^^^W*1`K=.X<[+5I<ZE2+=SO%<`O^^^W*1`INRW<ZJZOM:FLZK,`+_OOMRD
M0+.AIOBJ0;ZY`+_OOMRD0*;LJ,^ESJK,I<ZE2+=SO%<`O^^^W*G2IK,`O^^^
MW*G2IK.DZ;3!I+BE\RX`O^^^W*UNIU*PHZJZI$"EN[-QL%2__0"_[[[<K6Z]
M<[_HJKJD0*6[LW&P5+_]`+_OOMRD0*W3JJNE\P"DH[_OOMP`O^^^W*UNMM>E
M6*JZLW&P5+_].@"_[[[<K6ZVUZ1*JKJS<;!4O_TZ`*GSI4BD5:JZM?BUH:2D
MO^^H^J=!K6ZJNJ9RI+@NI4BWQKFKO<:[<ZG2O^^DY:9R++5-J^&V2Z17I.6E
M\[USO^BPSRX`O^^^W*C3M[W`R:[7JKJF<J2XO7.]6*[FIJ$Z`+_OOMRDZ;3!
MI,"Y:CH`O^^^W*3IM,&DZ;3!KN:FH3H`O^^^W+;7I5BNYJ:A.@"_[[[<P,FN
MUZ5(MM>D2CH`O^^^W*C3M[W`R:[7JKJNYJ:A.@"_[[[<I<ZHT\7CI=RF5[K9
MJKJNYJ:A.@"_[[[<L?W%W*?SJKJHK:7WP]&G3SH`O^^^W*[)MJ&DP+EJ.@"_
M[[[<I.FTP:[)MJ&NYJ:A.@"_[[[<K-NDK*3'L'2JNJ1'K=/$YJ;L+@"_[ZCZ
MN7>S7:JZP,NU^*3HIJ$LL<:GQZ3HIE8LI4BDSJVVK;&_[[:U+@"_[ZCZI<ZE
M2,7CI=RJNK-QL%2__<3FINPN`+_OOMRESJC3Q>.EW*97NMFJNJ[FIJ$N`+_O
MOMRG0:JZPT.FXK!TN&T`O^^^W+"^IFZ[>:BE.@"D=[_OOMRJNK-QL%2__2`B
M)7,B+@"VQ[!EL-W#1*3/P+,`ML>P9<*RL%0`4V5N96=A;"`HMNNDNJ5;NK@I
M`+=0M/J^N3H@`*1%I.L`4V5R8FEA(&%N9"!-;VYT96YE9W)O("BVZ[JXNONH
MR+M0NUBO4Z6GK?3#N2D`I\>XN0"F^*I!OKFXZJ[&O_F[?JG.JLRU3*IKJ,^E
MSBX`MWRTP;K>LGH`MWRTP2!)1""D=[E,M,$N`+=\M,$`KM:H^J3HMO0`I+FS
M7*=!J?.GT;!/L4N]6*JZKLFMU"RE::5(IMNFYJVKLUVQ2[U8+@"S7:EWN[>Z
MW:;XJD&^N:17Q-VI\Z=!JKJMTZ1(K[BE>"X`LUVI=Z=!JKJPOJ9NNWFHI2P@
MKLFPSZ5(I,ZDZ;3!KN:FH2X`LUVI=Z=!JKJQTJELP+.ESK5[IJ$LPT.FXK!T
MN&TLK;:ML:?SMW/`5[)V+*3.J.2E3,7CI=R_[[:U+@"S7:EW`*?SMW.U>Z:A
MM$ZZ_`"FLZ9NM%BMTZ9APDFI3;-OK=.PT;S&IK/#]CH@`%-E>6-H96QL97,@
M*+;KJ?6ZN"D`ID"HR:78O_T`P<JJJP#"LK5UNDNM;@"L3Z=?K+"D:K.AI?>J
MNK-SM;*I=[AQI]:QMJ5<K^#!Y#\`Q>.EW`#%XZ7<("5S`,7CI=RE_K.A`,7C
MI=RS<[6XI$@`Q>.EW+ASLM4`Q>.EW+=SLJ.ES;M0K>S`>*9SLUVI=\#)JKJN
M=+*G+@"H0Z:XM6ZD2JOAQ>.EW*17I$"FN*JZM6ZD2J[)MJ$@/P#%XZ7<PDF_
M[[ZY`,7CI=RJ[:[FOMZG0*5<K^"J[2`_`*GSI:K#Y,7CI=P@)7,@I5ROX*KM
M/P#%XZ7<P'BF<Z[FI+JN9;GON-RDZ+;T`,7CI=RJ[:[FI+JN9;GON-RDZ+;T
M`,7CI=RF0Z2ZKF6Y[[C<I.BV]`#%XZ7<O':YLZ2ZKF6Y[[C<I.BV]`#%XZ7<
MI%>VQP"K^<3RL'VK0@"FK::SL'VK0@"QWZ:SL'VK0@"[MZ3HIK.P?:M"`*:L
MP5D`4VEE<G)A($QE;VYE("BWX*1LI'.PZBD`M?FE50##L;.Y`,.QL[FZ=+KB
M`%-I;F=A<&]R92`HMW.E6ZE9*0"D:J1P`+*DN4RZ^\5``%-L;W9A:VEA("BT
MM:REI>^G2BD`4VQO=F5N:6$@*+2UK*6E[Z6GJ,@I`+.W`+!]L[<`L'VSMP"F
MK::SL'VSMP"QWZ:SL'VSMP"_;K.WLF"KUSH@`%-O;&]M;VX@27-L86YD<R`H
MK\'#N:KYN'.N<2D`4V]M86QI82`HK\&PJ*=1J,@I`+IQNU"XU@"QQJ?'I.BF
M5@"QQJ9#I.BF5K_OOMP`J-.WO:9AIWT`J-.WO0!3;W5T:"!!9G)I8V$@**MN
MJT0I`*MNO-H@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S`*MNI6*R>0"JQ:75IN8`MJ&V6@"VH;9:
MNU"YU*52`%-P86EN("BFZ*]:I/HI`*E5IZ.V;*7S`*]3KNVF<J2XO^FD2@"K
M_*GZK6ZQ3K9IMJ6W:K1-JKJULJI'J?&F8JW^N,PN`*3`L\[`>*9S`*3`L\[$
MYJ;L`*3`L\ZF0P"Y0K#*`%-R:2!,86YK82`HM+6HO<3UI60I`+S0M\<`K%"[
MVJJGQ5&^U`"QTJELIGZE]P"LV0"JK+I!`,!XIG.NYJ:A`+7SN40`IU*PH[UU
M`*9RINJF0P"FV[9LI?.F8:=]I*2E:+"CNO2P[*97NMD`O,NFH2!;0U-370"L
M4+3!I-$`I^2DHZCLIKBEV+_]("(E<R(`I42FK@"P9:58`+Q7I5L@(B5S(B"H
M[*ATLLZJNJ73O="D=[!EI5@N(*=!I;*VM[6EJ.RXTZ73O="S4:[6K>.KX:1^
MK^"U;J1*+@"D5;S0`*:HI5P`IJBE7*JZI5ND2B`B)7,B(*CLJ'2RSJ2D+@"D
M=Z:HI5RF8:5;I$H@)60@K=.S<[6XI$BH[+ASLM6DI"X`)7,@I'>FJ*5<IF&E
M6Z1*J.P@)7,@J'2RSJ2D+@"FJ*5<JKJFVZATLLZDI+)-L*.HSZ7.JLP@(B5S
M(B"JNKCJKL8N`*1WIJBE7*JZJ]BEW[ASLM4@(B5S(BX`(B5S(J1WIU*PHZ>Y
MIJ@N`"5D(*W3LW.UN*1(I'>G4K"CI[FFJ"X`IJBE7*JZIMNH=++.I*2ROK"C
M("(E<R(N`*1WIJBE7*9AL7&X<[+5LKZPHR`E9""MT[-SM;BD2"X`I'>FJ*5<
MJKJF7K1?LUVI=RX@O="MJ[=SN/RD2L#+M?BN=+*G+@"D=Z:HI5RJNK/&I?>S
M7:EWN.JNQBX`I'>FJ*5<JKJSQJ7WLUVI=[CJKL8@)7,N`*:HI5RJNJ?SMW,@
M(B5S(@"D=Z:HI5RJNL+0O&<@)7,`4W5D86X@*,2LI*8I`+I+K6X`I.FE6`"D
MZ;BH`+2X`*3II5@`I.FE6"^DZ;BH`*3II5@Z(`"DZ;BH`*3IN*@Z(`"D5[S0
M`*3DM*D`4W5R:6YA;64@*,2LIU&K;BD`NN^XN0!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9"`HI7:ER\#9Q/4I`%-W961E;B`HM^>HY2D`4W=I
M='IE<FQA;F0@*+?GI&@I`*90J$*P3[_]I'>G4K"C`*90J$*FYK#*N,NX;0"W
M:K1-MK6EV*2DJKJ[>:IKO_F[?@!3>7)I86X@07)A8B!297!U8FQI8R`HL=2G
M4:C(*0"Y<*M"`+EPJT*FLZVW`+EPJT(`IJVFLZOYQ/*Y<*M"`%1A8B"DP+EJ
MKN:FH0!404(@I,"Y:J[FIJ'`R:[7`%1A8B"DP+EJK<@@*"HN='-V*0"J[;/F
M`*KMKN:DNJYE`*KMKN:DNJYE`*5XQE<`I7C&5P!486II:VES=&%N("BV\*9.
MM+6I6BD`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B`HJ5JI?*6GJ,@I
M`*78O-`Z`*O=O^RHQK:U`+EQN-RXN;U8`+/,JO&D0*1PKLFJNK?%J]<Z(`"W
MQ:O7`+?%J]<Z(`"WQ:O7/&)R("\^*"5SL*HE<R\E<Z=#)7,I("9D96<[)7,`
MI^2DHZCLO,NJ3R`B)7,B+@"\RZI/NMZR>@"DNJYE`*_"I.6F<@"Y[[OTI.6F
M<@"Y[[OTI.6F<K.[NMT`K%"TP:5\`*[UI.4@*%1)4RTV,C`I`%1H86EL86YD
M("BN];#J*0!&5%`@J;6F^2AE>'1E;G-I;VXIM4RNQ"X`2&]R9&4O2V]L86(@
MON.F6*1UM7NHPZ6\I.2TJ2`B)7,B`$E-4U`@K/:__;5,JFNS4:KLJ6PN`$UA
M:6YT96YA;F-E(,/^IT^HPZ6\IJBE7+C\I$H`O^^VM;7XM:&E2,/VLZPNPO>V
M?:2D+@"M;K'2I<ZJ_J7SI%>VQZ5<K^"K92RUZL#`P,FNUZATLLXH5D93*:;X
MJD&ZW:6RMK>S7:EWI[FFJ"X`LW&P5+_]("(E<R(@I*.F<Z9B+@"S<;!4O_T@
M(B5S(B"KV*7?I[FFJ"X`LW&P5+_]("(E<R(@LKZPHZ>YIJ@N`+-QL%2__2`B
M)7,B(*?SMW.GN::H+@"FN;-QL%2__;5,JFNS4;)-JL4Z("5S`*=!JKJH=++.
MNMZR>JW[I;*VMZ7]LUVI=Z9NI$"MT\5VK:VKX;K=I'ZOX,7]IT&HSZ7.Q7:M
MK:ATLLXN`*FSKMB]=0#!<+6XN+F]6*6\J_RI=RRJQ:75J<ZF8KCJKL:N=Z2D
MI^2DHZCL+@"D=Z:HI5RJNK%.P7"UN*1(MW.\5Z;<LW&P5+_]I*0N`+C3LW.U
MN*1(I*.F<Z9B+@#%Y\/2MFRE\\.QL[F[W:UNIK.D0*W3I'>XT;9]JKH@4$=0
M(+#/MO0N`+!TN&VX<[+5JKK#T:=/N+F]6"A)1"FDHZQ/I;RK_*EW++1.K$^J
MQ:75J<ZJS*2CIF*XZJ[&KG>DI"X`L'2X;;ASLM6EO*O\J7<N`+O=K6ZD0*W3
MN&>Y3*5;L4NJNKKTN/2S<[6R+@#`R:[7("(E<R(@I'>G4K"CI[FFJ"X`P,FN
MUR`E<R#`L[C3I5VG=*1`K=,@)7,@LUVI=RX`P,FNUR`E<R#`L[C3I5VG=*1`
MJ,<@)7,@LUVI=RX`M4RJ:[W&NW.H[*;;J*W`R:[7+@"FN<#)KM>DI*A3IK.X
MZJ[&+@"E2*15K$\@<F9C.#(R(+9LI?.JNJKMP%DN`*BMI??#T:=/("5S(*1W
MLU&G4K"C+@"^J+K>IK/$M:=IL%2NIZ;]I+2U3:5II4BGN::HN.JNQJJZMM>D
M2BX`I:JNV+UU`$=N=5!'(*1'I+C`R:JZN/2N?*6RMK>I=[AQIF(@0W)Y<'1?
M<&=P.CH@P_ZG3Z2D+@"G0;2_J?,@)7,@L4BUN2`E<R"D0*O*I42FKJRP("(E
M<R(@JKJK2*7SI'>S4;9]L=(N"J;]LV^HPZ2CK^"K3\/2N-.K2*7SJKJDNJYE
MI'>GN:7^LU&FK*7SI$BLW:>YJ<ZD1KC1+@"S<[6RJ.R]<[QGMFRE\ZVVK;&I
MTJC/I<ZJNJ97NMD`I;*VMZQ/I$"MT[S&IG(N`$AO<F1E7T-R>7!T7W-M:6UE
M.CH@P_ZG3RRELKO=K6ZFLR!O<&5N<W-L(+S2LM4N`*:YL+ZF;B`B)7,B(+CJ
MKL:F7:RPME>Y3+/,I&JDN;-<K<@LJ=*E2+5,JFNS4<!XIG,`I<ZE2,#+M?BF
MN;CJKL;#_JNL("@E<RD@JKJU>Z:AJ,.DHZ9SIF*I\ZATLLZD5RX`I-ZM>J9R
MI;*VMZRPL^:D0*9RI+@N`*6JI6NNV+UU`*5KKMB]=0#$YJ;LI,"Y:J9RI;*V
MMZRPL^:D0*9RI+@N`*:YIOBJ0;ZY("(E<R(@I'>S4:=2L*,N`*:YIOBJ0;ZY
M("(E<R(@I'>S4<!XIG,N`"5S(*JZM?FE5;O=J$2D=[-1LKZPHRX`J_RI=ZJZ
ML$^__:C#I*.F<Z9B+@"\R*9SP,FNUR(E<R*DHZ9SIF(N`*=!J=*_Z:1*JKJX
MZJ[&NU"U9:VQN.JNQJ2CLL4N`*17I%6NV+UU`*17KMB]=0"Q<:17I$"MTZA"
MQDJDIZOAI%>VQZJZN.JNQK_RI:(N`*17ML?`R:[7J,.EO+-1P'BF<RX`=V5A
M=&AE<BYC;VT@L,^V]+5,JFNHSZ7.+@"GY*2CJ.R\RZ:AL'2X;:78O_T@(B5S
M(BX`M4RE::C1PG/$_:JZLW&P5+_]+@"U3*5II<ZJNK_OMK4N`+5,JOZE\Z5I
MJKVQM;9]L=(N`+5,I6FESJC3MW.\5[!/O_VJNK-QL%2__:5II<XNIG"J1Z=!
MNWNLL+-OJ<ZS7*Q/K=._^;M^++W0P7"UN*=!JKJH=++.NMZR>JW[+@"FN<3F
MINRDI*5=IW2DTZ9HJKJF<KS&+J=!I'>_Z:1*("5S(*W3IG*\QCNG0;_II$JJ
MNJ9RO,:ELK:WI'"I\R`E<RX`MW.\5R`B)7,B(*CLJ'2RSCH@)7,@KLFU;Z7-
MI$"MT[#=PT0N`*;;J'2RSK)-L*,@(B5S(B"JNKCJKL:NR;5OI<VD0*W3L-W#
M1#H`IMNH=++.LKZPHR`B)7,B(*[)M6^ES:1`K=.PW<-$.@"G\[=S("(E<R(Z
M("5S(*[)M6^ES:1`K=.PW<-$`*17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z("5S
M(*6\LU&D5[;'+@"D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E<R"D:J1PME>Y
M3*2YLURSS*1JK<@@*"5D(&)Y=&5S*2X`I%>VQ\#)KM>NR;5OI<VD0*W3L-W#
M1#H@MLBSH:3`JKH@)7,@P,FNU[-1I%>VQRX`MW.\5[-SM;BD2*[)M6^ES:1`
MK=._^;M^+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BX`J]BEW[=S
MN'.RU:[)M6^ES;_YNWXN`*O8I=^S<;!4O_TZ("5S(*[)M6^ES:1`K=._^;M^
M+@"FVZC3M[VS<;!4O_VDI*=2L*,@(B5S(B"NR;5OI<VD0*W3O_F[?BX`IU*P
MH[-SM;BD2#H@)7,@KLFU;Z7-I$"MT[_YNWXN`,7CI=RX<[+5KLFU;Z7-I$"M
MT[_YNWX`P,NU^+9LI?.NR;5OI<VD0*W3O_F[?BX`MM>D2J:YLW&P5+_]N.JN
MQJ[)M6^ES;_YNWXN`+;7I$JXZJ[&.B5S(*[)M6^ES:1`K=._^;M^`+;7I$H@
M:4-A;&5N9&%R(+CJKL:NR;5OI<VD0*W3O_F[?BX`IF*S7:EWJNVSYJ2DM6^E
MS:1&I$"MT[_YNWXNIK.E::_@IT&_\KI\I$:ELK:WMO&\9ZJZQ.:F["X`L/6F
MYK-QL%2__:O\J7>E7*_@KLFU;Z7-I$"MT[_YNWXN(+W0M7FKX:9!N-6D0*:X
M+@"ROK"CLW&P5+_].B`E<R"NR;5OI<VD0*W3O_F[?@"G\[=SP7"UN*1(N.JN
MQJ[)M6^ES:1&I$"MT[_YNWXN(+W0M7FKX:9!N-4N`*?SMW.P=+AMN'.RU:[)
MM6^ES:1&I$"MT[_YNWXN(+W0M7FKX:9!N-4N`*?SMW.S<;!4O_TZ("5S(*[)
MM6^ES:1`K=._^;M^`*?SMW.S;[6GN.JNQCH@)7,@KLFU;Z7-I$"MT[_YNWX`
MM4RS<;!4O_VXZJ[&I6FHT;;7I5BS<;!4O_TN`+-QL%2__<7CI=RVMJ?'IG"D
M53H`Q.:F[*97NMG%XZ7<MK:GQZ9PI%4Z`*:Y($E-05`@IOBJ0;ZYJ,.EO*3D
MM*FK2*7SIUBDP*C)I5ROX"X`LV^F_*5'I*.L3Z6_O52JNB!R87(@P*/!6<#)
MKM<N`+-OIORE1Z2CK$^EO[U4JKH@>FEP(,"CP5G`R:[7+@"S;Z;\I4>DHZQ/
MI;^]5*JZJTBESJ5DN+F]6"X`IKG$YJ;LK$^ELKO=K6ZJNBX`IKG$YJ;LI+JN
M9:5UI+FS7+[CO,:\QJ9R+@"FN<3FINRDNJYEI76DN;-<O,:F<J3.JU^XN2X`
MIKG$YJ;LI+JN9:5UI+FS7*1+MFFF[+S&K<@N`*:YQ.:F[*2ZKF6ELK:WK+"S
M<KBYJ<ZJQ:75I,"Y:JJZO,:F<@"ELK:WK$^D0*W3O,:F<BX`IKG$YJ;LI+JN
M9:6RMK>E7:=TI$"RU:11I+NV::;LJKH@4D="(,-#IN*E3KU8+*C2IG`@)R,Q
M,C,T868G+@"FN;K8P,FNUZ[FIJ&HPZ6\LU&DY+2I+@"S;ZW3JNVSYJ1WLU&S
M0K)ZN4PN`+-OK$\@)7,N`+-OK$\@2V]L86(@N'.RU:JZI$"MTZJKI?,N(+']
MP,NU^*:YJJNE\[O=K6ZOX*3DM*E+;VQA8B"X<[+5KN:FH:JZN7&D;+9LI?.S
M;L7I+KW0L-&FTB`E<R"E2*1&N-&S;ZC'MFRE\[-NQ>D`LV^KRK9LI?.HPZM$
MI4BG0;I$I<ZJNJ9RI+BVL*;3K$^HSZ7.("@E<RD@KM&\9Z;3IJ@N`*:YO,:M
MR+/,I-:ELK:WK$\@,2X`LV^MTZ1(JKH@)7,@L$^__:1WIG.F8JGSLW&P5+_]
MI*0N`*:YIOBJ0;ZYM4RJ:[GO('II<""DSB!G>FEP(*[FIJ'`R:[7MFFFYKC1
MP*/!60"FN:ATLLZEV*MEK$^PL:7.JKJJK+I!+@"ELK:WK$^D0*W3O,:F<BX`
MMW.\5ZG.MM>D2K-SM;BD2*JZN7>S7;-QL%2__2X`IKFU^+6AI;*VMZUNI=&_
M[[:UM?BUH2A/<'1I;VXIJ=*I2:5S`+EP`+#=PT2P;,+<`*[)MJ$`KLFVH:O\
MJVX`KLFVH:[FIJ$`KLFPS[_OOMP`5&EM;W(M3&5S=&4`NMF_UP"\T,-$("AT
M;V]L=&EP*3H`IJRE\Z1(`*9PJD>M;KW&O^\LO="F8L))O^^WQKFKJKJF4*[)
MJ_8@0V]N=')O;,'D**W3I$BY<;BC*2"ISB!#;VUM86YDP>0HQ*NJ1[EQN*,I
M+@"DM:31`$A434P@K>RI;,#)`%1O9V\@**9HK?0I`%1O:V5L874`J?JDT0!4
M;VYG82`HJD:E6RD`L[NSH0"SS*17O&BNV*Q;("A?=&]P*0"D9*B]N4:DSJ:K
MJ*FM]`"O=:G.L+``K%"TP:1'`%1U;FES:6$@**SPI:>FZ*C(*0!4=7)K97D@
M**1GIM6HY"D`I&>FU:CDI.4@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4
M=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU("BD9Z7+OGPI`+_II$JG
M0:JZO^^^W#H@`+6UI7Z]=:O\O,8Z(`"Z]*=]`+KTIWTZ`%5G86YD82`HKU&D
M>KE&*0!5:W)A:6YE("BO4:=*Q/4I`+5,JFNF<ZCZ(%9&4R"EV+_]+@"U^:55
MKLFU3*IKO%>E6\-"I7ZJNJC/I<ZJS+CJL%0N`+5,JFNG[\7<(%9&4R#`R:[7
M("(E<R(@JKK%=JVM+@"U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNL5VK:TN
M`+5,JFO%W*?SK+`@)7,N`+5,JFO`RZQDP,FNUZ1JI'`@(B5S(BX`M4RJ:\#+
MK&3`R:[7I&JD<"`B)7,O)7,B+@"U3*IKLW.ULB!344P@IOBJ0;ZY+@"U3*IK
MJ,^ESB!34TP@LW.ULBX`M4RJ:[W&NW,@5D93(,#)KM<N`+5,JFNKV*7?(%9&
M4R"EV+_]("(E<R(N`+5,JFNKV*7?(%9&4R"EV+_]+@"U3*IKJ]BEWR!61E,@
MP,FNURX`M4RJ:ZO8I=\@5D93(*78O_T@(B5S(BX`M4RJ:ZO8I=^JQ:75JKH@
M5D93(,#)KM<N`+5,JFNKV*7?MW.JNJ9`J,DN(*_*I-:HT[>]JZRZ02X`M4RJ
M:[%.N.JNQKC1P*/!62X`M4RJ:Z=2L*,@(B5S(BRFN:78O_VHPZM$JL6EU2X`
MM4RJ:Z=2L*,@(B5S(CH@)7,`M4RJ:Z=2L*,@)7,LIKFEV+_]J,.K1*K%I=4`
MM4RJ:[N\L&JG4K"CI=B__2X`M4RJ:Z=2L*,@5D93(*78O_TN`+5,JFNG4K"C
M(%9&4R"EV+_].B`E<RX`M4RJ:Z=2L*,@5D93(,#)KM<@(B5S(BX`M4RJ:Z=2
ML*,@5D93(,#)KM<N`+5,JFNG4K"C(%9&4R"EV+_]("(E<R(N`+5,JFN[O+!J
MIU*PHR!61E,Z("5S+@"U3*IKIU#"7Z78JV6JNJ78O_TN`+5,JFNXT;9]OLS#
MTK+3N&``M4RJ:[C\I$H@)7,@JKJI=[AQN.JNQBX`M4RJ:[=HLKX@5D93(,#)
MKM<N`+5,JFNV?;'2(%9&4R#`R:[7("(E<R(N`+5,JFN\9Z1*(%9&4R#`R:[7
M+@"U3*IKMGVQTB!61E,@P,FNURX`M4RJ:[9]L=+`H\%9P,DN`+5,JFO%JJCZ
M(%9&4R#`R:[7("AF:6QE<VEZ92@I(&9A:6QE9"DN`+5,JFO%JJCZ(%9&4R#`
MR:[7("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`+5,JFO%JJCZP,FNUSH@`+5,
MJFO%JJCZ('9F<W)O;W0@I=B__2X`M4RJ:Z?SIE<@)7,@K+`@)7,Z(*9=K+"E
MV+S0JTBE\Z=8I'>F<Z9B`+5,JFO%W*?S(%9&4R"EV+_]JKJF5[K9+@"U3*IK
MLKZPHR!61E,@I=B__3H@)7,N`+5,JFO%W*?S(%9&4R#`R:[7("(E<R(@JKJF
M5[K9+@"U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNJ97NMDN`+5,JFO%W*?S
M(%9&4R#`R:[7JKJF5[K9+@"U3*IKL/6FYB`G;6MI<V]F<R<N`+5,JFO"X+2K
M(%=O<F0@I.6E\P"U3*IKO&>D2B!61E,@(B5S(B#`R:[7+@"U3*IKO&>D2B!6
M1E,@P,FNUR`H8V]P>2@I(&9A:6QE9"DN`+5,JFN\9Z1*(%9&4R#`R:[7N.JN
MQBX`M4RJ:[QGI$H@5D93(,#)KM<L(+K/NM"P=,-"I'>ZH2X`J;.]=0"K[+1?
MQ=RG\P"T7ZWL`*;XJD&^N;-SM;*NR;5OI<VEO+EWM,&JNJ9>P+,Z(`"U;Z7-
MI;RY=[3!JKJF7L"S+*71IOBJ0;ZY.B``I;RDP,/^`+A5L.J]6"`H551&+3@I
M`+W2J\<`56YI=&5D($%R86(@16UI<F%T97,@**K\J=2G0L%PIEBD:J2]L.HI
M`%5N:71E9"!+:6YG9&]M("BM7K#J*0!5;FET960@4W1A=&5S("BL_+#J*0!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`L^:F[`"EO*J^
MJKH`I;RJOJJZ($%022"P5*ZGO7.XN2`H05!)($UE<W-A9V4@240I+@"EO*J^
MJKJKR*3AL%2NI[USN+D@*$%022!-97-S86=E($E$*2X`I;RJOJJZINRX;;CJ
ML%0N`*6\JKZJNJC/I<ZJS*97NMFISK%+O5@N`*2DPE^EV*MEI+BE\ZJZLW.U
ML@"EO*E2IE<`IEVF=Z7^Q56\>Z2CI+FS7*6\L<+%=JJZM7NFH;#UIN:PQ:15
M+[W&NW,OMDND5RX@PDF_[[U4J7>E2,#+M?@@;6]Z:6QL82YO<F<@J=*THZC1
MJKJLV\/VI]ZS3J3EI?,LQ?VG0:5II4BXT;"CIKFD0*VMJ.ZHPZ;;IN:V?:GQ
MM7NFH:9SJ/JPQ;9+PZ\N`*CZKOC#0Z;B`*6\I.2TJ:JZI+JN9:NLND$Z("5S
M`*6\I.2TJ:JZL,;`R:97`,7<I_,`I_.W<R`E<P"G\[=SJ,^ESJK,`"(E<R*D
M=Z?SMW,N`*?SMW.U>Z:AI'>G4K"C+@"D5[;'`*1WI%>VQZG2IK/`LZ7.M7NF
MH:JZLUVI=\#)J.RF^*I!OKDN`*1JO&>IU*1"O,:F<@"D:KQGP[FPJ+S&IG(`
MNO2G?0!5<G5G=6%Y("BO4:G4IF,I`*C/I<ZEV*MEJKHZ("5S`*C/I<X@4U-,
M`*9PJD>G0:JZJ,^ESJK,IE>ZV2^Q2[U8NU`@24U34""F^*I!OKFDHZ90+*5I
MIF*FN;-=J7<N`*C/I<ZJS`"HSZ7.JLP@)7,@I;RS<;E,("5S(*JZL<+%=L7G
MP](N`*C/I<ZJS+K>LGH`J,^ESJK,O^^VM0"HSZ7.JLRU^:55`*:YK[BE>*JZ
MJ,^ESJK,M?FE5:ATLLZD=["QI<XN`*?DI*.H[*C/I<ZJS+%BN+D`J,^ESJK,
MIE>ZV0"HSZ7.JLRF5[K9("(E<R(@I'>F<Z9B+@"HSZ7.JLRF5[K9.@"HSZ7.
MJLPZ(`"H=++.I*2JNJC/I<ZJS#H`57IB96MI<W1A;B`HKU&O]Z=/ITHI`%9&
M4R"EV+_]J,.DHZ9SIF(N`+"RM,$`I'>GY*CLIK.NQ*JZIF'"23H@`*:SKL2I
MR@"E2*3`Q,&LL+/FINPHL7&R>Z9BL%^ZXBD`K<@`O^^H^JW(IML`5F%N=6%T
M=2`HI<NEHZK\N<\I`,7<I,8`5F5N97IU96QA("BI9:2ZM^>IU"D`Q>?#TJ6B
ML=$@+2"FN;9LI?.E::_@I'>^1*1(OM6FV[]YI^\N`%9E<FES:6=N(*78O_T`
MJJFENP"JJ:6[L;&H[@"KJZJ]N>^[]`"KJZJ]N=2E4@"KJZJ].@"K1+%@L*H`
M5FEE="!.86T@*+96JVXI`+96JVZDY2`H5DE30TE)*0#`R[7X("(E<R(`P,NU
M^"`E<P#`R[7XLW.UN*1(`*9BMW.U^+6AMGVQT@"E2"`E<R#`R[7X`+EWLUW`
MR[7X.@!6:7)G:6X@27-L86YD<RP@0G)I=&ES:"`HK5[$W;K[J,JX<ZYQ*0!6
M:7)G:6X@27-L86YD<RP@52Y3+B`HK/S$W;K[J,JX<ZYQ*0"OX*BCJ]<`K^"H
MHZO7.B``N'&D:J=1I?&\=ZVWN7&K2*2]I7&S>KE,(%--5%``Q+6G:0#$M:=I
M(2$A(+%Q("5S(*3BL,JROK"CM7NFH2X`5TE.(+AGI=$@2%144`!786QL:7,@
M86YD($9U='5N80#$M:=I`*Q0M,&D5`"DT:[PN7>T^@"N\+9(N.JNQK2CJ-$`
M=V5A=&AE<BYC;VT@NO2ON`"Z]*^X`+KTK[@`NO2G?0"H0[9G`,5WJN\`Q7>J
M[ZCL("5S`,5WJN\L("5S`*;HO-H@*$E33RTX.#4Y+3$I`*;HO-H@*$E33RTX
M.#4Y+3$U*0!797-T97)N(%-A:&%R82`HINB\NZNBJ=0I`+5NI$JKX<"SN-.E
M_<7CI=P@)7,@K?ZD0*W3P+.ESK5[IJ$_`,3FINRJNJ3`N6JF<J2X/P"DWJUZ
MJKJK9;AMIG*DN#\`5VAE<F5I<R!!=7-T<F%L:6$@IF&YSP"M_JW3I.NLVP"Z
M]*VVO7._Z+ZYJKJTH:7S*'!L=6=I;G,IL=*PRK&QJ.XN`+QEJ]<`I4@@0U-3
M(*RPL^:F[*JZO&6KUP"EJL/D)7.E7*_@JNVJNKQEJ]<HI%6FN+5NI$JI;*7-
MKL0I.@"J[:[FO&6KUP"\9:O7L^:F[`"\9:O7.@"VL,7IL]"G0`"MMP"FK::S
MK;<`K;>S="BX8"D`K;>S=#H`K;>S=#H@`+2\O'H`M,&KW<*GJJL`I'6G0`"_
M[*2]J\>F8:=]`+_LI+VKQZG2Q-VKL*6K`+_LI+VKQZG2Q-VPZJYA`+_LI+VK
MQ[EQN-P`O^RDO:O'MFR[O+#/N+D`O^RDO:O'J=+$W:S9I?<`O^RDO:O'INVG
M?0"RQ"5DIN:JNL3FINR\QJ78I*.EO[U4+B#`L[C3K6ZFLR5DK=/$YJ;L+*5U
MI^2H["5DK=/$YJ;L+@#$YJ;LO,:EV*2CI;^]5"X@P+.XTZUNIK,E9*W3Q.:F
M["RE=:?DJ.PE9*W3Q.:F["X`6#4P.78S(*FUIOFJ]\9?NWFJ:P!8-3`Y=C,@
MI42FKK3`I4ZF5[K9`%@U,#EV,R"E1*:NJO?&7\/1IT^JS`!8-3`Y=C,@L,;`
MR:97`*9^`*9^`%EA:&]O("$@IF&YSP"H0Z9^`%EE;65N("BXK:KY*0"L3P"L
M3ZJZ+*?:IE"W3@"G0:78JV6HSZ7.K\*DY:9RO7.\9[S2IJ$N(*C/I<X@6SP^
M72"K]K9SI6FDP;2KK+"Z]*VVO7.\9[S2IJ$N`*2CI+FS7*=!J]BEWR5DI4BD
M5ZJZL,^V]"X`I*.DN;-<IT&F8B`B)3(D<R(@I*2KV*7?("4Q)&0@K=.E2*17
MJKJS<[6XI$@N`*=!I;RS4;'"Q78N`*=!JKJE_J97I*2DHZ5IIK,@)UPG(+-O
MO,NJNJ9RI+@N(`"G0:C#I;R_Z:1*I$"MTZ:SKL2JNKEQI&RV;*7SINRG?2X`
MIT&HPZ6\I=&VUZ1*JKK`R:[7I*2Y[ZQ-I?2F\\3FINRH["`E<P"G0:A3IK/`
MR[7XLV^MT[-SM;BD2*JZQ7:MK2X`IT&H4Z:SP,NU^*:YJJNE\ZJZQ7:MK2X`
MIT&H4Z:SIU*PHZ:YJ-.WO:JZQ7:MK2X`IT&D=[AGM6ZE6"X`O="_Z:1*I$"M
MTZ:SKL2JNKEQN-RXN;U8++#JN]JY<;C<N+F]6+;(I76DN;-<O,:F<KBYO5@L
MJ,.U^+&AJG"E::GSJV6ML:9!I5ND0*W3("<K)RX`IT&ELK:WO^FD2J1`K=.F
MLZ[$JKJMR"X`IT&ELK:WI?VS5[FZIFZ^\*JLN.JNQBA$871A5')E92FF^*I!
MNMVD?J_@Q'[$\JC/I<ZW<Z7.I.&U^:55JD&PR"X`IT&ELK:WI?VS5[FZI$"M
MT[7JP,#`R:[7J'2RSBA61E,IIOBJ0;K=+@"]T+1YK7JPW<-$H4&F8J=!ML>P
M9;#=PT2S^*=II*>K92X`IT&ELK:WO^FD2J:YLW.ULJG2J_RF5JJZNO2G?0"G
M0:6RMK>E_;_OOMRD0*W3I=BF8;-QL%2__2X`IT&ELK:WO^^^W*1`K=.EV*9A
MN'.RU2X`O="K_*EWK6ZG4K"CJKJF^*I!OKDN`*=!I;*VM[_OOMRFW*36I$"M
MT[-SM;BD2"X`K;JE_2RG0:6RMK>FW*36O^^^W*1`M:>XZJ[&+@"]T*O\J7>M
M;K)-L*.JNJC/I<ZJS"X`O="K_*EWK6ZROK"CJKJHSZ7.JLPN`+W0J_RI=ZUN
MMW.\5ZJZJ,^ESJK,+@"]T*O\J7>M;J?SMW.JNJC/I<ZJS"X`O="K_*EWK6ZP
M]:;FJKJG0*7.+@"G0:6RMK>_Z:1*MW.DP,/^JKJF5[K9+@"G0:6RMK>THZC1
MI$"MT[AQI&JG4;G2I+JJNKEQN-RXN;U8`*=!I76FL\#+M?BS;ZW3LW.UN*1(
MJKK%=JVM+@"G0:JZ("5S(+=\M,&D=[E,KLDNO="MJ[=SM6ZD2BX`IT&JNKEQ
MI&RV;*7SINVG?0"G0:JZL4BE\Z1(N7&D;+9LI?.F[:=].@"G0:JZN.JP5`"F
MV[%QIT&JNB`E<R"W?+3!MGVI;*5(J-.G0:JZNO2[VKKTN/2F[*=]I'?%W*?S
M+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!I;*VMZVKMW.U;J1*+@"G0:JZIE>Z
MV0"G0:JZQ>?#TJ;XJD&ZW:C#I*.DY+2IMW.\5ZC/I<ZJS"X@IG"J1Z=!I\:Q
MYKK>LGJHSZ7.JLRQ8KBY+*=!I;*VMZ5TO^^HY*5,JKK%Y\/2IOBJ0;K=+@"G
M0:JZQ>?#TKK=J,.EO*3DM*FF0Z58J,^ESJK,J<ZXTZ5<K^"D=[-1P_:SK"X`
MIMNQ<:=!JKH@)7,@MWRTP;9]J6RE2*C3IT&JNL)SQ/V^N:;\I4>D=\7<I_,N
M(*RPJT_%0*=!JKJF=Z7^L%^HHZ%!IT&ELK:WK:NW<[5NI$HN`*=!JKK"<\3]
MOKFHPZ6\I.2TJ;-OK=.E7*_@+@"G0:JZPG/$_;ZYJ,.EO*3DM*FF0Z9,O^^V
MM2Z]T*OV($-44DPO0V]M;6%N9"`K(%`@ID.F3"X`IT&EV*MEJ=*S7:EWJKJN
MR;#/.@"G0:JZN7>S7;-QL%2__:2CI6G"<\3]+@"[U:15N7>S7:JZJ*VE]\/1
MIT^D=\7<I_,N`+O5I%6Y=[-=JKJHK:7WP]&G3SH`IT&JNJ7^IE<Z`*=!JKJU
M;J1*I'>H[+3!+@"G0:9B("5S(*2DJKJW<[%+O5BL3SH@)7,`IT&F8K5NI$JT
MP;:AJKJ_[[:UI'>S4:?SMW,N`*=!JKJ_[[:UI'>G\[=S+@"G0:JZL4N]6*1W
MK:NW<[-=J7<`L4N]6*1WLU&MJ[=SLUVI=RRW<ZJZL4N]6*1WLWJY3+EQI&RV
M;*7SL4BU;[W0I4BXT[%+O5BU;J1*+@"G0:JZL4N]6*1WJ.RTP2X`IT&JNKNW
MNMVF^*I!OKDZ`%EU9V]S;&%V:6$@**MNM+6IU*32*0!:86ER92`HPL2E["D`
M6F%M8FEA("BI?*3QJ,@I`%II;6)A8G=E("BHKZ3:J\(I`%O!],+#I-ZM>ET`
M6[#=PT2DSZQ-70!;Q>.EW*3>K7H@+0!;Q>.EW*3>K7H@+2`E<R"FYET`6Z;L
MJ?.FYB`E<R"F0"`E<R"FYET`6ZK%I=5=`+K>LGI?00#"<\3]7T(`J5*E3Z9#
M7T,`LW.UN*1(7T,`OO"JK+CJKL9?1`"G4K"C7T0`IU*PHZ9#7T0`N'.RU5]'
M`+NAJ?I?2`"\=KFSI+JN95])+BXN`+;7I$HOMM>E6%])`+ASLM5?3`"U;J1*
M7TP`M6ZE6%],`*W7I^^S<[6R7TTN+BX`I]JJNK-QL%2__5]-`+=SO%>S<[6X
MI$A?3@"_[[:U7T\`Q7:MK5]0`+*^L*.Y[[-SM;)?4BXN+@"Q<;-OK=.X<[+5
MI*2ROK"C7U(`MVJT35]3`+-=J7=?4P"J[:[FI+JN95]4+BXN`*C/I<ZJS%]5
M`+-QL%2__0"FYJC&ON0`M4RJ:ZO8I=^_Z:58P,FNUP"U3*IKMGVQTK_II$H`
MJ_:FN0"Q2Z5/ID.[>:IKO_F[?@"S7:EWO_F[?@"S<;!4O_TN=F-F`+-QL%2_
M_2YC<W8`LW&P5+_]+G1S=@!C;VYT86-T<RYV8V8`O_*EHJVKK6ZJNJATLL[`
MR:[7`+CJKL:NYJ:AO_F[?@"GY*2CJ.RP3[_]`,#)KM<`L7$@)7,@*"5S*2"I
M\R`E<R`E<P"P?:VW`*[).@"NR0"EO*J^JKJV;*7SI42^]Z97NMD`I=^G60"J
MO;&UQ>.EW*GSI;NDY;#/`+_II$HOO^FE6+_YNWX`I+JSH;-NQ>F_^;M^`*;F
M70"DP`"F5[K9`+5,`*A3IK,`J7REO+GJIT`N`*E\I;RYZJ=`+@"SQJ?1O_T`
MILJDP*3Q`*9SJ/J^1*G:`+FSK\``LW&K2*CSJ7>[M[K=O_F[?@"D5Z3)`+5,
MI6FESJJZJD&PR`#%XZ7<KG2RIP!S;7,R96UA:6P@N&>ET2!(5%10`*SM`,.M
MJ7<`J'2RSK_YNWX`J]V_[,.O`+S(KLFIRJJZI:*QT0"H[+ASLM4`J.RHY*5,
MJKJS<;!4O_T`ID&FN+_II$JG0:JZL4N]6*5(O52[>[5,NWX`ON.F6`"EO*E2
MIE<`J,^ESJK,O^^^W`!V0V%R9`"L4+3!.@!W96%T:&5R+F-O;2"Z]*^X````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQO8V%L92\N:'1A8V-E<W,`````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S
M-C(W-38`,#(P-3<S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$1E;GD@9G)O;2!A;&P*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T=7)B82]P;R\`````````````````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S4V`#`Q-C$V
M,@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+VMO7TM2+G!O````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S,R,30`
M,3`T,3<S-C(W-38`,#$W-3,S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@2V]R96%N('1R86YS;&%T:6]N<R!F;W(@:&]R
M9&4@<&%C:V%G90HC(&AO<F1E(,;0Q;#!]K^A(+3KQ]$@Q]&QN;[N(+GXOZJY
MKBX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC(%1H:7,@
M9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S
M('1H92!H;W)D92!P86-K86=E+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!4=7)B82`R+C`M8W9S7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P,2TQ,2TQ,"`P,CHT,"LP.3`P7&XB"B),87-T+51R86YS
M;&%T;W(Z($II;FAY;VL@2&5O(#QN;W9E;6)R94!O=7)N871U<F4N;W)G/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]975C+6MR7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET7&XB"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C0R
M"B,L(&9U>GIY"FUS9VED("(@061D(&%N($E-4U`@061D<F5S<R!";V]K(@IM
M<V=S='(@(E!I;F4@P=:\TK?/(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?
M;W!T+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B($1E;&5T92!)35-0($%D9')E
M<W,@0F]O:R(*;7-G<W1R("*\L<7#M<@@P=:\TK?/P+BWSB(*"B,Z(&1A=&$N
M<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR96%D>2!E
M>&ES=',@86YD('=A<R!N;W0@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&)R
M;W=S92YP:'`Z,3(V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S
M='(@(B<E<R>TPB"XKKVZQJ[`S+G'M\X@NKF[Y[7'P?8@OLK`O2(*"B,Z(&)R
M;W=S92YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&YO="!M;W9E9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T
M<B`B)R5S)[3"(+BNO;K&KL#,N<>WSB"_Q;#<P?;!]B"^RL"](@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S
M=&YA;65<(B`@*&EE+B!*;VAN($1O92DB"FUS9W-T<B`BP,RXIR"\NBB_N3H@
M2F]H;B!$;V4I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I
M9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM
M<V=S='(@(KRZ+"#`S+BG*+^Y.B!$;V4L($IO:&XI(@H*(SH@861D+G!H<#HQ
M,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@861D960N(@IM<V=S='(@(B5S
M(,/?L*&URBXB"@HC.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B)7,@
MQL3`S\"[(+RZL/C`^\"XM\X@L*'!KK_4O<"TS[39+B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O9F]O=&5R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('1O("5S(&]F("5S(@IM<V=S='(@(B5S('X@)7,L(,#\P[P@)7,@L+,B"@HC
M.B!L:6(O5'5R8F$N<&AP.C0T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B4&EN92#!UKS2M\\B"@HC
M.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#4*;7-G:60@(D$@8G)O=W-E
M<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B"FUS9W-T<B`B
M:49R86UEP+L@P?:_^,?/M,(@NNJV\[_LP:ZPH2#'RK_DQ]6TS[39(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.0IM<V=I9"`B06)O=F4@<V5A<F-H
M(&9O<FTB"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z-3(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@=&\@)7,B"FUS9W-T<B`B
M)7.PH2`E<[^A(+RZL/C`^\"XM\X@P]^PH;7*(@H*(SH@861D+G!H<#HU-B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(R"FUS9VED(")!9&0B"FUS
M9W-T<B`BP]^PH2(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E
M;&5C="YI;F,Z,3<T"B,L(&9U>GIY"FUS9VED(")!9&0@861D<F5S<R!B;V]K
M(@IM<V=S='(@(L#?N/BUR"#!UKS2M\\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@
M861D<F5S<R!B;V]K<R(*;7-G<W1R("+!UKS2M\\@)R5S)R"\L<7#(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,W"FUS9VED(")!
M9&0@8V]L=6UN(@IM<V=S='(@(L2NM[,@P]^PH2(*"B,Z(&5D:70N<&AP.C$R
M.`IM<V=I9"`B061D(&9I;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHR,@IM<V=I9"`B061D('1O(@IM<V=S='(@(L/?
ML*$B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F=7IZ
M>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@P=:\TK?/(@H*
M(SH@8G)O=W-E+G!H<#HR."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"FUS
M9VED(")!9&1R97-S($)O;VL@3&ES=&EN9R(*;7-G<W1R("+!UKS2M\\@N*Z]
MNL:N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"B,L(&9U>GIY"FUS
M9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(E!I;F4@P=:\TK?/(@H*(SH@
M861D+G!H<#HQ,#@*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R>2(*;7-G<W1R
M("+!UKS2M\\@P-2WPB(*"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B061D<F5S
M<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(L'6O-*WS\#,
M(+RZL/C`^\"XM\X@NO&_]L'\(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K
M<RYI;F,Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@8F]O:R!T;R!D96QE
M=&4@(@IM<V=S='(@(L'6O-*WSR#`U+?"(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S`*(RP@9G5Z>GD*;7-G:60@(D%D
M9')E<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S
M='(@(L'6O-*WS\"[(+KQO^\@O/8@OOB]P+3/M-DZ("5S(@H*(SH@<V5A<F-H
M+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S<*;7-G:60@
M(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R("*P[;'>(+#+N_8B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HV-`IM<V=I9"`B06QI87,B"FUS9W-T
M<B`BNK"X[2(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC
M.C<@=&5M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S
M='(@(KCPM<X@O+'%PR(*"B,Z(&QI8B]A<&DN<&AP.C4U,@IM<V=I9"`B06QR
M96%D>2!%>&ES=',B"FUS9W-T<B`BP,RYS"#!N,#GQ]0B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.CDS"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE
M=&4@)7,_(@IM<V=S='(@(B6XIB#!I+B[(,'VO^RPVKW`M,^Q[C\B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8W"FUS9VED(")!<F4@
M>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C=&5D
M(&5N=')I97,_(@IM<V=S='(@(KRQQ</'T2"PS;7IP+L@P:2XNR#!]K_LL-J]
MP+3/L>X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!
M<V-E;F1I;F<B"FUS9W-T<B`BO\"XI\+WO/@B"@HC.B!S96%R8V@N<&AP.C@U
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS-@IM<V=I9"`B0F%S:6,@
M4V5A<F-H(@IM<V=S='(@(K'BNKL@L,N[]B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-3@*;7-G:60@(D)E;&]W('-E87)C:"!F;W)M(@IM<V=S='(@
M(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S<@;&EB+T1R:79E<B]L9&%P
M+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL
M960Z("@E<RD@)7,B"FUS9W-T<B`BO/;!I""]Q\>E.B`H)7,I("5S(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A
M>2(*;7-G<W1R("*[_<#/(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*(RP@
M9G5Z>GD*;7-G:60@(D)R;W=S92(*;7-G<W1R(")?0L6]N_8B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)U<VEN97-S($-A
M=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C0Y"FUS9VED(")#4U8B
M"FUS9W-T<B`B0U-6(@H*(SH@;&EB+T]B:F5C="]'<F]U<"YP:'`Z-3<*;7-G
M:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I
M9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(KRQQ<,B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E
M(&$@;F%M92(*;7-G<W1R("+!UKS2M\\@O+'%PR(*"B,Z(&%D9"YP:'`Z-#@*
M;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLB"FUS9W-T<B`BP=:\TK?/
M(+RQQ<,B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR
M,C$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLZ(@IM
M<V=S='(@(L'6O-*WSR"\L<7#(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E
M<W-B;V]K<V5L96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R
M97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*(RP@9G5Z>GD*
M;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O('5S92XB"FUS
M9W-T<B`BP=:\TK?/(+RQQ<,B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR,C@*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!W:&EC:"!C
M;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H870@;W)D97(Z(@IM<V=S='(@
M(L'6O-(@N/&WS\#'(,2NM[,@QZ6]PR"\^+RM(+RQQ<,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D-O;'5M;B!/<'1I;VYS(@IM<V=S
M='(@(L3#M[,@O\F\QR(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE
M8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I
M<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")#
M;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(L3>N+:WSB"QN+K0M<@@
ML*HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$S"FUS9VED(")#
M;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RDB"FUS
M9W-T<B`BQ-ZXMK?.(+&XNM"UR""PJBB^QK_TM^@@O^LI(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T
M<B`BR+B[YR(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`IM
M<V=I9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S='(@(LBXN^<@P=:\TB(*"B,Z
M(&QI8B]A<&DN<&AP.C,Q."!L:6(O87!I+G!H<#HS-C,@;&EB+V%P:2YP:'`Z
M-#`W(&QI8B]A<&DN<&AP.C0Y,0HC.B!L:6(O87!I+G!H<#HV,#$@;&EB+V%P
M:2YP:'`Z-C@X(&QI8B]A<&DN<&AP.C<T,2!L:6(O87!I+G!H<#HX,3D*(SH@
M;&EB+V%P:2YP:'`Z,3`P-B!L:6(O87!I+G!H<#HQ,#DT"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("*_K+#A
M(+W'QM`Z("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(K^LL.$@O<?&T"(*"B,Z(&)R
M;W=S92YP:'`Z,3DQ(&)R;W=S92YP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")#
M;VYT86-T(&%D9&5D('1O(&QI<W0N(@IM<V=S='(@(B5S(+BNO;K&KL#'(+^L
MMO3#LR"X\;?/(@H*(SH@8G)O=W-E+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B
M0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES="XB"FUS9W-T<B`BN*Z]NL:NOZ&\
MK2#!IK#%(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`B)7,@N*Z]NL:NP,<@
MOZRV],.S(+CQM\\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C$R"FUS9VED(")#;W!Y(@IM<V=S='(@(KJYN^<B"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHU,PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E(@IM
M<V=S='(@(KO]O+HB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHT
M,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O:R(*;7-G<W1R
M("*PL\#.(,'6O-*WSR(*"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED
M(")#<F5A=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC
M.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S
M='(@(KO]O+HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@
M(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(K'BNKL@P:2W
MQ""YYKG](@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z(&QI8B]/8FIE8W0N<&AP
M.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z-3`*
M;7-G:60@(D1E;&5T92(*;7-G<W1R("*[Z,&F(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!!9&1R
M97-S($)O;VLB"FUS9W-T<B`BP=:\TK?/(+RQQ<,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS
M9W-T<B`BN^C!IB#(KL#.(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M"FUS9VED(")$96QE=&4@8G5T=&]N(&)E:&%V:6]U<B(*;7-G<W1R("*[Z,&F
M(+GVQK`@M;_`VR(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C<P"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92!F86EL960Z("@E<RD@)7,B"FUS9W-T
M<B`BN^C!IB"]Q\;0.B`H)7,I("5S(@H*(SH@9&5L971E+G!H<#HS.`IM<V=I
M9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q,PIM<V=I9"`B1&5P87)T;65N
M="(*;7-G<W1R("*ZSKRM(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW
M"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(K.[N++"][SX(@H*(SH@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3$U"FUS9VED(")$97-C<FEP=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z
M,3$X"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`BM?"WNL7DN*XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@(D1I<W!L
M87DB"FUS9W-T<B`BR*VXZ2"\L\&D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3<V"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C
M;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_(@IM<V=S='(@(L'VO^\@MJ<@R*[`
MSL?/L>(B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@
M(D1O=VYL;V%D(@IM<V=S='(@(G9#87)D(+.[M\&YWK'B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]R;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C
M=')O=RYI;F,Z,C4*;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(G9#
M87)D(+.[M\&YWK'B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M,3`R('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHR-0HC.B!T96UP;&%T97,O
M8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ,"!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C,*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W
M+FEN8SHS,R!L:6(O4F5N9&5R97(N<&AP.C0R"FUS9VED(")%9&ET(@IM<V=S
M='(@(KSVP:0B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4@=&5M
M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`BO/;!I"`G)7,G
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*(RP@9G5Z>GD*
M;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G<W1R("+!UKS2M\\@L[NZ
MN+.[L>(B"@HC.B!E9&ET+G!H<#HW."!E9&ET+G!H<#HQ-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!E;G1R>2!F;W(@)7,B"FUS9W-T<B`B)7,@Q]>X
M\2"\]L&D(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-3@*;7-G
M:60@(D5M86EL(@IM<V=S='(@(L#,N-[`SR(*"B,Z(&5D:70N<&AP.C$T-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"P@8G5T
M('-A=FEN9R!T:&4@=7!L;V%D960@9FEL92!F86EL960Z("5S(@IM<V=S='(@
M(B(*"B,Z(&5D:70N<&AP.C$T.2!E9&ET+G!H<#HQ-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960N(@IM<V=S='(@(B5S(+SV
MP:2URB(*"B,Z(&)R;W=S92YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D5N=')Y
M('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("(E<R#&Q,#/P+L@O+JP
M^,#[P+BWSB"PH<&NO]2]P+3/M-DN(@H*(SH@;&EB+V%P:2YP:'`Z-#$S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96%R8VAI;F<@=&AE
M(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`BP=:\TK?/(,&BL=D@O<?&T#H@
M)7,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C8@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@
M(K.[NKBSN['B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHV"FUS
M9VED(")%>'!O<G0@061D<F5S<R!";V]K(@IM<V=S='(@(L'6O-*WSR"SN[JX
ML[NQXB(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@
M(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP
M;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H<#HR,C@@9&%T82YP
M:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY,`HC.B!B<F]W<V4N
M<&AP.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E
M<R(*;7-G<W1R("+!UKS2M\\@P:*QV2"]Q\;0.B`E<R(*"B,Z(&)R;W=S92YP
M:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@)7,@
M=&\@)7,Z("5S(@IM<V=S='(@(B5SN*8@)7._H2##W["A(+W'QM`@.B`E<R(*
M"B,Z(&)R;W=S92YP:'`Z,C<R"FUS9VED(")&86EL960@=&\@8G)O=W-E(&QI
M<W0B"FUS9W-T<B`BN*Z]NL:N(,6]N_8@O<?&T"(*"B,Z(&)R;W=S92YP:'`Z
M,S$P"FUS9VED(")&86EL960@=&\@8G)O=W-E('1H92!D:7)E8W1O<GDB"FUS
M9W-T<B`BM?"WNL7DN*X@L,N[]KW'QM`B"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C,P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8VAA;F=E
M(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@/2`E<RP@4F]O
M="`]("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(P"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E
M9#H@)7,B"FUS9W-T<B`BP]^PH<?2(+3KN_/`NR##H\'V(+CXQ]0Z)7,B"@HC
M.B!S96%R8V@N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@<V5A
M<F-H('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`BP=:\TK?/(,&BL=D@O<?&
MT#H@)7,B"@HC.B!D871A+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E<R(*;7-G<W1R("*U
M\+>ZQ>2XKB"PR[OV(+W'QM`Z("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,38W"FUS9VED(")&87@B"FUS9W-T<B`BQM&]NB(*"B,Z(&5D
M:70N<&AP.C$R-"!D:7-P;&%Y+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D9I
M;&5S(@IM<V=S='(@(L&FN/$B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z-S`*;7-G:60@(D9I;F0B"FUS9W-T<B`BPZ.QXB(*"B,Z(&5D:70N
M<&AP.CDW(&5D:70N<&AP.C$X-PHC+"!F=7IZ>0IM<V=I9"`B1FEN:7-H(@IM
M<V=S='(@(L.CL>(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT
M.`IM<V=I9"`B1FER<W0@3F%M92(*;7-G<W1R("+`S+BG(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@S
M"FUS9VED(")&<F]M(@IM<V=S='(@(L"GQ*$B"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HV,#0*;7-G:60@(D=L;V)A;"!!9&1R97-S($)O;VLB"FUS
M9W-T<B`BP/S#O"#!UKS2M\\B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT-`IM<V=I
M9"`B1W)O=7`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+!_2#!UKS2
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3,*;7-G:60@(DAO
M;64@0VET>2(*;7-G<W1R("*UM;W#(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3`X"FUS9VED(")(;VUE($-O=6YT<GDB"FUS9W-T<B`BL;FP
MH2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U,`IM<V=I9"`B
M2&]M92!0:&]N92(*;7-G<W1R("+!_2#`_,BM(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3`S"FUS9VED(")(;VUE(%!O<W1A;"!#;V1E(@IM
M<V=S='(@(K_LQNVY^,BC(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z.3@*;7-G:60@(DAO;64@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`BO<,O
MM;4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX.`IM<V=I9"`B
M2&]M92!3=')E970@061D<F5S<R(*;7-G<W1R("+!_2#!UKS2(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z-3`V"FUS9VED("))35-0(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-PHC+"!F=7IZ>0IM<V=I
M9"`B24U34"!!9&1R97-S($)O;VL@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MP=:\TK?/(+BNO;K&KB(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D<F5S<R!";V]K+"!3
M=&5P("5D(@IM<V=S='(@(L'6O-*WSR"PH<&NO\"QXBP@M-RPZ"`E9"(*"B,Z
M(&1A=&$N<&AP.C,V,0IM<V=I9"`B26UP;W)T+T5X<&]R="!!9&1R97-S($)O
M;VMS(@IM<V=S='(@(L'6O-*WSR"PH<&NO\"QXB^SN[JXL[NQXB(*"B,Z(&QI
M8B]A<&DN<&AP.C4Y-B!L:6(O87!I+G!H<#HV.#,*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@240B"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@;&EB+V%P
M:2YP:'`Z,C,P(&QI8B]A<&DN<&AP.C0P,B!L:6(O87!I+G!H<#HT.#8@;&EB
M+V%P:2YP:'`Z-3DR"B,Z(&QI8B]A<&DN<&AP.C8W.2!L:6(O87!I+G!H<#HW
M,S$@;&EB+V%P:2YP:'`Z,3`W-PIM<V=I9"`B26YV86QI9"!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`BP-^X^+7((,'6O-*WSR(*"B,Z(&QI8B]A<&DN<&AP.C$P
M.#$@;&EB+V%P:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ,C`W"FUS9VED("))
M;G9A;&ED(&5M86EL(@IM<V=S='(@(L#?N/BUR"#`S+C>P,\N(@H*(SH@;&EB
M+V%P:2YP:'`Z,3`X.0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!E;G1R>2(*
M;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C(V-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!K97D@<W!E8VEF:65D+B(*
M;7-G<W1R("*YKL#:OZT@P-2WPB"_P+?Y(@H*(SH@;&EB+V%P:2YP:'`Z,3`X
M-0IM<V=I9"`B26YV86QI9"!N86UE(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*
M"B,Z(&QI8B]A<&DN<&AP.C<S-0IM<V=I9"`B26YV86QI9"!O8FIE8W1)9"(*
M;7-G<W1R("+`W[CXM<@@L+3#O""^QL#,M?`B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C,P"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@
M8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L
M;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S@*
M;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`BN+;!]KBW(+SVP:0B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PIM<V=I9"`B3&%S="!.
M86UE(@IM<V=S='(@(KRZ(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?
M:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`BN*Z]NL:N(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<W"FUS9VED(")-871C
M:&EN9R(*;7-G<W1R("+#H[3"(+FNP-J_K2(*"B,Z(&QI8B]A<&DN<&AP.C(P
M-0HC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B
M"FUS9W-T<B`BP]:TZR#&Y,#,P?:\]B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM<V=S
M='(@(L/6M.L@QN3`S,'VO/8B"@HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HS"B,L(&9U>GIY"FUS9VED(")-96YU($QI<W0B"FUS9W-T<B`BN_4@N*Z]
MNL:N(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,*;7-G:60@(DUI
M;FD@4V5A<F-H(@IM<V=S='(@(K"CM-S'T2"PR[OV(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI<W-I;F<@1$X@:6X@3$1!4"!S;W5R
M8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,38R"FUS9VED(")-;V)I;&4@4&AO;F4B"FUS9W-T
M<B`BQ]JUY<;Y(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,S(@;&EB+T1R
M:79E<B]L9&%P+G!H<#HS-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y
M(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("*\]L&D(+W'QZ4Z("@E<RD@)7,B
M"@HC.B!L:6(O87!I+G!H<#HQ,3DS"FUS9VED(")-;W)E('1H86X@,2!E;G1R
M>2!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C$Q"FUS9VED(")-;W9E(@IM<V=S='(@(L#,M;\B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S
M+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*;7-G:60@(DUO=F4@
M;&5F="(*;7-G<W1R("*_WL+*P+BWSB#`S+6_(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y"B,Z('1E;7!L871E<R]P<F5F<R]A
M9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V"FUS9VED(")-;W9E(')I9VAT(@IM
M<V=S='(@(K_`N*7"RL"XM\X@P,RUOR(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,38*;7-G:60@(DUU;&)E<G)Y($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")-=6QB97)R>2#!UKS2M\\B"@HC.B!L:6(O87!I
M+G!H<#HQ,3$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUU;'1I<&QE('!E
M<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL(&)U="!N;VYE('=I=&@@;F%M92!;
M)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T<B`B)7,@P=:\TKBF(+"AP?@@N^>V
M]\"Z(,#,N<P@P-;`N+.J+"`E<R#`S+BGP+BWSB#!N,#GQ\^TPB"PS<"Z(+[X
MP+TB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ,#<@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z,C0S"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S
M($)O;VLB"FUS9W-T<B`BL[L@P=:\TK?/(@H*(SH@861D<F5S<V)O;VMS+G!H
M<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B"FUS9W-T
M<B`BL[L@P=:\TK?/(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M,3`W(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0R"FUS9VED(").86UE
M(@IM<V=S='(@(L#,N*<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*
M;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@(L#,N*<@Q_R]Q"(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T8V5N=&5R($UE
M;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@861D+G!H<#HS-B!A9&0N
M<&AP.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*(SH@;&EB+T)L
M;V-K+W1R965?;65N=2YP:'`Z,C<*;7-G:60@(DYE=R!#;VYT86-T(@IM<V=S
M='(@(KOUM\Z_[B"_K+;TP[,@P]^PH2(*"B,Z(&5D:70N<&AP.C@X(&5D:70N
M<&AP.CDU(&5D:70N<&AP.C(P,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C0U"FUS9VED(").97AT(@IM<V=S='(@(K39P+TB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HR,3@*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@
M(KJPN.TB"@HC.B!L:6(O87!I+G!H<#HQ,3DU(&QI8B]A<&DN<&AP.C$R-#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO("5S(&5N=')Y(&9O=6YD
M(&9O<B`E<R(*;7-G<W1R("(E<R#'U[CQ(+SVP:0B"@HC.B!L:6(O87!I+G!H
M<#HQ,38S"FUS9VED(").;R!A9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R
M("+!UKS2M\\@OOC`O2(*"B,Z(&UI;FES96%R8V@N<&AP.C@S"FUS9VED(").
M;R!C;VYT86-T<R!F;W5N9"(*;7-G<W1R("*_K+;TP[,@OOC`O2(*"B,Z(&QI
M8B]A<&DN<&AP.C4Q,2!L:6(O87!I+G!H<#HW-C8*;7-G:60@(DYO('9#87)D
M(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R(")V0V%R9"#!I+JX(,.CP?8@N/C'
MU"(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHW"FUS9VED(").
M;VYE(@IM<V=S='(@(KRQQ</'S\'V(+[*P+TB"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM<V=S='(@(L+\P;8B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(").=6UB97(@
M;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T<B`BQN3`S,'VM.<@L.&P^B"PN;SV
M(@H*(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<T-PIM<V=I9"`B
M3V)J96-T(&YO="!F;W5N9"(*;7-G<W1R("+#H\'V(+CXQ]0B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,C,*;7-G:60@(D]F9FEC92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(S"FUS
M9VED("(B"B)/;F-E('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H92!A
M9&1R97-S(&)O;VL@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B!)
M9B!T:&ES(&ES(&YO="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T(&-H
M86YG92!Y;W5R('-E;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z-S<T"FUS9VED(")/;FQY(&]N92!V8V%R9"!S
M=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D]T:&5R($]P
M=&EO;G,B"FUS9W-T<B`BL>+%N""\L\&D(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3DP"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HT.34@;&EB+V%P:2YP:'`Z-C`U(&QI8B]A
M<&DN<&AP.C8Y,B!L:6(O87!I+G!H<#HY,S0*(SH@;&EB+V%P:2YP:'`Z,3`Y
M.`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`BL<?'T2"^^,"]
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z-30S"FUS9VED(")097)M:7-S:6]N(&1E
M;FEE9"(*;7-G<W1R("*QQ\?1(+[XP+TB"@HC.B!T96UP;&%T97,O861D<F5S
M<V)O;VMS+FEN8SHY.0HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`BL<?'T2"^^,"](@H*(SH@9&%T82YP:'`Z-3,@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B4&EN92!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B4&EN92#!UKS2M\\B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C(X"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@;F%M92!T:&4@
M;F5W(&-O;G1A8W0@;&ES=#HB"FUS9W-T<B`BN_6WSK_N(+BNO;K&KL#'(,#,
MN*?`NR#`U+?"Q\^\O+_D.B(*"B,Z(&5D:70N<&AP.CDQ(&5D:70N<&AP.CDT
M(&5D:70N<&AP.C$Y-`IM<V=I9"`B4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-#$V"FUS9VED(")0<FEV871E($%D
M9')E<W,@0F]O:R(*;7-G<W1R("*PL\#.(,'6O-*WSR(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(E%U97)Y(&9A
M:6QE9#H@*"5S*2`E<R(*;7-G<W1R("*PR[OV(+W'QM`Z("@E<RD@)7,B"@HC
M.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,3@*;7-G:60@(E%U
M:6-K(%-E87)C:"(*;7-G<W1R("*[H;BN(,.CL>(B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C$Y,2!L:6(O1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I
M=F5R+VQD87`N<&AP.C0R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`BL,N[]B"]Q\;0.B`H)7,I
M("5S(@H*(SH@;&EB+U)E;F1E<F5R+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E
M;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB
M"FUS9W-T<B`BQZ6]PR(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O
M:W-E;&5C="YI;F,Z,3<V"B,L(&9U>GIY"FUS9VED(")296UO=F4@861D<F5S
M<R!B;V]K(@IM<V=S='(@(L'6O-*WSR"\L<7#(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-O;'5M;G-E;&5C="YI;F,Z,C,Y"FUS9VED(")296UO=F4@8V]L=6UN
M(@IM<V=S='(@(L2NM[,@N^C!IB(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,@IM<V=I9"`B4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S
M='(@(KBNO;K&KK^AO*T@P::PQ2(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@
M861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY7
M87)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C
M=7)R96YT(&%D9')E<W,@8F]O:RX\+W-T<F]N9SXB"FUS9W-T<B`B(@HBL*'!
MKK_"(+#-P+BWSB"QXL&X(,'6O-*WS\"[(+G9LMRQ[K_D/R`\8C[!UL#'.B#`
MS+#-P+H@Q_;`YR#!UKS2M\_`QR"X\+7G(,?7N/$B"B+`NR#!]K_SM,^TV2X\
M+V(^(@H*(SH@;&EB+T1R:79E<BYP:'`Z-#,X"B,L(&9U>GIY"FUS9VED(")2
M97%U97-T960@;V)J96-T(&YO="!F;W5N9"XB"FUS9W-T<B`BPZ/!]B"X^,?4
M(@H*(SH@861D+G!H<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z
M,3$S"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R("+#RK'BR*TB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.38*;7-G:60@(E,O
M34E-12!0=6)L:6,@0V5R=&EF:6-A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HV.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4U1!4E143%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(K#+N_8@O<?&T#H@
M*"5S*2`E<R(*"B,Z(&5D:70N<&AP.CDY(&%D9"YP:'`Z,S<@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S='(@(L#Z
MP.4B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.38@=&5M<&QA
M=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q,@HC.B!T96UP;&%T97,O8FQO8VLO
M;6EN:7-E87)C:"YI;F,Z,C$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z-#D*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B4V5A<F-H(@IM
M<V=S='(@(K#+N_8B"@HC.B!M:6YI<V5A<F-H+G!H<#HV,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H(%)E<W5L=',Z(@IM<V=S='(@(K#+N_8@L.&P^B(*"B,Z
M(&QI8B]A<&DN<&AP.C$P,3$*;7-G:60@(E-E87)C:"!F86EL960B"FUS9W-T
M<B`BL,N[]B"]Q\;0(@H*(SH@;&EB+V%P:2YP:'`Z,3$P,R!L:6(O87!I+G!H
M<#HQ,3`Y(&QI8B]A<&DN<&AP.C$Q,3@@;&EB+V%P:2YP:'`Z,3$S,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R("*P
MR[OV(+W'QM`Z("5S(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N
M:6YC.C(R"FUS9VED(")396%R8VAI;F<N+BXB"FUS9W-T<B`BPZ.TPL'?+BXN
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C8*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@9&5L971E(@IM<V=S
M='(@(K.[NKBSOB#!UKS2M\\@O+'%PSHB"@HC.B!T96UP;&%T97,O861D<F5S
M<V)O;VMS+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%D9')E
M<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(K"AP:Z_PR#!UKS2M\\@O+'%PSHB
M"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C,R"FUS9VED(")396QE
M8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T<B`B
ML[NZN+.^(,'6O-*WSR"\L<7#.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,C8*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&EM
M<&]R="!T;SHB"FUS9W-T<B`BL*'!KK_#(,'6O-*WSR"\L<7#.B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S4*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@
M(KS2O;H@QL3`SR#&][C+(+RQQ<,B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$P"FUS9VED(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM
M<V=S='(@(K.[NKBSN['B(,?\O<0@O+'%PR(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z-#,*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O
M<G0Z(@IM<V=S='(@(L#3QO?&KL?2(,;$P,\@O+'%PSHB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA
M="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(KS2O;H@QL3`SR#&][C+
M(+RQQ<,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")3
M96QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@;F%M97,Z(@IM<V=S
M='(@(L#,N*<@QZ6]PR#'_+W$(+RQQ<,Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P
M;&%Y(&)Y(&1E9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I
M;VYS+B(*;7-G<W1R("*QXKJ[(,>EO<,@O+'%PR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.`IM<V=I9"`B4V5L96-T('=H:6-H(&9I96QD<R!T;R!D
M:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+B(*;7-G<W1R("+!UKS2(+BN
MO;K&KK^A(,>EO</'TB#'U[CQ(+RQQ<,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S(*;7-G:60@(E-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA
M>2!N86UE<RXB"FUS9W-T<B`BP,RXIR#'I;W#(,?\O<0@O+'%PR(*"B,Z(&%D
M9"YP:'`Z-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-E;&5C=&5D
M(&%D9')E<W,@8F]O:R!<(B5S7"(N(@IM<V=S='(@(L'6O-*WSR`G)7,G(+RQ
MQ<,B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ-S,*;7-G:60@(E-H
M87)E9"!$:7)E8W1O<GDB"FUS9W-T<B`BL/C`KR"U\+>ZQ>2XKB(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`BN*Z]NL:N(+JXL>(B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0Q"FUS9VED(")3:&]W
M($%L;"(*;7-G<W1R("*X\+7.(+JXL>(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C0P"FUS9VED(")3:&]W($-O;G1A8W1S(@IM<V=S='(@
M(K^LMO3#LR"ZN+'B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHS.0IM<V=I9"`B4VAO=R!,:7-T<R(*;7-G<W1R("*XKKVZQJX@NKBQXB(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C(Q"B,Z
M('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C,T"FUS9VED
M(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R("+!I+?$(+GFN?TB"@HC.B!L:6(O
M87!I+G!H<#HQ.3@*;7-G:60@(E-O=7)C97,B"FUS9W-T<B`BO-*]NB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3<*;7-G:60@(E-P96-I9GD@=VAE
M<F4@>6]U('=A;G0@861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R
M+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$T,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,B"FUS9W-T<B`B
M)7.PH2`E<[^A(+RZL/C`^\"XM\X@P]^PH;7*(@H*(SH@8G)O=W-E+G!H<#HR
M,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C
M<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R("(E<["A
M("5SOZ$@O+JP^,#[P+BWSB##W["AM<HB"@HC.B!D871A+G!H<#HU,`HC+"!F
M=7IZ>0IM<V=I9"`B5%-6(@IM<V=S='(@(D-35B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`BQ<?`N+?.
M(+&XNM"UR""PJB(*"B,Z('9I97<N<&AP.C$U"FUS9VED(")4:&4@5D93(&)A
M8VME;F0@;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@871T86-H
M;65N="!U<&QO861S+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M,#4T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B
M;V]K(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BP=:\TK?/P+L@
MNO&_[R"\]B"^^+W`M,^TV3H@)7,B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C0U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K
M(%PB)7-<(B!W87,@8W)E871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(L'6
MO-*WS\#,(+RZL/C`^\"XM\X@NO&_]L'\(@H*(SH@861D<F5S<V)O;VMS+G!H
M<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@
M8F]O:R!<(B5S7"(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M("+!UKS2M\_`S""\NK#XP/O`N+?.(+KQO_;!_"(*"B,Z(&%D9')E<W-B;V]K
M<RYP:'`Z.#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R
M97-S(&)O;VL@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS
M9W-T<B`BP=:\TK?/P,P@O+JP^,#[P+BWSB"Z\;_VP?PB"@HC.B!D871A+G!H
M<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!C
M;W5L9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R("+!UKS2M\_`NR"Z\;_O
M(+SV(+[XO<"TS[39.B`E<R(*"B,Z(&5D:70N<&AP.C0W('9C87)D+G!H<#HR
M,B!D:7-P;&%Y+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A
M8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BO^3#
MN\?1(+^LMO3#L["A(+[XO<"TS[39+B(*"B,Z(&5D:70N<&AP.C$Q-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S
M=6-C97-S9G5L;'D@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(E<R#&Q,#/P+L@
MO+JP^,#[P+BWSB"PH<&NO]2]P+3/M-DN(@H*(SH@9&%T82YP:'`Z,C@T"FUS
M9VED(")4:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W
M87)N:6YG<RXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RXB"FUS9W-T
M<B`BQ;V[]K"AM,G'T2#!UKS2M\_`S""^^+W`M,^TV2XB"@HC.B!A9&0N<&AP
M.C(Y"FUS9VED("(B"B)4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E<W,@
M8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS("(*
M(F%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I
M97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R`B"B)I<R!A;B!E<G)O
M<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@HBN_6WSK_N(,?7N/'`NR##W["AQ](@O/8@P-:UM;?/(+RS
MP:2UR"#!UKS2M\_`S""^^+W`M,^TV2X@N+B^X"#`S+#-P,P@O\"W^;;S(@HB
ML.T@N_VPHL?/O<6TV;CI+""P_+BNP-J_H;#4(+FNP,?'S[W#L>(@N=FV^+3/
MM-DN(@H*(SH@861D+G!H<#HQ,C$*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!A9&1I;F<@=&AE(&YE=R!C;VYT86-T+B!#;VYT86-T('EO=7(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(@(@HB9F]R(&9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`BP]^PH<?/M,*UI2"_P+?YL*$@N=^[_<??O<"TS[39+B"P_+BNP-J_H;#4
M(+6UO_+`NR"_Y,.[Q\^]P['B(+G9MOBTS[39+B(*"B,Z(&)R;W=S92YP:'`Z
M,3@Y(&)R;W=S92YP:'`Z,C,P"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@861D:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R("*[Z,&F(+_`
MM_DB"@HC.B!B<F]W<V4N<&AP.C(S.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N(@IM<V=S='(@(KOUM\Z_[B"XKKVZ
MQJX@N+BUZ;'B(+_`M_DB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E
M871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(KSVP:0@O\"W
M^3H@)7,B"@HC.B!B<F]W<V4N<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(%PB)7-<(B!F
M<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+B(*;7-G<W1R("*[Z,&F(+_`
MM_DZ("5S(@H*(SH@9&5L971E+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E
M<R(*;7-G<W1R("*[Z,&F(+_`M_D@.B`E<R(*"B,Z(&)R;W=S92YP:'`Z-S(*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C
M="XB"FUS9W-T<B`BN^C!IB"_P+?Y(@H*(SH@8G)O=W-E+G!H<#HR-S@*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M92!L:7-T(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0(#0N,"UC=G,I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0(#0N,"UC
M=G,I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0(#0N,"UC=G,I("`C+2,M(RTC+2-<;B(*(KC>O+S!]B#`_+S;(+_`M_E<
M;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B*XWKR\P?8@NKBSN['B(+_`M_E<;B(*(B,M(RTC+2,M(R`@:V]?
M2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B*XWKR\P?8@NKBS
MN['B(+_`M_E<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B*XWKR\P?8@NKBSN['B(+_`M_E<;B(*(B,M(RTC
M+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B*X
MWKR\P?8@NKBSN['B(+_`M_E<;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-
M4"`T+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B*XWKR\P?8@NKBSN['B(+_`M_E<
M;B(*(B,M(RTC+2,M(R`@:V]?2U(N<&\@*$E-4"`T+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B*XWKR\P?8@NKBSN['B(+_`M_DB"@HC.B!D871A+G!H<#HS,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`BM:7`S,6X(+"AP:Z_P+'B(+_`
MM_DZ("5S(@H*(SH@;&EB+V%P:2YP:'`Z-3`W(&QI8B]A<&DN<&AP.C<V,0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<B"UI<#,Q<T@L*'!KK_`L>(@
MO\"W^2(*"B,Z(&)R;W=S92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!R96UO=FEN9R!A(&-O;G1A8W0@9G)O;2!T:&4@;&ES
M="XB"FUS9W-T<B`BN_6WSK_N(+BNO;K&KB"XN+7IL>(@O\"W^2(*"B,Z(&%D
M9')E<W-B;V]K<RYP:'`Z-34@861D<F5S<V)O;VMS+G!H<#HV,"!A9&1R97-S
M8F]O:W,N<&AP.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@<F5M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S
M(@IM<V=S='(@(L&FL,4@O\"W^2(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#$@
M861D<F5S<V)O;VMS+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@861D<F5S<R!B
M;V]K.B`E<R(*;7-G<W1R("*\]L&D(+_`M_DZ("5S(@H*(SH@961I="YP:'`Z
M,34X"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&ES(&5N=')Y.B`E<R(*;7-G<W1R("*\]L&D(+_`M_DZ("5S
M(@H*(SH@9&%T82YP:'`Z,3<Y"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E
M<W-E<R!T;R!E>'!O<G0N(@IM<V=S='(@(K"AP:Z_PR"\]B#`UK3"(,'6O-*P
MH2"^^+W`M,^TV2XB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS
M96QE8W0N:6YC.C$X,`IM<V=I9"`B5&AE<V4@861D<F5S<R!B;V]K<R!W:6QL
M(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0S"FUS9VED(")4:&5S92!C
M;VQU;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B
M"@HC.B!D871A+G!H<#HR-CD*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3$R
M,B!L:6(O87!I+G!H<#HQ,3,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@
M8F]O:R(*;7-G<W1R("(G)7,GM,(@P,RYS"#!UKS2M\^_H2"U[K?/M<>^[B#`
MUKW`M,^TV2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30W"FUS9VED
M("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K('=H
M96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@(E1I=&QE
M(@IM<V=S='(@(L&FN/$B"@HC.B!L:6(O5'5R8F$N<&AP.C0S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R92X@($UI
M<W-I;F<@<V]U<F-E('1Y<&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B)7,@P:3`Q[BF(,#0P+L@
MO/8@OOB]P+3/M-DN(@H*(SH@961I="YP:'`Z.#@@961I="YP:'`Z.3$@961I
M="YP:'`Z.30@961I="YP:'`Z.3D@961I="YP:'`Z,3DV"FUS9VED(")5;F1O
M($-H86YG97,B"FUS9W-T<B`BNJ^PYKOGQ]<@M<>UN;BNL>(B"@HC.B!L:6(O
M87!I+G!H<#HU-#`@;&EB+V%P:2YP:'`Z-C0S(&QI8B]A<&DN<&AP.C<W.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N
M="U4>7!E.B`E<R(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!C;VYF:6<O
M<V]U<F-E<RYP:'`N9&ES=#HS-S8*;7-G:60@(E9E<FES:6=N($1I<F5C=&]R
M>2(*;7-G<W1R(")697)I<VEG;B"U\+>ZQ>2XKB(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N
M:6YC.C(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(%PB)7-<
M(B(*;7-G<W1R("(G)7,G(+JXL>(B"@HC.B!M:6YI<V5A<F-H+G!H<#HW.`IM
M<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(K^LMO3#LR"ZN+'B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE=R!T;R!D:7-P
M;&%Y(&)Y(&1E9F%U;'0Z(@IM<V=S='(@(L.Y(+'BNKL@R*VXZ2(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!5
M4DPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3$S"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BP??`Y2#!UKS2(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(T"FUS9VED(")7;W)K
M($-I='DB"FUS9W-T<B`BP??`Y2"UM;W#(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3,Y"FUS9VED(")7;W)K($-O=6YT<GDB"FUS9W-T<B`B
MP??`Y2"QN;"A(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34V
M"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(L'WP.4@P/S(K2(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S-`IM<V=I9"`B5V]R:R!0;W-T
M86P@0V]D92(*;7-G<W1R("+!]\#E(+_LQNVY^,BC(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3(Y"FUS9VED(")7;W)K(%-T871E+U!R;W9I
M;F-E(@IM<V=S='(@(L'WP.4@O<,OM;4B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ,3D*;7-G:60@(E=O<FL@4W1R965T($%D9')E<W,B"FUS
M9W-T<B`BP??`Y2#!UKS2(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP:'`Z
M.3,@8G)O=W-E+G!H<#HR,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@8V]N=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H
M<#HV.2!D:7-P;&%Y+G!H<#HU."!V:65W+G!H<#HS-@HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O
M;G1A8W0N(@IM<V=S='(@(L#,(+CQM\_`NR"ZO""\]B#`UK3"(+''Q]&XN"#`
MUKW`M,^TV2XB"@HC.B!V8V%R9"YP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N
M(@IM<V=S='(@(L#,(+CQM\_`NR"ZO""\]B#`UK3"(+''Q]&XN"#`UKW`M,^T
MV2XB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C4U"FUS
M9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("+!UKS2M\_`NR"\L<7#Q]B^WR#'U;3/M-DN(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHR,PIM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&$@=&%R9V5T(&QI<W0N(@IM<V=S='(@(KBNO;K&KKBF(+RQQ</'
MV+[?(,?5M,^TV2XB"@HC.B!E9&ET+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+B(*
M;7-G<W1R("*_K+;TP[.XIB"XU<#Z(+RQQ</'S[R\O^0N(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E
M+VIA=F%S8W)I<'0N:6YC.C0Y"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C
M<FEP="YI;F,Z-S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O
M;F4@96YT<GD@9FER<W0N(@IM<V=S='(@(K^LMO3#L[BF(+C5P/H@O+'%P\?/
MO+R_Y"XB"@HC.B!E9&ET+G!H<#HW,PIM<V=I9"`B66]U(&]N;'D@:&%V92!P
M97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R("+`S""X
M\;?/P+L@NKP@O/8@P-:TPB"QQ\?1N+@@P-:]P+3/M-DN(@H*(SH@8G)O=W-E
M+G!H<#HR.#4*;7-G:60@(EEO=7(@9&5F875L="!A9&1R97-S(&)O;VL@:7,@
M;F]T(&)R;W=S96%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O<F]W+FEN8SHV('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z
M,3(*;7-G:60@(EMN;R!V86QU95TB"FUS9W-T<B`B6["J(+[XP+U=(@H*(SH@
M;&EB+U1U<F)A+G!H<#HT.#0*;7-G:60@(E]"<F]W<V4B"FUS9W-T<B`B7T+%
MO;OV(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`HC+"!F
M=7IZ>0IM<V=I9"`B7T-O;G1A8W1S(@IM<V=S='(@(E]COZRV],.S(+JXL>(B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@(E]$
M96QE=&4B"FUS9W-T<B`B7T2[Z,&F(@H*(SH@;&EB+U1U<F)A+G!H<#HT.3,*
M;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(E])L*'!KK_`L>(OL[NZ
MN+.[L>(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L
M(&9U>GIY"FUS9VED(")?3&ES=',B"FUS9W-T<B`BN*Z]NL:N(@H*(SH@;&EB
M+U1U<F)A+G!H<#HT.#$*(RP@9G5Z>GD*;7-G:60@(E]->2!!9&1R97-S($)O
M;VMS(@IM<V=S='(@(K.[(,'6O-*WSR(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@W
M"B,L(&9U>GIY"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T<B`BN_6WSK_N
M(+^LMO3#LR##W["A(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHR"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(E]2
MP,P@N*Z]NL:NOZ&\K2#!]K_LL>(B"@HC.B!L:6(O5'5R8F$N<&AP.C0X.0IM
M<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?4[#+N_8B"@HC.B!V8V%R9"YP:'`Z
M-#8*;7-G:60@(F-O;G1A8W0N=F-F(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C$Y.2!D871A+G!H<#HR,#0@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M"FUS9VED(")C;VYT86-T<RYC<W8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M,C`Y"FUS9VED(")C;VYT86-T<RYT<W8B"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")C;VYT86-T<RYV8V8B"FUS9W-T<B`B
MOZRV],.S(+[XP+TB"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC
M.C,T"B,L(&9U>GIY"FUS9VED(")N;VYE(@IM<V=S='(@(KRQQ</'S\'V(+[*
MP+TB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(T"B,L(&9U
M>GIY"FUS9VED(")T;R!A($-O;G1A8W0@3&ES="(*;7-G<W1R("*_K+;TP[,@
MNKBQXB(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,30*(RP@
M9G5Z>GD*;7-G:60@(G1O(&$@9&EF9F5R96YT($%D9')E<W,@0F]O:R(*;7-G
M<W1R("*\L<7#M<@@P=:\TK?/P+BWSB(*"B,Z(&1A=&$N<&AP.C4Q('1E;7!L
M871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$S"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,34@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<&\O97-?15,N<&\`
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P-C(R
M-@`Q,#0Q-S,V,C<U-@`P,3<U,C0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!3<&%N:7-H('1R86YS;&%T:6]N<R!F;W(@
M:&]R9&4@<&%C:V%G90HC(%1R861U8V-I;VYE<R!A;"!E<W!A\6]L('!A<F$@
M96P@<&%Q=65T92!H;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@
M4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K86=E+@HC($%U=&]M871I
M8V%L;'D@9V5N97)A=&5D+"`R,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!4=7)B82`R+C`M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#(M,#$@,3(Z,#8K,#$P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-BTP,BTP,2`Q,CHP-BLP,3`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($UA;G5E;"!0+B!!>6%L82`\;6%Y86QA0'5N97@N97,^7&XB
M"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-
M12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A
M;#TH;B`A/2`Q*3M<;B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI
M;F,Z-#`*;7-G:60@(B!!9&0@86X@24U34"!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B($'Q861I<B!U;F$@3&EB<F5T82!D92!D:7)E8V-I;VYE<R!)35-0(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHR.0IM<V=I9"`B($1E
M;&5T92!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R("(@16QI;6EN87(@=6YA
M($QI8G)E=&$@9&4@9&ER96-C:6]N97,@24U34"(*"B,Z(&1A=&$N<&AP.C,R
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR96%D>2!E>&ES=',@
M86YD('=A<R!N;W0@:6UP;W)T960N(@IM<V=S='(@(EPB)7-<(B!Y82!E>&ES
M=&4@>2!N;R!S92!I;7!O<G3S+B(*"B,Z(&)R;W=S92YP:'`Z,30P"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E
M(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B3F\@<V4@8V]P:?,@7"(E<UPB('!O
M<G%U92!E<R!U;F$@;&ES=&$N(@H*(SH@8G)O=W-E+G!H<#HQ,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@;6]V960@8F5C875S92!I
M="!I<R!A(&QI<W0N(@IM<V=S='(@(DYO('-E('1R87-L863S(%PB)7-<(B!P
M;W)Q=64@97,@=6YA(&QI<W1A+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@*&EE
M+B!*;VAN($1O92DB"FUS9W-T<B`B7").;VUB<F4@07!E;&QI9&]S7"(@("AP
M+F4N($IU86X@3F%D:64I(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z,3,V"FUS9VED(")<(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H:64N($1O
M92P@2F]H;BDB"FUS9W-T<B`B7")!<&5L;&ED;W,L($YO;6)R95PB("AP+F4N
M($YA9&EE+"!*=6%N*2(*"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%D9&5D+B(*;7-G<W1R(")392!H82!A\6%D:61O("5S+B(*
M"B,Z(&1A=&$N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE
M('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R(")%;"!A<F-H:79O("5S
M('-E(&AA(&EM<&]R=&%D;R!S871I<V9A8W1O<FEA;65N=&4B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!A;"`E<R!D92`E<R(*"B,Z
M(&QI8B]4=7)B82YP:'`Z-#8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M061D<F5S<R!";V]K(@IM<V=S='(@(DQI8G)E=&$@9&4@9&ER96-C:6]N97,@
M9&4@)7,B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#(*;7-G:60@
M(D$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B
M"FUS9W-T<B`B2&%C92!F86QT82!U;B!N879E9V%D;W(@8V]N('-O<&]R=&4@
M9&4@:49R86UE<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$V
M,`IM<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T<B`B4V]B<F4@96P@
M9F]R;75L87)I;R!D92!B^G-Q=65D82(*"B,Z('9I97<N<&AP.C4R"B,L('!H
M<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@=&\@)7,B"FUS9W-T<B`B
M06-C97-O(&1E;F5G861O(&$@)7,B"@HC.B!A9&0N<&AP.C4V('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"(*;7-G<W1R(")!
M\6%D:7(@82(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C
M="YI;F,Z,3<T"FUS9VED(")!9&0@861D<F5S<R!B;V]K(@IM<V=S='(@(D'Q
M861I<B!L:6)R971A(&1E(&1I<F5C8VEO;F5S(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z-#@*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@
M861D<F5S<R!B;V]K<R(*;7-G<W1R(")!\6%D:7(@>2!E;&EM:6YA<B!L:6)R
M971A<R!D92!D:7)E8V-I;VYE<R!)35-0(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-O;'5M;G-E;&5C="YI;F,Z,C,W"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S
M='(@(D'Q861I<B!C;VQU;6YA(@H*(SH@961I="YP:'`Z,3,U"FUS9VED(")!
M9&0@9FEL92(*;7-G<W1R(")!\6%D:7(@87)C:&EV;R(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"!T;R(*;7-G<W1R
M(")!\6%D:7(@82(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-3<*;7-G:60@
M(D%D9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").
M;R!S92!P=65D92!A\6%D:7(@8V]N=&%C=&]S+B(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C@V"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`B3&EB<F5T82!D92!D:7)E8V-I;VYE<R(*"B,Z(&)R;W=S92YP:'`Z,C@@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3(U"FUS9VED(")!9&1R97-S
M($)O;VL@3&ES=&EN9R(*;7-G<W1R("),:7-T861O(&1E(&1I<F5C8VEO;F5S
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3`*;7-G:60@(D%D
M9')E<W,@0F]O:W,B"FUS9W-T<B`B3&EB<F5T87,@9&4@9&ER96-C:6]N97,B
M"@HC.B!A9&0N<&AP.C$P.`IM<V=I9"`B061D<F5S<R!B;V]K(&5N=')Y(@IM
M<V=S='(@(D5N=')A9&$@9&4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R(*
M"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B061D<F5S<R!B;V]K('-U8V-E<W-F
M=6QL>2!P=7)G960N(@IM<V=S='(@(E-E(&AA('9A8VEA9&\@8V]R<F5C=&%M
M96YT92!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C8R"FUS9VED(")!9&1R97-S(&)O;VL@=&\@
M9&5L971E("(*;7-G<W1R("),:6)R971A(&1E(&1I<F5C8VEO;F5S(&$@96QI
M;6EN87(@(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T
M+FEN8SHQ-S`*;7-G:60@(D%D9')E<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B
M92!D:7-P;&%Y960Z(@IM<V=S='(@(DQI8G)E=&%S(&1E(&1I<F5C8VEO;F5S
M('%U92!N;R!S92!M;W-T<F%RX6XZ(@H*(SH@<V5A<F-H+G!H<#HX."!T96UP
M;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S@*;7-G:60@(D%D=F%N8V5D(%-E
M87)C:"(*;7-G<W1R(")"^G-Q=65D82!A=F%N>F%D82(*"B,Z(&-O;F9I9R\N
M8F%K+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G:60@(D%L:6%S(@IM<V=S
M='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI
M;F,Z-R!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA+FEN8SHQ,`HC.B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0X"FUS9VED(")!;&PB"FUS
M9W-T<B`B5&]D;R(*"B,Z(&QI8B]A<&DN<&AP.C4U-`IM<V=I9"`B06QR96%D
M>2!%>&ES=',B"FUS9W-T<B`B66$@97AI<W1E(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]J879A<V-R:7!T+FEN8SHY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@)7,_(@IM<V=S
M='(@(K]%<W3A('-E9W5R;R!D92!Q=64@9&5S96$@96QI;6EN87(@)7,_(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHV-PIM<V=I9"`B
M07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E('1H92!S96QE
M8W1E9"!E;G1R:65S/R(*;7-G<W1R("*_17-T82!S96=U<F\@9&4@<75E(&1E
M<V5A(&5L:6UI;F%R(&QA<R!E;G1R861A<R!S96QE8V-I;VYA9&%S/R(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!<V-E;F1I
M;F<B"FUS9W-T<B`B07-C96YD96YT92(*"B,Z('-E87)C:"YP:'`Z.#4@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,W"FUS9VED(")"87-I8R!396%R
M8V@B"FUS9W-T<B`B0OIS<75E9&$@<VEM<&QE(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,34Y"FUS9VED(")"96QO=R!S96%R8V@@9F]R;2(*
M;7-G<W1R(")!(&-O;G1I;G5A8VGS;B!D96P@9F]R;75L87)I;R!D92!B^G-Q
M=65D82(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S<@;&EB+T1R:79E<B]L
M9&%P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R(")(82!F86QL861O(&5L(&5N;&%Z861O.B`H)7,I
M("5S(@H*(SH@8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HQ-S@*
M;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D-U;7!L96'Q;W,B"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B0G)O=W-E(@IM<V=S='(@(D5X86UI
M;F%R(@H*(SH@8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*
M;7-G:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(D-A=&5G;W+M82!D
M92!N96=O8VEO(@H*(SH@9&%T82YP:'`Z-#D*;7-G:60@(D-35B(*;7-G<W1R
M(")#4U8B"@HC.B!L:6(O3V)J96-T+T=R;W5P+G!H<#HU-PIM<V=I9"`B0V%N
M)W0@861D(&$@9W)O=7`@=&\@:71S96QF+B(*;7-G<W1R(").;R!S92!P=65D
M92!A\6%D:7(@=6X@9W)U<&\@82!S[2!M:7-M;RXB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHW"FUS9VED(")#:&5C:R!?06QL
M+TYO;F4B"FUS9W-T<B`B0V]M<')O8F%R(%]4;V1A<R].:6YG=6YA(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#0*;7-G:60@(D-H;V]S92!A
M(&YA;64B"FUS9W-T<B`B16QI:F$@=6X@;F]M8G)E(@H*(SH@861D+G!H<#HT
M.`IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R(")%;&EJ
M82!U;F$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RXB"@HC.B!T96UP;&%T97,O
M<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C$*;7-G:60@(D-H;V]S92!A;B!A
M9&1R97-S(&)O;VLZ(@IM<V=S='(@(D5L:6IA('5N82!L:6)R971A(&1E(&1I
M<F5C8VEO;F5S.B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E
M;&5C="YI;F,Z,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K
M<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B16QI
M:F$@<77I(&QI8G)E=&%S(&1E(&1I<F5C8VEO;F5S(&UO<W1R87(@>2!E;B!Q
M=>D@;W)D96XZ(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3$*
M;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O('5S92XB"FUS
M9W-T<B`B16QI:F$@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!Q=64@<75I
M97)A('5S87(N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI
M;F,Z,C(X"FUS9VED(")#:&]O<V4@=VAI8V@@8V]L=6UN<R!T;R!D:7-P;&%Y
M(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R(")%;&EJ82!Q=>D@8V]L=6UN
M87,@;6]S=')A<B!Y(&5N('%UZ2!O<F1E;CHB"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B0V]L=6UN($]P=&EO;G,B"FUS9W-T
M<B`B3W!C:6]N97,@9&4@8V]L=6UN82(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@
M;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B0V]L=6UN87,@<75E(&YO('-E
M(&UO<W1R87+A;CHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(D-O;6UA('-E
M<&%R871E9"!V86QU97,B"FUS9W-T<B`B5F%L;W)E<R!S97!A<F%D;W,@<&]R
M(&-O;6%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,PIM<V=I
M9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI
M(@IM<V=S='(@(E9A;&]R97,@<V5P87)A9&]S('!O<B!C;VUA<R`H3W5T;&]O
M:R!D92!-:6-R;W-O9G0I(@H*(SH@8V]N9FEG+RYB86LO871T<FEB=71E<RYP
M:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")#;VUP8?'M82(*
M"B,Z(&-O;F9I9R\N8F%K+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"FUS9VED
M(")#;VUP86YY($%D9')E<W,B"FUS9W-T<B`B1&]M:6-I;&EO(&QA8F]R86PB
M"@HC.B!L:6(O87!I+G!H<#HS,C`@;&EB+V%P:2YP:'`Z,S8U(&QI8B]A<&DN
M<&AP.C0P.2!L:6(O87!I+G!H<#HT.3,*(SH@;&EB+V%P:2YP:'`Z-C$Y(&QI
M8B]A<&DN<&AP.C<P-B!L:6(O87!I+G!H<#HW-3D@;&EB+V%P:2YP:'`Z.#,W
M"B,Z(&QI8B]A<&DN<&AP.C$P,C0@;&EB+V%P:2YP:'`Z,3$Q,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M1F%L;&\@86P@8V]N96-T87(Z("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HU.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(D9A;&QO
M(&%L(&-O;F5C=&%R(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,@
M;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C(V"FUS9VED(")#;VYT86-T(%-E
M87)C:"(*;7-G<W1R(")"^G-Q=65D82!D92!C;VYT86-T;W,B"@HC.B!B<F]W
M<V4N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT86-T<R!I;B!L
M:7-T.B`E<R(*;7-G<W1R(")#;VYT86-T;W,@96X@;&$@;&ES=&$Z("5S(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B0V]P
M>2(*;7-G<W1R(")#;W!I87(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHU,PIM<V=I9"`B0W)E871E(@IM<V=S='(@(D-R96%R(@H*(SH@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#`*;7-G:60@(D-R96%T92!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B0W)E87(@;&EB<F5T82!D92!D:7)E8V-I;VYE
M<R(*"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S0X"FUS9VED(")#<F5A=&4@82!N
M97<@0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R(")#<F5A<B!U;F$@;G5E=F$@
M3&ES=&$@96XZ(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S,PIM<V=I9"`B
M0W)E871E9"(*;7-G<W1R(")#<F5A9&\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO
M;CHB"FUS9W-T<B`B4V5N=&ED;R!D92!C;&%S:69I8V%C:?-N('!O<B!O;6ES
M:?-N.B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C<V('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PHC.B!L:6(O3V)J96-T+G!H<#HS
M,C@@;&EB+U)E;F1E<F5R+G!H<#HT-R!L:6(O4F5N9&5R97(N<&AP.C4P"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B16QI;6EN87(B"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHU.`IM<V=I9"`B1&5L971E($%D9')E<W,@0F]O
M:R(*;7-G<W1R(")%;&EM:6YA<B!L:6)R971A(&1E(&1I<F5C8VEO;F5S(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T
M92!#;VYF:7)M871I;VXB"FUS9W-T<B`B0V]N9FER;6%C:?-N(&1E(&5L:6UI
M;F%C:?-N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,SD*;7-G
M:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(D-O;7!O<G1A
M;6EE;G1O(&1E;"!B;W3S;B!%;&EM:6YA<B`B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(E-E(&AA('!R;V1U8VED;R!U;B!E<G)O<B!A
M;"!E;&EM:6YA<CH@*"5S*2`E<R(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z
M-C(*;7-G:60@(D1E;&5T:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(DYO('-E('!U961E(&5L:6UI;F%R(&-O;G1A8W1O<RXB"@HC
M.B!D96QE=&4N<&AP.C,X"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T
M<B`B4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&%L(&5L:6UI;F%R(@H*(SH@
M8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E
M<&%R=&UE;G0B"FUS9W-T<B`B1&5P87)T86UE;G1O(@H*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T
M<B`B1&5S8V5N9&5N=&4B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHQ,34*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!C:?-N
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q.0IM<V=I9"`B
M1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=&]R:6\B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")6
M:7-U86QI>F%C:?-N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M.2!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ-@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HR,R!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HS,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S
M(&1E(%9I<W5A;&EZ86-I\VXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HQ-S<*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I
M;F<@96YT<FEE<S\B"FUS9W-T<B`BOT1E<V5A(&-O;F9I<FUA<B!E;"!B;W)R
M861O(&1E(&QA<R!E;G1R861A<S\B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*
M;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(D1E<V-A<F=A<B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<F]W+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C(U"FUS9VED(")$;W=N;&]A9"!V0V%R9"(*;7-G<W1R(")$
M97-C87)G87(@=D-A<F0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L871E
M<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B"FUS
M9W-T<B`B36]D:69I8V%R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC
M.C(U('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B36]D:69I8V%R
M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C@Q"FUS
M9VED(")%9&ET($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B36]D:69I8V%R($QI
M8G)E=&%S(&1E(&1I<F5C8VEO;F5S(@H*(SH@961I="YP:'`Z.#4@961I="YP
M:'`Z,38Q"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@96YT<GD@9F]R("5S
M(@IM<V=S='(@(DUO9&EF:6-A<B!E;G1R861A(&1E("5S(@H*(SH@8V]N9FEG
M+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B16UA:6PB"FUS
M9W-T<B`B0V]R<F5O(@H*(SH@961I="YP:'`Z,34T"B,L('!H<"UF;W)M870*
M;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U
M<&QO861E9"!F:6QE(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@HB4V4@:&$@86-T
M=6%L:7IA9&\@;&$@96YT<F%D82!D92`E<RP@<&5R;R!N;R!S92!H82!P;V1I
M9&\@9W5A<F1A<B!E;"!A<F-H:79O("(*(F-A<F=A9&\Z("5S(@H*(SH@961I
M="YP:'`Z,34V(&5D:70N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;G1R>2!F;W(@)7,@=7!D871E9"XB"FUS9W-T<B`B4V4@:&$@86-T=6%L:7IA
M9&\@;&$@96YT<F%D82!D92`E<RXB"@HC.B!B<F]W<V4N<&AP.C(Q-B!B<F]W
M<V4N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!A9&1I;F<@
M)60@8V]N=&%C="AS*2!T;R!L:7-T+B(*;7-G<W1R(")392!H82!P<F]D=6-I
M9&\@=6X@97)R;W(@86P@8?%A9&ER("5D(&-O;G1A8W1O*',I(&$@;&$@;&ES
M=&$N(@H*(SH@8G)O=W-E+G!H<#HR,3@@8G)O=W-E+G!H<#HR-C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@861D:6YG("5D(&]F("5D(')E<75E<W1E
M9"!C;VYT86-T*',I('1O(&QI<W0N(@IM<V=S='(@(B(*(E-E(&AA('!R;V1U
M8VED;R!U;B!E<G)O<B!A;"!A\6%D:7(@)60@9&4@)60@8V]N=&%C=&\H<RD@
M<V]L:6-I=&%D;RAS*2!A(&QA("(*(FQI<W1A+B(*"B,Z(&)R;W=S92YP:'`Z
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@)60@8V]N
M=&%C="AS*2XB"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!E;&EM
M:6YA<B`E9"!C;VYT86-T;RAS*2XB"@HC.B!B<F]W<V4N<&AP.C@X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG("5D(&]F("5D(')E<75E
M<W1E9"!C;VYT86-T<RAS*2XB"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O
M<B!A;"!E;&EM:6YA<B`E9"!D92`E9"!C;VYT86-T;RAS*2!S;VQI8VET861O
M*',I+B(*"B,Z(&)R;W=S92YP:'`Z-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@<F5M;W9I;F<@)60@8V]N=&%C="AS*2!F<F]M(&QI<W0N(@IM<V=S
M='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@96QI;6EN87(@)60@8V]N=&%C
M=&\H<RD@9&4@;&$@;&ES=&$N(@H*(SH@8G)O=W-E+G!H<#HV.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!R96UO=FEN9R`E9"!O9B`E9"!R97%U97-T
M960@8V]N=&%C="AS*2!F<F]M(&QI<W0N(@IM<V=S='(@(B(*(E-E('!R;V1U
M:F\@=6X@97)R;R!A;"!E;&EM:6YA<B`E9"!D92`E9"!C;VYT86-T;RAS*2!S
M;VQI8VET861O*',I(&1E(&QA("(*(FQI<W1A+B(*"B,Z(&QI8B]A<&DN<&AP
M.C0Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96%R8VAI;F<@=&AE
M(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O
M<B!B=7-C86YD;R!E;B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S.B`E<R(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3`@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(D5X
M<&]R=&%R(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHV"FUS9VED
M(")%>'!O<G0@061D<F5S<R!";V]K(@IM<V=S='(@(D5X<&]R=&%R(&QI8G)E
M=&$@9&4@9&ER96-C:6]N97,B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C(Q"FUS9VED(")%>'!O<G0@;VYL>2!T:&4@<V5L96-T960@8V]N=&%C
M=',N(@IM<V=S='(@(D5X<&]R=&%R('/S;&\@;&]S(&-O;G1A8W1O<R!S96QE
M8V-I;VYA9&]S+B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C<*
M;7-G:60@(D5X<&]R="!T:&4@9F]L;&]W:6YG(&%D9')E<W,@8F]O:R!C;VUP
M;&5T96QY+B(*;7-G<W1R(")%>'!O<G1A<B!L87,@<VEG=6EE;G1E<R!L:6)R
M971A<R!D92!D:7)E8V-I;VYE<R!C;VUP;&5T87,N(@H*(SH@9&%T82YP:'`Z
M,3,T(&1A=&$N<&AP.C(R."!D871A+G!H<#HR.3<@8G)O=W-E+G!H<#HS-2!B
M<F]W<V4N<&AP.C$P,PHC.B!B<F]W<V4N<&AP.C$S,"!A9&0N<&AP.C8W('-E
M87)C:"YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%C
M8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")&86QL;R!A;"!A
M8V-E9&5R(&$@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<SH@)7,B"@HC.B!B
M<F]W<V4N<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M861D("5S('1O("5S.B`E<R(*;7-G<W1R(")&86QL;R!A;"!A\6%D:7(@)7,@
M82`E<SH@)7,B"@HC.B!B<F]W<V4N<&AP.C,P-0IM<V=I9"`B1F%I;&5D('1O
M(&)R;W=S92!L:7-T(@IM<V=S='(@(D9A;&QO(&%L('9I<W5A;&EZ87(@96P@
M;&ES=&%D;R(*"B,Z(&)R;W=S92YP:'`Z,S0S"FUS9VED(")&86EL960@=&\@
M8G)O=W-E('1H92!D:7)E8W1O<GDB"FUS9W-T<B`B1F%L;&\@86P@=FES=6%L
M:7IA<B!E;"!D:7)E8W1O<FEO(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS
M,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-H86YG92!N86UE
M.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@/2`E
M<R(*;7-G<W1R("(B"B)&86QL;R!A;"!C86UB:6%R(&5L(&YO;6)R93H@*"5S
M*2`E<SL@06YT:6=U;R!$3B`]("5S+"!.=65V;R!$3B`]("5S+"!286EZ(#T@
M)2(*(G,B"@HC.B!B<F]W<V4N<&AP.C$S-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S(@IM<V=S
M='(@(D9A;&QO(&%L(&QO8V%L:7IA<B!E;"!O8FIE8W1O(&$@8?%A9&ER.B`E
M<R(*"B,Z('-E87)C:"YP:'`Z-SD*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@
M=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(").;R!S92!P=65D92!B=7-C87(@
M96X@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R(*"B,Z(&1A=&$N<&AP.C$T
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H92!D
M:7)E8W1O<GDZ("5S(@IM<V=S='(@(D9A;&QO(&%L(&)U<V-A<B!E;B!E;"!D
M:7)E8W1O<FEO.B`E<R(*"B,Z(&-O;F9I9R\N8F%K+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,38W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@961I="YP
M:'`Z,3,Q(&1I<W!L87DN<&AP.C$P,`IM<V=I9"`B1FEL97,B"FUS9W-T<B`B
M07)C:&EV;W,B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S$*
M;7-G:60@(D9I;F0B"FUS9W-T<B`B16YC;VYT<F%R(@H*(SH@961I="YP:'`Z
M,3`T(&5D:70N<&AP.C$Y-`IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(E1E<FUI
M;F%R(@H*(SH@8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HT.`IM
M<V=I9"`B1FER<W0@3F%M92(*;7-G<W1R(")0<FEM97(@;F]M8G)E(@H*(SH@
M8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HR,#(*;7-G:60@(D9R
M965B=7-Y(%523"(*;7-G<W1R(")54DP@9&4@=&EE;7!O(&1I<W!O;FEB;&4B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.#0*;7-G:60@(D9R
M;VTB"FUS9W-T<B`B1&4B"@HC.B!C;VYF:6<O+F)A:R]S;W5R8V5S+G!H<"YD
M:7-T.C8P-@IM<V=I9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R("),
M:6)R971A(&1E(&1I<F5C8VEO;F5S(&=L;V)A;"(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<F]W+FEN8SHT,R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N
M:6YC.C0T"FUS9VED(")'<F]U<"(*;7-G<W1R(")'<G5P;R(*"B,Z(&-O;F9I
M9R\N8F%K+V%T=')I8G5T97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R(")$;VUI8VEL:6\B"@HC.B!C;VYF:6<O+F)A:R]A='1R
M:6)U=&5S+G!H<"YD:7-T.CDS"FUS9VED(")(;VUE($-I='DB"FUS9W-T<B`B
M0VEU9&%D(&1E;"!D;VUI8VEL:6\B"@HC.B!C;VYF:6<O+F)A:R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$P.`IM<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@
M(E!A:7,@9&5L(&1O;6EC:6QI;R(*"B,Z(&-O;F9I9R\N8F%K+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,34P"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E
M;.EF;VYO('!A<G1I8W5L87(B"@HC.B!C;VYF:6<O+F)A:R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$P,PIM<V=I9"`B2&]M92!0;W-T86P@0V]D92(*;7-G<W1R
M(")#\V1I9V\@<&]S=&%L(&1E;"!D;VUI8VEL:6\B"@HC.B!C;VYF:6<O+F)A
M:R]A='1R:6)U=&5S+G!H<"YD:7-T.CDX"FUS9VED(")(;VUE(%-T871E+U!R
M;W9I;F-E(@IM<V=S='(@(D5S=&%D;R]0<F]V:6YC:6$@9&5L(&1O;6EC:6QI
M;R(*"B,Z(&-O;F9I9R\N8F%K+V%T=')I8G5T97,N<&AP+F1I<W0Z.#@*;7-G
M:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N(&1E
M;"!D;VUI8VEL:6\B"@HC.B!C;VYF:6<O+F)A:R]S;W5R8V5S+G!H<"YD:7-T
M.C4P.`IM<V=I9"`B24U34"(*;7-G<W1R("))35-0(@H*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z-#<*;7-G:60@(DE-4U`@061D<F5S<R!";V]K
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:?-N(&1E(&QI
M8G)E=&$@9&4@9&ER96-C:6]N97,@24U34"(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D
M<F5S<R!";V]K+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&%R(&QI8G)E=&$@
M9&4@9&ER96-C:6]N97,N(%!A<V\@)60B"@HC.B!D871A+G!H<#HS-C$*;7-G
M:60@(DEM<&]R="]%>'!O<G0@061D<F5S<R!";V]K<R(*;7-G<W1R("));7!O
M<G1A<B]%>'!O<G1A<B!L:6)R971A<R!D92!D:7)E8V-I;VYE<R(*"B,Z(&QI
M8B]A<&DN<&AP.C8Q-"!L:6(O87!I+G!H<#HW,#$*;7-G:60@(DEN=F%L:60@
M240B"FUS9W-T<B`B240@;F\@=N%L:61O(@H*(SH@;&EB+V%P:2YP:'`Z,C,R
M(&QI8B]A<&DN<&AP.C0P-"!L:6(O87!I+G!H<#HT.#@@;&EB+V%P:2YP:'`Z
M-C$P"B,Z(&QI8B]A<&DN<&AP.C8Y-R!L:6(O87!I+G!H<#HW-#D@;&EB+V%P
M:2YP:'`Z,3`Y-0IM<V=I9"`B26YV86QI9"!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B3&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!N;R!E<R!VX6QI9&$N(@H*
M(SH@;&EB+V%P:2YP:'`Z,3`Y.2!L:6(O87!I+G!H<#HQ,3<R(&QI8B]A<&DN
M<&AP.C$R,C4*;7-G:60@(DEN=F%L:60@96UA:6PB"FUS9W-T<B`B3&$@9&ER
M96-C:?-N(&1E(&-O<G)E;R!N;R!E<R!VX6QI9&$N(@H*(SH@;&EB+V%P:2YP
M:'`Z,3$P-PIM<V=I9"`B26YV86QI9"!E;G1R>2(*;7-G<W1R(")%;G1R861A
M(&YO(';A;&ED82XB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(V-@IM<V=I
M9"`B26YV86QI9"!K97D@<W!E8VEF:65D+B(*;7-G<W1R(")392!H82!I;F1I
M8V%D;R!U;F$@8VQA=F4@;F\@=N%L:61A+B(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M,#,*;7-G:60@(DEN=F%L:60@;F%M92(*;7-G<W1R(").;VUB<F4@;F\@=N%L
M:61O(@H*(SH@;&EB+V%P:2YP:'`Z-S4S"FUS9VED("));G9A;&ED(&]B:F5C
M=$ED(@IM<V=S='(@(D]B:F5C=$ED(&YO(';A;&ED;R(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U
M:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@
M;F]T(&QO861E9"XB"FUS9W-T<B`B(@HB4V4@<')E8VES82!S;W!O<G1E($Q$
M05`@<&5R;R!E;"!M\V1U;&\@3$1!4"!N;R!E<W3A(&1I<W!O;FEB;&4@;R!C
M87)G861O+B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S@*;7-G:60@(DQA
M<W0@36]D:69I960B"FUS9W-T<B`BVFQT:6UA(&UO9&EF:6-A8VGS;B(*"B,Z
M(&-O;F9I9R\N8F%K+V%T=')I8G5T97,N<&AP+F1I<W0Z-3,*;7-G:60@(DQA
M<W0@3F%M92(*;7-G<W1R("+:;'1I;6\@;F]M8G)E(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS
M9W-T<B`B3&ES=&$B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z
M-S@*;7-G:60@(DUA=&-H:6YG(@IM<V=S='(@(D-O:6YC:61E;G1E(@H*(SH@
M;&EB+V%P:2YP:'`Z,C`W"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!#;VYT
M86-T<R(*;7-G<W1R(").^FUE<F\@;>%X:6UO(&1E($-O;G1A8W1O<R(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU
M;2!N=6UB97(@;V8@<&%G97,B"FUS9W-T<B`B3OIM97)O(&WA>&EM;R!D92!P
MX6=I;F%S(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PIM<V=I9"`B
M365N=2!,:7-T(@IM<V=S='(@(DQI<W1A(&1E(&UE;OHB"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$3B!I;B!,1$%0('-O
M=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")&86QT82!$3B!E;B!L82!C
M;VYF:6=U<F%C:?-N(&]R:6=E;B!D92!,1$%0+B(*"B,Z(&-O;F9I9R\N8F%K
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"FUS9VED(")-;V)I;&4@4&AO;F4B
M"FUS9W-T<B`B5&5LZ69O;F\@;?-V:6PB"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(DAA(&9A
M;&QA9&\@;&$@;6]D:69I8V%C:?-N.B`H)7,I("5S(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(Q,0IM<V=I9"`B36]R92!T:&%N(#$@96YT<GD@9F]U;F0B"FUS9W-T
M<B`B4V4@:&$@96YC;VYT<F%D;R!MX7,@9&4@,2!E;G1R861A(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B36]V92(*;7-G
M<W1R(")4<F%S;&%D87(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L
M96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L
M96-T+FEN8SHQ.#0*;7-G:60@(DUO=F4@;&5F="(*;7-G<W1R(")$97-P;&%Z
M87(@82!L82!I>G%U:65R9&$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR-#D*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K
M<V5L96-T+FEN8SHQ.#8*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B1&5S
M<&QA>F%R(&$@;&$@9&5R96-H82(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,38*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@
M0F]O:R(*;7-G<W1R("),:6)R971A(&1E(&1I<F5C8VEO;F5S($UU;&)E<G)Y
M(@H*(SH@;&EB+V%P:2YP:'`Z,3$S,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)-=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N
M92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T(@IM<V=S='(@(B(*(E9A
M<FEA<R!P97)S;VYA<R!C;VX@;&$@9&ER96-C:?-N(%LE<UT@<&5R;R!T;V1A
M=NUA(&YO(&5X:7-T92!N:6YG=6YA(&-O;B!E;"`B"B)N;VUB<F4@6R5S72(*
M"B,Z(&-O;F9I9R\N8F%K+W-O=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I9R\N
M8F%K+W-O=7)C97,N<&AP+F1I<W0Z,C0S"FUS9VED(")->2!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B36D@;&EB<F5T82(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z
M,3$Y"FUS9VED(")->2!!9&1R97-S($)O;VMS(@IM<V=S='(@(DUI<R!L:6)R
M971A<R(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P-R!C;VYF
M:6<O+F)A:R]A='1R:6)U=&5S+G!H<"YD:7-T.C0R"FUS9VED(").86UE(@IM
M<V=S='(@(DYO;6)R92(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C,Q"FUS9VED(").86UE($9O<FUA="(*;7-G<W1R(")&;W)M871O(&1E(&YO
M;6)R92(*"B,Z(&-O;F9I9R\N8F%K+W-O=7)C97,N<&AP+F1I<W0Z,S$U"FUS
M9VED(").971C96YT97(@365M8F5R($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E
M8W1O<FEO(&UI96UB<F\@9&4@3F5T8V5N=&5R(@H*(SH@861D+G!H<#HS-B!A
M9&0N<&AP.C$R-"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-PIM<V=I9"`B
M3F5W($-O;G1A8W0B"FUS9W-T<B`B0?%A9&ER(@H*(SH@961I="YP:'`Z.34@
M961I="YP:'`Z,3`R(&5D:70N<&AP.C(P.2!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@(E-I9W5I96YT92(*"B,Z
M(&-O;F9I9R\N8F%K+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$X"FUS9VED(").
M:6-K;F%M92(*;7-G<W1R(")!<&]D;R(*"B,Z(&QI8B]A<&DN<&AP.C$R,3,@
M;&EB+V%P:2YP:'`Z,3(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E
M;G1R>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B3F\@<V4@:&$@96YC;VYT<F%D
M;R!U;F$@96YT<F%D82`E<R!P87)A("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3$X
M,0IM<V=I9"`B3F\@861D<F5S<R!B;V]K<R!F;W5N9"XB"FUS9W-T<B`B3F\@
M<V4@:&%N(&5N8V]N=')A9&\@;&EB<F5T87,N(@H*(SH@;6EN:7-E87)C:"YP
M:'`Z.#$*;7-G:60@(DYO(&-O;G1A8W1S(&9O=6YD(@IM<V=S='(@(DYO('-E
M(&AA;B!E;F-O;G1R861O(&-O;G1A8W1O<R(*"B,Z(&QI8B]A<&DN<&AP.C4Q
M,R!L:6(O87!I+G!H<#HW.#0*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O
M=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R87)O;B!D871O<R!V0V%R9"XB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-PIM<V=I9"`B3F]N
M92(*;7-G<W1R(").:6YG=6YA(@H*(SH@8V]N9FEG+RYB86LO871T<FEB=71E
M<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&%S(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(").=6UB
M97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T<B`B3OIM97)O(&1E(&%R=.UC
M=6QO<R!P;W(@<.%G:6YA(@H*(SH@;&EB+V%P:2YP:'`Z-C,R(&QI8B]A<&DN
M<&AP.C<V-0IM<V=I9"`B3V)J96-T(&YO="!F;W5N9"(*;7-G<W1R(").;R!S
M92!H82!E;F-O;G1R861O(&5L(&]B:F5T;RXB"@HC.B!C;VYF:6<O+F)A:R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@
M(D]F:6-I;F$B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(R
M"FUS9VED("(B"B)/;F-E('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H
M92!A9&1R97-S(&)O;VL@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D
M+B!)9B!T:&ES(&ES(&YO="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T
M(&-H86YG92!Y;W5R('-E;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T
M<B`B(@HB56YA('9E>B!G=6%R9&4@97-T82!PX6=I;F$@9&4@;W!C:6]N97,L
M(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,@<V4@8F]R<F%RX2`B"B)D969I
M;FET:79A;65N=&4N(%-I(&YO(&5S(&QO('%U92!D97-E82P@9&5B97+M82!C
M86UB:6%R(&QA('-E;&5C8VGS;B!A("(*(EPB3FEN9W5N;UPB+B(*"B,Z(&QI
M8B]A<&DN<&AP.C<Y,@IM<V=I9"`B3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D
M+B(*;7-G<W1R(")3\VQO('-E('-O<&]R=&$@=6YA('9C87)D+B(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C0V"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D]T
M<F%S(&]P8VEO;F5S(@H*(SH@8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N
M9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D-L879E
M(%!'4"!P^F)L:6-A(@H*(SH@;&EB+V%P:2YP:'`Z-#DW(&QI8B]A<&DN<&AP
M.C8R,R!L:6(O87!I+G!H<#HW,3`@;&EB+V%P:2YP:'`Z.34R"B,Z(&QI8B]A
M<&DN<&AP.C$Q,38*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@
M(E!E<FUI<V\@9&5N96=A9&\B"@HC.B!L:6(O1')I=F5R+G!H<#HU-3`*;7-G
M:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(E!E<FUI<V\@9&5N96=A
M9&\B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY.0IM<V=I9"`B
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B4')I=FEL96=I;W,B"@HC.B!D871A+G!H
M<#HU,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")0:6YE
M($%D9')E<W,@0F]O:R(*;7-G<W1R("),:6)R971A(&1E(&1I<F5C8VEO;F5S
M(&1E(%!I;F4B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C(X"FUS9VED(")0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@;&ES=#HB
M"FUS9W-T<B`B26YT<F]D=7IC82!E;"!N;VUB<F4@9&4@;&$@;G5E=F$@;&ES
M=&$Z(@H*(SH@961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D:70N<&AP.C(P
M,0IM<V=I9"`B4')E=FEO=7,B"FUS9W-T<B`B06YT97)I;W(B"@HC.B!C;VYF
M:6<O+F)A:R]S;W5R8V5S+G!H<"YD:7-T.C0Q-@IM<V=I9"`B4')I=F%T92!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B3&EB<F5T82!D92!D:7)E8V-I;VYE<R!P
M<FEV861A(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B475E<GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(DAA
M(&9A;&QA9&\@;&$@8V]N<W5L=&$Z("@E<RD@)7,B"@HC.B!T96UP;&%T97,O
M8FQO8VLO;6EN:7-E87)C:"YI;F,Z,3@*;7-G:60@(E%U:6-K(%-E87)C:"(*
M;7-G<W1R(")"^G-Q=65D82!RX7!I9&$B"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C$Y,2!L:6(O1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD
M87`N<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")296%D(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R(")(82!F86QL861O(&QA(&QE8W1U<F$Z("@E<RD@
M)7,B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4R"FUS9VED(")296%D:6YG
M(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYO('-E('!U
M961E;B!L965R(&QO<R!C;VYT86-T;W,N(@H*(SH@;&EB+U)E;F1E<F5R+G!H
M<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S
M='(@(K]%;&EM:6YA<B!R96%L;65N=&4@97-T92!C;VYT86-T;S\B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D<R!D
M:7-P;&%Y960Z(@IM<V=S='(@(E)E9VES=')O<R!M;W-T<F%D;W,Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S8*;7-G
M:60@(E)E;6]V92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B16QI;6EN87(@;&EB
M<F5T82!D92!D:7)E8V-I;VYE<R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(S.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M(")1=6ET87(@8V]L=6UN82(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,PIM<V=I9"`B4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@
M(E%U:71A<B!D92!E<W1A(&QI<W1A(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHR,0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S
M(&)O;VL@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z
M(%1H:7,@(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@
M861D<F5S<R!B;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"B*_4W5S=&ET=6ER
M(&QA(&QI8G)E=&$@97AI<W1E;G1E('!O<B!L82!I;7!O<G1A9&$_(#QS=')O
M;F<^061V97)T96YC:6$Z(,ES=&\@(@HB96QI;6EN87+A('1O9&%S(&QA<R!E
M;G1R861A<R!D92!S=2!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&%C='5A;"X\
M+W-T<F]N9SXB"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G:60@(E)E<75E
M<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R
M\R!E;"!O8FIE=&\@<V]L:6-I=&%D;RXB"@HC.B!A9&0N<&AP.C,W('1E;7!L
M871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,30*;7-G:60@(E)E<V5T('1O($1E
M9F%U;'1S(@IM<V=S='(@(E)E<W1A=7)A<B!A(&QO<R!V86QO<F5S('!O<B!O
M;6ES:?-N(@H*(SH@8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HQ
M.38*;7-G:60@(E,O34E-12!0=6)L:6,@0V5R=&EF:6-A=&4B"FUS9W-T<B`B
M0V5R=&EF:6-A9&\@4R]-24U%('#Z8FQI8V\B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE
M9#H@*"5S*2`E<R(*;7-G<W1R(")(82!F86QL861O(%-405)45$Q3.B`H)7,I
M("5S(@H*(SH@961I="YP:'`Z,3`V(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S='(@(D=U87)D
M87(B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C8W"FUS9VED(")3879I;F<@
M8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3F\@<V4@<'5E
M9&5N(&=U87)D87(@;&]S(&-O;G1A8W1O<RXB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+W-E87)C:"YI;F,Z.3<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC
M.C$Q,PHC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C$@;&EB
M+T)L;V-K+W1R965?;65N=2YP:'`Z-#D*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B"FUS9W-T<B`B0G5S8V%R(@H*
M(SH@;&EB+V%P:2YP:'`Z,3`R.0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G
M<W1R(")(82!F86QL861O(&QA(&+Z<W%U961A(@H*(SH@;&EB+V%P:2YP:'`Z
M,3$R,2!L:6(O87!I+G!H<#HQ,3(W(&QI8B]A<&DN<&AP.C$Q,S8@;&EB+V%P
M:2YP:'`Z,3$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@9F%I;&5D
M.B`E<R(*;7-G<W1R(")(82!F86QL861O(&QA(&+Z<W%U961A.B`E<R(*"B,Z
M(&QI8B]$<FEV97(O;G5L;"YP:'`Z-#<*;7-G:60@(E-E87)C:&EN9R!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(").;R!S92!P=65D92!R96%L:7IA<B!B
M^G-Q=65D87,N(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC
M.C(R"FUS9VED(")396%R8VAI;F<N+BXB"FUS9W-T<B`B0G5S8V%N9&\N+BXB
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@IM<V=I9"`B4V5L
M96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B4V5L96-C
M:6]N92!U;F$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!A(&5L:6UI;F%R(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3`*;7-G:60@(E-E;&5C
M="!A;B!A9&1R97-S(&)O;VL@=&\@961I="(*;7-G<W1R(")396QE8V-I;VYE
M('5N82!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&$@;6]D:69I8V%R(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS,@IM<V=I9"`B4V5L96-T('1H
M92!A9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ(@IM<V=S='(@(E-E;&5C
M8VEO;F4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!A(&5X<&]R=&%R.B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C8*;7-G:60@(E-E;&5C
M="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B4V5L
M96-C:6]N92!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&$@;&$@<75E(&EM
M<&]R=&%R.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S4*;7-G
M:60@(E-E;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM
M<V=S='(@(E-E;&5C8VEO;F4@96P@:G5E9V\@9&4@8V%R86-T97)E<R!D96P@
M87)C:&EV;R!O<FEG96XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ,`IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R
M(")396QE8V-I;VYE(&5L(&9O<FUA=&\@9&4@97AP;W)T86-I\VXZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L96-T('1H
M92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B4V5L96-C:6]N92!E;"!A<F-H
M:79O(&$@:6UP;W)T87(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ,0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F
M:6QE.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&9O<FUA=&\@9&5L(&%R8VAI
M=F\@;W)I9V5N.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$S
M-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA
M;65S.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&9O<FUA=&\@=7-A9&\@<&%R
M82!M;W-T<F%R(&QO<R!N;VUB<F5S.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C(U"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y
M(&1E9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+B(*
M;7-G<W1R("(B"B)396QE8V-I;VYE(&QA('9I<W1A(&UO<W1R861A('!O<B!O
M;6ES:?-N('D@;&%S(&]P8VEO;F5S(&1E(&]R9&5N86-I\VX@>2`B"B)P86=I
M;F%C:?-N+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$X"FUS
M9VED(")396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D
M9')E<W,@;&ES=',N(@IM<V=S='(@(E-E;&5C8VEO;F4@;&]S(&-A;7!O<R!V
M:7-U86QI>F%D;W,@96X@96P@;&ES=&%D;R!D92!D:7)E8V-I;VYE<RXB"@HC
M.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L96-T
M('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R(")396QE
M8V-I;VYE(&/S;6\@;6]S=')A<B!L;W,@;F]M8G)E<RXB"@HC.B!A9&0N<&AP
M.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E-E;&5C=&5D(&%D9')E<W,@8F]O
M:R!<(B5S7"(N(@IM<V=S='(@(DQI8G)E=&$@9&4@9&ER96-C:6]N97,@<V5L
M96-C:6]N861A(%PB)7-<(BXB"@HC.B!C;VYF:6<O+F)A:R]S;W5R8V5S+G!H
M<"YD:7-T.C$W,PIM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G<W1R(")$
M:7)E8W1O<FEO(&-O;7!A<G1I9&\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS
M9W-T<B`B36]S=')A<B`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z-#@*;7-G:60@(E-H;W<@06QL(@IM<V=S='(@(DUO<W1R87(@=&]D
M;R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#<*;7-G:60@
M(E-H;W<@0V]N=&%C=',B"FUS9W-T<B`B36]S=')A<B!C;VYT86-T;W,B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0V"FUS9VED(")3:&]W
M($QI<W1S(@IM<V=S='(@(DUO<W1R87(@;&ES=&%S(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,C$*(SH@=&5M<&QA=&5S+V)R
M;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,S8*;7-G:60@(E-O<G0@1&ER96-T
M:6]N(@IM<V=S='(@(E-E;G1I9&\@9&4@8VQA<VEF:6-A8VGS;B(*"B,Z(&QI
M8B]A<&DN<&AP.C(P,`IM<V=I9"`B4V]U<F-E<R(*;7-G<W1R(")/<NUG96YE
M<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B
M4W!E8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT
M<R!T;R!A<'!E87(N(@IM<V=S='(@(B(*(DEN9&EQ=64@9/-N9&4@9&5S96$@
M<75E(&%P87)E>F-A;B!L;W,@<F5S=6QT861O<R!D92!L82!B^G-Q=65D82!A
M=F%N>F%D82XB"@HC.B!B<F]W<V4N<&AP.C(Q-"!B<F]W<V4N<&AP.C(V,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@)60@8V]N
M=&%C="AS*2!T;R!L:7-T+B(*;7-G<W1R(")392!H82AN*2!A\6%D:61O(&-O
M<G)E8W1A;65N=&4@)60@8V]N=&%C=&\H<RD@82!L82!L:7-T82XB"@HC.B!B
M<F]W<V4N<&AP.C$V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@861D960@)7,@=&\@)7,B"FUS9W-T<B`B4V4@:&$@8?%A9&ED;R!C;W)R
M96-T86UE;G1E("5S(&$@)7,N(@H*(SH@8G)O=W-E+G!H<#HR-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A
M8W0@;&ES="!<(B5S7"(N(@IM<V=S='(@(E-E(&AA(&-R96%D;R!C;W)R96-T
M86UE;G1E(&QA(&QI<W1A(%PB)7-<(BXB"@HC.B!B<F]W<V4N<&AP.C@T"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D("5D(&-O
M;G1A8W0H<RDN(@IM<V=S='(@(E-E(&AA*&XI(&5L:6UI;F%D;R!C;W)R96-T
M86UE;G1E("5D(&-O;G1A8W1O*',I+B(*"B,Z(&)R;W=S92YP:'`Z-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@)60@8V]N
M=&%C="AS*2!F<F]M(&QI<W0N(@IM<V=S='(@(E-E(&AA*&XI(&5L:6UI;F%D
M;R!C;W)R96-T86UE;G1E("5D(&-O;G1A8W1O*',I(&1E(&QA(&QI<W1A+B(*
M"B,Z(&1A=&$N<&AP.C4P"FUS9VED(")44U8B"FUS9W-T<B`B5%-6(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-"!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$T"FUS9VED(")486(@<V5P87)A=&5D('9A;'5E<R(*;7-G
M<W1R(")686QO<F5S('-E<&%R861O<R!P;W(@=&%B=6QA9&]R97,B"@HC.B!V
M:65W+G!H<#HQ-0IM<V=I9"`B5&AE(%9&4R!B86-K96YD(&YE961S('1O(&)E
M(&-O;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RXB"FUS
M9W-T<B`B2&%Y('%U92!C;VYF:6=U<F%R(&5L(&UO=&]R(%9&4R!P87)A('!E
M<FUI=&ER(&QA(&-A<F=A(&1E(&%D:G5N=&]S+B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$P-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DQA(&QI8G)E=&$@
M9&4@9&ER96-C:6]N97,@7"(E<UPB(&YO(&5X:7-T92XB"@HC.B!A9&1R97-S
M8F]O:W,N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S
M(&)O;VL@7"(E<UPB('=A<R!C<F5A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B4V4@:&$@8W)E861O(&-O<G)E8W1A;65N=&4@;&$@;&EB<F5T82!D92!D
M:7)E8V-I;VYE<R!<(B5S7"(N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HW,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W
M87,@<F5M;W9E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E-E(&AA(&5L:6UI
M;F%D;R!C;W)R96-T86UE;G1E(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,@
M7"(E<UPB+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")392!H82!A8W1U86QI>F%D;R!C;W)R
M96-T86UE;G1E(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,@7"(E<UPB+B(*
M"B,Z(&1A=&$N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D
M<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(DYO
M('-E('!U9&\@=F%C:6%R(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,Z("5S
M(@H*(SH@961I="YP:'`Z-3$@=F-A<F0N<&AP.C(R(&1I<W!L87DN<&AP.C(S
M('9I97<N<&AP.C(V"FUS9VED(")4:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")%;"!C;VYT86-T;R!S;VQI8VET
M861O(&YO(&5X:7-T92XB"@HC.B!E9&ET+G!H<#HQ,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")%;"!A<F-H:79O(%PB)7-<(B!S92!H82!E
M;&EM:6YA9&\@8V]R<F5C=&%M96YT92XB"@HC.B!D871A+G!H<#HR.#0*;7-G
M:60@(E1H92!I;7!O<G0@8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A
M<FYI;F=S+B(*;7-G<W1R(")392!P=65D92!C;VUP;&5T87(@;&$@:6UP;W)T
M86-I\VX@82!P97-A<B!D92!L;W,@879I<V]S+B(*"B,Z(&)R;W=S92YP:'`Z
M,S$*;7-G:60@(E1H97)E(&%R92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O
M:W,N(@IM<V=S='(@(DYO(&AA>2!L:6)R971A<R!D92!D:7)E8V-I;VYE<R!V
M:7-U86QI>F%B;&5S+B(*"B,Z(&%D9"YP:'`Z,CD*;7-G:60@(B(*(E1H97)E
M(&%R92!N;R!W<FET96%B;&4@861D<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@
M879A:6QA8FQE(&%D9')E<W,@8F]O:W,@(@HB87)E(&-O;F9I9W5R960@=&\@
M86QL;W<@>6]U('1O(&%D9"!N97<@96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@
M8F5L:65V92!T:&ES("(*(FES(&%N(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).;R!H87D@
M;&EB<F5T87,@9&4@9&ER96-C:6]N97,@96X@;&%S('%U92!S92!P=65D82!E
M<V-R:6)I<BX@3FEN9W5N82!D92!L87,@(@HB9&ES<&]N:6)L97,@97-TX2!C
M;VYF:6=U<F%D82!P87)A('!E<FUI=&ER;&4@8?%A9&ER(&5N=')A9&%S(&5N
M(&5L;&%S+B!3:2`B"B)C;VYS:61E<F$@<75E(&5S=&\@97,@=6X@97)R;W(L
M(&-O;G1A8W1E(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S+B(*
M"B,Z(&%D9"YP:'`Z,3(Q"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M861D:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R("(*(F9O<B!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M(E-E('!R;V1U:F\@=6X@97)R;W(@86P@8?%A9&ER(&5L(&-O;G1A8W1O+B!#
M;VYT86-T92!A;"!A9&UI;FES=')A9&]R(&1E("(*(G-I<W1E;6%S('!A<F$@
M;>%S(&EN9F]R;6%C:?-N+B(*"B,Z(&)R;W=S92YP:'`Z,C<Q"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="XB"FUS9W-T
M<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!C<F5A<B!U;F$@;&ES=&$N(@H*
M(SH@861D<F5S<V)O;VMS+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ
M("5S(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@8W)E87(@97-T
M82!L:6)R971A(&1E(&1I<F5C8VEO;F5S.B`E<R(*"B,Z(&)R;W=S92YP:'`Z
M,38V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!<(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B(@HB4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!E;&EM:6YA<B!<
M(B5S7"(@9&4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!O<FEG96XN(@H*
M(SH@9&5L971E+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G<W1R
M(")392!P<F]D=6IO('5N(&5R<F]R(&%L(&5L:6UI;F%R(&5S=&4@8V]N=&%C
M=&\Z("5S(@H*(SH@8G)O=W-E+G!H<#HS,3$*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!L:7-T(@IM<V=S='(@(E-E('!R;V1U
M:F\@=6X@97)R;W(@86P@;6]S=')A<B!L82!L:7-T82(*"B,Z(&1A=&$N<&AP
M.C,S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R(")392!P<F]D=6IO('5N
M(&5R<F]R(&%L(&EM<&]R=&%R(&QO<R!D871O<SH@)7,B"@HC.B!L:6(O87!I
M+G!H<#HU,#D@;&EB+V%P:2YP:'`Z-S<Y"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B
M4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L;W,@9&%T;W,@:4-A
M;&5N9&%R+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-3@@861D<F5S<V)O;VMS
M+G!H<#HV,R!A9&1R97-S8F]O:W,N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@
M8F]O:SH@)7,B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!E;&EM
M:6YA<B!E<W1A(&QI8G)E=&$@9&4@9&ER96-C:6]N97,Z("5S(@H*(SH@861D
M<F5S<V)O;VMS+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM
M<V=S='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L:7IA<B!E<W1A
M(&QI8G)E=&$@9&4@9&ER96-C:6]N97,Z("5S(@H*(SH@961I="YP:'`Z,38U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&ES(&5N=')Y.B`E<R(*;7-G<W1R(")392!P<F]D=6IO('5N(&5R
M<F]R(&%L(&%C='5A;&EZ87(@;&$@96YT<F%D83H@)7,B"@HC.B!D871A+G!H
M<#HQ-SD*;7-G:60@(E1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R
M="XB"FUS9W-T<B`B3F\@:'5B;R!D:7)E8V-I;VYE<R!A(&5X<&]R=&%R+B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@P
M"FUS9VED(")4:&5S92!A9&1R97-S(&)O;VMS('=I;&P@9&ES<&QA>2!I;B!T
M:&ES(&]R9&5R.B(*;7-G<W1R(")%<W1A<R!L:6)R971A<R!S92!M;W-T<F%R
MX6X@96X@97-T92!O<F1E;CHB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR-#,*;7-G:60@(E1H97-E(&-O;'5M;G,@=VEL;"!D:7-P
M;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@(D5S=&%S(&-O;'5M;F%S('-E
M(&UO<W1R87+A;B!E;B!E<W1E(&]R9&5N.B(*"B,Z(&1A=&$N<&AP.C(V.0IM
M<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R(")%<W1E(&9O<FUA=&\@9&4@87)C:&EV;R!N;R!E<W3A('-O<&]R=&%D
M;RXB"@HC.B!L:6(O87!I+G!H<#HQ,30P(&QI8B]A<&DN<&AP.C$Q-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E
M<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(D5S=&$@<&5R
M<V]N82!Y82!T:65N92!U;F$@96YT<F%D82`E<R!E;B!L82!L:6)R971A(&1E
M(&1I<F5C8VEO;F5S+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$T.`IM<V=I9"`B(@HB5&AI<R!W:6QL(&)E('1H92!D969A=6QT(&%D9')E
M<W,@8F]O:R!W:&5N(&%D9&EN9R!O<B!I;7!O<G1I;F<@8V]N=&%C=',N(@IM
M<V=S='(@(LES=&$@<V5RX2!L82!L:6)R971A('!O<B!O;6ES:?-N(&%L(&'Q
M861I<B!O(&EM<&]R=&%R(&-O;G1A8W1O<RXB"@HC.B!C;VYF:6<O+F)A:R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C<P"FUS9VED(")4:71L92(*;7-G<W1R(")4
M[71U;&\B"@HC.B!L:6(O5'5R8F$N<&AP.C0T.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R92X@36ES<VEN9R!S;W5R
M8V4@='EP92XB"FUS9W-T<B`B3F\@<V4@<'5E9&4@8W)E87(@=6X@;G5E=F\@
M7")S:&%R95PB+B!&86QT82!E;"!T:7!O(&1E(&]R:6=E;BXB"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ,#`P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("));F-A<&%Z
M(&1E(&-A<F=A<B!L82!D969I;FEC:?-N(&1E("5S+B(*"B,Z(&5D:70N<&AP
M.CDU(&5D:70N<&AP.CDX(&5D:70N<&AP.C$P,2!E9&ET+G!H<#HQ,#8@961I
M="YP:'`Z,C`S"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B1&5S:&%C
M97(@8V%M8FEO<R(*"B,Z(&QI8B]A<&DN<&AP.C4T,B!L:6(O87!I+G!H<#HV
M-C$@;&EB+V%P:2YP:'`Z-SDW"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P
M<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B5&EP;R!D92!C;VYT
M96YI9&\@;F\@<V]P;W)T861O.B`E<R(*"B,Z(&-O;F9I9R\N8F%K+W-O=7)C
M97,N<&AP+F1I<W0Z,S<V"FUS9VED(")697)I<VEG;B!$:7)E8W1O<GDB"FUS
M9W-T<B`B1&ER96-T;W)I;R!697)I<VEG;B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC
M.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB(@IM<V=S='(@
M(E9E<B!<(B5S7"(B"@HC.B!M:6YI<V5A<F-H+G!H<#HW-@IM<V=I9"`B5FEE
M=R!#;VYT86-T(@IM<V=S='(@(E9E<B!C;VYT86-T;R(*"B,Z(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE=R!T;R!D:7-P;&%Y
M(&)Y(&1E9F%U;'0Z(@IM<V=S='(@(E9I<W1A(&UO<W1R861A('!O<B!O;6ES
M:?-N.B(*"B,Z(&-O;F9I9R\N8F%K+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`X
M"FUS9VED(")796)S:71E(%523"(*;7-G<W1R(")54DP@9&4@<V5D92!796(B
M"@HC.B!C;VYF:6<O+F)A:R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q,PIM<V=I
M9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D1I<F5C8VGS;B!D96P@=')A8F%J
M;R(*"B,Z(&-O;F9I9R\N8F%K+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(T"FUS
M9VED(")7;W)K($-I='DB"FUS9W-T<B`B0VEU9&%D(&1E;"!T<F%B86IO(@H*
M(SH@8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HQ,SD*;7-G:60@
M(E=O<FL@0V]U;G1R>2(*;7-G<W1R(")08>US(&1E;"!T<F%B86IO(@H*(SH@
M8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O
M<FL@4&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@9&5L('1R86)A:F\B"@HC.B!C
M;VYF:6<O+F)A:R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S-`IM<V=I9"`B5V]R
M:R!0;W-T86P@0V]D92(*;7-G<W1R(")#\V1I9V\@<&]S=&%L(&1E;"!T<F%B
M86IO(@H*(SH@8V]N9FEG+RYB86LO871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*
M;7-G:60@(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B17-T861O+W!R
M;W9I;F-I82!D96P@=')A8F%J;R(*"B,Z(&-O;F9I9R\N8F%K+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3$Y"FUS9VED(")7;W)K(%-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(D1I<F5C8VGS;B!D96P@=')A8F%J;R(*"B,Z(&1A=&$N<&AP.C(S
M-R!B<F]W<V4N<&AP.C$P-B!B<F]W<V4N<&AP.C(R-R!A9&0N<&AP.C<S"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S='(@
M(DYO(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!C<F5A<B!MX7,@9&4@
M)60@8V]N=&%C=&]S(&5N(%PB)7-<(BXB"@HC.B!E9&ET+G!H<#HW,R!D:7-P
M;&%Y+G!H<#HU."!V:65W+G!H<#HS-@IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(DYO
M(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!V97(@97-T92!C;VYT86-T
M;RXB"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(DYO(&1I
M<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!V97(@97-T92!O8FIE=&\N(@H*
M(SH@;&EB+U1U<F)A+G!H<#HU,S<*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N<R!T;R!D96QE=&4@=&AI<R!S;W5R8V4N(@IM<V=S='(@(DYO
M(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!E;&EM:6YA<B!E<W1E(&]R
M:6=E;BXB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C4U
M"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")4:65N92!Q=64@<V5L96-C:6]N87(@=6YA(&QI8G)E=&$@
M9&4@9&ER96-C:6]N97,@9&4@9&5S=&EN;RXB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+VIA=F%S8W)I<'0N:6YC.C(S"FUS9VED(")9;W4@;75S="!S96QE8W0@
M82!T87)G970@;&ES="XB"FUS9W-T<B`B5&EE;F4@<75E('-E;&5C8VEO;F%R
M('5N82!L:7-T82!D92!D97-T:6YO+B(*"B,Z(&5D:70N<&AP.C,R"FUS9VED
M(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N
M(@IM<V=S='(@(E!R:6UE<F\@=&EE;F4@<75E('-E;&5C8VEO;F%R(&%L(&UE
M;F]S('5N(&-O;G1A8W1O+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C
M<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHT
M.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED
M(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+B(*
M;7-G<W1R(")0<FEM97)O('1I96YE('%U92!S96QE8V-I;VYA<B!A;"!M96YO
M<R!U;F$@96YT<F%D82XB"@HC.B!E9&ET+G!H<#HW-PIM<V=I9"`B66]U(&]N
M;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G
M<W1R(")3\VQO(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!V97(@97-T
M92!C;VYT86-T;RXB"@HC.B!B<F]W<V4N<&AP.C,Q.`IM<V=I9"`B66]U<B!D
M969A=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E86)L92XB"FUS9W-T
M<B`B3&$@;&EB<F5T82!P;W(@;VUI<VGS;B!N;R!S92!P=65D92!H;VIE87(N
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C8@=&5M<&QA=&5S+V)R
M;W=S92]C;VYT86-T<F]W+FEN8SHQ,@IM<V=I9"`B6VYO('9A;'5E72(*;7-G
M<W1R(");<VEN('9A;&]R72(*"B,Z(&QI8B]4=7)B82YP:'`Z-38P"FUS9VED
M(")?0G)O=W-E(@IM<V=S='(@(E]%>&%M:6YA<B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z-#<*;7-G:60@(E]#;VYT86-T<R(*;7-G<W1R
M(")?0V]N=&%C=&]S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHS"FUS9VED(")?1&5L971E(@IM<V=S='(@(D5L:5]M:6YA<B(*"B,Z(&QI
M8B]4=7)B82YP:'`Z-38Y"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R
M(")?26UP;W)T87(O17AP;W)T87(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C0V"FUS9VED(")?3&ES=',B"FUS9W-T<B`B7TQI<W1A<R(*
M"B,Z(&QI8B]4=7)B82YP:'`Z-34W"FUS9VED(")?37D@061D<F5S<R!";V]K
M<R(*;7-G<W1R(")?36ES(&QI8G)E=&%S(@H*(SH@;&EB+U1U<F)A+G!H<#HU
M-C,*;7-G:60@(E].97<@0V]N=&%C="(*;7-G<W1R(")?0?%A9&ER(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"FUS9VED(")?4F5M;W9E
M(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(D5?;&EM:6YA<B!D92!E<W1A(&QI
M<W1A(@H*(SH@;&EB+U1U<F)A+G!H<#HU-C4*;7-G:60@(E]396%R8V@B"FUS
M9W-T<B`B7T)U<V-A<B(*"B,Z('9C87)D+G!H<#HT-@IM<V=I9"`B8V]N=&%C
M="YV8V8B"FUS9W-T<B`B8V]N=&%C=&\N=F-F(@H*(SH@9&%T82YP:'`Z,3DY
M(&1A=&$N<&AP.C(P-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G
M:60@(F-O;G1A8W1S+F-S=B(*;7-G<W1R(")C;VYT86-T;W,N8W-V(@H*(SH@
M9&%T82YP:'`Z,C`Y"FUS9VED(")C;VYT86-T<RYT<W8B"FUS9W-T<B`B8V]N
M=&%C=&]S+G1S=B(*"B,Z(&1A=&$N<&AP.C(Q.0IM<V=I9"`B8V]N=&%C=',N
M=F-F(@IM<V=S='(@(F-O;G1A8W1O<RYV8V8B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HQ,S@*;7-G:60@(FYO(&9O<FUA='1I;F<B"FUS9W-T
M<B`B<VEN(&9O<FUA=&\B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N
M:6YC.C,R"FUS9VED(")N;VYE(@IM<V=S='(@(FYI;F=U;F\B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Q"FUS9VED(")T;R!A($-O;G1A
M8W0@3&ES="(*;7-G<W1R(")U;F$@3&ES=&$B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")T;R!A(&1I9F9E<F5N="!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B=6YA($QI8G)E=&$@9&4@9&ES=&EN=&$B"@HC
M.B!D871A+G!H<#HU,2!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHQ,PHC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(G9#87)D(@IM<V=S='(@
M(G9#87)D(@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<&\O
M>FA?0TXN<&\`````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`V-#$T-0`Q,#0Q-S,V,C<U-@`P,3<U,S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!4=7)B82!3:6UP;&EF:65D
M($-H:6YE<V4@5')A;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@5V%N
M9TAE;F=796XN"B,@5V%N9TAE;F=796X@/'=H=T!M>3$V.2YC;VT^+"`R,#`Q
M+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!4
M=7)B82`Q+C!<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q
M-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`Q+3`V+3$Y(#`Y
M.C0V*S`X,#!<;B(*(DQA<W0M5')A;G-L871O<CH@5V%N9TAE;F=796X@/'=H
M=T!M>3$V.2YC;VT^7&XB"B),86YG=6%G92U496%M.B!#:&EN97-E(#QW:'=`
M;7DQ-CDN8V]M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U'0C(S,3)<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!T96UP;&%T97,O<')E
M9G,O:6US<%]O<'0N:6YC.C0R"FUS9VED("(@061D(&%N($E-4U`@061D<F5S
M<R!";V]K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P
M="YI;F,Z,S$*;7-G:60@(B!$96QE=&4@24U34"!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I;7!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U<V4@:70@:7,@82!L
M:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!M;W9E9"!B96-A=7-E(&ET(&ES
M(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@*&EE+B!*;VAN
M($1O92DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L($IO
M:&XI(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP
M;W)T960B"FUS9W-T<B`B)7,@SL2\_M+1OJVSR;FFM;S(ZR(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O9F]O=&5R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z
M-#0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@
M0F]O:R(*;7-G<W1R("*UO,CKM=C6M[&^(@H*(SH@;&EB+T)L;V-K+VUI;FES
M96%R8V@N<&AP.C0U"FUS9VED(")!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I
M1G)A;65S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-3D*;7-G:60@(D%B;W9E('-E87)C:"!F;W)M(@IM<V=S
M='(@(B(*"B,Z('9I97<N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(D%C
M8V5S<R!D96YI960@=&\@)7,B"FUS9W-T<B`B(@H*(SH@861D+G!H<#HU-B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(R"FUS9VED(")!9&0B"FUS
M9W-T<B`BU/:\TR(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E
M;&5C="YI;F,Z,3<T"B,L(&9U>GIY"FUS9VED(")!9&0@861D<F5S<R!B;V]K
M(@IM<V=S='(@(K?'MZBUV-:WL;XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#@*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@861D<F5S<R!B;V]K
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T
M+FEN8SHR,S<*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@961I
M="YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")!9&0@9FEL92(*;7-G<W1R("+4
M]KS3LMG7]\JGL-PB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C(R"B,L(&9U>GIY"FUS9VED(")!9&0@=&\B"FUS9W-T<B`BU/:\TR(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C@V"B,L(&9U>GIY"FUS9VED
M(")!9&1R97-S($)O;VLB"FUS9W-T<B`BM;S(Z[78UK>QOB(*"B,Z(&)R;W=S
M92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC+"!F=7IZ>0IM
M<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`BM=C6M[&^RL?6
MN[;!M<0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(K6\R.NUV-:WL;XB"@HC
M.B!A9&0N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K(&5N
M=')Y(@IM<V=S='(@(K78UK>QOLK'UKNVP;7$+B(*"B,Z(&1A=&$N<&AP.C,P
M-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P
M=7)G960N(@IM<V=S='(@(B5S(,[$O/[2T;ZML\FYIK6\R.LB"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B061D
M<F5S<R!B;V]K('1O(&1E;&5T92`B"FUS9W-T<B`BM=C6M[&^RL?6N[;!M<0N
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ
M-S`*;7-G:60@(D%D9')E<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B92!D:7-P
M;&%Y960Z(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z.#@@=&5M<&QA=&5S
M+V)R;W=S92]S96%R8V@N:6YC.C,W"FUS9VED(")!9'9A;F-E9"!396%R8V@B
M"FUS9W-T<B`BN-^\MLO1R_<B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HV-`IM<V=I9"`B06QI87,B"FUS9W-T<B`BL?##^R(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S+V)R;W=S
M92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C4U,@IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE
M=&4@)7,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C
M<FEP="YI;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT
M('1O(&1E;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!<V-E;F1I;F<B
M"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HX-2!T96UP;&%T97,O8G)O=W-E
M+W-E87)C:"YI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(D)A<VEC(%-E87)C:"(*
M;7-G<W1R("*RZ=72(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM
M<V=I9"`B0F5L;W<@<V5A<F-H(&9O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HW-R!L:6(O1')I=F5R+VQD87`N<&AP.C@P"B,L('!H
M<"UF;W)M870*;7-G:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*
M;7-G:60@(D)R;W=S92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C0Y"FUS9VED(")#4U8B"FUS9W-T<B`B(@H*
M(SH@;&EB+T]B:F5C="]'<F]U<"YP:'`Z-3<*;7-G:60@(D-A;B=T(&%D9"!A
M(&=R;W5P('1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C0T"FUS9VED(")#:&]O<V4@82!N86UE(@IM<V=S='(@(B(*"B,Z(&%D9"YP
M:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLB
M"FUS9W-T<B`BM\>WJ+78UK>QOB(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(R,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%D
M9')E<W,@8F]O:SHB"FUS9W-T<B`BM\>WJ+78UK>QOB(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,38U"FUS9VED(")#:&]O
M<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA
M="!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(R.`IM<V=I9"`B0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@9&ES<&QA
M>2!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$W"FUS9VED(")#;VQU;6X@3W!T:6]N<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S,*
M;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3,@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I9"`B0V]M;6$@<V5P87)A
M=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R
M;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BN:O+OB(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`HC+"!F=7IZ>0IM
M<V=I9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S='(@(KS2S:6UV-:W(@H*(SH@
M;&EB+V%P:2YP:'`Z,S$X(&QI8B]A<&DN<&AP.C,V,R!L:6(O87!I+G!H<#HT
M,#<@;&EB+V%P:2YP:'`Z-#DQ"B,Z(&QI8B]A<&DN<&AP.C8P,2!L:6(O87!I
M+G!H<#HV.#@@;&EB+V%P:2YP:'`Z-S0Q(&QI8B]A<&DN<&AP.C@Q.0HC.B!L
M:6(O87!I+G!H<#HQ,#`V(&QI8B]A<&DN<&AP.C$P.30*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("+)OK/]LMG7]\JGL-PB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C4X"B,L
M(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QU<F4B"FUS9W-T<B`BR;ZS
M_;+9U_?*I[#<(@H*(SH@8G)O=W-E+G!H<#HQ.3$@8G)O=W-E+G!H<#HR,S(*
M;7-G:60@(D-O;G1A8W0@861D960@=&\@;&ES="XB"FUS9W-T<B`B(@H*(SH@
M8G)O=W-E+G!H<#HV,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I
M9"`B0V]P>2(*;7-G<W1R("*YJ\N^(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-3,*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B0W)E
M871E($%D9')E<W,@0F]O:R(*;7-G<W1R("*YI-?WM=C6MR(*"B,Z(&QI8B],
M:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A=&4@82!N97<@0V]N=&%C="!,
M:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S
M"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z(&QI8B]/8FIE8W0N
M<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z
M-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R("+)OK/](@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!!
M9&1R97-S($)O;VLB"FUS9W-T<B`BN:37][78UK<B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED(")$
M96QE=&4@8G5T=&]N(&)E:&%V:6]U<B(*;7-G<W1R("(B"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C(W,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("+)OK/]LMG7]\JGL-PB
M"@HC.B!D96QE=&4N<&AP.C,X"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS
M9W-T<B`BR;ZS_;+9U_?*I[#<(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*;7-G
M:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O<V5A<F-H+FEN8SHQ,3@*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("+$
MO\*\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS9VED(")$:7-P
M;&%Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$W-@IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E
M;G1R:65S/R(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*;7-G
M:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<F]W+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(U
M"FUS9VED(")$;W=N;&]A9"!V0V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N
M:6YC.C(U"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC
M.C$P('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PHC.B!T96UP;&%T
M97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z
M-#(*;7-G:60@(D5D:70B"FUS9W-T<B`BL>"\K2(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<F]W+FEN8SHR-2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N
M:6YC.C,S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<
M(B(*;7-G<W1R("*QX+RM(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z.#$*(RP@9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G
M<W1R("*YI-?WM=C6MR(*"B,Z(&5D:70N<&AP.C<X(&5D:70N<&AP.C$U-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(&5N=')Y(&9O<B`E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B
M16UA:6PB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,30W"B,L('!H<"UF;W)M
M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H
M92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@961I
M="YP:'`Z,30Y(&5D:70N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;G1R>2!F;W(@)7,@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H
M<#HW-`HC+"!F=7IZ>0IM<V=I9"`B16YT<GD@<W5C8V5S<V9U;&QY(&1E;&5T
M960N(@IM<V=S='(@(B5S(,[$O/[2T;ZML\FYIK6\R.LB"@HC.B!L:6(O87!I
M+G!H<#HT,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E
M87)C:&EN9R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+$O\*\R]'+
M]\JGL-PZ("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*
M;7-G<W1R("*UO+/V(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHV
M"B,L(&9U>GIY"FUS9VED(")%>'!O<G0@061D<F5S<R!";V]K(@IM<V=S='(@
M(KFDU_>UV-:W(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM
M<V=I9"`B17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(W"FUS9VED
M(")%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L
M>2XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3,T(&1A=&$N<&AP.C(R."!D
M871A+G!H<#HR.3<@8G)O=W-E+G!H<#HS-2!B<F]W<V4N<&AP.CDP"B,Z(&)R
M;W=S92YP:'`Z,3$R(&%D9"YP:'`Z-C<@<V5A<F-H+G!H<#HS-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D
M<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+$O\*\R]'+]\JGL-PZ("5S(@H*(SH@
M8G)O=W-E+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S(@IM<V=S='(@(L2_PKS+T<OWRJ>P
MW#H@)7,B"@HC.B!B<F]W<V4N<&AP.C(W,@IM<V=I9"`B1F%I;&5D('1O(&)R
M;W=S92!L:7-T(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,S$P"B,L(&9U
M>GIY"FUS9VED(")&86EL960@=&\@8G)O=W-E('1H92!D:7)E8W1O<GDB"FUS
M9W-T<B`BQ+_"O,O1R_?*I[#<.B`E<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,S`Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C:&%N9V4@
M;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T
M(#T@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B
M92!A9&1E9#H@)7,B"FUS9W-T<B`BQ+_"O,O1R_?*I[#<.B`E<R(*"B,Z('-E
M87)C:"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@
M=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("+$O\*\R]'+]\JGL-PZ("5S(@H*
M(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,B"FUS9W-T<B`BQ+_"O,O1R_?*
MI[#<.B`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM
M<V=I9"`B1F%X(@IM<V=S='(@(K2KU>8B"@HC.B!E9&ET+G!H<#HQ,C0@9&ES
M<&QA>2YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")&:6QE<R(*;7-G<W1R("*Q
MZLSB(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<P"FUS9VED
M(")&:6YD(@IM<V=S='(@(K+IU=(B"@HC.B!E9&ET+G!H<#HY-R!E9&ET+G!H
M<#HQ.#<*(RP@9G5Z>GD*;7-G:60@(D9I;FES:"(*;7-G<W1R("*RZ=72(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T
M($YA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@S"B,L(&9U>GIY"FUS9VED(")&
M<F]M(@IM<V=S='(@(K>BO/[(RR(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C8P-`HC+"!F=7IZ>0IM<V=I9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*
M;7-G<W1R("*YI-?WM=C6MR(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN
M8SHT,R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C0T"FUS9VED
M(")'<F]U<"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(KS2S:6UV-:W
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3,*;7-G:60@(DAO
M;64@0VET>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ,#@*(RP@9G5Z>GD*;7-G:60@(DAO;64@0V]U;G1R>2(*;7-G<W1R
M("*\TLVEM>>[L"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U
M,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("*\TLVEM>>[L"(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M2&]M92!0;W-T86P@0V]D92(*;7-G<W1R("*\TLVEM>>[L"(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED(")(;VUE
M(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(KS2S:6UY[NP(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z.#@*(RP@9G5Z>GD*;7-G:60@(DAO;64@
M4W1R965T($%D9')E<W,B"FUS9W-T<B`BO-+-I;78UK<B"@HC.B!C;VYF:6<O
M<V]U<F-E<RYP:'`N9&ES=#HU,#8*;7-G:60@(DE-4U`B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W"FUS9VED("))35-0($%D9')E
M<W,@0F]O:R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T<B`BM;S(
MZ[78UK>QOB(*"B,Z(&1A=&$N<&AP.C,V,0HC+"!F=7IZ>0IM<V=I9"`B26UP
M;W)T+T5X<&]R="!!9&1R97-S($)O;VMS(@IM<V=S='(@(K6\R.LOM;RS]K78
MUK>QOB(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O87!I+G!H<#HV.#,*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`BM\>WJ,/[L\8B"@HC
M.B!L:6(O87!I+G!H<#HR,S`@;&EB+V%P:2YP:'`Z-#`R(&QI8B]A<&DN<&AP
M.C0X-B!L:6(O87!I+G!H<#HU.3(*(SH@;&EB+V%P:2YP:'`Z-C<Y(&QI8B]A
M<&DN<&AP.C<S,2!L:6(O87!I+G!H<#HQ,#<W"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R("*WQ[>HM=C6M[&^(@H*(SH@
M;&EB+V%P:2YP:'`Z,3`X,2!L:6(O87!I+G!H<#HQ,34T(&QI8B]A<&DN<&AP
M.C$R,#<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@96UA:6PB"FUS9W-T<B`B
MM\>WJ+7$($4M36%I;""UV-:W(@H*(SH@;&EB+V%P:2YP:'`Z,3`X.0HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!E;G1R>2(*;7-G<W1R("*WQ[>HP_NSQB(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C8V"FUS9VED("));G9A;&ED(&ME
M>2!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$P.#4*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;F%M92(*;7-G<W1R("*WQ[>HP_NS
MQB(*"B,Z(&QI8B]A<&DN<&AP.C<S-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!O8FIE8W1)9"(*;7-G<W1R("*WQ[>HP_NSQB(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E
M9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T
M(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S
M.`IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HU,PHC+"!F=7IZ>0IM<V=I9"`B3&%S="!.
M86UE(@IM<V=S='(@(L/[L\8B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M
M;E]H96%D97)S+FEN8SHQ-@IM<V=I9"`B3&ES="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S<*;7-G:60@(DUA=&-H:6YG
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C(P-0IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@<&%G
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PIM
M<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M:6YI
M<V5A<F-H+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-:6YI(%-E87)C:"(*;7-G
M<W1R("*RZ=72(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G:60@
M(DUI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"B,L
M(&9U>GIY"FUS9VED(")-;V)I;&4@4&AO;F4B"FUS9W-T<B`BO-+-I;7GN[`B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N
M<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H
M)7,I("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.3,*;7-G:60@
M(DUO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3$*;7-G:60@(DUO=F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0W
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@T
M"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y"B,Z('1E;7!L871E<R]P<F5F<R]A
M9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V"FUS9VED(")-;W9E(')I9VAT(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O
M:R(*;7-G<W1R("*YI-?WM=C6MR(*"B,Z(&QI8B]A<&DN<&AP.C$Q,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB375L=&EP;&4@<&5R<V]N<R!W:71H(&%D
M9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@86QR96%D>2!E
M>&ES="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ
M,#<@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,C0S"B,L(&9U>GIY"FUS9VED
M(")->2!!9&1R97-S($)O;VLB"FUS9W-T<B`BM;S(Z[78UK>QOB(*"B,Z(&%D
M9')E<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S
M($)O;VMS(@IM<V=S='(@(KFDU_>UV-:W(@H*(SH@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z,3`W(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0R
M"FUS9VED(").86UE(@IM<V=S='(@(L/[L\8B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T8V5N=&5R
M($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@861D+G!H<#HS-B!A
M9&0N<&AP.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*(SH@;&EB
M+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE=R!#
M;VYT86-T(@IM<V=S='(@(M3VO-/0PK7$P:K/M<C+(@H*(SH@961I="YP:'`Z
M.#@@961I="YP:'`Z.34@961I="YP:'`Z,C`R('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z-#4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$X"B,L(&9U>GIY"FUS9VED(").:6-K
M;F%M92(*;7-G<W1R("+#^[/&(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y-2!L:6(O
M87!I+G!H<#HQ,C0T"B,L('!H<"UF;W)M870*;7-G:60@(DYO("5S(&5N=')Y
M(&9O=6YD(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,38S
M"B,L(&9U>GIY"FUS9VED(").;R!A9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G
M<W1R("*UV-:WL;[*Q]:[ML&UQ"XB"@HC.B!M:6YI<V5A<F-H+G!H<#HX,PIM
M<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z-3$Q(&QI8B]A<&DN<&AP.C<V-@IM<V=I9"`B3F\@=D-A<F0@9&%T
M82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M9F]O=&5R+FEN8SHW"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(K&X
MUZ(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(DYO=&5S(@IM<V=S='(@(K&XUZ(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$U"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<T-PIM<V=I
M9"`B3V)J96-T(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HR,C,*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(S"FUS9VED("(B
M"B)/;F-E('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H92!A9&1R97-S
M(&)O;VL@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B!)9B!T:&ES
M(&ES(&YO="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T(&-H86YG92!Y
M;W5R('-E;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z-S<T"FUS9VED(")/;FQY(&]N92!V8V%R9"!S=7!P;W)T
M960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D]T:&5R($]P=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DP
M"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HT.34@;&EB+V%P:2YP:'`Z-C`U(&QI8B]A<&DN<&AP.C8Y,B!L:6(O
M87!I+G!H<#HY,S0*(SH@;&EB+V%P:2YP:'`Z,3`Y.`IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z-30S
M"FUS9VED(")097)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHY.0IM<V=I9"`B4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-3,@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B4&EN92!!9&1R97-S($)O;VLB
M"FUS9W-T<B`BM;S(Z[78UK>QOB(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V
M87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE('1H92!N97<@8V]N
M=&%C="!L:7-T.B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY,2!E9&ET+G!H
M<#HY-"!E9&ET+G!H<#HQ.30*;7-G:60@(E!R979I;W5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q-@HC+"!F=7IZ>0IM<V=I
M9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`BN:37][78UK<B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")1=65R>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")1
M=6EC:R!396%R8V@B"FUS9W-T<B`BLNG5TB(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E860@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]296YD97)E<BYP:'`Z-#D*
M;7-G:60@(E)E86QL>2!D96QE=&4@=&AI<R!C;VYT86-T/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z,@IM<V=I9"`B4F5C
M;W)D<R!D:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<V"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4@861D<F5S<R!B;V]K(@IM<V=S='(@(K6\R.NUV-:WL;XB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,SD*;7-G:60@(E)E
M;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0IM<V=I
M9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@
M:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E
M<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO
M<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G
M:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!A9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*
M;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI
M8R!#97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY.2!A9&0N<&AP.C,W
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V92(*
M;7-G<W1R("*QH[3F(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC
M.CDV('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3(*(SH@=&5M<&QA
M=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(Q(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C0Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@
M(E-E87)C:"(*;7-G<W1R("*RZ=72(@H*(SH@;6EN:7-E87)C:"YP:'`Z-C,*
M(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!297-U;'1S.B(*;7-G<W1R("*RZ=72
MO>&Y^R(*"B,Z(&QI8B]A<&DN<&AP.C$P,3$*(RP@9G5Z>GD*;7-G:60@(E-E
M87)C:"!F86EL960B"FUS9W-T<B`BLNG5TB(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M,#,@;&EB+V%P:2YP:'`Z,3$P.2!L:6(O87!I+G!H<#HQ,3$X(&QI8B]A<&DN
M<&AP.C$Q,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N
M:6YC.C(R"B,L(&9U>GIY"FUS9VED(")396%R8VAI;F<N+BXB"FUS9W-T<B`B
MLNG5TB(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8V"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@86X@861D<F5S<R!B;V]K('1O(&1E;&5T92(*
M;7-G<W1R("+'Z]&AU/'2N[&^Q./2JM3VO-.UQ+78UK>QOBXB"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(L?KT:'4\=*[
ML;[$X]*JU/:\T[7$M=C6M[&^+B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,S(*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X
M<&]R="!F<F]M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&%D9')E<W,@
M8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(L?KT:'4\=*[L;[$X]*JU/:\
MT[7$M=C6M[&^+B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S4*
M;7-G:60@(E-E;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*
M;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L96-T
M('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHQ,0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@
M;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!U<V5D
M('1O(&1I<W!L87D@;F%M97,Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B
M>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED
M(")396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E
M<W,@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,@IM<V=I9"`B4V5L96-T('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA
M;65S+B(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C4T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")396QE8W1E9"!A9&1R97-S(&)O;VL@7"(E<UPB+B(*
M;7-G<W1R("*WQ[>HM=C6M[&^(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I
M<W0Z,3<S"B,L(&9U>GIY"FUS9VED(")3:&%R960@1&ER96-T;W)Y(@IM<V=S
M='(@(L2_PKPB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B4VAO=R!!
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT,`IM<V=I9"`B4VAO=R!#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")3:&]W($QI<W1S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C(Q"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N
M:6YC.C,T"B,L(&9U>GIY"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R
M("+$O\*\(@H*(SH@;&EB+V%P:2YP:'`Z,3DX"B,L(&9U>GIY"FUS9VED(")3
M;W5R8V5S(@IM<V=S='(@(K/)N:8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34W"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT(&%D=F%N8V5D
M('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B(@H*(SH@8G)O
M=W-E+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&%D9&5D("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C(R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C<F5A=&5D('1H
M92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HU,`IM<V=I9"`B5%-6(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-`IM
M<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B(@H*(SH@=FEE
M=RYP:'`Z,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D<R!T;R!B92!C
M;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A9',N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@
M7"(E<UPB('=A<R!R96UO=F5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*
M(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T
M960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C0W('9C87)D+G!H<#HR,B!D
M:7-P;&%Y+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A8W0@
M>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@
M961I="YP:'`Z,3$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92!<(B5S7"(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N(@IM
M<V=S='(@(B5S(,[$O/[2T;ZML\FYIK6\R.LB"@HC.B!D871A+G!H<#HR.#0*
M;7-G:60@(E1H92!I;7!O<G0@8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE
M('=A<FYI;F=S+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C,Q"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O
M;VMS+B(*;7-G<W1R("*XP[78UK?2T;ZMU-K$X[7$M=C6M[&^UM"TYM3:+B(*
M"B,Z(&%D9"YP:'`Z,CD*;7-G:60@(B(*(E1H97)E(&%R92!N;R!W<FET96%B
M;&4@861D<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@879A:6QA8FQE(&%D9')E
M<W,@8F]O:W,@(@HB87)E(&-O;F9I9W5R960@=&\@86QL;W<@>6]U('1O(&%D
M9"!N97<@96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES("(*
M(FES(&%N(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C$R,0IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A8W0N
M($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B`B"B)F;W(@9G5R
M=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$X.2!B<F]W
M<V4N<&AP.C(S,`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T
M:&ES(&]B:F5C="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR,S@*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*
M;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D
M9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T
M:6YG(%PB)7-<(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("(B"@HC.B!D96QE=&4N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z-S(*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B(@H*
M(SH@8G)O=W-E+G!H<#HR-S@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H92!L:7-T(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,S
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HU,#<@;&EB+V%P:2YP:'`Z-S8Q"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@8G)O=W-E+G!H<#HU.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E
M;6]V:6YG(&$@8V]N=&%C="!F<F]M('1H92!L:7-T+B(*;7-G<W1R("(B"@HC
M.B!A9&1R97-S8F]O:W,N<&AP.C4U(&%D9')E<W-B;V]K<RYP:'`Z-C`@861D
M<F5S<V)O;VMS+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@<F5M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM
M<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#$@861D<F5S<V)O;VMS
M+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(B(*
M"B,Z(&5D:70N<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,B"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z,3<Y"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E
M<W-E<R!T;R!E>'!O<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R
M97-S(&)O;VMS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#,*
M;7-G:60@(E1H97-E(&-O;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D
M97(Z(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F
M:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HQ,3(R(&QI8B]A<&DN<&AP.C$Q,S4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@
M96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("*XP[78UK?2T;ZM
MU-K$X[7$M=C6M[&^UM"TYM3:+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#<*;7-G:60@(B(*(E1H:7,@=VEL;"!B92!T:&4@9&5F875L="!A9&1R
M97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG(&-O;G1A8W1S+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW,`IM
M<V=I9"`B5&ET;&4B"FUS9W-T<B`BL>K,XB(*"B,Z(&QI8B]4=7)B82YP:'`Z
M-#,U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@;F5W
M('-H87)E+B`@36ES<VEN9R!S;W5R8V4@='EP92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H
M<#HY.2!E9&ET+G!H<#HQ.38*(RP@9G5Z>GD*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R("*QH[3FN/RXQ"(*"B,Z(&QI8B]A<&DN<&AP.C4T,"!L:6(O
M87!I+G!H<#HV-#,@;&EB+V%P:2YP:'`Z-S<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"B,L(&9U>GIY"FUS9VED
M(")697)I<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`BQ+_"O"(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&UI;FES96%R8V@N<&AP.C<X"B,L(&9U>GIY"FUS
M9VED(")6:65W($-O;G1A8W0B"FUS9W-T<B`BU/:\T]#"M<3!JL^UR,LB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")6:65W('1O(&1I
M<W!L87D@8GD@9&5F875L=#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,C`X"FUS9VED(")796)S:71E(%523"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3,*;7-G:60@
M(E=O<FL@061D<F5S<R(*;7-G<W1R("*YI-?WM=C6MR(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5V]R:R!#:71Y(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S.0HC+"!F
M=7IZ>0IM<V=I9"`B5V]R:R!#;W5N=')Y(@IM<V=S='(@(KFDU_>UY[NP(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34V"FUS9VED(")7;W)K
M(%!H;VYE(@IM<V=S='(@(KFDU_>UY[NP(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED(")7;W)K(%!O<W1A;"!#
M;V1E(@IM<V=S='(@(KFDU_>UY[NP(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3(Y"B,L(&9U>GIY"FUS9VED(")7;W)K(%-T871E+U!R;W9I
M;F-E(@IM<V=S='(@(KFDU_>UY[NP(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3$Y"B,L(&9U>GIY"FUS9VED(")7;W)K(%-T<F5E="!!9&1R
M97-S(@IM<V=S='(@(KFDU_>UV-:W(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S
M92YP:'`Z.3,@8G)O=W-E+G!H<#HR,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@8V]N=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!E
M9&ET+G!H<#HV.2!D:7-P;&%Y+G!H<#HU."!V:65W+G!H<#HS-@IM<V=I9"`B
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A
M8W0N(@IM<V=S='(@(B(*"B,Z('9C87)D+G!H<#HT,`IM<V=I9"`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHU
M-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T
M+FEN8SHR,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N
M(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C,R"FUS9VED(")9;W4@;75S="!S
M96QE8W0@870@;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O
M=W-E+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@
M870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!E9&ET
M+G!H<#HW,PIM<V=I9"`B66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(X
M-0IM<V=I9"`B66]U<B!D969A=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O
M=W-E86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N
M:6YC.C8@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHQ,@IM<V=I
M9"`B6VYO('9A;'5E72(*;7-G<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0X
M-`IM<V=I9"`B7T)R;W=S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C0P"FUS9VED(")?0V]N=&%C=',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,L(&9U>GIY
M"FUS9VED(")?1&5L971E(@IM<V=S='(@(LF^L_TB"@HC.B!L:6(O5'5R8F$N
M<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T
M<B`BM;S(ZR^UO+/V(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHS.0IM<V=I9"`B7TQI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP
M:'`Z-#@Q"B,L(&9U>GIY"FUS9VED(")?37D@061D<F5S<R!";V]K<R(*;7-G
M<W1R("*UO,CKM=C6M[&^(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#<*(RP@9G5Z
M>GD*;7-G:60@(E].97<@0V]N=&%C="(*;7-G<W1R("+4]KS3T,*UQ,&JS[7(
MRR(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@IM<V=I9"`B
M7U)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O5'5R
M8F$N<&AP.C0X.0HC+"!F=7IZ>0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R("*R
MZ=72(@H*(SH@=F-A<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C9B(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B8V]N=&%C=',N='-V(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z
M,S0*;7-G:60@(FYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHR-`IM<V=I9"`B=&\@82!#;VYT86-T($QI<W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ-`HC
M+"!F=7IZ>0IM<V=I9"`B=&\@82!D:69F97)E;G0@061D<F5S<R!";V]K(@IM
M<V=S='(@(KFDU_>UV-:W(@H*(SH@9&%T82YP:'`Z-3$@=&5M<&QA=&5S+V)R
M;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ-2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS
M9VED(")V0V%R9"(*;7-G<W1R("(B"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O<&\O>FA?5%<N<&\`````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W-#(V,@`Q,#0Q-S,V,C<U-@`P,3<U
M-C4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R!4=7)B82!4<F%D:71I;VYA;"!#:&EN97-E(%1R86YS;&%T:6]N+@HC($-O
M<'ER:6=H="`H0RD@,C`P,2!$879I9"!#:&%N9RX@L6FH?:3E+*5XQE<*(R!$
M879I9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SXL(#(P,#$N,3(*(PIM<V=I
M9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@,BXP
M+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`Q+3`U(#$U.C`T
M*S`X,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#$M,#@@,3`Z-3,K
M,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!$879I9"!#86AN9R`\9&%V:61`
M=&UV+F=O=BYT=SY<;B(*(DQA;F=U86=E+51E86TZ(%1R861I=&EO;F%L($-H
M:6YE<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U"
M24<U7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHT,`IM<V=I9"`B($%D
M9"!A;B!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R("*W<[Q7I$"ENR!)35-0
M(+-QL%2__2(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,CD*
M;7-G:60@(B!$96QE=&4@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`BIU*P
MHR!)35-0(+-QL%2__3HB"@HC.B!D871A+G!H<#HS,C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&%L<F5A9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM
M<&]R=&5D+B(*;7-G<W1R(")<(B5S7"(@I'>F<Z9BIM.E0JA3IK.VUZ1*N.JN
MQBXB"@HC.B!B<F]W<V4N<&AP.C$T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM
M<V=S='(@(J71J?,@7"(E<UPB(*Q/I$"MT[ASLM6F7::YM4RJ:[-1O<:[<RXB
M"@HC.B!B<F]W<V4N<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&YO="!M;W9E9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T
M<B`BI=&I\R!<(B5S7"(@K$^D0*W3N'.RU:9=IKFU3*IKLU&W:+*^+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@(EPB1FER<W1N86UE
M($QA<W1N86UE7"(@("AI92X@2F]H;B!$;V4I(@IM<V=S='(@(EPBIE>F<B"I
M;:3S7"(@**C2IG`N(*3TJ_,@LZ\I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$
M;V4L($IO:&XI(@IM<V=S='(@(EPBJ6VD\R"F5Z9R7"(@**C2IG`N(+.O(*3T
MJ_,I(@H*(SH@861D+G!H<#HQ,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M861D960N(@IM<V=S='(@(B5S(*1WMW.\5RXB"@HC.B!D871A+G!H<#HS-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP
M;W)T960B"FUS9W-T<B`BP,FNUR`E<R"D=[;7I$JGN::H(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B("5S(*CL("5S(*9`("5S(@H*(SH@
M;&EB+U1U<F)A+G!H<#HT-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B)7,@JKJS<;!4O_TB"@HC.B!L:6(O0FQO
M8VLO;6EN:7-E87)C:"YP:'`Z-#(*;7-G:60@(D$@8G)O=W-E<B!T:&%T('-U
M<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B"FUS9W-T<B`BPG/$_;ZYI;*V
MMZ3DM*D@:49R86UE<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C`*
M;7-G:60@(D%B;W9E('-E87)C:"!F;W)M(@IM<V=S='(@(K=JM$VJ[;/FI%>M
ML2(*"B,Z('9I97<N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S
M<R!D96YI960@=&\@)7,B"FUS9W-T<B`BIG.H^B`E<R"^1*G:(@H*(SH@861D
M+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(Y"FUS9VED
M(")!9&0B"FUS9W-T<B`BMW.\5R(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R
M97-S8F]O:W-E;&5C="YI;F,Z,3<T"FUS9VED(")!9&0@861D<F5S<R!B;V]K
M(@IM<V=S='(@(K=SO%>S<;!4O_TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#@*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@861D<F5S<R!B;V]K
M<R(*;7-G<W1R("*W<[Q7NU"G4K"C($E-4U`@LW&P5+_](@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,W"FUS9VED(")!9&0@8V]L
M=6UN(@IM<V=S='(@(K=SO%?$YJ;L(@H*(SH@961I="YP:'`Z,3,U"FUS9VED
M(")!9&0@9FEL92(*;7-G<W1R("*W<[Q7P,FNUR(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"!T;R(*;7-G<W1R("*W
M<[Q7J.PB"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4W"FUS9VED(")!9&1I
M;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BJ=*W<[Q7
MJKJS<[6XI$BU3*[$+B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C@V"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`BLW&P5+_](@H*(SH@
M8G)O=W-E+G!H<#HR."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"FUS9VED
M(")!9&1R97-S($)O;VL@3&ES=&EN9R(*;7-G<W1R("+"<\3](@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P"FUS9VED(")!9&1R97-S($)O;VMS(@IM
M<V=S='(@(K-QL%2__2(*"B,Z(&%D9"YP:'`Z,3`X"FUS9VED(")!9&1R97-S
M(&)O;VL@96YT<GDB"FUS9W-T<B`BLW&P5+_]N.JNQBXB"@HC.B!D871A+G!H
M<#HS,#4*;7-G:60@(D%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D
M+B(*;7-G<W1R("*S<;!4O_VD=Z>YIJBR3:K%+B(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C8R"FUS9VED(")!9&1R97-S(&)O;VL@=&\@9&5L
M971E("(*;7-G<W1R("*G4K"CLW&P5+_]("(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<P"FUS9VED(")!9&1R97-S(&)O
M;VMS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R("*DH\7C
MI=RJNK-QL%2__3HB"@HC.B!S96%R8V@N<&AP.C@X('1E;7!L871E<R]B<F]W
M<V4O<V5A<F-H+FEN8SHS.`IM<V=I9"`B061V86YC960@4V5A<F-H(@IM<V=S
M='(@(K9IMJ6W:K1-(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M-C0*;7-G:60@(D%L:6%S(@IM<V=S='(@(K9LI?.G3Z97(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z-R!T96UP;&%T97,O8G)O=W-E
M+V9O;W1E<D%L<&AA+FEN8SHQ,`HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C0X"FUS9VED(")!;&PB"FUS9W-T<B`BJ=*FLR(*"B,Z(&QI8B]A
M<&DN<&AP.C4U-`IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`BI'>F
M<Z9B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N
M="!T;R!D96QE=&4@)7,_(@IM<V=S='(@(J=!O52I=ZUNIU*PHR`E<R`_(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHV-PIM<V=I9"`B
M07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E('1H92!S96QE
M8W1E9"!E;G1R:65S/R(*;7-G<W1R("*G0;U4J7>M;J=2L*.ITK_OOMRJNKCJ
MKL:VW"`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!
M<V-E;F1I;F<B"FUS9W-T<B`BI,F^K2(*"B,Z('-E87)C:"YP:'`Z.#4@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,W"FUS9VED(")"87-I8R!396%R
M8V@B"FUS9W-T<B`BL/*EN[=JM$TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34Y"FUS9VED(")"96QO=R!S96%R8V@@9F]R;2(*;7-G<W1R("*W:K1-
MJNVSYJ15K;$B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL
M960Z("@E<RD@)7,B"FUS9W-T<B`BLW.ULJ6BL=$Z("@E<RD@)7,B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D)I<G1H9&%Y
M(@IM<V=S='(@(J7-I.DB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I
M9"`B0G)O=W-E(@IM<V=S='(@(L)SQ/TB"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S
M='(@(K#3MWZDP,/^(@H*(SH@9&%T82YP:'`Z-#D*;7-G:60@(D-35B(*;7-G
M<W1R("*S<L))I,"Y:J[FIJ$@+F-S=B(*"B,Z(&QI8B]/8FIE8W0O1W)O=7`N
M<&AP.C4W"FUS9VED(")#86XG="!A9&0@82!G<F]U<"!T;R!I='-E;&8N(@IM
M<V=S='(@(K5,JFNQ3KASLM6H[*6[J*TN(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]C;VQU;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE
M(@IM<V=S='(@(L#+K&0@I?ZSH2^U3%]!(@H*(SH@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z-#0*;7-G:60@(D-H;V]S92!A(&YA;64B"FUS9W-T<B`B
MO^^^W*1`K=.F5[K9(@H*(SH@861D+G!H<#HT.`IM<V=I9"`B0VAO;W-E(&%N
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("*_[[[<I$"EN[-QL%2__2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R,0IM<V=I9"`B0VAO
M;W-E(&%N(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BO^^^W*1`I;NS<;!4O_TZ
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ
M-C4*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O(&1I<W!L
M87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R("*_[[[<K6[%XZ7<JKJS
M<;!4O_TLI,ZHY+:VI\<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM
M<V=S='(@(K_OOMRM;JC/I<ZJNK-QL%2__2XB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V]L=6UN<V5L96-T+FEN8SHR,C@*;7-G:60@(D-H;V]S92!W:&EC:"!C
M;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H870@;W)D97(Z(@IM<V=S='(@
M(K_OOMRM;L7CI=RJNL3FINRF5[K9+*3.J.2VMJ?'.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B0V]L=6UN($]P=&EO;G,B"FUS9W-T
M<B`BQ.:F[+_OMK4B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T
M+FEN8SHR,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P
M;&%Y960Z(@IM<V=S='(@(J2CQ>.EW*JZQ.:F[*97NMDZ(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$R"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@
M(K-RPDFDP+EJK<@@*"HN8W-V*2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,@*$UI8W)O
M<V]F="!/=71L;V]K*2(*;7-G<W1R("*S<L))I,"Y:JW(("A-:6-R;W-O9G0@
M3W5T;&]O:R`J+F-S=BDB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("*DO:5Q(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"FUS9VED(")#;VUP86YY($%D9')E
M<W,B"FUS9W-T<B`BI+VE<:9AIWTB"@HC.B!L:6(O87!I+G!H<#HS,C`@;&EB
M+V%P:2YP:'`Z,S8U(&QI8B]A<&DN<&AP.C0P.2!L:6(O87!I+G!H<#HT.3,*
M(SH@;&EB+V%P:2YP:'`Z-C$Y(&QI8B]A<&DN<&AP.C<P-B!L:6(O87!I+G!H
M<#HW-3D@;&EB+V%P:2YP:'`Z.#,W"B,Z(&QI8B]A<&DN<&AP.C$P,C0@;&EB
M+V%P:2YP:'`Z,3$Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`BLW.ULJ6BL=$Z("5S(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HU.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM
M<V=S='(@(K-SM;*EHK'1(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP
M.C,@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C(V"FUS9VED(")#;VYT86-T
M(%-E87)C:"(*;7-G<W1R("*S<[6XI$BW:K1-(@H*(SH@8G)O=W-E+G!H<#HR
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&%C=',@:6X@;&ES=#H@)7,B
M"FUS9W-T<B`BN'.RU3H@)7,@I*2JNK-SM;BD2"(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z,3@*;7-G:60@(D-O<'DB"FUS9W-T<B`BO<:[
M<R(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C4S"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`BJ]BEWR(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C0P"FUS9VED(")#<F5A=&4@061D<F5S<R!";V]K(@IM<V=S='(@
M(JO8I=^S<;!4O_TB"@HC.B!L:6(O3&ES=%9I97<N<&AP.C,T.`IM<V=I9"`B
M0W)E871E(&$@;F5W($-O;G1A8W0@3&ES="!I;CHB"FUS9W-T<B`BIF*D5:9#
MLW&P5+_]J]BEW[=SN'.RU3HB"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S
M"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(JO8I=\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3@*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I
M;VXZ(@IM<V=S='(@(KEWLUVQQJ?'I.BF5CHB"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHW-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C,*(SH@;&EB+T]B:F5C="YP:'`Z,S(X(&QI8B]296YD97)E<BYP:'`Z-#<@
M;&EB+U)E;F1E<F5R+G!H<#HU,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(J=2
ML*,B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU.`IM<V=I9"`B
M1&5L971E($%D9')E<W,@0F]O:R(*;7-G<W1R("*G4K"CLW&P5+_].B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1&5L971E($-O;F9I
M<FUA=&EO;B(*;7-G<W1R("*G4K"CO52[>R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.0IM<V=I9"`B1&5L971E(&)U='1O;B!B96AA=FEO=7(B"FUS
M9W-T<B`BIU*PHZOVMG.JNJ;FK+`B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D.B`H)7,I
M("5S(@IM<V=S='(@(J=2L*.EHK'1.B`H)7,I("5S(@H*(SH@;&EB+T1R:79E
M<B]N=6QL+G!H<#HV,@IM<V=I9"`B1&5L971I;F<@8V]N=&%C=',@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`BJ=*G4K"CJKJS<[6XI$BU3*[$+B(*"B,Z
M(&1E;&5T92YP:'`Z,S@*;7-G:60@(D1E;&5T:6]N(&9A:6QE9"(*;7-G<W1R
M("*G4K"CI:*QT2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q
M,PIM<V=I9"`B1&5P87)T;65N="(*;7-G<W1R("*SH:KY(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@
M(JVPOJTB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*;7-G
M:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(K1YK7HB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+W-E87)C:"YI;F,Z,3$Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`BI=B__2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B
M1&ES<&QA>2(*;7-G<W1R("+%XZ7<(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+%XZ7<O^^VM2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D1O('EO=2!W86YT('1O(&-O
M;F9I<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T<B`BIU*PH[!/O_VNR:Q/
MIU^[W:UNO52[>R`_(@H*(SH@;&EB+T]B:F5C="YP:'`Z,CDW"FUS9VED(")$
M;W=N;&]A9"(*;7-G<W1R("*D5;C\(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R
M;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C4*
M;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(J15N/P@=D-A<F0B"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@=&5M<&QA=&5S+V)R
M;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C$P('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-@HC
M.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S(&QI8B]296YD
M97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B"FUS9W-T<B`BO7._Z"(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O<F]W+FEN8SHR-2!T96UP;&%T97,O8G)O=W-E+V-O
M;G1A8W1R;W<N:6YC.C,S"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E
M<UPB(@IM<V=S='(@(KUSO^@@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z.#$*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G
M<W1R("*]<[_HLW&P5+_](@H*(SH@961I="YP:'`Z.#4@961I="YP:'`Z,38Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@96YT<GD@9F]R("5S(@IM<V=S
M='(@(KUSO^BP3[_]("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(KEQI&RV;*7S(@H*(SH@961I
M="YP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U
M<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B)7.JNK!/O_VD=Z?SMW,LIOW`>*9SI%>VQ\#)KM>NR:6B
ML=$Z)7,B"@HC.B!E9&ET+G!H<#HQ-38@961I="YP:'`Z,34Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+B(*;7-G<W1R("(E
M<R"JNK!/O_VD=Z?SMW,N(@H*(SH@8G)O=W-E+G!H<#HR,38@8G)O=W-E+G!H
M<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@861D:6YG("5D(&-O
M;G1A8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`BMW.\5R`E9""MT[-SM;BD2*CL
MN'.RU:2DKLFU;Z7-O_F[?BXB"@HC.B!B<F]W<V4N<&AP.C(Q."!B<F]W<V4N
M<&AP.C(V-@IM<V=I9"`B17)R;W(@861D:6YG("5D(&]F("5D(')E<75E<W1E
M9"!C;VYT86-T*',I('1O(&QI<W0N(@IM<V=S='(@(K=SO%>RQ"`E9""MTZ9`
M("5D(*W3LW.UN*1(J.RX<[+5I*2NR;5OI<V_^;M^+B(*"B,Z(&)R;W=S92YP
M:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@)60@
M8V]N=&%C="AS*2XB"FUS9W-T<B`BIU*PHR`E9""MT[-SM;BD2*[)M6^ES;_Y
MNWXN(@H*(SH@8G)O=W-E+G!H<#HX.`IM<V=I9"`B17)R;W(@9&5L971I;F<@
M)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W1S*',I+B(*;7-G<W1R("*G4K"C
MLL0@)60@K=.F0"`E9""MT[-SM;BD2*[)M6^ES;_YNWXN(@H*(SH@8G)O=W-E
M+G!H<#HV-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R96UO=FEN9R`E
M9"!C;VYT86-T*',I(&9R;VT@;&ES="XB"FUS9W-T<B`BIMNX<[+5I*2ROK"C
M("5D(*W3LW.UN*1(KLFU;Z7-O_F[?BXB"@HC.B!B<F]W<V4N<&AP.C8X"FUS
M9VED(")%<G)O<B!R96UO=FEN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C
M="AS*2!F<F]M(&QI<W0N(@IM<V=S='(@(J;;N'.RU:2DLKZPH[+$("5D(*W3
MID`@)60@K=.S<[6XI$BNR;5OI<V_^;M^+B(*"B,Z(&QI8B]A<&DN<&AP.C0Q
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96%R8VAI;F<@=&AE(&%D
M9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`BMVJT3;-QL%2__3H@)7,@I:*QT2(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3`@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(K;7
MI5@B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*;7-G:60@(D5X
M<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`BMM>E6+-QL%2__2(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY
M('1H92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`BI76VUZ58I'>_[ZCZ
MJKJS<[6XI$@N(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM
M<V=I9"`B17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L
M971E;'DN(@IM<V=S='(@(J>YON.VUZ58I%6F0[-QL%2__2XB"@HC.B!D871A
M+G!H<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!B<F]W<V4N<&AP
M.C,U(&)R;W=S92YP:'`Z,3`S"B,Z(&)R;W=S92YP:'`Z,3,P(&%D9"YP:'`Z
M-C<@<V5A<F-H+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(J9SJ/JS
M<;!4O_TZ("5S(*6BL=$N(@H*(SH@8G)O=W-E+G!H<#HQ-3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%D9"`E<R!T;R`E<SH@)7,B"FUS9W-T
M<B`BMW.\5R`E<R"H["`E<SH@)7,B"@HC.B!B<F]W<V4N<&AP.C,P-0IM<V=I
M9"`B1F%I;&5D('1O(&)R;W=S92!L:7-T(@IM<V=S='(@(L)SQ/VX<[+5I:*Q
MT2(*"B,Z(&)R;W=S92YP:'`Z,S0S"FUS9VED(")&86EL960@=&\@8G)O=W-E
M('1H92!D:7)E8W1O<GDB"FUS9W-T<B`BMVJT3:78O_VEHK'1(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HS,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@3F5W
M($1.(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R("+%W*?SIE>ZV:6BL=$Z*"5S
M*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T(#T@)7,B"@HC
M.B!B<F]W<V4N<&AP.C$S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S(@IM<V=S='(@(J?DM$VJ
MJZ7SI4BW<[Q7J.PZ)7.EHK'1(@H*(SH@<V5A<F-H+G!H<#HW.0IM<V=I9"`B
M1F%I;&5D('1O('-E87)C:"!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(K=J
MM$VS<;!4O_VEHK'1(@H*(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,B"FUS
M9W-T<B`BMVJT3:78O_TZ("5S(*6BL=$B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-C<*;7-G:60@(D9A>"(*;7-G<W1R("*VQZ]U(@H*(SH@
M961I="YP:'`Z,3,Q(&1I<W!L87DN<&AP.C$P,`IM<V=I9"`B1FEL97,B"FUS
M9W-T<B`BJOZE\R(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW
M,0IM<V=I9"`B1FEN9"(*;7-G<W1R("*T3:?D(@H*(SH@961I="YP:'`Z,3`T
M(&5D:70N<&AP.C$Y-`IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(J>YIJ@B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT.`IM<V=I9"`B1FER<W0@
M3F%M92(*;7-G<W1R("*F5Z9R(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B1G)E96)U
M<WD@NO2G?2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHX-`IM
M<V=I9"`B1G)O;2(*;7-G<W1R("*Q<2(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H
M<"YD:7-T.C8V-`IM<V=I9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R
M("*E_K#LLW&P5+_](@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C0S
M('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z-#0*;7-G:60@(D=R
M;W5P(@IM<V=S='(@(KASLM4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(J;MKF&F8:=]
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3,*;7-G:60@(DAO
M;64@0VET>2(*;7-G<W1R("*F[:YAJ=+$W:NPI:LB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,#@*;7-G:60@(DAO;64@0V]U;G1R>2(*;7-G
M<W1R("*F[:YAJ=+$W;#JKF$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BINVN8;EQN-PB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*;7-G:60@(DAO
M;64@4&]S=&%L($-O9&4B"FUS9W-T<B`BINVN8;9LN[RPS[BY(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3@*;7-G:60@(DAO;64@4W1A=&4O
M4')O=FEN8V4B"FUS9W-T<B`BINVN8:G2Q-VLV:7W(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z.#@*;7-G:60@(DAO;64@4W1R965T($%D9')E
M<W,B"FUS9W-T<B`BINVN8:;MIWTB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N
M9&ES=#HU-C8*;7-G:60@(DE-4U`B"FUS9W-T<B`B24U34"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-PIM<V=I9"`B24U34"!!9&1R97-S($)O;VL@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B24U34""S<;!4O_VZWK)Z(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C,X"FUS9VED("))9"(*;7-G
M<W1R("+#T:=/N+F]6"(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D<F5S<R!";V]K+"!3
M=&5P("5D(@IM<V=S='(@(K;7I$JS<;!4O_TL(*A"QDH@)60B"@HC.B!D871A
M+G!H<#HS-C$*;7-G:60@(DEM<&]R="]%>'!O<G0@061D<F5S<R!";V]K<R(*
M;7-G<W1R("*VUZ1*+[;7I5@@LW&P5+_](@H*(SH@;&EB+V%P:2YP:'`Z-C$T
M(&QI8B]A<&DN<&AP.C<P,0IM<V=I9"`B26YV86QI9"!)1"(*;7-G<W1R("*U
M3*[$JKJ]<[BY(@H*(SH@;&EB+V%P:2YP:'`Z,C,R(&QI8B]A<&DN<&AP.C0P
M-"!L:6(O87!I+G!H<#HT.#@@;&EB+V%P:2YP:'`Z-C$P"B,Z(&QI8B]A<&DN
M<&AP.C8Y-R!L:6(O87!I+G!H<#HW-#D@;&EB+V%P:2YP:'`Z,3`Y-0IM<V=I
M9"`B26YV86QI9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`BM4RNQ*JZLW&P5+_]
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.3D@;&EB+V%P:2YP:'`Z,3$W,B!L:6(O
M87!I+G!H<#HQ,C(U"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(K5,
MKL2JNKEQI&RF[:=]+B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#<*;7-G:60@(DEN
M=F%L:60@96YT<GDB"FUS9W-T<B`BM4RNQ*JZL$^__2(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,C8V"FUS9VED("));G9A;&ED(&ME>2!S<&5C:69I960N
M(@IM<V=S='(@(JO\J7>JNJKWQE^U3*[$(@H*(SH@;&EB+V%P:2YP:'`Z,3$P
M,PIM<V=I9"`B26YV86QI9"!N86UE(@IM<V=S='(@(K5,KL2JNJ97NMDB"@HC
M.B!L:6(O87!I+G!H<#HW-3,*;7-G:60@(DEN=F%L:60@;V)J96-T260B"FUS
M9W-T<B`BM4RNQ*JZI,"HR:JKI?,N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T
M:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D
M+B(*;7-G<W1R("*ELK:WK6ZFLR!,1$%0(*JZI.2TJ2RF_:Q/($Q$05`@O-*R
MU:2CK$^EO*9WN,NT3JQ/J%.FL[C\I$HN(@H*(SH@;&EB+T]B:F5C=%9I97<N
M<&AP.C$S.`IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("*SS*KQI$"F
MN*?SMW,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PIM<V=I
M9"`B3&%S="!.86UE(@IM<V=S='(@(JEM(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`B
MLDVSYB(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW.`IM<V=I
M9"`B36%T8VAI;F<B"FUS9W-T<B`BI,>P="(*"B,Z(&QI8B]A<&DN<&AP.C(P
M-PIM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B
MLW.UN*1(I%>MK;S&I=@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W
M"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!P86=E<R(*;7-G<W1R("*MMKS&
MI%>MK2(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C,*;7-G:60@(DUE
M;G4@3&ES="(*;7-G<W1R("*E7*_@JNTB"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$3B!I;B!,1$%0('-O=7)C92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("*GY*2CJ.P@3$1!4""S7:EWJ=*[W:UNJKH@
M1$X@K<@N(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"FUS
M9VED(")-;V)I;&4@4&AO;F4B"FUS9W-T<B`BIN:PRKEQN-PB"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM
M<V=S='(@(L7<I_.EHK'1.B`H)7,I("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3(Q
M,0IM<V=I9"`B36]R92!T:&%N(#$@96YT<GD@9F]U;F0B"FUS9W-T<B`BME>Y
M3"`Q(+6GL$^__;-1ML>F7B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,38*;7-G:60@(DUO=F4B"FUS9W-T<B`BMVBROB(*"B,Z('1E;7!L
M871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T-PHC.B!T96UP;&%T97,O
M<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X-`IM<V=I9"`B36]V92!L
M969T(@IM<V=S='(@(KW5JD`B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR-#D*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K
M<V5L96-T+FEN8SHQ.#8*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`BO=6M
ML"(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,38*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G<W1R(")-=6QB
M97)R>2"S<;!4O_TB"@HC.B!L:6(O87!I+G!H<#HQ,3,Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE
M<UTL(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS
M9W-T<B`B(@HBIF*S<;!4O_VDI*:SIFZT6*;LLW.UN*1(JKJV;*7SINVG?;.C
MK$\@6R5S72RF_;-OJ,>S<[6XI$BH4Z:SI$"MTZQ/I7.PM2!;)7-=("(*(JJZ
M+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$P-R!C;VYF:6<O<V]U
M<F-E<RYP:'`N9&ES=#HS,#$*;7-G:60@(DUY($%D9')E<W,@0F]O:R(*;7-G
M<W1R("*GVJJZLW&P5+_](@H*(SH@861D<F5S<V)O;VMS+G!H<#HQ,3D*;7-G
M:60@(DUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`BI]JJNK-QL%2__2(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HT,@IM<V=I9"`B3F%M92(*;7-G<W1R("*F5[K9(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED(").86UE($9O<FUA
M="(*;7-G<W1R("*F5[K9KN:FH2(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C,W,PIM<V=I9"`B3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS
M9W-T<B`B3F5T<V-A<&4@MWRM^Z78O_TB"@HC.B!A9&0N<&AP.C,V(&%D9"YP
M:'`Z,3(T(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(W"FUS9VED(").97<@
M0V]N=&%C="(*;7-G<W1R("*W<[Q7LW.UN*1((@H*(SH@961I="YP:'`Z.34@
M961I="YP:'`Z,3`R(&5D:70N<&AP.C(P.2!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@(J15I$"H0B(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q.`IM<V=I9"`B3FEC:VYA;64B
M"FUS9W-T<B`BO,JZV2(*"B,Z(&QI8B]A<&DN<&AP.C$R,3,@;&EB+V%P:2YP
M:'`Z,3(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E;G1R>2!F;W5N
M9"!F;W(@)7,B"FUS9W-T<B`BI^2DHZCL("4R)',@JKH@)3$D<R"P3[_](@H*
M(SH@;&EB+V%P:2YP:'`Z,3$X,0IM<V=I9"`B3F\@861D<F5S<R!B;V]K<R!F
M;W5N9"XB"FUS9W-T<B`BI^2DHZCLLW&P5+_]+B(*"B,Z(&UI;FES96%R8V@N
M<&AP.C@Q"FUS9VED(").;R!C;VYT86-T<R!F;W5N9"(*;7-G<W1R("*GY*2C
MJ.RS<[6XI$@B"@HC.B!L:6(O87!I+G!H<#HU,3,@;&EB+V%P:2YP:'`Z-S@T
M"FUS9VED(").;R!V0V%R9"!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`BI^2D
MHZCL('9#87)D(+CJKL8N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N
M:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`BM4PB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM<V=S='(@(K/&
MM?DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(").=6UB
M97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T<B`BJ$.MMKS&I=@B"@HC.B!L
M:6(O87!I+G!H<#HV,S(@;&EB+V%P:2YP:'`Z-S8U"FUS9VED(")/8FIE8W0@
M;F]T(&9O=6YD(@IM<V=S='(@(J?DI*.H[*JKI?,B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HR,C,*;7-G:60@(D]F9FEC92(*;7-G<W1R("*_
M[*2]J\<B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(R"FUS
M9VED("(B"B)/;F-E('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H92!A
M9&1R97-S(&)O;VL@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B!)
M9B!T:&ES(&ES(&YO="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T(&-H
M86YG92!Y;W5R('-E;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z-SDR"FUS9VED(")/;FQY(&]N92!V8V%R9"!S
M=7!P;W)T960N(@IM<V=S='(@(K;(I.2TJ;/FI$!60T%21"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V
M"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(JCDI4R_[[:U(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DP"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R(")01U`@I+VV?:KWQE\B"@HC.B!L:6(O87!I+G!H
M<#HT.3<@;&EB+V%P:2YP:'`Z-C(S(&QI8B]A<&DN<&AP.C<Q,"!L:6(O87!I
M+G!H<#HY-3(*(SH@;&EB+V%P:2YP:'`Z,3$Q-@IM<V=I9"`B4&5R;6ES<VEO
M;B!$96YI960B"FUS9W-T<B`BIG.H^KY$J=HB"@HC.B!L:6(O1')I=F5R+G!H
M<#HU-3`*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(J9SJ/J^
M1*G:(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3D*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(L5VK:TB"@HC.B!D871A+G!H<#HU,R!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")0:6YE($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")0:6YE(+-QL%2__2(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE('1H
M92!N97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R("*]T+_II$JW<[ASLM6JNJ97
MNMDZ(@H*(SH@961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D:70N<&AP.C(P
M,0IM<V=I9"`B4')E=FEO=7,B"FUS9W-T<B`BI%>D0+%I(@H*(SH@8V]N9FEG
M+W-O=7)C97,N<&AP+F1I<W0Z-#<T"FUS9VED(")0<FEV871E($%D9')E<W,@
M0F]O:R(*;7-G<W1R("*H<*1(LW&P5+_](@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475E<GD@9F%I;&5D.B`H
M)7,I("5S(@IM<V=S='(@(JQDN-^EHK'1.B`H)7,I("5S(@H*(SH@=&5M<&QA
M=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"FUS9VED(")1=6EC:R!396%R
M8V@B"FUS9W-T<B`BI]:S=+=JM$TB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C$Y,2!L:6(O1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD87`N
M<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")296%D(&9A:6QE9#H@*"5S
M*2`E<R(*;7-G<W1R("+%JJCZI:*QT3H@*"5S*2`E<R(*"B,Z(&QI8B]$<FEV
M97(O;G5L;"YP:'`Z-3(*;7-G:60@(E)E861I;F<@8V]N=&%C=',@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`BJ=+%JJCZJKJS<[6XI$BU3*[$+B(*"B,Z
M(&QI8B]296YD97)E<BYP:'`Z-#D*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI
M<R!C;VYT86-T/R(*;7-G<W1R("*]5*EWIU*PHZ:YLW.UN*1(/R(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S(&1I
M<W!L87EE9#HB"FUS9W-T<B`BI'?%XZ7<L$^__3HB"@HC.B!T96UP;&%T97,O
M<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-@IM<V=I9"`B4F5M;W9E
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("*ROK"CLW&P5+_](@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,Y"FUS9VED(")296UO=F4@
M8V]L=6UN(@IM<V=S='(@(K*^L*/$YJ;L(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHS"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B
M"FUS9W-T<B`BL7&S;ZW3N'.RU:2DLKZPHR(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,C$*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@861D
M<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N
M:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R
M96YT(&%D9')E<W,@8F]O:RX\+W-T<F]N9SXB"FUS9W-T<B`B(@HBI4BVUZ1*
MJKJS<;!4O_VX;;2KIG.F8JJZLW&P5+_](#\@/'-T<F]N9S[$M:=I.B"S;[%.
MMWRG4K"CI=BK9;-QL%2__:2DJKJITJ:SK/8B"B*__2X\+W-T<F]N9SXB"@HC
M.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@
M;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.RITKO=JKJJJZ7S+B(*"B,Z(&%D
M9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q-`IM<V=I
M9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`BK:NS7:9>I+JI=ZW((@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DV"FUS9VED(")3+TU)
M344@4'5B;&EC($-E<G1I9FEC871E(@IM<V=S='(@(E,O34E-12"DO;9]OLS#
MTB(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4U1!4E143%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(E-405)4
M5$Q3(*6BL=$Z("@E<RD@)7,B"@HC.B!E9&ET+G!H<#HQ,#8@861D+G!H<#HS
M-R!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,C0*;7-G:60@(E-A=F4B
M"FUS9W-T<B`BP'BF<R(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-C<*;7-G
M:60@(E-A=FEN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("*ITL!XIG.JNK-SM;BD2+5,KL0N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.CDW('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*
M(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(Q(&QI8B]";&]C
M:R]T<F5E7VUE;G4N<&AP.C0Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C8*;7-G:60@(E-E87)C:"(*;7-G<W1R("*W:K1-(@H*(SH@;&EB+V%P:2YP
M:'`Z,3`R.0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R("*W:K1-I:*Q
MT2(*"B,Z(&QI8B]A<&DN<&AP.C$Q,C$@;&EB+V%P:2YP:'`Z,3$R-R!L:6(O
M87!I+G!H<#HQ,3,V(&QI8B]A<&DN<&AP.C$Q-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T<B`BMVJT3:6BL=$Z("5S
M(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HT-PIM<V=I9"`B4V5A<F-H:6YG
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(K=JM$VE7*_@M4RNQ"XB"@HC
M.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C(*;7-G:60@(E-E
M87)C:&EN9RXN+B(*;7-G<W1R("*W:K1-I*0N+BXB"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHV-@IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@
M8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`BO^^^W*UNIU*PHZJZI$"EN[-QL%2_
M_2(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDP"FUS9VED(")3
M96QE8W0@86X@861D<F5S<R!B;V]K('1O(&5D:70B"FUS9W-T<B`BO^^^W*UN
MO7._Z*JZI$"EN[-QL%2__2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,S(*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R
M="!F<F]M.B(*;7-G<W1R("*_[[[<K6ZVUZ58JKJS<;!4O_TZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR-@IM<V=I9"`B4V5L96-T('1H92!A
M9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.B(*;7-G<W1R("*_[[[<K6ZVUZ1*
MJKJS<;!4O_TZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0IM
M<V=I9"`B4V5L96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB
M"FUS9W-T<B`BO^^^W*C3M[W`R:[7JKJF<J2XO7.]6*[FIJ$Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,`IM<V=I9"`B4V5L96-T('1H92!E
M>'!O<G0@9F]R;6%T.B(*;7-G<W1R("*_[[[<MM>E6*[FIJ$Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L96-T('1H92!F
M:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`BO^^^W,#)KM>E2+;7I$HZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0IM<V=I9"`B4V5L96-T('1H
M92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("*_[[[<J-.W
MO<#)KM>JNJ[FIJ$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM
M<V=I9"`B4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA;65S
M.B(*;7-G<W1R("*_[[[<I<ZHT\7CI=RF5[K9JKJNYJ:A.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES
M<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T
M:6]N<RXB"FUS9W-T<B`BO^^H^KEWLUVJNL#+M?BDZ*:A++'&I\>DZ*96+*5(
MI,ZMMJVQO^^VM2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G
M:60@(E-E;&5C="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D
M<F5S<R!L:7-T<RXB"FUS9W-T<B`BO^^H^J7.I4C%XZ7<JKJS<;!4O_W$YJ;L
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L96-T
M('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R("*_[[[<
MI<ZHT\7CI=RF5[K9JKJNYJ:A+B(*"B,Z(&%D9"YP:'`Z-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K(%PB)7-<(BXB"FUS
M9W-T<B`BI'>_[[[<JKJS<;!4O_T@7"(E<UPB+B(*"B,Z(&-O;F9I9R]S;W5R
M8V5S+G!H<"YD:7-T.C(S,0IM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G
M<W1R("*F0*C)I=B__2(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R`E<R(*;7-G<W1R("+%
MXZ7<("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT.`IM
M<V=I9"`B4VAO=R!!;&PB"FUS9W-T<B`BQ>.EW*7^LZ$B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0W"FUS9VED(")3:&]W($-O;G1A8W1S
M(@IM<V=S='(@(L7CI=RS<[6XI$@B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C0V"FUS9VED(")3:&]W($QI<W1S(@IM<V=S='(@(L7CI=RX
M<[+5(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z
M,C$*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,S8*
M;7-G:60@(E-O<G0@1&ER96-T:6]N(@IM<V=S='(@(K'&I\>DZ*96(@H*(SH@
M;&EB+V%P:2YP:'`Z,C`P"FUS9VED(")3;W5R8V5S(@IM<V=S='(@(JC3M[TB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")3<&5C:69Y
M('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P
M<&5A<BXB"FUS9W-T<B`BJ_RI^JUNL4ZV:;:EMVJT3:JZM;*J1ZGQIF*M_KC,
M+B(*"B,Z(&)R;W=S92YP:'`Z,C$T(&)R;W=S92YP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E9"!C;VYT86-T*',I
M('1O(&QI<W0N(@IM<V=S='(@(J1WIJBE7*9AI5ND2B`E9""MT[-SM;BD2*CL
MN'.RU:2D+B(*"B,Z(&)R;W=S92YP:'`Z,38P"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<R(*;7-G<W1R("(E<R"D
M=Z:HI5RF8:5;I$JH["`E<R"H=++.I*0N(@H*(SH@8G)O=W-E+G!H<#HR-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-R96%T960@=&AE
M(&-O;G1A8W0@;&ES="!<(B5S7"(N(@IM<V=S='(@(J1WIJBE7*JZJ]BEW[AS
MLM4@7"(E<UPB+B(*"B,Z(&)R;W=S92YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@)60@8V]N=&%C="AS*2XB"FUS
M9W-T<B`B)60@K=.S<[6XI$BD=Z=2L*.GN::H+B(*"B,Z(&)R;W=S92YP:'`Z
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@
M)60@8V]N=&%C="AS*2!F<F]M(&QI<W0N(@IM<V=S='(@(J1WIJBE7*9AL7&X
M<[+5LKZPHR`E9""MT[-SM;BD2"XB"@HC.B!D871A+G!H<#HU,`IM<V=I9"`B
M5%-6(@IM<V=S='(@(E1A8B"DP+EJKN:FH2(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-`IM
M<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B5&%B(*3`N6JM
MR"`H*BYT<W8I(@H*(SH@=FEE=RYP:'`Z,34*;7-G:60@(E1H92!61E,@8F%C
M:V5N9"!N965D<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM
M96YT('5P;&]A9',N(@IM<V=S='(@(JUNL=*ESJK^I?.D5[;'I5ROX*ME++7J
MP,#`R:[7J'2RSBA61E,IIOBJ0;K=I;*VM[-=J7>GN::H+B(*"B,Z(&QI8B]$
M<FEV97(N<&AP.C$P-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E
M<W,@8F]O:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(K-QL%2_
M_2!<(B5S7"(@I*.F<Z9B+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S
M(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("*S<;!4O_T@7"(E<UPB
M(*O8I=^GN::H+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(')E;6]V
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("*S<;!4O_T@7"(E<UPB(+*^L*.G
MN::H+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!U<&1A=&5D+B(*;7-G<W1R("*S<;!4O_T@7"(E<UPB(*?SMW.GN::H+B(*
M"B,Z(&1A=&$N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D
M<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(J:Y
MLW&P5+_]M4RJ:[-1LDVJQ3H@)7,B"@HC.B!E9&ET+G!H<#HU,2!V8V%R9"YP
M:'`Z,C(@9&ES<&QA>2YP:'`Z,C,@=FEE=RYP:'`Z,C8*;7-G:60@(E1H92!C
M;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(KC3LW.UN*1(I*.F<Z9B+B(*"B,Z(&5D:70N<&AP.C$R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92!<(B5S7"(@:&%S('-U8V-E<W-F=6QL>2!B
M965N(&1E;&5T960N(@IM<V=S='(@(L#)KM<@7"(E<UPB(*1WIU*PHZ>YIJ@N
M(@H*(SH@9&%T82YP:'`Z,C@T"FUS9VED(")4:&4@:6UP;W)T(&-A;B!B92!F
M:6YI<VAE9"!D97-P:71E('1H92!W87)N:6YG<RXB"FUS9W-T<B`BOJBZWJ:S
MQ+6G:;!4KJ>F_:2TM4VE::5(I[FFJ+CJKL:JNK;7I$HN(@H*(SH@8G)O=W-E
M+G!H<#HS,0IM<V=I9"`B5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S
M<R!B;V]K<RXB"FUS9W-T<B`BM4RE::C1PG/$_:JZLW&P5+_]+B(*"B,Z(&%D
M9"YP:'`Z,CD*;7-G:60@(B(*(E1H97)E(&%R92!N;R!W<FET96%B;&4@861D
M<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@879A:6QA8FQE(&%D9')E<W,@8F]O
M:W,@(@HB87)E(&-O;F9I9W5R960@=&\@86QL;W<@>6]U('1O(&%D9"!N97<@
M96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES("(*(FES(&%N
M(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"B*U3*5II<ZHT[=SO%>P3[_]JKJS<;!4O_VE::7.
M+J9PJD>G0;M[K+"S;ZG.LURL3ZW3O_F[?BR]T,%PM;BG0:JZJ'2RSKK>LGJM
M^RXB"@HC.B!A9&0N<&AP.C$R,0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T
M96T@861M:6YI<W1R871O<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("*W<[Q7LW.UN*1(KLFU;Z7-I$"MT[_YNWXNO=#!<+6XIT&JNJATLLZZWK)Z
MK?NE2*CSIU6S0K)Z+B(*"B,Z(&)R;W=S92YP:'`Z,C<Q"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="XB"FUS9W-T<B`B
MJ]BEW[=SN'.RU:[)M6^ES;_YNWXN(@H*(SH@861D<F5S<V)O;VMS+G!H<#HS
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E
M871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(JO8I=^S<;!4
MO_TZ("5S(*[)M6^ES:1`K=._^;M^+B(*"B,Z(&)R;W=S92YP:'`Z,38V"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!<(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`BIMNHT[>]LW&P5+_]I*2G4K"C(%PB)7-<(B"NR;5OI<VD0*W3O_F[?BXB
M"@HC.B!D96QE=&4N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S(@IM<V=S
M='(@(J=2L*.S<[6XI$@Z("5S(*[)M6^ES:1`K=._^;M^+B(*"B,Z(&)R;W=S
M92YP:'`Z,S$Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&4@;&ES="(*;7-G<W1R("+%XZ7<N'.RU:[)M6^ES:1`K=._^;M^(@H*
M(SH@9&%T82YP:'`Z,S,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(K;7
MI$JXZJ[&.B5S(*[)M6^ES:1`K=._^;M^(@H*(SH@;&EB+V%P:2YP:'`Z-3`Y
M(&QI8B]A<&DN<&AP.C<W.0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(K;7I$H@:4-A
M;&5N9&%R(+CJKL:NR;5OI<VD0*W3O_F[?BXB"@HC.B!A9&1R97-S8F]O:W,N
M<&AP.C4X(&%D9')E<W-B;V]K<RYP:'`Z-C,@861D<F5S<V)O;VMS+G!H<#HV
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M
M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(K*^L*.S<;!4
MO_TZ("5S(*[)M6^ES:1`K=._^;M^(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(J?SMW.S<;!4
MO_TZ("5S(*[)M6^ES:1`K=._^;M^(@H*(SH@961I="YP:'`Z,38U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&ES(&5N=')Y.B`E<R(*;7-G<W1R("*G\[=SLV^UI[CJKL8Z("5S(*[)M6^E
MS:1`K=._^;M^(@H*(SH@9&%T82YP:'`Z,3<Y"FUS9VED(")4:&5R92!W97)E
M(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N(@IM<V=S='(@(K5,LW&P5+_]N.JN
MQJ5IJ-&VUZ58LW&P5+_]+B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S
M8F]O:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R97-S(&)O;VMS
M('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("*S<;!4O_W%
MXZ7<MK:GQZ9PI%4Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C
M="YI;F,Z,C0S"FUS9VED(")4:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA>2!I
M;B!T:&ES(&]R9&5R.B(*;7-G<W1R("+$YJ;LIE>ZV<7CI=RVMJ?'IG"D53HB
M"@HC.B!D871A+G!H<#HR-CD*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BIKFZV,#)KM>NYJ:AJ,.EO+-1I.2T
MJ2XB"@HC.B!L:6(O87!I+G!H<#HQ,30P(&QI8B]A<&DN<&AP.C$Q-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E
M<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(K-OK=.D2*JZ
M("5S(+!/O_VD=Z9SIF*I\[-QL%2__:2D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#@*;7-G:60@(B(*(E1H:7,@=VEL;"!B92!T:&4@9&5F875L
M="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG(&-O;G1A
M8W1S+B(*;7-G<W1R("*W<[Q7J<ZVUZ1*LW.UN*1(JKJY=[-=LW&P5+_]+B(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<P"FUS9VED(")4:71L
M92(*;7-G<W1R("*ZV;_7(@H*(SH@;&EB+U1U<F)A+G!H<#HT-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N($UI
M<W-I;F<@<V]U<F-E('1Y<&4N(@IM<V=S='(@(K5,JFNKV*7?MW.JNJ9`J,DN
M(*_*I-:HT[>]JZRZ02XB"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#`P"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N
M(&]F("5S+B(*;7-G<W1R("*U3*IKN/RD2B`E<R"JNJEWN'&XZJ[&+B(*"B,Z
M(&5D:70N<&AP.CDU(&5D:70N<&AP.CDX(&5D:70N<&AP.C$P,2!E9&ET+G!H
M<#HQ,#8@961I="YP:'`Z,C`S"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T
M<B`BJ^RT7\7<I_,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR
M,C@*;7-G:60@(E5N:70B"FUS9W-T<B`BO=*KQR(*"B,Z(&QI8B]A<&DN<&AP
M.C4T,B!L:6(O87!I+G!H<#HV-C$@;&EB+V%P:2YP:'`Z-SDW"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS
M9W-T<B`BI;RDY+2IJKJDNJYEJZRZ03H@)7,B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HR,S,*;7-G:60@(E5R;"(*;7-G<W1R("*Z]*=](@H*
M(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-#,T"FUS9VED(")697)I<VEG
M;B!$:7)E8W1O<GDB"FUS9W-T<B`B5F5R:7-I9VX@I=B__2(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB
M(@IM<V=S='(@(L#+M?@@7"(E<UPB(@H*(SH@;6EN:7-E87)C:"YP:'`Z-S8*
M;7-G:60@(E9I97<@0V]N=&%C="(*;7-G<W1R("+`R[7XLW.UN*1((@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE=R!T;R!D:7-P
M;&%Y(&)Y(&1E9F%U;'0Z(@IM<V=S='(@(KEWLUW`R[7X.B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB
M"FUS9W-T<B`BNO2G?2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$Q,PIM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(K_LI+VKQZ9AIWTB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O
M<FL@0VET>2(*;7-G<W1R("*_[*2]J\>ITL3=J["EJR(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$S.0IM<V=I9"`B5V]R:R!#;W5N=')Y(@IM
M<V=S='(@(K_LI+VKQZG2Q-VPZJYA(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,34V"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(K_LI+VK
MQ[EQN-PB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,S0*;7-G
M:60@(E=O<FL@4&]S=&%L($-O9&4B"FUS9W-T<B`BO^RDO:O'MFR[O+#/N+DB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*;7-G:60@(E=O
M<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`BO^RDO:O'J=+$W:S9I?<B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3D*;7-G:60@(E=O<FL@
M4W1R965T($%D9')E<W,B"FUS9W-T<B`BO^RDO:O'INVG?2(*"B,Z(&1A=&$N
M<&AP.C(S-R!B<F]W<V4N<&AP.C$P-B!B<F]W<V4N<&AP.C(R-R!A9&0N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM
M<V=S='(@(J2CI+FS7*=!IF(@7"(E,B1S7"(@I*2KV*7?("4Q)&0@K=.E2*17
MJKJS<[6XI$@N(@H*(SH@961I="YP:'`Z-S,@9&ES<&QA>2YP:'`Z-3@@=FEE
M=RYP:'`Z,S8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R("*G0:A3IK/`R[7XLV^MT[-S
MM;BD2*JZQ7:MK2XB"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N(@IM<V=S
M='(@(J=!J%.FL\#+M?BFN:JKI?.JNL5VK:TN(@H*(SH@;&EB+U1U<F)A+G!H
M<#HU,S<*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N<R!T;R!D
M96QE=&4@=&AI<R!S;W5R8V4N(@IM<V=S='(@(J=!J%.FLZ=2L*.FN:C3M[VJ
MNL5VK:TN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHU
M-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`BIT&ELK:WI?V_[[[<I$"MTZ78IF&S<;!4O_TN(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHR,PIM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N(@IM<V=S='(@(J=!I;*VM[_O
MOMRD0*W3I=BF8;ASLM4N(@H*(SH@961I="YP:'`Z,S(*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T
M<B`BIT&ELK:WO^^^W*;<I-:D0*W3LW.UN*1(+B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]J879A
M<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N
M:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&5N
M=')Y(&9I<G-T+B(*;7-G<W1R("*MNJ7]+*=!I;*VMZ;<I-:_[[[<I$"UI[CJ
MKL8N(@H*(SH@961I="YP:'`Z-S<*;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R
M;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB"FUS9W-T<B`BIT&E=::S
MP,NU^+-OK=.S<[6XI$BJNL5VK:TN(@H*(SH@8G)O=W-E+G!H<#HS,3@*;7-G
M:60@(EEO=7(@9&5F875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B
M;&4N(@IM<V=S='(@(J=!JKJY=[-=LW&P5+_]I*.E:<)SQ/TN(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C8@=&5M<&QA=&5S+V)R;W=S92]C;VYT
M86-T<F]W+FEN8SHQ,@IM<V=I9"`B6VYO('9A;'5E72(*;7-G<W1R(");JL6E
MU5TB"@HC.B!L:6(O5'5R8F$N<&AP.C4V,`IM<V=I9"`B7T)R;W=S92(*;7-G
M<W1R("+"<\3]7T(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C0W"FUS9VED(")?0V]N=&%C=',B"FUS9W-T<B`BLW.UN*1(7T,B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*;7-G:60@(E]$96QE=&4B
M"FUS9W-T<B`BIU*PHU]$(@H*(SH@;&EB+U1U<F)A+G!H<#HU-CD*;7-G:60@
M(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(K;7I$HOMM>E6%])(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-@IM<V=I9"`B7TQI<W1S(@IM
M<V=S='(@(KASLM5?3"(*"B,Z(&QI8B]4=7)B82YP:'`Z-34W"FUS9VED(")?
M37D@061D<F5S<R!";V]K<R(*;7-G<W1R("*GVJJZLW&P5+_]7TTB"@HC.B!L
M:6(O5'5R8F$N<&AP.C4V,PIM<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S='(@
M(K=SO%>S<[6XI$A?3B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z,PIM<V=I9"`B7U)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R("*Q
M<;-OK=.X<[+5I*2ROK"C7U(B"@HC.B!L:6(O5'5R8F$N<&AP.C4V-0IM<V=I
M9"`B7U-E87)C:"(*;7-G<W1R("*W:K1-7U,B"@HC.B!V8V%R9"YP:'`Z-#8*
M;7-G:60@(F-O;G1A8W0N=F-F(@IM<V=S='(@(K-QL%2__2YV8V8B"@HC.B!D
M871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(K-QL%2__2YC
M<W8B"@HC.B!D871A+G!H<#HR,#D*;7-G:60@(F-O;G1A8W1S+G1S=B(*;7-G
M<W1R("*S<;!4O_TN='-V(@H*(SH@9&%T82YP:'`Z,C$Y"FUS9VED(")C;VYT
M86-T<RYV8V8B"FUS9W-T<B`B8V]N=&%C=',N=F-F(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S.`IM<V=I9"`B;F\@9F]R;6%T=&EN9R(*;7-G<W1R
M("*U3"(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S(*;7-G
M:60@(FYO;F4B"FUS9W-T<B`BJ%.FLR(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z,S$*;7-G:60@(G1O(&$@0V]N=&%C="!,:7-T(@IM<V=S
M='(@(JCLN'.RU2(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,C$*;7-G:60@(G1O(&$@9&EF9F5R96YT($%D9')E<W,@0F]O:R(*;7-G<W1R
M("*H[*CDI4RJNK-QL%2__2(*"B,Z(&1A=&$N<&AP.C4Q('1E;7!L871E<R]B
M<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$S"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,34@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+VAU7TA5+G!O
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#0S
M,#,`,3`T,3<S-C(W-38`,#$W-3,P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@5'5R8F$@2'5N9V%R:6%N('1R86YS;&%T
M:6]N(&9I;&4N"B,@0V]P>7)I9VAT("A#*2`R,#`R+3(P,#8@3&%S>FQO($PN
M(%1O<FYO8VD*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@5'5R8F$@<&%C:V%G92X*(R!,871E<W0@
M=F5R<VEO;G,Z(&9T<#HO+WAE;FEA+G-O=&4N:'4O<'5B+VQI;G5X+VAO<F1E
M+PHC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!4
M=7)B82`R+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ-R`Q
M,#HP,"LP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$X(#$S
M.C$T*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@3&%S>FQO($PN(%1O<FYO
M8VD@/'1O<FQA<WI`>&5N:6$N<V]T92YH=3Y<;B(*(DQA;F=U86=E+51E86TZ
M($AU;F=A<FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E
M<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/6ES;RTX.#4Y+3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:71<;B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z-#`*
M;7-G:60@(B!!9&0@86X@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`B($E-
M4U`@8^UM:F5G>7KI:R!LZ71R96AO>N%S82(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I;7-P7V]P="YI;F,Z,CD*;7-G:60@(B!$96QE=&4@24U34"!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B($E-4U`@8^UM:F5G>7KI:R!T]G)LZ7-E(@H*(SH@
M9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!A;')E
M861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I;7!O<G1E9"XB"FUS9W-T<B`B7"(E
M<UPB(&WA<B!LZ71E>FEK+"!A>B!I;7!O<G3A;.%S(&YE;2!T]G)TZ6YT(&UE
M9RXB"@HC.B!B<F]W<V4N<&AP.C$T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM
M<V=S='(@(DUI=F5L(%PB)7-<(B!E9WD@;&ES=&$L(&5ZZ7)T(&YE;2!MX7-O
M;'1U:R#A="XB"@HC.B!B<F]W<V4N<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&YO="!M;W9E9"!B96-A=7-E(&ET(&ES(&$@;&ES
M="XB"FUS9W-T<B`B36EV96P@7"(E<UPB(&5G>2!L:7-T82P@97KI<G0@;F5M
M(&AE;'EE>G3\:R#A="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,W
M"FUS9VED(")<(D9I<G-T;F%M92!,87-T;F%M95PB("`H:64N($IO:&X@1&]E
M*2(*;7-G<W1R(")<(DME<F5S>G1NZ78@5F5Z973I:V[I=EPB("`H<&PN($KA
M;F]S($MO=N%C<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS
M9VED(")<(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H:64N($1O92P@2F]H;BDB
M"FUS9W-T<B`B7")697IE=.EK;NEV+"!+97)E<WIT;NEV7"(@("AP;"X@2V]V
MX6-S+"!*X6YO<RDB"@HC.B!A9&0N<&AP.C$P.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B)7,@8F5V:71E;&4@;65G=/9R=.EN
M="XB"@HC.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B02`E<R!FX6IL
M(&EM<&]R=.%LX7-A('-I:V5R97-E;B!M96=T]G)TZ6YT(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@+2`E<R`H]G-S>F5S96X@)7,I
M(@H*(SH@;&EB+U1U<F)A+G!H<#HT-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B)7,@8^UM:F5G>7KI:V4B"@HC
M.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#(*;7-G:60@(D$@8G)O=W-E
M<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B"FUS9W-T<B`B
M16AH97H@:49R86UE(&9U;FMC:6]N86QI=.%S<V%L(')E;F1E;&ME>O4@8O9N
M9^ES>O5P<F]G<F%M('-Z_&MSZ6=E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,38P"FUS9VED(")!8F]V92!S96%R8V@@9F]R;2(*;7-G<W1R(")A
M(&ME<F5S]69O<FT@9O9L]G1T(@H*(SH@=FEE=RYP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R("(E<R!E
M;.ERZ7/I:&5Z(&YE;2!R96YD96QK97II:R!M96=F96QE;/4@:F]G;W-U;'1S
MX6=G86PN(@H*(SH@861D+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C(Y"FUS9VED(")!9&0B"FUS9W-T<B`B0F5V:71E;"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<T"FUS9VED
M(")!9&0@861D<F5S<R!B;V]K(@IM<V=S='(@(MIJ(&/M;6IE9WEZZ6LB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@*;7-G:60@(D%D9"!A;F0@1&5L
M971E($E-4U`@861D<F5S<R!B;V]K<R(*;7-G<W1R("))35-0(&/M;6IE9WEZ
MZ6ME:R!LZ71R96AO>N%S82P@=/9R;.ES92(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M;B(*;7-G
M<W1R("+Z:B!O<WIL;W`B"@HC.B!E9&ET+G!H<#HQ,S4*;7-G:60@(D%D9"!F
M:6QE(@IM<V=S='(@(D;A:FP@:&]Z>N%A9.%S82(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"!T;R(*;7-G<W1R(")!
M9&IU:R!H;WIZX2(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-3<*;7-G:60@
M(D%D9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!
M(&/M;6IE9WEZZ6L@;F5M(&+U=NUT:&5T]2XB"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHX-@IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@
M(D/M;6IE9WEZZ6LB"@HC.B!B<F]W<V4N<&AP.C(X(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C4*;7-G:60@(D%D9')E<W,@0F]O:R!,:7-T:6YG(@IM<V=S
M='(@(D/M;6IE9WEZZ6L@;&ES=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B0^UM:F5G>7KI
M:V5K(@H*(SH@861D+G!H<#HQ,#@*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R
M>2(*;7-G<W1R(")#[6UJ96=Y>NEK(&%D870B"@HC.B!D871A+G!H<#HS,#4*
M;7-G:60@(D%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+B(*;7-G
M<W1R(")!(&/M;6IE9WEZZ6ME="!S:6ME<F5S96X@=/9R]FQT_&LN(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C(*;7-G:60@(D%D9')E<W,@
M8F]O:R!T;R!D96QE=&4@(@IM<V=S='(@(D$@=/9R;&5N9/4@8^UM:F5G>7KI
M:R`B"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC
M.C$W,`IM<V=I9"`B061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I
M<W!L87EE9#HB"FUS9W-T<B`B3F5M(&UE9VIE;&5N]2!C[6UJ96=Y>NEK96LZ
M(@H*(SH@<V5A<F-H+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI
M;F,Z,S@*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R(")2Z7-Z;&5T
M97,@:V5R97/I<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C8T
M"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT.`IM<V=I9"`B06QL(@IM<V=S='(@(F%Z(/9S<WIE<V5T(@H*(SH@;&EB
M+V%P:2YP:'`Z-34T"FUS9VED(")!;')E861Y($5X:7-T<R(*;7-G<W1R(")-
MX7(@;.ET97II:R(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI
M;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('1H870@
M>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R(")":7IT;W,L(&AO9WD@
M=/9R]FQN:2!K[7;A;FIA("5S+70_(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J
M879A<V-R:7!T+FEN8SHV-PIM<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U
M('=A;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/R(*;7-G<W1R
M(")":7IT;W,@86)B86XL(&AO9WD@=/9R]FQN:2!K[7;A;FIA(&5Z96ME="!A
M>B!A9&%T;VMA=#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*;7-G
M:60@(D%S8V5N9&EN9R(*;7-G<W1R(")N]G9E:W;U(@H*(SH@<V5A<F-H+G!H
M<#HX-2!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S<*;7-G:60@(D)A
M<VEC(%-E87)C:"(*;7-G<W1R(")+97)E<^ES(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U.0IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O<FTB"FUS9W-T
M<B`B82!K97)E<_5F;W)M(&%L871T(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HW-R!L:6(O1')I=F5R+VQD87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D$@:V%P8W-O;&%T
M(&9E;';I=&5L92!N96T@<VEK97+\;'0Z("@E<RD@)7,B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D)I<G1H9&%Y(@IM<V=S
M='(@(E-Z_&QE=.ES;F%P(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*;7-G
M:60@(D)R;W=S92(*;7-G<W1R(")"]FYGZ7-ZZ7,B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)U<VEN97-S($-A=&5G;W)Y
M(@IM<V=S='(@(MQZ;&5T:2!K871E9_-R:6$B"@HC.B!D871A+G!H<#HT.0IM
M<V=I9"`B0U-6(@IM<V=S='(@(D-35B(*"B,Z(&QI8B]/8FIE8W0O1W)O=7`N
M<&AP.C4W"FUS9VED(")#86XG="!A9&0@82!G<F]U<"!T;R!I='-E;&8N(@IM
M<V=S='(@(D5G>2!C<V]P;W)T(&YE;2!L96AE="#V;FUA9V$@=&%G:F$N(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I
M9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(DIE;/9L:OQK(&MI(&UI;F0O
M96=Y:6ME="!S96TB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHT
M-`IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G<W1R(")6X6QA<W-Z;VX@96=Y
M(&5L;F5V97KI<W0B"@HC.B!A9&0N<&AP.C0X"FUS9VED(")#:&]O<V4@86X@
M861D<F5S<R!B;V]K(@IM<V=S='(@(E;A;&%S<WIO;B!E9WD@8^UM:F5G>7KI
M:V5T(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C(Q
M"FUS9VED(")#:&]O<V4@86X@861D<F5S<R!B;V]K.B(*;7-G<W1R(")6X6QA
M<W-Z;VX@96=Y(&/M;6IE9WEZZ6ME=#HB"@HC.B!T96UP;&%T97,O<')E9G,O
M861D<F5S<V)O;VMS96QE8W0N:6YC.C$V-0IM<V=I9"`B0VAO;W-E('=H:6-H
M(&%D9')E<W,@8F]O:W,@=&\@9&ES<&QA>2P@86YD(&EN('=H870@;W)D97(Z
M(@IM<V=S='(@(B(*(E;A;&%S<WIA(&MI+"!H;V=Y(&UE;'D@8^UM:F5G>7KI
M:V5K(&IE;&5N:F5N96L@;65G+"#I<R!M:6QY96X@<V]R<F5N9&)E;CHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*;7-G:60@(D-H;V]S92!W:&EC
M:"!A9&1R97-S(&)O;VMS('1O('5S92XB"FUS9W-T<B`B5N%L87-S>F$@:VDL
M(&UE;'EI:R!C[6UJ96=Y>NEK92AK92ET(&OM=N%N:F$@:&%S>F[A;&YI+B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R.`IM<V=I
M9"`B0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA
M="!O<F1E<CHB"FUS9W-T<B`B365L>6EK(&]S>FQO<&]K(&IE;&5N:F5N96L@
M;65G(.ES(&UI;'EE;B!S;W)R96YD8F5N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-PIM<V=I9"`B0V]L=6UN($]P=&EO;G,B"FUS9W-T<B`B07H@
M;W-Z;&]P;VL@8F7A;&SM=.%S82(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@;F]T
M(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B3F5M(&UE9VIE;&5N]2!O<WIL;W!O
M:SHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(D-O;6UA('-E<&%R871E9"!V
M86QU97,B"FUS9W-T<B`B5F5S<WKU=F5L(&5L=N%L87-Z=&]T="#I<G3I:V5K
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M
M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI(@IM<V=S
M='(@(E9E<W-Z]79E;"!E;';A;&%S>G1O='0@Z7)TZ6ME:R`H36EC<F]S;V9T
M($]U=&QO;VLI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S8*
M;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B375N:V%H96QY(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"FUS9VED(")#;VUP86YY($%D9')E
M<W,B"FUS9W-T<B`B375N:V%H96QY:2!C[6TB"@HC.B!L:6(O87!I+G!H<#HS
M,C`@;&EB+V%P:2YP:'`Z,S8U(&QI8B]A<&DN<&AP.C0P.2!L:6(O87!I+G!H
M<#HT.3,*(SH@;&EB+V%P:2YP:'`Z-C$Y(&QI8B]A<&DN<&AP.C<P-B!L:6(O
M87!I+G!H<#HW-3D@;&EB+V%P:2YP:'`Z.#0P"B,Z(&QI8B]A<&DN<&AP.C$P
M,S<@;&EB+V%P:2YP:'`Z,3$R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!K87!C<V]L870@;F5M('-I
M:V5R_&QT.B`E<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-3@*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R(")!(&MA<&-S;VQA="!N96T@
M<VEK97+\;'0B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,R!L:6(O
M0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C8*;7-G:60@(D-O;G1A8W0@4V5A<F-H
M(@IM<V=S='(@(D/M;6ME<F5SZ7,B"@HC.B!B<F]W<V4N<&AP.C(Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYT86-T<R!I;B!L:7-T.B`E<R(*;7-G<W1R
M(")!("5S(&QI<W1A('1A9VIA:2(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,3@*;7-G:60@(D-O<'DB"FUS9W-T<B`B3>%S;VQJ=6L@X70B
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU,PIM<V=I9"`B0W)E
M871E(@IM<V=S='(@(DSI=')E:&]ZX7,B"@HC.B!T96UP;&%T97,O861D<F5S
M<V)O;VMS+FEN8SHT,`IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O:R(*;7-G
M<W1R(")#[6UJ96=Y>NEK(&SI=')E:&]ZX7-A(@H*(SH@;&EB+TQI<W16:65W
M+G!H<#HS-#@*;7-G:60@(D-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@:6XZ
M(@IM<V=S='(@(MIJ(&/M;6QI<W1A(&SI=')E:&]ZX7-A(&ET=#HB"@HC.B!L
M:6(O3V)J96-T5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@
M(DSI=')E:&]Z=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G
M:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(D$@<V]R
M8F%R96YD97KI<R!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!I<N%N>6$Z(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHS"B,Z(&QI8B]/8FIE8W0N<&AP.C,R."!L:6(O
M4F5N9&5R97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z-3`*;7-G:60@(D1E
M;&5T92(*;7-G<W1R(")4]G)LZ7,B"@HC.B!T96UP;&%T97,O861D<F5S<V)O
M;VMS+FEN8SHU.`IM<V=I9"`B1&5L971E($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")#[6UJ96=Y>NEK('3V<FSI<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@*;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T<B`B02!T
M]G)LZ7,@;65G97+U<^UTZ7-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y"FUS9VED(")$96QE=&4@8G5T=&]N(&)E:&%V:6]U<B(*;7-G<W1R(")!
M('3V<FSI<R!G;VUB('9I<V5L:V5DZ7-E(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HR-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R(")!('3V<FSI<R!N96T@<VEK97+\;'0Z("@E<RD@
M)7,B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C8R"FUS9VED(")$96QE=&EN
M9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!(&/M;6IE
M9WEZZ6MB]6P@;F5M(&QE:&5T('3V<O9L;FDN(@H*(SH@9&5L971E+G!H<#HS
M.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S='(@(D$@=/9R;.ES(&YE
M;2!S:6ME<OQL="(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q
M,PIM<V=I9"`B1&5P87)T;65N="(*;7-G<W1R(")2Z7-Z;&5G(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$97-C96YD:6YG(@IM<V=S
M='(@(F-S]FMK96[U(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M,3$U"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("),9>URX7,B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$Y"FUS9VED(")$:7)E8W1O
M<GDB"FUS9W-T<B`B0^UM=.%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(T"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(DUE9VIE;&5N[73I<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B
M365G:F5L96[M=.ES:2!B9>%L;.UTX7-O:R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-S<*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L
M971I;F<@96YT<FEE<S\B"FUS9W-T<B`B07H@861A=&]K('3V<FSI<^ET(&UE
M9V5L]7KU96X@\VAA:G0M92!E9WD@;65G97+U<^UT]2!KZ7)DZ7-T/R(*"B,Z
M(&QI8B]/8FIE8W0N<&AP.C(Y-PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B
M3&5T]FQTZ7,B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3<@=&5M
M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHR-0IM<V=I9"`B1&]W;FQO
M860@=D-A<F0B"FUS9W-T<B`B=D-A<F0@;&5T]FQTZ7,B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N
M:6YC.C(U"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC
M.C$P('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T
M97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z
M-#(*;7-G:60@(D5D:70B"FUS9W-T<B`B3?-D;W/M=.%S(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]R;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O8V]N=&%C
M=')O=RYI;F,Z,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B
M"FUS9W-T<B`B7"(E<UPB(&WS9&]S[73A<V$B"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHX,0IM<V=I9"`B161I="!!9&1R97-S($)O;VMS(@IM
M<V=S='(@(D/M;6IE9WEZZ6ME:R!M\V1O<^UTX7-A(@H*(SH@961I="YP:'`Z
M.#4@961I="YP:'`Z,38Q"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@96YT
M<GD@9F]R("5S(@IM<V=S='(@(DWS9&]S[71S=6L@)7,@861A=&%I="(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C4X"FUS9VED(")%;6%I;"(*
M;7-G<W1R(")%;6%I;"(*"B,Z(&5D:70N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@
M=7!L;V%D960@9FEL92!F86EL960Z("5S(@IM<V=S='(@(B(*(B5S(&%D871A
M:70@;?-D;W/M=&]T='5K+"!D92!A(&9E;'3V;'3V='0@X6QL;VWA;GET(&YE
M;2!S:6ME<OQL="!E;&UE;G1E;FDZ("5S(@H*(SH@961I="YP:'`Z,34V(&5D
M:70N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@
M=7!D871E9"XB"FUS9W-T<B`B)7,@^FH@861A=&%I="!E;&UE;G1E='3\:RXB
M"@HC.B!B<F]W<V4N<&AP.C(Q-B!B<F]W<V4N<&AP.C(V-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!A9&1I;F<@)60@8V]N=&%C="AS*2!T;R!L:7-T
M+B(*;7-G<W1R(")(:6)A('3V<G3I;G0@82`E9"!P87)T;F5R;F5K(&$@8^UM
M;&ES=.%H;WH@=F%L\R!H;WIZX6%DX7-A:V]R+B(*"B,Z(&)R;W=S92YP:'`Z
M,C$X(&)R;W=S92YP:'`Z,C8V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&%D9&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C="AS*2!T;R!L:7-T
M+B(*;7-G<W1R("(E9"!H:6)A('3V<G3I;G0@82`E9"!P87)T;F5R;F5K(&$@
M8^UM;&ES=.%H;WH@=F%L\R!H;WIZX6%DX7-A:V]R+B(*"B,Z(&)R;W=S92YP
M:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@)60@
M8V]N=&%C="AS*2XB"FUS9W-T<B`B2&EB82!T]G)TZ6YT(&$@)60@<&%R=&YE
M<B!T]G)LZ7-E:V]R+B(*"B,Z(&)R;W=S92YP:'`Z.#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@9&5L971I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O
M;G1A8W1S*',I+B(*;7-G<W1R("(E9"!H:6)A('3V<G3I;G0@82`E9"!P87)T
M;F5R('3V<FSI<V5K;W(N(@H*(SH@8G)O=W-E+G!H<#HV-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!R96UO=FEN9R`E9"!C;VYT86-T*',I(&9R;VT@
M;&ES="XB"FUS9W-T<B`B2&EB82!T]G)TZ6YT(&$@)60@<&%R=&YE<FYE:R!A
M(&/M;6QI<W3A8O-L('9A;/,@=/9R;.ES96MO<BXB"@HC.B!B<F]W<V4N<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E;6]V:6YG("5D(&]F
M("5D(')E<75E<W1E9"!C;VYT86-T*',I(&9R;VT@;&ES="XB"FUS9W-T<B`B
M)60@:&EB82!T]G)TZ6YT(&$@)60@<&%R=&YE<FYE:R!A(&/M;6QI<W3A8O-L
M('9A;/,@=/9R;.ES96MO<BXB"@HC.B!L:6(O87!I+G!H<#HT,34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@<V5A<F-H:6YG('1H92!A9&1R97-S(&)O
M;VLZ("5S(@IM<V=S='(@(DAI8F$@=/9R=.EN="!A(&/M;6IE9WEZZ6MB96X@
M=F%L\R!K97)E<^ES('-O<N%N.B`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHT,0IM
M<V=I9"`B17AP;W)T(@IM<V=S='(@(D5X<&]R=.%LX7,B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C8*;7-G:60@(D5X<&]R="!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B0^UM:F5G>7KI:R!E>'!O<G3A;.%S82(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H
M92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B0W-A:R!A(&MI:F5L]FQT
M(&QE=F5L97KU<&%R=&YE<F5K970@97AP;W)TX6QJ=6LN(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP;W)T('1H92!F;VQL
M;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM<V=S='(@(D$@=&5L
M:F5S(&/M;6IE9WEZZ6ME="!E>'!O<G3A;&IU:RXB"@HC.B!D871A+G!H<#HQ
M,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!B<F]W<V4N<&AP.C,U(&)R
M;W=S92YP:'`Z,3`S"B,Z(&)R;W=S92YP:'`Z,3,P(&%D9"YP:'`Z-C<@<V5A
M<F-H+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@86-C
M97-S('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D$H>BD@)7,@8^UM
M:F5G>7KI:R!N96T@Z7)H973U(&5L+B(*"B,Z(&)R;W=S92YP:'`Z,34X"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S
M(@IM<V=S='(@(DYE;2!S:6ME<OQL="`E<R!H;WIZX6%DX7-A("5S+6AE>CH@
M)7,B"@HC.B!B<F]W<V4N<&AP.C,P-0IM<V=I9"`B1F%I;&5D('1O(&)R;W=S
M92!L:7-T(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A(&QI<W1A(&+V;F?I<WKI
M<V4B"@HC.B!B<F]W<V4N<&AP.C,T,PIM<V=I9"`B1F%I;&5D('1O(&)R;W=S
M92!T:&4@9&ER96-T;W)Y(@IM<V=S='(@(D$@8^UM=.%R(&+V;F?I<WKI<V4@
M;F5M(&QE:&5T<^EG97,B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8VAA;F=E(&YA;64Z("@E
M<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@/2`E<RP@4F]O="`]("5S(@IM
M<V=S='(@(B(*(DYE;2!S:6ME<OQL="!A(&[I=B!M96=VX6QT;WIT873A<V$Z
M("@E<RD@)7,[('+I9VD@1$X@/2`E<RP@^FH@1$X@/2`E<RP@(@HB9WGV:^ER
M(#T@)7,B"@HC.B!B<F]W<V4N<&AP.C$S-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S(@IM<V=S
M='(@(DYE;2!S:6ME<OQL="!M96=T86SA;&YI(&$@8F5V:65N9/4@;V)J96MT
M=6UO=#H@)7,B"@HC.B!S96%R8V@N<&AP.C<Y"FUS9VED(")&86EL960@=&\@
M<V5A<F-H('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B02!C[6UJ96=Y>NEK
M8F5N(&YE;2!S:6ME<OQL="!A(&ME<F5SZ7,N(@H*(SH@9&%T82YP:'`Z,30Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I
M<F5C=&]R>3H@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&$@)7,@8^UM=.%R
M8F%N('9A;/,@:V5R97/I<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$V-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&5D:70N<&AP
M.C$S,2!D:7-P;&%Y+G!H<#HQ,#`*;7-G:60@(D9I;&5S(@IM<V=S='(@(D;A
M:FPB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S$*;7-G:60@
M(D9I;F0B"FUS9W-T<B`B365Z]2(*"B,Z(&5D:70N<&AP.C$P-"!E9&ET+G!H
M<#HQ.30*;7-G:60@(D9I;FES:"(*;7-G<W1R(")"969E:F5ZZ7,B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT.`IM<V=I9"`B1FER<W0@3F%M
M92(*;7-G<W1R(")+97)E<WIT;NEV(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B263U
M8F5O<WITX7-I('=E8B!C[6TB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z.#0*;7-G:60@(D9R;VTB"FUS9W-T<B`B:&]N;F%N(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`V"FUS9VED(")';&]B86P@061D<F5S
M<R!";V]K(@IM<V=S='(@(D=L;V+A;&ES(&/M;6IE9WEZZ6LB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+W)O=RYI;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT
M86-T<F]W+FEN8SHT-`IM<V=I9"`B1W)O=7`B"FUS9W-T<B`B0W-O<&]R="(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@R"FUS9VED(")(;VUE
M($%D9')E<W,B"FUS9W-T<B`B3W1T:&]N:2!C[6TZ('5T8V$B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y(@IM
M<V=S='(@(D]T=&AO;FD@8^UM.B!VX7)O<R(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$P.`IM<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@
M(D]T=&AO;FD@8^UM.B!O<G-ZX6<B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B3W1T:&]N
M:2!T96QE9F]N(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`S
M"FUS9VED(")(;VUE(%!O<W1A;"!#;V1E(@IM<V=S='(@(D]T=&AO;FD@8^UM
M.B!I<N%N>>UT\W-ZX6TB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HY.`IM<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R(")/='1H
M;VYI(&/M;3H@X6QL86TO=&%R=&]MX6YY(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z.#@*;7-G:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS
M9W-T<B`B3W1T:&]N:2!C[6TZ('5T8V$B"@HC.B!C;VYF:6<O<V]U<F-E<RYP
M:'`N9&ES=#HU,#@*;7-G:60@(DE-4U`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0W"FUS9VED("))35-0($%D9')E<W,@0F]O:R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("))35-0(&/M;6IE9WEZZ6L@:V5Z96SI
M<V4B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9"(*;7-G
M<W1R(")#[6UJ96=Y>NEK(&EM<&]R=.%LX7-A+"`E9"X@;.EPZ7,B"@HC.B!D
M871A+G!H<#HS-C$*;7-G:60@(DEM<&]R="]%>'!O<G0@061D<F5S<R!";V]K
M<R(*;7-G<W1R(")#[6UJ96=Y>NEK96L@:6UP;W)T+V5X<&]R=&IA(@H*(SH@
M;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<P,0IM<V=I9"`B26YV86QI
M9"!)1"(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@240N(@H*(SH@
M;&EB+V%P:2YP:'`Z,C,R(&QI8B]A<&DN<&AP.C0P-"!L:6(O87!I+G!H<#HT
M.#@@;&EB+V%P:2YP:'`Z-C$P"B,Z(&QI8B]A<&DN<&AP.C8Y-R!L:6(O87!I
M+G!H<#HW-#D@;&EB+V%P:2YP:'`Z,3$P.`IM<V=I9"`B26YV86QI9"!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B2&EBX7,@8^UM:F5G>7KI:RXB"@HC.B!L:6(O
M87!I+G!H<#HQ,3$R(&QI8B]A<&DN<&AP.C$Q.#4@;&EB+V%P:2YP:'`Z,3(S
M.`IM<V=I9"`B26YV86QI9"!E;6%I;"(*;7-G<W1R(")(:6+A<R!E;6%I;"!C
M[6TN(@H*(SH@;&EB+V%P:2YP:'`Z,3$R,`IM<V=I9"`B26YV86QI9"!E;G1R
M>2(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@861A="XB"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C(V-@IM<V=I9"`B26YV86QI9"!K97D@<W!E
M8VEF:65D+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@:W5L8W,N
M(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q-@IM<V=I9"`B26YV86QI9"!N86UE(@IM
M<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!NZ78N(@H*(SH@;&EB+V%P
M:2YP:'`Z-S4S"FUS9VED("));G9A;&ED(&]B:F5C=$ED(@IM<V=S='(@(DAI
M8N%S+V5L9F]G861H871A=&QA;B!O8FIE8W1)9"XB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C,P"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER
M960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO
M="!L;V%D960N(@IM<V=S='(@(B(*(DQ$05`@=.%M;V=A=.%S<F$@;&5N;F4@
M<WK\:W/I9RP@9&4@87H@3$1!4"!M;V1U;"!N96T@X6QL(')E;F1E;&ME>NES
M<F4L('9A9WD@(@HB;F5M('3V;'3U9/9T="!B92XB"@HC.B!L:6(O3V)J96-T
M5FEE=RYP:'`Z,3,X"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(E5T
M;VQS\R!M\V1O<^UTX7,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HU,PIM<V=I9"`B3&%S="!.86UE(@IM<V=S='(@(D-S86SA9&[I=B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$V"FUS9VED
M("),:7-T(@IM<V=S='(@(DQI<W1A(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.C<X"FUS9VED(")-871C:&EN9R(*;7-G<W1R(")M:70B"@HC
M.B!L:6(O87!I+G!H<#HR,#<*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($-O
M;G1A8W1S(@IM<V=S='(@(D$@<&%R=&YE<F5K(&UA>&EMX6QI<R!S>N%M82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@
M;G5M8F5R(&]F('!A9V5S(@IM<V=S='(@(D%Z(&]L9&%L86L@;6%X:6WA;&ES
M('-ZX6UA(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PIM<V=I9"`B
M365N=2!,:7-T(@IM<V=S='(@(DUE;OQL:7-T82(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,S`R"FUS9VED(")-:7-S:6YG($1.(&EN($Q$05`@<V]U<F-E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D%Z($Q$05`@<WIE<G9E<B!K;VYF
M:6=U<N%C:?-JX6)A;B!N:6YC<R!M96=A9'9A(&$@1$XN(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"FUS9VED(")-;V)I;&4@4&AO;F4B
M"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HS,S(@;&EB+T1R:79E<B]L9&%P+G!H<#HS-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B36]D:69Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")!(&WS9&]S
M[73A<R!N96T@<VEK97+\;'0Z("@E<RD@)7,B"@HC.B!L:6(O87!I+G!H<#HQ
M,C(T"FUS9VED(")-;W)E('1H86X@,2!E;G1R>2!F;W5N9"(*;7-G<W1R(")4
M]F)B+"!M:6YT(#$@=&%LX6QA="!V86XB"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C$V"FUS9VED(")-;W9E(@IM<V=S='(@(E1E9WG\:R#A
M="(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T-PHC
M.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X-`IM
M<V=I9"`B36]V92!L969T(@IM<V=S='(@(F)A;')A(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y"B,Z('1E;7!L871E<R]P<F5F
M<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V"FUS9VED(")-;W9E(')I9VAT
M(@IM<V=S='(@(FIO8F)R82(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,38*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O
M:R(*;7-G<W1R(")-=6QB97)R>2!C[6UJ96=Y>NEK(@H*(SH@;&EB+V%P:2YP
M:'`Z,3$T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S
M;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S
M72!A;')E861Y(&5X:7-T(@IM<V=S='(@(B(*(E3V8F(@<WIE;>EL>2!I<R!V
M86X@;>%R+"!A:VEN96L@82!C[6UE(%LE<UTL(&1E(&5G>6EK;F5K('-E;2!;
M)7-=(&$@;F5V92(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$P-R!C
M;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*;7-G:60@(DUY($%D9')E<W,@
M0F]O:R(*;7-G<W1R(")386KA="!C[6UJ96=Y>NEK(@H*(SH@861D<F5S<V)O
M;VMS+G!H<#HQ,3D*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B
M4V%JX70@8^UM:F5G>7KI:V5I;2(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT,@IM<V=I
M9"`B3F%M92(*;7-G<W1R(").Z78B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@(D[I=B!F;W)MX71U
M;2(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T
M8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B3F5T8V5N=&5R($UE
M;6)E<B!C[6UJ96=Y>NEK(@H*(SH@861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-PIM<V=I9"`B3F5W($-O;G1A8W0B
M"FUS9W-T<B`BVFH@;&5V96QE>O5P87)T;F5R(@H*(SH@961I="YP:'`Z.34@
M961I="YP:'`Z,3`R(&5D:70N<&AP.C(P.2!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@(DOV=F5T:V5Z]2(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q.`IM<V=I9"`B3FEC:VYA
M;64B"FUS9W-T<B`B0F5C96[I=B(*"B,Z(&QI8B]A<&DN<&AP.C$R,C8@;&EB
M+V%P:2YP:'`Z,3(W-0HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E;G1R
M>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B3FEN8W,@)7,@861A="!A*'HI("5S
M(&/M;6AE>B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.30*;7-G:60@(DYO(&%D9')E
M<W,@8F]O:W,@9F]U;F0N(@IM<V=S='(@(D5G>2!C[6UJ96=Y>NEK('-E;2!T
M86SA;&AA=/,N(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#$*;7-G:60@(DYO(&-O
M;G1A8W1S(&9O=6YD(@IM<V=S='(@(DYE;2!T86SA;'1U;FL@96=Y('!A<G1N
M97)T('-E;2(*"B,Z(&QI8B]A<&DN<&AP.C4Q,R!L:6(O87!I+G!H<#HW.#0*
M;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R(").96T@
M<VEK97+\;'0@=D-A<F0@861A=&]T('1A;.%L;FDN(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]F;V]T97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`B;FEN
M8W,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(DYO=&5S(@IM<V=S='(@(DUE9VIE9WEZZ7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$U"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B
M"FUS9W-T<B`B07H@;VQD86QO;B!M96=J96QE;NUT96YD]2!E;&5M96L@<WKA
M;6$B"@HC.B!L:6(O87!I+G!H<#HV,S(@;&EB+V%P:2YP:'`Z-S8U"FUS9VED
M(")/8FIE8W0@;F]T(&9O=6YD(@IM<V=S='(@(D%Z(&]B:F5K='5M(&YE;2!T
M86SA;&AA=/,@;65G(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2&EV871A;"]M=6YK86AE;'DB
M"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(R"FUS9VED("(B
M"B)/;F-E('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H92!A9&1R97-S
M(&)O;VL@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B!)9B!T:&ES
M(&ES(&YO="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T(&-H86YG92!Y
M;W5R('-E;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T<B`B(@HB2&$@
M96QM96YT:2!E>F5K970@82!B9>%L;.UTX7-O:V%T+"!A:VMO<B!A(&/M;6IE
M9WEZZ6L@=NEGZ7)VZ6YY97-E;B`B"B)T]G)L]61I:RX@2&$@97IT(&YE;2!S
M>F5R971NZ2P@86MK;W(@;F4@=N%L87-S>F]N(&MI('3V<FSI<W)E(&5G>65T
M('-E;2XB"@HC.B!L:6(O87!I+G!H<#HW.3(*;7-G:60@(D]N;'D@;VYE('9C
M87)D('-U<'!O<G1E9"XB"FUS9W-T<B`B0W-A:R!E9WEE=&QE;B!V8V%R9"!H
M87-Z;N%L871A(&QE:&5T<^EG97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B3W1H97(@
M3W!T:6]N<R(*;7-G<W1R(")%9WGI8B!B9>%L;.UTX7-O:R(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+
M97DB"FUS9W-T<B`B4$=0(&YY:6QVX6YO<R!K=6QC<R(*"B,Z(&QI8B]A<&DN
M<&AP.C0Y-R!L:6(O87!I+G!H<#HV,C,@;&EB+V%P:2YP:'`Z-S$P(&QI8B]A
M<&DN<&AP.CDV-0HC.B!L:6(O87!I+G!H<#HQ,3(Y"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R(")%:&AE>B!N:6YC<R!E:&AE>B!M96=F96QE
M;/4@:F]G;W-U;'1SX6=A(@H*(SH@;&EB+T1R:79E<BYP:'`Z-34P"FUS9VED
M(")097)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")%:&AE>B!N:6YC<R!M96=F
M96QE;/4@:F]G;W-U;'1SX6=A(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K
M<RYI;F,Z.3D*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(DIO9V]S=6QT
M<^%G;VLB"@HC.B!D871A+G!H<#HU,R!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$W"FUS9VED(")0:6YE($%D9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE
M(&/M;6IE9WEZZ6LB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N
M:6YC.C(X"FUS9VED(")0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@;&ES
M=#HB"FUS9W-T<B`B2^ER96T@861J82!M96<@87H@^FH@8^UM;&ES=&$@;F5V
MZ70Z(@H*(SH@961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D:70N<&AP.C(P
M,0IM<V=I9"`B4')E=FEO=7,B"FUS9W-T<B`B16SU>O4B"@HC.B!C;VYF:6<O
M<V]U<F-E<RYP:'`N9&ES=#HT,38*;7-G:60@(E!R:79A=&4@061D<F5S<R!"
M;V]K(@IM<V=S='(@(E-Z96WI;'EE<R!C[6UJ96=Y>NEK(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475E<GD@
M9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D$@:V5R97/I<R!S:6ME<G1E;&5N
M.B`H)7,I("5S(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC
M.C$X"FUS9VED(")1=6EC:R!396%R8V@B"FUS9W-T<B`B1WEO<G,@:V5R97/I
M<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,3DY(&QI8B]$<FEV97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E860@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D]L=F%S
MX7-I(&AI8F$Z("@E<RD@)7,B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4R
M"FUS9VED(")296%D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(D$@<&%R=&YE<F5K(&%D871A:2!N96T@;VQV87-H873S:RXB"@HC
M.B!L:6(O4F5N9&5R97(N<&AP.C0Y"FUS9VED(")296%L;'D@9&5L971E('1H
M:7,@8V]N=&%C=#\B"FUS9W-T<B`B5F%L\V)A;B!T]G+V;&YI(&OM=N%N:F$@
M96YN96L@82!L979E;&5Z]7!A<G1N97+I;F5K(&%Z(&%D871A:70_(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C(*;7-G:60@(E)E8V]R9',@
M9&ES<&QA>65D.B(*;7-G<W1R(")!(&UE9VIE;&5N[71E='0@861A=&]K.B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<V
M"FUS9VED(")296UO=F4@861D<F5S<R!B;V]K(@IM<V=S='(@(D$@8^UM:F5G
M>7KI:R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C
M="YI;F,Z,C,Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(F]S>FQO
M<"!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS
M"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B5/9R]FQJ
M_&L@82!L:7-TX7+S;"(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,C$*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K('=I
M=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES("(*
M(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@
M8F]O:RX\+W-T<F]N9SXB"FUS9W-T<B`B(@HBS7)J=6L@9F5L_&P@82!K:7;A
M;&%S>G1O='0@8^UM:F5G>7KI:V5T(&%Z(&EM<&]R=.%L='1A;#\@(@HB/'-T
M<F]N9SY&:6=Y96QM97IT973I<SH@97H@:VET]G)L:2!A>B#V<W-Z97,@861A
M=&]T(&$@:F5L96YL96=I("(*(F/M;6IE9WEZZ6MB]6PA/"]S=')O;F<^(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z-#,X"FUS9VED(")297%U97-T960@;V)J96-T
M(&YO="!F;W5N9"XB"FUS9W-T<B`B02!K97)E<V5T="!O8FIE:W1U;2!N96T@
M=&%LX6QH873S+B(*"B,Z(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.C$Q-`IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T
M<B`B2V5Z9&K\:R#Z:G)A(&$@:VET]FQTZ7-T(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I
M9FEC871E(@IM<V=S='(@(E,O34E-12!N>6EL=N%N;W,@=&%N^G/M=';A;GDB
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E-405)45$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")35$%25%1,
M4R!H:6)A.B`H)7,I("5S(@H*(SH@961I="YP:'`Z,3`V(&%D9"YP:'`Z,S<@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM
M<V=S='(@(DUE;G3I<R(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-C<*;7-G
M:60@(E-A=FEN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")!(&QE=F5L97KU<&%R=&YE<F5K(&%D871A:2!N96T@;65N=&AE=/5K(&5L
M+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-R!T96UP;&%T
M97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$S"B,Z('1E;7!L871E<R]B;&]C:R]M
M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HT.0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B"FUS
M9W-T<B`B2V5R97/I<R(*"B,Z(&QI8B]A<&DN<&AP.C$P-#(*;7-G:60@(E-E
M87)C:"!F86EL960B"FUS9W-T<B`B02!K97)E<^ES(&YE;2!S:6ME<OQL="(*
M"B,Z(&QI8B]A<&DN<&AP.C$Q,S0@;&EB+V%P:2YP:'`Z,3$T,"!L:6(O87!I
M+G!H<#HQ,30Y(&QI8B]A<&DN<&AP.C$Q-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!K97)E<^ES(&YE;2!S
M:6ME<OQL=#H@)7,B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C0W"FUS9VED
M(")396%R8VAI;F<@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B02!K97)E
M<^ES(&YE;2!L96AE='/I9V5S+B(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI
M<V5A<F-H+FEN8SHR,@IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S='(@(DME
M<F5SZ7,N+BXB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@IM
M<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T
M<B`B5N%L87-S>F$@:VDL(&UE;'EI:R!C[6UJ96=Y>NEK970@:^UVX6YJ82!T
M]G+V;&YI(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3`*;7-G
M:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@961I="(*;7-G<W1R(")6
MX6QA<W-Z82!K:2P@;65L>6EK(&/M;6IE9WEZZ6ME="!K[7;A;FIA(&WS9&]S
M[71A;FDB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C,R"FUS9VED
M(")396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS
M9W-T<B`B5N%L87-S>F$@:VDL(&UE;'EI:R!C[6UJ96=Y>NEK8O5L(&OM=N%N
M(&5X<&]R=.%L;FDZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR
M-@IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O
M.B(*;7-G<W1R(")6X6QA<W-Z82!K:2P@;65L>6EK(&/M;6IE9WEZZ6MB92!K
M[7;A;B!I;7!O<G3A;&YI.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,S4*;7-G:60@(E-E;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E
M(&9I;&4Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&%Z(&EM<&]R=.%L86YD\R!F
MX6IL(&MA<F%K=&5R:^ES>FQE=.ET.B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,3`*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB
M"FUS9W-T<B`B5N%L87-S>F$@:VD@87H@97AP;W)TX6SA<R!F;W)MX71U;>%T
M.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#,*;7-G:60@(E-E
M;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(E;A;&%S<WIA(&MI
M(&%Z(&EM<&]R=.%L86YD\R!FX6IL=#HB"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@
M<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&%Z(&EM<&]R=.%L
M86YD\R!FX6IL(&9O<FWA='5MX70Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P
M;&%Y(&YA;65S.B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A(&YE=F5K(&UE9VIE
M;&5N[73I<VD@9F]R;>%JX70Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L
M('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+B(*;7-G<W1R("(B
M"B)+:7;A;&%S>G1H873S(&%Z(&%L87#I<G1E;&UE>F5T="!M96=J96QE;NUT
MZ7,L('-O<F)A<F5N9&5ZZ7-I(.ES(&QA<&]ZX7-I("(*(F)EX6QL[73A<V]K
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.`IM<V=I9"`B4V5L96-T
M('=H:6-H(&9I96QD<R!T;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S
M+B(*;7-G<W1R(")+:7;A;&%S>G1H873S+"!H;V=Y(&$@8^UM;&ES=.%B86X@
M;6EL>65N(&UE>O5K(&IE;&5N:F5N96L@;65G+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L96-T('=H:6-H(&9O<FUA="!T;R!D
M:7-P;&%Y(&YA;65S+B(*;7-G<W1R(")+:7;A;&%S>G1H873S(&$@;F5V96L@
M;65G:F5L96[M=.ES:2!M\V1J82XB"@HC.B!A9&0N<&AP.C4T"B,L('!H<"UF
M;W)M870*;7-G:60@(E-E;&5C=&5D(&%D9')E<W,@8F]O:R!<(B5S7"(N(@IM
M<V=S='(@(D$@:VEVX6QA<WIT;W1T(&/M;6IE9WEZZ6L@7"(E<UPB+B(*"B,Z
M(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B4VAA<F5D($1I
M<F5C=&]R>2(*;7-G<W1R(")+]GKV<R!C[6UTX7(B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@)7,B"FUS9W-T<B`B)7,@;65G:F5L96[M=.ES92(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#@*;7-G:60@(E-H;W<@06QL(@IM<V=S
M='(@(DUU=&%S<W5K(&UI;F1E="(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z-#<*;7-G:60@(E-H;W<@0V]N=&%C=',B"FUS9W-T<B`B375T
M87-S=6L@82!P87)T;F5R96ME="(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z-#8*;7-G:60@(E-H;W<@3&ES=',B"FUS9W-T<B`B375T87-S
M=6L@82!L:7-TX6MA="(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C(Q"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C,V"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R(")!('-O
M<F)A<F5N9&5ZZ7,@:7+A;GEA(@H*(SH@;&EB+V%P:2YP:'`Z,C`P"FUS9VED
M(")3;W5R8V5S(@IM<V=S='(@(D/M;6IE9WEZZ6L@9F]R<N%S;VLB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")3<&5C:69Y('=H97)E
M('EO=2!W86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BXB
M"FUS9W-T<B`B5N%L87-S>F$@:VDL(&AO;"!J96QE;FIE;B!M96<@82!RZ7-Z
M;&5T97,@:V5R97/I<R!E<F5D;>EN>64N(@H*(SH@8G)O=W-E+G!H<#HR,30@
M8G)O=W-E+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&%D9&5D("5D(&-O;G1A8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`B02!L
M:7-TX6AO>B!S:6ME<F5S96X@:&]Z>N%A9'1U;FL@)60@8^UM970N(@H*(SH@
M8G)O=W-E+G!H<#HQ-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&%D9&5D("5S('1O("5S(@IM<V=S='(@(B5S(&AO>GKA863A<V$@)7,M
M:&5Z('-I:V5R97,@=F]L="(*"B,Z(&)R;W=S92YP:'`Z,C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T
M(&QI<W0@7"(E<UPB+B(*;7-G<W1R(")3:6ME<F5S96X@;.ET<F5H;WIT=6L@
M82AZ*2!<(B5S7"(@8^UM;&ES=.%T+B(*"B,Z(&)R;W=S92YP:'`Z.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@)60@8V]N
M=&%C="AS*2XB"FUS9W-T<B`B4VEK97)E<V5N('3V<O9L=/QN:R`E9"!C[6UE
M="XB"@HC.B!B<F]W<V4N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R96UO=F5D("5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+B(*
M;7-G<W1R(")3:6ME<F5S96X@96QTX79O;.UT;W1T=6L@)60@8^UM970@82!L
M:7-TX7+S;"XB"@HC.B!D871A+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU
M97,B"FUS9W-T<B`B5$%"(&MA<F%K=&5R<F5L(&5L=N%L87-Z=&]T="#I<G3I
M:V5K(@H*(SH@=FEE=RYP:'`Z,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N
M965D<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P
M;&]A9',N(@IM<V=S='(@(B(*(D$@5D93(&%L<F5N9'-Z97(@8F7A;&SM=.%S
M86EB86X@96YG963I;'EE>FYI(&ME;&P@82!M96QLZ6ML971E:R`B"B)F96QT
M]FQT:&5T]7/I9^ET+B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&/M;6IE9WEZZ6L@;F5M
M(&SI=&5Z:6LN(@H*(SH@861D<F5S<V)O;VMS+G!H<#HT.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@8W)E871E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D$H>BD@7"(E<UPB(&/M;6IE9WEZ
MZ6ME="!S:6ME<F5S96X@;.ET<F5H;WIT=6LN(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K
M(%PB)7-<(B!W87,@<F5M;W9E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D$H
M>BD@7"(E<UPB(&/M;6IE9WEZZ6ME="!S:6ME<F5S96X@=/9R]FQT_&LN(@H*
M(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T
M960N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&/M;6IE9WEZZ6ME="!S:6ME<F5S
M96X@;?-D;W/M=&]T='5K+B(*"B,Z(&1A=&$N<&AP.C,P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G
M960Z("5S(@IM<V=S='(@(D$@8^UM:F5G>7KI:R!N96T@=/9R]FQH973U.B`E
M<R(*"B,Z(&5D:70N<&AP.C4Q('9C87)D+G!H<#HR,B!D:7-P;&%Y+G!H<#HR
M,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A8W0@>6]U(')E<75E<W1E
M9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B02!K97)E<V5T="!L979E;&5Z
M]7!A<G1N97(@;F5M(&SI=&5Z:6LN(@H*(SH@961I="YP:'`Z,3(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE(%PB)7-<(B!H87,@<W5C8V5S<V9U
M;&QY(&)E96X@9&5L971E9"XB"FUS9W-T<B`B02AZ*2!<(B5S7"(@X6QL;VWA
M;GET('-I:V5R97-E;B!T]G+V;'3\:RXB"@HC.B!D871A+G!H<#HR.#0*;7-G
M:60@(E1H92!I;7!O<G0@8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A
M<FYI;F=S+B(*;7-G<W1R(")!>B!I;7!O<G3A;.%S(&$@9FEG>65L;65Z=&5T
MZ7-E:R!E;&QE;NER92!B969E:F5Z:&5T]2XB"@HC.B!B<F]W<V4N<&AP.C,Q
M"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS
M+B(*;7-G<W1R(").:6YC<V5N(&]L>6%N(&/M;6IE9WEZZ6LL(&%M:6)E;B!B
M]FYGZ7-Z;FD@='5D+B(*"B,Z(&%D9"YP:'`Z,CD*;7-G:60@(B(*(E1H97)E
M(&%R92!N;R!W<FET96%B;&4@861D<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@
M879A:6QA8FQE(&%D9')E<W,@8F]O:W,@(@HB87)E(&-O;F9I9W5R960@=&\@
M86QL;W<@>6]U('1O(&%D9"!N97<@96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@
M8F5L:65V92!T:&ES("(*(FES(&%N(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).:6YC<R#M
M<FAA=/,@8^UM:F5G>7KI:RX@16=Y971L96X@<F5N9&5L:V5ZZ7-R92#A;&SS
M(&/M;6IE9WEZZ6MH97H@<V5M("(*(FIO9V]S=6QT(/IJ86)B(&)E:F5G>7KI
M<V5K970@:&]Z>N%T96YN:2X@2&$@^F=Y(&=O;F1O;&IA+"!H;V=Y(&5Z("(*
M(G)E;F1E;&QE;F5S+"!A:VMO<B!F;W)D=6QJ;VX@82!H96QY:2!R96YD<WIE
M<F=A>F3A:&]Z+B(*"B,Z(&%D9"YP:'`Z,3(Q"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@861D:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R("(*(F9O<B!F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*(D$@<&%R=&YE<B!A9&%T86EN86L@:&]Z>N%A9.%S82!N
M96T@<VEK97+\;'0N(%1O=N%B8FD@<V5G[71SZ6?I<G0@9F]R9'5L:F]N(&$@
M(@HB<F5N9'-Z97)G87IDX6AO>BXB"@HC.B!B<F]W<V4N<&AP.C(W,0IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N(@IM
M<V=S='(@(DAI8F$@=/9R=.EN="!A>B#Z:B!L:7-T82!LZ71R96AO>N%S82!S
M;W+A;BXB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D9')E
M<W,@8F]O:SH@)7,B"FUS9W-T<B`B2&EB82!T]G)TZ6YT(&5N;F5K(&$@8^UM
M:F5G>7KI:VYE:R!A(&SI=')E:&]ZX7-A('-O<N%N.B`E<R(*"B,Z(&)R;W=S
M92YP:'`Z,38V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D96QE=&EN9R!<(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@
M8F]O:RXB"FUS9W-T<B`B7"(E<UPB+70@;F5M('-I:V5R_&QT(&MI=/9R]FQN
M:2!A>B!E<F5D971I(&/M;6IE9WEZZ6MB]6PN(@H*(SH@9&5L971E+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G<W1R(")!('!A<G1N97(@861A
M=&%I;F%K('3V<FSI<V4@<V]RX6X@:&EB82!T]G)TZ6YT.B`E<R(*"B,Z(&)R
M;W=S92YP:'`Z,S$Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&4@;&ES="(*;7-G<W1R(")!(&QI<W1A(&UE9VIE;&5N[73I<V5K
M;W(@:&EB82!T]G)TZ6YT(@H*(SH@9&%T82YP:'`Z,S,U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A
M=&$Z("5S(@IM<V=S='(@(D%Z(&EM<&]R=.%LX7,@<V]RX6X@:&EB82!T]G)T
MZ6YT.B`E<R(*"B,Z(&QI8B]A<&DN<&AP.C4P.2!L:6(O87!I+G!H<#HW-SD*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R(")!>B!I0V%L96YD87(@861A=&]K(&EM<&]R
M=.%LX7-A('-O<N%N(&AI8F$@=/9R=.EN="XB"@HC.B!A9&1R97-S8F]O:W,N
M<&AP.C4X(&%D9')E<W-B;V]K<RYP:'`Z-C,@861D<F5S<V)O;VMS+G!H<#HV
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M
M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(DAI8F$@=/9R
M=.EN="!E(&/M;6IE9WEZZ6L@=/9R;.ES92!S;W+A;CH@)7,B"@HC.B!A9&1R
M97-S8F]O:W,N<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS
M9W-T<B`B2&EB82!T]G)TZ6YT(&4@8^UM:F5G>7KI:R!M\V1O<^UTX7-A('-O
M<N%N.B`E<R(*"B,Z(&5D:70N<&AP.C$V-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,B
M"FUS9W-T<B`B2&EB82!T]G)TZ6YT(&5N;F5K(&%Z(&%D871N86L@82!M\V1O
M<^UTX7-A('-O<N%N.B`E<R(*"B,Z(&1A=&$N<&AP.C$W.0IM<V=I9"`B5&AE
M<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+B(*;7-G<W1R(").96T@
M=F]L="!E>'!O<G3A;&AA=/,@8^UM+B(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R97-S
M(&)O;VMS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R(")%
M>F5K(&$@8^UM:F5G>7KI:V5K(&$@:_9V971K97KU('-O<G)E;F1B96X@:F5L
M96YN96L@;65G.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(T,PIM<V=I9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@
M=&AI<R!O<F1E<CHB"FUS9W-T<B`B17IE:R!A>B!O<WIL;W!O:R!A(&OV=F5T
M:V5Z]2!S;W)R96YD8F5N(&IE;&5N;F5K(&UE9SHB"@HC.B!D871A+G!H<#HR
M-CD*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B07H@82!FX6IL9F]R;>%T=6T@;F5M('3A;6]G871O='0N(@H*
M(SH@;&EB+V%P:2YP:'`Z,3$U,R!L:6(O87!I+G!H<#HQ,38V"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT
M<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")%>B!A('-Z96WI;'D@
M;>%R('-Z97)E<&5L(&$@8^UM:F5G>7KI:^EB96XL(&UI;G0@)7,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30X"FUS9VED("(B"B)4:&ES('=I;&P@
M8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R(&EM
M<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T<B`B(@HB17H@;&5S>B!A>B!A;&%P
MZ7)T96QM97IE='0@8^UM:F5G>7KI:R#Z:B!A9&%T;VL@;.ET<F5H;WKA<V%K
M;W(@:6QL+B`B"B)I;7!O<G3A;.%S86MO<BXB"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HW,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET=6QU
M<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-#0S"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@;F5W('-H87)E+B!-:7-S:6YG('-O=7)C92!T
M>7!E+B(*;7-G<W1R("(B"B).96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(&OV
M>O9S(&/M;6IE9WEZZ6ME="X@27-M97)E=&QE;B!A(&9O<G+A<R!T[7!U<V$N
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N:2`E<R!D969I;NUC:?-JX70N(@H*
M(SH@961I="YP:'`Z.34@961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D:70N
M<&AP.C$P-B!E9&ET+G!H<#HR,#,*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G
M<W1R(")-Z6=S92!M96YT<_QK(&5L(@H*(SH@;&EB+V%P:2YP:'`Z-30R(&QI
M8B]A<&DN<&AP.C8V,2!L:6(O87!I+G!H<#HW.3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R(").
M96T@=.%M;V=A=&]T="!T87)T86QO;73M<'5S.B`E<R(*"B,Z(&-O;F9I9R]S
M;W5R8V5S+G!H<"YD:7-T.C,W-@IM<V=I9"`B5F5R:7-I9VX@1&ER96-T;W)Y
M(@IM<V=S='(@(E9E<FES:6=N(&/M;73A<B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC
M.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB(@IM<V=S='(@
M(EPB)7-<(B!M96=T96MI;G3I<V4B"@HC.B!M:6YI<V5A<F-H+G!H<#HW-@IM
M<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(MIJ(&)E:F5G>7KI<R!R]F=Z
M[73I<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")6
M:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS9W-T<B`B07H@86QA<.ER
M=&5L;65ZZ7,@<WIE<FEN=&D@;65G:F5L96[M=.ES.B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS
M9W-T<B`B5V5B(&/M;2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$Q,PIM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(DUU;FMA:&5L>6D@
M8^UM.B!U=&-A(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(T
M"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B375N:V%H96QY:2!C[6TZ(';A
M<F]S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,Y"FUS9VED
M(")7;W)K($-O=6YT<GDB"FUS9W-T<B`B375N:V%H96QY:2!C[6TZ(&]R<WKA
M9R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U-@IM<V=I9"`B
M5V]R:R!0:&]N92(*;7-G<W1R(")-=6YK86AE;'EI('1E;&5F;VXB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,S0*;7-G:60@(E=O<FL@4&]S
M=&%L($-O9&4B"FUS9W-T<B`B375N:V%H96QY:2!C[6TZ(&ERX6YY[73S<WKA
M;2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R.0IM<V=I9"`B
M5V]R:R!3=&%T92]0<F]V:6YC92(*;7-G<W1R(")-=6YK86AE;'EI(&/M;3H@
MX6QL86TO=&%R=&]MX6YY(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3$Y"FUS9VED(")7;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(DUU
M;FMA:&5L>6D@8^UM.B!U=&-A(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP
M:'`Z,3`V(&)R;W=S92YP:'`Z,C(W(&%D9"YP:'`Z-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T
M:&%N("5D(&-O;G1A8W1S(&EN(%PB)7-<(BXB"FUS9W-T<B`B3F5M(&AO>FAA
M="!LZ71R92!T]F)B+"!M:6YT("5D('!A<G1N97)T(&$@7"(E<UPB(&/M;6IE
M9WEZZ6MB96XN(@H*(SH@961I="YP:'`Z-S,@9&ES<&QA>2YP:'`Z-3@@=FEE
M=RYP:'`Z,S8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R(")%;FYE:R!A('-Z96WI;'EN
M96L@87H@861T86ET(&YE;2!J;V=O<W5L="!M96=T96MI;G1E;FDN(@H*(SH@
M=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO
M;B!T;R!V:65W('1H:7,@;V)J96-T+B(*;7-G<W1R(")%>G0@87H@;V)J96MT
M=6UO="!N96T@:F]G;W-U;'0@;65G=&5K:6YT96YI+B(*"B,Z(&QI8B]4=7)B
M82YP:'`Z-3,Q"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;G,@
M=&\@9&5L971E('1H:7,@<V]U<F-E+B(*;7-G<W1R("+6;FYE:R!N:6YC<R!J
M;V=O<W5L='/A9V$@=/9R]FQN:2!E>G0@87H@8^UM:F5G>7KI:V5T+B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-34*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(D5L]7-Z]G(@8^EL:^EN="!K:2!K96QL(';A;&%S>G1A;FEA(&5G>2!C[6UJ
M96=Y>NEK970N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN
M8SHR,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N(@IM
M<V=S='(@(D5L]7-Z]G(@8^EL:^EN="!K:2!K96QL(';A;&%S>G1A;FEA(&5G
M>2!L:7-TX70N(@H*(SH@961I="YP:'`Z,S(*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B16SU
M8F(@:VD@:V5L;"!VX6QA<WIT86YI82!L96=A;.%B8B!E9WD@;&5V96QE>O5P
M87)T;F5R="XB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C$W('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHW,@IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="XB"FUS9W-T<B`B
M16SU8F(@:VD@:V5L;"!VX6QA<WIT86YI82!L96=A;.%B8B!E9WD@861A=&]T
M+B(*"B,Z(&5D:70N<&AP.C<W"FUS9VED(")9;W4@;VYL>2!H879E('!E<FUI
M<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(D4@<WIE;>EL
M>2!A9&%T86ET(&-S86L@;65G=&5K:6YT96YI('9A;B!J;V=O<W5L='/A9V$N
M(@H*(SH@8G)O=W-E+G!H<#HS,3@*;7-G:60@(EEO=7(@9&5F875L="!A9&1R
M97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N(@IM<V=S='(@(D%Z(-9N(&%L
M87#I<G1E;&UE>NES('-Z97)I;G1I(&/M;6IE9WEZZ6ME(&YE;2!B]FYGZ7-Z
M:&5T]2XB"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z-B!T96UP;&%T
M97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS9VED(");;F\@=F%L=65=
M(@IM<V=S='(@(EMN:6YC<R!A9&%T72(*"B,Z(&QI8B]4=7)B82YP:'`Z-34T
M"FUS9VED(")?0G)O=W-E(@IM<V=S='(@(E]"]FYGZ7-ZZ7,B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0W"FUS9VED(")?0V]N=&%C=',B
M"FUS9W-T<B`B4&%R=&YE<F5K(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHS"FUS9VED(")?1&5L971E(@IM<V=S='(@(E3V<FSI<R(*"B,Z
M(&QI8B]4=7)B82YP:'`Z-38S"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G
M<W1R("));7!O<G0O7T5X<&]R="(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z-#8*;7-G:60@(E],:7-T<R(*;7-G<W1R("),:7-TX6LB"@HC
M.B!L:6(O5'5R8F$N<&AP.C4U,0IM<V=I9"`B7TUY($%D9')E<W,@0F]O:W,B
M"FUS9W-T<B`B4V%JX70@8^UM:F5G>7KI:V5I;2(*"B,Z(&QI8B]4=7)B82YP
M:'`Z-34W"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T<B`BVFH@;&5V96QE
M>O5P87)T;F5R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS
M"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(E3V<O9L
M:OQK(&$@;&ES=.%R\VPB"@HC.B!L:6(O5'5R8F$N<&AP.C4U.0IM<V=I9"`B
M7U-E87)C:"(*;7-G<W1R(")+97)E7W/I<R(*"B,Z('9C87)D+G!H<#HT-@IM
M<V=I9"`B8V]N=&%C="YV8V8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3DY
M(&1A=&$N<&AP.C(P-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G
M:60@(F-O;G1A8W1S+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,#D*
M;7-G:60@(F-O;G1A8W1S+G1S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR
M,3D*;7-G:60@(F-O;G1A8W1S+G9C9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,X"FUS9VED(")N;R!F;W)M871T:6YG(@IM<V=S
M='(@(F9O<FUA='3A;.%S(&[I;&O\;"(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M;7-P7V]P="YI;F,Z,S(*;7-G:60@(FYO;F4B"FUS9W-T<B`B96=Y('-E;2(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,S$*;7-G:60@(G1O
M(&$@0V]N=&%C="!,:7-T(@IM<V=S='(@(F5G>2!C[6UL:7-TX6)A(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B=&\@82!D
M:69F97)E;G0@061D<F5S<R!";V]K(@IM<V=S='(@(F5G>2!MX7-I:R!C[6UJ
M96=Y>NEK8F4B"@HC.B!D871A+G!H<#HU,2!T96UP;&%T97,O8G)O=W-E+V-O
M;'5M;E]H96%D97)S+FEN8SHQ,PHC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$U('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(G9#
M87)D(@IM<V=S='(@(G9#87)D(@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O='5R8F$O<&\O9FE?1DDN<&\`````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#$P,C,S-0`Q,#0Q-S,V,C<U-@`P,3<T-S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R!&:6YN
M:7-H('1R86YS;&%T:6]N(&9O<B!4=7)B82X*(R!#;W!Y<FEG:'0@*$,I"B,@
M3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3XL(#(P,#$M,C`P-BX*(PIM<V=I
M9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@,BXQ
M+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3(T(#$P.C0V
M*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,3,@,3(Z-3DK
M,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!,965N82!(96EN;R`\;&EI;G5`
M=71A+F9I/EQN(@HB3&%N9W5A9V4M5&5A;3H@1FEN;FES:"`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!T96UP;&%T
M97,O<')E9G,O:6US<%]O<'0N:6YC.C0P"FUS9VED("(@061D(&%N($E-4U`@
M061D<F5S<R!";V]K(@IM<V=S='(@(DQI<^3D($E-4U`M;W-O:71E:VER:F$B
M"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(Y"FUS9VED("(@
M1&5L971E($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(E!O:7-T82!)35-0
M+6]S;VET96MI<FIA(@H*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I;7!O
M<G1E9"XB"FUS9W-T<B`B7"(E<UPB(&]N(&IO(&]L96UA<W-A(&IA(&5I('1U
M;W1U+B(*"B,Z(&)R;W=S92YP:'`Z,30P"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB
M"FUS9W-T<B`B7"(E<UPB(&5I(&MO<&EO:71U(&MO<VMA('-E(&]N(&QI<W1A
M+B(*"B,Z(&)R;W=S92YP:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@;F]T(&UO=F5D(&)E8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G
M<W1R(")<(B5S7"(@96D@<VEI<G)E='1Y(&MO<VMA('-E(&]N(&QI<W1A+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@(EPB1FER<W1N
M86UE($QA<W1N86UE7"(@("AI92X@2F]H;B!$;V4I(@IM<V=S='(@(EPB171U
M;FEM:2!3=6MU;FEM:5PB("`H97-I;2X@36%T=&D@365I:^1LY&EN96XI(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M
M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(EPB4W5K
M=6YI;6DL($5T=6YI;6E<(B`H97-I;2X@365I:^1LY&EN96XL($UA='1I*2(*
M"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%D9&5D
M+B(*;7-G<W1R("(E<R!L:7/D='1Y+B(*"B,Z(&1A=&$N<&AP.C,T,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E
M9"(*;7-G<W1R("(E<R!T:65D;W-T;VX@='5O;G1I(&]N;FES='5I(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@+2`E<R`O("5S(@H*
M(SH@;&EB+U1U<F)A+G!H<#HT-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B)7,Z;B!O<V]I=&5K:7)J82(*"B,Z
M(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HT,@IM<V=I9"`B02!B<F]W<V5R
M('1H870@<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9"(*;7-G<W1R(")4
M87)V:71A86X@<V5L86EN+"!J;W-S82!O;B!T=6MI(&E&<F%M97,@=&]I;6EN
M;F]L;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38P"FUS9VED(")!
M8F]V92!S96%R8V@@9F]R;2(*;7-G<W1R(")H86MU;&]M86MK965N('ELY'!U
M;VQE;&QA(@H*(SH@=FEE=RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M06-C97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R("(E<R!KY'ET=/8@:VEE;&QE
M='1Y(@H*(SH@861D+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N
M:6YC.C(Y"FUS9VED(")!9&0B"FUS9W-T<B`B3&ESY.0B"@HC.B!T96UP;&%T
M97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-`IM<V=I9"`B061D
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("),:7/DY"!O<V]I=&5K:7)J82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.`IM<V=I9"`B061D(&%N9"!$96QE
M=&4@24U34"!A9&1R97-S(&)O;VMS(@IM<V=S='(@(DQI<^3D(&IA('!O:7-T
M82!)35-0+6]S;VET96MI<FIO:F$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L
M=6UN<V5L96-T+FEN8SHR,S<*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B
M3&ESY.0@<V%R86ME(@H*(SH@961I="YP:'`Z,3,U"FUS9VED(")!9&0@9FEL
M92(*;7-G<W1R("),:7/DY"!T:65D;W-T;R(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"!T;R(*;7-G<W1R("),:7/D
MY"!K;VAT965S965N(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HU-PIM<V=I
M9"`B061D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(EEH=&5Y<W1I971O:F5N(&QI<^3D;6EN96X@96D@;VQE(&OD>71E='3D=FES
M<^0N(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#8*;7-G:60@
M(D%D9')E<W,@0F]O:R(*;7-G<W1R(")/<V]I=&5K:7)J82(*"B,Z(&)R;W=S
M92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B061D
M<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B3W-O:71E:VER:F%N('-E;&%U
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B061D<F5S
M<R!";V]K<R(*;7-G<W1R(")/<V]I=&5K:7)J870B"@HC.B!A9&0N<&AP.C$P
M.`IM<V=I9"`B061D<F5S<R!B;V]K(&5N=')Y(@IM<V=S='(@(D]S;VET96MI
M<FIA;B!M97)K:6YTY"(*"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B061D<F5S
M<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(D]S;VET96MI
M<FIA('1Y:&IE;FYE='1I:6XN(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K
M<RYI;F,Z-C(*;7-G:60@(D%D9')E<W,@8F]O:R!T;R!D96QE=&4@(@IM<V=S
M='(@(E!O:7-T971T879A(&]S;VET96MI<FIA("(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<P"FUS9VED(")!9&1R97-S
M(&)O;VMS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R(")/
M<V]I=&5K:7)J86$@96D@=F]I='4@;N1Y='3DY#H@)7,B"@HC.B!S96%R8V@N
M<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS.`IM<V=I9"`B
M061V86YC960@4V5A<F-H(@IM<V=S='(@(E1A<FME;7!I(&AA:W4B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HV-`IM<V=I9"`B06QI87,B"FUS
M9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C0X('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<*(SH@=&5M
M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z,3`*;7-G:60@(D%L;"(*
M;7-G<W1R(")+86EK:VDB"@HC.B!L:6(O87!I+G!H<#HU-30*;7-G:60@(D%L
M<F5A9'D@17AI<W1S(@IM<V=S='(@(D]N(&IO(&]L96UA<W-A(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@
M)7,_(@IM<V=S='(@(D]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A
M82`E<S\B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8W
M"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@
M=&AE('-E;&5C=&5D(&5N=')I97,_(@IM<V=S='(@(D]L971K;R!V87)M82P@
M971TY"!H86QU870@<&]I<W1A82!V86QI='5T/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-@IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(DYO=7-E
M=F$B"@HC.B!S96%R8V@N<&AP.C@U('1E;7!L871E<R]B<F]W<V4O<V5A<F-H
M+FEN8SHS-PIM<V=I9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(EEK<VEN:V5R
M=&%I;F5N(&AA:W4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Y"FUS
M9VED(")"96QO=R!S96%R8V@@9F]R;2(*;7-G<W1R(")(86MU;&]M86MK965N
M(&%L87!U;VQE;&QA(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-R!L:6(O
M1')I=F5R+VQD87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@
M9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(EEH9&ES=.1M:6YE;B!E<.1O;FYI
M<W1U:2`H)7,I("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3<X"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")3>6YT>6WD<.1I=N0B"@HC
M.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B0G)O=W-E(@IM<V=S='(@
M(E-E;&%A(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<S"FUS
M9VED(")"=7-I;F5S<R!#871E9V]R>2(*;7-G<W1R("),:6EK971O:6UI;FYA
M;B!L=6]K:71U<R(*"B,Z(&1A=&$N<&AP.C0Y"FUS9VED(")#4U8B"FUS9W-T
M<B`B0U-6(@H*(SH@;&EB+T]B:F5C="]'<F]U<"YP:'`Z-3<*;7-G:60@(D-A
M;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BXB"FUS9W-T<B`B16D@=F]I(&QI
M<^1TY"!R>6AMY.0@:71S965N<^0N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C
M;VQU;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM
M<V=S='(@(E9A;&ET<V4@7VMA:6MK:2]E:2!M:73DY&XB"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHT-`IM<V=I9"`B0VAO;W-E(&$@;F%M92(*
M;7-G<W1R(")686QI='-E(&YI;6DB"@HC.B!A9&0N<&AP.C0X"FUS9VED(")#
M:&]O<V4@86X@861D<F5S<R!B;V]K(@IM<V=S='(@(E9A;&ET<V4@;W-O:71E
M:VER:F$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR
M,C$*;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(E9A
M;&ET<V4@;W-O:71E:VER:F$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E
M<W-B;V]K<V5L96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R
M97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G
M<W1R(")686QI='-E(&UI=&OD(&]S;VET96MI<FIA="!NY'ET973DY&X@:F$@
M;6ES<^0@:N1R:F5S='EK<V5S<^0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U
M<V4N(@IM<V=S='(@(E9A;&ET<V4@;6ETY"!O<V]I=&5K:7)J;VIA(&OD>71E
M=.3D;BXB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR
M,C@*;7-G:60@(D-H;V]S92!W:&EC:"!C;VQU;6YS('1O(&1I<W!L87D@86YD
M(&EN('=H870@;W)D97(Z(@IM<V=S='(@(E9A;&ET<V4@;6ET:^0@<V%R86MK
M965T(&[D>71E=.3D;B!J82!M:7-SY"!JY')J97-T>6MS97-SY#HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D-O;'5M;B!/<'1I;VYS
M(@IM<V=S='(@(E-A<F%K:V5I9&5N(&%S971U:W-E="(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T
M:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B4V%R86MK96ET
M82P@:F]I=&$@96D@=F]I='4@;N1Y='3DY#HB"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$S('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(*
M;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B4&EL:W5I
M;&QA(&5R;W1E='5T(&%R=F]T(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S
M;V9T($]U=&QO;VLI(@IM<V=S='(@(E!I;&MU:6QL82!E<F]T971U="!A<G9O
M="`H36EC<F]S;V9T($]U=&QO;VLI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B67)I='ES(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"FUS9VED(")#;VUP
M86YY($%D9')E<W,B"FUS9W-T<B`B67)I='EK<V5N(&]S;VET92(*"B,Z(&QI
M8B]A<&DN<&AP.C,R,"!L:6(O87!I+G!H<#HS-C4@;&EB+V%P:2YP:'`Z-#`Y
M(&QI8B]A<&DN<&AP.C0Y,PHC.B!L:6(O87!I+G!H<#HV,3D@;&EB+V%P:2YP
M:'`Z-S`V(&QI8B]A<&DN<&AP.C<U.2!L:6(O87!I+G!H<#HX-#`*(SH@;&EB
M+V%P:2YP:'`Z,3`S-R!L:6(O87!I+G!H<#HQ,3(U"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")9:'1E>7,@
M97#D;VYN:7-T=6DZ("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(EEH=&5Y<R!E<.1O
M;FYI<W1U:2(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HS(&QI8B]"
M;&]C:R]M:6YI<V5A<F-H+G!H<#HR-@IM<V=I9"`B0V]N=&%C="!396%R8V@B
M"FUS9W-T<B`B66AT97ES=&EE=&]J96X@:&%K=2(*"B,Z(&)R;W=S92YP:'`Z
M,CDY"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z("5S
M(@IM<V=S='(@(EEH=&5Y<W1I961O="!L:7-T87-S83H@)7,B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$X"FUS9VED(")#;W!Y(@IM<V=S
M='(@(DMO<&EO:2(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C4S
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3'5O(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-#`*;7-G:60@(D-R96%T92!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B3'5O(&]S;VET96MI<FIA(@H*(SH@;&EB+TQI<W16:65W+G!H
M<#HS-#@*;7-G:60@(D-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@:6XZ(@IM
M<V=S='(@(DQU;R!U=7-I('EH=&5Y<W1I971O;&ES=&$@;W-O:71E:VER:F%A
M;CHB"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D
M(@IM<V=S='(@(DQU;W1U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX
M"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R(")/
M;&5T=7-JY')J97-T>6MS96X@<W5U;G1A.B(*"B,Z('1E;7!L871E<R]A9&1R
M97-S8F]O:W,N:6YC.C<V('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,PHC.B!L:6(O3V)J96-T+G!H<#HS,C@@;&EB+U)E;F1E<F5R+G!H<#HT-R!L
M:6(O4F5N9&5R97(N<&AP.C4P"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4&]I
M<W1A(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3@*;7-G:60@
M(D1E;&5T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B4&]I<W1A(&]S;VET96MI
M<FIA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")$96QE
M=&4@0V]N9FER;6%T:6]N(@IM<V=S='(@(E!O:7-T;VX@=F%R;6ES='5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED(")$96QE=&4@8G5T
M=&]N(&)E:&%V:6]U<B(*;7-G<W1R(")6;VET(&UU=71T86$@4&]I<W1A('!A
M:6YI:VME96X@=&]I;6EN=&%A(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E(&9A:6QE9#H@*"5S*2`E
M<R(*;7-G<W1R(")0;VES=&%M:6YE;B!E<.1O;FYI<W1U:3H@*"5S*2`E<R(*
M"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-C(*;7-G:60@(D1E;&5T:6YG(&-O
M;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(EEH=&5Y<W1I971O
M:F5N('!O:7-T;R!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB"@HC.B!D96QE=&4N
M<&AP.C,X"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T<B`B4&]I<W1A
M;6EN96X@97#D;VYN:7-T=6DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B3W-A<W1O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$97-C96YD:6YG
M(@IM<V=S='(@(DQA<VME=F$B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHQ,34*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(DMU=F%U<R(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3D*;7-G:60@(D1I
M<F5C=&]R>2(*;7-G<W1R(")(86ME;6ES=&\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C0*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B3N1K>6WD(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M(").Y&MY;>1N(&%S971U:W-E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-S<*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@
M96YT<FEE<S\B"FUS9W-T<B`B5F%R;6ES=&$@86EN82!K=6X@<&]I<W1E=&%A
M;B!M97)K:6YT]FKD+B(*"B,Z(&QI8B]/8FIE8W0N<&AP.C(Y-PIM<V=I9"`B
M1&]W;FQO860B"FUS9W-T<B`B5&%L;&5N;F$B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V-O;G1A8W1R;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O<F]W+FEN
M8SHQ-PIM<V=I9"`B1&]W;FQO860@=D-A<F0B"FUS9W-T<B`B5&%L;&5N;F$@
M5D-A<F0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]B<F]W
M<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B<F]W<V4O8V]N
M=&%C=')O=RYI;F,Z,S,*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U
M(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B"FUS9W-T<B`B375O
M:VMA82(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,@
M=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(DUU;VMK86$@7"(E<UPB(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*;7-G:60@(D5D:70@061D
M<F5S<R!";V]K<R(*;7-G<W1R(")-=6]K:V%A(&]S;VET96MI<FIO:F$B"@HC
M.B!E9&ET+G!H<#HX-2!E9&ET+G!H<#HQ-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!E;G1R>2!F;W(@)7,B"FUS9W-T<B`B375O:VMA82`E<SIN(&UE
M<FMI;G3DY"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C4X"FUS
M9VED(")%;6%I;"(*;7-G<W1R(")3Y&AK]G!O<W1I(@H*(SH@961I="YP:'`Z
M,34T"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D
M+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@HB365R:VEN=.3D("5S('#D:79I=&5T=&EI;BP@;75T=&$@='5O
M9'5N('1I961O<W1O;B!T86QL971T86UI;F5N(&5PY&]N;FES='5I.B`B"B(E
M<R(*"B,Z(&5D:70N<&AP.C$U-B!E9&ET+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960N(@IM<V=S='(@(DUE<FMI
M;G3D("5S.G-TY"!O;B!PY&EV:71E='1Y+B(*"B,Z(&)R;W=S92YP:'`Z,C$V
M(&)R;W=S92YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&%D
M9&EN9R`E9"!C;VYT86-T*',I('1O(&QI<W0N(@IM<V=S='(@(E1A<&%H='5I
M('9I<FAE(&QI<^1T=.1E<W/D("5D('EH=&5Y<W1I971O82!L:7-T86QL92XB
M"@HC.B!B<F]W<V4N<&AP.C(Q."!B<F]W<V4N<&AP.C(V-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!A9&1I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O
M;G1A8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`B5&%P86AT=6D@=FER:&4@;&ES
MY'1TY&5S<^0@)60@+R`E9"!Y:'1E>7-T:65T;V$@;&ES=&%L;&4N(@H*(SH@
M8G)O=W-E+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE
M=&EN9R`E9"!C;VYT86-T*',I+B(*;7-G<W1R(")487!A:'1U:2!V:7)H92!P
M;VES=&5T=&%E<W-A("5D('EH=&5Y<W1I971O82XB"@HC.B!B<F]W<V4N<&AP
M.C@X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG("5D(&]F
M("5D(')E<75E<W1E9"!C;VYT86-T<RAS*2XB"FUS9W-T<B`B5&%P86AT=6D@
M=FER:&4@<&]I<W1E='1A97-S82`E9"`O("5D(&]S;VET971I971O82XB"@HC
M.B!B<F]W<V4N<&AP.C8V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E
M;6]V:6YG("5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G<W1R(")487!A
M:'1U:2!V:7)H92!P;VES=&5T=&%E<W-A("5D(&]S;VET971I971O82!L:7-T
M86QT82XB"@HC.B!B<F]W<V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(')E;6]V:6YG("5D(&]F("5D(')E<75E<W1E9"!C;VYT86-T*',I
M(&9R;VT@;&ES="XB"FUS9W-T<B`B5&%P86AT=6D@=FER:&4@<&]I<W1E='1A
M97-S82`E9"`O("5D(&]S;VET971I971O82!L:7-T86QT82XB"@HC.B!L:6(O
M87!I+G!H<#HT,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5A<F-H
M:6YG('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(E1A<&%H='5I('9I
M<FAE(&AA971T865S<V$@;W-O:71E:VER:F%S=&$Z("5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHT,2!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C$P"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B5FEE(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHV"FUS9VED(")%>'!O<G0@061D<F5S
M<R!";V]K(@IM<V=S='(@(E9I92!O<V]I=&5K:7)J82(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S
M96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B5FEE('9A:6X@=F%L:71U="!Y
M:'1E>7-T:65D;W0N(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR
M-PIM<V=I9"`B17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O
M;7!L971E;'DN(@IM<V=S='(@(E9I92!S975R86%V870@;W-O:71E:VER:F%T
M(&MO:V]N86%N+B(*"B,Z(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HQ,#,@
M8G)O=W-E+G!H<#HQ,S`@861D+G!H<#HV-R!D871A+G!H<#HQ,S0*(SH@9&%T
M82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!S96%R8V@N<&AP.C,W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O
M:SH@)7,B"FUS9W-T<B`B3W-O:71E:VER:F%A;B!E:2!S86%T=2!Y:'1E>71T
MY#H@)7,B"@HC.B!B<F]W<V4N<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@861D("5S('1O("5S.B`E<R(*;7-G<W1R("(E<SIN(&QI
M<^1Y<R!E<.1O;FYI<W1U:2`E<SKDY&XZ("5S(@H*(SH@8G)O=W-E+G!H<#HS
M,#4*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@;&ES="(*;7-G<W1R("),:7-T
M86X@<V5L875S(&5PY&]N;FES='5I+B(*"B,Z(&)R;W=S92YP:'`Z,S0S"FUS
M9VED(")&86EL960@=&\@8G)O=W-E('1H92!D:7)E8W1O<GDB"FUS9W-T<B`B
M2&%K96UI<W1O;B!S96QA=7,@97#D;VYN:7-T=6DB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C,P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@/2`E
M<RP@4F]O="`]("5S(@IM<V=S='(@(B(*(DYI;65N(&UU=71T86UI;F5N(&5P
MY&]N;FES='5I.B`H)7,I("5S.R!5=7-I($1.(#T@)7,L(%9A;FAA($1.(#T@
M)7,L($IU=7)I(#T@(@HB)7,B"@HC.B!B<F]W<V4N<&AP.C$S-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D
M960Z("5S(@IM<V=S='(@(DQI<^1T=.1VY&X@;V)J96MT:6X@:&%K=2!E<.1O
M;FYI<W1U:3H@)7,B"@HC.B!S96%R8V@N<&AP.C<Y"FUS9VED(")&86EL960@
M=&\@<V5A<F-H('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B2&%K=2!O<V]I
M=&5K:7)J87-T82!E<.1O;FYI<W1U:2(*"B,Z(&1A=&$N<&AP.C$T.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O
M<GDZ("5S(@IM<V=S='(@(DAA:W4@97#D;VYN:7-T=6D@:&%K96UI<W1O<W1A
M.B`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM<V=I
M9"`B1F%X(@IM<V=S='(@(D9A:W-I(@H*(SH@9&ES<&QA>2YP:'`Z,3`P(&5D
M:70N<&AP.C$S,0IM<V=I9"`B1FEL97,B"FUS9W-T<B`B5&EE9&]S=&]T(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<Q"FUS9VED(")&:6YD
M(@IM<V=S='(@(DAA:W4B"@HC.B!E9&ET+G!H<#HQ,#0@961I="YP:'`Z,3DT
M"FUS9VED(")&:6YI<V@B"FUS9W-T<B`B4.3D=.0B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HT.`IM<V=I9"`B1FER<W0@3F%M92(*;7-G<W1R
M(")%='5N:6UI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`R
M"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B1G)E96)U<WD@55),(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@T"FUS9VED(")&<F]M
M(@IM<V=S='(@(DSD:&1E(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z
M-C`V"FUS9VED(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@(EEL96EN
M96X@;W-O:71E:VER:F$B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C0T('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHT,PIM<V=I9"`B
M1W)O=7`B"FUS9W-T<B`B4GEH;>0B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DMO=&EO
M<V]I=&4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY,PIM<V=I
M9"`B2&]M92!#:71Y(@IM<V=S='(@(DMO=&EK875P=6YK:2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P.`IM<V=I9"`B2&]M92!#;W5N=')Y
M(@IM<V=S='(@(DMO=&EM86$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B4'5H96QI;B`H
M:V]T:2DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*;7-G
M:60@(DAO;64@4&]S=&%L($-O9&4B"FUS9W-T<B`B4&]S=&EN=6UE<F\@*&MO
M=&DI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3@*;7-G:60@
M(DAO;64@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B2V]T:6SDY&YI('1A:2!A
M;'5E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#@*;7-G:60@
M(DAO;64@4W1R965T($%D9')E<W,B"FUS9W-T<B`B2V%T=6]S;VET92`H:V]T
M:2DB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HU,#@*;7-G:60@(DE-
M4U`B"FUS9W-T<B`B24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-PIM<V=I9"`B24U34"!!9&1R97-S($)O;VL@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B24U34"UO<V]I=&5K:7)J86X@:&%L;&EN=&$B"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9"(*;7-G<W1R(")/<V]I=&5K:7)J
M86X@='5O;G1I+"!A<VME;"`E9"(*"B,Z(&1A=&$N<&AP.C,V,0IM<V=I9"`B
M26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS(@IM<V=S='(@(E1U;R]6:64@
M;W-O:71E:VER:F]J82(*"B,Z(&QI8B]A<&DN<&AP.C8Q-"!L:6(O87!I+G!H
M<#HW,#$*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`B5FER:&5E;&QI;F5N
M($E$(@H*(SH@;&EB+V%P:2YP:'`Z,C,R(&QI8B]A<&DN<&AP.C0P-"!L:6(O
M87!I+G!H<#HT.#@@;&EB+V%P:2YP:'`Z-C$P"B,Z(&QI8B]A<&DN<&AP.C8Y
M-R!L:6(O87!I+G!H<#HW-#D@;&EB+V%P:2YP:'`Z,3$P.`IM<V=I9"`B26YV
M86QI9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B17#D:V5L<&\@;W-O:71E:VER
M:F$B"@HC.B!L:6(O87!I+G!H<#HQ,3$R(&QI8B]A<&DN<&AP.C$Q.#8@;&EB
M+V%P:2YP:'`Z,3(S.0IM<V=I9"`B26YV86QI9"!E;6%I;"(*;7-G<W1R(")6
M:7)H965L;&EN96X@<^1H:_9P;W-T:6]S;VET92(*"B,Z(&QI8B]A<&DN<&AP
M.C$Q,C`*;7-G:60@(DEN=F%L:60@96YT<GDB"FUS9W-T<B`B5FER:&5E;&QI
M;F5N(&UE<FMI;G3D(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR-C8*;7-G
M:60@(DEN=F%L:60@:V5Y('-P96-I9FEE9"XB"FUS9W-T<B`B3>3D<FET96QT
M>2!A=F%I;B!O;B!V:7)H965L;&EN96XB"@HC.B!L:6(O87!I+G!H<#HQ,3$V
M"FUS9VED("));G9A;&ED(&YA;64B"FUS9W-T<B`B5FER:&5E;&QI;F5N(&YI
M;6DB"@HC.B!L:6(O87!I+G!H<#HW-3,*;7-G:60@(DEN=F%L:60@;V)J96-T
M260B"FUS9W-T<B`B5FER:&5E;&QI;F5N(&]B:F5C=$ED(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E
M<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O
M<B!N;W0@;&]A9&5D+B(*;7-G<W1R("(B"B),1$%0+71U:VD@;VX@<&%K;VQL
M:6YE;BP@;75T=&$@3$1!4"UM;V1U=6QI(&5I(&]L92!KY'ET971TY'9I<W/D
M('1A:2!L861A='1U+B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S@*;7-G
M:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B375O:V%T='4@=FEI;65K<VDB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PIM<V=I9"`B3&%S
M="!.86UE(@IM<V=S='(@(E-U:W5N:6UI(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`B
M3&ES=&$B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S@*;7-G
M:60@(DUA=&-H:6YG(@IM<V=S='(@(D]N(@H*(SH@;&EB+V%P:2YP:'`Z,C`W
M"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!#;VYT86-T<R(*;7-G<W1R(")9
M:'1E>7-T:65T;VIE;B!E;FEM;>1I<VWDY'+D(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@<&%G97,B
M"FUS9W-T<B`B4W5U<FEN('-A;&QI='1U(&WDY'+D('-I=G5J82XB"@HC.B!L
M:6(O0FQO8VLO=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU($QI<W0B"FUS
M9W-T<B`B5F%L:6MK;VQI<W1A(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS
M,#(*;7-G:60@(DUI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B1$X@<'5U='1U=2!,1$%0(&SD:&1E;>3D<FET=&5L
M>6ES=.0N(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"FUS
M9VED(")-;V)I;&4@4&AO;F4B"FUS9W-T<B`B36%T:V%P=6AE;&EN(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HS,S(@;&EB+T1R:79E<B]L9&%P+G!H<#HS
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y(&9A:6QE9#H@*"5S*2`E
M<R(*;7-G<W1R(")-=6]K:V%U<R!E<.1O;FYI<W1U:3H@*"5S*2`E<R(*"B,Z
M(&QI8B]A<&DN<&AP.C$R,C4*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y(&9O
M=6YD(@IM<V=S='(@(DSV>71Y:2!U<V5A;7!I(&MU:6X@,2!M97)K:6YTY.0B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$V"FUS9VED(")-
M;W9E(@IM<V=S='(@(E-I:7)RY"(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R
M97-S8F]O:W-E;&5C="YI;F,Z,3@T"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(T-PIM<V=I9"`B36]V92!L969T(@IM<V=S='(@(E-I
M:7)RY"!V87-E;6UA;&QE(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B
M;V]K<V5L96-T+FEN8SHQ.#8*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E
M;&5C="YI;F,Z,C0Y"FUS9VED(")-;W9E(')I9VAT(@IM<V=S='(@(E-I:7)R
MY"!O:6ME86QL92(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,38*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G
M<W1R(")-=6QB97)R>2UO<V]I=&5K:7)J82(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB375L=&EP;&4@<&5R<V]N<R!W
M:71H(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@86QR
M96%D>2!E>&ES="(*;7-G<W1R("(B"B)/<V]I=&5K:7)J87-S82!O;&D@;6]N
M=&$@:&5N:VEL]N0@;W-O:71T965L;&$@6R5S72P@;75T=&$@96D@:V5TY.1N
M(&YI;65L;.0@(@HB6R5S72XB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES
M=#HQ,#<@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,C0S"FUS9VED(")->2!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B3VUA(&]S;VET96MI<FIA(@H*(SH@861D
M<F5S<V)O;VMS+G!H<#HQ,3D*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B"FUS
M9W-T<B`B3VUA="!O<V]I=&5K:7)J870B"@HC.B!T96UP;&%T97,O861D<F5S
M<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#(*
M;7-G:60@(DYA;64B"FUS9W-T<B`B3FEM:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,0IM<V=I9"`B3F%M92!&;W)M870B"FUS9W-T<B`B3FEM96X@
M;75O=&\B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HS,34*;7-G:60@
M(DYE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y(@IM<V=S='(@(DYE=&-E;G1E
M<B!JY'-E;FAA:V5M:7-T;R(*"B,Z(&%D9"YP:'`Z,S8@861D+G!H<#HQ,C0@
M;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*;7-G:60@(DYE=R!#;VYT86-T
M(@IM<V=S='(@(E5U<VD@>6AT97ES=&EE=&\B"@HC.B!E9&ET+G!H<#HY-2!E
M9&ET+G!H<#HQ,#(@961I="YP:'`Z,C`Y('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z-#4*;7-G:60@(DYE>'0B"FUS9W-T<B`B4V5U<F%A=F$B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*;7-G:60@(DYI8VMN86UE
M(@IM<V=S='(@(DQE;7!I;FEM:2(*"B,Z(&QI8B]A<&DN<&AP.C$R,C<@;&EB
M+V%P:2YP:'`Z,3(W-@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E;G1R
M>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B365R:VEN=.3D("5S(&5I(&SV>71Y
M;GET("5S.FQL92(*"B,Z(&QI8B]A<&DN<&AP.C$Q.34*;7-G:60@(DYO(&%D
M9')E<W,@8F]O:W,@9F]U;F0N(@IM<V=S='(@(D5I(&SV>71Y;GET(&%I;G5T
M=&%K86%N(&]S;VET96MI<FIA82XB"@HC.B!M:6YI<V5A<F-H+G!H<#HX,0IM
M<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B"FUS9W-T<B`B16D@;/9Y='EN>70@
M>6AT97ES=&EE=&]J82(*"B,Z(&QI8B]A<&DN<&AP.C4Q,R!L:6(O87!I+G!H
M<#HW.#0*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R
M(")V0V%R9"!T:65T;VIA(&5I(&SV>71Y;GET+B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R+FEN8SHW"FUS9VED(").;VYE(@IM<V=S='(@(D5I(&UI
M=.3D;B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$X-`IM<V=I
M9"`B3F]T97,B"FUS9W-T<B`B375I<W1I:6YP86YO="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@
M<&%G92(*;7-G<W1R(")4:65T;VIA(&QU:W5MY.1RY"!S:79U;&QA(@H*(SH@
M;&EB+V%P:2YP:'`Z-C,R(&QI8B]A<&DN<&AP.C<V-0IM<V=I9"`B3V)J96-T
M(&YO="!F;W5N9"(*;7-G<W1R(")/8FIE:W1I82!E:2!L]GET>6YY="(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(R,PIM<V=I9"`B3V9F:6-E
M(@IM<V=S='(@(E1O:6UI<W1O(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?
M;W!T+FEN8SHR,@IM<V=I9"`B(@HB3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO
M;B!P86=E+"!T:&4@861D<F5S<R!B;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@
M(@HB9&5L971E9"X@268@=&AI<R!I<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE
M;B!Y;W4@;75S="!C:&%N9V4@>6]U<B!S96QE8W1I;VX@(@HB=&\@7").;VYE
M7"(N(@IM<V=S='(@(B(*(DMU;B!T86QL971A="!TY&WD;B!A<V5T=7-S:79U
M;BP@;FEI;B!O<V]I=&5K:7)J87-I('!O:7-T=74@;&]P=6QL:7-E<W1I+B!*
M;W,@(@HB970@:&%L=6$@<&]I<W1A82!O<V]I=&5K:7)J86%S:2P@;FEI;B!S
M:6YU;B!P:73DY"!M=75T=&%A('9A;&EN;F%K<VD@7")%:2`B"B)M:73DY&Y<
M(BXB"@HC.B!L:6(O87!I+G!H<#HW.3(*;7-G:60@(D]N;'D@;VYE('9C87)D
M('-U<'!O<G1E9"XB"FUS9W-T<B`B5'5E='1U;F$@=F%I;B!Y:W-I('9C87)D
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#8*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B375U
M="!A<V5T=6MS970B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(DIU;&MI;F5N(%!'
M4"UA=F%I;B(*"B,Z(&QI8B]A<&DN<&AP.C0Y-R!L:6(O87!I+G!H<#HV,C,@
M;&EB+V%P:2YP:'`Z-S$P(&QI8B]A<&DN<&AP.CDV-0HC.B!L:6(O87!I+G!H
M<#HQ,3(Y"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")+Y'ET
M=/8@:VEE;&QE='1Y(@H*(SH@;&EB+T1R:79E<BYP:'`Z-34T"FUS9VED(")0
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")+Y'ET=/8@:VEE;&QE='1Y(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3D*;7-G:60@(E!E<FUI
M<W-I;VYS(@IM<V=S='(@(D]I:V5U9&5T(@H*(SH@9&%T82YP:'`Z-3,@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B4&EN92!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B4&EN92UO<V]I=&5K:7)J82(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE
M('1H92!N97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R(")!;FYA(&YI;6D@=75D
M96QL92!Y:'1E>7-T:65T;VQI<W1A;&QE.B(*"B,Z(&5D:70N<&AP.CDX(&5D
M:70N<&AP.C$P,2!E9&ET+G!H<#HR,#$*;7-G:60@(E!R979I;W5S(@IM<V=S
M='(@(D5D96QL:6YE;B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q
M-@IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B66MS:71Y
M:6YE;B!O<V]I=&5K:7)J82(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30W
M"B,L('!H<"UF;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@*"5S*2`E<R(*
M;7-G<W1R(")+>7-E;'D@97#D;VYN:7-T=6DZ("@E<RD@)7,B"@HC.B!T96UP
M;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,34*;7-G:60@(E%U:6-K(%-E
M87)C:"(*;7-G<W1R(")0:6MA:&%K=2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E860@9F%I;&5D.B`H
M)7,I("5S(@IM<V=S='(@(DQU:W4@97#D;VYN:7-T=6DZ("@E<RD@)7,B"@HC
M.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4R"FUS9VED(")296%D:6YG(&-O;G1A
M8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(EEH=&5Y<W1I971O:F5N
M(&QU:W4@96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@;&EB+U)E;F1E<F5R
M+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM
M<V=S='(@(DAA;'5A=&MO('!O:7-T86$@=.1MY&X@>6AT97ES=&EE9&]N/R(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O
M<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`B3N1Y=&5T=.1VY'0@=&EE9&]T.B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<V
M"FUS9VED(")296UO=F4@861D<F5S<R!B;V]K(@IM<V=S='(@(E!O:7-T82!O
M<V]I=&5K:7)J82(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(S.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")0;VES=&$@
M<V%R86ME(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"FUS
M9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B4&]I<W1A('3D
M;'3D(&QI<W1A;'1A(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR
M,0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET
M:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB
M9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B
M;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"B)+;W)V86$@;VQE;6%S<V%O;&5V
M82!O<V]I=&5K:7)J82!T=6]D=6QL82!O<V]I=&5K:7)J86QL82X@/'-T<F]N
M9SY687)O:71U<SH@(@HB5.1MY"!P;VES=&%A(&MA:6MK:2!M97)K:6YNY'0@
M;GEK>6ES97-TY"!O<V]I=&5K:7)J87-T87-I+CPO<W1R;VYG/B(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C0T,@IM<V=I9"`B4F5Q=65S=&5D(&]B:F5C="!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!Y>61E='1YY"!O8FIE:W1I82!E:2!L]GET>6YY
M="XB"@HC.B!A9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN
M8SHQ,30*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(E!A;&%U
M=&$@;VQE='5K<V5T(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I9FEC871E(@IM<V=S='(@
M(DIU;&MI;F5N(%,O34E-12UV87)M96YN92(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(E-405)45$Q3(&5PY&]N;FES='5I.B`H)7,I
M("5S(@H*(SH@861D+G!H<#HS-R!E9&ET+G!H<#HQ,#8@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S='(@(E1A;&QE
M=&$B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C8W"FUS9VED(")3879I;F<@
M8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B66AT97ES=&EE
M=&]J96X@=&%L;&5T=7,@96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.CDW('1E;7!L871E<R]B<F]W<V4O
M<V5A<F-H+FEN8SHQ,3,*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N
M:6YC.C$X(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C0Y"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(E-E87)C:"(*;7-G<W1R(")(86MU
M(@H*(SH@;&EB+V%P:2YP:'`Z,3`T,@IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*
M;7-G<W1R(")(86MU(&5PY&]N;FES='5I(@H*(SH@;&EB+V%P:2YP:'`Z,3$S
M-"!L:6(O87!I+G!H<#HQ,30P(&QI8B]A<&DN<&AP.C$Q-#D@;&EB+V%P:2YP
M:'`Z,3$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@9F%I;&5D.B`E
M<R(*;7-G<W1R(")(86MU(&5PY&]N;FES='5I.B`E<R(*"B,Z(&QI8B]$<FEV
M97(O;G5L;"YP:'`Z-#<*;7-G:60@(E-E87)C:&EN9R!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")(86MU(&5I(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z
M('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHQ.0IM<V=I9"`B4V5A
M<F-H:6YG+BXN(@IM<V=S='(@(DAA971A86XN+BXB"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHV-@IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@
M8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B5F%L:71S92!P;VES=&5T=&%V82!O
M<V]I=&5K:7)J82(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDP
M"FUS9VED(")396QE8W0@86X@861D<F5S<R!B;V]K('1O(&5D:70B"FUS9W-T
M<B`B5F%L:71S92!M=6]K871T879A(&]S;VET96MI<FIA(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHS,@IM<V=I9"`B4V5L96-T('1H92!A9&1R
M97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ(@IM<V=S='(@(E9A;&ET<V4@;W-O
M:71E:VER:F$L(&IO<W1A('9I963DY&X@=&EE=&]J83HB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C(V"FUS9VED(")396QE8W0@=&AE(&%D9')E
M<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(E9A;&ET<V4@;W-O:71E
M:VER:F$L(&IO:&]N('1U;V1A86X@=&EE=&]J83HB"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C,U"FUS9VED(")396QE8W0@=&AE(&-H87)S970@
M;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")686QI='-E(&SD:&1E=&EE
M9&]S=&]N(&UE<FMI<W3V.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,3`*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T
M<B`B5F%L:71S92!V:65N;FES<^0@:^1Y=&5T=.1VY"!M=6]T;SHB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0S"FUS9VED(")396QE8W0@=&AE
M(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")686QI='-E('1I961O<W1O+"!J
M;W-T82!T=6]D86%N('1I971O:F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHQ,0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O
M=7)C92!F:6QE.B(*;7-G<W1R(")686QI='-E(&SD:&1E=&EE9&]S=&]N(&UU
M;W1O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E
M;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SHB"FUS9W-T
M<B`B5F%L:71S92!N:6UI96X@97-I='ES;75O=&\Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(U"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y
M(&)Y(&1E9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS
M+B(*;7-G<W1R(")686QI='-E(&]L971U<V[D:WEMY"P@:N1R:F5S='ES87-E
M='5K<V5T(&IA('-I=G5T=7-A<V5T=6MS970N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$X"FUS9VED(")396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I
M<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N(@IM<V=S='(@(E9A;&ET<V4@
M;W-O:71E;&ES=&%S<V$@;N1Y=&5T=.1VY'0@:V5N=.1T+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L96-T('=H:6-H(&9O<FUA
M="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R(")6;VET('9A;&ET82!N:6UI
M96X@97-I='ES;75O9&]N+B(*"B,Z(&%D9"YP:'`Z-30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K(%PB)7-<(BXB"FUS9W-T
M<B`B5F%L:71T=2!O<V]I=&5K:7)J82!<(B5S7"(N(@H*(SH@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z,3<S"FUS9VED(")3:&%R960@1&ER96-T;W)Y(@IM
M<V=S='(@(DIA971T=2!H86ME;6ES=&\B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B
M"FUS9W-T<B`B3N1Y=.0@)7,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C0X"FUS9VED(")3:&]W($%L;"(*;7-G<W1R(").Y'ETY"!K86EK
M:VDB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0W"FUS9VED
M(")3:&]W($-O;G1A8W1S(@IM<V=S='(@(D[D>73D('EH=&5Y<W1I961O="(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#8*;7-G:60@(E-H
M;W<@3&ES=',B"FUS9W-T<B`B3N1Y=.0@;&ES=&%T(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,C$*(SH@=&5M<&QA=&5S+V)R
M;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,S8*;7-G:60@(E-O<G0@1&ER96-T
M:6]N(@IM<V=S='(@(DKD<FIE<W1Y:W-E;B!S=75N=&$B"@HC.B!L:6(O87!I
M+G!H<#HR,#`*;7-G:60@(E-O=7)C97,B"FUS9W-T<B`B3.1H=&5E="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(E-P96-I9GD@=VAE
M<F4@>6]U('=A;G0@861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R
M+B(*;7-G<W1R(")-Y.1R:71T96QE(&UI:&EN(&AA;'5A="!E9&ES='EN965N
M(&AA=6X@='5L;VMS:65N('1U;&5V86XN(@H*(SH@8G)O=W-E+G!H<#HR,30@
M8G)O=W-E+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&%D9&5D("5D(&-O;G1A8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`B3VYN
M:7-T=71T:6EN(&QI<^3D;>3D;B`E9"!Y:'1E>7-T:65T;V$@;&ES=&%L;&4N
M(@H*(SH@8G)O=W-E+G!H<#HQ-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D("5S('1O("5S(@IM<V=S='(@(D]N;FES='5T=&EI
M;B!L:7/DY&WDY&X@)7,@)7,ZY.1N(@H*(SH@8G)O=W-E+G!H<#HR-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O
M;G1A8W0@;&ES="!<(B5S7"(N(@IM<V=S='(@(EEH=&5Y<W1I971O;&ES=&%N
M(%PB)7-<(B!L=6]N=&D@;VYN:7-T=6DN(@H*(SH@8G)O=W-E+G!H<#HX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"`E9"!C
M;VYT86-T*',I+B(*;7-G<W1R(")/;FYI<W1U='1I:6X@<&]I<W1A;6%A;B`E
M9"!Y:'1E>7-T:65T;V$N(@H*(SH@8G)O=W-E+G!H<#HV-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"`E9"!C;VYT86-T*',I
M(&9R;VT@;&ES="XB"FUS9W-T<B`B3VYN:7-T=71T:6EN('!O:7-T86UA86X@
M)60@>6AT97ES=&EE=&]A(&QI<W1A;'1A+B(*"B,Z(&1A=&$N<&AP.C4P"FUS
M9VED(")44U8B"FUS9W-T<B`B5%-6(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHQ-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$T"FUS9VED
M(")486(@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")486)U;&%A='1O<F5I
M;BA404(I(&5R;W1E='5T(&%R=F]T(@H*(SH@=FEE=RYP:'`Z,34*;7-G:60@
M(E1H92!61E,@8F%C:V5N9"!N965D<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N
M86)L92!A='1A8VAM96YT('5P;&]A9',N(@IM<V=S='(@(B(*(E9&4RUT875S
M=&%JY')J97-T96QMY"!P:73DY"!O;&QA(&OD>71E='3D=FES<^0@96YN96X@
M:W5I;B!L:6ET=&5I=.0@=F]I("(*(G1U;V1A+B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D]S;VET96MI<FIA
M82!<(B5S7"(@96D@;VQE(&]L96UA<W-A+B(*"B,Z(&%D9')E<W-B;V]K<RYP
M:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<
M(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")/<V]I
M=&5K:7)J86X@7"(E<UPB(&QU;VYT:2!O;FYI<W1U:2XB"@HC.B!A9&1R97-S
M8F]O:W,N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S
M(&)O;VL@7"(E<UPB('=A<R!R96UO=F5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B3W-O:71E:VER:F%N(%PB)7-<(B!P;VES=&\@;VYN:7-T=6DN(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T960N
M(@IM<V=S='(@(D]S;VET96MI<FIA;B!<(B5S7"(@;75O:VMA=7,@;VYN:7-T
M=6DN(@H*(SH@9&%T82YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T
M<B`B3W-O:71E:VER:F%A(&5I('9O:71U('1Y:&IE;G3DY#H@)7,B"@HC.B!D
M:7-P;&%Y+G!H<#HR,R!E9&ET+G!H<#HU,2!V8V%R9"YP:'`Z,C(@=FEE=RYP
M:'`Z,C8*;7-G:60@(E1H92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(E!Y>73D;>3D<VD@>6AT97ES=&EE=&]A(&5I
M(&]L92!O;&5M87-S82XB"@HC.B!E9&ET+G!H<#HQ,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")4:65D;W-T;VX@7"(E<UPB('!O:7-T;R!O
M;FYI<W1U:2XB"@HC.B!D871A+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@
M8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R
M(")4=6]N;FEN('9O:2!S=6]R:71T86$@;&]P<'5U;B!V86EK:V$@='5L:7-I
M('9A<F]I='5K<VEA+B(*"B,Z(&)R;W=S92YP:'`Z,S$*;7-G:60@(E1H97)E
M(&%R92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@(D]S
M;VET96MI<FIO:F$@96D@=F]I('-E;&%T82XB"@HC.B!A9&0N<&AP.C(Y"FUS
M9VED("(B"B)4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N
M($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS("(*(F%R92!C
M;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@
M=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R`B"B)I<R!A;B!E<G)O<BP@<&QE
M87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B(@HB3W-O:71E:VER:F]I:&EN(&5I('9O:2!K:7)J;VET=&%A+B!+Y'ET
M971TY'9I<W/D(&]L979A="!O<V]I=&5K:7)J870@96EVY'0@(@HB<V%L;&D@
M<VEN=6X@;&ESY'3D(&YI:6AI;B!U=7-I82!O<V]I='1E:71A+B!*;W,@97#D
M:6QE="!V:7)H971I;&%N;F5T=&$L("(*(FYI:6X@;W1A('EH=&5Y<R!JY')J
M97-T96QMY&X@>6QLY'!I=.1JY.1N+B(*"B,Z(&%D9"YP:'`Z,3(Q"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N97<@8V]N=&%C
M="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R("(*(F9O<B!F
M=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(E1A<&%H='5I('9I<FAE('5U<VEE
M;B!Y:'1E>7-T:65T;VIE;B!L:7/DY&UI<V5S<^0N($]T82!Y:'1E>71TY"!J
MY')J97-T96QMY&X@(@HB>6QLY'!I=.1JY.1N+B(*"B,Z(&)R;W=S92YP:'`Z
M,C<Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@
M;&ES="XB"FUS9W-T<B`B5&%P86AT=6D@=FER:&4@=&5H=.1E<W/D('5U='1A
M(&QI<W1A82XB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D
M9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B5&%P86AT=6D@=FER:&4@;'5O=&%E
M<W-A(&]S;VET96MI<FIA83H@)7,B"@HC.B!B<F]W<V4N<&AP.C$V-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M7"(E<UPB(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(B(*(E1A<&%H='5I('9I<FAE('!O:7-T971T865S<V$@7"(E<UPB(&SD:'1E
M96[D(&OD>71E='ES=.0@;W-O:71E:VER:F%S=&$N(@H*(SH@9&5L971E+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G<W1R(")487!A:'1U:2!V
M:7)H92!P;VES=&5T=&%E<W-A('3D=.0@>6AT97ES=&EE=&]A.B`E<R(*"B,Z
M(&)R;W=S92YP:'`Z,S$Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R(")487!A:'1U:2!V:7)H92!NY'ET
M971TY&5S<^0@;&ES=&%A(@H*(SH@9&%T82YP:'`Z,S,U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A
M=&$Z("5S(@IM<V=S='(@(E1A<&%H='5I('9I<FAE('1U;W1A97-S82!T:65T
M;V$Z("5S(@H*(SH@;&EB+V%P:2YP:'`Z-3`Y(&QI8B]A<&DN<&AP.C<W.0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<BUT:65T;VIE;B!T=6]N;FES
M<V$@=&%P86AT=6D@=FER:&4N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HU."!A
M9&1R97-S8F]O:W,N<&AP.C8S(&%D9')E<W-B;V]K<RYP:'`Z-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H
M:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")487!A:'1U:2!V:7)H92!P
M;VES=&5T=&%E<W-A('3D=.0@;W-O:71E:VER:F%A.B`E<RXB"@HC.B!A9&1R
M97-S8F]O:W,N<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS
M9W-T<B`B5&%P86AT=6D@=FER:&4@<.1I=FET971TY&5S<^0@=.1TY"!O<V]I
M=&5K:7)J86$Z("5S(@H*(SH@961I="YP:'`Z,38U"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y
M.B`E<R(*;7-G<W1R(")4Y&WD;B!M97)K:6YNY&X@<.1I=FET>6MS97-SY"!T
M87!A:'1U:2!V:7)H93H@)7,N(@H*(SH@9&%T82YP:'`Z,3<Y"FUS9VED(")4
M:&5R92!W97)E(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N(@IM<V=S='(@(D5I
M(&]L92!Y:'3DY&X@=FEE=.1VY.0@;W-O:71E='1A+B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S
M92!A9&1R97-S(&)O;VMS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*
M;7-G<W1R(").Y&WD(&]S;VET96MI<FIA="!NY'ET973DY&X@=.1S<^0@:N1R
M:F5S='EK<V5S<^0Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C
M="YI;F,Z,C0S"FUS9VED(")4:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA>2!I
M;B!T:&ES(&]R9&5R.B(*;7-G<W1R(").Y&WD('-A<F%K:V5E="!NY'ET973D
MY&X@=.1S<^0@:N1R:F5S='EK<V5S<^0Z(@H*(SH@9&%T82YP:'`Z,C8Y"FUS
M9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S
M='(@(E3D;>0@=&EE9&]S=&]M=6]T;R!E:2!O;&4@='5E='1U+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$Q-3,@;&EB+V%P:2YP:'`Z,3$V-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&ES('!E<G-O;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN
M('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B5.1L;.0@:&5N:VEL]FQLY"!O
M;B!J;R`E<R!M97)K:6YTY"!O<V]I=&5K:7)J87-S82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#@*;7-G:60@(B(*(E1H:7,@=VEL;"!B92!T:&4@
M9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG
M(&-O;G1A8W1S+B(*;7-G<W1R(")4Y&WD(&]N(&]L971U<V]S;VET96MI<FIA
M(&MU;B!L:7/D=.3D;B!T86D@='5O9&%A;B!Y:'1E>7-T:65T;VIA+B(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<P"FUS9VED(")4:71L92(*
M;7-G<W1R(")4:71T96QI(@H*(SH@;&EB+U1U<F)A+G!H<#HT-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N($UI
M<W-I;F<@<V]U<F-E('1Y<&4N(@IM<V=S='(@(D5I('9O:2!L=6]D82!U=71T
M82!J86MO82X@3.1H=&5E;B!T>7EP<&D@<'5U='1U=2XB"@HC.B!L:6(O1')I
M=F5R+G!H<#HQ,#`T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")-Y.1R:71Y:W-E
M;B`E<R!L=6ME;6EN96X@97#D;VYN:7-T=6DN(@H*(SH@961I="YP:'`Z.34@
M961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D:70N<&AP.C$P-B!E9&ET+G!H
M<#HR,#,*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")097)U(&UU=71O
M:W-E="(*"B,Z(&QI8B]A<&DN<&AP.C4T,B!L:6(O87!I+G!H<#HV-C$@;&EB
M+V%P:2YP:'`Z-SDW"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D
M($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B16D@='5E='1U($-O;G1E;G0M
M5'EP93H@)7,B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HS-S8*;7-G
M:60@(E9E<FES:6=N($1I<F5C=&]R>2(*;7-G<W1R(")697)I<VEG;B!H86ME
M;6ES=&\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(W
M('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W(%PB)7-<(B(*;7-G<W1R(").Y'ETY"!<(B5S7"(B"@HC.B!M
M:6YI<V5A<F-H+G!H<#HW-@IM<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@
M(D[D>73D('EH=&5Y<W1I961O="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(E9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G
M<W1R(")/;&5T=6MS96YA(&OD>71E='3D=N0@;N1K>6WD.B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB
M"FUS9W-T<B`B5V5B<VET92!54DPB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HQ,3,*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")/<V]I
M=&4@*'1Y]BDB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*
M;7-G:60@(E=O<FL@0VET>2(*;7-G<W1R(")+875P=6YK:2`H='GV*2(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S.0IM<V=I9"`B5V]R:R!#
M;W5N=')Y(@IM<V=S='(@(DUA82`H='GV*2(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$U-@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")0
M=6AE;&EN("AT>?8I(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3,T"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S='(@(E!O<W1I;G5M
M97)O("AT>?8I(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(Y
M"FUS9VED(")7;W)K(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(DSDY&YI('1A
M:2!A;'5E("AT>?8I(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3$Y"FUS9VED(")7;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(DMA='5O
M<V]I=&4@*'1Y]BDB"@HC.B!B<F]W<V4N<&AP.C$P-B!B<F]W<V4N<&AP.C(R
M-R!A9&0N<&AP.C<S(&1A=&$N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8V]N=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VD@;'5O9&$@:W5I
M;B!E;FEN=.3D;B`E9"!Y:'1E>7-T:65T;V$@7"(E<UPB.F5E;BXB"@HC.B!D
M:7-P;&%Y+G!H<#HU."!E9&ET+G!H<#HW,R!V:65W+G!H<#HS-@IM<V=I9"`B
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A
M8W0N(@IM<V=S='(@(E-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!NY&ADY"!T
MY'3D('EH=&5Y<W1I971O82XB"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N
M(@IM<V=S='(@(E-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!NY&ADY"!TY&WD
M;B!O8FIE:W1I;B!T:65T;VIA+B(*"B,Z(&QI8B]4=7)B82YP:'`Z-3,Y"FUS
M9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;G,@=&\@9&5L971E('1H
M:7,@<V]U<F-E+B(*;7-G<W1R(")3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@
M<&]I<W1A82!TY'3D(&SD:&1E='3D+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z-34*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A
M<F=E="!A9&1R97-S(&)O;VLN(@IM<V=S='(@(E-I;G5N('!I=.3D(&5N<VEN
M('9A;&ET82!K;VAD96]S;VET96MI<FIA+B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z,C,*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M('1A<F=E="!L:7-T+B(*;7-G<W1R(")3:6YU;B!P:73DY"!E;G-I;B!V86QI
M=&$@:V]H9&5L:7-T82XB"@HC.B!E9&ET+G!H<#HS,@IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+B(*;7-G<W1R
M(")3:6YU;B!P:73DY"!E;G-I;B!V86QI=&$@86EN86MI;B!Y:W-I('EH=&5Y
M<W1I971O+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z
M,3<@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP
M;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S
M="!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R(")3
M:6YU;B!P:73DY"!E;G-I;B!V86QI=&$@86EN86MI;B!Y:W-I('1I971U92XB
M"@HC.B!E9&ET+G!H<#HW-PIM<V=I9"`B66]U(&]N;'D@:&%V92!P97)M:7-S
M:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R(")3:6YU;&QA(&]N
M(&]I:V5U9&5T('9A:6X@:V%T<V]A('3D=.0@>6AT97ES=&EE=&]A+B(*"B,Z
M(&)R;W=S92YP:'`Z,S$X"FUS9VED(")9;W5R(&1E9F%U;'0@861D<F5S<R!B
M;V]K(&ES(&YO="!B<F]W<V5A8FQE+B(*;7-G<W1R(")/;&5T=7-O<V]I=&5K
M:7)J87-I(&5I(&]L92!S96QA='1A=FES<V$N(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]C;VYT86-T<F]W+FEN8SHQ,B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z-@IM<V=I9"`B6VYO('9A;'5E72(*;7-G<W1R(");96D@87)V;V%=(@H*
M(SH@;&EB+U1U<F)A+G!H<#HU-C(*;7-G:60@(E]"<F]W<V4B"FUS9W-T<B`B
M7U-E;&%A(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-PIM
M<V=I9"`B7T-O;G1A8W1S(@IM<V=S='(@(E]9:'1E>7-T:65D;W0B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*;7-G:60@(E]$96QE=&4B
M"FUS9W-T<B`B7U!O:7-T82(*"B,Z(&QI8B]4=7)B82YP:'`Z-3<Q"FUS9VED
M(")?26UP;W)T+T5X<&]R="(*;7-G<W1R(")?5'5O+U9I92(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#8*;7-G:60@(E],:7-T<R(*;7-G
M<W1R(")?3&ES=&%T(@H*(SH@;&EB+U1U<F)A+G!H<#HU-3D*;7-G:60@(E]-
M>2!!9&1R97-S($)O;VMS(@IM<V=S='(@(D]?;6%T(&]S;VET96MI<FIA="(*
M"B,Z(&QI8B]4=7)B82YP:'`Z-38U"FUS9VED(")?3F5W($-O;G1A8W0B"FUS
M9W-T<B`B7U5U<VD@>6AT97ES=&EE=&\B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C,*;7-G:60@(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B
M"FUS9W-T<B`B7U!O:7-T82!TY&QTY"!L:7-T86QT82(*"B,Z(&QI8B]4=7)B
M82YP:'`Z-38W"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E](86MU(@H*(SH@
M=F-A<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R(")C;VYT
M86-T<RYV8V8B"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM
M<V=S='(@(F-O;G1A8W1S+F-S=B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B
M8V]N=&%C=',N='-V(@IM<V=S='(@(F-O;G1A8W1S+F-S=B(*"B,Z(&1A=&$N
M<&AP.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(F-O;G1A8W1S
M+G9C9B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S@*;7-G:60@(FYO
M(&9O<FUA='1I;F<B"FUS9W-T<B`B96D@;75O=&]I;'5A(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VEM<W!?;W!T+FEN8SHS,@IM<V=I9"`B;F]N92(*;7-G<W1R
M(")%:2!M:73DY&XB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C,Q"FUS9VED(")T;R!A($-O;G1A8W0@3&ES="(*;7-G<W1R(")Y:'1E>7-T
M:65T;VQI<W1A86XB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C(Q"FUS9VED(")T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B97)I(&]S;VET96MI<FIA86XB"@HC.B!D871A+G!H<#HU,2!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$U('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,34*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z
M,3,*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+V5T
M7T5%+G!O````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-S`U,C4`,3`T,3<S-C(W-38`,#$W-3$Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@5%520D$@15-43TY)04X@5%)!
M3E-,051)3TXN"B,@5&]O;6%S($%A<R`\=&]O;6%S+F%A<T!M86EL+F5E/BP@
M,C`P,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO
M;CH@5'5R8F$@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M
M,#8M,#(@,3`Z-#DK,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!4;V]M87,@
M06%S(#QT;V]M87,N86%S0&UA:6PN964^7&XB"B),86YG=6%G92U496%M.B!%
M<W1O;FEA;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M25-/+3@X-3DM,3-<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M
M8FET7&XB"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C0R"FUS
M9VED("(@061D(&%N($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S$*;7-G:60@(B!$96QE
M=&4@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M,S(U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!A;')E861Y(&5X:7-T
M<R!A;F0@=V%S(&YO="!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E
M+G!H<#HQ,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@
M8V]P:65D(&)E8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!B
M<F]W<V4N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&YO="!M;W9E9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA
M;64@3&%S=&YA;65<(B`@*&EE+B!*;VAN($1O92DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@
M1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(B(*"B,Z(&%D
M9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%D9&5D+B(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B)7,@9F%I
M;&D@:6UP;W)T(/5N;F5S='5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT-#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D%A
M9')E<W-I<F%A;6%T=2!I;7!O<G0B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C
M:"YP:'`Z-#4*;7-G:60@(D$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M
M97,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U.0IM<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T<B`B
M(@H*(SH@=FEE=RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S
M(&1E;FEE9"!T;R`E<R(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C4V('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D%D9"(*;7-G<W1R
M("),:7-A(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T
M+FEN8SHQ-S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B5FEG86YE(&%A9')E<W-I<F%A;6%T+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.`HC+"!F=7IZ>0IM<V=I9"`B061D(&%N9"!$96QE=&4@
M24U34"!A9&1R97-S(&)O;VMS(@IM<V=S='(@(MQK<VMI(&%A9')E<W-I<F%A
M;6%T(&5I(&QU8F$@<V%L=F5S=&%M:7-T(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-O;'5M;G-E;&5C="YI;F,Z,C,W"B,L(&9U>GIY"FUS9VED(")!9&0@8V]L
M=6UN(@IM<V=S='(@(FQI<V$@=F5E<F<B"@HC.B!E9&ET+G!H<#HQ,C@*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!F:6QE(@IM<V=S='(@(DQI<V%M:6YE(&5B8?5N
M;F5S='5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR,@HC
M+"!F=7IZ>0IM<V=I9"`B061D('1O(@IM<V=S='(@(DQI<V$B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(D%A9')E<W-I<F%A;6%T=2!I;7!O<G0B"@HC
M.B!B<F]W<V4N<&AP.C(X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(RP@
M9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:R!,:7-T:6YG(@IM<V=S='(@(D%A
M9')E<W-I<F%A;6%T=6P@;VX@:VER:G5T=7-K86ET<V4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O
M:W,B"FUS9W-T<B`B06%D<F5S<VER86%M871U(&EM<&]R="(*"B,Z(&%D9"YP
M:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(&)O;VL@96YT<GDB"FUS
M9W-T<B`B06%D<F5S<VER86%M871U;"!O;B!K:7)J=71U<VMA:71S92(*"B,Z
M(&1A=&$N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K('-U
M8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(B5S(&9A:6QI(&EM<&]R="#U
M;FYE<W1U<R(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8R"B,L
M(&9U>GIY"FUS9VED(")!9&1R97-S(&)O;VL@=&\@9&5L971E("(*;7-G<W1R
M(")!861R97-S:7)A86UA='5L(&]N(&MI<FIU='5S:V%I='-E(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S`*;7-G:60@
M(D%D9')E<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM
M<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z.#@@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.C,W"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS9W-T<B`B
M4/5H:F%L:6L@;W1S:6YG(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z-C0*;7-G:60@(D%L:6%S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C4U
M,@IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@)7,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI
M;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E
M;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T
M<B`B(@H*(SH@<V5A<F-H+G!H<#HX-2!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R
M(")/='-I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED
M(")"96QO=R!S96%R8V@@9F]R;2(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C<W(&QI8B]$<FEV97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T
M:&1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I
M9"`B0G)O=W-E(@IM<V=S='(@(E-I<G9I(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3<S"FUS9VED(")"=7-I;F5S<R!#871E9V]R>2(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HT.0IM<V=I9"`B0U-6(@IM<V=S='(@(B(*
M"B,Z(&QI8B]/8FIE8W0O1W)O=7`N<&AP.C4W"FUS9VED(")#86XG="!A9&0@
M82!G<F]U<"!T;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C<*;7-G:60@(D-H96-K(%]!;&PO
M3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHT-`IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G<W1R("(B"@HC.B!A9&0N
M<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@861D<F5S<R!B;V]K
M(@IM<V=S='(@(E9I9V%N92!A861R97-S:7)A86UA="XB"@HC.B!T96UP;&%T
M97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C$*(RP@9G5Z>GD*;7-G:60@
M(D-H;V]S92!A;B!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(E9I9V%N92!A861R
M97-S:7)A86UA="XB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS
M96QE8W0N:6YC.C$V-0IM<V=I9"`B0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O
M:W,@=&\@9&ES<&QA>2P@86YD(&EN('=H870@;W)D97(Z(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B0VAO;W-E('=H
M:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C@*(RP@9G5Z>GD*;7-G
M:60@(D-H;V]S92!W:&EC:"!C;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H
M870@;W)D97(Z(@IM<V=S='(@(E9A;&D@=F5E<F=U9&4@:N1R:F5S='5S(&%A
M9')E<W-I9&4@;FEM96MI<FIA<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3<*;7-G:60@(D-O;'5M;B!/<'1I;VYS(@IM<V=S='(@(E9E97)U('-E
M861E9"(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S
M,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,R!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")#;VUM82!S97!A
M<F%T960@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,@*$UI
M8W)O<V]F="!/=71L;V]K*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M
M82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`HC+"!F=7IZ
M>0IM<V=I9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S='(@(DMO9'5N92!A861R
M97-S(@H*(SH@;&EB+V%P:2YP:'`Z,S$X(&QI8B]A<&DN<&AP.C,V,R!L:6(O
M87!I+G!H<#HT,#<@;&EB+V%P:2YP:'`Z-#DQ"B,Z(&QI8B]A<&DN<&AP.C8P
M,2!L:6(O87!I+G!H<#HV.#@@;&EB+V%P:2YP:'`Z-S0Q(&QI8B]A<&DN<&AP
M.C@Q.0HC.B!L:6(O87!I+G!H<#HQ,#`V(&QI8B]A<&DN<&AP.C$P.30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R(")+=7-T=71A;6EN92!E8F'U;FYE<W1U<R(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;'5R92(*;7-G<W1R(")+=7-T=71A;6EN92!E8F'U;FYE<W1U<R(*"B,Z
M(&)R;W=S92YP:'`Z,3DQ(&)R;W=S92YP:'`Z,C,R"FUS9VED(")#;VYT86-T
M(&%D9&5D('1O(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z-C`*
M;7-G:60@(D-O;G1A8W0@<F5M;W9E9"!F<F]M(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&)R;W=S92YP:'`Z,C8V"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1A
M8W1S(&EN(&QI<W0Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T
M<B`B1FER;6$B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU,PIM
M<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S
M8F]O:W,N:6YC.C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@061D<F5S<R!"
M;V]K(@IM<V=S='(@(D%A9')E<W-I<F%A;6%T=2!E:W-P;W)T(@H*(SH@;&EB
M+TQI<W16:65W+G!H<#HS,34*;7-G:60@(D-R96%T92!A(&YE=R!#;VYT86-T
M($QI<W0@:6XZ(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ
M,S,*;7-G:60@(D-R96%T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDX"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHW
M-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*(SH@;&EB+T]B:F5C
M="YP:'`Z,S(X(&QI8B]296YD97)E<BYP:'`Z-#<@;&EB+U)E;F1E<F5R+G!H
M<#HU,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(DMU<W1U=&$B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B1&5L
M971E($%D9')E<W,@0F]O:R(*;7-G<W1R(")!861R97-S:7)A86UA='4@96MS
M<&]R="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1&5L
M971E($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C<P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D.B`H)7,I("5S(@IM
M<V=S='(@(DMU<W1U=&%M:6YE(&5B8?5N;F5S='5S(@H*(SH@9&5L971E+G!H
M<#HS.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S='(@(DMU<W1U=&%M
M:6YE(&5B8?5N;F5S='5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*(RP@9G5Z
M>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(DMA<W5T86IA('-E861E
M9"(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3@*;7-G:60@
M(D1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]O9R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R
M(").Y&ET82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`B3N1I=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3<V"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N
M=')I97,_(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W0N<&AP.C(Y-PIM<V=I
M9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R
M;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C4*
M;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C$P,B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z,C4*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z
M,3`@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"B,Z('1E;7!L871E
M<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,@;&EB+U)E;F1E<F5R+G!H<#HT
M,@IM<V=I9"`B161I="(*;7-G<W1R(")087)A;F1A(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]R;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O
M=RYI;F,Z,S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E
M<UPB(@IM<V=S='(@(E!A<F%N9&$@)R5S)R(*"B,Z('1E;7!L871E<R]A9&1R
M97-S8F]O:W,N:6YC.C@Q"B,L(&9U>GIY"FUS9VED(")%9&ET($%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`B06%D<F5S<VER86%M871U(&5K<W!O<G0B"@HC.B!E
M9&ET+G!H<#HW."!E9&ET+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!E;G1R>2!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M;6%I
M;"(*"B,Z(&5D:70N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R
M>2!F;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D960@9FEL
M92!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$T.2!E9&ET
M+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P
M9&%T960N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z-S0*(RP@9G5Z>GD*
M;7-G:60@(D5N=')Y('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("(E
M<R!F86EL:2!I;7!O<G0@]6YN97-T=7,B"@HC.B!L:6(O87!I+G!H<#HT,3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E87)C:&EN9R!T
M:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+<:W-K:2!A861R97-S:7)A
M86UA="!E:2!L=6)A('-A;'9E<W1A;6ES="(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z-B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C0Q
M"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B16MS<&]R="(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B17AP;W)T($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")!861R97-S:7)A86UA='4@96MS<&]R="(*
M"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D5X<&]R
M="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP;W)T('1H
M92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM<V=S='(@
M(B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H<#HR,C@@9&%T82YP:'`Z,CDW
M(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY,`HC.B!B<F]W<V4N<&AP.C$Q
M,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@
M)7,B"FUS9W-T<B`B3W1S:6YG(&MA=&%L;V]G:7-T("5S(&5B8?5N;F5S='5S
M(@H*(SH@8G)O=W-E+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S(@IM<V=S='(@(D]T<VEN
M9R!K871A;&]O9VES="`E<R!E8F'U;FYE<W1U<R(*"B,Z(&)R;W=S92YP:'`Z
M,C<R"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8G)O=W-E(&QI<W0B"FUS
M9W-T<B`B2V%T86QO;V=I("5S('-I<G9I;6EN92!E8F'U;FYE<W1U<R(*"B,Z
M(&)R;W=S92YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8G)O
M=W-E('1H92!D:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO;V=I("5S('-I<G9I
M;6EN92!E8F'U;FYE<W1U<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C:&%N9V4@;F%M93H@
M*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T(#T@)7,B
M"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E
M9#H@)7,B"FUS9W-T<B`B3W1S:6YG(&MA=&%L;V]G:7-T("5S(&5B8?5N;F5S
M='5S(@H*(SH@<V5A<F-H+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D
M('1O('-E87)C:"!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(D]T<VEN9R!K
M871A;&]O9VES="`E<R!E8F'U;FYE<W1U<R(*"B,Z(&1A=&$N<&AP.C$T.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H92!D:7)E
M8W1O<GDZ("5S(@IM<V=S='(@(D]T<VEN9R!K871A;&]O9VES="`E<R!E8F'U
M;FYE<W1U<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM
M<V=I9"`B1F%X(@IM<V=S='(@(D9A:W,B"@HC.B!E9&ET+G!H<#HQ,C0@9&ES
M<&QA>2YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")&:6QE<R(*;7-G<W1R(")!
M;65T(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<P"FUS9VED
M(")&:6YD(@IM<V=S='(@(DQE:6$B"@HC.B!E9&ET+G!H<#HY-R!E9&ET+G!H
M<#HQ.#<*(RP@9G5Z>GD*;7-G:60@(D9I;FES:"(*;7-G<W1R("),96EA(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T
M($YA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@S"FUS9VED(")&<F]M(@IM<V=S
M='(@(DME;&QE;'0B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HV,#0*
M(RP@9G5Z>GD*;7-G:60@(D=L;V)A;"!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M06%D<F5S<VER86%M871U(&5K<W!O<G0B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT
M-`IM<V=I9"`B1W)O=7`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")+
M;V1U;F4@86%D<F5S<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.CDS"FUS9VED(")(;VUE($-I='DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3`X"B,L(&9U>GIY"FUS9VED(")(;VUE($-O
M=6YT<GDB"FUS9W-T<B`B2V]D=6YE('1E;&5F;VXB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T
M<B`B2V]D=6YE('1E;&5F;VXB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DAO;64@4&]S=&%L($-O9&4B"FUS
M9W-T<B`B2V]D=6YE('1E;&5F;VXB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC
M92(*;7-G<W1R(")+;V1U;F4@=&5L969O;B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C@X"B,L(&9U>GIY"FUS9VED(")(;VUE(%-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(DMO9'5N92!A861R97-S(@H*(SH@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z-3`V"FUS9VED("))35-0(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-PIM<V=I9"`B24U34"!!9&1R97-S
M($)O;VL@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0@061D<F5S<R!";V]K+"!3=&5P("5D(@IM<V=S='(@(D%A9')E
M<W-I<F%A;6%T=2!I;7!O<G0B"@HC.B!D871A+G!H<#HS-C$*(RP@9G5Z>GD*
M;7-G:60@(DEM<&]R="]%>'!O<G0@061D<F5S<R!";V]K<R(*;7-G<W1R(")!
M861R97-S:7)A86UA='5T92!I;7!O<G0O96MS<&]R="(*"B,Z(&QI8B]A<&DN
M<&AP.C4Y-B!L:6(O87!I+G!H<#HV.#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@240B"FUS9W-T<B`B5FEG86YE(&YI;6DN(@H*(SH@;&EB+V%P:2YP:'`Z
M,C,P(&QI8B]A<&DN<&AP.C0P,B!L:6(O87!I+G!H<#HT.#8@;&EB+V%P:2YP
M:'`Z-3DR"B,Z(&QI8B]A<&DN<&AP.C8W.2!L:6(O87!I+G!H<#HW,S$@;&EB
M+V%P:2YP:'`Z,3`W-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B5FEG86YE(&%A9')E<W-I<F%A;6%T+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$P.#$@;&EB+V%P:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ
M,C`W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(E9I
M9V%N92!E+6UA:6QI(&%A9')E<W,N(@H*(SH@;&EB+V%P:2YP:'`Z,3`X.0HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!E;G1R>2(*;7-G<W1R(")6:6=A;F4@
M;FEM:2XB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(V-@IM<V=I9"`B26YV
M86QI9"!K97D@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ,#@U"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&YA;64B"FUS9W-T<B`B
M5FEG86YE(&YI;6DN(@H*(SH@;&EB+V%P:2YP:'`Z-S,U"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(&]B:F5C=$ED(@IM<V=S='(@(E9I9V%N92!N:6UI+B(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P
M<&]R="!I<R!R97%U:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A
M=F%I;&%B;&4@;W(@;F]T(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T]B
M:F5C=%9I97<N<&AP.C$S.`IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PHC+"!F=7IZ
M>0IM<V=I9"`B3&%S="!.86UE(@IM<V=S='(@(DYI;6DB"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ-@IM<V=I9"`B3&ES="(*
M;7-G<W1R(").:6UE:VER:2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H
M+FEN8SHW-PIM<V=I9"`B36%T8VAI;F<B"FUS9W-T<B`B(&UI<R!S:7-A;&1A
M8B`B"@HC.B!L:6(O87!I+G!H<#HR,#4*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F($-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C,*(RP@9G5Z>GD*
M;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R(").:6UE:VER:2(*"B,Z(&QI8B]"
M;&]C:R]M:6YI<V5A<F-H+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-:6YI(%-E
M87)C:"(*;7-G<W1R(")/='-I;F<B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C,P,@IM<V=I9"`B36ES<VEN9R!$3B!I;B!,1$%0('-O=7)C92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ-C(*(RP@9G5Z>GD*;7-G:60@(DUO8FEL92!0:&]N92(*;7-G<W1R
M(")+;V1U;F4@=&5L969O;B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S,R
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@
M(DUO9&EF>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,3$Y,PIM<V=I9"`B36]R92!T:&%N(#$@96YT<GD@9F]U;F0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,0IM
M<V=I9"`B36]V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L
M=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B
M;V]K<V5L96-T+FEN8SHQ.#0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@;&5F="(*
M;7-G<W1R(")T]7-T82!V87-A:W5L92(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(T.0HC.B!T96UP;&%T97,O<')E9G,O861D<F5S
M<V)O;VMS96QE8W0N:6YC.C$X-@HC+"!F=7IZ>0IM<V=I9"`B36]V92!R:6=H
M="(*;7-G<W1R(")T]7-T82!P87)E;6%L92(*"B,Z(&1A=&$N<&AP.C4R('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUU
M;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G<W1R(")!861R97-S:7)A86UA='4@
M96MS<&]R="(*"B,Z(&QI8B]A<&DN<&AP.C$Q,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB375L=&EP;&4@<&5R<V]N<R!W:71H(&%D9')E<W,@6R5S72P@
M8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@86QR96%D>2!E>&ES="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ,#<@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z,C0S"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B06%D<F5S<VER86%M871U(&EM<&]R="(*"B,Z(&%D
M9')E<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S
M($)O;VMS(@IM<V=S='(@(D%A9')E<W-I<F%A;6%T=2!E:W-P;W)T(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`W(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C0R"FUS9VED(").86UE(@IM<V=S='(@(DYI;6DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM
M<V=I9"`B3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C
M:"YP:'`Z,C<*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(DYE=R!#;VYT86-T(@IM<V=S='(@(DQI<V$@=75S(&%A9')E
M<W,B"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY-2!E9&ET+G!H<#HR,#(@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT-0IM<V=I9"`B3F5X="(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*(RP@
M9G5Z>GD*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(DYI;6DB"@HC.B!L:6(O
M87!I+G!H<#HQ,3DU(&QI8B]A<&DN<&AP.C$R-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$Q-C,*(RP@9G5Z>GD*;7-G:60@(DYO(&%D9')E<W,@
M8F]O:W,@9F]U;F0N(@IM<V=S='(@(D%A9')E<W-I<F%A;6%T=6P@;VX@:VER
M:G5T=7-K86ET<V4B"@HC.B!M:6YI<V5A<F-H+G!H<#HX,PIM<V=I9"`B3F\@
M8V]N=&%C=',@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-3$Q
M(&QI8B]A<&DN<&AP.C<V-@IM<V=I9"`B3F\@=D-A<F0@9&%T82!W87,@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN
M8SHW"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(DWD<FMM960B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S
M(@IM<V=S='(@(DWD<FMM960B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$U"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<T-PIM<V=I9"`B
M3V)J96-T(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HR,C,*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(S"FUS9VED("(B"B)/
M;F-E('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H92!A9&1R97-S(&)O
M;VL@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B!)9B!T:&ES(&ES
M(&YO="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T(&-H86YG92!Y;W5R
M('-E;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z-S<T"FUS9VED(")/;FQY(&]N92!V8V%R9"!S=7!P;W)T960N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#8*(RP@9G5Z>GD*;7-G:60@(D]T:&5R($]P
M=&EO;G,B"FUS9W-T<B`B2V%S=71A:F$@<V5A9&5D(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3DP"FUS9VED(")01U`@4'5B;&EC($ME>2(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HT.34@;&EB+V%P:2YP:'`Z-C`U
M(&QI8B]A<&DN<&AP.C8Y,B!L:6(O87!I+G!H<#HY,S0*(SH@;&EB+V%P:2YP
M:'`Z,3`Y.`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z-30S"FUS9VED(")097)M:7-S:6]N(&1E;FEE
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY
M.0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M-3,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I
M9"`B4&EN92!!9&1R97-S($)O;VLB"FUS9W-T<B`B06%D<F5S<VER86%M871U
M(&EM<&]R="(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z
M,C@*;7-G:60@(E!L96%S92!N86UE('1H92!N97<@8V]N=&%C="!L:7-T.B(*
M;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H
M<#HQ.30*;7-G:60@(E!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S
M;W5R8V5S+G!H<"YD:7-T.C0Q-@HC+"!F=7IZ>0IM<V=I9"`B4')I=F%T92!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B06%D<F5S<VER86%M871U(&5K<W!O<G0B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")1=65R>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"B,L(&9U>GIY"FUS9VED
M(")1=6EC:R!396%R8V@B"FUS9W-T<B`B3W1S:6YG(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HQ.3$@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3D@;&EB+T1R
M:79E<B]L9&%P+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A9"!F
M86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+U)E;F1E<F5R+G!H
M<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED
M(")296-O<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S8*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B06%D<F5S<VER86%M
M871U(&EM<&]R="(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(S.0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M(")E96UA;&1A('9E97)G(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHR"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0IM<V=I9"`B(@HB
M4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@:6UP;W)T
M960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@
M96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R;VYG
M/B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G:60@(E)E
M<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&0N
M<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G:60@
M(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T
M:69I8V%T92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S*2`E
M<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY.2!A9&0N<&AP.C,W('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V92(*;7-G<W1R
M(")386QV97-T82(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY
M-B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$R"B,Z('1E;7!L871E
M<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU
M+G!H<#HT.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`B3W1S:6YG(@H*(SH@;6EN:7-E87)C:"YP:'`Z-C,*
M(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!297-U;'1S.B(*;7-G<W1R(")/='-I
M;F=U('1U;&5M=7,B"@HC.B!L:6(O87!I+G!H<#HQ,#$Q"B,L(&9U>GIY"FUS
M9VED(")396%R8V@@9F%I;&5D(@IM<V=S='(@(D]T<VEN9R(*"B,Z(&QI8B]A
M<&DN<&AP.C$Q,#,@;&EB+V%P:2YP:'`Z,3$P.2!L:6(O87!I+G!H<#HQ,3$X
M(&QI8B]A<&DN<&AP.C$Q,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI
M;FES96%R8V@N:6YC.C(R"B,L(&9U>GIY"FUS9VED(")396%R8VAI;F<N+BXB
M"FUS9W-T<B`B3W1S:6YG(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z-C8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@
M=&\@9&5L971E(@IM<V=S='(@(E!A;'5N('9A;&D@86%D<F5S<VER86%M870@
M:W5H=2!A861R97-S(&QI<V%D82XB"@HC.B!T96UP;&%T97,O861D<F5S<V)O
M;VMS+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@
M8F]O:R!T;R!E9&ET(@IM<V=S='(@(E!A;'5N('9A;&D@86%D<F5S<VER86%M
M870@:W5H=2!A861R97-S(&QI<V%D82XB"@HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&%D9')E
M<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T<B`B2W5S="!E:W-P;W)T
M:61A.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C8*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T
M;SHB"FUS9W-T<B`B2W5H=2!I;7!O<G1I9&$Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C
M:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B2W5S="!E:W-P
M;W)T:61A.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T
M<B`B2W5S="!E:W-P;W)T:61A.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z-#,*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM
M<V=S='(@(E9A;&D@:6UP;W)D:71A=B!F86EL.B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@
M9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B5F%L:2!E:W-P
M;W)D:2!F;W)M86%T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES
M<&QA>2!N86UE<SHB"FUS9W-T<B`B5F%L:2!I;7!O<F1I=&%V(&9O<FUA870Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U"FUS9VED(")396QE8W0@
M=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD
M('!A9VEN9R!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@*;7-G:60@(E-E;&5C="!W:&EC:"!F:65L9',@=&\@9&ES
M<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS9W-T<B`B5F%L:2!M:6QL
M:7-E:60@=N1L:G4@;N1I9&%T82!A861R97-S:61E(&YI;65K:7)J861E<RXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE<RXB"FUS9W-T
M<B`B5F%L:2!M:6QL:7-E:60@=N1L:G4@;N1I9&%T82!A861R97-S:61E(&YI
M;65K:7)J861E<RXB"@HC.B!A9&0N<&AP.C4T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")396QE8W1E9"!A9&1R97-S(&)O;VL@7"(E<UPB+B(*;7-G
M<W1R(")6:6=A;F4@86%D<F5S<VER86%M870N(@H*(SH@8V]N9FEG+W-O=7)C
M97,N<&AP+F1I<W0Z,3<S"B,L(&9U>GIY"FUS9VED(")3:&%R960@1&ER96-T
M;W)Y(@IM<V=S='(@(DMA=&%L;V]G(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHS.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*
M;7-G:60@(E-H;W<@06QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@(E-H;W<@0V]N=&%C=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0IM<V=I
M9"`B4VAO=R!,:7-T<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V-O;'5M;E]H96%D97)S+FEN8SHR,0HC.B!T96UP;&%T97,O8G)O=W-E+V-O
M;'5M;E]H96%D97)S+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B4V]R="!$:7)E
M8W1I;VXB"FUS9W-T<B`B2V%T86QO;V<B"@HC.B!L:6(O87!I+G!H<#HQ.3@*
M;7-G:60@(E-O=7)C97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U-PIM<V=I9"`B4W!E8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A
M;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N(@IM<V=S='(@(B(*"B,Z
M(&)R;W=S92YP:'`Z,30Q"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!A9&1E9"`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP
M.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8W)E871E
M9"!T:&4@8V]N=&%C="!L:7-T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z-3`*;7-G:60@(E135B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,30*;7-G:60@(E1A8B!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(B(*"B,Z
M('9I97<N<&AP.C$U"FUS9VED(")4:&4@5D93(&)A8VME;F0@;F5E9',@=&\@
M8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@871T86-H;65N="!U<&QO861S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#4T"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB('=A<R!C
M<F5A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@861D<F5S<V)O
M;VMS+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B
M;V]K(%PB)7-<(B!W87,@<F5M;W9E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!U
M<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@8F4@<'5R
M9V5D.B`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HT-R!V8V%R9"YP:'`Z
M,C(@9&ES<&QA>2YP:'`Z,C,@=FEE=RYP:'`Z,C8*;7-G:60@(E1H92!C;VYT
M86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*
M"B,Z(&5D:70N<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("(E<R!F86EL:2!I;7!O<G0@]6YN97-T=7,B"@HC.B!D871A
M+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@8V%N(&)E(&9I;FES:&5D(&1E
M<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP
M.C,Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A
M9&1R97-S(&)O;VMS+B(*;7-G<W1R("+<:W-K:2!A861R97-S:7)A86UA="!E
M:2!L=6)A('-A;'9E<W1A;6ES="(*"B,Z(&%D9"YP:'`Z,CD*(RP@9G5Z>GD*
M;7-G:60@(B(*(E1H97)E(&%R92!N;R!W<FET96%B;&4@861D<F5S<R!B;V]K
M<RX@3F]N92!O9B!T:&4@879A:6QA8FQE(&%D9')E<W,@8F]O:W,@(@HB87)E
M(&-O;F9I9W5R960@=&\@86QL;W<@>6]U('1O(&%D9"!N97<@96YT<FEE<R!T
M;R!T:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES("(*(FES(&%N(&5R<F]R+"!P
M;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"B+<:W-K:2!K87-U=&%T878@86%D<F5S<VER86%M870@96D@=O5I
M;6%L9&$@<W5L(&%A9')E<W-E(&QI<V%D82X@2W5I('-E92!O;B`B"B)S:6YU
M(&%R=F%T97,@=FEG82P@=O5T82#\:&5N9'5S="!S_'-T965M:2!A9&UI;FES
M=')A871O<FEG82XB"@HC.B!A9&0N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A8W0N
M($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B`B"B)F;W(@9G5R
M=&AE<B!H96QP+B(*;7-G<W1R("(B"B)396QL92!O8FIE:W1I(&QI<V%M:7-E
M;"!T96MK:7,@=FEG82X@06)I('-A86UI<V5K<R!V]71A(/QH96YD=7-T('/\
M<W1E96UI("(*(F%D;6EN:7-T<F%A=&]R:6=A+B(*"B,Z(&)R;W=S92YP:'`Z
M,3@Y(&)R;W=S92YP:'`Z,C,P"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@861D:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R(")!;F1M971E
M(&EM<&]R9&EL('1E:VMI<R!V:6=A+B(*"B,Z(&)R;W=S92YP:'`Z,C,X"B,L
M(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N
M97<@;&ES="XB"FUS9W-T<B`B06YD;65T92!I;7!O<F1I;"!T96MK:7,@=FEG
M82XB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A
M9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(DQA971U9"!F86EL:2!I;7!O<G1I
M;6ES96P@=&5K:VES('9I9V$B"@HC.B!B<F]W<V4N<&AP.C$T-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T
M:6YG(%PB)7-<(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("),865T=60@9F%I;&D@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A(@H*
M(SH@9&5L971E+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B
M"FUS9W-T<B`B06YD;65T92!I;7!O<F1I;"!T96MK:7,@=FEG82XB"@HC.B!B
M<F]W<V4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(D%N9&UE=&4@:6UP
M;W)D:6P@=&5K:VES('9I9V$N(@H*(SH@8G)O=W-E+G!H<#HR-S@*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!L
M:7-T(@IM<V=S='(@(D%N9&UE=&4@:6UP;W)D:6P@=&5K:VES('9I9V$N(@H*
M(SH@9&%T82YP:'`Z,S,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G
M<W1R(")!;F1M971E(&EM<&]R9&EL('1E:VMI<R!V:6=A+B(*"B,Z(&QI8B]A
M<&DN<&AP.C4P-R!L:6(O87!I+G!H<#HW-C$*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R(")!;F1M971E(&EM<&]R9&EL('1E:VMI<R!V:6=A+B(*"B,Z
M(&)R;W=S92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!R96UO=FEN9R!A(&-O;G1A8W0@9G)O;2!T:&4@;&ES="XB"FUS9W-T
M<B`B06YD;65T92!I;7!O<F1I;"!T96MK:7,@=FEG82XB"@HC.B!A9&1R97-S
M8F]O:W,N<&AP.C4U(&%D9')E<W-B;V]K<RYP:'`Z-C`@861D<F5S<V)O;VMS
M+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G
M<W1R("),865T=60@9F%I;&D@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A(@H*
M(SH@861D<F5S<V)O;VMS+G!H<#HX,2!A9&1R97-S8F]O:W,N<&AP.C@W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(DQA971U
M9"!F86EL:2!I;7!O<G1I;6ES96P@=&5K:VES('9I9V$B"@HC.B!E9&ET+G!H
M<#HQ-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y.B`E<R(*;7-G<W1R(")!;F1M
M971E(&EM<&]R9&EL('1E:VMI<R!V:6=A+B(*"B,Z(&1A=&$N<&AP.C$W.0HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP
M;W)T+B(*;7-G<W1R("+<:W-K:2!A861R97-S:7)A86UA="!E:2!L=6)A('-A
M;'9E<W1A;6ES="(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E
M;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R97-S(&)O;VMS('=I;&P@
M9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#,*;7-G:60@(E1H97-E(&-O
M;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@(B(*
M"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,3(R
M(&QI8B]A<&DN<&AP.C$Q,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D
M9')E<W,@8F]O:R(*;7-G<W1R(")3964@:7-I:R!O;B!J=6)A('-I;G4@86%D
M<F5S<VER86%M871U<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30W
M"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B
M;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@
M(E1I=&QE(@IM<V=S='(@(D%M970B"@HC.B!L:6(O5'5R8F$N<&AP.C0S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R
M92X@($UI<W-I;F<@<V]U<F-E('1Y<&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]$
M<FEV97(N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B16D@<W5U9&$@
M;&%A9&ED82`E<R!D969I;FET<VEO;VYI+B(*"B,Z(&5D:70N<&AP.C@X(&5D
M:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY(&5D:70N<&AP.C$Y
M-@HC+"!F=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(E-A;'9E
M<W1A(&UU=71U<V5D(@H*(SH@;&EB+V%P:2YP:'`Z-30P(&QI8B]A<&DN<&AP
M.C8T,R!L:6(O87!I+G!H<#HW-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS
M=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<V]U<F-E<RYP:'`N9&ES=#HS-S8*(RP@9G5Z>GD*;7-G:60@(E9E<FES
M:6=N($1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]O9R(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z(&UI;FES96%R8V@N<&AP.C<X"B,L(&9U>GIY"FUS9VED
M(")6:65W($-O;G1A8W0B"FUS9W-T<B`B3&ES82!U=7,@86%D<F5S<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E9I97<@=&\@9&ES
M<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HR,#@*;7-G:60@(E=E8G-I=&4@55),(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q,PIM<V=I9"`B
M5V]R:R!!9&1R97-S(@IM<V=S='(@(E3V]F%A9')E<W,B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O<FL@0VET>2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,SD*(RP@
M9G5Z>GD*;7-G:60@(E=O<FL@0V]U;G1R>2(*;7-G<W1R(")4]O9T96QE9F]N
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34V"FUS9VED(")7
M;W)K(%!H;VYE(@IM<V=S='(@(E3V]G1E;&5F;VXB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E=O<FL@4&]S
M=&%L($-O9&4B"FUS9W-T<B`B5/;V=&5L969O;B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$R.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=&%T
M92]0<F]V:6YC92(*;7-G<W1R(")4]O9T96QE9F]N(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3$Y"B,L(&9U>GIY"FUS9VED(")7;W)K(%-T
M<F5E="!!9&1R97-S(@IM<V=S='(@(E3V]F%A9')E<W,B"@HC.B!D871A+G!H
M<#HR,S<@8G)O=W-E+G!H<#HY,R!B<F]W<V4N<&AP.C(P,2!A9&0N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&5D:70N<&AP.C8Y(&1I<W!L87DN<&AP.C4X('9I97<N<&AP
M.C,V"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W
M('1H:7,@8V]N=&%C="XB"FUS9W-T<B`B(@H*(SH@=F-A<F0N<&AP.C0P"FUS
M9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@
M;V)J96-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C4U"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@
M861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+VIA=F%S8W)I<'0N:6YC.C(S"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T
M87)G970@;&ES="XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,S(*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN
M8SHQ-R!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C0Y"B,Z('1E
M;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A="!L96%S="!O;F4@96YT<GD@9FER<W0N(@IM<V=S='(@
M(B(*"B,Z(&5D:70N<&AP.C<S"FUS9VED(")9;W4@;VYL>2!H879E('!E<FUI
M<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(B(*"B,Z(&)R
M;W=S92YP:'`Z,C@U"FUS9VED(")9;W5R(&1E9F%U;'0@861D<F5S<R!B;V]K
M(&ES(&YO="!B<F]W<V5A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+W)O=RYI;F,Z-B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N
M:6YC.C$R"FUS9VED(");;F\@=F%L=65=(@IM<V=S='(@(B(*"B,Z(&QI8B]4
M=7)B82YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")?0G)O=W-E(@IM<V=S='(@
M(E-I<G9I(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM
M<V=I9"`B7T-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,@HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G
M<W1R(")+=7-T=71A(@H*(SH@;&EB+U1U<F)A+G!H<#HT.3,*(RP@9G5Z>GD*
M;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(DEM<&]R="]%:W-P;W)T
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0HC+"!F=7IZ
M>0IM<V=I9"`B7TQI<W1S(@IM<V=S='(@(DYI;65K:7)I(@H*(SH@;&EB+U1U
M<F)A+G!H<#HT.#$*(RP@9G5Z>GD*;7-G:60@(E]->2!!9&1R97-S($)O;VMS
M(@IM<V=S='(@(D%A9')E<W-I<F%A;6%T=2!I;7!O<G0B"@HC.B!L:6(O5'5R
M8F$N<&AP.C0X-PHC+"!F=7IZ>0IM<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S
M='(@(DQI<V$@=75S(&%A9')E<W,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C(*;7-G:60@(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#D*(RP@9G5Z>GD*;7-G:60@
M(E]396%R8V@B"FUS9W-T<B`B3W1S:6YG(@H*(SH@=F-A<F0N<&AP.C0V"FUS
M9VED(")C;VYT86-T+G9C9B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.3D@
M9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I
M9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(P.0IM
M<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(Q
M.0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S0*;7-G:60@(FYO;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR-`IM<V=I9"`B
M=&\@82!#;VYT86-T($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B=&\@82!D:69F
M97)E;G0@061D<F5S<R!";V]K(@IM<V=S='(@(D%A9')E<W-I<F%A;6%T=2!E
M:W-P;W)T(@H*(SH@9&%T82YP:'`Z-3$@=&5M<&QA=&5S+V)R;W=S92]C;VQU
M;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ-2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")V0V%R
M9"(*;7-G<W1R("(B"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<&\O4D5!1$U%
M````````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`R,P`Q,#0Q-S,V,C<U-@`P,3<P,S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````<V5E(&AO<F1E+W!O+U)%041-10``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+W1U<F)A+G!O=```````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C(T-C<`,3`T,3<S
M-C(W-38`,#(P,#,W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@4T]-12!$15-#4DE05$E612!4251,12X*(R!#;W!Y<FEG
M:'0@*$,I(%E%05(@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T
M<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!004-+04=%
M('!A8VMA9V4N"B,@1DE24U0@05542$]2(#Q%34%)3$!!1$1215-3/BP@645!
M4BX*(PHC+"!F=7IZ>0IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M
M5F5R<VEO;CH@4$%#2T%'12!615)324].7&XB"B)297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#8M,#,M,#8@,3(Z-#<K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T
M93H@645!4BU-3RU$02!(3SI-22M:3TY%7&XB"B),87-T+51R86YS;&%T;W(Z
M($953$P@3D%-12`\14U!24Q`041$4D534SY<;B(*(DQA;F=U86=E+51E86TZ
M($Q!3D=504=%(#Q,3$!L:2YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-(05)3151<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z-#`*;7-G:60@(B!!9&0@86X@
M24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VEM<W!?;W!T+FEN8SHR.0IM<V=I9"`B($1E;&5T92!)35-0($%D9')E
M<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&%L<F5A9'D@97AI<W1S(&%N9"!W87,@;F]T
M(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$T,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C;W!I960@8F5C875S
M92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3,X
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO=F5D(&)E
M8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,W"FUS9VED(")<(D9I<G-T;F%M92!,87-T;F%M95PB
M("`H:64N($IO:&X@1&]E*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,V"FUS9VED(")<(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H
M:64N($1O92P@2F]H;BDB"FUS9W-T<B`B(@H*(SH@861D+G!H<#HQ,#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@861D960N(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E
M<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V9O;W1E<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#(*;7-G:60@(D$@8G)O
M=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,`IM<V=I9"`B06)O
M=F4@<V5A<F-H(&9O<FTB"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R
M("(B"@HC.B!A9&0N<&AP.C4V('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z,CD*;7-G:60@(D%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-`IM<V=I9"`B061D(&%D9')E
M<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#@*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@861D<F5S<R!B;V]K<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN
M8SHR,S<*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@961I="YP
M:'`Z,3,U"FUS9VED(")!9&0@9FEL92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(Y"FUS9VED(")!9&0@=&\B"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HU-PIM<V=I9"`B061D:6YG
M(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C@V"FUS9VED(")!9&1R97-S($)O
M;VLB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR."!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(U"FUS9VED(")!9&1R97-S($)O;VL@3&ES=&EN9R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*;7-G:60@(D%D
M9')E<W,@0F]O:W,B"FUS9W-T<B`B(@H*(SH@861D+G!H<#HQ,#@*;7-G:60@
M(D%D9')E<W,@8F]O:R!E;G1R>2(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS
M,#4*;7-G:60@(D%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV,@IM
M<V=I9"`B061D<F5S<R!B;V]K('1O(&1E;&5T92`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S`*;7-G
M:60@(D%D9')E<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z
M(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z.#@@=&5M<&QA=&5S+V)R;W=S
M92]S96%R8V@N:6YC.C,X"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G:60@
M(D%L:6%S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R
M06QP:&$N:6YC.C<@=&5M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z
M,3`*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT.`IM<V=I9"`B
M06QL(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C4U,PIM<V=I9"`B06QR
M96%D>2!%>&ES=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J
M879A<V-R:7!T+FEN8SHY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@)7,_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-C<*;7-G:60@
M(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L
M96-T960@96YT<FEE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDV"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B(@H*(SH@<V5A
M<F-H+G!H<#HX-2!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S<*;7-G
M:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34Y"FUS9VED(")"96QO=R!S96%R8V@@9F]R;2(*;7-G<W1R
M("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z("@E
M<RD@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3<X"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z-PIM<V=I9"`B0G)O=W-E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@
M0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-#D*;7-G:60@(D-3
M5B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T+T=R;W5P+G!H<#HU-PIM<V=I
M9"`B0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHW"FUS9VED
M(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-#0*;7-G:60@(D-H;V]S92!A(&YA;64B"FUS9W-T
M<B`B(@H*(SH@861D+G!H<#HT.`IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@
M8F]O:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L
M96-T+FEN8SHR,C$*;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C
M="YI;F,Z,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T
M;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED(")#:&]O<V4@=VAI8V@@
M861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R.`IM<V=I9"`B0VAO;W-E('=H
M:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CHB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")#
M;VQU;6X@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M8V]L=6UN<V5L96-T+FEN8SHR,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL
M(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M,@IM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S
M97!A<F%T960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S8*;7-G:60@(D-O
M;7!A;GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,30T"FUS9VED(")#;VUP86YY($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,S(P(&QI8B]A<&DN<&AP.C,V-2!L:6(O87!I+G!H<#HT
M,#D@;&EB+V%P:2YP:'`Z-#DR"B,Z(&QI8B]A<&DN<&AP.C8Q."!L:6(O87!I
M+G!H<#HW,#4@;&EB+V%P:2YP:'`Z-S4X(&QI8B]A<&DN<&AP.C@S.0HC.B!L
M:6(O87!I+G!H<#HQ,#,V(&QI8B]A<&DN<&AP.C$Q,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z-3@*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z
M,R!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C8*;7-G:60@(D-O;G1A8W0@
M4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,CDY"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3@*;7-G:60@(D-O
M<'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M-3,*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHT,`IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O:R(*
M;7-G<W1R("(B"@HC.B!L:6(O3&ES=%9I97<N<&AP.C,T.`IM<V=I9"`B0W)E
M871E(&$@;F5W($-O;G1A8W0@3&ES="!I;CHB"FUS9W-T<B`B(@H*(SH@;&EB
M+T]B:F5C=%9I97<N<&AP.C$S,PIM<V=I9"`B0W)E871E9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(D1E9F%U;'0@
M<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C<V('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z,PHC.B!L:6(O3V)J96-T+G!H<#HS,C@@;&EB+U)E;F1E<F5R+G!H<#HT
M-R!L:6(O4F5N9&5R97(N<&AP.C4P"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3@*;7-G:60@(D1E
M;&5T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X"FUS9VED(")$96QE=&4@0V]N9FER;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B1&5L
M971E(&)U='1O;B!B96AA=FEO=7(B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HR-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E(&9A
M:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VYU;&PN
M<&AP.C8R"FUS9VED(")$96QE=&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R("(B"@HC.B!D96QE=&4N<&AP.C,X"FUS9VED(")$96QE
M=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*
M;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<V5A<F-H+FEN8SHQ,3D*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*;7-G:60@(D1I<W!L
M87DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1I<W!L87D@
M3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3<W"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N
M=')I97,_(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W0N<&AP.C(Y-PIM<V=I
M9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R
M;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C4*
M;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C$P,B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z,C4*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z
M,3`@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E
M<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,@;&EB+U)E;F1E<F5R+G!H<#HT
M,@IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z,C4@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX,0IM<V=I9"`B161I
M="!!9&1R97-S($)O;VMS(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C@U(&5D
M:70N<&AP.C$V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(&5N=')Y(&9O
M<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HU.`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,34T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B
M=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@961I="YP:'`Z,34V(&5D:70N<&AP.C$U.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"XB"FUS9W-T<B`B(@H*
M(SH@8G)O=W-E+G!H<#HR,38@8G)O=W-E+G!H<#HR-C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@861D:6YG("5D(&-O;G1A8W0H<RD@=&\@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR,3@@8G)O=W-E+G!H<#HR-C8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@861D:6YG("5D(&]F("5D(')E
M<75E<W1E9"!C;VYT86-T*',I('1O(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R
M;W=S92YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@)60@8V]N=&%C="AS*2XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HX
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R`E9"!O9B`E
M9"!R97%U97-T960@8V]N=&%C=',H<RDN(@IM<V=S='(@(B(*"B,Z(&)R;W=S
M92YP:'`Z-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5M;W9I;F<@
M)60@8V]N=&%C="AS*2!F<F]M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S
M92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5M;W9I;F<@
M)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HT,34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@<V5A<F-H:6YG('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3`@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-@IM<V=I9"`B
M17AP;W)T($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")%>'!O<G0@;VYL>2!T:&4@<V5L
M96-T960@8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,C<*;7-G:60@(D5X<&]R="!T:&4@9F]L;&]W:6YG(&%D
M9')E<W,@8F]O:R!C;VUP;&5T96QY+B(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!B<F]W<V4N<&AP.C,U
M(&)R;W=S92YP:'`Z,3`S"B,Z(&)R;W=S92YP:'`Z,3,P(&%D9"YP:'`Z-C<@
M<V5A<F-H+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(B(*"B,Z(&)R
M;W=S92YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A
M9&0@)7,@=&\@)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,S`U
M"FUS9VED(")&86EL960@=&\@8G)O=W-E(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M8G)O=W-E+G!H<#HS-#,*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I
M<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8VAA;F=E(&YA;64Z
M("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@/2`E<RP@4F]O="`]("5S
M(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3,T"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HW.0IM<V=I9"`B1F%I;&5D('1O
M('-E87)C:"!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z(&1A=&$N
M<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<V5A<F-H
M('1H92!D:7)E8W1O<GDZ("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$V-PIM<V=I9"`B1F%X(@IM<V=S='(@(B(*"B,Z
M(&5D:70N<&AP.C$S,2!D:7-P;&%Y+G!H<#HQ,#(*;7-G:60@(D9I;&5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW,0IM
M<V=I9"`B1FEN9"(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HQ,#0@961I="YP
M:'`Z,3DT"FUS9VED(")&:6YI<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T($YA;64B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`R"FUS9VED
M(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]S96%R8V@N:6YC.C@T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C8P-@IM<V=I9"`B1VQO8F%L($%D9')E
M<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT-`IM<V=I
M9"`B1W)O=7`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P
M.`IM<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$U,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*;7-G
M:60@(DAO;64@4&]S=&%L($-O9&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z.3@*;7-G:60@(DAO;64@4W1A=&4O4')O=FEN
M8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M.#@*;7-G:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-3`X"FUS9VED("))35-0(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-PIM<V=I9"`B24U3
M4"!!9&1R97-S($)O;VL@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z,S8Q"FUS9VED("));7!O<G0O17AP;W)T($%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-C$S(&QI8B]A<&DN
M<&AP.C<P,`IM<V=I9"`B26YV86QI9"!)1"(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HR,S(@;&EB+V%P:2YP:'`Z-#`T(&QI8B]A<&DN<&AP.C0X-R!L
M:6(O87!I+G!H<#HV,#D*(SH@;&EB+V%P:2YP:'`Z-CDV(&QI8B]A<&DN<&AP
M.C<T."!L:6(O87!I+G!H<#HQ,3`W"FUS9VED("));G9A;&ED(&%D9')E<W,@
M8F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,3$Q(&QI8B]A<&DN
M<&AP.C$Q.#4@;&EB+V%P:2YP:'`Z,3(S.`IM<V=I9"`B26YV86QI9"!E;6%I
M;"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,3$Y"FUS9VED("));G9A
M;&ED(&5N=')Y(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,C8V"FUS9VED("));G9A;&ED(&ME>2!S<&5C:69I960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$Q,34*;7-G:60@(DEN=F%L:60@;F%M92(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW-3(*;7-G:60@(DEN=F%L:60@;V)J
M96-T260B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,`IM
M<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!
M4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS9VED("),87-T
M($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C4S"FUS9VED("),87-T($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC
M.C<X"FUS9VED(")-871C:&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HR,#<*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA
M>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]T<F5E7VUE;G4N<&AP.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$
M3B!I;B!,1$%0('-O=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL
M92!0:&]N92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,S
M,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R,C0*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,38*
M;7-G:60@(DUO=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O
M;'5M;G-E;&5C="YI;F,Z,C0W"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S
M8F]O:W-E;&5C="YI;F,Z,3@T"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y"B,Z
M('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V"FUS
M9VED(")-;W9E(')I9VAT(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4R('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,38*;7-G:60@(DUU;&)E<G)Y($%D
M9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,30S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A
M9&1R97-S(%LE<UTL(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@
M97AI<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z
M,3`W(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C(T,PIM<V=I9"`B37D@061D
M<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z,3$Y
M"FUS9VED(")->2!!9&1R97-S($)O;VMS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HT,@IM<V=I9"`B3F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T
M8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@861D+G!H
M<#HS-B!A9&0N<&AP.C$R-"!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-PIM
M<V=I9"`B3F5W($-O;G1A8W0B"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z.34@
M961I="YP:'`Z,3`R(&5D:70N<&AP.C(P.2!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C(Q.`IM<V=I9"`B3FEC:VYA;64B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(R-B!L:6(O87!I+G!H<#HQ,C<U"B,L
M('!H<"UF;W)M870*;7-G:60@(DYO("5S(&5N=')Y(&9O=6YD(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,3DT"FUS9VED(").;R!A9&1R
M97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!M:6YI<V5A<F-H+G!H
M<#HX,0IM<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z-3$R(&QI8B]A<&DN<&AP.C<X,PIM<V=I9"`B3F\@=D-A
M<F0@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R+FEN8SHW"FUS9VED(").;VYE(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$X-`IM<V=I9"`B3F]T97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I
M9"`B3G5M8F5R(&]F(&ET96US('!E<B!P86=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C8S,2!L:6(O87!I+G!H<#HW-C0*;7-G:60@(D]B:F5C="!N
M;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VEM<W!?;W!T+FEN8SHR,@IM<V=I9"`B(@HB3VYC92!Y;W4@
M<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D<F5S<R!B;V]K('=I;&P@
M8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"X@268@=&AI<R!I<R!N;W0@=VAA
M="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N9V4@>6]U<B!S96QE8W1I
M;VX@(@HB=&\@7").;VYE7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C<Y,0IM<V=I9"`B3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0V"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0
M(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-#DV(&QI
M8B]A<&DN<&AP.C8R,B!L:6(O87!I+G!H<#HW,#D@;&EB+V%P:2YP:'`Z.38T
M"B,Z(&QI8B]A<&DN<&AP.C$Q,C@*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C4U,0IM<V=I9"`B4&5R
M;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z.3D*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(B(*
M"B,Z(&1A=&$N<&AP.C4S('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*
M;7-G:60@(E!I;F4@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N
M86UE('1H92!N97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R("(B"@HC.B!E9&ET
M+G!H<#HY."!E9&ET+G!H<#HQ,#$@961I="YP:'`Z,C`Q"FUS9VED(")0<F5V
M:6]U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HT
M,38*;7-G:60@(E!R:79A=&4@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@
M(E%U97)Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,34*;7-G:60@(E%U:6-K(%-E87)C
M:"(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$Y,2!L:6(O
M1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD87`N<&AP.C0R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4R"FUS9VED(")296%D
M:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]296YD97)E<BYP:'`Z-#D*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI
M<R!C;VYT86-T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O
M;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D<R!D:7-P;&%Y960Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z
M,3<V"FUS9VED(")296UO=F4@861D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S.0IM<V=I9"`B
M4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C,*;7-G:60@(E)E;6]V92!F<F]M('1H:7,@;&ES="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(Q"FUS
M9VED("(B"B)297!L86-E(&5X:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H
M92!I;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE
M=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN
M/"]S=')O;F<^(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C0S.0IM
M<V=I9"`B4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q
M-`IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DV"FUS9VED(")3+TU)344@4'5B
M;&EC($-E<G1I9FEC871E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$P-B!A9&0N<&AP
M.C,W('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V
M92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C8W"FUS9VED
M(")3879I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.CDW('1E;7!L871E
M<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*(SH@=&5M<&QA=&5S+V)L;V-K+VUI
M;FES96%R8V@N:6YC.C$X(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C0Y"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(E-E87)C:"(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,#0Q"FUS9VED(")396%R8V@@9F%I
M;&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,S,@;&EB+V%P:2YP
M:'`Z,3$S.2!L:6(O87!I+G!H<#HQ,30X(&QI8B]A<&DN<&AP.C$Q-C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HT-PIM<V=I9"`B4V5A<F-H:6YG
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M;&]C:R]M:6YI<V5A<F-H+FEN8SHQ.0IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8V"FUS
M9VED(")396QE8W0@86X@861D<F5S<R!B;V]K('1O(&1E;&5T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY,`IM<V=I9"`B
M4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S(*;7-G:60@(E-E;&5C="!T
M:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(V"FUS9VED(")396QE8W0@
M=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S4*;7-G:60@(E-E;&5C="!T
M:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*;7-G:60@(E-E;&5C="!T
M:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM
M<&]R=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ,0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F
M:6QE.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U
M"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@;F%M
M97,Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-0IM
M<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T
M(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")396QE8W0@=VAI8V@@
M9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L
M96-T('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R("(B
M"@HC.B!A9&0N<&AP.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E-E;&5C=&5D
M(&%D9')E<W,@8F]O:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S
M;W5R8V5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0V
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT.`IM<V=I9"`B4VAO=R!!
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT-PIM<V=I9"`B4VAO=R!#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0V"FUS9VED(")3:&]W($QI<W1S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C(Q"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N
M:6YC.C,V"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HR,#`*;7-G:60@(E-O=7)C97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B4W!E8VEF>2!W:&5R
M92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N
M(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C$T(&)R;W=S92YP:'`Z,C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E9"!C
M;VYT86-T*',I('1O(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z
M,38P"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E
M<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8W)E871E9"!T:&4@8V]N=&%C
M="!L:7-T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"`E9"!C
M;VYT86-T*',I+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D("5D(&-O;G1A
M8W0H<RD@9G)O;2!L:7-T+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,`IM
M<V=I9"`B5%-6(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-`IM<V=I9"`B
M5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z
M,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D<R!T;R!B92!C;VYF:6=U
M<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A9',N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$P-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB
M('=A<R!R96UO=F5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@861D
M<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D
M<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&5D:70N<&AP.C4Q('9C87)D+G!H<#HR,B!D:7-P;&%Y
M+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A8W0@>6]U(')E
M<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@961I="YP
M:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE(%PB)7-<(B!H
M87,@<W5C8V5S<V9U;&QY(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z,C@T"FUS9VED(")4:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE
M9"!D97-P:71E('1H92!W87)N:6YG<RXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E
M+G!H<#HS,0IM<V=I9"`B5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S
M<R!B;V]K<RXB"FUS9W-T<B`B(@H*(SH@861D+G!H<#HR.0IM<V=I9"`B(@HB
M5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S(&)O;VMS+B!.;VYE(&]F
M('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R`B"B)A<F4@8V]N9FEG=7)E
M9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S('1O('1H96TN($EF
M('EO=2!B96QI979E('1H:7,@(@HB:7,@86X@97)R;W(L('!L96%S92!C;VYT
M86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z
M(&%D9"YP:'`Z,3(Q"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@861D
M:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI
M;FES=')A=&]R("(*(F9O<B!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z
M(&)R;W=S92YP:'`Z,C<Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E
M871I;F<@82!N97<@;&ES="XB"FUS9W-T<B`B(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@8W)E871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(B(*
M"B,Z(&)R;W=S92YP:'`Z,38V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<(B5S7"(@9G)O;2!T:&4@<V]U<F-E
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9&5L971E+G!H<#HS-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP
M.C,Q,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AE
M(&QI<W0B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S,U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A
M=&$Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C4P."!L:6(O87!I
M+G!H<#HW-S@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O
M:W,N<&AP.C4X(&%D9')E<W-B;V]K<RYP:'`Z-C,@861D<F5S<V)O;VMS+G!H
M<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M<F5M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(B(*"B,Z
M(&%D9')E<W-B;V]K<RYP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E
M<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HQ-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT<GDZ
M("5S(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$W.0IM<V=I9"`B5&AE<F4@
M=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X,`IM<V=I
M9"`B5&AE<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O
M<F1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E
M;&5C="YI;F,Z,C0S"FUS9VED(")4:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA
M>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-CD*
M;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3$U,B!L:6(O87!I+G!H<#HQ,38U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S
M(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30X"FUS9VED("(B"B)4:&ES('=I
M;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R
M(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@(E1I=&QE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]4=7)B82YP:'`Z-#0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@;F5W('-H87)E+B!-:7-S:6YG('-O=7)C92!T>7!E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY-2!E9&ET+G!H<#HY."!E
M9&ET+G!H<#HQ,#$@961I="YP:'`Z,3`V(&5D:70N<&AP.C(P,PIM<V=I9"`B
M56YD;R!#:&%N9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C4T,2!L
M:6(O87!I+G!H<#HV-C`@;&EB+V%P:2YP:'`Z-SDV"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"FUS9VED(")697)I
M<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]R;W<N:6YC.C$Y('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z
M,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@;6EN:7-E87)C:"YP:'`Z-S8*;7-G:60@(E9I97<@0V]N=&%C="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED
M(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`X"FUS9VED(")796)S:71E
M(%523"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ,3,*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O<FL@0VET>2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,SD*
M;7-G:60@(E=O<FL@0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,T"FUS9VED
M(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$R.0IM<V=I9"`B5V]R:R!3=&%T92]0<F]V:6YC
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M,3D*;7-G:60@(E=O<FL@4W1R965T($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z,C,W(&)R;W=S92YP:'`Z,3`V(&)R;W=S92YP:'`Z,C(W(&%D
M9"YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S(&EN(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-S,@9&ES<&QA>2YP:'`Z-3@@
M=FEE=RYP:'`Z,S8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N
M('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R("(B"@HC.B!V8V%R9"YP
M:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z
M-3,Q"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;G,@=&\@9&5L
M971E('1H:7,@<V]U<F-E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+VIA=F%S8W)I<'0N:6YC.C4U"FUS9VED(")9;W4@;75S="!S96QE8W0@
M82!T87)G970@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S"FUS9VED(")9;W4@;75S="!S
M96QE8W0@82!T87)G970@;&ES="XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z
M,S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C
M="!F:7)S="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A
M<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C0Y"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-S(*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@96YT<GD@9FER<W0N
M(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C<W"FUS9VED(")9;W4@;VYL>2!H
M879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@
M(B(*"B,Z(&)R;W=S92YP:'`Z,S$X"FUS9VED(")9;W5R(&1E9F%U;'0@861D
M<F5S<R!B;V]K(&ES(&YO="!B<F]W<V5A8FQE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z-B!T96UP;&%T97,O8G)O=W-E+V-O
M;G1A8W1R;W<N:6YC.C$R"FUS9VED(");;F\@=F%L=65=(@IM<V=S='(@(B(*
M"B,Z(&QI8B]4=7)B82YP:'`Z-34T"FUS9VED(")?0G)O=W-E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#<*;7-G:60@
M(E]#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C,*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+U1U<F)A+G!H<#HU-C,*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#8*;7-G:60@
M(E],:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C4U,0IM<V=I
M9"`B7TUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A
M+G!H<#HU-3<*;7-G:60@(E].97<@0V]N=&%C="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*;7-G:60@(E]296UO=F4@
M9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HU
M-3D*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B(@H*(SH@=F-A<F0N<&AP.C0V
M"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ
M.3D@9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM
M<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(P
M.0IM<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S@*;7-G:60@(FYO(&9O<FUA='1I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHS,@IM
M<V=I9"`B;F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C,Q"FUS9VED(")T;R!A($-O;G1A8W0@3&ES="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(Q"FUS9VED
M(")T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z-3$@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI
M;F,Z,3,*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-2!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")V0V%R9"(*;7-G<W1R("(B
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O='5R8F$O<&\O<G5?4E4N<&\`````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#$Q-#(V,0`Q,#0Q-S,V,C<U-@`P,3<U-C``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R!2=7-S
M:6%N(%1U<F)A(%1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*0HC($EG;F%T
M($EK<GEA;F]V(#QI:6=N871`;F5W;6%I;"YR=3XL(#(P,#$*(R!!;G1O;B!.
M96MH;W)O<VAI:"`\86YT;VY`=F%L=65H;W-T+G)U/BP@,C`P,0HC($9E9&]R
M($$N($9E=&ES;W8@/&9A9D!S<V,N<G4^+"`R,#`R"B,@06QE>&5Y(%IA:VAA
M<F]V(#QB86)E<D!M;W-G82YN970^+"`R,#`V"B,*;7-G:60@(B(*;7-G<W1R
M("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A($@S('8R+C`N-%QN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`Q+3$U(#$U.C0R*S`R,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#$M,3<@,3DZ-#`K,#(P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!!;&5X97D@6F%K:&%R;W8@/&)A8F5R0&UO<V=A
M+FYE=#Y<;B(*(DQA;F=U86=E+51E86TZ(%)U<W-I86X@/&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3%<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I;7-P7V]P="YI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(B!!9&0@86X@24U3
M4"!!9&1R97-S($)O;VLB"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!T
M96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(Y"B,L(&9U>GIY"FUS9VED
M("(@1&5L971E($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(MWJ\>_N\/(@
MX.3PY?'M[ND@ZNWHX^@B"@HC.B!D871A+G!H<#HS,C4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S
M(&YO="!I;7!O<G1E9"XB"FUS9W-T<B`B)7,@\^;E(/'S^>7RXO/E\BX@PN#X
MX"`E<R#OX._JX"#MY2#A^^O@(._E\.7H[.7M[N+@[>`N(@H*(SH@8G)O=W-E
M+G!H<#HQ-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP
M+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HBS^#OZN`@7"(E<UPB(.'[Z^`@
M\_'OY?CM[B#OY?#EZ.SE[>[BX.W@(.(@7"(E<UPB+EQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B);\?+P
M[NK@("5S(.CG("5S75QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@
M=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B);\?+P[NK@("5S(.CG("5S75QN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC
M7&XB"B);\?+P[NK@("5S(.CG("5S72(*"B,Z(&)R;W=S92YP:'`Z,3,X"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO=F5D(&)E8V%U
M<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,W"FUS9VED(")<(D9I<G-T;F%M92!,87-T;F%M95PB("`H
M:64N($IO:&X@1&]E*2(*;7-G<W1R(")<(LCL_R#4X.SHZ^C_7"(@*,+@\?\@
MS_/OZNCM*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@
M(EPB3&%S=&YA;64L($9I<G-T;F%M95PB("AI92X@1&]E+"!*;VAN*2(*;7-G
M<W1R(")<(M3@[.CKZ/\L(,CL_UPB("C/\^_JZ.TL(,+@\?\I(@H*(SH@861D
M+G!H<#HQ,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@861D960N(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R("+4X.GK("5S
M(//Q[^7X[>X@Z.SO[O#RZ/#NXN#M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F
M;V]T97(N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O
M("5S(&]F("5S(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(EOQ\O#NZN`@)7,@Z.<@)7-=7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC
M7&XB"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&QI8B]4=7)B82YP:'`Z-#8T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O
M:R(*;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,Z(&QI8B]";&]C:R]M:6YI
M<V5A<F-H+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B02!B<F]W<V5R('1H870@
M<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9"(*;7-G<W1R("+"X/@@X?#N
M\^?E\"#MY2#O[N3DY?#FZ.+@Y?(@[N_VZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H
M(.W@YNSH\N4@0U123"M0+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C`*;7-G:60@(D%B;W9E('-E87)C:"!F;W)M(@IM<V=S='(@(LW@Y"#T[O#L
M[ND@[^[H\>K@(@H*(SH@=FEE=RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B06-C97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R("+$[O'R\^\@Y^#O\.7Y
MY>T@Y.O_("5S(@H*(SH@861D+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C(Y"FUS9VED(")!9&0B"FUS9W-T<B`BQ.[AX.+H\OPB"@HC
M.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-`HC
M+"!F=7IZ>0IM<V=I9"`B061D(&%D9')E<W,@8F]O:R(*;7-G<W1R("+`Y/#E
M\>W@_R#J[>CCX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.`HC+"!F
M=7IZ>0IM<V=I9"`B061D(&%N9"!$96QE=&4@24U34"!A9&1R97-S(&)O;VMS
M(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-O;'5M;G-E;&5C="YI;F,Z,C,W"B,L(&9U>GIY"FUS9VED(")!9&0@8V]L
M=6UN(@IM<V=S='(@(N3NX>#BZ/+\(/'R[NOAY?8B"@HC(&9U>GIY"B,Z(&5D
M:70N<&AP.C$S-0IM<V=I9"`B061D(&9I;&4B"FUS9W-T<B`BY^#C\//GZ/+\
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(Y
M"FUS9VED(")!9&0@=&\B"FUS9W-T<B`BQ.[AX.+H\OPB"@HC.B!L:6(O1')I
M=F5R+VYU;&PN<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!9&1I;F<@8V]N=&%C
M=',@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#M
MX/'R\.[EZBXB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*
M(SH@8G)O=W-E+G!H<#HR."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"FUS
M9VED(")!9&1R97-S($)O;VL@3&ES=&EN9R(*;7-G<W1R("+1[N3E\.;@[>CE
M(.#D\.7Q[>[I(.KMZ./H(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`BP.3PY?'M
M^^4@ZNWHX^@B"@HC.B!A9&0N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B061D
M<F5S<R!B;V]K(&5N=')Y(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(.3N\?+S
M[^W@(/+NZ_SJ[B#DZ_\@]_+E[>C_+B(*"B,Z(&1A=&$N<&AP.C,P-0HC+"!F
M=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N
M(@IM<V=S='(@(M3@Z>L@)7,@\_'OY?CM[B#H[._N\/+H\.[BX.TB"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B
M061D<F5S<R!B;V]K('1O(&1E;&5T92`B"FUS9W-T<B`BP.3PY?'MX/\@ZNWH
MX^`@Y.[Q\O/O[>`@\N[K_.KN(.3K_R#W\N7MZ/\N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S`*(RP@9G5Z>GD*;7-G
M:60@(D%D9')E<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z
M(@IM<V=S='(@(L_NY._H\?P@[>4@[.[FY?(@X?OR_"#GX.SE[>7MX"XB"@HC
M.B!S96%R8V@N<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS
M.`IM<V=I9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(M#@\?CH\.7M[?OI
M(,_NZ/'J(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT.`IM<V=I9"`B06QL(@IM<V=S='(@(L+QY2(*"B,Z(&QI8B]A<&DN<&AP
M.C4U-`IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B(@H*(R!F=7IZ
M>2P@<&AP+69O<FUA=`HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N
M:6YC.CDS"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D
M96QE=&4@)7,_(@IM<V=S='(@(L+[(//BY?#E[?LL(/?R[B#U[O+H\N4@\>3E
MZ^#R_"#]\NX_(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C8W"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N=')I97,_(@IM<V=S='(@(L+[
M(//BY?#E[?LL(/?R[B#U[O+H\N4@\>3EZ^#R_"#]\NX_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B
MS^X@XN[G\.#Q\N#MZ/XB"@HC(&9U>GIY"B,Z('-E87)C:"YP:'`Z.#4@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,W"FUS9VED(")"87-I8R!396%R
M8V@B"FUS9W-T<B`BS^[H\>HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34Y"FUS9VED(")"96QO=R!S96%R8V@@9F]R;2(*;7-G<W1R("+/[N0@].[P
M[.[I(._NZ/'JX"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S<@;&EB+T1R
M:79E<B]L9&%P+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0FEN9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`BSOCHX>K@(._PZ"#SY.#K
MY>WHZ"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0FER=&AD87DB"FUS9W-T<B`BQ.7M_"#P[N;DY>WH_R(*"B,@9G5Z>GD*
M(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(D)R;W=S
M92(*;7-G<W1R("+"^^'PX/+\(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3<S"B,L(&9U>GIY"FUS9VED(")"=7-I;F5S<R!#871E9V]R>2(*
M;7-G<W1R("+-[N+@_R#JX/+EX^[PZ/\B"@HC.B!D871A+G!H<#HT.0IM<V=I
M9"`B0U-6(@IM<V=S='(@(D-35BWTX.GK(@H*(SH@;&EB+T]B:F5C="]'<F]U
M<"YP:'`Z-3<*;7-G:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R
M<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(L+[Y.7K
MZ/+\(.+QY2(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C0T"B,L
M(&9U>GIY"FUS9VED(")#:&]O<V4@82!N86UE(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+$
MY>GQ\N+HY3HB"@HC.B!A9&0N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#:&]O
M<V4@86X@861D<F5S<R!B;V]K(@IM<V=S='(@(LWE\B#@Y/#E\>W[]2#J[>CC
M+"#D[O'R\^_M^_4@Y.O_(.+[X>[PX"XB"@HC.B!T96UP;&%T97,O<')E9G,O
M8V]L=6UN<V5L96-T+FEN8SHR,C$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A
M;B!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(LWE\B#@Y/#E\>W[]2#J[>CC+"#D
M[O'R\^_M^_4@Y.O_(.+[X>[PX"XB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,38U"B,L(&9U>GIY"FUS9VED
M(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!D:7-P;&%Y+"!A;F0@
M:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`BPOOAY?#H\N4@X.3PY?'M\_X@ZNWH
MX_,@Y.O_(.3NX>#BZ^7MZ/\@XB#MY>4@X.3PY?'NXBXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!W:&EC
M:"!A9&1R97-S(&)O;VMS('1O('5S92XB"FUS9W-T<B`BS>7R(.#D\.7Q[?OU
M(.KMZ.,L(.3N\?+S[^W[]2#DZ_\@XOOA[O#@+B(*"B,@9G5Z>GD*(SH@=&5M
M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C(X"FUS9VED(")#:&]O
M<V4@=VAI8V@@8V]L=6UN<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R
M.B(*;7-G<W1R("+"^^'E\.CRY2#QXN[I\?+BX"P@ZN[R[O#[Z2#A\^3S\B#N
M\N[A\.#FY>W[(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3<*;7-G:60@(D-O;'5M;B!/<'1I;VYS(@IM<V=S='(@(M'R[NOA]OLB"@HC
M.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S,*;7-G:60@
M(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S='(@
M(LWE[O+NX?#@YN#E[/OE(/'B[NGQ\N+@.B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM
M<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")#4U8M].#I
MZR`H\.#GY.7KY>WM^^D@Y^#O__+[[.@I(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H
M36EC<F]S;V9T($]U=&QO;VLI(@IM<V=S='(@(D-35BWTX.GK("CT[O#LX/(@
M36EC<F]S;V9T($]U=&QO;VLI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BRN[L[^#MZ/\B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-#0*(RP@9G5Z>GD*;7-G
M:60@(D-O;7!A;GD@061D<F5S<R(*;7-G<W1R("+$[NS@^.WHZ2#@Y/#E\2(*
M"B,Z(&QI8B]A<&DN<&AP.C,R,"!L:6(O87!I+G!H<#HS-C4@;&EB+V%P:2YP
M:'`Z-#`Y(&QI8B]A<&DN<&AP.C0Y,PHC.B!L:6(O87!I+G!H<#HV,3D@;&EB
M+V%P:2YP:'`Z-S`V(&QI8B]A<&DN<&AP.C<U.2!L:6(O87!I+G!H<#HX,S<*
M(SH@;&EB+V%P:2YP:'`Z,3`R-"!L:6(O87!I+G!H<#HQ,3$R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`BSOCHX>K@(._PZ"#SY.#KY>WHZ"(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*
M;7-G<W1R("+.^.CAZN`@[_#H(//DX.OE[>CH(@H*(R!F=7IZ>0HC.B!L:6(O
M0FQO8VLO;6EN:7-E87)C:"YP:'`Z,R!L:6(O0FQO8VLO;6EN:7-E87)C:"YP
M:'`Z,C8*;7-G:60@(D-O;G1A8W0@4V5A<F-H(@IM<V=S='(@(LW@Z?+H(.KN
M[?+@ZO(B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&)R;W=S92YP:'`Z,CDY
M"FUS9VED(")#;VYT86-T<R!I;B!L:7-T.B`E<R(*;7-G<W1R("+*[NWRX.KR
M^R#B(./P\^_OY3H@)7,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N
M:6YC.C$X"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S='(@(LKN[._@[>C_
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3,*;7-G:60@(D-R
M96%T92(*;7-G<W1R("+1[N?DX/+\(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!!9&1R97-S($)O
M;VLB"FUS9W-T<B`BT>[DY?#FX.WHY2#@Y/#E\>WNZ2#J[>CCZ"(*"B,@9G5Z
M>GD*(R!F=7IZ>0HC.B!L:6(O3&ES=%9I97<N<&AP.C,T.`IM<V=I9"`B0W)E
M871E(&$@;F5W($-O;G1A8W0@3&ES="!I;CHB"FUS9W-T<B`BT>[GY.#R_"#M
M[N+S_B#C\//O[_,@XCHB"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S"B,L
M(&9U>GIY"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(M'NY^3@\OPB"@HC(&9U
M>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`BS^[P_^3NZB#Q[O#RZ/#N
MXNKH(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"B,Z(&QI8B]/8FIE8W0N<&AP.C,R
M."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z-3`*;7-G
M:60@(D1E;&5T92(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!!9&1R
M97-S($)O;VLB"FUS9W-T<B`BW>KQ[^[P\B#@Y/#E\>WNZ2#J[>CCZ"(*"B,@
M9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")$96QE
M=&4@0V]N9FER;6%T:6]N(@IM<V=S='(@(M/DX.OE[>CE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED(")$96QE=&4@8G5T=&]N(&)E:&%V
M:6]U<B(*;7-G<W1R("+/[N3RXN7PYN3E[>CE(.[OY?#@]NCH(//DX.OE[>C_
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR-S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B
MSOCHX>K@(._PZ"#SY.#KY>WHZ"(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z
M-C(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T:6YG(&-O;G1A8W1S(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*
M(SH@9&5L971E+G!H<#HS.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S
M='(@(L[XZ.'JX"#O\.@@\^3@Z^7MZ.@B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HR,3,*(RP@9G5Z>GD*;7-G:60@(D1E<&%R=&UE;G0B"FUS
M9W-T<B`BS_#HZO#E[^O_Y>SNY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("+/[B#SX?OBX.WH_B(*
M"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3$U"FUS
M9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("+.[^CQX.WHY2(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3D*;7-G:60@(D1I<F5C=&]R>2(*
M;7-G<W1R("+*X/+@Z^[C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T
M"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(L[A[NON]^K@(@H*(R!F=7IZ>0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(L[Q[>[B[?OE(.W@\?+P[NGJZ"(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$W-PIM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D
M96QE=&EN9R!E;G1R:65S/R(*;7-G<W1R("+'X._PX/CHXN#R_"#O[N3RXN7P
MYN3E[>CE(._PZ"#SY.#KY>WHZ"#GX._H\>7I/R(*"B,@9G5Z>GD*(SH@;&EB
M+T]B:F5C="YP:'`Z,CDW"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("+'X./P
M\^?H\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ
M-R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(U"B,L(&9U>GIY
M"FUS9VED(")$;W=N;&]A9"!V0V%R9"(*;7-G<W1R("+'X./P\^?H\OPB"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@=&5M<&QA=&5S+V)R
M;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C$P('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-@HC
M.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S(&QI8B]296YD
M97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B"FUS9W-T<B`BT.7DX.KRZ/#NXN#M
MZ.4B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4@=&5M<&QA=&5S
M+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`BT.7DX.KRZ/#NXN#MZ.4@
M)R5S)R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M.#$*(RP@9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G<W1R
M("+`Y/#E\>W[Y2#J[>CCZ"(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@961I
M="YP:'`Z.#4@961I="YP:'`Z,38Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(&5N=')Y(&9O<B`E<R(*;7-G<W1R("+-X/'R\.[IZN@B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B16UA:6PB
M"FUS9W-T<B`B12UM86EL(@H*(SH@961I="YP:'`Z,34T"B,L('!H<"UF;W)M
M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H
M92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@961I
M="YP:'`Z,34V(&5D:70N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;G1R>2!F;W(@)7,@=7!D871E9"XB"FUS9W-T<B`BQ^#OZ/'\("5S(.[A[>[B
MZ^7MX"XB"@HC.B!B<F]W<V4N<&AP.C(Q-B!B<F]W<V4N<&AP.C(V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!A9&1I;F<@)60@8V]N=&%C="AS*2!T
M;R!L:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(Q."!B<F]W<V4N
M<&AP.C(V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!A9&1I;F<@)60@
M;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`B
M(@H*(SH@8G)O=W-E+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@)60@8V]N=&%C="AS*2XB"FUS9W-T<B`BSOCH
MX>K@(._PZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!B<F]W<V4N<&AP.C@X"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG("5D(&]F("5D(')E
M<75E<W1E9"!C;VYT86-T<RAS*2XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H
M<#HV-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R96UO=FEN9R`E9"!C
M;VYT86-T*',I(&9R;VT@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H
M<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R96UO=FEN9R`E9"!O
M9B`E9"!R97%U97-T960@8V]N=&%C="AS*2!F<F]M(&QI<W0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C0Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@<V5A<F-H:6YG('1H92!A9&1R97-S(&)O;VLZ("5S(@IM
M<V=S='(@(L[XZ.'JX"#O\.@@Y.[Q\O/OY2#J(//JX.?@[>WNZ2#@Y/#E\>WN
MZ2#J[>CCY2XB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$P
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*
M;7-G<W1R("+=ZO'O[O#R(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C8*;7-G:60@(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T
M<B`BW>KQ[^[P\B#@Y/#E\>WNZ2#J[>CCZ"(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D5X<&]R="!O;FQY('1H
M92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK
M_.WN(.W@\?+P[N7M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR
M-PIM<V=I9"`B17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O
M;7!L971E;'DN(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H
M<#HR,C@@9&%T82YP:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HQ
M,#,*(SH@8G)O=W-E+G!H<#HQ,S`@861D+G!H<#HV-R!S96%R8V@N<&AP.C,W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@86-C97-S
M('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(L[XZ.'JX"#O\.@@Y.[Q
M\O/OY2#J(//JX.?@[>WNZ2#@Y/#E\>WNZ2#J[>CCY2XB"@HC.B!B<F]W<V4N
M<&AP.C$U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&%D9"`E<R!T;R`E<SH@)7,B"FUS9W-T<B`BSOCHX>K@(._PZ"#B^^'N\.4@
M)7,N(@H*(SH@8G)O=W-E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(D9A:6QE
M9"!T;R!B<F]W<V4@;&ES="(*;7-G<W1R("+.^.CAZN`@[_#H(.+[X>[PY2`E
M<RXB"@HC.B!B<F]W<V4N<&AP.C,T,PHC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D
M('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM<V=S='(@(L[XZ.'JX"#O\.@@
M[^[H\>KE(.(@ZN#RX.ONX^4Z("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HS,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-H86YG92!N
M86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@
M/2`E<R(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$S-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&9I;F0@;V)J96-T('1O(&)E
M(&%D9&5D.B`E<R(*;7-G<W1R("+.^.CAZN`@[_#H(._NZ/'JY2#B(.K@\N#K
M[N/E.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D9A
M:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("+.^.CA
MZN`@[_#H(.3N\?+S[^4@ZB#SZN#GX.WM[ND@X.3PY?'M[ND@ZNWHX^4N(@H*
M(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,B"FUS9W-T<B`BSOCHX>K@(._P
MZ"#O[NCQZN4@XB#JX/+@Z^[CY3H@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-C<*;7-G:60@(D9A>"(*;7-G<W1R("+4X.KQ(@H*(R!F
M=7IZ>0HC(&9U>GIY"B,Z(&5D:70N<&AP.C$S,2!D:7-P;&%Y+G!H<#HQ,#`*
M;7-G:60@(D9I;&5S(@IM<V=S='(@(M3@Z>O[(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]S96%R8V@N:6YC.C<Q"FUS9VED(")&:6YD(@IM<V=S='(@(LW@Z?+H
M(@H*(SH@961I="YP:'`Z,3`T(&5D:70N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I
M9"`B1FEN:7-H(@IM<V=S='(@(LW@Z?+H(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z-#@*(RP@9G5Z>GD*;7-G:60@(D9I<G-T($YA;64B"FUS
M9W-T<B`BS^7PXN#_(/'R\.#MZ/;@(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@T"FUS9VED(")&<F]M
M(@IM<V=S='(@(L[R(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`V
M"B,L(&9U>GIY"FUS9VED(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@
M(L#D\.7Q[>#_(.KMZ./@(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT
M-`HC+"!F=7IZ>0IM<V=I9"`B1W)O=7`B"FUS9W-T<B`BP_#S[^_[(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R("+$[NS@^.WHZ2#@Y/#E\2(*"B,@9G5Z>GD*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3,*(RP@9G5Z>GD*;7-G:60@(DAO
M;64@0VET>2(*;7-G<W1R("+/[O#RX.LB"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ,#@*(RP@9G5Z>GD*;7-G:60@(DAO;64@0V]U;G1R>2(*
M;7-G<W1R("+$[NS@^.WHZ2#RY>OE].[M(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,34P"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(L3N
M[.#X[>CI(/+EZ^7T[NTB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DAO;64@4&]S=&%L($-O9&4B"FUS9W-T
M<B`BQ.[LX/CMZ.D@\N7KY?3N[2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED(")(;VUE(%-T871E+U!R;W9I;F-E
M(@IM<V=S='(@(L3N[.#X[>CI(/+EZ^7T[NTB"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HX.`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!3=')E970@
M061D<F5S<R(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z-3`X"FUS9VED("))35-0(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-PHC+"!F=7IZ>0IM<V=I9"`B24U3
M4"!!9&1R97-S($)O;VL@061M:6YI<W1R871I;VXB"FUS9W-T<B`BT>[DY?#F
MX.WHY2#@Y/#E\>WNZ2#J[>CCZ"(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T<B`BR.SO
M[O#R(.#D\.7Q[>[I(.KMZ./H+"#8X.,@)60B"@HC(&9U>GIY"B,Z(&1A=&$N
M<&AP.C,V,0IM<V=I9"`B26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS(@IM
M<V=S='(@(LCL[^[P\B_=ZO'O[O#R(.#D\.7Q[>[I(.KMZ./H(@H*(R!F=7IZ
M>0HC.B!L:6(O87!I+G!H<#HV,30@;&EB+V%P:2YP:'`Z-S`Q"FUS9VED("))
M;G9A;&ED($E$(@IM<V=S='(@(LWEZN[P\.7J\NWNY2#H[/\N(@H*(R!F=7IZ
M>0HC.B!L:6(O87!I+G!H<#HR,S(@;&EB+V%P:2YP:'`Z-#`T(&QI8B]A<&DN
M<&AP.C0X."!L:6(O87!I+G!H<#HV,3`*(SH@;&EB+V%P:2YP:'`Z-CDW(&QI
M8B]A<&DN<&AP.C<T.2!L:6(O87!I+G!H<#HQ,#DU"FUS9VED("));G9A;&ED
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("+-Y>KN\/#EZO+MX/\@X.3PY?'MX/\@
MZNWHX^`N(@H*(R!F=7IZ>0HC.B!L:6(O87!I+G!H<#HQ,#DY(&QI8B]A<&DN
M<&AP.C$Q-S(@;&EB+V%P:2YP:'`Z,3(R-0IM<V=I9"`B26YV86QI9"!E;6%I
M;"(*;7-G<W1R("+-Y>KN\/#EZO+M^^D@92UM86EL+B(*"B,@9G5Z>GD*(SH@
M;&EB+V%P:2YP:'`Z,3$P-PIM<V=I9"`B26YV86QI9"!E;G1R>2(*;7-G<W1R
M("+-Y>KN\/#EZO+M[N4@Z.S_+B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,C8V"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&ME>2!S<&5C:69I960N(@IM
M<V=S='(@(L'[Z^`@\^K@Y^#MX"#MY>KN\/#EZO+MX/\@XN7KZ/?H[>`N(@H*
M(R!F=7IZ>0HC.B!L:6(O87!I+G!H<#HQ,3`S"FUS9VED("));G9A;&ED(&YA
M;64B"FUS9W-T<B`BS>7J[O#PY>KR[>[E(.CL_RXB"@HC.B!L:6(O87!I+G!H
M<#HW-3,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;V)J96-T260B"FUS9W-T
M<B`BS>7J[O#PY>KR[>[E(.CL_RXB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C,P"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H
M92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S@*(RP@9G5Z
M>GD*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L'[\?+P
M^^D@\?+@\/(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PHC
M+"!F=7IZ>0IM<V=I9"`B3&%S="!.86UE(@IM<V=S='(@(L_N\>OEY.W__R#Q
M\O#@[>CVX"(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N
M:6YC.C$V"FUS9VED("),:7-T(@IM<V=S='(@(M'OZ/'NZB(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW.`IM<V=I9"`B36%T8VAI;F<B"FUS
M9W-T<B`BT>[B[^#DY>WHY2(*"B,Z(&QI8B]A<&DN<&AP.C(P-PHC+"!F=7IZ
M>0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B
MS.#J\>CLX.O\[>[E(.KNZ^CWY?'RXNX@\?+PX.WH]B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F('!A
M9V5S(@IM<V=S='(@(LS@ZO'H[.#K_.WNY2#J[NOH]^7Q\N+N(/'R\.#MZ/8B
M"@HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU($QI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G
M:60@(DUI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0:&]N92(*;7-G<W1R("+,[N'HZ_SM
M^^D@\N7KY?3N[2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S,R(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,S0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(L[XZ.'JX"#O\.@@
M\^3@Z^7MZ.@B"@HC.B!L:6(O87!I+G!H<#HQ,C$Q"FUS9VED(")-;W)E('1H
M86X@,2!E;G1R>2!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C$V"FUS9VED(")-;W9E(@IM<V=S='(@(L_E\.7L
MY?'RZ/+\(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z
M,C0W"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z
M,3@T"B,L(&9U>GIY"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B\>SE\?+H
M\OP@XNOEXNXB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN
M8SHR-#D*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN
M8SHQ.#8*(RP@9G5Z>GD*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B\>SE
M\?+H\OP@XN_PX.+N(@H*(R!F=7IZ>0HC.B!D871A+G!H<#HU,B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$V"FUS9VED(")-=6QB97)R>2!!9&1R97-S
M($)O;VLB"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`@375L8F5R<GDB"@HC.B!L
M:6(O87!I+G!H<#HQ,3,Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUU;'1I
M<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL(&)U="!N;VYE('=I=&@@
M;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC
M(&9U>GIY"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$P-R!C;VYF:6<O
M<V]U<F-E<RYP:'`N9&ES=#HR-#,*;7-G:60@(DUY($%D9')E<W,@0F]O:R(*
M;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!A
M9&1R97-S8F]O:W,N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S
M<R!";V]K<R(*;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HT,@IM<V=I9"`B3F%M92(*;7-G<W1R("+([/\B"@HC(&9U>GIY"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B3F%M92!&;W)M870B
M"FUS9W-T<B`BR.SE[>`B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HS
M,34*;7-G:60@(DYE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,@9G5Z>GD*(SH@861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L:6(O0FQO
M8VLO=')E95]M96YU+G!H<#HR-PIM<V=I9"`B3F5W($-O;G1A8W0B"FUS9W-T
M<B`BQ.[AX.+H\OP@[>[B\_X@Y^#OZ/'\(@H*(SH@961I="YP:'`Z.34@961I
M="YP:'`Z,3`R(&5D:70N<&AP.C(P.2!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@(L3@Z^7E(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$X"B,L(&9U>GIY"FUS9VED(").:6-K
M;F%M92(*;7-G<W1R("+([/\B"@HC.B!L:6(O87!I+G!H<#HQ,C$S(&QI8B]A
M<&DN<&AP.C$R-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@)7,@96YT<GD@
M9F]U;F0@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.#$*
M(RP@9G5Z>GD*;7-G:60@(DYO(&%D9')E<W,@8F]O:W,@9F]U;F0N(@IM<V=S
M='(@(L#D\.7Q[>#_(.KMZ./@(.3N\?+S[^W@(/+NZ_SJ[B#DZ_\@]_+E[>C_
M+B(*"B,Z(&UI;FES96%R8V@N<&AP.C@Q"B,L(&9U>GIY"FUS9VED(").;R!C
M;VYT86-T<R!F;W5N9"(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S
M(.WE(.W@Z>3E[2XB"@HC.B!L:6(O87!I+G!H<#HU,3,@;&EB+V%P:2YP:'`Z
M-S@T"B,L(&9U>GIY"FUS9VED(").;R!V0V%R9"!D871A('=A<R!F;W5N9"XB
M"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`@Y.[Q\O/O[>`@\N[K_.KN(.3K_R#W
M\N7MZ/\N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C<*(RP@
M9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$X-`IM<V=I9"`B3F]T97,B"FUS9W-T
M<B`BQ^#LY?+JZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G
M:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R("+*[NLMXNX@
MY^#OZ/'EZ2#MX"#Q\O#@[>CVY2(*"B,Z(&QI8B]A<&DN<&AP.C8S,B!L:6(O
M87!I+G!H<#HW-C4*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!N;W0@9F]U;F0B
M"FUS9W-T<B`BSO+LY>WH\OP@Z.?LY>WE[>C_(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,C(S"B,L(&9U>GIY"FUS9VED(")/9F9I8V4B"FUS
M9W-T<B`BQ^#C[NONXN[J(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T
M+FEN8SHR,@IM<V=I9"`B(@HB3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P
M86=E+"!T:&4@861D<F5S<R!B;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB
M9&5L971E9"X@268@=&AI<R!I<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y
M;W4@;75S="!C:&%N9V4@>6]U<B!S96QE8W1I;VX@(@HB=&\@7").;VYE7"(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C<Y,@HC+"!F=7IZ>0IM<V=I
M9"`B3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MS>[B[N4@\>[NX?GE[>CE(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V"FUS9VED(")/=&AE
M<B!/<'1I;VYS(@IM<V=S='(@(L3P\^/HY2#MX/'R\.[IZN@B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C0Y-R!L:6(O87!I+G!H
M<#HV,C,@;&EB+V%P:2YP:'`Z-S$P(&QI8B]A<&DN<&AP.CDU,@HC.B!L:6(O
M87!I+G!H<#HQ,3$V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z-34P"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N(&1E;FEE
M9"(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(R!F=7IZ>0HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY.0IM<V=I9"`B4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BS_#@XN`@Y.[Q\O/OX"(*"B,@9G5Z>GD*(SH@9&%T
M82YP:'`Z-3,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B
M4&EN92!!9&1R97-S($)O;VLB"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`@4&EN
M92(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN
M8SHR.`IM<V=I9"`B4&QE87-E(&YA;64@=&AE(&YE=R!C;VYT86-T(&QI<W0Z
M(@IM<V=S='(@(L_NYN#K\^GQ\N`@XN+EY.CRY2#M[N+NY2#H[/\Z(@H*(SH@
M961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D:70N<&AP.C(P,0HC+"!F=7IZ
M>0IM<V=I9"`B4')E=FEO=7,B"FUS9W-T<B`BS_#EY/OD\_G@_R#Q\O#@[>CV
MX"(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q-@HC+"!F=7IZ>0IM
M<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`BT>[DY?#FX.WH
MY2#@Y/#E\>WNZ2#J[>CCZ"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")1=65R>2!F86EL960Z("@E
M<RD@)7,B"FUS9W-T<B`BSOCHX>K@(._PZ"#SY.#KY>WHZ"(*"B,@9G5Z>GD*
M(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"FUS9VED(")1
M=6EC:R!396%R8V@B"FUS9W-T<B`BP?OQ\O#[Z2#O[NCQZB(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z-#(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("+.^.CAZN`@[_#H
M(//DX.OE[>CH(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HU,@HC+"!F=7IZ
M>0IM<V=I9"`B4F5A9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,@9G5Z>GD*(R!F
M=7IZ>0HC.B!L:6(O4F5N9&5R97(N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")2
M96%L;'D@9&5L971E('1H:7,@8V]N=&%C=#\B"FUS9W-T<B`BT^3@Z^CR_"#G
M\O,@Y^#DX/?S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C(*
M;7-G:60@(E)E8V]R9',@9&ES<&QA>65D.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-@HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(&%D9')E<W,@8F]O:R(*;7-G<W1R("+`Y/#E\>W@
M_R#J[>CCX"(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(S.0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("+S
MX?#@\OP@\?+NZ^'E]B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHS"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS
M9W-T<B`BT^3@Z^CR_"#HYR#C\//O[_LB"@HC(&9U>GIY"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,C$*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I
M;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N
M9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U
M<B!C=7)R96YT(&%D9')E<W,@8F]O:RX\+W-T<F]N9SXB"FUS9W-T<B`B(@HB
MS^[K[>[Q\OS^(.?@[.7MZ/+\(/'S^>7Q\N+S_OGS_B#@Y/#E\>WS_B#J[>CC
M\RX@/&(^S_#H(/WR[NP@X?/D\_(@\^3@Z^7M^R`B"B+"T<4@Y^#OZ/'H(.CG
M(/+EZO/YY>D@X.3PY?'M[ND@ZNWHX^@\+V(^(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z-#,X"B,L(&9U>GIY"FUS9VED(")297%U97-T960@;V)J96-T(&YO="!F
M;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GD
MY>TN(@H*(SH@861D+G!H<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI
M;F,Z,3$T"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R("+1X?#N
M\>CR_"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@HC+"!F
M=7IZ>0IM<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T:69I8V%T92(*;7-G<W1R
M("+"X/CE(._NZ^WNY2#H[/\Z(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HV
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(L[XZ.'JX"#O\.@@\^3@Z^7MZ.@B"@HC.B!E
M9&ET+G!H<#HQ,#8@861D+G!H<#HS-R!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHQ,C0*;7-G:60@(E-A=F4B"FUS9W-T<B`BT>[U\.#MZ/+\(@H*(SH@
M;&EB+T1R:79E<B]N=6QL+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B4V%V:6YG
M(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R
M\^_M^_4@[>#Q\O#NY>HN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.CDW('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*(SH@=&5M
M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(Q(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C0Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G
M:60@(E-E87)C:"(*;7-G<W1R("+/[NCQZB(*"B,Z(&QI8B]A<&DN<&AP.C$P
M,CD*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!F86EL960B"FUS9W-T<B`BS^[H
M\>HB"@HC.B!L:6(O87!I+G!H<#HQ,3(Q(&QI8B]A<&DN<&AP.C$Q,C<@;&EB
M+V%P:2YP:'`Z,3$S-B!L:6(O87!I+G!H<#HQ,30Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R("+/[NCQ
MZB(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@
M(E-E87)C:&EN9R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q
M\O/O[?OU(.W@\?+P[N7J+B(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A
M<F-H+FEN8SHR,@HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S
M='(@(L_NZ/'J(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96QE8W0N:6YC.CD*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!!9&1R97-S($)O;VLB"FUS9W-T<B`B
MW>KQ[^[P\B#@Y/#E\>WNZ2#J[>CCZ"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z-C8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A
M;B!A9&1R97-S(&)O;VL@=&\@9&5L971E(@IM<V=S='(@(L+[X>7PZ/+E(.#D
M\.7Q[?/^(.KMZ./S(.3K_R#]ZO'O[O#RX#HB"@HC(&9U>GIY"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.CDP"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@86X@861D<F5S<R!B;V]K('1O(&5D:70B"FUS9W-T<B`BRO/DX"#"^R#U
M[O+H\N4@Z.SO[O#RZ/#NXN#R_#HB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,S(*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B
M;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G<W1R("+"^^'E\.CRY2#@Y/#E\>WS
M_B#J[>CC\R#DZ_\@_>KQ[^[P\N`Z(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C(V"FUS9VED(")396QE8W0@=&AE(&%D9')E<W,@
M8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(LKSY.`@POL@]>[RZ/+E(.CL
M[^[P\NCP[N+@\OPZ(@H*(R!F=7IZ>0HC(&9U>GIY"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,S4*;7-G:60@(E-E;&5C="!T:&4@8VAA<G-E="!O
M9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(M/JX.;H\N4@ZN[DZ/#NXNKS
M(.CL[^[P\NCP\^7L[N/N(/3@Z>O@.B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ,`IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@
M9F]R;6%T.B(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@_>KQ[^[P\NCP\^7L
M[N/N(/3@Z>O@.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#,*
M;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(LCL
M[^[P\NCP\^7L^^D@].#IZSHB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3$*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H
M92!S;W5R8V4@9FEL93HB"FUS9W-T<B`BPOOAY?#H\N4@].[P[.#R(.CL[^[P
M\NCP\^7L[N/N(/3@Z>O@.B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D
M:7-P;&%Y(&YA;65S.B(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@[O+NX?#@
MYN7MZ/\@Z.SE[3HB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT
M+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`B
MS>#Q\O#NZ>K@(/#EYNCLX"#N\N[A\.#FY>WH_R#O[B#S[.[K]^#MZ/XB"@HC
M(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.`IM<V=I9"`B4V5L
M96-T('=H:6-H(&9I96QD<R!T;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI
M<W1S+B(*;7-G<W1R("+"^^'N\"#O[O#_Y.K@(.[R[N'PX.;E[>C_(/'R[NOA
M]N[B(.(@\>_H\>KE(.#D\.7Q[N(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,R"FUS9VED(")396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@
M;F%M97,N(@IM<V=S='(@(L+[X>[P(/3N\.S@\N`@[O+NX?#@YN7MZ/\@Z.SE
M[2(*"B,Z(&%D9"YP:'`Z-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-E;&5C=&5D(&%D9')E<W,@8F]O:R!<(B5S7"(N(@IM<V=S='(@(LWEZN[P
M\.7J\NW@_R#@Y/#E\>W@_R#J[>CCX"XB"@HC.B!C;VYF:6<O<V]U<F-E<RYP
M:'`N9&ES=#HQ-S,*(RP@9G5Z>GD*;7-G:60@(E-H87)E9"!$:7)E8W1O<GDB
M"FUS9W-T<B`BRN#RX.ONXR(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5L96-T
M+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R(*;7-G<W1R("+([._N\/(B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W("5S(@IM<V=S='(@(LCL[^[P\B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#@*;7-G:60@(E-H
M;W<@06QL(@IM<V=S='(@(L_NZN#GX/+\(.+QY2(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z-#<*;7-G:60@(E-H;W<@0V]N=&%C=',B"FUS
M9W-T<B`BS^[JX.?@\OP@RN[M\N#J\OLB"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C0V"FUS9VED(")3:&]W($QI<W1S(@IM<V=S='(@(L_N
MZN#GX/+\(,/P\^_O^R(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C(Q"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G
M<W1R("+*X/+@Z^[C(@H*(SH@;&EB+V%P:2YP:'`Z,C`P"B,L(&9U>GIY"FUS
M9VED(")3;W5R8V5S(@IM<V=S='(@(M/Q[^7X[>XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34X"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT
M(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B
MP^3E(.[R[N'PX.;@\OP@\.7G\^O\\N#R^R#PX/'XZ/#E[>WNX^X@[^[H\>K@
M(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!B<F]W<V4N<&AP.C(Q-"!B<F]W
M<V4N<&AP.C(V,@IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("5D(&-O;G1A
M8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`B)60@X?OK(//Q[^7X[>X@Y.[AX.+K
MY>TB"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&)R;W=S92YP:'`Z,38P"FUS
M9VED(")3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,B"FUS9W-T<B`BQ.[A
MX.+KY>WN(%PB)7-<(B#B(%PB)7-<(BXB"@HC(&9U>GIY+"!P:'`M9F]R;6%T
M"B,Z(&)R;W=S92YP:'`Z,C0X"FUS9VED(")3=6-C97-S9G5L;'D@8W)E871E
M9"!T:&4@8V]N=&%C="!L:7-T(%PB)7-<(BXB"FUS9W-T<B`BT>[GY.#MX"#C
M\//O[^`@)R5S)R(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP
M+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&)R;W=S92YP:'`Z.#0*
M;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D("5D(&-O;G1A8W0H<RDN(@IM
M<V=S='(@(M/DX.OE[>X@)60@ZN[M\N#J\N[B(@H*(R!F=7IZ>2P@<&AP+69O
M<FUA=`HC.B!B<F]W<V4N<&AP.C8T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M
M;W9E9"`E9"!C;VYT86-T*',I(&9R;VT@;&ES="XB"FUS9W-T<B`BT^3@Z^7M
M[B`E9"#J[NWRX.KR[N(@Z.<@X_#S[^_[(@H*(SH@9&%T82YP:'`Z-3`*;7-G
M:60@(E135B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,30*;7-G:60@(E1A
M8B!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(E135BWTX.GK("CPX.?DY>OE
M[>W[Z2#RX.'SZ__VZ.7I*2(*"B,Z('9I97<N<&AP.C$U"FUS9VED(")4:&4@
M5D93(&)A8VME;F0@;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@
M871T86-H;65N="!U<&QO861S+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ,#<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D
M<F5S<R!B;V]K(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BP.3P
MY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@861D<F5S<V)O
M;VMS+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D
M9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("+/X._JX"!<(B5S7"(@X?OKX"#S\>_E^.WN(//DX.OE[>`N(@H*
M(SH@861D<F5S<V)O;VMS+G!H<#HW,0IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+/
MX._JX"!<(B5S7"(@X?OKX"#S\>_E^.WN(//DX.OE[>`N(@H*(SH@861D<F5S
M<V)O;VMS+G!H<#HX.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D
M+B(*;7-G<W1R("+/X._JX"!<(B5S7"(@X?OKX"#S\>_E^.WN(//DX.OE[>`N
M(@H*(SH@9&%T82YP:'`Z,S`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM
M<V=S='(@(L_NY._H\?P@[>4@[.[FY?(@X?OR_"#GX.SE[>7MX"XB"@HC.B!E
M9&ET+G!H<#HU,2!V8V%R9"YP:'`Z,C(@9&ES<&QA>2YP:'`Z,C,@=FEE=RYP
M:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(E1H92!C;VYT86-T('EO=2!R97%U97-T
M960@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7M
MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&5D:70N<&AP.C$R,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S
M9G5L;'D@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+/X._JX"!<(B5S7"(@X?OK
MX"#S\>_E^.WN(//DX.OE[>`N(@H*(SH@9&%T82YP:'`Z,C@T"FUS9VED(")4
M:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W87)N:6YG
M<RXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HS,0IM<V=I9"`B5&AE<F4@
M87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RXB"FUS9W-T<B`BS>7R
M(.#D\.7Q[?OU(.KMZ.,L(.3N\?+S[^W[]2#DZ_\@XOOA[O#@+B(*"B,Z(&%D
M9"YP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E(&%R92!N;R!W<FET
M96%B;&4@861D<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@879A:6QA8FQE(&%D
M9')E<W,@8F]O:W,@(@HB87)E(&-O;F9I9W5R960@=&\@86QL;W<@>6]U('1O
M(&%D9"!N97<@96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES
M("(*(FES(&%N(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+-Z"#NY.W@(.CG(.3N\?+S[^W[
M]2#@Y/#E\>W[]2#J[>CC(.WE(.'[Z^`@\>KN[?3HX_/PZ/#NXN#MX"#RX.HL
M(/?R[N'[(,+[("(*(NCLY>OH(.+NY^SNYNWN\?+\(.3NX>#BZ__R_"#B(.WE
MY2#M[N+[Y2#GX._H\>@N(,7QZ^@@POL@\??H\N#E\N4L(/?R[B#]\NX@(@HB
M[OCHX>K@+"#R[B#QXO_FZ/+E\?P@\2#QZ/'@Y.SH[>[L+B(*"B,Z(&%D9"YP
M:'`Z,3(Q"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M861D:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R("(*(F9O<B!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(L[X
MZ.'JX"#O\.@@Y.[AX.+KY>WHZ"#NX?KEZO+@+B#1XO_FZ/+E\?P@\2#QZ/'@
MY.SH[>[L+B(*"B,Z(&)R;W=S92YP:'`Z,C<Q"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="XB"FUS9W-T
M<B`BSOCHX>K@(._PZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!A9&1R97-S8F]O
M:W,N<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@
M(RTC+2,M(RTC7&XB"B+/\.[AZ^7LX"#O\.@@[_#N\>SN\O#E(.?@[_#N^.7M
M[>[C[B#OZ/'\[.`N(@H*(SH@8G)O=W-E+G!H<#HQ-C8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<
M(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
MSOCHX>K@(._PZ"#H[._N\/+E(.?@X_#SYN7M[>[C[B#TX.GKX"(*"B,Z(&1E
M;&5T92YP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S(@IM<V=S
M='(@(L[XZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM^_4N(@H*(SH@8G)O=W-E+G!H
M<#HS,3$*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H92!L:7-T(@IM<V=S='(@(L[XZ.'JX"#O\.@@Z.SO[O#RY2#G
MX./P\^;E[>WNX^X@].#IZ^`B"@HC.B!D871A+G!H<#HS,S4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(L[XZ.'JX"#O\.@@Z.SO[O#RY2#D
MX.WM^_4N(@H*(SH@;&EB+V%P:2YP:'`Z-3`Y(&QI8B]A<&DN<&AP.C<W.0HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(L[XZ.'JX"#O\.@@Z.SO[O#R
MY2#DX.WM^_4N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HU."!A9&1R97-S8F]O
M:W,N<&AP.C8S(&%D9')E<W-B;V]K<RYP:'`Z-CD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES
M(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@
M+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC
M+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@
M[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@
M(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE
M[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T
M+C`N,BD@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#G
MX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H
M(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HBS_#NX>OE
M[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HB
MS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M
M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ
M_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M
M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WN
MX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N
M,BD@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P
M[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0
M('8T+C`N,BD@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+P
MY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@
M[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+EQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@
M+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8T+C`N,BD@(",M(RTC
M+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@
M[^CQ_.S@+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`BSOCHX>K@(._PZ"#H[._N
M\/+E(.3@[>W[]2XB"@HC.B!E9&ET+G!H<#HQ-C4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES
M(&5N=')Y.B`E<R(*;7-G<W1R("+.^.CAZN`@[_#H(.CL[^[P\N4@Y.#M[?OU
M+B(*"B,Z(&1A=&$N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V5R
M92!N;R!A9&1R97-S97,@=&\@97AP;W)T+B(*;7-G<W1R("+-Y?(@X.3PY?'M
M^_4@ZNWHXRP@Y.[Q\O/O[?OU(.3K_R#GX._H\>@N(@H*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X,`HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@
M:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`BPB#]\N[I(._@[^KE(.WE\B#TX.GK
M[N(N(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T
M+FEN8SHR-#,*;7-G:60@(E1H97-E(&-O;'5M;G,@=VEL;"!D:7-P;&%Y(&EN
M('1H:7,@;W)D97(Z(@IM<V=S='(@(MWRZ"#QXN[I\?+BX"#A\^3S\B#N\N[A
M\.#FY>W[(@H*(SH@9&%T82YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")4:&ES
M(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V
M-"XP+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WH
MY5QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@
M(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-
M[N+NY2#Q[N[A^>7MZ.4B"@HC.B!L:6(O87!I+G!H<#HQ,30P(&QI8B]A<&DN
M<&AP.C$Q-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H:7,@<&5R
M<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O
M:R(*;7-G<W1R("+=\N[R(/?EZ^[BY>H@\^;E(.?@[^CQX.T@XB#"X/CEZ2#@
MY/#E\>WNZ2#J[>CCY2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30X
M"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B
M;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@
M(E1I=&QE(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z(&QI8B]4=7)B82YP:'`Z
M-#0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(&YE=R!S:&%R92X@36ES<VEN9R!S;W5R8V4@='EP92XB"FUS9W-T<B`B
MS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L
M:6(O1')I=F5R+G!H<#HQ,#`P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(.?@X_#SY^CR_"#N[_#EY.7KY>WHY2`E<RXB"@HC(&9U>GIY"B,Z
M(&5D:70N<&AP.CDU(&5D:70N<&AP.CDX(&5D:70N<&AP.C$P,2!E9&ET+G!H
M<#HQ,#8@961I="YP:'`Z,C`S"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T
M<B`BSO+LY>WH\OP@Z.?LY>WE[>C_(@H*(SH@;&EB+V%P:2YP:'`Z-30R(&QI
M8B]A<&DN<&AP.C8V,2!L:6(O87!I+G!H<#HW.3<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS
M9W-T<B`BS>7J[O#PY>KR[>[E(.CL_RXB"@HC.B!C;VYF:6<O<V]U<F-E<RYP
M:'`N9&ES=#HS-S8*(RP@9G5Z>GD*;7-G:60@(E9E<FES:6=N($1I<F5C=&]R
M>2(*;7-G<W1R("+*X/+@Z^[C(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!T
M96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3D@=&5M<&QA=&5S+V)R;W=S92]C
M;VYT86-T<F]W+FEN8SHR-PIM<V=I9"`B5FEE=R!<(B5S7"(B"FUS9W-T<B`B
MS_#N\>SN\O`@)7,B"@HC.B!M:6YI<V5A<F-H+G!H<#HW-@HC+"!F=7IZ>0IM
M<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(L3NX>#BZ/+\(.WNXO/^(.?@
M[^CQ_"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E9I
M97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R("+0Y>;H["#O[B#S
M[.[K]^#MZ/XZ(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`X
M"FUS9VED(")796)S:71E(%523"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,3,*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G
M<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3(T"B,L(&9U>GIY"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B
MT.#A[O?HZ2#RY>OE].[M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")7;W)K($-O=6YT<GDB"FUS9W-T<B`B
MT.#A[O?HZ2#RY>OE].[M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,34V"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(M#@X>[WZ.D@\N7K
MY?3N[2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S-`HC+"!F
M=7IZ>0IM<V=I9"`B5V]R:R!0;W-T86P@0V]D92(*;7-G<W1R("+0X.'N]^CI
M(/+EZ^7T[NTB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*
M(RP@9G5Z>GD*;7-G:60@(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B
MT.#A[O?HZ2#RY>OE].[M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3$Y"B,L(&9U>GIY"FUS9VED(")7;W)K(%-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!D871A+G!H<#HR,S<@8G)O=W-E
M+G!H<#HQ,#8@8G)O=W-E+G!H<#HR,C<@861D+G!H<#HW,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S(&EN(%PB)7-<(BXB"FUS9W-T<B`B
MPOL@\>[GY.#E\N4@[^#OZO,@XN7P]>WEX^X@\_#NXNW_+B(*"B,Z(&5D:70N
M<&AP.C<S(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB
M"FUS9W-T<B`B(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@9&\@;F]T
M(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O5'5R8F$N<&AP.C4S-PHC+"!F=7IZ>0IM<V=I9"`B66]U
M(&1O(&YO="!H879E('!E<FUI<W-I;VYS('1O(&1E;&5T92!T:&ES('-O=7)C
M92XB"FUS9W-T<B`BT.7DX.KRZ/#NXN#R_"#O\.#BX"#DZ_\@_?+NZ2#RY>S[
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHU-0HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@
M8F]O:RXB"FUS9W-T<B`BPOL@Y.[KYNW[(/'MX/?@Z^`@XOOA\.#R_"#@Y/#E
M\2XB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB
M"FUS9W-T<B`BPOL@Y.[KYNW[(//JX.?@\OP@\>W@]^#KX"#B(.K@ZO/^(._@
M[^KS+B(*"B,Z(&5D:70N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")9;W4@;75S
M="!S96QE8W0@870@;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N(@IM<V=S='(@
M(L+[(.3NZ^;M^R#Q[>#WX.O@(.+[X?#@\OP@[^X@ZO#@Z>WEZ2#LY?#E(.[D
M[>X@\>[NX?GE[>CE+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP
M="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHT.0HC
M.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C<R"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I
M<G-T+B(*;7-G<W1R("+"^R#D[NOF[?L@\>W@]^#KX"#B^^'PX/+\(._N(.KP
MX.GMY>D@[.7PY2#NY.WN(/'N[N'YY>WHY2XB"@HC.B!E9&ET+G!H<#HW-PIM
M<V=I9"`B66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C
M;VYT86-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C,Q.`IM<V=I9"`B
M66]U<B!D969A=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E86)L92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C8@=&5M
M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I
M9"`B6VYO('9A;'5E72(*;7-G<W1R("+'X.SE\NKH(@H*(R!F=7IZ>0HC.B!L
M:6(O5'5R8F$N<&AP.C4V,`IM<V=I9"`B7T)R;W=S92(*;7-G<W1R("+"^^'P
MX/+\(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-PHC+"!F
M=7IZ>0IM<V=I9"`B7T-O;G1A8W1S(@IM<V=S='(@(L_NZN#GX/+\(,KN[?+@
MZO+[(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C,*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`BT^3@Z^CR_"(*"B,@9G5Z>GD*
M(SH@;&EB+U1U<F)A+G!H<#HU-CD*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM
M<V=S='(@(LCL[^[P\B_=ZO'O[O#R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B7TQI<W1S(@IM<V=S='(@
M(M'OZ/'NZB(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!L:6(O5'5R8F$N<&AP.C4U
M-PHC+"!F=7IZ>0IM<V=I9"`B7TUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B
MP.3PY?'MX/\@ZNWHX^`B"@HC(&9U>GIY"B,@9G5Z>GD*(SH@;&EB+U1U<F)A
M+G!H<#HU-C,*;7-G:60@(E].97<@0V]N=&%C="(*;7-G<W1R("+$[N'@XNCR
M_"(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PHC+"!F=7IZ
M>0IM<V=I9"`B7U)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R("+3Y.#K
MZ/+\(._@\/,B"@HC(&9U>GIY"B,Z(&QI8B]4=7)B82YP:'`Z-38U"FUS9VED
M(")?4V5A<F-H(@IM<V=S='(@(L_NZ/'J(@H*(SH@=F-A<F0N<&AP.C0V"FUS
M9VED(")C;VYT86-T+G9C9B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.3D@
M9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I
M9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(P.0IM
M<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(Q
M.0HC+"!F=7IZ>0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(L_NZN#G
MX/+\(,KN[?+@ZO+[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S.`HC
M+"!F=7IZ>0IM<V=I9"`B;F\@9F]R;6%T=&EN9R(*;7-G<W1R("+3Y.#KZ/+\
M(._@\/,B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C,R"FUS
M9VED(")N;VYE(@IM<V=S='(@(NWE\B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHS,0IM<V=I9"`B=&\@82!#;VYT86-T($QI
M<W0B"FUS9W-T<B`BXB#C\//O[_,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")T;R!A(&1I9F9E<F5N="!!
M9&1R97-S($)O;VLB"FUS9W-T<B`BW>KQ[^[P\B#@Y/#E\>WNZ2#J[>CCZ"(*
M"B,Z(&1A=&$N<&AP.C4Q('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C$S"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B=D-A<F0B"FUS9W-T
M<B`B=D-A<F0B"@IM<V=I9"`B(@HB0VAO;W-E(&$@9&5F875L="!D:7)E8W1O
M<GD@9F]R('EO=7(@<&5R<V]N86P@861D<F5S<V)O;VLL(&-O;G1A8W0@;&ES
M=',L(&%N9"`B"B)S96%R8VAE<RXB"FUS9W-T<B`BPOOA[O`@X.3PY?'M[ND@
MZNWHX^@@Z"#N[_;HZ2#DZ_\@[^[H\>K@(@H*;7-G:60@(D-H;V]S92!T:&4@
M;W)D97(@;V8@=&AE(&-O;'5M;G,@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S
M<R!L:7-T+B(*;7-G<W1R("+"^^'E\.CRY2#O[O#_Y.[J(.[R[N'PX.;E[>C_
M(/'R[NOA]N[B(.(@\>_H\>KE(.#D\.7Q[N(N(@H*;7-G:60@(D-L96%R(%-E
M87)C:"(*;7-G<W1R("+.]^CQ\NCR_"(*"FUS9VED(")#;VYT96YT<R!O9B`E
M<R(*;7-G<W1R("+1[N3E\.;@[>CE("5S(@H*(R!F=7IZ>0IM<V=I9"`B1&5F
M875L="!$:7-P;&%Y(@IM<V=S='(@(L_P[O3HZ_P@[^X@\^SNZ_?@[>C^(@H*
M;7-G:60@(B(*(D1E9F%U;'0@9&ER96-T;W)Y(&9O<B!Y;W5R('!E<G-O;F%L
M(&%D9')E<W-B;V]K+"!C;VYT86-T(&QI<W1S+"!A;F0@<V5A<F-H97,N(@IM
M<V=S='(@(L#D\.7Q[>#_(.KMZ./@(._N(//L[NOWX.WH_B(*"FUS9VED(")0
M;&5A<V4@<V5L96-T(&$@9&ER96-T;W)Y.B(*;7-G<W1R("+/[N;@Z_/I\?+@
M+"#B^^'E\.CRY2#JX/+@Z^[C.B(*"FUS9VED("(B"B)297!L86-E(&5X:7-T
M:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I;7!O<G1E9"!O;F4_(#QB/E=A
M<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U
M<G)E;G0@861D<F5S<R!B;V]K+CPO8CXB"FUS9W-T<B`B(@HBS^[K[>[Q\OS^
M(.?@[.7MZ/+\(/'S^>7Q\N+S_OGS_B#@Y/#E\>WS_B#J[>CC\RX@/&(^S_#H
M(/WR[NP@X?/D\_(@\^3@Z^7M^R`B"B+"T<4@Y^#OZ/'H(.CG(/+EZO/YY>D@
MX.3PY?'M[ND@ZNWHX^@\+V(^(@H*;7-G:60@(E-E87)C:"!297-U;'1S(@IM
M<V=S='(@(M#EY_/K_/+@\OL@[^[H\>K@(@H*(R!F=7IZ>0IM<V=I9"`B4V5A
M<F-H:6YG($]P=&EO;G,B"FUS9W-T<B`BS^[H\>HB"@IM<V=I9"`B4V5L96-T
M($QI<W0B"FUS9W-T<B`BPOOAY?#H\N4@X_#S[^_S(@H*;7-G:60@(E-E;&5C
M="!V:65W('1O(&1I<W!L87D@8GD@9&5F875L="XB"FUS9W-T<B`BS>#Q\O#N
MZ>K@(/#EYNCLX"#N\N[A\.#FY>WH_R#O[B#S[.[K]^#MZ/XB"@IM<V=I9"`B
M4V5L96-T960@0V]L=6UN<SHB"FUS9W-T<B`BPOOA\.#M[?OE(/'R[NOA]OLZ
M(@H*;7-G:60@(E-H;U]W($%L;"(*;7-G<W1R("+"\>4B"@IM<V=I9"`B4VAO
M=R!?0V]N=&%C=',B"FUS9W-T<B`BRN[M\N#J\OLB"@IM<V=I9"`B4VAO=R!?
M3&ES=',B"FUS9W-T<B`BP_#S[^_[(@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<&\O9VQ?15,N<&\`````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W,S0Q,@`Q
M,#0Q-S,V,C<U-@`P,3<U,3<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!4=7)B82`Q+C(@1V%L:6-I86X@=')A;G-A=&EO
M;@HC"B,@5F5R<VEO;B!I;FEC:6%L(&1E.@HC"B,@4F%F865L(%9A<F5L82`\
M<F%F865L+G9A<F5L84!U<V,N97,^"B,@1W5I;&QE<FUO($UE;F1E>B`\9W5I
M;&QE0'5S8RYE<SX*(R!397)V:6-I;R!D92!A=&5N8VEO;B!A('5S=6%R:6]S
M(&4@<VES=&5M87,*(R!5;FEV97)S:61A9&4@9&4@4V%N=&EA9V\@9&4@0V]M
M<&]S=&5L80HC"B,@4F5V:7-A9&$@>2!C;W)R96=I9&$@<&]R.@HC(`HC(%-E
M<G9I8VEO(&1E(&YO<FUA;&EZ86-I;VX@;&EN9W5I<W1I8V$@/'-N;'5S8T!U
M<V,N97,^"B,@56YI=F5R<VED861E(&1E(%-A;G1I86=O(&1E($-O;7!O<W1E
M;&$*(PHC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!4=7)B82`Q+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`S+3`X+3$Y
M(#$R.C$S1TU4*S%<;B(*(DQA<W0M5')A;G-L871O<CH@9W5I;&QE(#QG=6EL
M;&5`=7-C+F5S/EQN(@HB3&%N9W5A9V4M5&5A;3H@1V%L96=O7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:71<;B(*(E@M1V5N97)A=&]R.B!+0F%B96P@,"XY+C5<;B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z-#(*(RP@9G5Z>GD*;7-G
M:60@(B!!9&0@86X@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`B26UP;W)T
M87(@82!A>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VEM<W!?;W!T+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B($1E;&5T92!)35-0
M($%D9')E<W,@0F]O:R(*;7-G<W1R("));7!O<G1A<B!A(&%X96YD82!D92!E
M;F1E<F5Z;W,B"@HC.B!D871A+G!H<#HS,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&%L<F5A9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM<&]R=&5D
M+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO=F5D(&)E8V%U<V4@:70@
M:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,W"FUS9VED(")<(D9I<G-T;F%M92!,87-T;F%M95PB("`H:64N($IO
M:&X@1&]E*2(*;7-G<W1R(").;VUE+"!!<&5L:61O<R`H<"YE+B!8;V%N($?S
M;65Z*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(EPB
M3&%S=&YA;64L($9I<G-T;F%M95PB("AI92X@1&]E+"!*;VAN*2(*;7-G<W1R
M(")!<&5L:61O<RP@3F]M92`H<"YE+B!'\VUE>BP@6&]A;BDB"@HC.B!A9&0N
M<&AP.C$P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A9&1E9"XB"FUS9W-T
M<B`B(@H*(SH@9&%T82YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(D\@87)Q=6EV
M;R`E<R!I;7!O<G1O=7-E(&-O<G)E8W1A;65N=&4B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V9O;W1E<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T
M;R`E<R!O9B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0T-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B26UP;W)T87(@82!A>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@
M;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C0U"FUS9VED(")!(&)R;W=S97(@
M=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3D*;7-G:60@(D%B;W9E('-E
M87)C:"!F;W)M(@IM<V=S='(@(B(*"B,Z('9I97<N<&AP.C4R"B,L('!H<"UF
M;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@=&\@)7,B"FUS9W-T<B`B(@H*
M(SH@861D+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(R
M"FUS9VED(")!9&0B"FUS9W-T<B`B16YG861I<B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<T"B,L(&9U>GIY"FUS9VED
M(")!9&0@861D<F5S<R!B;V]K(@IM<V=S='(@(D$@87AE;F1A(&1E(&5N9&5R
M97IO<R!N;VX@Z2!VX6QI9&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0X"B,L(&9U>GIY"FUS9VED(")!9&0@86YD($1E;&5T92!)35-0(&%D9')E
M<W,@8F]O:W,B"FUS9W-T<B`B3F]N(&AA:2!N:6YG=6YH82!A>&5N9&$@9&4@
M96YD97)E>F]S(&]N9&4@<V4@<&]I9&$@97-C<FEB:7(N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,W"B,L(&9U>GIY"FUS9VED
M(")!9&0@8V]L=6UN(@IM<V=S='(@(F5N9V%D:7(@=6YH82!C;VQU;6YA(@H*
M(SH@961I="YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")!9&0@9FEL92(*;7-G
M<W1R(")&86QL;W4@\R!E;F=A9&ER(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR,@HC+"!F=7IZ>0IM<V=I9"`B061D('1O(@IM<V=S='(@
M(D5N9V%D:7(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC
M+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DEM<&]R=&%R
M(&$@87AE;F1A(&1E(&5N9&5R97IO<R(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S
M<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B02!A>&5N9&$@9&4@96YD97)E>F]S
M('-O86UE;G1E(.D@9&4@;&5C='5R82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T
M<B`B17AP;W)T87(@82!A>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@861D+G!H
M<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R>2(*;7-G
M<W1R(")!(&%X96YD82!D92!E;F1E<F5Z;W,@<V]A;65N=&4@Z2!D92!L96-T
M=7)A+B(*"B,Z(&1A=&$N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S
M<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(D\@87)Q=6EV
M;R`E<R!I;7!O<G1O=7-E(&-O<G)E8W1A;65N=&4B"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B
M;V]K('1O(&1E;&5T92`B"FUS9W-T<B`B02!A>&5N9&$@9&4@96YD97)E>F]S
M('-O86UE;G1E(.D@9&4@;&5C='5R82XB"@HC.B!T96UP;&%T97,O<')E9G,O
M861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`IM<V=I9"`B061D<F5S<R!B;V]K
M<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@
M<V5A<F-H+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S<*
M;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R(")"=7-C82!A=F%N>F%D
M82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C8T"FUS9VED(")!
M;&EA<R(*;7-G<W1R(")!;&-U;64B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O
M;W1E<D%L<&AA+FEN8SHW('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N
M:6YC.C$P"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G
M:60@(D%L;"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HU-3(*;7-G:60@
M(D%L<F5A9'D@17AI<W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8W"FUS
M9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE
M('-E;&5C=&5D(&5N=')I97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-@IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(B(*"B,Z
M('-E87)C:"YP:'`Z.#4@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,V
M"B,L(&9U>GIY"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B0G5S8V%R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B0F5L;W<@
M<V5A<F-H(&9O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HW-R!L:6(O1')I=F5R+VQD87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*;7-G:60@(D)R;W=S
M92(*;7-G<W1R(")%>&%M:6YA<B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z-#D*;7-G:60@(D-35B(*;7-G<W1R("(B"@HC.B!L
M:6(O3V)J96-T+T=R;W5P+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D(&$@9W)O
M=7`@=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V-O;'5M;E]H96%D97)S+FEN8SHW"FUS9VED(")#:&5C:R!?06QL+TYO;F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#0*
M;7-G:60@(D-H;V]S92!A(&YA;64B"FUS9W-T<B`B(@H*(SH@861D+G!H<#HT
M.`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G
M<W1R(")!(&%X96YD82!D92!E;F1E<F5Z;W,@;F]N(.D@=N%L:61A+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R,0HC+"!F=7IZ
M>0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B02!A
M>&5N9&$@9&4@96YD97)E>F]S(&YO;B#I(';A;&ED82XB"@HC.B!T96UP;&%T
M97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$V-0IM<V=I9"`B0VAO
M;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@9&ES<&QA>2P@86YD(&EN('=H
M870@;W)D97(Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,0IM<V=I9"`B0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T
M+FEN8SHR,C@*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!W:&EC:"!C;VQU;6YS
M('1O(&1I<W!L87D@86YD(&EN('=H870@;W)D97(Z(@IM<V=S='(@(D5S8V]L
M;&$@82!O<F1E(&1A<R!C;VQU;6YA<R!Q=64@<V4@=F5RX6X@;F$@;&ES=&$@
M9&4@96YD97)E>F]S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-PIM
M<V=I9"`B0V]L=6UN($]P=&EO;G,B"FUS9W-T<B`B3W!C:?-N<R!D82!C;VQU
M;6YA(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,S
M"FUS9VED(")#;VQU;6YS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(D-O;6UA('-E<&%R
M871E9"!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC
M<F]S;V9T($]U=&QO;VLI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C<V"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D-O;7!A
M\>UA(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"B,L(&9U
M>GIY"FUS9VED(")#;VUP86YY($%D9')E<W,B"FUS9W-T<B`B16YD97)E>F\@
M<&5R<V]A;"(*"B,Z(&QI8B]A<&DN<&AP.C,Q."!L:6(O87!I+G!H<#HS-C,@
M;&EB+V%P:2YP:'`Z-#`W(&QI8B]A<&DN<&AP.C0Y,0HC.B!L:6(O87!I+G!H
M<#HV,#$@;&EB+V%P:2YP:'`Z-C@X(&QI8B]A<&DN<&AP.C<T,2!L:6(O87!I
M+G!H<#HX,3D*(SH@;&EB+V%P:2YP:'`Z,3`P-B!L:6(O87!I+G!H<#HQ,#DT
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B1F%L;&]U(/,@8F]R<F%R(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M=7)E(@IM<V=S='(@(D9A;&QO=2#S(&)O<G)A<B(*"B,Z(&)R;W=S92YP:'`Z
M,3DQ(&)R;W=S92YP:'`Z,C,R"FUS9VED(")#;VYT86-T(&%D9&5D('1O(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z-C`*;7-G:60@(D-O;G1A
M8W0@<F5M;W9E9"!F<F]M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP
M:'`Z,C8V"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]M<&'Q[6$B
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU,PIM<V=I9"`B0W)E
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@061D<F5S<R!";V]K(@IM<V=S
M='(@(D5X<&]R=&%R(&$@87AE;F1A(&1E(&5N9&5R97IO<R(*"B,Z(&QI8B],
M:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A=&4@82!N97<@0V]N=&%C="!,
M:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S
M"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z(&QI8B]/8FIE8W0N
M<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z
M-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")";W)R87(B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M($%D9')E<W,@0F]O:R(*;7-G<W1R("));7!O<G1A<B!A(&%X96YD82!D92!E
M;F1E<F5Z;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@
M(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y"FUS9VED(")$96QE=&4@8G5T=&]N(&)E:&%V:6]U
M<B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(W,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E(&9A:6QE9#H@*"5S*2`E
M<R(*;7-G<W1R(")&86QL;W4@\R!B;W)R87(B"@HC.B!D96QE=&4N<&AP.C,X
M"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T<B`B1F%L;&]U(/,@8F]R
M<F%R(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$S"FUS9VED
M(")$97!A<G1M96YT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*(RP@9G5Z>GD*;7-G:60@(D1E
M<V-R:7!T:6]N(@IM<V=S='(@(D]P8VGS;G,@9&\@=7-U87)I;R(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3@*;7-G:60@(D1I<F5C=&]R
M>2(*;7-G<W1R(")$:7)E8W1O<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(T"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(D]P8VGS
M;G,@9&4@=FES=6%L:7IA8VGS;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!C:?-N<R!D92!V:7-U86QI>F%C
M:?-N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-@IM<V=I9"`B1&\@
M>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R:65S/R(*;7-G<W1R
M("(B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*;7-G:60@(D1O=VYL;V%D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ-R!T96UP
M;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(U"FUS9VED(")$;W=N;&]A
M9"!V0V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L
M871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z,PHC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B
M"FUS9W-T<B`B161I=&%R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC
M.C(U('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(D5D
M:71A<B`G)7,G(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*
M(RP@9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G<W1R(")%
M>'!O<G1A<B!A(&%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!E9&ET+G!H<#HW
M."!E9&ET+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!E;G1R
M>2!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(D-O<G)E;R!%;&5C='+S
M;FEC;R(*"B,Z(&5D:70N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;G1R>2!F;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D960@
M9FEL92!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$T.2!E
M9&ET+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S
M('5P9&%T960N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z-S0*(RP@9G5Z
M>GD*;7-G:60@(D5N=')Y('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R
M(")/(&%R<75I=F\@)7,@:6UP;W)T;W5S92!C;W)R96-T86UE;G1E(@H*(SH@
M;&EB+V%P:2YP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!S96%R8VAI;F<@=&AE(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B
M3F]N(&AA:2!N:6YG=6YH82!A>&5N9&$@9&4@96YD97)E>F]S(&]N9&4@<V4@
M<&]I9&$@97-C<FEB:7(N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHV('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-#$*;7-G:60@(D5X
M<&]R="(*;7-G<W1R(")%>'!O<G1A<B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z-@IM<V=I9"`B17AP;W)T($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")%>'!O<G1A<B!A(&%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")%>'!O<G0@;VYL>2!T:&4@
M<V5L96-T960@8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,C<*;7-G:60@(D5X<&]R="!T:&4@9F]L;&]W:6YG
M(&%D9')E<W,@8F]O:R!C;VUP;&5T96QY+B(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!B<F]W<V4N<&AP
M.C,U(&)R;W=S92YP:'`Z.3`*(SH@8G)O=W-E+G!H<#HQ,3(@861D+G!H<#HV
M-R!S96%R8V@N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@
M(D9A;&QO=2!O(&)U<V-A<B!N;R!D:7)E8W1O<FEO.B`E<R(*"B,Z(&)R;W=S
M92YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@861D("5S('1O("5S.B`E<R(*;7-G<W1R(")&86QL;W4@;R!B=7-C87(@
M;F\@9&ER96-T;W)I;SH@)7,B"@HC.B!B<F]W<V4N<&AP.C(W,@HC+"!F=7IZ
M>0IM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!L:7-T(@IM<V=S='(@(D9A;&QO
M=2#S(&)U<V-A<B!N;R!D:7)E8W1O<FEO.B`E<R(*"B,Z(&)R;W=S92YP:'`Z
M,S$P"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8G)O=W-E('1H92!D:7)E
M8W1O<GDB"FUS9W-T<B`B1F%L;&]U(/,@8G5S8V%R(&YO(&1I<F5C=&]R:6\Z
M("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@
M1$X@/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R("(B"@HC
M.B!B<F]W<V4N<&AP.C$R,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&9I;F0@;V)J96-T('1O(&)E(&%D9&5D.B`E<R(*;7-G<W1R
M(")&86QL;W4@;R!B=7-C87(@;F\@9&ER96-T;W)I;SH@)7,B"@HC.B!S96%R
M8V@N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H
M92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B1F%L;&]U(&\@8G5S8V%R(&YO(&1I
M<F5C=&]R:6\Z("5S(@H*(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,B"FUS
M9W-T<B`B1F%L;&]U(&\@8G5S8V%R(&YO(&1I<F5C=&]R:6\Z("5S(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38W"FUS9VED(")&87@B"FUS
M9W-T<B`B1F%X(@H*(SH@961I="YP:'`Z,3(T(&1I<W!L87DN<&AP.C$P,`HC
M+"!F=7IZ>0IM<V=I9"`B1FEL97,B"FUS9W-T<B`B5.UT=6QO(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<P"FUS9VED(")&:6YD(@IM<V=S
M='(@(D%T;W!A<B(*"B,Z(&5D:70N<&AP.CDW(&5D:70N<&AP.C$X-PHC+"!F
M=7IZ>0IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(D%T;W!A<B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0X"FUS9VED(")&:7)S="!.86UE(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P,@IM
M<V=I9"`B1G)E96)U<WD@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<V5A<F-H+FEN8SHX,PIM<V=I9"`B1G)O;2(*;7-G<W1R(")$92(*
M"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C8P-`HC+"!F=7IZ>0IM<V=I
M9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R("));7!O<G1A<B!A(&%X
M96YD82!D92!E;F1E<F5Z;W,B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT-`IM<V=I
M9"`B1W)O=7`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")%;F1E<F5Z
M;R!P97)S;V%L(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3,*
M;7-G:60@(DAO;64@0VET>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ,#@*(RP@9G5Z>GD*;7-G:60@(DAO;64@0V]U;G1R
M>2(*;7-G<W1R(")496SI9F]N;R!P97)S;V%L(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,34P"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@
M(E1E;.EF;VYO('!E<G-O86PB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DAO;64@4&]S=&%L($-O9&4B"FUS
M9W-T<B`B5&5LZ69O;F\@<&5R<V]A;"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED(")(;VUE(%-T871E+U!R;W9I
M;F-E(@IM<V=S='(@(E1E;.EF;VYO('!E<G-O86PB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HX.`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!3=')E
M970@061D<F5S<R(*;7-G<W1R(")%;F1E<F5Z;R!P97)S;V%L(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z-3`V"FUS9VED("))35-0(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-PIM<V=I9"`B24U34"!!
M9&1R97-S($)O;VL@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G0@061D<F5S<R!";V]K+"!3=&5P("5D(@IM<V=S='(@
M(DEM<&]R=&%R(&$@87AE;F1A(&1E(&5N9&5R97IO<R(*"B,Z(&1A=&$N<&AP
M.C,V,0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T+T5X<&]R="!!9&1R97-S($)O
M;VMS(@IM<V=S='(@(DEM<&]R=&%R+V5X<&]R=&%R(&$@87AE;F1A(&1E(&5N
M9&5R97IO<R(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O87!I+G!H<#HV.#,*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`B3R!N;VUE(&YO
M;B#I(';A;&ED;RXB"@HC.B!L:6(O87!I+G!H<#HR,S`@;&EB+V%P:2YP:'`Z
M-#`R(&QI8B]A<&DN<&AP.C0X-B!L:6(O87!I+G!H<#HU.3(*(SH@;&EB+V%P
M:2YP:'`Z-C<Y(&QI8B]A<&DN<&AP.C<S,2!L:6(O87!I+G!H<#HQ,#<W"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!
M(&%X96YD82!D92!E;F1E<F5Z;W,@;F]N(.D@=N%L:61A+B(*"B,Z(&QI8B]A
M<&DN<&AP.C$P.#$@;&EB+V%P:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ,C`W
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(D\@96YD
M97)E>F\@9&4@8V]R<F5O(&YO;B#I(';A;&ED;RXB"@HC.B!L:6(O87!I+G!H
M<#HQ,#@Y"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&5N=')Y(@IM<V=S='(@
M(D\@;F]M92!N;VX@Z2!VX6QI9&\N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HR-C8*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@:V5Y('-P96-I9FEE9"XB
M"FUS9W-T<B`B3R!V86QO<B!E<W!E8VEF:6-A9&\@;F]N(.D@=N%L:61O(@H*
M(SH@;&EB+V%P:2YP:'`Z,3`X-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!N
M86UE(@IM<V=S='(@(D\@;F]M92!N;VX@Z2!VX6QI9&\N(@H*(SH@;&EB+V%P
M:2YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]B:F5C=$ED(@IM
M<V=S='(@(D\@;F]M92!N;VX@Z2!VX6QI9&\N(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D
M(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X
M"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C4S"B,L(&9U>GIY"FUS9VED("),87-T($YA
M;64B"FUS9W-T<B`B3F]M92(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN
M7VAE861E<G,N:6YC.C$V"FUS9VED("),:7-T(@IM<V=S='(@(DQI<W1A<B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW-PIM<V=I9"`B36%T
M8VAI;F<B"FUS9W-T<B`B<75E(&-O:6YC:61A(&-O;B(*"B,Z(&QI8B]A<&DN
M<&AP.C(P-0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B
M36%X:6UU;2!N=6UB97(@;V8@<&%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1R965?;65N=2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!,:7-T
M(@IM<V=S='(@(DQI<W1A<B(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H
M<#HS"B,L(&9U>GIY"FUS9VED(")-:6YI(%-E87)C:"(*;7-G<W1R(")"=7-C
M87(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN
M9R!$3B!I;B!,1$%0('-O=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*(RP@9G5Z>GD*
M;7-G:60@(DUO8FEL92!0:&]N92(*;7-G<W1R(")496SI9F]N;R!P97)S;V%L
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,S(@;&EB+T1R:79E<B]L9&%P
M+G!H<#HS-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,3DS"FUS9VED
M(")-;W)E('1H86X@,2!E;G1R>2!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")-;W9E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T
M-PHC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X
M-`HC+"!F=7IZ>0IM<V=I9"`B36]V92!L969T(@IM<V=S='(@(FUO=F5R(.$@
M97-Q=65R9&$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN
M8SHR-#D*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN
M8SHQ.#8*(RP@9G5Z>GD*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B;6]V
M97(@X2!D97)E:71A(@H*(SH@9&%T82YP:'`Z-3(@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B375L8F5R<GD@061D<F5S
M<R!";V]K(@IM<V=S='(@(DEM<&]R=&%R(&$@87AE;F1A(&1E(&5N9&5R97IO
M<R(*"B,Z(&QI8B]A<&DN<&AP.C$Q,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB375L=&EP;&4@<&5R<V]N<R!W:71H(&%D9')E<W,@6R5S72P@8G5T(&YO
M;F4@=VET:"!N86UE(%LE<UT@86QR96%D>2!E>&ES="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ,#<@8V]N9FEG+W-O=7)C97,N
M<&AP+F1I<W0Z,C0S"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B26UP;W)T87(@82!A>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E
M<W,@0F]O:W,B"FUS9W-T<B`B17AP;W)T87(@82!A>&5N9&$@9&4@96YD97)E
M>F]S(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`W(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0R"FUS9VED(").86UE(@IM<V=S='(@
M(DYO;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA
M;64@1F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&\@;F]M92(*"B,Z(&-O;F9I
M9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T8V5N=&5R($UE;6)E
M<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@861D+G!H<#HS-B!A9&0N<&AP
M.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*(SH@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE=R!#;VYT86-T
M(@IM<V=S='(@(D5N9V%D:7(@=6X@;F]V;R!C;VYT86-T;R(*"B,Z(&5D:70N
M<&AP.C@X(&5D:70N<&AP.CDU(&5D:70N<&AP.C(P,B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q.`HC+"!F=7IZ>0IM<V=I9"`B
M3FEC:VYA;64B"FUS9W-T<B`B3F]M92(*"B,Z(&QI8B]A<&DN<&AP.C$Q.34@
M;&EB+V%P:2YP:'`Z,3(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E
M;G1R>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,3$V,PHC+"!F=7IZ>0IM<V=I9"`B3F\@861D<F5S<R!B;V]K<R!F;W5N9"XB
M"FUS9W-T<B`B02!A>&5N9&$@9&4@96YD97)E>F]S('-O86UE;G1E(.D@9&4@
M;&5C='5R82XB"@HC.B!M:6YI<V5A<F-H+G!H<#HX,PIM<V=I9"`B3F\@8V]N
M=&%C=',@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-3$Q(&QI
M8B]A<&DN<&AP.C<V-@IM<V=I9"`B3F\@=D-A<F0@9&%T82!W87,@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHW
M"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(DYO=&%S(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3@T"FUS9VED(").;W1E<R(*;7-G
M<W1R(").;W1A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G
M:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HV,30@;&EB+V%P:2YP:'`Z-S0W"FUS9VED(")/8FIE8W0@
M;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N8V4@>6]U
M('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL
M(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@;F]T('=H
M870@>6]U('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T
M:6]N("(*(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HW-S0*;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-@HC+"!F=7IZ>0IM<V=I9"`B3W1H97(@3W!T:6]N<R(*
M;7-G<W1R(")/<&-I\VYS(&1O('5S=6%R:6\B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C0Y-2!L:6(O87!I+G!H<#HV,#4@;&EB
M+V%P:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.CDS-`HC.B!L:6(O87!I+G!H<#HQ
M,#DX"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!L
M:6(O1')I=F5R+G!H<#HU-#,*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDY"FUS
M9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,R!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")0
M:6YE($%D9')E<W,@0F]O:R(*;7-G<W1R("));7!O<G1A<B!A(&%X96YD82!D
M92!E;F1E<F5Z;W,B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N
M:6YC.C(X"FUS9VED(")0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@;&ES
M=#HB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z.3$@961I="YP:'`Z.30@961I
M="YP:'`Z,3DT"FUS9VED(")0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<V]U<F-E<RYP:'`N9&ES=#HT,38*(RP@9G5Z>GD*;7-G:60@(E!R:79A
M=&4@061D<F5S<R!";V]K(@IM<V=S='(@(D5X<&]R=&%R(&$@87AE;F1A(&1E
M(&5N9&5R97IO<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30W"B,L('!H
M<"UF;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,3@*(RP@
M9G5Z>GD*;7-G:60@(E%U:6-K(%-E87)C:"(*;7-G<W1R(")"=7-C87(B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C$Y,2!L:6(O1')I=F5R+VQD87`N<&AP
M.C$Y.2!L:6(O1')I=F5R+VQD87`N<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M4F5N9&5R97(N<&AP.C0Y"FUS9VED(")296%L;'D@9&5L971E('1H:7,@8V]N
M=&%C=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N
M:6YC.C(*;7-G:60@(E)E8V]R9',@9&ES<&QA>65D.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-@HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&%D9')E<W,@8F]O:R(*;7-G<W1R("))
M;7!O<G1A<B!A(&%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!T96UP;&%T97,O
M<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,SD*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!C;VQU;6XB"FUS9W-T<B`B96QI;6EN87(@82!C;VQU;6YA(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED(")296UO=F4@
M9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHR,0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R
M97-S(&)O;VL@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI
M;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E
M;G0@861D<F5S<R!B;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HT,S@*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C,W('1E;7!L871E<R]B<F]W
M<V4O<V5A<F-H+FEN8SHQ,3,*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM
M<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T:69I8V%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E-405)45$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!E9&ET
M+G!H<#HY.2!A9&0N<&AP.C,W('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C$R-`IM<V=I9"`B4V%V92(*;7-G<W1R(")'87)D87(B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+W-E87)C:"YI;F,Z.38@=&5M<&QA=&5S+V)R;W=S92]S96%R
M8V@N:6YC.C$Q,@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z
M,C$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z-#D*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(D)U<V-A<B(*
M"B,Z(&UI;FES96%R8V@N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")396%R8V@@
M4F5S=6QT<SHB"FUS9W-T<B`B4F5S=6QT861O<R!D82!B=7-C82(*"B,Z(&QI
M8B]A<&DN<&AP.C$P,3$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!F86EL960B
M"FUS9W-T<B`B0G5S8V%R(@H*(SH@;&EB+V%P:2YP:'`Z,3$P,R!L:6(O87!I
M+G!H<#HQ,3`Y(&QI8B]A<&DN<&AP.C$Q,3@@;&EB+V%P:2YP:'`Z,3$S,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C(*(RP@
M9G5Z>GD*;7-G:60@(E-E87)C:&EN9RXN+B(*;7-G<W1R(")"=7-C87(B"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B
M17-C;VQL82!U;FAA(&%X96YD82!D92!E;F1E<F5Z;W,@<&%R82!E;F=A9&ER
M(&\@8V]N=&%C=&\N(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M.3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@
M961I="(*;7-G<W1R(")%<V-O;&QA('5N:&$@87AE;F1A(&1E(&5N9&5R97IO
M<R!P87)A(&5N9V%D:7(@;R!C;VYT86-T;RXB"@HC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&%D
M9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T<B`B17-C;VQL82!A
M(&9O;G1E(&5N('%U92!O('%U97)E(&5X<&]R=&%R.B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T
M:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B17-C;VQL
M82!O(&1E<W1I;F\@9&$@:6UP;W)T86-I\VXZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C
M:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B17-C;VQL82!A
M(&9O;G1E(&5N('%U92!O('%U97)E(&5X<&]R=&%R.B(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T
M:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B17-C;VQL82!A(&9O;G1E(&5N
M('%U92!O('%U97)E(&5X<&]R=&%R.B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z-#,*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z
M(@IM<V=S='(@(D5S8V]L;&$@;R!A<G%U:79O('%U92!Q=65R92!I;7!O<G1A
M<CHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z
M(@IM<V=S='(@(D5S8V]L;&$@;R!F;W)M871O(&5N('%U92!O('%U97)E(&5X
M<&]R=&%R.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@
M(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SHB"FUS
M9W-T<B`B4V5L96-C:6]N87(@;R!F;W)M871O('5S861O('!A<F$@86UO<V%R
M(&]S(&YO;65S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-0HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT
M+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`B
M4V5L96-C:6]N87(@=FES=&$@<&%R82!A;6]S87(@<&]R(&1E9F5C=&\N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")396QE8W0@=VAI
M8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N(@IM
M<V=S='(@(D5S8V]L;&$@;W,@8V%M<&]S('%U92!S92!V97+A;B!N87,@;&ES
M=&%S(&1E(&5N9&5R97IO<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S(*;7-G:60@(E-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA>2!N86UE
M<RXB"FUS9W-T<B`B4V5L96-C:6]N87(@;R!F;W)M871O('!A<F$@86UO<V%R
M(&]S(&YO;65S+B(*"B,Z(&%D9"YP:'`Z-30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-E;&5C=&5D(&%D9')E<W,@8F]O:R!<(B5S7"(N(@IM<V=S
M='(@(D$@87AE;F1A(&1E(&5N9&5R97IO<R!N;VX@Z2!VX6QI9&$N(@H*(SH@
M8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3<S"B,L(&9U>GIY"FUS9VED(")3
M:&%R960@1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=&]R:6\B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E-H;W<@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHT,0IM<V=I9"`B4VAO=R!!;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B4VAO=R!#
M;VYT86-T<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C,Y"FUS9VED(")3:&]W($QI<W1S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C(Q"B,Z('1E;7!L
M871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C,T"B,L(&9U>GIY"FUS
M9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R(")$:7)E8W1O<FEO(@H*(SH@
M;&EB+V%P:2YP:'`Z,3DX"B,L(&9U>GIY"FUS9VED(")3;W5R8V5S(@IM<V=S
M='(@(D-O<G)E8W1A;65N=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34W"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E
M87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E
M+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D
M9&5D("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C(R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C
M;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU
M,`IM<V=I9"`B5%-6(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-`IM<V=I
M9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B(@H*(SH@=FEE=RYP
M:'`Z,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D<R!T;R!B92!C;VYF
M:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A9',N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E
M<UPB('=A<R!R96UO=F5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T960N
M(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S
M(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C0W('9C87)D+G!H<#HR,B!D:7-P
M;&%Y+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A8W0@>6]U
M(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@961I
M="YP:'`Z,3$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL
M92!<(B5S7"(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N(@IM<V=S
M='(@(D\@87)Q=6EV;R`E<R!I;7!O<G1O=7-E(&-O<G)E8W1A;65N=&4B"@HC
M.B!D871A+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@8V%N(&)E(&9I;FES
M:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R("(B"@HC.B!B<F]W
M<V4N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E
M86)L92!A9&1R97-S(&)O;VMS+B(*;7-G<W1R(").;VX@:&%I(&YI;F=U;FAA
M(&%X96YD82!D92!E;F1E<F5Z;W,@;VYD92!S92!P;VED82!E<V-R:6)I<BXB
M"@HC.B!A9&0N<&AP.C(Y"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!A<F4@
M;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL
M86)L92!A9&1R97-S(&)O;VMS("(*(F%R92!C;VYF:6=U<F5D('1O(&%L;&]W
M('EO=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE
M=F4@=&AI<R`B"B)I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3FEN9W5N:&$@9&%S
M(&%X96YD87,@9&4@96YD97)E>F]S(&1I<W!O\6EB;&5S(&5S=.$@8V]N9FEG
M=7)A9&$@<&%R82`B"B)P97)M:71I<FQL92!E;F=A9&ER(&YO=F%S(&5N=')A
M9&%S+B!087)A(&%M8?%A;&\L(&-O;G1A8W1E(&-O(&%D;6EN:7-T<F%D;W(@
M(@HB9&\@<VES=&5M82XB"@HC.B!A9&0N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A
M8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B`B"B)F;W(@
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)(;W5B;R!U;B!P<F]B;&5M82!O
M(&5N9V%D:7(@97-T92!O8GAE8W1O+B!#;VYT86-T92!C;R!A9&UI;FES=')A
M9&]R(&1O("(*(G-I<W1E;6$@<&%R82!O8G1E<B!A>'5D82XB"@HC.B!B<F]W
M<V4N<&AP.C$X.2!B<F]W<V4N<&AP.C(S,`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B
M2&]U8F\@=6X@<')O8FQE;6$@\R!I;7!O<G1A<B!O<R!D871O<RXB"@HC.B!B
M<F]W<V4N<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N(@IM<V=S='(@(DAO=6)O('5N('!R
M;V)L96UA(/,@:6UP;W)T87(@;W,@9&%T;W,N(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G
M<W1R(")(;W5B;R!U;B!P<F]B;&5M82#S(&EM<&]R=&%R(&\@87)Q=6EV;R!E
M;G9I861O(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<(B5S7"(@
M9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2&]U8F\@
M=6X@<')O8FQE;6$@\R!I;7!O<G1A<B!O(&%R<75I=F\@96YV:6%D;R(*"B,Z
M(&1E;&5T92YP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S(@IM
M<V=S='(@(DAO=6)O('5N('!R;V)L96UA(/,@:6UP;W)T87(@;W,@9&%T;W,N
M(@H*(SH@8G)O=W-E+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R(")(;W5B
M;R!U;B!P<F]B;&5M82#S(&EM<&]R=&%R(&]S(&1A=&]S+B(*"B,Z(&)R;W=S
M92YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R(")(;W5B;R!U;B!P<F]B;&5M
M82#S(&EM<&]R=&%R(&]S(&1A=&]S+B(*"B,Z(&1A=&$N<&AP.C,S-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`B2&]U8F\@=6X@<')O8FQE
M;6$@\R!I;7!O<G1A<B!O<R!D871O<RXB"@HC.B!L:6(O87!I+G!H<#HU,#<@
M;&EB+V%P:2YP:'`Z-S8Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B
M2&]U8F\@=6X@<')O8FQE;6$@\R!I;7!O<G1A<B!O<R!D871O<RXB"@HC.B!B
M<F]W<V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@<F5M;W9I;F<@82!C;VYT86-T(&9R;VT@=&AE(&QI<W0N(@IM<V=S='(@
M(DAO=6)O('5N('!R;V)L96UA(/,@:6UP;W)T87(@;W,@9&%T;W,N(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HU-2!A9&1R97-S8F]O:W,N<&AP.C8P(&%D9')E
M<W-B;V]K<RYP:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@
M)7,B"FUS9W-T<B`B2&]U8F\@=6X@<')O8FQE;6$@\R!I;7!O<G1A<B!O(&%R
M<75I=F\@96YV:6%D;R(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#$@861D<F5S
M<V)O;VMS+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E
M<R(*;7-G<W1R(")(;W5B;R!U;B!P<F]B;&5M82#S(&EM<&]R=&%R(&\@87)Q
M=6EV;R!E;G9I861O(@H*(SH@961I="YP:'`Z,34X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI
M<R!E;G1R>3H@)7,B"FUS9W-T<B`B2&]U8F\@=6X@<')O8FQE;6$@\R!I;7!O
M<G1A<B!O<R!D871O<RXB"@HC.B!D871A+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G
M:60@(E1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="XB"FUS9W-T
M<B`B3F]N(&AA:2!N:6YG=6YH82!A>&5N9&$@9&4@96YD97)E>F]S(&]N9&4@
M<V4@<&]I9&$@97-C<FEB:7(N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E
M<W-B;V]K<V5L96-T+FEN8SHQ.#`*;7-G:60@(E1H97-E(&%D9')E<W,@8F]O
M:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T,PIM<V=I9"`B
M5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS
M9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED(")4:&ES(&9I;&4@9F]R
M;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$Q,C(@;&EB+V%P:2YP:'`Z,3$S-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I
M;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(EAA(&5S=.$@<F5X:7-T<F%D
M82!N82!S^F$@87AE;F1A(&1E(&5N9&5R97IO<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30W"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E
M9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C
M;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-S`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E3M='5L;R(*"B,Z(&QI
M8B]4=7)B82YP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@;F5W('-H87)E+B`@36ES<VEN9R!S;W5R8V4@='EP92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z.3<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R(").;VX@Z2!P;W-I8FQE(&-A<F=A<B!A(&1E9FEN:6-I\VX@9&4@
M)7,N(@H*(SH@961I="YP:'`Z.#@@961I="YP:'`Z.3$@961I="YP:'`Z.30@
M961I="YP:'`Z.3D@961I="YP:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")5;F1O
M($-H86YG97,B"FUS9W-T<B`B1V%R9&%R(&]S(&-A;6)I;W,B"@HC.B!L:6(O
M87!I+G!H<#HU-#`@;&EB+V%P:2YP:'`Z-C0S(&QI8B]A<&DN<&AP.C<W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z
M("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,W
M-@HC+"!F=7IZ>0IM<V=I9"`B5F5R:7-I9VX@1&ER96-T;W)Y(@IM<V=S='(@
M(D1I<F5C=&]R:6\B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3D@
M=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHR-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!M:6YI<V5A
M<F-H+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S
M='(@(D5N9V%D:7(@=6X@;F]V;R!C;VYT86-T;R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E9I97<@=&\@9&ES<&QA>2!B>2!D969A
M=6QT.B(*;7-G<W1R(")6:7-T82!A(&%M;W-A<B!P;W(@9&5F96-T;SHB"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,#@*;7-G:60@(E=E8G-I
M=&4@55),(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$Q,PIM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO
M(&1O('1R86)A;&QO(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3(T"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")7;W)K($-O
M=6YT<GDB"FUS9W-T<B`B5&5LZ69O;F\@9&\@=')A8F%L;&\B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O<FL@4&AO;F4B
M"FUS9W-T<B`B5&5LZ69O;F\@9&\@=')A8F%L;&\B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E=O<FL@4&]S
M=&%L($-O9&4B"FUS9W-T<B`B5&5LZ69O;F\@9&\@=')A8F%L;&\B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*(RP@9G5Z>GD*;7-G:60@
M(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B5&5LZ69O;F\@9&\@=')A
M8F%L;&\B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3D*(RP@
M9G5Z>GD*;7-G:60@(E=O<FL@4W1R965T($%D9')E<W,B"FUS9W-T<B`B16YD
M97)E>F\@9&\@=')A8F%L;&\B"@HC.B!D871A+G!H<#HR,S<@8G)O=W-E+G!H
M<#HY,R!B<F]W<V4N<&AP.C(P,2!A9&0N<&AP.C<S"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&5D:70N
M<&AP.C8Y(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB
M"FUS9W-T<B`B(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@9&\@;F]T
M(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C4U"FUS
M9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C(S"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB"FUS
M9W-T<B`B(@H*(SH@961I="YP:'`Z,S(*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O
M8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C0Y"B,Z('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L
M96%S="!O;F4@96YT<GD@9FER<W0N(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP
M.C<S"FUS9VED(")9;W4@;VYL>2!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T
M:&ES(&-O;G1A8W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C@U"FUS
M9VED(")9;W5R(&1E9F%U;'0@861D<F5S<R!B;V]K(&ES(&YO="!B<F]W<V5A
M8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z
M-B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS9VED(");
M;F\@=F%L=65=(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@T"B,L
M(&9U>GIY"FUS9VED(")?0G)O=W-E(@IM<V=S='(@(D5X86UI;F%R(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B7T-O;G1A
M8W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z,@HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")";W)R87(B
M"@HC.B!L:6(O5'5R8F$N<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I9"`B7TEM<&]R
M="]%>'!O<G0B"FUS9W-T<B`B26UP;W)T87(O97AP;W)T87(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY"FUS9VED(")?
M3&ES=',B"FUS9W-T<B`B3&ES=&%R(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#$*
M(RP@9G5Z>GD*;7-G:60@(E]->2!!9&1R97-S($)O;VMS(@IM<V=S='(@(DEM
M<&]R=&%R(&$@87AE;F1A(&1E(&5N9&5R97IO<R(*"B,Z(&QI8B]4=7)B82YP
M:'`Z-#@W"B,L(&9U>GIY"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T<B`B
M16YG861I<B!U;B!N;W9O(&-O;G1A8W1O(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHR"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@Y"B,L(&9U>GIY"FUS
M9VED(")?4V5A<F-H(@IM<V=S='(@(D)U<V-A<B(*"B,Z('9C87)D+G!H<#HT
M-@IM<V=I9"`B8V]N=&%C="YV8V8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M,3DY(&1A=&$N<&AP.C(P-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*
M;7-G:60@(F-O;G1A8W1S+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR
M,#D*;7-G:60@(F-O;G1A8W1S+G1S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HR,3D*;7-G:60@(F-O;G1A8W1S+G9C9B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C,T"FUS9VED(")N;VYE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C0*;7-G
M:60@(G1O(&$@0V]N=&%C="!,:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(G1O(&$@
M9&EF9F5R96YT($%D9')E<W,@0F]O:R(*;7-G<W1R("));7!O<G1A<B!A(&%X
M96YD82!D92!E;F1E<F5Z;W,B"@HC.B!D871A+G!H<#HU,2!T96UP;&%T97,O
M8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ,PHC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$U('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,34*
M;7-G:60@(G9#87)D(@IM<V=S='(@(B(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]P;R]C85]%4RYP;P``
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<R-S8V
M`#$P-#$W,S8R-S4V`#`Q-S4Q,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C(%1U<F)A($-A=&%L86X@=')A;G-L871I;VXN
M"B,@0V]P>7)I9VAT("A#*2`R,#`S($%N9V5L<R!'=6EM97+@"B,@06YG96QS
M($=U:6UE<N`@/$%N9V5L<RY'=6EM97)A0'5A8BYE<SXL(#(P,#,N"B,*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A(#$N
M,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R
M,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#(M,3@@,#DZ,SDK,#$P
M,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!!;F=E;',@1W5I;65RX"`\06YG96QS
M+D=U:6UE<F%`=6%B+F5S/EQN(@HB3&%N9W5A9V4M5&5A;3H@0V%T86QA;B`\
M9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM
M,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHT,@IM<V=I9"`B($%D9"!A
M;B!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O:6US<%]O<'0N:6YC.C,Q"FUS9VED("(@1&5L971E($E-4U`@061D
M<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,R-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR96%D>2!E>&ES=',@86YD('=A<R!N
M;W0@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(V"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A
M=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@;6]V960@
M8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@(EPB1FER<W1N86UE($QA<W1N86UE
M7"(@("AI92X@2F]H;B!$;V4I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S8*;7-G:60@(EPB3&%S=&YA;64L($9I<G-T;F%M95PB
M("AI92X@1&]E+"!*;VAN*2(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C$P.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@
M9&%T82YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C
M8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(DPG87)X:74@)7,@:&$@97-T
M870@:6UP;W)T870@<V%T:7-F86-T\G)I86UE;G0B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V9O;W1E<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T
M;R`E<R!O9B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0T-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B26UP;W)T87(@3&QI8G)E=&$@9"=A9')E8V5S(@H*(SH@;&EB
M+T)L;V-K+VUI;FES96%R8V@N<&AP.C0U"FUS9VED(")!(&)R;W=S97(@=&AA
M="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3D*;7-G:60@(D%B;W9E('-E87)C
M:"!F;W)M(@IM<V=S='(@(B(*"B,Z('9I97<N<&AP.C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(D%C8V5S<R!D96YI960@=&\@)7,B"FUS9W-T<B`B(@H*(SH@
M861D+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(R"FUS
M9VED(")!9&0B"FUS9W-T<B`B069E9VER(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S0*(RP@9G5Z>GD*;7-G:60@(D%D
M9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3&$@;&QI8G)E=&$@9"=A9')E8V5S
M(&YO(.ES(';@;&ED82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@861D<F5S<R!B
M;V]K<R(*;7-G<W1R(").;R!H:2!H82!L;&EB<F5T97,@9"=A9')E8V5S(&]N
M(&5S('!U9W5I(&5S8W)I=7)E+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(S-PHC+"!F=7IZ>0IM<V=I9"`B061D(&-O;'5M;B(*
M;7-G<W1R(")A9F5G:7(@8V]L=6UN82(*"B,Z(&5D:70N<&AP.C$R.`HC+"!F
M=7IZ>0IM<V=I9"`B061D(&9I;&4B"FUS9W-T<B`B2&$@9F%L;&%T(&%L(&%F
M96=I<B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C(*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!T;R(*;7-G<W1R(")!9F5G:7(B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(DEM<&]R=&%R($QL:6)R971A(&0G861R96-E
M<R(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T
M<B`B3&$@3&QI8G)E=&$@9"=A9')E8V5S(&YO;>ES(.ES(&1E(&QE8W1U<F$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"B,L(&9U>GIY"FUS9VED
M(")!9&1R97-S($)O;VMS(@IM<V=S='(@(DEM<&]R=&%R($QL:6)R971A(&0G
M861R96-E<R(*"B,Z(&%D9"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")!9&1R
M97-S(&)O;VL@96YT<GDB"FUS9W-T<B`B3&$@3&QI8G)E=&$@9"=A9')E8V5S
M(&YO;>ES(.ES(&1E(&QE8W1U<F$N(@H*(SH@9&%T82YP:'`Z,S`U"B,L(&9U
M>GIY"FUS9VED(")!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"XB
M"FUS9W-T<B`B3"=A<GAI=2`E<R!H82!E<W1A="!I;7!O<G1A="!S871I<V9A
M8W3R<FEA;65N="(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8R
M"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(&)O;VL@=&\@9&5L971E("(*;7-G
M<W1R("),82!,;&EB<F5T82!D)V%D<F5C97,@;F]MZ7,@Z7,@9&4@;&5C='5R
M82XB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC
M.C$W,`IM<V=I9"`B061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I
M<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HX."!T96UP;&%T
M97,O8G)O=W-E+W-E87)C:"YI;F,Z,S<*;7-G:60@(D%D=F%N8V5D(%-E87)C
M:"(*;7-G<W1R(")#97)C82!!=F%NYV%D82(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C8T"FUS9VED(")!;&EA<R(*;7-G<W1R("+`;&EE<R(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C4U,@IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N
M="!T;R!D96QE=&4@)7,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T
M('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!
M<V-E;F1I;F<B"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HX-2!T96UP;&%T
M97,O8G)O=W-E+W-E87)C:"YI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(D)A<VEC
M(%-E87)C:"(*;7-G<W1R(")#97)C87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,34X"FUS9VED(")"96QO=R!S96%R8V@@9F]R;2(*;7-G<W1R("(B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z("@E<RD@
M)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3<X"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65N=2YI;F,Z-PIM<V=I9"`B0G)O=W-E(@IM<V=S='(@(D5X86UI;F%R(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<S"FUS9VED(")"=7-I
M;F5S<R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HT.0IM<V=I
M9"`B0U-6(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W0O1W)O=7`N<&AP.C4W
M"FUS9VED(")#86XG="!A9&0@82!G<F]U<"!T;R!I='-E;&8N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C<*
M;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHT-`IM<V=I9"`B0VAO;W-E(&$@;F%M92(*
M;7-G<W1R("(B"@HC.B!A9&0N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#:&]O
M<V4@86X@861D<F5S<R!B;V]K(@IM<V=S='(@(DQA(&QL:6)R971A(&0G861R
M96-E<R!N;R#I<R!VX&QI9&$N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M
M;G-E;&5C="YI;F,Z,C(Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@861D
M<F5S<R!B;V]K.B(*;7-G<W1R("),82!L;&EB<F5T82!D)V%D<F5C97,@;F\@
MZ7,@=N!L:61A+B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E
M;&5C="YI;F,Z,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K
M<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED(")#:&]O<V4@=VAI
M8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R.`HC+"!F=7IZ>0IM<V=I
M9"`B0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA
M="!O<F1E<CHB"FUS9W-T<B`B(@HB17-C;VQL:74@;"=O<F1R92!D92!L97,@
M8V]L=6UN97,@<75E('9O;&5U('9I<W5S86QI='IA<B!A(&QA(&QL:7-T82`B
M"B)D)V%D<F5C97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS
M9VED(")#;VQU;6X@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS(&1E(&QA($-O
M;'5M;F$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR
M,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3,@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I9"`B0V]M;6$@<V5P
M87)A=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S("A-
M:6-R;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B0V]M
M<&%N>6EA(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"B,L
M(&9U>GIY"FUS9VED(")#;VUP86YY($%D9')E<W,B"FUS9W-T<B`B061R9>=A
M(%!E<G-O;F%L(@H*(SH@;&EB+V%P:2YP:'`Z,S$X(&QI8B]A<&DN<&AP.C,V
M,R!L:6(O87!I+G!H<#HT,#<@;&EB+V%P:2YP:'`Z-#DQ"B,Z(&QI8B]A<&DN
M<&AP.C8P,2!L:6(O87!I+G!H<#HV.#@@;&EB+V%P:2YP:'`Z-S0Q(&QI8B]A
M<&DN<&AP.C@Q.0HC.B!L:6(O87!I+G!H<#HQ,#`V(&QI8B]A<&DN<&AP.C$P
M.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R(")(82!F86QL870@86P@96QI;6EN87(B"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QU<F4B"FUS9W-T<B`B2&$@9F%L;&%T(&%L(&5L:6UI;F%R(@H*
M(SH@8G)O=W-E+G!H<#HQ.3$@8G)O=W-E+G!H<#HR,S(*;7-G:60@(D-O;G1A
M8W0@861D960@=&\@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HV
M,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES="XB"FUS9W-T<B`B
M(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*;7-G
M<W1R(")#;VUP86YY:6$B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHU,PIM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@061D
M<F5S<R!";V]K(@IM<V=S='(@(D5X<&]R=&%R($QL:6)R971A(&0G861R96-E
M<R(*"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A=&4@82!N
M97<@0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T
M5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG
M(&1I<F5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-S8@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z
M(&QI8B]/8FIE8W0N<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]2
M96YD97)E<BYP:'`Z-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")%;&EM:6YA
M<B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C4X"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@061D<F5S<R!";V]K(@IM<V=S='(@(D5X<&]R=&%R
M($QL:6)R971A(&0G861R96-E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T
M;VX@8F5H879I;W5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I
M;&5D.B`H)7,I("5S(@IM<V=S='(@(DAA(&9A;&QA="!A;"!E;&EM:6YA<B(*
M"B,Z(&1E;&5T92YP:'`Z,S@*;7-G:60@(D1E;&5T:6]N(&9A:6QE9"(*;7-G
M<W1R(")(82!F86QL870@86P@96QI;6EN87(B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$97-C96YD
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C$Q-0HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B3W!C
M:6]N<R!D92!L)U5S=6%R:2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H
M+FEN8SHQ,3@*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$:7)E8W1O<FDB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@
M(D1I<W!L87DB"FUS9W-T<B`B3W!C:6]N<R!D92!6:7-U86QI='IA8VGS(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M(")/<&-I;VYS(&1E(%9I<W5A;&ET>F%C:?,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3<V"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E
M;&5T:6YG(&5N=')I97,_(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W0N<&AP
M.C(Y-PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]R;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O
M=RYI;F,Z,C4*;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P,B!T96UP;&%T97,O8G)O
M=W-E+W)O=RYI;F,Z,C4*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A
M9&5R<RYI;F,Z,3`@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"B,Z
M('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,@;&EB+U)E;F1E
M<F5R+G!H<#HT,@IM<V=I9"`B161I="(*;7-G<W1R(")%9&ET87(B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4@=&5M<&QA=&5S+V)R;W=S92]C
M;VYT86-T<F]W+FEN8SHS,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!<(B5S7"(B"FUS9W-T<B`B161I=&%R("<E<R<B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B161I="!!
M9&1R97-S($)O;VMS(@IM<V=S='(@(D5X<&]R=&%R($QL:6)R971A(&0G861R
M96-E<R(*"B,Z(&5D:70N<&AP.C<X(&5D:70N<&AP.C$U-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET(&5N=')Y(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B16UA:6PB"FUS
M9W-T<B`B16UA:6PB"@HC.B!E9&ET+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960L(&)U="!S879I;F<@=&AE('5P
M;&]A9&5D(&9I;&4@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H
M<#HQ-#D@961I="YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y
M(&9O<B`E<R!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C<T
M"B,L(&9U>GIY"FUS9VED(")%;G1R>2!S=6-C97-S9G5L;'D@9&5L971E9"XB
M"FUS9W-T<B`B3"=A<GAI=2`E<R!H82!E<W1A="!I;7!O<G1A="!S871I<V9A
M8W3R<FEA;65N="(*"B,Z(&QI8B]A<&DN<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@<V5A<F-H:6YG('1H92!A9&1R97-S(&)O
M;VLZ("5S(@IM<V=S='(@(DYO(&AI(&AA(&QL:6)R971E<R!D)V%D<F5C97,@
M;VX@97,@<'5G=6D@97-C<FEU<F4N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHV('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-#$*;7-G
M:60@(D5X<&]R="(*;7-G<W1R(")%>'!O<G1A<B(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B17AP;W)T($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")%>'!O<G1A<B!,;&EB<F5T82!D)V%D<F5C97,B
M"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")%>'!O
M<G0@;VYL>2!T:&4@<V5L96-T960@8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C<*;7-G:60@(D5X<&]R="!T
M:&4@9F]L;&]W:6YG(&%D9')E<W,@8F]O:R!C;VUP;&5T96QY+B(*;7-G<W1R
M("(B"@HC.B!D871A+G!H<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y
M-R!B<F]W<V4N<&AP.C,U(&)R;W=S92YP:'`Z.3`*(SH@8G)O=W-E+G!H<#HQ
M,3(@861D+G!H<#HV-R!S96%R8V@N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@86-C97-S('1H92!A9&1R97-S(&)O;VLZ
M("5S(@IM<V=S='(@(DAA(&9A;&QA="!A;"!C97)C87(@96X@96P@9&ER96-T
M;W)I.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@861D("5S('1O("5S.B`E<R(*;7-G<W1R
M(")(82!F86QL870@86P@8V5R8V%R(&5N(&5L(&1I<F5C=&]R:3H@)7,B"@HC
M.B!B<F]W<V4N<&AP.C(W,@HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&)R
M;W=S92!L:7-T(@IM<V=S='(@(DAA(&9A;&QA="!E;"!L;&ES=&%T(&1E;"!D
M:7)E8W1O<FDZ("5S(@H*(SH@8G)O=W-E+G!H<#HS,3`*(RP@9G5Z>GD*;7-G
M:60@(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R>2(*;7-G<W1R(")(
M82!F86QL870@96P@;&QI<W1A="!D96P@9&ER96-T;W)I.B`E<R(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,S`Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE
M=R!$3B`]("5S+"!2;V]T(#T@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H
M<#HQ,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F
M:6YD(&]B:F5C="!T;R!B92!A9&1E9#H@)7,B"FUS9W-T<B`B2&$@9F%L;&%T
M(&%L(&-E<F-A<B!E;B!E;"!D:7)E8W1O<FDZ("5S(@H*(SH@<V5A<F-H+G!H
M<#HW.0HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T:&4@861D
M<F5S<R!B;V]K(@IM<V=S='(@(DAA(&9A;&QA="!A;"!C97)C87(@96X@96P@
M9&ER96-T;W)I.B`E<R(*"B,Z(&1A=&$N<&AP.C$T.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S(@IM
M<V=S='(@(DAA(&9A;&QA="!A;"!C97)C87(@96X@96P@9&ER96-T;W)I.B`E
M<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM<V=I9"`B
M1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&5D:70N<&AP.C$R-"!D:7-P;&%Y+G!H
M<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D9I;&5S(@IM<V=S='(@(E3M=&]L(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<P"FUS9VED(")&:6YD
M(@IM<V=S='(@(E1R;V)A<B(*"B,Z(&5D:70N<&AP.CDW(&5D:70N<&AP.C$X
M-PHC+"!F=7IZ>0IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(E1R;V)A<B(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0X"FUS9VED(")&:7)S="!.
M86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C(P,@IM<V=I9"`B1G)E96)U<WD@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<V5A<F-H+FEN8SHX,PIM<V=I9"`B1G)O;2(*;7-G<W1R
M(")$92(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C8P-`HC+"!F=7IZ
M>0IM<V=I9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R(")%>'!O<G1A
M<B!,;&EB<F5T82!D)V%D<F5C97,B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O
M=RYI;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT-`IM
M<V=I9"`B1W)O=7`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')E
MYV$@4&5R<V]N86PB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY
M,PIM<V=I9"`B2&]M92!#:71Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$P.`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!#;W5N
M=')Y(@IM<V=S='(@(E1E;.AF;VX@4&5R<V]N86PB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T
M<B`B5&5LZ&9O;B!097)S;VYA;"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$P,PHC+"!F=7IZ>0IM<V=I9"`B2&]M92!0;W-T86P@0V]D92(*
M;7-G<W1R(")496SH9F]N(%!E<G-O;F%L(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(DAO;64@4W1A=&4O4')O
M=FEN8V4B"FUS9W-T<B`B5&5LZ&9O;B!097)S;VYA;"(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C@X"B,L(&9U>GIY"FUS9VED(")(;VUE(%-T
M<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F7G82!097)S;VYA;"(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C4P-@IM<V=I9"`B24U34"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<*;7-G:60@(DE-4U`@
M061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9"(*;7-G<W1R
M("));7!O<G1A<B!,;&EB<F5T82!D)V%D<F5C97,B"@HC.B!D871A+G!H<#HS
M-C$*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="]%>'!O<G0@061D<F5S<R!";V]K
M<R(*;7-G<W1R("));7!O<G1A<B]%>'!O<G1A<B!,;&EB<F5T82!D)V%D<F5C
M97,B"@HC.B!L:6(O87!I+G!H<#HU.38@;&EB+V%P:2YP:'`Z-C@S"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED($E$(@IM<V=S='(@(D5L(&YO;2!N;R#I<R!V
MX&QI9"XB"@HC.B!L:6(O87!I+G!H<#HR,S`@;&EB+V%P:2YP:'`Z-#`R(&QI
M8B]A<&DN<&AP.C0X-B!L:6(O87!I+G!H<#HU.3(*(SH@;&EB+V%P:2YP:'`Z
M-C<Y(&QI8B]A<&DN<&AP.C<S,2!L:6(O87!I+G!H<#HQ,#<W"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R("),82!L;&EB
M<F5T82!D)V%D<F5C97,@;F\@Z7,@=N!L:61A+B(*"B,Z(&QI8B]A<&DN<&AP
M.C$P.#$@;&EB+V%P:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ,C`W"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(DPG861R9>=A(&0G
M92UM86EL(&YO(.ES(';@;&ED82XB"@HC.B!L:6(O87!I+G!H<#HQ,#@Y"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&5N=')Y(@IM<V=S='(@(D5L(&YO;2!N
M;R#I<R!VX&QI9"XB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(V-@HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!K97D@<W!E8VEF:65D+B(*;7-G<W1R(")3
M92!E<W!E8VEF:6/S('5N('9A;&]R(&EL96=A;"XB"@HC.B!L:6(O87!I+G!H
M<#HQ,#@U"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&YA;64B"FUS9W-T<B`B
M16P@;F]M(&YO(.ES(';@;&ED+B(*"B,Z(&QI8B]A<&DN<&AP.C<S-0HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!O8FIE8W1)9"(*;7-G<W1R(")%;"!N;VT@
M;F\@Z7,@=N!L:60N(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,`IM<V=I
M9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M
M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS9VED("),87-T($UO
M9&EF:65D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C4S"B,L(&9U>GIY"FUS9VED("),87-T($YA;64B"FUS9W-T<B`B3F]M
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,38*
M;7-G:60@(DQI<W0B"FUS9W-T<B`B3&QI<W1A<B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<V5A<F-H+FEN8SHW-PIM<V=I9"`B36%T8VAI;F<B"FUS9W-T<B`B
M<75E(&-O:6YC:61E:7AI(&%M8B(*"B,Z(&QI8B]A<&DN<&AP.C(P-0IM<V=I
M9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU;2!N=6UB
M97(@;V8@<&%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?;65N
M=2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(DQL
M:7-T87(B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,PHC+"!F=7IZ
M>0IM<V=I9"`B36EN:2!396%R8V@B"FUS9W-T<B`B0V5R8V%R(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI<W-I;F<@1$X@:6X@3$1!
M4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"B,L(&9U>GIY"FUS9VED(")-;V)I
M;&4@4&AO;F4B"FUS9W-T<B`B5&5LZ&9O;B!097)S;VYA;"(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,S,R(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S0X"B,L
M('!H<"UF;W)M870*;7-G:60@(DUO9&EF>2!F86EL960Z("@E<RD@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y,PIM<V=I9"`B36]R92!T:&%N
M(#$@96YT<GD@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B36]V92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA
M=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@;&5F="(*;7-G<W1R(")M;W5R92!A(&PG97-Q=65R<F$B
M"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#D*(SH@
M=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#8*(RP@
M9G5Z>GD*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B;6]U<F4@82!L82!D
M<F5T82(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*
M;7-G<W1R(")%>'!O<G1A<B!,;&EB<F5T82!D)V%D<F5C97,B"@HC.B!L:6(O
M87!I+G!H<#HQ,3$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUU;'1I<&QE
M('!E<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL(&)U="!N;VYE('=I=&@@;F%M
M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C(T
M,PHC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S<R!";V]K(@IM<V=S='(@(DEM
M<&]R=&%R($QL:6)R971A(&0G861R96-E<R(*"B,Z(&%D9')E<W-B;V]K<RYP
M:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S($)O;VMS(@IM<V=S
M='(@(D5X<&]R=&%R($QL:6)R971A(&0G861R96-E<R(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HT,@IM<V=I9"`B3F%M92(*;7-G<W1R(").;VTB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T
M8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@861D+G!H
M<#HS-B!A9&0N<&AP.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*
M(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!#;VYT86-T(@IM<V=S='(@(D%F96=I<B!N;W4@8V]N=&%C=&4B"@HC
M.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY-2!E9&ET+G!H<#HR,#(@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHT-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*(RP@9G5Z>GD*
M;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(DYO;2(*"B,Z(&QI8B]A<&DN<&AP
M.C$Q.34@;&EB+V%P:2YP:'`Z,3(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R`E<R!E;G1R>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,3$V,PHC+"!F=7IZ>0IM<V=I9"`B3F\@861D<F5S<R!B;V]K<R!F
M;W5N9"XB"FUS9W-T<B`B3&$@3&QI8G)E=&$@9"=A9')E8V5S(&YO;>ES(.ES
M(&1E(&QE8W1U<F$N(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#,*;7-G:60@(DYO
M(&-O;G1A8W1S(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C4Q
M,2!L:6(O87!I+G!H<#HW-C8*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI
M;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R(").;W1E<R(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$X-`IM<V=I9"`B3F]T97,B
M"FUS9W-T<B`B3F]T97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U
M"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<T-PIM<V=I9"`B3V)J
M96-T(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HR,C,*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(S"FUS9VED("(B"B)/;F-E
M('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H92!A9&1R97-S(&)O;VL@
M=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B!)9B!T:&ES(&ES(&YO
M="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T(&-H86YG92!Y;W5R('-E
M;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z-S<T"FUS9VED(")/;FQY(&]N92!V8V%R9"!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#8*(RP@9G5Z>GD*;7-G:60@(D]T:&5R($]P=&EO
M;G,B"FUS9W-T<B`B3W!C:6]N<R!D92!L)U5S=6%R:2(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-#DU(&QI8B]A<&DN<&AP.C8P
M-2!L:6(O87!I+G!H<#HV.3(@;&EB+V%P:2YP:'`Z.3,T"B,Z(&QI8B]A<&DN
M<&AP.C$P.3@*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C4T,PIM<V=I9"`B4&5R;6ES<VEO;B!D96YI
M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M.3D*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C4S('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*(RP@9G5Z>GD*;7-G
M:60@(E!I;F4@061D<F5S<R!";V]K(@IM<V=S='(@(DEM<&]R=&%R($QL:6)R
M971A(&0G861R96-E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP
M="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE('1H92!N97<@8V]N=&%C="!L
M:7-T.B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E
M9&ET+G!H<#HQ.30*;7-G:60@(E!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q-@HC+"!F=7IZ>0IM<V=I9"`B4')I
M=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B17AP;W)T87(@3&QI8G)E=&$@
M9"=A9')E8V5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B475E<GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHQ.`HC+"!F
M=7IZ>0IM<V=I9"`B475I8VL@4V5A<F-H(@IM<V=S='(@(D-E<F-A<B(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,3DY(&QI8B]$<FEV97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E860@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]2
M96YD97)E<BYP:'`Z-#D*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI<R!C;VYT
M86-T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI
M;F,Z,@IM<V=I9"`B4F5C;W)D<R!D:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<V"B,L
M(&9U>GIY"FUS9VED(")296UO=F4@861D<F5S<R!B;V]K(@IM<V=S='(@(DEM
M<&]R=&%R($QL:6)R971A(&0G861R96-E<R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(S.0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&-O;'5M;B(*;7-G<W1R(")T<F5U<F4@8V]L=6UN82(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@IM<V=I9"`B4F5M;W9E(&9R;VT@=&AI
M<R!L:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,C$*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K
M('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES
M("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E
M<W,@8F]O:RX\+W-T<F]N9SXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z-#,X"FUS9VED(")297%U97-T960@;V)J96-T(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@861D+G!H<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z,3$S"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.38*;7-G:60@(E,O
M34E-12!0=6)L:6,@0V5R=&EF:6-A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")35$%25%1,
M4R!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z.3D@
M861D+G!H<#HS-R!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,C0*;7-G
M:60@(E-A=F4B"FUS9W-T<B`B1&5S87(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+W-E87)C:"YI;F,Z.38@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q
M,@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C$@;&EB+T)L
M;V-K+W1R965?;65N=2YP:'`Z-#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(D-E<F-A<B(*"B,Z(&UI;FES
M96%R8V@N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")396%R8V@@4F5S=6QT<SHB
M"FUS9W-T<B`B4F5S=6QT871S(&1E(&QA($-E<F-A(@H*(SH@;&EB+V%P:2YP
M:'`Z,3`Q,0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R
M(")#97)C87(B"@HC.B!L:6(O87!I+G!H<#HQ,3`S(&QI8B]A<&DN<&AP.C$Q
M,#D@;&EB+V%P:2YP:'`Z,3$Q."!L:6(O87!I+G!H<#HQ,3,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E-E87)C:"!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,@HC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S='(@(D-E<F-A<B(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C8V"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@86X@861D<F5S<R!B;V]K('1O(&1E;&5T92(*;7-G<W1R("(B"B)3:2!U
M<R!P;&%U+"!E<V-O;&QI=7(@=6YA(&QL:6)R971A(&0G861R96-E<R!P97(@
M869E9VER+6AI(&5L(&-O;G1A8W1E+B(*"B,Z('1E;7!L871E<R]A9&1R97-S
M8F]O:W,N:6YC.CDP"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@861D<F5S
M<R!B;V]K('1O(&5D:70B"FUS9W-T<B`B(@HB4VD@=7,@<&QA=2P@97-C;VQL
M:75R('5N82!L;&EB<F5T82!D)V%D<F5C97,@<&5R(&%F96=I<BUH:2!E;"!C
M;VYT86-T92XB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C,R"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!E>'!O
M<G0@9G)O;3HB"FUS9W-T<B`B4V5L96-C:6]N974@;&$@9F]N="!D97,@9&4@
M;&$@<75E('9O;&5U(&5X<&]R=&%R.B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@861D<F5S
M<R!B;V]K('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B4V5L96-C:6]N974@96P@
M9&5S=.T@<&5R(&EM<&]R=&%R(&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C:&%R<V5T
M(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B4V5L96-C:6]N974@;&$@
M9F]N="!D97,@9&4@;&$@<75E('9O;&5U(&5X<&]R=&%R.B(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-C:6]N974@;&$@
M9F]N="!D97,@9&4@;&$@<75E('9O;&5U(&5X<&]R=&%R.B(*"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z-#,*;7-G:60@(E-E;&5C="!T:&4@9FEL
M92!T;R!I;7!O<G0Z(@IM<V=S='(@(E-E;&5C8VEO;F5U(&PG87)X:74@<75E
M('9O;&5U(&EM<&]R=&%R.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H
M92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B4V5L96-C:6]N974@96P@9F]R;6%T
M('%U92!V;VQE=2!E>'!O<G1A<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!U<V5D
M('1O(&1I<W!L87D@;F%M97,Z(@IM<V=S='(@(E-E;&5C8VEO;F5U(&5L(&9O
M<FUA="!Q=64@=F]L974@:6UP;W)T87(Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(U"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E
M9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-E
M;&5C="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L
M:7-T<RXB"FUS9W-T<B`B4V5L96-C:6]N974@<75I;G,@8V%M<',@=F]L974@
M=FES=6%L:71Z87(@96X@;&5S(&QL:7-T97,@9"=A9')E8V5S+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R(")396QE
M8V-I;VYE=2!Q=6EN<R!C86UP<R!V;VQE=2!V:7-U86QI='IA<B!E;B!L97,@
M;&QI<W1E<R!D)V%D<F5C97,N(@H*(SH@861D+G!H<#HU-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K(%PB)7-<
M(BXB"FUS9W-T<B`B3&$@;&QI8G)E=&$@9"=A9')E8V5S(&YO(.ES(';@;&ED
M82XB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ-S,*(RP@9G5Z>GD*
M;7-G:60@(E-H87)E9"!$:7)E8W1O<GDB"FUS9W-T<B`B1&ER96-T;W)I(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3:&]W("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H;W<@06QL(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@
M(E-H;W<@0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B4VAO=R!,:7-T<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHR,0HC
M.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHS-`HC+"!F
M=7IZ>0IM<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS9W-T<B`B1&ER96-T;W)I
M(@H*(SH@;&EB+V%P:2YP:'`Z,3DX"B,L(&9U>GIY"FUS9VED(")3;W5R8V5S
M(@IM<V=S='(@(LAX:70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34W
M"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E87)C
M:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H
M<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D
M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C(R"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT
M86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,`IM
M<V=I9"`B5%-6(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-`IM<V=I9"`B
M5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z
M,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D<R!T;R!B92!C;VYF:6=U
M<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A9',N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C$P-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB
M('=A<R!R96UO=F5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@861D
M<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D
M<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&5D:70N<&AP.C0W('9C87)D+G!H<#HR,B!D:7-P;&%Y
M+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A8W0@>6]U(')E
M<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@961I="YP
M:'`Z,3$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92!<
M(B5S7"(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N(@IM<V=S='(@
M(DPG87)X:74@)7,@:&$@97-T870@:6UP;W)T870@<V%T:7-F86-T\G)I86UE
M;G0B"@HC.B!D871A+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@8V%N(&)E
M(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R("(B"@HC
M.B!B<F]W<V4N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@
M8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+B(*;7-G<W1R(").;R!H:2!H82!L
M;&EB<F5T97,@9"=A9')E8V5S(&]N(&5S('!U9W5I(&5S8W)I=7)E+B(*"B,Z
M(&%D9"YP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E(&%R92!N;R!W
M<FET96%B;&4@861D<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@879A:6QA8FQE
M(&%D9')E<W,@8F]O:W,@(@HB87)E(&-O;F9I9W5R960@=&\@86QL;W<@>6]U
M('1O(&%D9"!N97<@96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@8F5L:65V92!T
M:&ES("(*(FES(&%N(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)#87`@9&4@;&5S(&QL:6)R
M97-T97,@9"=A9')E8V5S(&1I<W!O;FEB;&5S(&5S=.`@8V]N9FEG=7)A9&$@
M<&5R('!E<FUE=')E+75S("(*(F%F96=I<BUH:2!N;W9E<R!E;G1R861E<RX@
M4VD@8V]N<VED97)E=2!Q=64@86EX\B#I('-U;B!E<G)O<BP@<VD@<W4@<&QA
M=2`B"B)C;VYT86-T974@;"=A9&UI;FES=')A9&]R(&1E('-I<W1E;65S+B(*
M"B,Z(&%D9"YP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@861D:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R("(*(F9O<B!F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*(DA)(&AA(&AA9W5T('5N(&5R<F]R(&%L(&%F96=I<B!A<75E
M<W0@;V)J96-T92X@0V]N=&%C=&5U(&PG861M:6YI<W1R861O<B!D96P@(@HB
M<VES=&5M87!E<B!A(&%J=61A(&%D9&EC:6]N86PN(@H*(SH@8G)O=W-E+G!H
M<#HQ.#D@8G)O=W-E+G!H<#HR,S`*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!A9&1I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(DA)(&AA
M(&AA9W5T('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QE<R!D861E<RXB"@HC.B!B
M<F]W<V4N<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N(@IM<V=S='(@(DA)(&AA(&AA9W5T
M('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QE<R!D861E<RXB"@HC.B!A9&1R97-S
M8F]O:W,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S
M(@IM<V=S='(@(DA)(&AA(&AA9W5T('5N(&5R<F]R(&%L(&EM<&]R=&%R(&PG
M87)X:74@8V%R<F5G870B"@HC.B!B<F]W<V4N<&AP.C$T-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG
M(%PB)7-<(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+B(*;7-G<W1R
M(")(22!H82!H86=U="!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L)V%R>&EU(&-A
M<G)E9V%T(@H*(SH@9&5L971E+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N
M=&%C=#H@)7,B"FUS9W-T<B`B2$D@:&$@:&%G=70@=6X@97)R;W(@86P@:6UP
M;W)T87(@;&5S(&1A9&5S+B(*"B,Z(&)R;W=S92YP:'`Z-S(*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C
M="XB"FUS9W-T<B`B2$D@:&$@:&%G=70@=6X@97)R;W(@86P@:6UP;W)T87(@
M;&5S(&1A9&5S+B(*"B,Z(&)R;W=S92YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G
M<W1R(")(22!H82!H86=U="!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L97,@9&%D
M97,N(@H*(SH@9&%T82YP:'`Z,S,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E
M<R(*;7-G<W1R(")(22!H82!H86=U="!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L
M97,@9&%D97,N(@H*(SH@;&EB+V%P:2YP:'`Z-3`W(&QI8B]A<&DN<&AP.C<V
M,0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(DA)(&AA(&AA9W5T('5N
M(&5R<F]R(&%L(&EM<&]R=&%R(&QE<R!D861E<RXB"@HC.B!B<F]W<V4N<&AP
M.C4X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I
M;F<@82!C;VYT86-T(&9R;VT@=&AE(&QI<W0N(@IM<V=S='(@(DA)(&AA(&AA
M9W5T('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QE<R!D861E<RXB"@HC.B!A9&1R
M97-S8F]O:W,N<&AP.C4U(&%D9')E<W-B;V]K<RYP:'`Z-C`@861D<F5S<V)O
M;VMS+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*
M;7-G<W1R(")(22!H82!H86=U="!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L)V%R
M>&EU(&-A<G)E9V%T(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX,2!A9&1R97-S
M8F]O:W,N<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S
M(@IM<V=S='(@(DA)(&AA(&AA9W5T('5N(&5R<F]R(&%L(&EM<&]R=&%R(&PG
M87)X:74@8V%R<F5G870B"@HC.B!E9&ET+G!H<#HQ-3@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&ES(&5N=')Y.B`E<R(*;7-G<W1R(")(22!H82!H86=U="!U;B!E<G)O<B!A
M;"!I;7!O<G1A<B!L97,@9&%D97,N(@H*(SH@9&%T82YP:'`Z,3<Y"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N
M(@IM<V=S='(@(DYO(&AI(&AA(&QL:6)R971E<R!D)V%D<F5C97,@;VX@97,@
M<'5G=6D@97-C<FEU<F4N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B
M;V]K<V5L96-T+FEN8SHQ.#`*;7-G:60@(E1H97-E(&%D9')E<W,@8F]O:W,@
M=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T,PIM<V=I9"`B5&AE
M<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T
M<B`B(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T
M(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C$Q,C(@;&EB+V%P:2YP:'`Z,3$S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T
M:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(B(*(D%Q=65S=&$@<&5R<V]N82!J
M82!H82!E<W1A="!E;G)E9VES=')A9&$@96X@;&$@=F]S=')A(&QL:6)R971A
M(&0G861R96-E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30W"FUS
M9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K
M('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@(E1I
M=&QE(@IM<V=S='(@(E3M=&]L(@H*(SH@;&EB+U1U<F)A+G!H<#HT,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N
M("!-:7-S:6YG('-O=7)C92!T>7!E+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I
M=F5R+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEN8V%P8><@9&4@
M8V%R<F5G87(@;&$@9&5F:6YI8VGS(&1E("5S+B(*"B,Z(&5D:70N<&AP.C@X
M(&5D:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY(&5D:70N<&AP
M.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D1E
M<V%R(&5L<R!#86YV:7,B"@HC.B!L:6(O87!I+G!H<#HU-#`@;&EB+V%P:2YP
M:'`Z-C0S(&QI8B]A<&DN<&AP.C<W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,W-@HC+"!F=7IZ>0IM<V=I9"`B5F5R
M:7-I9VX@1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=&]R:2(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&UI;FES96%R8V@N<&AP.C<X"B,L(&9U>GIY"FUS
M9VED(")6:65W($-O;G1A8W0B"FUS9W-T<B`B069E9VER(&YO=2!C;VYT86-T
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E9I97<@
M=&\@9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HR,#@*;7-G:60@(E=E8G-I=&4@55),(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q,PIM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F7G82!,86)O<F%L(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(T"FUS9VED(")7;W)K
M($-I='DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")7;W)K($-O=6YT<GDB"FUS9W-T<B`B
M5&5LZ&9O;B!,86)O<F%L(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,34V"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;.AF;VX@3&%B
M;W)A;"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S-`HC+"!F
M=7IZ>0IM<V=I9"`B5V]R:R!0;W-T86P@0V]D92(*;7-G<W1R(")496SH9F]N
M($QA8F]R86PB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*
M(RP@9G5Z>GD*;7-G:60@(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B
M5&5LZ&9O;B!,86)O<F%L(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3$Y"B,L(&9U>GIY"FUS9VED(")7;W)K(%-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(D%D<F7G82!,86)O<F%L(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S
M92YP:'`Z.3,@8G)O=W-E+G!H<#HR,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@8V]N=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!E
M9&ET+G!H<#HV.2!D:7-P;&%Y+G!H<#HU."!V:65W+G!H<#HS-@IM<V=I9"`B
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A
M8W0N(@IM<V=S='(@(B(*"B,Z('9C87)D+G!H<#HT,`IM<V=I9"`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHU
M-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T
M+FEN8SHR,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N
M(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C,R"FUS9VED(")9;W4@;75S="!S
M96QE8W0@870@;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O
M=W-E+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@
M870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!E9&ET
M+G!H<#HW,PIM<V=I9"`B66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(X
M-0IM<V=I9"`B66]U<B!D969A=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O
M=W-E86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N
M:6YC.C8@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHQ,@IM<V=I
M9"`B6VYO('9A;'5E72(*;7-G<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0X
M-`HC+"!F=7IZ>0IM<V=I9"`B7T)R;W=S92(*;7-G<W1R(")%>&%M:6YA<B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@(E]#
M;VYT86-T<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C(*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B16QI
M;6EN87(B"@HC.B!L:6(O5'5R8F$N<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I9"`B
M7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B26UP;W)T87(O17AP;W)T87(B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY"FUS
M9VED(")?3&ES=',B"FUS9W-T<B`B3&QI<W1A<B(*"B,Z(&QI8B]4=7)B82YP
M:'`Z-#@Q"B,L(&9U>GIY"FUS9VED(")?37D@061D<F5S<R!";V]K<R(*;7-G
M<W1R("));7!O<G1A<B!,;&EB<F5T82!D)V%D<F5C97,B"@HC.B!L:6(O5'5R
M8F$N<&AP.C0X-PHC+"!F=7IZ>0IM<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S
M='(@(D%F96=I<B!N;W4@8V]N=&%C=&4B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C(*;7-G:60@(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#D*(RP@9G5Z>GD*;7-G
M:60@(E]396%R8V@B"FUS9W-T<B`B0V5R8V%R(@H*(SH@=F-A<F0N<&AP.C0V
M"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ
M.3D@9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM
M<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(P
M.0IM<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S0*;7-G:60@(FYO;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR-`IM<V=I
M9"`B=&\@82!#;VYT86-T($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B=&\@82!D
M:69F97)E;G0@061D<F5S<R!";V]K(@IM<V=S='(@(D5X<&]R=&%R($QL:6)R
M971A(&0G861R96-E<R(*"B,Z(&1A=&$N<&AP.C4Q('1E;7!L871E<R]B<F]W
M<V4O8V]L=6UN7VAE861E<G,N:6YC.C$S"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,34@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I
M9"`B=D-A<F0B"FUS9W-T<B`B(@H`````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T=7)B82]P;R]R;U]23RYP;P``````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<Q,S8R`#$P-#$W,S8R-S4V`#`Q
M-S4U,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C(%154D)!(%)O;6%N:6%N(%1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H
M0RD@,C`P,R!(;W)D92!0<F]J96-T"B,@175G96X@2&]A;F-A(#QE=6=E;FA`
M=7)B86XM9W)A9G@N<F\^+"`R,#`S+@HC($UA<FEU<R!$<F%G=6QE<V-U(#QM
M87)I=7-D0'5R8F%N+6=R869X+G)O/BP@,C`P,RX*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@5%520D$@,2XQ7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P,RTP,RTP,2`Q,CHP,"LP,C`P7&XB"B),87-T
M+51R86YS;&%T;W(Z($5U9V5N($AO86YC82`\975G96YH0'5R8F%N+6=R869X
M+G)O/EQN(@HB3&%N9W5A9V4M5&5A;3H@4F]M86YI86X@/'4Q.&U`;&ES=',N
M:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O
M<')E9G,O:6US<%]O<'0N:6YC.C0R"FUS9VED("(@061D(&%N($E-4U`@061D
M<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P
M7V]P="YI;F,Z,S$*;7-G:60@(B!$96QE=&4@24U34"!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I;7!O<G1E
M9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U<V4@:70@:7,@
M82!L:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!M;W9E9"!B96-A=7-E(&ET
M(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@*&EE+B!*
M;VAN($1O92DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L
M($IO:&XI(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@
M:6UP;W)T960B"FUS9W-T<B`B1FES:65R=6P@)7,@82!F;W-T(&EM<&]R=&%T
M(&-U('-U8V-E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("),:7-T87)E(&%G
M96YD82(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HT-0IM<V=I9"`B
M02!B<F]W<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Y"FUS9VED
M(")!8F]V92!S96%R8V@@9F]R;2(*;7-G<W1R("(B"@HC.B!V:65W+G!H<#HU
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('1O("5S(@IM
M<V=S='(@(B(*"B,Z(&%D9"YP:'`Z-38@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHR,@IM<V=I9"`B061D(@IM<V=S='(@(D%D875G87)E(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S0*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B06=E;F1A
M(&EN=F%L:61A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.`HC+"!F
M=7IZ>0IM<V=I9"`B061D(&%N9"!$96QE=&4@24U34"!A9&1R97-S(&)O;VMS
M(@IM<V=S='(@(DYU(&5X:7-T82!A9V5N9&4@:6X@8V%R92!S82!S92!S8W)I
M92XB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B861A=6=A<F4@
M8V]L;V%N82(*"B,Z(&5D:70N<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B061D
M(&9I;&4B"FUS9W-T<B`B061A=6=A<F4@97-U871A(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHR,@HC+"!F=7IZ>0IM<V=I9"`B061D('1O
M(@IM<V=S='(@(D%D875G87)E(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K
M<RYI;F,Z.#8*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R
M("),:7-T87)E(&%G96YD82(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B
M"FUS9W-T<B`B3&ES=&%R92!A9V5N9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T
M<B`B3&ES=&%R92!A9V5N9&$B"@HC.B!A9&0N<&AP.C$P.`HC+"!F=7IZ>0IM
M<V=I9"`B061D<F5S<R!B;V]K(&5N=')Y(@IM<V=S='(@(D%G96YD82!D;V%R
M(&EN(&-I=&ER92(*"B,Z(&1A=&$N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B
M061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(D9I
M<VEE<G5L("5S(&$@9F]S="!I;7!O<G1A="!C=2!S=6-C97,B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B061D
M<F5S<R!B;V]K('1O(&1E;&5T92`B"FUS9W-T<B`B06=E;F1A(&1O87(@:6X@
M8VET:7)E(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T
M+FEN8SHQ-S`*;7-G:60@(D%D9')E<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B
M92!D:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z.#@@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,W"FUS9VED(")!9'9A;F-E9"!3
M96%R8V@B"FUS9W-T<B`B0V%U=&%R92!A=F%N<V%T82(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C8T"FUS9VED(")!;&EA<R(*;7-G<W1R(")!
M;&EA<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@
M=&5M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C4U,@IM<V=I9"`B06QR96%D>2!%>&ES=',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN
M8SHY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y
M;W4@=V%N="!T;R!D96QE=&4@)7,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R
M92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L96-T960@96YT<FEE
M<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS
M9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HX-2!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@
M(D)A<VEC(%-E87)C:"(*;7-G<W1R(")#875T87)E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O<FTB"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-R!L:6(O1')I=F5R
M+VQD87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE;G4N:6YC.C<*;7-G:60@(D)R;W=S92(*;7-G<W1R(")287-F
M;VER92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W,PIM<V=I
M9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M-#D*;7-G:60@(D-35B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T+T=R;W5P
M+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHW"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#0*;7-G:60@(D-H;V]S92!A
M(&YA;64B"FUS9W-T<B`B(@H*(SH@861D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I
M9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R(").=2!E>&ES=&$@
M86=E;F1E('!E;G1R=2!R87-F;VET+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(R,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N
M(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B3G4@97AI<W1A(&%G96YD92!P96YT
M<G4@<F%S9F]I="XB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS
M96QE8W0N:6YC.C$V-0IM<V=I9"`B0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O
M:W,@=&\@9&ES<&QA>2P@86YD(&EN('=H870@;W)D97(Z(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B0VAO;W-E('=H
M:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C@*(RP@9G5Z>GD*;7-G
M:60@(D-H;V]S92!W:&EC:"!C;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H
M870@;W)D97(Z(@IM<V=S='(@(D%L96=E(&]R9&EN96$@869I<V%R:6D@8V]L
M;V%N96QO<B!I;B!L:7-T82!D92!A9')E<V4N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$W"FUS9VED(")#;VQU;6X@3W!T:6]N<R(*;7-G<W1R(")/
M<'1I=6YI(&-O;&]A;F$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L
M96-T+FEN8SHR,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D
M:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I9"`B
M0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@
M=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS
M9W-T<B`B0V]M<&%N:64B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ-#0*(RP@9G5Z>GD*;7-G:60@(D-O;7!A;GD@061D<F5S<R(*;7-G<W1R
M(")!9')E<V$@86-A<V$B"@HC.B!L:6(O87!I+G!H<#HS,3@@;&EB+V%P:2YP
M:'`Z,S8S(&QI8B]A<&DN<&AP.C0P-R!L:6(O87!I+G!H<#HT.3$*(SH@;&EB
M+V%P:2YP:'`Z-C`Q(&QI8B]A<&DN<&AP.C8X."!L:6(O87!I+G!H<#HW-#$@
M;&EB+V%P:2YP:'`Z.#$Y"B,Z(&QI8B]A<&DN<&AP.C$P,#8@;&EB+V%P:2YP
M:'`Z,3`Y-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(E-T97)G97)E(&5S=6%T82(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I
M;VX@9F%I;'5R92(*;7-G<W1R(")3=&5R9V5R92!E<W5A=&$B"@HC.B!B<F]W
M<V4N<&AP.C$Y,2!B<F]W<V4N<&AP.C(S,@IM<V=I9"`B0V]N=&%C="!A9&1E
M9"!T;R!L:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C8P"FUS9VED
M(")#;VYT86-T(')E;6]V960@9G)O;2!L:7-T+B(*;7-G<W1R("(B"@HC.B!B
M<F]W<V4N<&AP.C(V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT86-T<R!I
M;B!L:7-T.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O
M;7!A;FEE(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3,*;7-G
M:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O
M;VMS+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O
M:R(*;7-G<W1R(")%>'!O<G1A<F4@86=E;F1A(@H*(SH@;&EB+TQI<W16:65W
M+G!H<#HS,34*;7-G:60@(D-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@:6XZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S,*;7-G:60@
M(D-R96%T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDX"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHW-B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*(SH@;&EB+T]B:F5C="YP:'`Z,S(X
M(&QI8B]296YD97)E<BYP:'`Z-#<@;&EB+U)E;F1E<F5R+G!H<#HU,`IM<V=I
M9"`B1&5L971E(@IM<V=S='(@(E-T97)G97)E(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B17AP;W)T87)E(&%G96YD82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G
M:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&4@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(E-T97)G97)E
M(&5S=6%T82(*"B,Z(&1E;&5T92YP:'`Z,S@*;7-G:60@(D1E;&5T:6]N(&9A
M:6QE9"(*;7-G<W1R(")3=&5R9V5R92!E<W5A=&$B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$97-C
M96YD:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N
M:6YC.C$Q-0HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M3W!T:75N:2!U=&EL:7IA=&]R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R
M8V@N:6YC.C$Q.`IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=&]R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY"FUS9VED
M(")$:7-P;&%Y(@IM<V=S='(@(D]P=&EU;FD@869I<V%J("(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!T:75N
M:2!A9FES86H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-@IM<V=I
M9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R:65S/R(*
M;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*;7-G:60@(D1O=VYL
M;V%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ
M-R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(U"FUS9VED(")$
M;W=N;&]A9"!V0V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S
M<V)O;VMS+FEN8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,Z
M('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PHC.B!T96UP;&%T97,O8G)O=W-E
M+V-O;G1A8W1R;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@
M(D5D:70B"FUS9W-T<B`B161I=&%R92(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<F]W+FEN8SHR-2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G
M<W1R(")%9&ET87)E("<E<R<B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B161I="!!9&1R97-S($)O;VMS(@IM
M<V=S='(@(D5X<&]R=&%R92!A9V5N9&$B"@HC.B!E9&ET+G!H<#HW."!E9&ET
M+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!E;G1R>2!F;W(@
M)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&5D:70N<&AP
M.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E
M9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D960@9FEL92!F86EL960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$T.2!E9&ET+G!H<#HQ-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960N(@IM<V=S='(@
M(B(*"B,Z(&)R;W=S92YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D5N=')Y('-U
M8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")&:7-I97)U;"`E<R!A(&9O
M<W0@:6UP;W)T870@8W4@<W5C8V5S(@H*(SH@;&EB+V%P:2YP:'`Z-#$S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96%R8VAI;F<@=&AE
M(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B3G4@97AI<W1A(&%G96YD92!I
M;B!C87)E('-A('-E('-C<FEE+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z-B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C0Q"FUS9VED
M(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T87)E(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHV"B,L(&9U>GIY"FUS9VED(")%>'!O<G0@061D<F5S
M<R!";V]K(@IM<V=S='(@(D5X<&]R=&%R92!A9V5N9&$B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")%>'!O<G0@;VYL>2!T:&4@
M<V5L96-T960@8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,C<*;7-G:60@(D5X<&]R="!T:&4@9F]L;&]W:6YG
M(&%D9')E<W,@8F]O:R!C;VUP;&5T96QY+B(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!B<F]W<V4N<&AP
M.C,U(&)R;W=S92YP:'`Z.3`*(SH@8G)O=W-E+G!H<#HQ,3(@861D+G!H<#HV
M-R!S96%R8V@N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@
M(DYU(',M82!P=71U="!A8V-E<V$@86=E;F1A('-P96-I9FEC871A+B(*"B,Z
M(&)R;W=S92YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@861D("5S('1O("5S.B`E<R(*;7-G<W1R(")287-F;VER92!E
M<W5A=&$@<&5N=')U("5S+B(*"B,Z(&)R;W=S92YP:'`Z,C<R"B,L(&9U>GIY
M"FUS9VED(")&86EL960@=&\@8G)O=W-E(&QI<W0B"FUS9W-T<B`B4F%S9F]I
M<F4@97-U871A('!E;G1R=2`E<RXB"@HC.B!B<F]W<V4N<&AP.C,Q,`HC+"!F
M=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM
M<V=S='(@(D-A=71A<F4@97-U871A(&EN(&1I<F5C=&]R=6PZ("5S(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HS,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@
M3F5W($1.(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R("(B"@HC.B!B<F]W<V4N
M<&AP.C$R,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&9I;F0@;V)J96-T('1O(&)E(&%D9&5D.B`E<R(*;7-G<W1R(")#875T87)E
M(&5S=6%T82!I;B!D:7)E8W1O<G5L.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*
M(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@
M8F]O:R(*;7-G<W1R(").=2!S+6$@<'5T=70@86-C97-A(&%G96YD82!S<&5C
M:69I8V%T82XB"@HC.B!D871A+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E<R(*;7-G<W1R
M(")#875T87)E(&5S=6%T82!I;B!D:7)E8W1O<G5L.B`E<R(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM<V=I9"`B1F%X(@IM<V=S='(@
M(D9A>"(*"B,Z(&5D:70N<&AP.C$R-"!D:7-P;&%Y+G!H<#HQ,#`*(RP@9G5Z
M>GD*;7-G:60@(D9I;&5S(@IM<V=S='(@(E1I=&QU(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]S96%R8V@N:6YC.C<P"FUS9VED(")&:6YD(@IM<V=S='(@(D-A
M=71A<F4B"@HC.B!E9&ET+G!H<#HY-R!E9&ET+G!H<#HQ.#<*(RP@9G5Z>GD*
M;7-G:60@(D9I;FES:"(*;7-G<W1R(")#875T87)E(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T($YA;64B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`R"FUS9VED
M(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]S96%R8V@N:6YC.C@S"FUS9VED(")&<F]M(@IM<V=S='(@(D1E(&QA(@H*
M(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`T"B,L(&9U>GIY"FUS9VED
M(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@(D5X<&]R=&%R92!A9V5N
M9&$B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z-#,@=&5M<&QA=&5S
M+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT-`IM<V=I9"`B1W)O=7`B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#(*;7-G:60@
M(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')E<V$@86-A<V$B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P.`HC
M+"!F=7IZ>0IM<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@(E1E;&5F;VX@
M86-A<V$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G
M:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L969O;B!A8V%S82(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M2&]M92!0;W-T86P@0V]D92(*;7-G<W1R(")496QE9F]N(&%C87-A(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@
M(DAO;64@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B5&5L969O;B!A8V%S82(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"B,L(&9U>GIY"FUS
M9VED(")(;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!A8V%S
M82(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C4P-@IM<V=I9"`B24U3
M4"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<*(RP@
M9G5Z>GD*;7-G:60@(DE-4U`@061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(DQI<W1A<F4@86=E;F1A(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G0@061D<F5S<R!";V]K+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&%R92!A
M9V5N9&$B"@HC.B!D871A+G!H<#HS-C$*(RP@9G5Z>GD*;7-G:60@(DEM<&]R
M="]%>'!O<G0@061D<F5S<R!";V]K<R(*;7-G<W1R("));7!O<G1A<F4O17AP
M;W)T87)E(&%G96YD92(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O87!I+G!H
M<#HV.#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`B3G5M
M92!I;G9A;&ED+B(*"B,Z(&QI8B]A<&DN<&AP.C(S,"!L:6(O87!I+G!H<#HT
M,#(@;&EB+V%P:2YP:'`Z-#@V(&QI8B]A<&DN<&AP.C4Y,@HC.B!L:6(O87!I
M+G!H<#HV-SD@;&EB+V%P:2YP:'`Z-S,Q(&QI8B]A<&DN<&AP.C$P-S<*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@861D<F5S<R!B;V]K(@IM<V=S='(@(D%G
M96YD82!I;G9A;&ED82XB"@HC.B!L:6(O87!I+G!H<#HQ,#@Q(&QI8B]A<&DN
M<&AP.C$Q-30@;&EB+V%P:2YP:'`Z,3(P-PHC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!E;6%I;"(*;7-G<W1R(")!9')E<V$@9&4@92UM86EL(&EN=F%L:61A
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.#D*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@96YT<GDB"FUS9W-T<B`B3G5M92!I;G9A;&ED+B(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,C8V"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&ME>2!S
M<&5C:69I960N(@IM<V=S='(@(E,M82!S<&5C:69I8V%T(&\@=F%L;V%R92!I
M;G9A;&ED82XB"@HC.B!L:6(O87!I+G!H<#HQ,#@U"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&YA;64B"FUS9W-T<B`B3G5M92!I;G9A;&ED+B(*"B,Z(&QI
M8B]A<&DN<&AP.C<S-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O8FIE8W1)
M9"(*;7-G<W1R(").=6UE(&EN=F%L:60N(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U
M="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A
M9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS
M9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C4S"B,L(&9U>GIY"FUS9VED("),87-T($YA;64B
M"FUS9W-T<B`B3G5M92(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C$V"FUS9VED("),:7-T(@IM<V=S='(@(DQI<W1A(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<W"FUS9VED(")-871C:&EN
M9R(*;7-G<W1R(")#;W)E<W!U;GIA=&]R*&]A<F4I(@H*(SH@;&EB+V%P:2YP
M:'`Z,C`U"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!#;VYT86-T<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED(")-
M87AI;75M(&YU;6)E<B!O9B!P86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=')E95]M96YU+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-96YU($QI<W0B
M"FUS9W-T<B`B3&ES=&$B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z
M,PHC+"!F=7IZ>0IM<V=I9"`B36EN:2!396%R8V@B"FUS9W-T<B`B0V%U=&%R
M92(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`R"FUS9VED(")-:7-S:6YG
M($1.(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V,@HC+"!F=7IZ>0IM
M<V=I9"`B36]B:6QE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@86-A<V$B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP
M.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.3,*;7-G:60@(DUO
M<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3$*;7-G:60@(DUO=F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0W"B,Z
M('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@T"B,L
M(&9U>GIY"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B;75T87)E('-T86YG
M82(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T.0HC
M.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X-@HC
M+"!F=7IZ>0IM<V=I9"`B36]V92!R:6=H="(*;7-G<W1R(")M=71A<F4@9')E
M87!T82(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*
M;7-G<W1R(")%>'!O<G1A<F4@86=E;F1A(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I
M=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E
M861Y(&5X:7-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*
M;7-G:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R("),:7-T87)E(&%G96YD
M82(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")-
M>2!!9&1R97-S($)O;VMS(@IM<V=S='(@(DQI<W1A<F4@86=E;F1A(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`W(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C0R"FUS9VED(").86UE(@IM<V=S='(@(DYU;64B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM
M<V=I9"`B3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C
M:"YP:'`Z,C<*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(DYE=R!#;VYT86-T(@IM<V=S='(@(D%D875G82!C;VYT86-T
M(&YO=2(*"B,Z(&5D:70N<&AP.C@X(&5D:70N<&AP.CDU(&5D:70N<&AP.C(P
M,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0U"FUS9VED(").97AT(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q.`HC
M+"!F=7IZ>0IM<V=I9"`B3FEC:VYA;64B"FUS9W-T<B`B3G5M92(*"B,Z(&QI
M8B]A<&DN<&AP.C$Q.34@;&EB+V%P:2YP:'`Z,3(T-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R`E<R!E;G1R>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,3$V,PHC+"!F=7IZ>0IM<V=I9"`B3F\@861D<F5S
M<R!B;V]K<R!F;W5N9"XB"FUS9W-T<B`B06=E;F1A(&1O87(@:6X@8VET:7)E
M(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#,*;7-G:60@(DYO(&-O;G1A8W1S(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C4Q,2!L:6(O87!I+G!H
M<#HW-C8*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-PHC+"!F=7IZ
M>0IM<V=I9"`B3F]N92(*;7-G<W1R(").;W1I=&4B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO
M=&ET92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(DYU
M;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HV,30@;&EB+V%P:2YP:'`Z-S0W"FUS9VED(")/8FIE8W0@;F]T(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@
M=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E
M<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@;F]T('=H870@>6]U
M('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N("(*
M(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW-S0*
M;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-@HC+"!F=7IZ>0IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R
M(")/<'1I=6YI('5T:6QI>F%T;W(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C0Y-2!L:6(O87!I+G!H<#HV,#4@;&EB+V%P:2YP
M:'`Z-CDR(&QI8B]A<&DN<&AP.CDS-`HC.B!L:6(O87!I+G!H<#HQ,#DX"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O1')I
M=F5R+G!H<#HU-#,*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDY"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,R!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")0:6YE($%D
M9')E<W,@0F]O:R(*;7-G<W1R("),:7-T87)E(&%G96YD82(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N
M86UE('1H92!N97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R("(B"@HC.B!E9&ET
M+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HQ.30*;7-G:60@(E!R979I
M;W5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q
M-@HC+"!F=7IZ>0IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B17AP;W)T87)E(&%G96YD82(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,30W"B,L('!H<"UF;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@*"5S*2`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI
M;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(E%U:6-K(%-E87)C:"(*;7-G<W1R(")#
M875T87)E(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3$@;&EB+T1R:79E
M<B]L9&%P+G!H<#HQ.3D@;&EB+T1R:79E<B]L9&%P+G!H<#HT,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+U)E;F1E<F5R+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T
M92!T:&ES(&-O;G1A8W0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T
M+FEN8SHQ-S8*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!A9&1R97-S(&)O;VLB
M"FUS9W-T<B`B26UP;W)T87)E(&%G96YD82(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(S.0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&-O;'5M;B(*;7-G<W1R(")S=&5R9V5R92!C;VQO86YA(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED(")296UO=F4@9G)O;2!T
M:&ES(&QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHR,0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O
M;VL@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H
M:7,@(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D
M<F5S<R!B;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R
M+G!H<#HT,S@*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!A9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A
M<F-H+FEN8SHQ,3,*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B
M4R]-24U%(%!U8FQI8R!#97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-405)4
M5$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY
M.2!A9&0N<&AP.C,W('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM
M<V=I9"`B4V%V92(*;7-G<W1R(")386QV87)E(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]S96%R8V@N:6YC.CDV('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN
M8SHQ,3(*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(Q(&QI
M8B]";&]C:R]T<F5E7VUE;G4N<&AP.C0Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C8*;7-G:60@(E-E87)C:"(*;7-G<W1R(")#875T87)E(@H*(SH@
M;6EN:7-E87)C:"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!297-U
M;'1S.B(*;7-G<W1R(")297IU;'1A=&4@8V%U=&%R92(*"B,Z(&QI8B]A<&DN
M<&AP.C$P,3$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!F86EL960B"FUS9W-T
M<B`B0V%U=&%R92(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#,@;&EB+V%P:2YP:'`Z
M,3$P.2!L:6(O87!I+G!H<#HQ,3$X(&QI8B]A<&DN<&AP.C$Q,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(R"B,L(&9U>GIY
M"FUS9VED(")396%R8VAI;F<N+BXB"FUS9W-T<B`B0V%U=&%R92(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8V"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@86X@861D<F5S<R!B;V]K('1O(&1E;&5T92(*;7-G<W1R(")!;&5G
M92!O(&%G96YD82!I;B!C87)E('-A('-E(&%D875G92!C;VYT86-T=6PN(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3`*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@961I="(*;7-G<W1R(")!
M;&5G92!O(&%G96YD82!I;B!C87)E('-A('-E(&%D875G92!C;VYT86-T=6PN
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS,@HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ
M(@IM<V=S='(@(E-E;&5C=&5A>F$@<W5R<V$@9&EN(&-A<F4@<V4@97AP;W)T
M83HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(V"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z
M(@IM<V=S='(@(E-E;&5C=&5A>F$@9&5S=&EN871I82!S<')E(&-A<F4@<V4@
M:6UP;W)T83HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,U"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&-H87)S970@;V8@=&AE('-O=7)C
M92!F:6QE.B(*;7-G<W1R(")396QE8W1E87IA('-U<G-A(&1I;B!C87)E('-E
M(&5X<&]R=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,`HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G
M<W1R(")396QE8W1E87IA('-U<G-A(&1I;B!C87)E('-E(&5X<&]R=&$Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L96-T
M('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B4V5L96-T96%Z82!F:7-I
M97)U;"!C87)E('-E(&EM<&]R=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP
M;W)T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@
M;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")396QE8W1E87IA(&9O<FUA
M='5L(&EN(&-A<F4@<V4@97AP;W)T83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!U
M<V5D('1O(&1I<W!L87D@;F%M97,Z(@IM<V=S='(@(E-E;&5C=&5A>F$@9F]R
M;6%T=6P@9&EN(&-A<F4@<V4@:6UP;W)T83HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C4*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!V:65W('1O(&1I
M<W!L87D@8GD@9&5F875L="P@<V]R="!O<'1I;VYS+"!A;F0@<&%G:6YG(&]P
M=&EO;G,N(@IM<V=S='(@(E-E;&5C=&5A>F$@=FEZ=6%L:7IA<F5A(&EM<&QI
M8VET82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-E
M;&5C="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L
M:7-T<RXB"FUS9W-T<B`B4V5L96-T96%Z82!C86UP=7)I;&4@8V4@=F]R(&9I
M(&%F:7-A=&4@:6X@;&ES=&5L92!D92!A9')E<V4N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=VAI8V@@
M9F]R;6%T('1O(&1I<W!L87D@;F%M97,N(@IM<V=S='(@(E-E;&5C=&5A>F$@
M8V%M<'5R:6QE(&-E('9O<B!F:2!A9FES871E(&EN(&QI<W1E;&4@9&4@861R
M97-E+B(*"B,Z(&%D9"YP:'`Z-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-E;&5C=&5D(&%D9')E<W,@8F]O:R!<(B5S7"(N(@IM<V=S='(@(D%G
M96YD82!I;G9A;&ED82XB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ
M-S,*(RP@9G5Z>GD*;7-G:60@(E-H87)E9"!$:7)E8W1O<GDB"FUS9W-T<B`B
M1&ER96-T;W(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B4VAO=R!!
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT,`IM<V=I9"`B4VAO=R!#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")3:&]W($QI<W1S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C(Q"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N
M:6YC.C,T"B,L(&9U>GIY"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R
M(")$:7)E8W1O<B(*"B,Z(&QI8B]A<&DN<&AP.C$Y.`HC+"!F=7IZ>0IM<V=I
M9"`B4V]U<F-E<R(*;7-G<W1R(")3=6-C97,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34W"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT(&%D
M=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B(@H*
M(SH@8G)O=W-E+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&%D9&5D("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP
M:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C<F5A
M=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!D
M871A+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B(@H*
M(SH@=FEE=RYP:'`Z,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D<R!T
M;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A9',N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S
M(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S
M8F]O:W,N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S
M(&)O;VL@7"(E<UPB('=A<R!R96UO=F5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY
M('5P9&%T960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B92!P
M=7)G960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C0W('9C87)D+G!H
M<#HR,B!D:7-P;&%Y+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O
M;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M(@H*(SH@961I="YP:'`Z,3$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9FEL92!<(B5S7"(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T
M960N(@IM<V=S='(@(D9I<VEE<G5L("5S(&$@9F]S="!I;7!O<G1A="!C=2!S
M=6-C97,B"@HC.B!D871A+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@8V%N
M(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R("(B
M"@HC.B!B<F]W<V4N<&AP.C,Q"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E
M86)L92!A9&1R97-S(&)O;VMS+B(*;7-G<W1R(").=2!E>&ES=&$@86=E;F1E
M('!E;G1R=2!R87-F;VET+B(*"B,Z(&%D9"YP:'`Z,CD*(RP@9G5Z>GD*;7-G
M:60@(B(*(E1H97)E(&%R92!N;R!W<FET96%B;&4@861D<F5S<R!B;V]K<RX@
M3F]N92!O9B!T:&4@879A:6QA8FQE(&%D9')E<W,@8F]O:W,@(@HB87)E(&-O
M;F9I9W5R960@=&\@86QL;W<@>6]U('1O(&%D9"!N97<@96YT<FEE<R!T;R!T
M:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES("(*(FES(&%N(&5R<F]R+"!P;&5A
M<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B)-:6-I('5N82!D:6X@86=E;F1E;&4@9&ES<&]N:6)I;&4@;G4@92!C
M;VYF:6=U<F%T82!P96YT<G4@861A=6=A<F4@9&4@;F]I("(*(FEN=')A<FDN
M($1A8V$@<V4@8V]N<VED97)A(&-A(&5S=&4@;R!G<F5S96%L82P@8V]N=&%C
M=&%T:2!A9&UI;FES=')A=&]R=6P@9&4@(@HB<VES=&5M+B(*"B,Z(&%D9"YP
M:'`Z,3(Q"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M861D:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R("(*(F9O<B!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M(D$@87!A<G5T(&\@<')O8FQE;6$@;&$@86-E87-T82!A9&%U9V%R92X@0V]N
M=&%C=&%T:2!A9&UI;FES=')A=&]R=6P@9&4@(@HB<VES=&5M('!E;G1R=2!A
M<VES=&5N=&$N(@H*(SH@8G)O=W-E+G!H<#HQ.#D@8G)O=W-E+G!H<#HR,S`*
M(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AI
M<R!O8FIE8W0N(@IM<V=S='(@(D$@87!A<G5T(&\@97)O87)E(&QA(&EM<&]R
M=&%R96$@9&%T96QO<BXB"@HC.B!B<F]W<V4N<&AP.C(S.`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N
M(@IM<V=S='(@(D$@87!A<G5T(&\@97)O87)E(&QA(&EM<&]R=&%R96$@9&%T
M96QO<BXB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI
M<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D$@87!A<G5T(&\@97)O87)E
M(&QA('5P;&]A9'5L(&9I<VEE<G5L=6DB"@HC.B!B<F]W<V4N<&AP.C$T-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1E;&5T:6YG(%PB)7-<(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")!(&%P87)U="!O(&5R;V%R92!L82!U<&QO861U;"!F:7-I
M97)U;'5I(@H*(SH@9&5L971E+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N
M=&%C=#H@)7,B"FUS9W-T<B`B02!A<&%R=70@;R!E<F]A<F4@;&$@:6UP;W)T
M87)E82!D871E;&]R+B(*"B,Z(&)R;W=S92YP:'`Z-S(*(RP@9G5Z>GD*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C="XB
M"FUS9W-T<B`B02!A<&%R=70@;R!E<F]A<F4@;&$@:6UP;W)T87)E82!D871E
M;&]R+B(*"B,Z(&)R;W=S92YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R(")!
M(&%P87)U="!O(&5R;V%R92!L82!I;7!O<G1A<F5A(&1A=&5L;W(N(@H*(SH@
M9&%T82YP:'`Z,S,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R
M(")!(&%P87)U="!O(&5R;V%R92!L82!I;7!O<G1A<F5A(&1A=&5L;W(N(@H*
M(SH@;&EB+V%P:2YP:'`Z-3`W(&QI8B]A<&DN<&AP.C<V,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N(@IM<V=S='(@(D$@87!A<G5T(&\@97)O87)E(&QA(&EM<&]R
M=&%R96$@9&%T96QO<BXB"@HC.B!B<F]W<V4N<&AP.C4X"B,L(&9U>GIY"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@82!C;VYT86-T(&9R
M;VT@=&AE(&QI<W0N(@IM<V=S='(@(D$@87!A<G5T(&\@97)O87)E(&QA(&EM
M<&]R=&%R96$@9&%T96QO<BXB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C4U(&%D
M9')E<W-B;V]K<RYP:'`Z-C`@861D<F5S<V)O;VMS+G!H<#HV.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V
M:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")!(&%P87)U="!O
M(&5R;V%R92!L82!U<&QO861U;"!F:7-I97)U;'5I(@H*(SH@861D<F5S<V)O
M;VMS+G!H<#HX,2!A9&1R97-S8F]O:W,N<&AP.C@W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI
M<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D$@87!A<G5T(&\@97)O87)E
M(&QA('5P;&]A9'5L(&9I<VEE<G5L=6DB"@HC.B!E9&ET+G!H<#HQ-3@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&ES(&5N=')Y.B`E<R(*;7-G<W1R(")!(&%P87)U="!O(&5R
M;V%R92!L82!I;7!O<G1A<F5A(&1A=&5L;W(N(@H*(SH@9&%T82YP:'`Z,3<Y
M"B,L(&9U>GIY"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E<W-E<R!T;R!E
M>'!O<G0N(@IM<V=S='(@(DYU(&5X:7-T82!A9V5N9&4@:6X@8V%R92!S82!S
M92!S8W)I92XB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE
M8W0N:6YC.C$X,`IM<V=I9"`B5&AE<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I
M<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0S"FUS9VED(")4:&5S92!C;VQU
M;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC
M.B!D871A+G!H<#HR-CD*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3$R,B!L
M:6(O87!I+G!H<#HQ,3,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES('!E<G-O;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B06-E87-T82!P97)S;V%N82!E<W1E(&1E:F$@
M:6X@86=E;F1A('1A+B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30W
M"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B
M;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@
M(E1I=&QE(@IM<V=S='(@(E1I=&QU(@H*(SH@;&EB+U1U<F)A+G!H<#HT,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!N97<@<VAA
M<F4N("!-:7-S:6YG('-O=7)C92!T>7!E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DYU('-E('!O
M="!I;F-A<F-A(&1E9FEN:71I:6QE("5S+B(*"B,Z(&5D:70N<&AP.C@X(&5D
M:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY(&5D:70N<&AP.C$Y
M-@HC+"!F=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(E-A;'9A
M<F4@<V-H:6UB87)I(@H*(SH@;&EB+V%P:2YP:'`Z-30P(&QI8B]A<&DN<&AP
M.C8T,R!L:6(O87!I+G!H<#HW-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS
M=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<V]U<F-E<RYP:'`N9&ES=#HS-S8*(RP@9G5Z>GD*;7-G:60@(E9E<FES
M:6=N($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E8W1O<B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z(&UI;FES96%R8V@N<&AP.C<X"B,L(&9U>GIY"FUS9VED
M(")6:65W($-O;G1A8W0B"FUS9W-T<B`B061A=6=A(&-O;G1A8W0@;F]U(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE=R!T;R!D
M:7-P;&%Y(&)Y(&1E9F%U;'0Z(@IM<V=S='(@(D%F:7-A<F4@:6UP;&EC:71A
M.B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B
M5V5B<VET92!54DPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3$S"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R
M97-A(&)I<F]U(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(T
M"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")7;W)K($-O=6YT
M<GDB"FUS9W-T<B`B5&5L969O;B!B:7)O=2(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$U-@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")4
M96QE9F]N(&)I<F]U(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3,T"B,L(&9U>GIY"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S='(@
M(E1E;&5F;VX@8FER;W4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ,CD*(RP@9G5Z>GD*;7-G:60@(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS
M9W-T<B`B5&5L969O;B!B:7)O=2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=')E970@061D<F5S
M<R(*;7-G<W1R(")!9')E<V$@8FER;W4B"@HC.B!D871A+G!H<#HR,S<@8G)O
M=W-E+G!H<#HY,R!B<F]W<V4N<&AP.C(P,2!A9&0N<&AP.C<S"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&5D:70N<&AP.C8Y(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V"FUS9VED
M(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N
M=&%C="XB"FUS9W-T<B`B(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C4U"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B
M;V]K+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I
M<'0N:6YC.C(S"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,S(*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP
M;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C0Y"B,Z('1E;7!L871E<R]B
M<F]W<V4O:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A="!L96%S="!O;F4@96YT<GD@9FER<W0N(@IM<V=S='(@(B(*"B,Z(&5D
M:70N<&AP.C<S"FUS9VED(")9;W4@;VYL>2!H879E('!E<FUI<W-I;VX@=&\@
M=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z
M,C@U"FUS9VED(")9;W5R(&1E9F%U;'0@861D<F5S<R!B;V]K(&ES(&YO="!B
M<F]W<V5A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O
M=RYI;F,Z-B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS
M9VED(");;F\@=F%L=65=(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z
M-#@T"B,L(&9U>GIY"FUS9VED(")?0G)O=W-E(@IM<V=S='(@(E)A<V9O:7)E
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B
M7T-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,@HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")3
M=&5R9V5R92(*"B,Z(&QI8B]4=7)B82YP:'`Z-#DS"B,L(&9U>GIY"FUS9VED
M(")?26UP;W)T+T5X<&]R="(*;7-G<W1R("));7!O<G1A<F4O17AP;W)T87)E
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0HC+"!F=7IZ
M>0IM<V=I9"`B7TQI<W1S(@IM<V=S='(@(DQI<W1A(@H*(SH@;&EB+U1U<F)A
M+G!H<#HT.#$*(RP@9G5Z>GD*;7-G:60@(E]->2!!9&1R97-S($)O;VMS(@IM
M<V=S='(@(DQI<W1A<F4@86=E;F1A(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#<*
M(RP@9G5Z>GD*;7-G:60@(E].97<@0V]N=&%C="(*;7-G<W1R(")!9&%U9V$@
M8V]N=&%C="!N;W4B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C(*;7-G:60@(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+U1U<F)A+G!H<#HT.#D*(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B
M"FUS9W-T<B`B0V%U=&%R92(*"B,Z('9C87)D+G!H<#HT-@IM<V=I9"`B8V]N
M=&%C="YV8V8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3DY(&1A=&$N<&AP
M.C(P-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(F-O;G1A
M8W1S+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,#D*;7-G:60@(F-O
M;G1A8W1S+G1S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,3D*;7-G:60@
M(F-O;G1A8W1S+G9C9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M:6US<%]O<'0N:6YC.C,T"FUS9VED(")N;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C0*;7-G:60@(G1O(&$@0V]N
M=&%C="!,:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(G1O(&$@9&EF9F5R96YT($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")%>'!O<G1A<F4@86=E;F1A(@H*(SH@9&%T
M82YP:'`Z-3$@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z
M,3,*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-2!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")V0V%R9"(*;7-G<W1R("(B"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<&\O<VM?4TLN<&\`````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P,C$V,0`Q
M,#0Q-S,V,C<U-@`P,3<U,S(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!4=7)B82!3;&]V86L@=')A;G-L871I;VXN"B,@
M0V]P>7)I9VAT("A#*2`R,#`R($QE;R!-<F%F:V\N(#QL96]`;V5L+G-K/B`H
M;W)I9VEN86P@=')A;G-L871O<BD*(R`H0RD@,C`P,BP@,C`P,R!)=F%N($YO
M<FES(#QV:7A`=F%Z:V$N<VL^"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ(%1U<F)A(#(N,5QN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`Q+3,P(#(Q.C,P*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#8M,#$M,S`@,C$Z-3<K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!)=F%N($YO<FES(#QV:7A`=F%Z:V$N<VL^7&XB"B),86YG=6%G92U496%M
M.B!3;&]V86L@/'9I>$!V87IK82YS:SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X
M-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z-#`*;7-G:60@(B!!
M9&0@86X@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`B(%!R:61ANR!)35-0
M(&%D<F5SX7(B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(Y
M"FUS9VED("(@1&5L971E($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(B!6
M>6UA>F&[($E-4U`@861R97/A<B(*"B,Z(&1A=&$N<&AP.C,R-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR96%D>2!E>&ES=',@86YD('=A<R!N
M;W0@:6UP;W)T960N(@IM<V=S='(@(EPB)7-<(B!UOB!E>&ES='5J92!A(&YE
M8F]L(&EM<&]R=&]V86[]+B(*"B,Z(&)R;W=S92YP:'`Z,30P"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET
M(&ES(&$@;&ES="XB"FUS9W-T<B`B7"(E<UPB(&YE8F]L('-K;W#M<F]V86[]
M+"!P<F5T;[YE(&IE('1O('IO>FYA;2XB"@HC.B!B<F]W<V4N<&AP.C$S.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!M;W9E9"!B96-A
M=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B7"(E<UPB(&YE8F]L('!R97-U
M;G5T_2P@<')E=&^^92!J92!T;R!Z;WIN86TN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@
M*&EE+B!*;VAN($1O92DB"FUS9W-T<B`B7")-96YO+"!0<FEE>G9I<VMO7"(@
M*&YA<'(N($IO:&X@1&]E*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S8*;7-G:60@(EPB3&%S=&YA;64L($9I<G-T;F%M95PB("AI92X@1&]E+"!*
M;VAN*2(*;7-G<W1R(")<(E!R:65Z=FES:V\L($UE;F]<(B`H;F%P<BX@1&]E
M+"!*;VAN*2(*"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&%D9&5D+B(*;7-G<W1R("(E<R!B;VPH82D@<')I9&%N_2CA*2XB"@HC
M.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S
M=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B4_IB;W(@)7,@8F]L(/IS
M<&6Y;F4@:6UP;W)T;W9A;OTN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B
M"FUS9W-T<B`B)7,@8;X@)7,@>B`E<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-#8T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S
M='(@(D%D<F5SX7(@)7,B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z
M-#(*;7-G:60@(D$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B4')E:&QI861AZ"!M=7/M('!O9'!O<F]V8;L@
M:49R86UE<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C`*;7-G:60@
M(D%B;W9E('-E87)C:"!F;W)M(@IM<V=S='(@(DYA9"!F;W)M=6SA<F]M(&BU
M861A;FEA(@H*(SH@=FEE=RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M06-C97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R(")0<NUS='5P(&L@)7,@:F4@
M>F%M:65T;G5T_2(*"B,Z(&%D9"YP:'`Z-38@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR.0IM<V=I9"`B061D(@IM<V=S='(@(E!R:61ANR(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<T"FUS
M9VED(")!9&0@861D<F5S<R!B;V]K(@IM<V=S='(@(E!R:61ANR!A9')E<^%R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X"FUS9VED(")!9&0@86YD
M($1E;&5T92!)35-0(&%D9')E<W,@8F]O:W,B"FUS9W-T<B`B4')I9&&[(&$@
M=GEM87IANR!)35-0(&%D<F5SX7)E(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O
M;'5M;G-E;&5C="YI;F,Z,C,W"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@
M(E!R:61ANR!S=.5P96,B"@HC.B!E9&ET+G!H<#HQ,S4*;7-G:60@(D%D9"!F
M:6QE(@IM<V=S='(@(E!R:61ANR!S^F)O<B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"!T;R(*;7-G<W1R(")0<FED
M8;L@9&\B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4W"FUS9VED(")!9&1I
M;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4')I9.%V
M86YI92!K;VYT86MT;W8@;FEE(&IE(&1O<W1U<&[I+B(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C@V"FUS9VED(")!9&1R97-S($)O;VLB"FUS
M9W-T<B`B061R97/A<B(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS
M9W-T<B`B6F]B<F%Z:;L@861R97/A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,`IM<V=I9"`B061D<F5S<R!";V]K<R(*;7-G<W1R(")!9')E<^%R
M92(*"B,Z(&%D9"YP:'`Z,3`X"FUS9VED(")!9&1R97-S(&)O;VL@96YT<GDB
M"FUS9W-T<B`B4&]L;[YK82!A9')E<^%R82(*"B,Z(&1A=&$N<&AP.C,P-0IM
M<V=I9"`B061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S
M='(@(D%D<F5SX7(@8F]L(/IS<&6Y;F4@=GEM87IA;OTN(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C(*;7-G:60@(D%D9')E<W,@8F]O:R!T
M;R!D96QE=&4@(@IM<V=S='(@(D%D<F5SX7)E(&YA('9Y;6%Z86YI92(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<P"FUS
M9VED(")!9&1R97-S(&)O;VMS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D
M.B(*;7-G<W1R(")!9')E<^%R92P@:W1O<ND@<V$@;F5B=63Z('IO8G)A>F]V
M8;LZ(@H*(SH@<V5A<F-H+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z,S@*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R(")2;WJY
M[7)E;ND@=GEHM6%DX79A;FEE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-C0*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z-R!T96UP;&%T97,O8G)O
M=W-E+V9O;W1E<D%L<&AA+FEN8SHQ,`HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C0X"FUS9VED(")!;&PB"FUS9W-T<B`B5KEE=&MY(@H*(SH@
M;&EB+V%P:2YP:'`Z-34T"FUS9VED(")!;')E861Y($5X:7-T<R(*;7-G<W1R
M(")5OB!E>&ES='5J92(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP
M="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('1H
M870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R(").86]Z86H@8VAC
M971E('IM87IANR`E<S\B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I
M<'0N:6YC.C8W"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T
M;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N=')I97,_(@IM<V=S='(@(DYA;WIA
M:B!C:&-E=&4@=GEM87IANR!V>6)R86[I(&%D<F5S>3\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.38*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")6
M>F]S='5P;F4B"@HC.B!S96%R8V@N<&AP.C@U('1E;7!L871E<R]B<F]W<V4O
M<V5A<F-H+FEN8SHS-PIM<V=I9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(EKA
M:VQA9&[I(&BU861A;FEE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U
M.0IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O<FTB"FUS9W-T<B`B4&]D(&9O<FUU
M;.%R;VT@:+5A9&%N:6$B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN
M9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4')I<&]J96YI92`H8FEN9"D@
M>FQY:&%L;SH@*"5S*2`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B3F%R;V1E;FEN>2(*
M"B,Z('1E;7!L871E<R]M96YU+FEN8SHW"FUS9VED(")"<F]W<V4B"FUS9W-T
M<B`B4')E>F5R8;LB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M-S,*;7-G:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(D]B8VAO9&[I
M('IA;65R86YI92(*"B,Z(&1A=&$N<&AP.C0Y"FUS9VED(")#4U8B"FUS9W-T
M<B`B0U-6("AH;V1N;W1Y(&]D9&5L96[I(.AI87)K;W4I(@H*(SH@;&EB+T]B
M:F5C="]'<F]U<"YP:'`Z-3<*;7-G:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O
M(&ET<V5L9BXB"FUS9W-T<B`B3F5M;[YN;R!P<FED8;L@<VMU<&EN=2!D;R!S
M86UE:B!S96)A+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C<*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R(")6>6)R
M8;L@7W:Y971K>2^^:6%D;F4B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHT-`IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G<W1R(")6>6)E<G1E
M('-I(&UE;F\B"@HC.B!A9&0N<&AP.C0X"FUS9VED(")#:&]O<V4@86X@861D
M<F5S<R!B;V]K(@IM<V=S='(@(E9Y8F5R=&4@<VD@861R97/A<B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R,0IM<V=I9"`B0VAO
M;W-E(&%N(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B5GEB97)T92!S:2!A9')E
M<^%R.B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI
M;F,Z,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!D
M:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B5GEB97)T92!S
M:2!A9')E<^%R92P@:W1O<ND@8VAC971E('IO8G)A>FF[(&$@:6-H('!O<F%D
M:64Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED(")#:&]O
M<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@(E9Y8F5R
M=&4@<VD@861R97/A<F4L(&MT;W+I(&-H8V5T92!P;W6^:;LN(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C(X"FUS9VED(")#:&]O
M<V4@=VAI8V@@8V]L=6UN<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R
M.B(*;7-G<W1R(")6>6)E<G1E('-TY7!C92P@:W1O<ND@8VAC971E('IO8G)A
M>FF[(&$@:6-H('!O<F%D:64Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$W"FUS9VED(")#;VQU;6X@3W!T:6]N<R(*;7-G<W1R(").87-T879E;FEA
M('-TY7!C;W8B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN
M8SHR,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y
M960Z(@IM<V=S='(@(E-TY7!C92P@:W1O<ND@<V$@;F5B=63Z('IO8G)A>F]V
M8;LZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,R!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")#;VUM82!S97!A<F%T960@
M=F%L=65S(@IM<V=S='(@(DAO9&YO='D@;V1D96QE;ND@Z&EA<FMO=2(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E
M<&%R871E9"!V86QU97,@*$UI8W)O<V]F="!/=71L;V]K*2(*;7-G<W1R(")(
M;V1N;W1Y(&]D9&5L96[I(.AI87)K;W4@*$UI8W)O<V]F="!/=71L;V]K*2(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<V"FUS9VED(")#;VUP
M86YY(@IM<V=S='(@(E-P;VQOZ&YO<[LB"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D-O;7!A;GD@061D<F5S<R(*;7-G<W1R
M(")!9')E<V$@<W!O;&_H;F]S=&DB"@HC.B!L:6(O87!I+G!H<#HS,C`@;&EB
M+V%P:2YP:'`Z,S8U(&QI8B]A<&DN<&AP.C0P.2!L:6(O87!I+G!H<#HT.3,*
M(SH@;&EB+V%P:2YP:'`Z-C$Y(&QI8B]A<&DN<&AP.C<P-B!L:6(O87!I+G!H
M<#HW-3D@;&EB+V%P:2YP:'`Z.#,W"B,Z(&QI8B]A<&DN<&AP.C$P,C0@;&EB
M+V%P:2YP:'`Z,3$Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B4&]K=7,@;R!S<&]J96YI92!Z;'EH86PZ
M("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL=7)E(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('!O:W5S
M92!O('-P;VIE;FEE(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,@
M;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C(V"FUS9VED(")#;VYT86-T(%-E
M87)C:"(*;7-G<W1R(")(M6%D86YI92!K;VYT86MT=2(*"B,Z(&)R;W=S92YP
M:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z
M("5S(@IM<V=S='(@(DMO;G1A:W1Y('8@>F]Z;F%M93H@)7,B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$X"FUS9VED(")#;W!Y(@IM<V=S
M='(@(DMO<.UR;W9ANR(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C4S"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B5GET=F]R:;LB"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHT,`IM<V=I9"`B0W)E871E($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")6>71V;W)INR!A9')E<^%R(@H*(SH@;&EB+TQI
M<W16:65W+G!H<#HS-#@*;7-G:60@(D-R96%T92!A(&YE=R!#;VYT86-T($QI
M<W0@:6XZ(@IM<V=S='(@(E9Y='9O<FF[(&YO=OT@>F]Z;F%M(&MO;G1A:W1O
M=B!V.B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S,*;7-G:60@(D-R96%T
M960B"FUS9W-T<B`B5GET=F]R96[I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDX"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G
M<W1R(")0<F5D;F%S=&%V96[]('-M97(@=')I961E;FEA.B(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C<V('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,PHC.B!L:6(O3V)J96-T+G!H<#HS,C@@;&EB+U)E;F1E<F5R
M+G!H<#HT-R!L:6(O4F5N9&5R97(N<&AP.C4P"FUS9VED(")$96QE=&4B"FUS
M9W-T<B`B5GEM87IANR(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C4X"FUS9VED(")$96QE=&4@061D<F5S<R!";V]K(@IM<V=S='(@(E9Y;6%Z
M8;L@861R97/A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I
M9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R(")0;W1V<F1E;FEE('!R
M:2!V>6UA>F%N[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I
M9"`B1&5L971E(&)U='1O;B!B96AA=FEO=7(B"FUS9W-T<B`B4W!RX79A;FEE
M('-A('1L8>AI9&QA(&YA('9Y;6%Z86YI92(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!F86EL960Z
M("@E<RD@)7,B"FUS9W-T<B`B5GEM87KA=F%N:64@>FQY:&%L;SH@*"5S*2`E
M<R(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-C(*;7-G:60@(D1E;&5T:6YG
M(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E9Y;6%ZX79A
M;FEE(&MO;G1A:W1O=B!N:64@:F4@9&]S='5P;NDN(@H*(SH@9&5L971E+G!H
M<#HS.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S='(@(E9Y;6%ZX79A
M;FEE('IL>6AA;&\B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR
M,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B3V1D96QE;FEE(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$97-C96YD:6YG(@IM
M<V=S='(@(EIO<W1U<&YE(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z,3$U"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")0;W!I<R(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3D*;7-G:60@(D1I<F5C
M=&]R>2(*;7-G<W1R(")!9')E<^%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(T"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(EIO8G)A>F5N:64B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(DYA<W1A=F5N:64@>F]B<F%Z96YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-S<*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I
M;F<@96YT<FEE<S\B"FUS9W-T<B`B0VAC971E('!O='9R9'IO=F&[('9Y;6%Z
MX79A;FEE('!O;&^^:65K/R(*"B,Z(&QI8B]/8FIE8W0N<&AP.C(Y-PIM<V=I
M9"`B1&]W;FQO860B"FUS9W-T<B`B4W1I86AN=;LB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+W)O=RYI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W
M+FEN8SHR-0IM<V=I9"`B1&]W;FQO860@=D-A<F0B"FUS9W-T<B`B4W1I86AN
M=;L@=D-A<F0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@
M=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L871E<R]B<F]W
M<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC
M.C,S(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B"FUS9W-T<B`B
M57!R879INR(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHR-2!T96UP
M;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(E5P<F%V:;L@7"(E<UPB(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*;7-G:60@(D5D:70@
M061D<F5S<R!";V]K<R(*;7-G<W1R(")5<')A=FF[(&%D<F5SX7)E(@H*(SH@
M961I="YP:'`Z.#4@961I="YP:'`Z,38Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@96YT<GD@9F]R("5S(@IM<V=S='(@(E5P<F%V:;L@<&]L;[YK=2!P
M<F4@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I
M9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB"@HC.B!E9&ET+G!H<#HQ-30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960L(&)U="!S
M879I;F<@=&AE('5P;&]A9&5D(&9I;&4@9F%I;&5D.B`E<R(*;7-G<W1R("(B
M"B)0;VQOOFMA('!R92`E<R!B;VQA(&%K='5A;&EZ;W9A;N$L(&%L92!U:VQA
M9&%N:64@86MT=6%L:7IO=F%NZ6AO('/Z8F]R=2`B"B)Z;'EH86QO.B`E<R(*
M"B,Z(&5D:70N<&AP.C$U-B!E9&ET+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960N(@IM<V=S='(@(E!O;&^^:V$@
M<')E("5S(&)O;&$@86MT=6%L:7IO=F%NX2(*"B,Z(&)R;W=S92YP:'`Z,C$V
M(&)R;W=S92YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&%D
M9&EN9R`E9"!C;VYT86-T*',I('1O(&QI<W0N(@IM<V=S='(@(DYA<W1A;&$@
M8VAY8F$@<')I('!R:63A=F%N[2`E9"!K;VYT86MT;W8@9&\@>F]Z;F%M=2XB
M"@HC.B!B<F]W<V4N<&AP.C(Q."!B<F]W<V4N<&AP.C(V-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!A9&1I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O
M;G1A8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@
M<')I9.%V86[M("5D('H@)60@<&^^861O=F%N_6-H(&MO;G1A:W1O=B!D;R!Z
M;WIN86UU+B(*"B,Z(&)R;W=S92YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@)60@8V]N=&%C="AS*2XB"FUS9W-T<B`B3F%S
M=&%L82!C:'EB82!P<FD@=GEM87KA=F%N[2`E9"!K;VYT86MT;W8N(@H*(SH@
M8G)O=W-E+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE
M=&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C=',H<RDN(@IM<V=S='(@
M(DYA<W1A;&$@8VAY8F$@<')I('9Y;6%ZX79A;FD@)60@>B`E9"!P;[YA9&]V
M86[]8V@@:V]N=&%K=&]V+B(*"B,Z(&)R;W=S92YP:'`Z-C8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@<F5M;W9I;F<@)60@8V]N=&%C="AS*2!F<F]M
M(&QI<W0N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('9Y;6%ZX79A;NT@
M)60@:V]N=&%K=&]V('IO('IO>FYA;74N(@H*(SH@8G)O=W-E+G!H<#HV.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R96UO=FEN9R`E9"!O9B`E9"!R
M97%U97-T960@8V]N=&%C="AS*2!F<F]M(&QI<W0N(@IM<V=S='(@(B(*(DYA
M<W1A;&$@8VAY8F$@<')I('9Y;6%ZX79A;NT@)60@>B`E9"!P;[YA9&]V86[]
M8V@@:V]N=&%K=&]V('IO('IO>FYA;74N(@H*(SH@;&EB+V%P:2YP:'`Z-#$U
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E87)C:&EN9R!T:&4@861D
M<F5S<R!B;V]K.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!HM6%D
M86[M('8@861R97/A<FDZ("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHQ,"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C0Q"FUS9VED
M(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHV"FUS9VED(")%>'!O<G0@061D<F5S<R!";V]K(@IM<V=S
M='(@(D5X<&]R=&]V8;L@861R97/A<B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C
M;VYT86-T<RXB"FUS9W-T<B`B17AP;W)T;W9ANR!I8F$@=GEB<F%NZ2!K;VYT
M86MT>2XB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(W"FUS9VED
M(")%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L
M>2XB"FUS9W-T<B`B17AP;W)T;W9ANR!C96S](&YA<VQE9'5J^F-I(&%D<F5S
MX7(N(@H*(SH@9&%T82YP:'`Z,3,T(&1A=&$N<&AP.C(R."!D871A+G!H<#HR
M.3<@8G)O=W-E+G!H<#HS-2!B<F]W<V4N<&AP.C$P,PHC.B!B<F]W<V4N<&AP
M.C$S,"!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E<R(*
M;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K(&%D<F5SX7)U
M.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S(@IM<V=S='(@(DYA<W1A;&$@
M8VAY8F$@<')I('!R:63A=F%N[2`E<R!D;R`E<SH@)7,B"@HC.B!B<F]W<V4N
M<&AP.C,P-0IM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!L:7-T(@IM<V=S='(@
M(DYE;6^^;F\@>F]B<F%Z:;L@>F]Z;F%M(@H*(SH@8G)O=W-E+G!H<#HS-#,*
M;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R>2(*;7-G<W1R
M(").87-T86QA(&-H>6)A('!R:2!P<F5HM6%DX79A;NT@861R97/A<F$N(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E
M<RP@3F5W($1.(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R("(B"B).97!O9&%R
M:6QO('-A('IM96YINR!M96YO.B`H)7,I("5S.R!S=&%RZ2!$3B`]("5S+"!N
M;W;I($1.(#T@)7,L(&MO<F7R(#T@)7,B"@HC.B!B<F]W<V4N<&AP.C$S-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@
M8F4@861D960Z("5S(@IM<V=S='(@(DYE;6^^;F\@;N%J<[L@;V)J96MT(&YA
M('!R:61A;FEE.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*;7-G:60@(D9A:6QE
M9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(").97!O9&%R
M:6QO('-A(&BU861ANR!V(&%D<F5SX7)I(@H*(SH@9&%T82YP:'`Z,30Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C
M=&]R>3H@)7,B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@<')E:+5A9.%V
M86[M(&%D<F5SX7)A.B`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$V-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&5D:70N<&AP
M.C$S,2!D:7-P;&%Y+G!H<#HQ,#`*;7-G:60@(D9I;&5S(@IM<V=S='(@(E/Z
M8F]R>2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW,0IM<V=I
M9"`B1FEN9"(*;7-G<W1R(").X6ISNR(*"B,Z(&5D:70N<&AP.C$P-"!E9&ET
M+G!H<#HQ.30*;7-G:60@(D9I;FES:"(*;7-G<W1R(")3:V]NZ&F[(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T($YA
M;64B"FUS9W-T<B`B2W)S=&[I(&UE;F\B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HR,#(*;7-G:60@(D9R965B=7-Y(%523"(*;7-G<W1R(")5
M4DP@<R!I;F9O<FWA8VEO=2!O('IA;F5P<N%Z9&YE;F]S=&DB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.#0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B6B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C8P-@IM<V=I9"`B
M1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R(")';&]BX6QN>2!A9')E<^%R
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C0S('1E;7!L871E<R]B
M<F]W<V4O8V]N=&%C=')O=RYI;F,Z-#0*;7-G:60@(D=R;W5P(@IM<V=S='(@
M(E-K=7!I;F$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX,@IM
M<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D1O;>%C82!A9')E<V$B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY,PIM<V=I9"`B2&]M92!#
M:71Y(@IM<V=S='(@(DUE<W1O("AD;VUO=BDB"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ,#@*;7-G:60@(DAO;64@0V]U;G1R>2(*;7-G<W1R
M(")+<F%J:6YA("AD;VUO=BDB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L96;S;B!D
M;VUO=B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P,PIM<V=I
M9"`B2&]M92!0;W-T86P@0V]D92(*;7-G<W1R(")3;65R;W9A8VEE(.CM<VQO
M("AD;VUO=BDB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`IM
M<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R("*I=.%T+W!R;W9I
M;F-I82`H9&]M;W8I(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M.#@*;7-G:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS9W-T<B`B1&]MX6-A
M(&%D<F5S82(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C4P.`IM<V=I
M9"`B24U34"(*;7-G<W1R("))35-0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0W"FUS9VED("))35-0($%D9')E<W,@0F]O:R!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")3<'+A=F$@24U34"!A9')E<^%R82(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G0@061D<F5S<R!";V]K+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&]V8;L@
M861R97/A<BP@:W)O:R`E9"(*"B,Z(&1A=&$N<&AP.C,V,0IM<V=I9"`B26UP
M;W)T+T5X<&]R="!!9&1R97-S($)O;VMS(@IM<V=S='(@(DEM<&]R=&]V8;LO
M17AP;W)T;W9ANR!A9')E<^%R92(*"B,Z(&QI8B]A<&DN<&AP.C8Q-"!L:6(O
M87!I+G!H<#HW,#$*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`B3F5P;&%T
M;ND@240B"@HC.B!L:6(O87!I+G!H<#HR,S(@;&EB+V%P:2YP:'`Z-#`T(&QI
M8B]A<&DN<&AP.C0X."!L:6(O87!I+G!H<#HV,3`*(SH@;&EB+V%P:2YP:'`Z
M-CDW(&QI8B]A<&DN<&AP.C<T.2!L:6(O87!I+G!H<#HQ,#DU"FUS9VED("))
M;G9A;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R(").97!L871N_2!A9')E<^%R
M(@H*(SH@;&EB+V%P:2YP:'`Z,3`Y.2!L:6(O87!I+G!H<#HQ,3<R(&QI8B]A
M<&DN<&AP.C$R,C4*;7-G:60@(DEN=F%L:60@96UA:6PB"FUS9W-T<B`B3F5P
M;&%T;N$@92UM86EL;W;A(&%D<F5S82(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#<*
M;7-G:60@(DEN=F%L:60@96YT<GDB"FUS9W-T<B`B3F5P;&%T;N$@<&]L;[YK
M82(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C8V"FUS9VED("));G9A;&ED
M(&ME>2!S<&5C:69I960N(@IM<V=S='(@(D)O;"!Z861A;OT@;F5P;&%T;OT@
M:[7ZZ"XB"@HC.B!L:6(O87!I+G!H<#HQ,3`S"FUS9VED("));G9A;&ED(&YA
M;64B"FUS9W-T<B`B3F5P;&%T;ND@;65N;R(*"B,Z(&QI8B]A<&DN<&AP.C<U
M,PIM<V=I9"`B26YV86QI9"!O8FIE8W1)9"(*;7-G<W1R(").97!L871NZ2!O
M8FIE8W1)9"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`*;7-G:60@(B(*
M(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE
M(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E9"XB"FUS9W-T<B`B(@HB
M2F4@<&^^861O=F%NX2!P;V1P;W)A($Q$05`L(&%L92!,1$%0(&UO9'5L(&YI
M92!J92!D;W-T=7!N_2!A;&5B;R!N86AR873]+B(*"B,Z(&QI8B]/8FIE8W16
M:65W+G!H<#HQ,S@*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B4&]S
M;&5D;N$@86MT=6%L:7KA8VEA(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-3,*;7-G:60@(DQA<W0@3F%M92(*;7-G<W1R(")0<FEE>G9I<VMO
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,38*
M;7-G:60@(DQI<W0B"FUS9W-T<B`B6F]Z;F%M(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]S96%R8V@N:6YC.C<X"FUS9VED(")-871C:&EN9R(*;7-G<W1R(")/
M8G-A:'5J^F-E(@H*(SH@;&EB+V%P:2YP:'`Z,C`W"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!#;VYT86-T<R(*;7-G<W1R(")-87AI;>%L;GD@<&_H970@
M:V]N=&%K=&]V(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I
M9"`B36%X:6UU;2!N=6UB97(@;V8@<&%G97,B"FUS9W-T<B`B36%X:6WA;&YY
M('!OZ&5T('-T<N%N(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PIM
M<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(DUE;G4B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$3B!I;B!,1$%0('-O=7)C
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")#:/UB82!$3B!V(&MO;F9I9W5R
MX6-I:2!,1$%0('ID<F]J82XB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0:&]N92(*;7-G<W1R(")-;V)I;&[]
M('1E;&5F\VXB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,S,B!L:6(O1')I
M=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GD@
M9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(MIP<F%V82!Z;'EH86QA.B`H)7,I
M("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3(Q,0IM<V=I9"`B36]R92!T:&%N(#$@
M96YT<GD@9F]U;F0B"FUS9W-T<B`B5GEH;W9U:F4@=FEA8R!A:V\@,2!P;VQO
MOFMA(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ-@IM<V=I
M9"`B36]V92(*;7-G<W1R(")0<F5S=6[ZNR(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(T-PHC.B!T96UP;&%T97,O<')E9G,O861D
M<F5S<V)O;VMS96QE8W0N:6YC.C$X-`IM<V=I9"`B36]V92!L969T(@IM<V=S
M='(@(E!R97-U;OJ[(':U879O(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M
M;G-E;&5C="YI;F,Z,C0Y"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O
M:W-E;&5C="YI;F,Z,3@V"FUS9VED(")-;W9E(')I9VAT(@IM<V=S='(@(E!R
M97-U;OJ[('9P<F%V;R(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,38*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*
M;7-G<W1R(")!9')E<^%R('H@375L8F5R<GDB"@HC.B!L:6(O87!I+G!H<#HQ
M,3,Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@
M=VET:"!A9&1R97-S(%LE<UTL(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L
M<F5A9'D@97AI<W0B"FUS9W-T<B`B17AI<W1U:F4@=FEA8V5R;R!O<_1B(',@
M861R97-O=2!;)7-=+"!A;&4@OFEA9&YA(',@;65N;VT@6R5S72(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N
M9&ES=#HR-#,*;7-G:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R(")-]&H@
M861R97/A<B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z,3$Y"FUS9VED(")->2!!
M9&1R97-S($)O;VMS(@IM<V=S='(@(DUO:F4@861R97/A<F4B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`B365N;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B3F%M92!&;W)M870B"FUS
M9W-T<B`B1F]R;>%T(&UE;F$B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES
M=#HS,34*;7-G:60@(DYE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y(@IM<V=S
M='(@(D%D<F5SX7(@Z&QE;F]V($YE=&-E;G1E<B(*"B,Z(&%D9"YP:'`Z,S8@
M861D+G!H<#HQ,C0@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*;7-G:60@
M(DYE=R!#;VYT86-T(@IM<V=S='(@(DYO=OT@:V]N=&%K="(*"B,Z(&5D:70N
M<&AP.CDU(&5D:70N<&AP.C$P,B!E9&ET+G!H<#HR,#D@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHT-0IM<V=I9"`B3F5X="(*;7-G<W1R("+/86QE:B(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q.`IM<V=I9"`B3FEC
M:VYA;64B"FUS9W-T<B`B4')E>OUV:V$B"@HC.B!L:6(O87!I+G!H<#HQ,C$S
M(&QI8B]A<&DN<&AP.C$R-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@)7,@
M96YT<GD@9F]U;F0@9F]R("5S(@IM<V=S='(@(E!R92`E<R!N965X:7-T=6IE
M(&YI:F%KX2!P;VQOOFMA("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3$X,0IM<V=I
M9"`B3F\@861D<F5S<R!B;V]K<R!F;W5N9"XB"FUS9W-T<B`B3F5B;VQI(&[A
M:F1E;ND@OFEA9&YE(&%D<F5SX7)E+B(*"B,Z(&UI;FES96%R8V@N<&AP.C@Q
M"FUS9VED(").;R!C;VYT86-T<R!F;W5N9"(*;7-G<W1R(").96)O;&D@;N%J
M9&5NZ2"^:6%D;F4@:V]N=&%K='DB"@HC.B!L:6(O87!I+G!H<#HU,3,@;&EB
M+V%P:2YP:'`Z-S@T"FUS9VED(").;R!V0V%R9"!D871A('=A<R!F;W5N9"XB
M"FUS9W-T<B`B3F5B;VQI(&[A:F1E;ND@^F1A:F4@=D-A<F0N(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T
M<B`BKFEA9&YE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3@T
M"FUS9VED(").;W1E<R(*;7-G<W1R(")0;WINX6UK>2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@
M<&%G92(*;7-G<W1R(")0;^AE="!P;VQOOFEE:R!N82!S='+A;FMU(@H*(SH@
M;&EB+V%P:2YP:'`Z-C,R(&QI8B]A<&DN<&AP.C<V-0IM<V=I9"`B3V)J96-T
M(&YO="!F;W5N9"(*;7-G<W1R(")/8FIE:W0@;F5B;VP@;N%J9&5N_2(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(R,PIM<V=I9"`B3V9F:6-E
M(@IM<V=S='(@(E!R86-O=FES:V\B"@HC.B!T96UP;&%T97,O<')E9G,O:6US
M<%]O<'0N:6YC.C(R"FUS9VED("(B"B)/;F-E('EO=2!S879E('1H:7,@;W!T
M:6]N('!A9V4L('1H92!A9&1R97-S(&)O;VL@=VEL;"!B92!P97)M86YE;G1L
M>2`B"B)D96QE=&5D+B!)9B!T:&ES(&ES(&YO="!W:&%T('EO=2!W86YT+"!T
M:&5N('EO=2!M=7-T(&-H86YG92!Y;W5R('-E;&5C=&EO;B`B"B)T;R!<(DYO
M;F5<(BXB"FUS9W-T<B`B(@HB2V7O('5L;[[M=&4@=/IT;R!S='+A;FMU(',@
M;6^^;F]SNV%M:2P@861R97/A<B!B=61E('9Y;6%Z86[]+B!!:R!T;R`B"B)N
M96-H8V5T92P@;75S[71E('IM96YINR!N87-T879E;FEE(&YA(%PBKFEA9&YE
M7"(B"@HC.B!L:6(O87!I+G!H<#HW.3(*;7-G:60@(D]N;'D@;VYE('9C87)D
M('-U<'!O<G1E9"XB"FUS9W-T<B`B2F4@<&]D<&]R;W9A;N$@:6)A(&IE9&YA
M('9C87)D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T
M<B`B26[I(&YA<W1A=F5N:6$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"!V
M97)E:F[](&NU^N@B"@HC.B!L:6(O87!I+G!H<#HT.3<@;&EB+V%P:2YP:'`Z
M-C(S(&QI8B]A<&DN<&AP.C<Q,"!L:6(O87!I+G!H<#HY-3(*(SH@;&EB+V%P
M:2YP:'`Z,3$Q-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B
M4'+M<W1U<"!Z86UI971N=73](@H*(SH@;&EB+T1R:79E<BYP:'`Z-34P"FUS
M9VED(")097)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")0<NUS='5P('IA;6EE
M=&YU=/TB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY.0IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4'+A=F$B"@HC.B!D871A+G!H<#HU
M,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")0:6YE($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<^%R('H@4&EN92(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N
M86UE('1H92!N97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R(")0;VUE;G5J=&4@
M<')O<^UM(&YO=OT@>F]Z;F%M(&MO;G1A:W1O=CHB"@HC.B!E9&ET+G!H<#HY
M."!E9&ET+G!H<#HQ,#$@961I="YP:'`Z,C`Q"FUS9VED(")0<F5V:6]U<R(*
M;7-G<W1R(")0<F5D8VCA9'IA:OIC82(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H
M<"YD:7-T.C0Q-@IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B4')I=N%T;GD@861R97/A<B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,30W"B,L('!H<"UF;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@*"5S*2`E
M<R(*;7-G<W1R(")#:'EB;N$@<&^^:6%D879K83H@*"5S*2`E<R(*"B,Z('1E
M;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHQ.`IM<V=I9"`B475I8VL@
M4V5A<F-H(@IM<V=S='(@(E+]8VAL92!HM6%D86YI92(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E860@
M9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D-H>6)A('!R:2#H[71A;NTZ("@E
M<RD@)7,B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4R"FUS9VED(")296%D
M:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(LCM=&%N
M:64@:V]N=&%K=&]V(&YI92!J92!D;W-T=7!NZ2XB"@HC.B!L:6(O4F5N9&5R
M97(N<&AP.C0Y"FUS9VED(")296%L;'D@9&5L971E('1H:7,@8V]N=&%C=#\B
M"FUS9W-T<B`B3F%O>F%J('-I(+YE;.%T92!V>6UA>F&[('1E;G1O(&MO;G1A
M:W0_(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C(*;7-G:60@
M(E)E8V]R9',@9&ES<&QA>65D.B(*;7-G<W1R("):;V)R87IE;ND@<&]L;[YK
M>3HB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC
M.C$W-@IM<V=I9"`B4F5M;W9E(&%D9')E<W,@8F]O:R(*;7-G<W1R(")6>6UA
M>F&[(&%D<F5SX7(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T
M+FEN8SHR,SD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B3V1S='+A
M;FF[('-TY7!E8R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,PIM<V=I9"`B4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(D]D<W1R
MX6YINR!Z;R!Z;WIN86UU(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHR,0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@
M=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@
M(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S
M<R!B;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"B)0<F5P[7-ANR!E>&ES='5J
M^F-I(&%D<F5SX7(@:6UP;W)T;W9A;OUM(&%D<F5SX7)O;3\@/'-T<F]N9SY6
M87)O=F%N:64Z('1O=&\@(@HB=GEM8;YE(':Y971K>2!P;VQOOFMY('9O(%9A
MN6]M(&%K='7A;&YO;2!A9')E<^%R:2X\+W-T<F]N9SXB"@HC.B!L:6(O1')I
M=F5R+G!H<#HT,S@*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD
M+B(*;7-G<W1R(")0;[YA9&]V86[](&]B:F5K="!N96)O;"!NX6ID96[](@H*
M(SH@861D+G!H<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$T
M"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R(")/8FYO=FF[(&YA
M('!R961N87-T879E;ND@:&]D;F]T>2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T:69I8V%T
M92(*;7-G<W1R(")697)E:F[](%,O34E-12!C97)T:69I:^%T(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")35$%2
M5%1,4R!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B0VAY8F$@<')I(%-405)4
M5$Q3.B`H)7,I("5S(@H*(SH@961I="YP:'`Z,3`V(&%D9"YP:'`Z,S<@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S
M='(@(E5L;[YINR(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-C<*;7-G:60@
M(E-A=FEN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")5
M:VQA9&%N:64@:V]N=&%K=&]V(&YI92!J92!D;W-T=7!NZ2XB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.3<@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.C$Q,PHC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI
M;F,Z,C$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z-#D*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(DBU861A
MNR(*"B,Z(&QI8B]A<&DN<&AP.C$P,CD*;7-G:60@(E-E87)C:"!F86EL960B
M"FUS9W-T<B`B2+5A9&%N:64@>FQY:&%L;R(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M,C$@;&EB+V%P:2YP:'`Z,3$R-R!L:6(O87!I+G!H<#HQ,3,V(&QI8B]A<&DN
M<&AP.C$Q-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B2+5A9&%N:64@>FQY:&%L;SH@)7,B"@HC.B!L:6(O1')I
M=F5R+VYU;&PN<&AP.C0W"FUS9VED(")396%R8VAI;F<@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B2+5A9&%N:64@;FEE(&IE(&1O<W1U<&[I+B(*"B,Z
M('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,@IM<V=I9"`B4V5A
M<F-H:6YG+BXN(@IM<V=S='(@(DBU863A;2XN+B(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C8V"FUS9VED(")396QE8W0@86X@861D<F5S<R!B
M;V]K('1O(&1E;&5T92(*;7-G<W1R("):=F^U=&4@861R97/A<BP@:W1O<OT@
M8VAC971E('9Y;6%Z8;LB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHY,`IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM
M<V=S='(@(EIV;[5T92!A9')E<^%R+"!K=&]R_2!C:&-E=&4@=7!R879INR(*
M"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S(*;7-G:60@(E-E;&5C
M="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G<W1R("):
M=F^U=&4@861R97/A<BP@>B!K=&]RZ6AO(&-H8V5T92!E>'!O<G1O=F&[.B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C8*;7-G:60@(E-E;&5C
M="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B6G9O
MM71E(&%D<F5SX7(L(&1O(&MT;W+I:&\@8VAC971E(&EM<&]R=&]V8;LZ(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0IM<V=I9"`B4V5L96-T
M('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B6G9O
MM71E('IN86MO=OH@<V%D=2!Z9')O:F]VZ6AO('/Z8F]R=3HB"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P"FUS9VED(")396QE8W0@=&AE(&5X
M<&]R="!F;W)M870Z(@IM<V=S='(@(E9Y8F5R=&4@9F]R;>%T(&5X<&]R='4Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L
M96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B6G9OM71E('/Z8F]R
M('!R92!I;7!O<G0Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ
M,0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE
M.B(*;7-G<W1R("):=F^U=&4@9F]R;>%T(&5X<&]R='4Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@
M=7-E9"!T;R!D:7-P;&%Y(&YA;65S.B(*;7-G<W1R("):=F^U=&4@9F]R;>%T
M('IO8G)A>F]V86YI82!M:65N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT
M+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`B
M3F%S=&%V96YI92"Y=&%N9&%R9&[I:&\@<W#T<V]B=2!Z;V)R87IE;FEA+"!T
M<FEE9&5N:6$@82!S='+A;FMO=F%N:6$N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$X"FUS9VED(")396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L
M87D@:6X@=&AE(&%D9')E<W,@;&ES=',N(@IM<V=S='(@(DYA<W1A=F5N:64@
M<&]L[2P@:W1O<ND@<V$@8G5D^B!Z;V)R87IO=F&[('8@>F]Z;F%M92!A9')I
M97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R"FUS9VED(")396QE
M8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@;F%M97,N(@IM<V=S='(@(DYA
M<W1A=F5N:64@9F]R;>%T=2!Z;V)R87IO=F%N:6$@;6EE;BXB"@HC.B!A9&0N
M<&AP.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E-E;&5C=&5D(&%D9')E<W,@
M8F]O:R!<(B5S7"(N(@IM<V=S='(@(D)O;"!V>6)R86[](&%D<F5SX7(@7"(E
M<UPB+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B
M4VAA<F5D($1I<F5C=&]R>2(*;7-G<W1R("):9&EEM6%N_2!A9')E<^%R(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3:&]W("5S(@IM<V=S='(@(EIO8G)A>FF[("5S(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT.`IM<V=I9"`B4VAO=R!!
M;&PB"FUS9W-T<B`B6F]B<F%Z:;L@=KEE=&MO(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHT-PIM<V=I9"`B4VAO=R!#;VYT86-T<R(*;7-G
M<W1R("):;V)R87IINR!K;VYT86MT>2(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z-#8*;7-G:60@(E-H;W<@3&ES=',B"FUS9W-T<B`B6F]B
M<F%Z:;L@>F]Z;F%M>2(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C(Q"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C,V"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R(")3;65R
M('1R:65D96YI82(*"B,Z(&QI8B]A<&DN<&AP.C(P,`IM<V=I9"`B4V]U<F-E
M<R(*;7-G<W1R("):9')O:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34X"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E
M87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`BJ7!E8VEF:6MU:G1E
M+"!K9&4@<V$@;6%J^B!O8FIA=FF[(')O>KGM<F5NZ2!V_7-L961K>2!HM6%D
M86YI82XB"@HC.B!B<F]W<V4N<&AP.C(Q-"!B<F]W<V4N<&AP.C(V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@)60@8V]N=&%C
M="AS*2!T;R!L:7-T+B(*;7-G<W1R(")0<FED86YI92`E9"!K;VYT86MT;W8@
M9&\@>F]Z;F%M=2!B;VQO(/IS<&6Y;NDN(@H*(SH@8G)O=W-E+G!H<#HQ-C`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O
M("5S(@IM<V=S='(@(E!R:61A;FEE("5S(&1O("5S(&)O;&\@^G-P9;ENZ2(*
M"B,Z(&)R;W=S92YP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G
M<W1R(")6>71V;W)E;FEE('IO>FYA;74@:V]N=&%K=&]V(%PB)7-<(B!B;VQO
M(/IS<&6Y;NDN(@H*(SH@8G)O=W-E+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@9&5L971E9"`E9"!C;VYT86-T*',I+B(*;7-G
M<W1R(")6>6UA>F%N:64@)60@:V]N=&%K=&]V(&)O;&\@^G-P9;ENZ2XB"@HC
M.B!B<F]W<V4N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R96UO=F5D("5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G<W1R
M(")6>6UA>F%N:64@)60@:V]N=&%K=&]V('IO('IO>FYA;74@8F]L;R#Z<W!E
MN6[I+B(*"B,Z(&1A=&$N<&AP.C4P"FUS9VED(")44U8B"FUS9W-T<B`B5%-6
M("AH;V1N;W1Y(&]D9&5L96[I('1A8G5LX71O<F]M*2(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B2&]D
M;F]T>2!O9&1E;&5NZ2!T86)U;.%T;W)O;2(*"B,Z('9I97<N<&AP.C$U"FUS
M9VED(")4:&4@5D93(&)A8VME;F0@;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T
M;R!E;F%B;&4@871T86-H;65N="!U<&QO861S+B(*;7-G<W1R(")!8GD@<W1E
M(&UO:&QI(&YA:'+A=F&[('!R[6QO:'DL(&UU<^T@8GF[(&YA:V]N9FEG=7)O
M=F%N_2!61E,@8F%C:V5N9"XB"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#<V"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!9')E<^%R(%PB)7-<(B!N965X:7-T
M=6IE+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R(")!9')E<^%R(%PB)7-<(B!B;VP@^G-P9;EN
M92!V>71V;W)E;OTN(@H*(SH@861D<F5S<V)O;VMS+G!H<#HW,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<F5M
M;W9E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D%D<F5SX7(@7"(E<UPB(&)O
M;"#Z<W!EN6YE('9Y;6%Z86[]+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@
M=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")!9')E<^%R(%PB
M)7-<(B!B;VP@^G-P9;EN92!A:W1U86QI>F]V86[]+B(*"B,Z(&1A=&$N<&AP
M.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(&-O
M=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(D%D<F5SX7(@<V$@;F5P
M;V1A<FEL;R!V>6UA>F&[.B`E<R(*"B,Z(&5D:70N<&AP.C4Q('9C87)D+G!H
M<#HR,B!D:7-P;&%Y+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O
M;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M4&^^861O=F%N_2!K;VYT86MT(&YE97AI<W1U:F4N(@H*(SH@961I="YP:'`Z
M,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE(%PB)7-<(B!H87,@
M<W5C8V5S<V9U;&QY(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4_IB;W(@7"(E
M<UPB(&)O;"#Z<W!EN6YE('9Y;6%Z86[]+B(*"B,Z(&1A=&$N<&AP.C(X-`IM
M<V=I9"`B5&AE(&EM<&]R="!C86X@8F4@9FEN:7-H960@9&5S<&ET92!T:&4@
M=V%R;FEN9W,N(@IM<V=S='(@(DEM<&]R="!S82!DX2!D;VMO;NAINR!N87!R
M:65K('9A<F]V86YI86TN(@H*(SH@8G)O=W-E+G!H<#HS,0IM<V=I9"`B5&AE
M<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RXB"FUS9W-T<B`B
MKFEA9&YE(&%D<F5SX7)E(&YI92!S^B!P<NUS='5P;ND@;F$@<')E>F5R86YI
M92XB"@HC.B!A9&0N<&AP.C(Y"FUS9VED("(B"B)4:&5R92!A<F4@;F\@=W)I
M=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A
M9&1R97-S(&)O;VMS("(*(F%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T
M;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI
M<R`B"B)I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBKFEA9&5N('H@9&]S='5P;OUC
M:"!A9')E<^%R;W8@;F5U;6^^\G5J92!V:VQA9&%N:64@;F]V_6-H('!O;&^^
M:65K+B!!:R`B"B)P<F5D<&]K;&%DX71E+""^92!I9&4@;R!C:'EB=2P@:V]N
M=&%K='5J=&4@<')O<^UM('-P<N%V8W4@5N&Y:&\@<WES=.EM=2XB"@HC.B!A
M9&0N<&AP.C$R,0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN
M9R!T:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).87-T
M86QA(&-H>6)A('!R:2!P<FEDX79A;NT@=&]H=&\@:V]N=&%K='4N(%!R;W/M
M;2!K;VYT86MT=6IT92!S<'+A=F-U(%;AN6AO("(*(G-Y<W3I;74N(@H*(SH@
M8G)O=W-E+G!H<#HR-S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A
M=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!V
M>71VX7)A;NT@;F]VZ6AO('IO>FYA;74N(@H*(SH@861D<F5S<V)O;VMS+G!H
M<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M8W)E871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(DYA<W1A
M;&$@8VAY8F$@<')I('9Y=';A<F%N[2!T;VAT;R!A9')E<^%R83H@)7,B"@HC
M.B!B<F]W<V4N<&AP.C$V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@7"(E<UPB(&9R;VT@=&AE('-O=7)C92!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('9Y;6%Z
MX79A;NT@7"(E<UPB('IO('ID<F]J;W;I:&\@861R97/A<F$N(@H*(SH@9&5L
M971E+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G<W1R(").87-T
M86QA(&-H>6)A('!R:2!V>6UA>N%V86[M('1O:'1O(&MO;G1A:W1U.B`E<RXB
M"@HC.B!B<F]W<V4N<&AP.C,Q,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AE(&QI<W0B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P
M<FD@>F]B<F%Z;W9A;NT@>F]Z;F%M=2(*"B,Z(&1A=&$N<&AP.C,S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!D871A.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!I;7!O
M<G1E(/ID86IO=CH@)7,B"@HC.B!L:6(O87!I+G!H<#HU,#D@;&EB+V%P:2YP
M:'`Z-S<Y"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@
M:6UP;W)T92#Z9&%J;W8@:4-A;&5N9&%R+B(*"B,Z(&%D9')E<W-B;V]K<RYP
M:'`Z-3@@861D<F5S<V)O;VMS+G!H<#HV,R!A9&1R97-S8F]O:W,N<&AP.C8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO
M=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P<FD@=GEM87KA=F%N[2!T;VAT;R!A9')E<^%R83H@)7,N(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S
M(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2!T;VAT
M;R!A9')E<^%R83H@)7,B"@HC.B!E9&ET+G!H<#HQ-C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT
M<GDZ("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I
M:2!T96IT;R!P;VQOOFMY.B`E<R(*"B,Z(&1A=&$N<&AP.C$W.0IM<V=I9"`B
M5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+B(*;7-G<W1R(").
M965X:7-T=6KZ(+YI861N92!A9')E<^%R92!N82!E>'!O<G0N(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#`*;7-G:60@
M(E1H97-E(&%D9')E<W,@8F]O:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D
M97(Z(@IM<V=S='(@(D%D<F5SX7)E('-A('IO8G)A>FEA('8@=&]M=&\@<&]R
M863M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T
M,PIM<V=I9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O
M<F1E<CHB"FUS9W-T<B`B4W3E<&-E('-A('IO8G)A>FEA('8@=&]M=&\@<&]R
M863M.B(*"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA
M="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")496YT;R!F;W)MX70@<_IB
M;W)U(&YI92!J92!P;V1P;W)O=F%N_2XB"@HC.B!L:6(O87!I+G!H<#HQ,30P
M(&QI8B]A<&DN<&AP.C$Q-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P
M97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B
M;V]K(@IM<V=S='(@(E3A=&\@;W-O8F$@=;X@;>$@>N%Z;F%M("5S('8@861R
M97/A<FDN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T.`IM<V=I9"`B
M(@HB5&AI<R!W:6QL(&)E('1H92!D969A=6QT(&%D9')E<W,@8F]O:R!W:&5N
M(&%D9&EN9R!O<B!I;7!O<G1I;F<@8V]N=&%C=',N(@IM<V=S='(@(B(*(E1O
M=&\@8G5D92!P<F5D;F%S=&%V96[](&%D<F5SX7(@<')I('!R:63A=F%N[2!A
M;&5B;R!I;7!O<G1O=F%N[2!K;VYT86MT;W8N(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I='5L
M(@H*(SH@;&EB+U1U<F)A+G!H<#HT-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N($UI<W-I;F<@<V]U<F-E('1Y
M<&4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GET=F]R:;L@;F]VZ2!Z9&EE
MM6%N:64N($-H_6)A('1Y<"!Z9')O:F$N(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3`P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@
M9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B3F5M;[YNZ2!N86AR8;L@9&5F
M:6[M8VEU("5S+B(*"B,Z(&5D:70N<&AP.CDU(&5D:70N<&AP.CDX(&5D:70N
M<&AP.C$P,2!E9&ET+G!H<#HQ,#8@961I="YP:'`Z,C`S"FUS9VED(")5;F1O
M($-H86YG97,B"FUS9W-T<B`B6G)UN6F[('IM96YY(@H*(SH@;&EB+V%P:2YP
M:'`Z-30R(&QI8B]A<&DN<&AP.C8V,2!L:6(O87!I+G!H<#HW.3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<R(*
M;7-G<W1R(").97!O9'!O<F]V86[]('1Y<"!O8G-A:'4@*$-O;G1E;G0M5'EP
M92DZ("5S(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"FUS9VED
M(")697)I<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`B061R97/A<B!697)I<VEG
M;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O
M8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@7"(E<UPB(@IM<V=S='(@(EIO8G)A>FF[(%PB)7-<(B(*"B,Z(&UI
M;FES96%R8V@N<&AP.C<V"FUS9VED(")6:65W($-O;G1A8W0B"FUS9W-T<B`B
M6F]B<F%Z:;L@:V]N=&%K="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C0*;7-G:60@(E9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R
M(")0<F5D;F%S=&%V96[]('-P]'-O8B!Z;V)R87IE;FEA.B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB
M"FUS9W-T<B`B55),(%=75R!S='+A;FMY(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3$S"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B
M061R97-A(&1O('!RX6-E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3(T"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B365S=&\@*'!RX6-A
M*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S.0IM<V=I9"`B
M5V]R:R!#;W5N=')Y(@IM<V=S='(@(DMR86II;F$@*'!RX6-A*2(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U-@IM<V=I9"`B5V]R:R!0:&]N
M92(*;7-G<W1R(")496QE9O-N(&1O('!RX6-E(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3,T"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E(@IM
M<V=S='(@(E-M97)O=F%C:64@Z.US;&\@*'!RX6-A*2(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$R.0IM<V=I9"`B5V]R:R!3=&%T92]0<F]V
M:6YC92(*;7-G<W1R("*I=.%T+W!R:79I;F-I82`H<'+A8V$I(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$Y"FUS9VED(")7;W)K(%-T<F5E
M="!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!D;R!P<N%C92(*"B,Z(&1A=&$N
M<&AP.C(S-R!B<F]W<V4N<&AP.C$P-B!B<F]W<V4N<&AP.C(R-R!A9&0N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM
M<V=S='(@(DYE;?2^971E('9Y='9O<FF[('9I86,@86MO("5D(&MO;G1A:W1O
M=B!V(%PB)7-<(BXB"@HC.B!E9&ET+G!H<#HW,R!D:7-P;&%Y+G!H<#HU."!V
M:65W+G!H<#HS-@IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@
M=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(DYE;>%T92!P<N%V;R!N
M82!Z;V)R87IE;FEE('1O:'1O(&MO;G1A:W1U+B(*"B,Z('9C87)D+G!H<#HT
M,`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T
M:&ES(&]B:F5C="XB"FUS9W-T<B`B3F5MX71E('!RX79O(&YA('IO8G)A>F5N
M:64@=&]H=&\@;V)J96MT=2XB"@HC.B!L:6(O5'5R8F$N<&AP.C4S-PIM<V=I
M9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VYS('1O(&1E;&5T92!T:&ES
M('-O=7)C92XB"FUS9W-T<B`B3F5MX71E('!RX79O(&YA('9Y;6%Z86YI92!T
M;VAT;R!Z9')O:F$N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T
M+FEN8SHU-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B375S[71E('9Y8G)ANR!C:66U;W;](&%D<F5S
MX7(N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHR,PIM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N(@IM<V=S='(@
M(DUU<^UT92!V>6)R8;L@8VEEM6]V_2!Z;WIN86TN(@H*(SH@961I="YP:'`Z
M,S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@8V]N=&%C
M="!F:7)S="XB"FUS9W-T<B`B375S[71E('9Y8G)ANR!A<W!O\B!J961E;B!K
M;VYT86MT+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z
M,3<@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP
M;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S
M="!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R(")-
M=7/M=&4@=GEB<F&[(&%S<&_R(&IE9&YU('!O;&^^:W4N(@H*(SH@961I="YP
M:'`Z-S<*;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W
M('1H:7,@8V]N=&%C="XB"FUS9W-T<B`B3>%T92!P<N%V;R!I8F$@;F$@>F]B
M<F%Z96YI92!T;VAT;R!K;VYT86MT=2XB"@HC.B!B<F]W<V4N<&AP.C,Q.`IM
M<V=I9"`B66]U<B!D969A=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E
M86)L92XB"FUS9W-T<B`B5N&Y('!R961N87-T879E;OT@861R97/A<B!S82!N
M963A('!R97IE<F&[+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHV
M('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@(EMN
M;R!V86QU95TB"FUS9W-T<B`B6[YI861N82!H;V1N;W1A72(*"B,Z(&QI8B]4
M=7)B82YP:'`Z-38P"FUS9VED(")?0G)O=W-E(@IM<V=S='(@(E]0<F5Z97)A
MNR(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#<*;7-G:60@
M(E]#;VYT86-T<R(*;7-G<W1R(")?2V]N=&%K='DB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C,*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B
M7U9Y;6%Z8;LB"@HC.B!L:6(O5'5R8F$N<&AP.C4V.0IM<V=I9"`B7TEM<&]R
M="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R="]%>'!O<G0B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0V"FUS9VED(")?3&ES=',B"FUS9W-T
M<B`B7UIO>FYA;7DB"@HC.B!L:6(O5'5R8F$N<&AP.C4U-PIM<V=I9"`B7TUY
M($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B7TUO:F4@861R97/A<F4B"@HC.B!L
M:6(O5'5R8F$N<&AP.C4V,PIM<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S='(@
M(E].;W;](&MO;G1A:W0B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N
M:6YC.C,*;7-G:60@(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B
M3V1S=%]RX6YINR!Z('1O:'1O('IO>FYA;74B"@HC.B!L:6(O5'5R8F$N<&AP
M.C4V-0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?2+5A9&&[(@H*(SH@=F-A
M<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R(")C;VYT86-T
M<RYV8V8B"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S
M='(@(F-O;G1A8W1S+F-S=B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B8V]N
M=&%C=',N='-V(@IM<V=S='(@(F-O;G1A8W1S+G1S=B(*"B,Z(&1A=&$N<&AP
M.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(F-O;G1A8W1S+G9C
M9B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S@*;7-G:60@(FYO(&9O
M<FUA='1I;F<B"FUS9W-T<B`BOFEA9&YE(&9O<FWA=&]V86YI92(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S(*;7-G:60@(FYO;F4B"FUS
M9W-T<B`BOFEA9&YE(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHS,0IM<V=I9"`B=&\@82!#;VYT86-T($QI<W0B"FUS9W-T<B`B9&\@>F]Z
M;F%M=2!K;VYT86MT;W8B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N
M:6YC.C(Q"FUS9VED(")T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B9&\@:6[I:&\@861R97/A<F$B"@HC.B!D871A+G!H<#HU,2!T96UP
M;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ,PHC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$U('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,34*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1U<F)A+W!O+RYH=&%C8V5S<P``````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S-C(W-38`,#$W
M-S4R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$1E;GD@9G)O;2!A;&P*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M=7)B82]P;R]L=%],5"YP;P``````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#<V,S(R`#$P-#$W,S8R-S4V`#`Q-S4T-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C($QI=&AU86YI
M86X@=')A;G-L871I;VYS(&9O<B!4=7)B82!P86-K86=E+@HC($-O<'ER:6=H
M="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(%1U<F)A('!A
M8VMA9V4N"B,@5FEL:75S(%-U;7-K87,@/'9I;&EU<T!L;FLN;'0^+"`R,#`S
M+"`R,#`T+@HC(`IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R
M<VEO;CH@5'5R8F$@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#0M,3(M,#$@,34Z,38K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!6:6QI
M=7,@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#Y<;B(*(DQA;F=U86=E+51E86TZ
M($QI=&AU86YI86X@/'9I;&EU<T!L;FLN;'0^7&XB"B)-24U%+59E<G-I;VXZ
M(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E3
M3RTX.#4Y+3$S7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M7&XB"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C0R"B,L(&9U
M>GIY"FUS9VED("(@061D(&%N($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@
M(E!I;F4@861R97/X(&MN>6=E;.LB"@HC.B!T96UP;&%T97,O<')E9G,O:6US
M<%]O<'0N:6YC.C,Q"B,L(&9U>GIY"FUS9VED("(@1&5L971E($E-4U`@061D
M<F5S<R!";V]K(@IM<V=S='(@(N$@<&%S:7)I;FMTX"!A9')E<_@@:VYY9V5L
MYB(*"B,Z(&1A=&$N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@86QR96%D>2!E>&ES=',@86YD('=A<R!N;W0@:6UP;W)T960N(@IM<V=S
M='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(V"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*
M;7-G:60@(EPB1FER<W1N86UE($QA<W1N86UE7"(@("AI92X@2F]H;B!$;V4I
M(@IM<V=S='(@(EPB5F%R9&%S(%!A=F%R9.M<(B`H<'9Z+B!*;VYA<R!*;VYA
M:71I<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")<
M(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H:64N($1O92P@2F]H;BDB"FUS9W-T
M<B`B7")687)D87,L(%!A=F%R9.M<(B`H<'9Z+B!*;VYA<RP@2F]N86ET:7,I
M(@H*(SH@861D+G!H<#HQ,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@861D
M960N(@IM<V=S='(@(B5S('!R:63K=&%S+B(*"B,Z(&1A=&$N<&AP.C,T,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O
M<G1E9"(*;7-G<W1R("(E<R!F86EL87,@<^MK;6EN9V%I(.%K96QT87,B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R(")N=6\@)7,@:6MI("5S
M(&GP("5S(@H*(SH@;&EB+U1U<F)A+G!H<#HT-#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@
M861R97/X(&MN>6=E;.LB"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z
M-#4*;7-G:60@(D$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B2OMS^"!N87+P>6MLZR!N97!A;&%I:V\@:49R
M86UE<R!O8FIE:W3X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.0IM
M<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T<B`B4&%I9?!K;W,@9F]R
M;6]S('9I<O!U:F4B"@HC.B!V:65W+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R("(E<R!S
MZVMM:6YG86D@<')I9.MT87,@X2`E<R(*"B,Z(&%D9"YP:'`Z-38@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR,@HC+"!F=7IZ>0IM<V=I9"`B061D
M(@IM<V=S='(@(L%V97-?=&DB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S
M<V)O;VMS96QE8W0N:6YC.C$W-`HC+"!F=7IZ>0IM<V=I9"`B061D(&%D9')E
M<W,@8F]O:R(*;7-G<W1R(").971E:7-I;F=A(&%D<F5S^"!K;GEG96SK(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X"B,L(&9U>GIY"FUS9VED(")!
M9&0@86YD($1E;&5T92!)35-0(&%D9')E<W,@8F]O:W,B"FUS9W-T<B`B4&%S
M:7)I;FMT82!A9')E<_@@:VYY9V5LZR`G)7,G+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M;B(*
M;7-G<W1R(")0<FEDZW1I('-T=6QP96SA(@H*(SH@961I="YP:'`Z,3(X"FUS
M9VED(")!9&0@9FEL92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C(R"FUS9VED(")!9&0@=&\B"FUS9W-T<B`BP7)A\'ET
M:2#A(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#8*(RP@9G5Z
M>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE(&%D<F5S^"!K
M;GEG96SK(@H*(SH@8G)O=W-E+G!H<#HR."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(U"FUS9VED(")!9&1R97-S($)O;VL@3&ES=&EN9R(*;7-G<W1R(")!
M9')E<_@@<&5R_FG[<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*
M(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B4&EN92!A
M9')E<_@@:VYY9V5LZR(*"B,Z(&%D9"YP:'`Z,3`X"FUS9VED(")!9&1R97-S
M(&)O;VL@96YT<GDB"FUS9W-T<B`B061R97/X(&MN>6=E;.MS(.%R8?!A<R(*
M"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B061D<F5S<R!B;V]K('-U8V-E<W-F
M=6QL>2!P=7)G960N(@IM<V=S='(@(D%D<F5S^"!K;GEG96SK(&GP=F%L>71A
M('/K:VUI;F=A:2XB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV
M,@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K('1O(&1E;&5T92`B"FUS
M9W-T<B`B061R97/X(&MN>6=E;.MS(.%R8?!A<R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<P"B,L(&9U>GIY"FUS9VED
M(")!9&1R97-S(&)O;VMS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*
M;7-G<W1R(").97!A=GEK;R!I\'9A;'ET:2!A9')E<_@@:VYY9V5LZW,Z("5S
M(@H*(SH@<V5A<F-H+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI
M;F,Z,S<*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R(")$971A;&D@
M<&%I9?!K82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C8T"FUS
M9VED(")!;&EA<R(*;7-G<W1R(")0<F%V87)DZR(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(E9I<VO@(@H*(SH@;&EB+V%P:2YP
M:'`Z-34R"FUS9VED(")!;')E861Y($5X:7-T<R(*;7-G<W1R(")*874@96=Z
M:7-T=6]J82(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U
M('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R(")!<B!T:6MR86D@;F]R:71E
M(&GP=')I;G1I("5S/R(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP
M="YI;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O
M(&1E;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\B"FUS9W-T<B`B07(@=&EK
M<F%I(&YO<FET92!I\'1R:6YT:2!P87-I<FEN:W1U<R#A<F'P=7,_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!<V-E;F1I;F<B"FUS
M9W-T<B`B1&EDZVII;6\@='9A<FMA(@H*(SH@<V5A<F-H+G!H<#HX-2!T96UP
M;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S8*;7-G:60@(D)A<VEC(%-E87)C
M:"(*;7-G<W1R(")087!R87-T;VII('!A:67P:V$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34X"FUS9VED(")"96QO=R!S96%R8V@@9F]R;2(*;7-G
M<W1R(")086EE\&MO<R!F;W)M;W,@87!AZ&EO:F4B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C<W(&QI8B]$<FEV97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4')I
M<VEJ=6YG=&D@;F5P879Y:V\Z("@E<RD@)7,B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D=I
M;71A9&EE;FES(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*(RP@9G5Z>GD*
M;7-G:60@(D)R;W=S92(*;7-G<W1R(")07V5R_FG[<NMT:2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@0V%T
M96=O<GDB"FUS9W-T<B`B1&%R8F\@:V%T96=O<FEJ82(*"B,Z(&1A=&$N<&AP
M.C0Y"FUS9VED(")#4U8B"FUS9W-T<B`B0U-6(@H*(SH@;&EB+T]B:F5C="]'
M<F]U<"YP:'`Z-3<*;7-G:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L
M9BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A
M9&5R<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(E!?
M8?YY;>MT:2!V:7-U<R]N:65K;R(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!N86UE(@IM<V=S
M='(@(E!A<VER:6YK:71E(&%D<F5S^"!K;GEG96SF(@H*(SH@861D+G!H<#HT
M.`IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R(")087-I
M<FEN:VET92!A9')E<_@@:VYY9V5LYB(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(R,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N
M(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B4&%S:7)I;FMI=&4@861R97/X(&MN
M>6=E;.8B"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N
M:6YC.C$V-0IM<V=I9"`B0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@
M9&ES<&QA>2P@86YD(&EN('=H870@;W)D97(Z(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E
M('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E+B(*;7-G<W1R(")087-I<FEN
M:VET92!A9')E<_@@:VYY9V5LYB(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(R.`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('=H:6-H
M(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T
M<B`B4&%S:7)I;FMI=&4@<W1U;'!E;&GX(')O9'EM;R!T=F%R:^`@861R97/X
M('/@<F'P92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@
M(D-O;'5M;B!/<'1I;VYS(@IM<V=S='(@(E-T=6QP96QI^"!N=7-T871Y;6%I
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,S"FUS
M9VED(")#;VQU;6YS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(D-O;6UA('-E<&%R871E
M9"!V86QU97,B"FUS9W-T<B`B2V%B;&5L:6%I<R!A='-K:7)T;W,@<F5I:_!M
MZW,B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$S"FUS9VED(")#
M;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RDB"FUS
M9W-T<B`B2V%B;&5L:6%I<R!A='-K:7)T;W,@<F5I:_!MZW,@*$UI8W)O<V]F
M="!/=71L;V]K*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<V
M"FUS9VED(")#;VUP86YY(@IM<V=S='(@(DMO;7!A;FEJ82(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`IM<V=I9"`B0V]M<&%N>2!!9&1R
M97-S(@IM<V=S='(@(DMO;7!A;FEJ;W,@861R97-A<R(*"B,Z(&QI8B]A<&DN
M<&AP.C,Q."!L:6(O87!I+G!H<#HS-C,@;&EB+V%P:2YP:'`Z-#`W(&QI8B]A
M<&DN<&AP.C0Y,0HC.B!L:6(O87!I+G!H<#HV,#$@;&EB+V%P:2YP:'`Z-C@X
M(&QI8B]A<&DN<&AP.C<T,2!L:6(O87!I+G!H<#HX,3D*(SH@;&EB+V%P:2YP
M:'`Z,3`P-B!L:6(O87!I+G!H<#HQ,#DT"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")0<FES:6IU;F=T:2!N
M97!A=GEK;SH@)7,B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C4X"FUS9VED
M(")#;VYN96-T:6]N(&9A:6QU<F4B"FUS9W-T<B`B4')I<VEJ=6YG=&D@;F5P
M879Y:V\B"@HC.B!B<F]W<V4N<&AP.C$Y,2!B<F]W<V4N<&AP.C(S,@HC+"!F
M=7IZ>0IM<V=I9"`B0V]N=&%C="!A9&1E9"!T;R!L:7-T+B(*;7-G<W1R(")!
M9')E<V%S(&GP=')I;G1A<RXB"@HC.B!B<F]W<V4N<&AP.C8P"FUS9VED(")#
M;VYT86-T(')E;6]V960@9G)O;2!L:7-T+B(*;7-G<W1R(")!9')E<V%S(&GP
M=')I;G1A<RXB"@HC.B!B<F]W<V4N<&AP.C(V-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYT86-T<R!I;B!L:7-T.B`E<R(*;7-G<W1R(")!9')E<V%I('/@
M<F'P93H@)7,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$R
M"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&EJ=6]T:2(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C4S"B,L(&9U>GIY"FUS9VED(")#<F5A=&4B
M"FUS9W-T<B`B4W5K=7)T82(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N
M:6YC.C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@061D<F5S<R!";V]K(@IM
M<V=S='(@(D%S;65N:6[K(&%D<F5S^"!K;GEG96SK(@H*(SH@;&EB+TQI<W16
M:65W+G!H<#HS,34*;7-G:60@(D-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@
M:6XZ(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S,*;7-G
M:60@(D-R96%T960B"FUS9W-T<B`B4W5K=7)T82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO
M;CHB"FUS9W-T<B`B4W1A;F1A<G1I;NL@<OOP:6%V:6UO('1V87)K83HB"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHW-B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C(*(SH@;&EB+T]B:F5C="YP:'`Z,S(X(&QI8B]2
M96YD97)E<BYP:'`Z-#<@;&EB+U)E;F1E<F5R+G!H<#HU,`IM<V=I9"`B1&5L
M971E(@IM<V=S='(@(DGP=')I;G1I(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B4&%S:7)I;FMI=&4@861R97/X(&MN>6=E;.8B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T92!#;VYF:7)M
M871I;VXB"FUS9W-T<B`B5')Y;FEM;R!P871V:7)T:6YI;6%S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED(")$96QE=&4@8G5T=&]N(&)E
M:&%V:6]U<B(*;7-G<W1R(")4<GEN:6UO(&UY9W1U:V\@96QG97-Y<R(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B2?!T<FEN=&D@;F5P
M879Y:V\Z("@E<RD@)7,B"@HC.B!D96QE=&4N<&AP.C,X"FUS9VED(")$96QE
M=&EO;B!F86EL960B"FUS9W-T<B`B2?!T<FEN=&D@;F5P879Y:V\B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE
M;G0B"FUS9W-T<B`B1&5P87)T86UE;G1A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R(")-8?[K:FEM
M;R!T=F%R:V$B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*
M;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<V5A<F-H+FEN8SHQ,3@*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R
M(")+871A;&]G87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*(RP@
M9G5Z>GD*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B5F%I>F1A=FEM;R!N=7-T
M871Y;6%I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1I<W!L87D@3W!T:6]N
M<R(*;7-G<W1R(")686EZ9&%V:6UO(&YU<W1A='EM86DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3<V"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF
M:7)M(&1E;&5T:6YG(&5N=')I97,_(@IM<V=S='(@(D%R(&YO<FET92P@:V%D
M('!R:67P(&MI96MV:65NX"#A<F'P^"!T<GEN:6W@('!R8?!Y=/@@<&%T=FER
M:71I;6\_(@H*(SH@;&EB+T]B:F5C="YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED
M(")$;W=N;&]A9"(*;7-G<W1R(")!='-I<VGX<W1I(%9#87)D(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N
M=&%C=')O=RYI;F,Z,C4*;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@
M(D%T<VES:?AS=&D@=D-A<F0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L
M871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z,PHC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B
M"FUS9W-T<B`B4F5D86=U;W1I(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N
M:6YC.C(U('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@
M(E)E9&%G=6]T:2`G)7,G(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z.#$*(RP@9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G
M<W1R(")!9')E<_@@:VYY9V5LZW,@:?!KZVQI;6%S(@H*(SH@961I="YP:'`Z
M-S@@961I="YP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@96YT
M<GD@9F]R("5S(@IM<V=S='(@(E)E9&%G=6]T:2#A<F'PX"`E<R(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C4X"FUS9VED(")%;6%I;"(*;7-G
M<W1R(")%;"X@<&'P=&\@861R97-A<R(*"B,Z(&5D:70N<&AP.C$T-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"P@8G5T('-A
M=FEN9R!T:&4@=7!L;V%D960@9FEL92!F86EL960Z("5S(@IM<V=S='(@(B(*
M"B,Z(&5D:70N<&AP.C$T.2!E9&ET+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960N(@IM<V=S='(@(B5S(&%T;F%U
M:FEN=&%S+B(*"B,Z(&)R;W=S92YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D5N
M=')Y('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("(E<R!F86EL87,@
M<^MK;6EN9V%I(.%K96QT87,B"@HC.B!L:6(O87!I+G!H<#HT,3,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E87)C:&EN9R!T:&4@861D
M<F5S<R!B;V]K.B`E<R(*;7-G<W1R(").97!A=GEK;R!P87-I96MT:2!N=7)O
M9'ET;W,@861R97/X(&MN>6=E;.MS.B`E<RXB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHT
M,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(DGP:V5L=&DB"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C8*;7-G:60@(D5X<&]R="!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B061R97/X(&MN>6=E;.MS(&GP:^ML:6UA<R(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY
M('1H92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B2?!K96QT:2!T:6L@
M<&%S:7)I;FMT=7,@861R97-U<RXB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C(W"FUS9VED(")%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S
M(&)O;VL@8V]M<&QE=&5L>2XB"FUS9W-T<B`B2?!K96QT:2!V:7/@(&%D<F5S
M^"!K;GEG96SF+B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H<#HR,C@@9&%T
M82YP:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY,`HC.B!B<F]W
M<V4N<&AP.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K
M.B`E<R(*;7-G<W1R(").97!A=GEK;R!P87-I96MT:2!N=7)O9'ET;W,@861R
M97/X(&MN>6=E;.MS.B`E<RXB"@HC.B!B<F]W<V4N<&AP.C$S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@861D("5S('1O("5S.B`E<R(*;7-G
M<W1R(")0<FEDZW1I("5S('!R:64@)7,@;F5P879Y:V\Z("5S(@H*(SH@8G)O
M=W-E+G!H<#HR-S(*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@;&ES="(*;7-G
M<W1R(").97!A=GEK;R!P97+^:?MRZW1I('/@<F'P;R(*"B,Z(&)R;W=S92YP
M:'`Z,S$P"FUS9VED(")&86EL960@=&\@8G)O=W-E('1H92!D:7)E8W1O<GDB
M"FUS9W-T<B`B4&5R_FG[<F$@;F5P879Y:V\B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C,P.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@3F5W($1.
M(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R(").97!A=GEK;R!P86ME:7-T:2!V
M87)D;SH@*"5S*2`E<SH@)7,B"@HC.B!B<F]W<V4N<&AP.C$R,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D
M960Z("5S(@IM<V=S='(@(DYE<&%V>6MO(')A<W1I(&]B:F5K=&\@<')I9.MJ
M:6UU:3H@)7,B"@HC.B!S96%R8V@N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")&
M86EL960@=&\@<V5A<F-H('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3F5P
M879Y:V\@<&%S:65K=&D@;G5R;V1Y=&]S(&%D<F5S^"!K;GEG96SK<SH@)7,N
M(@H*(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,B"FUS9W-T<B`B4&%I9?!K
M82!N97!A=GEK;R!K871A;&]G93H@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-C<*;7-G:60@(D9A>"(*;7-G<W1R(")&86MS87,B"@HC
M.B!E9&ET+G!H<#HQ,C0@9&ES<&QA>2YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED
M(")&:6QE<R(*;7-G<W1R(")087)E:6=O<R(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O<V5A<F-H+FEN8SHW,`IM<V=I9"`B1FEN9"(*;7-G<W1R(")287-T:2(*
M"B,Z(&5D:70N<&AP.CDW(&5D:70N<&AP.C$X-PHC+"!F=7IZ>0IM<V=I9"`B
M1FEN:7-H(@IM<V=S='(@(E)A<W1I(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T($YA;64B"FUS9W-T<B`B5F%R9&%S
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`R"FUS9VED(")&
M<F5E8G5S>2!54DPB"FUS9W-T<B`B5?YI;71U;6\@:6YF;W)M86-I:F]S(%52
M3"(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHX,PIM<V=I9"`B
M1G)O;2(*;7-G<W1R("))\"(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C8P-`IM<V=I9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R(")';&]B
M86QI(&%D<F5S^"!K;GEG96SK(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N
M:6YC.C0S('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z-#0*;7-G
M:60@(D=R;W5P(@IM<V=S='(@(D=R=7#K(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(").
M86WX(&%D<F5S87,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY
M,PIM<V=I9"`B2&]M92!#:71Y(@IM<V=S='(@(DYA;?@@;6EE<W1A<R(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P.`IM<V=I9"`B2&]M92!#
M;W5N=')Y(@IM<V=S='(@(DYA;?@@=F%L<W1Y8NLB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T
M<B`B3F%M^"!T96PN(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3`S"FUS9VED(")(;VUE(%!O<W1A;"!#;V1E(@IM<V=S='(@(DYA;?@@<&'P
M=&\@:V]D87,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`IM
M<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R(").86WX(')A:F]N
M87,O<')O=FEN8VEJ82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C@X"B,L(&9U>GIY"FUS9VED(")(;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S
M='(@(DYA;?@@861R97-A<R(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C4P-@IM<V=I9"`B24U34"(*;7-G<W1R("))35-0(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0W"B,L(&9U>GIY"FUS9VED("))35-0($%D9')E<W,@
M0F]O:R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9')E<_@@<&5R_FG[<F$B
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9"(*;7-G<W1R
M(")!9')E<_@@:VYY9V5LZW,@X6OK;&EM87,L("5D+6%S(/YI;F=S;FES(@H*
M(SH@9&%T82YP:'`Z,S8Q"FUS9VED("));7!O<G0O17AP;W)T($%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`BP6ME;'1I+TGP:V5L=&D@861R97/X(&MN>6=E;&5S
M(@H*(SH@;&EB+V%P:2YP:'`Z-3DV(&QI8B]A<&DN<&AP.C8X,PIM<V=I9"`B
M26YV86QI9"!)1"(*;7-G<W1R(").971E:7-I;F=A<R!)1"(*"B,Z(&QI8B]A
M<&DN<&AP.C(S,"!L:6(O87!I+G!H<#HT,#(@;&EB+V%P:2YP:'`Z-#@V(&QI
M8B]A<&DN<&AP.C4Y,@HC.B!L:6(O87!I+G!H<#HV-SD@;&EB+V%P:2YP:'`Z
M-S,Q(&QI8B]A<&DN<&AP.C$P-S<*;7-G:60@(DEN=F%L:60@861D<F5S<R!B
M;V]K(@IM<V=S='(@(DYE=&5I<VEN9V$@861R97/X(&MN>6=E;.LB"@HC.B!L
M:6(O87!I+G!H<#HQ,#@Q(&QI8B]A<&DN<&AP.C$Q-30@;&EB+V%P:2YP:'`Z
M,3(P-PIM<V=I9"`B26YV86QI9"!E;6%I;"(*;7-G<W1R(").971E:7-I;F=A
M<R!E;"YP8?!T;R!A9')E<V%S(@H*(SH@;&EB+V%P:2YP:'`Z,3`X.0IM<V=I
M9"`B26YV86QI9"!E;G1R>2(*;7-G<W1R(").971E:7-I;F=A<R#A<F'P87,B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(V-@IM<V=I9"`B26YV86QI9"!K
M97D@<W!E8VEF:65D+B(*;7-G<W1R(").=7)O9'ET87,@;F5T96ES:6YG87,@
M<F%K=&%S+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.#4*;7-G:60@(DEN=F%L:60@
M;F%M92(*;7-G<W1R(").971E:7-I;F=A<R!V87)D87,B"@HC.B!L:6(O87!I
M+G!H<#HW,S4*;7-G:60@(DEN=F%L:60@;V)J96-T260B"FUS9W-T<B`B3F5T
M96ES:6YG87,@;V)J96MT;R!)1"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@=&AE
M($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E9"XB
M"FUS9W-T<B`B(@HB4F5I:V%L:6YG87,@3$1!4"!P86QA:6MY;6%S+"!T8>AI
M874@3$1!4"!M;V1U;&ES(&YE<F%S=&%S(&%R8F$@;F7A:W)A=71A<RXB"@HC
M.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS9VED("),87-T($UO9&EF:65D
M(@IM<V=S='(@(E!A<VMU=&ENX2!K87)TX"!R961A9W5O=&$B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PIM<V=I9"`B3&%S="!.86UE(@IM
M<V=S='(@(E!A=F%R9.LB"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H
M96%D97)S+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B3&ES="(*;7-G<W1R(").
M875J87,@<^!R8?!A<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN
M8SHW-PIM<V=I9"`B36%T8VAI;F<B"FUS9W-T<B`B071I=&EN:V$B"@HC.B!L
M:6(O87!I+G!H<#HR,#4*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F($-O;G1A8W1S(@IM<V=S='(@(DUA:W-I;6%L=7,@<'5S;&%P:?@@<VMA
M:>AI=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED(")-
M87AI;75M(&YU;6)E<B!O9B!P86=E<R(*;7-G<W1R(")-86MS:6UA;'5S('!U
M<VQA<&GX('-K86GH:75S(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z
M,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(DYA=6IA<R!S
MX')A\&%S(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,*;7-G:60@
M(DUI;FD@4V5A<F-H(@IM<V=S='(@(DUI;FD@<&%I9?!K82(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,S`R"FUS9VED(")-:7-S:6YG($1.(&EN($Q$05`@
M<V]U<F-E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DQ$05`@:V]N9FEG^W)A
M8VEJ;VIE(&[K<F$@1$X@<&%R86UE=')O+B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$V,@IM<V=I9"`B36]B:6QE(%!H;VYE(@IM<V=S='(@
M(DUO8FEL=7,@=&5L+B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S,R(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@(DUO
M9&EF>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4F5D86=U;W1I(&YE<&%V
M>6MO.B`H)7,I("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y,PIM<V=I9"`B36]R
M92!T:&%N(#$@96YT<GD@9F]U;F0B"FUS9W-T<B`B4F%S=&%S(&1A=6=I874@
M;F5I('9I96YA<R#A<F'P87,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C$Q"FUS9VED(")-;W9E(@IM<V=S='(@(E!E<FME;'1I(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0W"B,Z('1E;7!L
M871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@T"FUS9VED(")-
M;W9E(&QE9G0B"FUS9W-T<B`B4&5R:V5L=&D@:V%I<NMN(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V"FUS9VED(")-;W9E(')I
M9VAT(@IM<V=S='(@(E!E<FME;'1I(&1E\&ENZVXB"@HC.B!D871A+G!H<#HU
M,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$V"FUS9VED(")-=6QB97)R
M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B375L8F5R<GD@861R97/X(&MN>6=E
M;.LB"@HC.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL(&)U="!N
M;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T<B`B(@HB
M061R97/X(&MN>6=E;.MJ92!Y<F$@:V5L971A<R!A<VUE;O@@<W4@861R97-U
M(%LE<UTL(&)E="!N96D@=FEE;F\@=F%R9'4@6R5S72(*"B,Z(&-O;F9I9R]S
M;W5R8V5S+G!H<"YD:7-T.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR
M-#,*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R(")-
M86YO(&%D<F5S^"!K;GEG96SK(@H*(SH@861D<F5S<V)O;VMS+G!H<#HQ,C`*
M(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B36%N
M;R!A9')E<_@@:VYY9V5LZR(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N
M:6YC.C$P-R!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT,@IM<V=I9"`B
M3F%M92(*;7-G<W1R(")687)D87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@(E9A<F1O(&9O<FUA
M=&%S(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S$U"FUS9VED(").
M971C96YT97(@365M8F5R($1I<F5C=&]R>2(*;7-G<W1R(").971C96YT97(@
M;F%R:?@@:V%T86QO9V%S(@H*(SH@861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L
M:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*(SH@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,C<*;7-G:60@(DYE=R!#;VYT86-T(@IM<V=S='(@(DYA=6IA
M<R!A9')E<V%S(@H*(SH@961I="YP:'`Z.#@@961I="YP:'`Z.34@961I="YP
M:'`Z,C`R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#4*;7-G:60@(DYE
M>'0B"FUS9W-T<B`B4V5K86YT:7,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HR,3@*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(E-L87!Y=F%R
M9&ES(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y-2!L:6(O87!I+G!H<#HQ,C0T"B,L
M('!H<"UF;W)M870*;7-G:60@(DYO("5S(&5N=')Y(&9O=6YD(&9O<B`E<R(*
M;7-G<W1R("+!<F'P87,@)7,@;F5R87-T87,@)7,B"@HC.B!L:6(O87!I+G!H
M<#HQ,38S"FUS9VED(").;R!A9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R
M(")!9')E<_@@:VYY9V5L:?@@;NMR82XB"@HC.B!M:6YI<V5A<F-H+G!H<#HX
M,PIM<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B"FUS9W-T<B`B5&]K:?@@:V]N
M=&%K=/@@;NMR82(*"B,Z(&QI8B]A<&DN<&AP.C4Q,2!L:6(O87!I+G!H<#HW
M-C8*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R(")V
M0V%R9"!D=6]M96[X(&[K<F$N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`B3FEE:V\B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM<V=S
M='(@(E!A<W1A8F]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM
M<V=I9"`B3G5M8F5R(&]F(&ET96US('!E<B!P86=E(@IM<V=S='(@(D]B:F5K
M=/@@<VMA:>AI=7,@<'5S;&%P>6IE(@H*(SH@;&EB+V%P:2YP:'`Z-C$T(&QI
M8B]A<&DN<&AP.C<T-PIM<V=I9"`B3V)J96-T(&YO="!F;W5N9"(*;7-G<W1R
M(")/8FIE:W1A<R!N97)A<W1A<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@(D]F:7-A<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N
M8V4@>6]U('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O
M:R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@
M;F]T('=H870@>6]U('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@
M<V5L96-T:6]N("(*(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HW-S0*;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G
M<W1R(")+:71I(&YU<W1A='EM86DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'
M4"!V:67P87-I<R!R86MT87,B"@HC.B!L:6(O87!I+G!H<#HT.34@;&EB+V%P
M:2YP:'`Z-C`U(&QI8B]A<&DN<&AP.C8Y,B!L:6(O87!I+G!H<#HY,S0*(SH@
M;&EB+V%P:2YP:'`Z,3`Y.`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS
M9W-T<B`B3NMR82!T96ES:?@B"@HC.B!L:6(O1')I=F5R+G!H<#HU-#,*;7-G
M:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(D[K<F$@=&5I<VGX(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3D*(RP@9G5Z>GD*;7-G
M:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(D[K<F$@=&5I<VGX(@H*(SH@9&%T
M82YP:'`Z-3,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B
M4&EN92!!9&1R97-S($)O;VLB"FUS9W-T<B`B4&EN92!A9')E<_@@:VYY9V5L
MZR(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*(RP@
M9G5Z>GD*;7-G:60@(E!L96%S92!N86UE('1H92!N97<@8V]N=&%C="!L:7-T
M.B(*;7-G<W1R("+!=F5S:VET92!N875J;R!SX')A\&\@<&%V861I;FEMX#HB
M"@HC.B!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HQ.30*;7-G
M:60@(E!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H
M<"YD:7-T.C0Q-@IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B07-M96YI;NL@861R97/X(&MN>6=E;.LB"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")1=65R>2!F86EL960Z
M("@E<RD@)7,B"FUS9W-T<B`B5?YK;&%U<V$@;F5P879Y:V\Z("@E<RD@)7,B
M"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,3@*;7-G:60@
M(E%U:6-K(%-E87)C:"(*;7-G<W1R(")'<F5I=&]J:2!P86EE\&MA(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3$@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M.3D@;&EB+T1R:79E<B]L9&%P+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4VMA:71Y;6%S(&YE
M<&%V>6MO.B`H)7,I("5S(@H*(SH@;&EB+U)E;F1E<F5R+G!H<#HT.0IM<V=I
M9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S
M(&1I<W!L87EE9#HB"FUS9W-T<B`B4F]D;VUI(.%R8?!A:3HB"@HC.B!T96UP
M;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-@HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(&%D9')E<W,@8F]O:R(*;7-G<W1R(")087-I<FEN
M:VET92!A9')E<_@@:VYY9V5LYB(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(S.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M(")086YA:6MI;G1I('-T=6QP96SA(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS
M9W-T<B`B4&'P86QI;G1I(&GP(/!I;R!SX')A\&\B"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C(Q"B,L(&9U>GIY"FUS9VED("(B"B)297!L86-E
M(&5X:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I;7!O<G1E9"!O;F4_
M(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E;G1R:65S
M(&EN('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN/"]S=')O;F<^(@IM<V=S
M='(@(B(*(E!A:V5I<W1I('9I<W5S(.%R8?!U<R!A9')E<_@@:VYY9V5LZVIE
M(.$@X6ME;&EA;75S/R`\8CY$ZVUE<VEO.B!T86EP("(*(FGP=')I;G-I=&4@
M=FES=7,@X7)A\'5S(&1A8F%R=&ENZVIE(&%D<F5S^"!K;GEG96SK:F4N/"]B
M/B(*"B,Z(&QI8B]$<FEV97(N<&AP.C0S.`IM<V=I9"`B4F5Q=65S=&5D(&]B
M:F5C="!N;W0@9F]U;F0N(@IM<V=S='(@(E)E:6MA;&EN9V%S(&]B:F5K=&%S
M(&YE<F%S=&%S+B(*"B,Z(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.C$Q,PIM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T
M<B`B071S=&%T>71I(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I9FEC871E(@IM<V=S='(@
M(E,O34E-12!V:67P87-I<R!S97)T:69I:V%T87,B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C8Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")35$%2
M5%1,4R!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4VMA:71Y;6%S(&YE<&%V
M>6MO.B`H)7,I("5S(@H*(SH@961I="YP:'`Z.3D@861D+G!H<#HS-R!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,C0*;7-G:60@(E-A=F4B"FUS9W-T
M<B`B2?!S875G;W1I(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC
M.CDV('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3(*(SH@=&5M<&QA
M=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(Q(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C0Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@
M(E-E87)C:"(*;7-G<W1R("))9?!K;W1I(@H*(SH@;6EN:7-E87)C:"YP:'`Z
M-C,*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!297-U;'1S.B(*;7-G<W1R(")0
M86EE\&MO<R!R97IU;'1A=&%I(@H*(SH@;&EB+V%P:2YP:'`Z,3`Q,0IM<V=I
M9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R(")086EE\&MA(&YE<&%V>6MO(@H*
M(SH@;&EB+V%P:2YP:'`Z,3$P,R!L:6(O87!I+G!H<#HQ,3`Y(&QI8B]A<&DN
M<&AP.C$Q,3@@;&EB+V%P:2YP:'`Z,3$S,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R(")086EE\&MA(&YE<&%V>6MO
M.B`E<R(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,@IM
M<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S='(@(DEE\&MO;6$N+BXB"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B4&%S
M:7)I;FMI=&4@861R97/X(&MN>6=E;.8@:?!KZVQI;75I.B(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.CDP"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@86X@861D<F5S<R!B;V]K('1O(&5D:70B"FUS9W-T<B`B4&%S:7)I;FMI
M=&4@861R97-U(&MN>6=E;.8@X6OK;&EM=6DZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHS,@IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O
M;VL@=&\@97AP;W)T(&9R;VTZ(@IM<V=S='(@(E!A<VER:6YK:71E(&%D<F5S
M^"!K;GEG96SF(&GP:^ML:6UU:3HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C(V"FUS9VED(")396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I
M;7!O<G0@=&\Z(@IM<V=S='(@(E!A<VER:6YK:71E(&%D<F5S=2!K;GEG96SF
M(.%KZVQI;75I.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,S4*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U
M<F-E(&9I;&4Z(@IM<V=S='(@(E!A<VER:6YK:71E(&GP:V5L:6%M;R!F86EL
M;R!F;W)M873@.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*
M;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B4&%S
M:7)I;FMI=&4@:?!KZVQI;6\@9F]R;6%TX#HB"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C0S"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP
M;W)T.B(*;7-G<W1R(")087-I<FEN:VET92#A:V5L:6%MX"!F86ELX#HB"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q"FUS9VED(")396QE8W0@
M=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E!A<VER
M:6YK:71E(&GP:V5L:6%M;R!F86EL;R!F;W)M873@.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S
M960@=&\@9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`B4&%S:7)I;FMI=&4@=F%R
M9/@@=F%I>F1A=FEMX#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!V:65W('1O(&1I<W!L87D@8GD@9&5F
M875L="P@<V]R="!O<'1I;VYS+"!A;F0@<&%G:6YG(&]P=&EO;G,N(@IM<V=S
M='(@(E-T86YD87)T:6[A;R!V86EZ9&%V:6UO('!A<VER:6YK:6UA<RXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-E;&5C="!W:&EC
M:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS
M9W-T<B`B3&%U:_@L(&MU<FEE(&)U<R!R;V1O;6D@861R97/X('/@<F'P92P@
M<&%S:7)I;FMI;6%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM
M<V=I9"`B4V5L96-T('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*
M;7-G<W1R(")687)D^"!V86EZ9&%V:6UO('!A<VER:6YK:6UA<RXB"@HC.B!A
M9&0N<&AP.C4T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")396QE8W1E
M9"!A9&1R97-S(&)O;VL@7"(E<UPB+B(*;7-G<W1R(")087-I<FEN:W1A(&%D
M<F5S^"!K;GEG96SK("<E<R<N(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I
M<W0Z,3<S"FUS9VED(")3:&%R960@1&ER96-T;W)Y(@IM<V=S='(@(E9I9?!A
M<R!K871A;&]G87,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W("5S(@IM<V=S
M='(@(E)O9'ET:2(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M-#$*;7-G:60@(E-H;W<@06QL(@IM<V=S='(@(E)O9'ET:2!V:7-U<R(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@(E-H;W<@
M0V]N=&%C=',B"FUS9W-T<B`B4F]D>71I(&%D<F5S=7,B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")3:&]W($QI<W1S(@IM
M<V=S='(@(E)O9'ET:2!SX')A\'5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C
M;VQU;6Y?:&5A9&5R<RYI;F,Z,C$*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU
M;6Y?:&5A9&5R<RYI;F,Z,S0*;7-G:60@(E-O<G0@1&ER96-T:6]N(@IM<V=S
M='(@(E+[\&EA=FEM;R!T=F%R:V$B"@HC.B!L:6(O87!I+G!H<#HQ.3@*;7-G
M:60@(E-O=7)C97,B"FUS9W-T<B`BT&%L=&EN:6%I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U-PIM<V=I9"`B4W!E8VEF>2!W:&5R92!Y;W4@=V%N
M="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N(@IM<V=S='(@
M(DYU<F]D>6MI=&4L(&MU<B!N;W)I=&4@;6%T>71I(&GP<&SK<W1I;NMS('!A
M:67P:V]S(')E>G5L=&%T=7,N(@H*(SH@8G)O=W-E+G!H<#HQ-#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S(@IM
M<V=S='(@(B5S('/K:VUI;F=A:2!P<FEDZW1A<R#A("5S(@H*(SH@8G)O=W-E
M+G!H<#HR,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R
M("(E<R!SZVMM:6YG86D@<')I9.MT87,@X2`E<R(*"B,Z(&1A=&$N<&AP.C4P
M"FUS9VED(")44U8B"FUS9W-T<B`B5%-6(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$T"FUS
M9VED(")486(@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")486(@871S:VER
M=&]S(')E:6OP;>MS(@H*(SH@=FEE=RYP:'`Z,34*;7-G:60@(E1H92!61E,@
M8F%C:V5N9"!N965D<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A
M8VAM96YT('5P;&]A9',N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C$P-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S
M(&)O;VL@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(").97!A=GEK
M;R!I\'9A;'ET:2!A9')E<_@@:VYY9V5LZW,Z("5S(@H*(SH@861D<F5S<V)O
M;VMS+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D
M9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R(")!9')E<_@@:VYY9V5LZR!I\'9A;'ET82!SZVMM:6YG86DN(@H*
M(SH@861D<F5S<V)O;VMS+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(')E;6]V960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R(")!9')E<_@@:VYY9V5LZR!I\'9A;'ET82!S
MZVMM:6YG86DN(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")!9')E<_@@:VYY9V5L
MZR!I\'9A;'ET82!SZVMM:6YG86DN(@H*(SH@9&%T82YP:'`Z,S`S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E
M('!U<F=E9#H@)7,B"FUS9W-T<B`B3F5P879Y:V\@:?!V86QY=&D@861R97/X
M(&MN>6=E;.MS.B`E<R(*"B,Z(&5D:70N<&AP.C0W('9C87)D+G!H<#HR,B!D
M:7-P;&%Y+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A8W0@
M>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3G5R;V1Y
M=&%S(&MO;G1A:W1A<R!N965G>FES='5O:F$N(@H*(SH@961I="YP:'`Z,3$V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92!<(B5S7"(@
M:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N(@IM<V=S='(@(B5S(&9A
M:6QA<R!SZVMM:6YG86D@X6ME;'1A<R(*"B,Z(&1A=&$N<&AP.C(X-`IM<V=I
M9"`B5&AE(&EM<&]R="!C86X@8F4@9FEN:7-H960@9&5S<&ET92!T:&4@=V%R
M;FEN9W,N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,S$*;7-G:60@(E1H
M97)E(&%R92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@
M(D%D<F5S^"!K;GEG96QI^"!NZW)A+B(*"B,Z(&%D9"YP:'`Z,CD*;7-G:60@
M(B(*(E1H97)E(&%R92!N;R!W<FET96%B;&4@861D<F5S<R!B;V]K<RX@3F]N
M92!O9B!T:&4@879A:6QA8FQE(&%D9')E<W,@8F]O:W,@(@HB87)E(&-O;F9I
M9W5R960@=&\@86QL;W<@>6]U('1O(&%D9"!N97<@96YT<FEE<R!T;R!T:&5M
M+B!)9B!Y;W4@8F5L:65V92!T:&ES("(*(FES(&%N(&5R<F]R+"!P;&5A<V4@
M8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"B).ZW)A(&YE:2!V:65N;W,@<&%R=6_P=&]S(&%D<F5S^"!K;GEG96SK<RP@
M;&5I9/YI86[H:6]S('!R:63K=&D@;F%U:N`@X7)A\.`N("(*(DIE:6=U(&UA
M;F]T92P@:F]G('1A:2!N92!*^W/X(&ML86ED82P@<')A\&]M92!P<F%N9?!T
M:2!A9&UI;FES=')A=&]R:75I+B`B"@HC.B!A9&0N<&AP.C$R,0IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A8W0N
M($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B`B"B)F;W(@9G5R
M=&AE<B!H96QP+B(*;7-G<W1R(")+;&%I9&$@<')I9&5D86YT(&MO;G1A:W3@
M+B!3=7-I96MI=&4@<W4@<VES=&5M;W,@861M:6YI<W1R871O<FEU;6DN(@H*
M(SH@8G)O=W-E+G!H<#HQ.#D@8G)O=W-E+G!H<#HR,S`*(RP@9G5Z>GD*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AI<R!O8FIE8W0N(@IM
M<V=S='(@(DML86ED82!T<FEN86YT(&]B:F5K=.`N(@H*(SH@8G)O=W-E+G!H
M<#HR,S@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!A(&YE
M=R!L:7-T+B(*;7-G<W1R(")+;&%I9&$@:W5R:6%N="!N875JX"!SX')A\.`N
M(@H*(SH@861D<F5S<V)O;VMS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D
M<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")+;&%I9&$@<F5D86=U;VIA;G0@\.$@
MX7)A\.`Z("5S(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<(B5S
M7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2VQA
M:61A('1R:6YA;G0@)7,@:?`@<&%S:7)I;FMT;W,@861R97/X(&MN>6=E;.MS
M+B(*"B,Z(&1E;&5T92YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B"FUS
M9W-T<B`B2VQA:61A('1R:6YA;G0@861R97/@.B`E<R(*"B,Z(&)R;W=S92YP
M:'`Z-S(*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES
M(&]B:F5C="XB"FUS9W-T<B`B2VQA:61A('1R:6YA;G0@;V)J96MTX"XB"@HC
M.B!B<F]W<V4N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AE(&QI<W0B"FUS9W-T<B`B2VQA:61A(')O
M9&%N="!N=7)O9'ETX"!SX')A\.`B"@HC.B!D871A+G!H<#HS,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@9&%T83H@)7,B"FUS9W-T<B`B2VQA:61A(.%K96QI86YT(&1U;VUE;FES
M.B`E<R(*"B,Z(&QI8B]A<&DN<&AP.C4P-R!L:6(O87!I+G!H<#HW-C$*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R(")+;&%I9&$@X6ME;&EA;G0@:4-A;&5N9&%R(&1U
M;VUE;FES+B(*"B,Z(&)R;W=S92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!A(&-O;G1A8W0@9G)O;2!T:&4@
M;&ES="XB"FUS9W-T<B`B2VQA:61A(&MU<FEA;G0@;F%U:N`@<^!R8?#@+B(*
M"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-34@861D<F5S<V)O;VMS+G!H<#HV,"!A
M9&1R97-S8F]O:W,N<&AP.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@=&AI<R!A9&1R97-S(&)O
M;VLZ("5S(@IM<V=S='(@(DML86ED82!T<FEN86YT(&]B:F5K=.`N(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HX,2!A9&1R97-S8F]O:W,N<&AP.C@W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(DML86ED82!R
M961A9W5O:F%N="#PX2#A<F'PX#H@)7,B"@HC.B!E9&ET+G!H<#HQ-3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H:7,@96YT<GDZ("5S(@IM<V=S='(@(DML86ED82!R961A9W5O:F%N="#P
MX2#A<F'PX#H@)7,B"@HC.B!D871A+G!H<#HQ-SD*;7-G:60@(E1H97)E('=E
M<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="XB"FUS9W-T<B`B061R97/X(&GP
M:^ML:6UU:2!NZW)A+B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O
M:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R97-S(&)O;VMS('=I
M;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#,*;7-G:60@(E1H97-E
M(&-O;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@
M(B(*"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")&86EL;R!F;W)M871A<R!N97!A
M;&%I:V]M87,N(@H*(SH@;&EB+V%P:2YP:'`Z,3$R,B!L:6(O87!I+G!H<#HQ
M,3,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@
M:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("+0
M:7,@87-M=6\@:F%U('ER82`E<R!J^W/X(&%D<F5S^"!K;GEG96SK:F4N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-PIM<V=I9"`B(@HB5&AI<R!W
M:6QL(&)E('1H92!D969A=6QT(&%D9')E<W,@8F]O:R!W:&5N(&%D9&EN9R!O
M<B!I;7!O<G1I;F<@8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C<P"FUS9VED(")4:71L92(*;7-G<W1R(")0
M87)E:6=O<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-#,U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@;F5W('-H87)E+B`@36ES<VEN9R!S
M;W5R8V4@='EP92XB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z.3<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+B(*;7-G<W1R(").9>%M86YO;6$@<&%K<F%U=&D@)7,@
M87!R8?!Y;6\N(@H*(SH@961I="YP:'`Z.#@@961I="YP:'`Z.3$@961I="YP
M:'`Z.30@961I="YP:'`Z.3D@961I="YP:'`Z,3DV"FUS9VED(")5;F1O($-H
M86YG97,B"FUS9W-T<B`B073P875K=&D@<&%K96ET:6UU<R(*"B,Z(&QI8B]A
M<&DN<&AP.C4T,"!L:6(O87!I+G!H<#HV-#,@;&EB+V%P:2YP:'`Z-S<Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT
M+51Y<&4Z("5S(@IM<V=S='(@(DYE_FEN;VUA<R!D=6]M96[X('1I<&%S+B(*
M"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,W-@IM<V=I9"`B5F5R:7-I
M9VX@1&ER96-T;W)Y(@IM<V=S='(@(E9E<FES:6=N(&MA=&%L;V=A<R(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E
M+V-O;G1A8W1R;W<N:6YC.C(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W(%PB)7-<(B(*;7-G<W1R("+>:?MRZW1I("<E<R<B"@HC.B!M:6YI
M<V5A<F-H+G!H<#HW.`IM<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(E!E
M<OYI^W+K=&D@:V]N=&%K=.`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(T"FUS9VED(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS9W-T
M<B`B4W1A;F1A<G1I;FES('9A:7ID879I;6%S.B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T
M<B`B5U=7('!U<VQA<&ES(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3$S"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B1&%R8F\@861R
M97-A<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R-`IM<V=I
M9"`B5V]R:R!#:71Y(@IM<V=S='(@(D1A<F)O(&UI97-T87,B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,SD*;7-G:60@(E=O<FL@0V]U;G1R
M>2(*;7-G<W1R(")$87)B;R!V86QS='EBZR(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$U-@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")$
M87)B;R!T96PN(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,T
M"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S='(@(D1A<F)O('!A\'1O
M(&MO9&%S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(Y"FUS
M9VED(")7;W)K(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(D1A<F)O(')A:F]N
M87,O<')O=FEN8VEJ82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=')E970@061D<F5S<R(*;7-G
M<W1R(")$87)B;R!A9')E<V%S(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP
M:'`Z.3,@8G)O=W-E+G!H<#HR,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@8V]N=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!E9&ET
M+G!H<#HV.2!D:7-P;&%Y+G!H<#HU."!V:65W+G!H<#HS-@IM<V=I9"`B66]U
M(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N
M(@IM<V=S='(@(DYE='5R:71E('1E:7-I^"!P97+^:?MRZW1I(/#A(&MO;G1A
M:W3@+B(*"B,Z('9C87)D+G!H<#HT,`IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B3F5T
M=7)I=&4@=&5I<VGX('!E<OYI^W+K=&D@\.$@;V)J96MTX"XB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C4U"FUS9VED(")9;W4@;75S
M="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K+B(*;7-G<W1R(")6:7/X
M('!I<FUA(')E:6MI82!N=7)O9'ET:2!R96EK:6%MX"!A9')E<_@@:VYY9V5L
MYBXB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S"FUS
M9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB"FUS9W-T<B`B
M4&ER;6EA=7-I82!R96EK:6$@;G5R;V1Y=&D@<F5I:VEA;>`@<^!R8?#@+B(*
M"B,Z(&5D:70N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE
M8W0@870@;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N(@IM<V=S='(@(DGP('!R
M863^:?@@<&'^>6WK:VET92!B96YT('9I96[@(.%R8?#@+B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S
M92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@
M;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R("))\"!P<F%D_FGX('!A_GEMZVMI
M=&4@8F5N="!V:65NX"#A<F'PX"XB"@HC.B!E9&ET+G!H<#HW,PIM<V=I9"`B
M66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T
M+B(*;7-G<W1R(")*^W,@='5R:71E('1I:R!P97+^:?MRZVII;6\@=&5I<V5S
M(.$@\.$@:V]N=&%K=.`N(@H*(SH@8G)O=W-E+G!H<#HR.#4*;7-G:60@(EEO
M=7(@9&5F875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHV('1E;7!L
M871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@(EMN;R!V86QU
M95TB"FUS9W-T<B`B6V[K<F$@<F5I:_!MZW-=(@H*(SH@;&EB+U1U<F)A+G!H
M<#HT.#0*;7-G:60@(E]"<F]W<V4B"FUS9W-T<B`B4%]E<OYI^W+K=&DB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"B,L(&9U>GIY"FUS
M9VED(")?0V]N=&%C=',B"FUS9W-T<B`B7U)O9'ET:2!A9')E<W5S(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED(")?1&5L971E
M(@IM<V=S='(@(E])\'1R:6YT:2(*"B,Z(&QI8B]4=7)B82YP:'`Z-#DS"FUS
M9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R(")?P6ME;'1I+TGP:V5L=&DB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY
M"FUS9VED(")?3&ES=',B"FUS9W-T<B`B4F]D>71I(%]SX')A\'5S(@H*(SH@
M;&EB+U1U<F)A+G!H<#HT.#$*(RP@9G5Z>GD*;7-G:60@(E]->2!!9&1R97-S
M($)O;VMS(@IM<V=S='(@(DUA;F\@861R97/X(&MN>6=E;.LB"@HC.B!L:6(O
M5'5R8F$N<&AP.C0X-PHC+"!F=7IZ>0IM<V=I9"`B7TYE=R!#;VYT86-T(@IM
M<V=S='(@(DYA=6IA<R!A9')E<V%S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM
M<V=S='(@(DGP7W1R:6YT:2!I\"#P:6\@<^!R8?!O(@H*(SH@;&EB+U1U<F)A
M+G!H<#HT.#D*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B267P7VMO=&DB"@HC
M.B!V8V%R9"YP:'`Z-#8*;7-G:60@(F-O;G1A8W0N=F-F(@IM<V=S='(@(F%D
M<F5S87,N=F-F(@H*(SH@9&%T82YP:'`Z,3DY(&1A=&$N<&AP.C(P-"!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(F-O;G1A8W1S+F-S=B(*
M;7-G<W1R(")A9')E<V%I+F-S=B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B
M8V]N=&%C=',N='-V(@IM<V=S='(@(F%D<F5S86DN='-V(@H*(SH@9&%T82YP
M:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")C;VYT86-T<RYV8V8B"FUS9W-T<B`B
M861R97-A<RYV8V8B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC
M.C,T"B,L(&9U>GIY"FUS9VED(")N;VYE(@IM<V=S='(@(DYI96MO(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR-`HC+"!F=7IZ>0IM<V=I
M9"`B=&\@82!#;VYT86-T($QI<W0B"FUS9W-T<B`B4F]D>71I(&%D<F5S=7,B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$T"B,L(&9U>GIY
M"FUS9VED(")T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VLB"FUS9W-T<B`B
MX2!P87-I<FEN:W3@(&%D<F5S^"!K;GEG96SF(@H*(SH@9&%T82YP:'`Z-3$@
M=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-2!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1U<F)A+W!O+V1E7T1%+G!O````````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#4Q-3$`,3`T,3<S-C(W-38`,#$W-#8R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````",@
M5'5R8F$@1V5R;6%N(%1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P
M,2TR,#`U($IA;B!38VAN96ED97(N"B,@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SXL(#(P,#$M,C`P-2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@,BXQ+6-V<UQN(@HB4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`V+3`S+3`V(#$R.C0W*S`Q,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,3(M,C@@,30Z,C,K,#$P,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@1V5R;6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*
M(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@."UB:71<;B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P
M="YI;F,Z-#`*;7-G:60@(B!!9&0@86X@24U34"!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B24U34"U!9')E<W-B=6-H(&AI;GIU9OQG96XB"@HC.B!T96UP;&%T
M97,O<')E9G,O:6US<%]O<'0N:6YC.C(Y"FUS9VED("(@1&5L971E($E-4U`@
M061D<F5S<R!";V]K(@IM<V=S='(@(DE-4U`M061R97-S8G5C:"!L]G-C:&5N
M(@H*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I;7!O<G1E9"XB"FUS9W-T
M<B`B7"(E<UPB(&5X:7-T:65R="!B97)E:71S('5N9"!W=7)D92!N:6-H="!I
M;7!O<G1I97)T+B(*"B,Z(&)R;W=S92YP:'`Z,30P"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET(&ES(&$@
M;&ES="XB"FUS9W-T<B`B7"(E<UPB('=U<F1E(&YI8VAT(&MO<&EE<G0L(&1A
M(&5S('-I8V@@=6T@96EN92!,:7-T92!H86YD96QT+B(*"B,Z(&)R;W=S92YP
M:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO
M=F5D(&)E8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R(")<(B5S7"(@=W5R
M9&4@;FEC:'0@=F5R<V-H;V)E;BP@9&$@97,@<VEC:"!U;2!E:6YE($QI<W1E
M(&AA;F1E;'0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I
M9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@*&EE+B!*;VAN($1O92DB"FUS
M9W-T<B`B7")6;W)N86UE($YA8VAN86UE7"(@*'HN0BX@36%X($UU<W1E<FUA
M;FXI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),
M87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@
M(EPB3F%C:&YA;64L(%9O<FYA;65<(B`H>BY"+B!-=7-T97)M86YN+"!-87@I
M(@H*(SH@861D+G!H<#HQ,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@861D
M960N(@IM<V=S='(@(B5S(&AI;GIU9V5F_&=T+B(*"B,Z(&1A=&$N<&AP.C,T
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I
M;7!O<G1E9"(*;7-G<W1R(")$:64@)7,M1&%T96D@=W5R9&4@97)F;VQG<F5I
M8V@@:6UP;W)T:65R="(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S
M='(@(B5S(&)I<R`E<R!V;VX@)7,B"@HC.B!L:6(O5'5R8F$N<&AP.C0U.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R
M("(E<W,@061R97-S8G5C:"(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H
M<#HT,@IM<V=I9"`B02!B<F]W<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I
M<R!R97%U:7)E9"(*;7-G<W1R(")%:6X@0G)O=W-E<BP@9&5R($E&<F%M97,@
M=6YT97)S=/QT>G0L('=I<F0@8F5N]G1I9W0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,38P"FUS9VED(")!8F]V92!S96%R8V@@9F]R;2(*;7-G<W1R
M("+<8F5R(&1E;2!3=6-H9F]R;75L87(B"@HC.B!V:65W+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('1O("5S(@IM<V=S='(@
M(EIU9W)I9F8@875F("5S('9E<G=E:6=E<G0B"@HC.B!A9&0N<&AP.C4V('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"(*;7-G
M<W1R(")(:6YZ=6;\9V5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B
M;V]K<V5L96-T+FEN8SHQ-S0*;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B061R97-S8G5C:"!H:6YZ=6;\9V5N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0X"FUS9VED(")!9&0@86YD($1E;&5T92!)35-0(&%D9')E
M<W,@8F]O:W,B"FUS9W-T<B`B24U34"U!9')E<W-B_&-H97(@;/9S8VAE;B!U
M;F0@:&EN>G5F_&=E;B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE
M8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")3<&%L=&4@
M:&EN>G5F_&=E;B(*"B,Z(&5D:70N<&AP.C$S-0IM<V=I9"`B061D(&9I;&4B
M"FUS9W-T<B`B1&%T96D@:&EN>G5F_&=E;B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"!T;R(*;7-G<W1R(")(:6YZ
M=6;\9V5N('IU(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HU-PIM<V=I9"`B
M061D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DAI
M;GIU9OQG96X@=F]N($MO;G1A:W1E;B!N:6-H="!U;G1E<G-T_'1Z="XB"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@IM<V=I9"`B061D<F5S
M<R!";V]K(@IM<V=S='(@(D%D<F5S<V)U8V@B"@HC.B!B<F]W<V4N<&AP.C(X
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*;7-G:60@(D%D9')E<W,@0F]O
M:R!,:7-T:6YG(@IM<V=S='(@(D%D<F5S<V)U8VAL:7-T92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B061D<F5S<R!";V]K<R(*;7-G
M<W1R(")!9')E<W-B_&-H97(B"@HC.B!A9&0N<&AP.C$P.`IM<V=I9"`B061D
M<F5S<R!B;V]K(&5N=')Y(@IM<V=S='(@(D%D<F5S<V)U8VAE:6YT<F%G(@H*
M(SH@9&%T82YP:'`Z,S`U"FUS9VED(")!9&1R97-S(&)O;VL@<W5C8V5S<V9U
M;&QY('!U<F=E9"XB"FUS9W-T<B`B061R97-S8G5C:"!W=7)D92!E<F9O;&=R
M96EC:"!G96QE97)T+B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C8R"FUS9VED(")!9&1R97-S(&)O;VL@=&\@9&5L971E("(*;7-G<W1R("):
M=2!L]G-C:&5N9&5S($%D<F5S<V)U8V@B"@HC.B!T96UP;&%T97,O<')E9G,O
M861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`IM<V=I9"`B061D<F5S<R!B;V]K
M<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B061R97-S
M8OQC:&5R+"!D:64@;FEC:'0@86YG97IE:6=T('=E<F1E;CHB"@HC.B!S96%R
M8V@N<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS.`IM<V=I
M9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(D5R=V5I=&5R=&4@4W5C:&4B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HV-`IM<V=I9"`B06QI
M87,B"FUS9W-T<B`B4W!I='IN86UE(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F
M;V]T97)!;'!H82YI;F,Z-R!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA
M+FEN8SHQ,`HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0X"FUS
M9VED(")!;&PB"FUS9W-T<B`B06QL92(*"B,Z(&QI8B]A<&DN<&AP.C4U,PIM
M<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B17AI<W1I97)T(&)E<F5I
M=',B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT
M('1O(&1E;&5T92`E<S\B"FUS9W-T<B`B4VEN9"!3:64@<VEC:&5R+"!D87-S
M(%-I92`E<R!L]G-C:&5N(&WV8VAT96X_(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]J879A<V-R:7!T+FEN8SHV-PIM<V=I9"`B07)E('EO=2!S=7)E('1H870@
M>6]U('=A;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/R(*;7-G
M<W1R(")3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I92!A=7-G97?D:&QT
M96X@16EN='+D9V4@;/9S8VAE;B!M]F-H=&5N/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-@IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(D%U9G-T
M96EG96YD(@H*(SH@<V5A<F-H+G!H<#HX-2!T96UP;&%T97,O8G)O=W-E+W-E
M87)C:"YI;F,Z,S<*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R(")%:6YF
M86-H92!3=6-H92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3D*;7-G
M:60@(D)E;&]W('-E87)C:"!F;W)M(@IM<V=S='(@(E5N=&5R(&1E;2!3=6-H
M9F]R;75L87(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL
M960Z("@E<RD@)7,B"FUS9W-T<B`B5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E
M;CH@*"5S*2`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W
M.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B1V5B=7)T<W1A9R(*"B,Z('1E
M;7!L871E<R]M96YU+FEN8SHW"FUS9VED(")"<F]W<V4B"FUS9W-T<B`B3&ES
M=&4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*;7-G:60@
M(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(D=E<V-HY&9T<VMA=&5G;W)I
M92(*"B,Z(&1A=&$N<&AP.C0Y"FUS9VED(")#4U8B"FUS9W-T<B`B0U-6(@H*
M(SH@;&EB+T]B:F5C="]'<F]U<"YP:'`Z-3<*;7-G:60@(D-A;B=T(&%D9"!A
M(&=R;W5P('1O(&ET<V5L9BXB"FUS9W-T<B`B16EN92!'<G5P<&4@:V%N;B!N
M:6-H="!Z=2!S:6-H('-E;&)S="!H:6YZ=6=E9OQG="!W97)D96XN(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I9"`B
M0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(E]!;&QE+TME:6YE(&%U<W?D:&QE
M;B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C0T"FUS9VED(")#
M:&]O<V4@82!N86UE(@IM<V=S='(@(E?D:&QE;B!3:64@96EN96X@3F%M96XB
M"@HC.B!A9&0N<&AP.C0X"FUS9VED(")#:&]O<V4@86X@861D<F5S<R!B;V]K
M(@IM<V=S='(@(E?D:&QE;B!3:64@96EN($%D<F5S<V)U8V@B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C$*;7-G:60@(D-H;V]S
M92!A;B!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(E?D:&QE;B!3:64@96EN($%D
M<F5S<V)U8V@Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L
M96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS
M('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R("(B"B)7
MY&AL96X@4VEE(&%U<RP@=V5L8VAE($%D<F5S<V+\8VAE<B!I;B!W96QC:&5R
M(%)E:6AE;F9O;&=E(&%N9V5Z96EG="!W97)D96X@(@HB<V]L;&5N.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B0VAO;W-E('=H:6-H
M(&%D9')E<W,@8F]O:W,@=&\@=7-E+B(*;7-G<W1R(")7Y&AL96X@4VEE(&1I
M92!Z=2!B96YU='IE;F1E;B!!9')E<W-B_&-H97(@875S+B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R.`IM<V=I9"`B0VAO;W-E
M('=H:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CHB
M"FUS9W-T<B`B(@HB5^1H;&5N(%-I92!A=7,L('=E;&-H92!3<&%L=&5N(&EN
M('=E;&-H97(@4F5I:&5N9F]L9V4@86YG97IE:6=T('=E<F1E;B`B"B)S;VQL
M96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")#;VQU
M;6X@3W!T:6]N<R(*;7-G<W1R(")!9')E<W-S<&%L=&5N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,S"FUS9VED(")#;VQU;6YS
M('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R(")3<&%L=&5N
M+"!D:64@;FEC:'0@86YG97IE:6=T('=E<F1E;CHB"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$S('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,3(*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B2V]M
M;6%G971R96YN=&4@5V5R=&4B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R;W-O
M9G0@3W5T;&]O:RDB"FUS9W-T<B`B2V]M;6%G971R96YN=&4@5V5R=&4@*$UI
M8W)O<V]F="!/=71L;V]K*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C<V"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D9I<FUA(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"FUS9VED(")#;VUP86YY($%D
M9')E<W,B"FUS9W-T<B`B1FER;65N861R97-S92(*"B,Z(&QI8B]A<&DN<&AP
M.C,R,"!L:6(O87!I+G!H<#HS-C4@;&EB+V%P:2YP:'`Z-#`Y(&QI8B]A<&DN
M<&AP.C0Y,@HC.B!L:6(O87!I+G!H<#HV,3@@;&EB+V%P:2YP:'`Z-S`U(&QI
M8B]A<&DN<&AP.C<U."!L:6(O87!I+G!H<#HX,SD*(SH@;&EB+V%P:2YP:'`Z
M,3`S-B!L:6(O87!I+G!H<#HQ,3(T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")697)B:6YD=6YG(&9E:&QG
M97-C:&QA9V5N.B`E<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-3@*;7-G
M:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R(")697)B:6YD=6YG(&9E
M:&QG97-C:&QA9V5N(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,@
M;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C(V"FUS9VED(")#;VYT86-T(%-E
M87)C:"(*;7-G<W1R(")+;VYT86MT<W5C:&4B"@HC.B!B<F]W<V4N<&AP.C(Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT86-T<R!I;B!L:7-T.B`E<R(*
M;7-G<W1R(")+;VYT86MT92!I;B!,:7-T93H@)7,B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C$X"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO
M<&EE<F5N(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3,*;7-G
M:60@(D-R96%T92(*;7-G<W1R(")%<G-T96QL96XB"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHT,`IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O
M:R(*;7-G<W1R(")!9')E<W-B=6-H($5R<W1E;&QE;B(*"B,Z(&QI8B],:7-T
M5FEE=RYP:'`Z,S0X"FUS9VED(")#<F5A=&4@82!N97<@0V]N=&%C="!,:7-T
M(&EN.B(*;7-G<W1R(").975E($MO;G1A:W1L:7-T92!A;FQE9V5N(&EN.B(*
M"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S,*;7-G:60@(D-R96%T960B"FUS
M9W-T<B`B17)S=&5L;'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*
M;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(E-O
M<G1I97)R:6-H='5N9SHB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHW-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*(SH@;&EB+T]B
M:F5C="YP:'`Z,S(X(&QI8B]296YD97)E<BYP:'`Z-#<@;&EB+U)E;F1E<F5R
M+G!H<#HU,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(DSV<V-H96XB"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU.`IM<V=I9"`B1&5L971E($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-B=6-H($SV<V-H96XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T92!#;VYF:7)M
M871I;VXB"FUS9W-T<B`B3/9S8VAB97-TY'1I9W5N9R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B1&5L971E(&)U='1O;B!B96AA=FEO
M=7(B"FUS9W-T<B`B5F5R:&%L=&5N(&)E:6T@3/9S8VAE;BXB"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(DSV<V-H96X@9F5H;&=E<V-H
M;&%G96XZ("@E<RD@)7,B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C8R"FUS
M9VED(")$96QE=&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("),]G-C:&5N('9O;B!+;VYT86MT96X@;FEC:'0@=6YT97)S=/QT>G0N
M(@H*(SH@9&5L971E+G!H<#HS.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM
M<V=S='(@(DSV<V-H96X@:7-T(&9E:&QG97-C:&QA9V5N(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM
M<V=S='(@(D%B=&5I;'5N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R(")!8G-T96EG96YD(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3$U"FUS9VED(")$97-C<FEP
M=&EO;B(*;7-G<W1R(")"97-C:')E:6)U;F<B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+W-E87)C:"YI;F,Z,3$Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B
M5F5R>F5I8VAN:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*;7-G
M:60@(D1I<W!L87DB"FUS9W-T<B`B06YZ96EG92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P
M"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B06YZ96EG92U%:6YS
M=&5L;'5N9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-PIM<V=I
M9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R:65S/R(*
M;7-G<W1R(")-]F-H=&5N(%-I92!D87,@3/9S8VAE;B!V;VX@16EN='+D9V5N
M(&)E<W3D=&EG96X_(@H*(SH@;&EB+T]B:F5C="YP:'`Z,CDW"FUS9VED(")$
M;W=N;&]A9"(*;7-G<W1R(")(97)U;G1E<FQA9&5N(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]R;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O
M=RYI;F,Z,C4*;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(G9#87)D
M(&AE<G5N=&5R;&%D96XB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L871E
M<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B"FUS
M9W-T<B`B0F5A<F)E:71E;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN
M8SHR-2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!B
M96%R8F5I=&5N(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*
M;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G<W1R(")!9')E<W-B_&-H
M97(@0F5A<F)E:71E;B(*"B,Z(&5D:70N<&AP.C@U(&5D:70N<&AP.C$V,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(&5N=')Y(&9O<B`E<R(*;7-G<W1R
M(")%:6YT<F%G('9O;B`E<R!B96%R8F5I=&5N(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(D5M86EL
M(@H*(SH@961I="YP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y
M(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@HB16EN=')A9R!V;VX@)7,@86MT=6%L
M:7-I97)T+"!A8F5R(&1I92!H;V-H9V5L861E;F4@1&%T96D@:V]N;G1E(&YI
M8VAT("(*(F=E<W!E:6-H97)T('=E<F1E;CH@)7,B"@HC.B!E9&ET+G!H<#HQ
M-38@961I="YP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O
M<B`E<R!U<&1A=&5D+B(*;7-G<W1R(")%:6YT<F%G('9O;B`E<R!A:W1U86QI
M<VEE<G0N(@H*(SH@8G)O=W-E+G!H<#HR,38@8G)O=W-E+G!H<#HR-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@861D:6YG("5D(&-O;G1A8W0H<RD@
M=&\@;&ES="XB"FUS9W-T<B`B1F5H;&5R(&)E:6T@2&EN>G5F_&=E;B!V;VX@
M)60@2V]N=&%K=&5N('IU<B!,:7-T92XB"@HC.B!B<F]W<V4N<&AP.C(Q."!B
M<F]W<V4N<&AP.C(V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!A9&1I
M;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@=&\@;&ES="XB"FUS
M9W-T<B`B1F5H;&5R(&)E:6T@2&EN>G5F_&=E;B!V;VX@)60@=F]N("5D($MO
M;G1A:W1E;B!Z=7(@3&ES=&4N(@H*(SH@8G)O=W-E+G!H<#HX-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R`E9"!C;VYT86-T*',I+B(*
M;7-G<W1R(")&96AL97(@8F5I;2!,]G-C:&5N('9O;B`E9"!+;VYT86MT96XN
M(@H*(SH@8G)O=W-E+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C=',H<RDN(@IM
M<V=S='(@(D9E:&QE<B!B96EM($SV<V-H96X@=F]N("5D('9O;B`E9"!+;VYT
M86MT96XN(@H*(SH@8G)O=W-E+G!H<#HV-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!R96UO=FEN9R`E9"!C;VYT86-T*',I(&9R;VT@;&ES="XB"FUS
M9W-T<B`B1F5H;&5R(&)E:6T@16YT9F5R;F5N('9O;B`E9"!+;VYT86MT96X@
M875S(&1E<B!,:7-T92XB"@HC.B!B<F]W<V4N<&AP.C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(')E;6]V:6YG("5D(&]F("5D(')E<75E<W1E9"!C
M;VYT86-T*',I(&9R;VT@;&ES="XB"FUS9W-T<B`B1F5H;&5R(&)E:6T@16YT
M9F5R;F5N('9O;B`E9"!V;VX@)60@2V]N=&%K=&5N(&%U<R!D97(@3&ES=&4N
M(@H*(SH@;&EB+V%P:2YP:'`Z-#$U"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('-E87)C:&EN9R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")$
M87,@061R97-S8G5C:"!K;VYN=&4@;FEC:'0@9'5R8VAS=6-H="!W97)D96XZ
M("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C0Q"FUS9VED(")%>'!O<G0B"FUS9W-T
M<B`B17AP;W)T:65R96XB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C8*;7-G:60@(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S
M8G5C:"!E>'!O<G1I97)E;B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T
M<RXB"FUS9W-T<B`B3G5R(&1I92!A=7-G97?D:&QT96X@2V]N=&%K=&4@97AP
M;W)T:65R96XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM
M<V=I9"`B17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L
M971E;'DN(@IM<V=S='(@(D1A<R!F;VQG96YD92!!9')E<W-B=6-H(&MO;7!L
M971T(&5X<&]R=&EE<F5N+B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H<#HR
M,C@@9&%T82YP:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HQ,#,*
M(SH@8G)O=W-E+G!H<#HQ,S`@861D+G!H<#HV-R!S96%R8V@N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E
M<W,@8F]O:SH@)7,B"FUS9W-T<B`B1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI
M8VAT(&=E]F9F;F5T('=E<F1E;CH@)7,B"@HC.B!B<F]W<V4N<&AP.C$U.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@861D("5S('1O("5S.B`E
M<R(*;7-G<W1R("(E<R!K;VYN=&4@;FEC:'0@>G4@)7,@:&EN>G5G96;\9W0@
M=V5R9&5N.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,S`U"FUS9VED(")&86EL960@
M=&\@8G)O=W-E(&QI<W0B"FUS9W-T<B`B1&EE($QI<W1E(&MO;FYT92!N:6-H
M="!A;F=E>F5I9W0@=V5R9&5N(@H*(SH@8G)O=W-E+G!H<#HS-#,*;7-G:60@
M(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R>2(*;7-G<W1R(")$87,@
M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&%N9V5Z96EG="!W97)D96XB"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S
M+"!.97<@1$X@/2`E<RP@4F]O="`]("5S(@IM<V=S='(@(B(*(DYA;64@:V]N
M;G1E(&YI8VAT(&=EY&YD97)T('=E<F1E;CH@*"5S*2`E<SL@06QT92!$3B`]
M("5S+"!.975E($1.(#T@)7,L(%)O;W0@(@HB/2`E<R(*"B,Z(&)R;W=S92YP
M:'`Z,3,T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B
M:F5C="!T;R!B92!A9&1E9#H@)7,B"FUS9W-T<B`B(@HB1&%S($]B:F5K="P@
M9&%S(&AI;GIU9V5F_&=T('=E<F1E;B!S;VQL=&4L(&MO;FYT92!N:6-H="!G
M969U;F1E;B!W97)D96XZ("5S(@H*(SH@<V5A<F-H+G!H<#HW.0IM<V=I9"`B
M1F%I;&5D('1O('-E87)C:"!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(D1A
M<R!!9')E<W-B=6-H(&MO;FYT92!N:6-H="!D=7)C:'-U8VAT('=E<F1E;B(*
M"B,Z(&1A=&$N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S(@IM<V=S='(@(D1A<R!697)Z
M96EC:&YI<R`E<R!K;VYN=&4@;FEC:'0@9'5R8VAS=6-H="!W97)D96XN(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38W"FUS9VED(")&87@B
M"FUS9W-T<B`B1F%X(@H*(SH@961I="YP:'`Z,3,Q(&1I<W!L87DN<&AP.C$P
M,@IM<V=I9"`B1FEL97,B"FUS9W-T<B`B1&%T96EE;B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O<V5A<F-H+FEN8SHW,0IM<V=I9"`B1FEN9"(*;7-G<W1R(")$
M=7)C:'-U8VAE;B!V;VX@(@H*(SH@961I="YP:'`Z,3`T(&5D:70N<&AP.C$Y
M-`IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(D)E96YD96XB"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HT.`IM<V=I9"`B1FER<W0@3F%M92(*;7-G
M<W1R(")6;W)N86UE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B1G)E:2TO1V5B=6-H
M="U54DPB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.#0*;7-G
M:60@(D9R;VTB"FUS9W-T<B`B5F]N(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP
M+F1I<W0Z-C`V"FUS9VED(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@
M(D%L;&=E;65I;F5S($%D<F5S<V)U8V@B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT
M-`IM<V=I9"`B1W)O=7`B"FUS9W-T<B`B1W)U<'!E(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G
M<W1R(")!9')E<W-E('!R:79A="(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.CDS"FUS9VED(")(;VUE($-I='DB"FUS9W-T<B`B4W1A9'0@<')I
M=F%T(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`X"FUS9VED
M(")(;VUE($-O=6YT<GDB"FUS9W-T<B`B3&%N9"!P<FEV870B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B
M"FUS9W-T<B`B5&5L969O;B!P<FEV870B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ,#,*;7-G:60@(DAO;64@4&]S=&%L($-O9&4B"FUS9W-T
M<B`B4&]S=&QE:71Z86AL('!R:79A="(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.CDX"FUS9VED(")(;VUE(%-T871E+U!R;W9I;F-E(@IM<V=S
M='(@(D)U;F1E<W-T86%T(&]D97(@4')O=FEN>B!P<FEV870B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HX.`IM<V=I9"`B2&]M92!3=')E970@
M061D<F5S<R(*;7-G<W1R(")3=')AWV4@<')I=F%T(@H*(SH@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z-3`X"FUS9VED("))35-0(@IM<V=S='(@(DE-4U`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<*;7-G:60@(DE-4U`@061D
M<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(DE-4U`M061R97-S
M8G5C:'9E<G=A;'1U;F<B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($%D9')E<W,@0F]O:RP@
M4W1E<"`E9"(*;7-G<W1R(")!9')E<W-B=6-H(&EM<&]R=&EE<F5N+"!38VAR
M:71T("5D(@H*(SH@9&%T82YP:'`Z,S8Q"FUS9VED("));7!O<G0O17AP;W)T
M($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B061R97-S8OQC:&5R($EM<&]R="]%
M>'!O<G0B"@HC.B!L:6(O87!I+G!H<#HV,3,@;&EB+V%P:2YP:'`Z-S`P"FUS
M9VED("));G9A;&ED($E$(@IM<V=S='(@(E5N9_QL=&EG92!)1"(*"B,Z(&QI
M8B]A<&DN<&AP.C(S,B!L:6(O87!I+G!H<#HT,#0@;&EB+V%P:2YP:'`Z-#@W
M(&QI8B]A<&DN<&AP.C8P.0HC.B!L:6(O87!I+G!H<#HV.38@;&EB+V%P:2YP
M:'`Z-S0X(&QI8B]A<&DN<&AP.C$Q,#<*;7-G:60@(DEN=F%L:60@861D<F5S
M<R!B;V]K(@IM<V=S='(@(E5N9_QL=&EG97,@061R97-S8G5C:"(*"B,Z(&QI
M8B]A<&DN<&AP.C$Q,3$@;&EB+V%P:2YP:'`Z,3$X-2!L:6(O87!I+G!H<#HQ
M,C,X"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(E5N9_QL=&EG92!%
M;6%I;"U!9')E<W-E(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q.0IM<V=I9"`B26YV
M86QI9"!E;G1R>2(*;7-G<W1R(")5;F?\;'1I9V5R($5I;G1R86<B"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C(V-@IM<V=I9"`B26YV86QI9"!K97D@<W!E
M8VEF:65D+B(*;7-G<W1R(")5;F?\;'1I9V5R(%-C:&S\<W-E;"!A;F=E9V5B
M96XN(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q-0IM<V=I9"`B26YV86QI9"!N86UE
M(@IM<V=S='(@(E5N9_QL=&EG97(@3F%M92(*"B,Z(&QI8B]A<&DN<&AP.C<U
M,@IM<V=I9"`B26YV86QI9"!O8FIE8W1)9"(*;7-G<W1R(")5;F?\;'1I9V4@
M3V)J96MT($E$(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,`IM<V=I9"`B
M(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U
M;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D+B(*;7-G<W1R("(B
M"B),1$%0+55N=&5R<W3\='IU;F<@=VER9"!B96[V=&EG="P@86)E<B!D87,@
M3$1!4"U-;V1U;"!I<W0@;FEC:'0@=F5R9OQG8F%R("(*(F]D97(@=W5R9&4@
M;FEC:'0@9V5L861E;BXB"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS
M9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(DQE='IT92#$;F1E<G5N9R(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C4S"FUS9VED("),87-T
M($YA;64B"FUS9W-T<B`B3F%C:&YA;64B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V-O;'5M;E]H96%D97)S+FEN8SHQ-@IM<V=I9"`B3&ES="(*;7-G<W1R("),
M:7-T92(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW.`IM<V=I
M9"`B36%T8VAI;F<B"FUS9W-T<B`B;F%C:"(*"B,Z(&QI8B]A<&DN<&AP.C(P
M-PIM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B
M36%X:6UA;&4@06YZ86AL(&%N($MO;G1A:W1E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F('!A9V5S
M(@IM<V=S='(@(DUA>&EM86QE(%-E:71E;GIA:&PB"@HC.B!L:6(O0FQO8VLO
M=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU($QI<W0B"FUS9W-T<B`B365N
M_&QI<W1E(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI
M<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B1$X@9F5H;'0@:6X@9&5R($Q$05`M2V]N9FEG=7)A=&EO;BXB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0
M:&]N92(*;7-G<W1R(")496QE9F]N(&UO8FEL(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HS,S(@;&EB+T1R:79E<B]L9&%P+G!H<#HS-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B36]D:69Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("+$
M;F1E<G5N9R!F96AL9V5S8VAL86=E;CH@*"5S*2`E<R(*"B,Z(&QI8B]A<&DN
M<&AP.C$R,C0*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S
M='(@(DUE:'(@86QS(#$@16EN=')A9R!Z=7+\8VMG96QI969E<G0B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$V"FUS9VED(")-;W9E(@IM
M<V=S='(@(E9E<G-C:&EE8F5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M
M;G-E;&5C="YI;F,Z,C0W"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O
M:W-E;&5C="YI;F,Z,3@T"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B3F%C
M:"!L:6YK<R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(T.0HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC
M.C$X-@IM<V=I9"`B36]V92!R:6=H="(*;7-G<W1R(").86-H(')E8VAT<R(*
M"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,38*
M;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G<W1R(")-=6QB97)R
M>2U!9')E<W-B=6-H(@H*(SH@;&EB+V%P:2YP:'`Z,3$T,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;
M)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T(@IM
M<V=S='(@(B(*(DUE:')E<F4@4&5R<V]N96X@;6ET(&1E<B!!9')E<W-E(%LE
M<UTL(&%B97(@:V5I;F4@;6ET(&1E;2!.86UE;B!;)7-=(&EM("(*(D%D<F5S
M<V)U8V@B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ,#<@8V]N9FEG
M+W-O=7)C97,N<&AP+F1I<W0Z,C0S"FUS9VED(")->2!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B365I;B!!9')E<W-B=6-H(@H*(SH@861D<F5S<V)O;VMS+G!H
M<#HQ,3D*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B365I;F4@
M061R97-S8OQC:&5R(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M,3`W(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0R"FUS9VED(").86UE
M(@IM<V=S='(@(DYA;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*
M;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@(DYA;65N<V9O<FUA="(*"B,Z
M(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T8V5N=&5R
M($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B3F5T8V5N=&5R($UI=&=L:65D
M97)V97)Z96EC:&YI<R(*"B,Z(&%D9"YP:'`Z,S8@861D+G!H<#HQ,C0@;&EB
M+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*;7-G:60@(DYE=R!#;VYT86-T(@IM
M<V=S='(@(DYE=65R($MO;G1A:W0B"@HC.B!E9&ET+G!H<#HY-2!E9&ET+G!H
M<#HQ,#(@961I="YP:'`Z,C`Y('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M-#4*;7-G:60@(DYE>'0B"FUS9W-T<B`B5V5I=&5R(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,C$X"FUS9VED(").:6-K;F%M92(*;7-G<W1R
M(")3<&ET>FYA;64B"@HC.B!L:6(O87!I+G!H<#HQ,C(V(&QI8B]A<&DN<&AP
M.C$R-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@)7,@96YT<GD@9F]U;F0@
M9F]R("5S(@IM<V=S='(@(D5S('=U<F1E(&ME:6X@)7,@16EN=')A9R!F_'(@
M)7,@9V5F=6YD96XB"@HC.B!L:6(O87!I+G!H<#HQ,3DT"FUS9VED(").;R!A
M9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R(")+96EN92!!9')E<W-B_&-H
M97(@9V5F=6YD96XN(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#$*;7-G:60@(DYO
M(&-O;G1A8W1S(&9O=6YD(@IM<V=S='(@(DME:6YE($MO;G1A:W1E(&=E9G5N
M9&5N+B(*"B,Z(&QI8B]A<&DN<&AP.C4Q,B!L:6(O87!I+G!H<#HW.#,*;7-G
M:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R(")%<R!W=7)D
M96X@:V5I;F4@=D-A<F0M1&%T96X@9V5F=6YD96XN(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]F;V]T97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`B2V5I
M;F4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(DYO=&5S(@IM<V=S='(@(D)E;65R:W5N9V5N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-0IM<V=I9"`B3G5M8F5R(&]F(&ET96US('!E<B!P86=E
M(@IM<V=S='(@(D%N>F%H;"!D97(@16EN='+D9V4@<')O(%-E:71E(@H*(SH@
M;&EB+V%P:2YP:'`Z-C,Q(&QI8B]A<&DN<&AP.C<V-`IM<V=I9"`B3V)J96-T
M(&YO="!F;W5N9"(*;7-G<W1R(")/8FIE:W0@;FEC:'0@9V5F=6YD96XB"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,C,*;7-G:60@(D]F9FEC
M92(*;7-G<W1R(")"_')O(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T
M+FEN8SHR,@IM<V=I9"`B(@HB3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P
M86=E+"!T:&4@861D<F5S<R!B;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB
M9&5L971E9"X@268@=&AI<R!I<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y
M;W4@;75S="!C:&%N9V4@>6]U<B!S96QE8W1I;VX@(@HB=&\@7").;VYE7"(N
M(@IM<V=S='(@(B(*(E=E;FX@4VEE(&1I97-E($5I;G-T96QL=6YG('-P96EC
M:&5R;BP@=VER9"!D87,@86YG96=E8F5N92!!9')E<W-B=6-H("(*(F5N9&?\
M;'1I9R!G96SV<V-H="X@5V5N;B!3:64@9&%S(&YI8VAT(&WV8VAT96XL(.1N
M9&5R;B!3:64@26AR92!!=7-W86AL(&%U9B`B"B)<(FME:6Y<(BXB"@HC.B!L
M:6(O87!I+G!H<#HW.3$*;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E
M9"XB"FUS9W-T<B`B3G5R(&5I;GIE;&YE('9#87)D<R!W97)D96X@=6YT97)S
M=/QT>G0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R
M(")!;F1E<F4@16EN<W1E;&QU;F=E;B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B
MUF9F96YT;&EC:&5R(%!'4"U38VAL_'-S96PB"@HC.B!L:6(O87!I+G!H<#HT
M.38@;&EB+V%P:2YP:'`Z-C(R(&QI8B]A<&DN<&AP.C<P.2!L:6(O87!I+G!H
M<#HY-C0*(SH@;&EB+V%P:2YP:'`Z,3$R.`IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`B6G5G<FEF9B!V97)W96EG97)T(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z-34Q"FUS9VED(")097)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M("):=6=R:69F('9E<G=E:6=E<G0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O
M;VMS+FEN8SHY.0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5C:'1E
M(@H*(SH@9&%T82YP:'`Z-3,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ
M-PIM<V=I9"`B4&EN92!!9&1R97-S($)O;VLB"FUS9W-T<B`B4&EN92U!9')E
M<W-B=6-H(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHR
M.`IM<V=I9"`B4&QE87-E(&YA;64@=&AE(&YE=R!C;VYT86-T(&QI<W0Z(@IM
M<V=S='(@(D)I='1E(&5I;F5N($YA;65N(&;\<B!D:64@;F5U92!+;VYT86ML
M:7-T92!A;F=E8F5N.B(*"B,Z(&5D:70N<&AP.CDX(&5D:70N<&AP.C$P,2!E
M9&ET+G!H<#HR,#$*;7-G:60@(E!R979I;W5S(@IM<V=S='(@(EIU<OQC:R(*
M"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q-@IM<V=I9"`B4')I=F%T
M92!!9&1R97-S($)O;VLB"FUS9W-T<B`B4')I=F%T97,@061R97-S8G5C:"(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G
M:60@(E%U97)Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")!8F9R86=E(&9E
M:&QG97-C:&QA9V5N.B`H)7,I("5S(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI
M;FES96%R8V@N:6YC.C$U"FUS9VED(")1=6EC:R!396%R8V@B"FUS9W-T<B`B
M4V-H;F5L;'-U8VAE(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3$@;&EB
M+T1R:79E<B]L9&%P+G!H<#HQ.3D@;&EB+T1R:79E<B]L9&%P+G!H<#HT,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A9"!F86EL960Z("@E<RD@)7,B"FUS
M9W-T<B`B3&5S96X@9F5H;&=E<V-H;&%G96XZ("@E<RD@)7,B"@HC.B!L:6(O
M1')I=F5R+VYU;&PN<&AP.C4R"FUS9VED(")296%D:6YG(&-O;G1A8W1S(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%N>F5I9V5N('9O;B!+;VYT86MT
M96X@;FEC:'0@=6YT97)S=/QT>G0N(@H*(SH@;&EB+U)E;F1E<F5R+G!H<#HT
M.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S='(@
M(D1I97-E;B!+;VYT86MT('=I<FML:6-H(&SV<V-H96X_(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97(N:6YC.C(*;7-G:60@(E)E8V]R9',@9&ES<&QA
M>65D.B(*;7-G<W1R(")!;F=E>F5I9W1E($5I;G1RY&=E.B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<V"FUS9VED(")2
M96UO=F4@861D<F5S<R!B;V]K(@IM<V=S='(@(D%D<F5S<V)U8V@@96YT9F5R
M;F5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,Y
M"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E-P86QT92!E;G1F97)N
M96XB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*;7-G:60@
M(E)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R(")!=7,@9&EE<V5R($QI
M<W1E(&5N=&9E<FYE;B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,C$*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K('=I
M=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES("(*
M(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@
M8F]O:RX\+W-T<F]N9SXB"FUS9W-T<B`B(@HB17AI<W1I97)E;F1E<R!!9')E
M<W-B=6-H(&UI="!D96T@:6UP;W)T:65R=&5N(&5R<V5T>F5N/R`\<W1R;VYG
M/E=A<FYU;F<Z("(*(D1A;6ET('=E<F1E;B!A;&QE(&%K='5E;&QE;B!%:6YT
M<N1G92!I;B!D96T@061R97-S8G5C:"!G96SV<V-H="X\+W-T<F]N9SXB"@HC
M.B!L:6(O1')I=F5R+G!H<#HT,SD*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@
M;F]T(&9O=6YD+B(*;7-G<W1R(")'97?\;G-C:'1E<R!/8FIE:W0@;FEC:'0@
M9V5F=6YD96XN(@H*(SH@861D+G!H<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E
M87)C:"YI;F,Z,3$T"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R
M("):=7+\8VMS971Z96XB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ.38*;7-G:60@(E,O34E-12!0=6)L:6,@0V5R=&EF:6-A=&4B"FUS9W-T
M<B`BUF9F96YT;&EC:&5S(%,O34E-12U:97)T:69I:V%T(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")35$%25%1,
M4R!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4U1!4E143%,@9F5H;&=E<V-H
M;&%G96XZ("@E<RD@)7,B"@HC.B!E9&ET+G!H<#HQ,#8@861D+G!H<#HS-R!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,C0*;7-G:60@(E-A=F4B"FUS
M9W-T<B`B4W!E:6-H97)N(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HV-PIM
M<V=I9"`B4V%V:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(E-P96EC:&5R;B!V;VX@2V]N=&%K=&5N(&YI8VAT('5N=&5R<W3\='IT
M+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-R!T96UP;&%T
M97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$S"B,Z('1E;7!L871E<R]B;&]C:R]M
M:6YI<V5A<F-H+FEN8SHQ."!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HT.0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B"FUS
M9W-T<B`B4W5C:&4B"@HC.B!L:6(O87!I+G!H<#HQ,#0Q"FUS9VED(")396%R
M8V@@9F%I;&5D(@IM<V=S='(@(E-U8VAE(&9E:&QG97-C:&QA9V5N(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$S,R!L:6(O87!I+G!H<#HQ,3,Y(&QI8B]A<&DN<&AP
M.C$Q-#@@;&EB+V%P:2YP:'`Z,3$V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M96%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R(")3=6-H92!F96AL9V5S8VAL86=E
M;CH@)7,B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C0W"FUS9VED(")396%R
M8VAI;F<@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4W5C:&5N('9O;B!+
M;VYT86MT96X@;FEC:'0@=6YT97)S=/QT>G0N(@H*(SH@=&5M<&QA=&5S+V)L
M;V-K+VUI;FES96%R8V@N:6YC.C$Y"FUS9VED(")396%R8VAI;F<N+BXB"FUS
M9W-T<B`B4W5C:&4N+BXB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHV-@IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B
M"FUS9W-T<B`B5^1H;&5N(%-I92!D87,@061R97-S8G5C:"P@9&%S(&=E;/9S
M8VAT('=E<F1E;B!S;VQL(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z.3`*;7-G:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@961I="(*
M;7-G<W1R(")7Y&AL96X@4VEE(&1A<R!!9')E<W-B=6-H+"!D87,@8F5A<F)E
M:71E="!W97)D96X@<V]L;"(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,S(*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R
M="!F<F]M.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1A<R!!9')E<W-B=6-H+"!A
M=7,@9&5M(&5X<&]R=&EE<G0@=V5R9&5N('-O;&PZ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHR-@IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S
M(&)O;VL@=&\@:6UP;W)T('1O.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1A<R!!
M9')E<W-B=6-H+"!I;B!D87,@:6UP;W)T:65R="!W97)D96X@<V]L;#HB"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,U"FUS9VED(")396QE8W0@
M=&AE(&-H87)S970@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")7Y&AL
M96X@4VEE(&1E;B!:96EC:&5N<V%T>B!D97(@:6UP;W)T:65R=&5N($1A=&5I
M.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*;7-G:60@(E-E
M;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B5^1H;&5N(%-I92!D
M87,@17AP;W)T9F]R;6%T.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z-#,*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S
M='(@(E?D:&QE;B!3:64@9&EE($1A=&5I+"!D:64@:6UP;W)T:65R="!W97)D
M96X@<V]L;#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q"FUS
M9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM
M<V=S='(@(E?D:&QE;B!3:64@9&%S($9O<FUA="!D97(@:6UP;W)T:65R=&5N
M($1A=&5I.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@
M(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SHB"FUS
M9W-T<B`B3&5G96X@4VEE(&9E<W0L('=I92!D:64@3F%M96X@86YG97IE:6=T
M('=E<F1E;B!S;VQL96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U
M"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L('-O
M<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+B(*;7-G<W1R("(B"B)7
MY&AL96X@4VEE(&1I92!3=&%N9&%R9&%N<VEC:'0@=6YD($5I;G-T96QL=6YG
M96X@9OQR<R!3;W)T:65R96X@=6YD($)LY'1T97)N+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.`IM<V=I9"`B4V5L96-T('=H:6-H(&9I96QD<R!T
M;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+B(*;7-G<W1R("(B"B)7
MY&AL96X@4VEE(&1I92!&96QD97(@875S+"!D:64@:6X@9&5R($%D<F5S<VQI
M<W1E(&%N9V5Z96EG="!W97)D96X@<V]L;&5N+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L96-T('=H:6-H(&9O<FUA="!T;R!D
M:7-P;&%Y(&YA;65S+B(*;7-G<W1R(")7Y&AL96X@4VEE(&1A<R!&;W)M870L
M(&EN(&1E;2!D:64@3F%M96X@86YG97IE:6=T('=E<F1E;B!S;VQL96XN(@H*
M(SH@861D+G!H<#HU-`HC+"!P:'`M9F]R;6%T"FUS9VED(")396QE8W1E9"!A
M9&1R97-S(&)O;VL@7"(E<UPB+B(*;7-G<W1R(")!9')E<W-B=6-H(%PB)7-<
M(B!A=7-G97?D:&QT+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$W
M,PIM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G<W1R(")'96UE:6YS86UE
M<R!697)Z96EC:&YI<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R`E<R(*;7-G<W1R("(E
M<R!A;GIE:6=E;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M-#@*;7-G:60@(E-H;W<@06QL(@IM<V=S='(@(D%L;&4@86YZ96EG96XB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0W"FUS9VED(")3:&]W
M($-O;G1A8W1S(@IM<V=S='(@(DMO;G1A:W1E(&%N>F5I9V5N(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-@IM<V=I9"`B4VAO=R!,:7-T
M<R(*;7-G<W1R("),:7-T96X@86YZ96EG96XB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V-O;'5M;E]H96%D97)S+FEN8SHR,0HC.B!T96UP;&%T97,O8G)O=W-E
M+V-O;'5M;E]H96%D97)S+FEN8SHS-@IM<V=I9"`B4V]R="!$:7)E8W1I;VXB
M"FUS9W-T<B`B4V]R=&EE<G)I8VAT=6YG(@H*(SH@;&EB+V%P:2YP:'`Z,C`P
M"FUS9VED(")3;W5R8V5S(@IM<V=S='(@(E%U96QL96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W
M86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T
M<B`B(@HB1V5B96X@4VEE(&%N+"!W;R!D:64@17)G96)N:7-S92!D97(@97)W
M96ET97)T96X@4W5C:&4@97)S8VAE:6YE;B!S;VQL96XN(@H*(SH@8G)O=W-E
M+G!H<#HR,30@8G)O=W-E+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&%D9&5D("5D(&-O;G1A8W0H<RD@=&\@;&ES="XB"FUS
M9W-T<B`B)60@2V]N=&%K=&4@97)F;VQG<F5I8V@@>G5R($QI<W1E(&AI;GIU
M9V5F_&=T+B(*"B,Z(&)R;W=S92YP:'`Z,38P"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<R(*;7-G<W1R("(E<R!W
M=7)D92!E<F9O;&=R96EC:"!Z=2`E<R!H:6YZ=6=E9OQG="(*"B,Z(&)R;W=S
M92YP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C
M<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R(")$:64@
M2V]N=&%K=&QI<W1E(%PB)7-<(B!W=7)D92!E<F9O;&=R96EC:"!E<G-T96QL
M="XB"@HC.B!B<F]W<V4N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!D96QE=&5D("5D(&-O;G1A8W0H<RDN(@IM<V=S='(@(B5D
M($MO;G1A:W1E(&5R9F]L9W)E:6-H(&=E;/9S8VAT+B(*"B,Z(&)R;W=S92YP
M:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V
M960@)60@8V]N=&%C="AS*2!F<F]M(&QI<W0N(@IM<V=S='(@(B5D($MO;G1A
M:W1E(&5R9F]L9W)E:6-H(&%U<R!D97(@3&ES=&4@96YT9F5R;G0N(@H*(SH@
M9&%T82YP:'`Z-3`*;7-G:60@(E135B(*;7-G<W1R(")44U8B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,30*;7-G:60@(E1A8B!S97!A<F%T960@=F%L=65S(@IM<V=S='(@
M(E1A8F=E=')E;FYT92!797)T92(*"B,Z('9I97<N<&AP.C$U"FUS9VED(")4
M:&4@5D93(&)A8VME;F0@;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B
M;&4@871T86-H;65N="!U<&QO861S+B(*;7-G<W1R("(B"B)$87,@5D93+4)A
M8VME;F0@;75S<R!K;VYF:6=U<FEE<G0@<V5I;BP@=6T@9&%S($AO8VAL861E
M;B!V;VX@1&%T96EE;B!Z=2`B"B)E<FQA=6)E;BXB"@HC.B!L:6(O1')I=F5R
M+G!H<#HQ,#<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O
M;VL@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$87,@061R97-S
M8G5C:"!<(B5S7"(@97AI<W1I97)T(&YI8VAT+B(*"B,Z(&%D9')E<W-B;V]K
M<RYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")$
M87,@061R97-S8G5C:"!<(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@97)S=&5L
M;'0N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<F5M;W9E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(D1A<R!!9')E<W-B=6-H(%PB)7-<(B!W=7)D
M92!E<F9O;&=R96EC:"!G96SV<V-H="XB"@HC.B!A9&1R97-S8F]O:W,N<&AP
M.C@Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E
M<UPB('=A<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B1&%S($%D
M<F5S<V)U8V@@7"(E<UPB('=U<F1E(&5R9F]L9W)E:6-H(&%K='5A;&ES:65R
M="XB"@HC.B!D871A+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R
M(")$87,@061R97-S8G5C:"!K;VYN=&4@;FEC:'0@9V5L965R="!W97)D96XZ
M("5S(@H*(SH@961I="YP:'`Z-3$@=F-A<F0N<&AP.C(R(&1I<W!L87DN<&AP
M.C(S('9I97<N<&AP.C(V"FUS9VED(")4:&4@8V]N=&%C="!Y;W4@<F5Q=65S
M=&5D(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$97(@875S9V5WY&AL=&4@
M2V]N=&%K="!E>&ES=&EE<G0@;FEC:'0N(@H*(SH@961I="YP:'`Z,3(S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE(%PB)7-<(B!H87,@<W5C8V5S
M<V9U;&QY(&)E96X@9&5L971E9"XB"FUS9W-T<B`B1&EE($1A=&5I(%PB)7-<
M(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="XB"@HC.B!D871A+G!H<#HR
M.#0*;7-G:60@(E1H92!I;7!O<G0@8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@
M=&AE('=A<FYI;F=S+B(*;7-G<W1R(")$97(@26UP;W)T(&MA;FX@=')O='H@
M9&5R(%=A<FYU;F=E;B!A8F=E<V-H;&]S<V5N('=E<F1E;BXB"@HC.B!B<F]W
M<V4N<&AP.C,Q"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A9&1R
M97-S(&)O;VMS+B(*;7-G<W1R(")%<R!G:6)T(&ME:6YE($%D<F5S<V+\8VAE
M<BP@9&EE(&%U9F=E;&ES=&5T('=E<F1E;B!K]FYN96XN(@H*(SH@861D+G!H
M<#HR.0IM<V=I9"`B(@HB5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S
M(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R`B
M"B)A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R
M:65S('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@(@HB:7,@86X@97)R
M;W(L('!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(D5S(&=I8G0@:V5I;F4@8F5S8VAR96EB8F%R96X@061R
M97-S8OQC:&5R+B!+96EN97,@9&5R('9E<F;\9V)A<F5N("(*(D%D<F5S<V+\
M8VAE<B!E<FQA=6)T($EH;F5N+"!N975E($%D<F5S<V5N(&AI;GIU>G5F_&=E
M;BX@5V5N;B!3:64@;65I;F5N+"`B"B)D87-S(&5S('-I8V@@9&%B96D@=6T@
M96EN96X@1F5H;&5R(&AA;F1E;'0L('=E;F1E;B!3:64@<VEC:"!B:71T92!A
M;B!):')E;B`B"B)3>7-T96TM061M:6YI<W1R871O<BXB"@HC.B!A9&0N<&AP
M.C$R,0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@
M;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)"96EM($AI;GIU
M9OQG96X@9&EE<V5S($MO;G1A:W1S(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E
M=&5N+B!":71T92!W96YD96X@4VEE("(*(G-I8V@@86X@26AR96X@4WES=&5M
M861M:6YI<W1R871O<B!F_'(@=V5I=&5R92!(:6QF92XB"@HC.B!B<F]W<V4N
M<&AP.C(W,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG(&$@
M;F5W(&QI<W0N(@IM<V=S='(@(D)E:6T@17)S=&5L;&5N(&5I;F5R(&YE=65N
M($QI<W1E(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B(*"B,Z(&%D9')E
M<W-B;V]K<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G
M<W1R(")"96EM($5R<W1E;&QE;B!D97,@061R97-S8G5C:',@:7-T(&5I;B!&
M96AL97(@875F9V5T<F5T96XZ("5S(@H*(SH@8G)O=W-E+G!H<#HQ-C8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG
M(%PB)7-<(B!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+B(*;7-G<W1R
M(")"96EM($SV<V-H96X@=F]N(%PB)7-<(B!A=7,@9&5M($%D<F5S<V)U8V@@
M:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN(@H*(SH@9&5L971E+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G<W1R(")"96EM($SV<V-H96X@
M9&5S($MO;G1A:W1S(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N.B`E<R(*
M"B,Z(&)R;W=S92YP:'`Z,S$Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R(")"96EM($%N>F5I9V5N(&1E
M<B!,:7-T92!I<W0@96EN($9E:&QE<B!A=69G971R971E;B(*"B,Z(&1A=&$N
M<&AP.C,S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R(")"96EM($EM<&]R
M=&EE<F5N(&1E<B!$871E;B!I<W0@96EN($9E:&QE<B!A=69G971R971E;CH@
M)7,B"@HC.B!L:6(O87!I+G!H<#HU,#@@;&EB+V%P:2YP:'`Z-S<X"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82XB"FUS9W-T<B`B0F5I;2!);7!O<G1I97)E;B!D97(@:4-A;&5N9&%R
M($1A=&5N(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B(*"B,Z(&%D9')E
M<W-B;V]K<RYP:'`Z-3@@861D<F5S<V)O;VMS+G!H<#HV,R!A9&1R97-S8F]O
M:W,N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B
M0F5I;2!,]G-C:&5N(&1E<R!!9')E<W-B=6-H<R!I<W0@96EN($9E:&QE<B!A
M=69G971R971E;CH@)7,B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C@W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B0F5I;2!!:W1U86QI<VEE
M<F5N(&1E<R!!9')E<W-B=6-H<R!I<W0@96EN($9E:&QE<B!A=69G971R971E
M;CH@)7,B"@HC.B!E9&ET+G!H<#HQ-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT<GDZ("5S(@IM
M<V=S='(@(D)E:6T@06MT=6%L:7-I97)E;B!D:65S97,@16EN=')A9W,@:7-T
M(&5I;B!&96AL97(@875F9V5T<F5T96XZ("5S(@H*(SH@9&%T82YP:'`Z,3<Y
M"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N(@IM
M<V=S='(@(D5S(&MO;FYT96X@:V5I;F4@061R97-S96X@>G5M($5X<&]R=&EE
M<F5N(&=E9G5N9&5N('=E<F1E;BXB"@HC.B!T96UP;&%T97,O<')E9G,O861D
M<F5S<V)O;VMS96QE8W0N:6YC.C$X,`IM<V=I9"`B5&AE<V4@861D<F5S<R!B
M;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B1&EE
M<V4@061R97-S8OQC:&5R('=E<F1E;B!I;B!D97(@9F]L9V5N9&5N(%)E:6AE
M;F9O;&=E(&%N9V5Z96EG=#HB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR-#,*;7-G:60@(E1H97-E(&-O;'5M;G,@=VEL;"!D:7-P
M;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@(D1I97-E(%-P86QT96X@=V5R
M9&5N(&EN(&1E<B!F;VQG96YD96X@4F5I:&5N9F]L9V4@86YG97IE:6=T.B(*
M"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")$:65S97,@1&%T96EF;W)M870@=VER
M9"!N:6-H="!U;G1E<G-T_'1Z="XB"@HC.B!L:6(O87!I+G!H<#HQ,34R(&QI
M8B]A<&DN<&AP.C$Q-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S
M;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K
M(@IM<V=S='(@(D1I97-E(%!E<G-O;B!H870@8F5R96ET<R!E:6YE;B`E<RU%
M:6YT<F%G(&EN($EH<F5M($%D<F5S<V)U8V@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30X"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U
M;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT
M86-T<RXB"FUS9W-T<B`B(@HB1&EE<R!W:7)D(&%L<R!3=&%N9&%R9&%D<F5S
M<V)U8V@@9OQR(&1A<R!(:6YZ=6;\9V5N(&]D97(@26UP;W)T:65R96X@=F]N
M("(*(DMO;G1A:W1E;B!B96YU='IT+B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C<P"FUS9VED(")4:71L92(*;7-G<W1R(")0;W-I=&EO;B(*
M"B,Z(&QI8B]4=7)B82YP:'`Z-#0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@;F5W('-H87)E+B!-:7-S:6YG('-O=7)C92!T>7!E
M+B(*;7-G<W1R("(B"B)$87,@9V5M96EN<V%M92!!9')E<W-B=6-H(&MO;FYT
M92!N:6-H="!E<G-T96QL="!W97)D96XL(&1E<B!1=65L;'1Y<"!F96AL="XB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#`Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R
M(")$97(@)7,M5')E:6)E<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96XN
M(@H*(SH@961I="YP:'`Z.34@961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D
M:70N<&AP.C$P-B!E9&ET+G!H<#HR,#,*;7-G:60@(E5N9&\@0VAA;F=E<R(*
M;7-G<W1R("+$;F1E<G5N9V5N('+\8VMGY&YG:6<@;6%C:&5N(@H*(SH@;&EB
M+V%P:2YP:'`Z-30Q(&QI8B]A<&DN<&AP.C8V,"!L:6(O87!I+G!H<#HW.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E
M.B`E<R(*;7-G<W1R(").:6-H="!U;G1E<G-T_'1Z=&5R($EN:&%L='-T>7`Z
M("5S(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"FUS9VED(")6
M97)I<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`B5F5R:7-I9VX@5F5R>F5I8VAN
M:7,B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3D@=&5M<&QA=&5S
M+V)R;W=S92]C;VYT86-T<F]W+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@86YZ96EG96XB"@HC.B!M
M:6YI<V5A<F-H+G!H<#HW-@IM<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@
M(DMO;G1A:W0@86YZ96EG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(T"FUS9VED(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS9W-T
M<B`B4W1A;F1A<F1A;G-I8VAT.B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T<B`B5V5B<VET
M92U54DPB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3,*;7-G
M:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')E<W-E(&=E<V-HY&9T;&EC
M:"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R-`IM<V=I9"`B
M5V]R:R!#:71Y(@IM<V=S='(@(E-T861T(&=E<V-HY&9T;&EC:"(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S.0IM<V=I9"`B5V]R:R!#;W5N
M=')Y(@IM<V=S='(@(DQA;F0@9V5S8VCD9G1L:6-H(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,34V"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S
M='(@(E1E;&5F;VX@9V5S8VCD9G1L:6-H(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3,T"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S
M='(@(E!O<W1L96ET>F%H;"!G97-C:.1F=&QI8V@B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,CD*;7-G:60@(E=O<FL@4W1A=&4O4')O=FEN
M8V4B"FUS9W-T<B`B0G5N9&5S<W1A870@;V1E<B!0<F]V:6YZ(&=E<V-HY&9T
M;&EC:"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q.0IM<V=I
M9"`B5V]R:R!3=')E970@061D<F5S<R(*;7-G<W1R(")3=')AWV4@9V5S8VCD
M9G1L:6-H(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP:'`Z,3`V(&)R;W=S
M92YP:'`Z,C(W(&%D9"YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A
M8W1S(&EN(%PB)7-<(BXB"FUS9W-T<B`B4VEE(&3\<F9E;B!N:6-H="!M96AR
M(&%L<R`E9"!+;VYT86MT92!I;B!<(B5S7"(@97)S=&5L;&5N+B(*"B,Z(&5D
M:70N<&AP.C<S(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V"FUS9VED(")9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C
M="XB"FUS9W-T<B`B4VEE(&AA8F5N(&YI8VAT(&=E;OQG96YD(%)E8VAT92P@
M=6T@9&EE<V5N($MO;G1A:W0@>G4@<V5H96XN(@H*(SH@=F-A<F0N<&AP.C0P
M"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H
M:7,@;V)J96-T+B(*;7-G<W1R(")3:64@:&%B96X@;FEC:'0@9V5N_&=E;F0@
M4F5C:'1E+"!U;2!D:65S97,@3V)J96MT('IU('-E:&5N+B(*"B,Z(&QI8B]4
M=7)B82YP:'`Z-3,Q"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO
M;G,@=&\@9&5L971E('1H:7,@<V]U<F-E+B(*;7-G<W1R(")3:64@:&%B96X@
M;FEC:'0@9V5N_&=E;F0@4F5C:'1E+"!U;2!D:65S92!1=65L;&4@>G4@;/9S
M8VAE;BXB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C4U
M"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")3:64@;?QS<V5N(&5R<W0@96EN(%II96QA9')E<W-B=6-H
M(&%U<W?D:&QE;BXB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N
M:6YC.C(S"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB
M"FUS9W-T<B`B4VEE(&W\<W-E;B!E<G-T(&5I;F4@6FEE;&QI<W1E(&%N9V5B
M96XN(@H*(SH@961I="YP:'`Z,S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B4VEE(&W\<W-E
M;B!E<G-T(&UI;F1E<W1E;G,@96EN96X@2V]N=&%K="!A=7-WY&AL96XN(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP;&%T
M97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C0Y"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M="!L96%S="!O;F4@96YT<GD@9FER<W0N(@IM<V=S='(@(E-I92!M_'-S96X@
M97)S="!M:6YD97-T96YS(&5I;F5N($5I;G1R86<@875S=^1H;&5N+B(*"B,Z
M(&5D:70N<&AP.C<W"FUS9VED(")9;W4@;VYL>2!H879E('!E<FUI<W-I;VX@
M=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(E-I92!H86)E;B!N=7(@
M9&%S(%)E8VAT+"!D:65S96X@2V]N=&%K="!A;GIU<V5H96XN(@H*(SH@8G)O
M=W-E+G!H<#HS,3@*;7-G:60@(EEO=7(@9&5F875L="!A9&1R97-S(&)O;VL@
M:7,@;F]T(&)R;W=S96%B;&4N(@IM<V=S='(@(DEH<B!3=&%N9&%R9"U!9')E
M<W-B=6-H(&MA;FX@;FEC:'0@86YG97IE:6=T('=E<F1E;BXB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+W)O=RYI;F,Z-B!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C$R"FUS9VED(");;F\@=F%L=65=(@IM<V=S='(@(EMK96EN
M(%=E<G1=(@H*(SH@;&EB+U1U<F)A+G!H<#HU-30*;7-G:60@(E]"<F]W<V4B
M"FUS9W-T<B`B7TQI<W1E(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHT-PIM<V=I9"`B7T-O;G1A8W1S(@IM<V=S='(@(E]+;VYT86MT92(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PIM<V=I9"`B7T1E
M;&5T92(*;7-G<W1R("),]G-?8VAE;B(*"B,Z(&QI8B]4=7)B82YP:'`Z-38S
M"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R(")?26UP;W)T+T5X<&]R
M="(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#8*;7-G:60@
M(E],:7-T<R(*;7-G<W1R(")?3&ES=&5N(@H*(SH@;&EB+U1U<F)A+G!H<#HU
M-3$*;7-G:60@(E]->2!!9&1R97-S($)O;VMS(@IM<V=S='(@(E]-96EN92!!
M9')E<W-B_&-H97(B"@HC.B!L:6(O5'5R8F$N<&AP.C4U-PIM<V=I9"`B7TYE
M=R!#;VYT86-T(@IM<V=S='(@(E].975E<B!+;VYT86MT(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"FUS9VED(")?4F5M;W9E(&9R;VT@
M=&AI<R!L:7-T(@IM<V=S='(@(E]!=7,@9&EE<V5R($QI<W1E(&5N=&9E<FYE
M;B(*"B,Z(&QI8B]4=7)B82YP:'`Z-34Y"FUS9VED(")?4V5A<F-H(@IM<V=S
M='(@(E]3=6-H92(*"B,Z('9C87)D+G!H<#HT-@IM<V=I9"`B8V]N=&%C="YV
M8V8B"FUS9W-T<B`B861R97-S92YV8V8B"@HC.B!D871A+G!H<#HQ.3D@9&%T
M82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B
M8V]N=&%C=',N8W-V(@IM<V=S='(@(F%D<F5S<V5N+F-S=B(*"B,Z(&1A=&$N
M<&AP.C(P.0IM<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@(F%D<F5S<V5N
M+G1S=B(*"B,Z(&1A=&$N<&AP.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM
M<V=S='(@(F%D<F5S<V5N+G9C9B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S@*;7-G:60@(FYO(&9O<FUA='1I;F<B"FUS9W-T<B`B2V5I;F4@1F]R
M;6%T:65R=6YG(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHS
M,@IM<V=I9"`B;F]N92(*;7-G<W1R(")K96EN(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHS,0IM<V=I9"`B=&\@82!#;VYT86-T($QI<W0B
M"FUS9W-T<B`B>G4@96EN97(@2V]N=&%K=&QI<W1E(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B=&\@82!D:69F97)E;G0@
M061D<F5S<R!";V]K(@IM<V=S='(@(GIU(&5I;F5M(&%N9&5R96X@061R97-S
M8G5C:"(*"B,Z(&1A=&$N<&AP.C4Q('1E;7!L871E<R]B<F]W<V4O8V]L=6UN
M7VAE861E<G,N:6YC.C$S"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,34@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B=D-A<F0B
M"FUS9W-T<B`B=D-A<F0B"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M=7)B82]P;R]N;%].3"YP;P``````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#<W,C(V`#$P-#$W,S8R-S4V`#`Q-S4S-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C(%1U<F)A($1U
M=&-H('1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,2!*86X@2W5I
M<&5R<RX*(R!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E
M+FYL/BP@,C`P,2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M
M5F5R<VEO;CH@5'5R8F$@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#0M,3(M,3D@,38Z-#4K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!*
M86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@1'5T8V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN
M(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O
M<'0N:6YC.C0R"B,L(&9U>GIY"FUS9VED("(@061D(&%N($E-4U`@061D<F5S
M<R!";V]K(@IM<V=S='(@(E!I;F4@861R97-B;V5K(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VEM<W!?;W!T+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B($1E;&5T
M92!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R(")N86%R(&=E<V5L96-T965R
M9"!A9')E<V)O96LB"@HC.B!D871A+G!H<#HS,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&%L<F5A9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM<&]R
M=&5D+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U
M<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("(G)7,G('=E<F0@;FEE="!G96MO
M<&EE97)D+"!O;61A="!H970@965N(&QI:G-T(&)E=')E9G0N(@H*(SH@8G)O
M=W-E+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@;F]T(&UO=F5D(&)E8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R
M("(G)7,G('=E<F0@;FEE="!V97)P;&%A='-T+"!O;61A="!H970@965N(&QI
M:G-T(&)E=')E9G0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM
M<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@*&EE+B!*;VAN($1O92DB
M"FUS9W-T<B`B7")6;V]R;F%A;2!!8VAT97)N86%M7"(@*&(N=BX@2F]H;B!$
M;V4I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),
M87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@
M(EPB06-H=&5R;F%A;2P@5F]O<FYA86U<(B`H8BYV+B!$;V4L($IO:&XI(@H*
M(SH@861D+G!H<#HQ,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@861D960N
M(@IM<V=S='(@(B5S('1O96=E=F]E9V0N(@H*(SH@9&%T82YP:'`Z,S0S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R
M=&5D(@IM<V=S='(@(B5S(&)E<W1A;F0@;65T('-U8V-E<R!G96EM<&]R=&5E
M<F0B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!T;W0@
M)7,@=F%N("5S(@H*(SH@;&EB+U1U<F)A+G!H<#HT-#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(E!I
M;F4@861R97-B;V5K(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C0U
M"FUS9VED(")!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E
M<75I<F5D(@IM<V=S='(@(D5E;B!B<F]W<V5R(&UE="!I1G)A;64@;VYD97)S
M=&5U;FEN9R!I<R!V97)E:7-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U.0IM<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T<B`B0F]V96X@
M>F]E:V9O<FUU;&EE<B(*"B,Z('9I97<N<&AP.C4R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('1O("5S(@IM<V=S='(@(B5S
M(&UE="!S=6-C97,@=&]E9V5V;V5G9"!A86X@)7,B"@HC.B!A9&0N<&AP.C4V
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C(*(RP@9G5Z>GD*;7-G
M:60@(D%D9"(*;7-G<W1R(")?5&]E=F]E9V5N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S0*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3VYG96QD:6<@861R97-B;V5K
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X"B,L(&9U>GIY"FUS9VED
M(")!9&0@86YD($1E;&5T92!)35-0(&%D9')E<W,@8F]O:W,B"FUS9W-T<B`B
M1V5S96QE8W1E97)D(&%D<F5S8F]E:R`G)7,G+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M;B(*
M;7-G<W1R(")+;VQO;2!T;V5V;V5G96XB"@HC.B!E9&ET+G!H<#HQ,C@*;7-G
M:60@(D%D9"!F:6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z,C(*;7-G:60@(D%D9"!T;R(*;7-G<W1R(")4;V5V;V5G
M96X@86%N(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#8*(RP@
M9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE(&%D<F5S
M8F]E:R(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B061R
M97-B;V5K(&QI:G-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"B,L
M(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(E!I;F4@861R
M97-B;V5K(@H*(SH@861D+G!H<#HQ,#@*;7-G:60@(D%D9')E<W,@8F]O:R!E
M;G1R>2(*;7-G<W1R(")!9')E<V)O96MI;G9O97(B"@HC.B!D871A+G!H<#HS
M,#4*;7-G:60@(D%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+B(*
M;7-G<W1R(")!9')E<V)O96L@;65T('-U8V-E<R!G96QE96=D+B(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8R"B,L(&9U>GIY"FUS9VED(")!
M9&1R97-S(&)O;VL@=&\@9&5L971E("(*;7-G<W1R(")!9')E<V)O96MI;G9O
M97(B"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC
M.C$W,`HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K<R!T:&%T('=I;&P@
M;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B2&5T(&%D<F5S8F]E:R!K;VX@
M;FEE="!W;W)D96X@9V5L965G9#H@)7,B"@HC.B!S96%R8V@N<&AP.C@X('1E
M;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS-PIM<V=I9"`B061V86YC960@
M4V5A<F-H(@IM<V=S='(@(E5I=&=E8G)E:60@>F]E:V5N(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G:60@(D%L:6%S(@IM<V=S='(@
M(D%L:6%S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z
M-R!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA+FEN8SHQ,`HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0Q"FUS9VED(")!;&PB"FUS9W-T
M<B`B06QL92(*"B,Z(&QI8B]A<&DN<&AP.C4U,@IM<V=I9"`B06QR96%D>2!%
M>&ES=',B"FUS9W-T<B`B0F5S=&%A="!A;"(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R
M(")7965T('4@>F5K97(@9&%T('4@)7,@=VEL="!V97)W:6ID97)E;C\B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8W"FUS9VED(")!
M<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C
M=&5D(&5N=')I97,_(@IM<V=S='(@(E=E970@=2!Z96ME<B!D870@=2!D92!G
M97-E;&5C=&5E<F1E(&EN=F]E<B!W:6QT('9E<G=I:F1E<F5N/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B07-C96YD:6YG(@IM<V=S
M='(@(E1O96YE;65N9"(*"B,Z('-E87)C:"YP:'`Z.#4@=&5M<&QA=&5S+V)R
M;W=S92]S96%R8V@N:6YC.C,V"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T
M<B`B165N=F]U9&EG('IO96ME;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3@*;7-G:60@(D)E;&]W('-E87)C:"!F;W)M(@IM<V=S='(@(D]N9&5R
M('IO96MF;W)M=6QI97(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN
M9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B5F5R8FEN9&EN9R!M:7-L=6MT
M.B`H)7,I("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<X
M"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")697)J86%R9&%G(@H*(SH@=&5M
M<&QA=&5S+VUE;G4N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(D)R;W=S92(*;7-G
M<W1R(")?0FQA9&5R96XB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ-S,*;7-G:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(EIA:V5L
M:6IK92!C871E9V]R:64B"@HC.B!D871A+G!H<#HT.0IM<V=I9"`B0U-6(@IM
M<V=S='(@(D-35B(*"B,Z(&QI8B]/8FIE8W0O1W)O=7`N<&AP.C4W"FUS9VED
M(")#86XG="!A9&0@82!G<F]U<"!T;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C<*;7-G:60@
M(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R(")#;VYT<F]L965R(%]!;&QE<R]'
M965N(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#0*(RP@9G5Z
M>GD*;7-G:60@(D-H;V]S92!A(&YA;64B"FUS9W-T<B`B2VEE<R!E96X@861R
M97-B;V5K(@H*(SH@861D+G!H<#HT.`IM<V=I9"`B0VAO;W-E(&%N(&%D9')E
M<W,@8F]O:R(*;7-G<W1R(")+:65S(&5E;B!A9')E<V)O96LB"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C$*(RP@9G5Z>GD*;7-G
M:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(DMI97,@965N
M(&%D<F5S8F]E:R(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E
M;&5C="YI;F,Z,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K
M<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"B,L(&9U>GIY"FUS9VED(")#
M:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@(DMI
M97,@965N(&%D<F5S8F]E:R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS
M96QE8W0N:6YC.C(R.`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('=H:6-H(&-O
M;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B
M2VEE<R!D92!W965R9V%V979O;&=O<F1E('9A;B!D92!K;VQO;6UE;B!I;B!D
M92!A9')E<VQI:G-T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-PIM
M<V=I9"`B0V]L=6UN($]P=&EO;G,B"FUS9W-T<B`B2V]L;VUO<'1I97,B"@HC
M.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S,*;7-G:60@
M(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3,@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A
M;'5E<R(*;7-G<W1R(")+;VUM82!G97-C:&5I9&5N('=A87)D96XB"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A
M<F%T960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`B2V]M
M;6$@9V5S8VAE:61E;B!W86%R9&5N("A-:6-R;W-O9G0@3W5T;&]O:RDB"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N
M>2(*;7-G<W1R(")"961R:6IF(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,30T"FUS9VED(")#;VUP86YY($%D9')E<W,B"FUS9W-T<B`B0F5D
M<FEJ9G-A9')E<R(*"B,Z(&QI8B]A<&DN<&AP.C,Q."!L:6(O87!I+G!H<#HS
M-C,@;&EB+V%P:2YP:'`Z-#`W(&QI8B]A<&DN<&AP.C0Y,0HC.B!L:6(O87!I
M+G!H<#HV,#$@;&EB+V%P:2YP:'`Z-C@X(&QI8B]A<&DN<&AP.C<T,2!L:6(O
M87!I+G!H<#HX,3D*(SH@;&EB+V%P:2YP:'`Z,3`P-B!L:6(O87!I+G!H<#HQ
M,#DT"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R(")697)B:6YD:6YG(&UI<VQU:W0Z("5S(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HU.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM
M<V=S='(@(E9E<F)I;F1I;F<@;6ES;'5K="(*"B,Z(&)R;W=S92YP:'`Z,3DQ
M(&)R;W=S92YP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")#;VYT86-T(&%D9&5D
M('1O(&QI<W0N(@IM<V=S='(@(D%D<F5S('9A;B!L:6IS="!V97)W:6ID97)D
M+B(*"B,Z(&)R;W=S92YP:'`Z-C`*;7-G:60@(D-O;G1A8W0@<F5M;W9E9"!F
M<F]M(&QI<W0N(@IM<V=S='(@(D%D<F5S('9A;B!L:6IS="!V97)W:6ID97)D
M+B(*"B,Z(&)R;W=S92YP:'`Z,C8V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1A8W1S(&EN(&QI<W0Z("5S(@IM<V=S='(@(D%D<F5S<V5N(&EN(&QI:G-T
M.B`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3(*;7-G
M:60@(D-O<'DB"FUS9W-T<B`B2V]P:>MR96XB"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHU,PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E(@IM<V=S
M='(@(D=E;6%A:W0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHT
M,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")0<FEV92!A9')E<V)O96LB"@HC.B!L:6(O3&ES=%9I97<N<&AP.C,Q-0IM
M<V=I9"`B0W)E871E(&$@;F5W($-O;G1A8W0@3&ES="!I;CHB"FUS9W-T<B`B
M(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S,PIM<V=I9"`B0W)E871E9"(*
M;7-G<W1R(")'96UA86MT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX
M"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R(")3
M=&%N9&%A<F0@<V]R=&5E<G9O;&=O<F1E.B(*"B,Z('1E;7!L871E<R]A9&1R
M97-S8F]O:W,N:6YC.C<V('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,@HC.B!L:6(O3V)J96-T+G!H<#HS,C@@;&EB+U)E;F1E<F5R+G!H<#HT-R!L
M:6(O4F5N9&5R97(N<&AP.C4P"FUS9VED(")$96QE=&4B"FUS9W-T<B`B5F5R
M=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU.`HC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E($%D9')E<W,@0F]O:R(*;7-G<W1R(")3
M96QE8W1E97(@861R97-B;V5K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X"FUS9VED(")$96QE=&4@0V]N9FER;6%T:6]N(@IM<V=S='(@(E9E<G=I
M:F1E<F)E=F5S=&EG:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M"FUS9VED(")$96QE=&4@8G5T=&]N(&)E:&%V:6]U<B(*;7-G<W1R(")697)W
M:6ID97)K;F]P9V5D<F%G(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E(&9A:6QE9#H@*"5S*2`E<R(*
M;7-G<W1R(")697)W:6ID97)E;B!M:7-L=6MT.B`H)7,I("5S(@H*(SH@9&5L
M971E+G!H<#HS.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S='(@(E9E
M<G=I:F1E<F5N(&UI<VQU:W0B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B069D96QI;F<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1E<V-E;F1I
M;F<B"FUS9W-T<B`B069N96UE;F0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O
M;VMS+FEN8SHQ,34*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3@*;7-G:60@(D1I<F5C
M=&]R>2(*;7-G<W1R(")$:7)E8W1O<GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B5V5E
M<F=A=F5O<'1I97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&ES<&QA>2!/
M<'1I;VYS(@IM<V=S='(@(E=E97)G879E;W!T:65S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$W-@IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER
M;2!D96QE=&EN9R!E;G1R:65S/R(*;7-G<W1R(")7:6QT('4@:&5T('9E<G=I
M:F1E<F5N('9A;B!I;G9O97(@8F5V97-T:6=E;C\B"@HC.B!L:6(O3V)J96-T
M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(D1O
M=VYL;V%D('9#87)D(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$W
M('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C4*;7-G:60@(D1O
M=VYL;V%D('9#87)D(@IM<V=S='(@(D1O=VYL;V%D('9#87)D(@H*(SH@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`R('1E;7!L871E<R]B<F]W<V4O
M<F]W+FEN8SHR-0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHQ,"!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*(SH@=&5M
M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,R!L:6(O4F5N9&5R97(N
M<&AP.C0R"FUS9VED(")%9&ET(@IM<V=S='(@(D)E=V5R:V5N(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O8V]N
M=&%C=')O=RYI;F,Z,S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D
M:70@7"(E<UPB(@IM<V=S='(@(B<E<R<@8F5W97)K96XB"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B161I="!!
M9&1R97-S($)O;VMS(@IM<V=S='(@(D%D<F5S8F]E:R!E>'!O<G1E<F5N(@H*
M(SH@961I="YP:'`Z-S@@961I="YP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@96YT<GD@9F]R("5S(@IM<V=S='(@(DEN=F]E<B!B97=E<FME
M;B!V;V]R("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-3@*
M;7-G:60@(D5M86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&5D:70N<&AP.C$T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"P@
M8G5T('-A=FEN9R!T:&4@=7!L;V%D960@9FEL92!F86EL960Z("5S(@IM<V=S
M='(@(B(*"B,Z(&5D:70N<&AP.C$T.2!E9&ET+G!H<#HQ-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960N(@IM<V=S='(@(DEN
M=F]E<B!V;V]R("5S(&)I:F=E=V5R:W0N(@H*(SH@8G)O=W-E+G!H<#HW-`HC
M+"!F=7IZ>0IM<V=I9"`B16YT<GD@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM
M<V=S='(@(B5S(&)E<W1A;F0@;65T('-U8V-E<R!G96EM<&]R=&5E<F0B"@HC
M.B!L:6(O87!I+G!H<#HT,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R('-E87)C:&EN9R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R
M(")4;V5G86YG('1O="!A9')E<V)O96L@;6ES;'5K=#H@)7,B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(D5X<&]R=&5R96XB
M"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*;7-G:60@(D5X<&]R
M="!!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-B;V5K(&5X<&]R=&5R96XB
M"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")%>'!O
M<G0@;VYL>2!T:&4@<V5L96-T960@8V]N=&%C=',N(@IM<V=S='(@(D%L;&5E
M;B!D92!G97-E;&5C=&5E<F1E(&%D<F5S<V5N(&5X<&]R=&5R96XN(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP;W)T('1H
M92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM<V=S='(@
M(DAE="!V;VQG96YD92!A9')E<V)O96L@=F]L;&5D:6<@97AP;W)T97)E;BXB
M"@HC.B!D871A+G!H<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!B
M<F]W<V4N<&AP.C,U(&)R;W=S92YP:'`Z.3`*(SH@8G)O=W-E+G!H<#HQ,3(@
M861D+G!H<#HV-R!S96%R8V@N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T
M<B`B5&]E9V%N9R!T;W0@861R97-B;V5K(&UI<VQU:W0Z("5S(@H*(SH@8G)O
M=W-E+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%D
M9"`E<R!T;R`E<SH@)7,B"FUS9W-T<B`B5&]E=F]E9V5N('9A;B`E<R!A86X@
M)7,@;6ES;'5K=#H@)7,B"@HC.B!B<F]W<V4N<&AP.C(W,@IM<V=I9"`B1F%I
M;&5D('1O(&)R;W=S92!L:7-T(@IM<V=S='(@(D)L861E<F5N(&EN(&QI:G-T
M(&UI<VQU:W0B"@HC.B!B<F]W<V4N<&AP.C,Q,`IM<V=I9"`B1F%I;&5D('1O
M(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM<V=S='(@(D)L861E<F5N(&EN(&1I
M<F5C=&]R>2!M:7-L=6MT(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#D*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C:&%N9V4@
M;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T
M(#T@)7,B"FUS9W-T<B`B5VEJ>FEG96X@=F%N(&YA86T@;6ES;'5K=#H@*"5S
M*2`E<RP@)7,B"@HC.B!B<F]W<V4N<&AP.C$R,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S(@IM
M<V=S='(@(E9I;F1E;B!V86X@=&]E('1E('9O96=E;B!O8FIE8W0@;6ES;'5K
M=#H@)7,B"@HC.B!S96%R8V@N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")&86EL
M960@=&\@<V5A<F-H('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B5&]E9V%N
M9R!T;W0@861R97-B;V5K(&UI<VQU:W0Z("5S(@H*(SH@9&%T82YP:'`Z,30Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I
M<F5C=&]R>3H@)7,B"FUS9W-T<B`B1&]O<GIO96ME;B!V86X@9&ER96-T;W)Y
M("5S(&UI<VQU:W0N(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,38W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@961I="YP:'`Z,3(T
M(&1I<W!L87DN<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B1FEL97,B"FUS9W-T
M<B`B5&ET96PB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S`*
M;7-G:60@(D9I;F0B"FUS9W-T<B`B5FEN9&5N(@H*(SH@961I="YP:'`Z.3<@
M961I="YP:'`Z,3@W"B,L(&9U>GIY"FUS9VED(")&:6YI<V@B"FUS9W-T<B`B
M5FEN9&5N(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G
M:60@(D9I<G-T($YA;64B"FUS9W-T<B`B5F]O<FYA86TB"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HR,#(*;7-G:60@(D9R965B=7-Y(%523"(*
M;7-G<W1R(")&<F5E8G5S>2!54DPB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E
M87)C:"YI;F,Z.#,*;7-G:60@(D9R;VTB"FUS9W-T<B`B5F%N(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`T"FUS9VED(")';&]B86P@061D<F5S
M<R!";V]K(@IM<V=S='(@(D=L;V)A;&4@861R97-B;V5K(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]R;W<N:6YC.C0S('1E;7!L871E<R]B<F]W<V4O8V]N=&%C
M=')O=RYI;F,Z-#0*;7-G:60@(D=R;W5P(@IM<V=S='(@(D=R;V5P(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R(")!9')E<R`H<')I=NDI(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z.3,*;7-G:60@(DAO;64@0VET>2(*;7-G<W1R(")7
M;V]N<&QA871S("AP<FEVZ2DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ,#@*;7-G:60@(DAO;64@0V]U;G1R>2(*;7-G<W1R("),86YD("AP
M<FEVZ2DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G
M:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L+FYR+B`H<')I=NDI(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`S"FUS9VED(")(;VUE(%!O
M<W1A;"!#;V1E(@IM<V=S='(@(E!O<W1C;V1E("AP<FEVZ2DB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`IM<V=I9"`B2&]M92!3=&%T92]0
M<F]V:6YC92(*;7-G<W1R(")3=&%A="!O9B!P<F]V:6YC:64@*'!R:7;I*2(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"B,L(&9U>GIY"FUS
M9VED(")(;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F5S("AP<FEV
MZ2DB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HU,#8*;7-G:60@(DE-
M4U`B"FUS9W-T<B`B24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-PHC+"!F=7IZ>0IM<V=I9"`B24U34"!!9&1R97-S($)O;VL@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B061R97-B;V5K(&QI:G-T(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T<B`B061R97-B;V5K(&EM
M<&]R=&5R96XL('-T87`@)60B"@HC.B!D871A+G!H<#HS-C$*;7-G:60@(DEM
M<&]R="]%>'!O<G0@061D<F5S<R!";V]K<R(*;7-G<W1R(")!9')E<V)O96ME
M;B!I;7!O<G1E<F5N+V5X<&]R=&5R96XB"@HC.B!L:6(O87!I+G!H<#HU.38@
M;&EB+V%P:2YP:'`Z-C@S"FUS9VED("));G9A;&ED($E$(@IM<V=S='(@(D]N
M9V5L9&EG($E$(@H*(SH@;&EB+V%P:2YP:'`Z,C,P(&QI8B]A<&DN<&AP.C0P
M,B!L:6(O87!I+G!H<#HT.#8@;&EB+V%P:2YP:'`Z-3DR"B,Z(&QI8B]A<&DN
M<&AP.C8W.2!L:6(O87!I+G!H<#HW,S$@;&EB+V%P:2YP:'`Z,3`W-PIM<V=I
M9"`B26YV86QI9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3VYG96QD:6<@861R
M97-B;V5K(@H*(SH@;&EB+V%P:2YP:'`Z,3`X,2!L:6(O87!I+G!H<#HQ,34T
M(&QI8B]A<&DN<&AP.C$R,#<*;7-G:60@(DEN=F%L:60@96UA:6PB"FUS9W-T
M<B`B3VYG96QD:6=E(&4M;6%I;"(*"B,Z(&QI8B]A<&DN<&AP.C$P.#D*;7-G
M:60@(DEN=F%L:60@96YT<GDB"FUS9W-T<B`B3VYG96QD:6=E(&EN=F]E<B(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C8V"FUS9VED("));G9A;&ED(&ME
M>2!S<&5C:69I960N(@IM<V=S='(@(D]N9V5L9&EG92!S;&5U=&5L(&]P9V5G
M979E;BXB"@HC.B!L:6(O87!I+G!H<#HQ,#@U"FUS9VED("));G9A;&ED(&YA
M;64B"FUS9W-T<B`B3VYG96QD:6=E(&YA86TB"@HC.B!L:6(O87!I+G!H<#HW
M,S4*;7-G:60@(DEN=F%L:60@;V)J96-T260B"FUS9W-T<B`B3VYG96QD:6<@
M;V)J96-T260B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P"FUS9VED("(B
M"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L
M92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(@IM<V=S='(@(B(*
M(DQ$05`@;VYD97)S=&5U;FEN9R!I<R!V97)E:7-T+"!M86%R(&1E($Q$05`@
M;6]D=6QE(&ES(&YI970@8F5S8VAI:V)A87(@;V8@(@HB;FEE="!G96QA9&5N
M+B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S@*;7-G:60@(DQA<W0@36]D
M:69I960B"FUS9W-T<B`B3&%A='-T(&=E=VEJ>FEG9"(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C4S"FUS9VED("),87-T($YA;64B"FUS9W-T
M<B`B06-H=&5R;F%A;2(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C$V"FUS9VED("),:7-T(@IM<V=S='(@(DQI:G-T(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<W"FUS9VED(")-871C:&EN
M9R(*;7-G<W1R(")O=F5R965N:V]M96YD(&UE="(*"B,Z(&QI8B]A<&DN<&AP
M.C(P-0HC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C
M=',B"FUS9W-T<B`B36%X:6UU;2!A86YT86P@<&%G:6YA)W,N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU;2!N=6UB97(@
M;V8@<&%G97,B"FUS9W-T<B`B36%X:6UU;2!A86YT86P@<&%G:6YA)W,N(@H*
M(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B
M365N=2!,:7-T(@IM<V=S='(@(DYI975W92!L:6IS="(*"B,Z(&QI8B]";&]C
M:R]M:6YI<V5A<F-H+G!H<#HS"FUS9VED(")-:6YI(%-E87)C:"(*;7-G<W1R
M(")-:6YI('IO96ME;B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`R"FUS
M9VED(")-:7-S:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(D]N=&)R96ME;F1E($1.(&EN(&1E($Q$05`@8G)O;F-O;F9I
M9W5R871I92XB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*
M;7-G:60@(DUO8FEL92!0:&]N92(*;7-G<W1R(")-;V)I96QE('1E;&5F;V]N
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,S(@;&EB+T1R:79E<B]L9&%P
M+G!H<#HS-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R(")7:6IZ:6=E;B!M:7-L=6MT.B`H)7,I("5S(@H*
M(SH@;&EB+V%P:2YP:'`Z,3$Y,PIM<V=I9"`B36]R92!T:&%N(#$@96YT<GD@
M9F]U;F0B"FUS9W-T<B`B365E<B!D86X@,2!I;G9O97(@9V5V;VYD96XB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")-;W9E
M(@IM<V=S='(@(E9E<G!L86%T<V5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O
M;'5M;G-E;&5C="YI;F,Z,C0W"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S
M8F]O:W-E;&5C="YI;F,Z,3@T"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B
M3F%A<B!L:6YK<R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(T.0HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N
M:6YC.C$X-@IM<V=I9"`B36]V92!R:6=H="(*;7-G<W1R(").86%R(')E8VAT
M<R(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M,38*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G<W1R(")-=6QB
M97)R>2!A9')E<V)O96LB"@HC.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S
M(%LE<UTL(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B
M"FUS9W-T<B`B(@HB365E<F1E<F4@<&5R<V]N96X@;65T(&%D<F5S(%LE<UTL
M(&UA87(@9V5E;B!M970@;F%A;2!;)7-=(&1I92!A;"!B97-T86%T(@H*(SH@
M8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I9R]S;W5R8V5S+G!H
M<"YD:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S<R!";V]K(@IM
M<V=S='(@(DUI:FX@861R97-B;V5K(@H*(SH@861D<F5S<V)O;VMS+G!H<#HQ
M,C`*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B
M36EJ;B!A9')E<V)O96LB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHQ,#<@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#(*;7-G:60@(DYA
M;64B"FUS9W-T<B`B3F%A;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,0IM<V=I9"`B3F%M92!&;W)M870B"FUS9W-T<B`B3F%A;69O<FUA870B"@HC
M.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HS,34*;7-G:60@(DYE=&-E;G1E
M<B!-96UB97(@1&ER96-T;W)Y(@IM<V=S='(@(DYE=&-E;G1E<B!L961E;F1I
M<F5C=&]R>2(*"B,Z(&%D9"YP:'`Z,S8@861D+G!H<#HQ,C0@;&EB+T)L;V-K
M+VUI;FES96%R8V@N<&AP.C(W"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP
M.C(W"FUS9VED(").97<@0V]N=&%C="(*;7-G<W1R(").:65U=R!A9')E<R(*
M"B,Z(&5D:70N<&AP.C@X(&5D:70N<&AP.CDU(&5D:70N<&AP.C(P,B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@
M(E9O;&=E;F1E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$X
M"FUS9VED(").:6-K;F%M92(*;7-G<W1R(")":6IN86%M(@H*(SH@;&EB+V%P
M:2YP:'`Z,3$Y-2!L:6(O87!I+G!H<#HQ,C0T"B,L('!H<"UF;W)M870*;7-G
M:60@(DYO("5S(&5N=')Y(&9O=6YD(&9O<B`E<R(*;7-G<W1R(")'965N("5S
M(&EN=F]E<B!G979O;F1E;B!V;V]R("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3$V
M,PIM<V=I9"`B3F\@861D<F5S<R!B;V]K<R!F;W5N9"XB"FUS9W-T<B`B1V5E
M;B!A9')E<V)O96ME;B!G979O;F1E;BXB"@HC.B!M:6YI<V5A<F-H+G!H<#HX
M,PIM<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B"FUS9W-T<B`B1V5E;B!A9')E
M<W-E;B!G979O;F1E;B(*"B,Z(&QI8B]A<&DN<&AP.C4Q,2!L:6(O87!I+G!H
M<#HW-C8*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R
M(")'965N('9#87)D(&1A=&$@9V5V;VYD96XN(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]F;V]T97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`B1V5E;B(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$X-`IM<V=I9"`B3F]T
M97,B"FUS9W-T<B`B3F]T:71I97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$U"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T
M<B`B06%N=&%L(&]N9&5R9&5L96X@<&5R('!A9VEN82(*"B,Z(&QI8B]A<&DN
M<&AP.C8Q-"!L:6(O87!I+G!H<#HW-#<*;7-G:60@(D]B:F5C="!N;W0@9F]U
M;F0B"FUS9W-T<B`B3V)J96-T(&YI970@9V5V;VYD96XN(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T
M<B`B2V%N=&]O<B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z
M,C,*;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@
M=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T
M960N($EF('1H:7,@:7,@;F]T('=H870@>6]U('=A;G0L('1H96X@>6]U(&UU
M<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N("(*(G1O(%PB3F]N95PB+B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW-S0*;7-G:60@(D]N;'D@;VYE('9C
M87)D('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B3W1H
M97(@3W!T:6]N<R(*;7-G<W1R(")!;F1E<F4@;W!T:65S(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DP"FUS9VED(")01U`@4'5B;&EC($ME
M>2(*;7-G<W1R(")/<&5N8F%R92!01U`@<VQE=71E;"(*"B,Z(&QI8B]A<&DN
M<&AP.C0Y-2!L:6(O87!I+G!H<#HV,#4@;&EB+V%P:2YP:'`Z-CDR(&QI8B]A
M<&DN<&AP.CDS-`HC.B!L:6(O87!I+G!H<#HQ,#DX"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R(")4;V5G86YG(&=E=V5I9V5R9"(*"B,Z(&QI
M8B]$<FEV97(N<&AP.C4T,PIM<V=I9"`B4&5R;6ES<VEO;B!D96YI960B"FUS
M9W-T<B`B5&]E9V%N9R!G97=E:6=E<F0B"@HC.B!T96UP;&%T97,O861D<F5S
M<V)O;VMS+FEN8SHY.0HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B5&]E9V%N9R!G97=E:6=E<F0B"@HC.B!D871A+G!H<#HU,R!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")0:6YE($%D9')E<W,@
M0F]O:R(*;7-G<W1R(")0:6YE(&%D<F5S8F]E:R(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*(RP@9G5Z>GD*;7-G:60@(E!L96%S
M92!N86UE('1H92!N97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R(")'965F(&1E
M(&YA86T@=F%N(&1E(&YI975W92!L:6IS="P@82YU+F(Z(@H*(SH@961I="YP
M:'`Z.3$@961I="YP:'`Z.30@961I="YP:'`Z,3DT"FUS9VED(")0<F5V:6]U
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HT,38*
M;7-G:60@(E!R:79A=&4@061D<F5S<R!";V]K(@IM<V=S='(@(E!R:79E(&%D
M<F5S8F]E:R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30W"B,L('!H<"UF
M;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")1
M=65R>2!M:7-L=6MT.B`H)7,I("5S(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI
M;FES96%R8V@N:6YC.C$X"FUS9VED(")1=6EC:R!396%R8V@B"FUS9W-T<B`B
M4VYE;"!Z;V5K96XB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$Y,2!L:6(O
M1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD87`N<&AP.C0R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G
M<W1R("),97IE;B!M:7-L=6MT.B`H)7,I("5S(@H*(SH@;&EB+U)E;F1E<F5R
M+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS
M9VED(")296-O<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`B4F5C;W)D<R!W965R
M9V5G979E;CHB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE
M8W0N:6YC.C$W-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&%D9')E<W,@8F]O
M:R(*;7-G<W1R(")+:65S(&5E;B!A9')E<V)O96LB"@HC.B!T96UP;&%T97,O
M<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,SD*;7-G:60@(E)E;6]V92!C;VQU
M;6XB"FUS9W-T<B`B2V]L;VT@=F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@(E)E;6]V92!F<F]M('1H:7,@
M;&ES="(*;7-G<W1R(")5:70@9&5Z92!L:6IS="!V97)W:6ID97)E;BXB"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(Q"B,L(&9U>GIY"FUS9VED
M("(B"B)297!L86-E(&5X:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I
M;7!O<G1E9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S
M(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN/"]S
M=')O;F<^(@IM<V=S='(@(B(*(E9E<G9A;F<@:&5T(&)E<W1A86YD92!A9')E
M<V)O96L@9&]O<B!H970@9V5I;7!O<G1E97)D92!A9')E<V)O96L_("(*(CQB
M/E=A87)S8VAU=VEN9SH@1&ET('9E<G=I:F1E<G0@86QL92!I;G9O97(@=F%N
M('5W(&AU:61I9V4@861R97-B;V5K+CPO8CXB"@HC.B!L:6(O1')I=F5R+G!H
M<#HT,S@*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!86YG979R86%G9"!O8FIE8W0@;FEE="!G979O;F1E;BXB"@HC.B!A
M9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G
M:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(DAE<G-T96P@<W1A;F1A
M87)D:6YS=&5L;&EN9V5N(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I9FEC871E(@IM<V=S
M='(@(D]P96YB86%R(%,O34E-12!C97)T:69I8V%A="(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z-CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-4
M05)45$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("),97IE;B!M:7-L=6MT
M.B`H)7,I("5S(@H*(SH@961I="YP:'`Z.3D@861D+G!H<#HS-R!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHQ,C0*;7-G:60@(E-A=F4B"FUS9W-T<B`B
M3W!S;&%A;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$R"B,Z('1E;7!L871E<R]B
M;&]C:R]M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HT.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R
M8V@B"FUS9W-T<B`B6F]E:V5N(@H*(SH@;6EN:7-E87)C:"YP:'`Z-C,*(RP@
M9G5Z>GD*;7-G:60@(E-E87)C:"!297-U;'1S.B(*;7-G<W1R("):;V5K<F5S
M=6QT871E;B(*"B,Z(&QI8B]A<&DN<&AP.C$P,3$*;7-G:60@(E-E87)C:"!F
M86EL960B"FUS9W-T<B`B6F]E:V5N(&UI<VQU:W0B"@HC.B!L:6(O87!I+G!H
M<#HQ,3`S(&QI8B]A<&DN<&AP.C$Q,#D@;&EB+V%P:2YP:'`Z,3$Q."!L:6(O
M87!I+G!H<#HQ,3,Q"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:"!F86EL
M960Z("5S(@IM<V=S='(@(EIO96ME;B!M:7-L=6MT.B`E<R(*"B,Z('1E;7!L
M871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,@IM<V=I9"`B4V5A<F-H:6YG
M+BXN(@IM<V=S='(@(EIO96ME;BXN+B(*"B,Z('1E;7!L871E<R]A9&1R97-S
M8F]O:W,N:6YC.C8V"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@861D<F5S
M<R!B;V]K('1O(&1E;&5T92(*;7-G<W1R(")396QE8W1E97(@:&5T(&%D<F5S
M8F]E:R!O;2!V86YU:70@=&4@97AP;W)T97)E;CHB"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N
M(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(E-E;&5C=&5E<B!D92!A
M9V5N9&$@;VT@;F%A<B!T92!I;7!O<G1E<F5N.B(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,S(*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B
M;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G<W1R(")396QE8W1E97(@:&5T(&%D
M<F5S8F]E:R!O;2!V86YU:70@=&4@97AP;W)T97)E;CHB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C(V"FUS9VED(")396QE8W0@=&AE(&%D9')E
M<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(E-E;&5C=&5E<B!D92!A
M9V5N9&$@;VT@;F%A<B!T92!I;7!O<G1E<F5N.B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,S4*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@
M8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E-E;&5C=&5E
M<B!H970@9F]R;6%A="!V86X@:&5T(&)R;VYB97-T86YD.B(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,3`*;7-G:60@(E-E;&5C="!T:&4@97AP
M;W)T(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-T965R(&AE="!E>'!O<G1F;W)M
M86%T.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#,*;7-G:60@
M(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(E-E;&5C=&5E
M<B!H970@:6UP;W)T8F5S=&%N9#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U
M<F-E(&9I;&4Z(@IM<V=S='(@(E-E;&5C=&5E<B!H970@9F]R;6%A="!V86X@
M:&5T(&)R;VYB97-T86YD.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S4*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N
M86UE<SHB"FUS9W-T<B`B4V5L96-T965R(&AE="!F;W)M86%T('9O;W(@:&5T
M('=E97)G979E;B!V86X@;F%M96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y
M(&)Y(&1E9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS
M+B(*;7-G<W1R(")396QE8W1E97(@9&4@<W1A;F1A87)D=V5E<F=A=F4N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")396QE8W0@=VAI
M8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N(@IM
M<V=S='(@(E-E;&5C=&5E<B!W96QK92!V96QD96X@=V]R9&5N('=E97)G96=E
M=F5N(&EN(&1E(&%D<F5S;&EJ<W1E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S(*;7-G:60@(E-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA
M>2!N86UE<RXB"FUS9W-T<B`B4V5L96-T965R(&AE="!F;W)M86%T('9O;W(@
M:&5T('=E97)G979E;B!V86X@;F%M96XN(@H*(SH@861D+G!H<#HU-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K
M(%PB)7-<(BXB"FUS9W-T<B`B1V5S96QE8W1E97)D(&%D<F5S8F]E:R`G)7,G
M+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B4VAA
M<F5D($1I<F5C=&]R>2(*;7-G<W1R(")'961E96QD92!D:7)E8W1O<GDB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3:&]W("5S(@IM<V=S='(@(E=E97)G979E;B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H
M;W<@06QL(@IM<V=S='(@(D%L;&4@=V5E<F=E=F5N(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B4VAO=R!#;VYT86-T<R(*
M;7-G<W1R(")!9')E<W-E;B!W965R9V5V96XB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")3:&]W($QI<W1S(@IM<V=S='(@
M(DQI:G-T96X@=V5E<F=E=F5N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU
M;6Y?:&5A9&5R<RYI;F,Z,C$*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?
M:&5A9&5R<RYI;F,Z,S0*;7-G:60@(E-O<G0@1&ER96-T:6]N(@IM<V=S='(@
M(E-O<G1E97)V;VQG;W)D92(*"B,Z(&QI8B]A<&DN<&AP.C$Y.`IM<V=I9"`B
M4V]U<F-E<R(*;7-G<W1R(")"<F]N;F5N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U-PIM<V=I9"`B4W!E8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A
M;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N(@IM<V=S='(@(D]P9V5V
M96X@=V%A<B!U(&1E(&=E879A;F-E97)D92!Z;V5K<F5S=6QT871E;B!W:6QT
M(&QA=&5N('9E<G-C:&EJ;F5N+B(*"B,Z(&)R;W=S92YP:'`Z,30Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<R(*
M;7-G<W1R("(E<R!M970@<W5C8V5S('1O96=E=F]E9V0@86%N("5S(@H*(SH@
M8G)O=W-E+G!H<#HR,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*
M;7-G<W1R("(E<R!M970@<W5C8V5S('1O96=E=F]E9V0@86%N("5S(@H*(SH@
M9&%T82YP:'`Z-3`*;7-G:60@(E135B(*;7-G<W1R(")44U8B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,30*;7-G:60@(E1A8B!S97!A<F%T960@=F%L=65S(@IM<V=S='(@
M(E1A8B!G97-C:&5I9&5N('=A87)D96XB"@HC.B!V:65W+G!H<#HQ-0IM<V=I
M9"`B5&AE(%9&4R!B86-K96YD(&YE961S('1O(&)E(&-O;F9I9W5R960@=&\@
M96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z,3`U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(DAE="!A9')E<V)O96L@:V]N(&YI970@=V]R9&5N(&=E;&5E9V0Z("5S
M(@H*(SH@861D<F5S<V)O;VMS+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!9')E<V)O96L@;65T('-U8V-E<R!G
M96QE96=D+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-S`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB('=A<R!R
M96UO=F5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B061R97-B;V5K(&UE="!S
M=6-C97,@9V5L965G9"XB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C@Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<
M(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S='(@(D%D<F5S8F]E
M:R!M970@<W5C8V5S(&=E;&5E9V0N(@H*(SH@9&%T82YP:'`Z,S`S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E
M('!U<F=E9#H@)7,B"FUS9W-T<B`B2&5T(&%D<F5S8F]E:R!K;VX@;FEE="!W
M;W)D96X@9V5L965G9#H@)7,B"@HC.B!E9&ET+G!H<#HT-R!V8V%R9"YP:'`Z
M,C(@9&ES<&QA>2YP:'`Z,C,@=FEE=RYP:'`Z,C8*;7-G:60@(E1H92!C;VYT
M86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DAE
M="!G979R86%G9&4@861R97,@8F5S=&%A="!N:65T+B(*"B,Z(&5D:70N<&AP
M.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@7"(E
M<UPB(&AA<R!S=6-C97-S9G5L;'D@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(E
M<R!B97-T86YD(&UE="!S=6-C97,@9V5I;7!O<G1E97)D(@H*(SH@9&%T82YP
M:'`Z,C@T"FUS9VED(")4:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P
M:71E('1H92!W87)N:6YG<RXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HS
M,0IM<V=I9"`B5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K
M<RXB"FUS9W-T<B`B17(@>FEJ;B!G965N(&1O;W(@=&4@8FQA9&5R96X@861R
M97-B;V5K96XN(@H*(SH@861D+G!H<#HR.0IM<V=I9"`B(@HB5&AE<F4@87)E
M(&YO('=R:71E86)L92!A9&1R97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I
M;&%B;&4@861D<F5S<R!B;V]K<R`B"B)A<F4@8V]N9FEG=7)E9"!T;R!A;&QO
M=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S('1O('1H96TN($EF('EO=2!B96QI
M979E('1H:7,@(@HB:7,@86X@97)R;W(L('!L96%S92!C;VYT86-T('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D5R('II:FX@9V5E
M;B!B97-C:')I:F9B87)E(&%D<F5S8F]E:V5N+B!'965N('9A;B!D92!B97-C
M:&EK8F%R92!A9')E<V)O96ME;B`B"B)Z:6IN(&=E8V]N9FEG=7)E97)D('9O
M;W(@:&5T('1O979O96=E;B!V86X@;FEE=7=E(&EN=F]E<BX@5V%N;F5E<B!U
M(&1E;FMT("(*(F1A="!D:70@965N(&9O=70@8F5T<F5F="P@;F5E;2!D86X@
M8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E<BXB"@HC.B!A9&0N
M<&AP.C$R,0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T
M:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)%<B!H965F
M="!Z:6-H(&5E;B!F;W5T('9O;W)G961A86X@8FEJ(&AE="!T;V5V;V5G96X@
M=F%N(&AE="!N:65U=V4@861R97,N("(*(DYE96T@8V]N=&%C="!O<"!M970@
M=7<@<WES=&5E;6)E:&5E<F1E<B!V;V]R('9E<F1E<F4@:'5L<"XB"@HC.B!B
M<F]W<V4N<&AP.C$X.2!B<F]W<V4N<&AP.C(S,`HC+"!F=7IZ>0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T
M<B`B165N(&9O=70@8FEJ(&AE="!V97)W:6ID97)E;B!V86X@9&ET(&]B:F5C
M="XB"@HC.B!B<F]W<V4N<&AP.C(S.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N(@IM<V=S='(@(D5E;B!F;W5T(&)I
M:B!H970@;6%K96X@=F%N(&5E;B!N:65U=V4@;&EJ<W0N(@H*(SH@861D<F5S
M<V)O;VMS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E
M<R(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&)I:G=E<FME;B!V86X@9&5Z
M92!I;G9O97(Z("5S(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<
M(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M165N(&9O=70@8FEJ(&AE="!V97)W:6ID97)E;B!V86X@)7,@=6ET(&AE="!B
M<F]N861R97-B;V5K+B(*"B,Z(&1E;&5T92YP:'`Z,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N
M=&%C=#H@)7,B"FUS9W-T<B`B165N(&9O=70@8FEJ(&AE="!V97)W:6ID97)E
M;B!V86X@9&ET(&%D<F5S.B`E<R(*"B,Z(&)R;W=S92YP:'`Z-S(*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C="XB"FUS
M9W-T<B`B165N(&9O=70@8FEJ(&AE="!V97)W:6ID97)E;B!V86X@9&ET(&]B
M:F5C="XB"@HC.B!B<F]W<V4N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AE(&QI<W0B"FUS9W-T<B`B
M165N(&9O=70@8FEJ(&AE="!W965R9V5V96X@=F%N(&1E(&=E<V5L96-T965R
M9&4@;&EJ<W0B"@HC.B!D871A+G!H<#HS,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,B
M"FUS9W-T<B`B165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D92!D
M871A.B`E<R(*"B,Z(&QI8B]A<&DN<&AP.C4P-R!L:6(O87!I+G!H<#HW-C$*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R
M96X@=F%N(&1E(&E#86QE;F1A<F1A=&$N(@H*(SH@8G)O=W-E+G!H<#HU.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG(&$@
M8V]N=&%C="!F<F]M('1H92!L:7-T+B(*;7-G<W1R(")%96X@9F]U="!B:6H@
M:&5T(&UA:V5N('9A;B!E96X@;FEE=7=E(&QI:G-T+B(*"B,Z(&%D9')E<W-B
M;V]K<RYP:'`Z-34@861D<F5S<V)O;VMS+G!H<#HV,"!A9&1R97-S8F]O:W,N
M<&AP.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@<F5M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S
M='(@(D5E;B!F;W5T(&)I:B!H970@=F5R=VEJ9&5R96X@=F%N(&1I="!O8FIE
M8W0N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX,2!A9&1R97-S8F]O:W,N<&AP
M.C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@
M(D5E;B!F;W5T(&)I:B!H970@8FEJ=V5R:V5N('9A;B!D97IE(&EN=F]E<CH@
M)7,B"@HC.B!E9&ET+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT<GDZ("5S(@IM<V=S
M='(@(D5E;B!F;W5T(&)I:B!H970@8FEJ=V5R:V5N('9A;B!D97IE(&EN=F]E
M<CH@)7,B"@HC.B!D871A+G!H<#HQ-SD*;7-G:60@(E1H97)E('=E<F4@;F\@
M861D<F5S<V5S('1O(&5X<&]R="XB"FUS9W-T<B`B17(@=V%R96X@9V5E;B!A
M9')E<W-E;B!O;2!T92!E>'!O<G1E<F5N+B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R
M97-S(&)O;VMS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#,*
M;7-G:60@(E1H97-E(&-O;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D
M97(Z(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F
M:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")$:70@8F5S
M=&%N9'-F;W)M86%T('=O<F1T(&YI970@;VYD97)S=&5U;F0N(@H*(SH@;&EB
M+V%P:2YP:'`Z,3$R,B!L:6(O87!I+G!H<#HQ,3,U"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@
M=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")$97IE('!E<G-O;VX@:&5E9G0@
M<F5E9',@965N("5S(&EN=F]E<B!I;B!H970@861R97-B;V5K(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T-PIM<V=I9"`B(@HB5&AI<R!W:6QL(&)E
M('1H92!D969A=6QT(&%D9')E<W,@8F]O:R!W:&5N(&%D9&EN9R!O<B!I;7!O
M<G1I;F<@8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C<P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71E;"(*
M"B,Z(&QI8B]4=7)B82YP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@;F5W('-H87)E+B`@36ES<VEN9R!S;W5R8V4@='EP
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z.3<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R(").:65T(&EN('-T86%T(&]M(&1E(&1E9FEN:71I92!V
M86X@)7,@=&4@;&%D96XN(@H*(SH@961I="YP:'`Z.#@@961I="YP:'`Z.3$@
M961I="YP:'`Z.30@961I="YP:'`Z.3D@961I="YP:'`Z,3DV"FUS9VED(")5
M;F1O($-H86YG97,B"FUS9W-T<B`B2&5R<W1E;"!W:6IZ:6=I;F=E;B(*"B,Z
M(&QI8B]A<&DN<&AP.C4T,"!L:6(O87!I+G!H<#HV-#,@;&EB+V%P:2YP:'`Z
M-S<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#
M;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(DYI970@;VYD97)S=&5U;F0@0V]N
M=&5N="U4>7!E+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,W-@IM
M<V=I9"`B5F5R:7-I9VX@1&ER96-T;W)Y(@IM<V=S='(@(E9E<FES:6=N(&1I
M<F5C=&]R>2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP
M;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W(%PB)7-<(B(*;7-G<W1R("(G)7,G(&)E:VEJ
M:V5N(@H*(SH@;6EN:7-E87)C:"YP:'`Z-S@*;7-G:60@(E9I97<@0V]N=&%C
M="(*;7-G<W1R(")!9')E<R!W965R9V5V96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(T"FUS9VED(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L
M=#HB"FUS9W-T<B`B4W1A;F1A87)D=V5E<F=A=F4Z(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,C`X"FUS9VED(")796)S:71E(%523"(*;7-G
M<W1R(")796)S:71E(%523"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$Q,PIM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(E=E<FMA9')E
M<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R-`IM<V=I9"`B
M5V]R:R!#:71Y(@IM<V=S='(@(E=O;VYP;&%A=',@*'=E<FLI(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,Y"FUS9VED(")7;W)K($-O=6YT
M<GDB"FUS9W-T<B`B3&%N9"`H=V5R:RDB"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5L
M+FYR+B`H=V5R:RDB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M,S0*;7-G:60@(E=O<FL@4&]S=&%L($-O9&4B"FUS9W-T<B`B5&5L+FYR+B`H
M=V5R:RDB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*;7-G
M:60@(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B4W1A870@;V8@<')O
M=FEN8VEE("AW97)K*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=')E970@061D<F5S<R(*;7-G
M<W1R(")797)K861R97,B"@HC.B!D871A+G!H<#HR,S<@8G)O=W-E+G!H<#HY
M,R!B<F]W<V4N<&AP.C(P,2!A9&0N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP
M.C8Y(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB"FUS
M9W-T<B`B52!H965F="!G965N(')E8VAT(&]M(&1I="!A9')E<R!T92!B96MI
M:FME;BXB"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(E4@
M:&5E9G0@9V5E;B!R96-H="!O;2!D:70@;V)J96-T('1E(&)E:VEJ:V5N+B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-34*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(E4@9&EE;G0@965N(&1O96QA9')E<V)O96L@=&4@<V5L96-T97)E;BXB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S"FUS9VED
M(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB"FUS9W-T<B`B52!D
M:65N="!E96X@9&]E;&QI:G-T('1E('-E;&5C=&5R96XN(@H*(SH@961I="YP
M:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S
M="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B52!D:65N="!T96YM:6YS
M=&4@965R<W0@Z>EN(&EN=F]E<B!T92!S96QE8W1E<F5N+B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S
M92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@
M;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R(")5(&1I96YT('1E;FUI;G-T92!E
M97)S="#IZ6X@:6YV;V5R('1E('-E;&5C=&5R96XN(@H*(SH@961I="YP:'`Z
M-S,*;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H
M:7,@8V]N=&%C="XB"FUS9W-T<B`B52!H965F="!A;&QE96X@<F5C:'0@;VT@
M9&ET(&%D<F5S('1E(&)E:VEJ:V5N+B(*"B,Z(&)R;W=S92YP:'`Z,C@U"FUS
M9VED(")9;W5R(&1E9F%U;'0@861D<F5S<R!B;V]K(&ES(&YO="!B<F]W<V5A
M8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z
M-B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS9VED(");
M;F\@=F%L=65=(@IM<V=S='(@(EMG965N('=A87)D95TB"@HC.B!L:6(O5'5R
M8F$N<&AP.C0X-`IM<V=I9"`B7T)R;W=S92(*;7-G<W1R(")?0FQA9&5R96XB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"B,L(&9U>GIY
M"FUS9VED(")?0V]N=&%C=',B"FUS9W-T<B`B7T%D<F5S<V5N('=E97)G979E
M;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@IM<V=I9"`B
M7T1E;&5T92(*;7-G<W1R(")697)?=VEJ9&5R96XB"@HC.B!L:6(O5'5R8F$N
M<&AP.C0Y,PIM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R
M="]%>'!O<G0B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y
M"B,L(&9U>GIY"FUS9VED(")?3&ES=',B"FUS9W-T<B`B3&EJ<W0B"@HC.B!L
M:6(O5'5R8F$N<&AP.C0X,0HC+"!F=7IZ>0IM<V=I9"`B7TUY($%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`B36EJ;B!A9')E<V)O96LB"@HC.B!L:6(O5'5R8F$N
M<&AP.C0X-PHC+"!F=7IZ>0IM<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S='(@
M(DYI975W(&%D<F5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHR"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(E]5
M:70@9&5Z92!L:6IS="!V97)W:6ID97)E;BXB"@HC.B!L:6(O5'5R8F$N<&AP
M.C0X.0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?6F]E:V5N(@H*(SH@=F-A
M<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R(")C;VYT86-T
M<RYV8V8B"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S
M='(@(F-O;G1A8W1S+F-S=B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B8V]N
M=&%C=',N='-V(@IM<V=S='(@(F-O;G1A8W1S+G1S=B(*"B,Z(&1A=&$N<&AP
M.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(F-O
M;G1A8W1S+G9C9B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z
M,S0*(RP@9G5Z>GD*;7-G:60@(FYO;F4B"FUS9W-T<B`B1V5E;B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@
M(G1O(&$@0V]N=&%C="!,:7-T(@IM<V=S='(@(D%D<F5S<V5N('=E97)G979E
M;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,30*(RP@9G5Z
M>GD*;7-G:60@(G1O(&$@9&EF9F5R96YT($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")N86%R(&=E<V5L96-T965R9"!A9')E<V)O96LB"@HC.B!D871A+G!H<#HU
M,2!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ,PHC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,34*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O<&\O:F%?2E`N<&\`````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W-C0V,``Q
M,#0Q-S,V,C<U-@`P,3<U,3<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!*87!A;F5S92!T<F%N<VQA=&EO;B!F;W(@5'5R
M8F$N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*(R!4:&ES
M(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A
M<R!T:&4@5'5R8F$@<&%C:V%G92X*(R!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`
M=&%C+G1S=6MU8F$N86,N:G`^"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ(%1U<F)A(#(N,%QN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#4M,#$M,3,@,#@Z,#`K,#DP,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N:G`^7&XB
M"B),86YG=6%G92U496%M.B!*87!A;F5S92`\=6YK;F]W;D!U;FMN;W=N+F1O
M;6%I;CY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]4TA)1E1?2DE37&XB"B)#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O<')E9G,O
M:6US<%]O<'0N:6YC.C0R"B,L(&9U>GIY"FUS9VED("(@061D(&%N($E-4U`@
M061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@C&".KH+,@T&#:(.,@UB2H"(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S$*(RP@9G5Z>GD*
M;7-G:60@(B!$96QE=&4@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`BD4F1
M\(*S@NJ"O8-!@VB#C(-8DJ""UB(*"B,Z(&1A=&$N<&AP.C,R-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR96%D>2!E>&ES=',@86YD('=A<R!N
M;W0@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(V"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A
M=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@;6]V960@
M8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@(EPB1FER<W1N86UE($QA<W1N86UE
M7"(@("AI92X@2F]H;B!$;V4I(@IM<V=S='(@(EPBD*D@EKQ<(BQ<(D9I<G-T
M;F%M92!,87-T;F%M95PB(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L($IO
M:&XI(@IM<V=S='(@(EPBEKPL()"I7"(L7"),87-T;F%M92P@1FER<W1N86UE
M7"(B"@HC.B!A9&0N<&AP.C$P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M9&1E9"XB"FUS9W-T<B`B)7,@@O"2QXG!@K6"W(*U@KV!0B(*"B,Z(&1A=&$N
M<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F
M=6QL>2!I;7!O<G1E9"(*;7-G<W1R("(E<R"#=(-`@T.#BX*J@T.#DX-\@5N#
M9X*S@NJ"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#0V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE((Q@
MCJZ"S(-!@VB#C(-8DJ`B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z
M-#4*;7-G:60@(D$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B:49R86UE<R""\(-4@WR!6X-G@K>"Z8-U@XF#
M18-5@JJ52Y=V@L6"MR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3D*
M;7-G:60@(D%B;W9E('-E87)C:"!F;W)M(@IM<V=S='(@(HR?C?6#=(-(@5N#
M@(+,C^,B"@HC.B!V:65W+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B06-C97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R("(E<R""S2`E<R""
MR9+'B<&"LX+J@MR"M8*](@H*(SH@861D+G!H<#HU-B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C(R"B,L(&9U>GIY"FUS9VED(")!9&0B"FUS9W-T
M<B`B7T&2QXG!(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L
M96-T+FEN8SHQ-S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB
M"FUS9W-T<B`BE7.0LX+(@T&#:(.,@UB2H(+%@K<B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!A;F0@1&5L971E
M($E-4U`@861D<F5S<R!B;V]K<R(*;7-G<W1R("*129'P@K."ZH*]@T&#:(.,
M@UB2H"`G)7,G@4(B"@HC(&US9W-T<B`BBF>2HXR?C?4B"B,Z('1E;7!L871E
M<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M
M;B(*;7-G<W1R("*7\8+,DL>)P2(*"B,Z(&5D:70N<&AP.C$R.`IM<V=I9"`B
M061D(&9I;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHR,@IM<V=I9"`B061D('1O(@IM<V=S='(@(H*Q@K&"R9+'B<$B
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F=7IZ>0IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@C&".KH+,@T&#:(.,
M@UB2H"(*"B,@;7-G<W1R("*2QXG!(@HC.B!B<F]W<V4N<&AP.C(X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C4*;7-G:60@(D%D9')E<W,@0F]O:R!,:7-T
M:6YG(@IM<V=S='(@(H-!@VB#C(-8DJ"(ZI>7(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VMS(@IM
M<V=S='(@(E!I;F4@C&".KH+,@T&#:(.,@UB2H"(*"B,Z(&%D9"YP:'`Z,3`X
M"FUS9VED(")!9&1R97-S(&)O;VL@96YT<GDB"FUS9W-T<B`B@T&#:(.,@UB2
MH(V`EMHB"@HC.B!D871A+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(D%D9')E
M<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+B(*;7-G<W1R("(E<R"#=(-`
M@T.#BX*J@T.#DX-\@5N#9X*S@NJ"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C8R"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(&)O
M;VL@=&\@9&5L971E("(*;7-G<W1R("*#08-H@XR#6)*@C8"6VB(*"B,@;7-G
M<W1R("*#7H-U@L6+YI#8@N>"ZH*]@V:!6X->(@HC.B!T96UP;&%T97,O<')E
M9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`HC+"!F=7IZ>0IM<V=I9"`B
M061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS
M9W-T<B`B@T&#:(.,@UB2H(+PC\&+CH+%@JN"W(*Y@O&"Q8*U@KTZ("5S(@H*
M(SH@<V5A<F-H+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z
M,S<*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R("*/VHW7C)^-]2(*
M"B,@;7-G<W1R("**9Y*CC)^-]2(*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-C0*;7-G:60@(D%L:6%S(@IM<V=S='(@(I7*EKPB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA+FEN8SHW('1E;7!L871E<R]B<F]W
M<V4O9F]O=&5R06QP:&$N:6YC.C$P"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z-#$*;7-G:60@(D%L;"(*;7-G<W1R("*14X+$(@H*(SH@;&EB
M+V%P:2YP:'`Z-34R"FUS9VED(")!;')E861Y($5X:7-T<R(*;7-G<W1R("**
M^8+)D;:-W8*U@MR"MR(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP
M="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('1H
M870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R("*6>Y.6@LD@)7,@
M@O"-[8^<@K6"Q(+@@J*"HH+%@K>"J8%((@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]J879A<V-R:7!T+FEN8SHV-PIM<V=I9"`B07)E('EO=2!S=7)E('1H870@
M>6]U('=A;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/R(*;7-G
M<W1R("*129'P@K."ZH*]C8"6VH+PEGN3EH+)C>V/G(*U@MR"MX*I@4@B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*;7-G:60@(D%S8V5N9&EN9R(*
M;7-G<W1R("*/N(^'(@H*(SH@<V5A<F-H+G!H<#HX-2!T96UP;&%T97,O8G)O
M=W-E+W-E87)C:"YI;F,Z,S8*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R
M("**R(C5C)^-]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G
M:60@(D)E;&]W('-E87)C:"!F;W)M(@IM<V=S='(@(HR?C?6#=(-(@5N#@(+,
MB;HB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z("@E
M<RD@)7,B"FUS9W-T<B`B@V^#0X.3@VB.N)1S.B`H)7,I("5S(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A>2(*
M;7-G<W1R("*289"VD_HB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PHC+"!F
M=7IZ>0IM<V=I9"`B0G)O=W-E(@IM<V=S='(@(E]"B7N7ER(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@0V%T
M96=O<GDB"FUS9W-T<B`BD$6+QI6JE]XB"@HC.B!D871A+G!H<#HT.0IM<V=I
M9"`B0U-6(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W0O1W)O=7`N<&AP.C4W
M"FUS9VED(")#86XG="!A9&0@82!G<F]U<"!T;R!I='-E;&8N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C<*
M;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E
M(&$@;F%M92(*;7-G<W1R("*#08-H@XR#6)*@@O"129'P(@H*(SH@861D+G!H
M<#HT.`IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R("*#
M08-H@XR#6)*@@O"129'P(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E
M;&5C="YI;F,Z,C(Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@861D<F5S
M<R!B;V]K.B(*;7-G<W1R("*#08-H@XR#6)*@@O"129'P(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-C4*;7-G:60@(D-H
M;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W
M:&%T(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O
M;VMS('1O('5S92XB"FUS9W-T<B`B@T&#:(.,@UB2H(+PD4F1\"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R.`HC+"!F=7IZ>0IM
M<V=I9"`B0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@
M=VAA="!O<F1E<CHB"FUS9W-T<B`B@T&#:(.,@UB(ZI>7@LF57(ZF@K>"Z9?Q
M@LR/AY34@O"129'P@K6"Q(FZ@K."HH%"(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$W"FUS9VED(")#;VQU;6X@3W!T:6]N<R(*;7-G<W1R("*57(ZF
ME_&#28-V@U:#AX.3(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C
M="YI;F,Z,C,S"FUS9VED(")#;VQU;6YS('1H870@=VEL;"!N;W0@8F4@9&ES
M<&QA>65D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$S('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(D-O
M;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B@U*#DX-]B^:0V(+HC&".
MKB(*"B,@;7-G<W1R("*#2H.3@WV"Q8OFD-B"YX+J@KV#9H%;@UXB"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R
M871E9"!V86QU97,@*$UI8W)O<V]F="!/=71L;V]K*2(*;7-G<W1R("*#4H.3
M@WV+YI#8@NB,8(ZN("A-:6-R;W-O9G0@3W5T;&]O:RDB"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R
M("*)[X[0(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"FUS
M9VED(")#;VUP86YY($%D9')E<W,B"FUS9W-T<B`BB>^.T(]:CXHB"@HC.B!L
M:6(O87!I+G!H<#HS,3@@;&EB+V%P:2YP:'`Z,S8S(&QI8B]A<&DN<&AP.C0P
M-R!L:6(O87!I+G!H<#HT.3$*(SH@;&EB+V%P:2YP:'`Z-C`Q(&QI8B]A<&DN
M<&AP.C8X."!L:6(O87!I+G!H<#HW-#$@;&EB+V%P:2YP:'`Z.#$Y"B,Z(&QI
M8B]A<&DN<&AP.C$P,#8@;&EB+V%P:2YP:'`Z,3`Y-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BD-J1L8ZX
ME',Z("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(I#:D;&.N)1S(@H*(SH@8G)O=W-E
M+G!H<#HQ.3$@8G)O=W-E+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(D-O;G1A
M8W0@861D960@=&\@;&ES="XB"FUS9W-T<B`BF$&7C9#F@LV#BH-8@V>"J8+G
MC>V/G(*S@NJ"W(*U@KV!0B(*"B,Z(&)R;W=S92YP:'`Z-C`*;7-G:60@(D-O
M;G1A8W0@<F5M;W9E9"!F<F]M(&QI<W0N(@IM<V=S='(@(IA!EXV0YH+-@XJ#
M6(-G@JF"YXWMCYR"LX+J@MR"M8*]@4(B"@HC.B!B<F]W<V4N<&AP.C(V-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&%C=',@:6X@;&ES=#H@
M)7,B"FUS9W-T<B`BD-J1L8ZXE',Z("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B0V]P>2(*;7-G<W1R("*#4H-S@5LB
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU,PHC+"!F=7IZ>0IM
M<V=I9"`B0W)E871E(@IM<V=S='(@(HWLD*PB"@HC(&US9W-T<B`B@V:#0H.,
M@TZ#9X.*@O"129'P@K6"Q(FZ@K."HCHB"B,Z('1E;7!L871E<R]A9&1R97-S
M8F]O:W,N:6YC.C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@061D<F5S<R!"
M;V]K(@IM<V=S='(@(HS"D&R328-!@VB#C(-8DJ`B"@HC.B!L:6(O3&ES=%9I
M97<N<&AP.C,Q-0IM<V=I9"`B0W)E871E(&$@;F5W($-O;G1A8W0@3&ES="!I
M;CHB"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S,PIM<V=I
M9"`B0W)E871E9"(*;7-G<W1R("*-[)"L(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDX"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*
M;7-G<W1R("*#9H-T@TB#BX-G@LR5P(+1CX>!1B(*"B,@;7-G<W1R("*#9H-T
M@TB#BX-G@LR#7(%;@V>5^XS\@48B"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C<V('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@HC.B!L
M:6(O3V)J96-T+G!H<#HS,C@@;&EB+U)E;F1E<F5R+G!H<#HT-R!L:6(O4F5N
M9&5R97(N<&AP.C4P"FUS9VED(")$96QE=&4B"FUS9W-T<B`BC>V/G"(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C4X"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@061D<F5S<R!";V]K(@IM<V=S='(@(H-!@VB#C(-8DJ""S)%)
MD?`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T
M92!#;VYF:7)M871I;VXB"FUS9W-T<B`BC>V/G(+,BFV41B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B1&5L971E(&)U='1O;B!B96AA
M=FEO=7(B"FUS9W-T<B`BC>V/G(-[@UZ#DX+,DZZ-["(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!F
M86EL960Z("@E<RD@)7,B"FUS9W-T<B`BC>V/G(+%@JN"W(*Y@O&"Q8*U@KTZ
M("@E<RD@)7,B"@HC.B!D96QE=&4N<&AP.C,X"FUS9VED(")$96QE=&EO;B!F
M86EL960B"FUS9W-T<B`BC>V/G(+%@JN"W(*Y@O&"Q8*U@KTB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B
M"FUS9W-T<B`BE92/D"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("*-?H^'(@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z,3$U"FUS9VED(")$97-C<FEP=&EO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$X"FUS
M9VED(")$:7)E8W1O<GDB"FUS9W-T<B`BD&R6O)7K(@H*(R!M<V=S='(@(H-F
M@T*#C(-.@V>#BB(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U
M>GIY"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(I5<CJ:#28-V@U:#AX.3(@H*
M(R!M<V=S='(@(H-F@T*#C(-.@V>#BB(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("*57(ZF@TF#=H-6@X>#DR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D1O('EO=2!W86YT
M('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T<B`BC8"6VH+P
MC>V/G(*W@NF-VX+)BFV41H*U@MR"MX*I@4@B"@HC.B!L:6(O3V)J96-T+G!H
M<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E9#87)D
M((+,@U^#18.3@XV!6X-H(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC
M.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C4*;7-G:60@
M(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(E9#87)D((+,@U^#18.3@XV!6X-H
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`R('1E;7!L871E
M<R]B<F]W<V4O<F]W+FEN8SHR-0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M
M;E]H96%D97)S+FEN8SHQ,"!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C,*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,R!L:6(O
M4F5N9&5R97(N<&AP.C0R"FUS9VED(")%9&ET(@IM<V=S='(@(I72CU<B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4@=&5M<&QA=&5S+V)R;W=S
M92]C;VYT86-T<F]W+FEN8SHS,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!<(B5S7"(B"FUS9W-T<B`B)R5S)R""S)72CU<B"@HC(&US9W-T
M<B`BCY&"JX]O@K4B"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C@Q
M"B,L(&9U>GIY"FUS9VED(")%9&ET($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B
M@T&#:(.,@UB2H(+,@T>#3H-8@WR!6X-G(@H*(SH@961I="YP:'`Z-S@@961I
M="YP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@96YT<GD@9F]R
M("5S(@IM<V=S='(@(B5S((V`EMJ"S)72CU<B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B@X&!6X.+
M@T&#:(.,@U@B"@HC.B!E9&ET+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B16YT<GD@9F]R("5S('5P9&%T960L(&)U="!S879I;F<@=&AE('5P;&]A
M9&5D(&9I;&4@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC(&US9W-T<B`B@X&!
M6X.+(@HC.B!E9&ET+G!H<#HQ-#D@961I="YP:'`Z,34R"B,L('!H<"UF;W)M
M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+B(*;7-G<W1R("(E<R""
MS(V`EMJ"\(U8D%:"M8+<@K6"O8%"(@H*(SH@8G)O=W-E+G!H<#HW-`HC+"!F
M=7IZ>0IM<V=I9"`B16YT<GD@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(B5S((-T@T"#0X.+@JJ#0X.3@WR!6X-G@K."ZH+<@K6"O8%"(@H*(SH@
M;&EB+V%P:2YP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!S96%R8VAI;F<@=&AE(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B
M@T&#:(.,@UB2H(+)D-J1L8+%@JN"W(*Y@O&"Q8*U@KTZ("5S(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*;7-G<W1R("*#1X-.@UB#?(%;
M@V<B"@HC(&US9W-T<B`BCY&"JX]O@K4B"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z-@IM<V=I9"`B17AP;W)T($%D9')E<W,@0F]O:R(*;7-G<W1R
M("*#08-H@XR#6)*@@LR#1X-.@UB#?(%;@V<B"@HC(&US9W-T<B`B@T&#:(.,
M@UB2H(+,CY&"JX]O@K4B"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T<RXB
M"FUS9W-T<B`BD4F1\(*S@NJ"O8+@@LR"OH*O@T>#3H-8@WR!6X-G@K>"Z8%"
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP
M;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM
M<V=S='(@(HC(B;J"S(-!@VB#C(-8DJ""S)%3@L2"S)/@EV6"\(-'@TZ#6(-\
M@5N#9X*W@NF!0B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H<#HR,C@@9&%T
M82YP:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY,`HC.B!B<F]W
M<V4N<&AP.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K
M.B`E<R(*;7-G<W1R("*#08-H@XR#6)*@@LF0VI&Q@L6"JX+<@KF"\8+%@K6"
MO3H@)7,B"@HC.B!B<F]W<V4N<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@861D("5S('1O("5S.B`E<R(*;7-G<W1R("(E<R""\"`E
M<R""R9+'B<&"Q8*K@MR"N8+Q.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,C<R"FUS
M9VED(")&86EL960@=&\@8G)O=W-E(&QI<W0B"FUS9W-T<B`B@XJ#6(-G@LR)
M>Y>7@LF.N)1S@K6"W(*U@KTB"@HC(&US9W-T<B`B@XJ#6(-G@LR)>Y>7@JJ"
MQ8*K@MR"N8+Q@L6"M8*]@4(B"B,Z(&)R;W=S92YP:'`Z,S$P"FUS9VED(")&
M86EL960@=&\@8G)O=W-E('1H92!D:7)E8W1O<GDB"FUS9W-T<B`BD&R6O)7K
M@LR)>Y>7@LF.N)1S@K6"W(*U@KTB"@HC(&US9W-T<B`B@V:#0H.,@TZ#9X.*
M@LR)>Y>7@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(B"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,S`Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@
M/2`E<RP@4F]O="`]("5S(@IM<V=S='(@(I:\D4^"S)7/C5B"R8ZXE'."M8+<
M@K6"O3H@*"5S*2`E<RP@)7,B"@HC.B!B<F]W<V4N<&AP.C$R,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D
M960Z("5S(@IM<V=S='(@(I+'B<&"MX+7@JN#28-U@U>#1H-.@V>"JHRIE72"
MJ8+H@MR"N8+Q.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*(RP@9G5Z>GD*;7-G
M:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("*#08-H@XR#6)*@@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O3H@)7,B"@HC.B!D
M871A+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O('-E
M87)C:"!T:&4@9&ER96-T;W)Y.B`E<R(*;7-G<W1R("*0;):\E>N"\(R?C?6"
MQ8*K@MR"N8+Q@L6"M8*].B`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$V-PIM<V=I9"`B1F%X(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP
M.C$R-"!D:7-P;&%Y+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D9I;&5S(@IM
M<V=S='(@(HRHCY$B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z
M-S`*;7-G:60@(D9I;F0B"FUS9W-T<B`BC)^-]2(*"B,Z(&5D:70N<&AP.CDW
M(&5D:70N<&AP.C$X-PHC+"!F=7IZ>0IM<V=I9"`B1FEN:7-H(@IM<V=S='(@
M(HR?C?4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT.`IM<V=I
M9"`B1FER<W0@3F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HR,#(*;7-G:60@(D9R965B=7-Y(%523"(*;7-G<W1R("*7
M7)+HC^Z5\2!54DPB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z
M.#,*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(R!M<V=S='(@(HVWCV^0;"(*
M(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`T"FUS9VED(")';&]B86P@
M061D<F5S<R!";V]K(@IM<V=S='(@(HU,B.:#08-H@XR#6)*@(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C0S('1E;7!L871E<R]B<F]W<V4O8V]N
M=&%C=')O=RYI;F,Z-#0*;7-G:60@(D=R;W5P(@IM<V=S='(@(H-/@XN!6X-V
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO
M;64@061D<F5S<R(*;7-G<W1R("*.J9'N@LR/6H^*(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z.3,*;7-G:60@(DAO;64@0VET>2(*;7-G<W1R
M("*.J9'N@LR.<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P
M.`IM<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@(HZID>Z"S(V1(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34P"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(HZID>Z"S)-DF&*4U(V&(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3`S"FUS9VED(")(;VUE(%!O<W1A;"!#;V1E(@IM
M<V=S='(@(HZID>Z"S)=8E=:4U(V&(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z.3@*;7-G:60@(DAO;64@4W1A=&4O4')O=FEN8V4B"FUS9W-T
M<B`BCJF1[H+,CT*!7HRG(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z.#@*(RP@9G5Z>GD*;7-G:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS
M9W-T<B`BCJF1[H+,CUJ/BB(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C4P-@IM<V=I9"`B24U34"(*;7-G<W1R("(B"@HC(&US9W-T<B`BDL>)P2(*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W"B,L(&9U>GIY"FUS9VED("))
M35-0($%D9')E<W,@0F]O:R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*#08-H
M@XR#6)*@B.J7ER(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D<F5S<R!";V]K+"!3=&5P
M("5D(@IM<V=S='(@(H-!@VB#C(-8DJ""S(-#@Y.#?(%;@V>!08-8@V6#8H-V
M("5D(@H*(SH@9&%T82YP:'`Z,S8Q"FUS9VED("));7!O<G0O17AP;W)T($%D
M9')E<W,@0F]O:W,B"FUS9W-T<B`B@T&#:(.,@UB2H(+,@T.#DX-\@5N#9X%>
M@T>#3H-8@WR!6X-G(@H*(SH@;&EB+V%P:2YP:'`Z-3DV(&QI8B]A<&DN<&AP
M.C8X,PIM<V=I9"`B26YV86QI9"!)1"(*;7-G<W1R("*5<Y"S@L@@240@@L6"
MMR(*"B,Z(&QI8B]A<&DN<&AP.C(S,"!L:6(O87!I+G!H<#HT,#(@;&EB+V%P
M:2YP:'`Z-#@V(&QI8B]A<&DN<&AP.C4Y,@HC.B!L:6(O87!I+G!H<#HV-SD@
M;&EB+V%P:2YP:'`Z-S,Q(&QI8B]A<&DN<&AP.C$P-S<*;7-G:60@(DEN=F%L
M:60@861D<F5S<R!B;V]K(@IM<V=S='(@(I5SD+."R(-!@VB#C(-8DJ""Q8*W
M(@H*(SH@;&EB+V%P:2YP:'`Z,3`X,2!L:6(O87!I+G!H<#HQ,34T(&QI8B]A
M<&DN<&AP.C$R,#<*;7-G:60@(DEN=F%L:60@96UA:6PB"FUS9W-T<B`BE7.0
MLX+(@X&!6X.+@T&#:(.,@UB"Q8*W(@H*(R!M<V=S='(@(H.!@5N#BX-!@VB#
MC(-8@JJ5<Y"S@L6"MX%"(@HC.B!L:6(O87!I+G!H<#HQ,#@Y"FUS9VED("))
M;G9A;&ED(&5N=')Y(@IM<V=S='(@(I5SD+."R)/\E\V"Q8*W(@H*(R!M<V=S
M='(@(I/\E\V2;(*JE7.0LX+%@K>!0B(*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HR-C8*;7-G:60@(DEN=F%L:60@:V5Y('-P96-I9FEE9"XB"FUS9W-T<B`B
ME7.0LX+(@TR#0X*JCG>2Z(*S@NJ"W(*U@KV!0B(*"B,Z(&QI8B]A<&DN<&AP
M.C$P.#4*;7-G:60@(DEN=F%L:60@;F%M92(*;7-G<W1R("*5<Y"S@LB6O)%/
M@L6"MR(*"B,@;7-G<W1R("*6O)%/@JJ5<Y"S@L6"MX%"(@HC.B!L:6(O87!I
M+G!H<#HW,S4*;7-G:60@(DEN=F%L:60@;V)J96-T260B"FUS9W-T<B`BE7.0
MLX+(@TF#=8-7@T:#3H-G240@@L6"MR(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@
M=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E
M9"XB"FUS9W-T<B`B(@HB3$1!4"""S(-4@WR!6X-G@JJ52Y=V@L6"MX*J@4%,
M1$%0((."@U>#A8%;@XN"JI:S@J*"J8.-@5N#:(+%@JN"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S@*;7-G:60@(DQA<W0@36]D
M:69I960B"FUS9W-T<B`BC<6/297/C5@B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HU,PHC+"!F=7IZ>0IM<V=I9"`B3&%S="!.86UE(@IM<V=S
M='(@(I:\D4\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B3&ES="(*;7-G<W1R("*05HM+@XJ#
M6(-G(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<W"FUS9VED
M(")-871C:&EN9R(*;7-G<W1R("*"JHZ?@LF(ZI)V@K>"Z2(*"B,Z(&QI8B]A
M<&DN<&AP.C(P-0HC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@
M0V]N=&%C=',B"FUS9W-T<B`BC<61Y8+,@WF!6X-7D)0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!P
M86=E<R(*;7-G<W1R("*-Q9'E@LR#>8%;@U>0E"(*"B,Z(&QI8B]";&]C:R]T
M<F5E7VUE;G4N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@3&ES="(*;7-G
M<W1R("*05HM+@XJ#6(-G(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP
M.C,*;7-G:60@(DUI;FD@4V5A<F-H(@IM<V=S='(@(HK(B-6,GXWU(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI<W-I;F<@1$X@:6X@
M3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"FUS9VED(")-;V)I;&4@4&AO
M;F4B"FUS9W-T<B`BC&>1T9-DF&(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(I7/C5B.N)1S
M.B`H)7,I("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y,PIM<V=I9"`B36]R92!T
M:&%N(#$@96YT<GD@9F]U;F0B"FUS9W-T<B`B@E""PHC(C^."H(+H@MR"MR(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3$*;7-G:60@(DUO
M=F4B"FUS9W-T<B`BB-J3KB(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS
M96QE8W0N:6YC.C(T-PHC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS
M96QE8W0N:6YC.C$X-`IM<V=I9"`B36]V92!L969T(@IM<V=S='(@(HVV@LF(
MVI.N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V
M"FUS9VED(")-;W9E(')I9VAT(@IM<V=S='(@(HE%@LF(VI.N(@H*(SH@9&%T
M82YP:'`Z-3(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-@IM<V=I9"`B
M375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(DUU;&)E<G)Y((Q@CJZ"
MS(-!@VB#C(-8DJ`B"@HC.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE
M<UTL(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I
M9R]S;W5R8V5S+G!H<"YD:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B37D@061D
M<F5S<R!";V]K(@IM<V=S='(@(HZ$@LR#08-H@XR#6)*@(@H*(SH@861D<F5S
M<V)O;VMS+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O
M:W,B"FUS9W-T<B`BCH2"S(-!@VB#C(-8DJ`B"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M-#(*;7-G:60@(DYA;64B"FUS9W-T<B`BEKR13R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,0IM<V=I9"`B3F%M92!&;W)M870B"FUS9W-T<B`BEKR1
M3X+,C&".KB(*"B,@;7-G<W1R("*6O)%/@LR57(ZFC&".KB(*(SH@8V]N9FEG
M+W-O=7)C97,N<&AP+F1I<W0Z,S$U"FUS9VED(").971C96YT97(@365M8F5R
M($1I<F5C=&]R>2(*;7-G<W1R(").971C96YT97(@@X&#DX-O@5N"S)!LEKR5
MZR(*"B,Z(&%D9"YP:'`Z,S8@861D+G!H<#HQ,C0@;&EB+T)L;V-K+VUI;FES
M96%R8V@N<&AP.C(W"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(W"FUS
M9VED(").97<@0V]N=&%C="(*;7-G<W1R("*05HM+F$&7C9#F(@H*(SH@961I
M="YP:'`Z.#@@961I="YP:'`Z.34@961I="YP:'`Z,C`R('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z-#4*;7-G:60@(DYE>'0B"FUS9W-T<B`BCI\B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*;7-G:60@(DYI8VMN
M86UE(@IM<V=S='(@(H-J@V*#3H-L@5N#@"(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M.34@;&EB+V%P:2YP:'`Z,3(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`E
M<R!E;G1R>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B)7,@@LT@)7,@@LF"H(+H
M@MR"N8+Q(@H*(SH@;&EB+V%P:2YP:'`Z,3$V,PIM<V=I9"`B3F\@861D<F5S
M<R!B;V]K<R!F;W5N9"XB"FUS9W-T<B`B@T&#:(.,@UB2H(*JC*F5=(*I@NB"
MW(*Y@O&!0B(*"B,Z(&UI;FES96%R8V@N<&AP.C@S"FUS9VED(").;R!C;VYT
M86-T<R!F;W5N9"(*;7-G<W1R("*809>-D.:"JHRIE72"J8+H@MR"N8+Q(@H*
M(SH@;&EB+V%P:2YP:'`Z-3$Q(&QI8B]A<&DN<&AP.C<V-@IM<V=I9"`B3F\@
M=D-A<F0@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(G9#87)D((-F@5N#7H*J
MC*F5=(*I@NB"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R
M+FEN8SHW"FUS9VED(").;VYE(@IM<V=S='(@(H+(@K4B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM<V=S='(@
M(I*-BTPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(").
M=6UB97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T<B`B,8-Y@5N#5X+,C8"6
MVI"4(@H*(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<T-PIM<V=I
M9"`B3V)J96-T(&YO="!F;W5N9"(*;7-G<W1R("*#28-U@U>#1H-.@V>"JHRI
ME72"J8+H@MR"N8+Q(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T<B`BB>^.T"(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N8V4@>6]U('-A
M=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E
M('!E<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@;F]T('=H870@
M>6]U('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N
M("(*(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW
M-S0*;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-@IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R("*"NX+,
MD;R"S(-)@W:#5H.'@Y,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"",]HI*
MC*XB"@HC.B!L:6(O87!I+G!H<#HT.34@;&EB+V%P:2YP:'`Z-C`U(&QI8B]A
M<&DN<&AP.C8Y,B!L:6(O87!I+G!H<#HY,S0*(SH@;&EB+V%P:2YP:'`Z,3`Y
M.`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B@T&#3H-:@UB"
MJHN1E-N"LX+J@MR"M8*](@H*(SH@;&EB+T1R:79E<BYP:'`Z-30S"FUS9VED
M(")097)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("*#08-.@UJ#6(*JBY&4VX*S
M@NJ"W(*U@KTB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY.0HC
M+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B@T&#3H-:@UB"
MJHN1E-N"LX+J@MR"M8*](@H*(SH@9&%T82YP:'`Z-3,@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B4&EN92!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B4&EN92",8(ZN@LR#08-H@XR#6)*@(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]J879A<V-R:7!T+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E
M(&YA;64@=&AE(&YE=R!C;VYT86-T(&QI<W0Z(@IM<V=S='(@(I!6BTN#BH-8
M@V>"S):\D4^"\)/\E\V"M8+$B;J"LX*B@48B"@HC.B!E9&ET+G!H<#HY,2!E
M9&ET+G!H<#HY-"!E9&ET+G!H<#HQ.30*;7-G:60@(E!R979I;W5S(@IM<V=S
M='(@(B(*"B,@;7-G<W1R("*#9H-"@XR#3H-G@XJ"\)%)D?""M8+$B;J"LX*B
M.B(*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-#$V"FUS9VED(")0<FEV
M871E($%D9')E<W,@0F]O:R(*;7-G<W1R("*,PI!LDTF#08-H@XR#6)*@(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B475E<GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(I;B@J*-AX+M@KF.
MN)1S.B`H)7,I("5S(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N
M:6YC.C$X"FUS9VED(")1=6EC:R!396%R8V@B"FUS9W-T<B`BBLB(U8R?C?4B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$Y,2!L:6(O1')I=F5R+VQD87`N
M<&AP.C$Y.2!L:6(O1')I=F5R+VQD87`N<&AP.C0R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("*3QXV>@MV.
MN)1S.B`H)7,I("5S(@H*(SH@;&EB+U)E;F1E<F5R+G!H<#HT.0IM<V=I9"`B
M4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S(&1I
M<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E
M<W-B;V]K<V5L96-T+FEN8SHQ-S8*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B@T&#:(.,@UB2H(+PD4F1\"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S.0IM<V=I9"`B4F5M
M;W9E(&-O;'5M;B(*;7-G<W1R("*7\8+PC>V/G"(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z,@IM<V=I9"`B4F5M;W9E(&9R;VT@=&AI<R!L
M:7-T(@IM<V=S='(@(H.*@UB#9X*I@N>*3X*W(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B(@HB4F5P;&%C92!E
M>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\
M<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@96YT<FEE<R!I
M;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R;VYG/B(*;7-G<W1R
M("(B"B*#0X.3@WR!6X-G@L6*^9&V@LR#08-H@XR#6)*@@O"2=8*KBK>"IH+<
M@K>"J8%((#QB/HQXC9"!1H*[@J2"MX+I@L:,NXW=@LR#08-H(@HB@XR#6)*@
M@LR3X)=E@LV14X+$CKB"[8+J@MR"MX%"/"]B/B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C0S.`IM<V=I9"`B4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N(@IM
M<V=S='(@(I=VBX&"LX+J@KV#28-U@U>#1H-.@V>"S8RIE72"J8+H@MR"N8+Q
M@L6"M8*]@4(B"@HC.B!A9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A
M<F-H+FEN8SHQ,3,*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@
M(H-F@W2#2(.+@V>"R9;?@K<B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ.38*;7-G:60@(E,O34E-12!0=6)L:6,@0V5R=&EF:6-A=&4B"FUS
M9W-T<B`B4R]-24U%((SVBDJ/V):^CY$B"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C8Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")35$%25%1,4R!F
M86EL960Z("@E<RD@)7,B"FUS9W-T<B`BD\>-GH+=CKB4<SH@*"5S*2`E<R(*
M"B,Z(&5D:70N<&AP.CDY(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S='(@(I7;D;8B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.38@=&5M<&QA=&5S+V)R;W=S
M92]S96%R8V@N:6YC.C$Q,@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C
M:"YI;F,Z,C$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z-#D*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(HR?
MC?4B"@HC.B!M:6YI<V5A<F-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4V5A
M<F-H(%)E<W5L=',Z(@IM<V=S='(@(HR?C?6,BXG*(@H*(SH@;&EB+V%P:2YP
M:'`Z,3`Q,0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R("*,GXWUCKB4
M<R(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#,@;&EB+V%P:2YP:'`Z,3$P.2!L:6(O
M87!I+G!H<#HQ,3$X(&QI8B]A<&DN<&AP.C$Q,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T<B`BC)^-]8ZXE',Z("5S
M(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(R"FUS9VED
M(")396%R8VAI;F<N+BXB"FUS9W-T<B`BC)^-]9*&("XN+B(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C8V"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@86X@861D<F5S<R!B;V]K('1O(&1E;&5T92(*;7-G<W1R("*#1X-.@UB#
M?(%;@V>"MX+I@T&#:(.,@UB2H(+PD4F1\(*U@L2"K8*^@K."HCHB"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(H-#@Y.#
M?(%;@V>0YH+,@T&#:(.,@UB2H(+PD4F1\(*U@L2"K8*^@K."HCHB"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C,R"FUS9VED(")396QE8W0@=&AE
M(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T<B`B@T>#3H-8
M@WR!6X-G@K>"Z8-!@VB#C(-8DJ""\)%)D?""M8+$@JV"OH*S@J(Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR-@IM<V=I9"`B4V5L96-T('1H
M92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.B(*;7-G<W1R("*#0X.3@WR!
M6X-GD.:"S(-!@VB#C(-8DJ""\)%)D?""M8+$@JV"OH*S@J(Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B
MC+."S(-T@T"#0X.+@LR,8(ZN@O"129'P@K6"Q(FZ@K."HCHB"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P"FUS9VED(")396QE8W0@=&AE(&5X
M<&]R="!F;W)M870Z(@IM<V=S='(@(H-'@TZ#6(-\@5N#9X*W@NF,8(ZN@O"1
M29'P@K6"Q(*M@KZ"LX*B.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI
M;F,Z-#,*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S
M='(@(H-#@Y.#?(%;@V>"MX+I@W2#0(-#@XN"\)%)D?""M8+$@JV"OH*S@J(Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0IM<V=I9"`B4V5L
M96-T('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("*,
MLX+,@W2#0(-#@XN"S(Q@CJZ"\)%)D?""M8+$B;J"LX*B.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T
M('5S960@=&\@9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`BE5R.IH+,C&".KH+P
MD4F1\(*U@L2"K8*^@K."HCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C4*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!V:65W('1O(&1I<W!L87D@8GD@
M9&5F875L="P@<V]R="!O<'1I;VYS+"!A;F0@<&%G:6YG(&]P=&EO;G,N(@IM
M<V=S='(@(H-F@W2#2(.+@V>"S)5<CJ:)YI;*@O"129'P@K6"W(*W@4(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-E;&5C="!W:&EC
M:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS
M9W-T<B`B@T&#:(.,@UB"S(CJEY>"Q95<CJ:"MX+IE_&"\)%)D?""M8+<@K>!
M0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L96-T
M('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R("*6O)%/
M@LR57(ZFC&".KH+PD4F1\(*U@MR"MX%"(@H*(SH@861D+G!H<#HU-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K
M(%PB)7-<(BXB"FUS9W-T<B`BD4F1\(*S@NJ"O8-!@VB#C(-8DJ`@)R5S)X%"
M(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3<S"FUS9VED(")3:&%R
M960@1&ER96-T;W)Y(@IM<V=S='(@(HNDETR"S)!LEKR5ZR(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`BE5R.IB(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H;W<@06QL(@IM<V=S
M='(@(I%3@L257(ZF(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT,`IM<V=I9"`B4VAO=R!#;VYT86-T<R(*;7-G<W1R("*809>-D.:"S)5<
MCJ8B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"FUS9VED
M(")3:&]W($QI<W1S(@IM<V=S='(@(H.*@UB#9X+,E5R.IB(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C(Q"B,Z('1E;7!L871E
M<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C,T"FUS9VED(")3;W)T($1I
M<F5C=&EO;B(*;7-G<W1R("*5P(+1CX<B"@HC(&US9W-T<B`B@UR!6X-GE?N,
M_"(*(SH@;&EB+V%P:2YP:'`Z,3DX"FUS9VED(")3;W5R8V5S(@IM<V=S='(@
M(H-<@5N#6"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3<*;7-G:60@
M(E-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V86YC960@<V5A<F-H(')E<W5L
M=',@=&\@87!P96%R+B(*;7-G<W1R("*/VHW7C)^-]8+,C(N)RH+P@L>"L8+)
ME5R.IH*W@NF"J8YWDNB"M8+$B;J"LX*B@4(B"@HC.B!B<F]W<V4N<&AP.C$T
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@)7,@
M=&\@)7,B"FUS9W-T<B`B)7,@@LT@)7,@@LF2QXG!@K."ZH+<@K6"O2(*"B,Z
M(&)R;W=S92YP:'`Z,C(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@8W)E871E9"!T:&4@8V]N=&%C="!L:7-T(%PB)7-<(BXB
M"FUS9W-T<B`B)7,@@LT@)7,@@LF2QXG!@K."ZH+<@K6"O2(*"B,Z(&1A=&$N
M<&AP.C4P"FUS9VED(")44U8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$T
M"FUS9VED(")486(@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("*#7H-UB^:0
MV(+HC&".KB(*"B,Z('9I97<N<&AP.C$U"FUS9VED(")4:&4@5D93(&)A8VME
M;F0@;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@871T86-H;65N
M="!U<&QO861S+B(*;7-G<W1R("(B"@HC(&US9W-T<B`B@UZ#=8+%B^:0V(+G
M@NJ"O8-F@5N#7B(*(SH@;&EB+T1R:79E<BYP:'`Z,3`U-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(H-!@VB#C(-8DJ""\(_!BXZ"Q8*K@MR"
MN8+Q@L6"M8*].B`E<R(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB
M('=A<R!C<F5A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B@K&"S(-!@VB#
MC(-8DJ""S9/'CV^"M9#JEW""Q8*W(@H*(SH@861D<F5S<V)O;VMS+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<
M(B!W87,@<F5M;W9E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&%D
M9')E<W-B;V]K<RYP:'`Z.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D
M9')E<W,@8F]O:R!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*
M;7-G<W1R("(B"@HC(&US9W-T<B`B@UZ#=8+%B^:0V(+G@NJ"O8-F@5N#7B(*
M(SH@9&%T82YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R
M97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B@T&#
M:(.,@UB2H(+PC\&+CH+%@JN"W(*Y@O&"Q8*U@KTZ("5S(@H*(SH@961I="YP
M:'`Z-#<@=F-A<F0N<&AP.C(R(&1I<W!L87DN<&AP.C(S('9I97<N<&AP.C(V
M"FUS9VED(")4:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R("*7=HN!@K."ZH*]F$&7C9#F@LV1MHW=@K6"W(*Y@O&!
M0B(*"B,Z(&5D:70N<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("(E<R"#=(-`@T.#BX*J@T.#DX-\@5N#9X*S@NJ"W(*U
M@KV!0B(*"B,Z(&1A=&$N<&AP.C(X-`IM<V=I9"`B5&AE(&EM<&]R="!C86X@
M8F4@9FEN:7-H960@9&5S<&ET92!T:&4@=V%R;FEN9W,N(@IM<V=S='(@(B(*
M"B,Z(&)R;W=S92YP:'`Z,S$*;7-G:60@(E1H97)E(&%R92!N;R!B<F]W<V5A
M8FQE(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@(HE[EY>)PI1<@LB#08-H@XR#
M6)*@@LV"H(+H@MR"N8+Q@4(B"@HC.B!A9&0N<&AP.C(Y"FUS9VED("(B"B)4
M:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@
M=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS("(*(F%R92!C;VYF:6=U<F5D
M('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@
M>6]U(&)E;&EE=F4@=&AI<R`B"B)I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A
M8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBCY&"
MJXV>@MV)PI1<@LB#08-H@XR#6)*@@LV"H(+H@MR"N8+Q@4*"H(+(@KV"JI!6
M@K6"HHV`EMJ"\)+'B<&"Q8*K@NF"YH*D@LB#02(*(H-H@XR#6)*@@LV7<(C3
M@K."ZH+$@J*"W(*Y@O&!0H*[@NJ"JHK4B.&"HH*^@L:.=H*D@LB"YX%!@U:#
M6(-E@X"*QY>=CM*"R8*HEN(B"B*"HHV'@NV"N8*M@KZ"LX*B@4(B"@HC.B!A
M9&0N<&AP.C$R,0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN
M9R!T:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B*809>-
MD.:"S)+'B<&2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0H_:C=>"R8+"@J*"
MQ(+-@U:#6(-E@X"*QY>=CM*"R8*HEN*"HHV'(@HB@NV"N8*M@KZ"LX*B@4(B
M"@HC.B!B<F]W<V4N<&AP.C$X.2!B<F]W<V4N<&AP.C(S,`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&ES(&]B:F5C="XB
M"FUS9W-T<B`B@TF#=8-7@T:#3H-GC>V/G)*&@LF#1X.)@5N"JI2MD+:"M8+<
M@K6"O8%"(@H*(SH@8G)O=W-E+G!H<#HR,S@*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R("*05HM+@XJ#
M6(-GC>R0K(Z>@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"(@H*(SH@861D<F5S
M<V)O;VMS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E
M<R(*;7-G<W1R("*"L8+,C8"6VH+,C5B05I*&@LF#1X.)@5N"JH*@@NB"W(*U
M@KTZ("5S(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<(B5S7"(@
M9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B@T&#:(.,
M@UB2H(*I@N<@)7,@C>V/G)*&@LF#1X.)@5N"JH*@@NB"W(*U@KV!0B(*"B,Z
M(&1E;&5T92YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`B
M@K&"S)A!EXV0YH+,C>V/G)*&@LF#1X.)@5N"JH*@@NB"W(*U@KTZ("5S(@H*
M(SH@8G)O=W-E+G!H<#HW,@IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R("*#28-U@U>#1H-.@V>-[8^<
MDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4(B"@HC.B!B<F]W<V4N<&AP.C(W
M.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AE(&QI<W0B"FUS9W-T<B`B@XJ#6(-GE5R.II*&@LF#1X.)@5N"JI2M
MD+:"M8+<@K6"O2(*"B,Z(&1A=&$N<&AP.C,S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E
M<R(*;7-G<W1R("*#9H%;@UZ"S(-#@Y.#?(%;@V>2AH+)@T>#B8%;@JJ4K9"V
M@K6"W(*U@KTZ("5S(@H*(SH@;&EB+V%P:2YP:'`Z-3`W(&QI8B]A<&DN<&AP
M.C<V,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<B""S(-#@Y.#?(%;
M@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0B(*"B,Z(&)R;W=S92YP:'`Z
M-3@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN
M9R!A(&-O;G1A8W0@9G)O;2!T:&4@;&ES="XB"FUS9W-T<B`BD%:+2X.*@UB#
M9XWLD*R.GH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0B(*"B,Z(&%D9')E<W-B
M;V]K<RYP:'`Z-34@861D<F5S<V)O;VMS+G!H<#HV,"!A9&1R97-S8F]O:W,N
M<&AP.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@<F5M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S
M='(@(H-)@W6#5X-&@TZ#9XWMCYR2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!
M0B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#$@861D<F5S<V)O;VMS+G!H<#HX
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("*"
ML8+,C8"6VH+,C5B05I*&@LF#1X.)@5N"JH*@@NB"W(*U@KTZ("5S(@H*(SH@
M961I="YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y.B`E<R(*;7-G<W1R("*"L8+,
MC8"6VH+,C5B05I*&@LF#1X.)@5N"JH*@@NB"W(*U@KTZ("5S(@H*(SH@9&%T
M82YP:'`Z,3<Y"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E<W-E<R!T;R!E
M>'!O<G0N(@IM<V=S='(@(H-'@TZ#6(-\@5N#9X*W@M>"JX-!@VB#C(-8DJ""
MJH*@@NB"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O
M:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R97-S(&)O;VMS('=I
M;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#,*;7-G:60@(E1H97-E
M(&-O;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@
M(B(*"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("*"L8+,C&".KH+-@U2#?(%;@V>"
MLX+J@L2"HH+<@KF"\8%"(@H*(SH@;&EB+V%P:2YP:'`Z,3$R,B!L:6(O87!I
M+G!H<#HQ,3,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@<&5R<V]N(&%L
M<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*;7-G
M<W1R("*"L8+,D&R5J(+-@K>"Q8+)@T&#:(.,@UB2H(+)("5S((+&@K6"Q)-O
MF%Z"LX+J@L2"HH+<@K>!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#<*;7-G:60@(B(*(E1H:7,@=VEL;"!B92!T:&4@9&5F875L="!A9&1R97-S
M(&)O;VL@=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG(&-O;G1A8W1S+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW,`IM<V=I
M9"`B5&ET;&4B"FUS9W-T<B`BC*B/D2(*"B,Z(&QI8B]4=7)B82YP:'`Z-#,U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@;F5W('-H
M87)E+B`@36ES<VEN9R!S;W5R8V4@='EP92XB"FUS9W-T<B`B(@H*(R!M<V=S
M='(@(HQHC\PB"B,Z(&QI8B]$<FEV97(N<&AP.CDW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`B)7,@@LR2Z(M@@O"#C8%;@VB"Q8*K@MR"N8+Q@4(B"@HC.B!E
M9&ET+G!H<#HX."!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HY
M.2!E9&ET+G!H<#HQ.38*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("*5
MSXU8@O".YH+HC\&"MR(*"B,Z(&QI8B]A<&DN<&AP.C4T,"!L:6(O87!I+G!H
M<#HV-#,@;&EB+V%P:2YP:'`Z-S<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(H-4
M@WR!6X-G@K6"Q(*B@LB"HB!#;VYT96YT+51Y<&4@@L6"MX%"(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"FUS9VED(")697)I<VEG;B!$:7)E
M8W1O<GDB"FUS9W-T<B`B5F5R:7-I9VX@CM""S)!LEKR5ZR(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M(%PB)7-<(B(*;7-G<W1R("(G)7,G((+PE5R.IB(*"B,Z(&UI;FES96%R8V@N
M<&AP.C<X"FUS9VED(")6:65W($-O;G1A8W0B"FUS9W-T<B`BF$&7C9#F@O"5
M7(ZF(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE
M=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0Z(@IM<V=S='(@(H-F@W2#2(.+@V>"
MS)5<CJ:)YI;*.B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P
M.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T<B`B5V5B((+,(%523"(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q,PIM<V=I9"`B5V]R:R!!
M9&1R97-S(@IM<V=S='(@(HO.EK&0YH+,CUJ/BB(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5V]R:R!#:71Y(@IM<V=S='(@
M(HO.EK&0YH+,CG,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M,SD*;7-G:60@(E=O<FL@0V]U;G1R>2(*;7-G<W1R("*+SI:QD.:"S(V1(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34V"FUS9VED(")7;W)K
M(%!H;VYE(@IM<V=S='(@(HO.EK&0YH+,DV288I34C88B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ,S0*;7-G:60@(E=O<FL@4&]S=&%L($-O
M9&4B"FUS9W-T<B`BB\Z6L9#F@LR76)76E-2-AB(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$R.0IM<V=I9"`B5V]R:R!3=&%T92]0<F]V:6YC
M92(*;7-G<W1R("*+SI:QD.:"S(]"@5Z,IR(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=')E970@
M061D<F5S<R(*;7-G<W1R("*+SI:QD.:"S(]:CXHB"@HC.B!D871A+G!H<#HR
M,S<@8G)O=W-E+G!H<#HY,R!B<F]W<V4N<&AP.C(P,2!A9&0N<&AP.C<S"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&5D:70N<&AP.C8Y(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V
M"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H
M:7,@8V]N=&%C="XB"FUS9W-T<B`B@J""R(*]@LV"L8+,F$&7C9#F@O",J8+I
MC*"7F(*J@J""Z(+<@KF"\8%"(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T
M+B(*;7-G<W1R("*"H(+(@KV"S8*Q@LR#28-U@U>#1H-.@V>"\(RI@NF,H)>8
M@JJ"H(+H@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I
M<'0N:6YC.C4U"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("*6VI-)@LR#08-H@XR#6)*@@O"128+Q@L6)
MNH*S@J*!0B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z
M,C,*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(*;7-G
M<W1R("*6VI-)@LR#BH-8@V>"\)%)@O&"Q8*M@KZ"LX*B@4(B"@HC.B!E9&ET
M+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE
M87-T(&]N92!C;VYT86-T(&9I<G-T+B(*;7-G<W1R("*/K8+(@JV"QH+@@E""
MPH+PD4F"\8+%@JV"OH*S@J*!0B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V
M87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN
M8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C<R"FUS
M9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T
M+B(*;7-G<W1R("*/K8+(@JV"QH+@@E""PH+PD4F"\8+%@JV"OH*S@J*!0B(*
M"B,Z(&5D:70N<&AP.C<S"FUS9VED(")9;W4@;VYL>2!H879E('!E<FUI<W-I
M;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(H*@@LB"O8+)@LV"
ML8+,F$&7C9#F@O",J8+I@KZ"KX+,C*"7F(*U@JF"H(+H@MR"N8+Q@4(B"@HC
M.B!B<F]W<V4N<&AP.C(X-0IM<V=I9"`B66]U<B!D969A=6QT(&%D9')E<W,@
M8F]O:R!I<R!N;W0@8G)O=W-E86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]R;W<N:6YC.C8@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T
M<F]W+FEN8SHQ,@IM<V=I9"`B6VYO('9A;'5E72(*;7-G<W1R("(B"@HC.B!L
M:6(O5'5R8F$N<&AP.C0X-`IM<V=I9"`B7T)R;W=S92(*;7-G<W1R(")?0HE[
MEY<B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"B,L(&9U
M>GIY"FUS9VED(")?0V]N=&%C=',B"FUS9W-T<B`B7T.809>-D.:"\)5<CJ8B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@(E]$
M96QE=&4B"FUS9W-T<B`B7T2-[8^<(@H*(SH@;&EB+U1U<F)A+G!H<#HT.3,*
M;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(E])@T.#DR^#08-%@V<B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY
M"FUS9VED(")?3&ES=',B"FUS9W-T<B`B7TR#BH-8@V>"S)5<CJ8B"@HC.B!L
M:6(O5'5R8F$N<&AP.C0X,0HC+"!F=7IZ>0IM<V=I9"`B7TUY($%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`BCH2"S(-!@VB#C(-8DJ`B"@HC.B!L:6(O5'5R8F$N
M<&AP.C0X-PHC+"!F=7IZ>0IM<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S='(@
M(I!6BTN809>-D.8B"@HC(&US9W-T<B`B7TF#0X.3@WR!6X-G@5Z#1X-.@UB#
M?(%;@V<B"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@IM<V=I
M9"`B7U)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R(")?4H.*@UB#9X*I
M@N>-[8^<(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#D*;7-G:60@(E]396%R8V@B
M"FUS9W-T<B`B7U.,GXWU(@H*(SH@=F-A<F0N<&AP.C0V"FUS9VED(")C;VYT
M86-T+G9C9B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z
M,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C
M=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B8V]N
M=&%C=',N='-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(Q.0HC+"!F=7IZ
M>0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(IA!EXV0YH*JC*F5=(*I
M@NB"W(*Y@O$B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C,T
M"B,L(&9U>GIY"FUS9VED(")N;VYE(@IM<V=S='(@(H+(@K4B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")T
M;R!A($-O;G1A8W0@3&ES="(*;7-G<W1R("*809>-D.:"S)5<CJ8B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$T"B,L(&9U>GIY"FUS9VED
M(")T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VLB"FUS9W-T<B`BD4F1\(*S
M@NJ"O8-!@VB#C(-8DJ""UB(*"B,Z(&1A=&$N<&AP.C4Q('1E;7!L871E<R]B
M<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$S"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,34@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B(@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]P;R]I<U])
M4RYP;P``````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#4T-C`W`#$P-#$W,S8R-S4V`#`Q-S4T,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($EC96QA;F1I8R!T<F%N<VQA=&EO
M;G,@9F]R(&1I<VL@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R
M9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T
M:&4@<V%M92!L:6-E;G-E(&%S('1H92!D:7-K('!A8VMA9V4N"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(&1I<VL@,5QN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&)J;W-S:4!S;F5R<&$N:7-<;B(*(E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`U+3$Q+3$Y(#(P.C,S*S`P,#!<;B(*(E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#4M,3$M,3D@,C`Z,S,K,#`P,%QN(@HB3&%S
M="U4<F%N<VQA=&]R.B!":F]R;B!$879I9'-S;VX@/&)J;W-S:4!S;F5R<&$N
M:7,^7&XB"B),86YG=6%G92U496%M.B!S=7!P;W)T0'-N97)P82YI<UQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"@HC.B!B<F]W<V4N<&AP.C$R,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I
M<R!A(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3$X"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO=F5D(&)E8V%U<V4@
M:70@:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$Q"FUS9VED(")<(D9I<G-T;F%M92!,87-T;F%M95PB("`H:64N
M($IO:&X@1&]E*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$P"FUS9VED(")<(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H:64N($1O
M92P@2F]H;BDB"FUS9W-T<B`B(@H*(SH@861D+G!H<#HX-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M,C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E
M<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R(")-87!P86X@7"(E<UPB('9A<B!B
M^FEN('1I;"XB"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS
M9W-T<B`B)60@=&EL("5D(&%F("5D('-K97ET=6TB"@HC.B!L:6(O0FQO8VLO
M;6EN:7-E87)C:"YP:'`Z-#4*;7-G:60@(D$@8G)O=W-E<B!T:&%T('-U<'!O
M<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C8U
M"FUS9VED(")!9%]V86YC960@4V5A<F-H(@IM<V=S='(@(LUT87)L96<@;&5I
M="(*"B,Z(&%D9"YP:'`Z-3(*;7-G:60@(D%D9"(*;7-G<W1R(")"YG1A('9I
M\"(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S-PIM
M<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C(R"FUS9VED(")!9&0@=&\B"FUS9W-T<B`B0N9T
M82!V:?`B"@HC.B!B<F]W<V4N<&AP.C,P(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS
M9W-T<B`B3F5T9F%N9V%B\VLB"@HC.B!A9&0N<&AP.C@V"B,L(&9U>GIY"FUS
M9VED(")!9&1R97-S(&)O;VL@96YT<GDB"FUS9W-T<B`B3F5T9F%N9V%BYFMU
M<B(*"B,Z(&QI8B]$<FEV97(N<&AP.C0W.`HC+"!F=7IZ>0IM<V=I9"`B061D
M<F5S<R!B;V]K(&ES(')E860M;VYL>2XB"FUS9W-T<B`B3F5T9F%N9V%BYFMU
M<B(*"B,Z(&1A=&$N<&AP.C(S-@IM<V=I9"`B061D<F5S<R!B;V]K('-U8V-E
M<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z.3<@
M=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C8U"B,Z('1E;7!L871E<R]B
M<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*
M;7-G<W1R("+-=&%R;&5G(&QE:70B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HV-`IM<V=I9"`B06QI87,B"FUS9W-T<B`B4W1U='1N969N:2(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C8@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z.0IM<V=I9"`B06QL(@IM<V=S
M='(@(D%L;&%R('-K<N%N:6YG87(B"@HC.B!L:6(O87!I+G!H<#HS.34*;7-G
M:60@(D%L<F5A9'D@17AI<W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O:F%V87-C<FEP="YI;F,Z.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G
M<W1R(")%<G0@_OH@=FES<R!U;2!A\"#^^B!V:6QJ:7(@97GP82`E<S\B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8S"FUS9VED(")!
M<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C
M=&5D(&5N=')I97,_(@IM<V=S='(@(D5R="#^^B!V:7-S('5M(&'P(/[Z('9I
M;&II<B!E>?!A(';V;&1U;2!L[6YU;3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S`*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")(YFMK86YD:2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S,PHC+"!F
M=7IZ>0IM<V=I9"`B079A:6QA8FQE($-O;'5M;G,Z(@IM<V=S='(@(E1I;'3F
M:V%R(&YE=&9A;F=A8N9K=7(Z(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")"85]C:R!T;R`E<R(*
M;7-G<W1R(")4:6P@8F%K82#M("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHT-`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R(")4:6P@
M8F%K82#M("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q
M-@IM<V=I9"`B0F%S:5]C(%-E87)C:"(*;7-G<W1R(")%:6YF]FQD(&QE:70B
M"@HC.B!S96%R8V@N<&AP.CDT('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN
M8SHV,@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$V"FUS9VED
M(")"87-I8R!396%R8V@B"FUS9W-T<B`B16EN9O9L9"!L96ET(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,0IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O
M<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HX-2!L:6(O
M1')I=F5R+VQD87`N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@
M9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<S"FUS9VED(")"=7-I
M;F5S<R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR.`IM<V=I
M9"`B0U-6(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D-?;&5A<B!396%R8V@B"FUS9W-T
M<B`B3&5I=&$@[2!S:V5Y='5M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU
M;6Y?:&5A9&5R<RYI;F,Z-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S
M='(@(E9E;&IA(&%L;&$O96YG86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,CD*;7-G:60@(B(*(D-H;V]S92!A(&1E9F%U;'0@9&ER96-T;W)Y(&9O
M<B!Y;W5R('!E<G-O;F%L(&%D9')E<W-B;V]K+"!C;VYT86-T(&QI<W1S+"!A
M;F0@(@HB<V5A<F-H97,N(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z-#0*;7-G
M:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLB"FUS9W-T<B`B5F5L9'4@;F5T
M9F%N9V%B\VLB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN
M8SHR,C@*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@;W)D97(@;V8@=&AE
M(&-O;'5M;G,@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T+B(*;7-G
M<W1R("(B"B)696QD=2!U<'!R]O!U;B!N971F86YG86+S:V$@<V5M(.$@8?`@
M;&5I=&$@[2P@_F5G87(@;&5I=&'P(&5R(&'P(&YE=&;V;F=U;2XB"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0X"B,L(&9U>GIY"FUS9VED
M(")#;&5A<B!396%R8V@B"FUS9W-T<B`B3&5I=&$@[2!S:V5Y='5M(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"B,L(&9U>GIY"FUS9VED(")#;VQU
M;6X@3W!T:6]N<R(*;7-G<W1R(")686QS=&EL;&EN9V%R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ-B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$X"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3<*;7-G:60@(D-O
M;6UA('-E<&%R871E9"!V86QU97,@*$UI8W)O<V]F="!/=71L;V]K*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW-@IM<V=I
M9"`B0V]M<&%N>2(*;7-G<W1R(")&>7)I<G3F:VDB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D-O;7!A;GD@061D<F5S<R(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR-#<@;&EB+V%P:2YP:'`Z,C8X
M(&QI8B]A<&DN<&AP.C,X-"!L:6(O87!I+G!H<#HT-30*(SH@;&EB+V%P:2YP
M:'`Z-30T(&QI8B]A<&DN<&AP.C4Y,"!L:6(O87!I+G!H<#HV,S@@;&EB+V%P
M:2YP:'`Z.#(U"B,Z(&QI8B]A<&DN<&AP.CDQ.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D5N
M9'5R=NUS=6X@;6ES:&5P<&'P:7-T+B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z-C8*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R("(B"@HC
M.B!B<F]W<V4N<&AP.C8P"FUS9VED(")#;VYT86-T(')E;6]V960@9G)O;2!L
M:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYT86-T<R!I;B!L:7-T.B`E<R(*;7-G<W1R(")496YG
M:6QI\&ER(.T@;&ES=&$Z("5S(@H*(SH@8G)O=W-E+G!H<#HR.#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@)7,B"FUS9W-T<B`B26YN:6AA
M;&0@[2`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3(*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B069R:70B"@HC.B!L:6(O3V)J96-T5FEE
M=RYP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(D+Z
M82!T:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0@1&ES<&QA>2(*;7-G<W1R(")3:N%L9F=E9FGP(&ME
M;FYI;6%R:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G:60@
M(B(*(D1E9F%U;'0@9&ER96-T;W)Y(&9O<B!Y;W5R('!E<G-O;F%L(&%D9')E
M<W-B;V]K+"!C;VYT86-T(&QI<W1S+"!A;F0@<V5A<F-H97,N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,@IM<V=I9"`B1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B4VKA;&9G969I;B!U<'!R
M]O!U;CHB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,@;&EB
M+U)E;F1E<F5R+G!H<#HT.`IM<V=I9"`B1&5L971E(@IM<V=S='(@(D5Y\&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T<B`B57!P;/US:6YG87(@;F5T
M_FKS;G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8*;7-G:60@(D1E
M;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&4@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D5Y\&$@;?9P<'4H;2DB
M"@HC.B!D96QE=&4N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")$96QE=&EO;B!F
M86EL960B"FUS9W-T<B`B16YD=7)V[7-U;B!M:7-H97!P8?!I<W0N(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M
M96YT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,0IM
M<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("),YFMK86YD:2(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,S(*;7-G:60@(D1I<F5C=&]R>2(*
M;7-G<W1R(").971F86YG86+S:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BVG1L:71S<W1I;&QI;F=A<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#D*(RP@9G5Z>GD*;7-G:60@(D1O
M('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T
M<B`B5FEL='4@;W!N82#^97-S82!M]G!P=3\B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V-O;G1A8W1R;W<N:6YC.C(U"B,L(&9U>GIY"FUS9VED(")$;W=N;&]A
M9"!V0V%R9"(*;7-G<W1R(")3YFMJ82!Y9FER(.$@=FEN;G5S=/;P(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z-B!T96UP;&%T
M97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S"B,Z(&QI8B]296YD97)E<BYP
M:'`Z-#8*;7-G:60@(D5D:70B"FUS9W-T<B`B0G)E>71A(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B0G)E>71A(@H*(SH@
M961I="YP:'`Z-3,@961I="YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!E;G1R>2!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(DYE=&9A
M;F<B"@HC.B!E9&ET+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R
M>2!F;W(@)7,@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M-#8*;7-G:60@(D5X<&]R="(*;7-G<W1R(")&;'ET:F$@^G0B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C<*;7-G:60@(D5X<&]R="!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B1FQY=&IA(/IT(&YE=&9A;F=A8O-K(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-@IM<V=I9"`B17AP;W)T(&]N;'D@
M=&AE('-E;&5C=&5D(&-O;G1A8W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C,R"FUS9VED(")%>'!O<G0@=&AE(&9O;&QO
M=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2XB"FUS9W-T<B`B(@H*(SH@
M<V5A<F-H+G!H<#HU,B!D871A+G!H<#HQ,3`@9&%T82YP:'`Z,C(X(&%D9"YP
M:'`Z-C,@8G)O=W-E+G!H<#HS-PHC.B!B<F]W<V4N<&AP.CDT(&)R;W=S92YP
M:'`Z,3`Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D+F=&$@[2!N
M971F86YG86+S:R`H)7,I(@H*(SH@8G)O=W-E+G!H<#HQ,C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%D9"`E<R!T;R`E<SH@)7,B"FUS9W-T
M<B`B(@H*(SH@8G)O=W-E+G!H<#HR-C,*;7-G:60@(D9A:6QE9"!T;R!B<F]W
M<V4@;&ES="(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(Y-PIM<V=I9"`B
M1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L
M($YE=R!$3B`]("5S+"!2;V]T(#T@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E
M+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&9I;F0@
M;V)J96-T('1O(&)E(&%D9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!S96%R8V@N
M<&AP.C@X(&1A=&$N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW,@IM
M<V=I9"`B1FEN9"(*;7-G<W1R(")&:6YN82(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C0X"B,L(&9U>GIY"FUS9VED(")&:7)S="!.86UE(@IM
M<V=S='(@(D9Y<G-T82!S[?!A(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@U"FUS9VED(")&<F]M(@IM
M<V=S='(@(NTB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HU-C(*(RP@
M9G5Z>GD*;7-G:60@(D=L;V)A;"!!9&1R97-S($)O;VLB"FUS9W-T<B`B3F5T
M9F%N9V%B\VLB"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC
M.C0T"FUS9VED(")'<F]U<"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@
M(DAE:6UI;&ES9F%N9R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.CDS"FUS9VED(")(;VUE($-I='DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3`X"FUS9VED(")(;VUE($-O=6YT<GDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34P"FUS
M9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(DAE:6UA<^UM:2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P,PIM<V=I9"`B2&]M92!0;W-T86P@
M0V]D92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HY.`IM<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX.`HC+"!F=7IZ>0IM<V=I
M9"`B2&]M92!3=')E970@061D<F5S<R(*;7-G<W1R(")396YD86YD86YE=&9A
M;F<B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HT.#<*;7-G:60@(DE-
M4U`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHY
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D<F5S<R!"
M;V]K+"!3=&5P("5D(@IM<V=S='(@(DYE=&9A;F=A8O-K(@H*(SH@9&%T82YP
M:'`Z,C<T"B,L(&9U>GIY"FUS9VED("));7!O<G0O17AP;W)T($%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`B3F5T9F%N9V%B\VLB"@HC.B!L:6(O87!I+G!H<#HS
M-S@@;&EB+V%P:2YP:'`Z-C`T"FUS9VED("));G9A;&ED($-O;G1E;G0M5'EP
M92(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HT-#$@;&EB+V%P:2YP:'`Z
M-3,Q"FUS9VED("));G9A;&ED($E$(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$Y,2!L:6(O87!I+G!H<#HS,S0@;&EB+V%P:2YP:'`Z-#,W(&QI8B]A
M<&DN<&AP.C4R-PHC.B!L:6(O87!I+G!H<#HU.#`@;&EB+V%P:2YP:'`Z.#DU
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R
M(")4:6QTYFMA<B!N971F86YG86+F:W5R.B(*"B,Z(&QI8B]A<&DN<&AP.C@Y
M.2!L:6(O87!I+G!H<#HY-S,@;&EB+V%P:2YP:'`Z,3`R-@IM<V=I9"`B26YV
M86QI9"!E;6%I;"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HY,#<*;7-G
M:60@(DEN=F%L:60@96YT<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HR-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@:V5Y('-P96-I
M9FEE9"XB"FUS9W-T<B`B96YG:6YN('1E>'1I('1I;&=R96EN9'5R(@H*(SH@
M;&EB+V%P:2YP:'`Z.3`S"FUS9VED("));G9A;&ED(&YA;64B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z-3@T"FUS9VED("));G9A;&ED(&]B:F5C=$ED
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S@*;7-G:60@
M(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@=&AE($Q$05`@;6]D
M=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S.0IM<V=I9"`B3&%S="!-;V1I
M9FEE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HU,PHC+"!F=7IZ>0IM<V=I9"`B3&%S="!.86UE(@IM<V=S='(@(G/M\&%S
M=&$@8FQS+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N
M:6YC.C@*;7-G:60@(DQI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]S96%R8V@N:6YC.C<Y"FUS9VED(")-871C:&EN9R(*;7-G<W1R(")S
M96T@<&%S<V%R('9I\"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,0IM
M<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@<&%G97,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUI
M;FD@4V5A<F-H(@IM<V=S='(@(DQE:71A(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HS,34*;7-G:60@(DUI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,38R"FUS9VED(")-;V)I;&4@4&AO;F4B"FUS9W-T<B`B1F%R
M<^UM:2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S0T(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(DUO9&EF>2!F86EL
M960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3`Q,@IM
M<V=I9"`B36]R92!T:&%N(#$@96YT<GD@9F]U;F0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B36]V92(*
M;7-G<W1R(")&;'ET:F$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L
M96-T+FEN8SHR-#<*(RP@9G5Z>GD*;7-G:60@(DUO=F4@;&5F="(*;7-G<W1R
M(")&;'ET:F$@=7!P(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C
M="YI;F,Z,C0Y"FUS9VED(")-;W9E(')I9VAT(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C,Q('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C$*(RP@9G5Z
M>GD*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G<W1R(").971F
M86YG86+S:R(*"B,Z(&QI8B]A<&DN<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B
M=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C@W(&-O;F9I9R]S;W5R
M8V5S+G!H<"YD:7-T.C(R,0HC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S<R!"
M;V]K(@IM<V=S='(@(DYE=&9A;F=A8O-K(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%F;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,@IM<V=I9"`B3F%M92!&;W)M870B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,CDU"FUS
M9VED(").971C96YT97(@365M8F5R($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!A9&0N<&AP.C,V(&%D9"YP:'`Z,3`R(&QI8B]";&]C:R]M:6YI<V5A<F-H
M+G!H<#HR-PIM<V=I9"`B3F5W($-O;G1A8W0B"FUS9W-T<B`B3OUR('1E;F=I
M;&GP=7(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(V"B,L
M(&9U>GIY"FUS9VED(").97<@3&ES="(*;7-G<W1R(")._7(@</-S='5R(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,@IM<V=I9"`B3F5X="(*
M;7-G<W1R(").YG-T82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C(Q.`HC+"!F=7IZ>0IM<V=I9"`B3FEC:VYA;64B"FUS9W-T<B`B3F%F;B(*
M"B,Z(&QI8B]A<&DN<&AP.C$P,30@;&EB+V%P:2YP:'`Z,3`V,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(").;R`E<R!E;G1R>2!F;W5N9"!F;W(@)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.3@R"B,L(&9U>GIY"FUS9VED(").;R!A
M9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R(").971F86YG86+F:W5R(@H*
M(SH@;6EN:7-E87)C:"YP:'`Z.#<*;7-G:60@(DYO(&-O;G1A8W1S(&9O=6YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C,U-@IM<V=I9"`B3F\@=D-A
M<F0@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R+FEN8SHW"FUS9VED(").;VYE(@IM<V=S='(@(D5N9VEN
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3@T"FUS9VED(").
M;W1E<R(*;7-G<W1R(")';/-S=7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#D*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HT-C`*;7-G:60@(D]B:F5C="!N;W0@9F]U
M;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D'P
M<F%R('-T:6QL:6YG87(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C,T,"!L:6(O87!I+G!H<#HT-#<@;&EB+V%P:2YP:'`Z-3,W
M(&QI8B]A<&DN<&AP.C4Y-@HC.B!L:6(O87!I+G!H<#HW-3,@;&EB+V%P:2YP
M:'`Z.3$S"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC
M.B!L:6(O1')I=F5R+G!H<#HT,S8*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D
M(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(E!I;F4@061D<F5S<R!";V]K
M(@IM<V=S='(@(DYE=&9A;F=A8O-K(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J
M879A<V-R:7!T+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R
M('1H92!N86UE(&]F('1H92!N97<@;&ES=#HB"FUS9W-T<B`B4VSA\'4@:6YN
M(&[]='0@;?9P<'5N869N.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS
M96QE8W0N:6YC.C(R,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('-E;&5C="!A
M(&1I<F5C=&]R>3HB"FUS9W-T<B`B5F5L9'4@9?!A(&)R97ET='4@=&EL(&CF
M9W)I+"!NYG-T.B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Y.0HC
M+"!F=7IZ>0IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M3F5T9F%N9V%B\VLB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$U-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")1=65R>2!F86EL960Z("@E<RD@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"B,L
M(&9U>GIY"FUS9VED(")1=6EC:R!396%R8V@B"FUS9W-T<B`B3&5I=&$B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD87`N<&AP
M.C(P-R!L:6(O1')I=F5R+VQD87`N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D<R!D:7-P
M;&%Y960Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS
M96QE8W0N:6YC.C(S.0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*
M;7-G<W1R(")FYG)A(&YI\'5R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHS"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T
M<B`B1FIA<FSF9VIA(/IR(&QI<W1A;G5M(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHR-@IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R
M97-S(&)O;VL@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\8CY787)N:6YG.B!4
M:&ES("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D
M9')E<W,@8F]O:RX\+V(^(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C,S,`IM<V=I9"`B4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.C$R-@IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B16YD
M=7)S971J82!L96ET87)R96ET:2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T:69I8V%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R
M("(B"@HC.B!E9&ET+G!H<#HU-R!A9&0N<&AP.C,W"FUS9VED(")3879E(@IM
M<V=S='(@(E9I<W1A(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC
M.CDX('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,C4*(SH@=&5M<&QA
M=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(S(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#`*;7-G:60@(E-E87)C:"(*;7-G<W1R("),96ET82(*"B,Z(&UI
M;FES96%R8V@N<&AP.C8V(&)R;W=S92YP:'`Z,C0Q"FUS9VED(")396%R8V@@
M4F5S=6QT<R(*;7-G<W1R(").:?!U<G-T8?!A(&QE:71A<B(*"B,Z(&QI8B]A
M<&DN<&AP.C@R.0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G
M<W1R("),96ET82(*"B,Z(&QI8B]A<&DN<&AP.CDR,B!L:6(O87!I+G!H<#HY
M,C@@;&EB+V%P:2YP:'`Z.3,W(&QI8B]A<&DN<&AP.CDU,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@*;7-G:60@(E-E87)C:&EN9R!/<'1I
M;VYS(@IM<V=S='(@(DQE:71A<G9A;&MO<W1I<B(*"B,Z('1E;7!L871E<R]B
M;&]C:R]M:6YI<V5A<F-H+FEN8SHR-`IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM
M<V=S='(@(DQE:71A+BXN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96QE8W0N
M:6YC.CD*;7-G:60@(E-E;&5C="!!9&1R97-S($)O;VLB"FUS9W-T<B`B5F5L
M:FGP(&YE=&9A;F=A8O-K.B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,C0*;7-G:60@(E-E;&5C="!,:7-T(@IM<V=S='(@(E9A;&EN;B!L
M:7-T82(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S<*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F
M<F]M.B(*;7-G<W1R(")686QD87(@;F5T9F%N9V%BYFMU<CHB"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(E9A
M;&1A<B!N971F86YG86+F:W5R.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,30*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I
M9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"FUS9VED(")396QE8W0@=&AE(&9O
M<FUA="!U<V5D('1O(&1I<W!L87D@;F%M97,Z(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B4V5L96-T('9I97<@=&\@
M9&ES<&QA>2!B>2!D969A=6QT+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$*;7-G:60@(E-E;&5C="!W:&EC:"!F:65L9',@=&\@
M9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"FUS9VED(")396QE8W0@=VAI8V@@
M9F]R;6%T('1O(&1I<W!L87D@;F%M97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T960@0V]L=6UN<SHB"FUS9W-T<B`B5F5L:F$@96MK97)T(@H*
M(SH@861D+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5L
M96-T960@861D<F5S<R!B;V]K(%PB)7-<(BXB"FUS9W-T<B`B5F%L9&%R(&YE
M=&9A;F=A8N9K=7(Z(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,34T
M"B,L(&9U>GIY"FUS9VED(")3:&%R960@1&ER96-T;W)Y(@IM<V=S='(@(E+V
M\'5N87+A='0B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0R
M"FUS9VED(")3:&]?=R!!;&PB"FUS9W-T<B`B4_UN82!A;&QT(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96QE8W0N:6YC.C$Q"FUS9VED(")3:&]W(@IM<V=S
M='(@(E/];F$B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0R
M"FUS9VED(")3:&]W($%L;"(*;7-G<W1R(")3_6YA(&%L;'0B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0Q"FUS9VED(")3:&]W($-O;G1A
M8W1S(@IM<V=S='(@(E/];F$@=&5N9VEL:?!I(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B4VAO=R!,:7-T<R(*;7-G<W1R
M(")3_6YA(&QI<W1A(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT,0IM<V=I9"`B4VAO=R!?0V]N=&%C=',B"FUS9W-T<B`B4_UN82!T96YG
M:6QI\&DB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"FUS
M9VED(")3:&]W(%],:7-T<R(*;7-G<W1R(")3_6YA(&QI<W1A(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3`*(SH@=&5M<&QA
M=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,34*;7-G:60@(E-O<G0@
M1&ER96-T:6]N(@IM<V=S='(@(E+V\'5N87+A='0B"@HC.B!L:6(O87!I+G!H
M<#HQ-30*(RP@9G5Z>GD*;7-G:60@(E-O=7)C97,B"FUS9W-T<B`B1G)A;6MV
MYFUT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,`IM<V=I9"`B4W!E
M8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T
M;R!A<'!E87(N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3,P"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<R(*
M;7-G<W1R("(B"@HC.B!D871A+G!H<#HR.0IM<V=I9"`B5%-6(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3@@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHQ.0IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU
M97,B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C,T"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,C0@=F-A<F0N<&AP.C(R(&1I
M<W!L87DN<&AP.C(S"FUS9VED(")4:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C,S
M"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS
M+B(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C(Y"FUS9VED("(B"B)4:&5R92!A
M<F4@;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V
M86EL86)L92!A9&1R97-S(&)O;VMS("(*(F%R92!C;VYF:6=U<F5D('1O(&%L
M;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E
M;&EE=F4@=&AI<R`B"B)I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U
M<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@861D+G!H
M<#HY.0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@
M;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N
M<&AP.C$X-0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R
M96%T:6YG(&$@;F5W(&QI<W0N(@IM<V=S='(@(E9I;&QA(&MO;2!U<'`@_F5G
M87(@X71T:2!A\"!V:7-T82!U<'!K87-T:?`N(@H*(SH@8G)O=W-E+G!H<#HQ
M,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D96QE=&EN9R`E<R!F<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("(B"B)6:6QL82!K;VT@=7!P(/YE9V%R(.%T=&D@8?`@97GP
M82!S:V5Y='5M+B!6:6QL=71I;&MY;FYI;F<@;F5T_FKS;G-I;G,@9GEL9VER
M("(*(FCI<B#A(&5F=&ER(@H*(SH@9&5L971E+G!H<#HS,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG
M('1H:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`B5FEL;&$@:V]M('5P<"!V:?`@
M8FER=&EN9W4@_F5S<V$@:&QU=&$@<VME>71I<VEN<R(*"B,Z(&)R;W=S92YP
M:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B5FEL;&$@:V]M('5P<"!V:?`@
M8FER=&EN9W4@_F5S<V$@:&QU=&$@<VME>71I<VEN<R(*"B,Z(&)R;W=S92YP
M:'`Z,C<S"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&4@<V5L96-T($QI<W0B"FUS9W-T<B`B5FEL;&$@:V]M('5P
M<"!V:?`@8FER=&EN9W4@_F5S<V$@:&QU=&$@<VME>71I<VEN<R(*"B,Z(&1A
M=&$N<&AP.C(T.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`B
M5FEL;&$@:V]M('5P<"#^96=A<B#A='1I(&'P('9I<W1A('5P<&MA<W1I\"XB
M"@HC.B!L:6(O87!I+G!H<#HS-3(*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G
M<W1R(")6:6QL82!K;VT@=7!P(/YE9V%R(.%T=&D@8?`@=FES=&$@=7!P:V%S
M=&GP+B(*"B,Z(&)R;W=S92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B
M5FEL;&$@:V]M('5P<"#^96=A<B#A='1I(&'P('9I<W1A('5P<&MA<W1I\"XB
M"@HC.B!E9&ET+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT<GDZ("5S(@IM
M<V=S='(@(E9I;&QA(&MO;2!U<'`@=FGP(&)I<G1I;F=U(/YE<W-A(&AL=71A
M('-K97ET:7-I;G,B"@HC.B!D871A+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G:60@
M(E1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="XB"FUS9W-T<B`B
MWF'P(&5R=2!E;F=I;B!S:V5Y=&D@[2#^97-S=2!P\W-T:/-L9FDN(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z,SDP(&QI8B]$<FEV97(N<&AP.C0R-PIM<V=I9"`B
M5&AI<R!A9&1R97-S(&)O;VL@:7,@<F5A9"UO;FQY(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C(Q,0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA="!I<R!N;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HY-#$@;&EB
M+V%P:2YP:'`Z.34T"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@<&5R<V]N
M(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW,`IM
M<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET:6QL(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HU
M-PIM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D9J87)LYF=J82!B<F5Y
M=&EN9V%R(@H*(SH@;&EB+V%P:2YP:'`Z-#@Y"FUS9VED(")5;G-U<'!O<G1E
M9"!#;VYT96YT+51Y<&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S
M+G!H<"YD:7-T.C,U.`IM<V=I9"`B5F5R:7-I9VX@1&ER96-T;W)Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB(@IM<V=S
M='(@(E/];F$@)7,B"@HC.B!M:6YI<V5A<F-H+G!H<#HX,@IM<V=I9"`B5FEE
M=R!#;VYT86-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.`IM<V=I9"`B5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I
M9"`B5V5B<VET92!54DPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3$S"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B
M2&5I;6EL:7-F+B!V:6YN=2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$R-`IM<V=I9"`B5V]R:R!#:71Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S.0IM<V=I9"`B5V]R:R!#;W5N=')Y
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U
M-@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")6:6YN=7/M;6DB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,S0*;7-G:60@(E=O<FL@4&]S
M=&%L($-O9&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3(Y"FUS9VED(")7;W)K(%-T871E+U!R;W9I;F-E(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q.0IM<V=I9"`B
M5V]R:R!3=')E970@061D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")9;W4@
M87)E(&-R96%T:6YG(&$@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(M[Z
M(&5R="!U;2#^8?`@8FEL(&'P(&+Z82!T:6P@=6YD:7)M]G!P=2#M("(*"B,Z
M(&5D:70N<&AP.C0T(&1I<W!L87DN<&AP.C4Y"FUS9VED(")9;W4@9&\@;F]T
M(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB"FUS9W-T
M<B`B(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C4Q"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("+>^B#^87)F="!A\"!V96QJ82!N971F86YG(&9Y<G-T+B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C,*(RP@9G5Z
M>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(*;7-G
M<W1R("+>^B#^87)F="!A\"!V96QJ82#M(&AV8?!A(&WV<'!U('#S<W1U<FEN
M;B#A(&'P(&9A<F$@9GER<W0N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A
M<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C0U"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-C@*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@96YT
M<GD@9FER<W0N(@IM<V=S='(@(E9E;&1U(&$N;2YK+B!E:71T('-K97ET:2!F
M>7)S="XB"@HC.B!E9&ET+G!H<#HT.`IM<V=I9"`B66]U(&]N;'D@:&%V92!P
M97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R("(B"@HC
M.B!B<F]W<V4N<&AP.C(X-`IM<V=I9"`B66]U<B!D969A=6QT(&%D9')E<W-B
M;V]K(&ES(&YO="!B<F]W<V5A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS9VED(");;F\@=F%L=65=
M(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z,C@V"FUS9VED(")?061D
M(@IM<V=S='(@(D+F=&$@=FGP(@H*(SH@;&EB+U1U<F)A+G!H<#HR.#,*;7-G
M:60@(E]"<F]W<V4B"FUS9W-T<B`B4VMO\&$B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C,*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B17GP
M82(*"B,Z(&QI8B]4=7)B82YP:'`Z,CDR"FUS9VED(")?26UP;W)T+T5X<&]R
M="(*;7-G<W1R(")&;'ET:F$@:6YN+_IT(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHS"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T
M(@IM<V=S='(@(D9J87)LYF=J82#Z<B!L:7-T86YU;2(*"B,Z(&QI8B]4=7)B
M82YP:'`Z,C@X"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(DQE:71A(@H*(SH@
M=F-A<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R("(B"@HC
M.B!D871A+G!H<#HQ-S(@9&%T82YP:'`Z,3<W('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B8V]N=&%C=',N='-V(@IM
M<V=S='(@(E1E;F=I;&GP86QI<W1I(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHQ-`IM<V=I9"`B=&\@4V5L96-T960@061D<F5S<R!";V]K
M(@IM<V=S='(@(NT@=F%L:6YN:2!N971F86YG86+S:R(*"B,Z(&1A=&$N<&AP
M.C,P('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C<*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,"!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C(P"FUS9VED(")V0V%R9"(*;7-G<W1R("(B"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1U<F)A+W!O+W-L7U-)+G!O````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-S4W,3$`,3`T,3<S-C(W-38`,#$W-30S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",@4VQO
M=F5N:6%N('1R86YS;&%T:6]N(&]F(%1U<F)A"B,@0V]P>7)I9VAT("A#*2`R
M,#`U($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@
M=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@5'5R8F$@<&%C:V%G92X*
M(R!-871I8R!$;VQA<B`\<VUE<VYI0&UE9&EU;2YS:3X*(PIM<V=I9"`B(@IM
M<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@(%1U<F)A($@S("@R+C`I
M7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P
M,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP,BTR,2`Q-3HR-2LP,3`P
M7&XB"B),87-T+51R86YS;&%T;W(Z($UA=&EC($1O;&%R(#QS;65S;FE`;65D
M:75M+G-I/EQN(@HB3&%N9W5A9V4M5&5A;3H@4VQO=F5NN>AI;F%<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=%QN(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN
M8SHT,@HC+"!F=7IZ>0IM<V=I9"`B($%D9"!A;B!)35-0($%D9')E<W,@0F]O
M:R(*;7-G<W1R(")0:6YE($%D<F5S87(B"@HC.B!T96UP;&%T97,O<')E9G,O
M:6US<%]O<'0N:6YC.C,Q"B,L(&9U>GIY"FUS9VED("(@1&5L971E($E-4U`@
M061D<F5S<R!";V]K(@IM<V=S='(@(G8@27IB<F%N($%D<F5S87(B"@HC.B!D
M871A+G!H<#HS,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&%L<F5A
M9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!B<F]W<V4N<&AP.C$R-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U<V4@:70@:7,@82!L:7-T+B(*
M;7-G<W1R("(G)7,G(&YI(&)I;"!K;W!I<F%N+"!K97(@:F4@;F$@<V5Z;F%M
M=2XB"@HC.B!B<F]W<V4N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI
M<W0N(@IM<V=S='(@(B<E<R<@;FD@8FEL('!R96UA:VYJ96XL(&ME<B!J92!N
M82!S97IN86UU+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*;7-G
M:60@(EPB1FER<W1N86UE($QA<W1N86UE7"(@("AI92X@2F]H;B!$;V4I(@IM
M<V=S='(@(EPB26UE(%!R:6EM96M<(B`@*&YP<BX@2F%N97H@2W)A;FIS:VDI
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T
M;F%M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(EPB
M4')I:6UE:RP@26UE7"(@*&YP<BX@2W)A;FIS:VDL($IA;F5Z*2(*"B,Z(&%D
M9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%D9&5D+B(*;7-G
M<W1R("(E<R!D;V1A;BXB"@HC.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T
M<B`B1&%T;W1E:V$@)7,@=7-P9;EN;R!U=F^^96YA(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]F;V]T97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@:R`E<R!O9"`E<R(*"B,Z(&QI8B]4
M=7)B82YP:'`Z-#0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($%D9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE($%D<F5S87(B"@HC.B!L:6(O
M0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#4*;7-G:60@(D$@8G)O=W-E<B!T:&%T
M('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B"FUS9W-T<B`B6F%H=&5V
M86X@:F4@8G)S:V%L;FEK(&MI('!O9'!I<F$@:49R86UE<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3D*;7-G:60@(D%B;W9E('-E87)C:"!F;W)M
M(@IM<V=S='(@(DYA9"!O8G)A>F-E;2!Z82!I<VMA;FIE(@H*(SH@=FEE=RYP
M:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI
M960@=&\@)7,B"FUS9W-T<B`B57-P9;EN;R!D;V1A;"`E<R!V("5S(@H*(SH@
M861D+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(R"B,L
M(&9U>GIY"FUS9VED(")!9&0B"FUS9W-T<B`B7T1O9&%J(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S0*(RP@9G5Z>GD*
M;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3F5V96QJ879E;B!A
M9')E<V%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X"B,L(&9U>GIY
M"FUS9VED(")!9&0@86YD($1E;&5T92!)35-0(&%D9')E<W,@8F]O:W,B"FUS
M9W-T<B`B27IB<F%N(&%D<F5S87(@)R5S)RXB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`B1&]D86H@<W1O;'!E8R(*"B,Z(&5D:70N<&AP.C$R.`IM<V=I9"`B
M061D(&9I;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHR,@IM<V=I9"`B061D('1O(@IM<V=S='(@(D1O9&%J('8B"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F=7IZ>0IM<V=I
M9"`B061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@061R97-A<B(*"B,Z(&)R
M;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B
M061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B4V5Z;F%M($%D<F5S87)J
M978B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z>GD*;7-G
M:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B4&EN92!!9')E<V%R(@H*(SH@
M861D+G!H<#HQ,#@*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R>2(*;7-G<W1R
M(")6;F]S('8@861R97-A<B(*"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B061D
M<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(D%D<F5S
M87(@=7-P9;EN;R!P;^AIN>AE;BXB"@HC.B!T96UP;&%T97,O861D<F5S<V)O
M;VMS+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K('1O(&1E
M;&5T92`B"FUS9W-T<B`B5FYO<R!V(&%D<F5S87(B"@HC.B!T96UP;&%T97,O
M<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`HC+"!F=7IZ>0IM<V=I
M9"`B061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB
M"FUS9W-T<B`B061R97-A<FIA(&YI(&)I;&\@;6]G;^AE('!OZ&ES=&ET:3H@
M)7,B"@HC.B!S96%R8V@N<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H
M+FEN8SHS-PIM<V=I9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(DYA<')E
M9&YO($ES:V%N:F4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HV
M-`IM<V=I9"`B06QI87,B"FUS9W-T<B`B4'-E=F1O;FEM(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z-R!T96UP;&%T97,O8G)O=W-E
M+V9O;W1E<D%L<&AA+FEN8SHQ,`HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C0Q"FUS9VED(")!;&PB"FUS9W-T<B`B5G-E(@H*(SH@;&EB+V%P
M:2YP:'`Z-34R"FUS9VED(")!;')E861Y($5X:7-T<R(*;7-G<W1R("*N92!O
M8G-T86IA(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@
M=V%N="!T;R!D96QE=&4@)7,_(@IM<V=S='(@(E-T92!P<F5P<FGH86YI+"!D
M82"^96QI=&4@:7IB<FES871I("5S/R(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO
M=2!W86YT('1O(&1E;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\B"FUS9W-T
M<B`B4W1E('!R97!R:>AA;FDL(&1A(+YE;&ET92!I>F)R:7-A=&D@:7IB<F%N
M92!V;F]S93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*;7-G:60@
M(D%S8V5N9&EN9R(*;7-G<W1R(").87)AN>AA:F_H(@H*(SH@<V5A<F-H+G!H
M<#HX-2!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S8*;7-G:60@(D)A
M<VEC(%-E87)C:"(*;7-G<W1R(")/<VYO=FYO($ES:V%N:F4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")"96QO=R!S96%R8V@@9F]R
M;2(*;7-G<W1R(")0;V0@;V)R87IC96T@>F$@:7-K86YJ92(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z-S<@;&EB+T1R:79E<B]L9&%P+G!H<#HX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R
M(")697IA=F$@<W!O9&QE=&5L83H@*"5S*2`E<R(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B
M4F]J<W1N:2!D86XB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PHC+"!F=7IZ
M>0IM<V=I9"`B0G)O=W-E(@IM<V=S='(@(E]"<G-K86HB"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)U<VEN97-S($-A=&5G
M;W)Y(@IM<V=S='(@(DMA=&5G;W)I:F$@4&]S;&$B"@HC.B!D871A+G!H<#HT
M.0IM<V=I9"`B0U-6(@IM<V=S='(@(D-35B(*"B,Z(&QI8B]/8FIE8W0O1W)O
M=7`N<&AP.C4W"FUS9VED(")#86XG="!A9&0@82!G<F]U<"!T;R!I='-E;&8N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C<*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R(")0<F5V
M97)I(%]6<V4O3F]B96YE9V$B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G<W1R
M("))>F)E<FET92!A9')E<V%R(@H*(SH@861D+G!H<#HT.`IM<V=I9"`B0VAO
M;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R("))>F)E<FET92!A9')E<V%R
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C(Q"B,L
M(&9U>GIY"FUS9VED(")#:&]O<V4@86X@861D<F5S<R!B;V]K.B(*;7-G<W1R
M("))>F)E<FET92!A9')E<V%R(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E
M<W-B;V]K<V5L96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R
M97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*(RP@9G5Z>GD*
M;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O('5S92XB"FUS
M9W-T<B`B27IB97)I=&4@861R97-A<B(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(R.`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('=H
M:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CHB"FUS
M9W-T<B`B27IB97)I=&4@=G)S=&YI(')E9"!Z82!P<FEK87H@<W1O;'!C978@
M<V5Z;F%M82!N87-L;W9O=BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3<*;7-G:60@(D-O;'5M;B!/<'1I;VYS(@IM<V=S='(@(DUOOFYO<W1I('-T
M;VQP8V5V(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z
M,C,S"FUS9VED(")#;VQU;6YS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(D-O;6UA('-E
M<&%R871E9"!V86QU97,B"FUS9W-T<B`B5G)E9&YO<W1I(&QOZ&5N92!Z('IN
M86MI(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,PIM<V=I9"`B
M0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI(@IM
M<V=S='(@(E9R961N;W-T:2!L;^AE;F4@>B!Z;F%K:2`H36EC<F]S;V9T($]U
M=&QO;VLI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S8*;7-G
M:60@(D-O;7!A;GDB"FUS9W-T<B`B4&]D:F5T:F4B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D-O;7!A;GD@061D<F5S<R(*
M;7-G<W1R(").87-L;W8@4&]D:F5T:F$B"@HC.B!L:6(O87!I+G!H<#HS,3@@
M;&EB+V%P:2YP:'`Z,S8S(&QI8B]A<&DN<&AP.C0P-R!L:6(O87!I+G!H<#HT
M.3$*(SH@;&EB+V%P:2YP:'`Z-C`Q(&QI8B]A<&DN<&AP.C8X."!L:6(O87!I
M+G!H<#HW-#$@;&EB+V%P:2YP:'`Z.#$Y"B,Z(&QI8B]A<&DN<&AP.C$P,#8@
M;&EB+V%P:2YP:'`Z,3`Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B4&]V97IA=F$@<W!O9&QE=&5L83H@
M)7,B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C4X"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QU<F4B"FUS9W-T<B`B4&]V97IA=F$@<W!O9&QE=&5L82(*"B,Z
M(&)R;W=S92YP:'`Z,3DQ(&)R;W=S92YP:'`Z,C,R"B,L(&9U>GIY"FUS9VED
M(")#;VYT86-T(&%D9&5D('1O(&QI<W0N(@IM<V=S='(@(E-T:6L@;V1S=')A
M;FIE;B!S('-E>FYA;6$N(@H*(SH@8G)O=W-E+G!H<#HV,`IM<V=I9"`B0V]N
M=&%C="!R96UO=F5D(&9R;VT@;&ES="XB"FUS9W-T<B`B4W1I:R!O9'-T<F%N
M:F5N(',@<V5Z;F%M82XB"@HC.B!B<F]W<V4N<&AP.C(V-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYT86-T<R!I;B!L:7-T.B`E<R(*;7-G<W1R(")3=&EK
M:2!N82!S97IN86UU.B`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,3(*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:7)A:B(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C4S"B,L(&9U>GIY"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B57-T=F%R:F5N;R(*"B,Z('1E;7!L871E<R]A9&1R
M97-S8F]O:W,N:6YC.C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@061D<F5S
M<R!";V]K(@IM<V=S='(@(EIA<V5B;FD@061R97-A<B(*"B,Z(&QI8B],:7-T
M5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A=&4@82!N97<@0V]N=&%C="!,:7-T
M(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S"FUS
M9VED(")#<F5A=&5D(@IM<V=S='(@(E5S='9A<FIE;F\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E
M8W1I;VXZ(@IM<V=S='(@(E!R:79Z971A('-M97(@<F%Z=G)S=&ET=F4Z(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHR"B,Z(&QI8B]/8FIE8W0N<&AP.C,R."!L:6(O
M4F5N9&5R97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z-3`*;7-G:60@(D1E
M;&5T92(*;7-G<W1R("))>F)R:;EI(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B27IB97)I($%D<F5S87(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T
M<B`B4&]T<F1I=&5V(&EZ8G)I<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@
M(D]B;F&Y86YJ92!G=6UB82!Z82!B<FES86YJ92(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!F86EL
M960Z("@E<RD@)7,B"FUS9W-T<B`B0G)I<V%N:F4@<W!O9&QE=&5L;SH@*"5S
M*2`E<R(*"B,Z(&1E;&5T92YP:'`Z,S@*;7-G:60@(D1E;&5T:6]N(&9A:6QE
M9"(*;7-G<W1R(")"<FES86YJ92!S<&]D;&5T96QO(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM<V=S
M='(@(D]D9&5L96LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G
M:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B4&%D86IOZ"(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C$Q-0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q.`IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DUA<&$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87DB"FUS9W-T
M<B`B36^^;F]S=&D@<')I:V%Z82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B36^^;F]S=&D@<')I:V%Z82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D1O('EO=2!W86YT
M('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T<B`BKF5L:71E
M('!O=')J979A=&D@:7IB<FES('9N;W-O=C\B"@HC.B!L:6(O3V)J96-T+G!H
M<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E!R97-N
M96UI('9#87)D(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$W('1E
M;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C4*;7-G:60@(D1O=VYL
M;V%D('9#87)D(@IM<V=S='(@(E!R97-N96UI('9#87)D(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`R('1E;7!L871E<R]B<F]W<V4O<F]W
M+FEN8SHR-0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN
M8SHQ,"!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*(SH@=&5M<&QA
M=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,R!L:6(O4F5N9&5R97(N<&AP
M.C0R"FUS9VED(")%9&ET(@IM<V=S='(@(E5R961I(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]R;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O
M=RYI;F,Z,S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E
M<UPB(@IM<V=S='(@(E5R961I("<E<R<B"@HC.B!T96UP;&%T97,O861D<F5S
M<V)O;VMS+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B161I="!!9&1R97-S($)O
M;VMS(@IM<V=S='(@(DEZ=F]Z:2!!9')E<V%R(@H*(SH@961I="YP:'`Z-S@@
M961I="YP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@96YT<GD@
M9F]R("5S(@IM<V=S='(@(E5R961I('9P:7,@>F$@)7,B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B
M12UP;[ET82(*"B,Z(&5D:70N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%;G1R>2!F;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D
M960@9FEL92!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$T
M.2!E9&ET+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R
M("5S('5P9&%T960N(@IM<V=S='(@(E9P:7,@>F$@)7,@<&]S;V1O8FQJ96XN
M(@H*(SH@8G)O=W-E+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B16YT<GD@<W5C
M8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(D1A=&]T96MA("5S('5S<&6Y
M;F\@=79OOF5N82(*"B,Z(&QI8B]A<&DN<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@<V5A<F-H:6YG('1H92!A9&1R97-S(&)O
M;VLZ("5S(@IM<V=S='(@(D1O<W1O<"!D;R!A9')E<V%R:F$@;FD@=7-P96PZ
M("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*;7-G<W1R
M("))>G9O>FDB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*;7-G
M:60@(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`B27IV;WII($%D<F5S
M87(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")%
M>'!O<G0@;VYL>2!T:&4@<V5L96-T960@8V]N=&%C=',N(@IM<V=S='(@(DEZ
M=F]Z:2!S86UO(&EZ8G)A;F4@<W1I:V4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP;W)T('1H92!F;VQL;W=I;F<@861D
M<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM<V=S='(@(DEZ=F]Z:2!I>F)R86X@
M861R97-A<B!V(&-E;&]T:2XB"@HC.B!D871A+G!H<#HQ,S0@9&%T82YP:'`Z
M,C(X(&1A=&$N<&AP.C(Y-R!B<F]W<V4N<&AP.C,U(&)R;W=S92YP:'`Z.3`*
M(SH@8G)O=W-E+G!H<#HQ,3(@861D+G!H<#HV-R!S96%R8V@N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E
M<W,@8F]O:SH@)7,B"FUS9W-T<B`B1&]S=&]P(&1O(&%D<F5S87)J82!N:2!U
M<W!E;#H@)7,B"@HC.B!B<F]W<V4N<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@861D("5S('1O("5S.B`E<R(*;7-G<W1R(")$;V1A
M:F%N:F4@)7,@=B`E<R!N:2!U<W!E;&\Z("5S(@H*(SH@8G)O=W-E+G!H<#HR
M-S(*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@;&ES="(*;7-G<W1R(")"<G-K
M86YJ92!P;R!S97IN86UU(&YI('5S<&5L;R(*"B,Z(&)R;W=S92YP:'`Z,S$P
M"FUS9VED(")&86EL960@=&\@8G)O=W-E('1H92!D:7)E8W1O<GDB"FUS9W-T
M<B`B0G)S:V%N:F4@<&\@;6%P:2!N:2!U<W!E;&\B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C,P.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@3F5W
M($1.(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R(")3<')E;6EN:F%N:F4@:6UE
M;F$@;FD@=7-P96QO.B`H)7,I("5S+"`E<R(*"B,Z(&)R;W=S92YP:'`Z,3(P
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T
M;R!B92!A9&1E9#H@)7,B"FUS9W-T<B`B27-K86YJ92!O8FIE:W1O=B!Z82!D
M;V1A:F%N:F4@;FD@=7-P96QO.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O
M:R(*;7-G<W1R(")$;W-T;W`@9&\@861R97-A<FIA(&YI('5S<&5L.B`E<R(*
M"B,Z(&1A=&$N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S(@IM<V=S='(@(DES:V%N:F4@
M<&\@;6%P:2!N:2!U<W!E;&\Z("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,38W"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<R(*"B,Z(&5D
M:70N<&AP.C$R-"!D:7-P;&%Y+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D9I
M;&5S(@IM<V=S='(@(DYA<VQO=B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A
M<F-H+FEN8SHW,`IM<V=I9"`B1FEN9"(*;7-G<W1R("))N>AI(@H*(SH@961I
M="YP:'`Z.3<@961I="YP:'`Z,3@W"B,L(&9U>GIY"FUS9VED(")&:6YI<V@B
M"FUS9W-T<B`B2;GH:2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C0X"FUS9VED(")&:7)S="!.86UE(@IM<V=S='(@(DEM92(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P,@IM<V=I9"`B1G)E96)U<WD@55),
M(@IM<V=S='(@(D9R965B=7-Y(%523"(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<V5A<F-H+FEN8SHX,PIM<V=I9"`B1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C8P-`IM<V=I9"`B1VQO8F%L($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")';&]B86QN:2!!9')E<V%R(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]R;W<N:6YC.C0S('1E;7!L871E<R]B<F]W<V4O8V]N=&%C
M=')O=RYI;F,Z-#0*;7-G:60@(D=R;W5P(@IM<V=S='(@(E-K=7!I;F$B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!
M9&1R97-S(@IM<V=S='(@(D1O;6'H:2!N87-L;W8B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y(@IM<V=S='(@
M(D1O;6%L92!M97-T;R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$P.`IM<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@(D1O;6'H82!D<KYA
M=F$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G:60@
M(DAO;64@4&AO;F4B"FUS9W-T<B`B1&]M8>@@=&5L969O;B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P,PIM<V=I9"`B2&]M92!0;W-T86P@
M0V]D92(*;7-G<W1R(")$;VUAZ&$@<&^Y=&YA(+ET979I;&MA(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3@*;7-G:60@(DAO;64@4W1A=&4O
M4')O=FEN8V4B"FUS9W-T<B`B1&]M8>AA(&1ROF%V82]O:W)A:B(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"B,L(&9U>GIY"FUS9VED(")(
M;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(D1O;6'H:2!N87-L;W8B"@HC
M.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HU,#8*;7-G:60@(DE-4U`B"FUS
M9W-T<B`B24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-PHC+"!F
M=7IZ>0IM<V=I9"`B24U34"!!9&1R97-S($)O;VL@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B4V5Z;F%M($%D<F5S87)J978B"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($%D
M9')E<W,@0F]O:RP@4W1E<"`E9"(*;7-G<W1R(")5=F]Z:2!!9')E9&%R+"!K
M;W)A:R`E9"(*"B,Z(&1A=&$N<&AP.C,V,0IM<V=I9"`B26UP;W)T+T5X<&]R
M="!!9&1R97-S($)O;VMS(@IM<V=S='(@(E5V;WHO27IV;WH@061R97-A<FIE
M=B(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O87!I+G!H<#HV.#,*;7-G:60@
M(DEN=F%L:60@240B"FUS9W-T<B`B3F5V96QJ879N82!)1"(*"B,Z(&QI8B]A
M<&DN<&AP.C(S,"!L:6(O87!I+G!H<#HT,#(@;&EB+V%P:2YP:'`Z-#@V(&QI
M8B]A<&DN<&AP.C4Y,@HC.B!L:6(O87!I+G!H<#HV-SD@;&EB+V%P:2YP:'`Z
M-S,Q(&QI8B]A<&DN<&AP.C$P-S<*;7-G:60@(DEN=F%L:60@861D<F5S<R!B
M;V]K(@IM<V=S='(@(DYE=F5L:F%V96X@861R97-A<B(*"B,Z(&QI8B]A<&DN
M<&AP.C$P.#$@;&EB+V%P:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ,C`W"FUS
M9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(DYE=F5L:F%V;F$@92UP;[ET
M82(*"B,Z(&QI8B]A<&DN<&AP.C$P.#D*;7-G:60@(DEN=F%L:60@96YT<GDB
M"FUS9W-T<B`B3F5V96QJ879E;B!V<&ES(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HR-C8*;7-G:60@(DEN=F%L:60@:V5Y('-P96-I9FEE9"XB"FUS9W-T
M<B`B4&]D86X@;F5V96QJ879E;B!K;&IUZ"XB"@HC.B!L:6(O87!I+G!H<#HQ
M,#@U"FUS9VED("));G9A;&ED(&YA;64B"FUS9W-T<B`B3F5V96QJ879N;R!I
M;64B"@HC.B!L:6(O87!I+G!H<#HW,S4*;7-G:60@(DEN=F%L:60@;V)J96-T
M260B"FUS9W-T<B`B3F5V96QJ879E;B!O8FIE8W1)9"(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U
M:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@
M;F]T(&QO861E9"XB"FUS9W-T<B`B(@HB4&]T<F5B;F$@:F4@<&]D<&]R82!,
M1$%0+"!V96YD87(@3$1!4"!M;V1U;"!N:2!N82!V;VQJ;R!A;&D@;FD@;F%L
M;[YE;BXB"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS9VED("),87-T
M($UO9&EF:65D(@IM<V=S='(@(EIA9&YJ82!S<')E;65M8F$B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PIM<V=I9"`B3&%S="!.86UE(@IM
M<V=S='(@(E!R:6EM96LB"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H
M96%D97)S+FEN8SHQ-@IM<V=I9"`B3&ES="(*;7-G<W1R(")397IN86TB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S<*;7-G:60@(DUA=&-H
M:6YG(@IM<V=S='(@(E5J96UA;FIE(@H*(SH@;&EB+V%P:2YP:'`Z,C`U"B,L
M(&9U>GIY"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!#;VYT86-T<R(*;7-G
M<W1R(").86IV9>AJ92"Y=&5V:6QO('-T<F%N:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F('!A9V5S
M(@IM<V=S='(@(DYA:G9EZ&IE(+ET979I;&\@<W1R86YI(@H*(SH@;&EB+T)L
M;V-K+W1R965?;65N=2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!,:7-T
M(@IM<V=S='(@(DYO=B!397IN86TB"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C
M:"YP:'`Z,PIM<V=I9"`B36EN:2!396%R8V@B"FUS9W-T<B`B36EN:2!I<VMA
M;FIE(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI<W-I
M;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M5B!K;VYF:6=U<F%C:6II($Q$05`@:7IV;W)A(&UA;FIK82!$3BXB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0
M:&]N92(*;7-G<W1R(")-;V)I;&YI('1E;&5F;VXB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@
M(E-P<F5M:6YJ86YJ92!N:2!U<W!E;&\Z("@E<RD@)7,B"@HC.B!L:6(O87!I
M+G!H<#HQ,3DS"FUS9VED(")-;W)E('1H86X@,2!E;G1R>2!F;W5N9"(*;7-G
M<W1R(")69>@@:V]T(#$@=G!I<R!N86ID96XB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")-;W9E(@IM<V=S='(@(E!R96UA
M:VYI(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0W
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@T
M"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B4')E;6%K;FD@;&5V;R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T.0HC.B!T96UP
M;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X-@IM<V=I9"`B
M36]V92!R:6=H="(*;7-G<W1R(")0<F5M86MN:2!D97-N;R(*"B,Z(&1A=&$N
M<&AP.C4R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,38*;7-G:60@(DUU
M;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G<W1R(")-=6QB97)R>2!!9')E<V%R
M(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)-=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N
M92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T(@IM<V=S='(@(D]B<W1A
M:F$@=F7H(&]S96(@>B!N87-L;W9O;2!;)7-=+"!V96YD87(@;F]B96YA('H@
M:6UE;F]M(%LE<UTB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ,#<@
M8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,C0S"B,L(&9U>GIY"FUS9VED(")-
M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B36]J($%D<F5S87(B"@HC.B!A9&1R
M97-S8F]O:W,N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S<R!"
M;V]K<R(*;7-G<W1R(")-;VH@061R97-A<B(*"B,Z('1E;7!L871E<R]A9&1R
M97-S8F]O:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT
M,@IM<V=I9"`B3F%M92(*;7-G<W1R("));64B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@(D]B;&EK
M82!I;65N82(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I
M9"`B3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B26UE;FEK
M(.AL86YO=B!S=&]R:71V92!.971C96YT97(B"@HC.B!A9&0N<&AP.C,V(&%D
M9"YP:'`Z,3(T(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HR-PHC.B!L:6(O
M0FQO8VLO=')E95]M96YU+G!H<#HR-PIM<V=I9"`B3F5W($-O;G1A8W0B"FUS
M9W-T<B`B3F]V(%-T:6LB"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY-2!E
M9&ET+G!H<#HR,#(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT-0IM<V=I
M9"`B3F5X="(*;7-G<W1R(").87!R96HB"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HR,3@*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(DYA9&EM
M96LB"@HC.B!L:6(O87!I+G!H<#HQ,3DU(&QI8B]A<&DN<&AP.C$R-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S(@IM
M<V=S='(@(DYO8F5N('9P:7,@)7,@;FD@8FEL(&YA:F1E;B!Z82`E<R(*"B,Z
M(&QI8B]A<&DN<&AP.C$Q-C,*;7-G:60@(DYO(&%D9')E<W,@8F]O:W,@9F]U
M;F0N(@IM<V=S='(@(DYO8F5N(&%D<F5S87(@;FD@8FEL(&YA:F1E;BXB"@HC
M.B!M:6YI<V5A<F-H+G!H<#HX,PIM<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B
M"FUS9W-T<B`B3F]B96X@<W1I:R!N:2!B:6P@;F%J9&5N(@H*(SH@;&EB+V%P
M:2YP:'`Z-3$Q(&QI8B]A<&DN<&AP.C<V-@IM<V=I9"`B3F\@=D-A<F0@9&%T
M82!W87,@9F]U;F0N(@IM<V=S='(@(E!O9&%T:VD@=D-A<F0@;FES;R!B:6QI
M(&YA:F1E;FDN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C<*
M;7-G:60@(DYO;F4B"FUS9W-T<B`B3F]B96XB"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM<V=S='(@(D)E;&6^
M:V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(").=6UB
M97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T<B`BJ71E=FEL;R!O8FIE:W1O
M=B!N82!S=')A;B(*"B,Z(&QI8B]A<&DN<&AP.C8Q-"!L:6(O87!I+G!H<#HW
M-#<*;7-G:60@(D]B:F5C="!N;W0@9F]U;F0B"FUS9W-T<B`B3V)J96MT(&YI
M(&)I;"!N86ID96XB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR
M,C,*;7-G:60@(D]F9FEC92(*;7-G<W1R(")0:7-A<FYA(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VEM<W!?;W!T+FEN8SHR,PIM<V=I9"`B(@HB3VYC92!Y;W4@
M<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D<F5S<R!B;V]K('=I;&P@
M8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"X@268@=&AI<R!I<R!N;W0@=VAA
M="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N9V4@>6]U<B!S96QE8W1I
M;VX@(@HB=&\@7").;VYE7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C<W-`IM<V=I9"`B3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0V"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D]S
M=&%L92!M;[YN;W-T:2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B2F%V;FD@4$=0
M(&ML:G7H(@H*(SH@;&EB+V%P:2YP:'`Z-#DU(&QI8B]A<&DN<&AP.C8P-2!L
M:6(O87!I+G!H<#HV.3(@;&EB+V%P:2YP:'`Z.3,T"B,Z(&QI8B]A<&DN<&AP
M.C$P.3@*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(D1O<W1O
M<"!Z879R;FIE;B(*"B,Z(&QI8B]$<FEV97(N<&AP.C4T,PIM<V=I9"`B4&5R
M;6ES<VEO;B!D96YI960B"FUS9W-T<B`B1&]S=&]P('IA=G)N:F5N(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3D*(RP@9G5Z>GD*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(D1O<W1O<"!Z879R;FIE;B(*"B,Z(&1A
M=&$N<&AP.C4S('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*;7-G:60@
M(E!I;F4@061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@061R97-A<B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*(RP@9G5Z>GD*
M;7-G:60@(E!L96%S92!N86UE('1H92!N97<@8V]N=&%C="!L:7-T.B(*;7-G
M<W1R(")0<F]S:6T@=G!IN6ET92!I;64@>F$@;F]V('-E>FYA;3HB"@HC.B!E
M9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HQ.30*;7-G:60@(E!R
M979I;W5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C0Q-@IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B6F%S
M96)N:2!!9')E<V%R(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B475E<GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S
M='(@(E!O:7IV961B82!J92!S<&]D;&5T96QA.B`H)7,I("5S(@H*(SH@=&5M
M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"FUS9VED(")1=6EC:R!3
M96%R8V@B"FUS9W-T<B`B2&ET<F\@27-K86YJ92(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E860@9F%I
M;&5D.B`H)7,I("5S(@IM<V=S='(@(D)R86YJ92!S<&]D;&5T96QO.B`H)7,I
M("5S(@H*(SH@;&EB+U)E;F1E<F5R+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E
M;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB
M"FUS9W-T<B`B4')I:V%Z86YI('IA<&ES:3HB"@HC.B!T96UP;&%T97,O<')E
M9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-@HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E(&%D9')E<W,@8F]O:R(*;7-G<W1R("))>F)E<FET92!A9')E<V%R
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,Y"FUS
M9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(D]D<W1R86YI('-T;VQP96,B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@(E)E
M;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R(")/9'-T<F%N:2!S('1E9V$@
M<V5Z;F%M82(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K
M('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES
M("(*(F1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E
M<W,@8F]O:RX\+W-T<F]N9SXB"FUS9W-T<B`B(@HB6F%M96YJ86T@;V)S=&]J
M9>@@861R97-A<B!Z('5V;[YE;FEM/R`\8CY/<&]Z;W)I;&\Z(%1O(&1E:F%N
M:F4@8F\@:7IB<FES86QO("(*(G9S92!Z87!I<V4@=B!V8;EE;2!T<F5N=71N
M96T@861R97-A<FIU+CPO8CXB"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G
M:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R("):86AT
M979A;B!O8FIE:W0@;FD@8FEL(&YA:F1E;BXB"@HC.B!A9&0N<&AP.C,W('1E
M;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G:60@(E)E<V5T('1O
M($1E9F%U;'1S(@IM<V=S='(@(E!O;F%S=&%V:2!N82!0<FEV>F5T;R(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%
M(%!U8FQI8R!#97)T:69I8V%T92(*;7-G<W1R(")*879N;R!3+TU)344@4&]T
M<F1I;&\B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C8Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")35$%25%1,4R!F86EL960Z("@E<RD@)7,B"FUS
M9W-T<B`B0G)A;FIE('-P;V1L971E;&\Z("@E<RD@)7,B"@HC.B!E9&ET+G!H
M<#HY.2!A9&0N<&AP.C,W('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$R
M-`IM<V=I9"`B4V%V92(*;7-G<W1R(")3:')A;FDB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+W-E87)C:"YI;F,Z.38@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.C$Q,@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C$@
M;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z-#D*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(DFYZ&DB"@HC.B!M
M:6YI<V5A<F-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(%)E<W5L
M=',Z(@IM<V=S='(@(E)E>G5L=&%T:2!I<VMA;FIA(@H*(SH@;&EB+V%P:2YP
M:'`Z,3`Q,0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R("))<VMA;FIE
M('-P;V1L971E;&\B"@HC.B!L:6(O87!I+G!H<#HQ,3`S(&QI8B]A<&DN<&AP
M.C$Q,#D@;&EB+V%P:2YP:'`Z,3$Q."!L:6(O87!I+G!H<#HQ,3,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E-E87)C:"!F86EL960Z("5S(@IM<V=S='(@(DES
M:V%N:F4@<W!O9&QE=&5L;SH@)7,B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN
M:7-E87)C:"YI;F,Z,C(*;7-G:60@(E-E87)C:&EN9RXN+B(*;7-G<W1R("))
MN>AE;2XN+B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86X@861D<F5S<R!B;V]K('1O(&1E;&5T
M92(*;7-G<W1R("))>F)E<FET92!A9')E<V%R('IA(&EZ=F]Z.B(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDP"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@86X@861D<F5S<R!B;V]K('1O(&5D:70B"FUS9W-T<B`B27IB97)I
M=&4@861R97-A<B!Z82!U=F]Z.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,S(*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X
M<&]R="!F<F]M.B(*;7-G<W1R("))>F)E<FET92!A9')E<V%R('IA(&EZ=F]Z
M.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C8*;7-G:60@(E-E
M;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B
M27IB97)I=&4@861R97-A<B!Z82!U=F]Z.B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,S4*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@8VAA
M<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(DEZ8F5R:71O(&]B
M;&EK;R!I>G9O<FYE(&1A=&]T96ME.B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,3`*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB
M"FUS9W-T<B`B27IB97)I=&4@;V)L:6MO(&EZ=F]Z83HB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C0S"FUS9VED(")396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.B(*;7-G<W1R("))>F)E<FET92!D871O=&5K;R!Z82!U=F]Z
M.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G:60@(E-E
M;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B
M27IB97)I=&\@;V)L:6MO(&EZ=F]R;F4@9&%T;W1E:V4Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@
M=7-E9"!T;R!D:7-P;&%Y(&YA;65S.B(*;7-G<W1R("))>F)E<FET92!O8FQI
M:V\@>F$@<')I:V%Z(&EM96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y
M(&1E9F%U;'0L('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+B(*
M;7-G<W1R("))>F)E<FET92!P<FEV>F5T:2!N8>AI;B!P<FEK87IA+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.`IM<V=I9"`B4V5L96-T('=H:6-H
M(&9I96QD<R!T;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+B(*;7-G
M<W1R("))>F)E<FET92!K871E<F$@<&]L:F$@;F%J(&)O9&\@<')I:V%Z86YA
M('8@<V5Z;F%M:6@@;F%S;&]V;W8N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,R"FUS9VED(")396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@
M;F%M97,N(@IM<V=S='(@(DEZ8F5R:71E(&]B;&EK;R!Z82!P<FEK87H@:6UE
M;BXB"@HC.B!A9&0N<&AP.C4T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")396QE8W1E9"!A9&1R97-S(&)O;VL@7"(E<UPB+B(*;7-G<W1R("))>F)R
M86X@861R97-A<B`G)7,G+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C$W,PIM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G<W1R(")-87!A('8@
M4VMU<&YI(')A8FDB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W("5S(@IM<V=S
M='(@(E!R:6MAOFDB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C0Q"FUS9VED(")3:&]W($%L;"(*;7-G<W1R(")0<FEK8;YI(%9S92(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@(E-H;W<@
M0V]N=&%C=',B"FUS9W-T<B`B4')I:V&^:2!3=&EK92(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*;7-G:60@(E-H;W<@3&ES=',B"FUS
M9W-T<B`B4')I:V&^:2!397IN86UE(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C
M;VQU;6Y?:&5A9&5R<RYI;F,Z,C$*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU
M;6Y?:&5A9&5R<RYI;F,Z,S0*;7-G:60@(E-O<G0@1&ER96-T:6]N(@IM<V=S
M='(@(E-M97(@<F%Z=G)S=&ET=F4B"@HC.B!L:6(O87!I+G!H<#HQ.3@*;7-G
M:60@(E-O=7)C97,B"FUS9W-T<B`B27IV;W)I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U-PIM<V=I9"`B4W!E8VEF>2!W:&5R92!Y;W4@=V%N="!A
M9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N(@IM<V=S='(@(D1O
M;&_H:71E+"!K:F4@;F%J(&)O9&\@<')I:V%Z86YI("!R97IU;'1A=&D@;F%P
M<F5D;F5G82!I<VMA;FIA+B(*"B,Z(&)R;W=S92YP:'`Z,30Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<R(*;7-G
M<W1R(")5<W!EN6YO(&1O9&%L("5S('8@)7,B"@HC.B!B<F]W<V4N<&AP.C(R
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-R
M96%T960@=&AE(&-O;G1A8W0@;&ES="!<(B5S7"(N(@IM<V=S='(@(E5S<&6Y
M;F\@9&]D86P@)7,@=B`E<R(*"B,Z(&1A=&$N<&AP.C4P"FUS9VED(")44U8B
M"FUS9W-T<B`B5%-6(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ
M-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$T"FUS9VED(")486(@<V5P
M87)A=&5D('9A;'5E<R(*;7-G<W1R(")6<F5D;F]S=&D@;&_H96YE(',@5&%B
M+6DB"@HC.B!V:65W+G!H<#HQ-0IM<V=I9"`B5&AE(%9&4R!B86-K96YD(&YE
M961S('1O(&)E(&-O;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L
M;V%D<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`U-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S
M7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D%D<F5S87)J82!N:2!B:6QO
M(&UO9V_H92!P;^AI<W1I=&DZ("5S(@H*(SH@861D<F5S<V)O;VMS+G!H<#HT
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!
M9')E<V%R('5S<&6Y;F\@<&_H:;GH96XN(@H*(SH@861D<F5S<V)O;VMS+G!H
M<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@
M8F]O:R!<(B5S7"(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M(")!9')E<V%R('5S<&6Y;F\@<&_H:;GH96XN(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HX.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E
M<W,@8F]O:R!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G
M<W1R(")!9')E<V%R('5S<&6Y;F\@<&_H:;GH96XN(@H*(SH@9&%T82YP:'`Z
M,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U
M;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B061R97-A<FIA(&YI(&)I
M;&\@;6]G;^AE('!OZ&ES=&ET:3H@)7,B"@HC.B!E9&ET+G!H<#HT-R!V8V%R
M9"YP:'`Z,C(@9&ES<&QA>2YP:'`Z,C,@=FEE=RYP:'`Z,C8*;7-G:60@(E1H
M92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(EIA:'1E=F%N('-T:6L@;F4@;V)S=&%J82XB"@HC.B!E9&ET+G!H<#HQ
M,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE(%PB)7-<
M(B!H87,@<W5C8V5S<V9U;&QY(&)E96X@9&5L971E9"XB"FUS9W-T<B`B1&%T
M;W1E:V$@)7,@=7-P9;EN;R!U=F^^96YA(@H*(SH@9&%T82YP:'`Z,C@T"FUS
M9VED(")4:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W
M87)N:6YG<RXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RXB"FUS9W-T
M<B`B3FD@861R97-A<FIE=B!P;R!K871E<FEH(&)I(&)I;&\@;6]G;^AE(&)R
M<VMA=&DN(@H*(SH@861D+G!H<#HR.0IM<V=I9"`B(@HB5&AE<F4@87)E(&YO
M('=R:71E86)L92!A9&1R97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B
M;&4@861D<F5S<R!B;V]K<R`B"B)A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y
M;W4@=&\@861D(&YE=R!E;G1R:65S('1O('1H96TN($EF('EO=2!B96QI979E
M('1H:7,@(@HB:7,@86X@97)R;W(L('!L96%S92!C;VYT86-T('EO=7(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DYI(&%D<F5S87)J978L
M('8@:V%T97)E(&)I(&)I;&\@;6]G;^AE('!I<V%T:2X@3F]B96X@:7IM960@
M861R97-A<FIE=BP@:VD@(@HB<V]N82!V;VQJ;R!N:2!N87-T879L:F5N('1A
M:V\L(&1A(&)I('9A;2!D;W9O;&IE=F%L(&1O9&%J86YJ92!V<&ES;W8N(,AE
M("(*(G-M871R871E(&1A(&=R92!Z82!N87!A:V\L('!R;W-I;2!K;VYT86MT
M:7)A:G1E('-V;VIE9V$@<VMR8FYI:V$@<VES=&5M82XB"@HC.B!A9&0N<&AP
M.C$R,0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@
M;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)0<FD@9&]D86IA
M;FIU('-T:6MA(&IE('!R:;EL;R!D;R!N87!A:V4N(%IA(&YA9&%L:FYO('!O
M;6_H(&MO;G1A:W1I<F%J=&4@(@HB<W9O:F5G82!S:W)B;FEK82!S:7-T96UA
M+B(*"B,Z(&)R;W=S92YP:'`Z,3@Y(&)R;W=S92YP:'`Z,C,P"B,L(&9U>GIY
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H:7,@;V)J96-T
M+B(*;7-G<W1R(")0<FD@8G)I<V%N:G4@;V)J96MT82!J92!P<FFY;&\@9&\@
M;F%P86ME+B(*"B,Z(&)R;W=S92YP:'`Z,C,X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="XB"FUS9W-T<B`B4')I('5S
M='9A<FIA;FIU(&YO=F5G82!S97IN86UA(&IE('!R:;EL;R!D;R!N87!A:V4N
M(@H*(SH@861D<F5S<V)O;VMS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D
M<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")0<FD@<&]S;V1O8FQJ86YJ=2!V<&ES
M82!J92!P<FFY;&\@9&\@;F%P86ME.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,30W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@7"(E<UPB(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(E!R:2!B<FES86YJ=2`E<R!I>B!A9')E<V%R:F$@:F4@
M<')IN6QO(&1O(&YA<&%K92XB"@HC.B!D96QE=&4N<&AP.C,W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES
M(&-O;G1A8W0Z("5S(@IM<V=S='(@(E!R:2!B<FES86YJ=2!S=&EK82!J92!P
M<FFY;&\@9&\@;F%P86ME.B`E<R(*"B,Z(&)R;W=S92YP:'`Z-S(*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C="XB"FUS
M9W-T<B`B4')I(&)R:7-A;FIU(&]B:F5K=&$@:F4@<')IN6QO(&1O(&YA<&%K
M92XB"@HC.B!B<F]W<V4N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AE(&QI<W0B"FUS9W-T<B`B4')I
M('!R:6MA>G4@:7IB<F%N96=A('-E>FYA;6$@:F4@<')IN6QO(&1O(&YA<&%K
M92(*"B,Z(&1A=&$N<&AP.C,S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R
M(")0<FD@=79AOF%N:G4@<&]D871K;W8@:F4@<')IN6QO(&1O(&YA<&%K93H@
M)7,B"@HC.B!L:6(O87!I+G!H<#HU,#<@;&EB+V%P:2YP:'`Z-S8Q"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82XB"FUS9W-T<B`B4')I('5V8;YA;FIU(&E#86QE;F1A<B!P;V1A=&MO
M=B!J92!P<FFY;&\@9&\@;F%P86ME+B(*"B,Z(&)R;W=S92YP:'`Z-3@*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!A(&-O
M;G1A8W0@9G)O;2!T:&4@;&ES="XB"FUS9W-T<B`B4')I('5S='9A<FIA;FIU
M(&YO=F5G82!S97IN86UA(&IE('!R:;EL;R!D;R!N87!A:V4N(@H*(SH@861D
M<F5S<V)O;VMS+G!H<#HU-2!A9&1R97-S8F]O:W,N<&AP.C8P(&%D9')E<W-B
M;V]K<RYP:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B
M"FUS9W-T<B`B4')I(&]D<W1R86YJ979A;FIU(&]B:F5K=&$@:F4@<')IN6QO
M(&1O(&YA<&%K92XB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C@Q(&%D9')E<W-B
M;V]K<RYP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B
M"FUS9W-T<B`B4')I('!O<V]D;V)L:F%N:G4@=G!I<V$@:F4@<')IN6QO(&1O
M(&YA<&%K93H@)7,B"@HC.B!E9&ET+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT<GDZ
M("5S(@IM<V=S='(@(E!R:2!P;W-O9&]B;&IA;FIU('9P:7-A(&IE('!R:;EL
M;R!D;R!N87!A:V4Z("5S(@H*(SH@9&%T82YP:'`Z,3<Y"FUS9VED(")4:&5R
M92!W97)E(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N(@IM<V=S='(@(DYI(&YA
M<VQO=F]V('IA(&EZ=F]Z+B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S
M8F]O:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R97-S(&)O;VMS
M('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#,*;7-G:60@(E1H
M97-E(&-O;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA
M="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")/8FQI:V$@9&%T;W1E:V4@
M;FD@<&]D<')T82XB"@HC.B!L:6(O87!I+G!H<#HQ,3(R(&QI8B]A<&DN<&AP
M.C$Q,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D
M>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@
M(D]S96)A(+YE(&EM82`E<R!V<&ES('8@861R97-A<FIU(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T-PIM<V=I9"`B(@HB5&AI<R!W:6QL(&)E('1H
M92!D969A=6QT(&%D9')E<W,@8F]O:R!W:&5N(&%D9&EN9R!O<B!I;7!O<G1I
M;F<@8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C<P"FUS9VED(")4:71L92(*;7-G<W1R(").87-L;W8B"@HC
M.B!L:6(O5'5R8F$N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(&YE=R!S:&%R92X@($UI<W-I;F<@<V]U<F-E('1Y<&4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.CDW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E
M<RXB"FUS9W-T<B`B1&5F:6YI8VEJ92`E<R!N:2!B:6QO(&UO9V_H92!N86QO
MOFET:2XB"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY
M-"!E9&ET+G!H<#HY.2!E9&ET+G!H<#HQ.38*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R(")0<F5K;&GH:2!S<')E;65M8F4B"@HC.B!L:6(O87!I+G!H
M<#HU-#`@;&EB+V%P:2YP:'`Z-C0S(&QI8B]A<&DN<&AP.C<W.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E
M.B`E<R(*;7-G<W1R(").97!O9'!R="!T:7`@=G-E8FEN92(*"B,Z(&-O;F9I
M9R]S;W5R8V5S+G!H<"YD:7-T.C,W-@IM<V=I9"`B5F5R:7-I9VX@1&ER96-T
M;W)Y(@IM<V=S='(@(E9E<FES:6=N($EM96YI:R(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N
M:6YC.C(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(%PB)7-<
M(B(*;7-G<W1R(")0;V=L96H@)R5S)R(*"B,Z(&UI;FES96%R8V@N<&AP.C<X
M"FUS9VED(")6:65W($-O;G1A8W0B"FUS9W-T<B`B4&]G;&5J(%-T:6LB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")6:65W('1O(&1I
M<W!L87D@8GD@9&5F875L=#HB"FUS9W-T<B`B4')I=GIE=&D@;F'H:6X@<')I
M:V%Z83HB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,#@*;7-G
M:60@(E=E8G-I=&4@55),(@IM<V=S='(@(E-P;&5T;F$@<W1R86XB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3,*;7-G:60@(E=O<FL@061D
M<F5S<R(*;7-G<W1R(")3;'6^8F5N:2!N87-L;W8B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O<FL@0VET>2(*;7-G<W1R
M(")-97-T;R!S;'6^8F4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ,SD*;7-G:60@(E=O<FL@0V]U;G1R>2(*;7-G<W1R(")$<KYA=F$@<VQU
MOF)E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34V"FUS9VED
M(")7;W)K(%!H;VYE(@IM<V=S='(@(E-L=;YB96YI('1E;&5F;VXB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,S0*;7-G:60@(E=O<FL@4&]S
M=&%L($-O9&4B"FUS9W-T<B`B4&^Y=&YA(+ET979I;&MA('-L=;YB92(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R.0IM<V=I9"`B5V]R:R!3
M=&%T92]0<F]V:6YC92(*;7-G<W1R(")$<KYA=F$O3VMR86H@<VQUOF)E(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$Y"B,L(&9U>GIY"FUS
M9VED(")7;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(E-L=;YB96YI(&YA
M<VQO=B(*"B,Z(&1A=&$N<&AP.C(S-R!B<F]W<V4N<&AP.CDS(&)R;W=S92YP
M:'`Z,C`Q(&%D9"YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S
M(&EN(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-CD@9&ES<&QA
M>2YP:'`Z-3@@=FEE=RYP:'`Z,S8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R("):82!O
M9VQE9"!S=&EK82!N:6UA=&4@9&]V;VQJ96YJ82XB"@HC.B!V8V%R9"YP:'`Z
M-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@
M=&AI<R!O8FIE8W0N(@IM<V=S='(@(EIA(&]G;&5D(&]B:F5K=&$@;FEM871E
M(&1O=F]L:F5N:F$N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T
M+FEN8SHU-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B27IB<F%T:2!M;W)A=&4@8VEL:FYI(&%D<F5S
M87(N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHR,PIM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N(@IM<V=S='(@
M(DEZ8G)A=&D@;6]R871E(&-I;&IN:2!S97IN86TN(@H*(SH@961I="YP:'`Z
M,S(*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O
M;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B3F%J<')E:B!M;W)A=&4@:7IB
M<F%T:2!V<V%J(&5N('9P:7,N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A
M<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C0Y"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-S(*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@96YT<GD@9FER<W0N
M(@IM<V=S='(@(DYA:G!R96H@;6]R871E(&EZ8G)A=&D@=G-A:B!E;B!V<&ES
M+B(*"B,Z(&5D:70N<&AP.C<S"FUS9VED(")9;W4@;VYL>2!H879E('!E<FUI
M<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(EIA(&]G;&5D
M('-T:6MA('!O=')E8G5J971E('!R879I8V4N(@H*(SH@8G)O=W-E+G!H<#HR
M.#4*;7-G:60@(EEO=7(@9&5F875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R
M;W=S96%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W
M+FEN8SHV('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G
M:60@(EMN;R!V86QU95TB"FUS9W-T<B`B6V)R97H@=G)E9&YO<W1I72(*"B,Z
M(&QI8B]4=7)B82YP:'`Z-#@T"FUS9VED(")?0G)O=W-E(@IM<V=S='(@(E]"
M<G-K86HB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"B,L
M(&9U>GIY"FUS9VED(")?0V]N=&%C=',B"FUS9W-T<B`B4')I:V&^:2!?4W1I
M:V4B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@
M(E]$96QE=&4B"FUS9W-T<B`B7TEZ8G)IN6DB"@HC.B!L:6(O5'5R8F$N<&AP
M.C0Y,PIM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7U5V;WII+TEZ
M=F]Z:2(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@
M9G5Z>GD*;7-G:60@(E],:7-T<R(*;7-G<W1R(")397IN86TB"@HC.B!L:6(O
M5'5R8F$N<&AP.C0X,0HC+"!F=7IZ>0IM<V=I9"`B7TUY($%D9')E<W,@0F]O
M:W,B"FUS9W-T<B`B36]J($%D<F5S87(B"@HC.B!L:6(O5'5R8F$N<&AP.C0X
M-PHC+"!F=7IZ>0IM<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S='(@(DYO=B!3
M=&EK(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED
M(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(E]/9'-T<F%N:2!S
M('-E>FYA;6$B"@HC.B!L:6(O5'5R8F$N<&AP.C0X.0IM<V=I9"`B7U-E87)C
M:"(*;7-G<W1R(")?2;GH:2(*"B,Z('9C87)D+G!H<#HT-@IM<V=I9"`B8V]N
M=&%C="YV8V8B"FUS9W-T<B`B8V]N=&%C="YV8V8B"@HC.B!D871A+G!H<#HQ
M.3D@9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM
M<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(F-O;G1A8W1S+F-S=B(*"B,Z
M(&1A=&$N<&AP.C(P.0IM<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@(F-O
M;G1A8W1S+G1S=B(*"B,Z(&1A=&$N<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B
M8V]N=&%C=',N=F-F(@IM<V=S='(@(F-O;G1A8W0N=F-F(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VEM<W!?;W!T+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B;F]N
M92(*;7-G<W1R(").;V)E;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(G1O(&$@0V]N=&%C="!,:7-T(@IM
M<V=S='(@(E!R:6MAOFD@4W1I:V4B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")T;R!A(&1I9F9E<F5N="!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B=B!)>F)R86X@061R97-A<B(*"B,Z(&1A
M=&$N<&AP.C4Q('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC
M.C$S"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A
M<F0B"@``````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A
M+W!O+V)G7T)'+G!O````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P-S,S,#$`,3`T,3<S-C(W-38`,#$W-#8S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````",@0G5L9V%R:6%N('1R
M86YS;&%T:6]N<R!F;W(@5'5R8F$@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I
M(#(P,#(@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E
M9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!4=7)B82!P86-K86=E
M+@HC($UI<F]S;&%V(%!E;F1E=B`\;6ER;T!C>6)E<G-H861E+G5S/BP@,C`P
M,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@
M5'5R8F$@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,3$M
M,3D@,C`Z-#0M,#4P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!-:7)O<VQA=B!0
M96YD978@/&UI<F]`8WEB97)S:&%D92YU<SY<;B(*(DQA;F=U86=E+51E86TZ
M($)'(&DQ.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B)-24U%+59E<G-I;VXZ(#$N
M,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U
M,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHT,@HC+"!F=7IZ>0IM<V=I
M9"`B($%D9"!A;B!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE(,#D
M\.7Q[>`@ZNWHX^`B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC
M.C,Q"B,L(&9U>GIY"FUS9VED("(@1&5L971E($E-4U`@061D<F5S<R!";V]K
M(@IM<V=S='(@(LCGX>7PZ"#@Y/#E\>W@(.KMZ./@(@H*(SH@9&%T82YP:'`Z
M,S(U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!A;')E861Y(&5X:7-T
M<R!A;F0@=V%S(&YO="!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E
M+G!H<#HQ,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@
M8V]P:65D(&)E8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!B
M<F]W<V4N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&YO="!M;W9E9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA
M;64@3&%S=&YA;65<(B`@*&EE+B!*;VAN($1O92DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@
M1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(B(*"B,Z(&%D
M9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%D9&5D+B(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B)7,@].#I
MZR#AY?CE(.CL[^[P\NCPX.T@\_'OY?CM[B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O9F]O=&5R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S
M(&]F("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#0V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G
M<W1R(")0:6YE(,#D\.7Q[>`@ZNWHX^`B"@HC.B!L:6(O0FQO8VLO;6EN:7-E
M87)C:"YP:'`Z-#4*;7-G:60@(D$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&
M<F%M97,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U.0IM<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T
M<B`B(@H*(SH@=FEE=RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C
M97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C4V('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D%D9"(*;7-G
M<W1R("+$[N'@XN@B"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS
M96QE8W0N:6YC.C$W-`HC+"!F=7IZ>0IM<V=I9"`B061D(&%D9')E<W,@8F]O
M:R(*;7-G<W1R("+-Y>+@Z^CD[>`@X.3PY?'MX"#J[>CCX"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!A;F0@
M1&5L971E($E-4U`@861D<F5S<R!B;V]K<R(*;7-G<W1R("+-_^S@(.#D\.7Q
M[>@@ZNWHX^@L(.(@ZN[H\NX@[.[FY?+E(.3@(._H^.7RY2XB"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`BY.[AX.+H(.KNZ^[MX"(*"B,Z(&5D
M:70N<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B061D(&9I;&4B"FUS9W-T<B`B
MP_#E^.K@(._PZ"#D[N'@XO_MY2(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R(*;7-G<W1R("+$
M[N'@XN@B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F
M=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@P.3PY?'M
MX"#J[>CCX"(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B
MP.3PY?'E[2#Q[^CQ^NHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*
M(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`BR.?U[N0@
MX.3PY?'MX"#J[>CCX"(*"B,Z(&%D9"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED
M(")!9&1R97-S(&)O;VL@96YT<GDB"FUS9W-T<B`BP.3PY?'MX/+@(.KMZ./@
M(.4@XB#PY>;H["#WY?+E[>4N(@H*(SH@9&%T82YP:'`Z,S`U"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS
M9W-T<B`B4&EN92#@Y/#E\>W@(.KMZ./@(.'E^.4@Z.SO[O#RZ/#@[>`@\_'O
MY?CM[B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8R"B,L(&9U
M>GIY"FUS9VED(")!9&1R97-S(&)O;VL@=&\@9&5L971E("(*;7-G<W1R("+`
MY/#E\>W@\N`@ZNWHX^`@Y2#B(/#EYNCL(/?E\N7MY2XB"@HC.B!T96UP;&%T
M97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`IM<V=I9"`B061D
M<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T
M<B`B(@H*(SH@<V5A<F-H+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z,S<*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R("+0X.?X
MZ/#E[>X@\OKP\>7MY2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C8T"FUS9VED(")!;&EA<R(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA+FEN8SHW('1E;7!L871E<R]B<F]W
M<V4O9F]O=&5R06QP:&$N:6YC.C$P"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z-#$*;7-G:60@(D%L;"(*;7-G<W1R("+"\>CWZN@B"@HC.B!L
M:6(O87!I+G!H<#HU-3(*;7-G:60@(D%L<F5A9'D@17AI<W1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@
M=&\@9&5L971E("5S/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+VIA=F%S8W)I<'0N:6YC.C8W"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y
M;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N=')I97,_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B07-C
M96YD:6YG(@IM<V=S='(@(LW@\.#Q\N+@^>@B"@HC.B!S96%R8V@N<&AP.C@U
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS-@HC+"!F=7IZ>0IM<V=I
M9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(M+Z\/'H(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O<FTB"FUS
M9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-R!L:6(O1')I=F5R
M+VQD87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE;G4N:6YC.C<*;7-G:60@(D)R;W=S92(*;7-G<W1R("+/\.7C
MZ^7DX.DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*;7-G
M:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C0Y"FUS9VED(")#4U8B"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C="]'<F]U
M<"YP:'`Z-3<*;7-G:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R
M<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C0T"FUS9VED(")#:&]O<V4@
M82!N86UE(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z-#@*(RP@9G5Z>GD*;7-G
M:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLB"FUS9W-T<B`BS>7BX.OHY.W@
M(.#D\.7Q[>`@ZNWHX^`N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E
M;&5C="YI;F,Z,C(Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@861D<F5S
M<R!B;V]K.B(*;7-G<W1R("+-Y>+@Z^CD[>`@X.3PY?'MX"#J[>CCX"XB"@HC
M.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$V-0IM
M<V=I9"`B0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@9&ES<&QA>2P@
M86YD(&EN('=H870@;W)D97(Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,0IM<V=I9"`B0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O
M:W,@=&\@=7-E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L
M=6UN<V5L96-T+FEN8SHR,C@*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!W:&EC
M:"!C;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H870@;W)D97(Z(@IM<V=S
M='(@(LCGX>7PY?+E(/#EY.`@[>`@[^[JX.?BX.WE(.W@(.KNZ^[MZ/+E(.(@
MX.3PY?'MZ/\@\>_H\?KJ+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-PIM<V=I9"`B0V]L=6UN($]P=&EO;G,B"FUS9W-T<B`BSN_VZ.@@Y^`@ZN[K
M[NWH\N4B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR
M,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3,@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I9"`B0V]M;6$@<V5P
M87)A=&5D('9A;'5E<R(*;7-G<W1R(")#4U8@+2#PX.?DY>OE[>@@\?KQ(.?@
M[^7RX/\@\?+NZ>WN\?+H(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H
M36EC<F]S;V9T($]U=&QO;VLI(@IM<V=S='(@(D-35B`M(/#@Y^3EZ^7MZ"#Q
M^O$@Y^#OY?+@_R#Q\N[I[>[Q\N@B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+*[NSOX.WH_R(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`HC+"!F=7IZ>0IM
M<V=I9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S='(@(L3N[.#XY>T@X.3PY?$B
M"@HC.B!L:6(O87!I+G!H<#HS,3@@;&EB+V%P:2YP:'`Z,S8S(&QI8B]A<&DN
M<&AP.C0P-R!L:6(O87!I+G!H<#HT.3$*(SH@;&EB+V%P:2YP:'`Z-C`Q(&QI
M8B]A<&DN<&AP.C8X."!L:6(O87!I+G!H<#HW-#$@;&EB+V%P:2YP:'`Z.#$Y
M"B,Z(&QI8B]A<&DN<&AP.C$P,#8@;&EB+V%P:2YP:'`Z,3`Y-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(L/PY?CJX"#O\.@@\O#HY>WE(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM
M<V=S='(@(L/PY?CJX"#O\.@@\O#HY>WE(@H*(SH@8G)O=W-E+G!H<#HQ.3$@
M8G)O=W-E+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(D-O;G1A8W0@861D960@
M=&\@;&ES="XB"FUS9W-T<B`BRN[M\N#J\OKR(.'E^.4@[_#E[.#U[>#R(.[R
M(/'OZ/'ZZN`N(@H*(SH@8G)O=W-E+G!H<#HV,`IM<V=I9"`B0V]N=&%C="!R
M96UO=F5D(&9R;VT@;&ES="XB"FUS9W-T<B`BRN[M\N#J\OKR(.'E^.4@[_#E
M[.#U[>#R(.[R(/'OZ/'ZZN`N(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z("5S(@IM
M<V=S='(@(L#D\.7QZ"#B(/'OZ/'ZZCH@)7,B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S
M='(@(LKN[._@[>C_(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M-3,*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($%D9')E
M<W,@0F]O:R(*;7-G<W1R("+7X/'R[>`@P.3PY?'MX"#J[>CCX"(*"B,Z(&QI
M8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A=&4@82!N97<@0V]N=&%C
M="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z
M,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO
M;CHB"FUS9W-T<B`BS^[Q[NK@(.W@(/'N\/+H\.#MY2#O[B#O[N3PX.?AZ/#@
M[>4Z(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z(&QI8B]/8FIE8W0N<&AP.C,R
M."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z-3`*;7-G
M:60@(D1E;&5T92(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($%D9')E
M<W,@0F]O:R(*;7-G<W1R("+(Y^'E\.@@X.3PY?'MX"#J[>CCX"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1&5L971E($-O;F9I<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*
M;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@\O#HY>WE(@H*(SH@9&5L971E+G!H<#HS.`IM<V=I9"`B1&5L971I
M;VX@9F%I;&5D(@IM<V=S='(@(L/PY?CJX"#O\.@@\O#HY>WE(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M96YT
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I
M9"`B1&5S8V5N9&EN9R(*;7-G<W1R("+-X.S@Z__BX/GH(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3$U"B,L(&9U>GIY"FUS9VED(")$97-C
M<FEP=&EO;B(*;7-G<W1R("+/[O+PY>'H\N7K\>KH(.[O]NCH(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q.`IM<V=I9"`B1&ER96-T;W)Y
M(@IM<V=S='(@(L3H\.7J\N[PZ/\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C0*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`BQ.CQ[^OE
MZ2#.[_;HZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`BQ.CQ[^OEZ2#.[_;HZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-S8*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L
M971I;F<@96YT<FEE<S\B"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C="YP:'`Z
M,CDW"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+W)O=RYI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W
M+FEN8SHR-0IM<V=I9"`B1&]W;FQO860@=D-A<F0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`R('1E;7!L871E<R]B<F]W
M<V4O<F]W+FEN8SHR-0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D
M97)S+FEN8SHQ,"!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*(SH@
M=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,R!L:6(O4F5N9&5R
M97(N<&AP.C0R"FUS9VED(")%9&ET(@IM<V=S='(@(M#EY.#J]NC_(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O
M8V]N=&%C=')O=RYI;F,Z,S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D5D:70@7"(E<UPB(@IM<V=S='(@(M#EY.#J\NCPX.D@)R5S)R(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C@Q"B,L(&9U>GIY"FUS9VED(")%
M9&ET($%D9')E<W,@0F]O:W,B"FUS9W-T<B`BR.?U[N0@X.3PY?'MX"#J[>CC
MX"(*"B,Z(&5D:70N<&AP.C<X(&5D:70N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!E;G1R>2!F;W(@)7,B"FUS9W-T<B`BS?_L
MX"`E<R#MX.SE\.7MZ"#DX.WMZ"`@Y^`@)7,N(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(L_H\>SN
M(@H*(SH@961I="YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y
M(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,30Y(&5D:70N
M<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D
M871E9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HW-`HC+"!F=7IZ>0IM
M<V=I9"`B16YT<GD@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(B5S
M(/3@Z>L@X>7XY2#H[._N\/+H\.#M(//Q[^7X[>XB"@HC.B!L:6(O87!I+G!H
M<#HT,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E87)C
M:&EN9R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+-_^S@(.#D\.7Q
M[>@@ZNWHX^@L(.(@ZN[H\NX@[.[FY?+E(.3@(._H^.7RY2XB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHT,0HC+"!F=7IZ>0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(LCL
M[^[P\B_%ZO'O[O#R(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHV
M"FUS9VED(")%>'!O<G0@061D<F5S<R!";V]K(@IM<V=S='(@(L7J\>_N\/(@
M[>`@X.3PY?'MX"#J[>CCX"(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR
M-PIM<V=I9"`B17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O
M;7!L971E;'DN(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H
M<#HR,C@@9&%T82YP:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY
M,`HC.B!B<F]W<V4N<&AP.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@
M=&AE(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#D[O'R
M^N_@(.3N(.?@Y.#DY>W@\N`@X.3PY?'MX"#J[>CCX"(*"B,Z(&)R;W=S92YP
M:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M861D("5S('1O("5S.B`E<R(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y^`@\OKP
M\>7MY2#B(.3H\.7J\N[PZ/\Z("5S(@H*(SH@8G)O=W-E+G!H<#HR-S(*;7-G
M:60@(D9A:6QE9"!T;R!B<F]W<V4@;&ES="(*;7-G<W1R("+#\.7XZN`@[_#H
M(._PY>/KY>;DX.WE(.W@(/'OZ/'ZZN`B"@HC.B!B<F]W<V4N<&AP.C,Q,`IM
M<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM<V=S='(@
M(L/PY?CJX"#O\.@@[_#EX^OEYN3@[>4@[>`@[^#OZN#RX"(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,S`Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$
M3B`]("5S+"!2;V]T(#T@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ
M,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD
M(&]B:F5C="!T;R!B92!A9&1E9#H@)7,B"FUS9W-T<B`BS>7B^N?L[N;M[O'R
M(.?@(/+Z\/'E[>4@XB#DZ/#EZO+N\.C_.B`E<R(*"B,Z('-E87)C:"YP:'`Z
M-SD*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E
M<W,@8F]O:R(*;7-G<W1R("+#\.7XZN`@[_#H(.3N\?+Z[^`@Y.X@Y^#DX.3E
M[>#RX"#@Y/#E\>W@(.KMZ./@(@H*(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@
M)7,B"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.?@(/+Z\/'E[>4@XB#DZ/#EZO+N
M\.C_.B`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM
M<V=I9"`B1F%X(@IM<V=S='(@(M3@ZO$B"@HC.B!E9&ET+G!H<#HQ,C0@9&ES
M<&QA>2YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")&:6QE<R(*;7-G<W1R("+$
MZ_KF[>[Q\B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW,`IM
M<V=I9"`B1FEN9"(*;7-G<W1R("+2^O#QZ"(*"B,Z(&5D:70N<&AP.CDW(&5D
M:70N<&AP.C$X-PHC+"!F=7IZ>0IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(M+Z
M\/'H(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@
M(D9I<G-T($YA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@S"FUS9VED(")&<F]M
M(@IM<V=S='(@(L[R(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`T
M"B,L(&9U>GIY"FUS9VED(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@
M(DUU;&)E<G)Y(.#D\.7Q[>`@ZNWHX^`B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT
M-`IM<V=I9"`B1W)O=7`B"FUS9W-T<B`BP_#S[^`B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S
M='(@(L3N[.#XY>T@X.3PY?$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P.`HC+"!F=7IZ>0IM<V=I9"`B2&]M
M92!#;W5N=')Y(@IM<V=S='(@(L3N[.#XY>T@\N7KY?3N[2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U,`IM<V=I9"`B2&]M92!0:&]N92(*
M;7-G<W1R("+$[NS@^.7M(/+EZ^7T[NTB"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DAO;64@4&]S=&%L($-O
M9&4B"FUS9W-T<B`BQ.[LX/CE[2#RY>OE].[M(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(DAO;64@4W1A=&4O
M4')O=FEN8V4B"FUS9W-T<B`BQ.[LX/CE[2#RY>OE].[M(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z.#@*(RP@9G5Z>GD*;7-G:60@(DAO;64@
M4W1R965T($%D9')E<W,B"FUS9W-T<B`BQ.[LX/CE[2#@Y/#E\2(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C4P-@IM<V=I9"`B24U34"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<*(RP@9G5Z>GD*;7-G
M:60@(DE-4U`@061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(L#D\.7QY>T@\>_H\?KJ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D<F5S
M<R!";V]K+"!3=&5P("5D(@IM<V=S='(@(LCL[^[P\B#MX"#@Y/#E\>W@(.KM
MZ./@(@H*(SH@9&%T82YP:'`Z,S8Q"B,L(&9U>GIY"FUS9VED("));7!O<G0O
M17AP;W)T($%D9')E<W,@0F]O:W,B"FUS9W-T<B`BR.SO[O#R+\7J\>_N\/(@
M[>`@X.3PY?'MZ"#J[>CCZ"(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O87!I
M+G!H<#HV.#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`B
MS>7BX.OHY.WN(.CLY2XB"@HC.B!L:6(O87!I+G!H<#HR,S`@;&EB+V%P:2YP
M:'`Z-#`R(&QI8B]A<&DN<&AP.C0X-B!L:6(O87!I+G!H<#HU.3(*(SH@;&EB
M+V%P:2YP:'`Z-C<Y(&QI8B]A<&DN<&AP.C<S,2!L:6(O87!I+G!H<#HQ,#<W
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("+-Y>+@Z^CD[>`@X.3PY?'MX"#J[>CCX"XB"@HC.B!L:6(O87!I+G!H<#HQ
M,#@Q(&QI8B]A<&DN<&AP.C$Q-30@;&EB+V%P:2YP:'`Z,3(P-PHC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!E;6%I;"(*;7-G<W1R("+-Y>+@Z^CDY>T@96UA
M:6PB"@HC.B!L:6(O87!I+G!H<#HQ,#@Y"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED(&5N=')Y(@IM<V=S='(@(LWEXN#KZ.3MZ"#DX.WMZ"XB"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C(V-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!K
M97D@<W!E8VEF:65D+B(*;7-G<W1R("+-Y>+@Z^CDY>T@96UA:6PB"@HC.B!L
M:6(O87!I+G!H<#HQ,#@U"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&YA;64B
M"FUS9W-T<B`BS>7BX.OHY.WN(.CLY2XB"@HC.B!L:6(O87!I+G!H<#HW,S4*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;V)J96-T260B"FUS9W-T<B`BS>7B
MX.OHY.WH(.3@[>WH+B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`*;7-G
M:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@=&AE($Q$05`@
M;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S.`IM<V=I9"`B3&%S="!-
M;V1I9FEE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HU,PHC+"!F=7IZ>0IM<V=I9"`B3&%S="!.86UE(@IM<V=S='(@(LCL
MY2(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$V
M"B,L(&9U>GIY"FUS9VED("),:7-T(@IM<V=S='(@(LWNXB#Q[^CQ^NHB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S<*;7-G:60@(DUA=&-H
M:6YG(@IM<V=S='(@(M'ZY/KPYN#YZ"(*"B,Z(&QI8B]A<&DN<&AP.C(P-0IM
M<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU;2!N
M=6UB97(@;V8@<&%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@
M(LWNXB#Q[^CQ^NHB"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,PHC
M+"!F=7IZ>0IM<V=I9"`B36EN:2!396%R8V@B"FUS9W-T<B`BTOKP\>@B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$3B!I
M;B!,1$%0('-O=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0
M:&]N92(*;7-G<W1R("+,[N'HZ^7M(/+EZ^7T[NTB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.3,*(RP@9G5Z>GD*;7-G:60@(DUO<F4@
M=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S='(@(L'E^.4@XOKP[>#R(._NXN7W
MY2#N\B`Q(/#EY"XB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C$Q"FUS9VED(")-;W9E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(T-PHC.B!T96UP;&%T97,O<')E9G,O861D
M<F5S<V)O;VMS96QE8W0N:6YC.C$X-`HC+"!F=7IZ>0IM<V=I9"`B36]V92!L
M969T(@IM<V=S='(@(N_PY>SE\?+H(.W@(.O_XNXB"@HC.B!T96UP;&%T97,O
M<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#D*(SH@=&5M<&QA=&5S+W!R969S
M+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#8*(RP@9G5Z>GD*;7-G:60@(DUO
M=F4@<FEG:'0B"FUS9W-T<B`B[_#E[.7Q\N@@[>`@Y/_Q[>XB"@HC.B!D871A
M+G!H<#HU,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$V"FUS9VED(")-
M=6QB97)R>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B375L8F5R<GD@X.3PY?'M
MX"#J[>CCX"(*"B,Z(&QI8B]A<&DN<&AP.C$Q,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB375L=&EP;&4@<&5R<V]N<R!W:71H(&%D9')E<W,@6R5S72P@
M8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@86QR96%D>2!E>&ES="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ,#<@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z,C0S"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S
M($)O;VLB"FUS9W-T<B`BS.[_\N`@X.3PY?'MX"#J[>CCX"(*"B,Z(&%D9')E
M<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S($)O
M;VMS(@IM<V=S='(@(LSN__+@(.#D\.7Q[>`@ZNWHX^`B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`BR.SE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED(").86UE($9O<FUA="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HS,34*;7-G:60@(DYE
M=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y(@IM<V=S='(@(DYE=&-E;G1E<B!-
M96UB97(@1&ER96-T;W)Y(@H*(SH@861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L
M:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*(SH@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE=R!#;VYT86-T(@IM<V=S
M='(@(L_NZN#FZ"#J[NWRX.KRZ/+E(@H*(SH@961I="YP:'`Z.#@@961I="YP
M:'`Z.34@961I="YP:'`Z,C`R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z
M-#4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,C$X"B,L(&9U>GIY"FUS9VED(").:6-K;F%M92(*;7-G
M<W1R("+([.4B"@HC.B!L:6(O87!I+G!H<#HQ,3DU(&QI8B]A<&DN<&AP.C$R
M-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO("5S(&5N=')Y(&9O
M=6YD(&9O<B`E<R(*;7-G<W1R("+-_^S@("5S(.W@[.7PY>WH(.3@[>WH("#G
MX"`E<RXB"@HC.B!L:6(O87!I+G!H<#HQ,38S"B,L(&9U>GIY"FUS9VED(").
M;R!A9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>W@\N`@ZNWH
MX^`@Y2#B(/#EYNCL(/?E\N7MY2XB"@HC.B!M:6YI<V5A<F-H+G!H<#HX,PHC
M+"!F=7IZ>0IM<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B"FUS9W-T<B`BS^[J
MX.;H(.KN[?+@ZO+H\N4B"@HC.B!L:6(O87!I+G!H<#HU,3$@;&EB+V%P:2YP
M:'`Z-S8V"FUS9VED(").;R!V0V%R9"!D871A('=A<R!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C<*;7-G:60@
M(DYO;F4B"FUS9W-T<B`BS?_LX"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$X-`IM<V=I9"`B3F]T97,B"FUS9W-T<B`BP>7KY>;JZ"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(DYU;6)E<B!O9B!I
M=&5M<R!P97(@<&%G92(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HV,30@
M;&EB+V%P:2YP:'`Z-S0W"FUS9VED(")/8FIE8W0@;F]T(&9O=6YD(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(R,PIM<V=I
M9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P
M7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@=&AI<R!O<'1I
M;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E<FUA;F5N=&QY
M("(*(F1E;&5T960N($EF('1H:7,@:7,@;F]T('=H870@>6]U('=A;G0L('1H
M96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N("(*(G1O(%PB3F]N
M95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW-S0*;7-G:60@(D]N
M;'D@;VYE('9C87)D('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R("+/[O+PY>'H
M\N7K\>KH(.[O]NCH(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3DP"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@S_/AZ^CW
MY>T@ZNO^]R(*"B,Z(&QI8B]A<&DN<&AP.C0Y-2!L:6(O87!I+G!H<#HV,#4@
M;&EB+V%P:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.CDS-`HC.B!L:6(O87!I+G!H
M<#HQ,#DX"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC
M.B!L:6(O1')I=F5R+G!H<#HU-#,*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDY
M"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU
M,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")0:6YE($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE(,#D\.7Q[>`@ZNWHX^`B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(X"FUS9VED(")0;&5A
M<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@;&ES=#HB"FUS9W-T<B`B(@H*(SH@
M961I="YP:'`Z.3$@961I="YP:'`Z.30@961I="YP:'`Z,3DT"FUS9VED(")0
M<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES
M=#HT,38*;7-G:60@(E!R:79A=&4@061D<F5S<R!";V]K(@IM<V=S='(@(M?@
M\?+MX"#`Y/#E\>W@(.KMZ./@(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475E<GD@9F%I;&5D.B`H)7,I("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN
M8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B475I8VL@4V5A<F-H(@IM<V=S='(@(M+Z
M\/'H(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3$@;&EB+T1R:79E<B]L
M9&%P+G!H<#HQ.3D@;&EB+T1R:79E<B]L9&%P+G!H<#HT,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+U)E;F1E<F5R+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T
M:&ES(&-O;G1A8W0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN
M8SHQ-S8*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`BS>7BX.OHY.W@(.#D\.7Q[>`@ZNWHX^`N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,Y"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4@8V]L=6UN(@IM<V=S='(@(N_PY>S@]>WH(.KNZ^[MX"(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@IM<V=I9"`B4F5M;W9E(&9R
M;VT@=&AI<R!L:7-T(@IM<V=S='(@(L_PY>S@]>+@[>4@[O(@\N[GZ"#Q[^CQ
M^NHN(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0IM<V=I9"`B
M(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@:6UP
M;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A
M;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R
M;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G:60@
M(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A
M9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G
M:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#
M97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S
M*2`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY.2!A9&0N<&AP.C,W('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.38@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q,@HC.B!T96UP;&%T97,O8FQO
M8VLO;6EN:7-E87)C:"YI;F,Z,C$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z
M-#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B4V5A<F-H
M(@IM<V=S='(@(M+Z\/'H(@H*(SH@;6EN:7-E87)C:"YP:'`Z-C,*(RP@9G5Z
M>GD*;7-G:60@(E-E87)C:"!297-U;'1S.B(*;7-G<W1R("+0Y>?SZ_+@\N@@
M[O(@\OKP\>7MY?+N(@H*(SH@;&EB+V%P:2YP:'`Z,3`Q,0HC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R("+2^O#QZ"(*"B,Z(&QI8B]A
M<&DN<&AP.C$Q,#,@;&EB+V%P:2YP:'`Z,3$P.2!L:6(O87!I+G!H<#HQ,3$X
M(&QI8B]A<&DN<&AP.C$Q,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI
M;FES96%R8V@N:6YC.C(R"B,L(&9U>GIY"FUS9VED(")396%R8VAI;F<N+BXB
M"FUS9W-T<B`BTOKP\>@B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHV-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T
M;R!D96QE=&4B"FUS9W-T<B`BR.?AY?#H(.#D\.7Q[>`@ZNWHX^`B"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(LCGX>7P
MZ"#@Y/#E\>W@(.KMZ./@(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHS,@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@
M=&\@97AP;W)T(&9R;VTZ(@IM<V=S='(@(LCGX>7PY?+E(.CG\N[W[>CJ(.?@
M(.7J\>_N\/(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR-@HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP
M;W)T('1O.B(*;7-G<W1R("+(Y^'E\.7RY2#J^N3E(.3@(/'E(.CGXOKP^.@@
MZ.SO[O#RX#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,U"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&-H87)S970@;V8@=&AE('-O=7)C
M92!F:6QE.B(*;7-G<W1R("+(Y^'E\.7RY2#HY_+N]^WHZB#GX"#EZO'O[O#R
M.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`BR.?A
MY?#E\N4@Z.?R[O?MZ.H@Y^`@Y>KQ[^[P\CHB"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C0S"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP
M;W)T.B(*;7-G<W1R("+(Y^'E\.7RY2#TX.GK(.?@(.CL[^[P\CHB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@
M(LCGX>7PY?+E(/3N\.S@\BP@ZOKL(.KNZ?+N(.3@(/'E(.7J\>_N\/+H\.`Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA;65S.B(*
M;7-G<W1R("+(Y^'E\.7RY2#T[O#LX/(L(.[R(.KNZ?+N(.3@(/'E(.CL[^[P
M\NCPX#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!V:65W('1O(&1I<W!L87D@8GD@9&5F875L="P@<V]R
M="!O<'1I;VYS+"!A;F0@<&%G:6YG(&]P=&EO;G,N(@IM<V=S='(@(LCGX>7P
MY?+E(.CGX^OEY"#O[B#O[N3PX.?AZ/#@[>4N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$X"FUS9VED(")396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I
M<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES=',N(@IM<V=S='(@(LCGX>7PY?+E
M(.KNZ"#O[NOE\N`@Y.`@\>`@[^[JX.?@[>@@XB#Q[^CQ^NK@(/$@X.3PY?'H
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G
M<W1R("+(Y^'E\.7RY2#J[N@@[^[KY?+@(.3@(/'@(._NZN#GX.WH(.(@\>_H
M\?KJX"#Q(.#D\.7QZ"XB"@HC.B!A9&0N<&AP.C4T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")396QE8W1E9"!A9&1R97-S(&)O;VL@7"(E<UPB+B(*
M;7-G<W1R("+(Y^'E\.@@X.3PY?'MX"#J[>CCX"(*"B,Z(&-O;F9I9R]S;W5R
M8V5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G
M<W1R("+1[^[DY>OE[>`@Q.CPY>KR[O#H_R(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-H;W<@)7,B"FUS9W-T<B`BS^[JX.;H(/'OZ/'Z]NCRY2(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H;W<@06QL(@IM
M<V=S='(@(L_NZN#FZ"#B\>CWZN@B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C0P"FUS9VED(")3:&]W($-O;G1A8W1S(@IM<V=S='(@(L_N
MZN#FZ"#J[NWRX.KRZ/+E(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHS.0IM<V=I9"`B4VAO=R!,:7-T<R(*;7-G<W1R("+/[NK@YN@@\>_H
M\?KVZ/+E(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI
M;F,Z,C$*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z
M,S0*;7-G:60@(E-O<G0@1&ER96-T:6]N(@IM<V=S='(@(M'N\/+H\.#MY2(*
M"B,Z(&QI8B]A<&DN<&AP.C$Y.`IM<V=I9"`B4V]U<F-E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34W"FUS9VED(")3<&5C:69Y
M('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P
M<&5A<BXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ-#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S(@IM<V=S
M='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V
M86QU97,B"FUS9W-T<B`B5&%B("CRX.'SZ^#VZ/\I(/#@Y^3EZ^7MZ"#Q\N[I
M[>[Q\N@B"@HC.B!V:65W+G!H<#HQ-0IM<V=I9"`B5&AE(%9&4R!B86-K96YD
M(&YE961S('1O(&)E(&-O;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@
M=7!L;V%D<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`U-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<
M(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L[AY>KRX"P@ZN[I\NX@
MZ.?H\>KBX/+E(.WE(/'Z^>7Q\N+SXN`N(@H*(SH@861D<F5S<V)O;VMS+G!H
M<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@
M8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M(")0:6YE(.#D\.7Q[>`@ZNWHX^`@X>7XY2#H[._N\/+H\.#MX"#S\>_E^.WN
M(@H*(SH@861D<F5S<V)O;VMS+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(')E;6]V960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")0:6YE(.#D\.7Q[>`@ZNWHX^`@X>7X
MY2#H[._N\/+H\.#MX"#S\>_E^.WN(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")0
M:6YE(.#D\.7Q[>`@ZNWHX^`@X>7XY2#H[._N\/+H\.#MX"#S\>_E^.WN(@H*
M(SH@9&%T82YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R
M97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@961I="YP:'`Z-#<@=F-A<F0N<&AP.C(R(&1I<W!L87DN<&AP.C(S('9I
M97<N<&AP.C(V"B,L(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C="!Y;W4@<F5Q
M=65S=&5D(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+.X>7J\N`L(.KNZ?+N
M(.CGZ/'JXN#RY2#MY2#Q^OGE\?+B\^+@+B(*"B,Z(&5D:70N<&AP.C$Q-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA
M<R!S=6-C97-S9G5L;'D@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(E<R#TX.GK
M(.'E^.4@Z.SO[O#RZ/#@[2#S\>_E^.WN(@H*(SH@9&%T82YP:'`Z,C@T"FUS
M9VED(")4:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W
M87)N:6YG<RXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RXB"FUS9W-T
M<B`BS?_LX"#@Y/#E\>WH(.KMZ./H(.?@(._PY>/KY>;DX.WE+B(*"B,Z(&%D
M9"YP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E(&%R92!N;R!W<FET
M96%B;&4@861D<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@879A:6QA8FQE(&%D
M9')E<W,@8F]O:W,@(@HB87)E(&-O;F9I9W5R960@=&\@86QL;W<@>6]U('1O
M(&%D9"!N97<@96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@8F5L:65V92!T:&ES
M("(*(FES(&%N(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+-Z.KN_R#N\B#MX.OH]^WH\N4@
MX.3PY?'MZ"#J[>CCZ"#MY2#E(.KN[?3HX_/PZ/#@[>`@Y.`@Y.[AX.+_\N4@
MY.#M[>@@ZOKL("(*(NWE_RX@P.KN(/'L__+@\N4L(/?E(/+NXN`@[>4@Y2#B
M__#M[BP@[.[K_R#J[NWQ\^ORZ/#@Z?+E(/'E(/'Z\2#1Z/'RY>SMZ/\@(@HB
MP.3LZ.WH\?+PX/+N\"XB"@HC.B!A9&0N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A
M8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B`B"B)F;W(@
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B+#\.7XZN`@[_#H(.3NX>#B_^WE
M\NX@[>`@\N[GZ"#NX>7J\BX@RN[M\?/K\NCPX.GRY2#QY2#Q^O$@T>CQ\N7L
M[>C_("(*(L#D[.CMZ/'R\.#R[O`N(@H*(SH@8G)O=W-E+G!H<#HQ.#D@8G)O
M=W-E+G!H<#HR,S`*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!A9&1I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R
M\.CBX.WE\NX@[>`@\N[GZ"#NX>7J\BXB"@HC.B!B<F]W<V4N<&AP.C(S.`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N
M(@IM<V=S='(@(L/PY?CJX"#O\.@@\?KGY.#BX.WE(.W@(.WNXB#Q[^CQ^NHN
M(@H*(SH@861D<F5S<V)O;VMS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D
M<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(/'ZY^3@XN#MY2#M
MX"#M[N(@\>_H\?KJ+B(*"B,Z(&)R;W=S92YP:'`Z,30W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M7"(E<UPB(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Z.?R\.CBX.WE\NX@[>`@\N[GZ"#NX>7J\BXB"@HC.B!D
M96QE=&4N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G
M<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY?+N(.W@(/+NY^@@[N'EZO(N(@H*
M(SH@8G)O=W-E+G!H<#HW,@IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#H
MXN#MY?+N(.W@(/+NY^@@[N'EZO(N(@H*(SH@8G)O=W-E+G!H<#HR-S@*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M92!L:7-T(@IM<V=S='(@(L/PY?CJX"#O\.@@[^[JX.?BX.WE\NX@[>`@Z.?A
M\.#MZ/\@\>_H\?KJ(@H*(SH@9&%T82YP:'`Z,S,U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!D871A.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\NCPX.WE(.W@
M(.3@[>WH\N4Z("5S+B(*"B,Z(&QI8B]A<&DN<&AP.C4P-R!L:6(O87!I+G!H
M<#HW-C$*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("+#\.7XZN`@[_#H
M(.CL[^[P\B#MX"!V0V%R9"#DX.WMZ"XB"@HC.B!B<F]W<V4N<&AP.C4X"B,L
M(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@82!C
M;VYT86-T(&9R;VT@=&AE(&QI<W0N(@IM<V=S='(@(L/PY?CJX"#O\.@@\?KG
MY.#BX.WE(.W@(.WNXB#Q[^CQ^NHN(@H*(SH@861D<F5S<V)O;VMS+G!H<#HU
M-2!A9&1R97-S8F]O:W,N<&AP.C8P(&%D9')E<W-B;V]K<RYP:'`Z-C@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R
M96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`BP_#E^.K@
M(._PZ"#O\.7LY?'RXN#MY2#MX"#NX>7J\N`N(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HX,2!A9&1R97-S8F]O:W,N<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A
M9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.SO[O#RZ/#@
M[>4@[>`@Y.#M[>CRY3H@)7,N(@H*(SH@961I="YP:'`Z,34X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AI<R!E;G1R>3H@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#H[._N\/+H
M\.#MY2#MX"#DX.WMZ/+E.B`E<RXB"@HC.B!D871A+G!H<#HQ-SD*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="XB
M"FUS9W-T<B`BS?_LX"#@Y/#E\>WH(.KMZ./H+"#B(.KNZ/+N(.SNYN7RY2#D
MX"#OZ/CE\N4N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L
M96-T+FEN8SHQ.#`*;7-G:60@(E1H97-E(&%D9')E<W,@8F]O:W,@=VEL;"!D
M:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T,PIM<V=I9"`B5&AE<V4@8V]L
M=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z,C8Y"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,C(@
M;&EB+V%P:2YP:'`Z,3$S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@861D
M<F5S<R!B;V]K(@IM<V=S='(@(M+NY^@@]^[BY>H@XN7WY2#Q^OGE\?+B\^+@
M(.K@\NX@)7,@XOKB(.#D\.7Q[>#RX"#J[>CCX"XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30W"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E
M9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C
M;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-S`*;7-G:60@(E1I=&QE(@IM<V=S='(@(L3K^N;M[O'R(@H*(SH@
M;&EB+U1U<F)A+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!N97<@<VAA<F4N("!-:7-S:6YG('-O=7)C92!T>7!E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HY-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M(@IM<V=S='(@(L/PY?CJX"#O\.@@Y^#PY>;DX.WE(.W@(.3E].CMZ/;HZ/+E
M(.W@("5S+B(*"B,Z(&5D:70N<&AP.C@X(&5D:70N<&AP.CDQ(&5D:70N<&AP
M.CDT(&5D:70N<&AP.CDY(&5D:70N<&AP.C$Y-@IM<V=I9"`B56YD;R!#:&%N
M9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C4T,"!L:6(O87!I+G!H
M<#HV-#,@;&EB+V%P:2YP:'`Z-S<Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"FUS9VED(")697)I<VEG;B!$:7)E
M8W1O<GDB"FUS9W-T<B`B5F5R:7-I9VX@1&ER96-T;W)Y(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]R;W<N:6YC.C$Y('1E;7!L871E<R]B<F]W<V4O8V]N=&%C
M=')O=RYI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@;6EN:7-E87)C:"YP:'`Z-S@*(RP@9G5Z>GD*;7-G
M:60@(E9I97<@0V]N=&%C="(*;7-G<W1R("+/[NK@YN@@ZN[M\N#J\NCRY2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E9I97<@=&\@
M9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R("+(Y^/KY>0L(.KNZ/+N(.3@
M(.'ZY.4@[^[JX.?@[2#O[B#O[N3PX.?AZ/#@[>4Z(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,C`X"FUS9VED(")796)S:71E(%523"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3,*;7-G
M:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+!Z.?MY?$@X.3PY?$B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O<FL@0VET
M>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M,SD*(RP@9G5Z>GD*;7-G:60@(E=O<FL@0V]U;G1R>2(*;7-G<W1R("+!Z.?M
MY?$@\N7KY?3N[2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U
M-@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+!Z.?MY?$@\N7KY?3N[2(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S-`HC+"!F=7IZ>0IM
M<V=I9"`B5V]R:R!0;W-T86P@0V]D92(*;7-G<W1R("+!Z.?MY?$@\N7KY?3N
M[2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R.0HC+"!F=7IZ
M>0IM<V=I9"`B5V]R:R!3=&%T92]0<F]V:6YC92(*;7-G<W1R("+!Z.?MY?$@
M\N7KY?3N[2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q.0HC
M+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=')E970@061D<F5S<R(*;7-G<W1R("+!
MZ.?MY?$@X.3PY?$B"@HC.B!D871A+G!H<#HR,S<@8G)O=W-E+G!H<#HY,R!B
M<F]W<V4N<&AP.C(P,2!A9&0N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C
M;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C8Y
M(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V"FUS9VED(")9;W4@9&\@;F]T
M(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB"FUS9W-T
M<B`B(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C4U"FUS9VED(")9
M;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S"FUS
M9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB"FUS9W-T<B`B
M(@H*(SH@961I="YP:'`Z,S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L
M96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E
M+VIA=F%S8W)I<'0N:6YC.C0Y"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C
M<FEP="YI;F,Z-S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O
M;F4@96YT<GD@9FER<W0N(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C<S"FUS
M9VED(")9;W4@;VYL>2!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O
M;G1A8W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C@U"FUS9VED(")9
M;W5R(&1E9F%U;'0@861D<F5S<R!B;V]K(&ES(&YO="!B<F]W<V5A8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z-B!T96UP
M;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS9VED(");;F\@=F%L
M=65=(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@T"B,L(&9U>GIY
M"FUS9VED(")?0G)O=W-E(@IM<V=S='(@(L_PY>/KY>3@Z2(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(E]#
M;VYT86-T<R(*;7-G<W1R("+/[NK@YN@@ZN[M\N#J\NCRY2(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@HC+"!F=7IZ>0IM<V=I9"`B7T1E
M;&5T92(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!L:6(O5'5R8F$N<&AP.C0Y,PHC
M+"!F=7IZ>0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`BR.SO[O#R
M+\7J\>_N\/(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y
M"B,L(&9U>GIY"FUS9VED(")?3&ES=',B"FUS9W-T<B`BS^[JX.;H(/'OZ/'Z
M]NCRY2(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@Q"B,L(&9U>GIY"FUS9VED(")?
M37D@061D<F5S<R!";V]K<R(*;7-G<W1R("+,[O_RX"#@Y/#E\>W@(.KMZ./@
M(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#<*(RP@9G5Z>GD*;7-G:60@(E].97<@
M0V]N=&%C="(*;7-G<W1R("+/[NK@YN@@ZN[M\N#J\NCRY2(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@HC+"!F=7IZ>0IM<V=I9"`B7U)E
M;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R("+/\.7LX/7BX.WE(.[R(/+N
MY^@@\>_H\?KJ+B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@Y"B,L(&9U>GIY"FUS
M9VED(")?4V5A<F-H(@IM<V=S='(@(M+Z\/'H(@H*(SH@=F-A<F0N<&AP.C0V
M"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ
M.3D@9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM
M<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(P
M.0IM<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(FYO
M;F4B"FUS9W-T<B`BS?_LX"(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(G1O(&$@0V]N=&%C="!,:7-T(@IM
M<V=S='(@(L_NZN#FZ"#J[NWRX.KRZ/+E(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B=&\@82!D:69F97)E
M;G0@061D<F5S<R!";V]K(@IM<V=S='(@(LCGX>7PZ"#@Y/#E\>W@(.KMZ./@
M(@H*(SH@9&%T82YP:'`Z-3$@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A
M9&5R<RYI;F,Z,3,*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-2!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")V0V%R9"(*;7-G
M<W1R(")V0V%R9"(*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R
M8F$O<&\O9G)?1E(N<&\`````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$P-38S,P`Q,#0Q-S,V,C<U-@`P,3<U,C4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!T<F%N<VQA=&EO
M;B!O9B!F<E]&4BYP;R!T;R!&<F%NYV%I<PHC(%1U<F)A(&9R96YC:"!T<F%N
M<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$M,C`P,BX*(R!&:7)S="!A
M=71H;W(Z(#QS86UP0&%R:6%L+6-O;F-E<'0N8V]M/BP@,C`P,2X*(R!5<&1A
M=&5S(&%N9"!F:7AE<SH@4F]N;FEE($=A<F-I82`\<F]N;FEE0&UK,BYN970^
M+"`R,#`R+@HC(%!I97)R92!,86-H86YC92`\<&Q`<&EE<G)E;&%C:&%N8V4N
M;F5T/B!E="!"96YO:70@4W0M06YD<ND@/&)E;D!B96YO:71S="UA;F1R92YN
M970^+"`R,#`S+"`R,#`T+@HC($)E;F]I="!3="U!;F1RZ2`\8F5N0&)E;F]I
M='-T+6%N9')E+FYE=#XL(#(P,#0N"B,@5&AI97)R>2!4:&]M87,@/'1H:65R
M<GE`<&]M<&\N;F5T/BP@,C`P,BP@,C`P,RP@,C`P-2P@,C`P-BX*(PIM<V=I
M9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@9G)?1E)<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ."`R,CHS."LP,3`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$Y(#`Y.C4U*S`Q,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@5&AI97)R>2!4:&]M87,@/'1H:65R<GE`<&]M
M<&\N;F5T/EQN(@HB3&%N9W5A9V4M5&5A;3H@1G)A;N=A:7,@/&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B(\8F5N0&)E;F]I
M='-T+6%N9')E+FYE=#Y<;B(*(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@
M<&QU<F%L/2AN(#X@,2D[7&XB"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O
M<'0N:6YC.C0P"FUS9VED("(@061D(&%N($E-4U`@061D<F5S<R!";V]K(@IM
M<V=S='(@(D%J;W5T97(@=6X@8V%R;F5T(&0G861R97-S97,@24U34"(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,CD*;7-G:60@(B!$96QE
M=&4@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`B4W5P<')I;65R('5N(&-A
M<FYE="!D)V%D<F5S<V5S($E-4U`B"@HC.B!D871A+G!H<#HS,C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&%L<F5A9'D@97AI<W1S(&%N9"!W87,@
M;F]T(&EM<&]R=&5D+B(*;7-G<W1R("*KH"5SH+L@97AI<W1A:70@9.EJX"!E
M="!N)V$@<&%S(.ETZ2!I;7!O<G3I+B(*"B,Z(&)R;W=S92YP:'`Z,30P"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A
M=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`BJR`E<R"[(&XG82!P87,@Z73I
M(&-O<&GI('!A<F-E('%U92!C)V5S="!U;F4@;&ES=&4N(@H*(SH@8G)O=W-E
M+G!H<#HQ,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@
M;6]V960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(JL@)7,@NR!N
M)V$@<&%S(.ETZ2!DZ7!L86/I('!A<F-E('%U92!C)V5S="!U;F4@;&ES=&4N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S
M=&YA;64@3&%S=&YA;65<(B`@*&EE+B!*;VAN($1O92DB"FUS9W-T<B`BJZ!0
M<NEN;VT@3F]MH+L@("AC+B#@(&0N+B!-:6-H96P@5')E;6)L87DI(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@
M1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(JN@3F]M+"!0
M<NEN;VV@NR`@*&,N(.`@9"XN(%1R96UB;&%Y+"!-:6-H96PI(@H*(SH@861D
M+G!H<#HQ,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@861D960N(@IM<V=S
M='(@(B5S(&%J;W5TZ2XB"@HC.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T
M<B`B9FEC:&EE<B`E<R!I;7!O<G3I(&%V96,@<W5C8^AS(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@X"`E<R!S=7(@)7,B"@HC.B!L
M:6(O5'5R8F$N<&AP.C0U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")#87)N970@9"=A9')E<W-E<R!D92`E<R(*
M"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HT,@IM<V=I9"`B02!B<F]W
M<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9"(*;7-G<W1R
M(")5;B!N879I9V%T975R('-U<'!O<G1A;G0@;&5S(&-A9')E<R`H:49R86UE
M<RD@97-T(')E<75I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C`*
M;7-G:60@(D%B;W9E('-E87)C:"!F;W)M(@IM<V=S='(@(D%U+61E<W-U<R!D
M=2!F;W)M=6QA:7)E(&1E(')E8VAE<F-H92(*"B,Z('9I97<N<&AP.C4R"B,L
M('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@=&\@)7,B"FUS9W-T
M<B`B06-CZ',@X"`E<R!R969U<^DB"@HC.B!A9&0N<&AP.C4V('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,CD*;7-G:60@(D%D9"(*;7-G<W1R(")!
M:F]U=&5R(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T
M+FEN8SHQ-S0*;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B06IO
M=71E<B!U;B!C87)N970@9"=A9')E<W-E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.`IM<V=I9"`B061D(&%N9"!$96QE=&4@24U34"!A9&1R97-S
M(&)O;VMS(@IM<V=S='(@(D%J;W5T97(@970@<W5P<')I;65R(&1E<R!C87)N
M971S(&0G861R97-S97,@24U34"(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")!
M:F]U=&5R('5N92!C;VQO;FYE(@H*(SH@961I="YP:'`Z,3,U"FUS9VED(")!
M9&0@9FEL92(*;7-G<W1R(")!:F]U=&5R('5N(&9I8VAI97(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(Y"FUS9VED(")!9&0@=&\B"FUS
M9W-T<B`B06IO=71E<B#@(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HU-PIM
M<V=I9"`B061D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(DPG86IO=70@9&4@8V]N=&%C=',@;B=E<W0@<&%S(&1I<W!O;FEB;&4N
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#8*;7-G:60@(D%D
M9')E<W,@0F]O:R(*;7-G<W1R(")#87)N970@9"=A9')E<W-E<R(*"B,Z(&)R
M;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B
M061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B3&ES=&4@9&5S(&%N;G5A
M:7)E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B061D
M<F5S<R!";V]K<R(*;7-G<W1R(")#87)N971S(&0G861R97-S97,B"@HC.B!A
M9&0N<&AP.C$P.`IM<V=I9"`B061D<F5S<R!B;V]K(&5N=')Y(@IM<V=S='(@
M(D1O;F[I97,@9'4@8V%R;F5T(&0G861R97-S97,B"@HC.B!D871A+G!H<#HS
M,#4*;7-G:60@(D%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+B(*
M;7-G<W1R(")#87)N970@9"=A9')E<W-E<R!N971T;WGI(&%V96,@<W5C8^AS
M+B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8R"FUS9VED(")!
M9&1R97-S(&)O;VL@=&\@9&5L971E("(*;7-G<W1R(")#87)N970@9"=A9')E
M<W-E<R#@('-U<'!R:6UE<B`B"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S
M<V)O;VMS96QE8W0N:6YC.C$W,`IM<V=I9"`B061D<F5S<R!B;V]K<R!T:&%T
M('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B0V%R;F5T(&0G861R
M97-S97,@<75I(&YE('-E<F]N="!P87,@869F:6-HZ7.@.B(*"B,Z('-E87)C
M:"YP:'`Z.#@@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,X"FUS9VED
M(")!9'9A;F-E9"!396%R8V@B"FUS9W-T<B`B4F5C:&5R8VAE(&%V86YCZ64B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HV-`IM<V=I9"`B06QI
M87,B"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E
M<D%L<&AA+FEN8SHW('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC
M.C$P"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#@*;7-G:60@
M(D%L;"(*;7-G<W1R(")4;W5T(@H*(SH@;&EB+V%P:2YP:'`Z-34T"FUS9VED
M(")!;')E861Y($5X:7-T<R(*;7-G<W1R(")%>&ES=&4@9.EJX"(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E
M("5S/R(*;7-G<W1R("+*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER('-U
M<'!R:6UE<B`E<Z`_(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T
M+FEN8SHV-PIM<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@
M9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/R(*;7-G<W1R("+*=&5S+79O
M=7,@8V5R=&%I;B!D92!V;W5L;VER('-U<'!R:6UE<B!L97,@96YT<NEE<R!S
MZ6QE8W1I;VYNZ65SH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*
M;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")!<V-E;F1A;G0B"@HC.B!S96%R
M8V@N<&AP.C@U('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS-PIM<V=I
M9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(E)E8VAE<F-H92!S:6UP;&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Y"FUS9VED(")"96QO=R!S96%R
M8V@@9F]R;2(*;7-G<W1R(")!=2!D97-S;W5S(&1U(&9O<FUU;&%I<F4@9&4@
M<F5C:&5R8VAE(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-R!L:6(O1')I
M=F5R+VQD87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@9F%I
M;&5D.B`H)7,I("5S(@IM<V=S='(@(LEC:&5C(&1U(&QI96Z@*"5S*3H@)7,B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D)I
M<G1H9&%Y(@IM<V=S='(@(D%N;FEV97)S86ER92(*"B,Z('1E;7!L871E<R]M
M96YU+FEN8SHW"FUS9VED(")"<F]W<V4B"FUS9W-T<B`B4&%R8V]U<FER(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<S"FUS9VED(")"=7-I
M;F5S<R!#871E9V]R>2(*;7-G<W1R(")#873I9V]R:64@869F86ER92(*"B,Z
M(&1A=&$N<&AP.C0Y"FUS9VED(")#4U8B"FUS9W-T<B`B0U-6(@H*(SH@;&EB
M+T]B:F5C="]'<F]U<"YP:'`Z-3<*;7-G:60@(D-A;B=T(&%D9"!A(&=R;W5P
M('1O(&ET<V5L9BXB"FUS9W-T<B`B26UP;W-S:6)L92!D)V%J;W5T97(@=6X@
M9W)O=7!E(.`@;'5I+6WJ;64N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU
M;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S
M='(@(E;I<FEF:65R(%]4;W5T+U)I96XB"@HC.B!T96UP;&%T97,O861D<F5S
M<V)O;VMS+FEN8SHT-`IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G<W1R(")#
M:&]I<VER('5N(&YO;2(*"B,Z(&%D9"YP:'`Z-#@*;7-G:60@(D-H;V]S92!A
M;B!A9&1R97-S(&)O;VLB"FUS9W-T<B`B0VAO:7-I<B!U;B!C87)N970@9"=A
M9')E<W-E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(R,0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B
M0VAO:7-I<B!U;B!C87)N970@9"=A9')E<W-E<Z`Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S
M92!W:&EC:"!A9&1R97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T
M(&]R9&5R.B(*;7-G<W1R(")#:&]I<VER('%U96QS(&-A<FYE=',@9"=A9')E
M<W-E<R!A9F9I8VAE<BP@970@9&%N<R!Q=65L(&]R9')EH#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R
M97-S(&)O;VMS('1O('5S92XB"FUS9W-T<B`B0VAO:7-I<B!Q=65L(&-A<FYE
M="!D)V%D<F5S<V5S('5T:6QI<V5R+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(R.`IM<V=I9"`B0VAO;W-E('=H:6-H(&-O;'5M
M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B0VAO
M:7-I<W-E>B!Q=65L;&5S(&-O;&]N;F5S(&%F9FEC:&5R(&5T(&1A;G,@<75E
M;"!O<F1R9:`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED
M(")#;VQU;6X@3W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS(&1E<R!C;VQO;FYE
M<R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S,PIM
M<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS
M9W-T<B`B0V]L;VYN97,@<75I(&YE('-E<F]N="!P87,@869F:6-HZ65SH#HB
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$S('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU
M97,B"FUS9W-T<B`B5F%L975R<R!SZ7!A<NEE<R!P87(@9&5S('9I<F=U;&5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M
M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI(@IM<V=S
M='(@(E9A;&5U<G,@<^EP87+I97,@<&%R(&1E<R!V:7)G=6QE<R`H36EC<F]S
M;V9T($]U=&QO;VLI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B4V]C:>ETZ2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`IM<V=I9"`B0V]M<&%N>2!!9&1R
M97-S(@IM<V=S='(@(D%D<F5S<V4@<')O9F5S<VEO;FYE;&QE(@H*(SH@;&EB
M+V%P:2YP:'`Z,S(P(&QI8B]A<&DN<&AP.C,V-2!L:6(O87!I+G!H<#HT,#D@
M;&EB+V%P:2YP:'`Z-#DS"B,Z(&QI8B]A<&DN<&AP.C8Q.2!L:6(O87!I+G!H
M<#HW,#8@;&EB+V%P:2YP:'`Z-S4Y(&QI8B]A<&DN<&AP.C@T,`HC.B!L:6(O
M87!I+G!H<#HQ,#,W(&QI8B]A<&DN<&AP.C$Q,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DQA(&-O;FYE
M>&EO;B!A(.EC:&]UZ:`Z("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU
M.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(LEC:&5C(&1E
M(&QA(&-O;FYE>&EO;B(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HS
M(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HR-@IM<V=I9"`B0V]N=&%C="!3
M96%R8V@B"FUS9W-T<B`B4F5C:&5R8VAE(&1E(&-O;G1A8W1S(@H*(SH@8G)O
M=W-E+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&%C=',@:6X@
M;&ES=#H@)7,B"FUS9W-T<B`B0V]N=&%C=',@9&%N<R!L82!L:7-T9:`Z("5S
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B
M0V]P>2(*;7-G<W1R(")#;W!I97(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O
M;VMS+FEN8SHU,PIM<V=I9"`B0W)E871E(@IM<V=S='(@(D-RZ65R(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#`*;7-G:60@(D-R96%T92!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B0W+I97(@=6X@8V%R;F5T(&0G861R97-S
M97,B"@HC.B!L:6(O3&ES=%9I97<N<&AP.C,T.`IM<V=I9"`B0W)E871E(&$@
M;F5W($-O;G1A8W0@3&ES="!I;CHB"FUS9W-T<B`B0W+I97(@=6YE(&YO=79E
M;&QE(&QI<W1E(&1E(&-O;G1A8W1S(&1A;G.@.B(*"B,Z(&QI8B]/8FIE8W16
M:65W+G!H<#HQ,S,*;7-G:60@(D-R96%T960B"FUS9W-T<B`B0W+IZ2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T
M:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B3W)D<F4@9&4@=')I('!A<B!DZ69A
M=72@.B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C<V('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PHC.B!L:6(O3V)J96-T+G!H<#HS
M,C@@;&EB+U)E;F1E<F5R+G!H<#HT-R!L:6(O4F5N9&5R97(N<&AP.C4P"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B169F86-E<B(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C4X"FUS9VED(")$96QE=&4@061D<F5S<R!";V]K
M(@IM<V=S='(@(E-U<'!R:6UE<B!U;B!C87)N970@9"=A9')E<W-E<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1&5L971E($-O;F9I
M<FUA=&EO;B(*;7-G<W1R(")#;VYF:7)M871I;VX@9&4@<W5P<')E<W-I;VXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B
M=71T;VX@8F5H879I;W5R(@IM<V=S='(@(D-O;7!O<G1E;65N="!D=2!B;W5T
M;VX@9&4@<W5P<')E<W-I;VXB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D.B`H)7,I("5S
M(@IM<V=S='(@(LEC:&5C(&1E(&QA('-U<'!R97-S:6]NH#H@*"5S*2`E<R(*
M"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-C(*;7-G:60@(D1E;&5T:6YG(&-O
M;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DQA('-U<'!R97-S
M:6]N(&1E<R!C;VYT86-T<R!N)V5S="!P87,@9&ES<&]N:6)L92XB"@HC.B!D
M96QE=&4N<&AP.C,X"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T<B`B
MR6-H96,@9&4@;&$@<W5P<')E<W-I;VXB"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B1.EP
M87)T96UE;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@
M(D1E<V-E;F1I;F<B"FUS9W-T<B`B1&5S8V5N9&%N="(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C$Q-0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B1&5S8W)I<'1I;VXB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z,3$Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B4NEP97)T;VER
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B1&ES<&QA
M>2(*;7-G<W1R(")!9F9I8VAA9V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B
M1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P=&EO;G,@9"=A9F9I8VAA9V4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<W"FUS9VED(")$;R!Y;W4@
M=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_(@IM<V=S='(@(E9O
M=6QE>BUV;W5S(&-O;F9I<FUE<B!L82!S=7!P<F5S<VEO;B!D97,@96YT<NEE
M<Z`_(@H*(SH@;&EB+T]B:F5C="YP:'`Z,CDW"FUS9VED(")$;W=N;&]A9"(*
M;7-G<W1R(")4Z6SI8VAA<F=E<B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W
M+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(U"FUS
M9VED(")$;W=N;&]A9"!V0V%R9"(*;7-G<W1R(")4Z6SI8VAA<F=E<B!V0V%R
M9"(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P,B!T96UP;&%T
M97,O8G)O=W-E+W)O=RYI;F,Z,C4*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU
M;6Y?:&5A9&5R<RYI;F,Z,3`@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHV"B,Z('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,@;&EB
M+U)E;F1E<F5R+G!H<#HT,@IM<V=I9"`B161I="(*;7-G<W1R("+)9&ET97(B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4@=&5M<&QA=&5S+V)R
M;W=S92]C;VYT86-T<F]W+FEN8SHS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET(%PB)7-<(B(*;7-G<W1R("+)9&ET97(@JZ`E<Z"[(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*;7-G:60@(D5D:70@061D<F5S<R!"
M;V]K<R(*;7-G<W1R("+)9&ET97(@;&5S(&-A<FYE=',@9"=A9')E<W-E<R(*
M"B,Z(&5D:70N<&AP.C@U(&5D:70N<&AP.C$V,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(&5N=')Y(&9O<B`E<R(*;7-G<W1R(")-;V1I9FEE<B!L97,@
M:6YF;W)M871I;VYS('!O=7(@JZ`E<Z"[(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(D-O=7)R:65L
M(@H*(SH@961I="YP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y
M(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@HB16YT<NEE(&1E("5S(&UI<V4@X"!J
M;W5R+"!M86ES(.EC:&5C(&1E(&QA('-A=79E9V%R9&4@9'4@9FEC:&EE<B`B
M"B)TZ6SI8VAA<F?IH#H@)7,B"@HC.B!E9&ET+G!H<#HQ-38@961I="YP:'`Z
M,34Y"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D
M+B(*;7-G<W1R(")-:7-E(.`@:F]U<B!D92`E<R!E9F9E8W1UZ64N(@H*(SH@
M8G)O=W-E+G!H<#HR,38@8G)O=W-E+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@861D:6YG("5D(&-O;G1A8W0H<RD@=&\@;&ES="XB"FUS
M9W-T<B`B17)R975R(&QO<G,@9&4@;"=A:F]U="!D92`E9"!C;VYT86-T*',I
M(.`@;&$@;&ES=&4N(@H*(SH@8G)O=W-E+G!H<#HR,3@@8G)O=W-E+G!H<#HR
M-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@861D:6YG("5D(&]F("5D
M(')E<75E<W1E9"!C;VYT86-T*',I('1O(&QI<W0N(@IM<V=S='(@(D5R<F5U
M<B!L;W)S(&1E(&PG86IO=70@X"!L82!L:7-T92!D92`E9"!S=7(@)60@8V]N
M=&%C="AS*2!D96UA;F3I*',I+B(*"B,Z(&)R;W=S92YP:'`Z.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@)60@8V]N=&%C="AS*2XB
M"FUS9W-T<B`B17)R975R(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@)60@
M8V]N=&%C="AS*2XB"@HC.B!B<F]W<V4N<&AP.C@X"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&1E;&5T:6YG("5D(&]F("5D(')E<75E<W1E9"!C;VYT
M86-T<RAS*2XB"FUS9W-T<B`B17)R975R(&QO<G,@9&4@;&$@<W5P<')E<W-I
M;VX@9&4@)60@8V]N=&%C="AS*2!S=7(@)60N(@H*(SH@8G)O=W-E+G!H<#HV
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!R96UO=FEN9R`E9"!C;VYT
M86-T*',I(&9R;VT@;&ES="XB"FUS9W-T<B`B17)R975R(&QO<G,@9'4@<F5T
M<F%I="!D92`E9"!C;VYT86-T*',I(&1E(&QA(&QI<W1E+B(*"B,Z(&)R;W=S
M92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5M;W9I;F<@
M)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G
M<W1R(")%<G)E=7(@;&]R<R!D=2!R971R86ET(&1E(&QA(&QI<W1E(&1E("5D
M(&-O;G1A8W0H<RD@<W5R("5D+B(*"B,Z(&QI8B]A<&DN<&AP.C0Q-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96%R8VAI;F<@=&AE(&%D9')E<W,@
M8F]O:SH@)7,B"FUS9W-T<B`B17)R975R(&QO<G,@9&4@;&$@<F5C:&5R8VAE
M(&1A;G,@;&4@8V%R;F5T(&0G861R97-S9:`Z("5S(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHQ,"!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C0Q"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T97(B"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*;7-G:60@(D5X<&]R="!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B17AP;W)T97(@;"=A;FYU86ER92(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY
M('1H92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B3B=E>'!O<G1E<B!Q
M=64@;&5S(&-O;G1A8W1S('/I;&5C=&EO;F[I<RXB"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C(W"FUS9VED(")%>'!O<G0@=&AE(&9O;&QO=VEN
M9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2XB"FUS9W-T<B`B17AP;W)T97(@
M96X@=&]T86QI=.D@;&4@8V%R;F5T(&0G861R97-S97,@<W5I=F%N="XB"@HC
M.B!D871A+G!H<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!B<F]W
M<V4N<&AP.C,U(&)R;W=S92YP:'`Z,3`S"B,Z(&)R;W=S92YP:'`Z,3,P(&%D
M9"YP:'`Z-C<@<V5A<F-H+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@
M(DEM<&]S<VEB;&4@9"=A8V/I9&5R(&%U(&-A<FYE="!D)V%D<F5S<V5SH#H@
M)7,B"@HC.B!B<F]W<V4N<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@861D("5S('1O("5S.B`E<R(*;7-G<W1R("));7!O<W-I8FQE
M(&0G86IO=71E<B`E<R#@("5SH#H@)7,B"@HC.B!B<F]W<V4N<&AP.C,P-0IM
M<V=I9"`B1F%I;&5D('1O(&)R;W=S92!L:7-T(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9"=A8V/I9&5R(.`@8V5T=&4@;&ES=&4B"@HC.B!B<F]W<V4N<&AP.C,T
M,PIM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9"=A8V/I9&5R(.`@8V4@<NEP97)T;VER92(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L
M($YE=R!$3B`]("5S+"!2;V]T(#T@)7,B"FUS9W-T<B`B(@HB26UP;W-S:6)L
M92!D92!M;V1I9FEE<B!L92!N;VV@.B`H)7,I("5SH#L@86YC:65N($1.(#T@
M)7,L(&YO=79E874@1$X@/2`E<RP@(@HB<F%C:6YE(#T@)7,B"@HC.B!B<F]W
M<V4N<&AP.C$S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@9FEN
M9"!O8FIE8W0@=&\@8F4@861D960Z("5S(@IM<V=S='(@(DEM<&]S<VEB;&4@
M9&4@=')O=79E<B!U;B!S=6IE="#@(&%J;W5T97(Z("5S(@H*(SH@<V5A<F-H
M+G!H<#HW.0IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T:&4@861D<F5S<R!B
M;V]K(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=E9F9E8W1U97(@=6YE(')E8VAE
M<F-H92!D86YS(&-E(&-A<FYE="!D)V%D<F5S<V5SH#H@)7,B"@HC.B!D871A
M+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O('-E87)C
M:"!T:&4@9&ER96-T;W)Y.B`E<R(*;7-G<W1R("));7!O<W-I8FQE(&0G969F
M96-T=65R('5N92!R96-H97)C:&4@9&%N<R!C92!RZ7!E<G1O:7)EH#H@)7,B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C<*;7-G:60@(D9A
M>"(*;7-G<W1R(")4Z6SI8V]P:64B"@HC.B!E9&ET+G!H<#HQ,S$@9&ES<&QA
M>2YP:'`Z,3`P"FUS9VED(")&:6QE<R(*;7-G<W1R(")&:6-H:65R<R(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW,0IM<V=I9"`B1FEN9"(*
M;7-G<W1R(")296-H97)C:&5R(@H*(SH@961I="YP:'`Z,3`T(&5D:70N<&AP
M.C$Y-`IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(E1E<FUI;F5R(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T($YA;64B
M"FUS9W-T<B`B4'+I;F]M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B55),(&1E<R!D
M:7-P;VYI8FEL:73I<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN
M8SHX-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")$86YS(@H*(SH@8V]N9FEG+W-O
M=7)C97,N<&AP+F1I<W0Z-C`V"FUS9VED(")';&]B86P@061D<F5S<R!";V]K
M(@IM<V=S='(@(D-A<FYE="!D)V%D<F5S<V5S(&=L;V)A;"(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<F]W+FEN8SHT,R!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C0T"FUS9VED(")'<F]U<"(*;7-G<W1R(")'<F]U<&4B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!
M9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@9&]M:6-I;&4B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y(@IM<V=S
M='(@(E9I;&QE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`X
M"FUS9VED(")(;VUE($-O=6YT<GDB"FUS9W-T<B`B4&%Y<R(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U,`IM<V=I9"`B2&]M92!0:&]N92(*
M;7-G<W1R(")4Z6PN(&1O;6EC:6QE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3`S"FUS9VED(")(;VUE(%!O<W1A;"!#;V1E(@IM<V=S='(@
M(D-O9&4@<&]S=&%L(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M.3@*;7-G:60@(DAO;64@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`BR71A="]0
M<F]V:6YC92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"FUS
M9VED(")(;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(E)U92(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C4P.`IM<V=I9"`B24U34"(*;7-G<W1R
M("))35-0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W"FUS9VED("))
M35-0($%D9')E<W,@0F]O:R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI
M;FES=')A=&EO;B!D97,@86YN=6%I<F5S($E-4U`@*$EN=&5R;F5T($UE<W-A
M9V4@4W5P<&]R="!0<F]T;V-O;"DB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($%D9')E<W,@
M0F]O:RP@4W1E<"`E9"(*;7-G<W1R("));7!O<G1E<B!U;B!C87)N970@9"=A
M9')E<W-E<RP@Z71A<&4@)60B"@HC.B!D871A+G!H<#HS-C$*;7-G:60@(DEM
M<&]R="]%>'!O<G0@061D<F5S<R!";V]K<R(*;7-G<W1R("));7!O<G1E<B]%
M>'!O<G1E<B!C87)N970@9"=A9')E<W-E<R(*"B,Z(&QI8B]A<&DN<&AP.C8Q
M-"!L:6(O87!I+G!H<#HW,#$*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`B
M261E;G1I9FEA;G0@:6YV86QI9&4B"@HC.B!L:6(O87!I+G!H<#HR,S(@;&EB
M+V%P:2YP:'`Z-#`T(&QI8B]A<&DN<&AP.C0X."!L:6(O87!I+G!H<#HV,3`*
M(SH@;&EB+V%P:2YP:'`Z-CDW(&QI8B]A<&DN<&AP.C<T.2!L:6(O87!I+G!H
M<#HQ,3`X"FUS9VED("));G9A;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R(")#
M87)N970@9"=A9')E<W-E<R!I;G9A;&ED92(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M,3(@;&EB+V%P:2YP:'`Z,3$X-2!L:6(O87!I+G!H<#HQ,C,X"FUS9VED("))
M;G9A;&ED(&5M86EL(@IM<V=S='(@(D-O=7)R:65L(&EN=F%L:61E(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$R,`IM<V=I9"`B26YV86QI9"!E;G1R>2(*;7-G<W1R
M(")%;G1RZ64@:6YV86QI9&4B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(V
M-@IM<V=I9"`B26YV86QI9"!K97D@<W!E8VEF:65D+B(*;7-G<W1R(")#;&5F
M('-PZ6-I9FGI92!I;G9A;&ED92XB"@HC.B!L:6(O87!I+G!H<#HQ,3$V"FUS
M9VED("));G9A;&ED(&YA;64B"FUS9W-T<B`B3F]M(&EN=F%L:61E(@H*(SH@
M;&EB+V%P:2YP:'`Z-S4S"FUS9VED("));G9A;&ED(&]B:F5C=$ED(@IM<V=S
M='(@(D]B:F5C=$ED(&EN=F%L:61E(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T
M:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D
M+B(*;7-G<W1R("(B"B),92!S=7!P;W)T($Q$05`@97-T(')E<75I<R!M86ES
M(&QE(&UO9'5L92!,1$%0(&5S="!I;F%C8V5S<VEB;&4@;W4@;F]N("(*(F-H
M87)GZ2XB"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS9VED("),87-T
M($UO9&EF:65D(@IM<V=S='(@(D1E<FYIZ')E(&UO9&EF:6-A=&EO;B(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C4S"FUS9VED("),87-T($YA
M;64B"FUS9W-T<B`B3F]M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?
M:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`B3&ES=&4B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S@*;7-G:60@(DUA=&-H
M:6YG(@IM<V=S='(@(D-O;G1E;F%N="(*"B,Z(&QI8B]A<&DN<&AP.C(P-PIM
M<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B3F]M
M8G)E(&UA>&EM86P@9&4@8V]N=&%C=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`W"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!P86=E<R(*;7-G
M<W1R(").;VUB<F4@;6%X:6UA;"!D92!P86=E<R(*"B,Z(&QI8B]";&]C:R]T
M<F5E7VUE;G4N<&AP.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R(")-96YU
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI<W-I;F<@
M1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1$X@
M;6%N<75A;G0@9&%N<R!L82!C;VYF:6=U<F%T:6]N(&1E(&QA('-O=7)C92!,
M1$%0+B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V,@IM<V=I
M9"`B36]B:6QE(%!H;VYE(@IM<V=S='(@(E3I;"X@;6]B:6QE(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HS,S(@;&EB+T1R:79E<B]L9&%P+G!H<#HS-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y(&9A:6QE9#H@*"5S*2`E<R(*
M;7-G<W1R("+)8VAE8R!D92!L82!M;V1I9FEC871I;VZ@.B`H)7,I("5S(@H*
M(SH@;&EB+V%P:2YP:'`Z,3(R-`IM<V=I9"`B36]R92!T:&%N(#$@96YT<GD@
M9F]U;F0B"FUS9W-T<B`B4&QU<R!D)W5N92!E;G1RZ64@=')O=7;I92(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,38*;7-G:60@(DUO=F4B
M"FUS9W-T<B`B1.EP;&%C97(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K
M<V5L96-T+FEN8SHQ.#0*;7-G:60@(DUO=F4@;&5F="(*;7-G<W1R(")$Z7!L
M86-E<B#@(&=A=6-H92(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE
M8W0N:6YC.C(T.0HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE
M8W0N:6YC.C$X-@IM<V=I9"`B36]V92!R:6=H="(*;7-G<W1R(")$Z7!L86-E
M<B#@(&1R;VET92(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,38*;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G
M<W1R(")!;FYU86ER92!-=6QB97)R>2(*"B,Z(&QI8B]A<&DN<&AP.C$Q-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB375L=&EP;&4@<&5R<V]N<R!W:71H
M(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@86QR96%D
M>2!E>&ES="(*;7-G<W1R("(B"B)0;'5S:65U<G,@<&5R<V]N;F5S(&%V96,@
M;"=A9')E<W-E(%LE<UTL(&UA:7,@875C=6YE(&%V96,@;&4@;F]M(%LE<UT@
M(@HB97AI<W1E;G0@9.EJX"(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*;7-G:60@(DUY($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")-;VX@86YN=6%I<F4B"@HC.B!A9&1R97-S
M8F]O:W,N<&AP.C$Q.0IM<V=I9"`B37D@061D<F5S<R!";V]K<R(*;7-G<W1R
M(")-97,@86YN=6%I<F5S(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z,3`W(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0R"FUS9VED(").
M86UE(@IM<V=S='(@(DYO;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,0IM<V=I9"`B3F%M92!&;W)M870B"FUS9W-T<B`B1F]R;6%T(&1E(&YO;2(*
M"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T8V5N
M=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B4NEP97)T;VER92!-96UB
M<F4@3F5T8V5N=&5R(@H*(SH@861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L:6(O
M0FQO8VLO=')E95]M96YU+G!H<#HR-PIM<V=I9"`B3F5W($-O;G1A8W0B"FUS
M9W-T<B`B3F]U=F5A=2!C;VYT86-T(@H*(SH@961I="YP:'`Z.34@961I="YP
M:'`Z,3`R(&5D:70N<&AP.C(P.2!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C0U"FUS9VED(").97AT(@IM<V=S='(@(E-U:79A;G0B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HR,3@*;7-G:60@(DYI8VMN86UE(@IM<V=S
M='(@(E-U<FYO;2(*"B,Z(&QI8B]A<&DN<&AP.C$R,C8@;&EB+V%P:2YP:'`Z
M,3(W-0HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E;G1R>2!F;W5N9"!F
M;W(@)7,B"FUS9W-T<B`B075C=6YE(&5N='+I92`E<R!T<F]U=NEE('!O=7(@
M)7,N("(*"B,Z(&QI8B]A<&DN<&AP.C$Q.30*;7-G:60@(DYO(&%D9')E<W,@
M8F]O:W,@9F]U;F0N(@IM<V=S='(@(D%U8W5N(&-A<FYE="!D)V%D<F5S<V5S
M('1R;W5VZ2XB"@HC.B!M:6YI<V5A<F-H+G!H<#HX,0IM<V=I9"`B3F\@8V]N
M=&%C=',@9F]U;F0B"FUS9W-T<B`B075C=6X@8V]N=&%C="!T<F]U=NDB"@HC
M.B!L:6(O87!I+G!H<#HU,3,@;&EB+V%P:2YP:'`Z-S@T"FUS9VED(").;R!V
M0V%R9"!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B075C=6YE(&1O;F[I92!V
M0V%R9"!T<F]U=NEE+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN
M8SHW"FUS9VED(").;VYE(@IM<V=S='(@(D%U8W5N(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3@T"FUS9VED(").;W1E<R(*;7-G<W1R(").
M;W1E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(DYU
M;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R(").;VUB<F4@9"=I=&5M
M<R!P87(@<&%G92(*"B,Z(&QI8B]A<&DN<&AP.C8S,B!L:6(O87!I+G!H<#HW
M-C4*;7-G:60@(D]B:F5C="!N;W0@9F]U;F0B"FUS9W-T<B`B4W5J970@;F]N
M('1R;W5VZ2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(R,PIM
M<V=I9"`B3V9F:6-E(@IM<V=S='(@(D)U<F5A=2(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I;7-P7V]P="YI;F,Z,C(*;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@
M=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E
M<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@;F]T('=H870@>6]U
M('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N("(*
M(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"B)!<'+H<R!A=F]I<B!S875V97(@
M8V5T=&4@<&%G92!D)V]P=&EO;G,L(&QE(&-A<FYE="!D)V%D<F5S<V5S('-E
M<F$@<W5P<')I;>D@(@HB9.EF:6YI=&EV96UE;G0N(%-I(&-E(&XG97-T('!A
M<R!C92!Q=64@=F]U<R!V;W5L97HL('9O=7,@9&5V97H@8VAA;F=E<B!V;W1R
M92`B"B)SZ6QE8W1I;VX@96X@JZ!!=6-U;J"[+B(*"B,Z(&QI8B]A<&DN<&AP
M.C<Y,@IM<V=I9"`B3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D+B(*;7-G<W1R
M(")5;F4@<V5U;&4@=D-A<F0@97-T('-U<'!O<G3I92XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V"FUS
M9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D%U=')E<R!O<'1I;VYS(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DP"FUS9VED(")01U`@
M4'5B;&EC($ME>2(*;7-G<W1R(")#;.D@<'5B;&EQ=64@4$=0(@H*(SH@;&EB
M+V%P:2YP:'`Z-#DW(&QI8B]A<&DN<&AP.C8R,R!L:6(O87!I+G!H<#HW,3`@
M;&EB+V%P:2YP:'`Z.38U"B,Z(&QI8B]A<&DN<&AP.C$Q,CD*;7-G:60@(E!E
M<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<FUI<W-I;VX@<F5F=7/I92(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C4U,`IM<V=I9"`B4&5R;6ES<VEO;B!D96YI
M960B"FUS9W-T<B`B4&5R;6ES<VEO;B!R969U<^EE(@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z.3D*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S
M='(@(D1R;VET<R!D)V%C8^AS(@H*(SH@9&%T82YP:'`Z-3,@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHQ-PIM<V=I9"`B4&EN92!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B06YN=6%I<F4@4&EN92(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE('1H92!N97<@
M8V]N=&%C="!L:7-T.B(*;7-G<W1R(")6975I;&QE>B!N;VUM97(@;&$@;F]U
M=F5L;&4@;&ES=&4@9&4@8V]N=&%C='.@.B(*"B,Z(&5D:70N<&AP.CDX(&5D
M:70N<&AP.C$P,2!E9&ET+G!H<#HR,#$*;7-G:60@(E!R979I;W5S(@IM<V=S
M='(@(E!RZ6/I9&5N="(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q
M-@IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B06YN=6%I
M<F4@<')I=NDB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")1=65R>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B
MR6-H96,@9&4@;&$@<F5Q=>IT9:`Z("@E<RD@)7,B"@HC.B!T96UP;&%T97,O
M8FQO8VLO;6EN:7-E87)C:"YI;F,Z,3@*;7-G:60@(E%U:6-K(%-E87)C:"(*
M;7-G<W1R(")296-H97)C:&4@<VEM<&QI9FGI92(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E860@9F%I
M;&5D.B`H)7,I("5S(@IM<V=S='(@(LEC:&5C(&1E(&QE8W1U<F6@.B`H)7,I
M("5S(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HU,@IM<V=I9"`B4F5A9&EN
M9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),82!L96-T
M=7)E(&1E<R!C;VYT86-T<R!N)V5S="!P87,@9&ES<&]N:6)L92XB"@HC.B!L
M:6(O4F5N9&5R97(N<&AP.C0Y"FUS9VED(")296%L;'D@9&5L971E('1H:7,@
M8V]N=&%C=#\B"FUS9W-T<B`B4W5P<')I;65R(&-E(&-O;G1A8W0@9.EF:6YI
M=&EV96UE;G2@/R(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR
M"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`B16YR96=I<W1R
M96UE;G1S(&%F9FEC:.ESH#HB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S
M<V)O;VMS96QE8W0N:6YC.C$W-@IM<V=I9"`B4F5M;W9E(&%D9')E<W,@8F]O
M:R(*;7-G<W1R(")3=7!P<FEM97(@=6X@8V%R;F5T(&0G861R97-S97,B"@HC
M.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,SD*;7-G:60@
M(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B4F5T:7)E<B!L82!C;VQO;FYE(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"FUS9VED(")296UO
M=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B4F5T:7)E<B!D92!L82!L:7-T
M92(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C$*;7-G:60@(B(*
M(E)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R
M=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL
M(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@8F]O:RX\+W-T<F]N
M9SXB"FUS9W-T<B`B(@HB4F5M<&QA8V5R(&QE(&-A<FYE="!D)V%D<F5S<V5S
M(&5X:7-T86YT('!A<B!C96QU:2!I;7!O<G3IH#\@(@HB/'-T<F]N9SY!='1E
M;G1I;VZ@.B!C96QA('-U<'!R:6UE<F$@=&]U=&5S('9O<R!E;G1RZ65S(&1U
M('!RZ7-E;G0@8V%R;F5T("(*(F0G861R97-S97,N/"]S=')O;F<^(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z-#,X"FUS9VED(")297%U97-T960@;V)J96-T(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4W5J970@;F]N('1R;W5VZ2XB"@HC.B!A9&0N
M<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,30*;7-G:60@
M(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(E)E;65T=')E(.`@;&$@8V]N
M9FEG=7)A=&EO;B!P87(@9.EF875T(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I9FEC871E
M(@IM<V=S='(@(D-E<G1I9FEC870@<'5B;&EC(%,O34E-12(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E14
M3%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(LEC:&5C(&1E(%-405)45$Q3
MH#H@*"5S*2`E<R(*"B,Z(&5D:70N<&AP.C$P-B!A9&0N<&AP.C,W('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V92(*;7-G<W1R
M(")%;G)E9VES=')E<B(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-C<*;7-G
M:60@(E-A=FEN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("),)V5N<F5G:7-T<F5M96YT(&1E<R!C;VYT86-T<R!N)V5S="!P87,@9&ES
M<&]N:6)L92(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-R!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$S"B,Z('1E;7!L871E<R]B
M;&]C:R]M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HT.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R
M8V@B"FUS9W-T<B`B4F5C:&5R8VAE<B(*"B,Z(&QI8B]A<&DN<&AP.C$P-#(*
M;7-G:60@(E-E87)C:"!F86EL960B"FUS9W-T<B`B3&$@<F5C:&5R8VAE(&$@
MZ6-H;W7I(@H*(SH@;&EB+V%P:2YP:'`Z,3$S-"!L:6(O87!I+G!H<#HQ,30P
M(&QI8B]A<&DN<&AP.C$Q-#D@;&EB+V%P:2YP:'`Z,3$V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R("+)8VAE8R!D
M92!L82!R96-H97)C:&6@.B`E<R(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z
M-#<*;7-G:60@(E-E87)C:&EN9R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("),82!R96-H97)C:&4@;B=E<W0@<&%S(&1I<W!O;FEB;&4B"@HC.B!T96UP
M;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C(*;7-G:60@(E-E87)C:&EN
M9RXN+B(*;7-G<W1R(")296-H97)C:&4@96X@8V]U<G,N+BXB"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@IM<V=I9"`B4V5L96-T(&%N(&%D
M9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&QE
M(&-A<FYE="!D)V%D<F5S<V5S(.`@<W5P<')I;65RH#HB"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHY,`IM<V=I9"`B4V5L96-T(&%N(&%D9')E
M<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L92!C87)N
M970@9"=A9')E<W-E<R#@(.ED:71E<J`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHS,@IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@
M=&\@97AP;W)T(&9R;VTZ(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L92!C87)N
M970@9"=A9')E<W-E<R!P;W5R(&PG97AP;W)T871I;VZ@.B(*"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,C8*;7-G:60@(E-E;&5C="!T:&4@861D
M<F5S<R!B;V]K('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B4^EL96-T:6]N;F5Z
M(&QE(&-A<FYE="!D)V%D<F5S<V5S('!O=7(@;"=I;7!O<G1A=&EO;J`Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0IM<V=I9"`B4V5L96-T
M('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B4^EL
M96-T:6]N;F5Z(&QE(&IE=2!D92!C87)A8W3H<F5S(&1U(&9I8VAI97(@<V]U
M<F-EH#HB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P"FUS9VED
M(")396QE8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(D-H;VES:7-S
M97H@;&4@9F]R;6%T(&0G97AP;W)T871I;VZ@.B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z-#,*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I
M;7!O<G0Z(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L92!F:6-H:65R(.`@:6UP
M;W)T97*@.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G
M:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS
M9W-T<B`B0VAO:7-I<W-E>B!L92!F;W)M870@9'4@9FEC:&EE<B!S;W5R8V6@
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C
M="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`B
M4^EL96-T:6]N;F5Z(&QE(&9O<FUA="#@('5T:6QI<V5R('!O=7(@869F:6-H
M97(@;&5S(&YO;7.@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-0IM
M<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T
M(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4^EL
M96-T:6]N;F5Z(&QA('9U92#@(&%F9FEC:&5R('!A<B!DZ69A=70L(&%I;G-I
M('%U92!L97,@;W!T:6]N<R!D92!T<FD@970@(@HB9&4@<&%G:6YA=&EO;BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-E;&5C="!W
M:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB
M"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&QE<R!C:&%M<',@X"!A9F9I8VAE<B!D
M86YS(&QA(&QI<W1E(&1E<R!A9')E<W-E<RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S(*;7-G:60@(E-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES
M<&QA>2!N86UE<RXB"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&QE(&9O<FUA="!U
M=&EL:7/I('!O=7(@869F:6-H97(@;&5S(&YO;7,N(@H*(SH@861D+G!H<#HU
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")396QE8W1E9"!A9&1R97-S(&)O;VL@
M7"(E<UPB+B(*;7-G<W1R(")#87)N970@9"=A9')E<W-E<R!SZ6QE8W1I;VYN
MZ:`Z("5S+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$W,PIM<V=I
M9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G<W1R(")2Z7!E<G1O:7)E('!A<G1A
M9^DB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0V"B,L('!H
M<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`B069F:6-H97(@)7,B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0X"FUS9VED(")3
M:&]W($%L;"(*;7-G<W1R(")!9F9I8VAE<B!T;W5T(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHT-PIM<V=I9"`B4VAO=R!#;VYT86-T<R(*
M;7-G<W1R(")!9F9I8VAE<B!C;VYT86-T<R(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z-#8*;7-G:60@(E-H;W<@3&ES=',B"FUS9W-T<B`B
M069F:6-H97(@;&ES=&5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?
M:&5A9&5R<RYI;F,Z,C$*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A
M9&5R<RYI;F,Z,S8*;7-G:60@(E-O<G0@1&ER96-T:6]N(@IM<V=S='(@(E-E
M;G,@9'4@=')I(@H*(SH@;&EB+V%P:2YP:'`Z,C`P"FUS9VED(")3;W5R8V5S
M(@IM<V=S='(@(E-O=7)C97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34X"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E
M87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B(@HB4W#I8VEF:65R
M(&PG96YD<F]I="!O^2!L92!RZ7-U;'1A="!D92!L82!R96-H97)C:&4@879A
M;F/I92!D;VET(',G869F:6-H97(N(@H*(SH@8G)O=W-E+G!H<#HR,30@8G)O
M=W-E+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&%D9&5D("5D(&-O;G1A8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`B)60@8V]N
M=&%C="AS*2!A:F]U=.DH<RD@X"!L82!L:7-T92XB"@HC.B!B<F]W<V4N<&AP
M.C$V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@
M)7,@=&\@)7,B"FUS9W-T<B`BJZ`E<Z"[(&$@8FEE;B#I=.D@86IO=73I*&4I
M(.`@)7,N(@H*(SH@8G)O=W-E+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A8W0@;&ES="!<(B5S
M7"(N(@IM<V=S='(@(DQA(&QI<W1E(*N@)7.@NR!A(&)I96X@Z73I(&-RZ>EE
M+B(*"B,Z(&)R;W=S92YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&1E;&5T960@)60@8V]N=&%C="AS*2XB"FUS9W-T<B`B4W5P
M<')E<W-I;VX@9&4@)60@8V]N=&%C="AS*2XB"@HC.B!B<F]W<V4N<&AP.C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D("5D
M(&-O;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G<W1R("(E9"!C;VYT86-T*',I
M(')E=&ERZ2AS*2!D92!L82!L:7-T92XB"@HC.B!D871A+G!H<#HU,`IM<V=I
M9"`B5%-6(@IM<V=S='(@(E135B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-`IM<V=I9"`B
M5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B5F%L975R<R!SZ7!A<NEE
M<R!P87(@=&%B=6QA=&EO;B(*"B,Z('9I97<N<&AP.C$U"FUS9VED(")4:&4@
M5D93(&)A8VME;F0@;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@
M871T86-H;65N="!U<&QO861S+B(*;7-G<W1R("(B"B),92!M;V1U;&4@5D93
M(&1O:70@ZG1R92!C;VYF:6=U<ND@<&]U<B!P97)M971T<F4@;&4@=.ELZ6-H
M87)G96UE;G0@9&5S("(*(G!IZ&-E<R!J;VEN=&5S+B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$P-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@
M8F]O:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DQE(&-A<FYE
M="!D)V%D<F5S<V5S(*N@)7.@NR!N)V5X:7-T92!P87,N(@H*(SH@861D<F5S
M<V)O;VMS+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S
M<R!B;V]K(%PB)7-<(B!W87,@8W)E871E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(DQE(&-A<FYE="!D)V%D<F5S<V5S(*N@)7.@NR!A(.ETZ2!C<NGI+B(*
M"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(')E;6]V960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R("),92!C87)N970@9"=A9')E<W-E<R"KH"5SH+L@82#I
M=.D@<W5P<')I;>DN(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C
M8V5S<V9U;&QY('5P9&%T960N(@IM<V=S='(@(DQE(&-A<FYE="!D)V%D<F5S
M<V5S(*N@)7.@NR!A(.ETZ2!M:7,@X"!J;W5R+B(*"B,Z(&1A=&$N<&AP.C,P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(&-O=6QD
M(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(DQE(&-A<FYE="!D)V%D<F5S
M<V5S(&XG82!P87,@<'4@ZG1R92!P=7)GZ:`Z("5S(@H*(SH@961I="YP:'`Z
M-3$@=F-A<F0N<&AP.C(R(&1I<W!L87DN<&AP.C(S('9I97<N<&AP.C(V"FUS
M9VED(")4:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("),92!C;VYT86-T(&1E;6%N9.D@;B=E>&ES=&4@<&%S+B(*
M"B,Z(&5D:70N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL
M92!<(B5S7"(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N(@IM<V=S
M='(@(DQE(&9I8VAI97(@JZ`E<Z"[(&$@Z73I('-U<'!R:6WI+B(*"B,Z(&1A
M=&$N<&AP.C(X-`IM<V=I9"`B5&AE(&EM<&]R="!C86X@8F4@9FEN:7-H960@
M9&5S<&ET92!T:&4@=V%R;FEN9W,N(@IM<V=S='(@(DPG:6UP;W)T871I;VX@
M<R=E<W0@=&5R;6ENZ64@;6%L9W+I(&QE<R!A=F5R=&ES<V5M96YT<RXB"@HC
M.B!B<F]W<V4N<&AP.C,Q"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E86)L
M92!A9&1R97-S(&)O;VMS+B(*;7-G<W1R(")!=6-U;B!C87)N970@9"=A9')E
M<W-E<R!D:7-P;VYI8FQE(&5N(&QE8W1U<F4N(@H*(SH@861D+G!H<#HR.0IM
M<V=I9"`B(@HB5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S(&)O;VMS
M+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R`B"B)A<F4@
M8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S('1O
M('1H96TN($EF('EO=2!B96QI979E('1H:7,@(@HB:7,@86X@97)R;W(L('!L
M96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(D%U8W5N(&1E<R!A;FYU86ER97,@9&ES<&]N:6)L97,@;B=E<W0@
M8V]N9FEG=7+I('!O=7(@=F]U<R!P97)M971T<F4@(@HB9"=A:F]U=&5R('5N
M(&YO=79E874@8V]N=&%C="X@4VD@=F]U<R!P96YS97H@<75E(&-E8VD@97-T
M('5N92!E<G)E=7(L("(*(F-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U
M<B!S>7-TZ&UE+B(*"B,Z(&%D9"YP:'`Z,3(Q"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@861D:6YG('1H92!N97<@8V]N=&%C="X@0V]N=&%C="!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R("(*(F9O<B!F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@
M;"=A:F]U="!D92!C92!C;VYT86-T+B!#;VYT86-T97H@=F]T<F4@(@HB861M
M:6YI<W1R871E=7(@<WES=.AM92!P;W5R('!L=7,@9"=I;F9O<FUA=&EO;G,N
M(@H*(SH@8G)O=W-E+G!H<#HR-S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R(")5;F4@97)R975R(&5S
M="!S=7)V96YU92!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1E(&-E='1E(&QI<W1E
M+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D<F5S<R!B
M;V]K.B`E<R(*;7-G<W1R("(B"B)5;F4@97)R975R(&5S="!S=7)V96YU92!L
M;W)S(&1E(&QA(&-RZ6%T:6]N(&1E(&-E(&-A<FYE="!D)V%D<F5S<V5SH#H@
M)7,B"@HC.B!B<F]W<V4N<&AP.C$V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@7"(E<UPB(&9R;VT@=&AE('-O
M=7)C92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@97-T
M('-U<G9E;G5E(&QO<G,@9&4@;"=E9F9A8V5M96YT(&1E("5S(&1U(&-A<FYE
M="!D)V%D<F5S<V5S("(*(F0G;W)I9VEN92XB"@HC.B!D96QE=&4N<&AP.C,W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!T:&ES(&-O;G1A8W0Z("5S(@IM<V=S='(@(E5N92!E<G)E=7(@97-T
M('-U<G9E;G5E(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@8V4@8V]N=&%C
M=*`Z("5S(@H*(SH@8G)O=W-E+G!H<#HS,3$*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!L:7-T(@IM<V=S='(@(E5N92!E<G)E
M=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=A9F9I8VAA9V4@9&4@;&$@;&ES
M=&4B"@HC.B!D871A+G!H<#HS,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T
M<B`B56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)VEM<&]R=&%T
M:6]N(&1E<R!D;VYNZ65SH#H@)7,B"@HC.B!L:6(O87!I+G!H<#HU,#D@;&EB
M+V%P:2YP:'`Z-S<Y"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B56YE(&5R<F5U<B!E
M<W0@<W5R=F5N=64@;&]R<R!D92!L)VEM<&]R=&%T:6]N(&1E<R!D;VYNZ65S
M(&E#86QE;F1A<BXB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C4X(&%D9')E<W-B
M;V]K<RYP:'`Z-C,@861D<F5S<V)O;VMS+G!H<#HV.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@=&AI<R!A9&1R
M97-S(&)O;VLZ("5S(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@97-T('-U<G9E
M;G5E(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@8V4@8V%R;F5T(&0G861R
M97-S97.@.B`E<R(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@
M861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("(B"B)5;F4@97)R975R(&5S="!S
M=7)V96YU92!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1E(&-E(&-A<FYE="!D
M)V%D<F5S<V5SH#H@)7,B"@HC.B!E9&ET+G!H<#HQ-C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT
M<GDZ("5S(@IM<V=S='(@(E5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@
M9&4@;&$@;6ES92#@(&IO=7(@9&4@;"=E;G1RZ66@.B`E<R(*"B,Z(&1A=&$N
M<&AP.C$W.0IM<V=I9"`B5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP
M;W)T+B(*;7-G<W1R("));"!N)WD@82!P87,@9&4@8V%R;F5T(&0G861R97-S
M97,@X"!E>'!O<G1E<BXB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O
M;VMS96QE8W0N:6YC.C$X,`IM<V=I9"`B5&AE<V4@861D<F5S<R!B;V]K<R!W
M:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B0V5S(&-A<FYE
M=',@9"=A9')E<W-E<R!S97)O;G0@869F:6-HZ7,@9&%N<R!C970@;W)D<F6@
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T,PIM
M<V=I9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E
M<CHB"FUS9W-T<B`B0V5S(&-O;&]N;F5S('-E<F]N="!A9F9I8VCI97,@9&%N
M<R!C970@;W)D<F6@.B(*"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F
M:6QE(&9O<FUA="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")#92!F;W)M
M870@9&4@9FEC:&EE<B!N)V5S="!P87,@<W5P<&]R=.DN(@H*(SH@;&EB+V%P
M:2YP:'`Z,3$U,R!L:6(O87!I+G!H<#HQ,38V"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@=&AE
M(&%D9')E<W,@8F]O:R(*;7-G<W1R(")#971T92!P97)S;VYN92!A(&3I:N`@
M=6YE(&5N='+I92`E<R!D86YS(&QE(&-A<FYE="!D)V%D<F5S<V5S+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#@*;7-G:60@(B(*(E1H:7,@=VEL
M;"!B92!T:&4@9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@
M:6UP;W)T:6YG(&-O;G1A8W1S+B(*;7-G<W1R("(B"B)#92!S97)A(&QE(&-A
M<FYE="!D)V%D<F5S<V5S('!A<B!DZ69A=70@<&]U<B!L)V%J;W5T(&]U(&PG
M:6UP;W)T871I;VX@9&4@(@HB8V]N=&%C=',N(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@(E1I=&QE(@IM<V=S='(@(D9O;F-T
M:6]N(@H*(SH@;&EB+U1U<F)A+G!H<#HT-#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N($UI<W-I;F<@<V]U<F-E
M('1Y<&4N(@IM<V=S='(@(B(*(DEM<&]S<VEB;&4@9&4@8W+I97(@=6X@;F]U
M=F5A=2!P87)T86=E+B!);"!M86YQ=64@;&4@='EP92!D92!L82!S;W5R8V4N
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`B26UP;W-S:6)L92!D92!C:&%R9V5R(&QA(&3I9FEN:71I;VX@9&4@)7,N
M(@H*(SH@961I="YP:'`Z.34@961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D
M:70N<&AP.C$P-B!E9&ET+G!H<#HR,#,*;7-G:60@(E5N9&\@0VAA;F=E<R(*
M;7-G<W1R(")$Z69A:7)E(&QE<R!M;V1I9FEC871I;VYS(@H*(SH@;&EB+V%P
M:2YP:'`Z-30R(&QI8B]A<&DN<&AP.C8V,2!L:6(O87!I+G!H<#HW.3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E
M<R(*;7-G<W1R(")4>7!E(&1E(&-O;G1E;G4@;F]N+7-U<'!O<G3IH#H@)7,B
M"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HS-S8*;7-G:60@(E9E<FES
M:6=N($1I<F5C=&]R>2(*;7-G<W1R(")2Z7!E<G1O:7)E(%9E<FES:6=N(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$Y('1E;7!L871E<R]B<F]W
M<V4O8V]N=&%C=')O=RYI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE
M=R!<(B5S7"(B"FUS9W-T<B`B5F]I<B"KH"5SH+LB"@HC.B!M:6YI<V5A<F-H
M+G!H<#HW-@IM<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(D%F9FEC:&5R
M(&QE(&-O;G1A8W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS
M9VED(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS9W-T<B`B069F
M:6-H86=E('!A<B!DZ69A=72@.B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T<B`B55),(&1U
M('-I=&4@=V5B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$S
M"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R97-S92!B=7)E874B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O
M<FL@0VET>2(*;7-G<W1R(")6:6QL92!D=2!B=7)E874B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ,SD*;7-G:60@(E=O<FL@0V]U;G1R>2(*
M;7-G<W1R(")087ES(&1U(&)U<F5A=2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$U-@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")4Z6PN
M(&)U<F5A=2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S-`IM
M<V=I9"`B5V]R:R!0;W-T86P@0V]D92(*;7-G<W1R(")#;V1E('!O<W1A;"!D
M=2!B=7)E874B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*
M;7-G:60@(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`BR71A="]0<F]V
M:6YC92!D=2!B=7)E874B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ,3D*;7-G:60@(E=O<FL@4W1R965T($%D9')E<W,B"FUS9W-T<B`B4G5E
M(&1U(&)U<F5A=2(*"B,Z(&1A=&$N<&AP.C(S-R!B<F]W<V4N<&AP.C$P-B!B
M<F]W<V4N<&AP.C(R-R!A9&0N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C
M;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S='(@(E9O=7,@;B?J=&5S('!A<R!A
M=71O<FESZ2#@(&-RZ65R('!L=7,@9&4@)60@8V]N=&%C=',@9&%N<R"KH"5S
MH+LN(@H*(SH@961I="YP:'`Z-S,@9&ES<&QA>2YP:'`Z-3@@=FEE=RYP:'`Z
M,S8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@
M=&AI<R!C;VYT86-T+B(*;7-G<W1R(")6;W5S(&XGZG1E<R!P87,@875T;W)I
M<^D@X"!C;VYS=6QT97(@8V4@8V]N=&%C="XB"@HC.B!V8V%R9"YP:'`Z-#`*
M;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI
M<R!O8FIE8W0N(@IM<V=S='(@(E9O=7,@;B?J=&5S('!A<R!A=71O<FESZ2#@
M(&-O;G-U;'1E<B!C970@;V)J970N(@H*(SH@;&EB+U1U<F)A+G!H<#HU,S$*
M;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N<R!T;R!D96QE=&4@
M=&AI<R!S;W5R8V4N(@IM<V=S='(@(E9O=7,@;B=A=F5Z('!A<R!L)V%U=&]R
M:7-A=&EO;B!D92!S=7!P<FEM97(@8V5T=&4@<V]U<F-E+B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-34*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DEL(&9A
M=70@9"=A8F]R9"!SZ6QE8W1I;VYN97(@=6X@8V%R;F5T(&0G861R97-S92!C
M:6)L92XB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S
M"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB"FUS9W-T
M<B`B5F]U<R!D979E>B!D)V%B;W)D('/I;&5C=&EO;FYE<B!U;F4@;&ES=&4@
M8VEB;&4N(@H*(SH@961I="YP:'`Z,S(*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B5F]U<R!D
M979E>B!D)V%B;W)D('/I;&5C=&EO;FYE<B!A=2!M;VEN<R!U;B!C;VYT86-T
M+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M
M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O
M8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE
M8W0@870@;&5A<W0@;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R(")6;W5S(&1E
M=F5Z(&0G86)O<F0@<^EL96-T:6]N;F5R(&%U(&UO:6YS('5N92!E;G1RZ64N
M(@H*(SH@961I="YP:'`Z-S<*;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES
M<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB"FUS9W-T<B`B5F]U<R#J=&5S
M('-E=6QE;65N="!A=71O<FESZ2#@(&-O;G-U;'1E<B!C92!C;VYT86-T+B(*
M"B,Z(&)R;W=S92YP:'`Z,S$X"FUS9VED(")9;W5R(&1E9F%U;'0@861D<F5S
M<R!B;V]K(&ES(&YO="!B<F]W<V5A8FQE+B(*;7-G<W1R("));7!O<W-I8FQE
M(&1E('!A<F-O=7)I<B!V;W1R92!C87)N970@9"=A9')E<W-E<R!P87(@9.EF
M875T+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHV('1E;7!L871E
M<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@(EMN;R!V86QU95TB
M"FUS9W-T<B`B6U!A<R!D92!V86QE=7)=(@H*(SH@;&EB+U1U<F)A+G!H<#HU
M-30*;7-G:60@(E]"<F]W<V4B"FUS9W-T<B`B7TQI<W1E<B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#<*;7-G:60@(E]#;VYT86-T<R(*
M;7-G<W1R(")?0V]N=&%C=',B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C,*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B4U]U<'!R:6UE<B(*
M"B,Z(&QI8B]4=7)B82YP:'`Z-38S"FUS9VED(")?26UP;W)T+T5X<&]R="(*
M;7-G<W1R(")?26UP;W)T97(O17AP;W)T97(B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C0V"FUS9VED(")?3&ES=',B"FUS9W-T<B`B7TQI
M<W1E<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-34Q"FUS9VED(")?37D@061D<F5S
M<R!";V]K<R(*;7-G<W1R(")?365S(&%N;G5A:7)E<R(*"B,Z(&QI8B]4=7)B
M82YP:'`Z-34W"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T<B`B7TYO=79E
M874@8V]N=&%C="(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,PIM<V=I9"`B7U)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R(")?4F5T
M:7)E<B!D92!L82!L:7-T92(*"B,Z(&QI8B]4=7)B82YP:'`Z-34Y"FUS9VED
M(")?4V5A<F-H(@IM<V=S='(@(E]296-H97)C:&4B"@HC.B!V8V%R9"YP:'`Z
M-#8*;7-G:60@(F-O;G1A8W0N=F-F(@IM<V=S='(@(F-O;G1A8W0N=F-F(@H*
M(SH@9&%T82YP:'`Z,3DY(&1A=&$N<&AP.C(P-"!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$*;7-G:60@(F-O;G1A8W1S+F-S=B(*;7-G<W1R(")C;VYT
M86-T<RYC<W8B"@HC.B!D871A+G!H<#HR,#D*;7-G:60@(F-O;G1A8W1S+G1S
M=B(*;7-G<W1R(")C;VYT86-T<RYT<W8B"@HC.B!D871A+G!H<#HR,3D*;7-G
M:60@(F-O;G1A8W1S+G9C9B(*;7-G<W1R(")C;VYT86-T<RYV8V8B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,X"FUS9VED(")N;R!F;W)M871T:6YG
M(@IM<V=S='(@(D%U8W5N(&9O<FUA=&%G92(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I;7-P7V]P="YI;F,Z,S(*;7-G:60@(FYO;F4B"FUS9W-T<B`B875C=6XB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Q"FUS9VED(")T
M;R!A($-O;G1A8W0@3&ES="(*;7-G<W1R(")V97)S('5N92!L:7-T92!D92!C
M;VYT86-T<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C$*
M;7-G:60@(G1O(&$@9&EF9F5R96YT($%D9')E<W,@0F]O:R(*;7-G<W1R(")V
M97)S('5N(&%U=')E(&-A<FYE="!D)V%D<F5S<V5S(@H*(SH@9&%T82YP:'`Z
M-3$@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-2!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+V%R
M7U-9+G!O````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-S$W,3<`,3`T,3<S-C(W-38`,#$W-34Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@5'5R8F$@07)A8FEC(%1R86YS
M;&%T:6]N+@HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!4=7)B82!P86-K86=E+@HC($-O<'ER:6=H
M="`H0RD@,C`P,R!0;&%T:6YU;2!);F,N(#QP;$!T:6YU;2YI;F9O/@HC($-U
M<W1O;2!796(@07!P;&EC871I;VYS(#QH='1P.B\O<&QA=&EN=6TM<WDN8V]M
M/@HC(%!L871I;G5M($1E=F5L;W!M96YT(%1E86T@/&1E=G1E86U`<&QA=&EN
M=6TM<WDN;F5T/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U6
M97)S:6]N.B!4=7)B82!<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`S+3`T
M+3,P(#$R.C`P*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@(%!L871I;G5M
M($1E=F5L;W!M96YT(%1E86T@/&1E=G1E86U`<&QA=&EN=6TM<WDN8V]M/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@07)A8FEC(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]0U`Q,C4V7&XB"B)#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([
M('!L=7)A;#TH;B`^(#$I.UQN(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?
M;W!T+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B($%D9"!A;B!)35-0($%D9')E
M<W,@0F]O:R(*;7-G<W1R("+/W<K1(,?AVN3'YNWD(,?AU>3FR-'M(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHS,0HC+"!F=7IZ>0IM<V=I
M9"`B($1E;&5T92!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R("+'SLK1(,_=
MRM$@VN3'YNWD(@H*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I;7!O<G1E
M9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U<V4@:70@:7,@
M82!L:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!M;W9E9"!B96-A=7-E(&ET
M(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@*&EE+B!*
M;VAN($1O92DB"FUS9W-T<B`B7"+'X<?3XR"A(,?AX=[(7"(@("CCR\?A.B#C
MS>//(,?AVM'([2DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS
M9VED(")<(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H:64N($1O92P@2F]H;BDB
M"FUS9W-T<B`B7"+'X>'>R""A(,?AQ]/C7"(@("CCR\?A.B#'X=K1R.T@X\WC
MSRDB"@HC.B!A9&0N<&AP.C$P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M9&1E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S0S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S
M='(@(LKC(,?3RNW1Q\\@Q^'CX=T@)7,@R.3,Q\TB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V9O;W1E<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T
M;R`E<R!O9B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0T-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`BS]W*T2#'X=KDQ^;MY"#'X=7DYLC1[2(*"B,Z(&QI8B]";&]C
M:R]M:6YI<V5A<F-H+G!H<#HT-0IM<V=I9"`B02!B<F]W<V5R('1H870@<W5P
M<&]R=',@:49R86UE<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34Y"FUS9VED(")!8F]V92!S96%R8V@@9F]R
M;2(*;7-G<W1R("(B"@HC.B!V:65W+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!8V-E<W,@9&5N:65D('1O("5S(@IM<V=S='(@(B(*"B,Z(&%D9"YP
M:'`Z-38@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR,@IM<V=I9"`B
M061D(@IM<V=S='(@(L76Q]W)(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E
M<W-B;V]K<V5L96-T+FEN8SHQ-S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`BS]W*T2#:Y,?F[>0@V^W1(-7-[<TB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!A
M;F0@1&5L971E($E-4U`@861D<F5S<R!B;V]K<R(*;7-G<W1R("+AQ^WFS,\@
MS]W*T2#:Y,?F[>0@WL?(X2#AX=_*Q\C)+B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(S-PHC+"!F=7IZ>0IM<V=I9"`B061D(&-O
M;'5M;B(*;7-G<W1R("+%UL?=R2#:X^;/(@H*(SH@961I="YP:'`Z,3(X"B,L
M(&9U>GIY"FUS9VED(")!9&0@9FEL92(*;7-G<W1R("+.V,,@SN''X2#'X<76
MQ]W)(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR,@IM<V=I
M9"`B061D('1O(@IM<V=S='(@(L76Q]W)(,7A["(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C@V"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O
M;VLB"FUS9W-T<B`BS]W*T2#'X=KDQ^;MY"#'X=7DYLC1[2(*"B,Z(&)R;W=S
M92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B061D
M<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`BWL?&X\D@S]W*T2#'X=KDQ^;M
MY"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`HC+"!F=7IZ>0IM<V=I
M9"`B061D<F5S<R!";V]K<R(*;7-G<W1R("+.T>;,(./D(,_=RM$@Q^':Y,?F
M[>0B"@HC.B!A9&0N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B
M;V]K(&5N=')Y(@IM<V=S='(@(L_=RM$@Q^':Y,?F[>0@X>'>T<?!R2#=WM@B
M"@HC.B!D871A+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@8F]O
M:R!S=6-C97-S9G5L;'D@<'5R9V5D+B(*;7-G<W1R("+*XR#'T\KMT<?/(,_=
MRM$@Q^':Y,?F[>0@Q^'5Y.;(T>T@R.3,Q\TB"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K
M('1O(&1E;&5T92`B"FUS9W-T<B`BS]W*T2#'X=KDQ^;MY"#AX=[1Q\')(-W>
MV"(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z
M,3<P"FUS9VED(")!9&1R97-S(&)O;VMS('1H870@=VEL;"!N;W0@8F4@9&ES
M<&QA>65D.B(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C@X('1E;7!L871E
M<R]B<F]W<V4O<V5A<F-H+FEN8SHS-PIM<V=I9"`B061V86YC960@4V5A<F-H
M(@IM<V=S='(@(LC-RR#CRM[/XR(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C8T"FUS9VED(")!;&EA<R(*;7-G<W1R("+'T^,@R,_MX2(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S
M+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(L?AS./MVB(*
M"B,Z(&QI8B]A<&DN<&AP.C4U,@IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@
M=V%N="!T;R!D96QE=&4@)7,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O:F%V87-C<FEP="YI;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R92!T
M:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED
M(")!<V-E;F1I;F<B"FUS9W-T<B`BRM7'VL_M(@H*(SH@<V5A<F-H+G!H<#HX
M-2!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S8*(RP@9G5Z>GD*;7-G
M:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R("+(S<LB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34X"FUS9VED(")"96QO=R!S96%R8V@@9F]R;2(*;7-G
M<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z
M("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B0G)O=W-E(@IM<V=S='(@(LK5W<TB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)U
M<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C0Y"FUS
M9VED(")#4U8B"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C="]'<F]U<"YP:'`Z
M-3<*;7-G:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z
M-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C0T"FUS9VED(")#:&]O<V4@82!N86UE
M(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-H
M;V]S92!A;B!A9&1R97-S(&)O;VLB"FUS9W-T<B`BS]W*T2#:Y,?F[>0@V^W1
M(-7-[<TB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR
M,C$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLZ(@IM
M<V=S='(@(L_=RM$@VN3'YNWD(-OMT2#5S>W-(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S92!W
M:&EC:"!A9&1R97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R
M9&5R.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*
M;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O('5S92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z
M,C(X"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=VAI8V@@8V]L=6UN<R!T;R!D
M:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R("+'SLK1(,KFUMH@
MQ^'#VN//R2#AQ=GEQ]'EQR#=[2#>Q\;CR2#'X=KDQ^;MY"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B0V]L=6UN($]P=&EO;G,B"FUS
M9W-T<B`BSNW'T<?*(,?AP]KCS\DB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L
M=6UN<V5L96-T+FEN8SHR,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO
M="!B92!D:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM
M<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("+>[>,@X]W5
MYN')(,C=Q]'2R2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3,*
M(RP@9G5Z>GD*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,@*$UI8W)O
M<V]F="!/=71L;V]K*2(*;7-G<W1R("+>[>,@X]W5YN')(,C=Q]'2R2(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<V"FUS9VED(")#;VUP86YY
M(@IM<V=S='(@(L?AU-'?R2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$T-`HC+"!F=7IZ>0IM<V=I9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S
M='(@(MKDYL?D(,?AX^32X2(*"B,Z(&QI8B]A<&DN<&AP.C,Q."!L:6(O87!I
M+G!H<#HS-C,@;&EB+V%P:2YP:'`Z-#`W(&QI8B]A<&DN<&AP.C0Y,0HC.B!L
M:6(O87!I+G!H<#HV,#$@;&EB+V%P:2YP:'`Z-C@X(&QI8B]A<&DN<&AP.C<T
M,2!L:6(O87!I+G!H<#HX,3D*(SH@;&EB+V%P:2YP:'`Z,3`P-B!L:6(O87!I
M+G!H<#HQ,#DT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BSMC#(,[AQ^$@Q^'-T-TB"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QU<F4B"FUS9W-T<B`BSMC#(,[AQ^$@Q^'-T-TB"@HC.B!B<F]W
M<V4N<&AP.C$Y,2!B<F]W<V4N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B0V]N
M=&%C="!A9&1E9"!T;R!L:7-T+B(*;7-G<W1R("+'RM7'X2#CS=#FW2#CY"#'
MX=['QN/)+B(*"B,Z(&)R;W=S92YP:'`Z-C`*;7-G:60@(D-O;G1A8W0@<F5M
M;W9E9"!F<F]M(&QI<W0N(@IM<V=S='(@(L?*U<?A(./-T.;=(./D(,?AWL?&
MX\DN(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z("5S(@IM<V=S='(@(MK/SR#'X=KD
MQ^;MY"#=[2#'X=['QN/).B`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`BQ^'4
MT=_)(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3,*;7-G:60@
M(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O:R(*
M;7-G<W1R("+*U<_MT2#/W<K1(,?AVN3'YNWD(@H*(SH@;&EB+TQI<W16:65W
M+G!H<#HS,34*;7-G:60@(D-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@:6XZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S,*;7-G:60@
M(D-R96%T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDX"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R
M("+'RLS'Y2#'X=W1TB#'X<?=RM''UNTZ(@H*(SH@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z-S8@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR
M"B,Z(&QI8B]/8FIE8W0N<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI
M8B]296YD97)E<BYP:'`Z-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R("+-T-TB
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU.`HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E($%D9')E<W,@0F]O:R(*;7-G<W1R("+'SLK1(,_=RM$@
MVN3'YNWD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")$
M96QE=&4@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.0IM<V=I9"`B1&5L971E(&)U='1O;B!B96AA=FEO=7(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR-S`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!F86EL960Z("@E<RD@)7,B
M"FUS9W-T<B`BSMC#(,[AQ^$@Q^'-T-TB"@HC.B!D96QE=&4N<&AP.C,X"FUS
M9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T<B`BSMC#(,[AQ^$@Q^'-T-TB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E
M<&%R=&UE;G0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDW"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(LKDQ]+A[2(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$Q-0HC+"!F=7IZ>0IM<V=I9"`B
M1&5S8W)I<'1I;VXB"FUS9W-T<B`BSNW'T<?*(,?AX]/*SL_C(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q.`IM<V=I9"`B1&ER96-T;W)Y
M(@IM<V=S='(@(N/,X<\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*
M(RP@9G5Z>GD*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`BSNW'T<?*(,?AQ=GE
MQ]$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM
M<V=S='(@(L[MQ]''RB#'X<79Y<?1(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN
M9R!E;G1R:65S/R(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*
M;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O<F]W+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC
M.C(U"FUS9VED(")$;W=N;&]A9"!V0V%R9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R
M;W<N:6YC.C(U"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N
M:6YC.C$P('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PHC.B!T96UP
M;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S(&QI8B]296YD97)E<BYP
M:'`Z-#(*;7-G:60@(D5D:70B"FUS9W-T<B`BRLW1[=$B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+W)O=RYI;F,Z,C4@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T
M<F]W+FEN8SHS,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!<
M(B5S7"(B"FUS9W-T<B`BRLW1[=$@JZ`E<Z"[(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z.#$*(RP@9G5Z>GD*;7-G:60@(D5D:70@061D<F5S
M<R!";V]K<R(*;7-G<W1R("+.T>;,(./D(,_=RM$@Q^':Y,?F[>0B"@HC.B!E
M9&ET+G!H<#HW."!E9&ET+G!H<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D5D:70@96YT<GD@9F]R("5S(@IM<V=S='(@(N''(,KFS,\@R.W'
MY,?*("5S(./D(,/,X2`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C4X"FUS9VED(")%;6%I;"(*;7-G<W1R("+(T>W/(,7AW\K1YN3M(@H*
M(SH@961I="YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O
M<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,30Y(&5D:70N<&AP
M.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E
M9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HW-`HC+"!F=7IZ>0IM<V=I
M9"`B16YT<GD@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(LKC(,?3
MRNW1Q\\@Q^'CX=T@)7,@R.3,Q\TB"@HC.B!L:6(O87!I+G!H<#HT,3,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E87)C:&EN9R!T:&4@
M861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+AQ^WFS,\@S]W*T2#:Y,?F[>0@
MWL?(X2#AX=_*Q\C)+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z-B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C0Q"FUS9VED(")%>'!O
M<G0B"FUS9W-T<B`BRM7/[=$B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C8*;7-G:60@(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`BRM7/
M[=$@S]W*T2#'X=KDQ^;MY"(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR
M-PIM<V=I9"`B17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O
M;7!L971E;'DN(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H
M<#HR,C@@9&%T82YP:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY
M,`HC.B!B<F]W<V4N<&AP.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@
M=&AE(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`BSMC#(-WM(-W*S2#/W<K1
M(,?AVN3'YNWD(,?AX]CAYL@N(@H*(SH@8G)O=W-E+G!H<#HQ,SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z
M("5S(@IM<V=S='(@(L[8PR#.X<?A(,?AR,W+(-WM(,?AX\SASSH@)7,B"@HC
M.B!B<F]W<V4N<&AP.C(W,@IM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!L:7-T
M(@IM<V=S='(@(L[8PR#=[2#*U=W-(,?AWL?&X\DB"@HC.B!B<F]W<V4N<&AP
M.C,Q,`IM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM
M<V=S='(@(L[8PR#=[2#*U=W-(,?AX\SASR(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,S`Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C:&%N
M9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2
M;V]T(#T@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T
M;R!B92!A9&1E9#H@)7,B"FUS9W-T<B`BSMC#(,[AQ^$@Q^'(S<L@W>T@Q^'C
MS.'/.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D9A
M:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("+.V,,@
MW>T@W<K-(,_=RM$@Q^':Y,?F[>0@Q^'CV.'FR"XB"@HC.B!D871A+G!H<#HQ
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T:&4@
M9&ER96-T;W)Y.B`E<R(*;7-G<W1R("+.V,,@SN''X2#'X<C-RR#=[2#'X>/,
MX<\Z("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38W"FUS
M9VED(")&87@B"FUS9W-T<B`BW<??TR(*"B,Z(&5D:70N<&AP.C$R-"!D:7-P
M;&%Y+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D9I;&5S(@IM<V=S='(@(L?A
MX=[((@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<P"FUS9VED
M(")&:6YD(@IM<V=S='(@(L/FS,\B"@HC.B!E9&ET+G!H<#HY-R!E9&ET+G!H
M<#HQ.#<*(RP@9G5Z>GD*;7-G:60@(D9I;FES:"(*;7-G<W1R("+#YLS/(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T
M($YA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@S"FUS9VED(")&<F]M(@IM<V=S
M='(@(N/D(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`T"B,L(&9U
M>GIY"FUS9VED(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@(L_=RM$@
MVN3'YNWD(,?ARN;*[2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHT
M,R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C0T"FUS9VED(")'
M<F]U<"(*;7-G<W1R("+CS./FVLDB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(MKDYL?D
M(,?AX^32X2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.CDS"FUS
M9VED(")(;VUE($-I='DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3`X"B,L(&9U>GIY"FUS9VED(")(;VUE($-O=6YT<GDB
M"FUS9W-T<B`BY<?*W2#'X>/DTN$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BY<?*W2#'
MX>/DTN$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*(RP@
M9G5Z>GD*;7-G:60@(DAO;64@4&]S=&%L($-O9&4B"FUS9W-T<B`BY<?*W2#'
MX>/DTN$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R("+EQ\K=
M(,?AX^32X2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"B,L
M(&9U>GIY"FUS9VED(")(;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(MKD
MYL?D(,?AX^32X2(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C4P-@IM
M<V=I9"`B24U34"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#<*(RP@9G5Z>GD*;7-G:60@(DE-4U`@061D<F5S<R!";V]K($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(M['QN/)(,_=RM$@Q^':Y,?F[>0B"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T
M<B`BQ]/*[=''SR#/W<K1(-KDQ^;MY"(*"B,Z(&1A=&$N<&AP.C,V,0HC+"!F
M=7IZ>0IM<V=I9"`B26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS(@IM<V=S
M='(@(L?3RNW1Q\\ORM7/[=$@S]W'RM$@VN3'YNWD(@H*(SH@;&EB+V%P:2YP
M:'`Z-3DV(&QI8B]A<&DN<&AP.C8X,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!)1"(*;7-G<W1R("+.V,,@W>T@Q^''T^,B"@HC.B!L:6(O87!I+G!H<#HR
M,S`@;&EB+V%P:2YP:'`Z-#`R(&QI8B]A<&DN<&AP.C0X-B!L:6(O87!I+G!H
M<#HU.3(*(SH@;&EB+V%P:2YP:'`Z-C<Y(&QI8B]A<&DN<&AP.C<S,2!L:6(O
M87!I+G!H<#HQ,#<W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&%D9')E<W,@
M8F]O:R(*;7-G<W1R("+/W<K1(-KDQ^;MY"#;[=$@U<WMS2(*"B,Z(&QI8B]A
M<&DN<&AP.C$P.#$@;&EB+V%P:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ,C`W
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(LC1[<\@
MQ>'?RM'FY.T@V^W1(-7-[<TB"@HC.B!L:6(O87!I+G!H<#HQ,#@Y"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&5N=')Y(@IM<V=S='(@(L[8PR#=[2#>[>,@
MQ^'%S\['X2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C8V"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(&ME>2!S<&5C:69I960N(@IM<V=S='(@(LC1[<\@
MQ>'?RM'FY.T@V^W1(-7-[<TB"@HC.B!L:6(O87!I+G!H<#HQ,#@U"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&YA;64B"FUS9W-T<B`BSMC#(-WM(,?AQ]/C
M(@H*(SH@;&EB+V%P:2YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M(&]B:F5C=$ED(@IM<V=S='(@(L[8PR#=[2#>[>,@Q^'%S\['X2(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I
M<R!R97%U:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B
M;&4@;W(@;F]T(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C=%9I
M97<N<&AP.C$S.`IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PHC+"!F=7IZ>0IM<V=I
M9"`B3&%S="!.86UE(@IM<V=S='(@(L?3XR(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O8V]L=6UN7VAE861E<G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED("),:7-T
M(@IM<V=S='(@(M['QN/)(,S/[<_)(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.C<W"FUS9VED(")-871C:&EN9R(*;7-G<W1R("+CV,?(WLD@
MU<WMS<DB"@HC.B!L:6(O87!I+G!H<#HR,#4*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F($-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C,*(RP@9G5Z
M>GD*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R("+>Q\;CR2#,S^W/R2(*"B,Z
M(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-
M:6YI(%-E87)C:"(*;7-G<W1R("+(S<LB"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$3B!I;B!,1$%0('-O=7)C92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0:&]N92(*;7-G<W1R("+'X>7'
MRMT@Q^'CS>/FX2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S,R(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@(DUO9&EF
M>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,3$Y,PHC+"!F=7IZ>0IM<V=I9"`B36]R92!T:&%N(#$@96YT<GD@9F]U;F0B
M"FUS9W-T<B`BRN,@Q=',Q]H@P]_+T2#CY"#>[>/)(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B36]V92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@
M=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*(RP@
M9G5Z>GD*;7-G:60@(DUO=F4@;&5F="(*;7-G<W1R("+*S='MWR#DS>8@Q^'M
MT\?1(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V
M"B,L(&9U>GIY"FUS9VED(")-;W9E(')I9VAT(@IM<V=S='(@(LK-T>W?(.3-
MYB#'X>WC[>0B"@HC.B!D871A+G!H<#HU,B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$V"FUS9VED(")-=6QB97)R>2!!9&1R97-S($)O;VLB"FUS9W-T
M<B`BS]W*T2#:Y,?F[>0@Q^'*YLKM(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I=&@@
M861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y
M(&5X:7-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*;7-G
M:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R("+/W<K1(-KDQ^;MY"#'X<KF
MRNTB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B
M37D@061D<F5S<R!";V]K<R(*;7-G<W1R("+/W<K1(-KDQ^;MY"#'X<KFRNTB
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`BQ]/C
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED(").86UE($9O
M<FUA="(*;7-G<W1R("+*Y-/MWB#'X<?3XR(*"B,Z(&-O;F9I9R]S;W5R8V5S
M+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L:6(O
M0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*(SH@;&EB+T)L;V-K+W1R965?;65N
M=2YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE=R!#;VYT86-T(@IM<V=S='(@
M(L79Y<?1(,?AQ\K5Q^''RB(*"B,Z(&5D:70N<&AP.C@X(&5D:70N<&AP.CDU
M(&5D:70N<&AP.C(P,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0U"FUS
M9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C(Q.`HC+"!F=7IZ>0IM<V=I9"`B3FEC:VYA;64B"FUS9W-T<B`B
MQ]/C(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y-2!L:6(O87!I+G!H<#HQ,C0T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E;G1R>2!F;W5N9"!F
M;W(@)7,B"FUS9W-T<B`BX<<@RN;,SR#([<?DQ\H@)7,@X^0@P\SA("5S(@H*
M(SH@;&EB+V%P:2YP:'`Z,3$V,PHC+"!F=7IZ>0IM<V=I9"`B3F\@861D<F5S
M<R!B;V]K<R!F;W5N9"XB"FUS9W-T<B`BS]W*T2#'X=KDQ^;MY"#AX=[1Q\')
M(-W>V"(*"B,Z(&UI;FES96%R8V@N<&AP.C@S"B,L(&9U>GIY"FUS9VED(").
M;R!C;VYT86-T<R!F;W5N9"(*;7-G<W1R("+%V>7'T2#'X<?*U<?AQ\HB"@HC
M.B!L:6(O87!I+G!H<#HU,3$@;&EB+V%P:2YP:'`Z-S8V"FUS9VED(").;R!V
M0V%R9"!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]F;V]T97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`BX<?M
MYLS/(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3@T"FUS9VED
M(").;W1E<R(*;7-G<W1R("+CX<?-V<?*(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q-0IM<V=I9"`B3G5M8F5R(&]F(&ET96US('!E<B!P86=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C8Q-"!L:6(O87!I+G!H<#HW-#<*
M;7-G:60@(D]B:F5C="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHR,PIM<V=I
M9"`B(@HB3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D
M<F5S<R!B;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"X@268@
M=&AI<R!I<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N
M9V4@>6]U<B!S96QE8W1I;VX@(@HB=&\@7").;VYE7"(N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C<W-`IM<V=I9"`B3VYL>2!O;F4@=F-A<F0@<W5P
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V"B,L(&9U>GIY"FUS9VED(")/
M=&AE<B!/<'1I;VYS(@IM<V=S='(@(L[MQ]''RB#'X>/3RL[/XR(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI
M8R!+97DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-#DU(&QI8B]A<&DN
M<&AP.C8P-2!L:6(O87!I+G!H<#HV.3(@;&EB+V%P:2YP:'`Z.3,T"B,Z(&QI
M8B]A<&DN<&AP.C$P.3@*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C4T,PIM<V=I9"`B4&5R;6ES<VEO
M;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K
M<RYI;F,Z.3D*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C4S('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*;7-G:60@
M(E!I;F4@061D<F5S<R!";V]K(@IM<V=S='(@(L_=RM$@Q^':Y,?F[>0@Q^'5
MY.;(T>TB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(X
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@
M;&ES=#HB"FUS9W-T<B`BQ^'1S,?!(,7/SL?A(,?3XR#'X=['QN/)(,?AS,_M
MS\DZ(@H*(SH@961I="YP:'`Z.3$@961I="YP:'`Z.30@961I="YP:'`Z,3DT
M"FUS9VED(")0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HT,38*(RP@9G5Z>GD*;7-G:60@(E!R:79A=&4@061D<F5S
M<R!";V]K(@IM<V=S='(@(L_=RM$@Q^':Y,?F[>0@Q^'5Y.;(T>TB"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")1
M=65R>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")1=6EC
M:R!396%R8V@B"FUS9W-T<B`BR,W+(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HQ.3$@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3D@;&EB+T1R:79E<B]L9&%P
M+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A9"!F86EL960Z("@E
M<RD@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+U)E;F1E<F5R+G!H<#HT.0IM<V=I
M9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S
M(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D
M9')E<W-B;V]K<V5L96-T+FEN8SHQ-S8*(RP@9G5Z>GD*;7-G:60@(E)E;6]V
M92!A9&1R97-S(&)O;VLB"FUS9W-T<B`BS]W*T2#:Y,?F[>0@V^W1(-7-[<TB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,SD*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`BS=#=(-KCYL\B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@(E)E
M;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R("+'S=#=(./D(,?AWL?&X\DB
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(Q"FUS9VED("(B"B)2
M97!L86-E(&5X:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I;7!O<G1E
M9"!O;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E
M;G1R:65S(&EN('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN/"]S=')O;F<^
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C0S.`IM<V=I9"`B4F5Q
M=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D9"YP
M:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q,PIM<V=I9"`B
M4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I
M9FEC871E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D.B`H)7,I("5S
M(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.CDY(&%D9"YP:'`Z,S<@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S='(@
M(LW=V2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-B!T96UP
M;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$R"B,Z('1E;7!L871E<R]B;&]C
M:R]M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HT
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`BR,W+(@H*(SH@;6EN:7-E87)C:"YP:'`Z-C,*(RP@9G5Z>GD*
M;7-G:60@(E-E87)C:"!297-U;'1S.B(*;7-G<W1R("+DRL?&S"#'X<C-RR(*
M"B,Z(&QI8B]A<&DN<&AP.C$P,3$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!F
M86EL960B"FUS9W-T<B`BR,W+(@H*(SH@;&EB+V%P:2YP:'`Z,3$P,R!L:6(O
M87!I+G!H<#HQ,3`Y(&QI8B]A<&DN<&AP.C$Q,3@@;&EB+V%P:2YP:'`Z,3$S
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C(*
M(RP@9G5Z>GD*;7-G:60@(E-E87)C:&EN9RXN+B(*;7-G<W1R("+(S<LB"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B
MQ\[*T2#/W<K1(-KDQ^;MY"(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N
M:6YC.CDP"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@861D<F5S<R!B;V]K
M('1O(&5D:70B"FUS9W-T<B`BQ\[*T2#/W<K1(-KDQ^;MY"(*"B,Z('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G<W1R("+'
MSLK1(,?AX]7/T2#AX<K5S^W1(./DY3HB"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&%D9')E
M<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(L?.RM$@Q^'FS.7)(,?A
MRNT@RM'MSR#'X<73RNW1Q\\@Q>'MY<<Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C:&%R
M<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`BQ\[*T2#'X>/5S]$@
MX>'*U<_MT2#CY.4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*
M;7-G<W1R("+'SLK1(,?AX]7/T2#AX<K5S^W1(./DY3HB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C0S"FUS9VED(")396QE8W0@=&AE(&9I;&4@
M=&\@:6UP;W)T.B(*;7-G<W1R("+'SLK1(./AW2#A[<KC(,?3RNW1Q\_E.B(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3$*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS
M9W-T<B`BQ\[*T2#*Y-/MWB#'X<K5S^W1.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@
M9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`BQ\[*T2#*Y-/MWB#%V>7'T2#'X</3
MX\?!.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-0HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T
M(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`BQ\[*T2#4
MW^$@Q^'%V>7'T2#'X<?=RM''UNTN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$X"FUS9VED(")396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@
M:6X@=&AE(&%D9')E<W,@;&ES=',N(@IM<V=S='(@(L?.RM$@S=[FX<?P(.'M
MRN,@Q=GEQ]'EQR#=[2#>Q\;CR2#'X=KDQ^;MY"XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-E;&5C="!W:&EC:"!F;W)M870@=&\@
M9&ES<&QA>2!N86UE<RXB"FUS9W-T<B`BQ\[*T2#*Y-/MWB#%V>7'T2#'X</3
MX\?!+B(*"B,Z(&%D9"YP:'`Z-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-E;&5C=&5D(&%D9')E<W,@8F]O:R!<(B5S7"(N(@IM<V=S='(@(L?.
MRM$@S]W*T2#:Y,?F[>0B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ
M-S,*(RP@9G5Z>GD*;7-G:60@(E-H87)E9"!$:7)E8W1O<GDB"FUS9W-T<B`B
MX\SASR(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`BQ=GE
MQ]$B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0Q"FUS9VED
M(")3:&]W($%L;"(*;7-G<W1R("+%V>7'T2#'X=_A(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B4VAO=R!#;VYT86-T<R(*
M;7-G<W1R("+%V>7'T2#'X<?*U<?AQ\HB"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")3:&]W($QI<W1S(@IM<V=S='(@(L79
MY<?1(,?AWN;'QN,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D
M97)S+FEN8SHR,0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHS-`IM<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS9W-T<B`BQ\K,Q^4@
MQ^'=T=(B"@HC.B!L:6(O87!I+G!H<#HQ.3@*(RP@9G5Z>GD*;7-G:60@(E-O
M=7)C97,B"FUS9W-T<B`BRN,@R.3,Q\TB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,34W"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT(&%D=F%N
M8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B(@H*(SH@
M8G)O=W-E+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&%D9&5D("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z
M,C(R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C<F5A=&5D
M('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`BWNWC(./=
MU>;AR2#(X]/'S<DB"@HC.B!V:65W+G!H<#HQ-0IM<V=I9"`B5&AE(%9&4R!B
M86-K96YD(&YE961S('1O(&)E(&-O;F9I9W5R960@=&\@96YA8FQE(&%T=&%C
M:&UE;G0@=7!L;V%D<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z
M,3`U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB
M)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@861D<F5S<V)O
M;VMS+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B
M;V]K(%PB)7-<(B!W87,@8W)E871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(')E;6]V960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C@Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S='(@(LKC(,?3
MRNW1Q\\@S]W*T2#'X=KDQ^;MY"#'X=7DYLC1[2#(Y,S'S2(*"B,Z(&1A=&$N
M<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K
M(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N
M<&AP.C0W('9C87)D+G!H<#HR,B!D:7-P;&%Y+G!H<#HR,R!V:65W+G!H<#HR
M-@IM<V=I9"`B5&AE(&-O;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,3$V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92!<(B5S7"(@:&%S('-U8V-E<W-F
M=6QL>2!B965N(&1E;&5T960N(@IM<V=S='(@(LKC(,?3RNW1Q\\@Q^'CX=T@
M)7,@R.3,Q\TB"@HC.B!D871A+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@
M8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R
M("(B"@HC.B!B<F]W<V4N<&AP.C,Q"FUS9VED(")4:&5R92!A<F4@;F\@8G)O
M=W-E86)L92!A9&1R97-S(&)O;VMS+B(*;7-G<W1R("+AQ^WFS,\@S]W*T2#:
MY,?F[>0@WL?(X2#AX<K5W<TN(@H*(SH@861D+G!H<#HR.0HC+"!F=7IZ>0IM
M<V=I9"`B(@HB5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S(&)O;VMS
M+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R`B"B)A<F4@
M8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S('1O
M('1H96TN($EF('EO=2!B96QI979E('1H:7,@(@HB:7,@86X@97)R;W(L('!L
M96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(N''[>;,SR#/W<K1(-KDQ^;MY"#CVL\@X<7/SL?A(,CMQ^3'RB#,
MS^W/R2X@Q=#'(-_DRB#*VLK>SR##Y.4@SMC#(./'H2#'X=',Q\$@(@HBQ<CA
MQ]L@X\_MT2#'X>39Q^,N(@H*(SH@861D+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE=R!C;VYT
M86-T+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@(@HB9F]R
M(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?AQ=;'W<DN
M(,?AT<S'P2#3Q,?A(.//[=$@Q^'DV<?C(.'8X<@@Q^'CT\?:S\DN(@H*(SH@
M8G)O=W-E+G!H<#HQ.#D@8G)O=W-E+G!H<#HR,S`*(RP@9G5Z>GD*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AI<R!O8FIE8W0N(@IM<V=S
M='(@(LW5X2#.V,,@SN''X2#'X<W0W2XB"@HC.B!B<F]W<V4N<&AP.C(S.`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG(&$@;F5W(&QI<W0N
M(@IM<V=S='(@(LW5X2#.V,,@SN''X2#%Y-3'P2#>Q\;CR2#,S^W/R2XB"@HC
M.B!A9&1R97-S8F]O:W,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A9&1R97-S
M(&)O;VLZ("5S(@IM<V=S='(@(LW5X2#.V,,@SN''X2#%Y-3'P2#>Q\;CR2#,
MS^W/R2XB"@HC.B!B<F]W<V4N<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(%PB)7-<(B!F
M<F]M('1H92!S;W5R8V4@861D<F5S<R!B;V]K+B(*;7-G<W1R("+-U>$@SMC#
M(,[AQ^$@Q^'-T-TN(@H*(SH@9&5L971E+G!H<#HS-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H
M:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?AS=#=+B(*
M"B,Z(&)R;W=S92YP:'`Z-S(*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?A
MS=#=+B(*"B,Z(&)R;W=S92YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R("+-
MU>$@SMC#(,[AQ^$@Q=GEQ]$@Q^'>Q\;CR2#'X>/.RL?1R2XB"@HC.B!D871A
M+G!H<#HS,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(LW5
MX2#.V,,@SN''X2#'T\KMT<?/(,?AR.W'Y,?*+B(*"B,Z(&QI8B]A<&DN<&AP
M.C4P-R!L:6(O87!I+G!H<#HW-C$*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G
M<W1R("+-U>$@SMC#(,[AQ^$@Q]/*[=''SR#([<?DQ\H@X^0@=D-A<F0B"@HC
M.B!B<F]W<V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@<F5M;W9I;F<@82!C;VYT86-T(&9R;VT@=&AE(&QI<W0N(@IM<V=S
M='(@(LW5X2#.V,,@SN''X2#%Y-3'P2#>Q\;CR2#,S^W/R2XB"@HC.B!A9&1R
M97-S8F]O:W,N<&AP.C4U(&%D9')E<W-B;V]K<RYP:'`Z-C`@861D<F5S<V)O
M;VMS+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*
M;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q^'-T-TN(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HX,2!A9&1R97-S8F]O:W,N<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A
M9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'X<W0W2XB
M"@HC.B!E9&ET+G!H<#HQ-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y.B`E<R(*
M;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q^'-T-TN(@H*(SH@9&%T82YP:'`Z,3<Y
M"B,L(&9U>GIY"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E<W-E<R!T;R!E
M>'!O<G0N(@IM<V=S='(@(N''[>;,SR#/W<K1(-KDQ^;MY"#>Q\CA(.'AW\K'
MR,DN(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN
M8SHQ.#`*;7-G:60@(E1H97-E(&%D9')E<W,@8F]O:W,@=VEL;"!D:7-P;&%Y
M(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(T,PIM<V=I9"`B5&AE<V4@8V]L=6UN<R!W
M:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z,C8Y"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,C(@;&EB+V%P
M:2YP:'`Z,3$S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P
M97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B
M;V]K(@IM<V=S='(@(NW-RN;M(,_=RM$@Q^':Y,?F[>0@Q<_.Q^''RB#:S\\@
M)7,@X>70QR#'X=3.U2`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M-PIM<V=I9"`B(@HB5&AI<R!W:6QL(&)E('1H92!D969A=6QT(&%D9')E<W,@
M8F]O:R!W:&5N(&%D9&EN9R!O<B!I;7!O<G1I;F<@8V]N=&%C=',N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<P"FUS9VED
M(")4:71L92(*;7-G<W1R("+'X>'>R"(*"B,Z(&QI8B]4=7)B82YP:'`Z-#,U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@;F5W('-H
M87)E+B`@36ES<VEN9R!S;W5R8V4@='EP92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T1R:79E<BYP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+*VM#1(,K-
MX^WA(,K:T>W=.B`E<RXB"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY,2!E
M9&ET+G!H<#HY-"!E9&ET+G!H<#HY.2!E9&ET+G!H<#HQ.38*(RP@9G5Z>GD*
M;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+-W=D@Q^'*V^WMT<?*(@H*
M(SH@;&EB+V%P:2YP:'`Z-30P(&QI8B]A<&DN<&AP.C8T,R!L:6(O87!I+G!H
M<#HW-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N
M="U4>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N
M9&ES=#HS-S8*(RP@9G5Z>GD*;7-G:60@(E9E<FES:6=N($1I<F5C=&]R>2(*
M;7-G<W1R("+CS.'/(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$Y
M('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@;6EN:7-E
M87)C:"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(E9I97<@0V]N=&%C="(*;7-G
M<W1R("+%V>7'T2#'X<?*U<?AQ\HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(T"FUS9VED(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS
M9W-T<B`BU-_A(,?AQ=GEQ]$@Q^''W<K1Q];M.B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$S"FUS9VED
M(")7;W)K($%D9')E<W,B"FUS9W-T<B`BY<?*W2#'X=KCX2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5V]R:R!#:71Y(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S.0HC
M+"!F=7IZ>0IM<V=I9"`B5V]R:R!#;W5N=')Y(@IM<V=S='(@(N7'RMT@Q^':
MX^$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@
M(E=O<FL@4&AO;F4B"FUS9W-T<B`BY<?*W2#'X=KCX2(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!0
M;W-T86P@0V]D92(*;7-G<W1R("+EQ\K=(,?AVN/A(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3(Y"B,L(&9U>GIY"FUS9VED(")7;W)K(%-T
M871E+U!R;W9I;F-E(@IM<V=S='(@(N7'RMT@Q^':X^$B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ,3D*(RP@9G5Z>GD*;7-G:60@(E=O<FL@
M4W1R965T($%D9')E<W,B"FUS9W-T<B`BY<?*W2#'X=KCX2(*"B,Z(&1A=&$N
M<&AP.C(S-R!B<F]W<V4N<&AP.CDS(&)R;W=S92YP:'`Z,C`Q(&%D9"YP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T
M;R!C<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S(&EN(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@961I="YP:'`Z-CD@9&ES<&QA>2YP:'`Z-3@@=FEE=RYP
M:'`Z,S8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R("(B"@HC.B!V8V%R9"YP:'`Z-#`*
M;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI
M<R!O8FIE8W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V
M87-C<FEP="YI;F,Z-34*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A('1A<F=E="!A9&1R97-S(&)O;VLN(@IM<V=S='(@(NW,R"#*S<_MSR#'
MRM7'X2#FQ\W/(-KA["#'X</>X2XB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA
M=F%S8W)I<'0N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE
M8W0@82!T87)G970@;&ES="XB"FUS9W-T<B`B[<S((,K-S^W/(,?*U<?A(.;'
MS<\@VN'L(,?AP][A+B(*"B,Z(&5D:70N<&AP.C,R"FUS9VED(")9;W4@;75S
M="!S96QE8W0@870@;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N(@IM<V=S='(@
M(NW,R"#*S<_MSR#'RM7'X2#FQ\W/(-KA["#'X</>X2XB"@HC.B!T96UP;&%T
M97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z-#D*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R
M:7!T+FEN8SHW,@HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T
M(&QE87-T(&]N92!E;G1R>2!F:7)S="XB"FUS9W-T<B`B[<S((,K-S^W/(,?*
MU<?A(.;'S<\@VN'L(,?AP][A+B(*"B,Z(&5D:70N<&AP.C<S"FUS9VED(")9
M;W4@;VYL>2!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N
M(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C@U"FUS9VED(")9;W5R(&1E
M9F%U;'0@861D<F5S<R!B;V]K(&ES(&YO="!B<F]W<V5A8FQE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z-B!T96UP;&%T97,O
M8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS9VED(");;F\@=F%L=65=(@IM
M<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED
M(")?0G)O=W-E(@IM<V=S='(@(LK5W<TB"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C0P"B,L(&9U>GIY"FUS9VED(")?0V]N=&%C=',B"FUS
M9W-T<B`BQ=GEQ]$@Q^''RM7'X<?*(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR"B,L(&9U>GIY"FUS9VED(")?1&5L971E(@IM<V=S='(@
M(LW0W2(*"B,Z(&QI8B]4=7)B82YP:'`Z-#DS"B,L(&9U>GIY"FUS9VED(")?
M26UP;W)T+T5X<&]R="(*;7-G<W1R("+'T\KMT<?/+\K5S^W1(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0HC+"!F=7IZ>0IM<V=I9"`B
M7TQI<W1S(@IM<V=S='(@(L79Y<?1(,?AWN;'QN,B"@HC.B!L:6(O5'5R8F$N
M<&AP.C0X,0HC+"!F=7IZ>0IM<V=I9"`B7TUY($%D9')E<W,@0F]O:W,B"FUS
M9W-T<B`BS]W*T2#:Y,?F[>0@Q^'*YLKM(@H*(SH@;&EB+U1U<F)A+G!H<#HT
M.#<*(RP@9G5Z>GD*;7-G:60@(E].97<@0V]N=&%C="(*;7-G<W1R("+%V>7'
MT2#'X<?*U<?AQ\HB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C(*(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS
M9W-T<B`BQ\W0W2#CY"#'X=['QN/)(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#D*
M(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS9W-T<B`BR,W+(@H*(SH@=F-A
M<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R("(B"@HC.B!D
M871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A
M=&$N<&AP.C(P.0IM<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S0*(RP@9G5Z>GD*
M;7-G:60@(FYO;F4B"FUS9W-T<B`BX<?MYLS/(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHR-`HC+"!F=7IZ>0IM<V=I9"`B=&\@82!#;VYT
M86-T($QI<W0B"FUS9W-T<B`BQ=GEQ]$@Q^''RM7'X<?*(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B=&\@
M82!D:69F97)E;G0@061D<F5S<R!";V]K(@IM<V=S='(@(L?.RM$@S]W*T2#:
MY,?F[>0B"@HC.B!D871A+G!H<#HU,2!T96UP;&%T97,O8G)O=W-E+V-O;'5M
M;E]H96%D97)S+FEN8SHQ,PHC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$U('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(G9#87)D
M(@IM<V=S='(@(G9#87)D(@H`````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T=7)B82]P;R]U:U]502YP;P``````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#<P-C<W`#$P-#$W,S8R-S4V`#`Q-S4T-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````C(%1U<F)A
M(%5K<F%I;FEA;B!+3TDX+54@=')A;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I
M(#(P,#(@06YD<FEY($MO<'ES='EA;G-K>2X*(R!!;F1R:7D@2V]P>7-T>6%N
M<VMY(#QA;G)I0'!O;'EN970N;'9I=BYU83XL(#(P,#(N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A('8Q+C`N,5QN
M(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<
M;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<
M;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#$M,#4@,34Z,S4K,#(P,%QN
M(@HB3&%S="U4<F%N<VQA=&]R.B!!;F1R:7D@2V]P>7-T>6%N<VMY(#QA;G)I
M0'!O;'EN970N;'9I=BYU83Y<;B(*(DQA;F=U86=E+51E86TZ(%5K<F%I;FEA
M;B`\=V5B;6%S=&5R0'!O;'EN970N;'9I=BYU83Y<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M2T])."U57&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHT,@IM<V=I9"`B
M($%D9"!A;B!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C,Q"FUS9VED("(@1&5L971E($E-
M4U`@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,R-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR96%D>2!E>&ES=',@86YD
M('=A<R!N;W0@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z
M,3(V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE
M9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E
M+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@
M;6]V960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@(EPB1FER<W1N86UE($QA
M<W1N86UE7"(@("AI92X@2F]H;B!$;V4I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(EPB3&%S=&YA;64L($9I<G-T
M;F%M95PB("AI92X@1&]E+"!*;VAN*2(*;7-G<W1R("(B"@HC.B!A9&0N<&AP
M.C$P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I
M;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S='(@(B`E<R#&P<K,(-73
MT*;;SL\@ILW0S]+4S]?!SLG*(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT-#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(K;-
MT,_2U"#AQ-+%T\[/IR#+SLG'R2(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H
M+G!H<#HT-0IM<V=I9"`B02!B<F]W<V5R('1H870@<W5P<&]R=',@:49R86UE
M<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,34Y"FUS9VED(")!8F]V92!S96%R8V@@9F]R;2(*;7-G<W1R("(B
M"@HC.B!V:65W+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@
M9&5N:65D('1O("5S(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z-38@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR,@IM<V=I9"`B061D(@IM<V=S='(@
M(N3/Q,'4R2(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C
M="YI;F,Z,3<T"B,L(&9U>GIY"FUS9VED(")!9&0@861D<F5S<R!B;V]K(@IM
M<V=S='(@(N[%R\_2Q<O4SL$@X<32Q=/.P2#+SLG'P2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!A;F0@1&5L
M971E($E-4U`@861D<F5S<R!B;V]K<R(*;7-G<W1R("+NQ<W!(-;/Q,[/IR#!
MQ-+%T\[/IR#+SLG'R2P@Q,_3U-70SL^G(,3,T2#:P=#)T]77P<[.T2XB"@HC
M.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*;7-G:60@
M(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,3(X"B,L(&9U
M>GIY"FUS9VED(")!9&0@9FEL92(*;7-G<W1R("+NQ2#7Q,',S]/1(,3/Q,'4
MR2(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C(*(RP@9G5Z
M>GD*;7-G:60@(D%D9"!T;R(*;7-G<W1R("+DS\3!U,DB"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S
M<R!";V]K(@IM<V=S='(@(K;-T,_2U"#AQ-+%T\[/IR#+SLG'R2(*"B,Z(&)R
M;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC+"!F=7IZ
M>0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`BX<32Q=/.
MP2#+SLG'P2#$S]/4U=#.P2#4ILS8R\D@Q,S1(-[)U,'.SM$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`BMLW0S]+4(.'$TL73SL^G(,O.R<?)(@H*(SH@861D
M+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R>2(*
M;7-G<W1R("+AQ-+%T\[!(,O.R<?!(,3/T]35T,[!(-2FS-C+R2#$S-$@WLG4
MP<[.T2(*"B,Z(&1A=&$N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S
M<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(B`E<R#&P<K,
M(-73T*;;SL\@ILW0S]+4S]?!SLG*(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@8F]O:R!T;R!D
M96QE=&4@(@IM<V=S='(@(N'$TL73SL$@R\[)Q\$@Q,_3U-70SL$@U*;,V,O)
M(,3,T2#>R=3!SL[1(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K
M<V5L96-T+FEN8SHQ-S`*;7-G:60@(D%D9')E<W,@8F]O:W,@=&AA="!W:6QL
M(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z
M.#@@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,W"FUS9VED(")!9'9A
M;F-E9"!396%R8V@B"FUS9W-T<B`B\L_:V\G2Q<[)RB#PS]O5RR(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C8T"FUS9VED(")!;&EA<R(*;7-G
M<W1R("+PT\77Q,_.ILTB"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L
M<&AA+FEN8SHW('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C$P
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(D%L
M;"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HU-3(*;7-G:60@(D%L<F5A
M9'D@17AI<W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V
M87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S
M=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8W"FUS9VED(")!
M<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C
M=&5D(&5N=')I97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-@IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(B(*"B,Z('-E87)C
M:"YP:'`Z.#4@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,V"B,L(&9U
M>GIY"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B\,_;U<LB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")"96QO=R!S96%R8V@@
M9F]R;2(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN
M9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B0G)O=W-E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W,PIM<V=I
M9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M-#D*;7-G:60@(D-35B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T+T=R;W5P
M+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHW"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#0*;7-G:60@(D-H;V]S92!A
M(&YA;64B"FUS9W-T<B`B(@H*(SH@861D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I
M9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R("+NQ<O/TL7+U,[!
M(.'$TL73SL$@R\[)Q\$N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E
M;&5C="YI;F,Z,C(Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@861D<F5S
M<R!B;V]K.B(*;7-G<W1R("+NQ<O/TL7+U,[!(.'$TL73SL$@R\[)Q\$N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-C4*
M;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O(&1I<W!L87DL
M(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O
M;VMS('1O('5S92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O
M;'5M;G-E;&5C="YI;F,Z,C(X"FUS9VED(")#:&]O<V4@=VAI8V@@8V]L=6UN
M<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D-O;'5M;B!/<'1I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE
M8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I
M<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")#
M;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V
M86QU97,@*$UI8W)O<V]F="!/=71L;V]K*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R("+OTL?!SJ;:P<.FT2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$T-`HC+"!F=7IZ>0IM<V=I9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S
M='(@(N3/S<';SM$@P<32Q=/!(@H*(SH@;&EB+V%P:2YP:'`Z,S$X(&QI8B]A
M<&DN<&AP.C,V,R!L:6(O87!I+G!H<#HT,#<@;&EB+V%P:2YP:'`Z-#DQ"B,Z
M(&QI8B]A<&DN<&AP.C8P,2!L:6(O87!I+G!H<#HV.#@@;&EB+V%P:2YP:'`Z
M-S0Q(&QI8B]A<&DN<&AP.C@Q.0HC.B!L:6(O87!I+G!H<#HQ,#`V(&QI8B]A
M<&DN<&AP.C$P.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+NQ2#7Q,',S]/1(/?)U,72U,DB
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QU<F4B"FUS9W-T<B`B[L4@U\3!S,_3T2#WR=3%TM3)
M(@H*(SH@8G)O=W-E+G!H<#HQ.3$@8G)O=W-E+G!H<#HR,S(*;7-G:60@(D-O
M;G1A8W0@861D960@=&\@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H
M<#HV,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*
M;7-G<W1R("+OTL?!SJ;:P<.FT2(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C4S"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T
M92!!9&1R97-S($)O;VLB"FUS9W-T<B`BY<O3T,_2U"#AQ-+%T\[/IR#+SLG'
MR2(*"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A=&4@82!N
M97<@0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T
M5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG
M(&1I<F5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-S8@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z
M(&QI8B]/8FIE8W0N<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]2
M96YD97)E<BYP:'`Z-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R("+WR=3%TM3)
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!!9&1R97-S($)O;VLB"FUS9W-T<B`BY<O3T,_2U"#A
MQ-+%T\[/IR#+SLG'R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM
M<V=I9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T;VX@8F5H
M879I;W5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C<P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D.B`H
M)7,I("5S(@IM<V=S='(@(N[%(-?$P<S/T]$@]\G4Q=+4R2(*"B,Z(&1E;&5T
M92YP:'`Z,S@*;7-G:60@(D1E;&5T:6]N(&9A:6QE9"(*;7-G<W1R("+NQ2#7
MQ,',S]/1(/?)U,72U,DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$Q-0IM<V=I9"`B
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.C$Q.`IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(N3)TL7+
MU,_2IM$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*;7-G:60@(D1I
M<W!L87DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3<V"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T:6YG
M(&5N=')I97,_(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W0N<&AP.C(Y-PIM
M<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]R;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z
M,C4*;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C$P,B!T96UP;&%T97,O8G)O=W-E+W)O
M=RYI;F,Z,C4*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI
M;F,Z,3`@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"B,Z('1E;7!L
M871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,@;&EB+U)E;F1E<F5R+G!H
M<#HT,@IM<V=I9"`B161I="(*;7-G<W1R("+RQ<3!Q]77P=3)(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O8V]N
M=&%C=')O=RYI;F,Z,S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D
M:70@7"(E<UPB(@IM<V=S='(@(O+%Q,''U=?!U,DB"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B161I="!!9&1R
M97-S($)O;VMS(@IM<V=S='(@(N7+T]#/TM0@X<32Q=/.SZ<@R\[)Q\DB"@HC
M.B!E9&ET+G!H<#HW."!E9&ET+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!E;G1R>2!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S='(@(N4M
MT,_;U,$B"@HC.B!E9&ET+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M16YT<GD@9F]R("5S('5P9&%T960L(&)U="!S879I;F<@=&AE('5P;&]A9&5D
M(&9I;&4@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HQ-#D@
M961I="YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E
M<R!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C<T"B,L(&9U
M>GIY"FUS9VED(")%;G1R>2!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T
M<B`B("5S(,;!RLP@U=/0IMO.SR"FS=#/TM3/U\'.R<HB"@HC.B!L:6(O87!I
M+G!H<#HT,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E
M87)C:&EN9R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+NQ<W!(-;/
MQ,[/IR#!Q-+%T\[/IR#+SLG'R2P@Q,_3U-70SL^G(,3,T2#:P=#)T]77P<[.
MT2XB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C8@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@
M(N7+T]#/TM0B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*(RP@
M9G5Z>GD*;7-G:60@(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`BY<O3
MT,_2U"#AQ-+%T\[/IR#+SLG'R2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT
M86-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHR-PIM<V=I9"`B17AP;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K
M(&-O;7!L971E;'DN(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A
M+G!H<#HR,C@@9&%T82YP:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H
M<#HY,`HC.B!B<F]W<V4N<&AP.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z
M,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E
M<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B[L77Q,'>P2#0S]O5
MR]4@UR#$R=+%R]3/TJ:G.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,3,Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@861D("5S('1O("5S
M.B`E<R(*;7-G<W1R("+NQ=?$P=[!(-#/V]7+U2#7(,3)TL7+U,_2IJ<Z("5S
M(@H*(SH@8G)O=W-E+G!H<#HR-S(*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@
M;&ES="(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C,Q,`HC+"!F=7IZ>0IM
M<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM<V=S='(@
M(N[%U\3!WL$@T,_;U<O5(-<@Q,G2Q<O4S]*FISH@)7,B"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C,P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S+"!.97<@1$X@
M/2`E<RP@4F]O="`]("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@9FEN9"!O
M8FIE8W0@=&\@8F4@861D960Z("5S(@IM<V=S='(@(N[%U\3!WL$@T,_;U<O5
M(-<@Q,G2Q<O4S]*FISH@)7,B"@HC.B!S96%R8V@N<&AP.C<Y"B,L(&9U>GIY
M"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H92!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B[L77Q,'>P2#0S]O5R]4@UR#$R=+%R]3/TJ:G.B`E<R(*"B,Z(&1A
M=&$N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<V5A
M<F-H('1H92!D:7)E8W1O<GDZ("5S(@IM<V=S='(@(N[%U\3!WL$@T,_;U<O5
M(-<@Q,G2Q<O4S]*FISH@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ-C<*;7-G:60@(D9A>"(*;7-G<W1R("+FP<O3(@H*(SH@961I="YP
M:'`Z,3(T(&1I<W!L87DN<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B1FEL97,B
M"FUS9W-T<B`B],G4U<PB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI
M;F,Z-S`*;7-G:60@(D9I;F0B"FUS9W-T<B`B^L[!RM3)(@H*(SH@961I="YP
M:'`Z.3<@961I="YP:'`Z,3@W"B,L(&9U>GIY"FUS9VED(")&:6YI<V@B"FUS
M9W-T<B`B^L[!RM3)(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M-#@*;7-G:60@(D9I<G-T($YA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@S"FUS
M9VED(")&<F]M(@IM<V=S='(@(M<B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N
M9&ES=#HV,#0*(RP@9G5Z>GD*;7-G:60@(D=L;V)A;"!!9&1R97-S($)O;VLB
M"FUS9W-T<B`BY<O3T,_2U"#AQ-+%T\[/IR#+SLG'R2(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O<F]W+FEN8SHT,R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C0T"FUS9VED(")'<F]U<"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM
M<V=S='(@(N3/S<';SM$@P<32Q=/!(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z.3,*;7-G:60@(DAO;64@0VET>2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#@*(RP@9G5Z>GD*;7-G:60@
M(DAO;64@0V]U;G1R>2(*;7-G<W1R("+DS\W!V\ZFRB#4Q<S%QL_.(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34P"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(N3/S<';SJ;*(-3%S,7&S\XB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DAO;64@4&]S
M=&%L($-O9&4B"FUS9W-T<B`BY,_-P=O.ILH@U,7,Q<;/SB(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED(")(;VUE
M(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(N3/S<';SJ;*(-3%S,7&S\XB"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX.`HC+"!F=7IZ>0IM<V=I
M9"`B2&]M92!3=')E970@061D<F5S<R(*;7-G<W1R("+DS\W!V\[1(,'$TL73
MP2(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C4P-@IM<V=I9"`B24U3
M4"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<*;7-G
M:60@(DE-4U`@061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E
M9"(*;7-G<W1R("*VS=#/TM0@X<32Q=/.SZ<@R\[)Q\DB"@HC.B!D871A+G!H
M<#HS-C$*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="]%>'!O<G0@061D<F5S<R!"
M;V]K<R(*;7-G<W1R("*VS=#/TM0OY<O3T,_2U"#AQ-+%T\[)R"#+SLG'(@H*
M(SH@;&EB+V%P:2YP:'`Z-3DV(&QI8B]A<&DN<&AP.C8X,PHC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!)1"(*;7-G<W1R("+NQ<O/TL7+U,[!(,[!VM?!+B(*
M"B,Z(&QI8B]A<&DN<&AP.C(S,"!L:6(O87!I+G!H<#HT,#(@;&EB+V%P:2YP
M:'`Z-#@V(&QI8B]A<&DN<&AP.C4Y,@HC.B!L:6(O87!I+G!H<#HV-SD@;&EB
M+V%P:2YP:'`Z-S,Q(&QI8B]A<&DN<&AP.C$P-S<*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@861D<F5S<R!B;V]K(@IM<V=S='(@(N[%R\_2Q<O4SL$@X<32
MQ=/.P2#+SLG'P2XB"@HC.B!L:6(O87!I+G!H<#HQ,#@Q(&QI8B]A<&DN<&AP
M.C$Q-30@;&EB+V%P:2YP:'`Z,3(P-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!E;6%I;"(*;7-G<W1R("+NQ<O/TL7+U,[!(,'$TL73P2#%+=#/V]3)+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$P.#D*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M96YT<GDB"FUS9W-T<B`B[L7+S]+%R]3.P2#.P=K7P2XB"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C(V-@IM<V=I9"`B26YV86QI9"!K97D@<W!E8VEF:65D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,#@U"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(&YA;64B"FUS9W-T<B`B[L7+S]+%R]3.P2#.P=K7P2XB
M"@HC.B!L:6(O87!I+G!H<#HW,S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M;V)J96-T260B"FUS9W-T<B`B[L7+S]+%R]3.P2#.P=K7P2XB"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C,P"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@
M<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE
M(&]R(&YO="!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W
M+G!H<#HQ,S@*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-3,*(RP@9G5Z>GD*;7-G:60@
M(DQA<W0@3F%M92(*;7-G<W1R("))S6#1(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<W"FUS9VED(")-
M871C:&EN9R(*;7-G<W1R("+=SR#7IL30S]>FQ,&D(@H*(SH@;&EB+V%P:2YP
M:'`Z,C`U"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!#;VYT86-T<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED(")-
M87AI;75M(&YU;6)E<B!O9B!P86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=')E95]M96YU+G!H<#HS"FUS9VED(")-96YU($QI<W0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,*(RP@9G5Z>GD*;7-G
M:60@(DUI;FD@4V5A<F-H(@IM<V=S='(@(O#/V]7+(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI<W-I;F<@1$X@:6X@3$1!4"!S;W5R
M8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,38R"B,L(&9U>GIY"FUS9VED(")-;V)I;&4@4&AO
M;F4B"FUS9W-T<B`BY,_-P=O.ILH@U,7,Q<;/SB(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,S,R(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S0X"B,L('!H<"UF
M;W)M870*;7-G:60@(DUO9&EF>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y,PIM<V=I9"`B36]R92!T:&%N(#$@96YT
M<GD@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHQ,0IM<V=I9"`B36]V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S+W!R
M969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*;7-G:60@(DUO=F4@;&5F
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T
M+FEN8SHR-#D*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T
M+FEN8SHQ.#8*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z-3(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-@HC+"!F=7IZ
M>0IM<V=I9"`B375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(N7+T]#/
MTM0@X<32Q=/.SZ<@R\[)Q\DB"@HC.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R
M97-S(%LE<UTL(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI
M<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3`W
M(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B
M37D@061D<F5S<R!";V]K(@IM<V=S='(@(K;-T,_2U"#AQ-+%T\[/IR#+SLG'
MR2(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")-
M>2!!9&1R97-S($)O;VMS(@IM<V=S='(@(N7+T]#/TM0@X<32Q=/.SZ<@R\[)
MQ\DB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`B
M2<U@T2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B3F%M
M92!&;W)M870B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I
M<W0Z,S$U"FUS9VED(").971C96YT97(@365M8F5R($1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!A9&0N<&AP.C,V(&%D9"YP:'`Z,3(T(&QI8B]";&]C:R]M
M:6YI<V5A<F-H+G!H<#HR-PHC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR
M-PHC+"!F=7IZ>0IM<V=I9"`B3F5W($-O;G1A8W0B"FUS9W-T<B`BY,_$P=3)
M(,[/U\G*(-K!T,G3(@H*(SH@961I="YP:'`Z.#@@961I="YP:'`Z.34@961I
M="YP:'`Z,C`R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#4*;7-G:60@
M(DYE>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,C$X"B,L(&9U>GIY"FUS9VED(").:6-K;F%M92(*;7-G<W1R("))S6#1
M(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y-2!L:6(O87!I+G!H<#HQ,C0T"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO("5S(&5N=')Y(&9O=6YD(&9O<B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,38S"B,L(&9U>GIY"FUS9VED(").
M;R!A9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R("+AQ-+%T\[!(,O.R<?!
M(,3/T]35T,[!(-2FS-C+R2#$S-$@WLG4P<[.T2(*"B,Z(&UI;FES96%R8V@N
M<&AP.C@S"FUS9VED(").;R!C;VYT86-T<R!F;W5N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HU,3$@;&EB+V%P:2YP:'`Z-S8V"FUS9VED(").;R!V
M0V%R9"!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]F;V]T97(N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS
M9W-T<B`B[L_4P=3+R2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P
M97(@<&%G92(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HV,30@;&EB+V%P
M:2YP:'`Z-S0W"FUS9VED(")/8FIE8W0@;F]T(&9O=6YD(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(R,PIM<V=I9"`B3V9F
M:6-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI
M;F,Z,C,*;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@=&AI<R!O<'1I;VX@<&%G
M92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E
M;&5T960N($EF('1H:7,@:7,@;F]T('=H870@>6]U('=A;G0L('1H96X@>6]U
M(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N("(*(G1O(%PB3F]N95PB+B(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW-S0*;7-G:60@(D]N;'D@;VYE
M('9C87)D('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B
M3W1H97(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C0Y-2!L:6(O87!I+G!H<#HV,#4@;&EB+V%P
M:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.CDS-`HC.B!L:6(O87!I+G!H<#HQ,#DX
M"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HU-#,*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDY"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,R!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")0:6YE
M($%D9')E<W,@0F]O:R(*;7-G<W1R("*VS=#/TM0@X<32Q=/.SZ<@R\[)Q\DB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(X"FUS9VED
M(")0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@;&ES=#HB"FUS9W-T<B`B
M(@H*(SH@961I="YP:'`Z.3$@961I="YP:'`Z.30@961I="YP:'`Z,3DT"FUS
M9VED(")0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP
M:'`N9&ES=#HT,38*(RP@9G5Z>GD*;7-G:60@(E!R:79A=&4@061D<F5S<R!"
M;V]K(@IM<V=S='(@(N7+T]#/TM0@X<32Q=/.SZ<@R\[)Q\DB"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")1=65R
M>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)L
M;V-K+VUI;FES96%R8V@N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")1=6EC:R!3
M96%R8V@B"FUS9W-T<B`B\,_;U<LB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C$Y,2!L:6(O1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD87`N
M<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")296%D(&9A:6QE9#H@*"5S
M*2`E<R(*;7-G<W1R("(B"@HC.B!L:6(O4F5N9&5R97(N<&AP.C0Y"FUS9VED
M(")296%L;'D@9&5L971E('1H:7,@8V]N=&%C=#\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C(*;7-G:60@(E)E8V]R9',@
M9&ES<&QA>65D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O861D
M<F5S<V)O;VMS96QE8W0N:6YC.C$W-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("*VS=#/TM0@X<32Q=/.SZ<@R\[)Q\DB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,SD*;7-G
M:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR
M,0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET
M:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB
M9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B
M;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HT
M,S@*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!A9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN
M8SHQ,3,*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%
M(%!U8FQI8R!#97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A
M:6QE9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY.2!A9&0N
M<&AP.C,W('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B
M4V%V92(*;7-G<W1R("+ZPL72Q<?4R2(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<V5A<F-H+FEN8SHY-B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$R
M"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO
M8VLO=')E95]M96YU+G!H<#HT.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(V"FUS9VED(")396%R8V@B"FUS9W-T<B`B\,_;U<LB"@HC.B!M:6YI<V5A
M<F-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(%)E<W5L=',Z(@IM
M<V=S='(@(O+%VM7,V-3!U,D@\,_;U<O5(@H*(SH@;&EB+V%P:2YP:'`Z,3`Q
M,0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R("+PS]O5
MRR(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#,@;&EB+V%P:2YP:'`Z,3$P.2!L:6(O
M87!I+G!H<#HQ,3$X(&QI8B]A<&DN<&AP.C$Q,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(R"B,L(&9U>GIY"FUS9VED(")3
M96%R8VAI;F<N+BXB"FUS9W-T<B`B\,_;U<LB"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHV-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%D
M9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B]\O!UJ;4V"#!Q,73SM4@
MR\[)Q]4@Q,S1(,3/Q,'7P<[.T2#:P=#)T]4N(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A
M9&1R97-S(&)O;VL@=&\@961I="(*;7-G<W1R("+WR\'6IM38(,'$Q=/.U2#+
MSLG'U2#$S-$@Q,_$P=?!SL[1(-K!T,G3U2XB"@HC.B!T96UP;&%T97,O9&%T
M82]E>'!O<G0N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&%D
M9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T<B`B]\G"Q=*FU-@@
MQ-;%TL7,SRP@VM>FQ,O)(,7+T]#/TM35U\'4R3HB"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE
M(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(O?+P=:FU-@@
MT-+)VL[!WL7.SM$@ILW0S]+4U3HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C,U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&-H87)S970@
M;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("+WR<+%TJ;4V"#$UL72Q<S/
M+"#:UZ;$R\D@Q<O3T,_2U-77P=3).B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T
M(&9O<FUA=#HB"FUS9W-T<B`B]\G"Q=*FU-@@Q-;%TL7,SRP@VM>FQ,O)(,7+
MT]#/TM35U\'4R3HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0S
M"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R("+W
MR<+%TJ;4V"#&P<K,(,3,T2"FS=#/TM35.B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9F]R
M;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B]\O!UJ;4V"#&S]+-
MP=0@Q,S1(,7+T]#/TM35.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S4*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@
M9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`B]\O!UJ;4V"#&S]+-P=0@Q,S1(*;-
MT,_2U-4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U"FUS9VED(")3
M96QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L('-O<G0@;W!T:6]N
M<RP@86YD('!A9VEN9R!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-E;&5C="!W:&EC:"!F:65L9',@
M=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@;F%M97,N(@IM<V=S='(@
M(O?+P=:FU-@@QL_2S<'4(,3,T2"FS=#/TM35.B(*"B,Z(&%D9"YP:'`Z-30*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-E;&5C=&5D(&%D9')E<W,@
M8F]O:R!<(B5S7"(N(@IM<V=S='(@(N[%R\_2Q<O4SL$@X<32Q=/.P2#+SLG'
MP2XB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ-S,*(RP@9G5Z>GD*
M;7-G:60@(E-H87)E9"!$:7)E8W1O<GDB"FUS9W-T<B`BY,G2Q<O4S]*FT2(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4VAO=R`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C0Q"FUS9VED(")3:&]W($%L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"FUS9VED
M(")3:&]W($-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,SD*;7-G:60@(E-H;W<@3&ES=',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,C$*
M(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,S0*(RP@
M9G5Z>GD*;7-G:60@(E-O<G0@1&ER96-T:6]N(@IM<V=S='(@(N3)TL7+U,_2
MIM$B"@HC.B!L:6(O87!I+G!H<#HQ.3@*(RP@9G5Z>GD*;7-G:60@(E-O=7)C
M97,B"FUS9W-T<B`B]=/0IMO.SR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3<*;7-G:60@(E-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V86YC960@
M<V5A<F-H(')E<W5L=',@=&\@87!P96%R+B(*;7-G<W1R("(B"@HC.B!B<F]W
M<V4N<&AP.C$T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M861D960@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-R96%T960@=&AE
M(&-O;G1A8W0@;&ES="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C4P"FUS9VED(")44U8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$T"FUS
M9VED(")486(@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC.B!V:65W
M+G!H<#HQ-0IM<V=I9"`B5&AE(%9&4R!B86-K96YD(&YE961S('1O(&)E(&-O
M;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`U-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B(@H*(SH@861D<F5S<V)O;VMS+G!H<#HT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@8W)E871E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<
M(B5S7"(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC
M.B!A9&1R97-S8F]O:W,N<&AP.C@Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!A9&1R97-S(&)O;VL@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@=7!D871E
M9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-#<@=F-A<F0N<&AP.C(R(&1I
M<W!L87DN<&AP.C(S('9I97<N<&AP.C(V"FUS9VED(")4:&4@8V]N=&%C="!Y
M;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!E
M9&ET+G!H<#HQ,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F
M:6QE(%PB)7-<(B!H87,@<W5C8V5S<V9U;&QY(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B("5S(,;!RLP@U=/0IMO.SR"FS=#/TM3/U\'.R<HB"@HC.B!D871A
M+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@8V%N(&)E(&9I;FES:&5D(&1E
M<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP
M.C,Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@8G)O=W-E86)L92!A
M9&1R97-S(&)O;VMS+B(*;7-G<W1R("+NQ<W!(-;/Q,[/IR#!Q-+%T\[/IR#+
MSLG'R2P@Q,_3U-70SL^G(,3,T2#:P=#)T]77P<[.T2XB"@HC.B!A9&0N<&AP
M.C(Y"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!A<F4@;F\@=W)I=&5A8FQE
M(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S
M(&)O;VMS("(*(F%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@
M;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R`B"B)I
M<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@HB]L_$SL$@VB#$S]/4U=#.R<@@P<32Q=/.
MR<@@R\[)QR#.Q2#3R\_.QJ;'U=+/U\'.P2#$S-$@Q,_$P=?!SL[1(/?!S<D@
MSL_7R<@@(@HBVL'0R=.FUR#$SR#.R<@N(/'+W<\@]\D@U]?!UL&DU,4L(-W/
M(,/%(-#/S<G,R\$L(-K7Q=+.IM38T]$@Q,\@]\';S\?/("(*(M/)T]3%S<[/
MQ\\@P<3-ILZFT]32P=3/TL$N(@H*(SH@861D+G!H<#HQ,C$*(RP@9G5Z>GD*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE=R!C
M;VYT86-T+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@(@HB
M9F]R(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB]-+!T,G,P=/1(-#/S<G,
MR\$@T-+)(,3/Q,'7P<[.IB#.S]?/Q\\@VL'0R=/5+B#ZU\72SJ;4V-/1(,3/
M(-/)T]3%S<[/Q\\@(@HBP<3-ILZFT]32P=3/TL$N(@H*(SH@8G)O=W-E+G!H
M<#HQ.#D@8G)O=W-E+G!H<#HR,S`*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!A9&1I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(O32P=#)
MS,'3T2#0S\W)S,O!(-#2R2"FS=#/TM35U\'.SJ8@Q,'.R<@N(@H*(SH@8G)O
M=W-E+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R("+TTL'0R<S!T]$@T,_-
MR<S+P2#0TLD@ILW0S]+4U=?!SLZF(,3!SLG(+B(*"B,Z(&%D9')E<W-B;V]K
M<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS
M9W-T<B`B]-+!T,G,P=/1(-#/S<G,R\$@ILW0S]+4U2#:P=?!SM3!UL7.S\?/
M(,;!RLS5(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<(B5S7"(@
M9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B]-+!T,G,
MP=/1(-#/S<G,R\$@ILW0S]+4U2#:P=?!SM3!UL7.S\?/(,;!RLS5(@H*(SH@
M9&5L971E+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B"FUS
M9W-T<B`B]-+!T,G,P=/1(-#/S<G,R\$@T-+)(*;-T,_2U-77P<[.IB#$P<[)
MR"XB"@HC.B!B<F]W<V4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(O32
MP=#)S,'3T2#0S\W)S,O!(-#2R2"FS=#/TM35U\'.SJ8@Q,'.R<@N(@H*(SH@
M8G)O=W-E+G!H<#HR-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H92!L:7-T(@IM<V=S='(@(O32P=#)S,'3T2#0
MS\W)S,O!(-#2R2"FS=#/TM35U\'.SJ8@Q,'.R<@N(@H*(SH@9&%T82YP:'`Z
M,S,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R("+TTL'0R<S!
MT]$@T,_-R<S+P2#0TLD@ILW0S]+4U=?!SLZF(,3!SLG(+B(*"B,Z(&QI8B]A
M<&DN<&AP.C4P-R!L:6(O87!I+G!H<#HW-C$*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R("+TTL'0R<S!T]$@T,_-R<S+P2#0TLD@ILW0S]+4U=?!SLZF
M(,3!SLG(+B(*"B,Z(&)R;W=S92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!A(&-O;G1A8W0@9G)O;2!T:&4@
M;&ES="XB"FUS9W-T<B`B]-+!T,G,P=/1(-#/S<G,R\$@T-+)(*;-T,_2U-77
MP<[.IB#$P<[)R"XB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C4U(&%D9')E<W-B
M;V]K<RYP:'`Z-C`@861D<F5S<V)O;VMS+G!H<#HV.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H
M:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+TTL'0R<S!T]$@T,_-R<S+
MP2"FS=#/TM35(-K!U\'.U,'6Q<[/Q\\@QL'*S-4B"@HC.B!A9&1R97-S8F]O
M:W,N<&AP.C@Q(&%D9')E<W-B;V]K<RYP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES
M(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B]-+!T,G,P=/1(-#/S<G,R\$@
MILW0S]+4U2#:P=?!SM3!UL7.S\?/(,;!RLS5(@H*(SH@961I="YP:'`Z,34X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,B"FUS9W-T<B`B]-+!T,G,P=/1
M(-#/S<G,R\$@T-+)(*;-T,_2U-77P<[.IB#$P<[)R"XB"@HC.B!D871A+G!H
M<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=E<F4@;F\@861D<F5S<V5S
M('1O(&5X<&]R="XB"FUS9W-T<B`B[L7-P2#6S\3.SZ<@P<32Q=/.SZ<@R\[)
MQ\DL(,3/T]35T,[/IR#$S-$@VL'0R=/5U\'.SM$N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#`*;7-G:60@(E1H97-E
M(&%D9')E<W,@8F]O:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(T,PIM<V=I9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI
M<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED(")4
M:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$Q,C(@;&EB+V%P:2YP:'`Z,3$S-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@
M82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(N/1(,_3
MS\+!(-?6Q2#:P<[%T\7.P2#$SR#WP=O/IR#AQ-+%T\[/IR#+SLG'R2XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30W"FUS9VED("(B"B)4:&ES('=I
M;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R
M(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z-S`*;7-G:60@(E1I=&QE(@IM<V=S='(@(O3)
MU-7,(@H*(SH@;&EB+U1U<F)A+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N("!-:7-S:6YG('-O=7)C
M92!T>7!E+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HY-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(N[%S<_6S,G7SR#:P=?!SM3!ULG4R2#7R=K.
MP=[%SL[1(,3,T2`E<RXB"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY,2!E
M9&ET+G!H<#HY-"!E9&ET+G!H<#HY.2!E9&ET+G!H<#HQ.38*(RP@9G5Z>GD*
M;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+ZPL72Q<?4R2#:S:;.R2(*
M"B,Z(&QI8B]A<&DN<&AP.C4T,"!L:6(O87!I+G!H<#HV-#,@;&EB+V%P:2YP
M:'`Z-S<Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E
M;G0M5'EP93H@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP
M+F1I<W0Z,S<V"B,L(&9U>GIY"FUS9VED(")697)I<VEG;B!$:7)E8W1O<GDB
M"FUS9W-T<B`BY,G2Q<O4S]*FT2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W
M+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(W"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M(&UI;FES96%R8V@N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")6:65W($-O;G1A
M8W0B"FUS9W-T<B`BY,_$P=3)(,[/U\G*(-K!T,G3(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE=R!T;R!D:7-P;&%Y(&)Y(&1E
M9F%U;'0Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$S"FUS9VED(")7;W)K($%D9')E
M<W,B"FUS9W-T<B`B\L_"S][!(,'$TL73P2(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5V]R:R!#:71Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S.0HC+"!F=7IZ>0IM
M<V=I9"`B5V]R:R!#;W5N=')Y(@IM<V=S='(@(O+/PL_>R<H@U,7,Q<;/SB(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U-@IM<V=I9"`B5V]R
M:R!0:&]N92(*;7-G<W1R("+RS\+/WLG*(-3%S,7&S\XB"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E=O<FL@
M4&]S=&%L($-O9&4B"FUS9W-T<B`B\L_"S][)RB#4Q<S%QL_.(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(Y"B,L(&9U>GIY"FUS9VED(")7
M;W)K(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(O+/PL_>R<H@U,7,Q<;/SB(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q.0HC+"!F=7IZ>0IM
M<V=I9"`B5V]R:R!3=')E970@061D<F5S<R(*;7-G<W1R("+RS\+/WL$@P<32
MQ=/!(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP:'`Z.3,@8G)O=W-E+G!H
M<#HR,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8V]N=&%C=',@
M:6X@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HV.2!D:7-P;&%Y
M+G!H<#HU."!V:65W+G!H<#HS-@IM<V=I9"`B66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(B(*"B,Z
M('9C87)D+G!H<#HT,`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I
M;VX@=&\@=FEE=R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHU-0IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHR,PIM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&5D
M:70N<&AP.C,R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE
M(&-O;G1A8W0@9FER<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R
M:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y
M(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HW,PIM<V=I9"`B66]U
M(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*
M;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(X-0IM<V=I9"`B66]U<B!D969A
M=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E86)L92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C8@=&5M<&QA=&5S+V)R
M;W=S92]C;VYT86-T<F]W+FEN8SHQ,@IM<V=I9"`B6VYO('9A;'5E72(*;7-G
M<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0X-`IM<V=I9"`B7T)R;W=S92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P
M"FUS9VED(")?0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHR"B,L(&9U>GIY"FUS9VED(")?1&5L971E(@IM
M<V=S='(@(O?)U,72U,DB"@HC.B!L:6(O5'5R8F$N<&AP.C0Y,PHC+"!F=7IZ
M>0IM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`BMLW0S]+4+^7+T]#/
MTM0B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"FUS9VED
M(")?3&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#$*(RP@
M9G5Z>GD*;7-G:60@(E]->2!!9&1R97-S($)O;VMS(@IM<V=S='(@(K;-T,_2
MU"#AQ-+%T\[/IR#+SLG'R2(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@W"B,L(&9U
M>GIY"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T<B`BY,_$P=3)(,[/U\G*
M(-K!T,G3(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS
M9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]4=7)B82YP:'`Z-#@Y"B,L(&9U>GIY"FUS9VED(")?4V5A<F-H(@IM<V=S
M='(@(O#/V]7+(@H*(SH@=F-A<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C
M9B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V
M(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B8V]N=&%C=',N
M='-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(Q.0IM<V=I9"`B8V]N=&%C
M=',N=F-F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P
M="YI;F,Z,S0*;7-G:60@(FYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHR-`IM<V=I9"`B=&\@82!#;VYT86-T($QI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B=&\@82!D:69F97)E;G0@061D<F5S<R!"
M;V]K(@IM<V=S='(@(N7+T]#/TM0@X<32Q=/.SZ<@R\[)Q\DB"@HC.B!D871A
M+G!H<#HU,2!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ
M,PHC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,34*;7-G:60@(G9#87)D(@IM<V=S='(@(B(*````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U
M<F)A+W!O+VET7TE4+G!O````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-S8S-C4`,3`T,3<S-C(W-38`,#$W-34P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@5'5R8F$@,"XP
M+C,@271A;&EA;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@
M4&%O;&$@0V%R<&5N=&5R+@HC(%!A;VQA($-A<G!E;G1E<B`\<&-A<G!E;G1E
M<D!I;F9V:6,N:70^.R!':6]V86YN:2!-96YE9VAE='1I(#QG;65N96=H971T
M:4!I;F9V:6,N:70^+"`R,#`Q+@HC($-O<'ER:6=H="`H8RD@,C`P,R!397)G
M:6\@1RX@0V%R961D82X*(R!397)G:6\@1RX@0V%R961D82`\<V-A<F5D9&%`
M=&ES8V%L:2YI=#XL(#(P,#,N"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C
M="U)9"U697)S:6]N.B!4=7)B82`P+C`N,UQN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#4M,#(M,C,@,3<Z-#`K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!-87)C;R!0:7)O=F%N;R`\;6%R8V\N<&ER;W9A;F]`=6YI8F]C8V]N:2YI
M=#Y<;B(*(DQA;F=U86=E+51E86TZ($ET86QI86X@/&1E=D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I;7-P7V]P="YI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(B!!9&0@86X@24U3
M4"!!9&1R97-S($)O;VLB"FUS9W-T<B`B4G5B<FEC82!0:6YE(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B
M($1E;&5T92!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R(")A;&QA(%)U8G)I
M8V$@4V5L97II;VYA=&$B"@HC.B!D871A+G!H<#HS,C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&%L<F5A9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C;W!I960@8F5C875S92!I
M="!I<R!A(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO=F5D(&)E8V%U
M<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,W"FUS9VED(")<(D9I<G-T;F%M92!,87-T;F%M95PB("`H
M:64N($IO:&X@1&]E*2(*;7-G<W1R(")<(DYO;64@0V]G;F]M95PB("AE<RX@
M36%R:6\@4F]S<VDI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM
M<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$;V4L($IO:&XI
M(@IM<V=S='(@(EPB0V]G;F]M92P@3F]M95PB("AE<RX@4F]S<VDL($UA<FEO
M*2(*"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%D
M9&5D+B(*;7-G<W1R("(E<R!A9V=I=6YT;RXB"@HC.B!D871A+G!H<#HS-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP
M;W)T960B"FUS9W-T<B`B1FEL92`E<R!I;7!O<G1A=&\@8V]N('-U8V-E<W-O
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@82`E<R!D
M:2`E<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-#0V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")2=6)R:6-A
M(%!I;F4B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#4*;7-G:60@
M(D$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B
M"FUS9W-T<B`B12<@;F5C97-S87)I;R!U;B!B<F]W<V5R(&-H92!S=7!P;W)T
M:2!I1G)A;65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.0IM<V=I
M9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z
M-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@
M=&\@)7,B"FUS9W-T<B`B06=G:75N=&\@8V]N('-U8V-E<W-O("5S(&$@)7,B
M"@HC.B!A9&0N<&AP.C4V('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,C(*(RP@9G5Z>GD*;7-G:60@(D%D9"(*;7-G<W1R(")?06=G:75N9VDB"@HC
M.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-`HC
M+"!F=7IZ>0IM<V=I9"`B061D(&%D9')E<W,@8F]O:R(*;7-G<W1R(")2=6)R
M:6-A(&YO;B!V86QI9&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X
M"B,L(&9U>GIY"FUS9VED(")!9&0@86YD($1E;&5T92!)35-0(&%D9')E<W,@
M8F]O:W,B"FUS9W-T<B`B4V5L97II;VYA(')U8G)I8V$@)R5S)RXB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*;7-G:60@(D%D
M9"!C;VQU;6XB"FUS9W-T<B`B06=G:75N9VD@8V]L;VYN82(*"B,Z(&5D:70N
M<&AP.C$R.`IM<V=I9"`B061D(&9I;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR,@IM<V=I9"`B061D('1O(@IM<V=S
M='(@(D%G9VEU;F=I(&$B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHX-@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(E)U
M8G)I8V$@4&EN92(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T
M<B`B3&ES=&$@4G5B<FEC82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B17-C
M:2!D86QL82!2=6)R:6-A(@H*(SH@861D+G!H<#HQ,#@*;7-G:60@(D%D9')E
M<W,@8F]O:R!E;G1R>2(*;7-G<W1R("));G-E<FEM96YT;R!S8VAE9&$@;F5L
M;&$@<G5B<FEC82(*"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B061D<F5S<R!B
M;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(E)U8G)I8V$@<W9U
M;W1A=&$@8V]N('-U8V-E<W-O+B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C8R"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(&)O;VL@=&\@9&5L
M971E("(*;7-G<W1R("));G-E<FEM96YT;R!S8VAE9&$@;F5L;&$@<G5B<FEC
M82(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z
M,3<P"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(&)O;VMS('1H870@=VEL;"!N
M;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R(").;VX@97)A('!O<W-I8FEL92!S
M;W-T:71U:7)E(&QA(&9I<FUA+B(*"B,Z('-E87)C:"YP:'`Z.#@@=&5M<&QA
M=&5S+V)R;W=S92]S96%R8V@N:6YC.C,W"FUS9VED(")!9'9A;F-E9"!396%R
M8V@B"FUS9W-T<B`B4FEC97)C82!!=F%N>F%T82(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C8T"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA
M<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M
M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(E1U
M='1I(@H*(SH@;&EB+V%P:2YP:'`Z-34R"FUS9VED(")!;')E861Y($5X:7-T
M<R(*;7-G<W1R(")':6$G(&5S:7-T96YT92(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R
M(")396D@<VEC=7)O(&1I('9O;&5R(&-A;F-E;&QA<F4@)7,_(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHV-PIM<V=I9"`B07)E('EO
M=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E
M;G1R:65S/R(*;7-G<W1R(")396D@<VEC=7)O(&1I('9O;&5R(&5L:6UI;F%R
M92!Q=65S=&\@87)T:6-O;&\_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDV"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B07-C96YD96YT92(*"B,Z
M('-E87)C:"YP:'`Z.#4@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,V
M"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B4FEC97)C82!396UP;&EC
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(D)E;&]W
M('-E87)C:"!F;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z-S<@;&EB+T1R:79E<B]L9&%P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("),:6YK(&9A;&QI
M=&\N("@E<RD@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M-S@*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M96YU+FEN8SHW"B,L(&9U>GIY"FUS9VED(")"<F]W<V4B"FUS9W-T<B`B7U-F
M;V=L:6$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*;7-G
M:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(D-A=&5G;W)I82!!9F9A
M<FDB"@HC.B!D871A+G!H<#HT.0IM<V=I9"`B0U-6(@IM<V=S='(@(E-#5B(*
M"B,Z(&QI8B]/8FIE8W0O1W)O=7`N<&AP.C4W"FUS9VED(")#86XG="!A9&0@
M82!G<F]U<"!T;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C<*;7-G:60@(D-H96-K(%]!;&PO
M3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G<W1R(")3
M8V5G;&D@=6YA(')U8G)I8V$B"@HC.B!A9&0N<&AP.C0X"FUS9VED(")#:&]O
M<V4@86X@861D<F5S<R!B;V]K(@IM<V=S='(@(E-C96=L:2!U;F$@<G5B<FEC
M82(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R,0HC
M+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:SHB"FUS9W-T
M<B`B4V-E9VQI('5N82!R=6)R:6-A(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D
M9')E<W-B;V]K<V5L96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S92!W:&EC:"!A
M9&1R97-S(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*(RP@9G5Z
M>GD*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O('5S92XB
M"FUS9W-T<B`B4V-E9VQI('5N82!R=6)R:6-A(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-O;'5M;G-E;&5C="YI;F,Z,C(X"B,L(&9U>GIY"FUS9VED(")#:&]O
M<V4@=VAI8V@@8V]L=6UN<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R
M.B(*;7-G<W1R(")38V5G;&D@;"=O<F1I;F4@9&5L;&4@8V]L;VYN92!D82!M
M;W-T<F%R92!N96QL82!L:7-T82!I;F1I<FEZ>FDN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$W"FUS9VED(")#;VQU;6X@3W!T:6]N<R(*;7-G<W1R
M(")/<'II;VYI($-O;&]N;F4B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B
M92!D:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I
M9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")686QO<FD@<V5P
M87)A=&D@9&$@=FER9V]L92(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,@*$UI8W)O<V]F
M="!/=71L;V]K*2(*;7-G<W1R(")686QO<FD@<V5P87)A=&D@9&$@=FER9V]L
M92`H36EC<F]S;V9T($]U=&QO;VLI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B07II96YD82(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`IM<V=I9"`B0V]M
M<&%N>2!!9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R!,879O<F\B"@HC.B!L
M:6(O87!I+G!H<#HS,3@@;&EB+V%P:2YP:'`Z,S8S(&QI8B]A<&DN<&AP.C0P
M-R!L:6(O87!I+G!H<#HT.3$*(SH@;&EB+V%P:2YP:'`Z-C`Q(&QI8B]A<&DN
M<&AP.C8X."!L:6(O87!I+G!H<#HW-#$@;&EB+V%P:2YP:'`Z.#$Y"B,Z(&QI
M8B]A<&DN<&AP.C$P,#8@;&EB+V%P:2YP:'`Z,3`Y-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B0V]N;F5S
M<VEO;F4@9F%L;&ET83H@)7,B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C4X
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QU<F4B"FUS9W-T<B`B0V]N;F5S<VEO
M;F4@9F%L;&ET82(*"B,Z(&)R;W=S92YP:'`Z,3DQ(&)R;W=S92YP:'`Z,C,R
M"B,L(&9U>GIY"FUS9VED(")#;VYT86-T(&%D9&5D('1O(&QI<W0N(@IM<V=S
M='(@(D-O;G1A='1I(')I;6]S<VD@9&%L;&$@;&ES=&$N(@H*(SH@8G)O=W-E
M+G!H<#HV,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES="XB"FUS
M9W-T<B`B0V]N=&%T=&D@<FEM;W-S:2!D86QL82!L:7-T82XB"@HC.B!B<F]W
M<V4N<&AP.C(V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT86-T<R!I;B!L
M:7-T.B`E<R(*;7-G<W1R(")#;VYT871T:2!N96QL82!L:7-T83H@)7,B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$R"FUS9VED(")#;W!Y
M(@IM<V=S='(@(D-O<&EA(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z-3,*(RP@9G5Z>GD*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<F5A=&\B
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHT,`HC+"!F=7IZ>0IM
M<V=I9"`B0W)E871E($%D9')E<W,@0F]O:R(*;7-G<W1R(")2=6)R:6-A(%!E
M<G-O;F%L92(*"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A
M=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O
M3V)J96-T5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(D-R
M96%T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F
M875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B3W)D:6YE(&1I(&1E
M9F%U;'0Z(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z(&QI8B]/8FIE8W0N<&AP
M.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z-3`*
M;7-G:60@(D1E;&5T92(*;7-G<W1R(")#86YC96QL82(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C4X"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M061D<F5S<R!";V]K(@IM<V=S='(@(E-E;&5Z:6]N82!2=6)R:6-A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")$96QE=&4@0V]N9FER
M;6%T:6]N(@IM<V=S='(@(D-O;F9E<FUA(&1I(&-A;F-E;&QA>FEO;F4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T
M;VX@8F5H879I;W5R(@IM<V=S='(@(D5L:6UI;F$@5F%L;W)E($]P>FEO;F4B
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&4@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D5L:6UI;F%Z
M:6]N92!F86QL:71A.B`H)7,I("5S(@H*(SH@9&5L971E+G!H<#HS.`IM<V=I
M9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S='(@(D5L:6UI;F%Z:6]N92!&86QL
M:71A(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$S"FUS9VED
M(")$97!A<G1M96YT(@IM<V=S='(@(D1I<&%R=&EM96YT;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R
M(")$:7-C96YD96YT92(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C$Q-0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q.`IM<V=I9"`B1&ER96-T;W)Y(@IM
M<V=S='(@(D-A<G1E;&QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T
M"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(D]P>FEO;FD@9&D@
M5FES=6%L:7IZ87II;VYE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI(&1I(%9I<W5A;&EZ>F%Z:6]N
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D1O('EO
M=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T<B`B
M4VEC=7)O(&1I('9O;&5R(&-A;F-E;&QA<F4@4$5234%.14Y414U%3E1%('%U
M97-T:2!M97-S86=G:3\B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*(RP@9G5Z
M>GD*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E-C87)I8V$@5D-A<F0B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S
M92]C;VYT86-T<F]W+FEN8SHR-0IM<V=I9"`B1&]W;FQO860@=D-A<F0B"FUS
M9W-T<B`B4V-A<FEC82!C0V%R9"(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C$P,B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4*(SH@=&5M
M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3`@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHS"B,Z('1E;7!L871E<R]B<F]W<V4O8V]N
M=&%C=')O=RYI;F,Z,S,@;&EB+U)E;F1E<F5R+G!H<#HT,@IM<V=I9"`B161I
M="(*;7-G<W1R(")-;V1I9FEC82(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W
M+FEN8SHR-2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R
M(")-;V1I9FEC82`G)7,G(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z.#$*(RP@9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G
M<W1R(")%<V-I(&1A;&QA(%)U8G)I8V$B"@HC.B!E9&ET+G!H<#HW."!E9&ET
M+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!E;G1R>2!F;W(@
M)7,B"FUS9W-T<B`B36]D:69I8V$@<V-H961A('!E<B`E<R(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C4X"FUS9VED(")%;6%I;"(*;7-G<W1R
M(")%;6%I;"(*"B,Z(&5D:70N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%;G1R>2!F;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D
M960@9FEL92!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$T
M.2!E9&ET+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R
M("5S('5P9&%T960N(@IM<V=S='(@(D%G9VEO<FYA=&$@;&$@<V-H961A('!E
M<B`E<RXB"@HC.B!B<F]W<V4N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")%;G1R
M>2!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B1FEL92`E<R!I;7!O
M<G1A=&\@8V]N('-U8V-E<W-O(@H*(SH@;&EB+V%P:2YP:'`Z-#$S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96%R8VAI;F<@=&AE(&%D
M9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B4V5L97II;VYA(')U8G)I8V$@)R5S
M)RXB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C8@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@
M(D5S<&]R=&$B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*;7-G
M:60@(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`B17-P;W)T82!2=6)R
M:6-A(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+B(*
M;7-G<W1R(")396QE>FEO;F$@=6X@8V]N=&%T=&\B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C(W"FUS9VED(")%>'!O<G0@=&AE(&9O;&QO=VEN
M9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2XB"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z,3,T(&1A=&$N<&AP.C(R."!D871A+G!H<#HR.3<@8G)O=W-E+G!H
M<#HS-2!B<F]W<V4N<&AP.CDP"B,Z(&)R;W=S92YP:'`Z,3$R(&%D9"YP:'`Z
M-C<@<V5A<F-H+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R
M(")#;VYN97-S:6]N92!F86QI=&$@86QL82!R=6)R:6-A(&EN9&EC871A.B`E
M<R(*"B,Z(&)R;W=S92YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S(@IM<V=S='(@(D%G9VEU;F=I;65N
M=&\@9&5L("5S(&$@)7,@9F%L:71A.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,C<R
M"FUS9VED(")&86EL960@=&\@8G)O=W-E(&QI<W0B"FUS9W-T<B`B26UP;W-S
M:6)I;&4@97-A;6EN87)E(&QA(&QI<W1A(@H*(SH@8G)O=W-E+G!H<#HS,3`*
M;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R>2(*;7-G<W1R
M("));7!O<W-I8FEL92!P87-S87)E(&EN(')A<W-E9VYA(&QA(&1I<F5C=&]R
M>2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[
M($]L9"!$3B`]("5S+"!.97<@1$X@/2`E<RP@4F]O="`]("5S(@IM<V=S='(@
M(DUO9&EF:6-A(&9A;&QI=&$@9&5L(&YO;64Z("@E<RD@)7,L("5S(@H*(SH@
M8G)O=W-E+G!H<#HQ,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&9I;F0@;V)J96-T('1O(&)E(&%D9&5D.B`E<R(*;7-G<W1R(")2:6-E<F-A
M(&1I(&]G9V5T=&D@9&$@86=G:75N9V5R92!F86QI=&$Z("5S(@H*(SH@<V5A
M<F-H+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T
M:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(E)I8V5R8V$@;F5L;&$@9&ER96-T
M;W)Y(&9A;&ET83H@)7,B"@HC.B!D871A+G!H<#HQ-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E<R(*
M;7-G<W1R(")2:6-E<F-A(&YE;&QA(&1I<F5C=&]R>2!F86QI=&$Z("5S(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38W"FUS9VED(")&87@B
M"FUS9W-T<B`B1F%X(@H*(SH@961I="YP:'`Z,3(T(&1I<W!L87DN<&AP.C$P
M,`HC+"!F=7IZ>0IM<V=I9"`B1FEL97,B"FUS9W-T<B`B5&ET;VQO(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<P"FUS9VED(")&:6YD(@IM
M<V=S='(@(E1R;W9A(@H*(SH@961I="YP:'`Z.3<@961I="YP:'`Z,3@W"B,L
M(&9U>GIY"FUS9VED(")&:6YI<V@B"FUS9W-T<B`B5')O=F$B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HT.`IM<V=I9"`B1FER<W0@3F%M92(*
M;7-G<W1R(").;VUE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B55),(&QI8F5R;R]O
M8V-U<&%T;R(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHX,PIM
M<V=I9"`B1G)O;2(*;7-G<W1R(")$82(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H
M<"YD:7-T.C8P-`IM<V=I9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")2=6)R:6-A(&=L;V)A;&4B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT-`IM<V=I
M9"`B1W)O=7`B"FUS9W-T<B`B1W)U<'!O(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("))
M;F1I<FEZ>F\@06)I=&%Z:6]N92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.CDS"FUS9VED(")(;VUE($-I='DB"FUS9W-T<B`B0VET=.`B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#@*;7-G:60@(DAO;64@
M0V]U;G1R>2(*;7-G<W1R(")0865S92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$U,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE
M9F]N;R!!8FET87II;VYE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3`S"FUS9VED(")(;VUE(%!O<W1A;"!#;V1E(@IM<V=S='(@(D-!4"(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.CDX"FUS9VED(")(;VUE
M(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(E!R;W9I;F-I82!O(%-T871O(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#@*(RP@9G5Z>GD*;7-G
M:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO($%B
M:71A>FEO;F4B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HU,#8*;7-G
M:60@(DE-4U`B"FUS9W-T<B`B24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-PHC+"!F=7IZ>0IM<V=I9"`B24U34"!!9&1R97-S($)O;VL@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B3&ES=&$@4G5B<FEC82XB"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9"(*;7-G<W1R("));7!O<G1A
M>FEO;F4@4G5B<FEC82P@<W1E<"`E9"(*"B,Z(&1A=&$N<&AP.C,V,0IM<V=I
M9"`B26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS(@IM<V=S='(@(DEM<&]R
M=&$O17-P;W)T82!2=6)R:6-H92(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O
M87!I+G!H<#HV.#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@240B"FUS9W-T
M<B`B0VAI879E(&EN=F%L:61A(@H*(SH@;&EB+V%P:2YP:'`Z,C,P(&QI8B]A
M<&DN<&AP.C0P,B!L:6(O87!I+G!H<#HT.#8@;&EB+V%P:2YP:'`Z-3DR"B,Z
M(&QI8B]A<&DN<&AP.C8W.2!L:6(O87!I+G!H<#HW,S$@;&EB+V%P:2YP:'`Z
M,3`W-PIM<V=I9"`B26YV86QI9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B4G5B
M<FEC82!N;VX@=F%L:61A+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.#$@;&EB+V%P
M:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ,C`W"FUS9VED("));G9A;&ED(&5M
M86EL(@IM<V=S='(@(DEN9&ER:7IZ;R!E+6UA:6P@;F]N('9A;&ED;RXB"@HC
M.B!L:6(O87!I+G!H<#HQ,#@Y"FUS9VED("));G9A;&ED(&5N=')Y(@IM<V=S
M='(@(D1A=&\@;F]N('9A;&ED;RXB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C(V-@IM<V=I9"`B26YV86QI9"!K97D@<W!E8VEF:65D+B(*;7-G<W1R(")#
M:&EA=F4@:6YV86QI9&$@<W!E8VEF:6-A=&$N(@H*(SH@;&EB+V%P:2YP:'`Z
M,3`X-0IM<V=I9"`B26YV86QI9"!N86UE(@IM<V=S='(@(DYO;64@;F]N('9A
M;&ED;RXB"@HC.B!L:6(O87!I+G!H<#HW,S4*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@;V)J96-T260B"FUS9W-T<B`B1&%T;R!N;VX@=F%L:61O+B(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R
M="!I<R!R97%U:7)E9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I
M;&%B;&4@;W(@;F]T(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C
M=%9I97<N<&AP.C$S.`IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R(")5
M;'1I;6$@36]D:69I8V$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HU,PIM<V=I9"`B3&%S="!.86UE(@IM<V=S='(@(D-O9VYO;64B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ-@HC+"!F=7IZ
M>0IM<V=I9"`B3&ES="(*;7-G<W1R(").=6]V82!,:7-T82(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW-PIM<V=I9"`B36%T8VAI;F<B"FUS
M9W-T<B`B0V]R<FES<&]N9&5N=&4B"@HC.B!L:6(O87!I+G!H<#HR,#4*(RP@
M9G5Z>GD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S(@IM<V=S
M='(@(DEL(&YU;65R;R!M87-S:6UO(&1I('!A9VEN92!E)R!G:6$G('!R97-E
M;G1E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA
M>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM<V=S='(@(DEL(&YU;65R;R!M87-S
M:6UO(&1I('!A9VEN92!E)R!G:6$G('!R97-E;G1E+B(*"B,Z(&QI8B]";&]C
M:R]T<F5E7VUE;G4N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@3&ES="(*
M;7-G<W1R(").=6]V82!,:7-T82(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H
M+G!H<#HS"FUS9VED(")-:6YI(%-E87)C:"(*;7-G<W1R(")2:6-E<F-A(%9E
M;&]C92(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`R"FUS9VED(")-:7-S
M:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V,@IM<V=I9"`B
M36]B:6QE(%!H;VYE(@IM<V=S='(@(D-E;&QU;&%R92(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,S,R(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S0X"B,L('!H
M<"UF;W)M870*;7-G:60@(DUO9&EF>2!F86EL960Z("@E<RD@)7,B"FUS9W-T
M<B`B36]D:69I8V$@9F%L;&ET83H@*"5S*2`E<R(*"B,Z(&QI8B]A<&DN<&AP
M.C$Q.3,*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S='(@
M(E)I<W5L=&$@<&DF=6=R879E.R!D:2!U;B!D871O+B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3$*;7-G:60@(DUO=F4B"FUS9W-T<B`B
M4W!O<W1A(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z
M,C0W"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z
M,3@T"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B4W!O<W1A(&$@<VEN:7-T
M<F$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#D*
M(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#8*
M;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B4W!O<W1A(&$@9&5S=')A(@H*
M(SH@9&%T82YP:'`Z-3(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-@IM
M<V=I9"`B375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(E)U8G)I8V$@
M375L8F5R<GDB"@HC.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL
M(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T
M<B`B(@HB1&EV97)S92!P97)S;VYE(&-O;B!I;F1I<FEZ>F\@6R5S72P@;6$@
M;F5S<W5N82!C;VX@;F]M92!;)7-=(&YE;&QA(')U8G)I8V$N(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S<R!";V]K(@IM<V=S
M='(@(E)U8G)I8V$@4&5R<V]N86QE(@H*(SH@861D<F5S<V)O;VMS+G!H<#HQ
M,C`*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B
M4G5B<FEC82!097)S;VYA;&4B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHQ,#<@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#(*;7-G:60@
M(DYA;64B"FUS9W-T<B`B3F]M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,0IM<V=I9"`B3F%M92!&;W)M870B"FUS9W-T<B`B1F]R;6%T;R!.;VUE
M(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S$U"FUS9VED(").971C
M96YT97(@365M8F5R($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!A9&0N<&AP
M.C,V(&%D9"YP:'`Z,3(T(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HR-PHC
M.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-PIM<V=I9"`B3F5W($-O;G1A
M8W0B"FUS9W-T<B`B3G5O=F\@0V]N=&%T=&\B"@HC.B!E9&ET+G!H<#HX."!E
M9&ET+G!H<#HY-2!E9&ET+G!H<#HR,#(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHT-0IM<V=I9"`B3F5X="(*;7-G<W1R(")3=6-C97-S:79O(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$X"FUS9VED(").:6-K;F%M
M92(*;7-G<W1R(")N;VUE(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y-2!L:6(O87!I
M+G!H<#HQ,C0T"B,L('!H<"UF;W)M870*;7-G:60@(DYO("5S(&5N=')Y(&9O
M=6YD(&9O<B`E<R(*;7-G<W1R(").97-S=6X@9&%T;R`E<R!T<F]V871O('!E
M<B`E<RXB"@HC.B!L:6(O87!I+G!H<#HQ,38S"B,L(&9U>GIY"FUS9VED(").
M;R!A9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R("),82!R=6)R:6-A(.@@
M:6X@<V]L82!L971T=7)A+B(*"B,Z(&UI;FES96%R8V@N<&AP.C@S"FUS9VED
M(").;R!C;VYT86-T<R!F;W5N9"(*;7-G<W1R(").97-S=6X@8V]N=&%T=&\@
M=')O=F%T;R(*"B,Z(&QI8B]A<&DN<&AP.C4Q,2!L:6(O87!I+G!H<#HW-C8*
M;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R(").97-S
M=6X@8V]M<&QE86YN;R!T<F]V871O+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M9F]O=&5R+FEN8SHW"FUS9VED(").;VYE(@IM<V=S='(@(DYE<W-U;F\B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S
M(@IM<V=S='(@(DYO=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U
M"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T<B`B3G5M
M97)O(&1I(&-A<F%T=&5R:2(*"B,Z(&QI8B]A<&DN<&AP.C8Q-"!L:6(O87!I
M+G!H<#HW-#<*;7-G:60@(D]B:F5C="!N;W0@9F]U;F0B"FUS9W-T<B`B3V=G
M971T;R!N;VX@=')O=F%T;R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@(E5F9FEC:6\B"@HC.B!T
M96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(S"FUS9VED("(B"B)/;F-E
M('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H92!A9&1R97-S(&)O;VL@
M=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B!)9B!T:&ES(&ES(&YO
M="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T(&-H86YG92!Y;W5R('-E
M;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z-S<T"FUS9VED(")/;FQY(&]N92!V8V%R9"!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T
M<B`B06QT<F4@3W!Z:6]N:2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B0VAI879E
M(%!'4"!P=6)B;&EC82(*"B,Z(&QI8B]A<&DN<&AP.C0Y-2!L:6(O87!I+G!H
M<#HV,#4@;&EB+V%P:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.CDS-`HC.B!L:6(O
M87!I+G!H<#HQ,#DX"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R
M(")097)M97-S;R!.96=A=&\B"@HC.B!L:6(O1')I=F5R+G!H<#HU-#,*(RP@
M9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(E!E<FUE
M<W-O($YE9V%T;R(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDY
M"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")097)M97-S
M;R!.96=A=&\B"@HC.B!D871A+G!H<#HU,R!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$W"FUS9VED(")0:6YE($%D9')E<W,@0F]O:R(*;7-G<W1R(")2
M=6)R:6-A(%!I;F4B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N
M:6YC.C(X"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@;F%M92!T:&4@;F5W(&-O
M;G1A8W0@;&ES=#HB"FUS9W-T<B`B26YS97)I<V-I(&EL(&YO;64@9&5L;&$@
M;G5O=F$@8V%R=&5L;&$Z(@H*(SH@961I="YP:'`Z.3$@961I="YP:'`Z.30@
M961I="YP:'`Z,3DT"FUS9VED(")0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HT,38*;7-G:60@(E!R:79A=&4@061D
M<F5S<R!";V]K(@IM<V=S='(@(E)U8G)I8V$@4&5R<V]N86QE(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475E
M<GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(E%U97)Y(&9A;&QI=&$Z("@E
M<RD@)7,B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,3@*
M;7-G:60@(E%U:6-K(%-E87)C:"(*;7-G<W1R(")2:6-E<F-A(%9E;&]C92(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,3DY(&QI8B]$<FEV97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E860@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(DQE='1U<F$@
M9F%L;&ET83H@*"5S*2`E<R(*"B,Z(&QI8B]296YD97)E<BYP:'`Z-#D*(RP@
M9G5Z>GD*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI<R!C;VYT86-T/R(*;7-G
M<W1R(")396QE>FEO;F$@=6X@8V]N=&%T=&\B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V9O;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D<R!D:7-P;&%Y960Z(@IM
M<V=S='(@(E-I(')I<&5T92!O9VYI(&=I;W)N;R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<V"B,L(&9U>GIY"FUS9VED
M(")296UO=F4@861D<F5S<R!B;V]K(@IM<V=S='(@(E-C96=L:2!U;F$@<G5B
M<FEC82(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S
M.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")2:6UU;W9I(&-O;&]N
M;F$B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@
M(E)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R(")%;&EM:6YA(&1A('%U
M97-T82!L:7-T82(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C$*
M;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K('=I=&@@
M=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES("(*(F1E
M;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@8F]O
M:RX\+W-T<F]N9SXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z-#,X
M"FUS9VED(")297%U97-T960@;V)J96-T(&YO="!F;W5N9"XB"FUS9W-T<B`B
M3V=G971T;R!R:6-H:65S=&\@;F]N('1R;W9A=&\N(@H*(SH@861D+G!H<#HS
M-R!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$S"FUS9VED(")297-E
M="!T;R!$969A=6QT<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ.38*;7-G:60@(E,O34E-12!0=6)L:6,@0V5R=&EF:6-A
M=&4B"FUS9W-T<B`B0V5R=&EF:6-A=&\@4'5B8FQI8V\@4R]-24U%(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HV.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4U1!4E143%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(DQE='1U
M<F$@9F%L;&ET83H@*"5S*2`E<R(*"B,Z(&5D:70N<&AP.CDY(&%D9"YP:'`Z
M,S<@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E
M(@IM<V=S='(@(E-A;'9A(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.CDV('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3(*(SH@=&5M
M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(Q(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C0Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")#97)C82(*"B,Z(&UI;FES96%R8V@N<&AP
M.C8S"B,L(&9U>GIY"FUS9VED(")396%R8V@@4F5S=6QT<SHB"FUS9W-T<B`B
M4FES=6QT871I(&1E;&QA(%)I8V5R8V$B"@HC.B!L:6(O87!I+G!H<#HQ,#$Q
M"FUS9VED(")396%R8V@@9F%I;&5D(@IM<V=S='(@(E)I8V5R8V$@9F%L;&ET
M82(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#,@;&EB+V%P:2YP:'`Z,3$P.2!L:6(O
M87!I+G!H<#HQ,3$X(&QI8B]A<&DN<&AP.C$Q,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T<B`B4FEC97)C82!F86QL
M:71A.B`E<R(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR
M,@IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S='(@(E)I8V5R8V$@:6X@8V]R
M<V\N+BXB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B
M"FUS9W-T<B`B4V5L97II;VYA(&QA(&9O;G1E(&1A(&-U:2!E<W!O<G1A<F4Z
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3`*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@961I="(*;7-G<W1R
M(")396QE>FEO;F$@:6P@8V%L96YD87)I;R!V97)S;R!C=6D@:6UP;W)T87)E
M.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S(*;7-G:60@(E-E
M;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G<W1R
M(")396QE>FEO;F$@;&$@9F]N=&4@9&$@8W5I(&5S<&]R=&%R93HB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(V"FUS9VED(")396QE8W0@=&AE
M(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(E-E;&5Z:6]N
M82!I;"!C86QE;F1A<FEO('9E<G-O(&-U:2!I;7!O<G1A<F4Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B
M4V5L97II;VYA(&EL(&9O<FUA=&\@:6X@8W5I(&5S<&]R=&%R93HB"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P"FUS9VED(")396QE8W0@=&AE
M(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E-E;&5Z:6]N82!I;"!F;W)M871O
M('!E<B!E<W!O<G1A<F4B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C0S"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R
M(")396QE>FEO;F$@:6P@9FEL92!D82!I;7!O<G1A<F4Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0IM<V=I9"`B4V5L96-T('1H92!F;W)M
M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")396QE>FEO;F$@:6P@
M9F]R;6%T;R!I;B!C=6D@97-P;W)T87)E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@
M9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`B4V5L97II;VYA(&EL(&9O<FUA=&\@
M=71I;&EZ>F%T;R!P97(@;6]S=')A<F4@:2!N;VUI.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('9I97<@
M=&\@9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I
M;F<@;W!T:6]N<RXB"FUS9W-T<B`B4V5L97II;VYA(&QA('9I<W1A(&1A(&UO
M<W1R87)E(&1I(&1E9F%U;'0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$X"FUS9VED(")396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@
M=&AE(&%D9')E<W,@;&ES=',N(@IM<V=S='(@(E-E;&5Z:6]N82!Q=6%L:2!C
M86UP:2!M;W-T<F%R92!N96QL82!L:7-T82!I;F1I<FEZ>FDN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,R"FUS9VED(")396QE8W0@=VAI8V@@9F]R
M;6%T('1O(&1I<W!L87D@;F%M97,N(@IM<V=S='(@(E-E;&5Z:6]N82!I;B!Q
M=6%L92!F;W)M871O('9I<W5A;&EZ>F%R92!I(&YO;6DN(@H*(SH@861D+G!H
M<#HU-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5L96-T960@861D
M<F5S<R!B;V]K(%PB)7-<(BXB"FUS9W-T<B`B4V5L97II;VYA(')U8G)I8V$@
M)R5S)RXB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ-S,*;7-G:60@
M(E-H87)E9"!$:7)E8W1O<GDB"FUS9W-T<B`B1&ER96-T;W)Y($-O;F1I=FES
M82(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`B36]S=')A
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B
M4VAO=R!!;&PB"FUS9W-T<B`B36]S=')A(%1U='1O(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B4VAO=R!#;VYT86-T<R(*
M;7-G<W1R(")-;W-T<F$@0V]N=&%T=&DB"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")3:&]W($QI<W1S(@IM<V=S='(@(DUO
M<W1R82!,:7-T92(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C(Q"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N
M:6YC.C,T"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R(")$:7)E>FEO
M;F4@9&D@;W)D:6YA;65N=&\B"@HC.B!L:6(O87!I+G!H<#HQ.3@*;7-G:60@
M(E-O=7)C97,B"FUS9W-T<B`B55),($YO=&EZ:6$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34W"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT
M(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B
M(@H*(SH@8G)O=W-E+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D("5S('1O("5S(@IM<V=S='(@(D%G9VEU;G1O(&-O
M;B!S=6-C97-S;R`E<R!A("5S(@H*(SH@8G)O=W-E+G!H<#HR,C(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C<F5A=&5D('1H
M92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R(")!9V=I=6YT;R!C;VX@
M<W5C8V5S<V\@)7,@82`E<R(*"B,Z(&1A=&$N<&AP.C4P"FUS9VED(")44U8B
M"FUS9W-T<B`B5%-6(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ
M-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$T"FUS9VED(")486(@<V5P
M87)A=&5D('9A;'5E<R(*;7-G<W1R(")686QO<FD@<V5P87)A=&D@9&$@5&%B
M(@H*(SH@=FEE=RYP:'`Z,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D
M<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A
M9',N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-30*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(").;VX@97)A('!O<W-I8FEL92!S
M;W-T:71U:7)E(&QA(&9I<FUA+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@
M7"(E<UPB('=A<R!C<F5A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4G5B
M<FEC82!S=G5O=&%T82!C;VX@<W5C8V5S<V\N(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E
M<W,@8F]O:R!<(B5S7"(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(")2=6)R:6-A('-V=6]T871A(&-O;B!S=6-C97-S;RXB"@HC.B!A9&1R
M97-S8F]O:W,N<&AP.C@Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T
M960N(@IM<V=S='(@(E)U8G)I8V$@<W9U;W1A=&$@8V]N('-U8V-E<W-O+B(*
M"B,Z(&1A=&$N<&AP.C,P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G
M<W1R(").;VX@97)A('!O<W-I8FEL92!S;W-T:71U:7)E(&QA(&9I<FUA+B(*
M"B,Z(&5D:70N<&AP.C0W('9C87)D+G!H<#HR,B!D:7-P;&%Y+G!H<#HR,R!V
M:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A8W0@>6]U(')E<75E<W1E9"!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3"=O9V=E='1O(')I8VAI97-T;R!N
M;VX@97-I<W1E+B(*"B,Z(&5D:70N<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")&:6QE("5S(&EM<&]R=&%T;R!C;VX@
M<W5C8V5S<V\B"@HC.B!D871A+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@
M8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R
M("(B"@HC.B!B<F]W<V4N<&AP.C,Q"FUS9VED(")4:&5R92!A<F4@;F\@8G)O
M=W-E86)L92!A9&1R97-S(&)O;VMS+B(*;7-G<W1R(").;VX@8VD@<V]N;R!R
M=6)R:6-H92!E<V%M:6YA8FEL:2XB"@HC.B!A9&0N<&AP.C(Y"FUS9VED("(B
M"B)4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@
M;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS("(*(F%R92!C;VYF:6=U
M<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@
M268@>6]U(&)E;&EE=F4@=&AI<R`B"B)I<R!A;B!E<G)O<BP@<&QE87-E(&-O
M;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB
M3F5S<W5N82!D96QL92!R=6)R:6-H92!D:7-P;VYI8FEL:2#H(&-O;F9I9W5R
M871A(&EN(&UO9&\@9&$@8V]N<V5R=&ER=&D@(@HB9&EA9V=I=6YG97)E(&YU
M;W9E(&5N=')A=&4N(%-E('!E;G-I('-I82!U;B!E<G)O<F4L('!E<B!F879O
M<F4@8V]N=&%T=&$@:6P@(@HB='5O(&%M;6EN:7-T<F%T;W)E(&1I('-I<W1E
M;6$N(@H*(SH@861D+G!H<#HQ,C$*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!A9&1I;F<@=&AE(&YE=R!C;VYT86-T+B!#;VYT86-T('EO=7(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(@(@HB9F]R(&9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@HB0R<F96=R879E.R!S=&%T;R!U;B!E<G)O<F4@86=G:75N9V5N9&\@
M<75E<W1O(&]G9V5T=&\N($-O;G1A='1A(&EL('1U;R`B"B)A;6UI;FES=')A
M=&]R92!D:2!S:7-T96UA('!E<B!U;'1E<FEO<F4@86EU=&\N(@H*(SH@8G)O
M=W-E+G!H<#HQ.#D@8G)O=W-E+G!H<#HR,S`*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@
M(D5R<F]R92!N96QL82!C86YC96QL87II;VYE(&1E;&PG;V=G971T;RXB"@HC
M.B!B<F]W<V4N<&AP.C(S.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R
M96%T:6YG(&$@;F5W(&QI<W0N(@IM<V=S='(@(D5R<F]R92!N96QL82!C<F5A
M>FEO;F4@9&D@=6YA(&YU;W9A(&QI<W1A+B(*"B,Z(&%D9')E<W-B;V]K<RYP
M:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T
M<B`B4VD@92<@=F5R:69I8V%T;R!U;B!E<G)O<F4@;F5L;"=A9V=I;W)N86UE
M;G1O(&1I('%U97-T;R!O9V=E='1O.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,30W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@7"(E<UPB(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*(E-I(&4G('9E<FEF:6-A=&\@=6X@97)R;W)E(&YE
M;&PG96QI;6EN87II;VYE(&1I("5S(&1A;&QA(&9O;G1E(&1E;&QA(')U8G)I
M8V$N(@H*(SH@9&5L971E+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C
M=#H@)7,B"FUS9W-T<B`B17)R;W)E(&YE;&QA(&-A;F-E;&QA>FEO;F4@9&5L
M;"=O9V=E='1O+B(*"B,Z(&)R;W=S92YP:'`Z-S(*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B17)R
M;W)E(&YE;&QA(&-A;F-E;&QA>FEO;F4@9&5L;"=O9V=E='1O+B(*"B,Z(&)R
M;W=S92YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R(")%<G)O<F4@;F5L;&$@
M=FES=6%L:7IZ87II;VYE(&1E;&QA(&QI<W1A(%-E;&5Z:6]N871A(@H*(SH@
M9&%T82YP:'`Z,S,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(D5R<F]R
M92!N96QL)VEM<&]R=&%Z:6]N92!D96D@9&%T:3H@)7,B"@HC.B!L:6(O87!I
M+G!H<#HU,#<@;&EB+V%P:2YP:'`Z-S8Q"B,L(&9U>GIY"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB
M"FUS9W-T<B`B17)R;W)E(&YE;&PG:6UP;W)T87II;VYE(&1E:2!D871I.B`E
M<R(*"B,Z(&)R;W=S92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!R96UO=FEN9R!A(&-O;G1A8W0@9G)O;2!T:&4@;&ES="XB
M"FUS9W-T<B`B17)R;W)E(&YE;&QA(&-R96%Z:6]N92!D:2!U;F$@;G5O=F$@
M;&ES=&$N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HU-2!A9&1R97-S8F]O:W,N
M<&AP.C8P(&%D9')E<W-B;V]K<RYP:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D
M9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B17)R;W)E(&YE;&QA(')I;6]Z:6]N
M92!D96QL)V]G9V5T=&\N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX,2!A9&1R
M97-S8F]O:W,N<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ
M("5S(@IM<V=S='(@(E-I(&4G('9E<FEF:6-A=&\@=6X@97)R;W)E(&YE;&PG
M86=G:6]R;F%M96YT;R!D:2!Q=65S=&\@;V=G971T;SH@)7,B"@HC.B!E9&ET
M+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H:7,@96YT<GDZ("5S(@IM<V=S='(@(E-I(&4G('9E
M<FEF:6-A=&\@=6X@97)R;W)E(&YE;&PG86=G:6]R;F%M96YT;R!D:2!Q=65S
M=&\@;V=G971T;SH@)7,B"@HC.B!D871A+G!H<#HQ-SD*;7-G:60@(E1H97)E
M('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="XB"FUS9W-T<B`B3F]N(&-I
M('-O;F\@:6YD:7)I>GII(&1A(&5S<&]R=&%R92XB"@HC.B!T96UP;&%T97,O
M<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X,`IM<V=I9"`B5&AE<V4@
M861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z
M,C0S"FUS9VED(")4:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES
M(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-CD*;7-G:60@(E1H
M:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B455E
M<W1O(&9O<FUA=&\@9&D@9FEL92!N;VX@)F5G<F%V93L@<W5P<&]R=&%T;RXB
M"@HC.B!L:6(O87!I+G!H<#HQ,3(R(&QI8B]A<&DN<&AP.C$Q,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E
M;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(E%U97-T82!P97)S
M;VYA(&AA(&=I82<@=6YA("5S('-C:&5D82!N96QL82!R=6)R:6-A+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#<*;7-G:60@(B(*(E1H:7,@=VEL
M;"!B92!T:&4@9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@
M:6UP;W)T:6YG(&-O;G1A8W1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HW,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET
M;VQO(@H*(SH@;&EB+U1U<F)A+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N("!-:7-S:6YG('-O=7)C
M92!T>7!E+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HY-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A<FEC87)E(&QE(&1E
M9FEN:7II;VYI(&1I("5S+B(*"B,Z(&5D:70N<&AP.C@X(&5D:70N<&AP.CDQ
M(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY(&5D:70N<&AP.C$Y-@IM<V=I9"`B
M56YD;R!#:&%N9V5S(@IM<V=S='(@(DEN9&EE=')O(@H*(SH@;&EB+V%P:2YP
M:'`Z-30P(&QI8B]A<&DN<&AP.C8T,R!L:6(O87!I+G!H<#HW-SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP
M93H@)7,B"FUS9W-T<B`B17-T96YS:6]N92!.;VX@4W5P<&]R=&%T82(*"B,Z
M(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,W-@IM<V=I9"`B5F5R:7-I9VX@
M1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=&]R>2!697)I<VEG;B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O
M;G1A8W1R;W<N:6YC.C(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W(%PB)7-<(B(*;7-G<W1R(")6:7-U86QI>GIA("<E<R<B"@HC.B!M:6YI
M<V5A<F-H+G!H<#HW.`IM<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(E9I
M<W5A;&EZ>F$@0V]N=&%T=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(T"FUS9VED(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS9W-T
M<B`B5FES=&$@9&$@;6]S=')A<F4@9&D@9&5F875L=#HB"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HR,#@*;7-G:60@(E=E8G-I=&4@55),(@IM
M<V=S='(@(E523"!D:2!B87-E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3$S"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B26YD:7)I
M>GIO(&1I($QA=F]R;R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$R-`HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!#:71Y(@IM<V=S='(@(E!A97-E
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,Y"FUS9VED(")7
M;W)K($-O=6YT<GDB"FUS9W-T<B`B4&%E<V4B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B
M5&5L969O;F\@9&D@;&%V;W)O(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3,T"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S='(@(D-!
M4"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R.0IM<V=I9"`B
M5V]R:R!3=&%T92]0<F]V:6YC92(*;7-G<W1R(")0<F]V:6YC:6$@;R!3=&%T
M;R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q.0HC+"!F=7IZ
M>0IM<V=I9"`B5V]R:R!3=')E970@061D<F5S<R(*;7-G<W1R("));F1I<FEZ
M>F\@9&D@3&%V;W)O(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP:'`Z.3,@
M8G)O=W-E+G!H<#HR,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8V]N=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HV
M.2!D:7-P;&%Y+G!H<#HU."!V:65W+G!H<#HS-@IM<V=I9"`B66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S
M='(@(DYO;B!H86D@:6P@<&5R;65S<V\@9&D@=FES=6%L:7IZ87)E(&PG;V=G
M971T;RXB"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(DYO
M;B!H86D@:6P@<&5R;65S<V\@9&D@=FES=6%L:7IZ87)E(&PG;V=G971T;RXB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C4U"FUS9VED
M(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B;V]K+B(*;7-G
M<W1R(")$979I('!R:6UA('-E;&5Z:6]N87)E('5N(&EN9&ER:7IZ;RXB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S"FUS9VED(")9
M;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB"FUS9W-T<B`B1&5V:2!P
M<FEM82!S96QE>FEO;F%R92!U;F$@8V%S96QL82!D:2!D97-T:6YA>FEO;F4N
M(@H*(SH@961I="YP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`B1&5V
M:2!P<FEM82!S<&5C:69I8V%R92!A;&UE;F\@=6X@;65S<V%G9VEO+B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S
M+V)R;W=S92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E
M+VIA=F%S8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@
M;&5A<W0@;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R(")$979I('!R:6UA('-P
M96-I9FEC87)E(&%L;65N;R!U;B!M97-S86=G:6\N(@H*(SH@961I="YP:'`Z
M-S,*;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H
M:7,@8V]N=&%C="XB"FUS9W-T<B`B2&%I('-O;&\@:6P@<&5R;65S<V\@9&D@
M=FES=6%L:7IZ87)E(&PG;V=G971T;RXB"@HC.B!B<F]W<V4N<&AP.C(X-0IM
M<V=I9"`B66]U<B!D969A=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E
M86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC
M.C8@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHQ,@IM<V=I9"`B
M6VYO('9A;'5E72(*;7-G<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0X-`IM
M<V=I9"`B7T)R;W=S92(*;7-G<W1R(")?4V9O9VQI82(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(E]#;VYT
M86-T<R(*;7-G<W1R(")-;W-T<F$@7T-O;G1A='1I(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED(")?1&5L971E(@IM<V=S='(@
M(E]%;&EM:6YA(@H*(SH@;&EB+U1U<F)A+G!H<#HT.3,*;7-G:60@(E]);7!O
M<G0O17AP;W)T(@IM<V=S='(@(E]);7!O<G1A+T5S<&]R=&$B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY"FUS9VED(")?
M3&ES=',B"FUS9W-T<B`B36]S=')A(%],:7-T92(*"B,Z(&QI8B]4=7)B82YP
M:'`Z-#@Q"B,L(&9U>GIY"FUS9VED(")?37D@061D<F5S<R!";V]K<R(*;7-G
M<W1R(")2=6)R:6-A(%!E<G-O;F%L92(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@W
M"B,L(&9U>GIY"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T<B`B3G5O=F\@
M0V]N=&%T=&\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*
M;7-G:60@(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B7T5L:6UI
M;F$@9&$@<75E<W1A(&QI<W1A(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#D*;7-G
M:60@(E]396%R8V@B"FUS9W-T<B`B7T-E<F-A(@H*(SH@=F-A<F0N<&AP.C0V
M"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R(")C;VYT871T:2YC<W8B"@HC
M.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(F-O;G1A
M='1I+F-S=B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B8V]N=&%C=',N='-V
M(@IM<V=S='(@(F-O;G1A='1I+G1S=B(*"B,Z(&1A=&$N<&AP.C(Q.0HC+"!F
M=7IZ>0IM<V=I9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(F-O;G1A='1I+F-S
M=B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S0*(RP@9G5Z
M>GD*;7-G:60@(FYO;F4B"FUS9W-T<B`B3F5S<W5N;R(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(G1O(&$@
M0V]N=&%C="!,:7-T(@IM<V=S='(@(DQI<W1A($-O;G1A='1O(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B
M=&\@82!D:69F97)E;G0@061D<F5S<R!";V]K(@IM<V=S='(@(F%L;&$@4G5B
M<FEC82!396QE>FEO;F%T82(*"B,Z(&1A=&$N<&AP.C4Q('1E;7!L871E<R]B
M<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$S"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,34@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O='5R8F$O<&\O;6M?34LN<&\`````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`W,3(T,@`Q,#0Q-S,V,C<U-@`P,3<U,C,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R!T
M<F%N<VQA=&EO;B!O9B!M:U]-2RYP;R!T;R!-86-E9&]N:6%N"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE(%1U<F)A('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`S($5U<F5K
M82!);F9O<FUA=&EK80HC(%-T;VIA;B!097-O=B`\<W-P0&5U<F5K82YC;VTN
M;6L^+"`R,#`S"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ(&UK7TU+7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP-BTR
M-B`Q-#HU.2LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%-T;VIA;B!097-O
M=B`\<W-P0&5U<F5K82YC;VTN;6L^7&XB"B),86YG=6%G92U496%M.B!-86-E
M9&]N:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M25-/+3@X-3DM-5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@HB6"U'96YE<F%T;W(Z($M"86)E;"`Q+C`N,5QN(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VEM<W!?;W!T+FEN8SHT,@IM<V=I9"`B($%D9"!A;B!)35-0
M($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M:6US<%]O<'0N:6YC.C,Q"FUS9VED("(@1&5L971E($E-4U`@061D<F5S<R!"
M;V]K(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,R-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@86QR96%D>2!E>&ES=',@86YD('=A<R!N;W0@:6UP
M;W)T960N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(V"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET
M(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@;6]V960@8F5C875S
M92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S<*;7-G:60@(EPB1FER<W1N86UE($QA<W1N86UE7"(@("AI
M92X@2F]H;B!$;V4I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S8*;7-G:60@(EPB3&%S=&YA;64L($9I<G-T;F%M95PB("AI92X@
M1&]E+"!*;VAN*2(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C$P.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U
M;&QY(&EM<&]R=&5D(@IM<V=S='(@(B5S(-3>VN/<U=WBWN(@U2#CX=_5Z-W>
M(-C<W][@XMC@T-TB"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0T-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`BN-S?WN#BV.#0
M^"#0U.#5X=#@(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C0U"FUS
M9VED(")!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I
M<F5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3D*
M;7-G:60@(D%B;W9E('-E87)C:"!F;W)M(@IM<V=S='(@(B(*"B,Z('9I97<N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@=&\@
M)7,B"FUS9W-T<B`B(@H*(SH@861D+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C(R"FUS9VED(")!9&0B"FUS9W-T<B`BM-[4T/@B"@HC
M.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-`HC
M+"!F=7IZ>0IM<V=I9"`B061D(&%D9')E<W,@8F]O:R(*;7-G<W1R("*PU.#5
MX=#@WN(@U2#=U=+0V]C4U=TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@861D<F5S
M<R!B;V]K<R(*;7-G<W1R("*]U=S0(-#4X-7AT.`@TMX@VM[X(-4@U-[7TM[;
MU=W>(-?0W]CHX]+0^M4N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E
M;&5C="YI;F,Z,C,W"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z
M(&5D:70N<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B061D(&9I;&4B"FUS9W-T
M<B`BM-[4T-+0^M7BWB#5(-W5X^'?U>C=WB(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R(*;7-G
M<W1R("*TWM30^"(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C@V
M"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`BN-S?WN#B
MV.#0^"#0U.#5X=#@(@H*(SH@8G)O=W-E+G!H<#HR."!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(U"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VL@3&ES
M=&EN9R(*;7-G<W1R("*RWB#0U.#5X=#@WN(@W=4@W-[6U2#4T"#AU2#7T-_8
MZ./2T"`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z>GD*
M;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`BN-S?WN#BV.#0^"#0U.#5
MX=#@(@H*(SH@861D+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@
M8F]O:R!E;G1R>2(*;7-G<W1R("*RWB#0U.#5X=#@WN(@W=4@W-[6U2#4T"#A
MU2#7T-_8Z./2T"`B"@HC.B!D871A+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@
M(D%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+B(*;7-G<W1R("(E
M<R#4WMKCW-7=XM[B(-4@X^'?U>C=WB#8W-_>X.+8X-#=(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9')E
M<W,@8F]O:R!T;R!D96QE=&4@(@IM<V=S='(@(K+>(-#4X-7AT.#>XB#=U2#<
MWM;5(-30(.'5(-?0W]CHX]+0("(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R
M97-S8F]O:W-E;&5C="YI;F,Z,3<P"FUS9VED(")!9&1R97-S(&)O;VMS('1H
M870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R("(B"@HC.B!S96%R
M8V@N<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS-PIM<V=I
M9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(KW0W^#5U-W>(-_@U='0X./2
MT/K5(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G:60@
M(D%L:6%S(@IM<V=S='(@(K#;V-#A(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F
M;V]T97)!;'!H82YI;F,Z-R!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA
M+FEN8SHQ,`HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0Q"FUS
M9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-34R"FUS9VED
M(")!;')E861Y($5X:7-T<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+VIA=F%S8W)I<'0N:6YC.CDS"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92`E<S\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHV-PIM
M<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E('1H
M92!S96QE8W1E9"!E;G1R:65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.38*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R("(B"@HC
M.B!S96%R8V@N<&AP.C@U('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS
M-@HC+"!F=7IZ>0IM<V=I9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(K_@U='0
MX./2T/@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")"
M96QO=R!S96%R8V@@9F]R;2(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C<W(&QI8B]$<FEV97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0FEN9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B
M0G)O=W-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-#D*;7-G:60@(D-35B(*;7-G<W1R("(B"@HC.B!L:6(O
M3V)J96-T+T=R;W5P+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D(&$@9W)O=7`@
M=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O
M;'5M;E]H96%D97)S+FEN8SHW"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#0*;7-G
M:60@(D-H;V]S92!A(&YA;64B"FUS9W-T<B`B(@H*(SH@861D+G!H<#HT.`HC
M+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("*PU.#5X=#@WN(@U2#=U=+0V]C4U=TB"@HC.B!T96UP;&%T97,O<')E9G,O
M8V]L=6UN<V5L96-T+FEN8SHR,C$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A
M;B!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(K#4X-7AT.#>XB#5(-W5TM#;V-35
MW2(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z
M,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!D:7-P
M;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S
M<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(R.`IM<V=I9"`B0VAO;W-E('=H:6-H(&-O
M;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")#;VQU;6X@
M3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W:6QL(&YO="!B
M92!D:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3,@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,@IM<V=I
M9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T
M960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB
M"FUS9W-T<B`BQ-C@W-`B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ-#0*(RP@9G5Z>GD*;7-G:60@(D-O;7!A;GD@061D<F5S<R(*;7-G<W1R
M("*TWMS0Z-W0(-#4X-7AT"(*"B,Z(&QI8B]A<&DN<&AP.C,Q."!L:6(O87!I
M+G!H<#HS-C,@;&EB+V%P:2YP:'`Z-#`W(&QI8B]A<&DN<&AP.C0Y,0HC.B!L
M:6(O87!I+G!H<#HV,#$@;&EB+V%P:2YP:'`Z-C@X(&QI8B]A<&DN<&AP.C<T
M,2!L:6(O87!I+G!H<#HX,3D*(SH@;&EB+V%P:2YP:'`Z,3`P-B!L:6(O87!I
M+G!H<#HQ,#DT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BM-[4T-+0^M7BWB#5(-W5X^'?U>C=
MWB(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R("*TWM30TM#ZU>+>(-4@W=7C
MX=_5Z-W>(@H*(SH@8G)O=W-E+G!H<#HQ.3$@8G)O=W-E+G!H<#HR,S(*;7-G
M:60@(D-O;G1A8W0@861D960@=&\@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O
M=W-E+G!H<#HV,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B
M0V]P>2(*;7-G<W1R("+$V.#<T"(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C4S"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T
M92!!9&1R97-S($)O;VLB"FUS9W-T<B`BM=KAW][@XMC@T/@@T-3@U>'0X"(*
M"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A=&4@82!N97<@
M0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE
M=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I
M<F5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K
M<RYI;F,Z-S8@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z(&QI
M8B]/8FIE8W0N<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]296YD
M97)E<BYP:'`Z-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R("*XU]'@V.C8(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!!9&1R97-S($)O;VLB"FUS9W-T<B`BM=KAW][@XMC@T/@@
MT-3@U>'0X"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B
M1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C<P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D.B`H)7,I("5S
M(@IM<V=S='(@(K3>U-#2T/K5XMX@U2#=U>/AW]7HW=XB"@HC.B!D96QE=&4N
M<&AP.C,X"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T<B`BM-[4T-+0
M^M7BWB#5(-W5X^'?U>C=WB(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C(Q,PIM<V=I9"`B1&5P87)T;65N="(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3$U"FUS9VED
M(")$97-C<FEP=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+W-E87)C:"YI;F,Z,3$X"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`BM-C@
MU=KBWN#8X]PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*;7-G:60@
M(D1I<W!L87DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3<V"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T
M:6YG(&5N=')I97,_(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W0N<&AP.C(Y
M-PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]R;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI
M;F,Z,C4*;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P,B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z,C4*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R
M<RYI;F,Z,3`@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"B,Z('1E
M;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,@;&EB+U)E;F1E<F5R
M+G!H<#HT,@IM<V=I9"`B161I="(*;7-G<W1R("+#X-74V"(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<F]W+FEN8SHR-2!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C,S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M(%PB)7-<(B(*;7-G<W1R("+#X-74V"(*"B,Z('1E;7!L871E<R]A9&1R97-S
M8F]O:W,N:6YC.C@Q"B,L(&9U>GIY"FUS9VED(")%9&ET($%D9')E<W,@0F]O
M:W,B"FUS9W-T<B`BM=KAW][@XMC@T/@@T-3@U>'0X"(*"B,Z(&5D:70N<&AP
M.C<X(&5D:70N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(&5N
M=')Y(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HU.`IM<V=I9"`B16UA:6PB"FUS9W-T<B`BU2W?WNCBT"(*"B,Z
M(&5D:70N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@
M)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D960@9FEL92!F86EL
M960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$T.2!E9&ET+G!H<#HQ
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960N
M(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@
M(D5N=')Y('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("(E<R#4WMKC
MW-7=XM[B(-4@X^'?U>C=WB#8W-_>X.+8X-#=(@H*(SH@;&EB+V%P:2YP:'`Z
M-#$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96%R8VAI
M;F<@=&AE(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`BO=7<T"#0U.#5X=#@
M(-+>(-K>^"#5(-3>U]+>V]7=WB#7T-_8Z./2T/K5+B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z-B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C0Q"FUS9VED(")%>'!O<G0B"FUS9W-T<B`BM=KAW][@XMC@T/@B"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*(RP@9G5Z>GD*;7-G:60@
M(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`BM=KAW][@XMC@T/@@T-3@
MU>'0X"(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@
M(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP
M;W)T('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H<#HR,C@@9&%T82YP
M:'`Z,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY,`HC.B!B<F]W<V4N
M<&AP.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@
M8F]O:SH@)7,B"FUS9W-T<B`BO=4@W-[6T-P@U-`@W^#5T=#@X]+0W"#?WB#4
MV.#5VN+>X-CCW-[B("5S(@H*(SH@8G)O=W-E+G!H<#HQ,SD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S
M(@IM<V=S='(@(KW5(-S>UM#<(-30(-_@U='0X./2T-P@W]X@U-C@U=KBWN#8
MX]S>XB`E<R(*"B,Z(&)R;W=S92YP:'`Z,C<R"FUS9VED(")&86EL960@=&\@
M8G)O=W-E(&QI<W0B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HS,3`*(RP@
M9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R>2(*
M;7-G<W1R("*]U2#<WM;0W"#4T"#?X-71T.#CTM#<(-_>(-38X-7:XM[@V./<
MWN(@)7,B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L
M9"!$3B`]("5S+"!.97<@1$X@/2`E<RP@4F]O="`]("5S(@IM<V=S='(@(B(*
M"B,Z(&)R;W=S92YP:'`Z,3(P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@9FEN9"!O8FIE8W0@=&\@8F4@861D960Z("5S(@IM<V=S
M='(@(KW5(-S>UM#<(-30(-_@U='0X./2T-P@W]X@U-C@U=KBWN#8X]S>XB`E
M<R(*"B,Z('-E87)C:"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T
M;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("*]U2#<WM;0W"#4
MT"#?X-71T.#CTM#<(-_>(-38X-7:XM[@V./<WN(@)7,B"@HC.B!D871A+G!H
M<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T
M:&4@9&ER96-T;W)Y.B`E<R(*;7-G<W1R("*]U2#<WM;0W"#4T"#?X-71T.#C
MTM#<(-_>(-38X-7:XM[@V./<WN(@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-C<*;7-G:60@(D9A>"(*;7-G<W1R("+$T-KA(@H*(SH@
M961I="YP:'`Z,3(T(&1I<W!L87DN<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B
M1FEL97,B"FUS9W-T<B`BO=#AV][2(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S
M96%R8V@N:6YC.C<P"FUS9VED(")&:6YD(@IM<V=S='(@(K'0X-#X(@H*(SH@
M961I="YP:'`Z.3<@961I="YP:'`Z,3@W"B,L(&9U>GIY"FUS9VED(")&:6YI
M<V@B"FUS9W-T<B`BL=#@T/@B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HT.`IM<V=I9"`B1FER<W0@3F%M92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,#(*;7-G:60@(D9R965B=7-Y(%52
M3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z
M.#,*;7-G:60@(D9R;VTB"FUS9W-T<B`BOM0B"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HV,#0*(RP@9G5Z>GD*;7-G:60@(D=L;V)A;"!!9&1R97-S
M($)O;VLB"FUS9W-T<B`BM=KAW][@XMC@T/@@T-3@U>'0X"(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O<F]W+FEN8SHT,R!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C0T"FUS9VED(")'<F]U<"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(K3>W-#HW=`@T-3@U>'0(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z.3,*;7-G:60@(DAO;64@0VET>2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#@*(RP@9G5Z>GD*;7-G
M:60@(DAO;64@0V]U;G1R>2(*;7-G<W1R("*TWMS0Z-7=(.+5V]7DWMTB"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G:60@(DAO;64@
M4&AO;F4B"FUS9W-T<B`BM-[<T.C5W2#BU=O5Y-[=(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3`S"B,L(&9U>GIY"FUS9VED(")(;VUE(%!O
M<W1A;"!#;V1E(@IM<V=S='(@(K3>W-#HU=T@XM7;U>3>W2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED(")(;VUE
M(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(K3>W-#HU=T@XM7;U>3>W2(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"B,L(&9U>GIY"FUS9VED
M(")(;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(K3>W-#HW=`@T-3@U>'0
M(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-3`V"FUS9VED("))35-0
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-PIM<V=I
M9"`B24U34"!!9&1R97-S($)O;VL@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D<F5S<R!";V]K+"!3=&5P("5D
M(@IM<V=S='(@(KC<W][@XMC@T/@@T-3@U>'0X"(*"B,Z(&1A=&$N<&AP.C,V
M,0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS
M(@IM<V=S='(@(KC<W][@XB^UVN'?WN#B(-W0(-#4X-7AT.`B"@HC.B!L:6(O
M87!I+G!H<#HU.38@;&EB+V%P:2YP:'`Z-C@S"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED($E$(@IM<V=S='(@(KC<U>+>(-W5(-4@TM#;V-3=WBXB"@HC.B!L
M:6(O87!I+G!H<#HR,S`@;&EB+V%P:2YP:'`Z-#`R(&QI8B]A<&DN<&AP.C0X
M-B!L:6(O87!I+G!H<#HU.3(*(SH@;&EB+V%P:2YP:'`Z-C<Y(&QI8B]A<&DN
M<&AP.C<S,2!L:6(O87!I+G!H<#HQ,#<W"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R("*PU.#5X=#@WN(@U2#=U=+0V]C4
MU=TB"@HC.B!L:6(O87!I+G!H<#HQ,#@Q(&QI8B]A<&DN<&AP.C$Q-30@;&EB
M+V%P:2YP:'`Z,3(P-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!E;6%I;"(*
M;7-G<W1R("*PU.#5X=#BT"#=U2#5(-+0V]C4W=`B"@HC.B!L:6(O87!I+G!H
M<#HQ,#@Y"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&5N=')Y(@IM<V=S='(@
M(KC<U>+>(-W5(-4@TM#;V-3=WBXB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C(V-@IM<V=I9"`B26YV86QI9"!K97D@<W!E8VEF:65D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HQ,#@U"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M(&YA;64B"FUS9W-T<B`BN-S5XMX@W=4@U2#2T-O8U-W>+B(*"B,Z(&QI8B]A
M<&DN<&AP.C<S-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O8FIE8W1)9"(*
M;7-G<W1R("*XW-7BWB#=U2#5(-+0V]C4W=XN(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D
M(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X
M"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C4S"B,L(&9U>GIY"FUS9VED("),87-T($YA
M;64B"FUS9W-T<B`BN-S5(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?
M:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<W"FUS9VED(")-871C:&EN9R(*
M;7-G<W1R("+!U2#?WMK;WM_CTM`B"@HC.B!L:6(O87!I+G!H<#HR,#4*;7-G
M:60@(DUA>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M
M8F5R(&]F('!A9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE
M;G4N<&AP.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6EN:7-E87)C:"YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B36EN:2!3
M96%R8V@B"FUS9W-T<B`BO^#5T=#@X]+0^"(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,S`R"FUS9VED(")-:7-S:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$V,@HC+"!F=7IZ>0IM<V=I9"`B36]B:6QE(%!H;VYE(@IM
M<V=S='(@(K3>W-#HU=T@XM7;U>3>W2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,S,R(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*
M;7-G:60@(DUO9&EF>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$Y,PIM<V=I9"`B36]R92!T:&%N(#$@96YT<GD@9F]U
M;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHQ,0IM<V=I9"`B36]V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S+W!R969S+V%D
M9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*;7-G:60@(DUO=F4@;&5F="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR
M-#D*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ
M.#8*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z
M-3(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(K7:X=_>X.+8X-#X
M(-#4X-7AT.`B"@HC.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL
M(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I9R]S
M;W5R8V5S+G!H<"YD:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S
M<R!";V]K(@IM<V=S='(@(KC<W][@XMC@T/@@T-3@U>'0X"(*"B,Z(&%D9')E
M<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S($)O
M;VMS(@IM<V=S='(@(K7:X=_>X.+8X-#X(-#4X-7AT.`B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`BN-S5(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED(").86UE($9O<FUA="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HS,34*;7-G:60@(DYE
M=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&%D9"YP
M:'`Z,S8@861D+G!H<#HQ,C0@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C(W
M"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(W"B,L(&9U>GIY"FUS9VED
M(").97<@0V]N=&%C="(*;7-G<W1R("*TWM30U-@@W=[2(-K>W>+0VN(B"@HC
M.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY-2!E9&ET+G!H<#HR,#(@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHT-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*(RP@9G5Z>GD*
M;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(KC<U2(*"B,Z(&QI8B]A<&DN<&AP
M.C$Q.34@;&EB+V%P:2YP:'`Z,3(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R`E<R!E;G1R>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,3$V,PHC+"!F=7IZ>0IM<V=I9"`B3F\@861D<F5S<R!B;V]K<R!F
M;W5N9"XB"FUS9W-T<B`BLMX@T-3@U>'0X-[B(-W5(-S>UM4@U-`@X=4@U]#?
MV.CCTM`@(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#,*;7-G:60@(DYO(&-O;G1A
M8W1S(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C4Q,2!L:6(O
M87!I+G!H<#HW-C8*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-PHC
M+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R("*WT-'5V]7HVM@B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM
M<V=S='(@(K?0T=7;U>C:V"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,34*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HV,30@;&EB+V%P:2YP:'`Z-S0W"FUS9VED(")/
M8FIE8W0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N
M8V4@>6]U('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O
M:R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@
M;F]T('=H870@>6]U('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@
M<V5L96-T:6]N("(*(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HW-S0*;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C0Y-2!L:6(O87!I+G!H<#HV,#4@;&EB+V%P:2YP:'`Z-CDR(&QI8B]A<&DN
M<&AP.CDS-`HC.B!L:6(O87!I+G!H<#HQ,#DX"FUS9VED(")097)M:7-S:6]N
M($1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HU-#,*;7-G
M:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.CDY"FUS9VED(")097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HU,R!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$W"B,L(&9U>GIY"FUS9VED(")0:6YE($%D9')E<W,@0F]O:R(*;7-G
M<W1R("*XW-_>X.+8X-#X(-#4X-7AT.`B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+VIA=F%S8W)I<'0N:6YC.C(X"FUS9VED(")0;&5A<V4@;F%M92!T:&4@;F5W
M(&-O;G1A8W0@;&ES=#HB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z.3$@961I
M="YP:'`Z.30@961I="YP:'`Z,3DT"FUS9VED(")0<F5V:6]U<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HT,38*(RP@9G5Z>GD*
M;7-G:60@(E!R:79A=&4@061D<F5S<R!";V]K(@IM<V=S='(@(K7:X=_>X.+8
MX-#X(-#4X-7AT.`B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")1=65R>2!F86EL960Z("@E<RD@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"B,L
M(&9U>GIY"FUS9VED(")1=6EC:R!396%R8V@B"FUS9W-T<B`BO^#5T=#@X]+0
M^"(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,3DY(&QI8B]$<FEV97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E860@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]296YD97)E<BYP:'`Z-#D*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI
M<R!C;VYT86-T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O
M;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D<R!D:7-P;&%Y960Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z
M,3<V"B,L(&9U>GIY"FUS9VED(")296UO=F4@861D<F5S<R!B;V]K(@IM<V=S
M='(@(KC<W][@XMC@T/@@T-3@U>'0X"(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(S.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G
M:60@(E)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C(Q"FUS9VED("(B"B)297!L86-E(&5X
M:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I;7!O<G1E9"!O;F4_(#QS
M=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E;G1R:65S(&EN
M('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN/"]S=')O;F<^(@IM<V=S='(@
M(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C0S.`IM<V=I9"`B4F5Q=65S=&5D(&]B
M:F5C="!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z,S<@=&5M
M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q,PIM<V=I9"`B4F5S970@=&\@
M1&5F875L=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I9FEC871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@
M(B(*"B,Z(&5D:70N<&AP.CDY(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S='(@(K?0Y^/2T/@B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.38@=&5M<&QA=&5S
M+V)R;W=S92]S96%R8V@N:6YC.C$Q,@HC.B!T96UP;&%T97,O8FQO8VLO;6EN
M:7-E87)C:"YI;F,Z,C$@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z-#D*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(K_@U='0X./2T/@B"@HC.B!M:6YI<V5A<F-H+G!H<#HV,PHC+"!F=7IZ
M>0IM<V=I9"`B4V5A<F-H(%)E<W5L=',Z(@IM<V=S='(@(L#5U^/;XM#BV"#>
MU"#?X-71T.#CTM#ZU>+>(@H*(SH@;&EB+V%P:2YP:'`Z,3`Q,0HC+"!F=7IZ
M>0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R("*_X-71T.#CTM#X(@H*
M(SH@;&EB+V%P:2YP:'`Z,3$P,R!L:6(O87!I+G!H<#HQ,3`Y(&QI8B]A<&DN
M<&AP.C$Q,3@@;&EB+V%P:2YP:'`Z,3$S,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(E-E87)C
M:&EN9RXN+B(*;7-G<W1R("*_X-71T.#CTM#X(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-C8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A
M9&1R97-S(&)O;VL@=&\@9&5L971E(@IM<V=S='(@(K+5(-S>V]C<U2#>U-'5
MX-7BU2#0U.#5X=#@(-+>(-K>^"#\U2#3V"#AW-7AXMCBU2#:WMWBT-KBW=CB
MU2#?WM30XM[FV"XB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY
M,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E
M9&ET(@IM<V=S='(@(K+5(-S>V]C<U2#>U-'5X-7BU2#0U.#5X=#@(-+>(-K>
M^"#\U2#3V"#AW-7AXMCBU2#:WMWBT-KBW=CBU2#?WM30XM[FV"XB"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T
M<B`BOM31U>#8(-[4(-K0U-4@_-4@U=KAW][@XMC@T.@Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.B(*;7-G<W1R("*^T=7@
MV"#4U>'BV-W0YMCXT"#7T"#8W-_>X.+8X-#ZU3HB"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C,U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE
M(&-H87)S970@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("*^U-'5X-@@
MWM0@VM#4U2#\U2#5VN'?WN#BV.#0Z#HB"@HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&5X<&]R
M="!F;W)M870Z(@IM<V=S='(@(K[4T=7@V"#>U"#:T-35(/S5(-7:X=_>X.+8
MX-#H.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#,*;7-G:60@
M(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(K[1U>#8(-/>
M(-3>VN/<U=WBWN(@TMX@VM[X(/S5(-C<W][@XMC@T.@Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M('1H92!F;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("*^U-'5
MX-@@T]X@Y-[@W-#BWN(@U]`@U=KAW][@XCHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&9O<FUA
M="!U<V5D('1O(&1I<W!L87D@;F%M97,Z(@IM<V=S='(@(K[4T=7@V"#3WB#D
MWN#<T.+>XB#7T"#8W-_>X.(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L
M('-O<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-E;&5C="!W
M:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@;F%M
M97,N(@IM<V=S='(@(K[4T=7@V"#3WB#DWN#<T.+>XB#7T"#8W-_>X.(Z(@H*
M(SH@861D+G!H<#HU-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5L
M96-T960@861D<F5S<R!B;V]K(%PB)7-<(BXB"FUS9W-T<B`BL-3@U>'0X-[B
M(-4@W=72T-O8U-7=(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3<S
M"B,L(&9U>GIY"FUS9VED(")3:&%R960@1&ER96-T;W)Y(@IM<V=S='(@(K38
MX-7:XM[@V./<(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H;W<@
M06QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z-#`*;7-G:60@(E-H;W<@0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B4VAO=R!,:7-T
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D
M97)S+FEN8SHR,0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS9W-T
M<B`BM-C@U=KBWN#8X]PB"@HC.B!L:6(O87!I+G!H<#HQ.3@*(RP@9G5Z>GD*
M;7-G:60@(E-O=7)C97,B"FUS9W-T<B`BP^'?U>C=WB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-3<*;7-G:60@(E-P96-I9GD@=VAE<F4@>6]U('=A
M;G0@861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R+B(*;7-G<W1R
M("(B"@HC.B!B<F]W<V4N<&AP.C$T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@8G)O
M=W-E+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&-R96%T960@=&AE(&-O;G1A8W0@;&ES="!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&1A=&$N<&AP.C4P"FUS9VED(")44U8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-"!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$T"FUS9VED(")486(@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R
M("(B"@HC.B!V:65W+G!H<#HQ-0IM<V=I9"`B5&AE(%9&4R!B86-K96YD(&YE
M961S('1O(&)E(&-O;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L
M;V%D<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`U-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@861D<F5S<V)O;VMS+G!H<#HT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<
M(B!W87,@8W)E871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&%D
M9')E<W-B;V]K<RYP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D
M9')E<W,@8F]O:R!<(B5S7"(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S`S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T
M(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-#<@=F-A
M<F0N<&AP.C(R(&1I<W!L87DN<&AP.C(S('9I97<N<&AP.C(V"FUS9VED(")4
M:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("(B"@HC.B!E9&ET+G!H<#HQ,38*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!F:6QE(%PB)7-<(B!H87,@<W5C8V5S<V9U;&QY(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B)7,@U-[:X]S5W>+>XB#5(./AW]7HW=X@V-S?
MWN#BV.#0W2(*"B,Z(&1A=&$N<&AP.C(X-`IM<V=I9"`B5&AE(&EM<&]R="!C
M86X@8F4@9FEN:7-H960@9&5S<&ET92!T:&4@=V%R;FEN9W,N(@IM<V=S='(@
M(B(*"B,Z(&)R;W=S92YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R
M92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@(KW5W-`@
MT-3@U>'0X"#2WB#:WO@@U2#4WM?2WMO5W=X@U]#?V.CCTM#ZU2XB"@HC.B!A
M9&0N<&AP.C(Y"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!A<F4@;F\@=W)I
M=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A
M9&1R97-S(&)O;VMS("(*(F%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T
M;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI
M<R`B"B)I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBO=C5U-7=(-[4(-#4X-7AT.#8
MXM4@W=4@U2#?WM35X=7=(-?0(-+>TM74X]+0^M4@W=[2V"#AXM#2VM@N(+#:
MWB#<V.';V.+5("(*(M35VM`@X=4@X-#1WN+8(-?0(-/@U>C:T"P@TM4@W-[;
MV-S5(-K>W>+0VN+8X-#XXM4@X=X@TM#HV-[B(-#4W-C=V.'BX-#BWN`N(@H*
M(SH@861D+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!A9&1I;F<@=&AE(&YE=R!C;VYT86-T+B!#;VYT86-T('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@(@HB9F]R(&9U<G1H97(@:&5L<"XB"FUS
M9W-T<B`B(@HBO=#AXM#=T"#3X-7HVM`@W^#8(-3>U-#2T/K5(-W0(-[1^-7:
MXM[B+B"ZWMWBT-KBV.#0^.+5(.'>(-+0Z-C>XB`B"B+0U-S8W=CAXN#0XM[@
M(-?0(-_>W=#BT-S>Z-W8(-C=X>+@X]KFV-@N(@H*(SH@8G)O=W-E+G!H<#HQ
M.#D@8G)O=W-E+G!H<#HR,S`*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!A9&1I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(KW0X>+0W=`@
MT^#5Z-K0(-_@V"#8W-_>X.+8X-#ZU>+>(-W0(-_>U-#BWN;8XM4N(@H*(SH@
M8G)O=W-E+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R("*]T.'BT-W0(-/@
MU>C:T"#?X-@@V-S?WN#BV.#0^M7BWB#=T"#?WM30XM[FV.+5+B(*"B,Z(&%D
M9')E<W-B;V]K<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D9')E<W,@8F]O
M:SH@)7,B"FUS9W-T<B`BO=#AXM#=T"#3X-7HVM`@TMX@V-S?WN#BV.#0^M7B
MWB#=T"#AV-S=T.+8WMT@U-[:X]S5W>(N(@H*(SH@8G)O=W-E+G!H<#HQ-#<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D96QE=&EN9R!<(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`BO=#AXM#=T"#3X-7HVM`@TMX@V-S?WN#BV.#0^M7BWB#=
MT"#AV-S=T.+8WMT@U-[:X]S5W>(N(@H*(SH@9&5L971E+G!H<#HS-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`BO=#AXM#=T"#3X-7H
MVM`@W^#8(-C<W][@XMC@T/K5XMX@W=`@W][4T.+>YMCBU2XB"@HC.B!B<F]W
M<V4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(KW0X>+0W=`@T^#5Z-K0
M(-_@V"#8W-_>X.+8X-#ZU>+>(-W0(-_>U-#BWN;8XM4N(@H*(SH@8G)O=W-E
M+G!H<#HR-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H92!L:7-T(@IM<V=S='(@(KW0X>+0W=`@T^#5Z-K0(-_@
MV"#8W-_>X.+8X-#ZU>+>(-W0(-_>U-#BWN;8XM4N(@H*(SH@9&%T82YP:'`Z
M,S,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R("*]T.'BT-W0
M(-/@U>C:T"#?X-@@V-S?WN#BV.#0^M7BWB#=T"#?WM30XM[FV.+5+B(*"B,Z
M(&QI8B]A<&DN<&AP.C4P-R!L:6(O87!I+G!H<#HW-C$*(RP@9G5Z>GD*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R("*]T.'BT-W0(-/@U>C:T"#?X-@@V-S?WN#BV.#0
M^M7BWB#=T"#?WM30XM[FV.+5+B(*"B,Z(&)R;W=S92YP:'`Z-3@*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!A(&-O;G1A
M8W0@9G)O;2!T:&4@;&ES="XB"FUS9W-T<B`BO=#AXM#=T"#3X-7HVM`@W^#8
M(-C<W][@XMC@T/K5XMX@W=`@W][4T.+>YMCBU2XB"@HC.B!A9&1R97-S8F]O
M:W,N<&AP.C4U(&%D9')E<W-B;V]K<RYP:'`Z-C`@861D<F5S<V)O;VMS+G!H
M<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R
M("*]T.'BT-W0(-/@U>C:T"#2WB#8W-_>X.+8X-#ZU>+>(-W0(.'8W-W0XMC>
MW2#4WMKCW-7=XBXB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C@Q(&%D9')E<W-B
M;V]K<RYP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B
M"FUS9W-T<B`BO=#AXM#=T"#3X-7HVM`@TMX@V-S?WN#BV.#0^M7BWB#=T"#A
MV-S=T.+8WMT@U-[:X]S5W>(N(@H*(SH@961I="YP:'`Z,34X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AI<R!E;G1R>3H@)7,B"FUS9W-T<B`BO=#AXM#=T"#3X-7HVM`@W^#8
M(-C<W][@XMC@T/K5XMX@W=`@W][4T.+>YMCBU2XB"@HC.B!D871A+G!H<#HQ
M-SD*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=E<F4@;F\@861D<F5S<V5S('1O
M(&5X<&]R="XB"FUS9W-T<B`BO=7<T"#0U.#5X=#@(-+>(-K>^"#5(-3>U]+>
MV]7=WB#7T-_8Z./2T/K5+B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S
M8F]O:W-E;&5C="YI;F,Z,3@P"FUS9VED(")4:&5S92!A9&1R97-S(&)O;VMS
M('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#,*;7-G:60@(E1H
M97-E(&-O;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C(V.0IM<V=I9"`B5&AI<R!F:6QE(&9O<FUA
M="!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ,3(R(&QI8B]A<&DN<&AP.C$Q,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@
M=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("*[V.?=WN'BT"#5(-+5_-4@TMW5
MX=7=T"#2WB#2T.C8WN(@T-3@U>'0X"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30W"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@
M861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T
M<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M-S`*;7-G:60@(E1I=&QE(@IM<V=S='(@(KW0X=O>TB(*"B,Z(&QI8B]4=7)B
M82YP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@;F5W('-H87)E+B`@36ES<VEN9R!S;W5R8V4@='EP92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T1R:79E<BYP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R
M("*]U2#<WM;0W"#4T"#3V"#?X-[GV.+0W"#8W>3>X-S0YMC8XM4@U]`@)7,N
M(@H*(SH@961I="YP:'`Z.#@@961I="YP:'`Z.3$@961I="YP:'`Z.30@961I
M="YP:'`Z.3D@961I="YP:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")5;F1O($-H
M86YG97,B"FUS9W-T<B`BM]#GX]+0^"#3V"#?X-[<U=W8XM4B"@HC.B!L:6(O
M87!I+G!H<#HU-#`@;&EB+V%P:2YP:'`Z-C0S(&QI8B]A<&DN<&AP.C<W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z
M("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,W
M-@HC+"!F=7IZ>0IM<V=I9"`B5F5R:7-I9VX@1&ER96-T;W)Y(@IM<V=S='(@
M(K38X-7:XM[@V./<(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$Y
M('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@;6EN:7-E
M87)C:"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(E9I97<@0V]N=&%C="(*;7-G
M<W1R("*TWM30U-@@W=[2(-K>W>+0VN(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(T"FUS9VED(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`X
M"FUS9VED(")796)S:71E(%523"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,3,*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G
M<W1R("*PU.#5X=`@W=`@X-#1WN+0(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3(T"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED
M(")7;W)K($-O=6YT<GDB"FUS9W-T<B`BPM7;U>3>W2#=T"#@T-'>XM`B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O<FL@
M4&AO;F4B"FUS9W-T<B`BPM7;U>3>W2#=T"#@T-'>XM`B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E=O<FL@
M4&]S=&%L($-O9&4B"FUS9W-T<B`BPM7;U>3>W2#=T"#@T-'>XM`B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*(RP@9G5Z>GD*;7-G:60@
M(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`BPM7;U>3>W2#=T"#@T-'>
MXM`B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3D*(RP@9G5Z
M>GD*;7-G:60@(E=O<FL@4W1R965T($%D9')E<W,B"FUS9W-T<B`BL-3@U>'0
M(-W0(.#0T=[BT"(*"B,Z(&1A=&$N<&AP.C(S-R!B<F]W<V4N<&AP.CDS(&)R
M;W=S92YP:'`Z,C`Q(&%D9"YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&-O
M;G1A8W1S(&EN(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-CD@
M9&ES<&QA>2YP:'`Z-3@@=FEE=RYP:'`Z,S8*;7-G:60@(EEO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R
M("(B"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-34*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C,*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(*;7-G<W1R("(B
M"@HC.B!E9&ET+G!H<#HS,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE
M87-T(&]N92!C;VYT86-T(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z-#D*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R
M:7!T+FEN8SHW,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N
M92!E;G1R>2!F:7)S="XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-S,*;7-G
M:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N
M=&%C="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR.#4*;7-G:60@(EEO
M=7(@9&5F875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHV('1E;7!L
M871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@(EMN;R!V86QU
M95TB"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#0*;7-G:60@(E]"
M<F]W<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHT,`IM<V=I9"`B7T-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@HC+"!F=7IZ>0IM<V=I9"`B7T1E
M;&5T92(*;7-G<W1R("*XU]'@V.C8(@H*(SH@;&EB+U1U<F)A+G!H<#HT.3,*
M(RP@9G5Z>GD*;7-G:60@(E]);7!O<G0O17AP;W)T(@IM<V=S='(@(KC<W][@
MXB^UVN'?WN#B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS
M.0IM<V=I9"`B7TQI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z
M-#@Q"B,L(&9U>GIY"FUS9VED(")?37D@061D<F5S<R!";V]K<R(*;7-G<W1R
M("*XW-_>X.+8X-#X(-#4X-7AT.`B"@HC.B!L:6(O5'5R8F$N<&AP.C0X-PHC
M+"!F=7IZ>0IM<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S='(@(K3>U-#4V"#=
MWM(@VM[=XM#:XB(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,@IM<V=I9"`B7U)E;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O5'5R8F$N<&AP.C0X.0HC+"!F=7IZ>0IM<V=I9"`B7U-E87)C:"(*
M;7-G<W1R("*_X-71T.#CTM#X(@H*(SH@=F-A<F0N<&AP.C0V"FUS9VED(")C
M;VYT86-T+G9C9B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP
M:'`Z,C`T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N
M=&%C=',N8W-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B
M8V]N=&%C=',N='-V(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(Q.0IM<V=I
M9"`B8V]N=&%C=',N=F-F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I;7-P7V]P="YI;F,Z,S0*;7-G:60@(FYO;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR-`IM<V=I9"`B=&\@82!#
M;VYT86-T($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B=&\@82!D:69F97)E;G0@
M061D<F5S<R!";V]K(@IM<V=S='(@(K7:X=_>X.+8X-#X(-#4X-7AT.`B"@HC
M.B!D871A+G!H<#HU,2!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHQ,PHC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(G9#87)D(@IM<V=S='(@
M(B(*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+VQV7TQ6+G!O````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S$Q-3``,3`T,3<S
M-C(W-38`,#$W-30U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@3&%T=FEA;B!T<F%N<VQA=&EO;B!F;W(@5'5R8F$*(R!+
M87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^+"`R,#`R+@HC"FUS
M9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!4=7)B82`Q
M+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R+3$Q+3(Y(#$V.C`P*S`R
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2V%S<&%R<R!+87!E;FEE:W,@/&MA
M<W!A<G-`<F-C+FQV/EQN(@HB3&%N9W5A9V4M5&5A;3H@3&%T=FEA;B`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U-UQN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z-#(*;7-G:60@(B!!9&0@86X@24U3
M4"!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VEM<W!?;W!T+FEN8SHS,0IM<V=I9"`B($1E;&5T92!)35-0($%D9')E<W,@
M0F]O:R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&%L<F5A9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C;W!I960@8F5C875S92!I
M="!I<R!A(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO=F5D(&)E8V%U
M<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,W"FUS9VED(")<(D9I<G-T;F%M92!,87-T;F%M95PB("`H
M:64N($IO:&X@1&]E*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,V"FUS9VED(")<(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H:64N
M($1O92P@2F]H;BDB"FUS9W-T<B`B(@H*(SH@861D+G!H<#HQ,#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@861D960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N
M<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U8V-E<W-F
M=6QL>2!I;7!O<G1E9"(*;7-G<W1R(")F86EL<R`E<R!V96EK<VWN9VD@:65L
MXF3G=',B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O5'5R8F$N<&AP.C0T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-U(&=RXFUA='4@
M<V%R86MS=',B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#4*;7-G
M:60@(D$@8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.0IM
M<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T<B`B(@H*(SH@=FEE=RYP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C4V('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z,C(*;7-G:60@(D%D9"(*;7-G<W1R(")0:65V:65N;W0B
M"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W
M-`HC+"!F=7IZ>0IM<V=I9"`B061D(&%D9')E<W,@8F]O:R(*;7-G<W1R(").
M961E<NYG82!A9')E<W4@9W+B;6%T82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@
M861D<F5S<R!B;V]K<R(*;7-G<W1R(").878@<F5D:>SG:F%M=2!A9')E<W4@
M9W+B;6%T=2XB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN
M8SHR,S<*(RP@9G5Z>GD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B<&EE
M=FEE;F]T(&MO;&]N;G4B"@HC.B!E9&ET+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!F:6QE(@IM<V=S='(@(E!I979I96YO="!N96EZ9&5VXG,B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(R"B,L(&9U>GIY"FUS
M9VED(")!9&0@=&\B"FUS9W-T<B`B4&EE=FEE;F]T(@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z.#8*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@
M0F]O:R(*;7-G<W1R(")!9')E<W4@9W+B;6%T=2!S87)A:W-T<R(*"B,Z(&)R
M;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B
M061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B061R97-U(&=RXFUA='4@
M<V%R86MS=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z
M>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B061R97-U(&=RXFUA
M='4@<V%R86MS=',B"@HC.B!A9&0N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B
M061D<F5S<R!B;V]K(&5N=')Y(@IM<V=S='(@(D%D<F5S=2!G<N)M871A('!I
M965J86UA('1I:V%I(&QA<^[P86YA:2XB"@HC.B!D871A+G!H<#HS,#4*(RP@
M9G5Z>GD*;7-G:60@(D%D9')E<W,@8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D
M+B(*;7-G<W1R(")F86EL<R`E<R!V96EK<VWN9VD@:65LXF3G=',B"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV,@HC+"!F=7IZ>0IM<V=I9"`B
M061D<F5S<R!B;V]K('1O(&1E;&5T92`B"FUS9W-T<B`B061R97-U(&=RXFUA
M=&$@<&EE96IA;6$@=&EK86D@;&%S[O!A;F%I+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<P"FUS9VED(")!9&1R97-S
M(&)O;VMS('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R("(B
M"@HC.B!S96%R8V@N<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN
M8SHS-PIM<V=I9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(E-A<F7^[.YT
MXB!M96MLY_!A;F$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HV
M-`IM<V=I9"`B06QI87,B"FUS9W-T<B`B4V'N<VENXFIU;7,B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA+FEN8SHW('1E;7!L871E<R]B<F]W
M<V4O9F]O=&5R06QP:&$N:6YC.C$P"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z-#$*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HU-3(*;7-G:60@(D%L<F5A9'D@17AI<W1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L
M971E("5S/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C8W"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AE('-E;&5C=&5D(&5N=')I97,_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B07-C96YD:6YG
M(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z.#4@=&5M<&QA=&5S+V)R;W=S
M92]S96%R8V@N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")"87-I8R!396%R8V@B
M"FUS9W-T<B`B365K;.?P86YA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U.`IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O<FTB"FUS9W-T<B`B(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HW-R!L:6(O1')I=F5R+VQD87`N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W.`IM
M<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N
M:6YC.C<*;7-G:60@(D)R;W=S92(*;7-G<W1R(")0XG)L^VMO="(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@
M0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-#D*;7-G:60@(D-3
M5B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T+T=R;W5P+G!H<#HU-PIM<V=I
M9"`B0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHW"FUS9VED
M(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-#0*;7-G:60@(D-H;V]S92!A(&YA;64B"FUS9W-T
M<B`B(@H*(SH@861D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("+096ET(&YA=B!PXG)L^VMO:F%M=2!A
M9')E<W4@9W+B;6%T=2XB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L
M96-T+FEN8SHR,C$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A9&1R97-S
M(&)O;VLZ(@IM<V=S='(@(M!E:70@;F%V('#B<FS[:V]J86UU(&%D<F5S=2!G
M<N)M871U+B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C
M="YI;F,Z,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T
M;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED(")#:&]O<V4@=VAI8V@@
M861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R.`HC+"!F=7IZ>0IM<V=I9"`B
M0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@:6X@=VAA="!O
M<F1E<CHB"FUS9W-T<B`B27IVYVQI971I97,@:^)DXB!KXG)T[F+B(&MO;&]N
M;F%S('1I:W,@<&%RXF3N=&%S(&%D<F5S=2!S87)A:W-TXBXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D-O;'5M;B!/<'1I;VYS(@IM
M<V=S='(@(DMO;&]N;G4@;W!C:6IA<R(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@
M;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R
M"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E
M<&%R871E9"!V86QU97,@*$UI8W)O<V]F="!/=71L;V]K*2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW-@IM<V=I9"`B0V]M
M<&%N>2(*;7-G<W1R(")/<F=A;FEZXF-I:F$B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ-#0*(RP@9G5Z>GD*;7-G:60@(D-O;7!A;GD@061D
M<F5S<R(*;7-G<W1R(")-XFIA<R!A9')E<V4B"@HC.B!L:6(O87!I+G!H<#HS
M,3@@;&EB+V%P:2YP:'`Z,S8S(&QI8B]A<&DN<&AP.C0P-R!L:6(O87!I+G!H
M<#HT.3$*(SH@;&EB+V%P:2YP:'`Z-C`Q(&QI8B]A<&DN<&AP.C8X."!L:6(O
M87!I+G!H<#HW-#$@;&EB+V%P:2YP:'`Z.#$Y"B,Z(&QI8B]A<&DN<&AP.C$P
M,#8@;&EB+V%P:2YP:'`Z,3`Y-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N;F5C=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DEZ9'KG<W0@;F5I
M>F1E=N)S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`HC+"!F=7IZ>0IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(DEZ9'KG<W0@;F5I
M>F1E=N)S(@H*(SH@8G)O=W-E+G!H<#HQ.3$@8G)O=W-E+G!H<#HR,S(*;7-G
M:60@(D-O;G1A8W0@861D960@=&\@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O
M=W-E+G!H<#HV,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B
M0V]P>2(*;7-G<W1R(")/<F=A;FEZXF-I:F$B"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHU,PIM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C0P"B,L(&9U>GIY"FUS9VED
M(")#<F5A=&4@061D<F5S<R!";V]K(@IM<V=S='(@(D5K<W!O<G3G="!A9')E
M<W4@9W+B;6%T=2(*"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#
M<F5A=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L
M:6(O3V)J96-T5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z-S8@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHR"B,Z(&QI8B]/8FIE8W0N<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP
M.C0W(&QI8B]296YD97)E<BYP:'`Z-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R
M(")$>N=S="(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C4X"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@061D<F5S<R!";V]K(@IM<V=S='(@(D5K
M<W!O<G3G="!A9')E<W4@9W+B;6%T=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B
M=71T;VX@8F5H879I;W5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(DEZ9'KG<W0@;F5I>F1E=N)S(@H*
M(SH@9&5L971E+G!H<#HS.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S
M='(@(DEZ9'KG<W0@;F5I>F1E=N)S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*
M(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(DQI971O=.)J
M82!O<&-I:F%S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q
M.`IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V=S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y
M(@IM<V=S='(@(D5K<N)N82!O<&-I:F%S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")%:W+B;F$@;W!C:6IA<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D1O('EO=2!W
M86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T]B:F5C="YP:'`Z,CDW"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3<@=&5M<&QA=&5S
M+V)R;W=S92]C;VYT86-T<F]W+FEN8SHR-0IM<V=I9"`B1&]W;FQO860@=D-A
M<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M,3`R('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHR-0HC.B!T96UP;&%T97,O
M8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ,"!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C,*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W
M+FEN8SHS,R!L:6(O4F5N9&5R97(N<&AP.C0R"FUS9VED(")%9&ET(@IM<V=S
M='(@(E)E9&GLYW0B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4@
M=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B4F5D:>SG
M="`G)7,G(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*(RP@
M9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G<W1R(")%:W-P
M;W)TYW0@861R97-U(&=RXFUA='4B"@HC.B!E9&ET+G!H<#HW."!E9&ET+G!H
M<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!E;G1R>2!F;W(@)7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-3@*
M;7-G:60@(D5M86EL(@IM<V=S='(@(D4M<&%S=',B"@HC.B!E9&ET+G!H<#HQ
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960L
M(&)U="!S879I;F<@=&AE('5P;&]A9&5D(&9I;&4@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!E9&ET+G!H<#HQ-#D@961I="YP:'`Z,34R"B,L('!H<"UF
M;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+B(*;7-G<W1R("(B
M"@HC.B!B<F]W<V4N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")%;G1R>2!S=6-C
M97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B9F%I;',@)7,@=F5I:W-M[F=I
M(&EE;.)DYW1S(@H*(SH@;&EB+V%P:2YP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!S96%R8VAI;F<@=&AE(&%D9')E<W,@8F]O
M:SH@)7,B"FUS9W-T<B`B3F%V(')E9&GLYVIA;74@861R97-U(&=RXFUA='4N
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%
M:W-P;W)TYW0B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*(RP@
M9G5Z>GD*;7-G:60@(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`B16MS
M<&]R=.=T(&%D<F5S=2!G<N)M871U(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHR,0IM<V=I9"`B17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O
M;G1A8W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C(W"FUS9VED(")%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O
M;VL@8V]M<&QE=&5L>2XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3,T(&1A
M=&$N<&AP.C(R."!D871A+G!H<#HR.3<@8G)O=W-E+G!H<#HS-2!B<F]W<V4N
M<&AP.CDP"B,Z(&)R;W=S92YP:'`Z,3$R(&%D9"YP:'`Z-C<@<V5A<F-H+G!H
M<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%C
M8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(").96EZ9&5VXG,@
M<&EE:^_[="!N;W+B9.YT86IA:2!A9')E<W4@9W+B;6%T86DN(@H*(SH@8G)O
M=W-E+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!A9&0@)7,@=&\@)7,Z("5S(@IM<V=S='(@(DYE:7ID97;B<R`E<R!P
MXG)L^VMO\&%N82XB"@HC.B!B<F]W<V4N<&AP.C(W,@HC+"!F=7IZ>0IM<V=I
M9"`B1F%I;&5D('1O(&)R;W=S92!L:7-T(@IM<V=S='(@(DYE:7ID97;B<R`E
M<R!PXG)L^VMO\&%N82XB"@HC.B!B<F]W<V4N<&AP.C,Q,`HC+"!F=7IZ>0IM
M<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM<V=S='(@
M(DYE:7ID97;B<R!M96MLY_!A;F$@:V%T86QO9^(Z("5S(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HS,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@3F5W($1.
M(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&9I;F0@
M;V)J96-T('1O(&)E(&%D9&5D.B`E<R(*;7-G<W1R(").96EZ9&5VXG,@;65K
M;.?P86YA(&MA=&%L;V?B.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*(RP@9G5Z
M>GD*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*
M;7-G<W1R(").96EZ9&5VXG,@<&EE:^_[="!N;W+B9.YT86IA:2!A9')E<W4@
M9W+B;6%T86DN(@H*(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,B"FUS9W-T
M<B`B3F5I>F1E=N)S(&UE:VSG\&%N82!K871A;&]GXCH@)7,B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C<*;7-G:60@(D9A>"(*;7-G<W1R
M(")&86MS<R(*"B,Z(&5D:70N<&AP.C$R-"!D:7-P;&%Y+G!H<#HQ,#`*(RP@
M9G5Z>GD*;7-G:60@(D9I;&5S(@IM<V=S='(@(E9I<G-R86MS=',B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S`*;7-G:60@(D9I;F0B"FUS
M9W-T<B`B365K;.=T(@H*(SH@961I="YP:'`Z.3<@961I="YP:'`Z,3@W"B,L
M(&9U>GIY"FUS9VED(")&:6YI<V@B"FUS9W-T<B`B365K;.=T(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T($YA;64B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`R
M"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]S96%R8V@N:6YC.C@S"FUS9VED(")&<F]M(@IM<V=S='(@(DYO
M(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`T"B,L(&9U>GIY"FUS
M9VED(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@(D5K<W!O<G3G="!A
M9')E<W4@9W+B;6%T=2(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHT
M,R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C0T"FUS9VED(")'
M<F]U<"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DWB:F%S(&%D<F5S
M92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.CDS"FUS9VED(")(
M;VUE($-I='DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3`X"B,L(&9U>GIY"FUS9VED(")(;VUE($-O=6YT<GDB"FUS9W-T
M<B`B3>)J87,@=&5L969O;G,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ-3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B3>)J87,@=&5L
M969O;G,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*(RP@
M9G5Z>GD*;7-G:60@(DAO;64@4&]S=&%L($-O9&4B"FUS9W-T<B`B3>)J87,@
M=&5L969O;G,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`HC
M+"!F=7IZ>0IM<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R(")-
MXFIA<R!T96QE9F]N<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C@X"B,L(&9U>GIY"FUS9VED(")(;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S
M='(@(DWB:F%S(&%D<F5S92(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C4P-@IM<V=I9"`B24U34"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#<*(RP@9G5Z>GD*;7-G:60@(DE-4U`@061D<F5S<R!";V]K
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D<F5S=2!G<N)M871U('-A<F%K
M<W1S(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D<F5S<R!";V]K+"!3=&5P
M("5D(@IM<V=S='(@(DEM<&]R=.=T(&%D<F5S=2!G<N)M871U(@H*(SH@9&%T
M82YP:'`Z,S8Q"B,L(&9U>GIY"FUS9VED("));7!O<G0O17AP;W)T($%D9')E
M<W,@0F]O:W,B"FUS9W-T<B`B26UP;W)TYW0O16MS<&]R=.=T(&%D<F5S=2!G
M<N)M871A<R(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O87!I+G!H<#HV.#,*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`B3F5D97+N9W,@
M=N)R9',N(@H*(SH@;&EB+V%P:2YP:'`Z,C,P(&QI8B]A<&DN<&AP.C0P,B!L
M:6(O87!I+G!H<#HT.#8@;&EB+V%P:2YP:'`Z-3DR"B,Z(&QI8B]A<&DN<&AP
M.C8W.2!L:6(O87!I+G!H<#HW,S$@;&EB+V%P:2YP:'`Z,3`W-PHC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3F5D97+N
M9V$@861R97-U(&=RXFUA=&$N(@H*(SH@;&EB+V%P:2YP:'`Z,3`X,2!L:6(O
M87!I+G!H<#HQ,34T(&QI8B]A<&DN<&AP.C$R,#<*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@96UA:6PB"FUS9W-T<B`B3F5D97+N9V$@92UP87-T82!A9')E
M<V4N(@H*(SH@;&EB+V%P:2YP:'`Z,3`X.0HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!E;G1R>2(*;7-G<W1R(").961E<NYG<R!VXG)D<RXB"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C(V-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!K
M97D@<W!E8VEF:65D+B(*;7-G<W1R(").;W+B9.YT82!N961E<NYG82!VYW)T
M[F)A(@H*(SH@;&EB+V%P:2YP:'`Z,3`X-0HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!N86UE(@IM<V=S='(@(DYE9&5R[F=S(';B<F1S+B(*"B,Z(&QI8B]A
M<&DN<&AP.C<S-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O8FIE8W1)9"(*
M;7-G<W1R(").961E<NYG<R!VXG)D<RXB"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C,P"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T
M('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ,S@*;7-G
M:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-3,*(RP@9G5Z>GD*;7-G:60@(DQA<W0@3F%M92(*
M;7-G<W1R(")6XG)D<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C$V"FUS9VED("),:7-T(@IM<V=S='(@(E-A<F%K<W1S(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<W"FUS9VED(")-871C
M:&EN9R(*;7-G<W1R(")!=&)I;'-T;_!S(@H*(SH@;&EB+V%P:2YP:'`Z,C`U
M"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!#;VYT86-T<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED(")-87AI;75M
M(&YU;6)E<B!O9B!P86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=')E
M95]M96YU+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-96YU($QI<W0B"FUS9W-T
M<B`B4V%R86MS=',B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,PHC
M+"!F=7IZ>0IM<V=I9"`B36EN:2!396%R8V@B"FUS9W-T<B`B365K;.?P86YA
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI<W-I;F<@
M1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"B,L(&9U>GIY"FUS
M9VED(")-;V)I;&4@4&AO;F4B"FUS9W-T<B`B3>)J87,@=&5L969O;G,B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP
M.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.3,*;7-G:60@(DUO
M<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3$*;7-G:60@(DUO=F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0W"B,Z
M('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@T"B,L
M(&9U>GIY"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B<.)R=FEE=&]T('!A
M(&MR96ES:2(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(T.0HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC
M.C$X-@HC+"!F=7IZ>0IM<V=I9"`B36]V92!R:6=H="(*;7-G<W1R(")PXG)V
M:65T;W0@<&$@;&%B:2(*"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUU;&)E<G)Y($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")%:W-P;W)TYW0@861R97-U(&=RXFUA='4B"@HC
M.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(DUU
M;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL(&)U="!N;VYE('=I
M=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S<R!";V]K(@IM<V=S
M='(@(D%D<F5S=2!G<N)M871U('-A<F%K<W1S(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B"FUS
M9W-T<B`B061R97-U(&=RXFUA='4@<V%R86MS=',B"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`B5N)R9',B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T
M8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@861D+G!H
M<#HS-B!A9&0N<&AP.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*
M(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!#;VYT86-T(@IM<V=S='(@(E!I979I96YO="!J875N=2(*"B,Z(&5D
M:70N<&AP.C@X(&5D:70N<&AP.CDU(&5D:70N<&AP.C(P,B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q.`HC+"!F=7IZ>0IM<V=I
M9"`B3FEC:VYA;64B"FUS9W-T<B`B5N)R9',B"@HC.B!L:6(O87!I+G!H<#HQ
M,3DU(&QI8B]A<&DN<&AP.C$R-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M)7,@96YT<GD@9F]U;F0@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$Q-C,*(RP@9G5Z>GD*;7-G:60@(DYO(&%D9')E<W,@8F]O:W,@9F]U
M;F0N(@IM<V=S='(@(D%D<F5S=2!G<N)M871A('!I965J86UA('1I:V%I(&QA
M<^[P86YA:2XB"@HC.B!M:6YI<V5A<F-H+G!H<#HX,PIM<V=I9"`B3F\@8V]N
M=&%C=',@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-3$Q(&QI
M8B]A<&DN<&AP.C<V-@IM<V=I9"`B3F\@=D-A<F0@9&%T82!W87,@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHW
M"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(E!I97KN;65S(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3@T"FUS9VED(").;W1E<R(*
M;7-G<W1R(")0:65Z[FUE<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,34*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HV,30@;&EB+V%P:2YP:'`Z-S0W"FUS9VED(")/
M8FIE8W0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N
M8V4@>6]U('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O
M:R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@
M;F]T('=H870@>6]U('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@
M<V5L96-T:6]N("(*(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HW-S0*;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-@HC+"!F=7IZ>0IM<V=I9"`B3W1H97(@3W!T
M:6]N<R(*;7-G<W1R("),:65T;W3B:F$@;W!C:6IA<R(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-#DU(&QI8B]A<&DN<&AP.C8P
M-2!L:6(O87!I+G!H<#HV.3(@;&EB+V%P:2YP:'`Z.3,T"B,Z(&QI8B]A<&DN
M<&AP.C$P.3@*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.C4T,PIM<V=I9"`B4&5R;6ES<VEO;B!D96YI
M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M.3D*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP
M.C4S('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,3<*(RP@9G5Z>GD*;7-G
M:60@(E!I;F4@061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S=2!G<N)M871U
M('-A<F%K<W1S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN
M8SHR.`IM<V=I9"`B4&QE87-E(&YA;64@=&AE(&YE=R!C;VYT86-T(&QI<W0Z
M(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N
M<&AP.C$Y-`IM<V=I9"`B4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W-O=7)C97,N<&AP+F1I<W0Z-#$V"B,L(&9U>GIY"FUS9VED(")0<FEV871E
M($%D9')E<W,@0F]O:R(*;7-G<W1R(")%:W-P;W)TYW0@861R97-U(&=RXFUA
M='4B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")1=65R>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"B,L(&9U>GIY"FUS
M9VED(")1=6EC:R!396%R8V@B"FUS9W-T<B`B365K;.?P86YA(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HQ.3$@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3D@
M;&EB+T1R:79E<B]L9&%P+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+U)E;F1E
M<F5R+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR
M"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S8*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]V92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B26UP;W)T
MYW0@861R97-U(&=RXFUA='4B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR,SD*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB
M"FUS9W-T<B`B:7ID>N=S="!K;VQO;FYU(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHR"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0IM
M<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T
M:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L
M971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K
M+CPO<W1R;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*
M;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!A9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ
M,3,*;7-G:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U
M8FQI8R!#97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE
M9#H@*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY.2!A9&0N<&AP
M.C,W('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V
M92(*;7-G<W1R(")386=L86+B="(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A
M<F-H+FEN8SHY-B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$R"B,Z
M('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO
M=')E95]M96YU+G!H<#HT.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B365K;.?P86YA(@H*(SH@;6EN:7-E
M87)C:"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!297-U;'1S.B(*
M;7-G<W1R(")-96MLY_!A;F%S(')E>G5L=.)T:2(*"B,Z(&QI8B]A<&DN<&AP
M.C$P,3$*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!F86EL960B"FUS9W-T<B`B
M365K;.?P86YA(@H*(SH@;&EB+V%P:2YP:'`Z,3$P,R!L:6(O87!I+G!H<#HQ
M,3`Y(&QI8B]A<&DN<&AP.C$Q,3@@;&EB+V%P:2YP:'`Z,3$S,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C(*(RP@9G5Z>GD*
M;7-G:60@(E-E87)C:&EN9RXN+B(*;7-G<W1R(")-96MLY_!A;F$B"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B3/MD
M>G4@:7IVYVQI971I97,@861R97-U(&=RXFUA='4L(&MU<F%I('!I979I96YO
M="!I97)A:W-T=7,N(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M.3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@
M961I="(*;7-G<W1R("),^V1Z=2!I>G;G;&EE=&EE<R!A9')E<W4@9W+B;6%T
M=2P@:W5R86D@<&EE=FEE;F]T(&EE<F%K<W1U<RXB"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE
M(&%D9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T<B`B27IVYVQI
M971I97,@879O='4L(&YO(&MU<F$@:6UP;W)TYW0Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H
M92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.B(*;7-G<W1R("))>G;G;&EE
M=&EE<R!K=7(@:6UP;W)TYW0Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C:&%R<V5T(&]F
M('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B27IVYVQI971I97,@879O='4L
M(&YO(&MU<F$@:6UP;W)TYW0Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R
M;6%T.B(*;7-G<W1R("))>G;G;&EE=&EE<R!A=F]T=2P@;F\@:W5R82!I;7!O
M<G3G=#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0S"FUS9VED
M(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R("))>G;G;&EE
M=&EE<R!F86EL=2P@:V\@:6UP;W)TYW0Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!F;W)M
M870@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R("))>G;G;&EE=&EE<R!K
MXF3B(&9O<FWB=.(@96MS<&]R=.=T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S4*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S
M960@=&\@9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`B27IVYVQI971I97,@:^)D
MXB!F;W)MXG3B(&EM<&]R=.=T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B
M>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB
M"FUS9W-T<B`B27IVYVQI971I97,@<VMA='4L(&MO('!A<N)D[G0@;F]K;'5S
MYW1I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.`IM<V=I9"`B4V5L
M96-T('=H:6-H(&9I96QD<R!T;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI
M<W1S+B(*;7-G<W1R("))>G;G;&EE=&EE<R!K=7)U<R!L875K=7,@<N)D[G0@
M861R97-U('-A<F%K<W1O<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES
M<&QA>2!N86UE<RXB"FUS9W-T<B`B27IVYVQI971I97,@:W5R=7,@;&%U:W5S
M('+B9.YT(&%D<F5S=2!S87)A:W-T;W,N(@H*(SH@861D+G!H<#HU-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K
M(%PB)7-<(BXB"FUS9W-T<B`B3F5D97+N9V$@861R97-U(&=RXFUA=&$N(@H*
M(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3<S"B,L(&9U>GIY"FUS9VED
M(")3:&%R960@1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V=S(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3:&]W("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H;W<@06QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@(E-H;W<@
M0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHS.0IM<V=I9"`B4VAO=R!,:7-T<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHR,0HC.B!T96UP
M;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHS-`HC+"!F=7IZ>0IM
M<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS9W-T<B`B2V%T86QO9W,B"@HC.B!L
M:6(O87!I+G!H<#HQ.3@*(RP@9G5Z>GD*;7-G:60@(E-O=7)C97,B"FUS9W-T
M<B`B5F5I:W-M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3<*;7-G
M:60@(E-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V86YC960@<V5A<F-H(')E
M<W5L=',@=&\@87!P96%R+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$T
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@)7,@
M=&\@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR,C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A8W0@
M;&ES="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4P"FUS9VED
M(")44U8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$T"FUS9VED(")486(@
M<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R("(B"@HC.B!V:65W+G!H<#HQ-0IM
M<V=I9"`B5&AE(%9&4R!B86-K96YD(&YE961S('1O(&)E(&-O;F9I9W5R960@
M=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z,3`U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M861D<F5S<R!B;V]K(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M(@H*(SH@861D<F5S<V)O;VMS+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@8W)E871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S
M(')E;6]V960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S
M8F]O:W,N<&AP.C@Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S
M(&)O;VL@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T
M<B`B(@H*(SH@9&%T82YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@961I="YP:'`Z-#<@=F-A<F0N<&AP.C(R(&1I<W!L87DN<&AP
M.C(S('9I97<N<&AP.C(V"FUS9VED(")4:&4@8V]N=&%C="!Y;W4@<F5Q=65S
M=&5D(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HQ
M,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE(%PB)7-<
M(B!H87,@<W5C8V5S<V9U;&QY(&)E96X@9&5L971E9"XB"FUS9W-T<B`B9F%I
M;',@)7,@=F5I:W-M[F=I(&EE;.)DYW1S(@H*(SH@9&%T82YP:'`Z,C@T"FUS
M9VED(")4:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W
M87)N:6YG<RXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RXB"FUS9W-T
M<B`BT&5I="!N878@<.)R;/MK;VIA;74@861R97-U(&=RXFUA='4N(@H*(SH@
M861D+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@87)E(&YO('=R
M:71E86)L92!A9&1R97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@
M861D<F5S<R!B;V]K<R`B"B)A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@
M=&\@861D(&YE=R!E;G1R:65S('1O('1H96TN($EF('EO=2!B96QI979E('1H
M:7,@(@HB:7,@86X@97)R;W(L('!L96%S92!C;VYT86-T('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DYE=FEE;N(@;F\@;F]RXF3N
M=&%JXFT@861R97-U(&=RXFUA=.)M(&YA=B!I97-PYVIA;7,@<&EE=FEE;F]T
M(&EE<F%K<W1U<RXB"@HC.B!A9&0N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A8W0N
M($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B`B"B)F;W(@9G5R
M=&AE<B!H96QP+B(*;7-G<W1R(")+[_MD82!P:65V:65N;VIO="!O8FIE:W1U
M+B!387II;FEE=&EE<R!A<B!S:7-TYVUA<R!A9&UI;FES=')A=&]R=2XB"@HC
M.B!B<F]W<V4N<&AP.C$X.2!B<F]W<V4N<&AP.C(S,`HC+"!F=7IZ>0IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&ES(&]B:F5C="XB"FUS
M9W-T<B`B2^_[9&$@:6UP;W)TYVIO="!D871U<RXB"@HC.B!B<F]W<V4N<&AP
M.C(S.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T
M:6YG(&$@;F5W(&QI<W0N(@IM<V=S='(@(DOO^V1A(&EM<&]R=.=J;W0@9&%T
M=7,N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@
M861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")+[_MD82!I;7!O<G3G:F]T(&EE
M;.)DYW1O(&9A:6QU(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<
M(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M2^_[9&$@:6UP;W)TYVIO="!I96SB9.=T;R!F86EL=2(*"B,Z(&1E;&5T92YP
M:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S(@IM<V=S='(@(DOO
M^V1A(&EM<&]R=.=J;W0@9&%T=7,N(@H*(SH@8G)O=W-E+G!H<#HW,@HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@
M;V)J96-T+B(*;7-G<W1R(")+[_MD82!I;7!O<G3G:F]T(&1A='5S+B(*"B,Z
M(&)R;W=S92YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R(")+[_MD82!I;7!O
M<G3G:F]T(&1A='5S+B(*"B,Z(&1A=&$N<&AP.C,S-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@9&%T83H@)7,B"FUS9W-T<B`B2^_[9&$@:6UP;W)TYVIO="!D871U<RXB
M"@HC.B!L:6(O87!I+G!H<#HU,#<@;&EB+V%P:2YP:'`Z-S8Q"B,L(&9U>GIY
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82XB"FUS9W-T<B`B2^_[9&$@:6UP;W)TYVIO="!D871U<RXB
M"@HC.B!B<F]W<V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@<F5M;W9I;F<@82!C;VYT86-T(&9R;VT@=&AE(&QI<W0N(@IM
M<V=S='(@(DOO^V1A(&EM<&]R=.=J;W0@9&%T=7,N(@H*(SH@861D<F5S<V)O
M;VMS+G!H<#HU-2!A9&1R97-S8F]O:W,N<&AP.C8P(&%D9')E<W-B;V]K<RYP
M:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T
M<B`B2^_[9&$@:6UP;W)TYVIO="!I96SB9.=T;R!F86EL=2(*"B,Z(&%D9')E
M<W-B;V]K<RYP:'`Z.#$@861D<F5S<V)O;VMS+G!H<#HX-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")+[_MD82!I;7!O<G3G
M:F]T(&EE;.)DYW1O(&9A:6QU(@H*(SH@961I="YP:'`Z,34X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AI<R!E;G1R>3H@)7,B"FUS9W-T<B`B2^_[9&$@:6UP;W)TYVIO="!D
M871U<RXB"@HC.B!D871A+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(E1H97)E
M('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="XB"FUS9W-T<B`B3F%V(')E
M9&GLYVIA;74@861R97-U(&=RXFUA='4N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#`*;7-G:60@(E1H97-E(&%D9')E
M<W,@8F]O:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T,PIM
M<V=I9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E
M<CHB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED(")4:&ES(&9I
M;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$Q,C(@;&EB+V%P:2YP:'`Z,3$S-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E
M;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(M#N('!E<G-O;F$@
M:F%U(&ER(&K[<W4@861R97-U(&=RXFUA=.(N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T-PIM<V=I9"`B(@HB5&AI<R!W:6QL(&)E('1H92!D969A
M=6QT(&%D9')E<W,@8F]O:R!W:&5N(&%D9&EN9R!O<B!I;7!O<G1I;F<@8V]N
M=&%C=',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C<P"FUS9VED(")4:71L92(*;7-G<W1R(")6:7)S<F%K<W1S(@H*(SH@
M;&EB+U1U<F)A+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!N97<@<VAA<F4N("!-:7-S:6YG('-O=7)C92!T>7!E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HY-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M(@IM<V=S='(@(DYE=F%R(&EE;.)DYW0@)7,@9&5F:6[N8VEJ=2XB"@HC.B!E
M9&ET+G!H<#HX."!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HY
M.2!E9&ET+G!H<#HQ.38*(RP@9G5Z>GD*;7-G:60@(E5N9&\@0VAA;F=E<R(*
M;7-G<W1R(")386=L86+B="!I>FUA:?)A<R(*"B,Z(&QI8B]A<&DN<&AP.C4T
M,"!L:6(O87!I+G!H<#HV-#,@;&EB+V%P:2YP:'`Z-S<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"B,L(&9U>GIY
M"FUS9VED(")697)I<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9W,B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3D@=&5M<&QA=&5S+V)R
M;W=S92]C;VYT86-T<F]W+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!M:6YI<V5A<F-H+G!H<#HW.`HC
M+"!F=7IZ>0IM<V=I9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(E!I979I96YO
M="!J875N=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@
M(E9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R(")3:V%T[FIU
M;7,L(&MO('!A<N)D[G0@<.=C(&YO:VQU<^?P86YA<SHB"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HR,#@*;7-G:60@(E=E8G-I=&4@55),(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q,PIM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D1A<F)A(&%D<F5S92(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5V]R:R!#
M:71Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$S.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!#;W5N=')Y(@IM<V=S='(@(D1A
M<F)A('1E;&5F;VYS(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,34V"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(D1A<F)A('1E;&5F;VYS
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY
M"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S='(@(D1A<F)A('1E;&5F
M;VYS(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(Y"B,L(&9U
M>GIY"FUS9VED(")7;W)K(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(D1A<F)A
M('1E;&5F;VYS(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$Y
M"B,L(&9U>GIY"FUS9VED(")7;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@
M(D1A<F)A(&%D<F5S92(*"B,Z(&1A=&$N<&AP.C(S-R!B<F]W<V4N<&AP.CDS
M(&)R;W=S92YP:'`Z,C`Q(&%D9"YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(&-O;G1A8W1S(&EN(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z
M-CD@9&ES<&QA>2YP:'`Z-3@@=FEE=RYP:'`Z,S8*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G
M<W1R("(B"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V
M92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-34*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C,*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!E9&ET+G!H<#HS,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T
M(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C$W('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z-#D*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A
M<V-R:7!T+FEN8SHW,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T
M(&]N92!E;G1R>2!F:7)S="XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-S,*
M;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@
M8V]N=&%C="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR.#4*;7-G:60@
M(EEO=7(@9&5F875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHV('1E
M;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@(EMN;R!V
M86QU95TB"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#0*(RP@9G5Z
M>GD*;7-G:60@(E]"<F]W<V4B"FUS9W-T<B`B4.)R;/MK;W0B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"FUS9VED(")?0V]N=&%C=',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR
M"B,L(&9U>GIY"FUS9VED(")?1&5L971E(@IM<V=S='(@(D1ZYW-T(@H*(SH@
M;&EB+U1U<F)A+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@(E]);7!O<G0O17AP
M;W)T(@IM<V=S='(@(DEM<&]R=.=T+T5K<W!O<G3G="(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z>GD*;7-G:60@(E],:7-T
M<R(*;7-G<W1R(")387)A:W-T<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@Q"B,L
M(&9U>GIY"FUS9VED(")?37D@061D<F5S<R!";V]K<R(*;7-G<W1R(")!9')E
M<W4@9W+B;6%T=2!S87)A:W-T<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@W"B,L
M(&9U>GIY"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T<B`B4&EE=FEE;F]T
M(&IA=6YU(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS
M9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]4=7)B82YP:'`Z-#@Y"B,L(&9U>GIY"FUS9VED(")?4V5A<F-H(@IM<V=S
M='(@(DUE:VSG\&%N82(*"B,Z('9C87)D+G!H<#HT-@IM<V=I9"`B8V]N=&%C
M="YV8V8B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3DY(&1A=&$N<&AP.C(P
M-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(F-O;G1A8W1S
M+F-S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,#D*;7-G:60@(F-O;G1A
M8W1S+G1S=B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR,3D*;7-G:60@(F-O
M;G1A8W1S+G9C9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:6US
M<%]O<'0N:6YC.C,T"FUS9VED(")N;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C0*;7-G:60@(G1O(&$@0V]N=&%C
M="!,:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(G1O(&$@9&EF9F5R96YT($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")%:W-P;W)TYW0@861R97-U(&=RXFUA='4B"@HC
M.B!D871A+G!H<#HU,2!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHQ,PHC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$U('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z,34*;7-G:60@(G9#87)D(@IM<V=S='(@
M(B(*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]P;R]N;E].
M3RYP;P``````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#<Q-S0R`#$P-#$W,S8R-S4V`#`Q-S4T,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C(%1U<F)A($YO<G=E9VEA;B!.>6YO
M<G-K('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R(%!E<BU3=&EA
M;B!6871N90HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!4=7)B82!P86-K86=E+@HC(%!E<BU3=&EA
M;B!6871N92`\<'-V0&]R<W1A+F]R9SXL(#(P,#(N"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A(#(N,"UC=G-<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`R+3`V+3`X(#(R.C0T*S`Q,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@4&5R+5-T:6%N(%9A=&YE(#QP<W9`;W)S=&$N
M;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@3F]R=V5G:6%N($YY;F]R<VL@/&YY
M;F]R<VM`;W)S=&$N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB
M"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP
M;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C0R"FUS9VED("(@061D(&%N($E-
M4U`@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I;7-P7V]P="YI;F,Z,S$*;7-G:60@(B!$96QE=&4@24U34"!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I
M;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U<V4@
M:70@:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!M;W9E9"!B96-A
M=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@
M*&EE+B!*;VAN($1O92DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@*&EE
M+B!$;V4L($IO:&XI(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S
M9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B1FEL82`E<R!V87)T(&EM<&]R=&5R
M="(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHU"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]4=7)B82YP:'`Z-#0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E8F]K;&ES=&EN9R(*
M"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HT-0IM<V=I9"`B02!B<F]W
M<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Y"FUS9VED(")!8F]V
M92!S96%R8V@@9F]R;2(*;7-G<W1R("(B"@HC.B!V:65W+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('1O("5S(@IM<V=S='(@
M(B(*"B,Z(&%D9"YP:'`Z-38@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHR,@IM<V=I9"`B061D(@IM<V=S='(@(DQE9V<@=&EL(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S0*(RP@9G5Z>GD*
M;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B56=Y;&1I9R!A9')E
M<W-E8F]K+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.`HC+"!F=7IZ
M>0IM<V=I9"`B061D(&%N9"!$96QE=&4@24U34"!A9&1R97-S(&)O;VMS(@IM
M<V=S='(@(DEN9V5N(&%D<F5S<V5B^&ME<B!M960@<VMR:79E=&EL9V%N9RXB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B;&5G9R!T:6P@:V]L
M;VYN92(*"B,Z(&5D:70N<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B061D(&9I
M;&4B"FUS9W-T<B`B2W5N;F4@:6MK:F4@;&5G9V4@=&EL(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR,@HC+"!F=7IZ>0IM<V=I9"`B061D
M('1O(@IM<V=S='(@(DQE9V<@=&EL(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z.#8*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R(")!9')E<W-E8F]K;&ES=&EN9R(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B061D<F5S<R!";V]K($QI
M<W1I;F<B"FUS9W-T<B`B061R97-S96)O:VQI<W1I;F<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O
M:W,B"FUS9W-T<B`B061R97-S96)O:VQI<W1I;F<B"@HC.B!A9&0N<&AP.C$P
M.`HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K(&5N=')Y(@IM<V=S='(@
M(D%D<F5S<V5B;VMA(&5R(&)E<G)E(&QE<V)A<B(*"B,Z(&1A=&$N<&AP.C,P
M-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P
M=7)G960N(@IM<V=S='(@(E!I;F4M861R97-S96)O:R!V87)T(&EM<&]R=&5R
M="(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8R"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S(&)O;VL@=&\@9&5L971E("(*;7-G<W1R(")!9')E
M<W-E8F]K82!E<B!B97)R92!L97-B87(B"@HC.B!T96UP;&%T97,O<')E9G,O
M861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`IM<V=I9"`B061D<F5S<R!B;V]K
M<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@
M<V5A<F-H+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S<*
M;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R(")!=F%N<V5R="!S^&LB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HV-`IM<V=I9"`B06QI
M87,B"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E
M<D%L<&AA+FEN8SHW('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC
M.C$P"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@
M(D%L;"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HU-3(*;7-G:60@(D%L
M<F5A9'D@17AI<W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO
M=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8W"FUS9VED
M(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E
M;&5C=&5D(&5N=')I97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-@IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(B(*"B,Z('-E
M87)C:"YP:'`Z.#4@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,V"B,L
M(&9U>GIY"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B4_AK(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B0F5L;W<@<V5A<F-H
M(&9O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-R!L
M:6(O1')I=F5R+VQD87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(D)I
M;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*;7-G:60@(D)R;W=S92(*;7-G
M<W1R(")";&$@9VIE;FYO;2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS9W-T<B`B(@H*
M(SH@9&%T82YP:'`Z-#D*;7-G:60@(D-35B(*;7-G<W1R("(B"@HC.B!L:6(O
M3V)J96-T+T=R;W5P+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D(&$@9W)O=7`@
M=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O
M;'5M;E]H96%D97)S+FEN8SHW"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#0*;7-G
M:60@(D-H;V]S92!A(&YA;64B"FUS9W-T<B`B(@H*(SH@861D+G!H<#HT.`HC
M+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("));F=E;B!A9')E<W-E8OAK97(@=&EL9VIE;F=E;&5G(&9O<B!G:F5N;F]M
M<WEN:6YG+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(R,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:SHB
M"FUS9W-T<B`B26YG96X@861R97-S96+X:V5R('1I;&=J96YG96QE9R!F;W(@
M9VIE;FYO;7-Y;FEN9RXB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O
M;VMS96QE8W0N:6YC.C$V-0IM<V=I9"`B0VAO;W-E('=H:6-H(&%D9')E<W,@
M8F]O:W,@=&\@9&ES<&QA>2P@86YD(&EN('=H870@;W)D97(Z(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I9"`B0VAO;W-E
M('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C@*(RP@9G5Z>GD*
M;7-G:60@(D-H;V]S92!W:&EC:"!C;VQU;6YS('1O(&1I<W!L87D@86YD(&EN
M('=H870@;W)D97(Z(@IM<V=S='(@(E9E;"!R96MK96;X;&=J82!PY2!K;VQO
M;FYE;F4@<V]M('-K86P@=FES87-T(&D@861R97-S96QI<W1A+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B0V]L=6UN($]P=&EO;G,B
M"FUS9W-T<B`B06QT97)N871I=B!F;W(@:V]L;VYN92(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T
M:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$R"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3,*;7-G:60@
M(D-O;6UA('-E<&%R871E9"!V86QU97,@*$UI8W)O<V]F="!/=71L;V]K*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW-@IM
M<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$T-`HC+"!F=7IZ>0IM<V=I9"`B0V]M<&%N>2!!
M9&1R97-S(@IM<V=S='(@(D%D<F5S<V4L('!R:79A="(*"B,Z(&QI8B]A<&DN
M<&AP.C,Q."!L:6(O87!I+G!H<#HS-C,@;&EB+V%P:2YP:'`Z-#`W(&QI8B]A
M<&DN<&AP.C0Y,0HC.B!L:6(O87!I+G!H<#HV,#$@;&EB+V%P:2YP:'`Z-C@X
M(&QI8B]A<&DN<&AP.C<T,2!L:6(O87!I+G!H<#HX,3D*(SH@;&EB+V%P:2YP
M:'`Z,3`P-B!L:6(O87!I+G!H<#HQ,#DT"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B2W5N;F4@
M:6MK:F4@<VQE='1E(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`HC+"!F
M=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(DMU;FYE
M(&EK:VIE('-L971T92(*"B,Z(&)R;W=S92YP:'`Z,3DQ(&)R;W=S92YP:'`Z
M,C,R"FUS9VED(")#;VYT86-T(&%D9&5D('1O(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&)R;W=S92YP:'`Z-C`*;7-G:60@(D-O;G1A8W0@<F5M;W9E9"!F<F]M
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C8V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3(*(RP@9G5Z>GD*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B1FER;6$B"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHU,PIM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C0P"B,L(&9U>GIY"FUS9VED
M(")#<F5A=&4@061D<F5S<R!";V]K(@IM<V=S='(@(D5K<W!O<G1E<B!A9')E
M<W-E8F]K(@H*(SH@;&EB+TQI<W16:65W+G!H<#HS,34*;7-G:60@(D-R96%T
M92!A(&YE=R!#;VYT86-T($QI<W0@:6XZ(@IM<V=S='(@(B(*"B,Z(&QI8B]/
M8FIE8W16:65W+G!H<#HQ,S,*;7-G:60@(D-R96%T960B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED(")$969A=6QT('-O
M<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHW-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C(*(SH@;&EB+T]B:F5C="YP:'`Z,S(X(&QI8B]296YD97)E<BYP:'`Z-#<@
M;&EB+U)E;F1E<F5R+G!H<#HU,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-L
M971T(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B16MS<&]R
M=&5R(&%D<F5S<V5B;VLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*
M;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED(")$96QE=&4@8G5T=&]N(&)E
M:&%V:6]U<B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(W
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4B"@HC.B!D96QE
M=&4N<&AP.C,X"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@<VQE='1E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*(RP@9G5Z
M>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)R=6MA<F%L=&5R;F%T
M:78B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$X"FUS9VED
M(")$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R
M(")6:7-I;F=S86QT97)N871I=B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B5FES:6YG<V%L=&5R;F%T:78B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<V"FUS9VED(")$;R!Y;W4@=V%N
M="!T;R!C;VYF:7)M(&1E;&5T:6YG(&5N=')I97,_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]/8FIE8W0N<&AP.C(Y-PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$W('1E;7!L871E<R]B
M<F]W<V4O8V]N=&%C=')O=RYI;F,Z,C4*;7-G:60@(D1O=VYL;V%D('9#87)D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P
M,B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4*(SH@=&5M<&QA=&5S+V)R
M;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3`@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHS"B,Z('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI
M;F,Z,S,@;&EB+U)E;F1E<F5R+G!H<#HT,@IM<V=I9"`B161I="(*;7-G<W1R
M(")%;F1R92(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHR-2!T96UP
M;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R(")%;F1R92`G)7,G
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*(RP@9G5Z>GD*
M;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G<W1R(")%:W-P;W)T97(@
M861R97-S96)O:R(*"B,Z(&5D:70N<&AP.C<X(&5D:70N<&AP.C$U-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(&5N=')Y(&9O<B`E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B16UA
M:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@961I="YP:'`Z,30W"B,L('!H<"UF
M;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG
M('1H92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M961I="YP:'`Z,30Y(&5D:70N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%;G1R>2!F;W(@)7,@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E
M+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B16YT<GD@<W5C8V5S<V9U;&QY(&1E
M;&5T960N(@IM<V=S='(@(D9I;&$@)7,@=F%R="!I;7!O<G1E<G0B"@HC.B!L
M:6(O87!I+G!H<#HT,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('-E87)C:&EN9R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("))
M;F=E;B!A9')E<W-E8OAK97(@;65D('-K<FEV971I;&=A;F<N(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*;7-G<W1R(")%:W-P;W)T(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHV"B,L(&9U>GIY"FUS9VED
M(")%>'!O<G0@061D<F5S<R!";V]K(@IM<V=S='(@(D5K<W!O<G1E<B!A9')E
M<W-E8F]K(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM<V=I
M9"`B17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(W"FUS9VED(")%
M>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2XB
M"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3,T(&1A=&$N<&AP.C(R."!D871A
M+G!H<#HR.3<@8G)O=W-E+G!H<#HS-2!B<F]W<V4N<&AP.CDP"B,Z(&)R;W=S
M92YP:'`Z,3$R(&%D9"YP:'`Z-C<@<V5A<F-H+G!H<#HS-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S
M<R!B;V]K.B`E<R(*;7-G<W1R(")&96MK(&EK:VIE('1I;&=A;F<@=&EL(&1E
M;B!S<&5S:69I<V5R=&4@861R97-S96)O:V$N(@H*(SH@8G)O=W-E+G!H<#HQ
M,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@
M)7,@=&\@)7,Z("5S(@IM<V=S='(@(DMU;FYE(&EK:VIE(&)L82!I("5S+B(*
M"B,Z(&)R;W=S92YP:'`Z,C<R"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@
M8G)O=W-E(&QI<W0B"FUS9W-T<B`B2W5N;F4@:6MK:F4@8FQA(&D@)7,N(@H*
M(SH@8G)O=W-E+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!B
M<F]W<V4@=&AE(&1I<F5C=&]R>2(*;7-G<W1R(")+=6YN92!I:VMJ92!S^&ME
M(&D@:V%T86QO9V5N.B`E<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C:&%N9V4@;F%M93H@
M*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T(#T@)7,B
M"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E
M9#H@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@<_AK92!I(&MA=&%L;V=E;CH@
M)7,B"@HC.B!S96%R8V@N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")&86EL960@
M=&\@<V5A<F-H('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B1F5K:R!I:VMJ
M92!T:6QG86YG('1I;"!D96X@<W!E<VEF:7-E<G1E(&%D<F5S<V5B;VMA+B(*
M"B,Z(&1A=&$N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@<V5A<F-H('1H92!D:7)E8W1O<GDZ("5S(@IM<V=S='(@(DMU;FYE(&EK
M:VIE('/X:V4@:2!K871A;&]G96XZ("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,38W"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<R(*"B,Z
M(&5D:70N<&AP.C$R-"!D:7-P;&%Y+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@
M(D9I;&5S(@IM<V=S='(@(E1I='1E;"(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<V5A<F-H+FEN8SHW,`IM<V=I9"`B1FEN9"(*;7-G<W1R(")&:6YN(@H*(SH@
M961I="YP:'`Z.3<@961I="YP:'`Z,3@W"B,L(&9U>GIY"FUS9VED(")&:6YI
M<V@B"FUS9W-T<B`B1FEN;B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C0X"FUS9VED(")&:7)S="!.86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P,@IM<V=I9"`B1G)E96)U<WD@55),
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHX
M,PIM<V=I9"`B1G)O;2(*;7-G<W1R(")&<N4B"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HV,#0*(RP@9G5Z>GD*;7-G:60@(D=L;V)A;"!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B16MS<&]R=&5R(&%D<F5S<V5B;VLB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+W)O=RYI;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT
M86-T<F]W+FEN8SHT-`IM<V=I9"`B1W)O=7`B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S
M<R(*;7-G<W1R(")!9')E<W-E+"!P<FEV870B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P.`HC+"!F=7IZ>0IM
M<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@(E1E;&5F;VXL('!R:79A="(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U,`IM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R(")496QE9F]N+"!P<FEV870B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DAO;64@
M4&]S=&%L($-O9&4B"FUS9W-T<B`B5&5L969O;BP@<')I=F%T(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(DAO
M;64@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B5&5L969O;BP@<')I=F%T(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#@*(RP@9G5Z>GD*;7-G
M:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS9W-T<B`B061R97-S92P@<')I
M=F%T(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-3`V"FUS9VED("))
M35-0(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-PHC
M+"!F=7IZ>0IM<V=I9"`B24U34"!!9&1R97-S($)O;VL@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B061R97-S96)O:VQI<W1I;F<B"@HC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T<B`B26UP;W)T
M97(@861R97-S96)O:R(*"B,Z(&1A=&$N<&AP.C,V,0HC+"!F=7IZ>0IM<V=I
M9"`B26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS(@IM<V=S='(@(DEM<&]R
M=&5R+V5K<W!O<G1E<B!A9')E<W-E8OAK97(B"@HC.B!L:6(O87!I+G!H<#HU
M.38@;&EB+V%P:2YP:'`Z-C@S"B,L(&9U>GIY"FUS9VED("));G9A;&ED($E$
M(@IM<V=S='(@(E5G>6QD:6<@;F%M;BXB"@HC.B!L:6(O87!I+G!H<#HR,S`@
M;&EB+V%P:2YP:'`Z-#`R(&QI8B]A<&DN<&AP.C0X-B!L:6(O87!I+G!H<#HU
M.3(*(SH@;&EB+V%P:2YP:'`Z-C<Y(&QI8B]A<&DN<&AP.C<S,2!L:6(O87!I
M+G!H<#HQ,#<W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&%D9')E<W,@8F]O
M:R(*;7-G<W1R(")59WEL9&EG(&%D<F5S<V5B;VLN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3`X,2!L:6(O87!I+G!H<#HQ,34T(&QI8B]A<&DN<&AP.C$R,#<*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@96UA:6PB"FUS9W-T<B`B56=Y;&1I9R!E
M+7!O<W1A9')E<W-E+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.#D*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@96YT<GDB"FUS9W-T<B`B56=Y;&1I9R!N86UN+B(*
M"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C8V"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED(&ME>2!S<&5C:69I960N(@IM<V=S='(@(E5G>6QD:6<@92UP;W-T
M861R97-S92XB"@HC.B!L:6(O87!I+G!H<#HQ,#@U"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&YA;64B"FUS9W-T<B`B56=Y;&1I9R!N86UN+B(*"B,Z(&QI
M8B]A<&DN<&AP.C<S-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O8FIE8W1)
M9"(*;7-G<W1R(")59WEL9&EG(&YA;6XN(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U
M="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A
M9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS
M9VED("),87-T($UO9&EF:65D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C4S"B,L(&9U>GIY"FUS9VED("),87-T($YA;64B
M"FUS9W-T<B`B3F%M;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C$V"FUS9VED("),:7-T(@IM<V=S='(@(DQI<W0B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S<*;7-G:60@(DUA=&-H:6YG
M(@IM<V=S='(@(G-A;7-V87)A;F1E(&UE9"(*"B,Z(&QI8B]A<&DN<&AP.C(P
M-0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU
M;2!N=6UB97(@;V8@<&%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R
M965?;65N=2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!,:7-T(@IM<V=S
M='(@(DQI<W0B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,PHC+"!F
M=7IZ>0IM<V=I9"`B36EN:2!396%R8V@B"FUS9W-T<B`B4_AK(@H*(SH@;&EB
M+T1R:79E<B]L9&%P+G!H<#HS,#(*;7-G:60@(DUI<W-I;F<@1$X@:6X@3$1!
M4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,38R"B,L(&9U>GIY"FUS9VED(")-;V)I
M;&4@4&AO;F4B"FUS9W-T<B`B5&5L969O;BP@<')I=F%T(@H*(SH@;&EB+T1R
M:79E<B]L9&%P+G!H<#HS,S(@;&EB+T1R:79E<B]L9&%P+G!H<#HS-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B36]D:69Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,3DS"B,L(&9U>GIY"FUS9VED(")-
M;W)E('1H86X@,2!E;G1R>2!F;W5N9"(*;7-G<W1R(")-96ER(&5N;B`Q(&]P
M<&;X<FEN9R!R971U<FYE<G0N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHQ,0IM<V=I9"`B36]V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S+W!R
M969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*(RP@9G5Z>GD*;7-G:60@
M(DUO=F4@;&5F="(*;7-G<W1R(")F;'ET="!V96YS=')E(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V"B,L(&9U>GIY"FUS9VED
M(")-;W9E(')I9VAT(@IM<V=S='(@(F9L>71T(&CX9W)E(@H*(SH@9&%T82YP
M:'`Z-3(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-@HC+"!F=7IZ>0IM
M<V=I9"`B375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(D5K<W!O<G1E
M<B!A9')E<W-E8F]K(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;
M)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$P-R!C;VYF
M:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*;7-G:60@(DUY($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E8F]K;&ES=&EN9R(*"B,Z(&%D
M9')E<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S
M($)O;VMS(@IM<V=S='(@(D%D<F5S<V5B;VML:7-T:6YG(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`W(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C0R"FUS9VED(").86UE(@IM<V=S='(@(DYA;6XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B
M3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@861D
M+G!H<#HS-B!A9&0N<&AP.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z
M,C<*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,C<*(RP@9G5Z>GD*;7-G
M:60@(DYE=R!#;VYT86-T(@IM<V=S='(@(DQE9V<@=&EL(&YY(&MO;G1A:W0B
M"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY-2!E9&ET+G!H<#HR,#(@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT-0IM<V=I9"`B3F5X="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*(RP@9G5Z
M>GD*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(DYA;6XB"@HC.B!L:6(O87!I
M+G!H<#HQ,3DU(&QI8B]A<&DN<&AP.C$R-#0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DYO("5S(&5N=')Y(&9O=6YD(&9O<B`E<R(*;7-G<W1R(")&
M86YN(&EN9V5N(&]F9F5N=&QE9R!N^&MK96P@9F]R("5S+B(*"B,Z(&QI8B]A
M<&DN<&AP.C$Q-C,*(RP@9G5Z>GD*;7-G:60@(DYO(&%D9')E<W,@8F]O:W,@
M9F]U;F0N(@IM<V=S='(@(D%D<F5S<V5B;VMA(&5R(&)E<G)E(&QE<V)A<B(*
M"B,Z(&UI;FES96%R8V@N<&AP.C@S"FUS9VED(").;R!C;VYT86-T<R!F;W5N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HU,3$@;&EB+V%P:2YP:'`Z
M-S8V"FUS9VED(").;R!V0V%R9"!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C<*(RP@9G5Z>GD*
M;7-G:60@(DYO;F4B"FUS9W-T<B`B3F]T871A<B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$X-`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B3F]T
M871A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(DYU
M;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HV,30@;&EB+V%P:2YP:'`Z-S0W"FUS9VED(")/8FIE8W0@;F]T(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@
M=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E
M<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@;F]T('=H870@>6]U
M('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N("(*
M(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW-S0*
M;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-@HC+"!F=7IZ>0IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R
M(")"<G5K87)A;'1E<FYA=&EV(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3DP"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@
M;V9F96YT;&5G(&[X:VME;"(*"B,Z(&QI8B]A<&DN<&AP.C0Y-2!L:6(O87!I
M+G!H<#HV,#4@;&EB+V%P:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.CDS-`HC.B!L
M:6(O87!I+G!H<#HQ,#DX"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G
M<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HU-#,*;7-G:60@(E!E<FUI<W-I
M;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.CDY"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!D
M871A+G!H<#HU,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"B,L(&9U
M>GIY"FUS9VED(")0:6YE($%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E
M8F]K;&ES=&EN9R(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI
M;F,Z,C@*;7-G:60@(E!L96%S92!N86UE('1H92!N97<@8V]N=&%C="!L:7-T
M.B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET
M+G!H<#HQ.30*;7-G:60@(E!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]S;W5R8V5S+G!H<"YD:7-T.C0Q-@HC+"!F=7IZ>0IM<V=I9"`B4')I=F%T
M92!!9&1R97-S($)O;VLB"FUS9W-T<B`B16MS<&]R=&5R(&%D<F5S<V5B;VLB
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")1=65R>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C$X"B,L(&9U>GIY"FUS9VED
M(")1=6EC:R!396%R8V@B"FUS9W-T<B`B4_AK(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HQ.3$@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3D@;&EB+T1R:79E
M<B]L9&%P+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A9"!F86EL
M960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+U)E;F1E<F5R+G!H<#HT
M.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")2
M96-O<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S8*(RP@9G5Z>GD*;7-G:60@
M(E)E;6]V92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B26UP;W)T97(@861R97-S
M96)O:R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S
M.0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")F:F5R
M;B!K;VQO;FYE(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR
M"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0IM<V=I9"`B(@HB4F5P;&%C
M92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@:6UP;W)T960@;VYE
M/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@96YT<FEE
M<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R;VYG/B(*;7-G
M<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G:60@(E)E<75E<W1E
M9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C,W
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G:60@(E)E<V5T
M('1O($1E9F%U;'1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T:69I8V%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G
M<W1R("(B"@HC.B!E9&ET+G!H<#HY.2!A9&0N<&AP.C,W('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V92(*;7-G<W1R("),86=R
M92(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-B!T96UP;&%T
M97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$R"B,Z('1E;7!L871E<R]B;&]C:R]M
M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HT.0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B"FUS
M9W-T<B`B4_AK(@H*(SH@;6EN:7-E87)C:"YP:'`Z-C,*(RP@9G5Z>GD*;7-G
M:60@(E-E87)C:"!297-U;'1S.B(*;7-G<W1R(")3^&ME<F5S=6QT870B"@HC
M.B!L:6(O87!I+G!H<#HQ,#$Q"B,L(&9U>GIY"FUS9VED(")396%R8V@@9F%I
M;&5D(@IM<V=S='(@(E/X:R(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#,@;&EB+V%P
M:2YP:'`Z,3$P.2!L:6(O87!I+G!H<#HQ,3$X(&QI8B]A<&DN<&AP.C$Q,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(R"B,L
M(&9U>GIY"FUS9VED(")396%R8VAI;F<N+BXB"FUS9W-T<B`B4_AK(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C8*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@9&5L971E(@IM<V=S='(@(E9E
M;"!E:2!A9')E<W-E8F]K(&9O<B#E(&QE9V=E('1I;"!E:2!K;VYT86MT+B(*
M"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDP"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@86X@861D<F5S<R!B;V]K('1O(&5D:70B"FUS9W-T<B`B
M5F5L(&5I(&%D<F5S<V5B;VL@9F]R(.4@;&5G9V4@=&EL(&5I(&MO;G1A:W0N
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS,@HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ
M(@IM<V=S='(@(E9E;"!K:F5L9&4@Y2!E:W-P;W)T97)E(&9RY3HB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@
M(E9E;"!MY6P@9F]R(&EM<&]R=#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C,U"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&-H87)S970@
M;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")696P@:VIE;&1E(.4@96MS
M<&]R=&5R92!F<N4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*
M;7-G<W1R(")696P@:VIE;&1E(.4@96MS<&]R=&5R92!F<N4Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L96-T('1H92!F
M:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B5F5L(&9I;"!S;VT@<VMA;"!I;7!O
M<G1E<F%S=#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E
M(&9I;&4Z(@IM<V=S='(@(E9E;"!F;W)M870@Y2!E:W-P;W)T97)E('1I;#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@;F%M97,Z(@IM
M<V=S='(@(E9E;"!F;W)M870@Y2!I;7!O<G1E<F4@9G+E.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('9I
M97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P
M86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`B5F5L('9I<VEN9R!S;VT@<VMA;"!B
M<G5K87-T('-O;2!S=&%N9&%R9"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3@*;7-G:60@(E-E;&5C="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I
M;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS9W-T<B`B5F5L(&MV82!F96QT('-O
M;2!S:V%L('9I<V%S="!I(&%D<F5S<V5L:7-T96YE+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('=H:6-H
M(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R(")696P@:W9A(&9E
M;'0@<V]M('-K86P@=FES87-T(&D@861R97-S96QI<W1E;F4N(@H*(SH@861D
M+G!H<#HU-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5L96-T960@
M861D<F5S<R!B;V]K(%PB)7-<(BXB"FUS9W-T<B`B56=Y;&1I9R!A9')E<W-E
M8F]K+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$W,PHC+"!F=7IZ
M>0IM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3:&]W("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H;W<@06QL(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@
M(E-H;W<@0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B4VAO=R!,:7-T<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHR,0HC
M.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHS-`HC+"!F
M=7IZ>0IM<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS9W-T<B`B2V%T86QO9R(*
M"B,Z(&QI8B]A<&DN<&AP.C$Y.`IM<V=I9"`B4V]U<F-E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34W"FUS9VED(")3<&5C:69Y
M('=H97)E('EO=2!W86YT(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P
M<&5A<BXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ-#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S(@IM<V=S
M='(@(B(*"B,Z(&)R;W=S92YP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V
M86QU97,B"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z,34*;7-G:60@(E1H92!6
M1E,@8F%C:V5N9"!N965D<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A
M='1A8VAM96YT('5P;&]A9',N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N
M<&AP.C$P-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&%D9')E
M<W-B;V]K<RYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E
M<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB('=A<R!R96UO=F5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")0
M:6YE+6%D<F5S<V5B;VL@=F%R="!I;7!O<G1E<G0B"@HC.B!D871A+G!H<#HS
M,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!C;W5L
M9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HT
M-R!V8V%R9"YP:'`Z,C(@9&ES<&QA>2YP:'`Z,C,@=FEE=RYP:'`Z,C8*;7-G
M:60@(E1H92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")&:6QA("5S('9A<G0@:6UP;W)T97)T
M(@H*(SH@9&%T82YP:'`Z,C@T"FUS9VED(")4:&4@:6UP;W)T(&-A;B!B92!F
M:6YI<VAE9"!D97-P:71E('1H92!W87)N:6YG<RXB"FUS9W-T<B`B(@H*(SH@
M8G)O=W-E+G!H<#HS,0IM<V=I9"`B5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@
M861D<F5S<R!B;V]K<RXB"FUS9W-T<B`B26YG96X@861R97-S96+X:V5R('1I
M;&=J96YG96QE9R!F;W(@9VIE;FYO;7-Y;FEN9RXB"@HC.B!A9&0N<&AP.C(Y
M"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D
M9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O
M;VMS("(*(F%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W
M(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R`B"B)I<R!A
M;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@HB26YG96X@878@9&5I;"!T:6QG:F5N9V5L96=E
M(&%D<F5S<V5B^&ME;F4@97(@:V]N9FEG=7)E<G0@=&EL(.4@;&$@9&5G(&QE
M9V=E("(*(G1I;"!N>64@;W!P9OAR:6YG87(N($1E<G-O;2!D=2!M96EN87(@
M9&5T=&4@97(@9F5I;"P@=F5R('9E;FQE9R!O9R!K;VYT86MT("(*(F1I;B!S
M>7-T96UA9&UI;FES=')A=&]R+B(*"B,Z(&%D9"YP:'`Z,3(Q"B,L(&9U>GIY
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N97<@
M8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R("(*
M(F9O<B!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(D9E:6P@;N5R(&]B:F5K
M=&5T('-K=6QL92!L96=G87-T('1I;"X@2V]N=&%K="!D:6X@<WES=&5M861M
M:6YI<W1R871O<B!F;W(@(@HB=FED87)E(&AJ96QP+B(*"B,Z(&)R;W=S92YP
M:'`Z,3@Y(&)R;W=S92YP:'`Z,C,P"B,L(&9U>GIY"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@861D:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R(")$970@
M<VMJ961D92!E:6X@9F5I;"!V960@:6UP;W)T(&%V(&1A=&$N(@H*(SH@8G)O
M=W-E+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R(")$970@<VMJ961D92!E
M:6X@9F5I;"!V960@:6UP;W)T(&%V(&1A=&$N(@H*(SH@861D<F5S<V)O;VMS
M+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&-R96%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G
M<W1R(")$970@<VMJ961D92!E:6X@9F5I;"!V960@:6UP;W)T(&%V(&1E;B!O
M<'!L87-T82!F:6QA(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<
M(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M1&5T('-K:F5D9&4@96EN(&9E:6P@=F5D(&EM<&]R="!A=B!D96X@;W!P;&%S
M=&$@9FEL82(*"B,Z(&1E;&5T92YP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O
M;G1A8W0Z("5S(@IM<V=S='(@(D1E="!S:VIE9&1E(&5I;B!F96EL('9E9"!I
M;7!O<G0@878@9&%T82XB"@HC.B!B<F]W<V4N<&AP.C<R"B,L(&9U>GIY"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!O8FIE8W0N
M(@IM<V=S='(@(D1E="!S:VIE9&1E(&5I;B!F96EL('9E9"!I;7!O<G0@878@
M9&%T82XB"@HC.B!B<F]W<V4N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AE(&QI<W0B"FUS9W-T<B`B
M1&5T('-K:F5D9&4@96EN(&9E:6P@=F5D(&EM<&]R="!A=B!D871A+B(*"B,Z
M(&1A=&$N<&AP.C,S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T
M<B`B1&5T('-K:F5D9&4@96EN(&9E:6P@=F5D(&EM<&]R="!A=B!D871A+B(*
M"B,Z(&QI8B]A<&DN<&AP.C4P-R!L:6(O87!I+G!H<#HW-C$*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R(")$970@<VMJ961D92!E:6X@9F5I;"!V960@
M:6UP;W)T(&%V(&1A=&$N(@H*(SH@8G)O=W-E+G!H<#HU.`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG(&$@8V]N=&%C="!F
M<F]M('1H92!L:7-T+B(*;7-G<W1R(")$970@<VMJ961D92!E:6X@9F5I;"!V
M960@:6UP;W)T(&%V(&1A=&$N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HU-2!A
M9&1R97-S8F]O:W,N<&AP.C8P(&%D9')E<W-B;V]K<RYP:'`Z-C@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO
M=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B1&5T('-K:F5D
M9&4@96EN(&9E:6P@=F5D(&EM<&]R="!A=B!D96X@;W!P;&%S=&$@9FEL82(*
M"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#$@861D<F5S<V)O;VMS+G!H<#HX-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")$970@
M<VMJ961D92!E:6X@9F5I;"!V960@:6UP;W)T(&%V(&1E;B!O<'!L87-T82!F
M:6QA(@H*(SH@961I="YP:'`Z,34X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@
M)7,B"FUS9W-T<B`B1&5T('-K:F5D9&4@96EN(&9E:6P@=F5D(&EM<&]R="!A
M=B!D871A+B(*"B,Z(&1A=&$N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+B(*;7-G<W1R("));F=E
M;B!A9')E<W-E8OAK97(@;65D('-K<FEV971I;&=A;F<N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#`*;7-G:60@(E1H
M97-E(&%D9')E<W,@8F]O:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(T,PIM<V=I9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@
M=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED
M(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,C(@;&EB+V%P:2YP:'`Z,3$S-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H
M87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(D1E
M;FYE('!E<G-O;F5N(&AA<B!A;&QE<F5I92!E:6X@;V9F96YT;&5G(&[X:VME
M;"!I(&%D<F5S<V5B;VMA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#<*;7-G:60@(B(*(E1H:7,@=VEL;"!B92!T:&4@9&5F875L="!A9&1R97-S
M(&)O;VL@=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG(&-O;G1A8W1S+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW,`IM<V=I
M9"`B5&ET;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@;&EB+U1U<F)A+G!H<#HT
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!N97<@
M<VAA<F4N("!-:7-S:6YG('-O=7)C92!T>7!E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O1')I=F5R+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DMU;FYE
M(&EK:VIE(&QA<W1E(&EN;B!D969I;FES:F]N96X@=&EL("5S+B(*"B,Z(&5D
M:70N<&AP.C@X(&5D:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY
M(&5D:70N<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM
M<V=S='(@(DQA9W)E(&5N9')I;F=A<B(*"B,Z(&QI8B]A<&DN<&AP.C4T,"!L
M:6(O87!I+G!H<#HV-#,@;&EB+V%P:2YP:'`Z-S<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"B,L(&9U>GIY"FUS
M9VED(")697)I<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E
M+V-O;G1A8W1R;W<N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&UI;FES96%R8V@N<&AP.C<X"B,L(&9U
M>GIY"FUS9VED(")6:65W($-O;G1A8W0B"FUS9W-T<B`B3&5G9R!T:6P@;GD@
M:V]N=&%K="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@
M(E9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R(")"<G5K(&1E
M;FYE('9I<VEN9V$@<V]M('-T86YD87)D.B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$S"FUS9VED(")7
M;W)K($%D9')E<W,B"FUS9W-T<B`B061R97-S92P@87)B96ED(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(T"FUS9VED(")7;W)K($-I='DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,Y
M"B,L(&9U>GIY"FUS9VED(")7;W)K($-O=6YT<GDB"FUS9W-T<B`B5&5L969O
M;BP@87)B96ED(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34V
M"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F;VXL(&%R8F5I9"(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S-`HC+"!F=7IZ>0IM
M<V=I9"`B5V]R:R!0;W-T86P@0V]D92(*;7-G<W1R(")496QE9F]N+"!A<F)E
M:60B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*(RP@9G5Z
M>GD*;7-G:60@(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B5&5L969O
M;BP@87)B96ED(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$Y
M"B,L(&9U>GIY"FUS9VED(")7;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@
M(D%D<F5S<V4L(&%R8F5I9"(*"B,Z(&1A=&$N<&AP.C(S-R!B<F]W<V4N<&AP
M.CDS(&)R;W=S92YP:'`Z,C`Q(&%D9"YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&-O;G1A8W1S(&EN(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@961I="YP
M:'`Z-CD@9&ES<&QA>2YP:'`Z-3@@=FEE=RYP:'`Z,S8*;7-G:60@(EEO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*
M;7-G<W1R("(B"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-34*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z
M,C,*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(*;7-G
M<W1R("(B"@HC.B!E9&ET+G!H<#HS,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T
M(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C$W('1E;7!L871E<R]B
M<F]W<V4O:F%V87-C<FEP="YI;F,Z-#D*(SH@=&5M<&QA=&5S+V)R;W=S92]J
M879A<V-R:7!T+FEN8SHW,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE
M87-T(&]N92!E;G1R>2!F:7)S="XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z
M-S,*;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H
M:7,@8V]N=&%C="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR.#4*;7-G
M:60@(EEO=7(@9&5F875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B
M;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHV
M('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@(EMN
M;R!V86QU95TB"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#0*(RP@
M9G5Z>GD*;7-G:60@(E]"<F]W<V4B"FUS9W-T<B`B0FQA(&=J96YN;VTB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"FUS9VED(")?0V]N
M=&%C=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHR"B,L(&9U>GIY"FUS9VED(")?1&5L971E(@IM<V=S='(@(E-L971T
M(@H*(SH@;&EB+U1U<F)A+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@(E]);7!O
M<G0O17AP;W)T(@IM<V=S='(@(DEM<&]R="]E:W-P;W)T(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0HC+"!F=7IZ>0IM<V=I9"`B7TQI
M<W1S(@IM<V=S='(@(DQI<W0B"@HC.B!L:6(O5'5R8F$N<&AP.C0X,0HC+"!F
M=7IZ>0IM<V=I9"`B7TUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B061R97-S
M96)O:VQI<W1I;F<B"@HC.B!L:6(O5'5R8F$N<&AP.C0X-PHC+"!F=7IZ>0IM
M<V=I9"`B7TYE=R!#;VYT86-T(@IM<V=S='(@(DQE9V<@=&EL(&YY(&MO;G1A
M:W0B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@
M(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+U1U
M<F)A+G!H<#HT.#D*(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B
M4_AK(@H*(SH@=F-A<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C9B(*;7-G
M<W1R("(B"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C(P.0IM<V=I9"`B8V]N=&%C=',N='-V(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C(Q.0IM<V=I9"`B8V]N=&%C=',N=F-F
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z
M,S0*;7-G:60@(FYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHR-`IM<V=I9"`B=&\@82!#;VYT86-T($QI<W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ-`HC
M+"!F=7IZ>0IM<V=I9"`B=&\@82!D:69F97)E;G0@061D<F5S<R!";V]K(@IM
M<V=S='(@(D5K<W!O<G1E<B!A9')E<W-E8F]K(@H*(SH@9&%T82YP:'`Z-3$@
M=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-2!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$U"FUS9VED(")V0V%R9"(*;7-G<W1R("(B"@``````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M='5R8F$O<&\O<&Q?4$PN<&\`````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`V,S0V,``Q,#0Q-S,V,C<U-@`P,3<U,S8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R!0;VQI<V@@
M=')A;G-L871I;VYS(&9O<B!4=7)B82!P86-K86=E+@HC($-O<'ER:6=H="`H
M0RD@,C`P-2!(;W)D92!0<F]J96-T"B,@0V]P>7)I9VAT("A#*2`R,#`U($MR
M>GES>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#X*(R!4:&ES(&9I;&4@
M:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@
M5%520D$@<&%C:V%G92X*(R!-871E=7-Z($MA;6EN<VMI(#QM871I<&Q`<&QD
M+6QI;G5X+F]R9SXL(#(P,#4N"B,@2W)Z>7-Z=&]F($MO>FQO=W-K:2`\:V]Z
M:6LQ0&\R+G!L/BP@,C`P-2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE
M8W0M260M5F5R<VEO;CH@5'5R8F$@:#,M,BXP+C-<;B(*(E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,2TR-"`R,#HT-RLP,3`P7&XB"B)03RU2979I<VEO
M;BU$871E.B`R,#`U+3$Q+3(T(#(P.C0Y*S`Q,#!<;B(*(DQA<W0M5')A;G-L
M871O<CH@2W)Z>7-Z=&]F($MO>FQO=W-K:2`\:V]Z:6LQ0&\R+G!L/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@4&]L:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@8G)O=W-E+G!H<#HQ,C`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U<V4@
M:70@:7,@82!L:7-T+B(*;7-G<W1R(")<(B5S7"(@;FEE('IO<W1ALR!S:V]P
M:6]W86YY+"!P;VYI97=AOR!J97-T(&QI<W2Q+B(*"B,Z(&)R;W=S92YP:'`Z
M,3$X"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO=F5D
M(&)E8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R(")<(B5S7"(@;FEE('IO
M<W1ALR!P<GIE;FEE<VEO;GDL('!O;FEE=V&_(&IE<W0@;&ES=+$N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0IM<V=I9"`B7")&:7)S=&YA;64@
M3&%S=&YA;65<(B`@*&EE+B!*;VAN($1O92DB"FUS9W-T<B`B7"));6GJ($YA
M>G=I<VMO7"(@*&YP+B!*86X@2V]W86QS:VDI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q,`IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@
M*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(EPB3F%Z=VES:V\L($EM:>I<(B`H
M;G`N($MO=V%L<VMI+"!*86XI(@H*(SH@861D+G!H<#HX-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B)7,@9&]D86YE+B(*"B,Z
M(&1A=&$N<&AP.C(U-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F:6QE('-U
M8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R(")0;&EK("5S('IO<W1ALR!Z
M86EM<&]R=&]W86YY(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T
M<B`B)7,@9&\@)7,@>B`E<R(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H
M<#HT-0IM<V=I9"`B02!B<F]W<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I
M<R!R97%U:7)E9"(*;7-G<W1R(")7>6UA9V%N82!J97-T(&]B<[-U9V$@:49R
M86UE<RAPLWEW86JQ8WEC:"!R86UE:RD@<')Z97H@<')Z96=LL61A<FOJ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B06)O=F4@<V5A
M<F-H(&9O<FTB"FUS9W-T<B`B4&]W>;]E:B!W>7-Z=6MI=V%R:VDB"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-C4*;7-G:60@(D%D7W9A;F-E
M9"!396%R8V@B"FUS9W-T<B`B6F%A=V%N<V]W86YE('-Z=6MA;FEE("A?=BDB
M"@HC.B!A9&0N<&AP.C4R"FUS9VED(")!9&0B"FUS9W-T<B`B1&]D86HB"@HC
M.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*;7-G:60@
M(D%D9"!C;VQU;6XB"FUS9W-T<B`B1&]D86H@:V]L=6UNZB(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D%D9"!T;R(*;7-G
M<W1R(")$;V1A:B!D;R(*"B,Z(&)R;W=S92YP:'`Z,S`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDY"FUS9VED(")!9&1R97-S($)O;VL@3&ES=&EN9R(*;7-G
M<W1R("),:7-T;W=A(&MS:;&_:V$@861R97-O=V$B"@HC.B!A9&0N<&AP.C@V
M"FUS9VED(")!9&1R97-S(&)O;VL@96YT<GDB"FUS9W-T<B`B5W!I<R!K<VFQ
MOVMI(&%D<F5S;W=E:B(*"B,Z(&QI8B]$<FEV97(N<&AP.C0W.`IM<V=I9"`B
M061D<F5S<R!B;V]K(&ES(')E860M;VYL>2XB"FUS9W-T<B`B2W-IL;]K82!A
M9')E<V]W82!T>6QK;R!D;R!O9&-Z>71U+B(*"B,Z(&1A=&$N<&AP.C(S-@IM
M<V=I9"`B061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S
M='(@(DMS:;&_:V$@861R97-O=V$@=WEC>GES>F-Z;VYA+B(*"B,Z('-E87)C
M:"YP:'`Z.3<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C8U"B,Z('1E
M;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G:60@(D%D=F%N8V5D
M(%-E87)C:"(*;7-G<W1R("):86%W86YS;W=A;F4@<WIU:V%N:64B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HV-`IM<V=I9"`B06QI87,B"FUS
M9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA
M+FEN8SHV('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.CD*;7-G
M:60@(D%L;"(*;7-G<W1R(")7<WIY<W1K;R(*"B,Z(&QI8B]A<&DN<&AP.C,Y
M-0IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B2G6_(&ES=&YI96IE
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHX.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T
M;R!D96QE=&4@)7,_(@IM<V=S='(@(DYA('!E=VYO('5S=6ZQYB`E<S\B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8S"FUS9VED(")!
M<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE('-E;&5C
M=&5D(&5N=')I97,_(@IM<V=S='(@(DYA('!E=VYO('5S=6ZQYB!T96X@=WEB
M<F%N>2!W<&ES/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,`IM<V=I
M9"`B07-C96YD:6YG(@IM<V=S='(@(E=Z<F%S=&%JL6-O(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,S"FUS9VED(")!=F%I;&%B
M;&4@0V]L=6UN<SHB"FUS9W-T<B`B1&]S=.IP;F4@:V]L=6UU;GDZ(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")"85]C:R!T;R`E<R(*;7-G<W1R(")7<O/F(&1O("5S("A?8RDB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0T"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B5W+SYB!D;R`E<R(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,38*;7-G:60@(D)A
M<VE?8R!396%R8V@B"FUS9W-T<B`B4&]D<W1A=V]W92!S>G5K86YI92`H7V,I
M(@H*(SH@<V5A<F-H+G!H<#HY-"!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI
M;F,Z-C(*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q-@IM<V=I
M9"`B0F%S:6,@4V5A<F-H(@IM<V=S='(@(E!O9'-T87=O=V4@<WIU:V%N:64B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q"FUS9VED(")"96QO=R!S
M96%R8V@@9F]R;2(*;7-G<W1R(")0;VYIOV5J('=Y<WIU:VEW87)K:2(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z.#4@;&EB+T1R:79E<B]L9&%P+G!H<#HX
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*
M;7-G<W1R(").:65U9&%N92!":6YD.B`H)7,I("5S(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A>2(*;7-G<W1R
M(")5<F]D>FEN>2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W
M,PIM<V=I9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS9W-T<B`B2V%T96=O<FEA
M(&)I>FYE<V]W82(*"B,Z(&1A=&$N<&AP.C(X"FUS9VED(")#4U8B"FUS9W-T
M<B`B0U-6(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT.`IM
M<V=I9"`B0U]L96%R(%-E87)C:"(*;7-G<W1R(")7>6-Z>;;F('-Z=6MA;FEE
M("A?;"DB"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN
M8SHU"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B6E]A>FYA8WH@
M5W-Z>7-T:V\O3FEC(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y"FUS
M9VED("(B"B)#:&]O<V4@82!D969A=6QT(&1I<F5C=&]R>2!F;W(@>6]U<B!P
M97)S;VYA;"!A9&1R97-S8F]O:RP@8V]N=&%C="!L:7-T<RP@86YD("(*(G-E
M87)C:&5S+B(*;7-G<W1R("(B"B)7>6)I97)Z(&1O;7FV;&ZQ(&MA=&%L;V<@
M9&QA('1W;VIE:B!K<VFQOVMI(&%D<F5S;W=E:BP@;&ES='D@:V]N=&%K=/-W
M+"`B"B)W>7-Z:VEW86YI82XB"@HC.B!A9&0N<&AP.C0T"FUS9VED(")#:&]O
M<V4@86X@861D<F5S<R!B;V]K(@IM<V=S='(@(E=Y8FEE<GH@:W-IL;]KZB!A
M9')E<V]WL2(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(R.`IM<V=I9"`B0VAO;W-E('1H92!O<F1E<B!O9B!T:&4@8V]L=6UN<R!T
M;R!D:7-P;&%Y(&EN('1H92!A9&1R97-S(&QI<W0N(@IM<V=S='(@(E=Y8FEE
M<GH@:V]L=6UN>2P@:W3S<F4@;6%JL2!B>>8@=WFV=VEE=&QA;F4@;F$@;&FV
M8VEE(&MO;G1A:W3S=RXB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N
M:6YC.C0X"FUS9VED(")#;&5A<B!396%R8V@B"FUS9W-T<B`B5WEC>GFVYB!S
M>G5K86YI92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,`IM<V=I9"`B
M0V]L=6UN($]P=&EO;G,B"FUS9W-T<B`B3W!C:F4@:V]L=6UN(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ."!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$V"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S
M='(@(E!R>F5C:6YE:R!O9&1Z:65L82!W87)T;[9C:2(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3<*;7-G:60@(D-O;6UA('-E<&%R871E9"!V
M86QU97,@*$UI8W)O<V]F="!/=71L;V]K*2(*;7-G<W1R(")0<GIE8VEN96L@
M;V1D>FEE;&$@=V%R=&^V8VD@*$UI8W)O<V]F="!/=71L;V]K*2(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<V"FUS9VED(")#;VUP86YY(@IM
M<V=S='(@(D9I<FUA(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,30T"FUS9VED(")#;VUP86YY($%D9')E<W,B"FUS9W-T<B`B061R97,@9FER
M;7DB"@HC.B!L:6(O87!I+G!H<#HR-#<@;&EB+V%P:2YP:'`Z,C8X(&QI8B]A
M<&DN<&AP.C,X-"!L:6(O87!I+G!H<#HT-30*(SH@;&EB+V%P:2YP:'`Z-30T
M(&QI8B]A<&DN<&AP.C4Y,"!L:6(O87!I+G!H<#HV,S@@;&EB+V%P:2YP:'`Z
M.#(U"B,Z(&QI8B]A<&DN<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B4&^SL6-Z96YI92!N:64@
M<&]W:6]DLV\@<VGJ.B`E<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-C8*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R(")0;[.Q8WIE;FEE
M(&YI92!P;W=I;V2S;R!S:>HB"@HC.B!B<F]W<V4N<&AP.C8P"FUS9VED(")#
M;VYT86-T(')E;6]V960@9G)O;2!L:7-T+B(*;7-G<W1R(")+;VYT86MT('5S
M=6YIZG1Y('H@;&ES='DN(@H*(SH@8G)O=W-E+G!H<#HR-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`B2V]N
M=&%K='D@;F$@;&FV8VEE.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,C@Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F("5S(@IM<V=S='(@(EIA=V%R
M=&^VYB`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3(*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:75J(@H*(SH@;&EB+T]B:F5C=%9I
M97<N<&AP.C$S-`IM<V=I9"`B0W)E871E9"(*;7-G<W1R(")5='=O<GIO;GDB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38*;7-G:60@(D1E9F%U;'0@
M1&ES<&QA>2(*;7-G<W1R(")$;VUYMFQN92!W>;9W:65T;&%N:64B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"FUS9VED("(B"B)$969A=6QT(&1I
M<F5C=&]R>2!F;W(@>6]U<B!P97)S;VYA;"!A9&1R97-S8F]O:RP@8V]N=&%C
M="!L:7-T<RP@86YD('-E87)C:&5S+B(*;7-G<W1R("(B"B)$;VUYMFQN>2!K
M871A;&]G(&1L82!T=V]J96H@;W-O8FES=&5J(&MS:;&_:VD@861R97-O=V5J
M+"!L:7-T>2!K;VYT86MT\W<@:2`B"B)W>7-Z=6MI=V%N:6$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<R"FUS9VED(")$969A=6QT('-O<G1I;F<@
M9&ER96-T:6]N.B(*;7-G<W1R(")$;VUYMFQN>2!S<&]S\V(@<V]R=&]W86YI
M83HB"@HC.B!L:6(O4F5N9&5R97(N<&AP.C0X('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z,PIM<V=I9"`B1&5L971E(@IM<V=S='(@(E5S=?$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4*;7-G:60@(D1E;&5T92!#;VYF
M:7)M871I;VXB"FUS9W-T<B`B4&]T=VEE<F1Z96YI92!U<W5W86YI82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-@IM<V=I9"`B1&5L971E(&)U='1O
M;B!B96AA=FEO=7(B"FUS9W-T<B`B6FUI9?$@<&]W:6%D86UI86YI92!O('5S
M=7=A;FEU(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")5
M<W5N:>IC:64@;FEE=61A;F4Z("@E<RD@)7,B"@HC.B!D96QE=&4N<&AP.C,R
M"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T<B`B57-U;FGJ8VEE(&YI
M975D86YE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$S"FUS
M9VED(")$97!A<G1M96YT(@IM<V=S='(@(D1Z:6&S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Q"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(DUA
M;&5JL6-O(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$S,@IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P8VIE('=Y
MMG=I971L86YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#D*;7-G
M:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B
M"FUS9W-T<B`B0VAC97-Z('!O='=I97)D>F'F('5S=7=A;FEE('=P:7/S=S\B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(U"FUS9VED
M(")$;W=N;&]A9"!V0V%R9"(*;7-G<W1R("*F8VFQ9VYI:B!V0V%R9"(*"B,Z
M(&QI8B]296YD97)E<BYP:'`Z-#8@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?
M:&5A9&5R<RYI;F,Z-@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N
M:6YC.C,S"FUS9VED(")%9&ET(@IM<V=S='(@(D5D>71U:B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B161Y='5J(%PB)7-<(B(*"B,Z
M(&5D:70N<&AP.C4S(&5D:70N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@96YT<GD@9F]R("5S(@IM<V=S='(@(D5D>6-J82!W<&ES=3H@)7,B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B16UA
M:6PB"FUS9W-T<B`B16UA:6PB"@HC.B!E9&ET+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"XB"FUS9W-T<B`B5W!I
M<R!D;&$@)7,@>F%K='5A;&EZ;W=A;GDN(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-#8*
M;7-G:60@(D5X<&]R="(*;7-G<W1R(")%:W-P;W)T(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHW"FUS9VED(")%>'!O<G0@061D<F5S<R!";V]K
M(@IM<V=S='(@(D5K<W!O<G0@:W-IL;]K:2!A9')E<V]W96HB"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C(V"FUS9VED(")%>'!O<G0@;VYL>2!T
M:&4@<V5L96-T960@8V]N=&%C=',N(@IM<V=S='(@(D5K<W!O<G1U:B!T>6QK
M;R!Z87IN86-Z;VYE(&MO;G1A:W1Y+B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,S(*;7-G:60@(D5X<&]R="!T:&4@9F]L;&]W:6YG(&%D9')E
M<W,@8F]O:R!C;VUP;&5T96QY+B(*;7-G<W1R(")%:W-P;W)T(&YA<W3J<'5J
ML6-E:B!K<VFQOVMI(&%D<F5S;W=E:B!Z86MO\6-Z;VYY+B(*"B,Z(&%D9"YP
M:'`Z-C,@9&%T82YP:'`Z,3$P(&1A=&$N<&AP.C(R."!S96%R8V@N<&AP.C4R
M(&)R;W=S92YP:'`Z,S<*(SH@8G)O=W-E+G!H<#HY-"!B<F]W<V4N<&AP.C$P
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@86-C97-S('1H92!A
M9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(DYI975D86YY(&1O<W3J<"!D;R!K
M<VFQOVMI(&%D<F5S;W=E:CH@)7,B"@HC.B!B<F]W<V4N<&AP.C$R.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@861D("5S('1O("5S.B`E<R(*
M;7-G<W1R(").:65U9&%N92!D;V1A;FEE("5S(&1O("5S.B`E<R(*"B,Z(&)R
M;W=S92YP:'`Z,C8S"FUS9VED(")&86EL960@=&\@8G)O=W-E(&QI<W0B"FUS
M9W-T<B`B3FEE=61A;F4@<')Z96=LL61A;FEE(&QI<W1Y(@H*(SH@8G)O=W-E
M+G!H<#HR.3<*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R
M>2(*;7-G<W1R(").:65U9&%N92!P<GIE9VRQ9&%N:64@:V%T86QO9W4B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C,R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S
M+"!.97<@1$X@/2`E<RP@4F]O="`]("5S(@IM<V=S='(@(B(*(DYI975D86YA
M('IM:6%N82!N87IW>3H@*"5S*2`E<SL@4W1A<GD@1$X@/2`E<RP@3F]W>2!$
M3B`]("5S+"!+;W)Z9?$@/2`E<R(*"B,Z(&)R;W=S92YP:'`Z,3$T"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A
M9&1E9#H@)7,B"FUS9W-T<B`B3FEE=61A;GD@<WIU:V%N>2!O8FEE:W0@9&\@
M9&]D86YI83H@)7,B"@HC.B!D871A+G!H<#HQ,C0@<V5A<F-H+G!H<#HX.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H92!D:7)E
M8W1O<GDZ("5S(@IM<V=S='(@(DYI975D86YE('-Z=6MA;FEE(&MA=&%L;V=U
M.B`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM<V=I
M9"`B1F%X(@IM<V=S='(@(D9A:W,B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E
M87)C:"YI;F,Z-S(*;7-G:60@(D9I;F0B"FUS9W-T<B`B6FYA:F2\(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T($YA
M;64B"FUS9W-T<B`B26UIZB(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C(P,@IM<V=I9"`B1G)E96)U<WD@55),(@IM<V=S='(@(E523"!7;VQN
M>2]:86KJ='DB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.#4*
M;7-G:60@(D9R;VTB"FUS9W-T<B`B3V0B"@HC.B!C;VYF:6<O<V]U<F-E<RYP
M:'`N9&ES=#HU-C(*;7-G:60@(D=L;V)A;"!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B3V?S;&YA(&MS:;&_:V$@861R97-O=V$B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V-O;G1A8W1R;W<N:6YC.C0T"FUS9VED(")'<F]U<"(*;7-G<W1R(")'
M<G5P82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@R"FUS9VED
M(")(;VUE($%D9')E<W,B"FUS9W-T<B`B061R97,@9&]M;W=Y(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3,*;7-G:60@(DAO;64@0VET>2(*
M;7-G<W1R(")-:6%S=&\B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ,#@*;7-G:60@(DAO;64@0V]U;G1R>2(*;7-G<W1R(")+<F%J(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34P"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(E1E;&5F;VX@9&]M+B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$P,PIM<V=I9"`B2&]M92!0;W-T86P@0V]D92(*;7-G
M<W1R(")+;V0@<&]C>G1O=WDB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R(")7
M;VIE=_-DO'1W;R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X
M"FUS9VED(")(;VUE(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F5S(&1O
M;6]W>2(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0X-PIM<V=I9"`B
M24U34"(*;7-G<W1R("))35-0(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHY"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!!9&1R97-S($)O
M;VLL(%-T97`@)60B"FUS9W-T<B`B26UP;W)T(&MS:;&_:VD@861R97-O=V5J
M+"!K<F]K("5D(@H*(SH@9&%T82YP:'`Z,C<T"FUS9VED("));7!O<G0O17AP
M;W)T($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B26UP;W)T+T5K<W!O<G0@:W-I
ML;]K:2!A9')E<V]W96HB"@HC.B!L:6(O87!I+G!H<#HS-S@@;&EB+V%P:2YP
M:'`Z-C`T"FUS9VED("));G9A;&ED($-O;G1E;G0M5'EP92(*;7-G<W1R(").
M:65P;W!R87=N>2!#;VYT96YT+51Y<&4B"@HC.B!L:6(O87!I+G!H<#HT-#$@
M;&EB+V%P:2YP:'`Z-3,Q"FUS9VED("));G9A;&ED($E$(@IM<V=S='(@(DYI
M97!O<')A=VYY($E$(@H*(SH@;&EB+V%P:2YP:'`Z,3DQ(&QI8B]A<&DN<&AP
M.C,S-"!L:6(O87!I+G!H<#HT,S<@;&EB+V%P:2YP:'`Z-3(W"B,Z(&QI8B]A
M<&DN<&AP.C4X,"!L:6(O87!I+G!H<#HX.34*;7-G:60@(DEN=F%L:60@861D
M<F5S<R!B;V]K(@IM<V=S='(@(DYI97!O<')A=VYA(&MS:;&_:V$@861R97-O
M=V$B"@HC.B!L:6(O87!I+G!H<#HX.3D@;&EB+V%P:2YP:'`Z.3<S(&QI8B]A
M<&DN<&AP.C$P,C8*;7-G:60@(DEN=F%L:60@96UA:6PB"FUS9W-T<B`B3FEE
M<&]P<F%W;GD@96UA:6PB"@HC.B!L:6(O87!I+G!H<#HY,#<*;7-G:60@(DEN
M=F%L:60@96YT<GDB"FUS9W-T<B`B3FEE<&]P<F%W;GD@=W!I<R(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,C<Y"FUS9VED("));G9A;&ED(&ME>2!S<&5C
M:69I960N(@IM<V=S='(@(DYI97!O<')A=VYA(&1E9FEN:6-J82!K;'5C>F$N
M(@H*(SH@;&EB+V%P:2YP:'`Z.3`S"FUS9VED("));G9A;&ED(&YA;64B"FUS
M9W-T<B`B3FEE<&]P<F%W;F$@;F%Z=V$B"@HC.B!L:6(O87!I+G!H<#HU.#0*
M;7-G:60@(DEN=F%L:60@;V)J96-T260B"FUS9W-T<B`B3FEE<&]P<F%W;GD@
M;V)J96-T260B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,X"FUS9VED("(B
M"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L
M92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(@IM<V=S='(@(B(*
M(D]B<[-U9V$@3$1!4"!J97-T('=Y;6%G86YA+"!A;&4@;6]D=;,@3$1!4"!J
M97-T(&YI961O<W3J<&YY(&QU8B`B"B)N:65Z8;-A9&]W86YY+B(*"B,Z(&QI
M8B]/8FIE8W16:65W+G!H<#HQ,SD*;7-G:60@(DQA<W0@36]D:69I960B"FUS
M9W-T<B`B3W-T871N:6$@;6]D>69I:V%C:F$B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HU,PIM<V=I9"`B3&%S="!.86UE(@IM<V=S='(@(DYA
M>G=I<VMO(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI
M;F,Z.`IM<V=I9"`B3&ES="(*;7-G<W1R("),:7-T82(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O<V5A<F-H+FEN8SHW.0IM<V=I9"`B36%T8VAI;F<B"FUS9W-T
M<B`B1G)A>F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$*;7-G:60@
M(DUA>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM<V=S='(@(DUA:W-Y;6%L;F$@
M:6QOMN8@;F$@<W1R;V[J(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP
M.C,*;7-G:60@(DUI;FD@4V5A<F-H(@IM<V=S='(@(DUI;FD@=WES>G5K:7=A
M<FMA(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,34*;7-G:60@(DUI<W-I
M;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M0G)A:R!$3B!W(&MO;F9I9W5R86-J:2"\<O-DLV$@3$1!4"XB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0:&]N
M92(*;7-G<W1R(")496QE9F]N(&MO;2XB"@HC.B!L:6(O1')I=F5R+VQD87`N
M<&AP.C,T-"!L:6(O1')I=F5R+VQD87`N<&AP.C,V,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(DUO9'EF
M:6MA8VIA(&YI97!O=VEA9+-A('-IZCH@*"5S*2`E<R(*"B,Z(&QI8B]A<&DN
M<&AP.C$P,3(*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S
M='(@(E=IZF-E:B!N:;\@,2!W<&ES('IN86QE>FEO;GDB"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")-;W9E(@IM<V=S='(@
M(E!R>F5N:66V(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI
M;F,Z,C0W"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B4')Z96YI9;8@=R!L
M97=O(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y
M"FUS9VED(")-;W9E(')I9VAT(@IM<V=S='(@(E!R>F5N:66V('<@<')A=V\B
M"@HC.B!D871A+G!H<#HS,2!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(Q
M"FUS9VED(")-=6QB97)R>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B2W-IL7IK
M82!A9')E<V]W82!-=6QB97)R>2(*"B,Z(&QI8B]A<&DN<&AP.CDS,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I=&@@861D
M<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X
M:7-T(@IM<V=S='(@(DES=&YI96IE('=I96QE(&]S\V(@>B!A9')E<V5M(%LE
M<UTL(&%L92"_861N82!Z(&YA>G>Q(%LE<UTB"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HX-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR,C$*;7-G
M:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R(")-;VIA(&MS:;&_:V$@861R
M97-O=V$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT,@IM<V=I
M9"`B3F%M92(*;7-G<W1R(").87IW82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,@IM<V=I9"`B3F%M92!&;W)M870B"FUS9W-T<B`B1F]R;6%T(&YA
M>G=Y(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,CDU"FUS9VED(").
M971C96YT97(@365M8F5R($1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G($YE
M=&-E;G1E<B!-96UB97(B"@HC.B!A9&0N<&AP.C,V(&%D9"YP:'`Z,3`R(&QI
M8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HR-PIM<V=I9"`B3F5W($-O;G1A8W0B
M"FUS9W-T<B`B3F]W>2!K;VYT86MT(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR-@IM<V=I9"`B3F5W($QI<W0B"FUS9W-T<B`B3F]W82!L
M:7-T82(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#(*;7-G:60@
M(DYE>'0B"FUS9W-T<B`B3F%S=.IP;F4B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HR,3@*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(E!S975D
M;VYI;2(*"B,Z(&QI8B]A<&DN<&AP.C$P,30@;&EB+V%P:2YP:'`Z,3`V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E;G1R>2!F;W5N9"!F;W(@)7,B
M"FUS9W-T<B`B3FEE('IN86QE>FEO;GD@=W!I<R`E<R!D;&$@)7,B"@HC.B!L
M:6(O87!I+G!H<#HY.#(*;7-G:60@(DYO(&%D9')E<W,@8F]O:W,@9F]U;F0N
M(@IM<V=S='(@(DYI92!Z;F%L97II;VYO(&MS:;&_:VD@861R97-O=V5J+B(*
M"B,Z(&UI;FES96%R8V@N<&AP.C@W"FUS9VED(").;R!C;VYT86-T<R!F;W5N
M9"(*;7-G<W1R(").:64@>FYA;&5Z:6]N;R!K;VYT86MT\W<B"@HC.B!L:6(O
M87!I+G!H<#HS-38*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*
M;7-G<W1R(").:64@>FYA;&5Z:6]N;R!D86YY8V@@=D-A<F0N(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T
M<B`BKV%D96XB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*
M;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&%T:VDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#D*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G
M92(*;7-G<W1R("));&^VYB!W<&ES\W<@;F$@<W1R;V[J(@H*(SH@;&EB+V%P
M:2YP:'`Z-#8P"FUS9VED(")/8FIE8W0@;F]T(&9O=6YD(@IM<V=S='(@(D]B
M:F5K="!N:65Z;F%L97II;VYY(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B0FEU<F\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0*;7-G:60@(D]T:&5R($]P=&EO;G,B
M"FUS9W-T<B`B26YN92!O<&-J92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B2VQU
M8WH@<'5B;&EC>FYY(%!'4"(*"B,Z(&QI8B]A<&DN<&AP.C,T,"!L:6(O87!I
M+G!H<#HT-#<@;&EB+V%P:2YP:'`Z-3,W(&QI8B]A<&DN<&AP.C4Y-@HC.B!L
M:6(O87!I+G!H<#HW-3,@;&EB+V%P:2YP:'`Z.3$S"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R(")"<F%K(&1O<W3J<'4B"@HC.B!L:6(O1')I
M=F5R+G!H<#HT,S8*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@
M(D)R86L@9&]S=.IP=2(*"B,Z(&1A=&$N<&AP.C,R('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,C(*;7-G:60@(E!I;F4@061D<F5S<R!";V]K(@IM<V=S
M='(@(DMS:;&_:V$@861R97-O=V$@4&EN92(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z,S`*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@
M;F%M92!O9B!T:&4@;F5W(&QI<W0Z(@IM<V=S='(@(E!O9&%J(&YA>G?J(&1L
M82!N;W=E:B!L:7-T>3HB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L
M96-T+FEN8SHR,C$*;7-G:60@(E!L96%S92!S96QE8W0@82!D:7)E8W1O<GDZ
M(@IM<V=S='(@(E=Y8FEE<GH@:V%T86QO9SHB"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HS.3D*;7-G:60@(E!R:79A=&4@061D<F5S<R!";V]K(@IM
M<V=S='(@(E!R>7=A=&YA(&MS:;&_:V$@861R97-O=V$B"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C$U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")1=65R>2!F
M86EL960Z("@E<RD@)7,B"FUS9W-T<B`B6F%P>71A;FEE(&YI92!P;W=I;V2S
M;R!S:>HZ("@E<RD@)7,B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C
M:"YI;F,Z,3@*;7-G:60@(E%U:6-K(%-E87)C:"(*;7-G<W1R(")3>GEB:VEE
M('-Z=6MA;FEE(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3D@;&EB+T1R
M:79E<B]L9&%P+G!H<#HR,#<@;&EB+T1R:79E<B]L9&%P+G!H<#HT-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A9"!F86EL960Z("@E<RD@)7,B"FUS9W-T
M<B`B0WIY=&%N:64@;FEE('!O=VEO9+-O('-IZCH@*"5S*2`E<R(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR"FUS9VED(")296-O<F1S(&1I
M<W!L87EE9#HB"FUS9W-T<B`B5WFV=VEE=&QO;F4@<F5K;W)D>3HB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,SD*;7-G:60@(E)E
M;6]V92!C;VQU;6XB"FUS9W-T<B`B57-U\2!K;VQU;6[J(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"FUS9VED(")296UO=F4@9G)O;2!T
M:&ES(&QI<W0B"FUS9W-T<B`B57-U\2!Z('1E:B!L:7-T>2(*"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,C8*;7-G:60@(B(*(E)E<&QA8V4@97AI
M<W1I;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/&(^
M5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@
M8W5R<F5N="!A9&1R97-S(&)O;VLN/"]B/B(*;7-G<W1R("(B"B):87-TL7!I
MYB!O8F5C;K$@:W-IL;]KZB!A9')E<V]WL2!I;7!O<G1O=V%NL3\@/&(^3W-T
M<GIEOV5N:64Z(%1A(&]P97)A8VIA("(*(G5S=6YI92!D;W1Y8VAC>F%S;W=E
M('=P:7-Y('<@;V)E8VYE:B!K<VFQOV-E(&%D<F5S;W=E:BX\+V(^(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z,S,P"FUS9VED(")297%U97-T960@;V)J96-T(&YO
M="!F;W5N9"XB"FUS9W-T<B`BKV%D86YY(&]B:F5K="!N:65Z;F%L97II;VYY
M+B(*"B,Z(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC
M.C$R-@IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B4')Z>7=R
M\V,@9&]M>;9L;F4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M.38*;7-G:60@(E,O34E-12!0=6)L:6,@0V5R=&EF:6-A=&4B"FUS9W-T<B`B
M4'5B;&EC>FYY(&-E<G1Y9FEK870@4R]-24U%(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")35$%25%1,4R!F86EL
M960Z("@E<RD@)7,B"FUS9W-T<B`B3W!E<F%C:F$@4U1!4E143%,@;FEE('!O
M=VEO9+-A('-IZCH@*"5S*2`E<R(*"B,Z(&%D9"YP:'`Z,S<@961I="YP:'`Z
M-3<*;7-G:60@(E-A=F4B"FUS9W-T<B`B6F%P:7-Z(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]S96%R8V@N:6YC.CDX('1E;7!L871E<R]B<F]W<V4O<V5A<F-H
M+FEN8SHQ,C4*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(E-E87)C:"(*;7-G
M<W1R(")3>G5K86HB"@HC.B!M:6YI<V5A<F-H+G!H<#HV-B!B<F]W<V4N<&AP
M.C(T,0IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B5WEN:6MI('=Y
M<WIU:VEW86YI82(*"B,Z(&QI8B]A<&DN<&AP.C@R.0IM<V=I9"`B4V5A<F-H
M(&9A:6QE9"(*;7-G<W1R(")7>7-Z=6MI=V%N:64@;FEE('!O=VEO9+-O('-I
MZB(*"B,Z(&QI8B]A<&DN<&AP.CDR,B!L:6(O87!I+G!H<#HY,C@@;&EB+V%P
M:2YP:'`Z.3,W(&QI8B]A<&DN<&AP.CDU,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")396%R8V@@9F%I;&5D.B`E<R(*;7-G<W1R(")7>7-Z=6MI=V%N:64@;FEE
M('!O=VEO9+-O('-I93H@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C@*;7-G:60@(E-E87)C:&EN9R!/<'1I;VYS(@IM<V=S='(@(D]P8VIE('=Y
M<WIU:VEW86YI82(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN
M8SHR-`IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S='(@(E-Z=6MA;FEE+BXN
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96QE8W0N:6YC.CD*;7-G:60@(E-E
M;&5C="!!9&1R97-S($)O;VLB"FUS9W-T<B`B5WEB:65R>B!K<VFQOVOJ(&%D
M<F5S;W>Q(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR-`IM
M<V=I9"`B4V5L96-T($QI<W0B"FUS9W-T<B`B5WEB:65R>B!L:7-TZB(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S<*;7-G:60@(E-E;&5C="!T
M:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G<W1R(")7>6)I
M97)Z(&MS:;&_:^H@861R97-O=[$@9&\@96MS<&]R=&]W86YI83HB"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,Q"FUS9VED(")396QE8W0@=&AE
M(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM<V=S='(@(E=Y8FEE<GH@
M:W-IL;]KZB!A9')E<V]WL2!D;R!Z86EM<&]R=&]W86YI83HB"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$T"FUS9VED(")396QE8W0@=&AE(&5X
M<&]R="!F;W)M870Z(@IM<V=S='(@(E=Y8FEE<GH@9F]R;6%T(&5K<W!O<G1O
M=V%N:6$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,`IM<V=I
M9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B5WEB:65R
M>B!P;&EK(&1O('IA:6UP;W)T;W=A;FEA.B(*"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H
M92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B5WEB:65R>B!F;W)M870@<&QI:W4@
MO'+S9+-O=V5G;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"FUS
M9VED(")396QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@;F%M97,Z
M(@IM<V=S='(@(E=Y8FEE<GH@9F]R;6%T('6_>7=A;GD@9&\@=WFV=VEE=&QA
M;FEA(&YA>G<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED
M(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0N(@IM<V=S='(@
M(E=Y8FEE<GH@9&]M>;9L;GD@<W!O<_-B('=YMG=I971L86YI82XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*;7-G:60@(E-E;&5C="!W:&EC:"!F
M:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS9W-T
M<B`B5WEB:65R>B!P;VQA+"!K=/-R92!BZF2Q('=YMG=I971L86YE(&YA(&QI
MMF-I92!A9')E<V]W96HN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M"FUS9VED(")396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@;F%M97,N
M(@IM<V=S='(@(E=Y8FEE<GH@9F]R;6%T('=YMG=I971L86YY8V@@;F%Z=RXB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#,*;7-G
M:60@(E-E;&5C=&5D($-O;'5M;G,Z(@IM<V=S='(@(E=Y8G)A;F4@:V]L=6UN
M>3HB"@HC.B!A9&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(E-E;&5C
M=&5D(&%D9')E<W,@8F]O:R!<(B5S7"(N(@IM<V=S='(@(E=Y8G)A;F$@:W-I
ML;]K82!A9')E<V]W82!<(B5S7"(N(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP
M+F1I<W0Z,34T"FUS9VED(")3:&%R960@1&ER96-T;W)Y(@IM<V=S='(@(E5D
M;W-TZG!N:6]N>2!K871A;&]G(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHT,@IM<V=I9"`B4VAO7W<@06QL(@IM<V=S='(@(E!O:V&_(%]W
M<WIY<W1K:64B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E;&5C="YI;F,Z,3$*
M;7-G:60@(E-H;W<B"FUS9W-T<B`B4&]K8;\B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C0R"FUS9VED(")3:&]W($%L;"(*;7-G<W1R(")0
M;VMAOR!W<WIY<W1K:64B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N
M:6YC.C0Q"FUS9VED(")3:&]W($-O;G1A8W1S(@IM<V=S='(@(E!O:V&_(&MO
M;G1A:W1Y(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM
M<V=I9"`B4VAO=R!,:7-T<R(*;7-G<W1R(")0;VMAOR!L:7-T>2(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H;W<@7T-O
M;G1A8W1S(@IM<V=S='(@(E!O:V&_(&MO;G1A:W1Y("A?8RDB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"FUS9VED(")3:&]W(%],:7-T
M<R(*;7-G<W1R(")0;VMAOR!?;&ES='DB"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V-O;'5M;E]H96%D97)S+FEN8SHQ,`HC.B!T96UP;&%T97,O8G)O=W-E+V-O
M;'5M;E]H96%D97)S+FEN8SHQ-0IM<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS
M9W-T<B`B4W!O<_-B('-O<G1O=V%N:6$B"@HC.B!L:6(O87!I+G!H<#HQ-30*
M;7-G:60@(E-O=7)C97,B"FUS9W-T<B`BK'+S9+-A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,`IM<V=I9"`B4W!E8VEF>2!W:&5R92!Y;W4@=V%N
M="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N(@IM<V=S='(@
M(D]K<F6V;"!G9'II92!M86JQ(&)YYB!W>6YI:VD@>F%A=VYS;W=A;F5G;R!S
M>G5K86YI82XB"@HC.B!B<F]W<V4N<&AP.C$S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,B"FUS9W-T<B`B4&]M
M>;9L;FEE(&1O9&%N92`E<R!D;R`E<R(*"B,Z(&1A=&$N<&AP.C(Y"FUS9VED
M(")44U8B"FUS9W-T<B`B5%-6(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHQ.2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$X"FUS9VED(")4
M86(@<V5P87)A=&5D('9A;'5E<R(*;7-G<W1R(")486(@;V1D>FEE;&$@=V%R
M=&^V8VDB"@HC.B!D871A+G!H<#HR,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G
M<W1R(")+<VFQOVMA(&%D<F5S;W=A(&YI92!M;V>S82!B>>8@=WEC>GES>F-Z
M;VYA.B`E<R(*"B,Z('9C87)D+G!H<#HR,B!E9&ET+G!H<#HR-"!D:7-P;&%Y
M+G!H<#HR,PIM<V=I9"`B5&AE(&-O;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B2V]N=&%K="P@:W3S<F5G;R!S>G5K87-Z
M(&YI92!I<W1N:65J92XB"@HC.B!B<F]W<V4N<&AP.C,S"FUS9VED(")4:&5R
M92!A<F4@;F\@8G)O=W-E86)L92!A9&1R97-S(&)O;VMS+B(*;7-G<W1R(")"
M<F%K(&MS:;&_:VD@861R97-O=V5J('H@;6^_;&EW;[9C:;$@<')Z96=LL61A
M;FEA(@H*(SH@861D+G!H<#HR.0IM<V=I9"`B(@HB5&AE<F4@87)E(&YO('=R
M:71E86)L92!A9&1R97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@
M861D<F5S<R!B;V]K<R`B"B)A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@
M=&\@861D(&YE=R!E;G1R:65S('1O('1H96TN($EF('EO=2!B96QI979E('1H
M:7,@(@HB:7,@86X@97)R;W(L('!L96%S92!C;VYT86-T('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D)R86L@:W-IL;]K:2!A9')E
M<V]W96H@>B!M;[]L:7=OMF-IL2!Z87!I<W5J+B"O861N82!Z(&1O<W3J<&YY
M8V@@:W-IL;]E:R`B"B)A9')E<V]W>6-H(&YI92!Z;W-T8;-A('-K;VYF:6=U
M<F]W86YA('H@;6^_;&EW;[9C:;$@9&]D87=A;FEA(&YO=WEC:"!W<&ES\W<N
M("(*(DIEMFQI('.Q9'II<WHL(+]E('1O(&IE<W0@8K.Q9"P@<VMO;G1A:W1U
M:B!S:>H@>B!A9&UI;FES=&%T;W)E;2!S>7-T96UU+B(*"B,Z(&%D9"YP:'`Z
M.3D*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE
M=R!C;VYT86-T+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M(@HB9F]R(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB5WES=+%P:;,@8K.Q
M9"!P;V1C>F%S(&1O9&%W86YI82!N;W=E9V\@:V]N=&%K='4N(%-K;VYT86MT
M=6H@<VGJ('H@='=O:6T@(@HB861M:6YI<W1R871O<F5M('-Y<W1E;74@=R!C
M96QU('5Z>7-K86YI82!P;VUO8WDN(@H*(SH@8G)O=W-E+G!H<#HQ.#4*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*
M;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O9&-Z87,@='=O<GIE;FEA(&YO=V5J
M(&QI<W1Y+B(*"B,Z(&)R;W=S92YP:'`Z,3,V"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R`E<R!F<F]M('1H92!S
M;W5R8V4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O
M9&-Z87,@=7-U=V%N:6$@)7,@>F4@O'+S9+-A(&MS:;&_:VD@861R97-O=V5J
M+B(*"B,Z(&1E;&5T92YP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B"FUS
M9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S('5S=7=A;FEA('1E9V\@:V]N
M=&%K='4Z("5S(@H*(SH@8G)O=W-E+G!H<#HV.`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R(")7>7-T
ML7!ILR!BL[%D('!O9&-Z87,@:V%S;W=A;FEA('1E9V\@;V)J96MT=2XB"@HC
M.B!B<F]W<V4N<&AP.C(W,PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AE('-E;&5C="!,:7-T(@IM<V=S='(@(E=Y<W2Q<&FS(&*S
M860@<&]D8WIA<R!W>;9W:65T;&%N:6$@=WEB<F%J;F5J(&QI<W1Y(@H*(SH@
M9&%T82YP:'`Z,C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(E=Y<W2Q
M<&FS(&*SL60@<&]D8WIA<R!I;7!O<G1O=V%N:6$@9&%N>6-H.B`E<R(*"B,Z
M(&QI8B]A<&DN<&AP.C,U,@IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E=Y<W2Q<&FS
M(&*SL60@<&]C>F%S(&EM<&]R=&]W86YI82!D86YY8V@@:4-A;&5N9&%R+B(*
M"B,Z(&)R;W=S92YP:'`Z-3@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R
M96UO=FEN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P
M;V1C>F%S('5S=7=A;FEA('1E9V\@;V)J96MT=2XB"@HC.B!E9&ET+G!H<#HX
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AI<R!E;G1R>3H@)7,B"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P
M;V1C>F%S(&%K='5A;&EZ86-J:2!T96=O('=P:7-U.B`E<R(*"B,Z(&1A=&$N
M<&AP.C$U,0IM<V=I9"`B5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP
M;W)T+B(*;7-G<W1R(")"<F%K(&%D<F5S\W<@9&\@96MS<&]R=&]W86YI82XB
M"@HC.B!L:6(O1')I=F5R+G!H<#HS.3`@;&EB+T1R:79E<BYP:'`Z-#(W"FUS
M9VED(")4:&ES(&%D9')E<W,@8F]O:R!I<R!R96%D+6]N;'DB"FUS9W-T<B`B
M5&$@:W-IL;]K82!A9')E<V]W82!J97-T('1Y;&MO(&1O(&]D8WIY='4B"@HC
M.B!D871A+G!H<#HR,3$*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B5&5N(&9O<FUA="!P;&EK=2!J97-T(&YI
M96]B<[-U9VEW86YY+B(*"B,Z(&QI8B]A<&DN<&AP.CDT,2!L:6(O87!I+G!H
M<#HY-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D
M>2!H87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@
M(E1A(&]S;V)A(&IUOR!M82!W<&ES("5S('<@:W-IL;]C92!A9')E<V]W96HB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW,`IM<V=I9"`B5&ET
M;&4B"FUS9W-T<B`B5'ET=;,B"@HC.B!L:6(O1')I=F5R+G!H<#HX,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(DYI92!M;V?J('=C>GET8>8@9&5F:6YI8VII
M("5S+B(*"B,Z(&5D:70N<&AP.C4W"FUS9VED(")5;F1O($-H86YG97,B"FUS
M9W-T<B`B0V]F;FEJ('IM:6%N>2(*"B,Z(&QI8B]A<&DN<&AP.C0X.0IM<V=I
M9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E+B(*;7-G<W1R(").:65O8G.S
M=6=I=V%N>2!#;VYT96YT+51Y<&4N(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP
M+F1I<W0Z,S4X"FUS9VED(")697)I<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`B
M2V%T86QO9R!697)I<VEG;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]N=&%C
M=')O=RYI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!<(B5S7"(B
M"FUS9W-T<B`B5VED;VL@7"(E<UPB(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#(*
M;7-G:60@(E9I97<@0V]N=&%C="(*;7-G<W1R("):;V)A8WH@:V]N=&%K="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B5FEE=R!T;R!D
M:7-P;&%Y(&)Y(&1E9F%U;'0Z(@IM<V=S='(@(D1O;7FV;&YI92!W>;9W:65T
M;&%J.B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I
M9"`B5V5B<VET92!54DPB"FUS9W-T<B`B55),('-T<F]N>2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q,PIM<V=I9"`B5V]R:R!!9&1R97-S
M(@IM<V=S='(@(D%D<F5S(&1O('!R86-Y(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3(T"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B36EA
M<W1O("AP<F%C82DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M,SD*;7-G:60@(E=O<FL@0V]U;G1R>2(*;7-G<W1R(")+<F%J("AP<F%C82DB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O
M<FL@4&AO;F4B"FUS9W-T<B`B5&5L969O;B`H<')A8V$I(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,T"FUS9VED(")7;W)K(%!O<W1A;"!#
M;V1E(@IM<V=S='(@(DMO9"!P;V-Z=&]W>2`H<')A8V$I(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(Y"FUS9VED(")7;W)K(%-T871E+U!R
M;W9I;F-E(@IM<V=S='(@(E=O:F5W\V2\='=O("AP<F%C82DB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3D*;7-G:60@(E=O<FL@4W1R965T
M($%D9')E<W,B"FUS9W-T<B`B061R97,@<')A8WDB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C,P"FUS9VED(")9;W4@87)E(&-R96%T
M:6YG(&$@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(E-T=V]R>GFS9;8@
M;&ES=.H@9'ES=')Y8G5C>6INL2XB"@HC.B!E9&ET+G!H<#HT-"!D:7-P;&%Y
M+G!H<#HU.0IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@(DYI92!M87-Z('!R87<@86)Y
M('IO8F%C>GGF('1E;B!K;VYT86MT+B(*"B,Z('9C87)D+G!H<#HT,`IM<V=I
M9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B
M:F5C="XB"FUS9W-T<B`B3FEE(&UA<WH@<')A=R!A8GD@>F]B86-Z>>8@=&5N
M(&]B:F5K="XB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C4Q"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@861D<F5S<R!B
M;V]K+B(*;7-G<W1R(")-=7-I<WH@=WEB<F'F(&1O8V5L;W>Q(&MS:;&_:^H@
M861R97-O=[$N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN
M8SHR,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N(@IM
M<V=S='(@(DUU<VES>B!W>6)R8>8@9&]C96QO=[$@;&ES=.HN(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O8G)O
M=W-E+VIA=F%S8W)I<'0N:6YC.C0U"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V
M87-C<FEP="YI;F,Z-C@*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S
M="!O;F4@96YT<GD@9FER<W0N(@IM<V=S='(@(DUU<VES>B!W8GER8>8@;F%J
M<&EE<G<@<')Z>6YA:FUN:65J(&IE9&5N('=P:7,N(@H*(SH@961I="YP:'`Z
M-#@*;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H
M:7,@8V]N=&%C="XB"FUS9W-T<B`B36%S>B!U<')A=VYI96YI82!T>6QK;R!D
M;R!P;V1G;+%D=2!T96=O(&MO;G1A:W1U+B(*"B,Z(&)R;W=S92YP:'`Z,C@T
M"FUS9VED(")9;W5R(&1E9F%U;'0@861D<F5S<V)O;VL@:7,@;F]T(&)R;W=S
M96%B;&4N(@IM<V=S='(@(E1W;VIA(&1O;7FV;&YA(&MS:;&_:V$@861R97-O
M=V$@;FEE(&IE<W0@<')Z96=LL61A;&YA+B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@(EMN;R!V86QU95TB"FUS9W-T
M<B`B6V)R86L@=V%R=&^V8VE=(@H*(SH@;&EB+U1U<F)A+G!H<#HR.#8*;7-G
M:60@(E]!9&0B"FUS9W-T<B`B1&]D7V%J(@H*(SH@;&EB+U1U<F)A+G!H<#HR
M.#,*;7-G:60@(E]"<F]W<V4B"FUS9W-T<B`B4')Z96=LL61A:B`H7V(I(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"FUS9VED(")?1&5L
M971E(@IM<V=S='(@(E5S=?$@*%]D*2(*"B,Z(&QI8B]4=7)B82YP:'`Z,CDR
M"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G<W1R(")?26UP;W)T+T5K<W!O
M<G0B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*;7-G:60@
M(E]296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B57-U\2!Z('1E:B!L
M:7-T>2`H7W(I(@H*(SH@;&EB+U1U<F)A+G!H<#HR.#@*;7-G:60@(E]396%R
M8V@B"FUS9W-T<B`B7U-Z=6MA:B(*"B,Z('9C87)D+G!H<#HT-@IM<V=I9"`B
M8V]N=&%C="YV8V8B"FUS9W-T<B`B:V]N=&%K="YV8V8B"@HC.B!D871A+G!H
M<#HQ-S(@9&%T82YP:'`Z,3<W('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(FMO;G1A:W1Y+F-S=B(*
M"B,Z(&1A=&$N<&AP.C$X,@IM<V=I9"`B8V]N=&%C=',N='-V(@IM<V=S='(@
M(FMO;G1A:W1Y+G1S=B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI
M;F,Z,30*;7-G:60@(G1O(%-E;&5C=&5D($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")W>6)R86YA(&MS:;&_:V$@861R97-O=V$B"@HC.B!D871A+G!H<#HS,"!T
M96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHW"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,C`@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHR,`IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1U<F)A+W!O+V1A7T1++G!O````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-S$P,3$`,3`T,3<S-C(W-38`,#$W-#8Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@5'5R8F$@
M1&%N:7-H('1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@36%R=&EN($QI
M<W0M4&5T97)S96X@/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K/BP@,C`P,2X*
M(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@5'5R
M8F$@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#$M,#8@
M,3,Z,#0K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!-87)T:6X@3&ES="U0
M971E<G-E;B`\;6%R=&EN0&QI<W0M<&5T97)S96XN9&L^7&XB"B),86YG=6%G
M92U496%M.B!$86YI<V@@/&1K+6AO<F1E0&AU;'!S>7-T96US+FYE=#Y<;B(*
M(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=%QN(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T
M+FEN8SHT,@IM<V=I9"`B($%D9"!A;B!)35-0($%D9')E<W,@0F]O:R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C,Q"FUS
M9VED("(@1&5L971E($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z
M(&1A=&$N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR
M96%D>2!E>&ES=',@86YD('=A<R!N;W0@:6UP;W)T960N(@IM<V=S='(@(B(*
M"B,Z(&)R;W=S92YP:'`Z,3(V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@
M(EPB1FER<W1N86UE($QA<W1N86UE7"(@("AI92X@2F]H;B!$;V4I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(EPB
M3&%S=&YA;64L($9I<G-T;F%M95PB("AI92X@1&]E+"!*;VAN*2(*;7-G<W1R
M("(B"@HC.B!A9&0N<&AP.C$P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M9&1E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S0S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R=&5D(@IM<V=S
M='(@(DEM<&]R="!A9B`E<R!F:6QE;B!L>6MK961E<R(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O9F]O=&5R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('1O("5S(&]F("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#0V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O
M:R(*;7-G<W1R("));7!O<G1E<B!A9')E<W-E:V%R=&]T96LB"@HC.B!L:6(O
M0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#4*;7-G:60@(D$@8G)O=W-E<B!T:&%T
M('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.0IM<V=I9"`B06)O=F4@<V5A<F-H
M(&9O<FTB"FUS9W-T<B`B(@H*(SH@=FEE=RYP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B06-C97-S(&1E;FEE9"!T;R`E<R(*;7-G<W1R("(B"@HC.B!A
M9&0N<&AP.C4V('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C(*;7-G
M:60@(D%D9"(*;7-G<W1R(")4:6QF^&HB"@HC.B!T96UP;&%T97,O<')E9G,O
M861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-`HC+"!F=7IZ>0IM<V=I9"`B061D
M(&%D9')E<W,@8F]O:R(*;7-G<W1R(")59WEL9&EG(&%D<F5S<V5K87)T;W1E
M:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.`HC+"!F=7IZ>0IM<V=I
M9"`B061D(&%N9"!$96QE=&4@24U34"!A9&1R97-S(&)O;VMS(@IM<V=S='(@
M(D1E<B!F:6YD97,@:6YG96X@861R97-S96MA<G1O=&5K97(L('-O;2!D97(@
M:V%N(&=E;6UE<R!I+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE
M8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!E
M9&ET+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D%D9"!F:6QE(@IM<V=S='(@
M(DMU;FYE(&EK:V4@=&EL9OAJ92(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R(*;7-G<W1R(")4
M:6QF^&HB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F
M=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DEM<&]R=&5R(&%D
M<F5S<V5K87)T;W1E:R(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K($QI
M<W1I;F<B"FUS9W-T<B`B061R97-S96MA<G1O=&5K970@97(@<VMR:79E8F5S
M:WET=&5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(DEM<&]R=&5R(&%D<F5S
M<V5K87)T;W1E:R(*"B,Z(&%D9"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")!
M9&1R97-S(&)O;VL@96YT<GDB"FUS9W-T<B`B061R97-S96MA<G1O=&5K970@
M97(@<VMR:79E8F5S:WET=&5T(@H*(SH@9&%T82YP:'`Z,S`U"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS
M9W-T<B`B26UP;W)T(&%F("5S(&9I;&5N(&QY:VME9&5S(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9')E
M<W,@8F]O:R!T;R!D96QE=&4@(@IM<V=S='(@(D%D<F5S<V5K87)T;W1E:V5T
M(&5R('-K<FEV96)E<VMY='1E="(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R
M97-S8F]O:W-E;&5C="YI;F,Z,3<P"FUS9VED(")!9&1R97-S(&)O;VMS('1H
M870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R("(B"@HC.B!S96%R
M8V@N<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS-PIM<V=I
M9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(E5D=FED970@<_AG;FEN9R(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C8T"FUS9VED(")!;&EA
M<R(*;7-G<W1R(")+86QD96YA=FXB"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O
M;W1E<D%L<&AA+FEN8SHW('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N
M:6YC.C$P"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G
M:60@(D%L;"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HU-3(*;7-G:60@
M(D%L<F5A9'D@17AI<W1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C8W"FUS
M9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@=&AE
M('-E;&5C=&5D(&5N=')I97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-@IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(B(*"B,Z
M('-E87)C:"YP:'`Z.#4@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,V
M"B,L(&9U>GIY"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B4_AG(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B0F5L;W<@<V5A
M<F-H(&9O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW
M-R!L:6(O1')I=F5R+VQD87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C<*;7-G:60@(D)R;W=S92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*
M;7-G:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&1A=&$N
M<&AP.C0Y"FUS9VED(")#4U8B"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C="]'
M<F]U<"YP:'`Z-3<*;7-G:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L
M9BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A
M9&5R<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C0T"FUS9VED(")#:&]O
M<V4@82!N86UE(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z-#@*(RP@9G5Z>GD*
M;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLB"FUS9W-T<B`B56=Y;&1I
M9R!A9')E<W-E:V%R=&]T96LB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR,C$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A9&1R
M97-S(&)O;VLZ(@IM<V=S='(@(E5G>6QD:6<@861R97-S96MA<G1O=&5K(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-C4*
M;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O(&1I<W!L87DL
M(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O
M;VMS('1O('5S92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O
M;'5M;G-E;&5C="YI;F,Z,C(X"FUS9VED(")#:&]O<V4@=VAI8V@@8V]L=6UN
M<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D-O;'5M;B!/<'1I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE
M8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I
M<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")#
M;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V5X<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V
M86QU97,@*$UI8W)O<V]F="!/=71L;V]K*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R(")&:7)M82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T
M-`HC+"!F=7IZ>0IM<V=I9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S='(@(D%D
M<F5S<V4@*&AJ96UM92DB"@HC.B!L:6(O87!I+G!H<#HS,3@@;&EB+V%P:2YP
M:'`Z,S8S(&QI8B]A<&DN<&AP.C0P-R!L:6(O87!I+G!H<#HT.3$*(SH@;&EB
M+V%P:2YP:'`Z-C`Q(&QI8B]A<&DN<&AP.C8X."!L:6(O87!I+G!H<#HW-#$@
M;&EB+V%P:2YP:'`Z.#$Y"B,Z(&QI8B]A<&DN<&AP.C$P,#8@;&EB+V%P:2YP
M:'`Z,3`Y-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(E-L971N:6YG(&UI<VQY:VME9&5S(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(E-L971N:6YG(&UI<VQY:VME9&5S
M(@H*(SH@8G)O=W-E+G!H<#HQ.3$@8G)O=W-E+G!H<#HR,S(*;7-G:60@(D-O
M;G1A8W0@861D960@=&\@;&ES="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H
M<#HV,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*
M;7-G<W1R(")&:7)M82(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C4S"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B16MS<&]R=&5R(&%D<F5S<V5K87)T;W1E:R(*
M"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A=&4@82!N97<@
M0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T5FEE
M=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I
M<F5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K
M<RYI;F,Z-S8@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z(&QI
M8B]/8FIE8W0N<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]296YD
M97)E<BYP:'`Z-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")3;&5T(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B16MS<&]R=&5R(&%D<F5S
M<V5K87)T;W1E:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I
M9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I
M;W5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C<P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D.B`H)7,I
M("5S(@IM<V=S='(@(E-L971N:6YG(&UI<VQY:VME9&5S(@H*(SH@9&5L971E
M+G!H<#HS.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S='(@(E-L971N
M:6YG(&UI<VQY:VME9&5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<V5A<F-H+FEN8SHQ,3@*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")+871A
M;&]G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS9VED(")$:7-P
M;&%Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$W-@IM<V=I9"`B1&\@>6]U('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E
M;G1R:65S/R(*;7-G<W1R("(B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*;7-G
M:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<F]W+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(U
M"FUS9VED(")$;W=N;&]A9"!V0V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N
M:6YC.C(U"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC
M.C$P('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PHC.B!T96UP;&%T
M97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z
M-#(*;7-G:60@(D5D:70B"FUS9W-T<B`B4F5D:6=E<B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O<F]W+FEN8SHR-2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C,S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB
M)7-<(B(*;7-G<W1R(")2961I9V5R(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z.#$*(RP@9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K
M<R(*;7-G<W1R(")%:W-P;W)T97(@861R97-S96MA<G1O=&5K(@H*(SH@961I
M="YP:'`Z-S@@961I="YP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@96YT<GD@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C4X"FUS9VED(")%;6%I;"(*;7-G<W1R(")E36%I;"(*
M"B,Z(&5D:70N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F
M;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D960@9FEL92!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$T.2!E9&ET+G!H
M<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T
M960N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z-S0*(RP@9G5Z>GD*;7-G
M:60@(D5N=')Y('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("));7!O
M<G0@868@)7,@9FEL96X@;'EK:V5D97,B"@HC.B!L:6(O87!I+G!H<#HT,3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E87)C:&EN9R!T
M:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")$97(@9FEN9&5S(&EN9V5N
M(&%D<F5S<V5K87)T;W1E:V5R+"!S;VT@9&5R(&MA;B!G96UM97,@:2XB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(D5K<W!O
M<G1E<B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-@HC+"!F=7IZ
M>0IM<V=I9"`B17AP;W)T($%D9')E<W,@0F]O:R(*;7-G<W1R(")%:W-P;W)T
M97(@861R97-S96MA<G1O=&5K(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHR,0IM<V=I9"`B17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A
M8W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C(W"FUS9VED(")%>'!O<G0@=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@
M8V]M<&QE=&5L>2XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,3,T(&1A=&$N
M<&AP.C(R."!D871A+G!H<#HR.3<@8G)O=W-E+G!H<#HS-2!B<F]W<V4N<&AP
M.CDP"B,Z(&)R;W=S92YP:'`Z,3$R(&%D9"YP:'`Z-C<@<V5A<F-H+G!H<#HS
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%C8V5S
M<R!T:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")+=6YN92!I:VME('/X
M9V4@:2!K871A;&]G970Z("5S(@H*(SH@8G)O=W-E+G!H<#HQ,SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z
M("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@<_AG92!I(&MA=&%L;V=E=#H@)7,B
M"@HC.B!B<F]W<V4N<&AP.C(W,@IM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!L
M:7-T(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,S$P"B,L(&9U>GIY"FUS
M9VED(")&86EL960@=&\@8G)O=W-E('1H92!D:7)E8W1O<GDB"FUS9W-T<B`B
M2W5N;F4@:6MK92!S^&=E(&D@:V%T86QO9V5T.B`E<R(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,S`Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]
M("5S+"!2;V]T(#T@)7,B"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B
M:F5C="!T;R!B92!A9&1E9#H@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!S^&=E
M(&D@:V%T86QO9V5T.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*(RP@9G5Z>GD*
M;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G
M<W1R(")+=6YN92!I:VME('/X9V4@:2!K871A;&]G970Z("5S(@H*(SH@9&%T
M82YP:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!S96%R
M8V@@=&AE(&1I<F5C=&]R>3H@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!S^&=E
M(&D@:V%T86QO9V5T.B`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$V-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&5D:70N<&AP
M.C$R-"!D:7-P;&%Y+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D9I;&5S(@IM
M<V=S='(@(E1I=&5L(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC
M.C<P"FUS9VED(")&:6YD(@IM<V=S='(@(D9I;F0B"@HC.B!E9&ET+G!H<#HY
M-R!E9&ET+G!H<#HQ.#<*(RP@9G5Z>GD*;7-G:60@(D9I;FES:"(*;7-G<W1R
M(")&:6YD(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G
M:60@(D9I<G-T($YA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,C`R"FUS9VED(")&<F5E8G5S>2!54DPB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C@S"FUS9VED(")&
M<F]M(@IM<V=S='(@(D9R82(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C8P-`HC+"!F=7IZ>0IM<V=I9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G
M<W1R(")%:W-P;W)T97(@861R97-S96MA<G1O=&5K(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]R;W<N:6YC.C0S('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O
M=RYI;F,Z-#0*;7-G:60@(D=R;W5P(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C@R"FUS9VED(")(;VUE($%D9')E<W,B"FUS
M9W-T<B`B061R97-S92`H:&IE;6UE*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.CDS"FUS9VED(")(;VUE($-I='DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`X"B,L(&9U>GIY"FUS9VED
M(")(;VUE($-O=6YT<GDB"FUS9W-T<B`B5&5L969O;B`H:&IE;6UE*2(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U,`IM<V=I9"`B2&]M92!0
M:&]N92(*;7-G<W1R(")496QE9F]N("AH:F5M;64I(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3`S"B,L(&9U>GIY"FUS9VED(")(;VUE(%!O
M<W1A;"!#;V1E(@IM<V=S='(@(E1E;&5F;VX@*&AJ96UM92DB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B2&]M
M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R(")496QE9F]N("AH:F5M;64I(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.#@*(RP@9G5Z>GD*;7-G
M:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS9W-T<B`B061R97-S92`H:&IE
M;6UE*2(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C4P-@IM<V=I9"`B
M24U34"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<*
M;7-G:60@(DE-4U`@061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T($%D9')E<W,@0F]O:RP@4W1E
M<"`E9"(*;7-G<W1R("));7!O<G1E<B!A9')E<W-E:V%R=&]T96LB"@HC.B!D
M871A+G!H<#HS-C$*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="]%>'!O<G0@061D
M<F5S<R!";V]K<R(*;7-G<W1R("));7!O<G0O16MS<&]R="!A9B!A9')E<W-E
M:V%R=&]T96LB"@HC.B!L:6(O87!I+G!H<#HU.38@;&EB+V%P:2YP:'`Z-C@S
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED($E$(@IM<V=S='(@(E5G>6QD:6=T
M(&YA=FXN(@H*(SH@;&EB+V%P:2YP:'`Z,C,P(&QI8B]A<&DN<&AP.C0P,B!L
M:6(O87!I+G!H<#HT.#8@;&EB+V%P:2YP:'`Z-3DR"B,Z(&QI8B]A<&DN<&AP
M.C8W.2!L:6(O87!I+G!H<#HW,S$@;&EB+V%P:2YP:'`Z,3`W-PHC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`B56=Y;&1I
M9R!A9')E<W-E:V%R=&]T96LB"@HC.B!L:6(O87!I+G!H<#HQ,#@Q(&QI8B]A
M<&DN<&AP.C$Q-30@;&EB+V%P:2YP:'`Z,3(P-PHC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!E;6%I;"(*;7-G<W1R(")59WEL9&EG(&5-86EL+6%D<F5S<V4N
M(@H*(SH@;&EB+V%P:2YP:'`Z,3`X.0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!E;G1R>2(*;7-G<W1R(")59WEL9&EG="!N879N+B(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,C8V"FUS9VED("));G9A;&ED(&ME>2!S<&5C:69I960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$P.#4*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@;F%M92(*;7-G<W1R(")59WEL9&EG="!N879N+B(*"B,Z
M(&QI8B]A<&DN<&AP.C<S-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O8FIE
M8W1)9"(*;7-G<W1R(")59WEL9&EG="!N879N+B(*"B,Z(&QI8B]$<FEV97(O
M;&1A<"YP:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E
M9"!B=70@=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T
M(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S
M.`IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HU,PHC+"!F=7IZ>0IM<V=I9"`B3&%S="!.
M86UE(@IM<V=S='(@(DYA=FXB"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M
M;E]H96%D97)S+FEN8SHQ-@IM<V=I9"`B3&ES="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S<*;7-G:60@(DUA=&-H:6YG
M(@IM<V=S='(@(DUA=&-H97(B"@HC.B!L:6(O87!I+G!H<#HR,#4*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R
M(&]F('!A9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N
M<&AP.C,*;7-G:60@(DUE;G4@3&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6EN:7-E87)C:"YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B36EN:2!396%R
M8V@B"FUS9W-T<B`B4_AG(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#(*
M;7-G:60@(DUI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,38R"B,L(&9U>GIY"FUS9VED(")-;V)I;&4@4&AO;F4B"FUS9W-T<B`B5&5L
M969O;B`H:&IE;6UE*2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S,R(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@(DUO
M9&EF>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,3$Y,PIM<V=I9"`B36]R92!T:&%N(#$@96YT<GD@9F]U;F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,0IM<V=I
M9"`B36]V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN
M<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K
M<V5L96-T+FEN8SHQ.#0*;7-G:60@(DUO=F4@;&5F="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#D*(SH@=&5M
M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#8*;7-G:60@
M(DUO=F4@<FEG:'0B"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z-3(@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B375L8F5R
M<GD@061D<F5S<R!";V]K(@IM<V=S='(@(D5K<W!O<G1E<B!A9')E<W-E:V%R
M=&]T96LB"@HC.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL(&)U
M="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I9R]S;W5R
M8V5S+G!H<"YD:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B37D@061D<F5S<R!"
M;V]K(@IM<V=S='(@(DEM<&]R=&5R(&%D<F5S<V5K87)T;W1E:R(*"B,Z(&%D
M9')E<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")->2!!9&1R97-S
M($)O;VMS(@IM<V=S='(@(D5K<W!O<G1E<B!A9')E<W-E:V%R=&]T96LB"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%V;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B3F%M92!&;W)M
M870B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S$U
M"FUS9VED(").971C96YT97(@365M8F5R($1I<F5C=&]R>2(*;7-G<W1R("(B
M"@HC.B!A9&0N<&AP.C,V(&%D9"YP:'`Z,3(T(&QI8B]";&]C:R]M:6YI<V5A
M<F-H+G!H<#HR-PHC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HR-PHC+"!F
M=7IZ>0IM<V=I9"`B3F5W($-O;G1A8W0B"FUS9W-T<B`B5&EL9OAJ(&YY(&MO
M;G1A:W0B"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY-2!E9&ET+G!H<#HR
M,#(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT-0IM<V=I9"`B3F5X="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*
M(RP@9G5Z>GD*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(DYA=FXB"@HC.B!L
M:6(O87!I+G!H<#HQ,3DU(&QI8B]A<&DN<&AP.C$R-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$Q-C,*(RP@9G5Z>GD*;7-G:60@(DYO(&%D9')E
M<W,@8F]O:W,@9F]U;F0N(@IM<V=S='(@(D%D<F5S<V5K87)T;W1E:V5T(&5R
M('-K<FEV96)E<VMY='1E="(*"B,Z(&UI;FES96%R8V@N<&AP.C@S"FUS9VED
M(").;R!C;VYT86-T<R!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HU,3$@;&EB+V%P:2YP:'`Z-S8V"FUS9VED(").;R!V0V%R9"!D871A('=A
M<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97(N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`B3F]T97(B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO
M=&5S(@IM<V=S='(@(DYO=&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-0IM<V=I9"`B3G5M8F5R(&]F(&ET96US('!E<B!P86=E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C8Q-"!L:6(O87!I+G!H<#HW-#<*;7-G:60@
M(D]B:F5C="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHR,PIM<V=I9"`B(@HB
M3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D<F5S<R!B
M;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"X@268@=&AI<R!I
M<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N9V4@>6]U
M<B!S96QE8W1I;VX@(@HB=&\@7").;VYE7"(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C<W-`IM<V=I9"`B3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0V"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z-#DU(&QI8B]A<&DN<&AP.C8P-2!L:6(O87!I+G!H<#HV.3(@;&EB+V%P
M:2YP:'`Z.3,T"B,Z(&QI8B]A<&DN<&AP.C$P.3@*;7-G:60@(E!E<FUI<W-I
M;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C4T,PIM
M<V=I9"`B4&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3D*;7-G:60@(E!E<FUI<W-I;VYS(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4S('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(E!I;F4@061D<F5S<R!";V]K(@IM
M<V=S='(@(DEM<&]R=&5R(&%D<F5S<V5K87)T;W1E:R(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE
M('1H92!N97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H
M<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HQ.30*;7-G:60@(E!R979I;W5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q-@HC
M+"!F=7IZ>0IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M16MS<&]R=&5R(&%D<F5S<V5K87)T;W1E:R(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E
M87)C:"YI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(E%U:6-K(%-E87)C:"(*;7-G
M<W1R(")3^&<B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$Y,2!L:6(O1')I
M=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD87`N<&AP.C0R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O4F5N9&5R97(N<&AP.C0Y"FUS9VED(")296%L;'D@9&5L
M971E('1H:7,@8V]N=&%C=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]F;V]T97(N:6YC.C(*;7-G:60@(E)E8V]R9',@9&ES<&QA>65D.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE
M8W0N:6YC.C$W-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&%D9')E<W,@8F]O
M:R(*;7-G<W1R("));7!O<G1E<B!A9')E<W-E:V%R=&]T96LB"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,SD*;7-G:60@(E)E;6]V
M92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHR"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0IM<V=I9"`B
M(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@:6UP
M;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A
M;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R
M;VYG/B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G:60@
M(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A
M9&0N<&AP.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G
M:60@(E)E<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#
M97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S
M*2`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY.2!A9&0N<&AP.C,W('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V92(*;7-G
M<W1R(")'96TB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.38@
M=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q,@HC.B!T96UP;&%T97,O
M8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C$@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z-#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(E/X9R(*"B,Z(&UI;FES96%R8V@N<&AP.C8S"B,L(&9U
M>GIY"FUS9VED(")396%R8V@@4F5S=6QT<SHB"FUS9W-T<B`B4_AG97)E<W5L
M=&%T97(B"@HC.B!L:6(O87!I+G!H<#HQ,#$Q"B,L(&9U>GIY"FUS9VED(")3
M96%R8V@@9F%I;&5D(@IM<V=S='(@(E/X9R(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M,#,@;&EB+V%P:2YP:'`Z,3$P.2!L:6(O87!I+G!H<#HQ,3$X(&QI8B]A<&DN
M<&AP.C$Q,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N
M:6YC.C(R"B,L(&9U>GIY"FUS9VED(")396%R8VAI;F<N+BXB"FUS9W-T<B`B
M4_AG(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C8*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@9&5L971E(@IM
M<V=S='(@(E;F;&<@=F5N;&EG<W0@9&5N(&%D<F5S<V5K87)T;W1E:RP@<V]M
M(&1U('9I;"!T:6QF^&IE(&MO;G1A:W1E;B!T:6PN(@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A
M;B!A9&1R97-S(&)O;VL@=&\@961I="(*;7-G<W1R(")6YFQG('9E;FQI9W-T
M(&1E;B!A9')E<W-E:V%R=&]T96LL('-O;2!D=2!V:6P@=&EL9OAJ92!K;VYT
M86MT96X@=&EL+B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S(*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X
M<&]R="!F<F]M.B(*;7-G<W1R(")6YFQG(&MI;&1E('-O;2!D97(@<VMA;"!E
M:W-P;W)T97)E<R!F<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@
M=&\@:6UP;W)T('1O.B(*;7-G<W1R(")6YFQG('-T961E="P@9'4@=FEL(&EM
M<&]R=&5R92!T:6PZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS
M-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C:&%R<V5T(&]F('1H92!S
M;W5R8V4@9FEL93HB"FUS9W-T<B`B5N9L9R!K:6QD92!S;VT@9&5R('-K86P@
M96MS<&]R=&5R97,@9G)A.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA
M=#HB"FUS9W-T<B`B5N9L9R!K:6QD92!S;VT@9&5R('-K86P@96MS<&]R=&5R
M97,@9G)A.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#,*;7-G
M:60@(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(E;F;&<@
M9FEL96X@<V]M('-K86P@:6UP;W)T97)E<SHB"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&9O
M<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(E;F;&<@96MS<&]R
M=&9O<FUA=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@
M;F%M97,Z(@IM<V=S='(@(E;F;&<@:6UP;W)T9F]R;6%T.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES
M<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T
M:6]N<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M"FUS9VED(")396QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE
M(&%D9')E<W,@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('=H:6-H(&9O<FUA
M="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R(")6YFQG(&EM<&]R=&9O<FUA
M=#HB"@HC.B!A9&0N<&AP.C4T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")396QE8W1E9"!A9&1R97-S(&)O;VL@7"(E<UPB+B(*;7-G<W1R(")59WEL
M9&EG(&%D<F5S<V5K87)T;W1E:R(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C$W,PHC+"!F=7IZ>0IM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G
M<W1R(")+871A;&]G(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHS.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#$*;7-G:60@(E-H
M;W<@06QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z-#`*;7-G:60@(E-H;W<@0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B4VAO=R!,
M:7-T<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H
M96%D97)S+FEN8SHR,0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D
M97)S+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS
M9W-T<B`B2V%T86QO9R(*"B,Z(&QI8B]A<&DN<&AP.C$Y.`HC+"!F=7IZ>0IM
M<V=I9"`B4V]U<F-E<R(*;7-G<W1R(")59&;X<G0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34W"FUS9VED(")3<&5C:69Y('=H97)E('EO=2!W86YT
M(&%D=F%N8V5D('-E87)C:"!R97-U;'1S('1O(&%P<&5A<BXB"FUS9W-T<B`B
M(@H*(SH@8G)O=W-E+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&)R;W=S
M92YP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C
M<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!D871A+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B
M(@H*(SH@=FEE=RYP:'`Z,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D
M<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A
M9',N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C$P-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@
M=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R
M97-S8F]O:W,N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R
M97-S(&)O;VL@7"(E<UPB('=A<R!R96UO=F5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U
M;&QY('5P9&%T960N(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C,P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(&-O=6QD(&YO="!B
M92!P=7)G960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C0W('9C87)D
M+G!H<#HR,B!D:7-P;&%Y+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE
M(&-O;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B(@H*(SH@961I="YP:'`Z,3$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92!<(B5S7"(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E
M;&5T960N(@IM<V=S='(@(DEM<&]R="!A9B`E<R!F:6QE;B!L>6MK961E<R(*
M"B,Z(&1A=&$N<&AP.C(X-`IM<V=I9"`B5&AE(&EM<&]R="!C86X@8F4@9FEN
M:7-H960@9&5S<&ET92!T:&4@=V%R;FEN9W,N(@IM<V=S='(@(B(*"B,Z(&)R
M;W=S92YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!B<F]W
M<V5A8FQE(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@(D1E<B!F:6YD97,@:6YG
M96X@861R97-S96MA<G1O=&5K97(L('-O;2!D97(@:V%N(&=E;6UE<R!I+B(*
M"B,Z(&%D9"YP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E(&%R92!N
M;R!W<FET96%B;&4@861D<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@879A:6QA
M8FQE(&%D9')E<W,@8F]O:W,@(@HB87)E(&-O;F9I9W5R960@=&\@86QL;W<@
M>6]U('1O(&%D9"!N97<@96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@8F5L:65V
M92!T:&ES("(*(FES(&%N(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B));F=E;B!A9B!D92!T
M:6QGYFYG96QI9V4@861R97-S96MA<G1O=&5K97(@=&EL;&%D97(@9&EG(&%T
M('1I;&;X:F4@;GEE("(*(F5M;F5R+B!(=FES(&1U(&UE;F5R(&1E='1E(&5R
M(&5N(&9E:FPL('/E(&MO;G1A:W0@=F5N;&EG<W0@9&EN("(*(G-Y<W1E;6%D
M;6EN:7-T<F%T;W(N(@H*(SH@861D+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE=R!C;VYT86-T
M+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@(@HB9F]R(&9U
M<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB1&5R(&]P<W1O9"!E;B!F96IL('9E
M9"!T:6QF^&IE;'-E(&%F(&]B:F5K=&5T+B!+;VYT86MT(&1I;B`B"B)S>7-T
M96UA9&UI;FES=')A=&]R(&9O<B!Y9&5R;&EG97)E(&AJYFQP+B(*"B,Z(&)R
M;W=S92YP:'`Z,3@Y(&)R;W=S92YP:'`Z,C,P"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@861D:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R
M(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T97)I;F=E;B!A9B!D
M871A+B(*"B,Z(&)R;W=S92YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="XB"FUS9W-T<B`B
M1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG96X@868@9&%T
M82XB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A
M9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!V
M960@:6UP;W)T97)I;F<@868@9&5N(&]V97)F^')T92!F:6PB"@HC.B!B<F]W
M<V4N<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG(%PB)7-<(B!F<F]M('1H92!S;W5R8V4@
M861D<F5S<R!B;V]K+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=F5D
M(&EM<&]R=&5R:6YG(&%F(&1E;B!O=F5R9OAR=&4@9FEL(@H*(SH@9&5L971E
M+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`B
M1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG96X@868@9&%T
M82XB"@HC.B!B<F]W<V4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(D1E
M<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!I;7!O<G1E<FEN9V5N(&%F(&1A=&$N
M(@H*(SH@8G)O=W-E+G!H<#HR-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H92!L:7-T(@IM<V=S='(@(D1E<B!O
M<'-T;V0@96X@9F5J;"!U;F1E<B!I;7!O<G1E<FEN9V5N(&%F(&1A=&$N(@H*
M(SH@9&%T82YP:'`Z,S,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G
M<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T97)I;F=E;B!A
M9B!D871A+B(*"B,Z(&QI8B]A<&DN<&AP.C4P-R!L:6(O87!I+G!H<#HW-C$*
M(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E
M:FP@=6YD97(@:6UP;W)T97)I;F=E;B!A9B!D871A+B(*"B,Z(&)R;W=S92YP
M:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO
M=FEN9R!A(&-O;G1A8W0@9G)O;2!T:&4@;&ES="XB"FUS9W-T<B`B1&5R(&]P
M<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG96X@868@9&%T82XB"@HC
M.B!A9&1R97-S8F]O:W,N<&AP.C4U(&%D9')E<W-B;V]K<RYP:'`Z-C`@861D
M<F5S<V)O;VMS+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K
M.B`E<R(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=F5D(&EM<&]R=&5R
M:6YG(&%F(&1E;B!O=F5R9OAR=&4@9FEL(@H*(SH@861D<F5S<V)O;VMS+G!H
M<#HX,2!A9&1R97-S8F]O:W,N<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A9&1R
M97-S(&)O;VLZ("5S(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!V960@
M:6UP;W)T97)I;F<@868@9&5N(&]V97)F^')T92!F:6PB"@HC.B!E9&ET+G!H
M<#HQ-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y.B`E<R(*;7-G<W1R(")$97(@
M;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T97)I;F=E;B!A9B!D871A+B(*
M"B,Z(&1A=&$N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V5R92!N
M;R!A9&1R97-S97,@=&\@97AP;W)T+B(*;7-G<W1R(")$97(@9FEN9&5S(&EN
M9V5N(&%D<F5S<V5K87)T;W1E:V5R+"!S;VT@9&5R(&MA;B!G96UM97,@:2XB
M"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X
M,`IM<V=I9"`B5&AE<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@
M=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O
M;'5M;G-E;&5C="YI;F,Z,C0S"FUS9VED(")4:&5S92!C;VQU;6YS('=I;&P@
M9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HR-CD*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3$R,B!L:6(O87!I+G!H
M<#HQ,3,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES('!E<G-O
M;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R97-S(&)O;VLB
M"FUS9W-T<B`B1&5N;F4@97(@<&5R<V]N(&9I;F1E<R!A;&QE<F5D92!I(&1I
M;B!A9')E<W-E:V%R=&]T96LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30W"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S
M<R!B;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S`*;7-G
M:60@(E1I=&QE(@IM<V=S='(@(E1I=&5L(@H*(SH@;&EB+U1U<F)A+G!H<#HT
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!N97<@
M<VAA<F4N("!-:7-S:6YG('-O=7)C92!T>7!E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O1')I=F5R+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DMA;B!I
M:VME(&EN9&SF<V4@9&5F:6YI=&EO;F5N(&%F("5S+B(*"B,Z(&5D:70N<&AP
M.C@X(&5D:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY(&5D:70N
M<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@
M(D=E;2#F;F1R:6YG97(B"@HC.B!L:6(O87!I+G!H<#HU-#`@;&EB+V%P:2YP
M:'`Z-C0S(&QI8B]A<&DN<&AP.C<W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C,W-@HC+"!F=7IZ>0IM<V=I9"`B5F5R
M:7-I9VX@1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V<B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+W)O=RYI;F,Z,3D@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T
M<F]W+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!M:6YI<V5A<F-H+G!H<#HW.`HC+"!F=7IZ>0IM<V=I
M9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(E1I;&;X:B!N>2!K;VYT86MT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE=R!T;R!D
M:7-P;&%Y(&)Y(&1E9F%U;'0Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$S"FUS9VED
M(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R97-S92`H87)B96ID92DB"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O<FL@
M0VET>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HQ,SD*(RP@9G5Z>GD*;7-G:60@(E=O<FL@0V]U;G1R>2(*;7-G<W1R(")4
M96QE9F]N("AA<F)E:F1E*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$U-@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N("AA
M<F)E:F1E*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S-`HC
M+"!F=7IZ>0IM<V=I9"`B5V]R:R!0;W-T86P@0V]D92(*;7-G<W1R(")496QE
M9F]N("AA<F)E:F1E*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$R.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=&%T92]0<F]V:6YC92(*;7-G
M<W1R(")496QE9F]N("AA<F)E:F1E*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=')E970@061D
M<F5S<R(*;7-G<W1R(")!9')E<W-E("AA<F)E:F1E*2(*"B,Z(&1A=&$N<&AP
M.C(S-R!B<F]W<V4N<&AP.CDS(&)R;W=S92YP:'`Z,C`Q(&%D9"YP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S(&EN(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@961I="YP:'`Z-CD@9&ES<&QA>2YP:'`Z-3@@=FEE=RYP:'`Z
M,S8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@
M=&AI<R!C;VYT86-T+B(*;7-G<W1R("(B"@HC.B!V8V%R9"YP:'`Z-#`*;7-G
M:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O
M8FIE8W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C
M<FEP="YI;F,Z-34*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z,C,*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A
M<F=E="!L:7-T+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HS,@IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C$W('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHW,@IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="XB"FUS9W-T<B`B
M(@H*(SH@961I="YP:'`Z-S,*;7-G:60@(EEO=2!O;FQY(&AA=F4@<&5R;6ES
M<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB"FUS9W-T<B`B(@H*(SH@8G)O
M=W-E+G!H<#HR.#4*;7-G:60@(EEO=7(@9&5F875L="!A9&1R97-S(&)O;VL@
M:7,@;F]T(&)R;W=S96%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<F]W+FEN8SHV('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI
M;F,Z,3(*;7-G:60@(EMN;R!V86QU95TB"FUS9W-T<B`B(@H*(SH@;&EB+U1U
M<F)A+G!H<#HT.#0*;7-G:60@(E]"<F]W<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B7T-O;G1A8W1S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,@HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")3;&5T(@H*(SH@
M;&EB+U1U<F)A+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@(E]);7!O<G0O17AP
M;W)T(@IM<V=S='(@(DEM<&]R="]%:W-P;W)T(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B7TQI<W1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]4=7)B82YP:'`Z-#@Q"B,L(&9U>GIY"FUS9VED(")?37D@061D
M<F5S<R!";V]K<R(*;7-G<W1R("));7!O<G1E<B!A9')E<W-E:V%R=&]T96LB
M"@HC.B!L:6(O5'5R8F$N<&AP.C0X-PHC+"!F=7IZ>0IM<V=I9"`B7TYE=R!#
M;VYT86-T(@IM<V=S='(@(E1I;&;X:B!N>2!K;VYT86MT(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED(")?4F5M;W9E(&9R;VT@
M=&AI<R!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@Y"B,L
M(&9U>GIY"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E/X9R(*"B,Z('9C87)D
M+G!H<#HT-@IM<V=I9"`B8V]N=&%C="YV8V8B"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z,3DY(&1A=&$N<&AP.C(P-"!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$*;7-G:60@(F-O;G1A8W1S+F-S=B(*;7-G<W1R("(B"@HC.B!D871A
M+G!H<#HR,#D*;7-G:60@(F-O;G1A8W1S+G1S=B(*;7-G<W1R("(B"@HC.B!D
M871A+G!H<#HR,3D*;7-G:60@(F-O;G1A8W1S+G9C9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C,T"FUS9VED(")N;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,C0*;7-G:60@(G1O(&$@0V]N=&%C="!,:7-T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@
M(G1O(&$@9&EF9F5R96YT($%D9')E<W,@0F]O:R(*;7-G<W1R(")%:W-P;W)T
M97(@861R97-S96MA<G1O=&5K(@H*(SH@9&%T82YP:'`Z-3$@=&5M<&QA=&5S
M+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHQ-2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U
M"FUS9VED(")V0V%R9"(*;7-G<W1R("(B"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T=7)B82]P;R]C<U]#6BYP;P``````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<V-C0T`#$P-#$W,S8R-S4V
M`#`Q-S4T,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C(%1U<F)A($-Z96-H(%1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H
M0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U
M=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA
M9V4N"B,@4&%V96P@0VAY=&EL(#QP879E;$!C:'ET:6PN=&L^+"`R,#`Q+3(P
M,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M(%1U<F)A(#(N,"XR7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@(#(P,#$M,#<M
M,C8@,30Z-38M,#<P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!-:6QO<R!7:6UM
M97(@/'=I;6UE<D!Z8W4N8WH^7&XB"B),86YG=6%G92U496%M.B!#>F5C:"`\
M9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*(E!L
M=7)A;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU<F%L/2AN)3$P/3TQ("8F(&XE
M,3`P(3TQ,2`_(#`@.B!N)3$P/CTR("8F(&XE(@HB,3`\/30@)B8@*&XE,3`P
M/#$P('Q\(&XE,3`P/CTR,"D@/R`Q(#H@,BD[7&XB"@HC.B!T96UP;&%T97,O
M<')E9G,O:6US<%]O<'0N:6YC.C0R"B,L(&9U>GIY"FUS9VED("(@061D(&%N
M($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@861R97/A^"(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S$*(RP@9G5Z>GD*;7-G
M:60@(B!$96QE=&4@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`B9&\@=GEB
M<F%NZ6AO(&%D<F5SX?AE(@H*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I
M;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B
M96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B)R5S)R!N96)Y;"!Z:V]P
M[7)O=N%N+"!P<F]T;[YE(&IE('1O('-E>FYA;2XB"@HC.B!B<F]W<V4N<&AP
M.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B<E<R<@
M;F5B>6P@</AE<W5N=70L('!R;W1OOF4@:F4@=&\@<V5Z;F%M+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@(EPB1FER<W1N86UE($QA
M<W1N86UE7"(@("AI92X@2F]H;B!$;V4I(@IM<V=S='(@(EPB2FWI;F\@</CM
M:FUE;NU<(B`H;F%P^"X@2F]S968@3F]VX6LI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@
M*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(EPB4/CM:FUE;NTL(&IMZ6YO7"(@
M*&YA</@N($YO=N%K+"!*;W-E9BD@(@H*(SH@861D+G!H<#HQ,#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@861D960N(@IM<V=S='(@(B5S('#X:63A;BXB
M"@HC.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL
M92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B)7,@<V]U8F]R(&)Y
M;"#Z<W#LN6[L(&EM<&]R=&]VX6XB"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O
M;W1E<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E
M<R(*;7-G<W1R("(E<R!AOB`E<R!Z("5S(@H*(SH@;&EB+U1U<F)A+G!H<#HT
M-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!"
M;V]K(@IM<V=S='(@(E!I;F4@861R97/A^"(*"B,Z(&QI8B]";&]C:R]M:6YI
M<V5A<F-H+G!H<#HT-0IM<V=I9"`B02!B<F]W<V5R('1H870@<W5P<&]R=',@
M:49R86UE<R!I<R!R97%U:7)E9"(*;7-G<W1R(")*92!N=71NZ2!P;W6^[70@
M<')O:&SMOF7H('!O9'!O<G5J[6/M(&E&<F%M97,N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U.0IM<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS
M9W-T<B`B5OVY92!U=F5D96[](&9O<FUU;.'X('!R;R!V>6AL963A=N%N[2(*
M"B,Z('9I97<N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M8V-E<W,@9&5N:65D('1O("5S(@IM<V=S='(@(MIS<.RY;NP@</AI9.%N;R`E
M<R!D;R`E<R(*"B,Z(&%D9"YP:'`Z-38@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHR,@IM<V=I9"`B061D(@IM<V=S='(@(E#X:61A="(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3<T"B,L(&9U
M>GIY"FUS9VED(")!9&0@861D<F5S<R!B;V]K(@IM<V=S='(@(DYE<&QA=&[]
M(&%D<F5SX?@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@*(RP@9G5Z
M>GD*;7-G:60@(D%D9"!A;F0@1&5L971E($E-4U`@861D<F5S<R!B;V]K<R(*
M;7-G<W1R(")6>6)R86[](&%D<F5SX?@@)R5S)RXB"@HC.B!T96UP;&%T97,O
M<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*;7-G:60@(D%D9"!C;VQU;6XB
M"FUS9W-T<B`B4/AI9&%T('-L;W5P96,B"@HC.B!E9&ET+G!H<#HQ,C@*;7-G
M:60@(D%D9"!F:6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z,C(*;7-G:60@(D%D9"!T;R(*;7-G<W1R(")0^&ED870@
M9&\B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F=7IZ
M>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(E!I;F4@861R97/A^"(*
M"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM
M<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B5OUP:7,@861R
M97/A^&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z>GD*
M;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B4&EN92!A9')E<^'X(@H*
M(SH@861D+G!H<#HQ,#@*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R>2(*;7-G
M<W1R(")0;VQOOFMA(&%D<F5SX?AE(@H*(SH@9&%T82YP:'`Z,S`U"FUS9VED
M(")!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS9W-T<B`B
M061R97/A^"!B>6P@^G-P[+EN["!V>>AI<W3L;OTN(@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@
M8F]O:R!T;R!D96QE=&4@(@IM<V=S='(@(E!O;&^^:V$@861R97/A^&4B"@HC
M.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`HC
M+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E
M(&1I<W!L87EE9#HB"FUS9W-T<B`B3F5L>F4@=GGH:7-T:70@861R97/A^#H@
M)7,B"@HC.B!S96%R8V@N<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H
M+FEN8SHS-PIM<V=I9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(E!O:W)O
MZ&ELZ2!V>6AL963A=N%N[2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C8T"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S+V)R;W=S
M92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(E:Y92(*"B,Z(&QI8B]A
M<&DN<&AP.C4U,@IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B2FF^
M(&5X:7-T=6IE(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN
M8SHY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y
M;W4@=V%N="!T;R!D96QE=&4@)7,_(@IM<V=S='(@(DIS=&4@<VD@:FES=.TL
M(+YE(&-H8V5T92!S;6%Z870@)7,_(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J
M879A<V-R:7!T+FEN8SHV-PIM<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U
M('=A;G0@=&\@9&5L971E('1H92!S96QE8W1E9"!E;G1R:65S/R(*;7-G<W1R
M(")*<W1E('-I(&II<W3M+""^92!C:&-E=&4@<VUA>F%T('9Y8G)A;ND@<&]L
M;[YK>3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*;7-G:60@(D%S
M8V5N9&EN9R(*;7-G<W1R(")6>F5S='5P;NPB"@HC.B!S96%R8V@N<&AP.C@U
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS-@IM<V=I9"`B0F%S:6,@
M4V5A<F-H(@IM<V=S='(@(E9Y:&QE9&%T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U.`IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O<FTB"FUS9W-T<B`B
M4&]D(&9O<FUU;.'X96T@<')O('9Y:&QE9.%VX6[M(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HW-R!L:6(O1')I=F5R+VQD87`N<&AP.C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(E-P
M;VIE;NT@<V5L:&%L;SH@*"5S*2`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B3F%R;WIE
M;FEN>2(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHW"B,L(&9U>GIY"FUS9VED
M(")"<F]W<V4B"FUS9W-T<B`B7U!R;VAL[;YE="(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@0V%T96=O<GDB
M"FUS9W-T<B`B3V)C:&]D;NT@:V%T96=O<FEE(@H*(SH@9&%T82YP:'`Z-#D*
M;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!L:6(O3V)J96-T+T=R;W5P
M+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHW"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B5GEB<F%T
M(%]VN64OON%D;NDB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHT
M-`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G<W1R(")6>6)E
M<G1E(&%D<F5SX?@B"@HC.B!A9&0N<&AP.C0X"FUS9VED(")#:&]O<V4@86X@
M861D<F5S<R!B;V]K(@IM<V=S='(@(E9Y8F5R=&4@861R97/A^"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R,0HC+"!F=7IZ>0IM
M<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B5GEB97)T
M92!A9')E<^'X(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L
M96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS
M('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$*(RP@9G5Z>GD*;7-G:60@(D-H
M;V]S92!W:&EC:"!A9&1R97-S(&)O;VMS('1O('5S92XB"FUS9W-T<B`B5GEB
M97)T92!A9')E<^'X(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C
M="YI;F,Z,C(X"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=VAI8V@@8V]L=6UN
M<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R(")6>6)E
M<G1E(&IA:R!Z;V)R87IO=F%T('-L;W5P8V4@=B!S97IN86UU(&%D<F5S+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-PIM<V=I9"`B0V]L=6UN($]P
M=&EO;G,B"FUS9W-T<B`B36^^;F]S=&D@<VQO=7!C92(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T
M:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$R"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S
M='(@(LCA<FMO=2!O9&3L;&5NZ2!H;V1N;W1Y(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O97AP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E
M<R`H36EC<F]S;V9T($]U=&QO;VLI(@IM<V=S='(@(LCA<FMO=2!O9&3L;&5N
MZ2!H;V1N;W1Y("A-:6-R;W-O9G0@3W5T;&]O:RDB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&
M:7)M82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`IM<V=I
M9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!F:7)M>2(*"B,Z
M(&QI8B]A<&DN<&AP.C,Q."!L:6(O87!I+G!H<#HS-C,@;&EB+V%P:2YP:'`Z
M-#`W(&QI8B]A<&DN<&AP.C0Y,0HC.B!L:6(O87!I+G!H<#HV,#$@;&EB+V%P
M:2YP:'`Z-C@X(&QI8B]A<&DN<&AP.C<T,2!L:6(O87!I+G!H<#HX,3D*(SH@
M;&EB+V%P:2YP:'`Z,3`P-B!L:6(O87!I+G!H<#HQ,#DT"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")3<&]J
M96[M('-E;&AA;&\Z("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(E-P;VIE;NT@<V5L
M:&%L;R(*"B,Z(&)R;W=S92YP:'`Z,3DQ(&)R;W=S92YP:'`Z,C,R"B,L(&9U
M>GIY"FUS9VED(")#;VYT86-T(&%D9&5D('1O(&QI<W0N(@IM<V=S='(@(DMO
M;G1A:W0@8GEL(&]D<W1R86[L;B!Z92!S97IN86UU+B(*"B,Z(&)R;W=S92YP
M:'`Z-C`*;7-G:60@(D-O;G1A8W0@<F5M;W9E9"!F<F]M(&QI<W0N(@IM<V=S
M='(@(DMO;G1A:W0@8GEL(&]D<W1R86[L;B!Z92!S97IN86UU+B(*"B,Z(&)R
M;W=S92YP:'`Z,C8V"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1A8W1S(&EN
M(&QI<W0Z("5S(@IM<V=S='(@(DMO;G1A:W1Y('8@<V5Z;F%M=3H@)7,B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$R"FUS9VED(")#;W!Y
M(@IM<V=S='(@(DMO<.UR;W9A="(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C4S"B,L(&9U>GIY"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B5GET
M=F_X96YO(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-#`*(RP@
M9G5Z>GD*;7-G:60@(D-R96%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B3W-O
M8F[M(&%D<F5SX?@B"@HC.B!L:6(O3&ES=%9I97<N<&AP.C,Q-0IM<V=I9"`B
M0W)E871E(&$@;F5W($-O;G1A8W0@3&ES="!I;CHB"FUS9W-T<B`B(@H*(SH@
M;&EB+T]B:F5C=%9I97<N<&AP.C$S,PIM<V=I9"`B0W)E871E9"(*;7-G<W1R
M(")6>71V;_AE;F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G
M:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(DEM<&QI
M8VET;NT@<VWL<B!T^.UD[&[M.B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.C<V('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@HC.B!L
M:6(O3V)J96-T+G!H<#HS,C@@;&EB+U)E;F1E<F5R+G!H<#HT-R!L:6(O4F5N
M9&5R97(N<&AP.C4P"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4VUA>F%T(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B5GEB<F%T(&%D<F5S
MX?@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T
M92!#;VYF:7)M871I;VXB"FUS9W-T<B`B4&]T=G)Z96[M('-M87KA;NTB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T
M;VX@8F5H879I;W5R(@IM<V=S='(@(E9L87-T;F]S=&D@=&QAZ.UT:V$@<')O
M('-M87KA;NTB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C(W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@
M(E-M87IA;NT@<V5L:&%L;SH@*"5S*2`E<R(*"B,Z(&1E;&5T92YP:'`Z,S@*
M;7-G:60@(D1E;&5T:6]N(&9A:6QE9"(*;7-G<W1R(")3;6%Z86[M('-E;&AA
M;&\B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@
M(D1E<&%R=&UE;G0B"FUS9W-T<B`B3V1D[&SL;NTB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B4V5S
M='5P;NPB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*;7-G
M:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O<V5A<F-H+FEN8SHQ,3@*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")!
M9')E<^'X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY
M"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(EIO8G)A>FET(&UOOFYO<W1I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M("):;V)R87II="!M;[YN;W-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-S8*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I<FT@9&5L971I;F<@
M96YT<FEE<S\B"FUS9W-T<B`B0VAC971E('!O='9R9&ET('-M87KA;NT@<&]L
M;[YE:S\B"@HC.B!L:6(O3V)J96-T+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@
M(D1O=VYL;V%D(@IM<V=S='(@(E-T86AN;W5T('9#87)D(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]R;W<N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O8V]N=&%C
M=')O=RYI;F,Z,C4*;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S='(@(E-T
M86AN;W5T('9#87)D(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M,3`R('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHR-0HC.B!T96UP;&%T97,O
M8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ,"!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C,*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W
M+FEN8SHS,R!L:6(O4F5N9&5R97(N<&AP.C0R"FUS9VED(")%9&ET(@IM<V=S
M='(@(E5P<F%V:70B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,C4@
M=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!<(B5S7"(B"FUS9W-T<B`B57!R879I
M="`G)7,G(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*(RP@
M9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G<W1R(")%>'!O
M<G1O=F%T(&%D<F5SX?@B"@HC.B!E9&ET+G!H<#HW."!E9&ET+G!H<#HQ-30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!E;G1R>2!F;W(@)7,B"FUS9W-T
M<B`B57!R879I="!P;VQOOFMU('!R;R`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C4X"FUS9VED(")%;6%I;"(*;7-G<W1R(")%;6%I;"(*
M"B,Z(&5D:70N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F
M;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L;V%D960@9FEL92!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$T.2!E9&ET+G!H
M<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T
M960N(@IM<V=S='(@(E!O;&^^:WD@<')O("5S(&)Y;'D@86MT=6%L:7IO=N%N
M>2XB"@HC.B!B<F]W<V4N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")%;G1R>2!S
M=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B)7,@<V]U8F]R(&)Y;"#Z
M<W#LN6[L(&EM<&]R=&]VX6XB"@HC.B!L:6(O87!I+G!H<#HT,3,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E87)C:&EN9R!T:&4@861D
M<F5S<R!B;V]K.B`E<R(*;7-G<W1R(").96QZ92!P^&ES=&]U<&ET(&L@861R
M97/A^&DZ("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*
M;7-G<W1R(")%>'!O<G1O=F%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T
M+FEN8SHV"FUS9VED(")%>'!O<G0@061D<F5S<R!";V]K(@IM<V=S='(@(D5X
M<&]R=&]V870@861R97/A^"(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T
M<RXB"FUS9W-T<B`B17AP;W)T;W9A="!P;W5Z92!V>6)R86[I(&MO;G1A:W1Y
M+B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C<*;7-G:60@(D5X
M<&]R="!T:&4@9F]L;&]W:6YG(&%D9')E<W,@8F]O:R!C;VUP;&5T96QY+B(*
M;7-G<W1R(")+;VUP;&5T;NP@97AP;W)T;W9A="!NX7-L961U:NUC[2!A9')E
M<^'X+B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H<#HR,C@@9&%T82YP:'`Z
M,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY,`HC.B!B<F]W<V4N<&AP
M.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E<R(*
M;7-G<W1R(").96QZ92!P^&ES=&]U<&ET(&L@861R97/A^&DZ("5S(@H*(SH@
M8G)O=W-E+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&%D9"`E<R!T;R`E<SH@)7,B"FUS9W-T<B`B4V5L:&%L;R!P^&EDX6[M("5S
M(&1O("5S.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,C<R"FUS9VED(")&86EL960@
M=&\@8G)O=W-E(&QI<W0B"FUS9W-T<B`B3F5L>F4@<')O:&SI9&YO=70@<V5Z
M;F%M(@H*(SH@8G)O=W-E+G!H<#HS,3`*;7-G:60@(D9A:6QE9"!T;R!B<F]W
M<V4@=&AE(&1I<F5C=&]R>2(*;7-G<W1R(").96QZ92!P<F]H;.ED;F]U="!A
M9')E<^'X(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/
M;&0@1$X@/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R(")3
M96QH86QA('IM[&YA(&IMZ6YA.B`H)7,I("5S.R!S=&%RZ2!$3B`]("5S+"!N
M;W;I($1.(#T@)7,L(%)O;W0@/2`E<R(*"B,Z(&)R;W=S92YP:'`Z,3(P"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B
M92!A9&1E9#H@)7,B"FUS9W-T<B`B3F5L>F4@;F%LZ7IT(&]B:F5K="!K('#X
M:63A;NTZ("5S(@H*(SH@<V5A<F-H+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B
M1F%I;&5D('1O('-E87)C:"!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(DYE
M;'IE('#X:7-T;W5P:70@:R!A9')E<^'X:3H@)7,B"@HC.B!D871A+G!H<#HQ
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T:&4@
M9&ER96-T;W)Y.B`E<R(*;7-G<W1R(").96QZ92!P<F]H;&5D870@:V]N=&%K
M='DZ("5S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38W"FUS
M9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@961I="YP:'`Z,3(T(&1I<W!L
M87DN<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B1FEL97,B"FUS9W-T<B`B5&ET
M=6PB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S`*;7-G:60@
M(D9I;F0B"FUS9W-T<B`B2&QE9&%T(@H*(SH@961I="YP:'`Z.3<@961I="YP
M:'`Z,3@W"B,L(&9U>GIY"FUS9VED(")&:6YI<V@B"FUS9W-T<B`B2&QE9&%T
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I
M<G-T($YA;64B"FUS9W-T<B`B2FWI;F\B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HR,#(*;7-G:60@(D9R965B=7-Y(%523"(*;7-G<W1R(")&
M<F5E+T)U<WD@55),(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC
M.C@S"FUS9VED(")&<F]M(@IM<V=S='(@(D]D(@H*(SH@8V]N9FEG+W-O=7)C
M97,N<&AP+F1I<W0Z-C`T"FUS9VED(")';&]B86P@061D<F5S<R!";V]K(@IM
M<V=S='(@(D=L;V+A;&[M(&%D<F5SX?@B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT
M-`IM<V=I9"`B1W)O=7`B"FUS9W-T<B`B4VMU<&EN82(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C@R"FUS9VED(")(;VUE($%D9')E<W,B"FUS
M9W-T<B`B061R97-A(&1O;?DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y(@IM<V=S='(@(DWL<W1O(&%D<F5S
M>2!D;VWY(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`X"FUS
M9VED(")(;VUE($-O=6YT<GDB"FUS9W-T<B`B6F5M["!A9')E<WD@9&]M^2(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U,`IM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R(")496QE9F]N(&1O;?DB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,#,*;7-G:60@(DAO;64@4&]S=&%L($-O9&4B
M"FUS9W-T<B`B4%/((&1O;?DB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R(")3
M=.%T+W!R;W9I;F-I92!A9')E<WD@9&]M^2(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C@X"FUS9VED(")(;VUE(%-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(E5L:6-E(&%D<F5S>2!D;VWY(@H*(SH@8V]N9FEG+W-O=7)C97,N
M<&AP+F1I<W0Z-3`V"FUS9VED("))35-0(@IM<V=S='(@(DE-4U`B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<*(RP@9G5Z>GD*;7-G:60@(DE-4U`@
M061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E;]<&ES(&%D
M<F5SX?AE(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B
M"FUS9W-T<B`B26UP;W)T;W9A="!A9')E<^'X+"!K<F]K("5D(@H*(SH@9&%T
M82YP:'`Z,S8Q"FUS9VED("));7!O<G0O17AP;W)T($%D9')E<W,@0F]O:W,B
M"FUS9W-T<B`B26UP;W)T;W9A="]E>'!O<G1O=F%T(&%D<F5SX?AE(@H*(SH@
M;&EB+V%P:2YP:'`Z-3DV(&QI8B]A<&DN<&AP.C8X,PIM<V=I9"`B26YV86QI
M9"!)1"(*;7-G<W1R(").97!L871NZ2!)1"(*"B,Z(&QI8B]A<&DN<&AP.C(S
M,"!L:6(O87!I+G!H<#HT,#(@;&EB+V%P:2YP:'`Z-#@V(&QI8B]A<&DN<&AP
M.C4Y,@HC.B!L:6(O87!I+G!H<#HV-SD@;&EB+V%P:2YP:'`Z-S,Q(&QI8B]A
M<&DN<&AP.C$P-S<*;7-G:60@(DEN=F%L:60@861D<F5S<R!B;V]K(@IM<V=S
M='(@(DYE<&QA=&[](&%D<F5SX?@B"@HC.B!L:6(O87!I+G!H<#HQ,#@Q(&QI
M8B]A<&DN<&AP.C$Q-30@;&EB+V%P:2YP:'`Z,3(P-PIM<V=I9"`B26YV86QI
M9"!E;6%I;"(*;7-G<W1R(").97!L871N_2!E;6%I;"(*"B,Z(&QI8B]A<&DN
M<&AP.C$P.#D*;7-G:60@(DEN=F%L:60@96YT<GDB"FUS9W-T<B`B3F5P;&%T
M;N$@<&]L;[YK82(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C8V"FUS9VED
M("));G9A;&ED(&ME>2!S<&5C:69I960N(@IM<V=S='(@(D)Y;"!P;W-K>71N
M=70@;F5P;&%T;OT@:VSMZ"XB"@HC.B!L:6(O87!I+G!H<#HQ,#@U"FUS9VED
M("));G9A;&ED(&YA;64B"FUS9W-T<B`B3F5P;&%T;ND@:FWI;F\B"@HC.B!L
M:6(O87!I+G!H<#HW,S4*;7-G:60@(DEN=F%L:60@;V)J96-T260B"FUS9W-T
M<B`B3F5P;&%T;ND@240@;V)J96MT=2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,S`*;7-G:60@(B(*(DQ$05`@<W5P<&]R="!I<R!R97%U:7)E9"!B=70@
M=&AE($Q$05`@;6]D=6QE(&ES(&YO="!A=F%I;&%B;&4@;W(@;F]T(&QO861E
M9"XB"FUS9W-T<B`B2F4@=GF^861O=N%N($Q$05`L(&%L92!T96YT;R!M;V1U
M;"!N96[M(&1O<W1U<&[](&YE8F\@:6YS=&%L;W9A;OTN(@H*(SH@;&EB+T]B
M:F5C=%9I97<N<&AP.C$S.`IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R
M(").87!O<VQE9'D@>FWL;NQN;R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C4S"FUS9VED("),87-T($YA;64B"FUS9W-T<B`B4/CM:FUE;NTB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ-@IM
M<V=I9"`B3&ES="(*;7-G<W1R(")397IN86TB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+W-E87)C:"YI;F,Z-S<*;7-G:60@(DUA=&-H:6YG(@IM<V=S='(@(E-H
M;V1U:NUC[2!S92!S(@H*(SH@;&EB+V%P:2YP:'`Z,C`U"B,L(&9U>GIY"FUS
M9VED(")-87AI;75M($YU;6)E<B!O9B!#;VYT86-T<R(*;7-G<W1R(")-87AI
M;>%L;NT@<&_H970@<W1RX6YE:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM<V=S='(@
M(DUA>&EMX6QN[2!P;^AE="!S='+A;F5K(@H*(SH@;&EB+T)L;V-K+W1R965?
M;65N=2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@
M(DYO=OT@<V5Z;F%M(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,*
M;7-G:60@(DUI;FD@4V5A<F-H(@IM<V=S='(@(DUA;.D@=GEH;&5DX7;A;NTB
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$
M3B!I;B!,1$%0('-O=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")#:'EB
M[&KM8^T@1$X@=2!K;VYF:6=U<F%C92!Z9')O:F4@3$1!4"XB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0:&]N
M92(*;7-G<W1R(")-;V)I;&[M('1E;&5F;VXB"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(E-E
M;&AA;&$@^G!R879A.B`H)7,I("5S(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y,PIM
M<V=I9"`B36]R92!T:&%N(#$@96YT<GD@9F]U;F0B"FUS9W-T<B`B0GEL82!N
M86QE>F5N82!V[6-E(&YEOB`Q('!O;&^^:V$B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")-;W9E(@IM<V=S='(@(E#X97-U
M;F]U="(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T
M-PHC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X
M-`IM<V=I9"`B36]V92!L969T(@IM<V=S='(@(E#X97-U;F]U="!V;&5V;R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T.0HC.B!T
M96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X-@IM<V=I
M9"`B36]V92!R:6=H="(*;7-G<W1R(")0^&5S=6YO=70@=G!R879O(@H*(SH@
M9&%T82YP:'`Z-3(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-@IM<V=I
M9"`B375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(DUU;&)E<G)Y(&%D
M<F5SX?@B"@HC.B!L:6(O87!I+G!H<#HQ,3$S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R97-S(%LE<UTL(&)U
M="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI<W0B"FUS9W-T<B`B
M5NUC92!O<V]B(',@861R97-O=2!;)7-=+"!A;&4@<V4@:FWI;F5M(%LE<UT@
M;F5E>&ES='5J92!N:6MD;R(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*;7-G
M:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<^'X(@H*(SH@861D
M<F5S<V)O;VMS+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`B061R97/A^"(*"B,Z('1E;7!L871E<R]A9&1R97-S
M8F]O:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT,@IM
M<V=I9"`B3F%M92(*;7-G<W1R(")*;>EN;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,0IM<V=I9"`B3F%M92!&;W)M870B"FUS9W-T<B`B1F]R;>%T
M(&IMZ6YA(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S$U"FUS9VED
M(").971C96YT97(@365M8F5R($1I<F5C=&]R>2(*;7-G<W1R(").971C96YT
M97(@365M8F5R($1I<F5C=&]R>2(*"B,Z(&%D9"YP:'`Z,S8@861D+G!H<#HQ
M,C0@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C(W"B,Z(&QI8B]";&]C:R]T
M<F5E7VUE;G4N<&AP.C(W"FUS9VED(").97<@0V]N=&%C="(*;7-G<W1R(").
M;W;](&MO;G1A:W0B"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H<#HY-2!E9&ET
M+G!H<#HR,#(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT-0IM<V=I9"`B
M3F5X="(*;7-G<W1R(")$86RY[2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C(Q.`IM<V=I9"`B3FEC:VYA;64B"FUS9W-T<B`B4/AE>F3M=FMA
M+V%L:6%S(@H*(SH@;&EB+V%P:2YP:'`Z,3$Y-2!L:6(O87!I+G!H<#HQ,C0T
M"B,L('!H<"UF;W)M870*;7-G:60@(DYO("5S(&5N=')Y(&9O=6YD(&9O<B`E
M<R(*;7-G<W1R("*NX61NX2!P;VQOOFMA("5S(&YE8GEL82!N86QE>F5N82!P
M<F\@)7,B"@HC.B!L:6(O87!I+G!H<#HQ,38S"FUS9VED(").;R!A9&1R97-S
M(&)O;VMS(&9O=6YD+B(*;7-G<W1R(").96)Y;"!N86QE>F5N(+[A9&[](&%D
M<F5SX?@N(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#,*;7-G:60@(DYO(&-O;G1A
M8W1S(&9O=6YD(@IM<V=S='(@(DYE8GEL>2!N86QE>F5N>2"^X61NZ2!K;VYT
M86MT>2XB"@HC.B!L:6(O87!I+G!H<#HU,3$@;&EB+V%P:2YP:'`Z-S8V"FUS
M9VED(").;R!V0V%R9"!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B3F5B>6QY
M(&YA;&5Z96YY(+[A9&[A('9#87)D(&1A=&$N(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]F;V]T97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`BKN%D;OTB
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO
M=&5S(@IM<V=S='(@(E!O>F[A;6MA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-0IM<V=I9"`B3G5M8F5R(&]F(&ET96US('!E<B!P86=E(@IM<V=S
M='(@(E!OZ&5T('!O;&^^96L@;F$@<W1RX6YK=2(*"B,Z(&QI8B]A<&DN<&AP
M.C8Q-"!L:6(O87!I+G!H<#HW-#<*;7-G:60@(D]B:F5C="!N;W0@9F]U;F0B
M"FUS9W-T<B`B3V)J96MT(&YE8GEL(&YA;&5Z96XB"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HR,C,*;7-G:60@(D]F9FEC92(*;7-G<W1R(")+
M86YC96SA^"(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,C,*
M;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE
M(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N
M($EF('1H:7,@:7,@;F]T('=H870@>6]U('=A;G0L('1H96X@>6]U(&UU<W0@
M8VAA;F=E('EO=7(@<V5L96-T:6]N("(*(G1O(%PB3F]N95PB+B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HW-S0*;7-G:60@(D]N;'D@;VYE('9C87)D
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B3W1H97(@
M3W!T:6]N<R(*;7-G<W1R(")$86RY[2!M;[YN;W-T:2(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B5F7X96IN_2!01U`@:VSMZ"(*"B,Z(&QI8B]A<&DN<&AP.C0Y
M-2!L:6(O87!I+G!H<#HV,#4@;&EB+V%P:2YP:'`Z-CDR(&QI8B]A<&DN<&AP
M.CDS-`HC.B!L:6(O87!I+G!H<#HQ,#DX"FUS9VED(")097)M:7-S:6]N($1E
M;FEE9"(*;7-G<W1R(").97!O=F]L96[]('#X[7-T=7`B"@HC.B!L:6(O1')I
M=F5R+G!H<#HU-#,*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@
M(DYE<&]V;VQE;OT@</CM<W1U<"(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O
M:W,N:6YC.CDY"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M(").97!O=F]L96[]('#X[7-T=7`B"@HC.B!D871A+G!H<#HU,R!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")0:6YE($%D9')E<W,@0F]O
M:R(*;7-G<W1R(")0:6YE(&%D<F5SX?@B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+VIA=F%S8W)I<'0N:6YC.C(X"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@;F%M
M92!T:&4@;F5W(&-O;G1A8W0@;&ES=#HB"FUS9W-T<B`B4')O<^UM('IA9&5J
M=&4@:FWI;F\@;F]VZ6AO('-E>FYA;74Z(@H*(SH@961I="YP:'`Z.3$@961I
M="YP:'`Z.30@961I="YP:'`Z,3DT"FUS9VED(")0<F5V:6]U<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HT,38*;7-G:60@(E!R
M:79A=&4@061D<F5S<R!";V]K(@IM<V=S='(@(D]S;V)N[2!A9')E<^'X(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B475E<GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(E9Y:&QE9.%VX6[M
M('-E;&AA;&\Z("@E<RD@)7,B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E
M87)C:"YI;F,Z,3@*;7-G:60@(E%U:6-K(%-E87)C:"(*;7-G<W1R(")2>6-H
M;.D@=GEH;&5DX7;A;NTB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$Y,2!L
M:6(O1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD87`N<&AP.C0R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*
M;7-G<W1R("+(=&5N[2!S96QH86QO.B`H)7,I("5S(@H*(SH@;&EB+U)E;F1E
M<F5R+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHR
M"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`B6F]B<F%Z96[I
M('KA>FYA;7DZ(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L
M96-T+FEN8SHQ-S8*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B5GEB97)T92!A9')E<^'X(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-O;'5M;G-E;&5C="YI;F,Z,C,Y"FUS9VED(")296UO=F4@8V]L=6UN
M(@IM<V=S='(@(D]D<W1R86YI="!S;&]U<&5C(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI
M<W0B"FUS9W-T<B`B3V1S=')A;FET('IE('-E>FYA;74B"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C(Q"B,L(&9U>GIY"FUS9VED("(B"B)297!L
M86-E(&5X:7-T:6YG(&%D9')E<W,@8F]O:R!W:71H('1H92!I;7!O<G1E9"!O
M;F4_(#QS=')O;F<^5V%R;FEN9SH@5&AI<R`B"B)D96QE=&5S(&%L;"!E;G1R
M:65S(&EN('EO=7(@8W5R<F5N="!A9&1R97-S(&)O;VLN/"]S=')O;F<^(@IM
M<V=S='(@(B(*(DYA:')A=&ET(&5X:7-T=6KM8^T@861R97/A^"!I;7!O<G1O
M=F%N_6T_(#QB/E5P;WIO<F[L;NTZ(%1A=&\@;W!E<F%C92!S;6&^92`B"B)V
MN65C:&YY(&1O<V%V861N[2!P;VQOOFMY('8@861R97/A^&DN/"]B/B(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C0S.`IM<V=I9"`B4F5Q=65S=&5D(&]B:F5C="!N
M;W0@9F]U;F0N(@IM<V=S='(@(E!OOF%D;W9A;OT@;V)J96MT(&YE8GEL(&YA
M;&5Z96XN(@H*(SH@861D+G!H<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z,3$S"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R(").
M87-T879I="!V_6-H;WKM(&EM<&QI8VET;NT@:&]D;F]T>2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI
M8R!#97)T:69I8V%T92(*;7-G<W1R(")3+TU)344@=F7X96IN_2!C97)T:69I
M:^%T(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HV.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")35$%25%1,4R!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4U1!
M4E143%,@<V5L:&%L;SH@*"5S*2`E<R(*"B,Z(&5D:70N<&AP.CDY(&%D9"YP
M:'`Z,S<@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3
M879E(@IM<V=S='(@(E5L;[YI="(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A
M<F-H+FEN8SHY-B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$R"B,Z
M('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO
M=')E95]M96YU+G!H<#HT.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B2&QE9&%T(@H*(SH@;6EN:7-E87)C
M:"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!297-U;'1S.B(*;7-G
M<W1R(")6_7-L961K>2!H;&5DX6[M(@H*(SH@;&EB+V%P:2YP:'`Z,3`Q,0IM
M<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R(")(;&5DX6[M('-E;&AA;&\B
M"@HC.B!L:6(O87!I+G!H<#HQ,3`S(&QI8B]A<&DN<&AP.C$Q,#D@;&EB+V%P
M:2YP:'`Z,3$Q."!L:6(O87!I+G!H<#HQ,3,Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E-E87)C:"!F86EL960Z("5S(@IM<V=S='(@(DAL963A;NT@<V5L:&%L
M;SH@)7,B"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,C(*
M;7-G:60@(E-E87)C:&EN9RXN+B(*;7-G<W1R(")6>6AL963A=N%M+BXN(@H*
M(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C8*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@9&5L971E(@IM<V=S='(@
M(E9Y8F5R=&4@861R97/A^"P@>F4@:W1E<NEH;R!B=61E=&4@97AP;W)T;W9A
M=#HB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY,`HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S
M='(@(E9Y8F5R=&4@861R97/A^"P@9&\@:W1E<NEH;R!S92!B=61E(&EM<&]R
M=&]V870Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHS,@IM<V=I
M9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R;VTZ(@IM
M<V=S='(@(E9Y8F5R=&4@861R97/A^"P@>F4@:W1E<NEH;R!B=61E=&4@97AP
M;W)T;W9A=#HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(V"FUS
M9VED(")396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!I;7!O<G0@=&\Z(@IM
M<V=S='(@(E9Y8F5R=&4@861R97/A^"P@9&\@:W1E<NEH;R!S92!B=61E(&EM
M<&]R=&]V870Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R
M8V4@9FEL93HB"FUS9W-T<B`B5GEB97)T92!F;W)MX70@>F1R;VIO=NEH;R!S
M;W5B;W)U.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*;7-G
M:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B5F5B97)T
M92!F;W)MX70@97AP;W)T=3HB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C0S"FUS9VED(")396QE8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G
M<W1R(")6>6)E<G1E('-O=6)O<B!K(&EM<&]R=&]VX6[M.B(*"B,Z('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z,3$*;7-G:60@(E-E;&5C="!T:&4@9F]R
M;6%T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T<B`B5GEB97)T92!F;W)M
MX70@>F1R;VIO=NEH;R!S;W5B;W)U.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES
M<&QA>2!N86UE<SHB"FUS9W-T<B`B5GEB97)T92!F;W)MX70@>F]B<F%Z96[M
M(&IM96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@=FEE=R!T;R!D:7-P;&%Y(&)Y(&1E9F%U;'0L('-O
M<G0@;W!T:6]N<RP@86YD('!A9VEN9R!O<'1I;VYS+B(*;7-G<W1R(")6;VQB
M82!I;7!L:6-I=&[M:&\@>F]B<F%Z96[M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.`IM<V=I9"`B4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P
M;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+B(*;7-G<W1R(")6;VQB82!P;VSM
M+"!K=&5RX2!M86KM(&+]="!Z;V)R87IE;F$@=B!S97IN86UU(&%D<F5S+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L96-T('=H
M:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R(")6;VQB82!F
M;W)MX71U('IO8G)A>F5N[2!J;65N+B(*"B,Z(&%D9"YP:'`Z-30*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-E;&5C=&5D(&%D9')E<W,@8F]O:R!<
M(B5S7"(N(@IM<V=S='(@(E9Y8G)A;OT@861R97/A^"`G)7,G+B(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B4VAA<F5D($1I<F5C
M=&]R>2(*;7-G<W1R(")39.UL96[](&%D<F5SX?@B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3:&]W("5S(@IM<V=S='(@(EIO8G)A>FET(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B4VAO=R!!;&PB"FUS9W-T
M<B`B6F]B<F%Z:70@=KEE(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHT,`IM<V=I9"`B4VAO=R!#;VYT86-T<R(*;7-G<W1R("):;V)R87II
M="!K;VYT86MT>2(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,SD*;7-G:60@(E-H;W<@3&ES=',B"FUS9W-T<B`B6F]B<F%Z:70@<V5Z;F%M
M>2(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C(Q
M"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C,T"FUS
M9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R(")3;>QR('3X[63L;NTB"@HC
M.B!L:6(O87!I+G!H<#HQ.3@*;7-G:60@(E-O=7)C97,B"FUS9W-T<B`B6F1R
M;VIE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U-PIM<V=I9"`B4W!E
M8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T
M;R!A<'!E87(N(@IM<V=S='(@(E5RZ&5T92!K86T@<VD@</AE:F5T92!Z;V)R
M87II="!V_7-L961K>2!P;VMR;^AI;.EH;R!V>6AL963A=N%N[2XB"@HC.B!B
M<F]W<V4N<&AP.C$T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@861D960@)7,@=&\@)7,B"FUS9W-T<B`BVG-P[+EN["!P^&EDX6YO("5S
M(&1O("5S(@H*(SH@8G)O=W-E+G!H<#HR,C(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI
M<W0@7"(E<UPB+B(*;7-G<W1R("+:<W#LN6[L('#X:63A;F\@)7,@9&\@)7,B
M"@HC.B!D871A+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S='(@(E135B(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS
M9W-T<B`B5&%B(&]D9.QL96[I(&AO9&YO='DB"@HC.B!V:65W+G!H<#HQ-0IM
M<V=I9"`B5&AE(%9&4R!B86-K96YD(&YE961S('1O(&)E(&-O;F9I9W5R960@
M=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T1R:79E<BYP:'`Z,3`U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(DYE;'IE('9YZ&ES=&ET(&%D<F5SX?@Z("5S(@H*(SH@861D<F5S
M<V)O;VMS+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R(")!9')E<^'X(&)Y;"#Z<W#LN6[L('9YZ&ES=.QN_2XB"@HC
M.B!A9&1R97-S8F]O:W,N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<F5M;W9E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(D%D<F5SX?@@8GEL(/IS<.RY;NP@=GGH:7-T
M[&[]+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB('=A<R!S=6-C
M97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B061R97/A^"!B>6P@^G-P[+EN
M["!V>>AI<W3L;OTN(@H*(SH@9&%T82YP:'`Z,S`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U;&0@;F]T(&)E('!U<F=E9#H@
M)7,B"FUS9W-T<B`B3F5L>F4@=GGH:7-T:70@861R97/A^#H@)7,B"@HC.B!E
M9&ET+G!H<#HT-R!V8V%R9"YP:'`Z,C(@9&ES<&QA>2YP:'`Z,C,@=FEE=RYP
M:'`Z,C8*;7-G:60@(E1H92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(E!OOF%D;W9A;OT@:V]N=&%K="!N965X:7-T
M=6IE+B(*"B,Z(&5D:70N<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R("(E<R!S;W5B;W(@8GEL(/IS<.RY;NP@:6UP;W)T
M;W;A;B(*"B,Z(&1A=&$N<&AP.C(X-`IM<V=I9"`B5&AE(&EM<&]R="!C86X@
M8F4@9FEN:7-H960@9&5S<&ET92!T:&4@=V%R;FEN9W,N(@IM<V=S='(@(B(*
M"B,Z(&)R;W=S92YP:'`Z,S$*;7-G:60@(E1H97)E(&%R92!N;R!B<F]W<V5A
M8FQE(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@(DYE:G-O=2!D;W-T=7!NZ2"^
M861NZ2!A9')E<^'X92!K('!R;VAL[;YE;NTN(@H*(SH@861D+G!H<#HR.0IM
M<V=I9"`B(@HB5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S(&)O;VMS
M+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R`B"B)A<F4@
M8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S('1O
M('1H96TN($EF('EO=2!B96QI979E('1H:7,@(@HB:7,@86X@97)R;W(L('!L
M96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(DYE:G-O=2!Z9&4@ON%D;ND@861R97/A^&4@<R!M;[YN;W-T[2!Z
MX7!I<W4N(*[A9&[I(&%D<F5SX?AE(&YE:G-O=2`B"B)N86MO;F9I9W5R;W;A
M;GD@<')O('KA<&ES(&YO=OUC:"!P;VQOOF5K+B!0;VMU9"!S:2!M>7-L[71E
M+""^92!J92!T;R!C:'EB82P@(@HB<')O<^UM(&MO;G1A:W1U:G1E('-VZ6AO
M('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T;W)A+B(*"B,Z(&%D9"YP:'`Z,3(Q
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N97<@
M8V]N=&%C="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R("(*
M(F9O<B!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@
M</AI('9K;.%DX6[M(&YO=NEH;R!K;VYT86MT=2X@2V]N=&%K='5J=&4@5F&Y
M96AO('-Y<W3I;6]VZ6AO("(*(F%D;6EN:7-T<N%T;W)A+B(*"B,Z(&)R;W=S
M92YP:'`Z,3@Y(&)R;W=S92YP:'`Z,C,P"B,L(&9U>GIY"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@861D:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R(").
M87-T86QA(&-H>6)A('#X:2!M87KA;NT@=&]H;W1O(&]B:F5K='4N(@H*(SH@
M8G)O=W-E+G!H<#HR,S@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A
M=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!V
M>71VX?AE;NT@;F]VZ6AO('-E>FYA;74N(@H*(SH@861D<F5S<V)O;VMS+G!H
M<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&-R96%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R
M(").87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!TZ71O('!O;&^^:WDZ
M("5S(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!<(B5S7"(@9G)O
M;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P^&D@;6%ZX6[M("5S('IE('ID<F]J;W;I:&\@861R97/A^&4N(@H*
M(SH@9&5L971E+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G<W1R
M(").87-T86QA(&-H>6)A('#X:2!M87KA;NT@=&]H;W1O(&MO;G1A:W1U.B`E
M<R(*"B,Z(&)R;W=S92YP:'`Z-S(*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D96QE=&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B3F%S=&%L82!C:'EB
M82!P^&D@;6%ZX6[M('1O:&]T;R!O8FIE:W1U+B(*"B,Z(&)R;W=S92YP:'`Z
M,C<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&4@;&ES="(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!Z;V)R
M87IO=N%N[2!V>6)R86[I:&\@<V5Z;F%M=2(*"B,Z(&1A=&$N<&AP.C,S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!D871A.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!I
M;7!O<G1O=N%N[2!D870Z("5S(@H*(SH@;&EB+V%P:2YP:'`Z-3`W(&QI8B]A
M<&DN<&AP.C<V,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E#X:2!I;7!O<G1O=N%N
M[2!I0V%L96YD87(@9&%T(&1ON6QO(&L@8VAY8NPN(@H*(SH@8G)O=W-E+G!H
M<#HU.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V
M:6YG(&$@8V]N=&%C="!F<F]M('1H92!L:7-T+B(*;7-G<W1R(").87-T86QA
M(&-H>6)A('#X:2!V>71VX?AE;NT@;F]VZ6AO('-E>FYA;74N(@H*(SH@861D
M<F5S<V)O;VMS+G!H<#HU-2!A9&1R97-S8F]O:W,N<&AP.C8P(&%D9')E<W-B
M;V]K<RYP:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B
M"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P^&D@;V1S=')A\F]VX6[M('1O:&]T
M;R!O8FIE:W1U+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#$@861D<F5S<V)O
M;VMS+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*
M;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!TZ71O('!O
M;&^^:WDZ("5S(@H*(SH@961I="YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y.B`E
M<R(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!TZ71O
M('!O;&^^:WDZ("5S(@H*(SH@9&%T82YP:'`Z,3<Y"FUS9VED(")4:&5R92!W
M97)E(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N(@IM<V=S='(@(J[A9&[I(&MO
M;G1A:W1Y('!R;R!E>'!O<G1O=N%N[2XB"@HC.B!T96UP;&%T97,O<')E9G,O
M861D<F5S<V)O;VMS96QE8W0N:6YC.C$X,`IM<V=I9"`B5&AE<V4@861D<F5S
M<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0S"FUS
M9VED(")4:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R
M.B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HR-CD*;7-G:60@(E1H:7,@9FEL
M92!F;W)M870@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B5&5N=&\@9F]R
M;>%T('-O=6)O<G4@;F5L>F4@<&]UONUT+B(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M,C(@;&EB+V%P:2YP:'`Z,3$S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES
M('!E<G-O;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B5&%T;R!O<V]B82!S92!J:;X@;F%C:.%Z[2!V92!6
M8;EE;2!A9')E<^'X:2!J86MO("5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#<*;7-G:60@(B(*(E1H:7,@=VEL;"!B92!T:&4@9&5F875L="!A
M9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG(&-O;G1A8W1S
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW
M,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET=6PB"@HC.B!L:6(O5'5R8F$N
M<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(&YE=R!S:&%R92X@($UI<W-I;F<@<V]U<F-E('1Y<&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]$<FEV97(N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B
M3F5L>F4@9&]SX6AN;W5T(&1E9FEN:6-I("5S+B(*"B,Z(&5D:70N<&AP.C@X
M(&5D:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY(&5D:70N<&AP
M.C$Y-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(E-T;W)N;R!Z;>QN
M(@H*(SH@;&EB+V%P:2YP:'`Z-30P(&QI8B]A<&DN<&AP.C8T,R!L:6(O87!I
M+G!H<#HW-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N<W5P<&]R
M=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B3F5P;V1P;W)O=F%N_2!T
M>7`@;V)S86AU("A#;VYT96YT+51Y<&4I+B(*"B,Z(&-O;F9I9R]S;W5R8V5S
M+G!H<"YD:7-T.C,W-@IM<V=I9"`B5F5R:7-I9VX@1&ER96-T;W)Y(@IM<V=S
M='(@(E9E<FES:6=N($1I<F5C=&]R>2(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(%PB)7-<(B(*;7-G
M<W1R("):;V)R87II="`G)7,G(@H*(SH@;6EN:7-E87)C:"YP:'`Z-S@*;7-G
M:60@(E9I97<@0V]N=&%C="(*;7-G<W1R("):;V)R87II="!K;VYT86MT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE=R!T;R!D
M:7-P;&%Y(&)Y(&1E9F%U;'0Z(@IM<V=S='(@(DEM<&QI8VET;NT@>F]B<F%Z
M96[M.B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I
M9"`B5V5B<VET92!54DPB"FUS9W-T<B`B55),('=W=R!S='+A;FMY(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$S"FUS9VED(")7;W)K($%D
M9')E<W,B"FUS9W-T<B`B061R97-A(&1O('IA;>QS=&[A;NTB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O<FL@0VET>2(*
M;7-G<W1R(")-['-T;R!A9')E<WD@9&\@>F%M['-T;N%N[2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S.0IM<V=I9"`B5V]R:R!#;W5N=')Y
M(@IM<V=S='(@(EIE;>P@861R97-Y(&1O('IA;>QS=&[A;NTB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O<FL@4&AO;F4B
M"FUS9W-T<B`B5&5L969O;B!D;R!Z86WL<W1NX6[M(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3,T"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E
M(@IM<V=S='(@(E!3R"!D;R!Z86WL<W1NX6[M(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3(Y"FUS9VED(")7;W)K(%-T871E+U!R;W9I;F-E
M(@IM<V=S='(@(E-TX70O<')O=FEN8VEE(&%D<F5S>2!D;R!Z86WL<W1NX6[M
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$Y"FUS9VED(")7
M;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(E5L:6-E(&%D<F5S>2!D;R!Z
M86WL<W1NX6[M(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP:'`Z.3,@8G)O
M=W-E+G!H<#HR,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8V]N
M=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HV.2!D
M:7-P;&%Y+G!H<#HU."!V:65W+G!H<#HS-@IM<V=I9"`B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S='(@
M(DYE9&]S=&%T9>ANX2!P<N%V82!P<F\@<')O:&SMOF5N[2!T;VAO=&\@:V]N
M=&%K='4N(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+B(*;7-G<W1R(").
M961O<W1A=&7H;N$@<'+A=F$@<')O('!R;VAL[;YE;NT@=&]H;W1O(&]B:F5K
M='4N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHU-0IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B375S[71E(&YE:F3X[79E('9Y8G)A="!C[6QO=OT@861R97/A
M^"XB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S"FUS
M9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB"FUS9W-T<B`B
M375S[71E(&YE:F3X[79E('9Y8G)A="!C[6QO=OT@<V5Z;F%M+B(*"B,Z(&5D
M:70N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@870@
M;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N(@IM<V=S='(@(DUU<^UT92!N96ID
M^.UV92!V>6)R870@86QE<W!O\B!J961N=2!P;VQOOFMU+B(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S
M92]J879A<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@
M;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R(")-=7/M=&4@;F5J9/CM=F4@=GEB
M<F%T(&%L97-P;_(@:F5D;G4@<&]L;[YK=2XB"@HC.B!E9&ET+G!H<#HW,PIM
M<V=I9"`B66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C
M;VYT86-T+B(*;7-G<W1R(")68;EE('!RX79A(&1O=F]L=6KM('!O=7IE('!R
M;VAL[;YE;NT@=&]H;W1O(&MO;G1A:W1U+B(*"B,Z(&)R;W=S92YP:'`Z,C@U
M"FUS9VED(")9;W5R(&1E9F%U;'0@861D<F5S<R!B;V]K(&ES(&YO="!B<F]W
M<V5A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z-B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS9VED
M(");;F\@=F%L=65=(@IM<V=S='(@(EN^X61NX2!H;V1N;W1A72(*"B,Z(&QI
M8B]4=7)B82YP:'`Z-#@T"FUS9VED(")?0G)O=W-E(@IM<V=S='(@(E]0<F]H
M;.V^970B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"B,L
M(&9U>GIY"FUS9VED(")?0V]N=&%C=',B"FUS9W-T<B`B6F]B<F%Z:70@7VMO
M;G1A:W1Y(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS
M9VED(")?1&5L971E(@IM<V=S='(@(E]3;6%Z870B"@HC.B!L:6(O5'5R8F$N
M<&AP.C0Y,PIM<V=I9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R
M=&]V870O97AP;W)T;W9A="(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,SD*(RP@9G5Z>GD*;7-G:60@(E],:7-T<R(*;7-G<W1R(")397IN
M86TB"@HC.B!L:6(O5'5R8F$N<&AP.C0X,0HC+"!F=7IZ>0IM<V=I9"`B7TUY
M($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B061R97/A^"(*"B,Z(&QI8B]4=7)B
M82YP:'`Z-#@W"B,L(&9U>GIY"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T
M<B`B3F]V_2!K;VYT86MT(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHR"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@
M(E]/9'-T<F%N:70@>B!T;VAO=&\@<V5Z;F%M=2(*"B,Z(&QI8B]4=7)B82YP
M:'`Z-#@Y"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E]6>6AL961A="(*"B,Z
M('9C87)D+G!H<#HT-@IM<V=I9"`B8V]N=&%C="YV8V8B"FUS9W-T<B`B:V]N
M=&%K='DN=F-F(@H*(SH@9&%T82YP:'`Z,3DY(&1A=&$N<&AP.C(P-"!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C$*;7-G:60@(F-O;G1A8W1S+F-S=B(*
M;7-G<W1R(")K;VYT86MT>2YC<W8B"@HC.B!D871A+G!H<#HR,#D*;7-G:60@
M(F-O;G1A8W1S+G1S=B(*;7-G<W1R(")K;VYT86MT>2YT<W8B"@HC.B!D871A
M+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(F-O;G1A8W1S+G9C9B(*;7-G<W1R
M(")K;VYT86MT>2YV8V8B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N
M:6YC.C,T"B,L(&9U>GIY"FUS9VED(")N;VYE(@IM<V=S='(@(J[A9&[](@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR-`HC+"!F=7IZ>0IM
M<V=I9"`B=&\@82!#;VYT86-T($QI<W0B"FUS9W-T<B`B6F]B<F%Z:70@:V]N
M=&%K='DB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$T"B,L
M(&9U>GIY"FUS9VED(")T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B9&\@=GEB<F%NZ6AO(&%D<F5SX?AE(@H*(SH@9&%T82YP:'`Z-3$@
M=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-2!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C$U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+W!T7T)2+G!O````````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#0V-C(`,3`T
M,3<S-C(W-38`,#$W-3,V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````",@=')A;G-L871I;VX@;V8@='5R8F$N<&\@=&\@0G)A
M>FEL:6%N(%!O<G1U9W5E<V4*(R!#;W!Y<FEG:'0@*$,I(%E%05(@2&]R9&4@
M4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!4=7)B82!P86-K86=E+@HC"B,@1F%B:6\@
M1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R/BP@,C`P-BX*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-BTP,BTQ-B`Q-SHT.2TP,C`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB<CY<;B(*
M(DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T=6=U97-E(#QI,3AN0&QI
M<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB6"U'96YE<F%T
M;W(Z($M"86)E;"`Q+C,N,5QN(@HB4&QU<F%L+49O<FUS.B`@;G!L=7)A;',]
M,CL@<&QU<F%L/2AN(#X@,2D[7&XB"@HC.B!T96UP;&%T97,O<')E9G,O:6US
M<%]O<'0N:6YC.C0P"FUS9VED("(@061D(&%N($E-4U`@061D<F5S<R!";V]K
M(@IM<V=S='(@(B!!9&EC:6]N87(@=6T@0V%TX6QO9V\@9&4@96YD97)EYV]S
M($E-4U`B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(Y"FUS
M9VED("(@1&5L971E($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(D5X8VQU
M:7(@;R!#873A;&]G;R!D92!%;F1E<F7G;W,@24U34"(*"B,Z(&1A=&$N<&AP
M.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR96%D>2!E>&ES
M=',@86YD('=A<R!N;W0@:6UP;W)T960N(@IM<V=S='(@(EPB)7-<(B!JX2!E
M>&ES=&4@92!NXV\@9F]I(&EM<&]R=&%D;RXB"@HC.B!B<F]W<V4N<&AP.C$T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C;W!I960@
M8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B<E<R<@;N-O(&9O:2!C
M;W!I861O('!O<G%U92#I('5M82!L:7-T82XB"@HC.B!B<F]W<V4N<&AP.C$S
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!M;W9E9"!B
M96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B)R5S)R!NXV\@9F]I(&UO
M=FED;R!P;W)Q=64@Z2!U;6$@;&ES=&$N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@*&EE
M+B!*;VAN($1O92DB"FUS9W-T<B`B7").;VUE(%-O8G)E;F]M95PB("`H97@N
M($IOXV\@3FEN9W7I;2DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V
M"FUS9VED(")<(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H:64N($1O92P@2F]H
M;BDB"FUS9W-T<B`B7")3;V)R96YO;64L($YO;65<(B`H97@N($YI;F=UZ6TL
M($IOXV\I(@H*(SH@861D+G!H<#HQ,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@861D960N(@IM<V=S='(@(B5S(&%D:6-I;VYA9&\N(@H*(SH@9&%T82YP
M:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U
M;&QY(&EM<&]R=&5D(@IM<V=S='(@(D%R<75I=F\@)7,@:6UP;W)T861O(&-O
M;2!S=6-E<W-O(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B
M)7,@82`E<R!D92`E<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-#8T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D-A=.%L
M;V=O(&1E($5N9&5R9>=O<R!D92`E<R(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A
M<F-H+G!H<#HT,@IM<V=I9"`B02!B<F]W<V5R('1H870@<W5P<&]R=',@:49R
M86UE<R!I<R!R97%U:7)E9"(*;7-G<W1R("+)(&]B<FEG873S<FEO('5M(&YA
M=F5G861O<B!Q=64@<W5P;W)T92!I1G)A;65S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$V,`IM<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T
M<B`B1F]R;75LX7)I;R!D92!P97-Q=6ES82!A8VEM82(*"B,Z('9I97<N<&AP
M.C4R"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@=&\@)7,B
M"FUS9W-T<B`B06-E<W-O(&YE9V%D;R!A("5S(@H*(SH@861D+G!H<#HU-B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(Y"FUS9VED(")!9&0B"FUS
M9W-T<B`B061I8VEO;F%R(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B
M;V]K<V5L96-T+FEN8SHQ-S0*;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B061I8VEO;F%R(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.`IM<V=I9"`B061D(&%N9"!$96QE=&4@
M24U34"!A9&1R97-S(&)O;VMS(@IM<V=S='(@(D%D:6-I;VYA<B!E($5X8VQU
M:7(@8V%TX6QO9V\@9&4@96YD97)EYV]S($E-4U`B"@HC.B!T96UP;&%T97,O
M<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S<*;7-G:60@(D%D9"!C;VQU;6XB
M"FUS9W-T<B`B061I8VEO;F%R(&-O;'5N82(*"B,Z(&5D:70N<&AP.C$S-0IM
M<V=I9"`B061D(&9I;&4B"FUS9W-T<B`B061I8VEO;F%R(&%R<75I=F\B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(Y"FUS9VED(")!9&0@
M=&\B"FUS9W-T<B`B061I8VEO;F%R(&5M(@H*(SH@;&EB+T1R:79E<B]N=6QL
M+G!H<#HU-PIM<V=I9"`B061D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(D%D:>?C;R!D92!C;VYT871O<R!NXV\@97-TX2!D:7-P
M;V[M=F5L+B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C@V"FUS
M9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B0V%TX6QO9V\@9&4@16YD97)E
MYV]S(@H*(SH@8G)O=W-E+G!H<#HR."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(U"FUS9VED(")!9&1R97-S($)O;VL@3&ES=&EN9R(*;7-G<W1R("),:7-T
M86=E;2!D92!#873A;&]G;W,@9&4@16YD97)EYV]S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@
M(D-A=.%L;V=O<R!D92!%;F1E<F7G;W,B"@HC.B!A9&0N<&AP.C$P.`IM<V=I
M9"`B061D<F5S<R!B;V]K(&5N=')Y(@IM<V=S='(@(E)E9VES=')O(&1O(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<R(*"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B
M061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(D\@
M8V%TX6QO9V\@9&4@96YD97)EYV]S(&9O:2!L:6UP;R!C;VT@<W5C97-S;RXB
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV,@IM<V=I9"`B061D
M<F5S<R!B;V]K('1O(&1E;&5T92`B"FUS9W-T<B`B0V%TX6QO9V\@9&4@96YD
M97)EYV]S('!A<F$@97AC;'5I<B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R
M97-S8F]O:W-E;&5C="YI;F,Z,3<P"FUS9VED(")!9&1R97-S(&)O;VMS('1H
M870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R(")#873A;&]G;R!D
M92!E;F1E<F7G;W,@<75E(&[C;R!S97+C;R!E>&EB:61O<SHB"@HC.B!S96%R
M8V@N<&AP.C@X('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS.`IM<V=I
M9"`B061V86YC960@4V5A<F-H(@IM<V=S='(@(E!E<W%U:7-A($%V86[G861A
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G:60@(D%L
M:6%S(@IM<V=S='(@(D%P96QI9&\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O
M;W1E<D%L<&AA+FEN8SHW('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N
M:6YC.C$P"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#@*;7-G
M:60@(D%L;"(*;7-G<W1R(")4;V1O<R(*"B,Z(&QI8B]A<&DN<&AP.C4U-`IM
M<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B2N$@17AI<W1E(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE
M=&4@)7,_(@IM<V=S='(@(E9O8^H@=&5M(&-E<G1E>F$@<75E('%U97(@97AC
M;'5I<B`E<S\B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C8W"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE
M=&4@=&AE('-E;&5C=&5D(&5N=')I97,_(@IM<V=S='(@(E9O8^H@=&5M(&-E
M<G1E>F$@<75E('%U97(@97AC;'5I<B!O<R!R96=I<W1R;W,@<V5L96-I;VYA
M9&]S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B07-C
M96YD:6YG(@IM<V=S='(@(D%S8V5N9&5N=&4B"@HC.B!S96%R8V@N<&AP.C@U
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS-PIM<V=I9"`B0F%S:6,@
M4V5A<F-H(@IM<V=S='(@(E!E<W%U:7-A(%-I;7!L97,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34Y"FUS9VED(")"96QO=R!S96%R8V@@9F]R;2(*
M;7-G<W1R(")&;W)M=6SA<FEO(&1E('!E<W%U:7-A(&%B86EX;R(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z-S<@;&EB+T1R:79E<B]L9&%P+G!H<#HX,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*;7-G
M<W1R(")!(&-O;F5XXV\@9F%L:&]U.B`H)7,I("5S(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A>2(*;7-G<W1R
M(")!;FEV97)SX7)I;R(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHW"FUS9VED
M(")"<F]W<V4B"FUS9W-T<B`B7T5X:6)I<B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS
M9W-T<B`B0V%T96=O<FEA(&1E($YE9_-C:6]S(@H*(SH@9&%T82YP:'`Z-#D*
M;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!L:6(O3V)J96-T+T=R;W5P
M+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+B(*
M;7-G<W1R("));7!O<W/M=F5L(&%D:6-I;VYA<B!U;2!G<G5P;R!N96QE(&UE
M<VUO+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC
M.C<*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R(")-87)C87(@5&]D
M87,O7TYE;FAU;6$B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHT
M-`IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G<W1R(")%<V-O;&AA('5M(&YO
M;64B"@HC.B!A9&0N<&AP.C0X"FUS9VED(")#:&]O<V4@86X@861D<F5S<R!B
M;V]K(@IM<V=S='(@(D5S8V]L:&$@=6T@8V%TX6QO9V\@9&4@96YD97)EYV]S
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C(Q"FUS
M9VED(")#:&]O<V4@86X@861D<F5S<R!B;V]K.B(*;7-G<W1R(")%<V-O;&AA
M('5M(&-A=.%L;V=O(&1E(&5N9&5R9>=O<SHB"@HC.B!T96UP;&%T97,O<')E
M9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$V-0IM<V=I9"`B0VAO;W-E('=H
M:6-H(&%D9')E<W,@8F]O:W,@=&\@9&ES<&QA>2P@86YD(&EN('=H870@;W)D
M97(Z(@IM<V=S='(@(D5S8V]L:&$@<75A:7,@8V%TX6QO9V]S(&1E(&5N9&5R
M9>=O(&5X:6)I<B!E(&5M('%U86P@;W)D96TZ(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K
M<R!T;R!U<V4N(@IM<V=S='(@(D5S8V]L:&$@<75A;"!C873A;&]G;R!D92!E
M;F1E<F7G;W,@=71I;&EZ87(N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M
M;G-E;&5C="YI;F,Z,C(X"FUS9VED(")#:&]O<V4@=VAI8V@@8V]L=6UN<R!T
M;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R(")%<V-O;&AA
M('%U86ES(&-O;'5N87,@97AI8FER(&4@96T@<75A;"!O<F1E;3HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D-O;'5M;B!/<'1I;VYS
M(@IM<V=S='(@(D]PY_5E<R!D92!#;VQU;F$B"@HC.B!T96UP;&%T97,O<')E
M9G,O8V]L=6UN<V5L96-T+FEN8SHR,S,*;7-G:60@(D-O;'5M;G,@=&AA="!W
M:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S='(@(D-O;'5N87,@<75E(&[C
M;R!S97+C;R!E>&EB:61A<SHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N
M:6YC.C$S('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3(*;7-G:60@(D-O
M;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B5F%L;W)E<R!S97!A<F%D
M;W,@<&]R(';M<F=U;&$B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R;W-O9G0@
M3W5T;&]O:RDB"FUS9W-T<B`B5F%L;W)E<R!S97!A<F%D;W,@<&]R(';M<F=U
M;&%S("A-:6-R;W-O9G0@3W5T;&]O:RDB"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HW-@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")%;7!R97-A
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"FUS9VED(")#
M;VUP86YY($%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@9&$@16UP<F5S82(*
M"B,Z(&QI8B]A<&DN<&AP.C,R,"!L:6(O87!I+G!H<#HS-C4@;&EB+V%P:2YP
M:'`Z-#`Y(&QI8B]A<&DN<&AP.C0Y,PHC.B!L:6(O87!I+G!H<#HV,3D@;&EB
M+V%P:2YP:'`Z-S`V(&QI8B]A<&DN<&AP.C<U.2!L:6(O87!I+G!H<#HX,S<*
M(SH@;&EB+V%P:2YP:'`Z,3`R-"!L:6(O87!I+G!H<#HQ,3$R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")!
M(&-O;F5XXV\@9F%L:&]U.B`E<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M-3@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R92(*;7-G<W1R(")&86QH82!D
M92!C;VYE>.-O(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,@;&EB
M+T)L;V-K+VUI;FES96%R8V@N<&AP.C(V"FUS9VED(")#;VYT86-T(%-E87)C
M:"(*;7-G<W1R(")097-Q=6ES87(@0V]N=&%T;R(*"B,Z(&)R;W=S92YP:'`Z
M,CDY"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z("5S
M(@IM<V=S='(@(D-O;G1A=&]S(&YA(&QI<W1A.B`E<R(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3@*;7-G:60@(D-O<'DB"FUS9W-T<B`B
M0V]P:6%R(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3,*;7-G
M:60@(D-R96%T92(*;7-G<W1R(")#<FEA<B(*"B,Z('1E;7!L871E<R]A9&1R
M97-S8F]O:W,N:6YC.C0P"FUS9VED(")#<F5A=&4@061D<F5S<R!";V]K(@IM
M<V=S='(@(D-R:6%R($-A=.%L;V=O(&1E($5N9&5R9>=O<R(*"B,Z(&QI8B],
M:7-T5FEE=RYP:'`Z,S0X"FUS9VED(")#<F5A=&4@82!N97<@0V]N=&%C="!,
M:7-T(&EN.B(*;7-G<W1R(")#<FEA<B!U;6$@;F]V82!,:7-T82!D92!#;VYT
M871O<R!E;3HB"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S"FUS9VED(")#
M<F5A=&5D(@IM<V=S='(@(D-R:6%D;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS
M9W-T<B`B1&ER9>?C;R!D92!O<F1E;F'GXV\@<&%D<N-O.B(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C<V('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,PHC.B!L:6(O3V)J96-T+G!H<#HS,C@@;&EB+U)E;F1E<F5R
M+G!H<#HT-R!L:6(O4F5N9&5R97(N<&AP.C4P"FUS9VED(")$96QE=&4B"FUS
M9W-T<B`B17AC;'5I<B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C4X"FUS9VED(")$96QE=&4@061D<F5S<R!";V]K(@IM<V=S='(@(D5X8VQU
M:7(@;R!#873A;&]G;R!D92!%;F1E<F7G;W,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@*;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T
M<B`B0V]N9FER;6'GXV\@9&4@17AC;'5SXV\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T;VX@8F5H879I;W5R(@IM
M<V=S='(@(D-O;7!O<G1A;65N=&\@9&\@8F]TXV\@9&4@97AC;'5SXV\B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D$@97AC;'5SXV\@
M9F%L:&]U.B`H)7,I("5S(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HV,@IM
M<V=I9"`B1&5L971I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B17AC;'5SXV\@9&4@8V]N=&%T;W,@;N-O(&5S=.$@9&ES<&]N[79E
M;"XB"@HC.B!D96QE=&4N<&AP.C,X"FUS9VED(")$96QE=&EO;B!F86EL960B
M"FUS9W-T<B`B02!E>&-L=7/C;R!F86QH;W4B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B
M1&5P87)T86UE;G1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS
M9VED(")$97-C96YD:6YG(@IM<V=S='(@(D1E<V-E;F1E;G1E(@H*(SH@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3$U"FUS9VED(")$97-C<FEP=&EO
M;B(*;7-G<W1R(")$97-C<FGGXV\B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E
M87)C:"YI;F,Z,3$Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B1&ER973S
M<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS9VED(")$:7-P
M;&%Y(@IM<V=S='(@(D5X:6)I<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1E($5X:6)IY^-O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-PIM<V=I9"`B1&\@>6]U('=A
M;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R:65S/R(*;7-G<W1R(")6;V/J
M(&1E<V5J82!C;VYF:7)M87(@82!E>&-L=7/C;R!D92!R96=I<W1R;W,_(@H*
M(SH@;&EB+T]B:F5C="YP:'`Z,CDW"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M(")"86EX87(B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3<@=&5M
M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHR-0IM<V=I9"`B1&]W;FQO
M860@=D-A<F0B"FUS9W-T<B`B0F%I>&%R('9#87)D(@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z,3`R('1E;7!L871E<R]B<F]W<V4O<F]W+FEN
M8SHR-0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ
M,"!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C8*(SH@=&5M<&QA=&5S
M+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,R!L:6(O4F5N9&5R97(N<&AP.C0R
M"FUS9VED(")%9&ET(@IM<V=S='(@(D5D:71A<B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<F]W+FEN8SHR-2!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N
M:6YC.C,S"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S
M='(@(D5D:71A<B`G)7,G(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z.#$*;7-G:60@(D5D:70@061D<F5S<R!";V]K<R(*;7-G<W1R(")%>'!O
M<G1A<B!#873A;&]G;R!D92!%;F1E<F7G;W,B"@HC.B!E9&ET+G!H<#HX-2!E
M9&ET+G!H<#HQ-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!E;G1R>2!F
M;W(@)7,B"FUS9W-T<B`B161I=&%R(')E9VES=')O(&1E("5S(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-3@*;7-G:60@(D5M86EL(@IM<V=S
M='(@(D4M;6%I;"(*"B,Z(&5D:70N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"P@8G5T('-A=FEN9R!T:&4@=7!L
M;V%D960@9FEL92!F86EL960Z("5S(@IM<V=S='(@(D\@<F5G:7-T<F\@9&4@
M)7,@9F]I(&%T=6%L:7IA9&\L(&UA<R!F86QH;W4@86\@<V5R(&5N=FEA9&\Z
M("5S(@H*(SH@961I="YP:'`Z,34V(&5D:70N<&AP.C$U.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"XB"FUS9W-T<B`B4F5G
M:7-T<F\@9&4@)7,@9F]I(&%T=6%L:7IA9&\N(@H*(SH@8G)O=W-E+G!H<#HR
M,38@8G)O=W-E+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M861D:6YG("5D(&-O;G1A8W0H<RD@=&\@;&ES="XB"FUS9W-T<B`B17)R;R!A
M;R!A9&EC:6]N87(@)60@8V]N=&%T;RAS*2#@(&QI<W1A+B(*"B,Z(&)R;W=S
M92YP:'`Z,C$X(&)R;W=S92YP:'`Z,C8V"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&%D9&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C="AS*2!T
M;R!L:7-T+B(*;7-G<W1R(")%<G)O(&%O(&%D:6-I;VYA<B`E9"!D92`E9"!C
M;VYT871O*',I('-O;&EC:71A9&\H<RD@X"!L:7-T82XB"@HC.B!B<F]W<V4N
M<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG("5D
M(&-O;G1A8W0H<RDN(@IM<V=S='(@(D5R<F\@86\@97AC;'5I<B`E9"!C;VYT
M871O*',I+B(*"B,Z(&)R;W=S92YP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W1S
M*',I+B(*;7-G<W1R(")%<G)O(&%O(&5X8VQU:7(@)60@9&4@)60@8V]N=&%T
M;RAS*2!S;VQI8VET861O*',I+B(*"B,Z(&)R;W=S92YP:'`Z-C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@<F5M;W9I;F<@)60@8V]N=&%C="AS*2!F
M<F]M(&QI<W0N(@IM<V=S='(@(D5R<F\@86\@97AC;'5I<B`E9"!C;VYT871O
M*',I(&1A(&QI<W1A+B(*"B,Z(&)R;W=S92YP:'`Z-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@<F5M;W9I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O
M;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G<W1R(")%<G)O(&%O(&5X8VQU:7(@
M)60@9&4@)60@8V]N=&%T;RAS*2!D82!L:7-T82XB"@HC.B!L:6(O87!I+G!H
M<#HT,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5A<F-H:6YG('1H
M92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D9A;&AA(&%O('!E<W%U:7-A
M<B!N;R!C873A;&]G;R!D92!E;F1E<F7G;W,Z("5S(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHQ,"!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C0Q"FUS9VED(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T87(B"@HC.B!T
M96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C8*;7-G:60@(D5X<&]R="!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B17AP;W)T87(@0V%TX6QO9V\@9&4@16YD97)E
MYV]S(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM<V=I9"`B
M17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+B(*;7-G<W1R(")%
M>'!O<G1A<B!S;VUE;G1E(&]S(&-O;G1A=&]S('-E;&5C:6]N861O<RXB"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(W"FUS9VED(")%>'!O<G0@
M=&AE(&9O;&QO=VEN9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2XB"FUS9W-T
M<B`B17AP;W)T87(@;W,@<V5G=6EN=&5S(&-A=.%L;V=O<R!D92!E;F1E<F7G
M;W,@8V]M<&QE=&%M96YT92XB"@HC.B!D871A+G!H<#HQ,S0@9&%T82YP:'`Z
M,C(X(&1A=&$N<&AP.C(Y-R!B<F]W<V4N<&AP.C,U(&)R;W=S92YP:'`Z,3`S
M"B,Z(&)R;W=S92YP:'`Z,3,P(&%D9"YP:'`Z-C<@<V5A<F-H+G!H<#HS-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@86-C97-S('1H92!A9&1R
M97-S(&)O;VLZ("5S(@IM<V=S='(@(D9A;&AA(&%O(&%C97-S87(@;R!C873A
M;&]G;R!D92!E;F1E<F7G;W,Z("5S(@H*(SH@8G)O=W-E+G!H<#HQ-3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%D9"`E<R!T;R`E<SH@)7,B
M"FUS9W-T<B`B1F%L:&$@86\@861I8VEO;F%R("5S(&5M("5S.B`E<R(*"B,Z
M(&)R;W=S92YP:'`Z,S`U"FUS9VED(")&86EL960@=&\@8G)O=W-E(&QI<W0B
M"FUS9W-T<B`B1F%L:&$@86\@97AI8FER(&$@;&ES=&%G96TB"@HC.B!B<F]W
M<V4N<&AP.C,T,PIM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T
M;W)Y(@IM<V=S='(@(D9A;&AA(&%O(&5X:6)I<B!O(&1I<F5T\W)I;R(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L
M($YE=R!$3B`]("5S+"!2;V]T(#T@)7,B"FUS9W-T<B`B(@HB1F%L:&$@86\@
M86QT97)A<B!O(&YO;64Z("@E<RD@)7,[($%N=&EG;R!$3B`]("5S+"!.;W9O
M($1.(#T@)7,L(%)A:7H@/2`E<R(*"B,Z(&)R;W=S92YP:'`Z,3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A
M9&1E9#H@)7,B"FUS9W-T<B`B1F%L:&]U(&5M(&5N8V]N=')A<B!O(&]B:F5T
M;R!A('-E<B!A9&EC:6]N861O.B`E<R(*"B,Z('-E87)C:"YP:'`Z-SD*;7-G
M:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R
M(")&86QH82!A;R!P97-Q=6ES87(@;F\@8V%TX6QO9V\@9&4@96YD97)EYV]S
M(@H*(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,B"FUS9W-T<B`B1F%L:&]U
M(&5M('!E<W%U:7-A<B!N;R!D:7)E=/-R:6\Z("5S(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,38W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X
M(@H*(SH@961I="YP:'`Z,3,Q(&1I<W!L87DN<&AP.C$P,`IM<V=I9"`B1FEL
M97,B"FUS9W-T<B`B07)Q=6EV;W,B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E
M87)C:"YI;F,Z-S$*;7-G:60@(D9I;F0B"FUS9W-T<B`B16YC;VYT<F%R(@H*
M(SH@961I="YP:'`Z,3`T(&5D:70N<&AP.C$Y-`IM<V=I9"`B1FEN:7-H(@IM
M<V=S='(@(D9I;F%L:7IA<B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C0X"FUS9VED(")&:7)S="!.86UE(@IM<V=S='(@(E!R:6UE:7)O($YO
M;64B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,#(*;7-G:60@
M(D9R965B=7-Y(%523"(*;7-G<W1R(")54DP@3&EV<F4O3V-U<&%D;R(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHX-`IM<V=I9"`B1G)O;2(*
M;7-G<W1R(")$92(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C8P-@IM
M<V=I9"`B1VQO8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R(")#873A;&]G;R!D
M92!%;F1E<F7G;W,@1VQO8F%L(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N
M:6YC.C0S('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z-#0*;7-G
M:60@(D=R;W5P(@IM<V=S='(@(D=R=7!O(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z.#(*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")%
M;F1E<F7G;R!297-I9&5N8VEA;"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.CDS"FUS9VED(")(;VUE($-I='DB"FUS9W-T<B`B0VED861E(&1E
M(%)E<VEDZFYC:6$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ
M,#@*;7-G:60@(DAO;64@0V]U;G1R>2(*;7-G<W1R(")08>US(&1E(%)E<VED
MZFYC:6$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-3`*;7-G
M:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B1F]N92!297-I9&5N8VEA;"(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P,PIM<V=I9"`B2&]M92!0
M;W-T86P@0V]D92(*;7-G<W1R(")#15`@4F5S:61E;F-I86PB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`IM<V=I9"`B2&]M92!3=&%T92]0
M<F]V:6YC92(*;7-G<W1R(")%<W1A9&\@9&4@4F5S:63J;F-I82(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"FUS9VED(")(;VUE(%-T<F5E
M="!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O(%)E<VED96YC:6%L(@H*(SH@
M8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-3`X"FUS9VED("))35-0(@IM<V=S
M='(@(DE-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<*;7-G:60@
M(DE-4U`@061D<F5S<R!";V]K($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D
M;6EN:7-T<F'GXV\@9&4@0V%TX6QO9V\@9&4@16YD97)EYV]S($E-4U`B"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9"(*;7-G<W1R("))
M;7!O<G1A<B!#873A;&]G;R!D92!%;F1E<F7G;W,L(%!A<W-O("5D(@H*(SH@
M9&%T82YP:'`Z,S8Q"FUS9VED("));7!O<G0O17AP;W)T($%D9')E<W,@0F]O
M:W,B"FUS9W-T<B`B26UP;W)T87(O17AP;W)T87(@0V%TX6QO9V\@9&4@16YD
M97)EYV]S(@H*(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<P,0IM
M<V=I9"`B26YV86QI9"!)1"(*;7-G<W1R("))1"!);G;A;&ED;R(*"B,Z(&QI
M8B]A<&DN<&AP.C(S,B!L:6(O87!I+G!H<#HT,#0@;&EB+V%P:2YP:'`Z-#@X
M(&QI8B]A<&DN<&AP.C8Q,`HC.B!L:6(O87!I+G!H<#HV.3<@;&EB+V%P:2YP
M:'`Z-S0Y(&QI8B]A<&DN<&AP.C$P.34*;7-G:60@(DEN=F%L:60@861D<F5S
M<R!B;V]K(@IM<V=S='(@(D-A=.%L;V=O(&1E(&5N9&5R9>=O<R!I;G;A;&ED
M;R(*"B,Z(&QI8B]A<&DN<&AP.C$P.3D@;&EB+V%P:2YP:'`Z,3$W,B!L:6(O
M87!I+G!H<#HQ,C(U"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(D4M
M;6%I;"!I;G;A;&ED;R(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#<*;7-G:60@(DEN
M=F%L:60@96YT<GDB"FUS9W-T<B`B4F5G:7-T<F\@:6YVX6QI9&\B"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C(V-@IM<V=I9"`B26YV86QI9"!K97D@<W!E
M8VEF:65D+B(*;7-G<W1R(")#:&%V92!E<W!E8VEF:6-A9&$@:6YVX6QI9&$N
M(@H*(SH@;&EB+V%P:2YP:'`Z,3$P,PIM<V=I9"`B26YV86QI9"!N86UE(@IM
M<V=S='(@(DYO;64@:6YVX6QI9&\B"@HC.B!L:6(O87!I+G!H<#HW-3,*;7-G
M:60@(DEN=F%L:60@;V)J96-T260B"FUS9W-T<B`B3V)J96-T260@:6YVX6QI
M9&\B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P"FUS9VED("(B"B),1$%0
M('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N
M;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(@IM<V=S='(@(B(*(LD@;V)R
M:6=A=/-R:6\@<W5P;W)T92!A($Q$05`@;6%S(&\@;?-D=6QO($Q$05`@;N-O
M(&5S=.$@9&ES<&]N[79E;"!O=2!NXV\@(@HB9F]I(&-A<G)E9V%D;RXB"@HC
M.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS9VED("),87-T($UO9&EF:65D
M(@IM<V=S='(@(MIL=&EM82!-;V1I9FEC8>?C;R(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C4S"FUS9VED("),87-T($YA;64B"FUS9W-T<B`B
M4V]B<F5N;VUE(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R
M<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`B3&ES=&$B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S@*;7-G:60@(DUA=&-H:6YG(@IM
M<V=S='(@(D-O;7!A<F%N9&\B"@HC.B!L:6(O87!I+G!H<#HR,#<*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S(@IM<V=S='(@(D[Z;65R;R!-
MX7AI;6\@9&4@0V]N=&%T;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`W"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!P86=E<R(*;7-G<W1R(").
M^FUE<F\@;>%X:6UO(&1E('#A9VEN87,B"@HC.B!L:6(O0FQO8VLO=')E95]M
M96YU+G!H<#HS"FUS9VED(")-96YU($QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@
M365N=2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`R"FUS9VED(")-:7-S
M:6YG($1.(&EN($Q$05`@<V]U<F-E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(D1.(&9A;'1A;F1O(&YA(&9O;G1E(&1E(&-O;F9I9W5R8>?C;R!D92!,1$%0
M+B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V,@IM<V=I9"`B
M36]B:6QE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VYE($-E;'5L87(B"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S
M(@IM<V=S='(@(D$@86QT97)AY^-O(&9A;&AO=3H@*"5S*2`E<R(*"B,Z(&QI
M8B]A<&DN<&AP.C$R,3$*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD
M(@IM<V=S='(@(DUA:7,@9&4@,2!R96=I<W1R;R!E;F-O;G1R861O(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B36]V92(*
M;7-G<W1R(")-;W9E<B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE
M8W0N:6YC.C(T-PHC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE
M8W0N:6YC.C$X-`IM<V=I9"`B36]V92!L969T(@IM<V=S='(@(DUO=F5R(.`@
M97-Q=65R9&$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN
M8SHR-#D*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN
M8SHQ.#8*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B36]V97(@X"!D:7)E
M:71A(@H*(SH@9&%T82YP:'`Z-3(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ-@IM<V=I9"`B375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(D-A
M=.%L;V=O(&1E($5N9&5R9>=O<R!-=6QB97)R>2(*"B,Z(&QI8B]A<&DN<&AP
M.C$Q,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB375L=&EP;&4@<&5R<V]N
M<R!W:71H(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE<UT@
M86QR96%D>2!E>&ES="(*;7-G<W1R("(B"B)-^FQT:7!L87,@<&5S<V]A<R!C
M;VT@;R!E;F1E<F7G;R!;)7-=+"!M87,@;F5N:'5M82!C;VT@;F]M92!;)7-=
M(&KA(&5X:7-T92(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$P-R!C
M;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*;7-G:60@(DUY($%D9')E<W,@
M0F]O:R(*;7-G<W1R(")-974@0V%TX6QO9V\@9&4@16YD97)EYV]S(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HQ,3D*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B
M"FUS9W-T<B`B365U<R!#873A;&]G;W,@9&4@16YD97)EYV]S(@H*(SH@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`W(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C0R"FUS9VED(").86UE(@IM<V=S='(@(DYO;64B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R;6%T(@IM
M<V=S='(@(D9O<FUA=&\@9&\@3F]M92(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H
M<"YD:7-T.C,Q-0IM<V=I9"`B3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB
M"FUS9W-T<B`B1&ER973S<FEO(&1E($UE;6)R;W,@3F5T8V5N=&5R(@H*(SH@
M861D+G!H<#HS-B!A9&0N<&AP.C$R-"!L:6(O0FQO8VLO=')E95]M96YU+G!H
M<#HR-PIM<V=I9"`B3F5W($-O;G1A8W0B"FUS9W-T<B`B3F]V;R!#;VYT871O
M(@H*(SH@961I="YP:'`Z.34@961I="YP:'`Z,3`R(&5D:70N<&AP.C(P.2!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S
M='(@(E!R\WAI;6$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR
M,3@*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(D%P96QI9&\B"@HC.B!L:6(O
M87!I+G!H<#HQ,C$S(&QI8B]A<&DN<&AP.C$R-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S(@IM<V=S='(@(DYE;FAU
M;2!R96=I<W1R;R`E<R!F;VD@96YC;VYT<F%D;R!P87)A("5S(@H*(SH@;&EB
M+V%P:2YP:'`Z,3$X,0IM<V=I9"`B3F\@861D<F5S<R!B;V]K<R!F;W5N9"XB
M"FUS9W-T<B`B3F5N:'5M(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!E;F-O;G1R
M861O+B(*"B,Z(&UI;FES96%R8V@N<&AP.C@Q"FUS9VED(").;R!C;VYT86-T
M<R!F;W5N9"(*;7-G<W1R(").96YH=6T@8V]N=&%T;R!E;F-O;G1R861O(@H*
M(SH@;&EB+V%P:2YP:'`Z-3$S(&QI8B]A<&DN<&AP.C<X-`IM<V=I9"`B3F\@
M=D-A<F0@9&%T82!W87,@9F]U;F0N(@IM<V=S='(@(DYE;FAU;2!D861O('9#
M87)D(&9O:2!E;F-O;G1R861O+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O
M=&5R+FEN8SHW"FUS9VED(").;VYE(@IM<V=S='(@(DYE;FAU;6$B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM
M<V=S='(@(D%N;W1AY_5E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,34*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R(").
M^FUE<F\@9&4@[71E;G,@<&]R('#A9VEN82(*"B,Z(&QI8B]A<&DN<&AP.C8S
M,B!L:6(O87!I+G!H<#HW-C4*;7-G:60@(D]B:F5C="!N;W0@9F]U;F0B"FUS
M9W-T<B`B3V)J971O(&[C;R!E;F-O;G1R861O(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B17-C
M<FET\W)I;R(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,C(*
M;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE
M(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N
M($EF('1H:7,@:7,@;F]T('=H870@>6]U('=A;G0L('1H96X@>6]U(&UU<W0@
M8VAA;F=E('EO=7(@<V5L96-T:6]N("(*(G1O(%PB3F]N95PB+B(*;7-G<W1R
M("(B"B)5;6$@=F5Z('%U92!V;V/J('-A;'9E(&5S=&$@<.%G:6YA(&1E(&]P
MY_5E<RP@;R!C873A;&]G;R!D92!E;F1E<F7G;W,@<V5RX2`B"B)P97)M86YE
M;G1E;65N=&4@97AC;'7M9&\N(%-E(&ES=&\@;N-O(.D@;R!Q=64@=F]CZB!Q
M=65R+"!E;G3C;R!V;V/J(&1E=F4@(@HB86QT97)A<B!S=6$@<V5L9>?C;R!P
M87)A(%PB3F5N:'5M7"(N(@H*(SH@;&EB+V%P:2YP:'`Z-SDR"FUS9VED(")/
M;FQY(&]N92!V8V%R9"!S=7!P;W)T960N(@IM<V=S='(@(E-O;65N=&4@=6T@
M=F-A<F0@Z2!S=7!O<G1A9&\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-@IM<V=I9"`B3W1H97(@3W!T
M:6]N<R(*;7-G<W1R(")/=71R87,@3W#G]65S(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3DP"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G
M<W1R(")#:&%V92!0^F)L:6-A(%!'4"(*"B,Z(&QI8B]A<&DN<&AP.C0Y-R!L
M:6(O87!I+G!H<#HV,C,@;&EB+V%P:2YP:'`Z-S$P(&QI8B]A<&DN<&AP.CDU
M,@HC.B!L:6(O87!I+G!H<#HQ,3$V"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R(")097)M:7-SXV\@3F5G861A(@H*(SH@;&EB+T1R:79E<BYP
M:'`Z-34P"FUS9VED(")097)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")097)M
M:7-SXV\@;F5G861A(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z
M.3D*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U97,B"@HC
M.B!D871A+G!H<#HU,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS
M9VED(")0:6YE($%D9')E<W,@0F]O:R(*;7-G<W1R(")#873A;&]G;R!D92!%
M;F1E<F7G;W,@9&\@4&EN92(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C
M<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE('1H92!N97<@8V]N=&%C
M="!L:7-T.B(*;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G82!U;2!N;VUE('!A
M<F$@82!N;W9A(&QI<W1A(&1E(&-O;G1A=&]S.B(*"B,Z(&5D:70N<&AP.CDX
M(&5D:70N<&AP.C$P,2!E9&ET+G!H<#HR,#$*;7-G:60@(E!R979I;W5S(@IM
M<V=S='(@(D%N=&5R:6]R(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z
M-#$V"FUS9VED(")0<FEV871E($%D9')E<W,@0F]O:R(*;7-G<W1R(")#873A
M;&]G;R!D92!%;F1E<F7G;W,@4')I=F%D;R(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R(")!(&-O;G-U;'1A(&9A;&AO=3H@*"5S*2`E<R(*
M"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHQ.`IM<V=I9"`B
M475I8VL@4V5A<F-H(@IM<V=S='(@(E!E<W%U:7-A(%+A<&ED82(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E860@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D$@;&5I='5R82!F86QH
M;W4Z("@E<RD@)7,B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4R"FUS9VED
M(")296%D:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(D$@;&5I='5R82!D92!C;VYT871O<R!NXV\@97-TX2!D:7-P;V[M=F5L+B(*
M"B,Z(&QI8B]296YD97)E<BYP:'`Z-#D*;7-G:60@(E)E86QL>2!D96QE=&4@
M=&AI<R!C;VYT86-T/R(*;7-G<W1R(")$97-E:F$@<F5A;&UE;G1E(&5X8VQU
M:7(@97-T92!C;VYT871O/R(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R
M+FEN8SHR"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`B4F5G
M:7-T<F]S(&5X:6)I9&]S.B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S
M8F]O:W-E;&5C="YI;F,Z,3<V"FUS9VED(")296UO=F4@861D<F5S<R!B;V]K
M(@IM<V=S='(@(D5S8V]L:&$@=6T@8V%TX6QO9V\@9&4@96YD97)EYV]S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,Y"FUS9VED
M(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E)E;6]V97(@8V]L=6YA(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"FUS9VED(")296UO=F4@
M9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B4F5M;W9E<B!D97-T82!L:7-T82(*
M"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C$*;7-G:60@(B(*(E)E
M<&QA8V4@97AI<W1I;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D
M(&]N93\@/'-T<F]N9SY787)N:6YG.B!4:&ES("(*(F1E;&5T97,@86QL(&5N
M=')I97,@:6X@>6]U<B!C=7)R96YT(&%D9')E<W,@8F]O:RX\+W-T<F]N9SXB
M"FUS9W-T<B`B(@HB4W5B<W1I='5I<B!O(&-A=.%L;V=O(&1E(&5N9&5R9>=O
M<R!P96QO(&EM<&]R=&%D;S\@/'-T<F]N9SY!=&5NY^-O.B!)<W1O("(*(F5X
M8VQU:7+A('1O9&]S(&]S(')E9VES=')O<R!D;R!S974@8V%TX6QO9V\@9&4@
M96YD97)EYV]S(&%T=6%L+CPO<W1R;VYG/B(*"B,Z(&QI8B]$<FEV97(N<&AP
M.C0S.`IM<V=I9"`B4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N(@IM<V=S
M='(@(D\@;V)J971O('-O;&EC:71A9&\@;N-O(&9O:2!E;F-O;G1R861O+B(*
M"B,Z(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q
M-`IM<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B4F5T;W)N87(@
M<&%R82!O<R!P861R]65S(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I9FEC871E(@IM<V=S
M='(@(D-E<G1I9FEC861O(%#Z8FQI8V\@4R]-24U%(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")35$%25%1,4R!F
M86EL960Z("@E<RD@)7,B"FUS9W-T<B`B3R!35$%25%1,4R!F86QH;W4Z("@E
M<RD@)7,B"@HC.B!E9&ET+G!H<#HQ,#8@861D+G!H<#HS-R!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHQ,C0*;7-G:60@(E-A=F4B"FUS9W-T<B`B4V%L
M=F%R(@H*(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HV-PIM<V=I9"`B4V%V:6YG
M(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D\@<V%L=F%M
M96YT;R!D92!C;VYT871O<R!NXV\@97-TX2!D:7-P;V[M=F5L+B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-R!T96UP;&%T97,O8G)O=W-E
M+W-E87)C:"YI;F,Z,3$S"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H
M+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HT.0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B"FUS9W-T<B`B4&5S
M<75I<V%R(@H*(SH@;&EB+V%P:2YP:'`Z,3`R.0IM<V=I9"`B4V5A<F-H(&9A
M:6QE9"(*;7-G<W1R(")!('!E<W%U:7-A(&9A;&AO=2(*"B,Z(&QI8B]A<&DN
M<&AP.C$Q,C$@;&EB+V%P:2YP:'`Z,3$R-R!L:6(O87!I+G!H<#HQ,3,V(&QI
M8B]A<&DN<&AP.C$Q-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B02!P97-Q=6ES82!F86QH;W4Z("5S(@H*(SH@
M;&EB+T1R:79E<B]N=6QL+G!H<#HT-PIM<V=I9"`B4V5A<F-H:6YG(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(E!E<W%U:7-A(&[C;R!E<W3A(&1I<W!O
M;NUV96PN(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(R
M"FUS9VED(")396%R8VAI;F<N+BXB"FUS9W-T<B`B4&5S<75I<V%N9&\N+BXB
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV-@IM<V=I9"`B4V5L
M96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D96QE=&4B"FUS9W-T<B`B4V5L96-I
M;VYE('5M(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!P87)A(&5X8VQU:7(B"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY,`IM<V=I9"`B4V5L96-T
M(&%N(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(E-E;&5C:6]N92!U
M;2!C873A;&]G;R!D92!E;F1E<F7G;W,@<&%R82!E9&ET87(B"@HC.B!T96UP
M;&%T97,O9&%T82]E>'!O<G0N:6YC.C,R"FUS9VED(")396QE8W0@=&AE(&%D
M9')E<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T<B`B4V5L96-I;VYE
M(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S('!A<F$@97AP;W)T87(Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR-@IM<V=I9"`B4V5L96-T('1H
M92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.B(*;7-G<W1R(")396QE8VEO
M;F4@;R!C873A;&]G;R!D92!E;F1E<F7G;W,@<&%R82!I;7!O<G1A<CHB"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,U"FUS9VED(")396QE8W0@
M=&AE(&-H87)S970@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G<W1R(")396QE
M8VEO;F4@;R!C;VYJ=6YT;R!D92!C87)A8W1E<F5S(&1O(&%R<75I=F\@9&4@
M;W)I9V5M.B(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*;7-G
M:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-I
M;VYE(&\@9F]R;6%T;R!P87)A(&5X<&]R=&%R.B(*"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z-#,*;7-G:60@(E-E;&5C="!T:&4@9FEL92!T;R!I
M;7!O<G0Z(@IM<V=S='(@(E-E;&5C:6]N92!O(&%R<75I=F\@<&%R82!I;7!O
M<G1A<CHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$Q"FUS9VED
M(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S
M='(@(E-E;&5C:6]N92!O(&9O<FUA=&\@9&\@87)Q=6EV;R!D92!O<FEG96TZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L96-T
M('1H92!F;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA;65S.B(*;7-G<W1R(")3
M96QE8VEO;F4@;R!F;W)M871O('5T:6QI>F%D;R!P87)A(&5X:6)I<B!O<R!N
M;VUE<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4*;7-G:60@(E-E
M;&5C="!V:65W('1O(&1I<W!L87D@8GD@9&5F875L="P@<V]R="!O<'1I;VYS
M+"!A;F0@<&%G:6YG(&]P=&EO;G,N(@IM<V=S='(@(B(*(E-E;&5C:6]N92!A
M('9I<W5A;&EZ8>?C;R!P87)A(&5X:6)I<B!P;W(@<&%D<N-O+"!O<.?U97,@
M9&4@;W)D96YAY^-O(&4@(@HB;W#G]65S(&1E('!A9VEN8>?C;RXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@*;7-G:60@(E-E;&5C="!W:&EC:"!F
M:65L9',@=&\@9&ES<&QA>2!I;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS9W-T
M<B`B4V5L96-I;VYE('%U86ES(&-A;7!O<R!E>&EB:7(@;F%S(&QI<W1A<R!D
M92!E;F1E<F7G;W,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R"FUS
M9VED(")396QE8W0@=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@;F%M97,N(@IM
M<V=S='(@(E-E;&5C:6]N92!E;2!Q=6%L(&9O<FUA=&\@97AI8FER(&YO;65S
M+B(*"B,Z(&%D9"YP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5L96-T
M960@861D<F5S<R!B;V]K(%PB)7-<(BXB"FUS9W-T<B`B0V%TX6QO9V\@9&4@
M96YD97)EYV]S('-E;&5C:6]N861O("<E<R<N(@H*(SH@8V]N9FEG+W-O=7)C
M97,N<&AP+F1I<W0Z,3<S"FUS9VED(")3:&%R960@1&ER96-T;W)Y(@IM<V=S
M='(@(D1I<F5T\W)I;R!#;VUP87)T:6QH861O(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W
M("5S(@IM<V=S='(@(D5X:6)I<B`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z-#@*;7-G:60@(E-H;W<@06QL(@IM<V=S='(@(D5X:6)I
M<B!4;V1A<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#<*
M;7-G:60@(E-H;W<@0V]N=&%C=',B"FUS9W-T<B`B17AI8FER($-O;G1A=&]S
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-@IM<V=I9"`B
M4VAO=R!,:7-T<R(*;7-G<W1R(")%>&EB:7(@3&ES=&%S(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,C$*(SH@=&5M<&QA=&5S
M+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,S8*;7-G:60@(E-O<G0@1&ER
M96-T:6]N(@IM<V=S='(@(D1I<F7GXV\@9&4@3W)D96YAY^-O(@H*(SH@;&EB
M+V%P:2YP:'`Z,C`P"FUS9VED(")3;W5R8V5S(@IM<V=S='(@(D9O;G1E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(E-P96-I9GD@
M=VAE<F4@>6]U('=A;G0@861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P
M96%R+B(*;7-G<W1R("(B"B)%<W!E8VEF:7%U92!O;F1E('9O8^H@<75E<B!Q
M=64@;W,@<F5S=6QT861O<R!D82!P97-Q=6ES82!A=F%NYV%D82!A<&%R9>=A
M;2XB"@HC.B!B<F]W<V4N<&AP.C(Q-"!B<F]W<V4N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@)60@8V]N=&%C="AS
M*2!T;R!L:7-T+B(*;7-G<W1R("(E9"!C;VYT871O*',I(&%D:6-I;VYA9&]S
M(&-O;2!S=6-E<W-O(.`@;&ES=&$N(@H*(SH@8G)O=W-E+G!H<#HQ-C`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S
M(@IM<V=S='(@(B5S(&%D:6-I;VYA9&\@8V]M('-U8V5S<V\@X"`E<R(*"B,Z
M(&)R;W=S92YP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!C<F5A=&5D('1H92!C;VYT86-T(&QI<W0@7"(E<UPB+B(*;7-G<W1R
M("),:7-T82!D92!C;VYT871O<R!<(B5S7"(@8W)I861A(&-O;2!S=6-E<W-O
M+B(*"B,Z(&)R;W=S92YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&1E;&5T960@)60@8V]N=&%C="AS*2XB"FUS9W-T<B`B)60@
M8V]N=&%T;RAS*2!E>&-L=>UD;RAS*2!C;VT@<W5C97-S;RXB"@HC.B!B<F]W
M<V4N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M96UO=F5D("5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G<W1R("(E9"!C
M;VYT871O*',I(&5X8VQU[61O<R!C;VT@<W5C97-S;R!D82!L:7-T82XB"@HC
M.B!D871A+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S='(@(E135B(*"B,Z('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T
M<B`B5F%L;W)E<R!S97!A<F%D;W,@<&]R('1A8G5L8>?U97,B"@HC.B!V:65W
M+G!H<#HQ-0IM<V=I9"`B5&AE(%9&4R!B86-K96YD(&YE961S('1O(&)E(&-O
M;F9I9W5R960@=&\@96YA8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RXB"FUS9W-T
M<B`B(@HB3R!C;VYE8W1O<B!61E,@;F5C97-S:71A('-E<B!C;VYF:6=U<F%D
M;R!P87)A(&AA8FEL:71A<B!O(&5N=FEO(&1E(&%N97AO<RXB"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ,#<V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R
M97-S(&)O;VL@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")/(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<R!<(B5S7"(@;N-O(&5X:7-T92XB"@HC.B!A
M9&1R97-S8F]O:W,N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A
M9&1R97-S(&)O;VL@7"(E<UPB('=A<R!C<F5A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B3R!C873A;&]G;R!D92!E;F1E<F7G;W,@7"(E<UPB(&9O:2!C
M<FEA9&\@8V]M('-U8V5S<V\N(@H*(SH@861D<F5S<V)O;VMS+G!H<#HW,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W
M87,@<F5M;W9E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D\@8V%TX6QO9V\@
M9&4@96YD97)EYV]S(%PB)7-<(B!F;VD@97AC;'7M9&\@8V]M('-U8V5S<V\N
M(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P
M9&%T960N(@IM<V=S='(@(D\@8V%TX6QO9V\@9&4@96YD97)EYV]S(%PB)7-<
M(B!F;VD@871U86QI>F%D;R!C;VT@<W5C97-S;RXB"@HC.B!D871A+G!H<#HS
M,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!C;W5L
M9"!N;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R(")/(&-A=.%L;V=O(&1E(&5N
M9&5R9>=O<R!NXV\@</1D92!S97(@;&EM<&\Z("5S(@H*(SH@961I="YP:'`Z
M-3$@=F-A<F0N<&AP.C(R(&1I<W!L87DN<&AP.C(S('9I97<N<&AP.C(V"FUS
M9VED(")4:&4@8V]N=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R(")/(&-O;G1A=&\@<75E('9O8^H@<V]L:6-I=&]U(&[C;R!E
M>&ES=&4N(@H*(SH@961I="YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE(%PB)7-<(B!H87,@<W5C8V5S<V9U;&QY(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B3R!A<G%U:79O(%PB)7-<(B!F;VD@97AC;'7M9&\@8V]M
M('-U8V5S<V\N(@H*(SH@9&%T82YP:'`Z,C@T"FUS9VED(")4:&4@:6UP;W)T
M(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W87)N:6YG<RXB"FUS9W-T
M<B`B02!I;7!O<G1AY^-O('!O9&4@<V5R(&9I;F%L:7IA9&$@:6YD97!E;F1E
M;G1E(&1O<R!A=FES;W,N(@H*(SH@8G)O=W-E+G!H<#HS,0IM<V=I9"`B5&AE
M<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RXB"FUS9W-T<B`B
M3N-O(&5X:7-T96T@8V%TX6QO9V]S(&1E(&5N9&5R9>=O<R!Q=64@<&]S<V%M
M('-E<B!E>&EB:61O<RXB"@HC.B!A9&0N<&AP.C(Y"FUS9VED("(B"B)4:&5R
M92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE
M(&%V86EL86)L92!A9&1R97-S(&)O;VMS("(*(F%R92!C;VYF:6=U<F5D('1O
M(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@>6]U
M(&)E;&EE=F4@=&AI<R`B"B)I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@
M>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3N-O(&5X
M:7-T96T@8V%TX6QO9V]S(&1E(&5N9&5R9>=O<R!C;VT@<&5R;6ES<_5E<R!D
M92!G<F%V8>?C;RX@3F5N:'5M(&1O<R`B"B)C873A;&]G;W,@9&4@96YD97)E
MYV]S(&5S=.-O(&-O;F9I9W5R861O<R!P87)A('!E<FUI=&ER('9O8^H@861I
M8VEO;F%R(&YO=F]S("(*(G)E9VES=')O<RX@4V4@=F]CZB!A8W)E9&ET82!Q
M=64@:7-T;R#I('5M(&5R<F\L('!O<B!F879O<B!E;G1R92!E;2!C;VYT871O
M("(*(F-O;2!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M82XB"@HC.B!A9&0N
M<&AP.C$R,0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T
M:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)(;W5V92!U
M;2!E<G)O(&%O(&%D:6-I;VYA<B!O(&YO=F\@8V]N=&%T;RX@16YT<F4@96T@
M8V]N=&%T;R!C;VT@;R`B"B)A9&UI;FES=')A9&]R(&1O('-I<W1E;6$@<&%R
M82!M86EO<F5S(&1E=&%L:&5S+B(*"B,Z(&)R;W=S92YP:'`Z,C<Q"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="XB"FUS
M9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!C<FEA<B!U;6$@;F]V82!L:7-T82XB
M"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D9')E<W,@8F]O
M:SH@)7,B"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!C<FEA<B!E<W1E(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<SH@)7,B"@HC.B!B<F]W<V4N<&AP.C$V-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@7"(E<UPB(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(DAO=79E('5M(&5R<F\@86\@97AC;'5I<B`E<R!D;R!C873A;&]G;R!D
M92!E;F1E<F7G;W,@9&4@;W)I9V5M+B(*"B,Z(&1E;&5T92YP:'`Z,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG
M('1H:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!E
M>&-L=6ER(&5S=&4@8V]N=&%T;SH@)7,B"@HC.B!B<F]W<V4N<&AP.C,Q,0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AE(&QI<W0B
M"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!E>&EB:7(@82!L:7-T82(*"B,Z
M(&1A=&$N<&AP.C,S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A.B`E<R(*;7-G<W1R(")(;W5V
M92!U;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S.B`E<R(*"B,Z(&QI8B]A
M<&DN<&AP.C4P.2!L:6(O87!I+G!H<#HW-SD*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R
M(")(;W5V92!U;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S(&1O(&E#86QE
M;F1A<BXB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C4X(&%D9')E<W-B;V]K<RYP
M:'`Z-C,@861D<F5S<V)O;VMS+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@=&AI<R!A9&1R97-S(&)O
M;VLZ("5S(@IM<V=S='(@(DAO=79E('5M(&5R<F\@86\@97AC;'5I<B!E<W1E
M(&-A=.%L;V=O(&1E(&5N9&5R9>=O<SH@)7,B"@HC.B!A9&1R97-S8F]O:W,N
M<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B2&]U
M=F4@=6T@97)R;R!A;R!A='5A;&EZ87(@97-T92!R96=I<W1R;SH@)7,B"@HC
M.B!E9&ET+G!H<#HQ-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H:7,@96YT<GDZ("5S(@IM<V=S='(@(DAO
M=79E('5M(&5R<F\@86\@871U86QI>F%R(&5S=&4@<F5G:7-T<F\Z("5S(@H*
M(SH@9&%T82YP:'`Z,3<Y"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E<W-E
M<R!T;R!E>'!O<G0N(@IM<V=S='(@(D[C;R!E>&ES=&EA;2!E;F1E<F7G;W,@
M<&%R82!E>'!O<G1A<BXB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O
M;VMS96QE8W0N:6YC.C$X,`IM<V=I9"`B5&AE<V4@861D<F5S<R!B;V]K<R!W
M:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B17-T97,@8V%T
MX6QO9V]S(&1E(&5N9&5R9>=O<R!S97+C;R!E>&EB:61O<R!N82!S96=U:6YT
M92!O<F1E;3HB"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN
M8SHR-#,*;7-G:60@(E1H97-E(&-O;'5M;G,@=VEL;"!D:7-P;&%Y(&EN('1H
M:7,@;W)D97(Z(@IM<V=S='(@(D5S=&%S(&-O;'5N87,@<V5RXV\@97AI8FED
M87,@;F$@<V5G=6EN=&4@;W)D96TZ(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED
M(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(D5S=&4@9F]R;6%T;R!D92!A<G%U:79O(&[C;R#I('-U<&]R=&%D;RXB"@HC
M.B!L:6(O87!I+G!H<#HQ,30P(&QI8B]A<&DN<&AP.C$Q-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R
M>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(D5S=&$@<&5S<V]A(&KA
M('1E;2!U;2!R96=I<W1R;R`E<R!N;R!C873A;&]G;R!D92!E;F1E<F7G;W,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30X"FUS9VED("(B"B)4:&ES
M('=I;&P@8F4@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG
M(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB"FUS9W-T<B`B(@HB17-T92!S97+A
M(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S('!A9'+C;R!P87)A(&%D:6-I;VYA
M<B!E(&EM<&]R=&%R(&-O;G1A=&]S+B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C<P"FUS9VED(")4:71L92(*;7-G<W1R(")4[71U;&\B"@HC
M.B!L:6(O5'5R8F$N<&AP.C0T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(&YE=R!S:&%R92X@36ES<VEN9R!S;W5R8V4@='EP92XB
M"FUS9W-T<B`B26UP;W-S[79E;"!C<FEA<B!U;2!N;W9O(&-O;7!A<G1I;&AA
M;65N=&\N(%1I<&\@9&4@;W)I9V5M(&9A;'1A;F1O+B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C$P,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@
M8V%R<F5G87(@82!D969I;FGGXV\@9&4@)7,N(@H*(SH@961I="YP:'`Z.34@
M961I="YP:'`Z.3@@961I="YP:'`Z,3`Q(&5D:70N<&AP.C$P-B!E9&ET+G!H
M<#HR,#,*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")$97-F87IE<B!!
M;'1E<F'G]65S(@H*(SH@;&EB+V%P:2YP:'`Z-30R(&QI8B]A<&DN<&AP.C8V
M,2!L:6(O87!I+G!H<#HW.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YS=7!P
M;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G<W1R(")#;VYT96YT+51Y<&4@
M;N-O('-U<&]R=&%D;SH@)7,B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES
M=#HS-S8*;7-G:60@(E9E<FES:6=N($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E
M=/-R:6\@5F5R:7-I9VXB"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z
M,3D@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHR-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W(%PB)7-<(B(*;7-G<W1R(")6:7-U86QI>F%R
M(%PB)7-<(B(*"B,Z(&UI;FES96%R8V@N<&AP.C<V"FUS9VED(")6:65W($-O
M;G1A8W0B"FUS9W-T<B`B5FES=6%L:7IA<B!#;VYT871O(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5FEE=R!T;R!D:7-P;&%Y(&)Y
M(&1E9F%U;'0Z(@IM<V=S='(@(E9I<W5A;&EZ8>?C;R!P87)A(&5X:6)I<B!P
M;W(@<&%D<N-O.B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P
M.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T<B`B55),(&1O(%=E8G-I=&4B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3,*;7-G:60@(E=O
M<FL@061D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!#;VUE<F-I86PB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E=O<FL@0VET
M>2(*;7-G<W1R(")#:61A9&4@9&4@5')A8F%L:&\B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ,SD*;7-G:60@(E=O<FL@0V]U;G1R>2(*;7-G
M<W1R(")08>US(&1E(%1R86)A;&AO(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,34V"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(D9O;F4@
M0V]M97)C:6%L(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,T
M"FUS9VED(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S='(@(D-%4"!#;VUE<F-I
M86PB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*;7-G:60@
M(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B17-T861O(&1E(%1R86)A
M;&AO(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$Y"FUS9VED
M(")7;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O($-O;65R
M8VEA;"(*"B,Z(&1A=&$N<&AP.C(S-R!B<F]W<V4N<&AP.C$P-B!B<F]W<V4N
M<&AP.C(R-R!A9&0N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!C;VYT86-T
M<R!I;B!<(B5S7"(N(@IM<V=S='(@(E9O8^H@;N-O(&5S=.$@875T;W)I>F%D
M;R!A(&-R:6%R(&UA:7,@9&4@)60@8V]N=&%T;W,@96T@7"(E<UPB+B(*"B,Z
M(&5D:70N<&AP.C<S(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V"FUS9VED
M(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N
M=&%C="XB"FUS9W-T<B`B5F]CZB!NXV\@=&5M('!E<FUI<W/C;R!P87)A('9I
M<W5A;&EZ87(@97-T92!C;VYT871O+B(*"B,Z('9C87)D+G!H<#HT,`IM<V=I
M9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B
M:F5C="XB"FUS9W-T<B`B5F]CZB!NXV\@=&5M('!E<FUI<W/C;R!P87)A('9I
M<W5A;&EZ87(@97-T92!O8FIE=&\N(@H*(SH@;&EB+U1U<F)A+G!H<#HU,S<*
M;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N<R!T;R!D96QE=&4@
M=&AI<R!S;W5R8V4N(@IM<V=S='(@(E9O8^H@;N-O('1E;2!P97)M:7-SXV\@
M<&%R82!E>&-L=6ER(&5S=&$@9F]N=&4N(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]J879A<V-R:7!T+FEN8SHU-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@
M=&%R9V5T(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B5F]CZB!D979E('-E;&5C
M:6]N87(@=6T@8V%TX6QO9V\@9&4@96YD97)EYV]S(&1E<W1I;F\N(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHR,PIM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N(@IM<V=S='(@(E9O8^H@9&5V
M92!S96QE8VEO;F%R('5M82!L:7-T82!D92!D97-T:6YO+B(*"B,Z(&5D:70N
M<&AP.C,R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&-O
M;G1A8W0@9FER<W0N(@IM<V=S='(@(E9O8^H@9&5V92!S96QE8VEO;F%R('!E
M;&\@;65N;W,@=6T@8V]N=&%T;R!P<FEM96ER;RXB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O:F%V
M87-C<FEP="YI;F,Z-#D*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T
M+FEN8SHW,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!E
M;G1R>2!F:7)S="XB"FUS9W-T<B`B5F]CZB!D979E('-E;&5C:6]N87(@<&5L
M;R!M96YO<R!U;2!R96=I<W1R;RXB"@HC.B!E9&ET+G!H<#HW-PIM<V=I9"`B
M66]U(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T
M+B(*;7-G<W1R(")6;V/J('-O;65N=&4@=&5M('!E<FUI<W/C;R!D92!V:7-U
M86QI>F%R(&5S=&4@8V]N=&%T;RXB"@HC.B!B<F]W<V4N<&AP.C,Q.`IM<V=I
M9"`B66]U<B!D969A=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E86)L
M92XB"FUS9W-T<B`B4V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!P861RXV\@
M;N-O(.D@;F%V96?A=F5L+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN
M8SHV('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@
M(EMN;R!V86QU95TB"FUS9W-T<B`B6W-E;2!V86QO<ETB"@HC.B!L:6(O5'5R
M8F$N<&AP.C4V,`IM<V=I9"`B7T)R;W=S92(*;7-G<W1R(")?17AI8FER(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-PIM<V=I9"`B7T-O
M;G1A8W1S(@IM<V=S='(@(D5X:6)I<B!?0V]N=&%T;W,B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*;7-G:60@(E]$96QE=&4B"FUS9W-T
M<B`B17AC7VQU:7(B"@HC.B!L:6(O5'5R8F$N<&AP.C4V.0IM<V=I9"`B7TEM
M<&]R="]%>'!O<G0B"FUS9W-T<B`B26UP;W)T87(O15]X<&]R=&%R(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT-@IM<V=I9"`B7TQI<W1S
M(@IM<V=S='(@(DQI<W1A(@H*(SH@;&EB+U1U<F)A+G!H<#HU-3<*;7-G:60@
M(E]->2!!9&1R97-S($)O;VMS(@IM<V=S='(@(DUE=7,@0V%TX6QO9V]S(&1E
M($5N9&5R9>=O<R(*"B,Z(&QI8B]4=7)B82YP:'`Z-38S"FUS9VED(")?3F5W
M($-O;G1A8W0B"FUS9W-T<B`B3E]O=F\@0V]N=&%T;R(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PIM<V=I9"`B7U)E;6]V92!F<F]M('1H
M:7,@;&ES="(*;7-G<W1R(")?4F5M;W9E<B!D97-T82!L:7-T82(*"B,Z(&QI
M8B]4=7)B82YP:'`Z-38U"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E]097-Q
M=6ES87(B"@HC.B!V8V%R9"YP:'`Z-#8*;7-G:60@(F-O;G1A8W0N=F-F(@IM
M<V=S='(@(F-O;G1A=&]S+G9C9B(*"B,Z(&1A=&$N<&AP.C$Y.2!D871A+G!H
M<#HR,#0@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ"FUS9VED(")C;VYT
M86-T<RYC<W8B"FUS9W-T<B`B8V]N=&%T;W,N8W-V(@H*(SH@9&%T82YP:'`Z
M,C`Y"FUS9VED(")C;VYT86-T<RYT<W8B"FUS9W-T<B`B8V]N=&%T;W,N='-V
M(@H*(SH@9&%T82YP:'`Z,C$Y"FUS9VED(")C;VYT86-T<RYV8V8B"FUS9W-T
M<B`B8V]N=&%T;W,N=F-F(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M.`IM<V=I9"`B;F\@9F]R;6%T=&EN9R(*;7-G<W1R(")S96T@9F]R;6%T8>?C
M;R(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S(*;7-G:60@
M(FYO;F4B"FUS9W-T<B`B;F5N:'5M82(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z,S$*;7-G:60@(G1O(&$@0V]N=&%C="!,:7-T(@IM<V=S
M='(@(G!A<F$@=6UA($QI<W1A(&1E($-O;G1A=&]S(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B=&\@82!D:69F97)E;G0@
M061D<F5S<R!";V]K(@IM<V=S='(@(G!A<F$@=6T@0V%TX6QO9V\@9&4@16YD
M97)EYV]S(&1I9F5R96YT92(*"B,Z(&1A=&$N<&AP.C4Q('1E;7!L871E<R]B
M<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$S"B,Z('1E;7!L871E<R]D871A
M+VEM<&]R="YI;F,Z,34@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R
M8F$O<&\O<'1?4%0N<&\`````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`V-#`V-P`Q,#0Q-S,V,C<U-@`P,3<U-C(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!455)"02!0;W)T
M=6=A;"!0;W)T=6=U97-E('1R86YS;&%T:6]N+@HC($UA;G5E;"!-96YE>F5S
M(&1E(%-E<75E:7)A(#Q-86YU96PN4V5Q=65I<F$^+"`R,#`U+@HC($)A<V5D
M(&]N(&$@<')E=FEO=7,*(R!4=7)B82!0;W)T=6=A;"!0;W)T=6=U97-E('1R
M86YS;&%T:6]N+@HC($YU;F\@3&]U<F5I<F\@/&YU;F]`971H+G!T/BP@,C`P
M,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@
M5'5R8F$@,BXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$S(#$W.C$S*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#(M
M,C$@,3@Z,S$K,#`P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!.=6YO($QO=7)E
M:7)O(#QN=6YO0&5T:"YP=#Y<;B(*(DQA;F=U86=E+51E86TZ(%!O<G1U9W5E
M<V4@/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N
M,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX
M.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB
M"@HC.B!B<F]W<V4N<&AP.C$R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&YO="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S
M='(@(EPB)7-<(B!NXV\@9F]I(&-O<&EA9&\@<&]R('-E<B!U;6$@;&ES=&$N
M(@H*(SH@8G)O=W-E+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S
M='(@(EPB)7-<(B!NXV\@9F]I(&UO=FED;R!P;W(@<V5R('5M82!L:7-T82XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"FUS9VED(")<(D9I<G-T
M;F%M92!,87-T;F%M95PB("`H:64N($IO:&X@1&]E*2(*;7-G<W1R(")<(E!R
M\W!R:6\@07!E;&ED;UPB("AE+F<N+"!*;W/I(%-I;'9A*2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(EPB3&%S=&YA;64L($9I<G-T
M;F%M95PB("AI92X@1&]E+"!*;VAN*2(*;7-G<W1R(")<(D%P96QI9&\L(%!R
M\W!R:6]<(B`H92YG+BP@4VEL=F$L($IO<^DI(@H*(SH@861D+G!H<#HX-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B)7,@861I
M8VEO;F%D;RXB"@HC.B!D871A+G!H<#HR-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@9FEL92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B1FEC
M:&5I<F\@)7,@:6UP;W)T861O(&-O;2!S=6-E<W-O(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]F;V]T97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@82`E<R!D92`E<R(*"B,Z(&QI8B]"
M;&]C:R]M:6YI<V5A<F-H+G!H<#HT-0IM<V=I9"`B02!B<F]W<V5R('1H870@
M<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9"(*;7-G<W1R("+)(&YE8V5S
M<^%R:6\@=6T@;F%V96=A9&]R('%U92!S=7!O<G1E(&E&<F%M97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"FUS9VED(")!8F]V92!S96%R8V@@
M9F]R;2(*;7-G<W1R(")3;V)R92!O(&9O<FUU;.%R:6\@9&4@<')O8W5R82(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHV-0IM<V=I9"`B061?
M=F%N8V5D(%-E87)C:"(*;7-G<W1R(")097-?<75I<V$@079A;N=A9&$B"@HC
M.B!A9&0N<&AP.C4R"FUS9VED(")!9&0B"FUS9W-T<B`B061I8VEO;F%R(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,W"FUS9VED
M(")!9&0@8V]L=6UN(@IM<V=S='(@(D%D:6-I;VYA<B!C;VQU;F$B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(R"FUS9VED(")!9&0@=&\B
M"FUS9W-T<B`B061I8VEO;F%R(&$B"@HC.B!B<F]W<V4N<&AP.C,P(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I
M;F<B"FUS9W-T<B`B3&ES=&%G96T@9&]S($-O;G1A8W1O<R(*"B,Z(&%D9"YP
M:'`Z.#8*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R>2(*;7-G<W1R(")#;VYT
M86-T;R(*"B,Z(&QI8B]$<FEV97(N<&AP.C0W.`IM<V=I9"`B061D<F5S<R!B
M;V]K(&ES(')E860M;VYL>2XB"FUS9W-T<B`B3&EV<F\@9&4@96YD97)EYV]S
M('/S('!O9&4@<V5R(&QI9&\N(@H*(SH@9&%T82YP:'`Z,C,V"FUS9VED(")!
M9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"XB"FUS9W-T<B`B3&EV
M<F\@9&4@96YD97)EYV]S('!U<F=A9&\@8V]M('-U8V5S<V\N(@H*(SH@<V5A
M<F-H+G!H<#HY-R!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-C4*(SH@
M=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q,PIM<V=I9"`B061V86YC
M960@4V5A<F-H(@IM<V=S='(@(E!E<W%U:7-A($%V86[G861A(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G:60@(D%L:6%S(@IM<V=S
M='(@(D%L8W5N:&$B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA
M+FEN8SHV('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.CD*;7-G
M:60@(D%L;"(*;7-G<W1R(")4=61O(@H*(SH@;&EB+V%P:2YP:'`Z,SDU"FUS
M9VED(")!;')E861Y($5X:7-T<R(*;7-G<W1R(")*X2!%>&ES=&4B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T
M92`E<S\B"FUS9W-T<B`B475E<B!M97-M;R!R96UO=F5R("5S/R(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-C,*;7-G:60@(D%R92!Y
M;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L96-T960@
M96YT<FEE<S\B"FUS9W-T<B`B475E<B!M97-M;R!R96UO=F5R(&%S(&5N=')A
M9&%S('-E;&5C8VEO;F%D87,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<P"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B0W)E<V-E;G1E(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,S"FUS9VED(")!
M=F%I;&%B;&4@0V]L=6UN<SHB"FUS9W-T<B`B0V]L=6YA<R!D:7-P;V[M=F5I
M<SHB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0T"B,L('!H
M<"UF;W)M870*;7-G:60@(D)A7V-K('1O("5S(@IM<V=S='(@(E]6;VQT87(@
M82`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R(")6;VQT87(@
M82`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,38*;7-G
M:60@(D)A<VE?8R!396%R8V@B"FUS9W-T<B`B4')O8W5R82!"X7-I7V-A(@H*
M(SH@<V5A<F-H+G!H<#HY-"!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z
M-C(*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q-@IM<V=I9"`B
M0F%S:6,@4V5A<F-H(@IM<V=S='(@(E!R;V-U<F$@0N%S:6-A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,0IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O
M<FTB"FUS9W-T<B`B4V]B(&\@9F]R;75LX7)I;R!D92!P<F]C=7)A(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HX-2!L:6(O1')I=F5R+VQD87`N<&AP.C@X
M"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S(@IM
M<V=S='(@(DQI9V'GXV\@9F%L:&]U.B`H)7,I("5S(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A>2(*;7-G<W1R
M(")!;FEV97)SX7)I;R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$W,PIM<V=I9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS9W-T<B`B0V%T96=O
M<FEA(&1E($YE9_-C:6\B"@HC.B!D871A+G!H<#HR.`IM<V=I9"`B0U-6(@IM
M<V=S='(@(D-35B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M-#@*;7-G:60@(D-?;&5A<B!396%R8V@B"FUS9W-T<B`B7TQI;7!A<B!097-Q
M=6ES82(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC
M.C4*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R(")-87)C87(@7U1U
M9&\O3F%D82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.0IM<V=I9"`B
M(@HB0VAO;W-E(&$@9&5F875L="!D:7)E8W1O<GD@9F]R('EO=7(@<&5R<V]N
M86P@861D<F5S<V)O;VLL(&-O;G1A8W0@;&ES=',L(&%N9"`B"B)S96%R8VAE
M<RXB"FUS9W-T<B`B(@HB17-C;VQH82!U;6$@<&%S=&$@<&]R(&]M:7-SXV\@
M<&%R82!O<R!S975S(&QI=G)O(&1E(&5N9&5R9>=O<R!P97-S;V%L+"!A<R`B
M"B)S=6%S(&QI<W1A<R!D92!C;VYT86-T;W,@92!A<R!S=6%S('!R;V-U<F%S
M+B(*"B,Z(&%D9"YP:'`Z-#0*;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B17-C;VQH82!O(&QI=G)O(&1E(&5N9&5R9>=O<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R.`IM<V=I9"`B
M0VAO;W-E('1H92!O<F1E<B!O9B!T:&4@8V]L=6UN<R!T;R!D:7-P;&%Y(&EN
M('1H92!A9&1R97-S(&QI<W0N(@IM<V=S='(@(D5S8V]L:&$@82!O<F1E;2!D
M87,@8V]L=6YA<R!A(&UO<W1R87(@;F$@;&ES=&$@9&4@8V]N=&%C=&]S+B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#@*;7-G:60@(D-L
M96%R(%-E87)C:"(*;7-G<W1R("),:6UP87(@4&5S<75I<V$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`*;7-G:60@(D-O;'5M;B!/<'1I;VYS(@IM
M<V=S='(@(D]PY_5E<R!D92!#;VQU;F$B"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C$X('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,38*;7-G
M:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B5F%L;W)E<R!S
M97!A<F%D;W,@<&]R(';M<F=U;&%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP
M;W)T+FEN8SHQ-PIM<V=I9"`B0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC
M<F]S;V9T($]U=&QO;VLI(@IM<V=S='(@(E9A;&]R97,@<V5P87)A9&]S('!O
M<B!V[7)G=6QA<R`H36EC<F]S;V9T($]U=&QO;VLI(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B
M16UP<F5S82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`IM
M<V=I9"`B0V]M<&%N>2!!9&1R97-S(@IM<V=S='(@(DUO<F%D82!N82!%;7!R
M97-A(@H*(SH@;&EB+V%P:2YP:'`Z,C0W(&QI8B]A<&DN<&AP.C(V."!L:6(O
M87!I+G!H<#HS.#0@;&EB+V%P:2YP:'`Z-#4T"B,Z(&QI8B]A<&DN<&AP.C4T
M-"!L:6(O87!I+G!H<#HU.3`@;&EB+V%P:2YP:'`Z-C,X(&QI8B]A<&DN<&AP
M.C@R-0HC.B!L:6(O87!I+G!H<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DQI9V'GXV\@9F%L:&]U
M.B`E<R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z-C8*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;'5R92(*;7-G<W1R(")&86QH82!D92!L:6=AY^-O(@H*(SH@
M8G)O=W-E+G!H<#HV,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@;&ES
M="XB"FUS9W-T<B`B0V]N=&%C=&\@<F5M;W9I9&\@9&$@;&ES=&$N(@H*(SH@
M8G)O=W-E+G!H<#HR-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&%C=',@
M:6X@;&ES=#H@)7,B"FUS9W-T<B`B0V]N=&%C=&]S(&YA(&QI<W1A.B`E<R(*
M"B,Z(&)R;W=S92YP:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E
M;G1S(&]F("5S(@IM<V=S='(@(D-O;G1E^F1O(&1E("5S(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B0V]P>2(*;7-G<W1R
M(")#;W!I87(B"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,T"FUS9VED(")#
M<F5A=&5D(@IM<V=S='(@(D-R:6%D;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-@IM<V=I9"`B1&5F875L="!$:7-P;&%Y(@IM<V=S='(@(E9I<W5A
M;&EZ8>?C;R!P;W(@3VUI<W/C;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C$*;7-G:60@(B(*(D1E9F%U;'0@9&ER96-T;W)Y(&9O<B!Y;W5R('!E
M<G-O;F%L(&%D9')E<W-B;V]K+"!C;VYT86-T(&QI<W1S+"!A;F0@<V5A<F-H
M97,N(@IM<V=S='(@(B(*(E!A<W1A('!O<B!O;6ES<^-O('!A<F$@;R!S974@
M;&EV<F\@9&4@96YD97)EYV]S('!E<W-O86PL(&%S('-U87,@;&ES=&%S(&1E
M("(*(F-O;G1A8W1O<R!E(&%S('-U87,@<')O8W5R87,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<R"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER
M96-T:6]N.B(*;7-G<W1R(")$:7)E8^?C;R!D92!O<F1E;F'GXV\@<&]R(&]M
M:7-SXV\Z(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS(&QI
M8B]296YD97)E<BYP:'`Z-#@*;7-G:60@(D1E;&5T92(*;7-G<W1R(")296UO
M=F5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U"FUS9VED(")$96QE
M=&4@0V]N9FER;6%T:6]N(@IM<V=S='(@(D-O;F9I<FUAY^-O(&1E(%)E;6_G
MXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8*;7-G:60@(D1E;&5T
M92!B=71T;VX@8F5H879I;W5R(@IM<V=S='(@(D-O;7!O<G1A;65N=&\@9&\@
M8G5TXV\@7")D96QE=&5<(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!F86EL960Z("@E<RD@)7,B
M"FUS9W-T<B`B4F5M;^?C;R!F86QH;W4Z("@E<RD@)7,B"@HC.B!D96QE=&4N
M<&AP.C,R"FUS9VED(")$96QE=&EO;B!F86EL960B"FUS9W-T<B`B4F5M;^?C
M;R!F86QH;W4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3,*
M;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B1&5P87)T86UE;G1O(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q"FUS9VED(")$97-C96YD:6YG(@IM
M<V=S='(@(D1E8W)E<V-E;G1E(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R
M8V@N:6YC.C$S,@IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=/-R
M:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM
M<V=S='(@(D]PY_5E<R!D92!6:7-U86QI>F'GXV\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30Y"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF:7)M
M(&1E;&5T:6YG(&5N=')I97,_(@IM<V=S='(@(D1E<V5J82!C;VYF:7)M87(@
M82!R96UOY^-O(&1E(&5N=')A9&%S/R(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M8V]N=&%C=')O=RYI;F,Z,C4*;7-G:60@(D1O=VYL;V%D('9#87)D(@IM<V=S
M='(@(D1E<V-A<G)E9V%R('9#87)D(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C
M;VQU;6Y?:&5A9&5R<RYI;F,Z-B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C,S"B,Z(&QI8B]296YD97)E<BYP:'`Z-#8*;7-G:60@(D5D:70B
M"FUS9W-T<B`B161I=&%R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T
M<F]W+FEN8SHS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*
M;7-G<W1R(")%9&ET87(@7"(E<UPB(@H*(SH@961I="YP:'`Z-3,@961I="YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!E;G1R>2!F;W(@)7,B
M"FUS9W-T<B`B161I=&%R(&5N=')A9&$@9&4@)7,B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B0V]R
M<F5I;R!%;&5C='+S;FEC;R(*"B,Z(&5D:70N<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+B(*;7-G<W1R(")%;G1R
M861A(&1E("5S(&%C='5A;&EZ861A+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z-B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C0V"FUS
M9VED(")%>'!O<G0B"FUS9W-T<B`B17AP;W)T87(B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C<*;7-G:60@(D5X<&]R="!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B17AP;W)T87(@3&EV<F\@9&4@16YD97)EYV]S(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-@IM<V=I9"`B17AP;W)T(&]N;'D@
M=&AE('-E;&5C=&5D(&-O;G1A8W1S+B(*;7-G<W1R(")%>'!O<G1A<B!A<&5N
M87,@;W,@8V]N=&%C=&]S('-E;&5C8VEO;F%D;W,B"@HC.B!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C,R"FUS9VED(")%>'!O<G0@=&AE(&9O;&QO=VEN
M9R!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2XB"FUS9W-T<B`B17AP;W)T87(@
M;F$@[6YT96=R87(@;R!L:79R;R!D92!E;F1E<F7G;W,@<75E('-E('-E9W5E
M+B(*"B,Z(&1A=&$N<&AP.C$Q,"!D871A+G!H<#HR,C@@8G)O=W-E+G!H<#HS
M-R!B<F]W<V4N<&AP.CDT(&)R;W=S92YP:'`Z,3`Y"B,Z(&%D9"YP:'`Z-C,@
M<V5A<F-H+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D9A;&AO=2!A
M8V5S<V\@86\@;&EV<F\@9&4@96YD97)EYV]S.B`E<R(*"B,Z(&)R;W=S92YP
M:'`Z,3(X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@)7,@
M=&\@)7,Z("5S(@IM<V=S='(@(D9A;&AO=2!A9&GGXV\@9&4@)7,@82`E<SH@
M)7,B"@HC.B!B<F]W<V4N<&AP.C(V,PIM<V=I9"`B1F%I;&5D('1O(&)R;W=S
M92!L:7-T(@IM<V=S='(@(D9A;&AO=2!N879E9V'GXV\@9&$@;&ES=&$B"@HC
M.B!B<F]W<V4N<&AP.C(Y-PIM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@
M9&ER96-T;W)Y(@IM<V=S='(@(D9A;&AO=2!N879E9V'GXV\@9&\@9&ER96-T
M\W)I;R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD
M($1.(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T(#T@)7,B"FUS9W-T<B`B1F%L
M:&]U(&$@;75D86[G82!D;R!N;VUE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@
M3F5W($1.(#T@)7,L(%)O;W0@/2`E<R(*"B,Z(&)R;W=S92YP:'`Z,3$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B
M92!A9&1E9#H@)7,B"FUS9W-T<B`B4')O8W5R82!D;R!O8FIE8W1O(&$@861I
M8VEO;F%R(&9A;&AO=3H@)7,B"@HC.B!D871A+G!H<#HQ,C0@<V5A<F-H+G!H
M<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H
M92!D:7)E8W1O<GDZ("5S(@IM<V=S='(@(E!E<W%U:7-A(&YO(&1I<F5C=/-R
M:6\@9F%L:&]U.B`E<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$V-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<V5A<F-H+FEN8SHW,@IM<V=I9"`B1FEN9"(*;7-G<W1R(")0<F]C
M=7)A<B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0X"FUS9VED
M(")&:7)S="!.86UE(@IM<V=S='(@(DYO;64@4'+S<')I;R(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P,@IM<V=I9"`B1G)E96)U<WD@55),
M(@IM<V=S='(@(E523"!D92!L:79R92]O8W5P861O(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]S96%R8V@N:6YC.C@U"FUS9VED(")&<F]M(@IM<V=S='(@(D1E
M(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-38R"FUS9VED(")';&]B
M86P@061D<F5S<R!";V]K(@IM<V=S='(@(DQI<W1A(&1E($5N9&5R9>=O<R!'
M;&]B86PB"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C0T
M"FUS9VED(")'<F]U<"(*;7-G<W1R(")'<G5P;R(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C@R"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T
M<B`B36]R861A(&1E($-A<V$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HY,PIM<V=I9"`B2&]M92!#:71Y(@IM<V=S='(@(D-I9&%D92!D92!#
M87-A(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`X"FUS9VED
M(")(;VUE($-O=6YT<GDB"FUS9W-T<B`B4&'M<R!D92!#87-A(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34P"FUS9VED(")(;VUE(%!H;VYE
M(@IM<V=S='(@(E1E;&5F;VYE:2!D92!#87-A(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3`S"FUS9VED(")(;VUE(%!O<W1A;"!#;V1E(@IM
M<V=S='(@(D/S9&EG;R!0;W-T86P@9&4@0V%S82(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.CDX"FUS9VED(")(;VUE(%-T871E+U!R;W9I;F-E
M(@IM<V=S='(@(D5S=&%D;R]0<F]V[6YC:6$@9&4@0V%S82(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"FUS9VED(")(;VUE(%-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(E)U82!D92!#87-A(@H*(SH@8V]N9FEG+W-O=7)C
M97,N<&AP+F1I<W0Z-#@W"FUS9VED("))35-0(@IM<V=S='(@(DE-4U`B"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T($%D9')E<W,@0F]O:RP@4W1E<"`E9"(*;7-G<W1R("))
M;7!O<G1A<B!,:7-T82!D92!%;F1E<F7G;W,L(%!A<W-O("5D(@H*(SH@9&%T
M82YP:'`Z,C<T"FUS9VED("));7!O<G0O17AP;W)T($%D9')E<W,@0F]O:W,B
M"FUS9W-T<B`B26UP;W)T87(O17AP;W)T87(@3&ES=&%S(&1E($5N9&5R9>=O
M<R(*"B,Z(&QI8B]A<&DN<&AP.C,W."!L:6(O87!I+G!H<#HV,#0*;7-G:60@
M(DEN=F%L:60@0V]N=&5N="U4>7!E(@IM<V=S='(@(EPB0V]N=&5N="U4>7!E
M7"(@26YVX6QI9&\N(@H*(SH@;&EB+V%P:2YP:'`Z-#0Q(&QI8B]A<&DN<&AP
M.C4S,0IM<V=I9"`B26YV86QI9"!)1"(*;7-G<W1R("))1"!);G;A;&ED;RXB
M"@HC.B!L:6(O87!I+G!H<#HQ.3$@;&EB+V%P:2YP:'`Z,S,T(&QI8B]A<&DN
M<&AP.C0S-R!L:6(O87!I+G!H<#HU,C<*(SH@;&EB+V%P:2YP:'`Z-3@P(&QI
M8B]A<&DN<&AP.C@Y-0IM<V=I9"`B26YV86QI9"!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B3&EV<F\@9&4@96YD97)EYV]S(&EN=N%L:61O+B(*"B,Z(&QI8B]A
M<&DN<&AP.C@Y.2!L:6(O87!I+G!H<#HY-S,@;&EB+V%P:2YP:'`Z,3`R-@IM
M<V=I9"`B26YV86QI9"!E;6%I;"(*;7-G<W1R(")%;F1E<F7G;R!D92!C;W)R
M96EO(&5L96-T<O-N:6-O(&EN=N%L:61O+B(*"B,Z(&QI8B]A<&DN<&AP.CDP
M-PIM<V=I9"`B26YV86QI9"!E;G1R>2(*;7-G<W1R(")%;G1R861A($EN=N%L
M:61A+B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C<Y"FUS9VED("));G9A
M;&ED(&ME>2!S<&5C:69I960N(@IM<V=S='(@(D-H879E(&EN=N%L:61A(&5S
M<&5C:69I8V%D82XB"@HC.B!L:6(O87!I+G!H<#HY,#,*;7-G:60@(DEN=F%L
M:60@;F%M92(*;7-G<W1R(").;VUE($EN=N%L:61O+B(*"B,Z(&QI8B]A<&DN
M<&AP.C4X-`IM<V=I9"`B26YV86QI9"!O8FIE8W1)9"(*;7-G<W1R(")O8FIE
M8W1)1"!);G;A;&ED;RXB"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,X"FUS
M9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0
M(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(@IM<V=S
M='(@(B(*(E-U<&]R=&4@3$1!4"#I(&YE8V5S<^%R:6\@;6%S(&\@;?-D=6QO
M($Q$05`@;N-O(&5S=.$@9&ES<&]N[79E;"!O=2!NXV\@97-TX2`B"B)C87)R
M96=A9&\N(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S.0IM<V=I9"`B3&%S
M="!-;V1I9FEE9"(*;7-G<W1R(")-;V1I9FEC861O(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z-3,*;7-G:60@(DQA<W0@3F%M92(*;7-G<W1R
M("+:;'1I;6\@3F]M92(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C@*;7-G:60@(DQI<W0B"FUS9W-T<B`B3&ES=&$B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-SD*;7-G:60@(DUA=&-H:6YG
M(@IM<V=S='(@(D-O<G)E<W!O;F1E;G1E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Q"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!P86=E<R(*;7-G
M<W1R(").^FUE<F\@;>%X:6UO(&1E('#A9VEN87,B"@HC.B!L:6(O0FQO8VLO
M;6EN:7-E87)C:"YP:'`Z,PIM<V=I9"`B36EN:2!396%R8V@B"FUS9W-T<B`B
M36EN:2UP<F]C=7)A(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,34*;7-G
M:60@(DUI<W-I;F<@1$X@:6X@3$1!4"!S;W5R8V4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B1F%L=&$@1$X@;F$@8V]N9FEG=7)AY^-O(&1O($Q$05`@9F]N
M=&4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@
M(DUO8FEL92!0:&]N92(*;7-G<W1R(")496QE;?-V96PB"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C,T-"!L:6(O1')I=F5R+VQD87`N<&AP.C,V,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S
M='(@(DUO9&EF:6-AY^-O(&9A;&AO=3H@*"5S*2`E<R(*"B,Z(&QI8B]A<&DN
M<&AP.C$P,3(*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S
M='(@(D5N8V]N=')A9&$@;6%I<R!Q=64@=6UA(&5N=')A9&$N(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B36]V92(*;7-G
M<W1R(")-;W9E<B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(T-PIM<V=I9"`B36]V92!L969T(@IM<V=S='(@(DUO=F5R(.`@97-Q
M=65R9&$B"@HC.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR
M-#D*;7-G:60@(DUO=F4@<FEG:'0B"FUS9W-T<B`B36]V97(@X"!D:7)E:71A
M(@H*(SH@9&%T82YP:'`Z,S$@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR
M,0IM<V=I9"`B375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(DQI=G)O
M(&1E($5N9&5R9>=O<R!-=6QB97)R>2(*"B,Z(&QI8B]A<&DN<&AP.CDS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I=&@@
M861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y
M(&5X:7-T(@IM<V=S='(@(DCA(';A<FEA<R!P97-S;V%S(&-O;2!O(&5N9&5R
M9>=O(%LE<UTL(&UA<R!N96YH=6UA(&-O;2!O(&YO;64@6R5S72(*"B,Z(&-O
M;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C@W(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C(R,0IM<V=I9"`B37D@061D<F5S<R!";V]K(@IM<V=S='(@(D\@365U
M($QI=G)O(&1E($5N9&5R9>=O<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C0R"FUS9VED(").86UE(@IM<V=S='(@(DYO;64B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C(*;7-G:60@(DYA;64@1F]R;6%T(@IM<V=S
M='(@(D9O<FUA=&\@9&\@3F]M92(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C(Y-0IM<V=I9"`B3F5T8V5N=&5R($UE;6)E<B!$:7)E8W1O<GDB"FUS
M9W-T<B`B1&ER96-T\W)I;R!D92!-96UB<F]S(&1O($YE=&-E;G1E<B(*"B,Z
M(&%D9"YP:'`Z,S8@861D+G!H<#HQ,#(@;&EB+T)L;V-K+VUI;FES96%R8V@N
M<&AP.C(W"FUS9VED(").97<@0V]N=&%C="(*;7-G<W1R(").;W9O($-O;G1A
M8W1O(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR-@IM<V=I
M9"`B3F5W($QI<W0B"FUS9W-T<B`B3F]V82!,:7-T82(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z-#(*;7-G:60@(DYE>'0B"FUS9W-T<B`B4'+S
M>&EM82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q.`IM<V=I
M9"`B3FEC:VYA;64B"FUS9W-T<B`B06QC=6YH82(*"B,Z(&QI8B]A<&DN<&AP
M.C$P,30@;&EB+V%P:2YP:'`Z,3`V,PHC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R`E<R!E;G1R>2!F;W5N9"!F;W(@)7,B"FUS9W-T<B`B3N-O('-E(&5N8V]N
M=')O=2!E;G1R861A("5S('!A<F$@)7,B"@HC.B!L:6(O87!I+G!H<#HY.#(*
M;7-G:60@(DYO(&%D9')E<W,@8F]O:W,@9F]U;F0N(@IM<V=S='(@(D[C;R!S
M92!E;F-O;G1R;W4@;&EV<F]S(&1E(&5N9&5R9>=O<RXB"@HC.B!M:6YI<V5A
M<F-H+G!H<#HX-PIM<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B"FUS9W-T<B`B
M3N-O('-E(&5N8V]N=')O=2!C;VYT86-T;W,B"@HC.B!L:6(O87!I+G!H<#HS
M-38*;7-G:60@(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R(").
MXV\@<V4@96YC;VYT<F]U(&1A9&]S('9#87)D+B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O9F]O=&5R+FEN8SHW"FUS9VED(").;VYE(@IM<V=S='(@(DYE;FAU
M;6$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(DYO=&5S(@IM<V=S='(@(DYO=&%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T
M<B`B3OIM97)O(&1E(&ET96YS('!O<B!PX6=I;F$B"@HC.B!L:6(O87!I+G!H
M<#HT-C`*;7-G:60@(D]B:F5C="!N;W0@9F]U;F0B"FUS9W-T<B`B3V)J96-T
M;R!NXV\@96YC;VYT<F%D;RXB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HR,C,*;7-G:60@(D]F9FEC92(*;7-G<W1R(")%<V-R:73S<FEO(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T"FUS9VED(")/=&AE<B!/<'1I
M;VYS(@IM<V=S='(@(D]U=')A<R!/<.?U97,B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(D-H879E(%#Z8FQI8V$@4$=0(@H*(SH@;&EB+V%P:2YP:'`Z,S0P(&QI
M8B]A<&DN<&AP.C0T-R!L:6(O87!I+G!H<#HU,S<@;&EB+V%P:2YP:'`Z-3DV
M"B,Z(&QI8B]A<&DN<&AP.C<U,R!L:6(O87!I+G!H<#HY,3,*;7-G:60@(E!E
M<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<FUI<W/C;R!.96=A9&$B"@HC
M.B!L:6(O1')I=F5R+G!H<#HT,S8*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D
M(@IM<V=S='(@(E!E<FUI<W/C;R!.96=A9&$B"@HC.B!D871A+G!H<#HS,B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C(R"FUS9VED(")0:6YE($%D9')E
M<W,@0F]O:R(*;7-G<W1R("),:79R;R!D92!%;F1E<F7G;W,@4&EN92(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,S`*;7-G:60@(E!L
M96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&QI<W0Z(@IM<V=S='(@
M(E!O<B!F879O<B!I;G1R;V1U>F$@;R!N;VUE(&1A(&YO=F$@<&%S=&$Z(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C(Q"FUS9VED
M(")0;&5A<V4@<V5L96-T(&$@9&ER96-T;W)Y.B(*;7-G<W1R(")0;W(@9F%V
M;W(@97-C;VQH82!U;2!D:7)E8W3S<FEO.B(*"B,Z(&-O;F9I9R]S;W5R8V5S
M+G!H<"YD:7-T.C,Y.0IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B3&EV<F\@9&4@16YD97)EYV]S(%!R:79A9&\B"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C$U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")1=65R>2!F
M86EL960Z("@E<RD@)7,B"FUS9W-T<B`B02!I;G1E<G)O9V'GXV\@9F%L:&]U
M.B`H)7,I("5S(@H*(SH@=&5M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC
M.C$X"FUS9VED(")1=6EC:R!396%R8V@B"FUS9W-T<B`B4')O8W5R82!2X7!I
M9&$B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C$Y.2!L:6(O1')I=F5R+VQD
M87`N<&AP.C(P-R!L:6(O1')I=F5R+VQD87`N<&AP.C0T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")296%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")!(&QE
M:71U<F$@9F%L:&]U.B`H)7,I("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F
M;V]T97(N:6YC.C(*;7-G:60@(E)E8V]R9',@9&ES<&QA>65D.B(*;7-G<W1R
M(")296=I<W1O<R!M;W-T<F%D;W,Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O
M;'5M;G-E;&5C="YI;F,Z,C,Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S
M='(@(E)E;6]V97(@8V]L=6YA(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHS"FUS9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T
M<B`B4F5M;W9E<B!D97-T82!L:7-T82(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,C8*;7-G:60@(B(*(E)E<&QA8V4@97AI<W1I;F<@861D<F5S
M<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/&(^5V%R;FEN9SH@5&AI
M<R`B"B)D96QE=&5S(&%L;"!E;G1R:65S(&EN('EO=7(@8W5R<F5N="!A9&1R
M97-S(&)O;VLN/"]B/B(*;7-G<W1R("(B"B)3=6)S=&ET=6ER(&QI=G)O(&1E
M(&5N9&5R9>=O<R!E>&ES=&5N=&4@<&5L;R!I;7!O<G1A9&\_(#QB/D%V:7-O
M.B!)<W-O("(*(G)E;6]V97+A('1O9&%S(&%S(&5N=')A9&%S(&YO('-E=2!L
M:79R;R!D92!E;F1E<F7G;W,@8V]R<F5N=&4N/"]B/B(*"B,Z(&QI8B]$<FEV
M97(N<&AP.C,S,`IM<V=I9"`B4F5Q=65S=&5D(&]B:F5C="!N;W0@9F]U;F0N
M(@IM<V=S='(@(D]B:F5C=&\@<&5D:61O(&[C;R!E;F-O;G1R861O+B(*"B,Z
M(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$R-@IM
M<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`B5F]L=&%R(&$@5F%L
M;W)E<R!P;W(@3VUI<W/C;R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T:69I8V%T92(*;7-G
M<W1R(")#97)T:69I8V%D;R!0^F)L:6-O(%,O34E-12(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@
M9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(E-405)43%,@9F%L:&]U.B`H)7,I
M("5S(@H*(SH@961I="YP:'`Z-3<@861D+G!H<#HS-PIM<V=I9"`B4V%V92(*
M;7-G<W1R(")'=6%R9&%R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.CDX('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,C4*(SH@=&5M
M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(S(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#`*;7-G:60@(E-E87)C:"(*;7-G<W1R(")0<F]C=7)A<B(*
M"B,Z(&)R;W=S92YP:'`Z,C0Q(&UI;FES96%R8V@N<&AP.C8V"FUS9VED(")3
M96%R8V@@4F5S=6QT<R(*;7-G<W1R(")297-U;'1A9&]S(&1A(%!R;V-U<F$B
M"@HC.B!L:6(O87!I+G!H<#HX,CD*;7-G:60@(E-E87)C:"!F86EL960B"FUS
M9W-T<B`B4')O8W5R82!F86QH;W4B"@HC.B!L:6(O87!I+G!H<#HY,C(@;&EB
M+V%P:2YP:'`Z.3(X(&QI8B]A<&DN<&AP.CDS-R!L:6(O87!I+G!H<#HY-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B4')O8W5R82!F86QH;W4Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(X"FUS9VED(")396%R8VAI;F<@3W!T:6]N<R(*;7-G<W1R(")/<.?U
M97,@9&4@4')O8W5R82(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H
M+FEN8SHR-`IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S='(@(E!R;V-U<F%N
M9&\N+BXB"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E;&5C="YI;F,Z.0IM<V=I
M9"`B4V5L96-T($%D9')E<W,@0F]O:R(*;7-G<W1R(")396QE8V-I;VYA<B!,
M:79R;R!D92!%;F1E<F7G;W,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C(T"FUS9VED(")396QE8W0@3&ES="(*;7-G<W1R(")396QE8V-I
M;VYA<B!,:7-T82(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S<*
M;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M
M.B(*;7-G<W1R(")396QE8V-I;VYE(&\@;&EV<F\@9&4@96YD97)EYV]S(&1O
M('%U86P@97AP;W)T87(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHS,0IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T
M('1O.B(*;7-G<W1R(")396QE8V-I;VYE(&\@;&EV<F\@9&4@96YD97)EYV]S
M('!A<F$@;R!Q=6%L(&EM<&]R=&%R.B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,30*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA=#HB
M"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O<FUA=&\@9&4@97AP;W)T8>?C;SHB
M"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C0P"FUS9VED(")396QE
M8W0@=&AE(&9I;&4@=&\@:6UP;W)T.B(*;7-G<W1R(")396QE8V-I;VYE(&\@
M9FEC:&5I<F\@82!I;7!O<G1A<CHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O
M<G0N:6YC.C$V"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@<V]U
M<F-E(&9I;&4Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!F;W)M871O(&1O(&9I
M8VAE:7)O(&9O;G1E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*
M;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE
M<SHB"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O<FUA=&\@=7-A9&\@<&%R82!M
M;W-T<F%R(&YO;65S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-PIM
M<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+B(*;7-G
M<W1R(")%<V-O;&AE<B!A('9I>G5A;&EZ8>?C;R!A(&UO<W1R87(@<&]R(&]M
M:7-SXV\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED(")3
M96QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@
M;&ES=',N(@IM<V=S='(@(D5S8V]L:&5R(&]S(&-A;7!O<R!V:7/M=F5I<R!N
M87,@;&ES=&%S(&1E(&-O;G1A8W1O<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,*;7-G:60@(E-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES<&QA
M>2!N86UE<RXB"FUS9W-T<B`B17-C;VQH97(@8V]M('%U92!F;W)M871O(&UO
M<W1R87(@;W,@;F]M97,N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E
M;&5C="YI;F,Z,C0S"FUS9VED(")396QE8W1E9"!#;VQU;6YS.B(*;7-G<W1R
M(")#;VQU;F%S(%-E;&5C8VEO;F%D87,Z(@H*(SH@861D+G!H<#HU,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")396QE8W1E9"!A9&1R97-S(&)O;VL@7"(E<UPB
M+B(*;7-G<W1R(")396QE8V-I;VYA9&\@;R!L:79R;R!D92!E;F1E<F7G;W,@
M7"(E<UPB+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$U-`IM<V=I
M9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E8W3S<FEO(%!A<G1I
M;&AA9&\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0R"FUS
M9VED(")3:&]?=R!!;&PB"FUS9W-T<B`B36]S=')A<B!47W5D;R(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O<V5L96-T+FEN8SHQ,0IM<V=I9"`B4VAO=R(*;7-G
M<W1R(")-;W-T<F%R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHT,@IM<V=I9"`B4VAO=R!!;&PB"FUS9W-T<B`B36]S=')A<B!4=61O(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B4VAO
M=R!#;VYT86-T<R(*;7-G<W1R(")-;W-T<F%R($-O;G1A8W1O<R(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@(E-H;W<@3&ES
M=',B"FUS9W-T<B`B36]S=')A<B!,:7-T87,B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C0Q"FUS9VED(")3:&]W(%]#;VYT86-T<R(*;7-G
M<W1R(")-;W-T<F%R(%]#;VYT86-T;W,B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C0P"FUS9VED(")3:&]W(%],:7-T<R(*;7-G<W1R(")-
M;W-T<F%R(%],:7-T87,B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H
M96%D97)S+FEN8SHQ,`HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D
M97)S+FEN8SHQ-0IM<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS9W-T<B`B1&ER
M96/GXV\@9&4@3W)D96YAY^-O(@H*(SH@;&EB+V%P:2YP:'`Z,34T"FUS9VED
M(")3;W5R8V5S(@IM<V=S='(@(D9O;G1E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S`*;7-G:60@(E-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V
M86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R+B(*;7-G<W1R(")%<W!E
M8VEF:7%U92!O;F1E('!R971E;F1E('%U92!A<&%R9>=A;2!O<R!R97-U;'1A
M9&]S(&1A('!R;V-U<F$N(@H*(SH@8G)O=W-E+G!H<#HQ,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("5S('1O("5S(@IM<V=S
M='(@(D%D:6-AY^-O(&1E("5S(&$@)7,@=&5V92!S=6-E<W-O(@H*(SH@9&%T
M82YP:'`Z,CD*;7-G:60@(E135B(*;7-G<W1R(")44U8B"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$Y('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,3@*;7-G:60@(E1A8B!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(E9A
M;&]R97,@<V5P87)A9&]S('!O<B!T86)U;&'G]65S(@H*(SH@9&%T82YP:'`Z
M,C,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U
M;&0@;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B3R!L:79R;R!D92!E;F1E
M<F7G;W,@;N-O('#T9&4@<V5R('!U<F=A9&\Z("5S(@H*(SH@961I="YP:'`Z
M,C0@=F-A<F0N<&AP.C(R(&1I<W!L87DN<&AP.C(S"FUS9VED(")4:&4@8V]N
M=&%C="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")/
M(&-O;G1A8W1O('!E9&ED;R!NXV\@97AI<W1E+B(*"B,Z(&)R;W=S92YP:'`Z
M,S,*;7-G:60@(E1H97)E(&%R92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O
M:W,N(@IM<V=S='(@(D[C;R!HX2!L:79R;W,@9&4@96YD97)EYV]S(&YA=F5G
MX79E:7,N(@H*(SH@861D+G!H<#HR.0IM<V=I9"`B(@HB5&AE<F4@87)E(&YO
M('=R:71E86)L92!A9&1R97-S(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B
M;&4@861D<F5S<R!B;V]K<R`B"B)A<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y
M;W4@=&\@861D(&YE=R!E;G1R:65S('1O('1H96TN($EF('EO=2!B96QI979E
M('1H:7,@(@HB:7,@86X@97)R;W(L('!L96%S92!C;VYT86-T('EO=7(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D[C;R!HX2!L:79R;W,@
M9&4@96YD97)EYV]S(&%L=&5RX79E:7,N($YE;FAU;2!D;W,@;&EV<F]S(&1E
M(&5N9&5R9>=O<R`B"B)D:7-P;V[M=F5I<R!E<W3A(&-O;F9I9W5R861O('!A
M<F$@<&5R;6ET:7(@82!A9&GGXV\@9&4@;F]V87,@96YT<F%D87,N(%-E("(*
M(F%C:&%R('%U92!I<W1O(.D@=6T@97)R;RP@<&]R(&9A=F]R(&-O;G1A8W1E
M(&\@861M:6YI<W1R861O<B!D;R!S:7-T96UA+B(*"B,Z(&%D9"YP:'`Z.3D*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE=R!C
M;VYT86-T+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@(@HB
M9F]R(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!E<G)O
M(&%O(&%D:6-I;VYA<B!E<W1E(&-O;G1A8W1O+B!#;VYT86-T92!O('-E=2!A
M9&UI;FES=')A9&]R(&1E("(*(G-I<W1E;6$@<&%R82!O8G1E<B!A:G5D82XB
M"@HC.B!B<F]W<V4N<&AP.C$X-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&-R96%T:6YG(&$@;F5W(&QI<W0N(@IM<V=S='(@(D]C;W)R974@=6T@97)R
M;R!A;R!C<FEA<B!U;6$@;F]V82!L:7-T82XB"@HC.B!B<F]W<V4N<&AP.C$S
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@)7,@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B3V-O<G)E=2!U;2!E<G)O(')E;6]V96YD;R`E<R!D;R!L:79R;R!D92!E
M;F1E<F7G;W,@9&4@;W)I9V5M+B(*"B,Z(&1E;&5T92YP:'`Z,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H
M:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O(')E
M;6]V97(@97-T92!C;VYT86-T;SH@)7,B"@HC.B!B<F]W<V4N<&AP.C8X"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!O8FIE8W0N
M(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!R96UO=F5N9&\@97-T92!O8FIE
M8W1O+B(*"B,Z(&)R;W=S92YP:'`Z,C<S"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&4@<V5L96-T($QI<W0B"FUS9W-T<B`B3V-O
M<G)E=2!U;2!E<G)O(&%O(&UO<W1R87(@82!,:7-T82!S96QE8V-I;VYA9&$N
M(@H*(SH@9&%T82YP:'`Z,C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@
M(D]C;W)R974@=6T@97)R;R!N82!I;7!O<G1AY^-O(&1E(&1A9&]S.B`E<R(*
M"B,Z(&QI8B]A<&DN<&AP.C,U,@IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D]C;W)R
M974@=6T@97)R;R!N82!I;7!O<G1AY^-O(&1E(&1A9&]S(&E#86QE;F1A<BXB
M"@HC.B!B<F]W<V4N<&AP.C4X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M<F5M;W9I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(D]C;W)R974@=6T@97)R
M;R!N82!R96UOY^-O(&1E<W1E(&]B:F5C=&\N(@H*(SH@961I="YP:'`Z.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H:7,@96YT<GDZ("5S(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!A
M;R!A8W1U86QI>F%R(&5S=&$@96YT<F%D83H@)7,B"@HC.B!D871A+G!H<#HQ
M-3$*;7-G:60@(E1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="XB
M"FUS9W-T<B`B3N-O(&AA=FEA(&5N9&5R9>=O<R!A(&5X<&]R=&%R+B(*"B,Z
M(&QI8B]$<FEV97(N<&AP.C,Y,"!L:6(O1')I=F5R+G!H<#HT,C<*;7-G:60@
M(E1H:7,@861D<F5S<R!B;V]K(&ES(')E860M;VYL>2(*;7-G<W1R(")/(&QI
M=G)O(&1E(&5N9&5R9>=O<R!S\R!P97)M:71E(&QE:71U<F$B"@HC.B!D871A
M+G!H<#HR,3$*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U<'!O
M<G1E9"XB"FUS9W-T<B`B17-T92!F;W)M871O(&1E(&9I8VAE:7)O(&[C;R#I
M('-U<&]R=&%D;RXB"@HC.B!L:6(O87!I+G!H<#HY-#$@;&EB+V%P:2YP:'`Z
M.34T"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@
M:&%S(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")%
M<W1A('!E<W-O82!JX2!T96T@=6UA(&5N=')A9&$@)7,@;F\@<V5U(&QI=G)O
M(&1E(&5N9&5R9>=O<RXB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HW,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("));7!O<W/M=F5L
M(&QE<B!A(&1E9FEN:>?C;R!D92`E<RXB"@HC.B!E9&ET+G!H<#HU-PIM<V=I
M9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(E9O;'1A<B!A='+A<R!N87,@86QT
M97)AY_5E<R(*"B,Z(&QI8B]A<&DN<&AP.C0X.0IM<V=I9"`B56YS=7!P;W)T
M960@0V]N=&5N="U4>7!E+B(*;7-G<W1R(")4:7!O(&1E(&-O;G1E^F1O("A#
M;VYT96YT+51Y<&4I(&[C;R#I('-U<&]R=&%D;RXB"@HC.B!C;VYF:6<O<V]U
M<F-E<RYP:'`N9&ES=#HS-3@*;7-G:60@(E9E<FES:6=N($1I<F5C=&]R>2(*
M;7-G<W1R(")$:7)E8W3S<FEO(%9E<FES:6=N(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]C;VYT86-T<F]W+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W(%PB)7-<(B(*;7-G<W1R(")697(@7"(E<UPB(@H*(SH@;6EN:7-E87)C
M:"YP:'`Z.#(*;7-G:60@(E9I97<@0V]N=&%C="(*;7-G<W1R(")697(@0V]N
M=&%C=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(E9I
M97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R(")6:7-U86QI>F'G
MXV\@82!M;W-T<F%R('!O<B!D969E:71O.B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C(P.`IM<V=I9"`B5V5B<VET92!54DPB"FUS9W-T<B`B
M55),(&1A('#A9VEN82!796(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ,3,*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")%;F1E<F7G
M;R!D;R!%;7!R96=O(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3(T"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B0VED861E(&1O($5M<')E
M9V\B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,SD*;7-G:60@
M(E=O<FL@0V]U;G1R>2(*;7-G<W1R(")08>US(&1O($5M<')E9V\B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O<FL@4&AO
M;F4B"FUS9W-T<B`B5&5L969O;F4@9&\@16UP<F5G;R(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$S-`IM<V=I9"`B5V]R:R!0;W-T86P@0V]D
M92(*;7-G<W1R(")#\V1I9V\@4&]S=&%L(&1O($5M<')E9V\B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*;7-G:60@(E=O<FL@4W1A=&4O
M4')O=FEN8V4B"FUS9W-T<B`B17-T861O+U!R;W;M;F-I82!D;R!%;7!R96=O
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$Y"FUS9VED(")7
M;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(E)U82!D;R!%;7!R96=O(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHS,`IM<V=I9"`B
M66]U(&%R92!C<F5A=&EN9R!A(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M(")%<W3A(&$@8W)I87(@=6UA(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RXB"@HC
M.B!E9&ET+G!H<#HT-"!D:7-P;&%Y+G!H<#HU.0IM<V=I9"`B66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S
M='(@(D[C;R!T96T@<&5R;6ES<^-O('!A<F$@=F5R(&5S=&4@8V]N=&%C=&\N
M(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R
M;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+B(*;7-G<W1R(").XV\@=&5M
M('!E<FUI<W/C;R!P87)A('9E<B!E<W1E(&]B:F5C=&\N(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHU,0IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B5&5M(&1E
M('-E;&5C8VEO;F%R('5M(&QI=G)O(&1E(&5N9&5R9>=O<R!A;'9O+B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C,*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(*;7-G<W1R(")496T@9&4@
M<V5L96-C:6]N87(@=6UA(&QI<W1A(&%L=F\N(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C0U"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI
M;F,Z-C@*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@96YT
M<GD@9FER<W0N(@IM<V=S='(@(E1E;2!D92!S96QE8V-I;VYA<B!P<FEM96ER
M;R!P96QO(&UE;F]S('5M82!E;G1R861A+B(*"B,Z(&5D:70N<&AP.C0X"FUS
M9VED(")9;W4@;VYL>2!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O
M;G1A8W0N(@IM<V=S='(@(E/S('1E;2!P97)M:7-SXV\@<&%R82!V97(@97-T
M92!C;VYT86-T;RXB"@HC.B!B<F]W<V4N<&AP.C(X-`IM<V=I9"`B66]U<B!D
M969A=6QT(&%D9')E<W-B;V]K(&ES(&YO="!B<F]W<V5A8FQE+B(*;7-G<W1R
M(")/('-E=2!L:79R;R!D92!E;F1E<F7G;W,@<&]R(&]M:7-SXV\@;N-O(.D@
M;F%V96?A=F5L+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI
M;F,Z,3(*;7-G:60@(EMN;R!V86QU95TB"FUS9W-T<B`B6W-E;2!V86QO<ETB
M"@HC.B!L:6(O5'5R8F$N<&AP.C(X-@IM<V=I9"`B7T%D9"(*;7-G<W1R(")?
M061I8VEO;F%R(@H*(SH@;&EB+U1U<F)A+G!H<#HR.#,*;7-G:60@(E]"<F]W
M<V4B"FUS9W-T<B`B7TYA=F5G87(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C,*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B7U)E;6]V97(B
M"@HC.B!L:6(O5'5R8F$N<&AP.C(Y,@IM<V=I9"`B7TEM<&]R="]%>'!O<G0B
M"FUS9W-T<B`B7TEM<&]R=&%R+T5X<&]R=&%R(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHS"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L
M:7-T(@IM<V=S='(@(E)E;6]V7V5R(&1E<W1A(&QI<W1A(@H*(SH@;&EB+U1U
M<F)A+G!H<#HR.#@*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B7U!R;V-U<F%R
M(@H*(SH@=F-A<F0N<&AP.C0V"FUS9VED(")C;VYT86-T+G9C9B(*;7-G<W1R
M(")C;VYT86-T;RYV8V8B"@HC.B!D871A+G!H<#HQ-S(@9&%T82YP:'`Z,3<W
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N
M8W-V(@IM<V=S='(@(F-O;G1A8W1O<RYC<W8B"@HC.B!D871A+G!H<#HQ.#(*
M;7-G:60@(F-O;G1A8W1S+G1S=B(*;7-G<W1R(")C;VYT86-T;W,N='-V(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ-`IM<V=I9"`B=&\@
M4V5L96-T960@061D<F5S<R!";V]K(@IM<V=S='(@(E-E;&5C8VEO;F%R($QI
M=G)O(&1E($5N9&5R9>=O<R(*"B,Z(&1A=&$N<&AP.C,P('1E;7!L871E<R]B
M<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHR,"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(P"FUS
M9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O='5R8F$O<&\O;F)?3D\N<&\`````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W,C,Q-0`Q,#0Q-S,V,C<U
M-@`P,3<U,C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(R!.;W)W96=I86X@5'5R8F$@5')A;G-L871I;VXN"B,@0V]P>7)I
M9VAT("A#*2`R,#`Q+3(P,#(@2&]R9&4@4')O:F5C="X*(R!/>7-T96EN(%-T
M96EM;&5R(#QO>7-T96EN0')E>'1A+FYE=#XL(#(P,#$N"B,@5&]R<W1E:6X@
M4RX@2&%N<V5N(#QH=6QE8F]E<D!T96-H8F5E+FYO/BP@,C`P,BX*(R!!;F1R
M96%S($=U;FQE:6MS:V%A<R`\86YD<F5A<T!G=6YL96EK<VMA87,N;F\^+"`R
M,#`S+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!4=7)B82`Q+C)<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`T+3`U+3$X
M(#(S.C,W*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@06YD<F5A<R!'=6YL
M96EK<VMA87,@/&%N9')E87-`9W5N;&5I:W-K86%S+FYO/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@3F]R=V5G:6%N("A";VMM86PI(#QI,3AN0&QI<W1S+FAO<F1E
M+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VEM<W!?;W!T+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B($%D9"!A;B!)35-0
M($%D9')E<W,@0F]O:R(*;7-G<W1R(")696QG(&%D<F5S<V5B;VLB"@HC.B!T
M96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C,Q"B,L(&9U>GIY"FUS9VED
M("(@1&5L971E($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(G1I;"!V86QG
M="!A9')E<W-E8F]K(@H*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I;7!O
M<G1E9"XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U<V4@:70@
M:7,@82!L:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C$R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!M;W9E9"!B96-A=7-E
M(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@3&%S=&YA;65<(B`@*&EE
M+B!*;VAN($1O92DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE7"(@*&EE+B!$
M;V4L($IO:&XI(@IM<V=S='(@(B(*"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H
M<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL92!S=6-C97-S9G5L
M;'D@:6UP;W)T960B"FUS9W-T<B`B26UP;W)T(&%V("5S(&9I;&5N('9A<B!V
M96QL>6MK970B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O5'5R8F$N<&AP.C0T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B5F5L9R!A9')E<W-E
M8F]K(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C0U"FUS9VED(")!
M(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E<75I<F5D(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3D*;7-G:60@
M(D%B;W9E('-E87)C:"!F;W)M(@IM<V=S='(@(B(*"B,Z('9I97<N<&AP.C4R
M"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@=&\@)7,B"FUS
M9W-T<B`B(@H*(SH@861D+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C(R"FUS9VED(")!9&0B"FUS9W-T<B`B3&5G9R!T:6PB"@HC.B!T
M96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-`HC+"!F
M=7IZ>0IM<V=I9"`B061D(&%D9')E<W,@8F]O:R(*;7-G<W1R(")59WEL9&EG
M(&%D<F5S<V5B;VLN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X"B,L
M(&9U>GIY"FUS9VED(")!9&0@86YD($1E;&5T92!)35-0(&%D9')E<W,@8F]O
M:W,B"FUS9W-T<B`B1&5T(&9I;FYE<R!I;F=E;B!S:W)I=F)A<F4@861R97-S
M96+X:V5R+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(S-PHC+"!F=7IZ>0IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("),96=G
M('1I;"!K;VQO;FYE(@H*(SH@961I="YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED
M(")!9&0@9FEL92(*;7-G<W1R(")+=6YN92!I:VME(&QE9V=E('1I;"(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D%D9"!T
M;R(*;7-G<W1R("),96=G('1I;"XN+B(*"B,Z('1E;7!L871E<R]A9&1R97-S
M8F]O:W,N:6YC.C@V"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VLB"FUS
M9W-T<B`B5F5L9R!A9')E<W-E8F]K(@H*(SH@8G)O=W-E+G!H<#HR."!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(U"FUS9VED(")!9&1R97-S($)O;VL@3&ES
M=&EN9R(*;7-G<W1R(")!9')E<W-E8F]K;&ES=&4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B
M"FUS9W-T<B`B061R97-S96)O:VQI<W1E(@H*(SH@861D+G!H<#HQ,#@*(RP@
M9G5Z>GD*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R>2(*;7-G<W1R(")!9')E
M<W-E8F]K96X@97(@<VMR:79E8F5S:WET=&5T+B(*"B,Z(&1A=&$N<&AP.C,P
M-0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P
M=7)G960N(@IM<V=S='(@(DEM<&]R="!A=B`E<R!F:6QE;B!V87(@=F5L;'EK
M:V5T(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C(*(RP@9G5Z
M>GD*;7-G:60@(D%D9')E<W,@8F]O:R!T;R!D96QE=&4@(@IM<V=S='(@(D%D
M<F5S<V5B;VME;B!E<B!S:W)I=F5B97-K>71T970N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S`*;7-G:60@(D%D9')E
M<W,@8F]O:W,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S='(@
M(B(*"B,Z('-E87)C:"YP:'`Z.#@@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.C,W"FUS9VED(")!9'9A;F-E9"!396%R8V@B"FUS9W-T<B`B079A;G-E
M<G0@<_AK(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]F;V]T97)!;'!H82YI;F,Z-R!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L
M<&AA+FEN8SHQ,`HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0Q
M"FUS9VED(")!;&PB"FUS9W-T<B`B06QL92(*"B,Z(&QI8B]A<&DN<&AP.C4U
M,@IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D96QE=&4@)7,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI
M;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E
M;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T
M<B`B(@H*(SH@<V5A<F-H+G!H<#HX-2!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z,S8*;7-G:60@(D)A<VEC(%-E87)C:"(*;7-G<W1R(")3=&%N9&%R
M9"!S^&LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")"
M96QO=R!S96%R8V@@9F]R;2(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C<W(&QI8B]$<FEV97(O;&1A<"YP:'`Z.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0FEN9"!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3<X"FUS9VED(")":7)T:&1A
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM<V=I9"`B
M0G)O=W-E(@IM<V=S='(@(DQI<W1E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3<S"B,L(&9U>GIY"FUS9VED(")"=7-I;F5S<R!#871E9V]R
M>2(*;7-G<W1R(")+871E9V]R:2(*"B,Z(&1A=&$N<&AP.C0Y"FUS9VED(")#
M4U8B"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C="]'<F]U<"YP:'`Z-3<*;7-G
M:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I
M9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&1R97-S8F]O:W,N:6YC.C0T"FUS9VED(")#:&]O<V4@82!N86UE(@IM<V=S
M='(@(B(*"B,Z(&%D9"YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A
M;B!A9&1R97-S(&)O;VLB"FUS9W-T<B`B1&5T(&9I;FYE<R!I;F=E;B!S:W)I
M=F)A<F4@861R97-S96+X:V5R+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU
M;6YS96QE8W0N:6YC.C(R,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%D
M9')E<W,@8F]O:SHB"FUS9W-T<B`B1&5T(&9I;FYE<R!I;F=E;B!S:W)I=F)A
M<F4@861R97-S96+X:V5R+B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S
M8F]O:W-E;&5C="YI;F,Z,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S
M<R!B;V]K<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED(")#:&]O
M<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R.`HC+"!F=7IZ
M>0IM<V=I9"`B0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@9&ES<&QA>2!A;F0@
M:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B5F5L9R!R96MK96;X;&=E;B!A=B!K
M;VQO;FYE;F4@<V]M('-K86P@8FQI('9I<W0@:2!A9')E<W-E(&QI<W1E;BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<*;7-G:60@(D-O;'5M;B!/
M<'1I;VYS(@IM<V=S='(@(DMO;&]N;F5V86QG(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-O;'5M;G-E;&5C="YI;F,Z,C,S"FUS9VED(")#;VQU;6YS('1H870@
M=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$S('1E;7!L871E<R]D871A+V5X<&]R="YI
M;F,Z,3(*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,PIM<V=I9"`B0V]M
M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO;VLI(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<V"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(D9I<FUA(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,30T"B,L(&9U>GIY"FUS9VED(")#;VUP86YY($%D9')E
M<W,B"FUS9W-T<B`B2&IE;6UE861R97-S92(*"B,Z(&QI8B]A<&DN<&AP.C,Q
M."!L:6(O87!I+G!H<#HS-C,@;&EB+V%P:2YP:'`Z-#`W(&QI8B]A<&DN<&AP
M.C0Y,0HC.B!L:6(O87!I+G!H<#HV,#$@;&EB+V%P:2YP:'`Z-C@X(&QI8B]A
M<&DN<&AP.C<T,2!L:6(O87!I+G!H<#HX,3D*(SH@;&EB+V%P:2YP:'`Z,3`P
M-B!L:6(O87!I+G!H<#HQ,#DT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYN96-T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B4VQE='1I;F=E;B!F
M96EL970B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C4X"B,L(&9U>GIY"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QU<F4B"FUS9W-T<B`B4VQE='1I;F=E;B!F
M96EL970B"@HC.B!B<F]W<V4N<&AP.C$Y,2!B<F]W<V4N<&AP.C(S,@IM<V=I
M9"`B0V]N=&%C="!A9&1E9"!T;R!L:7-T+B(*;7-G<W1R("(B"@HC.B!B<F]W
M<V4N<&AP.C8P"B,L(&9U>GIY"FUS9VED(")#;VYT86-T(')E;6]V960@9G)O
M;2!L:7-T+B(*;7-G<W1R(")3;&5T="!F<F$@9&5N;F4@;&ES=&5N(@H*(SH@
M8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&%C=',@
M:6X@;&ES=#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHQ,@IM<V=I9"`B0V]P>2(*;7-G<W1R(")+;W!I97(B"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU,PIM<V=I9"`B0W)E871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C0P
M"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@061D<F5S<R!";V]K(@IM<V=S='(@
M(E9E;&<@861R97-S96)O:R(*"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS
M9VED(")#<F5A=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B
M"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B
M1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-S8@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR"B,Z(&QI8B]/8FIE8W0N<&AP.C,R."!L:6(O4F5N9&5R
M97(N<&AP.C0W(&QI8B]296YD97)E<BYP:'`Z-3`*;7-G:60@(D1E;&5T92(*
M;7-G<W1R(")3;&5T="(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C4X"B,L(&9U>GIY"FUS9VED(")$96QE=&4@061D<F5S<R!";V]K(@IM<V=S
M='(@(E9E;&<@861R97-S96)O:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(D1E;&5T92!B=71T
M;VX@8F5H879I;W5R(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z,C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I
M;&5D.B`H)7,I("5S(@IM<V=S='(@(E-L971T:6YG96X@9F5I;&5T(@H*(SH@
M9&5L971E+G!H<#HS.`IM<V=I9"`B1&5L971I;VX@9F%I;&5D(@IM<V=S='(@
M(E-L971T:6YG96X@9F5I;&5T(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M96YT(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,34*(RP@
M9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)R=6ME<B!V86QG
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q.`IM<V=I9"`B
M1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B
M5FES;FEN9W,@=F%L9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"FUS9VED(")$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`B5FES;FEN9W,@=F%L9R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I
M<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C
M="YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("),
M87-T(&YE9"!V0V%R9"(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ
M-R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C(U"FUS9VED(")$
M;W=N;&]A9"!V0V%R9"(*;7-G<W1R("),87-T(&YE9"!V0V%R9"(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P,B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z,C4*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R
M<RYI;F,Z,3`@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"B,Z('1E
M;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,@;&EB+U)E;F1E<F5R
M+G!H<#HT,@IM<V=I9"`B161I="(*;7-G<W1R(")2961I9V5R(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O8V]N
M=&%C=')O=RYI;F,Z,S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D
M:70@7"(E<UPB(@IM<V=S='(@(E)E9&EG97(B"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B161I="!!9&1R97-S
M($)O;VMS(@IM<V=S='(@(E9E;&<@861R97-S96)O:R(*"B,Z(&5D:70N<&AP
M.C<X(&5D:70N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(&5N
M=')Y(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HU.`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B17!O<W0B"@HC.B!E
M9&ET+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S
M('5P9&%T960L(&)U="!S879I;F<@=&AE('5P;&]A9&5D(&9I;&4@9F%I;&5D
M.B`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HQ-#D@961I="YP:'`Z,34R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+B(*
M;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")%
M;G1R>2!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B26UP;W)T(&%V
M("5S(&9I;&5N('9A<B!V96QL>6MK970B"@HC.B!L:6(O87!I+G!H<#HT,3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E87)C:&EN9R!T
M:&4@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")$970@9FEN;F5S(&EN9V5N
M('-K<FEV8F%R92!A9')E<W-E8OAK97(N(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-#$*
M;7-G:60@(D5X<&]R="(*;7-G<W1R(")%:W-P;W)T97(B"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C8*(RP@9G5Z>GD*;7-G:60@(D5X<&]R="!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B16MS<&]R=&5R(&%D<F5S<V5B;VLB"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C(Q"FUS9VED(")%>'!O<G0@
M;VYL>2!T:&4@<V5L96-T960@8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C<*;7-G:60@(D5X<&]R="!T:&4@
M9F]L;&]W:6YG(&%D9')E<W,@8F]O:R!C;VUP;&5T96QY+B(*;7-G<W1R("(B
M"@HC.B!D871A+G!H<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N<&AP.C(Y-R!B
M<F]W<V4N<&AP.C,U(&)R;W=S92YP:'`Z.3`*(SH@8G)O=W-E+G!H<#HQ,3(@
M861D+G!H<#HV-R!S96%R8V@N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S
M(@IM<V=S='(@(DMU;FYE(&EK:V4@:V]B;&4@=&EL(&1E;B!A;F=I='1E(&MA
M=&%L;V=E;BXB"@HC.B!B<F]W<V4N<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&%D9"`E<R!T;R`E<SH@)7,B"FUS9W-T
M<B`B1F5I;&5T(.4@<_AK92!E='1E<B`E<RXB"@HC.B!B<F]W<V4N<&AP.C(W
M,@HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!L:7-T(@IM<V=S
M='(@(D9E:6QE="#E('/X:V4@971T97(@)7,N(@H*(SH@8G)O=W-E+G!H<#HS
M,3`*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C
M=&]R>2(*;7-G<W1R(")+=6YN92!I:VME('/X:V4@:2!K871A;&]G96XZ("5S
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&-H86YG92!N86UE.B`H)7,I("5S.R!/;&0@1$X@
M/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@/2`E<R(*;7-G<W1R("(B"@HC.B!B
M<F]W<V4N<&AP.C$R,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&9I;F0@;V)J96-T('1O(&)E(&%D9&5D.B`E<R(*;7-G<W1R(")+
M=6YN92!I:VME('/X:V4@:2!K871A;&]G96XZ("5S(@H*(SH@<V5A<F-H+G!H
M<#HW.0HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T:&4@861D
M<F5S<R!B;V]K(@IM<V=S='(@(DMU;FYE(&EK:V4@:V]B;&4@=&EL(&1E;B!A
M;F=I='1E(&MA=&%L;V=E;BXB"@HC.B!D871A+G!H<#HQ-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E
M<R(*;7-G<W1R(")+=6YN92!I:VME('/X:V4@:2!K871A;&]G96XZ("5S(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38W"FUS9VED(")&87@B
M"FUS9W-T<B`B5&5L969A:W,B"@HC.B!E9&ET+G!H<#HQ,C0@9&ES<&QA>2YP
M:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")&:6QE<R(*;7-G<W1R(")4:71T96PB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S`*;7-G:60@(D9I
M;F0B"FUS9W-T<B`B1FEN;B(*"B,Z(&5D:70N<&AP.CDW(&5D:70N<&AP.C$X
M-PHC+"!F=7IZ>0IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(D9I;FXB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT.`IM<V=I9"`B1FER<W0@3F%M
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR
M,#(*;7-G:60@(D9R965B=7-Y(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+W-E87)C:"YI;F,Z.#,*;7-G:60@(D9R;VTB"FUS9W-T<B`B
M1G)A(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`T"B,L(&9U>GIY
M"FUS9VED(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@(E9E;&<@861R
M97-S96)O:R(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHT,R!T96UP
M;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C0T"FUS9VED(")'<F]U<"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX,@IM
M<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DAJ96UM96%D<F5S<V4B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY,PIM<V=I9"`B2&]M92!#
M:71Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$P.`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@(E1E
M;&5F;VX@:&IE;6UE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,34P"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@:&IE;6UE
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`S"B,L(&9U>GIY
M"FUS9VED(")(;VUE(%!O<W1A;"!#;V1E(@IM<V=S='(@(E1E;&5F;VX@:&IE
M;6UE(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3@*(RP@9G5Z
M>GD*;7-G:60@(DAO;64@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`B5&5L969O
M;B!H:F5M;64B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX.`HC
M+"!F=7IZ>0IM<V=I9"`B2&]M92!3=')E970@061D<F5S<R(*;7-G<W1R(")(
M:F5M;65A9')E<W-E(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-3`V
M"FUS9VED("))35-0(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-PHC+"!F=7IZ>0IM<V=I9"`B24U34"!!9&1R97-S($)O;VL@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061R97-S96)O:VQI<W1E(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T<B`B26UP;W)T
M97(@861R97-S96)O:RP@<W1E9R`E9"(*"B,Z(&1A=&$N<&AP.C,V,0HC+"!F
M=7IZ>0IM<V=I9"`B26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS(@IM<V=S
M='(@(DEM<&]R=&5R+T5K<W!O<G1E<B!A9')E<W-E8F]K(@H*(SH@;&EB+V%P
M:2YP:'`Z-3DV(&QI8B]A<&DN<&AP.C8X,PHC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!)1"(*;7-G<W1R(")59WEL9&EG(&YA=FXN(@H*(SH@;&EB+V%P:2YP
M:'`Z,C,P(&QI8B]A<&DN<&AP.C0P,B!L:6(O87!I+G!H<#HT.#8@;&EB+V%P
M:2YP:'`Z-3DR"B,Z(&QI8B]A<&DN<&AP.C8W.2!L:6(O87!I+G!H<#HW,S$@
M;&EB+V%P:2YP:'`Z,3`W-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B56=Y;&1I9R!A9')E<W-E8F]K+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$P.#$@;&EB+V%P:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ
M,C`W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(E5G
M>6QD:6<@97!O<W1A9')E<W-E+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.#D*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@96YT<GDB"FUS9W-T<B`B56=Y;&1I9R!N
M879N+B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,C8V"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(&ME>2!S<&5C:69I960N(@IM<V=S='(@(D5N('5G>6QD
M:6<@=F5R9&D@=F%R('9A;&=T+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.#4*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@;F%M92(*;7-G<W1R(")59WEL9&EG(&YA
M=FXN(@H*(SH@;&EB+V%P:2YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED(&]B:F5C=$ED(@IM<V=S='(@(E5G>6QD:6<@;F%V;BXB"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C,P"FUS9VED("(B"B),1$%0('-U<'!O<G0@:7,@
M<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A:6QA8FQE
M(&]R(&YO="!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]/8FIE8W16:65W
M+G!H<#HQ,S@*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-3,*(RP@9G5Z>GD*;7-G:60@
M(DQA<W0@3F%M92(*;7-G<W1R(").879N(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`B
M3&ES=&4B"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S<*;7-G
M:60@(DUA=&-H:6YG(@IM<V=S='(@(DMO8FQI;F<B"@HC.B!L:6(O87!I+G!H
M<#HR,#4*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DUA
M>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]T<F5E7VUE;G4N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@3&ES="(*
M;7-G<W1R(").>2!L:7-T92(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H
M<#HS"B,L(&9U>GIY"FUS9VED(")-:6YI(%-E87)C:"(*;7-G<W1R(")3^&LB
M"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$
M3B!I;B!,1$%0('-O=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL
M92!0:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.3,*;7-G:60@(DUO<F4@=&AA;B`Q(&5N
M=')Y(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,3$*;7-G:60@(DUO=F4B"FUS9W-T<B`B1FQY='0B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA
M=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@;&5F="(*;7-G<W1R(")&;'ET="!T:6P@=F5N<W1R92(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T.0HC.B!T
M96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X-@HC+"!F
M=7IZ>0IM<V=I9"`B36]V92!R:6=H="(*;7-G<W1R(")&;'ET="!T:6P@:/AY
M<F4B"@HC.B!D871A+G!H<#HU,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$V"B,L(&9U>GIY"FUS9VED(")-=6QB97)R>2!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B5F5L9R!A9')E<W-E8F]K(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I=&@@
M861D<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y
M(&5X:7-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*;7-G
M:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R(")696QG(&%D<F5S<V5B;VLB
M"@HC.B!A9&1R97-S8F]O:W,N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B37D@
M061D<F5S<R!";V]K<R(*;7-G<W1R(")696QG(&%D<F5S<V5B;VLB"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#<@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z-#(*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%V;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B3F%M92!&;W)M870B
M"FUS9W-T<B`B3F%V;F5F;W)M870B"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N
M9&ES=#HS,34*;7-G:60@(DYE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y(@IM
M<V=S='(@(B(*"B,Z(&%D9"YP:'`Z,S8@861D+G!H<#HQ,C0@;&EB+T)L;V-K
M+VUI;FES96%R8V@N<&AP.C(W"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP
M.C(W"FUS9VED(").97<@0V]N=&%C="(*;7-G<W1R(").>2!K;VYT86MT(@H*
M(SH@961I="YP:'`Z.#@@961I="YP:'`Z.34@961I="YP:'`Z,C`R('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z-#4*;7-G:60@(DYE>'0B"FUS9W-T<B`B
M3F5S=&4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*(RP@
M9G5Z>GD*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(DYA=FXB"@HC.B!L:6(O
M87!I+G!H<#HQ,3DU(&QI8B]A<&DN<&AP.C$R-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$Q-C,*(RP@9G5Z>GD*;7-G:60@(DYO(&%D9')E<W,@
M8F]O:W,@9F]U;F0N(@IM<V=S='(@(D%D<F5S<V5B;VME;B!E<B!S:W)I=F5B
M97-K>71T970N(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#,*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-O;G1A8W1S(&9O=6YD(@IM<V=S='(@(E9I<R!K;VYT86MT97(B
M"@HC.B!L:6(O87!I+G!H<#HU,3$@;&EB+V%P:2YP:'`Z-S8V"FUS9VED(").
M;R!V0V%R9"!D871A('=A<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]F;V]T97(N:6YC.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`B
M26YG96XB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G
M:60@(DYO=&5S(@IM<V=S='(@(DYO=&%T97(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$U"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<T
M-PIM<V=I9"`B3V)J96-T(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,C,*;7-G:60@(D]F9FEC92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C(S"FUS
M9VED("(B"B)/;F-E('EO=2!S879E('1H:7,@;W!T:6]N('!A9V4L('1H92!A
M9&1R97-S(&)O;VL@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B!)
M9B!T:&ES(&ES(&YO="!W:&%T('EO=2!W86YT+"!T:&5N('EO=2!M=7-T(&-H
M86YG92!Y;W5R('-E;&5C=&EO;B`B"B)T;R!<(DYO;F5<(BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z-S<T"FUS9VED(")/;FQY(&]N92!V8V%R9"!S
M=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8*(RP@9G5Z>GD*;7-G:60@
M(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B0G)U:V5R('9A;&<B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(E!'4"!O9F9E;G1L:6<@;OAK:V5L(@H*(SH@;&EB+V%P
M:2YP:'`Z-#DU(&QI8B]A<&DN<&AP.C8P-2!L:6(O87!I+G!H<#HV.3(@;&EB
M+V%P:2YP:'`Z.3,T"B,Z(&QI8B]A<&DN<&AP.C$P.3@*;7-G:60@(E!E<FUI
M<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.C4T
M,PIM<V=I9"`B4&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3D*;7-G:60@(E!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C4S('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(E!I;F4@061D<F5S<R!";V]K
M(@IM<V=S='(@(E9E;&<@861R97-S96)O:R(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE('1H92!N
M97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY,2!E
M9&ET+G!H<#HY-"!E9&ET+G!H<#HQ.30*;7-G:60@(E!R979I;W5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C0Q-@HC+"!F=7IZ
M>0IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B5F5L9R!A
M9')E<W-E8F]K(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B475E<GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHQ.`HC+"!F
M=7IZ>0IM<V=I9"`B475I8VL@4V5A<F-H(@IM<V=S='(@(E-T86YD87)D('/X
M:R(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,3DY(&QI8B]$<FEV97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E860@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]296YD97)E<BYP:'`Z-#D*;7-G:60@(E)E86QL>2!D96QE=&4@=&AI
M<R!C;VYT86-T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O
M;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D<R!D:7-P;&%Y960Z(@IM<V=S='(@
M(D%N=&%L(&D@=FES;FEN9SHB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S
M<V)O;VMS96QE8W0N:6YC.C$W-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&%D
M9')E<W,@8F]O:R(*;7-G<W1R("));7!O<G1E<B!A9')E<W-E8F]K(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C,Y"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(F9J97)N(&MO;&]N;F4B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@(E)E
M;6]V92!F<F]M('1H:7,@;&ES="(*;7-G<W1R(")3;&5T="!F<F$@9&5N;F4@
M;&ES=&5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0HC+"!F
M=7IZ>0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@
M=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@
M(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S
M<R!B;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"B)%<G-T871T(&5K:7-T97)E
M;F1E(&%D<F5S<V5B;VL@;65D(&1E;B!I;7!O<G1E<G1E(#\@/&(^061V87)S
M96PZ($1E='1E("(*(G-L971T97(@86QT(&EN;FAO;&0@:2!D:6X@861R97-S
M96)O:RX\+V(^(@H*(SH@;&EB+T1R:79E<BYP:'`Z-#,X"FUS9VED(")297%U
M97-T960@;V)J96-T(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861D+G!H
M<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$S"FUS9VED(")2
M97-E="!T;R!$969A=6QT<R(*;7-G<W1R(")4^&T@<VMJ96UA(@H*(SH@8V]N
M9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DV"FUS9VED(")3+TU)344@4'5B
M;&EC($-E<G1I9FEC871E(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&5D:70N<&AP.CDY(&%D9"YP:'`Z
M,S<@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E
M(@IM<V=S='(@(DQA9W)E(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.CDV('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3(*(SH@=&5M
M<&QA=&5S+V)L;V-K+VUI;FES96%R8V@N:6YC.C(Q(&QI8B]";&]C:R]T<F5E
M7VUE;G4N<&AP.C0Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")3^&LB"@HC.B!M:6YI<V5A<F-H+G!H<#HV
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(%)E<W5L=',Z(@IM<V=S='(@(E/X
M:V5R97-U;'1A=&5R(@H*(SH@;&EB+V%P:2YP:'`Z,3`Q,0HC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R(")3^&LB"@HC.B!L:6(O87!I
M+G!H<#HQ,3`S(&QI8B]A<&DN<&AP.C$Q,#D@;&EB+V%P:2YP:'`Z,3$Q."!L
M:6(O87!I+G!H<#HQ,3,Q"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:"!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI
M<V5A<F-H+FEN8SHR,@HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM
M<V=S='(@(E/X:R(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8V
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@861D<F5S<R!B;V]K('1O(&1E
M;&5T92(*;7-G<W1R(")696QG(&%D<F5S<V5B;VLB"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N
M(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@(E9E;&<@861R97-S96)O
M:R(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S(*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M
M.B(*;7-G<W1R(")696QG(&MI;&1E('-O;2!D970@<VMA;"!E:W-P;W)T97)E
M<R!F<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR-@HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T
M('1O.B(*;7-G<W1R(")696QG(&WE;"#E(&EM<&]R=&5R92!T:6PZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS9W-T
M<B`B5F5L9R!F;W)M870@<.4@:VEL9&5N.B(*"B,Z('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,3`*;7-G:60@(E-E;&5C="!T:&4@97AP;W)T(&9O<FUA
M=#HB"FUS9W-T<B`B5F5L9R!F;W)M871E="!D=2!V:6P@96MS<&]R=&5R92!T
M:6PZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B
M4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B5F5L9R!F:6QE
M;B!S;VT@<VMA;"!I;7!O<G1E<F5S.B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3$*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S
M;W5R8V4@9FEL93HB"FUS9W-T<B`B5F5L9R!F;W)M870@<.4@:VEL9&5N.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!T
M:&4@9F]R;6%T('5S960@=&\@9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`B5F5L
M9R!V:7-N:6YG<V9O<FUA=&5T('-O;2!S:V%L(&)E;GET=&5S.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N
M9"!P86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`B5F5L9R!S=&%N9&%R9'9I<VYI
M;F<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")396QE
M8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@;&ES
M=',N(@IM<V=S='(@(E9E;&<@:'9I;&ME(&9E;'1E<B!S;VT@<VMA;"!V:7-E
M<R!I(&%D<F5S<V4@;&ES=&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,@IM<V=I9"`B4V5L96-T('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA
M;65S+B(*;7-G<W1R(")696QG(&AV82!S;&%G<R!V:7-N:6YG<V9O<FUA="!N
M879N('-K86P@:&$N(@H*(SH@861D+G!H<#HU-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K(%PB)7-<(BXB"FUS
M9W-T<B`B=&EL('9A;&=T(&%D<F5S<V5B;VLB"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HQ-S,*(RP@9G5Z>GD*;7-G:60@(E-H87)E9"!$:7)E8W1O
M<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-H;W<@
M)7,B"FUS9W-T<B`B5FES(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHT,0IM<V=I9"`B4VAO=R!!;&PB"FUS9W-T<B`B5FES(&%L;&4B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0P"FUS9VED(")3:&]W
M($-O;G1A8W1S(@IM<V=S='(@(E9I<R!K;VYT86MT97(B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")3:&]W($QI<W1S(@IM
M<V=S='(@(E9I<R!L:7-T97(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M
M;E]H96%D97)S+FEN8SHR,0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H
M96%D97)S+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B4V]R="!$:7)E8W1I;VXB
M"FUS9W-T<B`B2V%T86QO9R(*"B,Z(&QI8B]A<&DN<&AP.C$Y.`HC+"!F=7IZ
M>0IM<V=I9"`B4V]U<F-E<R(*;7-G<W1R(")3=6MS97-S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$U-PIM<V=I9"`B4W!E8VEF>2!W:&5R92!Y;W4@
M=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N(@IM<V=S
M='(@(B(*"B,Z(&)R;W=S92YP:'`Z,30Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!A9&1E9"`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!B
M<F]W<V4N<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8W)E871E9"!T:&4@8V]N=&%C="!L:7-T(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9&%T82YP:'`Z-3`*;7-G:60@(E135B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,30*;7-G:60@(E1A8B!S97!A<F%T960@=F%L=65S(@IM<V=S
M='(@(B(*"B,Z('9I97<N<&AP.C$U"FUS9VED(")4:&4@5D93(&)A8VME;F0@
M;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E;F%B;&4@871T86-H;65N="!U
M<&QO861S+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#4T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E
M<UPB('=A<R!C<F5A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<F5M;W9E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z.#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S('-U8V-E
M<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HS,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N
M;W0@8F4@<'5R9V5D.B`E<R(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HT-R!V
M8V%R9"YP:'`Z,C(@9&ES<&QA>2YP:'`Z,C,@=FEE=RYP:'`Z,C8*;7-G:60@
M(E1H92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&5D:70N<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R("));7!O<G0@878@)7,@9FEL96X@=F%R('9E
M;&QY:VME="(*"B,Z(&1A=&$N<&AP.C(X-`IM<V=I9"`B5&AE(&EM<&]R="!C
M86X@8F4@9FEN:7-H960@9&5S<&ET92!T:&4@=V%R;FEN9W,N(@IM<V=S='(@
M(B(*"B,Z(&)R;W=S92YP:'`Z,S$*;7-G:60@(E1H97)E(&%R92!N;R!B<F]W
M<V5A8FQE(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@(D1E="!F:6YN97,@:6YG
M96X@<VMR:79B87)E(&%D<F5S<V5B^&ME<BXB"@HC.B!A9&0N<&AP.C(Y"B,L
M(&9U>GIY"FUS9VED("(B"B)4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E
M<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS
M("(*(F%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N
M=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R`B"B)I<R!A;B!E
M<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB26YG96X@878@9&4@=&EL9VIE;F=E;&EG92!A9')E
M<W-E8OAK96YE('1I;&QA=&5R(&1E9R#E(&QE9V=E('1I;"!N>64@(@HB;W!P
M9OAR:6YG97(N($AV:7,@9'4@;65N97(@9&5T=&4@97(@9F5I;"P@=F5N;FQI
M<W0@:V]N=&%K="!S>7-T96T@(@HB861M:6YI<W1R871O<F5N(&1I;BXB"@HC
M.B!A9&0N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"B)$970@;W!P<W1O9"!E;B!F96EL(&ED970@;V)J96MT970@<VMU
M;&QE(&QE9V=E<R!T:6PN($MO;G1A:W0@(@HB<WES=&5M861M:6YI<W1R871O
M<F5N(&1I;B!F;W(@>71T97)L:6=E<F5R92!H:F5L<"XB"@HC.B!B<F]W<V4N
M<&AP.C$X.2!B<F]W<V4N<&AP.C(S,`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B1&5T
M(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T(&%V(&1A=&%E;F4N(@H*(SH@
M8G)O=W-E+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R(")$970@;W!P<W1O
M9"!E;B!F96EL('9E9"!I;7!O<G0@878@9&%T865N92XB"@HC.B!A9&1R97-S
M8F]O:W,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S
M(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@;N5R(&1E;B!O<'!L87-T
M961E(&9I;&5N('-K=6QL92!I;7!O<G1E<F5S(@H*(SH@8G)O=W-E+G!H<#HQ
M-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D96QE=&EN9R!<(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@
M8F]O:RXB"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!NY7(@9&5N(&]P
M<&QA<W1E9&4@9FEL96X@<VMU;&QE(&EM<&]R=&5R97,B"@HC.B!D96QE=&4N
M<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@=&AI<R!C;VYT86-T.B`E<R(*;7-G<W1R(")$
M970@;W!P<W1O9"!E;B!F96EL('9E9"!I;7!O<G0@878@9&%T865N92XB"@HC
M.B!B<F]W<V4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(D1E="!O<'!S
M=&]D(&5N(&9E:6P@=F5D(&EM<&]R="!A=B!D871A96YE+B(*"B,Z(&)R;W=S
M92YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F
M96EL('9E9"!I;7!O<G0@878@9&%T865N92XB"@HC.B!D871A+G!H<#HS,S4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(D1E="!O<'!S=&]D
M(&5N(&9E:6P@=F5D(&EM<&]R="!A=B!D871A96YE+B(*"B,Z(&QI8B]A<&DN
M<&AP.C4P-R!L:6(O87!I+G!H<#HW-C$*(RP@9G5Z>GD*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*
M;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('9E9"!I;7!O<G0@878@9&%T
M865N92XB"@HC.B!B<F]W<V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@<F5M;W9I;F<@82!C;VYT86-T(&9R;VT@=&AE(&QI
M<W0N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=F5D(&EM<&]R="!A
M=B!D871A96YE+B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-34@861D<F5S<V)O
M;VMS+G!H<#HV,"!A9&1R97-S8F]O:W,N<&AP.C8X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M;W9I;F<@=&AI
M<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E
M:6P@;N5R(&1E;B!O<'!L87-T961E(&9I;&5N('-K=6QL92!I;7!O<G1E<F5S
M(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX,2!A9&1R97-S8F]O:W,N<&AP.C@W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D1E
M="!O<'!S=&]D(&5N(&9E:6P@;N5R(&1E;B!O<'!L87-T961E(&9I;&5N('-K
M=6QL92!I;7!O<G1E<F5S(@H*(SH@961I="YP:'`Z,34X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AI<R!E;G1R>3H@)7,B"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!V
M960@:6UP;W)T(&%V(&1A=&%E;F4N(@H*(SH@9&%T82YP:'`Z,3<Y"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!W97)E(&YO(&%D9')E<W-E<R!T;R!E>'!O<G0N
M(@IM<V=S='(@(D1E="!F:6YN97,@:6YG96X@<VMR:79B87)E(&%D<F5S<V5B
M^&ME<BXB"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N
M:6YC.C$X,`IM<V=I9"`B5&AE<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L
M87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-O;'5M;G-E;&5C="YI;F,Z,C0S"FUS9VED(")4:&5S92!C;VQU;6YS
M('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R.B(*;7-G<W1R("(B"@HC.B!D
M871A+G!H<#HR-CD*;7-G:60@(E1H:7,@9FEL92!F;W)M870@:7,@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3$R,B!L:6(O
M87!I+G!H<#HQ,3,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES
M('!E<G-O;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B1&5N;F4@<&5R<V]N96X@9FEN;F5S(&%L;&5R961E
M(&D@861R97-S96)O:V5N(&1I;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30W"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE(&1E9F%U;'0@861D
M<F5S<R!B;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN9R!C;VYT86-T<RXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S`*
M;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I='1E;"(*"B,Z(&QI8B]4=7)B82YP
M:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M;F5W('-H87)E+B`@36ES<VEN9R!S;W5R8V4@='EP92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")+
M86X@:6MK92!L87-T92!D971F:6YI<VIO;F5N(&%V("5S+B(*"B,Z(&5D:70N
M<&AP.C@X(&5D:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY(&5D
M:70N<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S
M='(@(DQA9W)E(&5N9')I;F=E<B(*"B,Z(&QI8B]A<&DN<&AP.C4T,"!L:6(O
M87!I+G!H<#HV-#,@;&EB+V%P:2YP:'`Z-S<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"B,L(&9U>GIY"FUS9VED
M(")697)I<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ.2!T96UP;&%T97,O8G)O=W-E+V-O
M;G1A8W1R;W<N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&UI;FES96%R8V@N<&AP.C<X"B,L(&9U>GIY
M"FUS9VED(")6:65W($-O;G1A8W0B"FUS9W-T<B`B3GD@:V]N=&%K="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E9I97<@=&\@9&ES
M<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R(")3=&%N9&%R9'9I<VYI;F<Z(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C`X"FUS9VED(")796)S
M:71E(%523"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HQ,3,*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")&:7)M86%D
M<F5S<V4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,C0*;7-G
M:60@(E=O<FL@0VET>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ,SD*(RP@9G5Z>GD*;7-G:60@(E=O<FL@0V]U;G1R>2(*
M;7-G<W1R(")496QE9F]N($%R8F5I9"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$U-@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE
M9F]N($%R8F5I9"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$S
M-`HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!0;W-T86P@0V]D92(*;7-G<W1R(")4
M96QE9F]N($%R8F5I9"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$R.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=&%T92]0<F]V:6YC92(*;7-G
M<W1R(")496QE9F]N($%R8F5I9"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!3=')E970@061D<F5S
M<R(*;7-G<W1R(")&:7)M86%D<F5S<V4B"@HC.B!D871A+G!H<#HR,S<@8G)O
M=W-E+G!H<#HY,R!B<F]W<V4N<&AP.C(P,2!A9&0N<&AP.C<S"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&5D:70N<&AP.C8Y(&1I<W!L87DN<&AP.C4X('9I97<N<&AP.C,V"FUS9VED
M(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N
M=&%C="XB"FUS9W-T<B`B(@H*(SH@=F-A<F0N<&AP.C0P"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@;V)J96-T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C4U"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@
M861D<F5S<R!B;V]K+B(*;7-G<W1R(")T:6P@=F%L9W0@861R97-S96)O:R(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C,*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(*;7-G<W1R("(B"@HC
M.B!E9&ET+G!H<#HS,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T
M(&]N92!C;VYT86-T(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C$W('1E;7!L871E<R]B<F]W<V4O:F%V
M87-C<FEP="YI;F,Z-#D*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T
M+FEN8SHW,@IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!E
M;G1R>2!F:7)S="XB"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-S,*;7-G:60@
M(EEO=2!O;FQY(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C
M="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HR.#4*;7-G:60@(EEO=7(@
M9&5F875L="!A9&1R97-S(&)O;VL@:7,@;F]T(&)R;W=S96%B;&4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHV('1E;7!L871E
M<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,3(*;7-G:60@(EMN;R!V86QU95TB
M"FUS9W-T<B`B(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#0*;7-G:60@(E]"<F]W
M<V4B"FUS9W-T<B`B0FQA(&=J96YN;VTB"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C0P"B,L(&9U>GIY"FUS9VED(")?0V]N=&%C=',B"FUS
M9W-T<B`B5FES(&MO;G1A:W1E<B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T
M:6]N<RYI;F,Z,@IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")3;&5T="(*"B,Z
M(&QI8B]4=7)B82YP:'`Z-#DS"FUS9VED(")?26UP;W)T+T5X<&]R="(*;7-G
M<W1R("));7!O<G1E<B]%:W-P;W)T97(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY"FUS9VED(")?3&ES=',B"FUS9W-T
M<B`B3&ES=&4B"@HC.B!L:6(O5'5R8F$N<&AP.C0X,0HC+"!F=7IZ>0IM<V=I
M9"`B7TUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`B5F5L9R!A9')E<W-E8F]K
M(@H*(SH@;&EB+U1U<F)A+G!H<#HT.#<*(RP@9G5Z>GD*;7-G:60@(E].97<@
M0V]N=&%C="(*;7-G<W1R(").>2!K;VYT86MT(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHR"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E(&9R
M;VT@=&AI<R!L:7-T(@IM<V=S='(@(E-L971T(&9R82!D96YN92!L:7-T96XB
M"@HC.B!L:6(O5'5R8F$N<&AP.C0X.0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R
M(")3^&LB"@HC.B!V8V%R9"YP:'`Z-#8*;7-G:60@(F-O;G1A8W0N=F-F(@IM
M<V=S='(@(B(*"B,Z(&1A=&$N<&AP.C$Y.2!D871A+G!H<#HR,#0@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHQ"FUS9VED(")C;VYT86-T<RYC<W8B"FUS
M9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C`Y"FUS9VED(")C;VYT86-T<RYT<W8B
M"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C$Y"FUS9VED(")C;VYT86-T<RYV
M8V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN
M8SHS-`HC+"!F=7IZ>0IM<V=I9"`B;F]N92(*;7-G<W1R("));F=E;B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G
M:60@(G1O(&$@0V]N=&%C="!,:7-T(@IM<V=S='(@(E9I<R!K;VYT86MT97(B
M"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C$T"B,L(&9U>GIY
M"FUS9VED(")T;R!A(&1I9F9E<F5N="!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M=&EL('9A;&=T(&%D<F5S<V5B;VLB"@HC.B!D871A+G!H<#HU,2!T96UP;&%T
M97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ,PHC.B!T96UP;&%T97,O
M9&%T82]I;7!O<G0N:6YC.C$U('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z
M,34*;7-G:60@(G9#87)D(@IM<V=S='(@(B(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M='5R8F$O<&\O<W9?4T4N<&\`````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#$P-#$Q,``Q,#0Q-S,V,C<U-@`P,3<U,S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R!4=7)B82!3
M=V5D:7-H('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R+3(P,#8@
M2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E
M<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!4=7)B82!P86-K86=E+@HC($IO
M87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/BP@,C`P
M-BX*(R!!;F1R96%S($1A:&SI;B`\86YD<F5A<T!D86AL96XN=W,^+"`R,#`U
M+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!4
M=7)B82`R+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ-2`Q
M,#HP-RLP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$U(#$Q
M.C$U*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2F]A<75I;2!(;VUR:6=H
M875S96X@/&IO:&]`=V5B8G!L871S96XN<V4^7&XB"B),86YG=6%G92U496%M
M.B!3=V5D:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R
M<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@
M(3T@,2D[7&XB"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC.C0P
M"FUS9VED("(@061D(&%N($E-4U`@061D<F5S<R!";V]K(@IM<V=S='(@(B!,
MY&=G('1I;&P@96X@24U34"UA9')E<W-B;VLB"@HC.B!T96UP;&%T97,O<')E
M9G,O:6US<%]O<'0N:6YC.C(Y"FUS9VED("(@1&5L971E($E-4U`@061D<F5S
M<R!";V]K(@IM<V=S='(@(B!2861E<F$@24U34"UA9')E<W-B;VLB"@HC.B!D
M871A+G!H<#HS,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&%L<F5A
M9'D@97AI<W1S(&%N9"!W87,@;F]T(&EM<&]R=&5D+B(*;7-G<W1R("(G)7,G
M(&9I;FYS(')E9&%N(&]C:"!I;7!O<G1E<F%D97,@:6YT92XB"@HC.B!B<F]W
M<V4N<&AP.C$T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO
M="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B<E<R<@
M:V]P:65R861E<R!I;G1E(&5F=&5R<V]M(&1E="#D<B!E;B!L:7-T82XB"@HC
M.B!B<F]W<V4N<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!M;W9E9"!B96-A=7-E(&ET(&ES(&$@;&ES="XB"FUS9W-T<B`B
M)R5S)R!F;'ET=&%D97,@:6YT92!E9G1E<G-O;2!D970@Y'(@96X@;&ES=&$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S
M=&YA;64@3&%S=&YA;65<(B`@*&EE+B!*;VAN($1O92DB"FUS9W-T<B`B7")&
M]G)N86UN($5F=&5R;F%M;EPB("`H2F]H;B!$;V4I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N86UE
M7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(EPB169T97)N86UN+"!&]G)N
M86UN7"(@*$1O92P@2F]H;BDB"@HC.B!A9&0N<&AP.C$P.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B)7,@;&%D97,@=&EL;"XB
M"@HC.B!D871A+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9FEL
M92!S=6-C97-S9G5L;'D@:6UP;W)T960B"FUS9W-T<B`B)7,M9FEL96X@Y'(@
M:6UP;W)T97)A9"(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@
M(B5S('1I;&P@)7,@878@)7,B"@HC.B!L:6(O5'5R8F$N<&AP.C0U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(E
M<W,@861R97-S8F]K(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C0R
M"FUS9VED(")!(&)R;W=S97(@=&AA="!S=7!P;W)T<R!I1G)A;65S(&ES(')E
M<75I<F5D(@IM<V=S='(@(D5N('=E8FSD<V%R92!S;VT@<W3V9&IE<B!I1G)A
M;65S(&MRY'9S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,`IM<V=I
M9"`B06)O=F4@<V5A<F-H(&9O<FTB"FUS9W-T<B`B3W9A;F;V<B!S]FMF;W)M
M=6SD<B(*"B,Z('9I97<N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(D%C
M8V5S<R!D96YI960@=&\@)7,B"FUS9W-T<B`BQ71K;VUS="!N96MA9&5S('1I
M;&P@)7,B"@HC.B!A9&0N<&AP.C4V('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,CD*;7-G:60@(D%D9"(*;7-G<W1R("),Y&=G('1I;&PB"@HC.B!T
M96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-`IM<V=I
M9"`B061D(&%D9')E<W,@8F]O:R(*;7-G<W1R(").>2!A9')E<W-B;VLB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@*;7-G:60@(D%D9"!A;F0@1&5L
M971E($E-4U`@861D<F5S<R!B;V]K<R(*;7-G<W1R("),Y&=G('1I;&P@;V-H
M(')A9&5R82!)35-0+6%D<F5S<V+V8VME<B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M;B(*;7-G
M<W1R("),Y&=G('1I;&P@:V]L=6UN(@H*(SH@961I="YP:'`Z,3,U"FUS9VED
M(")!9&0@9FEL92(*;7-G<W1R("),Y&=G('1I;&P@9FEL(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR.0IM<V=I9"`B061D('1O(@IM<V=S
M='(@(DSD9V<@=&EL;"(*"B,Z(&%D9&QI;FLN<&AP.C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9&5D(&$@)7,@;&EN:R!T;R`E<RXB"FUS9W-T<B`B3&%D
M92!T:6QL(&5N("5S+6SD;FL@=&EL;"`E<RXB"@HC.B!L:6(O1')I=F5R+VYU
M;&PN<&AP.C4W"FUS9VED(")!9&1I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B1&5T(&?E<B!I;G1E(&%T="!LY&=G82!T:6QL(&MO
M;G1A:W1E<BXB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V)O:R(*"B,Z(&)R
M;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B
M061D<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B061R97-S8F]K<VQI<W1A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P"FUS9VED(")!9&1R97-S
M($)O;VMS(@IM<V=S='(@(D%D<F5S<V+V8VME<B(*"B,Z(&%D9"YP:'`Z,3`X
M"FUS9VED(")!9&1R97-S(&)O;VL@96YT<GDB"FUS9W-T<B`B061R97-S8F]K
M<W!O<W0B"@HC.B!L:6(O4V]U<F-E+G!H<#HT,3,*;7-G:60@(D%D9')E<W,@
M8F]O:R!I<R!R96%D+6]N;'DN(@IM<V=S='(@(D%D<F5S<V)O:R!K86X@96YD
M87-T(&SD<V%S+B(*"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B061D<F5S<R!B
M;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(D%D<F5S<V)O;VME
M;B#D<B!T]FUD+B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C8R
M"FUS9VED(")!9&1R97-S(&)O;VL@=&\@9&5L971E("(*;7-G<W1R(")!9')E
M<W-B;VL@<V]M('-K86QL(')A9&5R87,@(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S`*;7-G:60@(D%D9')E<W,@8F]O
M:W,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S='(@(D%D<F5S
M<V+V8VME<B!S;VT@:6YT92!V:7-A<SHB"@HC.B!S96%R8V@N<&AP.C@X('1E
M;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHS.`IM<V=I9"`B061V86YC960@
M4V5A<F-H(@IM<V=S='(@(D%V86YC97)A9"!S]FMN:6YG(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z-C0*;7-G:60@(D%L:6%S(@IM<V=S='(@
M(D%L:6%S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z
M-R!T96UP;&%T97,O8G)O=W-E+V9O;W1E<D%L<&AA+FEN8SHQ,`HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0X"FUS9VED(")!;&PB"FUS9W-T
M<B`B06QL82(*"B,Z(&QI8B]A<&DN<&AP.C4U-`IM<V=I9"`B06QR96%D>2!%
M>&ES=',B"FUS9W-T<B`B1FEN;G,@<F5D86XB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+VIA=F%S8W)I<'0N:6YC.CDS"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92`E<S\B"FUS9W-T
M<B`BQ'(@9&5T('/D:V5R="!A='0@9'4@=FEL;"!R861E<F$@)7,_(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHV-PIM<V=I9"`B07)E
M('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E('1H92!S96QE8W1E
M9"!E;G1R:65S/R(*;7-G<W1R("+$<B!D=2!SY&ME<B!PY2!A='0@9'4@=FEL
M;"!R861E<F$@;6%R:V5R861E('!O<W1E<C\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.38*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")3=&EG86YD
M92(*"B,Z('-E87)C:"YP:'`Z.#4@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.C,W"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B4_9K;FEN9R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3D*;7-G:60@(D)E;&]W('-E
M87)C:"!F;W)M(@IM<V=S='(@(DYE9&%N9O9R('/V:V9O<FUU;.1R970B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C<W(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FEN9"!F86EL960Z("@E<RD@)7,B
M"FUS9W-T<B`B0FEN9"!M:7-S;'EC:V%D97,Z("@E<RD@)7,B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D)I<G1H9&%Y(@IM
M<V=S='(@(D;V9&5L<V5D86<B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PIM
M<V=I9"`B0G)O=W-E(@IM<V=S='(@(DQI<W1A(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3<S"FUS9VED(")"=7-I;F5S<R!#871E9V]R>2(*
M;7-G<W1R(")!9F;D<G-K871E9V]R:2(*"B,Z(&1A=&$N<&AP.C0Y"FUS9VED
M(")#4U8B"FUS9W-T<B`B0U-6(@H*(SH@;&EB+T]B:F5C="]'<F]U<"YP:'`Z
M-3<*;7-G:60@(D-A;B=T(&%D9"!A(&=R;W5P('1O(&ET<V5L9BXB"FUS9W-T
M<B`B2V%N(&EN=&4@;.1G9V$@=&EL;"!G<G5P<"!T:6QL('-I9R!S:N1L=BXB
M"@HC.B!T96UP;&%T97,O861D;&EN:R]C;VYT86-T<RYI;F,Z,3(W"FUS9VED
M(")#86YC96PB"FUS9W-T<B`B079B<GET(@H*(SH@=&5M<&QA=&5S+V)R;W=S
M92]C;VQU;6Y?:&5A9&5R<RYI;F,Z-PIM<V=I9"`B0VAE8VL@7T%L;"].;VYE
M(@IM<V=S='(@(DUA<FME<F$@7T%L;&$O26YG96XB"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHT-`IM<V=I9"`B0VAO;W-E(&$@;F%M92(*;7-G
M<W1R(")6Y&QJ(&5T="!N86UN(@H*(SH@861D+G!H<#HT.`IM<V=I9"`B0VAO
M;W-E(&%N(&%D9')E<W,@8F]O:R(*;7-G<W1R(")6Y&QJ(&5N(&%D<F5S<V)O
M:R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(R,0IM
M<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B5N1L:B!E
M;B!A9')E<W-B;VLZ(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K
M<V5L96-T+FEN8SHQ-C4*;7-G:60@(D-H;V]S92!W:&EC:"!A9&1R97-S(&)O
M;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R(")6
MY&QJ(&%D<F5S<V+V8VME<B!S;VT@<VMA;&P@=FES87,@;V-H(&D@=FEL:V5N
M(&]R9&YI;F<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q"FUS9VED
M(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@
M(E;D;&H@861R97-S8O9C:V5R('-O;2!S:V%L;"!A;G;D;F1A<RXB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C@*;7-G:60@(D-H
M;V]S92!W:&EC:"!C;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H870@;W)D
M97(Z(@IM<V=S='(@(E;D;&H@:V]L=6UN97(@<V]M('9I<V%S(&]C:"!I('9I
M;&ME;B!O<F1N:6YG.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-PIM
M<V=I9"`B0V]L=6UN($]P=&EO;G,B"FUS9W-T<B`B2V]L=6UN:6YS=.1L;&YI
M;F=A<B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S
M,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB
M"FUS9W-T<B`B2V]L=6UN97(@<V]M(&EN=&4@=FES87,Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O<G0N
M:6YC.C$R"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@
M(DMO;6UA<V5P87)E<F%D92!VY')D96XB"@HC.B!T96UP;&%T97,O9&%T82]E
M>'!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S("A-
M:6-R;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`B2V]M;6%S97!A<F5R861E(';D
M<F1E;B`H36EC<F]S;V9T($]U=&QO;VLI(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z-S8*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B1O9R971A
M9R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$T-`IM<V=I9"`B
M0V]M<&%N>2!!9&1R97-S(@IM<V=S='(@(D%D<F5S<RP@9O9R971A9R(*"B,Z
M(&QI8B]A<&DN<&AP.C,R,"!L:6(O87!I+G!H<#HS-C4@;&EB+V%P:2YP:'`Z
M-#`Y(&QI8B]A<&DN<&AP.C0Y,PHC.B!L:6(O87!I+G!H<#HV,3D@;&EB+V%P
M:2YP:'`Z-S`V(&QI8B]A<&DN<&AP.C<U.2!L:6(O87!I+G!H<#HX-#`*(SH@
M;&EB+V%P:2YP:'`Z,3`S-R!L:6(O87!I+G!H<#HQ,3(U"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")!;G-L
M=71N:6YG('1I;&P@<V5R=F5R(&UI<W-L>6-K861E<SH@)7,B"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C4X"FUS9VED(")#;VYN96-T:6]N(&9A:6QU<F4B
M"FUS9W-T<B`B06YS;'5T;FEN9R!T:6QL('-E<G9E<B!M:7-S;'EC:V%D97,B
M"@HC.B!A9&1L:6YK+G!H<#HQ,S@@=&5M<&QA=&5S+V%D9&QI;FLO8V]N=&%C
M=',N:6YC.C4Y"FUS9VED(")#;VYT86-T($QI<W0B"FUS9W-T<B`B2V]N=&%K
M=&QI<W1A(@H*(SH@;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP.C,@;&EB+T)L
M;V-K+VUI;FES96%R8V@N<&AP.C(V"FUS9VED(")#;VYT86-T(%-E87)C:"(*
M;7-G<W1R(")3]FL@:V]N=&%K="(*"B,Z(&)R;W=S92YP:'`Z,CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z("5S(@IM<V=S='(@
M(DMO;G1A:W1E<B!I(&QI<W1A;CH@)7,B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C$X"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&EE<F$B
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU,PIM<V=I9"`B0W)E
M871E(@IM<V=S='(@(E-K87!A(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K
M<RYI;F,Z-#`*;7-G:60@(D-R96%T92!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M4VMA<&$@861R97-S8F]K(@H*(SH@;&EB+TQI<W16:65W+G!H<#HS-#@*;7-G
M:60@(D-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@:6XZ(@IM<V=S='(@(E-K
M87!A(&YY(&MO;G1A:W1L:7-T82!I.B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H
M<#HQ,S,*;7-G:60@(D-R96%T960B"FUS9W-T<B`B4VMA<&%D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED(")$969A=6QT('-O<G1I;F<@
M9&ER96-T:6]N.B(*;7-G<W1R(")&]G)V86QD('-O<G1E<FEN9W-R:6MT;FEN
M9SHB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHW-B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,*(SH@;&EB+T]B:F5C="YP:'`Z,S(X
M(&QI8B]296YD97)E<BYP:'`Z-#<@;&EB+U)E;F1E<F5R+G!H<#HU,`IM<V=I
M9"`B1&5L971E(@IM<V=S='(@(E)A9&5R82(*"B,Z('1E;7!L871E<R]A9&1R
M97-S8F]O:W,N:6YC.C4X"FUS9VED(")$96QE=&4@061D<F5S<R!";V]K(@IM
M<V=S='(@(E)A9&5R82!A9')E<W-B;VLB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@*;7-G:60@(D1E;&5T92!#;VYF:7)M871I;VXB"FUS9W-T<B`B
M4F%D97)A(&)E:W+D9G1E;'-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y"FUS9VED(")$96QE=&4@8G5T=&]N(&)E:&%V:6]U<B(*;7-G<W1R(")&
M=6YK=&EO;B!F]G(@:VYA<'!E;B!2861E<F$B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(E)A9&5R:6YG(&UI<W-L>6-K861E<SH@*"5S
M*2`E<R(*"B,Z(&QI8B]$<FEV97(O;G5L;"YP:'`Z-C(*;7-G:60@(D1E;&5T
M:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D9U;FMT
M:6]N96X@<F%D97)A(&MO;G1A:W1E<B#D<B!I;G1E('1I;&QGY&YG;&EG+B(*
M"B,Z(&1E;&5T92YP:'`Z,S@*;7-G:60@(D1E;&5T:6]N(&9A:6QE9"(*;7-G
M<W1R(")2861E<FEN9R!M:7-S;'EC:V%D97,B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HR,3,*;7-G:60@(D1E<&%R=&UE;G0B"FUS9W-T<B`B
M079D96QN:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED
M(")$97-C96YD:6YG(@IM<V=S='(@(D9A;&QA;F1E(@H*(SH@=&5M<&QA=&5S
M+V%D9')E<W-B;V]K<RYI;F,Z,3$U"FUS9VED(")$97-C<FEP=&EO;B(*;7-G
M<W1R(")"97-K<FEV;FEN9R(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H
M+FEN8SHQ,3D*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS9VED(")$:7-P;&%Y(@IM
M<V=S='(@(E9I<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&ES<&QA>2!/
M<'1I;VYS(@IM<V=S='(@(E9I<VYI;F=S:6YS=.1L;&YI;F=A<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D1O('EO=2!W86YT('1O
M(&-O;F9I<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T<B`B5FEL;"!D=2!B
M96MRY&9T82!R861E<FEN9R!A=B!P;W-T97(_(@H*(SH@;&EB+T]B:F5C="YP
M:'`Z,CDW"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R(")(Y&UT82(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O<F]W+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+V-O
M;G1A8W1R;W<N:6YC.C(U"FUS9VED(")$;W=N;&]A9"!V0V%R9"(*;7-G<W1R
M("),861D82!N960@=D-A<F0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L
M871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A
M8W1R;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B
M"FUS9W-T<B`BQ&YD<F$B"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z
M,C4@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R("+$;F1R82`G)7,G
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.#$*;7-G:60@(D5D
M:70@061D<F5S<R!";V]K<R(*;7-G<W1R(")2961I9V5R82!A9')E<W-B]F-K
M97(B"@HC.B!E9&ET+G!H<#HX-2!E9&ET+G!H<#HQ-C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!E;G1R>2!F;W(@)7,B"FUS9W-T<B`BQ&YD<F$@<&]S
M="!F]G(@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU.`IM
M<V=I9"`B16UA:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@961I="YP:'`Z,34T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B
M=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@HB4&]S=&5N(&;V<B`G)7,G('5P<&1A=&5R861E<RP@;65N(&1E;B!U
M<'!L861D861E(&9I;&5N(&MU;F1E(&EN=&4@<W!A<F%S.B`E<R(*"B,Z(&5D
M:70N<&AP.C$U-B!E9&ET+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M16YT<GD@9F]R("5S('5P9&%T960N(@IM<V=S='(@(E!O<W1E;B!F]G(@)7,@
M=7!P9&%T97)A9"XB"@HC.B!B<F]W<V4N<&AP.C(Q-B!B<F]W<V4N<&AP.C(V
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!A9&1I;F<@)60@8V]N=&%C
M="AS*2!T;R!L:7-T+B(*;7-G<W1R(")$970@9VEC:R!I;G1E(&%T="!LY&=G
M82!T:6QL("5D(&MO;G1A:W0H97(I('1I;&P@;&ES=&%N+B(*"B,Z(&)R;W=S
M92YP:'`Z,C$X(&)R;W=S92YP:'`Z,C8V"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&%D9&EN9R`E9"!O9B`E9"!R97%U97-T960@8V]N=&%C="AS*2!T
M;R!L:7-T+B(*;7-G<W1R(")$970@9VEC:R!I;G1E(&%T="!LY&=G82!T:6QL
M("5D(&%V("5D(&)E9^1R9&$@:V]N=&%K=&5R('1I;&P@;&ES=&%N+B(*"B,Z
M(&)R;W=S92YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L
M971I;F<@)60@8V]N=&%C="AS*2XB"FUS9W-T<B`B1F5L('9I9"!R861E<FEN
M9R!A=B`E9"!K;VYT86MT*&5R*2XB"@HC.B!B<F]W<V4N<&AP.C@X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG("5D(&]F("5D(')E<75E
M<W1E9"!C;VYT86-T<RAS*2XB"FUS9W-T<B`B1F5L('9I9"!R861E<FEN9R!A
M=B`E9"!A=B`E9"!B96?D<F1A(&MO;G1A:W1E<BXB"@HC.B!B<F]W<V4N<&AP
M.C8V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(')E;6]V:6YG("5D(&-O
M;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G<W1R(")&96P@=FED(')A9&5R:6YG
M(&%V("5D(&MO;G1A:W0H97(I(&9RY6X@;&ES=&%N+B(*"B,Z(&)R;W=S92YP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<F5M;W9I;F<@)60@
M;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@9G)O;2!L:7-T+B(*;7-G<W1R
M(")&96P@=FED(')A9&5R:6YG(&%V("5D(&%V("5D(&MO;G1A:W1E<B!F<N5N
M(&QI<W1A;BXB"@HC.B!L:6(O87!I+G!H<#HT,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@<V5A<F-H:6YG('1H92!A9&1R97-S(&)O;VLZ("5S(@IM
M<V=S='(@(D9E;"!V:60@<_9K;FEN9R!I(&%D<F5S<V)O:V5N.B`E<R(*"B,Z
M('1E;7!L871E<R]M:6YI=VEN9&]W+VUE;G4N:6YC.C$*;7-G:60@(D5X:70@
M061D<F5S<R!";V]K(@IM<V=S='(@(DSD;6YA(&%D<F5S<V)O:R(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O
M97AP;W)T+FEN8SHT,0IM<V=I9"`B17AP;W)T(@IM<V=S='(@(D5X<&]R=&5R
M82(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z-@IM<V=I9"`B17AP
M;W)T($%D9')E<W,@0F]O:R(*;7-G<W1R(")%>'!O<G1E<F$@861R97-S8F]K
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR,0IM<V=I9"`B17AP
M;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+B(*;7-G<W1R(")%>'!O
M<G1E<F$@96YD87-T(&UA<FME<F%D92!K;VYT86MT97(N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP;W)T('1H92!F;VQL
M;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM<V=S='(@(D5X<&]R
M=&5R82!A;&QA(&MO;G1A:W1E<B!I(&%D<F5S<V)O:V5N+B(*"B,Z(&1A=&$N
M<&AP.C$S-"!D871A+G!H<#HR,C@@9&%T82YP:'`Z,CDW(&)R;W=S92YP:'`Z
M,S4@8G)O=W-E+G!H<#HQ,#,*(SH@8G)O=W-E+G!H<#HQ,S`@861D+G!H<#HV
M-R!S96%R8V@N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`B1F5L('9I
M9"#E=&MO;7-T(&%V(&%D<F5S<V)O:V5N.B`E<R(*"B,Z(&)R;W=S92YP:'`Z
M,34X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@)7,@=&\@
M)7,Z("5S(@IM<V=S='(@(DUI<W-L>6-K861E<R!A='0@;.1G9V$@=&EL;"`E
M<R!T:6QL("5S.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,S`U"FUS9VED(")&86EL
M960@=&\@8G)O=W-E(&QI<W0B"FUS9W-T<B`B36ES<VQY8VMA9&5S(&%T="!V
M:7-A(&QI<W1A;B(*"B,Z(&)R;W=S92YP:'`Z,S0S"FUS9VED(")&86EL960@
M=&\@8G)O=W-E('1H92!D:7)E8W1O<GDB"FUS9W-T<B`B36ES<VQY8VMA9&5S
M(&%T="!V:7-A(&MA=&%L;V=E;B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,S`Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C:&%N9V4@;F%M
M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T(#T@
M)7,B"FUS9W-T<B`B(@HB36ES<VQY8VMA9&5S(&%T="#D;F1R82!N86UN.B`H
M)7,I("5S.R!'86UM86QT($1.(#T@)7,L($YY='0@1$X@/2`E<RP@4F]O="`]
M("4B"B)S(@H*(SH@8G)O=W-E+G!H<#HQ,S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&9I;F0@;V)J96-T('1O(&)E(&%D9&5D.B`E<R(*;7-G
M<W1R(")(:71T861E(&EN=&4@;V)J96MT('-O;2!S:W5L;&4@;.1G9V%S('1I
M;&PZ("5S(@H*(SH@<V5A<F-H+G!H<#HW.0IM<V=I9"`B1F%I;&5D('1O('-E
M87)C:"!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(D9E;"!V:60@<_9K;FEN
M9R!I(&%D<F5S<V)O:V5N(@H*(SH@9&%T82YP:'`Z,30Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I<F5C=&]R>3H@)7,B
M"FUS9W-T<B`B36ES<VQY8VMA9&5S(&%T="!S]FMA(&D@:V%T86QO9V5N.B`E
M<R(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$V-PIM<V=I9"`B
M1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&5D:70N<&AP.C$S,2!D:7-P;&%Y+G!H
M<#HQ,#`*;7-G:60@(D9I;&5S(@IM<V=S='(@(D9I;&5R(@H*(SH@=&5M<&QA
M=&5S+V%D9&QI;FLO8V]N=&%C=',N:6YC.C<W('1E;7!L871E<R]B<F]W<V4O
M<V5A<F-H+FEN8SHW,0IM<V=I9"`B1FEN9"(*;7-G<W1R(")3]FLB"@HC.B!E
M9&ET+G!H<#HQ,#0@961I="YP:'`Z,3DT"FUS9VED(")&:6YI<V@B"FUS9W-T
M<B`B4VQU=&;V<B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0X
M"FUS9VED(")&:7)S="!.86UE(@IM<V=S='(@(D;V<FYA;6XB"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,#(*;7-G:60@(D9R965B=7-Y(%52
M3"(*;7-G<W1R("),961I9R]U<'!T86=E;BU54DPB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+W-E87)C:"YI;F,Z.#0*;7-G:60@(D9R;VTB"FUS9W-T<B`B1G+E
M;B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C8P-@IM<V=I9"`B1VQO
M8F%L($%D9')E<W,@0F]O:R(*;7-G<W1R(")';&]B86P@861R97-S8F]K(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C0S('1E;7!L871E<R]B<F]W
M<V4O8V]N=&%C=')O=RYI;F,Z-#0*;7-G:60@(D=R;W5P(@IM<V=S='(@(D=R
M=7!P(@H*(SH@=&5M<&QA=&5S+V%D9&QI;FLO;65N=2YI;F,Z,C,*;7-G:60@
M(DAE;'`B"FUS9W-T<B`B2&KD;'`B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HX,@IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S
M<RP@:&5M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3,*;7-G
M:60@(DAO;64@0VET>2(*;7-G<W1R(")/<G0L(&AE;2(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$P.`IM<V=I9"`B2&]M92!#;W5N=')Y(@IM
M<V=S='(@(DQA;F0L(&AE;2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$U,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE9F]N+"!H
M96TB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*;7-G:60@
M(DAO;64@4&]S=&%L($-O9&4B"FUS9W-T<B`B4&]S=&YR+"!H96TB"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`IM<V=I9"`B2&]M92!3=&%T
M92]0<F]V:6YC92(*;7-G<W1R(")296=I;VXL(&AE;2(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C@X"FUS9VED(")(;VUE(%-T<F5E="!!9&1R
M97-S(@IM<V=S='(@(D=A='5A9')E<W,L(&AE;2(*"B,Z(&-O;F9I9R]S;W5R
M8V5S+G!H<"YD:7-T.C4P.`IM<V=I9"`B24U34"(*;7-G<W1R("))35-0(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W"FUS9VED("))35-0($%D9')E
M<W,@0F]O:R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO
M;B!A=B!)35-0+6%D<F5S<V)O:R(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R
M="YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@061D<F5S<R!"
M;V]K+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&5R82!A9')E<W-B;VLL('-T
M96<@)60B"@HC.B!D871A+G!H<#HS-C$*;7-G:60@(DEM<&]R="]%>'!O<G0@
M061D<F5S<R!";V]K<R(*;7-G<W1R("));7!O<G1E<F$O17AP;W)T97)A(&%D
M<F5S<V+V8VME<B(*"B,Z(&QI8B]A<&DN<&AP.C8Q-"!L:6(O87!I+G!H<#HW
M,#$*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`B1F5L86MT:6=T($E$(@H*
M(SH@;&EB+V%P:2YP:'`Z,C,R(&QI8B]A<&DN<&AP.C0P-"!L:6(O87!I+G!H
M<#HT.#@@;&EB+V%P:2YP:'`Z-C$P"B,Z(&QI8B]A<&DN<&AP.C8Y-R!L:6(O
M87!I+G!H<#HW-#D@;&EB+V%P:2YP:'`Z,3$P.`IM<V=I9"`B26YV86QI9"!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B1F5L86MT:6<@861R97-S8F]K(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$Q,B!L:6(O87!I+G!H<#HQ,3@U(&QI8B]A<&DN<&AP
M.C$R,S@*;7-G:60@(DEN=F%L:60@96UA:6PB"FUS9W-T<B`B3V=I;'1I9R!E
M+7!O<W1A9')E<W,B"@HC.B!L:6(O87!I+G!H<#HQ,3(P"FUS9VED("));G9A
M;&ED(&5N=')Y(@IM<V=S='(@(D9E;&%K=&EG="!VY')D92(*"B,Z(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z,C8V"FUS9VED("));G9A;&ED(&ME>2!S<&5C:69I
M960N(@IM<V=S='(@(D9E;&%K=&EG(&YY8VME;"!A;F=I=F5N+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$Q,38*;7-G:60@(DEN=F%L:60@;F%M92(*;7-G<W1R(")&
M96QA:W1I9W0@;F%M;B(*"B,Z(&QI8B]A<&DN<&AP.C<U,PIM<V=I9"`B26YV
M86QI9"!O8FIE8W1)9"(*;7-G<W1R(")&96QA:W1I9W0@;V)J96MT260B"@HC
M.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P"FUS9VED("(B"B),1$%0('-U<'!O
M<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0(&UO9'5L92!I<R!N;W0@879A
M:6QA8FQE(&]R(&YO="!L;V%D960N(@IM<V=S='(@(DQ$05`M<W3V9"!K<N1V
M<RP@;65N($Q$05`M;6]D=6QE;B#D<B!I;G1E('1I;&QGY&YG;&EG(&5L;&5R
M(&QA9&1A9"XB"@HC.B!L:6(O3V)J96-T5FEE=RYP:'`Z,3,X"FUS9VED("),
M87-T($UO9&EF:65D(@IM<V=S='(@(E-E;F%S="#D;F1R860B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HU,PIM<V=I9"`B3&%S="!.86UE(@IM
M<V=S='(@(D5F=&5R;F%M;B(*"B,Z(&%D9&QI;FLN<&AP.C4U"FUS9VED("),
M:6YK(&%D9&5D+B(*;7-G<W1R("),Y&YK(&QA9&5S('1I;&PN(@H*(SH@861D
M;&EN:RYP:'`Z-C0*;7-G:60@(DQI;FL@8V%N8V5L960N(@IM<V=S='(@(DSD
M;FL@879B<G5T96XN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A
M9&5R<RYI;F,Z,38*;7-G:60@(DQI<W0B"FUS9W-T<B`B3&ES=&$B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S@*;7-G:60@(DUA=&-H:6YG
M(@IM<V=S='(@(DUA=&-H87(B"@HC.B!L:6(O87!I+G!H<#HR,#<*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S(@IM<V=S='(@(DUA>&EM86QT
M(&%N=&%L(&MO;G1A:W1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F('!A9V5S(@IM<V=S='(@(DUA
M>&EM86QT(&%N=&%L('-I9&]R(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP
M:'`Z,PIM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(DUE;GEL:7-T82(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`R"FUS9VED(")-:7-S:6YG($1.(&EN
M($Q$05`@<V]U<F-E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E-A:VYA<B!$
M3B!I($Q$05`M:V]N9FEG=7)A=&EO;F5N+B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$V,@IM<V=I9"`B36]B:6QE(%!H;VYE(@IM<V=S='(@
M(DUO8FEL=&5L969O;B(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S,R(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@(DUO
M9&EF>2!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`BQ&YD<FEN9R!M:7-S;'EC
M:V%D97,Z("@E<RD@)7,B"@HC.B!L:6(O87!I+G!H<#HQ,C(T"FUS9VED(")-
M;W)E('1H86X@,2!E;G1R>2!F;W5N9"(*;7-G<W1R(")-97(@Y&X@,2!P;W-T
M(&AI='1A9&5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ
M-@IM<V=I9"`B36]V92(*;7-G<W1R(")&;'ET=&$B"@HC.B!T96UP;&%T97,O
M<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S+W!R969S
M+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*;7-G:60@(DUO=F4@;&5F="(*
M;7-G<W1R(")&;'ET=&$@=N1N<W1E<B(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(T.0HC.B!T96UP;&%T97,O<')E9G,O861D<F5S
M<V)O;VMS96QE8W0N:6YC.C$X-@IM<V=I9"`B36]V92!R:6=H="(*;7-G<W1R
M(")&;'ET=&$@:/9G97(B"@HC.B!D871A+G!H<#HU,B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$V"FUS9VED(")-=6QB97)R>2!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B375L8F5R<GDB"@HC.B!L:6(O87!I+G!H<#HQ,30T"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(DUU;'1I<&QE('!E<G-O;G,@=VET:"!A9&1R
M97-S(%LE<UTL(&)U="!N;VYE('=I=&@@;F%M92!;)7-=(&%L<F5A9'D@97AI
M<W0B"FUS9W-T<B`B1FQE<F$@<&5R<V]N97(@;65D(&%D<F5S<V5N(%LE<UTL
M(&UE;B!I;F=E;B!M960@;F%M;F5T(%LE<UT@97AI<W1E<F%R(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3`W(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C(T,PIM<V=I9"`B37D@061D<F5S<R!";V]K(@IM<V=S='(@(DUI;B!A
M9')E<W-B;VLB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C$Q.0IM<V=I9"`B37D@
M061D<F5S<R!";V]K<R(*;7-G<W1R(")-:6YA(&%D<F5S<V+V8VME<B(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HT,@IM<V=I9"`B3F%M92(*;7-G<W1R(").86UN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED(").86UE($9O<FUA
M="(*;7-G<W1R(").86UN9F]R;6%T97)I;F<B"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HS,34*;7-G:60@(DYE=&-E;G1E<B!-96UB97(@1&ER96-T
M;W)Y(@IM<V=S='(@(DYE=&-E;G1E<B!M961L96US:V%T86QO9R(*"B,Z(&%D
M9"YP:'`Z,S8@861D+G!H<#HQ,C0@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z
M,C<*;7-G:60@(DYE=R!#;VYT86-T(@IM<V=S='(@(DYY(&MO;G1A:W0B"@HC
M.B!E9&ET+G!H<#HY-2!E9&ET+G!H<#HQ,#(@961I="YP:'`Z,C`Y('1E;7!L
M871E<R]D871A+VEM<&]R="YI;F,Z-#4*;7-G:60@(DYE>'0B"FUS9W-T<B`B
M3N1S=&$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,3@*;7-G
M:60@(DYI8VMN86UE(@IM<V=S='(@(E-M96MN86UN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(R-B!L:6(O87!I+G!H<#HQ,C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(DYO("5S(&5N=')Y(&9O=6YD(&9O<B`E<R(*;7-G<W1R(")0;W-T("5S('-A
M:VYA<R!F]G(@)7,B"@HC.B!L:6(O87!I+G!H<#HQ,3DT"FUS9VED(").;R!A
M9&1R97-S(&)O;VMS(&9O=6YD+B(*;7-G<W1R("));F=E;B!A9')E<W-B;VL@
M:&ET=&%D97,N(@H*(SH@;6EN:7-E87)C:"YP:'`Z.#$*;7-G:60@(DYO(&-O
M;G1A8W1S(&9O=6YD(@IM<V=S='(@(DEN9V$@:V]N=&%K=&5R(&AI='1A9&5S
M+B(*"B,Z(&QI8B]A<&DN<&AP.C4Q,R!L:6(O87!I+G!H<#HW.#0*;7-G:60@
M(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R("));F=E;B!V0V%R
M9"UI;F9O<FUA=&EO;B!H:71T861E<RXB"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V9O;W1E<BYI;F,Z-PIM<V=I9"`B3F]N92(*;7-G<W1R("));F=A(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3@T"FUS9VED(").;W1E<R(*
M;7-G<W1R(")!;G1E8VMN:6YG87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$U"FUS9VED(").=6UB97(@;V8@:71E;7,@<&5R('!A9V4B"FUS9W-T
M<B`B06YT86P@<&]S=&5R('!E<B!S:61A(@H*(SH@;&EB+V%P:2YP:'`Z-C,R
M(&QI8B]A<&DN<&AP.C<V-0IM<V=I9"`B3V)J96-T(&YO="!F;W5N9"(*;7-G
M<W1R(")/8FIE:W1E="!H:71T861E<R!I;G1E(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,C(S"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2V]N
M=&]R(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHR,@IM<V=I
M9"`B(@HB3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D
M<F5S<R!B;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"X@268@
M=&AI<R!I<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N
M9V4@>6]U<B!S96QE8W1I;VX@(@HB=&\@7").;VYE7"(N(@IM<V=S='(@(B(*
M(D[D<B!D=2!S<&%R87(@9&5N;F$@<VED82!M960@:6YS=.1L;&YI;F=A<BP@
M<^4@:V]M;65R(&%D<F5S<V)O:V5N(&%T="`B"B)R861E<F%S+B!/;2!D971T
M82!I;G1E(.1R('9A9"!D=2!V:6QL(.5S=&%K;VUM82!SY2!MY7-T92!D=2#D
M;F1R82!D:71T('9A;"`B"B)T:6QL("=);F=E;B<N(@H*(SH@;&EB+V%P:2YP
M:'`Z-SDR"FUS9VED(")/;FQY(&]N92!V8V%R9"!S=7!P;W)T960N(@IM<V=S
M='(@(D5N9&%S="!E='0@=D-A<F0@<W3V9',N(@H*(SH@=&5M<&QA=&5S+V%D
M9&QI;FLO;65N=2YI;F,Z,3,*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B26YS
M=.1L;&YI;F=A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS
M9W-T<B`B06YD<F$@:6YS=.1L;&YI;F=A<B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T
M<B`B4'5B;&EK(%!'4"UN>6-K96PB"@HC.B!L:6(O87!I+G!H<#HT.3<@;&EB
M+V%P:2YP:'`Z-C(S(&QI8B]A<&DN<&AP.C<Q,"!L:6(O87!I+G!H<#HY-C4*
M(SH@;&EB+V%P:2YP:'`Z,3$R.0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`BQ71K;VUS="!N96MA9"(*"B,Z(&QI8B]$<FEV97(N<&AP.C4U
M,`IM<V=I9"`B4&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`BQ71K;VUS="!N
M96MA9"(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDY"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R(")"96CV<FEG:&5T97(B"@HC.B!D871A
M+G!H<#HU,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")0
M:6YE($%D9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE(&%D<F5S<V)O:R(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z,C@*;7-G:60@(E!L
M96%S92!N86UE('1H92!N97<@8V]N=&%C="!L:7-T.B(*;7-G<W1R(")3:W)I
M=B!I;B!E='0@;F%M;B!PY2!D96X@;GEA(&MO;G1A:W1L:7-T86XZ(@H*(SH@
M=&5M<&QA=&5S+V%D9&QI;FLO8V]N=&%C=',N:6YC.CDV"FUS9VED(")0;&5A
M<V4@<V5L96-T(&-O;G1A8W0B"FUS9W-T<B`B5F%R(&=O9"!VY&QJ(&MO;G1A
M:W0B"@HC.B!E9&ET+G!H<#HY."!E9&ET+G!H<#HQ,#$@961I="YP:'`Z,C`Q
M"FUS9VED(")0<F5V:6]U<R(*;7-G<W1R(")&]G)E9^5E;F1E(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z-#$V"FUS9VED(")0<FEV871E($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")0<FEV870@861R97-S8F]K(@H*(SH@=&5M<&QA
M=&5S+V%D9&QI;FLO;65N=2YI;F,Z,3@*;7-G:60@(E!R;V)L96TB"FUS9W-T
M<B`B4')O8FQE;2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,30W"B,L('!H
M<"UF;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R
M(")3]FMN:6YG(&UI<W-L>6-K861E<SH@*"5S*2`E<R(*"B,Z('1E;7!L871E
M<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHQ.`IM<V=I9"`B475I8VL@4V5A<F-H
M(@IM<V=S='(@(E-N86)B<_9K(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HQ
M.3$@;&EB+T1R:79E<B]L9&%P+G!H<#HQ.3D@;&EB+T1R:79E<B]L9&%P+G!H
M<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A9"!F86EL960Z("@E<RD@
M)7,B"FUS9W-T<B`B3.1S;FEN9R!M:7-S;'EC:V%D97,Z("@E<RD@)7,B"@HC
M.B!L:6(O1')I=F5R+VYU;&PN<&AP.C4R"FUS9VED(")296%D:6YG(&-O;G1A
M8W1S(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D9U;FMT:6]N96X@871T
M(&SD<V$@:V]N=&%K=&5R(.1R(&EN=&4@=&EL;&?D;F=L:6<N(@H*(SH@;&EB
M+U)E;F1E<F5R+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O
M;G1A8W0_(@IM<V=S='(@(E)A9&5R82!D96X@:.1R(&MO;G1A:W1E;C\B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D
M<R!D:7-P;&%Y960Z(@IM<V=S='(@(E!O<W1E<B!V:7-A9&4Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S8*;7-G:60@
M(E)E;6]V92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B4F%D97)A(&%D<F5S<V)O
M:R(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S.0IM
M<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")482!B;W)T(&MO;'5M;B(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,PIM<V=I9"`B4F5M
M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(E1A(&)O<G0@9G+E;B!A:W1U
M96QL(&QI<W1A(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0IM
M<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T
M:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L
M971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K
M+CPO<W1R;VYG/B(*;7-G<W1R("(B"B)%<G/D='0@8F5F:6YT;&EG(&%D<F5S
M<V)O:R!M960@9&5N(&EM<&]R=&5R861E/R`\<W1R;VYG/E9A<FYI;F<Z($%L
M;&$@<&]S=&5R("(*(FD@86MT=65L;"!A9')E<W-B;VL@:V]M;65R(&%T="!R
M861E<F%S+CPO<W1R;VYG/B(*"B,Z(&QI8B]3;W5R8V4N<&AP.C(X,B!L:6(O
M1')I=F5R+G!H<#HT,S@*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O
M=6YD+B(*;7-G<W1R(")%9G1E<F9RY6=A="!O8FIE:W0@<V%K;F%S+B(*"B,Z
M(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q-`IM
M<V=I9"`B4F5S970@=&\@1&5F875L=',B"FUS9W-T<B`BQ71E<G-TY&QL('1I
M;&P@9W)U;F1I;G-TY&QL;FEN9V%R(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3DV"FUS9VED(")3+TU)344@4'5B;&EC($-E<G1I9FEC871E
M(@IM<V=S='(@(E!U8FQI:W0@4R]-24U%+6-E<G1I9FEK870B"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-405)4
M5$Q3(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R(")35$%25%1,4R!M:7-S;'EC
M:V%D97,Z("@E<RD@)7,B"@HC.B!E9&ET+G!H<#HQ,#8@861D+G!H<#HS-R!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,C0*;7-G:60@(E-A=F4B"FUS
M9W-T<B`B4W!A<F$B"@HC.B!L:6(O1')I=F5R+VYU;&PN<&AP.C8W"FUS9VED
M(")3879I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M1G5N:W1I;VYE;B!A='0@<W!A<F$@:V]N=&%K=&5R(.1R(&EN=&4@=&EL;&?D
M;F=L:6<N(@H*(SH@=&5M<&QA=&5S+V%D9&QI;FLO8V]N=&%C=',N:6YC.C@Y
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-PHC.B!T96UP;&%T97,O
M8G)O=W-E+W-E87)C:"YI;F,Z,3$S('1E;7!L871E<R]B;&]C:R]M:6YI<V5A
M<F-H+FEN8SHR,0HC.B!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HT.2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B"FUS9W-T<B`B
M4_9K(@H*(SH@;&EB+V%P:2YP:'`Z,3`T,@IM<V=I9"`B4V5A<F-H(&9A:6QE
M9"(*;7-G<W1R(")3]FMN:6YG(&UI<W-L>6-K861E<R(*"B,Z(&QI8B]A<&DN
M<&AP.C$Q,S0@;&EB+V%P:2YP:'`Z,3$T,"!L:6(O87!I+G!H<#HQ,30Y(&QI
M8B]A<&DN<&AP.C$Q-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B4_9K;FEN9R!M:7-S;'EC:V%D97,Z("5S(@H*
M(SH@;&EB+T1R:79E<B]N=6QL+G!H<#HT-PIM<V=I9"`B4V5A<F-H:6YG(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D9U;FMT:6]N96X@871T('/V:V$@
MY'(@:6YT92!T:6QL9^1N9VQI9RXB"@HC.B!T96UP;&%T97,O8FQO8VLO;6EN
M:7-E87)C:"YI;F,Z,C(*;7-G:60@(E-E87)C:&EN9RXN+B(*;7-G<W1R(")3
M]FME<BXN+B(*"B,Z('1E;7!L871E<R]A9&1L:6YK+V-O;G1A8W1S+FEN8SHQ
M,C8*;7-G:60@(E-E;&5C="(*;7-G<W1R(")6Y&QJ(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]S96QE8W0N:6YC.CD*;7-G:60@(E-E;&5C="!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B5N1L:B!A9')E<W-B;VLB"@HC.B!T96UP;&%T97,O861D
M<F5S<V)O;VMS+FEN8SHV-@IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O
M:R!T;R!D96QE=&4B"FUS9W-T<B`B5N1L:B!A9')E<W-B;VL@<V]M('-K86QL
M(')A9&5R87,B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY,`IM
M<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!E9&ET(@IM<V=S='(@
M(E;D;&H@861R97-S8F]K(&%T="!R961I9V5R82(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,S(*;7-G:60@(E-E;&5C="!T:&4@861D<F5S<R!B
M;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G<W1R(")6Y&QJ(&%D<F5S<V)O:R!A
M='0@97AP;W)T97)A(&9RY6XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHR-@IM<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP
M;W)T('1O.B(*;7-G<W1R(")6Y&QJ(&%D<F5S<V)O:R!A='0@:6UP;W)T97)A
M('1I;&PZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0IM<V=I
M9"`B4V5L96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB"FUS
M9W-T<B`B5N1L:B!T96-K96YU<'!SY'1T;FEN9R!PY2!I;7!O<G1F:6QE;CHB
M"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$P"FUS9VED(")396QE
M8W0@=&AE(&5X<&]R="!F;W)M870Z(@IM<V=S='(@(E;D;&H@97AP;W)T9F]R
M;6%T.B(*"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#,*;7-G:60@
M(E-E;&5C="!T:&4@9FEL92!T;R!I;7!O<G0Z(@IM<V=S='(@(E;D;&H@9FEL
M('-O;2!S:V%L;"!I;7!O<G1E<F%S.B(*"B,Z('1E;7!L871E<R]D871A+VEM
M<&]R="YI;F,Z,3$*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T(&]F('1H92!S
M;W5R8V4@9FEL93HB"FUS9W-T<B`B5N1L:B!F;W)M870@<.4@:6UP;W)T9FEL
M96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L
M96-T('1H92!F;W)M870@=7-E9"!T;R!D:7-P;&%Y(&YA;65S.B(*;7-G<W1R
M(")6Y&QJ(&9O<FUA="!F]G(@=FES;FEN9R!A=B!N86UN.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES
M<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T
M:6]N<RXB"FUS9W-T<B`B5N1L:B!S=&%N9&%R9'9Y+"!S;W)T97)I;F=S+2!O
M8V@@<VED:6YS=.1L;&YI;F=A<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3@*;7-G:60@(E-E;&5C="!W:&EC:"!F:65L9',@=&\@9&ES<&QA>2!I
M;B!T:&4@861D<F5S<R!L:7-T<RXB"FUS9W-T<B`B5N1L:B!V:6QK82!FY&QT
M('-O;2!V:7-A<R!I(&%D<F5S<VQI<W1A;BXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S(*;7-G:60@(E-E;&5C="!W:&EC:"!F;W)M870@=&\@9&ES
M<&QA>2!N86UE<RXB"FUS9W-T<B`B5N1L:B!H=7(@;F%M;B!V:7-A<RXB"@HC
M.B!A9&0N<&AP.C4T"B,L('!H<"UF;W)M870*;7-G:60@(E-E;&5C=&5D(&%D
M9')E<W,@8F]O:R!<(B5S7"(N(@IM<V=S='(@(E9A;&0@861R97-S8F]K("<E
M<R<N(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,3<S"FUS9VED(")3
M:&%R960@1&ER96-T;W)Y(@IM<V=S='(@(D1E;&%D(&MA=&%L;V<B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E;&5C="YI;F,Z,3$*;7-G:60@(E-H;W<B"FUS
M9W-T<B`B5FES82(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R`E<R(*;7-G<W1R(")6:7-A
M("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT.`IM<V=I
M9"`B4VAO=R!!;&PB"FUS9W-T<B`B5FES82!A;&QA(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHT-PIM<V=I9"`B4VAO=R!#;VYT86-T<R(*
M;7-G<W1R(")6:7-A(&MO;G1A:W1E<B(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z-#8*;7-G:60@(E-H;W<@3&ES=',B"FUS9W-T<B`B5FES
M82!L:7-T;W(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHR,0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN
M8SHS-@IM<V=I9"`B4V]R="!$:7)E8W1I;VXB"FUS9W-T<B`B4V]R=&5R:6YG
M<W)I:W1N:6YG(@H*(SH@;&EB+V%P:2YP:'`Z,C`P"FUS9VED(")3;W5R8V5S
M(@IM<V=S='(@(DOD;&QO<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-3@*;7-G:60@(E-P96-I9GD@=VAE<F4@>6]U('=A;G0@861V86YC960@<V5A
M<F-H(')E<W5L=',@=&\@87!P96%R+B(*;7-G<W1R(")!;F=E('9A<B!R97-U
M;'1A="!F<N5N(&%V86YC97)A9"!S]FMN:6YG('-K86QL('9I<V%S+B(*"B,Z
M(&)R;W=S92YP:'`Z,C$T(&)R;W=S92YP:'`Z,C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`E9"!C;VYT86-T*',I('1O(&QI
M<W0N(@IM<V=S='(@(DQA9&4@=&EL;"`E9"!K;VYT86MT*&5R*2!T:6QL(&QI
M<W1A;BXB"@HC.B!B<F]W<V4N<&AP.C$V,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@861D960@)7,@=&\@)7,B"FUS9W-T<B`B)7,@;&%D
M97,@=&EL;"!I("5S(@H*(SH@8G)O=W-E+G!H<#HR-#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A8W0@;&ES
M="!<(B5S7"(N(@IM<V=S='(@(E-K87!A9&4@:V]N=&%K=&QI<W1A;B`G)7,G
M+B(*"B,Z(&)R;W=S92YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&1E;&5T960@)60@8V]N=&%C="AS*2XB"FUS9W-T<B`B4F%D
M97)A9&4@)60@:V]N=&%K="AE<BDN(@H*(SH@8G)O=W-E+G!H<#HV-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"`E9"!C;VYT
M86-T*',I(&9R;VT@;&ES="XB"FUS9W-T<B`B4F%D97)A9&4@)60@:V]N=&%K
M="AE<BD@9G+E;B!L:7-T86XN(@H*(SH@9&%T82YP:'`Z-3`*;7-G:60@(E13
M5B(*;7-G<W1R(")44U8B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,30*;7-G:60@(E1A8B!S
M97!A<F%T960@=F%L=65S(@IM<V=S='(@(E1A8G-E<&%R97)A9&4@=N1R9&5N
M(@H*(SH@=FEE=RYP:'`Z,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D
M<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A
M9',N(@IM<V=S='(@(B(*(E9&4RUB86-K96YD(&)E:/9V97(@:V]N9FEG=7)E
M<F%S(&;V<B!A='0@86MT:79E<F$@=7!P;&%D9&YI;F<@878@8FEL86=O<BXB
M"@HC.B!L:6(O1')I=F5R+G!H<#HQ,#<V"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!A9&1R97-S(&)O;VL@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R(")!9')E<W-B;VL@)R5S)R!F:6YN<R!I;G1E+B(*"B,Z(&%D9')E<W-B
M;V]K<RYP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@
M8F]O:R!<(B5S7"(@=V%S(&-R96%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M(")!9')E<W-B;VME;B`G)7,G('-K87!A9&5S+B(*"B,Z(&%D9')E<W-B;V]K
M<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O
M:R!<(B5S7"(@=V%S(')E;6]V960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!
M9')E<W-B;VME;B`G)7,G(')A9&5R861E<RXB"@HC.B!A9&1R97-S8F]O:W,N
M<&AP.C@Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B061R
M97-S8F]K96X@)R5S)R!U<'!D871E<F%D97,N(@H*(SH@9&%T82YP:'`Z,S`S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@8V]U;&0@
M;F]T(&)E('!U<F=E9#H@)7,B"FUS9W-T<B`B061R97-S8F]K96X@:W5N9&4@
M:6YT92!T]FUM87,Z("5S(@H*(SH@961I="YP:'`Z-3$@=F-A<F0N<&AP.C(R
M(&1I<W!L87DN<&AP.C(S('9I97<N<&AP.C(V"FUS9VED(")4:&4@8V]N=&%C
M="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")+;VYT
M86MT96X@9'4@<_9K97(@9FEN;G,@:6YT92XB"@HC.B!E9&ET+G!H<#HQ,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@7"(E<UPB(&AA<R!S=6-C
M97-S9G5L;'D@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")&:6QE;B`G)7,G(')A
M9&5R861E<RXB"@HC.B!D871A+G!H<#HR.#0*;7-G:60@(E1H92!I;7!O<G0@
M8V%N(&)E(&9I;FES:&5D(&1E<W!I=&4@=&AE('=A<FYI;F=S+B(*;7-G<W1R
M("));7!O<G1E;B!K86X@879S;'5T87,@=')O=',@=F%R;FEN9V%R+B(*"B,Z
M(&)R;W=S92YP:'`Z,S$*;7-G:60@(E1H97)E(&%R92!N;R!B<F]W<V5A8FQE
M(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@(D1E="!F:6YN<R!I;F=A(&%D<F5S
M<V+V8VME<B!A='0@=FES82XB"@HC.B!A9&0N<&AP.C(Y"FUS9VED("(B"B)4
M:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D9')E<W,@8F]O:W,N($YO;F4@;V8@
M=&AE(&%V86EL86)L92!A9&1R97-S(&)O;VMS("(*(F%R92!C;VYF:6=U<F5D
M('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W(&5N=')I97,@=&\@=&AE;2X@268@
M>6]U(&)E;&EE=F4@=&AI<R`B"B)I<R!A;B!E<G)O<BP@<&QE87-E(&-O;G1A
M8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB26YG
M96X@878@9&4@=&EL;&?D;F=L:6=A(&%D<F5S<V+V8VME<FYA(.1R(&MO;F9I
M9W5R97)A9&4@<^4@871T(&1U(&;E<B!LY&=G82`B"B)T:6QL(&MO;G1A:W1E
M<B!I(&1E;2P@3VT@9'4@=')O<B!A='0@9&5T(.1R(&5T="!F96PL(&MO;G1A
M:W1A(&1I;B!S>7-T96T@(@HB861M:6YI<W1R873V<BXB"@HC.B!A9&0N<&AP
M.C$R,0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@
M;F5W(&-O;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<B`B"B)F;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)$970@=7!P<W1O
M9"!P<F]B;&5M("!NY'(@:V]N=&%K=&5N('-K=6QL92!LY&=G87,@=&EL;"X@
M2V]N=&%K=&$@9&EN("(*(G-Y<W1E;6%D;6EN:7-T<F%T]G(@9O9R('ET=&5R
M;&EG87)E(&AJY&QP+B(*"B,Z(&)R;W=S92YP:'`Z,C<Q"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="XB"FUS9W-T<B`B
M1&5T('5P<'-T;V0@9F5L('9I9"!S:V%P86YD92!A=B!N>2!L:7-T82XB"@HC
M.B!A9&1R97-S8F]O:W,N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@
M)7,B"FUS9W-T<B`B1F5L('5P<'-T;V0@;N1R(&%D<F5S<V)O:V5N("<E<R<@
M<VMU;&QE('-K87!A<RXB"@HC.B!B<F]W<V4N<&AP.C$V-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@7"(E<UPB
M(&9R;VT@=&AE('-O=7)C92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D1E="!U
M<'!S=&]D(&9E;"!V:60@<F%D97)I;F<@878@)7,@9G+E;B!A9')E<W-B;VME
M;BXB"@HC.B!D96QE=&4N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&-O;G1A8W0Z("5S(@IM
M<V=S='(@(D1E="!U<'!S=&]D(&9E;"!V:60@<F%D97)I;F<@878@:V]N=&%K
M=&5N.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,S$Q"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&4@;&ES="(*;7-G<W1R(")$970@=7!P
M<W1O9"!F96P@=FED('9I<VYI;F<@878@;&ES=&%N(@H*(SH@9&%T82YP:'`Z
M,S,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S='(@(D1E="!U<'!S=&]D(&9E
M;"!V:60@:6UP;W)T(&%V(&1A=&$Z("5S+B(*"B,Z(&QI8B]A<&DN<&AP.C4P
M.2!L:6(O87!I+G!H<#HW-SD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")&96P@=FED
M(&EM<&]R="!A=B!I0V%L96YD87(M9&%T82XB"@HC.B!A9&1R97-S8F]O:W,N
M<&AP.C4X(&%D9')E<W-B;V]K<RYP:'`Z-C,@861D<F5S<V)O;VMS+G!H<#HV
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<F5M
M;W9I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D1E="!U<'!S
M=&]D(&9E;"!V:60@<F%D97)I;F<@878@861R97-S8F]K96XZ("5S(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S
M(@IM<V=S='(@(D1E="!U<'!S=&]D(&9E;"!V:60@=7!P9&%T97)I;F<@878@
M861R97-S8F]K96XZ("5S+B(*"B,Z(&5D:70N<&AP.C$V-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E
M;G1R>3H@)7,B"FUS9W-T<B`B1&5T('5P<'-T;V0@9F5L('9I9"!U<'!D871E
M<FEN9R!A=B!P;W-T96XZ("5S+B(*"B,Z(&1A=&$N<&AP.C$W.0IM<V=I9"`B
M5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP;W)T+B(*;7-G<W1R("))
M;F=A(&%D<F5S<V5R(&%T="!E>'!O<G1E<F$N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#`*;7-G:60@(E1H97-E(&%D
M9')E<W,@8F]O:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S
M='(@(D%D<F5S<V+V8VME<FYA('9I<V%S(&D@9&5N(&CD<B!O<F1N:6YG96XZ
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0S"FUS
M9VED(")4:&5S92!C;VQU;6YS('=I;&P@9&ES<&QA>2!I;B!T:&ES(&]R9&5R
M.B(*;7-G<W1R(")+;VQU;6YE<FYA('9I<V%S(&D@9&5N(&CD<B!O<F1N:6YG
M96XZ(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T
M(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D9I;&9O<FUA=&5T('-T]F1S
M(&EN=&4N(@H*(SH@;&EB+V%P:2YP:'`Z,3$U,R!L:6(O87!I+G!H<#HQ,38V
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S
M(&$@)7,@96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")097)S
M;VYE;B!H87(@<F5D86X@971T(';D<F1E(&;V<B`E<R!I(&%D<F5S<V)O:V5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T.`IM<V=I9"`B(@HB5&AI
M<R!W:6QL(&)E('1H92!D969A=6QT(&%D9')E<W,@8F]O:R!W:&5N(&%D9&EN
M9R!O<B!I;7!O<G1I;F<@8V]N=&%C=',N(@IM<V=S='(@(D;V<G9A;&0@861R
M97-S8F]K(&;V<B!N>6$@;V-H(&EM<&]R=&5R861E(&MO;G1A:W1E<BXB"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW,`IM<V=I9"`B5&ET;&4B
M"FUS9W-T<B`B5&ET96PB"@HC.B!L:6(O5'5R8F$N<&AP.C0T,PIM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N($UI<W-I;F<@<V]U<F-E('1Y
M<&4N(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(&YY('5T9&5L;FEN9RX@2^1L
M;'1Y<"!S86MN87,N(@H*(SH@;&EB+T1R:79E<BYP:'`Z,3`P,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RXB"FUS9W-T<B`B2V%N(&EN=&4@;&%D9&$@9&5F:6YI=&EO;F5N(&%V
M("5S+B(*"B,Z(&5D:70N<&AP.CDU(&5D:70N<&AP.CDX(&5D:70N<&AP.C$P
M,2!E9&ET+G!H<#HQ,#8@961I="YP:'`Z,C`S"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`BQ6YG<F$@Y&YD<FEN9V%R(@H*(SH@;&EB+V%P:2YP:'`Z
M-30R(&QI8B]A<&DN<&AP.C8V,2!L:6(O87!I+G!H<#HW.3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E<R(*;7-G
M<W1R(")#;VYT96YT+51Y<&4@<W3V9',@:6YT93H@)7,B"@HC.B!C;VYF:6<O
M<V]U<F-E<RYP:'`N9&ES=#HS-S8*;7-G:60@(E9E<FES:6=N($1I<F5C=&]R
M>2(*;7-G<W1R(")697)I<VEG;B!K871A;&]G(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]R;W<N:6YC.C$Y('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI
M;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!<(B5S7"(B"FUS9W-T
M<B`B5FES82`G)7,G(@H*(SH@;6EN:7-E87)C:"YP:'`Z-S8*;7-G:60@(E9I
M97<@0V]N=&%C="(*;7-G<W1R(")6:7-A(&MO;G1A:W0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")6:65W('1O(&1I<W!L87D@8GD@
M9&5F875L=#HB"FUS9W-T<B`B5GD@<V]M('-K86QL('9I<V%S('-O;2!D969A
M=6QT.B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(P.`IM<V=I
M9"`B5V5B<VET92!54DPB"FUS9W-T<B`B5V5B8F%D<F5S<R(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q,PIM<V=I9"`B5V]R:R!!9&1R97-S
M(@IM<V=S='(@(D%D<F5S<RP@87)B971E(@H*(SH@8V]N9FEG+V%T=')I8G5T
M97,N<&AP+F1I<W0Z,3(T"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B4W1A
M9"P@87)B971E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,Y
M"FUS9VED(")7;W)K($-O=6YT<GDB"FUS9W-T<B`B3&%N9"P@87)B971E(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34V"FUS9VED(")7;W)K
M(%!H;VYE(@IM<V=S='(@(E1E;&5F;VXL(&%R8F5T92(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$S-`IM<V=I9"`B5V]R:R!0;W-T86P@0V]D
M92(*;7-G<W1R(")0;W-T;G(L(&%R8F5T92(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$R.0IM<V=I9"`B5V]R:R!3=&%T92]0<F]V:6YC92(*
M;7-G<W1R(")296=I;VXL(&%R8F5T92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$Q.0IM<V=I9"`B5V]R:R!3=')E970@061D<F5S<R(*;7-G
M<W1R(")'871U861R97-S+"!A<F)E=&4B"@HC.B!D871A+G!H<#HR,S<@8G)O
M=W-E+G!H<#HQ,#8@8G)O=W-E+G!H<#HR,C<@861D+G!H<#HW,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@8V]N=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R(")$=2!H
M87(@:6YT92!B96CV<FEG:&5T('-K87!A(&UE<B#D;B`E9"!K;VYT86MT97(@
M:2`G)7,G+B(*"B,Z(&5D:70N<&AP.C<S(&1I<W!L87DN<&AP.C4X('9I97<N
M<&AP.C,V"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V
M:65W('1H:7,@8V]N=&%C="XB"FUS9W-T<B`B1'4@:&%R(&EN=&4@8F5H]G)I
M9R!A='0@=FES82!A:W1U96QL(&MO;G1A:W0N(@H*(SH@=F-A<F0N<&AP.C0P
M"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H
M:7,@;V)J96-T+B(*;7-G<W1R(")$=2!H87(@:6YT92!B96CV<FEG:&5T(&%T
M="!V:7-A(&]B:F5K=&5T+B(*"B,Z(&QI8B]4=7)B82YP:'`Z-3,Q"FUS9VED
M(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;G,@=&\@9&5L971E('1H:7,@
M<V]U<F-E+B(*;7-G<W1R(")$=2!H87(@:6YT92!B96CV<FEG:&5T(&%T="!R
M861E<F$@9&5N;F$@:^1L;&$N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A
M<V-R:7!T+FEN8SHU-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B1'4@;>5S=&4@=N1L:F$@96X@861R
M97-S8F]K+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z
M,C,*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(*;7-G
M<W1R(")$=2!MY7-T92!VY&QJ82!E;B!L:7-T82XB"@HC.B!T96UP;&%T97,O
M861D;&EN:R]C;VYT86-T<RYI;F,Z-#0*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R(")$=2!MY7-T92!A;F=E(&5N
M(&%D<F5S<R!F]G)S="XB"@HC.B!E9&ET+G!H<#HS,@IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+B(*;7-G<W1R
M(")6Y&QJ(&UI;G-T(&5N(&MO;G1A:W0@9O9R<W0N(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O8G)O=W-E+VIA
M=F%S8W)I<'0N:6YC.C0Y"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP
M="YI;F,Z-S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@
M96YT<GD@9FER<W0N(@IM<V=S='(@(E;D;&H@;6EN<W0@96X@<&]S="!F]G)S
M="XB"@HC.B!E9&ET+G!H<#HW-PIM<V=I9"`B66]U(&]N;'D@:&%V92!P97)M
M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R(")$=2!H87(@
M96YB87)T(&)E:/9R:6=H970@871T('9I<V$@86MT=65L;"!K;VYT86MT+B(*
M"B,Z(&)R;W=S92YP:'`Z,S$X"FUS9VED(")9;W5R(&1E9F%U;'0@861D<F5S
M<R!B;V]K(&ES(&YO="!B<F]W<V5A8FQE+B(*;7-G<W1R(")$:6X@9O9R=F%L
M9&$@861R97-S8F]K(.1R(&EN=&4@;.1S8F%R+B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O<F]W+FEN8SHV('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI
M;F,Z,3(*;7-G:60@(EMN;R!V86QU95TB"FUS9W-T<B`B6TEN9V5T(';D<F1E
M72(*"B,Z(&QI8B]4=7)B82YP:'`Z-34T"FUS9VED(")?0G)O=W-E(@IM<V=S
M='(@(E],:7-T82(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M-#<*;7-G:60@(E]#;VYT86-T<R(*;7-G<W1R(")?2V]N=&%K=&5R(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS"FUS9VED(")?1&5L971E
M(@IM<V=S='(@(E]2861E<F$B"@HC.B!L:6(O5'5R8F$N<&AP.C4V,PIM<V=I
M9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`B7TEM<&]R="]%>'!O<G0B"@HC
M.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C0V"FUS9VED(")?3&ES
M=',B"FUS9W-T<B`B7TQI<W1O<B(*"B,Z(&QI8B]4=7)B82YP:'`Z-34Q"FUS
M9VED(")?37D@061D<F5S<R!";V]K<R(*;7-G<W1R(")!9')E<W-B]F-K97(B
M"@HC.B!L:6(O5'5R8F$N<&AP.C4U-PIM<V=I9"`B7TYE=R!#;VYT86-T(@IM
M<V=S='(@(E].>2!K;VYT86MT(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHS"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S
M='(@(E]2861E<F$@9G+E;B!L:7-T86XN(@H*(SH@;&EB+U1U<F)A+G!H<#HU
M-3D*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B7U/V:R(*"B,Z('9C87)D+G!H
M<#HT-@IM<V=I9"`B8V]N=&%C="YV8V8B"FUS9W-T<B`B:V]N=&%K="YV8V8B
M"@HC.B!D871A+G!H<#HQ.3D@9&%T82YP:'`Z,C`T('1E;7!L871E<R]D871A
M+V5X<&]R="YI;F,Z,0IM<V=I9"`B8V]N=&%C=',N8W-V(@IM<V=S='(@(FMO
M;G1A:W1E<BYC<W8B"@HC.B!D871A+G!H<#HR,#D*;7-G:60@(F-O;G1A8W1S
M+G1S=B(*;7-G<W1R(")K;VYT86MT97(N='-V(@H*(SH@9&%T82YP:'`Z,C$Y
M"FUS9VED(")C;VYT86-T<RYV8V8B"FUS9W-T<B`B:V]N=&%K=&5R+G9C9B(*
M"B,Z('1E;7!L871E<R]A9&1L:6YK+V-O;G1A8W1S+FEN8SHX,`IM<V=I9"`B
M9G)O;2(*;7-G<W1R(")F<N5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S.`IM<V=I9"`B;F\@9F]R;6%T=&EN9R(*;7-G<W1R(")I;F=E;B!F;W)M
M871E<FEN9R(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S(*
M;7-G:60@(FYO;F4B"FUS9W-T<B`B:6YG96XB"@HC.B!T96UP;&%T97,O8G)O
M=W-E+V%C=&EO;G,N:6YC.C,Q"FUS9VED(")T;R!A($-O;G1A8W0@3&ES="(*
M;7-G<W1R(")T:6QL(&MO;G1A:W1L:7-T82(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,C$*;7-G:60@(G1O(&$@9&EF9F5R96YT($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")T:6QL(&%N;F%N(&%D<F5S<V)O:R(*"B,Z(&1A
M=&$N<&AP.C4Q('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC
M.C$S"B,Z('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,34@=&5M<&QA=&5S
M+V1A=&$O97AP;W)T+FEN8SHQ-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A
M<F0B"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]P;R]T<E]44BYP;P``````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<V-34Q`#$P-#$W
M,S8R-S4V`#`Q-S4V-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C(%1U<FMI<V@@=')A;G-L871I;VYS(&9O<B!455)"02!P
M86-K86=E"B,@5%520D$@<&%K971I(&GG:6X@5/QR:^=E(.=E=FER:6QE<BX*
M(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL
M92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H
M92!455)"02!P86-K86=E+@HC($=E;F5R871E9"!B>0HC(%-E<G9E="!'_&YE
M>2`\<V=U;F5Y0&UE='4N961U+G1R/@HC($%H;65T(-9Z=/QR:R`\;V%H;65T
M0&UE='4N961U+G1R/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)
M9"U697)S:6]N.B!4=7)B82TR+C`N,EQN(@HB4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#4M,#(M,3`@,#(Z,#@K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!!
M=71O;6%T:6-A;&QY(&=E;F5R871E9%QN(@HB3&%N9W5A9V4M5&5A;3H@:3$X
M;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM.5QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L
M+49O<FUS.B!N<&QU<F%L<STQ.R!P;'5R86P],#M<;B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I;7-P7V]P="YI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(B!!9&0@
M86X@24U34"!!9&1R97-S($)O;VLB"FUS9W-T<B`B4&EN92!!9')E<R!$969T
M97)I(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHS,0HC+"!F
M=7IZ>0IM<V=I9"`B($1E;&5T92!)35-0($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")39>=I;&5N($%D<F5S($1E9G1E<FEN92(*"B,Z(&1A=&$N<&AP.C,R-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@86QR96%D>2!E>&ES=',@86YD
M('=A<R!N;W0@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z
M,3(V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO
M="!C;W!I960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@(B<E<R<@
M8FER(&QI<W1E(&]L9'7P=2!IYVEN(&MO<'EA;&%N;6%D_2XB"@HC.B!B<F]W
M<V4N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI<W0N(@IM<V=S='(@
M(B<E<R<@8FER(&QI<W1E(&]L9'7P=2!IYVEN('1A_OUN86UA9/TN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-PIM<V=I9"`B7")&:7)S=&YA;64@
M3&%S=&YA;65<(B`@*&EE+B!*;VAN($1O92DB"FUS9W-T<B`B7")!9"!3;WEA
M9%PB("C6<BX@06QI(%G];&UA>BDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,V"FUS9VED(")<(DQA<W1N86UE+"!&:7)S=&YA;65<(B`H:64N($1O
M92P@2F]H;BDB"FUS9W-T<B`B7")3;WEA9"P@061<(B`HUG(N(%G];&UA>BP@
M06QI*2(*"B,Z(&%D9"YP:'`Z,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&%D9&5D+B(*;7-G<W1R("(E<R!E:VQE;F1I(@H*(SH@9&%T82YP:'`Z,S0S
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM
M<&]R=&5D(@IM<V=S='(@(B5S(&1O<WEA<_T@8F'^87+]>6QA("AIYV5R:2D@
M86MT87+];&3](@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B
M)7,@:6QE("5S+"!T;W!L86T@)7,B"@HC.B!L:6(O5'5R8F$N<&AP.C0T-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B4&EN92!!9')E<R!$969T97)I(@H*(SH@;&EB+T)L;V-K+VUI
M;FES96%R8V@N<&AP.C0U"FUS9VED(")!(&)R;W=S97(@=&AA="!S=7!P;W)T
M<R!I1G)A;65S(&ES(')E<75I<F5D(@IM<V=S='(@(FE&<F%M97,@9&5S=&5K
M;&5Y96X@8FER('1A<F%Y_6/](&=E<F5K;65K=&5D:7(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34Y"FUS9VED(")!8F]V92!S96%R8V@@9F]R;2(*
M;7-G<W1R(")9=6MA<OT@87)A;6$@9F]R;74B"@HC.B!V:65W+G!H<#HU,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06-C97-S(&1E;FEE9"!T;R`E
M<R(*;7-G<W1R("(E<R`E<R!E(&)A_F%R_7EL82!E:VQE;F1I(@H*(SH@861D
M+G!H<#HU-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(R"FUS9VED
M(")!9&0B"FUS9W-T<B`B16ML92(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R
M97-S8F]O:W-E;&5C="YI;F,Z,3<T"B,L(&9U>GIY"FUS9VED(")!9&0@861D
M<F5S<R!B;V]K(@IM<V=S='(@(D=EYV5R<VEZ(&%D<F5S(&1E9G1E<FDB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@*(RP@9G5Z>GD*;7-G:60@(D%D
M9"!A;F0@1&5L971E($E-4U`@861D<F5S<R!B;V]K<R(*;7-G<W1R(")39>=I
M;&5N(&%D<F5S(&1E9G1E<FD@)R5S)RXB"@HC.B!T96UP;&%T97,O<')E9G,O
M8V]L=6UN<V5L96-T+FEN8SHR,S<*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T
M<B`B2V]L;VX@96ML92(*"B,Z(&5D:70N<&AP.C$R.`IM<V=I9"`B061D(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHR,@IM<V=I9"`B061D('1O(@IM<V=S='(@(D5K;&4B"@HC.B!T96UP;&%T
M97,O861D<F5S<V)O;VMS+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S
M<R!";V]K(@IM<V=S='(@(E!I;F4@061R97,@1&5F=&5R:2(*"B,Z(&)R;W=S
M92YP:'`Z,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0IM<V=I9"`B061D
M<F5S<R!";V]K($QI<W1I;F<B"FUS9W-T<B`B061R97,@1&5F=&5R:2!,:7-T
M96QE;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*(RP@9G5Z>GD*
M;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B4&EN92!!9')E<R!$969T
M97)I(@H*(SH@861D+G!H<#HQ,#@*;7-G:60@(D%D9')E<W,@8F]O:R!E;G1R
M>2(*;7-G<W1R(")!9')E<R!D969T97)I(&MA>63](@H*(SH@9&%T82YP:'`Z
M,S`U"FUS9VED(")!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY('!U<F=E9"XB
M"FUS9W-T<B`B061R97,@9&5F=&5R:2!B8?YA<OUY;&$@8F_^86QT_6QD_2XB
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV,@HC+"!F=7IZ>0IM
M<V=I9"`B061D<F5S<R!B;V]K('1O(&1E;&5T92`B"FUS9W-T<B`B061R97,@
M9&5F=&5R:2!K87ED_2(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O
M:W-E;&5C="YI;F,Z,3<P"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(&)O;VMS
M('1H870@=VEL;"!N;W0@8F4@9&ES<&QA>65D.B(*;7-G<W1R(")!9')E<R!D
M969T97)I(&)O_F%L=/UL86UA9/TZ("5S(@H*(SH@<V5A<F-H+G!H<#HX."!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S<*;7-G:60@(D%D=F%N8V5D
M(%-E87)C:"(*;7-G<W1R(")'96QI_FUI_B!!<F%M82(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C8T"FUS9VED(")!;&EA<R(*;7-G<W1R("+6
M=&5K:2!!9"(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC
M.C<@=&5M<&QA=&5S+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S
M='(@(E3\;?PB"@HC.B!L:6(O87!I+G!H<#HU-3(*;7-G:60@(D%L<F5A9'D@
M17AI<W1S(@IM<V=S='(@(EIA=&5N(%9A<B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E("5S/R(*;7-G<W1R
M("(E<R!S:6QM96L@:7-T961I\&EN:7ID96X@96UI;B!M:7-I;FEZ/R(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP="YI;F,Z-C<*;7-G:60@(D%R
M92!Y;W4@<W5R92!T:&%T('EO=2!W86YT('1O(&1E;&5T92!T:&4@<V5L96-T
M960@96YT<FEE<S\B"FUS9W-T<B`B4V7G:6QE;B!G:7)I_FQE<FD@<VEL;65K
M(&ES=&5D:?!I;FEZ9&5N(&5M:6X@;6ES:6YI>C\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.38*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")!<G1A
M;B(*"B,Z('-E87)C:"YP:'`Z.#4@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N
M:6YC.C,V"FUS9VED(")"87-I8R!396%R8V@B"FUS9W-T<B`B0F%S:70@07)A
M;6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")"96QO
M=R!S96%R8V@@9F]R;2(*;7-G<W1R(")!_F'P_2!A<F%M82!F;W)M=2(*"B,Z
M(&QI8B]$<FEV97(O;&1A<"YP:'`Z-S<@;&EB+T1R:79E<B]L9&%P+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")":6YD(&9A:6QE9#H@*"5S*2`E<R(*
M;7-G<W1R(")"8?!L86YT_2!K=7)U;&%M863]("@E<RD@)7,B"@HC.B!C;VYF
M:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D)I<G1H9&%Y(@IM
M<V=S='(@(D1O\'5M(&?\;OPB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z-PHC
M+"!F=7IZ>0IM<V=I9"`B0G)O=W-E(@IM<V=S='(@(E]']GIA="(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W,PIM<V=I9"`B0G5S:6YE<W,@
M0V%T96=O<GDB"FUS9W-T<B`BW?X@4_UN_6;](@H*(SH@9&%T82YP:'`Z-#D*
M;7-G:60@(D-35B(*;7-G<W1R(")#4U8B"@HC.B!L:6(O3V)J96-T+T=R;W5P
M+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M;E]H96%D97)S
M+FEN8SHW"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B5/QM_%]N
M_"#=_F%R971L92_=_F%R971L96UE(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A(&YA;64B"FUS
M9W-T<B`B0FER(&%D<F5S(&1E9G1E<FD@<V7G:6XB"@HC.B!A9&0N<&AP.C0X
M"FUS9VED(")#:&]O<V4@86X@861D<F5S<R!B;V]K(@IM<V=S='(@(D)I<B!A
M9')E<R!D969T97)I('-EYVEN(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M
M;G-E;&5C="YI;F,Z,C(Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@861D
M<F5S<R!B;V]K.B(*;7-G<W1R(")":7(@861R97,@9&5F=&5R:2!S9>=I;B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,38U
M"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!D:7-P;&%Y
M+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=VAI8V@@
M861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM<V=S='(@(D)I<B!A9')E<R!D969T
M97)I('-EYVEN(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI
M;F,Z,C(X"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=VAI8V@@8V]L=6UN<R!T
M;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R(")!9')E<R!L
M:7-T97-I;F1E(&?V<OQN=&5L96YE8V5K(&MO;&]N;&%R_6X@<_UR87/];OT@
M<V7G:6XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")#
M;VQU;6X@3W!T:6]N<R(*;7-G<W1R(")+;VQO;B!39>=E;F5K;&5R:2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S,PIM<V=I9"`B
M0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ,R!T96UP;&%T97,O
M9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L
M=65S(@IM<V=S='(@(E9I<F?\;"!I;&4@87ER_6QM_?X@9&7P97)L97(B"@HC
M.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$S"FUS9VED(")#;VUM82!S
M97!A<F%T960@=F%L=65S("A-:6-R;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`B
M5FER9_QL(&EL92!A>7+];&W]_B!D9?!E<FQE<B`H36EC<F]S;V9T($]U=&QO
M;VLI(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-S8*;7-G:60@
M(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D-O;7!A;GD@061D<F5S<R(*;7-G<W1R
M(")&:7)M82!!9')E<VDB"@HC.B!L:6(O87!I+G!H<#HS,3@@;&EB+V%P:2YP
M:'`Z,S8S(&QI8B]A<&DN<&AP.C0P-R!L:6(O87!I+G!H<#HT.3$*(SH@;&EB
M+V%P:2YP:'`Z-C`Q(&QI8B]A<&DN<&AP.C8X."!L:6(O87!I+G!H<#HW-#$@
M;&EB+V%P:2YP:'`Z.#$Y"B,Z(&QI8B]A<&DN<&AP.C$P,#8@;&EB+V%P:2YP
M:'`Z,3`Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B0F'P;&%N=/T@8F'^87+]<_UZ.B`E<R(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z-3@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;'5R
M92(*;7-G<W1R(")"8?!L86YT_2!B8?YA<OUS_7HB"@HC.B!B<F]W<V4N<&AP
M.C$Y,2!B<F]W<V4N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C="!A
M9&1E9"!T;R!L:7-T+B(*;7-G<W1R("+=;&5T:?YI;2!N;VMT87/](&QI<W1E
M9&5N('-I;&EN9&DN(@H*(SH@8G)O=W-E+G!H<#HV,`IM<V=I9"`B0V]N=&%C
M="!R96UO=F5D(&9R;VT@;&ES="XB"FUS9W-T<B`BW6QE=&G^:6T@;F]K=&%S
M_2!L:7-T961E;B!S:6QI;F1I+B(*"B,Z(&)R;W=S92YP:'`Z,C8V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;G1A8W1S(&EN(&QI<W0Z("5S(@IM<V=S='(@
M(DQI<W1E9&5K:2!I;&5T:?YI;2!N;VMT86QA<OTZ("5S(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B0V]P>2(*;7-G<W1R
M(")+;W!Y86QA(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3,*
M(RP@9G5Z>GD*;7-G:60@(D-R96%T92(*;7-G<W1R(")/;'7^='5R=6QD=2(*
M"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C0P"B,L(&9U>GIY"FUS
M9VED(")#<F5A=&4@061D<F5S<R!";V]K(@IM<V=S='(@(M9Z96P@061R97,@
M1&5F=&5R:2(*"B,Z(&QI8B],:7-T5FEE=RYP:'`Z,S$U"FUS9VED(")#<F5A
M=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.B(*;7-G<W1R("(B"@HC.B!L:6(O
M3V)J96-T5FEE=RYP:'`Z,3,S"FUS9VED(")#<F5A=&5D(@IM<V=S='(@(D]L
M=?YT=7)U;&1U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED
M(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R("+6;G1A;OUM
M;/T@<_UR86QA;6$@>?9N_#HB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHW-B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*(SH@;&EB
M+T]B:F5C="YP:'`Z,S(X(&QI8B]296YD97)E<BYP:'`Z-#<@;&EB+U)E;F1E
M<F5R+G!H<#HU,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-I;"(*"B,Z('1E
M;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C4X"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S($1E9G1E<FD@4V7G
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")$96QE=&4@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(E-I;&UE($]N87G](@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED(")$96QE=&4@8G5T=&]N(&)E:&%V
M:6]U<B(*;7-G<W1R(")3:6QM92!D_/!M97-I(&1A=G)A;OW^_2(*"B,Z(&QI
M8B]$<FEV97(O;&1A<"YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B4VEL;64@8F'^87+]<_UZ
M.B`H)7,I("5S(@H*(SH@9&5L971E+G!H<#HS.`IM<V=I9"`B1&5L971I;VX@
M9F%I;&5D(@IM<V=S='(@(E-I;&UE(&)A_F%R_7/]>B(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C(Q,PIM<V=I9"`B1&5P87)T;65N="(*;7-G
M<W1R(")"]FS\;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I
M9"`B1&5S8V5N9&EN9R(*;7-G<W1R(")!>F%L86XB"@HC.B!T96UP;&%T97,O
M861D<F5S<V)O;VMS+FEN8SHQ,34*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3@*;7-G
M:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$:7II;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R
M(")']G+\;OQM(%-EYV5N96ML97)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")']G+\;OQM(%-EYV5N96ML97)I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-@IM<V=I9"`B1&\@>6]U
M('=A;G0@=&\@8V]N9FER;2!D96QE=&EN9R!E;G1R:65S/R(*;7-G<W1R(")'
M:7)I_FQE<FD@<VEL;65Y:2!O;F%Y;&%M86L@:7-T:7EO<B!M=7-U;G5Z/R(*
M"B,Z(&QI8B]/8FIE8W0N<&AP.C(Y-PHC+"!F=7IZ>0IM<V=I9"`B1&]W;FQO
M860B"FUS9W-T<B`B=D-A<F0@:6YD:7(B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+W)O=RYI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHR
M-0IM<V=I9"`B1&]W;FQO860@=D-A<F0B"FUS9W-T<B`B=D-A<F0@:6YD:7(B
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ,#(@=&5M<&QA=&5S
M+V)R;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN
M7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,PHC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C,S(&QI8B]2
M96YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B"FUS9W-T<B`B1/QZ96YL92(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHR-2!T96UP;&%T97,O8G)O
M=W-E+V-O;G1A8W1R;W<N:6YC.C,S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(%PB)7-<(B(*;7-G<W1R("(G)7,G($3\>F5N;&4B"@HC.B!T
M96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B
M161I="!!9&1R97-S($)O;VMS(@IM<V=S='(@(D%D<F5S($1E9G1E<FEN:2!$
M_?YA<OT@06MT87(B"@HC.B!E9&ET+G!H<#HW."!E9&ET+G!H<#HQ-30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!E;G1R>2!F;W(@)7,B"FUS9W-T<B`B
M)7,@9VER:?YI;FD@9/QZ96YL92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C4X"FUS9VED(")%;6%I;"(*;7-G<W1R(")%+7!O<W1A(@H*(SH@
M961I="YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E
M<R!U<&1A=&5D+"!B=70@<V%V:6YG('1H92!U<&QO861E9"!F:6QE(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z,30Y(&5D:70N<&AP.C$U
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!F;W(@)7,@=7!D871E9"XB
M"FUS9W-T<B`B)7,@:V%Y9'4@9_QN8V5L;&5N9&DN(@H*(SH@8G)O=W-E+G!H
M<#HW-`HC+"!F=7IZ>0IM<V=I9"`B16YT<GD@<W5C8V5S<V9U;&QY(&1E;&5T
M960N(@IM<V=S='(@(B5S(&1O<WEA<_T@8F'^87+]>6QA("AIYV5R:2D@86MT
M87+];&3](@H*(SH@;&EB+V%P:2YP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!S96%R8VAI;F<@=&AE(&%D9')E<W,@8F]O:SH@
M)7,B"FUS9W-T<B`B061R97,@9&5F=&5R:6YE(&5R:?YI;2!B8?YA<OUS_7HZ
M("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV('1E;7!L
M871E<R]D871A+V5X<&]R="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*;7-G<W1R
M(")$_?YA<OT@06MT87(B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C8*;7-G:60@(D5X<&]R="!!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97,@
M1&5F=&5R:6YI($3]_F%R_2!!:W1A<B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,C$*;7-G:60@(D5X<&]R="!O;FQY('1H92!S96QE8W1E9"!C
M;VYT86-T<RXB"FUS9W-T<B`B4V%D96-E('-EYVEL96X@:6QE=&G^:6T@;F]K
M=&%L87+];OT@9/W^87+](&%K=&%R+B(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,C<*;7-G:60@(D5X<&]R="!T:&4@9F]L;&]W:6YG(&%D9')E
M<W,@8F]O:R!C;VUP;&5T96QY+B(*;7-G<W1R(")"=2!A9')E<R!D969T97)I
M;FD@=/QM_'EL92!D_?YA<OT@86MT87(N(@H*(SH@9&%T82YP:'`Z,3,T(&1A
M=&$N<&AP.C(R."!D871A+G!H<#HR.3<@8G)O=W-E+G!H<#HS-2!B<F]W<V4N
M<&AP.CDP"B,Z(&)R;W=S92YP:'`Z,3$R(&%D9"YP:'`Z-C<@<V5A<F-H+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@86-C97-S('1H
M92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@(D%D<F5S(&1E9G1E<FEN92!E
M<FG^:6T@8F'^87+]<_UZ.B`E<R(*"B,Z(&)R;W=S92YP:'`Z,3,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@)7,@=&\@)7,Z("5S(@IM
M<V=S='(@(B5S(&D@)7,@92!E:VQE;64@8F'^87+]<_UZ.B`E<R(*"B,Z(&)R
M;W=S92YP:'`Z,C<R"FUS9VED(")&86EL960@=&\@8G)O=W-E(&QI<W0B"FUS
M9W-T<B`B3&ES=&4@9_9R_&YT_&QE;64@8F'^87+]<_UZ(@H*(SH@8G)O=W-E
M+G!H<#HS,3`*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@=&AE(&1I<F5C=&]R
M>2(*;7-G<W1R(")$:7II;B!G]G+\;G3\;&5M92!B8?YA<OUS_7HB"@HC.B!L
M:6(O1')I=F5R+VQD87`N<&AP.C,P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8VAA;F=E(&YA;64Z("@E<RD@)7,[($]L9"!$3B`]("5S+"!.
M97<@1$X@/2`E<RP@4F]O="`]("5S(@IM<V=S='(@(B(*(MUS:6T@9&7P:?YT
M:7)M92!B8?YA<OUS_7HZ("@E<RD@)7,[($5S:VD@1$X@/2`E<RP@665N:2!$
M3B`]("5S+"!+]FL@/2`E<R(*"B,Z(&)R;W=S92YP:'`Z,3(P"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E
M9#H@)7,B"FUS9W-T<B`B16ML96YE8V5K(&YE<VYE(&)U;'5N86UA9/TZ("5S
M(@H*(SH@<V5A<F-H+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O
M('-E87)C:"!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(D%D<F5S(&1E9G1E
M<FEN92!E<FG^:6T@8F'^87+]<_UZ.B`E<R(*"B,Z(&1A=&$N<&AP.C$T.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<V5A<F-H('1H92!D:7)E
M8W1O<GDZ("5S(@IM<V=S='(@(D1I>FEN(&%R86UA(&)A_F%R_7/]>CH@)7,B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C<*;7-G:60@(D9A
M>"(*;7-G<W1R(")&86MS(@H*(SH@961I="YP:'`Z,3(T(&1I<W!L87DN<&AP
M.C$P,`HC+"!F=7IZ>0IM<V=I9"`B1FEL97,B"FUS9W-T<B`BW&YV86XB"@HC
M.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S`*;7-G:60@(D9I;F0B
M"FUS9W-T<B`B0G5L(@H*(SH@961I="YP:'`Z.3<@961I="YP:'`Z,3@W"B,L
M(&9U>GIY"FUS9VED(")&:6YI<V@B"FUS9W-T<B`B0G5L(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z-#@*;7-G:60@(D9I<G-T($YA;64B"FUS
M9W-T<B`B060B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR,#(*
M;7-G:60@(D9R965B=7-Y(%523"(*;7-G<W1R(")&<F5E8G5S>2!!9')E<VDB
M"@HC.B!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z.#,*;7-G:60@(D9R
M;VTB"FUS9W-T<B`BW>=I;F1E(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I
M<W0Z-C`T"FUS9VED(")';&]B86P@061D<F5S<R!";V]K(@IM<V=S='(@(D=E
M;F5L($%D<F5S($1E9G1E<FDB"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI
M;F,Z-#,@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHT-`IM<V=I
M9"`B1W)O=7`B"FUS9W-T<B`B1W)U<"(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C@R"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B178@
M061R97-I(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z.3,*;7-G
M:60@(DAO;64@0VET>2(*;7-G<W1R("+>96AI<B(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$P.`IM<V=I9"`B2&]M92!#;W5N=')Y(@IM<V=S
M='(@(MQL:V4B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-3`*
M;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BW?X@5&5L969O;G4B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*;7-G:60@(DAO;64@4&]S
M=&%L($-O9&4B"FUS9W-T<B`B4&]S=&$@2V]D=2(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.CDX"FUS9VED(")(;VUE(%-T871E+U!R;W9I;F-E
M(@IM<V=S='(@(D+V;&=E(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I
M<W0Z.#@*;7-G:60@(DAO;64@4W1R965T($%D9')E<W,B"FUS9W-T<B`B178@
M061R97-I(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z-3`V"FUS9VED
M("))35-0(@IM<V=S='(@(DE-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#<*(RP@9G5Z>GD*;7-G:60@(DE-4U`@061D<F5S<R!";V]K($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D%D<F5S($1E9G1E<FD@3&ES=&5L96UE(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T<B`B
M061R97,@1&5F=&5R:2#=YV5R:2!!:W1A<FUA+"!!9/UM("5D(@H*(SH@9&%T
M82YP:'`Z,S8Q"FUS9VED("));7!O<G0O17AP;W)T($%D9')E<W,@0F]O:W,B
M"FUS9W-T<B`B061R97,@1&5F=&5R;&5R:6YI(-WG97)I+T3]_F%R_2!!:W1A
M<B(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O87!I+G!H<#HV.#,*;7-G:60@
M(DEN=F%L:60@240B"FUS9W-T<B`B1V7G97)S:7H@:VEM;&EK(@H*(SH@;&EB
M+V%P:2YP:'`Z,C,P(&QI8B]A<&DN<&AP.C0P,B!L:6(O87!I+G!H<#HT.#8@
M;&EB+V%P:2YP:'`Z-3DR"B,Z(&QI8B]A<&DN<&AP.C8W.2!L:6(O87!I+G!H
M<#HW,S$@;&EB+V%P:2YP:'`Z,3`W-PIM<V=I9"`B26YV86QI9"!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B1V7G97)S:7H@861R97,@9&5F=&5R:2(*"B,Z(&QI
M8B]A<&DN<&AP.C$P.#$@;&EB+V%P:2YP:'`Z,3$U-"!L:6(O87!I+G!H<#HQ
M,C`W"FUS9VED("));G9A;&ED(&5M86EL(@IM<V=S='(@(D=EYV5R<VEZ(&4M
M<&]S=&$B"@HC.B!L:6(O87!I+G!H<#HQ,#@Y"FUS9VED("));G9A;&ED(&5N
M=')Y(@IM<V=S='(@(D=EYV5R<VEZ(&MA>?UT(@H*(SH@;&EB+T1R:79E<B]L
M9&%P+G!H<#HR-C8*;7-G:60@(DEN=F%L:60@:V5Y('-P96-I9FEE9"XB"FUS
M9W-T<B`B1V7G97)S:7H@86YA:'1A<B!B96QI<G1I;&1I+B(*"B,Z(&QI8B]A
M<&DN<&AP.C$P.#4*;7-G:60@(DEN=F%L:60@;F%M92(*;7-G<W1R(")'9>=E
M<G-I>B!A9"(*"B,Z(&QI8B]A<&DN<&AP.C<S-0IM<V=I9"`B26YV86QI9"!O
M8FIE8W1)9"(*;7-G<W1R(")'9>=E<G-I>B!N97-N92!K:6UL:?!I(@H*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P;W)T
M(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL
M86)L92!O<B!N;W0@;&]A9&5D+B(*;7-G<W1R("(B"B),1$%0(&1E<W1E\&D@
M9V5R96MI>6]R(&%N8V%K($Q$05`@;6]D_&S\(&MU;&QA;OUL86)I;&ER(&1E
M\&EL('EA(&1A("(*(GG\:VQE;FUE9&DN(@H*(SH@;&EB+T]B:F5C=%9I97<N
M<&AP.C$S.`IM<V=I9"`B3&%S="!-;V1I9FEE9"(*;7-G<W1R(")3;VX@1_QN
M8V5L;&5M92(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C4S"FUS
M9VED("),87-T($YA;64B"FUS9W-T<B`B4V]Y860B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ-@IM<V=I9"`B3&ES="(*;7-G
M<W1R("),:7-T92(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHW
M-PIM<V=I9"`B36%T8VAI;F<B"FUS9W-T<B`B1?YL9?YE;B(*"B,Z(&QI8B]A
M<&DN<&AP.C(P-0HC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@
M0V]N=&%C=',B"FUS9W-T<B`B07IA;6D@<V%Y9F$@<V%Y_7/](@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU;2!N=6UB97(@
M;V8@<&%G97,B"FUS9W-T<B`B07IA;6D@<V%Y9F$@<V%Y_7/](@H*(SH@;&EB
M+T)L;V-K+W1R965?;65N=2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!,
M:7-T(@IM<V=S='(@(EEE;FD@3&ES=&4B"@HC.B!L:6(O0FQO8VLO;6EN:7-E
M87)C:"YP:'`Z,PIM<V=I9"`B36EN:2!396%R8V@B"FUS9W-T<B`B36EN:6L@
M07)A;6$B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES
M<VEN9R!$3B!I;B!,1$%0('-O=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("),1$%0(&MA>6YA:R!Y87#];&%N9/UR;6%S_6YD82!E:W-I:R!$3BXB"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL
M92!0:&]N92(*;7-G<W1R(")-;V)I;"!496QE9F]N(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HS,S(@;&EB+T1R:79E<B]L9&%P+G!H<#HS-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B36]D:69Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R
M(")$9?!I_FEK;&EK(&)A_F%R_7/]>CH@*"5S*2`E<R(*"B,Z(&QI8B]A<&DN
M<&AP.C$Q.3,*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y(&9O=6YD(@IM<V=S
M='(@(D)I<F1E;B!F87IL82!K87G]="!B=6QU;F1U(@H*(SH@=&5M<&QA=&5S
M+V)R;W=S92]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B36]V92(*;7-G<W1R(")4
M8?[](@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0W
M"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@T
M"FUS9VED(")-;W9E(&QE9G0B"FUS9W-T<B`B4V]L82!T8?[](@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y"B,Z('1E;7!L871E
M<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V"FUS9VED(")-;W9E
M(')I9VAT(@IM<V=S='(@(E-A\&$@=&'^_2(*"B,Z(&1A=&$N<&AP.C4R('1E
M;7!L871E<R]D871A+VEM<&]R="YI;F,Z,38*;7-G:60@(DUU;&)E<G)Y($%D
M9')E<W,@0F]O:R(*;7-G<W1R(")-=6QB97)R>2!!9')E<R!$969T97)I(@H*
M(SH@;&EB+V%P:2YP:'`Z,3$Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)-
M=6QT:7!L92!P97)S;VYS('=I=&@@861D<F5S<R!;)7-=+"!B=70@;F]N92!W
M:71H(&YA;64@6R5S72!A;')E861Y(&5X:7-T(@IM<V=S='(@(ELE<UT@861R
M97-I(&EL92!B:7)D96X@9F%Z;&$@:VG^:2!B=6QU;F1U(&%N8V%K(%LE<UT@
M:7-M:6YD92!B:7)I('EO:R(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*;7-G
M:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<R!$969T97)I;2(*
M"B,Z(&%D9')E<W-B;V]K<RYP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")->2!!
M9&1R97-S($)O;VMS(@IM<V=S='(@(D%D<F5S($1E9G1E<FEM(@H*(SH@=&5M
M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`W(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C0R"FUS9VED(").86UE(@IM<V=S='(@(D%D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED(").86UE($9O<FUA="(*;7-G
M<W1R(")!9"!":>=I;6DB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HS
M,34*;7-G:60@(DYE=&-E;G1E<B!-96UB97(@1&ER96-T;W)Y(@IM<V=S='(@
M(DYE=&-E;G1E<B#<>64@1&EZ:6YI(@H*(SH@861D+G!H<#HS-B!A9&0N<&AP
M.C$R-"!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,C<*(SH@;&EB+T)L;V-K
M+W1R965?;65N=2YP:'`Z,C<*;7-G:60@(DYE=R!#;VYT86-T(@IM<V=S='(@
M(EEE;FD@W6QE=&G^:6T@3F]K=&%S_2(*"B,Z(&5D:70N<&AP.C@X(&5D:70N
M<&AP.CDU(&5D:70N<&AP.C(P,B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C0U"FUS9VED(").97AT(@IM<V=S='(@(D1E=F%M(@H*(SH@8V]N9FEG+V%T
M=')I8G5T97,N<&AP+F1I<W0Z,C$X"FUS9VED(").:6-K;F%M92(*;7-G<W1R
M(")486MM82!!9"(*"B,Z(&QI8B]A<&DN<&AP.C$Q.34@;&EB+V%P:2YP:'`Z
M,3(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R`E<R!E;G1R>2!F;W5N9"!F
M;W(@)7,B"FUS9W-T<B`B)7,@9VER:?YI(&)U;'5N86UA9/TZ("5S(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$V,PIM<V=I9"`B3F\@861D<F5S<R!B;V]K<R!F;W5N
M9"XB"FUS9W-T<B`B2&GG(&%D<F5S(&1E9G1E<FD@8G5L=6YA;6%D_2XB"@HC
M.B!M:6YI<V5A<F-H+G!H<#HX,PIM<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B
M"FUS9W-T<B`B2&GG(&EL971I_FEM(&YO:W1A<_T@8G5L=6YA;6%D_2(*"B,Z
M(&QI8B]A<&DN<&AP.C4Q,2!L:6(O87!I+G!H<#HW-C8*;7-G:60@(DYO('9#
M87)D(&1A=&$@=V%S(&9O=6YD+B(*;7-G<W1R(")(:><@=D-A<F0@=F5R:7-I
M(&)U;'5N86UA9/TN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC
M.C<*;7-G:60@(DYO;F4B"FUS9W-T<B`B2&GG8FER:2(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$X-`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M3F]T;&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B
M3G5M8F5R(&]F(&ET96US('!E<B!P86=E(@IM<V=S='(@(E-A>69A(&)A_OUN
M82#V\&4@<V%Y_7/](@H*(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP
M.C<T-PIM<V=I9"`B3V)J96-T(&YO="!F;W5N9"(*;7-G<W1R(").97-N92!B
M=6QU;F%M863](@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C(S
M"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B3V9I<R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N8V4@>6]U('-A=F4@
M=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL(&)E('!E
M<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@;F]T('=H870@>6]U
M('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T:6]N("(*
M(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HW-S0*
M;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-@IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R(")$:?!E<B!3
M9>=E;F5K;&5R(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DP
M"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@0>?]:R!!;F%H
M=&%R_2(*"B,Z(&QI8B]A<&DN<&AP.C0Y-2!L:6(O87!I+G!H<#HV,#4@;&EB
M+V%P:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.CDS-`HC.B!L:6(O87!I+G!H<#HQ
M,#DX"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")%<FG^:6T@
M16YG96QL96YD:2(*"B,Z(&QI8B]$<FEV97(N<&AP.C4T,PIM<V=I9"`B4&5R
M;6ES<VEO;B!D96YI960B"FUS9W-T<B`B17)I_FEM(&5N9V5L;&5N9&DB"@HC
M.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHY.0HC+"!F=7IZ>0IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B17)I_FEM($5N9V5L;&5N9&DB"@HC
M.B!D871A+G!H<#HU,R!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS
M9VED(")0:6YE($%D9')E<W,@0F]O:R(*;7-G<W1R(")0:6YE($%D<F5S($1E
M9G1E<FDB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(X
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@
M;&ES=#HB"FUS9W-T<B`B3/QT9F5N('EE;FD@;&ES=&5N:6X@863];OT@9VER
M:6XZ(@H*(SH@961I="YP:'`Z.3$@961I="YP:'`Z.30@961I="YP:'`Z,3DT
M"FUS9VED(")0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HT,38*;7-G:60@(E!R:79A=&4@061D<F5S<R!";V]K(@IM
M<V=S='(@(M9Z96P@061R97,@1&5F=&5R:2(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(E%U97)Y(&9A:6QE9#H@
M*"5S*2`E<R(*;7-G<W1R(")3;W)G=2!B8?YA<OUS_7HZ("@E<RD@)7,B"@HC
M.B!T96UP;&%T97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,3@*;7-G:60@(E%U
M:6-K(%-E87)C:"(*;7-G<W1R(")(_7IL_2!!<F%M82(*"B,Z(&QI8B]$<FEV
M97(O;&1A<"YP:'`Z,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY(&QI8B]$
M<FEV97(O;&1A<"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E860@
M9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(D]K=6UA(&)A_F%R_7/]>CH@*"5S
M*2`E<R(*"B,Z(&QI8B]296YD97)E<BYP:'`Z-#D*;7-G:60@(E)E86QL>2!D
M96QE=&4@=&AI<R!C;VYT86-T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V9O;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D<R!D:7-P;&%Y960Z
M(@IM<V=S='(@(D?V<OQN=/QL96YE;B!K87G]=&QA<CHB"@HC.B!T96UP;&%T
M97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-@HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E(&%D9')E<W,@8F]O:R(*;7-G<W1R(")":7(@861R97,@
M9&5F=&5R:2!S9>=I;B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE
M8W0N:6YC.C(S.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")+;VQO
M;G4@<VEL(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS
M9VED(")296UO=F4@9G)O;2!T:&ES(&QI<W0B"FUS9W-T<B`B0G4@;&ES=&5D
M96X@<VEL(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0HC+"!F
M=7IZ>0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@
M=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@
M(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S
M<R!B;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"B)9_&ML96YE;B!A9')E<R!D
M969T97)I;FD@=F%R;VQA;B!I;&4@9&7P:?YT:7)M96L@:7-T:7EO<B!M=7-U
M;G5Z/R`\8CY5>6%R_3H@(@HB0G4@:?YL96T@_G4@86YK:2!A9')E<R!D969T
M97)I;FEZ9&5K:2!T_&T@9VER:?YL97)I('-I;&5R+CPO8CXB"@HC.B!L:6(O
M1')I=F5R+G!H<#HT,S@*;7-G:60@(E)E<75E<W1E9"!O8FIE8W0@;F]T(&9O
M=6YD+B(*;7-G<W1R(")"96QI<G1I;&5N(&YE<VYE(&)U;'5N86UA9/TN(@H*
M(SH@861D+G!H<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,3$S
M"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R("+6;G1A;OUM;/T@
M9&7P97)L97)I(&%T82(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T
M.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T:69I8V%T92(*;7-G<W1R
M(")3+TU)344@0>?]:R!397)T:69I:V%S_2(*"B,Z(&QI8B]$<FEV97(O;&1A
M<"YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4U1!4E143%,@9F%I;&5D
M.B`H)7,I("5S(@IM<V=S='(@(E-405)45$Q3(&)A_F%R_7/]>CH@*"5S*2`E
M<R(*"B,Z(&5D:70N<&AP.CDY(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S='(@(DMA>61E="(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-B!T96UP;&%T97,O
M8G)O=W-E+W-E87)C:"YI;F,Z,3$R"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI
M<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HT.0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B"FUS9W-T
M<B`B07)A(@H*(SH@;6EN:7-E87)C:"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@
M(E-E87)C:"!297-U;'1S.B(*;7-G<W1R(")!<F%M82!3;VYUYVQA<OTB"@HC
M.B!L:6(O87!I+G!H<#HQ,#$Q"FUS9VED(")396%R8V@@9F%I;&5D(@IM<V=S
M='(@(D%R86UA(&)A_F%R_7/]>B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,#,@;&EB
M+V%P:2YP:'`Z,3$P.2!L:6(O87!I+G!H<#HQ,3$X(&QI8B]A<&DN<&AP.C$Q
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B07)A;6$@8F'^87+]<_UZ.B`E<R(*"B,Z('1E;7!L871E<R]B;&]C
M:R]M:6YI<V5A<F-H+FEN8SHR,@IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S
M='(@(D%R_7EO<BXN+B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC
M.C8V"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@861D<F5S<R!B;V]K('1O
M(&1E;&5T92(*;7-G<W1R(")697)I;&5R:6X@9/W^87+](&%K=&%R_6QA8V'P
M_2!A9')E<R!D969T97)I;FD@<V7G:6XZ(@H*(SH@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A9&1R
M97-S(&)O;VL@=&\@961I="(*;7-G<W1R(")697)I;&5R:6X@:>=I;F4@86MT
M87+];&%C8?#](&%D<F5S(&1E9G1E<FEN:2!S9>=I;CHB"@HC.B!T96UP;&%T
M97,O9&%T82]E>'!O<G0N:6YC.C,R"FUS9VED(")396QE8W0@=&AE(&%D9')E
M<W,@8F]O:R!T;R!E>'!O<G0@9G)O;3HB"FUS9W-T<B`B5F5R:6QE<FEN(&3]
M_F%R_2!A:W1A<OUL86-A\/T@861R97,@9&5F=&5R:6YI('-EYVEN.B(*"B,Z
M('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,C8*;7-G:60@(E-E;&5C="!T
M:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SHB"FUS9W-T<B`B5F5R:6QE
M<FEN(&GG:6YE(&%K=&%R_6QA8V'P_2!A9')E<R!D969T97)I;FD@<V7G:6XZ
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHS-0HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T('1H92!C:&%R<V5T(&]F('1H92!S;W5R8V4@9FEL93HB
M"FUS9W-T<B`B2V%Y;F%K(&1O<WEA;OUN(&)IYVEM:6YI('-EYVEN.B(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,3`*;7-G:60@(E-E;&5C="!T
M:&4@97AP;W)T(&9O<FUA=#HB"FUS9W-T<B`B1/W^87+](&%K=&%R;6$@8FGG
M:6UI;FD@<V7G:6XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT
M,PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`B
MW>=E<FD@86MT87+];&%C86L@9&]S>6%Y_2!S9>=I;CHB"@HC.B!T96UP;&%T
M97,O9&%T82]I;7!O<G0N:6YC.C$Q"FUS9VED(")396QE8W0@=&AE(&9O<FUA
M="!O9B!T:&4@<V]U<F-E(&9I;&4Z(@IM<V=S='(@(DMA>6YA:R!D;W-Y86[]
M;B!B:>=I;6EN:2!S9>=I;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,U"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!U<V5D('1O(&1I<W!L87D@
M;F%M97,Z(@IM<V=S='(@(MUS:6UL97)I;B!G]G+\;G3\;&5N96-E\&D@8FGG
M:6UI('-EYVEN.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-0HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT
M+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T:6]N<RXB"FUS9W-T<B`B
MUFYT86[];6S](&?V<OQN_&W\('-EYVEN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.`IM<V=I9"`B4V5L96-T('=H:6-H(&9I96QD<R!T;R!D:7-P
M;&%Y(&EN('1H92!A9&1R97-S(&QI<W1S+B(*;7-G<W1R(")!9')E<R!L:7-T
M96QE<FEN9&4@:&%N9VD@86QA;FQA<OUN(&?V<OQN=/QL96YE8V7P:6YI('-E
MYVEN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4V5L
M96-T('=H:6-H(&9O<FUA="!T;R!D:7-P;&%Y(&YA;65S+B(*;7-G<W1R("+=
M<VEM;&5R:6X@9_9R_&YT_&QE;F5C9?!I(&)IYVEM:2!S9>=I;BXB"@HC.B!A
M9&0N<&AP.C4T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")396QE8W1E
M9"!A9&1R97-S(&)O;VL@7"(E<UPB+B(*;7-G<W1R(")39>=I;&5N(&%D<F5S
M(&1E9G1E<FD@)R5S)RXB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HQ
M-S,*;7-G:60@(E-H87)E9"!$:7)E8W1O<GDB"FUS9W-T<B`B4&%Y;&'^_6QA
M;B!$:7II;B(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T<B`B
M1_9S=&5R(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,0IM
M<V=I9"`B4VAO=R!!;&PB"FUS9W-T<B`B5/QM_&[\($?V<W1E<B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z-#`*;7-G:60@(E-H;W<@0V]N
M=&%C=',B"FUS9W-T<B`BW6QE=&G^:6T@3F]K=&%L87+];OT@1_9S=&5R(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B4VAO
M=R!,:7-T<R(*;7-G<W1R("),:7-T96QE<FD@1_9S=&5R(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,C$*(SH@=&5M<&QA=&5S
M+V)R;W=S92]C;VQU;6Y?:&5A9&5R<RYI;F,Z,S0*;7-G:60@(E-O<G0@1&ER
M96-T:6]N(@IM<V=S='(@(E/]<F%L86UA(%GV;OPB"@HC.B!L:6(O87!I+G!H
M<#HQ.3@*;7-G:60@(E-O=7)C97,B"FUS9W-T<B`B2V%Y;F%K;&%R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U-PIM<V=I9"`B4W!E8VEF>2!W:&5R
M92!Y;W4@=V%N="!A9'9A;F-E9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N
M(@IM<V=S='(@(D=E;&G^;6G^(&%R86UA('-O;G7G;&%R_6[];B!N97)E9&4@
M9_9R_&YT_&QE;F5C9?!I;FD@8F5L:7)T:6XN(@H*(SH@8G)O=W-E+G!H<#HQ
M-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("5S
M('1O("5S(@IM<V=S='(@(B5S("5S(&4@8F'^87+]>6QA(&5K;&5N9&DB"@HC
M.B!B<F]W<V4N<&AP.C(R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&-R96%T960@=&AE(&-O;G1A8W0@;&ES="!<(B5S7"(N
M(@IM<V=S='(@(B5S("5S(&4@8F'^87+]>6QA(&5K;&5N9&DB"@HC.B!D871A
M+G!H<#HU,`IM<V=I9"`B5%-6(@IM<V=S='(@(E135B(*"B,Z('1E;7!L871E
M<R]D871A+VEM<&]R="YI;F,Z,30@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ-`IM<V=I9"`B5&%B('-E<&%R871E9"!V86QU97,B"FUS9W-T<B`B5&%B
M(&EL92!A>7+];&W]_B!D9?!E<FQE<B(*"B,Z('9I97<N<&AP.C$U"FUS9VED
M(")4:&4@5D93(&)A8VME;F0@;F5E9',@=&\@8F4@8V]N9FEG=7)E9"!T;R!E
M;F%B;&4@871T86-H;65N="!U<&QO861S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HQ,#4T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@861D<F5S<R!B;V]K(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B061R97,@9&5F=&5R:2!B;_YA;'3];&%M863].B`E<R(*"B,Z(&%D9')E
M<W-B;V]K<RYP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!A9&1R97-S(&)O;VL@7"(E<UPB('=A<R!C<F5A=&5D('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`B061R97,@9&5F=&5R:2!B8?YA<OUY;&$@8F_^86QT_6QD
M_2XB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@<F5M;W9E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D%D<F5S(&1E9G1E<FD@8F'^87+]
M>6QA(&)O_F%L=/UL9/TN(@H*(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S
M7"(@=V%S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")!9')E<R!D
M969T97)I(&)A_F%R_7EL82!B;_YA;'3];&3]+B(*"B,Z(&1A=&$N<&AP.C,P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(&-O=6QD
M(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(D%D<F5S(&1E9G1E<FD@8F_^
M86QT_6QA;6%D_3H@)7,B"@HC.B!E9&ET+G!H<#HT-R!V8V%R9"YP:'`Z,C(@
M9&ES<&QA>2YP:'`Z,C,@=FEE=RYP:'`Z,C8*;7-G:60@(E1H92!C;VYT86-T
M('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D)E;&ER
M='1I\&EN:7H@:6QE=&G^:6T@;F]K=&%S_2!Y;VLN(@H*(SH@961I="YP:'`Z
M,3$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92!<(B5S
M7"(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N(@IM<V=S='(@(B5S
M(&1O<WEA<_T@8F'^87+]>6QA("AIYV5R:2D@86MT87+];&3](@H*(SH@9&%T
M82YP:'`Z,C@T"FUS9VED(")4:&4@:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D
M97-P:71E('1H92!W87)N:6YG<RXB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H
M<#HS,0IM<V=I9"`B5&AE<F4@87)E(&YO(&)R;W=S96%B;&4@861D<F5S<R!B
M;V]K<RXB"FUS9W-T<B`B1_9Z873];&%B:6QE8V5K(&)I<B!A9')E<R!D969T
M97)I('EO:R(*"B,Z(&%D9"YP:'`Z,CD*;7-G:60@(B(*(E1H97)E(&%R92!N
M;R!W<FET96%B;&4@861D<F5S<R!B;V]K<RX@3F]N92!O9B!T:&4@879A:6QA
M8FQE(&%D9')E<W,@8F]O:W,@(@HB87)E(&-O;F9I9W5R960@=&\@86QL;W<@
M>6]U('1O(&%D9"!N97<@96YT<FEE<R!T;R!T:&5M+B!)9B!Y;W4@8F5L:65V
M92!T:&ES("(*(FES(&%N(&5R<F]R+"!P;&5A<V4@8V]N=&%C="!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)987K];&%B:6QI<B!B
M:7(@861R97,@9&5F=&5R:2!Y;VLN(%9A<F]L86X@861R97,@9&5F=&5R;&5R
M:6YI;B!H:>=B:7)I('EE;FD@(@HB9VER:?YL97(@96ML97EE8FEL96-E\&EN
M:7H@_F5K:6QD92!Y87#];&%N9/UR_6QM86W]_BX@1?!E<B!B=6YU;B!B:7(@
M:&%T82`B"B)D=7)U;74@;VQD=?!U;G4@9/S^_&[\>6]R<V%N_7H@;/QF=&5N
M('-I<W1E;2!Y]FYE=&EC:6YI>F4@8F'^=G5R=6XN(@H*(SH@861D+G!H<#HQ
M,C$*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE
M=R!C;VYT86-T+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M(@HB9F]R(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB665N:2!I;&5T:?YI
M;2!N;VMT87/](&5K;&5R:V5N(&AA=&$@;VQU_G1U+B!,_&9T96X@<VES=&5M
M("(*(GGV;F5T:6-I;FEZ96)A_G9U<G5N+B(*"B,Z(&)R;W=S92YP:'`Z,3@Y
M(&)R;W=S92YP:'`Z,C,P"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@861D:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R(")"=2!N97-N97EI
M('-I;&5R:V5N(&AA=&$@;VQU_G1U+B(*"B,Z(&)R;W=S92YP:'`Z,C,X"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@;&ES="XB
M"FUS9W-T<B`B665N:2!L:7-T92#\<F5T:6QI<FME;B!H871A(&]L=?YT=2XB
M"@HC.B!A9&1R97-S8F]O:W,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A9&1R
M97-S(&)O;VLZ("5S(@IM<V=S='(@(D)U(&MA>?UT_2!G_&YC96QL97)K96X@
M:&%T82!O;'7^='4Z("5S(@H*(SH@8G)O=W-E+G!H<#HQ-#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!<(B5S7"(@9G)O;2!T:&4@<V]U<F-E(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B2V%Y;F%K(&%D<F5S(&1E9G1E<FEN9&5N("5S)WEI('-I;&5R:V5N(&AA
M=&$@;VQU_G1U+B(*"B,Z(&1E;&5T92YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C
M=#H@)7,B"FUS9W-T<B`B0G4@:6QE=&G^:6T@;F]K=&%S_6[]('-I;&5R:V5N
M(&AA=&$@;VQU_G1U.B`E<R(*"B,Z(&)R;W=S92YP:'`Z-S(*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&ES(&]B:F5C="XB"FUS9W-T
M<B`B0G4@;F5S;F5Y:2!S:6QE<FME;B!H871A(&]L=?YT=2XB"@HC.B!B<F]W
M<V4N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AE(&QI<W0B"FUS9W-T<B`B4V7G:6QE;B!L:7-T97EI
M(&?V<OQN=/QL97)K96X@:&%T82!O;'7^='4B"@HC.B!D871A+G!H<#HS,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`B5F5R:7EI(&GG97)I(&%K=&%R
M_7)K96X@:&%T82!O;'7^='4Z("5S(@H*(SH@;&EB+V%P:2YP:'`Z-3`W(&QI
M8B]A<&DN<&AP.C<V,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<B!V
M97)I<VEN:2!IYV5R:2!A:W1A<OUR:V5N(&AA=&$@;VQU_G1U+B(*"B,Z(&)R
M;W=S92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!R96UO=FEN9R!A(&-O;G1A8W0@9G)O;2!T:&4@;&ES="XB"FUS9W-T<B`B
M665N:2!L:7-T92#\<F5T:6QI<FME;B!H871A(&]L=?YT=2XB"@HC.B!A9&1R
M97-S8F]O:W,N<&AP.C4U(&%D9')E<W-B;V]K<RYP:'`Z-C`@861D<F5S<V)O
M;VMS+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*
M;7-G<W1R(")"=2!N97-N97EI('-I;&5R:V5N(&AA=&$@;VQU_G1U+B(*"B,Z
M(&%D9')E<W-B;V]K<RYP:'`Z.#$@861D<F5S<V)O;VMS+G!H<#HX-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R(")"=2!K87G]
M=/T@9_QN8V5L;&5R:V5N(&AA=&$@;VQU_G1U.B`E<R(*"B,Z(&5D:70N<&AP
M.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AI<R!E;G1R>3H@)7,B"FUS9W-T<B`B0G4@:V%Y_73](&?\
M;F-E;&QE<FME;B!H871A(&]L=?YT=3H@)7,B"@HC.B!D871A+G!H<#HQ-SD*
M;7-G:60@(E1H97)E('=E<F4@;F\@861D<F5S<V5S('1O(&5X<&]R="XB"FUS
M9W-T<B`B1/W^87+](&%K=&%R_6QA8V%K(&AIYR!A9')E<R!Y;VLN(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#`*;7-G
M:60@(E1H97-E(&%D9')E<W,@8F]O:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@
M;W)D97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS
M96QE8W0N:6YC.C(T,PIM<V=I9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L
M87D@:6X@=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C8Y
M"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(D)U(&1O<WEA(&)IYVEM:2!D97-T96ML96YM:7EO<BXB"@HC.B!L
M:6(O87!I+G!H<#HQ,3(R(&QI8B]A<&DN<&AP.C$Q,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H87,@82`E<R!E;G1R>2!I
M;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(D)U(&MI_FEY92!A:70@)7,@
M:V%Y_73](&%D<F5S(&1E9G1E<FEN9&4@;65V8W5T+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#<*;7-G:60@(B(*(E1H:7,@=VEL;"!B92!T:&4@
M9&5F875L="!A9&1R97-S(&)O;VL@=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG
M(&-O;G1A8W1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HW,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`BW&YV86XB"@HC.B!L
M:6(O5'5R8F$N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(&YE=R!S:&%R92X@($UI<W-I;F<@<V]U<F-E('1Y<&4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.CDW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`B)7,@=&%N_6W]('G\:VQE;F5M:7EO<BXB"@HC.B!E9&ET+G!H
M<#HX."!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HY.2!E9&ET
M+G!H<#HQ.38*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")$9?!I_FEK
M;&EK;&5R:2!'97)I($%L(@H*(SH@;&EB+V%P:2YP:'`Z-30P(&QI8B]A<&DN
M<&AP.C8T,R!L:6(O87!I+G!H<#HW-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B
M1&5S=&5K;&5N;65Y96X@W>=E<FEK(%3\<OPB"@HC.B!C;VYF:6<O<V]U<F-E
M<RYP:'`N9&ES=#HS-S8*;7-G:60@(E9E<FES:6=N($1I<F5C=&]R>2(*;7-G
M<W1R(")697)I<VEG;B!$:7II;FDB"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O
M=RYI;F,Z,3D@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHR-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!<(B5S7"(B"FUS9W-T
M<B`B)R5S)R!']G+\;G3\;&4B"@HC.B!M:6YI<V5A<F-H+G!H<#HW.`IM<V=I
M9"`B5FEE=R!#;VYT86-T(@IM<V=S='(@(MUL971I_FEM($YO:W1A<_UN_2!'
M]G+\;G3\;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED
M(")6:65W('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS9W-T<B`BUFYT86[]
M;6S](&?V<OQN_&TB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HR
M,#@*;7-G:60@(E=E8G-I=&4@55),(@IM<V=S='(@(E=E8B!S87EF87/](&%D
M<F5S:2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$Q,PIM<V=I
M9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(MW^($%D<F5S:2(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$R-`IM<V=I9"`B5V]R:R!#:71Y(@IM
M<V=S='(@(MYE:&ER(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3,Y"FUS9VED(")7;W)K($-O=6YT<GDB"FUS9W-T<B`BW&QK92(*"B,Z(&-O
M;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U-@IM<V=I9"`B5V]R:R!0:&]N
M92(*;7-G<W1R("+=_B!496QE9F]N=2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.C$S-`IM<V=I9"`B5V]R:R!0;W-T86P@0V]D92(*;7-G<W1R
M(")0;W-T82!+;V1U(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M,3(Y"FUS9VED(")7;W)K(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(D+V;&=E
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3$Y"FUS9VED(")7
M;W)K(%-T<F5E="!!9&1R97-S(@IM<V=S='(@(MW^($%D<F5S:2(*"B,Z(&1A
M=&$N<&AP.C(S-R!B<F]W<V4N<&AP.CDS(&)R;W=S92YP:'`Z,C`Q(&%D9"YP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E
M9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S(&EN(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@961I="YP:'`Z-CD@9&ES<&QA>2YP:'`Z-3@@=FEE
M=RYP:'`Z,S8*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O
M('9I97<@=&AI<R!C;VYT86-T+B(*;7-G<W1R(")"=2!I;&5T:?YI;2!N;VMT
M87/];OT@9_9R_&YT_&QE;65Y92!I>FYI;FEZ('EO:RXB"@HC.B!V8V%R9"YP
M:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I
M97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(D)U(&YE<VYE>6D@9_9R_&YT_&QE
M;65Y92!I>FYI;FEZ('EO:RXB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S
M8W)I<'0N:6YC.C4U"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@
M861D<F5S<R!B;V]K+B(*;7-G<W1R(")":7(@:&5D968@861R97,@9&5F=&5R
M:2!S9>=M96QI<VEN:7HN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R
M:7!T+FEN8SHR,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI
M<W0N(@IM<V=S='(@(D)I<B!H961E9B!L:7-T92!S9>=M96QI<VEN:7HN(@H*
M(SH@961I="YP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A="!L96%S="!O;F4@8V]N=&%C="!F:7)S="XB"FUS9W-T<B`BUFYC92!E
M;B!A>B!B:7(@:W-Y_70@<V7G;65L:7-I;FEZ+B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]J879A
M<V-R:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N
M:6YC.C<R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&5N
M=')Y(&9I<G-T+B(*;7-G<W1R("+6;F-E(&5N(&%Z(&)I<B!K<WG]="!S9>=M
M96QI<VEN:7HN(@H*(SH@961I="YP:'`Z-S,*;7-G:60@(EEO=2!O;FQY(&AA
M=F4@<&5R;6ES<VEO;B!T;R!V:65W('1H:7,@8V]N=&%C="XB"FUS9W-T<B`B
M0G4@:6QE=&G^:6T@;F]K=&%S_6[]('-A9&5C92!G]G+\;G3\;&5M92!I>FYI
M;FEZ('9A<BXB"@HC.B!B<F]W<V4N<&AP.C(X-0IM<V=I9"`B66]U<B!D969A
M=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E86)L92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C8@=&5M<&QA=&5S+V)R
M;W=S92]C;VYT86-T<F]W+FEN8SHQ,@IM<V=I9"`B6VYO('9A;'5E72(*;7-G
M<W1R(");9&7P97(@>6]K72(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@T"FUS9VED
M(")?0G)O=W-E(@IM<V=S='(@(E]']GIA="(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(E]#;VYT86-T<R(*
M;7-G<W1R("+=;&5T:?YI;2!?3F]K=&%L87+];OT@1_9S=&5R(@H*(SH@=&5M
M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"FUS9VED(")?1&5L971E(@IM
M<V=S='(@(E-?:6PB"@HC.B!L:6(O5'5R8F$N<&AP.C0Y,PIM<V=I9"`B7TEM
M<&]R="]%>'!O<G0B"FUS9W-T<B`BW>=E<FDO7T3]_F%R_2!!:W1A<B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z>GD*;7-G
M:60@(E],:7-T<R(*;7-G<W1R("),:7-T92(*"B,Z(&QI8B]4=7)B82YP:'`Z
M-#@Q"B,L(&9U>GIY"FUS9VED(")?37D@061D<F5S<R!";V]K<R(*;7-G<W1R
M(")!9')E<R!$969T97)I;2(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@W"B,L(&9U
M>GIY"FUS9VED(")?3F5W($-O;G1A8W0B"FUS9W-T<B`B665N:2#=;&5T:?YI
M;2!.;VMT87/](@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR
M"FUS9VED(")?4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@(D)?=2!L
M:7-T961E;B!S:6PB"@HC.B!L:6(O5'5R8F$N<&AP.C0X.0IM<V=I9"`B7U-E
M87)C:"(*;7-G<W1R(")?07)A;6$B"@HC.B!V8V%R9"YP:'`Z-#8*;7-G:60@
M(F-O;G1A8W0N=F-F(@IM<V=S='(@(F-O;G1A8W0N=F-F(@H*(SH@9&%T82YP
M:'`Z,3DY(&1A=&$N<&AP.C(P-"!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC
M.C$*;7-G:60@(F-O;G1A8W1S+F-S=B(*;7-G<W1R(")C;VYT86-T<RYC<W8B
M"@HC.B!D871A+G!H<#HR,#D*;7-G:60@(F-O;G1A8W1S+G1S=B(*;7-G<W1R
M(")C;VYT86-T<RYT<W8B"@HC.B!D871A+G!H<#HR,3D*(RP@9G5Z>GD*;7-G
M:60@(F-O;G1A8W1S+G9C9B(*;7-G<W1R(")C;VYT86-T+G9C9B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@
M(FYO;F4B"FUS9W-T<B`B2&GG8FER:2(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(G1O(&$@0V]N=&%C="!,
M:7-T(@IM<V=S='(@(MUL971I_FEM($YO:W1A;&%R_6[]($?V<W1E<B(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,30*(RP@9G5Z>GD*;7-G
M:60@(G1O(&$@9&EF9F5R96YT($%D9')E<W,@0F]O:R(*;7-G<W1R(")39>=I
M;&5N($%D<F5S($1E9G1E<FEN92(*"B,Z(&1A=&$N<&AP.C4Q('1E;7!L871E
M<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$S"B,Z('1E;7!L871E<R]D
M871A+VEM<&]R="YI;F,Z,34@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+V5L7T=2+G!O
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S4P
M-C4`,3`T,3<S-C(W-38`,#$W-3(T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@5'5R8F$@1W)E96L@=')A;G-L871I;VXN
M"B,@0V]P>7)I9VAT("A#*2`R,#`R(%-T969A;F]S($DN($1I;6ET<FEO=2X*
M(R!3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-U<'!O<G1?=V5B;6%I;$!T96EA
M=&@N9W(^+"`R,#`R+@HC(%-I;&QI9V%R9&]S(%AR:7-T;V9O<F]S+"`R,#`R
M+@HC($%N86=N;W-T;W!O=6QO<R!!<&]S=&]L:7,L(#(P,#(N"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%1U<F)A.B`Q+C(M
M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,2TP-RTR-B`Q,3HS-BLP
M,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%-T969A;F]S($DN($1I;6ET<FEO
M=2`\<W5P<&]R=%]W96)M86EL0'1E:6%T:"YG<CY<;B(*(DQA;F=U86=E+51E
M86TZ($=R965K(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#UI<V\M.#@U.2TW7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M+6)I=%QN(@H*(SH@=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHT,@HC
M+"!F=7IZ>0IM<V=I9"`B($%D9"!A;B!)35-0($%D9')E<W,@0F]O:R(*;7-G
M<W1R("+$Z>7UZ/7M\^GOX_'<]N_R(%!I;F4B"@HC.B!T96UP;&%T97,O<')E
M9G,O:6US<%]O<'0N:6YC.C,Q"B,L(&9U>GIY"FUS9VED("(@1&5L971E($E-
M4U`@061D<F5S<R!";V]K(@IM<V=S='(@(L7PZ>O=[O3E(,3IY?7H]>WSZ>_C
M\=SV[R(*"B,Z(&1A=&$N<&AP.C,R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@86QR96%D>2!E>&ES=',@86YD('=A<R!N;W0@:6UP;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z,3(V"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@;F]T(&-O<&EE9"!B96-A=7-E(&ET(&ES(&$@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@8G)O=W-E+G!H<#HQ,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S<*;7-G:60@(EPB1FER<W1N86UE($QA<W1N86UE7"(@("AI92X@2F]H;B!$
M;V4I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*
M;7-G:60@(EPB3&%S=&YA;64L($9I<G-T;F%M95PB("AI92X@1&]E+"!*;VAN
M*2(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C$P.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,S0S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&9I;&4@<W5C8V5S<V9U;&QY(&EM<&]R
M=&5D(@IM<V=S='(@(B5S(,7PZ?3U]_[R(.7I\^'C^>/>(/3O]2#A\??EW^_U
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T97(N:6YC.C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+U1U<F)A+G!H<#HT-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@061D<F5S<R!";V]K(@IM<V=S='(@(L3IY?7H]>WSZ>_C\=SV[_(@4&EN
M92(*"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HT-0IM<V=I9"`B02!B
M<F]W<V5R('1H870@<W5P<&]R=',@:49R86UE<R!I<R!R97%U:7)E9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Y"FUS9VED(")!
M8F]V92!S96%R8V@@9F]R;2(*;7-G<W1R("(B"@HC.B!V:65W+G!H<#HU,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!8V-E<W,@9&5N:65D('1O("5S(@IM<V=S
M='(@(B(*"B,Z(&%D9"YP:'`Z-38@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHR,@IM<V=I9"`B061D(@IM<V=S='(@(M#Q[_/HWNKG(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ-S0*(RP@9G5Z
M>GD*;7-G:60@(D%D9"!A9&1R97-S(&)O;VLB"FUS9W-T<B`BR^'MZ.'S[-WM
M[R#"Z>+KW^\@Q.GE]>C][?/E^>TN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0X"B,L(&9U>GIY"FUS9VED(")!9&0@86YD($1E;&5T92!)35-0(&%D
M9')E<W,@8F]O:W,B"FUS9W-T<B`BQ.7M(/7PW/'W[_7M(.3IY?7H]>WSZ>_C
M\=SV[^D@\_3O]?(@[_#OW^_U\B#L\._QY=_TY2#MX2#C\=SXY?3E+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(S-PHC+"!F=7IZ
M>0IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("+P\>_SZ-[JYR#S]-[KY_(B
M"@HC.B!E9&ET+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D%D9"!F:6QE(@IM
M<V=S='(@(L<@\/'O\^C>ZN<@X?#=]/7WY2(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D%D9"!T;R(*;7-G<W1R("+0\>_S
MZ-[JYR#S].\B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX-@HC
M+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(L3IY?7H]>WS
MZ>_C\=SV[_(@4&EN92(*"B,Z(&)R;W=S92YP:'`Z,C@@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-0IM<V=I9"`B061D<F5S<R!";V]K($QI<W1I;F<B"FUS
M9W-T<B`BR]_S].$@Q.GE]>C][?/E^>TB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T
M<B`BN.[OY._R(.'P_"#T[R#$Z>7UZ/7M\^GOX_'<]N\B"@HC.B!A9&0N<&AP
M.C$P.`HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!B;V]K(&5N=')Y(@IM<V=S
M='(@(L\@Y.GE]>CU[?/I[^/QW/;O\B#EW^WAZ2#L_.WO(./IX2#A[=SC[?GS
MYRXB"@HC.B!D871A+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@
M8F]O:R!S=6-C97-S9G5L;'D@<'5R9V5D+B(*;7-G<W1R("*XX^GMY2#E\.GT
M]??^\B#EZ?/AX_GCWB#T[_4@Y.GE]>CU[?/I[^/QW/;O]2!0:6YE(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C(*(RP@9G5Z>GD*;7-G:60@
M(D%D9')E<W,@8F]O:R!T;R!D96QE=&4@(@IM<V=S='(@(L\@Y.GE]>CU[?/I
M[^/QW/;O\B#EW^WAZ2#L_.WO(./IX2#A[=SC[?GSYRXB"@HC.B!T96UP;&%T
M97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`IM<V=I9"`B061D
M<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T
M<B`B(@H*(SH@<V5A<F-H+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C
M:"YI;F,Z,S<*;7-G:60@(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R("+%Z>3I
MZMX@P>WAYM[TY_/G(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z
M-C0*;7-G:60@(D%L:6%S(@IM<V=S='(@(MCE]>3^[?7L[R(*"B,Z('1E;7!L
M871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S+V)R;W=S
M92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(KSKX2(*"B,Z(&QI8B]A
M<&DN<&AP.C4U,@IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHY,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@=&AA="!Y;W4@=V%N="!T;R!D
M96QE=&4@)7,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V
M87-C<FEP="YI;F,Z-C<*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W
M86YT('1O(&1E;&5T92!T:&4@<V5L96-T960@96YT<FEE<S\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!<V-E;F1I
M;F<B"FUS9W-T<B`BP?WN[_7SX2(*"B,Z('-E87)C:"YP:'`Z.#4@=&5M<&QA
M=&5S+V)R;W=S92]S96%R8V@N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")"87-I
M8R!396%R8V@B"FUS9W-T<B`BP>WAYM[TY_/G(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U.`IM<V=I9"`B0F5L;W<@<V5A<F-H(&9O<FTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-R!L:6(O1')I=F5R+VQD
M87`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@9F%I;&5D.B`H
M)7,I("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUE;G4N:6YC.C<*;7-G:60@(D)R;W=S92(*;7-G<W1R("++W_/TX2(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$W,PHC+"!F=7IZ>0IM
M<V=I9"`B0G5S:6YE<W,@0V%T96=O<GDB"FUS9W-T<B`BRN'TY^/O\=_A(,7Q
MX^'SW^'R(@H*(SH@9&%T82YP:'`Z-#D*;7-G:60@(D-35B(*;7-G<W1R("(B
M"@HC.B!L:6(O3V)J96-T+T=R;W5P+G!H<#HU-PIM<V=I9"`B0V%N)W0@861D
M(&$@9W)O=7`@=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHW"FUS9VED(")#:&5C:R!?06QL
M+TYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI
M;F,Z-#0*;7-G:60@(D-H;V]S92!A(&YA;64B"FUS9W-T<B`B(@H*(SH@861D
M+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E<W,@8F]O
M:R(*;7-G<W1R("++X>WHX?/LW>WO(,+IXNO?[R#$Z>7UZ/WM\^7Y[2XB"@HC
M.B!T96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,C$*(RP@9G5Z
M>GD*;7-G:60@(D-H;V]S92!A;B!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(LOA
M[>CA\^S=[>\@PNGBZ]_O(,3IY?7H_>WSY?GM+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,38U"FUS9VED(")#:&]O<V4@
M=VAI8V@@861D<F5S<R!B;V]K<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O
M<F1E<CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S<R!B;V]K<R!T;R!U<V4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(R.`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('=H:6-H(&-O;'5M;G,@=&\@
M9&ES<&QA>2!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T<B`B(@HBQ?#IZ^_C
MWB#TY_(@\^7I\=SR(/3Y[2#S].?K_NT@ZN'TW"#TY^T@\/'OXN_KWB#TY_(@
MZ]_S].'R(/3Y[2#DZ>7UZ/WM\^7Y[2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3<*;7-G:60@(D-O;'5M;B!/<'1I;VYS(@IM<V=S='(@(L7PZ>OO
MX]WR(-/TY^O^[2(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(S,PIM<V=I9"`B0V]L=6UN<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L
M87EE9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN
M8SHQ,R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")#;VUM
M82!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(M3I[-WR(.3IX??Y\>GS[-WM
MY?(@[.4@ZOSL[.$B"@HC.B!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")#;VUM82!S97!A<F%T960@=F%L=65S("A-:6-R
M;W-O9G0@3W5T;&]O:RDB"FUS9W-T<B`BU.GLW?(@Y.GA]_GQZ?/LW>WE\B#L
MY2#J_.SLX2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<V"FUS
M9VED(")#;VUP86YY(@IM<V=S='(@(L7TX>GQW^$B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-#0*(RP@9G5Z>GD*;7-G:60@(D-O;7!A;GD@
M061D<F5S<R(*;7-G<W1R("+$Z>7]Z/7M\^<@RN'T[^GJW^'R(@H*(SH@;&EB
M+V%P:2YP:'`Z,S$X(&QI8B]A<&DN<&AP.C,V,R!L:6(O87!I+G!H<#HT,#<@
M;&EB+V%P:2YP:'`Z-#DQ"B,Z(&QI8B]A<&DN<&AP.C8P,2!L:6(O87!I+G!H
M<#HV.#@@;&EB+V%P:2YP:'`Z-S0Q(&QI8B]A<&DN<&AP.C@Q.0HC.B!L:6(O
M87!I+G!H<#HQ,#`V(&QI8B]A<&DN<&AP.C$P.30*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+$
MZ>'C\>'VWB#A\-WT]??E(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HU.`HC
M+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(L3I
MX>/QX?;>(.'PW?3U]^4B"@HC.B!B<F]W<V4N<&AP.C$Y,2!B<F]W<V4N<&AP
M.C(S,@HC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C="!A9&1E9"!T;R!L:7-T+B(*
M;7-G<W1R("+'(.KA\?3=Z^$@X?;AZ?'=Z.?JY2#A\/P@].<@Z]_S].$N(@H*
M(SH@8G)O=W-E+G!H<#HV,`IM<V=I9"`B0V]N=&%C="!R96UO=F5D(&9R;VT@
M;&ES="XB"FUS9W-T<B`BQR#JX?'TW>OA(.'VX>GQW>CGZN4@X?#\(/3G(.O?
M\_3A+B(*"B,Z(&)R;W=S92YP:'`Z,C8V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYT86-T<R!I;B!L:7-T.B`E<R(*;7-G<W1R("+$Z>7UZ/WM
M\^7I\B#S].<@Z]_S].$Z("5S(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I
M;VYS+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*;7-G<W1R("+%].'I
M\=_A(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-3,*;7-G:60@
M(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS
M+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O:R(*
M;7-G<W1R("+%[N'C^>/>(,+IXNO?[_4@Q.GE]>C][?/E^>TB"@HC.B!L:6(O
M3&ES=%9I97<N<&AP.C,Q-0IM<V=I9"`B0W)E871E(&$@;F5W($-O;G1A8W0@
M3&ES="!I;CHB"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S
M,PIM<V=I9"`B0W)E871E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3@*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ
M(@IM<V=S='(@(M#Q[^7PZ>OEX^S=[><@ZN'TY?WH]>WSYR#TX>[I[?SLY_/G
M\CHB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHW-B!T96UP;&%T
M97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*(SH@;&EB+T]B:F5C="YP:'`Z,S(X
M(&QI8B]296YD97)E<BYP:'`Z-#<@;&EB+U)E;F1E<F5R+G!H<#HU,`IM<V=I
M9"`B1&5L971E(@IM<V=S='(@(L3IX>/QX?;>(@H*(SH@=&5M<&QA=&5S+V%D
M9')E<W-B;V]K<RYI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!!9&1R
M97-S($)O;VLB"FUS9W-T<B`BQ?#IZ]WN].4@Q.GE]>CU[?/I[^/QW/;O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")$96QE=&4@0V]N
M9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.0IM<V=I9"`B1&5L971E(&)U='1O;B!B96AA=FEO=7(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HR-S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!F86EL960Z("@E<RD@)7,B"FUS9W-T<B`B
MQ.GAX_'A]MX@X?#=]/7WY2(*"B,Z(&1E;&5T92YP:'`Z,S@*;7-G:60@(D1E
M;&5T:6]N(&9A:6QE9"(*;7-G<W1R("+$Z>'C\>'VWB#A\-WT]??E(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C$S"FUS9VED(")$97!A<G1M
M96YT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("+6Z-_M[_7SX2(*"B,Z('1E;7!L
M871E<R]A9&1R97-S8F]O:W,N:6YC.C$Q-0HC+"!F=7IZ>0IM<V=I9"`B1&5S
M8W)I<'1I;VXB"FUS9W-T<B`BQ?#IZ^_CW?(@U_'>\_3G(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]S96%R8V@N:6YC.C$Q.`IM<V=I9"`B1&ER96-T;W)Y(@IM
M<V=S='(@(LKA]-SK[^/O\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R("+%\.GK[^/=\B#%
M[/;<[>GSY_(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`IM<V=I9"`B1&ES<&QA>2!/<'1I
M;VYS(@IM<V=S='(@(L7PZ>OOX]WR(,7L]MSMZ?/G\B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D1O('EO=2!W86YT('1O(&-O;F9I
M<FT@9&5L971I;F<@96YT<FEE<S\B"FUS9W-T<B`B(@H*(SH@;&EB+T]B:F5C
M="YP:'`Z,CDW"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+W)O=RYI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]C;VYT
M86-T<F]W+FEN8SHR-0IM<V=I9"`B1&]W;FQO860@=D-A<F0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z,3`R('1E;7!L871E
M<R]B<F]W<V4O<F]W+FEN8SHR-0HC.B!T96UP;&%T97,O8G)O=W-E+V-O;'5M
M;E]H96%D97)S+FEN8SHQ,"!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC
M.C,*(SH@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W+FEN8SHS,R!L:6(O
M4F5N9&5R97(N<&AP.C0R"FUS9VED(")%9&ET(@IM<V=S='(@(L7PY>[E\>/A
M\]_A(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U('1E;7!L871E
M<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S='(@(L7PY>[E\>/A\]_A("<E
M<R<B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX,0HC+"!F=7IZ
M>0IM<V=I9"`B161I="!!9&1R97-S($)O;VMS(@IM<V=S='(@(KCN[^3O\B#A
M\/P@].\@Q.GE]>CU[?/I[^/QW/;O(@H*(SH@961I="YP:'`Z-S@@961I="YP
M:'`Z,34T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(&5N=')Y
M(&9O<B`E<R(*;7-G<W1R("+$Y>T@XO'=Z.?JY2`E<R#JX?3A]_[QZ?/G(./I
MX2`E<RXB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HU.`IM<V=I
M9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB"@HC.B!E9&ET+G!H<#HQ-#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@9F]R("5S('5P9&%T960L(&)U="!S
M879I;F<@=&AE('5P;&]A9&5D(&9I;&4@9F%I;&5D.B`E<R(*;7-G<W1R("(B
M"@HC.B!E9&ET+G!H<#HQ-#D@961I="YP:'`Z,34R"B,L('!H<"UF;W)M870*
M;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!B
M<F]W<V4N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")%;G1R>2!S=6-C97-S9G5L
M;'D@9&5L971E9"XB"FUS9W-T<B`B)7,@Q?#I]/7W_O(@Y>GSX>/YX]X@]._U
M(.'Q]^7?[_4B"@HC.B!L:6(O87!I+G!H<#HT,3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('-E87)C:&EN9R!T:&4@861D<F5S<R!B;V]K
M.B`E<R(*;7-G<W1R("+$Y>T@]?#<\??O]>T@Y.GE]>CU[?/I[^/QW/;OZ2#S
M]._U\B#O\._?[_7R(.SP[_'EW_3E(.WA(./QW/CE].4N(@H*(SH@=&5M<&QA
M=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]D871A+V5X<&]R
M="YI;F,Z-#$*;7-G:60@(D5X<&]R="(*;7-G<W1R("+%[N'C^>/>(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHV"FUS9VED(")%>'!O<G0@061D
M<F5S<R!";V]K(@IM<V=S='(@(L7NX>/YX]X@PNGBZ]_O]2#$Z>7UZ/WM\^7Y
M[2(*"B,Z('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,C$*;7-G:60@(D5X
M<&]R="!O;FQY('1H92!S96QE8W1E9"!C;VYT86-T<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHR-PIM<V=I9"`B17AP;W)T
M('1H92!F;VQL;W=I;F<@861D<F5S<R!B;V]K(&-O;7!L971E;'DN(@IM<V=S
M='(@(B(*"B,Z(&1A=&$N<&AP.C$S-"!D871A+G!H<#HR,C@@9&%T82YP:'`Z
M,CDW(&)R;W=S92YP:'`Z,S4@8G)O=W-E+G!H<#HY,`HC.B!B<F]W<V4N<&AP
M.C$Q,B!A9&0N<&AP.C8W('-E87)C:"YP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O
M:SH@)7,B"FUS9W-T<B`BP?#O]/7WW^$@ZN'TW"#TYR#S_>WDY?/G(//T[^T@
MY?#IZ^7C[-WM[R#DZ>7UZ/7M\^GOX_'<]N\N(@H*(SH@8G)O=W-E+G!H<#HQ
M,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A9&0@
M)7,@=&\@)7,Z("5S(@IM<V=S='(@(L'P[_3U]]_A(.KA]-P@].?M(.'MX>;>
M].?SYR#S]._M(.KA]-SK[^/O(#H@)7,B"@HC.B!B<F]W<V4N<&AP.C(W,@IM
M<V=I9"`B1F%I;&5D('1O(&)R;W=S92!L:7-T(@IM<V=S='(@(L'P[_3U]]_A
M(.KA]-P@].?M(.7L]MSMZ?/G(/3G\B#KW_/TX?(B"@HC.B!B<F]W<V4N<&AP
M.C,Q,`IM<V=I9"`B1F%I;&5D('1O(&)R;W=S92!T:&4@9&ER96-T;W)Y(@IM
M<V=S='(@(L'P[_3U]]_A(.KA]-P@].?M(/#Q[^+OZ]X@]._U(.KA].'K_./O
M]2(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z,S`Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C:&%N9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.
M(#T@)7,L($YE=R!$3B`]("5S+"!2;V]T(#T@)7,B"FUS9W-T<B`B(@H*(SH@
M8G)O=W-E+G!H<#HQ,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!F:6YD(&]B:F5C="!T;R!B92!A9&1E9#H@)7,B"FUS9W-T<B`B
MP?#O]/7WW^$@ZN'TW"#TY^T@X>WAYM[TY_/G(//T[^T@ZN'TW.OOX^\@.B`E
M<R(*"B,Z('-E87)C:"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T
M;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("+!\._T]???X2#J
MX?3<(/3G(//][>3E\^<@\_3O[2#E\.GKY>/LW>WO(.3IY?7H]>WSZ>_C\=SV
M[RXB"@HC.B!D871A+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O('-E87)C:"!T:&4@9&ER96-T;W)Y.B`E<R(*;7-G<W1R("+!\._T
M]???X2#JX?3<(/3G[2#A[>'FWO3G\^<@\_3O[2#JX?3<Z^_C[R`Z("5S(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,38W"FUS9VED(")&87@B
M"FUS9W-T<B`BUN'N(@H*(SH@961I="YP:'`Z,3(T(&1I<W!L87DN<&AP.C$P
M,`HC+"!F=7IZ>0IM<V=I9"`B1FEL97,B"FUS9W-T<B`BU-_TZ^_R(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C<P"FUS9VED(")&:6YD(@IM
M<V=S='(@(L'MX>;>].?SYR(*"B,Z(&5D:70N<&AP.CDW(&5D:70N<&AP.C$X
M-PHC+"!F=7IZ>0IM<V=I9"`B1FEN:7-H(@IM<V=S='(@(L'MX>;>].?SYR(*
M"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C0X"FUS9VED(")&:7)S
M="!.86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C(P,@IM<V=I9"`B1G)E96)U<WD@55),(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHX,PIM<V=I9"`B1G)O;2(*;7-G
M<W1R("+!\/PB"@HC.B!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HV,#0*(RP@
M9G5Z>GD*;7-G:60@(D=L;V)A;"!!9&1R97-S($)O;VLB"FUS9W-T<B`BQ.GE
M]>CU[?/I[^/QW/;O\B!-=6QB97)R>2(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M<F]W+FEN8SHT,R!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C0T
M"FUS9VED(")'<F]U<"(*;7-G<W1R("+/[-SDX2(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C@R"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T
M<B`BQ.GE_>CU[?/G(,KA]._IZM_A\B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S
M+G!H<"YD:7-T.CDS"FUS9VED(")(;VUE($-I='DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3`X"B,L(&9U>GIY"FUS9VED
M(")(;VUE($-O=6YT<GDB"FUS9W-T<B`BU.?KW?;Y[>\@RN'T[^GJW^'R(@H*
M(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34P"FUS9VED(")(;VUE
M(%!H;VYE(@IM<V=S='(@(M3GZ]WV^>WO(,KA]._IZM_A\B(*"B,Z(&-O;F9I
M9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P,PHC+"!F=7IZ>0IM<V=I9"`B2&]M
M92!0;W-T86P@0V]D92(*;7-G<W1R("+4Y^O=]OGM[R#*X?3OZ>K?X?(B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I
M9"`B2&]M92!3=&%T92]0<F]V:6YC92(*;7-G<W1R("+4Y^O=]OGM[R#*X?3O
MZ>K?X?(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HX.`HC+"!F
M=7IZ>0IM<V=I9"`B2&]M92!3=')E970@061D<F5S<R(*;7-G<W1R("+$Z>7]
MZ/7M\^<@RN'T[^GJW^'R(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z
M-3`V"FUS9VED("))35-0(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-PHC+"!F=7IZ>0IM<V=I9"`B24U34"!!9&1R97-S($)O;VL@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`BR]_S].$@Q.GE]>C][?/E^>TB"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS
M9W-T<B`BQ>GSX>/YX]X@PNGBZ]_O]2#$Z>7UZ/WM\^7Y[2(*"B,Z(&1A=&$N
M<&AP.C,V,0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T+T5X<&]R="!!9&1R97-S
M($)O;VMS(@IM<V=S='(@(L7I\^'C^>/>+\7NX>/YX]X@Q.GE]>CU[?/I[^/Q
MW/;O]2(*"B,Z(&QI8B]A<&DN<&AP.C4Y-B!L:6(O87!I+G!H<#HV.#,*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@240B"FUS9W-T<B`BR]SH[_(@_.WO[.$B
M"@HC.B!L:6(O87!I+G!H<#HR,S`@;&EB+V%P:2YP:'`Z-#`R(&QI8B]A<&DN
M<&AP.C0X-B!L:6(O87!I+G!H<#HU.3(*(SH@;&EB+V%P:2YP:'`Z-C<Y(&QI
M8B]A<&DN<&AP.C<S,2!L:6(O87!I+G!H<#HQ,#<W"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&%D9')E<W,@8F]O:R(*;7-G<W1R("++X>WHX?/LW>WO(,+I
MXNO?[R#$Z>7UZ/WM\^7Y[2XB"@HC.B!L:6(O87!I+G!H<#HQ,#@Q(&QI8B]A
M<&DN<&AP.C$Q-30@;&EB+V%P:2YP:'`Z,3(P-PHC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!E;6%I;"(*;7-G<W1R("++W.CO\B!E;6%I;"XB"@HC.B!L:6(O
M87!I+G!H<#HQ,#@Y"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&5N=')Y(@IM
M<V=S='(@(LO<Z._R(,KA].'W_O'I\^<N(@H*(SH@;&EB+T1R:79E<B]L9&%P
M+G!H<#HR-C8*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@:V5Y('-P96-I9FEE
M9"XB"FUS9W-T<B`BR]SH[_(@96UA:6PN(@H*(SH@;&EB+V%P:2YP:'`Z,3`X
M-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!N86UE(@IM<V=S='(@(LO<Z._R
M(/SM[^SA(@H*(SH@;&EB+V%P:2YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED(&]B:F5C=$ED(@IM<V=S='(@(LO<Z._R(,KA].'W_O'I\^<N(@H*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HS,`IM<V=I9"`B(@HB3$1!4"!S=7!P
M;W)T(&ES(')E<75I<F5D(&)U="!T:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V
M86EL86)L92!O<B!N;W0@;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O3V)J
M96-T5FEE=RYP:'`Z,3,X"FUS9VED("),87-T($UO9&EF:65D(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C4S"B,L(&9U>GIY
M"FUS9VED("),87-T($YA;64B"FUS9W-T<B`BO.WO[.$B"@HC.B!T96UP;&%T
M97,O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B3&ES="(*;7-G<W1R("+-W>$@R]_S].$B"@HC.B!T96UP;&%T97,O8G)O
M=W-E+W-E87)C:"YI;F,Z-S<*;7-G:60@(DUA=&-H:6YG(@IM<V=S='(@(M3A
MZ?'IW.;EZ2#LY2(*"B,Z(&QI8B]A<&DN<&AP.C(P-0IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@<&%G
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PHC
M+"!F=7IZ>0IM<V=I9"`B365N=2!,:7-T(@IM<V=S='(@(LW=X2#+W_/TX2(*
M"B,Z(&QI8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HS"B,L(&9U>GIY"FUS9VED
M(")-:6YI(%-E87)C:"(*;7-G<W1R("+![>'FWO3G\^<B"@HC.B!L:6(O1')I
M=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$3B!I;B!,1$%0('-O
M=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O871T
M<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0:&]N92(*;7-G
M<W1R("+*Z>WG]/P@U.?KW?;Y[>\B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP
M.C,S,B!L:6(O1')I=F5R+VQD87`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-;V1I9GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$Q.3,*(RP@9G5Z>GD*;7-G:60@(DUO<F4@=&AA;B`Q(&5N
M=')Y(&9O=6YD(@IM<V=S='(@(L7PZ?/T\=SVY^KA[2#PY?'I\_/\].7QY?(@
MX?#\(.S?X2#JX?3A]_GQWO/EZ?(N(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHQ,0IM<V=I9"`B36]V92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA=&5S
M+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*(RP@9G5Z>GD*;7-G
M:60@(DUO=F4@;&5F="(*;7-G<W1R("+,Y?3A]N_QW"#!\>GS].7QW"(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T.0HC.B!T96UP
M;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$X-@HC+"!F=7IZ
M>0IM<V=I9"`B36]V92!R:6=H="(*;7-G<W1R("+,Y?3A]N_QW"#$Y>[IW"(*
M"B,Z(&1A=&$N<&AP.C4R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z,38*
M;7-G:60@(DUU;&)E<G)Y($%D9')E<W,@0F]O:R(*;7-G<W1R("+$Z>7UZ/7M
M\^GOX_'<]N_R($UU;&)E<G)Y(@H*(SH@;&EB+V%P:2YP:'`Z,3$Q,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)-=6QT:7!L92!P97)S;VYS('=I=&@@861D
M<F5S<R!;)7-=+"!B=70@;F]N92!W:71H(&YA;64@6R5S72!A;')E861Y(&5X
M:7-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T.C$P
M-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*;7-G:60@
M(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R("+$Z>7UZ/7M\^GOX_'<]N_R($UU
M;&)E<G)Y(@H*(SH@861D<F5S<V)O;VMS+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G
M:60@(DUY($%D9')E<W,@0F]O:W,B"FUS9W-T<B`BQ.GE]>CU[?/I[^/QW/;O
M\B!-=6QB97)R>2(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P
M-R!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT,@IM<V=I9"`B3F%M92(*
M;7-G<W1R("*\[>_LX2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM
M<V=I9"`B3F%M92!&;W)M870B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-O=7)C
M97,N<&AP+F1I<W0Z,S$U"FUS9VED(").971C96YT97(@365M8F5R($1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!A9&0N<&AP.C,V(&%D9"YP:'`Z,3(T(&QI
M8B]";&]C:R]M:6YI<V5A<F-H+G!H<#HR-PHC.B!L:6(O0FQO8VLO=')E95]M
M96YU+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5W($-O;G1A8W0B"FUS9W-T
M<B`BQ>SVW.WI\^<@Q?#A]O[M(@H*(SH@961I="YP:'`Z.#@@961I="YP:'`Z
M.34@961I="YP:'`Z,C`R('1E;7!L871E<R]D871A+VEM<&]R="YI;F,Z-#4*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,C$X"B,L(&9U>GIY"FUS9VED(").:6-K;F%M92(*;7-G<W1R
M("*\[>_LX2(*"B,Z(&QI8B]A<&DN<&AP.C$Q.34@;&EB+V%P:2YP:'`Z,3(T
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@)7,@96YT<GD@9F]U
M;F0@9F]R("5S(@IM<V=S='(@(L3E[2#B\=WHY^KE("5S(.KA].'W_O'I\^<@
MX^GA("5S+B(*"B,Z(&QI8B]A<&DN<&AP.C$Q-C,*(RP@9G5Z>GD*;7-G:60@
M(DYO(&%D9')E<W,@8F]O:W,@9F]U;F0N(@IM<V=S='(@(L\@Y.GE]>CU[?/I
M[^/QW/;O\B#EW^WAZ2#L_.WO(./IX2#A[=SC[?GSYRXB"@HC.B!M:6YI<V5A
M<F-H+G!H<#HX,PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N=&%C=',@9F]U;F0B
M"FUS9W-T<B`BQ>SVW.WI\^<@Q?#A]O[M(@H*(SH@;&EB+V%P:2YP:'`Z-3$Q
M(&QI8B]A<&DN<&AP.C<V-@IM<V=I9"`B3F\@=D-A<F0@9&%T82!W87,@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN
M8SHW"FUS9VED(").;VYE(@IM<V=S='(@(LKA[=WMX2(*"B,Z(&-O;F9I9R]A
M='1R:6)U=&5S+G!H<"YD:7-T.C$X-`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
MT^?LY>G^\^7I\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G
M:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HV,30@;&EB+V%P:2YP:'`Z-S0W"FUS9VED(")/8FIE8W0@
M;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.C(R,PIM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z,C,*;7-G:60@(B(*(D]N8V4@>6]U
M('-A=F4@=&AI<R!O<'1I;VX@<&%G92P@=&AE(&%D9')E<W,@8F]O:R!W:6QL
M(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N($EF('1H:7,@:7,@;F]T('=H
M870@>6]U('=A;G0L('1H96X@>6]U(&UU<W0@8VAA;F=E('EO=7(@<V5L96-T
M:6]N("(*(G1O(%PB3F]N95PB+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HW-S0*;7-G:60@(D]N;'D@;VYE('9C87)D('-U<'!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-@HC+"!F=7IZ>0IM<V=I9"`B3W1H97(@3W!T:6]N<R(*
M;7-G<W1R("+%\.GK[^/=\B#7\=[S].<B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C0Y-2!L:6(O87!I+G!H<#HV,#4@;&EB+V%P
M:2YP:'`Z-CDR(&QI8B]A<&DN<&AP.CDS-`HC.B!L:6(O87!I+G!H<#HQ,#DX
M"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O
M1')I=F5R+G!H<#HU-#,*;7-G:60@(E!E<FUI<W-I;VX@9&5N:65D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.CDY"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!D871A+G!H<#HU,R!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C$W"FUS9VED(")0:6YE($%D9')E<W,@
M0F]O:R(*;7-G<W1R("+$Z>7UZ/7M\^GOX_'<]N_R(%!I;F4B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(X"B,L(&9U>GIY"FUS9VED
M(")0;&5A<V4@;F%M92!T:&4@;F5W(&-O;G1A8W0@;&ES=#HB"FUS9W-T<B`B
MT.'QX>KAZ_X@Y/[S].4@].\@_.WO[.$@X^GA(/3G(.W=X2#KW_/TX3HB"@HC
M.B!E9&ET+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HQ.30*;7-G:60@
M(E!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C0Q-@HC+"!F=7IZ>0IM<V=I9"`B4')I=F%T92!!9&1R97-S($)O;VLB
M"FUS9W-T<B`BQ.GE]>CU[?/I[^/QW/;O\B!0:6YE(@H*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475E<GD@9F%I
M;&5D.B`H)7,I("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]B;&]C:R]M
M:6YI<V5A<F-H+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B475I8VL@4V5A<F-H
M(@IM<V=S='(@(L'MX>;>].?SYR(*"B,Z(&QI8B]$<FEV97(O;&1A<"YP:'`Z
M,3DQ(&QI8B]$<FEV97(O;&1A<"YP:'`Z,3DY(&QI8B]$<FEV97(O;&1A<"YP
M:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E860@9F%I;&5D.B`H)7,I
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]296YD97)E<BYP:'`Z-#D*;7-G:60@
M(E)E86QL>2!D96QE=&4@=&AI<R!C;VYT86-T/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,Z,@IM<V=I9"`B4F5C;W)D<R!D
M:7-P;&%Y960Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R
M97-S8F]O:W-E;&5C="YI;F,Z,3<V"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M861D<F5S<R!B;V]K(@IM<V=S='(@(LOA[>CA\^S=[>\@PNGBZ]_O(,3IY?7H
M_>WSY?GM+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC
M.C(S.0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("+!
M]N'?\>7SYR#3]-[KY_(B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N
M:6YC.C(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F<F]M('1H:7,@;&ES="(*
M;7-G<W1R("+'(.KA\?3=Z^$@X?;AZ?'=Z.?JY2#A\/P@].<@Z]_S].$N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR,0IM<V=I9"`B(@HB4F5P
M;&%C92!E>&ES=&EN9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@:6UP;W)T960@
M;VYE/R`\<W1R;VYG/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@96YT
M<FEE<R!I;B!Y;W5R(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R;VYG/B(*
M;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+G!H<#HT,S@*;7-G:60@(E)E<75E
M<W1E9"!O8FIE8W0@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&0N<&AP
M.C,W('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3,*;7-G:60@(E)E
M<V5T('1O($1E9F%U;'1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4R]-24U%(%!U8FQI8R!#97)T:69I
M8V%T92(*;7-G<W1R("(B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S*2`E<R(*
M;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HY.2!A9&0N<&AP.C,W('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C$R-`IM<V=I9"`B4V%V92(*;7-G<W1R("+!
M\._HWNKE]?/G(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.CDV
M('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3(*(SH@=&5M<&QA=&5S
M+V)L;V-K+VUI;FES96%R8V@N:6YC.C(Q(&QI8B]";&]C:R]T<F5E7VUE;G4N
M<&AP.C0Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(E-E
M87)C:"(*;7-G<W1R("+![>'FWO3G\^<B"@HC.B!M:6YI<V5A<F-H+G!H<#HV
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(%)E<W5L=',Z(@IM<V=S='(@(L'P
M[_3EZ]WS[.'TX2#![>'FWO3G\^?R(@H*(SH@;&EB+V%P:2YP:'`Z,3`Q,0HC
M+"!F=7IZ>0IM<V=I9"`B4V5A<F-H(&9A:6QE9"(*;7-G<W1R("+![>'FWO3G
M\^<B"@HC.B!L:6(O87!I+G!H<#HQ,3`S(&QI8B]A<&DN<&AP.C$Q,#D@;&EB
M+V%P:2YP:'`Z,3$Q."!L:6(O87!I+G!H<#HQ,3,Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E-E87)C:"!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]B;&]C:R]M:6YI<V5A<F-H+FEN8SHR,@HC+"!F=7IZ>0IM<V=I9"`B
M4V5A<F-H:6YG+BXN(@IM<V=S='(@(L'MX>;>].?SYR(*"B,Z('1E;7!L871E
M<R]A9&1R97-S8F]O:W,N:6YC.C8V"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M86X@861D<F5S<R!B;V]K('1O(&1E;&5T92(*;7-G<W1R("+%\.GKW>[TY2#$
MZ>7UZ/7M\^GOX_'<]N\B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T
M;R!E9&ET(@IM<V=S='(@(L7PZ>O=[O3E(,3IY?7H]>WSZ>_C\=SV[R(*"B,Z
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&5X<&]R="!F<F]M.B(*;7-G
M<W1R("+%\.GKW>[TY2#A\/P@\._U(.CA(.7NW./E].4@].$@Y.7D[^S=[>$Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR-@HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.B(*
M;7-G<W1R("+%\.GKW>[TY2#P[_4@Z.$@X]_MY>D@YR#EZ?/AX_GCWCHB"@HC
M.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C,U"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@=&AE(&-H87)S970@;V8@=&AE('-O=7)C92!F:6QE.B(*;7-G
M<W1R("+%\.GKW>[TY2#A\/P@\._U(.CA(.7NW./E].4@].$@Y.7D[^S=[>$Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,`HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R("+%\.GK
MW>[TY2#A\/P@\._U(.CA(.7NW./E].4@].$@Y.7D[^S=[>$Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L96-T('1H92!F
M:6QE('1O(&EM<&]R=#HB"FUS9W-T<B`BQ?#IZ]WN].4@].\@X?'WY=_O(/#O
M]2#HX2#EZ?/A]^CEWSHB"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&9O<FUA="!O9B!T:&4@
M<V]U<F-E(&9I;&4Z(@IM<V=S='(@(L7PZ>O=[O3E(/3G[2#L[_'VWB#E[N'C
M^>/>\B#T^>T@Y.7D[^S=[?GM.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S4*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@
M=&\@9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`BQ?#IZ]WN].4@].?M(.SO\?;>
M(.7I\^'C^>/>\B#T^>T@Y.7D[^S=[?GM.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('9I97<@=&\@9&ES
M<&QA>2!B>2!D969A=6QT+"!S;W)T(&]P=&EO;G,L(&%N9"!P86=I;F<@;W!T
M:6]N<RXB"FUS9W-T<B`BQ?#IZ^_CWB#TY_(@\/'OY?#IZ^7C[-WMY_(@\/'O
MXN_KWO(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")3
M96QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@
M;&ES=',N(@IM<V=S='(@(L7PZ>OOX]X@]/GM(/#EY-_Y[2#P[_4@Z.$@Y>SV
MX>W?YN_M].'I(//TYR#KW_/TX2#T^>T@Y.GE]>C][?/E^>TN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,R"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M=VAI8V@@9F]R;6%T('1O(&1I<W!L87D@;F%M97,N(@IM<V=S='(@(L7PZ>OO
MX]X@]/GM(/#EY-_Y[2#P[_4@Z.$@Y>SVX>W?YN_M].'I(//TYR#KW_/TX2#T
M^>T@Y.GE]>C][?/E^>TN(@H*(SH@861D+G!H<#HU-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K(%PB)7-<(BXB
M"FUS9W-T<B`BQ?#IZ]WN].4@Q.GE]>CU[?/I[^/QW/;O(@H*(SH@8V]N9FEG
M+W-O=7)C97,N<&AP+F1I<W0Z,3<S"B,L(&9U>GIY"FUS9VED(")3:&%R960@
M1&ER96-T;W)Y(@IM<V=S='(@(LKA]-SK[^/O\B(*"B,Z('1E;7!L871E<R]B
M<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-H;W<@)7,B"FUS9W-T<B`BQ>SVW.WI\^<B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C0Q"FUS9VED(")3:&]W($%L;"(*;7-G<W1R
M("+%[/;<[>GSYR"\Z_GM(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS
M+FEN8SHT,`IM<V=I9"`B4VAO=R!#;VYT86-T<R(*;7-G<W1R("+%[/;<[>GS
MYR#%\.'V_NTB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C,Y
M"FUS9VED(")3:&]W($QI<W1S(@IM<V=S='(@(L7L]MSMZ?/G(,OI\_3^[2(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C(Q"B,Z
M('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C,T"FUS9VED
M(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R("+*X?3E_>CU[?/G(-3A[NGM_.SG
M\^?R(@H*(SH@;&EB+V%P:2YP:'`Z,3DX"B,L(&9U>GIY"FUS9VED(")3;W5R
M8V5S(@IM<V=S='(@(L7PZ?3U]]_A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$U-PIM<V=I9"`B4W!E8VEF>2!W:&5R92!Y;W4@=V%N="!A9'9A;F-E
M9"!S96%R8V@@<F5S=6QT<R!T;R!A<'!E87(N(@IM<V=S='(@(B(*"B,Z(&)R
M;W=S92YP:'`Z,30Q"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!A9&1E9"`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(R
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8W)E871E9"!T
M:&4@8V]N=&%C="!L:7-T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z-3`*;7-G:60@(E135B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]I;7!O<G0N:6YC.C$T('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,30*
M;7-G:60@(E1A8B!S97!A<F%T960@=F%L=65S(@IM<V=S='(@(M3I[-[R(.3I
MX??Y\>GS[-WMY?(@[.4@)U1A8B<B"@HC.B!V:65W+G!H<#HQ-0IM<V=I9"`B
M5&AE(%9&4R!B86-K96YD(&YE961S('1O(&)E(&-O;F9I9W5R960@=&\@96YA
M8FQE(&%T=&%C:&UE;G0@=7!L;V%D<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z,3`U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S
M<R!B;V]K(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M861D<F5S<R!B;V]K(%PB)7-<(B!W87,@8W)E871E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(B(*"B,Z(&%D9')E<W-B;V]K<RYP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(')E;6]V
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!A9&1R97-S8F]O:W,N
M<&AP.C@Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S
M<R!B;V]K(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S
M='(@(KCCZ>WE(.7PZ?3U]_[R(.7I\^'C^>/>(/3O]2#DZ>7UZ/7M\^GOX_'<
M]N_U(%!I;F4B"@HC.B!D871A+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&%D9')E<W,@8F]O:R!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HT-R!V8V%R9"YP:'`Z,C(@9&ES<&QA
M>2YP:'`Z,C,@=FEE=RYP:'`Z,C8*;7-G:60@(E1H92!C;VYT86-T('EO=2!R
M97%U97-T960@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&5D:70N
M<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M7"(E<UPB(&AA<R!S=6-C97-S9G5L;'D@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("(E<R#%\.GT]??^\B#EZ?/AX_GCWB#T[_4@X?'WY=_O]2(*"B,Z(&1A=&$N
M<&AP.C(X-`IM<V=I9"`B5&AE(&EM<&]R="!C86X@8F4@9FEN:7-H960@9&5S
M<&ET92!T:&4@=V%R;FEN9W,N(@IM<V=S='(@(B(*"B,Z(&)R;W=S92YP:'`Z
M,S$*;7-G:60@(E1H97)E(&%R92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O
M:W,N(@IM<V=S='(@(L3E[2#U\-SQ]^_U[2#DZ>7UZ/7M\^GOX_'<]N_I(/3O
M]?(@[_#OW^_U\B#L\._QY=_TY2#MX2#DY=_TY2XB"@HC.B!A9&0N<&AP.C(Y
M"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!A<F4@;F\@=W)I=&5A8FQE(&%D
M9')E<W,@8F]O:W,N($YO;F4@;V8@=&AE(&%V86EL86)L92!A9&1R97-S(&)O
M;VMS("(*(F%R92!C;VYF:6=U<F5D('1O(&%L;&]W('EO=2!T;R!A9&0@;F5W
M(&5N=')I97,@=&\@=&AE;2X@268@>6]U(&)E;&EE=F4@=&AI<R`B"B)I<R!A
M;B!E<G)O<BP@<&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@HBRN'MW>WA\B#A\/P@]._U\B#DZ>'HW?/I[._U
M\B#DZ>7UZ/7M\^GOX_'<]N_U\B#DY>T@W??EZ2#Q]>CLZ?/TY=\@_O/TY2#M
MX2`B"B+L\._QY=\@[>$@ZN'TX??Y\>7?(.7CX_'A]MWR+B#,\._QY=_TY2#M
MX2#E[>?LY?'^\^7TY2#T[R#DZ>'WY>GQZ?/TWB#T[_4@(@HB\_7S]-[LX?3O
M\B#SX?(N(@H*(SH@861D+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@=&AE(&YE=R!C;VYT86-T+B!#;VYT
M86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@(@HB9F]R(&9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@HBU?#>\>[E(/#Q_.+KY^SA(//TY^T@\/'O\^C>
MZN<@]._U(.'M].GJY>GLW>WO]2X@Q?#IZN_I[?GMWO/TY2#LY2#T[^T@(@HB
MY.GA]^7I\>GS]-XN(@H*(SH@8G)O=W-E+G!H<#HQ.#D@8G)O=W-E+G!H<#HR
M,S`*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A9&1I;F<@
M=&AI<R!O8FIE8W0N(@IM<V=S='(@(M#A\>_U\^G<\_3GZN4@\_;<Z^SA(.KA
M]-P@].?M(.3IX>/QX?;>(.'U]._](/3O]2#A[?3IZN7I[-WM[_4N(@H*(SH@
M8G)O=W-E+G!H<#HR,S@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!C<F5A
M=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R("+0X?'O]?/IW//TY^KE(//VW.OL
MX2#JX?3<(/3G[2#DY^SI[_7QX]_A(/3G\B#MW>'R(.O?\_3A\BXB"@HC.B!A
M9&1R97-S8F]O:W,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@=&AI<R!A9&1R97-S(&)O
M;VLZ("5S(@IM<V=S='(@(M#A\>_U\^G<\_3GZN4@\_;<Z^SA(.KA]-P@].?M
M(.3G[.GO]?'CW^$@].?R(.W=X?(@Z]_S].'R+B(*"B,Z(&)R;W=S92YP:'`Z
M,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@7"(E<UPB(&9R;VT@=&AE('-O=7)C92!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(M#A\>_U\^G<\_3GZN4@\_;<Z^SA(.KA]-P@].?M
M(.3IX>/QX?;>(.'U]._](/3O]2#A[?3IZN7I[-WM[_4N(@H*(SH@9&5L971E
M+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`B
MT.'Q[_7SZ=SS].?JY2#S]MSK[.$@ZN'TW"#TY^T@Y.GAX_'A]MX@X?7T[_T@
M]._U(.'M].GJY>GLW>WO]2XB"@HC.B!B<F]W<V4N<&AP.C<R"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AI<R!O8FIE8W0N(@IM<V=S
M='(@(M#A\>_U\^G<\_3GZN4@\_;<Z^SA(.KA]-P@].?M(.3IX>/QX?;>(.'U
M]._](/3O]2#A[?3IZN7I[-WM[_4N(@H*(SH@8G)O=W-E+G!H<#HR-S@*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M92!L:7-T(@IM<V=S='(@(M#A\>_U\^G<\_3GZN4@\_;<Z^SA(.KA]-P@Y>SV
MW.WI\^<@].?R(.O?\_3A\B(*"B,Z(&1A=&$N<&AP.C,S-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@9&%T83H@)7,B"FUS9W-T<B`BT.'Q[_7SZ=SS].?JY2#S]MSK[.$@
MZN'TW"#TY^T@Y>GSX>/YX]X@Y.7D[^S=[?GM+B(*"B,Z(&QI8B]A<&DN<&AP
M.C4P-R!L:6(O87!I+G!H<#HW-C$*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G
M<W1R("+0X?'O]?/IW//TY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#T
MY_(@V.?VZ>'JWO(@RMSQ].'R+B(*"B,Z(&)R;W=S92YP:'`Z-3@*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!A(&-O;G1A
M8W0@9G)O;2!T:&4@;&ES="XB"FUS9W-T<B`BT.'Q[_7SZ=SS].?JY2#S]MSK
M[.$@ZN'TW"#TY^T@Y.?LZ>_U\>/?X2#TY_(@[=WA\B#KW_/TX?(N(@H*(SH@
M861D<F5S<V)O;VMS+G!H<#HU-2!A9&1R97-S8F]O:W,N<&AP.C8P(&%D9')E
M<W-B;V]K<RYP:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@
M)7,B"FUS9W-T<B`BT.'Q[_7SZ=SS].?JY2#S]MSK[.$@ZN'TW"#TY^T@Y.GA
MX_'A]MX@X?7T[_T@]._U(.'M].GJY>GLW>WO]2XB"@HC.B!A9&1R97-S8F]O
M:W,N<&AP.C@Q(&%D9')E<W-B;V]K<RYP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES
M(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T<B`BT.'Q[_7SZ=SS].?JY2#S]MSK
M[.$@ZN'TW"#TY^T@Y.GAX_'A]MX@X?7T[_T@]._U(.'M].GJY>GLW>WO]2XB
M"@HC.B!E9&ET+G!H<#HQ-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&5N=')Y.B`E<R(*
M;7-G<W1R("+0X?'O]?/IW//TY^KE(//VW.OLX2#JX?3<(/3G[2#DZ>'C\>'V
MWB#A]?3O_2#T[_4@X>WTZ>KEZ>S=[>_U+B(*"B,Z(&1A=&$N<&AP.C$W.0HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V5R92!N;R!A9&1R97-S97,@=&\@97AP
M;W)T+B(*;7-G<W1R("+$Y>T@]?#<\??O]>T@Y.GE]>CU[?/I[^/QW/;OZ2#S
M]._U\B#O\._?[_7R(.SP[_'EW_3E(.WA(./QW/CE].4N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#`*;7-G:60@(E1H
M97-E(&%D9')E<W,@8F]O:W,@=VEL;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N
M:6YC.C(T,PIM<V=I9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@
M=&AI<R!O<F1E<CHB"FUS9W-T<B`B(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED
M(")4:&ES(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,C(@;&EB+V%P:2YP:'`Z,3$S-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!P97)S;VX@86QR96%D>2!H
M87,@82`E<R!E;G1R>2!I;B!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(L'U
M]-X@YR#E\.'VWB`E<R#=]^7I(-[DYR#JX?3A]_GQY^CEWR#S].\@Y.GE]>CU
M[?/I[^/QW/;O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#<*;7-G
M:60@(B(*(E1H:7,@=VEL;"!B92!T:&4@9&5F875L="!A9&1R97-S(&)O;VL@
M=VAE;B!A9&1I;F<@;W(@:6UP;W)T:6YG(&-O;G1A8W1S+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HW,`IM<V=I9"`B5&ET
M;&4B"FUS9W-T<B`BU-_TZ^_R(@H*(SH@;&EB+U1U<F)A+G!H<#HT,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N
M("!-:7-S:6YG('-O=7)C92!T>7!E+B(*;7-G<W1R("(B"@HC.B!L:6(O1')I
M=F5R+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(L3E[2#L\._Q[_WM
M(.WA(./?[>_U[2#OZ2#Q]>CLW_/EZ?(@]._U("5S+B(*"B,Z(&5D:70N<&AP
M.C@X(&5D:70N<&AP.CDQ(&5D:70N<&AP.CDT(&5D:70N<&AP.CDY(&5D:70N
M<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@
M(L'P[^C>ZN7U\^<@X>OKX>/^[2(*"B,Z(&QI8B]A<&DN<&AP.C4T,"!L:6(O
M87!I+G!H<#HV-#,@;&EB+V%P:2YP:'`Z-S<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W-O=7)C97,N<&AP+F1I<W0Z,S<V"B,L(&9U>GIY"FUS9VED
M(")697)I<VEG;B!$:7)E8W1O<GDB"FUS9W-T<B`BRN'TW.OOX^_R(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$Y('1E;7!L871E<R]B<F]W<V4O
M8V]N=&%C=')O=RYI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@;6EN:7-E87)C:"YP:'`Z-S@*(RP@9G5Z
M>GD*;7-G:60@(E9I97<@0V]N=&%C="(*;7-G<W1R("+%[/;<[>GSYR#%\.'V
M_NTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")6:65W
M('1O(&1I<W!L87D@8GD@9&5F875L=#HB"FUS9W-T<B`BQR#P\>_B[^O>(/#O
M]2#HX2#E[/;A[=_FY?3AZ3HB"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N
M9&ES=#HR,#@*(RP@9G5Z>GD*;7-G:60@(E=E8G-I=&4@55),(@IM<V=S='(@
M(L?KY>KT\>_MZ>K>(,3IY?WH]>WSYRA54DPI(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3$S"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T
M<B`BQ.GE_>CU[?/G(,7QX^'SW^'R(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z,3(T"FUS9VED(")7;W)K($-I='DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED
M(")7;W)K($-O=6YT<GDB"FUS9W-T<B`BU.?KW?;Y[>\@Q?'CX?/?X?(B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-38*;7-G:60@(E=O<FL@
M4&AO;F4B"FUS9W-T<B`BU.?KW?;Y[>\@Q?'CX?/?X?(B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E=O<FL@
M4&]S=&%L($-O9&4B"FUS9W-T<B`BU.?KW?;Y[>\@Q?'CX?/?X?(B"@HC.B!C
M;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,CD*(RP@9G5Z>GD*;7-G:60@
M(E=O<FL@4W1A=&4O4')O=FEN8V4B"FUS9W-T<B`BU.?KW?;Y[>\@Q?'CX?/?
MX?(B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,3D*(RP@9G5Z
M>GD*;7-G:60@(E=O<FL@4W1R965T($%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU
M[?/G(,7QX^'SW^'R(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP:'`Z.3,@
M8G)O=W-E+G!H<#HR,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8V]N=&%C=',@:6X@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!E9&ET+G!H<#HV
M.2!D:7-P;&%Y+G!H<#HU."!V:65W+G!H<#HS-@IM<V=I9"`B66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(@IM<V=S
M='(@(B(*"B,Z('9C87)D+G!H<#HT,`IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&]B:F5C="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHU-0HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`BT/'=\.7I(/#Q_O3A(.WA(.7PZ>O=[N7TY2#LW^$@Y?#A
M]MXN(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHR,PHC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&QI<W0N
M(@IM<V=S='(@(M#QW?#EZ2#P\?[TX2#MX2#E\.GKW>[E].4@[-_A(.7PX?;>
M+B(*"B,Z(&5D:70N<&AP.C,R"FUS9VED(")9;W4@;75S="!S96QE8W0@870@
M;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N(@IM<V=S='(@(M#QW?#EZ2#P\?[T
MX2#MX2#E\.GKW>[E].4@[-_A(.7PX?;>+B(*"B,Z('1E;7!L871E<R]B<F]W
M<V4O:F%V87-C<FEP="YI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R
M:7!T+FEN8SHT.0HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC
M.C<R"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@
M;VYE(&5N=')Y(&9I<G-T+B(*;7-G<W1R("+0\=WPY>D@\/'^].$@[>$@Y?#I
MZ]WNY?3E(.S?X2#E\.'VWBXB"@HC.B!E9&ET+G!H<#HW,PIM<V=I9"`B66]U
M(&]N;'D@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(*
M;7-G<W1R("(B"@HC.B!B<F]W<V4N<&AP.C(X-0IM<V=I9"`B66]U<B!D969A
M=6QT(&%D9')E<W,@8F]O:R!I<R!N;W0@8G)O=W-E86)L92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C8@=&5M<&QA=&5S+V)R
M;W=S92]C;VYT86-T<F]W+FEN8SHQ,@IM<V=I9"`B6VYO('9A;'5E72(*;7-G
M<W1R("(B"@HC.B!L:6(O5'5R8F$N<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B
M7T)R;W=S92(*;7-G<W1R("++W_/TX2(*"B,Z('1E;7!L871E<R]B<F]W<V4O
M86-T:6]N<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(E]#;VYT86-T<R(*;7-G
M<W1R("+%[/;<[>GSYR#%\.'V_NTB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C
M=&EO;G,N:6YC.C(*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B
MQ.GAX_'A]MXB"@HC.B!L:6(O5'5R8F$N<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I
M9"`B7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`BQ>GSX>/YX]XOQ>[AX_GCWB(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z>GD*
M;7-G:60@(E],:7-T<R(*;7-G<W1R("+%[/;<[>GSYR#+Z?/T_NTB"@HC.B!L
M:6(O5'5R8F$N<&AP.C0X,0HC+"!F=7IZ>0IM<V=I9"`B7TUY($%D9')E<W,@
M0F]O:W,B"FUS9W-T<B`BQ.GE]>CU[?/I[^/QW/;O\B!-=6QB97)R>2(*"B,Z
M(&QI8B]4=7)B82YP:'`Z-#@W"B,L(&9U>GIY"FUS9VED(")?3F5W($-O;G1A
M8W0B"FUS9W-T<B`BQ>SVW.WI\^<@Q?#A]O[M(@H*(SH@=&5M<&QA=&5S+V)R
M;W=S92]A8W1I;VYS+FEN8SHR"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E(&9R
M;VT@=&AI<R!L:7-T(@IM<V=S='(@(L<@ZN'Q]-WKX2#A]N'I\=WHY^KE(.'P
M_"#TYR#KW_/TX2XB"@HC.B!L:6(O5'5R8F$N<&AP.C0X.0HC+"!F=7IZ>0IM
M<V=I9"`B7U-E87)C:"(*;7-G<W1R("+![>'FWO3G\^<B"@HC.B!V8V%R9"YP
M:'`Z-#8*;7-G:60@(F-O;G1A8W0N=F-F(@IM<V=S='(@(B(*"B,Z(&1A=&$N
M<&AP.C$Y.2!D871A+G!H<#HR,#0@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHQ"FUS9VED(")C;VYT86-T<RYC<W8B"FUS9W-T<B`B(@H*(SH@9&%T82YP
M:'`Z,C`Y"FUS9VED(")C;VYT86-T<RYT<W8B"FUS9W-T<B`B(@H*(SH@9&%T
M82YP:'`Z,C$Y"FUS9VED(")C;VYT86-T<RYV8V8B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VEM<W!?;W!T+FEN8SHS-`HC+"!F=7IZ>0IM<V=I
M9"`B;F]N92(*;7-G<W1R("+*X>W=[>$B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")T;R!A($-O;G1A8W0@
M3&ES="(*;7-G<W1R("+%[/;<[>GSYR#%\.'V_NTB"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")T;R!A(&1I
M9F9E<F5N="!!9&1R97-S($)O;VLB"FUS9W-T<B`BQ?#IZ]WN].4@Q.GE]>CU
M[?/I[^/QW/;O(@H*(SH@9&%T82YP:'`Z-3$@=&5M<&QA=&5S+V)R;W=S92]C
M;VQU;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHQ-2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")V
M0V%R9"(*;7-G<W1R("+8Y_;IX>K>(,K<\?3A(@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W!O+V9A7TE2+G!O````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3(T,S,`,3`T,3<S
M-C(W-38`,#$W-3`S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@4&5R<VEA;B!T<F%N<VQA=&EO;G,@9F]R(%1U<F)A('!A
M8VMA9V4N"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S
M86UE(&QI8V5N<V4@87,@=&AE(%1U<F)A('!A8VMA9V4N"B,@"B,@0V]P>7)I
M9VAT("A#*2`R,#`T($AI9V@@0V]N8VEL(&]F($EN9F]R;6%T:6-S("AW=W<N
M<VAC:2YI<BD*(R!0<F]V:61E9"!B>2`@06UI<FMA8FER($UE=&%N971W;W)K
M:6YG($QT9"P@,C`P-"`\<&5R<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RYC
M;VT^"B,@36]H<V5N($YA9&5R+4)A9'(@("`@("`@/&YA9&5R:4!M971A;F5T
M=V]R:VEN9RYC;VT^"B,@0VAA:V%M96@@36]R=&5Z86YI82`@("`@/&UO<G1E
M>F%N:6%`;65T86YE='=O<FMI;F<N8V]M/@HC(%-A;&UA;B!.:6MS969A="`@
M("`@("`@(#QN:6MS969A=$!M971A;F5T=V]R:VEN9RYC;VT^"B,@2&%M960@
M1VAE>6)I("`@("`@("`@("`@/&=H97EB:4!M971A;F5T=V]R:VEN9RYC;VT^
M"B,@5F%H:60@1VAA9F%R<&]U<B`@("`@("`@/&=H869A<G!O=7)`;65T86YE
M='=O<FMI;F<N8V]M/@HC(%IA:')A($%H;6%D:2!&:7)O=7IJ865E(#QA:&UA
M9&E`;65T86YE='=O<FMI;F<N8V]M/@HC(`IM<V=I9"`B(@IM<V=S='(@(B(*
M(E!R;VIE8W0M260M5F5R<VEO;CH@5'5R8F$@,B!!3%!(05QN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#4M,#<M,#@@,3(Z-#4K,#0S,%QN(@HB3&%S="U4
M<F%N<VQA=&]R.B!!;6ER:V%B:7(@365T86YE='=O<FMI;F<@;'1D+B`\<&5R
M<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RXB"B)C;VT^7&XB"B),86YG=6%G
M92U496%M.B!097)S:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]551&+3A<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:71<;B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;7-P7V]P="YI;F,Z-#(*
M(RP@9G5Z>GD*;7-G:60@(B!!9&0@86X@24U34"!!9&1R97-S($)O;VLB"FUS
M9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI(-JIV*K8I]BHVH;9A]F4
M(-BBV*_8L=BS($E-4U`B"@HC.B!T96UP;&%T97,O<')E9G,O:6US<%]O<'0N
M:6YC.C,Q"B,L(&9U>GIY"FUS9VED("(@1&5L971E($E-4U`@061D<F5S<R!"
M;V]K(@IM<V=S='(@(MBMV+#9@2#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR!)
M35-0(@H*(R`*(SH@9&%T82YP:'`Z,S(U"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!A;')E861Y(&5X:7-T<R!A;F0@=V%S(&YO="!I;7!O<G1E9"XB
M"FUS9W-T<B`B7"(E<UPB(-BOV+$@V*W8I]F$(-BMV*?8MMBQ(-F%V8C8K-F(
MV*\@V87;C.*`C-BHV*?8M-BO(-F((-BOV+'9B-F&XH",V*C8L=BO(-F&V+38
MK]F'(-BHV8C8KRXB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!B<F]W<V4N<&AP.C$R-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E
M8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("+8J-F'(-BYV839D=BJ(-F!
MV8?8L=BSV*H@V*C9B-BOV88@)R5S)R#8I]BR(-BBV88@V+'9B-F&V8C8M-BJ
M(-BJV8?;C-F1V8<@V8;8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@8G)O=W-E+G!H<#HQ,C0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&UO
M=F5D(&)E8V%U<V4@:70@:7,@82!L:7-T+B(*;7-G<W1R("+8J-F'(-BYV839
MD=BJ(-F!V8?8L=BSV*H@V*C9B-BOV88@)R5S)R#9A=F&V*K9@MF$(-F&V+38
MKR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S<*;7-G:60@(EPB1FER
M<W1N86UE($QA<W1N86UE7"(@("AI92X@2F]H;B!$;V4I(@IM<V=S='(@(EPB
MV8;8I]F%("#9AMBGV84@V*[8I]F&V8C8I]BOVJ_;C%PB(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B7"),87-T;F%M92P@1FER<W1N
M86UE7"(@*&EE+B!$;V4L($IO:&XI(@IM<V=S='(@(EPBV8;8I]F%(-BNV*?9
MAMF(V*?8K]JOVXP@(-F&V*?9A5PB(@H*(R`*(SH@861D+G!H<#HQ,#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@861D960N(@IM<V=S='(@(B5S(-BGV+;8
MI]F!V8<@V+38KR(*"B,@"B,Z(&1A=&$N<&AP.C,T,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!F:6QE('-U8V-E<W-F=6QL>2!I;7!O<G1E9"(*;7-G<W1R
M("+9OMBQV8C9AMBOV8<@)7,@V*C8IR#9A=F(V8'9@MN,V9'8JB#8K]BQV8C9
MAN*`C-BHV+'8KR#8M-BO(@H*(R`*(SH@=&5M<&QA=&5S+V)R;W=S92]F;V]T
M97(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B
M"FUS9W-T<B`B)7,@V*C9AR`E<R#8I]BR("5S(@H*(SH@;&EB+U1U<F)A+G!H
M<#HT-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S
M<R!";V]K(@IM<V=S='(@(MJIV*K8I]BHVH;9A^*`C-F'V*?;C"#8HMBOV+'8
MLR`B"@HC.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z-#4*;7-G:60@(D$@
M8G)O=W-E<B!T:&%T('-U<'!O<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B"FUS
M9W-T<B`BV878L=F(V+':K]BQVXP@VJG9AR!I1G)A;65S(-BQV*<@V;[8M-BJ
MVXS8J-BGV8;;C"#:J=F&V*\@V838I]BRV84@V*?8L]BJ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$U.0IM<V=I9"`B06)O=F4@<V5A<F-H(&9O<FTB
M"FUS9W-T<B`BV*C8I]F$V*?;C"#9@=BQV84@V*S8L]BJV*S9B"(*"B,Z('9I
M97<N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(D%C8V5S<R!D96YI960@
M=&\@)7,B"FUS9W-T<B`BV+G8K]F%(-BGV*S8I]BRV8?9E"#8K]BSV*K8L=BS
MVXP@V*C9AR`E<R(*"B,Z(&%D9"YP:'`Z-38@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHR,@IM<V=I9"`B061D(@IM<V=S='(@(MBGV+;8I]F!V8<@
MVJG8L=BOV88B"@HC.B!T96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE
M8W0N:6YC.C$W-`IM<V=I9"`B061D(&%D9')E<W,@8F]O:R(*;7-G<W1R("+8
MI]BVV*?9@=F'(-JIV+'8K]F&(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X"B,L(&9U>GIY"FUS9VED(")!
M9&0@86YD($1E;&5T92!)35-0(&%D9')E<W,@8F]O:W,B"FUS9W-T<B`BV*?8
MMMBGV8'9AR#:J=BQV*_9AB#9B"#;C-BG(-BMV+#9@2#:J=BJV*?8J-J&V8?B
M@(S9A]BGVXP@V*+8K]BQV+,@24U34"(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M;VQU;6YS96QE8W0N:6YC.C(S-PIM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R
M("+8I]BVV*?9@=F'(-JIV+'8K]F&(-BSV*K9B-F&(@H*(SH@961I="YP:'`Z
M,3(X"FUS9VED(")!9&0@9FEL92(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8
MK]F&(-F^V+'9B-F&V*_9AR(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,C(*;7-G:60@(D%D9"!T;R(*;7-G<W1R("+8I]BVV*?9@=F'(-JI
MV+'8K]F&(-BHV8<B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHX
M-@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(MJIV*K8
MI]BHVH;9A^*`C-F'V*?;C"#8HMBOV+'8LR`B"@HC.B!B<F]W<V4N<&AP.C(X
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*;7-G:60@(D%D9')E<W,@0F]O
M:R!,:7-T:6YG(@IM<V=S='(@(MF!V8?8L=BSV*H@VJG8JMBGV*C:AMF'V90@
MV*+8K]BQV+,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`*;7-G:60@
M(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`BVJG8JMBGV*C:AMF'XH",V8?8I]N,
M(-BBV*_8L=BS("(*"B,Z(&%D9"YP:'`Z,3`X"FUS9VED(")!9&1R97-S(&)O
M;VL@96YT<GDB"FUS9W-T<B`BV8C8L=F(V*_;C"#:J=BJV*?8J-J&V8?9E"#8
MHMBOV+'8LR(*"B,@"B,Z(&1A=&$N<&AP.C,P-0IM<V=I9"`B061D<F5S<R!B
M;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(@IM<V=S='(@(MJIV*K8I]BHVH;9
MA]F4(-BBV*_8L=BS(-BHV*?9A=F(V8'9@MN,V9'8JB#8KMBGV83;C"#8M-BO
M(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z-C(*(RP@9G5Z>GD*
M;7-G:60@(D%D9')E<W,@8F]O:R!T;R!D96QE=&4@(@IM<V=S='(@(MF(V+'9
MB-BOVXP@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,B"@HC.B!T96UP;&%T97,O
M<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W,`IM<V=I9"`B061D<F5S
M<R!B;V]K<R!T:&%T('=I;&P@;F]T(&)E(&1I<W!L87EE9#HB"FUS9W-T<B`B
MVJG8JMBGV*C:AMF'(-BBV*_8L=BSXH",V8?8I]N,VXP@VJG9AR#9AMF%V*?;
MC-BT(-BOV*?8K]F'(-F&V*[9B-BGV8?9AMBO(-BTV*\Z(@H*(SH@<V5A<F-H
M+G!H<#HX."!T96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z,S<*;7-G:60@
M(D%D=F%N8V5D(%-E87)C:"(*;7-G<W1R("+8K-BSV*K8K-F(VXP@V;[;C-BT
MV+'9@=BJV8<B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HV-`IM
M<V=I9"`B06QI87,B"FUS9W-T<B`BV8;8I]F%(-F%V+/8JMBYV*?8L2(*"B,Z
M('1E;7!L871E<R]B<F]W<V4O9F]O=&5R06QP:&$N:6YC.C<@=&5M<&QA=&5S
M+V)R;W=S92]F;V]T97)!;'!H82YI;F,Z,3`*(SH@=&5M<&QA=&5S+V)R;W=S
M92]A8W1I;VYS+FEN8SHT,0IM<V=I9"`B06QL(@IM<V=S='(@(MF'V879AR(*
M"B,Z(&QI8B]A<&DN<&AP.C4U,@IM<V=I9"`B06QR96%D>2!%>&ES=',B"FUS
M9W-T<B`BV*?8LB#9@MBHV80@V879B-BLV8C8KR#9A=N,XH",V*C8I]BTV*\B
M"@HC(`HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!T:&%T('EO=2!W86YT
M('1O(&1E;&5T92`E<S\B"FUS9W-T<B`BV*+;C-BG(-F%V+?9A=BFV8;;C-BO
M(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR`E<R#8L=BG(-BMV+#9@2#:J=F&
MVXS8K]B?(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHV
M-PIM<V=I9"`B07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L971E
M('1H92!S96QE8W1E9"!E;G1R:65S/R(*;7-G<W1R("+8HMN,V*<@V878M]F%
MV*;9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-F(V+'9B-BOVXSB
M@(S9A]BGVXP@V*?9AMBJV*[8I]BH(-BTV*_9AR#8L=BG(-BMV+#9@2#:J=F&
MVXS8K]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")!
M<V-E;F1I;F<B"FUS9W-T<B`BV+78N=F(V*_;C"(*"B,Z('-E87)C:"YP:'`Z
M.#4@=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC.C,V"FUS9VED(")"87-I
M8R!396%R8V@B"FUS9W-T<B`BV*S8L]BJV*S9B-N,(-BSV*?8K]F'(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B0F5L;W<@<V5A<F-H
M(&9O<FTB"FUS9W-T<B`BV++;C-BQ(-F!V+'9A2#8K-BSV*K8K-F((@H*(R`*
M(SH@;&EB+T1R:79E<B]L9&%P+G!H<#HW-R!L:6(O1')I=F5R+VQD87`N<&AP
M.C@P"B,L('!H<"UF;W)M870*;7-G:60@(D)I;F0@9F%I;&5D.B`H)7,I("5S
M(@IM<V=S='(@(MF^VXS9B-BSV*K9AB#9AMBGV879B-F!V9'9@B#8J-F(V*\Z
M("@E<RD@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S@*
M;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(MBQV8C8LB#8JMF(V838KR(*"B,Z
M('1E;7!L871E<R]M96YU+FEN8SHW"FUS9VED(")"<F]W<V4B"FUS9W-T<B`B
MV878L=F(V+$B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ-S,*
M;7-G:60@(D)U<VEN97-S($-A=&5G;W)Y(@IM<V=S='(@(MBOV+/8JMF'(-BJ
MV*S8I]BQVXPB"@HC.B!D871A+G!H<#HT.0IM<V=I9"`B0U-6(@IM<V=S='(@
M(D-35B(*"B,Z(&QI8B]/8FIE8W0O1W)O=7`N<&AP.C4W"FUS9VED(")#86XG
M="!A9&0@82!G<F]U<"!T;R!I='-E;&8N(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-N,VJD@VJ_8L=F(V8<@V+'8IR#8J-F'(-BNV8C8K]BT(-BGV+;8
MI]F!V8<@VJG8L=BO+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE
M861E<G,N:6YC.C<*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R("+8
MJ-BQV+'8L]N,("#9A]F%V8<OV8?;C-J&XH",VJG8K]BGV84B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B0VAO
M;W-E(&$@;F%M92(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#:J=BJV*?8
MJ-J&V8?9E"#8HMBOV+'8LR`B"@HC.B!A9&0N<&AP.C0X"FUS9VED(")#:&]O
M<V4@86X@861D<F5S<R!B;V]K(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI
M(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS("(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C;VQU;6YS96QE8W0N:6YC.C(R,0IM<V=I9"`B0VAO;W-E(&%N(&%D9')E
M<W,@8F]O:SHB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@VJG8JMBGV*C:
MAMF'V90@V*+8K]BQV+,Z("(*"B,Z('1E;7!L871E<R]P<F5F<R]A9&1R97-S
M8F]O:W-E;&5C="YI;F,Z,38U"FUS9VED(")#:&]O<V4@=VAI8V@@861D<F5S
M<R!B;V]K<R!T;R!D:7-P;&%Y+"!A;F0@:6X@=VAA="!O<F1E<CHB"FUS9W-T
M<B`BV*?9AMBJV*[8I]BH(-JIV*K8I]BHVH;9A^*`C-F'V*?;C"#8HMBOV+'8
MLR#9B"#8JMBYVXS;C-F&(-BJV+'8JMN,V*@@V*+9AMF'V*<@V*C8L=BGVXP@
MV8;9A=BGVXS8M"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,0IM<V=I
M9"`B0VAO;W-E('=H:6-H(&%D9')E<W,@8F]O:W,@=&\@=7-E+B(*;7-G<W1R
M("+8I]F&V*K8KMBGV*@@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+/B@(S9A]BG
MVXP@V879B-BQV*\@V*?8L]BJV8'8I]BOV8<@(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-O;'5M;G-E;&5C="YI;F,Z,C(X"FUS9VED(")#:&]O<V4@=VAI8V@@
M8V]L=6UN<R!T;R!D:7-P;&%Y(&%N9"!I;B!W:&%T(&]R9&5R.B(*;7-G<W1R
M("+8I]F&V*K8KMBGV*@@V8;8I]F%(-F((-BJV+'8JMN,V*@@V+/8JMF(V8;9
MA]BGVXP@V8;9A=BGVXS8M"#8K]BGV*_9AR#8M-BOV8<Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$W"FUS9VED(")#;VQU;6X@3W!T:6]N<R(*;7-G
M<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-BSV*K9B-F&VXPB"@HC.B!T96UP
M;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR,S,*;7-G:60@(D-O;'5M
M;G,@=&AA="!W:6QL(&YO="!B92!D:7-P;&%Y960Z(@IM<V=S='(@(MBSV*K9
MB-F&V8?8I]N,VXP@VJG9AR#9AMF%V*?;C-BT(-BOV*?8K]F'(-F&V*[9B-BG
MV8?9AMBO(-BTV*\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ
M,R!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$R"FUS9VED(")#;VUM82!S
M97!A<F%T960@=F%L=65S(@IM<V=S='(@(MF%V8+8I]BOVXS8L2#8K-BOV*<@
MV+38K]F'(-BJV8C8L]BW(-F(VXS8L=JOV8C9A"(*"B,Z('1E;7!L871E<R]D
M871A+V5X<&]R="YI;F,Z,3,*;7-G:60@(D-O;6UA('-E<&%R871E9"!V86QU
M97,@*$UI8W)O<V]F="!/=71L;V]K*2(*;7-G<W1R("+9A=F"V*?8K]N,V+$@
MV*S8K]BG(-BTV*_9AR#8JMF(V+/8MR#9B-N,V+':K]F(V80@*$UI8W)O<V]F
M="!/=71L;V]K*2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C<V
M"FUS9VED(")#;VUP86YY(@IM<V=S='(@(MBTV+':J=BJ(@H*(SH@8V]N9FEG
M+V%T=')I8G5T97,N<&AP+F1I<W0Z,30T"FUS9VED(")#;VUP86YY($%D9')E
M<W,B"FUS9W-T<B`BV*+8K]BQV+,@V+38L=JIV*HB"@HC.B!L:6(O87!I+G!H
M<#HS,3@@;&EB+V%P:2YP:'`Z,S8S(&QI8B]A<&DN<&AP.C0P-R!L:6(O87!I
M+G!H<#HT.3$*(SH@;&EB+V%P:2YP:'`Z-C`Q(&QI8B]A<&DN<&AP.C8X."!L
M:6(O87!I+G!H<#HW-#$@;&EB+V%P:2YP:'`Z.#$Y"B,Z(&QI8B]A<&DN<&AP
M.C$P,#8@;&EB+V%P:2YP:'`Z,3`Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BV*?8JMBUV*?9A"#9AMBG
MV879B-F!V9'9@B#8J-F(V*\Z("5S(@H*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HU.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL=7)E(@IM<V=S='(@(MBNV+'8
MI]BHVXP@V*?8L=BJV*C8I]BW(@H*(SH@8G)O=W-E+G!H<#HQ.3$@8G)O=W-E
M+G!H<#HR,S(*;7-G:60@(D-O;G1A8W0@861D960@=&\@;&ES="XB"FUS9W-T
M<B`BV*K9A=BGV+,@V*C9AR#9@=F'V+'8L]BJ(-BGV+;8I]F!V8<@V+38KRXB
M"@HC.B!B<F]W<V4N<&AP.C8P"FUS9VED(")#;VYT86-T(')E;6]V960@9G)O
M;2!L:7-T+B(*;7-G<W1R("+8JMF%V*?8LR#8I]BR(-F!V8?8L=BSV*H@V*W8
ML-F!(-BTV*\N(@H*(R`*(SH@8G)O=W-E+G!H<#HR-C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N=&%C=',@:6X@;&ES=#H@)7,B"FUS9W-T<B`BV*K9A=BG
MV+/B@(S9A]BG(-BOV+$@V8'9A]BQV+/8JCH@)7,B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+V%C=&EO;G,N:6YC.C$R"FUS9VED(")#;W!Y(@IM<V=S='(@(MBQ
MV8C9AMF(V+38JB(*"B,Z('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C4S
M"B,L(&9U>GIY"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BV*?;C-BLV*?8KR#8
MM-BOV8<B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHT,`HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E($%D9')E<W,@0F]O:R(*;7-G<W1R("+:J=BJ
MV*?8J-J&V8?9E"#8HMBOV+'8LR#8KMBUV8C8M=N,(@H*(SH@;&EB+TQI<W16
M:65W+G!H<#HS,34*;7-G:60@(D-R96%T92!A(&YE=R!#;VYT86-T($QI<W0@
M:6XZ(@IM<V=S='(@(MBGVXS8K-BGV*\@VXS:J2#9@=F'V+'8L]BJ(-BJV878
MI]BS(-BLV*_;C-BO(-BOV+$Z(@H*(SH@;&EB+T]B:F5C=%9I97<N<&AP.C$S
M,PIM<V=I9"`B0W)E871E9"(*;7-G<W1R("+8I]N,V*S8I]BO(-BTV*_9AR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B1&5F875L="!S
M;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`BV*S9A]BJ(-F%V+'8JMBH(-BS
MV*?8LMN,(-F^VXS8M"#9@=BQV+8Z(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z-S8@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHR"B,Z
M(&QI8B]/8FIE8W0N<&AP.C,R."!L:6(O4F5N9&5R97(N<&AP.C0W(&QI8B]2
M96YD97)E<BYP:'`Z-3`*;7-G:60@(D1E;&5T92(*;7-G<W1R("+8K=BPV8$B
M"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHU.`HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E($%D9')E<W,@0F]O:R(*;7-G<W1R("+8K=BPV8$@VJG8
MJMBGV*C:AMF'V90@V*+8K]BQV+,@24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.`IM<V=I9"`B1&5L971E($-O;F9I<FUA=&EO;B(*;7-G<W1R
M("+8JMBCVXS;C-BO(-BMV+#9@2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.0IM<V=I9"`B1&5L971E(&)U='1O;B!B96AA=FEO=7(B"FUS9W-T<B`B
MV+'9@=BJV*?8L2#:J=F$VXS8KR#8K=BPV8$B"@HC(`HC.B!L:6(O1')I=F5R
M+VQD87`N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@9F%I
M;&5D.B`H)7,I("5S(@IM<V=S='(@(MBMV+#9@2#9AMBGV879B-F!V9'9@B#8
MJ-F(V*\Z("@E<RD@)7,B"@HC.B!D96QE=&4N<&AP.C,X"FUS9VED(")$96QE
M=&EO;B!F86EL960B"FUS9W-T<B`BV*W8L-F!(-F&V*?9A=F(V8'9D=F"(-BH
MV8C8KR(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C(Q,PIM<V=I
M9"`B1&5P87)T;65N="(*;7-G<W1R("+8I]BOV*?8L=F'(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@
M(MF&V++9B-F$VXPB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHQ
M,34*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]B<F]W<V4O<V5A<F-H+FEN8SHQ,3@*;7-G:60@(D1I<F5C=&]R>2(*;7-G
M<W1R("+8M-BGV*[9AR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM
M<V=I9"`B1&ES<&QA>2(*;7-G<W1R("+9AMF%V*?;C-BT(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9
MAMF'XH",V8?8I]N,(-F&V878I]N,V+0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3<V"FUS9VED(")$;R!Y;W4@=V%N="!T;R!C;VYF:7)M(&1E;&5T
M:6YG(&5N=')I97,_(@IM<V=S='(@(MBBVXS8IR#9A=N,XH",V*[9B-BGV8?;
MC-BO(-BMV+#9@2#9B-BQV8C8K]N,XH",V8?8IR#8L=BG(-BJV*/;C-N,V*\@
MVJG9AMN,V*_8GR(*"B,Z(&QI8B]/8FIE8W0N<&AP.C(Y-PIM<V=I9"`B1&]W
M;FQO860B"FUS9W-T<B`BV*?8L]BJV8+8L=BGV+$B"@HC.B!T96UP;&%T97,O
M8G)O=W-E+W)O=RYI;F,Z,3<@=&5M<&QA=&5S+V)R;W=S92]C;VYT86-T<F]W
M+FEN8SHR-0IM<V=I9"`B1&]W;FQO860@=D-A<F0B"FUS9W-T<B`BV*?8L]BJ
MV8+8L=BGV+$@=D-A<F0B"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN
M8SHQ,#(@=&5M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C(U"B,Z('1E;7!L871E
M<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC.C$P('1E;7!L871E<R]B<F]W
M<V4O86-T:6]N<RYI;F,Z,PHC.B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R
M;W<N:6YC.C,S(&QI8B]296YD97)E<BYP:'`Z-#(*;7-G:60@(D5D:70B"FUS
M9W-T<B`BV8C;C-BQV*?;C-BT(@H*(R`*(SH@=&5M<&QA=&5S+V)R;W=S92]R
M;W<N:6YC.C(U('1E;7!L871E<R]B<F]W<V4O8V]N=&%C=')O=RYI;F,Z,S,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@7"(E<UPB(@IM<V=S
M='(@(MF(VXS8L=BGVXS8M"`G)7,G(@H*(SH@=&5M<&QA=&5S+V%D9')E<W-B
M;V]K<RYI;F,Z.#$*(RP@9G5Z>GD*;7-G:60@(D5D:70@061D<F5S<R!";V]K
M<R(*;7-G<W1R("+:J=BJV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,@(@H*
M(R`*(SH@961I="YP:'`Z-S@@961I="YP:'`Z,34T"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@96YT<GD@9F]R("5S(@IM<V=S='(@(MF(VXS8L=BGVXS8
MM"#9B-BQV8C8K]N,(-BHV+'8I]N,("5S("(*"B,Z(&-O;F9I9R]A='1R:6)U
M=&5S+G!H<"YD:7-T.C4X"FUS9VED(")%;6%I;"(*;7-G<W1R("+9OMBSV*H@
MV*?9A-JIV*K8L=F(V8;;C-JI(@H*(SH@961I="YP:'`Z,30W"B,L('!H<"UF
M;W)M870*;7-G:60@(D5N=')Y(&9O<B`E<R!U<&1A=&5D+"!B=70@<V%V:6YG
M('1H92!U<&QO861E9"!F:6QE(&9A:6QE9#H@)7,B"FUS9W-T<B`BV8C8L=F(
MV*_;C"#8J-BQV*?;C"`E<R#8J-BQV8C8LMBQV+/8I]F&VXP@V+38KR#8I]F%
MV*<@V*W9@=BX(-F^V+'9B-F&V*_9A]F4(-BGV+'8L]BGV80@V+38K]F'(-F&
MV*?9A=F(V8'9D=F"(-BHV8C8KSH@)7,B"@HC(`HC.B!E9&ET+G!H<#HQ-#D@
M961I="YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(&9O<B`E
M<R!U<&1A=&5D+B(*;7-G<W1R("+9B-BQV8C8K]N,(-BHV+'8I]N,("5S(-BH
MV+'9B-BRV+'8L]BGV8;;C"#8M-BO(@H*(SH@8G)O=W-E+G!H<#HW-`IM<V=I
M9"`B16YT<GD@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(MF(V+'9
MB-BOVXP@V*C8IR#9A=F(V8'9@MN,V9'8JB#8K=BPV8$@V+38KR(*"B,@"B,Z
M(&QI8B]A<&DN<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@<V5A<F-H:6YG('1H92!A9&1R97-S(&)O;VLZ("5S(@IM<V=S='(@
M(MBOV+/8JMBQV+/;C"#8J-F'(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F&
MV*?9A=F(V8'9D=F"(-BHV8C8KSH@)7,B"@HC.B!T96UP;&%T97,O8G)O=W-E
M+V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHT,0IM
M<V=I9"`B17AP;W)T(@IM<V=S='(@(MBHV+'9B-F&XH",V*C8L=BO(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHV"FUS9VED(")%>'!O<G0@061D
M<F5S<R!";V]K(@IM<V=S='(@(MBHV+'9B-F&XH",V*C8L=BO(-JIV*K8I]BH
MVH;9A]F4(-BBV*_8L=BS(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN
M8SHR,0IM<V=I9"`B17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S
M+B(*;7-G<W1R("+8J-BQV8C9AN*`C-BHV+'8KR#8I]BWV838I]BYV*?8JB#8
MJMF%V*?8LR#8I]F&V*K8KMBGV*C;C"(*"B,Z('1E;7!L871E<R]D871A+V5X
M<&]R="YI;F,Z,C<*;7-G:60@(D5X<&]R="!T:&4@9F]L;&]W:6YG(&%D9')E
M<W,@8F]O:R!C;VUP;&5T96QY+B(*;7-G<W1R("+8J-BQV8C9AN*`C-BHV+'8
MKR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8LMN,V+$@V*C8M]F(V+$@VJG8
MI]F%V80B"@HC(`HC.B!D871A+G!H<#HQ,S0@9&%T82YP:'`Z,C(X(&1A=&$N
M<&AP.C(Y-R!B<F]W<V4N<&AP.C,U(&)R;W=S92YP:'`Z.3`*(SH@8G)O=W-E
M+G!H<#HQ,3(@861D+G!H<#HV-R!S96%R8V@N<&AP.C,W"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@
M)7,B"FUS9W-T<B`BV*_8L]BJV+'8L]N,(-BHV8<@VJG8JMBGV*C:AMF'V90@
MV*+8K]BQV+,@V8;8I]F%V8C9@=F1V8(@V*C9B-BO.B`E<R(*"B,@"B,Z(&)R
M;W=S92YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!A
M9&0@)7,@=&\@)7,Z("5S(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@
M)7,@V*C9AR`E<R#9AMBGV879B-F!V9'9@B#8J-F(V*\Z("5S(@H*(SH@8G)O
M=W-E+G!H<#HR-S(*;7-G:60@(D9A:6QE9"!T;R!B<F]W<V4@;&ES="(*;7-G
M<W1R("+9A=BQV8C8L2#9@=F'V+'8L]BJ(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKR(*"B,Z(&)R;W=S92YP:'`Z,S$P"FUS9VED(")&86EL960@=&\@8G)O=W-E
M('1H92!D:7)E8W1O<GDB"FUS9W-T<B`BV878L=F(V+$@V+38I]BNV8<@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO(@H*(R`*(SH@;&EB+T1R:79E<B]L9&%P+G!H
M<#HS,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-H86YG92!N
M86UE.B`H)7,I("5S.R!/;&0@1$X@/2`E<RP@3F5W($1.(#T@)7,L(%)O;W0@
M/2`E<R(*;7-G<W1R("+8JMBZVXS;C-BQ(-F&V*?9A2#9AMBGV879B-F!V9'9
M@B#8J-F(V*\Z("`H)7,I("5SV)L@1$X@V8+8J-F$VXP]("5S(-B,($1.(-BL
MV*_;C-BO/2`E<R#8C"#8L=N,V+39AST@("5S(@H*(R`*(SH@8G)O=W-E+G!H
M<#HQ,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&9I;F0@;V)J
M96-T('1O(&)E(&%D9&5D.B`E<R(*;7-G<W1R("+9OMN,V*_8IR#:J=BQV*_9
MAB#8M-N,V*$@V*?8MMBGV8'9A^*`C"#8M-BOV8<@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO.B`E<R(*"B,@"B,Z('-E87)C:"YP:'`Z-SD*(RP@9G5Z>GD*;7-G
M:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("+8K]BSV*K8L=BSVXP@V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#9
MAMBGV879B-F!V9'9@B#8J-F(V*\Z("5S(@H*(R`*(SH@9&%T82YP:'`Z,30Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!S96%R8V@@=&AE(&1I
M<F5C=&]R>3H@)7,B"FUS9W-T<B`BV*S8L]BJV*S9B-N,(-BTV*?8KMF'(-F&
MV*?9A=F(V8'9D=F"(-BHV8C8KSH@)7,B"@HC.B!C;VYF:6<O871T<FEB=71E
M<RYP:'`N9&ES=#HQ-C<*;7-G:60@(D9A>"(*;7-G<W1R("+8K]F(V+'9AMJO
MV*?8L2(*"B,Z(&5D:70N<&AP.C$R-"!D:7-P;&%Y+G!H<#HQ,#`*;7-G:60@
M(D9I;&5S(@IM<V=S='(@(MF^V+'9B-F&V*_9A^*`C-F'V*?B@(PB"@HC.B!T
M96UP;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S`*;7-G:60@(D9I;F0B"FUS
M9W-T<B`BV;[;C-BOV*?:J=BQV*_9AB(*"B,Z(&5D:70N<&AP.CDW(&5D:70N
M<&AP.C$X-PIM<V=I9"`B1FEN:7-H(@IM<V=S='(@(MBNV*?8JMF%V8<B"@HC
M.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HT.`IM<V=I9"`B1FER<W0@
M3F%M92(*;7-G<W1R("+9AMBGV84B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP
M:'`N9&ES=#HR,#(*;7-G:60@(D9R965B=7-Y(%523"(*;7-G<W1R(")54DP@
MV*+8LMBGV*\OV878M-BZV8C9A"(*"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A
M<F-H+FEN8SHX,PIM<V=I9"`B1G)O;2(*;7-G<W1R("+8I]BR(@H*(SH@8V]N
M9FEG+W-O=7)C97,N<&AP+F1I<W0Z-C`T"FUS9VED(")';&]B86P@061D<F5S
M<R!";V]K(@IM<V=S='(@(MJIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BSV+'8
MI]BSV+';C"(*"B,Z('1E;7!L871E<R]B<F]W<V4O<F]W+FEN8SHT,R!T96UP
M;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C0T"FUS9VED(")'<F]U<"(*
M;7-G<W1R("+:K]BQV8C9AR(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C@R"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@
MV879AMBRV80B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HY,PIM
M<V=I9"`B2&]M92!#:71Y(@IM<V=S='(@(MBTV8?8L2#9A=BMV80@V+/:J=F(
MV8;8JB(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$P.`IM<V=I
M9"`B2&]M92!#;W5N=')Y(@IM<V=S='(@(MJIV+39B-BQ(-F%V*W9A"#8I]F"
MV*?9A=BJ(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,34P"FUS
M9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(MBTV878I]BQV8<@V*K9A-F!V88@
MV879AMBRV80B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES=#HQ,#,*
M;7-G:60@(DAO;64@4&]S=&%L($-O9&4B"FUS9W-T<B`BVJG8KR#9OMBSV*K;
MC"#9A=BMV80@V+/:J=F(V8;8JB(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H
M<"YD:7-T.CDX"FUS9VED(")(;VUE(%-T871E+U!R;W9I;F-E(@IM<V=S='(@
M(MBGVXS8I]F$V*HOV*?8L]BJV*?9AB#9A=BMV80@V+/:J=F(V8;8JB(*"B,Z
M(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C@X"FUS9VED(")(;VUE(%-T
M<F5E="!!9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-BNVXS8I]BHV*?9AB#9
MA=BMV80@V+/:J=F(V8;8JB(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD:7-T
M.C4P-@IM<V=I9"`B24U34"(*;7-G<W1R("))35-0(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0W"B,L(&9U>GIY"FUS9VED("))35-0($%D9')E<W,@
M0F]O:R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+8L]BQV;[8L=BSV*K;C"#:
MJ=BJV*?8J-J&V8?9E"#8HMBOV+'8LR!)35-0(@H*(R`*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M="!!9&1R97-S($)O;VLL(%-T97`@)60B"FUS9W-T<B`BV*_8L=F(V8;B@(S8
MJ-BQV*\@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+/8C"#:K]BGV84@)60B"@HC
M.B!D871A+G!H<#HS-C$*;7-G:60@(DEM<&]R="]%>'!O<G0@061D<F5S<R!"
M;V]K<R(*;7-G<W1R("+8K]BQV8C9AN*`C-BHV+'8KR_8J-BQV8C9AN*`C-BH
MV+'8KR#:J=BJV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,B"@HC.B!L:6(O
M87!I+G!H<#HU.38@;&EB+V%P:2YP:'`Z-C@S"FUS9VED("));G9A;&ED($E$
M(@IM<V=S='(@(DE$(-F&V*?9A=BYV*K8J-BQ(@H*(SH@;&EB+V%P:2YP:'`Z
M,C,P(&QI8B]A<&DN<&AP.C0P,B!L:6(O87!I+G!H<#HT.#8@;&EB+V%P:2YP
M:'`Z-3DR"B,Z(&QI8B]A<&DN<&AP.C8W.2!L:6(O87!I+G!H<#HW,S$@;&EB
M+V%P:2YP:'`Z,3`W-PIM<V=I9"`B26YV86QI9"!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`BVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V8;8I]F%V+G8JMBHV+$B
M"@HC.B!L:6(O87!I+G!H<#HQ,#@Q(&QI8B]A<&DN<&AP.C$Q-30@;&EB+V%P
M:2YP:'`Z,3(P-PIM<V=I9"`B26YV86QI9"!E;6%I;"(*;7-G<W1R("+9OMBS
MV*H@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V8;8I]F%V+G8JMBHV+$B"@HC.B!L
M:6(O87!I+G!H<#HQ,#@Y"FUS9VED("));G9A;&ED(&5N=')Y(@IM<V=S='(@
M(MF(V+'9B-BOVXP@V8;8I]F%V+G8JMBHV+$B"@HC.B!L:6(O1')I=F5R+VQD
M87`N<&AP.C(V-@IM<V=I9"`B26YV86QI9"!K97D@<W!E8VEF:65D+B(*;7-G
M<W1R("+:J=F$VXS8KR#9AMBGV878N=BJV*C8L2#9A=BTV*[8M2#8M-BO(@H*
M(SH@;&EB+V%P:2YP:'`Z,3`X-0IM<V=I9"`B26YV86QI9"!N86UE(@IM<V=S
M='(@(MF&V*?9A2#9AMBGV878N=BJV*C8L2(*"B,Z(&QI8B]A<&DN<&AP.C<S
M-0IM<V=I9"`B26YV86QI9"!O8FIE8W1)9"(*;7-G<W1R(")I9"#8M-N,V*$@
MV8;8I]F%V+G8JMBHV+$B"@HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C,P"FUS
M9VED("(B"B),1$%0('-U<'!O<G0@:7,@<F5Q=6ER960@8G5T('1H92!,1$%0
M(&UO9'5L92!I<R!N;W0@879A:6QA8FQE(&]R(&YO="!L;V%D960N(@IM<V=S
M='(@(B(*(MF^V+38JMN,V*C8I]F&VXP@3$1!4"#9A=F(V+'8KR#9AMN,V*?8
MLB#8I]BSV*HN(-BGV878IR#9A=BOV8C9A"!,1$%0(-F"V*?8J-F$(-BOV+/8
MJMBQV+/;C"#9AMN,V+/8JB#9B"#;C-BG(-BGVXS9AMJIV8<@V*C8I]BQ("(*
M(MF&V+38K]F'XH",V*?8L]BJ+B(*"B,Z(&QI8B]/8FIE8W16:65W+G!H<#HQ
M,S@*;7-G:60@(DQA<W0@36]D:69I960B"FUS9W-T<B`BV*+8KMBQVXS9AB#8
MI]BUV838I]BM(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z-3,*
M;7-G:60@(DQA<W0@3F%M92(*;7-G<W1R("+9AMBGV84@V*[8I]F&V8C8I]BO
MVJ_;C"(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N:6YC
M.C$V"FUS9VED("),:7-T(@IM<V=S='(@(MF!V8?8L=BSV*HB"@HC.B!T96UP
M;&%T97,O8G)O=W-E+W-E87)C:"YI;F,Z-S<*;7-G:60@(DUA=&-H:6YG(@IM
M<V=S='(@(MBJV+?8I]BHV8(B"@HC.B!L:6(O87!I+G!H<#HR,#4*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F($-O;G1A8W1S(@IM<V=S='(@(MBHVXS8M-N,
MV8;9A]F4(-BJV+G8K]BGV*\@V*K9A=BGV+/9A]BG(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@<&%G
M97,B"FUS9W-T<B`BV*C;C-BTV8K9AMF'V90@V*K8N=BOV*?8KR#8M=F!V*W8
MI]BJ(@H*(SH@;&EB+T)L;V-K+W1R965?;65N=2YP:'`Z,PIM<V=I9"`B365N
M=2!,:7-T(@IM<V=S='(@(MF!V8?8L=BSV*H@VJ_8LMN,V8;:K]BGV88B"@HC
M.B!L:6(O0FQO8VLO;6EN:7-E87)C:"YP:'`Z,PIM<V=I9"`B36EN:2!396%R
M8V@B"FUS9W-T<B`BV*S8L]BJV*S9B-N,(-F%V*W8K]F(V*\B"@HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C,P,@IM<V=I9"`B36ES<VEN9R!$3B!I;B!,1$%0
M('-O=7)C92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+8N=BOV84@V8C8K-F(
MV*\@1$X@V*_8L2#9OMN,VJG8L=BHV8;8K]N,($Q$05`B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ-C(*;7-G:60@(DUO8FEL92!0:&]N92(*
M;7-G<W1R("+8JMF$V8'9AB#9A]F%V+'8I]F'(@H*(R`*(SH@;&EB+T1R:79E
M<B]L9&%P+G!H<#HS,S(@;&EB+T1R:79E<B]L9&%P+G!H<#HS-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B36]D:69Y(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R
M("+8JMBZVXS;C-BQ(-F&V*?9A=F(V8'9D=F"(-BHV8C8KSH@*"5S*2`E<R(*
M"B,Z(&QI8B]A<&DN<&AP.C$Q.3,*;7-G:60@(DUO<F4@=&AA;B`Q(&5N=')Y
M(&9O=6YD(@IM<V=S='(@(MBHVXS8M"#8I]BR(-N,VJD@V8C8L=F(V*_;C"#9
MOMN,V*_8IR#8M-BO(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN
M8SHQ,0IM<V=I9"`B36]V92(*;7-G<W1R("+8I]F&V*K9@MBGV80B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V]L=6UN<V5L96-T+FEN8SHR-#<*(SH@=&5M<&QA
M=&5S+W!R969S+V%D9')E<W-B;V]K<V5L96-T+FEN8SHQ.#0*;7-G:60@(DUO
M=F4@;&5F="(*;7-G<W1R("+8I]F&V*K9@MBGV80@V*C9AR#:AMF^(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-O;'5M;G-E;&5C="YI;F,Z,C0Y"B,Z('1E;7!L
M871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,Z,3@V"FUS9VED(")-
M;W9E(')I9VAT(@IM<V=S='(@(MBGV8;8JMF"V*?9A"#8J-F'(-BQV*?8L]BJ
M(@H*(SH@9&%T82YP:'`Z-3(@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ
M-@IM<V=I9"`B375L8F5R<GD@061D<F5S<R!";V]K(@IM<V=S='(@(MJIV*K8
MI]BHVH;9A]F4(-BBV*_8L=BS($UU;&)E<G)Y("(*"B,@"B,Z(&QI8B]A<&DN
M<&AP.C$Q,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB375L=&EP;&4@<&5R
M<V]N<R!W:71H(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE(%LE
M<UT@86QR96%D>2!E>&ES="(*;7-G<W1R("(B"B+:AMF&V*\@V8;9@=BQ(-BH
MV*<@V*+8K]BQV+,@6R5S72P@V*?9A=BG(-F'VXS:AN*`C-JIV*_8I]F%(-BH
MV*<@V8;8I]F%(%LE<UT@V*_8L2#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8
MI]BR(-F"V*C9A"#9A=F(V*S9B-BO("(*(MF&VXS8L]BJ+B(*"B,Z(&-O;F9I
M9R]S;W5R8V5S+G!H<"YD:7-T.C$P-R!C;VYF:6<O<V]U<F-E<RYP:'`N9&ES
M=#HR-#,*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O:R(*;7-G<W1R
M("+:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#9A=F&(@H*(SH@861D<F5S<V)O
M;VMS+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(DUY($%D9')E<W,@0F]O:W,B
M"FUS9W-T<B`BVJG8JMBGV*C:AMF'XH",V8?8I]N,(-BBV*_8L=BS("(*"B,Z
M('1E;7!L871E<R]A9&1R97-S8F]O:W,N:6YC.C$P-R!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HT,@IM<V=I9"`B3F%M92(*;7-G<W1R("+9AMBGV84B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(DYA;64@1F]R
M;6%T(@IM<V=S='(@(MF"V*?9A-BH(-F&V*?9A2(*"B,Z(&-O;F9I9R]S;W5R
M8V5S+G!H<"YD:7-T.C,Q-0IM<V=I9"`B3F5T8V5N=&5R($UE;6)E<B!$:7)E
M8W1O<GDB"FUS9W-T<B`BV+38I]BNV8?9E"#8I]BYV+;8I]N,($YE=&-E;G1E
M<B(*"B,Z(&%D9"YP:'`Z,S8@861D+G!H<#HQ,C0@;&EB+T)L;V-K+VUI;FES
M96%R8V@N<&AP.C(W"B,Z(&QI8B]";&]C:R]T<F5E7VUE;G4N<&AP.C(W"FUS
M9VED(").97<@0V]N=&%C="(*;7-G<W1R("+8JMF%V*?8LR#8K-BOVXS8KR(*
M"B,Z(&5D:70N<&AP.C@X(&5D:70N<&AP.CDU(&5D:70N<&AP.C(P,B!T96UP
M;&%T97,O9&%T82]I;7!O<G0N:6YC.C0U"FUS9VED(").97AT(@IM<V=S='(@
M(MJOV*?9A2#8J-BYV*\B"@HC.B!C;VYF:6<O871T<FEB=71E<RYP:'`N9&ES
M=#HR,3@*;7-G:60@(DYI8VMN86UE(@IM<V=S='(@(MF&V*?9A2#9A=BSV*K8
MN=BGV+$B"@HC(`HC.B!L:6(O87!I+G!H<#HQ,3DU(&QI8B]A<&DN<&AP.C$R
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@)7,@96YT<GD@9F]U;F0@9F]R
M("5S(@IM<V=S='(@(MF'VXS:AB#9B-BQV8C8K]N,("5S(-BHV+'8I]N,("5S
M(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&QI8B]A<&DN<&AP.C$Q-C,*;7-G:60@
M(DYO(&%D9')E<W,@8F]O:W,@9F]U;F0N(@IM<V=S='(@(MJIV*K8I]BHVH;9
MA]F4(-BBV*_8L=BSVXP@V;[;C-BOV*<@V8;8M-BO(@H*(SH@;6EN:7-E87)C
M:"YP:'`Z.#,*;7-G:60@(DYO(&-O;G1A8W1S(&9O=6YD(@IM<V=S='(@(MF'
MVXS:AB#8JMF%V*?8L]N,(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&QI8B]A<&DN
M<&AP.C4Q,2!L:6(O87!I+G!H<#HW-C8*;7-G:60@(DYO('9#87)D(&1A=&$@
M=V%S(&9O=6YD+B(*;7-G<W1R("+9A]N,VH8@V*_8I]BOV8?9E"!V0V%R9"#9
MOMN,V*_8IR#9AMBTV*\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI
M;F,Z-PIM<V=I9"`B3F]N92(*;7-G<W1R("+9A]N,VH8B"@HC.B!C;VYF:6<O
M871T<FEB=71E<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DYO=&5S(@IM<V=S='(@
M(MN,V*?8K]BOV*?8M-BJV8?8IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,34*;7-G:60@(DYU;6)E<B!O9B!I=&5M<R!P97(@<&%G92(*;7-G<W1R
M("+8JMBYV*_8I]BO(-F%V8C8I]BQV*\@V*_8L2#9A]BQ(-BUV8'8K=F'(@H*
M(SH@;&EB+V%P:2YP:'`Z-C$T(&QI8B]A<&DN<&AP.C<T-PIM<V=I9"`B3V)J
M96-T(&YO="!F;W5N9"(*;7-G<W1R("+8M-N,V*$@V;[;C-BOV*<@V8;8M-BO
M(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,C(S"FUS9VED(")/
M9F9I8V4B"FUS9W-T<B`BV*_9@=BJV+$@VJG8I]BQ(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VEM<W!?;W!T+FEN8SHR,PIM<V=I9"`B(@HB3VYC92!Y;W4@<V%V
M92!T:&ES(&]P=&EO;B!P86=E+"!T:&4@861D<F5S<R!B;V]K('=I;&P@8F4@
M<&5R;6%N96YT;'D@(@HB9&5L971E9"X@268@=&AI<R!I<R!N;W0@=VAA="!Y
M;W4@=V%N="P@=&AE;B!Y;W4@;75S="!C:&%N9V4@>6]U<B!S96QE8W1I;VX@
M(@HB=&\@7").;VYE7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C<W
M-`IM<V=I9"`B3VYL>2!O;F4@=F-A<F0@<W5P<&]R=&5D+B(*;7-G<W1R("+8
MJMF&V8?8IR#;C-JI('9C87)D(-F^V+38JMN,V*C8I]F&VXP@V87;C.*`C-BT
MV8C8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#8*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B
MVJ_8LMN,V8;9A^*`C-F'V*?;C"#8K]N,VJ_8L2(*"B,Z(&-O;F9I9R]A='1R
M:6)U=&5S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS
M9W-T<B`BVJG9A-N,V*\@V+G9A=F(V87;C"!01U`B"@HC.B!L:6(O87!I+G!H
M<#HT.34@;&EB+V%P:2YP:'`Z-C`U(&QI8B]A<&DN<&AP.C8Y,B!L:6(O87!I
M+G!H<#HY,S0*(SH@;&EB+V%P:2YP:'`Z,3`Y.`IM<V=I9"`B4&5R;6ES<VEO
M;B!$96YI960B"FUS9W-T<B`BV+G8K]F%(-F(V*S9B-BO(-F%V*S9B-BR(@H*
M(SH@;&EB+T1R:79E<BYP:'`Z-30S"FUS9VED(")097)M:7-S:6]N(&1E;FEE
M9"(*;7-G<W1R("+8N=BOV84@V8C8K-F(V*\@V878K-F(V+(B"@HC.B!T96UP
M;&%T97,O861D<F5S<V)O;VMS+FEN8SHY.0HC+"!F=7IZ>0IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`BV+G8K]F%(-F(V*S9B-BO(-F%V*S9B-BR(@H*
M(SH@9&%T82YP:'`Z-3,@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHQ-PIM
M<V=I9"`B4&EN92!!9&1R97-S($)O;VLB"FUS9W-T<B`BVJG8JMBGV*C:AMF'
MV90@V*+8K]BQV+,@4&EN92(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C
M<FEP="YI;F,Z,C@*;7-G:60@(E!L96%S92!N86UE('1H92!N97<@8V]N=&%C
M="!L:7-T.B(*;7-G<W1R("+9A-BWV8'8I]F+(-BHV8<@V8'9A]BQV+/8JB#8
MJMF%V*?8LR#8K-BOVXS8KR#9AMBGV87;C"#8K]F'VXS8KSHB"@HC.B!E9&ET
M+G!H<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HQ.30*;7-G:60@(E!R979I
M;W5S(@IM<V=S='(@(MF"V*C9A-N,(@H*(SH@8V]N9FEG+W-O=7)C97,N<&AP
M+F1I<W0Z-#$V"FUS9VED(")0<FEV871E($%D9')E<W,@0F]O:R(*;7-G<W1R
M("+:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8KMBUV8C8M=N,(@H*(R`*(SH@
M;&EB+T1R:79E<B]L9&%P+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M475E<GD@9F%I;&5D.B`H)7,I("5S(@IM<V=S='(@(MF^V+'8L^*`C-F(V*S9
MB"#9AMBGV879B-F!V9'9@B#8J-F(V*\Z("@E<RD@)7,B"@HC.B!T96UP;&%T
M97,O8FQO8VLO;6EN:7-E87)C:"YI;F,Z,3@*;7-G:60@(E%U:6-K(%-E87)C
M:"(*;7-G<W1R("+8K-BSV*K8K-F(VXP@V+/8L=N,V+DB"@HC(`HC.B!L:6(O
M1')I=F5R+VQD87`N<&AP.C$Y,2!L:6(O1')I=F5R+VQD87`N<&AP.C$Y.2!L
M:6(O1')I=F5R+VQD87`N<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%D(&9A:6QE9#H@*"5S*2`E<R(*;7-G<W1R("+8KMF(V*?9AMBOV88@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO.B`H)7,I("5S(@H*(SH@;&EB+U)E;F1E<F5R
M+G!H<#HT.0IM<V=I9"`B4F5A;&QY(&1E;&5T92!T:&ES(&-O;G1A8W0_(@IM
M<V=S='(@(MBBVXS8IR#9B-BGV8+8N=BGV9(@V*?;C-F&(-BJV878I]BS(-BM
MV+#9@2#8M-F(V*_8GR(*"B,Z('1E;7!L871E<R]B<F]W<V4O9F]O=&5R+FEN
M8SHR"FUS9VED(")296-O<F1S(&1I<W!L87EE9#HB"FUS9W-T<B`BV+':J=F(
MV+'8K]F'V*?;C"#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV*_9ASHB"@HC.B!T
M96UP;&%T97,O<')E9G,O861D<F5S<V)O;VMS96QE8W0N:6YC.C$W-@IM<V=I
M9"`B4F5M;W9E(&%D9')E<W,@8F]O:R(*;7-G<W1R("+8K=BPV8$@VJG8JMBG
MV*C:AMF'V90@V*+8K]BQV+,@(@H*(SH@=&5M<&QA=&5S+W!R969S+V-O;'5M
M;G-E;&5C="YI;F,Z,C,Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@
M(MBMV+#9@2#8L]BJV8C9AB(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z,@IM<V=I9"`B4F5M;W9E(&9R;VT@=&AI<R!L:7-T(@IM<V=S='(@
M(MBMV+#9@2#8I]BR(-BGVXS9AB#9@=F'V+'8L]BJ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O:6UP;W)T+FEN8SHR,0IM<V=I9"`B(@HB4F5P;&%C92!E>&ES=&EN
M9R!A9&1R97-S(&)O;VL@=VET:"!T:&4@:6UP;W)T960@;VYE/R`\<W1R;VYG
M/E=A<FYI;F<Z(%1H:7,@(@HB9&5L971E<R!A;&P@96YT<FEE<R!I;B!Y;W5R
M(&-U<G)E;G0@861D<F5S<R!B;V]K+CPO<W1R;VYG/B(*;7-G<W1R("(B"B+8
MHMN,V*<@VJG8JMBGV*C:AMF'(-BBV*_8L=BS(-F%V8C8K-F(V*\@V*C8IR#:
MJ=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8K]BQV8C9AN*`C-BHV+'8KR#8M-BO
MV8<@V*S8I]BHV*S8IR#8M-F(V*_8GR`\<W1R;VYG/MBGV*[8M]BGV+$Z("(*
M(MBGVXS9AB#8N=F%V80@V*K9A=BGV87;C"#9B-BQV8C8K]N,XH",V8?8I]N,
M(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-JIV8;9B-F&VXP@V+39A=BG(-BQ
MV*<@V*W8L-F!(-F%VXSB@(S:J=F&V*\N/"]S=')O;F<^(@H*(SH@;&EB+T1R
M:79E<BYP:'`Z-#,X"FUS9VED(")297%U97-T960@;V)J96-T(&YO="!F;W5N
M9"XB"FUS9W-T<B`BV+3;C-BA(-BNV8C8I]BSV*K9AR#8M-BOV8<@V;[;C-BO
MV*<@V8;8M-BO(@H*(SH@861D+G!H<#HS-R!T96UP;&%T97,O8G)O=W-E+W-E
M87)C:"YI;F,Z,3$S"FUS9VED(")297-E="!T;R!$969A=6QT<R(*;7-G<W1R
M("+8J-BGV++9AMBTV*?9AMN,(-F^VXS8M"#9@=BQV+;B@(S9A]BG(@H*(SH@
M8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3DV"FUS9VED(")3+TU)344@
M4'5B;&EC($-E<G1I9FEC871E(@IM<V=S='(@(MJOV8C8I]F'VXP@V+G9A=F(
MV87;C"!3+TU)344B"@HC(`HC.B!L:6(O1')I=F5R+VQD87`N<&AP.C8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E-405)45$Q3(&9A:6QE9#H@*"5S*2`E<R(*
M;7-G<W1R(")35$%25%1,4R#9AMBGV879B-F!V9'9@B#8J-F(V*\@*"5S*2`E
M<R(*"B,Z(&5D:70N<&AP.CDY(&%D9"YP:'`Z,S<@=&5M<&QA=&5S+V%D9')E
M<W-B;V]K<RYI;F,Z,3(T"FUS9VED(")3879E(@IM<V=S='(@(MBMV8'8N"(*
M"B,Z('1E;7!L871E<R]B<F]W<V4O<V5A<F-H+FEN8SHY-B!T96UP;&%T97,O
M8G)O=W-E+W-E87)C:"YI;F,Z,3$R"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI
M<V5A<F-H+FEN8SHR,2!L:6(O0FQO8VLO=')E95]M96YU+G!H<#HT.0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")396%R8V@B"FUS9W-T
M<B`BV*S8L]BJV*S9B"(*"B,Z(&UI;FES96%R8V@N<&AP.C8S"FUS9VED(")3
M96%R8V@@4F5S=6QT<SHB"FUS9W-T<B`BV8;8JMBGVXS8K"#8K-BSV*K8K-F(
M.B(*"B,Z(&QI8B]A<&DN<&AP.C$P,3$*;7-G:60@(E-E87)C:"!F86EL960B
M"FUS9W-T<B`BV*S8L]BJV*S9B"#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC
M.B!L:6(O87!I+G!H<#HQ,3`S(&QI8B]A<&DN<&AP.C$Q,#D@;&EB+V%P:2YP
M:'`Z,3$Q."!L:6(O87!I+G!H<#HQ,3,Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E-E87)C:"!F86EL960Z("5S(@IM<V=S='(@(MBLV+/8JMBLV8@@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO.B`E<R(*"B,Z('1E;7!L871E<R]B;&]C:R]M:6YI
M<V5A<F-H+FEN8SHR,@IM<V=I9"`B4V5A<F-H:6YG+BXN(@IM<V=S='(@(MBL
MV+/8JMBLV8@N+BXB"@HC.B!T96UP;&%T97,O861D<F5S<V)O;VMS+FEN8SHV
M-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%D9')E<W,@8F]O:R!T;R!D
M96QE=&4B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-JIV*K8I]BHVH;9A]F4(-BB
MV*_8L=BS(-BHV+'8I]N,(-BHV+'9B-F&XH",V*C8L=BO(-BGV+(Z(@H*(SH@
M=&5M<&QA=&5S+V%D9')E<W-B;V]K<RYI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A;B!A9&1R97-S(&)O;VL@=&\@961I="(*;7-G<W1R("+8I]F&
MV*K8KMBGV*@@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V*C8L=BGVXP@V*_8
ML=F(V8;B@(S8J-BQV*\@V*C9ASHB"@HC.B!T96UP;&%T97,O9&%T82]E>'!O
M<G0N:6YC.C,R"FUS9VED(")396QE8W0@=&AE(&%D9')E<W,@8F]O:R!T;R!E
M>'!O<G0@9G)O;3HB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-JIV*K8I]BHVH;9
MA]F4(-BBV*_8L=BS(-BHV+'8I]N,(-BHV+'9B-F&XH",V*C8L=BO(-BGV+(Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8SHR-@IM<V=I9"`B4V5L
M96-T('1H92!A9&1R97-S(&)O;VL@=&\@:6UP;W)T('1O.B(*;7-G<W1R("+8
MI]F&V*K8KMBGV*@@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V*C8L=BGVXP@
MV*_8L=F(V8;B@(S8J-BQV*\@V*C9ASHB"@HC.B!T96UP;&%T97,O9&%T82]I
M;7!O<G0N:6YC.C,U"FUS9VED(")396QE8W0@=&AE(&-H87)S970@;V8@=&AE
M('-O=7)C92!F:6QE.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V878K-F%V8C8
MN=F'V90@V8;9B-N,V+/9AR#9OMBQV8C9AMBOV8?9E"#8L]BQVH;8M-F%V8<Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ,`IM<V=I9"`B4V5L
M96-T('1H92!E>'!O<G0@9F]R;6%T.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@
MV8+8I]F$V*@@V*C8L=F(V8;B@(S8J-BQV*\Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O:6UP;W)T+FEN8SHT,PIM<V=I9"`B4V5L96-T('1H92!F:6QE('1O(&EM
M<&]R=#HB"FUS9W-T<B`BV*?9AMBJV*[8I]BH("#9OMBQV8C9AMBOV8<@V*C8
ML=BGVXP@V*_8L=F(V8;B@(S8J-BQV*\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M:6UP;W)T+FEN8SHQ,0IM<V=I9"`B4V5L96-T('1H92!F;W)M870@;V8@=&AE
M('-O=7)C92!F:6QE.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8+8I]F$V*@@
MV;[8L=F(V8;8K]F'V90@V+/8L=J&V+39A=F'.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!T:&4@9F]R;6%T('5S960@
M=&\@9&ES<&QA>2!N86UE<SHB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F"V*?9
MA-BH(-F&V878I]N,V+0@V*?8L]BGV87;C#HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C4*;7-G:60@(E-E;&5C="!V:65W('1O(&1I<W!L87D@8GD@
M9&5F875L="P@<V]R="!O<'1I;VYS+"!A;F0@<&%G:6YG(&]P=&EO;G,N(@IM
M<V=S='(@(MBGV8;8JMBNV*?8J"#9AMBMV8C9A]F4(-F&V878I]N,V+0@V;[;
MC-BT(-F!V+'8MMB,(-JOV++;C-F&V8?B@(S9A]BGVXP@V878L=BJV*CB@(P@
MV+/8I]BRVXP@V8@@VJ_8LMN,V8;9A^*`C-F'V*?;C"#8M=F!V*W9A^*`C-BH
MV8;8K]N,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X"FUS9VED(")3
M96QE8W0@=VAI8V@@9FEE;&1S('1O(&1I<W!L87D@:6X@=&AE(&%D9')E<W,@
M;&ES=',N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9@=N,V838K]F'V*?;C-N,
M(-JIV8<@V*_8L2#9@=F'V+'8L]BJ(-BBV*_8L=BSV8?8IR#9AMF%V*?;C-BT
M(-BOV*?8K]F'(-F%VXSB@(S8M-F(V8;8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,@IM<V=I9"`B4V5L96-T('=H:6-H(&9O<FUA="!T;R!D:7-P
M;&%Y(&YA;65S+B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8+8I]F$V*@@V8;9
MA=BGVXS8M"#8I]BSV*?9A=N,(@H*(R`*(SH@861D+G!H<#HU-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5L96-T960@861D<F5S<R!B;V]K(%PB
M)7-<(BXB"FUS9W-T<B`BVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@)R5S)R#8
MI]F&V*K8KMBGV*@@V+38K]F'+B(*"B,Z(&-O;F9I9R]S;W5R8V5S+G!H<"YD
M:7-T.C$W,PIM<V=I9"`B4VAA<F5D($1I<F5C=&]R>2(*;7-G<W1R("+8M-BG
MV*[9A]F4(-F%V+38JMBQVJDB"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO
M;G,N:6YC.C,Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@)7,B"FUS9W-T
M<B`BV8;9A=BGVXS8M"`E<R(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N
M<RYI;F,Z-#$*;7-G:60@(E-H;W<@06QL(@IM<V=S='(@(MF&V878I]N,V+0@
MV8?9A=F'(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM
M<V=I9"`B4VAO=R!#;VYT86-T<R(*;7-G<W1R("+9AMF%V*?;C-BT(-BJV878
MI]BSV8?8IR(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,SD*
M;7-G:60@(E-H;W<@3&ES=',B"FUS9W-T<B`BV8;9A=BGVXS8M"#9@=F'V+'8
ML]BJXH",V8?8IR(*"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E
M<G,N:6YC.C(Q"B,Z('1E;7!L871E<R]B<F]W<V4O8V]L=6UN7VAE861E<G,N
M:6YC.C,T"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R("+8K-F'V*H@
MV878L=BJV*@@V+/8I]BRVXPB"@HC.B!L:6(O87!I+G!H<#HQ.3@*;7-G:60@
M(E-O=7)C97,B"FUS9W-T<B`BV+/8L=J&V+39A=F'XH",V8?8IR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3<*;7-G:60@(E-P96-I9GD@=VAE<F4@
M>6]U('=A;G0@861V86YC960@<V5A<F-H(')E<W5L=',@=&\@87!P96%R+B(*
M;7-G<W1R("+9A=BTV*[8M2#:J=BQV*_9AB#9A=BMV80@V8;9A=BGVXS8M"#9
MAMBJV*?;C-BL(-BLV+/8JMBLV8C;C"#9OMN,V+38L=F!V*K9AR(*"B,@"B,Z
M(&)R;W=S92YP:'`Z,30Q"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!A9&1E9"`E<R!T;R`E<R(*;7-G<W1R("(E<R#8J-BG(-F%V8C9@=F"
MVXS9D=BJ(-BHV8<@)7,@V*?8MMBGV8'9AR#8M-BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@8G)O
M=W-E+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&-R96%T960@=&AE(&-O;G1A8W0@;&ES="!<(B5S7"(N(@IM<V=S='(@(MF!
MV8?8L=BSV*H@V*K9A=BGV+,@7"(E<UPB(-BHV*<@V879B-F!V8+;C-F1V*H@
MV*?;C-BLV*?8KR#8M-BO(@H*(SH@9&%T82YP:'`Z-3`*;7-G:60@(E135B(*
M;7-G<W1R(")44U8B"@HC.B!T96UP;&%T97,O9&%T82]I;7!O<G0N:6YC.C$T
M('1E;7!L871E<R]D871A+V5X<&]R="YI;F,Z,30*;7-G:60@(E1A8B!S97!A
M<F%T960@=F%L=65S(@IM<V=S='(@(MF%V8+8I]BOVXS8L2#8K-BOV*<@V+38
MK]F'(-BHV*<@V8'8I]BUV839A]F4(-J&V8;8K]BJV*?;C-N,(@H*(SH@=FEE
M=RYP:'`Z,34*;7-G:60@(E1H92!61E,@8F%C:V5N9"!N965D<R!T;R!B92!C
M;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT('5P;&]A9',N(@IM<V=S
M='(@(MF^V+38JMN,V*C8I]F&(%9&4R#8J-BGVXS8KR#9OMN,VJG8L=BHV8;8
MK]N,(-BTV8C8KR#8JMBG(-F^VXS9B-BSV*K9A]BG(-BHV*K9B-BGV8;9AMBO
M(-BOV+';C-BGV8'8JB#8M-F(V8;8KRXB"@HC.B!L:6(O1')I=F5R+G!H<#HQ
M,#4T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A9&1R97-S(&)O;VL@7"(E
M<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+:J=BJV*?8J-J&V8?9E"#8
MHMBOV+'8LR`@7"(E<UPBV879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&%D9')E
M<W-B;V]K<RYP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!A9&1R97-S(&)O;VL@7"(E<UPB('=A<R!C<F5A=&5D('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`BVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@(%PB)7-<(MF%
MV8C8K-F(V*\@V8;;C-BSV*HB"@HC.B!A9&1R97-S8F]O:W,N<&AP.C<P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B;V]K(%PB
M)7-<(B!W87,@<F5M;W9E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(MJIV*K8
MI]BHVH;9A]F4(-BBV*_8L=BS("!<(B5S7"+9A=F(V*S9B-BO(-F&VXS8L]BJ
M(@H*(R`*(SH@861D<F5S<V)O;VMS+G!H<#HX.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S('-U8V-E
M<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R("+:J=BJV*?8J-J&V8?9E"#8HMBO
MV+'8LR#8J-BGV879B-F!V8+;C-F1V*H@V*[8I]F$VXP@V+38KR(*"B,Z(&1A
M=&$N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S<R!B
M;V]K(&-O=6QD(&YO="!B92!P=7)G960Z("5S(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BQV*<@V*[8I]F$
MVXP@VJG8L=BO.B`E<R(*"B,Z(&5D:70N<&AP.C0W('9C87)D+G!H<#HR,B!D
M:7-P;&%Y+G!H<#HR,R!V:65W+G!H<#HR-@IM<V=I9"`B5&AE(&-O;G1A8W0@
M>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BV*K9A=BG
MV+,@V*_8L=BNV8C8I]BSV*K;C"#8M-F%V*<@V879B-BLV8C8KR#9AMN,V+/8
MJB(*"B,Z(&5D:70N<&AP.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92!<(B5S7"(@:&%S('-U8V-E<W-F=6QL>2!B965N(&1E;&5T960N(@IM
M<V=S='(@(MF^V+'9B-F&V*_9A]F4(%PB)7-<(B#8J-BG(-F%V8C9@=F"VXS9
MD=BJ(-BMV+#9@2#8M-BO(@H*(SH@9&%T82YP:'`Z,C@T"FUS9VED(")4:&4@
M:6UP;W)T(&-A;B!B92!F:6YI<VAE9"!D97-P:71E('1H92!W87)N:6YG<RXB
M"FUS9W-T<B`BV*_8L=F(V8;B@(S8J-BQV*\@V+G9A-N,XH",V+'8NMF%(-F(
MV*S9B-BO(-BGV*[8M]BGV+$@V87;C.*`C-BJV8C8I]F&V*\@V*[8I]BJV879
MAR#;C-BGV*C8KR(*"B,Z(&)R;W=S92YP:'`Z,S$*;7-G:60@(E1H97)E(&%R
M92!N;R!B<F]W<V5A8FQE(&%D9')E<W,@8F]O:W,N(@IM<V=S='(@(MJIV*K8
MI]BHVH;9A]F4(-BBV*_8L=BSXH",(-F"V*?8J-F$(-F%V+'9B-BQVXP@V879
MB-BLV8C8KR#9AMF%VXSB@(S8J-BGV+39AMBO(@H*(SH@861D+G!H<#HR.0IM
M<V=I9"`B(@HB5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S(&)O;VMS
M+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R`B"B)A<F4@
M8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S('1O
M('1H96TN($EF('EO=2!B96QI979E('1H:7,@(@HB:7,@86X@97)R;W(L('!L
M96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(MJIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F"V*?8J-F$(-F&V8C8
MM-BJV88@V879B-BLV8C8KR#9AMN,V+/8JBX@V8?;C-J&(-N,VJD@V*?8LB#:
MJ=BJV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,@V8+8I]BHV80@V*_8L]BJ
MV+'8L]N,V(P@(@HBV*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9AB#9B-BQ
MV8C8K]N,(-BLV*_;C-BO(-BHV8<@V*+9AMF'V*?8C"#9OMN,VJG8L=BHV8;8
MK]N,(-F&V+38K]F'XH",V*?9AMBO+B#8I]JOV+$@V8':J=BQ(-F%VXSB@(S:
MJ=F&VXS8KR#8I]N,V88@(@HBV*W8I]F$V*H@VXS:J2#8KMBWV*?8L]BJV(P@
MV838M]F!V*?9BR#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*[9
MB-BO(-BJV878I]BS(-BHVJ_;C-BQVXS8KRXB"@HC.B!A9&0N<&AP.C$R,0IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&%D9&EN9R!T:&4@;F5W(&-O
M;G1A8W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B`B"B)F
M;W(@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B+8KMBWV*?;C-N,(-BOV+$@
MV*?8MMBGV8'9AR#:J=BQV*_9AB#8JMF%V*?8LR#8K-BOVXS8KR#8L=BN(-BO
MV*?8K]F'(-BGV+/8JBX@V*C8L=BGVXP@V+'8I]F'V8;9A=BGVXS;C"#8J-N,
MV+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ("(*(MBSV*?9A=BGV8;9A]F4(-BN
MV8C8KR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\N(@H*(SH@8G)O=W-E+G!H<#HQ
M.#D@8G)O=W-E+G!H<#HR,S`*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!A
M9&1I;F<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8L2#8
MI]BVV*?9@=F'(-JIV+'8K]F&(-BGVXS9AB#8M-N,V*$@V+'8KB#8K]BGV*_9
MAR#8I]BSV*HN(@H*(SH@8G)O=W-E+G!H<#HR,S@*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!C<F5A=&EN9R!A(&YE=R!L:7-T+B(*;7-G<W1R("+8KMBW
MV*?;C-N,(-BOV+$@V*?;C-BLV*?8KR#;C-JI(-F$VXS8L]BJ(-BLV*_;C-BO
M(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B(*"B,@"B,Z(&%D9')E<W-B;V]K<RYP
M:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!C<F5A=&EN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B"FUS9W-T
M<B`BV*[8M]BGVXS;C"#8K]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#8I]N,V88@
MV8C8L=F(V*_;C"#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,B"@HC(`HC.B!B
M<F]W<V4N<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(%PB)7-<(B!F<F]M('1H92!S;W5R
M8V4@861D<F5S<R!B;V]K+B(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@V*W8
ML-F!("5S(-BGV+(@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+/8L=J&V+39
MA=F'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B(*"B,@"B,Z(&1E;&5T92YP:'`Z
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H:7,@8V]N=&%C=#H@)7,B"FUS9W-T<B`BV*[8M]BGVXS;C"#8
MK]BQ(-BMV+#9@2#8JMF%V*?8LR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,N
M(@H*(SH@8G)O=W-E+G!H<#HW,@IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1E;&5T:6YG('1H:7,@;V)J96-T+B(*;7-G<W1R("+8KMBWV*?;C-N,(-BO
MV+$@V*W8L-F!(-BGVXS9AB#8M-N,V*$@V+'8KB#8K]BGV*_9AR#8I]BSV*HN
M(@H*(SH@8G)O=W-E+G!H<#HR-S@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H92!L:7-T(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8
ML2#9AMF%V*?;C-BT(-F!V8?8L=BSV*H@V+'8KB#8K]BGV*_9AR#8I]BSV*HN
M(@H*(R`*(SH@9&%T82YP:'`Z,S,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$Z("5S(@IM<V=S
M='(@(MBNV+?8I]N,VXP@V*_8L2#8K]BQV8C9AN*`C-BHV+'8KR#8K]BGV*_9
MAR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,B"@HC.B!L:6(O87!I+G!H<#HU
M,#<@;&EB+V%P:2YP:'`Z-S8Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`BV*[8M]BG
MVXS;C"#8K]BQ(-BOV+'9B-F&XH",V*C8L=BO(-BOV*?8K]F'V90@:4-A;&5N
M9&%R(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B(*"B,Z(&)R;W=S92YP:'`Z-3@*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!R96UO=FEN9R!A(&-O;G1A8W0@
M9G)O;2!T:&4@;&ES="XB"FUS9W-T<B`BV*[8M]BGVXS;C"#8K]BQ(-BMV+#9
M@2#;C-JI(-BJV878I]BS(-BGV+(@V8'9A]BQV+/8JB#8L=BN(-BOV*?8K]F'
M(-BGV+/8JBXB"@HC(`HC.B!A9&1R97-S8F]O:W,N<&AP.C4U(&%D9')E<W-B
M;V]K<RYP:'`Z-C`@861D<F5S<V)O;VMS+G!H<#HV.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG('1H
M:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@
MV*W8L-F!("5S(-BGV+(@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+/8L=J&
MV+39A=F'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B(*"B,@"B,Z(&%D9')E<W-B
M;V]K<RYP:'`Z.#$@861D<F5S<V)O;VMS+G!H<#HX-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M:7,@861D<F5S<R!B;V]K.B`E<R(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@
MV*C8L=F(V++8L=BSV*?9AMN,(-BGVXS9AB#9B-BQV8C8K]N,(-BQV*X@V*_8
MI]BOV8<@V*?8L]BJ.B`E<R(*"B,@"B,Z(&5D:70N<&AP.C$U.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI
M<R!E;G1R>3H@)7,B"FUS9W-T<B`BV*[8M]BGVXS;C"#8K]BQ(-BHV+'9B-BR
MV+'8L]BGV8;;C"#8I]N,V88@V8C8L=F(V*_;C"#8L=BN(-BOV*?8K]F'(-BG
MV+/8JCH@)7,B"@HC.B!D871A+G!H<#HQ-SD*;7-G:60@(E1H97)E('=E<F4@
M;F\@861D<F5S<V5S('1O(&5X<&]R="XB"FUS9W-T<B`BV*+8K]BQV+/;C"#8
MJ-BQV*?;C"#8J-BQV8C9AN*`C-BHV+'8KR#9AMF%V8C8K]F&(-F%V8C8K-F(
MV*\@V8;;C-BSV*HN(@H*(SH@=&5M<&QA=&5S+W!R969S+V%D9')E<W-B;V]K
M<V5L96-T+FEN8SHQ.#`*;7-G:60@(E1H97-E(&%D9')E<W,@8F]O:W,@=VEL
M;"!D:7-P;&%Y(&EN('1H:7,@;W)D97(Z(@IM<V=S='(@(MBGVXS9AB#:J=BJ
MV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,@V*C8IR#8I]N,V88@V*K8L=BJ
MVXS8J"#9AMF%V*?;C-BT(-BOV*?8K]F'(-BNV8C8I]F'V8;8KR#8M-BO.B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC.C(T,PIM<V=I
M9"`B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB
M"FUS9W-T<B`BV*?;C-F&(-BSV*K9B-F&V8?8IR#8J-BG(-BGVXS9AB#8JMBQ
MV*K;C-BH(-F&V878I]N,V+0@V*_8I]BOV8<@V*[9B-BGV8?9AMBO(-BTV*\Z
M(@H*(SH@9&%T82YP:'`Z,C8Y"FUS9VED(")4:&ES(&9I;&4@9F]R;6%T(&ES
M(&YO="!S=7!P;W)T960N(@IM<V=S='(@(MF"V*?9A-BH(-BGVXS9AB#9OMBQ
MV8C9AMBOV8<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S8M-F(V*\N(@H*
M(R`*(SH@;&EB+V%P:2YP:'`Z,3$R,B!L:6(O87!I+G!H<#HQ,3,U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@
M96YT<GD@:6X@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("+8I]N,V88@V8'8
ML=BO(-F'V84@V*?:J=F&V8C9AB#;C-JI(-F(V+'9B-BOVXP@)7,@V*_8L2#:
MJ=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8K]BGV+'8KRXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30W"FUS9VED("(B"B)4:&ES('=I;&P@8F4@=&AE
M(&1E9F%U;'0@861D<F5S<R!B;V]K('=H96X@861D:6YG(&]R(&EM<&]R=&EN
M9R!C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N
M<&AP+F1I<W0Z-S`*;7-G:60@(E1I=&QE(@IM<V=S='(@(MBYV8;9B-BGV88B
M"@HC.B!L:6(O5'5R8F$N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(&YE=R!S:&%R92X@($UI<W-I;F<@<V]U<F-E('1Y
M<&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]$<FEV97(N<&AP.CDW.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*K8N=BQVXS9@2`E
M<R#8L=BG(-BHV*?8L=JIV+'8KRXB"@HC.B!E9&ET+G!H<#HX."!E9&ET+G!H
M<#HY,2!E9&ET+G!H<#HY-"!E9&ET+G!H<#HY.2!E9&ET+G!H<#HQ.38*;7-G
M:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+9B-BGVJ_8L=BOV*?9AMBOV88@
MV*K8NMN,VXS8L=BGV*HB"@HC.B!L:6(O87!I+G!H<#HU-#`@;&EB+V%P:2YP
M:'`Z-C0S(&QI8B]A<&DN<&AP.C<W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;G-U<'!O<G1E9"!#;VYT96YT+51Y<&4Z("5S(@IM<V=S='(@(MF&V8C8N2#9
MA=BJV88@V*C8K]F(V88@V;[8M-BJVXS8J-BGV8;;C#H@)7,B"@HC.B!C;VYF
M:6<O<V]U<F-E<RYP:'`N9&ES=#HS-S8*;7-G:60@(E9E<FES:6=N($1I<F5C
M=&]R>2(*;7-G<W1R("+8M-BGV*[9A]F4(%9E<FES:6=N(@H*(R`*(SH@=&5M
M<&QA=&5S+V)R;W=S92]R;W<N:6YC.C$Y('1E;7!L871E<R]B<F]W<V4O8V]N
M=&%C=')O=RYI;F,Z,C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I
M97<@7"(E<UPB(@IM<V=S='(@(MF&V878I]N,V+0@)R5S)R(*"B,Z(&UI;FES
M96%R8V@N<&AP.C<X"FUS9VED(")6:65W($-O;G1A8W0B"FUS9W-T<B`BV8;9
MA=BGVXS8M"#8JMF%V*?8LR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C0*;7-G:60@(E9I97<@=&\@9&ES<&QA>2!B>2!D969A=6QT.B(*;7-G<W1R
M("+9AMF%V*?;C-BT(-F^VXS8M"#9@=BQV+8B"@HC.B!C;VYF:6<O871T<FEB
M=71E<RYP:'`N9&ES=#HR,#@*;7-G:60@(E=E8G-I=&4@55),(@IM<V=S='(@
M(E523"#9B-BHXH",VJ_8I]F'(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP
M+F1I<W0Z,3$S"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BV*+8K]BQ
MV+,@V878K=F$(-JIV*?8L2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD
M:7-T.C$R-`IM<V=I9"`B5V]R:R!#:71Y(@IM<V=S='(@(MBTV8?8L2#9A=BM
MV80@VJG8I]BQ(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,Y
M"FUS9VED(")7;W)K($-O=6YT<GDB"FUS9W-T<B`BVJG8M-F(V+$@V878K=F$
M(-JIV*?8L2(*"B,Z(&-O;F9I9R]A='1R:6)U=&5S+G!H<"YD:7-T.C$U-@IM
M<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+8JMF$V8'9AB#9A=BMV80@VJG8
MI]BQ(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3,T"FUS9VED
M(")7;W)K(%!O<W1A;"!#;V1E(@IM<V=S='(@(MJIV*_9OMBSV*K;C"#9A=BM
MV80@VJG8I]BQ(@H*(SH@8V]N9FEG+V%T=')I8G5T97,N<&AP+F1I<W0Z,3(Y
M"FUS9VED(")7;W)K(%-T871E+U!R;W9I;F-E(@IM<V=S='(@(MBGVXS8I]F$
MV*HOV*?8L]BJV*?9AB#9A=BMV80@VJG8I]BQ(@H*(SH@8V]N9FEG+V%T=')I
M8G5T97,N<&AP+F1I<W0Z,3$Y"FUS9VED(")7;W)K(%-T<F5E="!!9&1R97-S
M(@IM<V=S='(@(MBBV*_8L=BS(-BNVXS8I]BHV*?9AB#9A=BMV80@VJG8I]BQ
M(@H*(SH@9&%T82YP:'`Z,C,W(&)R;W=S92YP:'`Z.3,@8G)O=W-E+G!H<#HR
M,#$@861D+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8V]N=&%C=',@:6X@
M7"(E<UPB+B(*;7-G<W1R("+8M-F%V*<@V878K-F(V+(@V*?;C-BLV*?8KR#8
MJ-N,V+0@V*?8LB`E9"#8JMF%V*?8LR#8L=BG(-BOV+$@7"(E<UPB(-F&V*_8
MI]BQVXS8KR(*"B,Z(&5D:70N<&AP.C8Y(&1I<W!L87DN<&AP.C4X('9I97<N
M<&AP.C,V"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!V
M:65W('1H:7,@8V]N=&%C="XB"FUS9W-T<B`BV+39A=BG(-F%V*S9B-BR(-F%
MV+38I]F'V*_9A]F4(-BGVXS9AB#8JMF%V*?8LR#8L=BG(-F&V*_8I]BQVXS8
MKRXB"@HC.B!V8V%R9"YP:'`Z-#`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE8W0N(@IM<V=S='(@(MBTV878
MIR#9A=BLV8C8LB#9A=BTV*?9A]BOV8?9E"#8I]N,V88@V+3;C-BA(-BQV*<@
MV8;8K]BGV+';C-BO+B(*"B,Z('1E;7!L871E<R]B<F]W<V4O:F%V87-C<FEP
M="YI;F,Z-34*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR#;C-JI(-JIV*K8
MI]BHVH;9A]F4(-BBV*_8L=BS(-F%V8+8M=BO(-BGV8;8JMBNV*?8J"#:J=F&
MVXS8KRXB"@HC.B!T96UP;&%T97,O8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C(S
M"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;&ES="XB"FUS9W-T
M<B`BV+39A=BG(-BHV*?;C-BO(-N,VJD@V8'9A]BQV+/8JB#9A=F"V+78KR#9
MA=BTV*[8M2#:J=F&VXS8KRXB"@HC.B!E9&ET+G!H<#HS,@IM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!C;VYT86-T(&9I<G-T+B(*;7-G
M<W1R("+8M-F%V*<@V*_8L2#8I]BHV*K8K]BG(-BHV*?;C-BO(-BMV*_8I]F"
MV80@VXS:J2#8JMF%V*?8LR#8I]F&V*K8KMBGV*@@VJG9AMN,V*\N(@H*(SH@
M=&5M<&QA=&5S+V)R;W=S92]J879A<V-R:7!T+FEN8SHQ-R!T96UP;&%T97,O
M8G)O=W-E+VIA=F%S8W)I<'0N:6YC.C0Y"B,Z('1E;7!L871E<R]B<F]W<V4O
M:F%V87-C<FEP="YI;F,Z-S(*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L
M96%S="!O;F4@96YT<GD@9FER<W0N(@IM<V=S='(@(MBTV878IR#8K]BQ(-BG
MV*C8JMBOV*<@V*C8I]N,V*\@V*W8K]BGV8+9A"#;C-JI(-F(V+'9B-BOVXP@
MV*?9AMBJV*[8I]BH(-JIV8;;C-BO+B(*"B,Z(&5D:70N<&AP.C<S"FUS9VED
M(")9;W4@;VYL>2!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A
M8W0N(@IM<V=S='(@(MBTV878IR#9@=F"V+<@V878K-BGV+(@V*C9AR#8K]N,
MV*_9AB#8I]N,V88@V*K9A=BGV+,@V8?8L]BJVXS8KRXB"@HC.B!B<F]W<V4N
M<&AP.C(X-0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&%D9')E<W,@
M8F]O:R!I<R!N;W0@8G)O=W-E86)L92XB"FUS9W-T<B`BVJG8JMBGV*C:AMF'
MV90@V*+8K]BQV+,@V;[;C-BT(-F!V+'8MB#8M-F%V*<@V8+8I]BHV80@V878
ML=F(V+$@V8;;C-BSV*HB"@HC.B!T96UP;&%T97,O8G)O=W-E+W)O=RYI;F,Z
M-B!T96UP;&%T97,O8G)O=W-E+V-O;G1A8W1R;W<N:6YC.C$R"FUS9VED(");
M;F\@=F%L=65=(@IM<V=S='(@(EO8J-BOV8C9AB#9A=F"V*_8I]BQ72(*"B,Z
M(&QI8B]4=7)B82YP:'`Z-#@T"FUS9VED(")?0G)O=W-E(@IM<V=S='(@(MF%
MV+'9B-BQ(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A8W1I;VYS+FEN8SHT,`IM
M<V=I9"`B7T-O;G1A8W1S(@IM<V=S='(@(MF&V878I]BSV8?8IR(*"B,Z('1E
M;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z,@IM<V=I9"`B7T1E;&5T92(*
M;7-G<W1R("+8K=BPV8$B"@HC.B!L:6(O5'5R8F$N<&AP.C0Y,PIM<V=I9"`B
M7TEM<&]R="]%>'!O<G0B"FUS9W-T<B`BV*_8L=F(V8;B@(S8J-BQV*\OV*C8
ML=F(V8;B@(S8J-BQV*\B"@HC.B!T96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N
M:6YC.C,Y"FUS9VED(")?3&ES=',B"FUS9W-T<B`BV8'9A]BQV+/8JN*`C-F'
MV*<B"@HC.B!L:6(O5'5R8F$N<&AP.C0X,0HC+"!F=7IZ>0IM<V=I9"`B7TUY
M($%D9')E<W,@0F]O:W,B"FUS9W-T<B`BVJG8JMBGV*C:AMF'XH",V8?8I]N,
M(-BBV*_8L=BS("(*"B,Z(&QI8B]4=7)B82YP:'`Z-#@W"FUS9VED(")?3F5W
M($-O;G1A8W0B"FUS9W-T<B`BV*K9A=BGV+,@V*S8K]N,V*\B"@HC.B!T96UP
M;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC.C(*;7-G:60@(E]296UO=F4@9G)O
M;2!T:&ES(&QI<W0B"FUS9W-T<B`BV*W8L-F!(-BGV+(@V*?;C-F&(-F!V8?8
ML=BSV*HB"@HC.B!L:6(O5'5R8F$N<&AP.C0X.0IM<V=I9"`B7U-E87)C:"(*
M;7-G<W1R("+8K-BSV*K8K-F((@H*(SH@=F-A<F0N<&AP.C0V"FUS9VED(")C
M;VYT86-T+G9C9B(*;7-G<W1R(")C;VYT86-T+G9C9B(*"B,Z(&1A=&$N<&AP
M.C$Y.2!D871A+G!H<#HR,#0@=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8SHQ
M"FUS9VED(")C;VYT86-T<RYC<W8B"FUS9W-T<B`B8V]N=&%C=',N8W-V(@H*
M(SH@9&%T82YP:'`Z,C`Y"FUS9VED(")C;VYT86-T<RYT<W8B"FUS9W-T<B`B
M8V]N=&%C=',N='-V(@H*(SH@9&%T82YP:'`Z,C$Y"FUS9VED(")C;VYT86-T
M<RYV8V8B"FUS9W-T<B`B8V]N=&%C="YV8V8B"@HC.B!T96UP;&%T97,O<')E
M9G,O:6US<%]O<'0N:6YC.C,T"B,L(&9U>GIY"FUS9VED(")N;VYE(@IM<V=S
M='(@(MF'VXS:AB(*"B,Z('1E;7!L871E<R]B<F]W<V4O86-T:6]N<RYI;F,Z
M,C0*;7-G:60@(G1O(&$@0V]N=&%C="!,:7-T(@IM<V=S='(@(MBHV8<@VXS:
MJ2#9@=F'V+'8L]BJ(-BJV878I]BS(@H*(SH@=&5M<&QA=&5S+V)R;W=S92]A
M8W1I;VYS+FEN8SHQ-`IM<V=I9"`B=&\@82!D:69F97)E;G0@061D<F5S<R!"
M;V]K(@IM<V=S='(@(MBHV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V878
MJMF!V*?9B-BJ(@H*(SH@9&%T82YP:'`Z-3$@=&5M<&QA=&5S+V)R;W=S92]C
M;VQU;6Y?:&5A9&5R<RYI;F,Z,3,*(SH@=&5M<&QA=&5S+V1A=&$O:6UP;W)T
M+FEN8SHQ-2!T96UP;&%T97,O9&%T82]E>'!O<G0N:6YC.C$U"FUS9VED(")V
M0V%R9"(*;7-G<W1R(")V0V%R9"(*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O='5R8F$O;&EB+P``````````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-@`P,38S,3(`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L:6(O1')I=F5R+P``````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S4V`#`Q-S4T-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A
M+VQI8B]$<FEV97(O;&1A<"YP:'``````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P-C,S,30`,3`T,3<S-C(W-38`,#(Q,C`R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M=7)B82!D:7)E8W1O<GD@9')I=F5R(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G
M<R!,1$%0(&5X=&5N<VEO;BX*("H*("H@)$AO<F1E.B!T=7)B82]L:6(O1')I
M=F5R+VQD87`N<&AP+'8@,2XU-"XT+C$R(#(P,#4O,3$O,3`@,3(Z-#0Z,S`@
M;61J=6MI8R!%>'`@)`H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N
M0&-S:"YR:70N961U/@H@*B!`<&%C:V%G92!4=7)B80H@*B\*8VQA<W,@5'5R
M8F%?1')I=F5R7VQD87`@97AT96YD<R!4=7)B85]$<FEV97(@>PH*("`@("\J
M*@H@("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!,1$%0(&-O;FYE8W1I
M;VXN"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V
M87(@)%]D<R`](#`["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M(%1U<F)A($Q$05`@9')I=F5R(&]B:F5C="X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@)'!A<F%M<R`@2&%S
M:"!C;VYT86EN:6YG(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!4=7)B85]$<FEV97)?;&1A<"@D
M<&%R86US*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI
M<W1S*"=L9&%P)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z
M.G)A:7-E17)R;W(H7R@B3$1!4"!S=7!P;W)T(&ES(')E<75I<F5D(&)U="!T
M:&4@3$1!4"!M;V1U;&4@:7,@;F]T(&%V86EL86)L92!O<B!N;W0@;&]A9&5D
M+B(I*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AE;7!T>2@D<&%R86US6R=S97)V97(G72DI('L*("`@("`@("`@("`@
M)'!A<F%M<ULG<V5R=F5R)UT@/2`G;&]C86QH;W-T)SL*("`@("`@("!]"B`@
M("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W!O<G0G72DI('L*("`@("`@("`@
M("`@)'!A<F%M<ULG<&]R="==(#T@,S@Y.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)'!A<F%M<ULG<F]O="==*2D@>PH@("`@("`@("`@("`D<&%R
M86US6R=R;V]T)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1P87)A;7-;)VUU;'1I<&QE7V5N=')Y7W-E<&%R871O<B==*2D@>PH@("`@
M("`@("`@("`D<&%R86US6R=M=6QT:7!L95]E;G1R>5]S97!A<F%T;W(G72`]
M("<L("<["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=C
M:&%R<V5T)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)V-H87)S970G72`]
M("<G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG<V-O
M<&4G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG<V-O<&4G72`]("=S=6(G
M.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT.CI4=7)B85]$<FEV97(H)'!A
M<F%M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7VEN:70H*0H@("`@>PH@("`@
M("`@(&EF("@A*"1T:&ES+3Y?9',@/2!`;&1A<%]C;VYN96-T*"1T:&ES+3Y?
M<&%R86US6R=S97)V97(G72P@)'1H:7,M/E]P87)A;7-;)W!O<G0G72DI*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O;FYE
M8W1I;VX@9F%I;'5R92(I*3L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T
M:&4@3$1!4"!P<F]T;V-O;"!V97)S:6]N+B`J+PH@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72DI('L*("`@("`@("`@("`@
M0&QD87!?<V5T7V]P=&EO;B@D=&AI<RT^7V1S+"!,1$%07T]05%]04D]43T-/
M3%]615)324].+"`D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==*3L*("`@("`@
M("!]"@H@("`@("`@("\J(%-T87)T(%1,4R!I9B!W92=R92!U<VEN9R!I="X@
M*B\*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=T;',G72DI
M('L*("`@("`@("`@("`@:68@*"%`;&1A<%]S=&%R=%]T;',H)'1H:7,M/E]D
M<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B4U1!4E143%,@9F%I;&5D.B`H)7,I("5S(BDL(&QD87!?
M97)R;F\H)'1H:7,M/E]D<RDL(&QD87!?97)R;W(H)'1H:7,M/E]D<RDI*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@0FEN9"!T;R!T
M:&4@<V5R=F5R+B`J+PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M
M<ULG8FEN9%]D;B==*2`F)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W!A
M<F%M<ULG8FEN9%]P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!I9B`H(4!L
M9&%P7V)I;F0H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)I;F1?9&XG
M72P@)'1H:7,M/E]P87)A;7-;)V)I;F1?<&%S<W=O<F0G72DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M0FEN9"!F86EL960Z("@E<RD@)7,B*2P@;&1A<%]E<G)N;R@D=&AI<RT^7V1S
M*2P@;&1A<%]E<G)O<B@D=&AI<RT^7V1S*2DI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E:68@*"$H0&QD87!?8FEN9"@D=&AI<RT^7V1S*2DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")":6YD(&9A:6QE9#H@*"5S*2`E<R(I+"!L9&%P7V5R<FYO*"1T:&ES+3Y?
M9',I+"!L9&%P7V5R<F]R*"1T:&ES+3Y?9',I*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E87)C
M:&5S('1H92!,1$%0(&1I<F5C=&]R>2!W:71H('1H92!G:79E;B!C<FET97)I
M82!A;F0@<F5T=7)N<PH@("`@("H@82!F:6QT97)E9"!L:7-T(&]F(')E<W5L
M=',N($EF(&YO(&-R:71E<FEA(&%R92!S<&5C:69I960L(&%L;`H@("`@("H@
M<F5C;W)D<R!A<F4@<F5T=7)N960N"B`@("`@*@H@("`@("H@0'!A<F%M("1C
M<FET97)I82`@("`@($%R<F%Y(&-O;G1A:6YI;F<@=&AE('-E87)C:"!C<FET
M97)I82X*("`@("`J($!P87)A;2`D9FEE;&1S("`@("`@("!,:7-T(&]F(&9I
M96QD<R!T;R!R971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M2&%S:"!C;VYT86EN:6YG('1H92!S96%R8V@@<F5S=6QT<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-E87)C:"@D8W)I=&5R:6$L("1F:65L9',I"B`@("![
M"B`@("`@("`@+RH@0G5I;&0@=&AE($Q$05`@9FEL=&5R+B`J+PH@("`@("`@
M("1F:6QT97(@/2`G)SL*("`@("`@("!I9B`H8V]U;G0H)&-R:71E<FEA*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D
M=F%L<RD@>PH@("`@("`@("`@("`@("`@:68@*"1K97D@/3T@)T]2)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1F:6QT97(@+CT@)RA\)R`N("1T:&ES+3Y?
M8G5I;&1396%R8VA1=65R>2@D=F%L<RD@+B`G*2<["B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)&ME>2`]/2`G04Y$)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1F:6QT97(@+CT@)R@F)R`N("1T:&ES+3Y?8G5I;&1396%R8VA1=65R
M>2@D=F%L<RD@+B`G*2<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!&:6QT97(@;VX@
M;V)J96-T8VQA<W,N("HO"B`@("`@("`@("`@("1F:6QT97(@/2`D=&AI<RT^
M7V)U:6QD3V)J96-T8VQA<W-&:6QT97(H*3L*("`@("`@("!]"@H@("`@("`@
M("\J($%D9"!S;W5R8V4M=VED92!F:6QT97)S+"!W:&EC:"!A<F4@7V%L=V%Y
M<U\@04Y$+65D+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A
M;7-;)V9I;'1E<B==*2D@>PH@("`@("`@("`@("`D9FEL=&5R(#T@)R@F)R`N
M("<H)R`N("1T:&ES+3Y?<&%R86US6R=F:6QT97(G72`N("<I)R`N("1F:6QT
M97(@+B`G*2<["B`@("`@("`@?0H*("`@("`@("`O*B!&;W5R,3$@*&%T(&QE
M87-T*2!D;V5S;B=T('-E96T@=&\@<F5T=7)N("=C;B<@:68@>6]U(&1O;B=T
M"B`@("`@("`@("H@87-K(&9O<B`G<VXG(&%S('=E;&PN($%D9"`G<VXG(&EM
M<&QI8VET;'DN("HO"B`@("`@("`@)&%T='(@/2`D9FEE;&1S.PH@("`@("`@
M(&EF("@A:6Y?87)R87DH)W-N)RP@)&%T='(I*2!["B`@("`@("`@("`@("1A
M='1R6UT@/2`G<VXG.PH@("`@("`@('T*"B`@("`@("`@+RH@061D(&$@<VEZ
M96QI;6ET+"!I9B!S<&5C:69I960N($1E9F%U;'0@:7,@,"P@=VAI8V@@;65A
M;G,@;F\*("`@("`@("`@*B!L:6UI="X@($YO=&4Z(%EO=2!C86YN;W0@;W9E
M<G)I9&4@82!S97)V97(M<VED92!L:6UI="!W:71H"B`@("`@("`@("H@=&AI
M<RX@*B\*("`@("`@("`D<VEZ96QI;6ET(#T@,#L*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=S:7IE;&EM:70G72DI('L*("`@("`@("`@
M("`@)'-I>F5L:6UI="`]("1T:&ES+3Y?<&%R86US6R=S:7IE;&EM:70G73L*
M("`@("`@("!]"@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)5
M1R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R
M:6YT9B@G3$1!4"!Q=65R>2!B>2!4=7)B85]$<FEV97)?;&1A<#HZ7W-E87)C
M:"@I.B!U<V5R(#T@)7,L(')O;W0@/2`E<R`H)7,I.R!F:6QT97(@/2`B)7,B
M.R!A='1R:6)U=&5S(#T@(B5S(CL@<VEZ96QI;6ET(#T@)60G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@075T:#HZ9V5T075T:"@I+"`D
M=&AI<RT^7W!A<F%M<ULG<F]O="==+"`D=&AI<RT^7W!A<F%M<ULG<V5R=F5R
M)UTL("1F:6QT97(L(&EM<&QO9&4H)RP@)RP@)&%T='(I+"`D<VEZ96QI;6ET
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@4V5N9"!T:&4@<75E
M<GD@=&\@=&AE($Q$05`@<V5R=F5R(&%N9"!F971C:"!T:&4@;6%T8VAI;F<*
M("`@("`@("`@*B!E;G1R:65S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A
M<F%M<ULG<V-O<&4G72`]/2`G;VYE)RD@>PH@("`@("`@("`@("`D9G5N8R`]
M("=L9&%P7VQI<W0G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M=6YC(#T@)VQD87!?<V5A<F-H)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A
M*"1R97,@/2!`)&9U;F,H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)W)O
M;W0G72P@)&9I;'1E<BP@)&%T='(L(#`L("1S:7IE;&EM:70I*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E%U
M97)Y(&9A:6QE9#H@*"5S*2`E<R(I+"!L9&%P7V5R<FYO*"1T:&ES+3Y?9',I
M+"!L9&%P7V5R<F]R*"1T:&ES+3Y?9',I*2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H:7,M/E]G971297-U;'1S*"1F:65L9',L("1R97,I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@=&AE($Q$05`@9&ER96-T;W)Y
M(&9O<B!A(&=I=F5N(&5L96UE;G0@86YD(')E='5R;G,*("`@("`J('1H92!R
M97-U;'0G<R!F:65L9',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8W)I=&5R:6$@(%-E87)C:"!C<FET97)I82`H;75S="!B92`G9&XG*2X*("`@
M("`J($!P87)A;2!M:7AE9"`@)&1N("`@("`@("!4:&4@9&X@;V8@=&AE(&]B
M:F5C="!T;R!R96%D+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D9FEE;&1S("`@
M($QI<W0@;V8@9FEE;&1S('1O(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!(87-H(&-O;G1A:6YI;F<@=&AE('-E87)C:"!R97-U;'1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5A9"@D8W)I=&5R:6$L("1D;BP@
M)&9I96QD<RD*("`@('L*("`@("`@("`O*B!/;FQY($1.+B`J+PH@("`@("`@
M(&EF("@D8W)I=&5R:6$@(3T@)V1N)RD@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1F:6QT97(@/2`D=&AI<RT^
M7V)U:6QD3V)J96-T8VQA<W-&:6QT97(H*3L*"B`@("`@("`@+RH@1F]U<C$Q
M("AA="!L96%S="D@9&]E<VXG="!S965M('1O(')E='5R;B`G8VXG(&EF('EO
M=2!D;VXG=`H@("`@("`@("`J(&%S:R!F;W(@)W-N)R!A<R!W96QL+B!!9&0@
M)W-N)R!I;7!L:6-I=&QY+B`J+PH@("`@("`@("1A='1R(#T@)&9I96QD<SL*
M("`@("`@("!I9B`H(6EN7V%R<F%Y*"=S;B<L("1A='1R*2D@>PH@("`@("`@
M("`@("`D871T<EM=(#T@)W-N)SL*("`@("`@("!]"@H@("`@("`@("\J($AA
M;F1L92!A(')E<75E<W0@9F]R(&UU;'1I<&QE(')E8V]R9',N("HO"B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1D;BDI('L*("`@("`@("`@("`@)')E<W5L=',@
M/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D9&X@87,@)&0I('L*
M("`@("`@("`@("`@("`@("1R97,@/2!`;&1A<%]R96%D*"1T:&ES+3Y?9',L
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&0L($Y,4SHZ9V5T0VAA<G-E="@I
M+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*2P@)&9I;'1E<BP@)&%T='(I
M.PH@("`@("`@("`@("`@("`@:68@*"1R97,I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES7V$H)')E<W5L="`]("1T:&ES+3Y?9V5T4F5S=6QT<R@D
M9FEE;&1S+"`D<F5S*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5S=6QT<R`](&%R<F%Y7VUE<F=E*"1R97-U;'1S+"`D
M<F5S=6QT*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M4F5A9"!F86EL960Z("@E<RD@)7,B*2P@;&1A<%]E<G)N;R@D=&AI<RT^7V1S
M*2P@;&1A<%]E<G)O<B@D=&AI<RT^7V1S*2DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT<SL*
M("`@("`@("!]"@H@("`@("`@("1R97,@/2!`;&1A<%]R96%D*"1T:&ES+3Y?
M9',L(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&1N+"!.3%,Z.F=E=$-H87)S
M970H*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72DL("1F:6QT97(L("1A
M='1R*3L*("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")296%D(&9A:6QE9#H@*"5S
M*2`E<R(I+"!L9&%P7V5R<FYO*"1T:&ES+3Y?9',I+"!L9&%P7V5R<F]R*"1T
M:&ES+3Y?9',I*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]G971297-U;'1S*"1F:65L9',L("1R97,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@061D<R!T:&4@<W!E8VEF:65D(&5N=')Y('1O('1H92!,1$%0(&1I
M<F5C=&]R>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T
M97,@(%1H92!I;FET:6%L(&%T=')I8G5T97,@9F]R('1H92!N97<@;V)J96-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D*"1A='1R:6)U=&5S*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D871T<FEB=71E<ULG9&XG72DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U1R:65D('1O(&%D
M9"!A;B!O8FIE8W0@=VET:"!N;R!D;CH@6R<@+B!S97)I86QI>F4H)&%T=')I
M8G5T97,I("X@)UTN)RD["B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1T:&ES
M+3Y?<&%R86US6R=O8FIE8W1C;&%S<R==*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G5')I960@=&\@861D(&%N(&]B:F5C="!W
M:71H(&YO(&]B:F5C=&-L87-S.B!;)R`N('-E<FEA;&EZ92@D871T<FEB=71E
M<RD@+B`G72XG*3L*("`@("`@("!]"@H@("`@("`@("\J(%1A:V4@=&AE($1.
M(&]U="!O9B!T:&4@871T<FEB=71E<R!A<G)A>2X@*B\*("`@("`@("`D9&X@
M/2`D871T<FEB=71E<ULG9&XG73L*("`@("`@("!U;G-E="@D871T<FEB=71E
M<ULG9&XG72D["@H@("`@("`@("\J(%!U="!T:&4@;V)J96-T0VQA<W,@:6YT
M;R!T:&4@871T<FEB=71E<R!A<G)A>2X@*B\*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1T:&ES+3Y?<&%R86US6R=O8FIE8W1C;&%S<R==*2D@>PH@("`@("`@
M("`@("`D871T<FEB=71E<ULG;V)J96-T8VQA<W,G72`]("1T:&ES+3Y?<&%R
M86US6R=O8FIE8W1C;&%S<R==.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1I(#T@,#L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)A
M;7-;)V]B:F5C=&-L87-S)UT@87,@)&]B:F5C=&-L87-S*2!["B`@("`@("`@
M("`@("`@("`D871T<FEB=71E<ULG;V)J96-T8VQA<W,G75LD:5T@/2`D;V)J
M96-T8VQA<W,["B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!$;VXG="!A9&0@96UP='D@871T<FEB
M=71E<RX@*B\*("`@("`@("`D871T<FEB=71E<R`](&%R<F%Y7V9I;'1E<B@D
M871T<FEB=71E<RP@87)R87DH)'1H:7,L("=?96UP='E!='1R:6)U=&5&:6QT
M97(G*2D["@H@("`@("`@("\J($EF(&$@<F5Q=6ER960@871T<FEB=71E(&1O
M97-N)W0@97AI<W0L(&%D9"!A(&1U;6UY"B`@("`@("`@("H@=F%L=64N("HO
M"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG8VAE8VMR97%U
M:7)E9"==*2D@>PH@("`@("`@("`@("`D<F5Q=6ER960@/2`D=&AI<RT^7V-H
M96-K4F5Q=6ER961!='1R:6)U=&5S*"1T:&ES+3Y?<&%R86US6R=O8FIE8W1C
M;&%S<R==*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<75I<F5D+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<75I<F5D
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D<F5Q=6ER
M960@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&%T=')I8G5T97-;)'9=*2D@>PH@("`@("`@("`@("`@("`@("`@("1A='1R
M:6)U=&5S6R1V72`]("1T:&ES+3Y?<&%R86US6R=C:&5C:W)E<75I<F5D7W-T
M<FEN9R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V5N8V]D94%T=')I8G5T97,H)&%T=')I
M8G5T97,I.PH*("`@("`@("!I9B`H(4!L9&%P7V%D9"@D=&AI<RT^7V1S+"!3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D;BP@3DQ3.CIG971#:&%R<V5T*"DL
M("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI+"`D871T<FEB=71E<RDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T
M;R!A9&0@86X@;V)J96-T.B!;)R`N(&QD87!?97)R;F\H)'1H:7,M/E]D<RD@
M+B`G72`B)R`N(&QD87!?97)R;W(H)'1H:7,M/E]D<RD@+B`G(B!$3CH@)R`N
M("1D;B`N("<@*&%T=')I8G5T97,Z(%LG("X@<V5R:6%L:7IE*"1A='1R:6)U
M=&5S*2`N("==*2XG("X@(D-H87)S970Z(B`N($Y,4SHZ9V5T0VAA<G-E="@I
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H92!S
M<&5C:69I960@96YT<GD@9G)O;2!T:&4@3$1!4"!D:7)E8W1O<GDN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]D96QE=&4H)&]B:F5C=%]K97DL("1O8FIE8W1?
M:60I"B`@("!["B`@("`@("`@:68@*"1O8FIE8W1?:V5Y("$]("=D;B<I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI
M9"!K97D@<W!E8VEF:65D+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M0&QD87!?9&5L971E*"1T:&ES+3Y?9',L(%-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H)&]B:F5C=%]I9"P@3DQ3.CIG971#:&%R<V5T*"DL("1T:&ES+3Y?<&%R
M86US6R=C:&%R<V5T)UTI*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(D1E;&5T92!F86EL960Z("@E<RD@)7,B
M*2P@;&1A<%]E<G)N;R@D=&AI<RT^7V1S*2P@;&1A<%]E<G)O<B@D=&AI<RT^
M7V1S*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UO9&EF:65S
M('1H92!S<&5C:69I960@96YT<GD@:6X@=&AE($Q$05`@9&ER96-T;W)Y+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;V)J96-T(&ED+"!P
M;W-S:6)L>2!U<&1A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V%V92@D
M;V)J96-T7VME>2P@)&]B:F5C=%]I9"P@)&%T=')I8G5T97,I"B`@("!["B`@
M("`@("`@+RH@1V5T('1H92!O;&0@96YT<GD@<V\@=&AA="!W92!C86X@86-C
M97-S('1H92!O;&0*("`@("`@("`@*B!V86QU97,N(%1H97-E(&%R92!N965D
M960@<V\@=&AA="!W92!C86X@9&5L971E(&%N>0H@("`@("`@("`J(&%T=')I
M8G5T97,@=&AA="!H879E(&)E96X@<F5M;W9E9"!B>2!U<VEN9R!L9&%P7VUO
M9%]D96PN("HO"B`@("`@("`@)&9I;'1E<B`]("1T:&ES+3Y?8G5I;&1/8FIE
M8W1C;&%S<T9I;'1E<B@I.PH@("`@("`@("1O;&1R97,@/2!`;&1A<%]R96%D
M*"1T:&ES+3Y?9',L(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&]B:F5C=%]I
M9"P@3DQ3.CIG971#:&%R<V5T*"DL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T
M)UTI+"`D9FEL=&5R+"!A<G)A>5]M97)G92AA<G)A>5]K97ES*"1A='1R:6)U
M=&5S*2P@87)R87DH)V]B:F5C=&-L87-S)RDI*3L*("`@("`@("`D:6YF;R`]
M(&QD87!?9V5T7V%T=')I8G5T97,H)'1H:7,M/E]D<RP@;&1A<%]F:7)S=%]E
M;G1R>2@D=&AI<RT^7V1S+"`D;VQD<F5S*2D["@H@("`@("`@("\J($-H96-K
M(&EF('=E(&YE960@=&\@<F5N86UE('1H92!O8FIE8W0N("HO"B`@("`@("`@
M:68@*"1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UT@/3T@,R`F)@H@("`@("`@
M("`@("!3=')I;F<Z.FQO=V5R*"1T:&ES+3Y?;6%K94ME>2@D871T<FEB=71E
M<RDI("$](%-T<FEN9SHZ;&]W97(H)&]B:F5C=%]I9"DI('L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D;B==*2`F)B!I<U]A<G)A
M>2@D=&AI<RT^7W!A<F%M<ULG9&XG72D@)B8@8V]U;G0H)'1H:7,M/E]P87)A
M;7-;)V1N)UTI*2!["B`@("`@("`@("`@("`@("`D<&%I<G,@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;)V1N
M)UT@87,@)'!A<F%M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1A='1R:6)U=&5S6R1P87)A;5TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1P86ER<UM=(#T@87)R87DH)'!A<F%M+"`D871T<FEB=71E<ULD<&%R
M86U=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D;F5W<F1N(#T@)'1H:7,M/E]Q=6]T941.*"1P
M86ER<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")-:7-S:6YG($1.(&EN($Q$05`@
M<V]U<F-E(&-O;F9I9W5R871I;VXN(BDI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H;&1A<%]R96YA;64H)'1H:7,M/E]D<RP@4W1R:6YG.CIC
M;VYV97)T0VAA<G-E="@D;V)J96-T7VED+"!.3%,Z.F=E=$-H87)S970H*2P@
M)'1H:7,M/E]P87)A;7-;)V-H87)S970G72DL"B`@("`@("`@("`@("`@("`@
M("`@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;F5W<F1N+"!.3%,Z.F=E=$-H
M87)S970H*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72DL("1T:&ES+3Y?
M<&%R86US6R=R;V]T)UTL('1R=64I*2!["B`@("`@("`@("`@("`@("`D;V)J
M96-T7VED(#T@)&YE=W)D;B`N("<L)R`N("1T:&ES+3Y?<&%R86US6R=R;V]T
M)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9A:6QE9"!T;R!C:&%N
M9V4@;F%M93H@*"5S*2`E<SL@3VQD($1.(#T@)7,L($YE=R!$3B`]("5S+"!2
M;V]T(#T@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V1S*2P@;&1A<%]E
M<G)O<B@D=&AI<RT^7V1S*2P@)&]B:F5C=%]I9"P@)&YE=W)D;BP@)'1H:7,M
M/E]P87)A;7-;)W)O;W0G72DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O*B!4:&4@871T<FEB=71E<R!I;B!T:&4@871T<FEB=71E<R!A
M<G)A>2!A<F4@86QL(&QO=V5R(&-A<V4*("`@("`@("`@*B!W:&EL92!T:&5Y
M(&%R92!M:7AE9$-A<V4@:6X@=&AE('-E87)C:"!R97-U;'0N(%-O(&-O;G9E
M<G0*("`@("`@("`@*B!T:&4@:V5Y<R!T;R!L;W=E<BX@*B\*("`@("`@("`D
M:6YF;R`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D:6YF;RP@0T%315],3U=%
M4BD["@H@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1K97D@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("1V87(@/2`D:6YF;ULD:V5Y73L*("`@("`@("`@
M("`@)&]L9'9A;"`](&YU;&P["@H@("`@("`@("`@("`O*B!#:&5C:R!T;R!S
M964@:68@=&AE(&]L9"!V86QU92!A;F0@=&AE(&YE=R!V86QU92!A<F4*("`@
M("`@("`@("`@("H@9&EF9F5R96YT(&%N9"!T:&%T('1H92!N97<@=F%L=64@
M:7,@96UP='DN($EF('-O('1H96X*("`@("`@("`@("`@("H@=V4@=7-E(&QD
M87!?;6]D7V1E;"!T;R!D96QE=&4@=&AE(&%T=')I8G5T92X@*B\*("`@("`@
M("`@("`@:68@*&ES<V5T*"1A='1R:6)U=&5S6R1K97E=*2`F)@H@("`@("`@
M("`@("`@("`@*"1V87);,%T@(3T@)&%T=')I8G5T97-;)&ME>5TI("8F"B`@
M("`@("`@("`@("`@("`D871T<FEB=71E<ULD:V5Y72`]/2`G)RD@>PH*("`@
M("`@("`@("`@("`@("1O;&1V86Q;)&ME>5T@/2`D=F%R6S!=.PH@("`@("`@
M("`@("`@("`@:68@*"%`;&1A<%]M;V1?9&5L*"1T:&ES+3Y?9',L(%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)&]B:F5C=%]I9"P@3DQ3.CIG971#:&%R<V5T
M*"DL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI+"`D;VQD=F%L*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B36]D:69Y(&9A:6QE9#H@*"5S*2`E<R(I+"!L9&%P7V5R<FYO
M*"1T:&ES+3Y?9',I+"!L9&%P7V5R<F]R*"1T:&ES+3Y?9',I*2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!U;G-E="@D871T<FEB=71E
M<ULD:V5Y72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('5N
M<V5T*"1A='1R:6)U=&5S6R1O8FIE8W1?:V5Y72D["B`@("`@("`@)'1H:7,M
M/E]E;F-O9&5!='1R:6)U=&5S*"1A='1R:6)U=&5S*3L*("`@("`@("`D871T
M<FEB=71E<R`](&%R<F%Y7V9I;'1E<B@D871T<FEB=71E<RP@87)R87DH)'1H
M:7,L("=?96UP='E!='1R:6)U=&5&:6QT97(G*2D["@H@("`@("`@("\J($UO
M9&EF>2!O8FIE8W1C;&%S<R!I9B!O;&0@;VYE(&ES(&]U=&1A=&5D+B`J+PH@
M("`@("`@("1A='1R:6)U=&5S6R=O8FIE8W1C;&%S<R==(#T@87)R87E?=6YI
M<75E*&%R<F%Y7VUA<"@G<W1R=&]L;W=E<B<L(&%R<F%Y7VUE<F=E*"1I;F9O
M6R=O8FIE8W1C;&%S<R==+"`D=&AI<RT^7W!A<F%M<ULG;V)J96-T8VQA<W,G
M72DI*3L*("`@("`@("!U;G-E="@D871T<FEB=71E<ULG;V)J96-T8VQA<W,G
M75LG8V]U;G0G72D["B`@("`@("`@)&%T=')I8G5T97-;)V]B:F5C=&-L87-S
M)UT@/2!A<G)A>5]V86QU97,H)&%T=')I8G5T97-;)V]B:F5C=&-L87-S)UTI
M.PH*("`@("`@("!I9B`H(4!L9&%P7VUO9&EF>2@D=&AI<RT^7V1S+"!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1O8FIE8W1?:60L($Y,4SHZ9V5T0VAA<G-E
M="@I+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*2P@)&%T=')I8G5T97,I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B36]D:69Y(&9A:6QE9#H@*"5S*2`E<R(I+"!L9&%P7V5R<FYO*"1T
M:&ES+3Y?9',I+"!L9&%P7V5R<F]R*"1T:&ES+3Y?9',I*2D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1O8FIE8W1?:60["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&0@82!$3B!B87-E9"!O
M;B!A('-E="!O9B!A='1R:6)U=&5S(&%N9"!W:&%T(&%T=')I8G5T97,*("`@
M("`J(&UA:V4@82!$3B!F;W(@=&AE(&-U<G)E;G0@<V]U<F-E+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E<R!4:&4@871T<FEB=71E
M<R`H:6X@9')I=F5R(&ME>7,I(&]F('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&]B:F5C="!B96EN9R!A9&1E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($1.(&9O<B!T:&4@;F5W(&]B:F5C="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7VUA:V5+97DH)&%T=')I8G5T97,I"B`@
M("!["B`@("`@("`@)&1N(#T@)R<["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3Y?<&%R86US6R=D;B==*2D@>PH@("`@("`@("`@("`D<&%I<G,@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG
M9&XG72!A<R`D<&%R86TI('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M871T<FEB=71E<ULD<&%R86U=*2D@>PH@("`@("`@("`@("`@("`@("`@("1P
M86ER<UM=(#T@87)R87DH)'!A<F%M+"`D871T<FEB=71E<ULD<&%R86U=*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M9&X@/2`D=&AI<RT^7W%U;W1E1$XH)'!A:7)S*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9&X@+B`G+"<@+B`D=&AI<RT^7W!A<F%M<ULG<F]O="==
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&0@82!P:65C92!O9B!A('-E
M87)C:"!Q=65R>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("1C<FET
M97)I82`@5&AE(&%R<F%Y(&]F(&-R:71E<FEA+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!!;B!,1$%0('%U97)Y(&9R86=M96YT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8G5I;&1396%R8VA1=65R>2@D8W)I=&5R:6$I"B`@
M("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92],1$%0+G!H<"<["@H@
M("`@("`@("1C;&%U<V4@/2`G)SL*("`@("`@("!F;W)E86-H("@D8W)I=&5R
M:6$@87,@)&ME>2`]/B`D=F%L<RD@>PH@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1V86QS6R=/4B==*2D@>PH@("`@("`@("`@("`@("`@)&-L875S92`N/2`G
M*'PG("X@)'1H:7,M/E]B=6EL9%-E87)C:%%U97)Y*"1V86QS*2`N("<I)SL*
M("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=F%L<ULG04Y$)UTI*2![
M"B`@("`@("`@("`@("`@("`D8VQA=7-E("X]("<H)B<@+B`D=&AI<RT^7V)U
M:6QD4V5A<F-H475E<GDH)'9A;',I("X@)RDG.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QS6R=F:65L9"==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1R:',@/2!3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*"1V86QS6R=T97-T)UTL($Y,4SHZ9V5T0VAA<G-E="@I+"`D
M=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*3L*("`@("`@("`@("`@("`@("`@
M("`D8VQA=7-E("X]($AO<F1E7TQ$05`Z.F)U:6QD0VQA=7-E*"1V86QS6R=F
M:65L9"==+"`D=F%L<ULG;W`G72P@)')H<RD["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QS(&%S
M("1T97-T*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)'1E<W1;)T]2)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8VQA=7-E("X]("<H?"<@+B`D=&AI<RT^7V)U:6QD4V5A<F-H475E<GDH)'1E
M<W0I("X@)RDG.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M(65M<'1Y*"1T97-T6R=!3D0G72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1C;&%U<V4@+CT@)R@F)R`N("1T:&ES+3Y?8G5I;&1396%R8VA1
M=65R>2@D=&5S="D@+B`G*2<["B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<FAS(#T@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="@D=&5S=%LG=&5S="==+"!.3%,Z.F=E=$-H
M87)S970H*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8VQA=7-E("X]($AO<F1E7TQ$05`Z.F)U
M:6QD0VQA=7-E*"1T97-T6R=F:65L9"==+"`D=&5S=%LG;W`G72P@)')H<RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8VQA=7-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('-O;64@<F5S=6QT<R!F<F]M(&$@<F5S=6QT(&ED96YT:69I97(@
M86YD(&-L96%N('1H96T@=7`N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("`@("1F:65L9',@($QI<W0@;V8@9FEE;&1S('1O(')E='5R;BX*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S("`@("!297-U;'0@:61E;G1I9FEE<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!(87-H(&-O;G1A:6YI;F<@
M=&AE(')E<W5L=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971297-U;'1S
M*"1F:65L9',L("1R97,I"B`@("!["B`@("`@("`@:68@*"$H)&5N=')I97,@
M/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<F5S*2DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")2
M96%D(&9A:6QE9#H@*"5S*2`E<R(I+"!L9&%P7V5R<FYO*"1T:&ES+3Y?9',I
M+"!L9&%P7V5R<F]R*"1T:&ES+3Y?9',I*2D["B`@("`@("`@?0H*("`@("`@
M("`O*B!2971U<FX@;VYL>2!T:&4@<F5Q=65S=&5D(&9I96QD<R`H9G)O;2`D
M9FEE;&1S+"!A8F]V92DN("HO"B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1E;G1R:65S6R=C;W5N="==
M.R`D:2LK*2!["B`@("`@("`@("`@("1E;G1R>2`]("1E;G1R:65S6R1I73L*
M("`@("`@("`@("`@)')E<W5L="`](&%R<F%Y*"D["@H@("`@("`@("`@("!F
M;W)E86-H("@D9FEE;&1S(&%S("1F:65L9"D@>PH@("`@("`@("`@("`@("`@
M)&9I96QD7VP@/2!3=')I;F<Z.FQO=V5R*"1F:65L9"D["B`@("`@("`@("`@
M("`@("!I9B`H)&9I96QD(#T]("=D;B<I('L*("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT6R1F:65L9%T@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1E
M;G1R>5LD9FEE;&1?;%TL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M<F5S=6QT6R1F:65L9%T@/2`G)SL*("`@("`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1E;G1R>5LD9FEE;&1?;%TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1E;G1R>5LD9FEE;&1?;%U;)V-O
M=6YT)UT[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)')E<W5L=%LD9FEE;&1=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R97-U;'1;)&9I96QD72`N/2`D=&AI<RT^7W!A
M<F%M<ULG;75L=&EP;&5?96YT<GE?<V5P87)A=&]R)UT["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT6R1F:65L9%T@+CT@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M96YT<GE;)&9I96QD7VQ=6R1J72P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G
M72D["B`@("`@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`@("`@("`@("\J($EF('-C:&5M82!C:&5C:VEN9R!I<R!E;F%B;&5D(&-H
M96-K('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@*B!B86-K96YD('-Y
M;G1A>"X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG8VAE8VMS>6YT87@G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;W-T86P@/2`D=&AI<RT^7VES4&]S=&%L061D
M<F5S<R@D9FEE;&1?;"D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O*B!/=&AE<G=I<V4@
M<F5L>2!O;B!T:&4@871T<FEB=71E(&UA<'!I;F<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`J(&EN(&%T=')I8G5T97,N<&AP+B`J+PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&%T='(@/2!A<G)A>5]S96%R8V@H)&9I
M96QD7VPL("1T:&ES+3YM87`I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!O<W1A;"`]("@A96UP='DH)&%T='(I("8F("%E;7!T>2@D1TQ/0D%,
M4ULG871T<FEB=71E<R==6R1A='1R72D@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)V%T=')I8G5T97,G75LD
M871T<EU;)W1Y<&4G72`]/2`G861D<F5S<R<I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<&]S=&%L
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6R1F:65L
M9%T@/2!S=')?<F5P;&%C92@G)"<L(")<<EQN(BP@)')E<W5L=%LD9FEE;&1=
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)')E<W5L='-;72`]("1R97-U;'0["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)')E<W5L=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO
M=F4@96UP='D@871T<FEB=71E<R!F<F]M(&%T=')I8G5T97,@87)R87DN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1V86P@("`@5F%L=64@9G)O;2!A
M='1R:6)U=&5S(&%R<F%Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@("`@("`@($)O;VQE86X@=7-E9"!B>2!A<G)A>5]F:6QT97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]E;7!T>4%T=')I8G5T949I;'1E<B@D=F%R*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)'9A<BDI('L*("`@("`@("`@
M("`@<F5T=7)N("@D=F%R("$]("<G*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!F;W)E86-H("@D=F%R(&%S("1V*2!["B`@("`@("`@("`@("`@
M("!I9B`H)'8@/3T@)R<I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1F]R;6%T(&%N9"!E;F-O9&4@871T<FEB=71E<R!I;F-L=61I;F<@
M<&]S=&%L(&%D9')E<W-E<RP*("`@("`J(&-H87)A8W1E<B!S970@96YC;V1I
M;F<L(&5T8RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V5N8V]D94%T=')I8G5T
M97,H)B1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1A='1R
M:6)U=&5S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`O*B!)9B!S
M8VAE;6$@8VAE8VMI;F<@:7,@96YA8FQE9"!C:&5C:R!T:&4@8F%C:V5N9"!S
M>6YT87@N("HO"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A
M;7-;)V-H96-K<WEN=&%X)UTI*2!["B`@("`@("`@("`@("`@("`D<&]S=&%L
M(#T@)'1H:7,M/E]I<U!O<W1A;$%D9')E<W,H)&ME>2D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!/=&AE<G=I<V4@<F5L>2!O
M;B!T:&4@871T<FEB=71E(&UA<'!I;F<@:6X*("`@("`@("`@("`@("`@("`J
M(&%T=')I8G5T97,N<&AP+B`J+PH@("`@("`@("`@("`@("`@)&%T='(@/2!A
M<G)A>5]S96%R8V@H)&ME>2P@)'1H:7,M/FUA<"D["B`@("`@("`@("`@("`@
M("`D<&]S=&%L(#T@*"%E;7!T>2@D871T<BD@)B8@(65M<'1Y*"1V86PI("8F
M("%E;7!T>2@D1TQ/0D%,4ULG871T<FEB=71E<R==6R1A='1R72D@)B8*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)V%T=')I8G5T97,G
M75LD871T<EU;)W1Y<&4G72`]/2`G861D<F5S<R<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@D<&]S=&%L*2!["B`@("`@("`@("`@("`@("`O
M*B!#;W)R96-T;'D@<W1O<F4@<&]S=&%L(&%D9')E<W-E<RX@*B\*("`@("`@
M("`@("`@("`@("1V86P@/2!S=')?<F5P;&%C92AA<G)A>2@B7')<;B(L(")<
M<B(L(")<;B(I+"`G)"<L("1V86PI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@("`@("`@("`D
M871T<FEB=71E<ULD:V5Y72`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A
M;"P@3DQ3.CIG971#:&%R<V5T*"DL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T
M)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@0G5I;&0@86X@3$1!4"!F:6QT97(@8F%S960@;VX@=&AE(&]B:F5C
M=&-L87-S('!A<F%M971E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@06X@3$1!4"!F:6QT97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL
M9$]B:F5C=&-L87-S1FEL=&5R*"D*("`@('L*("`@("`@("`D9FEL=&5R(#T@
M)R<["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG;V)J96-T
M8VQA<W,G72DI('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=&AI<RT^
M7W!A<F%M<ULG;V)J96-T8VQA<W,G72DI('L*("`@("`@("`@("`@("`@("1F
M:6QT97(@/2`G*&]B:F5C=&-L87-S/2<@+B`D=&AI<RT^7W!A<F%M<ULG;V)J
M96-T8VQA<W,G72`N("<I)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1F:6QT97(@/2`G*'PG.PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]P87)A;7-;)V]B:F5C=&-L87-S)UT@87,@)&]B:F5C
M=&-L87-S*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;'1E<B`N/2`G*&]B
M:F5C=&-L87-S/2<@+B`D;V)J96-T8VQA<W,@+B`G*2<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D9FEL=&5R("X]("<I)SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&9I;'1E<CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T(&]F(')E<75I<F5D
M(&%T=')I8G5T97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1O8FIE8W1C;&%S<V5S("!,:7-T
M(&]F(&]B:F5C=&-L87-S97,@=&AA="!S:&]U;&0@8F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8VAE8VME9"!F;W(@<F5Q=6ER960@
M871T<FEB=71E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!,:7-T
M(&]F(&%T=')I8G5T92!N86UE<R!O9B!T:&4@<W!E8VEF:65D(&]B:F5C=&-L
M87-S97,*("`@("`J("`@("`@("`@("`@("`@('1H870@:&%V92!B965N(&-O
M;F9I9W5R960@87,@8F5I;F<@<F5Q=6ER960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]C:&5C:U)E<75I<F5D071T<FEB=71E<R@D;V)J96-T8VQA<W-E<RD*
M("`@('L*("`@("`@("1S8VAE;6$@/2`F)'1H:7,M/E]G97138VAE;6$H*3L*
M("`@("`@(&EF("AI<U]A*"1S8VAE;6$L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("!R971U<FX@)'-C:&5M83L*("`@("`@('T*"B`@("`@("`D<F5T
M=F%L(#T@87)R87DH*3L*"B`@("`@("!F;W)E86-H("@D;V)J96-T8VQA<W-E
M<R!A<R`D;V,I('L*("`@("`@("`@("!I9B`H4W1R:6YG.CIL;W=E<B@D;V,I
M(#T]("=T;W`G*2!["B`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@('T*"B`@("`@("`@("`@)')E<75I<F5D(#T@)'-C:&5M82T^;75S="@D
M;V,I.PH*("`@("`@("`@("!I9B`H:7-?87)R87DH)')E<75I<F5D*2D@>PH@
M("`@("`@("`@("`@("!F;W)E86-H("@D<F5Q=6ER960@87,@)'8I('L*("`@
M("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VES4W1R:6YG*"1V*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("1R971V86Q;72`](%-T<FEN9SHZ;&]W
M97(H)'8I.PH@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@?0H@("`@("`@?0H*("`@("`@(')E='5R;B`D<F5T=F%L
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF(&%N(&%T=')I8G5T
M92!R969E<G,@=&\@82!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D871T<FEB=71E
M("!!;B!A='1R:6)U=&4@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=&AE('-P96-I9FEE9"!A='1R:6)U=&4@<F5F97)S
M('1O(&$@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:7-3=')I;F<H
M)&%T=')I8G5T92D*("`@('L*("`@("`@("`D<WEN=&%X(#T@)'1H:7,M/E]G
M9713>6YT87@H)&%T=')I8G5T92D["@H@("`@("`@("\J(%-Y;G1A>&5S('=E
M('=A;G0@=&\@86QL;W<L(&DN92X@;F\@:6YT96=E<G,N"B`@("`@("`@("H@
M4WEN=&%X97,@:&%V92!T:&4@9F]R;3H*("`@("`@("`@*B`Q+C,N-BXQ+C0N
M,2XQ-#8V+C$Q-2XQ,C$N,2XD;GLD>7T*("`@("`@("`@*B`N+BX@=VAE<F4@
M)&X@:7,@=&AE(&EN=&5G97(@=7-E9"!B96QO=R!A;F0@)'D@:7,@82!S:7IE
M;&EM:70N("HO"B`@("`@("`@)&]K4WEN=&%X(#T@87)R87DH-#0@/3X@,2P@
M+RH@4')I;G1A8FQE('-T<FEN9RX@*B\*("`@("`@("`@("`@("`@("`@("`@
M("`@("`T,2`]/B`Q+"`O*B!0;W-T86P@861D<F5S<RX@*B\*("`@("`@("`@
M("`@("`@("`@("`@("`@("`S.2`]/B`Q+"`O*B!/=&AE<B!M86EL8F]X+B`J
M+PH@("`@("`@("`@("`@("`@("`@("`@("`@(#,T(#T^(#$L("\J($YA;64@
M86YD(&]P=&EO;F%L(%5)1"X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@
M("`R-B`]/B`Q+"`O*B!)034@<W1R:6YG+B`J+PH@("`@("`@("`@("`@("`@
M("`@("`@("`@(#$U(#T^(#$L("\J($1I<F5C=&]R>2!S=')I;F<N("HO"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R]>*"XJ*5PN*%QD*RE<>UQD*UQ])"\G+"`D<WEN=&%X+"`D;6%T
M8VAE<RD@)B8*("`@("`@("`@("`@)&UA=&-H97-;,5T@/3T@(C$N,RXV+C$N
M-"XQ+C$T-C8N,3$U+C$R,2XQ(B`F)@H@("`@("`@("`@("!I<W-E="@D;VM3
M>6YT87A;)&UA=&-H97-;,EU=*2D@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VAE8VMS(&EF(&%N(&%T=')I8G5T92!R969E<G,@=&\@
M82!0;W-T86P@061D<F5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U=&4@($%N
M(&%T=')I8G5T92!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!T:&4@<W!E8VEF:65D(&%T=')I8G5T92!R969E<G,@=&\@
M82!0;W-T86P@061D<F5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7VES4&]S
M=&%L061D<F5S<R@D871T<FEB=71E*0H@("`@>PH@("`@("`@("1S>6YT87@@
M/2`D=&AI<RT^7V=E=%-Y;G1A>"@D871T<FEB=71E*3L*"B`@("`@("`@+RHJ
M($Q$05`@<&]S=&%L(&%D9')E<W,@<WEN=&%X"B`@("`@("`@("H@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N-#$@*B\*("`@("`@("!I9B`H)'-Y;G1A
M>"`]/2`B,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N-#$B*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S>6YT
M87@@;V8@86X@871T<FEB=71E+"!I9B!N96-E<W-A<GD@<F5C=7)S:79E;'DN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D871T("!!='1R:6)U=&4@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@071T<FEB=71E('-Y;G1A>"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=%-Y;G1A>"@D871T*0H@("`@>PH@("`@("`@
M("1S8VAE;6$@/2`F)'1H:7,M/E]G97138VAE;6$H*3L*("`@("`@("!I9B`H
M:7-?82@D<V-H96UA+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<V-H96UA.PH@("`@("`@('T*("`@("`@("`D871T=B`]("1S8VAE
M;6$M/F=E="@G871T<FEB=71E)RP@)&%T="D["@H@("`@("`@(&EF("AI<W-E
M="@D871T=ELG<WEN=&%X)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D871T
M=ELG<WEN=&%X)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9V5T4WEN=&%X*"1A='1V6R=S=7`G75LP72D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!,1$%07U-C
M:&5M82!O8FIE8W0@=&AA="!C;VYT86EN=',@=&AE($Q$05`@<V-H96UA+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R
M971U<FX@3F5T7TQ$05!?4V-H96UA("!2971U<FYS(&$@<F5F97)E;F-E('1O
M('1H92!L9&%P('-C:&5M82!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9?9V5T4V-H96UA*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TYE
M="],1$%0+G!H<"<["@H@("`@("`@('-T871I8R`D7W-C:&5M83L*"B`@("`@
M("`@+RH@0VAE8VL@:68@=&AE(&-A8VAE9"!S8VAE;6$@:7,@=F%L:60L("HO
M"B`@("`@("`@:68@*&ES7V]B:F5C="@D7W-C:&5M82D@)B8@:7-?82@D7W-C
M:&5M82P@)TYE=%],1$%07U-C:&5M82<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D7W-C:&5M83L*("`@("`@("!]"@H@("`@("`@("1C;VYF:6<@/2!A<G)A
M>2@G:&]S="<@/3X@)'1H:7,M/E]P87)A;7-;)W-E<G9E<B==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G<&]R="<@/3X@)'1H:7,M/E]P87)A;7-;)W!O
M<G0G72D["B`@("`@("`@)&QD87`@/2`F;F5W($YE=%],1$%0*"1C;VYF:6<I
M.PH@("`@("`@("1L9&%P+3Y?;&EN:R`]("1T:&ES+3Y?9',["@H@("`@("`@
M("1?<V-H96UA(#T@)B1L9&%P+3YS8VAE;6$H*3L*"B`@("`@("`@<F5T=7)N
M("1?<V-H96UA.PH@("`@?0H*("`@("\J*@H@("`@("H@5&%K92!A;B!A<G)A
M>2!O9B!$3B!E;&5M96YT<R!A;F0@<')O<&5R;'D@<75O=&4@:70@86-C;W)D
M:6YG('1O"B`@("`@*B!21D,@,30X-2X*("`@("`J"B`@("`@*B!`<V5E($AO
M<F1E7TQ$05`Z.G%U;W1E1$XH*0H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R=',@($%N(&%R<F%Y(&]F('1U<&QE<R!C;VYT86EN:6YG('1H92!A
M='1R:6)U=&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&YA;64@86YD
M('1H870@871T<FEB=71E)W,@=F%L=64@=VAI8V@@;6%K90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@=7`@=&AE($1.+B!%>&%M<&QE.@H@("`@("H*
M("`@("`J("`@("1P87)T<R`](&%R<F%Y*#`@/3X@87)R87DH)V-N)RP@)TIO
M:&X@4VUI=&@G*2P*("`@("`J("`@("`@("`@("`@("`@("`@(#$@/3X@87)R
M87DH)V1C)RP@)V5X86UP;&4G*2P*("`@("`J("`@("`@("`@("`@("`@("`@
M(#(@/3X@87)R87DH)V1C)RP@)V-O;2<I*3L*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('!R;W!E<FQY('%U;W1E9"!S=')I;F<@1$XN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]Q=6]T941.*"1P87)T<RD*("`@('L*("`@
M("`@("`D9&X@/2`G)SL*("`@("`@("`D8V]U;G0@/2!C;W5N="@D<&%R=',I
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@
M("`@("`@("`@("!I9B`H)&D@/B`P*2!["B`@("`@("`@("`@("`@("`D9&X@
M+CT@)RPG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D;B`N/2`D<&%R
M='-;)&E=6S!=("X@)STG.PH*("`@("`@("`@("`@+RH@4V5E(&EF('=E(&YE
M960@=&\@<75O=&4@=&AE('9A;'5E+B`J+PH@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UY<<WQ<<R1\7'-<<WQ;+"L](EQR7&X\/B,[72\G+"`D<&%R
M='-;)&E=6S%=*2D@>PH@("`@("`@("`@("`@("`@)&1N("X]("<B)R`N('-T
M<E]R97!L86-E*"<B)RP@)UQ<(B<L("1P87)T<ULD:5U;,5TI("X@)R(G.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1N("X]("1P
M87)T<ULD:5U;,5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D9&X["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B
M82]L:6(O1')I=F5R+W!R969S+G!H<```````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`U-S0R`#$P-#$W,S8R-S4V`#`R,30P,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5'5R8F$@9&ER96-T;W)Y(&1R:79E<B!I;7!L96UE;G1A=&EO;B!F;W(@2&]R
M9&4@4')E9F5R96YC97,@+2!V97)Y('-I;7!L92P*("H@;&EG:'1W96EG:'0@
M8V]N=&%I;F5R+@H@*@H@*B`D2&]R9&4Z('1U<F)A+VQI8B]$<FEV97(O<')E
M9G,N<&AP+'8@,2XQ,"XQ,"XU(#(P,#4O,3$O,3`@,3(Z-#0Z,S`@;61J=6MI
M8R!%>'`@)`H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@5'5R8F$@,2XR"B`J($!P86-K86=E
M(%1U<F)A"B`J+PIC;&%S<R!4=7)B85]$<FEV97)?<')E9G,@97AT96YD<R!4
M=7)B85]$<FEV97(@>PH*("`@("\J*@H@("`@("H*("`@("`J+PH@("`@9G5N
M8W1I;VX@7VEN:70H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@96YT<FEE<R`M('-E87)C
M:&EN9R!I<VXG="!I;7!L96UE;G1E9"!H97)E(&9O<B!N;W<N(%1H90H@("`@
M("H@<&%R86UE=&5R<R!A<F4@<VEM<&QY(&EG;F]R960N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1C<FET97)I82`@07)R87D@8V]N=&%I;FEN9R!T
M:&4@<V5A<F-H(&-R:71E<FEA+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:65L
M9',@("`@3&ES="!O9B!F:65L9',@=&\@<F5T=7)N+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($AA<V@@8V]N=&%I;FEN9R!T:&4@<V5A<F-H(')E
M<W5L=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96%R8V@H)&-R:71E<FEA
M+"`D9FEE;&1S*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>5]V86QU97,H
M)'1H:7,M/E]G971!9&1R97-S0F]O:R@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E861S('1H92!G:79E;B!D871A(&9R;VT@=&AE('!R969E<F5N8V5S
M(&%N9"!R971U<FYS('1H92!R97-U;'0G<PH@("`@("H@9FEE;&1S+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D8W)I=&5R:6$@(%-E87)C:"!C<FET
M97)I82X*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("`@($1A=&$@:61E
M;G1I9FEE<BX*("`@("`J($!P87)A;2!A<G)A>2`D9FEE;&1S("`@($QI<W0@
M;V8@9FEE;&1S('1O(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N("!(
M87-H(&-O;G1A:6YI;F<@=&AE('-E87)C:"!R97-U;'1S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<F5A9"@D8W)I=&5R:6$L("1I9',L("1F:65L9',I"B`@
M("!["B`@("`@("`@)&)O;VL@/2`D=&AI<RT^7V=E=$%D9')E<W-";V]K*"D[
M"B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-?
M87)R87DH)&ED<RDI('L*("`@("`@("`@("`@)&ED<R`](&%R<F%Y*"1I9',I
M.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D:61S(&%S("1I9"D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)&)O;VM;)&ED72DI('L*("`@("`@("`@
M("`@("`@("1R97-U;'1S6UT@/2`D8F]O:ULD:61=.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=',["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&1S('1H92!S<&5C:69I960@;V)J96-T('1O('1H
M92!P<F5F97)E;F-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9"@D871T
M<FEB=71E<RD*("`@('L*("`@("`@("`D8F]O:R`]("1T:&ES+3Y?9V5T061D
M<F5S<T)O;VLH*3L*("`@("`@("`D8F]O:ULD871T<FEB=71E<ULG:60G75T@
M/2`D871T<FEB=71E<SL*("`@("`@("`D=&AI<RT^7W-E=$%D9')E<W-B;V]K
M*"1B;V]K*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96QE=&5S('1H92!S<&5C:69I960@;V)J96-T(&9R;VT@=&AE
M('!R969E<F5N8V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5L971E*"1O
M8FIE8W1?:V5Y+"`D;V)J96-T7VED*0H@("`@>PH@("`@("`@("1B;V]K(#T@
M)'1H:7,M/E]G971!9&1R97-S0F]O:R@I.PH@("`@("`@('5N<V5T*"1B;V]K
M6R1O8FIE8W1?:61=*3L*("`@("`@("`D=&AI<RT^7W-E=$%D9')E<W-B;V]K
M*"1B;V]K*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3879E<R!T:&4@<W!E8VEF:65D(&]B:F5C="!I;B!T:&4@<')E
M9F5R96YC97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S879E*"1O8FIE8W1?
M:V5Y+"`D;V)J96-T7VED+"`D871T<FEB=71E<RD*("`@('L*("`@("`@("`D
M8F]O:R`]("1T:&ES+3Y?9V5T061D<F5S<T)O;VLH*3L*("`@("`@("`D8F]O
M:ULD;V)J96-T7VED72`]("1A='1R:6)U=&5S.PH@("`@("`@("1T:&ES+3Y?
M<V5T061D<F5S<T)O;VLH)&)O;VLI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G
M971!9&1R97-S0F]O:R@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*
M"B`@("`@("`@)'9A;"`]("1P<F5F<RT^9V5T5F%L=64H)W!R969B;V]K<R<I
M.PH@("`@("`@(&EF("@A96UP='DH)'9A;"DI('L*("`@("`@("`@("`@)'!R
M969B;V]K<R`]('5N<V5R:6%L:7IE*"1V86PI.PH@("`@("`@("`@("!R971U
M<FX@)'!R969B;V]K<ULD=&AI<RT^7W!A<F%M<ULG;F%M92==73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W-E=$%D9')E<W-";V]K*"1A9&1R
M97-S8F]O:RD*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@
M("`D=F%L(#T@)'!R969S+3YG971686QU92@G<')E9F)O;VMS)RD["B`@("`@
M("`@:68@*"%E;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`D<')E9F)O;VMS
M(#T@=6YS97)I86QI>F4H)'9A;"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'!R969B;V]K<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@
M("`D<')E9F)O;VMS6R1T:&ES+3Y?<&%R86US6R=N86UE)UU=(#T@)&%D9')E
M<W-B;V]K.PH@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)W!R969B;V]K<R<L
M('-E<FEA;&EZ92@D<')E9F)O;VMS*2D["B`@("`@("`@)'!R969S+3YS=&]R
M92@I.PH@("`@?0H*?0H````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQI8B]$<FEV97(O:V]L
M86(N<&AP````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`W,3,`
M,3`T,3<S-C(W-38`,#(Q,S0W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TMO
M;&%B+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1&%T82YP:'`G.PH*+RHJ
M"B`J($AO<F1E(%1U<F)A(&1R:79E<B!F;W(@=&AE($MO;&%B($E-05`@4V5R
M=F5R+@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($AO<F1E(%!R;VIE8W0@*&AT
M='`Z+R]H;W)D92YO<F<O*0H@*@H@*B`D2&]R9&4Z('1U<F)A+VQI8B]$<FEV
M97(O:V]L86(N<&AP+'8@,2XU+C$P+C@@,C`P-B\P,2\P,2`R,3HR.3HQ-B!J
M86X@17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N
M;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J"B`J($!A=71H;W(@(%-T=6%R="!"
M:6YG92`\;VUI8W)O;D!M:6=H='DN8V\N>F$^"B`J($!P86-K86=E(%1U<F)A
M"B`J+PIC;&%S<R!4=7)B85]$<FEV97)?:V]L86(@97AT96YD<R!4=7)B85]$
M<FEV97(@>PH*("`@("\J*@H@("`@("H@3W5R($MO;&%B('-E<G9E<B!C;VYN
M96-T:6]N+@H@("`@("H*("`@("`J($!V87(@2V]L86(*("`@("`J+PH@("`@
M=F%R("1?:V]L86(@/2!N=6QL.PH*("`@(&9U;F-T:6]N(%]I;FET*"D*("`@
M('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]K;VQA8BDI('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7VMO;&%B(#T@;F5W($MO;&%B*"D["@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7VMO;&%B+3YO<&5N*"1T:&ES+3Y?<&%R86US6R=S:&%R92==*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]K;VQA8BT^8VQO<V4H*3L*("`@("`@("`D=&AI<RT^7VMO;&%B(#T@
M;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B!?8G5I;&1#;VYT86-T*"D*("`@
M('L*("`@("`@("`D:R`]("8D=&AI<RT^7VMO;&%B.PH*("`@("`@("`D8V]N
M=&%C="`](&%R<F%Y*`H@("`@("`@("`@("`G=6ED)R`]/B`D:RT^9V5T54E$
M*"DL"B`@("`@("`@("`@("=O=VYE<B<@/3X@075T:#HZ9V5T075T:"@I+`H@
M("`@("`@("`@("`G:F]B+71I=&QE)R`]/B`D:RT^9V5T4W1R*"=J;V(M=&ET
M;&4G*2P*("`@("`@("`@("`@)V]R9V%N:7IA=&EO;B<@/3X@)&LM/F=E=%-T
M<B@G;W)G86YI>F%T:6]N)RDL"B`@("`@("`@("`@("=B;V1Y)R`]/B`D:RT^
M9V5T4W1R*"=B;V1Y)RDL"B`@("`@("`@("`@("=W96(M<&%G92<@/3X@)&LM
M/F=E=%-T<B@G=V5B+7!A9V4G*2P*("`@("`@("`@("`@)VYI8VLM;F%M92<@
M/3X@)&LM/F=E=%-T<B@G;FEC:RUN86UE)RDL"B`@("`@("`@*3L*"B`@("`@
M("`@)&YA;64@/2`F)&LM/F=E=%)O;W1%;&5M*"=N86UE)RD["B`@("`@("`@
M)&-O;G1A8W1;)V9U;&PM;F%M92==(#T@)&LM/F=E=$5L96U3='(H)&YA;64L
M("=F=6QL+6YA;64G*3L*("`@("`@("`D8V]N=&%C=%LG9VEV96XM;F%M92==
M(#T@)&LM/F=E=$5L96U3='(H)&YA;64L("=G:79E;BUN86UE)RD["B`@("`@
M("`@)&-O;G1A8W1;)VQA<W0M;F%M92==(#T@)&LM/F=E=$5L96U3='(H)&YA
M;64L("=L87-T+6YA;64G*3L*"B`@("`@("`@)&5M86EL(#T@)B1K+3YG9712
M;V]T16QE;2@G96UA:6PG*3L*("`@("`@("`D8V]N=&%C=%LG<VUT<"UA9&1R
M97-S)UT@/2`D:RT^9V5T16QE;5-T<B@D96UA:6PL("=S;71P+6%D9')E<W,G
M*3L*"B`@("`@("`@)'!H;VYE<R`]("8D:RT^9V5T06QL4F]O=$5L96US*"=P
M:&]N92<I.PH@("`@("`@(&9O<B`H)&D@/2`P+"`D:B`](&-O=6YT*"1P:&]N
M97,I.R`D:2`\("1J.R`D:2LK*2!["B`@("`@("`@("`@("1P:&]N92`]("8D
M<&AO;F5S6R1I73L*("`@("`@("`@("`@)'1Y<&4@/2`D:RT^9V5T16QE;5-T
M<B@D<&AO;F4L("=T>7!E)RD["@H@("`@("`@("`@("!S=VET8V@@*"1T>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@)VAO;64Q)SH*("`@("`@("`@("`@("`@
M("1C;VYT86-T6R=H;VUE,2==(#T@)&LM/F=E=$5L96U3='(H)'!H;VYE+"`G
M;G5M8F5R)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)V)U<VEN97-S,2<Z"B`@("`@("`@("`@("`@("`D8V]N=&%C=%LG
M8G5S:6YE<W,Q)UT@/2`D:RT^9V5T16QE;5-T<B@D<&AO;F4L("=N=6UB97(G
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M;6]B:6QE)SH*("`@("`@("`@("`@("`@("1C;VYT86-T6R=M;V)I;&4G72`]
M("1K+3YG971%;&5M4W1R*"1P:&]N92P@)VYU;6)E<B<I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=B=7-I;F5S<V9A>"<Z
M"B`@("`@("`@("`@("`@("`D8V]N=&%C=%LG8G5S:6YE<W-F87@G72`]("1K
M+3YG971%;&5M4W1R*"1P:&]N92P@)VYU;6)E<B<I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1A
M9&1R97-S97,@/2`F)&LM/F=E=$%L;%)O;W1%;&5M<R@G861D<F5S<R<I.PH@
M("`@("`@(&9O<B`H)&D@/2`P+"`D:B`](&-O=6YT*"1A9&1R97-S97,I.R`D
M:2`\("1J.R`D:2LK*2!["B`@("`@("`@("`@("1A9&1R97-S(#T@)B1A9&1R
M97-S97-;)&E=.PH@("`@("`@("`@("`D='EP92`]("1K+3YG971%;&5M4W1R
M*"1A9&1R97-S+"`G='EP92<I.PH*("`@("`@("`@("`@<W=I=&-H("@D='EP
M92D@>PH@("`@("`@("`@("!C87-E("=H;VUE)SH*("`@("`@("`@("`@("`@
M("1C;VYT86-T6R=H;VUE+7-T<F5E="==(#T@)&LM/F=E=$5L96U3='(H)&%D
M9')E<W,L("=S=')E970G*3L*("`@("`@("`@("`@("`@("1C;VYT86-T6R=H
M;VUE+6QO8V%L:71Y)UT@/2`D:RT^9V5T16QE;5-T<B@D861D<F5S<RP@)VQO
M8V%L:71Y)RD["B`@("`@("`@("`@("`@("`D8V]N=&%C=%LG:&]M92UR96=I
M;VXG72`]("1K+3YG971%;&5M4W1R*"1A9&1R97-S+"`G<F5G:6]N)RD["B`@
M("`@("`@("`@("`@("`D8V]N=&%C=%LG:&]M92UP;W-T86PM8V]D92==(#T@
M)&LM/F=E=$5L96U3='(H)&%D9')E<W,L("=P;W-T86PM8V]D92<I.PH@("`@
M("`@("`@("`@("`@)&-O;G1A8W1;)VAO;64M8V]U;G1R>2==(#T@)&LM/F=E
M=$5L96U3='(H)&%D9')E<W,L("=C;W5N=')Y)RD["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V)U<VEN97-S)SH*("`@("`@
M("`@("`@("`@("1C;VYT86-T6R=B=7-I;F5S<RUS=')E970G72`]("1K+3YG
M971%;&5M4W1R*"1A9&1R97-S+"`G<W1R965T)RD["B`@("`@("`@("`@("`@
M("`D8V]N=&%C=%LG8G5S:6YE<W,M;&]C86QI='DG72`]("1K+3YG971%;&5M
M4W1R*"1A9&1R97-S+"`G;&]C86QI='DG*3L*("`@("`@("`@("`@("`@("1C
M;VYT86-T6R=B=7-I;F5S<RUR96=I;VXG72`]("1K+3YG971%;&5M4W1R*"1A
M9&1R97-S+"`G<F5G:6]N)RD["B`@("`@("`@("`@("`@("`D8V]N=&%C=%LG
M8G5S:6YE<W,M<&]S=&%L+6-O9&4G72`]("1K+3YG971%;&5M4W1R*"1A9&1R
M97-S+"`G<&]S=&%L+6-O9&4G*3L*("`@("`@("`@("`@("`@("1C;VYT86-T
M6R=B=7-I;F5S<RUC;W5N=')Y)UT@/2`D:RT^9V5T16QE;5-T<B@D861D<F5S
M<RP@)V-O=6YT<GDG*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;G1A8W0["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W-E=%!H;VYE*"1T>7!E+"`F)'!H;VYE+"`D
M871T<FEB=71E<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&%T=')I8G5T
M97-;)'1Y<&5=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VMO;&%B+3YD96Q2
M;V]T16QE;2@D<&AO;F4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&EF("@D<&AO;F4@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<&AO
M;F4@/2`F)'1H:7,M/E]K;VQA8BT^87!P96YD4F]O=$5L96TH)W!H;VYE)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VMO;&%B+3YS971%;&5M4W1R*"1P
M:&]N92P@)W1Y<&4G+"`D='EP92D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]K;VQA8BT^<V5T16QE;5-T<B@D<&AO;F4L("=N=6UB97(G
M+"`D871T<FEB=71E<ULD='EP95TI.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!?<V5T061D<F5S<R@D='EP92P@)B1A9&1R97-S+"`D871T<FEB
M=71E<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&%T=')I8G5T97-;(B1T
M>7!E+7-T<F5E=")=*2`F)B!E;7!T>2@D871T<FEB=71E<ULB)'1Y<&4M;&]C
M86QI='DB72D@)B8*("`@("`@("`@("`@96UP='DH)&%T=')I8G5T97-;(B1T
M>7!E+7)E9VEO;B)=*2`F)B!E;7!T>2@D871T<FEB=71E<ULB)'1Y<&4M<&]S
M=&%L+6-O9&4B72D@)B8*("`@("`@("`@("`@96UP='DH)&%T=')I8G5T97-;
M(B1T>7!E+6-O=6YT<GDB72DI('L*("`@("`@("`@("`@)'1H:7,M/E]K;VQA
M8BT^9&5L4F]O=$5L96TH)&%D9')E<W,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D861D<F5S<R`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("1A9&1R97-S(#T@)B1T:&ES+3Y?:V]L86(M/F%P<&5N9%)O;W1%
M;&5M*"=A9&1R97-S)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7VMO;&%B
M+3YS971%;&5M4W1R*"1A9&1R97-S+"`G='EP92<L("1T>7!E*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VMO;&%B+3YS971%;&5M4W1R
M*"1A9&1R97-S+"`G<W1R965T)RP@)&%T=')I8G5T97-;(B1T>7!E+7-T<F5E
M=")=*3L*("`@("`@("`@("`@)'1H:7,M/E]K;VQA8BT^<V5T16QE;5-T<B@D
M861D<F5S<RP@)VQO8V%L:71Y)RP@)&%T=')I8G5T97-;(B1T>7!E+6QO8V%L
M:71Y(ETI.PH@("`@("`@("`@("`D=&AI<RT^7VMO;&%B+3YS971%;&5M4W1R
M*"1A9&1R97-S+"`G<F5G:6]N)RP@)&%T=')I8G5T97-;(B1T>7!E+7)E9VEO
M;B)=*3L*("`@("`@("`@("`@)'1H:7,M/E]K;VQA8BT^<V5T16QE;5-T<B@D
M861D<F5S<RP@)W!O<W1A;"UC;V1E)RP@)&%T=')I8G5T97-;(B1T>7!E+7!O
M<W1A;"UC;V1E(ETI.PH@("`@("`@("`@("`D=&AI<RT^7VMO;&%B+3YS971%
M;&5M4W1R*"1A9&1R97-S+"`G8V]U;G1R>2<L("1A='1R:6)U=&5S6R(D='EP
M92UC;W5N=')Y(ETI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?
M8W)E871E0V]N=&%C="@F)'AM;"P@)&%T=')I8G5T97,I"B`@("!["B`@("`@
M("`@)&L@/2`F)'1H:7,M/E]K;VQA8CL*"B`@("`@("`@)&YA;64@/2`F)&LM
M/FEN:712;V]T16QE;2@G;F%M92<I.PH@("`@("`@("1K+3YS971%;&5M4W1R
M*"1N86UE+"`G9G5L;"UN86UE)RP@)&%T=')I8G5T97-;)V9U;&PM;F%M92==
M*3L*("`@("`@("`D:RT^<V5T16QE;5-T<B@D;F%M92P@)V=I=F5N+6YA;64G
M+"`D871T<FEB=71E<ULG9VEV96XM;F%M92==*3L*("`@("`@("`D:RT^<V5T
M16QE;5-T<B@D;F%M92P@)VQA<W0M;F%M92<L("1A='1R:6)U=&5S6R=L87-T
M+6YA;64G72D["@H@("`@("`@("1E;6%I;"`]("8D:RT^:6YI=%)O;W1%;&5M
M*"=E;6%I;"<I.PH@("`@("`@("1K+3YS971%;&5M4W1R*"1E;6%I;"P@)V1I
M<W!L87DM;F%M92<L("1A='1R:6)U=&5S6R=F=6QL+6YA;64G72D["B`@("`@
M("`@)&LM/G-E=$5L96U3='(H)&5M86EL+"`G<VUT<"UA9&1R97-S)RP@)&%T
M=')I8G5T97-;)W-M='`M861D<F5S<R==*3L*"B`@("`@("`@)&LM/G-E=%-T
M<B@G:F]B+71I=&QE)RP@)&%T=')I8G5T97-;)VIO8BUT:71L92==*3L*("`@
M("`@("`D:RT^<V5T4W1R*"=O<F=A;FEZ871I;VXG+"`D871T<FEB=71E<ULG
M;W)G86YI>F%T:6]N)UTI.PH@("`@("`@("1K+3YS9713='(H)V)O9'DG+"`D
M871T<FEB=71E<ULG8F]D>2==*3L*("`@("`@("`D:RT^<V5T4W1R*"=W96(M
M<&%G92<L("1A='1R:6)U=&5S6R=W96(M<&%G92==*3L*("`@("`@("`D:RT^
M<V5T4W1R*"=N:6-K+6YA;64G+"`D871T<FEB=71E<ULG;FEC:RUN86UE)UTI
M.PH*("`@("`@("`O+R!0:&]N97,*("`@("`@("`D<&AO;F5S(#T@)B1K+3YG
M971!;&Q2;V]T16QE;7,H)W!H;VYE)RD["B`@("`@("`@)&AO;64@/2!F86QS
M93L*("`@("`@("`D8G5S(#T@9F%L<V4["B`@("`@("`@)&UO8B`](&9A;'-E
M.PH@("`@("`@("1F87@@/2!F86QS93L*("`@("`@("!F;W(@*"1I(#T@,"P@
M)&H@/2!C;W5N="@D<&AO;F5S*3L@)&D@/"`D:CL@)&DK*RD@>PH@("`@("`@
M("`@("`D<&AO;F4@/2`F)'!H;VYE<ULD:5T["B`@("`@("`@("`@("1T>7!E
M(#T@)&LM/F=E=$5L96U3='(H)'!H;VYE+"`G='EP92<I.PH*("`@("`@("`@
M("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C87-E("=H;VUE,2<Z
M"B`@("`@("`@("`@("`@("`D:&]M92`]("8D<&AO;F4["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V)U<VEN97-S,2<Z"B`@
M("`@("`@("`@("`@("`D8G5S(#T@)B1P:&]N93L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;6]B:6QE)SH*("`@("`@("`@
M("`@("`@("1M;V(@/2`F)'!H;VYE.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=B=7-I;F5S<V9A>"<Z"B`@("`@("`@("`@
M("`@("`D9F%X(#T@)B1P:&]N93L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E=%!H
M;VYE*"=H;VUE,2<L("1H;VUE+"`D871T<FEB=71E<RD["B`@("`@("`@)'1H
M:7,M/E]S9710:&]N92@G8G5S:6YE<W,Q)RP@)&)U<RP@)&%T=')I8G5T97,I
M.PH@("`@("`@("1T:&ES+3Y?<V5T4&AO;F4H)VUO8FEL92<L("1M;V(L("1A
M='1R:6)U=&5S*3L*("`@("`@("`D=&AI<RT^7W-E=%!H;VYE*"=B=7-I;F5S
M<V9A>"<L("1F87@L("1A='1R:6)U=&5S*3L*"B`@("`@("`@+R\@061D<F5S
M<V5S"B`@("`@("`@)&AO;64@/2!F86QS93L*("`@("`@("`D8G5S(#T@9F%L
M<V4["B`@("`@("`@)&%D9')E<W-E<R`]("8D:RT^9V5T06QL4F]O=$5L96US
M*"=A9&1R97-S)RD["B`@("`@("`@9F]R("@D:2`](#`L("1J(#T@8V]U;G0H
M)&%D9')E<W-E<RD[("1I(#P@)&H[("1I*RLI('L*("`@("`@("`@("`@)&%D
M9')E<W,@/2`F)&%D9')E<W-E<ULD:5T["B`@("`@("`@("`@("1T>7!E(#T@
M)&LM/F=E=$5L96U3='(H)&%D9')E<W,L("=T>7!E)RD["@H@("`@("`@("`@
M("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)VAO;64G.@H@
M("`@("`@("`@("`@("`@)&AO;64@/2`F)&%D9')E<W,["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V)U<VEN97-S)SH*("`@
M("`@("`@("`@("`@("1B=7,@/2`F)&%D9')E<W,["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]S971!9&1R97-S*"=H;VUE)RP@)&AO;64L("1A='1R:6)U=&5S*3L*
M("`@("`@("`D=&AI<RT^7W-E=$%D9')E<W,H)V)U<VEN97-S)RP@)&)U<RP@
M)&%T=')I8G5T97,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5A<F-H97,@
M=&AE($MO;&%B(&UE<W-A9V4@<W1O<F4@=VET:"!T:&4@9VEV96X@8W)I=&5R
M:6$@86YD(')E='5R;G,@80H@("`@("H@9FEL=&5R960@;&ES="!O9B!R97-U
M;'1S+B!)9B!T:&4@8W)I=&5R:6$@<&%R86UE=&5R(&ES(&%N(&5M<'1Y"B`@
M("`@*B!A<G)A>2P@86QL(')E8V]R9',@=VEL;"!B92!R971U<FYE9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@)&-R:71E<FEA("`@("`@07)R87D@8V]N=&%I
M;FEN9R!T:&4@<V5A<F-H(&-R:71E<FEA+@H@("`@("H@0'!A<F%M("1F:65L
M9',@("`@("`@($QI<W0@;V8@9FEE;&1S('1O(')E='5R;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N("`@("`@("`@("`@("`@2&%S:"!C;VYT86EN:6YG('1H
M92!S96%R8V@@<F5S=6QT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E87)C
M:"@D8W)I=&5R:6$L("1F:65L9',I"B`@("!["B`@("`@("`@)'%U97)Y(#T@
M)'1H:7,M/E]B=6EL9$E-05!396%R8V@H)&-R:71E<FEA*3L*"B`@("`@("`@
M)')E<W5L=',@/2!A<G)A>2@I.PH*("`@("`@("`D;7-G7VQI<W0@/2`D=&AI
M<RT^7VMO;&%B+3YF:6YD3V)J96-T<R@D<75E<GDI.PH@("`@("`@(&EF("AI
M<U]A*"1M<V=?;&ES="P@)U!%05)?17)R;W(G*2!\?"!E;7!T>2@D;7-G7VQI
M<W0I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1M<V=?;&ES="!A<R`D;7-G*2!["B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VMO;&%B+3YL;V%D3V)J96-T*"1M
M<V<L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-O;G1A8W0@/2`D=&AI<RT^
M7V)U:6QD0V]N=&%C="@I.PH*("`@("`@("`@("`@)&-A<F0@/2!A<G)A>2@I
M.PH@("`@("`@("`@("!F;W)E86-H("@D9FEE;&1S(&%S("1F:65L9"D@>PH@
M("`@("`@("`@("`@("`@)&-A<F1;)&9I96QD72`]("AI<W-E="@D8V]N=&%C
M=%LD9FEE;&1=*2`_("1C;VYT86-T6R1F:65L9%T@.B`G)RD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1R97-U;'1S6UT@/2`D8V%R9#L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E860@=&AE(&=I=F5N(&1A=&$@9G)O;2!T:&4@2V]L86(@;65S
M<V%G92!S=&]R92!A;F0@<F5T=7)N<R!T:&4*("`@("`J(')E<W5L="=S(&9I
M96QD<RX*("`@("`J"B`@("`@*B!`<&%R86T@)&-R:71E<FEA("`@("`@4V5A
M<F-H(&-R:71E<FEA+@H@("`@("H@0'!A<F%M("1I9"`@("`@("`@("`@($1A
M=&$@:61E;G1I9FEE<BX*("`@("`J($!P87)A;2`D9FEE;&1S("`@("`@("!,
M:7-T(&]F(&9I96QD<R!T;R!R971U<FXN"B`@("`@*@H@("`@("H@0')E='5R
M;B`@("`@("`@("`@("`@($AA<V@@8V]N=&%I;FEN9R!T:&4@<V5A<F-H(')E
M<W5L=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96%D*"1C<FET97)I82P@
M)&ED7VQI<W0L("1F:65L9',I"B`@("!["B`@("`@("`@)')E<W5L=',@/2!A
M<G)A>2@I.PH*("`@("`@("!I9B`H)&-R:71E<FEA("$]("=U:60G*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-?87)R87DH)&ED7VQI<W0I*2!["B`@("`@("`@("`@("1I9%]L
M:7-T(#T@87)R87DH)&ED7VQI<W0I.PH@("`@("`@('T*"B`@("`@("`@9F]R
M96%C:"`H)&ED7VQI<W0@87,@)&ED*2!["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7VMO;&%B+3YL;V%D3V)J96-T*"1I9"D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D8V]N=&%C="`]("1T:&ES+3Y?8G5I;&1#;VYT86-T*"1R97-U;'0I
M.PH*("`@("`@("`@("`@)&-A<F0@/2!A<G)A>2@I.PH@("`@("`@("`@("!F
M;W)E86-H("@D9FEE;&1S(&%S("1F:65L9"D@>PH@("`@("`@("`@("`@("`@
M)&-A<F1;)&9I96QD72`]("AI<W-E="@D8V]N=&%C=%LD9FEE;&1=*2`_("1C
M;VYT86-T6R1F:65L9%T@.B`G)RD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1R97-U;'1S6UT@/2`D8V%R9#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S=6QT<SL*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@=&AE
M('-P96-I9FEE9"!O8FIE8W0@=&\@=&AE($MO;&%B(&UE<W-A9V4@<W1O<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&0H)&%T=')I8G5T97,I"B`@("![
M"B`@("`@("`@)'AM;"`]("8D=&AI<RT^7VMO;&%B+3YN97=/8FIE8W0H)&%T
M=')I8G5T97-;)W5I9"==*3L*("`@("`@("!I9B`H:7-?82@D>&UL+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D>&UL.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]C<F5A=&5#;VYT86-T*"1X;6PL("1A='1R
M:6)U=&5S*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:V]L86(M/G-A=F5/
M8FIE8W0H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@=&AE('-P
M96-I9FEE9"!O8FIE8W0@9G)O;2!T:&4@2V]L86(@;65S<V%G92!S=&]R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V1E;&5T92@D;V)J96-T7VME>2P@)&]B
M:F5C=%]I9"D*("`@('L*("`@("`@("!I9B`H)&]B:F5C=%]K97D@(3T@)W5I
M9"<I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:V]L86(M/G)E;6]V94]B:F5C=',H)&]B
M:F5C=%]I9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&5S(&%N(&5X
M:7-T:6YG(&]B:F5C="!I;B!T:&4@2V]L86(@;65S<V%G92!S=&]R92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&]B:F5C="!I9"P@<&]S
M<VEB;'D@=7!D871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-A=F4H)&]B
M:F5C=%]K97DL("1O8FIE8W1?:60L("1A='1R:6)U=&5S*0H@("`@>PH@("`@
M("`@(&EF("@D;V)J96-T7VME>2`A/2`G=6ED)RD@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G:V5Y(&UU<W0@8F4@=6ED)RD["B`@
M("`@("`@?0H*("`@("`@("`D>&UL(#T@)B1T:&ES+3Y?:V]L86(M/FQO861/
M8FIE8W0H)&]B:F5C=%]I9"D["B`@("`@("`@:68@*&ES7V$H)'AM;"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'AM;#L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?8W)E871E0V]N=&%C="@D>&UL+"`D871T
M<FEB=71E<RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VMO;&%B+3YS
M879E3V)J96-T*"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;V)J96-T7VED.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E(&%N(&]B:F5C="!K97D@9F]R(&$@;F5W(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@(%1H
M92!A='1R:6)U=&5S("AI;B!D<FEV97(@:V5Y<RD@;V8@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="!B96EN9R!A9&1E9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!U;FEQ=64@240@9F]R
M('1H92!N97<@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;6%K94ME
M>2@D871T<FEB=71E<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E
M;F5R871E54E$*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!4
M=7)B82!S96%R8V@@8W)I=&5R:6$@:6YT;R!A(&-O;7!A<F%B;&4@24U!4"!S
M96%R8V@@<W1R:6YG"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<FET
M97)I82`@("`@(%1H92!S96%R8V@@8W)I=&5R:6$N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!)34%0('-E87)C:"!S=')I;F<@8V]R<F5S
M<&]N9&EN9R!T;R`D8W)I=&5R:6$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B
M=6EL9$E-05!396%R8V@H)&-R:71E<FEA*0H@("`@>PH@("`@("`@("1V86QU
M97,@/2!A<G)A>5]V86QU97,H)&-R:71E<FEA*3L*("`@("`@("`D=F%L=65S
M(#T@)'9A;'5E<ULP73L*("`@("`@("`D<75E<GD@/2`G2$5!1$52("(G("X@
M2T],04)?2$5!1$527U194$4@+B`G(B`B)R`N("1T:&ES+3Y?:V]L86(M/F=E
M=$UI;654>7!E*"D@+B`G(B`G.PH*("`@("`@("!F;W(@*"1C=7)R96YT(#T@
M,#L@)&-U<G)E;G0@/"!C;W5N="@D=F%L=65S*3L@)&-U<G)E;G0K*RD@>PH@
M("`@("`@("`@("`D=&5M<"`]("1V86QU97-;)&-U<G)E;G1=.PH*("`@("`@
M("`@("`@=VAI;&4@*"%E;7!T>2@D=&5M<"D@)B8@(6%R<F%Y7VME>5]E>&ES
M=',H)V9I96QD)RP@)'1E;7`I*2!["B`@("`@("`@("`@("`@("`D=&5M<"`]
M(&%R<F%Y7W9A;'5E<R@D=&5M<"D["B`@("`@("`@("`@("`@("`D=&5M<"`]
M("1T96UP6S!=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H96UP
M='DH)'1E;7`I*2!C;VYT:6YU93L*"B`@("`@("`@("`@("1S96%R8VAK97D@
M/2`D=&5M<%LG9FEE;&0G73L*("`@("`@("`@("`@)'-E87)C:'9A;"`]("1T
M96UP6R=T97-T)UT["@H@("`@("`@("`@("!S=VET8V@@*"1S96%R8VAK97DI
M('L*("`@("`@("`@("`@8V%S92`G;W=N97(G.@H@("`@("`@("`@("`@("`@
M)'%U97)Y("X]("=&4D]-("(G("X@)'-E87)C:'9A;"`N("<B("<["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1S96%R8VAK97DI*2!["B`@("`@("`@
M("`@("`@("`@("`@)'%U97)Y("X]("="3T19("(G("X@)'-E87)C:&ME>2`N
M("<B("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1S96%R8VAV86PI*2!["B`@("`@("`@("`@("`@("`@("`@)'%U
M97)Y("X]("="3T19("(G("X@)'-E87)C:'9A;"`N("<B("<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<FEM*"1Q=65R>2D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T=7)B82]L:6(O1')I=F5R+W-Q;"YP:'``````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,S,C0T`#$P-#$W,S8R
M-S4V`#`R,3`V,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5'5R8F$@9&ER96-T;W)Y(&1R:79E<B!I
M;7!L96UE;G1A=&EO;B!F;W(@4$A0)W,@4$5!4B!D871A8F%S92!A8G-T<F%C
M=&EO;@H@*B!L87EE<BX*("H*("H@)$AO<F1E.B!T=7)B82]L:6(O1')I=F5R
M+W-Q;"YP:'`L=B`Q+C4Y+C$P+C$U(#(P,#8O,#$O,3@@,3DZ-3`Z,C4@8F5N
M($5X<"`D"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!C<V@N<FET
M+F5D=3X*("H@0'!A8VMA9V4@5'5R8F$*("HO"F-L87-S(%1U<F)A7T1R:79E
M<E]S<6P@97AT96YD<R!4=7)B85]$<FEV97(@>PH*("`@("\J*@H@("`@("H@
M5VAA="!C86X@=&AI<R!B86-K96YD(&1O/PH@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?8V%P86)I;&ET:65S(#T@87)R87DH
M"B`@("`@("`@)V1E;&5T95]A;&PG(#T^('1R=64L"B`@("`@("`@)V1E;&5T
M95]A9&1R97-S8F]O:R<@/3X@=')U90H@("`@*3L*"B`@("`O*BH*("`@("`J
M($AA;F1L92!F;W(@=&AE(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@
M("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@)%]D8CL*"B`@("!F=6YC
M=&EO;B!?:6YI="@I"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=$0BYP
M:'`G.PH@("`@("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H)'1H:7,M
M/E]P87)A;7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G<&5R<VES=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P
M97)S:7-T96YT)UTI*2D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D
M8CL*("`@("`@("!]"@H@("`@("`@("\O(%-E="!$0B!P;W)T86)I;&ET>2!O
M<'1I;VYS+@H@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^<&AP='EP92D@
M>PH@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@)'1H:7,M/E]D
M8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/
M5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24R!\($1"7U!/4E1!0DE,
M25197U)44DE-*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I
M;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,
M25197T524D]24RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]P
M87)A;7-;)W!H<'1Y<&4G72`]/2`G;V-I."<I('L*("`@("`@("`@("`@)'1H
M:7,M/E]D8BT^<75E<GDH)T%,5$52(%-%4U-)3TX@4T54($Y,4U]$051%7T9/
M4DU!5"`](%PG65E962U-32U$1%PG)RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&YU;6)E<B!O9B!C;VYT86-T<R!O9B!T:&4@8W5R<F5N="!U<V5R(&EN('1H
M:7,@861D<F5S<R!B;V]K+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&YU;6)E<B!O9B!C;VYT86-T<R!T:&%T('1H92!U<V5R(&]W;G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT0V]N=&%C=',H*0H@("`@>PH@
M("`@("`@('-T871I8R`D8V]U;G0["@H@("`@("`@(&EF("@A:7-S970H)&-O
M=6YT*2D@>PH@("`@("`@("`@("`O*B!"=6EL9"!U<"!T:&4@9G5L;"!Q=65R
M>2X@*B\*("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!#3U5.5"@J*2!&
M4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@
M("`@("`@("`@("<@5TA%4D4@)R`N("1T:&ES+3YT;T1R:79E<B@G7U]O=VYE
M<B<I("X@)R`](#\G.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH075T
M:#HZ9V5T075T:"@I*3L*"B`@("`@("`@("`@("\J($QO9R!T:&4@<75E<GD@
M870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=344P@<75E<GD@8GD@5'5R8F%?1')I=F5R7W-Q;#HZ8V]U
M;G1#;VYT86-T<R@I.B`G("X@)'%U97)Y+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@("`@("\J(%)U;B!Q=65R>2X@*B\*("`@("`@("`@("`@
M)&-O=6YT(#T@)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O=6YT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5A<F-H97,@=&AE(%-13"!D871A8F%S92!W:71H('1H
M92!G:79E;B!C<FET97)I82!A;F0@<F5T=7)N<R!A"B`@("`@*B!F:6QT97)E
M9"!L:7-T(&]F(')E<W5L=',N($EF('1H92!C<FET97)I82!P87)A;65T97(@
M:7,@86X@96UP='D@87)R87DL"B`@("`@*B!A;&P@<F5C;W)D<R!W:6QL(&)E
M(')E='5R;F5D+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D8W)I=&5R
M:6$@($%R<F%Y(&-O;G1A:6YI;F<@=&AE('-E87)C:"!C<FET97)I82X*("`@
M("`J($!P87)A;2!A<G)A>2`D9FEE;&1S("`@($QI<W0@;V8@9FEE;&1S('1O
M(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!(87-H(&-O
M;G1A:6YI;F<@=&AE('-E87)C:"!R97-U;'1S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<V5A<F-H*"1C<FET97)I82P@)&9I96QD<RD*("`@('L*("`@("`@
M("`O*B!"=6EL9"!T:&4@5TA%4D4@8VQA=7-E+B`J+PH@("`@("`@("1W:&5R
M92`]("<G.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@I.PH@("`@("`@(&EF
M("AC;W5N="@D8W)I=&5R:6$I('Q\("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M9FEL=&5R)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1C<FET97)I82!A
M<R`D:V5Y(#T^("1V86QS*2!["B`@("`@("`@("`@("`@("!I9B`H)&ME>2`]
M/2`G3U(G('Q\("1K97D@/3T@)T%.1"<I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1W:&5R92DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'=H97)E("X]("<@)R`N("1K97D@+B`G("<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1B:6YD<R`]("1T:&ES+3Y?
M8G5I;&1396%R8VA1=65R>2@D:V5Y+"`D=F%L<RD["B`@("`@("`@("`@("`@
M("`@("`@)'=H97)E("X]("<H)R`N("1B:6YD<ULP72`N("<I)SL*("`@("`@
M("`@("`@("`@("`@("`D=F%L=65S("L]("1B:6YD<ULQ73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=VAE<F4@/2`G
M(%=(15)%("<@+B`D=VAE<F4["B`@("`@("`@("`@(&EF("AC;W5N="@D8W)I
M=&5R:6$I("8F("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG9FEL=&5R)UTI*2![
M"B`@("`@("`@("`@("`@("`D=VAE<F4@+CT@)R!!3D0@)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=F
M:6QT97(G72DI('L*("`@("`@("`@("`@("`@("1W:&5R92`N/2`D=&AI<RT^
M7W!A<F%M<ULG9FEL=&5R)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\J($)U:6QD('5P('1H92!F=6QL('%U97)Y+B`J+PH@("`@("`@
M("1Q=65R>2`]("=314Q%0U0@)R`N(&EM<&QO9&4H)RP@)RP@)&9I96QD<RD@
M+B`G($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@)'=H97)E
M.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE
M=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@<75E<GD@
M8GD@5'5R8F%?1')I=F5R7W-Q;#HZ7W-E87)C:"@I.B`G("X@)'%U97)Y+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!2=6X@<75E<GDN("HO"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A
M;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L=',@
M/2!A<G)A>2@I.PH@("`@("`@("1I36%X(#T@8V]U;G0H)&9I96QD<RD["B`@
M("`@("`@=VAI;&4@*"1R;W<@/2`D<F5S=6QT+3YF971C:%)O=R@I*2!["B`@
M("`@("`@("`@(&EF("AI<U]A*"1R;W<L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R;W<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F]W
M(#T@)'1H:7,M/E]C;VYV97)T1G)O;41R:79E<B@D<F]W*3L*"B`@("`@("`@
M("`@("1E;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1I36%X.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D9FEE;&0@
M/2`D9FEE;&1S6R1I73L*("`@("`@("`@("`@("`@("1E;G1R>5LD9FEE;&1=
M(#T@)')O=ULD:5T["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L
M='-;72`]("1E;G1R>3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S
M=6QT<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E861S('1H92!G:79E;B!D
M871A(&9R;VT@=&AE(%-13"!D871A8F%S92!A;F0@<F5T=7)N<R!T:&4@<F5S
M=6QT)W,*("`@("`J(&9I96QD<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&-R:71E<FEA("!396%R8V@@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9"`@("`@("!$871A(&ED96YT:69I97(N"B`@("`@*B!`<&%R
M86T@87)R87D@)&9I96QD<R`@("!,:7-T(&]F(&9I96QD<R!T;R!R971U<FXN
M"B`@("`@*@H@("`@("H@0')E='5R;B`@2&%S:"!C;VYT86EN:6YG('1H92!S
M96%R8V@@<F5S=6QT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E860H)&-R
M:71E<FEA+"`D:60L("1F:65L9',I"B`@("!["B`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*"D["@H@("`@("`@("1I;B`]("<G.PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D:60I*2!["B`@("`@("`@("`@(&EF("@A8V]U;G0H)&ED*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1I9"!A<R`D:V5Y*2!["B`@("`@("`@
M("`@("`@("`D:6X@+CT@96UP='DH)&EN*2`_("<_)R`Z("<L(#\G.PH@("`@
M("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'1H:7,M/E]C;VYV97)T5&]$<FEV
M97(H)&ME>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'=H97)E(#T@
M)&-R:71E<FEA("X@)R!)3B`H)R`N("1I;B`N("<I)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=VAE<F4@/2`D8W)I=&5R:6$@+B`G(#T@/R<[
M"B`@("`@("`@("`@("1V86QU97-;72`]("1T:&ES+3Y?8V]N=F5R=%1O1')I
M=F5R*"1I9"D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]P87)A;7-;)V9I;'1E<B==*2D@>PH@("`@("`@("`@("`D=VAE<F4@+CT@
M)R!!3D0@)R`N("1T:&ES+3Y?<&%R86US6R=F:6QT97(G73L*("`@("`@("!]
M"@H@("`@("`@("1Q=65R>2`@/2`G4T5,14-4("<@+B!I;7!L;V1E*"<L("<L
M("1F:65L9',I("X@)R`G.PH@("`@("`@("1Q=65R>2`N/2`G1E)/32`G("X@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+B`G(%=(15)%("<@+B`D=VAE<F4[
M"@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V
M96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!Q=65R>2!B
M>2!4=7)B85]$<FEV97)?<W%L.CI?<F5A9"@I.B`G("X@)'%U97)Y+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^
M9V5T06QL*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT<R`](&%R<F%Y*"D[
M"B`@("`@("`@)&E-87@@/2!C;W5N="@D9FEE;&1S*3L*("`@("`@("!I9B`H
M(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!F
M;W)E86-H("@D<F5S=6QT(&%S("1R;W<I('L*("`@("`@("`@("`@("`@("1E
M;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!F;W(@*"1I/3`[("1I
M(#P@)&E-87@[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D9FEE;&0@
M/2`D9FEE;&1S6R1I73L*("`@("`@("`@("`@("`@("`@("`D96YT<GE;)&9I
M96QD72`]("1T:&ES+3Y?8V]N=F5R=$9R;VU$<FEV97(H)')O=ULD:5TI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W5L='-;72`]
M("1E;G1R>3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1R97-U;'1S.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!T:&4@
M<W!E8VEF:65D(&]B:F5C="!T;R!T:&4@4U%,(&1A=&%B87-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?861D*"1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@
M("1F:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1F:65L9"`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@)&9I96QD<UM=(#T@)&9I96QD.PH@("`@
M("`@("`@("`D=F%L=65S6UT@/2`D=&AI<RT^7V-O;G9E<G14;T1R:79E<B@D
M=F%L=64I.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y("`]("=)3E-%4E0@
M24Y43R`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+B`G("@G("X@:6UP
M;&]D92@G+"`G+"`D9FEE;&1S*2`N("<I)SL*("`@("`@("`D<75E<GD@+CT@
M)R!604Q515,@*"<@+B!S=')?<F5P96%T*"<_+"`G+"!C;W5N="@D=F%L=65S
M*2`M(#$I("X@)S\I)SL*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M
M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M96QE=&5S('1H92!S<&5C:69I960@;V)J96-T(&9R;VT@=&AE(%-13"!D871A
M8F%S92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E;&5T92@D;V)J96-T7VME
M>2P@)&]B:F5C=%]I9"D*("`@('L*("`@("`@("`D<75E<GD@/2`G1$5,151%
M($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@
M("`@("`@("`G(%=(15)%("<@+B`D;V)J96-T7VME>2`N("<@/2`_)SL*("`@
M("`@("`D=F%L=65S(#T@87)R87DH)&]B:F5C=%]I9"D["@H@("`@("`@("\J
M($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!Q=65R>2!B>2!4=7)B85]$<FEV
M97)?<W%L.CI?9&5L971E*"DZ("<@+B`D<75E<GDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E
M<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E
M<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;&P@
M8V]N=&%C=',@9G)O;2!A('-P96-I9FEC(&%D9')E<W,@8F]O:RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]U<F-E3F%M92`@5&AE(&]W;F5R
M7VED(&]F('1H92!A9&1R97-S(&)O;VL@=&\*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!D96QE=&4N("!)9B!O;6ET=&5D+"!T:&4@=7-E
M<B=S(&1E9F%U;'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A9&1R97-S(&)O;VL@=VEL;"!B92!C;&5A<F5D+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@;W!E<F%T:6]N('=O<FME
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E;&5T94%L;"@D<V]U<F-E3F%M
M92`]("<G*0H@("`@>PH@("`@("`@(&EF("@A075T:#HZ9V5T075T:"@I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P97)M:7-S
M:6]N(&1E;FEE9"<I.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@)T1%
M3$5412!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N("<@5TA%
M4D4@;W=N97)?:60@/2`_)SL*"B`@("`@("`@:68@*"$D<V]U<F-E3F%M92D@
M>PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH075T:#HZ9V5T075T:"@I
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L=65S(#T@87)R
M87DH)'-O=7)C94YA;64I.PH@("`@("`@('T*("`@("`@("`O*B!,;V<@=&AE
M('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"=344P@<75E<GD@8GD@5'5R8F%?1')I=F5R7W-Q;#HZ
M7V1E;&5T94%L;"@I.B`G("X@)'%U97)Y+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L
M=65S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-A=F5S('1H92!S<&5C:69I
M960@;V)J96-T(&EN('1H92!344P@9&%T86)A<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!O8FIE8W0@:60L('!O<W-I8FQY('5P9&%T
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S879E*"1O8FIE8W1?:V5Y+"`D
M;V)J96-T7VED+"`D871T<FEB=71E<RD*("`@('L*("`@("`@("`D=VAE<F4@
M/2`D;V)J96-T7VME>2`N("<@/2`_)SL*("`@("`@("!U;G-E="@D871T<FEB
M=71E<ULD;V)J96-T7VME>5TI.PH*("`@("`@("`D9FEE;&1S(#T@87)R87DH
M*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H
M("@D871T<FEB=71E<R!A<R`D9FEE;&0@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@("1F:65L9'-;72`]("1F:65L9"`N("<@/2`_)SL*("`@("`@("`@("`@
M)'9A;'5E<UM=(#T@)'1H:7,M/E]C;VYV97)T5&]$<FEV97(H)'9A;'5E*3L*
M("`@("`@("!]"@H@("`@("`@("1V86QU97-;72`]("1O8FIE8W1?:60["@H@
M("`@("`@("1Q=65R>2`@/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72`N("<@4T54("<@+B!I;7!L;V1E*"<L("<L("1F:65L9',I("X@
M)R`G.PH@("`@("`@("1Q=65R>2`N/2`G5TA%4D4@)R`N("1W:&5R93L*"B`@
M("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@
M*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,('%U97)Y(&)Y(%1U
M<F)A7T1R:79E<E]S<6PZ.E]S879E*"DZ("<@+B`D<75E<GDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R
M>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D;V)J96-T7VED.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0W)E871E<R!A;B!O8FIE8W0@:V5Y(&9O<B!A(&YE=R!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R:6)U=&5S("!4:&4@871T<FEB
M=71E<R`H:6X@9')I=F5R(&ME>7,I(&]F('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!O8FIE8W0@8F5I;F<@861D960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@($$@=6YI<75E($E$(&9O<B!T:&4@;F5W
M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@7VUA:V5+97DH)&%T=')I
M8G5T97,I"B`@("!["B`@("`@("`@<F5T=7)N(&UD-2AU;FEQ:60H;71?<F%N
M9"@I+"!T<G5E*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!P
M:65C92!O9B!A('-E87)C:"!Q=65R>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1G;'5E("`@("`@5&AE(&=L=64@=&\@:F]I;B!T:&4@8W)I=&5R
M:6$@*$]2+T%.1"DN"B`@("`@*B!`<&%R86T@87)R87D@("1C<FET97)I82`@
M5&AE(&%R<F%Y(&]F(&-R:71E<FEA+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(%-13"!F<F%G;65N="!A;F0@82!L:7-T(&]F('9A;'5E<R!S
M=6ET86)L92!F;W(@8FEN9&EN9PH@("`@("H@("`@("`@("`@("`@("`@87,@
M86X@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9%-E87)C:%%U
M97)Y*"1G;'5E+"`D8W)I=&5R:6$I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]344PN<&AP)SL*"B`@("`@("`@)&-L875S92`]("<G.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D
M8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L<RD@>PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1V86QS6R=/4B==*2!\?"`A96UP='DH)'9A;'-;)T%.1"==*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8VQA=7-E*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)R`G("X@)&=L=64@+B`G("<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8FEN9',@/2`D
M=&AI<RT^7V)U:6QD4V5A<F-H475E<GDH(65M<'1Y*"1V86QS6R=/4B==*2`_
M("=/4B<@.B`G04Y$)RP@)'9A;',I.PH@("`@("`@("`@("`@("`@)&-L875S
M92`N/2`G*"<@+B`D8FEN9'-;,%T@+B`G*2<["B`@("`@("`@("`@("`@("`D
M=F%L=65S(#T@87)R87E?;65R9V4H)'9A;'5E<RP@)&)I;F1S6S%=*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=F%L<ULG9FEE;&0G72DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1C;&%U<V4I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;&%U
M<V4@+CT@)R`G("X@)&=L=64@+B`G("<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1R:',@/2`D=&AI<RT^7V-O;G9E<G14
M;T1R:79E<B@D=F%L<ULG=&5S="==*3L*("`@("`@("`@("`@("`@("`@("`D
M8FEN9',@/2!(;W)D95]344PZ.F)U:6QD0VQA=7-E*"1T:&ES+3Y?9&(L("1V
M86QS6R=F:65L9"==+"`D=F%L<ULG;W`G72P@)')H<RP@=')U92D["B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1B:6YD<RDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-L875S92`N/2`D8FEN9'-;,%T["B`@("`@
M("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>5]M97)G92@D=F%L
M=65S+"`D8FEN9'-;,5TI.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)&)I;F1S.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;',@87,@)'1E<W0I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&5S=%LG
M3U(G72D@?'P@(65M<'1Y*"1T97-T6R=!3D0G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-L875S92DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQA=7-E("X]("<@)R`N("1G
M;'5E("X@)R`G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&)I;F1S(#T@)'1H:7,M/E]B=6EL
M9%-E87)C:%%U97)Y*"%E;7!T>2@D=F%L<ULG3U(G72D@/R`G3U(G(#H@)T%.
M1"<L("1T97-T*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&%U
M<V4@+CT@)R@G("X@)&)I;F1S6S!=("X@)RDG.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y7VUE<F=E*"1V86QU97,L("1B
M:6YD<ULQ72D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;&%U<V4I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L875S92`N
M/2`G("<@+B`D:V5Y("X@)R`G.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')H<R`]("1T:&ES
M+3Y?8V]N=F5R=%1O1')I=F5R*"1T97-T6R=T97-T)UTI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&)I;F1S(#T@2&]R9&5?4U%,.CIB=6EL9$-L
M875S92@D=&AI<RT^7V1B+"`D=&5S=%LG9FEE;&0G72P@)'1E<W1;)V]P)UTL
M("1R:',L('1R=64I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1B:6YD<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8VQA=7-E("X]("1B:6YD<ULP73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87E?;65R9V4H)'9A;'5E
M<RP@)&)I;F1S6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L875S
M92`N/2`D8FEN9',["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!A<G)A>2@D8VQA=7-E+"`D=F%L=65S*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@=F%L=64@9G)O;2!T:&4@9')I
M=F5R)W,@8VAA<G-E="!T;R!T:&4@9&5F875L="!C:&%R<V5T+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@($$@=F%L=64@=&\@8V]N=F5R
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("!4:&4@8V]N
M=F5R=&5D('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=$9R
M;VU$<FEV97(H)'9A;'5E*0H@("`@>PH@("`@("`@(')E='5R;B!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1V86QU92P@)'1H:7,M/E]P87)A;7-;)V-H87)S
M970G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A('9A;'5E
M(&9R;VT@=&AE(&1E9F%U;'0@8VAA<G-E="!T;R!T:&4@9')I=F5R)W,@8VAA
M<G-E="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E("!!('9A
M;'5E('1O(&-O;G9E<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M("`@("`@5&AE(&-O;G9E<G1E9"!V86QU92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-O;G9E<G14;T1R:79E<B@D=F%L=64I"B`@("!["B`@("`@("`@<F5T
M=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"!.3%,Z.F=E=$-H
M87)S970H*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O='5R8F$O;&EB+T1R:79E<B]I;7-P+G!H<```````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,S`V-``Q,#0Q-S,V,C<U
M-@`P,C$R,S(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O0V%C:&4N<&AP)SL*
M"B\J*@H@*B!4=7)B82!D:7)E8W1O<GD@9')I=F5R(&EM<&QE;65N=&%T:6]N
M(&9O<B!A;B!)35-0('-E<G9E<BX*("H*("H@)$AO<F1E.B!T=7)B82]L:6(O
M1')I=F5R+VEM<W`N<&AP+'8@,2XR,2XT+C$Q(#(P,#4O,3$O,3`@,3(Z-#0Z
M,S`@;61J=6MI8R!%>'`@)`H@*@H@*B!`875T:&]R("!-:6-H865L(%)U8FEN
M<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K86=E(%1U<F)A"B`J
M+PIC;&%S<R!4=7)B85]$<FEV97)?:6US<"!E>'1E;F1S(%1U<F)A7T1R:79E
M<B!["B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE($E-4U`@8V]N;F5C
M=&EO;BX*("`@("`J"B`@("`@*B!`=F%R($YE=%])35-0"B`@("`@*B\*("`@
M('9A<B`D7VEM<W`["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@
M861D<F5S<V)O;VLN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?8F]O:TYA;64@(#T@)R<["@H@("`@+RHJ"B`@("`@*B!(
M;VQD<R!I9B!W92!A<F4@875T:&5N=&EC871E9"X*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?875T:&5N=&EC871E9"`]
M("<G.PH*("`@("\J*@H@("`@("H@2&]L9',@;F%M92!O9B!T:&4@9FEE;&0@
M:6YD:6-A=&EN9R!A;B!)35-0(&=R;W5P+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V=R;W5P1FEE;&0@/2`G)SL*"B`@
M("`O*BH*("`@("`J($AO;&1S('9A;'5E('1H870@)%]G<F]U<$9I96QD('=I
M;&P@:&%V92!I9B!E;G1R>2!I<R!A;B!)35-0(&=R;W5P+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V=R;W5P5F%L=64@
M/2`G)SL*"B`@("`O*BH*("`@("`J(%5S960@=&\@<V5T(&EF('1H92!C=7)R
M96YT('-E87)C:"!I<R!F;W(@8V]N=&%C=',@;VYL>2X*("`@("`J"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?;F]'<F]U<',@/2`G
M)SL*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%1U<F)A(&EM
M<W`@9')I=F5R(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@2&%S:"!C;VYT86EN:6YG(&%D9&ET:6]N86P@8V]N9FEG=7)A
M=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!4=7)B85]$
M<FEV97)?:6US<"@D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3YT>7!E
M("`@("`@("`@/2`G:6US<"<["B`@("`@("`@)'1H:7,M/G!A<F%M<R`@("`@
M("`]("1P87)A;7,["B`@("`@("`@)'1H:7,M/E]G<F]U<$9I96QD("`]("1P
M87)A;7-;)V=R;W5P7VED7V9I96QD)UT["B`@("`@("`@)'1H:7,M/E]G<F]U
M<%9A;'5E("`]("1P87)A;7-;)V=R;W5P7VED7W9A;'5E)UT["B`@("`@("`@
M)'1H:7,M/E]B;V]K3F%M92`@("`]("1P87)A;7-;)VYA;64G73L*("`@("`@
M("`D=&AI<RT^7VUY4FEG:'1S("`@(#T@)'!A<F%M<ULG;7E?<FEG:'1S)UT[
M"B`@("`@("`@)'1H:7,M/E]P97)M<R`@("`@("`]("1T:&ES+3Y?86-L5&](
M;W)D95!E<FUS*"1P87)A;7-;)VUY7W)I9VAT<R==*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($EN:71I86QI>F4@=&AE($E-4U`@8V]N;F5C=&EO;B!A;F0@
M8VAE8VL@9F]R(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YI="@I
M"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<RP@)&-O;F8["B`@("`@("`@
M<F5Q=6ER95]O;F-E("=.970O24U34"YP:'`G.PH@("`@("`@("1T:&ES+3Y?
M:6US<"`]("9.971?24U34#HZ<VEN9VQE=&]N*"=";V]K)RP@)'1H:7,M/G!A
M<F%M<RD["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6YI="@I
M.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]A=71H96YT:6-A=&5D(#T@9F%L<V4["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D8V]N9ELG;&]G)UTI*2!["B`@("`@("`@("`@("1L;V=0
M87)A;7,@/2`D8V]N9ELG;&]G)UT["B`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7VEM<W`M/G-E=$QO9V=E<B@D8V]N9ELG;&]G)UTI.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]A=71H96YT:6-A=&5D(#T@=')U93L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@86QL(&5N=')I97,@;6%T8VAI;F<@)&-R:71E<F$N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1C<FET97)I82`@07)R87D@8V]N=&%I;FEN
M9R!T:&4@<V5A<F-H(&-R:71E<FEA+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F
M:65L9',@("`@3&ES="!O9B!F:65L9',@=&\@<F5T=7)N+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($AA<V@@8V]N=&%I;FEN9R!T:&4@<V5A<F-H
M(')E<W5L=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96%R8V@H)&-R:71E
M<FEA+"`D9FEE;&1S*0H@("`@>PH@("`@("`@("1Q=65R>2`](&%R<F%Y*"D[
M"B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H(21T
M:&ES+3Y?875T:&5N=&EC871E9"D@>PH@("`@("`@("`@("!R971U<FX@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@<V5A<F-H(&-R
M:71E<FEA+B`J+PH@("`@("`@("1I;7-P4V5A<F-H(#T@87)R87DH*3L*("`@
M("`@("!I9B`H8V]U;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@("!F;W)E
M86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L<RD@>PH@("`@("`@("`@
M("`@("`@:68@*'-T<G9A;"@D:V5Y*2`]/2`G3U(G*2!["B`@("`@("`@("`@
M("`@("`@("`@)&YA;65S(#T@)'1H:7,M/E]D;U-E87)C:"@D=F%L<RP@)T]2
M)RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<W1R=F%L*"1K97DI(#T]
M("=!3D0G*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;65S(#T@)'1H:7,M
M/E]D;U-E87)C:"@D=F%L<RP@)T%.1"<I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!.;W<@=V4@:&%V
M92!A(&QI<W0@;V8@;F%M97,L(&=E="!T:&4@<F5S="X@*B\*("`@("`@("`D
M;F%M97-#;W5N="`](&-O=6YT*"1N86UE<RD["B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&YA;65S0V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)'1E
M;7`@/2`D=&AI<RT^7W)E860H)VYA;64G+"!A<G)A>2@D;F%M97-;)&E=*2P@
M)&9I96QD<RD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&5M<%LP73L*("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H
M*"1R97-U;'1S+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"@D=&AI<RT^7VYO1W)O=7!S*2`F)B`H:7-S970H)')E<W5L=%LD=&AI
M<RT^7V=R;W5P1FEE;&1=*2D@)B8*("`@("`@("`@("`@("`@("`@("`@("@D
M<F5S=6QT6R1T:&ES+3Y?9W)O=7!&:65L9%TI(#T]("1T:&ES+3Y?9W)O=7!6
M86QU92D@>PH@("`@("`@("`@("`@("`@=6YS970H)')E<W5L="D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S=6QT<UM=(#T@
M)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G24U34"!R971U<FYE9"`E<R!R97-U
M;'1S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O=6YT
M*"1R97-U;'1S*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH@("`@("`@(')E='5R;B!A<G)A>5]V86QU97,H)')E<W5L=',I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@=&AE(&=I=F5N(&1A=&$@9G)O
M;2!T:&4@24U34"!S97)V97(@86YD(')E='5R;G,@=&AE"B`@("`@*B!R97-U
M;'0G<R!F:65L9',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<FET
M97)I82`@*$EG;F]R960Z($%L=V%Y<R`G;F%M92<@9F]R($E-4U`I(%-E87)C
M:"!C<FET97)I82X*("`@("`J($!P87)A;2!A<G)A>2`D:60@("`@("`@($%R
M<F%Y(&]F(&1A=&$@:61E;G1I9FEE<G,N"B`@("`@*B!`<&%R86T@87)R87D@
M)&9I96QD<R`@("!,:7-T(&]F(&9I96QD<R!T;R!R971U<FXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@2&%S:"!C;VYT86EN:6YG('1H92!S96%R
M8V@@<F5S=6QT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E860H)&-R:71E
M<FEA+"`D:60L("1F:65L9',I"B`@("!["B`@("`@("`@)')E<W5L=',@/2!A
M<G)A>2@I.PH@("`@("`@(&EF("@A)'1H:7,M/E]A=71H96YT:6-A=&5D*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@("`@("!]"B`@("`@
M("`@)&ED(#T@87)R87E?=F%L=65S*"1I9"D["B`@("`@("`@)&ED0V]U;G0@
M/2!C;W5N="@D:60I.PH@("`@("`@("1R97-U;'0@/2!A<G)A>2@I.PH@("`@
M("`@("1M96UB97)S(#T@87)R87DH*3L*("`@("`@("`D=&UE;6)E<G,@/2!A
M<G)A>2@I.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:61#;W5N=#L@
M)&DK*RD@>PH@("`@("`@("`@("`D=&5M<"`]("1T:&ES+3Y?:6US<"T^9V5T
M16YT<GDH)'1H:7,M/E]B;V]K3F%M92P@)&ED6R1I72D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1T96UP+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1E;7`["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=&5M<%LG9G5L;&YA;64G72`]("1T96UP6R=N86UE)UT[
M"B`@("`@("`@("`@("`@("`D:7-)35-01W)O=7`@/2!F86QS93L*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1E;7!;)U]?;W=N97(G72DI('L*("`@
M("`@("`@("`@("`@("`@("`D=&5M<%LG7U]O=VYE<B==(#T@075T:#HZ9V5T
M075T:"@I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF
M("@H:7-S970H)'1E;7!;)'1H:7,M/E]G<F]U<$9I96QD72DI("8F"B`@("`@
M("`@("`@("`@("`@("`@*"1T96UP6R1T:&ES+3Y?9W)O=7!&:65L9%T@/3T@
M)'1H:7,M/E]G<F]U<%9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@("1I
M<TE-4U!'<F]U<"`]('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`O+R!'970@=&AE(&=R;W5P(&UE;6)E<G,@=&AA="!M:6=H="!H
M879E(&)E96X@861D960@9G)O;2!O=&AE<@H@("`@("`@("`@("`@("`@+R\@
M24U34"!A<'!L:6-A=&EO;G,N"B`@("`@("`@("`@("`@("!I9B`H)&ES24U3
M4$=R;W5P*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T96UP
M6R=E;6%I;"==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D96UA:6Q,
M:7-T(#T@)'1H:7,M/E]G971'<F]U<$5M86EL<R@D=&5M<%LG96UA:6PG72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N="`](&-O=6YT*"1E;6%I
M;$QI<W0I.PH@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@
M)&H@/"`D8V]U;G0[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1M96UB97).86UE(#T@)'1H:7,M/E]I;7-P+3YS96%R8V@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H)'1H:7,M/E]B;V]K3F%M92P@
M87)R87DH)V5M86EL)R`]/B!T<FEM*"1E;6%I;$QI<W1;)&I=*2DI.PH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D;65M8F5R3F%M
M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;65M8F5R
M<UM=(#T@)&UE;6)E<DYA;65;,%T["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T96UP
M6R=?7VUE;6)E<G,G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1M
M96UB97)S(#T@=6YS97)I86QI>F4H)'1E;7!;)U]?;65M8F5R<R==*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1E;7!;
M)U]?;65M8F5R<R==(#T@<V5R:6%L:7IE*"1T:&ES+3Y?<F5M;W9E1'5P;&EC
M871E9"@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)&UE;6)E<G,L("1T;65M8F5R<RDI*3L*("`@
M("`@("`@("`@("`@("`@("`D=&5M<%LG7U]T>7!E)UT@/2`G1W)O=7`G.PH@
M("`@("`@("`@("`@("`@("`@("1T96UP6R=E;6%I;"==(#T@;G5L;#L*("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1E;7`["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O($E-4U`@8V]N
M=&%C="X*("`@("`@("`@("`@("`@("`@("`D8V]U;G0@/2!C;W5N="@D9FEE
M;&1S*3L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"`D
M8V]U;G0[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1T96UP6R1F:65L9'-;)&I=72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R97-U;'1;)&9I96QD<ULD:EU=(#T@)'1E;7!;)&9I96QD
M<ULD:EU=.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D<F5S=6QT<UM=(#T@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9',@=&AE('-P96-I9FEE9"!O8FIE8W0@=&\@=&AE($E-4U`@<V5R=F5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D*"1A='1R:6)U=&5S*0H@("`@
M>PH@("`@("`@("\J(%=E(&YE960@=&\@;6%P(&]U="!4=7)B85]/8FIE8W1?
M1W)O=7!S(&)A8VL@=&\@24U34"!G<F]U<',@8F5F;W)E"B`@("`@("`@("H@
M=W)I=&EN9R!O=70@=&\@=&AE('-E<G9E<BX@5V4@;F5E9"!T;R!A<G)A>5]V
M86QU97,H*2!I="!I;@H@("`@("`@("`J(&-A<V4@86X@96YT<GD@=V%S(&1E
M;&5T960@9G)O;2!T:&4@9W)O=7`N("HO"B`@("`@("`@:68@*"1A='1R:6)U
M=&5S6R=?7W1Y<&4G72`]/2`G1W)O=7`G*2!["B`@("`@("`@("`@("\J(%=E
M(&UA>2!H879E(&$@;F5W;'D@8W)E871E9"!G<F]U<"X@*B\*("`@("`@("`@
M("`@)&%T=')I8G5T97-;)'1H:7,M/E]G<F]U<$9I96QD72`]("1T:&ES+3Y?
M9W)O=7!686QU93L*("`@("`@("`@("`@:68@*"%I<W-E="@D871T<FEB=71E
M<ULG7U]M96UB97)S)UTI*2!["B`@("`@("`@("`@("`@("`D871T<FEB=71E
M<ULG7U]M96UB97)S)UT@/2`G)SL*("`@("`@("`@("`@("`@("1A='1R:6)U
M=&5S6R=E;6%I;"==(#T@)R`G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D=&5M<"`]('5N<V5R:6%L:7IE*"1A='1R:6)U=&5S6R=?7VUE;6)E<G,G
M72D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=&5M<"DI('L*("`@("`@
M("`@("`@("`@("1M96UB97)S(#T@87)R87E?=F%L=65S*"1T96UP*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M96UB97)S(#T@
M87)R87DH*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&-O=6YT
M*"1M96UB97)S*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?<F5A9"@G;F%M92<L("1M96UB97)S+"!A<G)A>2@G96UA:6PG*2D["B`@
M("`@("`@("`@("`@("`D8V]U;G0@/2!C;W5N="@D<F5S=6QT*3L*("`@("`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F5S=6QT6R1I75LG96UA
M:6PG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1A8W0@/2!S
M<')I;G1F*"(E<SPE<SY<;B(L("1M96UB97)S6R1I72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;)&E=6R=E
M;6%I;"==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;
M)V5M86EL)UT@+CT@)&-O;G1A8W0["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!U;G-E="@D871T<FEB=71E<ULG7U]T>7!E)UTI.PH@("`@("`@('5N
M<V5T*"1A='1R:6)U=&5S6R=F=6QL;F%M92==*3L*("`@("`@("!I9B`H(21T
M:&ES+3YP87)A;7-;)V-O;G1A8W1?;W=N97)S:&EP)UTI('L*("`@("`@("`@
M("`@=6YS970H)&%T=')I8G5T97-;)U]?;W=N97(G72D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YA9&1%;G1R>2@D=&AI<RT^
M7V)O;VM.86UE+"`D871T<FEB=71E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$96QE=&5S('1H92!S<&5C:69I960@;V)J96-T(&9R;VT@=&AE($E-4U`@
M<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5L971E*"1O8FIE8W1?
M:V5Y+"`D;V)J96-T7VED*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/F1E;&5T945N=')Y*"1T:&ES+3Y?8F]O:TYA;64L("1O8FIE8W1?
M:60I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V%V97,@=&AE('-P96-I9FEE
M9"!O8FIE8W0@=&\@=&AE($E-4U`@<V5R=F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&]B:F5C=%]K97D@("A)9VYO<F5D*2!N86UE(&]F('1H
M92!F:65L9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6X@
M)&%T=')I8G5T97-;72!T;R!T<F5A="!A<R!K97DN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1O8FIE8W1?:60@("!4:&4@=F%L=64@;V8@=&AE(&ME>2!F:65L
M9"X*("`@("`J($!P87)A;2!A<G)A>2`@)&%T=')I8G5T97,@($-O;G1A:6YS
M('1H92!F:65L9"!N86UE<R!A;F0@=F%L=65S(&]F('1H92!E;G1R>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&]B:F5C="!I9"P@<&]S
M<VEB;'D@=7!D871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-A=F4H)&]B
M:F5C=%]K97DL("1O8FIE8W1?:60L("1A='1R:6)U=&5S*0H@("`@>PH@("`@
M("`@("\J($-H96-K(&EF('1H92!K97D@8VAA;F=E9"P@8F5C875S92!)35-0
M('=I;&P@:G5S="!W<FET92!O=70*("`@("`@("`@*B!A(&YE=R!E;G1R>2!W
M:71H;W5T(')E;6]V:6YG('1H92!P<F5V:6]U<R!O;F4N("HO"B`@("`@("`@
M:68@*"1A='1R:6)U=&5S6R=N86UE)UT@(3T@)'1H:7,M/E]M86ME2V5Y*"1A
M='1R:6)U=&5S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1E;&5T92@D;V)J
M96-T7VME>2P@)&%T=')I8G5T97-;)VYA;64G72D["B`@("`@("`@("`@("1A
M='1R:6)U=&5S6R=N86UE)UT@/2`D=&AI<RT^7VUA:V5+97DH)&%T=')I8G5T
M97,I.PH@("`@("`@("`@("`D;V)J96-T7VED(#T@)&%T=')I8G5T97-;)VYA
M;64G73L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V%D
M9"@D871T<FEB=71E<RD["B`@("`@("`@<F5T=7)N(&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2`_("1R97-U;'0@.B`D;V)J96-T7VED.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E(&%N(&]B:F5C="!K97D@9F]R(&$@;F5W
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T
M97,@(%1H92!A='1R:6)U=&5S("AI;B!D<FEV97(@:V5Y<RD@;V8@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="!B96EN9R!A
M9&1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!U;FEQ=64@
M240@9F]R('1H92!N97<@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M;6%K94ME>2@D871T<FEB=71E<RD*("`@('L*("`@("`@("!R971U<FX@)&%T
M=')I8G5T97-;)V9U;&QN86UE)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S97,@;W5T("1E;6%I;%1E>'0@:6YT;R!A;B!A<G)A>2!O9B!P=7)E(&5M
M86EL(&%D9')E<W-E<PH@("`@("H@<W5I=&%B;&4@9F]R('-E87)C:&EN9R!T
M:&4@24U34"!D871A<W1O<F4@=VET:"X*("`@("`J"B`@("`@*B!`<&%R86T@
M)&5M86EL5&5X="!S=')I;F<@<VEN9VQE('-T<FEN9R!C;VYT86EN:6YG(&5M
M86EL(&%D9')E<W-S97,N"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&]F('!U<F4@
M96UA:6P@861D<F5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$=R;W5P
M16UA:6QS*"1E;6%I;%1E>'0I"B`@("!["B`@("`@("`@)')E<W5L="`]('!R
M96=?;6%T8VA?86QL*"(H7'=;+2Y?7'==*EQW0%QW6RTN7UQW72I<=UPN7'=[
M,BPS?2DB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96UA
M:6Q497AT+"`D;6%T8VAE<RD["@H@("`@("`@(')E='5R;B`D;6%T8VAE<ULP
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!T:&4@<V5A<F-H(&-R
M:71E<FEA+"!R97%U97-T<R!T:&4@:6YD:79I9'5A;"!S96%R8VAE<R!F<F]M
M('1H90H@("`@("H@<V5R=F5R(&%N9"!P97)F;W)M<R!A;GD@;F5C97-S87)Y
M($%.1',@+R!/4G,@;VX@=&AE(')E<W5L=',N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("`D8W)I=&5R:6$@($%R<F%Y(&-O;G1A:6YI;F<@=&AE('-E
M87)C:"!C<FET97)I82X*("`@("`J($!P87)A;2!S=')I;F<@)&=L=64@("`@
M("!4>7!E(&]F('-E87)C:"!T;R!P97)F;W)M("A!3D0@+R!/4BDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@8V]N=&%I;FEN9R!C;VYT
M86-T(&YA;65S('1H870@;6%T8V@@)&-R:71E<FEA+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9&]396%R8V@H)&-R:71E<FEA+"`D9VQU92D*("`@('L*("`@
M("`@("`D<F5S=6QT<R`](&%R<F%Y*"D["B`@("`@("`@)&YA;65S(#T@87)R
M87DH*3L*("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D
M=F%L<RD@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86QS6R=/4B==*2D@
M>PH@("`@("`@("`@("`@("`@)')E<W5L='-;72`]("1T:&ES+3Y?9&]396%R
M8V@H)'9A;'-;)T]2)UTL("=/4B<I.PH@("`@("`@("`@("!](&5L<V5I9B`H
M(65M<'1Y*"1V86QS6R=!3D0G72DI('L*("`@("`@("`@("`@("`@("1R97-U
M;'1S6UT@/2`D=&AI<RT^7V1O4V5A<F-H*"1V86QS6R=!3D0G72P@)T%.1"<I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@268@
M=V4@87)E(&AE<F4L(&%N9"!W92!H879E(&$@6R=F:65L9"==('1H96X@=V4*
M("`@("`@("`@("`@("`@("`J(&UU<W0@96ET:&5R(&1O('1H92`G04Y$)R!O
M<B!T:&4@)T]2)R!S96%R8V@N("HO"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'9A;'-;)V9I96QD)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)')E
M<W5L='-;72`]("1T:&ES+3Y?<V5N9%-E87)C:"@D=F%L<RD["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1V86QS(&%S("1T97-T*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)'1E<W1;)T]2)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5S=6QT<UM=(#T@)'1H:7,M/E]D;U-E87)C:"@D=&5S=%LG
M3U(G72P@)T]2)RD["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("@A96UP='DH)'1E<W1;)T%.1"==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<W5L='-;72`]("1T:&ES+3Y?9&]396%R8V@H)'1E<W1;
M)T%.1"==+"`G04Y$)RD["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT<UM=(#T@
M)'1H:7,M/E]D;U-E87)C:"AA<G)A>2@D=&5S="DL("1G;'5E*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*"1G;'5E(#T]("=!3D0G*2!["B`@("`@("`@("`@("1N86UE<R`]
M("1T:&ES+3Y?9V5T1'5P;&EC871E9"@D<F5S=6QT<RD["B`@("`@("`@?2!E
M;'-E:68@*"1G;'5E(#T]("=/4B<I('L*("`@("`@("`@("`@)&YA;65S(#T@
M)'1H:7,M/E]R96UO=F5$=7!L:6-A=&5D*"1R97-U;'1S*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D;F%M97,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!396YD<R!A('-E87)C:"!R97%U97-T('1O('1H92!S97)V97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<FET97)I82`@07)R87D@8V]N=&%I
M;FEN9R!T:&4@<V5A<F-H(&-R:71E<F$N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@07)R87D@8V]N=&%I;FEN9R!A(&QI<W0@;V8@;F%M97,@=&AA
M="!M871C:"!T:&4@<V5A<F-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5N
M9%-E87)C:"@D8W)I=&5R:6$I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF
M.PH@("`@("`@("1N86UE<R`]("<G.PH@("`@("`@("1I;7-P4V5A<F-H(#T@
M87)R87DH*3L*("`@("`@("`D<V5A<F-H:V5Y(#T@)&-R:71E<FEA6R=F:65L
M9"==.PH@("`@("`@("1S96%R8VAV86P@/2`D8W)I=&5R:6%;)W1E<W0G73L*
M("`@("`@("`D<V5A<F-H;W`@/2`D8W)I=&5R:6%;)V]P)UT["B`@("`@("`@
M)&AA<TYA;64@/2!F86QS93L*("`@("`@("`D=&AI<RT^7VYO1W)O=7!S(#T@
M9F%L<V4["B`@("`@("`@)&-A8VAE(#T@)DAO<F1E7T-A8VAE.CIS:6YG;&5T
M;VXH)&-O;F9;)V-A8VAE)UU;)V1R:79E<B==+"!(;W)D93HZ9V5T1')I=F5R
M0V]N9FEG*"=C86-H92<L("1C;VYF6R=C86-H92==6R=D<FEV97(G72DI.PH@
M("`@("`@("1K97D@/2!I;7!L;V1E*"(N(BP@87)R87E?;65R9V4H)&-R:71E
M<FEA+"!A<G)A>2@D=&AI<RT^7V)O;VM.86UE*2DI.PH*("`@("`@("`O*B!.
M;W<@;6%K92!S=7)E('=E(&%R96XG="!S96%R8VAI;F<@;VX@82!D>6YA;6EC
M86QL>2!C<F5A=&5D"B`@("`@("`@("H@9FEE;&0N("HO"B`@("`@("`@<W=I
M=&-H("@D<V5A<F-H:V5Y*2!["B`@("`@("`@8V%S92`G9G5L;&YA;64G.@H@
M("`@("`@("`@("!I9B`H(21H87-.86UE*2!["B`@("`@("`@("`@("`@("`D
M<V5A<F-H:V5Y(#T@)VYA;64G.PH@("`@("`@("`@("`@("`@)&AA<TYA;64@
M/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'-E87)C:&ME>2`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=?7V]W;F5R)SH*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^<&%R86US6R=C;VYT86-T7V]W;F5R<VAI<"==*2!["B`@("`@
M("`@("`@("`@("`D<V5A<F-H:V5Y(#T@)R<["B`@("`@("`@("`@("`@("`D
M:&%S3F%M92`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("`O*B!!<F4@=V4@<V5A<F-H:6YG(&9O
M<B!O;FQY(%1U<F)A7T]B:F5C=%]'<F]U<',@;W(@5'5R8F%?3V)J96-T<S\*
M("`@("`@("`@*B!4:&ES(&ES(&YE961E9"!S;R!T:&4@)U-H;W<@3&ES=',G
M(&%N9"`G4VAO=R!#;VYT86-T<R<*("`@("`@("`@*B!L:6YK<R!W;W)K(&-O
M<G)E8W1L>2!I;B!4=7)B82X@*B\*("`@("`@("!I9B`H)'-E87)C:&ME>2`]
M/2`G7U]T>7!E)RD@>PH@("`@("`@("`@("!S=VET8V@@*"1S96%R8VAV86PI
M('L*("`@("`@("`@("`@8V%S92`G1W)O=7`G.@H@("`@("`@("`@("`@("`@
M)'-E87)C:&ME>2`]("1T:&ES+3Y?9W)O=7!&:65L9#L*("`@("`@("`@("`@
M("`@("1S96%R8VAV86P@/2`D=&AI<RT^7V=R;W5P5F%L=64["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T]B:F5C="<Z"B`@
M("`@("`@("`@("`@("!I9B`H(21H87-.86UE*2!["B`@("`@("`@("`@("`@
M("`@("`@)'-E87)C:&ME>2`]("=N86UE)SL*("`@("`@("`@("`@("`@("`@
M("`D<V5A<F-H=F%L(#T@)R<["B`@("`@("`@("`@("`@("`@("`@)&AA<TYA
M;64@/2!T<G5E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D<V5A<F-H:V5Y(#T@)R<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VYO1W)O=7!S(#T@=')U93L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H(21S96%R8VAK97D@/3T@)R<I('L*("`@("`@("`@("`@
M+R\@0VAE8VL@)'-E87)C:'9A;"!F;W(@8V]N=&5N="!A;F0@9F]R('-T<FEC
M="!M871C:&5S+@H@("`@("`@("`@("!I9B`H<W1R;&5N*"1S96%R8VAV86PI
M(#X@,"`I('L*("`@("`@("`@("`@("`@(&EF("@D<V5A<F-H;W`@/3T@)TQ)
M2T4G*2!["B`@("`@("`@("`@("`@("`@("`@)'-E87)C:'9A;"`]("<J)R`N
M("1S96%R8VAV86P@+B`G*B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V5A<F-H=F%L(#T@)RHG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I;7-P4V5A<F-H6R1S96%R
M8VAK97E=(#T@)'-E87)C:'9A;#L*("`@("`@("!]"B`@("`@("`@:68@*"%C
M;W5N="@D:6US<%-E87)C:"DI('L*("`@("`@("`@("`@)&EM<W!396%R8VA;
M)VYA;64G72`]("<J)SL*("`@("`@("!]"@H@("`@("`@("\J($9I;F%L;'D@
M9V5T('1O('1H92!C;VUM86YD+B`@0VAE8VL@=&AE(&-A8VAE(&9I<G-T+"!S
M:6YC92!E86-H("=4=7)B82<*("`@("`@("`@("!S96%R8V@@;6%Y(&-O;G-I
M<W0@;V8@82!N=6UB97(@;V8@:61E;G1I8V%L($E-4U`@<V5A<F-H861D<F5S
M<R!C86QL<R!I;@H@("`@("`@("`@(&]R9&5R(&9O<B!T:&4@04Y$(&%N9"!/
M4B!P87)T<R!T;R!W;W)K(&-O<G)E8W1L>2X@(#$U(%-E8V]N9"!L:69E=&EM
M90H@("`@("`@("`@('-H;W5L9"!B92!R96%S;VYA8FQE(&9O<B!T:&ES+B!4
M:&ES('-H;W5L9"!R961U8V4@;&]A9"!O;B!)35-0('-E<G9E<@H@("`@("`@
M("`@('-O;65W:&%T+BHO"B`@("`@("`@)')E<W5L=',@/2`D8V%C:&4M/F=E
M="@D:V5Y+"`Q-2D["@H@("`@("`@(&EF("@D<F5S=6QT<RD@>PH@("`@("`@
M("`@("`D;F%M97,@/2!E>'!L;V1E*"<L)RP@)')E<W5L=',I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"$D;F%M97,I('L*("`@("`@("`@("`@)&YA;65S
M(#T@)'1H:7,M/E]I;7-P+3YS96%R8V@H)'1H:7,M/E]B;V]K3F%M92P@)&EM
M<W!396%R8V@I.PH@("`@("`@("`@("!I9B`H:7-?82@D;F%M97,L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC
M871I;VXG72T^<'5S:"@D;F%M97,L("=H;W)D92YE<G)O<B<I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-A8VAE+3YS970H)&ME
M>2P@:6UP;&]D92@B+"(L("1N86UE<RDI.PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1N86UE<SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D;F%M97,["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!O;FQY('1H;W-E(&YA;65S('1H870@87)E
M(&1U<&QI8V%T960@:6X@)&YA;65S"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1N86UE<R`@02!N97-T960@87)R87D@;V8@87)R87ES(&-O;G1A:6YI
M;F<@;F%M97,*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!C
M;VYT86EN:6YG('1H92`G04Y$)R!O9B!A;&P@87)R87ES(&EN("1N86UE<PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T1'5P;&EC871E9"@D;F%M97,I"B`@
M("!["B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@("1M871C
M:&5D(#T@87)R87DH*3L*("`@("`@("`O*B!)9B!T:&5R92!I<R!O;FQY(#$@
M87)R87DL('-I;7!L>2!R971U<FX@:70N("HO"B`@("`@("`@:68@*&-O=6YT
M*"1N86UE<RD@/"`R*2!["B`@("`@("`@("`@(')E='5R;B`D;F%M97-;,%T[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)&YA;65S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)')E
M<W5L=',@/2!A<G)A>5]M97)G92@D<F5S=6QT<RP@)&YA;65S6R1I72D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'-E87)C:"`](&%R<F%Y7V-O=6YT
M7W9A;'5E<R@D<F5S=6QT<RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1S96%R
M8V@@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@D
M=F%L=64@/B`Q*2!["B`@("`@("`@("`@("`@("`@("`@)&UA=&-H961;72`]
M("1K97D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;6%T8VAE9#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@86X@87)R87D@=VET:"!A;&P@9'5P;&EC871E(&YA
M;65S(')E;6]V960N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1N86UE
M<R`@3F5S=&5D(&%R<F%Y(&]F(&%R<F%Y<R!C;VYT86EN:6YG(&YA;65S+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&-O;G1A:6YG('1H
M92`G3U(G(&]F(&%L;"!A<G)A>7,@:6X@)&YA;65S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<F5M;W9E1'5P;&EC871E9"@D;F%M97,I"B`@("!["B`@("`@
M("`@)'5N86UE<R`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)&YA;65S*3L@)&DK*RD@>PH@("`@("`@("`@("`D=6YA;65S
M(#T@87)R87E?;65R9V4H)'5N86UE<RP@)&YA;65S6R1I72D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!A<G)A>5]U;FEQ=64H)'5N86UE<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@=&AE(&-U<G)E;G0@=7-E<B!H
M87,@=&AE(')E<75E<W1E9"!P97)M:7-S:6]N"B`@("`@*B!O;B!T:&ES('-O
M=7)C92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;2`@5&AE
M('!E<FUI<W-I;VX@=&\@8VAE8VL@9F]R+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@=')U92!I9B!U<V5R(&AA<R!P97)M:7-S:6]N+"!F86QS
M92!O=&AE<G=I<V4N"B`@("`@*B\*("`@("!F=6YC=&EO;B!H87-097)M:7-S
M:6]N*"1P97)M*0H@("`@('L*("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&5R
M;7,@)B`D<&5R;3L*("`@("!]"@H@("`@("\J*@H@("`@("`J($-O;G9E<G1S
M(&%N(&%C;"!S=')I;F<@=&\@82!(;W)D92!097)M:7-S:6]N<R!B:71M87-K
M+@H@("`@("`J"B`@("`@("H@0'!A<F%M('-T<FEN9R`D86-L("!!('-T86YD
M87)D+"!)34%0('-T>6QE(&%C;"!S=')I;F<N"B`@("`@("H*("`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@($AO<F1E(%!E<FUI<W-I;VYS(&)I=&UA<VLN"B`@
M("`@("HO"B`@("`@9G5N8W1I;VX@7V%C;%1O2&]R9&5097)M<R@D86-L*0H@
M("`@('L*("`@("`@("`@)&A097)M<R`](#`["B`@("`@("`@(&EF("AS=')P
M;W,H)&%C;"P@)W<G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("1H4&5R
M;7,@?#T@4$5235-?141)5#L*("`@("`@("`@?0H@("`@("`@("!I9B`H<W1R
M<&]S*"1A8VPL("=R)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`D:%!E
M<FUS('P](%!%4DU37U)%040["B`@("`@("`@('T*("`@("`@("`@:68@*'-T
M<G!O<R@D86-L+"`G9"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@)&A0
M97)M<R!\/2!015)-4U]$14Q%5$4["B`@("`@("`@('T*("`@("`@("`@:68@
M*'-T<G!O<R@D86-L+"`G;"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M)&A097)M<R!\/2!015)-4U]32$]7.PH@("`@("`@("!]"B`@("`@("`@(')E
M='5R;B`D:%!E<FUS.PH@("`@('T*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T=7)B82]L:6(O1')I=F5R+VYU;&PN<&AP````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S<T`#$P-#$W,S8R-S4V
M`#`R,3(S-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@3G5L;"!4=7)B82!D:7)E8W1O<GD@9')I=F5R
M+@H@*@H@*B`D2&]R9&4Z('1U<F)A+VQI8B]$<FEV97(O;G5L;"YP:'`L=B`Q
M+C(N,BXQ(#(P,#4O,3$O,3`@,#`Z,#(Z-#`@;61J=6MI8R!%>'`@)`H@*@H@
M*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UD:G5K:6-`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!4=7)B82`R+C(*("H@0'!A8VMA9V4@5'5R8F$*("HO"F-L
M87-S(%1U<F)A7T1R:79E<E]N=6QL(&5X=&5N9',@5'5R8F%?1')I=F5R('L*
M"B`@("`O*BH*("`@("`J(%=H971H97(@=&AI<R!S;W5R8V4@:&%S(&$@<F5A
M9&]N;'D@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@
M("HO"B`@("!V87(@)')E861O;FQY(#T@=')U93L*"B`@("`O*BH*("`@("`J
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET*"D*("`@('L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!T
M:&4@8W5R<F5N="!U<V5R(&AA<R!T:&4@<F5Q=65S=&5D('!E<FUI<W-I;VYS
M(&]N('1H:7,*("`@("`J('-O=7)C92X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<&5R;2`@5&AE('!E<FUI<W-I;VX@=&\@8VAE8VL@9F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@=7-E
M<B!H87,@<&5R;6ES<VEO;BP@;W1H97)W:7-E(&9A;'-E+@H@("`@("HO"B`@
M("`@9G5N8W1I;VX@:&%S4&5R;6ES<VEO;B@D<&5R;2D*("`@("!["B`@("`@
M("`@('-W:71C:"`H)'!E<FTI('L*("`@("`@("`@("`@(&-A<V4@4$5235-?
M141)5#H@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@8V%S92!015)-4U]$
M14Q%5$4Z(')E='5R;B!F86QS93L*("`@("`@("`@("`@(&1E9F%U;'0Z(')E
M='5R;B!T<G5E.PH@("`@("`@("!]"B`@("`@?0H*("`@(&9U;F-T:6]N(%]S
M96%R8V@H*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E-E87)C:&EN9R!I<R!N;W0@879A:6QA8FQE+B(I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5A9"@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B4F5A9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA
M8FQE+B(I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?861D*"1A='1R:6)U=&5S
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%D
M9&EN9R!C;VYT86-T<R!I<R!N;W0@879A:6QA8FQE+B(I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?9&5L971E*"1O8FIE8W1?:V5Y+"`D;V)J96-T7VED*0H@
M("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D1E;&5T
M:6YG(&-O;G1A8W1S(&ES(&YO="!A=F%I;&%B;&4N(BDI.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]S879E*"1O8FIE8W1?:V5Y+"`D;V)J96-T7VED+"`D871T
M<FEB=71E<RD*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")3879I;F<@8V]N=&%C=',@:7,@;F]T(&%V86EL86)L92XB*2D["B`@
M("!]"@I]"@`````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQI
M8B]";&]C:R\`````````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-38`,#$W,S0T`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$V,``Q,#0Q-S,V,C<U-@`P,C(Q
M-S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B0V]N=&%C="!396%R8V@B*3L*"B\J
M*@H@*B!4=7)B85]-:6YI<V5A<F-H7T)L;V-K.CH@26UP;&5M96YT871I;VX@
M;V8@=&AE($AO<F1E7T)L;V-K($%022!T;PH@*B!A;&QO=W,@<V5A<F-H:6YG
M(&]F(&%D9')E<W-B;V]K<R!F<F]M('1H92!P;W)T86PN"B`J"B`J("1(;W)D
M93H@='5R8F$O;&EB+T)L;V-K+VUI;FES96%R8V@N<&AP+'8@,2XQ-RXR+C,@
M,C`P-B\P,2\P,R`R,#HU,#HQ."!C:'5C:R!%>'`@)`H@*@H@*B!`<&%C:V%G
M92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?='5R8F%?;6EN
M:7-E87)C:"!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@
M/2`G='5R8F$G.PH*("`@("\J*@H@("`@("H@5&AE('1I=&QE('1O(&=O(&EN
M('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4
M:&4@=&ET;&4@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W1I=&QE*"D*
M("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("!R971U
M<FX@2&]R9&4Z.FQI;FLH2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E=$EN:71I
M86Q086=E*"DL('1R=64I*2`N(%\H(D-O;G1A8W0@4V5A<F-H(BD@+B`G/"]A
M/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@
M5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E<BP@)')E9VES=')Y+"`D<')E
M9G,["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B]B87-E+G!H<"<["@H@("`@("`@(&EF("@D8G)O=W-E<BT^:&%S1F5A
M='5R92@G:69R86UE<R<I*2!["B`@("`@("`@("`@(')E='5R;B!5=&EL.CIB
M=69F97)/=71P=70H)VEN8VQU9&4G+"!455)"05]414U03$%415,@+B`G+V)L
M;V-K+VUI;FES96%R8V@N:6YC)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("<\96T^)R`N(%\H(D$@8G)O=W-E<B!T:&%T('-U<'!O
M<G1S(&E&<F%M97,@:7,@<F5Q=6ER960B*2`N("<\+V5M/B<["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L:6(O0FQO
M8VLO=')E95]M96YU+G!H<```````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S-C`V`#$P-#$W,S8R-S4V`#`R,C`T,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*)&)L;V-K7VYA;64@/2!?
M*")-96YU($QI<W0B*3L*)&)L;V-K7W1Y<&4@/2`G=')E92<["@HO*BH*("H@
M)$AO<F1E.B!T=7)B82]L:6(O0FQO8VLO=')E95]M96YU+G!H<"QV(#$N-2XR
M+C$@,C`P-2\Q,"\Q."`Q,CHU,#HP-2!J86X@17AP("0*("H*("H@0'!A8VMA
M9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7W1U<F)A7W1R
M965?;65N=2!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@
M/2`G='5R8F$G.PH*("`@(&9U;F-T:6]N(%]B=6EL9%1R964H)B1T<F5E+"`D
M:6YD96YT(#T@,"P@)'!A<F5N="`](&YU;&PI"B`@("!["B`@("`@("`@9VQO
M8F%L("1R96=I<W1R>3L*"B`@("`@("`@9&5F:6YE*"=455)"05]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["B`@("`@("`@<F5Q=6ER
M95]O;F-E(%154D)!7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@H@("`@("`@
M("1B<F]W<V4@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V)R;W=S92YP:'`G
M*3L*("`@("`@("`D:6-O;F1I<B`]("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M*2`N("<O;65N=2<["@H@("`@("`@("1T<F5E+3YA9&1.;V1E*"1P87)E;G0@
M+B`G7U]N97<G+`H@("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0L"B`@
M("`@("`@("`@("`@("`@("`@("`@7R@B3F5W($-O;G1A8W0B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`D:6YD96YT("L@,2P*("`@("`@("`@("`@("`@
M("`@("`@("!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M:6-O;B<@/3X@)VYE=RYP;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=I8V]N9&ER)R`]/B`D:6-O;F1I<BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=7)L)R`]/B!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D
M9"YP:'`G*2DI.PH*("`@("`@("!F;W)E86-H("A4=7)B83HZ9V5T061D<F5S
M<T)O;VMS*"D@87,@)&%D9')E<W-B;V]K(#T^("1C;VYF:6<I('L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D8V]N9FEG6R=B<F]W<V4G72DI('L*("`@("`@
M("`@("`@("`@("1T<F5E+3YA9&1.;V1E*"1P87)E;G0@+B`D861D<F5S<V)O
M;VLL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R96YT+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9I9ULG=&ET;&4G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F1E;G0@*R`Q
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6-O;B<@/3X@)V)R
M;W=S92YP;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VEC;VYD:7(G(#T^("1I8V]N9&ER+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@571I;#HZ861D4&%R86UE=&5R
M*"1B<F]W<V4L(&%R<F%Y*"=S;W5R8V4G(#T^("1A9&1R97-S8F]O:RDI*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T<F5E+3YA9&1.
M;V1E*"1P87)E;G0@+B`G7U]S96%R8V@G+`H@("`@("`@("`@("`@("`@("`@
M("`@("1P87)E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@7R@B4V5A<F-H
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@)&EN9&5N="`K(#$L"B`@("`@
M("`@("`@("`@("`@("`@("`@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)VEC;VXG(#T^("=S96%R8V@N<&YG)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:6-O;F1I<B<@/3X@)')E9VES=')Y+3YG971)
M;6%G941I<B@G:&]R9&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=7)L)R`]/B!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E87)C:"YP:'`G
M*2DI.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&EB+T]B:F5C="\`
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<U-@`P,3<U,C``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M=7)B82]L:6(O3V)J96-T+T=R;W5P+G!H<```````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$S-#(R`#$P-#$W,S8R-S4V`#`R,3,R-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E(%154D)!7T)!4T4@+B`G+VQI8B]/8FIE8W0N<&AP)SL*"B\J
M*@H@*B!4:&4@5'5R8F%?3V)J96-T7T=R;W5P.CH@8VQA<W,@<')O=FED97,@
M82!S970@;V8@;65T:&]D<R!F;W(@9&5A;&EN9R!W:71H"B`J(&-O;G1A8W0@
M9W)O=7!S+@H@*@H@*B`D2&]R9&4Z('1U<F)A+VQI8B]/8FIE8W0O1W)O=7`N
M<&AP+'8@,2XY+C(N,B`R,#`U+S$Q+S$T(#(Q.C`S.C(W(&UR=6)I;G-K($5X
M<"`D"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`8W-H+G)I="YE
M9'4^"B`J($!P86-K86=E(%1U<F)A"B`J+PIC;&%S<R!4=7)B85]/8FIE8W1?
M1W)O=7`@97AT96YD<R!4=7)B85]/8FIE8W0@>PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!4=7)B85]/8FIE8W1?1W)O=7`N"B`@("`@*@H@
M("`@("H@0'!A<F%M(%1U<F)A7T1R:79E<B`D9')I=F5R("!4:&4@9')I=F5R
M(&]B:F5C="!T:&%T('1H:7,@9W)O=7`@8V]M97,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9G)O;2X*("`@("`J($!P87)A;2!A<G)A
M>2`D871T<FEB=71E<R`@("`@2&%S:"!O9B!A='1R:6)U=&5S(&9O<B!T:&ES
M(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!4=7)B85]/8FIE8W1?1W)O
M=7`H)B1D<FEV97(L("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!P87)E;G0Z.E1U<F)A7T]B:F5C="@D9')I=F5R+"`D871T<FEB=71E
M<RD["B`@("`@("`@)'1H:7,M/F%T=')I8G5T97-;)U]?='EP92==(#T@)T=R
M;W5P)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!I9B!T
M:&ES(&]B:F5C="!I<R!A(&=R;W5P(&]F(&UU;'1I<&QE(&-O;G1A8W1S+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-'<F]U<"@I"B`@("!["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;F5W(&-O;G1A8W0@
M96YT<GD@=&\@=&AI<R!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C;VYT86-T260@(%1H92!I9"!O9B!T:&4@8V]N=&%C="!T;R!A9&0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S;W5R8V5)9"`@(%1H92!S;W5R8V4@
M)&-O;G1A8W1)9"!I<R!F<F]M+@H@("`@("H*("`@("`J($!S:6YC92!4=7)B
M82`Q+C(*("`@("`J+PH@("`@9G5N8W1I;VX@861D365M8F5R*"1C;VYT86-T
M260L("1S;W5R8V5)9"`](&YU;&PI"B`@("!["B`@("`@("`@+R\@1&5F875L
M="!T;R!T:&4@<V%M92!S;W5R8V4@87,@=&AE(&=R;W5P+@H@("`@("`@(&EF
M("AI<U]N=6QL*"1S;W5R8V5)9"DI('L*("`@("`@("`@("`@)'-O=7)C94ED
M(#T@)'1H:7,M/F=E=%-O=7)C92@I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M0V%N)W0@861D(&$@9W)O=7`@=&\@:71S96QF+@H@("`@("`@(&EF("@D8V]N
M=&%C=$ED(#T]("1T:&ES+3YA='1R:6)U=&5S6R=?7VME>2==*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;B=T(&%D9"!A
M(&=R;W5P('1O(&ET<V5L9BXB*2D["B`@("`@("`@?0H*("`@("`@("`O+R!4
M<GD@=&\@9FEN9"!T:&4@8V]N=&%C="!B96EN9R!A9&1E9"X*("`@("`@("!I
M9B`H)'-O=7)C94ED(#T]("1T:&ES+3YG9713;W5R8V4H*2D@>PH@("`@("`@
M("`@("`D8V]N=&%C="`]("1T:&ES+3YD<FEV97(M/F=E=$]B:F5C="@D8V]N
M=&%C=$ED*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9')I=F5R
M(#T@)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1S;W5R8V5)9"D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1D<FEV97(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D9')I=F5R.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1C;VYT86-T(#T@)&1R:79E<BT^9V5T3V)J96-T*"1C;VYT
M86-T260I.PH@("`@("`@('T*"B`@("`@("`@+R\@0F%I;"!O=70@:68@=&AE
M(&-O;G1A8W0@8F5I;F<@861D960@9&]E<VXG="!E>&ES="!O<B!C86XG=`H@
M("`@("`@("\O(&)E(')E=')I979E9"X*("`@("`@("!I9B`H:7-?82@D8V]N
M=&%C="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O
M;G1A8W0["B`@("`@("`@?0H*("`@("`@("`O+R!%>'!L;V1E(&UE;6)E<G,N
M"B`@("`@("`@)&UE;6)E<G,@/2!`=6YS97)I86QI>F4H)'1H:7,M/F%T=')I
M8G5T97-;)U]?;65M8F5R<R==*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1M
M96UB97)S*2D@>PH@("`@("`@("`@("`D;65M8F5R<R`](&%R<F%Y*"D["B`@
M("`@("`@?0H*("`@("`@("`O+R!)9B!T:&4@8V]N=&%C="!I<R!F<F]M(&$@
M9&EF9F5R96YT('-O=7)C92P@<W1O<F4@:71S('-O=7)C90H@("`@("`@("\O
M(&ED(&%S('=E;&PN"B`@("`@("`@:68@*"1S;W5R8V5)9"`]/2`D=&AI<RT^
M9V5T4V]U<F-E*"DI('L*("`@("`@("`@("`@)&UE;6)E<G-;72`]("1C;VYT
M86-T260["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UE;6)E<G-;
M72`]("1S;W5R8V5)9"`N("<Z)R`N("1C;VYT86-T260["B`@("`@("`@?0H*
M("`@("`@("`O+R!296UO=F4@9'5P;&EC871E<RX*("`@("`@("`D;65M8F5R
M<R`](&%R<F%Y7W5N:7%U92@D;65M8F5R<RD["@H@("`@("`@("1T:&ES+3YA
M='1R:6)U=&5S6R=?7VUE;6)E<G,G72`]('-E<FEA;&EZ92@D;65M8F5R<RD[
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5L971E<R!A(&-O;G1A8W0@9G)O;2!T:&ES(&=R;W5P+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&-O;G1A8W1)9"`@5&AE(&ED(&]F('1H92!C
M;VYT86-T('1O(')E;6]V92X*("`@("`J($!P87)A;2!S=')I;F<@)'-O=7)C
M94ED("`@5&AE('-O=7)C92`D8V]N=&%C=$ED(&ES(&9R;VTN"B`@("`@*@H@
M("`@("H@0'-I;F-E(%1U<F)A(#$N,@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96UO=F5-96UB97(H)&-O;G1A8W1)9"P@)'-O=7)C94ED(#T@;G5L;"D*("`@
M('L*("`@("`@("`D;65M8F5R<R`]($!U;G-E<FEA;&EZ92@D=&AI<RT^871T
M<FEB=71E<ULG7U]M96UB97)S)UTI.PH*("`@("`@("!I9B`H:7-?;G5L;"@D
M<V]U<F-E260I('Q\("1S;W5R8V5)9"`]/2`D=&AI<RT^9V5T4V]U<F-E*"DI
M('L*("`@("`@("`@("`@)&D@/2!A<G)A>5]S96%R8V@H)&-O;G1A8W1)9"P@
M)&UE;6)E<G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I(#T@
M87)R87E?<V5A<F-H*"1S;W5R8V5)9"`N("<Z)R`N("1C;VYT86-T260L("1M
M96UB97)S*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D:2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@=6YS970H)&UE;6)E<G-;)&E=*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3YA='1R:6)U=&5S6R=?7VUE;6)E<G,G72`]('-E
M<FEA;&EZ92@D;65M8F5R<RD["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE($]B:F5C=',@:6X@=&AI
M<R!G<F]U<`H@("`@("H*("`@("`J($!P87)A;2`D<V]R=%]C<FET97)I82`@
M("`@5&AE(')E<75E<W1E9"!S;W)T(&]R9&5R('=H:6-H(&ES('!A<W-E9"!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!4=7)B85],:7-T
M.CIS;W)T*"DN"B`@("`@*@H@("`@("H@0'!A<F%M("1S;W)T7V1I<F5C=&EO
M;B`@("!4:&4@<F5Q=65S=&5D('-O<G0@9&ER96-T:6]N('=H:6-H(&ES('!A
M<W-E9"!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!4=7)B
M85],:7-T.CIS;W)T*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!4=7)B85],
M:7-T("`@("`@("!,:7-T(&-O;G1A:6YI;F<@=&AE(&UE;6)E<G,@;V8@=&AI
M<R!G<F]U<`H@("`@("H*("`@("`J($!S:6YC92!4=7)B82`Q+C(*("`@("`J
M+PH@("`@9G5N8W1I;VX@)FQI<W1-96UB97)S*"1S;W)T7V-R:71E<FEA(#T@
M)VQA<W1N86UE)RP@)'-O<G1?9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+TQI<W0N<&AP)SL*
M("`@("`@("`D;&ES="`]("9N97<@5'5R8F%?3&ES="@I.PH*("`@("`@("`D
M8VAI;&1R96X@/2!U;G-E<FEA;&EZ92@D=&AI<RT^871T<FEB=71E<ULG7U]M
M96UB97)S)UTI.PH@("`@("`@(&EF("@A:7-?87)R87DH)&-H:6QD<F5N*2D@
M>PH@("`@("`@("`@("`D8VAI;&1R96X@/2!A<G)A>2@I.PH@("`@("`@('T*
M"B`@("`@("`@<F5S970H)&-H:6QD<F5N*3L*("`@("`@("`D;6]D:69I960@
M/2!F86QS93L*("`@("`@("!F;W)E86-H("@D8VAI;&1R96X@87,@)&UE;6)E
M<BD@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1M96UB97(L("<Z)RD@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D8V]N=&%C="`]("1T:&ES+3YD
M<FEV97(M/F=E=$]B:F5C="@D;65M8F5R*3L*("`@("`@("`@("`@("`@(&EF
M("AI<U]A*"1C;VYT86-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@4F5M;W9E('1H92!C;VYT86-T(&EF(&ET(&YO(&QO;F=E
M<B!E>&ES=',*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<F5M;W9E365M
M8F5R*"1M96UB97(I.PH@("`@("`@("`@("`@("`@("`@("1M;V1I9FEE9"`]
M('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!L:7-T*"1S;W5R8V5)9"P@)&-O;G1A8W1)9"D@
M/2!E>'!L;V1E*"<Z)RP@)&UE;6)E<BP@,BD["B`@("`@("`@("`@("`@("!I
M9B`H<W1R<&]S*"1C;VYT86-T260L("<Z)RDI('L*("`@("`@("`@("`@("`@
M("`@("!L:7-T*"1O=VYE<BP@)&-O;G1A8W1)9"D@/2!E>'!L;V1E*"<Z)RP@
M)&-O;G1A8W1)9"P@,BD["B`@("`@("`@("`@("`@("`@("`@)'-O=7)C94ED
M("X]("<Z)R`N("1O=VYE<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1D<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS:6YG;&5T;VXH)'-O
M=7)C94ED*3L*("`@("`@("`@("`@("`@("\O($1O;B=T('!R=6YE(&-O;G1A
M8W1S(&EF('1H92!S;W5R8V4@:7,@;F]T"B`@("`@("`@("`@("`@("`O+R!F
M;W5N9"P@8V]U;&0@:G5S="!B92!T96UP;W)A<FEL>2!U;F%V86EL86)L92X*
M("`@("`@("`@("`@("`@(&EF("@A:7-?82@D9')I=F5R+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&-O;G1A8W0@/2`D9')I=F5R
M+3YG971/8FIE8W0H)&-O;G1A8W1)9"D["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)&-O;G1A8W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@4F5M;W9E('1H92!C;VYT86-T(&EF(&ET(&YO
M(&QO;F=E<B!E>&ES=',*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G)E;6]V94UE;6)E<B@D8V]N=&%C=$ED+"`D<V]U<F-E260I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;6]D:69I960@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1L:7-T+3YI;G-E<G0H)&-O;G1A8W0I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@268@=V4G=F4@<')U;F5D(&%N>2!D
M96%D(&5N=')I97,L('-T;W)E('1H92!C:&%N9V5S+@H@("`@("`@(&EF("@D
M;6]D:69I960I('L*("`@("`@("`@("`@)'1H:7,M/G-T;W)E*"D["B`@("`@
M("`@?0H*("`@("`@("`D;&ES="T^<V]R="@D<V]R=%]C<FET97)I82P@)'-O
M<G1?9&ER96-T:6]N*3L*("`@("`@("!R971U<FX@)&QI<W0["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A
M+VQI8B\N:'1A8V-E<W,`````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,38`,3`T,3<S-C(W-38`,#(P,3`R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$1E;GD@9G)O;2!A;&P*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]L:6(O1W)O=7`N
M<&AP````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q
M,C(S`#$P-#$W,S8R-S4V`#`R,#$Q,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(%154D)!
M7T)!4T4@+B`G+VQI8B]!8G-T<F%C=$]B:F5C="YP:'`G.PH*+RHJ"B`J(%1H
M92!4=7)B85]'<F]U<#HZ(&-L87-S('!R;W9I9&5S(&$@<V5T(&]F(&UE=&AO
M9',@9F]R(&1E86QI;F<@=VET:`H@*B!C;VYT86-T(&=R;W5P<RX*("H*("H@
M)$AO<F1E.B!T=7)B82]L:6(O1W)O=7`N<&AP+'8@,2XR,RXQ,"XR(#(P,#4O
M,#8O,#<@,#8Z,C$Z,34@<V5L<VMY($5X<"`D"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!J
M;VX@4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^"B`J($!S:6YC92`@(%1U<F)A
M(#`N,"XQ"B`J($!P86-K86=E(%1U<F)A"B`J+PIC;&%S<R!4=7)B85]'<F]U
M<"!E>'1E;F1S(%1U<F)A7T%B<W1R86-T3V)J96-T('L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=',@82!N97<@5'5R8F%?1W)O=7`@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!4=7)B85]$<FEV97(@)&1R:79E<B`@5&AE(&1R
M:79E<B!O8FIE8W0@=&AA="!T:&ES(&=R;W5P(&-O;65S"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&9R;VTN"B`@("`@*B!`<&%R86T@
M87)R87D@)&%T=')I8G5T97,@("`@($AA<V@@;V8@871T<FEB=71E<R!F;W(@
M=&AI<R!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@5'5R8F%?1W)O=7`H
M)B1D<FEV97(L("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D=&AI<RT^5'5R8F%?06)S=')A8W1/8FIE8W0H)&1R:79E<BP@)&%T=')I
M8G5T97,I.PH@("`@("`@("1T:&ES+3YA='1R:6)U=&5S6R=?7W1Y<&4G72`]
M("='<F]U<"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@
M:68@=&AI<R!O8FIE8W0@:7,@82!G<F]U<"!O9B!M=6QT:7!L92!C;VYT86-T
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES1W)O=7`H*0H@("`@>PH@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&YE=R!C;VYT
M86-T(&5N=')Y('1O('1H:7,@9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]N=&%C=$ED("!4:&4@:60@;V8@=&AE(&-O;G1A8W0@=&\@
M861D+@H@("`@("H*("`@("`J($!S:6YC92!4=7)B82`Q+C(*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D365M8F5R*"1C;VYT86-T260I"B`@("!["B`@("`@
M("`@+R\@0V%N)W0@861D(&ET<V5L9BX*("`@("`@("!I9B`H)&-O;G1A8W1)
M9"`A/2`D=&AI<RT^871T<FEB=71E<ULG7U]K97DG72D@>PH@("`@("`@("`@
M("`D8V]N=&%C="`]("1T:&ES+3YD<FEV97(M/F=E=$]B:F5C="@D8V]N=&%C
M=$ED*3L*("`@("`@("`@("`@:68@*&ES7V$H)&-O;G1A8W0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D8V]N=&%C=#L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&UE;6)E<G,@/2!`=6YS97)I86QI
M>F4H)'1H:7,M/F%T=')I8G5T97-;)U]?;65M8F5R<R==*3L*("`@("`@("`@
M("`@:68@*"%I<U]A<G)A>2@D;65M8F5R<RDI('L*("`@("`@("`@("`@("`@
M("1M96UB97)S(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D;65M8F5R<UM=(#T@)&-O;G1A8W0M/F=E=%9A;'5E*"=?7VME>2<I.PH*
M("`@("`@("`@("`@+R\@4F5M;W9E(&1U<&QI8V%T97,*("`@("`@("`@("`@
M)&UE;6)E<G,@/2!A<G)A>5]U;FEQ=64H)&UE;6)E<G,I.PH@("`@("`@("`@
M("`D=&AI<RT^871T<FEB=71E<ULG7U]M96UB97)S)UT@/2!S97)I86QI>F4H
M)&UE;6)E<G,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M;&5T97,@82!C;VYT86-T(&9R;VT@=&AI<R!G<F]U<"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VYT86-T260@(%1H92!I9"!O9B!T:&4@8V]N
M=&%C="!T;R!R96UO=F4N"B`@("`@*@H@("`@("H@0'-I;F-E(%1U<F)A(#$N
M,@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5-96UB97(H)&-O;G1A8W1)
M9"D*("`@('L*("`@("`@("`D;65M8F5R<R`]('5N<V5R:6%L:7IE*"1T:&ES
M+3YA='1R:6)U=&5S6R=?7VUE;6)E<G,G72D["@H@("`@("`@(&EF("@H)&D@
M/2!A<G)A>5]S96%R8V@H)&-O;G1A8W1)9"P@)&UE;6)E<G,I*2`A/3T@9F%L
M<V4I('L*("`@("`@("`@("`@=6YS970H)&UE;6)E<G-;)&E=*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YA='1R:6)U=&5S6R=?7VUE;6)E<G,G72`]
M('-E<FEA;&EZ92@D;65M8F5R<RD["B`@("`@("`@)'1H:7,M/G-T;W)E*"D[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V92!T:&4@3V)J96-T<R!I;B!T:&ES(&=R;W5P"B`@("`@*@H@("`@
M("H@0'!A<F%M("1S;W)T7V-R:71E<FEA("`@("!4:&4@<F5Q=65S=&5D('-O
M<G0@;W)D97(@=VAI8V@@:7,@<&%S<V5D('1O"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%1U<F)A7TQI<W0Z.G-O<G0H*2X*("`@("`J"B`@
M("`@*B!`<&%R86T@)'-O<G1?9&ER96-T:6]N("`@(%1H92!R97%U97-T960@
M<V]R="!D:7)E8W1I;VX@=VAI8V@@:7,@<&%S<V5D('1O"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%1U<F)A7TQI<W0Z.G-O<G0H*2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(%1U<F)A7TQI<W0@("`@("`@($QI<W0@8V]N
M=&%I;FEN9R!T:&4@;65M8F5R<R!O9B!T:&ES(&=R;W5P"B`@("`@*@H@("`@
M("H@0'-I;F-E(%1U<F)A(#$N,@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T
M365M8F5R<R@D<V]R=%]C<FET97)I82`]("=L87-T;F%M92<L("1S;W)T7V1I
M<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(%154D)!
M7T)!4T4@+B`G+VQI8B],:7-T+G!H<"<["B`@("`@("`@)&QI<W0@/2`F;F5W
M(%1U<F)A7TQI<W0H*3L*"B`@("`@("`@)&-H:6QD<F5N(#T@=6YS97)I86QI
M>F4H)'1H:7,M/F%T=')I8G5T97-;)U]?;65M8F5R<R==*3L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1C:&EL9')E;BDI('L*("`@("`@("`@("`@)&-H:6QD
M<F5N(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(')E<V5T*"1C:&EL
M9')E;BD["B`@("`@("`@9F]R96%C:"`H)&-H:6QD<F5N(&%S("1M96UB97(I
M('L*("`@("`@("`@("`@)&YE=TUE;6)E<B`]("1T:&ES+3YD<FEV97(M/F=E
M=$]B:F5C="@D;65M8F5R*3L*("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D
M;F5W365M8F5R*2D@>PH@("`@("`@("`@("`@("`@)&QI<W0M/FEN<V5R="@D
M;F5W365M8F5R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D
M;&ES="T^<V]R="@D<V]R=%]C<FET97)I82P@)'-O<G1?9&ER96-T:6]N*3L*
M"B`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5A<F-H97,@=&AE(&=R;W5P(&)A<V5D(&]N('1H92!P<F]V:61E9"!C<FET
M97)I82X*("`@("`J"B`@("`@*B!43T1/.B!!;&QO=R`D8W)I=&5R:6$@=&\@
M8V]N=&%I;B!T:&4@8V]M<&%R:7-O;B!O<&5R871O<B`H/"P@/2P@/BP*("`@
M("`J("`@("`@("=L:6ME)RD@86YD(&UO9&EF>2!T:&4@9')I=F5R<R!A8V-O
M<F1I;F=L>2X*("`@("`J"B`@("`@*B!`<&%R86T@)'-E87)C:%]C<FET97)I
M82`@($AA<V@@8V]N=&%I;FEN9R!T:&4@<V5A<F-H(&-R:71E<FEA+@H@("`@
M("H@0'!A<F%M("1S;W)T7V-R:71E<FEA("`@("!4:&4@<F5Q=65S=&5D('-O
M<G0@;W)D97(@=VAI8V@@:7,@<&%S<V5D('1O"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%1U<F)A7TQI<W0Z.G-O<G0H*2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%1U<F)A7TQI<W0@("`@("`@(%1H92!S;W)T960L(&9I
M;'1E<F5D(&QI<W0@;V8@<V5A<F-H(')E<W5L=',N"B`@("`@*@H@("`@("H@
M0'-I;F-E(%1U<F)A(#$N,@H@("`@("HO"B`@("!F=6YC=&EO;B!S96%R8V@H
M)'-E87)C:%]C<FET97)I82P@)'-O<G1?8W)I=&5R:6$@/2`G;&%S=&YA;64G
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92!455)"05]"05-%("X@)R]L
M:6(O3&ES="YP:'`G.PH@("`@("`@("1R97-U;'1S(#T@)FYE=R!4=7)B85],
M:7-T*"D["@H@("`@("`@("\J($=E="!A;&P@;65M8F5R<RX@*B\*("`@("`@
M("`D;65M8F5R<R`]("1T:&ES+3YL:7-T365M8F5R<R@D<V]R=%]C<FET97)I
M82D["@H@("`@("`@("1M96UB97)S+3YR97-E="@I.PH@("`@("`@('=H:6QE
M("@D;65M8F5R(#T@)&UE;6)E<G,M/FYE>'0H*2D@>PH@("`@("`@("`@("`D
M;6%T8V@@/2!T<G5E.PH@("`@("`@("`@("!F;W)E86-H("@D<V5A<F-H7V-R
M:71E<FEA(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&UE;6)E<BT^:&%S5F%L=64H)&ME>2DI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&UE;6)E<BT^9V5T5F%L=64H)&ME>2D@/3T@)'9A;'5E*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1M871C:"`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H)&UA=&-H*2!["B`@("`@("`@("`@("`@
M("`D<F5S=6QT<RT^:6YS97)T*"1M96UB97(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!2971U<FX@=&AE(&9I;'1E<F5D("AS;W)T
M960I(')E<W5L=',N("HO"B`@("`@("`@<F5T=7)N("1R97-U;'1S.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&EB
M+W9E<G-I;VXN<&AP````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`U-0`Q,#0Q-S,V,C<U-@`P,C`U,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`@9&5F:6YE*"=455)"
M05]615)324].)RP@)T@S("@R+C$I)RD@/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQI8B],:7-T5FEE=RYP
M:'``````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C0P,3$`
M,3`T,3<S-C(W-38`,#(P-38T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@5'5R8F%?3&ES=%9I
M97<Z.B!C;&%S<R!P<F]V:61E<R!A;B!I;G1E<F9A8V4@9F]R(&]B:F5C=',@
M=&AA=`H@*B!V:7-U86QI>F4@5'5R8F%?;&ES=',N"B`J"B`J("1(;W)D93H@
M='5R8F$O;&EB+TQI<W16:65W+G!H<"QV(#$N,3<N,3`N.2`R,#`U+S$R+S`X
M(#$X.C,V.C4Y(&UR=6)I;G-K($5X<"`D"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;VX@
M4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^"B`J($!P86-K86=E(%1U<F)A"B`J
M+PIC;&%S<R!4=7)B85],:7-T5FEE=R!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M5'5R8F%?3&ES="!O8FIE8W0@=&AA="!W92!A<F4@=FES=6%L:7II;F<N"B`@
M("`@*@H@("`@("H@0'9A<B!4=7)B85],:7-T"B`@("`@*B\*("`@('9A<B`D
M;&ES=#L*"B`@("`O*BH*("`@("`J(%1H92!H96%D97(@=&5M<&QA=&4N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1T96UP
M;&%T94AE861E<CL*"B`@("`O*BH*("`@("`J(%1H92!F;V]T97(@=&5M<&QA
M=&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1T96UP;&%T949O;W1E<CL*"B`@("`O*BH*("`@("`J(%1H92!T96UP;&%T
M92!U<V5D('1O(&1I<W!L87D@96%C:"!R;W<@;V8@=&AE(&QI<W0N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1T96UP;&%T
M95)O=SL*"B`@("`O*BH*("`@("`J(%-H;W<O:&ED92`B;6%R:R(@8V]L=6UN
M(&EN('1H92!D:7-P;&%Y+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@
M("`@("HO"B`@("!V87(@)'-H;W=-87)K(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!3:&]W+VAI9&4@(F5D:70B(&-O;'5M;B!I;B!T:&4@9&ES<&QA>2X*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1S
M:&]W161I="`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4VAO=R]H:61E(")V
M8V%R9"(@8V]L=6UN(&EN('1H92!D:7-P;&%Y+@H@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)'-H;W=68V%R9"`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@4VAO=R]H:61E(")G<F]U<"(@8V]L=6UN(&EN
M('1H92!D:7-P;&%Y+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@
M("HO"B`@("!V87(@)'-H;W='<F]U<"`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@4VAO=R]H:61E(")S;W)T(B!C;VQU;6X@:6X@=&AE(&1I<W!L87DN"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D<VAO
M=U-O<G0@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1Y<&4@;V8@;&ES="X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'1Y
M<&4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%1U<F)A7TQI
M<W16:65W(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@5'5R8F%?3&ES
M="`D;&ES="`@3&ES="!O9B!C;VYT86-T<R!T;R!D:7-P;&%Y+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!4=7)B85],:7-T5FEE=R@F)&QI<W0L("1C;VQU;6YS
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D8V]L=6UN<RDI
M('L*("`@("`@("`@("`@)&-O;'5M;G,@/2!A<G)A>2@G36%R:R<@/3X@=')U
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G161I="<@/3X@=')U
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5F-A<F0G(#T^('1R
M=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T=R;W5P)R`]/B!T
M<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=3;W)T)R`]/B!T
M<G5E*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YL:7-T(#T@)B1L:7-T
M.PH@("`@("`@("1T:&ES+3YS971#;VQU;6YS*"1C;VQU;6YS*3L*("`@("`@
M("`D=&AI<RT^<V5T5&5M<&QA=&5S*&%R<F%Y*"=(96%D97(G(#T^(%154D)!
M7U1%35!,051%4R`N("<O8G)O=W-E+V-O;'5M;E]H96%D97)S+FEN8R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1F]O=&5R)R`]/B!4
M55)"05]414U03$%415,@+B`G+V)R;W=S92]C;VQU;6Y?9F]O=&5R<RYI;F,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U)O=R<@/3X@
M5%520D%?5$5-4$Q!5$53("X@)R]B<F]W<V4O<F]W+FEN8R<I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G1R;VP@=VAI8V@@8V]L=6UN<R!A<F4@<VAO
M=VX@8GD@=&AE(&1I<W!L87D@=&5M<&QA=&5S+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D8V]L=6UN<PH@("`@("HO"B`@("!F=6YC=&EO;B!S971#
M;VQU;6YS*"1C;VQU;6YS*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1C;VQU
M;6YS(&%S("1C;VQU;6X@/3X@)'-H;W<I('L*("`@("`@("`@("`@)&ME>2`]
M("=S:&]W)R`N("1C;VQU;6X["B`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@
M*&)O;VPI)'-H;W<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!H96%D97(L(&9O;W1E<BP@86YD(')O=R!T96UP;&%T97,@9F]R
M(&1I<W!L87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1T96UP;&%T
M97,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&5M<&QA=&5S*"1T96UP;&%T
M97,I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1E;7!L871E<R!A<R`D=&5M
M<&QA=&4@/3X@)&9I;&4I('L*("`@("`@("`@("`@)&ME>2`]("=T96UP;&%T
M92<@+B`D=&5M<&QA=&4["B`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)&9I
M;&4["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%1Y<&4H)'1Y
M<&4I"B`@("!["B`@("`@("`@)'1H:7,M/G1Y<&4@/2`D='EP93L*("`@('T*
M"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N=6UB97(@;V8@5'5R8F%?3V)J96-T<R!T:&%T(&%R92!I;B!T:&4@;&ES
M="X@57-E('1H:7,@=&\*("`@("`J(&AI9&4@:6YT97)N86P@:6UP;&5M96YT
M871I;VX@9&5T86EL<R!F<F]M(&-L:65N="!O8FIE8W1S+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!O8FIE8W1S(&EN
M('1H92!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N="@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YL:7-T+3YC;W5N="@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&1I<W!L87DH*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M<')E9G,L("1C;VYF+"`D<V]U<F-E+"`D861D7W-O=7)C95]O<'1I;VYS.PH*
M("`@("`@("`D9')I=F5R(#T@)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1S
M;W5R8V4I.PH@("`@("`@(&EF("@A:7-?82@D9')I=F5R+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(&EF("@D9')I=F5R+3YH87-097)M:7-S:6]N
M*%!%4DU37T1%3$5412DI('L*("`@("`@("`@("`@("`@("1H87-$96QE=&4@
M/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@:68@*"1D<FEV97(M
M/FAA<U!E<FUI<W-I;VXH4$5235-?141)5"DI('L*("`@("`@("`@("`@("`@
M("1H87-%9&ET(#T@=')U93L*("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&QI<W0H)&%D9%1O3&ES="P@)&%D9%1O3&ES=%-O=7)C97,I(#T@)'1H
M:7,M/F=E=$%D9%-O=7)C97,H*3L*("`@("`@("!R97%U:7)E(%154D)!7U1%
M35!,051%4R`N("<O8G)O=W-E+V%C=&EO;G,N:6YC)SL*"B`@("`@("`@)'9I
M97=U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)V)R;W=S92YP:'`G+"!A<G)A
M>2@*("`@("`@("`@("`@)W-O<G1B>2<@/3X@571I;#HZ9V5T1F]R;41A=&$H
M)W-O<G1B>2<I+`H@("`@("`@("`@("`G<V]R=&1I<B<@/3X@571I;#HZ9V5T
M1F]R;41A=&$H)W-O<G1D:7(G*2P*("`@("`@("`@("`@)VME>2<@/3X@571I
M;#HZ9V5T1F]R;41A=&$H)VME>2<I+`H@("`@("`@("`@("`G<V]U<F-E)R`]
M/B!5=&EL.CIG971&;W)M1&%T82@G<V]U<F-E)RP@)'-O=7)C92DL"B`@("`@
M("`@("`@("DI.PH*("`@("`@("!I9B`H)'1H:7,M/G1Y<&4@/3T@)W-E87)C
M:"<I('L*("`@("`@("`@("`@)'!A9V4@/2!5=&EL.CIG971&;W)M1&%T82@G
M<&%G92<L(#`I.PH@("`@("`@("`@("`D;G5M:71E;2`]("1T:&ES+3YC;W5N
M="@I.PH@("`@("`@("`@("`D;6%X<&%G92`]("1P<F5F<RT^9V5T5F%L=64H
M)VUA>'!A9V4G*3L*("`@("`@("`@("`@)'!E<G!A9V4@/2`D<')E9G,M/F=E
M=%9A;'5E*"=P97)P86=E)RD["@H@("`@("`@("`@("`D;6EN(#T@)'!A9V4@
M*B`D<&5R<&%G93L*("`@("`@("`@("`@=VAI;&4@*"1M:6X@/B`D;G5M:71E
M;2D@>PH@("`@("`@("`@("`@("`@)'!A9V4M+3L*("`@("`@("`@("`@("`@
M("1M:6X@/2`D<&%G92`J("1P97)P86=E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D;6%X(#T@)&UI;B`K("1P97)P86=E.PH@("`@("`@("`@("`D
M<W1A<G0@/2`H)'!A9V4@*B`D<&5R<&%G92D@*R`Q.PH@("`@("`@("`@("`D
M96YD(#T@;6EN*"1N=6UI=&5M+"`D<W1A<G0@*R`D<&5R<&%G92`M(#$I.PH*
M("`@("`@("`@("`@)&YU;41I<W!L87EE9"`]("1T:&ES+3YD:7-P;&%Y4&%G
M92@D;6EN+"`D;6%X*3L*"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O5F%R:6%B;&5S+G!H<"<["B`@("`@("`@("`@("1V87)S(#T@)E9A<FEA
M8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PH@("`@("`@("`@("`D8W)I
M="`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("@D7U-%4U-)3TY;)W1U<F)A
M7W-E87)C:%]M;V1E)UT@/3T@)V%D=F%N8V5D)RD@>PH@("`@("`@("`@("`@
M("`@)&UA<"`]("1D<FEV97(M/F=E=$-R:71E<FEA*"D["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;6%P(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1K97D@(3T@)U]?:V5Y)RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L(#T@571I;#HZ9V5T1F]R;41A=&$H)&ME
M>2D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'9A;"DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C<FET6R1K97E=(#T@
M)'9A;#L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<&%R86US(#T@87)R87E?;65R9V4H)&-R:70L(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@)W-O=7)C92<@/3X@)'-O=7)C92P*("`@("`@("`@
M("`@("`@("=C<FET97)I82<@/3X@571I;#HZ9V5T1F]R;41A=&$H)V-R:71E
M<FEA)RDL"B`@("`@("`@("`@("`@("`G=F%L)R`]/B!5=&EL.CIG971&;W)M
M1&%T82@G=F%L)RD*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1V:65W
M=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=S96%R8V@N<&AP)RP@)'!A<F%M
M<RD["@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U5)+U!A9V5R
M+G!H<"<["B`@("`@("`@("`@("1P86=E<B`]("9N97<@2&]R9&5?54E?4&%G
M97(H)W!A9V4G+"`D=F%R<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G;G5M)R`]/B`D;G5M1&ES<&QA>65D+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=U<FPG(#T^("1V:65W=7)L+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=P86=E7VQI;6ET)R`]/B`D;6%X<&%G
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<&5R<&%G92<@/3X@)'!E<G!A9V4I*3L*"B`@("`@("`@("`@("1F
M;V]T97(@/2`G9F]O=&5R+FEN8R<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'!A9V4@/2!5=&EL.CIG971&;W)M1&%T82@G<&%G92<L("<J)RD[
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^8V]U;G0H*2`^("1P<F5F<RT^9V5T
M5F%L=64H)W!E<G!A9V4G*2`F)@H@("`@("`@("`@("`@("`@*%5T:6PZ.F=E
M=$9O<FU$871A*"=S:&]W)RD@(3T@)VQI<W1S)R!\?`H@("`@("`@("`@("`@
M("`@(55T:6PZ.F=E=$9O<FU$871A*"=K97DG*2DI('L*("`@("`@("`@("`@
M("`@("1P86=E(#T@571I;#HZ9V5T1F]R;41A=&$H)W!A9V4G+"`G02<I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H96UP='DH)'!A9V4I('Q\
M("%P<F5G7VUA=&-H*"<O7EM!+5IA+7HJ720O)RP@)'!A9V4I*2!["B`@("`@
M("`@("`@("`@("`D<&%G92`]("<J)SL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1H:7,M/F1I<W!L87E!;'!H82@D<&%G92D["B`@("`@("`@("`@
M("1F;V]T97(@/2`G9F]O=&5R06QP:&$N:6YC)SL*("`@("`@("!]"@H@("`@
M("`@(')E<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]B<F]W<V4O86-T:6]N
M<RYI;F,G.PH@("`@("`@(')E<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]B
M<F]W<V4O)R`N("1F;V]T97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD
M97)S('1H92!L:7-T(&-O;G1E;G1S(&EN=&\@86X@2%1-3"!V:65W+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`D8V]U;G0@5&AE(&YU;6)E<B!O
M9B!O8FIE8W1S(&EN('1H92!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M:7-P;&%Y4&%G92@D;6EN(#T@;G5L;"P@)&UA>"`](&YU;&PI"B`@("!["B`@
M("`@("`@9VQO8F%L("1R96=I<W1R>2P@)&%T=')I8G5T97,L("1C;VQU;6YS
M+"`D<V]U<F-E.PH*("`@("`@("!I9B`H:7-?;G5L;"@D;6EN*2D@>PH@("`@
M("`@("`@("`D;6EN(#T@,#L*("`@("`@("!]"B`@("`@("`@:68@*&ES7VYU
M;&PH)&UA>"DI('L*("`@("`@("`@("`@)&UA>"`]("1T:&ES+3YL:7-T+3YC
M;W5N="@I.PH@("`@("`@('T*"B`@("`@("`@)'-O<G1B>2`]("1'3$]"04Q3
M6R=P<F5F<R==+3YG971686QU92@G<V]R=&)Y)RD["B`@("`@("`@)'-O<G1D
M:7(@/2`H:6YT*21'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G<V]R=&1I
M<B<I.PH@("`@("`@("1W:61T:"`](&9L;V]R*#DP("\@*&-O=6YT*"1C;VQU
M;6YS*2`K(#$I*3L*"B`@("`@("`@:6YC;'5D92`D=&AI<RT^=&5M<&QA=&5(
M96%D97(["@H@("`@("`@("1I(#T@,#L*("`@("`@("`D=&AI<RT^;&ES="T^
M<F5S970H*3L*("`@("`@("!W:&EL92`H)&]B(#T@)'1H:7,M/FQI<W0M/FYE
M>'0H*2D@>PH@("`@("`@("`@("!I9B`H)&DK*R`\("1M:6X@?'P@)&D@/B`D
M;6%X*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:6YC;'5D92`D=&AI<RT^=&5M<&QA=&52;W<["B`@
M("`@("`@?0H*("`@("`@("!I;F-L=61E("1T:&ES+3YT96UP;&%T949O;W1E
M<CL*("`@("`@("!R971U<FX@)&D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96YD97)S('1H92!L:7-T(&-O;G1E;G1S('1H870@;6%T8V@@)&%L<&AA(&EN
M=&\@86YD($A434P@=FEE=RX*("`@("`J"B`@("`@*B!`<&%R86T@)&%L<&AA
M("`@(%1H92!L971T97(@=&\@9&ES<&QA>2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&ES<&QA>4%L<&AA*"1A;'!H82D*("`@('L*("`@("`@("!G;&]B86P@
M)')E9VES=')Y+"`D871T<FEB=71E<RP@)&-O;'5M;G,L("1S;W5R8V4["@H@
M("`@("`@("1S;W)T8GD@/2`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H
M)W-O<G1B>2<I.PH@("`@("`@("1S;W)T9&ER(#T@*&EN="DD1TQ/0D%,4ULG
M<')E9G,G72T^9V5T5F%L=64H)W-O<G1D:7(G*3L*("`@("`@("`D=VED=&@@
M/2!F;&]O<B@Y,"`O("AC;W5N="@D8V]L=6UN<RD@*R`Q*2D["@H@("`@("`@
M(&EN8VQU9&4@)'1H:7,M/G1E;7!L871E2&5A9&5R.PH*("`@("`@("`D86QP
M:&$@/2!3=')I;F<Z.FQO=V5R*"1A;'!H82D["@H@("`@("`@("1I(#T@,#L*
M("`@("`@("`D=&AI<RT^;&ES="T^<F5S970H*3L*("`@("`@("!W:&EL92`H
M)&]B(#T@)'1H:7,M/FQI<W0M/FYE>'0H*2D@>PH@("`@("`@("`@("`D;F%M
M92`](%1U<F)A.CIF;W)M871.86UE*"1O8BD["@H@("`@("`@("`@("!I9B`H
M)&%L<&AA("$]("<J)R`F)B!3=')I;F<Z.FQO=V5R*"1N86UE>S!]*2`A/2`D
M86QP:&$I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I;F-L=61E("1T:&ES+3YT96UP;&%T95)O=SL*
M("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@(&EN8VQU9&4@
M)'1H:7,M/G1E;7!L871E1F]O=&5R.PH@("`@("`@(')E='5R;B`D:3L*("`@
M('T*"B`@("!F=6YC=&EO;B!G971!9&13;W5R8V5S*"D*("`@('L*("`@("`@
M("!G;&]B86P@)&%D9%-O=7)C97,["@H@("`@("`@("\O($-R96%T92!L:7-T
M(&]F(&QI<W1S(&9O<B!!9&0@=&\N"B`@("`@("`@)&%D9%1O3&ES="`](&%R
M<F%Y*"D["B`@("`@("`@)&%D9%1O3&ES=%-O=7)C97,@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<F5A8V@@*"1A9&13;W5R8V5S(&%S("1S<F,@/3X@)'-R8T-O
M;F9I9RD@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1S<F-#;VYF:6=;)VUA
M<"==6R=?7W1Y<&4G72DI('L*("`@("`@("`@("`@("`@("1A9&14;TQI<W13
M;W5R8V5S6UT@/2!A<G)A>2@G:V5Y)R`]/B`G)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)R9N8G-P
M.R9N8G-P.R<@+B!H=&UL<W!E8VEA;&-H87)S*"1S<F-#;VYF:6=;)W1I=&QE
M)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=S;W5R8V4G(#T^(&AT;6QS<&5C:6%L8VAA<G,H)'-R8RDI.PH*("`@
M("`@("`@("`@("`@("1S<F-$<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS:6YG
M;&5T;VXH)'-R8RD["B`@("`@("`@("`@("`@("`D;&ES=$QI<W0@/2`D<W)C
M1')I=F5R+3YS96%R8V@H87)R87DH)U]?='EP92<@/3X@)T=R;W5P)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VYA;64G+"`G04Y$)RP@,"P@87)R87DH)VYA;64G*2D["B`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D;&ES=$QI<W0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/G!U
M<V@H)&QI<W1,:7-T+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&QI<W1,:7-T+3YR97-E
M="@I.PH@("`@("`@("`@("`@("`@("`@("1C=7)R96YT3&ES="`](%5T:6PZ
M.F=E=$9O<FU$871A*"=K97DG*3L*("`@("`@("`@("`@("`@("`@("!W:&EL
M92`H)&QI<W1/8FIE8W0@/2`D;&ES=$QI<W0M/FYE>'0H*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&QI<W1/8FIE8W0M/F=E=%9A;'5E*"=?
M7VME>2<I("$]("1C=7)R96YT3&ES="D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&%D9%1O3&ES=%M=(#T@87)R87DH)VYA;64G(#T^(&AT;6QS
M<&5C:6%L8VAA<G,H)&QI<W1/8FIE8W0M/F=E=%9A;'5E*"=N86UE)RDI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W-O=7)C92<@/3X@:'1M;'-P96-I86QC:&%R<R@D<W)C*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K
M97DG(#T^(&AT;6QS<&5C:6%L8VAA<G,H)&QI<W1/8FIE8W0M/F=E=%9A;'5E
M*"=?7VME>2<I*2D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@:68@*"1A9&14;TQI<W13;W5R8V5S*2![
M"B`@("`@("`@("`@(&EF("@D861D5&],:7-T*2!["B`@("`@("`@("`@("`@
M("!A<G)A>5]U;G-H:69T*"1A9&14;TQI<W0L("<M+2TM+2<I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1A9&14;TQI<W0@/2!A<G)A>5]M97)G92AA
M<G)A>2A?*")#<F5A=&4@82!N97<@0V]N=&%C="!,:7-T(&EN.B(I*2P@)&%D
M9%1O3&ES=%-O=7)C97,L("1A9&14;TQI<W0I.PH@("`@("`@("`@("`D861D
M5&],:7-T4V]U<F-E<R`](&YU;&P["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@87)R87DH)&%D9%1O3&ES="P@)&%D9%1O3&ES=%-O=7)C97,I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O
M;&EB+U)E;F1E<F5R+G!H<```````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S4P,P`Q,#0Q-S,V,C<U-@`P,C`U-C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PH*+RHJ"B`J(%1U<F)A
M($9O<FT@4F5N9&5R97(*("H*("H@)$AO<F1E.B!T=7)B82]L:6(O4F5N9&5R
M97(N<&AP+'8@,2XQ.2XV+C$@,C`P-2\Q,"\Q."`Q,CHU,#HP-2!J86X@17AP
M("0*("H*("H@0'!A8VMA9V4@5'5R8F$*("HO"F-L87-S(%1U<F)A7U)E;F1E
M<F5R(&5X=&5N9',@2&]R9&5?1F]R;5]296YD97)E<B!["@H@("`@=F%R("1?
M86-T:79E(#T@9F%L<V4["B`@("!V87(@)%]O8FIE8W0["@H@("`@9G5N8W1I
M;VX@<V5T3V)J96-T*"8D;V)J96-T*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;V)J96-T(#T@)B1O8FIE8W0["B`@("!]"@H@("`@9G5N8W1I;VX@8F5G:6Y!
M8W1I=F4H)&YA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E]A8W1I=F4@/2!T
M<G5E.PH@("`@("`@('!A<F5N=#HZ8F5G:6Y!8W1I=F4H)&YA;64I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&)E9VEN26YA8W1I=F4H)&YA;64I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]A8W1I=F4@/2!F86QS93L*("`@("`@("!P87)E;G0Z
M.F)E9VEN26YA8W1I=F4H)&YA;64I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S
M96-T:6]N2&5A9&5R*"1T:71L92D*("`@('L*("`@("`@("`D86-T:6]N<R`]
M(&%R<F%Y*"D["B`@("`@("`@:68@*"$D=&AI<RT^7V%C=&EV92`F)B!I<U]A
M*"1T:&ES+3Y?;V)J96-T+"`G5'5R8F%?3V)J96-T)RDI('L*("`@("`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y*"=S;W5R8V4G(#T^("1T:&ES+3Y?;V)J96-T
M+3YD<FEV97(M/FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:V5Y)R`@("`]/B`D=&AI<RT^7V]B:F5C="T^9V5T5F%L=64H)U]?:V5Y)RDI
M.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]O8FIE8W0M/FAA<U!E<FUI<W-I
M;VXH4$5235-?141)5"DI('L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=E9&ET+G!H
M<"<I+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("1A8W1I;VYS6UT@/2`G
M/&QI/B<@+B!(;W)D93HZ;&EN:R@D=7)L+"!?*")%9&ET(BDI("X@7R@B161I
M="(I("X@)SPO83XG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V]B:F5C="T^:&%S4&5R;6ES<VEO;BA015)-4U]$14Q%5$4I*2![
M"B`@("`@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*$AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G9&5L971E+G!H<"<I+"`D<&%R86US*3L*
M("`@("`@("`@("`@("`@("1A8W1I;VYS6UT@/2`G/&QI/B<@+@H@("`@("`@
M("`@("`@("`@("`@($AO<F1E.CIL:6YK*"1U<FPL(%\H(D1E;&5T92(I+"`G
M)RP@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!
M3%-;)W!R969S)UTM/F=E=%9A;'5E*"=D96QE=&5?;W!T)RD@/PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R971U<FX@=VEN9&]W+F-O;F9I
M<FTH7"<G("X@861D<VQA<VAE<RA?*")296%L;'D@9&5L971E('1H:7,@8V]N
M=&%C=#\B*2D@+B`G7"<I.R<@.B`G)RD@+@H@("`@("`@("`@("`@("`@("`@
M(%\H(D1E;&5T92(I("X@)SPO83XG.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&5C:&\@)SQD:78@8VQA<W,](FAE861E<B(^)SL*("`@("`@
M("!I9B`H(65M<'1Y*"1A8W1I;VYS*2D@>PH@("`@("`@("`@("!E8VAO("<\
M=6P^)R`N(&EM<&QO9&4H)R!\(#PO;&D^)RP@)&%C=&EO;G,I("X@)SPO;&D^
M/"]U;#XG.PH@("`@("`@('T*("`@("`@("!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)'1I=&QE*3L*("`@("`@("!E8VAO("<\+V1I=CXG.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQI8B]$
M<FEV97(N<&AP````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`Q,3(U-#``,3`T,3<S-C(W-38`,#(P,C4V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@5'5R
M8F%?1')I=F5R.CH@8VQA<W,@<')O=FED97,@82!C;VUM;VX@86)S=')A8W1E
M9"!I;G1E<F9A8V4@=&\@=&AE"B`J('9A<FEO=7,@9&ER96-T;W)Y('-E87)C
M:"!D<FEV97)S+B`@270@:6YC;'5D97,@9G5N8W1I;VYS(&9O<B!S96%R8VAI
M;F<L"B`J(&%D9&EN9RP@<F5M;W9I;F<L(&%N9"!M;V1I9GEI;F<@9&ER96-T
M;W)Y(&5N=')I97,N"B`J"B`J("1(;W)D93H@='5R8F$O;&EB+T1R:79E<BYP
M:'`L=B`Q+C4W+C(N,C(@,C`P-B\P,R\P,R`Q-CHT-3HU-"!J86X@17AP("0*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!C<V@N<FET+F5D=3X*
M("H@0'!A8VMA9V4@5'5R8F$*("HO"F-L87-S(%1U<F)A7T1R:79E<B!["@H@
M("`@+RHJ"B`@("`@*B!4:&4@:6YT97)N86P@;F%M92!O9B!T:&ES('-O=7)C
M92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)&YA;64["@H@("`@+RHJ"B`@("`@*B!4:&4@<WEM8F]L:6,@=&ET;&4@;V8@
M=&AI<R!S;W5R8V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1T:71L93L*"B`@("`O*BH*("`@("`J($AA<V@@9&5S8W)I
M8FEN9R!T:&4@;6%P<&EN9R!B971W965N(%1U<F)A(&%T=')I8G5T97,@86YD
M"B`@("`@*B!D<FEV97(M<W!E8VEF:6,@9FEE;&1S+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1M87`@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@2&%S:"!W:71H(&%L;"!T86)S(&%N9"!T:&5I<B!F
M:65L9',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)'1A8G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@3&ES="!O9B!A
M;&P@9FEE;&1S('1H870@8V%N(&)E(&%C8V5S<V5D(&EN('1H92!B86-K96YD
M("AE>&-L=61E<PH@("`@("H@8V]M<&]S:71E(&%T=')I8G5T97,L(&5T8RXI
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1F
M:65L9',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@9FEE
M;&1S('1H870@;75S="!M871C:"!E>&%C=&QY+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1S=')I8W0@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@5VAE=&AE<B!T:&ES('-O=7)C92!S=&]R97,@;VYE
M(&%D9')E<W,@8F]O:RP@;W(@;75L=&EP;&4@<')I=F%T92!A9&1R97-S"B`@
M("`@*B!B;V]K<RX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M+PH@("`@=F%R("1P=6)L:6,@/2!F86QS93L*"B`@("`O*BH*("`@("`J($AA
M<V@@:&]L9&EN9R!T:&4@9')I=F5R)W,@861D:71I;VYA;"!P87)A;65T97)S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%=H870@8V%N('1H
M:7,@8F%C:V5N9"!D;S\*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V-A<&%B:6QI=&EE<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!(;W)D95]3:&%R92!O8FIE8W0@9F]R('1H:7,@<V]U<F-E+@H@
M("`@("H*("`@("`J($!V87(@2&]R9&5?4VAA<F4*("`@("`J+PH@("`@('9A
M<B`D<VAA<F4["@H@("`@("\J*@H@("`@("`J($%R92!(;W)D95]3:&%R97,@
M96YA8FQE9"!F;W(@=&AI<R!S;W5R8V4_"B`@("`@("H*("`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`@*B\*("`@("!V87(@)'5S:6YG4VAA<F5S.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!4=7)B85]$<FEV97(@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!(87-H
M(&-O;G1A:6YI;F<@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@5'5R8F%?1')I=F5R*"1P87)A;7,I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@8W5R<F5N="!D<FEV97(G<R!A9&1I=&EO;F%L('!A
M<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@2&%S:"!C
M;VYT86EN:6YG('1H92!D<FEV97(G<R!A9&1I=&EO;F%L('!A<F%M971E<G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VAE8VMS(&EF('1H:7,@8F%C:V5N9"!H87,@82!C97)T86EN(&-A<&%B
M:6QI='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I;&ET
M>2`@5&AE(&-A<&%B:6QI='D@=&\@8VAE8VL@9F]R+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@4W5P<&]R=&5D(&]R(&YO="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:&%S0V%P86)I;&ET>2@D8V%P86)I;&ET>2D*("`@('L*
M("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3Y?8V%P86)I;&ET:65S6R1C
M87!A8FEL:71Y72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4<F%N<VQA=&5S
M('1H92!K97ES(&]F('1H92!F:7)S="!H87-H(&9R;VT@=&AE(&=E;F5R86QI
M>F5D(%1U<F)A"B`@("`@*B!A='1R:6)U=&5S('1O('1H92!D<FEV97(M<W!E
M8VEF:6,@9FEE;&1S+B!4:&4@=')A;G-L871I;VX@:7,@8F%S960@;VX*("`@
M("`J('1H92!C;VYT96YT<R!O9B`D=&AI<RT^;6%P+B!4:&ES(&EG;F]R97,@
M8V]M<&]S:71E(&9I96QD<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&AA<V@@($AA<V@@=7-I;F<@5'5R8F$@:V5Y<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4<F%N<VQA=&5D('9E<G-I;VX@;V8@)&AA<V@N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1O1')I=F5R2V5Y<R@D:&%S:"D*("`@('L*
M("`@("`@("`D9FEE;&1S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D
M:&%S:"!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YM87!;)&ME>5TI("8F("%I<U]A<G)A>2@D=&AI<RT^;6%P6R1K
M97E=*2D@>PH@("`@("`@("`@("`@("`@)&9I96QD<ULD=&AI<RT^;6%P6R1K
M97E=72`]("1V86P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1F:65L9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME<R!A
M(&AA<V@@;V8@5'5R8F$@:V5Y(#T^('-E87)C:"!V86QU92!A;F0@<F5T=7)N
M(&$@*'!O<W-I8FQY"B`@("`@*B!N97-T960I(&%R<F%Y+"!U<VEN9R!B86-K
M96YD(&%T=')I8G5T92!N86UE<RP@=&AA="!C86X@8F4@='5R;F5D(&EN=&\@
M80H@("`@("H@<V5A<F-H(&)Y('1H92!D<FEV97(N(%1H92!T<F%N<VQA=&EO
M;B!I<R!B87-E9"!O;B!T:&4@8V]N=&5N=',@;V8*("`@("`J("1T:&ES+3YM
M87`L(&%N9"!I;F-L=61E<R!N97-T960@3U(@<V5A<F-H97,@9F]R(&-O;7!O
M<VET92!F:65L9',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`D:&%S
M:"`@("`@("`@($AA<V@@;V8@8W)I=&5R:6$@=7-I;F<@5'5R8F$@:V5Y<RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'-E87)C:%]T>7!E("!/4B!S96%R8V@@
M;W(@04Y$('-E87)C:#\*("`@("`J($!P87)A;2!A<G)A>2`@)'-T<FEC="`@
M("`@("!&:65L9',@=&AA="!M=7-T(&)E(&UA=&-H960@97AA8W1L>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!S96%R8V@@
M8W)I=&5R:6$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UA:V5396%R8V@H)&-R
M:71E<FEA+"`D<V5A<F-H7W1Y<&4L("1S=')I8W0I"B`@("!["B`@("`@("`@
M)'-E87)C:"`](&%R<F%Y*"D["B`@("`@("`@)'-T<FEC=%]S96%R8V@@/2!A
M<G)A>2@I.PH@("`@("`@("1S96%R8VA?=&5R;7,@/2!A<G)A>2@I.PH@("`@
M("`@("1S=6)S96%R8V@@/2!A<G)A>2@I.PH@("`@("`@("1T96UP(#T@)R<[
M"B`@("`@("`@)&QA<W1#:&%R(#T@)UPB)SL*("`@("`@("`D9VQU92`]("<G
M.PH*("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L
M*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;6%P6R1K97E=*2D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YM87!;)&ME
M>5TI*2!["B`@("`@("`@("`@("`@("`@("`@+RH@0V]M<&]S:71E(&9I96QD
M+"!B<F5A:R!O=70@=&AE('-E87)C:"!T97)M<RX@*B\*("`@("`@("`@("`@
M("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<@)RP@)'9A;"D["B`@("`@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1P87)T<RD@/B`Q*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("\J($]N;'D@<&%R<V4@:68@=&AE<F4@=V%S(&UO
M<F4@=&AA;B`Q('-E87)C:"!T97)M(&%N9`H@("`@("`@("`@("`@("`@("`@
M("`@("`@*B`G04Y$)R!T:&4@8W5M=6QI=&EV92!S=6)S96%R8VAE<RX@*B\*
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U
M;G0H)'!A<G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1E<FT@/2`D<&%R='-;)&E=.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D=&5R;2P@,"P@,2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&9I<G-T0VAA<B`]/2)<(B(I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5M<"`]('-U
M8G-T<B@D=&5R;2P@,2P@<W1R;&5N*"1T97)M*2`M(#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D;VYE(#T@9F%L<V4["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"$D9&]N92`F)B`D:2`\
M(&-O=6YT*"1P87)T<RD@+2`Q*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D<&%R='-;)&D@*R`Q
M72P@+3$I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)&QA<W1#:&%R(#T](EPB(BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1E;7`@+CT@)R`G("X@<W5B<W1R*"1P87)T
M<ULD:2`K(#%=+"`P+"`M,2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&]N92`]('1R=64["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1E;7`@+CT@)R`G("X@)'!A<G1S
M6R1I("L@,5T["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S96%R8VA?=&5R;7-;72`]("1T
M96UP.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5A<F-H7W1E<FUS6UT@
M/2`D=&5R;3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9VQU92`]("=!3D0G.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("\J($EF(&]N;'D@;VYE('-E87)C:"!T
M97)M+"!U<V4@;W)I9VEN86P@:6YP=70@86YD"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=/4B<@=&AE('-E87)C97,@<VEN8V4@=V4G<F4@;VYL>2!L
M;V]K:6YG(&9O<B`Q"B`@("`@("`@("`@("`@("`@("`@("`@("`@('1E<FT@
M:6X@86YY(&]F('1H92!C;VUP;W-I=&4@9FEE;&1S+B`J+PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<V5A<F-H7W1E<FUS6S!=(#T@)'9A;#L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&=L=64@/2`G3U(G.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^
M;6%P6R1K97E=6R=F:65L9',G72!A<R`D9FEE;&0I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I96QD(#T@)'1H:7,M/G1O1')I=F5R*"1F:65L9"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'-T<FEC=%LD
M9FEE;&1=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+RH@1F]R
M('-T<FEC="!M871C:&5S+"!U<V4@=&AE(&]R:6=I;F%L('-E87)C:`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("H@=F%L<RX@*B\*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S=')I8W1?<V5A<F-H6UT@/2!A<G)A>2@G
M9FEE;&0G(#T^("1F:65L9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;W`G(#T^("<])RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=&5S="<@/3X@)'9A;"D["B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O*B!#<F5A=&4@
M82!S=6)S96%R8V@@9F]R(&5A8V@@:6YD:79I9'5A;"!S96%R8V@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`J('1E<FTN("HO"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'-E87)C:%]T97)M<RD@/B`Q
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+RH@0G5I;&0@
M=&AE("=/4B<@<V5A<F-H(&9O<B!E86-H('-E87)C:"!T97)M"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("H@;VX@=&AI<R!F:65L9"X@*B\*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D871O;7-E87)C:"`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@8V]U;G0H)'-E87)C:%]T97)M<RD[("1I*RLI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T;VUS96%R
M8VA;72`](&%R<F%Y*"=F:65L9"<@/3X@)&9I96QD+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V]P)R`]/B`G3$E+12<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5S="<@/3X@)'-E87)C
M:%]T97)M<ULD:5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W5B<V5A<F-H
M6UT@/2!A<G)A>2@G3U(G(#T^("1A=&]M<V5A<F-H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!U;G-E="@D871O;7-E87)C:"D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=L=64@/2`G04Y$)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+RH@)'!A<G1S(&UA>2!H879E(&UO<F4@
M=&AA;B!O;F4@96QE;65N="P@8G5T"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("H@:68@=&AE>2!A<F4@86QL('%U;W1E9"!W92!W:6QL(&]N
M;'D@:&%V92`Q"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("H@
M)'-U8G-E87)C:"X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<W5B<V5A<F-H6UT@/2!A<G)A>2@G9FEE;&0G(#T^("1F:65L9"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;W`G(#T^("=,24M%)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5S="<@/3X@)'-E87)C
M:%]T97)M<ULP72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&=L=64@/2`G3U(G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<W5B<V5A<F-H*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D<V5A<F-H6UT@/2!A<G)A>2@D
M9VQU92`]/B`D<W5B<V5A<F-H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J
M($YO="!A(&-O;7!O<VET92!F:65L9"X@*B\*("`@("`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1S=')I8W1;)'1H:7,M/FUA<%LD:V5Y75TI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1S=')I8W1?<V5A<F-H6UT@/2!A<G)A
M>2@G9FEE;&0G(#T^("1T:&ES+3YM87!;)&ME>5TL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;W`G(#T^("<]
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T97-T)R`]/B`D=F%L*3L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<V5A<F-H6UT@/2!A
M<G)A>2@G9FEE;&0G(#T^("1T:&ES+3YM87!;)&ME>5TL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<"<@/3X@)TQ)2T4G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=&5S="<@/3X@)'9A;"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H8V]U;G0H)'-T<FEC=%]S96%R8V@I("8F(&-O=6YT*"1S96%R8V@I*2![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G04Y$)R`]/B!A<G)A>2@D<W1R
M:6-T7W-E87)C:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"1S96%R8VA?='EP92`]/B`D<V5A<F-H*2DI.PH@("`@
M("`@('T@96QS96EF("AC;W5N="@D<W1R:6-T7W-E87)C:"DI('L*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=!3D0G(#T^("1S=')I8W1?<V5A<F-H*3L*
M("`@("`@("!](&5L<V5I9B`H8V]U;G0H)'-E87)C:"DI('L*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"1S96%R8VA?='EP92`]/B`D<V5A<F-H*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4<F%N<VQA=&5S(&$@<VEN
M9VQE(%1U<F)A(&%T=')I8G5T92!T;R!T:&4@9')I=F5R+7-P96-I9FEC"B`@
M("`@*B!C;W5N=&5R<&%R="X@5&AE('1R86YS;&%T:6]N(&ES(&)A<V5D(&]N
M('1H92!C;VYT96YT<R!O9@H@("`@("H@)'1H:7,M/FUA<"X@5&AI<R!I9VYO
M<F5S(&-O;7!O<VET92!F:65L9',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D871T<FEB=71E("!4:&4@5'5R8F$@871T<FEB=71E('1O('1R86YS
M;&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1R:79E
M<B!N86UE(&9O<B!T:&ES(&%T=')I8G5T92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=&]$<FEV97(H)&%T=')I8G5T92D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YM87!;)&%T=')I8G5T95TI*2!["B`@("`@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3YM87!;)&%T=')I8G5T95TI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;6%P6R1A='1R:6)U=&5=6R=F:65L9',G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUA<%LD871T<FEB=71E
M73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4<F%N<VQA=&5S
M(&%N(&%R<F%Y(&]F(&AA<VAE<R!F<F]M(&)E:6YG(&ME>65D(&]N(&1R:79E
M<BUS<&5C:69I8PH@("`@("H@9FEE;&1S('1O(&)E:6YG(&ME>65D(&]N('1H
M92!G96YE<F%L:7IE9"!4=7)B82!A='1R:6)U=&5S+B!4:&4*("`@("`J('1R
M86YS;&%T:6]N(&ES(&)A<V5D(&]N('1H92!C;VYT96YT<R!O9B`D=&AI<RT^
M;6%P+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;V)J96-T<R`@07)R
M87D@;V8@:&%S:&5S('5S:6YG(&1R:79E<BUS<&5C:69I8R!K97ES+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1R86YS;&%T960@=F5R<VEO;B!O
M9B`D;V)J96-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=&]4=7)B84ME>7,H
M)&]B:F5C=',I"B`@("!["B`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1O8FIE8W1S(&%S("1E;G1R>2D@>PH@("`@
M("`@("`@("`D;F5W7V5N=')Y(#T@87)R87DH*3L*"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3YM87`@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&YE=U]E;G1R>5LD:V5Y72`](&YU;&P["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1E;G1R>5LD=F%L72D@)B8@<W1R;&5N*"1E;G1R
M>5LD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U]E;G1R
M>5LD:V5Y72`]("1E;G1R>5LD=F%L73L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1A='1R:6)U=&5S6UT@/2`D;F5W7V5N=')Y.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&%T=')I8G5T97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M96%R8VAE<R!T:&4@<V]U<F-E(&)A<V5D(&]N('1H92!P<F]V:61E9"!C<FET
M97)I82X*("`@("`J"B`@("`@*B!`=&]D;R!!;&QO=R`D8W)I=&5R:6$@=&\@
M8V]N=&%I;B!T:&4@8V]M<&%R:7-O;B!O<&5R871O<B`H/"P@/2P@/BP*("`@
M("`J("`@("`@("=L:6ME)RD@86YD(&UO9&EF>2!T:&4@9')I=F5R<R!A8V-O
M<F1I;F=L>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'-E87)C:%]C
M<FET97)I82`@2&%S:"!C;VYT86EN:6YG('1H92!S96%R8V@@8W)I=&5R:6$N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S;W)T7V-R:71E<FEA("`@5&AE(')E
M<75E<W1E9"!S;W)T(&]R9&5R('=H:6-H(&ES('!A<W-E9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O(%1U<F)A7TQI<W0Z.G-O
M<G0H*2X*("`@("`J($!P87)A;2!S=')I;F<@)'-E87)C:%]T>7!E("`@("!$
M;R!A;B!!3D0@;W(@86X@3U(@<V5A<F-H("AD969A=6QT<R!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.1"DN"B`@("`@*B!`
M<&%R86T@87)R87D@)')E='5R;E]F:65L9',@("`@02!L:7-T(&]F(&9I96QD
M<R!T;R!R971U<FX[(&1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@86QL(&9I96QD<RX*("`@("`J($!P87)A;2!A
M<G)A>2`D8W5S=&]M7W-T<FEC="`@("!!(&QI<W0@;V8@9FEE;&1S('1H870@
M;75S="!M871C:"!E>&%C=&QY+@H@("`@("H*("`@("`J($!R971U<FX@(%1H
M92!S;W)T960L(&9I;'1E<F5D(&QI<W0@;V8@<V5A<F-H(')E<W5L=',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9S96%R8V@H)'-E87)C:%]C<FET97)I82P@
M)'-O<G1?8W)I=&5R:6$@/2`G;&%S=&YA;64G+`H@("`@("`@("`@("`@("`@
M("`@("`D<V5A<F-H7W1Y<&4@/2`G04Y$)RP@)'-O<G1?9&ER96-T:6]N(#T@
M,"P*("`@("`@("`@("`@("`@("`@("`@)')E='5R;E]F:65L9',@/2!A<G)A
M>2@I+"`D8W5S=&]M7W-T<FEC="`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M<F5Q=6ER95]O;F-E(%154D)!7T)!4T4@+B`G+VQI8B],:7-T+G!H<"<["B`@
M("`@("`@<F5Q=6ER95]O;F-E(%154D)!7T)!4T4@+B`G+VQI8B]/8FIE8W0N
M<&AP)SL*"B`@("`@("`@+RH@268@=V4@87)E(&YO="!U<VEN9R!(;W)D95]3
M:&%R92P@96YF;W)E('1H92!R97%U:7)E;65N="!T:&%T('1H90H@("`@("`@
M("`@(&-U<G)E;G0@=7-E<B!M=7-T(&)E('1H92!O=VYE<B!O9B!T:&4@861D
M<F5S<V)O;VLN("HO"B`@("`@("`@)'-T<FEC=%]F:65L9',@/2!A<G)A>2@I
M.PH@("`@("`@(&EF("@D=&AI<RT^=7-I;F=3:&%R97,I('L*("`@("`@("`@
M("`@)'5S97(@/2`D=&AI<RT^<VAA<F4M/F=E="@G=6ED)RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'5S97(@/2!!=71H.CIG971!=71H*"D[
M"B`@("`@("`@?0H@("`@("`@("1S96%R8VA?8W)I=&5R:6%;)U]?;W=N97(G
M72`]("1U<V5R.PH@("`@("`@("1S=')I8W1?9FEE;&1S(#T@87)R87DH)'1H
M:7,M/G1O1')I=F5R*"=?7V]W;F5R)RD@/3X@=')U92D["@H@("`@("`@("\J
M($%D9"!A;GD@9FEE;&1S('1H870@;75S="!M871C:"!E>&%C=&QY(&9O<B!T
M:&ES('-O=7)C92!T;R!T:&4*("`@("`@("`@*B`D<W1R:6-T7V9I96QD<R!A
M<G)A>2X@*B\*("`@("`@("!F;W)E86-H("@D=&AI<RT^<W1R:6-T(&%S("1S
M=')I8W1?9FEE;&0I('L*("`@("`@("`@("`@)'-T<FEC=%]F:65L9'-;)'-T
M<FEC=%]F:65L9%T@/2!T<G5E.PH@("`@("`@('T*("`@("`@("!F;W)E86-H
M("@D8W5S=&]M7W-T<FEC="!A<R`D<W1R:6-T7V9I96QD*2!["B`@("`@("`@
M("`@("1S=')I8W1?9FEE;&1S6R1T:&ES+3YM87!;)'-T<FEC=%]F:65L9%U=
M(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("\J(%1R86YS;&%T92!T:&4@
M5'5R8F$@871T<FEB=71E<R!T;R!D<FEV97(M<W!E8VEF:6,@871T<FEB=71E
M<RX@*B\*("`@("`@("`D9FEE;&1S(#T@)'1H:7,M/FUA:V5396%R8V@H)'-E
M87)C:%]C<FET97)I82P@)'-E87)C:%]T>7!E+"`D<W1R:6-T7V9I96QD<RD[
M"B`@("`@("`@:68@*&-O=6YT*"1R971U<FY?9FEE;&1S*2D@>PH@("`@("`@
M("`@("`D<F5T=7)N7V9I96QD<U]P<F4@/2!A<G)A>5]U;FEQ=64H87)R87E?
M;65R9V4H87)R87DH)U]?:V5Y)RP@)U]?='EP92<L("=?7V]W;F5R)RP@)VYA
M;64G*2P@)')E='5R;E]F:65L9',I*3L*("`@("`@("`@("`@)')E='5R;E]F
M:65L9',@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<F5T=7)N
M7V9I96QD<U]P<F4@87,@)&9I96QD*2!["B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/G1O1')I=F5R*"1F:65L9"D["B`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<F5S=6QT(&%S("1C;VUP;W-I=&5?9FEE;&0I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O;7!O<VET95]R97-U;'0@/2`D=&AI
M<RT^=&]$<FEV97(H)&-O;7!O<VET95]F:65L9"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D8V]M<&]S:71E7W)E<W5L="D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E='5R;E]F:65L9'-;72`]("1C;VUP;W-I
M=&5?<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1R97-U
M;'0I('L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7V9I96QD<UM=(#T@
M)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R971U<FY?9FEE;&1S(#T@87)R
M87E?=F%L=65S*"1T:&ES+3YF:65L9',I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4F5T<FEE=F4@=&AE('-E87)C:"!R97-U;'1S(&9R;VT@=&AE(&1R:79E
M<BX@*B\*("`@("`@("`D;V)J96-T<R`]("1T:&ES+3Y?<V5A<F-H*"1F:65L
M9',L("1R971U<FY?9FEE;&1S*3L*("`@("`@("!I9B`H:7-?82@D;V)J96-T
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&]B:F5C
M=',["B`@("`@("`@?0H*("`@("`@("`O*B!4<F%N<VQA=&4@=&AE(&1R:79E
M<BUS<&5C:69I8R!F:65L9',@:6X@=&AE(')E<W5L="!B86-K('1O('1H92!M
M;W)E"B`@("`@("`@("H@9V5N97)A;&EZ960@8V]M;6]N(%1U<F)A(&%T=')I
M8G5T97,@=7-I;F<@=&AE(&UA<"X@*B\*("`@("`@("`D;V)J96-T<R`]("1T
M:&ES+3YT;U1U<F)A2V5Y<R@D;V)J96-T<RD["@H@("`@("`@(')E<75I<F5?
M;VYC92!455)"05]"05-%("X@)R]L:6(O3V)J96-T+G!H<"<["B`@("`@("`@
M)&QI<W0@/2`F;F5W(%1U<F)A7TQI<W0H*3L*("`@("`@("!F;W)E86-H("@D
M;V)J96-T<R!A<R`D;V)J96-T*2!["B`@("`@("`@("`@("1D;VYE(#T@9F%L
M<V4["B`@("`@("`@("`@(&EF("@A96UP='DH)&]B:F5C=%LG7U]T>7!E)UTI
M("8F('5C=V]R9',H)&]B:F5C=%LG7U]T>7!E)UTI("$]("=/8FIE8W0G*2![
M"B`@("`@("`@("`@("`@("`D='EP92`]('5C=V]R9',H)&]B:F5C=%LG7U]T
M>7!E)UTI.PH@("`@("`@("`@("`@("`@)&-L87-S(#T@)U1U<F)A7T]B:F5C
M=%\G("X@)'1Y<&4["B`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M(%154D)!7T)!4T4@+B`G+VQI8B]/8FIE8W0O)R`N("1T>7!E("X@)RYP:'`G
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`@("`@("`@("1L:7-T
M+3YI;G-E<G0H;F5W("1C;&%S<R@D=&AI<RP@)&]B:F5C="DI.PH@("`@("`@
M("`@("`@("`@("`@("1D;VYE(#T@=')U93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21D;VYE*2!["B`@("`@
M("`@("`@("`@("`D;&ES="T^:6YS97)T*&YE=R!4=7)B85]/8FIE8W0H)'1H
M:7,L("1O8FIE8W0I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`D;&ES="T^<V]R="@D<V]R=%]C<FET97)I82P@)'-O<G1?9&ER96-T:6]N
M*3L*"B`@("`@("`@+RH@4F5T=7)N('1H92!F:6QT97)E9"`H<V]R=&5D*2!R
M97-U;'1S+B`J+PH@("`@("`@(')E='5R;B`D;&ES=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E=')I979E<R!A('-E="!O9B!O8FIE8W1S(&9R;VT@=&AE
M('-O=7)C92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&]B:F5C=$ED
M<R`@5&AE('5N:7%U92!I9',@;V8@=&AE(&]B:F5C=',@=&\@<F5T<FEE=F4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&%R<F%Y(&]F(')E
M=')I979E9"!O8FIE8W1S("A4=7)B85]/8FIE8W1S*2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F=E=$]B:F5C=',H)&]B:F5C=$ED<RD*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+T]B:F5C="YP:'`G
M.PH@("`@("`@("1C<FET97)I82`]("1T:&ES+3YM87!;)U]?:V5Y)UT["@H@
M("`@("`@("1O8FIE8W1S(#T@)'1H:7,M/E]R96%D*"1C<FET97)I82P@)&]B
M:F5C=$ED<RP@87)R87E?=F%L=65S*"1T:&ES+3YF:65L9',I*3L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1O8FIE8W1S*2D@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@4$5!4CHZ<F%I<V5%<G)O<BA?*")297%U97-T960@;V)J96-T(&YO
M="!F;W5N9"XB*2D["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@("1O
M8FIE8W1S(#T@)'1H:7,M/G1O5'5R8F%+97ES*"1O8FIE8W1S*3L*("`@("`@
M("!F;W)E86-H("@D;V)J96-T<R!A<R`D;V)J96-T*2!["B`@("`@("`@("`@
M("1D;VYE(#T@9F%L<V4["B`@("`@("`@("`@(&EF("@A96UP='DH)&]B:F5C
M=%LG7U]T>7!E)UTI("8F('5C=V]R9',H)&]B:F5C=%LG7U]T>7!E)UTI("$]
M("=/8FIE8W0G*2!["B`@("`@("`@("`@("`@("`D='EP92`]('5C=V]R9',H
M)&]B:F5C=%LG7U]T>7!E)UTI.PH@("`@("`@("`@("`@("`@)&-L87-S(#T@
M)U1U<F)A7T]B:F5C=%\G("X@)'1Y<&4["B`@("`@("`@("`@("`@("!I9B`H
M(6-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E(%154D)!7T)!4T4@+B`G+VQI8B]/8FIE8W0O)R`N("1T
M>7!E("X@)RYP:'`G.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1R97-U;'1S6UT@/2`F;F5W("1C;&%S<R@D=&AI<RP@)&]B:F5C
M="D["B`@("`@("`@("`@("`@("`@("`@)&1O;F4@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)&1O
M;F4I('L*("`@("`@("`@("`@("`@("1R97-U;'1S6UT@/2`F;F5W(%1U<F)A
M7T]B:F5C="@D=&AI<RP@)&]B:F5C="D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E=')I979E<R!O;F4@;V)J96-T(&9R;VT@=&AE('-O=7)C92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O8FIE8W1)9"`@5&AE('5N
M:7%U92!I9"!O9B!T:&4@;V)J96-T('1O(')E=')I979E+@H@("`@("H*("`@
M("`J($!R971U<FX@5'5R8F%?3V)J96-T("!4:&4@<F5T<FEE=F5D(&]B:F5C
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$]B:F5C="@D;V)J96-T260I
M"B`@("!["B`@("`@("`@)')E<W5L="`]("8D=&AI<RT^9V5T3V)J96-T<RAA
M<G)A>2@D;V)J96-T260I*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("\O($9A;&P@=&AR;W5G:"X*
M("`@("`@("!](&5L<V5I9B`H96UP='DH)')E<W5L=%LP72DI('L*("`@("`@
M("`@("`@)')E<W5L="`](%!%05(Z.G)A:7-E17)R;W(H)TYO(')E<W5L=',G
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)')E
M<W5L=%LP73L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^;6%P6R=?
M7V]W;F5R)UTI*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT+3YA='1R:6)U
M=&5S6R=?7V]W;F5R)UT@/2!!=71H.CIG971!=71H*"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A(&YE=R!E;G1R>2!T;R!T:&4@8V]N=&%C
M="!S;W5R8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R:6)U
M=&5S("!4:&4@871T<FEB=71E<R!O9B!T:&4@;F5W(&]B:F5C="!T;R!A9&0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&YE=R!?7VME>2!V
M86QU92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R;W(@;V)J96-T"B`@("`@
M*B`@("`@("`@("`@("`@("!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&0H)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@+RH@3VYL>2!S
M970@7U]T>7!E(&%N9"!?7V]W;F5R(&EF('1H97D@87)E(&YO="!A;')E861Y
M('-E="X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1A='1R:6)U=&5S6R=?7W1Y
M<&4G72DI('L*("`@("`@("`@("`@)&%T=')I8G5T97-;)U]?='EP92==(#T@
M)T]B:F5C="<["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M;6%P6R=?7V]W;F5R)UTI("8F("%I<W-E="@D871T<FEB=71E<ULG7U]O=VYE
M<B==*2D@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1T:&ES+3YN86UE("P@
M)SHG*2D@>PH@("`@("`@("`@("`@("`@(&QI<W0H)'-O=7)C92P@)&%T=')I
M8G5T97-;)U]?;W=N97(G72D@/2!E>'!L;V1E*"<Z)RP@)'1H:7,M/FYA;64L
M(#(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&%T
M=')I8G5T97-;)U]?;W=N97(G72`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@1V5T(&9I96QD('9A;'5E
M<R!B969O<F4@=V4@=')A;G-L871E(&ME>7,@<V\@=V4@8V%N('5S90H@("`@
M("`@("`J('1H96T@:6X@=&AE(&AI<W1O<GD@;&]G+B`J+PH@("`@("`@(&EF
M("AI<W-E="@D871T<FEB=71E<ULG7U]O=VYE<B==*2D@>PH@("`@("`@("`@
M("`D='5R8F%/=VYE<B`]("1A='1R:6)U=&5S6R=?7V]W;F5R)UT["B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-S970H)&%T=')I8G5T97-;)U]?=6ED)UTI
M*2!["B`@("`@("`@("`@("1A='1R:6)U=&5S6R=?7W5I9"==(#T@)'1H:7,M
M/F=E;F5R871E54E$*"D["B`@("`@("`@?0H*("`@("`@("`D:V5Y(#T@)&%T
M=')I8G5T97-;)U]?:V5Y)UT@/2`D=&AI<RT^7VUA:V5+97DH)'1H:7,M/G1O
M1')I=F5R2V5Y<R@D871T<FEB=71E<RDI.PH@("`@("`@("1U:60@/2`D871T
M<FEB=71E<ULG7U]U:60G73L*"B`@("`@("`@)&%T=')I8G5T97,@/2`D=&AI
M<RT^=&]$<FEV97)+97ES*"1A='1R:6)U=&5S*3L*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]A9&0H)&%T=')I8G5T97,I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE(&-R96%T
M:6]N(&]F('1H:7,@:71E;2!I;B!T:&4@:&ES=&]R>2!L;V<N("HO"B`@("`@
M("`@)&AI<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@
M("`@("`@)&AI<W1O<GDM/FQO9R@G='5R8F$Z)R`N("@A96UP='DH)'1U<F)A
M3W=N97(I(#\@)'1U<F)A3W=N97(@.B!!=71H.CIG971!=71H*"DI("X@)SHG
M("X@)'5I9"P@87)R87DH)V%C=&EO;B<@/3X@)V%D9"<I+"!T<G5E*3L*"B`@
M("`@("`@<F5T=7)N("1K97D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE
M=&5S('1H92!S<&5C:69I960@96YT<GD@9G)O;2!T:&4@8V]N=&%C="!S;W5R
M8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;V)J96-T7VED("!4
M:&4@240@;V8@=&AE(&]B:F5C="!T;R!D96QE=&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E;&5T92@D;V)J96-T7VED*0H@("`@>PH@("`@("`@("1O8FIE
M8W0@/2`F)'1H:7,M/F=E=$]B:F5C="@D;V)J96-T7VED*3L*("`@("`@("!I
M9B`H:7-?82@D;V)J96-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D;V)J96-T.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D;V)J
M96-T+3YH87-097)M:7-S:6]N*%!%4DU37T1%3$5412DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&5R;6ES<VEO;B!D96YI
M960B*2D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M96QE=&4H)'1H:7,M/G1O1')I=F5R*"=?7VME>2<I+"`D;V)J96-T7VED*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M+RH@3&]G('1H92!D96QE=&EO;B!O9B!T:&ES(&ET96T@:6X@=&AE(&AI<W1O
M<GD@;&]G+B`J+PH@("`@("`@(&EF("@D;V)J96-T+3YG971686QU92@G7U]U
M:60G*2D@>PH@("`@("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y
M.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&AI<W1O<GDM/FQO9R@G='5R
M8F$Z)R`N("@D;V)J96-T+3YG971686QU92@G7U]O=VYE<B<I(#\@)&]B:F5C
M="T^9V5T5F%L=64H)U]?;W=N97(G*2`Z($%U=&@Z.F=E=$%U=&@H*2D@+B`G
M.B<@+B`D;V)J96-T+3YG971686QU92@G7U]U:60G*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G86-T:6]N)R`]/B`G9&5L971E)RDL('1R
M=64I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&5S(&%L;"!C;VYT86-T<R!F<F]M(&%N(&%D
M9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]U
M<F-E3F%M92`@5&AE(&ED96YT:69I97(@;V8@=&AE(&%D9')E<W,@8F]O:R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E;&5T92X@
M($EF(&]M:71T960L('=I;&P@8VQE87(@=&AE(&-U<G)E;G0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!U<V5R)W,@)V1E9F%U;'0G(&%D
M9')E<W,@8F]O:R!F;W(@=&AI<R!S;W5R8V4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T>7!E+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5!;&PH)'-O=7)C94YA;64@
M/2`G)RD*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YH87-#87!A8FEL:71Y
M*"=D96QE=&5?86QL)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)TYO="!S=7!P;W)T960G*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D96QE=&5!;&PH)'-O=7)C94YA
M;64I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UO9&EF:65S
M(&%N(&5X:7-T:6YG(&5N=')Y(&EN('1H92!C;VYT86-T('-O=7)C92X*("`@
M("`J"B`@("`@*B!`<&%R86T@5'5R8F%?3V)J96-T("1O8FIE8W0@(%1H92!O
M8FIE8W0@=&\@=7!D871E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;V)J96-T(&ED+"!P;W-S:6)L>2!U<&1A=&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S879E*"1O8FIE8W0I"B`@("!["B`@("`@("`@)&%T=')I
M8G5T97,@/2`D=&AI<RT^=&]$<FEV97)+97ES*"1O8FIE8W0M/F=E=$%T=')I
M8G5T97,H*2D["B`@("`@("`@)&ME>2`]("1T:&ES+3YT;T1R:79E<DME>7,H
M87)R87DH)U]?:V5Y)R`]/B`D;V)J96-T+3YG971686QU92@G7U]K97DG*2DI
M.PH@("`@("`@(&QI<W0H)&]B:F5C=%]K97DL("1O8FIE8W1?:60I(#T@96%C
M:"@D:V5Y*3L*"B`@("`@("`@)&]B:F5C=%]I9"`]("1T:&ES+3Y?<V%V92@D
M;V)J96-T7VME>2P@)&]B:F5C=%]I9"P@)&%T=')I8G5T97,I.PH@("`@("`@
M(&EF("AI<U]A*"1O8FIE8W1?:60L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1O8FIE8W1?:60["B`@("`@("`@?0H*("`@("`@("`O
M*B!,;V<@=&AE(&UO9&EF:6-A=&EO;B!O9B!T:&ES(&ET96T@:6X@=&AE(&AI
M<W1O<GD@;&]G+B`J+PH@("`@("`@(&EF("@D;V)J96-T+3YG971686QU92@G
M7U]U:60G*2D@>PH@("`@("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](:7-T
M;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&AI<W1O<GDM/FQO9R@G
M='5R8F$Z)R`N("@D;V)J96-T+3YG971686QU92@G7U]O=VYE<B<I(#\@)&]B
M:F5C="T^9V5T5F%L=64H)U]?;W=N97(G*2`Z($%U=&@Z.F=E=$%U=&@H*2D@
M+B`G.B<@+B`D;V)J96-T+3YG971686QU92@G7U]U:60G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G86-T:6]N)R`]/B`G;6]D:69Y)RDL
M('1R=64I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8FIE8W1?:60[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N=6UB97(@;V8@
M8V]N=&%C=',@;V8@=&AE(&-U<G)E;G0@=7-E<B!I;B!T:&ES(&%D9')E<W,@
M8F]O:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB
M97(@;V8@8V]N=&%C=',@=&AA="!T:&4@=7-E<B!O=VYS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;W5N=$-O;G1A8W1S*"D*("`@('L*("`@("`@("!S=&%T
M:6,@)&-O=6YT.PH*("`@("`@("!I9B`H(6ES<V5T*"1C;W5N="DI('L*("`@
M("`@("`@("`@)&-O=6YT(#T@)'1H:7,M/E]S96%R8V@H87)R87DH)T%.1"<@
M/3X@87)R87DH87)R87DH)V9I96QD)R`]/B`D=&AI<RT^=&]$<FEV97(H)U]?
M;W=N97(G*2P@)V]P)R`]/B`G/2<L("=T97-T)R`]/B!!=71H.CIG971!=71H
M*"DI*2DL(&%R<F%Y*"1T:&ES+3YT;T1R:79E<B@G7U]K97DG*2DI.PH@("`@
M("`@("`@("!I9B`H:7-?82@D8V]U;G0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D8V]U;G0["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&-O=6YT*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D8V]U;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!C<FET97)I82!A=F%I;&%B;&4@9F]R('1H:7,@<V]U<F-E
M(&5X8V5P="`G7U]K97DG+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&-R:71E<FEA+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971#<FET97)I82@I"B`@("!["B`@("`@("`@)&-R:71E
M<FEA(#T@)'1H:7,M/FUA<#L*("`@("`@("!U;G-E="@D8W)I=&5R:6%;)U]?
M:V5Y)UTI.PH@("`@("`@(')E='5R;B`D8W)I=&5R:6$["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&%L;"!N;VXM8V]M<&]S:71E(&9I96QD<R!F
M;W(@=&AI<R!S;W5R8V4N(%5S969U;"!F;W(@:6UP;W)T:6YG"B`@("`@*B!A
M;F0@97AP;W)T:6YG(&1A=&$L(&5T8RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!4:&4@9FEE;&0@;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1FEE;&1S*"D*("`@('L*("`@("`@("!R971U<FX@87)R87E?9FQI<"@D
M=&AI<RT^9FEE;&1S*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E
M<R!A('5N:79E<G-A;"]U;FEQ=64@:61E;G1I9FEE<B!F;W(@82!C;VYT86-T
M+B!4:&ES(&ES($Y/5`H@("`@("H@<V]M971H:6YG('1H870@=V4@97AP96-T
M('1O(&)E(&%B;&4@=&\@<&%R<V4@:6YT;R!A;B!A9&1R97-S8F]O:R!A;F0@
M80H@("`@("H@8V]N=&%C=$ED+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!!(&YI8V4@=6YI<75E('-T<FEN9R`H<VAO=6QD(&)E(#(U-2!C:&%R
M<R!O<B!L97-S*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&55240H
M*0H@("`@>PH@("`@("`@(')E='5R;B!D871E*"=9;61(:7,G*2`N("<N)R`N
M"B`@("`@("`@("`@('-U8G-T<BAB87-E7V-O;G9E<G0H;6EC<F]T:6UE*"DL
M(#$P+"`S-BDL("TQ-BD@+@H@("`@("`@("`@("`G0"<@+B`D1TQ/0D%,4ULG
M8V]N9B==6R=S97)V97(G75LG;F%M92==.PH@("`@?0H*("`@("\J*@H@("`@
M("H@17AP;W)T<R!A(&=I=F5N(%1U<F)A7T]B:F5C="!A<R!A;B!I0V%L96YD
M87(@=D-A<F0N"B`@("`@*@H@("`@("H@0'!A<F%M(%1U<F)A7T]B:F5C="`D
M;V)J96-T("!!(%1U<F)A7T]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7VE#86QE;F1A<E]V8V%R9"`@02!(;W)D95]I0V%L96YD87)?=F-A
M<F0@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;W9#87)D*"1O8FIE
M8W0I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L96YD
M87(O=F-A<F0N<&AP)SL*"B`@("`@("`@)&AA<V@@/2`D;V)J96-T+3YG971!
M='1R:6)U=&5S*"D["B`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE
M;F1A<B@I.PH@("`@("`@("1V8V%R9"`]($AO<F1E7VE#86QE;F1A<CHZ;F5W
M0V]M<&]N96YT*"=V8V%R9"<L("1I0V%L*3L*"B`@("`@("`@9F]R96%C:"`H
M)&AA<V@@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H
M)&ME>2D@>PH@("`@("`@("`@("!C87-E("=N86UE)SH*("`@("`@("`@("`@
M("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=&3B<L("1V86PI.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=N:6-K;F%M92<Z
M"B`@("`@("`@("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G3DE#2TY!
M344G+"`D=F%L*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G:&]M95!H;VYE)SH*("`@("`@("`@("`@("`@("1V8V%R9"T^
M<V5T071T<FEB=71E*"=414PG+"`D=F%L+"!A<G)A>2@G5%E012<]/B=(3TU%
M)RDI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=W;W)K4&AO;F4G.@H@("`@("`@("`@("`@("`@)'9C87)D+3YS971!='1R
M:6)U=&4H)U1%3"<L("1V86PL(&%R<F%Y*"=465!%)ST^)U=/4DLG*2D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-E;&Q0
M:&]N92<Z"B`@("`@("`@("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G
M5$5,)RP@)'9A;"P@87)R87DH)U194$4G/3XG0T5,3"<I*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G9F%X)SH*("`@("`@
M("`@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=414PG+"`D=F%L+"!A
M<G)A>2@G5%E012<]/B=&05@G*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)V5M86EL)SH*("`@("`@("`@("`@("`@("1V
M8V%R9"T^<V5T071T<FEB=71E*"=%34%)3"<L($AO<F1E7VE#86QE;F1A<E]V
M8V%R9#HZ9V5T0F%R945M86EL*"1V86PI*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G=&ET;&4G.@H@("`@("`@("`@("`@
M("`@)'9C87)D+3YS971!='1R:6)U=&4H)U1)5$Q%)RP@)'9A;"D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;7!A;GDG
M.@H@("`@("`@("`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)T]21R<L
M("1V86PI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=N;W1E<R<Z"B`@("`@("`@("`@("`@("`D=F-A<F0M/G-E=$%T=')I
M8G5T92@G3D]412<L("1V86PI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("=W96)S:71E)SH*("`@("`@("`@("`@("`@("1V
M8V%R9"T^<V5T071T<FEB=71E*"=54DPG+"`D=F%L*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8FER=&AD87DG.@H@("`@
M("`@("`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)T)$05DG+"`D=F%L
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1H87-H6R=L87-T;F%M92==*2!\
M?"`A96UP='DH)&AA<VA;)V9I<G-T;F%M92==*2D@>PH@("`@("`@("`@("`D
M82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@5D-!4D1?3E]&04U)3%D@/3X@
M:7-S970H)&AA<VA;)VQA<W1N86UE)UTI(#\@)&AA<VA;)VQA<W1N86UE)UT@
M.B`G)RP*("`@("`@("`@("`@("`@(%9#05)$7TY?1TE614X@(#T^(&ES<V5T
M*"1H87-H6R=F:7)S=&YA;64G72D@/R`D:&%S:%LG9FER<W1N86UE)UT@.B`G
M)RP*("`@("`@("`@("`@("`@(%9#05)$7TY?041$3"`@(#T^("<G+`H@("`@
M("`@("`@("`@("`@5D-!4D1?3E]04D5&25@@/3X@)R<L"B`@("`@("`@("`@
M("`@("!60T%21%].7U-51D9)6"`]/B`G)RP*("`@("`@("`@("`@*3L*("`@
M("`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)TXG+"!I;7!L;V1E*"<[
M)RP@)&$I+"!A<G)A>2@I+"!F86QS92P@)&$I.PH@("`@("`@('T*"B`@("`@
M("`@)&$@/2!A<G)A>2@*("`@("`@("`@("`@5D-!4D1?04127U!/0B`@("`@
M(#T^("<G+`H@("`@("`@("`@("!60T%21%]!1%)?15A414Y$("`@/3X@)R<L
M"B`@("`@("`@("`@(%9#05)$7T%$4E]35%)%150@("`]/B!I<W-E="@D:&%S
M:%LG:&]M94%D9')E<W,G72D@/R`D:&%S:%LG:&]M94%D9')E<W,G72`Z("<G
M+`H@("`@("`@("`@("!60T%21%]!1%)?3$]#04Q)5%D@/3X@:7-S970H)&AA
M<VA;)VAO;65#:71Y)UTI(#\@)&AA<VA;)VAO;65#:71Y)UT@.B`G)RP*("`@
M("`@("`@("`@5D-!4D1?04127U)%1TE/3B`@(#T^(&ES<V5T*"1H87-H6R=H
M;VUE4')O=FEN8V4G72D@/R`D:&%S:%LG:&]M95!R;W9I;F-E)UT@.B`G)RP*
M("`@("`@("`@("`@5D-!4D1?04127U!/4U1#3T1%(#T^(&ES<V5T*"1H87-H
M6R=H;VUE4&]S=&%L0V]D92==*2`_("1H87-H6R=H;VUE4&]S=&%L0V]D92==
M(#H@)R<L"B`@("`@("`@("`@(%9#05)$7T%$4E]#3U5.5%)9("`]/B!I<W-E
M="@D:&%S:%LG:&]M94-O=6YT<GDG72D@/R`D:&%S:%LG:&]M94-O=6YT<GDG
M72`Z("<G+`H@("`@("`@("D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U
M=&4H)T%$4B<L(&EM<&QO9&4H)SLG+"`D82DL(&%R<F%Y*"=465!%)R`]/B`G
M2$]-12<I+"!T<G5E+"`D82D["@H@("`@("`@("1A(#T@87)R87DH"B`@("`@
M("`@("`@(%9#05)$7T%$4E]03T(@("`@("`]/B`G)RP*("`@("`@("`@("`@
M5D-!4D1?04127T585$5.1"`@(#T^("<G+`H@("`@("`@("`@("!60T%21%]!
M1%)?4U121454("`@/3X@:7-S970H)&AA<VA;)W=O<FM!9&1R97-S)UTI(#\@
M)&AA<VA;)W=O<FM!9&1R97-S)UT@.B`G)RP*("`@("`@("`@("`@5D-!4D1?
M04127TQ/0T%,2519(#T^(&ES<V5T*"1H87-H6R=W;W)K0VET>2==*2`_("1H
M87-H6R=W;W)K0VET>2==(#H@)R<L"B`@("`@("`@("`@(%9#05)$7T%$4E]2
M14=)3TX@("`]/B!I<W-E="@D:&%S:%LG=V]R:U!R;W9I;F-E)UTI(#\@)&AA
M<VA;)W=O<FM0<F]V:6YC92==(#H@)R<L"B`@("`@("`@("`@(%9#05)$7T%$
M4E]03U-40T]$12`]/B!I<W-E="@D:&%S:%LG=V]R:U!O<W1A;$-O9&4G72D@
M/R`D:&%S:%LG=V]R:U!O<W1A;$-O9&4G72`Z("<G+`H@("`@("`@("`@("!6
M0T%21%]!1%)?0T]53E1262`@/3X@:7-S970H)&AA<VA;)W=O<FM#;W5N=')Y
M)UTI(#\@)&AA<VA;)W=O<FM#;W5N=')Y)UT@.B`G)RP*("`@("`@("`I.PH@
M("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=!1%(G+"!I;7!L;V1E*"<[
M)RP@)&$I+"!A<G)A>2@G5%E012<@/3X@)U=/4DLG*2P@=')U92P@)&$I.PH*
M("`@("`@("!R971U<FX@)'9C87)D.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4W1A=&EC(&9U;F-T:6]N('1O(&-O;G9E<G0@82!(;W)D95]I0V%L96YD87)?
M=F-A<F0@;V)J96-T(&EN=&\@82!4=7)B80H@("`@("H@3V)J96-T($AA<V@@
M=VET:"!4=7)B82!A='1R:6)U=&5S('-U:71A8FQE(&%S(&$@<&%R86UE=&5R
M(&9O<B!A9&0H*2X*("`@("`J"B`@("`@*B!`<V5E(&%D9"@I"B`@("`@*@H@
M("`@("H@0'!A<F%M($AO<F1E7VE#86QE;F1A<E]V8V%R9"`D=F-A<F0@(%1H
M92!(;W)D95]I0V%L96YD87)?=F-A<F0@;V)J96-T"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@<&%R<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!4=7)B82!A='1R:6)U=&4@:&%S
M:"X*("`@("`J+PH@("`@9G5N8W1I;VX@=&](87-H*"8D=F-A<F0I"B`@("![
M"B`@("`@("`@:68@*"%I<U]A*"1V8V%R9"P@)TAO<F1E7VE#86QE;F1A<E]V
M8V%R9"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=);G9A;&ED('!A<F%M971E<B!F;W(@5'5R8F%?1')I=F5R.CIT;TAA<V@H
M*2P@97AP96-T960@2&]R9&5?:4-A;&5N9&%R7W9C87)D(&]B:F5C="XG*3L*
M("`@("`@("!]"@H@("`@("`@("1H87-H(#T@87)R87DH*3L*("`@("`@("`D
M871T<B`]("1V8V%R9"T^9V5T06QL071T<FEB=71E<R@I.PH@("`@("`@(&9O
M<F5A8V@@*"1A='1R(&%S("1I=&5M*2!["B`@("`@("`@("`@(&EF("AE;7!T
M>2@D:71E;5LG=F%L=64G72DI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S=VET8V@@*"1I=&5M6R=N
M86UE)UTI('L*("`@("`@("`@("`@8V%S92`G1DXG.@H@("`@("`@("`@("`@
M("`@)&AA<VA;)VYA;64G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=.)SH*("`@("`@("`@
M("`@("`@("1N86UE(#T@)&ET96U;)W9A;'5E<R==.PH@("`@("`@("`@("`@
M("`@)&AA<VA;)VQA<W1N86UE)UT@/2`D;F%M95M60T%21%].7T9!34E,65T[
M"B`@("`@("`@("`@("`@("`D:&%S:%LG9FER<W1N86UE)UT@/2`D;F%M95M6
M0T%21%].7T=)5D5.73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G3DE#2TY!344G.@H@("`@("`@("`@("`@("`@)&AA<VA;
M)VYI8VMN86UE)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@+R\@5V4@=7-E($Q!0D5,(&)U="!A;'-O
M('-U<'!O<G0@0412+@H@("`@("`@("`@("!C87-E("=,04)%3"<Z"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=(3TU%)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)VAO;65!9&1R97-S)UT@
M/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D:71E;5LG<&%R86US)UU;)U=/4DLG72DI('L*("`@("`@("`@("`@
M("`@("`@("`D:&%S:%LG=V]R:T%D9')E<W,G72`]("1I=&5M6R=V86QU92==
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D:&%S:%LG=V]R:T%D9')E<W,G72`]("1I=&5M6R=V86QU92==.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`O+R!&;W(@=D-A<F0@,RXP+@H@("`@("`@("`@("!C87-E("=!1%(G
M.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG
M5%E012==*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)&ET96U;)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E012==(#T@87)R87DH)&ET96U;
M)W!A<F%M<R==6R=465!%)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&ET
M96U;)W!A<F%M<R==6R=465!%)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D:71E;5LG<&%R86US)UU;)U=/4DLG72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%
M)UU;72`]("=73U)+)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG2$]-12==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:71E;5LG<&%R86US)UU;
M)U194$4G75M=(#T@)TA/344G.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D861D<F5S<R`]("1I
M=&5M6R=V86QU97,G73L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I=&5M
M6R=P87)A;7,G75LG5%E012==(&%S("1A9'(I('L*("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*%-T<FEN9SHZ=7!P97(H)&%D<BDI('L*("`@("`@("`@
M("`@("`@("`@("!C87-E("=(3TU%)SH*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!R969I>"`]("=H;VUE)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)U=/4DLG.@H@("`@
M("`@("`@("`@("`@("`@("`@("`D<')E9FEX(#T@)W=O<FLG.PH@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`](&YU
M;&P["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'!R969I>"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:&%S
M:%LD<')E9FEX("X@)T%D9')E<W,G72`]("<G.PH*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<UM60T%21%]!1%)?4U121454
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F
M:7@@+B`G4W1R965T)UT@/2`D861D<F5S<UM60T%21%]!1%)?4U12145473L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G
M061D<F5S<R==("X]("1H87-H6R1P<F5F:7@@+B`G4W1R965T)UT@+B`B7&XB
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)&%D9')E<W-;5D-!4D1?04127TQ/0T%,2519
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F
M:7@@+B`G0VET>2==(#T@)&%D9')E<W-;5D-!4D1?04127TQ/0T%,251973L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G
M061D<F5S<R==("X]("1H87-H6R1P<F5F:7@@+B`G0VET>2==.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ETI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LD<')E9FEX("X@)U!R;W9I
M;F-E)UT@/2`D861D<F5S<UM60T%21%]!1%)?4D5'24].73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G061D<F5S<R==
M("X]("<L("<@+B`D:&%S:%LD<')E9FEX("X@)U!R;W9I;F-E)UT["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N("=0
M;W-T86Q#;V1E)UT@/2`D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N("=!
M9&1R97-S)UT@+CT@)R`G("X@)&AA<VA;)'!R969I>"`N("=0;W-T86Q#;V1E
M)UT["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<UM60T%21%]!1%)?0T]53E12
M65TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LD<')E
M9FEX("X@)T-O=6YT<GDG72`]("1A9&1R97-S6U9#05)$7T%$4E]#3U5.5%)9
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@
M+B`G061D<F5S<R==("X](")<;B(@+B`D:&%S:%LD<')E9FEX("X@)T-O=6YT
M<GDG73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N("=!9&1R97-S)UT@/2!T<FEM
M*"1H87-H6R1P<F5F:7@@+B`G061D<F5S<R==*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)U1%3"<Z"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=&05@G72DI('L*("`@("`@("`@
M("`@("`@("`@("`D:&%S:%LG9F%X)UT@/2`D:71E;5LG=F%L=64G73L*("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D:71E;5LG<&%R86US)UU;
M)U194$4G72DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1I=&5M6R=P87)A;7,G75LG5%E012==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:71E;5LG<&%R86US)UU;)U194$4G72`](&%R<F%Y*"1I=&5M
M6R=P87)A;7,G75LG5%E012==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@+R\@1F]R('9#87)D(#,N,"X*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D:71E;5LG<&%R86US)UU;)U194$4G72!A
M<R`D=&5L*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("A3=')I;F<Z
M.G5P<&5R*"1T96PI(#T]("=73U)+)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&AA<VA;)W=O<FM0:&]N92==(#T@)&ET96U;)W9A;'5E)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("A3=')I;F<Z.G5P
M<&5R*"1T96PI(#T]("=(3TU%)RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&AA<VA;)VAO;650:&]N92==(#T@)&ET96U;)W9A;'5E)UT["B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("A3=')I;F<Z.G5P<&5R
M*"1T96PI(#T]("=#14Q,)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&AA<VA;)V-E;&Q0:&]N92==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("A3=')I;F<Z.G5P<&5R*"1T
M96PI(#T]("=&05@G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:&%S:%LG9F%X)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I
M=&5M6R=P87)A;7,G75LG2$]-12==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D:&%S:%LG:&]M95!H;VYE)UT@/2`D:71E;5LG=F%L=64G73L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&ET96U;)W!A<F%M
M<R==6R=73U)+)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H87-H
M6R=W;W)K4&AO;F4G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("AI<W-E="@D:71E;5LG<&%R86US)UU;)T-%3$PG
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)V-E;&Q0:&]N
M92==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)VAO;650:&]N
M92==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=%34%)3"<Z"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&ET96U;)W!A<F%M<R==6R=04D5&)UTI('Q\("%I<W-E="@D:&%S:%LG
M96UA:6PG72DI('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG96UA:6PG
M72`]($AO<F1E7VE#86QE;F1A<E]V8V%R9#HZ9V5T0F%R945M86EL*"1I=&5M
M6R=V86QU92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G5$E43$4G.@H@("`@("`@("`@
M("`@("`@)&AA<VA;)W1I=&QE)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G3U)')SH*("`@
M("`@("`@("`@("`@("1H87-H6R=C;VUP86YY)UT@/2`D:71E;5LG=F%L=64G
M73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M3D]412<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG;F]T97,G72`]("1I=&5M
M6R=V86QU92==.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E("=54DPG.@H@("`@("`@("`@("`@("`@)&AA<VA;)W=E8G-I=&4G
M72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("="1$%9)SH*("`@("`@("`@("`@("`@("1H87-H
M6R=B:7)T:&1A>2==(#T@)&ET96U;)W9A;'5E)UU;)WEE87(G72`N("<M)R`N
M("1I=&5M6R=V86QU92==6R=M;VYT:"==("X@)RTG("X@("1I=&5M6R=V86QU
M92==6R=M9&%Y)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H87-H.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VAE8VMS(&EF('1H92!C=7)R96YT('5S97(@:&%S
M('1H92!R97%U97-T960@<&5R;6ES<VEO;G,@;VX@=&AI<PH@("`@("H@<V]U
M<F-E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M("!4:&4@
M<&5R;6ES<VEO;B!T;R!C:&5C:R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!U<V5R(&AA<R!P97)M:7-S:6]N+"!O
M=&AE<G=I<V4@9F%L<V4N"B`@("`@*B\*("`@("!F=6YC=&EO;B!H87-097)M
M:7-S:6]N*"1P97)M*0H@("`@('L*("`@("`@("`@:68@*"1T:&ES+3YU<VEN
M9U-H87)E<RD@>PH@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS:&%R92T^
M:&%S4&5R;6ES<VEO;BA!=71H.CIG971!=71H*"DL("1P97)M*3L*("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@(')E='5R;B!4=7)B83HZ:&%S4&5R
M;6ES<VEO;B@D=&AI<RT^;F%M92P@)W-O=7)C92<L("1P97)M*3L*("`@("`@
M("`@?0H@("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@86X@;V)J96-T
M(&ME>2!F;W(@82!N97<@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D871T<FEB=71E<R`@5&AE(&%T=')I8G5T97,@*&EN(&1R:79E<B!K
M97ES*2!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;V)J96-T(&)E:6YG(&%D9&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!!('5N:7%U92!)1"!F;W(@=&AE(&YE=R!O8FIE8W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]M86ME2V5Y*"1A='1R:6)U=&5S*0H@("`@>PH@("`@
M("`@(')E='5R;B!M9#4H;71?<F%N9"@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-T871I8R!M971H;V0@=&\@8V]N<W1R=6-T(%1U<F)A7T1R:79E<B!O
M8FIE8W1S+B!5<V4@=&AI<R!S;R!T:&%T('=E"B`@("`@*B!C86X@<F5T=7)N
M(%!%05)?17)R;W(@;V)J96-T<R!I9B!A;GET:&EN9R!G;V5S('=R;VYG+@H@
M("`@("H*("`@("`J(%-H;W5L9"!O;FQY(&)E(&-A;&QE9"!B>2!4=7)B85]$
M<FEV97(Z.G-I;F=L971O;B@I+@H@("`@("H*("`@("`J($!S964@5'5R8F%?
M1')I=F5R.CIS:6YG;&5T;VXH*0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@(%-T<FEN9R!C;VYT
M86EN:6YG('1H92!I;G1E<FYA;"!N86UE(&]F('1H:7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!S;W5R8V4N"B`@("`@*B!`<&%R86T@87)R87D@
M)&-O;F9I9R`@07)R87D@8V]N=&%I;FEN9R!T:&4@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T
M:&ES('-O=7)C92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&YA
M;64L("1C;VYF:6<I"B`@("!["B`@("`@("`@)&-L87-S(#T@8F%S96YA;64H
M)&-O;F9I9ULG='EP92==*3L*("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+T1R:79E<B\G("X@)&-L87-S("X@)RYP:'`G.PH@
M("`@("`@("1C;&%S<R`]("=4=7)B85]$<FEV97)?)R`N("1C;&%S<SL*("`@
M("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@
M)&1R:79E<B`]("9N97<@)&-L87-S*"1C;VYF:6=;)W!A<F%M<R==*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9')I=F5R(#T@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+B(I+"`D8VQA<W,I*3L*("`@("`@("`@("`@<F5T=7)N("1D
M<FEV97(["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)&1R:79E<BT^
M7VEN:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4W1O<F4@;F%M92!A;F0@=&ET;&4N("HO"B`@("`@("`@
M)&1R:79E<BT^;F%M92`]("1N86UE.PH@("`@("`@("1D<FEV97(M/G1I=&QE
M(#T@)&-O;F9I9ULG=&ET;&4G73L*"B`@("`@("`@+RH@4W1O<F4@86YD('1R
M86YS;&%T92!T:&4@;6%P(&%T('1H92!3;W5R8V4@;&5V96PN("HO"B`@("`@
M("`@)&1R:79E<BT^;6%P(#T@)&-O;F9I9ULG;6%P)UT["B`@("`@("`@9F]R
M96%C:"`H)&1R:79E<BT^;6%P(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@("`@("`@("`D
M9')I=F5R+3YF:65L9'-;)&ME>5T@/2`D=F%L.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T86)S+B`J+PH@("`@("`@(&EF
M("AI<W-E="@D8V]N9FEG6R=T86)S)UTI*2!["B`@("`@("`@("`@("1D<FEV
M97(M/G1A8G,@/2`D8V]N9FEG6R=T86)S)UT["B`@("`@("`@?0H*("`@("`@
M("`O*B!3=&]R92!S=')I8W0@9FEE;&1S+B`J+PH@("`@("`@(&EF("AI<W-E
M="@D8V]N9FEG6R=S=')I8W0G72DI('L*("`@("`@("`@("`@)&1R:79E<BT^
M<W1R:6-T(#T@)&-O;F9I9ULG<W1R:6-T)UT["B`@("`@("`@?0H*("`@("`@
M("`O*B!'970@82!S:&%R92!O8FIE8W0@:68@=V4@;F5E9"!I="X@*B\*("`@
M("`@("!I9B`H(65M<'1Y*"1C;VYF:6=;)W5S95]S:&%R97,G72DI('L*("`@
M("`@("`@("`@:68@*"AS=')P;W,H)&YA;64L("<Z)RD@/3T](&9A;'-E*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"$D1TQ/0D%,4ULG='5R8F%?<VAA<F5S
M)UTM/F5X:7-T<R@D;F%M92`N("<Z)R`N($%U=&@Z.F=E=$%U=&@H*2DI('L*
M("`@("`@("`@("`@("`@("`@("`O*B!5<V5R)W,@)V1E9F%U;'0G('-H87)E
M(&9O<B!T:&ES('-O=7)C92!T>7!E(&YO="!P<F5S96YT("HO"B`@("`@("`@
M("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=S;W5R8V54>7!E)R`]/B`D
M;F%M92D["B`@("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)E1U<F)A.CIC
M<F5A=&53:&%R92@D<&%R86US+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1S:&%R93L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;F%M
M92`N/2`G.B<@+B!!=71H.CIG971!=71H*"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&1R:79E<BT^<VAA<F4@/2`F)$=,3T)!3%-;)W1U<F)A7W-H
M87)E<R==+3YG9713:&%R92@D;F%M92D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1D<FEV97(M/G-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)&1R:79E<BT^<VAA<F4["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&1R:79E<BT^=7-I;F=3:&%R97,@/2!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1D<FEV97(M/G5S:6YG4VAA<F5S(#T@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1R:79E<CL*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R
M96YC92!T;R!A(&-O;F-R971E(%1U<F)A7T1R:79E<B!I;G-T86YC90H@("`@
M("H@8F%S960@;VX@=&AE("1C;VYF:6<@87)R87DN($ET('=I;&P@;VYL>2!C
M<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\*("`@("`J(%1U<F)A7T1R:79E
M<B!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY
M(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN
M=F]K960@87,Z"B`@("`@*B`@("1D<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS
M:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@:6YT97)N86P@;F%M92!O9B!T:&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V]U<F-E+@H@("`@("H*
M("`@("`J($!R971U<FX@5'5R8F%?1')I=F5R("!4:&4@8V]N8W)E=&4@5'5R
M8F%?1')I=F5R(')E9F5R96YC92P@;W(@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9S:6YG;&5T;VXH)&YA;64I"B`@("!["B`@("`@("`@<W1A=&EC
M("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97-;)&YA;65=*2D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1'
M3$]"04Q36R=C9F=3;W5R8V5S)UU;)&YA;65=*2D@>PH@("`@("`@("`@("`@
M("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E1H92!A
M9&1R97-S(&)O;VL@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(I+"`D;F%M92DI
M.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:6YS=&%N8V5S6R1N86UE72`]("94=7)B85]$<FEV
M97(Z.F9A8W1O<GDH)&YA;64L("1'3$]"04Q36R=C9F=3;W5R8V5S)UU;)&YA
M;65=*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1N
M86UE73L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&EB+TQI<W0N<&AP````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3(Q,0`Q,#0Q
M-S,V,C<U-@`P,3<W,C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!4=7)B85],:7-T.CH@8VQA
M<W,@<')O=FED97,@86X@:6YT97)F86-E(&9O<B!D96%L:6YG('=I=&@@80H@
M*B!L:7-T(&]F(%1U<F)A7T]B:F5C=',N"B`J"B`J("1(;W)D93H@='5R8F$O
M;&EB+TQI<W0N<&AP+'8@,2XT,2XQ,"XT(#(P,#4O,3`O,3@@,3(Z-3`Z,#4@
M:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`8W-H
M+G)I="YE9'4^"B`J($!P86-K86=E(%1U<F)A"B`J+PIC;&%S<R!4=7)B85],
M:7-T('L*"B`@("`O*BH*("`@("`J(%1H92!A<G)A>2!C;VYT86EN:6YG('1H
M92!4=7)B85]/8FIE8W1S(')E<')E<V5N=&5D(&EN('1H:7,@;&ES="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D;V)J96-T
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@9FEE;&0@=&\@8V]M
M<&%R92!O8FIE8W1S(&)Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W5S;W)T0W)I=&5R:6$["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@5'5R8F%?3&ES
M="@D:61S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)&ED<RD@>PH@
M("`@("`@("`@("!F;W)E86-H("@D:61S(&%S("1V86QU92D@>PH@("`@("`@
M("`@("`@("`@;&ES="@D<V]U<F-E+"`D:V5Y*2`](&5X<&QO9&4H)SHG+"`D
M=F%L=64I.PH@("`@("`@("`@("`@("`@)&1R:79E<B`]("94=7)B85]$<FEV
M97(Z.G-I;F=L971O;B@D<V]U<F-E*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1D<FEV97(L("=4=7)B85]$<FEV97(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YI;G-E<G0H)&1R:79E<BT^9V5T3V)J96-T*"1K97DI
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($EN<V5R=',@82!N97<@;V)J96-T(&EN
M=&\@=&AE(&QI<W0N"B`@("`@*@H@("`@("H@0'!A<F%M(%1U<F)A7T]B:F5C
M="`D;V)J96-T("!4:&4@;V)J96-T('1O(&EN<V5R="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:6YS97)T*"1O8FIE8W0I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)&]B:F5C="P@)U1U<F)A7T]B:F5C="<I*2!["B`@("`@("`@("`@("1K
M97D@/2`D;V)J96-T+3YG9713;W5R8V4H*2`N("<Z)R`N("1O8FIE8W0M/F=E
M=%9A;'5E*"=?7VME>2<I.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3YO8FIE8W1S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F]B
M:F5C='-;)&ME>5T@/2`D;V)J96-T.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5S971S(&]U<B!I;G1E<FYA;"!P
M;VEN=&5R('1O('1H92!B96=I;FYI;F<@;V8@=&AE(&QI<W0N(%5S92!T:&ES
M('1O"B`@("`@*B!H:61E('1H92!I;G1E<FYA;"!S=&]R86=E("AA<G)A>2P@
M;&ES="P@971C+BD@9G)O;2!C;&EE;G0@;V)J96-T<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5S970H*0H@("`@>PH@("`@("`@(')E<V5T*"1T:&ES+3YO
M8FIE8W1S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE
M>'0@5'5R8F%?3V)J96-T(&EN('1H92!L:7-T+B!5<V4@=&AI<R!T;R!H:61E
M(&EN=&5R;F%L"B`@("`@*B!I;7!L96UE;G1A=&EO;B!D971A:6QS(&9R;VT@
M8VQI96YT(&]B:F5C=',N"B`@("`@*@H@("`@("H@0')E='5R;B!4=7)B85]/
M8FIE8W0@(%1H92!N97AT(&]B:F5C="!I;B!T:&4@;&ES="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;F5X="@I"B`@("!["B`@("`@("`@;&ES="@L)'1M<"D@
M/2!E86-H*"1T:&ES+3YO8FIE8W1S*3L*("`@("`@("!R971U<FX@)'1M<#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O9B!4
M=7)B85]/8FIE8W1S('1H870@87)E(&EN('1H92!L:7-T+B!5<V4@=&AI<R!T
M;PH@("`@("H@:&ED92!I;G1E<FYA;"!I;7!L96UE;G1A=&EO;B!D971A:6QS
M(&9R;VT@8VQI96YT(&]B:F5C=',N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4:&4@;G5M8F5R(&]F(&]B:F5C=',@:6X@=&AE(&QI<W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT*"D*("`@('L*("`@("`@("!R971U
M<FX@8V]U;G0H)'1H:7,M/F]B:F5C=',I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1FEL=&5R<R]3;W)T<R!T:&4@;&ES="!B87-E9"!O;B!T:&4@<W!E8VEF
M:65D('-O<G0@<F]U=&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@)'-O<G0@
M(%1H92!S;W)T(&UE=&AO9"X*("`@("`J($!P87)A;2`D;&]W("`@5&AE(&QO
M=R!E;F0@;V8@=&AE('-O<G0@<F%N9V4N"B`@("`@*B!`<&%R86T@)&AI9V@@
M(%1H92!H:6=H(&5N9"!O9B!T:&4@<V]R="!R86YG92X*("`@("`J($!P87)A
M;2`D9&ER("`@4V]R="!D:7)E8W1I;VXL(#`@/2!A<V-E;F1I;F<L(#$@/2!D
M97-C96YD:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G0H)'-O<G0@/2`G
M;&%S=&YA;64G+"`D9&ER(#T@,"D*("`@('L*("`@("`@("!G;&]B86P@)'!R
M969S+"`D871T<FEB=71E<SL*"B`@("`@("`@)'-O<G1E9%]O8FIE8W1S(#T@
M87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F]B:F5C=',@87,@
M)&ME>2`]/B`D;V)J96-T*2!["B`@("`@("`@("`@("1L87-T;F%M92`]("1O
M8FIE8W0M/F=E=%9A;'5E*"=L87-T;F%M92<I.PH@("`@("`@("`@("!I9B`H
M(21L87-T;F%M92D@>PH@("`@("`@("`@("`@("`@)&QA<W1N86UE(#T@5'5R
M8F$Z.F=U97-S3&%S=&YA;64H)&]B:F5C="T^9V5T5F%L=64H)VYA;64G*2D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]B:F5C="T^<V5T5F%L=64H
M)VQA<W1N86UE)RP@)&QA<W1N86UE*3L*("`@("`@("`@("`@)'-O<G1E9%]O
M8FIE8W1S6R1K97E=(#T@)&]B:F5C=#L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?=7-O<G1#<FET97)I82`]("1S;W)T.PH*("`@("`@("`O+R!3970@
M=&AE(&-O;7!A<FES;VX@='EP92!B87-E9"!O;B!T:&4@='EP92!O9B!A='1R
M:6)U=&4@=V4G<F4*("`@("`@("`O+R!S;W)T:6YG(&)Y+@H@("`@("`@("1T
M:&ES+3Y?=7-O<G14>7!E(#T@)W1E>'0G.PH@("`@("`@(&EF("AI<W-E="@D
M871T<FEB=71E<ULD<V]R=%TI*2!["B`@("`@("`@("`@(&EF("@A96UP='DH
M)&%T=')I8G5T97-;)'-O<G1=6R=C;7!T>7!E)UTI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W5S;W)T5'EP92`]("1A='1R:6)U=&5S6R1S;W)T75LG
M8VUP='EP92==.PH@("`@("`@("`@("!](&5L<V5I9B`H)&%T=')I8G5T97-;
M)'-O<G1=6R=T>7!E)UT@/3T@)VEN="<@?'P*("`@("`@("`@("`@("`@("`@
M("`@("1A='1R:6)U=&5S6R1S;W)T75LG='EP92==(#T]("=I;G1L:7-T)R!\
M?`H@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)'-O<G1=6R=T
M>7!E)UT@/3T@)VYU;6)E<B<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=7-O<G14>7!E(#T@)VEN="<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@('5S;W)T*"1S;W)T961?;V)J96-T<RP@87)R87DH)'1H:7,L("=C
M;7`G*2D["@H@("`@("`@(&EF("@D9&ER(#T](#$I('L*("`@("`@("`@("`@
M)'1H:7,M/F]B:F5C=',@/2!A<G)A>5]R979E<G-E*"1S;W)T961?;V)J96-T
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F]B:F5C
M=',@/2`D<V]R=&5D7V]B:F5C=',["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@57-O<G0@:&5L<&5R(&9U;F-T:6]N+@H@("`@("H*("`@("`J
M($-O;7!A<F5S('1W;R!4=7)B85]/8FIE8W1S(&)A<V5D(&]N('1H92!M96UB
M97(@=F%R:6%B;&4*("`@("`J("1?=7-O<G1#<FET97)I82P@=&%K:6YG(&-A
M<F4@=&\@<V]R="!N=6UE<FEC86QL>2!I9B!I="!I<R!A;B!I;G1E9V5R"B`@
M("`@*B!F:65L9"X*("`@("`J"B`@("`@*B!`<&%R86T@5'5R8F%?3V)J96-T
M("1A("!4:&4@9FER<W0@5'5R8F%?3V)J96-T('1O(&-O;7!A<F4N"B`@("`@
M*B!`<&%R86T@5'5R8F%?3V)J96-T("1B("!4:&4@<V5C;VYD(%1U<F)A7T]B
M:F5C="!T;R!C;VUP87)E+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@0V]M<&%R:7-O;B!O9B!T:&4@='=O(&9I96QD('9A;'5E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@8VUP*"1A+"`D8BD*("`@('L*("`@("`@("!S=VET
M8V@@*"1T:&ES+3Y?=7-O<G14>7!E*2!["B`@("`@("`@8V%S92`G:6YT)SH*
M("`@("`@("`@("`@<F5T=7)N("@D82T^9V5T5F%L=64H)'1H:7,M/E]U<V]R
M=$-R:71E<FEA*2`^("1B+3YG971686QU92@D=&AI<RT^7W5S;W)T0W)I=&5R
M:6$I*2`_(#$@.B`M,3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)W1E>'0G.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1A8VUP
M(#T@4W1R:6YG.CIL;W=E<B@D82T^9V5T5F%L=64H)'1H:7,M/E]U<V]R=$-R
M:71E<FEA*2P@=')U92D["B`@("`@("`@("`@("1B8VUP(#T@4W1R:6YG.CIL
M;W=E<B@D8BT^9V5T5F%L=64H)'1H:7,M/E]U<V]R=$-R:71E<FEA*2P@=')U
M92D["@H@("`@("`@("`@("`O+R!5<V4@<W1R8V]L;"!F;W(@;&]C86QE+7-A
M9F4@8V]M<&%R:7-O;G,N"B`@("`@("`@("`@(')E='5R;B!S=')C;VQL*"1A
M8VUP+"`D8F-M<"D["B`@("`@("`@?0H@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQI8B]A<&DN<&AP
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,C<V
M-#4`,3`T,3<S-C(W-38`,#$W-C$P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4=7)B82!E>'1E<FYA
M;"!!4$D@:6YT97)F86-E+@H@*@H@*B`D2&]R9&4Z('1U<F)A+VQI8B]A<&DN
M<&AP+'8@,2XQ,C`N,BXR-B`R,#`V+S`S+S`V(#$S.C4T.C`T(&IA;B!%>'`@
M)`H@*@H@*B!4:&ES(&9I;&4@9&5F:6YE<R!4=7)B82=S(&5X=&5R;F%L($%0
M22!I;G1E<F9A8V4N($]T:&5R(&%P<&QI8V%T:6]N<R!C86X*("H@:6YT97)A
M8W0@=VET:"!4=7)B82!T:')O=6=H('1H:7,@05!)+@H@*@H@*B!`<&%C:V%G
M92!4=7)B80H@*B\*"B1?<V5R=FEC97-;)W!E<FUS)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E
M?6AA<VA(87-H)PHI.PH*)%]S97)V:6-E<ULG<VAO=R==(#T@87)R87DH"B`@
M("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O9&ES<&QA>2YP:'`_<V]U<F-E
M/7QS;W5R8V5\)FME>3U\:V5Y?"9U:60]?'5I9'PG+`HI.PH*)%]S97)V:6-E
M<ULG8G)O=W-E)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<&%T
M:"<@/3X@)W-T<FEN9R<L("=P<F]P97)T:65S)R`]/B`G>W5R;CIH;W)D97US
M=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?6AA<VA(
M87-H)RP**3L*"B1?<V5R=FEC97-;)W-O=7)C97,G72`](&%R<F%Y*`H@("`@
M)V%R9W,G(#T^(&%R<F%Y*"=W<FET96%B;&4G(#T^("=B;V]L96%N)RDL"B`@
M("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG+`HI.PH*)%]S
M97)V:6-E<ULG9FEE;&1S)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A
M>2@G<V]U<F-E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@
M)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RP**3L*"B1?<V5R
M=FEC97-;)VQI<W0G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"DL
M"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG+`HI.PH*
M)%]S97)V:6-E<ULG;&ES=$)Y)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A
M<G)A>2@G86-T:6]N)R`]/B`G<W1R:6YG)RP@)W1I;65S=&%M<"<@/3X@)VEN
M="<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RP*
M*3L*"B1?<V5R=FEC97-;)V=E=$%C=&EO;E1I;65S=&%M<"==(#T@87)R87DH
M"B`@("`G87)G<R<@/3X@87)R87DH)W5I9"<@/3X@)W-T<FEN9R<L("=T:6UE
M<W1A;7`G(#T^("=I;G0G*2P*("`@("=T>7!E)R`]/B`G:6YT)RP**3L*"B1?
M<V5R=FEC97-;)VEM<&]R="==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R
M87DH)V-O;G1E;G0G(#T^("=S=')I;F<G+"`G8V]N=&5N=%1Y<&4G(#T^("=S
M=')I;F<G+"`G<V]U<F-E)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@
M)W-T<FEN9R<L"BD["@HD7W-E<G9I8V5S6R=E>'!O<G0G72`](&%R<F%Y*`H@
M("`@)V%R9W,G(#T^(&%R<F%Y*"=U:60G(#T^("=S=')I;F<G+"`G8V]N=&5N
M=%1Y<&4G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G<W1R:6YG)RP*
M*3L*"B1?<V5R=FEC97-;)V1E;&5T92==(#T@87)R87DH"B`@("`G87)G<R<@
M/3X@87)R87DH)W5I9"<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B
M;V]L96%N)RP**3L*"B1?<V5R=FEC97-;)W)E<&QA8V4G72`](&%R<F%Y*`H@
M("`@)V%R9W,G(#T^(&%R<F%Y*"=U:60G(#T^("=S=')I;F<G+"`G8V]N=&5N
M="<@/3X@)W-T<FEN9R<L("=C;VYT96YT5'EP92<@/3X@)W-T<FEN9R<I+`H@
M("`@)W1Y<&4G(#T^("=B;V]L96%N)RP**3L*"B1?<V5R=FEC97-;)W-E87)C
M:"==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)VYA;65S)R`]/B`G
M>W5R;CIH;W)D97US=')I;F=!<G)A>2<L"B`@("`@("`@("`@("`@("`@("`@
M)W-O=7)C97,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RP*("`@("`@
M("`@("`@("`@("`@("`G9FEE;&1S)R`]/B`G>W5R;CIH;W)D97US=')I;F=!
M<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y
M)RP**3L*"B1?<V5R=FEC97-;)V=E=$-O;G1A8W0G72`](&%R<F%Y*`H@("`@
M)V%R9W,G(#T^(&%R<F%Y*"=S;W5R8V4G(#T^("=S=')I;F<G+"`G;V)J96-T
M260G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US
M=')I;F=!<G)A>2<L"BD["@HD7W-E<G9I8V5S6R=G971#;VYT86-T<R==(#T@
M87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-O=7)C92<@/3X@)W-T<FEN
M9R<L("=O8FIE8W1)9',G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL
M"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG+`HI.PH*
M)%]S97)V:6-E<ULG861D1FEE;&0G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^
M(&%R<F%Y*"=A9&1R97-S)R`]/B`G<W1R:6YG)RP@)VYA;64G(#T^("=S=')I
M;F<G+"`G9FEE;&0G(#T^("=S=')I;F<G+"`G=F%L=64G(#T^("=S=')I;F<G
M+"`G<V]U<F-E)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)WMU<FXZ
M:&]R9&5]<W1R:6YG07)R87DG+`HI.PH*)%]S97)V:6-E<ULG9&5L971E1FEE
M;&0G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=A9&1R97-S)R`]
M/B`G<W1R:6YG)RP@)V9I96QD)R`]/B`G<W1R:6YG)RP@)W-O=7)C97,G(#T^
M("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP92<@/3X@)WMU
M<FXZ:&]R9&5]<W1R:6YG07)R87DG+`HI.PH*)%]S97)V:6-E<ULG9V5T1FEE
M;&0G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=A9&1R97-S)R`]
M/B`G<W1R:6YG)RP@)V9I96QD)R`]/B`G<W1R:6YG)RP@)W-O=7)C97,G(#T^
M("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RP@)W-T<FEC="<@/3X@)V)O;VQE
M86XG*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<L
M"BD["@HD7W-E<G9I8V5S6R=G971!;&Q!='1R:6)U=&5686QU97,G72`](&%R
M<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=F:65L9"<@/3X@)W-T<FEN9R<L
M("=S;W5R8V5S)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@
M)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RP**3L*"B1?<V5R
M=FEC97-;)V=E=$-L:65N=%-O=7)C92==(#T@87)R87DH"B`@("`G8VAE8VMP
M97)M<R<@/3X@9F%L<V4L"B`@("`G87)G<R<@/3X@87)R87DH*2P*("`@("=T
M>7!E)R`]/B`G<W1R:6YG)RP**3L*"B1?<V5R=FEC97-;)V=E=$-L:65N="==
M(#T@87)R87DH"B`@("`G8VAE8VMP97)M<R<@/3X@9F%L<V4L"B`@("`G87)G
M<R<@/3X@87)R87DH)V]B:F5C=$ED)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP
M92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG+`HI.PH*)%]S97)V:6-E
M<ULG9V5T0VQI96YT<R==(#T@87)R87DH"B`@("`G8VAE8VMP97)M<R<@/3X@
M9F%L<V4L"B`@("`G87)G<R<@/3X@87)R87DH)V]B:F5C=$ED<R<@/3X@)WMU
M<FXZ:&]R9&5]<W1R:6YG07)R87DG*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH
M;W)D97US=')I;F=!<G)A>2<L"BD["@HD7W-E<G9I8V5S6R=A9&1#;&EE;G0G
M72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=A='1R:6)U=&5S)R`]
M/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=S
M=')I;F<G+`HI.PH*)%]S97)V:6-E<ULG=7!D871E0VQI96YT)UT@/2!A<G)A
M>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G;V)J96-T260G(#T^("=S=')I;F<G
M+"`G871T<FEB=71E<R<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG*2P*
M("`@("=T>7!E)R`]/B`G<W1R:6YG)RP**3L*"B1?<V5R=FEC97-;)V1E;&5T
M94-L:65N="==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)V]B:F5C
M=$ED)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]
M<W1R:6YG07)R87DG+`HI.PH*)%]S97)V:6-E<ULG<V5A<F-H0VQI96YT<R==
M(#T@87)R87DH"B`@("`G8VAE8VMP97)M<R<@/3X@9F%L<V4L"B`@("`G87)G
M<R<@/3X@87)R87DH)VYA;65S)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<L("=F:65L9',G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@
M("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG+`HI.PH*)%]S
M97)V:6-E<ULG8V]M;65N=$-A;&QB86-K)UT@/2!A<G)A>2@*("`@("=A<F=S
M)R`]/B!A<G)A>2@G:60G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G
M<W1R:6YG)PHI.PH*)%]S97)V:6-E<ULG:&%S0V]M;65N=',G72`](&%R<F%Y
M*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@("`G='EP92<@/3X@)V)O;VQE
M86XG"BD["@H*9G5N8W1I;VX@7W1U<F)A7V-O;6UE;G1#86QL8F%C:R@D:60I
M"GL*("`@(&EF("@A)$=,3T)!3%-;)V-O;F8G75LG8V]M;65N=',G75LG86QL
M;W<G72D@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!`9&5F
M:6YE*"=455)"05]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD[
M"B`@("!R97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+V)A<V4N<&AP
M)SL*("`@(&=L;V)A;"`D8V9G4V]U<F-E<SL*"B`@("!L:7-T*"1S;W5R8V4L
M("1K97DI(#T@97AP;&]D92@G+B<L("1I9"P@,BD["B`@("!I9B`H:7-S970H
M)&-F9U-O=7)C97-;)'-O=7)C95TI*2!["B`@("`@("`@)&1R:79E<B`]("94
M=7)B85]$<FEV97(Z.G-I;F=L971O;B@D<V]U<F-E*3L*("`@("`@("!I9B`H
M(6ES7V$H)&1R:79E<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D
M;V)J96-T(#T@)&1R:79E<BT^9V5T3V)J96-T*"1K97DI.PH@("`@("`@("`@
M("!I9B`H(6ES7V$H)&]B:F5C="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1O8FIE8W0M/F=E=%9A;'5E*"=N86UE)RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N(&9A;'-E
M.PI]"@IF=6YC=&EO;B!?='5R8F%?:&%S0V]M;65N=',H*0I["B`@("!R971U
M<FX@)$=,3T)!3%-;)V-O;F8G75LG8V]M;65N=',G75LG86QL;W<G73L*?0H*
M9G5N8W1I;VX@7W1U<F)A7W!E<FUS*"D*>PH@("`@<W1A=&EC("1P97)M<R`]
M(&%R<F%Y*"D["B`@("!I9B`H(65M<'1Y*"1P97)M<RDI('L*("`@("`@("!R
M971U<FX@)'!E<FUS.PH@("`@?0H*("`@($!D969I;F4H)U154D)!7T)!4T4G
M+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*("`@(')E<75I<F5?;VYC
M92!455)"05]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH@("`@<F5Q=6ER92!4
M55)"05]"05-%("X@)R]C;VYF:6<O<V]U<F-E<RYP:'`G.PH*("`@("1P97)M
M<ULG=')E92==6R=T=7)B82==6R=S;W5R8V5S)UT@/2!F86QS93L*("`@("1P
M97)M<ULG=&ET;&4G75LG='5R8F$Z<V]U<F-E<R==(#T@7R@B4V]U<F-E<R(I
M.PH*("`@("\O(%)U;B!T:')O=6=H(&5V97)Y(&-O;G1A8W0@<V]U<F-E+@H@
M("`@9F]R96%C:"`H)&-F9U-O=7)C97,@87,@)'-O=7)C92`]/B`D8W5R4V]U
M<F-E*2!["B`@("`@("`@)'!E<FUS6R=T<F5E)UU;)W1U<F)A)UU;)W-O=7)C
M97,G75LD<V]U<F-E72`](&9A;'-E.PH@("`@("`@("1P97)M<ULG=&ET;&4G
M75LG='5R8F$Z<V]U<F-E<SHG("X@)'-O=7)C95T@/2`D8W5R4V]U<F-E6R=T
M:71L92==.PH@("`@("`@("1P97)M<ULG=')E92==6R=T=7)B82==6R=S;W5R
M8V5S)UU;)'-O=7)C95U;)VUA>%]C;VYT86-T<R==(#T@9F%L<V4["B`@("`@
M("`@)'!E<FUS6R=T:71L92==6R=T=7)B83IS;W5R8V5S.B<@+B`D<V]U<F-E
M("X@)SIM87A?8V]N=&%C=',G72`](%\H(DUA>&EM=6T@3G5M8F5R(&]F($-O
M;G1A8W1S(BD["B`@("`@("`@)'!E<FUS6R=T>7!E)UU;)W1U<F)A.G-O=7)C
M97,Z)R`N("1S;W5R8V4@+B`G.FUA>%]C;VYT86-T<R==(#T@)VEN="<["B`@
M("!]"@H@("`@<F5T=7)N("1P97)M<SL*?0H*9G5N8W1I;VX@7W1U<F)A7W-O
M=7)C97,H)'=R:71E86)L92`](&9A;'-E*0I["B`@("!R97%U:7)E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A<V4N<&AP)SL*"B`@("`D861D<F5S
M<V)O;VMS(#T@5'5R8F$Z.F=E=$%D9')E<W-";V]K<R@D=W)I=&5A8FQE(#\@
M4$5235-?141)5"`Z(%!%4DU37U)%040I.PH@("`@9F]R96%C:"`H)&%D9')E
M<W-B;V]K<R!A<R`D861D<F5S<V)O;VL@/3X@)&-O;F9I9RD@>PH@("`@("`@
M("1A9&1R97-S8F]O:W-;)&%D9')E<W-B;V]K72`]("1C;VYF:6=;)W1I=&QE
M)UT["B`@("!]"@H@("`@<F5T=7)N("1A9&1R97-S8F]O:W,["GT*"F9U;F-T
M:6]N(%]T=7)B85]F:65L9',H)'-O=7)C92`]("<G*0I["B`@("!R97%U:7)E
M7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A<V4N<&AP)SL*("`@(&=L
M;V)A;"`D8V9G4V]U<F-E<RP@)&%T=')I8G5T97,["@H@("`@:68@*&5M<'1Y
M*"1S;W5R8V4I('Q\("%I<W-E="@D8V9G4V]U<F-E<ULD<V]U<F-E72DI('L*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*"));G9A;&ED(&%D
M9')E<W,@8F]O:R(I+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL+"`D<V]U
M<F-E*3L*("`@('T*"B`@("`D9FEE;&1S(#T@87)R87DH*3L*("`@(&9O<F5A
M8V@@*"1C9F=3;W5R8V5S6R1S;W5R8V5=6R=M87`G72!A<R`D9FEE;&1?;F%M
M92`]/B`D;G5L;"D@>PH@("`@("`@(&EF("AS=6)S='(H)&9I96QD7VYA;64L
M(#`L(#(I("$]("=?7R<I('L*("`@("`@("`@("`@)&9I96QD<ULD9FEE;&1?
M;F%M95T@/2!A<G)A>2@G;F%M92<@/3X@)&9I96QD7VYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("1A
M='1R:6)U=&5S6R1F:65L9%]N86UE75LG='EP92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L86)E;"<@/3X@)&%T=')I
M8G5T97-;)&9I96QD7VYA;65=6R=L86)E;"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S96%R8V@G(#T^(&EN7V%R<F%Y
M*"1F:65L9%]N86UE+"`D8V9G4V]U<F-E<ULD<V]U<F-E75LG<V5A<F-H)UTI
M*3L*("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N("1F:65L9',["GT*"B\J
M*@H@*B!"<F]W<V5S('1H<F]U9V@@5'5R8F$G<R!O8FIE8W0@=')E92X*("H*
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@<&%T:"!O9B!T:&4@
M=')E92!T;R!B<F]W<V4N"B`J($!P87)A;2!A<G)A>2`D<')O<&5R=&EE<R`@
M5&AE(&ET96T@<')O<&5R=&EE<R!T;R!R971U<FXN($1E9F%U;'1S('1O("=N
M86UE)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;B<L(&%N
M9"`G8G)O=W-E86)L92<N"B`J"B`J($!R971U<FX@87)R87D@($-O;G1E;G0@
M;V8@=&AE('-P96-I9FEE9"!P871H+@H@*B\*9G5N8W1I;VX@7W1U<F)A7V)R
M;W=S92@D<&%T:"`]("<G+"`D<')O<&5R=&EE<R`](&%R<F%Y*"DI"GL*("`@
M(&9U;F-T:6]N(%]M;V1I9FEE9"@D=6ED*0H@("`@>PH@("`@("`@("1M;V1I
M9FEE9"`](%]T=7)B85]G971!8W1I;VY4:6UE<W1A;7`H)'5I9"P@)VUO9&EF
M>2<I.PH@("`@("`@(&EF("AE;7!T>2@D;6]D:69I960I*2!["B`@("`@("`@
M("`@("1M;V1I9FEE9"`](%]T=7)B85]G971!8W1I;VY4:6UE<W1A;7`H)'5I
M9"P@)V%D9"<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&UO9&EF:65D
M.PH@("`@?0H*("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O8F%S92YP:'`G.PH@("`@9VQO8F%L("1R96=I<W1R>2P@)&-F9U-O=7)C
M97,["@H@("`@+R\@1&5F875L="!P<F]P97)T:65S+@H@("`@:68@*"$D<')O
M<&5R=&EE<RD@>PH@("`@("`@("1P<F]P97)T:65S(#T@87)R87DH)VYA;64G
M+"`G:6-O;B<L("=B<F]W<V5A8FQE)RD["B`@("!]"@H@("`@+R\@36%S<V%G
M92!T:&4@<&%T:"!I;G1O('1H92!F;W)M('=E('=A;G0N"B`@("!I9B`H<W5B
M<W1R*"1P871H+"`P+"`U*2`]/2`G='5R8F$G*2!["B`@("`@("`@)'!A=&@@
M/2!S=6)S='(H)'!A=&@L(#4I.PH@("`@?0H@("`@:68@*'-U8G-T<B@D<&%T
M:"P@,"P@,2D@/3T@)R\G*2!["B`@("`@("`@)'!A=&@@/2!S=6)S='(H)'!A
M=&@L(#$I.PH@("`@?0H@("`@:68@*'-U8G-T<B@D<&%T:"P@+3$I(#T]("<O
M)RD@>PH@("`@("`@("1P871H(#T@<W5B<W1R*"1P871H+"`P+"`M,2D["B`@
M("!]"@H@("`@+R\@1V5T(&$@;&ES="!O9B!A9&1R97-S(&)O;VMS+@H@("`@
M)&%D9')E<W-B;V]K<R`](%1U<F)A.CIG971!9&1R97-S0F]O:W,H*3L*"B`@
M("!I9B`H96UP='DH)'!A=&@I*2!["B`@("`@("`@)')E<W5L=',@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1A9&1R97-S8F]O:W,@87,@)&%D9')E
M<W-B;V]K(#T^("1I;F9O*2!["B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@G
M;F%M92<L("1P<F]P97)T:65S*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L
M='-;)W1U<F)A+R<@+B`D861D<F5S<V)O;VM=6R=N86UE)UT@/2`D:6YF;ULG
M=&ET;&4G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:6Y?87)R
M87DH)VEC;VXG+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@("`@("1R
M97-U;'1S6R=T=7)B82\G("X@)&%D9')E<W-B;V]K75LG:6-O;B==(#T@)')E
M9VES=')Y+3YG971);6%G941I<B@I("X@)R]T=7)B82YP;F<G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@G8G)O=W-E86)L92<L
M("1P<F]P97)T:65S*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L='-;)W1U
M<F)A+R<@+B`D861D<F5S<V)O;VM=6R=B<F]W<V5A8FQE)UT@/2`A96UP='DH
M)&-F9U-O=7)C97-;)&%D9')E<W-B;V]K75LG8G)O=W-E)UTI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@G8V]N=&5N='1Y<&4G
M+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@("`@("1R97-U;'1S6R=T
M=7)B82\G("X@)&%D9')E<W-B;V]K75LG8V]N=&5N='1Y<&4G72`]("=H='1P
M9"]U;FEX+61I<F5C=&]R>2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*&EN7V%R<F%Y*"=C;VYT96YT;&5N9W1H)RP@)'!R;W!E<G1I97,I*2![
M"B`@("`@("`@("`@("`@("`D<F5S=6QT<ULG='5R8F$O)R`N("1A9&1R97-S
M8F]O:UU;)V-O;G1E;G1L96YG=&@G72`](#`["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*&EN7V%R<F%Y*"=M;V1I9FEE9"<L("1P<F]P97)T:65S
M*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L='-;)W1U<F)A+R<@+B`D861D
M<F5S<V)O;VM=6R=M;V1I9FEE9"==(#T@=&EM92@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@G8W)E871E9"<L("1P<F]P97)T
M:65S*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L='-;)W1U<F)A+R<@+B`D
M861D<F5S<V)O;VM=6R=C<F5A=&5D)UT@/2`P.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@('T@96QS96EF
M("AI<W-E="@D861D<F5S<V)O;VMS6R1P871H72DI('L*("`@("`@("`O+R!,
M;V%D('1H92!4=7)B82!D<FEV97(N"B`@("`@("`@)&1R:79E<B`]("94=7)B
M85]$<FEV97(Z.G-I;F=L971O;B@D<&%T:"D["B`@("`@("`@:68@*&ES7V$H
M)&1R:79E<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O;FYE8W1I;VX@9F%I;&5D
M.B`E<R(I+"`D9')I=F5R+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G
M+"!N=6QL+"!N=6QL+"`D8V9G4V]U<F-E<ULD<&%T:%TI.PH@("`@("`@('T*
M"B`@("`@("`@)&-O;G1A8W1S(#T@)&1R:79E<BT^<V5A<F-H*&%R<F%Y*"DI
M.PH@("`@("`@(&EF("AI<U]A*"1C;VYT86-T<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&-O;G1A8W1S.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@("1C;VYT86-T<RT^
M<F5S970H*3L*("`@("`@("!W:&EL92`H)&-O;G1A8W0@/2`D8V]N=&%C=',M
M/FYE>'0H*2D@>PH@("`@("`@("`@("`D:V5Y(#T@)W1U<F)A+R<@+B`D8V]N
M=&%C="T^9V5T4V]U<F-E*"D@+B`G+R<@+B`D8V]N=&%C="T^9V5T5F%L=64H
M)U]?:V5Y)RD["B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@G;F%M92<L("1P
M<F]P97)T:65S*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5U;
M)VYA;64G72`](%1U<F)A.CIF;W)M871.86UE*"1C;VYT86-T*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH)VEC;VXG+"`D<')O
M<&5R=&EE<RDI('L*("`@("`@("`@("`@("`@("1R97-U;'1S6R1K97E=6R=I
M8V]N)UT@/2`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I("X@)R]M
M:6UE+W9C87)D+G!N9R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*&EN7V%R<F%Y*"=B<F]W<V5A8FQE)RP@)'!R;W!E<G1I97,I*2!["B`@("`@
M("`@("`@("`@("`D<F5S=6QT<ULD:V5Y75LG8G)O=W-E86)L92==(#T@9F%L
M<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"=C
M;VYT96YT='EP92<L("1P<F]P97)T:65S*2D@>PH@("`@("`@("`@("`@("`@
M)')E<W5L='-;)&ME>5U;)V-O;G1E;G1T>7!E)UT@/2`G=&5X="]X+79C87)D
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH)V-O
M;G1E;G1L96YG=&@G+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@("`@
M("1D871A(#T@7W1U<F)A7V5X<&]R="@D8V]N=&%C="T^9V5T5F%L=64H)U]?
M=6ED)RDL("=T97AT+W@M=F-A<F0G+"`D8V]N=&%C="T^9V5T4V]U<F-E*"DI
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("`D9&%T82`]("<G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5U;)V-O
M;G1E;G1L96YG=&@G72`]('-T<FQE;B@D9&%T82D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"=M;V1I9FEE9"<L("1P<F]P97)T
M:65S*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5U;)VUO9&EF
M:65D)UT@/2!?;6]D:69I960H)&-O;G1A8W0M/F=E=%9A;'5E*"=?7W5I9"<I
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH)V-R
M96%T960G+"`D<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@("`@("1R97-U
M;'1S6R1K97E=6R=C<F5A=&5D)UT@/2!?='5R8F%?9V5T06-T:6]N5&EM97-T
M86UP*"1C;VYT86-T+3YG971686QU92@G7U]U:60G*2P@)V%D9"<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT<SL*
M("`@('T@96QS92!["B`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G+R<L("1P
M871H*3L*("`@("`@("!I9B`H8V]U;G0H)'!A<G1S*2`]/2`R("8F(&ES<V5T
M*"1A9&1R97-S8F]O:W-;)'!A<G1S6S!=72DI('L*("`@("`@("`@("`@+R\@
M3&]A9"!T:&4@5'5R8F$@9')I=F5R+@H@("`@("`@("`@("`D9')I=F5R(#T@
M)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1P87)T<ULP72D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1D<FEV97(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M0V]N;F5C=&EO;B!F86EL960Z("5S(BDL("1D<FEV97(M/F=E=$UE<W-A9V4H
M*2DL("=H;W)D92YE<G)O<B<L(&YU;&PL(&YU;&PL("1C9F=3;W5R8V5S6R1P
M87)T<UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8V]N=&%C="`]
M("8D9')I=F5R+3YG971/8FIE8W0H)'!A<G1S6S%=*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)&-O;G1A8W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D8V]N=&%C=#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)')E<W5L="`](&%R<F%Y*"=D871A)R`]/B!?='5R8F%?97AP;W)T
M*"1C;VYT86-T+3YG971686QU92@G7U]U:60G*2P@)W1E>'0O>"UV8V%R9"<L
M("1C;VYT86-T+3YG9713;W5R8V4H*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;6EM971Y<&4G(#T^("=T97AT+W@M=F-A<F0G*3L*("`@("`@
M("`@("`@)&UO9&EF:65D(#T@7VUO9&EF:65D*"1C;VYT86-T+3YG971686QU
M92@G7U]U:60G*2D["B`@("`@("`@("`@(&EF("@A96UP='DH)&UO9&EF:65D
M*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L=%LG;71I;64G72`]("1M;V1I
M9FEE9#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)'!A=&@@+B`G(&1O97,@;F]T(&5X:7-T(&]R('!E<FUI<W-I;VX@9&5N
M:65D)RD["GT*"B\J*@H@*B!2971U<FYS(&%N(&%R<F%Y(&]F(%5)1',@9F]R
M(&%L;"!C;VYT86-T<R!T:&%T('1H92!C=7)R96YT('5S97(@:7,*("H@875T
M:&]R:7IE9"!T;R!S964N"B`J"B`J($!R971U<FX@87)R87D@($%N(&%R<F%Y
M(&]F(%5)1',@9F]R(&%L;"!C;VYT86-T<R!T:&4@=7-E<B!C86X@86-C97-S
M+@H@*B\*9G5N8W1I;VX@7W1U<F)A7VQI<W0H)'-O=7)C92`]("<G*0I["B`@
M("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A<V4N<&AP
M)SL*"B`@("!G;&]B86P@)&-F9U-O=7)C97,["@H@("`@+R\@1V5T(&1E9F%U
M;'0@861D<F5S<R!B;V]K(&9R;VT@=7-E<B!P<F5F97)E;F-E<RX*("`@(&EF
M("AE;7!T>2@D<V]U<F-E*2D@>PH@("`@("`@("1S;W5R8V4@/2`D1TQ/0D%,
M4ULG<')E9G,G72T^9V5T5F%L=64H)V1E9F%U;'1?9&ER)RD["B`@("!]"@H@
M("`@:68@*&5M<'1Y*"1S;W5R8V4I('Q\("%I<W-E="@D8V9G4V]U<F-E<ULD
M<V]U<F-E72DI('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*"));G9A;&ED(&%D9')E<W,@8F]O:R(I+"`G:&]R9&4N97)R;W(G+"!N=6QL
M+"!N=6QL+"`D<V]U<F-E*3L*("`@('T*"B`@("`D<W1O<F%G92`]("94=7)B
M85]$<FEV97(Z.G-I;F=L971O;B@D<V]U<F-E*3L*("`@(&EF("AI<U]A*"1S
M=&]R86=E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;VYN96-T:6]N(&9A:6QE9#H@)7,B
M*2P@)&1R:79E<BT^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RP@;G5L
M;"P@;G5L;"P@)'-O=7)C92D["B`@("!]"@H@("`@)')E<W5L=',@/2`D<W1O
M<F%G92T^<V5A<F-H*&%R<F%Y*"DI.PH*("`@(&EF("AI<U]A*"1R97-U;'1S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")%<G)O<B!S96%R8VAI;F<@=&AE(&%D9')E<W,@
M8F]O:SH@)7,B*2P@)&1R:79E<BT^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R
M<F]R)RP@;G5L;"P@;G5L;"P@)'-O=7)C92D["B`@("!]"@H@("`@)'(@/2!A
M<G)A>2@I.PH@("`@9F]R96%C:"`H)')E<W5L=',M/F]B:F5C=',@87,@)&\I
M('L*("`@("`@("`D<EM=(#T@)&\M/F=E=%9A;'5E*"=?7W5I9"<I.PH@("`@
M?0H*("`@(')E='5R;B`D<CL*?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R87D@
M;V8@54E$<R!F;W(@8V]N=&%C=',@=&AA="!H879E(&AA9"`D86-T:6]N(&AA
M<'!E;@H@*B!S:6YC92`D=&EM97-T86UP+@H@*@H@*B!`<&%R86T@<W1R:6YG
M("`D86-T:6]N("`@("!4:&4@86-T:6]N('1O(&-H96-K(&9O<B`M(&%D9"P@
M;6]D:69Y+"!O<B!D96QE=&4N"B`J($!P87)A;2!I;G1E9V5R("1T:6UE<W1A
M;7`@(%1H92!T:6UE('1O('-T87)T('1H92!S96%R8V@N"B`J($!P87)A;2!S
M=')I;F<@("1S;W5R8V4@("`@(%1H92!S;W5R8V4@9F]R('=H:6-H('1O(')E
M=')I979E('1H92!H:7-T;W)Y+@H@*@H@*B!`<F5T=7)N(&%R<F%Y("!!;B!A
M<G)A>2!O9B!5241S(&UA=&-H:6YG('1H92!A8W1I;VX@86YD('1I;64@8W)I
M=&5R:6$N"B`J+PIF=6YC=&EO;B!?='5R8F%?;&ES=$)Y*"1A8W1I;VXL("1T
M:6UE<W1A;7`L("1S;W5R8V4@/2`G)RD*>PH@("`@9VQO8F%L("1P<F5F<SL*
M("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O8F%S92YP
M:'`G.PH*("`@("\O($=E="!D969A=6QT(&%D9')E<W,@8F]O:R!F<F]M('5S
M97(@<')E9F5R96YC97,N"B`@("!I9B`H96UP='DH)'-O=7)C92DI('L*("`@
M("`@("`D<V]U<F-E(#T@)'!R969S+3YG971686QU92@G9&5F875L=%]D:7(G
M*3L*("`@('T*"B`@("!I9B`H96UP='DH)'-O=7)C92D@?'P@(6ES<V5T*"1C
M9F=3;W5R8V5S6R1S;W5R8V5=*2D@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(DEN=F%L:60@861D<F5S<R!B;V]K(BDL("=H;W)D92YE
M<G)O<B<L(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@?0H*("`@("1H:7-T
M;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@)&AI<W1O
M<FEE<R`]("1H:7-T;W)Y+3YG971">51I;65S=&%M<"@G/B<L("1T:6UE<W1A
M;7`L(&%R<F%Y*&%R<F%Y*"=O<"<@/3X@)STG+"`G9FEE;&0G(#T^("=A8W1I
M;VXG+"`G=F%L=64G(#T^("1A8W1I;VXI*2P@)W1U<F)A.B<@+B`D<V]U<F-E
M*3L*("`@(&EF("AI<U]A*"1H:7-T;W)I97,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("!R971U<FX@)&AI<W1O<FEE<SL*("`@('T*"B`@("`O+R!3=')I
M<"!L96%D:6YG('1U<F)A.G5S97)N86UE.BX*("`@(')E='5R;B!P<F5G7W)E
M<&QA8V4H)R]>*%M>.ETJ.BE[,GTO)RP@)R<L(&%R<F%Y7VME>7,H)&AI<W1O
M<FEE<RDI.PI]"@HO*BH*("H@4F5T=7)N<R!T:&4@=&EM97-T86UP(&]F(&%N
M(&]P97)A=&EO;B!F;W(@82!G:79E;B!U:60@86X@86-T:6]N+@H@*@H@*B!`
M<&%R86T@<W1R:6YG("1U:60@("`@(%1H92!U:60@=&\@;&]O:R!F;W(N"B`J
M($!P87)A;2!S=')I;F<@)&%C=&EO;B`@5&AE(&%C=&EO;B!T;R!C:&5C:R!F
M;W(@+2!A9&0L(&UO9&EF>2P@;W(@9&5L971E+@H@*B!`<&%R86T@<W1R:6YG
M("1S;W5R8V4@(%1H92!S;W5R8V4@9F]R('=H:6-H('1O(')E=')I979E('1H
M92!H:7-T;W)Y+@H@*@H@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!T:6UE<W1A
M;7`@9F]R('1H:7,@86-T:6]N+@H@*B\*9G5N8W1I;VX@7W1U<F)A7V=E=$%C
M=&EO;E1I;65S=&%M<"@D=6ED+"`D86-T:6]N+"`D<V]U<F-E(#T@)R<I"GL*
M("`@(&=L;V)A;"`D<')E9G,["B`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+V)A<V4N<&AP)SL*("`@("1H:7-T;W)Y(#T@)DAO<F1E
M7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH*("`@("\O($=E="!D969A=6QT(&%D
M9')E<W,@8F]O:R!F<F]M('5S97(@<')E9F5R96YC97,N"B`@("!I9B`H96UP
M='DH)'-O=7)C92DI('L*("`@("`@("`D<V]U<F-E(#T@)'!R969S+3YG9716
M86QU92@G9&5F875L=%]D:7(G*3L*("`@('T*"B`@("!I9B`H96UP='DH)'-O
M=7)C92D@?'P@(6ES<V5T*"1C9F=3;W5R8V5S6R1S;W5R8V5=*2D@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@861D<F5S
M<R!B;V]K(BDL("=H;W)D92YE<G)O<B<L(&YU;&PL(&YU;&PL("1S;W5R8V4I
M.PH@("`@?0H*("`@(')E='5R;B`D:&ES=&]R>2T^9V5T06-T:6]N5&EM97-T
M86UP*"=T=7)B83HG("X@)'-O=7)C92`N("<Z)R`N("1U:60L("1A8W1I;VXI
M.PI]"@HO*BH*("H@26UP;W)T(&$@8V]N=&%C="!R97!R97-E;G1E9"!I;B!T
M:&4@<W!E8VEF:65D(&-O;G1E;G14>7!E+@H@*@H@*B!`<&%R86T@<W1R:6YG
M("1C;VYT96YT("`@("`@5&AE(&-O;G1E;G0@;V8@=&AE(&-O;G1A8W0N"B`J
M($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("!7:&%T(&9O<FUA="!I<R!T
M:&4@9&%T82!I;C\@0W5R<F5N=&QY('-U<'!O<G1S"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2!A;F0@=&5X="]X+79C87)D+@H@*B!`
M<&%R86T@<W1R:6YG("1S;W5R8V4@("`@("`@5&AE('-O=7)C92!I;G1O('=H
M:6-H('1H92!C;VYT86-T('=I;&P@8F4*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EM<&]R=&5D+@H@*@H@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&YE=R!5240L(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`J+PIF=6YC=&EO;B!?
M='5R8F%?:6UP;W)T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4@/2`G87)R87DG
M+"`D<V]U<F-E(#T@)R<I"GL*("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?
M1DE,15]?*2`N("<O8F%S92YP:'`G.PH@("`@9VQO8F%L("1C9F=3;W5R8V5S
M+"`D<')E9G,["@H@("`@+R\@1V5T(&1E9F%U;'0@861D<F5S<R!B;V]K(&9R
M;VT@=7-E<B!P<F5F97)E;F-E<RX*("`@(&EF("AE;7!T>2@D<V]U<F-E*2D@
M>PH@("`@("`@("1S;W5R8V4@/2`D<')E9G,M/F=E=%9A;'5E*"=D969A=6QT
M7V1I<B<I.PH@("`@?0H*("`@("\O($-H96-K(&5X:7-T86YC92!O9B!A;F0@
M<&5R;6ES<VEO;G,@;VX@=&AE('-P96-I9FEE9"!S;W5R8V4N"B`@("!I9B`H
M(6ES<V5T*"1C9F=3;W5R8V5S6R1S;W5R8V5=*2D@>PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@861D<F5S<R!B;V]K(BDL
M("=H;W)D92YW87)N:6YG)RD["B`@("!]"@H@("`@)&1R:79E<B`]("94=7)B
M85]$<FEV97(Z.G-I;F=L971O;B@D<V]U<F-E*3L*("`@(&EF("AI<U]A*"1D
M<FEV97(L("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(I
M+"`D9')I=F5R+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G+"!N=6QL
M+"!N=6QL+"`D<V]U<F-E*3L*("`@('T*"B`@("!I9B`H(21D<FEV97(M/FAA
M<U!E<FUI<W-I;VXH4$5235-?141)5"DI('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")097)M:7-S:6]N($1E;FEE9"(I+"`G:&]R9&4N
M97)R;W(G+"!N=6QL+"!N=6QL+"`D<V]U<F-E*3L*("`@('T*"B`@("!I9B`H
M(6ES7V$H)&-O;G1E;G0L("=(;W)D95]I0V%L96YD87)?=F-A<F0G*2D@>PH@
M("`@("`@('-W:71C:"`H)&-O;G1E;G14>7!E*2!["B`@("`@("`@8V%S92`G
M87)R87DG.@H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G=&5X
M="]X+79C87)D)SH*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]I
M0V%L96YD87(N<&AP)SL*("`@("`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E
M7VE#86QE;F1A<B@I.PH@("`@("`@("`@("!I9B`H(21I0V%L+3YP87)S979#
M86QE;F1A<B@D8V]N=&5N="DI('L*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+B(I*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!S=VET8V@@*"1I0V%L+3YG971#;VUP;VYE;G1#;W5N="@I*2![
M"B`@("`@("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(DYO('9#87)D(&1A=&$@=V%S(&9O=6YD+B(I
M*3L*"B`@("`@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@)&E#86PM/F=E=$-O;7!O;F5N="@P*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("1I9',@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&E#
M86PM/F=E=$-O;7!O;F5N=',H*2!A<R`D8RD@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]A*"1C+"`G2&]R9&5?:4-A;&5N9&%R7W9C87)D)RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9')I=F5R+3YT
M;TAA<V@H)&,I.PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)&1R:79E<BT^<V5A<F-H*"1C;VYT96YT*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D<F5S=6QT+3YC;W5N="@I
M(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1D<FEV97(M/F%D9"@D8V]N=&5N="D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("1I9'-;72`]("1R97-U;'0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1I9',["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B56YS=7!P;W)T960@0V]N=&5N="U4>7!E.B`E
M<R(I+"`D8V]N=&5N=%1Y<&4I*3L*("`@("`@("!]"B`@("!]"@H@("`@:68@
M*&ES7V$H)&-O;G1E;G0L("=(;W)D95]I0V%L96YD87)?=F-A<F0G*2D@>PH@
M("`@("`@("1C;VYT96YT(#T@)&1R:79E<BT^=&](87-H*"1C;VYT96YT*3L*
M("`@('T*"B`@("`D<F5S=6QT(#T@)&1R:79E<BT^<V5A<F-H*"1C;VYT96YT
M*3L*("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@('T@96QS96EF("@D<F5S=6QT+3YC
M;W5N="@I(#X@,"D@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(D%L<F5A9'D@17AI<W1S(BDL("=H;W)D92YM97-S86=E)RP@;G5L;"P@
M;G5L;"P@)'-O=7)C92D["B`@("!]"@H@("`@)')E<W5L="`]("1D<FEV97(M
M/F%D9"@D8V]N=&5N="D["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M)&]B:F5C="`]("8D9')I=F5R+3YG971/8FIE8W0H)')E<W5L="D["B`@("!R
M971U<FX@:7-?82@D;V)J96-T+"`G4$5!4E]%<G)O<B<I(#\@)&]B:F5C="`Z
M("1O8FIE8W0M/F=E=%9A;'5E*"=?7W5I9"<I.PI]"@HO*BH*("H@17AP;W)T
M(&$@8V]N=&%C="P@:61E;G1I9FEE9"!B>2!5240L(&EN('1H92!R97%U97-T
M960@8V]N=&5N=%1Y<&4N"B`J"B`J($!P87)A;2!S=')I;F<@)'5I9"`@("`@
M("`@($ED96YT:69Y('1H92!C;VYT86-T('1O(&5X<&]R="X*("H@0'!A<F%M
M(&UI>&5D("1C;VYT96YT5'EP92`@5VAA="!F;W)M870@<VAO=6QD('1H92!D
M871A(&)E(&EN/PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!%:71H
M97(@82!S=')I;F<@=VET:"!O;F4@;V8Z"B`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QP<F4^"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T97AT+W@M=F-A<F0*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]P<F4^"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&%N(&%R
M<F%Y('=I=&@@;W!T:6]N<SH*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'!R93X*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=#;VYT
M96YT5'EP92<Z("!A<R!A8F]V90H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)T5.0T]$24Y')SH@*&]P=&EO;F%L*2!C:&%R86-T97(@96YC;V1I
M;F<*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<B!S=')I;F=S(&9I96QD<PH@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)T-(05)3150G.B`@*&]P=&EO;F%L*2!C:&%R<V5T+B!,:6ME(%54
M1BTX"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5D524TE/3B<Z
M("`H;W!T:6]N86PI($9O<FUA="!V97)S:6]N("AE>"X@:4-A;&5N9&%R(#(N
M,"P@=D-A;&5N9&%R(#$N,"DN"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO<')E/@H@*@H@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E<75E<W1E
M9"!D871A+@H@*B\*9G5N8W1I;VX@7W1U<F)A7V5X<&]R="@D=6ED+"`D8V]N
M=&5N=%1Y<&4L("1S;W5R8V4@/2`G)RD*>PH@("`@<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<["B`@("!G;&]B86P@)&-F
M9U-O=7)C97,L("1P<F5F<SL*"B`@("`D=F5R<VEO;B`]("<R+C$G.PH@("`@
M:68@*&ES7V%R<F%Y*"1C;VYT96YT5'EP92DI('L*("`@("`@("`D;W!T:6]N
M<R`]("1C;VYT96YT5'EP93L*("`@("`@("`D8V]N=&5N=%1Y<&4@/2`D;W!T
M:6]N<ULG0V]N=&5N=%1Y<&4G73L*("`@("`@("!U;G-E="@D;W!T:6]N<ULG
M0V]N=&5N=%1Y<&4G72D["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=6
M15)324].)UTI*2!["B`@("`@("`@("`@("1V97)S:6]N(#T@)&]P=&EO;G-;
M)U9%4E-)3TXG73L*("`@("`@("`@("`@=6YS970H)&]P=&EO;G-;)U9%4E-)
M3TXG72D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`D;W!T:6]N
M<R`](&%R<F%Y*"D["B`@("!]"@H@("`@+R\@1V5T(&1E9F%U;'0@861D<F5S
M<R!B;V]K(&9R;VT@=7-E<B!P<F5F97)E;F-E<RX*("`@(&EF("AE;7!T>2@D
M<V]U<F-E*2D@>PH@("`@("`@("1S;W5R8V4@/2`D<')E9G,M/F=E=%9A;'5E
M*"=D969A=6QT7V1I<B<I.PH@("`@?0H*("`@(&EF("AE;7!T>2@D<V]U<F-E
M*2!\?"`A:7-S970H)&-F9U-O=7)C97-;)'-O=7)C95TI*2!["B`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!A9&1R97-S(&)O
M;VLB*2P@)VAO<F1E+F5R<F]R)RP@;G5L;"P@;G5L;"P@)'-O=7)C92D["B`@
M("!]"@H@("`@:68@*&5M<'1Y*"1U:60I*2!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!)1"(I+"`G:&]R9&4N97)R;W(G
M+"!N=6QL+"!N=6QL+"`D<V]U<F-E*3L*("`@('T*"B`@("`D9')I=F5R(#T@
M)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1S;W5R8V4I.PH@("`@:68@*&ES
M7V$H)&1R:79E<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]N;F5C=&EO;B!F86EL960Z
M("5S(BDL("1D<FEV97(M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<L
M(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@?0H*("`@(&EF("@A)&1R:79E
M<BT^:&%S4&5R;6ES<VEO;BA015)-4U]%1$E4*2D@>PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E!E<FUI<W-I;VX@1&5N:65D(BDL("=H
M;W)D92YE<G)O<B<L(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@?0H*("`@
M("\O($EF('1H92!O8FIE8W1)9"!I<VXG="!I;B`D<V]U<F-E(&EN('1H92!F
M:7)S="!P;&%C92P@:G5S="!R971U<FX*("`@("\O('1R=64N($]T:&5R=VES
M92P@=')Y('1O(&1E;&5T92!I="!A;F0@<F5T=7)N('-U8V-E<W,@;W(@9F%I
M;'5R92X*("`@("1R97-U;'0@/2`D9')I=F5R+3YS96%R8V@H87)R87DH)U]?
M=6ED)R`]/B`D=6ED*2D["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!](&5L<V5I
M9B`H)')E<W5L="T^8V]U;G0H*2`]/2`P*2!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B3V)J96-T(&YO="!F;W5N9"(I+"`G:&]R9&4N
M97)R;W(G+"!N=6QL+"!N=6QL+"`D<V]U<F-E*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T@96QS96EF("@D<F5S=6QT+3YC;W5N="@I(#X@,2D@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"));G1E<FYA;"!(;W)D
M92!%<G)O<CH@;75L=&EP;&4@='5R8F$@;V)J96-T<R!W:71H('-A;64@;V)J
M96-T260N(BP@)VAO<F1E+F5R<F]R)RP@;G5L;"P@;G5L;"P@)'-O=7)C92D[
M"B`@("!]"@H@("`@<W=I=&-H("@D8V]N=&5N=%1Y<&4I('L*("`@(&-A<V4@
M)W1E>'0O>"UV8V%R9"<Z"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]I
M0V%L96YD87(N<&AP)SL*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A
M;&5N9&%R*"D["B`@("`@("`@)&5X<&]R="`]("<G.PH@("`@("`@(&9O<F5A
M8V@@*"1R97-U;'0M/F]B:F5C=',@87,@)&]B:BD@>PH@("`@("`@("`@("`D
M=F-A<F0@/2`D9')I=F5R+3YT;W9#87)D*"1O8FHI.PH@("`@("`@("`@("`D
M=F-A<F0M/G-E=%!A<F%M971E<B@G1DXG+"`D;W!T:6]N<RD["B`@("`@("`@
M("`@("1V8V%R9"T^<V5T4&%R86UE=&5R*"=/4D<G+"`D;W!T:6]N<RD["B`@
M("`@("`@("`@("1V8V%R9"T^<V5T4&%R86UE=&5R*"=!1%(G+"`D;W!T:6]N
M<RD["B`@("`@("`@("`@("1V8V%R9"T^<V5T4&%R86UE=&5R*"=,04)%3"<L
M("1O<'1I;VYS*3L*("`@("`@("`@("`@)'9C87)D+3YS971087)A;65T97(H
M)TY)0TM.04U%)RP@)&]P=&EO;G,I.PH@("`@("`@("`@("`D=F-A<F0M/G-E
M=%!A<F%M971E<B@G5$E43$4G+"`D;W!T:6]N<RD["B`@("`@("`@("`@("1V
M8V%R9"T^<V5T4&%R86UE=&5R*"=.3U1%)RP@)&]P=&EO;G,I.PH@("`@("`@
M("`@("`D=F-A<F0M/G-E=%!A<F%M971E<B@G3B<L("1O<'1I;VYS*3L*("`@
M("`@("`@("`@+R\@=D-A<F1S(&%R92!N;W0@96YC;&]S960@:6X@0D5'24XZ
M5D-!3$5.1$%2+BY%3D0Z5D-!3$5.1$%2('-O"B`@("`@("`@("`@("\O(&5X
M<&]R="!T:&4@:6YD:79I9'5A;"!C87)D<R!I;G-T96%D.@H@("`@("`@("`@
M("`D97AP;W)T("X]("1V8V%R9"T^97AP;W)T=D-A;&5N9&%R*"D["B`@("`@
M("`@("`@("1I0V%L+3YA9&1#;VUP;VYE;G0H)'9C87)D*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1E>'!O<G0["@H@("`@9&5F875L=#H*("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N<W5P<&]R
M=&5D($-O;G1E;G0M5'EP93H@)7,B*2P@)&-O;G1E;G14>7!E*2D["B`@("!]
M"GT*"B\J*@H@*B!$96QE=&5S(&$@8V]N=&%C="!I9&5N=&EF:65D(&)Y(%5)
M1"X*("H*("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D=6ED("!)9&5N=&EF>2!T
M:&4@8V]N=&%C="!T;R!D96QE=&4L(&5I=&AE<B!A('-I;F=L90H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%5)1"!O<B!A;B!A<G)A>2X*("H*("H@
M0')E='5R;B!B;V]L96%N("!3=6-C97-S(&]R(&9A:6QU<F4N"B`J+PIF=6YC
M=&EO;B!?='5R8F%?9&5L971E*"1U:60L("1S;W5R8V4@/2`G)RD*>PH@("`@
M+R\@2&%N9&QE(&%N(&%R<F%Y(&]F(%5)1',@9F]R(&-O;G9E;FEE;F-E(&]F
M(&1E;&5T:6YG(&UU;'1I<&QE(&-O;G1A8W1S"B`@("`O+R!A="!O;F-E+@H@
M("`@:68@*&ES7V%R<F%Y*"1U:60I*2!["B`@("`@("`@9F]R96%C:"`H)'5I
M9"!A<R`D9RD@>PH@("`@("`@("`@("`D<F5S=6QT(#T@7W1U<F)A7V1E;&5T
M92@D=6ED+"`D<V]U<F-E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O8F%S92YP:'`G.PH@("`@9VQO8F%L("1C9F=3;W5R8V5S+"`D
M<')E9G,["@H@("`@+R\@1V5T(&1E9F%U;'0@861D<F5S<R!B;V]K(&9R;VT@
M=7-E<B!P<F5F97)E;F-E<RX*("`@(&EF("AE;7!T>2@D<V]U<F-E*2D@>PH@
M("`@("`@("1S;W5R8V4@/2`D<')E9G,M/F=E=%9A;'5E*"=D969A=6QT7V1I
M<B<I.PH@("`@?0H*("`@(&EF("AE;7!T>2@D<V]U<F-E*2!\?"`A:7-S970H
M)&-F9U-O=7)C97-;)'-O=7)C95TI*2!["B`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B26YV86QI9"!A9&1R97-S(&)O;VLB*2P@)VAO<F1E
M+F5R<F]R)RP@;G5L;"P@;G5L;"P@)'-O=7)C92D["B`@("!]"@H@("`@:68@
M*&5M<'1Y*"1U:60I*2!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B26YV86QI9"!)1"(I+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL
M+"`D<V]U<F-E*3L*("`@('T*"B`@("`D9')I=F5R(#T@)E1U<F)A7T1R:79E
M<CHZ<VEN9VQE=&]N*"1S;W5R8V4I.PH@("`@:68@*&ES7V$H)&1R:79E<BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B0V]N;F5C=&EO;B!F86EL960Z("5S(BDL("1D<FEV
M97(M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<L(&YU;&PL(&YU;&PL
M("1S;W5R8V4I.PH@("`@?0H*("`@(&EF("@A)&1R:79E<BT^:&%S4&5R;6ES
M<VEO;BA015)-4U]%1$E4*2D@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E!E<FUI<W-I;VX@1&5N:65D(BDL("=H;W)D92YE<G)O<B<L
M(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@?0H*("`@("\O($EF('1H92!O
M8FIE8W1)9"!I<VXG="!I;B`D<V]U<F-E(&EN('1H92!F:7)S="!P;&%C92P@
M:G5S="!R971U<FX*("`@("\O('1R=64N($]T:&5R=VES92P@=')Y('1O(&1E
M;&5T92!I="!A;F0@<F5T=7)N('-U8V-E<W,@;W(@9F%I;'5R92X*("`@("1R
M97-U;'0@/2`D9')I=F5R+3YS96%R8V@H87)R87DH)U]?=6ED)R`]/B`D=6ED
M*2D["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!](&5L<V5I9B`H)')E<W5L="T^
M8V]U;G0H*2`]/2`P*2!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!](&5L
M<V4@>PH@("`@("`@("\O(%=E(&YE960@=&\@9&5L971E(&)Y('5I9"!R871H
M97(@=&AA;B!B>2!K97DL('-O('5S92!?9&5L971E(&EN<W1E860*("`@("`@
M("`O+R!O9B!D96QE=&4N"B`@("`@("`@<F5T=7)N("1D<FEV97(M/E]D96QE
M=&4H)&1R:79E<BT^=&]$<FEV97(H)U]?=6ED)RDL("1U:60I.PH@("`@?0I]
M"@HO*BH*("H@4F5P;&%C97,@=&AE(&-O;G1A8W0@:61E;G1I9FEE9"!B>2!5
M240@=VET:"!T:&4@8V]N=&5N="!R97!R97-E;G1E9"!I;B!T:&4*("H@<W!E
M8VEF:65D(&-O;G1E;G14>7!E+@H@*@H@*B!`<&%R86T@<W1R:6YG("1U:60@
M("`@("`@("`@261E;F9I='D@=&AE(&-O;G1A8W0@=&\@<F5P;&%C92X*("H@
M0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@(%1H92!C;VYT96YT(&]F('1H
M92!C;VYT86-T+@H@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@5VAA
M="!F;W)M870@:7,@=&AE(&1A=&$@:6X_($-U<G)E;G1L>2!S=7!P;W)T<PH@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87D@86YD('1E>'0O
M>"UV8V%R9"X*("H*("H@0')E='5R;B!B;V]L96%N("!3=6-C97-S(&]R(&9A
M:6QU<F4N"B`J+PIF=6YC=&EO;B!?='5R8F%?<F5P;&%C92@D=6ED+"`D8V]N
M=&5N="P@)&-O;G1E;G14>7!E+"`D<V]U<F-E(#T@)R<I"GL*("`@(')E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH@("`@
M9VQO8F%L("1C9F=3;W5R8V5S+"`D<')E9G,["@H@("`@+R\@1V5T(&1E9F%U
M;'0@861D<F5S<R!B;V]K(&9R;VT@=7-E<B!P<F5F97)E;F-E<RX*("`@(&EF
M("AE;7!T>2@D<V]U<F-E*2D@>PH@("`@("`@("1S;W5R8V4@/2`D<')E9G,M
M/F=E=%9A;'5E*"=D969A=6QT7V1I<B<I.PH@("`@?0H*("`@(&EF("@A:7-S
M970H)&-F9U-O=7)C97,I('Q\("%I<U]A<G)A>2@D8V9G4V]U<F-E<RD@?'P@
M(6-O=6YT*"1C9F=3;W5R8V5S*2!\?"`A:7-S970H)&-F9U-O=7)C97-;)'-O
M=7)C95TI*2!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M26YV86QI9"!A9&1R97-S(&)O;VLB*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@
M('T*"B`@("!I9B`H96UP='DH)'5I9"DI('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*"));G9A;&ED(&]B:F5C=$ED(BDL("=H;W)D92YE
M<G)O<B<L(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@?0H*("`@("\O($-H
M96-K('!E<FUI<W-I;VYS+@H@("`@)&1R:79E<B`]("94=7)B85]$<FEV97(Z
M.G-I;F=L971O;B@D<V]U<F-E*3L*("`@(&EF("AI<U]A*"1D<FEV97(L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(D-O;FYE8W1I;VX@9F%I;&5D.B`E<R(I+"`D9')I=F5R
M+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL+"`D
M<V]U<F-E*3L*("`@('T*("`@("1R97-U;'0@/2`D9')I=F5R+3YS96%R8V@H
M87)R87DH)U]?=6ED)R`]/B`D=6ED*2D["B`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("!](&5L<V5I9B`H(21R97-U;'0M/F-O=6YT*"DI('L*("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")/8FIE8W0@;F]T(&9O=6YD(BDL("=H
M;W)D92YE<G)O<B<L(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@?2!E;'-E
M:68@*"1R97-U;'0M/F-O=6YT*"D@/B`Q*2!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H(DEN=&5R;F%L($AO<F1E($5R<F]R.B!M=6QT:7!L
M92!T=7)B82!O8FIE8W1S('=I=&@@<V%M92!O8FIE8W1)9"XB+"`G:&]R9&4N
M97)R;W(G+"!N=6QL+"!N=6QL+"`D<V]U<F-E*3L*("`@('T*("`@("1O8FIE
M8W0@/2`D<F5S=6QT+3YO8FIE8W1S6S!=.PH*("`@('-W:71C:"`H)&-O;G1E
M;G14>7!E*2!["B`@("!C87-E("=A<G)A>2<Z"B`@("`@("`@8G)E86L["@H@
M("`@8V%S92`G=&5X="]X+79C87)D)SH*("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH@("`@("`@("1I0V%L(#T@)FYE=R!(
M;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21I0V%L+3YP87)S979#
M86QE;F1A<B@D8V]N=&5N="DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(BDI.PH@("`@("`@('T*"B`@("`@("`@<W=I
M=&-H("@D:4-A;"T^9V5T0V]M<&]N96YT0V]U;G0H*2D@>PH@("`@("`@(&-A
M<V4@,#H*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F\@=D-A<F0@9&%T82!W87,@9F]U;F0N(BDI.PH*("`@("`@("!C87-E(#$Z
M"B`@("`@("`@("`@("1C;VYT96YT(#T@)&E#86PM/F=E=$-O;7!O;F5N="@P
M*3L*("`@("`@("`@("`@)&-O;G1E;G0@/2`D9')I=F5R+3YT;TAA<V@H)&-O
M;G1E;G0I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3VYL>2!O
M;F4@=F-A<F0@<W5P<&]R=&5D+B(I*3L*("`@("`@("!]"B`@("`@("`@8G)E
M86L["@H@("`@9&5F875L=#H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(E5N<W5P<&]R=&5D($-O;G1E;G0M5'EP93H@)7,B
M*2P@)&-O;G1E;G14>7!E*2D["B`@("!]"@H@("`@9F]R96%C:"`H)&-O;G1E
M;G0@87,@)&%T=')I8G5T92`]/B`D=F%L=64I('L*("`@("`@("!I9B`H)&%T
M=')I8G5T92`A/2`G7U]K97DG*2!["B`@("`@("`@("`@("1O8FIE8W0M/G-E
M=%9A;'5E*"1A='1R:6)U=&4L("1V86QU92D["B`@("`@("`@?0H@("`@?0H*
M("`@(')E='5R;B`D;V)J96-T+3YS=&]R92@I.PI]"@IF=6YC=&EO;B!?='5R
M8F%?<V5A<F-H*"1N86UE<R`](&%R<F%Y*"DL("1S;W5R8V5S(#T@87)R87DH
M*2P@)&9I96QD<R`](&%R<F%Y*"DI"GL*("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH@("`@9VQO8F%L("1C9F=3
M;W5R8V5S+"`D871T<FEB=71E<RP@)'!R969S.PH*("`@(&EF("@A:7-S970H
M)&-F9U-O=7)C97,I('Q\("%I<U]A<G)A>2@D8V9G4V]U<F-E<RD@?'P@(6-O
M=6YT*"1C9F=3;W5R8V5S*2D@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@
M("`@?0H*("`@(&EF("@A8V]U;G0H)'-O=7)C97,I*2!["B`@("`@("`@)'-O
M=7)C97,@/2!A<G)A>2AK97DH)&-F9U-O=7)C97,I*3L*("`@('T*"B`@("`O
M+R!296%D('1H92!C;VQU;6YS('1O(&1I<W!L87D@9G)O;2!T:&4@<')E9F5R
M96YC97,N"B`@("`D<V]R=%]C;VQU;6YS(#T@5'5R8F$Z.F=E=$-O;'5M;G,H
M*3L*"B`@("`D<F5S=6QT<R`](&%R<F%Y*"D["B`@("`D<V5E;B`](&%R<F%Y
M*"D["B`@("!F;W)E86-H("@D<V]U<F-E<R!A<R`D<V]U<F-E*2!["B`@("`@
M("`@+R\@4VMI<"!I;G9A;&ED('-O=7)C97,N"B`@("`@("`@:68@*"%I<W-E
M="@D8V9G4V]U<F-E<ULD<V]U<F-E72DI('L*("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@?0H*("`@("`@("`O+R!3:VEP('-O=7)C97,@=&AA="!A
M<F5N)W0@8G)O=W-E86)L92!I9B!T:&4@<V5A<F-H(&ES(&5M<'1Y+@H@("`@
M("`@(&EF("@A8V]U;G0H)&YA;65S*2`F)B!E;7!T>2@D8V9G4V]U<F-E<ULD
M<V]U<F-E75LG8G)O=W-E)UTI*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@('T*"B`@("`@("`@)&1R:79E<B`]("94=7)B85]$<FEV97(Z.G-I
M;F=L971O;B@D<V]U<F-E*3L*("`@("`@("!I9B`H:7-?82@D9')I=F5R+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B0V]N;F5C=&EO;B!F86EL960Z("5S(BDL("1D
M<FEV97(M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<L(&YU;&PL(&YU
M;&PL("1S;W5R8V4I.PH@("`@("`@('T*(`H@("`@("`@("\O($1E=&5R;6EN
M92!T:&4@;F%M92!O9B!T:&4@8V]L=6UN('1O('-O<G0@8GDN"B`@("`@("`@
M)&-O;'5M;G,@/2!I<W-E="@D<V]R=%]C;VQU;6YS6R1S;W5R8V5=*0H@("`@
M("`@("`@("`_("1S;W)T7V-O;'5M;G-;)'-O=7)C95T@.B!A<G)A>2@I.PH@
M("`@("`@("1S;W)T8V]L=6UN(#T@*"1P<F5F<RT^9V5T5F%L=64H)W-O<G1B
M>2<I(#T](#`@?'P*("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)'-O
M<G1?8V]L=6UN<ULD<')E9G,M/F=E=%9A;'5E*"=S;W)T8GDG*2`M(#%=*2D*
M("`@("`@("`@("`@/R`H*"1P<F5F<RT^9V5T5F%L=64H)VYA;65?9F]R;6%T
M)RD@/3T@)V9I<G-T7VQA<W0G*0H@("`@("`@("`@("`@("`_("=N86UE)PH@
M("`@("`@("`@("`@("`Z("=L87-T;F%M92<I"B`@("`@("`@("`@(#H@)'-O
M<G1?8V]L=6UN<ULD<')E9G,M/F=E=%9A;'5E*"=S;W)T8GDG*2`M(#%=.PH*
M("`@("`@("!F;W)E86-H("@D;F%M97,@87,@)&YA;64I('L*("`@("`@("`@
M("`@)&-R:71E<FEA(#T@87)R87DH*3L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1F:65L9'-;)'-O=7)C95TI*2!["B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D9FEE;&1S6R1S;W5R8V5=(&%S("1F:65L9"D@>PH@("`@("`@("`@("`@
M("`@("`@("1C<FET97)I85LD9FEE;&1=(#T@=')I;2@D;F%M92D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&-O
M=6YT*"1C<FET97)I82D@/3T@,"D@>PH@("`@("`@("`@("`@("`@)&-R:71E
M<FEA6R=N86UE)UT@/2!T<FEM*"1N86UE*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<F5S(#T@)&1R:79E<BT^<V5A<F-H*"1C<FET97)I82P@)'-O
M<G1C;VQU;6XL("=/4B<I.PH*("`@("`@("`@("`@:68@*"%I<U]A*"1R97,L
M("=4=7)B85],:7-T)RDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!W:&EL92`H)&]B(#T@)')E<RT^
M;F5X="@I*2!["B`@("`@("`@("`@("`@("!I9B`H(21O8BT^:7-'<F]U<"@I
M*2!["B`@("`@("`@("`@("`@("`@("`@+RH@3F]T(&$@9W)O=7`N("HO"B`@
M("`@("`@("`@("`@("`@("`@)&%T="`]("1O8BT^9V5T071T<FEB=71E<R@I
M.PH@("`@("`@("`@("`@("`@("`@("1E;6%I;"`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D871T*2!A<R`D
M:V5Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;V(M/F=E=%9A
M;'5E*"1K97DI("8F(&ES<V5T*"1A='1R:6)U=&5S6R1K97E=*2`F)@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)&ME>5U;)W1Y
M<&4G72`]/2`G96UA:6PG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D96UA:6Q;72`]("1O8BT^9V5T5F%L=64H)&ME>2D["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1E;6%I;"DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&5M86EL*3L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-E96Y?:V5Y
M(#T@=')I;2A3=')I;F<Z.FQO=V5R*"1O8BT^9V5T5F%L=64H)VYA;64G*2DI
M("X@)R\G("X@=')I;2A3=')I;F<Z.FQO=V5R*"1E;6%I;%LD:5TI*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'-E96Y;)'-E
M96Y?:V5Y72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S965N6R1S965N7VME>5T@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<F5S
M=6QT<ULD;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<W5L='-;)&YA;65=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M97-U;'1S6R1N86UE75M=(#T@87)R87E?;65R9V4H)&%T="P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=I9"<@/3X@)&%T=%LG7U]K97DG72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE
M)R`]/B!4=7)B83HZ9F]R;6%T3F%M92@D;V(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5M
M86EL)R`]/B`D96UA:6Q;)&E=+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]?='EP92<@/3X@
M)T]B:F5C="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<V]U<F-E)R`]/B`D<V]U<F-E*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1R97-U;'1S6R1N86UE72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R97-U;'1S6R1N86UE72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;
M)&YA;65=6UT@/2!A<G)A>5]M97)G92@D871T+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:60G(#T^
M("1A='1;)U]?:V5Y)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!4=7)B83HZ9F]R
M;6%T3F%M92@D;V(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G96UA:6PG(#T^(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=?7W1Y<&4G(#T^("=/8FIE8W0G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V]U<F-E)R`]
M/B`D<V]U<F-E*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!)<R!A(&1I
M<W1R:6)U=&EO;B!L:7-T+B`J+PH@("`@("`@("`@("`@("`@("`@("1L:7-T
M871T(#T@)&]B+3YG971!='1R:6)U=&5S*"D["B`@("`@("`@("`@("`@("`@
M("`@)'-E96YI;FQI<W0@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@
M("1M96UB97)S(#T@)&]B+3YL:7-T365M8F5R<R@I.PH*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-?82@D;65M8F5R<RP@)U1U<F)A7TQI<W0G*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&UE;6)E<G,M/F-O=6YT*"D@
M/B`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1R97-U;'1S6R1N86UE72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5S=6QT<ULD;F%M95T@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5M86EL<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!W:&EL92`H)&]B(#T@)&UE;6)E<G,M/FYE>'0H*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A='0@/2`D;V(M/F=E=$%T=')I
M8G5T97,H*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D871T(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'9A;'5E*2`F)B!I
M<W-E="@D871T<FEB=71E<ULD:V5Y72D@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R1K97E=6R=T>7!E
M)UT@/3T@)V5M86EL)R`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@96UP='DH)'-E96YI;FQI<W1;=')I;2A3=')I;F<Z.FQO
M=V5R*"1A='1;)VYA;64G72DI("X@=')I;2A3=')I;F<Z.FQO=V5R*"1V86QU
M92DI72DI('L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D96UA:6QS6UT@/2`D=F%L=64["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<V5E;FEN;&ES=%MT<FEM*%-T<FEN9SHZ
M;&]W97(H)&%T=%LG;F%M92==*2D@+B!T<FEM*%-T<FEN9SHZ;&]W97(H)'9A
M;'5E*2E=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R97-U;'1S6R1N86UE75M=(#T@87)R87DH)VYA;64G(#T^
M("1L:7-T871T6R=N86UE)UTL("=E;6%I;"<@/3X@:6UP;&]D92@G+"`G+"`D
M96UA:6QS*2P@)VED)R`]/B`D;&ES=&%T=%LG7U]K97DG72P@)W-O=7)C92<@
M/3X@)'-O=7)C92D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N("1R97-U;'1S.PI]"@IF
M=6YC=&EO;B!?='5R8F%?9V5T0V]N=&%C="@D<V]U<F-E(#T@)R<L("1O8FIE
M8W1)9"`]("<G*0I["B`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+V)A<V4N<&AP)SL*("`@(&=L;V)A;"`D8V9G4V]U<F-E<SL*"B`@
M("!I9B`H(6ES<V5T*"1C9F=3;W5R8V5S*2!\?"`A:7-?87)R87DH)&-F9U-O
M=7)C97,I('Q\("%C;W5N="@D8V9G4V]U<F-E<RDI('L*("`@("`@("!R971U
M<FX@87)R87DH*3L*("`@('T*"B`@("!I9B`H:7-S970H)&-F9U-O=7)C97-;
M)'-O=7)C95TI*2!["B`@("`@("`@)&1R:79E<B`]("94=7)B85]$<FEV97(Z
M.G-I;F=L971O;B@D<V]U<F-E*3L*("`@("`@("!I9B`H:7-?82@D9')I=F5R
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9')I=F5R
M.PH@("`@("`@('T*"B`@("`@("`@)&]B:F5C="`]("1D<FEV97(M/F=E=$]B
M:F5C="@D;V)J96-T260I.PH@("`@("`@(&EF("AI<U]A*"1O8FIE8W0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O8FIE8W0["B`@
M("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!P97)M:7-S:6]N<RX@*B\*("`@
M("`@("!I9B`H(21O8FIE8W0M/FAA<U!E<FUI<W-I;VXH4$5235-?4D5!1"DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&5R
M;6ES<VEO;B!$96YI960B*2P@)VAO<F1E+F5R<F]R)RP@;G5L;"P@;G5L;"P@
M)'-O=7)C92D["B`@("`@("`@?0H*("`@("`@("`D871T<FEB=71E<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&-F9U-O=7)C97-;)'-O=7)C95U;
M)VUA<"==(&%S("1F:65L9"`]/B`D;6%P*2!["B`@("`@("`@("`@("1A='1R
M:6)U=&5S6R1F:65L9%T@/2`D;V)J96-T+3YG971686QU92@D9FEE;&0I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&%T=')I8G5T97,["B`@("!]"@H@
M("`@<F5T=7)N(&%R<F%Y*"D["GT*"F9U;F-T:6]N(%]T=7)B85]G971#;VYT
M86-T<R@D<V]U<F-E(#T@)R<L("1O8FIE8W1)9',@/2!A<G)A>2@I*0I["B`@
M("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+V)A<V4N<&AP
M)SL*("`@(&=L;V)A;"`D8V9G4V]U<F-E<SL*("`@("1R97-U;'1S(#T@87)R
M87DH*3L*("`@(&EF("@A:7-?87)R87DH)&]B:F5C=$ED<RDI('L*("`@("`@
M("`D;V)J96-T261S(#T@87)R87DH)&]B:F5C=$ED<RD["B`@("!]"@H@("`@
M:68@*"%I<W-E="@D8V9G4V]U<F-E<RD@?'P@(6ES7V%R<F%Y*"1C9F=3;W5R
M8V5S*2!\?"`A8V]U;G0H)&-F9U-O=7)C97,I*2!["B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D["B`@("!]"@H@("`@:68@*&ES<V5T*"1C9F=3;W5R8V5S6R1S
M;W5R8V5=*2D@>PH@("`@("`@("1D<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS
M:6YG;&5T;VXH)'-O=7)C92D["B`@("`@("`@:68@*&ES7V$H)&1R:79E<BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&1R:79E<CL*
M("`@("`@("!]"@H@("`@("`@("1O8FIE8W1S(#T@)&1R:79E<BT^9V5T3V)J
M96-T<R@D;V)J96-T261S*3L*("`@("`@("!I9B`H:7-?82@D;V)J96-T<RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&]B:F5C=',[
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D;V)J96-T<R!A<R`D;V)J
M96-T*2!["B`@("`@("`@("`@("\J($-H96-K('!E<FUI<W-I;VYS(&]N('1H
M:7,@;V)J96-T+B`J+PH@("`@("`@("`@("!I9B`H(21O8FIE8W0M/FAA<U!E
M<FUI<W-I;VXH4$5235-?4D5!1"DI('L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D871T<FEB=71E<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1C9F=3;W5R8V5S6R1S
M;W5R8V5=6R=M87`G72!A<R`D9FEE;&0@/3X@)&UA<"D@>PH@("`@("`@("`@
M("`@("`@)&%T=')I8G5T97-;)&9I96QD72`]("1O8FIE8W0M/F=E=%9A;'5E
M*"1F:65L9"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L='-;
M72`]("1A='1R:6)U=&5S.PH@("`@("`@('T*("`@('T*"B`@("!R971U<FX@
M)')E<W5L=',["GT*"F9U;F-T:6]N(%]T=7)B85]G971!;&Q!='1R:6)U=&56
M86QU97,H)&9I96QD(#T@)R<L("1S;W5R8V5S(#T@87)R87DH*2D*>PH@("`@
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<[
M"B`@("!G;&]B86P@)&-F9U-O=7)C97,["@H@("`@:68@*"%I<W-E="@D8V9G
M4V]U<F-E<RD@?'P@(6ES7V%R<F%Y*"1C9F=3;W5R8V5S*2!\?"`A8V]U;G0H
M)&-F9U-O=7)C97,I*2!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]
M"@H@("`@:68@*"%C;W5N="@D<V]U<F-E<RDI('L*("`@("`@("`D<V]U<F-E
M<R`](&%R<F%Y*&ME>2@D8V9G4V]U<F-E<RDI.PH@("`@?0H*("`@("1R97-U
M;'1S(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1S;W5R8V5S(&%S("1S;W5R
M8V4I('L*("`@("`@("!I9B`H:7-S970H)&-F9U-O=7)C97-;)'-O=7)C95TI
M*2!["B`@("`@("`@("`@("1D<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS:6YG
M;&5T;VXH)'-O=7)C92D["B`@("`@("`@("`@(&EF("AI<U]A*"1D<FEV97(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]N;F5C=&EO;B!F86EL960Z("5S
M(BDL("1D<FEV97(M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<L(&YU
M;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D<F5S(#T@)&1R:79E<BT^<V5A<F-H*&%R<F%Y*"DI.PH@("`@("`@("`@
M("!I9B`H(6ES7V$H)')E<RP@)U1U<F)A7TQI<W0G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4V5A<F-H(&9A:6QE
M9"(I+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL+"`D<V]U<F-E*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@=VAI;&4@*"1O8B`]("1R97,M/FYE
M>'0H*2D@>PH@("`@("`@("`@("`@("`@:68@*"1O8BT^:&%S5F%L=64H)&9I
M96QD*2D@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1O8BT^9V5T
M5F%L=64H)W-O=7)C92<I("X@)SHG("X@)&]B+3YG971686QU92@G7U]K97DG
M*5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^
M("1O8BT^9V5T5F%L=64H)VYA;64G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)V5M86EL)R`]/B`D;V(M/F=E=%9A;'5E*"=E;6%I;"<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEE;&0@/3X@)&]B+3YG971686QU92@D9FEE
M;&0I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("!R971U<FX@)')E<W5L=',["GT*"F9U;F-T:6]N(%]T
M=7)B85]G971#;&EE;G13;W5R8V4H*0I["B`@("!R971U<FX@(65M<'1Y*"1'
M3$]"04Q36R=C;VYF)UU;)V-L:65N="==6R=A9&1R97-S8F]O:R==*2`_("1'
M3$]"04Q36R=C;VYF)UU;)V-L:65N="==6R=A9&1R97-S8F]O:R==(#H@9F%L
M<V4["GT*"F9U;F-T:6]N(%]T=7)B85]G971#;&EE;G0H)&]B:F5C=$ED(#T@
M)R<I"GL*("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G
M8VQI96YT<R]G971#;VYT86-T)RP@87)R87DH)W-O=7)C92<@/3X@)$=,3T)!
M3%-;)V-O;F8G75LG8VQI96YT)UU;)V%D9')E<W-B;V]K)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=O8FIE8W1)9"<@/3X@)&]B:F5C=$ED*2D["GT*"F9U
M;F-T:6]N(%]T=7)B85]G971#;&EE;G1S*"1O8FIE8W1)9',@/2!A<G)A>2@I
M*0I["B`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)V-L
M:65N=',O9V5T0V]N=&%C=',G+"!A<G)A>2@G<V]U<F-E)R`]/B`D1TQ/0D%,
M4ULG8V]N9B==6R=C;&EE;G0G75LG861D<F5S<V)O;VLG72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=O8FIE8W1)9',G(#T^("1O8FIE8W1)9',I*3L*?0H*
M9G5N8W1I;VX@7W1U<F)A7V%D9$-L:65N="@D871T<FEB=71E<R`](&%R<F%Y
M*"DI"GL*("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G
M8VQI96YT<R]I;7!O<G0G+"!A<G)A>2@G8V]N=&5N="<@/3X@)&%T=')I8G5T
M97,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V-O;G1E;G14>7!E)R`]/B`G87)R87DG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=S;W5R8V4G(#T^("1'3$]"04Q36R=R96=I
M<W1R>2==+3YC86QL*"=C;&EE;G1S+V=E=$-L:65N=%-O=7)C92<I*2D["GT*
M"F9U;F-T:6]N(%]T=7)B85]U<&1A=&5#;&EE;G0H)&]B:F5C=$ED(#T@)R<L
M("1A='1R:6)U=&5S(#T@87)R87DH*2D*>PH@("`@<F5T=7)N("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YC86QL*"=C;&EE;G1S+W)E<&QA8V4G+"!A<G)A>2@G
M=6ED)R`]/B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G8VQI96YT<R]G
M971#;&EE;G13;W5R8V4G*2`N("<Z)R`N("1O8FIE8W1)9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V-O;G1E;G0G(#T^("1A='1R:6)U=&5S+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8V]N=&5N=%1Y<&4G(#T^("=A<G)A>2<I*3L*?0H*9G5N8W1I
M;VX@7W1U<F)A7V1E;&5T94-L:65N="@D;V)J96-T260@/2`G)RD*>PH@("`@
M<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=C;&EE;G1S+V1E
M;&5T92<L(&%R<F%Y*"1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=C;&EE
M;G1S+V=E=$-L:65N=%-O=7)C92<I("X@)SHG("X@)&]B:F5C=$ED*2D["GT*
M"F9U;F-T:6]N(%]T=7)B85]S96%R8VA#;&EE;G1S*"1N86UE<R`](&%R<F%Y
M*"DL("1F:65L9',@/2!A<G)A>2@I*0I["B`@("!R971U<FX@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F-A;&PH)V-L:65N=',O<V5A<F-H)RP@87)R87DH)VYA
M;65S)R`]/B`D;F%M97,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-O=7)C97,G(#T^
M(&%R<F%Y*"1'3$]"04Q36R=C;VYF)UU;)V-L:65N="==6R=A9&1R97-S8F]O
M:R==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B`D9FEE;&1S*2D[
M"GT*"F9U;F-T:6]N(%]T=7)B85]A9&1&:65L9"@D861D<F5S<R`]("<G+"`D
M;F%M92`]("<G+"`D9FEE;&0@/2`G)RP@)'9A;'5E(#T@)R<L("1S;W5R8V4@
M/2`G)RD*>PH@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]B87-E+G!H<"<["B`@("!G;&]B86P@)&-F9U-O=7)C97,["@H@("`@:68@
M*&5M<'1Y*"1S;W5R8V4I('Q\("%I<W-E="@D8V9G4V]U<F-E<ULD<V]U<F-E
M72DI('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*"));G9A
M;&ED(&%D9')E<W,@8F]O:R(I+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL
M+"`D<V]U<F-E*3L*("`@('T*"B`@("!I9B`H96UP='DH)&%D9')E<W,I*2![
M"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!E
M;6%I;"(I+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL+"`D<V]U<F-E*3L*
M("`@('T*"B`@("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!N86UE(BDL("=H;W)D92YE
M<G)O<B<L(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@?0H*("`@(&EF("AE
M;7!T>2@D=F%L=64I*2!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B26YV86QI9"!E;G1R>2(I+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N
M=6QL+"`D<V]U<F-E*3L*("`@('T*"B`@("`D9')I=F5R(#T@)E1U<F)A7T1R
M:79E<CHZ<VEN9VQE=&]N*"1S;W5R8V4I.PH@("`@:68@*&ES7V$H)&1R:79E
M<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B0V]N;F5C=&EO;B!F86EL960Z("5S(BDL("1D
M<FEV97(M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<L(&YU;&PL(&YU
M;&PL("1S;W5R8V4I.PH@("`@?0H*("`@(&EF("@A)&1R:79E<BT^:&%S4&5R
M;6ES<VEO;BA015)-4U]%1$E4*2D@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E!E<FUI<W-I;VX@1&5N:65D(BDL("=H;W)D92YE<G)O
M<B<L(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@?0H*("`@("1R97,@/2`D
M9')I=F5R+3YS96%R8V@H87)R87DH)V5M86EL)R`]/B!T<FEM*"1A9&1R97-S
M*2DL(&YU;&PL("=!3D0G*3L*("`@(&EF("AI<U]A*"1R97,L("=014%27T5R
M<F]R)RDI('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(E-E87)C:"!F86EL960Z("5S(BDL("1R97,M/F=E=$UE<W-A9V4H
M*2DL("=H;W)D92YM97-S86=E)RP@;G5L;"P@;G5L;"P@)'-O=7)C92D["B`@
M("!]"@H@("`@:68@*"1R97,M/F-O=6YT*"D@/B`Q*2!["B`@("`@("`@)')E
M<S(@/2`D9')I=F5R+3YS96%R8V@H87)R87DH)V5M86EL)R`]/B!T<FEM*"1A
M9&1R97-S*2P@)VYA;64G(#T^('1R:6TH)&YA;64I*2P@;G5L;"P@)T%.1"<I
M.PH@("`@("`@(&EF("AI<U]A*"1R97,R+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M4V5A<F-H(&9A:6QE9#H@)7,B*2P@)')E<S(M/F=E=$UE<W-A9V4H*2DL("=H
M;W)D92YM97-S86=E)RP@;G5L;"P@;G5L;"P@)'-O=7)C92D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(21R97,R+3YC;W5N="@I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B375L=&EP;&4@
M<&5R<V]N<R!W:71H(&%D9')E<W,@6R5S72P@8G5T(&YO;F4@=VET:"!N86UE
M(%LE<UT@86QR96%D>2!E>&ES="(I+"!T<FEM*"1A9&1R97-S*2P@=')I;2@D
M;F%M92DI+"`G:&]R9&4N;65S<V%G92<L(&YU;&PL(&YU;&PL("1S;W5R8V4I
M.PH@("`@("`@('T*"B`@("`@("`@)')E<S,@/2`D9')I=F5R+3YS96%R8V@H
M87)R87DH)V5M86EL)R`]/B`D861D<F5S<RP@)VYA;64G(#T^("1N86UE+"`D
M9FEE;&0@/3X@)'9A;'5E*2D["B`@("`@("`@:68@*&ES7V$H)')E<S,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")396%R8V@@9F%I;&5D.B`E<R(I+"`D<F5S,RT^
M9V5T365S<V%G92@I*2P@)VAO<F1E+FUE<W-A9V4G+"!N=6QL+"!N=6QL+"`D
M<V]U<F-E*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5S,RT^8V]U;G0H
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(E1H:7,@<&5R<V]N(&%L<F5A9'D@:&%S(&$@)7,@96YT<GD@:6X@
M=&AE(&%D9')E<W,@8F]O:R(I+"`D9FEE;&0I+"`G:&]R9&4N;65S<V%G92<L
M(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@("`@('T*"B`@("`@("`@)&]B
M(#T@)')E<S(M/FYE>'0H*3L*("`@("`@("`D;V(M/G-E=%9A;'5E*"1F:65L
M9"P@)'9A;'5E*3L*("`@("`@("`D;V(M/G-T;W)E*"D["B`@("!](&5L<V5I
M9B`H)')E<RT^8V]U;G0H*2`]/2`Q*2!["B`@("`@("`@)')E<S0@/2`D9')I
M=F5R+3YS96%R8V@H87)R87DH)V5M86EL)R`]/B`D861D<F5S<RP@)&9I96QD
M(#T^("1V86QU92DI.PH@("`@("`@(&EF("AI<U]A*"1R97,T+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B4V5A<F-H(&9A:6QE9#H@)7,B*2P@)')E<S0M/F=E=$UE
M<W-A9V4H*2DL("=H;W)D92YM97-S86=E)RP@;G5L;"P@;G5L;"P@)'-O=7)C
M92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)')E<S0M/F-O=6YT*"DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")4:&ES('!E<G-O;B!A;')E861Y(&AA<R!A("5S(&5N=')Y(&EN('1H92!A
M9&1R97-S(&)O;VLB*2P@)&9I96QD*2P@)VAO<F1E+FUE<W-A9V4G+"!N=6QL
M+"!N=6QL+"`D<V]U<F-E*3L*("`@("`@("!]"@H@("`@("`@("1O8B`]("1R
M97,M/FYE>'0H*3L*("`@("`@("`D;V(M/G-E=%9A;'5E*"1F:65L9"P@)'9A
M;'5E*3L*("`@("`@("`D;V(M/G-T;W)E*"D["B`@("!](&5L<V4@>PH@("`@
M("`@(')E='5R;B`D9')I=F5R+3YA9&0H87)R87DH)V5M86EL)R`]/B`D861D
M<F5S<RP@)VYA;64G(#T^("1N86UE+"`D9FEE;&0@/3X@)'9A;'5E+"`G7U]O
M=VYE<B<@/3X@075T:#HZ9V5T075T:"@I*2D["B`@("!]"@H@("`@<F5T=7)N
M.PI]"@IF=6YC=&EO;B!?='5R8F%?9V5T1FEE;&0H)&%D9')E<W,@/2`G)RP@
M)&9I96QD(#T@)R<L("1S;W5R8V5S(#T@87)R87DH*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1S=')I8W0@/2!F86QS92D*>PH@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<["B`@("!G;&]B
M86P@)&-F9U-O=7)C97,["@H@("`@:68@*&5M<'1Y*"1A9&1R97-S*2D@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@96UA
M:6PB*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]"@H@("`@:68@*"%I<W-E="@D
M8V9G4V]U<F-E<RD@?'P@(6ES7V%R<F%Y*"1C9F=3;W5R8V5S*2!\?"`A8V]U
M;G0H)&-F9U-O=7)C97,I*2!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@
M("!]"@H@("`@:68@*"%C;W5N="@D<V]U<F-E<RDI('L*("`@("`@("!I9B`H
M(6-O=6YT*"1C9F=3;W5R8V5S*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*").;R!A9&1R97-S(&)O;VMS(&9O=6YD+B(I*3L*
M("`@("`@("!]"B`@("`@("`@)'-O=7)C97,@/2!A<G)A>2AK97DH)&-F9U-O
M=7)C97,I*3L*("`@('T*"B`@("`D8V]U;G0@/2`P.PH@("`@9F]R96%C:"`H
M)'-O=7)C97,@87,@)'-O=7)C92D@>PH@("`@("`@(&EF("@A:7-S970H)&-F
M9U-O=7)C97-;)'-O=7)C95TI*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@('T*"B`@("`@("`@)&1R:79E<B`]("94=7)B85]$<FEV97(Z.G-I
M;F=L971O;B@D<V]U<F-E*3L*("`@("`@("!I9B`H:7-?82@D9')I=F5R+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M('T*"B`@("`@("`@)&QI<W0@/2`D9')I=F5R+3YS96%R8V@H87)R87DH)V5M
M86EL)R`]/B`D861D<F5S<RDL(&YU;&PL("=!3D0G+"`P+"!A<G)A>2@I+"`D
M<W1R:6-T(#\@87)R87DH)V5M86EL)RD@.B!A<G)A>2@I*3L*("`@("`@("!I
M9B`H(6ES7V$H)&QI<W0L("=4=7)B85],:7-T)RDI('L*("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("!W:&EL92`H)&]B(#T@)&QI
M<W0M/FYE>'0H*2D@>PH@("`@("`@("`@("!I9B`H)&]B+3YH87-686QU92@D
M9FEE;&0I*2!["B`@("`@("`@("`@("`@("`D8V]U;G0K*SL*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D;V(M/F=E=%9A;'5E*"1F:65L9"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@:68@*"1C;W5N="`^(#$I
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")-;W)E('1H
M86X@,2!E;G1R>2!F;W5N9"(I+"`G:&]R9&4N=V%R;FEN9R<L(&YU;&PL(&YU
M;&PL("1S;W5R8V4I.PH@("`@?2!E;'-E:68@*"%I<W-E="@D<F5S=6QT*2D@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M3F\@)7,@96YT<GD@9F]U;F0@9F]R("5S(BDL("1F:65L9"P@)&%D9')E<W,I
M+"`G:&]R9&4N=V%R;FEN9R<L(&YU;&PL(&YU;&PL("1S;W5R8V4I.PH@("`@
M?0H*("`@(')E='5R;B`D<F5S=6QT.PI]"@IF=6YC=&EO;B!?='5R8F%?9&5L
M971E1FEE;&0H)&%D9')E<W,@/2`G)RP@)&9I96QD(#T@)R<L("1S;W5R8V5S
M(#T@87)R87DH*2D*>PH@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]B87-E+G!H<"<["B`@("!G;&]B86P@)&-F9U-O=7)C97,["@H@
M("`@:68@*&5M<'1Y*"1A9&1R97-S*2D@>PH@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(DEN=F%L:60@96UA:6PB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("!]"@H@("`@:68@*"%I<W-E="@D8V9G4V]U<F-E<RD@?'P@(6ES
M7V%R<F%Y*"1C9F=3;W5R8V5S*2!\?"`A8V]U;G0H)&-F9U-O=7)C97,I*2![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@:68@*&-O=6YT
M*"1S;W5R8V5S*2`]/2`P*2!["B`@("`@("`@)'-O=7)C97,@/2!A<G)A>2AK
M97DH)&-F9U-O=7)C97,I*3L*("`@('T*"B`@("`D<W5C8V5S<R`](&9A;'-E
M.PH*("`@(&9O<F5A8V@@*"1S;W5R8V5S(&%S("1S;W5R8V4I('L*("`@("`@
M("!I9B`H:7-S970H)&-F9U-O=7)C97-;)'-O=7)C95TI*2!["B`@("`@("`@
M("`@("1D<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS:6YG;&5T;VXH)'-O=7)C
M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1D<FEV97(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D<F5S(#T@)&1R:79E<BT^<V5A<F-H*&%R<F%Y*"=E
M;6%I;"<@/3X@)&%D9')E<W,I*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<RP@)U1U<F)A7TQI<W0G*2D@>PH@("`@("`@("`@("`@("`@:68@*"1R97,M
M/F-O=6YT*"D@/B`Q*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&]B(#T@)')E
M<RT^;F5X="@I.PH@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D;V(I
M("8F("1O8BT^:&%S5F%L=64H)&9I96QD*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1O8BT^<V5T5F%L=64H)&9I96QD+"`G)RD["B`@("`@("`@("`@("`@
M("`@("`@)&]B+3YS=&]R92@I.PH@("`@("`@("`@("`@("`@("`@("1S=6-C
M97-S(#T@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("!I9B`H(21S=6-C97-S*2!["B`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*").;R`E<R!E;G1R
M>2!F;W5N9"!F;W(@)7,B*2P@)&9I96QD+"`D861D<F5S<RDL("=H;W)D92YE
M<G)O<B<I.PH@("`@?0H*("`@(')E='5R;CL*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T=7)B82]L:6(O5'5R8F$N<&AP````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0W,#4U`#$P-#$W,S8R-S4V`#`R
M,#$Q,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+RHJ"B`J(%1H92!V:7)T=6%L('!A=&@@=&\@=7-E(&9O<B!6
M1E,@9&%T82X*("HO"F1E9FEN92@G5%520D%?5D937U!!5$@G+"`G+FAO<F1E
M+W1U<F)A+V1O8W5M96YT<R<I.PH*+RHJ"B`J(%1U<F)A($)A<V4@0VQA<W,N
M"B`J"B`J("1(;W)D93H@='5R8F$O;&EB+U1U<F)A+G!H<"QV(#$N-3DN-"XR
M,B`R,#`V+S`R+S`S(#`P.C0X.C4R(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO
M<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@5'5R
M8F$*("HO"F-L87-S(%1U<F)A('L*"B`@("!F=6YC=&EO;B!F;W)M871%;6%I
M;$%D9')E<W-E<R@D9&%T82P@)&YA;64I"B`@("!["B`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*("`@("`@("!S=&%T:6,@)&)A=&-H0V]M<&]S93L*"B`@
M("`@("`@:68@*"%I<W-E="@D8F%T8VA#;VUP;W-E*2D@>PH@("`@("`@("`@
M("`D8F%T8VA#;VUP;W-E(#T@)')E9VES=')Y+3YH87--971H;V0H)VUA:6PO
M8F%T8VA#;VUP;W-E)RD["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TU)344N<&AP)SL*"B`@("`@("`@)&%R<F%Y(#T@:7-?87)R
M87DH)&1A=&$I.PH@("`@("`@(&EF("@A)&%R<F%Y*2!["B`@("`@("`@("`@
M("1D871A(#T@87)R87DH)&1A=&$I.PH@("`@("`@('T*"B`@("`@("`@)&%D
M9')E<W-E<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@
M)&D@/3X@)&5M86EL7W9A;',I('L*("`@("`@("`@("`@)&5M86EL7W9A;',@
M/2!E>'!L;V1E*"<L)RP@)&5M86EL7W9A;',I.PH@("`@("`@("`@("!F;W)E
M86-H("@D96UA:6Q?=F%L<R!A<R`D:B`]/B`D96UA:6Q?=F%L*2!["B`@("`@
M("`@("`@("`@("`D96UA:6Q?=F%L(#T@=')I;2@D96UA:6Q?=F%L*3L*"B`@
M("`@("`@("`@("`@("`O+R!&;W)M870@=&AE(&%D9')E<W,@86-C;W)D:6YG
M('1O(%)&0S@R,BX*("`@("`@("`@("`@("`@("1M86EL8F]X7VAO<W0@/2!E
M>'!L;V1E*"=`)RP@)&5M86EL7W9A;"D["B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1M86EL8F]X7VAO<W1;,5TI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&UA:6QB;WA?:&]S=%LQ72`]("<G.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1A9&1R97-S(#T@34E-13HZ<F9C.#(R5W)I=&5!
M9&1R97-S*"1M86EL8F]X7VAO<W1;,%TL("1M86EL8F]X7VAO<W1;,5TL("1N
M86UE*3L*"B`@("`@("`@("`@("`@("`O+R!'970@<FED(&]F('1H92!T<F%I
M;&EN9R!`("AW:&5N(&YO(&AO<W0@:7,@:6YC;'5D960@:6X*("`@("`@("`@
M("`@("`@("\O('1H92!E;6%I;"!A9&1R97-S*2X*("`@("`@("`@("`@("`@
M("1A9&1R97-S97-;)&D@+B`G.B<@+B`D:ET@/2!A<G)A>2@G=&\G(#T^(&%D
M9'-L87-H97,H<W1R7W)E<&QA8V4H)T`^)RP@)SXG+"`D861D<F5S<RDI*3L*
M("`@("`@("`@("`@("`@(&EF("@A)&)A=&-H0V]M<&]S92D@>PH@("`@("`@
M("`@("`@("`@("`@("1A9&1R97-S97-;)&D@+B`G.B<@+B`D:ET@/2`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G;6%I;"]C;VUP;W-E)RP@)&%D9')E
M<W-E<ULD:2`N("<Z)R`N("1J72D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D8F%T8VA#;VUP;W-E
M*2!["B`@("`@("`@("`@("1A9&1R97-S97,@/2`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^8V%L;"@G;6%I;"]B871C:$-O;7!O<V4G+"!A<G)A>2@D861D<F5S
M<V5S*2D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D
M:2`]/B`D96UA:6Q?=F%L<RD@>PH@("`@("`@("`@("`D96UA:6Q?=F%L<R`]
M(&5X<&QO9&4H)RPG+"`D96UA:6Q?=F%L<RD["B`@("`@("`@("`@("1E;6%I
M;%]V86QU97,@/2!F86QS93L*("`@("`@("`@("`@9F]R96%C:"`H)&5M86EL
M7W9A;',@87,@)&H@/3X@)&5M86EL7W9A;"D@>PH@("`@("`@("`@("`@("`@
M:68@*"%I<U]A*"1A9&1R97-S97,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("`D;6%I;%]L:6YK(#T@)&%D9')E<W-E<ULD:2`N("<Z
M)R`N("1J73L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D;6%I;%]L
M:6YK+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1M86EL7VQI;FL@/2`G;6%I;'1O.B<@+B`D861D<F5S<SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1M86EL7VQI;FL@/2`G;6%I;'1O.B<@+B`D861D<F5S
M<SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D96UA:6Q?
M=F%L=64@/2!(;W)D93HZ;&EN:R@D;6%I;%]L:6YK+"`D96UA:6Q?=F%L*2`N
M(&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL7W9A;"D@+B`G/"]A/B<["B`@("`@
M("`@("`@("`@("!I9B`H)&5M86EL7W9A;'5E<RD@>PH@("`@("`@("`@("`@
M("`@("`@("1E;6%I;%]V86QU97,@+CT@)RP@)R`N("1E;6%I;%]V86QU93L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&5M86EL7W9A;'5E<R`]("1E;6%I;%]V86QU93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1A<G)A
M>2D@>PH@("`@("`@("`@("!R971U<FX@)&5M86EL7W9A;'5E<ULP73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)&5M86EL7W9A;'5E
M<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@86QL('1H
M92!A9&1R97-S(&)O;VMS('1H92!U<V5R(&AA<R!T:&4@<F5Q=65S=&5D('!E
M<FUI<W-I;VYS('1O(&%N9`H@("`@("H@<F5T=7)N('1H96T@:6X@=&AE('5S
M97(G<R!P<F5F97)R960@;W)D97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'!E<FUI<W-I;VX@(%1H92!015)-4U\J(&-O;G-T86YT('1O(&9I
M;'1E<B!O;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9FEL
M=&5R960L(&]R9&5R960@)&-F9U-O=7)C97,@96YT<FEE<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T061D<F5S<T)O;VMS*"1P97)M:7-S:6]N(#T@4$52
M35-?4D5!1"D*("`@('L*("`@("`@("`D861D<F5S<V)O;VMS(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*%1U<F)A.CIG971!9&1R
M97-S0F]O:T]R9&5R*"DI(&%S("1A9&1R97-S8F]O:RD@>PH@("`@("`@("`@
M("`D861D<F5S<V)O;VMS6R1A9&1R97-S8F]O:UT@/2`D1TQ/0D%,4ULG8V9G
M4V]U<F-E<R==6R1A9&1R97-S8F]O:UT["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(21A9&1R97-S8F]O:W,I('L*("`@("`@("`@("`@)&%D9')E<W-B;V]K
M<R`]("1'3$]"04Q36R=C9F=3;W5R8V5S)UT["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@5'5R8F$Z.G!E<FUI<W-I;VYS1FEL=&5R*"1A9&1R97-S8F]O
M:W,L("=S;W5R8V4G+"`D<&5R;6ES<VEO;BD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@=&AE(&]R9&5R('1H92!U<V5R('-E;&5C=&5D(&9O<B!D:7-P
M;&%Y:6YG(&%D9')E<W,@8F]O:W,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@06X@87)R87D@9&5S8W)I8FEN9R!T:&4@;W)D97(@=&\@9&ES<&QA
M>2!T:&4@861D<F5S<R!B;V]K<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M061D<F5S<T)O;VM/<F1E<B@I"B`@("!["B`@("`@("`@)&D@/2`P.PH@("`@
M("`@("1L:6YE<R`](&5X<&QO9&4H(EQN(BP@)$=,3T)!3%-;)W!R969S)UTM
M/F=E=%9A;'5E*"=A9&1R97-S8F]O:W,G*2D["B`@("`@("`@)'1E;7`@/2`D
M;&EN97,["B`@("`@("`@)&%D9')E<W-B;V]K<R`](&%R<F%Y*"D["B`@("`@
M("`@9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@("1L
M:6YE(#T@=')I;2@D;&EN92D["B`@("`@("`@("`@(&EF("@D;&EN92`F)B!I
M<W-E="@D1TQ/0D%,4ULG8V9G4V]U<F-E<R==6R1L:6YE72DI('L*("`@("`@
M("`@("`@("`@("1A9&1R97-S8F]O:W-;)&QI;F5=(#T@)&DK*SL*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O($EF('1H92!A9&1R
M97-S(&)O;VL@9&]E<R!N;W0@97AI<W0@:6X@8V9G4V]U<F-E<RP*("`@("`@
M("`@("`@("`@("\O('-E92!I9B!I="!W;W5L9"!H879E(')E<')E<V5N=&5D
M(&$@2&]R9&5?4VAA<F4N("!)9B!S;RP*("`@("`@("`@("`@("`@("\O(&%S
M<W5M92!T:&4@<VAA<F4@:7,@;F\@;&]N9V5R(&%V86EL86)L92!A;F0@<')U
M;F4@=&AE"B`@("`@("`@("`@("`@("`O+R!S971T:6YG+@H@("`@("`@("`@
M("`@("`@:68@*'-T<G!O<R@D;&EN92P@)SHG*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1P;W,@/2!A<G)A>5]S96%R8V@H)&QI;F4L("1T96UP*3L*("`@
M("`@("`@("`@("`@("`@("!U;G-E="@D=&5M<%LD<&]S72D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)$=,
M3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=A9&1R97-S8F]O:W,G+"!I;7!L
M;V1E*")<;B(L("1T96UP*2D["B`@("`@("`@<F5T=7)N("1A9&1R97-S8F]O
M:W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT
M('5S97(G<R!D969A=6QT(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&1E9F%U;'0@861D<F5S<R!B;V]K(&YA;64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1!9&1R97-S0F]O:R@I
M"B`@("!["B`@("`@("`@)&QI;F5S(#T@97AP;&]D92@B7&XB+"`D1TQ/0D%,
M4ULG<')E9G,G72T^9V5T5F%L=64H)V%D9')E<W-B;V]K<R<I*3L*("`@("`@
M("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@)&QI
M;F4@/2!T<FEM*"1L:6YE*3L*("`@("`@("`@("`@:68@*"1L:6YE("8F(&ES
M<V5T*"1'3$]"04Q36R=C9F=3;W5R8V5S)UU;)&QI;F5=*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1L:6YE.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"@H@("`@+RHJ"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-O;'5M;G,H*0H@("`@>PH@("`@("`@("1C
M;VQU;6YS(#T@87)R87DH*3L*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<
M;B(L("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G8V]L=6UN<R<I*3L*
M("`@("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@
M("`@)&QI;F4@/2!T<FEM*"1L:6YE*3L*("`@("`@("`@("`@:68@*"1L:6YE
M*2!["B`@("`@("`@("`@("`@("`D8V]L<R`](&5X<&QO9&4H(EQT(BP@)&QI
M;F4I.PH@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1C;VQS*2`^(#$I('L*
M("`@("`@("`@("`@("`@("`@("`D<V]U<F-E(#T@87)R87E?<W!L:6-E*"1C
M;VQS+"`P+"`Q*3L*("`@("`@("`@("`@("`@("`@("`D8V]L=6UN<ULD<V]U
M<F-E6S!=72`]("1C;VQS.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;'5M;G,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8F5S="!G=65S<R!A="!T:&4@
M;&%S=&YA;64@:6X@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@4W1R:6YG(&-O;G1A:6X@=&AE(&9U;&P@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&QA<W0@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9W5E<W-,87-T
M;F%M92@D;F%M92D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@
M("`@("`D;F%M92`]('1R:6TH<')E9U]R97!L86-E*"=\7'-\)RP@)R`G+"`D
M;F%M92DI.PH@("`@("`@(&EF("@A96UP='DH)&YA;64I*2!["B`@("`@("`@
M("`@("\J($%S<W5M92!T:&%T(&QA<W0@;F%M97,@87)E(&%L=V%Y<R!B969O
M<F4@86YY(&-O;6UA<RX@*B\*("`@("`@("`@("`@:68@*&ES7VEN="AS=')P
M;W,H)&YA;64L("<L)RDI*2!["B`@("`@("`@("`@("`@("`D;F%M92`](%-T
M<FEN9SHZ<W5B<W1R*"1N86UE+"`P+"!S=')P;W,H)&YA;64L("<L)RDI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!486ME(&]U="!A;GET:&EN
M9R!I;B!P87)E;G1H97-E<RX@*B\*("`@("`@("`@("`@)&YA;64@/2!T<FEM
M*'!R96=?<F5P;&%C92@G?%PH+BI<*7PG+"`G)RP@)&YA;64I*3L*"B`@("`@
M("`@("`@("1N86UE;&ES="`](&5X<&QO9&4H)R`G+"`D;F%M92D["B`@("`@
M("`@("`@("1N86UE(#T@)&YA;65L:7-T6R@D;F%M96EN9&5X(#T@*&-O=6YT
M*"1N86UE;&ES="D@+2`Q*2E=.PH*("`@("`@("`@("`@=VAI;&4@*"%E;7!T
M>2@D;F%M92D@)B8@4W1R:6YG.CIL96YG=&@H)&YA;64I(#P@-2`F)@H@("`@
M("`@("`@("`@("`@("`@<W1R<W!N*"1N86UE6RA3=')I;F<Z.FQE;F=T:"@D
M;F%M92D@+2`Q*5TL("<N.BTG*2`F)@H@("`@("`@("`@("`@("`@("`@(65M
M<'1Y*"1N86UE;&ES=%LH)&YA;65I;F1E>"`M(#$I72DI('L*("`@("`@("`@
M("`@("`@("1N86UE:6YD97@M+3L*("`@("`@("`@("`@("`@("1N86UE(#T@
M)&YA;65L:7-T6R1N86UE:6YD97A=.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J
M($9O<FUA=',@=&AE(&YA;64@86-C;W)D:6YG('1O('1H92!U<V5R)W,@<')E
M9F5R96YC92X*("`@("`J"B`@("`@*B!`<&%R86T@5'5R8F%?3V)J96-T("1O
M8B`@5&AE(&]B:F5C="!T;R!G970@82!N86UE(&9R;VTN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@;F%M92P@96ET:&5R
M(")&:7)S=&YA;64@3&%S=&YA;64B"B`@("`@*B`@("`@("`@("`@("`@("`@
M;W(@(DQA<W1N86UE+"!&:7)S=&YA;64B(&1E<&5N9&EN9R!O;B!T:&4@=7-E
M<B=S"B`@("`@*B`@("`@("`@("`@("`@("`@<')E9F5R96YC92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9F]R;6%T3F%M92@D;V(I"B`@("!["B`@("`@("`@
M9VQO8F%L("1P<F5F<SL*("`@("`@("!S=&%T:6,@)&YA;65?9F]R;6%T.PH*
M("`@("`@("!I9B`H(6ES<V5T*"1N86UE7V9O<FUA="DI('L*("`@("`@("`@
M("`@)&YA;65?9F]R;6%T(#T@)'!R969S+3YG971686QU92@G;F%M95]F;W)M
M870G*3L*("`@("`@("!]"@H@("`@("`@("\J(&EF(&YO(&9O<FUA='1I;F<L
M(')E='5R;B!O<FEG:6YA;"!N86UE("HO"B`@("`@("`@:68@*"1N86UE7V9O
M<FUA="`A/2`G9FER<W1?;&%S="<@)B8@)&YA;65?9F]R;6%T("$]("=L87-T
M7V9I<G-T)RD@>PH@("`@("`@("`@("!R971U<FX@)&]B+3YG971686QU92@G
M;F%M92<I.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5E(&EF('=E(&AA=F4@
M=&AE(&YA;64@9FEE;&1S('-P;&ET(&]U="!E>'!L:6-I=&QY+B`J+PH@("`@
M("`@(&EF("@D;V(M/FAA<U9A;'5E*"=F:7)S=&YA;64G*2`F)B`D;V(M/FAA
M<U9A;'5E*"=L87-T;F%M92<I*2!["B`@("`@("`@("`@(&EF("@D;F%M95]F
M;W)M870@/3T@)VQA<W1?9FER<W0G*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&]B+3YG971686QU92@G;&%S=&YA;64G*2`N("<L("<@+B`D;V(M/F=E
M=%9A;'5E*"=F:7)S=&YA;64G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D;V(M/F=E=%9A;'5E*"=F:7)S=&YA;64G
M*2`N("<@)R`N("1O8BT^9V5T5F%L=64H)VQA<W1N86UE)RD["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!/;F4@9FEE
M;&0L('=E)VQL(&AA=F4@=&\@9W5E<W,N("HO"B`@("`@("`@("`@("1N86UE
M(#T@)&]B+3YG971686QU92@G;F%M92<I.PH@("`@("`@("`@("`D;&%S=&YA
M;64@/2!4=7)B83HZ9W5E<W-,87-T;F%M92@D;F%M92D["B`@("`@("`@("`@
M(&EF("@D;F%M95]F;W)M870@/3T@)VQA<W1?9FER<W0G("8F"B`@("`@("`@
M("`@("`@("`A:7-?:6YT*'-T<G!O<R@D;F%M92P@)RPG*2D@)B8*("`@("`@
M("`@("`@("`@(%-T<FEN9SHZ;&5N9W1H*"1N86UE*2`^(%-T<FEN9SHZ;&5N
M9W1H*"1L87-T;F%M92DI('L*("`@("`@("`@("`@("`@("1N86UE(#T@<')E
M9U]R97!L86-E*"<O7',K)R`N('!R96=?<75O=&4H)&QA<W1N86UE+"`G+R<I
M("X@)R\G+"`G)RP@)&YA;64I.PH@("`@("`@("`@("`@("`@)&YA;64@/2`D
M;&%S=&YA;64@+B`G+"`G("X@)&YA;64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1N86UE7V9O<FUA="`]/2`G9FER<W1?;&%S="<@)B8*("`@
M("`@("`@("`@("`@(&ES7VEN="AS=')P;W,H)&YA;64L("<L)RDI("8F"B`@
M("`@("`@("`@("`@("!3=')I;F<Z.FQE;F=T:"@D;F%M92D@/B!3=')I;F<Z
M.FQE;F=T:"@D;&%S=&YA;64I*2!["B`@("`@("`@("`@("`@("`D;F%M92`]
M('!R96=?<F5P;&%C92@G+R<@+B!P<F5G7W%U;W1E*"1L87-T;F%M92P@)R\G
M*2`N("<L7',J+R<L("<G+"`D;F%M92D["B`@("`@("`@("`@("`@("`D;F%M
M92`]("1N86UE("X@)R`G("X@)&QA<W1N86UE.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B`D;F%M93L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:W,@:68@82!U<V5R(&AA<R!T:&4@<W!E8VEF:65D
M('!E<FUI<W-I;VYS(&]N('1H92!P87-S960M:6X@;V)J96-T+@H@("`@("H*
M("`@("`J($!S:6YC92!4=7)B82`R+C$*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&EN("`@("`@("`@("`@5&AE(&1A=&$@=&\@8VAE8VL@;VXN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QT97(@("`@("`@5VAA="!A<F4@=V4@
M8VAE8VMI;F<@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FUI<W-I
M;VX@(%=H870@<&5R;6ES<VEO;B!T;R!C:&5C:R!F;W(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@16ET:&5R(&$@8F]O;&5A;B!I9B!C:&5C:VEN
M9R!015)-4U\J(&]R(&$@<F5Q=65S=&5D"B`@("`@*B`@("`@("`@("`@("`@
M("!E>'1E;F1E9"!P97)M:7-S:6]N<R!V86QU92X*("`@("`J"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)&EN+"`D9FEL=&5R+"`D<&5R
M;6ES<VEO;B`](%!%4DU37U)%040I"B`@("!["B`@("`@("`@9VQO8F%L("1P
M97)M<SL*"B`@("`@("`@)'5S97))1"`]($%U=&@Z.F=E=$%U=&@H*3L*"B`@
M("`@("`@<W=I=&-H("@D9FEL=&5R*2!["B`@("`@("`@8V%S92`G;V)J96-T
M)SH*("`@("`@("`@("`@:68@*"%I<U]A*"1I;BP@)U1U<F)A7T]B:F5C="<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1S;W5R8V5486<@/2`G='5R8F$Z<V]U<F-E<SHG
M("X@)&EN+3YD<FEV97(M/FYA;64["B`@("`@("`@("`@(&EF("@D<&5R;7,M
M/F5X:7-T<R@D<V]U<F-E5&%G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1P97)M<RT^:&%S4&5R;6ES<VEO;B@D<V]U<F-E5&%G+"`D=7-E<DE$+"`D
M<&5R;6ES<VEO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN+3YG971686QU92@G7U]O=VYE<B<I*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R\@3W1H97)W:7-E+"!W92!A<W-U;64@
M86YY;VYE(&-A;B!A8V-E<W,@=&AE:7(@<')I=F%T90H@("`@("`@("`@("`O
M+R!A9&1R97-S(&)O;VMS+"!B=70@;F]T('!U8FQI8R!O;F5S+@H@("`@("`@
M("`@("!R971U<FX@(21I;BT^9')I=F5R+3YP=6)L:6,["@H@("`@("`@(&-A
M<V4@)W-O=7)C92<Z"B`@("`@("`@("`@("\O($YO=&4@=&AA="!I9B!W92!A
M<F4@=7-I;F<@2&]R9&4@4&5R;6ES<VEO;G,@=&AE;B`D<V]U<F-E('=I;&P*
M("`@("`@("`@("`@+R\@*&-O<G)E8W1L>2D@8F4@<')U;F5D(&AE<F4@=&\@
M<&]I;G0@=&\@=&AE("=O<FEG:6YA;"<@96YT<GD@:6X*("`@("`@("`@("`@
M+R\@)&-F9U-O=7)C97,N($]T:&5R=VES92P@=V4@8V]U;&1N)W0@96YF;W)C
M92!T:&4@97AT96YD960*("`@("`@("`@("`@+R\@<&5R;6ES<VEO;G,@;&EK
M92!M87A?8V]N=&%C=',@;VX@82!P97(@<V]U<F-E(&)A<VES+@H@("`@("`@
M("`@("!I9B`H*"1P;W,@/2!S=')P;W,H)&EN+"`G.B<I*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("1S;W5R8V4@/2!S=6)S='(H)&EN+"`P+"`D
M<&]S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S
M;W5R8V4@/2`D:6X["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-R8T-O
M;F9I9R`]("1'3$]"04Q36R=C9F=3;W5R8V5S)UU;)'-O=7)C95T["B`@("`@
M("`@("`@(&EF("@A)'!E<FUS+3YE>&ES=',H)W1U<F)A.G-O=7)C97,Z)R`N
M("1I;BDI('L*("`@("`@("`@("`@("`@("\O($%S<W5M92!W92!H879E('!E
M<FUI<W-I;VYS(&EF(&ET)W,@;F]T(&5X<&QI8VET;'D@<V5T+@H@("`@("`@
M("`@("`@("`@+R\@268@=7-I;F<@2&]R9&5?4VAA<F4L('1H92!O;FQY('!E
M<FUS('=E)V0@8F4@8VAE8VMI;F<*("`@("`@("`@("`@("`@("\O(&%R92!T
M:&4@97AT96YD960@<&5R;6ES<VEO;G,N"B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"AE;7!T>2@D<W)C0V]N
M9FEG6R=U<V5?<VAA<F5S)UTI*2`F)@H@("`@("`@("`@("`@("`@("`@("`@
M*"1S;W5R8V4@/3T]("1I;BDI('L*("`@("`@("`@("`@("`@("\O(%5S:6YG
M($AO<F1E7U!E<FUS($%.1"!C:&5C:VEN9R!S;W5R8V4@;&5V96P@<&5R;7-I
M<W-I;VYS"B`@("`@("`@("`@("`@("!R971U<FX@)'!E<FUS+3YH87-097)M
M:7-S:6]N*"=T=7)B83IS;W5R8V5S.B<@+B`D:6XL("1U<V5R240L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P97)M
M:7-S:6]N*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("\O($-H96-K:6YG(&5X=&5N9&5D('!E<FUI<W-I;VYS(&9O<B!E:71H97(@
M2&]R9&5?4&5R;7,@;W(*("`@("`@("`@("`@("`@("\O($AO<F1E7U-H87)E
M"B`@("`@("`@("`@("`@("`D86QL;W=E9"`]("1P97)M<RT^9V5T4&5R;6ES
M<VEO;G,H)W1U<F)A.G-O=7)C97,Z)R`N("1I;BD["B`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&%L;&]W960I*2!["B`@("`@("`@("`@("`@("`@
M("`@<W=I=&-H("AS=6)S='(H)&EN+"!S=')P;W,H)&EN+"`G.B<I*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)VUA>%]C;VYT86-T<R<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1A;&QO=V5D(#T@87)R87E?<F5D=6-E*"1A
M;&QO=V5D+"!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L("=R971U<FX@;6%X
M*"1A+"`D8BD[)RDL(#`I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!R971U<FX@)&%L;&]W960["B`@("`@("`@("`@('T*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&:6QT97)S(&1A=&$@8F%S960@;VX@<&5R;6ES<VEO;G,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1I;B`@("`@("`@("`@(%1H92!D
M871A('=E('=A;G0@9FEL=&5R960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QT97(@("`@("`@5VAA="!T>7!E(&]F(&1A=&$@=V4@87)E(&9I;'1E<FEN
M9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N("!4:&4@4$52
M35-?*B!C;VYS=&%N="!W92!W:6QL(&9I;'1E<B!O;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@9FEL=&5R960@9&%T82X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<&5R;6ES<VEO;G-&:6QT97(H)&EN+"`D9FEL=&5R+"`D
M<&5R;6ES<VEO;B`](%!%4DU37U)%040I"B`@("!["B`@("`@("`@9VQO8F%L
M("1P97)M<SL*"B`@("`@("`@)&]U="`](&%R<F%Y*"D["@H@("`@("`@('-W
M:71C:"`H)&9I;'1E<BD@>PH@("`@("`@(&-A<V4@)W-O=7)C92<Z"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1I;B!A<R`D<V]U<F-E260@/3X@)'-O=7)C92D@
M>PH@("`@("`@("`@("`@("`@)&1R:79E<B`]("94=7)B85]$<FEV97(Z.G-I
M;F=L971O;B@D<V]U<F-E260I.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A
M*"1D<FEV97(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&1R:79E<BT^:&%S4&5R;6ES<VEO;B@D<&5R;6ES<VEO;BDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]U=%LD<V]U<F-E261=(#T@)'-O
M=7)C93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("1O=70@/2`D:6X["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&]U=#L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T
M97,@82!N97<@)&-F9U-O=7)C97,@96YT<GD@9F]R(&5A8V@@<VAA<F4@=&AE
M(&-U<G)E;G0@=7-E<B!H87,*("`@("`J(&%C8V5S<R!T;RX@($YO=&4@=&AA
M="!T:&ES('=I;&P@;VYL>2!S>6YC('-H87)E<R!T:&%T(&%R92!U;FEQ=64@
M=&\*("`@("`J($AO<F1E("AB87-I8V%L;'DL(&$@4U%,(&1R:79E<B!S;W5R
M8V4@9F]R(&YO=RDN("!!;GD@8F%C:V5N9"!T:&%T"B`@("`@*B!S=7!P;W)T
M<R!A8VQS(&]R('-I;6EL87(@;65C:&%N:7-M('-H;W5L9"!B92!C;VYF:6=U
M<F5D(&9R;VT@=VET:&EN"B`@("`@*B!S;W5R8V5S+G!H<"!O<B!?:&]R9&5?
M:&]O:U]S:&%R95\J(&-A;&QS+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<V]U<F-E<R`@5&AE(&1E9F%U;'0@)&-F9U-O=7)C97,@87)R87DN"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE("1C9F=3;W5R8V5S(&%R
M<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VYF:6=&<F]M4VAA<F5S
M*"1S;W5R8V5S*0H@("`@>PH@("`@("`@("1S:&%R97,@/2!4=7)B83HZ;&ES
M=%-H87)E<R@I.PH@("`@("`@+R\@3F]T:69Y('1H92!U<V5R(&EF('=E(&9A
M:6QE9"P@8G5T('-T:6QL(')E='5R;B!T:&4@)&-F9U-O=7)C92!A<G)A>2X*
M("`@("`@(&EF("AI<U]A*"1S:&%R97,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1S:&%R97,I.PH@("`@("`@
M("`@(')E='5R;B`D<V]U<F-E<SL*("`@("`@('T*("`@("`@("1S:&%R94YA
M;65S(#T@87)R87E?:V5Y<R@D<VAA<F5S*3L*("`@("`@(&9O<F5A8V@@*"1S
M:&%R94YA;65S(&%S("1N86UE*2!["B`@("`@("`@("`@:68@*"%I<W-E="@D
M<V]U<F-E<ULD;F%M95TI*2!["B`@("`@("`@("`@("`@(&QI<W0H)'-R8U1Y
M<&4L("1U<V5R*2`](&5X<&QO9&4H)SHG+"`D;F%M92P@,BD["B`@("`@("`@
M("`@("`@(&EF("@H)'5S97(@(3T@075T:#HZ9V5T075T:"@I*2`F)@H@("`@
M("`@("`@("`@("`@("`@*"%E;7!T>2@D<V]U<F-E<ULD<W)C5'EP95U;)W5S
M95]S:&%R97,G72DI*2!["B`@("`@("`@("`@("`@("`@("`D;F5W4W)C(#T@
M)'-O=7)C97-;)'-R8U1Y<&5=.PH@("`@("`@("`@("`@("`@("`@)&YE=U-R
M8ULG=&ET;&4G72`]("1S:&%R97-;)&YA;65=+3YG970H)VYA;64G*3L*("`@
M("`@("`@("`@("`@("`@("1S;W5R8V5S6R1N86UE72`]("1N97=3<F,["B`@
M("`@("`@("`@("`@('T*("`@("`@("`@("!]"B`@("`@("!]"B`@("`@("!R
M971U<FX@)'-O=7)C97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&%L;"!S:&%R97,@=&AE(&-U<G)E;G0@=7-E<B!H87,@<W!E8VEF:65D('!E
M<FUI<W-I;VYS('1O+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1O
M=VYE<F]N;'D@("!/;FQY(')E='5R;B!A9&1R97-S(&)O;VMS(&]W;F5D(&)Y
M('1H92!U<V5R/PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E
M<FUI<W-I;VX@(%!E<FUI<W-I;VYS('1O(&9I;'1E<B!B>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!3:&%R97,@=&AE('5S97(@:&%S('1H92!R
M97%U97-T960@<&5R;6ES<VEO;G,@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QI<W13:&%R97,H)&]W;F5R;VYL>2`](&9A;'-E+"`D<&5R;6ES<VEO;B`]
M(%!%4DU37U)%040I"B`@("!["B`@("`@("`@)'-O=7)C97,@/2`D1TQ/0D%,
M4ULG='5R8F%?<VAA<F5S)UTM/FQI<W13:&%R97,H075T:#HZ9V5T075T:"@I
M+"`D<&5R;6ES<VEO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&]W;F5R;VYL>2`_($%U=&@Z.F=E
M=$%U=&@H*2`Z(&YU;&PI.PH@("`@("`@(&EF("AI<U]A*"1S;W5R8V5S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"1S;W5R8V5S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'-O=7)C97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&4@82!N97<@5'5R8F$@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@("`@("`@4&%R86UE=&5R<R!F;W(@=&AE(&YE=R!S:&%R
M92!O8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:7-D969A=6QT("!!
M<F4@=V4@8W)E871I;F<@82`G9&5F875L="<@<VAA<F4_"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(&YE=R!S:&%R92!O8FIE8W0@;W(@4$5!
M4E]%<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B`F8W)E871E4VAA<F4H)'!A
M<F%M<RP@)&ES1&5F875L="`](&9A;'-E*0H@("`@>PH@("`@("`@("\O(%=E
M(&YE960@=&\@:VYO=R!W:&%T('1H92!S;W5R8V4@='EP92!I<R!F;W(@=&AI
M<R!S:&%R92X*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG<V]U<F-E5'EP
M92==*2D@>PH@("`@("`@("`@("`D<VAA<F4@/2!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B56YA8FQE('1O(&-R96%T92!N97<@<VAA<F4N($UI<W-I
M;F<@<V]U<F-E('1Y<&4N(BDI*3L*("`@("`@("`@("`@<F5T=7)N("1S:&%R
M93L*("`@("`@("!]"@H@("`@("`@(&EF("@D:7-$969A=6QT*2!["B`@("`@
M("`@("`@("\O($=A=&AE<B!I;F9O(&9O<B!U<V5R)W,@9&5F875L="!S:&%R
M92!F;W(@=&AI<R!S;W5R8V4N"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("`@("`@)&ED96YT:71Y(#T@
M)DED96YT:71Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@:68@*"%I<W-E
M="@D<&%R86US6R=S:&%R94YA;64G72DI('L*("`@("`@("`@("`@("`@("\O
M(%5S92!T:&4@<VAA<F5.86UE(&EF(&ET('=A<R!P87-S960@:6XL(&]T:&5R
M=VES92!U<V4*("`@("`@("`@("`@("`@("\O(&$@<V5N<VEB;&4@9&5F875L
M="X*("`@("`@("`@("`@("`@("1N86UE(#T@)&ED96YT:71Y+3YG971686QU
M92@G9G5L;&YA;64G*3L*("`@("`@("`@("`@("`@(&EF("AT<FEM*"1N86UE
M*2`]/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@075T:#HZ
M<F5M;W9E2&]O:RA!=71H.CIG971!=71H*"DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&YA;64@/2!S<')I;G1F*%\H(B5S)W,@061D
M<F5S<R!";V]K(BDL("1N86UE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1N86UE(#T@)'!A<F%M<ULG<VAA<F5.86UE)UT["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'5I9"`]($%U=&@Z.F=E=$%U=&@H
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!.;W0@9&5F875L
M="!S:&%R92P@<V5E(&EF('=E(&YE960@=&\@9V5N97)A=&4@82!U:60N"B`@
M("`@("`@("`@("1N86UE(#T@)'!A<F%M<ULG<VAA<F5.86UE)UT["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=U:60G72DI('L*("`@("`@("`@
M("`@("`@("1U:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'5I9"`]("1P87)A;7-;)W5I9"==
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!'96YE<F%T
M92!T:&4@;F5W('-H87)E"B`@("`@("`@)'-H87)E(#T@)B1'3$]"04Q36R=T
M=7)B85]S:&%R97,G72T^;F5W4VAA<F4H)'!A<F%M<ULG<V]U<F-E5'EP92==
M("X@)SHG("X@)'5I9"D["B`@("`@("`@:68@*&ES7V$H)'-H87)E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<VAA<F4["B`@("`@
M("`@?0H*("`@("`@("`D<VAA<F4M/G-E="@G;F%M92<L("1N86UE*3L*("`@
M("`@("`D<VAA<F4M/G-E="@G=6ED)RP@)'5I9"D["B`@("`@("`@)'-H87)E
M+3YA9&15<V5R4&5R;6ES<VEO;BA!=71H.CIG971!=71H*"DL(%!%4DU37T%,
M3"D["B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("!I9B`H)&ME>2`A/2`G<V]U<F-E5'EP92<@)B8@
M)&ME>2`A/2`G<VAA<F5.86UE)R`F)B`D:V5Y("$]("=U:60G*2!["B`@("`@
M("`@("`@("`@("`D<VAA<F4M/G-E="@D:V5Y+"`D=F%L=64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@("1'3$]"04Q36R=T=7)B85]S:&%R
M97,G72T^861D4VAA<F4H)'-H87)E*3L*("`@("`@("`D<VAA<F4M/G-A=F4H
M*3L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@57!D871E(&$@5'5R8F$@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@(%1H92!N86UE(&]F('1H92!S:&%R92!T;R!U<&1A
M=&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M<R!T
M;R!U<&1A=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&1I
M<W!L87D@;F%M92!O9B!T:&4@=7!D871E9"!S:&%R92!O<B!014%27T5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&53:&%R92@D;F%M92P@)'!A
M<F%M<RD*("`@('L*("`@("`@("`D<VAA<F4@/2`F)$=,3T)!3%-;)W1U<F)A
M7W-H87)E<R==+3YG9713:&%R92@D;F%M92D["B`@("`@("`@)&YA;64@/2`D
M<VAA<F4M/F=E="@G;F%M92<I.PH@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@
M87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)'-H87)E+3YS970H
M)&ME>2P@)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]("1S
M:&%R92T^<V%V92@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1N86UE.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!A(%1U<F)A('-H87)E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE
M(&]F('1H92!S:&%R92!T;R!R96UO=F4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&1I<W!L87D@;F%M92!O9B!T:&4@9&5L971E9"!S:&%R
M92!O<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&53
M:&%R92@D;F%M92D*("`@('L*("`@("`@("`D<VAA<F4@/2`F)$=,3T)!3%-;
M)W1U<F)A7W-H87)E<R==+3YG9713:&%R92@D;F%M92D["B`@("`@("`@:68@
M*&ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<VAA<F4["B`@("`@("`@?0H*("`@("`@("`O+R!%;F9O<F-E('1H
M92!R97%U:7)E;65N="!T:&%T(&]N;'D@=&AE('-H87)E)W,@;W=N97(@8V%N
M(&1E;&5T92!I="X*("`@("`@("!I9B`H)'-H87)E+3YG970H)V]W;F5R)RD@
M(3T@075T:#HZ9V5T075T:"@I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N<R!T
M;R!D96QE=&4@=&AI<R!S;W5R8V4N(BDI.PH@("`@("`@('T*("`@("`@("`D
M;F%M92`]("1S:&%R92T^9V5T*"=N86UE)RD["B`@("`@("`@)')E<R`]("1'
M3$]"04Q36R=T=7)B85]S:&%R97,G72T^<F5M;W9E4VAA<F4H)'-H87)E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D;F%M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!"=6EL9"!4=7)B82=S(&QI<W0@;V8@;65N=2!I=&5M<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T365N=2@D<F5T=7)N5'EP92`]("=O8FIE8W0G
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G
M.PH@("`@("`@("1M96YU(#T@)FYE=R!-96YU*"D["@H@("`@("`@(&EF("@D
M1TQ/0D%,4ULG:&%V95-H87)E)UTI('L*("`@("`@("`@("`@)&UE;G4M/F%D
M9"A(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D9')E<W-B;V]K<RYP:'`G*2P@
M7R@B7TUY($%D9')E<W,@0F]O:W,B*2P@)W1U<F)A+G!N9R<I.PH@("`@("`@
M('T*("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S95]S;W5R8V5?8V]U;G0G
M72D@>PH@("`@("`@("`@("`D;65N=2T^861D*$AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G8G)O=W-E+G!H<"<I+"!?*")?0G)O=W-E(BDL("=M96YU+V)R;W=S
M92YP;F<G+"!N=6QL+"!N=6QL+"!N=6QL+"`H*"1'3$]"04Q36R=P<F5F<R==
M+3YG971686QU92@G:6YI=&EA;%]P86=E)RD@/3T@)V)R;W=S92YP:'`G("8F
M(&)A<V5N86UE*"1?4T525D526R=02%!?4T5,1B==*2`]/2`G:6YD97@N<&AP
M)RD@?'P@*&)A<V5N86UE*"1?4T525D526R=02%!?4T5,1B==*2`]/2`G8G)O
M=W-E+G!H<"<@)B8@571I;#HZ9V5T1F]R;41A=&$H)VME>2<I("$]("<J*G-E
M87)C:"<I*2`_("=C=7)R96YT)R`Z("=?7VYO<V5L96-T:6]N)RD["B`@("`@
M("`@?0H@("`@("`@(&EF("AC;W5N="@D1TQ/0D%,4ULG861D4V]U<F-E<R==
M*2D@>PH@("`@("`@("`@("`D;65N=2T^861D*$AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G861D+G!H<"<I+"!?*")?3F5W($-O;G1A8W0B*2P@)VUE;G4O;F5W
M+G!N9R<I.PH@("`@("`@('T*("`@("`@("`D;65N=2T^861D*$AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G<V5A<F-H+G!H<"<I+"!?*")?4V5A<F-H(BDL("=S
M96%R8V@N<&YG)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER
M*"=H;W)D92<I+"!N=6QL+"!N=6QL+"`H*"1'3$]"04Q36R=P<F5F<R==+3YG
M971686QU92@G:6YI=&EA;%]P86=E)RD@/3T@)W-E87)C:"YP:'`G("8F(&)A
M<V5N86UE*"1?4T525D526R=02%!?4T5,1B==*2`]/2`G:6YD97@N<&AP)RD@
M?'P@*&)A<V5N86UE*"1?4T525D526R=02%!?4T5,1B==*2`]/2`G8G)O=W-E
M+G!H<"<@)B8@571I;#HZ9V5T1F]R;41A=&$H)VME>2<I(#T]("<J*G-E87)C
M:"<I*2`_("=C=7)R96YT)R`Z(&YU;&PI.PH*("`@("`@("`O*B!);7!O<G0O
M17AP;W)T("HO"B`@("`@("`@:68@*"1'3$]"04Q36R=C;VYF)UU;)VUE;G4G
M75LG:6UP;W)T7V5X<&]R="==*2!["B`@("`@("`@("`@("1M96YU+3YA9&0H
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=D871A+G!H<"<I+"!?*")?26UP;W)T
M+T5X<&]R="(I+"`G9&%T82YP;F<G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1R971U<FY4>7!E(#T]("=O8FIE8W0G*2!["B`@("`@("`@("`@(')E='5R
M;B`D;65N=3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M)&UE;G4M/G)E;F1E<B@I.PH@("`@("`@('T*("`@('T*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&EB+V)A
M<V4N<&AP````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-C(S-``Q,#0Q-S,V,C<U-@`P,3<W,S<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1U<F)A(&)A
M<V4@:6YC;'5S:6]N(&9I;&4N"B`J"B`J("1(;W)D93H@='5R8F$O;&EB+V)A
M<V4N<&AP+'8@,2XV,BXQ,"XQ,B`R,#`V+S`S+S`Q(#$Y.C,Q.C0V(&-H=6-K
M($5X<"`D"B`J"B`J(%1H:7,@9FEL92!B<FEN9W,@:6X@86QL(&]F('1H92!D
M97!E;F1E;F-I97,@=&AA="!E=F5R>2!4=7)B82!S8W)I<'0*("H@=VEL;"!N
M965D+"!A;F0@<V5T<R!U<"!O8FIE8W1S('1H870@86QL('-C<FEP=',@=7-E
M+@H@*B\*"B\O($-H96-K(&9O<B!A('!R:6]R(&1E9FEN:71I;VX@;V8@2$]2
M1$5?0D%312`H<&5R:&%P<R!B>2!A;@HO+R!A=71O7W!R97!E;F1?9FEL92!D
M969I;FET:6]N(&9O<B!S:71E(&-U<W1O;6EZ871I;VXI+@II9B`H(61E9FEN
M960H)TA/4D1%7T)!4T4G*2D@>PH@("`@0&1E9FEN92@G2$]21$5?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PI]"@HO+R!,;V%D('1H
M92!(;W)D92!&<F%M97=O<FL@8V]R92P@86YD('-E="!U<"!I;F-L=7-I;VX@
M<&%T:',N"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP
M:'`G.PH*+R\@4F5G:7-T<GDN"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN
M9VQE=&]N*"D["FEF("AI<U]A*"@D<'5S:&5D(#T@)')E9VES=')Y+3YP=7-H
M07!P*"=T=7)B82<L("%D969I;F5D*"=!551(7TA!3D1,15(G*2DI+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("!I9B`H)'!U<VAE9"T^9V5T0V]D92@I(#T]("=P
M97)M:7-S:6]N7V1E;FEE9"<I('L*("`@("`@("!(;W)D93HZ875T:&5N=&EC
M871I;VY&86EL=7)E4F5D:7)E8W0H*3L*("`@('T*("`@($AO<F1E.CIF871A
M;"@D<'5S:&5D+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*?0HD8V]N
M9B`]("1'3$]"04Q36R=C;VYF)UT["D!D969I;F4H)U154D)!7U1%35!,051%
M4R<L("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G*2D["@HO+R!(;W)D92!F
M<F%M97=O<FL@;&EB<F%R:65S+@IR97%U:7)E7V]N8V4@)TAO<F1E+TAE;'`N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92](:7-T;W)Y+G!H<"<["@HO+R!.
M;W1I9FEC871I;VX@<WES=&5M+@HD;F]T:69I8V%T:6]N(#T@)DYO=&EF:6-A
M=&EO;CHZ<VEN9VQE=&]N*"D["B1N;W1I9FEC871I;VXM/F%T=&%C:"@G<W1A
M='5S)RD["@HO+R!&:6YD('1H92!B87-E(&9I;&4@<&%T:"!O9B!4=7)B82X*
M0&1E9FEN92@G5%520D%?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B<I.PH*+R\@5'5R8F$@8F%S92!L:6)R87)Y+@IR97%U:7)E7V]N8V4@5%52
M0D%?0D%312`N("<O;&EB+U1U<F)A+G!H<"<["G)E<75I<F5?;VYC92!455)"
M05]"05-%("X@)R]L:6(O1')I=F5R+G!H<"<["@HO+R!4=7)B82!S;W5R8V4@
M86YD(&%T=')I8G5T92!C;VYF:6=U<F%T:6]N+@IR97%U:7)E(%154D)!7T)!
M4T4@+B`G+V-O;F9I9R]A='1R:6)U=&5S+G!H<"<["G)E<75I<F4@5%520D%?
M0D%312`N("<O8V]N9FEG+W-O=7)C97,N<&AP)SL*"B\O(%1U<F)A)W,@2&]R
M9&5?4VAA<F4@;V)J96-T+@IR97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H
M<"<["B1'3$]"04Q36R=T=7)B85]S:&%R97,G72`]("9(;W)D95]3:&%R93HZ
M<VEN9VQE=&]N*"1R96=I<W1R>2T^9V5T07!P*"DI.PH*+R\@4V5E(&EF(&%N
M>2!O9B!O=7(@<V]U<F-E<R!A<F4@8V]N9FEG=7)E9"!T;R!U<V4@2&]R9&5?
M4VAA<F4N"B1H879E4VAA<F4@/2!F86QS93L*9F]R96%C:"`H)&-F9U-O=7)C
M97,@87,@)&ME>2`]/B`D8V9G*2!["B`@("!I9B`H(65M<'1Y*"1C9F=;)W5S
M95]S:&%R97,G72DI('L*("`@("`@("`D:&%V95-H87)E(#T@=')U93L*("`@
M('T*?0II9B`H)&AA=F53:&%R92D@>PH@("`@)$=,3T)!3%-;)V-F9U-O=7)C
M97,G72`](%1U<F)A.CIG971#;VYF:6=&<F]M4VAA<F5S*"1C9F=3;W5R8V5S
M*3L*?2!E;'-E('L*("`@("1'3$]"04Q36R=C9F=3;W5R8V5S)UT@/2`D8V9G
M4V]U<F-E<SL*?0HD1TQ/0D%,4ULG8V9G4V]U<F-E<R==(#T@5'5R8F$Z.G!E
M<FUI<W-I;VYS1FEL=&5R*"1'3$]"04Q36R=C9F=3;W5R8V5S)UTL("=S;W5R
M8V4G*3L*)$=,3T)!3%-;)V%T=')I8G5T97,G72`]("1A='1R:6)U=&5S.PH*
M+R\@0G5I;&0@=&AE(&1I<F5C=&]R>2!S;W5R8V5S('-E;&5C="!W:61G970N
M"FEF("@A:7-S970H)'-O=7)C92DI('L*("`@("1S;W5R8V4@/2!5=&EL.CIG
M971&;W)M1&%T82@G<V]U<F-E)RP@5'5R8F$Z.F=E=$1E9F%U;'1!9&1R97-S
M0F]O:R@I*3L*?0HD8G)O=W-E7W-O=7)C95]O<'1I;VYS(#T@)R<["B1B<F]W
M<V5?<V]U<F-E7V-O=6YT(#T@,#L*9F]R96%C:"`H5'5R8F$Z.F=E=$%D9')E
M<W-";V]K<R@I(&%S("1K97D@/3X@)&-U<E-O=7)C92D@>PH@("`@:68@*"%E
M;7!T>2@D8W5R4V]U<F-E6R=B<F]W<V4G72DI('L*("`@("`@("`D<V5L96-T
M960@/2`H)&ME>2`]/2`D<V]U<F-E*2`_("<@<V5L96-T960](G-E;&5C=&5D
M(B<@.B`G)SL*("`@("`@("`D8G)O=W-E7W-O=7)C95]O<'1I;VYS("X]("<\
M;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`N("<B
M("<@+B`D<V5L96-T960@+B`G/B<@+@H@("`@("`@("`@("!H=&UL<W!E8VEA
M;&-H87)S*"1C=7)3;W5R8V5;)W1I=&QE)UTI("X@)SPO;W!T:6]N/B<["@H@
M("`@("`@("1B<F]W<V5?<V]U<F-E7V-O=6YT*RL["@H@("`@("`@(&EF("AE
M;7!T>2@D<V]U<F-E*2D@>PH@("`@("`@("`@("`D<V]U<F-E(#T@)&ME>3L*
M("`@("`@("!]"B`@("!]"GT*"B\O($AI9&4@=&AE(&QI<W0@;V8@861D<F5S
M<V)O;VMS(&EF('1H97)E(&ES(&]N;'D@;VYE(&%V86EL86)L92X*)&%D9%]S
M;W5R8V5?;W!T:6]N<R`]("<G.PHD861D4V]U<F-E<R`](%1U<F)A.CIG971!
M9&1R97-S0F]O:W,H4$5235-?141)5"D["FEF("AC;W5N="@D861D4V]U<F-E
M<RD@/B`Q*2!["B`@("!F;W)E86-H("@D861D4V]U<F-E<R!A<R`D:V5Y(#T^
M("1C=7)3;W5R8V4I('L*("`@("`@("!I9B`H)&ME>2`A/2`D<V]U<F-E*2![
M"B`@("`@("`@("`@("1A9&1?<V]U<F-E7V]P=&EO;G,@+CT@)SQO<'1I;VX@
M=F%L=64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1K97DI("X@)R(^)R`N"B`@
M("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1C=7)3;W5R8V5;)W1I
M=&QE)UTI("X@)SPO;W!T:6]N/B<["B`@("`@("`@?0H@("`@?0I]"@HO+R!3
M=&%R="!C;VUP<F5S<VEO;BP@:68@<F5Q=65S=&5D+@I(;W)D93HZ8V]M<')E
M<W-/=71P=70H*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+VQI8B]/
M8FIE8W16:65W+G!H<```````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3,P,3,`,3`T,3<S-C(W-38`,#(Q,#4W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@5'5R
M8F%?3V)J96-T5FEE=SHZ(&-L87-S('!R;W9I9&5S(&%N(&EN=&5R9F%C92!F
M;W(@=FES=6%L:7II;F<*("H@82!4=7)B85]/8FIE8W0N"B`J"B`J("1(;W)D
M93H@='5R8F$O;&EB+T]B:F5C=%9I97<N<&AP+'8@,2XR-RXT+C0@,C`P-2\Q
M,"\Q."`Q,CHU,#HP-2!J86X@17AP("0*("H*("H@0&%U=&AO<B`@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92`@5'5R
M8F$*("HO"F-L87-S(%1U<F)A7T]B:F5C=%9I97<@>PH*("`@("\J*@H@("`@
M("H@02!R969E<F5N8V4@=&\@=&AE(%1U<F)A7T]B:F5C="!T:&%T('1H:7,*
M("`@("`J(%1U<F)A7T]B:F5C=%9I97<@9&ES<&QA>7,N"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!V87(@5'5R8F%?3V)J96-T"B`@("`@*B\*
M("`@('9A<B`D7V]B:F5C=#L*"B`@("`O*BH*("`@("`J(%1H92!T96UP;&%T
M92!U<V5D('1O(&1I<W!L87D@=&AE(&]B:F5C="X*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M=&5M<&QA=&4["@H@("`@+RHJ"B`@("`@*B!$;R!W92!H879E('1H92!C<F5A
M=&EO;B!T:6UE<W1A;7`@;V8@=&AE(&]B:F5C=#\*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)%]C<F5A=&5D(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!$;R!W92!H879E('1H92!M;V1I9FEE9"!T:6UE<W1A;7`@
M;V8@=&AE(&]B:F5C=#\*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]M;V1I9FEE9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T<R!A(&YE=R!4=7)B85]/8FIE8W16:65W(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@5'5R8F%?3V)J96-T("1O8FIE8W0@(%1H92!O8FIE
M8W0@=&\@9&ES<&QA>2X*("`@("`J($!P87)A;2!S=')I;F<@)'1E;7!L871E
M("`@("`@5VAI8V@@=&5M<&QA=&4@9FEL92!T;R!D:7-P;&%Y('1H:7,@;V)J
M96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('=I=&@N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%1U<F)A7T]B:F5C=%9I97<H)B1O8FIE
M8W0L("1T96UP;&%T92`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]O
M8FIE8W0@/2`F)&]B:F5C=#L*("`@("`@("`D=&AI<RT^7W1E;7!L871E(#T@
M)'1E;7!L871E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('5P('1H92!(
M;W)D95]&;W)M(&9O<B!T:&4@8W5R<F5N="!O8FIE8W0G<R!A='1R:6)U=&5S
M+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]&;W)M("8D9F]R;2`@5&AE
M(&9O<FT@=&\@<V5T('9A<FEA8FQE<R!O;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T=7!&;W)M*"8D9F]R;2D*("`@('L*("`@("`@("!G;&]B86P@)&%T
M=')I8G5T97,["@H@("`@("`@("\O(%)U;B!T:')O=6=H(&]N8V4@=&\@<V5E
M('=H870@9F]R;2!A8W1I;VYS+"!I9B!A;GDL('=E(&YE960*("`@("`@("`O
M+R!T;R!S970@=7`N"B`@("`@("`@)&%C=&EO;G,@/2!A<G)A>2@I.PH@("`@
M("`@("1M87`@/2`D=&AI<RT^7V]B:F5C="T^9')I=F5R+3YM87`["B`@("`@
M("`@)&9I96QD<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]O8FIE8W0M/F1R:79E
M<BT^9V5T0W)I=&5R:6$H*2D["B`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A
M<R`D9FEE;&0I('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1M87!;)&9I
M96QD72DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1M87!;)&9I96QD
M75LG9FEE;&1S)UT@87,@)&%C=&EO;E]F:65L9"D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&%C=&EO;G-;)&%C=&EO;E]F:65L9%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A8W1I;VYS6R1A8W1I;VY?9FEE
M;&1=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)&%C=&EO;G-;)&%C=&EO;E]F:65L9%U;)V9I96QD<R==
M(#T@)&UA<%LD9FEE;&1=6R=F:65L9',G73L*("`@("`@("`@("`@("`@("`@
M("`D86-T:6]N<ULD86-T:6]N7V9I96QD75LG9F]R;6%T)UT@/2`D;6%P6R1F
M:65L9%U;)V9O<FUA="==.PH@("`@("`@("`@("`@("`@("`@("1A8W1I;VYS
M6R1A8W1I;VY?9FEE;&1=6R=T87)G970G72`]("1F:65L9#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@
M3F]W(')U;B!T:')O=6=H(&%N9"!A9&0@=&AE(&9O<FT@=F%R:6%B;&5S+@H@
M("`@("`@("1T86)S(#T@)'1H:7,M/E]O8FIE8W0M/F1R:79E<BT^=&%B<SL*
M("`@("`@("!I9B`H(6-O=6YT*"1T86)S*2D@>PH@("`@("`@("`@("`D=&%B
M<R`](&%R<F%Y*"<G(#T^("1F:65L9',I.PH@("`@("`@('T*("`@("`@("!F
M;W)E86-H("@D=&%B<R!A<R`D=&%B(#T^("1T86)?9FEE;&1S*2!["B`@("`@
M("`@("`@(&EF("@A96UP='DH)'1A8BDI('L*("`@("`@("`@("`@("`@("1F
M;W)M+3YS971396-T:6]N*"1T86(L("1T86(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1T86)?9FEE;&1S(&%S("1F:65L9"D@>PH@
M("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D9FEE;&0L("1F:65L9',I
M('Q\"B`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1A='1R:6)U=&5S6R1F
M:65L9%TI*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&%T=')I8G5T92`]("1A
M='1R:6)U=&5S6R1F:65L9%T["B`@("`@("`@("`@("`@("`D<&%R86US(#T@
M:7-S970H)&%T=')I8G5T95LG<&%R86US)UTI(#\@)&%T=')I8G5T95LG<&%R
M86US)UT@.B!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&1E<V,@/2!I<W-E
M="@D871T<FEB=71E6R=D97-C)UTI(#\@)&%T=')I8G5T95LG9&5S8R==(#H@
M;G5L;#L*"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&UA<%LD9FEE
M;&1=*2D@>PH@("`@("`@("`@("`@("`@("`@("1V(#T@)B1F;W)M+3YA9&16
M87)I86)L92@D871T<FEB=71E6R=L86)E;"==+"`G;V)J96-T6R<@+B`D9FEE
M;&0@+B`G72<L("1A='1R:6)U=&5;)W1Y<&4G72P@9F%L<V4L(&9A;'-E+"`D
M9&5S8RP@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@)'8M/F1I<V%B
M;&4H*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)')E861O;FQY(#T@:7-S970H)&%T=')I8G5T95LG<F5A9&]N;'DG
M72D@/R`D871T<FEB=71E6R=R96%D;VYL>2==(#H@;G5L;#L*"B`@("`@("`@
M("`@("`@("`@("`@+RH@5V4@;&EN:R!E;6%I;',L('-O('=E(&YE960@=&\@
M<W=I=&-H('1O('1H90H@("`@("`@("`@("`@("`@("`@("`J("=H=&UL)R!R
M96YD97)E<B!S:6YC92!T:&4@)V5M86EL)R!R96YD97)E<B!W:6QL"B`@("`@
M("`@("`@("`@("`@("`@("H@;G5K92!O=7(@9F]R;6%T=&EN9RX@($AO=V5V
M97(L(&]N;'D@9&\@=&AI<R!O;@H@("`@("`@("`@("`@("`@("`@("`J('1H
M92!D:7-P;&%Y+G!H<"!P86=E+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF
M("@H)&%T=')I8G5T95LG='EP92==(#T]("=E;6%I;"<I("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@("AB87-E;F%M92@D7U-%4E9%4ELG4$A07U-%3$8G
M72D@/3T@)V1I<W!L87DN<&AP)RDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y*&9A;'-E+"!F86QS92P@=')U92P@)&9O<FTM
M/E]V87)S+3YG970H)VYA;64G*2D["B`@("`@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("`@("`D=B`]("8D9F]R;2T^861D5F%R:6%B;&4H
M)&%T=')I8G5T95LG;&%B96PG72P@)V]B:F5C=%LG("X@)&9I96QD("X@)UTG
M+"`D871T<FEB=71E6R=T>7!E)UTL("1A='1R:6)U=&5;)W)E<75I<F5D)UTL
M("1R96%D;VYL>2P@)&1E<V,L("1P87)A;7,I.PH*("`@("`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1A8W1I;VYS6R1F:65L9%TI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]!8W1I
M;VXN<&AP)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&%C=&EO;F9I96QD
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1A8W1I;VYS6R1F:65L9%U;)V9I96QD<R==(&%S("1F*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D86-T:6]N9FEE;&1S6UT@/2`G;V)J96-T
M6R<@+B`D9B`N("==)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`D82`]("9(;W)D95]&;W)M7T%C=&EO;CHZ
M9F%C=&]R>2@G=7!D871E9FEE;&0G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9F]R
M;6%T)R`]/B`D86-T:6]N<ULD9FEE;&1=6R=F;W)M870G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1A<F=E="<@/3X@)V]B:F5C=%LG("X@)&%C=&EO;G-;)&9I
M96QD75LG=&%R9V5T)UT@+B`G72<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:65L
M9',G(#T^("1A8W1I;VYF:65L9',I*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'8M/G-E=$%C=&EO;B@D82D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1H:7,M/E]C<F5A=&5D*2!["B`@("`@("`@("`@("1V(#T@
M)B1F;W)M+3YA9&1687)I86)L92A?*")#<F5A=&5D(BDL("=O8FIE8W1;7U]C
M<F5A=&5D72<L("=T97AT)RP@9F%L<V4L(&9A;'-E*3L*("`@("`@("`@("`@
M)'8M/F1I<V%B;&4H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^
M7VUO9&EF:65D*2!["B`@("`@("`@("`@("1V(#T@)B1F;W)M+3YA9&1687)I
M86)L92A?*"),87-T($UO9&EF:65D(BDL("=O8FIE8W1;7U]M;V1I9FEE9%TG
M+"`G=&5X="<L(&9A;'-E+"!F86QS92D["B`@("`@("`@("`@("1V+3YD:7-A
M8FQE*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R
M<R!T:&4@;V)J96-T(&EN=&\@86X@2%1-3"!V:65W+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("!G;&]B86P@)&%T=')I
M8G5T97,["@H@("`@("`@("1F:65L9',@/2`D=&AI<RT^7V]B:F5C="T^9')I
M=F5R+3YG971#<FET97)I82@I.PH@("`@("`@(')E<75I<F4@)'1H:7,M/E]T
M96UP;&%T93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="`D871T<FEB=71E
M('1O("1V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R
M:6)U=&4@(%1H92!A='1R:6)U=&4@=&\@<V5T+@H@("`@("H@0'!A<F%M(&UI
M>&5D("`D=F%L=64@("`@("!4:&4@=F%L=64@9F]R("1A='1R:6)U=&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E="@D871T<FEB=71E+"`D=F%L=64I"B`@
M("!["B`@("`@("`@)&%T=')I8G5T92`]("=?)R`N("1A='1R:6)U=&4["B`@
M("`@("`@)'1H:7,M/B1A='1R:6)U=&4@/2`D=F%L=64["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O;&EB+T%B<W1R
M86-T3V)J96-T+G!H<```````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,C8S,@`Q,#0Q-S,V,C<U-@`P,C$W,38`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!4=7)B85]!
M8G-T<F%C=$]B:F5C=#HZ(&-L87-S('!R;W9I9&5S(&%N(&EN=&5R9F%C92!F
M;W(@5'5R8F$@;V)J96-T<R`M"B`J('!E;W!L92P@9W)O=7!S+"!R97-T875R
M86YT<RP@971C+@H@*@H@*B`D2&]R9&4Z('1U<F)A+VQI8B]!8G-T<F%C=$]B
M:F5C="YP:'`L=B`Q+C,S+C(N,R`R,#`U+S`V+S(S(#`P.C0W.C$V('-E;'-K
M>2!%>'`@)`H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&-S:"YR
M:70N961U/@H@*B!`<VEN8V4@("!4=7)B82`P+C`N,0H@*B!`<&%C:V%G92!4
M=7)B80H@*B\*8VQA<W,@5'5R8F%?06)S=')A8W1/8FIE8W0@>PH*("`@("\J
M*@H@("`@("H@56YD97)L>6EN9R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A
M<B!4=7)B85]$<FEV97(*("`@("`J+PH@("`@=F%R("1D<FEV97(["@H@("`@
M+RHJ"B`@("`@*B!(87-H(&]F(&%T=')I8G5T97,@9F]R('1H:7,@8V]N=&%C
M="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M871T<FEB=71E<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@
M5'5R8F%?06)S=')A8W1/8FIE8W0@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!4=7)B85]$<FEV97(@)&1R:79E<B`@5&AE('-O=7)C92!T:&%T('1H
M:7,@;V)J96-T(&-A;64@9G)O;2X*("`@("`J($!P87)A;2!A<G)A>2`D871T
M<FEB=71E<R`@("`@2&%S:"!O9B!A='1R:6)U=&5S(&9O<B!T:&ES(&]B:F5C
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@5'5R8F%?06)S=')A8W1/8FIE8W0H
M)B1D<FEV97(L("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D=&AI<RT^9')I=F5R(#T@)B1D<FEV97(["B`@("`@("`@)'1H:7,M/F%T
M=')I8G5T97,@/2`D871T<FEB=71E<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!K97DM=F%L=64@:&%S:"!C;VYT86EN:6YG(&%L;"!P<F]P
M97)T:65S(&]F('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%L;"!P<F]P97)T:65S(&]F('1H:7,@;V)J96-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&5S*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/F%T=')I8G5T97,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!N86UE(&]F('1H92!A9&1R97-S(&)O;VL@=&AA="!T
M:&ES(&]B:F5C="!I<R!F<F]M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713
M;W5R8V4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9')I=F5R+3YN
M86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=F%L=64@
M;V8@=&AE('-P96-I9FEE9"!A='1R:6)U=&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D871T<FEB=71E("!4:&4@871T<FEB=71E('1O(')E=')I
M979E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=F%L=64@
M;V8@)&%T=')I8G5T92P@;W(@=&AE(&5M<'1Y('-T<FEN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5F%L=64H)&%T=')I8G5T92D*("`@('L*("`@("`@
M("`O*B!#86-H92!H;V]K<R!T;R!A=F]I9"!F:6QE7V5X:7-T<R@I(&-A;&QS
M+B`J+PH@("`@("`@('-T871I8R`D:&]O:W,["@H@("`@("`@(&EF("@A:7-S
M970H)&AO;VMS*2D@>PH@("`@("`@("`@("`D:&]O:W,@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H2$]21$5?0D%312`N("<O8V]N
M9FEG+VAO;VMS+G!H<"<I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@2$]21$5?0D%312`N("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D:&]O:W-;)&%T
M=')I8G5T95TI*2!["B`@("`@("`@("`@("1F=6YC=&EO;B`]("=?='5R8F%?
M:&]O:U]D96-O9&5?)R`N("1A='1R:6)U=&4["B`@("`@("`@("`@(&EF("AF
M=6YC=&EO;E]E>&ES=',H)&9U;F-T:6]N*2D@>PH@("`@("`@("`@("`@("`@
M)&AO;VMS6R1A='1R:6)U=&5=(#T@)&9U;F-T:6]N.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&AO;VMS6R1A='1R:6)U=&5=(#T@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^871T<FEB=71E<ULD871T<FEB=71E72D@)B8@(65M<'1Y
M*"1H;V]K<ULD871T<FEB=71E72DI('L*("`@("`@("`@("`@<F5T=7)N(&-A
M;&Q?=7-E<E]F=6YC*"1H;V]K<ULD871T<FEB=71E72P@)'1H:7,M/F%T=')I
M8G5T97-;)&%T=')I8G5T95TI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YD<FEV97(M/FUA<%LD871T<FEB=71E72D@)B8*("`@("`@
M("`@("`@:7-?87)R87DH)'1H:7,M/F1R:79E<BT^;6%P6R1A='1R:6)U=&5=
M*2D@>PH@("`@("`@("`@("`D87)G<R`](&%R<F%Y*"1T:&ES+3YD<FEV97(M
M/FUA<%LD871T<FEB=71E75LG9F]R;6%T)UTI.PH@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^9')I=F5R+3YM87!;)&%T=')I8G5T95U;)V9I96QD<R==
M(&%S("1F:65L9"D@>PH@("`@("`@("`@("`@("`@)&%R9W-;72`]("1T:&ES
M+3YG971686QU92@D9FEE;&0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B!C86QL7W5S97)?9G5N8U]A<G)A>2@G<W!R:6YT9B<L("1A<F=S
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@*&ES<V5T
M*"1T:&ES+3YA='1R:6)U=&5S6R1A='1R:6)U=&5=*2`_("1T:&ES+3YA='1R
M:6)U=&5S6R1A='1R:6)U=&5=(#H@;G5L;"D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@=F%L=64@;V8@=&AE('-P96-I9FEE
M9"!A='1R:6)U=&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D871T
M<FEB=71E("!4:&4@871T<FEB=71E('1O('-E="X*("`@("`J($!P87)A;2!S
M=')I;F<@)'9A;'5E("`@("`@5&AE('9A;'5E(&]F("1A='1R:6)U=&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=%9A;'5E*"1A='1R:6)U=&4L("1V86QU
M92D*("`@('L*("`@("`@("!I9B`H9FEL95]E>&ES=',H2$]21$5?0D%312`N
M("<O8V]N9FEG+VAO;VMS+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@
M("`@("`@)&9U;F-T:6]N(#T@)U]T=7)B85]H;V]K7V5N8V]D95\G("X@)&%T
M=')I8G5T93L*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@D9G5N
M8W1I;VXI*2!["B`@("`@("`@("`@("`@("`D=F%L=64@/2!C86QL7W5S97)?
M9G5N8R@D9G5N8W1I;VXL("1V86QU92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YA='1R:6)U=&5S6R1A='1R:6)U
M=&5=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YD<FEV97(M/FUA<%LD871T<FEB=71E72D@)B8*("`@("`@
M("`@("`@:7-?87)R87DH)'1H:7,M/F1R:79E<BT^;6%P6R1A='1R:6)U=&5=
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^871T<FEB=71E<ULD871T<FEB=71E72`]("1V86QU93L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN97,@=VAE=&AE<B!O<B!N;W0@=&AE(&]B:F5C="!H87,@82!V86QU
M92!F;W(@=&AE('-P96-I9FEE9`H@("`@("H@871T<FEB=71E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&%T=')I8G5T92`@5&AE(&%T=')I8G5T
M92!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H
M971H97(@;W(@;F]T('1H97)E(&ES(&$@=F%L=64@9F]R("1A='1R:6)U=&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<U9A;'5E*"1A='1R:6)U=&4I"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD<FEV97(M/FUA<%LD871T
M<FEB=71E72D@)B8*("`@("`@("`@("`@:7-?87)R87DH)'1H:7,M/F1R:79E
M<BT^;6%P6R1A='1R:6)U=&5=*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^9')I=F5R+3YM87!;)&%T=')I8G5T95U;)V9I96QD<R==(&%S("1F
M:65L9"D@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YH87-686QU92@D
M9FEE;&0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`A:7-?;G5L;"@D=&AI<RT^9V5T5F%L=64H)&%T=')I8G5T92DI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!I9B!T
M:&ES(&]B:F5C="!I<R!A(&=R;W5P(&]F(&UU;'1I<&QE(&-O;G1A8W1S+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&]B
M:F5C="!I<R!A(&=R;W5P(&]F(&UU;'1I<&QE(&-O;G1A8W1S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<T=R;W5P*"D*("`@('L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@:68@
M=&AI<R!O8FIE8W0@:7,@961I=&%B;&4@8GD@=&AE(&-U<G)E;G0@=7-E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T
M('1H92!C=7)R96YT('5S97(@8V%N(&5D:70@=&AI<R!O8FIE8W0*("`@("`J
M+PH@("`@9G5N8W1I;VX@:7-%9&ET86)L92@I"B`@("!["B`@("`@("`@:68@
M*"$D=&AI<RT^9')I=F5R+3YR96%D;VYL>2D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)'1H:7,M/F1R
M:79E<BT^861M:6XI("8F"B`@("`@("`@("`@("`@("`@(&EN7V%R<F%Y*$%U
M=&@Z.F=E=$%U=&@H*2P@)'1H:7,M/F1R:79E<BT^861M:6XI*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^
M:&%S5F%L=64H)U]?;W=N97(G*2`F)@H@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9V5T5F%L=64H)U]?;W=N97(G*2`]/2!!=71H.CIG971!=71H*"DI('L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E<R!T:&4@
M8W5R<F5N="!S=&%T92!O9B!T:&4@;V)J96-T('1O('1H92!S=&]R86=E(&)A
M8VME;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W)E*"D*("`@('L*("`@
M("`@("`D;V)J96-T7VED(#T@)'1H:7,M/F1R:79E<BT^<V%V92@D=&AI<RD[
M"B`@("`@("`@:68@*&ES7V$H)&]B:F5C=%]I9"P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&]B:F5C=%]I9#L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^<V5T5F%L=64H)U]?:V5Y)RP@)&]B:F5C
M=%]I9"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O;&EB+W!R969S+G!H<```````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8P,0`Q,#0Q-S,V,C<U-@`P,C`Q
M,S<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(;W)D93H@='5R8F$O;&EB+W!R969S+G!H<"QV(#$N
M,BXQ,"XU(#(P,#8O,#$O,#$@,C$Z,CDZ,38@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`Q+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO
M<F<O;&EC96YS97,O87-L+G!H<"X*("HO"@IF=6YC=&EO;B!H86YD;&5?8V]L
M=6UN<V5L96-T*"1U<&1A=&5D*0I["B`@("`D8V]L=6UN<R`](%5T:6PZ.F=E
M=$9O<FU$871A*"=C;VQU;6YS)RD["B`@("!I9B`H(65M<'1Y*"1C;VQU;6YS
M*2D@>PH@("`@("`@("1'3$]"04Q36R=P<F5F<R==+3YS971686QU92@G8V]L
M=6UN<R<L("1C;VQU;6YS*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("!R971U<FX@9F%L<V4["GT*"F9U;F-T:6]N(&AA;F1L95]A9&1R97-S
M8F]O:W-E;&5C="@D=7!D871E9"D*>PH@("`@)&%D9')E<W-B;V]K<R`](%5T
M:6PZ.F=E=$9O<FU$871A*"=A9&1R97-S8F]O:W,G*3L*("`@(&EF("@A96UP
M='DH)&%D9')E<W-B;V]K<RDI('L*("`@("`@("`D1TQ/0D%,4ULG<')E9G,G
M72T^<V5T5F%L=64H)V%D9')E<W-B;V]K<R<L("1A9&1R97-S8F]O:W,I.PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(')E='5R;B!F86QS93L*
M?0H*9G5N8W1I;VX@:&%N9&QE7VEM<W!?;W!T*"1U<&1A=&5D*0I["B`@("!G
M;&]B86P@)&-F9U-O=7)C97,["B`@("`D;F%M92`](%5T:6PZ.F=E=$9O<FU$
M871A*"=I;7-P7V)O;VMS7V1E;&5T92<I.PH@("`@:68@*"1N86UE("$]("=N
M;VYE)RD@>PH@("`@("`@(')E<75I<F5?;VYC92`G3F5T+TE-4U`O571I;',N
M<&AP)SL*("`@("`@("`D<F5S=6QT(#T@3F5T7TE-4U!?571I;',Z.F1E;&5T
M94)O;VLH)&-F9U-O=7)C97-;)&YA;65=*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("!]"B`@("`D;F%M92`](%5T:6PZ.F=E=$9O
M<FU$871A*"=I;7-P7VYA;64G*3L*("`@(&EF("@D;F%M92`A/2`G)RD@>PH@
M("`@("`@("\O($=E="!U<V5R)W,@9&5F875L="!)35-0("1C9F=3;W5R8V4@
M96YT<GD*("`@("`@("!F;W)E86-H("@D8V9G4V]U<F-E<R!A<R`D:V5Y(#T^
M("1P87)A;7,I('L*("`@("`@("`@("`@:68@*"1P87)A;7-;)W1Y<&4G72`]
M/2`G:6US<"<@)B8@)'!A<F%M<ULG<&%R86US)UU;)VES7W)O;W0G72D@>PH@
M("`@("`@("`@("`@("`@)&1E9F%U;'0@/2`D:V5Y.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=.970O24U34"]5=&EL<RYP:'`G.PH@("`@("`@("1R97-U
M;'0@/2!.971?24U34%]5=&EL<SHZ8W)E871E0F]O:R@D8V9G4V]U<F-E<ULD
M9&5F875L=%TL("1N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"B`@("!]"B`@("!R971U<FX@=')U93L*?0H*+RH@07-S:6=N('9A
M<FEA8FQE<R!F;W(@<V5L96-T(&QI<W1S+B`J+PII9B`H(21P<F5F<RT^:7-,
M;V-K960H)V1E9F%U;'1?9&ER)RDI('L*("`@("1D969A=6QT7V1I<E]O<'1I
M;VYS(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1C9F=3;W5R8V5S(&%S("1K
M97D@/3X@)&EN9F\I('L*("`@("`@("`D9&5F875L=%]D:7)?;W!T:6]N<ULD
M:V5Y72`]("1I;F9O6R=T:71L92==.PH@("`@?0I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1U<F)A+VQI8B]/8FIE8W0N<&AP````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C4U,#0`,3`T,3<S-C(W-38`,#(P,C,T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@5'5R8F%?3V)J96-T.CH@8VQA<W,@<')O=FED97,@82!B
M87-E(&EM<&QE;65N=&%T:6]N(&9O<B!4=7)B80H@*B!O8FIE8W1S("T@<&5O
M<&QE+"!G<F]U<',L(')E<W1A=7)A;G1S+"!E=&,N"B`J"B`J("1(;W)D93H@
M='5R8F$O;&EB+T]B:F5C="YP:'`L=B`Q+C$W+C$P+C(@,C`P-2\Q,"\Q."`Q
M,CHU,#HP-2!J86X@17AP("0*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@
M/&IO;D!C<V@N<FET+F5D=3X*("H@0'!A8VMA9V4@5'5R8F$*("HO"F-L87-S
M(%1U<F)A7T]B:F5C="!["@H@("`@+RHJ"B`@("`@*B!5;F1E<FQY:6YG(&1R
M:79E<BX*("`@("`J"B`@("`@*B!`=F%R(%1U<F)A7T1R:79E<@H@("`@("HO
M"B`@("!V87(@)&1R:79E<CL*"B`@("`O*BH*("`@("`J($AA<V@@;V8@871T
M<FEB=71E<R!F;W(@=&AI<R!C;VYT86-T+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1A='1R:6)U=&5S.PH*("`@("\J*@H@
M("`@("H@4F5F97)E;F-E('1O('1H:7,@;V)J96-T)W,@5D93(&EN<W1A;F-E
M+@H@("`@("H*("`@("`J($!V87(@5D93"B`@("`@*B\*("`@('9A<B`D7W9F
M<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@5'5R8F%?3V)J
M96-T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@5'5R8F%?1')I=F5R
M("1D<FEV97(@(%1H92!S;W5R8V4@=&AA="!T:&ES(&]B:F5C="!C86UE(&9R
M;VTN"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@("`@($AA<V@@
M;V8@871T<FEB=71E<R!F;W(@=&AI<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%1U<F)A7T]B:F5C="@F)&1R:79E<BP@)&%T=')I8G5T97,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3YD<FEV97(@/2`F)&1R:79E
M<CL*("`@("`@("`D=&AI<RT^871T<FEB=71E<R`]("1A='1R:6)U=&5S.PH@
M("`@("`@("1T:&ES+3YA='1R:6)U=&5S6R=?7W1Y<&4G72`]("=/8FIE8W0G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&ME>2UV86QU92!H
M87-H(&-O;G1A:6YI;F<@86QL('!R;W!E<G1I97,@;V8@=&AI<R!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06QL('!R;W!E<G1I97,@
M;V8@=&AI<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I
M8G5T97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^871T<FEB=71E
M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YA;64@;V8@
M=&AE(&%D9')E<W,@8F]O:R!T:&%T('1H:7,@;V)J96-T(&ES(&9R;VTN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%-O=7)C92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YD<FEV97(M/FYA;64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!V86QU92!O9B!T:&4@<W!E8VEF:65D(&%T=')I
M8G5T92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U=&4@
M(%1H92!A='1R:6)U=&4@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!V86QU92!O9B`D871T<FEB=71E+"!O<B!T:&4@
M96UP='D@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971686QU92@D
M871T<FEB=71E*0H@("`@>PH@("`@("`@("\J($-A8VAE(&AO;VMS('1O(&%V
M;VED(&UU;'1I<&QE(&9I;&5?97AI<W1S*"D@8V%L;',N("HO"B`@("`@("`@
M<W1A=&EC("1H;V]K<SL*("`@("`@("!I9B`H(6ES<V5T*"1H;V]K<RDI('L*
M("`@("`@("`@("`@)&AO;VMS(#T@87)R87DH*3L*("`@("`@("`@("`@:68@
M*&9I;&5?97AI<W1S*$A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G
M*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92!(3U)$15]"05-%("X@)R]C
M;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H(6ES<V5T*"1H;V]K<ULD871T<FEB=71E72DI('L*("`@("`@
M("`@("`@)&9U;F-T:6]N(#T@)U]T=7)B85]H;V]K7V1E8V]D95\G("X@)&%T
M=')I8G5T93L*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@D9G5N
M8W1I;VXI*2!["B`@("`@("`@("`@("`@("`D:&]O:W-;)&%T=')I8G5T95T@
M/2`D9G5N8W1I;VX["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D:&]O:W-;)&%T=')I8G5T95T@/2!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YA='1R:6)U
M=&5S6R1A='1R:6)U=&5=*2`F)B`A96UP='DH)&AO;VMS6R1A='1R:6)U=&5=
M*2D@>PH@("`@("`@("`@("!R971U<FX@8V%L;%]U<V5R7V9U;F,H)&AO;VMS
M6R1A='1R:6)U=&5=+"`D=&AI<RT^871T<FEB=71E<ULD871T<FEB=71E72P@
M)'1H:7,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD
M<FEV97(M/FUA<%LD871T<FEB=71E72D@)B8*("`@("`@("`@("`@:7-?87)R
M87DH)'1H:7,M/F1R:79E<BT^;6%P6R1A='1R:6)U=&5=*2D@>PH@("`@("`@
M("`@("`D87)G<R`](&%R<F%Y*"1T:&ES+3YD<FEV97(M/FUA<%LD871T<FEB
M=71E75LG9F]R;6%T)UTI.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^
M9')I=F5R+3YM87!;)&%T=')I8G5T95U;)V9I96QD<R==(&%S("1F:65L9"D@
M>PH@("`@("`@("`@("`@("`@)&%R9W-;72`]("1T:&ES+3YG971686QU92@D
M9FEE;&0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!C86QL
M7W5S97)?9G5N8U]A<G)A>2@G<W!R:6YT9B<L("1A<F=S*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/F%T=')I
M8G5T97-;)&%T=')I8G5T95TI(#\@)'1H:7,M/F%T=')I8G5T97-;)&%T=')I
M8G5T95T@.B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=&AE('9A;'5E(&]F('1H92!S<&5C:69I960@871T<FEB=71E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%T=')I8G5T92`@5&AE(&%T
M=')I8G5T92!T;R!S970N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@
M("`@(%1H92!V86QU92!O9B`D871T<FEB=71E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971686QU92@D871T<FEB=71E+"`D=F%L=64I"B`@("!["B`@("`@
M("`@+RH@0V%C:&4@:&]O:W,@=&\@879O:60@;75L=&EP;&4@9FEL95]E>&ES
M=',H*2!C86QL<RX@*B\*("`@("`@("!S=&%T:6,@)&AO;VMS.PH@("`@("`@
M(&EF("@A:7-S970H)&AO;VMS*2D@>PH@("`@("`@("`@("`D:&]O:W,@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H2$]21$5?0D%3
M12`N("<O8V]N9FEG+VAO;VMS+G!H<"<I*2!["B`@("`@("`@("`@("`@("!R
M97%U:7)E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)&AO;VMS
M6R1A='1R:6)U=&5=*2D@>PH@("`@("`@("`@("`D9G5N8W1I;VX@/2`G7W1U
M<F)A7VAO;VM?96YC;V1E7R<@+B`D871T<FEB=71E.PH@("`@("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"1F=6YC=&EO;BDI('L*("`@("`@("`@("`@
M("`@("1H;V]K<ULD871T<FEB=71E72`]("1F=6YC=&EO;CL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H;V]K<ULD871T<FEB=71E
M72`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF
M("@D:&]O:W-;)&%T=')I8G5T95TI('L*("`@("`@("`@("`@)'9A;'5E(#T@
M8V%L;%]U<V5R7V9U;F,H)&AO;VMS6R1A='1R:6)U=&5=+"`D=F%L=64L("1T
M:&ES+3YA='1R:6)U=&5S6R1A='1R:6)U=&5=+"`D=&AI<RD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F1R:79E<BT^;6%P6R1A='1R
M:6)U=&5=*2`F)@H@("`@("`@("`@("!I<U]A<G)A>2@D=&AI<RT^9')I=F5R
M+3YM87!;)&%T=')I8G5T95TI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YA='1R:6)U=&5S6R1A='1R
M:6)U=&5=(#T@)'9A;'5E.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!W:&5T:&5R(&]R(&YO="!T:&4@
M;V)J96-T(&AA<R!A('9A;'5E(&9O<B!T:&4@<W!E8VEF:65D"B`@("`@*B!A
M='1R:6)U=&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D871T<FEB
M=71E("!4:&4@871T<FEB=71E('1O(&-H96-K+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE<F4@:7,@82!V86QU
M92!F;W(@)&%T=')I8G5T92X*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S5F%L
M=64H)&%T=')I8G5T92D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F1R:79E<BT^;6%P6R1A='1R:6)U=&5=*2`F)@H@("`@("`@("`@("!I<U]A
M<G)A>2@D=&AI<RT^9')I=F5R+3YM87!;)&%T=')I8G5T95TI*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD<FEV97(M/FUA<%LD871T<FEB=71E
M75LG9FEE;&1S)UT@87,@)&9I96QD*2!["B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/FAA<U9A;'5E*"1F:65L9"DI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("%I<U]N=6QL*"1T:&ES+3YG971686QU92@D
M871T<FEB=71E*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T<G5E(&EF('1H:7,@;V)J96-T(&ES(&$@9W)O=7`@;V8@;75L
M=&EP;&4@8V]N=&%C=',N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('1H:7,@;V)J96-T(&ES(&$@9W)O=7`@;V8@;75L=&EP;&4@
M8V]N=&%C=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES1W)O=7`H*0H@("`@
M>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=')U92!I9B!T:&ES(&]B:F5C="!I<R!E9&ET86)L92!B>2!T
M:&4@8W5R<F5N="!U<V5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-U<G)E;G0@=7-E<B!C86X@961I="!T
M:&ES(&]B:F5C=`H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5D:71A8FQE*"D*
M("`@('L*("`@("`@(')E='5R;B`D=&AI<RT^9')I=F5R+3YH87-097)M:7-S
M:6]N*%!%4DU37T5$250I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!W:&5T:&5R(&]R(&YO="!T:&4@8W5R<F5N="!U<V5R(&AA<R!T:&4@<F5Q
M=65S=&5D('!E<FUI<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'!E<FT@(%1H92!P97)M:7-S:6]N('1O(&-H96-K+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B!4<G5E(&EF('5S97(@:&%S('1H92!P97)M
M:7-S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1P
M97)M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9')I=F5R+3YH87-0
M97)M:7-S:6]N*"1P97)M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-A=F5S
M(&$@9FEL92!I;G1O('1H92!61E,@8F%C:V5N9"!A<W-O8VEA=&5D('=I=&@@
M=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1I;F9O
M("!!(&AA<V@@=VET:"!T:&4@9FEL92!I;F9O<FUA=&EO;B!A<R!R971U<FYE
M9"!F<F]M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@2&]R9&5?1F]R
M;5]4>7!E7V9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$9I;&4H)&EN
M9F\I"B`@("!["B`@("`@("`@)'1H:7,M/E]V9G-);FET*"D["@H@("`@("`@
M("1D:7(@/2!455)"05]61E-?4$%42"`N("<O)R`N("1T:&ES+3YG971686QU
M92@G7U]U:60G*3L*("`@("`@("`D9FEL92`]("1I;F9O6R=N86UE)UT["B`@
M("`@("`@=VAI;&4@*"1T:&ES+3Y?=F9S+3YE>&ES=',H)&1I<BP@)&9I;&4I
M*2!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*"XJ*5Q;*%QD*RE<
M72A<+EM>+ETJ*3\D+R<L("1F:6QE+"`D;6%T8V@I*2!["B`@("`@("`@("`@
M("`@("`D9FEL92`]("1M871C:%LQ72`N("=;)R`N("LK)&UA=&-H6S)=("X@
M)UTG("X@)&UA=&-H6S-=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&1O="`]('-T<G)P;W,H)&9I;&4L("<N)RD["B`@("`@("`@
M("`@("`@("!I9B`H)&1O="`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("`@("`D9FEL92`N/2`G6S%=)SL*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2!S=6)S='(H)&9I;&4L(#`L
M("1D;W0I("X@)ULQ72<@+B!S=6)S='(H)&9I;&4L("1D;W0I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/E]V9G,M/G=R:71E*"1D:7(L("1F:6QE+"`D:6YF;ULG
M=&UP7VYA;64G72P@=')U92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE
M=&5S(&$@9FEL92!F<F]M('1H92!61E,@8F%C:V5N9"!A<W-O8VEA=&5D('=I
M=&@@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FEL92`@5&AE(&9I;&4@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L
M971E1FEL92@D9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7W9F<TEN:70H
M*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YD96QE=&5&:6QE*%15
M4D)!7U9&4U]0051(("X@)R\G("X@)'1H:7,M/F=E=%9A;'5E*"=?7W5I9"<I
M+"`D9FEL92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%L;"!F
M:6QE<R!F<F]M('1H92!61E,@8F%C:V5N9"!A<W-O8VEA=&5D('=I=&@@=&AI
M<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949I;&5S*"D*
M("`@('L*("`@("`@("`D=&AI<RT^7W9F<TEN:70H*3L*"B`@("`@("`@:68@
M*"1T:&ES+3Y?=F9S+3YE>&ES=',H5%520D%?5D937U!!5$@L("1T:&ES+3YG
M971686QU92@G7U]U:60G*2DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=F9S+3YD96QE=&5&;VQD97(H5%520D%?5D937U!!5$@L("1T:&ES+3YG
M971686QU92@G7U]U:60G*2P@=')U92D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL
M(&9I;&5S(&9R;VT@=&AE(%9&4R!B86-K96YD(&%S<V]C:6%T960@=VET:"!T
M:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI
M<W0@;V8@:&%S:&5S('=I=&@@9FEL92!I;F9O<FUA=&EO;G,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QI<W1&:6QE<R@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]V9G-);FET*"D["@H@("`@("`@(&EF("@D=&AI<RT^7W9F<RT^97AI<W1S
M*%154D)!7U9&4U]0051(+"`D=&AI<RT^9V5T5F%L=64H)U]?=6ED)RDI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^;&ES=$9O;&1E<BA4
M55)"05]61E-?4$%42"`N("<O)R`N("1T:&ES+3YG971686QU92@G7U]U:60G
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(&QI;FL@=&\@9&ES<&QA>2!A;F0@9&]W;FQO860@82!F:6QE(&9R;VT@=&AE
M(%9&4R!B86-K96YD"B`@("`@*B!A<W-O8VEA=&5D('=I=&@@=&AI<R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@5&AE(&9I
M;&4@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A4
M34P@8V]D92!O9B!T:&4@9V5N97)A=&5D(&QI;FLN"B`@("`@*B\*("`@(&9U
M;F-T:6]N('9F<T1I<W!L87E5<FPH)&9I;&4I"B`@("!["B`@("`@("`@9VQO
M8F%L("1R96=I<W1R>2P@)&UI;65?9')I=F5R<U]M87`L("1M:6UE7V1R:79E
M<G,["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]-86=I8RYP
M:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]087)T+G!H
M<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U9I97=E<BYP
M:'`G.PH@("`@("`@(')E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF
M:6<O;6EM95]D<FEV97)S+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E(%15
M4D)!7T)!4T4@+B`G+V-O;F9I9R]M:6UE7V1R:79E<G,N<&AP)SL*"B`@("`@
M("`@)&UI;65?<&%R="`]("9N97<@34E-15]087)T*$U)345?36%G:6,Z.F5X
M=%1O34E-12@D9FEL95LG='EP92==*2P@)R<I.PH@("`@("`@("1V:65W97(@
M/2`F34E-15]6:65W97(Z.F9A8W1O<GDH)&UI;65?<&%R="D["@H@("`@("`@
M("\O(%=E(&-A;B!A;'=A>7,@9&]W;FQO860@9FEL97,N"B`@("`@("`@)'5R
M;%]P87)A;7,@/2!A<G)A>2@G86-T:6]N240G(#T^("=D;W=N;&]A9%]F:6QE
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:6QE)R`]/B`D9FEL
M95LG;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M(#T^("1F:6QE6R=T>7!E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<V]U<F-E)R`]/B`D=&AI<RT^9')I=F5R+3YN86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VME>2<@/3X@)'1H:7,M/F=E=%9A;'5E*"=?
M7VME>2<I*3L*("`@("`@("`D9&P@/2!(;W)D93HZ;&EN:RA(;W)D93HZ9&]W
M;FQO8615<FPH)&9I;&5;)VYA;64G72P@)'5R;%]P87)A;7,I+"`D9FEL95LG
M;F%M92==*2`N($AO<F1E.CII;6<H)V1O=VYL;V%D+G!N9R<L(%\H(D1O=VYL
M;V%D(BDL(&%R<F%Y*"=A;&EG;B<@/3X@)VUI9&1L92<I+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)SL*"B`@("`@("`@+R\@
M3&5T)W,@<V5E(&EF('=E(&-A;B!V:65W('1H:7,@;VYE+"!T;V\N"B`@("`@
M("`@:68@*"1V:65W97(@)B8@(6ES7V$H)'9I97=E<BP@)TU)345?5FEE=V5R
M7V1E9F%U;'0G*2D@>PH@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=V:65W+G!H<"<I.PH@("`@("`@("`@("`D=7)L7W!A<F%M
M<ULG86-T:6]N240G72`]("=V:65W7V9I;&4G.PH@("`@("`@("`@("`D=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1U<FQ?<&%R86US*3L*("`@
M("`@("`@("`@)&QI;FL@/2!(;W)D93HZ;&EN:R@D=7)L+"`D9FEL95LG;F%M
M92==+"!N=6QL+"`G7V)L86YK)RD@+B`D9FEL95LG;F%M92==("X@)SPO83XG
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1L:6YK(#T@)&9I;&5;
M)VYA;64G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&EN:R`N("<@
M)R`N("1D;#L*("`@('T*"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&EN
M:R!T;R!D:7-P;&%Y+"!D;W=N;&]A9"P@86YD(&1E;&5T92!A(&9I;&4@9G)O
M;2!T:&4@5D93"B`@("`@*B!B86-K96YD(&%S<V]C:6%T960@=VET:"!T:&ES
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("!4
M:&4@9FEL92!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@2%1-3"!C;V1E(&]F('1H92!G96YE<F%T960@;&EN:RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@=F9S161I=%5R;"@D9FEL92D*("`@('L*("`@("`@("`D
M=7)L7W!A<F%M<R`](&%R<F%Y*"=A8W1I;VY)1"<@/3X@)V1E;&5T95]V9G,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^("1F:6QE
M6R=N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V]U<F-E
M)R`]/B`D=&AI<RT^9')I=F5R+3YN86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VME>2<@/3X@)'1H:7,M/F=E=%9A;'5E*"=?7VME>2<I*3L*
M("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G961I="YP:'`G*2P@)'5R;%]P87)A;7,I.PH@("`@("`@
M("1L:6YK(#T@)'1H:7,M/G9F<T1I<W!L87E5<FPH)&9I;&4I("X@)R`G("X@
M2&]R9&4Z.FQI;FLH)'5R;"D@+B!(;W)D93HZ:6UG*"=D96QE=&4N<&YG)RP@
M7R@B1&5L971E(BDL(&%R<F%Y*"=A;&EG;B<@/3X@)VUI9&1L92<I+"`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO
M83XG.PH@("`@("`@(')E='5R;B`D;&EN:SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%-A=F5S('1H92!C=7)R96YT('-T871E(&]F('1H92!O8FIE8W0@=&\@
M=&AE('-T;W)A9V4@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1O
M<F4H*0H@("`@>PH@("`@("`@("1O8FIE8W1?:60@/2`D=&AI<RT^9')I=F5R
M+3YS879E*"1T:&ES*3L*("`@("`@("!I9B`H:7-?82@D;V)J96-T7VED+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;V)J96-T7VED
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YS971686QU92@G
M7U]K97DG+"`D;V)J96-T7VED*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO
M861S('1H92!61E,@8V]N9FEG=7)A=&EO;B!A;F0@:6YI=&EA;&EZ97,@=&AE
M(%9&4R!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F9S26YI="@I
M"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W9F<RDI('L*("`@
M("`@("`@("`@)'9?<&%R86US(#T@2&]R9&4Z.F=E=%9&4T-O;F9I9R@G9&]C
M=6UE;G1S)RD["B`@("`@("`@("`@(&EF("AI<U]A*"1V7W!A<F%M<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1V
M7W!A<F%M<RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U9&4RYP:'`G.PH@("`@("`@("`@
M("`D=&AI<RT^7W9F<R`]("961E,Z.G-I;F=L971O;B@D=E]P87)A;7-;)W1Y
M<&4G72P@)'9?<&%R86US6R=P87)A;7,G72D["B`@("`@("`@?0H@("`@?0I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]T96UP
M;&%T97,O````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S4V`#`Q-S4T,@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1U<F)A+W1E;7!L871E<R]B<F]W<V4O````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-38`,#(Q,#0S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=&5M<&QA=&5S+V)R;W=S
M92]F;V]T97)!;'!H82YI;F,`````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,34W-``Q
M,#0Q-S,V,C<U-@`P,C0P,#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`@:68@*"1T:&ES+3YC;W5N="@I(#X@)'!R
M969S+3YG971686QU92@G<&5R<&%G92<I*3H@/SX*/&1I=B!C;&%S<STB8V]N
M=')O;"(@<W1Y;&4](G1E>'0M86QI9VXZ8V5N=&5R(CX*/#]P:'`*)'-H;W<@
M/2!5=&EL.CIG971&;W)M1&%T82@G<VAO=R<L("=A;&PG*3L*)&-U<G)E;G10
M86=E(#T@4W1R:6YG.CIU<'!E<B@D<&%G92D["FEF("@D8W5R<F5N=%!A9V4@
M/3T@)RHG*2!["B`@("!E8VAO("<\<W1R;VYG/B@G("X@7R@B06QL(BD@+B`G
M*3PO<W1R;VYG/B9N8G-P.R<["GT@96QS92!["B`@("!E8VAO($AO<F1E.CIL
M:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"A5=&EL.CIA9&1087)A;65T97(H
M)'9I97=U<FPL(&%R<F%Y*"=P86=E)R`]/B`G*B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=S:&]W)R`]/B`D<VAO=RDI*2D@+B!?*")!
M;&PB*2`N("<\+V$^)FYB<W`[)SL*?0IF;W(@*"1I(#T@-C4[("1I(#P@.3$[
M("1I*RLI('L*("`@("1A(#T@8VAR*"1I*3L*("`@(&EF("@D8W5R<F5N=%!A
M9V4@/3T@)&$I('L*("`@("`@("!E8VAO("<\<W1R;VYG/B@G("X@)&$@+B`G
M*3PO<W1R;VYG/B9N8G-P.R<["B`@("!](&5L<V4@>PH@("`@("`@("1L:6YK
M(#T@571I;#HZ861D4&%R86UE=&5R*"1V:65W=7)L+"!A<G)A>2@G<&%G92<@
M/3X@)&$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S:&]W)R`]/B`D<VAO=RDI.PH@("`@("`@(&5C:&\@
M2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1L:6YK*2D@+B`D
M82`N("<\+V$^)FYB<W`[)SL*("`@('T*?0H_/@H\+V1I=CX*/#]P:'`@96YD
M:68[(#\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=&5M<&QA=&5S
M+V)R;W=S92]C;VQU;6Y?9F]O=&5R<RYI;F,`````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3(W-P`Q,#0Q-S,V,C<U-@`P,C0V,#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/"]T8F]D>3X*/"]T86)L93X*/&EN<'5T
M('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2(B("\^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](G-H;W<B('9A;'5E/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ9V5T1F]R;41A=&$H)W-H;W<G
M+"`G86QL)RDI(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)S
M;W5R8V4B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'-O
M=7)C92D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G-O<G1B
M>2(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<V]R=&)Y
M*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB<V]R=&1I<B(@
M=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<V]R=&1I<BD@
M/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FME>2(@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG971&;W)M1&%T
M82@G:V5Y)RDI(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)T
M87)G971!9&1R97-S8F]O:R(@=F%L=64](B(@+SX*/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB=&%R9V5T3&ES="(@=F%L=64](B(@+SX*/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB=&%R9V5T3F5W(B!V86QU93TB(B`O/@H\+V9O
M<FT^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=&5M
M<&QA=&5S+V)R;W=S92]R;W<N:6YC````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-38R-P`Q,#0Q-S,V,C<U-@`P,C(S-30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"FEF("@D;V(M/FAA
M<U9A;'5E*"=N86UE)RDI('L*("`@("1L:6YK7W1E>'0@/2!H=&UL<W!E8VEA
M;&-H87)S*%1U<F)A.CIF;W)M871.86UE*"1O8BDI.PI](&5L<V4@>PH@("`@
M)&QI;FM?=&5X="`](%\H(EMN;R!V86QU95TB*3L*?0H*)&5D:71?=7)L(#T@
M)'9C87)D7W5R;"`]("<F;F)S<#LG.PII9B`H)&]B+3YH87-686QU92@G7U]K
M97DG*2D@>PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D;V(M/FES
M1W)O=7`H*2`_("=B<F]W<V4N<&AP)R`Z("=D:7-P;&%Y+G!H<"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S;W5R8V4G(#T^("1O
M8BT^9V5T4V]U<F-E*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=K97DG(#T^("1O8BT^9V5T5F%L=64H)U]?:V5Y)RDI*3L*"B`@
M("`D=F-A<F1?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=V8V%R9"YP:'`G
M+"!A<G)A>2@G<V]U<F-E)R`]/B`D;V(M/F=E=%-O=7)C92@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VME>2<@/3X@)&]B+3YG971686QU92@G7U]K97DG*2DI.PH@("`@)'9C
M87)D7W5R;"`]($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D
M=F-A<F1?=7)L*2P@7R@B1&]W;FQO860@=D-A<F0B*2D@+B!(;W)D93HZ:6UG
M*"=M:6UE+W9C87)D+G!N9R<L(%\H(D1O=VYL;V%D('9#87)D(BDL("<G+"`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@
M)SPO83XG.PH*("`@("1C96QL(#T@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"1U<FPI+"!S<')I;G1F*%\H(E9I97<@7"(E<UPB(BDL("1O
M8BT^9V5T5F%L=64H)VYA;64G*2DI("X*("`@("`@("`D;&EN:U]T97AT("X@
M)SPO83XG.PH@("`@:68@*"1O8BT^:&%S4&5R;6ES<VEO;BA015)-4U]%1$E4
M*2D@>PH@("`@("`@("1E9&ET7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@G
M961I="YP:'`G+"!A<G)A>2@G<V]U<F-E)R`]/B`D;V(M/F=E=%-O=7)C92@I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G:V5Y)R`]/B`D;V(M/F=E=%9A;'5E*"=?7VME>2<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=7)L)R`]/B!(;W)D93HZ<V5L9E5R;"AT<G5E*2DI
M.PH@("`@("`@("1E9&ET7W5R;"`]($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@D961I=%]U<FPI+"!S<')I;G1F*%\H(D5D:70@7"(E<UPB
M(BDL("1O8BT^9V5T5F%L=64H)VYA;64G*2DI("X@2&]R9&4Z.FEM9R@G961I
M="YP;F<G+"!?*")%9&ET(BDL("<G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PH@("`@?0I](&5L<V4@
M>PH@("`@)&-E;&P@/2`D;&EN:U]T97AT.PI]"@H_/@H\='(^"CP_<&AP(&EF
M("@D=&AI<RT^<VAO=TUA<FLI.B`_/@H@(#QT9#X\:6YP=70@='EP93TB8VAE
M8VMB;W@B(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB;V)J96-T:V5Y<UM=(B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1O8BT^9V5T4V]U
M<F-E*"D@+B`G.B<@+B`D;V(M/F=E=%9A;'5E*"=?7VME>2<I*2`_/B(@+SX\
M+W1D/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*"1T:&ES+3YS:&]W161I
M="DZ(#\^"B`@/'1D/CP_<&AP(&5C:&\@)&5D:71?=7)L(#\^/"]T9#X*/#]P
M:'`@96YD:68[(#\^"CP_<&AP(&EF("@D=&AI<RT^<VAO=U9C87)D*3H@/SX*
M("`\=&0^/#]P:'`@96-H;R`D=F-A<F1?=7)L(#\^/"]T9#X*/#]P:'`@96YD
M:68[(#\^"CP_<&AP(&EF("@D=&AI<RT^<VAO=T=R;W5P*3H@/SX*("`\=&0^
M/#]P:'`@96-H;R`D;V(M/FES1W)O=7`H*2`_($AO<F1E.CII;6<H)V=R;W5P
M+G!N9R<L(%\H(D=R;W5P(BDI(#H@)R9N8G-P.R<@/SX\+W1D/@H\/W!H<"!E
M;F1I9CL@/SX*("`\=&0\/W!H<"!I9B`H)'1H:7,M/G-H;W=3;W)T("8F("1S
M;W)T8GD@/3T@,"D@96-H;R`G(&-L87-S/2)L:6YE9%)O=U-E;&5C=&5D0V]L
M(B<@/SX^/#]P:'`*96-H;R`D8V5L;#L*"B\O(%=E('!U<G!O<V5F=6QL>2!D
M;R!T:&ES(&)E9F]R92!T:&4@/"]T9#X@<V\@=&AA="!I9B!W92!E;F0@=7`*
M+R\@:6YC;'5D:6YG(&$@<V-R:7!T(&9I;&4@*'-A>2P@9F]R('1H92!)35`@
M8V]M<&]S92!W:6YD;W<I+"!I="=S(&EN"B\O(&$@;&5G86P@<W!O="X*+R\*
M+R\@0G5I;&0@=&AE(&-O;'5M;G,@=&\@9&ES<&QA>2X*)'-H;W=N7V-O;'5M
M;G,@/2!A<G)A>2@I.PIF;W(@*"1C(#T@,3L@)&,@/#T@8V]U;G0H)&-O;'5M
M;G,I.R`D8RLK*2!["B`@("!I9B`H)&]B+3YH87-686QU92@D8V]L=6UN<ULD
M8R`M(#%=*2D@>PH@("`@("`@("1S:&]W;E]C;VQU;6YS6R1C72`](&AT;6QS
M<&5C:6%L8VAA<G,H)&]B+3YG971686QU92@D8V]L=6UN<ULD8R`M(#%=*2D[
M"B`@("`@("`@:68@*"1'3$]"04Q36R=A='1R:6)U=&5S)UU;)&-O;'5M;G-;
M)&,@+2`Q75U;)W1Y<&4G72`]/2`G96UA:6PG*2!["B`@("`@("`@("`@("1S
M:&]W;E]C;VQU;6YS6R1C72`](%1U<F)A.CIF;W)M871%;6%I;$%D9')E<W-E
M<R@D<VAO=VY?8V]L=6UN<ULD8UTL("1O8BT^9V5T5F%L=64H)VYA;64G*2D[
M"B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`D<VAO=VY?8V]L=6UN
M<ULD8UT@/2`G)FYB<W`[)SL*("`@('T*?0H*96-H;R`G/"]T9#XG.PIF;W)E
M86-H("@D<VAO=VY?8V]L=6UN<R!A<R`D8V]L=6UN(#T^("1V86QU92D@>PH@
M("`@96-H;R`G/'1D)SL*("`@(&EF("@D=&AI<RT^<VAO=U-O<G0@)B8@)&-O
M;'5M;B`]/2`D<V]R=&)Y*2!["B`@("`@("`@96-H;R`G(&-L87-S/2)L:6YE
M9%)O=U-E;&5C=&5D0V]L(B<["B`@("!]"B`@("!E8VAO("<^)R`N("1V86QU
M92`N("<\+W1D/B<["GT*/SX*/"]T<CX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]T96UP;&%T97,O8G)O=W-E+W-E
M87)C:%]C<FET97)I82YI;F,`````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C4R`#$P-#$W
M,S8R-S4V`#`R-#8V-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`IF;W)E86-H("@D;6%P(&%S("1N86UE(#T^("1V
M*2!["B`@("!I9B`H<W5B<W1R*"1N86UE+"`P+"`R*2`A/2`G7U\G*2!["C\^
M"B`\='(^"B`@/'1D('=I9'1H/2(Q)2(@;F]W<F%P/2)N;W=R87`B(&-L87-S
M/2)L:6=H="!R:6=H=$%L:6=N(B`^/'-T<F]N9SX\/W!H<"!E8VAO("1A='1R
M:6)U=&5S6R1N86UE75LG;&%B96PG72`_/CPO<W1R;VYG/CPO=&0^"B`@/'1D
M(&-L87-S/2)L969T06QI9VXB/CQI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(S
M,"(@;F%M93TB/#]P:'`@96-H;R`D;F%M92`_/B(@=F%L=64](CP_<&AP(&5C
M:&\@:7-S970H)&-R:71E<FEA6R1N86UE72D@/R!H=&UL<W!E8VEA;&-H87)S
M*"1C<FET97)I85LD;F%M95TI(#H@)R<@/SXB("\^/"]T9#X*(#PO='(^"CP_
M<&AP"B`@("!]"GT*/SX*/"]T86)L93X*/"]F;W)M/@H`````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O=&5M<&QA=&5S+V)R;W=S92]C;VQU;6Y?:&5A9&5R
M<RYI;F,````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-30Q-@`Q,#0Q-S,V,C<U-@`P,C0U
M,S$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)C;VYT86-T<R(@86-T:6]N/2)B
M<F]W<V4N<&AP(CX*/#]P:'`@96-H;R!5=&EL.CIF;W)M26YP=70H*2`_/@H\
M=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(B!C;&%S<STB;&EN
M9612;W<B/@H\=&AE860^"B`\='(^"CP_<&AP(&EF("@D=&AI<RT^<VAO=TUA
M<FLI.B`_/@H@(#QT:"!C;&%S<STB:71E;2!L969T06QI9VXB('=I9'1H/2(Q
M)2(@<W1Y;&4](F-U<G-O<CIP;VEN=&5R(B!O;F-L:6-K/2)D;V-U;65N="YC
M;VYT86-T<RYC:&5C:T%L;"YC:&5C:V5D(#T@(61O8W5M96YT+F-O;G1A8W1S
M+F-H96-K06QL+F-H96-K960[(%-E;&5C=$%L;"@I.R(@;F]W<F%P/2)N;W=R
M87`B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB8VAE8VM!;&PB(&]N
M8VQI8VL](F1O8W5M96YT+F-O;G1A8W1S+F-H96-K06QL+F-H96-K960@/2`A
M9&]C=6UE;G0N8V]N=&%C=',N8VAE8VM!;&PN8VAE8VME9#L@4V5L96-T06QL
M*"D[(B`\/W!H<"!E8VAO($AO<F1E.CIG971!8V-E<W-+97E!;F14:71L92A?
M*")#:&5C:R!?06QL+TYO;F4B*2D@/SX@+SX\+W1H/@H\/W!H<"!E;F1I9CL@
M/SX*/#]P:'`@:68@*"1T:&ES+3YS:&]W161I="DZ(#\^"B`@/'1H(&-L87-S
M/2)I=&5M(B!W:61T:#TB,24B/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G961I
M="YP;F<G+"!?*")%9&ET(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*2`_/CPO=&@^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H
M)'1H:7,M/G-H;W=68V%R9"DZ(#\^"B`@/'1H(&-L87-S/2)I=&5M(B!W:61T
M:#TB,24B/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G;6EM92]V8V%R9"YP;F<G
M+"!?*")V0V%R9"(I+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2D@/SX\+W1H/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*"1T:&ES
M+3YS:&]W1W)O=7`I.B`_/@H@(#QT:"!C;&%S<STB:71E;2(@=VED=&@](C$E
M(CX\/W!H<"!E8VAO($AO<F1E.CII;6<H)V=R;W5P+G!N9R<L(%\H(DQI<W0B
M*2D@/SX\+W1H/@H\/W!H<"!E;F1I9CL@/SX*("`\=&@@8VQA<W,](CP_<&AP
M(&5C:&\@*"1T:&ES+3YS:&]W4V]R="`F)B`D<V]R=&)Y(#T](#`I(#\@)W-E
M;&5C=&5D)R`Z("=I=&5M)R`_/B!L969T06QI9VXB('=I9'1H/2(\/W!H<"!E
M8VAO("1W:61T:"`_/B4B(&YO=W)A<#TB;F]W<F%P(CX*/#]P:'`@:68@*"1T
M:&ES+3YS:&]W4V]R="DZ(#\^"B`@(#P_<&AP(&EF("@D1TQ/0D%,4ULG<')E
M9G,G72T^9V5T5F%L=64H)W-O<G1B>2<I(#T](#`I.B`_/@H@("`@("`\82!C
M;&%S<STB=VED9V5T(B!H<F5F/2(C(B!O;F-L:6-K/2)3;W)T*#`L(#P_<&AP
M(&5C:&\@86)S*#$@+2`D<V]R=&1I<BD@/SXI.R!R971U<FX@9F%L<V4[("(^
M/#]P:'`@96-H;R!(;W)D93HZ:6UG*"1S;W)T9&ER(#\@)WIA+G!N9R<@.B`G
M87HN<&YG)RP@7R@B4V]R="!$:7)E8W1I;VXB*2P@;G5L;"P@)')E9VES=')Y
M+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX\+V$^"B`@("`@(#QA(&-L87-S
M/2)W:61G970B(&AR968](B,B(&]N8VQI8VL](E-O<G0H,"P@/#]P:'`@96-H
M;R!A8G,H,2`M("1S;W)T9&ER*2`_/BD[(')E='5R;B!F86QS93LB/@H@("`\
M/W!H<"!E;'-E.B`_/@H@("`@("`\82!C;&%S<STB=VED9V5T(B!H<F5F/2(C
M(B!O;F-L:6-K/2)3;W)T*#`L(#P_<&AP(&5C:&\@)'-O<G1D:7(@/SXI.R!R
M971U<FX@9F%L<V4[(CX*("`@/#]P:'`@96YD:68[(#\^"CP_<&AP(&5N9&EF
M.R`_/@H@("`\/W!H<"!E8VAO("1A='1R:6)U=&5S6R=N86UE)UU;)VQA8F5L
M)UT@/SX*/#]P:'`@:68@*"1T:&ES+3YS:&]W4V]R="DZ(#\^"B`@(#PO83X*
M/#]P:'`@96YD:68[(#\^"B`@/"]T:#X*("`\/W!H<"!F;W(@*"1I(#T@,3L@
M)&D@/#T@8V]U;G0H)&-O;'5M;G,I.R`D:2LK*3H@/SX*("`\=&@@8VQA<W,]
M(CP_<&AP(&5C:&\@*"1T:&ES+3YS:&]W4V]R="`F)B`D<V]R=&)Y(#T]("1I
M*2`_("=S96QE8W1E9"<@.B`G:71E;2<@/SX@;&5F=$%L:6=N(B!W:61T:#TB
M/#]P:'`@96-H;R`D=VED=&@@/SXE(B!N;W=R87`](FYO=W)A<"(^"CP_<&AP
M(&EF("@D=&AI<RT^<VAO=U-O<G0I.B`_/@H@("`\/W!H<"!I9B`H)$=,3T)!
M3%-;)W!R969S)UTM/F=E=%9A;'5E*"=S;W)T8GDG*2`]/2`D:2DZ(#\^"B`@
M("`@(#QA(&-L87-S/2)W:61G970B(&AR968](B,B(&]N8VQI8VL](E-O<G0H
M/#]P:'`@96-H;R`D:2`_/BP@/#]P:'`@96-H;R!A8G,H,2`M("1S;W)T9&ER
M*2`_/BD[(')E='5R;B!F86QS93L@(CX\/W!H<"!E8VAO($AO<F1E.CII;6<H
M)'-O<G1D:7(@/R`G>F$N<&YG)R`Z("=A>BYP;F<G+"!?*")3;W)T($1I<F5C
M=&EO;B(I+"!N=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`_/CPO83X*("`@("`@/&$@8VQA<W,](G=I9&=E="(@:')E9CTB(R(@;VYC
M;&EC:STB4V]R="@\/W!H<"!E8VAO("1I(#\^+"`\/W!H<"!E8VAO(&%B<R@Q
M("T@)'-O<G1D:7(I(#\^*3L@<F5T=7)N(&9A;'-E.R(^"B`@(#P_<&AP(&5L
M<V4Z(#\^"B`@("`@(#QA(&-L87-S/2)W:61G970B(&AR968](B,B(&]N8VQI
M8VL](E-O<G0H/#]P:'`@96-H;R`D:2`_/BP@/#]P:'`@96-H;R`D<V]R=&1I
M<B`_/BD[(')E='5R;B!F86QS93LB/@H@("`\/W!H<"!E;F1I9CL@/SX*/#]P
M:'`@96YD:68[(#\^"B`@(#P_<&AP(&5C:&\@)&%T=')I8G5T97-;)&-O;'5M
M;G-;)&D@+2`Q75U;)VQA8F5L)UT@/SX*/#]P:'`@:68@*"1T:&ES+3YS:&]W
M4V]R="DZ(#\^"B`@(#PO83X*/#]P:'`@96YD:68[(#\^"B`@/"]T:#X*("`\
M/W!H<"!E;F1F;W([(#\^"B`\+W1R/@H\+W1H96%D/@H\=&)O9'D^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]T
M96UP;&%T97,O8G)O=W-E+V%C=&EO;G,N:6YC````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`U-C$W`#$P-#$W,S8R-S4V`#`R,S(P-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\9&EV(&-L87-S/2)C;VYT
M<F]L(&YO=W)A<"(^"CP_<&AP(&EF("@A96UP='DH)&AA<T1E;&5T92DI('L*
M("`@("`@("`@(&5C:&\@2&]R9&4Z.G=I9&=E="@G(R<L("1T:&ES+3YG9714
M>7!E*"D@/3T@)VQI<W0G(#\@7R@B4F5M;W9E(&9R;VT@=&AI<R!L:7-T(BD@
M.B!?*")$96QE=&4B*2P@)W=I9&=E="<L("<G+"`B4W5B;6ET*"=D96QE=&4G
M*3L@<F5T=7)N(&9A;'-E.R(L("1T:&ES+3YG9714>7!E*"D@/3T@)VQI<W0G
M(#\@7R@B7U)E;6]V92!F<F]M('1H:7,@;&ES="(I(#H@7R@B7T1E;&5T92(I
M*2`N("=\)SL*("`@("`@?0H@("`@("!I9B`H(65M<'1Y*"1H87-%9&ET*2D@
M>PH@("`@("`@("`@96-H;R!(;W)D93HZ=VED9V5T*"<C)RP@7R@B161I="(I
M+"`G=VED9V5T)RP@)R<L(")D;V-U;65N="YC;VYT86-T<RYA8W1I;VX])R(@
M+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)V5D:70N<&AP)RD@+B`B)SL@4W5B
M;6ET*"=G<F]U<&5D:70G*3L@<F5T=7)N(&9A;'-E.R(L(%\H(D5D:70B*2D@
M+B`G?"<["B`@("`@('T*/SX*(#P_<&AP(&EF("@D8V]N9ELG;65N=2==6R=I
M;7!O<G1?97AP;W)T)UTI.B`_/@H@/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T
M*"<C)RP@7R@B17AP;W)T(BDL("=W:61G970G+"`G)RP@(F1O8W5M96YT+F-O
M;G1A8W1S+F%C=&EO;CTG(B`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9&%T
M82YP:'`G*2`N("(G.R!3=6)M:70H)W-E;&5C="<I.R!R971U<FX@9F%L<V4[
M(BP@7R@B17AP;W)T(BDI(#\^"B`\/W!H<"!E;F1I9CL@/SX*(#P_<&AP(&EF
M("@A96UP='DH)&%D9%]S;W5R8V5?;W!T:6]N<RDI.B`D:60@/2!M9#4H;71?
M<F%N9"@I*3L@/SX*(#QF;W)M('-T>6QE/2)D:7-P;&%Y.FEN;&EN92(@;F%M
M93TB9CP_<&AP(&5C:&\@)&ED(#\^(B!A8W1I;VX](FIA=F%S8W)I<'0Z=F]I
M9"@P*3LB(&]N<W5B;6ET/2)R971U<FX@9F%L<V4[(CX*('P@/#]P:'`*("`@
M("`@("`@:68@*"%E;7!T>2@D:&%S1&5L971E*2D@>PH@("`@("`@("`@("`@
M96-H;R!(;W)D93HZ;&EN:R@G(R<L(%\H(DUO=F4B*2P@)W=I9&=E="<L("<G
M+"`B0V]P>4UO=F4H)VUO=F4G+"!D;V-U;65N="YF(B`N("1I9"`N("<N<R<@
M+B`D:60@+B`B*3L@<F5T=7)N(&9A;'-E.R(I("X@7R@B36]V92(I("X@)SPO
M83XL("<["B`@("`@("`@('T*("`@("`@("`@96-H;R!(;W)D93HZ;&EN:R@G
M(R<L(%\H(D-O<'DB*2P@)W=I9&=E="<L("<G+"`B0V]P>4UO=F4H)V-O<'DG
M+"!D;V-U;65N="YF(B`N("1I9"`N("<N<R<@+B`D:60@+B`B*3L@<F5T=7)N
M(&9A;'-E.R(I("X@7R@B0V]P>2(I("X@)SPO83XG.PH@("`_/@H@(#QS96QE
M8W0@;F%M93TB<SP_<&AP(&5C:&\@)&ED(#\^(B!I9#TB<SP_<&AP(&5C:&\@
M)&ED(#\^(CX*("`@/&]P=&EO;B!V86QU93TB(CX\/W!H<"!E8VAO(%\H(G1O
M(&$@9&EF9F5R96YT($%D9')E<W,@0F]O:R(I(#\^/"]O<'1I;VX^"B`@(#P_
M<&AP(&5C:&\@)&%D9%]S;W5R8V5?;W!T:6]N<R`_/@H@(#PO<V5L96-T/@H@
M/"]F;W)M/@H@/#]P:'`@96YD:68[(#\^"@H@/#]P:'`@:68@*"1A9&14;TQI
M<W0I.B`D:60@/2!M9#4H;71?<F%N9"@I*3L@/SX*(#QF;W)M('-T>6QE/2)D
M:7-P;&%Y.FEN;&EN92(@;F%M93TB9CP_<&AP(&5C:&\@)&ED(#\^(B!A8W1I
M;VX](FIA=F%S8W)I<'0Z=F]I9"@P*3LB(&]N<W5B;6ET/2)R971U<FX@9F%L
M<V4[(CX*('P@/#]P:'`@96-H;R!(;W)D93HZ;&EN:R@G(R<L(%\H(D%D9"!T
M;R(I+"`G=VED9V5T)RP@)R<L(")!9&0H9&]C=6UE;G0N9B(@+B`D:60@+B`G
M+G,G("X@)&ED("X@(BD[(')E='5R;B!F86QS93LB*2`N(%\H(D%D9"(I("X@
M)SPO83XG(#\^"B`\<V5L96-T(&YA;64](G,\/W!H<"!E8VAO("1I9"`_/B(@
M:60](G,\/W!H<"!E8VAO("1I9"`_/B(^"B`@/&]P=&EO;B!V86QU93TB(CX\
M/W!H<"!E8VAO(%\H(G1O(&$@0V]N=&%C="!,:7-T(BD@/SX\+V]P=&EO;CX*
M("`\;W!T:6]N('9A;'5E/2(B/BTM+2TM/"]O<'1I;VX^"B`@/#]P:'`@9F]R
M96%C:"`H)&%D9%1O3&ES="!A<R`D;&ES="DZ(#\^"B`@/#]P:'`@:68@*&ES
M7V%R<F%Y*"1L:7-T*2DZ(#\^"B`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H
M;R`D;&ES=%LG<V]U<F-E)UT@+B`H)&QI<W1;)VME>2==(#\@)SHG("X@)&QI
M<W1;)VME>2==(#H@*'-T<G!O<R@D;&ES=%LG<V]U<F-E)UTL("<Z)RD@/R`G
M.B<@.B`G)RDI(#\^(CX\/W!H<"!E8VAO("1L:7-T6R=N86UE)UT@/SX\+V]P
M=&EO;CX*("`\/W!H<"!E;'-E.B`_/@H@(#QO<'1I;VX@=F%L=64](B(^/#]P
M:'`@96-H;R`D;&ES="`_/CPO;W!T:6]N/@H@(#P_<&AP(&5N9&EF.R!E;F1F
M;W)E86-H.R`_/@H@/"]S96QE8W0^"B`\+V9O<FT^"B`\/W!H<"!E;F1I9CL@
M/SX*"CP_<&AP"B1B<F]W<V5?;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<BA(
M;W)D93HZ87!P;&EC871I;VY5<FPH)V)R;W=S92YP:'`G*2P@)W-O=7)C92<L
M("1S;W5R8V4I.PII9B`H)'1H:7,M/F=E=%1Y<&4H*2`]/2`G9&ER96-T;W)Y
M)R`F)B`A96UP='DH)&-F9U-O=7)C97-;)'-O=7)C95U;)VUA<"==6R=?7W1Y
M<&4G72DI('L*("`@('!R:6YT9BA?*")3:&]W("5S(BDL($AO<F1E.CIW:61G
M970H571I;#HZ861D4&%R86UE=&5R*"1B<F]W<V5?;&EN:RP@)W-H;W<G+"`G
M;&ES=',G*2P@7R@B4VAO=R!,:7-T<R(I+"`G=VED9V5T)RP@)R<L("<G+"!?
M*")?3&ES=',B*2D@+B`G+"`G("X*("`@("`@("!(;W)D93HZ=VED9V5T*%5T
M:6PZ.F%D9%!A<F%M971E<B@D8G)O=W-E7VQI;FLL("=S:&]W)RP@)V-O;G1A
M8W1S)RDL(%\H(E-H;W<@0V]N=&%C=',B*2P@)W=I9&=E="<L("<G+"`G)RP@
M7R@B7T-O;G1A8W1S(BDI("X@)RP@)R`N"B`@("`@("`@2&]R9&4Z.G=I9&=E
M="A5=&EL.CIA9&1087)A;65T97(H)&)R;W=S95]L:6YK+"`G<VAO=R<L("=A
M;&PG*2P@7R@B4VAO=R!!;&PB*2P@)W=I9&=E="<L("<G+"`G)RP@7R@B06QL
M(BDI*3L*?0H_/@H\+V1I=CX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W1E;7!L871E<R]B<F]W<V4O
M8V]N=&%C=')O=RYI;F,`````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4R,#4`,3`T
M,3<S-C(W-38`,#(S-S(P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@II9B`H)'1H:7,M/FQI<W0M/FES1G)E<V@H
M)&]B*2D@>PH@("`@)&-L87-S(#T@)W1E>'0G.PI](&5L<V4@>PH@("`@)&-L
M87-S(#T@)V]L9"<["GT*"FEF("@D;V(M/FAA<U9A;'5E*"=N86UE)RDI('L*
M("`@("1L:6YK7W1E>'0@/2!H=&UL<W!E8VEA;&-H87)S*%1U<F)A.CIF;W)M
M871.86UE*"1O8BDI.PI](&5L<V4@>PH@("`@)&QI;FM?=&5X="`](%\H(EMN
M;R!V86QU95TB*3L*?0H*)&5D:71?=7)L(#T@)R9N8G-P.R<["@IG;&]B86P@
M)'!R969S.PII9B`H)&]B+3YH87-686QU92@G7U]K97DG*2D@>PH@("`@)'5R
M;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D;V(M/FES1W)O=7`H*2`_("=B<F]W
M<V4N<&AP)R`Z("=D:7-P;&%Y+G!H<"<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=S;W5R8V4G(#T^("1O8BT^9V5T4V]U<F-E*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K97DG(#T^
M("1O8BT^9V5T5F%L=64H)U]?:V5Y)RDI*3L*"B`@("`D=F-A<F1?=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"=V8V%R9"YP:'`G+"!A<G)A>2@G<V]U<F-E
M)R`]/B`D;V(M/F=E=%-O=7)C92@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VME>2<@/3X@)&]B
M+3YG971686QU92@G7U]K97DG*2DI.PH@("`@)'9C87)D7W5R;"`]($AO<F1E
M.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D=F-A<F1?=7)L*2P@7R@B
M1&]W;FQO860@=D-A<F0B*2D@+B!(;W)D93HZ:6UG*"=M:6UE+W9C87)D+G!N
M9R<L(%\H(D1O=VYL;V%D('9#87)D(BDL("<G+"`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PH*("`@("1C
M96QL(#T@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1U<FPI
M+"!S<')I;G1F*%\H(E9I97<@7"(E<UPB(BDL("1O8BT^9V5T5F%L=64H)VYA
M;64G*2DI.PH@("`@)&-E;&P@+CT@)&QI;FM?=&5X="`N("<\+V$^)SL*("`@
M(&EF("A4=7)B83HZ:&%S4&5R;6ES<VEO;B@D;V(L("=O8FIE8W0G+"!015)-
M4U]%1$E4*2D@>PH@("`@("`@("1E9&ET7W5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<B@G961I="YP:'`G+"!A<G)A>2@G<V]U<F-E)R`]/B`D;V(M/F=E=%-O
M=7)C92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:V5Y)R`]/B`D;V(M/F=E=%9A;'5E*"=?
M7VME>2<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=7)L)R`]/B!(;W)D93HZ<V5L9E5R;"@I
M*2D["B`@("`@("`@)&5D:71?=7)L(#T@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"1E9&ET7W5R;"DL('-P<FEN=&8H7R@B161I="!<(B5S
M7"(B*2P@)&]B+3YG971686QU92@G;F%M92<I*2D@+B!(;W)D93HZ:6UG*"=E
M9&ET+G!N9R<L(%\H(D5D:70B*2P@)R<L("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<["B`@("!]"GT@96QS
M92!["B`@("`D8V5L;"`]("1L:6YK7W1E>'0["B`@("`D961I=%]U<FP@/2`D
M=F-A<F1?=7)L(#T@;G5L;#L*?0H_/@H\='(@8VQA<W,](CP_<&AP(&5C:&\@
M)&-L87-S(#\^(CX*("`\=&0^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C;&%S
M<STB8VAE8VMB;W@B(&YA;64](F]B:F5C=&ME>7-;72(@=F%L=64](CP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;V(M/F=E=%-O=7)C92@I("X@)SHG
M("X@)&]B+3YG971686QU92@G7U]K97DG*2D@/SXB("\^/"]T9#X*("`\=&0^
M/#]P:'`@96-H;R`D961I=%]U<FP@/SX\+W1D/@H@(#QT9#X\/W!H<"!E8VAO
M("1V8V%R9%]U<FP@/SX\+W1D/@H@(#QT9#X\/W!H<"!E8VAO("1O8BT^:7-'
M<F]U<"@I(#\@2&]R9&4Z.FEM9R@G9W)O=7`N<&YG)RP@7R@B1W)O=7`B*2D@
M.B`G)FYB<W`[)R`_/CPO=&0^"B`@/'1D/CP_<&AP"F5C:&\@)&-E;&P["@HO
M+R!792!P=7)P;W-E9G5L;'D@9&\@=&AI<R!B969O<F4@=&AE(#PO=&0^('-O
M('1H870@:68@=V4@96YD('5P"B\O(&EN8VQU9&EN9R!A('-C<FEP="!F:6QE
M("AS87DL(&9O<B!T:&4@24U0(&-O;7!O<V4@=VEN9&]W*2P@:70G<R!I;@HO
M+R!A(&QE9V%L('-P;W0N"B\O"B\O($)U:6QD('1H92!C;VQU;6YS('1O(&1I
M<W!L87DN"B1S:&]W(#T@87)R87DH*3L*9F]R96%C:"`H)$=,3T)!3%-;)V-O
M;'5M;G,G72!A<R`D8V]L=6UN*2!["B`@("!I9B`H)&]B+3YH87-686QU92@D
M8V]L=6UN*2D@>PH@("`@("`@("1S:&]W6R1C;VQU;6Y=(#T@:'1M;'-P96-I
M86QC:&%R<R@D;V(M/F=E=%9A;'5E*"1C;VQU;6XI*3L*("`@("`@("!I9B`H
M)$=,3T)!3%-;)V%T=')I8G5T97,G75LD8V]L=6UN75LG='EP92==(#T]("=E
M;6%I;"<I('L*("`@("`@("`@("`@)'-H;W=;)&-O;'5M;ET@/2!4=7)B83HZ
M9F]R;6%T16UA:6Q!9&1R97-S97,H)'-H;W=;)&-O;'5M;ETL("1O8BT^9V5T
M5F%L=64H)VYA;64G*2D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@
M("`D<VAO=ULD8V]L=6UN72`]("<F;F)S<#LG.PH@("`@?0I]"@H_/CPO=&0^
M"CP_<&AP(&9O<F5A8V@@*"1S:&]W(&%S("1F:65L9"DZ(#\^"B`@/'1D/CP_
M<&AP(&5C:&\@)&9I96QD(#\^/"]T9#X*/#]P:'`@96YD9F]R96%C:#L@/SX*
M/"]T<CX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O='5R8F$O=&5M<&QA=&5S+V)R;W=S92]S96%R8V@N:6YC````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#(Q-0`Q,#0Q-S,V,C<U-@`P,C(W-S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RH@0G5I;&0@=&AE(&1I<F5C=&]R>2!S;W5R8V5S('-E;&5C="!W:61G
M970N("HO"B1S;W5R8V5?;W!T:6]N<R`]("<G.PHD8W)I=&5R:6%?;W!T:6]N
M<R`]("<G.PHD:G-?8W)I=&5R:6$@/2`B=F%R(&-R:71E<FEA3W!T:6]N<R`]
M(&YE=R!!<G)A>2@I.UQN(CL*)'-O=7)C95]C;W5N="`](#`["F9O<F5A8V@@
M*%1U<F)A.CIG971!9&1R97-S0F]O:W,H*2!A<R`D:V5Y(#T^("1E;G1R>2D@
M>PH@("`@)&IS7V-R:71E<FEA("X](")C<FET97)I84]P=&EO;G-;)'-O=7)C
M95]C;W5N=%T@/2!N97<@07)R87DH*5QN(B`N"B`@("`@("`@(F-R:71E<FEA
M3W!T:6]N<ULD<V]U<F-E7V-O=6YT75LP72`]("<D:V5Y)SM<;B(["@H@("`@
M+RH@0G5I;&0@=&AE(&-R:71E<FEA('-E;&5C="!W:61G970N("HO"B`@("`D
M9FEE;&1?8V]U;G0@/2`Q.PH@("`@9F]R96%C:"`H)&5N=')Y6R=S96%R8V@G
M72!A<R`D9FEE;&0I('L*("`@("`@("`D:G-?8W)I=&5R:6$@+CT@(F-R:71E
M<FEA3W!T:6]N<ULD<V]U<F-E7V-O=6YT75LD9FEE;&1?8V]U;G1=(#T@;F5W
M($%R<F%Y*"<D9FEE;&0G+"`G(B`N("1A='1R:6)U=&5S6R1F:65L9%U;)VQA
M8F5L)UT@+B`B)RD[7&XB.PH@("`@("`@(&EF("@D:V5Y(#T]("1S;W5R8V4I
M('L*("`@("`@("`@("`@)'-E;&5C=&5D(#T@*"1C<FET97)I82`]/2`D9FEE
M;&0I(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G.PH@("`@("`@("`@
M("`D8W)I=&5R:6%?;W!T:6]N<R`N/2`B/&]P=&EO;B!V86QU93U<(B1F:65L
M9%PB)'-E;&5C=&5D/B(@+@H@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC
M:&%R<R@D871T<FEB=71E<ULD9FEE;&1=6R=L86)E;"==*2`N("(\+V]P=&EO
M;CY<;B(["B`@("`@("`@?0H@("`@("`@("1F:65L9%]C;W5N="LK.PH@("`@
M?0H*("`@("1S96QE8W1E9"`]("@D:V5Y(#T]("1S;W5R8V4I(#\@)R!S96QE
M8W1E9#TB<V5L96-T960B)R`Z("<G.PH@("`@)'-O=7)C95]O<'1I;VYS("X]
M("(\;W!T:6]N('9A;'5E/5PB)&ME>5PB)'-E;&5C=&5D/B(@+@H@("`@("`@
M(&AT;6QS<&5C:6%L8VAA<G,H)&5N=')Y6R=T:71L92==*2`N("(\+V]P=&EO
M;CY<;B(["@H@("`@)'5N:7%U95]S;W5R8V4@/2`D:V5Y.PH@("`@)'-O=7)C
M95]C;W5N="LK.PI]"@HO*B!"=6EL9"!S96%R8V@@;6]D92!T86)S+B`J+PIR
M97%U:7)E7V]N8V4@)TAO<F1E+U5)+U1A8G,N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]687)I86)L97,N<&AP)SL*)'-5<FP@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)W-E87)C:"YP:'`G*3L*)'9A<G,@/2`F5F%R:6%B;&5S.CIG
M971$969A=6QT5F%R:6%B;&5S*"D["B1T86)S(#T@)FYE=R!(;W)D95]525]4
M86)S*"=S96%R8VA?;6]D92<L("1V87)S*3L*)'1A8G,M/F%D9%1A8BA?*")"
M87-I8R!396%R8V@B*2P@)'-5<FPL("=B87-I8R<I.PHD=&%B<RT^861D5&%B
M*%\H(D%D=F%N8V5D(%-E87)C:"(I+"`D<U5R;"P@)V%D=F%N8V5D)RD["F5C
M:&\@)'1A8G,M/G)E;F1E<B@D7U-%4U-)3TY;)W1U<F)A7W-E87)C:%]M;V1E
M)UTI.PH*:68@*"1?4T534TE/3ELG='5R8F%?<V5A<F-H7VUO9&4G72`]/2`G
M8F%S:6,G*3H@/SX*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\
M(2TM"CP_<&AP(&5C:&\@)&IS7V-R:71E<FEA(#\^"F9U;F-T:6]N('5P9&%T
M94-R:71E<FEA<R@I"GL*("`@('9A<B!F(#T@9&]C=6UE;G0N9&ER96-T;W)Y
M7W-E87)C:#L*("`@('=H:6QE("AF+F-R:71E<FEA+FQE;F=T:"`^(#`I('L*
M("`@("`@("!F+F-R:71E<FEA+F]P=&EO;G-;9BYC<FET97)I82YL96YG=&@M
M,5T@/2!N=6QL.PH@("`@?0H*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@8W)I
M=&5R:6%/<'1I;VYS+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*&-R:71E
M<FEA3W!T:6]N<UMI75LP72`]/2!F+G-O=7)C92YO<'1I;VYS6V8N<V]U<F-E
M+G-E;&5C=&5D26YD97A=+G9A;'5E*2!["B`@("`@("`@("`@(&9O<B`H=F%R
M(&H@/2`Q.R!J(#P@8W)I=&5R:6%/<'1I;VYS6VE=+FQE;F=T:#L@:BLK*2![
M"B`@("`@("`@("`@("`@("!F+F-R:71E<FEA+F]P=&EO;G-;9BYC<FET97)I
M82YL96YG=&A=(#T@;F5W($]P=&EO;BAC<FET97)I84]P=&EO;G-;:5U;:EU;
M,5TL(&-R:71E<FEA3W!T:6]N<UMI75MJ75LP72D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@9BYC<FET97)I82YS96QE8W1E9$EN9&5X(#T@,#L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*?0HO+RTM/@H\+W-C
M<FEP=#X*"CQF;W)M(&YA;64](F1I<F5C=&]R>5]S96%R8V@B(&%C=&EO;CTB
M<V5A<F-H+G!H<"(@;65T:&]D/2)G970B/@H\/W!H<"!E8VAO(%5T:6PZ.F9O
M<FU);G!U="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO
M;DE$(B!V86QU93TB,2(@+SX*"CQT86)L92!C96QL<W!A8VEN9STB-2(^"B`@
M/'1R/@H@("`@/'1D(&-L87-S/2)L:6=H="!R:6=H=$%L:6=N(CX\<W1R;VYG
M/CP_<&AP(&5C:&\@7R@B1FEN9"(I(#\^/"]S=')O;F<^/"]T9#X*("`@(#QT
M9"!C;&%S<STB:71E;2(^"B`@("`@("`@/'-E;&5C="!N86UE/2)C<FET97)I
M82(^"B`@("`@("`@(#P_<&AP(&5C:&\@)&-R:71E<FEA7V]P=&EO;G,@/SX*
M("`@("`@("`\+W-E;&5C=#X*("`@(#PO=&0^"@H@("`@/'1D(&-L87-S/2)L
M:6=H="!R:6=H=$%L:6=N(CX\<W1R;VYG/CP_<&AP(&5C:&\@7R@B36%T8VAI
M;F<B*2`_/CPO<W1R;VYG/CPO=&0^"B`@("`\=&0@8VQA<W,](FET96TB/@H@
M("`@("`@(#QI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(S,"(@;F%M93TB=F%L
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1V86PI(#\^
M(B`O/@H@("`@/"]T9#X*"CP_<&AP(&EF("AC;W5N="@D8V9G4V]U<F-E<RD@
M/B`Q*3H@/SX*("`@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!;&EG;B(^/'-T
M<F]N9SX\/W!H<"!E8VAO(%\H(D9R;VTB*2`_/CPO<W1R;VYG/CPO=&0^"B`@
M("`\=&0@8VQA<W,](FET96TB/@H@("`@("`@(#QS96QE8W0@;F%M93TB<V]U
M<F-E(B!O;F-H86YG93TB=7!D871E0W)I=&5R:6%S*"DB/@H@("`@("`@("`\
M/W!H<"!E8VAO("1S;W5R8V5?;W!T:6]N<R`_/@H@("`@("`@(#PO<V5L96-T
M/@H@("`@/"]T9#X*/#]P:'`@96QS93H@/SX*("`@(#QT9#X*("`@("`@("`\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)S;W5R8V4B('9A;'5E/2(\/W!H
M<"!R97-E="@D8V9G4V]U<F-E<RD[(&5C:&\@:V5Y*"1C9F=3;W5R8V5S*2`_
M/B(@+SX*("`@(#PO=&0^"CP_<&AP(&5N9&EF.R`_/@H*("`@(#QT9#X*("`@
M("`@("`\:6YP=70@8VQA<W,](F)U='1O;B(@='EP93TB<W5B;6ET(B!N86UE
M/2)S96%R8V@B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-E87)C:"(I(#\^(B`O
M/@H@("`@/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H\+V9O<FT^"CQB<B`O/@H*
M/#]P:'`@96QS93H@/SX*"CQF;W)M(&YA;64](F1I<F5C=&]R>5]S96%R8V@B
M(&%C=&EO;CTB<V5A<F-H+G!H<"(@;65T:&]D/2)G970B/@H\/W!H<"!E8VAO
M(%5T:6PZ.F9O<FU);G!U="@I(#\^"@H\=&%B;&4@8V5L;'-P86-I;F<](C4B
M('=I9'1H/2(Q,#`E(CX*("`\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`@
M(#QT9#X*("`@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O
M;B(@;F%M93TB<V5A<F-H(B!V86QU93TB/#]P:'`@96-H;R!?*")396%R8V@B
M*2`_/B(@+SX*("`@("`@/&EN<'5T('1Y<&4](G)E<V5T(B!C;&%S<STB8G5T
M=&]N(B!N86UE/2)R97-E="(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5S970@
M=&\@1&5F875L=',B*2`_/B(@+SX*("`@(#PO=&0^"B`@/"]T<CX*(#P_<&AP
M(&EF("@D<V]U<F-E7V-O=6YT(#X@,2D@.B`_/@H@(#QT<CX*("`@(#QT9"!C
M;&%S<STB;&EG:'0@<FEG:'1!;&EG;B(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H
M(D1I<F5C=&]R>2(I(#\^/"]S=')O;F<^/"]T9#X*("`@(#QT9"!C;&%S<STB
M;&5F=$%L:6=N(CX*("`@("`@/'-E;&5C="!N86UE/2)S;W5R8V4B(&]N8VAA
M;F=E/2)D:7)E8W1O<GE?<V5A<F-H+G-U8FUI="@I(CX*("`@("`@(#P_<&AP
M(&5C:&\@)'-O=7)C95]O<'1I;VYS(#\^"B`@("`@(#PO<V5L96-T/@H@("`@
M/"]T9#X*("`\+W1R/@H@/#]P:'`@96QS93H@/SX*("`\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)S;W5R8V4B('9A;'5E/2(\/W!H<"!E8VAO("1U;FEQ
M=65?<V]U<F-E(#\^(CX*(#P_<&AP(&5N9&EF.R`_/@H*/#]P:'`@96YD:68[
M(#\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B
M82]T96UP;&%T97,O8G)O=W-E+V9O;W1E<BYI;F,`````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-#,T`#$P-#$W,S8R-S4V`#`R,S`S,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\9&EV(&-L87-S/2)C
M;VYT<F]L(CX*(#QS=')O;F<^/#]P:'`@96-H;R!?*")296-O<F1S(&1I<W!L
M87EE9#HB*2`_/CPO<W1R;VYG/@H\/W!H<`II9B`H(65M<'1Y*"1N=6U$:7-P
M;&%Y960I*2!["B`@("!E8VAO("=;)R`N('-P<FEN=&8H7R@B)7,@=&\@)7,@
M;V8@)7,B*2P@)'-T87)T+"`D96YD+"`D;G5M1&ES<&QA>65D*2`N("==)SL*
M?2!E;'-E('L*("`@(&5C:&\@7R@B3F]N92(I.PI]"FEF("AI<W-E="@D<&%G
M97(I*2!["B`@("!E8VAO("1P86=E<BT^<F5N9&5R*"D["GT*/SX*/"]D:78^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=&5M<&QA=&5S
M+V)R;W=S92]J879A<V-R:7!T+FEN8P``````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-3$S-@`Q,#0Q-S,V,C<U-@`P,C,W,#8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@H\(2TM"@IF=6YC=&EO;B!!;GE396QE8W1E9"@I"GL*("`@(&9O
M<B`H:2`](#`[(&D@/"!D;V-U;65N="YC;VYT86-T<RYE;&5M96YT<RYL96YG
M=&@[(&DK*RD@>PH@("`@("`@(&EF("AD;V-U;65N="YC;VYT86-T<RYE;&5M
M96YT<UMI72YC:&5C:V5D*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*("`@('T*("`@(')E='5R;B!F86QS93L*?0H*9G5N8W1I;VX@
M061D*'-E;&5C="D*>PH@("`@:68@*"%!;GE396QE8W1E9"@I*2!["B`@("`@
M("`@=VEN9&]W+F%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U
M(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="XB*2D@/SXG
M*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@:V5Y(#T@<V5L
M96-T6W-E;&5C="YS96QE8W1E9$EN9&5X72YV86QU93L*("`@(&EF("AK97D@
M/3T@)R<I('L*("`@("`@("!A;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!L:7-T+B(I*2`_/B<I.PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!I9B`H:V5Y+FEN9&5X
M3V8H)SHG*2`]/2`M,2!\?"!K97DN;&%S=$EN9&5X3V8H)SHG*2`]/2!K97DN
M;&5N9W1H("T@,2D@>PH@("`@("`@('9A<B!N97=,:7-T(#T@=VEN9&]W+G!R
M;VUP="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!L96%S92!N86UE('1H
M92!N97<@8V]N=&%C="!L:7-T.B(I*2`_/EQN)RP@)R<I.PH@("`@("`@(&EF
M("AN97=,:7-T("$](&YU;&P@)B8@;F5W3&ES="`A/2`G)RD@>PH@("`@("`@
M("`@("!I9B`H:V5Y+FQA<W1);F1E>$]F*"<Z)RD@/3T@:V5Y+FQE;F=T:"`M
M(#$I('L*("`@("`@("`@("`@("`@(&ME>2`](&ME>2YS=6)S='(H,"P@:V5Y
M+FQE;F=T:"`M(#$I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1O8W5M
M96YT+F-O;G1A8W1S+G-O=7)C92YV86QU92`](&ME>3L*("`@("`@("`@("`@
M9&]C=6UE;G0N8V]N=&%C=',N=&%R9V5T3F5W+G9A;'5E(#T@,3L*("`@("`@
M("`@("`@9&]C=6UE;G0N8V]N=&%C=',N=&%R9V5T3&ES="YV86QU92`](&YE
M=TQI<W0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@9&]C=6UE;G0N
M8V]N=&%C=',N=&%R9V5T3&ES="YV86QU92`](&ME>3L*("`@('T*"B`@("!3
M=6)M:70H)V%D9"<I.PI]"@IF=6YC=&EO;B!#;W!Y36]V92AA8W1I;VXL('-E
M;&5C="D*>PH@("`@:68@*"%!;GE396QE8W1E9"@I*2!["B`@("`@("`@=VEN
M9&]W+F%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U(&UU<W0@
M<V5L96-T(&%T(&QE87-T(&]N92!E;G1R>2!F:7)S="XB*2D@/SXG*3L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@:V5Y(#T@<V5L96-T6W-E
M;&5C="YS96QE8W1E9$EN9&5X72YV86QU93L*("`@(&EF("AK97D@/3T@)R<I
M('L*("`@("`@("!A;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO
M=2!M=7-T('-E;&5C="!A('1A<F=E="!A9&1R97-S(&)O;VLN(BDI(#\^)RD[
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(&1O8W5M96YT+F-O
M;G1A8W1S+G1A<F=E=$%D9')E<W-B;V]K+G9A;'5E(#T@:V5Y.PH@("`@4W5B
M;6ET*&%C=&EO;BD["GT*"F9U;F-T:6]N(%-U8FUI="AA8W1I;VXI"GL*("`@
M(&EF("A!;GE396QE8W1E9"@I*2!["B`@("`@("`@:68@*&%C=&EO;B`A/2`G
M9&5L971E)R!\?`H@("`@("`@("`@("!C;VYF:7)M*"<\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B07)E('EO=2!S=7)E('1H870@>6]U('=A;G0@=&\@9&5L
M971E('1H92!S96QE8W1E9"!E;G1R:65S/R(I*2`_/B<I*2!["B`@("`@("`@
M("`@(&1O8W5M96YT+F-O;G1A8W1S+F%C=&EO;DE$+G9A;'5E(#T@86-T:6]N
M.PH@("`@("`@("`@("!D;V-U;65N="YC;VYT86-T<RYS=6)M:70H*3L*("`@
M("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@('=I;F1O=RYA;&5R="@G/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO=2!M=7-T('-E;&5C="!A="!L96%S
M="!O;F4@96YT<GD@9FER<W0N(BDI(#\^)RD["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0I]"@IF=6YC=&EO;B!3;W)T*&-O;"P@9&ER96-T:6]N*0I[
M"B`@("!D;V-U;65N="YC;VYT86-T<RYS;W)T8GDN=F%L=64@/2!C;VP["B`@
M("!D;V-U;65N="YC;VYT86-T<RYS;W)T9&ER+G9A;'5E(#T@9&ER96-T:6]N
M.PH@("`@9&]C=6UE;G0N8V]N=&%C=',N<W5B;6ET*"D["GT*"F9U;F-T:6]N
M(%-E;&5C=$%L;"@I"GL*("`@(&9O<B`H:2`](#`[(&D@/"!D;V-U;65N="YC
M;VYT86-T<RYE;&5M96YT<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&1O8W5M
M96YT+F-O;G1A8W1S+F5L96UE;G1S6VE=+F-H96-K960@/2!D;V-U;65N="YC
M;VYT86-T<RYC:&5C:T%L;"YC:&5C:V5D.PH@("`@?0I]"@IF=6YC=&EO;B!C
M;VYF:7)M1&5L971E*&YA;64I"GL*("`@(')E='5R;B!C;VYF:7)M*"<\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B07)E('EO=2!S=7)E('1H870@>6]U('=A
M;G0@=&\@9&5L971E("5S/R(I*2`_/B<N<F5P;&%C92@G)7,G+"!N86UE*2D[
M"GT*"B\O+2T^"CPO<V-R:7!T/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T=7)B82]T96UP;&%T97,O8G)O=W-E+VAE861E<BYI
M;F,``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`R`#$P-#$W,S8R-S4V
M`#`R,C<U-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'1I=&QE*2`_/@H\+V@Q/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O='5R8F$O=&5M<&QA=&5S+V)L;V-K+P``````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<U-@`P,C`V,S0`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]T96UP;&%T97,O8FQO8VLO;6EN
M:7-E87)C:"YI;F,`````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S<S`#$P-#$W
M,S8R-S4V`#`R,S0U-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"G9A
M<B!B=7-Y17AP86YD:6YG(#T@9F%L<V4["F9U;F-T:6]N(&UI;FE?<V5A<F-H
M*"D*>PH@("`@:68@*&1O8W5M96YT+F)U<WE%>'!A;F1I;F<I('L*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"B`@("!D;V-U;65N="YG971%;&5M96YT
M0GE)9"@G='5R8F%?;6EN:7-E87)C:%]S96%R8VAI;F<G*2YS='EL92YV:7-I
M8FEL:71Y(#T@)W9I<VEB;&4G.PH@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)W1U<F)A7VUI;FES96%R8VA?:69R86UE)RDN<W1Y;&4N9&ES<&QA>2`]
M("=I;FQI;F4G.PI]"CPO<V-R:7!T/@H*/&9O<FT@;F%M93TB='5R8F%?;6EN
M:7-E87)C:"(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G;6EN:7-E87)C:"YP:'`G*2`_/B(@;VYS=6)M:70](FUI;FE?<V5A
M<F-H*"D[(B!T87)G970](G1U<F)A7VUI;FES96%R8VA?:69R86UE(CX*/#]P
M:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQP(&-L87-S/2)C;VYT<F]L(CX\
M<W1R;VYG/CP_<&AP(&5C:&\@7R@B475I8VL@4V5A<F-H(BD@/SX\+W-T<F]N
M9SX\+W`^"@H\:6YP=70@;F%M93TB<V5A<F-H(B!S:7IE/2(S-2(@+SX*/&EN
M<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP
M(&5C:&\@7R@B4V5A<F-H(BD@/SXB("\^"CQS<&%N(&ED/2)T=7)B85]M:6YI
M<V5A<F-H7W-E87)C:&EN9R(@8VQA<W,](FEN4')O9W)E<W,B/CP_<&AP(&5C
M:&\@7R@B4V5A<F-H:6YG+BXN(BD@/SX\+W-P86X^"CPO9F]R;3X*"CQD:78^
M/&EF<F%M92!I9#TB='5R8F%?;6EN:7-E87)C:%]I9G)A;64B(&YA;64](G1U
M<F)A7VUI;FES96%R8VA?:69R86UE(B!S='EL93TB=VED=&@Z,3`P)3L@:&5I
M9VAT.C$P,'!X.R!B;W)D97(Z;F]N93L@9&ES<&QA>3IN;VYE(B!F<F%M96)O
M<F1E<CTB,"(@<W)C/2(\/W!H<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G;6EN:7-E87)C:"YP:'`G*2`_/B(^/"]I9G)A;64^/"]D:78^"@``````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]T96UP;&%T97,O<')E
M9G,O````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S4V`#`R,#8V,0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U
M<F)A+W1E;7!L871E<R]P<F5F<R]C;VQU;6YS96QE8W0N:6YC````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C`V-C``,3`T,3<S-C(W-38`,#(T,#4R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP(&EF("@A
M)'!R969S+3YI<TQO8VME9"@G8V]L=6UN<R<I*3H*"F=L;V)A;"`D8V9G4V]U
M<F-E<RP@)&%T=')I8G5T97,["@HD<V]U<F-E<R`](%1U<F)A.CIG971#;VQU
M;6YS*"D["@HD:G,@/2`B=F%R(&-O;'5M;G,@/2!N97<@07)R87DH*3M<;B([
M"B1S;W5R8V5?8V]U;G0@/2`P.PIF;W)E86-H("@D8V9G4V]U<F-E<R!A<R`D
M<V]U<F-E(#T^("1I;F9O*2!["B`@("`D<V5L96-T960@/2!I<W-E="@D<V]U
M<F-E<ULD<V]U<F-E72D@/R!A<G)A>5]F;&EP*"1S;W5R8V5S6R1S;W5R8V5=
M*2`Z(&%R<F%Y*"D["B`@("`D:G,@+CT@(F-O;'5M;G-;)'-O=7)C95]C;W5N
M=%T@/2!N97<@07)R87DH*3M<;B(@+@H@("`@("`@(")C;VQU;6YS6R1S;W5R
M8V5?8V]U;G1=6S!=(#T@)R1S;W5R8V4G.UQN(CL*"B`@("`D8V]L=6UN7V-O
M=6YT(#T@,3L*("`@(&9O<F5A8V@@*"1I;F9O6R=M87`G72!A<R`D8V]L=6UN
M(#T^("1N=6QL*2!["B`@("`@("`@:68@*'-U8G-T<B@D8V]L=6UN+"`P+"`R
M*2`]/2`G7U\G('Q\("1C;VQU;6X@/3T@)VYA;64G*2!["B`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D;6%R:V5D(#T@:7-S970H
M)'-E;&5C=&5D6R1C;VQU;6Y=*2`_("=T<G5E)R`Z("=F86QS92<["B`@("`@
M("`@)&IS("X](")C;VQU;6YS6R1S;W5R8V5?8V]U;G1=6R1C;VQU;6Y?8V]U
M;G1=(#T@6R<D8V]L=6UN)RP@9&5C;V1E55))0V]M<&]N96YT*"<B("X@<F%W
M=7)L96YC;V1E*"1A='1R:6)U=&5S6R1C;VQU;6Y=6R=L86)E;"==*2`N("(G
M*2P@)&UA<FME9"P@(B`N("@H)&UA<FME9"`]/3T@)W1R=64G*2`_("1S96QE
M8W1E9%LD8V]L=6UN72`Z("=N=6QL)RD@+B`B73M<;B(["B`@("`@("`@)&-O
M;'5M;E]C;W5N="LK.PH@("`@?0H*("`@("1S;W5R8V5?8V]U;G0K*SL*?0H_
M/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"CP_<&AP
M(&5C:&\@)&IS(#\^"@IF=6YC=&EO;B!S96QE8W13;W5R8V4H*0I["B`@("!V
M87(@9B`](&1O8W5M96YT+G!R969S.PH@("`@=F%R(&9I96QD4W1R:6YG(#T@
M)R<["@H@("`@=VAI;&4@*&8N=6YS96QE8W1E9%]C;VQU;6YS+FQE;F=T:"`^
M(#$I('L*("`@("`@("!F+G5N<V5L96-T961?8V]L=6UN<RYO<'1I;VYS6V8N
M=6YS96QE8W1E9%]C;VQU;6YS+FQE;F=T:"`M(#%=(#T@;G5L;#L*("`@('T*
M("`@('=H:6QE("AF+G-E;&5C=&5D7V-O;'5M;G,N;&5N9W1H(#X@,2D@>PH@
M("`@("`@(&8N<V5L96-T961?8V]L=6UN<RYO<'1I;VYS6V8N<V5L96-T961?
M8V]L=6UN<RYL96YG=&@@+2`Q72`](&YU;&P["B`@("!]"@H@("`@:68@*&8N
M<V]U<F-E+G-E;&5C=&5D26YD97@@/"`Q*2!["B`@("`@("`@<F5T=7)N.PH@
M("`@?0H@("`@=F%R('-O=7)C92`](&8N<V]U<F-E+G-E;&5C=&5D26YD97@@
M+2`Q.PH*("`@('9A<B!S96QE8W1E9"`](&YE=R!!<G)A>2@I.PH@("`@=F%R
M('5N<V5L96-T960@/2!N97<@07)R87DH*3L*("`@(&9O<B`H=F%R(&D@/2`Q
M.R!I(#P@8V]L=6UN<UMS;W5R8V5=+FQE;F=T:#L@:2LK*2!["B`@("`@("`@
M:68@*&-O;'5M;G-;<V]U<F-E75MI75LR72D@>PH@("`@("`@("`@("!S96QE
M8W1E9%MC;VQU;6YS6W-O=7)C95U;:5U;,UU=(#T@;F5W($%R<F%Y*&-O;'5M
M;G-;<V]U<F-E75MI75LQ72P@8V]L=6UN<UMS;W5R8V5=6VE=6S!=*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!U;G-E;&5C=&5D6W5N<V5L96-T
M960N;&5N9W1H72`](&YE=R!!<G)A>2AC;VQU;6YS6W-O=7)C95U;:5U;,5TL
M(&-O;'5M;G-;<V]U<F-E75MI75LP72D["B`@("`@("`@?0H@("`@?0H@("`@
M9F]R("AI(#T@,#L@:2`\('-E;&5C=&5D+FQE;F=T:#L@:2LK*2!["B`@("`@
M("`@9BYS96QE8W1E9%]C;VQU;6YS+F]P=&EO;G-;:2`K(#%=(#T@;F5W($]P
M=&EO;BAS96QE8W1E9%MI75LP72P@<V5L96-T961;:5U;,5TI.PH@("`@?0H@
M("`@9F]R("AI(#T@,#L@:2`\('5N<V5L96-T960N;&5N9W1H.R!I*RLI('L*
M("`@("`@("!F+G5N<V5L96-T961?8V]L=6UN<RYO<'1I;VYS6VD@*R`Q72`]
M(&YE=R!/<'1I;VXH=6YS96QE8W1E9%MI75LP72P@=6YS96QE8W1E9%MI75LQ
M72D["B`@("!]"GT*"F9U;F-T:6]N(&1E<V5L96-T2&5A9&5R<R@I"GL*("`@
M(&1O8W5M96YT+G!R969S+G5N<V5L96-T961?8V]L=6UN<ULP72YS96QE8W1E
M9"`](&9A;'-E.PH@("`@9&]C=6UE;G0N<')E9G,N<V5L96-T961?8V]L=6UN
M<ULP72YS96QE8W1E9"`](&9A;'-E.PI]"@IF=6YC=&EO;B!R97-E=$AI9&1E
M;B@I"GL*("`@('9A<B!T;7`@/2`G)SL*("`@(&9O<B`H=F%R(&D@/2`P.R!I
M(#P@8V]L=6UN<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AI(#X@,"D@
M>PH@("`@("`@("`@("!T;7`@*ST@)UQN)SL*("`@("`@("!]"B`@("`@("`@
M=&UP("L](&-O;'5M;G-;:5U;,%T["B`@("`@("`@9F]R("AV87(@:B`](#$[
M(&H@/"!C;VQU;6YS6VE=+FQE;F=T:#L@:BLK*2!["B`@("`@("`@("`@(&EF
M("AC;VQU;6YS6VE=6VI=6S)=*2!["B`@("`@("`@("`@("`@("!T;7`@*ST@
M)UQT)R`K(&-O;'5M;G-;:5U;:EU;,%T["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"B`@("!D;V-U;65N="YP<F5F<RYC;VQU;6YS+G9A;'5E(#T@
M=&UP.PI]"@IF=6YC=&EO;B!A9&1#;VQU;6XH*0I["B`@("!V87(@9B`](&1O
M8W5M96YT+G!R969S.PH@("`@=F%R('-O=7)C92`](&8N<V]U<F-E+G-E;&5C
M=&5D26YD97@@+2`Q.PH*("`@(&9O<B`H:2`](#$[(&D@/"!F+G5N<V5L96-T
M961?8V]L=6UN<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AF+G5N<V5L
M96-T961?8V]L=6UN<UMI72YS96QE8W1E9"D@>PH@("`@("`@("`@("!F;W(@
M*'9A<B!J(#T@,3L@:B`\(&-O;'5M;G-;<V]U<F-E72YL96YG=&@[(&HK*RD@
M>PH@("`@("`@("`@("`@("`@:68@*&-O;'5M;G-;<V]U<F-E75MJ75LP72`]
M/2!F+G5N<V5L96-T961?8V]L=6UN<UMI72YV86QU92D@>PH@("`@("`@("`@
M("`@("`@("`@(&-O;'5M;G-;<V]U<F-E75MJ75LR72`]('1R=64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@9BYS96QE
M8W1E9%]C;VQU;6YS6V8N<V5L96-T961?8V]L=6UN<RYL96YG=&A=(#T@;F5W
M($]P=&EO;BAF+G5N<V5L96-T961?8V]L=6UN<UMI72YT97AT+"!F+G5N<V5L
M96-T961?8V]L=6UN<UMI72YV86QU92D["B`@("`@("`@("`@(&8N=6YS96QE
M8W1E9%]C;VQU;6YS6VE=(#T@;G5L;#L*("`@("`@("`@("`@:2TM.PH@("`@
M("`@('T*("`@('T*"B`@("!R97-E=$AI9&1E;B@I.PI]"@IF=6YC=&EO;B!R
M96UO=F5#;VQU;6XH*0I["B`@("!V87(@9B`](&1O8W5M96YT+G!R969S.PH@
M("`@=F%R('-O=7)C92`](&8N<V]U<F-E+G-E;&5C=&5D26YD97@@+2`Q.PH*
M("`@(&9O<B`H:2`](#$[(&D@/"!F+G-E;&5C=&5D7V-O;'5M;G,N;&5N9W1H
M.R!I*RLI('L*("`@("`@("!I9B`H9BYS96QE8W1E9%]C;VQU;6YS6VE=+G-E
M;&5C=&5D*2!["B`@("`@("`@("`@(&9O<B`H=F%R(&H@/2`Q.R!J(#P@8V]L
M=6UN<UMS;W5R8V5=+FQE;F=T:#L@:BLK*2!["B`@("`@("`@("`@("`@("!I
M9B`H8V]L=6UN<UMS;W5R8V5=6VI=6S!=(#T](&8N<V5L96-T961?8V]L=6UN
M<UMI72YV86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&-O;'5M;G-;<V]U
M<F-E75MJ75LR72`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&8N=6YS96QE8W1E9%]C;VQU;6YS6V8N=6YS
M96QE8W1E9%]C;VQU;6YS+FQE;F=T:%T@/2!N97<@3W!T:6]N*&8N<V5L96-T
M961?8V]L=6UN<UMI72YT97AT+"!F+G-E;&5C=&5D7V-O;'5M;G-;:5TN=F%L
M=64I"B`@("`@("`@("`@(&8N<V5L96-T961?8V]L=6UN<UMI72`](&YU;&P[
M"B`@("`@("`@("`@(&DM+3L*("`@("`@("!]"B`@("!]"@H@("`@<F5S971(
M:61D96XH*3L*?0H*9G5N8W1I;VX@;6]V94-O;'5M;E5P*"D*>PH@("`@=F%R
M(&8@/2!D;V-U;65N="YP<F5F<SL*("`@('9A<B!S96P@/2!F+G-E;&5C=&5D
M7V-O;'5M;G,N<V5L96-T961);F1E>#L*("`@('9A<B!S;W5R8V4@/2!F+G-O
M=7)C92YS96QE8W1E9$EN9&5X("T@,3L*"B`@("!I9B`H<V5L(#P](#$@?'P@
M9BYS96QE8W1E9%]C;VQU;6YS+FQE;F=T:"`\/2`R*2!R971U<FX["@H@("`@
M+R\@9&5S96QE8W0@979E<GET:&EN9R!B=70@=&AE(&9I<G-T('-E;&5C=&5D
M(&ET96T*("`@(&8N<V5L96-T961?8V]L=6UN<RYS96QE8W1E9$EN9&5X(#T@
M<V5L.PH@("`@=F%R('5P(#T@9BYS96QE8W1E9%]C;VQU;6YS6W-E;%TN=F%L
M=64["@H@("`@=&UP(#T@;F5W($%R<F%Y*"D["@H@("`@9F]R("AI(#T@,3L@
M:2`\(&8N<V5L96-T961?8V]L=6UN<RYL96YG=&@[(&DK*RD@>PH@("`@("`@
M('1M<%MI("T@,5T@/2!N97<@3W!T:6]N*&8N<V5L96-T961?8V]L=6UN<UMI
M72YT97AT+"!F+G-E;&5C=&5D7V-O;'5M;G-;:5TN=F%L=64I"B`@("!]"@H@
M("`@9F]R("AI(#T@,#L@:2`\('1M<"YL96YG=&@[(&DK*RD@>PH@("`@("`@
M(&EF("AI("L@,2`]/2!S96P@+2`Q*2!["B`@("`@("`@("`@(&8N<V5L96-T
M961?8V]L=6UN<UMI("L@,5T@/2!T;7!;:2`K(#%=.PH@("`@("`@('T@96QS
M92!I9B`H:2`K(#$@/3T@<V5L*2!["B`@("`@("`@("`@(&8N<V5L96-T961?
M8V]L=6UN<UMI("L@,5T@/2!T;7!;:2`M(#%=.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&8N<V5L96-T961?8V]L=6UN<UMI("L@,5T@/2!T;7!;
M:5T["B`@("`@("`@?0H@("`@?0H*("`@(&8N<V5L96-T961?8V]L=6UN<RYS
M96QE8W1E9$EN9&5X(#T@<V5L("T@,3L*"B`@("!F;W(@*&D@/2`R.R!I(#P@
M8V]L=6UN<UMS;W5R8V5=+FQE;F=T:"`M(#$[(&DK*RD@>PH@("`@("`@(&EF
M("AC;VQU;6YS6W-O=7)C95U;:5U;,%T@/3T@=7`I('L*("`@("`@("`@("`@
M8V]L=6UN(#T@8V]L=6UN<UMS;W5R8V5=6VE=.PH@("`@("`@("`@("!C;VQU
M;6YS6W-O=7)C95U;:5T@/2!C;VQU;6YS6W-O=7)C95U;:2`M(#%=.PH@("`@
M("`@("`@("!C;VQU;6YS6W-O=7)C95U;:2`M(#%=(#T@8V]L=6UN.PH@("`@
M("`@('T*("`@('T*"B`@("!R97-E=$AI9&1E;B@I.PI]"@IF=6YC=&EO;B!M
M;W9E0V]L=6UN1&]W;B@I"GL*("`@('9A<B!F(#T@9&]C=6UE;G0N<')E9G,[
M"B`@("!V87(@<V5L(#T@9BYS96QE8W1E9%]C;VQU;6YS+G-E;&5C=&5D26YD
M97@["B`@("!V87(@<V]U<F-E(#T@9BYS;W5R8V4N<V5L96-T961);F1E>"`M
M(#$["@H@("`@:68@*'-E;"`]/2`M,2!\?"!F+G-E;&5C=&5D7V-O;'5M;G,N
M;&5N9W1H(#P](#(@?'P@<V5L(#T](&8N<V5L96-T961?8V]L=6UN<RYL96YG
M=&@@+2`Q*2!R971U<FX["@H@("`@+R\@9&5S96QE8W0@979E<GET:&EN9R!B
M=70@=&AE(&9I<G-T('-E;&5C=&5D(&ET96T*("`@(&8N<V5L96-T961?8V]L
M=6UN<RYS96QE8W1E9$EN9&5X(#T@<V5L.PH@("`@=F%R(&1O=VX@/2!F+G-E
M;&5C=&5D7V-O;'5M;G-;<V5L72YV86QU93L*"B`@("!T;7`@/2!N97<@07)R
M87DH*3L*"B`@("!F;W(@*&D@/2`Q.R!I(#P@9BYS96QE8W1E9%]C;VQU;6YS
M+FQE;F=T:#L@:2LK*2!["B`@("`@("`@=&UP6VD@+2`Q72`](&YE=R!/<'1I
M;VXH9BYS96QE8W1E9%]C;VQU;6YS6VE=+G1E>'0L(&8N<V5L96-T961?8V]L
M=6UN<UMI72YV86QU92D*("`@('T*"B`@("!F;W(@*&D@/2`P.R!I(#P@=&UP
M+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*&D@*R`Q(#T]('-E;"D@>PH@
M("`@("`@("`@("!F+G-E;&5C=&5D7V-O;'5M;G-;:2`K(#%=(#T@=&UP6VD@
M*R`Q73L*("`@("`@("!](&5L<V4@:68@*&D@*R`Q(#T]('-E;"`K(#$I('L*
M("`@("`@("`@("`@9BYS96QE8W1E9%]C;VQU;6YS6VD@*R`Q72`]('1M<%MI
M("T@,5T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9BYS96QE8W1E
M9%]C;VQU;6YS6VD@*R`Q72`]('1M<%MI73L*("`@("`@("!]"B`@("!]"@H@
M("`@9BYS96QE8W1E9%]C;VQU;6YS+G-E;&5C=&5D26YD97@@/2!S96P@*R`Q
M.PH*("`@(&9O<B`H:2`](&-O;'5M;G-;<V]U<F-E72YL96YG=&@@+2`R.R!I
M(#X@,#L@:2TM*2!["B`@("`@("`@:68@*&-O;'5M;G-;<V]U<F-E75MI75LP
M72`]/2!D;W=N('Q\(&-O;'5M;G-;<V]U<F-E75MI("L@,5U;,%T@/3T@9&]W
M;BD@>PH@("`@("`@("`@("!C;VQU;6X@/2!C;VQU;6YS6W-O=7)C95U;:5T[
M"B`@("`@("`@("`@(&-O;'5M;G-;<V]U<F-E75MI72`](&-O;'5M;G-;<V]U
M<F-E75MI("L@,5T["B`@("`@("`@("`@(&-O;'5M;G-;<V]U<F-E75MI("L@
M,5T@/2!C;VQU;6X["B`@("`@("`@?0H@("`@?0H*("`@(')E<V5T2&ED9&5N
M*"D["GT*"B\O("TM/@H\+W-C<FEP=#X*"CQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](F-O;'5M;G,B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'!R969S+3YG971686QU92@G8V]L=6UN<R<I*2`_/B(@+SX*"CP_
M<&AP(&EF("@D<V]U<F-E7V-O=6YT(#X@,"DZ(#\^"CQD:78^"B`\<V5L96-T
M(&YA;64](G-O=7)C92(@;VYC:&%N9V4](FEF("AD;V-U;65N="YP<F5F<RYS
M;W5R8V4N<V5L96-T961);F1E>"`A/2`P*2!S96QE8W13;W5R8V4H*3LB/#]P
M:'`@:68@*"1S;W5R8V5?8V]U;G0@/3T@,2D@96-H;R`G('-T>6QE/2)D:7-P
M;&%Y.FYO;F4B)R`_/CX*("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@
M7R@B0VAO;W-E(&%N(&%D9')E<W,@8F]O:SHB*2`_/CPO;W!T:6]N/@H@(#P_
M<&AP(&9O<F5A8V@@*"1C9F=3;W5R8V5S(&%S("1K97D@/3X@)&EN9F\I.B`_
M/@H@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D:V5Y*2`_/B(\/W!H<"!I9B`H)'-O=7)C95]C;W5N="`]/2`Q*2!E8VAO
M("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1I;F9O6R=T:71L92==*2`_/CPO;W!T:6]N/@H@(#P_<&AP
M(&5N9&9O<F5A8V@[(#\^"B`\+W-E;&5C=#X*/"]D:78^"@H\/W!H<"!E8VAO
M(%\H(D-H;V]S92!W:&EC:"!C;VQU;6YS('1O(&1I<W!L87D@86YD(&EN('=H
M870@;W)D97(Z(BD@/SX\8G(@+SX*/'1A8FQE/@H@/'1R/@H@(#QT9#X*("`@
M/'-E;&5C="!N86UE/2)U;G-E;&5C=&5D7V-O;'5M;G,B(&UU;'1I<&QE/2)M
M=6QT:7!L92(@<VEZ93TB-2(@<W1Y;&4](G=I9'1H.C,P,'!X(B!O;F-H86YG
M93TB9&5S96QE8W1(96%D97)S*"D[(CX*("`@(#QO<'1I;VX@8VQA<W,](F-O
M;G1R;VPB('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B0V]L=6UN<R!T:&%T('=I
M;&P@;F]T(&)E(&1I<W!L87EE9#HB*2`_/CPO;W!T:6]N/@H@("`\+W-E;&5C
M=#X*("`\+W1D/@H@(#QT9#X*("`@/&$@:')E9CTB(R(@;VYC;&EC:STB861D
M0V]L=6UN*"D[(')E='5R;B!F86QS93LB/CP_<&AP(&5C:&\@2&]R9&4Z.FEM
M9RAI<W-E="@D1TQ/0D%,4ULG;FQS)UU;)W)T;"==6R1'3$]"04Q36R=L86YG
M=6%G92==72D@/R`G;&AA;F0N<&YG)R`Z("=R:&%N9"YP;F<G+"!?*")!9&0@
M8V]L=6UN(BDL(&YU;&PL("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI(#\^/"]A/@H@("`\8G(@+SX*("`@/&$@:')E9CTB(R(@;VYC;&EC:STB
M<F5M;W9E0V]L=6UN*"D[(')E='5R;B!F86QS93LB/CP_<&AP(&5C:&\@2&]R
M9&4Z.FEM9RAI<W-E="@D1TQ/0D%,4ULG;FQS)UU;)W)T;"==6R1'3$]"04Q3
M6R=L86YG=6%G92==72D@/R`G<FAA;F0N<&YG)R`Z("=L:&%N9"YP;F<G+"!?
M*")296UO=F4@8V]L=6UN(BDL(&YU;&PL("1R96=I<W1R>2T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI(#\^/"]A/@H@(#PO=&0^"B`@/'1D/@H@("`\<V5L96-T
M(&YA;64](G-E;&5C=&5D7V-O;'5M;G,B(&UU;'1I<&QE/2)M=6QT:7!L92(@
M<VEZ93TB-2(@<W1Y;&4](G=I9'1H.C,P,'!X(B!O;F-H86YG93TB9&5S96QE
M8W1(96%D97)S*"D[(CX*("`@(#QO<'1I;VX@8VQA<W,](F-O;G1R;VPB('9A
M;'5E/2(B/CP_<&AP(&5C:&\@7R@B5&AE<V4@8V]L=6UN<R!W:6QL(&1I<W!L
M87D@:6X@=&AI<R!O<F1E<CHB*2`_/CPO;W!T:6]N/@H@("`\+W-E;&5C=#X*
M("`\+W1D/@H@(#QT9#X*("`@/&$@:')E9CTB(R(@;VYC;&EC:STB;6]V94-O
M;'5M;E5P*"D[(')E='5R;B!F86QS93LB/CP_<&AP(&5C:&\@2&]R9&4Z.FEM
M9R@G;F%V+W5P+G!N9R<L(%\H(DUO=F4@;&5F="(I+"!N=6QL+"`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*("`@/&)R("\^"B`@
M(#QA(&AR968](B,B(&]N8VQI8VL](FUO=F5#;VQU;6Y$;W=N*"D[(')E='5R
M;B!F86QS93LB/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G;F%V+V1O=VXN<&YG
M)RP@7R@B36]V92!R:6=H="(I+"!N=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E
M1&ER*"=H;W)D92<I*2`_/CPO83X*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*
M"CP_<&AP(&EF("@D<V]U<F-E7V-O=6YT(#T](#$I.B`_/@H\<V-R:7!T('1Y
M<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*<V5L96-T4V]U<F-E*"D["B\O
M("TM/@H\+W-C<FEP=#X*/#]P:'`*96YD:68[("\O($5N9"!A=71O;6%T:6,@
M<V]U<F-E('-E;&5C=&EO;BX*96YD:68[("\O($5N9"!F;W)M(&5L96UE;G1S
M('=H96X@870@;&5A<W0@,2!S;W5R8V4N"F5N9&EF.R`O+R!%;F0@<')E9G,@
M54D@:68@;F]T(&QO8VME9"X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W1E;7!L
M871E<R]P<F5F<R]A9&1R97-S8F]O:W-E;&5C="YI;F,`````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,30W,38`,3`T,3<S-C(W-38`,#(U,#8R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HD;W)D97(@/2!4=7)B
M83HZ9V5T061D<F5S<T)O;VM/<F1E<B@I.PHD:G,@/2`B=F%R(&%D9')E<W-B
M;V]K<R`](&YE=R!!<G)A>2@I.UQN(CL*)'-O=7)C95]C;W5N="`](#`["F9O
M<F5A8V@@*"1'3$]"04Q36R=C9F=3;W5R8V5S)UT@87,@)'-O=7)C92`]/B`D
M:6YF;RD@>PH@("`@)'-E;&5C=&5D(#T@:7-S970H)&]R9&5R6R1S;W5R8V5=
M*2`_("=T<G5E)R`Z("=F86QS92<["B`@("`D:G,@+CT@(F%D9')E<W-B;V]K
M<ULD<V]U<F-E7V-O=6YT72`](%LG(B`N(&%D9'-L87-H97,H)'-O=7)C92D@
M+B`B)RP@9&5C;V1E55))0V]M<&]N96YT*"<B("X@<F%W=7)L96YC;V1E*"1I
M;F9O6R=T:71L92==*2`N("(G*2P@)'-E;&5C=&5D+"`B("X@*&ES<V5T*"1O
M<F1E<ELD<V]U<F-E72D@/R`H:6YT*21O<F1E<ELD<V]U<F-E72`Z("=N=6QL
M)RD@+B`B73M<;B(["B`@("`D<V]U<F-E7V-O=6YT*RL["GT*"FEF("@A)'!R
M969S+3YI<TQO8VME9"@G861D<F5S<V)O;VMS)RD@)B8@)'-O=7)C95]C;W5N
M="DZ"C\^"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*
M/#]P:'`@96-H;R`D:G,@/SX*"F9U;F-T:6]N('-E;&5C=$%D9')E<W-";V]K
M<R@I"GL*("`@('9A<B!S96QE8W1E9"`](&YE=R!!<G)A>2@I.PH@("`@=F%R
M('5N<V5L96-T960@/2!N97<@07)R87DH*3L*("`@(&9O<B`H=F%R(&D@/2`P
M.R!I(#P@861D<F5S<V)O;VMS+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@
M*&%D9')E<W-B;V]K<UMI75LR72D@>PH@("`@("`@("`@("!S96QE8W1E9%MA
M9&1R97-S8F]O:W-;:5U;,UU=(#T@;F5W($%R<F%Y*&%D9')E<W-B;V]K<UMI
M75LQ72P@861D<F5S<V)O;VMS6VE=6S!=*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!U;G-E;&5C=&5D6W5N<V5L96-T960N;&5N9W1H72`](&YE
M=R!!<G)A>2AA9&1R97-S8F]O:W-;:5U;,5TL(&%D9')E<W-B;V]K<UMI75LP
M72D["B`@("`@("`@?0H@("`@?0H@("`@9F]R("AI(#T@,#L@:2`\('-E;&5C
M=&5D+FQE;F=T:#L@:2LK*2!["B`@("`@("`@9BYS96QE8W1E9%]A9&1R97-S
M8F]O:W,N;W!T:6]N<UMI("L@,5T@/2!N97<@3W!T:6]N*'-E;&5C=&5D6VE=
M6S!=+"!S96QE8W1E9%MI75LQ72D["B`@("!]"B`@("!F;W(@*&D@/2`P.R!I
M(#P@=6YS96QE8W1E9"YL96YG=&@[(&DK*RD@>PH@("`@("`@(&8N=6YS96QE
M8W1E9%]A9&1R97-S8F]O:W,N;W!T:6]N<UMI("L@,5T@/2!N97<@3W!T:6]N
M*'5N<V5L96-T961;:5U;,%TL('5N<V5L96-T961;:5U;,5TI.PH@("`@?0I]
M"@IF=6YC=&EO;B!D97-E;&5C=$AE861E<G,H*0I["B`@("!D;V-U;65N="YP
M<F5F<RYU;G-E;&5C=&5D7V%D9')E<W-B;V]K<ULP72YS96QE8W1E9"`](&9A
M;'-E.PH@("`@9&]C=6UE;G0N<')E9G,N<V5L96-T961?861D<F5S<V)O;VMS
M6S!=+G-E;&5C=&5D(#T@9F%L<V4["GT*"F9U;F-T:6]N(')E<V5T2&ED9&5N
M*"D*>PH@("`@=F%R('1M<"`]("<G.PH@("`@9F]R("AV87(@:2`](#$[(&D@
M/"!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<RYL96YG=&@[(&DK*RD@>PH@("`@
M("`@(&EF("AT;7`@(3T@)R<I('L*("`@("`@("`@("`@=&UP("L]("=<;B<[
M"B`@("`@("`@?0H@("`@("`@('1M<"`K/2!F+G-E;&5C=&5D7V%D9')E<W-B
M;V]K<UMI72YV86QU93L*("`@('T*("`@(&1O8W5M96YT+G!R969S+F%D9')E
M<W-B;V]K<RYV86QU92`]('1M<#L*?0H*9G5N8W1I;VX@861D061D<F5S<T)O
M;VLH*0I["B`@("!F;W(@*&D@/2`Q.R!I(#P@9BYU;G-E;&5C=&5D7V%D9')E
M<W-B;V]K<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AF+G5N<V5L96-T
M961?861D<F5S<V)O;VMS6VE=+G-E;&5C=&5D*2!["B`@("`@("`@("`@(&8N
M<V5L96-T961?861D<F5S<V)O;VMS6V8N<V5L96-T961?861D<F5S<V)O;VMS
M+FQE;F=T:%T@/2!N97<@3W!T:6]N*&8N=6YS96QE8W1E9%]A9&1R97-S8F]O
M:W-;:5TN=&5X="P@9BYU;G-E;&5C=&5D7V%D9')E<W-B;V]K<UMI72YV86QU
M92D["B`@("`@("`@("`@(&8N=6YS96QE8W1E9%]A9&1R97-S8F]O:W-;:5T@
M/2!N=6QL.PH@("`@("`@("`@("!I+2T["B`@("`@("`@?0H@("`@?0H*("`@
M(')E<V5T2&ED9&5N*"D["GT*"F9U;F-T:6]N(')E;6]V94%D9')E<W-";V]K
M*"D*>PH@("`@9F]R("AI(#T@,3L@:2`\(&8N<V5L96-T961?861D<F5S<V)O
M;VMS+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*&8N<V5L96-T961?861D
M<F5S<V)O;VMS6VE=+G-E;&5C=&5D*2!["B`@("`@("`@("`@(&8N=6YS96QE
M8W1E9%]A9&1R97-S8F]O:W-;9BYU;G-E;&5C=&5D7V%D9')E<W-B;V]K<RYL
M96YG=&A=(#T@;F5W($]P=&EO;BAF+G-E;&5C=&5D7V%D9')E<W-B;V]K<UMI
M72YT97AT+"!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<UMI72YV86QU92D*("`@
M("`@("`@("`@9BYS96QE8W1E9%]A9&1R97-S8F]O:W-;:5T@/2!N=6QL.PH@
M("`@("`@("`@("!I+2T["B`@("`@("`@?0H@("`@?0H*("`@(')E<V5T2&ED
M9&5N*"D["GT*"F9U;F-T:6]N(&UO=F5!9&1R97-S0F]O:U5P*"D*>PH@("`@
M=F%R('-E;"`](&8N<V5L96-T961?861D<F5S<V)O;VMS+G-E;&5C=&5D26YD
M97@["@H@("`@:68@*'-E;"`\/2`Q('Q\(&8N<V5L96-T961?861D<F5S<V)O
M;VMS+FQE;F=T:"`\/2`R*2!R971U<FX["@H@("`@+R\@9&5S96QE8W0@979E
M<GET:&EN9R!B=70@=&AE(&9I<G-T('-E;&5C=&5D(&ET96T*("`@(&8N<V5L
M96-T961?861D<F5S<V)O;VMS+G-E;&5C=&5D26YD97@@/2!S96P["B`@("!V
M87(@=7`@/2!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<UMS96Q=+G9A;'5E.PH*
M("`@('1M<"`](&YE=R!!<G)A>2@I.PH*("`@(&9O<B`H:2`](#$[(&D@/"!F
M+G-E;&5C=&5D7V%D9')E<W-B;V]K<RYL96YG=&@[(&DK*RD@>PH@("`@("`@
M('1M<%MI("T@,5T@/2!N97<@3W!T:6]N*&8N<V5L96-T961?861D<F5S<V)O
M;VMS6VE=+G1E>'0L(&8N<V5L96-T961?861D<F5S<V)O;VMS6VE=+G9A;'5E
M*0H@("`@?0H*("`@(&9O<B`H:2`](#`[(&D@/"!T;7`N;&5N9W1H.R!I*RLI
M('L*("`@("`@("!I9B`H:2`K(#$@/3T@<V5L("T@,2D@>PH@("`@("`@("`@
M("!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<UMI("L@,5T@/2!T;7!;:2`K(#%=
M.PH@("`@("`@('T@96QS92!I9B`H:2`K(#$@/3T@<V5L*2!["B`@("`@("`@
M("`@(&8N<V5L96-T961?861D<F5S<V)O;VMS6VD@*R`Q72`]('1M<%MI("T@
M,5T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9BYS96QE8W1E9%]A
M9&1R97-S8F]O:W-;:2`K(#%=(#T@=&UP6VE=.PH@("`@("`@('T*("`@('T*
M"B`@("!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<RYS96QE8W1E9$EN9&5X(#T@
M<V5L("T@,3L*"B`@("!F;W(@*&D@/2`R.R!I(#P@861D<F5S<V)O;VMS+FQE
M;F=T:"`M(#$[(&DK*RD@>PH@("`@("`@(&EF("AA9&1R97-S8F]O:W-;:5U;
M,%T@/3T@=7`I('L*("`@("`@("`@("`@861D<F5S<V)O;VL@/2!A9&1R97-S
M8F]O:W-;:5T["B`@("`@("`@("`@(&%D9')E<W-B;V]K<UMI72`](&%D9')E
M<W-B;V]K<UMI("T@,5T["B`@("`@("`@("`@(&%D9')E<W-B;V]K<UMI("T@
M,5T@/2!A9&1R97-S8F]O:SL*("`@("`@("!]"B`@("!]"@H@("`@<F5S971(
M:61D96XH*3L*?0H*9G5N8W1I;VX@;6]V94%D9')E<W-";V]K1&]W;B@I"GL*
M("`@('9A<B!S96P@/2!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<RYS96QE8W1E
M9$EN9&5X.PH*("`@(&EF("AS96P@/3T@+3$@?'P@9BYS96QE8W1E9%]A9&1R
M97-S8F]O:W,N;&5N9W1H(#P](#(@?'P@<V5L(#T](&8N<V5L96-T961?861D
M<F5S<V)O;VMS+FQE;F=T:"`M(#$I(')E='5R;CL*"B`@("`O+R!D97-E;&5C
M="!E=F5R>71H:6YG(&)U="!T:&4@9FER<W0@<V5L96-T960@:71E;0H@("`@
M9BYS96QE8W1E9%]A9&1R97-S8F]O:W,N<V5L96-T961);F1E>"`]('-E;#L*
M("`@('9A<B!D;W=N(#T@9BYS96QE8W1E9%]A9&1R97-S8F]O:W-;<V5L72YV
M86QU93L*"B`@("!T;7`@/2!N97<@07)R87DH*3L*"B`@("!F;W(@*&D@/2`Q
M.R!I(#P@9BYS96QE8W1E9%]A9&1R97-S8F]O:W,N;&5N9W1H.R!I*RLI('L*
M("`@("`@("!T;7!;:2`M(#%=(#T@;F5W($]P=&EO;BAF+G-E;&5C=&5D7V%D
M9')E<W-B;V]K<UMI72YT97AT+"!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<UMI
M72YV86QU92D*("`@('T*"B`@("!F;W(@*&D@/2`P.R!I(#P@=&UP+FQE;F=T
M:#L@:2LK*2!["B`@("`@("`@:68@*&D@*R`Q(#T]('-E;"D@>PH@("`@("`@
M("`@("!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<UMI("L@,5T@/2!T;7!;:2`K
M(#%=.PH@("`@("`@('T@96QS92!I9B`H:2`K(#$@/3T@<V5L("L@,2D@>PH@
M("`@("`@("`@("!F+G-E;&5C=&5D7V%D9')E<W-B;V]K<UMI("L@,5T@/2!T
M;7!;:2`M(#%=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&8N<V5L
M96-T961?861D<F5S<V)O;VMS6VD@*R`Q72`]('1M<%MI73L*("`@("`@("!]
M"B`@("!]"@H@("`@9BYS96QE8W1E9%]A9&1R97-S8F]O:W,N<V5L96-T961)
M;F1E>"`]('-E;"`K(#$["@H@("`@9F]R("AI(#T@861D<F5S<V)O;VMS+FQE
M;F=T:"`M(#([(&D@/B`P.R!I+2TI('L*("`@("`@("!I9B`H861D<F5S<V)O
M;VMS6VE=6S!=(#T](&1O=VX@?'P@861D<F5S<V)O;VMS6VD@*R`Q75LP72`]
M/2!D;W=N*2!["B`@("`@("`@("`@(&%D9')E<W-B;V]K(#T@861D<F5S<V)O
M;VMS6VE=.PH@("`@("`@("`@("!A9&1R97-S8F]O:W-;:5T@/2!A9&1R97-S
M8F]O:W-;:2`K(#%=.PH@("`@("`@("`@("!A9&1R97-S8F]O:W-;:2`K(#%=
M(#T@861D<F5S<V)O;VL["B`@("`@("`@?0H@("`@?0H*("`@(')E<V5T2&ED
M9&5N*"D["GT*"B\O("TM/@H\+W-C<FEP=#X*"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F%D9')E<W-B;V]K<R(@=F%L=64](CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D<')E9G,M/F=E=%9A;'5E*"=A9&1R97-S8F]O:W,G
M*2D@/SXB("\^"@H\/W!H<"!E8VAO(%\H(D-H;V]S92!W:&EC:"!A9&1R97-S
M(&)O;VMS('1O(&1I<W!L87DL(&%N9"!I;B!W:&%T(&]R9&5R.B(I(#\^/&)R
M("\^"CQT86)L93X*(#QT<CX*("`\=&0^"B`@(#QS96QE8W0@;F%M93TB=6YS
M96QE8W1E9%]A9&1R97-S8F]O:W,B(&UU;'1I<&QE/2)M=6QT:7!L92(@<VEZ
M93TB-2(@<W1Y;&4](G=I9'1H.C,P,'!X(B!O;F-H86YG93TB9&5S96QE8W1(
M96%D97)S*"D[(CX*("`@(#QO<'1I;VX@8VQA<W,](F-O;G1R;VPB('9A;'5E
M/2(B/CP_<&AP(&5C:&\@7R@B061D<F5S<R!B;V]K<R!T:&%T('=I;&P@;F]T
M(&)E(&1I<W!L87EE9#HB*2`_/CPO;W!T:6]N/@H@("`\+W-E;&5C=#X*("`\
M+W1D/@H@(#QT9#X*("`@/&$@:')E9CTB(R(@;VYC;&EC:STB861D061D<F5S
M<T)O;VLH*3L@<F5T=7)N(&9A;'-E.R(^/#]P:'`@96-H;R!(;W)D93HZ:6UG
M*&ES<V5T*"1'3$]"04Q36R=N;',G75LG<G1L)UU;)$=,3T)!3%-;)VQA;F=U
M86=E)UU=*2`_("=L:&%N9"YP;F<G(#H@)W)H86YD+G!N9R<L(%\H(D%D9"!A
M9&1R97-S(&)O;VLB*2P@;G5L;"P@)')E9VES=')Y+3YG971);6%G941I<B@G
M:&]R9&4G*2D@/SX\+V$^"B`@(#QB<B`O/@H@("`\82!H<F5F/2(C(B!O;F-L
M:6-K/2)R96UO=F5!9&1R97-S0F]O:R@I.R!R971U<FX@9F%L<V4[(CX\/W!H
M<"!E8VAO($AO<F1E.CII;6<H:7-S970H)$=,3T)!3%-;)VYL<R==6R=R=&PG
M75LD1TQ/0D%,4ULG;&%N9W5A9V4G75TI(#\@)W)H86YD+G!N9R<@.B`G;&AA
M;F0N<&YG)RP@7R@B4F5M;W9E(&%D9')E<W,@8F]O:R(I+"!N=6QL+"`D<F5G
M:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*("`\+W1D/@H@
M(#QT9#X*("`@/'-E;&5C="!N86UE/2)S96QE8W1E9%]A9&1R97-S8F]O:W,B
M(&UU;'1I<&QE/2)M=6QT:7!L92(@<VEZ93TB-2(@<W1Y;&4](G=I9'1H.C,P
M,'!X(B!O;F-H86YG93TB9&5S96QE8W1(96%D97)S*"D[(CX*("`@(#QO<'1I
M;VX@8VQA<W,](F-O;G1R;VPB('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B5&AE
M<V4@861D<F5S<R!B;V]K<R!W:6QL(&1I<W!L87D@:6X@=&AI<R!O<F1E<CHB
M*2`_/CPO;W!T:6]N/@H@("`\+W-E;&5C=#X*("`\+W1D/@H@(#QT9#X*("`@
M/&$@:')E9CTB(R(@;VYC;&EC:STB;6]V94%D9')E<W-";V]K57`H*3L@<F5T
M=7)N(&9A;'-E.R(^/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=N878O=7`N<&YG
M)RP@7R@B36]V92!L969T(BDL(&YU;&PL("1R96=I<W1R>2T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI(#\^/"]A/@H@("`\8G(@+SX*("`@/&$@:')E9CTB(R(@
M;VYC;&EC:STB;6]V94%D9')E<W-";V]K1&]W;B@I.R!R971U<FX@9F%L<V4[
M(CX\/W!H<"!E8VAO($AO<F1E.CII;6<H)VYA=B]D;W=N+G!N9R<L(%\H(DUO
M=F4@<FEG:'0B*2P@;G5L;"P@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2D@/SX\+V$^"B`@/"]T9#X*(#PO='(^"CPO=&%B;&4^"CQS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0IV87(@9B`](&1O8W5M96YT
M+G!R969S.PIS96QE8W1!9&1R97-S0F]O:W,H*3L*+R\@+2T^"CPO<V-R:7!T
M/@H*/#]P:'`@96YD:68[("\O($5N9"!I9B!N;W0@;&]C:V5D("8F(&%D9')E
M<W,@8F]O:W,@97AI<W0N"@``````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T=7)B82]T96UP;&%T97,O<')E9G,O:6US<%]O<'0N:6YC````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-3(R`#$P-#$W,S8R-S4V`#`R,S(P-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M:68@*"$D<')E9G,M/FES3&]C:V5D*"=I;7-P7V]P="<I*3H*("`@(&=L;V)A
M;"`D8V9G4V]U<F-E<SL*("`@("1S;W5R8V5?8V]U;G0@/2`P.PH@("`@)&EM
M<W!?<V]U8V5S(#T@87)R87DH*3L*"B`@("!F;W)E86-H("@D8V9G4V]U<F-E
M<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@(&EF("@H)'9A;'5E6R=T
M>7!E)UT@/3T@)VEM<W`G*2`F)B`H(21V86QU95LG<&%R86US)UU;)VES7W)O
M;W0G72D@)B8*("`@("`@("`@("`@*'-T<G!O<R@D=F%L=65;)W!A<F%M<R==
M6R=M>5]R:6=H=',G72P@)V0G*2`A/2!F86QS92DI('L*("`@("`@("`@("`@
M)'-O=7)C95]C;W5N="LK.PH@("`@("`@("`@("`D:6US<%]S;W5R8V5S6R1K
M97E=(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"C\^"CQS8W)I<'0@='EP
M93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO;B!S:&]W06QE<G0H
M*0I["B`@("!I9B`H9&]C=6UE;G0N<')E9G,N:6US<%]B;V]K<U]D96QE=&4N
M=F%L=64@(3T@)VYO;F4G*2!["B`@("`@("`@=VEN9&]W+F%L97)T*"<\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B3VYC92!Y;W4@<V%V92!T:&ES(&]P=&EO
M;B!P86=E+"!T:&4@861D<F5S<R!B;V]K('=I;&P@8F4@<&5R;6%N96YT;'D@
M9&5L971E9"X@268@=&AI<R!I<R!N;W0@=VAA="!Y;W4@=V%N="P@=&AE;B!Y
M;W4@;75S="!C:&%N9V4@>6]U<B!S96QE8W1I;VX@=&\@7").;VYE7"(N(BDI
M(#\^)RD["B`@("!]"GT*+R\M+3X*/"]S8W)I<'0^"CQT86)L93X*(#QT<CX*
M("`\=&0^/#]P:'`@96-H;RA?*"(@1&5L971E($E-4U`@061D<F5S<R!";V]K
M(BDI(#\^/"]T9#X*("`\=&0^"B`@(#QS96QE8W0@;F%M93TB:6US<%]B;V]K
M<U]D96QE=&4B('-T>6QE/2)W:61T:#HR,#!P>"(@;VYC:&%N9V4](G-H;W=!
M;&5R="@I.R(^"B`@("`\;W!T:6]N('9A;'5E/2)N;VYE(CX\/W!H<"!E8VAO
M(%\H(FYO;F4B*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@9F]R96%C:"`H)&EM
M<W!?<V]U<F-E<R!A<R`D:V5Y(#T^("1V86QU92DZ(#\^"B`@("`\;W!T:6]N
M('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB
M/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=F%L=65;)W1I=&QE)UTI
M(#\^/"]O<'1I;VX^"B`@("`\/W!H<"!E;F1F;W)E86-H(#\^"B`@(#PO<V5L
M96-T/@H@(#PO=&0^"B`\+W1R/@H@/'1R/@H@(#QT9#X\/W!H<"!E8VAO*%\H
M(B!!9&0@86X@24U34"!!9&1R97-S($)O;VLB*2D@/SX\+W1D/@H@(#QT9#X\
M:6YP=70@;F%M93TB:6US<%]N86UE(B!T>7!E/2)T97AT(B!S='EL93TB=VED
M=&@Z,C`P<'@B("\^/"]T9#X*(#PO='(^"CPO=&%B;&4^"CP_<&AP(&5N9&EF
M.R`_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W1E;7!L871E<R]D871A
M+P``````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-38`,#(P-#4S`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R
M8F$O=&5M<&QA=&5S+V1A=&$O:6UP;W)T+FEN8P``````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-#,U,``Q,#0Q-S,V,C<U-@`P,C(T-3<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&9O<FT@;65T:&]D
M/2)P;W-T(B!N86UE/2)I;7!O<G1?9F]R;2(@96YC='EP93TB;75L=&EP87)T
M+V9O<FTM9&%T82(@86-T:6]N/2)D871A+G!H<"(^"CP_<&AP(%5T:6PZ.G!F
M;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I
M;VY)1"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;F5X
M=%]S=&5P*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP
M;W)T7W-T97`B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&EM<&]R=%]S=&5P
M(#\^(B`O/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F*%\H
M(DEM<&]R="!!9&1R97-S($)O;VLL(%-T97`@)60B*2P@*&EN="DD:6UP;W)T
M7W-T97`I(#\^"CPO:#$^"@H\9&EV(&-L87-S/2)I=&5M(CX*(#QL86)E;"!F
M;W(](FEM<&]R=%]F;W)M870B/CP_<&AP(&5C:&\@7R@B4V5L96-T('1H92!F
M;W)M870@;V8@=&AE('-O=7)C92!F:6QE.B(I(#\^/"]L86)E;#X\8G(@+SX*
M(#QS96QE8W0@;F%M93TB:6UP;W)T7V9O<FUA="(@:60](FEM<&]R=%]F;W)M
M870B/@H@(#QO<'1I;VX@=F%L=64](F-S=B(^/#]P:'`@96-H;R!?*")#;VUM
M82!S97!A<F%T960@=F%L=65S(BD@/SX\+V]P=&EO;CX*("`\;W!T:6]N('9A
M;'5E/2)T<W8B/CP_<&AP(&5C:&\@7R@B5&%B('-E<&%R871E9"!V86QU97,B
M*2`_/CPO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](G9C87)D(CX\/W!H<"!E
M8VAO(%\H(G9#87)D(BD@/SX\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)M
M=6QB97)R>2(^/#]P:'`@96-H;R!?*")-=6QB97)R>2!!9&1R97-S($)O;VLB
M*2`_/CPO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](G!I;F4B/CP_<&AP(&5C
M:&\@7R@B4&EN92!!9&1R97-S($)O;VLB*2`_/CPO;W!T:6]N/@H@/"]S96QE
M8W0^/&)R("\^"@H@/&EN<'5T('1Y<&4](F-H96-K8F]X(B!A;&EG;CTB;6ED
M9&QE(B!N86UE/2)P=7)G92(@:60](G!U<F=E(B!V86QU93TB,2(@+SX*(#QL
M86)E;"!F;W(](G!U<F=E(CX\/W!H<"!E8VAO(%\H(E)E<&QA8V4@97AI<W1I
M;F<@861D<F5S<R!B;V]K('=I=&@@=&AE(&EM<&]R=&5D(&]N93\@/'-T<F]N
M9SY787)N:6YG.B!4:&ES(&1E;&5T97,@86QL(&5N=')I97,@:6X@>6]U<B!C
M=7)R96YT(&%D9')E<W,@8F]O:RX\+W-T<F]N9SXB*2`_/CPO;&%B96P^"B`\
M8G(@+SX*"CP_<&AP(&EF("AC;W5N="@D9&5S=%]O<'1I;VYS*2`^(#$I.B`_
M/@H@/&)R("\^"B`\;&%B96P@9F]R/2)D97-T(CX\/W!H<"!E8VAO(%\H(E-E
M;&5C="!T:&4@861D<F5S<R!B;V]K('1O(&EM<&]R="!T;SHB*2`_/CPO;&%B
M96P^/&)R("\^"B`\<V5L96-T(&YA;64](F1E<W0B(&ED/2)D97-T(CX*("`\
M/W!H<"!E8VAO(&EM<&QO9&4H)R<L("1D97-T7V]P=&EO;G,I(#\^"B`\+W-E
M;&5C=#X\8G(@+SX*/#]P:'`@96QS93H@/SX*(#QI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F1E<W0B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'5N:7%U95]D97-T*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^"B`\
M8G(@+SX*"B`\;&%B96P@9F]R/2)C:&%R<V5T(CX\/W!H<"!E8VAO(%\H(E-E
M;&5C="!T:&4@8VAA<G-E="!O9B!T:&4@<V]U<F-E(&9I;&4Z(BD@/SX\+VQA
M8F5L/CQB<B`O/@H@/'-E;&5C="!N86UE/2)C:&%R<V5T(B!I9#TB8VAA<G-E
M="(@<W1Y;&4](F1I<F5C=&EO;CH@;'1R(CX*/#]P:'`@9F]R96%C:"`H)&-H
M87)S971S(&%S("1C:&%R<V5T(#T^("1C:&%R<V5T7VYA;64I.B`_/@H@(#QO
M<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8VAA
M<G-E="D@/SXB/#]P:'`@:68@*"1C:&%R<V5T(#T]("1M>5]C:&%R<V5T*2!E
M8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1C:&%R<V5T7VYA;64I(#\^/"]O<'1I;VX^"CP_<&AP
M(&5N9&9O<F5A8V@[(#\^"B`\+W-E;&5C=#X*(#QB<B`O/CQB<B`O/@H*(#QL
M86)E;"!F;W(](FEM<&]R=%]F:6QE(CX\/W!H<"!E8VAO(%\H(E-E;&5C="!T
M:&4@9FEL92!T;R!I;7!O<G0Z(BD@/SX\+VQA8F5L/CQB<B`O/@H@/&EN<'5T
M('1Y<&4](F9I;&4B(&YA;64](FEM<&]R=%]F:6QE(B!I9#TB:6UP;W)T7V9I
M;&4B(&-L87-S/2)F:7AE9"(@<VEZ93TB-#`B("\^/&)R("\^/&)R("\^"B`\
M:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*").97AT
M(BD@/SXB(&-L87-S/2)B=71T;VXB("\^"CPO9&EV/@H\+V9O<FT^"@H\8G(@
M8VQA<W,](G-P86-E<B(@+SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O=&5M<&QA=&5S+V1A=&$O97AP;W)T+FEN8P``````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8U-``Q,#0Q-S,V,C<U-@`P,C(T
M-S0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)E>'!O<G0B(&%C=&EO;CTB/#]P
M:'`@96-H;R!(;W)D93HZ9&]W;FQO8615<FPH7R@B8V]N=&%C=',N8W-V(BDL
M(&YU;&PL($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9&%T82YP:'`G*2D@/SXB
M/@H\/W!H<"!E8VAO(%5T:6PZ.F9O<FU);G!U="@I(#\^"CQI;G!U="!T>7!E
M/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB97AP;W)T(B`O/@H*
M/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")%>'!O<G0@061D
M<F5S<R!";V]K(BD@/SX*/"]H,3X*"CQD:78@8VQA<W,](FET96TB/@H@/&QA
M8F5L(&9O<CTB97AP;W)T240B/CP_<&AP(&5C:&\@7R@B4V5L96-T('1H92!E
M>'!O<G0@9F]R;6%T.B(I(#\^/"]L86)E;#X\8G(@+SX*(#QS96QE8W0@;F%M
M93TB97AP;W)T240B(&ED/2)E>'!O<G1)1"(^"B`@/&]P=&EO;B!V86QU93TB
M/#]P:'`@96-H;R!%6%!/4E1?0U-6(#\^(CX\/W!H<"!E8VAO(%\H(D-O;6UA
M('-E<&%R871E9"!V86QU97,B*2`_/CPO;W!T:6]N/@H@(#QO<'1I;VX@=F%L
M=64](CP_<&AP(&5C:&\@15A03U)47T]55$Q/3TM#4U8@/SXB/CP_<&AP(&5C
M:&\@7R@B0V]M;6$@<V5P87)A=&5D('9A;'5E<R`H36EC<F]S;V9T($]U=&QO
M;VLI(BD@/SX\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO
M($584$]25%]44U8@/SXB/CP_<&AP(&5C:&\@7R@B5&%B('-E<&%R871E9"!V
M86QU97,B*2`_/CPO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C
M:&\@15A03U)47U9#05)$(#\^(CX\/W!H<"!E8VAO(%\H(G9#87)D(BD@/SX\
M+V]P=&EO;CX*(#PO<V5L96-T/CQB<B`O/@H*/#]P:'`@:68@*"1A8W1I;VY)
M1"`]/2`G<V5L96-T)R`F)B!5=&EL.CIG971&;W)M1&%T82@G;V)J96-T:V5Y
M<R<I*3H@/SX*(#QB<B`O/@H@/&EN<'5T('1Y<&4](G)A9&EO(B!N86UE/2)S
M96QE8W1E9"(@:60](G-E;&5C=&5D,2(@=F%L=64](C$B(&-H96-K960](F-H
M96-K960B("\^"B`\;&%B96P@9F]R/2)S96QE8W1E9#$B/CP_<&AP(&5C:&\@
M7R@B17AP;W)T(&]N;'D@=&AE('-E;&5C=&5D(&-O;G1A8W1S+B(I(#\^/"]L
M86)E;#X*/#]P:'`@9F]R96%C:"`H571I;#HZ9V5T1F]R;41A=&$H)V]B:F5C
M=&ME>7,G*2!A<R`D:V5Y(#T^("1V86QU92DZ(#\^"B`\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)O8FIE8W1K97ES6SP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D:V5Y*2`_/ETB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'9A;'5E*2`_/B(@+SX*/#]P:'`@96YD9F]R96%C:#L@/SX*
M(#QB<B`O/@H@/&EN<'5T('1Y<&4](G)A9&EO(B!N86UE/2)S96QE8W1E9"(@
M:60](G-E;&5C=&5D,"(@=F%L=64](C`B("\^"B`\;&%B96P@9F]R/2)S96QE
M8W1E9#`B/CP_<&AP(&5C:&\@7R@B17AP;W)T('1H92!F;VQL;W=I;F<@861D
M<F5S<R!B;V]K(&-O;7!L971E;'DN(BD@/SX\+VQA8F5L/@H@/&)R("\^"CP_
M<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H8V]U;G0H)'-O=7)C95]O<'1I;VYS
M*2`^(#$I.B`_/@H@/&)R("\^"B`\;&%B96P@9F]R/2)S;W5R8V4B/CP_<&AP
M(&5C:&\@7R@B4V5L96-T('1H92!A9&1R97-S(&)O;VL@=&\@97AP;W)T(&9R
M;VTZ(BD@/SX\+VQA8F5L/CQB<B`O/@H@/'-E;&5C="!N86UE/2)S;W5R8V4B
M(&ED/2)S;W5R8V4B/@H@(#P_<&AP(&5C:&\@:6UP;&]D92@G)RP@)'-O=7)C
M95]O<'1I;VYS*2`_/@H@/"]S96QE8W0^/&)R("\^"CP_<&AP(&5L<V4Z(#\^
M"B`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)S;W5R8V4B('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5N:7%U95]S;W5R8V4I(#\^
M(B`O/@H\/W!H<"!E;F1I9CL@/SX*(#QB<B`O/@H*(#QI;G!U="!T>7!E/2)S
M=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H(D5X<&]R="(I(#\^(B!C;&%S
M<STB8G5T=&]N(B`O/@H\+V1I=CX*/"]F;W)M/@H`````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1U<F)A+W1E;7!L871E<R]M96YU+FEN8P``````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$P-S<`,3`T,3<S-C(W-38`,#(Q,C`S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QF;W)M
M(&YA;64](F1I<F5C=&]R>5]L:7-T(B!A8W1I;VX](F)R;W=S92YP:'`B(&UE
M=&AO9#TB9V5T(CX*/#]P:'`@96-H;R!5=&EL.CIF;W)M26YP=70H*2`_/@H\
M9&EV(&ED/2)M96YU(CX*/#]P:'`@:68@*"1B<F]W<V5?<V]U<F-E7V-O=6YT
M(#X@,2DZ(#\^"B`\<W!A;B!C;&%S<STB<FEG:'1&;&]A="(^"B`@/'-E;&5C
M="!N86UE/2)S;W5R8V4B(&]N8VAA;F=E/2)D;V-U;65N="YD:7)E8W1O<GE?
M;&ES="YS=6)M:70H*3LB/CP_<&AP(&5C:&\@)&)R;W=S95]S;W5R8V5?;W!T
M:6]N<R`_/CPO<V5L96-T/@H@(#QN;W-C<FEP=#X\:6YP=70@8VQA<W,](F)U
M='1O;B(@='EP93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*")"<F]W
M<V4B*2`_/B(@+SX\+VYO<V-R:7!T/@H@/"]S<&%N/@H\/W!H<"!E;F1I9CL@
M/SX*/'-P86X@8VQA<W,](FQE9G1&;&]A="(^"B`\/W!H<"!E8VAO(%1U<F)A
M.CIG971-96YU*"=S=')I;F<G*2`_/@H\+W-P86X^"CPO9&EV/@H\+V9O<FT^
M"CP_<&AP("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^;F]T:69Y*&%R<F%Y
M*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D@/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1U<F)A+W1E;7!L871E<R]C;VUM;VXM:&5A9&5R+FEN8P``
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R-3(`,3`T,3<S-C(W-38`,#(R
M-S4Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"F=L;V)A;"`D;&%N9W5A9V4["FEF("AI<W-E="@D;&%N9W5A9V4I
M*2!["B`@("!H96%D97(H)T-O;G1E;G0M='EP93H@=&5X="]H=&UL.R!C:&%R
M<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*2D["B`@("!H96%D97(H)U9A<GDZ
M($%C8V5P="U,86YG=6%G92<I.PI]"C\^"CPA1$]#5%E012!H=&UL(%!50DQ)
M0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP(%1R86YS:71I;VYA;"\O14XB(")$
M5$0O>&AT;6PQ+71R86YS:71I;VYA;"YD=&0B/@H\(2TM(%1U<F)A.B!#;W!Y
M<FEG:'0@,C`P,"TR,#`V+"!4:&4@2&]R9&4@4')O:F5C="X@5'5R8F$@:7,@
M=6YD97(@86X@05-,(&QI8V5N<V4N("TM/@H\(2TM("`@2&]R9&4@4')O:F5C
M=#H@:'1T<#HO+VAO<F1E+F]R9R\@?"!4=7)B83H@:'1T<#HO+VAO<F1E+F]R
M9R]T=7)B82\@("`@+2T^"CPA+2T@("`@("`@2&]R9&4@05-,($QI8V5N<V4Z
M(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`@("`@("`@
M("`M+3X*/#]P:'`@96-H;R`A96UP='DH)&QA;F=U86=E*2`_("<\:'1M;"!L
M86YG/2(G("X@<W1R='(H)&QA;F=U86=E+"`G7R<L("<M)RD@+B`G(CXG(#H@
M)SQH=&UL/B<@/SX*/&AE860^"CP_<&AP"@HD<&%G95]T:71L92`]("1R96=I
M<W1R>2T^9V5T*"=N86UE)RD["FEF("@A96UP='DH)'1I=&QE*2D@)'!A9V5?
M=&ET;&4@+CT@)R`Z.B`G("X@)'1I=&QE.PII9B`H(65M<'1Y*"1R969R97-H
M7W1I;64I("8F("@D<F5F<F5S:%]T:6UE(#X@,"D@)B8@(65M<'1Y*"1R969R
M97-H7W5R;"DI('L*("`@(&5C:&\@(CQM971A(&AT='`M97%U:78]7")R969R
M97-H7"(@8V]N=&5N=#U<(B1R969R97-H7W1I;64[=7)L/21R969R97-H7W5R
M;%PB/EQN(CL*?0I(;W)D93HZ:6YC;'5D95-C<FEP=$9I;&5S*"D["C\^"CQT
M:71L93X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!A9V5?=&ET;&4I
M(#\^/"]T:71L93X*/&QI;FL@:')E9CTB/#]P:'`@96-H;R`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H*3\^+V9A=FEC;VXN:6-O(B!R96P]
M(E-(3U)40U54($E#3TXB("\^"CP_<&AP(&5C:&\@2&]R9&4Z.G-T>6QE<VAE
M971,:6YK*"=T=7)B82<I(#\^"CPO:&5A9#X*"CQB;V1Y/#]P:'`@:68@*%5T
M:6PZ.FYO;DEN<'5T5F%R*"=B;V1Y0VQA<W,G*2D@96-H;R`G(&-L87-S/2(G
M("X@)&)O9'E#;&%S<R`N("<B)SL@/SX^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=&5M<&QA
M=&5S+RYH=&%C8V5S<P``````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`Q-@`Q,#0Q-S,V,C<U-@`P,C$S,S(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1&5N>2!F<F]M(&%L;`H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W1E;7!L871E<R]A9&1R97-S
M8F]O:W,N:6YC````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$R,#,`,3`T
M,3<S-C(W-38`,#(R-S$R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*
M/"$M+0IV87(@961I=%523"`](&1E8V]D955224-O;7!O;F5N="@G/#]P:'`@
M96-H;R!R87=U<FQE;F-O9&4H571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU
M<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP/V%P<#UT=7)B82<L('1R=64I+"`G<VAA
M<F4G+"`G0$E$0"<L(&9A;'-E*2D@/SXG*3L*=F%R('-H87)E<R`](&YE=R!!
M<G)A>2@I.PH\/W!H<"!F;W)E86-H("@D<VAA<F5S(&%S("1K97D@/3X@)'9A
M;'5E*3H@/SX*<VAA<F5S6R<\/W!H<"!E8VAO(&%D9'-L87-H97,H)&ME>2D@
M/SXG72`](&YE=R!!<G)A>2@I.PIS:&%R97-;)SP_<&AP(&5C:&\@861D<VQA
M<VAE<R@D:V5Y*2`_/B==6R=N86UE)UT@/2!D96-O9&554DE#;VUP;VYE;G0H
M(CP_<&AP(&5C:&\@<F%W=7)L96YC;V1E*"1S:&%R97-;)&ME>5TM/F=E="@G
M;F%M92<I*2`_/B(I.PIS:&%R97-;)SP_<&AP(&5C:&\@861D<VQA<VAE<R@D
M:V5Y*2`_/B==6R=D97-C<FEP=&EO;B==(#T@9&5C;V1E55))0V]M<&]N96YT
M*"(\/W!H<"!E8VAO(')A=W5R;&5N8V]D92@D<VAA<F5S6R1K97E=+3YG970H
M)V1E<V-R:7!T:6]N)RDI(#\^(BD["CP_<&AP(&5N9&9O<F5A8V@@/SX*"F9U
M;F-T:6]N(&YE=T-H;VEC92@I"GL*("`@('9A<B!S:&%R92`](&1O8W5M96YT
M+F5D:71S:&%R97,N<VAA<F4N;W!T:6]N<UMD;V-U;65N="YE9&ET<VAA<F5S
M+G-H87)E+G-E;&5C=&5D26YD97A=+G9A;'5E.PH@("`@:68@*'-H87)E(#T]
M("TQ*2!["B`@("`@("`@9&]C=6UE;G0N961I='-H87)E<RYE9&ET<VAA<F4N
M=F%L=64@/2`G)SL*("`@("`@("!D;V-U;65N="YE9&ET<VAA<F5S+G)E<V5T
M*"D["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M96YT+F5D:71S:&%R97,N
M961I='-H87)E+G9A;'5E(#T@<VAA<F4["B`@("`@("`@9&]C=6UE;G0N961I
M='-H87)E<RYS:&%R971I=&QE+G9A;'5E(#T@<VAA<F5S6W-H87)E75LG;F%M
M92==.PH@("`@("`@(&1O8W5M96YT+F5D:71S:&%R97,N9&5S8W)I<'1I;VXN
M=F%L=64@/2!S:&%R97-;<VAA<F5=6R=D97-C<FEP=&EO;B==.PH@("`@?0I]
M"@IF=6YC=&EO;B!C:&5C:U-U8FUI="@I"GL*("`@(&EF("@H9&]C=6UE;G0N
M961I='-H87)E<RYA8W1I;VY)1"YV86QU92`]/2`G861D)RD@)@H@("`@("`@
M("@H9&]C=6UE;G0N961I='-H87)E<RYS:&%R96YA;64N=F%L=64@/3T@)R<I
M('P*("`@("`@("`@*&1O8W5M96YT+F5D:71S:&%R97,N<VAA<F5T>7!E+G9A
M;'5E(#T]("=N;VYE)RDI*2!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H@("`@:68@*"AD;V-U;65N="YE9&ET<VAA<F5S+F%C=&EO;DE$+G9A;'5E
M(#T]("=D96QE=&4G*2`F"B`@("`@("`@*&1O8W5M96YT+F5D:71S:&%R97,N
M9&5L971E<VAA<F4N=F%L=64@/3T@)VYO;F4G*2D@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*?0HO+R`M+3X*/"]S8W)I<'0^"CQF;W)M(&%C=&EO
M;CTB861D<F5S<V)O;VMS+G!H<"(@;65T:&]D/2)P;W-T(B!N86UE/2)E9&ET
M<VAA<F5S(B!O;G-U8FUI=#TB<F5T=7)N(&-H96-K4W5B;6ET*"D[(CX*(#QI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB;F]N
M92(^"B`\:#$@8VQA<W,](FAE861E<B(^/#]P:'`@96-H;R!?*")#<F5A=&4@
M061D<F5S<R!";V]K(BD@/SX\+V@Q/@H@(#QT86)L92!W:61T:"`]("(Q,#`E
M(B!C;&%S<STB:&5A9&5R8F]X(CX*("`@/'1R/@H@("`@/'1D('=I9'1H/2(Q
M-24B(&-L87-S/2)N;W=R87`B(&%L:6=N/2)R:6=H="(^"B`@("`@/'-T<F]N
M9SX\/W!H<"!E8VAO(%\H(D-H;V]S92!A(&YA;64B*2`_/CPO<W1R;VYG/@H@
M("`@/"]T9#X*("`@(#QT9"!W:61T:#TB.#4E(CX*("`@("`\:6YP=70@='EP
M93TB=&5X="(@<W1Y;&4](G=I9'1H.C(P,'!X(B!N86UE/2)S:&%R96YA;64B
M("\^"B`@("`\+W1D/@H@("`\+W1R/@H@("`\='(^"B`@("`\=&0^)FYB<W`[
M/"]T9#X*("`@(#QT9#X*("`@("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE
M/2)N97=S:&%R92(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N
M961I='-H87)E<RYA8W1I;VY)1"YV86QU93TG861D)SLB('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(D-R96%T92(I(#\^(B`O/@H@("`@/"]T9#X*("`@/"]T<CX*
M("`\+W1A8FQE/@H\/W!H<"!I9B`H8V]U;G0H)&UY4F5M;W9A8FQE*2DZ(#\^
M"B`@/&@Q(&-L87-S/2)H96%D97(B/CP_<&AP(&5C:&\@7R@B1&5L971E($%D
M9')E<W,@0F]O:R(I(#\^/"]H,3X*("`\=&%B;&4@=VED=&@](C$P,"4B(&-L
M87-S/2)H96%D97)B;W@B/@H@("`\='(^"B`@("`\=&0@=VED=&@](C$U)2(@
M8VQA<W,](FYO=W)A<"(@86QI9VX](G)I9VAT(CX*("`@("`\<W1R;VYG/CP_
M<&AP(&5C:&\@7R@B061D<F5S<R!B;V]K('1O(&1E;&5T92`B*2`_/CPO<W1R
M;VYG/@H@("`@/"]T9#X*("`@(#QT9"!W:61T:#TB.#4E(CX*("`@("`\<V5L
M96-T(&YA;64](F1E;&5T97-H87)E(B!S='EL93TB=VED=&@Z,C`P<'@B/@H@
M("`@("`\;W!T:6]N('9A;'5E/2)N;VYE(CX\/W!H<"!E8VAO(%\H(E-E;&5C
M="!A;B!A9&1R97-S(&)O;VL@=&\@9&5L971E(BD@/SX\+V]P=&EO;CX*("`@
M("`@/#]P:'`@9F]R96%C:"`H)&UY4F5M;W9A8FQE(&%S("1S<F-.86UE*3H@
M/SX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1S<F-.86UE*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1M>5-O=7)C97-;)'-R8TYA;65=*2`_/CPO;W!T:6]N/@H@("`@("`\
M/W!H<"!E;F1F;W)E86-H.R`_/@H@("`@(#PO<V5L96-T/@H@("`@/"]T9#X*
M("`@/"]T<CX*("`@/'1R/@H@("`@/'1D/B9N8G-P.SPO=&0^"B`@("`\=&0^
M"B`@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB9&5L971E(B!C;&%S
M<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N="YE9&ET<VAA<F5S+F%C=&EO
M;DE$+G9A;'5E/2=D96QE=&4G.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B1&5L
M971E(BD@/SXB("\^"B`@("`\+W1D/@H@("`\+W1R/@H@(#PO=&%B;&4^"B`\
M/W!H<"!E;F1I9B`_/@H@/&@Q(&-L87-S/2)H96%D97(B/CP_<&AP(&5C:&\@
M7R@B161I="!!9&1R97-S($)O;VMS(BD@/SX\+V@Q/@H@/'1A8FQE(&-L87-S
M/2)H96%D97)B;W@B('=I9'1H/2(Q,#`E(CX*("`\='(^"B`@(#QT9"!W:61T
M:#TB,34E(B!C;&%S<STB;F]W<F%P(B!A;&EG;CTB<FEG:'0B/@H@("`@/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB961I='-H87)E(B!V86QU93TB(B`O
M/@H@("`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D%D9')E<W,@0F]O:R(I(#\^
M/"]S=')O;F<^"B`@(#PO=&0^"B`@(#QT9"!W:61T:#TB.#4E(CX*("`@(#QS
M96QE8W0@;F%M93TB<VAA<F4B('-T>6QE/2)W:61T:#HR,#!P>"(@;VYC:&%N
M9V4](FYE=T-H;VEC92@I.R(^"B`@("`@/&]P=&EO;B!V86QU93TB;F]N92(^
M/#]P:'`@96-H;R!?*")396QE8W0@86X@861D<F5S<R!B;V]K('1O(&5D:70B
M*2`_/CPO;W!T:6]N/@H@("`@(#P_<&AP(&9O<F5A8V@@*"1M>5-O=7)C97,@
M87,@)&ME>2`]/B`D=F%L=64I.B`_/@H@("`@(#QO<'1I;VX@=F%L=64](CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(^/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1V86QU92D@/SX\+V]P=&EO;CX*("`@("`\
M/W!H<"!E;F1F;W)E86-H.R`_/@H@("`@/"]S96QE8W0^"B`@(#PO=&0^"B`@
M/"]T<CX*("`\='(^"B`@(#QT9"!C;&%S<STB;F]W<F%P(B!A;&EG;CTB<FEG
M:'0B/@H@("`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E!E<FUI<W-I;VYS(BD@
M/SX\+W-T<F]N9SX*("`@/"]T9#X*("`@/'1D/@H@("`@/&EN<'5T('1Y<&4]
M(F)U='1O;B(@;F%M93TB<&5R;7,B(&-L87-S/2)B=71T;VXB(&]N8VQI8VL]
M(FEF("AD;V-U;65N="YE9&ET<VAA<F5S+F5D:71S:&%R92YV86QU92D@<&]P
M=7`H961I=%523"YR97!L86-E*"\E-#!)1"4T,"\L(&1O8W5M96YT+F5D:71S
M:&%R97,N961I='-H87)E+G9A;'5E*2D[(B!V86QU93TB/#]P:'`@96-H;R!?
M*")%9&ET(BD@/SXB("\^"B`@(#PO=&0^"B`@/"]T<CX*("`\='(^"B`@(#QT
M9"!C;&%S<STB;F]W<F%P(B!A;&EG;CTB<FEG:'0B/@H@("`@/'-T<F]N9SX\
M/W!H<"!E8VAO(%\H(DYA;64B*2`_/CPO<W1R;VYG/@H@("`\+W1D/@H@("`\
M=&0^"B`@("`\:6YP=70@='EP93TB=&5X="(@;F%M93TB<VAA<F5T:71L92(@
M<W1Y;&4](G=I9'1H.C(P,'!X(B`O/@H@("`\+W1D/@H@(#PO='(^"B`@/'1R
M/@H@("`\=&0@8VQA<W,](FYO=W)A<"(@=F%L:6=N/2)T;W`B(&%L:6=N/2)R
M:6=H="(^"B`@("`\<W1R;VYG/CP_<&AP(&5C:&\@7R@B1&5S8W)I<'1I;VXB
M*2`_/CPO<W1R;VYG/@H@("`\+W1D/@H@("`\=&0^"B`@("`\=&5X=&%R96$@
M<W1Y;&4](G=I9'1H.C(P,'!X(B!N86UE/2)D97-C<FEP=&EO;B(@<F]W<STB
M-"(@8V]L<STB-C`B/CPO=&5X=&%R96$^"B`@(#PO=&0^"B`@/"]T<CX*("`\
M='(^"B`@(#QT9#XF;F)S<#L\+W1D/@H@("`\=&0^"B`@("`\:6YP=70@='EP
M93TB<W5B;6ET(B!N86UE/2)S879E(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K
M/2)D;V-U;65N="YE9&ET<VAA<F5S+F%C=&EO;DE$+G9A;'5E/2=U<&1A=&4G
M(B!V86QU93TB/#]P:'`@96-H;R!?*")3879E(BD@/SXB("\^"B`@(#PO=&0^
M"B`@/"]T<CX*(#PO=&%B;&4^"CPO9F]R;3X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]T:&5M97,O````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S4V`#`Q-S`S,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1U<F)A+W1H96UE<R]I9&5A<R\`````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-38`,#(P,3$V`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=&AE;65S+VED96%S+W-C<F5E;BYC
M<W,`````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,P,``Q,#0Q-S,V
M,C<U-@`P,C(P-S4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J($ED96%S('1H96UE(&)Y(%)O96P@1VQO=61E;6%N
M<R`\<BYG;&]U9&5M86YS0&DM=&\M:2YN;#X*("H@0F%S960@;VX@=&AE($ED
M96%S('1O($EN=&5R8V]N;F5C="!"5B!W96)S:71E("AH='1P.B\O=W=W+FDM
M=&\M:2YN;"D*("HO"@HN=&5X=#IH;W9E<B!T9"!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C8F%D,&4W.PI]"@H*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1U<F)A+W1H96UE<R]G<F%P:&EC<R\`````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-38`,#(P-C,Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=&AE;65S+V=R87!H:6-S
M+VUE;G4O````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<U-@`P,C$U-S4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B
M82]T:&5M97,O9W)A<&AI8W,O;65N=2]B<F]W<V4N<&YG````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-#<V`#$P-#$W,S8R-S4V`#`R,S8Q,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```!44$Q410```!43$S$Q,9@L$TI*2DI+
M2X1?5VEJ:M]"'G5U=7Y^?H^/CYZ>GJVEIJVMK:ZNKK^_O]/3T^7EY>?GY^CH
MZ.GIZ>SL[/7U]?;V]OCX^/___P```*V\%Q\````!=%).4P!`YMAF`````6)+
M1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,"!(H!`"M
M+-H```!C241!5'C:;8]9#H`@#`5QWP7<=>Y_3R,%(XGSU\E[3:O4#WC>^=P=
M2S`<L\,0Y3&SU!B%#D-5/2&Z8"A"*142OS6?K$,SB.DO0=,XP2JS;?UM;-*P
M.91$EP2AR#PU\7.?_S[<_B$-+.K['10`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=&AE;65S+V=R
M87!H:6-S+VUE;G4O;F5W+G!N9P``````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#<W-0`Q,#0Q-S,V,C<U-@`P,C,Q,#(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````V%!,5$4````#`P,%!04)"`@-#`L-#0T-#Q0<'Q\@(!\U
M'P<=)#`H)2(@)S(X(PXW,B\I-D,U-3$^-RPX.3,[.SE6-1-=-Q%'/S-;/1M)
M24=+2DA,3$Q-3$M)6&A96%=97%".41%48W%E9EY6;86R9A9]?'J!@7^'AH2A
ME(FBE(F$G+2JFX^UIIJLJJ3RJ!6^KJ'#LJ76Q;?9Q[C9Q[G2SLC3T,G3T,K4
MT,K4T<K5T<O_U'+;V-/:V=3CX=[FY-_FY>'HYN'JZ>7KZ>7KZN7LZ^?N[>GP
M[NO_\-8```#O;3M/`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9
M<P``"Q(```L2`=+=?OP````'=$E-10?4#`@2*`N0$C%+````GDE$051XVH6/
M1Q;",`Q$0^^]A1)Z!P,))8B>0#SWOQ&V%T!6_)W^Z#V--.T_\"'FR]/[<H(&
M;Z2BIB/92@'3VI@67-T8NCLEUME0:@&YX.Z5F)8[B0D<?6PXMA*KS*`VQ[V7
M+[8/0KQ0B%7"55P#G.I+(1[HSEK]'$I!3K((;@UU-L(Y)R(ASO;1%L3%Q!C#
M;W5BJON')#'XODQ'9?X&?DHJS73MV?4`````245.1*Y"8((````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W1H96UE<R]G<F%P:&EC<R]F879I
M8V]N+FEC;P``````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-S8`,3`T,3<S
M-C(W-38`,#(R-S4U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````0`!`!`0````````:`0``!8````H````$````"`````!
M`"`````````$````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_P```/\```#_````_P```/\`
M``#_````_P```/\```#_````_P```/\```#_````_P```/\`````````_]39
MVO_*T=3_R]'5_\K1U/_*T=3_RM'4_\K1U/_*T=3_RM'4_\K1U/_*T=3_RM'4
M_\K1U/_$Q<?_````_P```/_AY>;_3$Q,_P```/\```#_````_P```/\```#_
M3$Q,_][CY?_>X^7_WN/E_][CY?_>X^7_R,_2_P```/\```#_Y>GJ_P```/]Q
M8U3_M)R$_VA82?^%;5;_0S8I_P```/_>X^7_WN/E_][CY?_>X^7_WN/E_\C/
MT_\```#_````_^GM[O\```#_+#<^_Q\?'/\1-UW_"PP-_S,_1_\```#_W^3F
M_]_DYO_>X^7_WN/E_][CY?_)T-/_````_P```/_K[O#_````_Z&NOO\.(SC_
M%F:R_QL]6_^/FZK_````_^'FZ/_AY>?_X.7G_^#EY__@Y>?_R]'5_P```/\`
M``#_Z^[P_P```/^)E*+_$S56_Q%1CO\''S7_B92A_P```/_EZ>O_1TE)_X2&
MA_]76%G_Y>GK_\K1U/\```#_````_^ON\/\```#_I;+#_R\R-_\("`G_(B4H
M_YJFM?\```#_Y>GK_^7IZ__EZ>O_Y>GK_^7JZ__*T-/_````_P```/_K[O#_
M````_[C'V?^YQ]G_M\76_[C'V?^YQ]G_````_^7JZ_]'24G_5UA9_WI\??_E
MZNO_R=#3_P```/\```#_Z^[P_W^!@?\```#_````_P```/\```#_````_TM,
M3?_EZ>O_Y>GK_^7IZ__EZ>O_Y>GK_\C.TO\```#_````_][AX__GZ^S_Z^[P
M_^ON\/_K[O#_Z^[P_^ON\/_K[O#_Z^[P_^ON\/_K[O#_Z^[P_^ON\/_3V-O_
M````_P````````#_````_P```/\```#_````_P```/\```#_````_P```/\`
M``#_````_P```/\```#_````_P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/__``#__P``@`$`````````````````````````
M``````````````````````````````"``0``__\``/__````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R
M8F$O=&AE;65S+V=R87!H:6-S+W1U<F)A+G!N9P``````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#<T,P`Q,#0Q-S,V,C<U-@`P,C(T-34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````M%!,5$4````)"`@-#`L<'Q\U'P<H
M)2(X(PXW,B\I-D,^-RQ6-1-=-Q%'/S-;/1M)24=,3$Q-3$M)6&A96%>.41%4
M8W%6;86R9A9]?'J!@7^'AH2AE(FBE(F$G+2JFX^UIIJ^KJ'#LJ7'Q<36Q;?9
MQ[C9Q[G2SLC2S\C3S\C3T,G3T,K4T<K5T<O;V-/:V=3CX=[EX][FY-_FY>'G
MY>#GY>'HYN'JZ>7KZ>7KZN7LZ^?N[>GP[NL```!FT=/^`````7123E,`0.;8
M9@````%B2T=$`(@%'4@````)<$A9<P``"Q(```L2`=+=?OP````'=$E-10?4
M#`@2'R';KEBI````$W1%6'1#;VUM96YT`%1H:7,@<F]C:W,A8Z%6M0```(E)
M1$%4>-J%SL<6PB`0A6'L/='8>TEL1"6B@N:^_WO)S$*/QT7^W7QP!H3(#C^Y
M^?),OYT@D([XJ&VH+0'":!-&L%XPM`>&52576H`NV"/#M-XM3F"\<6`DP[(\
M:,UQOVFM8P<OU`J-?!-)HI2B'0_T9IU^%8K:.[CZ_*S/L'-PEK'\M,;_US-[
M`W`:(B&:I;)H`````$E%3D2N0F""````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W1H96UE<R]G
M<F%P:&EC<R]N97<N<&YG````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`W-S4`,3`T,3<S-C(W-38`,#(R,3,V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P```-A03%1%`````P,#!04%"0@(#0P+#0T-#0\4'!\?("`?
M-1\''20P*"4B("<R.",.-S(O*39#-34Q/C<L.#DS.SLY5C4373<11S\S6ST;
M24E'2TI(3$Q,34Q+25AH65A765Q0CE$15&-Q969>5FV%LF86?7QZ@8%_AX:$
MH92)HI2)A)RTJIN/M:::K*JD\J@5OJZAP[*EUL6WV<>XV<>YTL[(T]#)T]#*
MU-#*U-'*U='+_]1RV]C3VMG4X^'>YN3?YN7AZ.;AZNGEZ^GEZ^KE[.OG[NWI
M\.[K__#6````[VT[3P````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(
M67,```L2```+$@'2W7[\````!W1)344'U`P($B<6=(Q!70```)Y)1$%4>-J%
MCT<6PC`,1$/OO842>@<#"26(GD`\][\1MA=`5OR=_N@]C33M/_`AYLO3^W*"
M!F^DHJ8CV4H!T]J8%ES=&+H[)=;94&H!N>#NE9B6.XD)''UL.+82J\R@-L>]
MER^V#T*\4(A5PE5<`YSJ2R$>Z,Y:_1Q*04ZR"&X-=3;".2<B(<[VT1;$Q<08
MPV]U8JK[AR0Q^+Y,1V7^!GY**LUT[=GU`````$E%3D2N0F""````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]T:&5M97,O9W)A<&AI8W,O9W)O
M=7`N<&YG````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#`U`#$P-#$W
M,S8R-S4V`#`R,C0V-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````#P````X$`P````*D6]P`
M```A4$Q410```("``/__`/___\#`P("`@`#___\``(````"`@````$*%UVD`
M```!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<
M&`````=T24U%!]0*$0X3"FS*640```!=241!5`C78V!``ERK5BT`4HRK0`#(
M6*2DM&J5%5!`26KA*F,00W&)\1*K!2#&8JLE(!$NI<7&5J9`$2ZAQ:9+C$%2
M0!&P;JY56:O**T`&AF7.7-[1!60LFPEE0`$`-3H?!"`/U.``````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O='5R8F$O=&AE;65S+V=R87!H:6-S+V-O;G1A8W0N<&YG````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<T,P`Q,#0Q-S,V,C<U-@`P,C(W
M-S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````M%!,5$4````)
M"`@-#`L<'Q\U'P<H)2(X(PXW,B\I-D,^-RQ6-1-=-Q%'/S-;/1M)24=,3$Q-
M3$M)6&A96%>.41%48W%6;86R9A9]?'J!@7^'AH2AE(FBE(F$G+2JFX^UIIJ^
MKJ'#LJ7'Q<36Q;?9Q[C9Q[G2SLC2S\C3S\C3T,G3T,K4T<K5T<O;V-/:V=3C
MX=[EX][FY-_FY>'GY>#GY>'HYN'JZ>7KZ>7KZN7LZ^?N[>GP[NL```!FT=/^
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q(```L2`=+=
M?OP````'=$E-10?4#`@2)R\KB<E5````$W1%6'1#;VUM96YT`%1H:7,@<F]C
M:W,A8Z%6M0```(E)1$%4>-J%SL<6PB`0A6'L/='8>TEL1"6B@N:^_WO)S$*/
MQT7^W7QP!H3(#C^Y^?),OYT@D([XJ&VH+0'":!-&L%XPM`>&52576H`NV"/#
MM-XM3F"\<6`DP[(\:,UQOVFM8P<OU`J-?!-)HI2B'0_T9IU^%8K:.[CZ_*S/
ML'-PEK'\M,;_US-[`W`:(B&:I;)H`````$E%3D2N0F""````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U
M<F)A+W1H96UE<R]S8W)E96XN8W-S````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`R,S8`,3`T,3<S-C(W-38`,#(Q,#(P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"\J*@H@*B`D2&]R
M9&4Z('1U<F)A+W1H96UE<R]S8W)E96XN8W-S+'8@,2XR+C0N,2`R,#`U+S$P
M+S$X(#$R.C4P.C$Y(&IA;B!%>'`@)`H@*B\*"B\J($UE;G4@8F]T=&]M(&UA
M<F=I;BP@861D960@9F]R($)#+B`J+PHC;65N=2!["B`@("!M87)G:6XM8F]T
M=&]M.B`X<'@["GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]D;V-S+P``
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S4V`#`Q-C0W-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1U<F)A+V1O8W,O55!'4D%$24Y'````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#4W-#$`,3`T,3<S-C(W-38`,#$W-S0S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H@57!G<F%D:6YG('1O(%1U<F)A(#(N>`H]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T
M93H@,C`P-2\Q,"\Q."`Q,CHU,#HP-"`D"CI2979I<VEO;CH@("`@("`D4F5V
M:7-I;VXZ(#$N,RXV+C(@)`HZ0V]N=&%C=#H@("`@("`@='5R8F%`;&ES=',N
M:&]R9&4N;W)G"@H*57!G<F%D:6YG('1O(%1U<F)A(#(N,0H]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"@H*5&AE<V4@87)E(&YO=&5S(&]N('5P9W)A9&EN9R!F
M<F]M(%1U<F)A(#(N,"YX('1O(%1U<F)A(#(N,2X*"BXN($EM<&]R=&%N=#HZ
M(%1H97-E('5P9W)A9&4@:6YS=')U8W1I;VYS(&%S<W5M92!T:&%T('EO=2!A
M<F4@=7!G<F%D:6YG(&9R;VT*("`@("`@("`@("`@("`@870@;&5A<W0@5'5R
M8F$@,BXP+B`@268@>6]U(&AA=F4@86X@;VQD97(@=F5R<VEO;B!O9B!4=7)B
M82P*("`@("`@("`@("`@("`@9F]L;&]W('1H92`G=7!G<F%D92!S=&5P<R=?
M(&1E<V-R:6)E9"!I;B!4=7)B82`Q+C(L(#(N,"!O<@H@("`@("`@("`@("`@
M("!H:6=H97(@9FER<W0N"@H*3F5W($AO;VL@4&%R86UE=&5R<PHM+2TM+2TM
M+2TM+2TM+2TM+2TM"@I4:&4@7W1U<F)A7VAO;VM?96YC;V1E7WMA='1R:6)U
M=&5](&%N9"!?='5R8F%?:&]O:U]D96-O9&5?>V%T=')I8G5T97T*9G5N8W1I
M;VYS(&%R92!N;W<@<&%S<V5D(&%N(&%D9&ET:6]N86P@<&%R86UE=&5R("T@
M=&AE(&]B:F5C="!T:&%T(&ES"F)E:6YG(&QO861E9"]S879E9"X@5&AI<R!E
M;F%B;&5S('EO=2!T;R!C<F5A=&4@;6]R92!P;W=E<F9U;"!C=7-T;VT*:&]O
M:W,@=&AA="!B=6EL9"!A(&9I96QD(&9R;VT@<V5V97)A;"!O=&AE<B!F:65L
M9"=S('9A;'5E<R`H=&AE"F]P<&]S:71E(&]F(&-O;7!O<VET92!F:65L9',I
M+"!O<B!O=&AE<G=I<V4@;6]D:69Y(&$@=F%L=64@8F%S960@;VX*;W1H97(@
M<')O<&5R=&EE<R!O9B!T:&4@;V)J96-T+@H*"DAO<F1E7U-H87)E(%-U<'!O
M<G0*+2TM+2TM+2TM+2TM+2TM+2TM+0H*2&]R9&5?4VAA<F4@<W5P<&]R="!H
M87,@8F5E;B!A9&1E9"!T;R!4=7)B82X@(%1H:7,@86QL;W=S('1H92!S:&%R
M:6YG+"!A9&1I;F<L"F%N9"!D96QE=&EN9R!O9B!A9&1R97-S8F]O:W,@9F]R
M('1H;W-E('-O=7)C97,@=&AA="!S=7!P;W)T(&ET+B`@0W5R<F5N=&QY+`IT
M:&ES(&ES('-U<'!O<G1E9"!B>2!T:&4@4U%,(&1R:79E<BX@(%=I=&@@=&AI
M<R!C:&%N9V4L('1H92`G<'5B;&EC)R!A='1R:6)U=&4*;V8@=&AE('!A<F%M
M<R!A<G)A>2!H87,@8F5E;B!R96UO=F5D(&EN(&9A=F]R(&]F('1H92`G=7-E
M7W-H87)E)R!A='1R:6)U=&4N"DEF('EO=2!A<F4@8W5R<F5N=&QY('5S:6YG
M(&$@4U%,('-O=7)C92!A<R!A('!U8FQI8R!S;W5R8V4L('EO=2!M=7-T(')U
M;B!T:&4*=7!G<F%D92!S8W)I<'0@<V-R:7!T<R]U<&=R861E<R]P=6)L:6-?
M=&]?:&]R9&5?<VAA<F4N<&AP+B`@0F4@<W5R92!T;R!R96%D"G1H92!S8W)I
M<'0@8V]M;65N=',@86YD(&)A8VMU<"!A;&P@9&%T82!B969O<F4@8V]N=F5R
M<VEO;BX@(%1H:7,@<V-R:7!T('=I;&P*8W)E871E(&$@;F5W($AO<F1E7U-H
M87)E('1H870@:7,@=FEE=V%B;&4@8GD@86QL('5S97)S+B`@268@>6]U(&-H
M;V]S92!N;W0@=&\*=7-E($AO<F1E7U-H87)E+"!S970@=&AE("=U<V5?<VAA
M<F5S)R!A='1R:6)U=&4@=&\@)V9A;'-E)R!A;F0@=&AE(%-13"!D<FEV97(*
M=VEL;"!B96AA=F4@87,@:6X@<')E=FEO=7,@=F5R<VEO;G,L('1H870@:7,L
M(&$@<V5P97)A=&4L('!R:79A=&4@861D<F5S<V)O;VL*9F]R(&5A8V@@=7-E
M<BX*"@H*57!G<F%D:6YG('1O(%1U<F)A(#(N,`H]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"@H*5&AE<V4@87)E(&EN<W1R=6-T:6]N<R!T;R!U<&=R861E(&9R
M;VT@5'5R8F$@,2XR+G@@=&\@5'5R8F$@,BXP+B`@4&QE87-E"F)A8VMU<"!Y
M;W5R(&5X:7-T:6YG(&1A=&$@8F5F;W)E(')U;FYI;F<@86YY(&]F('1H92!S
M=&5P<R!D97-C<FEB960@8F5L;W<N"EEO=2!C86XG="!U<V4@=&AE('5P9&%T
M960@9&%T82!W:71H('EO=7(@;VQD(%1U<F)A('9E<G-I;VX@86YY;6]R92X*
M"BXN($EM<&]R=&%N=#HZ(%1H97-E('5P9W)A9&4@:6YS=')U8W1I;VYS(&%S
M<W5M92!T:&%T('EO=2!A<F4@=7!G<F%D:6YG(&9R;VT*("`@("`@("`@("`@
M("`@870@;&5A<W0@5'5R8F$@,2XR+B`@268@>6]U(&AA=F4@86X@;VQD97(@
M=F5R<VEO;B!O9B!4=7)B82P*("`@("`@("`@("`@("`@9F]L;&]W('1H92`G
M=7!G<F%D92!S=&5P<R=?(&1E<V-R:6)E9"!I;B!4=7)B82`Q+C(@;W(@:&EG
M:&5R"B`@("`@("`@("`@("`@(&9I<G-T+@H*+BX@7R=U<&=R861E('-T97!S
M)SH@:'1T<#HO+V-V<RYH;W)D92YO<F<O86YN;W1A=&4N<&AP+W1U<F)A+V1O
M8W,O071T:6,O55!$051%/W-A/3$F<F5V/3$N,2XR+C8*"@I344P@0F%C:V5N
M9',*+2TM+2TM+2TM+2TM"@I&;W5R(&YE=R!F:65L9',@:&%V92!B965N(&%D
M9&5D('1O('1H92!D969A=6QT(%-13"!T86)L92!L87EO=70L(&]N92!B96EN
M9PIM86YD871O<GDN("!4:&4@;F5W(&!@;V)J96-T7W5I9&!@(&9I96QD('!R
M;W9I9&5S(&$@9VQO8F%L('5N:7%U92!)1"!T;PIO8FIE8W1S+@H*17AE8W5T
M92!T:&4@<')O=FED960@4U%,('-C<FEP="!T;R!U<&1A=&4@>6]U<B!D871A
M('1O('1H92!N97<@5'5R8F$@=F5R<VEO;CHZ"@H@("!M>7-Q;"`M+75S97(]
M<F]O="`M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M
M93X@/"`Q+C)?=&]?,BXP+G-Q;`H@("!P<W%L(#QD8B!N86UE/B`M9B`Q+C)?
M=&]?,BXP+G-Q;`H*"DAI<W1O<GD*+2TM+2TM+0H*5&AE(&-O;G1A8W1S(&AI
M<W1O<GD@:7,@;F]W(&)E:6YG(&UA:6YT86EN960@8GD@=&AE(&=L;V)A;"!(
M;W)D92!(:7-T;W)Y"F)A8VME;F0N("!4;R!C<F5A=&4@9&5F875L="!H:7-T
M;W)Y(&5N=')I97,@97AE8W5T92!T:&4@<')O=FED960@4$A0('-C<FEP=#HZ
M"@H@("!P:'`@<V-R:7!T<R]U<&=R861E<R\R,#`T+3$P+3(V7V-R96%T95]D
M969A=6QT7VAI<W1O<FEE<RYP:'`*````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O9&]C<R]2
M14%$344`````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-#0W,P`Q,#0Q-S,V,C<U-@`P,3<S-C$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````5VAA="!I<R!4=7)B83\*/3T]/3T]
M/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-2\Q,"\Q."`Q
M,CHU,#HP,R`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N,3(N,3`N
M,B`D"CI#;VYT86-T.B`@("`@("!T=7)B84!L:7-T<RYH;W)D92YO<F<*"BXN
M(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*
M5'5R8F$@:7,@=&AE($AO<F1E(&-O;G1A8W0@;6%N86=E;65N="!A<'!L:6-A
M=&EO;BP@9&5S:6=N960@=&\@8F4@:6YT96=R871E9`IW:71H(&]T:&5R($AO
M<F1E(&%P<&QI8V%T:6]N<R!T;R!P<F]V:61E(&$@=6YI9FEE9"!I;G1E<F9A
M8V4@=&\@8V]N=&%C=`IM86YA9V5M96YT('1H<F]U9VAO=70@=&AE($AO<F1E
M('-U:71E+@H*5&AI<R!S;V9T=V%R92!I<R!/4TD@0V5R=&EF:65D($]P96X@
M4V]U<F-E(%-O9G1W87)E+B`@3U-)($-E<G1I9FEE9"!I<R!A"F-E<G1I9FEC
M871I;VX@;6%R:R!O9B!T:&4@8$]P96X@4V]U<F-E($EN:71I871I=F5@7RX*
M"BXN(%]@3W!E;B!3;W5R8V4@26YI=&EA=&EV96`Z(&AT='`Z+R]W=W<N;W!E
M;G-O=7)C92YO<F<O"@H*3V)T86EN:6YG(%1U<F)A"BTM+2TM+2TM+2TM+2TM
M+0H*1G5R=&AE<B!I;F9O<FUA=&EO;B!O;B!4=7)B82!A;F0@=&AE(&QA=&5S
M="!V97)S:6]N(&-A;B!B92!O8G1A:6YE9"!A=`H*("!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]T=7)B82\*"@I$;V-U;65N=&%T:6]N"BTM+2TM+2TM+2TM+2T*
M"E1H92!F;VQL;W=I;F<@9&]C=6UE;G1A=&EO;B!I<R!A=F%I;&%B;&4@:6X@
M=&AE(%1U<F)A(&1I<W1R:6)U=&EO;CH*"CI214%$345?.B`@("`@("`@("`@
M(%1H:7,@9FEL90HZ3$E#14Y315\Z("`@("`@("`@("!#;W!Y<FEG:'0@86YD
M(&QI8V5N<V4@:6YF;W)M871I;VX*.F!D;V-S+T-(04Y'15-@7SH@("`@0VAA
M;F=E<R!B>2!R96QE87-E"CI@9&]C<R]#4D5$25138%\Z("`@(%!R;VIE8W0@
M9&5V96QO<&5R<PHZ8&1O8W,O24Y35$%,3&!?.B`@("!);G-T86QL871I;VX@
M:6YS=')U8W1I;VYS(&%N9"!N;W1E<PHZ8&1O8W,O3$1!4&!?.B`@("`@("!,
M1$%0('!E<G-O;F%L(&%D9')E<W-B;V]K($A/5U1/"CI@9&]C<R]43T1/8%\Z
M("`@("`@($1E=F5L;W!M96YT(%1/1$\@;&ES=`HZ8&1O8W,O55!'4D%$24Y'
M8%\Z("!0;VEN=&5R<R!O;B!U<&=R861I;F<@9G)O;2!P<F5V:6]U<R!3:V5L
M971O;B!V97)S:6]N<PH*"DEN<W1A;&QA=&EO;@HM+2TM+2TM+2TM+2T*"DEN
M<W1R=6-T:6]N<R!F;W(@:6YS=&%L;&EN9R!4=7)B82!C86X@8F4@9F]U;F0@
M:6X@=&AE(&9I;&4@24Y35$%,3%\@:6X@=&AE"F!@9&]C<R]@8"!D:7)E8W1O
M<GD@;V8@=&AE(%1U<F)A(&1I<W1R:6)U=&EO;BX*"@I!<W-I<W1A;F-E"BTM
M+2TM+2TM+2T*"DEF('EO=2!E;F-O=6YT97(@<')O8FQE;7,@=VET:"!4=7)B
M82P@:&5L<"!I<R!A=F%I;&%B;&4A(`H*5&AE($AO<F1E($9R97%U96YT;'D@
M07-K960@475E<W1I;VYS($QI<W0@*$9!42DL(&%V86EL86)L92!O;B!T:&4@
M5V5B(&%T"B`*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]F87$O"@I4:&4@2&]R
M9&4@4')O:F5C="!R=6YS(&$@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',L(&9O
M<B!I;F1I=FED=6%L(&%P<&QI8V%T:6]N<PIA;F0@9F]R(&ES<W5E<R!R96QA
M=&EN9R!T;R!T:&4@<')O:F5C="!A<R!A('=H;VQE+B`@26YF;W)M871I;VXL
M(&%R8VAI=F5S+"!A;F0*<W5B<V-R:7!T:6]N(&EN9F]R;6%T:6]N(&-A;B!B
M92!F;W5N9"!A=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]M86EL+PH*3&%S
M=&QY+"!(;W)D92!D979E;&]P97)S+"!C;VYT<FEB=71O<G,@86YD('5S97)S
M(&%L<V\@;6%K92!O8V-A<VEO;F%L"F%P<&5A<F%N8V5S(&]N($E20RP@;VX@
M=&AE(&-H86YN96P@(VAO<F1E(&]N('1H92!F<F5E;F]D92!.971W;W)K"BAI
M<F,N9G)E96YO9&4N;F5T*2X*"@I,:6-E;G-I;F<*+2TM+2TM+2TM"@I&;W(@
M;&EC96YS:6YG(&%N9"!C;W!Y<FEG:'0@:6YF;W)M871I;VXL('!L96%S92!S
M964@=&AE(&9I;&4@3$E#14Y315\@:6X@=&AE"E1U<F)A(&1I<W1R:6)U=&EO
M;BX*"E1H86YK<RP*"E1H92!4=7)B82!T96%M"@H*+BX@7U)%041-13H@/V8]
M4D5!1$U%+FAT;6P*+BX@7TQ)0T5.4T4Z(&AT='`Z+R]W=W<N:&]R9&4N;W)G
M+VQI8V5N<V5S+V%S;"YP:'`*+BX@7V1O8W,O0TA!3D=%4SH@/V8]0TA!3D=%
M4RYH=&UL"BXN(%]D;V-S+T-2141)5%,Z(#]F/4-2141)5%,N:'1M;`HN+B!?
M24Y35$%,3#H*+BX@7V1O8W,O24Y35$%,3#H@/V8]24Y35$%,3"YH=&UL"BXN
M(%]D;V-S+TQ$05`Z(#]F/4Q$05`N:'1M;`HN+B!?9&]C<R]43T1/.B`_9CU4
M3T1/+FAT;6P*+BX@7V1O8W,O55!'4D%$24Y'.B`_9CU54$=2041)3D<N:'1M
M;`H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M='5R8F$O9&]C<R]#2$%.1T53````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`U-S4R-``Q,#0Q-S,V,C<U-@`P,3<U,#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2TM+0IV,BXQ
M"BTM+2T*"EMB96Y=($)E='1E<B!S=7!P;W)T(&9O<B!-4RU344P*"@HM+2TM
M+2TM+0IV,BXQ+5)#,0HM+2TM+2TM+0H*6VUJ<ET@1&5F875L="!T;R!S:&]W
M:6YG('1H92`G02<@<&%G92!W:&5N(&)R;W=S:6YG(&%D9')E<W,@8F]O:W,@
M=&AA="!C;VYT86EN"B`@("`@(&UO<F4@=&AA;B!T:&4@)W!E<G!A9V4G(&YU
M;6)E<B!O9B!E;G1R:65S+@I;:F%N72!!9&0@26-E;&%N9&EC('1R86YS;&%T
M:6]N("A":F]R;B!$879I9'-S;VX@/&)J;W-S:4!S;F5R<&$N:7,^*2X*6VUJ
M<ET@1FEX('!A9VEN9R!W:&5N('9I97=I;F<@<V5A<F-H(')E<W5L=',N"EMM
M:G)=($]N;'D@<VAO=R!A8W1I;VYS('1H870@;6%K92!S96YS92!F;W(@=&AE
M(&-U<G)E;G0@<V]U<F-E+@I;;6IR72!!;&P@24U34"!A9&1R97-S(&)O;VMS
M+"!I;F-L=61I;F<@9'EN86UI8V%L;'D@8V]N9FEG=7)E9"!S;W5R8V5S(&%R
M92!N;W<*("`@("`@=6YI<75E;'D@:61E;G1I9FEE9"!A8W)O<W,@86QL('5S
M97)S(&EN=&5R;F%L;'DN"EMJ86Y=(%)E=F5R<V4@<V]R=&EN9R!O<F1E<B!I
M9B!C;&EC:VEN9R!O;B!C;VQU;6X@;F%M92`H="YZ96QL0&=M>"YD92P*("`@
M("`@4F5Q=65S="`C,C0X-"DN"EMJ86Y=($%D9"!O<'1I;VX@=&\@:V5E<"!N
M86UE(&9I96QD('5N9F]R;6%T=&5D("AM+GID:6QA0&5P:7-O9G1W87)E+F-O
M;2P*("`@("`@4F5Q=65S="`C,C0T,2DN"EMM87-=(%5S92!S=6UM87)Y(&YO
M=&EF:6-A=&EO;G,@9F]R(&-O;G1A8W0@8VAA;F=E<R!I;G-T96%D(&]F(&]N
M92!N;W1I8V4@9F]R"B`@("`@(&5A8V@@8VAA;F=E+B`H0G5G(",R-S8T*0I;
M:F%N72!!9&0@0TQ)('-C<FEP="!T;R!I;7!O<G0@=D-A<F0@9&%T82X*6V-J
M:%T@4W!L:70@8VAE8VMI;F<@;V8@3$1!4"!F:65L9"!S>6YT87@@86YD(&-H
M96-K:6YG(&]F(')E<75I<F5D(&9I96QD<PH@("`@("`H=&5V86YS0'1A8VAO
M;65T<GDN8V]M+"!"=6<@(S(V,C8I+@I;;6IR72!(;W)D95]3:&%R92!S=7!P
M;W)T(&%D9&5D+B!344P@1')I=F5R(&]N;'D@9F]R(&YO=RX*6V-J:%T@57!D
M871E(&]B:F5C=&-L87-S97,@=VAE;B!S879I;F<@3$1!4"!E;G1R:65S(&-R
M96%T960@8GD@;W1H97(@8VQI96YT<PH@("`@("`H;2YZ9&EL84!E<&ES;V9T
M=V%R92YC;VTL($)U9R`C,C0P-2DN"EMC:FA=($-H87)S970M87=A<F4@:&%N
M9&QI;F<@;V8@3$1!4"!$3G,@*$)U9R`C,C,Y-2DN"EMC:FA=($=E="!R:60@
M;V8@8V%C:&5D('-E87)C:"!R97-U;'1S(&5N=&ER96QY+"!A;F0@;6]V92!M
M;W)E(&1I<W!L87D*("`@("`@8V]D92!I;G1O(%1U<F)A7TQI<W16:65W+"!S
M:6UP;&EF>6EN9R!A(&YU;6)E<B!O9B!D:69F97)E;G0*("`@("`@8V]D97!A
M=&AS(&%N9"!A=F]I9&EN9R!S97)V97)C:61E('=H96X@=7-I;F<@061V86YC
M960@4V5A<F-H+@I;;6IR72!4=7)B85]/8FIE8W0@86YD(%1U<F)A7T1R:79E
M<B!O8FIE8W1S(&%R92!N;W<@<F5S<&]N<VEB;&4@9F]R"B`@("`@(&-H96-K
M:6YG('!E<FUI<W-I;VYS(&9O<B!T:&4@<V]U<F-E<R!T:&5Y(')E<')E<V5N
M="X@(%1H:7,@86QL;W=S"B`@("`@(&-O;F-R971E(%1U<F)A7T1R:79E<B!O
M8FIE8W1S('1O(&]V97)R:61E($AO<F1E(%!E<FUS(&%N9"!P97)F;W)M"B`@
M("`@('1H96ER(&]W;B!P97)M:7-S:6]N(&-H96-K:6YG("AB>2!C:&5C:VEN
M9R!!0TQS(&9O<B!E>&%M<&QE*2X*6V-J:%T@(G)E861O;FQY(B!A;F0@(F%D
M;6EN(B!S;W5R8V4@:&%S:"!E;G1R:65S(&%R92!D97!R96-A=&5D+B!097)M
M:7-S;VYS"B`@("`@(&%R92!S970@=&AR;W5G:"!T:&4@2&]R9&4@4&5R;7,@
M54D@;F]W+@I;8VIH72!!=F]I9"!A9&1I;F<@97AA8W0@9'5P;&EC871E<R!D
M=7)I;F<@:6UP;W)T"B`@("`@("AK979I;E]M>65R0&EU,3,N;W)G+"!"=6<@
M(S$X.3(I+@I;8VIH72!(;VYO<B!T:&4@9&5L971E(&-O;F9I<FUA=&EO;B!P
M<F5F97)E;F-E('=H96X@9&ES<&QA>6EN9R!A"B`@("`@(&-O;G1A8W0@*$)U
M9R`C,3,Q-2DN"EMC:FA=($EF('1H92!C;VUM96YT<R!!4$D@:7,@879A:6QA
M8FQE+"!C;VUM96YT<R!C86X@8F4@871T86-H960@=&\*("`@("`@8V]N=&%C
M=',@*%)E<75E<W0@(S$T.3(I+@I;8VIH72!5<V5R<R!C86X@<V5L96-T('=H
M:6-H(&%D9')E<W,@8F]O:W,@=&AE>2!W:7-H('1O('5S92P@86YD(&EN"B`@
M("`@('=H:6-H(&]R9&5R('1H97D@=VEL;"!B92!D:7-P;&%Y960@*%)E<75E
M<W0@(S$V-3`I+@I;8VIH72!#;VYT86-T<R!C86X@;F]W(&)E(&%D9&5D('1O
M(&QI<W1S('-T;W)E9"!I;B!A;GD@861D<F5S<R!B;V]K"B`@("`@("A297%U
M97-T(",Q-38Q*2X*6V-J:%T@26YT<F]D=6-E(&$@(F)R;W=S92(@<V5T=&EN
M9R!O;B!S;W5R8V5S+"!S97!E<F%T92!F<F]M('1H92`B97AP;W)T(@H@("`@
M("!S971T:6YG+"!T;R!A;&QO=R!D:69F97)E;G1I871I;VX@;V8@8G)O=W-E
M86)L92!A;F0@97AP;W)T86)L90H@("`@("!S;W5R8V5S+@I;:F%N72!!9&0@
M<&5R;6ES<VEO;G,@=&\@<F5S=')I8W0@;G5M8F5R(&]F(&-O;G1A8W1S('!E
M<B!A9&1R97-S(&)O;VLN"EMC:FA=($%D9"!E>'!O<G1I;F<@;V8@;75L=&EP
M;&4@=D-A<F1S(&EN(&]N92!F:6QE('1H<F]U9V@@=&AE(&5X<&]R=`H@("`@
M("!I;G1E<F9A8V4@*$9R86YK(%)O<W%U:6X@/&9R86YK+G)O<W%U:6Y`9VUA
M:6PN8V]M/BDN"EMM:G)=($%D9&5D('-U<'!O<G0@9F]R(&%D9&EN9R!A;F0@
M9&5L971I;F<@24U34"!A9&1R97-S8F]O:W,@=FEA('1H92!O<'1I;VYS"B`@
M("`@(&EN=&5R9F%C92`H4F5Q=65S="`C,34W."D*6VUJ<ET@4VAO=R!P<F5V
M:6]U<R!S96%R8V@@<F5S=6QT<R!W:&5N979E<B!R971U<FYI;F<@=&\@=&AE
M('-E87)C:"!P86=E+@I;8VIH72!(86YD;&4@96YC;V1I;F<@;V8@<&]S=&%L
M061D<F5S<R!F:65L9',@=&\@=7-E("0@9F]R(&YE=VQI;F5S+"!G;VEN9PH@
M("`@("!E:71H97(@8GD@871T<FEB=71E<RYP:'`@;W(@8GD@=&AE($Q$05`@
M<V-H96UA(&ET<V5L9B`H161W87)D(%)U9&0*("`@("`@/&5D9&EE0&]M96=A
M=V%R92YC;VT^+"!297%U97-T(",R*2X*6VUJ<ET@4V5A<F-H('1E<FUS(&]N
M(&-O;7!O<VET92!F:65L9',@87)E(&YO=R!T86ME;B!A<R!A('-P86-E(&1E
M;&EM:71E9`H@("`@("!L:7-T(&]F('-T<FEN9W,@=&AA="!A<F4@96%C:"!/
M4B=D(&%G86EN<W0@96%C:"!F:65L9"!M86MI;F<@=7`@=&AE"B`@("`@(&-O
M;7!O<VET92!F:65L9"`@86YD('1H96X@8W5M=6QA=&EV96QY($%.1"=D('1O
M9V5T:&5R+@I;:F%N72!3:&]W('=A<FYI;F=S(&9R;VT@0U-6(&EM<&]R=',N
M"EMJ86Y=($%D9"`B061D(B!A;F0@(E-E87)C:"(@96YT<FEE<R!T;R!S:61E
M8F%R(&UE;G4N"EMJ86Y=(%)E='5R;B!T;R!O<FEG:6YA;"!B<F]W<V4@=FEE
M=R!A9G1E<B!F:6YI<VAI;F<@9W)O=7`@961I=&EN9RX*6VIA;ET@061D('-U
M8FUE;G4@=VET:"!A9&1R97-S(&)O;VMS('1O('-I9&5B87(N"EMJ86Y=($%L
M;&]W('1O('-P96-I9GD@8VAA<G-E="!O9B!I;7!O<G1E9"!#4U8@9FEL97,N
M"EMC:FA=(%!A<W,@=&AE(%1U<F)A7T%B<W1R86-T3V)J96-T('1O(&%T=')I
M8G5T92!H;V]K<R!T;R!A;&QO=R!A8V-E<W,@=&\*("`@("`@;W1H97(@871T
M<FEB=71E('9A;'5E<R`H9F]R(&5X86UP;&4L('1O(&)U:6QD(&$@9FEE;&0G
M<R!V86QU92!O=70@;V8*("`@("`@;W1H97(@9FEE;&1S*2X*6VIA;ET@4VAO
M=R!L:7-T(&]F(&5D:71E9"!C;VYT86-T<R!B96QO=R!E9&ET(&9O<FT@=VAE
M;B!E9&ET:6YG('-E=F5R86P*("`@("`@8V]N=&%C=',@870@;VYC92X*6VIA
M;ET@061D(%9&4R!S=7!P;W)T('1O(&%T=&%C:"!F:6QE<R!T;R!C;VYT86-T
M<RX*6VIA;ET@06QL;W<@=&\@961I="!S979E<F%L(&-O;G1A8W1S(&%T(&]N
M8V4N"EMJ86Y=(%)E=')I979E(&]N;'D@<F5Q=6ER960@9FEE;&1S(&9R;VT@
M8F%C:V5N9"X*"@HM+2TM+2T*=C(N,"XU"BTM+2TM+0H*6V-J:%T@0VQO<V4@
M<V5V97)A;"!84U,@=G5L;F5R86)I;&ET:65S('=I=&@@861D<F5S<R!B;V]K
M(&%N9"!C;VYT86-T(&1A=&$N"@H*+2TM+2TM"G8R+C`N-`HM+2TM+2T*"EMJ
M86Y=($9I>"!S;W5R8V4@<V5L96-T:6]N(&EN('-O;64@05!)(&UE=&AO9',@
M*'1E=F%N<T!T86-H;VUE=')Y+F-O;2P*("`@("`@0G5G(",R-C(S*2X*6VIA
M;ET@1FEX('=A<FYI;F=S(&EN(&-O;'5M;G,@<')E9F5R96YC92!S8W)E96XN
M"EMM:G)=($-H96-K(&9O<B!G;&]B86P@24U34"!C;VYF:6=U<F%T:6]N(&%N
M9"!U<V4@:68@<')E<V5N="X*6VUA<UT@4F5S=&]R92!"0R!I;B!S96%R8VAI
M;F<@=7-I;F<@4U%,(&1R:79E<BX@*$)U9R`C,C0Q.2D*"@HM+2TM+2T*=C(N
M,"XS"BTM+2TM+0H*6VIA;ET@061D(%1U<FMI<V@@=')A;G-L871I;VX@*%-E
M<G9E="!'_&YE>2`\<V=U;F5Y0&UE='4N961U+G1R/BP@06AM970@UGIT_')K
M"B`@("`@(#QO86AM971`;65T=2YE9'4N='(^*2X*"@HM+2TM+2TM+2TM"G8R
M+C`N,RU20S$*+2TM+2TM+2TM+0H*6VIA;ET@1&]N)W0@<VAO=R`B061D(B!I
M8V]N(&EF(&YO('=R:71E86)L92!A9&1R97-S(&)O;VMS(&5X:7-T+@I;:F%N
M72!$;VXG="!S:&]W(")"<F]W<V4B(&EC;VX@86YD(&QI<W0@:68@;F\@8G)O
M=W-E86)L92!A9&1R97-S(&)O;VMS(&5X:7-T+@I;:F%N72!!9&0@97AA;7!L
M92!H;W<@=&\@=7-E(&$@9FEE;&0@9F]R($AO<F1E)W,@8V%T96=O<GD@<WES
M=&5M+@I;8VIH72!!;&QO=R!U:60@=&\@8F4@=7-E9"!I;B!K97D@9V5N97)A
M=&EO;B`H97-P96-I86QL>2!U<V5F=6P@9F]R($Q$05`*("`@("`@8F%C:V5N
M9',@=&AA="!W86YT('1O('5S92!U:60@:6X@=&AE($1.*2`H0G5G(",R,#(W
M*2X*6VUJ<ET@1FEX(&)U9R!W:&5R92!S96%R8V@@<F5S=6QT<R!A<F4@;F]T
M(&1I<W!L87EE9"!W:&5N(&YO(&)R;W=S96%B;&4*("`@("`@861D<F5S<V)O
M;VMS(&5X:7-T(&%N9"!B=6<@=VAE<F4@=&AE(&)R;W=S92!A='1R:6)U=&4@
M:7,@:6=N;W)E9"!F;W(*("`@("`@861D<F5S<V)O;VMS('1H870@87)E('-E
M="!A<R!D969A=6QT+"!A;&QO=VEN9R!A(&YO;BUB<F]W<V5A8FQE"B`@("`@
M(&%D9')E<W-B;V]K('1O(&)E(&)R;W=S960@*$)U9R`C,3DU.2DN"EMJ86Y=
M($EM<&]R="!A;F0@97AP;W)T(&]F(&)I<G1H9&%Y<R!W:71H('9#87)D<R`H
M=&AO;6%S0&=E;&8N;F5T+"!"=6<@(S$R-CDI+@I;:F%N72!&:7@@;6EN:2!S
M96%R8V@@<&]R=&%L(&)L;V-K('=I=&@@;F]N+6%S8VEI('-E87)C:"!S=')I
M;F=S("A"=6<@(S$V,#4I+@I;8VIH72!!9&0@82!G96YE<FEC(%-13"!U<&=R
M861E('-C<FEP="P@<F5P;&%C:6YG('1H92!->5-13"US<&5C:69I8PH@("`@
M("!V97)S:6]N("A"=6<@(S$W.#$I+@I;;6IR72!5<V4@861D<F5S<V)O;VL@
M;F%M92!A<R!P87)T(&]F(&-A8VAE(&ME>2!T;R!P<F5V96YT(&)R96%K:6YG
M('-I;6EL87(*("`@("`@<V5A<F-H97,@;VX@9&EF9F5R96YT($E-4U`@861D
M<F5S<V)O;VMS+@I;8VIH72!5<V4@8FEN9"!V87)I86)L97,@:6X@=&AE(%-1
M3"!D<FEV97(@*'-E;'-K>4!C;VQU;6)I82YE9'4L($)U9R`C,38U,2DN"EMM
M:G)=($9I>"!A<&D@<V5A<F-H*"D@;65T:&]D('1O(&-O<G)E8W1L>2!D96%L
M('=I=&@@8V]N=&%C=',@8V]N=&%I;FEN9PH@("`@("!M=6QT:7!L92!E;6%I
M;"UT>7!E(&9I96QD<R`H0G5G(",Q,C@T*2X*6V-J:%T@1FEX(%]R96%D*"D@
M9F]R(&UU;'1I<&QE(&]B:F5C=',@:6X@=&AE($Q$05`@9')I=F5R("A"=6<@
M(S$U,C`I+@I;;6IR72!#86-H92!)35-0('-E87)C:"!R97-U;'1S('=H96X@
M<V5N9&EN9R!M=6QT:7!L92!)35-0('-E87)C:&%D9')E<W,*("`@("`@8V]M
M;6%N9',@9F]R('1H92!S86UE('-E87)C:"X*6V-J:%T@4VAO=R!A8W1I;VYS
M(&%N9"!B<F]W<V4@;&5T=&5R<R!A="!T:&4@=&]P(&%N9"!B;W1T;VT@;V8@
M8V]N=&%C=`H@("`@("!L:7-T:6YG<R`H0G5G(",Q,S$R+"!"=6<@(S$T-3@I
M+@I;:F%N72!!9&0@<VAO<G1C=70@:6-O;B`H9F%V:6-O;BYI8V\I+@I;;6IR
M72!3:&]W($-O;G1A8W1S(&%N9"!3:&]W($=R;W5P<R!L:6YK<R!N;W<@=V]R
M:R!C;W)R96-T;'D@=VET:"!)35-0(&1R:79E<BX*6VIA;ET@1&]N)W0@:6YC
M;'5D92!N86UE<R!I;B!E;6%I;"!F:65L9',@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S(')E=')I979E9`H@("`@("!T:')O=6=H('1H92`B<V5A<F-H(B!!4$D@
M;65T:&]D("A"=6<@(S$S.#0I+@H*"BTM+2TM+0IV,BXP+C(*+2TM+2TM"@I;
M:F%N72!&:7AE9"!W87)N:6YG(&EN(&)R;W=S92!V:65W("A"=6<@(S$S-C,I
M+@H*"BTM+2TM+0IV,BXP+C$*+2TM+2TM"@I;:F%N72!&:7AE9"!S;VUE(&IA
M=F%S8W)I<'0@97)R;W)S('=H96X@8VQI8VMI;F<@;VX@=&AE(&-O;'5M;B!H
M96%D97)S('1O"B`@("`@(')E<V]R="!C;VYT86-T(&QI<W1I;F=S("A"=6<@
M(S$S,3,I+@I;8VIH72!1=6]T92!,1$%0($1.(&5N=')I97,@86-C;W)D:6YG
M('1O(%)&0R`Q-#@U("A"=6<@(S$Q-#8I+@I;8VIH72!7:&5N(&EM<&]R=&EN
M9R!V0V%R9"`S+C`@0412(&9I96QD<RP@=')Y('1O(&)U:6QD(&$@8V]M<&]S
M:71E(&5N=')Y(&9O<@H@("`@("!W;W)K061D<F5S<R!O<B!H;VUE061D<F5S
M<RP@86YD(&ME97`@=&AE('-T<F5E="!A9&1R97-S(&EN('=O<FM3=')E970@
M;W(*("`@("`@:&]M95-T<F5E="`H0G5G(",Q,3`Y*2X*6VIA;ET@26UP;&5M
M96YT($]2('-E87)C:&5S(&EN($E-4U`@9')I=F5R("A-:6-H865L(%)U8FEN
M<VMY"B`@("`@(#QM:6ME0'1H975P<W1A:7)S<F]O;2YC;VT^+"!"=6<@(S$R
M-38I+@H*"BTM+2TM+2TM+2T*=C(N,"XQ+5)#,0HM+2TM+2TM+2TM"@I;:F%N
M72!#<F5A=&4@8V]M<&]S92!L:6YK<R!F;W(@86QL(&5M86EL(&%D9')E<W-E
M<R!A="!O;F-E(&EN(&-O;G1A8W0@;&ES=&EN9W,*("`@("`@*')E<75I<F5S
M($E-4"`T+C`N,BDN"EMJ86Y=($]P96X@8V]M<&]S92!W:6YD;W=S(&9R;VT@
M=&AE('!O<G1A;"=S(&UI;FES96%R8V@@8FQO8VL@:6X@=&AE(&-O<G)E8W0*
M("`@("`@9G)A;64@*$)U9R`C,3(Y,RDN"EMJ86Y=(%-E=F5R86P@<&5R9F]R
M;6%N8V4@;W!T:6UI>F%T:6]N<RX*6VIA;ET@1&]N)W0@<F5T=7)N(&5M<'1Y
M(')E<W5L="!S971S(&EN('-E87)C:"!!4$D@*$)U9R`C,3(Q,"DN"EMC:FA=
M(%-U<'!O<G0@5$Q3(&-O;FYE8W1I;VYS('1O($Q$05`@<V5R=F5R<R`H0G5G
M(",Q,30Y*2X*"@HM+2TM"G8R+C`*+2TM+0H*6V-J:%T@54E$<R!N965D('1O
M(&)E('-T;W)E9"!I;B!T:&4@2&ES=&]R>2!S>7-T96T@=VET:"!A('1U<F)A
M.B!P<F5F:7@@86YD"B`@("`@('=I=&@@=&AE(&-O;G1A8W0@;W=N97(@<V\@
M87,@;F]T('1O(&-O;F9U<V4@9&EF9F5R96YT(&EN<W1A;F-E<R!O9B!T:&4*
M("`@("`@<V%M92!C;VYT86-T("AI9B!T=V\@=7-E<G,@8F]T:"!H879E(&$@
M8V]N=&%C="!I;B!T:&5I<B!S97!E<F%T90H@("`@("!A9&1R97-S8F]O:W,@
M:6X@82!P<FEV871E('-O=7)C92P@=&AE>2!S:&]U;&0@:&%V92!U;FEQ=64@
M:&ES=&]R:65S(&9O<@H@("`@("!T:&]S92!C;VYT86-T<RDN"EMC:FA=($EM
M<')O=F4@97)R;W(@86YD('!E<FUI<W-I;VX@8VAE8VMI;F<N"@H*+2TM+2TM
M+2T*=C(N,"U20S,*+2TM+2TM+2T*"EMC:FA=(%!R979E;G0@8V]P>6EN9R]M
M;W9I;F<@;V8@9W)O=7!S("A"=6<@(SDS-2DN"EMC:FA=($9I>"!)35-0(&=R
M;W5P<R`H36EC:&%E;"!2=6)I;G-K>2`\;6EK94!T:&5U<'-T86ER<W)O;VTN
M8V]M/BD*6VIA;ET@1FEX('!R;W!A9V%T:6YG(&]F(&UO;G1H9&%Y>65A<B!F
M:65L9',@*$)U9R`C.3(P*2X*6VIA;ET@1FEX(%-/05`@;F%M97-P86-E(&9O
M<B!!4$D@;65T:&]D('-I9VYA='5R97,N"EMC:FA=($-H86YG92!T;R!4=7)B
M83HZ9V5T365N=2@I+"!F:7AE<R!T:&4@;65N=2!O;B!T:&4@3W!T:6]N<R!S
M8W)E96X@*$)U9PH@("`@("`C.#DX*2X*6VIA;ET@1FEX('-O;64@:F%V87-C
M<FEP="!E<G)O<G,@=VET:"!)12`U+C`N"@H*+2TM+2TM+2T*=C(N,"U20S(*
M+2TM+2TM+2T*"EMC:FA=($1O;B=T(&]V97)W<FET92!F;W)M(&1A=&$@=VET
M:"!O8FIE8W0@9&5F875L=',@=VAE;B!E9&ET:6YG(&EF"B`@("`@('9A;&ED
M871I;VX@9F%I;',@*$)U9R`C.#@S*2X*6V-J:%T@57-E('-O=7)C92!P97)M
M:7-S:6]N<R!I9B!T:&5Y(&%R92!P<F5S96YT+"!A;F0@:68@;F]T+"!F86QL
M(&)A8VL@=&\@=&AE"B`@("`@(&]L9"!S;W5R8V4@861M:6X@87)R87D@*$)U
M9R`C.#4S*2X*6V-J:%T@26=N;W)E(&%N>2!?7RUP<F5F:7AE9"!A='1R:6)U
M=&4@:6X@8G5I;&1I;F<@<V5A<F-H(&-R:71E<FEA("A"=6<@(S@W-RDN"@H*
M+2TM+2TM+2T*=C(N,"U20S$*+2TM+2TM+2T*"EMM;7-=($9I>&5D('1H92!D
M96QE=&4@05!)('1O(&YO="!E>&ET('=I=&@@97)R;W(@:68@=&AE(&ET96T@
M=&\@8F4@9&5L971E9`H@("`@("!I<R!N;W0@9F]U;F0@:6X@=&AE(&9I<G-T
M('-O=7)C92!P<F]V:61E9"X*6V-J:%T@4F5M;W9E9"!M:6YI=VEN9&]W+G!H
M<#L@:70@<VEM<&QY('!R;W9I9&5D(&$@9G)A;64@87)O=6YD(%1U<F)A"B`@
M("`@('=I=&@@82!C;&]S92!B=71T;VXN"@H*+2TM+2TM+2TM"G8R+C`M0D54
M00HM+2TM+2TM+2T*"EMJ86Y=($%L;&]W('1O(&=R;W5P(&9I96QD<R!I;G1O
M('1A8G,N"EMM;7-=($QI;FL@96UA:6P@861D<F5S<R!I;B!O8FIE8W0@=FEE
M=RX*6V-J:%T@365R9V4@=&AE(&-O9&4@9F]R(%1U<F)A7U-O=7)C92!A;F0@
M5'5R8F%?1')I=F5R(&EN=&\@<VEM<&QY"B`@("`@(%1U<F)A7T1R:79E<BX*
M6VIA;ET@061D(%!E<G-I86X@*%=E<W1E<FXI('1R86YS;&%T:6]N("A686AI
M9"!':&%F87)P;W5R"B`@("`@(#QV86AI9$!G:&%F87)P;W5R+F-O;3XI+@I;
M:F%N72!!9&0@8V]N9FEG=7)A=&EO;B!O<'1I;VX@=&\@<F5Q=6ER92!C97)T
M86EN(&9I96QD<R!I;B!T:&4@3$1!4"!D<FEV97(N"B`@("`@("A487)J96D@
M2'5S92`\=&%R:F5I*V%?;&ES=',N<&AP9W=`;G4N;F\^*2X*6V-J:%T@4W5P
M<&]R="!C=7-T;VT@9FEE;&0@;6%P<&EN9W,@:6X@0U-6(&5X<&]R=',L(&%N
M9"!A9&0@86X@3W5T;&]O:R!E>'!O<G0*("`@("`@='EP92X*6V-J:%T@06QL
M;W<@<F5P;&%C:6YG('EO=7(@861D<F5S<V)O;VL@=VET:"!A;B!I;7!O<G1E
M9"!O;F4@*$9R86YC;VES($UA<FEE<@H@("`@("`\9G)A;F-O:7-`;FET+F-A
M/BDN"EMC:FA=($1O;B=T('-H;W<@<V]U<F-E('-E;&5C=&EO;B!D<F]P9&]W
M;G,@:6X@8V%S97,@=VAE<F4@=&AE<F4@=V]U;&0@;VYL>2!B90H@("`@("!O
M;F4@8VAO:6-E("A&<F%N8V]I<R!-87)I97(@/&9R86YC;VES0&YI="YC83XI
M+@I;8VIH72!4=7)B82=S($%022!H87,@8F5E;B!C;VYS;VQI9&%T960@<V]M
M97=H870L('=I=&@@82!U;FEF:65D(&EM<&]R="!M971H;V0*("`@("`@<F5P
M;&%C:6YG(&%D9"P@861D0V]N=&%C="P@86YD(&EM<&]R=%]V8V%R9"X*6VIA
M;ET@061D(&%C8V5S<R!K97ES+@I;8VIH72!!9&0@2V]L86(@9')I=F5R<R`H
M4W1U87)T($)I;F?K(#QS+F)I;F=E0&-O9&5F=7-I;VXN8V\N>F$^*2X*6V-J
M:%T@5&AE(&%L<&AA8F5T:6,@<&%G97(@;F]W(&AA<R!A;B`B06QL(B!O<'1I
M;VXN"@H*+2TM+2TM+2TM+0IV,BXP+4%,4$A!"BTM+2TM+2TM+2T*"EMC:FA=
M(%-H;W<@86X@86QP:&%B971I8R!P86=E<B!F;W(@8G)O=W-I;F<@861D<F5S
M<R!B;V]K<R`H36EK92!">61A;&5K"B`@("`@(#QM8GED86QE:T!Z:79I>"YC
M;VT^*2X*6V-J:%T@4F5N86UE($Q$05`@;V)J96-T<R!W:&5N('1H96ER($1.
M(&-H86YG97,@*%1A<FIE:2!(=7-E"B`@("`@(#QT87)J96DK85]L:7-T<RYP
M:'!G=T!N=2YN;SXI+@I;8VIH72!!9&0@97AP;W)T:6YG(&]F(%9#87)D<R!F
M<F]M('1H92!B<F]W<V4O<V5A<F-H('9I97<@*$UI:V4@0GED86QE:PH@("`@
M("`\;6)Y9&%L96M`>FEV:7@N8V]M/BDN"EMC:FA=($EN:71I86P@24U34"!D
M<FEV97(@*$UI8VAA96P@4G5B:6YS:WD@/&UI:V5`=&AE=7!S=&%I<G-R;V]M
M+F-O;3XI+@I;8VIH72!5<V4@2&]R9&5?54E?4&%G97(@=&\@<&%G92!B<F]W
M<V4@<F5S=6QT<R`H2F]E;"!686YD86P*("`@("`@/&IV86YD86Q`:6YF;W1E
M8VLN<6,N8V$^*2X*6V-J:%T@0F%S:6,@<W5P<&]R="!F;W(@<V5T=&EN9R!P
M97)M:7-S:6]N<R!O;B!4=7)B82!S;W5R8V5S("A*;V5L(%9A;F1A;`H@("`@
M("`\:G9A;F1A;$!I;F9O=&5C:RYQ8RYC83XI+@I;8VIH72!5;FEF>2!S96%R
M8V@@86YD(&%D=F%N8V5D('-E87)C:"!C;V1E('1O('5S92!A(&UU8V@@;6]R
M92!S:6UI;&%R"B`@("`@(&EN=&5R9F%C92`H2F]E;"!686YD86P@/&IV86YD
M86Q`:6YF;W1E8VLN<6,N8V$^*2X*6V-J:%T@2F%V87-C<FEP="!D96QE=&4@
M8V]N9FER;6%T:6]N(&ES(&YO=R!A=F%I;&%B;&4@87,@82!P<F5F97)E;F-E
M("@B5RX*("`@("`@1&%V:60@0F5T=',B(#QD879I9$!P;W!U;'5S+F-O;3XI
M+@I;8VIH72!396%R8VAI;F<@8V]M<&]S:71E(&9I96QD<RP@86YD(&]T:&5R
M(&-O;7!L97@@9V5N97)A=&5D('-E87)C:&EN9RP@;F]W"B`@("`@('=O<FMS
M('=I=&@@=&AE($Q$05`@9')I=F5R+@I;8VIH72!4<F%C:R!A9&1I=&EO;BP@
M;6]D:69I8V%T:6]N+"!A;F0@9&5L971I;VX@;V8@8V]N=&%C=',@=VET:"!T
M:&4@2&]R9&4*("`@("`@2&ES=&]R>3HZ($%022X*6V-J:%T@57-E(&%R8FET
M<F%R>2!S96%R8V@@<W5P<&]R="!T;R!I;F-L=61E('-E87)C:&EN9R!O9B!C
M;VUP;W-I=&4@9FEE;&1S+@I;8VIH72!4=7)B85]$<FEV97)S(&%R92!N;W<@
M8V%P86)L92!O9B!A<F)I=')A<GD@<V5A<F-H97,L(&EN8VQU9&EN9R!U;FQI
M;6ET960*("`@("`@;F5S=&5D(&-O;6)I;F%T:6]N<R!O9B!!3D0@86YD($]2
M('-E87)C:&5S+@I;8VIH72!!9&0@=&AE(&%B:6QI='D@=&\@;&EN:R!F:65L
M9',@:6X@=&AE(&)A8VME;F0@:6YT;R!A(&-O;7!O<VET92!F:65L9"P*("`@
M("`@=VAI8V@@:7,@;F]T(&5D:71A8FQE+"!B=70@=VAI8V@@9&ES<&QA>7,@
M=&AE(&-O<G)E8W0@=F%L=64N"EMC:FA=($%D9"!T:&4@86)I;&ET>2!T;R!M
M;W9E(&]R(&-O<'D@8V]N=&%C=',@=&\@82!S97!A<F%T92!A9&1R97-S8F]O
M:RX*6V-J:%T@1&ES<&QA>2!M=6QT:7!L92!E;6%I;"!A9&1R97-S97,@;6]R
M92!I;G1E;&QI9V5N=&QY("A*;VAN($1A;&)E8PH@("`@("`\:G!D86QB96-`
M>7-U+F5D=3XI+@I;8VIH72!!;&QO=R!S971T:6YG(&$@;&EM:70@;VX@=&AE
M(&YU;6)E<B!O9B!Q=65R:65S(')E='5R;F5D(&)Y(&%N($Q$05`*("`@("`@
M<V5A<F-H("A!;F1R97<@36]R9V%N(#QM;W)G86Y`;W)S="YE9'4^*2X*6V-J
M:%T@061D(&5D:70O9&5L971E(&QI;FMS(&EN(&)R;W=S92!V:65W<RX*6V-J
M:%T@4')E9F5R96YC92!F;W(@9&5F875L="!D:7)E8W1O<GD@9F]R('-E87)C
M:&5S+"!E=&,N("A2:6-H87)D($AE9V=S"B`@("`@(#Q2:6-H87)D+DAE9V=S
M0&YO='1I;F=H86UC:71Y+F=O=BYU:SXI+@I;8VIH72!!9&0@<W5P<&]R="!F
M;W(@;&ES=&EN9R]A9&1I;F<O<F5T<FEE=F%L(&]F('!U8FQI8R!K97ES("A-
M:6-H865L($T*("`@("`@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3XI+@I;8VIH72!5<V4@=&AE(&YE=R!0<F5F<U5)(&-L87-S+@I;
M:F]N72!!9&%P="!T;R!T:&4@;F5W($AO<F1E.CII;6<H*2!S>6YT87@N"EMC
M:FA=(%5S92!T:&4@;F5W($YO=&EF:6-A=&EO;B!S>7-T96TN"EMJ86Y=(%)E
M;6]V92!T:&4@<W1A;F1A<F0@=F%L=64@9F]R('1H92!L86YG=6%G92!P<F5F
M97)E;F-E+B!4:&4@;&%N9W5A9V4@=&\*("`@("`@9F%L;"!B86-K('1O('-H
M;W5L9"!B92!S970@2&]R9&4@=VED92!I;B!L86YG+G!H<"!I;G-T96%D+@H*
M"BTM+2TM+0IV,2XR+C4*+2TM+2TM"@I;:F%N72!#;&]S92!84U,@=VAE;B!S
M971T:6YG('1H92!P87)E;G0@9G)A;64G<R!P86=E('1I=&QE(&)Y(&IA=F%S
M8W)I<'0@*&-J:"DN"EMJ86Y=($9I>"!W87)N:6YG('=I=&@@3$1!4"!B86-K
M96YD<RX*"@HM+2TM+2T*=C$N,BXT"BTM+2TM+0H*6VIA;ET@1FEX(&1I<W1R
M:6)U=&EO;B!L:7-T<RX*"@HM+2TM+2T*=C$N,BXS"BTM+2TM+0H*6V-J:%T@
M0VAE8VL@<&5R;6ES<VEO;B!W:&5N(&%D9&EN9R!A;F0@9&5L971I;F<@;V)J
M96-T<R`H0G5G(",V-S$I+@I;:F%N72!&:7@@8G5G(&EN($Q$05`@9')I=F5R
M('=I=&@@9&X@=F%L=65S(&YO="!B96EN9R!55$8X(&5N8V]D960@*$)U9R`C
M,S<X*2X*6VIA;ET@1FEX('-O<G1I;F<@8GD@8V]L=6UN<R!I;B!B<F]W<V4@
M=FEE=RX*6V-J:%T@57-E('!R97!A<F4O97AE8W5T92!I;B!T:&4@4U%,(&1R
M:79E<B!T;R!S=7!P;W)T(&QA<F=E(&9I96QD<R!O;B!/<F%C;&4*("`@("`@
M86YD(&]T:&5R(&1A=&%B87-E<R`H36%T="!396QS:WD@/'-E;'-K>4!C;VQU
M;6)I82YE9'4^*2X*6VIA;ET@1&]N)W0@8W)E871E(&1I<W1R:6)U=&EO;B!L
M:7-T(&EF('!R;V-E<W,@9V5T<R!C86YC96QL960@*$)U9R`C,S<W*2X*"@HM
M+2TM+2T*=C$N,BXR"BTM+2TM+0H*6VIA;ET@061D($=A;&EC:6%N('1R86YS
M;&%T:6]N("A2869A96P@5F%R96QA(%!E="`\<W)R869A0'5S8RYE<SXL($=U
M:6QL97)M;PH@("`@("!-96YD97H@/&=U:6QL94!U<V,N97,^*2X*"@HM+2TM
M+2T*=C$N,BXQ"BTM+2TM+0H*6VIA;ET@1FEX(&EM<&]R=&EN9R!O9B!V0V%R
M9"`R+C$@9&%T82!T:&%T(&-O;G1A:6YS(&-O;6UA<R`H;F5E9',@2&]R9&4@
M,BXR+C0I+@I;:F%N72!-86ME('-O<G1I;F<@;W)D97(@9&5P96YD96YT(&]F
M('1H92!N86UE(&9O<FUA="`H4V5R9V5Y(%IH=6MO=@H@("`@("`\<V5R9V5Y
M0&EN=&5L;&EJ+FYE=#XI+@I;:F%N72!!9&0@07)A8FEC("A3>7)I82D@=')A
M;G-L871I;VX@*%!L871I;G5M($1E=F5L;W!M96YT(%1E86T*("`@("`@/&1E
M=G1E86U`<&QA=&EN=6TM<WDN;F5T/BDN"EMJ86Y=($%D9"!-86-E9&]N:6%N
M('1R86YS;&%T:6]N("A3=&]J86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M+FUK
M/BDN"EMJ86Y=($%D9"!2;VUA;FEA;B!T<F%N<VQA=&EO;B`H175G96X@2&]A
M;F-A(#QE=6=E;FA`=7)B86XM9W)A9G@N<F\^+"!-87)I=7,*("`@("`@1')A
M9W5L97-C=2`\;6%R:75S9$!U<F)A;BUG<F%F>"YR;SXI+@I;8VIH72!296UO
M=F4@9&5P96YD96YC>2!O;B!C;&%S<R!N;W0@:6X@2&]R9&4@,BYX+@H*"BTM
M+2T*=C$N,@HM+2TM"@I;8VIH72!5<V4@=&AE("=O8FIE8W1C;&%S<R<@96YT
M<GD@9G)O;2!,1$%0('-O=7)C97,@:6YS=&5A9"!O9B!D969A=6QT:6YG('1O
M"B`@("`@("=O8FIE8W1C;&%S<STJ)RX*6VIA;ET@061D($-A=&%L86X@=')A
M;G-L871I;VX@*$%N9V5L<R!'=6EM97+@(#QA;F=E;',N1W5I;65R84!U86(N
M97,^*2X*6VIA;ET@061D(&$@<')E9F5R96YC92!F;W(@=FEE=VEN9R!N86UE
M<R!A<R!,87-T;F%M92P@1FER<W1N86UE("A-87)C($IA=79I;@H@("`@("`\
M;6%R8T!R96=I<W1E<C1L97-S+F-O;3XI+@I;:F%N72!!9&0@3&%T=FEA;B!T
M<F%N<VQA=&EO;B`H2V%S<&%R<R!+87!E;FEE:W,@/&MA<W!A<G-`<F-C+FQV
M/BDN"EMC:FA=($-L;W-E('-E=F5R86P@<VUA;&P@6%-3('9U;&YE<F%B:6QI
M=&EE<R`H36ET:F$@2V]L<V5K"B`@("`@(#QM:71J82YK;VQS96M`86-R;W,N
M<VD^*2X*6V-J:%T@1FEX('!R;V)L96US('=I=&@@8V%C:&5D('-E87)C:"!R
M97-U;'1S(&9R;VT@9&EF9F5R96YT(&)A8VME;F1S+@I;:F%N72!)9B!A;B!,
M1$%0(&1I<F5C=&]R>2!I<R!C;VYF:6=U<F5D('1O('5S92!U=&8X(&5N8V]D
M:6YG+"!E;F-O9&4*("`@("`@871T<FEB=71E<R!W:&5N(&%D9&EN9R!T:&5M
M('1O('1H92!D:7)E8W1O<GD@*&-J:"DN"EMJ86Y=($%D9"!4=7)B85],:7-T
M.CIR96UO=F4H*2`H8VIH*2X*6VIA;ET@061D(%1U<F)A7T]B:F5C=#HZ9G)O
M;79#87)D*"D@*&-J:"DN"EMJ86Y=($%D9"!A(')E9VES=')Y('-C<FEP="!F
M;W(@5'5R8F$@*$UI8VAA96P@0V]C:')A;F4*("`@("`@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^*2X*6VIA;ET@061D(&1I<W1R:6)U=&EO;B!L:7-T('-U
M<'!O<G0@*$UI8VAA96P@0V]C:')A;F4*("`@("`@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^*2X*6VIA;ET@061D('!E<G-O;F%L($Q$05`@861D<F5S<R!B
M;V]K($A/5U1/(&%N9"!E>&%M<&QE("AC:F@I+@I;:F%N72!!9&0@9V5N97)I
M8R!A9&0L(&1E;&5T92P@9V5T+"!L:7-T($%022!F=6YC=&EO;G,@9F]R('-P
M96-I9FEC(&9I96QD<PH@("`@("`H;6US*2X*6VIA;ET@061D(%1U<F)A.CIA
M9&1087)A;65T97(H*2X*6VIA;ET@061D($QI=&AU86YI86X@=')A;G-L871I
M;VX@*$1A<FEU<R!-871U;&EA=7-K87,@/&1A<FEU<T!L;FLN;'0^*2X*6V-J
M:%T@061D(&$@;6EN:7=I;F1O=R!I;G1E<F9A8V4@=&AA="!C86X@8F4@=7-E
M9"!I;B!P;W!U<',@9G)O;2!O=&AE<@H@("`@("!A<'!L:6-A=&EO;G,N"EMC
M:FA=($%D9"!P<F5F97)E;F-E<RUB87-E9"!A9&1R97-S8F]O:R!C87!A8FEL
M:71Y(&9O<B!S;6%L;"P@<')I=F%T90H@("`@("!A9&1R97-S8F]O:W,N"EMC
M:FA=($UA:V4@<W5R92!V0V%R9"!E;6%I;"!A9&1R97-S97,@87)E(&EM<&]R
M=&5D(&%S(&IU<W0@=&AE(&5M86EL(&%D9')E<W,L"B`@("`@(&YO="!A<R!0
M97)S;VYA;"!);F9O(#QA9&1R97-S0&5X86UP;&4N8V]M/BX*6V-J:%T@061D
M(%1U<F)A.CIG971"87)E061D<F5S<R@I(&9O<B!C;VYV97)T:6YG(")097)S
M;VYA;"!);F9O"B`@("`@(#QA9&1R97-S0&5X86UP;&4N8V]M/B(@:6YT;R!J
M=7-T(&%D9')E<W-`97AA;7!L92YC;VTN"EMJ86Y=($%D9"!"=6QG87)I86X@
M=')A;G-L871I;VX@*$UI<F]S;&%V(%!E;F1E=B`\<&5N9&5V0&AO=&UA:6PN
M8V]M/BDN"EMC:FA=($%D9"!L:6YK<R!T;R!-87!1=65S="!F<F]M(&%D9')E
M<W,@9FEE;&1S+@I;:F%N72!087-S(&-O;G1A8W0@;F%M92!T;R!C;VUP;W-E
M(&QI;FL@:6X@9&ES<&QA>2!V:65W+@I;:F%N72!297!L86-E(#P_/2!W:71H
M(#P_<&AP(&5C:&\@=&\@<F5M;W9E('1H92!S:&]R=%]O<&5N7W1A9W,@<F5Q
M=6ER96UE;G0*("`@("`@*&-J:"DN"EMJ86Y=($9I>"!P<F5F97)E;F-E(&9O
M<B!D969A=6QT('9I97<N"EMJ86Y=($%D9"!I;7!O<G0O97AP;W)T(&9I;'1E
M<B!F;W(@5%-6+"!-=6QB97)R>2!A;F0@4&EN92`H3&EA;2!(;V5K96YG80H@
M("`@("`\;&EA;7)`=6UI8V@N961U/BDN"@H*+2TM+0IV,2XQ"BTM+2T*"EMJ
M86Y=($%D9"!(=6YG87)I86X@=')A;G-L871I;VX@*$QA<WIL;R!,+B!4;W)N
M;V-I(#QT;W)L87-Z0'AE;FEA+G-O=&4N:'4^*2X*6VIA;ET@061D($YO<G=E
M9VEA;B!.>6YO<G-K('1R86YS;&%T:6]N("A097(M4W1I86X@5F%T;F4@/'!S
M=D!O<G-T82YO<F<^*2X*6VIA;ET@061D(%-L;W9E;FEA;B!T<F%N<VQA=&EO
M;B`H2G5R92!+<F%S;W9I8R`\:G5R96M`<F-C+6ER8RYS:3XI+@I;:F%N72!!
M9&0@2F%P86YE<V4@=')A;G-L871I;VX@*$(N2BX@0FQA8VL@/'=I;&QI86TN
M8FQA8VM`<W5N+F-O;3XI+@I;8VIH72!!9&0@86X@;W!T:6]N86P@<&%R86UE
M=&5R('1O('-E="!T:&4@3$1!4"!P<F]T;V-O;"!V97)S:6]N+@I;8VIH72!#
M;&]S92!A('!O=&5N=&EA;"!P<F]B;&5M('=I=&@@<F5G:7-T97)?9VQO8F%L
M<R!/;B!A;F0@)&IS7V]N3&]A9"X*6VIA;ET@061D(%!O<G1U9V%L(%!O<G1U
M9W5E<R!T<F%N<VQA=&EO;B`H3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N<'0^
M*2X*6V-J:%T@061D(&$@0G)O=W-E(&EN=&5R9F%C92!F;W(@96%S:6QY(&QI
M<W1I;F<@86QL(&-O;G1A8W1S+@I;8VIH72!#:&%N9V4@<V]M92!B=71T;VX@
M:6YP=71S('1O('-U8FUI=',@86YD(')E;6]V92!S;VUE(&IA=F%S8W)I<'0N
M"EMC:FA=(%-O=7)C92UW:61E(&9I;'1E<G,@=VET:"!,1$%0(&%R92!A;'=A
M>7,@04Y$+65D+@I;8VIH72!296UO=F4@87=K=V%R9"!4;SHL($-C.BP@0F-C
M.B!M97-S86=E(&-O;7!O<VET:6]N(&EN=&5R9F%C92!A;F0@8VQE86X*("`@
M("`@=7`@54DN"EMC:FA=($1E;&5T92!E;7!T>2!A='1R:6)U=&5S(&EN<W1E
M860@;V8@:G5S="!L96%V:6YG('1H96T@=6YC:&%N9V5D+@I;8VIH72!,;V<@
M4U%,(&%N9"!,1$%0('%U97)I97,@870@3$]'7T1%0E5'+@I;8VIH72!$;VXG
M="!G96YE<F%T92!,1$%0('-E87)C:&5S('=I=&@@)V%T='(]*BHG(&EN('1H
M96T@9F]R(&5M<'1Y('9A;'5E<PH@("`@("`H=7-E(&%T='(]*BDN"EMC:FA=
M(%-A>2`B161I="`G96YT<GDG(B!I;G-T96%D(&]F(&IU<W0@(F5N=')Y(B!I
M;B!T:&4@;6]U<V5O=F5R('1E>'0@9F]R"B`@("`@('-E87)C:"!R97-U;'1S
M('=H:6-H(&%R92!E9&ET86)L92X*6V-J:%T@061D(&$@;&]C86P@3$1!4"!D
M:7)E8W1O<GD@97AA;7!L92X*6V-J:%T@1&]N)W0@<W1O<F4@;V)J96-T<R!I
M;B!T:&4@<V5A<F-H(')E<W5L=',@<V5S<VEO;B!C86-H93L@82!B:70@<VQO
M=V5R+`H@("`@("!B=70@<V5E;7,@=&\@8F4@;75C:"!M;W)E(')E;&EA8FQE
M+@I;8VIH72!687-T;'D@:6UP<F]V92!S96%R8V@@<F5S=6QT<R!H86YD;&EN
M9R`M('-T;W)E('1H96T@:6X@=&AE('-E<W-I;VXL"B`@("`@(&1O;B=T(&%D
M9"!D=7!L:6-A=&4@<F5S=6QT<RP@;&5T('!E;W!L92!U<V4@=&AE(&)A8VL@
M8G5T=&]N+"!E=&,N"EMC:FA=($9I>"!T:&4@8V]L=6UN('-E;&5C="!J879A
M<V-R:7!T+@I;8VIH72!!9&0@;&ES="!M;W5S96]V97(@969F96-T("A2;VYN
M:64@1V%R8VEA(#QR;VYN:65`;6LR+FYE=#XI+@I;8VIH72!&:7@@<F5S=6QT
M<R!P<F]B;&5M('=I=&@@861V86YC960N<&AP(&%N9"!O;&0@<F5S=6QT<RX*
M6V-J:%T@4&%T8VAE<R!T;R!T=V5A:R!T:&4@3$1!4"!D<FEV97(@=&\@:&%N
M9&QE('1H:6YG<R!A(&)I="!M;W)E(&-O<G)E8W1L>0H@("`@("`H2&E#:U,@
M/&AI8VMS0#8V-BYH;BYO<F<^*2X*6V-J:%T@061D(&%N9"!U<V4@5%520D%?
M5$5-4$Q!5$53(&-O;G-T86YT+@I;8VIH72!5<V4@)')E9VES=')Y+3YG970H
M*2!F;W(@86QL(%)E9VES=')Y(&EN9F]R;6%T:6]N+@I;:F%N72!!9&0@)V%D
M;6EN)R!E;G1R>2!T;R!T:&4@<V]U<F-E<R!H87-H('1O(&=I=F4@=W)I=&4@
M86-C97-S(&]N(')E861O;FQY"B`@("`@(&%D9')E<W-B;V]K<R!T;R!C97)T
M86EN(&QO9V=E9"!I;B!U<V5R<RX*6VIO;ET@16YA8FQE('1H92`B<&]R=&%B
M:6QI='DB(&]P=&EO;B!I;B!T:&4@4U%,(&1R:79E<BX*6VIA;ET@061D('!R
M969E<F5N8V5S('!A9V4@86YD('5S97(@<')E9F5R96YC92!T;R!S96QE8W0@
M=&AE(&-O;'5M;G,@=&AA="!S:&%L;`H@("`@("!B92!D:7-P;&%Y960@:6X@
M=&AE('-E87)C:"!R97-U;'1S+@I;:F%N72!!9&0@17-T;VYI86X@=')A;G-L
M871I;VX@*%1O;VUA<R!!87,@/'1O;VUA<RYA87-`<F%A9"YT87)T=2YE93XI
M+@I;:F%N72!!9&0@4VQO=F%K('1R86YS;&%T:6]N("A,96\@37)A9FMO(#QL
M96]`;V5L+G-K/BDN"EMJ;VY=($5N86)L92!T:&4@(G!O<G1A8FEL:71Y(B!O
M<'1I;VX@:6X@=&AE(%-13"!D<FEV97(N"EMJ86Y=($%D9"!5:W)A:6YI86X@
M=')A;G-L871I;VX@*$%N9')I>2!+;W!Y<W1Y86YS:WD@/&%N<FE`<&]L>6YE
M="YL=FEV+G5A/BDN"EMJ86Y=($%D9"!$86YI<V@@=')A;G-L871I;VX@*$UA
M<G1I;B!,:7-T+5!E=&5R<V5N(#QM87)T:6Y`;&ES="UP971E<G-E;BYD:SXI
M+@I;:F%N72!&:7@@8G5G(")4:&ES('!E<G-O;B!I<R!A;')E861Y(&EN('EO
M=7(@861D<F5S<V)O;VLN(BX*"@HM+2TM"G8Q+C`*+2TM+0H*6VIA;ET@061D
M($YO<G=E9VEA;B!";V]K;6%L('1R86YS;&%T:6]N("A/>7-T96EN(%-T96EM
M;&5R(#QO>7-T96EN0')E>'1A+FYE=#XI+@I;879S;5T@061D("YH=&%C8V5S
M<R!F:6QE<R!T;R!D96YY(&%C8V5S<R!T;R!D871A(&1I<F5C=&]R:65S+@I;
M:F%N72!!9&0@1FEN;FES:"!T<F%N<VQA=&EO;B`H3&5E;F$@2&5I;F\@/&QI
M:6YU0'5T82YF:3XI+@I;8VIH72!!=F]I9"!A9&1I;F<@9'5P;&EC871E(&5N
M=')I97,@=&AR;W5G:"!T:&4@861D($%022!M971H;V0N"@H*+2TM+2TM+2T*
M=C$N,"U20S0*+2TM+2TM+2T*"EMR:6-H72!);F-L=61E(')E=W)I='1E;B!A
M;F0@<F5O<F=A;FEZ960@9&]C=6UE;G1A=&EO;BX*6W)I8VA=($QI8V5N<V4@
M=6YD97(@2&]R9&4@05!,+@I;8VIH72!-86ME(&5M86EL(&%D9')E<W-E<R!C
M;&EC:V%B;&4@:6X@9&ES<&QA>65D(&]B:F5C=',N"EMB:FY=($-H86YG92`G
M96XG(&%N9"`G96Y?14XG(&QO8V%L97,@=&\@)V5N7U53)R`H9&5F875L="DN
M"EMC:FA=(%9A<W1L>2!I;7!R;W9E(&5R<F]R(')E<&]R=&EN9R!W:&5N(&%D
M9&EN9R!A;B!O8FIE8W0@9F%I;',N"EMJ86Y=($%D9"!"<F%Z:6QI86X@4&]R
M='5G=65S92!T<F%N<VQA=&EO;B`H0V%R;&]S($1A;FEE;"!+:6)R:70*("`@
M("`@/&MI8G)I=$!T97)R82YC;VTN8G(^*2X*6VIA;ET@061D($=R965K('1R
M86YS;&%T:6]N("A3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-D:6UI=')I0'1E
M:6%T:"YG<CXI+@I;:F%N72!!9&0@4W=E9&ES:"!T<F%N<VQA=&EO;B`H06YD
M<F5A<R!$86ALZ6X@/&%N9')E87-`9&%H;&5N+G=S/BDN"EMJ86Y=($%D9"!+
M;W)E86X@=')A;G-L871I;VX@*$HN22!+:6T@/&%P;W)I94!N971I86XN8V]M
M/BDN"EMC:FA=(%)E;6]V92!D=7!L:6-A=&4@96YT<FEE<R!F<F]M(&UU;'1I
M<&QE('-O=7)C97,@9G)O;0H@("`@("!T=7)B845X<&%N9$%D9')E<W-E<R@I
M(')E<W5L=',N"EMC:FA=($1O;B=T('-H;W<@=&AE(&%D9')E<W-B;V]K('-E
M;&5C="!W:61G970@;VX@=&AE('-E87)C:"!P86=E(&EF('1H97)E)W,*("`@
M("`@:G5S="!O;F4@=&\@<V5A<F-H(&9R;VTN"@H*+2TM+2TM"G8P+C`N,PHM
M+2TM+2T*"EMC:FA=($%D9"!A;B!O<'1I;VYA;"`G<W1R:6-T)R!C;VYF:6=U
M<F%T:6]N(&%R<F%Y(&1E9FEN:6YI;F<@9FEE;&1S('=H:6-H"B`@("`@(&UU
M<W0@86QW87ES(&)E(&UA=&-H960@97AA8W1L>2X*6VIA;ET@061D(&%P:2!F
M=6YC=&EO;B!T;R!G970@:6YF;R!A8F]U="!T:&4@9FEE;&1S+@I;:F%N72!!
M9&0@<V]U<F-E(&-O;F9I9W5R871I;VX@=&\@<V5L96-T('=H:6-H(&9I96QD
M<R!S:&]U;&0@8F4@<V5A<F-H86)L92!B>0H@("`@("!D969A=6QT+@I;8VIH
M72!!;&QO=R!/4B!S96%R8VAE<RX*6V-J:%T@4&%S<R!F=6QL(&5M86EL(&%D
M9')E<W-E<R`H=VET:"!N86UE<RD@=&\@;65S<V%G97,@8F5I;F<@8V]M<&]S
M960*("`@("`@*$QA<G,@3G5M;65D86P@/&QA<F=S0&YU;6UE9&%L+FYE=#XI
M+@I;:F%N72!!9&0@4&]L:7-H('1R86YS;&%T:6]N+@I;:F%N72!!9&0@;6%P
M<&EN9R!O9B!D871E+W1I;64@9FEE;&1S('1O('1H92!I;7!O<G0@9F5A='5R
M92X*6VIA;ET@061D('-U<'!O<G0@9F]R(&1A=&4@9FEE;&1S("AE+F<N(&)I
M<G1H9&%Y<RDN"EMJ86Y=('1U<F)A17AP86YD061D<F5S<V5S*"D@;F]W(')E
M='5R;G,@86QL(&5M86EL(&%D9')E<W-E<R!T:&%T(&)E;&]N9PH@("`@("!T
M;R!A(&-O;G1A8W0N"EMJ86Y=(%-H;W<@=&AE(&9I96QD<R!I;B!E9&ET(&%N
M9"!D:7-P;&%Y('9I97<@9'EN86UI8V%L;'D@8F%S960@;VX@=VAA="=S"B`@
M("`@('!R;W9I9&5D(&)Y('1H92!B86-K96YD+@I;:F%N72!!9&0@271A;&EA
M;B!T<F%N<VQA=&EO;B`H1VEO=F%N;FD@365N96=H971T:2`\9VUE;F5G:&5T
M=&E`:6YF=FEC+FET/BDN"EMJ86Y=($%D9"!I;7!O<G0O97AP;W)T('5I(&)A
M<V5D(&]N('1H92!N97<@1&%T82!C;&%S<RX*6V-J:%T@061D(%1R861I=&EO
M;F%L($-H:6YE<V4@=')A;G-L871I;VX@*$1A=FED($-H86YG(#QD879I9$!T
M:&)U;RYG;W8N='<^*2X*6V-J:%T@061D($-Z96-H('1R86YS;&%T:6]N("AP
M8VAY=&EL0&%S<"YO9VDN961U*2X*6V-J:%T@061D(%)U<W-I86X@=')A;G-L
M871I;VX@*$EG;F%T($EK<GEA;F]V(#QI9VYA=$!I8F0N<G4^*2X*6V-J:%T@
M061D("1C;VYF6R=M96YU)UU;)V%P<',G72!S=7!P;W)T(&%N9"!A(&AE;'`@
M;&EN:RX*6V-J:%T@36%K92!I;F-R96UE;G1A;"!B=6EL9&EN9R!U<"!O9B!S
M96%R8V@@<F5S=6QT<R!W;W)K<R!A9V%I;B!I;B!B;W1H"B`@("`@('-E87)C
M:"!A;F0@861V86YC960@<V5A<F-H+@I;8VIH72!!9&0@06QI87,@=&\@9&5F
M875L="!F:65L9',@*$UA<F,@2F%U=FEN(#QM87)C0')E9VES=&5R-&QE<W,N
M8V]M/BDN"EMC:FA=(%5S92!T:&4@*G5R;"@I(&9U;F-T:6]N<R!M;W)E(&-O
M;G-I<W1E;G1L>2!T;R!M86ME('-U<F4@=&AA=`H@("`@("!C;V]K:64M;&5S
M<R!S97-S:6]N<R!W;W)K+@H*"BTM+2TM+0IV,"XP+C(*+2TM+2TM"@I;8VIH
M72!!9&0@<V]M92!M;W)E(&5R<F]R(&-H96-K:6YG('1O('1H92!S96%R8VAI
M;F<@86YD($Q$05`@9')I=F5R+@I;8VIH72!!9&0@8V]N9FEG+V%T=')I8G5T
M97,N<&AP('1O('!R;W9I9&4@;FEC92!L86)E;',@9F]R(&1I<F5C=&]R>0H@
M("`@("!A='1R:6)U=&5S+@I;8VIH72!!9&1I;F<@1V5R;6%N('1R86YS;&%T
M:6]N(&9R;VT@2F%N(%-C:&YE:61E<B`\:F%N;6%I;&EN9T!G;7@N9&4^+@I;
M8VIH72!!;&QO=R!,1$%0(%-O=7)C97,@=&\@9&5F:6YE(&$@9FEL=&5R(&%L
M=V%Y<R!I;F-L=61E9"!I;B!S96%R8VAE<PH@("`@("`H<F)A<FYE='1`;F5U
M<F]M:6-S+F-O;2DN"EMJ;VY=(%!R97-E<G9E('1H92!S96%R8V@@<&%R86UE
M=&5R<R!A9G1E<B!A('-E87)C:"!I<R!P97)F;W)M960N"EMJ;VY=($%L;&]W
M('1H92!R96=I<W1R>2!T;R!H86YD;&4@5'5R8F$G<R!C;VYF:6=U<F%T:6]N
M('9A;'5E<RX*6VIO;ET@2$]21$5?0D%312!I<R!N;W<@9&5F:6YE9"!I;B!L
M:6(O8F%S92YP:'`@:6YS=&5A9"!O9B!C;VYF:6<O8V]N9BYP:'`N"EMM87A=
M($%D9&EN9R!S;W5R8V4@<F5T<FEE=F%L(&%P:2!F=6YC=&EO;BX*6V-J:%T@
M061D:6YG($1U=&-H('1R86YS;&%T:6]N(&9R;VT@2F%N($MU:7!E<G,@/&IR
M:W5I<&5R<T!L875W97)S8V]L;&5G92YN;#XN"EMJ;VY=($%D9&EN9R!&<F5N
M8V@@=')A;G-L871I;VX@9G)O;2!386T@4')Z>7-W82`\<V%M<$!A<FEA;"UC
M;VYC97!T+F-O;3XN"EMC:FA=($%D9"!G971T97AT(&EN9G)A<W1R=6-T=7)E
M+@I;8VIH72!$969I;F4@=&AE($A/4D1%7T)!4T4@8V]N<W1A;G0@:6X@8V]N
M9FEG+V-O;F8N<&AP+"!A;F0@=7-E(&ET('=H96X*("`@("`@<F5F97)R:6YG
M('1O(&%N>2!O9B!(;W)D92=S(&9I;&5S+@I;8VIH72!"<FEN9R!T:&4@861V
M86YC960@<V5A<F-H('!A9V4@=7`@=&\@9&%T92P@86YD(&%D9"!I="!T;R!T
M:&4@;65N=2X*6VIO;ET@4F5T:7)E9"!C;VYF:6<O;65N=2YT>'0@:6X@9F%V
M;W(@;V8@8V]N9FEG+VUE;G4N<&AP+B`@5&AI<R!F:6QE(&9O;&QO=W,*("`@
M("`@82!N97<@9F]R;6%T(&)A<V5D(&]N(&YA=&EV92!02%`@9&%T82!S=')U
M8W1U<F5S+@I;;6%X72!%>'!A;F0@87!I('1O(&%L;&]W(&%D9&EN9R!A9&1R
M97-S97,@=&\@86X@861D<F5S<V)O;VLN"EMC:FA=($%D9"!T:&4@9FER<W0@
M87!I(&9U;F-T:6]N("AE>'!A;F1I;F<@861D<F5S<V5S*2!F;W(@5'5R8F$@
M:6X*("`@("`@;&EB+V%P:2YP:'`N"EMC:FA=($%D9"!A;F0@1&5L971E(&YO
M=R!W;W)K(&9O<B!T:&4@3$1!4"!D<FEV97(N"EMC:FA=($9I>"!W87`@8V]N
M=&%C=',@<V5A<F-H:6YG+@I;8VIH72!4=7)B82!N;W<@=7-E<R!(;W)D92!A
M=71H96YT:6-A=&EO;B!I;G-T96%D(&]F(&ET<R!O=VXN(%1H:7,@;65A;G,*
M("`@("`@=&AA="!W:&%T979E<B!A=71H(&UE=&AO9"!Y;W4@87)E('5S:6YG
M(&9O<B!(;W)D92!W:6QL(&)E('5S960@=&\*("`@("`@875T:&5N=&EC871E
M('1O(%1U<F)A+"!A;F0@:6X@<F5T=7)N('EO=2!G970@<VEN9VQE('-I9VXM
M;VX@=VET:"!A;GD*("`@("`@;W1H97(@87!P<R!U<VEN9R!(;W)D92!A=71H
M96YT:6-A=&EO;BX*6V-J:%T@5V]R:VEN9R!A9&1/8FIE8W0H*2!A;F0@<F5M
M;W9E3V)J96-T*"D@4U%,(&1R:79E<B!M971H;V1S+@I;8VIH72!-;W9E(%1U
M<F)A7U-O=7)C93HZ9V5T37E/8FIE8W0H*2!T;R!4=7)B85]3;W5R8V4Z.F=E
M=$]B:F5C="@I.R!N;W1H:6YG"B`@("`@('=A<R!U<VEN9R!T:&4@;VQD(&=E
M=$]B:F5C="@I(&-A;&P@86YY;6]R92X*6V-J:%T@268@>6]U('-E="`D<&%R
M86US6R=B:6YD7V1N)UT@86YD("1P87)A;7-;)V)I;F1?<&%S<W=O<F0G72!F
M;W(@86X@3$1!4`H@("`@("!S;W5R8V4L(%1U<F)A('=I;&P@8FEN9"!A<R!T
M:&4@<W!E8VEF:65D(&1N('1O('1H92!,1$%0('-E<G9E<BP*("`@("`@;&5T
M=&EN9R!Y;W4@861D+V5D:70@96YT<FEE<RX*6V-J:%T@57!D871E(&-A<&%T
M:6QI>F%T:6]N('1O(&UA=&-H($AO<F1E+U!%05(@<W1A;F1A<F1S+@I;8VIH
M72!R96=I<W1E<E]G;&]B86QS(#T@3V9F(&9I>&5S+@I;8VUC72!!9&0@82!D
M:7-P;&%Y(&]B:F5C="!P86=E+"!F:7@@82!L9&%P(&)U9R!W:71H('1H92!D
M;BP@861D"B`@("`@(&$@<F5A9"!F=6YC=&EO;B!T;R!T:&4@='5R8F$@<V]U
M<F-E(&-L87-S("A$;VYE(&)Y($-H<FES=&EA;@H@("`@("!-+B!#;W5D97(@
M*&-M8RD@/&-H<FES=&EA;D!A;&-O=F4N9G(^*2X*6V-J:%T@061D(&%N(&%D
M=F%N8V5D('-E87)C:"!P86=E(&-O;G1R:6)U=&5D(&)Y($-H<FES=&EA;B!#
M;W5D97(*("`@("`@/&-H<FES=&EA;D!A;&-O=F4N9G(^+@I;8VIH72!"<FEN
M9R!T:&4@5TU,('1E;7!L871E<R!U<"!T;R!D871E('=I=&@@<F5C96YT(&-H
M86YG97,N"EMC:FA=($UA:V4@=&AE($Q$05`@<V5R=F5R('!O<G0@8V]N9FEG
M=7)A8FQE(&%N9"!M86ME('-U<F4@=&AE('!A<F%M971E<@H@("`@("!A<'!E
M87)S(&EN('1H92!E>&%M<&QE('-O=7)C97,N"EMC:FA=($EM<&QE;65N=&5D
M(&5D:70@9G5N8W1I;VYA;&ET>2!F;W(@=&AE(%-13"!D<FEV97(N"EMC:FA=
M($UO=F5D('1H92!F:6QT97(H*2!F=6YC=&EO;F%L:71Y("AA;F0@<W5P<&]R
M=&EN9R!F=6YC=&EO;G,I(&EN=&\*("`@("`@5'5R8F%?3&ES="P@=VAE<F4@
M:70@<F5A;&QY(&)E;&]N9W,N"EMC:FA=(%=E(&YO=R!A8W1U86QL>2!U<V4@
M5'5R8F%?3&ES="P@5'5R8F%?06)S=')A8W1/8FIE8W0L(%1U<F)A7TQI<W16
M:65W+`H@("`@("!A;F0@;6%N>2!O=&AE<B!P:65C97,@;V8@=&AE(&-L87-S
M(&AI97)A<F-H>2!T:&%T('=E<F4@<')E=FEO=7-L>2!O;FQY"B`@("`@(')E
M9F5R96YC960@:6X@=&AE(&]B:F5C="!M;V1E;"X*6V-J:%T@0VQE86X@=7`@
M=&AE('-Q;"!$<FEV97(@:6UP;&5M96YT871I;VX@82!B:70N($YO=RP@:68@
M=&AE('-O=7)C92!I<PH@("`@("!P<FEV871E+"!T:&4@7U]O=VYE<B!C<FET
M97)I82!M=7-T(&UA=&-H('1H92!C=7)R96YT('5S97(L(&EN<W1E860@;V8*
M("`@("`@=7-I;F<@7U]K97DN(%]?:V5Y('-H;W5L9"!U;FEQ=65L>2!I9&5N
M=&EF>2!E86-H(&]B:F5C="P@86YD('-H;W5L9&XG=`H@("`@("!B92!W:&%T
M('5S97(@=&AA="!O8FIE8W0@8F5L;VYG<R!T;RX*6V-J:%T@4F5O<F=A;FEZ
M92!T:&4@8VQA<W,@:&EE<F%R8VAY(&$@8FET("T@=7-E($]B:F5C="!I;G-T
M96%D(&]F($-O;G1A8W0L"B`@("`@(&%N9"!A(&9E=R!O=&AE<B!N86UI;F<@
M8VAA;F=E<RX*6V-J:%T@365R9V5D(%=!4"!F=6YC=&EO;F%L:71Y(&EN=&\@
M<V5A<F-H+G!H<"X@268@82!705`@8G)O=W-E<B!I<PH@("`@("!D971E8W1E
M9"P@82!S;&EM;65D+61O=VX@=VUL(&EN=&5R9F%C92!W:6QL(&)E('5S960@
M=&AA="!O;FQY(&1I<W!L87ES"B`@("`@(&YA;65S(&%N9"`H8V%L;&%B;&4I
M('!H;VYE(&YU;6)E<G,N"@H*+2TM+2TM"G8P+C`N,0HM+2TM+2T*"EMC:FA=
M($9I>"!B=6<@=VAE<F4@<V5A<F-H97,@=VET:"!N;R!R97-U;'1S('=O=6QD
M('1A8VL@;VX@86X@96UP='D@<F]W+@I;8VIH72!#;VYV97)S:6]N('1O($-3
M4RX*6V-J:%T@0VQE86YU<"P@;6]D97)N:7IA=&EO;BX*6VIO;ET@4VEL96YC
M92!S97-S:6]N7W-T87)T('=A<FYI;F=S+@I;:F]N72!5<V4@2&]R9&4Z.G5R
M;"@I(&EN('!L86-E(&]F('1H92!D97!R96-A=&5D(&)U:6QD55),*"D@9G5N
M8W1I;VXN"EMC:FA=(%5S92!N97<@<V5S<VEO;B!M;V1E;"!A;F0@)&AO<F1E
M6R=S97-S:6]N7VYA;64G72X*6V-J:%T@1FEX960@;65S<V%G92!S96YD:6YG
M(&IA=F%S8W)I<'0@=&\@=V]R:R!W:71H(&UU;'1I<&QE(&%D9')E<W-E<RX*
M6VIO;ET@06QL;W<@9&ER96-T;W)Y('-O=7)C97,@=&\@8F4@<V5T("=R96%D
M+6]N;'DG("AN;VXM961I=&%B;&4I+@I;:F]N72!!9&1E9"!A("=P=6)L:6,G
M(&9L86<@=&\@=&AE("1C9F=3;W5R8V5S(&5N=')I97,N"EMJ;VY=($-O;G1A
M8W0@871T<FEB=71E<R!A<F4@8V]N9FEG=7)A8FQE('9I82!C;VYF:6<O871T
M<FEB=71E<RYP:'`N"EMJ;VY=(%)E;F%M960@=&AE('-O=7)C92!C;VYF:6=U
M<F%T:6]N(&AA<V@@=&\@)&-F9U-O=7)C97,@*&9R;VT@:G5S=`H@("`@("`D
M<V]U<F-E<RDN"EMJ;VY=($UO=F5D(&9R;VT@8V]N9FEG+VQD87`N<&AP('1O
M(&-O;F9I9R]S;W5R8V5S+G!H<"X*6VIO;ET@0V]N=F5R=&5D($-H=6-K)W,@
M97AI<W1I;F<@8VQA<W,@<W1U8G,@:6YT;R!A(%!%05(M<W1Y;&4@;&EB+R!T
M<F5E+@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]D;V-S+T-2141)5%,`````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q,30U`#$P
M-#$W,S8R-S4V`#`Q-S4Q,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*(%1U<F)A
M($1E=F5L;W!M96YT(%1E86T*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ
M3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#8O,#,O,#8@,#DZ-#0Z,3D@)`HZ
M4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C4T+C@N,3D@)`HZ0V]N=&%C
M=#H@("`@("`@='5R8F%`;&ES=',N:&]R9&4N;W)G"@H*0V]R92!$979E;&]P
M97)S"CT]/3T]/3T]/3T]/3T]/0H*+2!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*+2!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H*
M"DQO8V%L:7IA=&EO;@H]/3T]/3T]/3T]/3T*"CT]/3T]/3T]/3T]/3T]/3T]
M/3T]/2`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0I!<F%B:6,@*%-Y<FEA*2`@("`@("`@("!0;&%T
M:6YU;2!$979E;&]P;65N="!496%M(#QD979T96%M0'!L871I;G5M+7-Y+FYE
M=#X*0G)A>FEL:6%N(%!O<G1U9W5E<V4@("`@0V%R;&]S($1A;FEE;"!+:6)R
M:70@/&MI8G)I=$!T97)R82YC;VTN8G(^"B`@("`@("`@("`@("`@("`@("`@
M("`@($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB<CX*0G5L9V%R:6%N
M("`@("`@("`@("`@("`@36ER;W-L878@4&5N9&5V(#QP96YD979`:&]T;6%I
M;"YC;VT^"D-A=&%L86X@("`@("`@("`@("`@("`@($%N9V5L<R!'=6EM97+@
M(#QA;F=E;',N1W5I;65R84!U86(N97,^"D-H:6YE<V4@*%-I;7!L:69I960I
M("`@(%=A;F=(96YG5V5N(#QW:'=`;7DQ-CDN8V]M/@I#:&EN97-E("A4<F%D
M:71I;VYA;"D@("!$879I9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SX*0WIE
M8V@@("`@("`@("`@("`@("`@("`@4&%V96P@0VAY=&EL(#QP8VAY=&EL0&%S
M<"YO9VDN961U/@I$86YI<V@@("`@("`@("`@("`@("`@("!-87)T:6X@3&ES
M="U0971E<G-E;B`\;6%R=&EN0&QI<W0M<&5T97)S96XN9&L^"B`@("`@("`@
M("`@("`@("`@("`@("`@($)R:6%N(%1R=65L<V5N(#QH;W)D92MI,3AN0&)R
M:6%N=')U96QS96XN9&L^"D1U=&-H("`@("`@("`@("`@("`@("`@($IA;B!+
M=6EP97)S(#QJ<FMU:7!E<G-`;&%U=V5R<V-O;&QE9V4N;FP^"B`@("`@("`@
M("`@("`@("`@("`@("`@($AA;B!3<')U>70@/&AA;BYS<')U>71`:6IS<V5L
M9W)O97`N;FP^"D5S=&]N:6%N("`@("`@("`@("`@("`@(%1O;VUA<R!!87,@
M/'1O;VUA<RYA87-`<F%A9"YT87)T=2YE93X*1FEN;FES:"`@("`@("`@("`@
M("`@("`@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3X*1G)E;F-H("`@("`@
M("`@("`@("`@("`@4V%M(%!R>GES=V$@/'-A;7!`87)I86PM8V]N8V5P="YC
M;VT^"B`@("`@("`@("`@("`@("`@("`@("`@(%)O;FYI92!'87)C:6$@/')O
M;FYI94!M:S(N;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!"96YO:70@
M4W0M06YD<ND@/&)E;D!B96YO:71S="UA;F1R92YN970^"B`@("`@("`@("`@
M("`@("`@("`@("`@(%!I97)R92!,86-H86YC92`\<&Q`<&EE<G)E;&%C:&%N
M8V4N;F5T/@I'86QI8VEA;B`@("`@("`@("`@("`@("!2869A96P@5F%R96QA
M(%!E="`\<F%F865L+G9A<F5L84!U<V,N97,^"B`@("`@("`@("`@("`@("`@
M("`@("`@($=U:6QL97)M;R!-96YD97H@/&=U:6QL94!U<V,N97,^"D=E<FUA
M;B`@("`@("`@("`@("`@("`@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"D=R965K("`@("`@("`@("`@("`@("`@(%-T969A;F]S($DN($1I;6ET
M<FEO=2`\<W5P<&]R=$!T96EA=&@N9W(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(%-I;&QI9V%R9&]S(%AR:7-T;V9O<F]S"B`@("`@("`@("`@("`@("`@
M("`@("`@($%N86=N;W-T;W!O=6QO<R!!<&]S=&]L:7,*2'5N9V%R:6%N("`@
M("`@("`@("`@("`@3&%S>FQO($PN(%1O<FYO8VD@/'1O<FQA<WI`>&5N:6$N
M<V]T92YH=3X*26-E;&%N9&EC("`@("`@("`@("`@("`@0FIO<FX@1&%V:61S
M<V]N(#QB:F]S<VE`<VYE<G!A+FES/@I)=&%L:6%N("`@("`@("`@("`@("`@
M("!':6]V86YN:2!-96YE9VAE='1I(#QG;65N96=H971T:4!I;F9V:6,N:70^
M"B`@("`@("`@("`@("`@("`@("`@("`@($UA<F-O(%!I<F]V86YO(#QM87)C
M;RYP:7)O=F%N;T!U;FEB;V-C;VYI+FET/@H@("`@("`@("`@("`@("`@("`@
M("`@("!#<FES=&EA;B!-86YO;FD@/&-R:7-T:6%N+FUA;F]N:4!N971H97-I
M<RYI=#X*2F%P86YE<V4@("`@("`@("`@("`@("`@0BY*+B!";&%C:R`\=VEL
M;&EA;2YB;&%C:T!S=6XN8V]M/@H@("`@("`@("`@("`@("`@("`@("`@("!4
M86ME<VAI($UO<FES:&EM82`\=&U`;VYE<&]S="YN970^"B`@("`@("`@("`@
M("`@("`@("`@("`@($AI<F]M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U:W5B
M82YA8RYJ<#X*2V]R96%N("`@("`@("`@("`@("`@("`@2BY)($MI;2`\87!O
M<FEE0&YE=&EA;BYC;VT^"B`@("`@("`@("`@("`@("`@("`@("`@($II;FAY
M;VL@2&5O(#QN;W9E;6)R94!O=7)N871U<F4N;W)G/@I,871V:6%N("`@("`@
M("`@("`@("`@("!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^
M"DQI=&AU86YI86X@("`@("`@("`@("`@($1A<FEU<R!-871U;&EA=7-K87,@
M/&1A<FEU<T!L;FLN;'0^"B`@("`@("`@("`@("`@("`@("`@("`@(%9I;&EU
M<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT/@I-86-E9&]N:6%N("`@("`@("`@
M("`@("!3=&]J86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M+FUK/@I.;W)W96=I
M86X@0F]K;6%A;"`@("`@("!/>7-T96EN(%-T96EM;&5R(#QO>7-T96EN0')E
M>'1A+FYE=#X*("`@("`@("`@("`@("`@("`@("`@("`@5&]R<W1E:6X@4RX@
M2&%N<V5N(#QH=6QE8F]E<D!T96-H8F5E+FYO/@H@("`@("`@("`@("`@("`@
M("`@("`@("!!;F1R96%S($=U;FQE:6MS:V%A<R`\86YD<F5A<T!G=6YL96EK
M<VMA87,N;F\^"B`@("`@("`@("`@("`@("`@("`@("`@(%1R;VYD($)J^')S
M=&%D(#QT<F)`;F1N+FYO/@H@("`@("`@("`@("`@("`@("`@("`@("!4:&]M
M87,@0VAR+B!$86AL(#QT8V1`;F1N+FYO/@I.;W)W96=I86X@3GEN;W)S:R`@
M("`@("!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^"E!E<G-I86X@
M("`@("`@("`@("`@("`@($UE=&%.150@06UI<FMA8FER(#QP97)S:6%N+6AO
M<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*4&]L:7-H("`@("`@("`@("`@("`@
M("`@4&EO='(@4F]S>F%T>6-K:2`\9&5X=&5R0&1E8FEA;BYP;#X*("`@("`@
M("`@("`@("`@("`@("`@("`@36%T975S>B!+86UI;G-K:2`\;6%T:7!L0'!L
M9"UL:6YU>"YO<F<^"B`@("`@("`@("`@("`@("`@("`@("`@($MR>GES>G1O
M9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#X*4&]R='5G=65S92`@("`@("`@
M("`@("`@3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N<'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@($IO<V4G($-A<FQO<R`\:&]R9&4N:3$X;D!A8FES;6\N
M;W)G/@H@("`@("`@("`@("`@("`@("`@("`@("!-86YU96P@365N97IE<R!D
M92!397%U96ER82`\36%N=65L+E-E<75E:7)A/@I2;VUA;FEA;B`@("`@("`@
M("`@("`@("!%=6=E;B!(;V%N8V$@/&5U9V5N:$!U<F)A;BUG<F%F>"YR;SX*
M("`@("`@("`@("`@("`@("`@("`@("`@36%R:75S($1R86=U;&5S8W4@/&UA
M<FEU<V1`=7)B86XM9W)A9G@N<F\^"E)U<W-I86X@("`@("`@("`@("`@("`@
M($EG;F%T($EK<GEA;F]V(#QI9VYA=$!I8F0N<G4^"B`@("`@("`@("`@("`@
M("`@("`@("`@($%N=&]N($YE:VAO<F]S:&EH(#QA;G1O;D!V86QU96AO<W0N
M<G4^"B`@("`@("`@("`@("`@("`@("`@("`@($9E9&]R($$N($9E=&ES;W8@
M/&9A9D!S<V,N<G4^"B`@("`@("`@("`@("`@("`@("`@("`@($%L97AE>2!:
M86MH87)O=B`\86QE>$!B:W,N8GD^"E-L;W9A:R`@("`@("`@("`@("`@("`@
M($QE;R!-<F%F:V\@/&QE;T!O96PN<VL^"B`@("`@("`@("`@("`@("`@("`@
M("`@($EV86X@3F]R:7,@/&YO<FES0&)G<RYS:SX*4VQO=F5N:6%N("`@("`@
M("`@("`@("`@2G5R92!+<F%S;W9I8R`\:G5R96M`<F-C+6ER8RYS:3X*("`@
M("`@("`@("`@("`@("`@("`@("`@36%T:6,@1&]L87(@/&UA=&EC0&UE9&EU
M;2YS:3X*4W!A;FES:"`@("`@("`@("`@("`@("`@2G5L:6%N($IA<F5S(#QJ
M:F%R97-`=&5C:&EE+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@4F'Z
M;"!!;'9A<F5Z(%9E;F5G87,@/')A=D!T96-O;6%N+G5C;VPN;7@^"B`@("`@
M("`@("`@("`@("`@("`@("`@($UA;G5E;"!097)E>B!!>6%L82`\;7!E<F%Y
M84!A;&-A>F%B82YU;F5X+F5S/@I3=V5D:7-H("`@("`@("`@("`@("`@("!!
M;F1R96%S($1A:&SI;B`\86YD<F5A<T!D86AL96XN=W,^"E1U<FMI<V@@("`@
M("`@("`@("`@("`@(%-E<G9E="!'_&YE>2`\<V=U;F5Y0&UE='4N961U+G1R
M/@H@("`@("`@("`@("`@("`@("`@("`@("!!:&UE="#6>G3\<FL@/&]A:&UE
M=$!M971U+F5D=2YT<CX*56MR86EN:6%N("`@("`@("`@("`@("`@06YD<FEY
M($MO<'ES='EA;G-K>2`\86YR:4!P;VQY;F5T+FQV:78N=6$^"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*"DEN86-T:79E($1E=F5L;W!E
M<G,*/3T]/3T]/3T]/3T]/3T]/3T]/0H*+2!*;VX@4&%R:7-E(#QJ;VY`8W-H
M+G)I="YE9'4^"BT@4FEC:"!,869F97)T>2`\<FEC:$!H;W)D92YO<F<^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O9&]C<R])3E-4
M04Q,````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R
M,3,U,``Q,#0Q-S,V,C<U-@`P,3<U,C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@
M26YS=&%L;&EN9R!4=7)B82`R+C$*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`U+S$P+S$X(#$R.C4Q.C0P("0*
M.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XQ,"XQ,"XT("0*.D-O;G1A
M8W0Z("`@("`@('1U<F)A0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z
M.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I4:&ES(&1O8W5M
M96YT(&-O;G1A:6YS(&EN<W1R=6-T:6]N<R!F;W(@:6YS=&%L;&EN9R!T:&4@
M5'5R8F$@8V]N=&%C="!M86YA9V5R"F]N('EO=7(@<WES=&5M+@H*1F]R(&EN
M9F]R;6%T:6]N(&]N('1H92!C87!A8FEL:71I97,@86YD(&9E871U<F5S(&]F
M(%1U<F)A+"!S964@=&AE(&9I;&4*4D5!1$U%7R!I;B!T:&4@=&]P+6QE=F5L
M(&1I<F5C=&]R>2!O9B!T:&4@5'5R8F$@9&ES=')I8G5T:6]N+@H*"D]B=&%I
M;FEN9R!4=7)B80H]/3T]/3T]/3T]/3T]/3T*"E1U<F)A(&-A;B!B92!O8G1A
M:6YE9"!F<F]M('1H92!(;W)D92!W96)S:71E(&%N9"!&5%`@<V5R=F5R+"!A
M=`H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O='5R8F$O"@H@("!F='`Z+R]F
M='`N:&]R9&4N;W)G+W!U8B]T=7)B82\*"D]R('5S92!T:&4@;6ER<F]R(&-L
M;W-E<W0@=&\@>6]U.@H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O;6ER<F]R
M<RYP:'`*"D)L965D:6YG+65D9V4@9&5V96QO<&UE;G0@=F5R<VEO;G,@;V8@
M5'5R8F$@87)E(&%V86EL86)L92!V:6$@0U93.R!S964@=&AE"F9I;&4@8&1O
M8W,O2$%#2TE.1V!?(&EN('1H92!(;W)D92!D:7-T<FEB=71I;VXL(&]R('1H
M92!W96)S:71E"FAT='`Z+R]W=W<N:&]R9&4N;W)G+W-O=7)C92\L(&9O<B!I
M;F9O<FUA=&EO;B!O;B!A8V-E<W-I;F<@=&AE($AO<F1E($-64PIR97!O<VET
M;W)Y+@H*"E!R97)E<75I<VET97,*/3T]/3T]/3T]/3T]/0H*5&\@9G5N8W1I
M;VX@<')O<&5R;'DL(%1U<F)A("HJ<F5Q=6ER97,J*B!T:&4@9F]L;&]W:6YG
M.@H*,2X@02!W;W)K:6YG($AO<F1E(&EN<W1A;&QA=&EO;BX*"B`@(%1U<F)A
M(')U;G,@=VET:&EN('1H92!@2&]R9&4@07!P;&EC871I;VX@1G)A;65W;W)K
M8%\L(&$@<V5T(&]F(&-O;6UO;B!T;V]L<PH@("!F;W(@5V5B(&%P<&QI8V%T
M:6]N<R!W<FET=&5N(&EN(%!(4"X@66]U(&UU<W0@:6YS=&%L;"!(;W)D92!B
M969O<F4*("`@:6YS=&%L;&EN9R!4=7)B82X*"B`@("XN($EM<&]R=&%N=#HZ
M(%1U<F)A(#(N,"!R97%U:7)E<R!V97)S:6]N(#,N,"L@;V8@=&AE($AO<F1E
M($9R86UE=V]R:R`M"B`@("`@("`@("`@("`@("`@(&5A<FQI97(@=F5R<VEO
M;G,@;V8@2&]R9&4@=VEL;"`J*FYO="HJ('=O<FLN"@H@("!4:&4@2&]R9&4@
M1G)A;65W;W)K(&-A;B!B92!O8G1A:6YE9"!F<F]M('1H92!(;W)D92!W96)S
M:71E(&%N9"!&5%`@<V5R=F5R+`H@("!A=`H*("`@("`@:'1T<#HO+W=W=RYH
M;W)D92YO<F<O:&]R9&4O"@H@("`@("!F='`Z+R]F='`N:&]R9&4N;W)G+W!U
M8B]H;W)D92\*"B`@($UA;GD@;V8@5'5R8F$G<R!P<F5R97%U:7-I=&5S(&%R
M92!A;'-O($AO<F1E('!R97)E<75I<VET97,N"@H@("`N+B!);7!O<G1A;G0Z
M.B!"92!S=7)E('1O(&AA=F4@8V]M<&QE=&5D(&%L;"!O9B!T:&4@<W1E<',@
M:6X@=&AE"B`@("`@("`@("`@("`@("`@(&!H;W)D92]D;V-S+TE.4U1!3$Q@
M7R!F:6QE(&9O<B!T:&4@2&]R9&4@1G)A;65W;W)K(&)E9F]R90H@("`@("`@
M("`@("`@("`@("!I;G-T86QL:6YG($E-4"X*"B`@("XN(%]@2&]R9&4@07!P
M;&EC871I;VX@1G)A;65W;W)K8#H@:'1T<#HO+W=W=RYH;W)D92YO<F<O:&]R
M9&4O"@I4:&4@9F]L;&]W:6YG(&%R92!N;W0@<F5Q=6ER960L(&)U="!A<F4@
M<W1R;VYG;'D@<F5C;VUM96YD960Z"@HQ+B!344P@86YD+V]R($Q$05`@<W5P
M<&]R="!I;B!02%`N"@H@("!4=7)B82!C86X@<W1O<F4@:71S(&-O;G1A8W1S
M(&5N=')I97,@:6X@96ET:&5R(&%N(%-13"!O<B!A;B!,1$%0(&1A=&%B87-E
M+`H@("!A;F0@8V%N('%U97)Y('!U8FQI8R`H<F5A9"UO;FQY*2!,1$%0(&1A
M=&%B87-E<R!F;W(@8V]N=&%C=',@87,@=V5L;"X*("`@0G5I;&0@4$A0('=I
M=&@@=VAI8VAE=F5R($Q$05`@;W(@4U%,(&1R:79E<G,@>6]U(')E<75I<F4[
M('-E92!T:&4@2&]R9&4*("`@24Y35$%,3%\@9FEL92!F;W(@9&5T86EL<RX*
M"@I);G-T86QL:6YG(%1U<F)A"CT]/3T]/3T]/3T]/3T]/3T*"E1U<F)A(&ES
M('=R:71T96X@:6X@4$A0+"!A;F0@;75S="!B92!I;G-T86QL960@:6X@82!W
M96(M86-C97-S:6)L92!D:7)E8W1O<GDN"E1H92!P<F5C:7-E(&QO8V%T:6]N
M(&]F('1H:7,@9&ER96-T;W)Y('=I;&P@9&EF9F5R(&9R;VT@<WES=&5M('1O
M"G-Y<W1E;2X@0V]N=F5N=&EO;F%L;'DL(%1U<F)A(&ES(&EN<W1A;&QE9"!D
M:7)E8W1L>2!U;F1E<FYE871H($AO<F1E(&EN('1H90IW96)S97)V97(G<R!D
M;V-U;65N="!T<F5E+@H*4VEN8V4@5'5R8F$@:7,@=W)I='1E;B!I;B!02%`L
M('1H97)E(&ES(&YO(&-O;7!I;&%T:6]N(&YE8V5S<V%R>3L@<VEM<&QY"F5X
M<&%N9"!T:&4@9&ES=')I8G5T:6]N('=H97)E('EO=2!W86YT(&ET('1O(')E
M<VED92!A;F0@<F5N86UE('1H92!R;V]T"F1I<F5C=&]R>2!O9B!T:&4@9&ES
M=')I8G5T:6]N('1O('=H871E=F5R('EO=2!W:7-H('1O(&%P<&5A<B!I;B!T
M:&4@55),+B`@1F]R"F5X86UP;&4L('=I=&@@=&AE($%P86-H92!W96)S97)V
M97(G<R!D969A=6QT(&1O8W5M96YT(')O;W0@;V8*8&`O=7-R+VQO8V%L+V%P
M86-H92]H=&1O8W-@8"P@>6]U('=O=6QD('1Y<&4Z.@H*("`@8V0@+W5S<B]L
M;V-A;"]A<&%C:&4O:'1D;V-S+VAO<F1E"B`@('1A<B!Z>'9F("]P871H+W1O
M+W1U<F)A+7@N>2YZ+G1A<BYG>@H@("!M=B!T=7)B82UX+GDN>B!T=7)B80H*
M86YD('=O=6QD('1H96X@9FEN9"!4=7)B82!A="!T:&4@55),.CH*"B`@(&AT
M='`Z+R]Y;W5R+7-E<G9E<B]H;W)D92]T=7)B82\*"@I#;VYF:6=U<FEN9R!4
M=7)B80H]/3T]/3T]/3T]/3T]/3T]/0H*,2X@0V]N9FEG=7)I;F<@2&]R9&4@
M9F]R(%1U<F)A"@H@("!A+B!296=I<W1E<B!T:&4@87!P;&EC871I;VX*"B`@
M("`@($EN(&!@:&]R9&4O8V]N9FEG+W)E9VES=')Y+G!H<&!@+"!F:6YD('1H
M92!@8&%P<&QI8V%T:6]N<ULG='5R8F$G76!@"B`@("`@('-T86YZ82X@(%1H
M92!D969A=6QT('-E='1I;F=S(&AE<F4@<VAO=6QD(&)E(&]K87DL(&)U="!Y
M;W4@8V%N(&-H86YG90H@("`@("!T:&5M(&EF(&1E<VER960N("!)9B!Y;W4@
M:&%V92!C:&%N9V5D('1H92!L;V-A=&EO;B!O9B!4=7)B82!R96QA=&EV92!T
M;PH@("`@("!(;W)D92P@96ET:&5R(&EN('1H92!54DPL(&EN('1H92!F:6QE
M<WES=&5M(&]R(&)O=&@L('EO=2!M=7-T('5P9&%T92!T:&4*("`@("`@8&!F
M:6QE<F]O=&!@(&%N9"!@8'=E8G)O;W1@8"!S971T:6YG<R!T;R!T:&5I<B!C
M;W)R96-T('9A;'5E<RX*"B`@(&(N($]P=&EO;F%L.B!0<F]V:61E(%1U<F)A
M(&%C8V5S<R!F<F]M($E-4`H*("`@("`@268@>6]U('=I<V@@=&\@:&%V92!4
M=7)B82!A<'!E87(@:6X@24U0)W,@;65N=6)A<BP@961I="!)35`G<PH@("`@
M("!C;VYF:6=U<F%T:6]N(&%N9"!S96QE8W0@5'5R8F$@:6X@8&!!9&UI;FES
M=')A=&EO;B]#;VYF:6=U<F%T:6]N+TUE;G4*("`@("`@4V5T=&EN9W-@8"X*
M"C(N($-R96%T:6YG(&1A=&%B87-E<PH*("`@5&AE('-P96-I9FEC('-T97!S
M('1O(&-R96%T92!4=7)B82!D871A8F%S97,@9&5P96YD(&]N('=H:6-H(&1A
M=&%B87-E"B`@('EO=2=V92!C:&]S96X@=&\@=7-E+@H*("`@1FER<W0L(&QO
M;VL@:6X@8&!S8W)I<'1S+V1R:79E<G,O8&`@=&\@<V5E(&EF(&$@<V-R:7!T
M(&%L<F5A9'D@97AI<W1S(&9O<@H@("!Y;W5R(&1A=&%B87-E('1Y<&4@*%-1
M3"!O<B!,1$%0*2X@($EF('-O+"!Y;W4@<VAO=6QD(&)E(&%B;&4@=&\@<VEM
M<&QY"B`@(&5X96-U=&4@=&AA="!S8W)I<'0@87,@<W5P97)U<V5R(&EN('EO
M=7(@9&%T86)A<V4N("`H3F]T92!T:&%T(&5X96-U=&EN9PH@("!T:&4@<V-R
M:7!T(&%S('1H92`B:&]R9&4B('5S97(@=VEL;"!P<F]B86)L>2!F86EL('=H
M96X@9W)A;G1I;F<*("`@<')I=FEL96=E<RXI"@H@("!)9B!S=6-H(&$@<V-R
M:7!T(&1O97,@;F]T(&5X:7-T+"!Y;W4G;&P@;F5E9"!T;R!B=6EL9"!Y;W5R
M(&]W;BP@=7-I;F<@=&AE"B`@(&9I;&4@8&!T=7)B82YS<6Q@8"!A<R!A('-T
M87)T:6YG('!O:6YT+B`@268@>6]U(&YE960@87-S:7-T86YC92!I;B!C<F5A
M=&EN9PH@("!D871A8F%S97,L('EO=2!M87D@=VES:"!T;R!L970@=7,@:VYO
M=R!O;B!T:&4@5'5R8F$@;6%I;&EN9R!L:7-T+@H*,RX@0V]N9FEG=7)I;F<@
M5'5R8F$N"@H@("!4;R!C;VYF:6=U<F4@5'5R8F$L(&-H86YG92!T;R!T:&4@
M8&!C;VYF:6<O8&`@9&ER96-T;W)Y(&]F('1H92!I;G-T86QL960*("`@9&ES
M=')I8G5T:6]N+"!A;F0@;6%K92!C;W!I97,@;V8@86QL(&]F('1H92!C;VYF
M:6=U<F%T:6]N(&!@9&ES=&!@(&9I;&5S"B`@('=I=&AO=70@=&AE(&!@9&ES
M=&!@('-U9F9I>#HZ"@H@("`@("!C9"!C;VYF:6<O"B`@("`@(&9O<B!F;V\@
M:6X@*BYD:7-T.R!D;R!C<"`D9F]O(&!B87-E;F%M92`D9F]O("YD:7-T8#L@
M9&]N90H*("`@3W(@;VX@5VEN9&]W<SHZ"@H@("`@("!C;W!Y("HN9&ES="`J
M+@H*("`@1&]C=6UE;G1A=&EO;B!O;B!T:&4@9F]R;6%T(&%N9"!P=7)P;W-E
M(&]F('1H;W-E(&9I;&5S(&-A;B!B92!F;W5N9"!I;B!E86-H"B`@(&9I;&4N
M("!9;W4@;6%Y(&5D:70@=&AE<V4@9FEL97,@:68@>6]U('=I<V@@=&\@8W5S
M=&]M:7IE(%1U<F)A)W,@87!P96%R86YC90H@("!A;F0@8F5H879I;W5R+B`@
M5VET:"!T:&4@97AC97!T:6]N(&]F('1H92!@8'-O=7)C97,N<&AP8&`@9FEL
M92!T:&4@9&5F875L=',*("`@=VEL;"!B92!C;W)R96-T(&9O<B!M;W-T('-I
M=&5S+@H*("`@66]U(&UU<W0@8V]N9FEG=7)E(&!@<V]U<F-E<RYP:'!@8"!T
M;R!L:7-T('EO=7(@9&%T82!S;W5R8V5S("AB;W1H(%-13"!A;F0*("`@3$1!
M4"!I9B!N96-E<W-A<GDI+B`@5&AI<R!C;VYF:6=U<F%T:6]N(&9I;&4@8V]N
M=&%I;G,@82!L87)G92!N=6UB97(@;V8*("`@*BIE>&%M<&QE<RHJ+B`@4&QE
M87-E(')E;6]V92!O<B!C;VUM96YT(&]U="!T:&]S92!E>&%M<&QE<R!T:&%T
M("HJ>6]U(&1O;B=T"B`@(&YE960J*BX*"B`@(%EO=2!M=7-T(&QO9VEN('1O
M($AO<F1E(&%S(&$@2&]R9&4@061M:6YI<W1R871O<B!T;R!F:6YI<V@@=&AE
M"B`@(&-O;F9I9W5R871I;VX@;V8@5'5R8F$N("!5<V4@=&AE($AO<F1E(&!@
M061M:6YI<W1R871I;VY@8"!M96YU(&ET96T@=&\@9V5T"B`@('1O('1H92!A
M9&UI;FES=')A=&EO;B!P86=E+"!A;F0@=&AE;B!C;&EC:R!O;B!T:&4@8&!#
M;VYF:6=U<F%T:6]N8&`@:6-O;B!T;PH@("!G970@=&AE(&-O;F9I9W5R871I
M;VX@<&%G92X@(%-E;&5C="!@8$%D9')E<W,@0F]O:V!@(&9R;VT@=&AE('-E
M;&5C=&EO;@H@("!L:7-T(&]F(&%P<&QI8V%T:6]N<RX@($9I;&P@:6X@;W(@
M8VAA;F=E(&%N>2!C;VYF:6=U<F%T:6]N('9A;'5E<R!A<PH@("!N965D960N
M("!7:&5N(&1O;F4@8VQI8VL@;VX@8&!'96YE<F%T92!!9&1R97-S($)O;VL@
M0V]N9FEG=7)A=&EO;F!@('1O"B`@(&=E;F5R871E('1H92!@8&-O;F8N<&AP
M8&`@9FEL92X@($EF('EO=7(@=V5B('-E<G9E<B!D;V5S;B=T(&AA=F4@=W)I
M=&4*("`@<&5R;6ES<VEO;G,@=&\@=&AE(%1U<F)A(&-O;F9I9W5R871I;VX@
M9&ER96-T;W)Y(&]R(&9I;&4L(&ET('=I;&P@;F]T(&)E"B`@(&%B;&4@=&\@
M=W)I=&4@=&AE(&9I;&4N("!);B!T:&ES(&-A<V4L(&=O(&)A8VL@=&\@8&!#
M;VYF:6=U<F%T:6]N8&`@86YD"B`@(&-H;V]S92!O;F4@;V8@=&AE(&]T:&5R
M(&UE=&AO9',@=&\@8W)E871E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4*("`@
M8&!T=7)B82]C;VYF:6<O8V]N9BYP:'!@8"X*"B`@($YO=&4@9F]R(&EN=&5R
M;F%T:6]N86P@=7-E<G,Z($E-4"!U<V5S($=.52!G971T97AT('1O('!R;W9I
M9&4@;&]C86P*("`@=')A;G-L871I;VYS(&]F('1E>'0@9&ES<&QA>65D(&)Y
M(&%P<&QI8V%T:6]N<SL@=&AE('1R86YS;&%T:6]N<R!A<F4@9F]U;F0*("`@
M:6X@=&AE('!O+R!D:7)E8W1O<GDN("!)9B!A('1R86YS;&%T:6]N(&ES(&YO
M="!Y970@879A:6QA8FQE(&9O<B!Y;W5R"B`@(&QO8V%L92`H86YD('EO=2!W
M:7-H('1O(&-R96%T92!O;F4I+"!S964@=&AE(&!@:&]R9&4O<&\O4D5!1$U%
M8&`@9FEL92P@;W(*("`@:68@>6]U)W)E(&AA=FEN9R!T<F]U8FQE('5S:6YG
M(&$@<')O=FED960@=')A;G-L871I;VXL('!L96%S92!S964@=&AE"B`@(&!H
M;W)D92]D;V-S+U1204Y33$%424].4V!?(&9I;&4@9F]R(&EN<W1R=6-T:6]N
M<RX*"C0N(%-E8W5R:6YG(%1U<F)A"@H@("!"969O<F4@>6]U(&-A;B!S96-U
M<F4@24U0+"!Y;W4@;F5E9"!A('-E8W5R92!(;W)D92!I;G-T86QL871I;VXN
M("!0;&5A<V4*("`@<F5A9"!T:&4@9FEL92!I;B!@:&]R9&4O9&]C<R]314-5
M4DE466!?(&9O<B!(;W)D92!S96-U<FET>2!I;F9O<FUA=&EO;@H@("!B969O
M<F4@<')O8V5E9&EN9RX*"B`@(%-O;64@;V8@5'5R8F$G<R!C;VYF:6=U<F%T
M:6]N(&9I;&5S(&-O;G1A:6X@<&%S<W=O<F1S('=H:6-H(&QO8V%L('5S97)S
M"B`@(&-O=6QD('5S92!T;R!A8V-E<W,@>6]U<B!D871A8F%S92X@($ET(&ES
M(')E8V]M;65N9&5D('1O(&5N<W5R92!T:&%T(&%T"B`@(&QE87-T('1H92!4
M=7)B82!C;VYF:6=U<F%T:6]N(&9I;&5S("AI;B!@8&-O;F9I9R]@8"D@87)E
M(&YO="!R96%D86)L92!T;PH@("!S>7-T96T@=7-E<G,N("!4:&5R92!A<F4@
M8&`N:'1A8V-E<W-@8"!F:6QE<R!R97-T<FEC=&EN9R!A8V-E<W,@=&\*("`@
M9&ER96-T;W)I97,@=&AA="!D;R!N;W0@;F5E9"!T;R!B92!A8V-E<W-E9"!D
M:7)E8W1L>3L@8F5F;W)E(')E;'EI;F<@;VX*("`@=&AO<V4L(&5N<W5R92!T
M:&%T('EO=7(@=V5B<V5R=F5R('-U<'!O<G1S(&!@+FAT86-C97-S8&`@86YD
M(&ES(&-O;F9I9W5R960*("`@=&\@=7-E('1H96TL(&%N9"!T:&%T('1H92!F
M:6QE<R!I;B!T:&]S92!D:7)E8W1O<FEE<R!A<F4@:6X@9F%C=`H@("!I;F%C
M8V5S<VEB;&4@=FEA('1H92!B<F]W<V5R+@H*("`@06X@861D:71I;VYA;"!A
M<'!R;V%C:"!I<R!T;R!M86ME(%1U<F)A)W,@8V]N9FEG=7)A=&EO;B!F:6QE
M<R!O=VYE9"!B>2!T:&4*("`@=7-E<B!@8')O;W1@8"!A;F0@8GD@82!G<F]U
M<"!W:&EC:"!O;FQY('1H92!W96)S97)V97(@=7-E<B!B96QO;F=S('1O+"!A
M;F0*("`@=&AE;B!M86MI;F<@=&AE;2!R96%D86)L92!O;FQY('1O(&]W;F5R
M(&%N9"!G<F]U<"X@($9O<B!E>&%M<&QE+"!I9B!Y;W5R"B`@('=E8G-E<G9E
M<B!R=6YS(&%S(&!@=W=W+G=W=V!@+"!D;R!A<R!F;VQL;W=S.CH*"B`@("`@
M(&-H;W=N(')O;W0N=W=W(&-O;F9I9R\J"B`@("`@(&-H;6]D(#`T-#`@8V]N
M9FEG+RH*"C4N(%1E<W1I;F<@5'5R8F$*"B`@(%1O('9E<FEF>2!T:&%T(%1U
M<F)A(&ES('=O<FMI;F<@8V]R<F5C=&QY+"!A='1E;7!T('1O(&QO;VL@=7`@
M82!K;F]W;@H@("!E>&ES=&EN9R!A;F0@82!K;F]W;B!N;VYE>&ES=&EN9R!E
M;G1R>2!I;B!E86-H(&]F('EO=7(@9&%T82!S;W5R8V5S+"!A;F0@=&\*("`@
M8W)E871E(&%N9"!T:&5N(&QO;VL@=7`@82!N97<@96YT<GD@:6X@96%C:"!D
M871A('-O=7)C92!W:&EC:"!A;&QO=W,@=7-E<G,*("`@=&\@8W)E871E(&YE
M=R!E;G1R:65S+@H*("`@268@87!P<F]P<FEA=&4L(&5N<W5R92!T:&%T(%1U
M<F)A(&%P<&5A<G,@:6X@=&AE($E-4"!M96YU(&)A<BX*"@I/8G1A:6YI;F<@
M4W5P<&]R=`H]/3T]/3T]/3T]/3T]/3T]/0H*268@>6]U(&5N8V]U;G1E<B!P
M<F]B;&5M<R!W:71H(%1U<F)A+"!H96QP(&ES(&%V86EL86)L92$*"E1H92!(
M;W)D92!&<F5Q=65N=&QY($%S:V5D(%%U97-T:6]N<R!,:7-T("A&05$I+"!A
M=F%I;&%B;&4@;VX@=&AE(%=E8B!A=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R
M9R]F87$O"@I4:&4@2&]R9&4@4')O:F5C="!R=6YS(&$@;G5M8F5R(&]F(&UA
M:6QI;F<@;&ES=',L(&9O<B!I;F1I=FED=6%L(&%P<&QI8V%T:6]N<PIA;F0@
M9F]R(&ES<W5E<R!R96QA=&EN9R!T;R!T:&4@<')O:F5C="!A<R!A('=H;VQE
M+B`@26YF;W)M871I;VXL(&%R8VAI=F5S+"!A;F0*<W5B<V-R:7!T:6]N(&EN
M9F]R;6%T:6]N(&-A;B!B92!F;W5N9"!A=`H*("!H='1P.B\O=W=W+FAO<F1E
M+F]R9R]M86EL+PH*3&%S=&QY+"!(;W)D92!D979E;&]P97)S+"!C;VYT<FEB
M=71O<G,@86YD('5S97)S(&%L<V\@;6%K92!A<'!E87)A;F-E<R!O;B!)4D,L
M"F]N('1H92!C:&%N;F5L("-H;W)D92!O;B!T:&4@9G)E96YO9&4@3F5T=V]R
M:R`H:7)C+F9R965N;V1E+FYE="DN"@I0;&5A<V4@:V5E<"!I;B!M:6YD('1H
M870@5'5R8F$@:7,@9G)E92!S;V9T=V%R92!W<FET=&5N(&)Y('9O;'5N=&5E
M<G,N("!&;W(*:6YF;W)M871I;VX@;VX@<F5A<V]N86)L92!S=7!P;W)T(&5X
M<&5C=&%T:6]N<RP@<&QE87-E(')E860*"B`@:'1T<#HO+W=W=RYH;W)D92YO
M<F<O<W5P<&]R="YP:'`*"E1H86YK<R!F;W(@=7-I;F<@5'5R8F$A"@I4:&4@
M2&]R9&4@=&5A;0H*"BXN(%]214%$344Z(#]F/5)%041-12YH=&UL"BXN(%])
M3E-404Q,.@HN+B!?8&AO<F1E+V1O8W,O24Y35$%,3&`Z("XN+RXN+VAO<F1E
M+V1O8W,O/V8]24Y35$%,3"YH=&UL"BXN(%]@9&]C<R](04-+24Y'8#H@+BXO
M+BXO:&]R9&4O9&]C<R\_9CU(04-+24Y'+FAT;6P*+BX@7V!H;W)D92]D;V-S
M+U!%4D9/4DU!3D-%8#H@+BXO+BXO:&]R9&4O9&]C<R\_9CU015)&3U)-04Y#
M12YH=&UL"BXN(%]@:&]R9&4O9&]C<R]314-54DE466`Z("XN+RXN+VAO<F1E
M+V1O8W,O/V8]4T5#55))5%DN:'1M;`HN+B!?8&AO<F1E+V1O8W,O5%)!3E-,
M051)3TY38#H@+BXO+BXO:&]R9&4O9&]C<R\_9CU44D%.4TQ!5$E/3E,N:'1M
M;`H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]D
M;V-S+TQ$05``````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$Q,S<T`#$P-#$W,S8R-S4V`#`Q-S$T,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!4=7)B82!,1$%0('!E<G-O
M;F%L(&%D9')E<W-B;V]K($A/5U1/"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*"E1H:7,@2$]75$\@:7,@82!B87)E(&)O;F5S(&QI
M<W0@;V8@=VAA="!H87,@=&\@8F4@9&]N92!T;R!I;7!L96UE;G0@82!P97)S
M;VYA;`IA9')E<W-B;V]K('1H<F]U9V@@;&1A<"!F;W(@='5R8F$N"@I4:&4@
M:&]W=&\@:7,@8F%S960@;VX@82!S971U<"!W:&5R92!B;W1H('1H92!A9&1R
M97-S8F]O:R!A;F0@=&AE('5S97)S(&%R90IS=&]R960@;VX@=&AE('-A;64@
M3$1!4"!S97)V97(N"@I4:&ES(&ES(&YO="!C;VUP<F5H96YS:79E+"!B=70@
M:70@;F]T97,@:&]W('-O;64@=7-E<G,@:&%V92!I;7!L96UE;G1E9`IP97)S
M;VYA;"!,1$%0(&%D9')E<W,@8F]O:W,N"@HQ+B!#;VYF:6=U<F4@8&!T=7)B
M82]C;VYF:6<O<V]U<F-E<RYP:'!@8"X*"B`@($YO=&4@=&AA="!/<&5N3$1!
M4"!A;F0@<V]M92!O=&AE<B!,1$%0('-E<G9E<G,@=7-E(%541C@@=&\@96YC
M;V1E(&ET<R!D871A+`H@("!S;R!Y;W4@<VAO=6QD(&AA=F4@8&!E;F-O9&EN
M9R`]("=U=&8X)V!@('-E="!I;B!T:&4@<&%R86UE=&5R<R!F;W(@>6]U<@H@
M("!,1$%0(&%D9')E<W,@8F]O:R!S;W5R8V4N"@H@("!4:&5R92!I<R!A;B!E
M>&%M<&QE(&]F('!E<G-O;F%L(&%D9')E<W,@8F]O:W,@:6X*("`@8&!T=7)B
M82]C;VYF:6<O<V]U<F-E<RYP:'`N9&ES=&!@+B`@66]U('=I;&P@:&%V92!T
M;R!M;V1I9GD@:70@=&\@=&\@;6%T8V@*("`@=&AE(&9I96QD<RP@<V5T=&EN
M9W,L(&%N9"!S8VAE;6$@;V8@>6]U<B!,1$%0('-E<G9E<BP@8G5T(&ET)W,@
M82!S;VQI9`H@("!P;&%C92!T;R!S=&%R="X*"C(N($5N9F]R8V4@04-,<R!T
M;R!P97)S;VYA;"!A9&1R97-S(&)O;VMS+@H*("`@061D('1H:7,@=&\@>6]U
M<B!,1$%0($%#3"!S;R!U<V5R<R!C86X@;VYL>2!S964@=&AE:7(@;W=N(&%D
M9')E<W,@8F]O:SHZ"@H@("`@(&%C8V5S<R!T;R!D;CTB;W4]*"XK*2P@;W4]
M<&5R<V]N86Q?861D<F5S<V)O;VLL(&1C/65X86UP;&4L(&1C/6-O;2(*("`@
M("`@("`@8GD@9&X](G5I9#TD,2P@9&,]97AA;7!L92P@9&,]8V]M(B!W<FET
M90H@("`@("`@("!B>2`J(&YO;F4*"B`@("XN($YO=&4Z.B!4:&ES(&%S<W5M
M97,@=&AA="!Y;W4@<W1O<F4@>6]U<B!U<V5R<R!I;B!T:&4@<V%M92!,1$%0
M"B`@("`@("`@("`@("!D:7)E8W1O<GDN($EF(&YO="P@;6]D:69Y(&%P<')O
M<')I871E;'D@9F]R('EO=7(@<V5T=7`N"@HS+B!-86ME(&!@;W5@8"=S(&9O
M<B!A;&P@;V8@>6]U<B!U<V5R<RX*"B`@(%EO=2=L;"!A;'-O(&AA=F4@=&\@
M861D('1H:7,@=&\@=&AE('-C<FEP="!Y;W4@=7-E('1O(&%D9"!U<V5R<R!T
M;R!Y;W5R"B`@($Q$05`@9&ER96-T;W)Y+@H*("`@8&!T=7)B82]S8W)I<'1S
M+VQD87`O861D;W4N<&Q@8"!I<R!A('-T87)T:6YG('!O:6YT.R!Y;W4@=VEL
M;"!N965D('1O(&5D:70*("`@:70@=&\@9FET('EO=7(@;F5E9',N($-O<'D@
M8F]T:"!I="!A;F0@=&AE(&!@861D;W5@8"!S:&5L;"!S8W)I<'0@=&\*("`@
M8&`O:&]M96!@+B`@5&AE;B!R=6X@8&`N+V%D9&]U8&`@86YD(&%L;"!T:&4@
M9&EF9F5R96YT(&YA;65S(&]F('1H90H@("!C871A;&]G=65S('=I;&P@8F4@
M861D960@=&\@=&AE(&QD87`@=')E92!A<R!N97<@8&!O=6!@)W,@=&\@<W1O
M<F4*("`@861D<F5S<V5S(&EN+B!9;W4@<VAO=6QD('!R;V)A8FQY(&1E;&5T
M92!A;GD@96YT<FEE<R!T:&%T(&1O(&YO="!B96QO;F<*("`@=&AE<F4@*&9O
M<B!I;G-T86YC92P@8&`O:&]M96!@(&1I<F5C=&]R:65S(&9O<B!M>7-Q;"!A
M;F0@;W1H97(@9&%E;6]N<PH@("!C<F5A=&5D(&)Y('-O;64@9&ES=')I8G5T
M:6]N<RDN"@H*16YT<FEE<R!F;W(@5'5R8F$M<W!E8VEF:6,@:6YF;W)M871I
M;VX@*&-O;G1A8W0@9W)O=7!S*2!F<F]M(&AO<F1E+W-C<FEP=',O;&1A<"]H
M;W)D92YS8VAE;6$Z.@H*("`@(PH@("`C(%1U<F)A(&%T=')I8G5T92!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+BH*("`@(PH@("!A='1R:6)U=&5T
M>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C(*("`@("!.04U%("=T=7)B
M851Y<&4G"B`@("`@1$530R`G5'5R8F$@3V)J96-T(%1Y<&4Z($-O;G1A8W0O
M3&ES="<*("`@("!%455!3$E462!C87-E26=N;W)E24$U36%T8V@*("`@("!3
M54)35%(@8V%S94EG;F]R94E!-5-U8G-T<FEN9W--871C:`H@("`@(%-93E1!
M6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLX?2`I"@H@("!A='1R
M:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C,*("`@("!.04U%
M("=T=7)B84UE;6)E<G,G"B`@("`@1$530R`G16YC;V1E9"!M96UB97)S(&]F
M(&$@5'5R8F$@;&ES="<*("`@("!%455!3$E462!C87-E26=N;W)E24$U36%T
M8V@*("`@("!364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M-#`P,'T@*0H*("`@871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C0N,2XT"B`@("`@3D%-12`G='5R8F%01U!0=6)L:6-+97DG"B`@("`@1$53
M0R`G4$=0+T=01R!0=6)L:6,@2V5Y)PH@("`@($5154%,2519(&-A<V5)9VYO
M<F5)035-871C:`H@("`@(%-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ
M,C$N,2XR-GLT,#`P?2`I"@H*16YT<FEE<R!F;W(@8V%L96YD87)I;F<@:6YF
M;W)M871I;VX@*&9R964O8G5S>2P@971C+BD@9G)O;2!21D,@,C<S.3HZ"@H@
M("!A='1R:6)U=&4@*#$N,BXX-#`N,3$S-34V+C$N-"XT-S@*("`@("!.04U%
M("=C86Q#86Q54DDG"B`@("`@1$530R`G4VYA<'-H;W0@;V8@=7-E<G,@96YT
M:7)E(&1E9F%U;'0@8V%L96YD87(G"B`@("`@15%504Q)5%D@8V%S94EG;F]R
M94UA=&-H"B`@("`@4U5"4U12(&-A<V5)9VYO<F5-871C:`H@("`@(%-93E1!
M6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-@H@("`@*0H*("`@871T
M<FEB=71E("@Q+C(N.#0P+C$Q,S4U-BXQ+C0N-#<Y"B`@("`@3D%-12`G8V%L
M1D)54DPG"B`@("`@1$530R`G55))(&]F('1H92!U<V5S(&9R964@86YD(&)U
M<WD@:6YF;W)M871I;VXG"B`@("`@15%504Q)5%D@8V%S94EG;F]R94UA=&-H
M"B`@("`@4U5"4U12(&-A<V5)9VYO<F5-871C:`H@("`@(%-93E1!6"`Q+C,N
M-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-@H@("`@*0H*("`@871T<FEB=71E
M("@Q+C(N.#0P+C$Q,S4U-BXQ+C0N-#@P"B`@("`@3D%-12`G8V%L0T%055))
M)PH@("`@($1%4T,@)U5222!U<V5D('1O(&-O;6UU;FEC871E('=I=&@@=&AE
M('5S97)S(&-A;&5N9&%R)PH@("`@($5154%,2519(&-A<V5)9VYO<F5-871C
M:`H@("`@(%-50E-44B!C87-E26=N;W)E36%T8V@*("`@("!364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C8*("`@("D*"B`@(&%T=')I8G5T
M92`H,2XR+C@T,"XQ,3,U-38N,2XT+C0X,0H@("`@($Y!344@)V-A;$-A;$%D
M<E5222<*("`@("!$15-#("=54DD@=&\@=VAI8V@@979E;G0@<F5Q=65S=',@
M<VAO=6QD(&)E('-E;G0@9F]R('1H92!U<V5R)PH@("`@($5154%,2519(&-A
M<V5)9VYO<F5-871C:`H@("`@(%-50E-44B!C87-E26=N;W)E36%T8V@*("`@
M("!364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C8*("`@("D*
M"B`@(&%T=')I8G5T92`H,2XR+C@T,"XQ,3,U-38N,2XT+C0X,@H@("`@($Y!
M344@)V-A;$]T:&5R0V%L55))<R<*("`@("!$15-#("=54DES('1O(&YO;BUD
M969A=6QT(&-A;&5N9&%R<R!B96QO;F=I;F<@=&\@=&AE('5S97(G"B`@("`@
M15%504Q)5%D@8V%S94EG;F]R94UA=&-H"B`@("`@4U5"4U12(&-A<V5)9VYO
M<F5-871C:`H@("`@(%-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N
M,2XR-@H@("`@*0H*("`@871T<FEB=71E("@Q+C(N.#0P+C$Q,S4U-BXQ+C0N
M-#@S"B`@("`@3D%-12`G8V%L3W1H97)&0E523',G"B`@("`@1$530R`G55))
M<R!T;R!N;VXM9&5F875L="!F<F5E(&%N9"!B=7-Y(&EN9F]R;6%T:6]N(&9I
M;&5S)PH@("`@($5154%,2519(&-A<V5)9VYO<F5-871C:`H@("`@(%-50E-4
M4B!C87-E26=N;W)E36%T8V@*("`@("!364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C8*("`@("D*"B`@(&%T=')I8G5T92`H,2XR+C@T,"XQ
M,3,U-38N,2XT+C0X-`H@("`@($Y!344@)V-A;$]T:&5R0T%055))<R<*("`@
M("!$15-#("=54DES(&9O<B!C;VUM=6YI8V%T:6YG('=I=&@@;F]N+61E9F%U
M;'0@8V%L96YD87)S)PH@("`@($5154%,2519(&-A<V5)9VYO<F5-871C:`H@
M("`@(%-50E-44B!C87-E26=N;W)E36%T8V@*("`@("!364Y405@@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C8*("`@("D*"B`@(&%T=')I8G5T92`H
M,2XR+C@T,"XQ,3,U-38N,2XT+C0X-0H@("`@($Y!344@)V-A;$]T:&5R0V%L
M061R55))<R<*("`@("!$15-#("=$97-T:6YA=&EO;G,@9F]R(&5V96YT(')E
M<75E<W1S('1O(&YO;BUD969A=6QT(&-A;&5N9&%R<R<*("`@("!%455!3$E4
M62!C87-E26=N;W)E36%T8V@*("`@("!354)35%(@8V%S94EG;F]R94UA=&-H
M"B`@("`@4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V"B`@
M("`I"@H@("!O8FIE8W1C;&%S<R`H,2XR+C@T,"XQ,3,U-38N,2XU+C@W"B`@
M("!.04U%("=C86Q%;G1R>2<*("`@($1%4T,@)T-A;&5N9&5R:6YG(&%N9"!&
M<F5E($)U<WD@:6YF;W)M871I;VXG"B`@("!355`@=&]P($%56$E,24%260H@
M("`@34%9("AC86Q#86Q54DD@)"!C86Q&0E523"`D(&-A;$-!4%5222`D(&-A
M;$-A;$%D<E5222`D"B`@("`@("`@(&-A;$]T:&5R0V%L55))<R`D(&-A;$]T
M:&5R1D)54DQS("0@8V%L3W1H97)#05!54DES("0*("`@("`@("`@8V%L3W1H
M97)#86Q!9')54DES"B`@("`@("`@*0H@("`@*0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M='5R8F$O9&]C<R]214Q%05-%7TY/5$53````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#,U,``Q,#0Q-S,V,C<U-@`P,C`T-#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%)E;&5A<V4@9F]C=7,N(%!O<W-I8FQE('9A;'5E<SH*("H@,"`M($XO
M00H@*B`Q("T@26YI=&EA;"!F<F5S:&UE870@86YN;W5N8V5M96YT"B`J(#(@
M+2!$;V-U;65N=&%T:6]N"B`J(#,@+2!#;V1E(&-L96%N=7`*("H@-"`M($UI
M;F]R(&9E871U<F4@96YH86YC96UE;G1S"B`J(#4@+2!-86IO<B!F96%T=7)E
M(&5N:&%N8V5M96YT<PH@*B`V("T@36EN;W(@8G5G9FEX97,*("H@-R`M($UA
M:F]R(&)U9V9I>&5S"B`J(#@@+2!-:6YO<B!S96-U<FET>2!F:7AE<PH@*B`Y
M("T@36%J;W(@<V5C=7)I='D@9FEX97,*("HO"B1T:&ES+3YN;W1E<ULG9FTG
M75LG9F]C=7,G72`](#4["@HO*B!-86EL:6YG(&QI<W0@<F5L96%S92!N;W1E
M<RX@*B\*)'1H:7,M/FYO=&5S6R=M;"==6R=C:&%N9V5S)UT@/2`\/#Q-3`I4
M:&4@2&]R9&4@5&5A;2!I<R!P;&5A<V5D('1O(&%N;F]U;F-E('1H92!F:6YA
M;"!R96QE87-E(&]F('1H92!4=7)B82!#;VYT86-T"DUA;F%G97(@=F5R<VEO
M;B!(,R`H,BXQ*2X*"E1U<F)A(&ES('1H92!(;W)D92!C;VYT86-T(&UA;F%G
M96UE;G0@87!P;&EC871I;VXN($ET(&ES(&$@<')O9'5C=&EO;B!L979E;`IA
M9&1R97-S(&)O;VLL(&%N9"!M86ME<R!H96%V>2!U<V4@;V8@=&AE($AO<F1E
M(&9R86UE=V]R:R!T;R!P<F]V:61E"FEN=&5G<F%T:6]N('=I=&@@24U0(&%N
M9"!O=&AE<B!(;W)D92!A<'!L:6-A=&EO;G,N"@I-86IO<B!C:&%N9V5S(&-O
M;7!A<F5D('1O('1H92!4=7)B82!(,R`H,BXP*2!V97)S:6]N<R!A<F4Z"B`@
M("`J(%-U8FUE;G4@=VET:"!A9&1R97-S(&)O;VMS(&%N9"`B061D(B!A;F0@
M(E-E87)C:"(@96YT<FEE<R!I;B!S:61E8F%R+@H@("`@*B!$:7-T<FEB=71I
M;VX@;&ES=',@8V%N(&-O;G1A:6X@8V]N=&%C=',@9G)O;2!M=6QT:7!L92!S
M;W5R8V5S+@H@("`@*B!3:&%R960@861D<F5S<R!B;V]K<RX*("`@("H@4&%G
M960@8G)O=W-E('9I97<N"B`@("`J($%D9"!F:6QE<R!A;F0@=&AR96%D960@
M8V]M;65N=',@=&\@8V]N=&%C=',N"B`@("`J($5D:70@<V5V97)A;"!C;VYT
M86-T<R!A="!O;F-E+@H@("`@*B!);7!R;W9E9"!#4U8@:6UP;W)T+@H@("`@
M*B!+965P(&YA;65S(&]P=&EO;F%L;'D@=6YF;W)M871T960N"B`@("`J($5X
M<&]R="!M;W)E('1H86X@;VYE('9#87)D(&%T(&]N8V4N"B`@("`J($YE=R!L
M86YG=6%G93H@26-E;&%N9&EC+@H@("`@*B!$<F]P(&-A8VAE9"!S96%R8VAE
M<RX*("`@("H@0V]M<&%T:6)L92!W:71H(%!(4"`U+C$N"B`@("`J($EM<')O
M=F5D($U3+5-13"!S=7!P;W)T+@H@("`@*B!097)M:7-S:6]N<R!M86YA9V5D
M(&-O;7!L971E;'D@=&AO=6=H(&%D;6EN:7-T<F%T:6]N(&EN=&5R9F%C92X*
M("`@("H@4&5R;6ES<VEO;B!T;R!R97-T<FEC="!N=6UB97(@;V8@8V]N=&%C
M=',N"B`@("`J($-O;6UA;F0@;&EN92!S8W)I<'0@=&\@8F%T8V@@:6UP;W)T
M('9#87)D<RX*34P["@HO*B!&<F5S:&UE870@<F5L96%S92!N;W1E<RP@;F]T
M(&UO<F4@=&AA;B`V,#`@8VAA<F%C=&5R<RX@*B\*)'1H:7,M/FYO=&5S6R=F
M;2==6R=C:&%N9V5S)UT@/2`\/#Q&30I!('-U8FUE;G4@=VET:"!A9&1R97-S
M(&)O;VMS(&AA<R!B965N(&%D9&5D('1O('1H92!S:61E8F%R+B!$:7-T<FEB
M=71I;VX@;&ES=',@86QL;W<@8V]N=&%C=',@9G)O;2!M=6QT:7!L92!S;W5R
M8V5S+B!3:&%R960@861D<F5S<R!B;V]K<R!A;F0@<W5P<&]R="!F;W(@861D
M:6YG(&9I;&5S(&%N9"!T:')E861E9"!C;VUM96YT<R!T;R!C;VYT86-T<R!H
M879E(&)E96X@861D960N(%-E=F5R86P@8V]N=&%C=',@8V%N(&)E(&%D9&5D
M(&%T(&]N8V4N($-35B!I;7!O<G0@86YD($U3+5-13"!S=7!P;W)T(&AA=F4@
M8F5E;B!I;7!R;W9E9"X@3F%M97,@87)E(&]P=&EO;F%L;'D@:V5P="!U;F9O
M<FUA='1E9"X@36]R92!T:&%N(&]N92!V0V%R9"!C86X@8F4@861D960@870@
M;VYC92X@0V%C:&5D('-E87)C:&5S(&AA=F4@8F5E;B!D<F]P<&5D+B!097)M
M:7-S:6]N(&UA;F%G96UE;G0@:&%S(&)E96X@<VEM<&QI9FEE9"!A;F0@;F5W
M('!E<FUI<W-I;VYS('1O(')E<W1R:6-T('1H92!N=6UB97(@;V8@8V]N=&%C
M=',@:&%V92!B965N(&%D9&5D+B!!(&-O;6UA;F0@;&EN92!S8W)I<'0@=&\@
M8F%T8V@@:6UP;W)T('9#87)D<R!H87,@8F5E;B!A9&1E9"X*1DT["@HD=&AI
M<RT^;F]T97-;)VYA;64G72`]("=4=7)B82<["B1T:&ES+3YN;W1E<ULG9FTG
M75LG<')O:F5C="==(#T@)W1U<F)A)SL*)'1H:7,M/FYO=&5S6R=F;2==6R=B
M<F%N8V@G72`]("=(;W)D92`S)SL*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O='5R8F$O9&]C<R]43T1/````````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8S-@`Q,#0Q-S,V,C<U-@`P
M,3<Q-C8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*(%1U<F)A($1E=F5L
M;W!M96YT(%1/1$\@3&ES=`H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`T+S$P+S(Y(#(R.C0X.C(R
M("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XS("0*.D-O;G1A8W0Z
M("`@("`@('1U<F)A0&QI<W1S+FAO<F1E+F]R9PH*+2!!9&0@9F5A='5R92!T
M;R!A;&QO=R!E86-H('5S97(@=&\@<V5T('5P('1H96ER(&]W;B!F:65L9'-E
M="P@;6%Y8F4@<W1O<FEN9PH@('-U8V@@<F5C;W)D<R!I;B!A;B!344P@871T
M<FEB=71E<RUT>7!E($1"(&)A8VME;F0N"@HM($9I9W5R92!O=70@:&]W('1O
M('-A;F5L>2!N86UE($=R;W5P<R!W:&5N('5S:6YG(&$@8V]M<&]S:71E("=N
M86UE)R!F:65L9"X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1U<F)A+V1O8W,O3$E#14Y310``````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#0S-S$`,3`T,3<S-C(W-38`,#$W-3`S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````%9E<G-I;VX@
M,2XP"@I#;W!Y<FEG:'0@*&,I(#(P,#`M,C`P,B!4:&4@2&]R9&4@4')O:F5C
M="X@06QL(')I9VAT<R!R97-E<G9E9"X*"E)E9&ES=')I8G5T:6]N(&%N9"!U
M<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U
M=`IM;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T
M:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@87)E"FUE=#H*"C$N(%)E9&ES=')I
M8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@
M8V]P>7)I9VAT"FYO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD
M('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*"C(N(%)E9&ES=')I8G5T:6]N
M<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P
M>7)I9VAT"FYO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4*9&]C=6UE;G1A=&EO;B!A
M;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R
M:6)U=&EO;BX*"C,N(%1H92!E;F0M=7-E<B!D;V-U;65N=&%T:6]N(&EN8VQU
M9&5D('=I=&@@=&AE(')E9&ES=')I8G5T:6]N+"!I9@IA;GDL(&UU<W0@:6YC
M;'5D92!T:&4@9F]L;&]W:6YG(&%C:VYO=VQE9&=M96YT.@H*("`@(E1H:7,@
M<')O9'5C="!I;F-L=61E<R!S;V9T=V%R92!D979E;&]P960@8GD@=&AE($AO
M<F1E(%!R;VIE8W0*("`@("AH='1P.B\O=W=W+FAO<F1E+F]R9R\I+B(*"D%L
M=&5R;F%T96QY+"!T:&ES(&%C:VYO=VQE9&=M96YT(&UA>2!A<'!E87(@:6X@
M=&AE('-O9G1W87)E(&ET<V5L9BP@:68*86YD('=H97)E=F5R('-U8V@@=&AI
M<F0M<&%R='D@86-K;F]W;&5D9VUE;G1S(&YO<FUA;&QY(&%P<&5A<BX*"C0N
M(%1H92!N86UE<R`B5'5R8F$B+"`B2&]R9&4B(&%N9"`B5&AE($AO<F1E(%!R
M;VIE8W0B(&UU<W0@;F]T(&)E('5S960*=&\@96YD;W)S92!O<B!P<F]M;W1E
M('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70*
M<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+B!&;W(@=W)I='1E;B!P97)M:7-S
M:6]N+"!P;&5A<V4@8V]N=&%C=`IC;W)E0&AO<F1E+F]R9RX*"C4N(%!R;V1U
M8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E(&UA>2!N;W0@8F4@8V%L
M;&5D(")4=7)B82(@;W(*(DAO<F1E(BP@;F]R(&UA>2`B5'5R8F$B(&]R(")(
M;W)D92(@87!P96%R(&EN('1H96ER(&YA;64L('=I=&AO=70*<')I;W(@=W)I
M='1E;B!P97)M:7-S:6]N(&]F('1H92!(;W)D92!0<F]J96-T+@H*5$A)4R!3
M3T945T%212!)4R!04D]6241%1"`B05,@25,B($%.1"!!3ED@15A04D534T5$
M($]2($E-4$Q)140*5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)
M34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8*34520TA!3E1!
M0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!
M4D4*1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($%004-(12!3
M3T945T%212!&3U5.1$%424].($]2($E44PI#3TY44DE"551/4E,@0D4@3$E!
M0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%
M0TE!3"P*15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.
M0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+`I04D]#55)%345.5"!/1B!3
M54)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%4
M02P@3U(*4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%
M5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1@I,24%"24Q)5%DL(%=(
M151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@
M*$E.0TQ51$E.1PI.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,*4T]&5%=!4D4L($56
M14X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!
M1T4N"@I4:&ES('-O9G1W87)E(&-O;G-I<W1S(&]F('9O;'5N=&%R>2!C;VYT
M<FEB=71I;VYS(&UA9&4@8GD@;6%N>0II;F1I=FED=6%L<R!O;B!B96AA;&8@
M;V8@=&AE($AO<F1E(%!R;VIE8W0N($9O<B!M;W)E(&EN9F]R;6%T:6]N(&]N
M"G1H92!(;W)D92!0<F]J96-T+"!P;&5A<V4@<V5E(#QH='1P.B\O=W=W+FAO
M<F1E+F]R9R\^+@H*+2TM+2TM+2TM+0HD2&]R9&4Z('1U<F)A+TQ)0T5.4T4L
M=B`Q+C$N,BXR(#(P,#4O,3`O,3@@,3(Z-3`Z,#,@:F%N($5X<"`D````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1U<F)A+V5D:70N<&AP````````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(V-#$`,3`T,3<S-C(W-38`
M,#$W,C`T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z('1U<F)A+V5D:70N<&AP+'8@,2XW
M,"XT+C8@,C`P-B\P,2\P,2`R,3HR.3HQ-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#`M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y3
M12!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D
M92YO<F<O;&EC96YS97,O87-L+G!H<"X*("HO"@I`9&5F:6YE*"=455)"05]"
M05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@5%520D%?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E(%154D)!7T)!
M4T4@+B`G+VQI8B]296YD97)E<BYP:'`G.PIR97%U:7)E7V]N8V4@5%520D%?
M0D%312`N("<O;&EB+T]B:F5C=%9I97<N<&AP)SL*<F5Q=6ER95]O;F-E(%15
M4D)!7T)!4T4@+B`G+VQI8B],:7-T+G!H<"<["G)E<75I<F5?;VYC92!455)"
M05]"05-%("X@)R]L:6(O3&ES=%9I97<N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]&;W)M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S
M+G!H<"<["@HD<F5N9&5R97(@/2`F;F5W(%1U<F)A7U)E;F1E<F5R*"D["B1V
M87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PHD<V]U
M<F-E(#T@)'9A<G,M/F=E="@G<V]U<F-E)RD["B1O<FEG:6YA;%]S;W5R8V4@
M/2`D=F%R<RT^9V5T*"=O<FEG:6YA;%]S;W5R8V4G*3L*)&ME>2`]("1V87)S
M+3YG970H)VME>2<I.PHD9W)O=7!E9&ET(#T@)'9A<G,M/F=E="@G86-T:6]N
M240G*2`]/2`G9W)O=7!E9&ET)SL*)&]B:F5C=&ME>7,@/2`D=F%R<RT^9V5T
M*"=O8FIE8W1K97ES)RD["B1U<FP@/2`D=F%R<RT^9V5T*"=U<FPG+"!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)'!R969S+3YG971686QU92@G:6YI=&EA;%]P
M86=E)RDL('1R=64I*3L*"B\J($5D:70@=&AE(&9I<G-T(&]F(&$@;&ES="!O
M9B!C;VYT86-T<S\@*B\*:68@*"1G<F]U<&5D:70@)B8@*"$D:V5Y('Q\("1K
M97D@/3T@)RHJ<V5A<F-H)RDI('L*("`@(&EF("@A8V]U;G0H)&]B:F5C=&ME
M>7,I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W4@;75S
M="!S96QE8W0@870@;&5A<W0@;VYE(&-O;G1A8W0@9FER<W0N(BDL("=H;W)D
M92YW87)N:6YG)RD["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U
M<FPI.PH@("`@("`@(&5X:70["B`@("!]"B`@("!I9B`H)&ME>2`]/2`G*BIS
M96%R8V@G*2!["B`@("`@("`@)&]R:6=I;F%L7W-O=7)C92`]("1K97D["B`@
M("!]"B`@("!L:7-T*"1S;W5R8V4L("1K97DI(#T@97AP;&]D92@G.B<L("1O
M8FIE8W1K97ES6S!=+"`R*3L*("`@(&EF("AS=')P;W,H)&ME>2P@)SHG*2D@
M>PH@("`@("`@(&QI<W0H)&]W;F5R+"`D:V5Y*2`](&5X<&QO9&4H)SHG+"`D
M:V5Y+"`R*3L*("`@("`@("`D<V]U<F-E("X]("<Z)R`N("1O=VYE<CL*("`@
M('T*("`@(&EF("AE;7!T>2@D;W)I9VEN86Q?<V]U<F-E*2D@>PH@("`@("`@
M("1O<FEG:6YA;%]S;W5R8V4@/2`D<V]U<F-E.PH@("`@?0H@("`@)'9A<G,M
M/G-E="@G;W)I9VEN86Q?<V]U<F-E)RP@)&]R:6=I;F%L7W-O=7)C92D["GT*
M"FEF("@D<V]U<F-E(#T]/2!N=6QL('Q\("%I<W-E="@D8V9G4V]U<F-E<ULD
M<V]U<F-E72DI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B5&AE(&-O
M;G1A8W0@>6]U(')E<75E<W1E9"!D;V5S(&YO="!E>&ES="XB*2D["B`@("!H
M96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HD9')I
M=F5R(#T@)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1S;W5R8V4I.PH*+RH@
M4V5T('1H92!C;VYT86-T(&9R;VT@=&AE(&ME>2!R97%U97-T960N("HO"FEF
M("AS=')P;W,H)&ME>2P@)SHG*2D@>PH@("`@;&ES="@D;W=N97(L("1K97DI
M(#T@97AP;&]D92@G.B<L("1K97DL(#(I.PI]"B1O8FIE8W0@/2`D9')I=F5R
M+3YG971/8FIE8W0H)&ME>2D["FEF("AI<U]A*"1O8FIE8W0L("=014%27T5R
M<F]R)RDI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&]B:F5C="T^9V5T
M365S<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C871I
M;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)'!R969S+3YG971686QU
M92@G:6YI=&EA;%]P86=E)RDL('1R=64I*3L*("`@(&5X:70["GT*"B\J($-H
M96-K('!E<FUI<W-I;VYS(&]N('1H:7,@8V]N=&%C="X@*B\*)&5D:71D;VYE
M(#T@9F%L<V4["FEF("@A)&]B:F5C="T^:&%S4&5R;6ES<VEO;BA015)-4U]%
M1$E4*2D@>PH@("!I9B`H(21O8FIE8W0M/FAA<U!E<FUI<W-I;VXH4$5235-?
M4D5!1"DI('L*("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(BDL
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D<')E9G,M/F=E=%9A;'5E*"=I;FET
M:6%L7W!A9V4G*2P@=')U92DI.PH@("`@("`@97AI=#L*("`@?2!E;'-E('L*
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&]N;'D@:&%V92!P
M97)M:7-S:6]N('1O('9I97<@=&AI<R!C;VYT86-T+B(I+"`G:&]R9&4N97)R
M;W(G*3L*("`@("`@("1U<FD@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V1I
M<W!L87DN<&AP)RP@=')U92D["B`@("`@("`D=7)I(#T@571I;#HZ861D4&%R
M86UE=&5R*"1U<FDL(&%R<F%Y*"=S;W5R8V4G(#T^("1O<FEG:6YA;%]S;W5R
M8V4L("=K97DG(#T^("1K97DI+"!N=6QL+"!F86QS92D["B`@("`@("!H96%D
M97(H)TQO8V%T:6]N.B`G("X@)'5R:2D["B`@("`@("!E>&ET.PH@("!]"GT*
M"B1T:71L92`]('-P<FEN=&8H7R@B161I="!E;G1R>2!F;W(@)7,B*2P@)&]B
M:F5C="T^9V5T5F%L=64H)VYA;64G*2D["@HO*B!'970@=&AE(&9O<FT@;V)J
M96-T+B`J+PHD9F]R;2`]("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)R<L("1V
M87)S+"`D=&ET;&4I.PII9B`H)&=R;W5P961I="D@>PH@("`@)&9O<FTM/F%D
M9$AI9&1E;B@G)RP@)V]B:F5C=&ME>7,G+"`G=&5X="<L(&9A;'-E*3L*("`@
M("1F;W)M+3YA9&1(:61D96XH)R<L("=O<FEG:6YA;%]S;W5R8V4G+"`G=&5X
M="<L(&9A;'-E*3L*("`@("1F;W)M+3YA9&1(:61D96XH)R<L("=A8W1I;VY)
M1"<L("=T97AT)RP@9F%L<V4I.PH@("`@:68@*"1S;W5R8V4@+B`G.B<@+B`D
M:V5Y(#T]("1O8FIE8W1K97ES6S!=*2!["B`@("`@("`@+RH@1FER<W0@8V]N
M=&%C="`J+PH@("`@("`@("1F;W)M+3YS971"=71T;VYS*%\H(DYE>'0B*2P@
M7R@B56YD;R!#:&%N9V5S(BDI.PH@("`@?2!E;'-E:68@*"1S;W5R8V4@+B`G
M.B<@+B`D:V5Y(#T]("1O8FIE8W1K97ES6V-O=6YT*"1O8FIE8W1K97ES*2`M
M(#%=*2!["B`@("`@("`@+RH@3&%S="!C;VYT86-T("HO"B`@("`@("`@)&9O
M<FTM/G-E=$)U='1O;G,H7R@B4')E=FEO=7,B*2P@7R@B56YD;R!#:&%N9V5S
M(BDI.PH@("`@?2!E;'-E('L*("`@("`@("`O*B!);F)E='=E96X@*B\*("`@
M("`@("`D9F]R;2T^<V5T0G5T=&]N<RA?*")0<F5V:6]U<R(I+"!?*")5;F1O
M($-H86YG97,B*2D["B`@("`@("`@)&9O<FTM/F%P<&5N9$)U='1O;G,H7R@B
M3F5X="(I*3L*("`@('T*("`@("1F;W)M+3YA<'!E;F1"=71T;VYS*%\H(D9I
M;FES:"(I*3L*?2!E;'-E('L*("`@("1F;W)M+3YS971"=71T;VYS*%\H(E-A
M=F4B*2P@7R@B56YD;R!#:&%N9V5S(BDI.PI]"B1F;W)M+3YA9&1(:61D96XH
M)R<L("=U<FPG+"`G=&5X="<L(&9A;'-E*3L*)&9O<FTM/F%D9$AI9&1E;B@G
M)RP@)W-O=7)C92<L("=T97AT)RP@=')U92D["B1F;W)M+3YA9&1(:61D96XH
M)R<L("=K97DG+"`G=&5X="<L(&9A;'-E*3L*"B1R96YD97)E<BT^<V5T3V)J
M96-T*"1O8FIE8W0I.PHD=FEE=R`]("9N97<@5'5R8F%?3V)J96-T5FEE=R@D
M;V)J96-T*3L*)'9I97<M/G-E='5P1F]R;2@D9F]R;2D["@II9B`H)&-O;F9;
M)V1O8W5M96YT<R==6R=T>7!E)UT@(3T@)VYO;F4G*2!["B`@("!I9B`H571I
M;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD@/3T@)V1E;&5T95]V9G,G*2![
M"B`@("`@("`@)&9I;&4@/2!5=&EL.CIG971&;W)M1&%T82@G9FEL92<I.PH@
M("`@("`@("1R97-U;'0@/2`D;V)J96-T+3YD96QE=&5&:6QE*"1F:6QE*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!F:6QE(%PB)7-<(B!H87,@
M<W5C8V5S<V9U;&QY(&)E96X@9&5L971E9"XB*2P@)&9I;&4I+"`G:&]R9&4N
M<W5C8V5S<R<I.PH@("`@("`@('T*("`@('T*"B`@("`D9FEL97,@/2`D;V)J
M96-T+3YL:7-T1FEL97,H*3L*("`@(&EF("AI<U]A*"1F:6QE<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&9I;&5S
M+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92!["B`@("`@("`@)'8@/2`D
M9F]R;2T^861D5F%R:6%B;&4H7R@B1FEL97,B*2P@)U]?=F9S)RP@)VAT;6PG
M+"!F86QS92D["B`@("`@("`@)'8M/F1I<V%B;&4H*3L*("`@("`@("`D=F%R
M<RT^<V5T*"=?7W9F<R<L(&EM<&QO9&4H)SQB<B`O/B<L(&%R<F%Y7VUA<"AA
M<G)A>2@D;V)J96-T+"`G=F9S161I=%5R;"<I+"`D9FEL97,I*2D["B`@("!]
M"B`@("`D9F]R;2T^861D5F%R:6%B;&4H7R@B061D(&9I;&4B*2P@)W9F<R<L
M("=F:6QE)RP@9F%L<V4I.PI]"@II9B`H)&9O<FTM/G9A;&ED871E*"1V87)S
M*2D@>PH@("`@+RH@1F]R;2!V86QI9"P@<V%V92!D871A+B`J+PH@("`@)&9O
M<FTM/F=E=$EN9F\H)'9A<G,L("1I;F9O*3L*"B`@("`O*B!5<&1A=&4@0V]N
M=&%C="X@*B\*("`@(&9O<F5A8V@@*"1I;F9O6R=O8FIE8W0G72!A<R`D:6YF
M;U]K97D@/3X@)&EN9F]?=F%L*2!["B`@("`@("`@:68@*"1I;F9O7VME>2`A
M/2`G7U]K97DG*2!["B`@("`@("`@("`@("1O8FIE8W0M/G-E=%9A;'5E*"1I
M;F9O7VME>2P@)&EN9F]?=F%L*3L*("`@("`@("!]"B`@("!]"B`@("`D<W5C
M8V5S<R`]("1O8FIE8W0M/G-T;W)E*"D["B`@("`D:V5Y(#T@)&]B:F5C="T^
M9V5T5F%L=64H)U]?:V5Y)RD["B`@("!I9B`H(6ES7V$H)'-U8V-E<W,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("!I9B`H)&-O;F9;)V1O8W5M96YT<R==
M6R=T>7!E)UT@(3T@)VYO;F4G("8F(&ES<V5T*"1I;F9O6R=V9G,G72DI('L*
M("`@("`@("`@("`@)'-U8V-E<W,@/2`D;V)J96-T+3YA9&1&:6QE*"1I;F9O
M6R=V9G,G72D["B`@("`@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*'-P<FEN=&8H7R@B16YT<GD@9F]R("5S('5P9&%T960L(&)U="!S879I
M;F<@=&AE('5P;&]A9&5D(&9I;&4@9F%I;&5D.B`E<R(I+"`D;V)J96-T+3YG
M971686QU92@G;F%M92<I+"`D<W5C8V5S<RT^9V5T365S<V%G92@I*2P@)VAO
M<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")%;G1R>2!F
M;W(@)7,@=7!D871E9"XB*2P@)&]B:F5C="T^9V5T5F%L=64H)VYA;64G*2DL
M("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B16YT<GD@9F]R("5S('5P9&%T960N(BDL("1O8FIE8W0M/F=E=%9A;'5E
M*"=N86UE)RDI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@('T*("`@("`@
M("`D9F]R;2T^<V5T5&ET;&4H<W!R:6YT9BA?*")%9&ET(&5N=')Y(&9O<B`E
M<R(I+"`D;V)J96-T+3YG971686QU92@G;F%M92<I*2D["B`@("`@("`@)&5D
M:71D;VYE(#T@=')U93L*("`@('T@96QS92!["B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)&ME>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AI<R!E;G1R>3H@)7,B*2P@
M)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@
M?0I](&5L<V4@>PH@("`@)&]B:F5C=%]V86QU97,@/2`D=F%R<RT^9V5T*"=O
M8FIE8W0G*3L*("`@(&9O<F5A8V@@*"1O8FIE8W0M/F%T=')I8G5T97,@87,@
M)&EN9F]?:V5Y(#T^("1I;F9O7W9A;"D@>PH@("`@("`@(&EF("@A:7-S970H
M)&]B:F5C=%]V86QU97-;)&EN9F]?:V5Y72DI('L*("`@("`@("`@("`@)&]B
M:F5C=%]V86QU97-;)&EN9F]?:V5Y72`]("1I;F9O7W9A;#L*("`@("`@("!]
M"B`@("!]"B`@("`D=F%R<RT^<V5T*"=O8FIE8W0G+"`D;V)J96-T7W9A;'5E
M<RD["B`@("`D=F%R<RT^<V5T*"=U<FPG+"`D=7)L*3L*("`@("1V87)S+3YS
M970H)W-O=7)C92<L("1S;W5R8V4I.PH@("`@)'9A<G,M/G-E="@G:V5Y)RP@
M)&ME>2D["B`@("!I9B`H)&=R;W5P961I="D@>PH@("`@("`@("1V87)S+3YS
M970H)V]B:F5C=&ME>7,G+"`D;V)J96-T:V5Y<RD["B`@("`@("`@)'9A<G,M
M/G-E="@G86-T:6]N240G+"`G9W)O=7!E9&ET)RD["B`@("!]"GT*"FEF("@D
M9W)O=7!E9&ET("8F("1E9&ET9&]N92D@>PH@("`@)&YE>'1?<&%G92`]($AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G961I="YP:'`G+"!T<G5E*3L*("`@("1N
M97AT7W!A9V4@/2!5=&EL.CIA9&1087)A;65T97(H)&YE>'1?<&%G92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W-O=7)C
M92<@/3X@)'-O=7)C92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V]R:6=I;F%L7W-O=7)C92<@/3X@)&]R:6=I;F%L7W-O
M=7)C92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V]B:F5C=&ME>7,G(#T^("1O8FIE8W1K97ES+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7)L)R`]/B`D=7)L+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G86-T
M:6]N240G(#T^("=G<F]U<&5D:70G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;G5L;"P@9F%L<V4I.PH@("`@)&]B:F5C=&ME>2`]
M(&%R<F%Y7W-E87)C:"@D<V]U<F-E("X@)SHG("X@)&ME>2P@)&]B:F5C=&ME
M>7,I.PH@("`@:68@*"1V87)S+3YG970H)W-U8FUI=&)U='1O;B<I(#T](%\H
M(D9I;FES:"(I*2!["B`@("`@("`@)&YE>'1?<&%G92`]($AO<F1E.CIU<FPH
M)V)R;W=S92YP:'`G+"!T<G5E*3L*("`@("`@("!I9B`H)&]R:6=I;F%L7W-O
M=7)C92`]/2`G*BIS96%R8V@G*2!["B`@("`@("`@("`@("1N97AT7W!A9V4@
M/2!5=&EL.CIA9&1087)A;65T97(H)&YE>'1?<&%G92P@)VME>2<L("1O<FEG
M:6YA;%]S;W5R8V4L(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;F5X=%]P86=E(#T@571I;#HZ861D4&%R86UE=&5R*"1N97AT7W!A
M9V4L("=S;W5R8V4G+"`D;W)I9VEN86Q?<V]U<F-E+"!F86QS92D["B`@("`@
M("`@?0H@("`@?2!E;'-E:68@*"1V87)S+3YG970H)W-U8FUI=&)U='1O;B<I
M(#T](%\H(E!R979I;W5S(BD@)B8@)'-O=7)C92`N("<Z)R`N("1K97D@(3T@
M)&]B:F5C=&ME>7-;,%TI('L*("`@("`@("`O*B!0<F5V:6]U<R!C;VYT86-T
M("HO"B`@("`@("`@)&9O<FTM/G-E=$)U='1O;G,H7R@B56YD;R!#:&%N9V5S
M(BDI.PH@("`@("`@(&QI<W0H+"`D<')E=FEO=7-?:V5Y*2`](&5X<&QO9&4H
M)SHG+"`D;V)J96-T:V5Y<ULD;V)J96-T:V5Y("T@,5TI.PH@("`@("`@("1N
M97AT7W!A9V4@/2!5=&EL.CIA9&1087)A;65T97(H)&YE>'1?<&%G92P@)VME
M>2<L("1P<F5V:6]U<U]K97DL(&9A;'-E*3L*("`@("`@("!I9B`H)&9O<FTM
M/F=E=$]P96Y396-T:6]N*"DI('L*("`@("`@("`@("`@)&YE>'1?<&%G92`]
M(%5T:6PZ.F%D9%!A<F%M971E<B@D;F5X=%]P86=E+"`G7U]F;W)M3W!E;E-E
M8W1I;VXG+"`D9F]R;2T^9V5T3W!E;E-E8W1I;VXH*2P@9F%L<V4I.PH@("`@
M("`@('T*("`@('T@96QS96EF("@D=F%R<RT^9V5T*"=S=6)M:71B=71T;VXG
M*2`]/2!?*").97AT(BD@)B8*("`@("`@("`@("`@("`D<V]U<F-E("X@)SHG
M("X@)&ME>2`A/2`D;V)J96-T:V5Y<UMC;W5N="@D;V)J96-T:V5Y<RD@+2`Q
M72D@>PH@("`@("`@("\J($YE>'0@8V]N=&%C="`J+PH@("`@("`@(&QI<W0H
M+"`D;F5X=%]K97DI(#T@97AP;&]D92@G.B<L("1O8FIE8W1K97ES6R1O8FIE
M8W1K97D@*R`Q72D["B`@("`@("`@)&YE>'1?<&%G92`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D;F5X=%]P86=E+"`G:V5Y)RP@)&YE>'1?:V5Y+"!F86QS92D[
M"B`@("`@("`@:68@*"1F;W)M+3YG971/<&5N4V5C=&EO;B@I*2!["B`@("`@
M("`@("`@("1N97AT7W!A9V4@/2!5=&EL.CIA9&1087)A;65T97(H)&YE>'1?
M<&%G92P@)U]?9F]R;4]P96Y396-T:6]N)RP@)&9O<FTM/F=E=$]P96Y396-T
M:6]N*"DL(&9A;'-E*3L*("`@("`@("!]"B`@("!]"B`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)&YE>'1?<&%G92D["B`@("!E>&ET.PI]"@II9B`H)&5D
M:71D;VYE*2!["B`@("!I9B`H96UP='DH)&EN9F];)W5R;"==*2D@>PH@("`@
M("`@("1U<FD@/2!5=&EL.CIA9&1087)A;65T97(H)V1I<W!L87DN<&AP)RP@
M87)R87DH)W-O=7)C92<@/3X@)&EN9F];)W-O=7)C92==+"`G:V5Y)R`]/B`D
M:V5Y*2D["B`@("`@("`@)'5R:2`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D
M=7)I+"!T<G5E*3L*("`@('T@96QS92!["B`@("`@("`@)'5R:2`]("1I;F9O
M6R=U<FPG73L*("`@('T*"B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R
M:2D["B`@("!E>&ET.PI]"@II9B`H)&=R;W5P961I="D@>PH@("`@+RH@4F5A
M9"!T:&4@8V]L=6UN<R!T;R!D:7-P;&%Y(&9R;VT@=&AE('!R969E<F5N8V5S
M+B`J+PH@("`@)'-O=7)C97,@/2!4=7)B83HZ9V5T0V]L=6UN<R@I.PH@("`@
M)&-O;'5M;G,@/2!I<W-E="@D<V]U<F-E<ULD<V]U<F-E72D@/R`D<V]U<F-E
M<ULD<V]U<F-E72`Z(&%R<F%Y*"D["B`@("`D<F5S=6QT<R`]("9N97<@5'5R
M8F%?3&ES="@D;V)J96-T:V5Y<RD["B`@("`D;&ES=%9I97<@/2`F;F5W(%1U
M<F)A7TQI<W16:65W*"1R97-U;'1S+"!A<G)A>2@G1W)O=7`G(#T^('1R=64I
M*3L*?0H*<F5Q=6ER92!455)"05]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*<F5Q=6ER92!455)"05]414U03$%415,@+B`G+VUE;G4N:6YC
M)SL*)&9O<FTM/G)E;F1E<D%C=&EV92@D<F5N9&5R97(L("1V87)S+"`G961I
M="YP:'`G+"`G<&]S="<I.PH*:68@*&ES<V5T*"1L:7-T5FEE=RD@)B8@:7-?
M;V)J96-T*"1L:7-T5FEE=RDI('L*("`@(&5C:&\@)SQB<B`O/B<["B`@("`D
M;&ES=%9I97<M/F1I<W!L87E086=E*"D["GT*"G)E<75I<F4@)')E9VES=')Y
M+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R
M+FEN8R<["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T=7)B82]D
M:7-P;&%Y+G!H<```````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$P-#<R`#$P-#$W,S8R-S4V`#`Q-S<R,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!T=7)B82]D:7-P;&%Y+G!H<"QV(#$N-C0N,BXX(#(P,#8O,#,O,#,@
M,C,Z,#`Z,S`@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P
M-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H05-,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O
M87-L+G!H<"X*("HO"@I`9&5F:6YE*"=455)"05]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*<F5Q=6ER95]O;F-E(%154D)!7T)!4T4@+B`G+VQI8B]296YD
M97)E<BYP:'`G.PIR97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+T]B
M:F5C=%9I97<N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<["@HD<F5N9&5R
M97(@/2`F;F5W(%1U<F)A7U)E;F1E<F5R*"D["B1V87)S(#T@)E9A<FEA8FQE
M<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PH*)'-O=7)C92`]("1V87)S+3YG
M970H)W-O=7)C92<I.PII9B`H(6ES<V5T*"1'3$]"04Q36R=C9F=3;W5R8V5S
M)UU;)'-O=7)C95TI*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E1H
M92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N(BDI.PH@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@D<')E9G,M/F=E=%9A;'5E*"=I;FET:6%L7W!A9V4G*2P@=')U92DI.PH@
M("`@97AI=#L*?0H*)&1R:79E<B`]("94=7)B85]$<FEV97(Z.G-I;F=L971O
M;B@D<V]U<F-E*3L*"B\J($=E="!T:&4@9F]R;2!O8FIE8W0N("HO"B1F;W)M
M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G)RP@)'9A<G,I.PHD9F]R;2T^
M861D2&ED9&5N*"<G+"`G=7)L)RP@)W1E>'0G+"!F86QS92D["B1F;W)M+3YA
M9&1(:61D96XH)R<L("=S;W5R8V4G+"`G=&5X="<L('1R=64I.PHD9F]R;2T^
M861D2&ED9&5N*"<G+"`G:V5Y)RP@)W1E>'0G+"!F86QS92D["@HO*B!3970@
M=&AE(&-O;G1A8W0@9G)O;2!T:&4@:V5Y(')E<75E<W1E9"X@*B\*)&]B:F5C
M="`](&YU;&P["B1U:60@/2`D=F%R<RT^9V5T*"=U:60G*3L*:68@*"%E;7!T
M>2@D=6ED*2D@>PH@("`@)'-E87)C:"`]("1D<FEV97(M/G-E87)C:"AA<G)A
M>2@G7U]U:60G(#T^("1U:60I*3L*("`@(&EF("@A:7-?82@D<V5A<F-H+"`G
M4$5!4E]%<G)O<B<I("8F("1S96%R8V@M/F-O=6YT*"DI('L*("`@("`@("`D
M;V)J96-T(#T@)'-E87)C:"T^;F5X="@I.PH@("`@("`@("1K97D@/2`D;V)J
M96-T+3YG971686QU92@G7U]K97DG*3L*("`@('T*?0II9B`H(21O8FIE8W0@
M?'P@:7-?82@D;V)J96-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D:V5Y(#T@
M)'9A<G,M/F=E="@G:V5Y)RD["B`@("`D;V)J96-T(#T@)&1R:79E<BT^9V5T
M3V)J96-T*"1K97DI.PH@("`@:68@*&ES7V$H)&]B:F5C="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&]B:F5C="T^
M9V5T365S<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!H96%D97(H
M)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1P<F5F<RT^
M9V5T5F%L=64H)VEN:71I86Q?<&%G92<I+"!T<G5E*2D["B`@("`@("`@97AI
M=#L*("`@('T*?0H*+RH@0VAE8VL@<&5R;6ES<VEO;G,@;VX@=&AI<R!C;VYT
M86-T+B`J+PII9B`H(21O8FIE8W0M/FAA<U!E<FUI<W-I;VXH4$5235-?4D5!
M1"DI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@D<')E9G,M/F=E=%9A;'5E*"=I;FET:6%L7W!A9V4G
M*2P@=')U92DI.PH@("`@97AI=#L*?0H*)')E;F1E<F5R+3YS971/8FIE8W0H
M)&]B:F5C="D["B1V:65W(#T@)FYE=R!4=7)B85]/8FIE8W16:65W*"1O8FIE
M8W0I.PH*)'9A;'5E<R`](&%R<F%Y*"D["B\J($=E="!T:&4@=F%L=65S('1H
M<F]U9V@@=&AE(%1U<F)A7T]B:F5C="!C;&%S<RX@*B\*9F]R96%C:"`H)&]B
M:F5C="T^9')I=F5R+3YG971#<FET97)I82@I(&%S("1I;F9O7VME>2`]/B`D
M:6YF;U]V86PI('L*("`@("1V86QU97-;)&EN9F]?:V5Y72`]("1O8FIE8W0M
M/F=E=%9A;'5E*"1I;F9O7VME>2D["GT*"B\J($=E="!T:&4@8V]N=&%C="=S
M(&AI<W1O<GDN("HO"FEF("@D;V)J96-T+3YG971686QU92@G7U]U:60G*2D@
M>PH@("`@)&AI<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D[
M"B`@("`D;&]G(#T@)&AI<W1O<GDM/F=E=$AI<W1O<GDH)W1U<F)A.B<@+B`H
M)&]B:F5C="T^9V5T5F%L=64H)U]?;W=N97(G*2`_("1O8FIE8W0M/F=E=%9A
M;'5E*"=?7V]W;F5R)RD@.B!!=71H.CIG971!=71H*"DI("X@)SHG("X@)&]B
M:F5C="T^9V5T5F%L=64H)U]?=6ED)RDI.PH@("`@:68@*"1L;V<@)B8@(6ES
M7V$H)&QO9RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(&9O<F5A8V@@*"1L
M;V<M/F=E=$1A=&$H*2!A<R`D96YT<GDI('L*("`@("`@("`@("`@<W=I=&-H
M("@D96YT<GE;)V%C=&EO;B==*2!["B`@("`@("`@("`@(&-A<V4@)V%D9"<Z
M"B`@("`@("`@("`@("`@("`D=FEE=RT^<V5T*"=C<F5A=&5D)RP@=')U92D[
M"B`@("`@("`@("`@("`@("`D=F%L=65S6R=?7V-R96%T960G72`]('-T<F9T
M:6UE*"1P<F5F<RT^9V5T5F%L=64H)V1A=&5?9F]R;6%T)RDL("1E;G1R>5LG
M=',G72D@+B`G("<@+B!D871E*"1P<F5F<RT^9V5T5F%L=64H)W1W96YT>49O
M=7(G*2`_("='.FDG(#H@)V<Z:2!A)RP@)&5N=')Y6R=T<R==*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;6]D:69Y)SH*
M("`@("`@("`@("`@("`@("1V:65W+3YS970H)VUO9&EF:65D)RP@=')U92D[
M"B`@("`@("`@("`@("`@("`D=F%L=65S6R=?7VUO9&EF:65D)UT@/2!S=')F
M=&EM92@D<')E9G,M/F=E=%9A;'5E*"=D871E7V9O<FUA="<I+"`D96YT<GE;
M)W1S)UTI("X@)R`G("X@9&%T92@D<')E9G,M/F=E=%9A;'5E*"=T=V5N='E&
M;W5R)RD@/R`G1SII)R`Z("=G.FD@82<L("1E;G1R>5LG=',G72D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*?0H*)'9I97<M/G-E='5P1F]R;2@D9F]R;2D["@HD=F%R<R`](&YE=R!6
M87)I86)L97,H87)R87DH)V]B:F5C="<@/3X@)'9A;'5E<RDI.PH*:68@*"1C
M;VYF6R=D;V-U;65N=',G75LG='EP92==("$]("=N;VYE)RD@>PH@("`@)&9I
M;&5S(#T@)&]B:F5C="T^;&ES=$9I;&5S*"D["B`@("!I9B`H:7-?82@D9FEL
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*"1F:6QE<RP@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@
M("`@("1F;W)M+3YA9&1687)I86)L92A?*")&:6QE<R(I+"`G7U]V9G,G+"`G
M:'1M;"<L(&9A;'-E*3L*("`@("`@("`D=F%R<RT^<V5T*"=?7W9F<R<L(&EM
M<&QO9&4H)SQB<B`O/B<L(&%R<F%Y7VUA<"AA<G)A>2@D;V)J96-T+"`G=F9S
M1&ES<&QA>55R;"<I+"`D9FEL97,I*2D["B`@("!]"GT*"B1T:71L92`]("1V
M87)S+3YG970H)V]B:F5C=%MN86UE72<I.PII9B`H(65M<'1Y*"1T:71L92D@
M?'P@)'1I=&QE(#T]("<P)RD@>PH@("`@)&9O<FTM/G-E=%1I=&QE*"1T:71L
M92D["GT*"FEF("@A96UP='DH)&-O;F9;)V-O;6UE;G1S)UU;)V%L;&]W)UTI
M("8F("1R96=I<W1R>2T^:&%S365T:&]D*"=F;W)U;7,O9&]#;VUM96YT<R<I
M*2!["B`@("`D8V]M;65N=',@/2`D<F5G:7-T<GDM/F-A;&PH)V9O<G5M<R]D
M;T-O;6UE;G1S)RP@87)R87DH)W1U<F)A)RP@)'-O=7)C92`N("<N)R`N("1K
M97DL("=C;VUM96YT0V%L;&)A8VLG*2D["GT*"G)E<75I<F4@5%520D%?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@5%520D%?
M5$5-4$Q!5$53("X@)R]M96YU+FEN8R<["B1F;W)M+3YR96YD97));F%C=&EV
M92@D<F5N9&5R97(L("1V87)S*3L*"FEF("@A96UP='DH)&-O;6UE;G1S6R=T
M:')E861S)UTI*2!["B`@("!E8VAO("<\8G(@+SXG("X@)&-O;6UE;G1S6R=T
M:')E861S)UT["GT*:68@*"%E;7!T>2@D8V]M;65N='-;)V-O;6UE;G1S)UTI
M*2!["B`@("!E8VAO("<\8G(@+SXG("X@)&-O;6UE;G1S6R=C;VUM96YT<R==
M.PI]"@IR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R
M9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+V1E;&5T92YP:'``
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W
M-C4`,3`T,3<S-C(W-38`,#$W-3(V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z('1U<F)A
M+V1E;&5T92YP:'`L=B`Q+C(Y+C0N-"`R,#`V+S`Q+S`Q(#(Q.C(Y.C$U(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($-H87)L97,@2BX@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!
M4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*B\*
M"D!D969I;F4H)U154D)!7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E
M<75I<F5?;VYC92!455)"05]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*)'-O
M=7)C92`](%5T:6PZ.F=E=$9O<FU$871A*"=S;W5R8V4G*3L*)&ME>2`](%5T
M:6PZ.F=E=$9O<FU$871A*"=K97DG*3L*)&1R:79E<B`]("94=7)B85]$<FEV
M97(Z.G-I;F=L971O;B@D<V]U<F-E*3L*"FEF("@D8V]N9ELG9&]C=6UE;G1S
M)UU;)W1Y<&4G72`A/2`G;F]N92<I('L*("`@("1O8FIE8W0@/2`D9')I=F5R
M+3YG971/8FIE8W0H)&ME>2D["B`@("!I9B`H:7-?82@D;V)J96-T+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D;V)J
M96-T+3YG971-97-S86=E*"DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@(&AE
M861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)'!R
M969S+3YG971686QU92@G:6YI=&EA;%]P86=E)RDL('1R=64I*3L*("`@("`@
M("!E>&ET.PH@("`@?0H@("`@:68@*&ES7V$H)&1E;&5T960@/2`D;V)J96-T
M+3YD96QE=&5&:6QE<R@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"@D9&5L971E9"P@)VAO<F1E+F5R<F]R)RD["B`@
M("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@D<')E9G,M/F=E=%9A;'5E*"=I;FET:6%L7W!A9V4G*2P@=')U92DI
M.PH@("`@("`@(&5X:70["B`@("!]"GT*"FEF("@A:7-?82@D<F5S=6QT(#T@
M)&1R:79E<BT^9&5L971E*"1K97DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("!H
M96%D97(H)TQO8V%T:6]N.B`G("X@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<L
M($AO<F1E.CIU<FPH)'!R969S+3YG971686QU92@G:6YI=&EA;%]P86=E)RDL
M('1R=64I*2D["B`@("!E>&ET.PI]"@HD;F]T:69I8V%T:6]N+3YP=7-H*'-P
M<FEN=&8H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H:7,@8V]N
M=&%C=#H@)7,B*2P@)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R
M<F]R)RD["B1T:71L92`](%\H(D1E;&5T:6]N(&9A:6QE9"(I.PIR97%U:7)E
M(%154D)!7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U
M:7)E(%154D)!7U1%35!,051%4R`N("<O;65N=2YI;F,G.PIR97%U:7)E("1R
M96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N
M+69O;W1E<BYI;F,G.PH``````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O='5R8F$O9&%T82YP:'``````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#`U-P`Q,#0Q-S,V,C<U-@`P,3<Q-S0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@='5R8F$O9&%T82YP:'`L=B`Q+C<P+C0N-2`R
M,#`V+S`Q+S`Q(#(Q.C(Y.C$U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A
M<VPN<&AP+@H@*B\*"F9U;F-T:6]N(%]C;&5A;G5P*"D*>PH@("`@9VQO8F%L
M("1I;7!O<G1?<W1E<#L*("`@("1I;7!O<G1?<W1E<"`](#$["B`@("!R971U
M<FX@24U03U)47T9)3$4["GT*"B\J*@H@*B!296UO=F4@96UP='D@871T<FEB
M=71E<R!F<F]M(&%T=')I8G5T97,@87)R87DN"B`J"B`J($!P87)A;2!M:7AE
M9"`D=F%L("`@(%9A;'5E(&9R;VT@871T<FEB=71E<R!A<G)A>2X*("H*("H@
M0')E='5R;B!B;V]L96%N("`@("`@("`@0F]O;&5A;B!U<V5D(&)Y(&%R<F%Y
M7V9I;'1E<BX*("HO"F9U;F-T:6]N(%]E;7!T>4%T=')I8G5T949I;'1E<B@D
M=F%R*0I["B`@("!I9B`H(6ES7V%R<F%Y*"1V87(I*2!["B`@("`@("`@<F5T
M=7)N("@D=F%R("$]("<G*3L*("`@('T@96QS92!["B`@("`@("`@9F]R96%C
M:"`H)'9A<B!A<R`D=BD@>PH@("`@("`@("`@("!I9B`H)'8@/3T@)R<I('L*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*?0H*0&1E9FEN
M92@G5%520D%?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O
M;F-E(%154D)!7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O1&%T82YP:'`G.PH*:68@*"$D8V]N9ELG;65N=2==6R=I;7!O
M<G1?97AP;W)T)UTI('L*("`@(')E<75I<F4@5%520D%?0D%312`N("<O:6YD
M97@N<&AP)SL*("`@(&5X:70["GT*"B\J($EM<&]R=&%B;&4@9FEL92!T>7!E
M<RX@*B\*)&9I;&5?='EP97,@/2!A<G)A>2@G8W-V)R`@("`@(#T^(%\H(D-3
M5B(I+`H@("`@("`@("`@("`@("`@("`@("=T<W8G("`@("`@/3X@7R@B5%-6
M(BDL"B`@("`@("`@("`@("`@("`@("`@)W9C87)D)R`@("`]/B!?*")V0V%R
M9"(I+`H@("`@("`@("`@("`@("`@("`@("=M=6QB97)R>2<@/3X@7R@B375L
M8F5R<GD@061D<F5S<R!";V]K(BDL"B`@("`@("`@("`@("`@("`@("`@)W!I
M;F4G("`@("`]/B!?*")0:6YE($%D9')E<W,@0F]O:R(I*3L*"B\J(%1E;7!L
M871E<R!F;W(@=&AE(&1I9F9E<F5N="!I;7!O<G0@<W1E<',N("HO"B1T96UP
M;&%T97,@/2!A<G)A>2@*("`@($E-4$]25%]&24Q%(#T^(&%R<F%Y*%154D)!
M7U1%35!,051%4R`N("<O9&%T82]E>'!O<G0N:6YC)RDL"B`@("!)35!/4E1?
M0U-6(#T^(&%R<F%Y*"1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R
M9&4G*2`N("<O9&%T82]C<W9I;F9O+FEN8R<I+`H@("`@24U03U)47U135B`]
M/B!A<G)A>2@D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@
M+B`G+V1A=&$O='-V:6YF;RYI;F,G*2P*("`@($E-4$]25%]-05!0140@/3X@
M87)R87DH)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@
M)R]D871A+V-S=FUA<"YI;F,G*2P*("`@($E-4$]25%]$051%5$E-12`]/B!A
M<G)A>2@D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G
M+V1A=&$O9&%T96UA<"YI;F,G*0HI.PH*+RH@26YI=&EA;"!V86QU97,N("HO
M"B1I;7!O<G1?<W1E<"`](%5T:6PZ.F=E=$9O<FU$871A*"=I;7!O<G1?<W1E
M<"<L(#`I("L@,3L*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C
M=&EO;DE$)RD["B1N97AT7W-T97`@/2!)35!/4E1?1DE,13L*)&%P<%]F:65L
M9',@/2!A<G)A>2@I.PHD=&EM95]F:65L9',@/2!A<G)A>2@I.PHD97)R;W(@
M/2!F86QS93L*)&]U=&QO;VM?;6%P<&EN9R`](&%R<F%Y*`H@("`@)V9I<G-T
M;F%M92<@/3X@)V9I<G-T7VYA;64G+`H@("`@)VUI9&1L96YA;64G(#T^("=M
M:61D;&5?;F%M92<L"B`@("`G;&%S=&YA;64G(#T^("=L87-T7VYA;64G+`H@
M("`@)V4M;6%I;"<@/3X@)V5M86EL)RP*("`@("=H;VUE861D<F5S<R<@/3X@
M)VAO;65!9&1R97-S)RP*("`@("=B=7-I;F5S<V%D9')E<W,G(#T^("=W;W)K
M061D<F5S<R<L"B`@("`G:&]M97!H;VYE)R`]/B`G:&]M95!H;VYE)RP*("`@
M("=B=7-I;F5S<W!H;VYE)R`]/B`G=V]R:U!H;VYE)RP*("`@("=M;V)I;&5P
M:&]N92<@/3X@)V-E;&Q0:&]N92<L"B`@("`G8G5S:6YE<W-F87@G(#T^("=F
M87@G+`H@("`@)VIO8G1I=&QE)R`]/B`G=&ET;&4G+`H@("`@)V-O;7!A;GDG
M(#T^("=C;VUP86YY)RP*("`@("=N;W1E<R<@/3X@)VYO=&5S)RP*("`@("=N
M86UE)R`]/B`G;F%M92<L"B`@("`G:6YT97)N971F<F5E8G5S>2<@/3X@)V9R
M965B=7-Y57)L)RP*("`@("=N:6-K;F%M92<@/3X@)V%L:6%S)RP*("`@("=P
M9W!0=6)L:6-+97DG(#T^("=P9W!0=6)L:6-+97DG+`H@("`@)W-M:6UE4'5B
M;&EC2V5Y)R`]/B`G<VUI;650=6)L:6-+97DG+`H@("`@*3L*)'!A<F%M(#T@
M87)R87DH)W1I;65?9FEE;&1S)R`]/B`D=&EM95]F:65L9',L"B`@("`@("`@
M("`@("`@("=F:6QE7W1Y<&5S)R`@/3X@)&9I;&5?='EP97,L"B`@("`@("`@
M("`@("`@("=I;7!O<G1?;6%P<&EN9R<@/3X@)&]U=&QO;VM?;6%P<&EN9RD[
M"B1I;7!O<G1?9F]R;6%T(#T@571I;#HZ9V5T1F]R;41A=&$H)VEM<&]R=%]F
M;W)M870G+"`G)RD["B1D<FEV97(@/2`D:6UP;W)T7V9O<FUA=#L*:68@*"1D
M<FEV97(@/3T@)VUU;&)E<G)Y)R!\?"`D9')I=F5R(#T]("=P:6YE)RD@>PH@
M("`@)&1R:79E<B`]("=T<W8G.PI]"FEF("@D86-T:6]N240@(3T@)W-E;&5C
M="<I('L*("`@(&%R<F%Y7W5N<VAI9G0H)'1E;7!L871E<UM)35!/4E1?1DE,
M15TL(%154D)!7U1%35!,051%4R`N("<O9&%T82]I;7!O<G0N:6YC)RD["GT*
M"B\J($QO;W`@=&AR;W5G:"!T:&4@86-T:6]N(&AA;F1L97)S+B`J+PIS=VET
M8V@@*"1A8W1I;VY)1"D@>PIC87-E("=E>'!O<G0G.@H@("`@)'-O=7)C97,@
M/2!A<G)A>2@I.PH@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=S96QE8W1E
M9"<I*2!["B`@("`@("`@9F]R96%C:"`H571I;#HZ9V5T1F]R;41A=&$H)V]B
M:F5C=&ME>7,G*2!A<R`D;V)J96-T:V5Y*2!["B`@("`@("`@("`@(&QI<W0H
M)'-O=7)C92P@)&ME>2D@/2!E>'!L;V1E*"<Z)RP@)&]B:F5C=&ME>2P@,BD[
M"B`@("`@("`@("`@(&EF("AS=')P;W,H)&ME>2P@)SHG*2D@>PH@("`@("`@
M("`@("`@("`@;&ES="@D;W=N97(L("1K97DI(#T@97AP;&]D92@G.B<L("1K
M97DL(#(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H
M)'-O=7)C97-;)'-O=7)C95TI*2!["B`@("`@("`@("`@("`@("`D<V]U<F-E
M<ULD<V]U<F-E72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'-O=7)C97-;)'-O=7)C95U;72`]("1K97D["B`@("`@("`@?0H@("`@
M?2!E;'-E('L*("`@("`@("`D<V]U<F-E(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W-O=7)C92<I.PH@("`@("`@(&EF("@A:7-S970H)'-O=7)C92D@)B8@(65M
M<'1Y*"1C9F=3;W5R8V5S*2D@>PH@("`@("`@("`@("!R97-E="@D8V9G4V]U
M<F-E<RD["B`@("`@("`@("`@("1S;W5R8V4@/2!K97DH)&-F9U-O=7)C97,I
M.PH@("`@("`@('T*("`@("`@("`D<V]U<F-E<ULD<V]U<F-E72`](&%R<F%Y
M*"D["B`@("!]"@H@("`@)&1A=&$@/2!A<G)A>2@I.PH@("`@)&-O;G1A8W1S
M(#T@87)R87DH*3L*("`@("1A;&Q?9FEE;&1S(#T@87)R87DH*3L*("`@(&9O
M<F5A8V@@*"1S;W5R8V5S(&%S("1S;W5R8V4@/3X@)&]B:F5C=&ME>7,I('L*
M("`@("`@("`O*B!#<F5A=&4@82!4=7)B82!S=&]R86=E(&EN<W1A;F-E+B`J
M+PH@("`@("`@("1S=&]R86=E(#T@)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N
M*"1S;W5R8V4I.PH@("`@("`@(&EF("AI<U]A*"1S=&]R86=E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")&86EL960@=&\@86-C97-S('1H92!A9&1R97-S(&)O;VLZ("5S
M(BDL("1S=&]R86=E+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("`@("`@)&5R<F]R(#T@=')U93L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(&9U;&PL('-O<G1E9"!C
M;VYT86-T(&QI<W0N("HO"B`@("`@("`@:68@*&-O=6YT*"1O8FIE8W1K97ES
M*2D@>PH@("`@("`@("`@("`D<F5S=6QT<R`]("8D<W1O<F%G92T^9V5T3V)J
M96-T<R@D;V)J96-T:V5Y<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E<W5L=',@/2`D<W1O<F%G92T^<V5A<F-H*&%R<F%Y*"DI.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT<RP@)U1U<F)A7TQI<W0G*2D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L=',@/2`D<F5S=6QT<RT^;V)J96-T<SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*'-P<FEN=&8H7R@B1F%I;&5D('1O('-E87)C:"!T:&4@9&ER
M96-T;W)Y.B`E<R(I+"`D<F5S=6QT<RT^9V5T365S<V%G92@I*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@("`@("1E<G)O<B`]('1R=64["B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@)&9I96QD<R`]("1S=&]R
M86=E+3YG971&:65L9',H*3L*("`@("`@("`D86QL7V9I96QD<R`](&%R<F%Y
M7VUE<F=E*"1A;&Q?9FEE;&1S+"`D9FEE;&1S*3L*("`@("`@("`D<&%R86US
M(#T@)'-T;W)A9V4M/F=E=%!A<F%M<R@I.PH@("`@("`@(&9O<F5A8V@@*"1R
M97-U;'1S(&%S("1O8BD@>PH@("`@("`@("`@("`D<F]W(#T@87)R87DH*3L*
M("`@("`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A<R`D9FEE;&0I('L*("`@
M("`@("`@("`@("`@(&EF("AS=6)S='(H)&9I96QD+"`P+"`R*2`A/2`G7U\G
M*2!["B`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T92`]("1O8BT^9V5T
M5F%L=64H)&9I96QD*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&%T=')I
M8G5T97-;)&9I96QD75LG='EP92==(#T]("=D871E)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<F]W6R1F:65L9%T@/2!S=')F=&EM92@G)5DM)6TM
M)60G+"`D871T<FEB=71E*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)&%T=')I8G5T97-;)&9I96QD75LG='EP92==(#T]("=T:6UE)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<F]W6R1F:65L9%T@/2!S=')F=&EM
M92@G)5(G+"`D871T<FEB=71E*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)&%T=')I8G5T97-;)&9I96QD75LG='EP92==(#T]("=D871E=&EM
M92<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULD9FEE;&1=(#T@
M<W1R9G1I;64H)R59+25M+25D("52)RP@)&%T=')I8G5T92D["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)')O=ULD9FEE;&1=(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D871T<FEB
M=71E+"!.3%,Z.F=E=$-H87)S970H*2P@)'!A<F%M<ULG8VAA<G-E="==*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&1A=&%;72`]("1R;W<["B`@("`@("`@
M?0H*("`@("`@("`D8V]N=&%C=',@/2!A<G)A>5]M97)G92@D8V]N=&%C=',L
M("1R97-U;'1S*3L*("`@('T*("`@(&EF("@A8V]U;G0H)&1A=&$I*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")4:&5R92!W97)E(&YO(&%D
M9')E<W-E<R!T;R!E>'!O<G0N(BDL("=H;W)D92YM97-S86=E)RD["B`@("`@
M("`@)&5R<F]R(#T@=')U93L*("`@("`@("!B<F5A:SL*("`@('T*"B`@("`O
M*B!-86ME('-U<F4@=&AA="!A;&P@<F]W<R!H879E('1H92!S86UE(&-O;'5M
M;G,@:68@97AP;W)T:6YG(&9R;VT*("`@("`J(&1I9F9E<F5N="!S;W5R8V5S
M+B`J+PH@("`@:68@*&-O=6YT*"1S;W5R8V5S*2`^(#$I('L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&%T82D[("1I*RLI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&%L;%]F:65L9',@87,@)&9I96QD*2!["B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1D871A6R1I75LD9FEE;&1=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1D871A6R1I75LD9FEE;&1=(#T@)R<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@<W=I=&-H("A5=&EL.CIG971&;W)M1&%T82@G97AP;W)T240G*2D@
M>PH@("`@8V%S92!%6%!/4E1?0U-6.@H@("`@("`@("1C<W8@/2`F2&]R9&5?
M1&%T83HZ<VEN9VQE=&]N*"=C<W8G*3L*("`@("`@("`D8W-V+3YE>'!O<G1&
M:6QE*%\H(F-O;G1A8W1S+F-S=B(I+"`D9&%T82P@=')U92D["B`@("`@("`@
M97AI=#L*"B`@("!C87-E($584$]25%]/551,3T]+0U-6.@H@("`@("`@("1C
M<W8@/2`F2&]R9&5?1&%T83HZ<VEN9VQE=&]N*"=O=71L;V]K8W-V)RD["B`@
M("`@("`@)&-S=BT^97AP;W)T1FEL92A?*")C;VYT86-T<RYC<W8B*2P@)&1A
M=&$L('1R=64L(&%R<F%Y7V9L:7`H)&]U=&QO;VM?;6%P<&EN9RDI.PH@("`@
M("`@(&5X:70["@H@("`@8V%S92!%6%!/4E1?5%-6.@H@("`@("`@("1T<W8@
M/2`F2&]R9&5?1&%T83HZ<VEN9VQE=&]N*"=T<W8G*3L*("`@("`@("`D='-V
M+3YE>'!O<G1&:6QE*%\H(F-O;G1A8W1S+G1S=B(I+"`D9&%T82P@=')U92D[
M"B`@("`@("`@97AI=#L*"B`@("!C87-E($584$]25%]60T%21#H*("`@("`@
M("`D8V%R9',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C;VYT86-T
M<R!A<R`D8V]N=&%C="D@>PH@("`@("`@("`@("`D8V%R9'-;72`])B!4=7)B
M85]$<FEV97(Z.G1O=D-A<F0H)&-O;G1A8W0I.PH@("`@("`@('T*"B`@("`@
M("`@)'9C87)D(#T@)DAO<F1E7T1A=&$Z.G-I;F=L971O;B@G=F-A<F0G*3L*
M("`@("`@("`D=F-A<F0M/F5X<&]R=$9I;&4H7R@B8V]N=&%C=',N=F-F(BDL
M("1C87)D<RP@=')U92D["B`@("`@("`@97AI=#L*("`@('T*("`@(&)R96%K
M.PH*8V%S92!)35!/4E1?1DE,13H*("`@("1D97-T(#T@571I;#HZ9V5T1F]R
M;41A=&$H)V1E<W0G*3L*("`@("1S=&]R86=E(#T@)E1U<F)A7T1R:79E<CHZ
M<VEN9VQE=&]N*"1D97-T*3L*("`@(&EF("AI<U]A*"1S=&]R86=E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,B
M*2P@)'-T;W)A9V4M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@("1E<G)O<B`]('1R=64["B`@("`@("`@8G)E86L["B`@("!]"@H@
M("`@+RH@0VAE8VL@<&5R;6ES<VEO;G,N("HO"B`@("`D;6%X7V-O;G1A8W1S
M(#T@5'5R8F$Z.FAA<U!E<FUI<W-I;VXH)&1E<W0@+B`G.FUA>%]C;VYT86-T
M<R<L("=S;W5R8V4G*3L*("`@(&EF("@D;6%X7V-O;G1A8W1S("$]/2!T<G5E
M("8F"B`@("`@("`@)&UA>%]C;VYT86-T<R`\/2`D<W1O<F%G92T^8V]U;G1#
M;VYT86-T<R@I*2!["B`@("`@("`@)&UE<W-A9V4@/2!`:'1M;'-P96-I86QC
M:&%R<RAS<')I;G1F*%\H(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!C;VYT86-T<R!I;B!<(B5S7"(N(BDL("1M87A?8V]N
M=&%C=',L("1S=&]R86=E+3YT:71L92DL($5.5%]#3TU0050L($Y,4SHZ9V5T
M0VAA<G-E="@I*3L*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==
M6R=P97)M<V1E;FEE9"==*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]($AO
M<F1E.CIC86QL2&]O:R@G7W!E<FUS7VAO;VM?9&5N:65D)RP@87)R87DH)W1U
M<F)A.FUA>%]C;VYT86-T<R<I+"`G:&]R9&4G+"`D;65S<V%G92D["B`@("`@
M("`@?0H@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&UE<W-A9V4L("=H
M;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@("`@("`D
M97)R;W(@/2!T<G5E.PH@("`@("`@(&)R96%K.PH@("`@?0H*("`@("1?4T53
M4TE/3ELG:6UP;W)T7V1A=&$G75LG=&%R9V5T)UT@/2`D9&5S=#L*("`@("1?
M4T534TE/3ELG:6UP;W)T7V1A=&$G75LG<'5R9V4G72`](%5T:6PZ.F=E=$9O
M<FU$871A*"=P=7)G92<I.PH@("`@8G)E86L["@IC87-E($E-4$]25%]-05!0
M140Z"F-A<V4@24U03U)47T1!5$5424U%.@H@("`@9F]R96%C:"`H)&-F9U-O
M=7)C97-;)%]315-324].6R=I;7!O<G1?9&%T82==6R=T87)G970G75U;)VUA
M<"==(&%S("1F:65L9"`]/B`D;G5L;"D@>PH@("`@("`@(&EF("AS=6)S='(H
M)&9I96QD+"`P+"`R*2`A/2`G7U\G("8F("%I<U]A<G)A>2@D;G5L;"DI('L*
M("`@("`@("`@("`@:68@*"1A='1R:6)U=&5S6R1F:65L9%U;)W1Y<&4G72`]
M/2`G;6]N=&AY96%R)R!\?`H@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;
M)&9I96QD75LG='EP92==(#T]("=M;VYT:&1A>7EE87(G*2!["B`@("`@("`@
M("`@("`@("`D=&EM95]F:65L9'-;)&9I96QD72`]("=D871E)SL*("`@("`@
M("`@("`@?2!E;'-E:68@*"1A='1R:6)U=&5S6R1F:65L9%U;)W1Y<&4G72`]
M/2`G=&EM92<I('L*("`@("`@("`@("`@("`@("1T:6UE7V9I96QD<ULD9FEE
M;&1=(#T@)W1I;64G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@
M("`@)'!A<F%M6R=T:6UE7V9I96QD<R==(#T@)'1I;65?9FEE;&1S.PH@("`@
M8G)E86L["GT*"FEF("@A)&5R<F]R("8F("%E;7!T>2@D9')I=F5R*2D@>PH@
M("`@)&1A=&$@/2`F2&]R9&5?1&%T83HZ<VEN9VQE=&]N*"1D<FEV97(I.PH@
M("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*%\H(E1H:7,@9FEL92!F;W)M870@:7,@;F]T
M('-U<'!O<G1E9"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@)&YE>'1?
M<W1E<"`]($E-4$]25%]&24Q%.PH@("`@?2!E;'-E('L*("`@("`@("`D;F5X
M=%]S=&5P(#T@)&1A=&$M/FYE>'13=&5P*"1A8W1I;VY)1"P@)'!A<F%M*3L*
M("`@("`@("!I9B`H:7-?82@D;F5X=%]S=&5P+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&YE>'1?<W1E<"T^
M9V5T365S<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@)&YE
M>'1?<W1E<"`]("1D871A+3YC;&5A;G5P*"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+RH@4F%I<V4@=V%R;FEN9W,@:68@<V]M92!E>&ES="X@
M*B\*("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&1A=&$L("=W87)N
M:6YG<R<I*2!["B`@("`@("`@("`@("`@("`D=V%R;FEN9W,@/2`D9&%T82T^
M=V%R;FEN9W,H*3L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D=V%R;FEN
M9W,I*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'=A<FYI;F=S
M(&%S("1W87)N:6YG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H)'=A<FYI;F<L("=H;W)D92YW87)N:6YG)RD["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B5&AE(&EM<&]R="!C86X@8F4@9FEN:7-H960@
M9&5S<&ET92!T:&4@=V%R;FEN9W,N(BDL("=H;W)D92YM97-S86=E)RD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"GT*"B\J(%=E(&AA=F4@82!F:6YA;"!R97-U;'0@<V5T+B`J+PII9B`H:7-?
M87)R87DH)&YE>'1?<W1E<"DI('L*("`@("\J($-R96%T92!A(%1U<F)A('-T
M;W)A9V4@:6YS=&%N8V4N("HO"B`@("`D9&5S="`]("1?4T534TE/3ELG:6UP
M;W)T7V1A=&$G75LG=&%R9V5T)UT["B`@("`D<W1O<F%G92`]("94=7)B85]$
M<FEV97(Z.G-I;F=L971O;B@D9&5S="D["B`@("!I9B`H:7-?82@D<W1O<F%G
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H<W!R:6YT9BA?*")&86EL960@=&\@86-C97-S('1H92!A9&1R97-S(&)O
M;VLZ("5S(BDL("1S=&]R86=E+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R
M;W(G*3L*("`@('T@96QS92!["B`@("`@("`@+RH@4'5R9V4@;VQD(&%D9')E
M<W,@8F]O:R!I9B!R97%U97-T960N("HO"B`@("`@("`@:68@*"1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG<'5R9V4G72D@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)'-T;W)A9V4M/F1E;&5T94%L;"@I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&%D9')E<W,@
M8F]O:R!C;W5L9"!N;W0@8F4@<'5R9V5D.B`E<R(I+"`D<F5S=6QT+3YG971-
M97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B061D
M<F5S<R!B;V]K('-U8V-E<W-F=6QL>2!P=7)G960N(BDL("=H;W)D92YS=6-C
M97-S)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1E<G)O
M<B`](&9A;'-E.PH@("`@("`@(&9O<F5A8V@@*"1N97AT7W-T97`@87,@)')O
M=RD@>PH@("`@("`@("`@("!I9B`H:7-?82@D<F]W+"`G2&]R9&5?:4-A;&5N
M9&%R7W9C87)D)RDI('L*("`@("`@("`@("`@("`@("1R;W<@/2`D<W1O<F%G
M92T^=&](87-H*"1R;W<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!$;VXG="!S96%R8V@@9F]R(&5M<'1Y(&%T=')I8G5T97,N("HO"B`@("`@
M("`@("`@("1R;W<@/2!A<G)A>5]F:6QT97(H)')O=RP@)U]E;7!T>4%T=')I
M8G5T949I;'1E<B<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'-T;W)A9V4M
M/G-E87)C:"@D<F]W*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"@D<F5S=6QT+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@
M("`@("1E<G)O<B`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?2!E;'-E:68@*"1R97-U;'0M/F-O=6YT*"DI('L*("`@("`@
M("`@("`@("`@("1R97-U;'0M/G)E<V5T*"D["B`@("`@("`@("`@("`@("`D
M;V)J96-T(#T@)')E<W5L="T^;F5X="@I.PH@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(EPB)7-<(B!A;')E861Y(&5X
M:7-T<R!A;F0@=V%S(&YO="!I;7!O<G1E9"XB*2P@)&]B:F5C="T^9V5T5F%L
M=64H)VYA;64G*2DL("=H;W)D92YM97-S86=E)RD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O*B!'970@<VAA<F4@:6YF;W)M871I
M;VXN("HO"B`@("`@("`@("`@("`@("!I9B`H)'-T;W)A9V4M/G5S:6YG4VAA
M<F5S*2!["B`@("`@("`@("`@("`@("`@("`@)')O=ULG7U]O=VYE<B==(#T@
M)'-T;W)A9V4M/G-H87)E+3YG970H)W5I9"<I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F]W6R=?7V]W;F5R)UT@
M/2!!=71H.CIG971!=71H*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@)'-T;W)A9V4M/F%D9"@D<F]W*3L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN
M=&8H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T83H@
M)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R(#T@=')U93L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(21E<G)O<BD@>PH@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B)7,@9FEL
M92!S=6-C97-S9G5L;'D@:6UP;W)T960B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F:6QE7W1Y<&5S6R1?4T534TE/3ELG
M:6UP;W)T7V1A=&$G75LG9F]R;6%T)UU=*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@("`@("!]"B`@("!]"B`@("`D;F5X=%]S=&5P(#T@)&1A=&$M/F-L96%N
M=7`H*3L*?0H*<W=I=&-H("@D;F5X=%]S=&5P*2!["F-A<V4@24U03U)47TU!
M4%!%1#H*8V%S92!)35!/4E1?1$%4151)344Z"B`@("!F;W)E86-H("@D8V9G
M4V]U<F-E<ULD7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)W1A<F=E="==75LG
M;6%P)UT@87,@)&9I96QD(#T^("1N=6QL*2!["B`@("`@("`@:68@*'-U8G-T
M<B@D9FEE;&0L(#`L(#(I("$]("=?7R<@)B8@(6ES7V%R<F%Y*"1N=6QL*2D@
M>PH@("`@("`@("`@("`D87!P7V9I96QD<ULD9FEE;&1=(#T@)&%T=')I8G5T
M97-;)&9I96QD75LG;&%B96PG73L*("`@("`@("!]"B`@("!]"B`@("!B<F5A
M:SL*?0H*)'1I=&QE(#T@7R@B26UP;W)T+T5X<&]R="!!9&1R97-S($)O;VMS
M(BD["G)E<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R
M+FEN8R<["G)E<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]M96YU+FEN8R<[
M"@HD9&5F875L=%]S;W5R8V4@/2`D<')E9G,M/F=E=%9A;'5E*"=D969A=6QT
M7V1I<B<I.PII9B`H)&YE>'1?<W1E<"`]/2!)35!/4E1?1DE,12D@>PH@("`@
M+RH@0G5I;&0@=&AE(&1I<F5C=&]R>2!S;W5R8V5S('-E;&5C="!W:61G970N
M("HO"B`@("`D=6YI<75E7W-O=7)C92`]("<G.PH@("`@)'-O=7)C95]O<'1I
M;VYS(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*%1U<F)A.CIG971!9&1R97-S
M0F]O:W,H*2!A<R`D:V5Y(#T^("1E;G1R>2D@>PH@("`@("`@(&EF("@A96UP
M='DH)&5N=')Y6R=E>'!O<G0G72DI('L*("`@("`@("`@("`@)'-O=7)C95]O
M<'1I;VYS6UT@/2`G/&]P=&EO;B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA
M<G,H)&ME>2D@+B`G(CXG("X*("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L
M8VAA<G,H)&5N=')Y6R=T:71L92==*2`N("(\+V]P=&EO;CY<;B(["B`@("`@
M("`@("`@("1U;FEQ=65?<V]U<F-E(#T@)&ME>3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RH@0G5I;&0@=&AE(&1I<F5C=&]R>2!D97-T:6YA=&EO;B!S96QE
M8W0@=VED9V5T+B`J+PH@("`@)'5N:7%U95]D97-T(#T@)R<["B`@("`D9&5S
M=%]O<'1I;VYS(#T@87)R87DH*3L*("`@("1H87-7<FET96%B;&4@/2!F86QS
M93L*("`@(&9O<F5A8V@@*%1U<F)A.CIG971!9&1R97-S0F]O:W,H4$5235-?
M141)5"D@87,@)&ME>2`]/B`D96YT<GDI('L*("`@("`@("`D<V5L96-T960@
M/2`H)&ME>2`]/2`D9&5F875L=%]S;W5R8V4I(#\@)R!S96QE8W1E9#TB<V5L
M96-T960B)R`Z("<G.PH@("`@("`@("1D97-T7V]P=&EO;G-;72`]("<\;W!T
M:6]N('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`N("<B("<@
M+B`D<V5L96-T960@+B`G/B<@+@H@("`@("`@("`@("!H=&UL<W!E8VEA;&-H
M87)S*"1E;G1R>5LG=&ET;&4G72D@+B`B/"]O<'1I;VX^7&XB.PH@("`@("`@
M("1U;FEQ=65?9&5S="`]("1K97D["B`@("`@("`@)&AA<U=R:71E86)L92`]
M('1R=64["B`@("!]"@H@("`@:68@*"$D:&%S5W)I=&5A8FQE*2!["B`@("`@
M("`@87)R87E?<VAI9G0H)'1E;7!L871E<ULD;F5X=%]S=&5P72D["B`@("!]
M"@H@("`@+RH@0G5I;&0@=&AE(&-H87)S970@;W!T:6]N<RX@*B\*("`@("1C
M:&%R<V5T<R`]("1N;'-;)V5N8V]D:6YG<R==.PH@("`@)&%L;%]C:&%R<V5T
M<R`]("1N;'-;)V-H87)S971S)UT["B`@("!N871C87-E<V]R="@D86QL7V-H
M87)S971S*3L*("`@(&9O<F5A8V@@*"1A;&Q?8VAA<G-E=',@87,@)&-H87)S
M970I('L*("`@("`@("!I9B`H(6ES<V5T*"1C:&%R<V5T<ULD8VAA<G-E=%TI
M*2!["B`@("`@("`@("`@("1C:&%R<V5T<ULD8VAA<G-E=%T@/2`D8VAA<G-E
M=#L*("`@("`@("!]"B`@("!]"B`@("`D;7E?8VAA<G-E="`]($Y,4SHZ9V5T
M0VAA<G-E="AT<G5E*3L*?0H*9F]R96%C:"`H)'1E;7!L871E<ULD;F5X=%]S
M=&5P72!A<R`D=&5M<&QA=&4I('L*("`@(')E<75I<F4@)'1E;7!L871E.PI]
M"G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I
M("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O8G)O=W-E+G!H<```````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,C(S-P`Q,#0Q
M-S,V,C<U-@`P,3<U-C,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@='5R8F$O8G)O=W-E
M+G!H<"QV(#$N-S8N,BXR,2`R,#`V+S`S+S`R(#$W.C$X.C4V(&-H=6-K($5X
M<"`D"B`J"B`J(%1U<F)A.B!#;W!Y<FEG:'0@,C`P,"TR,#`U($-H87)L97,@
M2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A!4TPI+B`@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@
M*B\*"D!D969I;F4H)U154D)!7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D[
M"G)E<75I<F5?;VYC92!455)"05]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+T]B:F5C="YP:'`G.PIR
M97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+TQI<W0N<&AP)SL*<F5Q
M=6ER95]O;F-E(%154D)!7T)!4T4@+B`G+VQI8B],:7-T5FEE=RYP:'`G.PH*
M+R\@4V]R="!O=70@=&AE('-O<G1I;F<@=F%L=65S+@II9B`H*"1S;W)T8GD@
M/2!5=&EL.CIG971&;W)M1&%T82@G<V]R=&)Y)RDI("$]/2!N=6QL*2!["B`@
M("!I9B`H)'-O<G1B>2`]/2`G;F%M92<@)B8@)'!R969S+3YG971686QU92@G
M;F%M95]F;W)M870G*2`]/2`G;&%S=%]F:7)S="<I('L*("`@("`@("`D<V]R
M=&)Y(#T@)VQA<W1N86UE)SL*("`@('T*("`@("1P<F5F<RT^<V5T5F%L=64H
M)W-O<G1B>2<L("1S;W)T8GDI.PI]"FEF("@H)'-O<G1D:7(@/2!5=&EL.CIG
M971&;W)M1&%T82@G<V]R=&1I<B<I*2`A/3T@;G5L;"D@>PH@("`@)'!R969S
M+3YS971686QU92@G<V]R=&1I<B<L("1S;W)T9&ER*3L*?0H*)'1I=&QE(#T@
M7R@B061D<F5S<R!";V]K($QI<W1I;F<B*3L*"FEF("@A)&)R;W=S95]S;W5R
M8V5?8V]U;G0@)B8@571I;#HZ9V5T1F]R;41A=&$H)VME>2<I("$]("<J*G-E
M87)C:"<I('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B5&AE<F4@87)E
M(&YO(&)R;W=S96%B;&4@861D<F5S<R!B;V]K<RXB*2P@)VAO<F1E+G=A<FYI
M;F<G*3L*?2!E;'-E('L*("`@("1D<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS
M:6YG;&5T;VXH)'-O=7)C92D["B`@("!I9B`H:7-?82@D9')I=F5R+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(D9A:6QE9"!T;R!A8V-E<W,@=&AE(&%D9')E<W,@8F]O:SH@)7,B
M*2P@)&1R:79E<BT^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("`@("`@=6YS970H)&1R:79E<BD["B`@("!]"GT*"FEF("AI<W-E="@D9')I
M=F5R*2D@>PH@("`@)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C
M=&EO;DE$)RD["@H@("`@+R\@4G5N('1H<F]U9V@@=&AE(&%C=&EO;B!H86YD
M;&5R<RX*("`@('-W:71C:"`H)&%C=&EO;DE$*2!["B`@("!C87-E("=D96QE
M=&4G.@H@("`@("`@("1K97ES(#T@571I;#HZ9V5T1F]R;41A=&$H)V]B:F5C
M=&ME>7,G*3L*("`@("`@("!I9B`H:7-?87)R87DH)&ME>7,I*2!["B`@("`@
M("`@("`@("1K97D@/2!5=&EL.CIG971&;W)M1&%T82@G:V5Y)RP@9F%L<V4I
M.PH@("`@("`@("`@("!I9B`H)&ME>2`F)B`D:V5Y("$]("<J*G-E87)C:"<I
M('L*("`@("`@("`@("`@("`@("\O(%=E(&%R92!R96UO=FEN9R!A(&-O;G1A
M8W0@9G)O;2!A(&QI<W0N"B`@("`@("`@("`@("`@("`D97)R;W)#;W5N="`]
M(#`["B`@("`@("`@("`@("`@("`D;&ES="`]("8D9')I=F5R+3YG971/8FIE
M8W0H)&ME>2D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D
M<V]U<F-E2V5Y*2!["B`@("`@("`@("`@("`@("`@("`@;&ES="@D;V)J96-T
M4V]U<F-E+"`D;V)J96-T2V5Y*2`](&5X<&QO9&4H)SHG+"`D<V]U<F-E2V5Y
M+"`R*3L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1O8FIE8W1+
M97DL("<Z)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D;V)J
M96-T3W=N97(L("1O8FIE8W1+97DI(#T@97AP;&]D92@G.B<L("1O8FIE8W1+
M97DL(#(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D;V)J96-T4V]U<F-E
M("X]("<Z)R`N("1O8FIE8W1/=VYE<CL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@:68@*"$D;&ES="T^<F5M;W9E365M8F5R
M*"1O8FIE8W1+97DL("1O8FIE8W13;W5R8V4I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1E<G)O<D-O=6YT*RL["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"$D97)R
M;W)#;W5N="D@>PH@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@<F5M;W9E9"`E9"!C;VYT
M86-T*',I(&9R;VT@;&ES="XB*2P@8V]U;G0H)&ME>7,I*2P@)VAO<F1E+G-U
M8V-E<W,G*3L*("`@("`@("`@("`@("`@('T@96QS96EF("AC;W5N="@D:V5Y
M<RD@/3T@)&5R<F]R0V]U;G0I('L*("`@("`@("`@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R;W(@<F5M;W9I;F<@)60@
M8V]N=&%C="AS*2!F<F]M(&QI<W0N(BDL(&-O=6YT*"1K97ES*2DL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R
M;W(@<F5M;W9I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@9G)O
M;2!L:7-T+B(I+"`D97)R;W)#;W5N="P@8V]U;G0H)&ME>7,I*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M;&ES="T^<W1O<F4H*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("\O(%=E(&%R92!D96QE=&EN9R!A;B!O8FIE8W0N"B`@("`@("`@
M("`@("`@("`D97)R;W)#;W5N="`](#`["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D:V5Y<R!A<R`D<V]U<F-E2V5Y*2!["B`@("`@("`@("`@("`@("`@
M("`@;&ES="@D;V)J96-T4V]U<F-E+"`D;V)J96-T2V5Y*2`](&5X<&QO9&4H
M)SHG+"`D<V]U<F-E2V5Y+"`R*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M<W1R<&]S*"1O8FIE8W1+97DL("<Z)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@;&ES="@D;V)J96-T3W=N97(L("1O8FIE8W1+97DI(#T@97AP;&]D
M92@G.B<L("1O8FIE8W1+97DL(#(I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D9')I=F5R+3YD96QE=&4H
M)&]B:F5C=$ME>2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5R<F]R0V]U;G0K*SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(21E<G)O
M<D-O=6YT*2!["B`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!D96QE=&5D("5D(&-O;G1A
M8W0H<RDN(BDL(&-O=6YT*"1K97ES*2DL("=H;W)D92YS=6-C97-S)RD["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H8V]U;G0H)&ME>7,I(#T]("1E<G)O
M<D-O=6YT*2!["B`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"AS<')I;G1F*%\H(D5R<F]R(&1E;&5T:6YG("5D(&-O;G1A8W0H<RDN
M(BDL(&-O=6YT*"1K97ES*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R;W(@9&5L971I;F<@)60@;V8@)60@
M<F5Q=65S=&5D(&-O;G1A8W1S*',I+B(I+"`D97)R;W)#;W5N="P@8V]U;G0H
M)&ME>7,I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@8G)E86L["@H@("`@8V%S
M92`G;6]V92<Z"B`@("!C87-E("=C;W!Y)SH*("`@("`@("`D:V5Y<R`](%5T
M:6PZ.F=E=$9O<FU$871A*"=O8FIE8W1K97ES)RD["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1K97ES*2`F)B`D:V5Y<RD@>PH@("`@("`@("`@("`O+R!)9B!W
M92!H879E(&1A=&$L('1R>2!L;V%D:6YG('1H92!T87)G970@861D<F5S<R!B
M;V]K(&1R:79E<BX*("`@("`@("`@("`@)'1A<F=E=%-O=7)C92`](%5T:6PZ
M.F=E=$9O<FU$871A*"=T87)G971!9&1R97-S8F]O:R<I.PH@("`@("`@("`@
M("`D=&%R9V5T1')I=F5R(#T@)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1T
M87)G9713;W5R8V4I.PH@("`@("`@("`@("`D;6%X7V-O;G1A8W1S(#T@5'5R
M8F$Z.FAA<U!E<FUI<W-I;VXH)'1A<F=E=%-O=7)C92`N("<Z;6%X7V-O;G1A
M8W1S)RP@)W-O=7)C92<I.PH@("`@("`@("`@("!I9B`H:7-?82@D=&%R9V5T
M1')I=F5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B1F%I;&5D('1O(&%C8V5S<R!T
M:&4@861D<F5S<R!B;V]K.B`E<R(I+"`D=&%R9V5T1')I=F5R+3YG971-97-S
M86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?2!E;'-E:68@
M*"1M87A?8V]N=&%C=',@(3T]('1R=64@)B8*("`@("`@("`@("`@("`@("`@
M("`@("1M87A?8V]N=&%C=',@/#T@)'1A<F=E=$1R:79E<BT^8V]U;G1#;VYT
M86-T<R@I*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]($!H=&UL<W!E
M8VEA;&-H87)S*'-P<FEN=&8H7R@B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&-O;G1A8W1S(&EN(%PB)7-<(BXB*2P@)&UA
M>%]C;VYT86-T<RP@)&-F9U-O=7)C97-;)'1A<F=E=%-O=7)C95U;)W1I=&QE
M)UTI+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P97)M<V1E;FEE
M9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1M97-S86=E(#T@2&]R9&4Z
M.F-A;&Q(;V]K*"=?<&5R;7-?:&]O:U]D96YI960G+"!A<G)A>2@G='5R8F$Z
M;6%X7V-O;G1A8W1S)RDL("=H;W)D92<L("1M97-S86=E*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M)&UE<W-A9V4L("=H;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1K97ES(&%S("1S;W5R8V5+97DI('L*("`@("`@("`@("`@("`@("`@
M("`O+R!3<&QI="!U<"!T:&4@:V5Y(&EN=&\@<V]U<F-E(&%N9"!O8FIE8W0@
M:61S+@H@("`@("`@("`@("`@("`@("`@(&QI<W0H)&]B:F5C=%-O=7)C92P@
M)&]B:F5C=$ME>2D@/2!E>'!L;V1E*"<Z)RP@)'-O=7)C94ME>2P@,BD["B`@
M("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;V)J96-T2V5Y+"`G.B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)&]B:F5C=$]W;F5R
M+"`D;V)J96-T2V5Y*2`](&5X<&QO9&4H)SHG+"`D;V)J96-T2V5Y+"`R*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]B:F5C=%-O=7)C92`N/2`G.B<@
M+B`D;V)J96-T3W=N97(["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("`@("`O+R!)9VYO<F4@=&AI<R!E;G1R>2!I9B!T:&4@=&%R
M9V5T(&ES('1H92!S86UE(&%S('1H90H@("`@("`@("`@("`@("`@("`@("\O
M('-O=7)C92X*("`@("`@("`@("`@("`@("`@("!I9B`H)&]B:F5C=%-O=7)C
M92`]/2`D=&%R9V5T1')I=F5R+3YN86UE("8F"B`@("`@("`@("`@("`@("`@
M("`@("`@("$D=&%R9V5T1')I=F5R+3YU<VEN9U-H87)E<RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@("\O(%1R>2!A;F0@;&]A9"!T:&4@
M9')I=F5R(&9O<B!T:&4@<V]U<F-E+@H@("`@("`@("`@("`@("`@("`@("1S
M;W5R8V5$<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS:6YG;&5T;VXH)&]B:F5C
M=%-O=7)C92D["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)'-O=7)C
M941R:79E<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B1F%I;&5D('1O
M(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E<R(I+"`D<V]U<F-E1')I=F5R
M+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;V)J
M96-T(#T@)B1S;W5R8V5$<FEV97(M/F=E=$]B:F5C="@D;V)J96-T2V5Y*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&]B:F5C="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D9A:6QE9"!T;R!F:6YD(&]B
M:F5C="!T;R!B92!A9&1E9#H@)7,B*2P@)&]B:F5C="T^9V5T365S<V%G92@I
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1O8FIE8W0M/FES1W)O=7`H*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1A8W1I;VY)1"`]/2`G;6]V92<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN
M=&8H7R@B7"(E<UPB('=A<R!N;W0@;6]V960@8F5C875S92!I="!I<R!A(&QI
M<W0N(BDL("1O8FIE8W0M/F=E=%9A;'5E*"=N86UE)RDI+"`G:&]R9&4N=V%R
M;FEN9R<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B7"(E<UPB('=A<R!N;W0@8V]P:65D(&)E8V%U
M<V4@:70@:7,@82!L:7-T+B(I+"`D;V)J96-T+3YG971686QU92@G;F%M92<I
M*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!4<GD@861D:6YG('1O('1H92!T87)G970N"B`@("`@("`@("`@
M("`@("`@("`@("`@("1O8FI!='1R:6)U=&5S(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@1V5T('1H92!V86QU97,@=&AR;W5G:"!T
M:&4@5'5R8F%?3V)J96-T(&-L87-S+@H@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=&%R9V5T1')I=F5R+3YG971#<FET97)I82@I(&%S("1I
M;F9O7VME>2`]/B`D:6YF;U]V86PI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1O8FI!='1R:6)U=&5S6R1I;F9O7VME>5T@/2`D;V)J96-T+3YG
M971686QU92@D:6YF;U]K97DI.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'1A<F=E=$1R:79E<BT^
M=7-I;F=3:&%R97,I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O
M8FI!='1R:6)U=&5S6R=?7V]W;F5R)UT@/2`D=&%R9V5T1')I=F5R+3YS:&%R
M92T^9V5T*"=U:60G*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1A<F=E=$1R:79E<BT^
M861D*"1O8FI!='1R:6)U=&5S*3L*"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")&86EL960@=&\@861D("5S('1O("5S.B`E<R(I+"`D;V)J96-T+3YG
M971686QU92@G;F%M92<I+"`D=&%R9V5T1')I=F5R+3YT:71L92P@)')E<W5L
M="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U
M;&QY(&%D9&5D("5S('1O("5S(BDL("1O8FIE8W0M/F=E=%9A;'5E*"=N86UE
M)RDL("1T87)G971$<FEV97(M/G1I=&QE*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!)9B!W92=R92!M;W9I
M;F<@;V)J96-T<RP@86YD('=E('-U8V-E961E9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&1E;&5T92!T:&5M(&9R;VT@=&AE(&]R:6=I;F%L
M('-O=7)C92!N;W<N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)&%C=&EO;DE$(#T]("=M;W9E)RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1S;W5R8V5$<FEV97(M/F1E;&5T92@D;V)J
M96-T2V5Y*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(%PB)7-<(B!F<F]M('1H
M92!S;W5R8V4@861D<F5S<R!B;V]K+B(I+"`D;V)J96-T+3YG971686QU92@G
M;F%M92<I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&)R96%K.PH*("`@(&-A<V4@)V%D9"<Z"B`@("`@("`@+R\@061D
M(&$@8V]N=&%C="!T;R!A(&QI<W0N"B`@("`@("`@)&ME>7,@/2!5=&EL.CIG
M971&;W)M1&%T82@G;V)J96-T:V5Y<R<I.PH@("`@("`@("1T87)G971+97D@
M/2!5=&EL.CIG971&;W)M1&%T82@G=&%R9V5T3&ES="<I.PH@("`@("`@(&EF
M("AE;7!T>2@D=&%R9V5T2V5Y*2D@>PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"B`@("`@("`@:68@*"%5=&EL.CIG971&;W)M1&%T82@G=&%R9V5T
M3F5W)RDI('L*("`@("`@("`@("`@;&ES="@D=&%R9V5T4V]U<F-E+"`D=&%R
M9V5T2V5Y*2`](&5X<&QO9&4H)SHG+"`D=&%R9V5T2V5Y+"`R*3L*("`@("`@
M("`@("`@:68@*'-T<G!O<R@D=&%R9V5T2V5Y+"`G.B<I*2!["B`@("`@("`@
M("`@("`@("!L:7-T*"1O8FIE8W1/=VYE<BP@)'1A<F=E=$ME>2D@/2!E>'!L
M;V1E*"<Z)RP@)'1A<F=E=$ME>2D["B`@("`@("`@("`@("`@("`D=&%R9V5T
M4V]U<F-E(#T@)'1A<F=E=%-O=7)C92`N("<Z)R`N("1O8FIE8W1/=VYE<CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1C9F=3;W5R
M8V5S6R1T87)G9713;W5R8V5=*2D@>PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1A<F=E=$1R:79E<B`]("94
M=7)B85]$<FEV97(Z.G-I;F=L971O;B@D=&%R9V5T4V]U<F-E*3L*("`@("`@
M("`@("`@)'1A<F=E="`]("8D=&%R9V5T1')I=F5R+3YG971/8FIE8W0H)'1A
M<F=E=$ME>2D["B`@("`@("`@("`@(&EF("AI<U]A*"1T87)G970L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H)'1A<F=E="P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(65M
M<'1Y*"1T87)G970I("8F("1T87)G970M/FES1W)O=7`H*2D@>PH@("`@("`@
M("`@("`O+R!!9&1I;F<@8V]N=&%C="!T;R!A;B!E>&ES=&EN9R!L:7-T+@H@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)&ME>7,I*2!["B`@("`@("`@("`@
M("`@("`D97)R;W)#;W5N="`](#`["B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D:V5Y<R!A<R`D<V]U<F-E2V5Y*2!["B`@("`@("`@("`@("`@("`@("`@
M;&ES="@D;V)J96-T4V]U<F-E+"`D;V)J96-T2V5Y*2`](&5X<&QO9&4H)SHG
M+"`D<V]U<F-E2V5Y+"`R*3L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M<&]S*"1O8FIE8W1+97DL("<Z)RDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@;&ES="@D;V)J96-T3W=N97(L("1O8FIE8W1+97DI(#T@97AP;&]D92@G
M.B<L("1O8FIE8W1+97DL(#(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;V)J96-T4V]U<F-E("X]("<Z)R`N("1O8FIE8W1/=VYE<CL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&%R9V5T
M+3YA9&1-96UB97(H)&]B:F5C=$ME>2P@)&]B:F5C=%-O=7)C92DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<F]R0V]U;G0K*SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H(21E<G)O<D-O=6YT*2!["B`@("`@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!A9&1E
M9"`E9"!C;VYT86-T*',I('1O(&QI<W0N(BDL(&-O=6YT*"1K97ES*2DL("=H
M;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B@D97)R
M;W)#;W5N="`]/2!C;W5N="@D:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R;W(@861D:6YG
M("5D(&-O;G1A8W0H<RD@=&\@;&ES="XB*2P@8V]U;G0H)&ME>7,I*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")%
M<G)O<B!A9&1I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@=&\@
M;&ES="XB*2P@)&5R<F]R0V]U;G0L(&-O=6YT*"1K97ES*2DL("=H;W)D92YE
M<G)O<B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1A
M<F=E="T^<W1O<F4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O($-H96-K('!E<FUI<W-I;VYS+@H@("`@("`@("`@
M("`D;6%X7V-O;G1A8W1S(#T@5'5R8F$Z.FAA<U!E<FUI<W-I;VXH)'-O=7)C
M92`N("<Z;6%X7V-O;G1A8W1S)RP@)W-O=7)C92<I.PH@("`@("`@("`@("!I
M9B`H)&UA>%]C;VYT86-T<R`A/3T@=')U92`F)@H@("`@("`@("`@("`@("`@
M)&UA>%]C;VYT86-T<R`\/2`D9')I=F5R+3YC;W5N=$-O;G1A8W1S*"DI('L*
M("`@("`@("`@("`@("`@("1M97-S86=E(#T@0&AT;6QS<&5C:6%L8VAA<G,H
M<W!R:6YT9BA?*")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@8V]N=&%C=',@:6X@7"(E<UPB+B(I+"`D;6%X7V-O;G1A8W1S
M+"`D8V9G4V]U<F-E<ULD<V]U<F-E75LG=&ET;&4G72DL($5.5%]#3TU0050L
M($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&-O;F9;)VAO;VMS)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&UE<W-A9V4@/2!(;W)D93HZ8V%L;$AO;VLH)U]P97)M
M<U]H;V]K7V1E;FEE9"<L(&%R<F%Y*"=T=7)B83IM87A?8V]N=&%C=',G*2P@
M)VAO<F1E)RP@)&UE<W-A9V4I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&UE<W-A9V4L("=H;W)D
M92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O($%D9&EN
M9R!C;VYT86-T('1O(&$@;F5W(&QI<W0N"B`@("`@("`@("`@("1N97=,:7-T
M(#T@87)R87DH*3L*("`@("`@("`@("`@:68@*"1D<FEV97(M/G5S:6YG4VAA
M<F5S*2!["B`@("`@("`@("`@("`@("`D;F5W3&ES=%LG7U]O=VYE<B==(#T@
M)&1R:79E<BT^<VAA<F4M/F=E="@G=6ED)RD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;F5W3&ES=%LG7U]O=VYE<B==(#T@075T
M:#HZ9V5T075T:"@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1N97=,
M:7-T6R=?7W1Y<&4G72`]("='<F]U<"<["B`@("`@("`@("`@("1N97=,:7-T
M6R=N86UE)UT@/2`D=&%R9V5T2V5Y.PH*("`@("`@("`@("`@)'1A<F=E=$ME
M>2`]("1D<FEV97(M/F%D9"@D;F5W3&ES="D["B`@("`@("`@("`@("1T87)G
M970@/2`F)&1R:79E<BT^9V5T3V)J96-T*"1T87)G971+97DI.PH@("`@("`@
M("`@("!I9B`H(6ES7V$H)'1A<F=E="P@)U!%05)?17)R;W(G*2`F)B`D=&%R
M9V5T+3YI<T=R;W5P*"DI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@8W)E871E9"!T:&4@
M8V]N=&%C="!L:7-T(%PB)7-<(BXB*2P@)&YE=TQI<W1;)VYA;64G72DL("=H
M;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)&ME>7,I*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R0V]U;G0@/2`P
M.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1S;W5R
M8V5+97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D;V)J96-T
M4V]U<F-E+"`D;V)J96-T2V5Y*2`](&5X<&QO9&4H)SHG+"`D<V]U<F-E2V5Y
M+"`R*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;V)J
M96-T2V5Y+"`G.B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!L
M:7-T*"1O8FIE8W1/=VYE<BP@)&]B:F5C=$ME>2D@/2!E>'!L;V1E*"<Z)RP@
M)&]B:F5C=$ME>2P@,BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;V)J96-T4V]U<F-E("X]("<Z)R`N("1O8FIE8W1/=VYE<CL*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(21T87)G970M/F%D9$UE;6)E<B@D;V)J96-T2V5Y+"`D;V)J96-T4V]U<F-E
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R0V]U;G0K
M*SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H(21E<G)O<D-O=6YT*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@861D960@)60@8V]N=&%C="AS*2!T
M;R!L:7-T+B(I+"!C;W5N="@D:V5Y<RDI+"`G:&]R9&4N<W5C8V5S<R<I.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D97)R;W)#;W5N="`]/2!C
M;W5N="@D:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D5R<F]R(&%D9&EN9R`E9"!C;VYT
M86-T*',I('1O(&QI<W0N(BDL(&-O=6YT*"1K97ES*2DL("=H;W)D92YE<G)O
M<B<I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")%
M<G)O<B!A9&1I;F<@)60@;V8@)60@<F5Q=65S=&5D(&-O;G1A8W0H<RD@=&\@
M;&ES="XB*2P@)&5R<F]R0V]U;G0L(&-O=6YT*"1K97ES*2DL("=H;W)D92YE
M<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D=&%R9V5T+3YS=&]R92@I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"A?*")4:&5R92!W87,@86X@97)R;W(@8W)E871I;F<@82!N97<@
M;&ES="XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@8G)E86L["B`@("!]"GT*"B1T96UP;&%T97,@/2!A<G)A
M>2@I.PII9B`H:7-S970H)&1R:79E<BDI('L*("`@("1T96UP;&%T97-;72`]
M("<O8G)O=W-E+VIA=F%S8W)I<'0N:6YC)SL*"B`@("`O+R!296%D('1H92!C
M;VQU;6YS('1O(&1I<W!L87D@9G)O;2!T:&4@<')E9F5R96YC97,N"B`@("`D
M<V]U<F-E<R`](%1U<F)A.CIG971#;VQU;6YS*"D["B`@("`D8V]L=6UN<R`]
M(&ES<V5T*"1S;W5R8V5S6R1S;W5R8V5=*2`_("1S;W5R8V5S6R1S;W5R8V5=
M(#H@87)R87DH*3L*"B`@("`O+R!$971E<FUI;F4@=&AE(&YA;64@;V8@=&AE
M(&-O;'5M;B!T;R!S;W)T(&)Y+@H@("`@)'-O<G1C;VQU;6X@/2`H)'!R969S
M+3YG971686QU92@G<V]R=&)Y)RD@/3T@,"!\?`H@("`@("`@("`@("`@("`@
M("`@(6ES<V5T*"1C;VQU;6YS6R1P<F5F<RT^9V5T5F%L=64H)W-O<G1B>2<I
M("T@,5TI*0H@("`@("`@(#\@*"@D<')E9G,M/F=E=%9A;'5E*"=N86UE7V9O
M<FUA="<I(#T]("=F:7)S=%]L87-T)RD*("`@("`@("`@("`_("=N86UE)PH@
M("`@("`@("`@(#H@)VQA<W1N86UE)RD*("`@("`@("`Z("1C;VQU;6YS6R1P
M<F5F<RT^9V5T5F%L=64H)W-O<G1B>2<I("T@,5T["@H@("`@:68@*%5T:6PZ
M.F=E=$9O<FU$871A*"=K97DG*2D@>PH@("`@("`@("\O(%=E(&%R92!D:7-P
M;&%Y:6YG(&$@;&ES="X*("`@("`@("`D;&ES="`]("8D9')I=F5R+3YG971/
M8FIE8W0H571I;#HZ9V5T1F]R;41A=&$H)VME>2<I*3L*("`@("`@("!I9B`H
M:7-S970H)&QI<W0I("8F(&ES7V]B:F5C="@D;&ES="D@)B8*("`@("`@("`@
M("`@(6ES7V$H)&QI<W0L("=014%27T5R<F]R)RD@)B8@)&QI<W0M/FES1W)O
M=7`H*2D@>PH@("`@("`@("`@("`D=&ET;&4@/2!S<')I;G1F*%\H(D-O;G1A
M8W1S(&EN(&QI<W0Z("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&QI<W0M/F=E=%9A;'5E*"=N86UE)RDI.PH@("`@("`@("`@("`D=&5M
M<&QA=&5S6UT@/2`G+V)R;W=S92]H96%D97(N:6YC)SL*"B`@("`@("`@("`@
M("\O(%-H;W<@3&ES="!-96UB97)S+@H@("`@("`@("`@("!I9B`H(6ES7V]B
M:F5C="@D<F5S=6QT<R`]("1L:7-T+3YL:7-T365M8F5R<R@D<V]R=&-O;'5M
M;BP@)'!R969S+3YG971686QU92@G<V]R=&1I<B<I*2DI('L*("`@("`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B1F%I;&5D('1O(&)R;W=S
M92!L:7-T(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'9I97<@/2`F;F5W(%1U<F)A7TQI<W16:65W
M*"1R97-U;'1S*3L*("`@("`@("`@("`@("`@("1V:65W+3YS9714>7!E*"=L
M:7-T)RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H92!L:7-T(BDL("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@('T*("`@('T@96QS92!["B`@("`@("`@+R\@5V4@87)E(&1I<W!L87EI
M;F<@86X@861D<F5S<R!B;V]K+@H@("`@("`@("1T:71L92`]("1C9F=3;W5R
M8V5S6R1S;W5R8V5=6R=T:71L92==.PH@("`@("`@("1T96UP;&%T97-;72`]
M("<O8G)O=W-E+VAE861E<BYI;F,G.PH@("`@("`@(&EF("AE;7!T>2@D8V9G
M4V]U<F-E<ULD<V]U<F-E75LG8G)O=W-E)UTI*2!["B`@("`@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H7R@B66]U<B!D969A=6QT(&%D9')E<W,@8F]O
M:R!I<R!N;W0@8G)O=W-E86)L92XB*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A
M=&$H)W-H;W<G+"`G86QL)RD@/3T@)V-O;G1A8W1S)RD@>PH@("`@("`@("`@
M("`@("`@+R\@4VAO=R!#;VYT86-T<RX*("`@("`@("`@("`@("`@("1R97-U
M;'1S(#T@)&1R:79E<BT^<V5A<F-H*&%R<F%Y*"=?7W1Y<&4G(#T^("=/8FIE
M8W0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S;W)T8V]L=6UN+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)T%.1"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<')E9G,M/F=E=%9A;'5E*"=S;W)T9&ER
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]L=6UN<RD["B`@("`@("`@("`@('T@96QS96EF("A5=&EL.CIG971&
M;W)M1&%T82@G<VAO=R<L("=A;&PG*2`]/2`G;&ES=',G*2!["B`@("`@("`@
M("`@("`@("`O+R!3:&]W($QI<W1S+@H@("`@("`@("`@("`@("`@)')E<W5L
M=',@/2`D9')I=F5R+3YS96%R8V@H87)R87DH)U]?='EP92<@/3X@)T=R;W5P
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<V]R=&-O;'5M;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=!3D0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!R969S+3YG971686QU92@G<V]R=&1I<B<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;'5M;G,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+R\@4VAO=R!!;&PN"B`@("`@("`@("`@("`@("`D<F5S=6QT<R`]("1D
M<FEV97(M/G-E87)C:"AA<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-O<G1C;VQU;6XL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G04Y$)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5F<RT^
M9V5T5F%L=64H)W-O<G1D:7(G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;VQU;6YS*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(6ES7V]B:F5C="@D<F5S=6QT<RDI('L*("`@("`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B1F%I;&5D('1O(&)R
M;W=S92!T:&4@9&ER96-T;W)Y(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@
M("`@("!](&5L<V5I9B`H:7-?82@D<F5S=6QT<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S=6QT
M<RP@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=FEE=R`]("9N97<@5'5R8F%?3&ES=%9I97<H)')E<W5L
M=',I.PH@("`@("`@("`@("`@("`@)'9I97<M/G-E=%1Y<&4H)V1I<F5C=&]R
M>2<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0I](&5L<V4@>PH@
M("`@)'1E;7!L871E<UM=(#T@)R]B<F]W<V4O:&5A9&5R+FEN8R<["GT*"G)E
M<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<[
M"G)E<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]M96YU+FEN8R<["F9O<F5A
M8V@@*"1T96UP;&%T97,@87,@)'1E;7!L871E*2!["B`@("!R97%U:7)E(%15
M4D)!7U1%35!,051%4R`N("1T96UP;&%T93L*?0H*:68@*&ES<V5T*"1V:65W
M*2`F)B!I<U]O8FIE8W0H)'9I97<I*2!["B`@("`D=FEE=RT^9&ES<&QA>2@I
M.PI]"@IR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R
M9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O='5R8F$O861D<F5S<V)O;VMS+G!H<```````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,38U,@`Q,#0Q-S,V,C<U-@`P,C`W-#(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1U<F)A('-C<FEP="!T;R!M86YA9V4@=&AE('5S97(G<R!A9&1R
M97-S8F]O:R!S:&%R97,N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@36EC
M:&%E;"!*+B!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B`D
M2&]R9&4Z('1U<F)A+V%D9')E<W-B;V]K<RYP:'`L=B`Q+C,N,BXV(#(P,#8O
M,#$O,3$@,38Z-#`Z,#D@:F%N($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI
M+B`@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*@H@*B!`
M875T:&]R($UI8VAA96P@2BX@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R
M9SX*("HO"@I`9&5F:6YE*"=455)"05]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RDI.PIR97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+V)A<V4N<&AP
M)SL*"B\O($5X:70@:68@=&AI<R!I<VXG="!A;B!A=71H96YT:6-A=&5D('5S
M97(L(&]R(&EF('1H97)E)W,@;F\@<V]U<F-E"B\O(&-O;F9I9W5R960@9F]R
M('-H87)E<RX*:68@*"%!=71H.CIG971!=71H*"D@?'P@(21H879E4VAA<F4I
M('L*("`@(')E<75I<F4@5%520D%?0D%312`N("<O)R`N("@D8G)O=W-E7W-O
M=7)C95]C;W5N=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#\@
M8F%S96YA;64H)'!R969S+3YG971686QU92@G:6YI=&EA;%]P86=E)RDI"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`G<V5A<F-H+G!H<"<I
M.PH@("`@97AI=#L*?0H*+R\@1FEG=7)E(&]U="!W:'D@=V4@87)E(&AE<F4N
M"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PIS
M=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=A9&0G.@H@("`@)'!A<F%M<R`]
M(&%R<F%Y*`H@("`@("`@("=S;W5R8V54>7!E)R`]/B`D8V]N9ELG<VAA<F5S
M)UU;)W-O=7)C92==+`H@("`@("`@("=S:&%R94YA;64G(#T^(%5T:6PZ.F=E
M=$9O<FU$871A*"=S:&%R96YA;64G*0H@("`@*3L*"B`@("`D<VAA<F4@/2`F
M5'5R8F$Z.F-R96%T95-H87)E*"1P87)A;7,L(&9A;'-E*3L*("`@(&EF("AI
M<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R92!W87,@86X@97)R;W(@8W)E
M871I;F<@=&AI<R!A9&1R97-S(&)O;VLZ("5S(BDL("1S:&%R92T^9V5T365S
M<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@
M("\O($-R96%T960@=&AE('-H87)E+"!N;W<@861D(&ET('1O('1H92!A9&1R
M97-S(&)O;VMS('!R968@:70@=V4@;F5E9`H@("`@("`@("\O('1O+@H@("`@
M("`@("1A9&1R97-S8F]O:W,@/2`D<')E9G,M/F=E=%9A;'5E*"=A9&1R97-S
M8F]O:W,G*3L*("`@("`@("`D<VAA<F5+97D@/2`D8V]N9ELG<VAA<F5S)UU;
M)W-O=7)C92==("X@)SHG("X@)'-H87)E+3YG970H)W5I9"<I.PH@("`@("`@
M(&EF("@D861D<F5S<V)O;VMS*2!["B`@("`@("`@("`@("1A9&1R97-S8F]O
M:W,@+CT@(EQN(B`N("1S:&%R94ME>3L*("`@("`@("`@("`@)'!R969S+3YS
M971686QU92@G861D<F5S<V)O;VMS)RP@)&%D9')E<W-B;V]K<RD["B`@("`@
M("`@?0H@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4
M:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W87,@8W)E871E9"!S=6-C97-S9G5L
M;'DN(BDL("1S:&%R92T^9V5T*"=N86UE)RDI+"`G:&]R9&4N<W5C8V5S<R<I
M.PH@("`@?0H@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861D<F5S<V)O;VMS+G!H<"<L('1R=64I*3L*("`@(&5X
M:70["@IC87-E("=D96QE=&4G.@H@("`@+R\@1V5T('1H92!S;W5R8V4@='EP
M92!A;F0@=6ED"B`@("!L:7-T*"1T>7!E+"`D=6ED*2`](&5X<&QO9&4H)SHG
M+"!5=&EL.CIG971&;W)M1&%T82@G9&5L971E<VAA<F4G*2P@,BD["B`@("`D
M9')I=F5R(#T@)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1T>7!E*3L*("`@
M(&EF("AI<U]A*"1D<FEV97(L("=014%27T5R<F]R)RDI('L*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&%N(&5R
M<F]R(')E;6]V:6YG('1H:7,@861D<F5S<R!B;V]K.B`E<R(I+"`D9')I=F5R
M+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92![
M"B`@("`@("`@+R\@5V4@:&%V92!A(%1U<F)A7T1R:79E<BP@=')Y('1O(&1E
M;&5T92!T:&4@861D<F5S<R!B;V]K+@H@("`@("`@("1R97-U;'0@/2`D9')I
M=F5R+3YD96QE=&5!;&PH)'5I9"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(')E;6]V:6YG
M('1H:7,@861D<F5S<R!B;V]K.B`E<R(I+"`D<F5S=6QT+3YG971-97-S86=E
M*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O+R!!9&1R97-S(&)O;VL@<W5C8V5S<V9U;&QY(&1E;&5T960@9G)O
M;2!B86-K96YD+"!R96UO=F4@=&AE"B`@("`@("`@("`@("\O('-H87)E+@H@
M("`@("`@("`@("`D<F5S=6QT(#T@5'5R8F$Z.F1E;&5T95-H87)E*%5T:6PZ
M.F=E=$9O<FU$871A*"=D96QE=&5S:&%R92<I*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H97)E('=A<R!A
M;B!E<G)O<B!R96UO=FEN9R!T:&ES(&%D9')E<W,@8F]O:SH@)7,B*2P@)')E
M<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*'-P<FEN=&8H7R@B5&AE(&%D9')E<W,@8F]O:R!<(B5S7"(@=V%S(')E
M;6]V960@<W5C8V5S<V9U;&QY+B(I+"`D<F5S=6QT*2P@)VAO<F1E+G-U8V-E
M<W,G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(&AE861E
M<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D9')E
M<W-B;V]K<RYP:'`G+"!T<G5E*2D["B`@("!E>&ET.PH*8V%S92`G=7!D871E
M)SH*("`@("\O(%5P9&%T:6YG('-O;64@:6YF;R!O;B!A;B!E>&ES=&EN9R!S
M:&%R92X*("`@("1S:&%R94YA;64@/2!5=&EL.CIG971&;W)M1&%T82@G961I
M='-H87)E)RD["B`@("`D<&%R86US(#T@87)R87DH"B`@("`@("`@)VYA;64G
M(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=S:&%R971I=&QE)RDL"B`@("`@("`@
M)V1E<V-R:7!T:6]N)R`]/B!5=&EL.CIG971&;W)M1&%T82@G9&5S8W)I<'1I
M;VXG*0H@("`@*3L*("`@("1R97-U;'0@/2!4=7)B83HZ=7!D871E4VAA<F4H
M)'-H87)E3F%M92P@)'!A<F%M<RD["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS
M<')I;G1F*%\H(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&ES(&%D
M9')E<W,@8F]O:SH@)7,B*2P@)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@861D<F5S<R!B;V]K(%PB)7-<(B!W
M87,@<W5C8V5S<V9U;&QY('5P9&%T960N(BDL("1R97-U;'0I+"`G:&]R9&4N
M<W5C8V5S<R<I.PH@("`@?0H@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G861D<F5S<V)O;VMS+G!H<"<L('1R=64I
M*3L*("`@(&5X:70["GT*"B\O($=E="!A;&P@=&AE(&EN9F\@=V4@=VEL;"!N
M965D('1O(&1I<W!L87D@=&AE('!A9V4N"B1M>5-O=7)C97,@/2!A<G)A>2@I
M.PHD;7E296UO=F%B;&4@/2!A<G)A>2@I.PH*+R\@1V5T('1H92!S:&%R97,@
M;W=N960@8GD@=&AE(&-U<G)E;G0@=7-E<BP@86YD(&9I9W5R92!O=70@=VAA
M="!W92!W:6QL"B\O(&1I<W!L87D@=&AE('-H87)E(&YA;64@87,@=&\@=&AE
M('5S97(N"B1S:&%R97,@/2!4=7)B83HZ;&ES=%-H87)E<RAT<G5E*3L*9F]R
M96%C:"`H)'-H87)E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@;&ES="@D
M<W)C+"`D=7-E<BD@/2!E>'!L;V1E*"<Z)RP@)&ME>2P@,BD["B`@("!I9B`H
M)'5S97(@/3T@075T:#HZ9V5T075T:"@I*2!["B`@("`@("`@)&-F9U-R8TME
M>2`]("1S<F,["B`@("!](&5L<V4@>PH@("`@("`@("1M>5)E;6]V86)L95M=
M(#T@)&ME>3L*("`@("`@("`D8V9G4W)C2V5Y(#T@)&ME>3L*("`@('T*("`@
M("\O(%1H:7,@:7,@=&AE("=D:7-P;&%Y(&YA;64G(&]F('1H92!S:&%R92X@
M(%1H:7,@:7,@<V\@=V4@8V%N(&-A;&P@=&AE"B`@("`O+R!U<V5R)W,@;W=N
M(&1E9F%U;'0@<VAA<F4@(DUY($%D9')E<W,@0F]O:R(@*&]R('=H871E=F5R
M('1H:7,@<V]U<F-E(&ES"B`@("`O+R!C;VYF:6=U<F5D('1O(&)E(&-A;&QE
M9"!I;B`D8V9G4V]U<F-E<RD@8G5T(&1I<W!L87D@=&AE('-A;64@<VAA<F4@
M87,*("`@("\O(")5<V5R;F%M92=S($%D9')E<W,@0F]O:R(@*&]R('-I;6EL
M87(I(&EF('1H92!C=7)R96YT('5S97(@:7,@;F]T('1H90H@("`@+R\@;W=N
M97(N"B`@("`D;7E3;W5R8V5S6R1K97E=(#T@)&-F9U-O=7)C97-;)&-F9U-R
M8TME>5U;)W1I=&QE)UT["GT*"DAO<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U
M<"YJ<R<L("=H;W)D92<L('1R=64I.PHD=&ET;&4@/2!?*")->2!!9&1R97-S
M($)O;VMS(BD["G)E<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]C;VUM;VXM
M:&5A9&5R+FEN8R<["G)E<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]M96YU
M+FEN8R<["G)E<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]A9&1R97-S8F]O
M:W,N:6YC)SL*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@
M)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1U<F)A+W9I97<N<&AP````````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0V-#8`,3`T,3<S-C(W-38`,#$W
M,C,V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z('1U<F)A+W9I97<N<&AP+'8@,2XV+C(N
M,B`R,#`V+S`Q+S`Q(#(Q.C(Y.C$U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E
M<R]A<VPN<&AP+@H@*B\*"D!D969I;F4H)U154D)!7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!455)"05]"05-%("X@)R]L:6(O
M8F%S92YP:'`G.PH*:68@*"1C;VYF6R=D;V-U;65N=',G75LG='EP92==(#T]
M("=N;VYE)RD@>PH@("`@2&]R9&4Z.F9A=&%L*%\H(E1H92!61E,@8F%C:V5N
M9"!N965D<R!T;R!B92!C;VYF:6=U<F5D('1O(&5N86)L92!A='1A8VAM96YT
M('5P;&]A9',N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"B1S;W5R8V4@
M/2!5=&EL.CIG971&;W)M1&%T82@G<V]U<F-E)RD["B1K97D@/2!5=&EL.CIG
M971&;W)M1&%T82@G:V5Y)RD["B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$
M871A*"=A8W1I;VY)1"<I.PHD9FEL96YA;64@/2!5=&EL.CIG971&;W)M1&%T
M82@G9FEL92<I.PHD='EP92`](%5T:6PZ.F=E=$9O<FU$871A*"=T>7!E)RD[
M"@HO*B!'970@=&AE(&]B:F5C="X@*B\*:68@*"%I<W-E="@D8V9G4V]U<F-E
M<ULD<V]U<F-E72DI('L*("`@($AO<F1E.CIF871A;"A?*")4:&4@8V]N=&%C
M="!Y;W4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T+B(I+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PI]"B1D<FEV97(@/2`F5'5R8F%?1')I=F5R.CIS:6YG;&5T
M;VXH)'-O=7)C92D["B1O8FIE8W0@/2`D9')I=F5R+3YG971/8FIE8W0H)&ME
M>2D["FEF("AI<U]A*"1O8FIE8W0L("=014%27T5R<F]R)RDI('L*("`@($AO
M<F1E.CIF871A;"@D;V)J96-T+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"@HO
M*B!#:&5C:R!P97)M:7-S:6]N<RX@*B\*:68@*"$D;V)J96-T+3YH87-097)M
M:7-S:6]N*%!%4DU37U)%040I*2!["B`@("!(;W)D93HZ9F%T86PH7R@B66]U
M(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@=FEE=R!T:&ES(&-O;G1A8W0N
M(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"B1V7W!A<F%M<R`]($AO<F1E
M.CIG97161E-#;VYF:6<H)V1O8W5M96YT<R<I.PII9B`H:7-?82@D=E]P87)A
M;7,L("=014%27T5R<F]R)RDI('L*("`@($AO<F1E.CIF871A;"@D=E]P87)A
M;7,L(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*<F5Q=6ER95]O;F-E("=61E,N
M<&AP)SL*)'9F<R`]("961E,Z.G-I;F=L971O;B@D=E]P87)A;7-;)W1Y<&4G
M72P@)'9?<&%R86US6R=P87)A;7,G72D["FEF("AI<U]A*"1V9G,L("=014%2
M7T5R<F]R)RDI('L*("`@($AO<F1E.CIF871A;"@D=F9S+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PI](&5L<V4@>PH@("`@)&1A=&$@/2`D=F9S+3YR96%D*%15
M4D)!7U9&4U]0051(("X@)R\G("X@)&]B:F5C="T^9V5T5F%L=64H)U]?=6ED
M)RDL("1F:6QE;F%M92D["GT*:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R
M)RDI('L*("`@($AO<F1E.CIL;V=-97-S86=E*"1D871A+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("!(;W)D93HZ9F%T86PH<W!R
M:6YT9BA?*")!8V-E<W,@9&5N:65D('1O("5S(BDL("1F:6QE;F%M92DL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["GT*"B\J(%)U;B!T:')O=6=H(&%C=&EO;B!H
M86YD;&5R<R`J+PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=D;W=N;&]A
M9%]F:6QE)SH*("`@("`D8G)O=W-E<BT^9&]W;FQO861(96%D97)S*"1F:6QE
M;F%M92D["B`@("`@96-H;R`D9&%T83L*("`@("!E>&ET.PH*8V%S92`G=FEE
M=U]F:6QE)SH*("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]-86=I8RYP
M:'`G.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U9I97=E<BYP:'`G
M.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*("`@
M(')E<75I<F4@2$]21$5?0D%312`N("<O8V]N9FEG+VUI;65?9')I=F5R<RYP
M:'`G.PH@("`@<F5Q=6ER92!455)"05]"05-%("X@)R]C;VYF:6<O;6EM95]D
M<FEV97)S+G!H<"<["B`@("`D;6EM95]P87)T(#T@)FYE=R!-24U%7U!A<G0H
M34E-15]-86=I8SHZ97AT5&]-24U%*"1T>7!E*2P@)&1A=&$I.PH@("`@)&UI
M;65?<&%R="T^<V5T3F%M92@D9FEL96YA;64I.PH@("`@)'9I97=E<B`]("9-
M24U%7U9I97=E<CHZ9F%C=&]R>2@D;6EM95]P87)T*3L*"B`@("`D8F]D>2`]
M("1V:65W97(M/G)E;F1E<B@I.PH@("`@)&)R;W=S97(M/F1O=VYL;V%D2&5A
M9&5R<R@D9FEL96YA;64L("1V:65W97(M/F=E=%1Y<&4H*2P@=')U92P@<W1R
M;&5N*"1B;V1Y*2D["B`@("!E8VAO("1B;V1Y.PH@("`@97AI=#L*?0H`````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+V-O;F9I9P``````````````
M````````````````````````````````````````````````````````````
M````````,#$R,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-38`,#(U,38V`"`R+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D
M92]T=7)B80``````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O
M861D+G!H<```````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,C,P-P`Q,#0Q-S,V,C<U-@`P,3<P,#4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!4=7)B82!S8W)I<'0@=&\@861D(&$@;F5W(&5N=')Y(&EN=&\@86X@861D
M<F5S<R!B;V]K+@H@*@H@*B`D2&]R9&4Z('1U<F)A+V%D9"YP:'`L=B`Q+C4T
M+C0N,3`@,C`P-B\P,2\P,2`R,3HR.3HQ-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#`M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y3
M12!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H05-,*2X@($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D
M92YO<F<O;&EC96YS97,O87-L+G!H<"X*("HO"@I`9&5F:6YE*"=455)"05]"
M05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@5%520D%?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E(%154D)!7T)!
M4T4@+B`G+VQI8B]296YD97)E<BYP:'`G.PIR97%U:7)E7V]N8V4@5%520D%?
M0D%312`N("<O;&EB+T]B:F5C=%9I97<N<&AP)SL*<F5Q=6ER95]O;F-E(%15
M4D)!7T)!4T4@+B`G+VQI8B]/8FIE8W0N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]687)I86)L97,N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]!8W1I;VXN<&AP)SL*
M"B\J($=E="!S;VUE('9A<FEA8FQE<RX@*B\*)'9A<G,@/2`F5F%R:6%B;&5S
M.CIG971$969A=6QT5F%R:6%B;&5S*"D["B1S;W5R8V4@/2`D=F%R<RT^9V5T
M*"=S;W5R8V4G*3L*)'5R;"`]("1V87)S+3YG970H)W5R;"<I.PH*+RH@17AI
M="!W:71H(&%N(&5R<F]R(&UE<W-A9V4@:68@;F\@<V]U<F-E<R!T;R!A9&0@
M=&\N("HO"FEF("AE;7!T>2@D861D4V]U<F-E<RDI('L*("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H7R@B5&AE<F4@87)E(&YO('=R:71E86)L92!A9&1R97-S
M(&)O;VMS+B!.;VYE(&]F('1H92!A=F%I;&%B;&4@861D<F5S<R!B;V]K<R!A
M<F4@8V]N9FEG=7)E9"!T;R!A;&QO=R!Y;W4@=&\@861D(&YE=R!E;G1R:65S
M('1O('1H96TN($EF('EO=2!B96QI979E('1H:7,@:7,@86X@97)R;W(L('!L
M96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@)'5R;"`]("@A96UP='DH)'5R;"D@/R!(;W)D
M93HZ=7)L*"1U<FPL('1R=64I(#H@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=I
M;F1E>"YP:'`G+"!T<G5E*2D["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@
M)'5R;"D["B`@("!E>&ET.PI]"@HO*B!3970@=7`@=&AE(&9O<FTN("HO"B1F
M;W)M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G)RP@)'9A<G,L(%\H(DYE
M=R!#;VYT86-T(BDI.PHD9F]R;2T^<V5T0G5T=&]N<RA?*")3879E(BDL(%\H
M(E)E<V5T('1O($1E9F%U;'1S(BDI.PHD9F]R;2T^861D2&ED9&5N*"<G+"`G
M=7)L)RP@)W1E>'0G+"!F86QS92D["B1F;W)M+3YA9&1(:61D96XH)R<L("=K
M97DG+"`G=&5X="<L(&9A;'-E*3L*"B\J($-H96-K(&EF(&$@<V]U<F-E('-E
M;&5C=&EO;B!B;W@@:7,@<F5Q=6ER960N("HO"FEF("AC;W5N="@D861D4V]U
M<F-E<RD@/B`Q*2!["B`@("`O*B!-=6QT:7!L92!S;W5R8V5S+"!S:&]W(&$@
M<V5L96-T:6]N(&)O>"X@*B\*("`@("1O<'1I;VYS(#T@87)R87DH*3L*("`@
M(&9O<F5A8V@@*"1A9&13;W5R8V5S(&%S("1K97D@/3X@)&-O;F9I9RD@>PH@
M("`@("`@("1O<'1I;VYS6R1K97E=(#T@)&-O;F9I9ULG=&ET;&4G73L*("`@
M('T*("`@("1V(#T@)B1F;W)M+3YA9&1687)I86)L92A?*")#:&]O<V4@86X@
M861D<F5S<R!B;V]K(BDL("=S;W5R8V4G+"`G96YU;2<L('1R=64L(&9A;'-E
M+"!N=6QL+"!A<G)A>2@D;W!T:6]N<RP@=')U92DI.PH@("`@)&%C=&EO;B`]
M("9(;W)D95]&;W)M7T%C=&EO;CHZ9F%C=&]R>2@G<W5B;6ET)RD["B`@("`D
M=BT^<V5T06-T:6]N*"1A8W1I;VXI.PH@("`@)'8M/G-E=$]P=&EO;B@G=')A
M8VMC:&%N9V4G+"!T<G5E*3L*("`@(&EF("AI<U]N=6QL*"1V87)S+3YG970H
M)V9O<FUN86UE)RDI("8F"B`@("`@("`@)'9A<G,M/F=E="@D=BT^9V5T5F%R
M3F%M92@I*2`A/2`D=F%R<RT^9V5T*"=?7V]L9%\G("X@)'8M/F=E=%9A<DYA
M;64H*2DI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B4V5L96-T960@861D<F5S<R!B;V]K(%PB)7-<(BXB*2P@)&%D9%-O=7)C
M97-;)'-O=7)C95U;)W1I=&QE)UTI+"`G:&]R9&4N;65S<V%G92<I.PH@("`@
M?0H@("`@)&9O<FTM/G-E=$)U='1O;G,H7R@B061D(BDI.PI](&5L<V4@>PH@
M("`@+RH@3VYE('-O=7)C92P@;F\@<V5L96-T:6]N(&)O>"!B=70@<W1O<F4@
M=&AE('9A;'5E(&EN(&$@:&ED9&5N(&9I96QD+B`J+PH@("`@)&9O<FTM/F%D
M9$AI9&1E;B@G)RP@)W-O=7)C92<L("=T97AT)RP@=')U92D["B`@("`D<V]U
M<F-E(#T@:V5Y*"1A9&13;W5R8V5S*3L*?0H*+RH@02!S;W5R8V4@:&%S(&)E
M96X@<V5L96-T960L(&-O;FYE8W0@86YD('-E="!U<"!T:&4@9FEE;&1S+B`J
M+PII9B`H)'-O=7)C92D@>PH@("`@)&1R:79E<B`]("94=7)B85]$<FEV97(Z
M.G-I;F=L971O;B@D<V]U<F-E*3L*("`@(&EF("AI<U]A*"1D<FEV97(L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P
M<FEN=&8H7R@B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B;V]K.B`E
M<R(I+"`D9')I=F5R+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*
M("`@('T@96QS92!["B`@("`@("`@+RH@0VAE8VL@<&5R;6ES<VEO;G,N("HO
M"B`@("`@("`@)&UA>%]C;VYT86-T<R`](%1U<F)A.CIH87-097)M:7-S:6]N
M*"1S;W5R8V4@+B`G.FUA>%]C;VYT86-T<R<L("=S;W5R8V4G*3L*("`@("`@
M("!I9B`H)&UA>%]C;VYT86-T<R`A/3T@=')U92`F)@H@("`@("`@("`@("`D
M;6%X7V-O;G1A8W1S(#P]("1D<FEV97(M/F-O=6YT0V]N=&%C=',H*2D@>PH@
M("`@("`@("`@("`D;65S<V%G92`]($!H=&UL<W!E8VEA;&-H87)S*'-P<FEN
M=&8H7R@B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&-O;G1A8W1S(&EN(%PB)7-<(BXB*2P@)&UA>%]C;VYT86-T<RP@)&-F
M9U-O=7)C97-;)'-O=7)C95U;)W1I=&QE)UTI+"!%3E1?0T]-4$%4+"!.3%,Z
M.F=E=$-H87)S970H*2D["B`@("`@("`@("`@(&EF("@A96UP='DH)&-O;F9;
M)VAO;VMS)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@("`@("`@("`@("`D
M;65S<V%G92`]($AO<F1E.CIC86QL2&]O:R@G7W!E<FUS7VAO;VM?9&5N:65D
M)RP@87)R87DH)W1U<F)A.FUA>%]C;VYT86-T<R<I+"`G:&]R9&4G+"`D;65S
M<V%G92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"@D;65S<V%G92P@)VAO<F1E+F5R<F]R)RP@87)R87DH)V-O;G1E
M;G0N<F%W)RDI.PH@("`@("`@("`@("`D=7)L(#T@*"%E;7!T>2@D=7)L*2`_
M($AO<F1E.CIU<FPH)'5R;"P@=')U92D@.B!(;W)D93HZ87!P;&EC871I;VY5
M<FPH)VEN9&5X+G!H<"<L('1R=64I*3L*("`@("`@("`@("`@:&5A9&5R*"=,
M;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@
M('T*"B`@("`@("`@)&]B:F5C="`]("9N97<@5'5R8F%?3V)J96-T*"1D<FEV
M97(I.PH@("`@("`@("1V:65W(#T@)FYE=R!4=7)B85]/8FIE8W16:65W*"1O
M8FIE8W0I.PH*("`@("`@("`O*B!'970@=&AE(&9O<FT@86YD('-E="!U<"!T
M:&4@=F%R:6%B;&5S+B`J+PH@("`@("`@("1V:65W+3YS971U<$9O<FTH)&9O
M<FTI.PH@("`@("`@("1V87)S+3YS970H)W-O=7)C92<L("1S;W5R8V4I.PH@
M("`@?0I]"@HO*B!686QI9&%T92!T:&4@9F]R;2X@*B\*:68@*"1S;W5R8V4@
M)B8@)&9O<FTM/G9A;&ED871E*"1V87)S*2D@>PH@("`@+RH@1F]R;2!V86QI
M9"P@<V%V92!D871A+B`J+PH@("`@)&9O<FTM/F=E=$EN9F\H)'9A<G,L("1I
M;F9O*3L*("`@("1S;W5R8V4@/2`D:6YF;ULG<V]U<F-E)UT["B`@("`D;V)J
M96-T(#T@)&EN9F];)V]B:F5C="==.PH*("`@("\J($=E="!S:&%R92!I;F9O
M<FUA=&EO;BX@*B\*("`@(&EF("@D9')I=F5R+3YU<VEN9U-H87)E<RD@>PH@
M("`@("`@("1O8FIE8W1;)U]?;W=N97(G72`]("1D<FEV97(M/G-H87)E+3YG
M970H)W5I9"<I.PH@("`@?0H*("`@("\J($-R96%T92!#;VYT86-T+B`J+PH@
M("`@)&ME>2`]("1D<FEV97(M/F%D9"@D;V)J96-T*3L*("`@(&EF("@A:7-?
M82@D:V5Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)'9A<G,M/G-E="@G
M:V5Y)RP@)&ME>2D["B`@("`@("`@)&YA;64@/2!I<W-E="@D;V)J96-T6R=N
M86UE)UTI(#\@)&]B:F5C=%LG;F%M92==(#H@7R@B061D<F5S<R!B;V]K(&5N
M=')Y(BD["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H
M(B5S(&%D9&5D+B(I+"`D;F%M92DL("=H;W)D92YS=6-C97-S)RD["B`@("`@
M("`@:68@*&5M<'1Y*"1I;F9O6R=U<FPG72DI('L*("`@("`@("`@("`@)'5R
M:2`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9&ES<&QA>2YP:'`G+"!T<G5E
M*3L*("`@("`@("`@("`@)'5R:2`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)I
M+"!A<G)A>2@G<V]U<F-E)R`]/B`D:6YF;ULG<V]U<F-E)UTL("=K97DG(#T^
M("1K97DI+"!N=6QL+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'5R:2`]("1I;F9O6R=U<FPG73L*("`@("`@("!]"B`@("`@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FDI.PH@("`@("`@(&5X:70["B`@
M("!]"@H@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&ME>2P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"A?*")4:&5R92!W87,@86X@97)R;W(@861D:6YG('1H92!N97<@8V]N=&%C
M="X@0V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R(&9O<B!F=7)T
M:&5R(&AE;'`N(BD@+B`D:V5Y+3YG971-97-S86=E*"DL("=H;W)D92YE<G)O
M<B<I.PI]"@HD=&ET;&4@/2!?*").97<@0V]N=&%C="(I.PIR97%U:7)E(%15
M4D)!7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E
M(%154D)!7U1%35!,051%4R`N("<O;65N=2YI;F,G.PH*+RH@4F5N9&5R('1H
M92!F;W)M+B`J+PHD<F5N9&5R97(@/2`F;F5W(%1U<F)A7U)E;F1E<F5R*"D[
M"B1F;W)M+3YR96YD97)!8W1I=F4H)')E;F1E<F5R+"`D=F%R<RP@)V%D9"YP
M:'`G+"`G<&]S="<I.PH*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA
M=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O=F-A<F0N<&AP````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$P,``Q,#0Q-S,V
M,C<U-@`P,3<S-#,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@='5R8F$O=F-A<F0N<&AP
M+'8@,2XQ,BXQ,"XT(#(P,#8O,#$O,#$@,C$Z,CDZ,34@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$%33"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S;"YP:'`N"B`J+PH*0&1E9FEN92@G
M5%520D%?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E
M(%154D)!7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92!4
M55)"05]"05-%("X@)R]L:6(O4F5N9&5R97(N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]&;W)M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1&%T82YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*)'9A
M<G,@/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R:6%B;&5S*"D["@HD<V]U
M<F-E(#T@)'9A<G,M/F=E="@G<V]U<F-E)RD["FEF("@A:7-S970H)&-F9U-O
M=7)C97-;)'-O=7)C95TI*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H
M(E1H92!C;VYT86-T('EO=2!R97%U97-T960@9&]E<R!N;W0@97AI<W0N(BDL
M("=H;W)D92YE<G)O<B<I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@D<')E9G,M/F=E=%9A;'5E*"=I;FET:6%L
M7W!A9V4G*2P@=')U92DI.PH@("`@97AI=#L*?0H*)&1R:79E<B`]("94=7)B
M85]$<FEV97(Z.G-I;F=L971O;B@D<V]U<F-E*3L*"B\J(%-E="!T:&4@8V]N
M=&%C="!F<F]M('1H92!K97D@<F5Q=65S=&5D+B`J+PHD:V5Y(#T@)'9A<G,M
M/F=E="@G:V5Y)RD["B1O8FIE8W0@/2`D9')I=F5R+3YG971/8FIE8W0H)&ME
M>2D["FEF("AI<U]A*"1O8FIE8W0L("=014%27T5R<F]R)RDI('L*("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H)&]B:F5C="T^9V5T365S<V%G92@I+"`G:&]R
M9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)'!R969S+3YG971686QU92@G:6YI=&EA;%]P86=E
M)RDL('1R=64I*3L*("`@(&5X:70["GT*"B\J($-H96-K('!E<FUI<W-I;VYS
M(&]N('1H:7,@8V]N=&%C="X@*B\*:68@*"$D;V)J96-T+3YH87-097)M:7-S
M:6]N*%!%4DU37U)%040I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H
M(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O('9I97<@=&AI<R!O8FIE
M8W0N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@
M)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D<')E9G,M/F=E=%9A;'5E*"=I
M;FET:6%L7W!A9V4G*2P@=')U92DI.PH@("`@97AI=#L*?0H*)'9C87)D(#T@
M)DAO<F1E7T1A=&$Z.G-I;F=L971O;B@G=F-A<F0G*3L*)'9C87)D+3YE>'!O
M<G1&:6QE*%\H(F-O;G1A8W0N=F-F(BDL(&%R<F%Y*"1D<FEV97(M/G1O=D-A
M<F0H)&]B:F5C="DI+"!.3%,Z.F=E=$-H87)S970H*2D["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1U<F)A+W1E<W0N<&AP````````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(P-S0`,3`T,3<S-C(W-38`
M,#$W,C,U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z('1U<F)A+W1E<W0N<&AP+'8@,2XY
M+C$P+C0@,C`P-B\P,2\P,2`R,3HR.3HQ-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#`M,C`P-B!"<F5N="!*+B!.;W)D<75I<W0@/&)J;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R
M9R]L:6-E;G-E<R]A<VPN<&AP+@H@*B\*"B\J($EN8VQU9&4@2&]R9&4G<R!C
M;W)E+G!H<"!F:6QE+B`J+PII;F-L=61E7V]N8V4@)RXN+VQI8B]C;W)E+G!H
M<"<["@HO*B!792!S:&]U;&0@:&%V92!L;V%D960@=&AE(%-T<FEN9R!C;&%S
M<RP@9G)O;2!T:&4@2&]R9&5?571I;`H@*B!P86-K86=E+"!I;B!C;W)E+G!H
M<"X@268@4W1R:6YG.CH@:7-N)W0@9&5F:6YE9"P@=&AE;B!W92=R92!N;W0*
M("H@9FEN9&EN9R!S;VUE(&-R:71I8V%L(&QI8G)A<FEE<RX@*B\*:68@*"%C
M;&%S<U]E>&ES=',H)U-T<FEN9R<I*2!["B`@("!E8VAO("<\8G(@+SX\<W!A
M;B!S='EL93TB8V]L;W(Z(')E9#L@9F]N="US:7IE.B`Q.'!X.R!F;VYT+7=E
M:6=H=#H@8F]L9#LB/E1H92!(;W)D95]5=&EL('!A8VMA9V4@=V%S(&YO="!F
M;W5N9"X@268@4$A07"=S(&5R<F]R7W)E<&]R=&EN9R!S971T:6YG(&ES(&AI
M9V@@96YO=6=H+"!T:&5R92!S:&]U;&0@8F4@97)R;W(@;65S<V%G97,@<')I
M;G1E9"!A8F]V92!T:&%T(&UA>2!H96QP('EO=2!I;B!D96)U9V=I;F<@=&AE
M('!R;V)L96TN($EF('EO=2!A<F4@<VEM<&QY(&UI<W-I;F<@=&AE<V4@9FEL
M97,L('1H96X@>6]U(&YE960@=&\@9V5T('1H92`\82!H<F5F/2)H='1P.B\O
M8W9S+FAO<F1E+F]R9R]C=G,N<&AP+V9R86UE=V]R:R(^9G)A;65W;W)K/"]A
M/B!M;V1U;&4@9G)O;2`\82!H<F5F/2)H='1P.B\O:&]R9&4N;W)G+W-O=7)C
M92\B/DAO<F1E($-64SPO83XL(&%N9"!I;G-T86QL('1H92!P86-K86=E<R!I
M;B!I="!W:71H('1H92!I;G-T86QL+7!A8VMA9V5S+G!H<"!S8W)I<'0N/"]S
M<&%N/B<["B`@("!E>&ET.PI]"@HO*B!);FET:6%L:7IE('1H92!(;W)D95]4
M97-T.CH@8VQA<W,N("HO"FEF("@A*$!I<U]R96%D86)L92@G+BXO;&EB+U1E
M<W0N<&AP)RDI*2!["B`@("!E8VAO("=%4E)/4CH@66]U(&UU<W0@:6YS=&%L
M;"!(;W)D92!B969O<F4@<G5N;FEN9R!T:&ES('-C<FEP="XG.PH@("`@97AI
M=#L*?0IR97%U:7)E7V]N8V4@)RXN+VQI8B]497-T+G!H<"<["B1H;W)D95]T
M97-T(#T@)FYE=R!(;W)D95]497-T.PH*+RH@5'5R8F$@=F5R<VEO;BX@*B\*
M)&UO9'5L92`]("=4=7)B82<["G)E<75I<F5?;VYC92`G+B]L:6(O=F5R<VEO
M;BYP:'`G.PHD;6]D=6QE7W9E<G-I;VX@/2!455)"05]615)324]..PH*<F5Q
M=6ER92!415-47U1%35!,051%4R`N("=H96%D97(N:6YC)SL*<F5Q=6ER92!4
M15-47U1%35!,051%4R`N("=V97)S:6]N+FEN8R<["@HO*B!$:7-P;&%Y(%!(
M4"!697)S:6]N(&EN9F]R;6%T:6]N+B`J+PHD<&AP7VEN9F\@/2`D:&]R9&5?
M=&5S="T^9V5T4&AP5F5R<VEO;DEN9F]R;6%T:6]N*"D["G)E<75I<F4@5$53
M5%]414U03$%415,@+B`G<&AP7W9E<G-I;VXN:6YC)SL*"B\J(%!(4"!M;V1U
M;&5S+B`J+PHD;6]D=6QE7VQI<W0@/2!A<G)A>2@*("`@("=M>7-Q;"<@/3X@
M)TUY4U%,(%-U<'!O<G0G+`H@("`@)W!G<W%L)R`]/B`G4&]S=&=R95-13"!3
M=7!P;W)T)RP*("`@("=M<W-Q;"<@/3X@)TUI8W)O<V]F="!344P@4W5P<&]R
M="<L"B`@("`G;V-I."<@/3X@)T]R86-L92!3=7!P;W)T)RP*("`@("=O9&)C
M)R`]/B`G56YI9FEE9"!/1$)#(%-U<'!O<G0G+`H@("`@)VQD87`G(#T^("=,
M1$%0(%-U<'!O<G0G"BD["@HO*B!'970@=&AE('-T871U<R!O=71P=70@;F]W
M+B`J+PHD;6]D=6QE7V]U='!U="`]("1H;W)D95]T97-T+3YP:'!-;V1U;&5#
M:&5C:R@D;6]D=6QE7VQI<W0I.PH*/SX*"CQH,3Y02%`@36]D=6QE($-A<&%B
M:6QI=&EE<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)&UO9'5L95]O=71P
M=70@/SX*/"]U;#X*"CQH,3Y02%`@3$1!4"!3=7!P;W)T(%1E<W0\+V@Q/@H\
M/W!H<`H*)'-E<G9E<B`](&ES<V5T*"1?4$]35%LG<V5R=F5R)UTI(#\@)%]0
M3U-46R=S97)V97(G72`Z("<G.R`O+R`G<V5R=F5R+F5X86UP;&4N8V]M)SL*
M)'!O<G0@/2!I<W-E="@D7U!/4U1;)W!O<G0G72D@/R`D7U!/4U1;)W!O<G0G
M72`Z("<G.R`O+R`G,S@Y)SL*)&)A<V5D;B`](&ES<V5T*"1?4$]35%LG8F%S
M961N)UTI(#\@)%]03U-46R=B87-E9&XG72`Z("<G.R`O+R`G9&,]97AA;7!L
M92QD8SUC;VTG.PHD=7-E<B`](&ES<V5T*"1?4$]35%LG=7-E<B==*2`_("1?
M4$]35%LG=7-E<B==(#H@)R<[("`@("`O+R`G=7-E<B<["B1P87-S=V0@/2!I
M<W-E="@D7U!/4U1;)W!A<W-W9"==*2`_("1?4$]35%LG<&%S<W=D)UT@.B`G
M)SL@+R\@)W!A<W-W;W)D)SL*)&9I;'1E<B`](&ES<V5T*"1?4$]35%LG9FEL
M=&5R)UTI(#\@)%]03U-46R=F:6QT97(G72`Z("<G.R`O+R`G8VX]0F%B<R!*
M96YS96XG.PH*:68@*"%E;7!T>2@D<V5R=F5R*2`F)B`A96UP='DH)&)A<V5D
M;BD@)B8@(65M<'1Y*"1F:6QT97(I*2!["B`@("!I9B`H96UP='DH)'!O<G0I
M*2!["B`@("`@("`@)'!O<G0@/2`G,S@Y)SL*("`@('T*("`@(&5C:&\@)W-E
M<G9E<CTB)RP@)'-E<G9E<BP@)R(@8F%S961N/2(G+"`D8F%S961N+"`G(B!F
M:6QT97(](B<L("1F:6QT97(L("<B/&)R("\^)SL*("`@(&EF("@D=7-E<BD@
M>PH@("`@("`@(&5C:&\@)V)I;F0@87,@=7-E<CTB)RP@)'5S97(L("<B/&)R
M("\^)SL*("`@('T@96QS92!["B`@("`@("`@96-H;R`G8FEN9"!A;F]N>6UO
M=7-L>3QB<B`O/B<["B`@("!]"B`@("`D;&1A<"`](&QD87!?8V]N;F5C="@D
M<V5R=F5R+"`D<&]R="D["B`@("!I9B`H)&QD87`I('L*("`@("`@("!I9B`H
M(65M<'1Y*"1U<V5R*2`F)B`A;&1A<%]B:6YD*"1L9&%P+"`D=7-E<BP@)'!A
M<W-W9"DI('L*("`@("`@("`@("`@96-H;R`B/'`^=6YA8FQE('1O(&)I;F0@
M87,@)'5S97(@=&\@3$1!4"!S97)V97(\+W`^7&XB.PH@("`@("`@("`@("!L
M9&%P7V-L;W-E*"1L9&%P*3L*("`@("`@("`@("`@)&QD87`@/2`G)SL*("`@
M("`@("!](&5L<V5I9B`H96UP='DH)'5S97(I("8F("%L9&%P7V)I;F0H)&QD
M87`I*2!["B`@("`@("`@("`@(&5C:&\@(CQP/G5N86)L92!T;R!B:6YD(&%N
M;VYY;6]U<VQY('1O($Q$05`@<V5R=F5R/"]P/EQN(CL*("`@("`@("`@("`@
M;&1A<%]C;&]S92@D;&1A<"D["B`@("`@("`@("`@("1L9&%P(#T@)R<["B`@
M("`@("`@?0H@("`@("`@(&EF("@D;&1A<"D@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@;&1A<%]S96%R8V@H)&QD87`L("1B87-E9&XL("1F:6QT97(I.PH@
M("`@("`@("`@("!I9B`H)')E<W5L="D@>PH@("`@("`@("`@("`@("`@96-H
M;R`G/'`^<V5A<F-H(')E='5R;F5D("<@+B!L9&%P7V-O=6YT7V5N=')I97,H
M)&QD87`L("1R97-U;'0I("X@(B!E;G1R:65S/"]P/EQN(CL*("`@("`@("`@
M("`@("`@("1I;F9O(#T@;&1A<%]G971?96YT<FEE<R@D;&1A<"P@)')E<W5L
M="D["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:6YF;ULG
M8V]U;G0G73L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@)SQP
M/F1N(&ES.B`G("X@)&EN9F];)&E=6R=D;B==("X@)SQB<B`O/B<["B`@("`@
M("`@("`@("`@("`@("`@96-H;R`G9FER<W0@8VX@96YT<GD@:7,Z("<@+B`D
M:6YF;ULD:5U;)V-N)UU;,%T@+B`G/&)R("\^)SL*("`@("`@("`@("`@("`@
M("`@("!E8VAO("=F:7)S="!M86EL(&5N=')Y(&ES.B`G("X@)&EN9F];)&E=
M6R=M86EL)UU;,%T@+B`G/"]P/B<["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1I(#X](#$P*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)SQP
M/BAO;FQY(&9I<G-T(#$P(&5N=')I97,@9&ES<&QA>65D*3PO<#XG.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!E8VAO("<\<#YU;F%B;&4@=&\@<V5A<F-H($Q$05`@
M<V5R=F5R/"]P/B<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!](&5L
M<V4@>PH@("`@("`@(&5C:&\@)SQP/G5N86)L92!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R/"]P/B<["B`@("!]"GT@96QS92!["B`@("`_/@H\9F]R;2!N
M86UE/2)F;W)M,2(@;65T:&]D/2)P;W-T(B!A8W1I;VX](G1E<W0N<&AP(CX*
M/'1A8FQE/@H\='(^/'1D(&%L:6=N/2)R:6=H="(^4V5R=F5R/"]T9#X\=&0^
M/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G-E<G9E<B(@+SX\+W1D/CPO='(^
M"CQT<CX\=&0@86QI9VX](G)I9VAT(CY0;W)T/"]T9#X\=&0^/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](G!O<G0B("\^/"]T9#X\=&0^*&1E9F%U;'1S('1O
M("(S.#DB*3PO=&0^/"]T<CX*/'1R/CQT9"!A;&EG;CTB<FEG:'0B/D)A<V4@
M1$X\+W1D/CQT9#X\:6YP=70@='EP93TB=&5X="(@;F%M93TB8F%S961N(B`O
M/CPO=&0^/'1D/BAE+F<N(")D8SUE>&%M<&QE+&1C/6-O;2(I/"]T9#X\+W1R
M/@H\='(^/'1D(&%L:6=N/2)R:6=H="(^57-E<CPO=&0^/'1D/CQI;G!U="!T
M>7!E/2)T97AT(B!N86UE/2)U<V5R(B`O/CPO=&0^/'1D/BAL96%V92!B;&%N
M:R!F;W(@86YO;GEM;W5S*3PO=&0^/"]T<CX*/'1R/CQT9"!A;&EG;CTB<FEG
M:'0B/E!A<W-W;W)D/"]T9#X\=&0^/&EN<'5T('1Y<&4](G!A<W-W;W)D(B!N
M86UE/2)P87-S=V0B("\^/"]T9#X\+W1R/@H\='(^/'1D(&%L:6=N/2)R:6=H
M="(^1FEL=&5R/"]T9#X\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F9I
M;'1E<B(@+SX\+W1D/CQT9#XH92YG+B`B8VX]0F%B<R!*96YS96XB*3PO=&0^
M/"]T<CX*/'1R/CQT9#X\+W1D/CQT9#X\:6YP=70@='EP93TB<W5B;6ET(B!N
M86UE/2)F7W-U8FUI="(@=F%L=64](E-U8FUI="(@+SX\:6YP=70@='EP93TB
M<F5S970B(&YA;64](F9?<F5S970B('9A;'5E/2)297-E="(@+SX\+W1D/CPO
M='(^"CPO=&%B;&4^"CPO9F]R;3X*/#]P:'`@?2`_/@H*/"]T9#X\+W1R/@H\
M+W1A8FQE/@H*/#]P:'`*<F5Q=6ER92!415-47U1%35!,051%4R`N("=F;V]T
M97(N:6YC)SL*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1U<F)A+W-E
M87)C:"YP:'``````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#<T,#8`,3`T,3<S-C(W-38`,#$W-3(V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z('1U<F)A+W-E87)C:"YP:'`L=B`Q+CDT+C0N.2`R,#`V+S`Q+S`Q(#(Q
M.C(Y.C$U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($-H
M87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A!4TPI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN
M<&AP+@H@*B\*"D!D969I;F4H)U154D)!7T)!4T4G+"!D:7)N86UE*%]?1DE,
M15]?*2D["G)E<75I<F5?;VYC92!455)"05]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+TQI<W0N<&AP
M)SL*<F5Q=6ER95]O;F-E(%154D)!7T)!4T4@+B`G+VQI8B],:7-T5FEE=RYP
M:'`G.PIR97%U:7)E7V]N8V4@5%520D%?0D%312`N("<O;&EB+T]B:F5C="YP
M:'`G.PH*+RH@5F5R:69Y(&EF('1H92!S96%R8V@@;6]D92!V87)I86)L92!I
M<R!P87-S960@:6X@9F]R;2!O<B!I<PH@*B!R96=I<W1E<F5D(&EN('1H92!S
M97-S:6]N+B!!;'=A>7,@=7-E(&)A<VEC('-E87)C:"!B>2!D969A=6QT("HO
M"FEF("A5=&EL.CIG971&;W)M1&%T82@G<V5A<F-H7VUO9&4G*2D@>PH@("`@
M)%]315-324].6R=T=7)B85]S96%R8VA?;6]D92==(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W-E87)C:%]M;V1E)RD["GT*:68@*"%I<W-E="@D7U-%4U-)3TY;
M)W1U<F)A7W-E87)C:%]M;V1E)UTI*2!["B`@("`D7U-%4U-)3TY;)W1U<F)A
M7W-E87)C:%]M;V1E)UT@/2`G8F%S:6,G.PI]"@HO*B!2=6X@<V5A<F-H(&EF
M('1H97)E(&ES(&]N92X@*B\*)'-O=7)C92`](%5T:6PZ.F=E=$9O<FU$871A
M*"=S;W5R8V4G+"!4=7)B83HZ9V5T1&5F875L=$%D9')E<W-";V]K*"DI.PII
M9B`H(6ES<V5T*"1C9F=3;W5R8V5S6R1S;W5R8V5=*2D@>PH@("`@<F5S970H
M)&-F9U-O=7)C97,I.PH@("`@)'-O=7)C92`](&ME>2@D8V9G4V]U<F-E<RD[
M"GT*"B1C<FET97)I82`](%5T:6PZ.F=E=$9O<FU$871A*"=C<FET97)I82<I
M.PHD=F%L(#T@571I;#HZ9V5T1F]R;41A=&$H)W9A;"<I.PHD9')I=F5R(#T@
M)E1U<F)A7T1R:79E<CHZ<VEN9VQE=&]N*"1S;W5R8V4I.PII9B`H:7-?82@D
M9')I=F5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*'-P<FEN=&8H7R@B1F%I;&5D('1O(&%C8V5S<R!T:&4@861D<F5S<R!B
M;V]K.B`E<R(I+"`D9')I=F5R+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R
M;W(G*3L*("`@("1M87`@/2!A<G)A>2@I.PI](&5L<V4@>PH@("`@)&UA<"`]
M("1D<FEV97(M/F=E=$-R:71E<FEA*"D["@H@("`@:68@*"1?4T534TE/3ELG
M='5R8F%?<V5A<F-H7VUO9&4G72`]/2`G861V86YC960G*2!["B`@("`@("`@
M)&-R:71E<FEA(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D;6%P(&%S
M("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@D:V5Y("$]("=?
M7VME>2<I('L*("`@("`@("`@("`@("`@("1V86P@/2!5=&EL.CIG971&;W)M
M1&%T82@D:V5Y*3L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'9A;"DI
M('L*("`@("`@("`@("`@("`@("`@("`D8W)I=&5R:6%;)&ME>5T@/2`D=F%L
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@(&EF("@H:7-?87)R87DH)&-R:71E<FEA*2`F)B!C;W5N="@D
M8W)I=&5R:6$I*2!\?"`A96UP='DH)'9A;"DI('L*("`@("`@("!I9B`H*"1?
M4T534TE/3ELG='5R8F%?<V5A<F-H7VUO9&4G72`]/2`G8F%S:6,G("8F"B`@
M("`@("`@("`@("!I<U]O8FIE8W0H)')E<W5L=',@/2`D9')I=F5R+3YS96%R
M8V@H87)R87DH)&-R:71E<FEA(#T^("1V86PI*2DI('Q\"B`@("`@("`@("`@
M("@D7U-%4U-)3TY;)W1U<F)A7W-E87)C:%]M;V1E)UT@/3T@)V%D=F%N8V5D
M)R`F)@H@("`@("`@("`@("`@:7-?;V)J96-T*"1R97-U;'1S(#T@)&1R:79E
M<BT^<V5A<F-H*"1C<FET97)I82DI*2D@>PH*("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L=',L("=H;W)D92YE<G)O<B<I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@4F5A
M9"!T:&4@8V]L=6UN<R!T;R!D:7-P;&%Y(&9R;VT@=&AE('!R969E<F5N8V5S
M+@H@("`@("`@("`@("`@("`@)'-O=7)C97,@/2!4=7)B83HZ9V5T0V]L=6UN
M<R@I.PH@("`@("`@("`@("`@("`@)&-O;'5M;G,@/2!I<W-E="@D<V]U<F-E
M<ULD<V]U<F-E72D@/R`D<V]U<F-E<ULD<V]U<F-E72`Z(&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("`D<V]R=&-O;'5M;B`]("@D<')E9G,M/F=E=%9A;'5E
M*"=S;W)T8GDG*2`]/2`P('Q\"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`A:7-S970H)&-O;'5M;G-;)'!R969S+3YG971686QU92@G<V]R=&)Y
M)RD@+2`Q72DI"B`@("`@("`@("`@("`@("`@("`@/R`H*"1P<F5F<RT^9V5T
M5F%L=64H)VYA;65?9F]R;6%T)RD@/3T@)V9I<G-T7VQA<W0G*0H@("`@("`@
M("`@("`@("`@("`@("`@(#\@)VYA;64G"B`@("`@("`@("`@("`@("`@("`@
M("`@.B`G;&%S=&YA;64G*0H@("`@("`@("`@("`@("`@("`@(#H@)&-O;'5M
M;G-;)'!R969S+3YG971686QU92@G<V]R=&)Y)RD@+2`Q73L*"B`@("`@("`@
M("`@("`@("`D<F5S=6QT<RT^<V]R="@D<V]R=&-O;'5M;BP@)'!R969S+3YG
M971686QU92@G<V]R=&1I<B<I*3L*"B`@("`@("`@("`@("`@("`D=FEE=R`]
M("9N97<@5'5R8F%?3&ES=%9I97<H)')E<W5L=',I.PH@("`@("`@("`@("`@
M("`@)'9I97<M/G-E=%1Y<&4H)W-E87)C:"<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"A?*")&86EL960@=&\@<V5A<F-H('1H92!A9&1R97-S(&)O;VLB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@?0H@("`@?0I]"@II9B`H)%]315-324].
M6R=T=7)B85]S96%R8VA?;6]D92==(#T]("=B87-I8R<I('L*("`@("1T:71L
M92`](%\H(D)A<VEC(%-E87)C:"(I.PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"@G9&]C=6UE;G0N9&ER96-T;W)Y7W-E87)C:"YV86PN9F]C=7,H*3LG+"`G
M:F%V87-C<FEP="<I.PI](&5L<V4@>PH@("`@)'1I=&QE(#T@7R@B061V86YC
M960@4V5A<F-H(BD["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"=D;V-U;65N
M="YD:7)E8W1O<GE?<V5A<F-H+FYA;64N9F]C=7,H*3LG+"`G:F%V87-C<FEP
M="<I.PI]"@IR97%U:7)E(%154D)!7U1%35!,051%4R`N("<O8V]M;6]N+6AE
M861E<BYI;F,G.PIR97%U:7)E(%154D)!7U1%35!,051%4R`N("<O;65N=2YI
M;F,G.PIR97%U:7)E(%154D)!7U1%35!,051%4R`N("<O8G)O=W-E+W-E87)C
M:"YI;F,G.PII9B`H)%]315-324].6R=T=7)B85]S96%R8VA?;6]D92==(#T]
M("=A9'9A;F-E9"<I('L*("`@(')E<75I<F4@5%520D%?5$5-4$Q!5$53("X@
M)R]B<F]W<V4O<V5A<F-H7V-R:71E<FEA+FEN8R<["GT*:68@*&ES<V5T*"1V
M:65W*2`F)B!I<U]O8FIE8W0H)'9I97<I*2!["B`@("!R97%U:7)E(%154D)!
M7U1%35!,051%4R`N("<O8G)O=W-E+VIA=F%S8W)I<'0N:6YC)SL*("`@(')E
M<75I<F4@5%520D%?5$5-4$Q!5$53("X@)R]B<F]W<V4O:&5A9&5R+FEN8R<[
M"B`@("`D=FEE=RT^9&ES<&QA>2@I.PI]"G)E<75I<F4@)')E9VES=')Y+3YG
M970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN
M8R<["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1U<F)A+VUI;FES96%R8V@N<&AP````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4V-3,`,3`T,3<S-C(W-38`,#(P
M-#`U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z('1U<F)A+VUI;FES96%R8V@N<&AP+'8@
M,2XR,"XT+C<@,C`P-B\P,B\Q."`P,SHS,CHT-B!C:'5C:R!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,
M24-%3E-%(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A!4TPI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]L:6-E;G-E<R]A<VPN<&AP+@H@*B\*"D!D969I;F4H)U15
M4D)!7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!4
M55)"05]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*)'-E87)C:"`](%5T:6PZ
M.F=E=$9O<FU$871A*"=S96%R8V@G*3L*)')E<W5L=',@/2!A<G)A>2@I.PH*
M+R\@36%K92!S=7)E('=E(&AA=F4@82!S;W5R8V4N"B1S;W5R8V4@/2!5=&EL
M.CIG971&;W)M1&%T82@G<V]U<F-E)RP@5'5R8F$Z.F=E=$1E9F%U;'1!9&1R
M97-S0F]O:R@I*3L*:68@*"%I<W-E="@D8V9G4V]U<F-E<ULD<V]U<F-E72DI
M('L*("`@(')E<V5T*"1C9F=3;W5R8V5S*3L*("`@("1S;W5R8V4@/2!K97DH
M)&-F9U-O=7)C97,I.PI]"@HO+R!$;R!T:&4@<V5A<F-H(&EF('=E(&AA=F4@
M;VYE+@II9B`H(6ES7VYU;&PH)'-E87)C:"DI('L*("`@("1D<FEV97(@/2`F
M5'5R8F%?1')I=F5R.CIS:6YG;&5T;VXH)'-O=7)C92D["B`@("!I9B`H(6ES
M7V$H)&1R:79E<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1C<FET97)I
M85LG;F%M92==(#T@=')I;2@D<V5A<F-H*3L*("`@("`@("`D<F5S(#T@)&1R
M:79E<BT^<V5A<F-H*"1C<FET97)I82D["B`@("`@("`@:68@*&ES7V$H)')E
M<RP@)U1U<F)A7TQI<W0G*2D@>PH@("`@("`@("`@("!W:&EL92`H)&]B(#T@
M)')E<RT^;F5X="@I*2!["B`@("`@("`@("`@("`@("!I9B`H)&]B+3YI<T=R
M;W5P*"DI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1A='0@/2`D;V(M/F=E=$%T
M=')I8G5T97,H*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A='0@87,@
M)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1A='1R:6)U=&5S6R1K97E=6R=T>7!E)UTI("8F("1A='1R:6)U=&5S
M6R1K97E=6R=T>7!E)UT@/3T@)V5M86EL)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5S=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1A='1;)VYA
M;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=E;6%I;"<@/3X@)'9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W-O=7)C92<@/3X@)'-O=7)C92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K97DG
M(#T^("1A='1;)U]?:V5Y)UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*?0H*)&)O9'E#;&%S<R`]
M("=S=6UM87)Y)SL*<F5Q=6ER92!455)"05]414U03$%415,@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)SL*"C\^"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CX*/"$M+0IW:6YD;W<N<V5T5&EM96]U="@G=F%R('-T871U<R`]('=I
M;F1O=RYP87)E;G0N9&]C=6UE;G0N9V5T16QE;65N=$)Y260H7"=T=7)B85]M
M:6YI<V5A<F-H7W-E87)C:&EN9UPG*3L@<W1A='5S+G-T>6QE+G9I<VEB:6QI
M='D@/2!<)VAI9&1E;EPG)RP@,3`I.PIW:6YD;W<N<&%R96YT+F)U<WE%>'!A
M;F1I;F<@/2!F86QS93L*+R\M+3X*/"]S8W)I<'0^"CP_<&AP"FEF("AC;W5N
M="@D<F5S=6QT<RDI('L*("`@(&5C:&\@)SQU;"!S='EL93TB;6%R9VEN+71O
M<#HT<'@B/B<["B`@("!F;W)E86-H("@D<F5S=6QT<R!A<R`D8V]N=&%C="D@
M>PH@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)V1I<W!L87DN
M<&AP)RP@87)R87DH)W-O=7)C92<@/3X@)&-O;G1A8W1;)W-O=7)C92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VME>2<@/3X@)&-O;G1A8W1;)VME>2==*2D["@H@("`@("`@
M("1M86EL7VQI;FL@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G;6%I
M;"]C;VUP;W-E)RP@87)R87DH87)R87DH)W1O)R`]/B!A9&1S;&%S:&5S*"1C
M;VYT86-T6R=E;6%I;"==*2DI*3L*("`@("`@("`D=&%R9V5T(#T@)R!T87)G
M970](E]P87)E;G0B)SL*("`@("`@("!I9B`H:7-?82@D;6%I;%]L:6YK+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1M86EL7VQI;FL@/2`G;6%I
M;'1O.B<@+B!U<FQE;F-O9&4H)&-O;G1A8W1;)V5M86EL)UTI.PH@("`@("`@
M("`@("`D=&%R9V5T(#T@)R<["B`@("`@("`@?0H*("`@("`@("!E8VAO("<\
M;&D@8VQA<W,](FQI;F5D4F]W(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FQI
M;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1U<FPI+"!?*")6:65W($-O;G1A
M8W0B*2P@)R<L("=?<&%R96YT)RD@+B!(;W)D93HZ:6UG*"=C;VYT86-T+G!N
M9R<L(%\H(E9I97<@0V]N=&%C="(I*2`N("<\+V$^("<@+@H@("`@("`@("`@
M("`G/&$@:')E9CTB)R`N("1M86EL7VQI;FL@+B`G(B<@+B`D=&%R9V5T("X@
M)SXG("X@:'1M;'-P96-I86QC:&%R<R@D8V]N=&%C=%LG;F%M92==("X@)R`\
M)R`N("1C;VYT86-T6R=E;6%I;"==("X@)SXG*2`N("<\+V$^/"]L:3XG.PH@
M("`@?0H@("`@96-H;R`G/"]U;#XG.PI](&5L<V5I9B`H(6ES7VYU;&PH)'-E
M87)C:"DI('L*("`@(&5C:&\@7R@B3F\@8V]N=&%C=',@9F]U;F0B*3L*?0H_
M/@H\+V)O9'D^"CPO:'1M;#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O='5R8F$O
M:6YD97@N<&AP````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C,T-0`Q,#0Q-S,V,C<U-@`P,3<S-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@='5R8F$O:6YD97@N<&AP+'8@,2XR.2XQ,"XW(#(P,#8O,#$O,#$@
M,C$Z,CDZ,34@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@
M0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$%33"DN("!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+V%S
M;"YP:'`N"B`J+PH*0&1E9FEN92@G5%520D%?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I*3L*)'1U<F)A7V-O;F9I9W5R960@/2`H0&ES7W)E861A8FQE*%15
M4D)!7T)!4T4@+B`G+V-O;F9I9R]C;VYF+G!H<"<I("8F"B`@("`@("`@("`@
M("`@("`@("`@($!I<U]R96%D86)L92A455)"05]"05-%("X@)R]C;VYF:6<O
M871T<FEB=71E<RYP:'`G*2`F)@H@("`@("`@("`@("`@("`@("`@("!`:7-?
M<F5A9&%B;&4H5%520D%?0D%312`N("<O8V]N9FEG+W!R969S+G!H<"<I("8F
M"B`@("`@("`@("`@("`@("`@("`@($!I<U]R96%D86)L92A455)"05]"05-%
M("X@)R]C;VYF:6<O;6EM95]D<FEV97)S+G!H<"<I("8F"B`@("`@("`@("`@
M("`@("`@("`@($!I<U]R96%D86)L92A455)"05]"05-%("X@)R]C;VYF:6<O
M<V]U<F-E<RYP:'`G*2D["@II9B`H(21T=7)B85]C;VYF:6=U<F5D*2!["B`@
M("!R97%U:7)E(%154D)!7T)!4T4@+B`G+RXN+VQI8B]497-T+G!H<"<["B`@
M("!(;W)D95]497-T.CIC;VYF:6=&:6QE<TUI<W-I;F<H)U1U<F)A)RP@5%52
M0D%?0D%312P*("`@("`@("!A<G)A>2@G8V]N9BYP:'`G+"`G<')E9G,N<&AP
M)RP@)VUI;65?9')I=F5R<RYP:'`G+"`G<V]U<F-E<RYP:'`G*2P*("`@("`@
M("!A<G)A>2@G871T<FEB=71E<RYP:'`G(#T^("=4:&ES(&9I;&4@9&5F:6YE
M<R!T:&4@5'5R8F$@9VQO8F%L(&%T=')I8G5T92!N86UE<R!A;F0@='EP97,@
M+2!N86UE<RP@96UA:6P@861D<F5S<V5S+"!E=&,N)RDI.PI]"@IR97%U:7)E
M7V]N8V4@5%520D%?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER92!4
M55)"05]"05-%("X@)R\G("X@*"1B<F]W<V5?<V]U<F-E7V-O=6YT"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`_(&)A<V5N86UE*"1P<F5F<RT^9V5T
M5F%L=64H)VEN:71I86Q?<&%G92<I*0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`G<V5A<F-H+G!H<"<I.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]A9&UI;B\`````````````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S8P`#`Q-34Q,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W!E<FUS
M+P``````````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-C``,#$V-C0P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O861M:6XO<&5R;7,O861D8VAI;&0N<&AP````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8S,P`Q,#0Q-S,V,C<V,``P,C$Q,3``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP+'8@,2XR-RXR+C0@,C`P-B\P,2\P,2`R,3HR.#HP-2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F
M:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN
M)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*"FEF("@A075T:#HZ
M:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E
M4F5D:7)E8W0H*3L*?0H*+RH@4V5T('5P('1H92!F;W)M('9A<FEA8FQE<RX@
M*B\*<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L97,N<&AP)SL*)'9A<G,@
M/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R:6%B;&5S*"D["B1P97)M7VED
M(#T@)'9A<G,M/F=E="@G<&5R;5]I9"<I.PH*)'!E<FUI<W-I;VX@/2`F)'!E
M<FUS+3YG971097)M:7-S:6]N0GE)9"@D<&5R;5]I9"D["FEF("AI<U]A*"1P
M97)M:7-S:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*%\H(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G
M861M:6XO<&5R;7,O:6YD97@N<&AP)RP@=')U92D["B`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HO*B!3970@=7`@9F]R
M;2X@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]097)M<R]522YP:'`G.PHD=6D@
M/2`F;F5W(%!E<FUS7U5)*"1P97)M<RD["B1U:2T^<V5T5F%R<R@D=F%R<RD[
M"B1U:2T^<V5T=7!!9&1&;W)M*"1P97)M:7-S:6]N*3L*"FEF("@D=6DM/G9A
M;&ED871E061D1F]R;2@D:6YF;RDI('L*("`@(&EF("@D:6YF;ULG<&5R;5]I
M9"==(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`D8VAI;&0@/2`F)'!E
M<FUS+3YN97=097)M:7-S:6]N*"1I;F9O6R=C:&EL9"==*3L*("`@("`@("`D
M<F5S=6QT(#T@)'!E<FUS+3YA9&1097)M:7-S:6]N*"1C:&EL9"D["B`@("!]
M(&5L<V4@>PH@("`@("`@("1P3V(@/2`F)'!E<FUS+3YG971097)M:7-S:6]N
M0GE)9"@D:6YF;ULG<&5R;5]I9"==*3L*("`@("`@("`D;F%M92`]("1P3V(M
M/F=E=$YA;64H*2`N("<Z)R`N($1A=&%4<F5E.CIE;F-O9&5.86UE*"1I;F9O
M6R=C:&EL9"==*3L*("`@("`@("`D8VAI;&0@/2`F)'!E<FUS+3YN97=097)M
M:7-S:6]N*"1N86UE*3L*("`@("`@("`D<F5S=6QT(#T@)'!E<FUS+3YA9&10
M97)M:7-S:6]N*"1C:&EL9"D["B`@("!]"B`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"AS<')I;G1F*%\H(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(I+"`D
M<&5R;7,M/F=E=%1I=&QE*"1C:&EL9"T^9V5T3F%M92@I*2P@)')E<W5L="T^
M9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(BDL("1P97)M
M<RT^9V5T5&ET;&4H)&-H:6QD+3YG971.86UE*"DI*2P@)VAO<F1E+G-U8V-E
M<W,G*3L*("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A
M9&UI;B]P97)M<R]E9&ET+G!H<"<L('1R=64I.PH@("`@("`@("1U<FP@/2!5
M=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W!E<FU?:60G+"`D8VAI;&0M/F=E
M=$ED*"DL(&9A;'-E*3L*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@
M)'5R;"D["B`@("`@("`@97AI=#L*("`@('T*?0H*)'1I=&QE(#T@7R@B4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VXB*3L*<F5Q=6ER92!(3U)$15]414U0
M3$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF
M:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G
M*2D["@HO*B!296YD97(@=&AE(&9O<FT@86YD('1R964N("HO"B1U:2T^<F5N
M9&5R1F]R;2@G861D8VAI;&0N<&AP)RD["F5C:&\@)SQB<B`O/B<["B1U:2T^
M<F5N9&5R5')E92@D<&5R;5]I9"D["@IR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&5R;7,O9&5L971E+G!H<```````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8Q-@`Q,#0Q-S,V
M,C<V,``P,C`V,3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO<&5R
M;7,O9&5L971E+G!H<"QV(#$N,3DN."XT(#(P,#8O,#$O,#$@,C$Z,C@Z,#4@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`U+3(P
M,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["@II
M9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T
M:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\J(%-E="!U<"!T:&4@9F]R;2!V
M87)I86)L97,N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H
M<"<["B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I
M.PHD<&5R;5]I9"`]("1V87)S+3YG970H)W!E<FU?:60G*3L*)&-A=&5G;W)Y
M(#T@)'9A<G,M/F=E="@G8V%T96=O<GDG*3L*)'!E<FUI<W-I;VX@/2`F)'!E
M<FUS+3YG971097)M:7-S:6]N0GE)9"@D<&5R;5]I9"D["@HO*B!)9B!T:&4@
M<&5R;6ES<VEO;B!F971C:&5D(&ES(&%N(&5R<F]R(')E='5R;B!T;R!P97)M
M:7-S:6]N<R!L:7-T+B`J+PII9B`H:7-?82@D<&5R;6ES<VEO;BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(I+"`G:&]R
M9&4N97)R;W(G*3L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)V%D;6EN+W!E<FUS+VEN9&5X+G!H<"<L('1R=64I.PH@("`@:&5A9&5R*"=,
M;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?0H*+RH@4V5T('5P(&9O
M<FTN("HO"G)E<75I<F5?;VYC92`G2&]R9&4O4&5R;7,O54DN<&AP)SL*)'5I
M(#T@)FYE=R!097)M<U]522@D<&5R;7,I.PHD=6DM/G-E=%9A<G,H)'9A<G,I
M.PHD=6DM/G-E='5P1&5L971E1F]R;2@D<&5R;6ES<VEO;BD["@II9B`H)&-O
M;F9I<FUE9"`]("1U:2T^=F%L:61A=&5$96QE=&5&;W)M*"1I;F9O*2D@>PH@
M("`@)')E<W5L="`]("1P97)M<RT^<F5M;W9E4&5R;6ES<VEO;B@D<&5R;6ES
M<VEO;BP@=')U92D["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H
M(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB*2P@)'!E<FUS+3YG9714
M:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M92@I*2P@)')E<W5L="T^9V5T365S
M<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@
M9&5L971E9"!<(B5S7"(N(BDL("1P97)M<RT^9V5T5&ET;&4H)'!E<FUI<W-I
M;VXM/F=E=$YA;64H*2DI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("1U
M<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W!E<FUS+VEN9&5X
M+G!H<"<L('1R=64I.PH@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D
M=7)L*3L*("`@("`@("!E>&ET.PH@("`@?0I](&5L<V5I9B`H)&-O;F9I<FUE
M9"`]/3T@9F%L<V4I('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB*2P@)'!E<FUS
M+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M92@I*2DL("=H;W)D92YS
M=6-C97-S)RD["B`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A
M9&UI;B]P97)M<R]I;F1E>"YP:'`G+"!T<G5E*3L*("`@(&AE861E<B@G3&]C
M871I;VXZ("<@+B`D=7)L*3L*("`@(&5X:70["GT*"B1T:71L92`](%\H(E!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(BD["G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I
M9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S
M)RDI.PH*+RH@4F5N9&5R('1H92!F;W)M(&%N9"!T<F5E+B`J+PHD=6DM/G)E
M;F1E<D9O<FTH)V1E;&5T92YP:'`G*3L*96-H;R`G/&)R("\^)SL*)'5I+3YR
M96YD97)4<F5E*"1P97)M7VED*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&5R;7,O961I
M="YP:'``````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,#8U-@`Q,#0Q-S,V,C<V,``P,C`S,#,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O861M:6XO<&5R;7,O961I="YP:'`L=B`Q+C,X+C(N-2`R,#`V+S`Q+S`Q
M(#(Q.C(X.C`U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N
M=2YP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E.CIA
M=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HO*B!3970@=7`@
M=&AE(&9O<FT@=F%R:6%B;&5S+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+U9A
M<FEA8FQE<RYP:'`G.PHD=F%R<R`]("9687)I86)L97,Z.F=E=$1E9F%U;'16
M87)I86)L97,H*3L*)'!E<FU?:60@/2`D=F%R<RT^9V5T*"=P97)M7VED)RD[
M"B1C871E9V]R>2`]("1V87)S+3YG970H)V-A=&5G;W)Y)RD["@HO*B!3964@
M:68@=V4@;F5E9"!T;R`H86YD(&%R92!S=7!P;W-E9"!T;RD@875T;V-R96%T
M92!T:&4@<&5R;6ES<VEO;BX@*B\*:68@*"1C871E9V]R>2`A/3T@;G5L;"D@
M>PH@("`@)'!E<FUI<W-I;VX@/2`F)'!E<FUS+3YG971097)M:7-S:6]N*"1C
M871E9V]R>2D["B`@("!I9B`H:7-?82@D<&5R;6ES<VEO;BP@)U!%05)?17)R
M;W(G*2`F)B!5=&EL.CIG971&;W)M1&%T82@G875T;V-R96%T92<I*2!["@H@
M("`@("`@("\J($-H96-K('1O('-E92!I9B!T:&4@<&5R;6ES<VEO;B!W92!A
M<F4@8V]P>6EN9R!F<F]M(&5X:7-T<R!B969O<F4@=V4*("`@("`@("`@*B!A
M=71O8W)E871E+B`J+PH@("`@("`@("1C;W!Y1G)O;2`](%5T:6PZ.F=E=$9O
M<FU$871A*"=A=71O8W)E871E7V-O<'DG*3L*("`@("`@("!I9B`H)&-O<'E&
M<F]M("8F("$D<&5R;7,M/F5X:7-T<R@D8V]P>49R;VTI*2!["B`@("`@("`@
M("`@("1C;W!Y1G)O;2`](&YU;&P["B`@("`@("`@?0H*("`@("`@("`D<&%R
M96YT(#T@)'9A<G,M/F=E="@G<&%R96YT)RD["B`@("`@("`@)'!E<FUI<W-I
M;VX@/2`F)'!E<FUS+3YN97=097)M:7-S:6]N*"1C871E9V]R>2D["B`@("`@
M("`@)')E<W5L="`]("1P97)M<RT^861D4&5R;6ES<VEO;B@D<&5R;6ES<VEO
M;BP@)'!A<F5N="D["B`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@
M("`@("`@("`@("`D<&5R;5]I9"`]("1P97)M<RT^9V5T4&5R;6ES<VEO;DED
M*"1P97)M:7-S:6]N*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D8V]P>49R
M;VTI('L*("`@("`@("`@("`@+RH@5V4@:&%V92!A=71O8W)E871E9"!T:&4@
M<&5R;6ES<VEO;B!A;F0@=V4@:&%V92!B965N('1O;&0@=&\*("`@("`@("`@
M("`@("H@8V]P>2!A;B!E>&ES=&EN9R!P97)M:7-S:6]N(&9O<B!T:&4@9&5F
M875L=',N("HO"B`@("`@("`@("`@("1C;W!Y1G)O;4]B:B`]("8D<&5R;7,M
M/F=E=%!E<FUI<W-I;VXH)&-O<'E&<F]M*3L*("`@("`@("`@("`@)'!E<FUI
M<W-I;VXM/F%D9$=U97-T4&5R;6ES<VEO;B@D8V]P>49R;VU/8FHM/F=E=$=U
M97-T4&5R;6ES<VEO;G,H*2P@9F%L<V4I.PH@("`@("`@("`@("`D<&5R;6ES
M<VEO;BT^861D1&5F875L=%!E<FUI<W-I;VXH)&-O<'E&<F]M3V)J+3YG971$
M969A=6QT4&5R;6ES<VEO;G,H*2P@9F%L<V4I.PH@("`@("`@("`@("`D<&5R
M;6ES<VEO;BT^861D0W)E871O<E!E<FUI<W-I;VXH)&-O<'E&<F]M3V)J+3YG
M971#<F5A=&]R4&5R;6ES<VEO;G,H*2P@9F%L<V4I.PH@("`@("`@("`@("!F
M;W)E86-H("@D8V]P>49R;VU/8FHM/F=E=%5S97)097)M:7-S:6]N<R@I(&%S
M("1U<V5R(#T^("1U<&5R;2D@>PH@("`@("`@("`@("`@("`@)'!E<FUI<W-I
M;VXM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R+"`D=7!E<FTL(&9A;'-E*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D8V]P>49R;VU/
M8FHM/F=E=$=R;W5P4&5R;6ES<VEO;G,H*2!A<R`D9W)O=7`@/3X@)&=P97)M
M*2!["B`@("`@("`@("`@("`@("`D<&5R;6ES<VEO;BT^861D1W)O=7!097)M
M:7-S:6]N*"1G<F]U<"P@)&=P97)M+"!F86QS92D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!792!H879E(&%U=&]C
M<F5A=&5D('1H92!P97)M:7-S:6]N(&%N9"!W92!D;VXG="!H879E(&%N"B`@
M("`@("`@("`@("`J(&5X:7-T:6YG('!E<FUI<W-I;VX@=&\@8V]P>2X@(%-E
M92!I9B!S;VUE(&1E9F%U;'1S('=E<F4*("`@("`@("`@("`@("H@<W5P<&QI
M960N("HO"B`@("`@("`@("`@("1A9&1097)M<R`](%5T:6PZ.F=E=$9O<FU$
M871A*"=A=71O8W)E871E7V=U97-T)RD["B`@("`@("`@("`@(&EF("@D861D
M4&5R;7,I('L*("`@("`@("`@("`@("`@("1P97)M:7-S:6]N+3YA9&1'=65S
M=%!E<FUI<W-I;VXH)&%D9%!E<FUS+"!F86QS92D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&%D9%!E<FUS(#T@571I;#HZ9V5T1F]R;41A=&$H)V%U
M=&]C<F5A=&5?9&5F875L="<I.PH@("`@("`@("`@("!I9B`H)&%D9%!E<FUS
M*2!["B`@("`@("`@("`@("`@("`D<&5R;6ES<VEO;BT^861D1&5F875L=%!E
M<FUI<W-I;VXH)&%D9%!E<FUS+"!F86QS92D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&%D9%!E<FUS(#T@571I;#HZ9V5T1F]R;41A=&$H)V%U=&]C
M<F5A=&5?8W)E871O<B<I.PH@("`@("`@("`@("!I9B`H)&%D9%!E<FUS*2![
M"B`@("`@("`@("`@("`@("`D<&5R;6ES<VEO;BT^861D0W)E871O<E!E<FUI
M<W-I;VXH)&%D9%!E<FUS+"!F86QS92D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@)'!E<FUI<W-I;VXM/G-A=F4H*3L*("`@('T@96QS92![
M"B`@("`@("`@)'!E<FU?:60@/2`D<&5R;7,M/F=E=%!E<FUI<W-I;VY)9"@D
M<&5R;6ES<VEO;BD["B`@("!]"B`@("`D=F%R<RT^<V5T*"=P97)M7VED)RP@
M)'!E<FU?:60I.PI](&5L<V4@>PH@("`@)'!E<FUI<W-I;VX@/2`F)'!E<FUS
M+3YG971097)M:7-S:6]N0GE)9"@D<&5R;5]I9"D["GT*"B\J($EF('1H92!P
M97)M:7-S:6]N(&9E=&-H960@:7,@86X@97)R;W(@<F5T=7)N('1O('1H92!P
M97)M:7-S:6]N<R!L:7-T+B`J+PII9B`H:7-?82@D<&5R;6ES<VEO;BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"=A9&UI;B]P97)M<R]I;F1E>"YP:'`G+"!T<G5E*3L*("`@(&AE861E<B@G
M3&]C871I;VXZ("<@+B`D=7)L*3L*("`@(&5X:70["GT*"G)E<75I<F5?;VYC
M92`G2&]R9&4O4&5R;7,O54DN<&AP)SL*)'5I(#T@)FYE=R!097)M<U]522@D
M<&5R;7,I.PHD=6DM/G-E=%9A<G,H)'9A<G,I.PHD=6DM/G-E='5P161I=$9O
M<FTH)'!E<FUI<W-I;VXI.PH*:68@*"1U:2T^=F%L:61A=&5%9&ET1F]R;2@D
M:6YF;RDI('L*("`@("\J(%5P9&%T92!A;F0@<V%V92!T:&4@<&5R;6ES<VEO
M;G,N("HO"B`@("`D<&5R;6ES<VEO;BT^=7!D871E4&5R;6ES<VEO;G,H)&EN
M9F\I.PH@("`@)'!E<FUI<W-I;VXM/G-A=F4H*3L*("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")5<&1A=&5D(%PB)7-<(BXB*2P@)'!E<FUS
M+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M92@I*2DL("=H;W)D92YS
M=6-C97-S)RD["B`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=A9&UI
M;B]P97)M<R]E9&ET+G!H<"<L("=P97)M7VED)RP@)'!E<FUI<W-I;VXM/F=E
M=$ED*"DI.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D=7)L
M+"!T<G5E*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@
M(&5X:70["GT*"B1T:71L92`](%\H(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A
M>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PH*+RH@4F5N9&5R('1H92!F
M;W)M(&%N9"!T<F5E+B`J+PHD=6DM/G)E;F1E<D9O<FTH)V5D:70N<&AP)RD[
M"F5C:&\@)SQB<B`O/B<["B1U:2T^<F5N9&5R5')E92@D<&5R;5]I9"D["@IR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]P97)M<R]I;F1E>"YP:'``````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C4R`#$P-#$W
M,S8R-S8P`#`R,#0V,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A9&UI;B]P
M97)M<R]I;F1E>"YP:'`L=B`Q+C$P+C$P+C,@,C`P-B\P,2\P,2`R,3HR.#HP
M-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#4M
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*
M"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC
M871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)'!E<FU?:60@/2!5=&EL.CIG
M971&;W)M1&%T82@G<&5R;5]I9"<I.PH*)'1I=&QE(#T@7R@B4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VXB*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@
M+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO
M;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["@IR
M97%U:7)E7V]N8V4@)TAO<F1E+U!E<FUS+U5)+G!H<"<["B1U:2`]("9N97<@
M4&5R;7-?54DH)'!E<FUS*3L*)'5I+3YR96YD97)4<F5E*"1P97)M7VED*3L*
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN
M8R<["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]S971U<"\`````````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S8P`#`Q-C8U,@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D
M;6EN+W-E='5P+V-O;F9I9RYP:'``````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3$V-C8`,3`T,3<S-C(W-C``,#(P-C,W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W-E='5P+V-O;F9I9RYP:'`L=B`Q+C(T
M+C0N.2`R,#`V+S`R+S$S(#$V.C4S.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\
M:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/
M4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q
M=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+T9O<FTO06-T:6]N+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]2
M96YD97)E<BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-O;F9I9RYP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*:68@*"%!
M=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"FEF("@A571I;#HZ97AT96YS
M:6]N17AI<W1S*"=D;VUX;6PG*2`F)B`A571I;#HZ97AT96YS:6]N17AI<W1S
M*"=D;VTG*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=9;W4@;F5E9"!T:&4@9&]M
M>&UL(&]R(&1O;2!02%`@97AT96YS:6]N('1O('5S92!T:&4@8V]N9FEG=7)A
M=&EO;B!T;V]L+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"B1A<'`@/2!5
M=&EL.CIG971&;W)M1&%T82@G87!P)RD["B1A<'!N86UE(#T@)')E9VES=')Y
M+3YG970H)VYA;64G+"`D87!P*3L*)'1I=&QE(#T@<W!R:6YT9BA?*"(E<R!3
M971U<"(I+"`D87!P;F%M92D["@II9B`H)&%P<"`]/3T@;G5L;"`F)@H@("`@
M:6Y?87)R87DH)&%P<"P@)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G:6YA
M8W1I=F4G+"`G:&ED9&5N)RP@)VYO=&]O;&)A<B<L("=A8W1I=F4G+"`G861M
M:6XG*2DI*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(DEN=F%L:60@
M87!P;&EC871I;VXN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@)'5R;"`]($AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O:6YD97@N<&AP)RP@
M=')U92D["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E
M>&ET.PI]"@HD=F%R<R`](%9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE
M<R@I.PHD9F]R;2`]("9N97<@0V]N9FEG1F]R;2@D=F%R<RP@)&%P<"D["B1F
M;W)M+3YS971"=71T;VYS*'-P<FEN=&8H7R@B1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;B(I+"`D87!P;F%M92DI.PII9B`H9FEL95]E>&ES=',H)')E9VES
M=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I9R]C;VYF+G!H
M<"YB86LG*2D@>PH@("`@)&9O<FTM/F%P<&5N9$)U='1O;G,H7R@B4F5V97)T
M($-O;F9I9W5R871I;VXB*2D["GT*"B1P:'`@/2`G)SL*:68@*%5T:6PZ.F=E
M=$9O<FU$871A*"=S=6)M:71B=71T;VXG*2`]/2!?*")2979E<G0@0V]N9FEG
M=7)A=&EO;B(I*2!["B`@("`D<&%T:"`]("1R96=I<W1R>2T^9V5T*"=F:6QE
M<F]O="<L("1A<'`I("X@)R]C;VYF:6<G.PH@("`@:68@*$!C;W!Y*"1P871H
M("X@)R]C;VYF+G!H<"YB86LG+"`D<&%T:"`N("<O8V]N9BYP:'`G*2D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!`=6YL:6YK*"1P871H("X@
M)R]C;VYF+G!H<"YB86LG*3L*("`@('T@96QS92!["B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"A?*")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@?0I](&5L<V5I9B`H)&9O<FTM
M/G9A;&ED871E*"1V87)S*2D@>PH@("`@)&-O;F9I9R`]("9N97<@2&]R9&5?
M0V]N9FEG*"1A<'`I.PH@("`@)'!H<"`]("1C;VYF:6<M/F=E;F5R871E4$A0
M0V]N9FEG*"1V87)S*3L*("`@("1P871H(#T@)')E9VES=')Y+3YG970H)V9I
M;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I9R<["B`@("!I9B`H9FEL95]E>&ES
M=',H)'!A=&@@+B`G+V-O;F8N<&AP)RDI('L*("`@("`@("!I9B`H0&-O<'DH
M)'!A=&@@+B`G+V-O;F8N<&AP)RP@)'!A=&@@+B`G+V-O;F8N<&AP+F)A:R<I
M*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(BDL(%5T:6PZ.G)E86Q0871H*"1P871H("X@)R]C;VYF+G!H
M<"YB86LG*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(I+"!5=&EL.CIR96%L4&%T:"@D<&%T:"`N("<O8V]N9BYP:'`N8F%K)RDI
M+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@('T*("`@('T*("`@(&EF("@D
M9G`@/2!`9F]P96XH)'!A=&@@+B`G+V-O;F8N<&AP)RP@)W<G*2D@>PH@("`@
M("`@("\J($-A;B!W<FET92P@<V\@;W5T<'5T('1O(&9I;&4N("HO"B`@("`@
M("`@9G=R:71E*"1F<"P@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D<&AP+"!.
M3%,Z.F=E=$-H87)S970H*2P@)VES;RTX.#4Y+3$G*2D["B`@("`@("`@9F-L
M;W-E*"1F<"D["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F
M*%\H(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(I+"!5=&EL.CIR96%L4&%T:"@D
M<&%T:"`N("<O8V]N9BYP:'`G*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@
M("`@)')E9VES=')Y+3YC;&5A<D-A8VAE*"D["B`@("`@("`@:&5A9&5R*"=,
M;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T
M=7`O:6YD97@N<&AP)RP@=')U92DI.PH@("`@("`@(&5X:70["B`@("!](&5L
M<V4@>PH@("`@("`@("\J($-A;B!N;W0@=W)I=&4N("HO"B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(BDL(%5T
M:6PZ.G)E86Q0871H*"1P871H("X@)R]C;VYF+G!H<"<I+"!(;W)D93HZ;&EN
M:RA(;W)D93HZ=7)L*"=I;F1E>"YP:'`G*2`N("<C=7!D871E)RP@7R@B4V5T
M=7`B*2D@+B!?*")3971U<"(I("X@)SPO83XG+"!5=&EL.CIR96%L4&%T:"@D
M<&%T:"`N("<O8V]N9BYP:'`G*2DL("=H;W)D92YW87)N:6YG)RP@87)R87DH
M)V-O;G1E;G0N<F%W)RDI.PH@("`@("`@("\J(%-A=F4@=&\@<V5S<VEO;BX@
M*B\*("`@("`@("`D7U-%4U-)3TY;)U]C;VYF:6<G75LD87!P72`]("1P:'`[
M"B`@("!]"GT@96QS96EF("@D9F]R;2T^:7-3=6)M:71T960H*2D@>PH@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82!R97%U:7)E9"!F:65L9"XB*2P@)VAO<F1E+F5R<F]R)RD["GT*"B\J(%)E
M;F1E<B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B`J+PIR97%U:7)E7V]N8V4@
M)TAO<F1E+U5)+U9A<E)E;F1E<F5R+G!H<"<["B1R96YD97)E<B`]("9N97<@
M2&]R9&5?1F]R;5]296YD97)E<B@I.PHD<F5N9&5R97(M/G-E=$%T=')#;VQU
M;6Y7:61T:"@G-3`E)RD["B1F;W)M(#T@571I;#HZ8G5F9F5R3W5T<'5T*&%R
M<F%Y*"1F;W)M+"`G<F5N9&5R06-T:79E)RDL("1R96YD97)E<BP@)'9A<G,L
M("=C;VYF:6<N<&AP)RP@)W!O<W0G*3L*"@HO*B!3970@=7`@=&AE('1E;7!L
M871E+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L871E+G!H<"<["B1T
M96UP;&%T92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*)'1E;7!L871E+3YS
M970H)W!H<"<L(&AT;6QS<&5C:6%L8VAA<G,H)'!H<"DL('1R=64I.PHO*B!#
M<F5A=&4@=&AE(&QI;FL@9F]R('1H92!D:69F('!O<'5P(&]N;'D@:68@<W1O
M<F5D(&EN('-E<W-I;VXN("HO"FEF("@A96UP='DH)%]315-324].6R=?8V]N
M9FEG)UU;)&%P<%TI*2!["B`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G<&]P
M=7`N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("1U<FP@/2!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+V1I9F8N<&AP)RD["B`@("`D=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=A<'`G+"`D87!P*3L*("`@
M("1L:6YK(#T@2&]R9&4Z.FQI;FLH)R,G+"`G)RP@)R<L("<G+"`G<&]P=7`H
M7"<G("X@)'5R;"`N("=<)RP@-C0P+"`T.#`I.R!R971U<FX@9F%L<V4[)RD@
M+B!?*")S:&]W(&1I9F9E<F5N8V5S(BD@+B`G/"]A/B<["B`@("`D=&5M<&QA
M=&4M/G-E="@G9&EF9E]P;W!U<"<L("1L:6YK*3L*?0HD=&5M<&QA=&4M/G-E
M="@G9F]R;2<L("1F;W)M*3L*)'1E;7!L871E+3YS970H)VYO=&EF>2<L(%5T
M:6PZ.F)U9F9E<D]U='!U="AA<G)A>2@D;F]T:69I8V%T:6]N+"`G;F]T:69Y
M)RDI*3L*)'1E;7!L871E+3YS971/<'1I;VXH)V=E='1E>'0G+"!T<G5E*3L*
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN
M8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8R<["F5C:&\@)'1E;7!L871E+3YF971C:"A(3U)$15]414U0
M3$%415,@+B`G+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL)RD["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]A9&UI;B]S971U<"]D:69F+G!H<```````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-C4U`#$P-#$W,S8R-S8P`#`R,#,P-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@4V-R:7!T('1O('-H;W<@=&AE(&1I9F9E<F5N8V5S(&)E='=E
M96X@=&AE(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY"B`J(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN
M+W-E='5P+V1I9F8N<&AP+'8@,2XT+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HP
M-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!4:&4@2&]R
M9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D92YO<F<O*0H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*
M<F5Q=6ER95]O;F-E("=(;W)D92]#;VYF:6<N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]496UP;&%T92YP:'`G.PII;F-L=61E7V]N8V4@)U1E>'0O1&EF
M9BYP:'`G.PII;F-L=61E7V]N8V4@)U1E>'0O1&EF9B]296YD97)E<BYP:'`G
M.PH*:68@*"%!=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E.CIF871A;"@G
M1F]R8FED9&5N+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"B\J(%-E="!U
M<"!T:&4@9&EF9B!R96YD97)E<BX@*B\*)')E;F1E<E]T>7!E(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W)E;F1E<B<L("=I;FQI;F4G*3L*:6YC;'5D95]O;F-E
M("=497AT+T1I9F8O4F5N9&5R97(O)R`N("1R96YD97)?='EP92`N("<N<&AP
M)SL*)&-L87-S(#T@)U1E>'1?1&EF9E]296YD97)E<E\G("X@)')E;F1E<E]T
M>7!E.PHD<F5N9&5R97(@/2`F;F5W("1C;&%S<R@I.PH*+RHJ"B`J(%!R:79A
M=&4@9G5N8W1I;VX@=&\@<F5N9&5R('1H92!D:69F97)E;F-E<R!F;W(@82!S
M<&5C:69I8R!A<'`N"B`J+PIF=6YC=&EO;B!?9V5T1&EF9B@D87!P*0I["B`@
M("!G;&]B86P@)')E;F1E<F5R+"`D<F5G:7-T<GD["@H@("`@+RH@4F5A9"!T
M:&4@97AI<W1I;F<@8V]N9FEG=7)A=&EO;BX@*B\*("`@("1C=7)R96YT7V-O
M;F9I9R`]("<G.PH@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O
M;W0G+"`D87!P*2`N("<O8V]N9FEG)SL*("`@("1S:7IE(#T@0&9I;&5S:7IE
M*"1P871H("X@)R]C;VYF+G!H<"<I.PH@("`@:68@*"1S:7IE("8F(&ES7W)E
M<V]U<F-E*"1F<"`]($!F;W!E;B@D<&%T:"`N("<O8V]N9BYP:'`G+"`G<B<I
M*2D@>PH@("`@("`@("1C=7)R96YT7V-O;F9I9R`]($!F<F5A9"@D9G`L("1S
M:7IE*3L*("`@('T*"B`@("`O*B!#86QC=6QA=&4@=&AE(&1I9F9E<F5N8V5S
M+B`J+PH@("`@)&1I9F8@/2`F;F5W(%1E>'1?1&EF9BAE>'!L;V1E*")<;B(L
M("1C=7)R96YT7V-O;F9I9RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&5X<&QO9&4H(EQN(BP@)%]315-324].6R=?8V]N9FEG)UU;)&%P<%TI*3L*
M("`@("1D:69F(#T@)')E;F1E<F5R+3YR96YD97(H)&1I9F8I.PH@("`@:68@
M*"%E;7!T>2@D9&EF9BDI('L*("`@("`@("!R971U<FX@)&1I9F8["B`@("!]
M(&5L<V4@>PH@("`@("`@(')E='5R;B!?*").;R!C:&%N9V4N(BD["B`@("!]
M"GT*"B1D:69F<R`](&%R<F%Y*"D["B\J($]N;'D@8F]T:&5R('1O(&1O(&%N
M>71H:6YG(&EF('1H97)E(&ES(&%N>2!C;VYF:6<N("HO"FEF("@A96UP='DH
M)%]315-324].6R=?8V]N9FEG)UTI*2!["B`@("`O*B!3970@=7`@=&AE('1O
M9V=L92!B=71T;VX@9F]R(&EN;&EN92]U;FEF:65D+B`J+PH@("`@)'5R;"`]
M($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O9&EF9BYP:'`G
M*3L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W)E;F1E
M<B<L("@D<F5N9&5R7W1Y<&4@/3T@)VEN;&EN92<I(#\@)W5N:69I960G(#H@
M)VEN;&EN92<I.PH*("`@(&EF("@D87!P(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V%P<"<I*2!["B`@("`@("`@+RH@2&%N9&QE(&$@<VEN9VQE(&%P<"!R97%U
M97-T+B`J+PH@("`@("`@("1T;V=G;&5?<F5N9&5R97(@/2!(;W)D93HZ;&EN
M:R@D=7)L("X@)R,G("X@)&%P<"D@+B`H*"1R96YD97)?='EP92`]/2`G:6YL
M:6YE)RD@/R!?*")U;FEF:65D(BD@.B!?*")I;FQI;F4B*2D@+B`G/"]A/B<[
M"B`@("`@("`@)&1I9F8@/2!?9V5T1&EF9B@D87!P*3L*("`@("`@("!I9B`H
M)')E;F1E<E]T>7!E("$]("=I;FQI;F4G*2!["B`@("`@("`@("`@("1D:69F
M(#T@:'1M;'-P96-I86QC:&%R<R@D9&EF9BD["B`@("`@("`@?0H@("`@("`@
M("1D:69F<UM=(#T@87)R87DH)V%P<"<@(#T^("1A<'`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&EF9B<@/3X@)&1I9F8L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`G=&]G9VQE7W)E;F1E<F5R)R`]/B`D=&]G9VQE7W)E;F1E
M<F5R*3L*("`@('T@96QS92!["B`@("`@("`@+RH@3&ES="!A;&P@=&AE(&%P
M<',@=VET:"!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX@*B\*("`@("`@("!K
M<V]R="@D7U-%4U-)3TY;)U]C;VYF:6<G72D["B`@("`@("`@9F]R96%C:"`H
M)%]315-324].6R=?8V]N9FEG)UT@87,@)&%P<"`]/B`D8V]N9FEG*2!["B`@
M("`@("`@("`@("1T;V=G;&5?<F5N9&5R97(@/2!(;W)D93HZ;&EN:R@D=7)L
M("X@)R,G("X@)&%P<"D@+B`H*"1R96YD97)?='EP92`]/2`G:6YL:6YE)RD@
M/R!?*")U;FEF:65D(BD@.B!?*")I;FQI;F4B*2D@+B`G/"]A/B<["B`@("`@
M("`@("`@("1D:69F(#T@7V=E=$1I9F8H)&%P<"D["B`@("`@("`@("`@(&EF
M("@D<F5N9&5R7W1Y<&4@(3T@)VEN;&EN92<I('L*("`@("`@("`@("`@("`@
M("1D:69F(#T@:'1M;'-P96-I86QC:&%R<R@D9&EF9BD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&1I9F9S6UT@/2!A<G)A>2@G87!P)R`@/3X@)&%P
M<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&EF9B<@/3X@)&1I
M9F8L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O9V=L95]R96YD
M97)E<B<@/3X@)'1O9V=L95]R96YD97)E<BD["B`@("`@("`@?0H@("`@?0I]
M"@HO*B!3970@=7`@=&AE('1E;7!L871E+B`J+PHD=&5M<&QA=&4@/2`F;F5W
M($AO<F1E7U1E;7!L871E*"D["B1T96UP;&%T92T^<V5T3W!T:6]N*"=G971T
M97AT)RP@=')U92D["B1T96UP;&%T92T^<V5T*"=D:69F<R<L("1D:69F<RP@
M=')U92D["@HD=&ET;&4@/2!?*")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R
M+FEN8R<["F5C:&\@)'1E;7!L871E+3YF971C:"A(3U)$15]414U03$%415,@
M+B`G+V%D;6EN+W-E='5P+V1I9F8N:'1M;"<I.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O861M:6XO<V5T=7`O:6YD97@N<&AP````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C(U,0`Q,#0Q-S,V,C<V,``P,C`T-S$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO<V5T=7`O:6YD97@N<&AP
M+'8@,2XR."XT+C$R(#(P,#8O,#,O,C@@,3(Z,S$Z,#@@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@
M4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E
M9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N
M+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]496UP;&%T92YP:'`G.PH*:68@*"%!
M=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"B\J*@H@*B!2971U<FYS('1H
M92!#5E,@=F5R<VEO;B!F;W(@82!G:79E;B!F:6QE+@H@*B\*9G5N8W1I;VX@
M7V=E=%9E<G-I;VXH)&9I;&4I"GL*("`@("1S:7IE(#T@0&9I;&5S:7IE*"1F
M:6QE*3L*("`@(&EF("@A)'-I>F4@?'P@(6ES7W)E<V]U<F-E*"1F<"`]($!F
M;W!E;B@D9FEL92P@)W(G*2DI('L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"B`@("`D9&%T82`]($!F<F5A9"@D9G`L("1S:7IE*3L*("`@(&EF("AP
M<F5G7VUA=&-H*"<O7"0N*C]C;VYF7"YX;6PL=B`H+BH_*2`N*EPD+R<L("1D
M871A+"`D;6%T8V@I*2!["B`@("`@("`@<F5T=7)N("1M871C:%LQ73L*("`@
M('T@96QS92!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0I]"@HO*BH*
M("H@1&]E<R!A;B!&5%`@=7!L;V%D('1O('-A=F4@=&AE(&-O;F9I9W5R871I
M;VXN"B`J+PIF=6YC=&EO;B!?=7!L;V%D1E10*"1P87)A;7,I"GL*("`@(&=L
M;V)A;"`D<F5G:7-T<GDL("1N;W1I9FEC871I;VX["@H@("`@<F5Q=6ER95]O
M;F-E("=61E,N<&AP)SL*("`@("1P87)A;7-;)VAO<W1S<&5C)UT@/2`G;&]C
M86QH;W-T)SL*("`@("1V9G,@/2`F5D93.CIS:6YG;&5T;VXH)V9T<"<L("1P
M87)A;7,I.PH@("`@:68@*&ES7V$H)'9F<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B*2P@
M)'!A<F%M<ULG:&]S='-P96,G72P@)'9F<RT^9V5T365S<V%G92@I*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J($QO;W`@=&AR;W5G:"!T:&4@8V]N9FEG(&%N9"!W<FET92!T;R!&5%`N
M("HO"B`@("`D;F]?97)R;W)S(#T@=')U93L*("`@(&9O<F5A8V@@*"1?4T53
M4TE/3ELG7V-O;F9I9R==(&%S("1A<'`@/3X@)&-O;F9I9RD@>PH@("`@("`@
M("1P871H(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G
M+V-O;F9I9R<["B`@("`@("`@+RH@5')Y('1O(&)A8VL@=7`@=&AE(&-U<G)E
M;G0@8V]N9BYP:'`N("HO"B`@("`@("`@:68@*"1V9G,M/F5X:7-T<R@D<&%T
M:"P@)V-O;F8N<&AP)RDI('L*("`@("`@("`@("`@:68@*"@D<F5S=6QT(#T@
M)'9F<RT^<F5N86UE*"1P871H+"`G8V]N9BYP:'`G+"`D<&%T:"P@)R]C;VYF
M+G!H<"YB86LG*2D@/3T]('1R=64I('L*("`@("`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@
M("!](&5L<V5I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(I+"`D
M<F5S=6QT+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H7R@B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)'=R:71E(#T@)'9F<RT^=W)I=&5$871A*"1P871H+"`G8V]N
M9BYP:'`G+"`D8V]N9FEG*3L*("`@("`@("!I9B`H:7-?82@D=W)I=&4L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO7V5R<F]R<R`](&9A;'-E
M.PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B
M*2P@)&%P<"P@)'=R:71E+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY('=R;W1E("5S(BDL(%5T
M:6PZ.G)E86Q0871H*"1P871H("X@)R]C;VYF+G!H<"<I*2P@)VAO<F1E+G-U
M8V-E<W,G*3L*("`@("`@("`@("`@=6YS970H)%]315-324].6R=?8V]N9FEG
M)UU;)&%P<%TI.PH@("`@("`@('T*("`@('T*("`@("1R96=I<W1R>2T^8VQE
M87)#86-H92@I.PH@("`@<F5T=7)N("1N;U]E<G)O<G,["GT*"B\J(%-E="!U
M<"!S;VUE(&EC;VYS+B`J+PHD<W5C8V5S<R`]($AO<F1E.CII;6<H)V%L97)T
M<R]S=6-C97-S+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I
M<B@G:&]R9&4G*2D["B1W87)N:6YG(#T@2&]R9&4Z.FEM9R@G86QE<G1S+W=A
M<FYI;F<N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*3L*)&5R<F]R(#T@2&]R9&4Z.FEM9R@G86QE<G1S+V5R<F]R+G!N
M9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D[
M"@HD8V]N9E]U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`G*3L*)&$@/2`D<F5G:7-T<GDM/FQI<W1!<'!S*&%R
M<F%Y*"=I;F%C=&EV92<L("=H:61D96XG+"`G;F]T;V]L8F%R)RP@)V%C=&EV
M92<L("=A9&UI;B<I*3L*)&%P<',@/2!A<G)A>2@I.PHD:2`]("TQ.PIF;W)E
M86-H("@D82!A<R`D87!P*2!["B`@("`O*B!3:VEP(&%P<"!I9B!N;R!C;VYF
M+GAM;"!F:6QE+B`J+PH@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E="@G9FEL
M97)O;W0G+"`D87!P*2`N("<O8V]N9FEG)SL*("`@(&EF("@A9FEL95]E>&ES
M=',H)'!A=&@@+B`G+V-O;F8N>&UL)RDI('L*("`@("`@("!C;VYT:6YU93L*
M("`@('T*"B`@("`D:2LK.PH@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E="@G
M9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG)SL*"B`@("`D8V]N9E]L:6YK
M(#T@571I;#HZ861D4&%R86UE=&5R*"1C;VYF7W5R;"P@)V%P<"<L("1A<'`I
M.PH@("`@)&-O;F9?;&EN:R`]($AO<F1E.CIL:6YK*"1C;VYF7VQI;FLL('-P
M<FEN=&8H7R@B0V]N9FEG=7)E("5S(BDL("1A<'`I*3L*("`@("1A<'!S6R1I
M75LG<V]R="==(#T@)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*2`N("<@
M*"<@+B`D87!P("X@)RDG.PH@("`@)&%P<'-;)&E=6R=N86UE)UT@/2`D8V]N
M9E]L:6YK("X@)&%P<'-;)&E=6R=S;W)T)UT@+B`G/"]A/B<["B`@("`D87!P
M<ULD:5U;)W9E<G-I;VXG72`]("<G.PH@("`@:68@*&ES7W)E861A8FQE*"1R
M96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O=F5R<VEO
M;BYP:'`G*2D@>PH@("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG970H)V9I
M;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]V97)S:6]N+G!H<"<["B`@("`@("`@
M)'9E<G-I;VY?8V]N<W1A;G0@/2!3=')I;F<Z.G5P<&5R*"1A<'`I("X@)U]6
M15)324].)SL*("`@("`@("!I9B`H9&5F:6YE9"@D=F5R<VEO;E]C;VYS=&%N
M="DI('L*("`@("`@("`@("`@)&%P<'-;)&E=6R=V97)S:6]N)UT@/2!C;VYS
M=&%N="@D=F5R<VEO;E]C;VYS=&%N="D["B`@("`@("`@?0H@("`@?0H@("`@
M:68@*"%F:6QE7V5X:7-T<R@D<&%T:"`N("<O8V]N9BYP:'`G*2D@>PH@("`@
M("`@("\J($YO(&-O;F8N<&AP(&5X:7-T<RX@*B\*("`@("`@("`D87!P<ULD
M:5U;)V-O;F8G72`]("1C;VYF7VQI;FL@+B`D97)R;W(@+B`G/"]A/B<["B`@
M("`@("`@)&%P<'-;)&E=6R=S=&%T=7,G72`](%\H(DUI<W-I;F<@8V]N9FEG
M=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W
M86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+B(I.PH@("`@?2!E;'-E('L*
M("`@("`@("`O*B!!(&-O;F8N<&AP(&5X:7-T<RP@9V5T('1H92!X;6P@=F5R
M<VEO;BX@*B\*("`@("`@("!I9B`H*"1X;6Q?=F5R(#T@7V=E=%9E<G-I;VXH
M)'!A=&@@+B`G+V-O;F8N>&UL)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`D87!P<ULD:5U;)V-O;F8G72`]("1C;VYF7VQI;FL@+B`D=V%R;FEN9R`N
M("<\+V$^)SL*("`@("`@("`@("`@)&%P<'-;)&E=6R=S=&%T=7,G72`](%\H
M(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(I.PH@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("!]"B`@("`@("`@+RH@1V5T('1H92!G96YE<F%T960@
M<&AP('9E<G-I;VXN("HO"B`@("`@("`@:68@*"@D<&AP7W9E<B`](%]G9716
M97)S:6]N*"1P871H("X@)R]C;VYF+G!H<"<I*2`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@+RH@3F\@=F5R<VEO;B!F;W5N9"!I;B!G96YE<F%T960@<&AP
M+"!S=6=G97-T(')E9V5N87)A=&EN9PH@("`@("`@("`@("`@*B!J=7-T(&EN
M(&-A<V4N("HO"B`@("`@("`@("`@("1A<'!S6R1I75LG8V]N9B==(#T@)&-O
M;F9?;&EN:R`N("1W87)N:6YG("X@)SPO83XG.PH@("`@("`@("`@("`D87!P
M<ULD:5U;)W-T871U<R==(#T@7R@B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB*3L*
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'AM;%]V97(@(3T@)'!H<%]V97(I('L*("`@("`@("`@("`@+RH@5F5R<VEO
M;G,@87)E(&YO="!T:&4@<V%M92P@8V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92X@*B\*("`@("`@("`@("`@)&%P<'-;)&E=6R=C;VYF)UT@/2`D8V]N
M9E]L:6YK("X@)&5R<F]R("X@)SPO83XG.PH@("`@("`@("`@("`D87!P<ULD
M:5U;)W-T871U<R==(#T@7R@B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92XB*3L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+RH@0V]N9FEG=7)A=&EO;B!I<R!O:RX@*B\*("`@("`@
M("`@("`@)&%P<'-;)&E=6R=C;VYF)UT@/2`D8V]N9E]L:6YK("X@)'-U8V-E
M<W,@+B`G/"]A/B<["B`@("`@("`@("`@("1A<'!S6R1I75LG<W1A='5S)UT@
M/2!?*")!<'!L:6-A=&EO;B!I<R!R96%D>2XB*3L*("`@("`@("!]"B`@("!]
M"GT*"B\J(%-O<G0@=&AE(&%P<',@8GD@;F%M92X@*B\*<F5Q=6ER95]O;F-E
M("=(;W)D92]!<G)A>2YP:'`G.PI(;W)D95]!<G)A>3HZ87)R87E3;W)T*"1A
M<'!S+"`G<V]R="<I.PH*+RH@4V5T('5P(&%N>2!A8W1I;VYS('1H870@;6%Y
M(&)E(&]F9F5R960N("HO"B1A8W1I;VYS(#T@87)R87DH*3L*)&9T<&9O<FT@
M/2`G)SL*:68@*"%E;7!T>2@D7U-%4U-)3TY;)U]C;VYF:6<G72DI('L*("`@
M($AO<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H;W)D92<L('1R
M=64I.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO
M<V5T=7`O9&EF9BYP:'`G*3L*("`@("1A8W1I;VX@/2!?*")3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VXN(BD["B`@("`D86-T:6]N<UM=(#T@
M87)R87DH)VEC;VXG(#T^($AO<F1E.CII;6<H)W-E87)C:"YP;F<G+"`G)RP@
M)V%L:6=N/2)M:61D;&4B)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^($AO<F1E
M.CIL:6YK*"<C)RP@)R<L("<G+"`G)RP@)W!O<'5P*%PG)R`N("1U<FP@+B`G
M7"<L-C0P+"`T.#`I.R!R971U<FX@9F%L<V4[)RD@+B`D86-T:6]N("X@)SPO
M83XG*3L*"B`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<"<I.PH@("`@+RH@06-T:6]N('1O(&1O=VYL
M;V%D('1H92!C;VYF:6=U<F%T:6]N('5P9W)A9&4@4$A0('-C<FEP="X@*B\*
M("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@87)R87DH)W-E
M='5P)R`]/B`G8V]N9B<L("=T>7!E)R`]/B`G<&AP)RDI.PH@("`@)&%C=&EO
M;B`](%\H(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N(BD["B`@("`D86-T:6]N<UM=(#T@87)R87DH)VEC;VXG(#T^
M($AO<F1E.CII;6<H)V1O=VYL;V%D+G!N9R<L("<G+"`G86QI9VX](FUI9&1L
M92(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2P*("`@("`@
M("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@2&]R9&4Z.FQI;FLH)'5R;"D@
M+B`D86-T:6]N("X@)SPO83XG*3L*("`@("\J($%C=&EO;B!T;R!S879E('1H
M92!C;VYF:6=U<F%T:6]N('5P9W)A9&4@4$A0('-C<FEP="X@*B\*("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W-A=F4G+"`G=&UP)RD[
M"B`@("`D86-T:6]N(#T@7R@B4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+B(I.PH@("`@)&%C=&EO;G-;72`](&%R<F%Y*"=I8V]N)R`]
M/B!(;W)D93HZ:6UG*"=S879E+G!N9R<L("<G+"`G86QI9VX](FUI9&1L92(G
M+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`G;&EN:R<@/3X@2&]R9&4Z.FQI;FLH)'5R;"D@+B`D
M86-T:6]N("X@)SPO83XG*3L*"B`@("`O*B!3970@=7`@=&AE(&9O<FT@9F]R
M($944"!U<&QO860@;V8@<V-R:7!T<RX@*B\*("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O1F]R;2YP:'`G.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]687)I
M86)L97,N<&AP)SL*"B`@("`D=F%R<R`]("9687)I86)L97,Z.F=E=$1E9F%U
M;'1687)I86)L97,H*3L*("`@("1F='!F;W)M(#T@)DAO<F1E7T9O<FTZ.G-I
M;F=L971O;B@G)RP@)'9A<G,I.PH@("`@)&9T<&9O<FTM/G-E=%1I=&QE*%\H
M(D944"!U<&QO860@;V8@<V5T=7`B*2D["B`@("`D9G1P9F]R;2T^<V5T0G5T
M=&]N<RA?*")5<&QO860B*2P@=')U92D["B`@("`D9G1P9F]R;2T^861D5F%R
M:6%B;&4H7R@B57-E<FYA;64B*2P@)W5S97)N86UE)RP@)W1E>'0G+"!T<G5E
M+"!F86QS92P@;G5L;"P@87)R87DH)R<L(#(P*2D["B`@("`D9G1P9F]R;2T^
M861D5F%R:6%B;&4H7R@B4&%S<W=O<F0B*2P@)W!A<W-W;W)D)RP@)W!A<W-W
M;W)D)RP@9F%L<V4I.PH*("`@(&EF("@D9G1P9F]R;2T^=F%L:61A=&4H)'9A
M<G,I*2!["B`@("`@("`@)&9T<&9O<FTM/F=E=$EN9F\H)'9A<G,L("1I;F9O
M*3L*("`@("`@("`D=7!L;V%D(#T@7W5P;&]A9$944"@D:6YF;RD["B`@("`@
M("`@:68@*"1U<&QO860I('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"A?*")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BXB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@
M("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O
M:6YD97@N<&AP)RP@=')U92D["B`@("`@("`@("`@(&AE861E<B@G3&]C871I
M;VXZ("<@+B`D=7)L*3L*("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@
M("!]"B`@("`O*B!296YD97(@=&AE(&9O<FTN("HO"B`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*("`@("1R96YD97)E<B`]
M("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@I.PH@("`@)&9T<&9O<FT@/2!5
M=&EL.CIB=69F97)/=71P=70H87)R87DH)&9T<&9O<FTL("=R96YD97)!8W1I
M=F4G*2P@)')E;F1E<F5R+"`D=F%R<RP@)VEN9&5X+G!H<"<L("=P;W-T)RD[
M"GT*"FEF("AF:6QE7V5X:7-T<RA(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R]H
M;W)D95]S971U<%]U<&=R861E+G!H<"<I*2!["B`@("`O*B!!8W1I;VX@=&\@
M<F5M;W9E('1H92!C;VYF:6=U<F%T:6]N('5P9W)A9&4@4$A0('-C<FEP="X@
M*B\*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP)RD["B`@("`D=7)L(#T@571I;#HZ861D4&%R86UE
M=&5R*"1U<FPL("=C;&5A;B<L("=T;7`G*3L*("`@("1A8W1I;VX@/2!?*")2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB*3L*("`@("1A8W1I;VYS6UT@/2!A<G)A>2@G:6-O;B<@/3X@
M2&]R9&4Z.FEM9R@G9&5L971E+G!N9R<L("<G+"`G86QI9VX](FUI9&1L92(G
M+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`G;&EN:R<@/3X@2&]R9&4Z.FQI;FLH)'5R;"D@+B`D
M86-T:6]N("X@)SPO83XG*3L*?0H*+RH@4V5T('5P('1H92!T96UP;&%T92X@
M*B\*)'1E;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T92@I.PHD=&5M<&QA
M=&4M/G-E="@G87!P<R<L("1A<'!S*3L*)'1E;7!L871E+3YS970H)V%C=&EO
M;G,G+"`D86-T:6]N<RP@=')U92D["B1T96UP;&%T92T^<V5T*"=F='!F;W)M
M)RP@)&9T<&9O<FTL('1R=64I.PHD=&5M<&QA=&4M/G-E="@G;F]T:69Y)RP@
M571I;#HZ8G5F9F5R3W5T<'5T*&%R<F%Y*"1N;W1I9FEC871I;VXL("=N;W1I
M9GDG*2DI.PHD=&5M<&QA=&4M/G-E=$]P=&EO;B@G9V5T=&5X="<L('1R=64I
M.PH*)'1I=&QE(#T@<W!R:6YT9BA?*"(E<R!3971U<"(I+"`D<F5G:7-T<GDM
M/F=E="@G;F%M92<L("=H;W)D92<I*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)W-T<FEP92YJ<R<L("=H;W)D92<L('1R=64I.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PIE8VAO
M("1T96UP;&%T92T^9F5T8V@H2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL)RD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3`U,S8`,3`T,3<S-C(W-C``,#(Q,#4T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!'96YE<F%T97,@
M=7!G<F%D92!S8W)I<'1S(&9O<B!(;W)D92=S('-E='5P+B!#=7)R96YT;'D@
M86QL;W=S('1H92!G96YE<F%T:6]N"B`J(&]F(%!(4"!U<&=R861E('-C<FEP
M=',@9F]R(&-O;F8N<&AP(&9I;&5S(&5I=&AE<B!A<R!D;W=N;&]A9"!O<B!S
M879E9"!T;R!T:&4*("H@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X*
M("H*("H@)$AO<F1E.B!H;W)D92]A9&UI;B]S971U<"]S8W)I<'1S+G!H<"QV
M(#$N.2XQ,"XU(#(P,#8O,#$O,3D@,3@Z,#0Z,#`@<VQU<V%R>B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N
M(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"F1E
M9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N
M+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP
M)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ9F%T86PH
M)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"@HO*B!'970@
M9F]R;2!D871A+B`J+PHD<V5T=7`@/2!5=&EL.CIG971&;W)M1&%T82@G<V5T
M=7`G*3L*)'1Y<&4@/2!5=&EL.CIG971&;W)M1&%T82@G='EP92<I.PHD<V%V
M92`](%5T:6PZ.F=E=$9O<FU$871A*"=S879E)RD["B1C;&5A;B`](%5T:6PZ
M.F=E=$9O<FU$871A*"=C;&5A;B<I.PH*)&9I;&5N86UE(#T@)VAO<F1E7W-E
M='5P7W5P9W)A9&4N<&AP)SL*"B\J($-H96-K(&EF('1H:7,@:7,@;VYL>2!A
M(')E<75E<W0@=&\@8VQE86X@=7`N("HO"FEF("@D8VQE86X@/3T@)W1M<"<I
M('L*("`@("1T;7!?9&ER(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*3L*("`@("1P
M871H(#T@571I;#HZ<F5A;%!A=&@H)'1M<%]D:7(@+B`G+R<@+B`D9FEL96YA
M;64I.PH@("`@:68@*'5N;&EN:R@D=&UP7V1I<B`N("<O)R`N("1F:6QE;F%M
M92DI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(BDL("1P871H
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T@96QS92!["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D-O=6QD(&YO="!D96QE=&4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(I+"!5=&EL.CIR96%L4&%T
M:"@D<&%T:"DI+"`G:&]R9&4N97)R;W(G*3L*("`@('T*("`@("1R96=I<W1R
M>2T^8VQE87)#86-H92@I.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G861M:6XO<V5T=7`O:6YD97@N<&AP)RP@=')U92D["B`@("!H96%D
M97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HD9&%T82`]
M("<G.PII9B`H)'-E='5P(#T]("=C;VYF)R`F)B`D='EP92`]/2`G<&AP)RD@
M>PH@("`@+RH@02!B:70@=6=L>2!H97)E+"!S879E(%!(4"!C;V1E(&EN=&\@
M82!S=')I;F<@9F]R(&-R96%T:6YG('1H92!S8W)I<'0*("`@("`J('1O(&)E
M(')U;B!A="!T:&4@8V]M;6%N9"!P<F]M<'0N("HO"B`@("`D9&%T82`]("<C
M(2]U<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`G("X@(EQN(CL*("`@("1D
M871A("X]("<\/W!H<"<@+B`B7&XB.PH@("`@9F]R96%C:"`H)%]315-324].
M6R=?8V]N9FEG)UT@87,@)&%P<"`]/B`D<&AP*2!["B`@("`@("`@)'!A=&@@
M/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG
M)SL*("`@("`@("`O*B!!9&0@8V]D92!T;R!S879E(&)A8VMU<"X@*B\*("`@
M("`@("`D9&%T82`N/2`G:68@*&9I;&5?97AI<W1S*%PG)R`N("1P871H("X@
M)R]C;VYF+G!H<%PG*2D@>R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@
M("`@:68@*$!C;W!Y*%PG)R`N("1P871H("X@)R]C;VYF+G!H<%PG+"!<)R<@
M+B`D<&%T:"`N("<O8V]N9BYP:'`N8F%K7"<I*2![)R`N(")<;B(["B`@("`@
M("`@)&1A=&$@+CT@)R`@("`@("`@96-H;R!<)R<@+B!?*")3=6-C97-S9G5L
M;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(BD@+B`G7"<@+B`B7&XB
M.R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@("`@?2!E;'-E('LG("X@
M(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@("`@("!E8VAO(%PG)R`N(%\H
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB*2`N("=<
M)R`N(")<;B([)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!])R`N
M(")<;B(["B`@("`@("`@)&1A=&$@+CT@)WTG("X@(EQN(CL*"B`@("`@("`@
M)&1A=&$@+CT@)VEF("@D9G`@/2!`9F]P96XH7"<G("X@)'!A=&@@+B`G+V-O
M;F8N<&AP7"<L(%PG=UPG*2D@>R<@+B`B7&XB.PH@("`@("`@("1D871A("X]
M("<@("`@9G=R:71E*"1F<"P@7"<G.PH@("`@("`@("1D871A("X](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H<W1R7W)E<&QA8V4H87)R87DH)UQ<)RP@)UPG
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G7%Q<7"<L("=<7%PG)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($Y,
M4SHZ9V5T0VAA<G-E="@I+"`G:7-O+3@X-3DM,2<I.PH@("`@("`@("1D871A
M("X]("=<)RD[)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!F8VQO
M<V4H)&9P*3LG("X@(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@(&5C:&\@
M7"<G("X@<W!R:6YT9BA?*")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(I+"`D
M87!P*2`N("=<)R`N(")<;B([)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@
M)WT@96QS92![)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!E8VAO
M(%PG)R`N('-P<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BXB*2P@)&%P<"D@+B`G7"<@+B`B7&XB.R<@+B`B7&XB.PH@("`@("`@
M("1D871A("X]("=])R`N(")<;EQN(CL*("`@('T*?0H*:68@*"1S879E(#T]
M("=T;7`G*2!["B`@("`D=&UP7V1I<B`]($AO<F1E.CIG971496UP1&ER*"D[
M"B`@("`O*B!!9&0@<V5L9BUD97-T<G5C="!C;V1E+B`J+PH@("`@)&1A=&$@
M+CT@)V5C:&\@7"=396QF+61E<W1R=6-T:6YG+BXN7"<@+B`B7&XB.R<@+B`B
M7&XB.PH@("`@)&1A=&$@+CT@)VEF("AU;FQI;FLH7U]&24Q%7U\I*2![)R`N
M(")<;B(["B`@("`D9&%T82`N/2`G("`@(&5C:&\@7"<G("X@7R@B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB*2`N("=<)R`N(")<;B([)R`N(")<;B(["B`@
M("`D9&%T82`N/2`G?2!E;'-E('LG("X@(EQN(CL*("`@("1D871A("X]("<@
M("`@96-H;R!<)R<@+B!S<')I;G1F*%\H(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(I+"`D=&UP7V1I<BD@+B`G7"<@+B`B
M7&XB.R<@+B`B7&XB.PH@("`@)&1A=&$@+CT@)WTG("X@(EQN(CL*("`@("\J
M(%1H92!S8W)I<'0@<VAO=6QD(&)E('-A=F5D('1O('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN("HO"B`@("`D<&%T:"`](%5T:6PZ.G)E86Q0871H
M*"1T;7!?9&ER("X@)R\G("X@)&9I;&5N86UE*3L*("`@(&EF("@D9G`@/2!`
M9F]P96XH)'1M<%]D:7(@+B`G+R<@+B`D9FEL96YA;64L("=W)RDI('L["B`@
M("`@("`@9G=R:71E*"1F<"P@)&1A=&$I.PH@("`@("`@(&9C;&]S92@D9G`I
M.PH@("`@("`@(&-H;6]D*"1T;7!?9&ER("X@)R\G("X@)&9I;&5N86UE+"`P
M-S<W*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB*2P@)'!A
M=&@I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@?2!E;'-E('L*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB*2P@)'!A=&@I+"`G
M:&]R9&4N97)R;W(G*3L*("`@('T*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I.PH@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?2!E;'-E
M('L*("`@("\J($]U='!U="!S8W)I<'0@=&\@8G)O=W-E<B!F;W(@9&]W;FQO
M860N("HO"B`@("`D8G)O=W-E<BT^9&]W;FQO861(96%D97)S*"1F:6QE;F%M
M92P@)W1E>'0O<&QA:6XG+"!F86QS92P@<W1R;&5N*"1D871A*2D["B`@("!E
M8VAO("1D871A.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO;&]C86QE+P``````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<V,``P,38W-3$`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]L
M;V-A;&4O96Y?55,O````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8P`#`Q-S<V,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]E;E]54R]H96QP+GAM;```````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,R,38`,3`T,3<S-C(W-C``,#(Q
M-#,S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_>&UL('9E<G-I;VX])S$N,"<_/@H\(2TM("1(;W)D93H@:&]R9&4O861M
M:6XO;&]C86QE+V5N7U53+VAE;'`N>&UL+'8@,2XS(#(P,#,O,#8O,30@,#0Z
M,C@Z,C$@8VAU8VL@17AP("0@+2T^"CQH96QP/@H*/&5N=')Y(&ED/2)A9&UI
M;BUP:'!S:&5L;"(^"B`@("`\=&ET;&4^061M:6X@5&]O;',Z(%!(4"!3:&5L
M;#PO=&ET;&4^"B`@("`\:&5A9&EN9SY(;W<@=&\@=7-E('1H92!02%`@4VAE
M;&P\+VAE861I;F<^"B`@("`\<&%R83Y4:&4@4$A0(&-O;6UA;F0@<VAE;&P@
M;&5T<R!Y;W4@97AE8W5T92!A<F)I=')A<GD@4$A0"B`@("`@("`@("!S=&%T
M96UE;G1S(&]N('1H92!S97)V97(N(%1H97-E(&-O;6UA;F1S(&%R92!E>&5C
M=71E9"!U<VEN9PH@("`@("`@("`@=&AE(#QC;V1E/F5V86PH*3PO8V]D93X@
M9G5N8W1I;VXL(&%N9"!E>&5C=71E(&EN('1H92!C;VYT97AT"B`@("`@("`@
M("!O9B!T:&4@8W5R<F5N="!S97-S:6]N+B!4:&ES('-H96QL(&ES(&EN=&5N
M9&5D('1O('1R>2!O=70*("`@("`@("`@('-Y;G1A>"!A;F0@97AE8W5T92!S
M;VUE('-I;7!L92!A<F)I=')A<GD@8V]D92X@3F]T92!T:&%T('1O"B`@("`@
M("`@("!G970@86YY(&]U='!U="P@>6]U(&UU<W0@96-H;R!O<B!P<FEN="!S
M;VUE=&AI;F<@:6X@>6]U<@H@("`@("`@("`@8V]D92!F<F%G;65N="X\+W!A
M<F$^"CPO96YT<GD^"@H\96YT<GD@:60](F%D;6EN+7-Q;'-H96QL(CX*("`@
M(#QT:71L93Y!9&UI;B!4;V]L<SH@4U%,(%-H96QL/"]T:71L93X*("`@(#QH
M96%D:6YG/DAO=R!T;R!U<V4@=&AE(%-13"!3:&5L;#PO:&5A9&EN9SX*("`@
M(#QP87)A/E1H92!344P@<75E<GD@<VAE;&P@;&5T<R!Y;W4@97AE8W5T92!A
M<F)I=')A<GD@4U%,"B`@("`@("`@("!S=&%T96UE;G1S(&]N('EO=7(@9&%T
M86)A<V4N(%1H97-E(&-O;6UA;F1S(&%R92!E>&5C=71E9`H@("`@("`@("`@
M86=A:6YS="!T:&4@9&%T86)A<V4@9&5F:6YE9"!I;B`D8V]N9ELG<W%L)UT@
M=7-I;F<@=&AE"B`@("`@("`@("!014%2.CI$0B!C;&%S<V5S+B!9;W4@8V%N
M('5S92!T:&ES('1O;VP@=&\@9&\@<75E<FEE<R!I;G1O"B`@("`@("`@("!T
M:&4@9&%T86)A<V4L('1O(&1O(&-O;7!L:6-A=&5D(%-13"!U<&1A=&5S+"!D
M96QE=&5S+"!E=&,N+`H@("`@("`@("`@;W(@=&\@9&\@<VEM<&QE(&1A=&$@
M8V]L;&5C=&EO;BX@270@<V5N9',@4U%,('%U97)I97,@=&\@=&AE"B`@("`@
M("`@("!D871A8F%S92!D:7)E8W1L>2P@86YD('=I;&P@<F5P;W)T(')E='5R
M;B!C;V1E<R!A;F0@8V]M<&QE=&4*("`@("`@("`@(')E<W5L="!S971S+CPO
M<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB861M:6XM8VUD<VAE;&PB/@H@
M("`@/'1I=&QE/D%D;6EN(%1O;VQS.B!#;VUM86YD(%-H96QL/"]T:71L93X*
M("`@(#QH96%D:6YG/DAO=R!T;R!U<V4@=&AE($-O;6UA;F0@4VAE;&P\+VAE
M861I;F<^"B`@("`\<&%R83Y4:&4@8V]M;6%N9"!S:&5L;"!L971S('EO=2!E
M>&5C=71E(&%R8FET<F%R>2!S:&5L;`H@("`@("`@("`@8V]M;6%N9',@;VX@
M>6]U<B!S97)V97(N(%EO=2!C86X@=7-E('1H:7,@=&\@9&\@<75I8VL*("`@
M("`@("`@('-H96QL(&]P97)A=&EO;G,@;W(@=VAE;B!A('-H96QL(&ES(&YO
M="!O=&AE<G=I<V4@879A:6QA8FQE+@H@("`@("`@("`@/"]P87)A/@H\+V5N
M=')Y/@H*/"]H96QP/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]A9&UI;B]L;V-A;&4O9FE?1DDO````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8P`#`Q-S<R-0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]F:5]&22]H96QP
M+GAM;```````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R-C$`,3`T
M,3<S-C(W-C``,#(Q,S<W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D
M93H@:&]R9&4O861M:6XO;&]C86QE+V9I7T9)+VAE;'`N>&UL+'8@,2XQ+C$R
M+C(@,C`P-B\P,B\R."`Q-#HP,CHS-2!J86X@17AP("0@+2T^"CQH96QP/@H@
M(#QE;G1R>2!I9#TB861M:6XM<&AP<VAE;&PB(&UD-3TB9#4P,3<U.3%E9C1A
M,V8S.60Y-S@W8C4X,6$P86)B834B('-T871E/2)U<'1O9&%T92(^"B`@("`\
M=&ET;&4^66QL)B-X130[<&ED;VX@='DF(WA&-CMK86QU=#H@4$A0+6MO;65N
M=&]T=6QK:VD\+W1I=&QE/@H@("`@/&AE861I;F<^36ET96X@4$A0+6MO;65N
M=&]T=6QK:VEA(&LF(WA%-#MY=&5T)B-X130[)B-X130[;CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@4$A0+6MO;65N=&]T=6QK:VES<V$@=F]I('-U;W)I
M='1A82!P86QV96QI;65L;&$@;6ET)B-X130[('1A:&%N<V$*("`@(%!(4"UK
M;VUE;G1O:F$N($XF(WA%-#MM)B-X130[(&MO;65N;F]T('-U;W)I=&5T86%N
M(#QC;V1E/F5V86PH*3PO8V]D93X*("`@(&9U;FMT:6]N('-I<R8C>$4T.VQL
M)B-X130[(&IA(&YY:WEI<V5N(&ES='5N;F]N(&MO;G1E:W-T:7-S82X@5"8C
M>$4T.VTF(WA%-#L*("`@(&MO;65N=&]T=6QK:VD@;VX@96YS:7-I:F%I<V5S
M=&D@=&%R:V]I=&5T='4@<WEN=&%K<VEN"B`@("!T87)K:7-T=6MS965N(&IA
M('EK<VEN:V5R=&%I<V5N(&MO;V1I;B!S=6]R:71U:W-E96XN($AU;VUA82P*
M("`@(&5T="8C>$4T.R!T=6QO<W1A86MS97-I(&IO=&%K:6XL(&YI:6X@<VEN
M=6X@<&ET)B-X130[)B-X130[(&LF(WA%-#MY='0F(WA%-#LF(WA%-#L@96-H
M;R!J80H@("`@<')I;G0@:V]M96YT;VIA+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB861M:6XM<W%L<VAE;&PB(&UD-3TB-6)D,F9C8CEC
M.38W.&4V,F-A,30Q-38V86(X9C1C-&8B('-T871E/2)U<'1O9&%T92(^"B`@
M("`\=&ET;&4^66QL)B-X130[<&ED;VX@='DF(WA&-CMK86QU=#H@4U%,+6MO
M;65N=&]T=6QK:VD\+W1I=&QE/@H@("`@/&AE861I;F<^36ET96X@4U%,+6MO
M;65N=&]T=6QK:VEA(&LF(WA%-#MY=&5T)B-X130[)B-X130[;CPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@4U%,+6MO;65N=&]T=6QK:7-S82!V;VD@<W5O
M<FET=&%A(&UI="8C>$4T.R!T86AA;G-A(%-13"UL875S96MK96ET82P@:F]T
M:V$*("`@('-U;W)I=&5T86%N('1I971O:V%N;F%S<V$N($LF(WA%-#MY=&5T
M="8C>$4T.W8F(WA%-#L@=&EE=&]K86YT82!O;@H@("`@;28C>$4T.R8C>$4T
M.W)I=&5L='D@)&-O;F9;)W-Q;"==(&IA('-I="8C>$4T.R!K)B-X130[>71E
M="8C>$4T.R8C>$4T.VX@4$5!4CI$0BUL=6]K86X*("`@(&%V=6QL82X@(%9O
M:70@:R8C>$4T.WET="8C>$4T.R8C>$4T.R!T)B-X130[="8C>$4T.R!T>28C
M>$8V.VMA;'5J82!T96AD)B-X130[:W-E<VD@:WES96QY:B8C>$4T.PH@("`@
M=&EE=&]K86YT86%N+"!P)B-X130[:79I='0F(WA%-#LF(WA%-#MK<V5S:2!T
M:65T;VIA('1I971O:V%N;F%S<V$L"B`@("!P;VES=&%A:W-E<VD@=&EE=&]J
M82!T:65T;VMA;FYA<W1A(&IN92X@=&%I(&AA:V5A('1I971O:F$*("`@('1I
M971O:V%N;F%S=&$N(%-13"UK;VUE;FYO="!L)B-X130[:&5T970F(WA%-#LF
M(WA%-#MN('-U;W)A86X@=&EE=&]K86YN86QL90H@("`@:F$@<&%L=75A<G9O
M;F$@='5L964@<W1A='5S:V]O9&D@:F$@:WES96QY;B!P86QA=71T86UA"B`@
M("!A<G9O+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB861M
M:6XM8VUD<VAE;&PB(&UD-3TB.61B8F4U.3,W,S5E96)B8C,T9&4Y.3%A-3=B
M.3AB.68B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^66QL)B-X130[
M<&ED;VX@='DF(WA&-CMK86QU=#H@2V]M96YT;W1U;&MK:3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY-:71E;B!K;VUE;G1O='5L:VMI82!K)B-X130[>71E="8C
M>$4T.R8C>$4T.VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@($MO;65N=&]T
M=6QK:6X@879U;&QA('9O:70@<W5O<FET=&%A(&MO;65N=&]J82!W=W<M<&%L
M=F5L:6UE;&QA+B!6;VET(&LF(WA%-#MY='0F(WA%-#LF(WA%-#L@="8C>$4T
M.W0F(WA%-#L@=&]I;6EN=&]A(&MU;B!H86QU870@;F]P96%S=&D@<W5O<FET
M=&%A(&IO;FMU;B!K;VUE;FYO;B!P86QV96QI;65L;&$@:F$@:V]M96YT;W1U
M;&MK:2!E:2!O;&4@;75U=&5N(&LF(WA%-#MY=&5T="8C>$4T.W9I<W,F(WA%
M-#LN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L
M92]H=5](52\`````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-C``,#$W-S8Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O861M:6XO;&]C86QE+VAU7TA5+VAE;'`N>&UL````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<V,P`Q,#0Q-S,V,C<V,``P,C$T-#$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,B(_/@H\(2TM
M($AO<F1E(#,N,2!!9&UI;B!H96QP.B!H=5](52`D2&]R9&4Z(&AO<F1E+V%D
M;6EN+VQO8V%L92]H=5](52]H96QP+GAM;"QV(#$N,2XR+C$@,C`P-B\P,R\P
M,R`Q,SHT-#HQ,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M861M:6XM<&AP<VAE;&PB('-T871E/2)U<'1O9&%T92(@;60U/2)D-3`Q-S4Y
M,65F-&$S9C,Y9#DW.#=B-3@Q83!A8F)A-2(^"B`@("`\=&ET;&4^061M:6YI
M<WIT<N%C:?-S(&5S>FOV>O9K.B!A(%!(4"!3:&5L;#PO=&ET;&4^"B`@("`\
M:&5A9&EN9SY!(%!(4"!3:&5L;"!H87-Z;N%L871A/"]H96%D:6YG/@H@("`@
M/'!A<F$^02!02%`@<&%R86YC<^ER=&5L;65Z]2!S96?M='/I9^EV96P@=&5T
M<WKU;&5G97,@4$A0('!A<F%N8W-O:V%T"B`@("`@("`@("!H86IT:&%T(';I
M9W)E(&$@<WIE<G9E<F5N+B!%>F5K970@82!P87)A;F-S;VMA="!A(&?I<"!A
M>B`*("`@("`@("`@(#QC;V1E/F5V86PH*3PO8V]D93X@9OQG9W;I;GD@<V5G
M[71SZ6?I=F5L+"!A>B!A:W1UX6QI<V%N(.ER=NEN>65S"B`@("`@("`@("!S
M97-S:6]N(&ME<F5TZ6)E;B!H86IT:F$@=NEG<F4N($4@<&%R86YC<^ER=&5L
M;65Z]2!CZ6QJ82P@:&]G>0H@("`@("`@("`@:VD@='5D:G5N:R!P<O-BX6QN
M:2!T971S>O5L96=E<RP@96=Y<WIE<OMB8B!K\V1RZ7-Z;&5T96ME="X@"B`@
M("`@("`@("!!:&AO>B!A>F]N8F%N+"!H;V=Y(&+A<FUI;'EE;B!O=71P=71O
M="!LX7-S=6YK+"!A(&OS9&YA:R!E8VAO"B`@("`@("`@("!V86=Y('!R:6YT
M('!A<F%N8W-O:V%T(&ME;&P@=&%R=&%L;6%Z;FEA+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB861M:6XM<W%L<VAE;&PB('-T871E/2)U
M<'1O9&%T92(@;60U/2(U8F0R9F-B.6,Y-C<X938R8V$Q-#$U-C9A8CAF-&,T
M9B(^"B`@("`\=&ET;&4^061M:6YI<WIT<N%C:?-S(&5S>FOV>O9K.B!A>B!3
M44P@4VAE;&P\+W1I=&QE/@H@("`@/&AE861I;F<^07H@4U%,(%-H96QL(&AA
M<WINX6QA=&$\+VAE861I;F<^"B`@("`\<&%R83Y!>B!344P@<&%R86YC<^ER
M=&5L;65Z]2!S96?M='/I9^EV96P@=&5T<WKU;&5G97,@4U%,('!A<F%N8W-O
M=`H@("`@("`@("`@:&%J=&AA="!VZ6=R92!A>B!A9&%T8N%Z:7-O;BX@17IE
M:V5T(&$@<&%R86YC<V]K870@82!GZ7`@82!014%2.CI$0@H@("`@("`@("`@
M<NEVZ6X@:&%J=&IA(';I9W)E(&$@)&-O;F9;)W-Q;"==+6)E;B!M96=A9&]T
M="!A9&%T8F%Z:7-O;BX*("`@("`@("`@($5Z>F5L(&%Z(&5S>FOV>GIE;"!L
M96OI<F1E>NES96ME="P@8F]N>6]L=6QT(%-13"!M\V1O<^UTX7-O:V%T+`H@
M("`@("`@("`@=/9R;.ES96ME="!H86IT:&%T(';I9W)E+"!V86=Y(&%D871O
M:V%T(&=Y^VIT:&5T+B!!>B!344P@<&%R86YC<V]K870*("`@("`@("`@(&OV
M>G9E=&QE;OQL(&%Z(&%D871BX7II<VYA:R!K_&QD:2P@;6%J9"!V:7-S>F%A
M9&IA(&%Z(&5R961MZ6YY:_-D;VMA=`H@("`@("`@("`@:6QL+B!A(&MA<&]T
M="!A9&%T;VMA="X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(F%D;6EN+6-M9'-H96QL(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB.61B8F4U
M.3,W,S5E96)B8C,T9&4Y.3%A-3=B.3AB.68B/@H@("`@/'1I=&QE/D%D;6EN
M:7-Z='+A8VGS<R!E<WIK]GKV:SH@82!P87)A;F-S<V]R/"]T:71L93X*("`@
M(#QH96%D:6YG/D$@<&%R86YC<W-O<B!H87-Z;N%L871A/"]H96%D:6YG/@H@
M("`@/'!A<F$^02!P87)A;F-S<V]R('-E9^UT<^EGZ79E;"!P87)A;F-S;VMA
M="!H86IT:&%T(';I9W)E(&$@<WIE<G9E<F5N+@H@("`@("`@("`@17H@96=Y
M+65G>2!P87)A;F-S(&=Y;W)S(';I9W)E:&%J=.%SX7)A(&KS+"!V86=Y(&%R
M<F$@87H@97-E=')E+"!H80H@("`@("`@("`@;>%S(&WS9&]N(&YE;2!KZ7!E
M<R!A('-Z97)V97(@<&%R86YC<^ER=&5L;65Z]6KI:&5Z("A#;VUM86YD(%-H
M96QL*0H@("`@("`@("`@:G5T;FEA+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\
M+VAE;'`^"@`````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+V%D;6EN+W-E<W-I;VYS+G!H<```````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#0P,C0`,3`T,3<S-C(W-C``,#(P,#8V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W-E<W-I;VYS+G!H<"QV(#$N,BXR
M+C,@,C`P-B\P,2\P,2`R,3HR.#HP-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#4M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-
M96YU+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;DAA;F1L97(N
M<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T
M:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)'1Y<&4@/2`A96UP
M='DH)&-O;F9;)W-E<W-I;VYH86YD;&5R)UU;)W1Y<&4G72D@/R`D8V]N9ELG
M<V5S<VEO;FAA;F1L97(G75LG='EP92==(#H@)VYO;F4G.PII9B`H)'1Y<&4@
M/3T@)V5X=&5R;F%L)RD@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#
M86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(BDL
M("=H;W)D92YE<G)O<B<I.PI](&5L<V4@>PH@("`@)'-H(#T@)E-E<W-I;VY(
M86YD;&5R.CIS:6YG;&5T;VXH)'1Y<&4I.PI]"@HD=&ET;&4@/2!?*")397-S
M:6]N($%D;6EN(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM
M;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A
M9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF
M>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PH*:68@*"%E;7!T
M>2@D<V@I*2!["B`@("`D=7-E<G,@/2`D<V@M/FQI<W1!=71H96YT:6-A=&5D
M57-E<G,H*3L*("`@("1C;W5N="`]("1S:"T^8V]U;G1!=71H96YT:6-A=&5D
M57-E<G,H*3L*("`@(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B
M0W5R<F5N="!5<V5R<R(I.PH@("`@:68@*&ES7V$H)'5S97)S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@96-H;R`G/"]H,3X\<"!C;&%S<STB:&5A9&5R
M8F]X(CX\96T^)R`N('-P<FEN=&8H7R@B3&ES=&EN9R!U<V5R<R!F86EL960Z
M("5S(BDL("1U<V5R<RT^9V5T365S<V%G92@I*2`N("<\+V5M/CPO<#XG.PH@
M("`@?2!E;'-E('L*("`@("`@("!E8VAO("<@*"<@+B`D8V]U;G0@+B`G*3PO
M:#$^)SL*("`@("`@("!E8VAO("<\=6P@8VQA<W,](FAE861E<F)O>"!L:6YE
M9%)O=R(^)SL*("`@("`@("!F;W)E86-H("@D=7-E<G,@87,@)'5S97(I('L*
M("`@("`@("`@("`@96-H;R`G/&QI/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1U
M<V5R*2`N("<\+VQI/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SPO=6P^
M)SL*("`@('T*"B`@("!E8VAO("<\8G(@+SXG.PH*("`@("1I9',@/2`D<V@M
M/F=E=%-E<W-I;VY)1',H*3L*("`@(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R
M(CXG("X@7R@B0W5R<F5N="!397-S:6]N<R(I("X@)SPO:#$^)SL*("`@(&EF
M("AI<U]A*"1I9',L("=014%27T5R<F]R)RDI('L*("`@("`@("!E8VAO("<\
M<"!C;&%S<STB:&5A9&5R8F]X(CX\96T^)R`N('-P<FEN=&8H7R@B3&ES=&EN
M9R!S97-S:6]N<R!F86EL960Z("5S(BDL("1I9',M/F=E=$UE<W-A9V4H*2D@
M+B`G/"]E;3X\+W`^)SL*("`@('T@96QS92!["B`@("`@("`@96-H;R`G/'5L
M(&-L87-S/2)H96%D97)B;W@@;&EN9612;W<B/B<["B`@("`@("`@9F]R96%C
M:"`H)&ED<R!A<R`D=7-E<BD@>PH@("`@("`@("`@("!E8VAO("<\;&D^)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I("X@)SPO;&D^)SL*("`@("`@("!]
M"B`@("`@("`@96-H;R`G/"]U;#XG.PH@("`@?0I]"@IR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+V%D;6EN+V-M9'-H96QL+G!H<```````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,R-3,`,3`T,3<S-C(W-C``
M,#(P,#$V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+V-M9'-H96QL
M+G!H<"QV(#$N.2XQ,"XV(#(P,#8O,#(O,C0@,C(Z-#@Z,CD@8VAU8VL@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G
M2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M2&5L<"YP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E
M.CIF871A;"@G1F]R8FED9&5N+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*
M"B1T:71L92`](%\H(D-O;6UA;F0@4VAE;&PB*3L*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*"F5C
M:&\@)SQD:78@<W1Y;&4](G!A9&1I;F<Z,3!P>"(^)SL*:68@*"1C;VUM86YD
M(#T@=')I;2A5=&EL.CIG971&;W)M1&%T82@G8VUD)RDI*2!["B`@("!E8VAO
M("<\:#$@8VQA<W,](FAE861E<B(^)R`N(%\H(D-O;6UA;F0B*2`N("<Z/"]H
M,3X\8G(@+SXG.PH@("`@96-H;R`G/'`@8VQA<W,](G1E>'0B/CQC;V1E/B<@
M+B!N;#)B<BAH=&UL<W!E8VEA;&-H87)S*"1C;VUM86YD*2D@+B`G/"]C;V1E
M/CPO<#XG.PH*("`@(&5C:&\@)SQB<B`O/CQH,2!C;&%S<STB:&5A9&5R(CXG
M("X@7R@B4F5S=6QT<R(I("X@)SH\+V@Q/CQB<B`O/B<["B`@("!E8VAO("<\
M<')E(&-L87-S/2)T97AT(CXG.PH*("`@("1C;61S(#T@97AP;&]D92@B7&XB
M+"`D8V]M;6%N9"D["B`@("!F;W)E86-H("@D8VUD<R!A<R`D8VUD*2!["B`@
M("`@("`@)&-M9"`]('1R:6TH)&-M9"D["B`@("`@("`@:68@*'-T<FQE;B@D
M8VUD*2D@>PH@("`@("`@("`@("!U;G-E="@D<F5S=6QT<RD["B`@("`@("`@
M("`@(&9L=7-H*"D["B`@("`@("`@("`@(&5C:&\@:'1M;'-P96-I86QC:&%R
M<RAS:&5L;%]E>&5C*"1C;60I*3L*("`@("`@("!]"B`@("!]"@H@("`@96-H
M;R`G/"]P<F4^/&)R("\^)SL*?0H_/@H*/&9O<FT@86-T:6]N/2(\/W!H<"!E
M8VAO("1?4T525D526R=02%!?4T5,1B==(#\^(B!M971H;V0](G!O<W0B/@H\
M/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/'1E>'1A<F5A(&-L87-S/2)F
M:7AE9"(@;F%M93TB8VUD(B!R;W=S/2(Q,"(@8V]L<STB-C`B/@H\/W!H<"!I
M9B`H(65M<'1Y*"1C;VUM86YD*2D@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C
M;VUM86YD*2`_/CPO=&5X=&%R96$^"CQB<B`O/@H\:6YP=70@='EP93TB<W5B
M;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")%>&5C
M=71E(BD@/SXB("\^"CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G861M:6XG+"`G
M861M:6XM8VUD<VAE;&PG*2`_/@H*/"]F;W)M/@H\+V1I=CX*/#]P:'`*"G)E
M<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]A9&UI;B]T96UP;&%T97,N<&AP````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,3,V`#$P-#$W,S8R-S8P`#`R,#(R
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@2&]R9&4@5&5M<&QA=&4@061M:6X*("H*("H@)$AO<F1E
M.B!H;W)D92]A9&UI;B]T96UP;&%T97,N<&AP+'8@,2XQ-2XQ,"XS(#(P,#8O
M,#$O,#$@,C$Z,C@Z,#4@:F%N($5X<"`D"B`J"B`J($9I<G-T('-T86(@870@
M82!T96UP;&%T92!L;V%D97(@9F]R(&AO<F1E+"!T;R!B92!U<V5D(&)Y('1H
M92!H;W)D90H@*B!A9&UI;B!T;R!L;V%D(&%L=&5R;F%T92!I;F1I=FED=6%L
M('1E;7!L871E<R!O<B!E;G1I<F4@=&AE;65S(&9O<B!T:&4*("H@2&]R9&5?
M5&5M<&QA=&4@<WES=&5M+@H@*B`M(&=I=F5S(&$@;&ES="!O9B!A8W1I=F4@
M:&]R9&4@87!P<R!A;F0@=&AE:7(@+W1E;7!L871E<R!D:7)E8W1O<GD*("H@
M("!C;VYT96YT<R!T;R!C:&]O<V4@9G)O;0H@*B`M('5S97(@8V%N(&1R:6QL
M(&1O=VX@=&\@82!S<&5C:69I8R!F:6QE(&%N9"!L;V%D(&%S(&UA;GD@86QT
M97)N871E"B`J("`@=&5M<&QA=&5S(&%S(')E<75I<F5D"B`J("T@:70@86QL
M;W=S('-A=FEN9R!O9B!T96UP;&%T97,@;VYL>2!O;B!A8W1U86P@9FEL97,@
M*&%N9"!N;W0*("H@("!D:7)E8W1O<FEE<RD@86YD(&1O97,@;F]T('-H;W<@
M:&ED9&5N(&9I;&5S+@H@*B`M('1H92!A;'1E<FYA=&4@=&5M<&QA=&5S(&%R
M92!S=&]R960@:6X@=&AE(%9&4R!U;F1E<B!T:&4@9&ER96-T;W)Y"B`J("`@
M<&%T:#H*("H@("`@("`N:&]R9&5?=&5M<&QA=&5S+R1A<'`O<V]M971E;7!L
M871E9&ER+W1E;7!L871E9FEL90H@*B`@('-O('1H870@9&ER96-T;W)Y('=O
M=6QD(&-O;G1A:6X@86QL('1H92!A;'1E<FYA=&EV97,@9F]R('1H870*("H@
M("!T96UP;&%T92X*("H@+2!43T1/.B!D;VXG="!S:&]W(&-E<G1A:6X@;W1H
M97(@9FEL97,L(&QI:V4@0U93(&1I<F5C=&]R:65S.R!C;VUM96YT<SL*("H@
M("!T:&5M92!S96QE8W1I;VX@86YD('-T;W)I;F<@:6X@=&AE(%9&4R!U;F1E
M<CH*("H@("`@("`N:&]R9&5?=&5M<&QA=&5S+R1A<'`O7W1H96UE<R\D=&AE
M;64O<V]M971E;7!L871E9&ER+W1E;7!L871E9FEL90H@*B`@('1O(&)E(&%B
M;&4@=&\@8V%L;"!U<"!A;B!E;G1I<F4@=&AE;64@9W)O=7`@;V8@=&5M<&QA
M=&5S/R!B971T97(@97)R;W(*("H@("!C:&5C:VEN9SL@9&]W;FQO861I;F<@
M;V8@;W)I9VEN86P@=&5M<&QA=&5S.R!T:&4@87!P;&EC871I;VX@<VED92!O
M9@H@*B`@(&%L;&]W:6YG(&$@9&EF9F5R96YT('1E;7!L871E('1O(&)E(&-H
M;W-E;B]P<F5F<R]E=&,N"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R
M:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*
M"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN
M*"DI('L*("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N+B<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["GT*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF
M6R=A=71H)UU;)V1R:79E<B==*3L*"F9U;F-T:6]N(%]S971686QU97-4;TME
M>7,H)&EN*2!["B`@("`D;W5T(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1I
M;B!A<R`D=F%L=64I('L*("`@("`@("`D;W5T6R1V86QU95T@/2`D=F%L=64[
M"B`@("!]"B`@("!A<V]R="@D;W5T*3L*("`@(')E='5R;B`D;W5T.PI]"@HO
M*B!3970@=7`@5D93+B`J+PIR97%U:7)E7V]N8V4@)U9&4RYP:'`G.PHD=F9S
M7W1Y<&4@/2`D8V]N9ELG=F9S)UU;)W1Y<&4G73L*)'9F<U]A<F=S(#T@2&]R
M9&4Z.F=E=$1R:79E<D-O;F9I9R@G=F9S)RP@)'9F<U]T>7!E*3L*)'9F<U]A
M<F=S6R=U<V5R)UT@/2!!=71H.CIG971!=71H*"D["B1V9G,@/2`F5D93.CIS
M:6YG;&5T;VXH)'9F<U]T>7!E+"`D=F9S7V%R9W,I.PH*0&1E9FEN92@G5$5-
M4$Q!5$537U9&4U]0051()RP@)RYH;W)D95]T96UP;&%T97,G*3L*"B\J(%)E
M<75I<F4@2&]R9&5?1F]R;2!L:6)S+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E
M+T9O<FTN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+U)E;F1E<F5R
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]!8W1I;VXN<&AP)SL*
M"B\J(%-E="!U<"!(;W)D95]&;W)M+B`J+PHD=F%R<R`]("9687)I86)L97,Z
M.F=E=$1E9F%U;'1687)I86)L97,H*3L*)&9O<FT@/2`F2&]R9&5?1F]R;3HZ
M<VEN9VQE=&]N*"=496UP;&%T97-&;W)M)RP@)'9A<G,I.PHD86-T:6]N(#T@
M)DAO<F1E7T9O<FU?06-T:6]N.CIF86-T;W)Y*"=S=6)M:70G*3L*"B\J(%-E
M="!U<"!F;W)M(&9I96QD<RX@*B\*)&%P<',@/2!?<V5T5F%L=65S5&]+97ES
M*"1R96=I<W1R>2T^;&ES=$%P<',H*2D["B1S96QE8W1?87!P(#T@)B1F;W)M
M+3YA9&1687)I86)L92A?*")!<'!L:6-A=&EO;B(I+"`G87!P)RP@)V5N=6TG
M+"!T<G5E+"!F86QS92P@;G5L;"P@87)R87DH)&%P<',I*3L*)'-E;&5C=%]A
M<'`M/G-E=$%C=&EO;B@D86-T:6]N*3L*)&9O<FTM/F%D9$AI9&1E;B@G)RP@
M)V]L9%]A<'`G+"`G=&5X="<L(&9A;'-E+"!F86QS92D["@HO*B!3970@=7`@
M<V]M92!V87)I86)L97,N("HO"B1F;W)M;F%M92`]("1V87)S+3YG970H)V9O
M<FUN86UE)RD["B1A<'`@/2`D=F%R<RT^9V5T*"=A<'`G*3L*)&]L9%]A<'`@
M/2`D=F%R<RT^9V5T*"=O;&1?87!P)RD["B1T96UP;&%T95]P871H(#T@)'9A
M<G,M/F=E="@G=&5M<&QA=&5?<&%T:"<I.PHD=&5M<&QA=&5?;W)I9R`]("1V
M87)S+3YG970H)W1E;7!L871E7V]R:6<G*3L*)&]L9%]T96UP;&%T95]O<FEG
M(#T@)'9A<G,M/F=E="@G;VQD7W1E;7!L871E7V]R:6<G*3L*)&AA<U]C:&%N
M9V5D(#T@9F%L<V4["@II9B`H)&%P<"`A/2`D;VQD7V%P<"D@>PH@("`@)&AA
M<U]C:&%N9V5D(#T@=')U93L*("`@("1T96UP;&%T95]P871H(#T@)R<["B`@
M("`D=&5M<&QA=&5?;W)I9R`]("<G.PH@("`@)&]L9%]T96UP;&%T95]O<FEG
M(#T@)R<["GT*)'9A<G,M/G-E="@G;VQD7V%P<"<L("1A<'`I.PII9B`H)'1E
M;7!L871E7V]R:6<@(3T@)&]L9%]T96UP;&%T95]O<FEG*2!["B`@("`D:&%S
M7V-H86YG960@/2!T<G5E.PI]"B1V87)S+3YS970H)V]L9%]T96UP;&%T95]O
M<FEG)RP@)'1E;7!L871E7V]R:6<I.PH*:68@*"%I<U]N=6QL*"1A<'`I*2![
M"B`@("!I9B`H)'1E;7!L871E7V]R:6<@/3T@)RXN)RD@>PH@("`@("`@("1P
M871H7W!A<G1S(#T@97AP;&]D92@G+R<L("1T96UP;&%T95]P871H*3L*("`@
M("`@("!A<G)A>5]P;W`H)'!A=&A?<&%R=',I.PH@("`@("`@("1T96UP;&%T
M95]P871H(#T@:6UP;&]D92@G+R<L("1P871H7W!A<G1S*3L*("`@("`@("`D
M=&5M<&QA=&5?;W)I9R`]("<G.PH@("`@?0H*("`@("\J($=E="!T:&4@9G5L
M;"!T96UP;&%T92!P871H(&]N('1H92!F:6QE('-Y<W1E;2X@*B\*("`@("1T
M96UP;&%T95]P871H7V9U;&P@/2`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S
M)RP@)&%P<"D@+B`G+R<@+B`D=&5M<&QA=&5?<&%T:#L*"B`@("`O*B!)9B!S
M96QE8W1E9"!T96UP;&%T92!I<R!D:7)E8W1O<GD@861D('1O('1E;7!L871E
M('!A=&@N("HO"B`@("!I9B`H(65M<'1Y*"1T96UP;&%T95]O<FEG*2`F)@H@
M("`@("`@(&ES7V1I<B@D=&5M<&QA=&5?<&%T:%]F=6QL("X@)R\G("X@)'1E
M;7!L871E7V]R:6<I*2!["B`@("`@("`@)'1E;7!L871E7W!A=&@@+CT@)R\G
M("X@)'1E;7!L871E7V]R:6<["B`@("`@("`@)'1E;7!L871E7W!A=&A?9G5L
M;"`N/2`G+R<@+B`D=&5M<&QA=&5?;W)I9SL*("`@('T*"B`@("`D9F]R;2T^
M861D5F%R:6%B;&4H<W!R:6YT9BA?*")/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z(BDL("1T96UP;&%T95]P871H*2P@)V]R:6=?=&5M<&QA=&5S7VAE861E
M<B<L("=H96%D97(G+"!F86QS92P@9F%L<V4I.PH*("`@("\J($%D9"!T:&4@
M<&%T:"!T;R!T:&4@:&ED9&5N('9A<B!I;B!T:&4@9F]R;2X@*B\*("`@("1F
M;W)M+3YA9&1(:61D96XH)R<L("=T96UP;&%T95]P871H)RP@)W1E>'0G+"!F
M86QS92P@9F%L<V4I.PH@("`@)'9A<G,M/G-E="@G=&5M<&QA=&5?<&%T:"<L
M("1T96UP;&%T95]P871H*3L*"B`@("`O*B!'970@9&ER96-T;W)Y(&QI<W0@
M9F]R(&-H;W-E;B!D:7)E8W1O<GD@:6X@=&5M<&QA=&5S+B`J+PH@("`@:68@
M*"1T96UP;&%T97-?9&ER(#T@;W!E;F1I<B@D=&5M<&QA=&5?<&%T:%]F=6QL
M*2D@>PH@("`@("`@('=H:6QE("AF86QS92`A/3T@*"1F:6QE(#T@<F5A9&1I
M<B@D=&5M<&QA=&5S7V1I<BDI*2!["B`@("`@("`@("`@("\J($1O;B=T('-H
M;W<@8W5R<F5N="!D:7(L(&AI9&1E;B!F:6QE<R!A;F0@;VYL>2!S:&]W("<N
M+B<*("`@("`@("`@("`@("H@:68@;F]T(&EN(')O;W0@9&ER(&]F(&%N(&%P
M<"=S('1E;7!L871E<RX@*B\*("`@("`@("`@("`@:68@*"1F:6QE("$]("(N
M(B`F)B`A*"1F:6QE(#T]("<N+B<@)B8@96UP='DH)'1E;7!L871E7W!A=&@I
M*2`F)@H@("`@("`@("`@("`@("`@(2@D9FEL92`A/2`G+BXG("8F('-U8G-T
M<B@D9FEL92P@,"P@,2D@/3T@)RXG*2D@>PH@("`@("`@("`@("`@("`@)'1E
M;7!L871E<UM=(#T@)&9I;&4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@8VQO<V5D:7(H)'1E;7!L871E<U]D:7(I.PH@("`@("`@("1T96UP
M;&%T97,@/2!?<V5T5F%L=65S5&]+97ES*"1T96UP;&%T97,I.PH@("`@("`@
M("1V(#T@)B1F;W)M+3YA9&1687)I86)L92A?*")/<FEG:6YA;"!A<'!L:6-A
M=&EO;B!T96UP;&%T92(I+"`G=&5M<&QA=&5?;W)I9R<L("=E;G5M)RP@=')U
M92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1T96UP;&%T97,I*3L*("`@("`@("`D
M=BT^<V5T06-T:6]N*"1A8W1I;VXI.PH@("`@("`@("1F;W)M+3YA9&1(:61D
M96XH)R<L("=O;&1?=&5M<&QA=&5?;W)I9R<L("=T97AT)RP@9F%L<V4L(&9A
M;'-E*3L*("`@('T*"B`@("`O*B!/;FQY('-E="!U<"!T:&5S92!V87)S(&EF
M('1H92!C:&]S96X@=&5M<&QA=&4@:7,@82!F:6QE+B`J+PH@("`@:68@*&ES
M7V9I;&4H)'1E;7!L871E7W!A=&A?9G5L;"`N("<O)R`N("1T96UP;&%T95]O
M<FEG*2D@>PH@("`@("`@("1F;W)M+3YA9&1687)I86)L92A?*")!;'1E<FYA
M=&4@=&5M<&QA=&5S(BDL("=A;'1?=&5M<&QA=&5S7VAE861E<B<L("=H96%D
M97(G+"!F86QS92P@9F%L<V4I.PH*("`@("`@("`O*B!'970@=&AE(&%L<F5A
M9'D@<V%V960@86QT97)N871E('1E;7!L871E<RX@*B\*("`@("`@("`D=F9S
M7W!A=&@@/2!414U03$%415-?5D937U!!5$@@+B`G+R<@+B`D87!P("X@)'1E
M;7!L871E7W!A=&@@+B`G+R<@+B`D=&5M<&QA=&5?;W)I9SL*("`@("`@("`D
M=&5M<&QA=&5S7V%L="`](&%R<F%Y7VME>7,H)'9F<RT^;&ES=$9O;&1E<B@D
M=F9S7W!A=&@L(&YU;&PL(&9A;'-E*2D["B`@("`@("`@)'1E;7!L871E<U]A
M;'0@/2!A<G)A>2@G)R`]/B`G)RD@*R!?<V5T5F%L=65S5&]+97ES*"1T96UP
M;&%T97-?86QT*3L*("`@("`@("`D9F]R;2T^861D5F%R:6%B;&4H7R@B1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(I+"`G9&5L971E7W1E
M;7!L871E7V%L="<L("=E;G5M)RP@9F%L<V4L(&9A;'-E+"!N=6QL+"!A<G)A
M>2@D=&5M<&QA=&5S7V%L="DI.PH*("`@("`@("`D9F]R;2T^861D5F%R:6%B
M;&4H7R@B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(I+"`G=&5M<&QA=&5?
M86QT)RP@)V9I;&4G+"!F86QS92P@9F%L<V4I.PH@("`@?0I]"@II9B`H)&9O
M<FUN86UE("8F("$D:&%S7V-H86YG960I('L*("`@("\J($EN<V5R=&EN9R!A
M(&YE=R!A;'1E<FYA=&4@=&5M<&QA=&4N("HO"B`@("`D9F]R;2T^=F%L:61A
M=&4H)'9A<G,I.PH*("`@(&EF("@D9F]R;2T^:7-686QI9"@I*2!["B`@("`@
M("`@)&9O<FTM/F=E=$EN9F\H)'9A<G,L("1I;F9O*3L*("`@("`@("!I9B`H
M(65M<'1Y*"1I;F9O6R=D96QE=&5?=&5M<&QA=&5?86QT)UTI*2!["B`@("`@
M("`@("`@("1V9G,M/F1E;&5T949I;&4H)'9F<U]P871H+"`D:6YF;ULG9&5L
M971E7W1E;7!L871E7V%L="==*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E
M;7!T>2@D:6YF;ULG=&5M<&QA=&5?86QT)UU;)W-I>F4G72DI('L*("`@("`@
M("`@("`@)'9F<RT^=W)I=&4H)'9F<U]P871H+"`D:6YF;ULG=&5M<&QA=&5?
M86QT)UU;)VYA;64G72P@)&EN9F];)W1E;7!L871E7V%L="==6R=T;7!?;F%M
M92==+"!T<G5E*3L*("`@("`@("!]"B`@("!]"GT*"B1T:71L92`](%\H(E1E
M;7!L871E($%D;6EN:7-T<F%T:6]N(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC
M871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI
M.PH*+RH@4F5N9&5R('1H92!F;W)M+B`J+PHD<F5N9&5R97(@/2`F;F5W($AO
M<F1E7T9O<FU?4F5N9&5R97(H*3L*)&9O<FTM/G)E;F1E<D%C=&EV92@D<F5N
M9&5R97(L("1V87)S+"`G=&5M<&QA=&5S+G!H<"<L("=P;W-T)RD["@IR97%U
M:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]U
M<V5R+G!H<```````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#(S-S<W`#$P-#$W,S8R-S8P`#`Q-S(Q-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]A9&UI;B]U<V5R+G!H<"QV(#$N-#<N,3`N-R`R,#`V+S`Q
M+S`Q(#(Q.C(X.C`U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O
M;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O
M<FTO4F5N9&5R97(N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L
M97,N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ
M9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"B1A
M=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==6R=D<FEV97(G
M72D["@II9B`H)&-O;F9;)W-I9VYU<"==6R=A;&QO=R==("8F("1C;VYF6R=S
M:6=N=7`G75LG87!P<F]V92==*2!["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<"<["B`@("`D<VEG;G5P(#T@)D%U=&A?4VEG;G5P
M.CIS:6YG;&5T;VXH*3L*?0H*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A
M=6QT5F%R:6%B;&5S*"D["B1A9&1&;W)M(#T@)FYE=R!(;W)D95]&;W)M*"1V
M87)S+"!?*")!9&0@82!N97<@=7-E<CHB*2P@)V%D9'5S97(G*3L*)&%D9$9O
M<FTM/G-E=$)U='1O;G,H7R@B061D('5S97(B*2P@7R@B4F5S970B*2D["@HD
M=F%R<RT^<V5T*"=F;W)M)RP@)V%D9"<I.PHD861D1F]R;2T^861D2&ED9&5N
M*"<G+"`G9F]R;2<L("=T97AT)RP@=')U92P@=')U92D["B1A9&1&;W)M+3YA
M9&1687)I86)L92A?*")5<V5R;F%M92(I+"`G=7-E<E]N86UE)RP@)W1E>'0G
M+"!T<G5E*3L*)&%D9$9O<FTM/F%D9%9A<FEA8FQE*%\H(E!A<W-W;W)D(BDL
M("=P87-S=V]R9"<L("=P87-S=V]R9&-O;F9I<FTG+"!F86QS92P@9F%L<V4L
M(%\H(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB*2D["@HO
M*B!5<V4@:&]O:W,@9V5T(&%N>2!E>'1R82!F:65L9',@9F]R(&YE=R!A8V-O
M=6YT<RX@*B\*)&5X=')A(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O
M:U]S:6=N=7!?9V5T97AT<F$G*3L*:68@*"%I<U]A*"1E>'1R82P@)U!%05)?
M17)R;W(G*2`F)B`A96UP='DH)&5X=')A*2D@>PH@("`@9F]R96%C:"`H)&5X
M=')A(&%S("1F:65L9%]N86UE(#T^("1F:65L9"D@>PH@("`@("`@("1R96%D
M;VYL>2`](&ES<V5T*"1F:65L9%LG<F5A9&]N;'DG72D@/R`D9FEE;&1;)W)E
M861O;FQY)UT@.B!N=6QL.PH@("`@("`@("1D97-C(#T@:7-S970H)&9I96QD
M6R=D97-C)UTI(#\@)&9I96QD6R=D97-C)UT@.B!N=6QL.PH@("`@("`@("1F
M:65L9%]P87)A;7,@/2!I<W-E="@D9FEE;&1;)W!A<F%M<R==*2`_("1F:65L
M9%LG<&%R86US)UT@.B!A<G)A>2@I.PH*("`@("`@("`D861D1F]R;2T^861D
M5F%R:6%B;&4H)&9I96QD6R=L86)E;"==+"`G97AT<F%;)R`N("1F:65L9%]N
M86UE("X@)UTG+"`D9FEE;&1;)W1Y<&4G72P@)&9I96QD6R=R97%U:7)E9"==
M+"`D<F5A9&]N;'DL("1D97-C+"`D9FEE;&1?<&%R86US*3L*("`@('T*?0H*
M"B\O(%!R;V-E<W,@9F]R;7,N(%5S92!5=&EL.CIG9710;W-T*"D@:6YS=&5A
M9"!O9B!5=&EL.CIG971&;W)M1&%T82@I"B\O(&9O<B!A(&QO="!O9B!T:&4@
M9&%T82!B96-A=7-E('=E('=A;G0@=&\@86-T:79E;'D@:6=N;W)E($=%5"!D
M871A"B\O(&EN('-O;64@8V%S97,@+2!A9&1I;F<O;6]D:69Y:6YG('5S97)S
M("T@87,@82!S96-U<FET>2!P<F5C875T:6]N+@IS=VET8V@@*%5T:6PZ.F=E
M=$9O<FU$871A*"=F;W)M)RDI('L*8V%S92`G861D)SH*("`@("1A9&1&;W)M
M+3YV86QI9&%T92@D=F%R<RD["@H@("`@:68@*"1A9&1&;W)M+3YI<U9A;&ED
M*"D@)B8@)'9A<G,M/F=E="@G9F]R;6YA;64G*2`]/2`G861D=7-E<B<I('L*
M("`@("`@("`D861D1F]R;2T^9V5T26YF;R@D=F%R<RP@)&EN9F\I.PH*("`@
M("`@("!I9B`H96UP='DH)&EN9F];)W5S97)?;F%M92==*2D@>PH@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"XB*2P@)VAO<F1E+F5R<F]R)RD["@H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1C<F5D96YT:6%L<R`](&%R<F%Y
M*"=P87-S=V]R9"<@/3X@)&EN9F];)W!A<W-W;W)D)UTI.PH@("`@("`@("`@
M("!I9B`H:7-S970H)&EN9F];)V5X=')A)UTI*2!["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D:6YF;ULG97AT<F$G72!A<R`D9FEE;&0@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-R961E;G1I86QS6R1F:65L9%T@
M/2`D=F%L=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("AI<U]A*"1R970@/2`D875T:"T^861D57-E<B@D:6YF
M;ULG=7-E<E]N86UE)UTL("1C<F5D96YT:6%L<RDL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B*2P@)&EN9F];)W5S97)?;F%M92==+"`D<F5T+3YG971-
M97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG97AT<F$G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@2&]R9&4Z.F-A;&Q(
M;V]K*"=?:&]R9&5?:&]O:U]S:6=N=7!?861D97AT<F$G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&EN
M9F];)W5S97)?;F%M92==+"`D:6YF;ULG97AT<F$G72DI.PH@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS
M<')I;G1F*%\H(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N
M(BDL("1I;F9O6R=U<V5R7VYA;64G72P@)')E<W5L="T^9V5T365S<V%G92@I
M*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H571I;#HZ9V5T
M1F]R;41A=&$H)W)E;6]V95%U975E9%-I9VYU<"<I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'-I9VYU<"T^<F5M;W9E475E=65D4VEG;G5P*"1I;F9O6R=U
M<V5R7VYA;64G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY
M(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(I+"`D:6YF;ULG=7-E<E]N
M86UE)UTI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("`@("`@)&%D
M9$9O<FTM/G5N<V5T5F%R<R@D=F%R<RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)W)E;6]V95]F)SH*("`@("1F
M7W5S97)?;F%M92`](%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G*3L*
M("`@("1R96UO=F5?9F]R;2`]('1R=64["B`@("!B<F5A:SL*"F-A<V4@)W)E
M;6]V92<Z"B`@("`D9E]U<V5R7VYA;64@/2!5=&EL.CIG971&;W)M1&%T82@G
M=7-E<E]N86UE)RD["B`@("!I9B`H96UP='DH)&9?=7-E<E]N86UE*2D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92XB*2P@)VAO<F1E+FUE<W-A9V4G*3L*
M("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G<W5B;6ET)RD@(3T]
M(%\H(D-A;F-E;"(I*2!["B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1A
M=71H+3YR96UO=F55<V5R*"1F7W5S97)?;F%M92DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H
M(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;3H@(BD@+B`D<F5S=6QT+3YG971-97-S86=E*"DL("1F7W5S97)?
M;F%M92DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S
M9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(I+"`D9E]U
M<V5R7VYA;64I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@('T*("`@('T*
M("`@("1V87)S+3YR96UO=F4H)W5S97)?;F%M92<I.PH@("`@8G)E86L["@IC
M87-E("=C;&5A<E]F)SH*("`@("1F7W5S97)?;F%M92`](%5T:6PZ.F=E=$9O
M<FU$871A*"=U<V5R7VYA;64G*3L*("`@("1C;&5A<E]F;W)M(#T@=')U93L*
M("`@(&)R96%K.PH*8V%S92`G8VQE87(G.@H@("`@)&9?=7-E<E]N86UE(#T@
M571I;#HZ9V5T1F]R;41A=&$H)W5S97)?;F%M92<I.PH@("`@:68@*&5M<'1Y
M*"1F7W5S97)?;F%M92DI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*%\H(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M(BDL("=H;W)D92YM97-S86=E)RD["B`@("!](&5L<V5I9B`H571I;#HZ9V5T
M1F]R;41A=&$H)W-U8FUI="<I("$]/2!?*")#86YC96PB*2D@>PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D875T:"T^<F5M;W9E57-E<D1A=&$H)&9?
M=7-E<E]N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(I("X@)')E<W5L="T^9V5T365S<V%G92@I+"`D9E]U<V5R7VYA;64I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY
M(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M+B(I+"`D9E]U<V5R7VYA;64I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@
M('T*("`@('T*("`@("1V87)S+3YR96UO=F4H)W5S97)?;F%M92<I.PH@("`@
M8G)E86L["@IC87-E("=U<&1A=&5?9B<Z"B`@("`D9E]U<V5R7VYA;64@/2!5
M=&EL.CIG971&;W)M1&%T82@G=7-E<E]N86UE)RD["B`@("`D=7!D871E7V9O
M<FT@/2!T<G5E.PH@("`@8G)E86L["@IC87-E("=U<&1A=&4G.@H@("`@)'5S
M97)?;F%M95\Q(#T@571I;#HZ9V5T4&]S="@G=7-E<E]N86UE)RD["B`@("`D
M=7-E<E]N86UE7S(@/2!5=&EL.CIG9710;W-T*"=U<V5R7VYA;64R)RP@)'5S
M97)?;F%M95\Q*3L*("`@("1F=6QL;F%M92`](%5T:6PZ.F=E=%!O<W0H)W5S
M97)?9G5L;&YA;64G*3L*("`@("1E;6%I;"`](%5T:6PZ.F=E=%!O<W0H)W5S
M97)?96UA:6PG*3L*"B`@("!I9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)W5P
M9&%T92<I*2!["B`@("`@("`@)'5S97)?<&%S<U\Q(#T@571I;#HZ9V5T4&]S
M="@G=7-E<E]P87-S7S$G*3L*("`@("`@("`D=7-E<E]P87-S7S(@/2!5=&EL
M.CIG9710;W-T*"=U<V5R7W!A<W-?,B<I.PH*("`@("`@("!I9B`H96UP='DH
M)'5S97)?;F%M95\Q*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T
M92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?2!E;'-E:68@*&5M<'1Y
M*"1U<V5R7W!A<W-?,2D@?'P@96UP='DH)'5S97)?<&%S<U\R*2D@>PH@("`@
M("`@("`@("`O+R!$;VXG="!U<&1A=&4L(&)U="!D;VXG="!C;VUP;&%I;BX*
M("`@("`@("!](&5L<V5I9B`H)'5S97)?<&%S<U\Q("$]("1U<V5R7W!A<W-?
M,BD@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!A<W-W
M;W)D<R!M=7-T(&UA=&-H+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)&%U=&@M/G5P9&%T955S
M97(H)'5S97)?;F%M95\Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'5S97)?;F%M95\R+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A<W-W;W)D)R`]/B`D=7-E
M<E]P87-S7S$I*3L*("`@("`@("!]"B`@("!]"@H@("`@:68@*&ES<V5T*"1R
M97-U;'0I("8F(&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?;F%M95\Q+"`D<F5S=6QT
M+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92![
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@
M("`@("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"=N;VYE
M)RP@)'5S97)?;F%M95\Q*3L*("`@("`@("`D:61E;G1I='DM/G-E=%9A;'5E
M*"=F=6QL;F%M92<L("1F=6QL;F%M92D["B`@("`@("`@)&ED96YT:71Y+3YS
M971686QU92@G9G)O;5]A9&1R)RP@)&5M86EL*3L*("`@("`@("`D:61E;G1I
M='DM/G-A=F4H*3L*"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<E]N86UE7S(I+"`G
M:&]R9&4N<W5C8V5S<R<I.PH@("`@?0H@("`@)'9A<G,M/G)E;6]V92@G=7-E
M<E]N86UE)RD["B`@("!B<F5A:SL*"F-A<V4@)V%P<')O=F5?9B<Z"B`@("`D
M=&AI<U-I9VYU<"`]("1S:6=N=7`M/F=E=%%U975E9%-I9VYU<"A5=&EL.CIG
M971&;W)M1&%T82@G=7-E<E]N86UE)RDI.PH@("`@)&EN9F\@/2`D=&AI<U-I
M9VYU<"T^9V5T1&%T82@I.PH*("`@("1V87)S+3YS970H)W!A<W-W;W)D)RP*
M("`@("`@("`@("`@("`@87)R87DH)V]R:6=I;F%L)R`]/B`D:6YF;ULG<&%S
M<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@)V-O;F9I<FTG(#T^("1I
M;F9O6R=P87-S=V]R9"==*2D["B`@("!U;G-E="@D:6YF;ULG<&%S<W=O<F0G
M72D["B`@("`D=F%R<RT^<V5T*"=E>'1R82<L("1I;F9O*3L*"B`@("`D=F%R
M<RT^<V5T*"=R96UO=F51=65U9613:6=N=7`G+"!T<G5E*3L*("`@("1A9&1&
M;W)M+3YA9&1(:61D96XH)R<L("=R96UO=F51=65U9613:6=N=7`G+"`G8F]O
M;&5A;B<L('1R=64I.PH@("`@8G)E86L["@IC87-E("=R96UO=F5Q=65U961?
M9B<Z"B`@("`D9E]U<V5R7VYA;64@/2!5=&EL.CIG971&;W)M1&%T82@G=7-E
M<E]N86UE)RD["B`@("`D<F5M;W9E<75E=65D7V9O<FT@/2!T<G5E.PH@("`@
M8G)E86L["@IC87-E("=R96UO=F5Q=65U960G.@H@("`@)')E<W5L="`]("1S
M:6=N=7`M/G)E;6]V95%U975E9%-I9VYU<"A5=&EL.CIG971&;W)M1&%T82@G
M=7-E<E]N86UE)RDI.PH@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="D[
M"B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N(BDL(%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G*2DI.PH@
M("`@?0H@("`@8G)E86L["GT*"B1T:71L92`](%\H(E5S97(@061M:6YI<W1R
M871I;VXB*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W-T<FEP92YJ<R<L("=H
M;W)D92<L('1R=64I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I
M9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*"FEF("AI<W-E
M="@D=7!D871E7V9O<FTI("8F("1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T
M)RDI('L*("`@(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*
M("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"=N;VYE)RP@
M)&9?=7-E<E]N86UE*3L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]A9&UI;B]U<V5R+W5P9&%T92YI;F,G.PI](&5L<V5I9B`H:7-S970H)')E
M;6]V95]F;W)M*2`F)B`D875T:"T^:&%S0V%P86)I;&ET>2@G;&ES="<I("8F
M("1A=71H+3YH87-#87!A8FEL:71Y*"=R96UO=F4G*2D@>PH@("`@<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+W5S97(O<F5M;W9E+FEN8R<[
M"GT@96QS96EF("AI<W-E="@D8VQE87)?9F]R;2DI('L*("`@(')E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+V-L96%R+FEN8R<["GT@
M96QS96EF("AI<W-E="@D<F5M;W9E<75E=65D7V9O<FTI*2!["B`@("!R97%U
M:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC)SL*?2!E;'-E:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=A9&0G
M*2D@>PH@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+W5S
M97(O861D+FEN8R<["B`@("!I9B`H)&-O;F9;)W-I9VYU<"==6R=A;&QO=R==
M("8F("1C;VYF6R=S:6=N=7`G75LG87!P<F]V92==*2!["B`@("`@("`@<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,G.PH@("`@?0I](&5L<V4@>PH@("`@<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+V%D;6EN+W5S97(O;F]A9&0N:6YC)SL*?0H*:68@*"1A=71H+3YH
M87-#87!A8FEL:71Y*"=L:7-T)RDI('L*"B`@("`O*B!)9B!W92!A<F5N)W0@
M<W5P<&QI960@=VET:"!A('!A9V4@;G5M8F5R+"!D969A=6QT('1O('!A9V4@
M,"X@*B\*("`@("1P86=E(#T@571I;#HZ9V5T1F]R;41A=&$H)W!A9V4G+"`P
M*3L*("`@("1S96%R8VA?<&%T=&5R;B`](%5T:6PZ.F=E=$9O<FU$871A*"=S
M96%R8VA?<&%T=&5R;B<L("<G*3L*"B`@("`D=7-E<G,@/2`D875T:"T^;&ES
M=%5S97)S*"D["B`@("!I9B`H:7-?82@D=7-E<G,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("!(;W)D93HZ9F%T86PH)'5S97)S+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@?0H*("`@("\J(%)E='5R;G,@;VYL>2!U<V5R<R!T:&%T
M(&UA=&-H('1H92!S<&5C:69I960@<&%T=&5R;BX@*B\*("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("1U<V5R<R`]('!R96=?9W)E
M<"@G+R<@+B`D<V5A<F-H7W!A='1E<FX@+B`G+R<L("1U<V5R<RD["B`@("!S
M;W)T*"1U<V5R<RD["@H@("`@<F5Q=6ER95]O;F-E("=(;W)D92]522]086=E
M<BYP:'`G.PH@("`@)'9I97=U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)V%D
M;6EN+W5S97(N<&AP)RP@)W-E87)C:%]P871T97)N)RP@)'-E87)C:%]P871T
M97)N*3L*"B`@("`D;G5M:71E;2`](&-O=6YT*"1U<V5R<RD["B`@("`D<&5R
M<&%G92`](#(P.PH*("`@("1M:6X@/2`D<&%G92`J("1P97)P86=E.PH@("`@
M=VAI;&4@*"1M:6X@/B`D;G5M:71E;2D@>PH@("`@("`@("1P86=E+2T["B`@
M("`@("`@)&UI;B`]("1P86=E("H@)'!E<G!A9V4["B`@("!]"B`@("`D;6%X
M(#T@)&UI;B`K("1P97)P86=E.PH*("`@("1S=&%R="`]("@D<&%G92`J("1P
M97)P86=E*2`K(#$["B`@("`D96YD(#T@;6EN*"1N=6UI=&5M+"`D<W1A<G0@
M*R`D<&5R<&%G92`M(#$I.PH*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]A9&UI;B]U<V5R+VQI<W0N:6YC)SL*?2!E;'-E('L*("`@(')E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+VYO;&ES="YI;F,G
M.PI]"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E
M<BYI;F,G.PH`+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]S<6QS
M:&5L;"YP:'``````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$S,S$R`#$P-#$W,S8R-S8P`#`R,#`T-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!H;W)D92]A9&UI;B]S<6QS:&5L;"YP:'`L=B`Q+C$X+C$P+CD@,C`P-B\P
M,B\R-"`R,CHT.#HR.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92](96QP+G!H<"<["G)E<75I<F5?;VYC
M92`G1$(N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D
M93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]
M"@HD=&ET;&4@/2!?*")344P@4VAE;&PB*3L*2&]R9&4Z.F%D9%-C<FEP=$9I
M;&4H)W-T<FEP92YJ<R<L("=H;W)D92<L('1R=64I.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/
M4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PH*
M/SX*/&1I=B!S='EL93TB<&%D9&EN9SHQ,'!X(CX*/&9O<FT@;F%M93TB<W%L
M<VAE;&PB(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%4E9%4ELG4$A07U-%3$8G
M72`_/B(@;65T:&]D/2)P;W-T(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I
M(#\^"@H\/W!H<`H*)&1B:"`]("9$0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTI
M.PII9B`H:7-?82@D9&)H+"`G4$5!4E]%<G)O<B<I*2!["B`@("!(;W)D93HZ
M9F%T86PH)&1B:"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0HD9&)H+3YS971/
M<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%
M('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*"FEF("A5=&EL.CIG971&;W)M
M1&%T82@G;&ES="UT86)L97,G*2D@>PH@("`@)&1E<V-R:7!T:6]N(#T@)TQ)
M4U0@5$%"3$53)SL*("`@("1R97-U;'0@/2`D9&)H+3YG971,:7-T3V8H)W1A
M8FQE<R<I.PI](&5L<V5I9B`H571I;#HZ9V5T1F]R;41A=&$H)VQI<W0M9&)S
M)RDI('L*("`@("1D97-C<FEP=&EO;B`]("=,25-4($1!5$%"05-%4R<["B`@
M("`D<F5S=6QT(#T@)&1B:"T^9V5T3&ES=$]F*"=D871A8F%S97,G*3L*?2!E
M;'-E:68@*"1C;VUM86YD(#T@=')I;2A5=&EL.CIG971&;W)M1&%T82@G<W%L
M)RDI*2!["B`@("`O+R!+965P(&$@8V%C:&4@;V8@<')I;W(@<75E<FEE<R!F
M;W(@8V]N=F5N:65N8V4N"B`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG7W-Q
M;%]Q=65R>5]C86-H92==*2D@>PH@("`@("`@("1?4T534TE/3ELG7W-Q;%]Q
M=65R>5]C86-H92==(#T@87)R87DH*3L*("`@('T*("`@(&EF("@H)&ME>2`]
M(&%R<F%Y7W-E87)C:"@D8V]M;6%N9"P@)%]315-324].6R=?<W%L7W%U97)Y
M7V-A8VAE)UTI*2`A/3T@9F%L<V4I('L*("`@("`@("!U;G-E="@D7U-%4U-)
M3TY;)U]S<6Q?<75E<GE?8V%C:&4G75LD:V5Y72D["B`@("!]"B`@("!A<G)A
M>5]U;G-H:69T*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==+"`D8V]M
M;6%N9"D["B`@("!W:&EL92`H8V]U;G0H)%]315-324].6R=?<W%L7W%U97)Y
M7V-A8VAE)UTI(#X@,C`I('L*("`@("`@("!A<G)A>5]P;W`H)%]315-324].
M6R=?<W%L7W%U97)Y7V-A8VAE)UTI.PH@("`@?0H*("`@("\O(%!A<G-E(&]U
M="!T:&4@<75E<GD@<F5S=6QT<RX*("`@("1R97-U;'0@/2`D9&)H+3YQ=65R
M>2A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1C;VUM86YD+"!.3%,Z.F=E=$-H
M87)S970H*2P@)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UTI*3L*?0H*:68@*&ES
M<V5T*"1R97-U;'0I*2!["B`@("!I9B`H:7-S970H)&-O;6UA;F0I*2!["B`@
M("`@("`@96-H;R`G/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")1=65R>2(I
M("X@)SPO:#$^/&)R("\^/'!R92!C;&%S<STB=&5X="(^)R`N(&AT;6QS<&5C
M:6%L8VAA<G,H)&-O;6UA;F0I("X@)SPO<')E/B<["B`@("!]"@H@("`@96-H
M;R`G/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")297-U;'1S(BD@+B`G/"]H
M,3X\8G(@+SXG.PH*("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("!E8VAO("<\<')E(&-L87-S/2)T97AT(CXG.R!V87)?
M9'5M<"@D<F5S=6QT*3L@96-H;R`G/"]P<F4^)SL*("`@('T@96QS92!["B`@
M("`@("`@:68@*&ES7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!E
M8VAO("<\=&%B;&4@8V5L;'-P86-I;F<](C$B(&-L87-S/2)I=&5M('-T<FEP
M960B/B<["B`@("`@("`@("`@("1F:7)S="`]('1R=64["B`@("`@("`@("`@
M("1I(#T@,#L*("`@("`@("`@("`@=VAI;&4@*"1R;W<@/2`D<F5S=6QT+3YF
M971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&9I<G-T*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`G/'1R
M/B<["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O=R!A<R`D:V5Y
M(#T^("1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`G/'1H
M(&%L:6=N/2)L969T(CXG("X@*&5M<'1Y*"1K97DI(#\@)R9N8G-P.R<@.B!H
M=&UL<W!E8VEA;&-H87)S*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&ME>2P@
M)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UTI*2D@+B`G/"]T:#XG.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E8VAO("<\+W1R
M/B<["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L<V4["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E8VAO("<\='(^)SL*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<@87,@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@("`@(&5C:&\@)SQT9"!C;&%S<STB9FEX960B/B<@+B`H96UP
M='DH)'9A;"D@/R`G)FYB<W`[)R`Z(&AT;6QS<&5C:6%L8VAA<G,H4W1R:6YG
M.CIC;VYV97)T0VAA<G-E="@D=F%L+"`D8V]N9ELG<W%L)UU;)V-H87)S970G
M72DI*2`N("<\+W1D/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!E8VAO("<\+W1R/B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96-H;R`G/"]T86)L93XG.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("!E8VAO("<\=&%B;&4@8V5L;'-P86-I
M;F<](C$B(&-L87-S/2)I=&5M('-T<FEP960B/B<["B`@("`@("`@("`@("1F
M:7)S="`]('1R=64["B`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@
M9F]R96%C:"`H)')E<W5L="!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&9I<G-T*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`G/'1R/CQT
M:"!A;&EG;CTB;&5F="(^)R`N("AI<W-E="@D9&5S8W)I<'1I;VXI(#\@:'1M
M;'-P96-I86QC:&%R<R@D9&5S8W)I<'1I;VXI(#H@)R9N8G-P.R<I("X@)SPO
M=&@^/"]T<CXG.PH@("`@("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96-H;R`G/'1R
M/CQT9"!C;&%S<STB9FEX960B/B<@+B`H96UP='DH)'9A;"D@/R`G)FYB<W`[
M)R`Z(&AT;6QS<&5C:6%L8VAA<G,H4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M=F%L+"`D8V]N9ELG<W%L)UU;)V-H87)S970G72DI*2`N("<\+W1D/CPO='(^
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\+W1A8FQE/B<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`G/'-T<F]N9SXG
M("X@7R@B4W5C8V5S<R(I("X@)SPO<W1R;VYG/B<["B`@("`@("`@?0H@("`@
M?0H*("`@(&5C:&\@)SQB<B`O/B<["GT*/SX*"CP_<&AP(&EF("AI<W-E="@D
M7U-%4U-)3TY;)U]S<6Q?<75E<GE?8V%C:&4G72D@)B8*("`@("`@("`@(&-O
M=6YT*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==*2DZ(#\^"B`@/'-E
M;&5C="!N86UE/2)Q=65R>5]C86-H92(@;VYC:&%N9V4](F1O8W5M96YT+G-Q
M;'-H96QL+G-Q;"YV86QU92`](&1O8W5M96YT+G-Q;'-H96QL+G%U97)Y7V-A
M8VAE6V1O8W5M96YT+G-Q;'-H96QL+G%U97)Y7V-A8VAE+G-E;&5C=&5D26YD
M97A=+G9A;'5E.R(^"B`@/#]P:'`@9F]R96%C:"`H)%]315-324].6R=?<W%L
M7W%U97)Y7V-A8VAE)UT@87,@)'%U97)Y*3H@/SX*("`@(#QO<'1I;VX@=F%L
M=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<75E<GDI(#\^(CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'%U97)Y*2`_/CPO;W!T:6]N
M/@H@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"B`@/"]S96QE8W0^"B`@/&EN<'5T
M('1Y<&4](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4&%S=&4B*2`_
M/B(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N<W%L<VAE;&PN
M<W%L+G9A;'5E(#T@9&]C=6UE;G0N<W%L<VAE;&PN<75E<GE?8V%C:&5;9&]C
M=6UE;G0N<W%L<VAE;&PN<75E<GE?8V%C:&4N<V5L96-T961);F1E>%TN=F%L
M=64[(B`O/@H@(#QI;G!U="!T>7!E/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E
M8VAO(%\H(E)U;B(I(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U
M;65N="YS<6QS:&5L;"YS<6PN=F%L=64@/2!D;V-U;65N="YS<6QS:&5L;"YQ
M=65R>5]C86-H95MD;V-U;65N="YS<6QS:&5L;"YQ=65R>5]C86-H92YS96QE
M8W1E9$EN9&5X72YV86QU93L@9&]C=6UE;G0N<W%L<VAE;&PN<W5B;6ET*"D[
M(B`O/@H@(#QB<B`O/@H\/W!H<"!E;F1I9CL@/SX*"CQT97AT87)E82!C;&%S
M<STB9FEX960B(&YA;64](G-Q;"(@<F]W<STB,3`B(&-O;',](C8P(CX*/#]P
M:'`@:68@*"%E;7!T>2@D8V]M;6%N9"DI(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D8V]M;6%N9"D@/SX\+W1E>'1A<F5A/@H\8G(@+SX*/&EN<'5T('1Y<&4]
M(G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M17AE8W5T92(I(#\^(B`O/@H\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB
M8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")#;&5A<B!1=65R>2(I(#\^
M(B!O;F-L:6-K/2)D;V-U;65N="YS<6QS:&5L;"YS<6PN=F%L=64])R<B("\^
M"CP_<&AP(&EF("@A96UP='DH)&-O;6UA;F0I*3H@/SX*/&EN<'5T('1Y<&4]
M(G)E<V5T(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")2
M97-T;W)E($QA<W0@475E<GDB*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^"CP_
M<&AP(&EF("@D9&)H+3YG9713<&5C:6%L475E<GDH)W1A8FQE<R<I("$]/2!N
M=6QL*3H@/SX\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N
M86UE/2)L:7-T+71A8FQE<R(@=F%L=64](CP_<&AP(&5C:&\@7R@B3&ES="!4
M86)L97,B*2`_/B(@+SX@/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("@D9&)H
M+3YG9713<&5C:6%L475E<GDH)V1A=&%B87-E<R<I("$]/2!N=6QL*3H@/SX\
M:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)L:7-T
M+61B<R(@=F%L=64](CP_<&AP(&5C:&\@7R@B3&ES="!$871A8F%S97,B*2`_
M/B(@+SX@/#]P:'`@96YD:68[(#\^"CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G
M861M:6XG+"`G861M:6XM<W%L<VAE;&PG*2`_/@H*/"]F;W)M/@H\+V1I=CX*
M/#]P:'`*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O
M=&5R+FEN8R<["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+V1A=&%T<F5E
M+G!H<```````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#0W,C,`,3`T,3<S-C(W-C``,#(P,#$W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+V%D;6EN+V1A=&%T<F5E+G!H<"QV(#$N-RXR+C0@,C`P-B\P,B\P,2`P
M.3HS,#HT-B!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("HO"@IF=6YC=&EO;B!A9&14<F5E*"1P87)E;G0L("1P87)E;G1?:60L("1I
M;F1E;G0@/2`Q*0I["B`@("!G;&]B86P@)&1A=&%T<F5E+"`D=')E93L*"B`@
M("`D;F]D97,@/2`D9&%T871R964M/F=E=$)Y260H1$%40512145?1D]234%4
M7T9,050L("1P87)E;G1?:60L('1R=64L("1P87)E;G0L(#$I.PH@("`@)&5X
M<&%N9&5D(#T@)'1R964M/FES17AP86YD960H)'!A<F5N="D["B`@("`D=7)L
M(#T@2&]R9&4Z.G5R;"@G9&%T871R964N<&AP)RD["B`@("!F;W)E86-H("@D
M;F]D97,@87,@)&ED(#T^("1N;V1E*2!["B`@("`@("`@:68@*"1I9"`]/2`D
M<&%R96YT7VED*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*
M("`@("`@("`D=')E92T^861D3F]D92@D<&%R96YT("X@)SHG("X@)&ED+"`D
M<&%R96YT+"`D9&%T871R964M/F=E=%-H;W)T3F%M92@D;F]D92DL("1I;F1E
M;G0L(&9A;'-E+"!A<G)A>2@G=7)L)R`]/B!5=&EL.CIA9&1087)A;65T97(H
M)'5R;"P@)W-H;W<G+"`D9&%T871R964M/F=E=%!A<F%M*"=G<F]U<"<I("X@
M)SHG("X@)&ED*2`N("<C<VAO=R<I*3L*("`@("`@("!I9B`H)&5X<&%N9&5D
M*2!["B`@("`@("`@("`@(&%D9%1R964H)'!A<F5N="`N("<Z)R`N("1I9"P@
M)&ED+"`D:6YD96YT("L@,2D["B`@("`@("`@?0H@("`@?0I]"@I`9&5F:6YE
M*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E
M<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92](96QP+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5')E92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4<F5E+G!H<"<["@II9B`H(4%U=&@Z
M.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R
M95)E9&ER96-T*"D["GT*"B1T<F5E(#T@)DAO<F1E7U1R964Z.F9A8W1O<GDH
M)V1A=&%T<F5E)RP@)VAT;6PG*3L*)'1R964M/G-E=$]P=&EO;B@G86QT97)N
M871E)RP@=')U92D["@HD9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R
M:79E<B==.PHD8V]N9FEG(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G9&%T
M871R964G+"`D8V]N9ELG9&%T871R964G75LG9')I=F5R)UTI.PHD9&%T871R
M964@/2`F1&%T851R964Z.G-I;F=L971O;B@D8V]N9ELG9&%T871R964G75LG
M9')I=F5R)UTI.PHD<F]O=',@/2`D9&%T871R964M/F=E=$=R;W5P<R@I.PH*
M:68@*&ES7V$H)')O;W1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*"1R;V]T<RD["GT@96QS92!["B`@("!F;W)E86-H("@D
M<F]O=',@87,@)')O;W0I('L*("`@("`@("`D=')E92T^861D3F]D92@D<F]O
M="P@;G5L;"P@)')O;W0L(#`L(&9A;'-E*3L*("`@("`@("`D9&%T871R964@
M/2`F1&%T851R964Z.G-I;F=L971O;B@D9')I=F5R+"!A<G)A>5]M97)G92@D
M8V]N9FEG+"!A<G)A>2@G9W)O=7`G(#T^("1R;V]T*2DI.PH@("`@("`@(&%D
M9%1R964H)')O;W0L($1!5$%44D5%7U)/3U0I.PH@("`@?0I]"@II9B`H)'-H
M;W<@/2!5=&EL.CIG971&;W)M1&%T82@G<VAO=R<I*2!["B`@("!L:7-T*"1R
M;V]T+"`D:60I(#T@97AP;&]D92@G.B<L("1S:&]W*3L*("`@("1D871A=')E
M92`]("9$871A5')E93HZ<VEN9VQE=&]N*"1D<FEV97(L(&%R<F%Y7VUE<F=E
M*"1C;VYF:6<L(&%R<F%Y*"=G<F]U<"<@/3X@)')O;W0I*2D["B`@("`D9&%T
M82`]("1D871A=')E92T^9V5T1&%T82@D:60I.PH@("`@)&%T=')I8G5T97,@
M/2`D9&%T871R964M/F=E=$%T=')I8G5T97,H)&ED*3L*?0H*)'1I=&QE(#T@
M7R@B1&%T851R964@0G)O=W-E<B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,
M051%4R`N("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T
M:6]N+3YN;W1I9GDH*3L*)'1R964M/G)E;F1E<E1R964H*3L*:68@*"1S:&]W
M*2!["B`@("!E8VAO("<\8G(@+SX\9&EV(&-L87-S/2)T97AT(B!S='EL93TB
M=VAI=&4M<W!A8V4Z<')E(CX\82!I9#TB<VAO=R(^/"]A/B<["B`@("!P<FEN
M=%]R*"1D871A*3L*("`@('!R:6YT7W(H)&%T=')I8G5T97,I.PH@("`@96-H
M;R`G/"]D:78^)SL*?0IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D
M;6EN+V=R;W5P<RYP:'``````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3<U,S<`,3`T,3<S-C(W-C``,#$W-34T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+V=R;W5P<RYP:'`L=B`Q+C4P+C(N-2`R
M,#`V+S`Q+S`Q(#(Q.C(X.C`U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%3
M12`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]4<F5E+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH
M*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T
M*"D["GT*"B1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PHD875T:"`]
M("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*
M)&9O<FT@/2!N=6QL.PHD<F5L;V%D(#T@9F%L<V4["B1A8W1I;VY)1"`](%5T
M:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PHD8VED(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V-I9"<I.PH*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G
M861D8VAI;&0G.@H@("`@:68@*"1C:60@/3T@1$%40512145?4D]/5"D@>PH@
M("`@("`@("1F;W)M(#T@)V%D9&-H:6QD+FEN8R<["B`@("`@("`@)&=N86UE
M(#T@7R@B06QL($=R;W5P<R(I.PH@("`@?2!E;'-E('L*("`@("`@("`D9W)O
M=7`@/2`F)&=R;W5P<RT^9V5T1W)O=7!">4ED*"1C:60I.PH@("`@("`@(&EF
M("@A:7-?82@D9W)O=7`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M)&=N86UE(#T@)&=R;W5P+3YG9713:&]R=$YA;64H*3L*("`@("`@("`@("`@
M)&9O<FT@/2`G861D8VAI;&0N:6YC)SL*("`@("`@("!]"B`@("!]"B`@("!B
M<F5A:SL*"F-A<V4@)V%D9&-H:6QD9F]R;2<Z"B`@("`D<&%R96YT(#T@)&-I
M9#L*("`@(&EF("@D<&%R96YT(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@
M("`D8VAI;&0@/2`F)&=R;W5P<RT^;F5W1W)O=7`H571I;#HZ9V5T1F]R;41A
M=&$H)V-H:6QD)RDI.PH@("`@("`@("1R97-U;'0@/2`D9W)O=7!S+3YA9&1'
M<F]U<"@D8VAI;&0I.PH@("`@?2!E;'-E('L*("`@("`@("`D8VAI;&0@/2`F
M)&=R;W5P<RT^;F5W1W)O=7`H571I;#HZ9V5T1F]R;41A=&$H)V-H:6QD)RDL
M("1P87)E;G0I.PH@("`@("`@("1R97-U;'0@/2`D9W)O=7!S+3YA9&1'<F]U
M<"@D8VAI;&0I.PH@("`@?0H@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B7"(E<UPB('=A<R!N;W0@
M8W)E871E9#H@)7,N(BDL("1C:&EL9"T^9V5T4VAO<G1.86UE*"DL("1R97-U
M;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E
M('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B7"(E
M<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB*2P@)&-H:6QD
M+3YG9713:&]R=$YA;64H*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@
M)&=R;W5P(#T@)B1C:&EL9#L*("`@("`@("`D9F]R;2`]("=E9&ET+FEN8R<[
M"B`@("`@("`@)')E;&]A9"`]('1R=64["B`@("!]"B`@("!B<F5A:SL*"F-A
M<V4@)V1E;&5T92<Z"B`@("`D9W)O=7`@/2`F)&=R;W5P<RT^9V5T1W)O=7!"
M>4ED*"1C:60I.PH@("`@:68@*"%I<U]A*"1G<F]U<"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("1F;W)M(#T@)V1E;&5T92YI;F,G.PH@("`@?0H@("`@
M8G)E86L["@IC87-E("=D96QE=&5F;W)M)SH*("`@(&EF("A5=&EL.CIG971&
M;W)M1&%T82@G8V]N9FER;2<I(#T](%\H(D1E;&5T92(I*2!["B`@("`@("`@
M)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D8VED*3L*("`@("`@
M("!I9B`H:7-?82@D9W)O=7`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`]("1G<F]U<',M/G)E
M;6]V94=R;W5P*"1G<F]U<"P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E
M(%PB)7-<(CH@)7,N(BDL("1G<F]U<"T^9V5T4VAO<G1.86UE*"DL("1R97-U
M;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(BDL
M("1G<F]U<"T^9V5T4VAO<G1.86UE*"DI+"`G:&]R9&4N<W5C8V5S<R<I.PH@
M("`@("`@("`@("`@("`@)&-I9"`](&YU;&P["B`@("`@("`@("`@("`@("`D
M<F5L;V%D(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M("`@(&)R96%K.PH*8V%S92`G961I="<Z"B`@("`D9W)O=7`@/2`F)&=R;W5P
M<RT^9V5T1W)O=7!">4ED*"1C:60I.PH@("`@:68@*"%I<U]A*"1G<F]U<"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1F;W)M(#T@)V5D:70N:6YC)SL*
M("`@('T@96QS96EF("@H)&-A=&5G;W)Y(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V-A=&5G;W)Y)RDI("$]/2!N=6QL*2!["B`@("`@("`@)&=R;W5P(#T@)B1G
M<F]U<',M/F=E=$=R;W5P*"1C871E9V]R>2D["B`@("`@("`@:68@*"%I<U]A
M*"1G<F]U<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9F]R;2`]
M("=E9&ET+FEN8R<["B`@("`@("`@?2!E;'-E:68@*%5T:6PZ.F=E=$9O<FU$
M871A*"=A=71O8W)E871E)RDI('L*("`@("`@("`@("`@)'!A<F5N="`](%5T
M:6PZ.F=E=$9O<FU$871A*"=P87)E;G0G*3L*("`@("`@("`@("`@)&=R;W5P
M(#T@)B1G<F]U<',M/FYE=T=R;W5P*"1C871E9V]R>2D["B`@("`@("`@("`@
M("1R97-U;'0@/2`D9W)O=7!S+3YA9&1'<F]U<"@D9W)O=7`L("1P87)E;G0I
M.PH@("`@("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@8G)E86L["@IC87-E("=E
M9&ET9F]R;2<Z"B`@("`D9W)O=7`@/2`F)&=R;W5P<RT^9V5T1W)O=7!">4ED
M*"1C:60I.PH*("`@("\O(&UA:V4@82!C;W!Y(&]F('1H92!G<F]U<"!S;R!W
M92!C86X@<F5S=&]R92!I="!I9B!T:&5R92!I<R!A;B!E<G)O<BX*("`@("1R
M97-T;W)E(#T@)&=R;W5P.PH*("`@("\O($%D9"!A;GD@;F5W('5S97)S+@H@
M("`@)&YE=W5S97(@/2!5=&EL.CIG971&;W)M1&%T82@G;F5W7W5S97(G*3L*
M("`@(&EF("@A96UP='DH)&YE=W5S97(I*2!["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1N97=U<V5R*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;F5W=7-E
M<B!A<R`D;F5W*2!["B`@("`@("`@("`@("`@("`D9W)O=7`M/F%D9%5S97(H
M)&YE=RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&=R;W5P+3YA9&15<V5R*"1N97=U<V5R+"!F86QS92D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\O(%)E;6]V92!A;GD@=7-E<G,@;6%R
M:V5D(&9O<B!P=7)G:6YG+@H@("`@)')E;6]V97,@/2!5=&EL.CIG971&;W)M
M1&%T82@G<F5M;W9E)RD["B`@("!I9B`H(65M<'1Y*"1R96UO=F5S*2`F)B!I
M<U]A<G)A>2@D<F5M;W9E<RDI('L*("`@("`@("!F;W)E86-H("@D<F5M;W9E
M<R!A<R`D=7-E<B`]/B`D:G5N:RD@>PH@("`@("`@("`@("`D9W)O=7`M/G)E
M;6]V955S97(H)'5S97(L(&9A;'-E*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+R\@4V5T('1H92!E;6%I;"!A9&1R97-S(&]F('1H92!G<F]U<"X*("`@("1G
M<F]U<"T^<V5T*"=E;6%I;"<L(%5T:6PZ.F=E=$9O<FU$871A*"=E;6%I;"<I
M*3L*"B`@("`O+R!3879E('1H92!G<F]U<"!T;R!T:&4@8F%C:V5N9"X*("`@
M("1R97-U;'0@/2`D9W)O=7`M/G-A=F4H*3L*"B`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"@D<F5S=6QT+3YG971-97-S86=E*"DL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@("\O(')E<W1O<F4@8F%C:W5P(&-O<'D*("`@("`@("`D9W)O=7`@
M/2`D<F5S=&]R93L*("`@('T@96QS92!["B`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"AS<')I;G1F*%\H(E5P9&%T960@7"(E<UPB+B(I+"`D9W)O=7`M
M/F=E=%-H;W)T3F%M92@I*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T*"B`@
M("`D9F]R;2`]("=E9&ET+FEN8R<["B`@("`D<F5L;V%D(#T@=')U93L*("`@
M(&)R96%K.PI]"@IS=VET8V@@*"1F;W)M*2!["@IC87-E("=A9&1C:&EL9"YI
M;F,G.@H@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G9&]C=6UE;G0N861D7V-H
M:6QD+F-H:6QD+F9O8W5S*"DG+"`G:F%V87-C<FEP="<I.PH@("`@8G)E86L[
M"@IC87-E("=E9&ET+FEN8R<Z"B`@("`O*B!3970@=7`@=&AE(&QI<W1S+B`J
M+PH@("`@)'5S97)S(#T@)&=R;W5P+3YL:7-T57-E<G,H*3L*("`@(&EF("AI
M<U]A*"1U<V5R<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H)'5S97)S+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`D
M=7-E<G,@/2!A<G)A>2@I.PH@("`@?0H@("`@:68@*"1A=71H+3YH87-#87!A
M8FEL:71Y*"=L:7-T)RDI('L*("`@("`@("`D=7-E<E]L:7-T(#T@)&%U=&@M
M/FQI<W15<V5R<R@I.PH@("`@("`@(&EF("AI<U]A*"1U<V5R7VQI<W0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"@D=7-E<E]L:7-T+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@)'5S
M97)?;&ES="`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@('-O<G0H)'5S
M97)?;&ES="D["B`@("!](&5L<V4@>PH@("`@("`@("1U<V5R7VQI<W0@/2!A
M<G)A>2@I.PH@("`@?0H@("`@8G)E86L["@I]"@HD=&ET;&4@/2!?*")'<F]U
M<"!!9&UI;FES=')A=&EO;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N
M+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*:68@
M*"%E;7!T>2@D9F]R;2DI('L*("`@(&EN8VQU9&4@2$]21$5?5$5-4$Q!5$53
M("X@)R]A9&UI;B]G<F]U<',O)R`N("1F;W)M.PI]"@HO*B!'970@=&AE('!E
M<FUS('1R964N("HO"B1N;V1E<R`]("1G<F]U<',M/FQI<W1'<F]U<',H=')U
M92D["B1N;V1E<UM$051!5%)%15]23T]472`]($1!5$%44D5%7U)/3U0["@HO
M*B!3970@=7`@<V]M92!N;V1E('!A<F%M<RX@*B\*)'-P86-E<B`]("<F;F)S
M<#LF;F)S<#LF;F)S<#LF;F)S<#LG.PHD:6-O;F1I<B`](&%R<F%Y*"=I8V]N
M9&ER)R`]/B`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"DI.PHD9W)O=7!?;F]D
M92`]("1I8V]N9&ER("L@87)R87DH)VEC;VXG(#T^("=G<F]U<"YP;F<G*3L*
M)&%D9"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO9W)O=7!S+G!H
M<#]A8W1I;VY)1#UA9&1C:&EL9"<I.PHD961I="`]($AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@G861M:6XO9W)O=7!S+G!H<#]A8W1I;VY)1#UE9&ET)RD["B1D
M96QE=&4@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+V=R;W5P<RYP
M:'`_86-T:6]N240]9&5L971E)RD["B1E9&ET7VEM9R`]($AO<F1E.CII;6<H
M)V5D:70N<&YG)RP@7R@B161I="!'<F]U<"(I*3L*)&1E;&5T95]I;6<@/2!(
M;W)D93HZ:6UG*"=D96QE=&4N<&YG)RP@7R@B1&5L971E($=R;W5P(BDI.PH*
M+RH@4V5T('5P('1H92!T<F5E+B`J+PHD=')E92`]("9(;W)D95]4<F5E.CIS
M:6YG;&5T;VXH)V%D;6EN7V=R;W5P<R<L("=J879A<V-R:7!T)RD["B1T<F5E
M+3YS971/<'1I;VXH87)R87DH)V%L=&5R;F%T92<@/3X@=')U92P@)VAI9&5(
M96%D97)S)R`]/B!T<G5E*2D["B1T<F5E+3YS971(96%D97(H87)R87DH87)R
M87DH)W=I9'1H)R`]/B`G-3`E)RDI*3L*"B\J($5X<&QI8VET;'D@8VAE8VL@
M9F]R(#X@,"!S:6YC92!W92!C86X@8F4@8V%L;&5D('=I=&@@8W5R<F5N="`]
M("TQ"B`J(&9O<B!T:&4@<F]O="!N;V1E+B`J+PII9B`H)&-I9"`^(#`I('L*
M("`@("1C:61?<&%R96YT<R`]("1G<F]U<',M/F=E=$=R;W5P4&%R96YT3&ES
M="@D8VED*3L*("`@(&EF("AI<U]A*"1C:61?<&%R96YT<RP@)U!%05)?15)R
M;W(G*2D@>PH@("`@("`@($AO<F1E.CIF871A;"@D8VED7W!A<F5N=',L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]"GT*"F9O<F5A8V@@*"1N;V1E<R!A
M<R`D:60@/3X@)&YO9&4I('L*("`@("1N;V1E7V-L87-S(#T@*"1C:60@/3T@
M)&ED*2`_(&%R<F%Y*"=C;&%S<R<@/3X@)W-E;&5C=&5D)RD@.B!A<G)A>2@I
M.PH@("`@:68@*"1I9"`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@)&%D
M9%]I;6<@/2!(;W)D93HZ:6UG*"=G<F]U<"YP;F<G+"!?*")!9&0@3F5W($=R
M;W5P(BDI.PH@("`@("`@("1A9&1?;&EN:R`]($AO<F1E.CIL:6YK*%5T:6PZ
M.F%D9%!A<F%M971E<B@D861D+"`G8VED)RP@)&ED*2P@7R@B061D($YE=R!'
M<F]U<"(I*2`N("1A9&1?:6UG("X@)SPO83XG.PH*("`@("`@("`D8F%S95]N
M;V1E7W!A<F%M<R`]("1I8V]N9&ER("L@87)R87DH)VEC;VXG(#T^("=A9&UI
M;FES=')A=&EO;BYP;F<G*3L*("`@("`@("`D=')E92T^861D3F]D92@D:60L
M(&YU;&PL(%\H(D%L;"!'<F]U<',B*2P@,"P@=')U92P@)&)A<V5?;F]D95]P
M87)A;7,@*R`D;F]D95]C;&%S<RP@87)R87DH)'-P86-E<BP@)&%D9%]L:6YK
M*2D["B`@("!](&5L<V4@>PH@("`@("`@("1A9&1?:6UG(#T@2&]R9&4Z.FEM
M9R@G9W)O=7`N<&YG)RP@7R@B061D($-H:6QD($=R;W5P(BDI.PH@("`@("`@
M("1A9&1?;&EN:R`]($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<B@D
M861D+"`G8VED)RP@)&ED*2P@7R@B061D($-H:6QD($=R;W5P(BDI("X@)&%D
M9%]I;6<@+B`G/"]A/B<["B`@("`@("`@)&5D:71?;&EN:R`]($AO<F1E.CIL
M:6YK*%5T:6PZ.F%D9%!A<F%M971E<B@D961I="P@)V-I9"<L("1I9"DL(%\H
M(D5D:70@1W)O=7`B*2D@+B`D961I=%]I;6<@+B`G/"]A/B<["B`@("`@("`@
M)&1E;&5T95]L:6YK(#T@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R
M*"1D96QE=&4L("=C:60G+"`D:60I+"!?*")$96QE=&4@1W)O=7`B*2D@+B`D
M9&5L971E7VEM9R`N("<\+V$^)SL*"B`@("`@("`@)'!A<F5N=%]I9"`]("1G
M<F]U<',M/F=E=$=R;W5P4&%R96YT*"1I9"D["B`@("`@("`@)&=R;W5P7V5X
M=')A(#T@87)R87DH)'-P86-E<BP@)&%D9%]L:6YK+"`D961I=%]L:6YK+"`D
M9&5L971E7VQI;FLI.PH@("`@("`@("1T<F5E+3YA9&1.;V1E*"1I9"P@)'!A
M<F5N=%]I9"P@)&=R;W5P<RT^9V5T1W)O=7!3:&]R=$YA;64H)&YO9&4I+"`D
M9W)O=7!S+3YG971,979E;"@D:60I("L@,2P@*&ES<V5T*"1C:61?<&%R96YT
M<ULD:61=*2D@/R!T<G5E(#H@9F%L<V4L("1G<F]U<%]N;V1E("L@)&YO9&5?
M8VQA<W,L("1G<F]U<%]E>'1R82D["B`@("!]"GT*"B1T<F5E+3YR96YD97)4
M<F5E*"D["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O
M=&5R+FEN8R<["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]A9&UI;B]I;F1E>"YP:'``````````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C4W`#$P-#$W,S8R
M-S8P`#`Q-S,S-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A9&UI;B]I;F1E
M>"YP:'`L=B`Q+C$U+C@N,R`R,#`V+S`Q+S`Q(#(Q.C(X.C`U(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F
M:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*"FEF("@A075T:#HZ:7-!
M9&UI;B@I*2!["B`@("!(;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PI]"@HD=&ET;&4@/2!?*")!9&UI;FES=')A=&EO
M;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E
M<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M
M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]P:'!S:&5L;"YP:'``````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-30S`#$P
M-#$W,S8R-S8P`#`R,#`T-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A9&UI
M;B]P:'!S:&5L;"YP:'`L=B`Q+C(T+C$P+C@@,C`P-B\P,B\R-"`R,CHT.#HR
M.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92](96QP+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@
M>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D[
M"GT*"B1T:71L92`](%\H(E!(4"!3:&5L;"(I.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PH*)&%P
M<'-?=&UP(#T@)')E9VES=')Y+3YL:7-T07!P<R@I.PHD87!P<R`](&%R<F%Y
M*"D["F9O<F5A8V@@*"1A<'!S7W1M<"!A<R`D87!P*2!["B`@("`D87!P<ULD
M87!P72`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D["GT*87-O<G0H
M)&%P<',I.PHD87!P;&EC871I;VX@/2!5=&EL.CIG971&;W)M1&%T82@G87!P
M)RP@)VAO<F1E)RD["C\^"CQD:78@<W1Y;&4](G!A9&1I;F<Z,3!P>"(^"CQF
M;W)M(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%4E9%4ELG4$A07U-%3$8G72`_
M/B(@;65T:&]D/2)P;W-T(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^
M"@H\:#$@8VQA<W,](FAE861E<B(^/#]P:'`@96-H;R!?*")!<'!L:6-A=&EO
M;B(I(#\^/"]H,3X\8G(@+SX*/'-E;&5C="!N86UE/2)A<'`B/@H\/W!H<"!F
M;W)E86-H("@D87!P<R!A<R`D87!P(#T^("1N86UE*3H@/SX*("`\;W!T:6]N
M('9A;'5E/2(\/W!H<"!E8VAO("1A<'`@/SXB/#]P:'`@:68@*"1A<'!L:6-A
M=&EO;B`]/2`D87!P*2!E8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^
M/#]P:'`@96-H;R`D;F%M92`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W)E86-H
M.R`_/@H\+W-E;&5C=#X\8G(@+SX\8G(@+SX*/#]P:'`*"FEF("@D8V]M;6%N
M9"`]('1R:6TH571I;#HZ9V5T1F]R;41A=&$H)W!H<"<I*2D@>PH@("`@:68@
M*$!F:6QE7V5X:7-T<R@D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P
M;&EC871I;VXI("X@)R]L:6(O8F%S92YP:'`G*2D@>PH@("`@("`@(&EN8VQU
M9&4@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<&QI8V%T:6]N*2`N
M("<O;&EB+V)A<V4N<&AP)SL*("`@('T@96QS92!["B`@("`@("`@)')E9VES
M=')Y+3YP=7-H07!P*"1A<'!L:6-A=&EO;BD["B`@("!]"@H@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]-24U%+U9I97=E<BYP:'`G.PH@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]-24U%+U9I97=E<B]S;W5R8V4N<&AP)SL*("`@("1P<F5T
M='D@/2!H:6=H;&EG:'1?<W1R:6YG*"<\/W!H<"`G("X@)&-O;6UA;F0L('1R
M=64I.PH@("`@)'!R971T>2`]('-T<E]R97!L86-E*&%R<F%Y*"<F;'0[/W!H
M<"`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<\9F]N="!C
M;VQO<CTB(S`P,#`P,"(^/&9O;G0@8V]L;W(](B,P,#<W,#`B/B9L=#L_/"]F
M;VYT/CQF;VYT(&-O;&]R/2(C,#`P,$)"(CYP:'`@/"]F;VYT/B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(EQR7&XB+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(")<<B(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G/&)R("\^)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(EQN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R971T
M>2D["B`@("`D<')E='1Y(#T@34E-15]6:65W97)?4V]U<F-E.CIL:6YE3G5M
M8F5R*'1R:6TH)'!R971T>2DI.PH*("`@(&5C:&\@)SQH,2!C;&%S<STB:&5A
M9&5R(CXG("X@7R@B4$A0($-O9&4B*2`N("<\+V@Q/CQB<B`O/B<["B`@("!E
M8VAO("1P<F5T='D["@H@("`@96-H;R`G/&)R("\^/&@Q(&-L87-S/2)H96%D
M97(B/B<@+B!?*")297-U;'1S(BD@+B`G/"]H,3X\8G(@+SXG.PH@("`@96-H
M;R`G/'!R92!C;&%S<STB=&5X="(^)SL*("`@(&5V86PH)&-O;6UA;F0I.PH@
M("`@96-H;R`G/"]P<F4^/&)R("\^)SL*?0H_/@H*/'1E>'1A<F5A(&-L87-S
M/2)F:7AE9"(@;F%M93TB<&AP(B!R;W=S/2(Q,"(@8V]L<STB-C`B/@H\/W!H
M<"!I9B`H(65M<'1Y*"1C;VUM86YD*2D@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1C;VUM86YD*2`_/CPO=&5X=&%R96$^"CQB<B`O/@H\:6YP=70@='EP93TB
M<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")%
M>&5C=71E(BD@/SXB("\^"CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G861M:6XG
M+"`G861M:6XM<&AP<VAE;&PG*2`_/@H*/"]F;W)M/@H\+V1I=CX*/#]P:'`*
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN
M8R<["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"\`````````````````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S``,#$U,C$P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W-C<FEP=',O````````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<V,``P,38V-S8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M<V-R:7!T<R]C=7-T;VU?;&]G:6XN<&AP````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R-S`W`#$P-#$W,S8R-S8P`#`R,C$Q-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+R`D2&]R
M9&4Z(&EM<"]S8W)I<'1S+V-U<W1O;5]L;V=I;BYP:'`L=B`Q+C8N,3`N,B`R
M,#`U+S$P+S$X(#$R.C$T.C`V(&IA;B!%>'`@)`H*+R\@0U535$]-25I%(%1(
M25,*9&5F:6YE*"=)35!?0D%312<L("<N+B<I.PH*9&5F:6YE*"=!551(7TA!
M3D1,15(G+"!T<G5E*3L*)&%U=&AE;G1I8V%T:6]N(#T@)VYO;F4G.PIR97%U
M:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?
M;VYC92!)35!?0D%312`N("<O8V]N9FEG+W-E<G9E<G,N<&AP)SL*"B\J(%-E
M="!U<"!T:&4@<&%S<W=O<F0@96YC<GEP=&EO;B!T;VME;BX@*B\*4V5C<F5T
M.CIS971+97DH)VEM<"<I.PH*+RH@57-E('1H92!F:7)S="!S97)V97(@9&5F
M:6YE9"!I;B!S97)V97)S+G!H<"X@*B\*+R\@0U535$]-25I%(%1(25,*"B1S
M97)V97)?:V5Y(#T@)VQO8V%L:&]S="<["@HD<V5R=F5R7W9A;'5E(#T@)'-E
M<G9E<G-;)'-E<G9E<E]K97E=6R=S97)V97(G73L*)'!R;W1O8V]L7W9A;'5E
M(#T@)'-E<G9E<G-;)'-E<G9E<E]K97E=6R=P<F]T;V-O;"==.PHD<&]R=%]V
M86QU92`]("1S97)V97)S6R1S97)V97)?:V5Y75LG<&]R="==.PHD;6%I;&1O
M;6%I;E]V86QU92`]("1S97)V97)S6R1S97)V97)?:V5Y75LG;6%I;&1O;6%I
M;B==.PHD<F5A;&U?=F%L=64@/2`D<V5R=F5R<ULD<V5R=F5R7VME>5U;)W)E
M86QM)UT["B1U<FP@/2`G+R<["B\O("1U<FP@/2`G+R<@+B`D<F5G:7-T<GDM
M/F=E="@G:6YI=&EA;%]P86=E)RPG:&]R9&4G*3L*"C\^"@H\(2TM($-54U1/
M34E:12!42$E3("TM/@H\9F]R;2!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=R961I<F5C="YP:'`G*2`_/B(@;65T:&]D/2)P
M;W-T(CX*57-E<CH@/&EN<'5T(&YA;64](FEM87!U<V5R(B!T>7!E/2)T97AT
M(B!S:7IE/2(R,"(@+SX\8G(@+SX*4&%S<SH@/&EN<'5T(&YA;64](G!A<W,B
M('1Y<&4](G!A<W-W;W)D(B!S:7IE/2(R,"(@+SX\8G(@+SX*/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB<V5R=F5R(B!V86QU93TB/#]P:'`@96-H;R`D
M<V5R=F5R7W9A;'5E(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)P<F]T;V-O;"(@=F%L=64](CP_<&AP(&5C:&\@)'!R;W1O8V]L7W9A;'5E
M(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)P;W)T(B!V86QU
M93TB/#]P:'`@96-H;R`D<&]R=%]V86QU92`_/B(@+SX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB;6%I;&1O;6%I;B(@=F%L=64](CP_<&AP(&5C:&\@
M)&UA:6QD;VUA:6Y?=F%L=64@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](G)E86QM(B!V86QU93TB/#]P:'`@96-H;R`D<F5A;&U?=F%L=64@
M/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5R;"(@=F%L=64]
M(CP_<&AP(&5C:&\@)'5R;"`_/B(@+SX*/&EN<'5T('1Y<&4](G-U8FUI="(@
M=F%L=64](DQO9R!I;B(@+SX*/"]F;W)M/@H`````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]S8W)I<'1S+TEM<"YR96<`````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$U,S4`,3`T,3<S
M-C(W-C``,#(P,3(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````%)%1T5$250T"@I;2$M%65],3T-!3%]-04-(24Y%7%-/1E17
M05)%7$-L:65N='-<36%I;%T*0#TB26UP(@H*6TA+15E?3$]#04Q?34%#2$E.
M15Q33T945T%215Q#;&EE;G1S7$UA:6Q<26UP70I`/2))35`B"@I;2$M%65],
M3T-!3%]-04-(24Y%7%-/1E1705)%7$-L:65N='-<36%I;%Q);7!<4')O=&]C
M;VQS70H*6TA+15E?3$]#04Q?34%#2$E.15Q33T945T%215Q#;&EE;G1S7$UA
M:6Q<26UP7%!R;W1O8V]L<UQM86EL=&]="B)%9&ET1FQA9W,B/6AE>#HP,BPP
M,"PP,"PP,`HB55),(%!R;W1O8V]L(CTB(@I`/2)54DPZ36%I;%1O(%!R;W1O
M8V]L(@H*6TA+15E?3$]#04Q?34%#2$E.15Q33T945T%215Q#;&EE;G1S7$UA
M:6Q<26UP7%!R;W1O8V]L<UQM86EL=&]<<VAE;&Q="@I;2$M%65],3T-!3%]-
M04-(24Y%7%-/1E1705)%7$-L:65N='-<36%I;%Q);7!<4')O=&]C;VQS7&UA
M:6QT;UQS:&5L;%QO<&5N70H*6TA+15E?3$]#04Q?34%#2$E.15Q33T945T%2
M15Q#;&EE;G1S7$UA:6Q<26UP7%!R;W1O8V]L<UQM86EL=&]<<VAE;&Q<;W!E
M;EQC;VUM86YD70I`/2)I97AP;&]R92YE>&4@+6YO:&]M92!W96)M86EL+F5X
M86UP;&4N8V]M+VAO<F1E+VEM<"\_86-T:6]N240];&]G:6Y?8V]M<&]S929T
M;STE,2(*"EM(2T597TQ/0T%,7TU!0TA)3D5<4T]&5%=!4D5<0VQI96YT<UQ-
M86EL7$EM<%QS:&5L;%T*"EM(2T597TQ/0T%,7TU!0TA)3D5<4T]&5%=!4D5<
M0VQI96YT<UQ-86EL7$EM<%QS:&5L;%QO<&5N70H*6TA+15E?3$]#04Q?34%#
M2$E.15Q33T945T%215Q#;&EE;G1S7$UA:6Q<26UP7'-H96QL7&]P96Y<8V]M
M;6%N9%T*0#TB:65X<&QO<F4N97AE("UN;VAO;64@=V5B;6%I;"YE>&%M<&QE
M+F-O;2]H;W)D92]I;7`B"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]S8W)I<'1S+RYH=&%C8V5S
M<P``````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`
M,3`T,3<S-C(W-C``,#(P-#8V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$1E;GD@9G)O;2!A;&P*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+P``````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S
M`#`Q-C0U,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O8F=?
M0D<O````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-C``,#$W-#`V`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+VQO8V%L92]B9U]"1R],0U]-15-304=%4R\`````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,``P,C$Q-S,`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+V)G7T)'+TQ#7TU%4U-!
M1T53+VEM<"YM;P``````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,30S-C`W`#$P-#$W
M,S8R-S8P`#`R,C,R-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#>$@25`````)<"```<````U!0``'<#``",*0```````&@W
M```*````:3<```H```!T-P``"@```'\W```.````BC<```@```"9-P``#```
M`*(W```*````KS<```0```"Z-P```0```+\W```7````P3<```L```#9-P``
M!0```.4W```H````ZS<``!4````4.```,@```"HX```I````73@``#(```"'
M.```#@```+HX```&````R3@``!L```#0.```+@```.PX```W````&SD``'P`
M``!3.0``'````-`Y```=````[3D```@````+.@``,@```!0Z```X````1SH`
M`%0```"`.@``40```-4Z```T````)SL```4```!<.P```P```&([```/````
M9CL```T```!V.P``$@```(0[```/````ESL``!D```"G.P``!P```,$[```,
M````R3L```T```#6.P``#@```.0[```#````\SL```4```#W.P```P```/T[
M```*`````3P```\````,/```4````!P\``!"````;3P``",```"P/```'P``
M`-0\```(````]#P``!$```#]/```(P````\]```1````,ST```P```!%/0``
M,````%(]```[````@ST``#$```"_/0``#````/$]```)````_CT``#D````(
M/@``-0```$(^```.````>#X```H```"'/@``"P```)(^```G````GCX``"P`
M``#&/@``*@```/,^```*````'C\``!4````I/P``*0```#\_```8````:3\`
M`!$```""/P``"@```)0_```6````GS\``!8```"V/P```P```,T_```(````
MT3\```D```#:/P``!````.0_```$````Z3\```D```#N/P``!````/@_```G
M````_3\```,````E0````P```"E````@````+4````(```!.0```"@```%%`
M```&````7$````H```!C0```7P```&Y````<````SD````X```#K0```%0``
M`/I````U````$$$``$4```!&00``40```(Q!```Q````WD$``!$````00@``
M#0```")"```,````,$(``!0````]0@``#P```%)"```,````8D(```8```!O
M0@``!P```'9"```'````?D(``!<```"&0@``)@```)Y"```0````Q4(``"L`
M``#60@``&P````)#```;````'D,``!X````Z0P``7````%E#```$````MD,`
M``<```"[0P``#@```,-#```>````TD,``!L```#Q0P``&P````U$```V````
M*40``#,```!@1```*0```)1$``!!````OD0``#H`````10``+P```#M%```I
M````:T4```T```"510``&@```*-%```=````OD4``!D```#<10``70```/9%
M```H````5$8```,```!]1@```@```(%&```%````A$8```0```"*1@``$```
M`(]&```9````H$8``!H```"Z1@``!@```-5&```4````W$8``!````#Q1@``
M,P````)'```'````-D<``!`````^1P``'````$]'```*````;$<```<```!W
M1P``+P```']'```/````KT<```<```"_1P``#P```,='```M````UT<``!H`
M```%2```*````"!(```+````24@``",```!52```$@```'E(```%````C$@`
M``X```"22```#@```*%(```6````L$@```4```#'2```#0```,U(```;````
MVT@``!T```#W2```#P```!5)```2````)4D```T````X20``&0```$9)```<
M````8$D``!4```!]20``"P```)-)```3````GTD``!````"S20``-0```,1)
M```%````^DD``!``````2@``$````!%*```/````(DH```L````R2@``#P``
M`#Y*```,````3DH```\```!;2@``"@```&M*```2````=DH```T```")2@``
M#````)=*``!#````I$H``#T```#H2@``'@```"9+```A````14L``"````!G
M2P```P```(A+```*````C$L``"````"72P``$P```+A+```4````S$L```P`
M``#A2P``"0```.Y+```;````^$L``"4````43```!P```#I,```$````0DP`
M``H```!'3```$````%),```&````8TP```<```!J3```"````'),```1````
M>TP``!D```"-3```!````*=,```,````K$P```D```"Y3```!````,-,```%
M````R$P``!H```#.3```%````.E,```&````_DP``!$````%30``'@```!=-
M```'````-DT```0````^30``#````$--```1````4$T```0```!B30``#0``
M`&=-```'````=4T```0```!]30``#````()-```*````CTT```4```":30``
M)P```*!-```$````R$T``"````#-30``(````.Y-```F````#TX```T````V
M3@``&P```$1.```,````8$X```4```!M3@``*0```'-.```*````G4X```\`
M``"H3@``!@```+A.```*````OTX```X```#*3@``'P```-E.```>````^4X`
M`!4````83P``$0```"Y/```0````0$\```D```!13P``$@```%M/```=````
M;D\``!(```",3P``$````)]/```Q````L$\``"0```#B3P``'`````=0```C
M````)%```"(```!(4```!@```&M0```6````<E```!<```")4```"P```*%0
M```A````K5```"````#/4```!@```/!0```,````]U````P````$40``#0``
M`!%1```H````'U$```H```!(40``*P```%-1```N````?U$```@```"N40``
M"0```+=1```0````P5$``'P```#240``%0```$]2```:````95(```X```"`
M4@``#````(]2```'````G%(```L```"D4@```P```+!2```,````M%(```8`
M``#!4@```@```,A2```E````RU(```0```#Q4@``!P```/92```(````_E(`
M`#<````'4P``#P```#]3```'````3U,```H```!74P``!P```&)3```3````
M:E,```P```!^4P``#@```(M3```,````FE,```X```"G4P``#P```+93```-
M````QE,```\```#44P``#P```.13```N````]%,``!H````C5```)@```#Y4
M```+````950```8```!Q5```"0```'A4```-````@E0```<```"05```!```
M`)A4```*````G50```0```"H5```(@```*U4```'````T%0```4```#85```
M`P```-Y4```*````XE0```@```#M5```%P```/94```,````#E4```P````;
M50``"0```"A5```"````,E4```T````U50``$@```$-5```;````5E4``!4`
M``!R50``,P```(A5```S````O%4``#@```#P50``&0```"E6```4````0U8`
M`"````!85@``+0```'E6```Q````IU8``"P```#95@``)0````97```D````
M+%<``!(```!15P``#@```&17```:````<U<```D```".5P``!````)A7```&
M````G5<```L```"D5P``"0```+!7```-````NE<```P```#(5P``%P```-57
M```4````[5<``!8````"6```!0```!E8```\````'U@```P```!<6```(P``
M`&E8```'````C5@```P```"56```$0```*)8```-````M%@``!$```#"6```
M`P```-18```T````V%@```L````-60``%````!E9```^````+ED``#0```!M
M60``,0```*)9```2````U%D``!````#G60``&````/A9```G````$5H``%8`
M```Y6@``30```)!:```)````WEH```0```#H6@``&P```.U:```,````"5L`
M``T````66P``!P```"1;```*````+%L``!(````W6P``(0```$I;```+````
M;%L``!P```!X6P``&````)5;```(````KEL```D```"W6P``"@```,%;```5
M````S%L```4```#B6P``*````.A;```+````$5P``!H````=7```"````#A<
M```4````05P``"P```!67```)P```(-<```J````JUP```4```#67```,0``
M`-Q<```@````#ET``'8````O70``>0```*9=```N````(%X``"$```!/7@``
M$````'%>```-````@EX```4```"07@``"````)9>```)````GUX``"\```"I
M7@``,@```-E>```-````#%\``!8````:7P``/@```#%?```G````<%\``!8`
M``"87P``!0```*]?```$````M5\``#(```"Z7P``"````.U?```5````]E\`
M`!,````,8```!P```"!@```5````*&````L````^8```%@```$I@```/````
M86```"H```!Q8```!@```)Q@```/````HV```!````"S8```+@```,1@```Z
M````\V````T````N80``!0```#QA```,````0F$```T```!/80``#0```%UA
M```.````:V$```@```!Z80``"@```(-A```&````CF$```X```"580``!@``
M`*1A``!+````JV$```8```#W80``#@```/YA```7````#6(``$$````E8@``
M,0```&=B```J````F6(```D```#$8@```P```,YB```'````TF(``#D```#:
M8@``!@```!1C```.````&V,```0````J8P``!@```"]C```5````-F,``!(`
M``!,8P``#P```%]C```4````;V,``$,```"$8P``"@```,AC```1````TV,`
M``L```#E8P``&@```/%C```7````#&0``!<````D9```&P```#QD```9````
M6&0``!\```!R9```%P```))D```<````JF0``!$```#'9```!@```-ED```'
M````X&0``$,```#H9```,@```"QE``!7````7V4``#\```"W90``.0```/=E
M``!&````,68```0```!X9@``$````'UF```,````CF8``!0```";9@``'0``
M`+!F```1````SF8``"````#@9@``*`````%G```$````*F<```\````O9P``
M#````#]G```4````3&<``!0```!A9P``#P```'9G```.````AF<``!<```"5
M9P``$@```*UG```+````P&<```T```#,9P``%````-IG```O````[V<```8`
M```?:```!P```"9H```-````+F@``!8````\:```!P```%-H```+````6V@`
M``4```!G:```+P```&UH```$````G6@```D```"B:```(@```*QH```@````
MSV@``#,```#P:```2@```"1I```X````;VD``!X```"H:0``=0```,=I```^
M````/6H``$(```!\:@``/0```+]J```I````_6H``"D````G:P``,0```%%K
M``!(````@VL``"````#,:P``'@```.UK``!)````#&P``#P```!6;```.```
M`)-L```\````S&P``"8````);0``,````#!M``!I````86T``#X```#+;0``
M/@````IN``!'````26X``#T```"1;@``90```,]N``!-````-6\``%,```"#
M;P``5P```-=O``!5````+W```$8```"%<```+P```,QP``!5````_'```"``
M``!2<0``+@```'-Q``!2````HG$``#(```#U<0``*P```"AR```P````5'(`
M`"\```"%<@``+````+5R```7````XG(``"4```#Z<@``,@```"!S```^````
M4W,``"4```"2<P``50```+AS```O````#G0``#(````^=```*0```'%T```/
M````FW0``"$```"K=```,````,UT```<````_G0```L````;=0``#0```"=U
M```%````-74```(````[=0``#0```#YU```#````3'4``"````!0=0``(@``
M`'%U```E````E'4``!@```"Z=0``)@```--U```*````^G4``!,````%=@``
M"````!EV```)````(G8``!8````L=@``$0```$-V```'````578```8```!=
M=@``&@```&1V```&````?W8```D```"&=@``!@```)!V```1````EW8``!X`
M``"I=@``$P```,AV```(````W'8```D```#E=@``"@```.]V```4````^G8`
M``@````/=P``/P```!AW```$````6'<```<```!==P``$@```&5W```9````
M>'<``!@```"2=P``)P```*MW```&````TW<```T```#:=P``"P```.AW```O
M````]'<``%H````D>```#````']X```*````C'@```(```"7>```!@```)IX
M```#````H7@``"@```"E>```2P```,YX``!.````&GD``"D```!I>0``)@``
M`)-Y```E````NGD``"@```#@>0``/0````EZ``!!````1WH``"@```")>@``
M+````+)Z```0````WWH```D```#P>@``'````/IZ```0````%WL```\````H
M>P``#@```#A[``!S````1WL``!\```"[>P``%````-M[```/````\'L```P`
M````?```#P````U\```$````'7P```0````B?```!````"=\```"````+'P`
M``X````O?```#P```#Y\```'````3GP```4```!6?```4P$``%Q\```*````
ML'T```H```"[?0``"@```,9]```/````T7T```<```#A?0``"````.E]```*
M````\GT```,```#]?0```0````%^```4`````WX```X````8?@``!0```"=^
M```E````+7X``!P```!3?@``.0```'!^```?````JGX``#````#*?@``#```
M`/M^```&````"'\``!L````/?P``-@```"M_```T````8G\``'H```"7?P``
M%@```!*````:````*8````<```!$@```-0```$R````U````@H```%(```"X
M@```3P````N!```W````6X$```4```"3@0```0```)F!```.````FX$``!8`
M``"J@0``%@```,&!```6````V($``"8```#O@0``!0```!:"```0````'((`
M``T````M@@``#@```#N"```'````2H(```D```!2@@``!@```%R"```,````
M8X(```P```!P@@``1P```'V"``!&````Q8(``"(````,@P``(P```"^#```)
M````4X,```\```!=@P``)0```&V#```7````DX,```T```"K@P``.0```+F#
M``!`````\X,``#`````TA```$P```&6$```*````>80``#<```"$A```.```
M`+R$```/````]80```X````%A0``$@```!2%```M````)X4``"T```!5A0``
M+P```(.%```(````LX4``!@```"\A0``,@```-6%```6````"(8```\````?
MA@``#````"^&```;````/(8``"4```!8A@```P```'Z&```*````@H8```P`
M``"-A@``!````)J&```)````GX8```<```"IA@``!0```+&&```<````MX8`
M``,```#4A@```P```-B&```F````W(8```(````#AP``#P````:'```'````
M%H<```X````>AP``:````"V'```B````EH<``!````"YAP``%0```,J'``!`
M````X(<``$<````AB```6@```&F(``!'````Q(@``!$````,B0``#P```!Z)
M```-````+HD``!,````\B0``#````%")```0````78D```<```!NB0``"```
M`':)```(````?XD``!(```"(B0``*@```)N)```3````QHD``"D```#:B0``
M(`````2*```A````)8H``"0```!'B@``70```&R*```'````RHH```D```#2
MB@``#P```-R*```E````[(H``"4````2BP``)P```#B+```W````8(L``"4`
M``"8BP``,P```+Z+```U````\HL``"T````HC```.@```%:,```U````D8P`
M``P```#'C```&P```-2,```=````\(P``!D````.C0``:````"B-```O````
MD8T```8```#!C0```@```,B-```)````RXT```0```#5C0``&P```-J-```F
M````]HT``"0````=C@``!@```$*.```7````28X```\```!AC@``1@```'&.
M```'````N(X```T```#`C@``(````,Z.```*````[XX```<```#ZC@``+@``
M``*/```>````,8\```8```!0CP``#0```%>/```V````98\``"````"<CP``
M,0```+V/```,````[X\``",```#\CP``$````""0```'````,9```!`````Y
MD```#````$J0```C````5Y````4```![D```"P```(&0```B````C9```"$`
M``"PD```$0```-*0```0````Y)```!````#UD```)@````:1```I````+9$`
M`!H```!7D0``#P```'*1```5````@I$``!8```"8D0``-````*^1```&````
MY)$```\```#KD0``$````/N1```.````#)(```T````;D@``%````"F2```,
M````/I(``!,```!+D@``#P```%^2```5````;Y(```X```"%D@``#@```)22
M```_````HY(``#X```#CD@``*0```"*3```R````3),``"0```!_DP``!```
M`*23```*````J9,``"L```"TDP``%0```."3```6````]I,```P````-E```
M"P```!J4```F````)I0``#4```!-E```!@```(.4```%````BI0```X```"0
ME```%````)^4```&````M)0```@```"[E```"0```,24```0````SI0``!8`
M``#?E````@```/:4```(````^90```L````"E0``!`````Z5```%````$Y4`
M`!@````9E0``%P```#*5```%````2I4```X```!0E0``(0```%^5```.````
M@94```4```"0E0``#P```):5```3````II4```4```"ZE0``"@```,"5```)
M````RY4```8```#5E0``#0```-R5```/````ZI4```4```#ZE0``+P````"6
M```$````,)8``"\````UE@``+P```&66```\````E98```X```#2E@``'0``
M`.&6```-````_Y8```4````-EP``)@```!.7```*````.I<```T```!%EP``
M"0```%.7```0````79<``!(```!NEP``'P```(&7```F````H9<``!L```#(
MEP``%0```.27```3````^I<```4````.F```"P```!28```@````()@``!0`
M``!!F```$P```%:8```X````:I@``#````"CF```'@```-28```E````\Y@`
M`"<````9F0``!@```$&9```O````2)D``!\```!XF0``#@```)B9```E````
MIYD``"<```#-F0``"0```/69```2````_YD``!$````2F@``$@```"2:```J
M````-YH``!````!BF@``+0```'.:```S````H9H```0```#5F@``$0```-J:
M```*````[)H``(<```#WF@``$P```'^;```A````DYL```T```"UFP``"0``
M`,.;```%````S9L```\```#3FP``"P```..;```.````[YL```T```#^FP``
M`@````R<```M````#YP```0````]G```#@```$*<```.````49P``$$```!@
MG```$````**<```'````LYP```X```"[G```!0```,J<```2````T)P```\`
M``#CG```$````/.<```1````!)T``!,````6G0``$````"J=```2````.YT`
M``X```!.G0``"P```%V=```X````:9T``!\```"BG0``)0```,*=```)````
MZ)T```4```#RG0``"````/B=```1`````9X```<````3G@``"````!N>```*
M````))X```,````OG@``)0```#.>```%````69X```8```!?G@``!````&:>
M```*````:YX```D```!VG@``(P```(">```*````I)X```X```"OG@``$0``
M`+Z>```"````T)X```X```#3G@``%@```.*>```B````^9X``"$````<GP``
M)@```#Z?```F````99\``"L```",GP``%0```+B?```>````SI\``",```#M
MGP``*P```!&@```O````/:```#4```!MH```+@```*.@```P````TJ```!8`
M```#H0``$````!JA```9````*Z$```X```!%H0``!````%2A```(````6:$`
M``D```!BH0``"@```&RA```)````=Z$```@```"!H0``&````(JA```/````
MHZ$```\```"SH0``!P```,.A``!+````RZ$```L````7H@``,0```".B```%
M````5:(```\```!;H@``$````&NB```+````?*(``!0```"(H@```P```)VB
M```V````H:(```D```#8H@``&@```.*B```\````_:(``#0````ZHP``+@``
M`&^C```3````GJ,```X```"RHP``'0```,&C```F````WZ,``$D````&I```
M1````%"D```)````E:0```0```"?I```'0```*2D```-````PJ0``!$```#0
MI```!P```.*D```-````ZJ0``!8```#XI```*`````^E```.````.*4``",`
M``!'I0``&@```&NE```&````AJ4```<```"-I0``"````)6E```2````GJ4`
M``8```"QI0``,@```+BE```%````ZZ4``!D```#QI0``"@````NF```5````
M%J8``#8````LI@``+````&.F```O````D*8```<```#`I@``.````,BF```>
M`````:<``&\````@IP``<@```)"G```U`````Z@``"(````YJ```#@```%RH
M```1````:Z@```D```!]J```"0```(>H```)````D:@``#````";J```-P``
M`,RH```0````!*D``",````5J0``/0```#FI```G````=ZD``!<```"?J0``
M"@```+>I```&````PJD``$(```#)J0``"0````RJ```4````%JH``!D````K
MJ@``!P```$6J```?````3:H``!$```!MJ@``&````'^J```/````F*H``"D`
M``"HJ@``"````-*J```7````VZH``!0```#SJ@``0`````BK``!`````2:L`
M``D```"*JP``!P```)2K```1````G*L``!(```"NJP``$@```,&K```3````
MU*L```H```#HJP``"P```/.K```(````_ZL```X````(K```!P```!>L``!,
M````'ZP```8```!LK```#````'.L```=````@*P``$X```">K```.0```.VL
M```I````)ZT```D```!1K0```P```%NM```+````7ZT``#H```!KK0``!0``
M`*:M```6````K*T```H```##K0``!@```,ZM```:````U:T``"````#PK0``
M#P```!&N```=````(:X``#<````_K@``#0```'>N```-````A:X```\```"3
MK@``&0```*.N```:````O:X``!@```#8K@``'@```/&N```C````$*\``"0`
M```TKP``%@```%FO```C````<*\``!<```"4KP``!@```*RO```'````LZ\`
M`#\```"[KP``/0```/NO``!H````.;```%$```"BL```0P```/2P``!.````
M.+$```D```"'L0``'````)&Q```0````KK$``",```"_L0``(0```..Q```4
M````!;(``"P````:L@``,P```$>R```&````>[(``!8```""L@``$````)FR
M```6````JK(``!T```#!L@``$````-^R```1````\+(``!X````"LP``$0``
M`"&S```(````,[,``!4````\LP``%P```%*S```V````:K,```8```"ALP``
M!````*BS```/````K;,``!4```"]LP``!0```-.S```-````V;,```8```#G
MLP``-0```.ZS```%````)+0```H````JM```'````#6T```:````4K0``#0`
M``!MM```1P```**T```K````ZK0``!P````6M0``A0```#.U```]````N;4`
M`$````#WM0``1````#BV```E````?;8``",```"CM@``+P```,>V``!)````
M][8``"0```!!MP``%P```&:W``!7````?K<``"\```#6MP``-`````:X```\
M````.[@``"$```!XN```+P```)JX``!?````RK@``#L````JN0``0P```&:Y
M```_````JKD``#4```#JN0``80```""Z```_````@KH``$4```#"N@``4P``
M``B[``!&````7+L``#D```"CNP``+````-V[``!+````"KP``"8```!6O```
M)P```'V\```^````I;P``"T```#DO```)0```!*]```R````.+T``!P```!K
MO0``&P```(B]```7````I+T``"H```"\O0``,0```.>]``!%````&;X``"``
M``!?O@``.P```("^```K````O+X``"X```#HO@``(0```!>_```,````.;\`
M`"0```!&OP``-P```&N_```@````H[\``!@```#$OP``%0```-V_```(````
M\[\```(```#\OP``#@```/^_```#````#L```"0````2P```*P```#?````E
M````8\```!X```")P```*````*C````+````T<```!$```#=P```"@```._`
M```*````^L```!4````%P0``&P```!O!```)````-\$```P```!!P0``$@``
M`$[!```'````8<$```H```!IP0``!P```'3!```D````?,$``"P```"AP0``
M'P```,[!```#````[L$```0```#RP0``!0```/?!```8````_<$```@````6
MP@``/0```!_"```#````7<(```D```!AP@``%````&O"```:````@,(``!P`
M``";P@``-@```+C"```(````[\(``!````#XP@``#P````G#```T````&<,`
M`%D```!.PP``#````*C#```.````M<,```(```#$PP``!P```,?#```"````
MS\,``"$```#2PP``4P```/3#``!6````2,0``"\```"?Q```*P```,_$```J
M````^\0``"T````FQ0``,````%3%```^````A<4``!X```#$Q0``'0```./%
M```1`````<8```H````3Q@``(@```![&```2````0<8``!0```!4Q@``#```
M`&G&``!E````=L8``"L```#<Q@``#P````C'```.````&,<```L````GQP``
M$````#/'```$````1,<```(```!)QP``!````$S'```#````4<<``!$```!5
MQP``$0```&?'```'````><<```4```"!QP```0```-H`````````D````#4!
M```O`@``8@```/H```!0````5`(````````]`````````'T"```,`@``````
M`,L```"S`````````%4```!C````G0```$$"``#J````%0(``!,"``!Y`0``
M``````````#G`0``X`$``!`"``"7`@``B0(``#@!```*``````````````"_
M`0``D@```-X`````````E@(````````:````D@(``#```````````````)8!
M```T`@``TP$```````#E`````````&H"``"^`0``K@```!$!````````````
M`,P````9`0``)`$`````````````MP```)8```",`0``XP$``(,"```/`@``
MT0$`````````````R````($"```Y````<@``````````````=P(```````!=
M````"0```$L````Z`@``V@$``+\``````````````%L"````````30$`````
M``#N`0``]0$``&(!``#J`0``\P$``#@"```V`0```````+D!``#M````00``
M`),!````````B@$```L!``#2`0``0````/L```!E`0```````(X!``"3`@``
MC0(``'X```"(`0```````.D```"7````,@(```0"```L`@``4@$``&$````E
M````P````+D````K`@``-`$``$P!``#=`0```````',"``"<````20(``!T`
M````````;@```!T"```]`@``]@$```@```!$`````````.@```![````````
M`&0"``!.`````````&H````&`@``#@`````````\`@````````````"<`0``
M`````#\"```'`@``VP```)L!```Y`0``?`(``!,````A````````````````
M````A0````4!``!7`@``!P```%P"`````````````"T"``!>`@```````'(!
M`````````````!<`````````C0````````!/`@``ZP``````````````````
M``````````````````````"Q`0``QP````````#"`0``L0````````"1`@``
M\0$``/D```"R`0``R@`````````S`@``&0```(8"```^`0``(@````````!K
M````,@```"L!``#%````!0```(,`````````3@(``(4!```Q`0``)P``````
M`````````````&P"````````4P(``$0!`````````````(\```#%`0``@`(`
M`*\!``"+`0``V0```)(!``#?`0``)@$``*T`````````50(```````"F`0``
M.P(``(``````````1P```(<````2`@```````%`!``````````````8!``"C
M`0``]`$``,T!``!H````9P```*H!``"+``````````````"A````7P```.$!
M``!P````0@$````````9`@``%`(```````#\`0````````````!:````-@``
M`*D```!C`0````````````!H`0``@0$``!0!````````=0```"("````````
M[`$``%H"````````U`$```\!``#Y`0``2@$````````D`@``(P$`````````
M````/`$``$H````7`@``D0```,(```#2````B@(``*L!```@`0``^P$``(8!
M```<`0``90```&T"``!+`0``:P$```,!``#V`````````(4"``"8````40``
M`%L```#7`0``U@$```````"\````EP$``!(!``!8`0````````L```"T`0``
M`P(``(0```!T`0``[P```,,!```Z````&P$``)X`````````Y@$`````````
M````CP$``%0!``!0`@```````*,```".`@``TP```)4"``",`@``R0$``%0`
M````````@`$``%P```!V`@``&`(``+,!``"H````N`$``%@"``!H`@``0P$`
M``````!6``````````````!)`0``)@```/(!``!<`0``+0```#`!````````
M1P$```````"E````$`$``)\````:`0``[0$``````````````````'@!````
M````)0$```(`````````)P(``&T````>`0``#0```)D```!#`@``V````-P`
M```R`0``V`$```````!"````0`(```H!````````A@```#X"``!!`0``-P``
M`'`"```?`0`````````````:`@``)```````````````60$``-<```"[`0``
M;@$``````````````````*$!````````)@(``#D"````````C`````4"``"L
M`0``10````````````````````````#]````\@```!X```#T````-0(`````
M``!D````H`````````!_`0``(@$```T"``!F````*@(``'H!``!L````````
M``````!Q`@``O@```+8```!&`0```````$\!``":`0```````)L````T````
MM0```+P!`````@``30`````````_`0```````($```""`@``Y@```+8!``!.
M`0``<@(``&,"``!6`@```````&8!``#W````Q@```'$!``!9`@``@@```$4"
M``!B`@``%```````````````K0$```````#Z`0``3`(``,0`````````````
M`-`!``"D````B@```"4"```[`0``P`$``"D!``!V``````$``'<`````````
M#@(```````!A`@``S@$``#P`````````(0$````````/````DP```'X!``!=
M`0```````(@"``!_`@``8````-4!```<````!P$``$H"``"@`0``O0$`````
M````````C0$``.(!``#N````JP```!@````S````%0$`````````````````
M```````C`@```````/@!``!6`0``N@```)`"``#O`0```````'H````+`@``
M`````&P!````````>P(```````#D`0````````````#1````X0```*0!``!"
M`@``B````'T`````````V0$``$L"``"/`@``*@```(<!``!\````%0``````
M````````*`(``"T!``!G`@``A`$`````````````*0```%("``!Y````````
M`$4!``!O`@``Z0$```````"+`@```````,8!`````````````%\"``!K`@``
MSP$``%$"``"Z`0``+````,@!``#C````````````````````_`````````"0
M`0```````!$"``!>`0``Y```````````````GP$``%T"``""`0``NP```#X`
M``!#````;0$``/@```"8`0``"0(``+<!``#P`0``'P(```````"#`0``'`(`
M`)H````3`0``QP$``/,```!1`0``B0$``'H"``!O````1`(``'@"````````
M+`$```@!```-`0``A`(```````!7`0``]0```'4"``!'`@```````%(```"1
M`0```````&D"``"J````2`(```````"]````7@```.<```!F`@```````*\`
M```Z`0``6````/X!``!?`0``%@(``&X"``!^`@``,0```,H!``"X`````P``
M````````````L@```$`!``"G`````````-4```#E`0`````````````(`@``
M3``````````8`0``G@$```$"```1````_0$``',!``!V`0``*0(``!T!```V
M`@``R0```````````````````&0!``"L````"@(``'0"```S`0````````(!
M``"4`@```````%<``````````0$``&`"```W`@``W0```&D!``#K`0``````
M`"X`````````J`$``-`````$````_P$``#@````6`0``````````````````
M`````-\````&````(P```'P!```O````-0```+``````````!`$``(<"````
M````X@```,$```##````B0```!L````J`0``6P$````````_`````````*(!
M```[````X`````````#!`0``4P```/<!``#<`0``\0```!8````H`0``>P$`
M`)4```!]`0``SP```!X"```0````+@$``$8"``"9`0```````!L"```K````
MH@```'\`````````20```,0!``!X````#@$````````)`0``S0```&4"````
M````<0``````````````>0(```P```#6````I@```!(````N`@``#`$`````
M``!T````_@```)0!``!W`0```````-X!``"T````50$``"@```"5`0``+P$`
M`&$!``#4````G0$``,X`````````(0(``$\```!O`0``4P$````````P`@``
ML`$```````!(````M0$``!\````W`0``6@$``"`"``!J`0``,0(``"<!````
M``````````````!P`0``:0````````#;`0```````',``````````````/``
M``!@`0``S`$``"````#L`````````'4!``#_````%P$``)0```"G`0``````
M`(X```#H`0``J0$```("``!9````1@```*4!``#+`0``2`$``&<!``!-`@``
M`````#T!``"N`0``````````````("`@("`@5&\Z(``@("`@1&%T93H@`"`@
M("!&<F]M.B``("@E<R!D87ES(&%G;RD`("AT;V1A>2D`("AY97-T97)D87DI
M`"!3=6)J96-T.B``(&EN(``C`"5D('1O("5D(&]F("5D($UE<W-A9V5S`"5S
M("T@3F]T:6-E`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@
M97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E
M<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S
M(&ES(')E<75I<F5D`"5S.B`E<P`E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE
M9"D`*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E
M96XN*0`H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C
M;VUP;W-E('-C<F5E;BXI`"A2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N
M(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#
M:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L
M:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S
M96QE8W0@861D<F5S<RAE<RD@*@`R-"!H;W5R<P!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--
M24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO
M4$T`04Y$`$%C8V]U;G0G<R!N86UE.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@
M4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&1R97-S($)O;VMS`$%D
M;6EN:7-T<F%T:6]N`$%D<P!!;&EA<P!!;&P`06QL($=R;W5P<P!!;&P@4&5R
M;6ES<VEO;G,`06QL(&UE<W-A9V5S(&EN('EO=7(@(B5S(B!F;VQD97(@;VQD
M97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E9"X`
M06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS
M(&]L9"!W:6QL(&)E(&1E;&5T960N`$%L=&5R;F%T:79E('!A<G1S(&9O<B!T
M:&ES('-E8W1I;VXZ`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`
M06YS=V5R960`06YS=V5R960@;65S<V%G97,`07!P;'D@9FEL=&5R(')U;&5S
M('5P;VX@;&]G9VEN9R!O;C\`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.
M86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L
M:6,@:V5Y/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@
M9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_`$%R<FEV86P@5&EM90!!<V-E
M;F1I;F<`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@
M<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_`$%T=&%C:&5D($9I;&4Z`$%T
M=&%C:&UE;G0`071T86-H;65N=',`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1R:6)U=&5S`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9`!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!
M=F%I;&%B;&4@061D<F5S<R!B;V]K<SH`079A:6QA8FQE(&9I96QD<SH`0F%C
M:R!T;R`E<P!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U
M<V5R;F%M92X`0F-C`$)I<G1H9&%Y`$)L86-K;&ES=`!";V1Y`$)O;&0`0F]O
M:VUA<FMS`$)O=&@`0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-
M97-S86=E`$--4P!#4D,`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V,`0V5L;"!0:&]N90!#:&%N9V4`0VAA;F=E($%L;`!#:&%N9V4@=&AE
M(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E
M('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&5C
M:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$-H;V]S92!!8W1I;VXZ`$-H;V]S
M92!A(&UA:6P@<V5R=F5R.@!#:&]O<V4@=&AE(&%D9')E<W,@8F]O:R!T;R!U
M<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+@!#:&]O<V4@=&AE(&]R9&5R(&]F
M(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E
M<W-E<RX`0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T960@861D<F5S<R!B
M;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T;R!S96%R8V@N`$-L
M:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O
M;VL`0VQO<V4@=&AI<R!W:6YD;W<`0VQO<V5D($9O;&1E<@!#;VQL87!S92!!
M;&P`0V]L;&%P<V4@06QL($9O;&1E<G,`0V]L;&%P<V4@1F]L9&5R`$-O;&]R
M(%!I8VME<@!#;VUI8W,`0V]M;65N=`!#;VUP86YY`$-O;7!O<V4@86YO=&AE
M<B!M97-S86=E`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD
M;W<_`$-O;F9I<FT@4&%S<W=O<F0`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N('1O('-E<G9E<B!F86EL
M960`0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@4R]-24U%
M('-U<'!O<G0@9F]R("5S+@!#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B
M92!C:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y
M;W4@=VAE;B!I="!A<G)I=F5S+@!#;W!Y`$-O<G)E8W0`0V]R<F5C=&5D(%1E
M>'0`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`
M0V]U;&0@;F]T(&1E;&5T92!M97-S86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R
M('-A:60Z("5S`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC
M92!O<&5R871I;VYS+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D
M(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!#;W5L9"!N;W0@
M97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI
M=F4N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-R96%T92!&;VQD97(`0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`
M0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(`0W)E871E(&$@;F5W('1R
M87-H(&9O;&1E<@!#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE
M('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L(&%N
M9"!D96QE=&4@<W!A;2X`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+@!#=70`1$0`1&%I;'D`1&%T90!$969A=6QT($ED96YT:71Y
M`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I
M<F5C=&EO;CH`1&5L971E`$1E;&5T92`E<R!0=6)L:6,@2V5Y`$1E;&5T92!&
M;VQD97(H<RD`1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I
M;FYI;F<@;V8@;6]N=&@_`$1E;&5T960`1&5L971E9"!M97-S86=E<P!$96QE
M=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E<V-E;F1I;F<`1&5T86EL<P!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!$:6T@<VEG;F%T=7)E<S\`1&ES<&QA>0!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_`$1I
M<W!L87D@:6X@0F]D>2!O9B!-97-S86=E`$1I<W!L87D@<&]P+75P(&YO=&EF
M:6-A=&EO;B!O9B!N97<@;6%I;#\`1&ES<&]S:71I;VX`1&\@3F]T($-H96-K
M($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`1&]W;FQO860@1F]L9&5R*',I`$1R
M869T`$1R869T<R!F;VQD97(Z`$4M;6%I;"!!9&1R97-S`$5D:70@>6]U<B!F
M:6QT97(@<G5L97,`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"X`16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RX`
M16UP='D@1F]L9&5R*',I`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T>2!R97-U
M;'0N`$5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\`16YA8FQE(%,O34E-12!F
M=6YC=&EO;F%L:71Y/P!%;F0@9F]R=V%R9&5D(&UE<W-A9V4`16YD(&UE<W-A
M9V4`16YD(&UE<W-A9V4@9G)O;2`E<P!%;G1E<B!087-S<&AR87-E`$5N=')Y
M("(E<R(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B
M;V]K`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%
M=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V
M97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AP86YD($%L;`!%>'!A;F0@
M06QL($9O;&1E<G,`17AP86YD($9O;&1E<@!%>'!A;F0@3F%M97,`17AP86YD
M(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN
M('1H92!B86-K9W)O=6YD/P!%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E
M92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_`$9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%X
M`$9E=&-H($UA:6P`1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\`
M1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE
M($UA;F%G97(`1FEL92!.86UE`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D
M+@!&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_`$9I;'1E
M<G,`1FEN9`!&:7)S="!086=E`$9O;&1E<B!.879I9V%T;W(`1F]R=6US`$9O
M<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R9&5D(&UE
M<W-A9V4@9G)O;2`E<P!&<F]M`$9R;VT@061D<F5S<P!&=6QL($YA;64`1G=D
M.@!&=V0Z(`!&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E<P!'<F]U<"!!9&UI
M;FES=')A=&EO;@!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AE861E<G,`2&5L<`!(:61E($1E;&5T
M960`2&ED92!5;G-U8G-C<FEB960`2&EG:`!(:6=H(%!R:6]R:71Y`$AI9VAE
M<W0`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!(;W<@9&\@
M>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\`24U!4`!)34%0(&UA
M:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I
M;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I
M;&5D.B`E<P!)34%0(&]V97(@4U-,`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG
M;F5D*0!)34%0+"!N;R!43%,`24Y"3U@`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E
M>'0`26=N;W)E`$EG;F]R92!!;&P`26UP;W)T(%!'4"!+97D`26UP;W)T(%!E
M<G-O;F%L(%!R:79A=&4@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4'5B;&EC
M(%!'4"!+97D`26UP;W)T(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!3+TU)344@
M2V5Y`$EM<&]R="!M8F]X($9I;&4`26UP;W)T86YT`$EM<&]R=&%N="!M97-S
M86=E<P!);7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+@!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F-L=61E(&$@8G)I968@<W5M
M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_`$EN8VQU9&4@;W)I9VEN
M86P@;65S<V%G92!I;B!A(')E<&QY/P!);F9O<FUA=&EO;B!O;B`E<R!0=6)L
M:6,@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y`$EN
M9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97D`26YL:6YE`$EN=F%L
M:60@4F5M;W1E($UA:6QB;W@`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV
M86QI9"!K97D`26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN`$EN
M=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN`$ET86QI8P!*=7-T:69Y
M($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@3&5N9W1H`$ME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2V5Y('-U
M8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!,86YG
M=6%G90!,87-T(%!A9V4`3&ES="!(96QP(%1O<&EC<P!,:7-T(&%L;"!C;VYT
M86-T<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I
M<V%B;&5D+"!Y;W4@=VEL;"!O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S
M96%R8V@@9F]R(&5X<&QI8VET;'DI`$QI<W1I;F<@:6X@=&AE($AE861E<@!,
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V-A;"!-86EL8F]X.@!,;V<@
M:6X@=&\@)7,`3&]G(&]U=`!,;V=I;B!487-K<P!,;W<`3&]W(%!R:6]R:71Y
M`$QO=V5S=`!-30!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N`$UA:6P`36%I;&)O>`!-87)K(&%S.@!-87)K(&1I9F9E<F5N="!L979E
M;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA=&-H:6YG
M(&9I96QD<P!-96UB97)S`$UE;G4@;6]D93H`365S<V%G90!-97-S86=E($-O
M;7!O<VET:6]N`$UE<W-A9V4@1&%T90!-97-S86=E(%-E87)C:`!-97-S86=E
M(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!6:65W:6YG`$UE<W-A9V4@
M9FQA9W,`365S<V%G92!F;VQD97)S`$UE<W-A9V4@9G)O;2`E<P!-97-S86=E
M('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S`$UE<W-A
M9V4@<V5N="!S=6-C97-S9G5L;'DN`$UE<W-A9V5S('!E<B!P86=E(&EN('1H
M92!M86EL8F]X('9I97<N`$UE<W-A9V5S('1O`$UE=&AO9`!-:6UE(%1Y<&4`
M36]D:69I960@1&%T90!-;VYT:&QY`$UO=F4`37D@06-C;W5N=`!.86UE`$YA
M;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='D`3F5T=V]R:P!.979E
M<@!.97<`3F5W($9O;&1E<@!.97<@36%I;`!.97<@57-E<FYA;64@*&]P=&EO
M;F%L*0!.97<@;65S<V%G97,`3F5X="!-97-S86=E`$YE>'0@4&%G90!.;P!.
M;R!%;F-R>7!T:6]N`$YO($ME>7,@:6X@2V5Y<FEN9P!.;R!01U`@<'5B;&EC
M(&ME>2!I;7!O<G1E9"X`3F\@871T86-H;65N=',@9F]U;F0N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"U&:6QE(%9&4RX`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9`!.
M;R!M97-S86=E(&)O9'D@=&5X=`!.;R!M97-S86=E<R!M871C:&5D('EO=7(@
M<V5A<F-H+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP
M;W)T960N`$YO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.
M;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S=&EO;G,`3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO;F4`3F]R;6%L`$YO="!$96QE
M=&5D`$YO="!$<F%F=`!.;W0@26UP;W)T86YT`$YO="!097)S;VYA;`!.;W0@
M82!V86QI9"!P=6)L:6,@:V5Y+@!.;W0@9&5L971E9"!M97-S86=E<P!.;W0@
M:6UP;W)T86YT(&UE<W-A9V5S`$YO=&5S`$YU;6)E<B!O9B!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+@!/;&0@
M;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"X`
M3W!T:6]N<P!/<F1E<F5D($QI<W0`3W1H97(@26YF;W)M871I;VX`3W1H97(@
M3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N<P!01U``4$=0($5R<F]R.B!.965D
M('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!01U`@3W!T
M:6]N<P!01U`@4&%S<W!H<F%S92!);G!U=`!01U`@4&5R<V]N86P@2V5Y<&%I
M<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!0
M1U`@4'5B;&EC($ME>2!F;W(@(B5S("@E<RDB('=A<R!S=6-C97-S9G5L;'D@
M861D960N`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,B('=A<R!S=6-C97-S9G5L
M;'D@9&5L971E9"X`4$=0(%!U8FQI8R!+97ER:6YG`%!'4"!3:6=N($UE<W-A
M9V4`4$=0(%-I9VXO16YC<GEP="!-97-S86=E`%!'4"!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R
M<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA
M8FQE('1O(&)E('9E<FEF:65D+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C
M<GEP=&5D+@!02%`@4VAE;&P`4$]0,P!03U`S(&]V97(@4U-,("AS96QF+7-I
M9VYE9"D`4$]0,RP@;F\@5$Q3`%!A9V4@)60@;V8@)60`4&%R="AS*0!087-S
M<&AR87-E`%!A<W-P:')A<V4@*$%G86EN*0!087-S<&AR87-E('-U8V-E<W-F
M=6QL>2!U;FQO861E9"X`4&%S<W!H<F%S93H`4&%S<W!H<F%S97,@8V%N(&YO
M="!B92!E;7!T>0!087-S<&AR87-E<R!D;R!N;W0@;6%T8V@`4&%S<W=O<F0`
M4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A
M<W1E`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N
M86P`4&5R<V]N86P@26YF;W)M871I;VX`4&5R<V]N86P@4$=0(&ME>7!A:7(@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4&5R<V]N86P@4$=0(&ME>7,@9&5L
M971E9"!S=6-C97-S9G5L;'DN`%!E<G-O;F%L(%,O34E-12!K97ES(&1E;&5T
M960@<W5C8V5S<V9U;&QY+@!0:&]N90!0;&%C92!Y;W5R('-I9VYA='5R92!B
M969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_`%!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F
M;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T
M;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BX`
M4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P
M<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N=&5R('1H:7,@
M<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A<V4@<F5S;VQV
M92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N`%!R969E<F5N8V5S
M('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!0<F5V:6]U<R!-97-S86=E`%!R979I
M;W5S(%!A9V4`4')I;G0`4')I;W)I='D`4')O=&]C;VPZ`%!U8FQI8R!01U`@
M:V5Y<V5R=F5R('-U<'!O<G0@:&%S(&)E96X@9&ES86)L960N`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U
M<F=E($1E;&5T960`4'5R9V4@5')A<V@@:&]W(&]F=&5N.@!0=7)G92!M97-S
M86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O
M9B!D87ES+@!1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2D`475O=&$@<W1A='5S.B!.3R!,24U)5`!2871I;P!296%D`%)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M9&ER96-T`%)E9&ER96-T('1H:7,@;65S<V%G90!2961I<F5C=&EN9R!F86EL
M960N`%)E9G)E<V@`4F5F<F5S:"!&;VQD97(@5FEE=W,Z`%)E;&]A9"!6:65W
M`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E($UA:6QB;W@Z`%)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`
M4F5M;W9E('5S97(Z("5S`%)E;F%M92!&;VQD97(H<RD`4F5N86UE('-E;G0M
M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/P!296YA;6EN9R`B
M)7,B('1O("(E<R(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%)E<&QA8V4@=VET:#H`4F5P;'D`4F5P;'D@=&\@06QL`%)E<&QY('1O
M($%L;#H`4F5P;'D@=&\@3&ES=`!297!L>2!T;R!,:7-T.@!297!L>2U4;P!2
M97!L>2U4;SH@`%)E<&QY.@!297!O<G0@87,@4W!A;0!297-U;64`4F5T=7)N
M('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN
M9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%,O34E-10!3+TU)344@3W!T:6]N
M<P!3+TU)344@4&%S<W!H<F%S92!);G!U=`!3+TU)344@4&5R<V]N86P@2V5Y
M<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+@!3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@
M861D960N`%,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES
M=&5M+@!344P@4VAE;&P`4U-(`%-A=F4@87,`4V%V:6YG('1H92!D<F%F="!F
M86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%-E87)C
M:`!396%R8V@@4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@82!G<F]U<"!T
M;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE
M8W0@82!U<V5R('1O(&%D9`!396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@
M9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N`%-E;&5C
M="!A;&P`4V5L96-T(&%N(&%C8V]U;G0`4V5L96-T(&YO;F4`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396QE8W1E9"!!9&1R97-S(&)O;VMS.@!396YD
M($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R`%-E;G0@;6%I;"!F;VQD97(Z`%-E
M<G9E<@!397)V97(Z`%-E="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS
M('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S86=E<RX`4V5T('1H92!8
M+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN9R!M97-S86=E<S\`4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-H;W5L
M9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@
M9F]R(%!'4"!D871A/P!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L
M;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=6QD('EO=7(@4$=0('!U
M8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D
M969A=6QT/P!3:&]W`%-H;W<@06QL($AE861E<G,`4VAO=R!$96QE=&5D`%-H
M;W<@3&EM:71E9"!(96%D97)S`%-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T
M:6]N`%-H;W<@56YS=6)S8W)I8F5D`%-H;W<@;&5G96YD(&EN('1H92!M86EL
M8F]X('9I97<_`%-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N
M=6)A<C\`4VEZ90!3;W)T(&)Y($%R<FEV86P`4V]R="!B>2!$871E`%-O<G0@
M8GD@1G)O;2!!9&1R97-S`%-O<G0@8GD@365S<V%G92!3:7IE`%-O<G0@8GD@
M4W5B:F5C=`!3;W)T(&)Y(%1H<F5A9`!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3<&5C:6%L($-H87)A8W1E<G,`4W!E;&P@0VAE8VL`4W!E;&P@0VAE8VME
M<@!3<&5L;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C
M<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+@!3=&%T=7,`4W5B:F5C=`!3=6)J
M96-T($9I96QD`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5C8V5S<P!3=6=G
M97-T:6]N<P!487-K<P!497)M<R!O9B!397)V:6-E(&9I;&4@;F]T('-P96-I
M9FEE9"!I;B!C;VYF+G!H<`!497AT`%1E>'0@3VYL>0!4:&4@86-C;W5N="`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!A8V-O=6YT("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@
M<F5N86UE9"!T;R`B)7,B+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+@!4:&4@9F]L9&5R("(E<R(@86QR96%D>2!E>&ES=',`
M5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL;&5G86P@8VAA<F%C=&5R<R!I
M;B!I=',@;F%M92X@270@;6%Y(&-A=7-E('!R;V)L96US+B!0;&5A<V4@<V5E
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!F;VQD97(@(B5S(B!W
M87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@:70N
M`%1H92!F;VQD97(@(B5S(B!W87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T
M('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S(&YO
M="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H92!F
M;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N`%1H92!F;VQD
M97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%1H92!F;VQD97(@
M(B5S(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@(B5S(BX`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M86EL8F]X("5S(&ES(&%L<F5A
M9'D@96UP='DN`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+@!4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R97%U97-T960@9FEL92!D
M;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!4:&4@
M<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A
M8VAM96YT+@!4:&5R92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO(&UE<W-A9V5S
M(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N
M(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R
M86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA
M<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@
M;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<P!4:&5R92!W87,@82!P<F]B
M;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`
M5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F
M;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+@!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O;2`B)7,B('1O("(E<R(N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R('-A
M=FEN9R!T:&ES(&UE<W-A9V4@87,@82!D<F%F="X`5&AE<F4@=V%S(&%N(&5R
M<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<P!4:&ES(%!'4"!0=6)L:6,@
M2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92X`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@;65S<V%G92!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C
M;W)D:6YG('1O(%)&0R`R,#$U*2X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I
M9VET86QL>2!S:6=N960@=FEA(%!'4"X`5&AI<R!M97-S86=E(&AA<R!B965N
M(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&AA
M<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"X`5&AI<R!M97-S86=E('1O`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+@!4:')E860@5FEE=P!4:6UE(%1R86-K:6YG
M`%1I=&QE`%1O`%1R87-H(&9O;&1E<CH`55),`%5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92X`56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$`56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0`56YA;G-W97)E9`!5;F%N<W=E<F5D(&UE<W-A
M9V5S`%5N9&5L971E`%5N9&5R;&EN90!5;F1I<V-L;W-E9"!296-I<&EE;G1S
M`%5N;&]A9"!087-S<&AR87-E`%5N;F%M960`56YS965N`%5N<W5B<V-R:6)E
M(&9R;VT@1F]L9&5R*',I`%5P9&%T90!5<&1A=&4@)7,`57!L;V%D`%5S92!$
M969A=6QT(%9A;'5E`%5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/P!5
M<V5R($%D;6EN:7-T<F%T:6]N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M
M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%9A8V%T:6]N`%9E<FEF:6-A=&EO
M;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E
M9"!W:71H+@!6:65W`%9I97<@)7,`5FEE=R`E<R!0=6)L:6,@2V5Y`%9I97<@
M4&5R<V]N86P@4')I=F%T92!+97D`5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y
M`%9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.@!7965K
M;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&5N(&1E;&5T:6YG
M(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS
M=&5A9"!O9B!M87)K:6YG('1H96T@87,@9&5L971E9#\`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`65D`665A<FQY`%EE<P!9;W4@9&ED(&YO="!E;G1E<B!A
M('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!M=7-T(&5N=&5R('1H92!P87-S
M<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@
M;65S<V%G90!9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U
M<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4`66]U
M(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!W97)E(&YO="!S=6)S8W)I8F5D
M('1O("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E
M<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB
M960@=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D
M(&9R;VT@(B5S(@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@3F%M90!9;W5R(%!'
M4"!0=6)L:6,O4')I=F%T92!+97ES`%EO=7(@4')I=F%T92!+97D`66]U<B!0
M=6)L:6,@2V5Y`%EO=7(@86-C;W5N=',Z`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R(')E
M;6]T92!S97)V97)S.@!9;W5R('-I9VYA='5R93H`6TYO(%-U8FIE8W1=`%ML
M:6YE("5S(&]F("5S70!F:6QE`&9R;VT`;F]N90!O<@!S<&5L;&EN9R!E<G)O
M<@!S<&5L;&EN9R!E<G)O<G,`=6YN86UE9`!V0V%R9`!0<F]J96-T+4ED+59E
M<G-I;VXZ($EM<"`T+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTQ,2TQ-"`P,#HS
M."TP-#`P"DQA<W0M5')A;G-L871O<CH@36ER;W-L878@4&5N9&5V(#QM:7)O
M0&-Y8F5R<VAA9&4N=7,^"DQA;F=U86=E+51E86TZ($)'(&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=`H`("`@("`@Q.XZ(``@("`@Q.#RX#H@`"`@("`@(,[R.B``
M("@E<R#D[>@@[>#GX.0I`"`HY.WE\2D`("CB]^7PX"D`("`@(-+E[.`Z(``@
MXB``(P`E9"#D[B`E9"#N\B`E9"#OZ/'LX``E<R`M(,?@X>7KY>;JX``E<R!+
M0@`E<R#.X?'K\^;BX/GH(.[OY?#@]NCH("T@S^[RXOKPYN3E[>CE`"5S(-/Q
MZ^[BZ/\@[^X@T>_N\.#G\^SE[>CE\NX`)7,@XN7WY2#Q^OGE\?+B\^+@+B#"
MX/C@\N`@[^#OZN`@)7,@[>4@X>7XY2#O\.7H[.7M\^+@[>`N`"5S(.WE(.4@
MXN#KZ.3MX"#O[OGE[?'JX"#J\_+H_RX`S^#OZN`@)7,@X>7XY2#O\.7H[.7M
M\^+@[>`@XB#MX/?@Z^[R[B#MX"#LY?'E]N`N`"5S(.WE[N'U[N3H[``E<SH@
M)7,`)7,Z("5S("@E9"9N8G-P.^[R)FYB<W`[)60I`"C/\.CK[N;H(/+EY^@@
M[_#N[.7MZ"#H(._P[N3ZZ^;H(.KZ["#QZ^7DXN#YZ/\@Y>KPX.TN*0#.\NK@
MYN@@XO'H]^KH(._P[NSE[>@@Z"#QY2#B^O#MZ"#J^NP@Y>KPX.W@("+-X._H
M^.@B`"C"^O#MZ"#QY2#J^NP@Y>KPX.W@("+-X._H^.@B(/'KY>0@ZN#R[B#O
M\.CK[N;H^"#B\>CWZN@@[_#N[.7MZ"#D[B#R\^HNS_#N[.7MZ/+E(.(@\N7J
M\_GH_R#EZO#@[2#-W\S`(.3@(.'ZY.#R(._PZ.ONYN7MZ"XI`"H@Q.[AX.+H
M(/+EY^@@\2`BSLHB("H`*B#,[NO_(.CGX>7PY?+E(.#D\.7Q*.@I("H`,C0@
M]^#QX`#'X"#DX"#J\.CO\NCPX/+E(._H\>SN(.4@[>7NX?7NY.CL(._SX>OH
M]^7M(%!'4"#JZ_[W+@#'X"#DX"#O\.[BY?#H\N4@[^[D[^CQX.WN(._H\>SN
M(.4@[>7NX?7NY.CL(%!'4"#JZ_[W+@#'X"#DX"#DY>KPZ._RZ/#@\N4@[^CQ
M[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@ZNO^]RP@Z^CWY>T@ZNO^]R#H
M(.KK_O?NXN`@]/#@Y^`N`,?@(.3@(._NY._H^.7RY2#OZ/'L[B#QX"#MY>[A
M]>[DZ.SH.B#O\^'KZ/?E[2#JZ_[W+"#KZ/?E[2#JZ_[W(.@@ZNO^]^[BX"#T
M\.#GX"X`Q^`@Y.`@ZO#H[_+H\.#RY2#OZ/'L[B#E(.WE[N'U[N3H["#O\^'K
MZ/?E[2!334E-12#JZ_[W+@!!32]030#H`,CLY2#MX"#O[OG@\N`Z`,3NX>#B
M_^WE(.W@(.WNXN`@X_#S[^``Q.[AX.+_[>4@[>`@[>[BZ"#O\.#BX`#$[N'@
MXN@@[>[B(._N\O#EX>CRY>LZ`,3NX>#B_^WE\NX@[>`@[^[R\.7AZ/+EZ^@@
MY2#GX.'PX.WE[>XN`,#D\.7Q`,#D\.7QY>T@X>7KY>;MZ.H`P.3PY?'MZ"#J
M[>CCZ`#`Y.SH[>CQ\O#H\.#MY0#$[N'@XNKH`,_QY>+D[NWH[`#"\>CWZN@`
MPO'H]^KH(./P\^_H`,+QZ/?JZ"#O\.#BX`#"\>CWZN@@[^CQ[.`@XOKB(,+@
M^.#RX"`B)7,B(._@[^K@(._N+?'RX/#H(.[R("5S(.3MZ"#YY2#A^N3@\B#H
MY_+PZ/+H(0#"\>CWZN@@[^#OZN@@(LCG[_#@\N7MZ"#OZ/'LX"(@[^XM\?+@
M\.@@[O(@)7,@[.7QY?;@(/GE(.'ZY.#R(.CG\O#H\N@A`,#K\N7P[>#RZ.+M
MZ"#WX/'RZ"#GX"#RX.?H(/'EZO;H_SH`POKBY>3E[>#RX"#Q\N[I[>[Q\B#M
MY2#E(.3N[_/Q\NCLX"X`T2#N\N/NXN[P`,_H\>S@(/$@[O+C[N+N\`#$X"#Q
MY2#O\.CKX./@\B#KZ"#TZ.OR\.CRY2#QZ^7D(.+U[N0_`-#@Y^SE\"#MX"#@
M\/7HXNWH_R#TX.GK`,CLY2#MX"#@\/7HXN``T>CC\_#MZ"#KZ"#Q\N4L(/?E
M(.CQZN#RY2#DX"#HY_+PZ.7RY2#R[N?H(._SX>OH]^7M(.KK_O<_`-'HX_/P
M[>@@Z^@@\?+E+"#WY2#H\>K@\N4@Y.`@Z.?R\.CE\N4@\N7GZ"#OZ/'LX"`H
M[>7B^N?B\.#RZ.SN*3\`T>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQZN#RY2#DX"#H
MY^_PX.?MZ/+E(.KN^/?E\NX_`,+PY>SE(.W@(._PZ/'RZ./@[>4`S>#PX/'R
MXN#YZ`#$X"#QY2#H\>K@(.OH(._N\N+Z\.;DY>WHY2#O\.7DZ"#NX?'K\^;B
MX/GH\N4@[N_E\.#VZ.@_`,3@(/'E(.3NX>#B_R#KZ"#"X/CH__(@[_/AZ^CW
MY>T@4$=0(.KK_O<@ZOKL(._H\>SN\NX@PN@_`,_PZ.KPY>_E[2#TX.GK.@#/
M\.CJ\.7OY>T@].#IZP#/\.CJ\.7OY>WH(/3@Z>ONXN4`P_#E^.K@(._PZ"#H
MY_+PZ.+@[>4@[>`@[>7Q^OGE\?+B\^+@^>`@X_#S[^`N`,/PY?CJX"#O\.@@
MZ.?R\.CBX.WE(.WE(.WE\?KYY?'RXO/BX/GH(._PX.+@+@##\.7XZN`@[_#H
M(/#EY.#J\NCPX.WE(.W@(.WE\?KYY?'RXO/BX/GH(._PX.+@+@#`\O#HX?/R
MZ`##\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\`R.3E[?+H].CJX/;H__+@(.'E
M^.4@[O+UXOKPZ^7MX"#N\B!2041)55,@\?KPXOKPX"X`S>#KZ/?MZ"#@Y/#E
M\>WH(.KMZ./H.@#-X.OH]^WH(._NZ^7RX#H`SN'PX/+M[B#B("5S`,WEXN#K
MZ.3MX"!K97)B97)O<R`@[^#P[NO@+@#-Y>+@Z^CD[>X@:V5R8F5R;W,@[^[R
M\.7AZ/+EZ_'J[B#H[.4N`$)C8P#0[N;DY>T@Y.7M`-?E\.7M(/'OZ/'ZZ@#2
M_^ON`-/DY>'EZ^7MZ`#.\NSE\NKH`,3BX/+@`-+_Z^[R[B#MX"#OZ/'L[O+N
M(.@@:&5A9&5R<R``0TU3`$-20P##\.7XZN`@[_#H(/'B^O#GXN#MY2#Q(.SE
MZ>L@\?KPXOKP.B`E<P!#8P#,[N'HZ^7M(/+EZ^7T[NT`S_#N[.7MZ`#/\.[L
MY>WH(.+QZ/?JZ`#/\.[LY>WE\N4@Z.SE\NXL(.#D\.7QX"#H(._NY._H\>`L
M(.KNZ/+N(._NZ_/WX/+EZ^CRY2#YY2#BZ.;DX/(L(.KNX^#R[B#WY?+@\B#H
M(.[RX^[BX/#_\B#MX"#OZ/'L[O+N(,+H+@#/\.[BY?#H(._@[^K@\N`HZ/+E
M*2#GX"#M[N+H(._H\>S@`,CGX>7PZ"#DY>GQ\N+HY3H`R.?AY?#E\N4@[.7I
MZR#Q^O#B^O`Z`,CGX>7PY?+E(.KN_R#@Y/#E\>W@(.KMZ./@(.3@(/'E(.CG
M[^[KY^+@(._PZ"#D[N'@XO_MY2#MX"#@Y/#E\2X`R.?AY?#E\N4@\.7DX"#M
MX"#R^O#QY>WE(.W@(.#D\.7Q[>CRY2#J[>CCZ"P@[_#H(.[RZO#HXN#MY?+N
M(.W@(.#D\.7QZ"X`RNOHZNWE\N4@[>`@Y>3MX"#N\B#HY^'PX.WH\N4@X.3P
MY?'MZ"#J[>CCZ"#H(/'KY>0@\N[BX"#HY^'E\.7RY2#B\>CWZN@@[^[KY?+@
M(.?@(/+Z\/'E[>4N`,KKZ.KMY?+E+"#GX"#DX"#GX._H^.7RY2#"X/CH__(@
M[_/AZ^CWY>T@4$=0(.KK_O<@XB#@Y/#E\>W@\N`@\>@@ZNWHX^`N`,?@\N+N
M\.@@[_#NY^[PY?;@`,?@\N+N\.7MX"#OX._JX`#1^N'E\.@@XO'H]^KH`-'Z
MX>7PZ"#B\>CWZN@@[^#OZN@`T?KAY?#H(._@[^K@`,CGX>CPX.WE(.W@(/;B
M__(`RN[LZ.KQZ`#J[NSE[?+@\`#*[NSOX.WH_P#-X._H^.@@Y/#SX^X@[^CQ
M[.X`Q.`@\>4@[^CXX/(@Z^@@[^CQ[.#RX"#B(.[RY.7KY>T@[_#NY^[PY?8_
M`,_N\N+Z\.3E\N4@[^#P[NO@\N``Q.[Q\OKOX"#D[B#O\^'KZ/?MZ/\@\?KP
MXOKP(.'E^.4@[O+JX.?@[2X`P_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(/'Z
M\.+Z\"X`RN[M\O#NZR#MX"!01U`@[^[DY/#ZYNK@\N`@Y^`@)7,N`,KN[?+P
M[NL@[>`@4R]-24U%(._NY.3P^N;JX/+@(.?@("5S+@#*[NWR\.[KZ/#@(.KN
MX^`@Y.`@\>4@[_#NXN7P_^+@(.?@(.WNXN`@[^[YX"#H(.3@Z^@@Y.`@X?KD
MY?+E(//BY>3N[.7MZ"P@ZN[CX/+N(/+_(/'E(._NZ_/WZ"X`RN[OZ/#@Z0#*
M[O#HX^CPX.D`RN[PZ./H\.#M(/+EZO'R`,/PY?CJX"#O\.@@4$=0(.KPZ._R
MZ/#@[>7R[B#MX"#OZ/'L[BX`P_#E^.K@(._PZ"!01U`@[^[D[^CQXN#MY?+N
M(.W@(._H\>SN+@##\.7XZN`@[_#H(.3EZO#H[_+H\.#MY?+N(.W@(%!'4"#D
MX.WMZ"X`P_#E^.K@(._PZ"#HY_+PZ.+@[>7R[B#MX"#OZ/'LX"#N\B`E<RX@
MT?KPXOKPX"#JX.?@.B`E<P#-Y>KN\.7J\N7M(&5M86EL(.#D\.7Q(.W@(._N
MZ_/WX/+EZ_\N`,/PY?CJX"#O\.@@Z.?O^NOMY>WHY2#MX"`BSN_E\.#VZ.@@
M[^X@[N'QZ_/FXN#MY?+N(@##\.7XZN`@[_#H(.CGXNOH]^#MY?+N(.W@(._P
MZ.K@]^7MZ/\@].#IZR#N\B!-4RU43D5&+@##\.7XZN`@[_#H(.CGXNOH]^#M
MY?+N(.W@(/3@Z>L@[O(@6FEP(.#P]>CBX"X`P_#E^.K@(._PZ"#O[NOS]^#B
MX.WE\NX@[>`@[_/AZ^CW[>C_(.KK_O<@[O(@ZNO^]RWQ^O#B^O#@+@#-Y>+Z
MY^SNYNWN\?(@Y.`@\>4@[O+B[O#H(,[A\>OSYN+@^>A?Y^#DX/?H(.SNY//K
M("5S(`#1^N?DX.D@[^#OZN``T?KGY.#I(.WNXN`@[^#OZN`@(M?E\.WNXN@B
M`-'ZY^3@Z2#M[N+@(._@[^K@("+(Y^_PX/+E[>@B`-'ZY^3@Z2#M[N+@(._@
M[^K@("+*[OCWY2(`T?KGY.#I(._PX.+HZ^`@Y^`@].CK\O#H\.#MY2#H(.[P
MX^#MZ.?@]NC_(.W@(.CDXN#YX/+@(._N^>`L(/'N\/+H\.#MY?+N(.D@XB#O
MX._JZ/+E(.@@Z.?R\.CBX.WE(.W@(/'OX.P`SN_PY>3EZ^@@Y^#DX/?H\N4@
MY^`@Z.?O^NOMY>WHY2#QZ^7D(.+U[N0@XB`E<RX`Z.?PY>;H`,3$`,7FY>3M
MY>+M[@#$X/+@`,CDY>WRZ/?M[O'R(._N(._NY/#@Y^'H\.#MY0#*\.CRY?#H
MZ"#GX"#Q[O#RZ/#@[>4@[^X@[^[D\.#GX>CPX.WE.@#/[O'NZN`@[>`@\>[P
M\NCPX.WE(._N(._NY/#@Y^'H\.#MY3H`R.?R\.CI`,CG\O#HZ2`E<R#O\^'K
MZ/?E[2#JZ_[W`,CG\O#HZ2#OX._JX"CH*0#$X"#QY2#HY_+PZ.+@\B#KZ"#Q
M\N#PZ/+E(._@[^KH("+(Y^_PX/+E[>`@[^[YX"(@XB#MX/?@Z^[R[B#MX"#L
MY?'E]N`_`,CG\O#H\N@`R.?R\.CRZ"#OZ/'LX`#(Y_+PZ.+@[>4@Z"#O\.7L
MY?'RXN#MY2#MX"#OZ/'LX`#-X.S@Z__BX/GH`,3E\N#IZ^@`Q.7RX.GKZ/+E
M(.'_]>`@\.7CZ/'R\.CPX.WH(.?@(.#D[.CMZ/'R\.#R[O#@+@#$X"#QY2#G
MX.SZX^O_XN#R(.OH(._NY._H\>CRY3\`S^[JX.;H`,3H\>_KY>D@SN_VZ.@`
MQ.`@\>4@[^[JX.?BX"#KZ"#O[O+B^O#FY.7MZ.4@\>OEY"#HY^_PX/G@[>4@
M[>`@[^CQ[.X_`,_NZN#FZ"#B(/'ZY/KPYN#MZ.7R[B#MX"#OZ/'L[O+N`,3@
M(/'E(._NZN#GXN`@Z^@@<&]P+75P(//BY>3N[/_BX.WE(.?@(.WNXN`@[^[Y
MX#\`T.#G[^[K[N;E[>CE`,WE(._P[N+E\/_BX.D@[^#OZN`HZ"D@Y^`@[>[B
MX"#O[OG@`,CG\N7CZ^@@[^#OZN`HZ"D`U^7P[>[BX`#/X._JX"`BU^7P[>[B
MZ"(Z`$4M36%I;"#@Y/#E\0#0Y>3@ZO;H_R#MX"#O\.#BZ.O@\N`@Y^`@].CK
M\O#H\.#MY0#/Z/'L[@#%;6%I;"#@Y/#E\0!%;6%I;"#@Y/#E\>CRY2#R\/_A
MXN`@Y.`@\?KB[^#DX/(N`,?@Z^CWY>WH(.'_]>`@XO'H]^KH(._H\>S@(.[R
M("5S+@#(Y^_PX.?MZ"#OX._JX"CH*0#(Y^_PX.?MZ"#J[OCWY?+N`,_PX.?E
M[2#PY>?SZ_+@\BX`Q.`@\>4@\.#G\.7XZ"#KZ"!01U`@]//MZO;H[NW@Z^WN
M\?+RX#\`Q.`@\>4@\.#G\.7XZ"#KZ"!3+TU)344@]//MZO;H[NW@Z^WN\?+R
MX#\`RO#@Z2#MX"#O\.7O\.#RY>WN\NX@[^CQ[.X`RO#@Z2#MX"#OZ/'L[O+N
M`,KPX.D@[>`@[^CQ[.[R[B#N\B`E<P#"^N+EY.7RY2#JZ_[W[N+@(/3PX.?@
M`,?@[^CQX"`B)7,B(.'E^.4@\_'OY?CM[B#D[N'@XN7M(.KZ["#@Y/#E\>W@
M\N`@ZNWHX^``P_#E^.K@`,+QY>KH(#$U(.SH[?/RZ`#"\>7JZ"`S,"#QY>KS
M[>3H`,+QY>KH(#4@[.CM\_+H`,+Q_^KN(.ONX^+@[>4`S>`@XO'EZN@@[^[K
M[N+H[2#WX/$`PO'_ZN`@[.CM\_+@`,_PZ.SE\.WH(/'R[NGM[O'RZ#H`T.#G
M\N+N\.@@XO'H]^KH`-#@Y_+B[O#H(.+QZ/?JZ"#OX._JZ`#0X.?RXN[PZ"#O
MX._JX`#$[N_H^.@@Z.SE[>#RX`#$X"#QY2#D[N_H\>+@\B#KZ"#@XO+N[.#R
MZ/?M[B#H[.7MX/+@(._PZ"#OZ/'@[>4@[>`@[>[B[B#OZ/'L[C\`Q.`@\>4@
M[O+BX/#_(.OH(/;_Z^[R[B#D^O#B[B#B(.CGX^OEY"`BS^#OZN@B(._N(._N
MY/#@Y^'H\.#MY3\`S>7B^N?L[N;M[O'R(.3@(/'E(.?@\.7D__(@[_#E].7P
MY>WVZ.CRY2X`S>7B^N?L[N;M[O'R(.3@(/'E(.[Q^OGE\?+BZ"#B\/KGZN`@
M\2!,1$%0(/'Z\.+Z\"X`P_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(%--0B#Q
M^O#B^O`N`-3@ZO$`Q/#SX^`@[^[YX`#$X"#QY2#HY_+EX^O_(.OH(._N^>#R
MX"#B(.[RY.7KY>T@[_#NY^[PY?8_`,'P[ND@].#IZ^[BY3H@)7,@].#IZP#!
M\.[I(/3@Z>ONXN4Z("5S(/3@Z>O@`-3@Z>L@[.7MX.;E\`#([.4@[>`@].#I
MZP#(Y^_PX/G@[>7R[B#MX"#TX.GK[N+E(.WE(/'E(._NY.3Z\.;@+@#$X"#Q
MY2#TZ.OR\.CPX"#KZ"#Q^N3Z\.;@[>CE\NX@[>`@[^CQ[.#RX"#GX"#P\^/@
M\NWH/P#4Z.OR^O``TOKP\>@`S_KPXN`@\?+PX.WH]N``S>#BZ./@\N[P(.W@
M(._@[^KH\N4`U.[P\^SH`,_PY>_PX/+H`,_PY>_PX/+H.@#/\.7O\.#RY>WN
M(._H\>SN`,_PY>_PX/+E[>X@[^CQ[.X@[O(@)7,`SO(`SO(@X.3PY?$`R.SE
M(.W@(/3@Z>L`1G=D.@!&=V0Z(`!&=V0Z("5U(,_PY>_PX/+E[>X@[^CQ[.X`
MP.3LZ.WH\?+PZ/#@[>4@[>`@X_#S[^@`P_#S[^@`S_#@XN`@Y^`@X^[Q\N@`
M2%144"#HY.7M\NCTZ.K@]NC_(.WE(.4@[>#LY?#E[>`N`,?@X^O@XNWH(/?@
M\?+H`,_N[.[Y`-'J\.CI(.CG\O#H\NCRY0#1ZO#HZ2#MY>#A[NWH\.#MZ/+E
M`,'Z\.?N`,'Z\.?@(._N^>``Q>KQ[_#E\>WN`,W@]^#K[@#$[NS@^.7M(.#D
M\.7Q`,3N[.#XY>T@\N7KY?3N[0!(;W)D90#*X.H@Z/'JX/+E(.3@(/'E(._N
MZN#GXN#R(._PZ.KPY>_E[>CRY2#TX.GK[N+E/P!)34%0`,/PY?CJX"#O\.@@
M\?KGY.#BX.WE(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S`,/PY?CJX"#O
M\.@@Z.?R\.CBX.WE(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S`,/PY?CJ
MX"#O[O#@Y.@@ZN+N\N`@[_#H(/'ZY^3@XN#MY2#MX"!)34%0(._N^>7M\>K@
M(.KS\NC_.B`E<P!)34%0(.+Z\/7S(%-33`!)34%0(.+Z\/7S(%-33"`H\>#L
M[N_NY._H\>#M*0!)34%0+"#AY><@5$Q3`$E.0D]8`$E0(.#D\.7QX"#MY2#E
M(.(@[^[GXN[KY>WH_R!#2412(.'K[NHN`-'@[.X@Z.KN[>@`R.KN[>@@\2#R
MY>KQ\@#(X^WN\.CPX.D`R./M[O#H\.#I(.+QZ/?JZ`#([._N\/(@[>`@4$=0
M(.KK_O<`R.SO[O#R(.W@(.OH]^7M(/?@\?+E[2!01U`@ZNO^]P#([._N\/(@
M[>`@[^7P\>[MX.OE[2#O\^'KZ/?E[2!01U`@ZNO^]P#([._N\/(@[>`@[_/A
MZ^CWY>T@4$=0(.KK_O<`R.SO[O#R(.W@(%,O34E-12#JZ_[W`,CL[^[P\B#M
MX"!M8F]X(/3@Z>L`PN#F[>@`PN#F[>X@[^CQ[.X`R.SO[O#RZ/#@[>@@X?_U
MX"`E9"#OZ/'LX"#N\B`E<RX`R.SO[O#RZ/#@[>X@[^[KY3H@)7,`R.SO[O#R
MZ/#@[>@@[^[KY?+@.@#$X"#QY2#BZNO^]^+@(.OH(.KPX/+J[B#NX>[A^>7M
MZ.4@[O(@:&5A9&5R<R#B(.[RX^[B[O#@/P#$X"#QY2#BZNO^]^@@Z^@@Z"#N
M\.CCZ.W@Z^WN\NX@[^CQ[.X@XB#N\N/NXN[PX#\`R.WT[O#LX/;H_R#GX"`E
M<R#O\^'KZ/?E[2#JZ_[W`,CM].[P[.#VZ/\@Y^`@[^7P\>[MX.OMZ/\@]^#Q
M\N7M(.KK_O<`R.WT[O#LX/;H_R#GX"#OY?#Q[NW@Z^WH_R#O\^'KZ/?E[2#J
MZ_[W`,(@\.7DX`#-Y>+@Z^CD[>`@[O+DX.OE]^7MX"`H[>7K[NK@Z^W@*2#O
M[OEE[?'JX"#J\_+H_P#(Y^_PX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N
M`,WEXN#KZ.3E[2#JZ_[W`,WEXN#KZ.3E[2#OY?#Q[NW@Z^7M(%!'4"#WX/'R
MY>T@ZNO^]RX`S>7BX.OHY.7M(._E\/'N[>#KY>T@4$=0(._SX>OH]^7M(.KK
M_O<N`,W@ZNON[>7MZ`#O^NOM[B#O[N3PX.+M_^+@[>4`Z__B[B#O[N3PX.+M
M_^+@[>4`Y/_Q[>X@[^[D\.#B[?_BX.WE`$ME<F)E<F]S(/'Z\.+Z\.`@[O+U
MXOKPZ^@@Z.3E[?+H].CJX/;H__+@+@#$^NOFZ.W@(.W@(.KK_O?@`,KK_O?@
M(.+E]^4@\?KYY?'RXO/BX"#B(._SX>OH]^WH_R#JZ_[W\?KPXOKP+@#*Z_[W
MX"#AY?CE(.CG[_#@\N7M(//Q[^7X[>X@XB#O\^'KZ/?MZ/\@ZNO^]_'Z\.+Z
M\"X`Q>?HZ@#/[O'KY>3MX"#Q\O#@[>CVX`#/[NSN^2#RY>SH`,3@(/'E(._N
MZN#GXN#R(.OH(.+QZ/?JZ"#J[NWRX.KRZ"P@ZN[CX/+N(/'E(.?@\.7FY.`@
MY>KPX.W@(/$@ZN[M\N#J\N@_("C@ZNX@Y2#GX.'PX.WE[>XL(/GE(.+HYN3@
M\N4@\>#L[B#J[NWRX.KRZ/+E(.KNZ/+N(/'RY2#R^O#QZ.OH*0#1[^CQ^NH@
MXB#GX./KX.+HY?+N`-'OZ/'ZZN`@\2#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M
M+@#+[NK@Z^W@(._N^>`Z`,+U[N0@XB`E<P#(Y_7NY`#'X.3@]^@@[_#H(.+U
M[N0`SN'HZNWNXN7M[>X`T>O@X2#O\.CN\.CRY?(`P>7G(._PZ.[PZ/+E\@#,
MS`!-4RU43D5&(._PZ.KPY>_E[>C_\B#TX.GK(.WE(/'ZY/KPYN#XY2#DX.WM
MZ"X`S^[YX`#/[OGE[?'JX"#J\_+H_P#,X/#JZ/#@Z2#JX/+N.@#$X"#QY2#L
MX/#JZ/#@\B#KZ"#PX.?KZ/?MZ/+E(.WHXN`@[>`@[O+C[N+N\.@@\2#PX.?K
MZ/?MZ"#VXN7R[N+E/P#1^N+OX.3@^>@@[^[KY?+@`-?KY>WNXN4`PNCD(.W@
M(.SE[?[R[CH`S^CQ[.X`S>#OZ/'BX.WE(.W@(._H\>SN`,3@\N`@[>`@[^CQ
M[.[R[@#2^O#QY>WE(.W@(._H\>SN`-#@Y^SE\"#MX"#OZ/'L[O+N`/'N\/$@
MZN[D(.W@(._H\>SN\NX`S_#EX^OEY"#MX"#OZ/'L[@#4Z^#C[N+E(.W@(._H
M\>SN\NX`S^#OZN@@Y^`@[^CQ[.``S^CQ[.X@[O(@)7,`S^CQ[.[R[B#AY?CE
M(.CG[_#@\N7M[B#S\>_E^.WN+"#M[B#MY2#AY?CE(.?@[^CQX.WN(.(@)7,`
MS^CQ[.[R[B#AY?CE(.CG[_#@\N7M[B#S\>_E^.WN+@#/Z/'LX"#B(/'R\.#M
MZ/;@(.?@(._N^>7M\>K@\N`@ZO/RZ/\N`._H\>S@\N`@X@#,Y?+NY`!-:6UE
M(/+H[P#$X/+@(.W@(._P[NSE[?_MY0#,Y?'E]^WN`,_PY>SE\?+H`,SN__+@
M(,_N^>``R.SE`,CLY2#H+^CKZ"!E;6%I;"#MY2#L[N/@\B#DX"#QX"#O\.#G
M[>@`S/#EYN``S>CJ[N/@`,WNXN@`S>[BX"#OX._JX`#-[N+@(._N^>``S>[B
M[B#O[O+PY>'H\N7K\>KN(.CLY2`H[N_VZ.[MX.OM[BD`S>[BZ"#OZ/'LX`#1
MZ^7DXN#Y[B#OZ/'L[@#1Z^7DXN#YX"#Q\O#@[>CVX`#-Y0#!Y><@ZO#H[_+H
M\.#MY0#-_^S@(.KK_O?NXN4@XB#Q[^CQ^NK@`,W_[.`@Z.SO[O#RZ/#@[2!0
M1U`@[_/AZ^CWY>T@ZNO^]RX`S?_LX"#MX.SE\.7MZ"#O\.CJ\.7OY>WH(/3@
MZ>ONXN4N`,W_[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@($944"!61E,N
M`,W_[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@(%-13"!61E,N`,W_[.`@
MY^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@(%-13"U&:6QE(%9&4RX`S>4@X?_U
MX"#HY^'PX.WH(._@[^KH`,W_[.`@\N7J\?(@XB#R_^ON\NX@[>`@[^CQ[.[R
M[@#-_^S@(._H\>S@(.[RX^[BX/#_^>@@[>`@\OKP\>7MY?+N+@#-_^S@(.?@
MY.#DY>W@(._@\.[KX"#GX"!)34%0(.CDY>WRZ/3HZN#VZ/\N`,W_[.`@Y^#D
MX.3E[>`@[^#P[NO@(.?@($ME<F)E<F]S(.CDY>WRZ/3HZN#VZ/\N`,W_[.`@
MZN[M].CC\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@4TU"(.CDY>WRZ/3HZN#V
MZ/\N`,WE(.'E^.4@Z.SO[O#RZ/#@[2#OY?#Q[NW@Z^7M(%!'4"#WX/'RY>T@
MZNO^]RX`S>4@X>7XY2#H[._N\/+H\.#M(._E\/'N[>#KY>T@4$=0(._SX>OH
M]^7M(.KK_O<N`,W_[.`@[_#@XN[OZ/'MZ"#C\.7XZN@`S?_LX"#O\.7DZ^[F
MY>WH_P#"^O#MX/+H\N4@Y.#M[>@@[>4@\>`@6$U,`,W_[.`@\?+NZ>WN\?+H
M`,W_[.``S>[P[.#K[>X`S>7HY_+PZ/+H`,WE+??E\.WNXN@`S.#K[N+@YNWH
M`,WE+>OH]^WH`,WEXN#KZ.3E[2#O\^'KZ/?E[2#JZ_[W+@#-Y>CG\O#H\N@@
M[^CQ[.``S.#K[N+@YNWH(._H\>S@`,'EZ^7FZN@`P?#NZ2#MX"#Q\N#PZ/+E
M(._@[^KH("+(Y^_PX/+E[>`@[^[YX"(@Y^`@\?KU\.#MY>WHY2P@X.KN(/'E
M(/+PZ/_R(.SE\>7W[>XN`-'RX/#H(._H\>S@`-'RX/#H(._@[^KH("+(Y^_P
MX/+E[>`@[^[YX"(L(.KNZ?+N(/'E(.?@Z^CWX.+@\BX`SN_VZ.@`S^[D\.7D
MY>T@\>_H\?KJ`,3P\^/@(.CM].[P[.#VZ/\`Q/#SX^@@SN_VZ.@`S_#@XN`@
M[>`@[_#H\N7FX/+EZ_\`4$=0`%!'4"##\.7XZN`Z(,WE[N'U[N3H[.`@Y2#J
MZ_[W[N+@(/3PX.?@(.?@(/?@\?+E[2#JZ_[W+@!01U`@SN_VZ.@`POKBY>3E
M\N4@4$=0(.KK_O?NXN`@]/#@Y^``4$=0(._E\/'N[>#K[>`@ZNO^]^[BX"#D
MXN[IZN`@Z.?H\>KBX"#J\.CO\NCPX.W@('=E8B#B\/KGZN`N`%!'4"#O\^'K
MZ/?E[2#JZ_[W(.?@("(E<R`H)7,I(B#AY?CE(//Q[^7X[>X@Y.[AX.+E[2X`
M4$=0(._SX>OH]^7M(.KK_O<@Y^`@(B5S(B#AY?CE(//Q[^7X[>X@Z.?R\.CR
M+@!01U`@[_/AZ^CWY>T@\>_H\?KJ`,_NY._H^.@@\2!01U`@`,_NY._H^.@O
MZO#H[_+H\.#I(._H\>SN(/$@4$=0`-'H\?+E[.#RX"#E(/$@Z.?JZ_[WY>W@
M(%!'4"#O[N3D\/KFZN`N`%!'4"#O[N3D\/KFZN#RX"#MY2#E(.#J\NCB[>`@
MZ"#VZ/3P[N+H__(@[^[D[^CQ(.WE(.SNYN4@Y.`@X?KDY2#O\.[BY?#E[2X`
M4$=0(._NY.3P^N;JX/+@(.WE(.4@X.KRZ.+MX"#H(._H\>SN\NX@[>4@[.[F
MY2#DX"#A^N3E(.3EZO#H[_+H\.#M[BX`4$=0(%-H96QL`%!/4#,`4$]0,R#B
M^O#U\R!34TP@*/'@[.[O[N3OZ/'@[2D`4$]0,RP@X>7G(%1,4P#Q\O#@[>CV
MX"`E9"#N\B`E9`#7X/'R*.@I`,KK_O?NXN`@]/#@Y^``RNO^]^[BX"#T\.#G
MX"`H[O+M[N+N*0#*Z_[W[N+@\N`@]/#@Y^`@X>7XY2#S\>_E^.WN(._PY>S@
M]>W@\N`N`,KK_O?NXN`@]/#@Y^`Z`,KK_O?NXN#RX"#T\.#GX"#MY2#L[N;E
M(.3@(.4@[_#@Y^W@`,KK_O?NXN#RX"#T\.#GX"#MY2#Q^N+OX.3@`,_@\.[K
MX`#/X/#NZ^`Z`,_@\.[KX#H@`,WEZN[PY>KR[>`@[^#P[NO@+@#"[/KJ[>@`
MQ.`@\>4@Z.?B^O#XXN#R(.OH(.[A\>OSYN+@^>CRY2#N[^7PX/;HZ"#O\.@@
MPO7NY#\`S_#@XN``P.3LZ.WH\?+PZ/#@[>4@[>`@[_#@XN#RX`#/Y?#Q[NW@
MZ^WH`,_E\/'N[>#K[>`@Z.WT[O#LX/;H_P#/Y?#Q[NW@Z^W@(%!'4"#JZ_[W
M[N+@(.3B[NGJX"#AY?CE(//Q[^7X[>X@X^7MY?#H\.#MX"X`S^7P\>[MX.OM
MZ"!01U`@ZNO^]^[BY2#A__7@(//Q[^7X[>X@Z.?R\.CRZ"X`S^7P\>[MX.OM
MZ"!3+TU)344@ZNO^]^[BY2#A__7@(//Q[^7X[>X@Z.?R\.CRZ"X`TN7KY?3N
M[0#$X"#QY2#QZ^#CX"#KZ"#BX/CH__(@[^[D[^CQ(._PY>3H(.[RX^[B[O`@
MZ"#O\.7O\.#YX.WE/P#,[NO_+"#B^N+EY.7RY2#LY?'E]B#H(./NY.CMX"X`
MS.[K_RP@XOKBY>3E\N4@ZNO^]^[BX"#T\.#GX"#GX"#"X/CH__(@4$=0(/?@
M\?+E[2#JZ_[W+B#-Y>[A]>[DZ.SN(.4@Y.`@XOKBY>3E\N4@\N#GZ"#T\.#G
MX"#BY>3M^N8@Y^`@)7,@\>7QZ/\N`,SNZ_\L(.+ZXN7DY?+E(.KK_O?NXN`@
M]/#@Y^`@Y^`@PN#XZ/_R(%,O34E-12#WX/'RY>T@ZNO^]RX@S>7NX?7NY.CL
M[B#E(.3@(.+ZXN7DY?+E(/+@Y^@@]/#@Y^`@XN7D[?KF(.?@("5S(/'E\>C_
M+@#,[NO_+"#J[O#HX^CPX.GRY2#MY>+@Z^CD[>CRY2#HZ^@@X>7G\>SH\>OE
M[>@@X.3PY?'H+@#-X/'R\.[IZNCRY2#A__7@(.[A[>[BY>WH(//Q[^7X[>XN
M`,_PY>3H^.WN(._H\>SN`,_PY>3H^.W@(/'R\.#MZ/;@`,[R[^7WX/+@Z0#/
M\.CN\.CRY?(`S_#N\N[J[NLZ`,_NY.3P^N;JX/+@(.?@(%!'4"#JZ_[W[N(@
M\?KPXOKP(.'E^.4@Y^#A\.#MY>W@+@#*Z_[W[N+@(.3B[NGJX"#O\^'KZ/?E
M[2_WX/'RY>T@ZNO^]R#MY2#AY?CE(./E[>7PZ/#@[>`N`,?@Z^CWZ"#HY_+P
MZ/+H\N4`RN[KZNX@]^7Q\NX@Y.`@\>4@Z.?O\.#GXN`@ZN[X]^7R[CH`R.?W
MZ/'RZ"#OZ/'LX/+@(.[R(.KN^/?E\NXL(.KNZ/+N(/'@(._N+?'RX/#H(.[R
M(/+NZ^KNXN`@Y.WH+@#*XN[RX"#Q\N#R\_$Z("4N,F9-0B`O("4N,F9-0B`@
M*"4N,F8E)2D`RN+N\N`@\?+@\O/Q.B#!Q<<@R\C,R-(`RN[E].CVZ.7M\@#7
MY?+E[>4`R/'JX/+E(.3@(.CG\O#HY?+E("5S(.OH/R#2X.?H(.[OY?#@]NC_
M(.WE(.SNYN4@Y.`@\>4@XOKP[>4@[>#GX.0N`,_PY>W@\>[WZ`#/\.7MX/'N
M]^@@\N[BX"#OZ/'L[@#/\.7MX/'N]^+@[>7R[B#QY2#O\.[BX.OH`,[O\.7Q
M[>@`SN_PY?'M_^+@Z2#HY^/KY>3H\N4@[>`@[^#OZNCRY0#/\.7GX/#EY.@@
MZ.?CZ^7DX`#'X._N[.WH(._N\>OEY.WH_R#HY^/KY>0`S^[YY>WQZN`@ZO/R
MZ/\Z`,#D\.7Q(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M`,_PY>S@]>WH`,_PY>S@]>WH(._N\O#EX>CRY>LZ("5S`,_PY>CLY>WSXN#I
M(._@[^K@*.@I`,3@(/'E(._PY>CLY>WSXN`@Z^@@(LCG[_#@\N7MX"#O[OG@
M(B#OX._JX"#B(.W@]^#K[O+N(.W@(.SE\>7VX#\`S_#EZ.SE[?/BX.WE\NX@
M[>`@(B5S(B#B("(E<R(@\>4@[_#NXN#KZ"X@Q?+N(.K@ZN+N(.K@Y^`@\?KP
MXOKPX`#'X.SE[>@@\3H`SO+C[N+N\`#.\N/NXN[P(.3N(.+QZ/?JZ`#.\N/N
MXN[P(.3N(.+QZ/?JZ#H`SO+C[N+N\"#D[B#Q[^CQ^NK@`,[RX^[B[O`@Y.X@
M\>_H\?KJX#H`SO+C[N+N\"W$[@#.\N/NXN[P+<3N.@#.\N/NXN[P.@#0X._N
M\/(@Y^`@T>_@[`#/[N3M[N+H`,+Z\.WH(/'E(.KZ["#O[OGE[?'JX/+@(.KS
M\NC_(/'KY>0@Z.?R\.CBX.WE+"#LY?'RY>WE(.CKZ"#J[N_H\.#MY2#MX"#O
MZ/'L[BX`4R]-24U%`%,O34E-12#.[_;HZ`#"^N+EY.7RY2!3+TU)344@ZNO^
M]^[BX"#T\.#GX`!3+TU)344@[^[DY/#ZYNK@\N`@Y^`@[^7P\>[MX.OMX"#J
MZ_[W[N+@(.3B[NGJX"#HY^CQZN+@(.KPZ._RZ/#@[>`@=V5B(.+P^N?JX"X`
M4R]-24U%(.3B[NGJX"#O\^'KZ/?E[2_WX/'RY>T@ZNO^]R#AY?CE(//Q[^7X
M[>X@Y.[AX.+E[>`N`-'H\?+E[.#RX"#E(/$@Z.?JZ_[WY>W@(%,O34E-12#O
M[N3D\/KFZN`N`%-13"!3:&5L;`!34T@`Q^#OZ/CH(.K@\NX`Q^#OZ/'@(.W@
M(/?E\.WNXN#RX"#QY2#O\.[BX.OH+B#%\NX@ZN#JXNX@ZN#GX"#Q^O#B^O#@
M.B`E<P#2^O#QZ`#0Y>?SZ_+@\N@@[O(@\OKP\>7MY?+N`,_PY>/KY>3@[>@`
MR.?AY?#H`,CGX>7PY?+E(./P\^_@(.?@(.3NX>#B_^WE`,CGX>7PY?+E(.WN
MXB#O\.CRY>;@\N7K(.W@(./P\^_@`,CGX>7PY?+E(/'Z\.+Z\`#(Y^'E\.@@
M[^[R\.7AZ/+EZR#GX"#D[N'@XO_MY0#(Y^'E\.7RY2#@Y/#E\>W@(.KMZ./@
M(.?@(.3NX>#B_^WE(.@@\OKP\>7MY2#MX"#@Y/#E\>@N`,CGX>7PZ"#B\>CW
MZN@`R.?AY?#E\N4@[^[YX`#-Y2#HY^'H\.#I(.WH^>X`R.?AY?#E\N4@Q.#R
MX"#PX.?DY>OH\N7K.@#(Y^'E\.7RY2#T[O#LX/(@Y^`@Q.#RX/+@.@#(Y^'E
M\.7RY2#T[O#LX/(@Y^`@U^#QX#H`R.?AY?#E\N4@Y.+E(/'ZXN_@Y.#YZ"#O
M[NOE\N`Z`,CGX>7PY?+E(.+@^.#RX"#Q]>7LX"#GX"#VXN7R[N+E\N4N`,CG
MX>7PY?+E(._PY>3O[O?H\N#MZ/_R(.[R(,+@\2#EY^CJ.@#(Y^'PX.W@(.#D
M\.7Q[>`@ZNWHX^`Z`,CG[_#@\N@@ZNO^]R#B(._SX>OH]^WH_R#JZ_[W\?KP
MXOKP`,_@[^K@("+(Y^_PX/+E[>`@[^[YX"(Z`-'Z\.+Z\`#1^O#B^O`Z`,W@
M\?+P[ND@ZN#JXNX@Y.`@\>4@\>OS]^+@+"#J[N/@\NX@[_#E[.7Q\NCX(.CK
MZ"#HY_+PZ.7X(._H\>SN+@#$X"#QY2#GX.3@XN`@Z^@@6"U0<FEO<FET>2#G
MX./KX.+MX"#WX/'R(._PZ"#OZ/'@[>4@[>`@[^CQ[.X_`,?@Y.#I\N4@PN#X
MY?+N(.W@]^#K[>X@[_#HZ^[FY>WHY2P@\?7E[.`@Y^`@]N+E\N[BY2P@[N_P
MY?'M_^+@[>4@[>`@\?+PX.WH]N#RX"#H(.3P\^/H(.[O]NCH(.?@(.3H\>_K
MY?\N`-+P_^'BX"#KZ"#DX"#QY2#O\.[BY?#_XN`@\?KD^O#FX.WHY?+N(.W@
M(.[AZ.KM[N+E[>@@\N7J\?+NXN@@[^CQ[.`@Y^`@4$=0(.3@[>WH/P#2\/_A
MXN`@Z^@@[_#NY^[PY?;@("+-X._H^.@B(.3@(/'E(.?@\N+N\.@@\>OEY"#G
MX._H\2#MX"#WY?#M[N+@\N`N`,3@(.'ZY.4@Z^@@[_#HZO#E[__M(,+@^.C_
M\B#O\^'KZ/?E[2!01U`@ZNO^]R#J^NP@[^CQ[.#RX"#"Z"P@[^X@[^[D\.#G
MX>CPX.WE/P#/[NK@Y^+@[>4`S^[JX.;H(.+QZ/?JZ"#GX./KX.+MZ"#WX/'R
MZ`#/[NK@YN@@Z.?R\.CRZ/+E`,_NZN#FZ"#QX.SN(.CGX?#@[>@@Y^#CZ^#B
M[>@@]^#Q\N@A`,_NZN#FZ"#H[?3N\.S@]NC_(.?@($UA:6QI;F<@3&ES=`#/
M[NK@YN@@[>7@X>[MZ/#@[>CRY0#$X"#QY2#O[NK@Y^+@(.OH(.OEX^7MY.`@
MXB#O[OGE[?'JX/+@(.KS\NC_/P#$X"#QY2#O[NK@Y^+@(.OH("+$\//CZ"#O
M[OGH(B#HZN[MX"#B(.SE[?X@Z^7M\N#RX#\`T.#G[.7P`-'N\/+H\.#I(._N
M(._NZ_/WX.+@[>4`T>[P\NCPX.D@[^X@Y.#RX`#1[O#RZ/#@Z2#O[B`BSO(B
M(.#D\.7Q`-'N\/+H\.#I(._N(/#@Y^SE\"#MX"#OZ/'L[O+N`-'N\/+H\.#I
M(._N(/+E[.``T>[P\NCPX.D@[^X@[>CXZN@`POKBY>;DX.WE(.W@(/'OY?;H
MX.OMZ"#QZ.SB[NOH`-'OY?;HX.OMZ"#QZ.SB[NOH`,_PX.+N[^CQ`,_P[N+E
M\.K@(.W@(._PX.+N[^CQX`#/\.#B[N_H\>`@X>7XY2#O\.[BY?#E[0#/\.#B
M[N_H\>WH(./PY?CJZ"#B(/'R\.#MZ/;@(._PZ"#O\.[BY?#JX"#GX"#O\.#B
M[N_H\2X`T?+@\O/Q`-+E[.``TN7LX"#MX"#OZ/'L[O+N`,#A[NWH\.#MY2#G
MX"#OX._JX"CH*0#3\>_E]0#/\.7D[^[K[N;E[>C_`,?@Y.#WZ`#4X.GK(.?@
M("+3\>ONXNC_(.W@(//QZ_/CX/+@(B#MY2#E(.?@Y.#DY>T@XB!C;VYF+G!H
M<`#2Y>KQ\@#1X.SN(/+EZO'R`,_N^>#RX"`B)7,B(.'E^.4@[_#E[.#U[>#R
MX"X`S^[YX/+@("(E<R(@X>7XY2#GX._H\>#MX"X`TN7J\_G@\N`@[^#OZN`H
MZ"D@(B5S(B#YY2#A^N3E(._PY>CLY>WSXN#MX"#MX"`B)7,B+@#/\.CJ\.7O
MY>WH__(@4$=0(._NY._H\2#E(.WE[N'U[N3H["#GX"#DX"#QY2#O\.[BY?#H
M(._NY._H\>#M[O+N(._H\>SN+@#*\.CO\NCPX.WE\NX@Z.?H\>KBX"#J\.CO
M\NCPX.W@('=E8B#B\/KGZN`N`,_@[^K@\N`@(B5S(B#BY??E(/'Z^>7Q\N+S
MXN``R.SE\NX@[>`@[^#OZN#RX"`B)7,B(/'ZY/KPYN`@[>7J[O#EZO+MZ"#Q
MZ.SB[NOH+B#2[N+@(.SNYN4@Y.`@Y.[BY>3E(.3N(._P[N'KY>SH+B#,[NO_
M(.KN[?'SZ_+H\.#I\N4@\>4@\?KQ(-'H\?+E[.WH_R#`Y.SH[>CQ\O#@\N[P
M+@#/X._JX/+@("(E<R(@X>7XY2#Q^N?DX.3E[>`L(.WN(,+HY2#MY2#Q\N4@
MX.'N[>CPX.WH(.?@(.WE_RX@`,_@[^K@\N`@(B5S(B#AY?CE(.CG\O#H\N`L
M(.WN(,+HY2#B\>4@[OGE(/'RY2!AX.'N[>CPX.WH(.?@(.WE_RX`S^#OZN#R
MX"`B)7,B(.WE(.'E^.4@\?KGY.#DY>W@+B#%\NX@ZN#JXN`@Y2#O\.CWZ.W@
M\N`@\>_N\.7D(/'Z\.+Z\.``S^#OZN#RX"`B)7,B(.'E^.4@\?KGY.#DY>W@
M(//Q[^7X[>XN(`#/X._JX/+@("(E<R(@X>7XY2#HY_+PZ/+@(//Q[^7X[>XN
M(`#/X._JX/+@("(E<R(@X>7XY2#S\>_E^.WN(._PY>CLY>WSXN#MX"#MX"`B
M)7,B+@#,Y?'R[N_NZ^[FY>WHY?+N(.W@($=N=5!'(/3@Z>O@(/+P_^'BX"#D
MX"#A^N3E(.3@Y.7M;R#MX"!#<GEP=%]P9W`Z.B!C;&%S`,_N^>7M\>K@\N`@
MZO/RZ/\@)7,@Y2#BY??E(.[RXN[PY>W@+@#/Z/'L[O+N(.'E^.4@[_#NXN7P
MY>WN+@#/\.[C\.#LX/+@+"#J[O_R[B#QZ_/FZ"#GX"#O[NK@Y^+@[>4@[>`@
M\N[GZ"#RZ.\@Y.#M[>@@*"5S*2#MY2#AY?CE(.[RZO#H\N`@XB#QZ/'RY>S@
M\N``R.?H\>K@[>C_(._PZ.KPY>_E[2#TX.GK(.WE(.4@[O+J\.CR(.(@35,M
M5$Y%1BX`R.?H\>K@[>C_(/3@Z>L@[>4@\?KYY?'RXO/BX"#B(%II<"#O\.CJ
M\.7OY>WH_R#TX.GK+@#-_^S@(.#K\N7P[>#RZ.+MZ"#DXN[IZN@L(.KNZ/+N
M(.3@(.'ZY.#R(._NZN#GX.WH(.(@Z^CMZ/_RX"X`S?_LX"#OZ/'LX"#B(/+@
MY^@@[^[YY>WQZN`@ZO/RZ/\N`,W_[.`@Y.+NZ>KH+"#J[NCR[B#DX"#A^N3@
M\B#O[NK@Y^#MZ"#B(.OH[>C_\N`N`,CLX"#RXOKPY.4@[.WNX^X@\>CLXN[K
MZ"#B(/+NXN`@[^[KY2X@POKBY>OH(/'RY2`E<R#QZ.SB[NO@.R#R\/_AXN`@
MY.`@XOKBY>3E\N4@[^XM[.#KZNX@[O(@)7,N`,CLX/CE(._P[N'KY>P@[_#H
M(.?@Z^CWX.+@[>7R[B#MX"`E<RX@Q?+N(.K@ZN+@(.4@[_#H]^CMX/+@`,/P
MY?CJX"#O\.@@Y^#KZ/?@XN#MY2#MX"#O[OGE[?'JX"#J\_+H_RX@Q?+N(.K@
MZN+N(.K@Y^`@\?KPXOKPX#H@)7,`R.S@^.4@[_#NX>OE["#O\.@@Y^#KZ/?@
MXN#MY?+N(.W@(._N^>7M\>K@\N`@ZO/RZ/\N(,_PZ/?H[>#RX"#E`,/PY?CJ
MX"#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`Z("5S(.WE(.'E^.4@Z.?O\.#R
MY>TN`,CLX/CE(._P[N'KY>P@[_#H(.CG[_#@^>#MY?+N(.W@(/3@Z>O@+B`E
M<R#E(._N+>/NZ__L(.[R(.S@ZO'H[.#K[>X@Y.[O\_'RZ.SH_R#PX.?LY?`@
M*"5D(.'@Z?+@*2X`P_#E^.K@(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX"X@
M)7,@X>7XY2#QX.SN(.[R]^#Q\N@@Z.?O\.#RY>TN`,/PY?CJX"#O\.@@ZN[O
MZ/#@[>7R[B#MX"#OZ/'LX"#N\B`B)7,B(.(@(B5S(BX@Q?+N(.K@ZN+N(.K@
MY^`@\?KPXOKPX`##\.7XZN`@[_#H(.CG\O#HXN#MY?+N(.W@(._H\>S@\N`@
M[O(@[^#OZN`@(B5S(BX@T>_N\.7D(/'Z\.+Z\.`@[_#H]^CMX/+@(.?@(/+N
MXN`@Y0##\.7XZN`@[_#H(.CG\O#HXN#MY2#MX"#OZ/'LX"#B(._@[^K@("(E
M<R(N(,_PZ/?H[>#RX"#Q[^[PY>0@\?KPXOKPX"#E`,/PY?CJX"#O\.@@Z.?R
M\.CBX.WE(.W@(._H\>S@+B#%\NX@ZN#JXNX@ZN#GX"#Q^O#B^O#@.B`E<P##
M\.7XZN`@[_#H(._NZN#GXN#MY2#MX"#RX.?H(/?@\?(@[O(@[^CQ[.[R[@##
M\.7XZN`@[_#H(//Q\N#M[N+_XN#MY2#MX"#TZ^#C[N+E(.(@[^#OZN`@(B5S
M(BX@S_#H]^CMX/+@(/'O[O#EY"#Q^O#B^O#@(.4`P_#E^.K@(._PZ"#H[._N
M\/+H\.#MY2#MX"#DX.WMZ/+E.B`E<RX`P_#E^.K@(._PZ"#H[._N\/(@[>`@
MY.#M[>@@Y^`@ZN[M\N#J\N@N`,/PY?CJX"#O\.@@[_#E[.7Q\N+@[>4@[>`@
M(B5S(B#B("(E<R(N(,7R[B#JX.KB[B#JX.?@(/'Z\.+Z\.`N`,/PY?CJX"#O
M\.@@Y^#OZ/'@(.W@(/+NXN`@[^CQ[.X@ZN#R[B#WY?#M[N+@+@##\.7XZN`@
M[_#H(.CG[_#@^>#MY?+N(.W@(._H\>SN\NXZ("5S`-+NY^@@4$=0(._SX>OH
M]^7M(.KK_O<@X>7XY2#O\.CJ\.7OY>T@ZOKL(._H\>SN\NXN`-+NXN`@[>4@
MY2#BX.OHY.7M(')A<B#@\/7HXBX`TN[BX"#MY2#E(.+@Z^CDY>T@>FEP(/3@
MZ>LN`-+NXN`@[^[KY2#E(.WE[N'U[N3H[.XN`-+NXN`@[^[KY2#L[N;E(.3@
M(/'ZY/KPYN`@\>#L[B#VY>OH(/?H\>O@+@#2[N+@(._NZ^4@[.[FY2#DX"#Q
M^N3Z\.;@(/'@[.X@]^CQZ^`@Z"#DXN[E\N[WZ.4N`-+NXN`@[^[KY2#R\/_A
MXN`@Y.`@Y2#GX._E\N#_(.CKZ"#H[?+E\.+@ZR#PX.?DY>OE[2#Q[^CQ^NH@
M[_#N[.7MZ^CBZ`#2X.?H(/3N\.S@(.+E]^4@X>7XY2#NX?#@X>[RY>W@+@#2
M[N+@(._H\>SN(.WE(.4@XB#J[O#EZO+E[2!01U`@].[P[.#R("CQ^N[A\.#G
M[>X@4D9#(#(P,34I+@#2[N+@(._H\>SN(.'E^.4@]NCT\.[B[B#O[N3OZ/'@
M[>X@]_#EYR!01U`N`-+NXN`@[^CQ[.X@X>7XY2#VZ/3P[N+N(._NY._H\>#M
M[B#W\.7G(%,O34E-12X`TN[BX"#OZ/'L[B#AY?CE(.KPZ._RZ/#@[>X@\2!0
M1U`N`-+NXN`@[^CQ[.X@X@#2[N+@(/?H\>ON(/+P_^'BX"#DX"#E(._N[>4@
MY>3H[>CVX"X`TN[GZ"#Q^O#B^O`@[>4@[.[FY2#DX"#DY>KN[._PY?'H\.`@
M>FEP(.@@9WII<"#TX.GK[N+E+@#2X.?H(/'R[NGM[O'R(/+P_^'BX"#DX"#E
M(/?H\>ON+@#(Y^/KY>0@[^X@\>SH\>ONXN@@[>CXZN@`S_#N\>OEY/_BX.WE
M(.WE(.+PY>SE`,3K^N;M[O'R`,3N`,_@[^K@("+*[OCWY2(Z`%523`#-Y>+Z
MY^SNYNWN\?(@Y^`@XO#ZY^K@(/$@4U%,(/'Z\.+Z\"X`P_#E^.K@(._PZ"#N
M\N+@\/_MY?+N(.W@(.KN[._PY?'H\.#M(.#P]>CB+@##\.7XZN`@[_#H(/?E
M\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N`,/PY?CJX"#O\.@@[_#NXN7PZN#R
MX"#GX"#JXN[RX`##\.7XZN`@[_#H(._PY>+NY.`@[>`@\N[GZ"!7;W)D(.3N
MZO/LY>WR`,'EYR#N\N/NXN[P`,_H\>S@(.'EYR#N\N/NXN[P`,+ZY_'RX.WN
MXN@`S^[D]^7P\N#MZ`#-Y>CGXN7Q\NWH(,_NZ_/WX/+EZ^@`S_#E[.#UXN#M
MY2#MX"#JZ_[W[N+@(/3PX.?@`,'EY^CLY>WMZ`#-Y>_PY>/KY>3@[>@`SO+O
MZ/CH(.[R(._@[^K@*.@I`,[O\.7Q[>@`SN_PY?'MZ"`E<P#(Y^_PX/+H`,CG
M[^[KY^+@Z2#O[N3PX.?AZ/#@^>#RX"#QY2#Q\N[I[>[Q\@#$X"#QY2#HY^_N
MZ^?BX/(@Z^@@24U!4"#@X>[MX.SE[?+H(.?@(._@[^KH/P#`Y.SH[>CQ\O#H
M\.#MY2#MX"#O[O+PY>'H\N7KZ/+E`,CLY0#([.4Z`,CLY3H@`,_N\O#EX>CR
MY>OH(.(@\>CQ\N7LX/+@.@#"X.K@[?;H_P##\.7XZN`@[_#H(._P[N+E\.K@
M\N`@+2#R[N+@(._H\>SN(.SNYN4@Y.`@Y2#AZ.ON(._NY._PX.+E[>XN`,+H
MY@#(Y^/KY>0@)7,`PNCF("5S(._SX>OH]^7M(.KK_O<`PNCF(._E\/'N[>#K
MY>T@]^#Q\N7M(.KK_O<`PNCF(._E\/'N[>#KY>T@[_/AZ^CWY>T@ZNO^]P#(
MY^/KY>0@Z.OH(._N^>7M\>K@(.KS\NC_(.3@(.'ZY.4@[>`@Y>KPX.W@(/'K
MY>0@XO7NY#H`T>7D[.CW[>X`Q.[A\.4@Q.[XZ^@@XB`E<P#$[N'PY2#D[OCK
MZ"P@)7,`R.?AY?#E\N4@[_#HZ^[FY>WHY?+N+"#J[N7R[B`E<R#DX"#O[NK@
MYN4@\>OEY"#B]>[D+@#/\.@@Z.?R\.CBX.WE(.W@(._H\>S@+"#DX"#QY2#O
M\.7LY?'RXN#R(.OH(.(@ZN[X]^7R[B#B[.7Q\NX@Y.`@\>4@[.#PZNCPX/(@
MZN#R[B#HY_+PZ/+H+@#!Z.?MY?$@X.3PY?$`P>CG[>7Q(/+EZ^7T[NT`P\,`
MP^[DZ/CM[@#$X`#-Y2#B^N+EY.[U\N4@XN#KZ.3E[2!E;6%I;"#@Y/#E\2X`
MTO#_X>+@(.3@(.+ZXN7DY?+E(.KK_O?NXN#RX"#T\.#GX"#MX"#"X/CH_R!0
M1U`@]^#Q\N7M(.KK_O<@Y^`@Y.`@XNCDZ/+E(/+NXN`@[^CQ[.X`TO#_X>+@
M(.3@(.+ZXN7DY?+E(.KK_O?NXN#RX"#T\.#GX"#MX"#"X/CH_R!3+TU)344@
M]^#Q\N7M(.KK_O<@Y^`@Y.`@XNCDZ/+E(/+NXN`@[^CQ[.X`TO#_X>+@(.3@
M(.CGX>7PY?+E(._N^>`L(.KN__+N(.3@(.'ZY.4@Z.?R\.CRX"X`TO#_X>+@
M(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@Z.?R\.CBX.WE+@#2\/_AXN`@
MY.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#D[N'@XO_MY2X`TO#_X>+@(.3@
M(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@[N_PY?'M_^+@[>4N`,WE(.'_]?+E
M(.#A[NWH\.#M(.?@("(E<R(N(,7R[B#JX.KBX"#E(._PZ/?H[>#RX`#-Y2#A
M__7RY2#N\N_H\>#M(.[R("(E<R(N(,7R[B#JX.KBX"#E(._PZ/?H[>#RX"#Q
M[^[PY>0@\?KPXOKPX`#!__7RY2#@X>[MZ/#@[2#S\>_E^.WN(.?@("(E<R(`
MP?_U\N4@[O+OZ/'@[2#S\>_E^.WN(.[R("(E<R(`R.WT[O#LX/;H_R#GX"#"
MX/$`PN#XY?+N(.CLY0#"X/CH\N4@4$=0(._SX>OH]^7M+_?@\?+E[2#JZ_[W
M[N+E`,+@^.C_\B#WX/'RY>T@ZNO^]P#"X/CH__(@[_/AZ^CWY>T@ZNO^]P#"
MX/CH\N4@[^[YZ#H`PN#XZ/_R(.CDY>WRZ/3HZN#VZ.[MY>T@Y/#@Z>+E\"#M
MY2#O[N3D^O#FX"#Q[^CQ^NH@[>`@[^[R\.7AZ/+EZ^CRY2P@Z.OH(/+@Y^@@
MXOKG[.[F[>[Q\B#E(.?@X?#@[>7MX"X`PN#XZ/+E(.KN[?3HX_/PX/;H[NWM
MZ"#N[_;HZ"#A__7@(.[A[>[BY>WH+@#"X/CH\N4@\?KPXOKPZ#H`PN#XZ/_R
M(._NY._H\3H`6\W_[.`@TN7LX%T`6^OH[>C_("5S(.[R("5S70#TX.GK`.[R
M`.W_[.``Z.OH`._PX.+N[^CQ[>`@X_#E^.K@`._PX.+N[^CQ[>@@X_#E^.KH
M`.'EYR#H[.4`=D-A<F0`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]A<E]/32\`
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<V,``P,3<T-#,`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O;&]C86QE+V%R7T]-+TQ#7TU%4U-!1T53+P``````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8P`#`R,3(S,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O87)?3TTO3$-?34534T%'15,O
M:6UP+FUO````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3$U,#$`,3`T,3<S-C(W
M-C``,#(R,S4Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-X2!)4`````+P$``!P```"4"0``F0$```P3````````<!D```H`
M``!Q&0``"@```'P9```*````AQD```H```"2&0``!````)T9```!````HAD`
M`!<```"D&0``,@```+P9```I````[QD``#(````9&@``&P```$P:```N````
M:!H``#<```"7&@``?````,\:```<````3!L``!T```!I&P``#````(<;```#
M````E!L``$X```"8&P``4````.<;``!"````.!P```@```!['```$0```(0<
M```C````EAP``"$```"Z'```.P```-P<```K````&!T``#$```!$'0``#```
M`'8=```)````@QT```8```"-'0``"@```)0=```+````GQT```H```"K'0``
M`P```+8=```)````NAT```0```#$'0``!````,D=```&````SAT```X```#5
M'0``/@```.0=```"````(QX```8````F'@``"@```"T>``!B````.!X``%\`
M``";'@``'````/L>```.````&!\``!4````G'P``#0```#T?```,````2Q\`
M`!0```!8'P``#P```&T?```F````?1\``%P```"D'P``!`````$@```'````
M!B````X````.(```!@```!T@```-````)"```!H````R(```'0```$T@```9
M````:R```%T```"%(```*````.,@```$````#"$``!D````1(0``&@```"LA
M```&````1B$``!````!-(0``,P```%XA```'````DB$``!````":(0``'```
M`*LA```*````R"$```\```#3(0``!P```.,A```H````ZR$``",````4(@``
M(````#@B```$````62(``!(```!>(@``!0```'$B```.````=R(```0```"&
M(@``%@```(LB```-````HB(```\```"P(@``$@```,`B```5````TR(``"D`
M``#I(@``+````!,C```H````0",```4```!I(P``$````&\C```0````@",`
M``\```"1(P``#P```*$C```,````L2,```H```"^(P``$@```,DC```-````
MW",```P```#J(P``/0```/<C```E````-20```<```!;)```!````&,D```*
M````:"0``!````!S)```!P```(0D```(````C"0``!D```"5)```!````*\D
M```,````M"0```0```#!)```#````,8D```1````TR0```4```#E)```!@``
M`.LD```*````\B0```D```#])```$@````<E```D````&B4```@````_)0``
M"0```$@E```&````4B4```P```!9)0``"P```&8E```'````<B4```@```!Z
M)0``-P```(,E```'````NR4``!,```##)0``#````-<E```.````Y"4```P`
M``#S)0``#@`````F```/````#R8```T````?)@``#P```"TF```F````/28`
M``L```!D)@``!@```'`F```$````=R8```0```!\)@``!0```($F```#````
MAR8```H```"+)@``"````)8F```,````GR8```0```"L)@``#````+$F```)
M````OB8```(```#()@``&0```,LF```D````Y28``!(````*)P``#@```!TG
M```$````+"<```L````Q)P``"0```#TG```-````1R<```P```!5)P``%```
M`&(G```6````=R<``#P```".)P```@```,LG```,````SB<``",```#;)P``
M#0```/\G```-````#2@```<````;*```"````",H```H````+"@```@```!5
M*```%````%XH```Q````<R@``"<```"E*```*````,TH```:````]B@``"X`
M```1*0``-@```$`I```L````=RD``#$```"D*0``$````-8I```-````YRD`
M``4```#U*0``#0```/LI```6````"2H``#X````@*@``"````%\J```0````
M:"H``!4```!Y*@``$P```(\J```'````HRH``!4```"K*@``"P```,$J```6
M````S2H``"X```#D*@``.@```!,K```-````3BL```4```!<*P``#````&(K
M```-````;RL```H```!]*P``!@```(@K```.````CRL```4```">*P``!@``
M`*0K``!+````JRL```H```#W*P``!P````(L```Y````"BP```8```!$+```
M#@```$LL```$````6BP```8```!?+```"@```&8L```+````<2P```P```!]
M+```$0```(HL```&````G"P``$,```"C+```.0```.<L```,````(2T``!$`
M```N+0``(````$`M```$````82T``!(```!F+0``"P```'DM```-````A2T`
M`!0```"3+0``+P```*@M```'````V"T```T```#@+0``%@```.XM```'````
M!2X```L````-+@``!````!DN```S````'BX``!X```!2+@``=0```'$N```^
M````YRX``$(````F+P``/0```&DO```]````IR\``"D```#E+P``*0````\P
M```Q````.3```"@```!K,```)@```)0P```^````NS```$<```#Z,```5P``
M`$(Q``!5````FC$``"\```#P,0``50```"`R```K````=C(``#L```"B,@``
M#P```-XR```+````[C(```(```#Z,@``#0```/TR```*````"S,``!,````6
M,P``"````"HS```6````,S,```<```!*,P``!@```%(S```:````63,``!$`
M``!T,P``'@```(8S```(````I3,```<```"N,P``)P```+8S```'````WC,`
M``T```#F,P``6@```/0S```#````3S0``"<```!3-```(0```'LT```D````
MG30``!T```#"-```&0```.`T```7````^C0``"H````2-0``*P```#TU```G
M````:34``"$```"1-0``*P```+,U```=````WS4``#T```#]-0``00```#LV
M```H````?38``"P```"F-@``#P```-,V```,````XS8```0```#P-@``!```
M`/4V```"````^C8```X```#]-@``#P````PW``!2`0``'#<```P```!O.```
M#0```'PX```*````BC@```P```"5.```!````*(X```#````IS@``!4```"K
M.```)P```,$X```@````Z3@``"@````*.0``&P```#,Y```N````3SD``"\`
M``!^.0``:P```*XY```=````&CH``"8````X.@``#````%\Z```&````;#H`
M`%H```!S.@``0@```,XZ```V````$3L```T```!(.P``&@```%8[```B````
M<3L``"$```"4.P``-@```+8[```J````[3L``#$````8/```"@```$H\```&
M````53P```4```!</```!````&(\```&````9SP```T```!N/```"0```'P\
M```/````ACP```0```"6/```!P```)L\```%````HSP```T```"I/```-P``
M`+<\```$````[SP```4```#T/```#````/H\``!.````!ST``%0```!6/0``
M*@```*L]```,````UCT``!(```#C/0``"0```/8]```)`````#X``!`````*
M/@``!P```!L^```;````(SX``$\````_/@```P```(\^```$````DSX```L`
M``"8/@``!0```*0^```*````JCX``!8```"U/@``&P```,P^```6````Z#X`
M`%@```#_/@``(````%@_```'````>3\``!D```"!/P``&0```)L_```%````
MM3\``!4```"[/P``,````-$_```$`````D````P````'0```%P```!1````&
M````+$```!`````S0```!````$1````N````24```#4```!X0```&````*Y`
M```"````QT```!D```#*0```!0```.1````/````ZD````4```#Z0```$P``
M``!!```7````%$$``!0````L00``%0```$%!```5````5T$``!T```!M00``
M)````(M!```A````L$$```,```#200``"P```-9!```+````XD$```H```#N
M00``"P```/E!```(````!4(```@````.0@``$0```!="```(````*4(```L`
M```R0@``.P```#Y"```E````>D(```@```"@0@```@```*E"```-````K$(`
M``T```"Z0@``!0```,A"```'````SD(``!$```#60@```@```.A"```*````
MZT(```4```#V0@``#````/Q"```1````"4,```8````;0P``!0```")#```*
M````*$,```,````S0P``"@```#=#```@````0D,```4```!C0P``"````&E#
M```$````<D,```L```!W0P``"P```(-#```,````CT,```D```"<0P``-```
M`*9#```%````VT,```P```#A0P``#0```.Y#```+````_$,```L````(1```
M#@```!1$```+````(T0```T````O1```#@```#U$```G````3$0```D```!T
M1```!0```'Y$```%````A$0```4```"*1```!0```)!$```$````ED0```D`
M``";1```"0```*5$```+````KT0```8```"[1```#P```,)$```.````TD0`
M``(```#A1```$0```.1$```A````]D0``!4````810``$````"Y%```&````
M/T4```X```!&10``#0```%5%```)````8T4```H```!M10``$````'A%```/
M````B44``$P```"910``!0```.9%```/````[$4``"P```#\10``"P```"E&
M```/````-48```L```!%1@``"P```%%&```A````748```0```!_1@``#0``
M`(1&```C````DD8``!X```"V1@``'@```-5&```9````]$8``"D````.1P``
M*0```#A'```H````8D<``"D```"+1P``#P```+5'```.````Q4<```4```#4
M1P``#@```-I'```:````Z4<``#\````$2```"P```$1(```1````4$@``!<`
M``!B2```$@```'I(```%````C4@``!0```"32```$0```*A(```,````ND@`
M`#````#'2```,@```/A(```,````*TD```0````X20``#0```#U)```/````
M2TD```H```!;20``!@```&9)```8````;4D``!$```"&20``!@```)A)```Z
M````GTD```D```#:20``!@```.1)```I````ZTD```,````52@``"P```!E*
M```#````)4H```0````I2@``"0```"Y*```+````.$H```H```!$2@``%@``
M`$]*```&````9DH``#<```!M2@``,P```*5*```*````V4H```\```#D2@``
M)0```/1*```#````&DL```D````>2P``#````"A+```+````-4L``!P```!!
M2P``-@```%Y+```'````E4L```L```"=2P``'P```*E+```$````R4L```<`
M``#.2P```@```-9+```\````V4L``!<````63```7P```"Y,```K````CDP`
M`#(```"Z3```,0```.U,```P````'TT``!L```!030``&P```&Q-```D````
MB$T``!<```"M30``'@```,5-```K````Y$T``#4````03@``00```$9.``!"
M````B$X``"4```#+3@``0@```/%.```>````-$\``#T```!33P``#P```)%/
M```*````H4\```,```"L3P``#@```+!/```,````OT\``!<```#,3P``$```
M`.1/```.````]4\```<````$4```!@````Q0```?````$U```!@````S4```
M(0```$Q0```,````;E````8```![4```)P```()0```%````JE````X```"P
M4```4````+]0```#````$%$``!P````440``%P```#%1```5````25$``!@`
M``!?40``&0```'A1```7````DE$``"$```"J40``)````,Q1```E````\5$`
M`!@````74@``(P```#!2```0````5%(``"T```!E4@``-@```)-2```8````
MRE(``!X```#C4@``"`````)3```/````"U,```(````;4P``!@```!Y3```"
M````)5,```H````H4P``#0```#-3```!````&P$``#H````?`````@```"D`
M``"B````B@```)D```!A````&````-4```#-````+P```",!``#O````^@``
M`+<````T`````````%,`````````"P$``-@```#"`````````)0````1`0``
M*`$``*4````K`0``70````````#D````P`````<```"]`````````&``````
M`````````+D```"U````6P```((```!7``````````````"3````L@``````
M``!I````9P```#<```!E````+P$``#D````!`0````````````!%````&0$`
M`,,``````````````/D```!.````)@$`````````````H````!,`````````
M`P```"@```"M````````````````````1P```"4!```)`````````,0`````
M`````````,X````4`````````.T`````````[@```.L`````````$@``````
M``#U````)P```'$`````````@P```!`````+````]```````````````X```
M`!\!``"F````HP```#T````>````"````(@```":`````P$``)P```#I````
M%@$``(8`````````;```````````````9@````T```"I````\P```"X`````
M````GP```*<````6````^P```'<```#*````_@```.$```!8````F````!,!
M```4`0````````````"K`````````#P```!M````$0```"H!``"D````D@``
M`-H`````````U````!T!```A`````````!H```!_````.P```(T````V````
M`````"$!``"P`````````-``````````#````+,````C````N````'`````D
M````\````!4!```<`0```````*@```">````B0````````!)````?````)4`
M````````+@$``'4```"\`````````&\```"1``````````````"[````````
M`,<```!Y````4````.,`````````>P```$,````^```````````````2`0``
MW0````D!``"J````A0````````#2`````@$``%X````/````$`$```\!```%
M````>@```,$`````````@0````````!1````'````)T````'`0``*@```&X`
M```B````+`$``.H````&`````````/T````L````Y@``````````````)`$`
M`'8```#\````0````#,```"7````CP````````!"`````````-<`````````
M-0```%0```"V````&0```-X`````````Q0```*X```!J````W`````````!S
M````X@`````````F````V0``````````````FP````P!``!&````1`````0`
M````````H0``````````````6@````@!``````````````````#G````)0``
M`)````#X````Q@`````````Q````Z````%4``````0``````````````````
ML0```/\````$`0```````"L````_````3P`````````M````:P```(L`````
M````4@```*\``````````````!H!````````&P```,\```!!````\@````X!
M``"'````U@```#@```!H````M````-$````-`0``C@```'@```#(````A```
M``````"L````]P```!T````5``````````````#Q````S````"(!````````
M`````$H```!?````%P$``&0`````````]@```#(`````````%P````H```#+
M````N@```````````````````"````"^````TP```+\```!,````R0``````
M``!(````?0````H!`````````````"T!```G`0````````4!```I`0``````
M``````"6````[`````8!````````#@`````````8`0``@````#````#?````
M30```!X!``",````60```.4```!T````8@```$L```!^````````````````
M``````````````!<````8P```-L```!R````(`$``%8``````````"`@("`@
M(%1O.B``("`@($1A=&4Z(``@("`@1G)O;3H@`"!3=6)J96-T.B``(&EN(``C
M`"5D('1O("5D(&]F("5D($UE<W-A9V5S`"5S(&%L<F5A9'D@97AI<W1S+B!9
M;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R
M96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S.B`E<R`H)60F
M;F)S<#MO9B9N8G-P.R5D*0`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V
M92!T;R!N97AT('-C<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R
M971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BD`*%)E='5R;B!T;R!T:&4@
M8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D
M92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I
M;&P@3D]4(&)E(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/
M2R`J`"H@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`$%D9')E<W,@0F]O
M:P!!;&P`06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I
M('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z`$%L;"!M
M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y
M<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D
M96QE=&5D+@!!;G-W97)E9`!!;G-W97)E9"!M97-S86=E<P!!<'!L>2!F:6QT
M97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/P!!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@9&\@=&AI<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!
M3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_`$%R<FEV86P@5&EM
M90!!<V-E;F1I;F<`071T86-H`$%T=&%C:&UE;G0`071T86-H;65N=',`0F%C
M:R!T;R`E<P!"8V,`0FQA8VML:7-T`$)O9'D`0F]T:`!#86YC96P`0V%N8V5L
M($UE<W-A9V4`0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE
M;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RX`0V,`0VAA;F=E`$-H86YG92!!
M;&P`0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE
M<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@
M87)E('-O<G1E9"X`0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG
M;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;"X`0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I
M;`!#:&]O<V4@06-T:6]N.@!#:&]O<V4@82!M86EL('-E<G9E<CH`0VQO<V5D
M($9O;&1E<@!#;VQL87!S92!!;&P`0V]L;&%P<V4@06QL($9O;&1E<G,`0V]L
M;&%P<V4@1F]L9&5R`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W
M:6YD;W<_`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@
M9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET
M(&%R<FEV97,N`$-O<'D`0V]R<F5C=`!#;W)R96-T960@5&5X=`!#<F5A=&4`
M0W)E871E($9O;&1E<@!#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<@!#<F5A
M=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@82!N97<@=')A<V@@
M9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U
M<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@86YD(&1E
M;&5T92!S<&%M+@!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N`$1A=&4`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT
M('-O<G1I;F<@9&ER96-T:6]N.@!$96QE=&4`1&5L971E($9O;&1E<BAS*0!$
M96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M
M;VYT:#\`1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T:6YG(&%N9"!-
M;W9I;F<@365S<V%G97,`1&5S8V5N9&EN9P!$:6T@<VEG;F%T=7)E<S\`1&ES
M<&QA>0!$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_
M`$1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$1O('EO=2!W
M86YT('1O(&]P96X@=&AA="!F;VQD97(_`$1O;F4`1&]W;FQO860@1F]L9&5R
M*',I`$1R869T`$1R869T<R!F;VQD97(Z`$5D:70`161I="!Y;W5R(&9I;'1E
M<B!R=6QE<P!%;6%I;"!!9&1R97-S`$5M<'1Y($9O;&1E<BAS*0!%;7!T>2!4
M<F%S:"!F;VQD97(`16YD(&9O<G=A<F1E9"!M97-S86=E`$5N=&5R('1H92!N
M86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(`17)R;W(`179E<GD@,34@;6EN
M=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H
M86QF(&AO=7(`179E<GD@;6EN=71E`$5X<&%N9"!!;&P`17AP86YD($%L;"!&
M;VQD97)S`$5X<&%N9"!&;VQD97(`17AP86YD($YA;65S`$5X<&%N9"!T:&4@
M96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@
M=FEE=S\`1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/P!&
M:6QT97)S`$9I;F0`1FER<W0@4&%G90!&;VQD97(@3F%V:6=A=&]R`$9O<G=A
M<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&<F]M`$9R
M;VT@061D<F5S<P!&=V0Z`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E
M9`!)3D)/6`!)9VYO<F4`26=N;W)E($%L;`!);7!O<G1A;G0`26UP;W)T86YT
M(&UE<W-A9V5S`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY
M/P!,86YG=6%G90!,87-T(%!A9V4`3&]G(&EN`$QO9R!I;B!T;R`E<P!,;V=I
M;B!487-K<P!-86EL8F]X`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L
M<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`365S<V%G90!-
M97-S86=E($-O;7!O<VET:6]N`$UE<W-A9V4@1&%T90!-97-S86=E(%-E87)C
M:`!-97-S86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!6:65W:6YG
M`$UE<W-A9V4@9FQA9W,`365S<V%G92!F;VQD97)S`$UE<W-A9V5S('!E<B!P
M86=E(&EN('1H92!M86EL8F]X('9I97<N`$UE<W-A9V5S('1O`$UO9&EF>0!-
M;W9E`$YA;64`3F5V97(`3F5W`$YE=R!&;VQD97(`3F5W($UA:6P`3F5W(&UE
M<W-A9V5S`$YE>'0`3F5X="!-97-S86=E`$YE>'0@4&%G90!.;P!.;R!F;VQD
M97)S('=E<F4@<W!E8VEF:65D`$YO('-P96QL8VAE8VMI;F<@<')O9W)A;2!C
M;VYF:6=U<F5D+@!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S=&EO;G,`
M3F]N90!.;W0@1&5L971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@
M4&5R<V]N86P`3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&]R=&%N="!M
M97-S86=E<P!.=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME
M97`@:68@9&5L971I;F<@;6]N=&AL>2X`3TL`3VQD(&UE<W-A9V5S`$]L9"!S
M96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]T:&5R($]P=&EO;G,`
M4&%G92`E9"!O9B`E9`!087)T*',I`%!A<W-W;W)D`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R<V]N86P`4&5R<V]N86P@
M26YF;W)M871I;VX`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI
M97,@86YD(&9O<G=A<F1S/P!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@
M9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.@!0;&5A<V4@<F5S
M;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N`%!L96%S92!S
M96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS
M+@!0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H
M+@!0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R
M871I;VXN`%!R979I;W5S($UE<W-A9V4`4')E=FEO=7,@4&%G90!0<FEN=`!0
M=7)G92!$96QE=&5D`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S
M<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@
M;V8@9&%Y<RX`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I<F5C="!T
M:&ES(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2969R97-H`%)E9G)E
M<V@@1F]L9&5R(%9I97=S.@!296QO860@5FEE=P!296UE;6)E<B!T:&4@;&%S
M="!V:65W`%)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O
M9B!M;VYT:#\`4F5N86UI;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9`!297!L86-E('=I=&@Z`%)E<&QY`%)E
M<&QY('1O($%L;`!297!L>2!T;R!!;&PZ`%)E<&QY+51O.B``4F5P;'DZ`%)E
M<&]R="!A<R!3<&%M`%)E<V5T`%)E<W5M90!2971U<FX@=&\@=&AE(&UA:6QB
M;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG
M(&$@;65S<V%G93\`4V%V92!$<F%F=`!3879E(&%S`%-A=FEN9R!T:&4@9')A
M9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<P!3
M96%R8V@`4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`4V5L96-T(&%L;`!3
M96QE8W0@;F]N90!396YD($UE<W-A9V4`4V5N="!M86EL(&9O;&1E<CH`4V5R
M=F5R`%-E="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U
M(&UO=F4@86YD(&1E;&5T92!M97-S86=E<RX`4VAO=6QD('1H92!C;VUP;W-E
M('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W<@
M1&5L971E9`!3:&]W(%5N<W5B<V-R:6)E9`!3:&]W(&QE9V5N9"!I;B!T:&4@
M;6%I;&)O>"!V:65W/P!3:7IE`%-P96-I86P@0VAA<F%C=&5R<P!3<&5L;"!#
M:&5C:P!3<&5L;"!#:&5C:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL
M:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-U
M8FIE8W0`4W5B:F5C="!&:65L9`!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U
M8V-E<W,`4W5G9V5S=&EO;G,`5&5X=`!4:&4@8W5R<F5N="!F;VQD97(H<RD@
M(B5S(B!W:6QL(&)E(')E;F%M960@=&\@(B5S(BX`5&AE(&9O;&1E<B`B)7,B
M(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!C;VYT86EN<R!I;&QE
M9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S92!P<F]B
M;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4
M:&4@9F]L9&5R("(E<R(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S
M=6)S8W)I8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S(&1E;&5T960@
M8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="X`5&AE(&9O
M;&1E<B`B)7,B('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S(&YO="!D96QE=&5D+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H92!F;VQD97(@(B5S(B!W
M87,@<W5C8V5S<V9U;&QY(&-R96%T960N`%1H92!F;VQD97(@(B5S(B!W87,@
M<W5C8V5S<V9U;&QY(&1E;&5T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C
M8V5S<V9U;&QY(')E;F%M960@=&\@(B5S(BX`5&AE('-I9VYA='5R92!W87,@
M<W5C8V5S<V9U;&QY(')E<&QA8V5D+@!4:&5R92!A<F4@;F\@;65S<V%G97,@
M:6X@=&AI<R!M86EL8F]X+@!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN
M9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@
M82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE
M<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S
M<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S
M<V%G93H@)7,`5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!C;VYT:6YU93\`5&AI<R!M97-S86=E('1O`%1H<F5A
M9"!6:65W`%1O`%1R87-H(&9O;&1E<CH`56YA;G-W97)E9`!5;F%N<W=E<F5D
M(&UE<W-A9V5S`%5N9&5L971E`%5N9&ES8VQO<V5D(%)E8VEP:65N=',`56YN
M86UE9`!5;G-E96X`56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RD`57-E($1E
M9F%U;'0@5F%L=64`57-E($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_`%5S
M97)N86UE`%9I97<@)7,`5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T
M97(@;&]G:6XZ`%=A<FYI;F<`5V5L8V]M92!T;R`E<P!7:&5N(&1E;&5T:6YG
M(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS
M=&5A9"!O9B!M87)K:6YG('1H96T@87,@9&5L971E9#\`665S`%EO=2!A<F4@
M8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+@!9;W4@87)E(&-R96%T
M:6YG(&$@<W5B+69O;&1E<B!T;R``66]U(&%R92!C<F5A=&EN9R!A('1O<"UL
M979E;"!F;VQD97(N`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO
M=2!H879E("5S(&YE=R!M97-S86=E<RX`66]U(&AA=F4@,2!N97<@;65S<V%G
M92X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z
M`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SH`
M66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M
M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@
M870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N`%EO=2!M=7-T('-P96-I9GD@
M82!R96-I<&EE;G0N`%EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N
M($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N
M<W5B<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S
M(@!9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S
M(@!9;W5R('-I9VYA='5R93H`6TYO(%-U8FIE8W1=`&9R;VT`;F]N90!O<@!S
M<&5L;&EN9R!E<G)O<@!S<&5L;&EN9R!E<G)O<G,`4')O:F5C="U)9"U697)S
M:6]N.B!)35`@=C,N,BXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U
M.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP-"TR,2`R,SHR-2LP
M,3`P"DQA<W0M5')A;G-L871O<CH@04P@2&]S;FD@/&%D;6EN0'=A8FAO<W1I
M;F<N8V]M/@I,86YG=6%G92U496%M.B!!<F%B:6,@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M:'1M;#L@8VAA<G-E=#U#4#$R-38*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=`H`("`@("`@Q^'LH#H@`"`@(,?ARL?1[<Z@.B``("`@("#CY*`Z
M(``@(,?AX^;6YMJ@.B``(-WM(`#1WN,`)60@Q^'L("5D(./D("5D(-'3Q^')
M`"5S(./FS.;/R2#CT\C>QRX@X\SASR`E<R#AXR#MRN,@RMOM[='E+@`E<R#A
MQR#MV>71(,?DY2#:Y.;'Y"#(T>W/[2#5Q^'-+@#*XR#*V^WMT2#'T^/'P2`@
M)7,@X\SASR#:Y,\@R,_'[<D@Q^'4Y=$N`"5S.B`E<R`H)60F;F)S<#MD929N
M8G-P.R5D*0`HV,C>(.70Y2#'X<K;[>W1Q\H@YL?DRM[A(,?A["#'X=3'U,D@
MQ^'*Q^'MR2XI`"C>XR#(Q^';Q\$@S./MVB#'X<K;[>W1Q\H@YMK/(,?A["#4
MQ]3)(,?AQ]'3Q^$I`"C:SR#'X>P@U,?4R2#'X<?1T\?A(,C:SR#*V,CMWB#,
MX^W:(,?ARMOM[=''RB#'X>//T<S)(,W*["#'X<+D+B#AY"#MRN,@RMC([=X@
MQ^'*V^WMT<?*(-KA["#'X=3'U,D@Q^'-Q^'MR2XI`"H@Q];=(.70Y2#(Q^'6
MV]@@VN'L(-+1(.3:XR`J`"H@[=',["#'SLKMQ]$@Q^':Y.;'Y"`H(,?AVN3'
MYNWD("D@+B`J`-/,X2#'X=KDQ^;MY`#'X<SC[=H`S./MVB#'X='3Q\;A(,?A
MX^;,YL_)(-WM(,?AX\SASR`HQ^'CS.'/Q\HI(,?ARL?A[<D@T^;=(.W*XR#*
MS>/MX>7'(-WM(-7DS^;>(.;'S<\@Q^'5Y,_FWJ`Z`-_A(,?AT=/'QN$@W>T@
MX\SASR`B)7,B(,?AQ][/XR#CY"`E<R#MYN,@T^;=(.W*XR#(U-_A(,_'QN/'
MX=O'Q.7'+@#?X2#CS.'/Q\H@Q^'1T\?&X2#'X>/1T^')(,?AQ][/XR#CY"`@
M)7,@U.71QR#3YMT@RN';["``RN,@Q^'1SR#:X>WEQP#'X='3Q\;A(,?ARNT@
MRN,@Q^'1SR#:X>WEQP`@WN,@R,K8R.W>(,?AX]'4S<?*(,?+Y,?!(,?AS\[F
MX2"_`.7A(,?DRB#FQ\O>(./D(,?DWR#*T>W/(-W:X2#0X=\@OP#EX2#'Y,H@
MYL?+WB#CY"#1V\C*WR#=[2#'X=O'P2#ET.4@Q^'1T\?&X2#(U-_A(.3EQ\;M
M(+\`Y>$@Q^3*(.;'R]X@X^0@T=O(RM\@W>T@Q]W1Q]L@Y=#'(,?AX\SASR"_
M`.7A(,?DRB#FQ\O>(./D(-';R,K?(-WM(,?=T<?;(./,X<\@T^')(,?AX^7C
MX<?*(+\`YM[*(,?AYM7FX0#*U<?:S^T`Q]'=Q]X`X]'=W@#CT=W>Q\H`Q^':
MYL_)(,?A["`E<P#CT=W>(./.W>T`Q^'>Q\;CR2#'X=/FS\?!`,?AY-4`Q^''
MR^3'Y`#'X=O'P0#'X=O'P2#'X='3Q^')`,?AV\?!(.70Y2#'X='3Q^')(-/F
MW2#MQ,_M(,KAWL?&[<<@Q^'L(,K/X^W1(./-RN;MQ\KEQRX`Y-/.R0#*V^WM
MT0#*V^WMT2#'X<SC[=H`RMOM[=$@SNW'T<?*(,?AVM'6(./+X2#:S\\@Q^'1
MT\?&X2#'X>/:T>;6R2#=[2#?X2#5W<W)(.8@(-_MW>W)(-WET=/)(,?AT=/'
MQN$N`,K;[>W1(,?AQ]/CH2#'X=KDYL?D(*$@YB#'X<KFWNW:(,?AT.T@[=''
MY2#'X<?4SL?5(-KDS^/'(.W>T<?FY"#F("#MT<_FY"#:X>P@T=/'QN'?+@#'
MX<C-RR#=[2#'X>/,X<\@*,?AX\SAS\?**2#:Y"#1T\?&X2#,S^W/R2X`Q\[*
MT2#%S-''P2`Z`,?.RM$@X]+FSR#'X<C1[<\@.@#CS.'/(./;X=X`V.T@Q^',
MX^W:`-CM(,SC[=H@Q^'CS.'/Q\H`V.T@X\SASP#'T=/A(-'3Q^')(-WM(.3'
MW=#)(,S/[<_)(+\`Q^'*S=_C(-WM(.;>RB#'X<C-RR#:Y"#1T\?&X2#,S^W/
MR2"A(.;EX2#MRN,@RN3([>7?(,?C(.''("#:Y,\@YM7A(-'3Q\;A(,S/[<_)
M+@#DT\X`U<WMS0#'X>35(,?AX]7-S0#%Y-3'P0#%Y-3'P2#CS.'/`,?DU,?!
M(./,X<\@X]/FS\?*(,S/[<\`Q>34Q\$@X\SASR#1T\?&X2#CT=/AR2#,S^W/
M`,?DU,?!(./,X<\@X^7CX<?*(,S/[<\`Q>34Q\$@WN;'VL\@W>'*T<D@X<K1
MRNW((,?AR-'MSR#'X>;'T<\@H2#*U>3MW>7'(-WM(,?AX\SAS\?*("#FQ^';
MQ\$@Q^'(T>W/(,?AV^W1(./1V^;(+@#6R-@@X^7'XR#AW^T@RMKCX2#:Y,\@
MQ^'/SN;A("5S+@#'X<K'T>W.`-7MV\D@Q^'=Y='3R2#'X<?=RM''UNW)H#H`
MQ\K,Q^4@Q^'=Y='3R2#'X<?=RM''UNV@.@#'X=O'P0#'X=O'P2#CS.'/("@@
MX\SAS\?*("D`S=#=(./,X<\@Q^'1T\?&X2#'X>/1T^')(,?AWL_MXR#=[2#(
MS\?MR2#'X=3ET2"_`./AV^T`T=/'QN$@X\W0YMW)`,?AV\?!(.;*V^WMT2#C
MYM[:(-'3Q\;A`,KDQ]+A[0#*VLKMXR#'X<KFQ][MVB"_`-K<T=8`VM'6(-'3
MQ^')(./DR,O>R2#AX<?:X<?C(-KD(.;5YN$@T=/'X<D@S,_MS\D@OP#AQR#*
MWN,@R,?AR,W+(-WM(,?AX\SASR`HQ^'CS.'/Q\HI(-KD(,?AT=/'QN$@Q^',
MS^W/R0#EX2#*T>W/(-W*S2#0X=\@Q^'CS.'/(+\`RN,`RLWC[>$@Q^'CS.'/
M("@@Q^'CS.'/Q\H@*0#CT^;/R0#CS.'/(,?AX]/FS\?*H#H`RLW1[=$`RLW1
M[=$@WN;'VL\@Q^'=X<K1R0#:Y.;'Y"#'X<C1[<\@Q^''X=_*T>;D[0#CS.'/
M("@@X\SAS\?**2#=Q]';R0#CS.'/(-/AR2#CY>/AQ\H@W<?1V\D`Q^3EQ\$@
MQ^'1T\?&X2#'X>/-YN')`,?/SN$@Q]/C(./,X<\@Q^'CT^;/Q\H@Q^',S^W/
M`,?/SN$@Q]/C(./,X<\@Q^'1T\?&X2#'X>/1T^')(,?AS,_MSP#'S\[A(,?3
MXR#CS.'/(-/AR2#'X>/EX^''RB#'X<S/[<\`SMC#`-_A(#$U(,_>[=[)`-_A
M(#,P(,O'Y.W)`-_A(#4@S]['QMX`W^$@Y-7=(-/'VLD`W^$@S][MWLD`R-/8
M(,?AW^$`R-/8(,SC[=H@Q^'CS.'/Q\H`R-/8(./,X<\`R-/8(,?AQ]/CQ\$`
MR-/8(-3,T<D@Q^'CS.'/Q\H@Q^'-Q^'MR2#(U-_A(,?=RM''UNT@Q\ODQ\$@
MVM'6(,?AX\SAS\?*(+\`RM'4[<T@Q^'CS<KF[<?*(,?AX<?'SN''WNW)(.'A
MT=/'QN$@OP#'X>/1U,W'R@#,SP#'X=7=S<D@Q^''YN'L`./3RM_4W2#'X>/,
MX<\`RLWF[>$`RLWF[>&@.@#1T\?AR2#CS>;AR2#CY"`E<P#CY`#CY"#'X=KD
MYL?D`./-YN$Z`,?.W<?!(,?AX^';[0#'SMW'P2#'X=OMT2#CU,K1WP#'X>;'
MT<\`RLS'Y>$`RLS'Y>$@Q^'?X0#CY>,`T=/'QN$@X^7CR0#'T=W'WB#'X='3
MQ\;A(,?AQ]7A[<D@VN3/(,?AT<\@OP#'X>';R0#"SM$@U=W-R0#/SN;A`,_.
MYN$@Q^'L("5S`./EQ^,@Q^'/SN;A`-7DS^;>(,?AR-'MSP#:X>/E(-_<H#H`
MVN'C(,?AX]/*YNW'RB#'X>/.RN'=R2#CY"#'X<?>RLC'T\?*(,C'X>;'Y"#C
MSLKAW<D@OP#1T\?AR0#(Y.W)(,?AT=/'X<D`RL?1[<X@Q^'1T\?AR0#(S<L@
MQ^'1T\?AR0#-S.,@Q^'1T\?AR0#CW^;DQ\H@Q^'1T\?AR0#:T=8@Q^'1T\?A
MR0#'VN''XR#'X='3Q^')`./,X<_'RB#'X='3Q^')`-'3Q^')(.'?X2#5W<W)
M(,?+Y,?!(-K1UB#5Y,_FWB#'X='3Q\;A+@#1T\?&X2#'X>P`RMK/[>$`Q^3*
MWN$`Q^''T^,`X]CAWL<`S,_MSP#CS.'/(,S/[<\`R-'MSR#,S^W/`-'3Q\;A
M(,S/[<_)`,?ARL?A[0#'X='3Q^')(,?ARL?A[<D`Q^'5W<W)(,?ARL?A[<D`
MX<<`X>,@[<KC(,K-S^W/(./,X<\`X>,@[<KC(,K:T>W=(,C1Y,?CS"#*S][M
MWB#'X^''QNTN`.''(,KFS,\@Q\[8Q\$@Q^/AQ\;MR0#AQR#*YLS/(,?>RM''
MS<?*`.''(-3MP0#AXR#MRN,@Q^''X=O'P0#AQR#*YLS/(./3YL_)`.'MT\H@
MX^7CY0#A[=/*(-3.U>WE`.'MT\H@T=/'QN$@X^';[<D`X>W3RB#1T\?&X2#C
MY>/)`-K/SR#CS.'/Q\H@Q^'1T\?&X2#'X>/1T^')(,?AWL_MX\D@Q^'*[2#M
MS,@@Q\C>Q\3EQR#=[2#-Q^$@Q^''X=O'P2`@(,?AU.71[2X`X^;'W=X`Q^'1
MT\?&X2#'X=[/[>/)`,KC(,?ARL[AU2#CY"#CS.'/Q\H@Q^'1T\?&X2#'X>/1
MT^')(,?AWL_MX\DN`,[MQ]''RB#'SM'L`,?AU=W-R2`E9"#CY"`E9`#,TL$@
M*,?,TL?!*0#?X>/)(,?AX]'FT0#*W=KMX2#:X^'MQ\H@Q^'5[<?DR2#:Y,\@
MQ^'/SN;A(+\`U,[5[0#CVN'FX\?*(-3.U>W)`.;6VB#*YM[MVM\@WLCA(,?A
MT<_FSR#F(,?ARLWF[>''RB"_`.W1S.P@Q\_.Q^$@Q]/C(.'AX\SASR#'X<S/
M[<^@.@#MT<SL(,?/SL?A(,?3XR#'X>/,X<\@Q^',S^W/H#H`[=',["#'S\['
MX2#'X<?3XR#'X<S/[<^@.@#MT<SL(,WA(,?AQ^'*R,?3(,/F(-K/XR#5X<?-
M[<D@Q^':Y,?F[>0@+@#'X=',Q\$@Q\[MQ]$@X\SASR#>R.$@Q^'4T>;:(-WM
M(,?M(,?,T<?!+@#'X=',Q\$@Q\[*[<?1(./,X<\@YL?-SR#:X>P@Q^''WN$@
MX>'(S<LN`,?AT<S'P2#'SLKMQ]$@X\SASR#FQ\W/(-W>V"#AY=#E(,?AVN/A
M[<DN`,?AT=/'X<D@Q^'3Q\C>R0#'X=7=S<D@Q^'3Q\C>R0#8R,?:R0#*SN'5
M(./D(,?AX^';[0#DV=T@T^')(,?AX^7CX<?*(-_A(-W*T<F@.@#-T-T@Q^'1
MT\?&X2#=[2#CS.'/(-/AR2#'X>/EX^''RB#'X<?>S^,@X^0@Y=#'(,?AVL_/
M(./D(,?AQ^W'XRX`Q]K'S\D@RN;,[>4`Q]K'S\D@RN;,[>4@T=/'X<D`Q]K'
MS\D@RN;,[>4@Y=#E(,?AT=/'X<D`S=[A(,?:Q\_)(,?ARN;,[>4N`,?DVL?4
M`,?DVL?4(-K1UB#'X>/,X<_'RJ`Z`,?:Q\_)(,K-X^WA(,?AVM'6`,K0W]$@
MPL[1(-K1U@#'VL?/R2#*T^/MR2#CS.'/(,?AT=/'QN$@Q^'CT=/AR2#=[2#(
MS\?MR2#'X=3ET;\`Q]K'S\D@RM/C[<D@(B5S(B#'X>P@(B5S(B#-WN$N(.70
MQR#CQR#>Q^'E(,?AX]+FSZ``Q]/*R,_AY2#(W*`Z`,?AT<\`Q^'1SR#:X>P@
MQ^'?X0#'X='/(-KA["#'X=_A(#H`Q^'1SR#:X>R@.@#'X='/H#H`Q\CAVR#:
MY"#1T\?AR2#;[=$@X]';YLC)`,?3RMK'S\D@Q^''W<K1Q];M`,?3RL/DW0#'
MT<S:(,?A["#:T=8@U>3'S^W>(,?AR-'MSR#(VL\@Q^';Q\$@RLWF[>$@Q^8@
MY-/.("#1T\?AR2"_`,W=V2#CT^;/R0#-W=D@W]P`S=W9(,W>X2#'X>/3YL_)
M+B#ET,<@X\<@WL?AY2#'X>/2YL^@.B`E<R``R,W+`.3*Q\;,(,?AR,W+`.39
MT0#'SLK1`,?.RM$@Q^'?X0#'SLK1(.''(-3MP0#'T=/A(-'3Q^')`./,X<\@
MQ^'1T\?&X2#'X>/1T^')H#H`Q^'CTN;/`-;(V"#'X<?/Q\$@X>/'(-/MS<_+
M(-KDS^/'(,K>YN,@R.3>X2#'YB#'X=O'P2`@Q^'1T\?&X2X`Y>$@[<S((,?;
MX<?>(.3'W=#)(,?1T\?A(,?AT=/'QN$@R-K/(,W=V2#'X>/3YL_'RB"_`-K1
MUB#'X>/AV^T`VM'6(-OMT2#'X>/4RM'?`,79Y<?1(,[AW>W'RB#'R\K'P2#:
MT=8@U>3/YMX@Q^'(T>W/(+\`S<SC`-'CYM(@SL?5R0#*S][MWB#%X^''QNT`
MX\_>WB#'X^''QNT`Q^''Y,KEQ\$@X^0@Q^'*S][MWB#'X<?CX<?&[0#:S\\@
MQ^''SMC'P2#'X<?CX<?&[<D@X=_A(-3'U,D@Q\ODQ\$@Q^'*S][MWB#'X<?C
MX<?&[2X`Q^'CYM;FV@#-WN$@Q^'CYM;FV@#'X<?4RM''WR#=[2#'X>/,X<\@
M*"#'X>/,X<_'RB`I`.3,Q\T`X][*T<W'R@#DU0#3YMT@[<KC(,K;[>W1(,?3
MX\?!(,?AX\SASR`HQ^'CS.'/Q\HI(,?AS<?A[<D@(B5S(B#'X>P@(B5S(BX`
MQ^'CS.'/("(E<R(@X^;,YL\@X]/(WL<`Q^'CS.'/("(E<R(@[<S*YNT@VN'L
M(-'CYM(@V^W1(./>R.;AR2#=[2#'T^/E+B#>SR#MQ,_M(-#AWR#'X>P@X]3'
MW^$@Q^'1S,?!(./1Q\S:R2#CS^W1(,?AY-G'XRX`RN,@Q^34Q\$@Q^'CS.'/
M("(E<R(@YN'?Y"#AXR#MRN,@Q]31Q]_?(,CE+@#*XR#'X=O'P2#'X>/,X<\@
M(B5S(B#FX=_D(.'C(.W*XR#'X=O'P2#'U,K1Q]_?(,CE+@#AXR#MRN,@Q^34
MQ\$@Q^'CS.'/("(E<R(@+B#ET,<@X\<@Q]W'SR#(Y2#'X>/2YL^@`.'C(.W*
MXR#'X=O'P2#'X>/,X<\@(B5S(B`N(.70QR#CQR#'W<?/(,CE(,?AX]+FSP#*
MXR#'Y-3'P2#'X>/,X<\@(B5S(B#(Y,S'S2X`RN,@Q^';Q\$@Q^'CS.'/("(E
M<R(@R.3,Q\TN`,KC(,?:Q\_)(,K3X^W)(,?AX\SASR`B)7,B(,?A["`B)7,B
M+@#*XR#*V^WMT2#'X<KFWNW:(,CDS,?-+@#AQR#*YLS/(-'3Q\;A(-WM(-7D
MS^;>(,?AR-'MSRX`Y>3'X=\@X]3?X<D@Y-K8X2`E<RX@Y=#'(./'(,?=Q\\@
MR.4@Q^'CTN;/(`#EY,?AWR#CU-_AR2#*VMCA(-7DS^;>(,?AR-'MSRX@Y=#'
M(./'(,?=Q\\@R.4@Q^'CTN;/H`#EY,?AWR#.V,,@W>T@Q^';Q\$@Q^'1T\?&
MX2#CY"#'X>/,X<\@("(E<R(N(.70QR#CQR#'W<?/(,CE(,?AX]+FSP#EY,?A
MWR#.V,,@W>T@Q^';Q\$@Q^'1T\?&X2#=[2#'X>/,X<\@("(E<R(N(.70QR#C
MQR#'W<?/("#(Y2#'X>/2YL\`Y>3'X=\@SMC#(-WM(-K1UB#ET,<@Q^',TL$@
MX^0@Q^'1T\?AR0#EY,?AWR#.V,,@W>T@RMKA[>,@Q^'1T\?&X2#=[2#'X>/,
MX<\@(B5S(BX@Y=#'(./'(,?=Q\\@(,CE(,?AX]+FSZ``Y>3'X=\@SMC#(-WM
M(,?1T\?A(-'3Q^'*WZ`Z("5S`-[/(.W3RMO1WB#ET,<@R-K6(,?AYM[*+B`@
MY>$@Q^3*(./*Q]_/(./D(-';R,K?(-WM(,?AQ]/*X]''T;\`Y=#E(,?AT=/'
MX<D@Q^'L`-K1UB#*T^'3X>T`Q^'L`-/AR2#'X>/EX^''RJ`Z`.'C(.W1SR#:
MX>WEQP#1T\?&X2#AXR#MRN,@Q^'1SR#:X>WEQP#*T<?,VB#:Y"#'X<?AV\?!
M`./3RN'C[>0@X\[=[>WD`.'C(,K3X^P`X>,@RM'L`,?AV\?!(,?AQ]3*T<??
M(./D(./,X<\@*./,X<_'RBD`Q]/*SL_C(,?AWNWCR2#'X<?=RM''UNW)`,?3
MRL[/XR#'U,K1Q]_'RB#CS.'/(,+M(,?C(,/M(,CMOP#'T^,@Q^'CT\K.S^,`
MVM'6("5S`./9Y=$@Q^8@U>3/YMX@R-'MSR#AX<?9Y<?1(,C:SR#'X<_.YN&@
M.@#*S=#MT0#CT<W(QR#(WR#=[2`E<P#:Y,\@Q^';Q\$@T=/'QN$@H2#>XR#(
MY-[AY<<@Q^'L(./,X<\@T^')(,?AX^7CX<?*(,C/X<<@X^0@RMKA[>/EY"#?
MT=/'QN$@X^';[<D@OP#DVN,`Q^3?(,KDT\XORN3>X2#'X>P@X\SASR#,S^W/
M+@#'Y-\@RM;MW2#CS.'/(-W1VNT@Q^'L(`#'Y-\@RN34[<$@X\SASR#'T\?3
M[2X`Q^3?(,K:[<\@RM/C[<D@Q^'CS.'/H#H@`,KFS,\@X<_MWR`E<R#1T\?A
MR2#,S^W/R2X`X<_MWR#1T\?AR2#FQ\W/R2#,S^W/R2X`X<_MWR#(T>W/(,S/
M[<\@W>T@Q^'CS.'/(,?ARL?A[:`Z`.'/[=\@R-'MSR#,S^W/(-WM(,?AX\SA
MS\?*(,?ARL?A[<F@.@#MS,@@Q^0@RL[*Q]$@U>3/YMX@Q^'(T>W/(,?AY<_=
M(,?FX<<N`.W,R"#'Y"#*SLK'T2#:Y.;'Y"#'YN''+@#MS,@@Q^0@RL[*Q]$@
MT=/'X<D@YL?-S\D@VN'L(,?AQ][A+@#MS,@@RLW/[<\@X]/*X>,N`.'C(,K?
MY"#CU,K1W\<@R-P@(B5S(BX@Y=#'(./'(,?=Q\\@R.4@Q^'CTN;/H`#AXR#M
MRN,@Q^';Q\$@Q]3*T<??WR#CY"`@(B5S(BX@(.70QR#CQR#'W<?/(,CE(,?A
MX]+FSZ``RN,@Q]31Q]_?(,CDS,?-(-WM("`B)7,B`,KC(,?AV\?!(,?4RM''
MW]\@R.3,Q\T@X^0@(B5S(@#*YM[MVM^@.@!;X<<@[>;,SR#CYM;FVET`X^0`
MX<<@U.W!`,/F`,[8PR#'X^''QNT`Q\[8Q\$@Q^/AQ\;MR0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]A<E]362\`
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<V,``P,3<T-C,`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O;&]C86QE+V%R7U-9+TQ#7TU%4U-!1T53+P``````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8P`#`R,3(U,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O87)?4UDO3$-?34534T%'15,O
M:6UP+FUO````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C8P,S``,3`T,3<S-C(W
M-C``,#(R,S<T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-X2!)4`````D@$``!P```"L#```'0(``#P9````````L"$```H`
M``"Q(0``"@```+PA```*````QR$```H```#2(0``!````-TA```!````XB$`
M`!<```#D(0``,@```/PA```I````+R(``#(```!9(@``&P```(PB```N````
MJ"(``#<```#7(@``?`````\C```<````C",``!T```"I(P``"````,<C```%
M````T",```@```#6(P``!P```-\C```,````YR,```,```#T(P``3@```/@C
M``!0````1R0``$(```"8)```'P```-LD```(````^R0``!$````$)0``(P``
M`!8E```A````.B4``#L```!<)0``*P```)@E```Q````Q"4```P```#V)0``
M"0````,F```Y````#28```8```!')@``"@```$XF```+````628``"D```!E
M)@``$0```(\F```*````H28``!8```"L)@``%@```,,F```#````VB8```@`
M``#>)@``"0```.<F```$````\28```0```#V)@``!@```/LF```.`````B<`
M`!4````1)P```@```"<G```*````*B<```8````U)P``"@```#PG``!B````
M1R<``%\```"J)P``'`````HH```.````)R@``!4````V*```-0```$PH``!%
M````@B@``%$```#(*```#````!HI```-````)RD```P````U*0``%````$(I
M```/````5RD```8```!G*0``!P```&XI```F````=BD``%P```"=*0``!```
M`/HI```'````_RD```X````'*@``*0```!8J```&````0"H```T```!'*@``
M&@```%4J```=````<"H``!D```".*@``70```*@J```H````!BL```(````O
M*P``!0```#(K```$````."L``!`````]*P``&0```$XK```:````:"L```8`
M``"#*P``$````(HK```S````FRL```<```#/*P``$````-<K```<````Z"L`
M``H````%+```%````!`L```O````)2P```\```!5+```!P```&4L```/````
M;2P``"@```!]+```(P```*8L```F````RBP``"````#Q+```!````!(M```2
M````%RT```4````J+0``#@```#`M```$````/RT``!8```!$+0``!0```%LM
M```-````82T```\```!O+0``$@```'\M```-````DBT``!4```"@+0``*0``
M`+8M```L````X"T``"@````-+@``-0```#8N```%````;"X``!````!R+@``
M$````(,N```/````E"X```L```"D+@``#P```+`N```,````P"X```\```#-
M+@``"@```-TN```2````Z"X```T```#[+@``#`````DO```]````%B\``!X`
M``!4+P``(0```',O```@````E2\```,```"V+P``)0```+HO```'````X"\`
M``0```#H+P``"@```.TO```0````^"\```<````),```"````!$P```9````
M&C````0````T,```#````#DP```$````1C````0```!+,```#````%`P```1
M````73````0```!O,```#````'0P```*````@3````4```",,```!0```)(P
M```*````F#````\```"C,```!@```+,P```*````NC````D```#%,```$@``
M`,\P```2````XC```!````#U,```)`````8Q```H````*S$```@```!4,0``
M"0```%TQ```0````9S$```8```!X,0``#````'\Q```'````C#$```L```"4
M,0```@```*`Q```'````HS$```@```"K,0``-P```+0Q```/````[#$```H`
M``#\,0``!P````<R```3````#S(```P````C,@``#@```#`R```,````/S(`
M``X```!,,@``#P```%LR```-````:S(```\```!Y,@``)@```(DR```+````
ML#(```8```"\,@``!P```,,R```$````RS(```0```#0,@``!0```-4R```#
M````VS(```H```#?,@``"````.HR```,````\S(```0`````,P``#`````4S
M```)````$C,```(````<,P``,P```!\S```S````4S,``#@```"',P``&0``
M`,`S```Q````VC,``"P````,-```)````#DT```2````7C0```X```!Q-```
M!````(`T```+````A30```D```"1-```#0```)LT```,````J30``!0```"V
M-```%@```,LT```%````XC0``#P```#H-````@```"4U```,````*#4``",`
M```U-0``!P```%DU```1````834```T```!S-0``#0```($U```'````CS4`
M``@```"7-0``'@```*`U```H````OS4```@```#H-0``%````/$U```%````
M!C8``#$````,-@``)P```#XV```H````9C8``!H```"/-@``*````*HV```I
M````TS8``"X```#]-@``-@```"PW```L````8S<``#$```"0-P``$````,(W
M```-````TS<```4```#A-P``$P```.<W```-````^S<``!8````).```/@``
M`"`X```(````7S@``!````!H.```%0```'DX```3````CS@```<```"C.```
M%0```*LX```+````P3@``!8```#-.```"P```.0X```N````\#@``#H````?
M.0``#0```%HY```%````:#D```P```!N.0``#0```'LY```*````B3D```8`
M``"4.0``#@```)LY```%````JCD```8```"P.0``2P```+<Y```*`````SH`
M``<````..@``.0```!8Z```&````4#H```X```!7.@``!````&8Z```&````
M:SH``$,```!R.@``"@```+8Z```+````P3H``!H```#-.@``%P```.@Z```7
M`````#L``!L````8.P``'P```#0[```,````5#L``!,```!A.P``$0```'4[
M```&````ASL``$,```"..P``.0```-([```,````##P``!$````9/```(```
M`"L\```$````3#P``!````!1/```%P```&(\```2````>CP```L```"-/```
M#0```)D\```4````ISP``"\```"\/```!P```.P\```-````]#P``!8````"
M/0``!P```!D]```+````(3T```4````M/0``!````#,]```)````.#T``#,`
M``!"/0``'@```'8]``!U````E3T``#X````+/@``0@```$H^```]````C3X`
M`#T```#+/@``*0````D_```I````,S\``#$```!=/P``*````(\_```F````
MN#\``#X```#?/P``1P```!Y```!7````9D```%4```"^0```+P```!1!``!5
M````1$$``"L```":00``.P```,9!```/`````D(``"$````20@``'````#1"
M```+````44(```4```!=0@```@```&-"```-````9D(```,```!T0@``+P``
M`'A"```@````J$(``"4```#)0@``(````.]"```F````$$,```H````W0P``
M$P```$)#```(````5D,``!8```!?0P``#````'9#```'````@T,```8```"+
M0P``&@```))#```1````K4,``!X```"_0P``#````-Y#```(````ZT,```<`
M``#T0P``!P```/Q#```&````!$0```T````+1```"P```!E$``!:````)40`
M``P```"`1```"@```(U$```"````F$0```8```";1````P```*)$```G````
MID0``"$```#.1```)````/!$```=````%44``!D````S10``%P```$U%```J
M````944``"L```"010``10```+Q%```G`````D8``"$````J1@``*P```$Q&
M```=````>$8``#T```"61@``00```-1&```H````%D<``"P````_1P``,```
M`&Q'```0````G4<``!\```"N1P``#P```,Y'```,````WD<``!````#K1P``
M#P```/Q'```$````#$@```0````12````@```!9(```.````&4@```\````H
M2```!0```#A(``!F`0``/D@```P```"E20``#````+))```*````OTD```P`
M``#*20``!````-=)```#````W$D``!4```#@20``)P```/9)```@````'DH`
M`"@````_2@``&P```&A*```N````A$H``"\```"S2@``:P```.-*```=````
M3TL``"8```!M2P``!P```)1+```,````G$L```D```"I2P``!P```+-+```,
M````NTL```8```#(2P``6@```,]+``!"````*DP``#8```!M3```&````*1,
M```-````O4P``!H```#+3```(@```.9,```1````"4T``#`````;30``)```
M`$Q-```K````<4T```H```"=30``!@```*A-```F````KTT```4```#630``
M!````-Q-```&````X4T``"T```#H30``$````!9.```-````)TX``!\````U
M3@``(0```%5.```)````=TX```L```"!3@``#P```(U.```$````G4X```<`
M``"B3@``!0```*I.```-````L$X``!4```"^3@``!````-1.```-````V4X`
M``4```#G3@``#````.U.``!.````^DX``#(```!)3P``*@```'Q/```,````
MIT\``!(```"T3P``$P```,=/```_````VT\``$(````;4```#0```%Y0```)
M````;%````D```!V4```$````(!0```'````D5````8```"94```!@```*!0
M```;````IU```$\```##4````P```!-1```$````%U$```L````<40``*@``
M`"A1```%````4U$```H```!940``%@```&11```;````>U$``!8```"740``
M60```*Y1```@````"%(```L````I4@``!````#52```'````.E(``!````!"
M4@``&0```%-2```9````;5(```4```"'4@``%0```(U2```P````HU(```0`
M``#44@``#````-E2```7````YE(```8```#^4@``"P````53```<````$5,`
M``\````N4P``!````#Y3```,````0U,``"X```!04P``-0```']3```I````
MM5,``!@```#?4P```@```/A3```9````^U,```4````55```#P```!M4```%
M````*U0``!0````Q5```$0```$94```7````6%0``!0```!P5```%0```(54
M```-````FU0``!4```"I5```'0```+]4```D````W50``"$````"50``*0``
M`"15```#````3E4```L```!250``"P```%Y5```*````:E4```<```!U50``
M"P```'U5```(````B54``!````"250``"````*-5```1````K%4```@```"^
M50``"P```,=5```[````TU4``!\````/5@``'P```"]6```>````3U8```0`
M``!N5@``)P```'-6```(````FU8```(```"D5@``#0```*=6```-````M58`
M``4```##5@``!P```,E6```1````T58```(```#C5@``"@```.96```%````
M\58```@```#W5@``#`````!7```1````#5<```<````?5P``#````"=7```+
M````-%<```4```!`5P``!@```$97```+````35<```\```!95P``!0```&E7
M```*````;U<```,```!Z5P``"@```'Y7```4````B5<``!$```">5P``(```
M`+!7```E````T5<```4```#W5P``"````/U7```5````!E@```0````<6```
M"P```"%8```$````+5@```L````R6```"P```#Y8```,````2E@```H```!7
M6```-````&)8```-````EU@```T```"E6```!0```+-8```,````N5@```T`
M``#&6```"P```-18```+````X%@```X```#L6```"P```/M8```-````!UD`
M``X````560``)P```"19```)````3%D```4```!660``!@```%Q9```%````
M8UD```4```!I60``!0```&]9```$````=5D```D```!Z60``"0```(19```+
M````CED```8```":60``#P```*%9```.````L5D```(```#`60``)P```,-9
M```G````ZUD``"D````36@``$0```#U:```@````3UH``!P```!P6@``(0``
M`(U:```5````KUH``!````#%6@``!@```-9:```.````W5H```T```#L6@``
M"````/I:```*`````UL``!`````.6P``#P```!];```'````+UL``$P````W
M6P``!0```(1;```/````BEL``"P```":6P``!@```,=;```,````SEL```L`
M``#;6P``#P```.=;```+````]UL```L````#7```%`````]<```A````)%P`
M``0```!&7```#0```$M<```$````65P``"4```!>7```'@```(1<```>````
MHUP``!D```#"7```'````-Q<```H````^5P``"D````B70``*@```$Q=```H
M````=UT``"D```"@70``#P```,I=```.````VET```4```#I70``"P```.]=
M```.````^UT``!H````*7@``/P```"5>```+````95X``!$```!Q7@``%P``
M`(->```2````FUX```4```"N7@``%````+1>```1````R5X```P```#;7@``
M#````.A>```P````]5X``#(````F7P``#````%E?```$````9E\```T```!K
M7P``#P```'E?```*````B5\```8```"47P``&````)M?```1````M%\```8`
M``#&7P``.@```,U?```)````"&````8````28```*0```!E@```#````0V``
M``L```!'8````P```%-@```$````5V```#(```!<8```"0```(]@```+````
MF6```!4```"E8```$P```+M@```1````SV```!0```#A8```$@```/9@```*
M````"6$``!@````480``%@```"UA```&````1&$``#<```!+80``,P```(-A
M```*````MV$```\```#"80``)0```-)A```#````^&$```P```#\80``#P``
M``EB```)````&6(```P````C8@``#P```#!B```<````0&(``#8```!=8@``
M!P```)1B```+````G&(``!\```"H8@``!````,AB```'````S6(```<```#5
M8@```@```-UB```&````X&(``#P```#G8@``%P```"1C``!?````/&,``"L`
M``"<8P``,@```,AC```Q````^V,``#`````M9```&P```%YD```;````>F0`
M`"0```"69```%P```+MD```>````TV0``"L```#R9```-0```!YE``!!````
M5&4``$(```"690``)0```-EE``!"````_V4``!X```!"9@``*@```&%F```/
M````C&8``",```"<9@``&P```,!F```*````W&8```4```#G9@```P```.UF
M```.````\68```\`````9P``*P```!!G```=````/&<``!\```!:9P``+@``
M`'IG```B````J6<```P```#,9P``%P```-EG```0````\6<```X````":```
M$@```!%H```'````)&@```8````L:```'P```#-H```8````4V@``!L```!L
M:```#P```(AH```,````F&@```8```"E:```!0```*QH```(````LF@```X`
M``"[:```#0```,IH``!0````V&@```L````I:0``"@```#5I```(````0&D`
M``8```!):0```P```%!I```<````5&D``!<```!Q:0``%0```(EI```8````
MGVD``!D```"X:0``%P```-)I```A````ZFD``"0````,:@``)@```#%J```E
M````6&H``!@```!^:@``(P```)=J```0````NVH``"T```#,:@``-@```/IJ
M```8````,6L``!X```!*:P``+0```&EK```(````EVL``!$```"@:P``"```
M`+)K```/````NVL```\```#+:P``$````-MK```"````[&L```8```#O:P``
M`@```/9K```*````^6L```T````$;```!0```!)L```!`````````#\!```D
M`0``=@$``&(!`````````````.P````O`````````$@```!M`0``Z0````<!
M``!Q`````````'4````F`0```````'8````>`0``V@`````````=````\P``
M`)T```!P````"@```-P```!*````AP```)L````<````4@````<`````````
MD````)H```#[````SP```$,```"0`0```````!X```"2`0``1P```&<!``"+
M````+````(H!``!?`0``7`$``&$```"&````M`````````"/````R```````
M``#P````H@```$,!``!G````!0$``",!````````)P```,(`````````^0``
M``````!N`0``3`$``%8```#J`````````#L`````````)0````````#,````
M%P```&L!``"1````3@$```````!O````%`$``#8```#O`````````%`!``"W
M`````````/<`````````(P```,0```!)`0```````%````!-`0``2@$``-(`
M``"H````U````%D!``"!````-0$``#$!```I`0```````#,!``"S````$@``
M`#4`````````(@``````````````H````!D```#1`````````"`!``![````
M90$``'T````.`0````````,`````````K0````H!```$````10$``!T!``!L
M`0``L@```!(!```0````#0$``"<!``"3````YP```)P```"[````$P$```8`
M````````C0$````````^`0````````````!O`0``B0```&X```"-````>0$`
M`$\!````````=0$``*4````6`0``N@```!\!````````B````'0!``!B````
MF````*,```#>````5````'L!```?````2P````````#*````0`$`````````
M````#````"X```!@````M0```'\!``!>````60```&0!````````6````"$!
M```M````*`````D!``#X```````````````-`````````!@```"D````````
M``````#'````?0$``"H!```P````&@$``.0```#?````!@$``$8!````````
MGP```#$``````````````%0!``!-````*P$``*H```"P````1````'<```!^
M`0``_````#0!````````1P$``!8````9`0``,@$``#X```#C`````````+@`
M``!!`0```````&@!```\`````````&`!``!$`0``[@```"\!````````.@$`
M`/0`````````8P$``)X```"K````Z````.$`````````/`$``(L!``"``0``
M````````````````^@````````"/`0```@$``)(````(`0```````(``````
M````.0$`````````````S@```$````#8````VP````L```#-````50```*<`
M````````O```````````````)@```,8```"6````>`$``,D```#3````A```
M`*P```!3`0``6@$``````````````````"$```"4````-P$``(P`````````
M`````'@```#]````&`$``(8!``"^```````````````%`````````(,`````
M````E0``````````````M@```,L````7`0``(``````!``!R````````````
M``#@````````````````````I@```#0````[`0``3P```'$!```E`0``(@$`
M```````;````*P````````!A`0``W0```$(!```````````````````0`0``
M3````&8```#`````20```#\```"'`0``P0```'P``````````````&,```!J
M````2`$``%T`````````C`$``````````````````#D````P`0``5@$``(4!
M````````:P```(X`````````50$``#T!``"]`````````!0`````````>@``
M`#<```!+`0``@@$``#@````/`0```````-<````;`0````````````!;`0``
M#`$```\````$`0``$P````````!Y````4@$``%$!``#Q``````````````"*
M`````````&4````D````$0$````````J````N0```.(```!T`````````',!
M``!;````U@```.L````L`0``?P```&D```!8`0````````L!``".`0``````
M``X```#5````B0$``!4```!L````D0$``"@!```(````\@```#@!````````
M``````````"A``````````````!R`0``3@```!$````!`0``Y@```*X```"(
M`0``00```((````:````,@```"X!``"Q````]0```'<!```I````40``````
M``!&````Q0```/\`````````_@````````!H````?`$```````!D````A`$`
M`&T`````````/0`````````M`0``6@````````!7`0```````$(`````````
MEP```*D`````````"0```&H!``!3`````````(,!````````7@$``*\````Z
M````,P```%\```"%````9@$``%P```"!`0``5P``````````````'`$```(`
M``#V````>@$``#8!```5`0``````````````````?@````````!%````````
M`&D!``##```````````````#`0``<`$`````````````<P```+\```#9````
M[0````````#E`````````%T!````````T`````````"9`````"`@("`@(%1O
M.B``("`@($1A=&4Z(``@("`@1G)O;3H@`"!3=6)J96-T.B``(&EN(``C`"5D
M('1O("5D(&]F("5D($UE<W-A9V5S`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R
M("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R96YA
M;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S.B`E<R`H)60F;F)S
M<#MO9B9N8G-P.R5D*0`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T
M;R!N97AT('-C<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U
M<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BD`*%)E='5R;B!T;R!T:&4@8V]M
M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T
M:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@
M3D]4(&)E(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J
M`"H@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`#(T(&AO=7)S`$%-+U!-
M`$%D9"!P86ER`$%D9')E<W,`061D<F5S<R!";V]K`$%L;`!!;&P@;65S<V%G
M97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A
M9&5D(&EN=&\@;VYE($U"3U@@9FEL93H`06QL(&UE<W-A9V5S(&EN('EO=7(@
M(B5S(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N
M96YT;'D@9&5L971E9"X`06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N`$%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YS=V5R960`06YS=V5R960@;65S
M<V%G97,`07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\`07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_
M`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L
M9&5R/P!!<G)I=F%L(%1I;64`07-C96YD:6YG`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1A
M8V@`071T86-H;65N=`!!='1A8VAM96YT<P!!=71H96YT:6-A=&EO;B!R96IE
M8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=F%I;&%B;&4@9FEE;&1S.@!"86-K
M('1O("5S`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S
M97)N86UE+@!"8V,`0FER=&AD87D`0FQA8VML:7-T`$)O9'D`0F]T:`!#86YC
M96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-C`$-E
M;&P@4&AO;F4`0VAA;F=E`$-H86YG92!!;&P`0VAA;F=E(&1I<W!L87D@;W!T
M:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C
M:"!P86=E(&%N9"!H;W<@;65S<V%G97,@87)E('-O<G1E9"X`0VAA;F=E('1H
M92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;"X`0VAE
M8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!#:&]O<V4@06-T:6]N.@!#:&]O
M<V4@82!M86EL('-E<G9E<CH`0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@
M=7-E('=H96X@861D:6YG(&%D9')E<W-E<RX`0VAO;W-E('1H92!O<F1E<B!O
M9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R
M97-S97,N`$-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@
M8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H+@!#
M;&]S92!7:6YD;W<`0VQO<V5D($9O;&1E<@!#;VQL87!S92!!;&P`0V]L;&%P
M<V4@06QL($9O;&1E<G,`0V]L;&%P<V4@1F]L9&5R`$-O;6EC<P!#;VUP86YY
M`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_`$-O;G1R
M;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE
M=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O
M<'D`0V]R<F5C=`!#;W)R96-T960@5&5X=`!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#<F5A=&4`0W)E871E($9O;&1E<@!#
M<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@<V5N="!M
M86EL(&9O;&1E<@!#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F
M:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL
M+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$1$`$1A:6QY
M`$1A=&4`1&5F875L="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@8W)I=&5R
M:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T90!$96QE=&4@
M1F]L9&5R*',I`$1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G
M:6YN:6YG(&]F(&UO;G1H/P!$96QE=&5D`$1E;&5T960@;65S<V%G97,`1&5L
M971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$97-C96YD:6YG`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1I;2!S:6=N871U<F5S/P!$:7-P;&%Y`$1I<W!L
M87D@3W!T:6]N<P!$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W
M(&UA:6P_`$1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W
M86YT('1O(&]P96X@=&AA="!F;VQD97(_`$1O;F4`1&]W;FQO860@1F]L9&5R
M*',I`$1R869T`$1R869T<R!F;VQD97(Z`$5D:70`161I="!Y;W5R(&9I;'1E
M<B!R=6QE<P!%;6%I;`!%;6%I;"!!9&1R97-S`$5M<'1Y($9O;&1E<BAS*0!%
M;7!T>2!4<F%S:"!F;VQD97(`16UP='D@<F5S=6QT+@!%;F0@9F]R=V%R9&5D
M(&UE<W-A9V4`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F
M;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F
M;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E
M<@!%;G1R>2`B)7,B('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D
M9')E<W,@8F]O:P!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E
M8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@
M:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X<&%N9"!!;&P`
M17AP86YD($%L;"!&;VQD97)S`$5X<&%N9"!&;VQD97(`17AP86YD($YA;65S
M`$5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@
M=&AE(&9O;&1E<G,@=FEE=S\`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC
M97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@
M=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&87@`1FEL=&5R(&UE<W-A9V4@
M8V]N=&5N="!F;W(@<')O9F%N:71Y/P!&:6QT97)S`$9I;F0`1FER<W0@4&%G
M90!&;VQD97(@3F%V:6=A=&]R`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D
M(&UE<W-A9V4@9G)O;2`E<P!&<F]M`$9R;VT@061D<F5S<P!&=V0Z`$AE;'``
M2&ED92!$96QE=&5D`$AI9&4@56YS=6)S8W)I8F5D`$AO;64`2&]M92!!9&1R
M97-S`$AO;64@4&AO;F4`2&]R9&4`24Y"3U@`26-O;G,@3VYL>0!)8V]N<R!W
M:71H('1E>'0`26=N;W)E`$EG;F]R92!!;&P`26UP;W)T86YT`$EM<&]R=&%N
M="!M97-S86=E<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\`2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!,86YG=6%G90!,
M87-T(%!A9V4`3&ES="!(96QP(%1O<&EC<P!,;V<@:6X`3&]G(&EN('1O("5S
M`$QO9R!O=70`3&]G:6X@5&%S:W,`34T`36%I;&)O>`!-87)K(&%S.@!-87)K
M(&1I9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C
M;VQO<G,_`$UA=&-H:6YG(&9I96QD<P!-96YU(&UO9&4Z`$UE<W-A9V4`365S
M<V%G92!#;VUP;W-I=&EO;@!-97-S86=E($1A=&4`365S<V%G92!396%R8V@`
M365S<V%G92!3:7IE`$UE<W-A9V4@4V]U<F-E`$UE<W-A9V4@5FEE=VEN9P!-
M97-S86=E(&9L86=S`$UE<W-A9V4@9F]L9&5R<P!-97-S86=E<R!P97(@<&%G
M92!I;B!T:&4@;6%I;&)O>"!V:65W+@!-97-S86=E<R!T;P!-;V1I9GD`36]N
M=&AL>0!-;W9E`$YA;64`3F5V97(`3F5W`$YE=R!&;VQD97(`3F5W($UA:6P`
M3F5W(&UE<W-A9V5S`$YE>'0`3F5X="!-97-S86=E`$YE>'0@4&%G90!.;P!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&9O;&1E<G,@=V5R92!S<&5C
M:69I960`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+@!.;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E
M9"X`3F\@<W!E;&QI;F<@97)R;W)S`$YO('-U9V=E<W1I;VYS`$YO;F4`3F]T
M($1E;&5T960`3F]T($1R869T`$YO="!);7!O<G1A;G0`3F]T(%!E<G-O;F%L
M`$YO="!D96QE=&5D(&UE<W-A9V5S`$YO="!I;7!O<G1A;G0@;65S<V%G97,`
M3F]T97,`3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P
M(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$]+`$]L9"!M97-S86=E<P!/;&0@<V5N
M="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D+@!/<'1I;VYS`$]T:&5R($EN
M9F]R;6%T:6]N`$]T:&5R($]P=&EO;G,`4&%G92`E9"!O9B`E9`!087)T*',I
M`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<G-O;F%L
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!L86-E('EO=7(@<VEG;F%T
M=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\`4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@
M;F%M92!O9B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N97<@
M;F%M93H`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N
M`%!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N
M>2!A8W1I;VYS+@!0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@
M=&\@<V5A<F-H+@!0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@
M=&AI<R!O<&5R871I;VXN`%!R979I;W5S($UE<W-A9V4`4')E=FEO=7,@4&%G
M90!0<FEN=`!0<F]B;&5M($1E<V-R:7!T:6]N`%!U<F=E($1E;&5T960`4'5R
M9V4@5')A<V@@:&]W(&]F=&5N.@!0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F
M;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+@!2961I<F5C
M=`!2961I<F5C="!-97-S86=E`%)E9&ER96-T('1H:7,@;65S<V%G90!2961I
M<F5C=&EN9R!F86EL960N`%)E9G)E<V@`4F5F<F5S:"!&;VQD97(@5FEE=W,Z
M`%)E;&]A9"!6:65W`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W9E('!A
M:7(`4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/P!296YA;6EN9R`B)7,B('1O("(E<R(@9F%I;&5D+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED`%)E<&QA8V4@=VET:#H`4F5P;'D`4F5P;'D@
M=&\@06QL`%)E<&QY('1O($%L;#H`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T
M(&%S(%-P86T`4F5S970`4F5S=6UE`%)E='5R;B!T;R!T:&4@;6%I;&)O>"!L
M:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M
M97-S86=E/P!3879E($1R869T`%-A=F4@87,`4V%V:6YG('1H92!D<F%F="!F
M86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%-E87)C
M:`!396%R8V@@4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@861D<F5S<R!B
M;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R
M97-S97,N`%-E;&5C="!A;&P`4V5L96-T(&YO;F4`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!-97-S86=E`%-E
M;F0@4')O8FQE;2!297!O<G0`4V5N="!M86EL(&9O;&1E<CH`4V5R=F5R`%-E
M="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@
M86YD(&1E;&5T92!M97-S86=E<RX`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O
M=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W<@1&5L971E
M9`!3:&]W(%5N<W5B<V-R:6)E9`!3:&]W(&QE9V5N9"!I;B!T:&4@;6%I;&)O
M>"!V:65W/P!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T
M97(@26YP=70`4W!E8VEA;"!#:&%R86-T97)S`%-P96QL($-H96-K`%-P96QL
M($-H96-K97(`4W!E;&P@8VAE8VL@8V]M<&QE=&4`4W!E;&QI;F<@97)R;W)S
M('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RX`4W5B:F5C=`!3=6)J
M96-T($9I96QD`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5C8V5S<P!3=6=G
M97-T:6]N<P!487-K<P!497AT`%1E>'0@3VYL>0!4:&4@8W5R<F5N="!F;VQD
M97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M960@=&\@(B5S(BX`5&AE(&9O;&1E
M<B`B)7,B(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!C;VYT86EN
M<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S
M92!P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+@!4:&4@9F]L9&5R("(E<R(@=V%S(&-R96%T960@8G5T('EO=2!W97)E
M(&YO="!S=6)S8W)I8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S(&1E
M;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="X`
M5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S(&YO="!D96QE
M=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H92!F;VQD97(@
M(B5S(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N`%1H92!F;VQD97(@(B5S
M(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%1H92!F;VQD97(@(B5S(B!W
M87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@(B5S(BX`5&AE('-I9VYA='5R
M92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+@!4:&5R92!A<F4@;F\@;65S
M<V%G97,@:6X@=&AI<R!M86EL8F]X+@!4:&5R92!W87,@82!P<F]B;&5M(&5X
M<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R
M92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T
M:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA9V=I
M;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO
M=7(@;65S<V%G93H@)7,`5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\`5&AI<R!M97-S86=E('1O
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N`%1H<F5A9"!6:65W`%1I=&QE`%1O`%1R87-H
M(&9O;&1E<CH`55),`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA;G-W97)E9`!5;F%N<W=E<F5D
M(&UE<W-A9V5S`%5N9&5L971E`%5N9&ES8VQO<V5D(%)E8VEP:65N=',`56YD
M;R!#:&%N9V5S`%5N;F%M960`56YS965N`%5N<W5B<V-R:6)E(&9R;VT@1F]L
M9&5R*',I`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0(&9O;&1E<B!S=6)S
M8W)I<'1I;VYS/P!5<V5R($]P=&EO;G,`57-E<FYA;64`5FEE=R`E<P!787)N
M:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H96X@9&5L
M971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E
M<B!I;G-T96%D(&]F(&UA<FMI;F<@=&AE;2!A<R!D96QE=&5D/P!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!A<F4@8V]P>6EN
M9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+@!9;W4@87)E(&-R96%T:6YG(&$@
M<W5B+69O;&1E<B!T;R``66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F
M;VQD97(N`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO=2!H879E
M("5S(&YE=R!M97-S86=E<RX`66]U(&AA=F4@,2!N97<@;65S<V%G92X`66]U
M(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z`%EO=2!H
M879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SH`66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!M
M86EL8F]X(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S
M="X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T
M+@!9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+@!9;W4@=V5R92!N;W0@
M<W5B<V-R:6)E9"!T;R`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2`B)7,B+B!(97)E
M(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E('-U8V-E<W-F=6QL
M>2!S=6)S8W)I8F5D('1O("(E<R(`66]U('=E<F4@<W5C8V5S<V9U;&QY('5N
M<W5B<V-R:6)E9"!F<F]M("(E<R(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@26YF;W)M871I;VX`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('-I9VYA='5R93H`
M6TYO(%-U8FIE8W1=`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=
M`&9R;VT`;F]N90!O<@!S<&5L;&EN9R!E<G)O<@!S<&5L;&EN9R!E<G)O<G,`
M=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!)35`@=C,N,BXQ"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P,RTP-"TS,"`Q,CHP,"LP,C`P"DQA<W0M5')A;G-L871O<CH@4&QA
M=&EN=6T@1&5V96QO<&UE;G0@5&5A;2`\9&5V=&5A;4!P;&%T:6YU;2US>2YN
M970^"DQA;F=U86=E+51E86TZ($%R86)I8R`\:3$X;D!L:7-T<RYH;W)D92YO
M<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]H=&UL
M.R!C:&%R<V5T/4-0,3(U-@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET"@`@("`@("#%X>R@.B``("`@Q^'*Q]'MSCH@`"`@("`@X^2@.B``("#'
MX>/FUN;:H#H@`"#=[2``T=[C`"5D(,7A["`E9"#CY"`E9"#1T\?AR0`E<R#C
MYLSFS\D@X]/(WL<N(./,X<\@)7,@X>,@[<KC(,K;[>W1Y2X`)7,@X<<@[=GE
MT2#'Y.4@VN3FQ^0@R-'MS^T@U<?AS2X`RN,@RMOM[=$@P]/CQ\$@("5S(./,
MX<\@VN3/(,C/Q^W)(,?AU.71+@`E<SH@)7,@*"5D)FYB<W`[9&4F;F)S<#LE
M9"D`*-C(WB#ET.4@Q^'*V^WMT<?*(.;'Y,K>X2#%X>P@Q^'4Q]3)(,?ARL?A
M[<DN*0`HWN,@R,7AV\?!(,SC[=H@Q^'*V^WMT<?*(.;:SR#%X>P@U,?4R2#'
MX<71T\?A*0`HVL\@Q>'L(-3'U,D@Q^'%T=/'X2#(VL\@RMC([=X@S./MVB#'
MX<K;[>W1Q\H@Q^'CS]',R2#-RNP@Q^'"Y"X@X>0@[<KC(,K8R.W>(,?ARMOM
M[=''RB#:X>P@Q^'4Q]3)(,?AS<?A[<DN*0`J(,/6W2#ET.4@R,?AUMO8(-KA
M["#2T2#DVN,@*@`J(.W1S.P@Q\[*[<?1(,?AVN3FQ^0@*"#'X=KDQ^;MY"`I
M("X@*@`R-"#3Q]K)`.3EQ]''\"_A[>''\`##UMT@R^3'QNT`Q^':Y.;'Y`#3
MS.$@Q^':Y,?F[>0`Q^',X^W:`,SC[=H@Q^'1T\?&X2#'X>/FS.;/R2#=[2#'
MX>/,X<\@*,?AX\SAS\?**2#'X<K'X>W)(-/FW2#MRN,@RLWC[>'EQR#=[2#5
MY,_FWB#FQ\W/(,?AU>3/YMZ@.@#?X2#'X='3Q\;A(-WM(./,X<\@(B5S(B#'
MX</>S^,@X^0@)7,@[>;C(-/FW2#MRN,@R-3?X2#/Q\;CQ>';Q\3EQRX`W^$@
MX\SAS\?*(,?AT=/'QN$@Q^'CT=/AR2#'X</>S^,@X^0@("5S(-3ET<<@T^;=
M(,KAV^P@`,KC(,K-S^W/(-[MX\D@V^W1(./>R.;AR0#*XR#'X='/(-KA[>7'
M`,?AT=/'QN$@Q^'*[2#*XR#'X='/(-KA[>7'`"#>XR#(RMC([=X@Q^'CT=3-
MQ\H@P\ODQ\$@Q^'/SN;A(+\`RL/?[<\@Q^''T\KCT<?1(+\`(,K#W^W/(,?A
MQ]/*X]''T2#FQ>';Q\$@Y=#E(,?AT=/'QN$@R-3?X2#DY<?&[2"_`"#*P]_M
MSR#'X<?3RN/1Q]$@YL7=T<?;(.70QR#'X>/,X<\@OP`@RL/?[<\@Q^''T\KC
MT<?1(.;%W=''VR#CS.'/(-/AR2#'X>/EX^''RB"_`.;>RB#'X>;5YN$`RM7'
MVL_M`,K#W^W/(,?AV.'((-[(X2#'X<C/P2#(VN/A[<?*(,?AU>W'Y,F_`,71
MW<?>`./1W=X`X]'=WL?*`,KC(-'=UB#'X<K-WMX@X^0@Q^'EYNW)(./D(-[(
MX2#'X>/.S^,@T<?/[>;3+@#'X<W>YN$@Q^'CRN;=T<DZ`,?AVN;/R2#%X>P@
M)7,`W^'CR2#CT>;1(-O(T2#CWLCFX<D@*-_MT<CMT>;3*0#'T^,@Q^'CT\K.
MS^,@V\C1(./>R.;A("C?[='([='FTRD`X]'=WB#CSMWM`.WFXR#'X>/MX<?/
M`,?AWL?&X\D@Q^'3YL_'P0#'X>35`,?AQ\ODQ^0`Q>';Q\$`Q>';Q\$@Q^'1
MT\?AR0#%X=O'P2#'X<CAQ]L@VN0@X]3?X<D`Y-/.R0#'X>7'RMT@Q^',YL?A
M`,K;[>W1`,K;[>W1(,?AS./MV@#*V^WMT2#.[<?1Q\H@Q^':T=8@X\OA(-K/
MSR#'X='3Q\;A(,?AX]K1YM;)(-WM(-_A(-7=S<D@YB`@W^W=[<D@W>71T\D@
MQ^'1T\?&X2X`RMOM[=$@Q^''T^.A(,?AVN3FQ^0@H2#F(,?ARN;>[=H@[='/
MYN0@VN'L(-'3Q\;AWRX`Q^'(S<L@W>T@Q^'CS.'/("C'X>/,X<_'RBD@VN0@
MT=/'QN$@S,_MS\DN`,?.RM$@Q<S1Q\$@.@#'SLK1(./2YL\@Q^'(T>W/(#H`
MQ\[*T2#3S.$@Q^':Y,?F[>0@+@#'SLK1(,?ARM'*[<@@Q^'0[2#*T>W/(,/D
M(.W*XR#'X<C-RR#(Y2#:Y,\@W<K-(-/,X<?*(,?AVN3'YNWD+B``Q^3>T2#:
MX>P@YL?-S\<@X^0@T\SAQ\H@TN;'T=\@Q^'CSLK'T<D@R^,@Q\[*T2#,X^W:
M(,?AS=[FX2`@X>'(S<LN`,7;X<?>(,?AY,?=T,D`X\SASR#CV^'>`-CM(,?A
MS./MV@#8[2#,X^W:(,?AX\SAS\?*`-CM(./,X<\`T=/FX\?*`,?AU-'?R0##
MT=/A(-'3Q^')(-WM(.3'W=#)(,S/[<_)(+\`Q^'*S=_C(-WM(.;>RB#'X<C-
MRR#:Y"#1T\?&X2#,S^W/R2"A(.;EX2#MRN,@RN3([>7?(,/C(.''("#:Y,\@
MYM7A(-'3Q\;A(,S/[<_)+@#DT\X`U<WMS0#'X>35(,?AX]7-S0#AQ\7CW\?D
M[<D@X=W*S2!-86EN=&5N86YC95]487-K(.'AR-'MX\P@)7,`Q>34Q\$`Q>34
MQ\$@X\SASP#%Y-3'P2#CS.'/(./3YL_'RB#,S^W/`,7DU,?!(./,X<\@T=/'
MQN$@X]'3X<D@S,_MSP#%Y-3'P2#CS.'/(./EX^''RB#,S^W/`,7DU,?!(-[F
MQ]K/(,?DRM['P2#ARM'*[<@@Q^'(T>W/(,?AYL?1SR"A(,K5Y.W=Y<<@W>T@
MQ^'CS.'/Q\H@(.;%X=O'P2#'X<C1[<\@Q^';[=$@X]';YL@N`-;(V"#CY<?C
M(.'?[2#*VN/A(-KDSR#'X<_.YN$@)7,N`.WFXR`M(-'>X^WD`.WFX^T`Q^'*
MQ]'MS@#'X<K-WMX@Q^''W<K1Q];M`-7MV\D@Q^'=Y='3R2#'X<?=RM''UNW)
MH#H`Q\K,Q^4@Q^'=Y='3R2#'X<?=RM''UNV@.@#%X=O'P0#%X=O'P2#CS.'/
M("@@X\SAS\?*("D`S=#=(./,X<\@Q^'1T\?&X2#'X>/1T^')(,?AWL_MXR#=
M[2#(S\?MR2#'X=3ET2"_`./AV^T`T=/'QN$@X\W0YMW)`,7AV\?!(.;*V^WM
MT2#CYM[:(-'3Q\;A`,KDQ]+A[0#4T<T@Q^'CU-_AR0#*XR#-W=D@Q^'*W<?5
M[>$@X>//[=$@Q^'DV<?C`,K:RNWC(,?ARN;>[=H@OP#:W-'6`,[MQ]''RB#'
MX=K1U@#:T=8@T=/'X<D@X^3(R][)(.'AQ=KAQ^,@VN0@YM7FX2#1T\?AR2#,
MS^W/R2"_`.''(,K>XR#(Q^'(S<L@W>T@Q^'CS.'/("C'X>/,X<_'RBD@VN0@
MQ^'1T\?&X2#'X<S/[<_)`.''(,K/SN$@X\C'U-')\"#%X>P@Q^'CX=T@;6%I
M;G1E;F%N8V4N<&AP`.7A(,K1[<\@W<K-(-#AWR#'X>/,X<\@OP#*XP#*S>/M
MX2#'X>/,X<\@*"#'X>/,X<_'RB`I`./3YL_)`./,X<\@Q^'CT^;/Q\J@.@#*
MS='MT0#*S='MT2#>YL?:SR#'X<7DRM['P0#'X<C1[<\@Q^'%X=_*T>;D[0#:
MY.;'Y"#'X<C1[<\@Q^''X=_*T>;D[0#CS.'/("@@X\SAS\?**2#=Q]';R0#C
MS.'/(-/AR2#CY>/AQ\H@W<?1V\D`X<?*YLS/(.3*Q\;,+@#%Y.7'P2#'X='3
MQ\;A(,?AX\WFX<D`Q\_.X2#'T^,@X\SASR#'X>/3YL_'RB#'X<S/[<\`Q\_.
MX2#'T^,@X\SASR#'X='3Q\;A(,?AX]'3X<D@Q^',S^W/`,?/SN$@Q]/C(./,
MX<\@T^')(,?AX^7CX<?*(,?AS,_MSP#*XR#%S\['X2#'X=/,X2`B)7,B(,CD
MS,?-(-WM(-/,X2#'X=KDQ^;MY`#.V,,`W^$@,34@S][MWLD`W^$@,S`@R\?D
M[<D`W^$@-2#/WL?&W@#?X2#/SN;A`-_A(.35W2#3Q]K)`-_A(,_>[=[)`,/C
MR^')(-KA["#'X=[MXSH`R-/8(,?AW^$`R-/8(,SC[=H@Q^'CS.'/Q\H`R-/8
M(./,X<\`R-/8(,?AP]/CQ\$`R-/8(-3,T<D@Q^'CS.'/Q\H@Q^'-Q^'MR2#(
MU-_A(,?=RM''UNT@P\ODQ\$@VM'6(,?AX\SAS\?*(+\`X<?%X]_'Y.W)(.'A
MVLOFT2#:X>P@Q^'*W=;MX<?*+@#AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C
M($Q$05`N`.''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@4TU"+@#=Q]_3`,K1
MU.W-(,?AX\W*YNW'RB#'X='3Q\;A(-OMT2#'X</.X<?>[<D@OP#'X>/1U,W'
MR@#,SP#'X=7=S<D@Q^'#YN'L`./3RM_4W2#'X>/,X<\`RLWF[>$`RLWF[>&@
M.@#1T\?AR2#CS>;AR2#CY"`E<P#CY`#CY"#'X=KDYL?D`./-YN$Z`,?AX]/'
MVL_)`,7.W<?!(,?AX^';[0#%SMW'P2#'X=OMT2#CU,K1WP#'X<C/Q^W)`-KD
MYL?D(,?AX^32X0#EQ\K=(,?AX^32X0#EYM'/[0#'X>;'T<\`P^W>YN3'RB#=
MWM@`P^W>YN3'RB#CVB#DU>;5`,K,Q^7A`,K,Q^7A(,?AW^$`X^7C`-'3Q\;A
M(./EX\D`Q^'-WN;A(,?AX]/*YM'/R3H@)7,`Q^'-WN;A(,?AX]/*YM'/R3H`
MQ='=Q]X@Q^'1T\?&X2#'X</5X>W)(-KDSR#'X='/(+\`Q^'CSL_C(-_MT<CM
MT>;3(-'=UB#'X<K-WMX@X^0@Q^'EYNW)+@#'X>';R0#"SM$@U=W-R0#>Q\;C
MR2#:Y,?F[>0@Q^'CT\?:S\D`S\[FX0#/SN;A(,7A["`E<P#.T>;,`./EQ^,@
MQ^'/SN;A`-3ET2`M(-'>X^WD`-7DS^;>(,?AR-'MSP#*VN'MXR#?W*`Z`-KA
MXR#'X>/3RN;MQ\H@Q^'CSLKAW<D@X^0@Q^''WLK(Q]/'RB#(P^'FQ^0@X\[*
MX=W)(+\`X]C'R-[)(,?AS=[FX0#FUMH@Q^'CT-_1Q\HZ`-'3Q^')`,CD[<D@
MQ^'1T\?AR0#*Q]'MSB#'X='3Q^')`,C-RR#'X='3Q^')`,W,XR#'X='3Q^')
M`./?YN3'RB#'X='3Q^')`-K1UB#'X='3Q^')`,/:X<?C(,?AT=/'X<D`X\SA
MS\?*(,?AT=/'X<D`T=/'X<D@X=_A(-7=S<D@P\ODQ\$@VM'6(-7DS^;>(,?A
MT=/'QN$N`-'3Q\;A(,7A[`#*VL_MX0#4Y='MQ_``Q^3*WN$`Q^''T^,`X]CA
MWL<`S,_MSP#CS.'/(,S/[<\`R-'MSR#,S^W/`-'3Q\;A(,S/[<_)`,?ARL?A
M[0#'X='3Q^')(,?ARL?A[<D`Q^'5W<W)(,?ARL?A[<D`X<<`X<?*YLS/(./:
MX>;CQ\H@S>;A(,7:S\?/Q\H@Q^'<($944"!61E,N`.''RN;,SR#CVN'FX\?*
M(,WFX2#%VL_'S\?*(,?AW"!344P@5D93+@#AQ\KFS,\@X]KAYN/'RB#-YN$@
MQ=K/Q\_'RB#CX=W'RB!344P@5D93+@#AXR#MRN,@RLW/[<\@X\SASP#AQ\KF
MS,\@W^'CR2#CT>;1(.'ARLW>WB#?[='([='FTP#AQ\KFS,\@W^'CR2#CT>;1
M(.'ARLW>WB!334(^`.'C(.W*XR#*VM'MW2#(T>3'X\P@RL_>[=X@Q>/AQ\;M
M+@#AQR#*YLS/(,/.V,?!(,7CX<?&[<D`X<<@RN;,SR#'WLK1Q\W'R@#AQR#4
M[<$`X>,@[<KC(,?AQ>';Q\$`X<<@RN;,SR#CT^;/R0#;[=$@X^7CR0#A[=/*
M(-3.U>WE`.'MT\H@T=/'QN$@X^';[<D`X>W3RB#1T\?&X2#CY>/)`./AQ\W9
MQ\H`VL_/(./,X<_'RB#'X='3Q\;A(,?AX]'3X<D@Q^'>S^WCR2#'X<KM(.W,
MR"#%R-['Q.7'(-WM(,W'X2#'X<7AV\?!("`@Q^'4Y='M+@#CYL?=W@#'X='3
MQ\;A(,?AWL_MX\D`RN,@Q^'*SN'5(./D(./,X<_'RB#'X='3Q\;A(,?AX]'3
MX<D@Q^'>S^WCR2X`SNW'T<?*`./:X>;CQ\H@PL[1[`#.[<?1Q\H@P\[1[`#'
MX=7=S<D@)60@X^0@)60`S-+!("C#S-+'P2D`W^'CR2#'X>/1YM$`RN3=[=`@
MVN/A[<?*(,?AU>W'Y,D`RMW:[>$@VN/A[<?*(,?AU>W'Y,D@VN3/(,?AS\[F
MX2"_`-3.U>T`X]KAYN/'RB#4SM7MR0#EQ\K=`,7/T<?,("#*YM[MVM\@WLCA
M(,?AT<_FSR#FQ^'*S>;MX<?*(+\`[=',["#%S\['X2#'T^,@X>'CS.'/(,?A
MS,_MSZ`Z`.W1S.P@Q<_.Q^$@Q]/C(,?AX\SASR#'X<S/[<^@.@#MT<SL(,7/
MSL?A(,?AQ]/C(,?AS,_MSZ`Z`,?AT<S'P2#*TN;MS^3'(./ASM4@Q^'CU-_A
MR2X`Q^'1S,?!(,K2YNW/Y,<@R,?3XR#'X>/3RL[/XR#FW^'CR2#'X=/1+@#M
MT<SL(,WA(,?AQ^'*R,?3(,/F(-K/XR#5X<?-[<D@Q^':Y,?F[>0@+@#'X=',
MQ\$@Q\[*[<?1(./,X<\@WLCA(,?AU-'FVB#=[2##[2#%S-''P2X`Q^'1S,?!
M(,?.RNW'T2#CS.'/(.;'S<\@VN'L(,?AP][A(.'AR,W++@#'X=',Q\$@Q\[*
M[<?1(./,X<\@YL?-SR#=WM@@X>70Y2#'X=KCX>W)+@#'X='3Q^')(,?AT\?(
MWLD`Q^'5W<W)(,?AT\?(WLD`V,C'VLD`U-'-(,?AX]3?X<D`RL[AU2#CY"#'
MX>/AV^T`Y-G=(-/AR2#'X>/EX^''RB#?X2#=RM')H#H`S=#=(,?AT=/'QN$@
MW>T@X\SASR#3X<D@Q^'CY>/AQ\H@Q^'*[2#*T\C>(.70QR#'X=K/SR#CY"#'
MX</MQ^,N`,7:Q\_)(,KFS.WE`,7:Q\_)(,KFS.WE(-'3Q^')`,7:Q\_)(,KF
MS.WE(.70Y2#'X='3Q^')`,W>X2#%VL?/R2#'X<KFS.WE+@#*S<_MRP#*S<_M
MRR#:T=8@Q^'CS.'/Q\J@.@#%VL?/R2#*S>/MX2#'X=K1U@#*T-_1(,+.T2#:
MT=8`Q=+AR2#'X<ODQ\;M`,7:Q\_)(,K3X^W)(./,X<\@Q^'1T\?&X2#'X>/1
MT^')(-WM(,C/Q^W)(,?AU.71OP#%VL?/R2#*T^/MR2`B)7,B(,7A["`B)7,B
M(,W>X2X@Y=#'(./'(-['X>4@Q^'CSL_CH`#'T\K(S^'E(,C<H#H`Q^'1SP#'
MX='/(-KA["#'X=_A`,?AT<\@VN'L(,?AW^$@.@#'X='/(-KA[*`Z`,?AT<^@
M.@#'R.';(-KD(-'3Q^')(-OMT2#CT=OFR,D`Q]/*VL?/R2#'X<?=RM''UNT`
MQ]/*P^3=`,?1S-H@Q>'L(-K1UB#5Y,?/[=X@Q^'(T>W/(,C:SR#%X=O'P2#*
MS>;MX2##YB#DT\X@(-'3Q^')(+\`S=W9(./3YL_)`,W=V2#?W`#-W=D@S=[A
M(,?AX]/FS\DN(.70QR#CQR#>Q^'E(,?AX\[/XZ`Z("5S(`#(S<L`Y,K'QLP@
MQ^'(S<L`Y-G1`,?.RM$`Q\[*T2#CU<_1(-/,X2#'X=KDQ^;MY"#AQ=;'W<D@
MYL?AR,W+("#=[2#'X=KDQ^;MY"X`Q\[*T2#'X=_A`,?.RM$@X<<@U.W!`,?.
MRM$@Q^'=YL?5X2#AX<K'T>W..@#'SLK1(,KDT^W>(,?ARL?1[<XZ`,?.RM$@
MRN33[=X@Q^'FWLHZ`,7.RM$@S=[A[>0@X\KCQ\OA[>0N`,7.RM$@X=O*WR#'
MX>/=UN').@##T=/A(-'3Q^')`,/1T^$@RM[1[=''\"#(X]3?X<D@S=7AR@#C
MS.'/(,?AT=/'QN$@Q^'CT=/AR:`Z`,?AX\[/XP#6R-@@Q^'#S\?!(.'CQR#3
M[<W/RR#:Y,_CQR#*WN;C(,CDWN$@P^8@Q>';Q\$@(,?AT=/'QN$N`.7A(.W,
MR"#%V^''WB#DQ]W0R2#%T=/'X2#'X='3Q\;A(,C:SR#-W=D@Q^'CT^;/Q\H@
MOP#:T=8@Q^'CX=OM`-K1UB#;[=$@Q^'CU,K1WP#%V>7'T<K=T^W1Q\H@P\OD
MQ\$@VM'6(-7DS^;>(,?AR-'MSR"_`,W,XP#%Y>/A(,?AU>W'Y,D`Q<_.Q]$@
MS='FW2#.Q]7)`-'CYM(@SL?5R0#*S][MWB#%X^''QNT`Q^'CS][>(,?AQ>/A
MQ\;M`,?AQ^3*Y<?!(./D(,?ARL_>[=X@Q^'%X^''QNT`VL_/(,?AP\[8Q\$@
MQ^'%X^''QNW)(.'?X2#4Q]3)(,/+Y,?!(,?ARL_>[=X@Q^'%X^''QNTN`,?A
MX^;6YMH`S=[A(,?AX^;6YMH`Q^''U,K1Q]\@W>T@Q^'CS.'/("@@Q^'CS.'/
MQ\H@*0#DS,?-`./>RM'-Q\H`Q^'CY>/'R@#DU0#DU2#=WM@`T^;=(.W*XR#*
MV^WMT2##T^/'P2#'X>/,X<\@*,?AX\SAS\?**2#'X<W'X>W)("(E<R(@Q>'L
M("(E<R(N`,?AX\SASR`B)7,B(./FS.;/(./3R-['`,?AX\SASR`B)7,B(.W-
MRN;M(-KA["#1X^;2(-OMT2#CWLCFX<D@W>T@Q]/CY2X@WL\@[<3/[2#0X=\@
MQ>'L(./4Q]_A(,?AT<S'P2#CT<?,VLD@X\_MT2#'X>39Q^,N`,KC(,7DU,?!
M(,?AX\SASR`B)7,B(.;AW^0@X>,@[<KC(,74T<??WR#(Y2X`RN,@Q>';Q\$@
MQ^'CS.'/("(E<R(@YN'?Y"#AXR#MRN,@Q>';Q\$@Q]3*T<??WR#(Y2X`X>,@
M[<KC(,7DU,?!(,?AX\SASR`B)7,B("X@Y=#'(./'(,/=Q\\@R.4@Q^'CSL_C
MH`#AXR#MRN,@Q>';Q\$@Q^'CS.'/("(E<R(@+B#ET,<@X\<@P]W'SR#(Y2#'
MX>/.S^,`RN,@Q>34Q\$@Q^'CS.'/("(E<R(@R.3,Q\TN`,KC(,7AV\?!(,?A
MX\SASR`B)7,B(,CDS,?-+@#*XR#%VL?/R2#*T^/MR2#'X>/,X<\@(B5S(B#%
MX>P@(B5S(BX`RN,@RMOM[=$@Q^'*YM[MVB#(Y,S'S2X`X<<@RN;,SR#1T\?&
MX2#=[2#5Y,_FWB#'X<C1[<\N`.7DQ^'?(./4W^')(.3:V.$@)7,N(.70QR#C
MQR##W<?/(,CE(,?AX\[/XR``Y>3'X=\@X]3?X<D@RMK8X2#5Y,_FWB#'X<C1
M[<\N(.70QR#CQR##W<?/(,CE(,?AX\[/XZ``Y>3'X=\@SMC#(-WM(,7AV\?!
M(,?AT=/'QN$@X^0@Q^'CS.'/("`B)7,B+B#ET,<@X\<@P]W'SR#(Y2#'X>/.
MS^,`Y>3'X=\@SMC#(-WM(,7AV\?!(,?AT=/'QN$@W>T@Q^'CS.'/("`B)7,B
M+B#ET,<@X\<@P]W'SR`@R.4@Q^'CSL_C`.7DQ^'?(,[8PR#=[2#:T=8@Y=#'
M(,?AS-+!(./D(,?AT=/'X<D`Y>3'X=\@SMC#(-WM(,K:X>WC(,?AT=/'QN$@
MW>T@Q^'CS.'/("(E<R(N(.70QR#CQR##W<?/("#(Y2#'X>/.S^.@`.7DQ^'?
M(,[8PR#=[2#%T=/'X2#1T\?ARM^@.B`E<P#>SR#MT\K;T=X@Y=#'(,C:UB#'
MX>;>RBX@(,K#W^W/(,?AQ]/*X]''T;\`Y=#E(,?AT=/'X<D@Q>'L`.W,R"##
MY"#MW^;D(.70QR#'X='>XR##W\C1(./D(,?AU=W1`.W,R"##Y"#*W^;D(.70
MY2#'X=[MX\D@T=[C+@#:T=8@RM/AT^'M`,?AX=[(`,7A[`#3X<D@Q^'CY>/A
MQ\J@.@#:Y.;'Y"#'X<7DRM'D[<H`X<<@Q>/?Q^3MR2#ARMOM[=$@Q^'3X\?-
M[<?*(.'CX=T@5D93("5S+R5S+@#AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.S^,@
M4U%,+@#AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N`.''(,KFS,\@
MQ>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RX`V^W1(-['
MS]$@VN'L(,K1S./)(./3RN3/(,?AYM'/(.70QP#AXR#MT<\@VN'MY<<`T=/'
MQN$@X>,@[<KC(,?AT<\@VN'MY<<`RM''S-H@VN0@Q^'%X=O'P0#CT\KAX^WD
M(./.W>WMY`#*T<?,VB#:Y"#'X<K;[>W1Q\H`X>,@RM/C[`#AXR#*T>P`Q>';
MQ\$@Q^''U,K1Q]\@X^0@X\SASR`HX\SAS\?**0#'T\K.S^,@Q^'>[>/)(,?A
MQ]W*T<?6[<D`Q]/*SL_C(,?4RM''W\?*(./,X<\@($E-05"_`,[MQ]''RB#'
MX>/3RL[/XP#'T^,@Q^'CT\K.S^,`VM'6("5S`,K-T.W1`,/3R.;:[<?P`./1
MS<C'(,C?(-WM("5S`,/EX<<@YM/EX<<@)7,`VN3/(,7AV\?!(-'3Q\;A(*$@
MWN,@R.3>X>7'(,7A["#CS.'/(-/AR2#'X>/EX^''RB#(S^''(./D(,K:X>WC
MY>0@W]'3Q\;A(./AV^W)(+\`VN3FQ^0@Q^':X^$`Y<?*W2#'X=KCX0#3Y,D@
M+2#7UP#3Y.;MQ_``Y-KC`,?DWR#*Y-/.+\KDWN$@Q>'L(./,X<\@S,_MSRX`
MQ^3?(,K6[=T@X\SASR#=T=KM(,7A["``T^;=("#*Y-3M(./,X<\@P]/'T^TN
M`,?DWR#*VNW/(,K3X^W)(,?AX\SASZ`Z(`#*YLS/(.'/[=\@)7,@T=/'X<D@
MS,_MS\DN`.'/[=\@T=/'X<D@YL?-S\D@S,_MS\DN`.'/[=\@R-'MSR#,S^W/
M(-WM(,?AX\SASR#'X<K'X>V@.@#AS^W?(,C1[<\@S,_MSR#=[2#'X>/,X<_'
MRB#'X<K'X>W)H#H`[<S((-31S2#'X>/4W^')(-[(X2#'T=/'X2#*WM'MT<?P
M(,CEQRX`[<S((,/D(,K.RL?1(-7DS^;>(,?AR-'MSR#'X>7/W2##YN''+@#M
MS,@@P^0@RL[*Q]$@VN3FQ^0@P^;AQRX`[<S((,/D(,K.RL?1(-'3Q^')(.;'
MS<_)(-KA["#'X</>X2X`[<S((,K-S^W/(./3RN'C+@#AXR#*W^0@X]3*T=_'
M(,C<("(E<R(N(.70QR#CQR##W<?/(,CE(,?AX\[/XZ``X>,@[<KC(,7AV\?!
M(,?4RM''W]\@X^0@("(E<R(N("#ET,<@X\<@P]W'SR#(Y2#'X>/.S^.@`,KC
M(,74T<??WR#(Y,S'S2#=[2`@(B5S(@#*XR#%X=O'P2#'U,K1Q]_?(,CDS,?-
M(./D("(E<R(`Q^3*Y<H@U>''S>W)(,?AQ\K5Q^$@)7,N(,?AT<S'P2#%VL?/
MR2#'X<_.YN$N`,CMQ^3'RM\Z`,KC(,K-S^W+(,?ASNW'T<?*`,KFWNW:WZ`Z
M`%OAQR#MYLS/(./FUN;:70!;RM[1[=$@Q^'CU-_AR5T`6\?AT]C1("5S(./D
M("5S70#CY`#AQR#4[<$`P^8`SMC#(,7CX<?&[0##SMC'P2#%X^''QNW)`'9#
M87)D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+V-A7T53+P``````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S8P`#`Q-S0R,``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M;V-A;&4O8V%?15,O3$-?34534T%'15,O````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C``,#(Q,C`U`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]C85]%4R],0U]-15-304=%4R]I;7`N
M;6\````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,C,V-P`Q,#0Q-S,V,C<V,``P
M,C(S-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````!I`0``'````&0+``#G`0``K!8```````!('@``"@```$D>
M```*````5!X```H```!?'@``"@```&H>```$````=1X```$```!Z'@``%P``
M`'P>```H````E!X``#(```"]'@``,@```/`>```;````(Q\``"X````_'P``
M-P```&X?``!\````IA\``!P````C(```'0```$`@```(````7B````4```!G
M(```"````&T@```'````=B````P```!^(```!0```(L@```#````D2```$X`
M``"5(```4````.0@``!"````-2$``!\```!X(0``"````)@A```1````H2$`
M`"$```"S(0``.P```-4A```K````$2(```P````](@``"0```$HB```&````
M5"(```H```!;(@``"P```&8B```1````<B(```H```"$(@```P```(\B```(
M````DR(```D```"<(@``!````*8B```$````JR(```8```"P(@``#@```+<B
M```5````QB(``#X```#<(@```@```!LC```*````'B,```8````I(P``"@``
M`#`C``!B````.R,``%\```">(P``'````/XC```.````&R0```P````J)```
M#0```#<D```,````120``!0```!2)```#P```&<D```'````=R0``%P```!_
M)```!````-PD```'````X20```X```#I)```*0```/@D```&````(B4```T`
M```I)0``&@```#<E```=````4B4``!D```!P)0``70```(HE```H````Z"4`
M``(````1)@``!0```!0F```$````&B8``!`````?)@``&0```#`F```:````
M2B8```8```!E)@``$````&PF```'````?28``!````"%)@``'````)8F```*
M````LR8``!0```"^)@``+P```-,F```/`````R<```<````3)P``#P```!LG
M```C````*R<``"8```!/)P``(````'8G```$````ER<``!(```"<)P``!0``
M`*\G```.````M2<```0```#$)P``%@```,DG```%````X"<```T```#F)P``
M#P```/0G```2````!"@```T````7*```%0```"4H```I````.R@``"P```!E
M*```*````)(H```%````NR@``!````#!*```$````-(H```/````XR@```L`
M``#S*```#P```/\H```,````#RD```\````<*0``"@```"PI```2````-RD`
M``T```!**0``#````%@I```>````92D``"$```"$*0```P```*8I```'````
MJBD```0```"R*0``"@```+<I```0````PBD```<```#3*0``"````-LI```9
M````Y"D```0```#^*0``#`````,J```$````$"H```0````5*@``#````!HJ
M```1````)RH```P````Y*@``"@```$8J```%````42H```4```!7*@``!@``
M`%TJ```*````9"H```D```!O*@``$@```'DJ```2````C"H``!````"?*@``
M)````+`J```(````U2H```D```#>*@``$````.@J```&````^2H```P`````
M*P``!P````TK```+````%2L```(````A*P``!P```"0K```(````+"L``#<`
M```U*P``#P```&TK```'````?2L``!,```"%*P``#````)DK```.````IBL`
M``P```"U*P``#@```,(K```/````T2L```T```#A*P``#P```.\K```F````
M_RL```L````F+```!@```#(L```'````.2P```0```!!+```!````$8L```%
M````2RP```,```!1+```"````%4L```,````7BP```0```!K+```#````'`L
M```)````?2P```(```"'+```&0```(HL```2````I"P```X```"W+```!```
M`,8L```+````RRP```D```#7+```#0```.$L```,````[RP``!0```#\+```
M%@```!$M```%````*"T```(````N+0``#````#$M```C````/BT```<```!B
M+0``$0```&HM```-````?"T```T```"*+0``!P```)@M```(````H"T``!X`
M``"I+0``"````,@M```4````T2T```4```#F+0``,0```.PM```H````'BX`
M`!H```!'+@``*````&(N```I````BRX``"X```"U+@``-@```.0N```L````
M&R\``#$```!(+P``$````'HO```-````BR\```4```"9+P``$P```)\O```-
M````LR\``!8```#!+P``"````-@O```0````X2\``!4```#R+P``$P````@P
M```'````'#```!4````D,```"P```#HP```6````1C````L```!=,```.@``
M`&DP```-````I#````4```"R,```#````+@P```-````Q3````H```#3,```
M!@```-XP```.````Y3````4```#T,```!@```/HP``!+`````3$```H```!-
M,0``!P```%@Q```Y````8#$```8```":,0``#@```*$Q```$````L#$```8`
M``"U,0``"@```+PQ```+````QS$``!H```#3,0``%P```.XQ```7````!C(`
M`!L````>,@``'P```#HR```,````6C(``!,```!G,@``$0```'LR```&````
MC3(``$,```"4,@``.0```-@R```,````$C,``!$````?,P``!````#$S```0
M````-C,``!<```!',P``$@```%\S```+````<C,```T```!^,P``%````(PS
M```O````H3,```<```#1,P``#0```-DS```6````YS,```<```#^,P``"P``
M``8T```%````$C0```0````8-```,P```!TT```>````430``'4```!P-```
M/@```.8T``!"````)34``#T```!H-0``/0```*8U```I````Y#4``"D````.
M-@``,0```#@V```H````:C8``"8```"3-@``/@```+HV``!'````^38``%<`
M``!!-P``50```)DW```O````[S<``%4````?.```*P```'4X```[````H3@`
M``\```#=.```(0```.TX```<````#SD```L````L.0``!0```#@Y```"````
M/CD```T```!!.0```P```$\Y```@````4SD``"8```!T.0``"@```)LY```3
M````ICD```@```"Z.0``%@```,,Y```,````VCD```<```#G.0``!@```.\Y
M```:````]CD``!$````1.@``#````",Z```(````,#H```<````Y.@``)P``
M`$$Z```'````:3H```8```!Q.@``#0```'@Z```+````ACH```P```"2.@``
M"@```)\Z```"````JCH```8```"M.@```P```+0Z```A````N#H``"0```#:
M.@``'0```/\Z```9````'3L``!<````W.P``*@```$\[```K````>CL``$4`
M``"F.P``)P```.P[```A````%#P``"L````V/```'0```&(\```]````@#P`
M`$$```"^/```*``````]```L````*3T``#````!6/0``$````(<]```?````
MF#T```\```"X/0``#````,@]```0````U3T```\```#F/0``!````/8]```$
M````^ST```(`````/@``#@````,^```/````$CX```4````B/@``70$``"@^
M```+````AC\```D```"2/P``"@```)P_```+````IS\```,```"S/P```0``
M`+<_```8````N3\``"H```#2/P``-0```/T_```L````,T```!L```!@0```
M-````'Q````^````L4```(8```#P0```(@```'=!```I````FD$```@```#$
M00``!0```,U!```-````TT$```8```#A00``$@```.A!```%````^T$```0`
M```!0@``4@````9"``!J````64(``$\```#$0@``(P```!1#```)````.$,`
M`!0```!"0P``(0```%=#``!!````>4,``"\```"[0P``$P```.M#```)````
M_T,```@````)1```#@```!)$```(````(40``!(````J1```"P```#U$```#
M````240```H```!-1```#````%A$```$````940```8```!J1```"@```'%$
M```3````?$0``!(```"01```1P```*-$```"````ZT0``!$```#N1```!P``
M``!%```-````"$4``'D````610``?@```)!%```C````#T8```\````S1@``
M#P```$-&```0````4T8``!````!D1@``'0```'5&```2````DT8```D```"F
M1@``30```+!&```&````_D8```@````%1P``#0````Y'```P````'$<```4`
M``!-1P``#0```%-'```C````84<``"<```"%1P``*````*U'``!E````UD<`
M`#T````\2````@```'I(```*````?4@```0```"(2```&````(U(```E````
MID@``"(```#,2```"````.](```4````^$@```D````-20``$P```!=)```<
M````*TD```H```!(20``%P```%-)```W````:TD``!0```"C20``"P```+A)
M```7````Q$D``"8```#<20``*`````-*```@````+$H```8```!-2@``%P``
M`%1*```)````;$H``!4```!V2@``!@```(Q*```8````DTH```4```"L2@``
M$@```+)*```2````Q4H``!H```#82@``#@```/-*```8`````DL``#`````;
M2P``-````$Q+```O````@4L```4```"Q2P``#@```+=+```.````QDL```T`
M``#52P``%````.-+```/````^$L```H````(3```$@```!-,```)````)DP`
M`!L````P3```$````$Q,```-````74P``"4```!K3```*0```)%,```#````
MNTP```<```"_3```!@```,=,```.````SDP``!4```#=3```"````/-,```(
M````_$P``!<````%30```@```!U-```4````($T```0````U30``!0```#I-
M```1````0$T``!,```!230``$0```&9-```2````>$T```4```"+30``!0``
M`)%-```'````ETT```T```"?30``"0```*U-```4````MTT``!$```#,30``
M$````-Y-```J````[TT```8````:3@``#@```"%.```5````,$X```8```!&
M3@``"P```$U.```0````64X``!D```!J3@```@```(1.```&````ATX```L`
M``".3@``.````)I.```3````TTX```@```#G3@``$0```/!.```5`````D\`
M`!(````83P``%P```"M/```$````0T\``!@```!(3P``%0```&%/```5````
M=T\``"T```"-3P``"P```+M/```)````QT\```L```#13P``!0```-U/```#
M````XT\```,```#G3P```P```.M/```*````[T\```X```#Z3P``!P````E0
M```0````$5````X````B4````@```#%0```=````-%```!P```!24```%0``
M`&]0```#````A5````L```")4```#````)50```,````HE````L```"O4```
M%@```+M0```7````TE````4```#J4````@```/!0```0````\U```"0````$
M40``!P```"E1```0````,5$```X```!"40``#P```%%1```'````85$```L`
M``!I40``(P```'51```(````F5$``!,```"B40``!P```+91``!9````OE$`
M`#`````84@``%@```$E2```O````8%(``#T```"04@``0P```,Y2```U````
M$E,``#T```!(4P``,P```(93```1````NE,```\```#,4P``"````-Q3```7
M````Y5,```\```#]4P``)P````U4```)````-50``!(````_5```&0```%)4
M```>````;%0```D```"+5```&P```)54```0````L50``!D```#"5```#0``
M`-Q4``!%````ZE0```\````P50``"0```$!5```0````2E4``!$```!;50``
M#0```&U5```*````>U4``!$```"&50``!P```)A5```)````H%4``$X```"J
M50``#P```/E5```)````"58``$4````35@``!@```%E6```5````8%8```0`
M``!V5@``"P```'M6```0````AU8```\```"85@``)@```*A6```A````SU8`
M`"````#Q5@``)P```!)7```F````.E<```\```!A5P``#@```'%7```;````
M@%<```@```"<5P``3````*57``!&````\E<``!$````Y6```$P```$M8```&
M````7U@``!(```!F6```'@```'E8```3````F%@``!8```"L6```%@```,-8
M```=````VE@``#,```#X6```"````"Q9```,````-5D``!T```!"60``!```
M`&!9```,````95D```8```!R60``!````'E9```V````?ED``!L```"U60``
MAP```-%9```^````65H``$,```"86@``10```-Q:``!$````(EL``#(```!G
M6P``-0```)I;```]````T%L``"\````.7```)0```#Y<``!'````9%P``$T`
M``"L7```8````/I<``!D````6UT``#T```#`70``7````/Y=```U````6UX`
M`#T```"17@``$0```,]>```I````X5X``"$````+7P``#0```"U?```%````
M.U\```4```!!7P``$0```$=?```#````65\``"H```!=7P``+@```(A?```/
M````MU\``!D```#'7P``"0```.%?```7````ZU\```T````#8```"0```!%@
M```'````&V```"0````C8```&P```$A@```0````9&````P```!U8```"```
M`()@```W````BV````0```##8```#````,A@```/````U6````T```#E8```
M$@```/-@```3````!F$```(````:80``"0```!UA```"````)V$``!\````J
M80``+````$IA```=````=V$``!@```"580``%0```*YA```F````Q&$``"D`
M``#K80``0P```!5B```N````66(``"4```"(8@``,0```*YB```R````X&(`
M`#\````38P``0@```%-C```K````EF,``"X```#"8P``1P```/%C```4````
M.60``"0```!.9```%````'-D```0````B&0``!8```"99```$````+!D```"
M````P60```,```#$9````0```,AD```2````RF0``!,```#=9```!0```/%D
M```!````/0$```````!)`0``]@````````!O````.`$```8````A`0``/`$`
M```````F`0``H`````````#;````W0```!````"O````"`$``/\````"`0``
MEP```%X!````````90````````"?````:````'4``````````````(`````P
M`0``*@````<`````````%P```"<!``!+`0```````+8```!>````[@```(H`
M```.`0``+@$``&``````````.@$``-D```"-````'0$```D!``!-`0``````
M```````-````W@``````````````````````````````!0$``"@!````````
M7`$``!H```">````3P$``.$```!#````*0```%H!``!C`0``/`````P!```_
M````+P$```````#*````8P```)4```#B````,````,P````^`0``P````%`!
M``!``0``QP```#L``````````````%(```!:`````````*$````B````R```
M`````````````````&(```"2````2`$``!,```!T````'@````````"Q````
M?0```!\```!I````(0```'(```!=`````````!(!````````````````````
M````N0```!P!```T`0``BP`````````S`0``Q0```+T```!)````[```````
M``"K``````````````!B`0```````'<```!$`````````)$```#Q````>P``
M`)L````K````F0```+4```!$`0``'0```#\!``#Z`````````.<```!?````
M?@``````````````IP```+\`````````&0````````!,`0``H@```+L```!E
M`0``U@```$H!``"S````!````%@````I`0``I````$,!``#!````5P``````
M``"8````4P```$P````C`0``@P```$H`````````60$``)T```"I````&P``
M``0!```J`0``<0`````````W````0@$``#(````+`0```````/0````B`0``
MRP`````````Q`0``"0```(\```!'``````````````!6`0``S0```%L!```V
M````B````#4````9`0``)`$``+0```!@`0````````,!```S````%P$`````
M```Z````:P`````````````````````````0`0``%@```"T`````````````
M```````Y`0``>````&P`````````Y@````H!```U`0``(P```*T````Y````
M*P$``,(``````````````#X````,````+````$\`````````XP```$````!5
M````W````%,!``!1````6P```+<```!!`0``A0````````#0````+P``````
M```>`0``U0```!\!```T````I0```+(```!8`0``<`````\````]````1P$`
M`-@```!D`0``!0```,X```"!`````P````````!D````"````&@!``!4`0``
MA``````````3`0``[P```%````"L````DP```/(````````````````````5
M````>@```-0``````````````"`!``!S````````````````````PP```$T`
M``""````%0$``%$!```;`0``+0$``&$```":`````````"8`````````Z0``
M`*H`````````50$``-$```#@````!P$``)8```!N````Z@```)0````"````
MN@```-<```"H`````0$```````"\````\````(<`````````]0`````````-
M`0``%@$``(X````<````^0```"P!`````````````$8```!7`0```````"``
M````````K@```&$!````````^P```,0`````````*````%\!```4`0``,0``
M`'\`````````9P$``%T!```8`0``3@$````````+`````````.4```#/````
M5`````````!%`0``N````$$```#]``````````8!```V`0``9P```"4!````
M`````````+````!F````:0$```````"0````_`````X`````````?````"<`
M``!Y````````````````````:@``````````````````````````````4@$`
M``````!"````^```````````````A@```.@`````````Q@````````!+````
M`````.T```!F`0``&@$``/X```"C````10```'8```"^````I@```"X```#S
M````````````````````5@```!$``````0``.P$``$8!``")`````````(P`
M````````$@``````````````"@```$X`````````&```````````````````
M`-H```#)````.````!0`````````;0```.L```#W````60```!$!````````
MT@```)P````E````2````.0```#3``````````\!````````)````-\````R
M`0``-P$``%P``````````"`@("`@(%1O.B``("`@($1A=&4Z(``@("`@1G)O
M;3H@`"!3=6)J96-T.B``(&EN(``C`"5D('1O("5D(&]F("5D($UE<W-A9V5S
M`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@
M86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE
M9"X`)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H
M92!M;VYT:"X`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!<'!L>2!T
M:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A
M<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E
M96XN*0`H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L
M>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T
M:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"H@061D
M('1H97-E(&)Y(&-L:6-K:6YG($]+("H`*B!0;&5A<V4@<V5L96-T(&%D9')E
M<W,H97,I("H`,C0@:&]U<G,`04TO4$T`061D('!A:7(`061D<F5S<P!!9&1R
M97-S($)O;VL`06QI87,`06QL`$%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W
M:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/
M6"!F:6QE.@!!;&P@;65S<V%G97,@:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E
M<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2!D96QE=&5D+@!!
M;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@
M;VQD('=I;&P@8F4@9&5L971E9"X`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!;G-W97)E9`!!;G-W97)E9"!M97-S86=E<P!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/P!!<G)I=F%L
M(%1I;64`07-C96YD:6YG`$%T=&%C:`!!='1A8VAM96YT`$%T=&%C:&UE;G1S
M`$%V86EL86)L92!F:65L9',Z`$)A8VL@=&\@)7,`0F-C`$)I<G1H9&%Y`$)L
M86-K;&ES=`!";V1Y`$)O=&@`0V%N8V5L`$-A;F-E;"!-97-S86=E`$-A;F-E
M;"!0<F]B;&5M(%)E<&]R=`!#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL
M('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+@!#8P!#96QL(%!H
M;VYE`$-H86YG90!#:&%N9V4@06QL`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@
M<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G
M92!A;F0@:&]W(&UE<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!T:&4@;F%M
M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6PN`$-H96-K($9O
M;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAO;W-E($%C=&EO;CH`0VQO<V4@5VEN
M9&]W`$-L;W-E9"!&;VQD97(`0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&
M;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VUP86YY`$-O;G1R;VP@=VAE;B!N
M97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N
M;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O<'D`0V]R<F5C
M=`!#;W)R96-T960@5&5X=`!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#<F5A=&4`0W)E871E($9O;&1E<@!#<F5A=&4@82!N
M97<@9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E
M<@!#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@
M<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET
M(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$1$`$1A:6QY`$1A=&4`1&5F
M875L="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U
M;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T90!$96QE=&4@1F]L9&5R*',I
M`$1E;&5T960`1&5L971E9"!M97-S86=E<P!$96QE=&EN9R!A;F0@36]V:6YG
M($UE<W-A9V5S`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&EM('-I9VYA='5R97,_`$1I<W!L87D`1&ES<&QA>2!/<'1I;VYS`$1O($YO
M="!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT('1O(&]P96X@
M=&AA="!F;VQD97(_`$1O;F4`1&]W;FQO860@1F]L9&5R*',I`$1R869T`$1R
M869T<R!F;VQD97(Z`$5D:70`161I="!Y;W5R(&9I;'1E<B!R=6QE<P!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M<'1Y($9O;&1E<BAS*0!%;7!T>2!4<F%S:"!F
M;VQD97(`16UP='D@<F5S=6QT+@!%;F0@9F]R=V%R9&5D(&UE<W-A9V4`16YT
M97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(`16YT97(@
M=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(`16YT97(@
M=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<@!%<G)O<@!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S
M`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA
M;7!L92!V86QU97,Z`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S`$5X
M<&%N9"!&;VQD97(`17AP86YD($YA;65S`$9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M1F%X`$9I;'1E<G,`1FEN9`!&:7)S="!086=E`$9O;&1E<B!.879I9V%T;W(`
M1F]R=V%R9`!&;W)W87)D.@!&;W)W87)D960@;65S<V%G92!F<F]M("5S`$9R
M;VT`1G)O;2!!9&1R97-S`$9W9#H`2&5L<`!(:61E($1E;&5T960`2&ED92!5
M;G-U8G-C<FEB960`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`24Y"
M3U@`26=N;W)E`$EG;F]R92!!;&P`26UP;W)T86YT`$EM<&]R=&%N="!M97-S
M86=E<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F-L
M=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\`3&%N9W5A9V4`3&%S
M="!086=E`$QI<W0@2&5L<"!4;W!I8W,`3&]G(&EN`$QO9R!I;B!T;R`E<P!,
M;V<@;W5T`$QO9VEN(%1A<VMS`$U-`$UA:6QB;W@`36%R:R!A<SH`36%R:R!D
M:69F97)E;G0@;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L
M;W)S/P!-871C:&EN9R!F:65L9',`365S<V%G90!-97-S86=E($-O;7!O<VET
M:6]N`$UE<W-A9V4@1&%T90!-97-S86=E(%-E87)C:`!-97-S86=E(%-I>F4`
M365S<V%G92!3;W5R8V4`365S<V%G92!6:65W:6YG`$UE<W-A9V4@9FQA9W,`
M365S<V%G92!F;VQD97)S`$UE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL
M8F]X('9I97<N`$UE<W-A9V5S('1O`$UO9&EF>0!-;VYT:&QY`$UO=F4`3F%M
M90!.979E<@!.97<`3F5W($UA:6P`3F5W(&UE<W-A9V5S`$YE>'0`3F5X="!-
M97-S86=E`$YE>'0@4&%G90!.;P!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D
M`$YO('-P96QL:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N<P!.;VYE`$YO="!$
M96QE=&5D`$YO="!$<F%F=`!.;W0@26UP;W)T86YT`$YO="!097)S;VYA;`!.
M;W0@9&5L971E9"!M97-S86=E<P!.;W0@:6UP;W)T86YT(&UE<W-A9V5S`$YO
M=&5S`$]+`$]L9"!M97-S86=E<P!/;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I
M;F<@<'5R9V5D+@!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P
M=&EO;G,`4&%G92`E9"!O9B`E9`!087)T*',I`%!A<W-W;W)D`%!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)S;VYA;`!097)S;VYA;"!);F9O
M<FUA=&EO;@!0:&]N90!0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P
M;&EE<R!A;F0@9F]R=V%R9',_`%!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T
M:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N97<@;F%M93H`4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5S
M;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N`%!L96%S92!S
M96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS
M+@!0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H
M+@!0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R
M871I;VXN`%!R979I;W5S($UE<W-A9V4`4')E=FEO=7,@4&%G90!0<FEN=`!0
M<F]B;&5M($1E<V-R:7!T:6]N`%!U<F=E($1E;&5T960`4'5R9V4@5')A<V@@
M:&]W(&]F=&5N.@!2961I<F5C=`!2961I<F5C="!-97-S86=E`%)E9&ER96-T
M('1H:7,@;65S<V%G90!2961I<F5C=&EN9R!F86EL960N`%)E9G)E<V@`4F5F
M<F5S:"!&;VQD97(@5FEE=W,Z`%)E;&]A9"!6:65W`%)E;65M8F5R('1H92!L
M87-T('9I97<`4F5M;W9E('!A:7(`4F5N86UI;F<@(B5S(B!T;R`B)7,B(&9A
M:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!297!L86-E('=I
M=&@Z`%)E<&QY`%)E<&QY('1O($%L;`!297!L>2!T;R!!;&PZ`%)E<&QY+51O
M.B``4F5P;'DZ`%)E<&]R="!A<R!3<&%M`%)E<V5T`%)E<W5M90!2971U<FX@
M=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG
M+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\`4V%V92!$<F%F=`!3879E(&%S`%-A
M=FEN9R!T:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B`E<P!396%R8V@`4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`
M4V5L96-T(&%L;`!396QE8W0@;F]N90!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD($UE<W-A9V4`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!396YT(&UA:6P@9F]L9&5R.@!397)V97(`4V5T('!R969E
M<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L
M971E(&UE<W-A9V5S+@!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L
M;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=R!$96QE=&5D`%-H;W<@
M56YS=6)S8W)I8F5D`%-I>F4`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H
M87)A8W1E<B!);G!U=`!3<&5C:6%L($-H87)A8W1E<G,`4W!E;&P@0VAE8VL`
M4W!E;&P@0VAE8VME<@!3<&5L;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E
M<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+@!3=6)J96-T
M`%-U8FIE8W0@1FEE;&0`4W5B<V-R:6)E('1O($9O;&1E<BAS*0!3=6-C97-S
M`%-U9V=E<W1I;VYS`%1A<VMS`%1E>'0`5&AE(&-U<G)E;G0@9F]L9&5R*',I
M("(E<R(@=VEL;"!B92!R96YA;65D('1O("(E<R(N`%1H92!F;VQD97(@(B5S
M(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L9&5R("(E<R(@8V]N=&%I;G,@:6QL
M96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@<')O
M8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`
M5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@
M<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!D96QE=&5D
M(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N`%1H92!F
M;VQD97(@(B5S(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@9&5L971E9"X@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@
M=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S
M('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U
M8V-E<W-F=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!S:6=N871U<F4@=V%S
M('-U8V-E<W-F=6QL>2!R97!L86-E9"X`5&AE<F4@87)E(&YO(&UE<W-A9V5S
M(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I
M;F<@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S
M(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG
M(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI
M<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE
M<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE
M<W-A9V4Z("5S`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G92!T;P!4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+@!4:')E860@5FEE=P!4:71L90!4;P!4<F%S:"!F;VQD
M97(Z`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%N<W=E<F5D
M`%5N86YS=V5R960@;65S<V%G97,`56YD96QE=&4`56YD:7-C;&]S960@4F5C
M:7!I96YT<P!5;F1O($-H86YG97,`56YN86UE9`!5;G-E96X`56YS=6)S8W)I
M8F4@9G)O;2!&;VQD97(H<RD`57-E($1E9F%U;'0@5F%L=64`57-E<B!/<'1I
M;VYS`%5S97)N86UE`%9I97<@)7,`5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L
M87D@869T97(@;&]G:6XZ`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY
M`%EE<P!9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R``66]U(&%R
M92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N`%EO=2!A<F4@<F5N86UI
M;F<@=&AE(&9O;&1E<CH@`%EO=2!H879E("5S(&YE=R!M97-S86=E<RX`66]U
M(&AA=F4@,2!N97<@;65S<V%G92X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE
M(&9O;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R<SH`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L
M96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO
M=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+@!9;W4@;75S
M="!S96QE8W0@86X@861D<F5S<R!F:7)S="X`66]U(&UU<W0@<V5L96-T(&%T
M(&QE87-T(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y(&$@
M<F5C:7!I96YT+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(
M97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U
M8G-C<FEB960@9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%EO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`
M66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN`%EO=7(@26YF;W)M871I;VX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+@!9;W5R('-I9VYA='5R93H`6TYO(%-U8FIE8W1=`%M0<F]B;&5M
M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`&9R;VT`;F]N90!O<@!S<&5L;&EN
M9R!E<G)O<@!S<&5L;&EN9R!E<G)O<G,`=D-A<F0`4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`R+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`S+3`R+3$X(#`Y.C,Y*S`Q
M,#`*3&%S="U4<F%N<VQA=&]R.B!!;F=E;',@1W5I;65RX"`\06YG96QS+D=U
M:6UE<F%`=6%B+F5S/@I,86YG=6%G92U496%M.B!#871A;&%N(#QD979`;&ES
M=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@`@("`@4&5R(&$Z(``@("!$871A.B``("`@
M("`@1&4Z(``@07-S=6UP=&4Z(``@82``(P`E9"!A;"`E9"!D92`E9"!-:7-S
M871G97,`3W!E<F%C:6]N<R!D92!-86YT96YI;65N="`E<R`M($-O;F9I<FUA
M8VGS`"5S(&IA(&5X:7-T96EX+B!,82!C87)P971A("5S(&YO(&AA(&5S=&%T
M(')E;F]M96YA9&$N`$QA(&-A<G!E=&$@)7,@97,@<F5N;VUE;F$@82!P<FEN
M8VEP:2!D92!M97,N`"5S.B`E<R`H)60F;F)S<#MD929N8G-P.R5D*0`H07!L
M:6-A<B!E;',@8V%N=FES(&D@<&%S<V%R(&$@;&$@<&%N=&%L;&$@<V5G_&5N
M="XI`"A296)U=&IA<B!T;W1S(&5L<R!C86YV:7,@:2!T;W)N87(@82!L82!P
M86YT86QL82!D92!R961A8V-I\RXI`"A4;W)N87(@82!L82!P86YT86QL82!D
M92!R961A8V-I\R!D97-P<NES(&0G87!L:6-A<B!T;W1S(&5L(&-A;G9I<R!F
M971S(&9I;G,@87%U[2X@16QS(&-A;G9I<R!A(&QA('!A;G1A;&QA(&%C='5A
M;"!.3R!S97)A;B!A<&QI8V%T<RXI`"H@069E<F=I<B!A<75E<W1S(&9E;G0@
M8VQI8R!A($]+("H`*B!3:2!U<R!P;&%U+"!S96QE8V-I;VYE=2!L82!A9')E
MYV$H8V5S*2H`,C0@:&]R97,`04TO4$T`069E9VER('!A<F5L;`!!9')EYV$`
M3&QI8G)E=&$@9"=!9')E8V5S`$%L:65S`%1O=',`5&]T<R!E;',@;6ES<V%T
M9V5S(&1E(&QA(&-A<G!E=&$H97,I('-E9_QE;G0H<RD@97,@9&5S8V%R<F5G
M87)A;B!E;B!U;F%R>&EU($U"3U@Z(`!4;W1S(&5L<R!M:7-S871G97,@9&4@
M;&$@=F]S=')A(&-A<G!E=&$B)7,B(&%M8B!MZ7,@9&4@)7,@9&EE<R!D)V%N
M=&EG=6ET870@<V5R86X@96QI;6EN871S('!E<FUA;F5N=&UE;G0N`%1O=&5S
M(&QE<R!C87)P971E<R!S96YT+6UA:6P@86UB(&WI<R!D92`E<R!M97-O<R!D
M)V%N=&EG=6ET870@<V5R86X@96QI;6EN861E<RX`4R=H82!E<W!E8VEF:6-A
M="!U;B!V86QO<B!I;+=L96=A;"X`0V]N=&5S=&%T`$UI<W-A=&=E<R!C;VYT
M97-T871S`+]%<W3@('-E9W5R('%U92!D97-I=&IA(&9E<B!A:7CR/P"_17-T
MX"!S96=U<B!Q=64@9&5S:71J82!E;&EM:6YA<B!015)-04Y%3E1%345.5&%Q
M=65S=',@;6ES<V%T9V5S/P"_17-TX"!S96=U<B!Q=64@9&5S:71J82!B=6ED
M87(@87%U97-T82!C87)P971A/P!097(@2&]R82!D)T%R<FEB861A`$%S8V5N
M9&5N=`!!9&IU;G1A<@!!9&IU;G1A<B!A<GAI=0!!9&IU;G1A<@!#86UP<R!D
M:7-P;VYI8FQE<SH`5&]R;F%R(&$@)7,`0F-C`$%N:79E<G-A<FD`3&QI<W1A
M(&YE9W)A`%1E>'0`06UB9/-S`$-A;F-E;+=L87(`0V%N8V5LMVQA<B!-:7-S
M871G90!#86YC96RW;&%R($EN9F]R;64`0V%N8V5LMVQA;G0@87%U97-T(&UI
M<W-A=&=E(')E8G5T:F%R974@<&5R;6%N96YT96UE;G0@96P@<V5U(&-O;G1I
M;F=U="X`0V,`5&5LZ&9O;B!#96RW;'5L87(`0V%N=FEA<@!#86YV:6%R('1O
M=&5S`$-A;G9I87(@;W!C:6]N<R!D92!V:7-U86QI='IA8VGS('1A;',@8V]M
M('%U86YT<R!M:7-S871G97,@=F5U<F4@<&5R('#@9VEN82!I(&5L(&-R:71E
M<FD@9&4@8VQA<W-I9FEC86-I\R!D96QS(&UI<W-A=&=E<RX`0V%N=FEA<B!E
M;"!N;VTL(&PG861R9>=A(&5L96-T<O)N:6-A+"!I(&QA('-I9VYA='5R82P@
M<75E(&5L<R!C;VYT86-T97,@=F5U96X@<75A;B!L;&5G96EX96X@:2!R97-P
M;VYE;B!E;',@=F]S=')E<R!M:7-S871G97,N`$5X86UI;F%R($-A<G!E=&$H
M97,I('!E<B!#;W)R974@3F]U`$5S8V]L;&ER($%C8VGS.@!486YC87(@1FEN
M97-T<F$`0V%R<&5T82!486YC86YD80!#;VRW;&%P<V%R(%1O=&5S`$-O;+=L
M87!S87(@5&]T97,@;&5S($-A<G!E=&5S`$-O;+=L87!S87(@0V%R<&5T80!#
M;VUP86YY:6$`4F5G=6QA<B!Q=6%N(&5S('9E<FEF:6-A<N`@<&5R(&-O<G)E
M=2!N;W4@:2P@<VD@;F]T:69I8V%R(&\@;F\@<75A;B!E<R!R96)I;BX`0V]P
M:6%R`$-O<G)E9VER`%1E>'0@0V]R<F5G:70`3F\@<R=H82!P;V=U="!O8G)I
M<B!E;"!M\F1U;"`E<R!-86EN=&5N86YC95]487-K`$-R96%R`$-R96%R($-A
M<G!E=&$`0W)E87(@=6YA(&YO=F$@8V%R<&5T82!D)V5S8F]R<F%N>7,`0W)E
M87(@=6YA(&YO=F$@8V%R<&5T82!D92!C;W)R974@96YV:6%T`$-R96%R('5N
M82!N;W9A(&-A<G!E=&$@<&5R(&$@;&$@4&%P97)E<F$`0W)E87(@<F5G;&5S
M(&1E(&9I;'1R870@<&5R(&]R9V%N:71Z87(@96P@8V]R<F5U(&5N=')A;G0L
M(&-L87-S:69I8V%R+6QO(&5N(&-A<G!E=&5S(&D@96QI;6EN87(@<W!A;2X`
M4&5R<V]N86QI='IA<B!L97,@=&%S<75E<R!A(&5X96-U=&%R(&%L(&EN:6-I
M87(@<V5S<VGS(&5N("5S+@!$1`!$:>!R:6%M96YT`$1A=&$`261E;G1I=&%T
M(%!R961E=&5R;6EN861A`$-R:71E<FD@9&4@8VQA<W-I9FEC86-I\R!P97(@
M9&5F96-T93H`3W)D<F4@9&4@8VQA<VEF:6-A8VGS('!E<B!D969E8W1E.@!%
M;&EM:6YA<@!%;&EM:6YA<B!#87)P971A*&5S*0!%;&EM:6YA=',`36ES<V%T
M9V5S(&5L:6UI;F%T<P!%;&EM:6YA;G0@:2!M;W9E;G0@;6ES<V%T9V5S`$1E
M<V-E;F1E;G0`1&5S8W)I<&-I\R!D96P@4')O8FQE;6$`16QS(&1E=&%L;',@
M:&%N(&5S=&%T(')E9VES=')A=',@<&5R(&$@;"=A9&UI;FES=')A9&]R+@"_
M071E;G5A<B!S:6=N871U<F5S/P!6:7-U86QI='IA<@!/<&-I;VYS(&1E(%9I
M<W5A;&EZ86-I\P!.;R!%>&%M:6YA<B!#87)P971A*&5S*2!P97(@0V]R<F5U
M($YO=0!.;R!A8V-E9&EU(&1I<F5C=&%M96YT(&$@;6%I;G1E;F%N8V4N<&AP
M`+]$97-I=&IE=2!O8G)I<B!A<75E<W1A(&-A<G!E=&$_`$%C86)A<@!$97-C
M87)R96=A<B!#87)P971A*&5S*0!%<V)O<G)A;GD`0V%R<&5T82!D)V5S8F]R
M<F%N>7,Z`$5D:71A<@!%9&ET87(@<F5G;&5S(&1E(&9I;'1R870`16UA:6P`
M061R9>=A($5L96-T<O)N:6-A`$)U:61A<B!#87)P971A*&5S*0!"=6ED87(@
M;&$@8V%R<&5T82!087!E<F5R80!297-U;'1A="!B=6ET+@!&:2!D96P@;6ES
M<V%T9V4@<F5E;G9I870`26YT<F]D=>]U(&5L(&YO;2!D92!L82!N;W9A(&-A
M<G!E=&$@9"=E<V)O<G)A;GES`$EN=')O9'7O=2!E;"!N;VT@9&4@;&$@;F]V
M82!C87)P971A(&1E(&-O<G)E=2!E;G9I870`26YT<F]D=>]U(&5L(&YO;2!D
M92!L82!N;W9A(&-A<G!E=&$@9&4@4&%P97)E<F$`17)R;W(`0V%D82`Q-2!M
M:6YU=',`0V%D82`S,"!S96=O;G,`0V%D82`U(&UI;G5T<P!#861A($EN:6-I
M(&1E(%-E<W-I\P!#861A(&UI=&IA(&AO<F$`0V%D82!M:6YU=`!%>&5M<&QE
M(&1E('9A;&]R<SH`17AP86YD:7(@`$5X<&%N9&ER(%1O=&5S(&QE<R!#87)P
M971E<P!%>'!A;F1I<B!#87)P971A`$5X<&%N9&ER($YO;7,`17)R861A(&%L
M(')E8W5P97)A<B!L97,@<')E9F5RZ&YC:65S+@!%<G)A9&$@86P@8V]N;F5C
M=&%R(&%M8B!E;"!S97)V:61O<B!,1$%0+@!&87@`1FEL=')E<P!4<F]B87(`
M4')I;65R82!0X&=I;F$`3F%V96=A9&]R(&1E($-A<G!E=&5S`%)E96YV:6%R
M`%)E96YV:6%R`$UI<W-A=&=E(')E96YV:6%T(&1E("5S`$1E`$0G061R9>=A
M($5L96-T<O)N:6-A`$9W9#H`06IU9&$`3V-U;'1A<B!%;&EM:6YA=',`3V-U
M;'1A<B!$97-U8G-C<FET<P!!9')EYV$@4&%R=&EC=6QA<@!496SH9F]N(%!A
M<G1I8W5L87(`2&]R9&4`24Y"3U@`26=N;W)A<@!)9VYO<F%R(%1O=&5S`$EM
M<&]R=&%N=`!-:7-S871G97,@:6UP;W)T86YT<P!#86UP(&EM<&]R=&%T.B`E
M<P!#86UP<R!I;7!O<G1A=',Z`+]);F-L;W5R92!M:7-S871G92!O<FEG:6YA
M;"!A(&QA(')E<W!O<W1A/P!)9&EO;6$`1&%R<F5R82!0X&=I;F$`3&QI<W1A
M<B!496UE<R!D)T%J=61A`$5N=')A<@!%;G1R87(@82`E<P!3;W)T:7(@9&4@
M<V5S<VGS`%1A<W%U97,@9"=);FEC:2!D92!397-S:?,`34T`0OIS=&EA`$UA
M<F-A<B!C;VTZ`+]-87)C87(@9&EF97)E;G1S(&YI=F5L;',@9&4@<75O=&$@
M86UB(&1I9F5R96YT<R!C;VQO<G,_`$-A;7!S($-O<G)E<W!O;F5N=',`36ES
M<V%T9V4`4F5D86-T87(@36ES<V%T9V4`4&5R($1A=&$@9&5L($UI<W-A=&=E
M`$-E<F-A(&1E($UI<W-A=&=E<P!097(@5&%M86YY(&1E;"!-:7-S871G90!&
M;VYT`%!R97-E;G1A8VGS(&1E($UI<W-A=&=E<P!"86YD97)E<R!D96P@;6ES
M<V%T9V4`0V%R<&5T97,@9&5L($UI<W-A=&=E`$UI<W-A=&=E<R!P97(@<.!G
M:6YA(&%L(&QL:7-T870@9&4@;&$@8OIS=&EA+@!-:7-S871G97,@80!-;V1I
M9FEC87(`365N<W5A;&UE;G0`36]U<F4`3F]M`$UA:0!.;W4`3F]U($-O<G)E
M=0!-27-S871G97,@3F]U<P!3:6?\96YT`$U)<W-A=&=E(%-E9_QE;G0`4.!G
M:6YA(%-E9_QE;G0`3F\`3F\@<R=H86X@97-P96-I9FEC870@8V%R<&5T97,`
M3F\@:&D@:&$@97)R;W)S(&0G;W)T;V=R869I80!.;R!H:2!H82!S=6=G97)I
M;65N=',`0V%P`$YO($5L:6UI;F%T`$YO($5S8F]R<F%N>0!.;R!);7!O<G1A
M;G0`3F\@4&5R<V]N86P`36ES<V%T9V5S($YO(&5L:6UI;F%T<P!-:7-S871G
M97,@3F\@:6UP;W)T86YT<P!.;W1E<P!/2P!-:7-S871G97,@06YT:6-S`%!U
M<F=A;G0@8V%R<&5T97,@<V5N="UM86EL(&%N=&EG=65S+@!/<&-I;VYS`$%L
M=')A($EN9F]R;6%C:?,`06QT<F5S($]P8VEO;G,`4.!G:6YA("5D(&1E("5D
M`%!A<G0H<RD`0V]N=')A<V5N>6$`4F5A;&ET>F%R($]P97)A8VEO;G,@9&4@
M36%N=&5N:6UE;G0`4&5R<V]N86P`26YF;W)M86-I\R!097)S;VYA;`!496SH
M9F]N`+]6;VQE=2!#;VRW;&]C87(@;&$@=F]S=')A('-I9VYA='5R82!A8F%N
M<R!D96QS(&UI<W-A=&=E<R!D92!R97-P;W-T82!I(&5L<R!R965N=FEA;65N
M=',_`%-I('5S('!L874L(&EN=')O9'7O=2!E;"!N;VT@9&4@;&$@;F]V82!C
M87)P971A.@!);G1R;V1U[W4@96P@;F]U("!N;VTZ`%-I('5S('!L874L('!R
M;W!O<F-I;VYE=2!U;B!R97-U;2!D96P@<')O8FQE;6$N`%-I('5S('!L874L
M('!R;W!O<F-I;VYE=2!E;"!V;W-T<F4@;F]M(&0G=7-U87)I(&D@8V]N=')A
M<V5N>6$`4VD@=7,@<&QA=2P@<F5S;VQE=2!L97,@861R96-E<R!E;&5C='+R
M;FEQ=65S(&%M8FEG_&5S(&\@:6YVX&QI9&5S+@!396QE8V-I;VYE=2!U;F$@
M8V%R<&5T82!A8F%N<R!D92!R96%L:71Z87(@8V%P(&%C8VGS+@!396QE8V-I
M;VYE=2!C;VT@82!M[6YI;2!U;F$@8V%R<&5T82!P97(@82!R96%L:71Z87(@
M;&$@8V5R8V$N`%-E;&5C8VEO;F5U('5N82!S;VQA(&-A<G!E=&$@<&5R(&$@
M87%U97-T82!O<&5R86-I\P!-:7-S871G92!!;G1E<FEO<@!0X&=I;F$@06YT
M97)I;W(`26UP<FEM:7(`1&5S8W)I<&-I\R!D96P@4')O8FQE;6$`0G5I9&%R
M(%!A<&5R97)A`%!E<FEO9&EC:71A="!D96P@8G5I9&%T(&1E(&QA(%!A<&5R
M97)A.@!2961I<FEG:7(`4F5D:7)I9VER($UI<W-A=&=E`%)E9&ER:6=I<B!A
M<75E<W0@;6ES<V%T9V4`16P@<F5D:7)E8V-I;VYA;65N="!H82!F86QL870N
M`%)E9G)E<V-A<@!2969R97-C87(@5FES=&5S(&1E($-A<G!E=&$`4F5C87)R
M96=A<B!6:7-T80!296-O<F1A<B!L82!D87)R97)A('9I<W1A`%1R975R92!P
M87)E;&P`2&$@9F%L;&%T(&%L(')E;F]M96YA<B`B)7,B(&$@(B5S(BX@06EX
M\B#I<R!E;"!Q=64@:&$@9&ET(&5L('-E<G9I9&]R`%)E96UP;&'G87(@86UB
M.@!297-P;VYD<F4`4F5S<&]N9')E(&$@5&]T<P!297-P;VYD<F4@82!4;W1S
M.@!297-P;VYD<F4M03H@`%)E<W!O;F1R93H`4F5P;W)T87(@8V]M(%-P86T`
M3F5T96IA<@!297!R96YD<F4`OU1O<FYA<B!A;"!L;&ES=&$@9&4@;&$@8OIS
M=&EA(&1E<W!RZ7,@9"=E;&EM:6YA<BP@;6]U<F4@;R!C;W!I87(@=6X@;6ES
M<V%T9V4_`$1E<V%R($5S8F]R<F%N>0!$97-A<B!C;VT`2&$@9F%L;&%T(&%L
M(&1E<V%R(&PG97-B;W)R86YY+B!!:7CR(.ES(&5L('%U92!H82!D:70@96P@
M<V5R=FED;W(Z("5S`$-E<F-A<@!297-U;'1A=',@9&4@;&$@0V5R8V$`5FES
M=`!396QE8V-I;VYA<@!396QE8V-I;VYA<B!T;W1S`%1R975R92!S96QE8V-I
M\P!396QE8V-I;VYE=2!E;"!D96QI;6ET861O<B!D92!L82!D871A.@!396QE
M8V-I;VYE=2!E;"!F;W)M870@9&4@;&$@9&%T83H`4V5L96-C:6]N974@96P@
M9F]R;6%T(&1E(&PG:&]R83H`4V5L96-C:6]N974@9&]S(&-A;7!S('%U92!C
M;VEN8VED96EX:6XN`%-E;&5C8VEO;F5U(&5L('9O<W1R92!I9&EO;6$@<')E
M9F5R:70Z`$5N=FEA<B!-:7-S871G90!%;G9I87(@26YF;W)M90!#87)P971A
M(&1E(&-O<G)E=7,@96YV:6%T<SH`4V5R=FED;W(`17-T86)L:74@<')E9F5R
MZ&YC:65S(&1E;"!Q=64@:&$@9&4@<W5C8V5I<B!Q=6%N(&UO=F5U(&D@96QI
M;6EN974@;6ES<V%T9V5S+@"_4R=H82!D92!T86YC87(@;&$@9FEN97-T<F$@
M9&4@<F5D86-C:?,@9&5S<'+I<R!D92!D97-A<B!U;B!E<V)O<G)A;GD_`$UO
M<W1R87(@16QI;6EN871S`$UO<W1R87(@1&5S=6)S8W)I=',`5&%M86YY`$]M
M:71I<B!-86YT96YI;65N=`!%;G1R861A(&1E($-A<N!C=&5R<R!%<W!E8VEA
M;',`0V%RX&-T97)S($5S<&5C:6%L<P!#;W)R96-C:?,@9"=/<G1O9W)A9FEA
M`$-O<G)E8W1O<B!D)T]R=&]G<F%F:6$`4F5V:7-I\R!D)V]R=&]G<F%F:6$@
M8V]M<&QE=&$`17)R;W)S(&0G;W)T;V=R869I82!P97(@<&%N=&%L;&$@9'5R
M86YT(&QA(')E=FES:?,N`$%S<W5M<'1E`%!E<B!!<W-U;7!T90!3=6)S8W)I
M=7)E)W,@82!L82!#87)P971A*&5S*0#(>&ET`%-U9V=E<FEM96YT<P!&96EN
M97,`5&5X=`!,82AE<RD@8V%R<&5T82AE<RD@(B5S(B!S97+@*&XI(')E;F]M
M96YA9&$H97,I(&$@(B5S(BX`3&$@8V%R<&5T82`B)7,B(&IA(&5X:7-T96EX
M`$QA(&-A<G!E=&$@(B5S(B!C;VYTZ2!C87+@8W1E<G,@:6RW;&5G86QS(&5N
M(&5L('-E=2!N;VTN($%I>/(@<&]T(&-A=7-A<B`@<')O8FQE;65S+B!3:2!U
M<R!P;&%U+"!C;VYT86-T974@;"=A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA
M+@!,82!C87)P971A("(E<R(@:&$@97-T870@8W)E861A('!E<O(@;F\@:&D@
M:&5U(&5S=&%T('-U8G-C<FET+@!,82!C87)P971A("(E<R(@:&$@97-T870@
M96QI;6EN861A('!E<O(@;F\@:&D@:&5U(&5S=&%T(&1E<W5B<V-R:70N`$QA
M(&-A<G!E=&$@(B5S(B!N;R!H82!E<W1A="!C<F5A9&$N($%I>/(@Z7,@96P@
M<75E(&AA(&1I="!E;"!S97)V:61O<@!,82!C87)P971A("(E<R(@;F\@:&$@
M97-T870@96QI;6EN861A+B!!:7CR(.D@<75E(&AA(&1I="!E;"!S97)V:61O
M<@!,82!C87)P971A("(E<R(@:&$@97-T870@8W)E861A('-A=&ES9F%C=/)R
M:6%M96YT+@!,82!C87)P971A("(E<R(@:&$@97-T870@96QI;6EN861A('-A
M=&ES9F%C=/)R:6%M96YT+@!,82!C87)P971A("(E<R(@:&$@97-T870@<F5N
M;VUE;F%D82!S871I<V9A8W3R<FEA;65N="!A("(E<R(N`$QA('-I9VYA='5R
M82!S)VAA(')E96UP;&'G870@<V%T:7-F86-T\G)I86UE;G0N`$YO(&AI(&AA
M(&UI<W-A=&=E<R!E;B!A<75E<W1A(&+Z<W1I82X`2&D@:&$@:&%G=70@=6X@
M<')O8FQE;6$@86P@8G5I9&%R("5S+B!!:7CR(.ES(&5L('%U92!H82!D:70@
M96P@<V5R=FED;W(`2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@86QB=6ED87(@
M;&$@8OIS=&EA+B!!:7CR(.ES(&5L('%U92!H82!D:70@96P@<V5R=FED;W(`
M2&D@:&$@:&%G=70@=6X@97)R;W(@86P@96QI;6EN87(@;6ES<V%T9V5S(&1E
M(&QA(&-A<G!E=&$@(B5S(BX@06EX\B#I<R!E;"!Q=64@:&$@9&ET(&5L('-E
M<G9I9&]R`$AI(&AA(&AA9W5T('5N(&5R<F]R(&%L(&5L:6UI;F%R(&5L<R!M
M:7-S871G97,@9&4@;&$@8V%R<&5T82`B)7,B+B!!:7CR(.ES(&5L('%U92!H
M82!D:70@96P@<V5R=FED;W(`2&D@:&$@:&%G=70@=6X@97)R;W(@86P@=FES
M=6%L:71Z87(@87%U97-T82!P87)T(&1E;"!M:7-S871G90!(:2!H82!H86=U
M="!U;B!E<G)O<B!A;"!M87)C87(@;6ES<V%T9V5S(&$@;&$@8V%R<&5T82`B
M)7,B+B!!:7CR(.ES(&5L('%U92!H82!D:71E;"!S97)V:61O<@!(:2!H82!H
M86=U="!U;B!E<G)O<B!A;"!E;G9I87(@96P@=F]S=')E(&UI<W-A=&=E.B`E
M<P!!:7CR('!O="!T87)D87(@=6YA(&UI8V$N(+]%<W3@<R!S96=U<B!Q=64@
M9&5S:71J82!C;VYT:6YU87(_`$%Q=65S="!M:7-S871G92!A`$%Q=65S="!N
M^FUE<F\@:&$@9&4@<V5R(&-O;2!A(&WM;FEM('5N(#$N`$%Q=65S="!V86QO
M<B!H82!D92!S97(@=6X@;OIM97)O+@!097(@4V5Q_.AN8VEA`%3M=&]L`%!E
M<B!A`$-A<G!E=&$@4&%P97)E<F$Z`%523`!);F-A<&'G(&1E(&-O;FYE8W1A
M<G-E(&%L('-E<G9I9&]R(&1E(%-13"X`3F\@Z7,@<&]S<VEB;&4@=')A9'5I
M<B!A<75E<W0@9&]C=6UE;G0@9&4@5V]R9`!396YS92!R97-P;VYD<F4`36ES
M<V%T9V5S('-E;G-E(')E<W!O;F1R90!296-U<&5R87(`1&5S=&EN871A<FES
M($1E<V-O;F5G=70`1&5S9F5R($-A;G9I<P!396YS92!N;VT`3F\@=FES=`!$
M97-U8G-C<FEU<F4G<R!D92!L82AE<RD@0V%R<&5T82AE<RD`571I;&ET>F%R
M(%9A;&]R(%!E<B!$969E8W1E`$]P8VEO;G,@9"=5<W5A<FD`3F]M(&0G57-U
M87)I`%9E=7)E("5S`%9I<W1A(&\@8OIS=&EA(&$@9&5S<&QE9V%R(&1E<W!R
MZ7,@9"=I;FEC:6%R(&QA('-E<W-I\SH`07;M<P!3971M86YA;&UE;G0`0F5N
M=FEN9W5T<R!A("5S`$)E;G9I;F=U="P@)7,`061R9>=A(&1E(&QA($9E:6YA
M`%1E;.AF;VX@9&4@;&$@1F5I;F$`04$`06YU86QM96YT`%/M`$5S=&5U(&-R
M96%N="!U;F$@<W5B+6-A<G!E=&$@82``17-T974@8W)E86YT('5N82!C87)P
M971A(&1E(&YI=F5L;"!S=7!E<FEO<BX`17-T974@<F5N;VUE;F%N="!L82!C
M87)P971A.B``5&5N:74@)7,@;6ES<V%T9V5S(&YO=7,N`%1E;FEU(#$@;6ES
M<V%T9V4@;F]U+@!496YI=2!C;W)R974@;F]U(&$@;&$@8V%R<&5T82!S96?\
M96YT.@!496YI=2!C;W)R974@;F]U(&$@;&5S(&-A<G!E=&5S('-E9_QE;G1S
M.@!(974@9&4@9&5S8W)I=7)E(&5L('!R;V)L96UA(&%B86YS(&0G96YV:6%R
M(&PG:6YF;W)M92!D96P@<')O8FQE;6$N`%!R:6UE<B!H974@9&4@<V5L96-C
M:6]N87(@=6YA(&+Z<W1I82!D92!D97-T[2X`4')I;65R(&AE=2!D92!S96QE
M8V-I;VYA<B!U;F$@861R9>=A+@!0<FEM97(@:&5U(&1E('-E;&5C8VEO;F%R
M+"!A;"!M96YY<RP@=6X@;6ES<V%T9V4N`$AE=2!D)V5S<&5C:69I8V%R('5N
M(&1E<W1I;F%T87)I(&5N(&5L(&-A;7`@4$52($$Z`$YO(&AE=2!E<W1A="!S
M=6)S8W)I="!A("(E<R(N($%I>/(@Z7,@96P@<75E(&AA(&1I="!E;"!S97)V
M:61O<@!.;R!H974@97-T870@9&5S=6)S8W)I="!D92`B)7,B+B!!:7CR(.ES
M(&5L('%U92!H82!D:70@96P@<V5R=FED;W(`2&5U(&5S=&%T('-U8G-C<FET
M('-A=&ES9F%C=/)R:6%M96YT(&$@(B5S(@!(974@97-T870@9&5S=6)S8W)I
M="!S871I<V9A8W3R<FEA;65N="!D92`B)7,B`$QA('9O<W1R82!S97-S:?,@
M96X@)7,@:&$@97AP:7)A="X@4VD@=7,@<&QA=2P@:6YI8VEE=2!U;F$@;F]V
M82!S97-S:?,N`$QA('9O<W1R82!);F9O<FUA8VGS`$QE<R!O<&-I;VYS(&AA
M;B!E<W1A="!A8W1U86QI='IA9&5S+@!,82!V;W-T<F$@<VEG;F%T=7)A.@!;
M4V5N<V4@07-S=6UP=&5=`%M);F9O<FUE(&1E;"!0<F]B;&5M85T`6VSM;FEA
M("5S(&1E("5S70!D90!C87``;P!E<G)O<B!D)V]R=&]G<F%F:6$`97)R;W)S
M(&0G;W)T;V=R869I80!V0V%R9```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M;&]C86QE+V-A7T53+VAE;'`N>&UL````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,3,Q,3<U`#$P-#$W,S8R-S8P`#`R,3`W-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA+2T@)$AO<F1E.B!I
M;7`O;&]C86QE+V-A7T53+VAE;'`N>&UL+'8@,2XQ,"XV+C0@,C`P-B\P,2\S
M,"`Q-3HU.#HP-"!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M8V]M<&]S92UB=71T;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M3F]U($UI<W-A=&=E.B!!8V-I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D%C
M8VEO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5L(&)O=/,@(D5N=FEA
M<B!-:7-S871G92(@=')A;65T(&5L(&UI<W-A=&=E(&5L+V5L<R!D97-T:6YA
M=&%R:2AS*2!P<F5V:7-T*',I+B!!<W-E9W5R974M=F]S(&1E('9E<FEF:6-A
M<B!E;"!C;VYT:6YG=70@9&5L(&UI<W-A=&=E(&D@9&5L+W,@9&5S=&EN871A
M<FDH<RD@86)A;G,@9&4@<'+I;65R(&%Q=65S="!B;W3S('!E<G%UZ"!U;B!C
M;W`@97AE8W5T870@;F\@<&]D<F5U(&-A;F-E;+=L87(@;"=O<&5R86-I\RX*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@(D1E<V%R(&5S8F]R<F%N>2(@
M8V]LMVQO8V$@=6X@;6ES<V%T9V4@<V5N<V4@86-A8F%R(&$@;&$@8V%R<&5T
M82`G1')A9G1S)RP@82!L82!Q=64@<&]D974@86-C961I<B!D97,@9&4@;&$@
M8V%S96QL82!D96P@;65N^B!D97-P;&5G86)L92!E;B!L82!P87)T('-U<&5R
M:6]R(&1R971A(&1E(&QA(&)A<G)A(&)L879A(&1E(&YA=F5G86-I\RX@4&]D
M974@86-A8F%R(&5L(&UI<W-A=&=E(&WI<R!T87)D(&-A;G9I86YT+6QO(&$@
M;&$@8V%R<&5T82`G1')A9G1S)RP@9F5N="!C;&EC:R!A;"!D86UU;G0@9&5L
M(&UI<W-A=&=E(&1E<V%T('!E<B!O8G)I<BUL;R!I(&9E;G0@8VQI8VL@;>ES
M('1A<F0@82`B4F5A;G5D87(B+B`@07-S96=U<F5U+79O<R!D92!P;W-A<B!L
M)V%S<W5M<'1E(&%L(&UI<W-A=&=E(&%B86YS(&1E(&1E<V%R(&PG97-B;W)R
M86YY(&1E(&UA;F5R82!Q=64@<'5G=6D@:61E;G1I9FEC87(@9N!C:6QM96YT
M(&5L(&UI<W-A=&=E(&$@;&$@8V%R<&5T82!$<F%F=',N($1E<W!RZ7,@9&4@
M9&5S87(@=6X@17-B;W)R86YY+"!S97)E=2!R971O<FYA=',@82!L82!C87)P
M971A($E.0D]8(&\@82!L82!D87)R97)A('%U92!E<W1A=F$@=FES=6%L:7IA
M;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($5L(&)O=/,@(D-A;F-E
M;+=L87(@36ES<V%T9V4B(&EN=&5R<F]M<"!E;"!M:7-S871G92!E;B!P<F]G
M<NES(&D@96P@<F5T;W)N82!A(&PG24Y"3U@@82!L82!D87)R97)A(&-A<G!E
M=&$@<75E(&5S=&%V82!V:7-U86QI>F%N="X*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@06-T:6]N<SPO=&ET;&4^
M"B`@("`\:&5A9&EN9SY!8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!396YD($UE<W-A9V4@;&%U;F-H97,@>6]U<B!E;6%I;"!T;R!T:&4@:6YT
M96YD960@<F5C:7!I96YT*',I+B!"92!S=7)E('EO=2!W86YT('1O('-E;F0@
M8F5F;W)E(&-L:6-K:6YG(&AE<F4@87,@;VYC92!S96YT(&ET(&-A;FYO="!B
M92!T86ME;B!B86-K+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3879E
M($1R869T('!L86-E<R!A;B!U;F9I;FES:&5D(&UE<W-A9V4@:6X@82!F;VQD
M97(@8V%L;&5D("=$<F%F=',G"F%C8V5S<VEB;&4@8GD@=&AE('!O<"UD;W=N
M(&)O>"!O;B!T:&4@<FEG:'0@<VED92!O9B!T:&4@8FQU92!N879I9V%T:6]N
M(&)A<B!A="!T;W`N(%EO=2!C86X@=&AE;B!F:6YI<V@@=&AE(&UE<W-A9V4@
M;&%T97(@8GD@<W=I=&-H:6YG('1O('1H92`G1')A9G1S)R!F;VQD97(L(&-L
M:6-K:6YG(&]N('1H92!S879E9"!M97-S86=E('1O(&]P96X@:70L(&%N9"!T
M:&5N(&-L:6-K:6YG(&]N("=297-U;64G+B!"92!S=7)E('1O('!U="!A('-U
M8FIE8W0@;VX@=&AE(&5M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A9G0@
M<V\@=&AA="!Y;W4@8V%N(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S86=E
M('EO=2!W86YT('=I=&AI;B!T:&4@1')A9G1S(&9O;&1E<BX@069T97(@<V%V
M:6YG(&%S(&$@1')A9G0L('EO=2!A<F4@<F5T=7)N960@=&\@>6]U<B!)3D)/
M6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#86YC96P@365S<V%G92!D<F]P
M<R!T:&4@;65S<V%G92!I;B!P<F]G<F5S<R!A;F0@<VEM<&QY(')E='5R;G,@
M>6]U('1O('1H92!)3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@
M=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB('-T871E/2)U;FMN;W=N(CX*
M("`@(#QT:71L93Y.;W4@36ES<V%T9V4Z($1E/"]T:71L93X*("`@(#QH96%D
M:6YG/B)$92(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EN=')O9'7O=2!L
M82!V;W-T<F$@861R9>=A(&1E(&-O<G)E=2!E>&%C=&$N(%!E<B!D969E8W1E
M+"!L82!V;W-T<F4@9&ER96-C:?,@97,@9V5N97)A9&$@875T;VW@=&EC86UE
M;G0@<&5L('!R;V=R86UA+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UF<F]M(CX*("`@(#QT:71L93Y-97-S
M86=E($-O;7!O<VET:6]N.B!&<F]M/"]T:71L93X*("`@(#QH96%D:6YG/B9Q
M=6]T.T9R;VTF<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R
M('EO=7(@8V]R<F5C="!E;6%I;"!A9&1R97-S+B!9;W5R(&5M86EL(&%D9')E
M<W,@:7,@875T;VUA=&EC86QL>2!E;G1E<F5D(&9O<B!Y;W4@9F]L;&]W:6YG
M("9Q=6]T.T9R;VTZ)G%U;W0[(&EN(&]U=&=O:6YG(&5M86EL+@H@("`@/"]P
M87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E
M+71O(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^3F]U($UI<W-A=&=E
M.B!097(@83PO=&ET;&4^"B`@("`\:&5A9&EN9SXB4&%R82(\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EN=')O9'7O=2!L)V%D<F7G82AC97,I(&5L96-T
M<O)N:6-A*'%U97,I(&1E(&-O<G)E=2!E>&%C=&$H97,I(&1E;',@<75I(')E
M8G)A;B!E;"!V;W-T<F4@;6ES<V%T9V4N($AE=2!D92!S97!A<F%R(&-A9&$@
M861R9>=A(&%M8B!U;F$@8V]M83L@<VD@=71I;&ET>F5U('%U86QS979O;"!A
M;'1R92!S:6=N92!D92!P=6YT=6%C:?,@=7,@9&]N87+@('5N(&5R<F]R+@H@
M("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M
M<&]S92UT;R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@5&\\
M+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[5&\F<75O=#L\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E
M<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@>6]U<B!M97-S86=E+B!9;W4@
M;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE
M<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E
M;G1R>2!F;VQL;W=S("9Q=6]T.U1O.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)C;VUP;W-E+6-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^3F]U
M($UI<W-A=&=E.B!#8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB0V,B/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!);G1R;V1U[W4@;"=A9')EYV$H8V5S*2!D
M92!C;W)R974@96QE8W1R\FYI8R!E>&%C=&$H97,I(&1E;',@<75I('9O;&5U
M('%U92!R96)I;B!U;F$@8_)P:6$@8V%R8O,@9&5L('9O<W1R92!M:7-S871G
M92X@4V5P87)E=2!C861A(&%D<F7G82!A;6(@=6YA(&-O;6$N($QE<R!#\G!I
M97,@8V%R8O,@97,@=')A;65T96X@9V5N97)A;&UE;G0@82!D)V%L=')E<R!P
M97)S;VYE<RP@9&EF97)E;G1S(&1E(&QE<R!P97)S;VYE<R!A(&QE<R!Q=64@
M97-C<FEU<F5U(&1I<F5C=&%M96YT('!E<O(@<75E(&1E<VET:F5U('%U92!C
M;VYE:7AI;B!E;"!C;VYT:6YG=70@9&5L(&UI<W-A=&=E+"!G96YE<F%L;65N
M="!A;&?Z(&EN9&ER96-T86UE;G0@:6YT97)E<V%T(&5N(&%L)V%S<W5M<'1E
M(&1E;"!M:7-S871G92X@5&]T<R!E;',@9&5S=&EN871A<FES("=097(@83HG
M(&D@)T-C.B<@<&]D<F%N('9E=7)E(&QA(&QL:7-T82!D)V%M8F3S<R!T:7!U
M<R!D92!D97-T:6YA=&%R:7,N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E
M;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6-C(CX*("`@(#QT:71L93Y-97-S
M86=E($-O;7!O<VET:6]N.B!#8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O
M=#M#8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE
M(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV
M92!A(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@4V5P87)A=&4@96%C
M:"!A9&1R97-S('=I=&@@82!C;VUM82X@66]U<B!E;G1R>2!F;VQL;W=S("9Q
M=6]T.T-C.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL+B!#87)B;VX@8V]P:65S
M(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O<&QE(&]T:&5R('1H86X@=&AE(&]N
M92AS*2!B96EN9R!W<FET=&5N('1O(&1I<F5C=&QY(&)U="!A<F4@:6UP;W)T
M86YT(')E8VEP:65N=',@;V8@=&AE(&5M86EL(&%S('=E;&PL('5S=6%L;'D@
M<V]M96]N92!I;F1I<F5C=&QY(&-O;F-E<FYE9"!A8F]U="!T:&4@<W5B:F5C
M="!O9B!T:&4@96UA:6PN("!!;&P@)U1O.B<@<F5C:7!I96YT<R!A;F0@)T-C
M.B<@<F5C:7!I96YT<R!C86X@<V5E('1H92!E;G1I<F4@;&ES="!O9B!B;W1H
M(&MI;F1S(&]F(')E8VEP:65N=',N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^
M/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M8F-C(B!S=&%T93TB=6YK
M;F]W;B(^"B`@("`\=&ET;&4^3F]U($UI<W-A=&=E.B!"8V,\+W1I=&QE/@H@
M("`@/&AE861I;F<^(D)C8R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EN
M=')O9'7O=2!L)V%D<F7G82AC97,I(&5L96-T<O)N:6-A*'%U97,I(&5X86-T
M82AE<RD@9&4@;&$H97,I('!E<G-O;F$H97,I('%U92!R96)R86X@=6YA(&/R
M<&EA(&]C=6QT82!D96P@=F]S=')E(&UI<W-A=&=E+B!!<W-E9W5R974M=F]S
M(&1E('-E<&%R87(@8V%D82!A9')EYV$@86UB('5N82!C;VUA.R!S:2!U=&QI
M='IE=2!Q=6%L<V5V;VP@86QT<F4@<VEG;F4@9&4@<'5N='5A8VGS+"!U<R!D
M;VYA<N`@=6X@97)R;W(N($QE<R!#\G!I97,@8V%R8O,@;V-U;'1E<R!S)V5N
M=NUE;B!G96YE<F%L;65N="!A('!E<G-O;F5S('%U92!T96YE;B!U;B!I;G1E
M<NAS(&EN9&ER96-T92!E;B!L)V%S<W5M<'1E(&1E;"!M:7-S871G92!P97+R
M('%U92!H86X@9&4@=&5N:7(M;F4@8V]N96EX96UE;G0@<75E(&1E8F5N('1E
M;F5R(&-O;F]C:6UI96YT;R!D92!D:6-H;R!M96YS86IE(%-)3B!Q=7-E;G-E
M('%U92!L82!R97-T82!D92!D97-T:6YA=&%R:7,@<^!P:6=U96X@<75E(&5L
M(&UI<W-A=&=E(&5L<R!H82!E<W1A="!E;G9I870N(%!E<B!T86YT+"`G;V-U
M;'1A)R!V;VP@9&ER('%U92!L82!I9&5N=&ET870@9&5L<R!D97-T:6YA=&%R
M:7,@<R=A;6%G82!D92!L82!R97-T82!D92!D97-T:6YA=&%R:7,@9&5L(&-O
M<G)E=2!I(&YO;>ES('9O<W3H(&D@96QL<R!S86)E;B!Q=64@:&%N(')E8G5T
M('5N82!C\G!I82!D96P@;6ES<V%T9V4N"B`@("`\+W!A<F$^"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6)C8R(^"B`@("`\=&ET
M;&4^365S<V%G92!#;VUP;W-I=&EO;CH@0F-C/"]T:71L93X*("`@(#QH96%D
M:6YG/B9Q=6]T.T)C8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@
M=&\@<F5C96EV92!A(&)L:6YD(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G
M92X@66]U(&UU<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM
M83L@;W1H97(@<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N
M(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O=#M"8V,Z)G%U;W0[(&EN(&]U=&=O
M:6YG(&UA:6PN($)L:6YD(&-A<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N
M="!T;R!P96]P;&4@;W1H97(@=&AA;B!D:7)E8W0@86YD(&EN9&ER96-T(')E
M8VEP:65N=',@*"9Q=6]T.U1O.B9Q=6]T.R!A;F0@)G%U;W0[0V,Z)G%U;W0[
M(')E8VEP:65N=',I('=H;R!N965D('1O(')E860@=VAA="!I<R!B96EN9R!W
M<FET=&5N(&%S('=E;&P@5TE42$]55"!T:&4@;W1H97(@<F5C:7!I96YT<R!K
M;F]W:6YG('1H870@=&AE>2!A<F4@<F5C96EV:6YG('1H92!E;6%I;"X@5&AU
M<R`G8FQI;F0G(&UE86YS('1H870@=&AE(&ED96YT:71Y(&]F('1H97-E(')E
M8VEP:65N=',@:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R(')E8VEP:65N=',@
M;V8@=&AE(&5M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H97D@:VYO=R!T:&5Y
M(&=O="!A(&-O<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H:7,@=&\@=&5L;"!A
M;B!A=71H;W)I='D@9FEG=7)E('1H870@>6]U(&%R92!T96QL:6YG('-O;65O
M;F4@<V]M971H:6YG('=I=&AO=70@86QA<FUI;F<@=&AE('!E<G-O;B!Y;W4@
M87)E('-E;F1I;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*("`@(#PO<&%R83X*
M/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US=6)J
M96-T(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^3F]U($UI<W-A=&=E
M.B!!<W-U;7!T93PO=&ET;&4^"B`@("`\:&5A9&EN9SXB07-S=6UP=&4B/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!);G1R;V1U[W4@96P@;F]M(&1E(&PG
M87-S=6UP=&4@86P@=F]S=')E(&UI<W-A=&=E+B!(82!D92!S97(@8W5R="P@
M<VEM<&QE(&D@9&5S8W)I<'1I=2X@3"=A<W-U;7!T92#I<R!L82!M86YE<F$@
M;>ES(&;@8VEL('!E<B!A('9O<V%L=')E<R!I(&5L('9O<W1R97,@8V]N=&%C
M=&5S(&1E(')E8V]R9&%R(&5L(&-O;G1I;F=U="!D96P@;6ES<V%T9V4L(&%I
M>.T@8V]M('!E<B!A(&]R9V%N:71Z87(M;&]S(&D@<&5R('1R;V)A<B!D97-P
M<NES(&5L<R!MZ7,@:6UP;W)T86YT<RX@5&%M8NDL('%U86X@=F]S86QT<F5S
M('9O;&=U974@(G)E<W!O;F1R92(@;R`B<F5E;G9I87(B('5N(&UI<W-A=&=E
M+"!L82!L[6YI82!D92!L)V%S<W5M<'1E(.ES(&-O<&EA9&$@96X@96P@;F]U
M(&UI<W-A=&=E+"!D92!T86P@;6%N97)A('%U92!A<75E<W1A(.ES('5N82!F
M;W)M82!D92!D:7(@<75I;G,@;6ES<V%T9V5S('9A;B!J=6YT('!E<B!F;W)M
M87(@96P@(F9I;"(@9"=U;F$@8V]N=F5R<V$N(%1A;FUA=&5I>"P@<VD@)U)E
M<W!O;F1R92<@;R`G4F5E;G9I87(G(&-O;G3I(&YO=F5S(&ED965S+"!H875R
M974@9"=A9F5G:7(@;6]D:69I8V%C:6]N<R!S:6UP;&5S(&$@;&$@;.UN:6$@
M9&4@;"<G07-S=6UP=&4G('!E<B!T86P@<75E(&5L<R!D97-T:6YA=&%R:7,@
M<'5G=6EN('-E9W5I<B!E;"!P<F]G<NES(&0G=6X@(F9I;"(N"B`@("`\+W!A
M<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+7-U
M8FIE8W0B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%-U8FIE
M8W0\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[4W5B:F5C="9Q=6]T.SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE('-U8FIE8W0@;V8@
M>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[4W5B:F5C
M=#HF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@2V5E<"!I="!S:&]R="P@<VEM
M<&QE(&%N9"!D97-C<FEP=&EV92X@(%1H92!S=6)J96-T(&QI;F4@:7,@=&AE
M(&5A<VEE<W0@=V%Y(&9O<B!Y;W4@86YD('EO=7(@8V]R<F5S<&]N9&5N=',@
M=&\@<F5M96UB97(@=VAA="!W87,@:6X@=&AE(&5M86EL(&%N9"!T:'5S(&ES
M('9E<GD@:6UP;W)T86YT(&EN(&]R9V%N:7II;F<@>6]U<B!E;6%I;"!A;F0@
M9FEN9&EN9R!I;7!O<G1A;G0@;VYE<R!L871E<BX@($%L<V\L('=H96X@>6]U
M("=297!L>2<@;W(@)T9O<G=A<F0G(&%N9"!E;6%I;"!T:&ES('-U8FIE8W0@
M;&EN92!I<R!C;W!I960@;W9E<B!I;G1O('1H92!N97<@;65S<V%G92!A;F0@
M<V\@:7,@82!V86QU86)L92!W87D@;V8@=&5L;&EN9R!W:&%T(&UE<W-A9V5S
M(&=O('1O9V5T:&5R('1O(&9O<FT@82`F<75O=#MT:')E860F<75O=#L@;V8@
M82!C;VYV97)S871I;VXN("!(;W=E=F5R+"!I9B!T:&4@)U)E<&QY)R!O<B`G
M1F]R=V%R9"<@8V]N=&%I;G,@;F5W(&ED96%S+"!Y;W4@;6%Y('=A;G0@=&\@
M861D('-I;7!L92!M;V1I9FEC871I;VYS('1O('1H92`G4W5B:F5C="<@;&EN
M92!S;R!T:&4@<F5C:7!I96YT*',I(&-A;B!F;VQL;W<@=&AE('!R;V=R97-S
M:6]N(&]F('1H92`F<75O=#MT:')E860N)G%U;W0["B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;W!T:6]N
M<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DYO=2!-27-S871G93H@
M3W!C:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB3W!C:6]N<R(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($%Q=65S=&5S($]P8VEO;G,@=7,@86IU9&%R
M86X@82!P<F5P87)A<B!E;"!V;W-T<F4@;6ES<V%T9V4N"B`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("`@1F5U(&-L:6-K(&1A;75N="!L82!L;&EG82`B0V]R
M<F5C8VGS(&0G3W)T;V=R869I82(@<&5R(')E=FES87(@;"=O<G1O9W)A9FEA
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!&974@8VQI8VL@9&%M=6YT
M(&QA(&QL:6=A(")!9&IU;G1A<B!A<GAI=7,B('!E<B!V:7-U86QI='IA<B!A
M(&QA('!A<G0@:6YF97)I;W(@9&4@;&$@<.!G:6YA('5N82!L;&ES=&$@9&5L
M<R!A<GAI=7,@861J=6YT871S(&%L(&UI<W-A=&=E+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!!8W1I=F5U(&QA(&-A<V5L;&$@9&4@<V5L96-C:?,@
M=6)I8V%D82!A('5N(&-O<W1A="!D92`B1&5S87(@8_)P:6$B('!E<B!D97-A
M<B!U;F$@8_)P:6$@9"=A<75E<W0@;6ES<V%T9V4@82!L82!C87)P971A(&1E
M(")#;W)R974@16YV:6%T(BX@1W5A<F1E=2!U;F$@8_)P:6$@9&5L<R!M:7-S
M871G97,@:6UP;W)T86YT<R!Q=64@:&5U(&5N=FEA="!P97)Q=>@@=7,@<V5R
M=FER86X@8V]M(&$@<F5F97+H;F-I82!I(&-O;2!A(')E9VES=')E(&1E;"!Q
M=64@<R=H82!D:70N($YO(&5S(')E8V]M86YA8FQE(&=U87)D87(@8V%D87-C
M=6X@9&5L<R!M:7-S871G97,@96YV:6%T('!E<G%UZ"!L82!Q=6]T82!D92!D
M:7-C(&5X8V5D:7+@('+@<&ED86UE;G0@9&5L(&SM;6ET("AE<W!E8VEA;&UE
M;G0@<75A;B!E;G9I974@87)X:75S(&%D:G5N=',I(&D@;&$@=F]S=')A(&+Z
M<W1I82!N;R!P;V1RX"!R96)R92!C87`@86QT<F4@8V]R<F5U(&YO=2X@36%L
M9W)A="!T;W0L('!O9&5U("=A8W1I=F%R)R!A<75E<W1A(&]P8VGS(&-O;2!A
M8V-I\R!P<F5D971E<FUI;F%D82!A;F%N="!A($]P8VEO;G,M)F=T.TEN9F]R
M;6%C:?,@4&5R<V]N86PM)F=T.T5D:71E=2!L97,@=F]S=')E<R!I9&5N=&ET
M871S+B!3:2!M;V1I9FEQ=65U(&%Q=65S=&$@;W!C:?,@<')E9&5T97)M:6YA
M9&$L(&%N974@86UB(&-O;7!T92!A(&PG=71I;&ET>F%R+6QA(&1O;F%T('%U
M92!H875R974@9&4@8G5I9&%R('!E<FGR9&EC86UE;G0@;&$@=F]S=')A(&-A
M<G!E=&$@9&4@(D-O<G)E=2!%;G9I870B(&\@979E;G1U86QM96YT(&QA('9O
M<W1R82!B^G-T:6$@9"=O;7!L:7+@(&D@<75E9&%RX"!I;G-E<G9I8FQE+@H@
M("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M
M<&]S92UO<'1I;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N
M.B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T]P=&EO;G,F
M<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H97-E($]P=&EO;G,@
M:&5L<"!Y;W4@<')E<&%R92!Y;W5R(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@($-L:6-K("9Q=6]T.U-P96QL($-H96-K)G%U;W0[('1O
M(&-H96-K('EO=7(@<W!E;&QI;F<N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@($-L:6-K("9Q=6]T.T%T=&%C:&UE;G1S)G%U;W0[('1O('9I97<@870@
M=&AE(&)O='1O;2!O9B!T:&4@<&%G92!A(&QI<W0@;V8@9FEL97,@871T86-H
M960@=&\@=&AI<R!M97-S86=E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@)G%U;W0[4V%V
M92!C;W!Y)G%U;W0[('1O('-A=F4@82!C;W!Y(&]F('1H:7,@;65S<V%G92!I
M;B!Y;W5R("9Q=6]T.U-E;G0@36%I;"9Q=6]T.R!F;VQD97(N(%-A=F4@8V]P
M:65S(&]F(&EM<&]R=&%N="!E;6%I;',@>6]U('-E;F0@<V\@=&AA="!Y;W4@
M:&%V92!S;VUE=&AI;F<@=&\@<F5F97(@8F%C:R!T;R!L871E<B!A;F0@=&\@
M:V5E<"!A;B!A8V-U<F%T92!R96-O<F0@;V8@=VAA="!W87,@<V%I9"X@5V4@
M9&\@;F]T(')E8V]M;65N9"!Y;W4@<V%V92!E=F5R>2!E;6%I;"!S:6YC92!T
M:&5N('EO=7(@9&ES:R!S=&]R86=E('%U;W1A('=I;&P@8F4@=7-E9"!U<"!Q
M=6EC:VQY("AE<W!E8VEA;&QY('=H96X@>6]U('-E;F0@871T86-H;65N=',I
M(&%N9"!Y;W5R(&UA:6QB;W@@=VEL;"!B92!F=6QL(&%N9"!U;F%B;&4@=&\@
M<F5C96EV92!N97<@:6YC;VUI;F<@96UA:6PN(%EO=2!C86XL(&AO=V5V97(L
M('1U<FX@=&AI<R!F96%T=7)E("=O;B<@87,@>6]U<B!D969A=6QT('=I=&AI
M;B!Y;W5R($ED96YT:71Y+"!B>2!G;VEN9R!T;R!/<'1I;VYS+29G=#M097)S
M;VYA;"!);F9O<FUA=&EO;BTF9W0[161I="!Y;W5R(&ED96YT:71I97,N($)E
M(&-A<F5F=6P@=VAE;B!U<VEN9R!T:&ES(&UO9&EF:65D(&1E9F%U;'0@87,@
M>6]U('=I;&P@;F5E9"!T;R!P97)I;V1I8V%L;'D@<'5R9V4@>6]U<B`F<75O
M=#M396YT($UA:6PF<75O=#L@9F]L9&5R(&]R(&ET('=I;&P@979E;G1U86QL
M>2!M86ME('EO=7(@;6%I;&)O>"!F=6QL(&%N9"!U;G5S96%B;&4N"B`@("`\
M+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O
M<V4M871T86-H(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^3F]U($UI
M<W-A=&=E.B!!9&IU;G1A<CPO=&ET;&4^"B`@("`\:&5A9&EN9SXB061J=6YT
M87(@87)X:75S(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("`@(%!O9')E
M=2!A9&IU;G1A<B!A<GAI=7,@86P@=F]S=')E(&UI<W-A=&=E+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^4&%S(#$Z(%!O9&5U(&9E<BUH;R!T96-L96IA;G0@
M;&$@<G5T82!I(&5L(&YO;2!D92!L)V%R>&EU('%U92!V;VQE=2!A9&IU;G1A
M<B!A;"!M:7-S871G92P@;R!BZ2!P<F5S<VEO;F%N="!E;"!B;W3S(")"<F]W
M<V4B(&D@<V5L96-C:6]N86YT(&PG87)X:74@<75E('9O;&5U(&%D:G5N=&%R
M+B!,82!R=71A(&D@96P@;F]M(&1E(&PG87)X:74@87!A<F5I>&5RX"!A(&PG
MX')E82!D92!T97AT($%N97AE<RX@4')O8V5D:74@82!C;VYT:6YU86-I\R!A
M;"!087,@,BX*("`@(#PO<&%R83X*("`@(#QP87)A/E!A<R`R.B!0<F5S<VEO
M;F5U(&5L(&)O=/,@(D%D:G5N=&%R(BX@16P@;F]M(&D@96P@=&%M86YY(&1E
M(&PG87)X:74@<R=A9F5G:7)A;B!A(&QA(&QL:7-T82!D)V%R>&EU<R!A9&IU
M;G1S+B!496YI=2!E;B!C;VUP=&4@<75E('!E<B!A(&%R>&EU<R!D92!G<F%N
M('1A;6%N>2!I+V\@96X@8V]N;F5X:6]N<R!A($EN=&5R;F5T(&QE;G1E<RP@
M96P@<')O8^ES(&1E('!U:F%R(&D@861J=6YT87(@;"=A<GAI=2!A;"!M:7-S
M871G92!P;W0@=')I9V%R('5N82!M:6-A(&1E('1E;7!S+B!3:2!U<R!P;&%U
M+"!T:6YG=65U('!A8VGH;F-I82!I(&YO(&5X96-U=&5U(&-A<"!A;'1R92!O
M<&-I\R!M96YT<F4@97-P97)E=2X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H
M(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M871T86-H(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8V@\+W1I=&QE/@H@("`@/&AE
M861I;F<^)G%U;W0[071T86-H)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!9;W4@;6%Y(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4[(&]N
M;'D@;VYE(&9I;&4@;6%Y(&)E(&%T=&%C:&5D(&%T(&$@=&EM92X*("`@(#PO
M<&%R83X*("`@(#QP87)A/E-T97`@,3H@16ET:&5R+"!T>7!E('1H92!P871H
M(&%N9"!N86UE(&]F(&$@9FEL92!T:&%T('EO=2!W86YT(&%T=&%C:&5D('1O
M('1H:7,@;65S<V%G92!O<B!C;&EC:R`F<75O=#M"<F]W<V4F<75O=#L@8G5T
M=&]N(&%N9"!S96QE8W0@=&AE(&9I;&4@=&\@8F4@871T871C:&5D+B!4:&4@
M<&%T:"!A;F0@;F%M92!O9B!T:&%T(&9I;&4@;F]W(&%P<&5A<G,@:6X@=&AE
M($%T=&%C:&UE;G0@8F]X+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`R
M.B!$96-I9&4@=VAE=&AE<B!Y;W4@=V%N="!T:&4@9FEL92!T;R!B92!V:65W
M960@87,@86X@871T86-H;65N="!O<B!I;FQI;F5D('=I=&@@=&AE(')E<W0@
M;V8@=&AE(&UE<W-A9V4N(%1H92!R96-E:79I;F<@<&5R<V]N*',I(&UA:6P@
M<F5A9&EN9R!S;V9T=V%R92!M=7-T(&)E(&%B;&4@=&\@:&%N9&QE('1H92!F
M:6QE('1Y<&4@:6YL:6YE.R!I9B!N;W0L('1H:7,@<&%R="!W:6QL(&)E('9I
M97=E9"!A<R!A;B!A='1A8VAM96YT(&EN<W1E860N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#,Z($-L:6-K("9Q=6]T.T%T=&%C:"9Q=6]T.R!B=71T
M;VXN(%1H92!F:6QE(&YA;64@86YD('-I>F4@=VEL;"!B92!A9&1E9"!T;R!Y
M;W5R(&QI<W0@;V8@071T86-H;65N=',N(%!L96%S92!N;W1E('1H870@9F]R
M(&QA<F=E(&9I;&5S(&%N9"]O<B!S;&]W97(@26YT97)N970@8V]N;F5C=&EO
M;G,L('1H92!P<F]C97-S(&]F('5P;&]A9&EN9R!A;F0@871T86-H:6YG('EO
M=7(@9FEL92!T;R!T:&4@96UA:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE87-E
M(&)E('!A=&EE;G0@86YD(&1O(&YO="!C;&EC:R!O=&AE<B!T:&EN9W,@=VAI
M;&4@>6]U(&%R92!W86ET:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(B!S=&%T
M93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^3F]U($UI<W-A=&=E.B!!9&IU;G1A
M<CPO=&ET;&4^"B`@("`\:&5A9&EN9SXB061J=6YT87(B/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!!<75E<W1A('-E8V-I\R!D97-P;&5G82!U;F$@;&QI
M<W1A(&1E;',@87)X:75S(&%D:G5N=',@86P@=F]S=')E(&UI<W-A=&=E+B!0
M97(@82!%;&EM:6YA<B!U;B!A<GAI=2!A9&IU;G0@<V5G=6EU(&5L<R!P87-S
M;W,@<V5G_&5N=',Z(`H@("`@/"]P87)A/@H@("`@/'!A<F$^4&%S(#$Z($%C
M=&EV974@;&$@8V%S96QL82!D92!S96QE8V-I\R!U8FEC861A(&$@=6X@8V]S
M=&%T(&1E;"!N;VT@9&4@;"=A<GAI=2!A9&IU;G0@<75E('9O;&5U(&5L:6UI
M;F%R+@H@("`@/"]P87)A/B`*("`@(#QP87)A/E!A<R`R.B!&974@8VQI8R!A
M(")4<F5U<F4@07)X:74B+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(^"B`@("`\=&ET
M;&4^365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H;65N=',\+W1I=&QE/@H@
M("`@/&AE861I;F<^071T86-H;65N=',\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1H:7,@<V5C=&EO;B!D:7-P;&%Y<R!A(&QI<W0@;V8@9FEL97,@86QR
M96%D>2!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY$96QE=&4@871T86-H960@9FEL92AS*3PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&\@9&5L971E(&%N(&%T=&%C:&5D(&9I;&4H<RDZ
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-T97`@,3H@06-T:79A=&4@
M=&AE(&-H96-K+6)U='1O;B!N97AT('1O('1H92!A='1A8VAE9"!F:6QE;F%M
M92AS*2!Y;W4@=V%N="!T;R!D96QE=&4N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@(%-T97`@,CH@0VQI8VL@)G%U;W0[1&5L971E($%T=&%C:&UE;G0H
M<RDF<75O=#LN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#:&%N9V4@071T
M86-H;65N="!$:7-P;W-I=&EO;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5&\@8VAA;F=E('1H92!D:7-P;W-I=&EO;B!F;W(@>6]U<B!A='1A8VAM96YT
M<SH*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4W1E<"`Q.B!#:&%N9V4@
M96%C:"!A='1A8VAM96YT)W,@9&ES<&]S:71I;VX@+2!E:71H97(@)VEN;&EN
M92<@;W(@)V%T=&%C:&UE;G0G("T@=&\@=&AE(&1E<VER960@=F%L=64N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-T97`@,CH@0VQI8VL@)G%U;W0[
M57!D871E($%T=&%C:&UE;G0@26YF;W)M871I;VXF<75O=#LN"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY#:&%N9V4@071T86-H;65N="!$97-C<FEP=&EO
M;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&\@8VAA;F=E('1H92!D97-C
M<FEP=&EO;B!F;W(@>6]U<B!A='1A8VAM96YT<R`H=&AE('1E>'0@=&AE(')E
M8VEP:65N="!W:6QL('-E92!T:&%T(&1E<V-R:6)E<R!T:&4@871T86-H;65N
M="DZ"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-T97`@,3H@16YT97(@
M82!D97-C<FEP=&EO;B!I;G1O('1H92!$97-C<FEP=&EO;B!F:65L9"X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@4W1E<"`R.B!#;&EC:R`F<75O=#M5
M<&1A=&4@071T86-H;65N="!);F9O<FUA=&EO;B9Q=6]T.RX*("`@(#PO<&%R
M83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UP
M<FEO<FET>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@4')I;W)I='D\+W1I=&QE/@H@("`@/&AE861I;F<^(E!R:6]R
M:71Y(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S971S('1H92`B
M6"U0<FEO<FET>2(@:&5A9&5R(&]N('EO=7(@;W5T9V]I;F<@;65S<V%G92X@
M5&AE(")8+5!R:6]R:71Y(B!T86<@:7,@82!S;W)T(&]F(")P<V5U9&\@<W1A
M;F1A<F0B('1H870@3F5T<V-A<&4L($UO>FEL;&$L($]P97)A+"!A;F0@3W5T
M;&]O:R!M86EL(&-L:65N=',@87!P96%R('1O(&%G<F5E(&]N+B!!;GD@;6%I
M;"!C;&EE;G1S('1H870@9&\@;F]T(&AA;F1L92!T:&ES(&AE861E<B!W:6QL
M('-I;7!L>2!I9VYO<F4@:70N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)C;VUP;W-E+7-A=F4M871T86-H;65N=',B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%-A=F4@071T86-H
M;65N=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H971H
M97(@=&AE(&%T=&%C:&UE;G1S(&EN('EO=7(@8V]M<&]S:71I;VX@87)E('-A
M=F5D('=I=&@@=&AE(&UE<W-A9V4@=VAE;B!S=&]R960@:6X@=&AE('-E;G0M
M;6%I;"!F;VQD97(N("!)9B`B665S(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W
M:6QL(&)E('-A=F5D+B`@268@(DYO(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W
M:6QL(&)E('-T<FEP<&5D(&9R;VT@=&AE(&UE<W-A9V4@869T97(@:70@:7,@
M<V5N="!T;R!A;&P@<F5C:7!I96YT<RX@($-H;V]S:6YG(").;R(@=VEL;"!H
M96QP(&-O;G-E<G9E(&1I<VL@<W!A8V4@8GD@<F5M;W9I;F<@*'!O=&5N=&EA
M;&QY(&QA<F=E*2!A='1A8VAM96YT(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-A
M=F5D(&UE<W-A9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UL:6YK+6%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!,:6YK($%T=&%C:&UE;G1S
M/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H
M92!A='1A8VAM96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N(&%R92!S96YT(&%S
M(&$@<&%R="!O9B!T:&4@;6%I;"!M97-S86=E(&]R('=H971H97(@=&AO<V4@
M871T86-H;65N=',@87)E(&ME<'0@;VX@82!L;V-A;"!S97)V97(N("!)9B!A
M='1A8VAM96YT<R!A<F4@;&EN:V5D+"!T:&4@<F5C:7!I96YT*',I(&]F('EO
M=7(@;65S<V%G92!W:6QL(&)E('!R;W9I9&5D(&$@=V5B;&EN:R!W:&5R92!T
M:&5Y(&-A;B!D;W=N;&]A9"!T:&4@871T86-H;65N="AS*2X@($QI;FMI;F<@
M871T86-H;65N=',@:&%S('1H92!A9'9A;G1A9V4@;V8@=')E;65N9&]U<VQY
M(')E9'5C:6YG('1H92!S:7IE(&]F(&]U=&=O:6YG(&UE<W-A9V5S+B`@3&EN
M:VEN9R!A='1A8VAM96YT<R!H87,@=&AE(&1I<V%D=F%N=&%G92!T:&%T('1H
M92!C;VYT96YT(&]F('1H92!A='1A8VAM96YT<R!C86X@;F]T(&)E(&=U87)A
M;G1E960@=&\@8F4@879A:6QA8FQE(&EN('1H92!F=71U<F4@<VEN8V4@=&AE
M(&%T=&%C:&UE;G0@9&%T82!I<R!N;W0@;&]C871E9"!W:71H:6X@=&AE(&4M
M;6%I;"!M97-S86=E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<V5A<F-H(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^0V5R8V$@
M9&4@36ES<V%T9V5S/"]T:71L93X*("`@(#QH96%D:6YG/D-R:71E<FD@9&4@
M;&$@0V5R8V$\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@("!497AT(&0G
M86IU9&$@<&5R(.ES<V5R(&5S8W)I="X*("`@(#PO<&%R83X*/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](G-E87)C:"(^"B`@("`\=&ET;&4^365S
M<V%G92!396%R8V@\+W1I=&QE/@H@("`@/&AE861I;F<^4V5A<F-H($-R:71E
M<FEA/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y('-E87)C:"!F
M;W(@;65S<V%G97,@9G)O;2!Y;W5R(&9O;&1E<G,@=7-I;F<@9&EF9F5R96YT
M('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@
M,3H@16YT97(@=&5X="!T;R!T:&4@9FEE;&1S('EO=2!W86YT('1O(&%D9"!T
M;R!Y;W5R('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*("`@(#QP87)A
M/E-T97`@,CH@0VAO;W-E('1H92!M97-S86=E(&9L86<H<RD@=&\@861D('1O
M('EO=7(@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M4W1E<"`S.B!#:&]O<V4@=&AE(&9O;&1E<BAS*2!F<F]M('=H:6-H('1O('-E
M87)C:"!F;W(@=&AE(&UE<W-A9V5S+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M4W1E<"`T.B!#;&EC:R`F<75O=#M396%R8V@F<75O=#LN"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@($EF(&%N>2!M97-S86=E<R!M871C:&5D('EO=7(@
M<V5A<F-H(&-R:71E<FEA+"!T:&5N('1H92!S=6)J96-T<R!O9B!T:&5S92!M
M97-S86=E<R!W:6QL(&)E('-H;W=N(&EN('1H92`F<75O=#M396%R8V@@4F5S
M=6QT<R9Q=6]T.R!V:65W+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/E5T:6QI='IA8VGS(&1E($-A<G!E=&5S/"]T:71L
M93X*("`@(#QH96%D:6YG/D]P8VEO;G,@9&4@0V%R<&5T97,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@4&]D974@<V5L96-C:6]N87(@=6YA(&-A<G!E
M=&$@=71I;&ET>F%N="!E;',@8F]T;VYS(&1E('+@9&EO<R!U8FEC86YT<R!A
M(&QA(&-O;'5M;F$@97-Q=65R<F$N(%5N(&-O<"!F970@86EX\BP@<V5L96-C
M:6]N974@;"=O<&-I\R!Q=64@9&5S:71J974@97AE8W5T87(@82!L82!C87)P
M971A('5T:6QI='IA;G0@;&$@8V%S96QL82!D92!S96QE8V-I\R!D92!L)V5S
M<75E<G)A+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@($5L('!R;V=R
M86UA('5S('!R96=U;G1A<N`@<&5R(&%L9W5N97,@;W!C:6]N<R!S=7!L96UE
M;G3@<FEE<RX@H4%N974@86UB(&-O;7!T92!A;6(@;"=O<&-I\R!E;&EM:6YA
M<B!P97)Q=>@@<&]D<NUE=2!P97)D<F4@=&]T<R!E;',@;6ES<V%T9V5S(&0G
M=6YA(&-A<G!E=&$@<VD@;"=E;&EM:6YE=2!P97(@97%U:79O8V%C:?,A"B`@
M("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F;VQD
M97(M;W!T:6]N<R(^"B`@("`\=&ET;&4^1F]L9&5R($UA;F%G96UE;G0\+W1I
M=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($]P=&EO;G,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@82!F;VQD97(@8GD@=7-I
M;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE(&QE9G0@8V]L=6UN+B`@
M3VYC92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C="!T:&4@;W!T:6]N('EO
M=2!W:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E<B!V:6$@=&AE('-E;&5C
M="!B;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M("`@66]U('=I;&P@8F4@<')O;7!T960@9F]R(&9U<G1H97(@;W!T:6]N<RX@
M($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO;BP@87,@>6]U(&-A
M;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD97(@:68@>6]U(&1E
M;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M26UP;W)T(&UB;W@@1FEL93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!4
M:&ES(&]P=&EO;B!W:6QL(&EM<&]R="!A(&UB;W@@9F]R;6%T(&9I;&4@:6YT
M;R!T:&4@9F]L9&5R(&]F('EO=7(@8VAO:6-E+B!#:&]O<V4@,2`H;VYE*2!F
M;VQD97(@=&\@:6UP;W)T('1H92!M97-S86=E<R!I;G1O(&%N9"!T:&5N('-E
M;&5C="!T:&ES(&]P=&EO;BX@66]U('=I;&P@=&AE;B!B92!T86ME;B!T;R!A
M('!A9V4@=&AA="!W:6QL('!R;VUP="!F;W(@=&AE(&UB;W@@9FEL92!T;R!I
M;7!O<G0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT
M<GD@:60](F9O;&1E<BUW:61G971S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y&;VQD97(@36%N86=E;65N=#H@1&ES<&QA>3PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY3:&]W+TAI9&4@56YS=6)S8W)I8F5D/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!)9B!U<VEN9R!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS+"!S
M:&]W+VAI9&4@=&AE('5N<W5B<V-R:6)E9"!F;VQD97)S+B`@5&\@<W5B<V-R
M:6)E+W5N<W5B<V-R:6)E('1O(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K
M8F]X(&YE>'0@=&\@=&AE(&9O;&1E<FYA;64@86YD('5S92!T:&4@4W5B<V-R
M:6)E+U5N<W5B<V-R:6)E(&]P=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D
M<F]P+61O=VX@;65N=2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X<&%N
M9"!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5X<&%N9"!A;&P@9F]L
M9&5R(&5N=')I97,N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S
M92!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-O;&QA<'-E(&%L;"!F
M;VQD97(@96YT<FEE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](F9I;'1E<G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y&:6QT
M<F5S.B!!<&QI8V%R/"]T:71L93X*("`@(#QH96%D:6YG/D%P;&EC87(@4F5G
M;&5S(&1E($9I;'1R870\+VAE861I;F<^"B`@("`\<&%R83X*("`@($9E=2!C
M;&EC(&1A;75N="!L)VEC;VYA($%P;&EC87(@1FEL=')E('%U92!T<F]B87)E
M=2!A(&-O;G1I;G5A8VGS(&1E;"!N;VT@9&5L(&QL:7-T870@9&4@;',@8OIS
M=&EA($E.0D]8('!E<B!F:6QT<F%R('1O=',@96QS(&UI<W-A=&=E<R!Q=64@
M;F\@<R=H86X@96QI;6EN870@<V5G;VYS(&QE<R!R96=L97,@97-P96-I9FEC
M861E<RX@3RP@86QT97)N871I=F%M96YT+"!F974@8VQI8R!E;B!!<&QI8V%R
M(%1O=&5S(&QE<R!296=L97,@96X@96P@;65N^B!D92!F:6QT<F5S+B!(974@
M9&4@=&5N:7(@96X@8V]M<'1E('%U92!E;"!F:6QT<F%T(&YO(&5S(')E86QI
M='IA<N`@9&4@;6%N97)A(&%U=&]MX'1I8V$N"B`@("`\+W!A<F$^"CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F:6QT97)S(CX*("`@(#QT:71L
M93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!&
M:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N
M('1H92`F<75O=#M!<'!L>2!&:6QT97(F<75O=#L@:6-O;B!N97AT('1O('1H
M92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X('9I97<@=&\@9FEL=&5R(&%L
M;"!U;F1E;&5T960@;65S<V%G97,@86-C;W)D:6YG('1O('1H92!S<&5C:69I
M960@<G5L97,N("!/<BP@86QT97)N871I=F5L>2P@8VQI8VL@;VX@)G%U;W0[
M07!P;'D@06QL(%)U;&5S)G%U;W0[(&EN('1H92!F:6QT97(@;65N=2X@($YO
M=&4@=&AA="!F:6QT97)I;F<@:7,@;F]T(&1O;F4@875T;VUA=&EC86QL>2X*
M("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M9FEL=&5R+65D:70M<G5L97,B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I
M;'1E<G,Z($5D:70@1FEL=&5R(%)U;&5S/"]T:71L93X*("`@(#QH96%D:6YG
M/D5D:70@66]U<B!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($-L:6-K(&]N(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(B!T;R!P<F]C
M965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L(&%N
M9"!E9&ET('1H92!C=7)R96YT;'D@86-T:79E('-E="!O9B!F:6QT97(@<G5L
M97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M
M961I="UB;&%C:VQI<W0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E
M<G,Z($5D:70@0FQA8VML:7-T/"]T:71L93X*("`@(#QH96%D:6YG/D5D:70@
M66]U<B!";&%C:VQI<W0\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K
M(&]N(")%9&ET('EO=7(@8FQA8VML:7-T(B!T;R!P<F]C965D('1O('1H92!P
M86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L(&%N9"!E9&ET('1H92!L
M:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U($%,5T%94R!R969U<V4@;6%I
M;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL
M=&5R+65D:70M=VAI=&5L:7-T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&
M:6QT97)S.B!%9&ET(%=H:71E;&ES=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY%
M9&ET(%EO=7(@5VAI=&5L:7-T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#
M;&EC:R!O;B`B161I="!Y;W5R('=H:71E;&ES="(@=&\@<')O8V5E9"!T;R!T
M:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E+"!A;F0@961I="!T
M:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S('EO=2!!3%=!65,@86-C97!T
M(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(F9I;'1E<BUO;BUL;V=I;B(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL
M=&5R<SH@1FEL=&5R(&]N($QO9VEN/"]T:71L93X*("`@(#QH96%D:6YG/D%P
M<&QY($9I;'1E<B!2=6QE<R!5<&]N($QO9V]N/SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@=&\@86QW87ES(&%P<&QY(&9I
M;'1E<G,@=VAE;B!F:7)S="!L;V=G:6YG(&]N=&\@24U0+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+61I<W!L87DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!O;B!2969R
M97-H/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY(&9I;'1E<B!R=6QE<R!W
M:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T;R!A;'=A>7,@87!P;'D@9FEL
M=&5R<R!W:&5N979E<B!Y;W5R('9I97<@=&AE($E.0D]8/PH@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6%N>2UM86EL8F]X(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!&:6QT97(@86YY($UA
M:6QB;W@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@9FEL=&5R(')U;&5S
M('1O(&%N>2!M86EL8F]X/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE
M8VL@=&AI<R!O<'1I;VX@:68@>6]U('=A;G0@=&\@8F4@86QL;W=E9"!T;R!A
M<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA:6QB;W@N($YO<FUA;&QY+"!F
M:6QT97)I;F<@<G5L97,@87)E(&]N;'D@87!P;&EE9"!T;R!N97<@;6%I;"!T
M:&%T(&ES(&1E;&EV97)E9"!T;R!Y;W5R($E.0D]8+B`@268@=&AI<R!O<'1I
M;VX@:7,@8VAE8VME9"P@86X@:6-O;B!W:6QL(&%P<&5A<B!O;B!A;&P@;6%I
M;&)O>"!P86=G97,@=&AA="!W:6QL(&%L;&]W('EO=2!T;R!A<'!L>2!F:6QT
M97(@<G5L97,@=&\@=&AE(&UE<W-A9V5S(&EN('1H92!C=7)R96YT(&UA:6QB
M;W@N("!.3U1%.B!&:6QT97)I;F<@:6X@;6%I;&)O>&5S(&]T:&5R('1H86X@
M24Y"3U@@;6%Y('!R;V1U8V4@<W1R86YG92`H92YG+B!T:&4@9FEL=&5R(&UA
M>2!C875S92!A(&-O<'D@;V8@;65S<V%G97,@=&\@8F4@9&5L:79E<F5D('1O
M('1H92!S86UE(&UA:6QB;W@I(&%N9"]O<B!U;F1E<VER960@<F5S=6QT<R`H
M92YG+B!I="!M87D@8V%U<V4@;65S<V%G97,@=&\@8F4@;6]V960O9&5L971E
M9"!I9B!N97<@9FEL=&5R:6YG(')U;&5S(&AA=F4@8F5E;B!I;7!L96UE;G1E
M9"!S:6YC92!T:&4@;65S<V%G92!H87,@8F5E;B!D96QI=F5R960@=&\@=&AE
M(&-U<G)E;G0@;6%I;&)O>"DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M<'5B:V5Y(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y01U`Z($%T=&%C:"!0=6)L:6,@2V5Y/"]T:71L93X*
M("`@(#QH96%D:6YG/D%T=&%C:"!0=6)L:6,@2V5Y/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N(&$@8V]P>2!O9B!Y;W5R(%!'
M4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L('=I;&P@8F4@871T86-H960@
M=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N("!9;W4@8V%N('-E="!T:&4@9&5F
M875L="!B96AA=FEO<B!V:6$@=&AE(%!'4"!/<'1I;VYS('-C<F5E;BX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I;VXM<V-A
M;BUB;V1Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z(%-C86X@5&5X
M="!";V1I97,\+W1I=&QE/@H@("`@/&AE861I;F<^4V-A;B!497AT($)O9&EE
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@<V5L96-T960@=&AE;B!)
M35`@=VEL;"!S8V%N('1H92!B;V1Y(&]F(&%L;"!T97AT(&UE<W-A9V5S(&9O
M<B!01U`@9&%T82P@86YD(&1I<W!L87D@=&AE(')E<W5L=',@:68@86YY(&1A
M=&$@:7,@9F]U;F0N("!.;W1E('1H870@=&AI<R!M87D@<VQO=R!D;W=N('1H
M92!S>7-T96T@87,@979E<GD@=&5X="!M97-S86=E(&UU<W0@8F4@<V-A;FYE
M9"!I;B!I=',@96YT:7)E='D@9F]R(%!'4"!D871A+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO<'1I;VYS+65N8W)Y<'0B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/D-O;7!O<V4Z($5N8W)Y<'1I;VX@
M3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY.;R!%;F-R>7!T:6]N/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD('1H92!M97-S86=E('=I=&@@
M;F\@96YC<GEP=&EO;B`H8VQE87)T97AT*2X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E!'4"!%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%1H:7,@;W!T:6]N('=I;&P@96YC<GEP="!T:&4@8W5R<F5N="!M
M97-S86=E+"!U<VEN9R!01U`@86YD('1H92!R96-I<&EE;G1S('!E<G-O;F%L
M('!U8FQI8R!K97DL(&%N9"!T:&5N('-E;F0@:70N(%EO=2!C86X@;VYL>2!S
M96YD(&$@;65S<V%G92!T;R!A('-I;F=L92!P97)S;VX@=7-I;F<@=&AI<R!O
M<'1I;VXN(%EO=2!-55-4(&AA=F4@=&AE('!U8FQI8R!K97D@;V8@=&AE(')E
M8VEP:65N="!S=&]R960@:6X@>6]U<B!A9&1R97-S8F]O:R!O<B!E;'-E('1H
M:7,@;W!T:6]N('=I;&P@9F%I;"X@268@>6]U(&AA=F4@=&AE('!U8FQI8R!K
M97D@9F]R('1H92!R96-I<&EE;G0@:6X@>6]U<B!A9&1R97-S8F]O:R!A;F0@
M87)E('-T:6QL(')E8V5I=FEN9R!E<G)O<G,L('9E<FEF>2!T:&%T('1H92!E
M+6UA:6P@861D<F5S<R!I;B!T:&4@<F5C:7!I96YT(&9I96QD(&UA=&-H97,@
M=&AE(&4M;6%I;"!A9&1R97-S('=H97)E('1H92!P=6)L:6,@:V5Y(&ES('-T
M;W)E9"X@5&AE(&5N8W)Y<'1E9"!D871A('=I;&P@8F4@871T86-H960@=&\@
M=&AE(&]U=&=O:6YG(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY01U`@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M:&ES(&]P=&EO;B!W:6QL(&1I9VET86QL>2!S:6=N('1H92!C=7)R96YT(&UE
M<W-A9V4@=7-I;F<@4$=0(&%N9"!Y;W5R('!E<G-O;F%L('!R:79A=&4@:V5Y
M+B!)9B!Y;W4@:&%V92!N;W0@86QR96%D>2!E;G1E<F5D('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R('!R:79A=&4@:V5Y(&1U<FEN9R!T:&ES('-E<W-I;VX@
M>6]U('=I;&P@8F4@<')O;7!T960@9F]R(&ET+B`@5&AE(')E8V5I<&EE;G0@
M;75S="!H879E(&$@8V]P>2!O9B!Y;W5R('!U8FQI8R!K97D@=&\@9&EG:71A
M;&QY('9E<FEF>2!Y;W5R"B`@("!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@9FER<W0@9&EG:71A
M;&QY('-I9VX@>6]U<B!M97-S86=E(&%N9"!T:&5N('=I;&P@96YC<GEP="!T
M:&4@<F5S=6QT:6YG(&]U='!U="X@4V5E('1H92`G4$=0($5N8W)Y<'0@365S
M<V%G92<@86YD("=01U`@4VEG;B!-97-S86=E)R!E;G1R:65S(&9O<B!F=7)T
M:&5R(&EN9F]R;6%T:6]N+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4R]-
M24U%($5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^4R]-24U%(%-I9VX@365S
M<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5$]$3PH@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!'4#H@3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE861I;F<^
M5VAA="!I<R!01U`_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!01U`@:7,@
M82!T;V]L(&9O<B!S96-U<F4@8V]M;75N:6-A=&EO;B!A;F0@9&%T82!S=&]R
M86=E+"!E<W!E8VEA;&QY(&9O<B!U<V4@=VET:"!E+6UA:6PN($ET(&-A;B!B
M92!U<V5D('1O(&5N8W)Y<'0@9&%T82!A;F0@=&\@8W)E871E(&1I9VET86P@
M<VEG;F%T=7)E<RX@24U0('5S97,@1VYU4$<@*$=.52!0<FEV86-Y($=U87)D
M*2!T;R!P<F]V:61E('1H:7,@9G5N8W1I;VYA;&ET>2X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/D5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@;W!T:6]N(&ES('-E;&5C=&5D
M+"!Y;W4@=VEL;"!B92!A8FQE('1O(&-R96%T92]V:65W('EO=7(@<&5R<V]N
M86P@4$=0(&ME>7,L(&%D9"]D96QE=&4@<'5B;&EC(&ME>7,@9G)O;2!O=&AE
M<B!I;F1I=FED=6%L<RP@<F5A9"!E;F-R>7!T960@;6%I;"P@=F5R:69Y(&1I
M9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N8W)Y<'0O<VEG;B!Y;W5R(&]U
M=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M;W!T:6]N+6%T=&%C:"UP=6)K97DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@3W!T:6]N<R`M($%T=&%C:"!0=6)L:6,@2V5Y/"]T:71L
M93X*("`@(#QH96%D:6YG/D]P=&EO;G,@+2!!='1A8V@@4'5B;&EC($ME>3PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@<V5L96-T960@=&AE;B!A(&-O
M<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@:68@:70@97AI<W1S+"!W:6QL
M(&)Y(&1E9F%U;'0@8F4@871T86-H960@=&\@86QL(&]U=&=O:6YG(&UE<W-A
M9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6UA
M;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N
M86=E(%!U8FQI8R!+97ES/"]T:71L93X*("`@(#QH96%D:6YG/D]V97)V:65W
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES('-C<F5E;B!L:7-T<R!A
M;&P@;V8@=&AE(&-U<G)E;G0@=7-E<G,@:6X@>6]U<B!A9&1R97-S8F]O:R!T
M:&%T(&AA=F4@4$=0('!U8FQI8R!K97ES+B!4:&5S92!U<V5R<R!A<F4@=&AE
M($].3%D@=7-E<G,@=&AA="!Y;W4@8V%N(&5I=&AE<B`Q*2!S96YD(&%N(&5N
M8W)Y<'1E9"!M97-S86=E('1O("U/4BT@,BD@=F5R:69Y(&$@9&EG:71A;"!S
M:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T;R!V:65W('1H
M92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E
M=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1I<W!L87ES('-O;64@
M9&5T86EL<R!A8F]U="!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY$96QE=&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($1E;&5T97,@=&AE('!U8FQI8R!K97D@9G)O;2!Y;W5R(&%D9')E<W-B;V]K
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6EM<&]R
M="UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E
M(%!U8FQI8R!+97ES("T@26UP;W)T/"]T:71L93X*("`@(#QH96%D:6YG/DEM
M<&]R="!0=6)L:6,@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI
M<R!B=71T;VX@=VEL;"!O<&5N(&$@=VEN9&]W('=H97)E('EO=2!C86X@;6%N
M=6%L;'D@:6UP;W)T(&$@4$=0('!U8FQI8R!K97DN("!4:&4@:V5Y(&-A;B!E
M:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT9FEE;&0@;W(L(&EF('1H92!K
M97D@<F5S:61E<R!I;B!A(&9I;&4@;VX@>6]U<B!L;V-A;"!C;VUP=71E<BP@
M>6]U(&-A;B!I;7!O<G0@:70N("!)9B!T:&4@:V5Y(&ES('9A;&ED(&ET('=I
M;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R(&%D9')E<W-B;V]K(&%N9"!T:&4@
M=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S
M<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]V97)V:65W+7!E<G-O
M;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!0
M97)S;VYA;"!+97ES/"]T:71L93X*("`@(#QH96%D:6YG/D]V97)V:65W/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V%N="!T;R!D:6=I=&%L
M;'D@<VEG;B!M97-S86=E<R!O<B!E;F%B;&4@;W1H97)S('1O('-E;F0@>6]U
M(&5N8W)Y<'1E9"!M97-S86=E<RP@>6]U(&UU<W0@:&%V92!Y;W5R(&]W;B!P
M97)S;VYA;"!P=6)L:6,O<')I=F%T92!01U`@:V5Y<&%I<BX*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/EEO=7(@4'5B;&EC($ME>3PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@66]U<B!P=6)L:6,@:V5Y('-H;W5L9"!B92!M861E(&%V
M86EL86)L92!T;R!A;GD@<&5R<V]N('1H870@>6]U('=A;G0@=&\@8F4@86)L
M92!T;R!S96YD('EO=2!E;F-R>7!T960@;65S<V%G97,@=&AA="!O;FQY(%E/
M52!C86X@9&5C<GEP="`H=7-I;F<@>6]U<B!P<FEV871E(&ME>2DN($%D9&ET
M:6]N86QL>2P@>6]U<B!P=6)L:6,@:V5Y(&YE961S('1O(&)E(&UA9&4@879A
M:6QA8FQE('1O(&%N>6)O9'D@>6]U('-E;F0@82!D9&EG:71A;&QY('-I9VYE
M9"!M97-S86=E('1O("T@=&AE('!U8FQI8R!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!D:6=I=&%L('-I9VYA='5R92X*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/EEO=7(@4')I=F%T92!+97D\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%EO=7(@<')I=F%T92!K97D@:7,@;F5C97-S87)Y('1O(&1E8W)Y
M<'0@86YY(&UE<W-A9V4@96YC<GEP=&5D('5S:6YG('EO=7(@<'5B;&EC(&ME
M>2X@061D:71I;VYA;&QY+"!Y;W5R('!R:79A=&4@:V5Y(&ES(&YE961E9"!I
M9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!A(&UE<W-A9V4N(%EO=7(@
M<')I=F%T92!K97D@=VEL;"!B92!P<F]T96-T960@=FEA(&$@<&%S<W!H<F%S
M92!C<F5A=&5D('=H96X@=&AE(&ME>7,@87)E(&=E;F5R871E9"X@5&AU<RP@
M=&\@<&5R9F]R;2!A;GD@86-T:79I='D@=&AA="!R97%U:7)E<R!Y;W5R('!R
M:79A=&4@:V5Y+"!)35`@=VEL;"!P<F]M<'0@>6]U(&9O<B!Y;W5R('!A<W-P
M:')A<V4N(%EO=2!O;FQY(&YE960@=&\@:6YS97)T('EO=7(@<&%S<W!H<F%S
M92!O;F-E('!E<B!S97-S:6]N("T@24U0('=I;&P@<W1O<F4@>6]U<B!P87-S
M<&AR87-E('5N=&EL('EO=2!L;V=O=70@*%-O(&)E('-U<F4@=&\@;&]G;W5T
M(2DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R
M<V]N86QK97DM<'5B;&EC(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z
M($UA;F%G92!097)S;VYA;"!+97ES("T@4'5B;&EC($ME>3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N
M<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!U
M8FQI8R!K97DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M<&5R<V]N86QK97DM<')I=F%T92(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M(%!R:79A=&4@2V5Y/"]T
M:71L93X*("`@(#QH96%D:6YG/D5N=&5R(%!A<W-P:')A<V4\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($]P96YS('1H92!P87-S<&AR87-E(&1I86QO9R!W
M:6YD;W<N(%1H92!P87-S<&AR87-E(&5N=&5R960L(&EF(&-O<G)E8W0L('=I
M;&P@8F4@<W1O<F5D(&)Y($E-4"!U;G1I;"!Y;W5R('-E<W-I;VX@96YD<RX*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5N;&]A9"!087-S<&AR87-E/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!296UO=F5S('1H92!S=&]R960@<&%S
M<W!H<F%S92!F<F]M($E-4"`M(&%N>2!A9&1I=&EO;F%L('5S86=E(&]F('1H
M92!P<FEV871E(&ME>2!W:6QL(')E<75I<F4@>6]U('1O(')E96YT97(@=&AE
M('!A<W-P:&5A<V4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T;R!V:65W
M('1H92!01U`@<')I=F%T92!K97DN($1/($Y/5"!314Y$(%1(25,@2T59(%1/
M($%.64].12`M('1H:7,@;W!T:6]N(&ES('-T<FEC=&QY('-O('1H870@>6]U
M(&-A;B!E>'!O<G0@>6]U<B!)35`@<&5R<V]N86P@<')I=F%T92!K97D@9F]R
M('5S92!I;B!A;F]T:&5R('!R;V=R86TN"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y
M<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P<FEV871E(&ME>2X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME
M>2UD96QE=&4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E
M(%!E<G-O;F%L($ME>7,@+2!$96QE=&4\+W1I=&QE/@H@("`@/&AE861I;F<^
M1&5L971E(%!E<G-O;F%L($ME>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1H:7,@8G5T=&]N('=I;&P@9&5L971E('EO=7(@<&5R<V]N86P@<'5B;&EC
M+W!R:79A=&4@:V5Y<&%I<B!F<F]M($E-4"=S('!R969E<F5N8V5S+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y
M+6-R96%T92UN86UE(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R
M96%T92!097)S;VYA;"!+97D@+2!.86UE/"]T:71L93X*("`@(#QH96%D:6YG
M/DYA;64\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!N86UE('EO=2!W
M86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@:V5Y<RX@02!R97%U:7)E
M9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UP97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N="(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@0V]M;65N=#PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY#;VUM96YT/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!!(&-O;6UE;G0@<W1R:6YG('EO=2!W86YT(&5M8F5D9&5D(&EN
M('EO=7(@<&5R<V]N86P@:V5Y<RX@06X@;W!T:6]N86P@9FEE;&0N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM
M8W)E871E+65M86EL(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R
M96%T92!097)S;VYA;"!+97D@+2!%+6UA:6P@061D<F5S<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY%+6UA:6P@061D<F5S<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AE(&4M;6%I;"!A9&1R97-S('EO=2!W86YT(&%S<V]C:6%T960@
M=VET:"!Y;W5R('!E<G-O;F%L(&ME>7,N($$@<F5Q=6ER960@9FEE;&0N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK
M97DM8W)E871E+6ME>6QE;F=T:"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@2V5Y;&5N9W1H/"]T:71L93X*
M("`@(#QH96%D:6YG/DME>6QE;F=T:#PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@5&AE(&ME>6QE;F=T:"P@:6X@8GET97,L(&]F('EO=7(@9V5N97)A=&5D
M(&ME>2X@5&AE(&=R96%T97(@=&AE('9A;'5E+"!T:&4@9W)E871E<B!T:&4@
M<')O=&5C=&EO;B`H86YD(&%L<V\@9W)E871E<B!G96YE<F%T:6]N('1I;64@
M86YD(&5N8W)Y<'1I;VX@=&EM92DN(#$P,C0@8GET97,@:7,@=&AE(&1E9F%U
M;'0@+2!T:&ES('9A;'5E('!R;W9I9&5S(&5X8V5L;&5N="!P<F]T96-T:6]N
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O
M;F%L:V5Y+6-R96%T92UP87-S<&AR87-E(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!087-S<&AR87-E/"]T
M:71L93X*("`@(#QH96%D:6YG/E!A<W-P:')A<V4\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H92!P87-S<&AR87-E('5S960@=&\@<')O=&5C="]E;F-R
M>7!T('EO=7(@<&5R<V]N86P@<')I=F%T92!K97DN(%1H:7,@<VAO=6QD(&)E
M($%4($Q%05-4(#8@8VAA<F%C=&5R<RP@<VAO=6QD($Y/5"!B92!T:&4@<V%M
M92!A<R!Y;W5R(&QO9VEN('!A<W-W;W)D+"!S:&]U;&0@3D]4(&)E(&)A<V5D
M(&]N(&$@9&EC=&EO;F%R>2!W;W)D+"!A;F0@<VAO=6QD(&EN8VQU9&4@8F]T
M:"!N=6UB97)S(&%N9"!L971T97)S+B!9;W4@;75S="!E;G1E<B!T:&ES('!A
M<W-P:')A<V4@='=I8V4@9F]R('9E<FEF:6-A=&EO;B!P=7)P;W-E<RX@02!R
M97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M86-T:6]N<R(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@06-T
M:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY#<F5A=&4@2V5Y<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@0W)E871E(&%N9"!S=&]R92!Y;W5R('!E<G-O
M;F%L('!U8FQI8R]P<FEV871E(&ME>7!A:7(N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY);7!O<G0@2V5Y<&%I<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@26UP;W)T(&$@<&5R<V]N86PO<')I=F%T92!K97EP86ER+B!4:&ES(&)U
M='1O;B!O<&5N<R!A('=I;F1O=R!W:&5R92!Y;W4@8V%N(&UA;G5A;&QY(&EM
M<&]R="!Y;W5R(&5X:7-T:6YG(%!'4"!P97)S;VYA;"!P=6)L:6,O<')I=F%T
M92!K97EP86ER+B`@5&AE(&ME>7,@8V%N(&5I=&AE<B!B92!P87-T960@:6YT
M;R!A('1E>'1F:65L9"!O<BP@:68@=&AE(&ME>7,@<F5S:61E(&EN(&$@9FEL
M92!O;B!Y;W5R(&QO8V%L(&-O;7!U=&5R+"!Y;W4@8V%N(&EM<&]R="!T:&5M
M+B`@268@=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E
M9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C
M;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@
M<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=R(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4R]-24U%.B!/=F5R=FEE=SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY7:&%T(&ES(%,O34E-13\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%,O
M34E-12!I<R!A('!R:79A=&4O<'5B;&EC(&ME>2!P86ER('-Y<W1E;2!W:&EC
M:"!P<F]V:61E<R!D:6=I=&%L('-I9VYA='5R97,L(&UE<W-A9V4@<')I=F%C
M>2P@86YD('1A;7!E<B!D971E8W1I;VX@:6X@82!O<&5N+"!I;G1E<F]P97)A
M8FQE('=A>2X@(%,O34E-12!C86X@<')O=FED92!M97-S86=E('!R:79A8WD@
M8GD@96YC<GEP=&EN9R!M97-S86=E<R!T:&%T(&]N;'D@=&AE('-E;F1E<B!A
M;F0@=&AE(&EN=&5N9&5D(')E8VEP:65N=',@8V%N(&1E8V]D92X@($ET(&%L
M;&]W<R!Y;W4@=&\@:61E;G1I9GD@=&AE('-E;F1E<B!O9B!A(&UE<W-A9V4@
M=FEA(&$@9&EG:71A;"!S:6=N871U<F4N("!4;V=E=&AE<BP@=&AI<R!E;F-R
M>7!T:6]N(&%N9"!D:6=I=&%L('-I9VYI;F<@:&5L<"!P<F]V:61E('1A;7!E
M<B!D971E8W1I;VXL(&%L;&]W:6YG(')E8VEP:65N=',@=&\@9&5T97)M:6YE
M('=H971H97(@82!M97-S86=E('=A<R!A;'1E<F5D(&%F=&5R(&ET('=A<R!S
M96YT+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16YA8FQE(%,O34E-12!F
M=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=&AI
M<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@:6UP
M;W)T('EO=7(@<&5R<V]N86P@4R]-24U%(&ME>7,L(')E860@96YC<GEP=&5D
M(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG;F5D(&UA:6PL(&%N9"!E;F-R
M>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<M<&5R<V]N86QK97DB
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@4&5R<V]N86P@2V5Y
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@268@>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@;W(@
M96YC<GEP="!M97-S86=E<R!Y;W4@;75S="!H879E('EO=7(@;W=N('!E<G-O
M;F%L('!U8FQI8R]P<FEV871E(%,O34E-12!K97EP86ER+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M:6UP;W)T+7!E<G-O;F%L
M+6-E<G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z($EM<&]R
M="!097)S;VYA;"!#97)T:69I8V%T97,\+W1I=&QE/@H@("`@/&AE861I;F<^
M26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@26UP;W)T('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M(&$@
M4$M#4R`C,3(@9F]R;6%T(&9I;&4N(%!+0U,@(S$R(&9I;&5S(&ES('1H92!F
M:6QE('5S=6%L;'D@9V5N97)A=&5D('=H96X@97AP;W)T:6YG(&$@:V5Y(&9R
M;VT@82!B<F]W<V5R("AE+F<N($EN=&5R;F5T($5X<&QO<F5R+"!&:7)E9F]X
M*2!O<B!F<F]M(&$@8V5R=&EF:6-A=&4@<W1O<F4@;6%I;G1A:6YE9"!B>2!A
M;B!/<&5R871I;F<@4WES=&5M("AE+F<N(%=I;F1O=W,@6%`I+B!)9B!T:&4@
M:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E(&EN<V5R=&5D(&EN=&\@>6]U
M<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L;W-E.R!I9B!N
M;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R971U<FYE9"!E
M>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G-M:6UE+61E;&5T92UP97)S;VYA;"UC97)T<R(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4R]-24U%.B!$96QE=&4@4&5R<V]N86P@0V5R=&EF:6-A
M=&5S/"]T:71L93X*("`@(#QH96%D:6YG/D1E;&5T92!097)S;VYA;"!#97)T
M:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T92!Y;W5R
M('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M('EO=7(@<')E9F5R96YC97,N
M("!9;W4@=VEL;"!N;R!L;VYG97(@8F4@86)L92!T;R!S:6=N(%,O34E-12!M
M97-S86=E<R!O<B!V:65W(&%N>2!3+TU)344@96YC<GEP=&5D(&UE<W-A9V5S
M(&%D9')E<W-E9"!T;R!Y;W4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y3+TU)344Z($UA;F%G92!0=6)L:6,@2V5Y<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY3+TU)344Z($UA;F%G92!0=6)L:6,@2V5Y<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@36%N86=E('EO=7(@4R]-24U%('!U8FQI8R!K
M97D@;&ES="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I97<\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&AE(')A=R!T97AT(&]F('1H92!P
M=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5FEE=R!T96-H;FEC86P@9&5T86EL
M<R!O9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T:&4@
M<V5L96-T960@<'5B;&EC(&ME>2!F<F]M('-T;W)A9V4N("!$96QE=&EN9R!A
M('!U8FQI8R!K97D@9F]R(&$@=7-E<B!W:6QL('!R979E;G0@>6]U<B!F<F]M
M(&5N8W)Y<'1I;F<@82!M97-S86=E('1O('1H870@=7-E<BX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R:6YT:6YG(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<FEN=&EN9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY0
M<FEN="!A(&UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1O('!R
M:6YT(&$@;65S<V%G92!Y;W4@87)E('9I97=I;F<L(&-L:6-K(&]N('1H92`B
M4')I;G0B(&QI;FL@870@96ET:&5R('1H92!T;W`@;W(@8F]T=&]M(&]F('1H
M92!M97-S86=E+B!4:&4@;65S<V%G92!W:6QL(&]P96X@:6X@82!N97<@=VEN
M9&]W(&9O<FUA=&5D(&9O<B!P<FEN=&EN9RX@($1E<&5N9&EN9R!O;B!Y;W5R
M('=E8B!B<F]W<V5R(&%N9"!O<&5R871I;F<@<WES=&5M+"!T:&4@<')I;G0@
M9&EA;&]G(&)O>"!M87D@;W!E;B!F;W(@>6]U+B`@268@:70@9&]E<R!N;W0@
M;W!E;BP@=&AE;B!P=6QL(&1O=VX@=&AE('=E8B!B<F]W<V5R)W,@(D9I;&4B
M(&UE;G4@86YD(&-H;V]S92`B4')I;G0B('1O(&]P96X@=&AE('!R:6YT(&1I
M86QO9R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S
M;W)T:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3;W)T:6YG(&%N9"!4
M:')E861I;F<\+W1I=&QE/@H@("`@/&AE861I;F<^4V]R=&EN9R!%;G1R:65S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!7:&5N('9I97=I;F<@82!L:7-T
M(&]F(&UE<W-A9V5S+"!Y;W4@8V%N('-O<G0@=&AE(&UE<W-A9V5S(&)Y(&%N
M>2!C;VQU;6X@8GD@8VQI8VMI;F<@;VX@=&AE(&%P<')O<')I871E(&-O;'5M
M;B!H96%D:6YG+B`@5&\@<W=I=&-H(&-O;'5M;G,@8F5T=V5E;B!A<V-E;F1I
M;F<@86YD(&1E<V-E;F1I;F<@;W)D97(L(&-L:6-K(&]N('1H92!A<G)O=R!I
M8V]N(&EN('1H92!C;VQU;6X@:&5A9&EN9RX*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E1H<F5A9&EN9SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&\@
M9W)O=7`@;65S<V%G97,@8GD@=&AR96%D<R`H<W5B:F5C="DL('-O(&5A8V@@
M;65S<V%G92!I<R!G<F]U<&5D('=I=&@@86QL(&ET<R!R97!L:65S+"!C;&EC
M:R!T:&4@6U1H<F5A9%T@;&EN:R!I;B!T:&4@<W5B:F5C="!C;VQU;6X@:&5A
M9&EN9RX@(%1O(')E='5R;B!T;R!N;W)M86P@<W5B:F5C="!S;W)T:6YG+"!C
M;&EC:R!O;B!T:&4@6U-U8FIE8W1=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L
M=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)A;'1E<FYA=&EV92UM<V<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUU
M;'1I<&%R="]!;'1E<FYA=&EV92!-97-S86=E<SPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(%-O;64@;65S<V%G92!H879E(&)E96X@<V5N="!A<R!A(")M=6QT
M:7!A<G0O86QT97)N871I=F4B('1Y<&4@8GD@=&AE('-E;F1E<BX@5&AE<V4@
M;65S<V%G97,@:&%V92!S979E<F%L('!A<G1S+"!A;&P@9&ES<&QA>6EN9R!T
M:&4@4T%-12!#3TY414Y4(&)U="!I;B!$249&15)%3E0@1D]234%44RX@5&AE
M(&UA:6P@86=E;G0@=VEL;"!D:7-P;&%Y('1H92!L87-T('!A<G0@:6X@=&AE
M(&QI<W0@=&AA="!C86X@8F4@<W5C8V5S<V9U;&QY(&1I<W!L87EE9"!I;FQI
M;F4@:6X@=&AE(&)R;W=S97(L(&EF(&%N>2X@06QL(&]T:&5R(&9O<FUA=',@
M=VEL;"!A<'!E87(@=6YD97(@=&AE(&AE861I;F<@(D%L=&5R;F%T:79E('!A
M<G1S(&9O<B!T:&ES('-E8W1I;VXB(&%N9"!C86X@8F4@=FEE=V5D(&]R(&1O
M=VYL;V%D960@<V5P87)A=&5L>2X@270@:7,@:6UP;W)T86YT('1O(&YO=&4@
M=&AA="!T:&5S92!A;'1E<FYA=&EV92!P87)T<R!C;VYT86EN('1H92!304U%
M($-/3E1%3E13(&%S('1H92!P87)T('1H870@:7,@<VAO=VX@+2!T:&5Y(&%R
M92!S:6UP;'D@:6X@82!D:69F97)E;G0@;65D:6$@9F]R;6%T("AE+F<N('1E
M>'0@=G,N($A434P@;W5T<'5T*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+7)E;F%M95]S96YT;6%I;%]M;VYT:&QY(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M(%)E;F%M92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L
M:6ME('1O(')E;F%M92!Y;W5R('-E;G0M;6%I;"!F;VQD97(@870@=&AE(&)E
M9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H92!F;VQD97(@=VEL;"!B92!R
M96YA;65D("AT;R!A(&YA;64@=&AA="!C;VYT86EN<R!T:&4@;6]N=&@@86YD
M('EE87(I(&%N9"!A(&YE=R!S96YT+6UA:6P@9F]L9&5R('=I;&P@8F4@8W)E
M871E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+61E;&5T95]S96YT;6%I;%]M;VYT:&QY(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T92!396YT+6UA
M:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N
M('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(&1E;&5T92!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R
M>2!M;VYT:"X@(%1H:7,@;6%Y(&)E('5S969U;"!I9B!Y;W4@:&%V92!A('%U
M;W1A+"!F;W(@97AA;7!L92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY7VME97`B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@1&5L971E(%-E;G0M;6%I;"!&;VQD97(@36]N=&AL>2`M(",@;V8@1F]L
M9&5R<R!T;R!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R
M92!D96QE=&EN9R!O;&0@<V5N="UM86EL(&9O;&1E<G,@979E<GD@;6]N=&@L
M(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@9F]L9&5R<R!D;R!Y;W4@('=A;G0@
M=&\@:V5E<#\@($%N>2!F;VQD97)S(&]L9&5R('1H86X@=&AI<R!M86YY(&UO
M;G1H<R!W:6QL(&)E(&1E;&5T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL>2(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE;G1S($UO;G1H;'D\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W
M;W5L9"!L:6ME('1O(&1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T
M('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&ES(&UA>2!B92!U
M<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T
M86-H;65N='-?;6]N=&AL>5]K965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T92!,:6YK960@071T
M86-H;65N=',@36]N=&AL>2`M(",@;V8@36]N=&AS('1O($ME97`\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E(&1E;&5T:6YG(&]L9"!L:6YK
M960@871T86-H;65N=',@979E<GD@;6]N=&@L(&AO=R!M86YY(&UO;G1H<R!O
M9B!O;&0@871T86-H;65N=',@9&\@>6]U("!W86YT('1O(&ME97`_("!!;GD@
M871T86-H;65N=',@;VQD97(@=&AA;B!T:&ES(&UA;GD@;6]N=&AS('=I;&P@
M8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+7!U<F=E7W1R87-H(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U<F=E(%1R87-H/"]T:71L93X*
M("`@(#QP87)A/@H@("`@1&\@>6]U('=A;G0@=&\@<'5R9V4@>6]U<B!T<F%S
M:"!F;VQD97(@979E<GD@<V\@;V9T96XN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]I;G1E<G9A;"(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!0=7)G92!4<F%S:"!);G1E<G9A;#PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($EF('EO=2!A<F4@<'5R9VEN9R!Y;W5R('1R87-H(&9O;&1E<BP@:&]W(&]F
M=&5N('-H;W5L9"!I="!B92!P=7)G960_"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]K965P(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U
M<F=E(%1R87-H($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L(&UE<W-A9V4@;VQD97(@
M=&AA;B!H;W<@;6%N>2!D87ES('-H;W5L9"!B92!P=7)G960_"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUA='1R:6)?=&5X="(@
M<W1A=&4](FYE=R(^"B`@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-97-S86=E
M($-O;7!O<VET:6]N.B!!='1R:6)U=&EO;B!497AT/"]T:71L93X*("`@("`\
M<&%R83X*("`@("!(97)E('EO=2!C86X@96YT97(@=&AE('!H<F%S92!T:&%T
M('EO=2!W:7-H('1O(&%P<&5A<B!B969O<F4@86YY('%U;W1E9"!T97AT(&EN
M(&$@<F5P;'D@=&AA="!Y;W4@<V5N9"X*("`@("`\+W!A<F$^"B`@("`@/'!A
M<F$^"B`@("`@66]U(&-A;B!I;F-L=61E(&]N92!O<B!M;W)E('-P96-I86P@
M<&QA8V5H;VQD97)S('1O(&EN<V5R="!I;F9O<FUA=&EO;B!A8F]U="!T:&4@
M;65S<V%G92!T;R!W:&EC:"!Y;W4@87)E(')E<&QY:6YG+B!0;&%C96AO;&1E
M<G,@8V]N<VES="!O9B!A("<E)R!F;VQL;W=E9"!B>2!A('-I;F=L92!L971T
M97(N(%1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&%R92!A=F%I;&%B;&4Z
M"B`@("`@/"]P87)A/@H*("`@("`\<&%R83X@)68@.B!4:&4@<V5N9&5R)W,@
M;F%M92!A;F0@96UA:6P@861D<F5S<SPO<&%R83X*("`@("`\<&%R83X@)6$@
M.B!4:&4@<V5N9&5R)W,@96UA:6P@861D<F5S<SPO<&%R83X*("`@("`\<&%R
M83X@)7`@.B!4:&4@<V5N9&5R)W,@;F%M93PO<&%R83X*("`@("`\<&%R83X@
M)7(@.B!4:&4@9G5L;"!21D,@,C@R,B!S='EL92!D871E(&%N9"!T:6UE('IO
M;F4\+W!A<F$^"B`@("`@/'!A<F$^("5D(#H@5&AE(&1A=&4@87,@=W=W+"!D
M9"!M;6T@65E963PO<&%R83X*("`@("`\<&%R83X@)7@@.B!4:&4@9&%T92!I
M;B!T:&4@;&]C86QE)W,@9&5F875L=#PO<&%R83X*("`@("`\<&%R83X@)6,@
M.B!4:&4@9&%T92!A;F0@=&EM92!I;B!T:&4@;&]C86QE)W,@9&5F875L=#PO
M<&%R83X*("`@("`\<&%R83X@)6T@.B!4:&4@365S<V%G92U)1#PO<&%R83X*
M("`@("`\<&%R83X@)7,@.B!4:&4@<W5B:F5C=#PO<&%R83X*("`@("`\<&%R
M83X@)6X@.B!!(&YE=R!L:6YE/"]P87)A/@H@("`@(#QP87)A/B`E)2`Z(%1H
M92`G)2<@8VAA<F%C=&5R/"]P87)A/@H*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?<F5A9"(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E<75E<W0@4F5A9"!296-E:7!T
M<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(")297%U97-T(&$@4F5A9"!296-E
M:7!T(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E8VEP:65N=',@;V8@=&AI
M<R!M97-S86=E('1O(&YO=&EF>2!Y;W4@=VAE;B!T:&ES(&UE<W-A9V4@:7,@
M;W!E;F5D(&)Y('1H92!R96-I<&EE;G1S+B!.;W0@86QL(&-L:65N=',@<W5P
M<&]R="`O(&AO;F]R('1H:7,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S96YD7VUD;B(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%-E;F0@341./"]T:71L93X*
M("`@(#QP87)A/@H@("`@(E-E;F0@82!-1$XB('-E;F1S(&$@365S<V%G92!$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@*&%L<V\@:VYO=VX@87,@82!R96%D
M(')E8V5I<'0I('=H96X@>6]U('9I97<@82!M97-S86=E(&EN('=H:6-H('1H
M92!U<V5R(&AA<R!R97%U97-T960@=&AA="!T:&5Y(')E8V5I=F4@;F]T:69I
M8V%T:6]N('1H870@>6]U(&AA=F4@<F5A9"!T:&4@;65S<V%G92X@26X@;6]S
M="!C87-E<RP@=&AI<R!W:6QL(&AA<'!E;B!A=71O;6%T:6-A;&QY('=I=&AO
M=70@<')O;7!T:6YG('EO=2X@26X@8V5R=&%I;B!I<V]L871E9"!C87-E<RP@
M>6]U(&UA>2!H879E('1O(&UA;G5A;&QY(&1E8VED92!T;R!S96YD('1H92!N
M;W1I9FEC871I;VX@8GD@8VQI8VMI;F<@;VX@82!L:6YK+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q
M=65S=%]D96QI=F5R>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z(%)E<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N/"]T:71L93X*
M("`@(#QP87)A/@H@("`@(E)E<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N
M(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E8VEP:65N="=S(&4M;6%I;"!S
M97)V97(@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&AA<R!D96QI=F5R960@=&AE
M(&UE<W-A9V4@=&\@=&AE(')E8VEP:65N="=S(&UA:6QB;W@N($ET(&1O97-N
M)W0@;65A;B!T:&4@;65S<V%G92!H87,@8F5E;B!S965N+"!J=7-T('1H870@
M:70G<R!S:71T:6YG(&EN(&$@;6%I;&)O>"!S;VUE=VAE<F4N($YO="!A;&P@
M;6%I;"!S97)V97)S('-U<'!O<G0@=&AI<RX@"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<W!A;5]A9G1E<E]R97!O
M<G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!$96QE
M=&4@4W!A;2!!9G1E<B!297!O<G1I;F<\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!9;W4@;6%Y(&5L96-T('1O(&1O(&]N92!O9B!T:')E92!I=&5M<R!A9G1E
M<B!R97!O<G1I;F<@82!M97-S86=E(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C
M96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!&:7)S="P@>6]U(&-A
M;B!D96-I9&4@=&\@9&\@;F]T:&EN9R`M('1H92!M97-S86=E('=I;&P@8F4@
M<F5P;W)T960@87,@96ET:&5R('-P86T@;W(@:6YN;V-E;G0@8G5T('=I;&P@
M;W1H97)W:7-E(')E;6%I;B!U;F-H86YG960@:6X@>6]U<B!M86EL8F]X+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!396-O;F0L(&EF(')E<&]R=&EN
M9R!A(&UE<W-A9V4@87,@<W!A;2P@>6]U(&-A;B!I;G-T96%D(&AA=F4@=&AE
M(&UE<W-A9V4@8F4@:6UM961I871E;'D@9&5L971E9"X@(%1H:7,@<V5T=&EN
M9R!H87,@;F\@969F96-T(&]N(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN
M;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%1H:7)D+"!A9G1E
M<B!R97!O<G1I;F<@82!M97-S86=E(&%S('-P86T@=&AE(&UE<W-A9V4@=VEL
M;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E;G0@;6%I;&)O>"!A;F0@;6]V
M960@=&\@>6]U<B!S<&%M(&9O;&1E<BX@($%L=&5R;F%T:79E;'DL(&EF(')E
M<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN;V-E;G0@=&AE(&UE<W-A9V4@=VEL
M;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E;G0@;6%I;&)O>"!A;F0@;6]V
M960@=&\@>6]U<B!)3D)/6"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+6AT;6Q?:6UA9V5?<F5P;&%C96UE;G0B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!(5$U,($EM86=E(%)E<&QA
M8V5M96YT/"]T:71L93X*("`@(#QP87)A/@H@("`@1F]R($A434P@;65S<V%G
M97,@9&ES<&QA>65D(&EN;&EN92P@<VAO=6QD(&%L;"!I;6%G92!T86=S(&)E
M(&)L;V-K960@=6YT:6P@>6]U('-P96-I9FEC86QL>2!D96-I9&4@=&\@=FEE
M=R!T:&]S92!I;6%G97,_($YO=&4@=&AA="P@:68@=FEE=VEN9R!A;B!(5$U,
M(&%T=&%C:&UE;G0L('1H92!I;6%G97,@=VEL;"!A;'=A>7,@8F4@9&ES<&QA
M>65D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M:'1M;%]I;6%G95]A9&1R8F]O:R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P;&%C96UE;G0O061D<F5S<V)O
M;VL@4VAO=SPO=&ET;&4^"B`@("`\<&%R83X*("`@($EF(&)L;V-K:6YG(&EM
M86=E<R!F;W(@:6YL:6YE($A434P@;65S<V%G97,L('-H;W5L9"!W92!A=71O
M;6%T:6-A;&QY(&1I<W!L87D@=&AE;2!I;G-T96%D(&EF('1H92!S96YD97(@
M87!P96%R<R!I;B!Y;W5R(&%D9')E<W-B;V]K/PH@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M;6%I;&)O>%]S=&%R="(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6QB;W@@4W1A<G0@
M4&%G93PO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R;6EN97,@=VAI8V@@
M<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W('=I;&P@8F4@9&ES<&QA>65D('=H
M96X@>6]U(&%C8V5S<R!A(&UA:6QB;W@@9F]R('1H92!F:7)S="!T:6UE+B!.
M;W1E('1H870@=&AE("=U;G-E96XG(&UE<W-A9V4@;W!T:6]N<R!D;R!N;W0@
M=V]R:R!W:71H('1H92`G5&AR96%D)R!S;W)T:6YG(&]P=&EO;B`M(&EN<W1E
M860L('EO=2!W:6QL(&)E('-E;G0@=&\@=&AE(&QA<W0@<&%G92X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7-A=F5?871T86-H
M;65N=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!3
M879E($%T=&%C:&UE;G1S(&]N(%-E;G0@365S<V%G97,\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!S879I;F<@82!C;VUP;W-E9"!M97-S86=E(&EN(&$@
M<V5N="UM86EL(&9O;&1E<BP@9&5T97)M:6YE(&EF(&%L;"!A='1A8VAM96YT
M(&1A=&$@:7,@<V%V960N(%1H92!F;VQL;W=I;F<@;W!T:6]N<R!A<F4@879A
M:6QA8FQE.@H@("`@/"]P87)A/@H*("`@(#QP87)A/BH@(D%L=V%Y<R!S879E
M(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP="!T;R!S879E(&%T=&%C:&UE
M;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@871T86-H;65N=',@87)E($%,
M5T%94R!S879E9"!W:71H('1H92!M97-S86=E+CPO<&%R83X*("`@("`\<&%R
M83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[
M(&1E9F%U;'0@=&\@6453(B`M($%,5T%94R!P<F]M<'0@=&\@<V%V92!A='1A
M8VAM96YT<R!I;B!T:&4@8V]M<&]S92!S8W)E96X[('1H92!D969A=6QT(&ES
M('1O('-A=F4@871T86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@(E!R
M;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L
M="!T;R!.3R(@+2!!3%=!65,@<')O;7!T('1O('-A=F4@871T86-H;65N=',@
M:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F875L="!I<R!T;R!N;W0@
M<V%V92!A='1A8VAM96YT<RX\+W!A<F$^"B`@("`@/'!A<F$^*B`B3F5V97(@
M<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A='1A
M8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S(&%R
M92!.159%4B!S879E9"!W:71H('1H92!M97-S86=E+CPO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G9I<G1U86Q?:6YB;W@B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E9I<G1U86P@1F]L9&5R<SH@5FER='5A;"!);F)O>#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@(%9I<G5T86P@26YB;W@@:7,@82!S879E9"!S
M96%R8V@@=&AA="!D;V5S(&%W87D@=VET:"!T:&4@;F5E9"!T;R!S96%R8V@@
M979E<GD@;6%I;&)O>"!F;W(@;65S<V%G97,@;6%R:V5D(&%S(&YE=RX@($EN
M<W1E860L(&%L;"!C=7)R96YT;'D@<W5B<V-R:6)E9"!M86EL8F]X97,@87)E
M('-E87)C:&5D(&9O<B!N97<@;65S<V%G97,@86YD('1H92!R97-U;'1S(&%R
M92!D:7-P;&%Y960@:6X@82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U86Q?=')A<V@B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E9I<G1U86P@1F]L9&5R<SH@5FER='5A;"!4<F%S
M:#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%9I<G1U86P@5')A<V@@:7,@82!S
M879E9"!S96%R8V@@=&AA="!D;V5S(&%W87D@=VET:"!T:&4@;F5E9"!F;W(@
M82!S97!A<F%T92!4<F%S:"!F;VQD97(N("!);G-T96%D(&]F(&UO=FEN9R!M
M97-S86=E<R!T;R!A(&-E;G1R86QI>F5D('1R87-H(&9O;&1E<BP@;65S<V%G
M97,@87)E('-I;7!L>2!M87)K960@87,@9&5L971E9"!I;B!T:&4@8W5R<F5N
M="!F;VQD97(@=&AE>2!L:79E(&EN+B`@5VAE;B`G<VAO=R!D96QE=&5D(&UE
M<W-A9V5S)R!I<R!T=7)N960@;V9F+"!T:&ES(')E<W5L=',@:6X@=&AE<V4@
M;65S<V%G97,@;F]T(&%P<&5A<FEN9R!I;B!A(&UA:6QB;W@@=FEE=RX@(%=H
M96X@82!U<V5R(&-L:6-K<R!O;B!6:7)T=6%L(%1R87-H+"`J86QL*B!M86EL
M8F]X97,@86QL('-E87)C:&5D(&9O<B!M97-S86=E<R!T:&%T(&%R92!F;&%G
M9V5D(&1E;&5T960@86YD('1H97-E(&UE<W-A9V5S(&%R92!D:7-P;&%Y960@
M:6X@82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H
M96QP/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O8G-?0D$O````````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C``
M,#$W-#$T`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]B<U]"
M02],0U]-15-304=%4R\`````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<V,``P,C$R,#$`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O;&]C86QE+V)S7T)!+TQ#7TU%4U-!1T53+VEM<"YM;P``````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,3<U,S4V`#$P-#$W,S8R-S8P`#`R,C,T,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`)L#```<````]!P``,\$``#,.0````````A-```*````"4T```H````430``
M"@```!]-```.````*DT```T````Y30``"````$=-```+````4$T```P```!<
M30``"@```&E-```$````=$T```0```!Y30```0```'Y-```9````@$T```P`
M``":30``2````*=-```K````\$T``$0````<3@``)P```&%.```7````B4X`
M``L```"A3@``!0```*U.```H````LTX```@```#<3@``"@```.5.```5````
M\$X``!(````&3P``,@```!E/```+````3$\``"D```!83P``,@```()/```*
M````M4\```T```#`3P``#@```,Y/```1````W4\```T```#O3P``#````/U/
M```-````"E```!L````84```+@```#10```W````8U```'P```";4```;```
M`!A1```<````A5$``!T```"B40``#````,!1``!%````S5$``"@````34@``
M00```#Q2```D````?E(```X```"C4@``#P```+)2```.````PE(```X```#1
M4@``"````.!2```.````Z5(```X```#X4@``&@````=3```%````(E,``!$`
M```H4P``"````#I3```0````0U,```\```!44P``#P```&13```*````=%,`
M``<```!_4P```P```(=3```)````BU,```\```"54P``"@```*53```*````
ML%,``"0```"[4P``%````.!3```<````]5,``"@````25```'@```#M4```:
M````6E0``"P```!U5```(````*)4```,````PU0```T```#05```+````-Y4
M```+````"U4```<````750``!P```!]5```#````)U4``$X````K50``4```
M`'I5``!"````RU4``",````.5@``%````#)6```7````1U8``!<```!?5@``
M!@```'=6```7````?E8``!\```"65@``"````+96```1````OU8```T```#1
M5@``$P```-]6```C````\U8```4````75P``,````!U7```A````3E<``#L`
M``!P5P``*P```*Q7```Q````V%<``#L````*6```#````$98```)````4U@`
M``,```!=6```.0```&%8```&````FU@``#,```"B6```"@```-98```+````
MX5@```8```#M6```4````/18```+````15D```H```!160``%````%Q9```#
M````<5D```D```!U60``"@```']9``!%````BED```0```#060``!````-59
M```'````VED```D```#B60``!@```.Q9```1````\UD```<````%6@``%@``
M``U:```$````)%H``"<````I6@``"````%%:```&````6EH```T```!A6@``
M!@```&]:```>````=EH``!$```"56@``"````*=:```-````L%H```P```"^
M6@``!P```,M:```#````TUH```,```#76@``$P```-M:```(````[UH```@`
M``#X6@``"`````%;```@````"EL```8````K6P``#@```#);```5````05L`
M`!4```!76P```@```&U;```4````<%L``!@```"%6P``'0```)Y;```&````
MO%L```H```##6P``8@```,Y;```G````,5P``%0```!97```7P```*Y<```6
M````#ET``!P````E70``,P```$)=```H````=ET```4```"?70``!0```*5=
M```;````JUT``!H```#'70``#@```.)=```5````\5T``!$````'7@``$0``
M`!E>```1````*UX``!P````]7@``*@```%I>```U````A5X``$4```"[7@``
M$`````%?```%````$E\``!,````87P``'P```"Q?``!`````3%\``#@```"-
M7P``!0```,9?```1````S%\```T```#>7P``#````.Q?```4````^5\```\`
M```.8```$````!Y@```'````+V````<````W8```%P```#]@```F````5V``
M`$\```!^8```)0```,Y@```?````]&```!L````480``'@```#!A``!<````
M3V$``"X```"L80``!````-MA```.````X&$```X```#O80``!P```/YA```.
M````!F(``"0````58@``-@```#IB```-````<6(```T```!_8@``&@```(UB
M```0````J&(``!T```"Y8@``&0```-=B``!=````\6(``!(```!/8P``%```
M`&)C```Y````=V,``!P```"Q8P``*````,YC```%````]V,```4```#]8P``
M!`````-D```(````"&0```T````19```$````!]D```9````,&0``!H```!*
M9```"P```&5D```&````<60``!,```!X9```$````(QD```5````G60``!D`
M``"S9```-````,UD```S`````F4``!@````V90``!P```$]E```0````5V4`
M`!P```!H90``"@```(5E```4````D&4```\```"E90``"0```+5E```'````
MOV4``!8```#'90``#P```-YE```M````[F4``!8````<9@``&@```#-F```H
M````3F8``",```!W9@``*@```)MF```(````QF8```L```#/9@``&@```-MF
M```G````]F8``!(````>9P``(````#%G```7````4F<```4```!J9P``#```
M`'!G```.````?6<```X```",9P``#````)MG```/````J&<``!````"X9P``
M%P```,EG```.````X6<``!$```#P9P``$P````)H```6````%F@``#@````M
M:```$P```&9H```-````>F@```D```"(:```#P```))H```2````HF@```P`
M``"U:```&0```,)H```<````W&@``!@```#Y:```(````!)I```3````,VD`
M``,```!':0``%0```$MI```+````86D``!,```!M:0``$````(%I```I````
MDFD``"P```"\:0``*````.EI```U````$FH``!$```!(:@``!P```%IJ```%
M````8FH``!@```!H:@``!P```(%J```(````B6H```8```"2:@``!@```)EJ
M```0````H&H```\```"Q:@``$````,%J```/````TFH```L```#B:@``#P``
M`.YJ```,````_FH```\````+:P``"@```!MK```2````)FL```T````Y:P``
M#````$=K``!#````5&L``#T```"8:P``"0```-9K```(````X&L```H```#I
M:P``(````/1K```(````%6P```0````>;```#@```"-L```/````,FP``"4`
M``!";```*@```&AL```'````DVP``!(```";;```&P```*YL```$````RFP`
M`!(```#/;```"@```.)L```(````[6P``!````#V;```#@````=M``!$````
M%FT```<```!;;0``"````&-M```9````;&T```\```"&;0``!0```)9M```$
M````G&T```P```"A;0``$````*YM```$````OVT```\```#$;0``#0```-1M
M```-````XFT```P```#P;0``$@```/UM```'````$&X``!4````8;@``!```
M`"YN```&````,VX``!4````Z;@``#````%!N```1````76X```T```!O;@``
M!0```'UN```$````@VX```P```"(;@``"@```)5N```(````H&X```D```"I
M;@``!0```+-N```G````N6X``"@```#A;@``!`````IO```<````#V\```T`
M```L;P``)P```#IO```;````8F\```P```!^;P``%@```(MO```%````HF\`
M``H```"H;P``&0```+-O```I````S6\```<```#W;P``"@```/]O```,````
M"G````\````7<```$````"=P```&````.'````H````_<```#P```$IP```)
M````6G```!(```!D<```!0```'=P```Q````?7```"0```"O<```#P```-1P
M```&````Y'````<```#K<```%@```/-P```$````"G$```0````/<0``!P``
M`!1Q```(````''$``"`````E<0``$0```$9Q```)````6'$```T```!B<0``
M#@```'!Q```6````?W$``!$```"6<0``!@```*AQ```#````KW$```8```"S
M<0``!P```+IQ```'````PG$``!$```#*<0``!P```-QQ```6````Y'$```T`
M``#[<0``!0````ER```>````#W(``'P````N<@``%0```*MR```)````P7(`
M``H```#+<@``#@```-9R```,````Y7(```\```#R<@``!@````)S```,````
M"7,```<````6<P``"P```!YS``!'````*G,```T```!R<P``"0```(!S```,
M````BG,```H```"7<P``!````*)S```-````IW,```<```"U<P``(@```+US
M``!H````X',```4```!)=```(P```$]T```E````<W0```@```"9=```-P``
M`*)T```3````VG0``!L```#N=```+P````IU```0````.G4```H```!+=0``
M$0```%9U```/````:'4```\```!X=0``"@```(AU```)````DW4``!<```"=
M=0```P```+5U```-````N74```<```#'=0``"@```,]U```+````VG4```<`
M``#F=0``$P```.YU```,`````G8```\````/=@``#@```!]V```,````+G8`
M``X````[=@``#P```$IV```-````6G8```\```!H=@``#P```'AV```@````
MB'8``"X```"I=@``&@```-AV```F````\W8```L````:=P``"0```"9W```'
M````,'<```0````X=P``$````#UW```$````3G<```<```!3=P``!0```%MW
M```6````87<```,```!X=P``#0```'QW```,````BG<```H```"7=P``"```
M`*)W```(````JW<``!<```"T=P``"P```,QW```,````V'<``!,```#E=P``
M!````/EW```*````_G<```P````)>```"0```!9X```,````('@```D````M
M>```!0```#=X```'````/7@```4```!%>```!````$MX```"````4'@```T`
M``!3>```"P```&%X```9````;7@``!0```"'>```$@```)QX```.````KW@`
M`!(```"^>```(0```-%X```$````\W@``!0```#X>```"P````UY```)````
M&7D```T````C>0``#````#%Y```4````/GD``!8```!3>0``"````&IY``!$
M````<WD``#P```"X>0``!P```/5Y```,````_7D``",````*>@``#0```"YZ
M```0````/'H```<```!->@``#@```%5Z```%````9'H``!$```!J>@``$P``
M`'QZ```-````D'H```,```">>@``$P```*)Z```+````MGH``#0```#">@``
M"P```/=Z```4`````WL``#X````8>P``$P```%=[```T````:WL``#$```"@
M>P``$@```-)[```0````Y7L``!@```#V>P``(P````]\```B````,WP``"<`
M``!6?```5@```'Y\``!-````U7P```0````C?0``'````"A]```-````17T`
M`"<```!3?0``&P```'M]```,````EWT```T```"D?0``(@```+)]```A````
MU7T```<```#W?0``"````/]]```&````"'X```<````/?@``'@```!=^```H
M````-GX```H```!??@``&@```&I^```M````A7X```@```"S?@``%````+Q^
M```Q````T7X``!P````#?P``*````"!_```=````27\``!T```!G?P``+@``
M`(5_```V````M'\``"P```#K?P``+@```!B````J````1X```!````!R@```
M*P```(.````0````KX````T```#`@```$````,Z````%````WX````@```#E
M@```%````.Z````'`````X$``!,````+@0``-@```!^!```W````5H$```D`
M``".@0``#@```)B!```-````IX$```\```"U@0``%@```,6!```^````W($`
M`"<````;@@``)P```$."```?````:X(``!8```"+@@``"P```**"```>````
MKH(```T```#-@@``"P```-N"```.````YX(```X```#V@@``"0````6#```(
M````#X,``!`````8@P``%0```"F#```3````/X,```<```!3@P``'@```%N#
M```5````>H,``!0```"0@P``"P```*6#```6````L8,```\```#(@P``#@``
M`-B#```J````YX,``!`````2A```+@```".$```Z````4H0```X```"-A```
M#0```)R$```%````JH0```L```"PA```#````+R$```-````R80```T```#7
MA```#@```.6$```-````](0``"`````"A0``)P```".%```K````2X4```@`
M``!WA0``"@```("%```&````BX4``!(```"2A0``#@```*6%```7````M(4`
M`!X```#,A0``%@```.N%```<`````H8```4````?A@``!@```"6&```3````
M+(8``!0```!`A@``$0```%6&``!+````9X8```<```"SA@``%````+N&```8
M````T(8```8```#IA@``%@```/"&```.````!X<```@````6AP``$````!^'
M```(````,(<```H````YAP``#````$2'```+````48<```<```!=AP``%@``
M`&6'```Z````?(<``"````"WAP``#P```-B'```Y````Z(<```8````BB```
M"0```"F(```.````,X@```0```!"B```!@```$>(```6````3H@```X```!E
MB```#P```'2(``!#````A(@```H```#(B```-0```-.(```1````"8D```L`
M```;B0``)P```">)```9````3XD``!\```!IB0``#````(F)```3````EHD`
M``@```"JB0``!P```+.)```(````NXD``!$```#$B0``"0```-:)```5````
MX(D```T```#VB0``!@````2*```=````"XH``!,````IB@```P```#V*``!&
M````08H``$,```"(B@``,@```,R*```_````_XH``#<````_BP``5P```'>+
M```%````SXL```H```#5BP``#0```."+```2````[HL``"D````!C```#0``
M`"N,```M````.8P``'````!GC```.0```-B,```$````$HT``!`````7C0``
M#````"B-```4````-8T``!$```!*C0``/0```%R-```E````FHT``"````#`
MC0``)P```.&-```:````"8X``!\````DC@``'0```$2.```H````8HX``"0`
M``"+C@``!0```+".```%````MHX```8```"\C@``!````,..```0````R(X`
M`!0```#9C@``%````.Z.```/`````X\```X````3CP``$@```"*/```;````
M-8\```P```!1CP``$@```%Z/```+````<8\```T```!]CP``%````(N/```O
M````H(\``!$```#0CP``"````.*/```'````ZX\```T```#SCP``!@````&0
M```6````")````<````?D```"P```">0```%````,Y```!\````YD```,0``
M`%F0```G````BY```#,```"SD```2P```.>0```>````,Y$``'4```!2D0``
M/@```,B1``!"````!Y(``#T```!*D@``/0```(B2```I````QI(``"D```#P
MD@``,0```!J3```C````3),``"8```!PDP``'P```)>3```^````MY,``$<`
M``#VDP``5P```#Z4``!5````EI0``"\```#LE```50```!R5```K````<I4`
M`$D```">E0``#P```.B5```A````^)4``!P````:E@``,0```#>6```+````
M:98```(```!UE@``"@```'B6``!6````@Y8```P```#:E@``#0```.>6```4
M````]98```H````*EP``$P```!67```(````*9<``!8````REP``#````$F7
M```'````5I<```\```!>EP``%````&Z7```=````@Y<```<```"AEP``!@``
M`*F7```:````L)<``!$```#+EP``'@```-V7```R````_)<```0````OF```
M(0```#28```,````5I@``!$```!CF```"````'68```)````?I@```<```"(
MF```"P```)"8```G````G)@```\```#$F```(````-28```4````]9@```8`
M```*F0``!P```!&9```-````&9D```L````GF0``%````#.9```5````2)D`
M``X```!>F0``+P```&V9``!:````G9D``#\```#XF0``-@```#B:```Q````
M;YH```D```"AF@``/P```*N:```&````ZYH```,```#RF@``-0```/::```9
M````+)L``"D```!&FP``*0```'";```]````FIL``$$```#8FP``*````!J<
M```L````0YP``#````!PG```$@```*&<```3````M)P``!````#(G```>0``
M`-F<```K````4YT``!<```!_G0``*@```)>=```T````PIT``!8```#WG0``
M#P````Z>```?````'IX``$`````^G@``'P```'^>```<````GYX``%$```"\
MG@``%`````Z?```/````(Y\```H````SGP``!0```#Z?```&````1)\```@`
M``!+GP``!0```%2?```2````6I\```P```!MGP``$````'J?```3````BY\`
M`!T```"?GP``#P```+V?```/````S9\```0```#=GP``"@```.*?```$````
M[9\```,```#RGP``"0```/:?```'`````*````L````(H```"````!2@```'
M````':````4````EH```"0```"N@```4````-:````8```!*H```!P```%&@
M```(````6:````\```!BH```#P```'*@```(````@J````P```"+H```!@``
M`)B@```/````GZ````8```"OH```!P```+:@```-````OJ````8```#,H```
M%````-.@```'````Z*````,```#PH```"0```/2@```&````_J````P````%
MH0``"@```!*A```,````':$```0````JH0``#````"^A```$````/*$```0`
M``!!H0```@```$:A```.````2:$```\```!8H0``"0```&BA```'````<J$`
M``4```!ZH0``"P```("A```.````C*$``',!``";H0``"0````^C```*````
M&:,```H````DHP``$````"^C```-````0*,```@```!.HP``"````%>C```'
M````8*,```<```!HHP```P```'"C```#````=*,```$```!XHP``&0```'JC
M```*````E*,``#T```"?HP``)@```-VC```Y````!*0``"(````^I```'```
M`&&D```-````?J0```4```",I```'P```)*D```.````LJ0```H```#!I```
M$0```,RD```/````WJ0``#````#NI```"@```!^E```J````*J4``"\```!5
MI0``"0```(6E```1````CZ4```X```"AI0``"@```+"E```+````NZ4```T`
M``#'I0``"0```-6E```;````WZ4``"\```#[I0``-````"NF``!V````8*8`
M`'````#7I@``'P```$BG```:````:*<```\```"#IP``/````).G```E````
MT*<``#@```#VIP``(0```"^H```+````4:@```P```!=J```#P```&JH```/
M````>J@```<```"*J```"P```)*H```+````GJ@``!H```"JJ```!0```,6H
M```.````RZ@```T```#:J```&````.BH```2`````:D``!<````4J0``#0``
M`"RI```&````.JD```4```!!J0``#````$>I```6````5*D```P```!KJ0``
M"P```'BI```?````A*D``!````"DJ0``%@```+6I```K````S*D``!,```#X
MJ0``'`````RJ```T````*:H``!P```!>J@``!@```'NJ```'````@JH``#8`
M``"*J@``"@```,&J```(````S*H```4```#5J@```P```-NJ``!-````WZH`
M`$T````MJP``1P```'NK```E````PZL``!<```#IJP``%P````&L```@````
M&:P```8````ZK```%@```$&L```?````6*P```H```!XK```$0```(.L```0
M````E:P``!8```"FK```+````+VL```%````ZJP``#8```#PK```*````">M
M```P````4*T``#,```"!K0``-````+6M```Y````ZJT``!,````DK@``!P``
M`#BN```%````0*X``"L```!&K@``!@```'*N```[````>:X```8```"UK@``
M!P```+RN```&````Q*X``$X```#+K@``"P```!JO```*````)J\``!8````Q
MKP```P```$BO```*````3*\```L```!7KP``0````&.O```&````I*\```4`
M``"KKP``"````+&O```*````NJ\```,```#%KP``$````,FO```&````VJ\`
M`!,```#AKP```P```/6O```?````^:\```<````9L````P```"&P```-````
M);````8````SL```)@```#JP```1````8;````@```!SL```$````'RP```,
M````C;````<```":L````P```**P```#````IK```!(```"JL```#P```+VP
M```'````S;````<```#5L```)0```-VP```&`````[$``!(````*L0``'```
M`!VQ```3````.K$```(```!.L0``%0```%&Q```;````9[$``!\```"#L0``
M"````*.Q```,````K+$``%$```"YL0``+`````NR``!1````.+(``%X```"*
ML@``&````.FR```?`````K,``#4````BLP``)@```%BS```$````?[,```0`
M``"$LP``(0```(FS```<````J[,``!$```#(LP``%@```-JS```/````\;,`
M`!@````!M```$0```!JT```B````++0``"L```!/M```1P```'NT```^````
MP[0```\````"M0``!@```!*U```6````&;4``"8````PM0``-@```%>U```O
M````CK4```<```"^M0``$P```,:U```/````VK4```D```#JM0``$0```/2U
M```,````!K8```H````3M@``!@```!ZV```)````);8``!(````OM@``'P``
M`$*V``!,````8K8``!<```"OM@``(````,>V```;````Z+8``!X````$MP``
M-````".W```H````6+<```<```"!MP``$````(FW```0````FK<```<```"K
MMP``$````+.W```A````Q+<``#$```#FMP``#@```!BX```,````)[@``!T`
M```TN```#````%*X```D````7[@``!P```"$N```A````*&X```6````)KD`
M`!,````]N0``/P```%&Y```<````D;D``$$```"NN0``!@```/"Y```&````
M][D```4```#^N0``"`````2Z```/````#;H``!$````=N@``'P```"^Z```:
M````3[H```H```!JN@``!@```'6Z```8````?+H```X```"5N@``%P```*2Z
M```=````O+H``#<```#:N@``.P```!*[```9````3KL```@```!HNP``#P``
M`'&[```>````@;L```D```"@NP``)````*J[```0````S[L```H```#@NP``
M!P```.N[```D````\[L```X````8O```)````">\```6````3+P``!<```!C
MO```)@```'N\```E````HKP``"D```#(O```"````/*\```+````^[P``!H`
M```'O0``)@```"*]```2````2;T``"````!<O0``&0```'V]```%````E[T`
M`!````"=O0``&0```*Z]```3````R+T``!````#<O0``$````.V]```0````
M_KT``!8````/O@``%0```":^```5````/+X``!D```!2O@``%@```&R^``!'
M````@[X``!L```#+O@``#````.>^```(````]+X``!````#]O@``%0````Z_
M```/````)+\``!L````TOP``'@```%"_```?````;[\``"@```"/OP``$@``
M`+B_```$````R[\``!@```#0OP``"P```.F_```1````];\```T````'P```
M*````!7````O````/L```"<```!NP```(````);````5````M\````@```#-
MP```!@```-;````>````W<````@```#\P```"`````7!```'````#L$```8`
M```6P0``$````!W!```/````+L$``!$````^P0``#P```%#!```1````8,$`
M`!````!RP0``"P```(/!```5````C\$```L```"EP0``$P```+'!```.````
MQ<$```T```#4P0``.0```.+!```R````',(```H```!/P@``!P```%K"```,
M````8L(``"````!OP@``"````)#"```(````F<(```X```"BP@``#P```+'"
M```F````P<(``#$```#HP@``!P```!K#```4````(L,``"(````WPP``!0``
M`%K#```5````8,,```L```!VPP``"P```(+#```/````CL,```\```">PP``
M.@```*[#```*````Z<,```L```#TPP``&@````#$```7````&\0```,````S
MQ````@```#?$```/````.L0```T```!*Q```!````%C$```,````7<0```T`
M``!JQ```#P```'C$```+````B,0``!(```"4Q```"0```*?$```8````L<0`
M``4```#*Q```"````-#$```<````V<0```\```#VQ```$`````;%```/````
M%\4```@````GQ0``!P```##%```-````.,4```X```!&Q0``"````%7%```)
M````7L4```4```!HQ0``'@```&[%```T````C<4```0```#"Q0``)````,?%
M```-````[,4``"<```#ZQ0``'````"+&```-````/\8``!8```!-Q@``!P``
M`&3&```)````;,8``!@```!VQ@``+````(_&```&````O,8```H```##Q@``
M"P```,[&```0````VL8```\```#KQ@``"````/O&```,````!,<```\````1
MQP``!0```"''```,````)\<```<````TQP``)0```#S'```E````8L<``!``
M``"(QP``"````)G'```&````HL<``!8```"IQP``!````,#'```$````Q<<`
M``D```#*QP``!0```-3'```A````VL<``!<```#\QP``#0```!3(```/````
M(L@``!(````RR```(````$7(```5````9L@```<```!\R```!0```(3(```(
M````BL@```4```"3R```!@```)G(```/````H,@```@```"PR```'````+G(
M```+````UL@```<```#BR```)P```.K(``!]````$LD``"$```"0R0``!0``
M`++)```+````N,D``!````#$R0``$0```-7)```:````Y\D```4````"R@``
M$`````C*```%````&<H```P````?R@``4@```"S*```5````?\H```H```"5
MR@``#P```*#*```*````L,H```4```"[R@``#0```,'*```'````S\H``"(`
M``#7R@``2@```/K*```$````1<L``!\```!*RP``(0```&K+```-````C,L`
M`#,```":RP``%0```,[+```E````Y,L``#<````*S```$````$+,```(````
M4\P``!4```!<S```#P```'+,```2````@LP```L```"5S```"@```*',```;
M````K,P```,```#(S```$P```,S,```'````X,P```T```#HS```"P```/;,
M```&`````LT```L````)S0``#````!7-```-````(LT``!0````PS0``#P``
M`$7-```2````5<T``!0```!HS0``#0```'W-```.````B\T```\```":S0``
M&0```*K-```P````Q,T``!@```#US0``)P````[.```(````-LX```@````_
MS@``"````$C.```'````4<X``!0```!9S@```P```&[.```%````<LX```8`
M``!XS@``%@```'_.```$````ELX```\```";S@``#P```*O.```+````N\X`
M``H```#'S@``"P```-+.```C````WLX```L````"SP``"P````[/```5````
M&L\```<````PSP``"@```#C/```/````0\\```\```!3SP``#P```&//```)
M````<\\```4```!]SP``"````(//```#````C,\```0```"0SP```@```)7/
M```.````F,\```L```"GSP``(````+//```2````U,\``!D```#GSP``"P``
M``'0```6````#=```"@````DT```!P```$W0```7````5=````H```!MT```
M"@```'C0```'````@]````H```"+T```$0```);0```.````J-````@```"W
MT```5@```,#0``!,````%]$```<```!DT0``#````&S1```C````>=$```\`
M``"=T0``$0```*W1```&````O]$```P```#&T0``!@```-/1```2````VM$`
M`!0```#MT0``#0````+2```#````$-(``!4````4T@``"P```"K2```V````
M-M(```H```!MT@``#@```'C2```^````A](``!<```#&T@``+P```-[2```L
M````#M,``!,````[TP``%P```$_3```9````9],``"4```"!TP``(@```*?3
M```J````RM,``%$```#UTP``2````$?4```$````D-0``"4```"5U```#0``
M`+O4```G````R=0``!L```#QU```#0````W5```1````&]4``"8````MU0``
M*````%35```.````?=4```4```",U0``!0```)+5```(````F-4``!D```"A
MU0``*@```+O5```'````YM4``"0```#NU0``+P```!/6```%````0]8``!@`
M``!)U@``-P```&+6```2````FM8``#4```"MU@``&@```./6```C````_M8`
M`#8````BUP``-0```%G7```G````C]<``"@```"WUP``-0```.#7```0````
M%M@``"0````GV```$````$S8```0````7=@``!````!NV```"0```'_8```)
M````B=@``!8```"3V```"````*K8```-````L]@``#P```#!V```/````/[8
M```)````.]D``!````!%V0``#P```%;9```6````9MD``"4```!]V0``.0``
M`*/9```J````W=D``"L````(V@``)P```#3:```>````7-H```L```![V@``
M%@```(?:```.````GMH```P```"MV@``#P```+K:```/````RMH```@```#:
MV@``!P```./:```.````Z]H``!(```#ZV@``&`````W;```(````)ML``",`
M```OVP``&````%/;```:````;-L```\```"'VP``%0```)?;```1````K=L`
M`!````"_VP``+````-#;```4````_=L``#L````2W```/@```$[<```2````
MC=P```L```"@W```"````*S<```2````M=P```X```#(W```#P```-?<```1
M````Y]P``!(```#YW```#P````S=```>````'-T``#8````[W0``+P```'+=
M```+````HMT```T```"NW0``"0```+S=```3````QMT``!````#:W0``%@``
M`.O=```:`````MX``"$````=W@``'@```#_>```'````7MX```<```!FW@``
M%0```&[>```7````A-X```\```"<W@``4````*S>```'````_=X``!D````%
MWP``%0```!_?```&````-=\``!0````\WP``#0```%'?```%````7]\``!(`
M``!EWP``#````'C?```1````A=\```P```"7WP``$@```*3?```+````M]\`
M`!T```##WP``-@```.'?```F````&.```!8````_X```.0```%;@```%````
MD.````@```"6X```$@```)_@```)````LN````<```"\X```&@```,3@```/
M````W^```!````#OX```/0````#A```+````/N$``#X```!*X0``&@```(GA
M```/````I.$``"P```"TX0``%````.'A```8````]N$```X````/X@``&```
M`![B```+````-^(```<```!#X@``"````$OB```5````5.(```D```!JX@``
M$@```'3B```-````A^(```8```"5X@``$````)SB```5````K>(```<```##
MX@``2````,OB``!8````%.,``#P```!MXP``1P```*KC```\````\N,``&(`
M```OY```"````)+D```'````F^0``!(```"CY```%P```+;D```W````SN0`
M``L````&Y0``+````!+E``!\````/^4``$8```"\Y0``!P````/F```1````
M"^8``!`````=Y@``%P```"[F```5````1N8``#@```!<Y@``+P```)7F```D
M````Q>8``"L```#JY@``'0```!;G```F````-.<``!<```!;YP``*0```'/G
M```?````G><```D```"]YP``"0```,?G```)````T><```@```#;YP``#P``
M`.3G```=````].<``!L````2Z```$````"[H```(````/^@``!L```!(Z```
M&P```&3H```/````@.@``!0```"0Z```$@```*7H```2````N.@``!D```#+
MZ```,P```.7H```3````&>D```4````MZ0``!````#/I```*````..D```<`
M``!#Z0``%P```$OI```(````8^D```H```!LZ0``!@```'?I```G````?ND`
M`"4```"FZ0``)@```,SI```V````\^D``$L````JZ@``%P```';J``!1````
MCNH``#8```#@Z@``-0```!?K```O````3>L``"\```!]ZP``(````*WK```@
M````SNL``#````#OZP``&@```"#L```=````.^P``!8```!9[```.````'#L
M```_````J>P``$T```#I[```30```#?M```Q````A>T``$8```"W[0``*```
M`/[M``!!````)^X```P```!I[@``+P```';N```>````INX``#0```#%[@``
M$P```/KN```"````#N\``!$````1[P``:@```"/O```0````CN\```T```"?
M[P``$P```*WO```,````P>\``!,```#.[P``#@```.+O```4````\>\```\`
M```&\```#@```!;P```.````)?```!H````T\```(P```$_P```(````<_``
M``L```!\\```%````(CP```:````G?```!P```"X\```.````-7P```(````
M#O$``!\````7\0``$0```#?Q```6````2?$```X```!@\0``#P```&_Q```)
M````?_$``!````")\0``-@```)KQ```1````T?$``"<```#C\0``&0````OR
M```(````)?(```L````N\@``$0```#KR```/````3/(``!0```!<\@``%0``
M`''R```.````A_(``"P```"6\@``80```,/R```^````)?,``#X```!D\P``
M1````*/S```,````Z/,``$H```#U\P``"````$#T```"````2?0``#,```!,
M]```(P```(#T```U````I/0``"4```#:]```,`````#U```O````,?4``"``
M``!A]0``'P```(+U```U````HO4``!(```#8]0``$@```.OU```0````_O4`
M`(`````/]@``)@```)#V```8````M_8``"L```#0]@``,P```/SV```6````
M,/<``!,```!']P``'````%OW```R````>/<``!,```"K]P``%P```+_W``!.
M````U_<``!8````F^```"P```#WX```+````2?@```0```!5^```!P```%KX
M```(````8O@```4```!K^```%P```''X```*````B?@``!(```"4^```&0``
M`*?X```D````P?@```X```#F^```#P```/7X```$````!?D```L````*^0``
M!````!;Y```#````&_D```D````?^0``!P```"GY```+````,?D```@````]
M^0``!@```$;Y```&````3?D```H```!4^0``$0```%_Y```(````<?D```L`
M``!Z^0``!@```(;Y```3````C?D``!$```"A^0``!P```+/Y```(````N_D`
M``H```#$^0``#P```,_Y```)````W_D```8```#I^0``#P```/#Y```'````
M`/H``!(````(^@``"0```!OZ```#````)?H```\````I^@``"@```#GZ```1
M````1/H```T```!6^@``!@```&3Z```"````:_H``!````!N^@```P```'_Z
M```%````@_H```,```")^@``$0```(WZ```1````G_H```X```"Q^@``"0``
M`,#Z```%````ROH```L```#0^@``$0```-SZ```!````CP,``)(```"L`@``
M]@```.,"``"9`0``?@$``&X!```^`@``/0,``%8```"7`@``(0````````!M
M````F@`````````^`0```````*T!`````````````)H!``!^`@``7`(``*$!
M``#B`0``7P(``.4`````````I0(````````%````%`````T```"D`@``````
M`*L!````````L0$``/\!``"-`0``Q@$``"<```!X`P```````"P!``#2````
M`````%X```!]`P`````````````A`P``"P,``-D"````````.`$``#D!``!T
M`P```````"D#``"$`@``(0$```````"3````#P````H#``!P`P``WP$``!<#
M````````D0$``(L```#!`0``_P```+<```!4`@``]@$``-<`````````````
M`/("````````D@$``&8!`````````````-`"```$`````P``````````````
MAP$```4!``!=````SP$``'$"````````<0,``%X#```4`0``"`(``(\!````
M`````````$\````N````?@```#4!``#\````(0(``#\```!Z`````````'L#
M``".````\`(``$8"````````"P$``&\```"S`0```````+8"``!?`0``:P``
M`/T!``!``P````````@```"P`````````(4!``#'````B`$```````#(`0``
MB0(`````````````W0```%T"``"O`@``MP$``#\"```C`P```````!L````6
M`@``(`(``(,"```7````6`,``&@"``!P``````````````````````````8"
M``!/`@``30```)T"``!:`@``@P```,D!``"8`@``60$``!8````?`0``P0``
M`&@````B`P``.`````````"@`0```````/4"```L`@```````"T#``#N`@``
M+@,````````Q`@``*@$```(!``!M`0``>0,``%L!``!Z`0```````(`"``"J
M``````````@!``#9`0``O`$``"@!``!6`@```````$`"``#K`0``````````
M```>`0``@`,``*X"`````````````"<"``#]````D`$```````!_````F0(`
M`*P!``"C`0``,P(``(0!```Z`P``6P````L```#)````ZP(``)$```#8`@``
MX@`````````>`P``?P$``'@```">`@``C@$```````"/`@``AP(``%8!``##
M`0``P@$```````#N`0````````````"&`@````````````!A`P``````````
M``!2`P```````.4!````````*P```'@!``"G`0``/0(``*("``#-`@``!@,`
M````````````#@$``.H"``!7`0``!0,``+`"``!!`P```````+@!``!W`P``
M`````,T```"R````UP(```````#)`@``3`(````````9`0``E@$``.$```#@
M````;@(``!P```!F`@``'0(````````*`0``OP```$<!````````?`$```H`
M``!]`0``E`$``!4!````````/P,```````",`P``_@$``"P```!4`0``````
M`(@#``#A`@``'0,`````````````R@(````````K`P```````#<```"X`@``
MNP$``%T#``````````````````!/`0``)`(```D"``#@`0``8P(``$L!````
M`````````'X#```@`0``EP```.,!``#]`@```````%("``#:`````@``````
M```@`P``XP````````````````````````"&````U````&4"````````````
M`,T!`````````````((````E`0``H0(``*,"````````NP(```````!G````
MMP(``-("``!F````]`(``*@```"(`@```````"H#````````1P```$T#````
M````$P```&$```"*`0````````````"2`P``!`,````````F`P``'@```'P"
M``!L`P``$@(``*L```!O`P````````````!-`@``U@$````!``!P`@``````
M`!,!```V`@``@0```.@!`````````````',!```O`P``Z````)\!``#9````
M`````(L!````````=P$``&`!``"U`0``-0,```````"L````40(``'("``!E
M`P``GP(``-$"`````````````/8"``"X````&@```````````````````%P`
M```#`@``4````!\#``#R````PP````````!I`P```````'L```"^````!0(`
M`"<!``"4``````````T"````````2`(``-P"``#"`@``&0(``&("``"R`@``
M8P$```````#8`0``&0```,P!````````3@```'T`````````>P(``,0"``!%
M`0```````#,#``#5`0``Y````,H!``")`P``#`,``%P#``"Y`@``S`(``&0#
M``#1`0``\@$``%H!``#(`@``1`,`````````````OP(``#X#````````````
M`.8````5`````````&(!``````````````X`````````U0(````````'`@``
M2P```$@````K`@```````(("``#3````9`(```````!R`P``^0```#,`````
M````$@,```````!5`P``:@```%D"``!)`@```````,8"``!$`@```````,L`
M``#0`0``[0````````"@`@``H@```',`````````O`(```````!&`0``-```
M```````T`P``6`(``,0`````````00$``)@```#I`@````````<!``"``0``
MNP```%X!````````]P````T#``"V````@0$``*H!``#U`````````%$#```$
M`0````````(#``#S````-`$```````".`P``&P$``&H#``!3`@```````&L"
M``#G````?P,```````";`P``$@$``/@!```Y````;@```$("``!Y````'0$`
M`"(```#Z````EP$``.L````<`P```````%(!````````G`$`````````````
M8P```&T#```I`@```````!T```!M`@``4P```,X!``"6`@``*0````````#Z
M`@```````"4````!`P``A@,``*@"``!"`````````(H```"%````````````
M``#J````O0$````````T`@``5P,`````````````M0```&L#````````%`(`
M`+X!````````=````(@```#[````@0,```````",`0```````,H```!B`P``
MM`(``"8"`````````````*T````O`@``3@$``#D#``"O`0``X`(``(,#``!T
M`0```````!,"``!1`0````````0"``````````````````"0`P``<P,``#T`
M```:`@``:`,```L"``"R`0``D`(``'L!``!@`@``2`,``#(#````````````
M````````````G0$``&0````'`P``C0````<```!#`P```````),#```2````
M"0$```````#%`0``9`$````#```[````)````"T``````````0(````````,
M`@``;````#,!``#H`@```````#`#``!R`0```````#@#``!B````<`$``(<`
M``#2`0``1P,``-``````````&P,``)4!``#G`0``5````,X"``!"`0``J0(`
M`(<#``"Z`0``E@,``````````@``2`$```````#>`0``V@$``$H````B`0``
MN@```$$"```D`P``$0```%L#````````#P(``$D```"-`@```````(``````
M````IP(``.\````>`@``3P,``)4```"*`@``W@```%L"``#;`````````((!
M``!H`0``6````!````!%`P``\````)0#``!`````)P,````````;`@``L0``
M``````"B`0``1`$``'$!```0`P``A````"H"````````;P$``,,"``#^`@``
M'`(`````````````*0$```````!J`@``=`(``.D!```D`0``BP(```````!W
M````````````````````)0(``!4#``""`P``,````)<#``"P`0``N@(``)@#
M``!:`P``.@(``(8!``"M`@``&````!`!````````=@(``-$```";`0``3```
M``````#:`@```````)8`````````9P(``%0#````````P0(``$L"``!Y`@``
M(````*<``````````````)0"``"S````D0(``&8#``!Q````M@$``,<!``"]
M`@``4P,``/H!``````````````````"C````U@```%4!````````K@$`````
M``!0`P``WP```"\!```3`P```````$(#``"3`@``6`$```````"F`0``3@(`
M````````````1P(``)L"```1`P```````$P#``#\`@``!@````````#A`0``
M'`$```````"D`0``+@(``/$```"I`0``P`$``+$"```V`P``/0$````````P
M`@``]`````````!I`@```````%X"``````````````\#``!0`0``6@```!$!
M````````Q0(```````!C`P``10(``.H!``!\`P``/`$``,\```#+`@``BP,`
M```````[`P``?0(``&<!``#F`@``)0,``(\```!L`0``00```($"``!S`@``
M)@```-@``````````````"T"``#>`@``U`(```````!K`0``B0````````"D
M````Y`$``-P```#L`@``*`````````!V````N0```#(!``!Y`0``4`(`````
M````````K@```.P!``!U``````````````!&`P``?P(``/$!``"-`P``;`(`
M`+\!``!?`P``G@```.\!``#M`0`````````````,````_@```-8"``#U`0``
M2P,``(P"``"5`P``J`$```````":`@``Q@``````````````3`$```````!9
M`P``TP(``#$#````````$0(``$D!``"3`0``VP(``"H```"5`@``?````(0#
M``#G`@````````````#Q`@```````$X#``#4`0```````-L!``#Y`@``R```
M`)P```"\````I@````T!````````'P``````````````F0```/L!```_`0``
M10```#8````)`P``>@(``$T!````````&`(``!D#```B`@``[0(``/0!``#.
M````M0(``/,!```C`@``H````",```!U`0``^````-T"``"E`0``%`,``,(`
M``!*`P``;P(```````">`0``^`(``#L!````````,`$``)````#P`0``LP(`
M``@#``"Y`0``FP```"L!```6`0```````(P```"I````80(``$`!````````
M0P$``/,"```"`@```````"@"````````Y0(``,\"``!U`P```````!\"``"8
M`0``+P``````````````+@$``'H#``#5````B0$``)H#```C`0``-0(``$D#
M```#`P`````````````[`@``:0$``&X#```7`0``.`(``*H"```Q`0``I0``
M`#P#``#$`0```````"P#```#`0`````````````Z`0``````````````````
M`0$``#<!``"^`@````````````#B`@``9P,``)D#````````#`$``,P````\
M````-@$``%\```````````````````#Y`0``80$``(4#````````$`(``$,`
M``#<`0``#@,``&4```#D`@``RP$`````````````C@(````````R`@``50``
M``````!5`@```````'4"````````.@```)("````````/@````````!W`@``
M`````)$#````````&`,```````#[`@```````$H"````````.0(``(,!```M
M`0``&@$``*\``````````````#4````/`0``"0```.8!``!$````5@,``'8#
M```W`P``M`$``.D```"*`P```````,`"```H`P```````.\"``!*`0``0P(`
M`&````!7````,0```#<"```\`@``&`$``+0`````````G0````````!7`@``
M[````%$````.`@``1@```'@"``#`````W0$```````#W`0``H0```*8"````
M`````````%D```!@`P``4@```'8!```:`P``_P(```````!3`0``UP$``!8#
M``!=`0``)@$``/P!```5`@``!@$```````"<`@``WP(``-,!``!I````````
M````````````O0``````````````A0(``'(```"?````[@`````````7`@``
M"@(```````#%`````````#(`````````JP(``%P!``!E`0``QP(``/<"``!J
M`0```"`@("`@(%1O.B``("`@($1A=&4Z(``@("`@1G)O;3H@`"`H)7,@9&%Y
M<R!A9V\I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"!3=6)J96-T.B``(&%T(``@:6X@`",`)2XR9DU"("\@)2XR
M9DU"("`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2X`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P
M86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@;65S<V%G97,@
M:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN`"5D('1O("5D(&]F("5D($UE
M<W-A9V5S`"5S("T@3F]T:6-E`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!4
M97)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%L<F5A
M9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S
M(&%T("5S("5S`"5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA
M:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O
M9B!T:&4@;6]N=&@N`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E
M<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P
M.R5D*0`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C
M<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE
M(&-O;7!O<V4@<V-R965N+BD`*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E
M96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@
M($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P
M<&QI960N*0`H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N
M9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C
M<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI
M8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`M+2!S
M96QE8W0@+2T`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S
M<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H
M87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2X`,2!M97-S86=E(&AA<R!B
M965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BX`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN`#$P
M,"!C:&%R86-T97)S`#$P,#`@8VAA<F%C=&5R<P`Q,B!(;W5R($9O<FUA=``R
M-"!(;W5R($9O<FUA=``R-"!H;W5R<P`R-3`@8VAA<F%C=&5R<P`U,#`@8VAA
M<F%C=&5R<P!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!32]030!!8F]U
M="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U
M;G0@9G)O>F5N+@!!8V-O=6YT)W,@;F%M93H`06-C;W5N=&EN9P!!8W1I;VYS
M`$%D9`!!9&0@2&5R93H`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D
M('-O=7)C90!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`
M061D('1O(&%D9')E<W,@8F]O:SH`061D960@(B5S(B!A<R!A;B!A='1A8VAM
M96YT+@!!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N
M`$%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<P!!9&1I=&EO;F%L(&UE
M<W-A9V4@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@
M8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL
M<P!!9&1R97-S($)O;VL`061D<F5S<R!";V]K<P!!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9F=H86YI<W1A;@!!;&)A
M;FEA`$%L9V5R:6$`06QL`$%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG
M(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F
M:6QE.@!!;&P@;65S<V%G97,@:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T
M:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@
M;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD
M('=I;&P@8F4@9&5L971E9"X`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@
M4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QW87ES`$%L=V%Y
M<R!S879E(&%T=&%C:&UE;G1S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I
M9FEE9"X`06YS=V5R960`06YS=V5R960@;65S<V%G97,`07!P;'D@1FEL=&5R
M<P!!<'!L>2!&:6QT97)S('1O("5S`$%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N
M(&QO9V=I;F<@;VX_`$%P<FEL`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D
M96QE=&4@=&AI<R!P=6)L:6,@:V5Y/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@9&\@=&AI<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.
M5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_
M`$%R<FEV86P@5&EM90!!<V-E;F1I;F<`07-K`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1A
M8V@`071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@
M>6]U('-E;G0N`$%T=&%C:&UE;G0`071T86-H;65N=',`075G=7-T`$%U=&]M
M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H
M92!S96YD97(@:7,@:6X@;7D@861D<F5S<V)O;VL_`$)A8U]K('1O("5S`$)A
M8VL@=&\@)7,`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F-C`$)L86-K;&ES=`!"
M;&]C:R!4>7!E`$)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S
M<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/P!";V1Y`$)O;&0`
M0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O
M<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O=&@@2&5A9&5R
M($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G90!";W1S=V%N80!";W1T;VT`
M0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI
M<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#7V5L;"!0<F]P97)T
M:65S+BXN`$-?:&%R<V5T`$-A;6)O9&EA`$-A;65R;V]N`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P@365S<V%G90!#
M86YC96P@4')O8FQE;2!297!O<G0`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-C
M`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1R86P@069R:6-A;B!297!U8FQI
M8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#:&%N9V4`0VAA;F=E
M($%L;`!#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@
M;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD(&AO=R!M97-S86=E
M<R!A<F4@<V]R=&5D+@!#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S
M971T:6YG<RX`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@96UA:6PN`$-H87)A8W1E<G,@=&\@9&ES<&QA>3H`0VAE8VL@1F]L9&5R
M*',I(&9O<B!.97<@36%I;`!#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W
M86YT('1O(&9E=&-H(&UA:6P@9G)O;3H`0VAE8VL@<W!E;&QI;F<@8F5F;W)E
M('-E;F1I;F<@82!M97-S86=E/P!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO
M;W-E($%C=&EO;CH`0VAO;W-E(&$@;6%I;"!S97)V97(Z`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H
M;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D<F5S<R!B
M;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N`$-H;V]S92!T:&4@
M;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I
M;F<@861D<F5S<V5S+@!#:')I<W1M87,@27-L86YD`$-L96%R`$-L96%R($U3
M3V9F:6-E('1A9W,`0VQI8VL@)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+@!#
M;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S
M<V%G92!T;R!T:&4@<V5N9&5R`$-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I
M;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D`$-L;W-E`$-L;W-E('1H
M:7,@=VEN9&]W`$-L;W-E9"!&;VQD97(`0V]L;&%P<V4@06QL`$-O;&QA<'-E
M($%L;"!&;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VQO=7(@<V5L96-T:6]N
M`$-O;6]R;W,`0V]M<&%N>0!#;VUP;W-E(&%N;W1H97(@;65S<V%G90!#;VUP
M;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!#;VUP;W-E(&UE
M<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H:68@8G)O=W-E
M<B!S=7!P;W)T<R!T:&4@9F5A='5R92D_`$-O;F9I9W5R92!H;W<@;65S<V%G
M97,@87)E(&1I<W!L87EE9"X`0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I
M;VYS+@!#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!3+TU)
M344@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL
M(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y
M('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O;G9E<G0@=&5X='5A;"!E;6]T:6-O
M;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\`0V]P>0!#;W!Y('-E;&5C=&EO;@!#
M;W!Y('1O(&9O;&1E<@!#;W)R96-T`$-O<G)E8W1E9"!497AT`$-O=6QD(&YO
M="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<P!#;W5L9"!N;W0@9&5L971E
M(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,`0W)E871E
M($9O;&1E<@!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!D<F%F=',@9F]L
M9&5R`$-R96%T92!A(&YE=R!O;F4`0W)E871E(&$@;F5W('-E;G0@;6%I;"!F
M;VQD97(`0W)E871E(&$@;F5W('1R87-H(&9O;&1E<@!#<F5A=&4@9FEL=&5R
M:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R
M="!I="!I;G1O(&9O;&1E<G,L(&%N9"!D96QE=&4@<W!A;2X`0W)E871E('-U
M8B!F;VQD97)S`$-U<G)E;G0@86-C97-S('1O("5S`$-U<W1O;6EZ92!A8V-O
M=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+@!#
M=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`1&%I;'D`1&%T7V4`1&%T90!$96-E
M;6)E<@!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$
M969I;FET:6]N<P!$96QE=&4`1&5L971E($-U<G)E;G0@2V5Y<P!$96QE=&4@
M1F]L9&5R*',I`$1E;&5T92!6:7)T=6%L($9O;&1E<@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T
M(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(&]L9"!S96YT+6UA:6P@9F]L
M9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>0!$96QE=&5D`$1E;&5T960@;65S<V%G97,`1&5L971I;F<@86YD
M($UO=FEN9R!-97-S86=E<P!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B
M;&5M`$1I;2!S:6=N871U<F5S/P!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&-O;F9I
M<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\`1&ES<&QA>2!F;W)E
M8V%S="`H5$%&*0!$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G90!$:7-P;&%Y
M('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_`$1O($YO="!#:&5C
M:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$1O(&YO="!G96YE<F%T92!A(&QI
M;FL@:6X@=&AE($9R;VTZ(&-O;'5M;@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA=`!$;W=N;&]A9"!!;&P@071T86-H
M;65N=',@*&EN("YZ:7`@9FEL92D`1&]W;FQO860@1F]L9&5R*',I`$1O=VYL
M;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=`$1O=VYL;V%D(&EN("YZ:7`@
M1F]R;6%T`$1R869T`$1R869T(&9O;&1E<@!$<F%F=',@9F]L9&5R.@!%9&ET
M($)L86-K;&ES=`!%9&ET($9I;'1E<G,`161I="!097)M:7-S:6]N`$5D:70@
M4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!7:&ET
M96QI<W0`161I="!O<'1I;VYS(&9O<CH`161I="!Y;W5R(&)L86-K;&ES=`!%
M9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D:70@>6]U<B!P<F5F97)E;F-E<R!F
M;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N`$5D:70@>6]U<B!W
M:&ET96QI<W0`16UA:6P@061D<F5S<P!%;6]T:6-O;G,`16UP='D@1F]L9&5R
M*',I`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T>2!?5')A<V@`16YA8FQE(%!'
M4"!F=6YC=&EO;F%L:71Y/P!%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_
M`$5N86)L92!M97-S86=E('!R979I97=S/P!%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/P!%;F-R7WEP=&EO;B!/<'1I;VYS`$5N9`!%;F0@9F]R
M=V%R9&5D(&UE<W-A9V4`16YD(&UE<W-A9V4`16YD(&UE<W-A9V4@9G)O;2`E
M<P!%;G1E<B!087-S<&AR87-E`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE
M=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S
M96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T
M<F%S:"!F;VQD97(`16YT<GD@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('1H92!A9&1R97-S(&)O;VL`17%U871O<FEA;"!'=6EN96$`17)I=')E
M80!%<G)O<@!%<G)O<B!S96YD:6YG(')E<&QY.B`E<RX`17-T;VYI80!%=&AI
M;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M
M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y
M($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V
M86QU97,Z`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N9"!&
M;VQD97(`17AP86YD($YA;65S`$5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S
M92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\`17AP
M86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@
M9F]L9&5R<R!V:65W/P!%>'!A;F1I;F<`1F5B<G5A<GD`1F5T8V@@36%I;`!&
M971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!&:5]L=&5R<P!&:6QE
M`$9I;'1E<B!/<'1I;VYS`$9I;'1E<B!3971T:6YG<P!&:6QT97(@;65S<V%G
M92!C;VYT96YT(&9O<B!P<F]F86YI='D_`$9I;'1E<B!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+@!&:6QT97)S`$9I;'1E<G,@3D]4($%C
M=&EV90!&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4`1FEN9`!&:7)S="!-
M86EL8F]X(%!A9V4`1FER<W0@4&%G90!&;U]R=V%R9`!&;VQD97(@3F%V:6=A
M=&]R`$9O;&1E<B!3=6UM87)Y`$9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN
M('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y`$9O
M<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&<F5E
M+T)U<WD@4F5P;'D`1G)O7VT`1G)O;0!&<F]M($%D9')E<W,`1G5L;"!$97-C
M<FEP=&EO;@!&=V0Z`$=E;F5R86P@3W!T:6]N<P!';R!T;R!-97-S86=E`$=O
M;V=L92!396%R8V@`1W)A;G0@86-C97-S`$=R965K("A)4T\M.#@U.2TW*0!(
M96%D97)S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96QP`$AI9&1E;@!(:61D
M96X@:6X@5&AR96%D(%9I97<`2&ED92!$96QE=&5D`$AI9&4@56YS=6)S8W)I
M8F5D`$AI9V@@4')I;W)I='D`2&]?;64`2&]M90!(;VUE($%D9')E<W,`2&]M
M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]W(&1O('EO=2!W
M86YT('1O(&1I<W!L87D@871T86-H;65N=',_`$AO=R!T;R!A='1R:6)U=&4@
M<75O=&5D(&QI;F5S(&EN(&$@<F5P;'D`24U!4`!)34%0("A!=71O($1E=&5C
M="!0<F]T;V-O;',I`$E-05`@;W9E<B!34TP`24U!4"!O=F5R(%-33"`H<V5L
M9BUS:6=N960@8V5R=&EF:6-A=&4I`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG
M;F5D*0!)34%0+"!N;R!43%,`24U!4"]03U`S($UA:6P@4V5R=F5R<P!)3D)/
M6`!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`26-E;&%N9`!)
M8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I
M='DG<R!N86UE.@!)9VYO<F4`26=N;W)E($%L;`!);7!O<G0@365S<V%G97,`
M26UP;W)T86YT`$EM<&]R=&%N="!M97-S86=E<P!);F)O>`!);F-L=61E(&$@
M8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_`$EN8VQU
M9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/P!);G-E<G0@;65S<V%G
M97,`26YV97)T`$IA;G5A<GD`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*=6QY
M`$IU;F4`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I
M8R!297!U8FQI8P!,87-T($UA:6QB;W@@4&%G90!,87-T(%!A9V4`3&%S="!5
M<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S
M`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE8F%N;VX`
M3&5S;W1H;P!,:5]N:R!!='1A8VAM96YT<P!,:6)E<FEA`$QI8GEA;B!!<F%B
M($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6YK<P!,:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(`3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D
M:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I
M;&P@;VYL>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L
M:6-I=&QY*0!,:7-T:6YG(&EN('1H92!(96%D97(`3&ET:'5A;FEA`$QO861I
M;F<N+BX`3&]C86P@36%I;&)O>#H`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@
M5&EM90!,;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G:6X@5&%S:W,`
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG
M('1E>'0`3&]W(%!R:6]R:71Y`$QU>&5M8F]U<F<`36%I;`!-86EL(%!R979I
M97=S`$UA:6QB;W@`36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T:6]N
M<P!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+@!-87)C:`!-87)K($%L;"!-97-S86=E<R!I;B!&
M;VQD97(@87,@4V5E;@!-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@
M56YS965N`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T
M:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`36%R:R!S:6UP;&4@;6%R:W5P
M/P!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L
M86YD<P!-87)T:6YI<75E`$UA=&-H($%L;"!1=65R:65S`$UA=&-H($%N>2!1
M=65R>0!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X
M:6UU;2!!='1A8VAM96YT(%-I>F4`36%Y`$UE971I;F<@4F5P;'D`365M8F5R
M<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!#;VUP
M;W-I=&EO;@!-97-S86=E($1A=&4`365S<V%G92!/<'1I;VYS`$UE<W-A9V4@
M4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9I
M97=I;F<`365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G92!M
M871C:&5S`$UE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN`$UE<W-A
M9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V960@=&\@)7,`365S
M<V%G92!S96YT('-U8V-E<W-F=6QL>2X`365S<V%G97,@<&5R('!A9V4@:6X@
M=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`36EM92!4>7!E`$UO;G1H
M;'D`36]V90!->2!0;W)T86P@3&%Y;W5T`$YA;64`3F5T=V]R:P!.979E<@!.
M979E<B!S879E(&%T=&%C:&UE;G1S`$YE=P!.97<@0V%L961O;FEA`$YE=R!#
M871E9V]R>0!.97<@1F]L9&5R`$YE=R!-86EL`$YE=R!-;V]N`$YE=R!5<V5R
M;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!M97-S86=E<P!.97<@
M=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT($UE<W-A9V4`
M3F5X="!086=E`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I
M80!.:6=H=`!.:75E`$YO`$YO($5N8W)Y<'1I;VX`3F\@365S<V%G97,`3F\@
M9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!M97-S86=E(&)O9'D@=&5X=`!.
M;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S=&EO;G,`3F\@=7-E<B!S<&5C
M:69I960N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;VYE
M`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO="!$96QE=&5D`$YO="!$<F%F=`!.
M;W0@26UP;W)T86YT`$YO="!097)S;VYA;`!.;W0@9&5L971E9"!M97-S86=E
M<P!.;W0@:6UP;W)T86YT(&UE<W-A9V5S`$YO=F5M8F5R`$YU;6)E<B!O9B!M
M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T
M:6YG(&UO;G1H;'DN`$YU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@
M=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+@!/8W1O8F5R`$]L9"!M97-S
M86=E<P!/;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D+@!/<&5N
M960@1F]L9&5R`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O
M<B`E<P!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!-86EL($%C8V]U
M;G1S`$]T:&5R($]P=&EO;G,`4$=0`%!'4"!%;F-R>7!T($UE<W-A9V4`4$=0
M($5R<F]R.B``4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O
M;F%L('!R:79A=&4@:V5Y+@!01U`@3W!T:6]N<P!01U`@4&%S<W!H<F%S92!)
M;G!U=`!01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+@!01U`@4'5B;&EC($ME>2!497AT`%!'
M4"!0=6)L:6,@2V5Y(&9O<B`B)7,@*"5S*2(@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"X`4$=0(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL
M>2!D96QE=&5D+@!01U`@4'5B;&EC($ME>7)I;F<`4$=0(%-I9VX@365S<V%G
M90!01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4`4$=0('!R:79A=&4@:V5Y('-U
M8V-E<W-F=6QL>2!A9&1E9"X`4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY
M(&%D9&5D+@!01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E
M;2X`4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE
M(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`
M4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE
M<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`4$]0,P!03U`S("A!
M=71O($1E=&5C="!0<F]T;V-O;',I`%!/4#,@;W9E<B!34TP`4$]0,R!O=F5R
M(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I`%!/4#,@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D*0!03U`S+"!N;R!43%,`4&%G92`E9"!O9B`E9`!086=E
M('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E`%!A9V4@=VET:"!T:&4@
M3&%S="!5;G-E96X@365S<V%G90!087)T*',I`%!A<W-W;W)D`%!E;W!L90!0
M97)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`
M4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R;6ES<VEO;G,@9F]R('1H
M:7,@=7-E<B!C86X@;F]T(&)E(&-H86YG960N`%!E<G-O;F%L`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L
M:65S(&%N9"!F;W)W87)D<S\`4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G
M90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L
M96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64N`%!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A
M;&ED(&%D9')E<W-E<RX`4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@
M>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N`%!L96%S92!S96QE8W0@86X@86-T
M:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@;W(@961I
M="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#H`4&]S="!T;R!T:&ES(&9O;&1E
M<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!O=V5R960@8GD@2&]R9&4`4')E
M8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/P!0<F5V
M:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0
M<FEN=`!0<FEO<FET>0!0<FEV871E($ME>2!087-S=V]R9`!0<F]B;&5M`%!R
M;V)L96T@1&5S8W)I<'1I;VX`4')O;7!T(&5V97)Y('1I;64@86X@871T86-H
M;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/`%!R;VUP="!E=F5R>2!T:6UE
M(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,`4')O=&]C
M;VPZ`%!U<E]G92!$96QE=&5D`%!U<F=E($1E;&5T960`4'5R9V4@1F]L9&5R
M*',I`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S<V%G97,@:6X@
M5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RX`
M4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_`%%U;W1A
M('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0!1=6]T82!S=&%T
M=7,Z("4N,F9-0B`O($Y/($Q)34E4`%%U;W1A('-T871U<SH@3D\@3$E-250`
M475O=&EN9R`E9CH`4F5?<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N`%)E
M860@;65S<V%G97,`4F5C96EV960@3VX`4F5C96EV960@4VEN8V4`4F5C96EV
M960@56YT:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T($UE<W-A9V4`
M4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE9"X`4F5F
M<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!&
M;VQD97(@5FEE=W,Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;&]A9"!6:65W
M`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E($UA:6QB;W@Z`%)E;6]T
M92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.@!296YA;64@1F]L9&5R*',I`%)E;F%M92!S96YT+6UA:6P@9F]L
M9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`4F5N86UI;F<@(B5S(B!T;R`B
M)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!297!L
M7WD@=&\@3&ES=`!297!L86-E('=I=&@Z`%)E<&QY`%)E<&QY(%-E;G0N`%)E
M<&QY('1O($%L;`!297!L>2!T;R!!;&PZ`%)E<&QY('1O($QI<W0`4F5P;'D@
M=&\@3&ES=#H`4F5P;'D@=&\@7T%L;`!297!L>2!W:71H($YO="!3=7!P;W)T
M960@365S<V%G90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO
M;G1H<RX`4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+@!297!L>2U4;P!297!L>2U4;SH@`%)E<&QY.@!297!O<G0@87,@26YN
M;V-E;G0`4F5P;W)T(&%S(%-P86T`4F5Q=65S="!A(%]296%D(%)E8V5I<'0`
M4F5Q=65S="!D96QI=F5R>2!C;VYF:7)M871I;VX_`%)E<75E<W0@<F5A9"!R
M96-E:7!T<S\`4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+@!297-E=`!2
M97-U;64`4F5S=6UE('EO=7(@<V5S<VEO;@!2971U<FX@=&\@1F5T8V@@36%I
M;`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES
M=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S
M<V%G93\`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,`4R]-24U%`%,O34E-12!%;F-R>7!T($UE<W-A9V4`
M4R]-24U%($]P=&EO;G,`4U]U8FIE8W0`4V%?=F4@82!C;W!Y(&EN(`!385]V
M92!A<P!3879E($1R869T`%-A=F4@3W!T:6]N<P!3879E(%]$<F%F=`!3879E
M(&%S`%-A=F4@9')A9G1S(&%S('5N<V5E;C\`4V%V92!R96-I<&EE;G1S(&%U
M=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K/P!3879E
M('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/P!3879E('-E;G0@;6%I;#\`
M4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("5S`%-E87)C:`!396%R8V@@)7,`4V5A<F-H(%)E<W5L=',`
M4V5E;@!396QE8W0`4V5L96-T($%N;W1H97(@06-C;W5N=`!396QE8W0@82!F
M:65L9`!396QE8W0@82!S97)V97(`4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R
M8V5S(&9O<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+@!3
M96QE8W0@86QL`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X
M<&%N9&EN9R!A9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!N
M;VYE`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE;2!297!O<G0`
M4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!396YT(&UA:6P@9F]L9&5R.@!3
M97!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`
M4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N`%-E<W-I;VX@
M240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T
M('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A
M;F0@9&5L971E(&UE<W-A9V5S+@!3970@=&AE(%@M4')I;W)I='D@:&5A9&5R
M('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/P!3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@
M;W!T:6]N<RX`4V5T=7``4V5Y8VAE;&QE<P!3:&%R92!&;VQD97)S`%-H87)E
M(&UA:6P@9F]L9&5R<P!3:&%R92!Y;W5R(&UA:6P@9F]L9&5R<R!W:71H(&]T
M:&5R('5S97)S+@!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]U;&0@;&%R9V4@8FQO8VMS
M(&]F('%U;W1E9"!T97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT
M/R!)="!C86X@8F4@=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O
M<V4N`%-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R
M('-A=FEN9R!A(&1R869T/P!3:&]W`%-H;W<@06QL($AE861E<G,`4VAO=R!$
M96QE=&5D`%-H;W<@3&EM:71E9"!(96%D97)S`%-H;W<@56YS=6)S8W)I8F5D
M`%-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@871T86-H;65N
M=',@9G)O;2!M97-S86=E<S\`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/P!3:&]W(&QE9V5N9"!I;B!T:&4@;6%I;&)O>"!V:65W/P!3
M:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\`4VAO=R!P
M<F5V:65W<R!I;B!T;V]L=&EP<S\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H
M92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE(&9I
M;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/P!3:&]W;@!3:5]Z90!3:6=N960`
M4VEZ90!3:VEP($UA:6YT96YA;F-E`%-O<G0@8GD@1G)O;2!!9&1R97-S`%-O
M<G0@8GD@365S<V%G92!3:7IE`%-O<G0@8GD@4W5B:F5C=`!3;W)T(&)Y(%1H
M<F5A9`!3;W)T(&)Y(%1O($%D9')E<W,`4V]U=&@@175R;W!E86X@*$E33RTX
M.#4Y+3,I`%-P86T@9F]L9&5R.@!3<&5C:6%L($-H87)A8W1E<G,`4W!E;&P@
M0VAE8VL`4W!E;&P@0VAE8VME<@!3<&5L;"!C:&5C:R!C;VUP;&5T90!3<&5L
M;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+@!3
M=')I<"!L:6YE8G)E86MS/P!3=6)?:F5C=`!3=6)J96-T`%-U8FIE8W0@1FEE
M;&0`4W5B;6ET`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5C8V5S<P!3=6=G
M97-T:6]N<P!495]X=`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN
M`%1H92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI
M;FME9#H`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N86UE9"!T
M;R`B)7,B+@!4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S
M('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960`5&AE(&9O
M;&1E<B`B)7,B(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!C;VYT
M86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C
M875S92!P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+@!4:&4@9F]L9&5R("(E<R(@=V%S(&-R96%T960@8G5T('EO=2!W
M97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S
M(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I
M="X`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S(&YO="!D
M96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H92!F;VQD
M97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N`%1H92!F;VQD97(@
M(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%1H92!F;VQD97(@(B5S
M(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@(B5S(BX`5&AE(&ED96YT
M:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE<F4@87)E(&YO(&UE<W-A
M9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A
M:6QA8FQE+@!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@82!P<F]B;&5M
M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@
M9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN
M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9`!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@
M<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@
M=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,`
M5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'
M4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z(`!4:&ES(&UE<W-A9V4@=&\`
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:')E860@5FEE=P!4;P!4;R!!9&1R
M97-S`%1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@8VQI8VMI;F<N
M`%1R87-H(&9O;&1E<@!4<F%S:"!F;VQD97(Z`%1U<FMI<V@@*$E33RTX.#4Y
M+3DI`%5N86YS=V5R960`56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T90!5
M;F1I<V-L;W-E9"!296-I<&EE;G1S`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5N
M:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FMN;W=N('5S
M97)N86UE(&]R('!A<W-W;W)D+@!5;FYA;65D`%5N<V5E;@!5;G-U8G-C<FEB
M92!F<F]M($9O;&1E<BAS*0!5<V4@1&5F875L="!686QU90!5<V4@24U!4"!F
M;VQD97(@<W5B<V-R:7!T:6]N<S\`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@
M9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO
M="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97)N86UE`%5S97)N86UE.@!6:65W("5S`%9I97<@5&AR96%D
M`%9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.@!6:7)T
M=6%L($9O;&1E<G,`5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"X`
M5FER='5A;"!F;VQD97(@;&%B96P`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T
M;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N
M("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAE;B!D96QE=&EN
M9R!M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN
M<W1E860@;V8@;6%R:VEN9R!T:&5M(&%S(&1E;&5T960_`%=H96X@;W!E;FEN
M9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T
M87)T(&]N/P!7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E
M(&%T=&%C:&UE;G0@9&%T83\`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R
M('1H92!2:6-H(%1E>'0@961I=&]R+@!7:&ET96QI<W0`5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ`%EE87)L>0!997,`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+@!9;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE
M=&5D+@!9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S
M+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(97)E(&ES('=H
M870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@
M9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W
M97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`66]U('=E<F4@
M<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@
M16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M
M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD
M:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@
M9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`
M66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E
M<G9E<G,Z`%EO=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6TYO(%-U8FIE
M8W1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO
M=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D
M;6EN:7-T<F%T:6]N`%]"8V,`7T)L86-K;&ES=`!?0TQ)`%]#8P!?1&%T851R
M964`7T1E;&5T90!?1&5L971E(%)O=P!?1F]L9&5R<P!?1W)O=7!S`%](96QP
M`%])9&5N=&ET>0!?26UA9V4@4')O<&5R=&EE<RXN+@!?26YB;W@`7TQO9R!I
M;@!?3&]G(&]U=`!?365S<V%G92!3;W5R8V4`7TUO9&EF>2!,:6YK+BXN`%]/
M<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U)E;6]V92!,:6YK+BXN`%]2
M97!L>0!?4V5A<F-H`%]396YD($UE<W-A9V4`7U-E='5P`%]486)L92!0<F]P
M97)T:65S+BXN`%]4:')E860`7U1O`%]5;F1E;&5T90!?57-E<G,`7U9I97<@
M5&AR96%D`%]7:&ET96QI<W0`861D<F5S<R!B;V]K`&9R;VT`;6%I;&)O>"!F
M:6QE`&YA;64`;F]N90!O<@!S<&5L;&EN9R!E<G)O<@!S<&5L;&EN9R!E<G)O
M<G,`=&%S:R!L:7-T`'5N;F%M960`=D-A<F0`=V5A=&AE<BYC;VT`>6]U<B!W
M:&ET96QI<W0`4')O:F5C="U)9"U697)S:6]N.B!I;7`M8G,*4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E
M.B`R,#`U+3`W+3`Q(#$S.C(X*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!6961R
M86X@3&IU8F]V:6,@/'9L:G5B;W9I8T!S;6%R=&YE="YB83X*3&%N9W5A9V4M
M5&5A;3H@0F]S;FEA;B`\;&]K86Q`;&EN=7@N;W)G+F)A/@I-24U%+59E<G-I
M;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/
M+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E@M1V5N
M97)A=&]R.B!+0F%B96P@,2XQ,`H`("`@("!:83H@`"`@($1A='5M.B``("`@
M("`@3V0Z(``@*'!R:6IE("5S(&1A;F$I`"`H>F$@)7,@9&%N82D`("AD86YA
M<RD`("AS=71R82D`("AJ=>AE*0`@5&5M83H@`"!U(``@=2``(P`E+C)F34(@
M+R`E+C)F34(@("@E+C)F)24I`"5D("5S(&D@)7,`)60@<&]R=6MA(&IE('!R
M:6IA=FQJ96YO(&1A(&YI<W4@<W!A;2!A9&UI;FES=')A=&]R=2!S:7-T96UA
M+@`E9"!P;W)U:V$@:F4@<')I:F%V;&IE;F\@9&$@;FES=2!S<&%M+@`E9"!P
M;W)U:V$@:F4@<')I:F%V;&IE;F\@:V%O('-P86T@861M:6YI<W1R871O<G4@
M<VES=&5M82X`)60@<&]R=6MA(&IE('!R:6IA=FQJ96YO(&MA;R!S<&%M+@!0
M;W)U:V4@)60@9&\@)60@;V0@=6MU<&YO("5D`"5S("T@3F%P;VUE;F$`)7,@
M2T(`)7,@4V5R=FES;F4@;W!E<F%C:6IE("T@<&]T=G)D80`E<R!P;V1EN6%V
M86YJ90`E<R!P<FEJ879A`"5S('5S;&]V:2!U9V]V;W)A`"5S('9EYB!P;W-T
M;VII+@`E<R!V9>8@<&]S=&]J:2X@26UE("5S(&9O;&1E<F$@;FEJ92!P<F]M
M:F5N:F5N;RX`)7,@=2`E<R`E<P`E<R!N92!I>F=L961A(&MA;R!D;WIV;VQJ
M96X@=&EP('-A;F1UZ&5T82X`26UE("5S(&9O;&1E<F$@:F4@<')O;6IE;FIE
M;F\@<&_H971K;VT@;6IE<V5C82X`)7,@;6EN=71A`"5S(&YI:F4@<')O;F'P
M96XN`"5S('IA("5S(&]D("5S`"5S(&%D<F5S87(`)7,@:V%L96YD87(`)7,@
M8FEL:F6^;FEC80`E<R!Z861A8VD`)7,Z("5S("@E9"9N8G-P.V]D)FYB<W`[
M)60I`"A0<FEM:F5N:2!O=F4@:7IM:F5N92!I(&ED:2!N82!S;&IE9&7F:2!E
M:W)A;BXI`"A/9&)A8VD@<W9E(&EZ;6IE;F4@:2!V<F%T:2!S92!N82!E:W)A
M;B!Z82!P:7-A;FIE+BD`*%9R871I('-E(&YA(&5K<F%N('IA('!I<V%N:F4@
M<&]S;&EJ92!P<FEM96YE('-V:6@@:7IM:F5N82!D;R!S861A+B!)>FUJ96YE
M(&YA('1R96YU=&YO;2!E:W)A;G4@3D7&12!B:71I(&%K=&EV:7)A;F4N*0`H
M4&^Y86QJ:2!P;W)U:W4@;F%K;VX@87!L:6-I<F%N:F$@<W9I:"!N87!R879L
M:F5N:6@@:7IM:F5N82X@($EZ;6IE;F4@;F$@=')E;G5T;F]M(&5K<F%N=2!.
M1<9%(&)I=&D@86MT:79I<F%N92XI`"H@1&]D86H@;W9E(&MA9"!K;&EK;F6Y
M(&YA($]+("H`*B!-;VQI;2!I>F%B97)I=&4@861R97-E("H`+2T@:7IA8F5R
M:71E("TM`#$@<&]R=6MA(&IE('!R:6IA=FQJ96YA(&1A(&YI:F4@<W!A;2!A
M9&UI;FES=')A=&]R=2!S:7-T96UA+@`Q('!O<G5K82!J92!P<FEJ879L:F5N
M;R!D82!N:6IE('-P86TN`#$@<&]R=6MA(&IE('!R:6IA=FQJ96YO(&MA;R!S
M<&%M(&%D;6EN:7-T<F%T;W)U('-I<W1E;6$N`#$@<&]R=6MA(&IE('!R:6IA
M=FQJ96YO(&MA;R!S<&%M+@`Q,#`@>FYA:V]V80`Q,#`P('IN86MO=F$`,3(M
M<V%T;FD@9F]R;6%T`#(T+7-A=&YI(&9O<FUA=``R-"!S871A`#(U,"!Z;F%K
M;W9A`#4P,"!Z;F%K;W9A`$1ON6QO(&IE(&1O(&9A=&%L;F4@9W)EN6ME`$%-
M+U!-`$\@;W9O;2!E9&ET;W)U`$\@<')O9W)A;74N+BX`J6EF<F$@:V]R:7-N
M:>AK;V<@;F%L;V=A`$YA;&]G(&IE('IA;7)Z;G5T+@!);64@:V]R:7-N:>AK
M;V<@<F'H=6YA.@!28>AU;F]V;V1S='9O`$%K8VEJ90!$;V1A:@!$;V1A:B!O
M=F1J93H`1&]D86H@;F]V;V<@:V]R:7-N:6MA.@!$;V1A:B!K;VQO;G4`1&]D
M86H@:7IV;W(`1&]D86H@)7,@;65N:2!U($UO>FEL;&$@4VED96)A<@!$;V1A
M:B!U(&%D<F5S87(Z`$1O9&%N("(E<R(@:V%O('!R:6QO9RX`36]G=>9E(&IE
M('!R:6MA>F%T:2!D;V1A=&YE(&EN9F]R;6%C:6IE("5S+@!$;V1A=&YE(&EN
M9F]R;6%C:6IE`$1O9&%T;F4@:6YF;W)M86-I:F4@;R!P;W)U8VD`36]G=>9E
M(&IE('!R:6MA>F%T:2!D;V1A=&YE(&EN9F]R;6%C:6IE(&\@<&]R=6-I("5S
M+@!$;V1A=&YE(&EN9F]R;6%C:6IE(&\@9W)EN6-I`$EM96YI:P!);65N:6-I
M`$%D;6EN:7-T<FER86YJ92`M('!O9&6Y879A;FIE(&1O>G9O;&$@9')U9VEH
M(&MO<FES;FEK80!!9F=A;FES=&%N`$%L8F%N:6IA`$%LOFER`%-V90!3=F4@
M<&]R=6ME('4@<VQJ961EYFEM(&9O;&1E<FEM82#F92!B:71I(&1O=VYL;V%D
M;W9A;F4@=2!J961N=2!-0D]8(&1A=&]T96MU.@!3=F4@<&]R=6ME('4@=F&Y
M96T@(B5S(B!F;VQD97)U('-T87)I:F4@;V0@)7,@9&%N82#F92!B:71I('IA
M=79I:F5K(&]B<FES86YE+@!3=FD@9F]L9&5R:2!P;W-L86YE('!ON71E('-T
M87)I:FD@=FFY92!O9"`E<R!M:F5S96-I+"#F92!B:71I(&]B<FES86YI+@!$
M;WIV;VQI('!R879L:F5N:F4@;G5M97)I<V%N:6@@;&ES=&D_`$%L=&5R;F%T
M:79N:2!)35-0(&QO9VEN`$%L=&5R;F%T:79N82!)35-0(+EI9G)A`$%L=&5R
M;F%T:79N;R!)35-0(&MO<FES;FGH:V\@:6UE`%5V:6IE:P!5=FEJ96L@>F%P
M86UT:2!P<FEL;V=E`%5N9;EE;F$@:F4@:6QE9V%L;F$@=G)I:F5D;F]S="X`
M3V1G;W9O<F5N80!/9&=O=F]R96YE('!O<G5K90!0<FEM:F5N:2!F:6QT97)E
M`%!R:6UJ96YI(&9I;'1E<F4@;F$@)7,`4')I;65N:2!F:6QT97(@<')A=FEL
M82!N86MO;B!P<FEJ879L:FEV86YJ83\`07!R:6P`1&$@;&D@<W1E('-I9W5R
M;FD@9&$@OF5L:71E(&]B<FES871I(&]V86H@:F%V;FD@:VQJ=>@_`$1A(&QI
M('-T92!S:6=U<FYI(&1A(+YE;&ET92!O=F\@=7)A9&ET:3\`1&$@;&D@<W1E
M('-I9W5R;FD@9&$@OF5L:71E(&]B<FES871I(&]V92!P;W)U:V4_`$1A(&QI
M('-T92!S:6=U<FYI(&1A(+YE;&ET92!I<W!R87IN:71I(&]V86H@9F]L9&5R
M/P!$82!L:2!S=&4@<VEG=7)N:2!D82"^96QI=&4@:7-P<F%Z;FET:2!F;VQD
M97(@2V]R<&$_`$1A(&QI('-T92!S:6=U<FYI(&1A(+YE;&ET92!Z875V:6IE
M:R!O8G)I<V%T:2!O=F4@<&]R=6ME/P!6<FEJ96UE('!R:7-T:7IA;FIA`%)A
M<W1UYFD`4&ET86H`4&ET86H@<')I:F4@;V)A=FQJ86YJ82!S97)V:7-N:6@@
M;W!E<F%C:6IA/P!:86MAZ&D`6F%K8>AE;B!J92!O9&=O=F]R(&YA(&MA;&5N
M9&%R<VMI('IA:'1J978@:V]J:2!S=&4@<&]S;&%L:2X`4')I;&]G`%!R:6QO
M>FD`075G=7-T`$%U=&]M871S:VD@<')I:V&^:2!S;&EK92!U($A434P@<&]R
M=6MA;6$@>F$@:V]J92!J92!P;[EI;&IA;&%C('4@;6]M(&%D<F5S87)U/P!?
M3F%Z860@=2`E<P!.87IA9"!U("5S`$)A;'1IZ&MI("A)4T\M.#@U.2TQ,RD`
M0F-C`$-R;F$@;&ES=&$`5G)S=&$@8FQO:V$`0FQO:VER86H@<VQI:V4@=2!(
M5$U,('!O<G5K86UA(&]S:6T@86MO('-U('-P96-I9FGH;F\@>F%T<F&^96YE
M/P!4:6IE;&\`36%S;F\`0F]L:79I:F$`6F%B:6QJ9;EK90!2=6(`1&5B;&II
M;F$@<G5B;W9A.@!2=6)O=FD`0F]S;F$@:2!(97)C96=O=FEN80!/8F$`22!U
M('IA9VQA=FQJ=2!I('4@=&5K<W1U('!O<G5K90!";V-V86YA`$1N;P!";W5V
M970@;W-T<G9O`$)R87II;`!"<FET86YS:V$@26YD:6IS:V\M3VME86YS:V$@
M5&5R:71O<FEJ80!"<G5N96D@1&%R=7-S86QA;0!"=6=A<G-K80!,:7-T82!S
M82!T8>AK86UA`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`3W-O8FEN
M92#F7V5L:6IE+BXN`%]+;V1N:2!R87-P;W)E9`!+86UB;_!A`$MA;65R=6X`
M3F4@;6]G=2!S92!S<&]J:71I(&YA($E-05`@<V5R=F5R.B`E<P!+86YA9&$`
M3V1U<W1A;FD@;V0@<VQA;FIA`$]D=7-T86YI(&]D('!R:6IA=F4@<')O8FQE
M;6$`2V%T96=O<FEJ92!I(&]Z;F%K90!#8P!+96QT<VMI("A)4T\M.#@U.2TQ
M-"D`0V5N=')A;&YO+4%F<FGH:V$@4F5P=6)L:6MA`$-E;G1R86QN;RUE=G)O
M<'-K:2`H25-/+3@X-3DM,BD`4')O;6IE;FD`4')O;6IE;FD@<W9E`%!R;VUI
M:F5N:71E(&]P8VEJ92!P<FEK87IA(&MA;R"Y=&\@<W4@8G)O:B!P;W)U:V$@
M;F$@<W1R86YI(&EL:2!N8>AI;B!S;W)T:7)A;FIA+@!0<F]M:6IE;FET92!P
M87)A;65T<F4@;6%I;"!S97)V97)A(&D@9F]L9&5R80!0<F]M:6IE;FET92!I
M;64@:2!A9')E<W4@:V]J92!V:61E(&1R=6=I(&MA9&$@Z&ET86IU(&D@;V1G
M;W9A<F%J=2!N82!V8;EE('!O<G5K92X`4')O;6EJ96YI=&4@:6UE+"!A9')E
M<W4@:2!P;W1P:7,@:V]J92#F92!D<G5G:2!V:61J971I(&MA9&$@Z&ET86IU
M(&D@;V1G;W9A<F%J=2!N82!V8;D@92UM86EL+@!"<F]J('!R:6MA>F%N:6@@
M>FYA:V]V83H`4')O=FIE<FD@;F]V=2!P;[ET=2!U(&9O;&1E<FEM80!)>F%B
M97)I=&4@;6%I;"!S97)V97(@<V$@:V]J96<@OF5L:71E('!R975Z971I('!O
MN71U.@!0<F]V:F5R:2!P<F%V;W!I<R!P<FEJ92!S;&%N:F$@<&]R=6ME/P#(
M:6QE`$MI;F$`2VEN97-K:2!P;VIE9&YO<W1A=FQJ96YI("A'0C(S,3(I`$MI
M;F5S:VD@=')A9&EC:6]N86QN:2`H0FEG-2D`27IA8F5R:71E(&%K8VEJ=3H`
M27IA8F5R:71E(&UA:6P@<V5R=F5R.@!)>F%B97)I=&4@N6EF<G4`27IA8F5R
M:71E(&MO<FES;FGH:V\@:6UE`$EZ86)E<FET92!A:V-I:G4Z`$EZ86)E<FET
M92!K86MO('-E('!R:6MA>G5J92!D871U;3H`27IA8F5R:71E('9R<W1U('-T
M:6QA("AZ82!N=6UE<FES86YE(&QI<W1E*0!)>F%B97)I=&4@(&EM96YI:R!K
M;VII(.9E('-E(&MO<FES=&ET:2!P<FEL:6MO;2!D;V1A=F%N:F$@;F]V:6@@
M861R97-A+@!)>F%B97)I(')E9&]S;&EJ960@>F$@<')E=')A9W4@:6UE;FEK
M82!Z82!P<F^Y:7)I=F%N:F4@861R97-A+@!5<VMRN6YJ92!O<W1R=F\`3^AI
M<W1I`$_H:7-T:2!-4T]F9FEC92!T86=O=F4`2VQI:VYI=&4@;F$@)7,@9&$@
M9&]W;FQO861U:F5T92!S;&EK=2X`2VQI:V%N:F5M(&YA(&%D<F5S=2!P<F%V
M:2!S92!N;W9A('!O<G5K82!Z82!P;[EI;&IA;V-A`$ML:6MA;FIE;2!N82!A
M9')E<W4@;W1V87)A('-E('!O<G5K82!Z82#H:71A;FIE`%IA='9O<FD`6F%T
M=F]R:2!O=F%J('!R;WIO<@!:871V;W)E;B!F;VQD97(`4VMU<&D@<W9E`%-K
M=7!I('-V92!F;VQD97)E`%-K=7!I(&9O;&1E<@!)>F)O<B!B;VIE`$MO;6]R
M:0!+;VUP86YI:F$`3F%P:;EI(&YO=G4@<&]R=6MU`%!IN6D@<&]R=6ME('4@
M>F%S96)N;VT@<')O>F]R=3\`2V]R:7-T:2!(5$U,(&]P8VEJ92!Z82!P:7-A
M;F4@<&]R=6MA("AA:V\@<')E9VQE9&YI:R!P;V1ROF%V82!T=2!M;V=UYFYO
M<W0I/P!0;V1E<VET92!P<FEK87H@<&]R=6MA+@!0;V1E<VET92!O<&-I:F4@
M<')E9VQE9&$@<&]R=6ME+@!0;V1E<VET92!01U`@<&]D<KEK=2!Z82`E<RX`
M4&]D97-I=&4@4R]-24U%('!O9'*Y:W4@>F$@)7,N`%!O9&5S:71E(&MA9&$@
MYF4@<V4@=G*Y:71I('!R;W9J97)A('!R:7-T:6=L92!P;[ET92X`4')E='9O
M<FD@=&5K<W1U86QN92!S;6%J;&EJ92!U(&=R869IZ&ME/P!+;W!I<F%J`$MO
M<&ER86H@:7IA8G)A;F\`2V]P:7)A:B!U(&9O;&1E<@!)<W!R879I`$ES<')A
M=FQJ96X@=&5K<W0`3F4@;6]G=2!N87!R879I=&D@5D93(&)A8VME;F0Z("5S
M`$YE(&UO9W4@;V)R:7-A=&D@<&]R=6ME(&]D("5S+B!0;W)U:V$@<V5R=F5R
M83H@)7,`2W)E:7)A:B!F;VQD97(`3F%P<F%V:2!L:6YK`$YA<')A=FD@;F]V
M:2!F;VQD97(@>F$@;F%C<G1E`$YA<')A=FD@;F]V:0!+<F5I<F%J(&YO=FD@
M9F]L9&5R('IA('!O<VQA;G4@<&^Y='4`2W)E:7)A:B!N;W9I(&9O;&1E<B!Z
M82!K;W)P=0!5<F5D:71E('!R879I;&$@9FEL=')I<F%N:F$@<&]M;^9U(&MO
M:FEH(&%U=&]M871S:VD@;W)G86YI>G5J971E('!R:7-T:6=L92!P;W)U:V4L
M('-O<G1I<F%T92!I:"!U(&9O;&1E<F4@:2!B<FFY971E(&YEOF5L:F5N=2!P
M;[ET=2X`4')A=FQJ96YJ92!P;V0M9F]L9&5R80!4<F5N=71N:2!P<FES='5P
M("5S`%!O9&5S:71E(&1O8F%V;&IA;FIE('!ON71E('-A(&4M;6%I;"!R8>AU
M;F$@;F$@9')U9VEM('-E<G9E<FEM80!/9')E9&ET92!K86MO(+EA;&IE=&4@
M<&^Y='4N`%!O9&5S:71E('IA9&%T:V4@:V]J:2#F92!S92!I>G9RN6%V871I
M(&YA:V]N('-V86ME('!R:6IA=F4@;F$@)7,N`$1N979N;P!$871?=6T`1&%T
M=6T`1&5C96UB87(`4W1A;F1A<F1N82!B;VIA`$1E9F%U;'0@:61E;G1I=&5T
M`$1E9F%U;'0@:W)I=&5R:6H@>F$@<V]R=&ER86YJ93H`1&5F875L="!P<F%V
M86,@<V]R=&ER86YJ83H`1&5F:6YI8VEJ90!/8G)IN6D`3V)R:;EI('1R96YU
M=&YE(&ML:G7H979E`$]B<FFY:2!F;VQD97)E`$]B<FFY:2!V:7)T=6%L;FD@
M9F]L9&5R`$)R:7-A;FIE(&D@:7IB86-I=F%N:F4@<&]R=6MA`$]B<FFY:2!S
M=&%R92!L:6YK;W9A;F4@<')I;&]G92!P;^AE=&MO;2!S=F%K;V<@;6IE<V5C
M83\`3V)R:;EI('-T87)E(&9O;&1E<F4@<&]S;&%N92!P;[ET92!P;V-E=&MO
M;2!S=F%K;V<@;6IE<V5C83\`3V)R:;EI(&EZ86)R86YI(&ED96YT:71E=`!/
M8G)I<V%N80!/8G)I<V%N92!P;W)U:V4`0G)I<V%N:F4@:2!P<F5B86-I=F%N
M:F4@<&]R=6MA`$]P861A:G7F:0!/<&FY:71E('!R;V)L96UE('4@<F%D=2!S
M82!W96)M86EL;VT`6F%T86UN:2!P;W1P:7-E/P!$:7)E:W1O<FEJ`%!R:6MA
MOFD`4')I:V&^:2!V<FEJ96UE('4@,C0M<V%T;F]M(&9O<FUA='4_`$]P8VEJ
M92!P<FEK87IA`%!R:6MAOFD@<&]T=G)D=2!N86MO;B!S;&%N:F$@<&]R=6ME
M/P!0<FEK8;YI('!R;V=N;WIU("A4048I`%!R:6MAOFD@=2!T:6IE;'4@<&]R
M=6ME`%!R:6MAOFD@<&]P+75P('!O<G5K=2!P<FES=&EG;&4@<&^Y=&4_`$YE
M('!R;W9J97)A=F%J(&YO=G4@<&^Y='4@=2!F;VQD97)I;6$`3F5M;VH@9V5N
M97)I<V%T:2!L:6YK('4@:V]L;VYI(%!ON6EL:F%O8V$`1&]W;FQO860`1&]W
M;FQO860@)7,`1&]W;FQO860@)7,@=2`N>FEP(&9O<FUA='4`1&]W;FQO860@
M<W9I:"!P<FEL;V=A("AU("YZ:7`@9F]R;6%T=2D`1&]W;FQO861U:B!F;VQD
M97)E`$1O=VYL;V%D=6H@9F]L9&5R92!;+GII<"!F;W)M871=`$1O=VYL;V%D
M=6H@=2`N>FEP(&9O<FUA='4`3F%C<G0`1F]L9&5R('IA(&YA8W)T90!&;VQD
M97(@;F5Z879RN65N92!P;W)U:V4Z`$EZ;6EJ96YI(&-R;G4@;&ES='4`27IM
M:6IE;FD@9FEL=&5R90!)>FUI:F5N:2!D;WIV;VQU`$EZ;6EJ96YI(&1O>G9O
M;&4`27IM:6IE;FD@9&]Z=F]L92!Z82`E<P!)>FUI:F5N:2!B:6IE;'4@;&ES
M='4`27IM:6IE;FET92!O<&-I:F4@>F$Z`$EZ;6IE;FET92!V8;EU(&-R;G4@
M;&ES='4`27IM:F5N:2!F:6QT97(@<')A=FEL80!)>FUI:F5N:71E('!O<W1A
M=FME('IA('!R:7-T=7!A;FIE(&4M;6%I;"!R8>AU;FEM82!N82!D<G5G:6T@
M<V5R=F5R:6UA+@!)>FUJ96YI=&4@=F&Y=2!B:6IE;'4@;&ES='4`16UA:6P@
M861R97-A`%-M86IL:6II`$ES<')A>FYI(&9O;&1E<F4`27-P<F%Z;FD@9F]L
M9&5R($MO<G!A`$ES<')A>FYI(%]K;W)P=0!5:VQJ=>AI(%!'4"!F=6YK8VEO
M;F%L;F]S=#\`56ML:G7H:2!3+TU)344@9G5N:V-I;VYA;&YO<W0_`%5K;&IU
MZ&D@<V&^971K92!P;W)U:V$@=2!L:7-T:3\`06MT:79I<F%J(&MO;G1E:W-T
M(&UE;FD@;F$@9&5S;F]M(&ML:6MU/P!/<&-I:F4@N5]I9G)O=F%N:F$`2W)A
M:@!+<F%J('!R;W-L:6IE\&5N92!P;W)U:V4`2W)A:B!P;W)U:V4`2W)A:B!P
M;W)U:V4@;V0@)7,`56YE<VET92!F<F%Z=0!5;F5S:71E(&EM92!Z82!V8;D@
M;F]V:2!F;VQD97(@>F$@;F%C<G1E`%5N97-I=&4@:6UE('IA('9AN2!N;W9I
M(&9O;&1E<B!Z82!P;W-L86YU('!ON71U`%5N97-I=&4@:6UE('IA('9AN2!N
M;W9I(&9O;&1E<B!Z82!S;67F90`B)7,B(&IE('5S<&IEN6YO(&1O9&%N('4@
M861R97-A<@!%:W9A=&]R:6IA;&YA($=V:6YE:F$`17)I=')E:F$`1W)EN6MA
M`$=R9;EK82!P<FD@<VQA;FIU(&]D9V]V;W)A.B`E<P!%<W1O;FEJ80!%=&EO
M<&EJ80!%=&YIZ&MI`$5V<F]P80!3=F%K:6@@,34@;6EN=71A`%-V86MI:"`R
M(&UI;G5T90!3=F%K:6@@,S`@<V5K=6YD:0!3=F%K:6@@-2!M:6YU=&$`2V]D
M('-V86ME('!R:6IA=F4`4W9A:VEH('!O;&$@<V%T80!3=F%K:2!M:6YU=`!6
M<FEJ961N;W-T:2!P<FEM:F5R:3H`4')ON6ER:2!S=F4`4')ON6ER:2!S=F4@
M9F]L9&5R90!0<F^Y:7)I(&9O;&1E<@!0<F^Y:7)I(&EM96YA`$%U=&]M871S
M:VD@<F&Y:7)I(&EM96YA('4@<')O>F]R=2!Z82!S87-T879L:F%N:F4@<&]R
M=6ME/P!!=71O;6%T<VMI(')AN6ER:2!C:6IE;&\@<W1A8FQO('4@<')I:V%Z
M=2!F;VQD97)A/P!0<F^Y:7)U:F5M`$9E8G)U87(`1&]B879I('!ON71U`%-K
M:6YI('!O<G5K92!U('IA<V5B;F]M('!R;WIO<G4_`$9I7VQT97)I`$1A=&]T
M96MA`$]P8VEJ92!F:6QT97)A`%!R879I;&$@9FEL=&5R80!&:6QT<FER86H@
M<&]R=6ME(&YE<&^^96QJ;F]G('-A9'*^86IA/P!0;V1RN6MA('IA(&9I;'1E
M<F4@:F4@:7-K;&IUZ&5N82!N82!O=F]M('-I<W1E;74N`$9I;'1E<FD`1FEL
M=&5R:2!.25-5(&%K=&EV;FD`1FEL=&5R:3H@)7,@<W1R86YI8V$@>F$@=7)E
M\&EV86YJ90!4<F&^:0!0<G9A('-T<F%N82!S86YD=>AE=&$`4')V82!S=')A
M;F$`4%]R;W-L:6IE9&D`4')E9VQE9"!F;VQD97)A`%-AOF5T86L@9F]L9&5R
M80!&;W)M870@9&%T=6UA('!O<G5K82!U('-A;F1UZ&5T=2!Z82!P;W)U:V4@
M<')I<W1I9VQE(&1A;F%S`%!R;W-L:6IE9&D`4')O<VQI:F5D:3H`4')O<VQI
M:F5D:F5N82!P;W)U:V$@;V0@)7,`3V1G;W9O<B!S;&]B;V1A;B]Z875Z970`
M7T]D`$]D`$%D<F5S82!P<FEM86]C80!$971A;&IA;B!O<&ES`$9W9#H`3W"Y
M=&4@;W!C:6IE`$ED:2!N82!P;W)U:W4`1V]O9VQE('!R971R86=A`$1A:B!P
M<FES='5P`$=RZ&MI("A)4T\M.#@U.2TW*0!:86=L879L:F4`2&5B<F5J<VMI
M("A)4T\M.#@U.2TX+4DI`%!O;6_F`%-K<FEV96YO`%-K<FEV96YO('4@<')I
M:V%Z=2!T;VMA('1E;64`4V%K<FEJ(&]B<FES86YE`%-A:W)I:B!N975P:7-A
M;F4`5FES;VL@<')I;W)I=&5T`%!OZ%]E=&%K`%!OZ&5T86L`061R97-A("AK
M=>9I*0!496QE9F]N("AK=>9I*0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`
M2V%K;R"^96QI=&4@<')I:V%Z871I('!R:6QO9V4_`$MO:FD@<')E9FEK<R!K
M;W)I<W1I=&D@>F$@8VET:7)A;F4@;&EN:6IE('4@;V1G;W9O<G4`24U!4`!)
M34%0("AA=71O;6%T<VMI('!R97!O>FYA:B!P<F]T;VMO;"D`24U!4"!O=F5R
M(%-33`!)34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92D`
M24U!4"!P<F5K;R!34TP@*'-E;&8M<VEG;F5D*0!)34%0+"!B97H@5$Q3`$E-
M05`O4$]0,R!M86EL('-E<G9E<FD`4T%.1%7(10!)4"!A9')E<V$`25`@861R
M97-A(&YI:F4@9&]S='5P;F$N`$E0(&%D<F5S82!N:6IE(&1O>G9O;&IE;F$@
M=6YU=&%R($-)1%(@8FQO:V$N`$ES;&%N9`!386UO(&EK;VYE`$EK;VYE('IA
M("5S`$EK;VYE('-A('1E:W-T;VT`26UE(&ED96YT:71E=&$Z`$EG;F]R:;EI
M`$EG;F]R:;EI('-V90!);7!O<G1U:B!P;W)U:V4`5F&^;F$`5F&^;F4@<&]R
M=6ME`%-A;F1UZ&4`56ML:G7H:2!S8;YE=&%K('4@>F%G;&%V;&IU(&]D9V]V
M;W)A/P!0<FEL;[YI(&]R:6=I;F%L;G4@<&]R=6MU('4@;V1G;W9O<G4_`$1O
M9&%V86YJ92!P;W)U:V$`26YV97)T=6H`2F%N=6%R`$IA<&%N<VMI("A)4T\M
M,C`R,BU*4"D`2G5L:0!*=6YI`%)A7W-P;W)E9`!*97II:P!,86\@3F%R;V1N
M82!$96UO:W)A='-K82!297!U8FQI:V$`6F%D;FIA('-T<F%N82!S86YD=>AE
M=&$`6F%D;FIA('-T<F%N80!:861N:F$@:7IM:F5N83H`6F%D;FIA('!R:6IA
M=F$Z("5S`%IA9&YJ82!P<FEJ879A.B`E<R!S82!A9')E<V4Z("5S`%IA9&YJ
M82!P<FEJ879A.B!.:6MA9`!,871V:6IA`%IA:V]N`%)A<W!O<F5D`$QI8F%N
M`$QE<V]T;P!,:5]N:W5J('!R:6QO9V4`3&EB97)I:F$`3&EB:6IS:V$@07)A
M<'-K82!$OF%M86AI<FEJ80!,:6AT96ZY=&%J;@!,:6YK;W9I`$QI<W1A;FIE
M("T@:V]R:7-N:6L@;6^^92!V:61J971I(&9O;&1E<@!)<W!IN6D@<W9E(&MO
M;G1A:W1E('!R:6QI:V]M(&]T=F%R86YJ82!E:W)A;F$@:V]N=&%K871A/R`H
M06MO(&IE(&]V82!O<&-I:F$@:7-K;&IUZ&5N82P@=FED:F7F/W1E('-A;6\@
M:V]N=&%K=&4@:V]J92!T<F&^:71E*0!3<&ES86L@<')I;&]G82!U('IA9VQA
M=FQJ=2!P;W)U:V4`3&ET=F$`5>AI=&%V86TN+BX`3&]K86QN;R!S86YD=>AE
M.@!,;VMA;&YO('9R:6IE;64Z(`!,;VMA;&YE('!O<W1A=FME(&D@=G)I:F5M
M90!+<F5N:0!0<FEJ879I('-E(&YA("5S`$EZ;&%Z`$QO9VEN('IA9&%C:0!0
M<FEJ879A(&YI:F4@=7-P:F5L82X@3F%J=F5R;W9A=&YI:F4@:F4@<&]G<F6Y
M;F\@=6YE<V5N;R!K;W)I<VYIZ&MO(&EM92!I;&D@N6EF<F$N`%!R:6IA=F$@
M;FEJ92!U<W!J96QA+@!$=6=I('1E:W-T`$YI>F%K('!R:6]R:71E=`!,=6MS
M96UB=7)G`%!ON71A`%!R96=L960@<&^Y=&4`4V%N9'7H90!/<&-I:F4@<')I
M:V%Z82!S86YD=>AE=&$@:2!F;VQD97)A`$YA<')A=FET92!K871E9V]R:6IE
M('-T879K:2!I('IA('-V86MU(&]D(&YJ:6@@;V1R961I=&4@;V1G;W9A<F%J
M=>9U(&)O:G4N`$UA<G0`3WIN8>AI('-V92!P;W)U:V4@:V%O('!R;^AI=&%N
M90!/>FYAZ&D@<W9E('!O<G5K92!K86\@;F5P<F_H:71A;F4`3V)I;&IEOFD@
M:V%O.@!/>FYAZ&D@<F%Z;&GH:71E(&YI=F]E(&-I=&ER86YJ82!R87IL:>AI
M=&EM(&)O:F%M83\`3V)O:FD@<&]S96)N92!O>FYA:V4_`$]Z;F'H879A;FIE
M(&MA;R!P<F_H:71A;F\O;F5P<F_H:71A;F\`3WIN8>AA=F%N:F4@9')U9VEM
M(&]Z;F%K86UA("AN<'(N('9AOFYO(&EL:2!O9&=O=F]R96YO*0!-87*Y86QO
M=F$@;W-T<G9A`$UA<G1I;FEK`%IA:'1I:F5V86H@<W9E('5S;&]V90!":6QO
M(&MO:FD@=7-L;W8`3V1G;W9A<F%J=>9A('!O;&IA`$UA=7)I=&%N:6IA`$UA
M=7)I8VEJ=7,`36%K<VEM86QN82!V96QIZ&EN82!P<FEL;V=A`$UA:@!/9&=O
M=F]R('IA('-A<W1A;F%K`,AL86YO=FD`5G)S=&$@;65N:6IA.@!3<&]J:2!P
M;VQJ80!0;W)U:V$`3F]V82!P;W)U:V$`1&%T=6T@<&]R=6ME`$]P8VEJ92!P
M;W)U:V$`4')E=')AOFEV86YJ92!P;W)U:V4`5F5L:>AI;F$@<&]R=6ME`$EZ
M=F]R;FD@:V]D('!O<G5K90!0<F5G;&5D879A;FIE('!O<G5K90!/>FYA:V4@
M<&]R=6MA`$9O;&1E<FD@<&]R=6MA`%5S;&]V:2!P<F5T<F%G90!0;W)U:V$@
M=7-P:F6Y;F\@=7-M:F5R96YA`%!O<G5K82!U<W!J9;EN;R!P;W-L86YA+"!A
M;&D@;FEJ92!S;FEM;&IE;F$@=2`E<P!0;W)U:V$@=7-P:F6Y;F\@<&]S;&%N
M82X`4&]R=6MA('!O('-T<F%N:2!K;V0@<')I:V%Z82!S86YD=>AE=&$N`%!O
M<G5K92!U`$UI;64@=&EP`$UJ97-EZ&YO`%!R96)A8VD`4F%S<&]R960@;6]G
M('!O<G1A;&$`26UE`$UR9;YA`$YI:V%D80!.:6MA9"!N92!P86UT:2!P<FEL
M;V=E`$YO=F\`3F]V82!+86QE9&]N:6IA`$YO=F$@:V%T96=O<FEJ80!.;W9I
M(&9O;&1E<@!.;W9A('!ON71A`$YO=FD@;6IE<V5C`$YO=F\@:V]R:7-N:>AK
M;R!I;64@*&YI:F4@;V)A=F5Z;F\I`$YO=FD@6F5L86YD`$YO=F4@<&]R=6ME
M`$YO=FD@<')O>F]R("A?<')A>F%N*0!.;W9O<W1I`$YE=W,M9W)U<&4`4VQJ
M961EYF$@<&]R=6MA`%-L:F5D9>9A('-T<F%N80!3;&IE9&7F92!O<&-I:F4`
M3FEK87)A9W9A`$YI9V5R`$YI9V5R:6IA`$YOY@!.:75E`$YE`$)E>B"Y:69R
M;W9A;FIA`$YE;6$@<&]R=6MA`$YI:F5D86X@9F]L9&5R(&YI:F4@<W!E8VEF
M:6-I<F%N`%!O<G5K82!N96UA('1E:W-T80!.:6IE9&YA(&=R86UA=&EC:V$@
M9W)EN6MA`$YE;6$@9W)EN6ME`$YI:F4@;F%V961E;B!K;W)I<VYI:RX`3FEJ
M92!P;W-L86YO(&MO<FES;FGH:V\@:6UE(&DO:6QI(+EI9G)A+@!.:6IE9&YA
M`$YO<F1I:G-K:2`H25-/+3@X-3DM,3`I`$YE;V)R:7-A;F$`3FEJ92!N86-R
M=`!.979AOFYA`$YI:F4@;&GH;F$`3F5O8G)I<V%N92!P;W)U:V4`3F5V8;YN
M92!P;W)U:V4`3F]V96UB87(`0G)O:B!M:F5S96-I(&MO;&EK;R!T<F5B82#H
M=79A=&D@<W1A<F4@;&EN:V]V86YE('!R:6QO9V4@=2!S;'7H86IU(&UJ97-E
MZ&YO9R!B<FES86YJ82X`0G)O:B!S=&%R:6@@9F]L9&5R82!P;W-L86YE('!O
MN71E(&MO:FD@8V4@<V4@<V%C=79A=&D@86MO('-E(&)R:;EU(&UJ97-E8VYO
M+@!/:W1O8F%R`%-T87)E('!O<G5K90!"<FFY96T@<W1A<F4@9F]L9&5R92!P
M;W-L86YE('!ON71E+@!/='9O<F5N:2!F;VQD97(`3W!E<F%T:79N:2!S:7-T
M96T`3W!C:6IE`$]P8VEJ92!Z82`E<P!/<W1A;&\`3W-T86QE(&EN9F]R;6%C
M:6IE`$]S=&%L:2!E+6UA:6P@<F'H=6YI`$]S=&%L92!O<&-I:F4`4$=0`%!'
M4""Y:69R;W9A;FIE('!O<G5K90!01U`@9W)EN6MA.@!01U`@9W)EN6MA.B!0
M;W1R96)N82!J92!F<F%Z82!Z82!L:>AN:2!P<FEV871N:2!K;&IUZ"X`4$=0
M(&]P8VEJ90!01U`@=6YO<R!F<F%Z90!0;V1RN6MA('IA(%!'4"!L:>AN92!K
M;&IUZ&5V92!Z86AT:6IE=F$@<VEG=7)N=2!W96(@:V]N96MC:6IU+@!01U`@
M=&5K<W0@:F%V;F]G(&ML:G7H80!01U`@:F%V;FD@:VQJ=>@@>F$@(B5S("@E
M<RDB(&IE('5S<&IEN6YO(&1O9&%N+@!01U`@:F%V;FD@:VQJ=>@@>F$@(B5S
M(B!J92!U<W!J9;EN;R!O8G)I<V%N+@!01U`@:F%V;FD@<')I=FIE<V%K`%!'
M4"!P;W1P:7-I=F%N:F4@<&]R=6MA`%!'4"!P;W1P:;EI+[EI9G)U:B!P;W)U
M:W4`4$=0('!R:79A=&YI(&ML:G7H(&IE('5S<&IEN6YO(&1O9&%N+@!01U`@
M:F%V;FD@:VQJ=>@@:F4@=7-P:F6Y;F\@9&]D86XN`%!'4"!P;V1RN6MA(&IE
M(&ES:VQJ=>AE;F$@;F$@;W9O;2!S:7-T96UU+@!01U`@<&]D<KEK82!T<F5N
M=71N;R!N:6IE(&%K=&EV;F$@=&%K;R!D82!S92!D:6=I=&%L;FD@<&]T<&ES
M(&YE(&UOOF4@<')O=FIE<FET:2X`4$=0('!O9'*Y:V$@=')E;G5T;F\@;FEJ
M92!A:W1I=FYA('1A:V\@9&$@<V4@<&]R=6MA(&YE(&UOOF4@9&6Y:69R;W9A
M=&DN`%!/4#,`4$]0,R`H875T;VUA='-K:2!P<F5P;WIN86H@<')O=&]K;VQE
M*0!03U`S(&]V97(@4U-,`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E
M<G1I9FEC871E*0!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"D`4$]0,RP@
M8F5Z(%1,4P!3=')A;FEC82`E9"!O9"`E9`!3=')A;FEC82!S82!P<G9O;2!N
M97!R;^AI=&%N;VT@<&]R=6MO;0!3=')A;FEC82!S82!Z861N:F]M(&YE<')O
MZ&ET86YO;2!P;W)U:V]M`$1I;R`H9&EJ96QO=FDI`*EI9G)A`$QJ=61I`%!R
M;V-E;F%T`$EZ=G*Y:2!S97)V:7-N92!O<&5R86-I:F4`27IV<KEI('-E<G9I
M<VYE(&]P97)A8VEJ92!P<FEJ92!L;V=I<F%N:F$_`$1O>G9O;&4`061M:6YI
M<W1R86-I:F$@9&]Z=F]L82`H<')I=FEL96=I:F$I`$1O>G9O;&4@>F$@;W9O
M9R!K;W)I<VYI:V$@<V4@;F4@;6]G=2!M:6IE;FIA=&DN`$QIZ&YA`$]S;V)N
M92],:>AN92!I;F9O<FUA8VEJ90!$;V1A:B!M;VH@<&]T<&ES('!R:6IE(&]D
M9V]V;W)A(&D@<')O<VQI:F7P96YI:"!P;W)U:V$_`$EZ=F]R;FD@:V]D('!O
M<G5K90!-;VQI;6\@9&%J=&4@:W)A=&%K(&]P:7,@=F&Y96<@<')O8FQE;6$@
M<V$@=V5B;6%I;&]M+@!-;VQI;2!N879E9&ET92!V8;EU(+EI9G)U+@!-;VQI
M;2!N879E9&ET92!V8;EE(&MO<FES;FGH:V\@:6UE+@!-;VQI;2!T92!P;W!R
M879I(&1V;W-M:7-L96YE(&]D;F]S;F\@:6YV86QI9&YE(&%D<F5S92X`36]L
M:6T@:7IA8F5R:71E(&YE:VD@9F]L9&5R('!R:6IE(&EZ=G*Y879A;FIA(&%K
M8VEJ82X`36]L:6T@:7IA8F5R:71E(&%K8VEJ=2!N82!M96YI:G4@:7-P;V0N
M`$EZ86)E<FET92!I;&D@<')O;6EJ96YI=&4@=2!P;VQJ=2!D97-N;SH`4VQA
M;FIE('4@;W9A:B!F;VQD97(@*&YI:F4@<')I;G7P96YO(&]D('-T<F%N92!)
M34%082D`4&]W97)E9"!B>2!(;W)D90!)<W!R960@<&]T<&ES82!D;V1A:B!C
M<G1I8V4@*"<M+2`G*3\`4')E=&AO9&YA('!O<G5K80!0<F5T:&]D;F$@<W1R
M86YA`%!R971H;V1N92!O<&-I:F4`3V2Y=&%M<&%J`%!R:6]R:71E=`"I:69R
M82!P<FEV871N;V<@:VQJ=>AA`%!R;V)L96T_`$]P:7,@<')O8FQE;6$`4&ET
M86H@<')I;&EK;VT@<VQA;FIA('!R:6QO9V$[('!O9')A>G5M:6IE=F%N:2!O
M9&=O=F]R(&IE($Y%`%!I=&%J('!R:6QI:V]M('-L86YJ82!P<FEL;V=A.R!P
M;V1R87IU;6EJ979A;FD@;V1G;W9O<B!J92!$00!0<F]T;VMO;#H`7TEZ8F%C
M:2!O8G)I<V%N90!)>F)A8VD@;V)R:7-A;F4`27IB86-I(&]B<FES86YE('!O
M<G5K90!+;VQI:V\@Z&5S=&\@8G)I<V%T:2!P;W)U:V4@:7H@:V]R<&4Z`$]B
M<FFY:2!P;W)U:V4@=2!F;VQD97)U(&MO<G!A('-T87)I:F4@;V0@;W9O9R!B
M<F]J82!D86YA+@!)<W!R87IN:2!S=&%R92!P;W)U:V4@=2!D:7)E:W1O<FEJ
M=2!+;W)P83\`4VQO8F]D86X@<')O<W1O<CH@)2XR9DU"("\@)2XR9DU"("`H
M)2XR9B4E*0!3;&]B;V1A;B!P<F]S=&]R.B`E+C)F34(@+R!.14]'4D%.2<A%
M3D\`4VQO8F]D86X@<')O<W1O<CH@3D5/1U)!3DG(14Y/`$-I=&ER86T@)68Z
M`%1?<F&^:2!P;W1V<F1U('!R:6IE;6$`R&ET86YJ92!P;W)U:V$`4')I;6QJ
M96YA(&YA`%!R:6UL:F5N82!N86MO;@!0<FEM;&IE;F$@<')I:F4`57-M:F5R
M7VD`57-M:F5R:0!5<VUJ97)I('!O<G5K=0!5<VUJ97)I(&]V=2!P;W)U:W4`
M57-M:F5R96YJ92!N:6IE('5S<&IE;&\N`$&^=7)I<F%J`$&^=7)I<F%J(&1I
M;F%M:>AK92!E;&5M96YT92!M96YI:F$Z`$&^=7)I<F%J('!R:6MA>B!F;VQD
M97)A.@!!OG5R:7)A:B!P;^AE=&YU('-T<F%N:6-U.@!!OG5R:7)A:B!P<FEK
M87H`6F%P86UT:2!Z861N:FD@<')I:V%Z`%5D86QJ96YO('-A;F1UZ&4Z`%5D
M86QJ96YI('-E<G9E<FD`561A;&IE;FD@55),("AH='1P.B\O=W=W+F5X86UP
M;&4N8V]M+VAO<F1E*3H`4')O;6IE;FD@:6UE(&9O;&1E<F$`4')O;6IE;FD@
M:6UE(&9O;&1E<F$@<&]S;&%N92!P;[ET92!P;^AE=&MO;2!S=F%K;V<@;6IE
M<V5C83\`4')O;6IE;F$@:6UE;F$@;FEJ92!U<W!J96QA("(E<R(@=2`B)7,B
M+B!/=F\@:F4@<&]R=6MA('-E<G9E<F$`3V1G;W9O7W)I(&YA(&QI<W1U`%IA
M;6IE;FD@<V$Z`$]D9V]V;W)I`$]D9V]V;W(@:F4@<&]S;&%N+@!/9&=O=F]R
M:2!S=FEM80!/9&=O=F]R:2!S=FEM83H`3V1G;W9O<FD@;F$@;&ES='4`3V1G
M;W9O<FD@;F$@;&ES='4Z`$]D9V]V;W)I(%]S=FEM80!/9&=O=F]R:2!P;W)U
M:V]M($YI:F4@<&]D<KYA;F\`3V1G;W9O<FD@<&]R=6MO;2!S;&]B;V1A;B]Z
M875Z970@>F$@;F%R961N82`R(&UJ97-E8V$N`$]D9V]V;W)I('1R8;YE;F]M
M('-L;V)O9&%N+WIA=7IE="!I;F9O<FUA8VEJ;VTN`$]D9V]V;W)I+6YA`$]D
M9V]V;W)I+4YA.B``3V1G;W9O<FDZ`%!R:6IA=FD@:V%O(&YE+7-P86T`4')I
M:F%V:2!K86\@<W!A;0!4<F&^:2!?<&]T=G)D=2#H:71A;FIA`$1A('1R8;YI
M;2!P;W1V<F1U('!R:6IE;6$_`$1A('1R8;YI;2!P;W1V<F1U(.AI=&%N:F$@
M<&]R=6ME/P!4<F&^96YA('!O<G5K82!N:6IE('!R;VYA\&5N82X`4&]N:;ET
M:0!.87-T879I`$YA<W1A=FET92!V8;EU('-E<VEJ=0!.87IA9"!N82!686YJ
M<VME(')AZ'5N90!.87IA9"!N82!O<&-I:F4`5G)A=&D@<V4@;F$@<')I:V%Z
M('-A;F1UZ&5T82!N86MO;B!B<FES86YJ82P@<')E8F%C:79A;FIA+"!I;&D@
M:V]P:7)A;FIA('!O<G5K93\`4F5U;FEO;@!6<F%T:2!S=&%R=2!K;VYF:6=U
M<F%C:6IU`$]P8VEJ92!E9&ET;W)A('1E:W-T80!3+TU)344`4R]-24U%(+EI
M9G)U:B!P;W)U:W4`4R]-24U%(&]P8VEJ90!47V5M80!38>AU7W9A:B!K;W!I
M:G4@=2``7U-AZ'5V86H@:V%O`%-AZ'5V86H@:V%O(&YA8W)T`%-N:6UI(&]P
M8VEJ90!38>AU=F%J(&MA;R!?;F%C<G0`4V'H=79A:B!K86\`R'5V86H@;F%C
M<G1E(&MA;R!N97!R;^AI=&%N93\`075T;VUA='-K:2!P86UT:2!P<FEM871E
M;&IE('!O<G5K92!U(&=L879N;VT@861R97-A<G4_`%IA<&%M=&D@<')E=')A
M9W4@:V%O('9I<G1U86QN:2!F;VQD97(_`%-AZ'5V86H@<&]S;&%N=2!P;[ET
M=3\`3FEJ92!U<W!J96QO('-P8;EA=F%N:F4@;F%C<G1A+B!/=F\@:F4@<&]R
M=6MA('-E<G9E<F$Z("5S`%1R8;YI`%1R8;YI("5S`%)E>G5L=&%T:2!P<F5T
M<F%G90!0<F_H:71A;F$`3V1A8F5R:0!)>F%B97)I=&4@:V]R:7-N:>AK:2!R
M8>AU;@!)>F%B97)I=&4@<&]L:F4`27IA8F5R:71E('-E<G9E<@!)>F%B97)I
M=&4@:7IV;W)E(&EM96YI:V$@>F$@9&]D879A;FIE(&D@<')E=')AOFEV86YJ
M92!A9')E<V$N`$]D86)E<FD@<W9E`$EZ86)E<FET92!P;VQJ82!K;VIA('1R
M96)A('!R971R8;YI=&D@<')I;&EK;VT@<')I:V%Z82!A9')E<V$N`$EZ86)E
M<FET92!K;W)I<VYIZ&MI(')AZ'5N`$]D86)E<FD@;FEJ961A;@!)>F%B97)I
M=&4@:61E;G1I=&5T(&MO:FD@OF5L:71E('!R;VUI:F5N:71I.@!)>F%B97)I
M=&4@N65M=2!B;VIA+@!)>F%B97)I=&4@OF5L:F5N:2!J97II:SH`4&^Y86QJ
M:2!P;W)U:W4`4&^Y86QJ:2!P<FEJ879U('!R;V)L96UA`%!ON6%L:FD@4TU3
M`%-E;F5G86P`4V5N>F]R.B``1F]L9&5R('!O<VQA;F4@<&^Y=&4Z`%-E<'1E
M;6)A<@!3<F)I:F$@:2!#<FYA($=O<F$`4V5R:6IS:VD@8G)O:@!397)V97(`
M4V5R=F5R(&D@9F]L9&5R:0!)1"!S97-I:F4@:F4@:7-T96MA;RX`3V1A8F5R
M:0!0;V1E<VET92!O<&-I:F4@:V]J92!V86T@;VUO9W7F=6IU(&1A('!O;FFY
M=&ET92"Y:69R=2!A:V\@:F4@>F%B;W)A=FET92X`4&]D97-I=&4@;W!C:6IE
M('4@:V]J:6UA(.9E('-E(&1E9FEN:6YI<V%T:2!A:V-I:F4@;F%K;VX@<')E
M;6IEN71A;FIA(&D@8G)I<V%N:F$@<&]R=6MA+@!0;V1E<VD@6"U0<FEO<FET
M>2!P;VQJ92!U('IA9VQA=FQJ=2!P<FEL:6MO;2!P:7-A;FIA('!O<G5K83\`
M4&]D97-I=&4@=61A;&IE;F4@<V5R=F5R92!K;VII;6$@OF5L:71E('!R:7-T
M=7!I=&D@<'5T96T@=F&Y96<@<&]R=&%L82X`3V1A8F5R:71E(+YE;&IE;FD@
M:F5Z:6LL('9R96UE;G-K=2!Z;VYU(&D@<&]S=&%V:V4@>F$@9&%T=6TN`%!O
M9&5S:71E('-T87)T;G4@:V]M<&]N96YT=2P@N65M=2!B;VIA+"!O<W9J9;YA
M=F%N:F4@<W1R86YI8V4@:2!D<G5G92!O<&-I:F4@:V]J92!S92!T:>AU('!R
M:6MA>F$N`%!O<W1A=FME`%-E:KEE;&D`1&EJ96QJ96YJ92!F;VQD97)A`$1I
M:F5L:F5N92!F;VQD97)A('!ON71E`%)A>FUJ96YJ=6IT92!V8;EE(&4M;6%I
M;"!F;VQD97)E('-A(&1R=6=I;2!K;W)I<VYI8VEM82X`2W)A=&%K(&]P:7,`
M1&$@;&D@9&5F:6YI<V%T:2!P<FES='5P;F4@=&EP:V4@>F$@;&EN:V]V93\`
M1&$@;&D@YF4@=F5L:6MI(&MO;6%D:2!C:71I<F%N;V<@=&5K<W1A(&)I=&D@
M875T;VUA='-K:2!S86MR:79E;FD@:6QI('!R:6MA>F%N:3\@3W9O('-E(&UO
MOF4@;&%K;R!P<F]M:6IE;FET:2!K861A('IAOF5L:71E+@!$82!L:2!Z871V
M;W)I=&D@<')O>F]R('IA('!I<V%N:F4@;F]V92!P;W)U:V4@;F%K;VX@<W!A
MN6%V86YJ82!N86-R=&$_`%!R:6MAOFD`4')I:V&^:2!S=F$@<&]L:F$`4')I
M:V&^:2!O8G)I<V%N90!0<FEK8;YI('-A;6\@;F5K82!P;VQJ80!0<FEK8;YI
M(&YE<')I:F%V;&IE;F4`4')I:V&^:2!I:V]N=2!K;VIA(&]M;V=UYG5J92!B
M<FES86YJ92!P<FEL;V=A(&EZ('!O<G5K93\`4')I:V&^:2!V<FEJ96UE('IA
M9&YJ92!P<FEJ879E(&YA:V]N(&QO9VER86YJ83\`4')I:V&^:2!L96=E;F1U
M('4@<')I:V%Z=2!S86YD=>AE=&$_`%!R:6MAOFD@<V&^971K92!S86UO('IA
M(&YE<')OZ&ET86YE('!O<G5K93\`4')I:V&^:2!S8;YE=&ME('4@;V)L8>AI
MYFEM83\`4')I:V&^:2!M96YI('IA(&UA;FEP=6QA8VEJ92!T86)E;&%M83\`
M4')I:V&^:2`E<R!M96YI(&QI:F5V;S\`4')I:V&^:2!I:V]N=2!Z82!686YJ
M<VME(')AZ'5N92!U(&UE;FEJ=3\`4')I:V&^:2!I:V]N=2!F:6QT97)A('4@
M;65N:6IU/P!0<FEK87IA;F\`7U9E;&GH:6YA`%!O='!I<V%N80!696QIZ&EN
M80!0<F5S:V_H:2!S97)V:7,`4V]R=&ER86H@<&\@861R97-I('!ON6EL:F%O
M8V$`4V]R=&ER86H@<&\@=F5L:>AI;FD@<&]R=6ME`%-O<G1I<F%J('!O('1E
M;6D`5&]K('1E;64`4V]R=&ER86H@<&\@861R97-I('!R:6UA;V-A`$IUOFYO
M+65V<F]P<VMI("A)4T\M.#@U.2TS*0!&;VQD97(@>F$@<W!A;3H`4W!E8VEJ
M86QN:2!K87)A:W1E<FD`4')O=FIE<F$@<')A=F]P:7-A`%!R;W9J97)A('!R
M879O<&ES80!0<F]V:F5R82!P<F%V;W!I<V$@9V]T;W9A`$)R;VH@9W)EN6%K
M82!P;R!E:W)A;G4@<')I;&EK;VT@<')O=FIE<F4@<')A=F]P:7-A/P!5:VQO
M;FD@;F]V92!R961O=F4_`%1E7VUA`%1E;6$`4&]L:F4@=&5M90!0;[EA;&II
M`%!R:6IA=FD@<V4@;F$@1F]L9&5R*&4I`%5S<&IEN6YO`%!R:6IE9&QO>FD`
M5&5?:W-T`$AV86QA(+ET;R!K;W)I<W1I=&4@16YE<F=O9&%T82!W96)M86EL
M+@!+;VQO;F$@4&^Y:6QJ86]C82!T<F5B82!B:71I(&QI;FL@;F$Z`%!R;WIO
M<B!Z82!O<&-I:F4@<V4@>F%T=F]R:6\N($EZ;&%Z:6TN`%1R96YU=&YO(&EM
M92!F;VQD97)A("(E<R(@YF4@8FET:2!P<F]M:6IE;FIE;F\@=2`B)7,B+@!.
M:7-A;2!M;V=A;R!D;V)A=FET:2!L:7-T=2!K;W)I<VYI:V$@:V]J:2!I;6%J
M=2!P<F%V;R!P<FES='5P82!O=F]M(&9O;&1E<G4`1F]L9&5R("(E<R(@=F7F
M('!O<W1O:FD`1F]L9&5R("(E<R(@<V%D<KYI(&EL96=A;&YE(&MA<F%K=&5R
M92!U(&EM96YU+B!+86\@=&%K878@;6^^92!B:71I('!R;V)L96UA=&GH86XN
M`$9O;&1E<B`B)7,B(&IE(&MR96ER86X@86QI(&YI<W1E('!R:6IA=FQJ96YI
M(&YA(&YJ96=A+@!&;VQD97(@(B5S(B!J92!O8G)I<V%N(&%L:2!N:7-T92!O
M9&IA=FQJ96YI('-A(&ES=&]G+@!&;VQD97(@(B5S(B!N:6IE(&MR96ER86XN
M($]V;R!J92!P;W)U:V$@<V5R=F5R80!&;VQD97(@(B5S(B!N:6IE(&]B<FES
M86XN($]V;R!J92!P;W)U:V$@<V5R=F5R80!&;VQD97(@(B5S(B!J92!U<W!J
M9;EN;R!K<F5I<F%N+@!&;VQD97(@(B5S(B!J92!U<W!J9;EN;R!O8G)I<V%N
M+@!);64@9F]L9&5R82`B)7,B(&IE('5S<&IEN6YO('!R;VUJ96YJ96YO('4@
M(B5S(BX`261E;G1I=&5T("(E<R(@:F4@;V)R:7-A;BX`3F5M82!P;W)U:V$@
M=2!O=F]M(&UA:6QB;W@M=2X`3F5M82!D;W-T=7!N:6@@;W!C:6IA+@!.87-T
M86\@:F4@<')O8FQE;2!S82#H:;GF96YJ96T@)7,N($]V;R!J92!P;W)U:V$@
M<V5R=F5R80!.87-T86\@:F4@<')O8FQE;2!S82#H:;GF96YJ96T@;6%I;&)O
M>"UA+B!/=F\@:F4@<&]R=6MA('-E<G9E<F$`1&5S:6QA('-E(&=R9;EK82!T
M;VMO;2!B<FES86YJ82!P;W)U:V$@:7H@9F]L9&5R82`B)7,B+B!/=F\@:F4@
M<&]R=6MA('-E<G9E<F$`1&5S:6QA('-E(&=R9;EK82!T;VMO;2!B<FES86YJ
M82!P;W)U:V$@:7H@9F]L9&5R82`B)7,B+B!/=F\@:F4@<&]R=6MA('-E<G9E
M<F$`1&5S:6QA('-E(&=R9;EK82!T;VMO;2!P<FEK87IA(&]V;V<@9&EJ96QA
M('!O<G5K90!$97-I;&$@<V4@9W)EN6MA('1O:V]M(&UA<FMI<F%N:F$@<&]R
M=6MA('4@(B5S(BX@3W9O(&IE('!O<G5K82!S97)V97)A`$1E<VEL82!S92!G
M<F6Y:V$@=&]K;VT@<VQA;FIA('!O<G5K93H@)7,`3W9A('!O<G5K82!N92!I
M>F=L961A(&MA;R!I<W!R879N82!01U`@N6EF<F]V86YA('!O<G5K82X@1W)E
MN6MA.B``3W9A('!O<G5K82!U`%9R:6IE9&YO<W0@;W9O9R!B<F]J82!M;W)A
M(&YA:FUA;FIE(&EZ;F]S:71I(#$N`$]V82!V<FEJ961N;W-T(&UO<F$@8FET
M:2!B<F]J+@!/=F%J('!R;WIO<B!S92!S;6EJ92!P;WII=F%T:2!S86UO(&EZ
M('!R;WIO<F$@3W!C:6IE`%!R:6MA>B!P;R!T;VMU('1E;64`6F$`061R97-A
M('!ON6EL:F%O8V$`1&$@8FES=&4@:7IA8G)A;&D@=FFY92!O9"!J961N;V<@
M<&]L:F$L(&1ROFET92!T:7!K=2!#;VYT<F]L("A00RD@;V1N;W-N;R!#;VUM
M86YD("A-86,I('!R:6QI:V]M(&ML:6MA;FIA+@!&;VQD97(@>F$@<VUEYF4Z
M`$9O;&1E<B!K;W)P83H`5'5R<VMI("A)4T\M.#@U.2TY*0!.96]D9V]V;W)E
M;F$`3F5O9&=O=F]R96YE('!O<G5K90!6<F%T:2!O8G)I<V%N90!0<FEM86]C
M:2!S=2!S:W)I=F5N:0!0;VYIN71I(&EZ;6IE;F4`3F5K871E9V]R:7-A;F\`
M56YI:V]D("A55$8M."D`56IE9&EN:F5N:2!!<F%P<VMI($5M:7)A=&D`3F5P
M;WIN871O(&MO<FES;FGH:V\@:6UE(&EL:2"Y:69R82X`0F5Z:6UE;FD`3F5P
M<F_H:71A;F$`3V1J879I('-E('-A($9O;&1E<F$`2V]R:7-T:2!D969A=6QT
M('9R:6IE9&YO<W0`2V]R:7-T:2!)34%0(&9O;&1E<B!P<FEJ879U/P!+;W)I
M<W1I=&4@;W9O(&%K;R!S92!I;64ON6EF<F$@<F%Z;&EK=6IU('IA($E-4U`@
M<V5R=F5R+@!+;W)I<VYI:P!+;W)I<VYI:R`E<R!N96UA(&1O>G9O;'4@>F$@
M)7,N`$MO<FES;FGH:V4@;W!C:6IE`%)E9VES=')A8VEJ82!K;W)I<VYI:V$`
M2V]R:7-N:>AK;R!I;64`2V]R:7-N:>AK;R!I;64Z`%!R:6MA>B`E<P!6:61I
M(.AI=&%V=2!T96UU`%!R:6MA>B!I;&D@<V%N9'7H92!K;VIE(.9E('-E('!R
M:6MA>F%T:2!N86MO;B!P<FEJ879E.@!6:7)T=6%L;FD@9F]L9&5R:0!:82!V
M:7)T=6%L;FD@9F]L9&5R(&IE(&]B879E>FYA(&]Z;F%K82X`3WIN86MA('9I
M<G1U86QN;V<@9F]L9&5R80!3961M:>AN;P!$;V)R;R!D;[EL:0!$;V)R;R!D
M;[EL:2!N82`E<P!$;V)R;R!D;[EL:2P@)7,`6F%P861N:2`H25-/+3@X-3DM
M,2D`6F%P861N:2`H25-/+3@X-3DM,34I`%IA<&%D;F$@4V%H87)A`$MO:G4@
M:V]M<&]N96YT=2#F92`E<R!P<FEK87IA=&D@;F%K;VX@=6QA>F$_`%!R:6QI
M:V]M(&)R:7-A;FIA('!O<G5K82P@9&$@;&D@9&$@:6@@<')E8F%C:6T@=2!F
M;VQD97(@2V]R<&$@=6UJ97-T;R!D82!I:"!O>FYAZ&EM(&MA;R!O8G)I<V%N
M93\`4')I;&EK;VT@;W1V87)A;FIA('-A;F1UZ&GF82P@;F$@:V]J;VH@<W1R
M86YI8VD@OF5L:71E('!OZ&5T:3\`4')I;&EK;VT@<VYI;6%N:F$@<&]S;&%N
M92!P;[ET92P@=')E8F%M;R!L:2!P86UT:71I(&D@<')I;&]G93\`2V]J92!D
M;V1A=&ME(+YE;&ET92!A:W1I=FER871I('IA(&5D:71O<B!F;W)M871I<F%N
M;V<@*')I8V@I('1E:W-T82X`0FEJ96QA(&QI<W1A`*EI<FEN82`E<R!M96YI
M:F$@<V$@;&EJ979E('-T<F%N:6-E("AS='5P82!N82!S;F%G=2!K;V0@<VQJ
M961EYF4@<')I:F%V92DZ`$=O9&FY;FIE`$1A`$YE(&UOOF4@<V%D<KYA=F%T
M:2`G7"<@:V%R86MT97(@=2!T=F]M('!U;F]M(&EM96YU+@!/9&IA=FQJ:79A
M;FIE(&IE('5S<&IEN6YO(&EZ=G*Y96YO+@!-;W)A=&4@;V1A8G)A=&D@:V]R
M:7-N:>AK:2!R8>AU;B!K;VII(+YE;&ET92!B<FES871I+@!5<VUJ97)I;&D@
M<W1E(&]V=2!P;W)U:W4@;F$@)7,@+2`E)7,N`$YI<W1E('!R:6IA=FQJ96YI
M(&YA("(E<R(N($]V;R!J92!P;W)U:V$@<V5R=F5R80!.:7-T92!O9&IA=FQJ
M96YI('-A("(E<R(N($]V;R!J92!P;W)U:V$@<V5R=F5R80!5<W!J9;EN;R!S
M=&4@<')I:F%V;&IE;FD@;F$@(B5S(@!5<W!J9;EN;R!S=&4@;V1J879L:F5N
M:2!S82`B)7,B`"`E<R!S97-I:F$@:F4@:7-T96ML82X@36]L:6UO(&1A('-E
M('!O;F]V;R!P<FEJ879I=&4N`%9AN6$@92UM86EL(&%D<F5S80!68;EA($9R
M;VTZ(&%D<F5S83H`5F&Y92!I;F9O<FUA8VEJ90!68;EA($EN=&5R;F5T(&%D
M<F5S82!J92!P<F]M:6IE;FIE;F$@;F%K;VX@<')I:F%V;&II=F%N:F$@;F$@
M)7,N($1A(&)I('9AN6$@<VEG=7)N;W-T(&)I;&$@<V'H=79A;F$L(&UO<F%T
M92!S92!P;VYO=F\@<')I:F%V:71I+@!68;D@8G)O=W-E<B!N92!P;V1ROF%V
M82!O=G4@;6]G=>9N;W-T+@!4<F5N=71N82!V<F5M96YS:V$@>F]N83H`56]B
M:>AA:F5N:2!K;V1N:2!R87-P;W)E9"!Z82!S;&%N:F4@<&]R=6MA.@!5;V)I
MZ&%J96YI(&UE=&]D(+EI9G)O=F%N:F$@<&]R=6MA('!R:6QI:V]M('-L86YJ
M83H`5F&Y(&1E9F%U;'0@:61E;G1I=&5T.@!68;EE(&EM92!I('!R97II;64Z
M`%9AN6$@;F]V82"Y:69R82!Z82`E<R!J93H@)7,`5F&Y92!O<&-I:F4@<W4@
M<V'H=79A;F4@=&]K;VT@=')A:F%N:F$@;W9E('-E<VEJ92X`3W!C:6IE('-U
M('-AZ'5V86YE+@!68;EA(+EI9G)A(&IE('!O;FFY=&5N80!68;EA(+EI9G)A
M(&IE('!O;FFY=&5N82P@<')O=FIE<FET92!V8;D@92UM86EL(&D@<')I:F%V
M:71E('-E('-A(&YO=F]M(+EI9G)O;2X`5F&Y:2!U9&%L:F5N:2!S97)V97)I
M.@!68;D@<&]T<&ES.@!*=6=O<VQA=FEJ80!:86ER`%IA;6)I:F$`6FEM8F%B
M=F4`6FEP<'D`6U-A:W)I:B!C:71I<F%N:2!T96MS=%T`6T)E>B!T96UE70!;
M4')I:F%V82!P<F]B;&5M85T`6U!R:6MAOFD@8VET:7)A;FD@=&5K<W0@+0!;
M4')I:V&^:2!C:71I<F%N:2!T96MS="`M("5S(')E9&]V85T`6W)E9"`E<R!O
M9"`E<UT`7T%D;6EN:7-T<F%C:6IA`%]"8V,`7T-R;F$@;&ES=&$`7T-,20!?
M0V,`7T1A=&%4<F5E`$]?8G)IN6D`7T]B<FFY:2!R960`7T9O;&1E<FD`7T=R
M=7!E`%]0;VUOY@!?261E;G1I=&5T`%]/<V]B:6YE('-L:6ME+BXN`%]386YD
M=>AE`%]0<FEJ879I('-E`%])>FQA>@!?27IV;W)N:2!K;V0@<&]R=6ME`%])
M>FUI:F5N:2!L:6YK+BXN`%]/<&-I:F4`7T1O>G9O;&4`3V2Y7W1A;7!A:@!?
M56ML;VYI(&QI;FLN+BX`7T]D9V]V;W)I`%]4<F&^:0!?4&^Y86QJ:2!P;W)U
M:W4`7U!O9&5S:0!/<V]B:6YE(%]T86)E;&4N+BX`7U1O:R!T96UE`%]:80!?
M5G)A=&D@;V)R:7-A;F4`7TMO<FES;FEC:0!?5FED:2#H:71A=G4@=&5M=0!?
M0FEJ96QA(&QI<W1A`&EM96YI:P!O9`!M86EL8F]X(&1A=&]T96MA`&EM90!N
M:;ET80!I;&D`<')A=F]P:7-N82!G<F6Y:V$`<')A=F]P:7-N92!G<F6Y:V4`
M;&ES=&$@>F%D871A:V$`8F5Z(&EM96YA`'9#87)D`'=E871H97(N8V]M`'9A
MN6$@8FEJ96QA(&QI<W1A````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]L;V-A;&4O9&%?1$LO````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C``,#$W-#$P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]D85]$2R],0U]-15-304=%
M4R\`````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<V,``P,C$Q-S4`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE
M+V1A7T1++TQ#7TU%4U-!1T53+VEM<"YM;P``````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,S`P-C0U`#$P-#$W,S8R-S8P`#`R,C,R-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25`````+($```<````K"4`
M`$<&```\2P```````%AD```*````660```H```!D9```"@```&]D```*````
M>F0```\```"%9```"@```)5D```$````H&0```$```"E9```&0```*=D```+
M````P60``!X```#-9```2````.QD```K````-64``$0```!A90``)P```*9E
M```7````SF4```4```#F90``*````.QE```R````%68``"D```!(9@``,@``
M`')F```0````I68``!0```"V9@``$````,MF```F````W&8``"<````#9P``
M)@```"MG```<````4F<``"<```!O9P``(````)=G```B````N&<``!<```#;
M9P``(@```/-G```U````%F@```8```!,:```&P```%-H```N````;V@``#<`
M``">:```!@```-9H```,````W6@``'P```#J:```;````&=I```<````U&D`
M`!T```#Q:0``&P````]J``!%````*VH``"@```!Q:@``00```)IJ```D````
MW&H```X````!:P``#P```!!K```(````(&L```X````I:P``#@```#AK```S
M````1VL``%$```![:P``!0```,UK```#````TVL```X```#7:P``*````.9K
M```(````#VP```H````8;```#P```"-L```'````,VP``!D````[;```#P``
M`%5L```(````96P```H```!N;```%P```'EL```(````D6P``!P```":;```
M&0```+=L``!@````T6P``"@````R;0``'@```%MM```:````>FT``"P```"5
M;0``(````,)M```R````XVT```<````6;@``#````!YN```-````*VX``%0`
M```Y;@``8P```(YN```.````\FX```4````!;P```P````=O``!.````"V\`
M`%````!:;P``0P```*MO``!"````[V\``#T````R<```%@```'!P```P````
MAW```",```"X<```!@```-QP```7````XW```%$```#[<```-0```$UQ```U
M````@W$```@```"Y<0``$0```,)Q```-````U'$``!,```#B<0``(P```/9Q
M```O````&G(``#````!*<@``2````'MR```A````Q'(``#L```#F<@``/```
M`")S```K````7W,``#````"+<P``,0```+QS```[````[G,``#D````J=```
M-0```&1T```,````FG0```D```"G=````P```+%T```&````M70```P```"\
M=```-0```,ET```.````_W0``$D````.=0``,P```%AU```*````C'4``"T`
M``"7=0``"P```,5U```)````T74```D```#;=0``+````.5U``!0````$G8`
M`!@```!C=@``$0```'QV```1````CG8```L```"@=@``"@```*QV```C````
MMW8``!8```#;=@``+@```/)V```#````(7<``#@````E=P``"````%YW```)
M````9W<``$4```!Q=P``!````+=W```$````O'<``"<```#!=P``"````.EW
M```(````\G<``"H```#[=P``*P```"9X``!3````4G@```8```"F>```#@``
M`*UX```5````O'@``#X```#2>````@```!%Y```*````%'D``$\````?>0``
M#````&]Y```&````?'D```H```"#>0``#0```(YY``!B````G'D``"<```#_
M>0``7P```"=Z```6````AWH``!P```">>@``#P```+MZ```S````RWH``"@`
M``#_>@``#@```"A[```5````-WL``#````!->P``$0```'Y[```U````D'L`
M`$4```#&>P``1P````Q\```?````5'P``"4```!T?```,P```)I\```K````
MSGP``#4```#Z?```0@```#!]```=````<WT``%$```"1?0``,0```.-]```[
M````%7X``$````!1?@``.````))^```%````RWX```P```#1?@``$0```-Y^
M```-````\'X```@```#^?@``#`````=_```4````%'\```\````I?P``$0``
M`#E_```'````2W\```<```!3?P``"0```%M_```7````97\``"8```!]?P``
M3P```*1_```E````]'\``!\````:@```$````#J````B````2X```!L```!N
M@```&P```(J````>````IH```"\```#%@```7````/6````N````4H$```0`
M``"!@0``#@```(:!```'````E8$```X```"=@0``+````*R!```D````V8$`
M`#8```#^@0``*0```#6"``!!````7X(``#H```"A@@``*0```-R"```Z````
M!H,```8```!!@P``#0```$B#```+````5H,``!4```!B@P``%````'B#```8
M````C8,``!H```"F@P``'0```,&#```9````WX,``%T```#Y@P``%0```%>$
M```E````;80``!0```"3A```.0```*B$```<````XH0``"@```#_A````@``
M`"B%```%````*X4```4````QA0``!````#>%```(````/(4```H```!%A0``
M!P```%"%```0````6(4``!0```!IA0``&0```'Z%```:````F(4```D```"S
MA0``!@```+V%```4````Q(4``!,```#9A0``$````.V%```7````_H4``!$`
M```6A@``%0```"B&```K````/H8``!<```!JA@``-````(*&```S````MX8`
M`!0```#KA@``!P````"'```0````"(<``!P````9AP``'````#:'```,````
M4X<``"8```!@AP``"@```(>'```4````DH<```L```"GAP``!P```+.'```/
M````NX<```<```#+AP``+0```-.'```:`````8@``"@````<B```+0```$6(
M```N````<X@```L```"BB```#````*Z(```C````NX@``"8```#?B```*@``
M``:)```@````,8D``!\```!2B0``!````'*)```:````=XD``"<```"2B0``
M$@```+J)```@````S8D``!<```#NB0``!0````:*```,````#(H```X````9
MB@``#@```"B*```#````-XH``"L````[B@``!````&>*```.````;(H```P`
M``![B@``$P```(B*```E````G(H```X```#"B@``$P```-&*```6````Y8H`
M`#@```#\B@``$P```#6+```%````28L```T```!/BP``'0```%V+```/````
M>XL``!8```"+BP``$@```**+```+````M8L```P```#!BP``#0```,Z+```9
M````W(L``!P```#VBP``&````!.,```3````+(P```,```!`C```%0```$2,
M```+````6HP``!,```!FC```$````'J,```G````BXP``"D```"SC```+```
M`-V,```H````"HT```X````SC0``-0```$*-```%````>(T``"D```!^C0``
M&````*B-```;````P8T``!````#=C0``$````.Z-```/````_XT```L````/
MC@``#P```!N.```,````*XX```\````XC@``!@```$B.```*````3XX``!(`
M``!:C@``#0```&V.```,````>XX``$,```"(C@``/0```,R.```)````"H\`
M``L````4CP``(0```""/```#````0H\```H```!&CP``(````%&/```?````
M<H\``!L```"2CP``&0```*Z/```+````R(\``!L```#4CP``"````/"/```$
M````^8\```P```#^CP``#@````N0```/````&I```"4````JD```*@```%"0
M```'````>Y```!(```"#D```&P```):0```$````LI```!(```"WD```"@``
M`,J0```(````U9```!T```#>D```$````/R0```.````#9$``!X````<D0``
M&@```#N1``!$````5I$```<```";D0``"````*.1```1````K)$``!D```"^
MD0``%0```-B1```/````[I$``!$```#^D0``&@```!"2```%````*Y(```0`
M```QD@``#````#:2```$````0Y(```4```!(D@``&@```$Z2```/````:9(`
M`"(```!YD@```@```)R2```-````GY(``"````"MD@``#````,Z2```$````
MVY(```0```#@D@``%P```.62```'````_9(```0````%DP``)P````J3```&
M````,I,``!4````YDP``#````$^3```1````7),```0```!NDP``#0```'.3
M```'````@9,```P```")DP``"@```):3```%````H9,``"<```"GDP``*```
M`,^3```$````^),``!P```#]DP``-P```!J4```-````4I0``"<```!@E```
M&P```(B4```B````I)0```P```#'E```%@```-24```%````ZY0``$0```#Q
ME```/````#:5```&````<Y4```H```!ZE0``!0```(65```&````BY4```H`
M``"2E0``#@```)V5```/````K)4```X```"\E0``&P```,N5```?````YY4`
M`!X````'E@``(P```":6```1````2I8``!4```!<E@``&````'*6```1````
MBY8``!````"=E@``(P```*Z6```)````TI8``!(```#<E@``'0```.^6```2
M````#9<``!`````@EP``"@```#&7```%````/)<``#$```!"EP``)````'27
M```$````F9<``!P```">EP``(P```+N7```B````WY<```8````"F```%P``
M``F8```D````(9@``",```!&F```&@```&J8```K````A9@```\```"QF```
M%@```,&8```H````V)@```L````!F0``(0````V9```@````+YD```8```!0
MF0```@```%>9```*````6ID``$\```!EF0``1P```+69``!3````_9D``"X`
M``!1F@``"````(":```1````B9H```D```";F@``$0```*6:```A````MYH`
M`!<```#9F@``$````/&:``!\`````IL``!4```!_FP``&@```)6;```.````
ML)L```@```"_FP``!@```,B;```,````SYL```<```#<FP``!0```.2;```+
M````ZIL```,```#VFP``#````/J;```&````!YP```(````.G```#@```!&<
M```$````()P```T````EG```'P```#.<```'````4YP``"(```!;G```(P``
M`'Z<```E````HIP```@```#(G```-P```-&<```B````"9T``!,````LG0``
M$0```$"=```/````4IT```\```!BG0``%P```'*=```9````BIT``"8```"D
MG0``)@```,N=```4````\IT``!,````'G@``$````!N>```-````+)X```X`
M```ZG@``%@```$F>```0````8)X```<```!QG@``$P```'F>```,````C9X`
M``\```":G@``#@```*J>```,````N9X```X```#&G@``#P```-6>```-````
MY9X```\```#SG@``#P````.?```7````$Y\``!0````KGP``$0```$"?```/
M````4I\``"````!BGP``+@```(.?```:````LI\``"8```#-GP``"P```/2?
M```&`````*````<````'H```*P````^@```$````.Z````D```!`H```0```
M`$J@```.````BZ````<```":H```%0```**@```5````N*````0```#.H```
M!````-.@```$````V*```"(```#=H```#`````"A```'````#:$```4````5
MH0``%@```!NA```#````,J$```H````VH0``"````$&A```1````2J$```P`
M``!<H0``!````&FA```$````;J$```P```!SH0``"0```("A```"````BJ$`
M`!0```"-H0``#0```**A```2````L*$```L```##H0``&P```,^A```?````
MZZ$```\````+H@``%````!NB```>````,*(``!4```!/H@``+P```&6B```3
M````E:(``"H```"IH@``&0```-2B```<````[J(``!\````+HP``%````"NC
M```@````0*,``"4```!AHP``)````(>C```I````K*,``"0```#6HP``$@``
M`/NC```.````#J0``#<````=I```$@```%6D```/````:*0```0```!XI```
M!@```'VD```+````A*0```D```"0I```#0```)JD```,````J*0``!<```"U
MI```%````,VD```6````XJ0``"$```#YI```!0```!NE```'````(:4``$0`
M```II0``/````&ZE```"````JZ4```(```"NI0``#````+&E```C````OJ4`
M`#(```#BI0``,P```!6F```,````2:8```T```!6I@``%````&2F```3````
M>:8```T```"-I@``#P```)NF```#````JZ8``!,```"OI@``"P```,.F```T
M````SZ8```L````$IP``%````!"G```^````):<``!,```!DIP``-````'BG
M```Q````K:<``!(```#?IP``$````/*G```8`````Z@``",````<J```(@``
M`$"H```G````8Z@``%8```"+J```30```.*H``"Y````,*D```0```#JJ0``
M'````.^I```-````#*H``"<````:J@``&P```$*J```,````7JH```T```!K
MJ@``(@```'FJ```A````G*H```<```"^J@``"@```,:J```2````T:H``"$`
M``#DJ@``"P````:K```<````$JL``!@````OJP``"````$BK```5````4:L`
M`!X```!GJP``*````(:K```M````KZL```@```#=JP``%````.:K```L````
M^ZL``"<````HK```*P```%"L```J````?*P```4```"GK```,0```*VL```<
M````WZP``*(```#\K```)P```)^M```H````QZT``!H```#PK0``=@````NN
M``!Y````@JX``!P!``#\K@``*````!FP```=````0K```"D```!@L```'0``
M`(JP```N````J+```%<```#7L```-@```"^Q```L````9K$``"P```"3L0``
M,0```,"Q```N````\K$``!`````AL@``*P```#*R```A````7K(```<```"`
ML@``$````(BR```-````F;(```4```"GL@``"````*VR```4````MK(``!,`
M``#+L@``-@```-^R```W````%K,```D```!.LP``+P```%BS```.````B+,`
M``T```"7LP``#P```*6S```6````M;,``#X```#,LP``)P````NT```F````
M,[0``"0```!:M```)P```'^T```?````I[0``!8```#'M```"P```-ZT```>
M````ZK0```L````)M0``#@```!6U```.````)+4```D````SM0``"````#VU
M```0````1K4``!4```!7M0``$P```&VU```'````@;4``!4```")M0``!@``
M`)^U```+````IK4``",```"RM0``%@```-:U```/````[;4``!@```#]M0``
M"P```!:V```-````(K8``!`````PM@``+@```$&V```Z````<+8```X```"K
MM@``#0```+JV```%````R+8```L```#.M@``#````-JV```-````Y[8```T`
M``#UM@``#@````.W```-````$K<``"`````@MP``)P```$&W```K````:;<`
M``@```"5MP``"@```)ZW```&````J;<``!(```"PMP``#@```,.W```7````
MTK<``!X```#JMP``%@````FX```<````(+@``!0````]N```!0```%*X```:
M````6+@```8```!SN```$P```'JX```?````CK@``!0```"NN```$0```,.X
M``!+````U;@```0````AN0``!@```":Y```6````+;D```X```!$N0``-P``
M`%.Y```.````B[D``!<```":N0``00```+*Y```T````]+D``"4````IN@``
M%0```$^Z```Q````9;H``!,```"7N@``&P```*NZ```J````Q[H``%$```#R
MN@``6@```$2[``!0````G[L``+\```#PNP``!````+"\```(````M;P``!``
M``"^O```"````,^\```$````V+P``#(```#=O```"@```!"]```*````&[T`
M`!4````FO0``#````#R]```/````2;T```L```!9O0``!P```&6]```6````
M;;T``#H```"$O0``(````+^]```/````X+T``#D```#PO0``!@```"J^```)
M````,;X```X````[O@``#@```$J^```$````6;X```8```!>O@``%@```&6^
M```-````?+X```X```"*O@``%````)F^``!#````KKX```H```#RO@``-0``
M`/V^```1````,[\```L```!%OP``&@```%&_```7````;+\``"@```"$OP``
M&P```*V_```7````R;\``!L```#AOP``%P```/V_```<````%<```!<````R
MP```#````$K````3````5\```"\```!KP```$````)O````1````K,````8`
M``"^P```'0```,7````'````X\```$,```#KP```,@```"_!```-````8L$`
M`!(```!PP0``*0```(/!``!P````K<$``#\````>P@``.0```%["``!&````
MF,(``!````#?P@``$````/#"```,`````<,``!0````.PP``'0```"/#```<
M````0<,``!$```!>PP``/0```'##```@````KL,``"<```#/PP``&@```/?#
M```H````$L0```\````[Q```)````$O$```E````<,0```4```"6Q```!0``
M`)S$```&````HL0```0```"IQ```$````*[$```/````O\0```P```#/Q```
M%````-S$```4````\<0```\````&Q0``#@```!;%```2````)<4```P````X
MQ0``%P```$7%```2````7<4``"H```!PQ0``"P```)O%```-````I\4``!0`
M``"UQ0``+P```,K%```%````^L4```H`````Q@``$`````O&```0````',8`
M``L````MQ@``!@```#G&```0````0,8``!$```!1Q@``"````&/&```'````
M;,8```T```!TQ@``!@```(+&```6````B<8```<```"@Q@``"P```*C&```'
M````M,8``!D```"\Q@``&@```-;&```@````\<8```4````2QP``!0```!C'
M```+````'L<``!H````JQP``%````$7'```O````6L<```0```"*QP``,0``
M`(_'``!X````P<<``!L````ZR```,0```%;(```B````B,@``"````"KR```
M'0```,S(```<````ZL@``%T````'R0``+0```&7)```S````D\D``$L```#'
MR0``+````!/*```E````0,H``"$```!FR@``'@```(C*``!U````I\H``#X`
M```=RP``0@```%S+```]````G\L``#T```#=RP``*0```!O,```I````1<P`
M`#$```!OS```+P```*',``!B````T<P``$\````TS0``-@```(3-```^````
MN\T``#````#ZS0``(````"O.```_````3,X``#0```",S@``'0```,'.```>
M````W\X``"H```#^S@``8````"G/```T````BL\``#P```"_SP``.````/S/
M``"G````-=```#P```#=T```)````!K1```H````/]$``"(```!HT0``(P``
M`(O1```E````K]$``"4```#5T0``*0```/O1```7````)=(``"D````]T@``
M(````&?2```R````B-(``!P```"[T@``+@```-C2```X````!],``#P```!`
MTP``)@```'W3```N````I-,``#X```#3TP``/@```!+4``!'````4=0``%,`
M``"9U```5P```.W4``!5````1=4``$8```";U0``*@```.+5```O````#=8`
M`%4````]U@``(````)/6```K````M-8``"H```#@U@``/@````O7``!2````
M2M<``#(```"=UP``*P```-#7```J````_-<``"8````GV```+````$[8``!.
M````>]@``#````#*V```'0```/O8```C````&=D``#L````]V0``)P```'G9
M``!.````H=D``$<```#PV0``8@```#C:``!)````F]H``%4```#EV@``0```
M`#O;```O````?-L``#(```"LVP``*P```-_;```I````"]P```\````UW```
M+0```$7<```Q````<]P```X```"EW```"P```+3<```%````P-P```(```#&
MW```"@```,G<``!6````U-P``$X````KW0``%P```'K=```,````DMT```T`
M``"?W0```P```*W=```@````L=T``!@```#2W0``)@```.O=```*````$MX`
M`!,````=W@``"````#'>```6````.MX```P```!1W@``'P```%[>```,````
M?MX``#L```"+W@``#P```,?>```1````U]X``!$```#IW@``!P```/O>```&
M`````]\``!H````*WP``'0```"7?```8````0]\```8```!<WP``$0```&/?
M```>````==\``!D```"4WP``!````*[?``!&````L]\```@```#ZWP``"0``
M``/@```4````#>````0````BX```!P```"?@```2````+^```"8```!"X```
M#0```&G@```9````=^```!@```"1X```"P```*K@```.````MN```"0```#%
MX```(0```.K@```*````#.$``!,````7X0``)P```"OA```)````4^$```\`
M``!=X0``*````&WA```/````EN$``"````"FX0``#0```,?A```4````U>$`
M``T```#JX0``%````/CA```4````#>(```<````BX@``!@```"KB```-````
M,>(```L````_X@``5P```$OB``!:````H^(``#\```#^X@``-@```#[C``!^
M````=>,```D```#TXP``#````/[C```*````"^0```(````6Y```!@```!GD
M```#````(.0``#L````DY```3P```&#D```U````L.0``"<```#FY```(0``
M``[E```D````,.4``"8```!5Y0``,P```'SE```=````L.4``"(```#.Y0``
M>````/'E``!6````:N8``#H```#!Y@``0@```/SF```9````/^<``!<```!9
MYP``)0```''G``"+````E^<``"H````CZ```*P```$[H``!%````>N@``"8`
M``#`Z```2P```.?H``!.````,^D``"<```""Z0``*0```*KI```A````U.D`
M`"L```#VZ0``'0```"+J```F````0.H``"T```!GZ@``)0```)7J```Z````
MN^H``"D```#VZ@``(@```"#K```]````0^L``$$```"!ZP``*````,/K```L
M````[.L```D````9[```'````"/L```0````0.P```\```!1[```*P```&'L
M```G````C>P```X```"U[```2P```,3L``!S````$.T``$````"$[0``*@``
M`,7M```T````\.T``"@````E[@``#P```$[N```,````7NX``!````!K[@``
M!````'SN```*````@>X```,```",[@``!P```)#N```(````F.X```D```"A
M[@``!@```*ON```(````LNX```\```"[[@``#````,ON```&````V.X```D`
M``#?[@``"P```.GN```&````]>X```<```#\[@``#0````3O```'````$N\`
M``,````:[P``"0```![O```,````*.\```H````U[P``$0```$#O```*````
M4N\```\```!=[P``!0```&WO```9````<^\``!$```"-[P``&````)_O```3
M````N.\``!P```#,[P``$0```.GO```/````^^\```0````+\```$0```!#P
M```2````(O```!<````U\````P```$WP```,````4?````0```!>\```!```
M`&/P```"````:/```!$```!K\```&````'WP```3````EO````X```"J\```
M#P```+GP```,````R?```!$```#6\```#@```.CP```.````]_```&4!```&
M\0``"@```&SR```+````=_(```H```"#\@``"0```([R```/````F/(```<`
M``"H\@```P```+#R```!````M/(``!D```"V\@``"P```-#R```>````W/(`
M`$@```#[\@``*P```$3S``!'````</,``"L```"X\P``&````.3S```%````
M_?,``"`````#]```+P```"3T```J````5/0``#,```!_]```$@```+/T```1
M````QO0```X```#8]```+````.?T```C````%/4``"\````X]0``'````&CU
M```O````A?4``"D```"U]0``*P```-_U```8````"_8``"8````D]@``+P``
M`$OV```&````>_8``!L```""]@``+````)[V``!"````R_8```8````.]P``
M"P```!7W``"&````(?<``&\```"H]P``(0```!CX```<````.O@``!L```!7
M^```1P```'/X```K````N_@``$0```#G^```*````"SY```(````5?D```D`
M``!>^0``"````&CY```(````<?D```@```!Z^0``-@```(/Y``!3````NOD`
M``4````.^@```@```!3Z```2````%_H``"D````J^@``"@```%3Z```,````
M7_H```X```!L^@``"@```'OZ```A````AOH``!4```"H^@``"0```+[Z```,
M````R/H``!````#5^@``#````.;Z```>````\_H``"(````2^P``4````#7[
M```B````AOL``!H```"I^P``&@```,3[```F````W_L``"(````&_```+@``
M`"G\```'````6/P```\```!@_```$0```'#\``!.````@OP``%T```#1_```
M#@```"_]```)````/OT```0```!(_0``20```$W]``!+````E_T``%(```#C
M_0``2@```#;^``!!````@?X``!P```##_@``-@```.#^```B````%_\```4`
M```Z_P``%P```$#_``!3````6/\``#T```"L_P``/0```.K_```(````*``!
M`!(````Q``$`#````$0``0`1````40`!`"````!C``$`,0```(0``0`Y````
MM@`!`$L```#P``$`(@```#P!`0`N````7P$!`#P```".`0$`*@```,L!`0`M
M````]@$!`"\````D`@$`.P```%0"`0`_````D`(!`#H```#0`@$`"`````L#
M`0`(````%`,!``4````=`P$`!P```",#`0`-````*P,!`#@````Y`P$`#@``
M`'(#`0!'````@0,!`$4```#)`P$`"P````\$`0`Q````&P0!``P```!-!`$`
M"0```%H$`0`&````9`0!`"T```!K!`$`6P```)D$`0`I````]00!`!0````?
M!0$`$0```#0%`0`.````1@4!``X```!5!0$`'````&0%`0`8````@04!`$,`
M``":!0$``P```-X%`0`Q````X@4!``H````4!@$`"@```!\&`0!`````*@8!
M``8```!K!@$`!0```'(&`0`F````>`8!``<```"?!@$`"````*<&`0`L````
ML`8!`"D```#=!@$`5P````<'`0`(````7P<!``\```!H!P$`'0```'@'`0`_
M````E@<!``(```#6!P$`!0```-D'`0!5````WP<!``D````U"`$`!0```#\(
M`0`*````10@!``L```!0"`$`A0```%P(`0`V````X@@!`&4````9"0$`$0``
M`'\)`0`B````D0D!`!$```"T"0$`.````,8)`0`M````_PD!``X````M"@$`
M$0```#P*`0`M````3@H!``X```!\"@$`0P```(L*`0!7````SPH!`$P````G
M"P$`'P```'0+`0`S````E`L!`#0```#("P$`,0```/T+`0`T````+PP!`$P`
M``!D#`$`(````+$,`0!.````T@P!`#P````A#0$`00```%X-`0`Z````H`T!
M`#\```#;#0$``P```!L.`0`*````'PX!``H````J#@$`#````#4.`0`(````
M0@X!``@```!+#@$`#P```%0.`0`)````9`X!`!````!N#@$`"0```'\.`0`%
M````B0X!``D```"/#@$`%0```)D.`0`C````KPX!`%D```#3#@$`)````"T/
M`0`F````4@\!``\```!Y#P$`*0```(D/`0`>````LP\!`"4```#2#P$`*```
M`/@/`0`X````(1`!`%\```!:$`$`*@```+H0`0`&````Y1`!`!````#L$`$`
M"````/T0`0`0````!A$!`"@````7$0$`*P```$`1`0`X````;!$!`"H```"E
M$0$`/0```-`1`0`U````#A(!`"P```!$$@$`10```'$2`0`%````MQ(!``L`
M``"]$@$`#````,D2`0`3````UA(!`!$```#J$@$`%@```/P2`0`=````$Q,!
M`"<````Q$P$`+@```%D3`0!2````B!,!`!8```#;$P$`(0```/(3`0`4````
M%!0!`#0````I%`$`(````%X4`0`Z````?Q0!``(```"Z%`$`!@```+T4`0`$
M````Q!0!``0```#)%`$`!@```,X4`0`(````U10!``@```#>%`$`$@```.<4
M`0`1````^A0!`!\````,%0$`'````"P5`0`)````214!``0```!3%0$`&```
M`%@5`0`1````<14!``T```"#%0$`$@```)$5`0`.````I!4!`!(```"S%0$`
M)P```,85`0`5````[A4!`#@````$%@$`/0```#T6`0`2````>Q8!``<```".
M%@$`$0```)86`0`:````J!8!`"````##%@$`#P```.06`0`L````]!8!``@`
M```A%P$`$0```"H7`0`+````/!<!``@```!(%P$`$````%$7`0`#````8A<!
M`"X```!F%P$`&0```)47`0`C````KQ<!`"D```#3%P$`,0```/T7`0`$````
M+Q@!``P````T&`$`(@```$$8`0`H````9!@!`"<```"-&`$`&````+48`0`F
M````SA@!``8```#U&`$`%0```/P8`0`C````$AD!``T````V&0$`&P```$09
M`0`2````8!D!``8```!S&0$`!P```'H9`0`2````@AD!``X```"5&0$`!```
M`*09`0`F````J1D!``4```#0&0$`$````-89`0`,````YQD!`!$```#T&0$`
M)P````8:`0`0````+AH!`!0````_&@$`%P```%0:`0`_````;!H!`!8```"L
M&@$`!0```,,:`0`.````R1H!`!P```#8&@$`#````/4:`0`1`````AL!`!``
M```4&P$`"````"4;`0`0````+AL!``\````_&P$`&P```$\;`0`>````:QL!
M`!4```"*&P$`&````*`;`0`$````N1L!`!H```"^&P$`#0```-D;`0`4````
MYQL!``T```#\&P$`/0````H<`0`X````2!P!`#X```"!'`$`/P```,`<`0`-
M`````!T!`"@````.'0$`!````#<=`0`L````/!T!`!T```!I'0$`$@```(<=
M`0`,````FAT!`!````"G'0$`#0```+@=`0`/````QAT!``\```#6'0$`"@``
M`.8=`0`0````\1T!``4````"'@$`"0````@>`0`0````$AX!``H````C'@$`
M&````"X>`0`Z````1QX!`"L```""'@$`"````*X>`0`+````MQX!`"P```##
M'@$``P```/`>`0`+````]!X!`"``````'P$`(0```"$?`0`9````0Q\!`!8`
M``!='P$`"P```'0?`0`>````@!\!``8```"?'P$``P```*8?`0`-````JA\!
M`!0```"X'P$`$````,T?`0`I````WA\!`#,````((`$`!@```#P@`0`6````
M0R`!`!H```!:(`$`!````'4@`0`+````>B`!``L```"&(`$`"@```)(@`0`>
M````G2`!``X```"\(`$`%````,L@`0`@````X"`!`"<````!(0$`00```"DA
M`0`*````:R$!``L```!V(0$`$@```((A`0`9````E2$!`!<```"O(0$`$@``
M`,<A`0`7````VB$!`!T```#R(0$``P```!`B`0`#````%"(!``L````8(@$`
M!````"0B`0`$````*2(!`!P````N(@$`&P```$LB`0`A````9R(!``4```")
M(@$`#````(\B`0`:````G"(!``T```"W(@$``P```,4B`0`$````R2(!`!4`
M``#.(@$`#````.0B`0`%````\2(!`!X```#W(@$`!@```!8C`0`5````'2,!
M``X````S(P$`$@```$(C`0`#````52,!``T```!9(P$`!0```&<C`0`.````
M;2,!``X```!\(P$`!0```(LC`0`A````D2,!`#H```"S(P$`!````.XC`0`C
M````\R,!`#0````7)`$`#0```$PD`0`H````6B0!`!T```"#)`$`(0```*$D
M`0`/````PR0!`!8```#3)`$`"````.HD`0!)````\R0!`$$````])0$`!P``
M`'\E`0`+````AR4!``<```"3)0$`"````)LE`0`.````I"4!`!$```"S)0$`
M$0```,4E`0`2````UR4!`!@```#J)0$`(`````,F`0`C````)"8!`"$```!(
M)@$`&````&HF`0`<````@R8!`!\```"@)@$`%0```,`F`0`1````UB8!`"0`
M``#H)@$`!P````TG`0`0````%2<!`!X````F)P$`%@```$4G`0`3````7"<!
M``\```!P)P$`"````(`G`0`Y````B2<!`"D```##)P$`!````.TG`0`A````
M\B<!`"(````4*`$`)````#<H`0`)````7"@!`!4```!F*`$`(0```'PH`0`D
M````GB@!`!X```##*`$`*P```.(H`0`/````#BD!`!<````>*0$`(P```#8I
M`0`-````6BD!`!\```!H*0$`(@```(@I`0`(````JRD!``(```"T*0$`"P``
M`+<I`0!(````PRD!`%D````,*@$`<@```&8J`0`J````V2H!``4````$*P$`
M$@````HK`0`+````'2L!`!0````I*P$`(P```#XK`0`;````8BL!`!D```!^
M*P$`;@```)@K`0`A````!RP!`"`````I+`$`#P```$HL`0`$````6BP!``<`
M``!?+`$`#0```&<L`0`&````=2P!``<```!\+`$`#0```(0L`0`#````DBP!
M``T```"6+`$`!P```*0L`0`"````K"P!``T```"O+`$`!````+TL`0`,````
MPBP!`"0```#/+`$`!P```/0L`0`L````_"P!`"0````I+0$`)0```$XM`0`+
M````="T!`#D```"`+0$`(0```+HM`0`@````W"T!`!T```#]+0$`(P```!LN
M`0`6````/RX!`"````!6+@$`%@```'<N`0`B````CBX!`"X```"Q+@$`$0``
M`.`N`0`0````\BX!``P````#+P$`"0```!`O`0`/````&B\!`!\````J+P$`
M$````$HO`0`&````6R\!`!8```!B+P$`!````'DO`0`4````?B\!``<```"3
M+P$`"0```)LO`0`*````I2\!``<```"P+P$`"P```+@O`0`&````Q"\!``T`
M``#++P$`%P```-DO`0`3````\2\!`!(````%,`$`#0```!@P`0`4````)C`!
M`"\````[,`$`$@```&LP`0`E````?C`!``P```"D,`$`!0```+$P`0`(````
MMS`!`#4```#`,`$`!````/8P`0`(````^S`!`$4````$,0$`"@```$HQ`0`'
M````53$!`!4```!=,0$`'@```',Q`0`%````DC$!``8```"8,0$`!````)\Q
M`0`H````I#$!`!(```#-,0$`!P```.`Q`0`&````Z#$!`!<```#O,0$``@``
M``<R`0`(````"C(!``P````3,@$`$P```"`R`0`,````-#(!``<```!!,@$`
M!0```$DR`0`,````3S(!``H```!<,@$``P```&<R`0`7````:S(!`!````"#
M,@$`&````)0R`0`.````K3(!`"4```"\,@$`'P```.(R`0`1`````C,!`!X`
M```4,P$`*@```#,S`0`:````7C,!`#<```!Y,P$`$@```+$S`0`H````Q#,!
M`!0```#M,P$`'0````(T`0`@````(#0!``\```!!-`$`'@```%$T`0`H````
M<#0!`"L```"9-`$`*````,4T`0`X````[C0!``\````G-0$`#0```#<U`0`N
M````134!`!4```!T-0$`"P```(HU`0`%````EC4!``8```"<-0$`#````*,U
M`0`+````L#4!``P```"\-0$`#P```,DU`0`>````V34!`!8```#X-0$`%0``
M``\V`0`@````)38!``4```!&-@$`"0```$PV`0!-````5C8!`%0```"D-@$`
M`@```/DV`0`%````_#8!``X````"-P$`+0```!$W`0`A````/S<!`"X```!A
M-P$`"@```)`W`0`+````FS<!`!````"G-P$`$````+@W`0`3````R3<!``\`
M``#=-P$``P```.TW`0`2````\3<!``H````$.`$`+P````\X`0`1````/S@!
M`!@```!1.`$`0@```&HX`0`8````K3@!`"L```#&.`$`)@```/(X`0`7````
M&3D!`!$````Q.0$`&0```$,Y`0`;````73D!`!T```!Y.0$`,P```)<Y`0!>
M````RSD!`$<````J.@$`Q````'(Z`0`$````-SL!`"4````\.P$`#0```&([
M`0`H````<#L!`!T```"9.P$`#P```+<[`0`-````QSL!`!P```#5.P$`'```
M`/([`0`&````#SP!``4````6/`$`#````!P\`0`.````*3P!``8````X/`$`
M&````#\\`0`7````6#P!``<```!P/`$`&0```'@\`0`5````DCP!`"(```"H
M/`$`+P```,L\`0`)````^SP!``@````%/0$`)P````X]`0`8````-CT!`"H`
M``!//0$`&P```'H]`0`'````ECT!`"\```">/0$`&0```,X]`0"G````Z#T!
M`"L```"0/@$`*@```+P^`0`<````YSX!`'`````$/P$`;0```'4_`0#Z````
MXS\!`#H```#>0`$`'0```!E!`0`F````-T$!`"````!>00$`,````']!`0!&
M````L$$!`#8```#W00$`+@```"Y"`0`H````74(!`"P```"&0@$`+P```+-"
M`0`0````XT(!`"P```#T0@$`&````"%#`0`%````.D,!``X```!`0P$`#```
M`$]#`0`'````7$,!``D```!D0P$`&````&Y#`0`2````AT,!`#8```":0P$`
M-0```-%#`0`)````!T0!`#D````11`$`#@```$M$`0`.````6D0!``T```!I
M1`$`'````'=$`0!#````E$0!`"8```#81`$`)````/]$`0`B````)$4!`"8`
M``!'10$`(````&Y%`0`7````CT4!``P```"G10$`)````+1%`0`,````V44!
M``X```#F10$`#````/5%`0`*`````D8!``H````-1@$`$0```!A&`0`7````
M*D8!`!H```!"1@$`!P```%U&`0`>````948!``H```"$1@$`#P```(]&`0`A
M````GT8!`!<```#!1@$`$0```-E&`0`6````ZT8!``@````"1P$`"P````M'
M`0`.````%T<!`#4````F1P$`2````%Q'`0`.````I4<!``L```"T1P$`!```
M`,!'`0`+````Q4<!``T```#11P$`#@```-]'`0`.````[D<!``\```#]1P$`
M#0````U(`0`A````&T@!`"L````]2`$`*P```&E(`0`(````E4@!``H```">
M2`$`!@```*E(`0`2````L$@!``\```##2`$`'P```--(`0`D````\T@!`!\`
M```820$`'P```#A)`0`/````6$D!``<```!H20$`'````'!)`0`'````C4D!
M`!,```"520$`*0```*E)`0`L````TTD!`!L`````2@$`3````!Q*`0`%````
M:4H!``8```!O2@$`%P```'9*`0`-````CDH!`#0```"<2@$`%````-%*`0`4
M````YDH!`$4```#[2@$`*````$%+`0`@````:DL!`!H```"+2P$`*@```*9+
M`0`4````T4L!`!P```#F2P$`,P````-,`0!-````-TP!`&(```"%3`$`6@``
M`.A,`0#4````0TT!``0````83@$`!````!U.`0`.````(DX!``<````Q3@$`
M`P```#E.`0`T````/4X!``H```!R3@$`"P```'U.`0`5````B4X!`!,```"?
M3@$`#P```+-.`0`*````PTX!``<```#.3@$`%@```-9.`0`W````[4X!`"$`
M```E3P$`$0```$=/`0!#````64\!``,```"=3P$`#````*%/`0`2````KD\!
M``X```#!3P$``P```-!/`0`$````U$\!`!,```#93P$`#````.U/`0`,````
M^D\!``\````'4`$`/0```!=0`0`)````55`!`$````!?4`$`#0```*!0`0`*
M````KE`!`!8```"Y4`$`$````-!0`0`I````X5`!`!8````+40$`$````")1
M`0`H````,U$!`!D```!<40$`)````'91`0`9````FU$!``L```"U40$`%P``
M`,%1`0`M````V5$!`!D````'4@$`&0```"%2`0`&````.U(!`!P```!"4@$`
M!P```%]2`0!'````9U(!`#4```"O4@$`"@```.52`0`1````\%(!`"8````"
M4P$`=P```"E3`0!!````H5,!`#\```#C4P$`/````"-4`0`/````8%0!`!0`
M``!P5`$`#````(54`0`7````DE0!`!D```"J5`$`&0```,14`0`0````WE0!
M`$D```#O5`$`*````#E5`0`@````8E4!`!X```"#50$`(@```*)5`0`.````
MQ54!`!X```#450$`(0```/-5`0`$````%58!``0````:5@$`"````!]6`0`)
M````*%8!`!L````R5@$`(0```$Y6`0`1````<%8!`!T```""5@$`%@```*!6
M`0`1````MU8!`!$```#)5@$`'````-M6`0`8````^%8!`!\````15P$`#@``
M`#%7`0`K````0%<!``P```!L5P$`#````'E7`0`6````AE<!`#````"=5P$`
M!0```,Y7`0`)````U%<!``X```#>5P$`#@```.U7`0`*````_%<!``8````'
M6`$`$0````Y8`0`1````(%@!``0````R6`$`!````#=8`0`-````/%@!``<`
M``!*6`$`$````%)8`0`&````8U@!``<```!J6`$`!P```')8`0`6````>E@!
M`!@```"16`$`'````*I8`0`'````QU@!``4```#/6`$`"P```-58`0`=````
MX5@!`!4```#_6`$`)@```!59`0`%````/%D!`"4```!"60$`8P```&A9`0`@
M````S%D!`#````#M60$`&````!Y:`0`5````-UH!`!D```!-6@$`&````&=:
M`0!#````@%H!`#$```#$6@$`-P```/9:`0!2````+EL!`!X```"!6P$`(P``
M`*!;`0`A````Q%L!`!L```#F6P$`=0````)<`0`W````>%P!`#D```"P7`$`
M.P```.I<`0`Z````)ET!`!\```!A70$`'@```(%=`0`A````H%T!`"<```#"
M70$`4@```.I=`0!'````/5X!`"X```"%7@$`,P```+1>`0`I````Z%X!`!<`
M```27P$`3````"I?`0`O````=U\!`!0```"G7P$`&````+Q?`0`F````U5\!
M`$````#\7P$`,P```#U@`0`T````<6`!`#````"F8`$`G@```-=@`0`R````
M=F$!`"(```"I80$`'@```,QA`0`A````ZV$!`!T````-8@$`'````"MB`0`;
M````2&(!`",```!D8@$`"P```(AB`0`?````E&(!`"$```"T8@$`+0```-9B
M`0`@````!&,!`"H````E8P$`+````%!C`0`^````?6,!`"<```"\8P$`-```
M`.1C`0!*````&60!`$8```!D9`$`40```*MD`0!2````_60!`%T```!090$`
M6P```*YE`0!!````"F8!`#,```!,9@$`,P```(!F`0!;````M&8!`"T````0
M9P$`-P```#YG`0`V````=F<!`$\```"M9P$`40```/UG`0`\````3V@!`#8`
M``",:`$`-````,-H`0`K````^&@!`"8````D:0$`3P```$MI`0`R````FVD!
M`"0```#.:0$`*P```/-I`0!!````'VH!`"4```!A:@$`2````(=J`0!`````
MT&H!`&(````1:P$`0P```'1K`0!$````N&L!`#0```#]:P$`)@```#)L`0`I
M````66P!`"$```"#;`$`'@```*5L`0`0````Q&P!`#````#5;`$`,@````9M
M`0`.````.6T!``X```!(;0$`!0```%=M`0`#````76T!``L```!A;0$`8```
M`&UM`0!'````SFT!`!\````6;@$`#````#9N`0`-````0VX!``,```!1;@$`
M*P```%5N`0`6````@6X!`"@```"8;@$`"0```,%N`0`3````RVX!`!````#?
M;@$`%````/!N`0`1````!6\!`"`````7;P$`"P```#AO`0`S````1&\!``L`
M``!X;P$`#P```(1O`0`+````E&\!``X```"@;P$`!0```*]O`0`2````M6\!
M`"(```#(;P$`'````.MO`0`&````"'`!`!(````/<`$`'0```")P`0`<````
M0'`!``8```!=<`$`.````&1P`0`*````G7`!``L```"H<`$`$P```+1P`0`"
M````R'`!``8```#+<`$`%0```-)P`0`C````Z'`!``L````,<0$`%````!AQ
M`0`7````+7$!``<```!%<0$`"P```$UQ`0`C````67$!`!\```!]<0$`"P``
M`)UQ`0`.````J7$!`"X```"X<0$`"0```.=Q`0`-````\7$!`!T```#_<0$`
M$````!UR`0`B````+G(!`!````!1<@$`%@```&)R`0`4````>7(!`!0```".
M<@$`%````*-R`0`(````N'(!``@```#!<@$`$````,IR`0`-````VW(!`%<`
M``#I<@$`9````$%S`0!%````IG,!`#<```#L<P$`B0```"1T`0`,````KG0!
M`!$```"[=`$`$0```,UT`0`"````WW0!``4```#B=`$``@```.AT`0`S````
MZW0!`#T````?=0$`+````%UU`0`L````BG4!`"<```"W=0$`,````-]U`0`K
M````$'8!`#@````\=@$`'````'5V`0`<````DG8!`&@```"O=@$`2P```!AW
M`0`Z````9'<!`$````"?=P$`%P```.!W`0`3````^'<!`!\````,>`$`@P``
M`"QX`0`E````L'@!`"8```#6>`$`2@```/UX`0`D````2'D!`$<```!M>0$`
M2@```+5Y`0`F`````'H!`"H````G>@$`'P```%)Z`0`E````<GH!`!L```"8
M>@$`+P```+1Z`0`Q````Y'H!`#`````6>P$`3P```$=[`0`M````EWL!`"$`
M``#%>P$`-@```.=[`0`X````'GP!`!,```!7?`$`%0```&M\`0`(````@7P!
M`"(```"*?`$`$0```*U\`0`4````OWP!`$D```#4?`$`*P```!Y]`0`+````
M2GT!`#T```!6?0$`@P```)1]`0!&````&'X!`"\```!??@$`.0```(]^`0`8
M````R7X!``T```#B?@$`#````/!^`0`4````_7X!``,````2?P$`"@```!9_
M`0`"````(7\!``0````D?P$`!@```"E_`0`&````,'\!``@````W?P$`!@``
M`$!_`0`*````1W\!``H```!2?P$`!P```%U_`0`)````97\!``T```!O?P$`
M!````'U_`0`#````@G\!``T```"&?P$`!````)1_`0`#````F7\!`!````"=
M?P$`!P```*Y_`0`,````MG\!`!````##?P$`"P```-1_`0`0````X'\!``<`
M``#Q?P$`&0```/E_`0`5````$X`!`"4````I@`$`$@```$^``0`9````8H`!
M`!$```!\@`$`$P```(Z``0`#````HH`!`!$```"F@`$`$P```+B``0`4````
MS(`!``4```#A@`$`#0```.>``0`$````]8`!``4```#Z@`$`!0````"!`0`1
M````!H$!`!X````8@0$`%0```#>!`0`)````38$!``D```!7@0$`"@```&&!
M`0`8````;($!``X```"%@0$`$````)2!`0`!`````````(`#````````20(`
M```````E````;0```(L!``#O`````````)X"``!5`@``.0```.4"````````
M2@(``)X$````````0@$``'<`````````X@```!D$``"$`P```````,4"``!;
M`0``3P0``"H#`````````````-P#``#7`0``90,```D````S`@``%@```)\!
M````````>P,``","``";`@``RP(``!P#````````2@```*P!````````V@$`
M`%T#``!U!```&@$``*,"```%`@```````%X#````````"`$````````K`@``
M`````!,```"2!```,`$````````K`0``M`,``/@"``!/`@``>````.@!````
M````&`````$$````````BP0```<$```*`0````````````#9````%@$``"<"
M``!X!```E`(``/0```"'`P``/`$``+,!``"\`0````````````#-`P``YP``
M`````````````````*P```",``````````````"1`0``7P,``&<```"B`0``
M[0$````````U````V@(``*P$````````4@(``.4#````````M0(```````#-
M`@``$`(``.@```#F````B````/P"```W`0``'@0``'\"``!)!```````````
M````````'`(``"T$``"#`0``!@,``,0"``!;!````````+T!``!B````I@0`
M`*4`````````]`,``.D```!3`0``!`(```````#^``````````````"P`@``
M7@0```````"5!```L@0``'D#``!]````B@````````",!```<0```%H!``!,
M`P``D@,``"D#``#M`@``FP,``.$````3`0```````$@!`````````````',$
M``"0`0``.00``+<`````````FP0``&<!``!#`@``*P0````````N`0``Q`,`
M`-0#````````F@,``$<`````````+@,``#L$```^`0``)0(```````!I````
M\0(````````"`P``N0```!<$````````W0,``)4`````````R`````("````
M````Z@````L$````````&@(``"D!``#6`@``80$``&4"````````,`,``+(`
M``````````````````!]`0``I0$``%\$``!4`@``VP$``$T$````````,```
M`)\``````````````+L"```7````>0(``-("```;!```Y@,``(L```!*`0``
MA@```(````"B````:`0````````8!```MP$``-@!``!>`@``P0,``$0"````
M`````````/T```!H`````````/`!````````Y@$``'<#```G`0``20,`````
M````````0P$``&T"``"J`0``9@```/,!```C`0````````<````=`0``*@$`
M`!8#``!?````@P,``"\"```[````$0$`````````````WP$``!P!``!!`0``
MR@$``(8#````````K@0``"P"````````,`(``!$`````````B0,```````"H
M`@``YP,``",#``"I`P```````!@!``!.`@```````"P$```V`0``$`0``&H!
M``#V`P``C`$``&L``````````````&("``!5!```:@```*H```!U````````
M`/(#``"-`0``#P0``)4!``#H`@``KP```,D#```9````+P0```4!````````
M``````````#,`@``'0(``!X```"!`````````$$```!C!```B@0``$D````G
M!```[@$``/L"```W`@```````%L#```[`@``[@(``+4#```?`0``00,``!L"
M``#1````M0$``"X"```7`@``T@$``.`!``!N`@``-P,``(\"``#.`@``L0(`
M`,D````S!```?P```'8!````````&`(``(\#````````2@,``(H!``!Y!```
M0@,``,(!``#.`0```````"D`````````0@0```````#.`P``P`(``+0"````
M````W0(``(,"``#$````;@$``*D$``#Y`@``(0```&0!```E`P``)@(`````
M````````000``!T#````````R@,``)`#``!*!```_0(``%<#````````````
M`*<```!R````+0$``-L"``#4`@``]P$``+@#`````````````&\$``!@`@``
M`````*`#``#X``````````````"X`@``/0```#0!``#2`P```````)````"4
M`P``@P```$P$```6`@``/0(``"T"``#A`0``L0,````````X`@```````+<#
M```.`P````````D#``"6`P````````````!&!```?`(```L!``#L`0``FP``
M`$@`````````<P$``*L$````````^P$``#H!```D`0``H0$```````!1`P``
M_P(``!P$````````F0(``$,#``"1````IP,```````!-````[P$``&$````!
M`P``>@$``%8$``!6`0``X0,```<"```)!```3@0``#D#``#I`@``B@(``'P!
M```_!```A0$``%$!``"O`@``,@````````"I`````````&(!````````(P0`
M`"T```"Y`P``P`$``"L#``"L`@```````$T"``!0````%0```.("```4!```
MC@```#T!`````````````+8"``"A````R`$``$`#``"C`P``%`$``#($``!Q
M`P``````````````````7`$``#0#``"?`@``E@```#X"```$`````````,\`
M``#7`@``M````(T```"D`0``)0$``/````"@`0``Y0````````!T`P``JP$`
M`+H"`````````````/L```!.````-@,``)@"``!``````````*0$``#@````
M4@0``$<"``!'`P``DP,``&P``````````````$0`````````!@(``'$"```Y
M`0``!0````<#````````#@$``-P"```Q````#@(``-$"````````+`,``%0!
M``"F`0``/P```)P$``!9`0``<````%,#````````OP,``%P````[`0``<00`
M`"X```"!`P``+P$``',````%!```.`0````````U!````````)<!```0`P``
M`````,```````````````%,$`````````````/4```````````````````!C
M````(@```,`#``!,`0```````````````````````/4"````````U@,``*,`
M``"6!```A0```,T!````````J@,``'X```!A`@``'00```````!:````````
M`.H"```Z```````````````_`P``!`,``-P```#C`P```````#8$``"8`P``
M```````````:!`````````8$```(````\`,``/0!``""`0```````*@```"-
M`P``%`,``+,#```Y`@``;0$``/,#``!#````1@$``.L!``"0!```J0$`````
M``!9`P``5`,``(<"````````K0(``$8```"?!```N@$``/\!````````````
M`$4!``#F`@``;@0``/X#``"3`0``"`0``)T#```,!```ZP(```````!B!```
M`````%,"``#%`0``,`0``'@!``!G!```6`0``&P$``">````NP```#H"```H
M!`````````````"F`P``NP$`````````````WP(``'<!``##`@``*@(``.,`
M``!I`@```````-D"`````P``>P(``$X!``!8`@``9@(`````````````,P,`
M`!0"``!O``````````H$``#1`0```````)(```!V!```QP```&H"``"T`0``
M`````*$"``",`@``R@```'(!``"R`@```````)D$```9`P```````*0"``!\
M!```^@$``.`#````````\0$``(8"``#D`P``0@(````````"!```H`0``'\$
M````````(@(``/\``````````````&0#```!`0```````*D"````````````
M`&8!``!E````]`(``/8"``#2````(0(``+X```#6`0``L`$``$0#````````
M_@(``&L#```?`@``^0,``,8````_`0``J`$``*,$``"4!```Q`$``!\#``!7
M`0``#`$``/$#``!F`P``4`$``),$````````6````!\$``"V`0``%@0``/<#
M``!5`P``?@(``#H$````````<`,``)@```!2`0``D0(``#\"````````*`,`
M`/L#``#(`@```````*($```7`0````````````#4````H@(``.T```#U`P``
M;P(``#X$``#)`0``\P(``$P````Q`P``*`$``(@#````````G0```-,```#0
M`0```````(D```#(`P``````````````````'@$``&\!``!0`P``G`$`````
M``"F`````````#P$``![`0``X0(``,,```#"````]0$````````2`P``````
M`)X#``")`@``S`,``),```!Z`@``B`(``````````````````%L"```0````
MY`````````!-`P````````````!T````90$```(!````````O0,``)<"``!6
M````*0(``)@$``!'`0``D@$```,!``#>`0``00(```````"J!```)@$```L"
M``"%`P``S`$``-4```!+`@``;P,````````G`P```````(\```!/`P``````
M`,8#``#7`P``?@,``+P`````````>0```"$!``!6`@``0P0``&,"``!"````
M`P,```````#V`0```````$8#`````````````(@!``#+````O@$```D"``!:
M!```8@,`````````````4`0`````````````<@,````````Q!````````+H`
M``"[`P``(````&`#``":`@``V`,``,P```!_`0``H0,``*T$``"O`0``````
M`,<!````````&P,``&L!```>`@``"@(``&P"```+````%0$``.H!````````
M`````,,#```:`P``````````````````6`,``)D!``!%`@``F@0``(0$````
M````[P(``````````````````&`$```.`````````*4#````````KP0``&@"
M`````````````*X"``"P`P`````````````B!````````*@#``"M````ZP``
M``````!(!```O0```)4#``!\```````````````-`0``70$``'@"``#L`P``
ME0(```````"S`@``40(``+,```"%`@``,@$``*H"``#J`P``OP````````#;
M`P``&P```"8$``!/`0``@@0``#$!```-````*````&L$``!V````+````"H$
M````````=`$``*,!``#?````N`$``/H#``!)`0``2P0``(P#``#;````````
M`+X#```$`0````````````!9`@```````&0"``"L`P``(`$``(L#````````
M[``````````E!```/````$`"``!\`P````````H#````````4@```$0$```O
M````\`(``)0!``"Y`0``7`0```````!T!```=@,``,8!```2`@```````/T#
M``!<`P``-0$``'T"``#9`P``1`$``%H"``#!`0``H`(```````#3`0``U0$`
M`"`$````````>@```'T#``!8`0``P@(```P"``#8`@``T`(``.D!````````
M`````+8````"````8P$``(0"``"G`@``EP,``%$`````````F0,``/P!``!^
M!```G0(``%0$``#4`0``V````&<"``!,`@``PP$``#,```"P!```:0$``'$!
M``#!`@``[P,``(8!``````````````````#/`0``9@0````````4````*P``
M`"(!```Q`@``^`$``%T```"B`P``7`(``"(#````````K0$``%X!````````
M(P```*@$```,````DP(``)L!``#>`P``````````````````=`(``"X$``!%
M````YP(``#@#``!_`P``]P`````!``"!!```EP0````````U`@``#P(``*4$
M`````````````#T#````````XP(``&P!````````H````$\````#````G00`
M`(<```!7!````````,4````W````D`(``(`$``!@`0``\0``````````````
M\@```(@$`````````````+X"````````(00```````"-!````````(,$``")
M`0``G0$`````````````OP(`````````````/`,``-,#```A`P```````(\!
M``#"`P``-@````````">`0``]@``````````````$0(`````````````;00`
M`!4#``#@`@``````````````````!@$``!4"````````:00``-`````R`@``
M#`,``!4$````````4P````@"``!G`P````````T"````````I`,``"P!````
M````)@,``/P```!&`@``/`(``)8!``#0`P``_0$``-T!``#R`0``GP,``*L#
M```F````Q0,``(X"``"_`0``BP(``,L!````````70(``'8"``#K`P``````
M`,L#``#D`0``900``!X#````````$@0```````"Q!```C@0```````"/!```
M`````*4"``!+````-`(```````#1`P``#0,``(T"`````````````,$```!W
M`@``!0,``'<$````````7P(```\!```T!```V@``````````````;@``````
M```$!``````````````U`P``K@```/\#````````EP`````$```T````_@$`
M`%<"```+`P````````````!U`P``$0,``$4$````````U0(```````#&`@``
M4`(``.0"``!D````9`0``+D"``!-`0``@@,````"``!2`P```````+<"```;
M`0```````#8"``!@````=0$``%4````#!```<@(``.T#``!5`0```````/H"
M``"!`0``Z0,``',"```2`0```````!\`````````A@0`````````````5P``
M`#H#````````^0$```````!(`@``F`$``.@#````````S@```*8"``#S````
M``````````#:`P``A`$``-T``````````````(X#``!^`0````````8```!P
M!````````&D#``!>````W@````````![`````````(<$```#`@``'````+P#
M```.!```&0(```````````````````D!````````)`0````````H`@``L@,`
M``H```"G`0``.`$```````#Y````>`,```````#5`P```````+4```!:`P``
M)`(`````````````L0````````#W`@``2P$``#X`````````,@,```````"<
M````700``'T$``#6````;`,``.X#```8`P```````+$!```=````[@```%\!
M````````N````(4$```7`P``R0(``#@```!P`@``<`$``/@#````````````
M`'H#``#B`0``0`$```@#```@`P````````````#>`@``&@```&$#``#/`@``
M```````````3!````````,<#`````````````'4"````````;0,``+`````/
M`````````+P"``!;````)`,```````!1!```10,``)H````S`0``*00`````
M``"!`@``XP$``!(```#E`0``@`(``&$$``"$`````````,\#````````(`(`
M`/P#``!+`P```````)P#````````L@$``&X#``"6`@``@@(``&H#``")!```
M`````)P"```[`P```````.P"```/`P```0(``-\#``!9!```UP``````````
M````1P0``(H#``"K`@``TP(``'L$``!R!```$P,``"<`````````$P(``',#
M```D``````````````"2`@``-P0``-D!``````````````````#*`@``````
M`.<!``"``0``#00``"T#````````*@````````"1!```N@,``#T$``#-````
M`````+T"````````H00``$@#````````K0,``*X!``"O`P``5@,``)$#``!`
M!```$`$``'H$``!H`P```````%D```!H`0``:@0``*<$```'`0``:P(``(X!
M``!Y`0``@@```)0``````````````+8#``":`0`````````````^`P``W`$`
M````````````JP`````````O`P``&0$``&,#````````F0```*0```#'`@``
M`````*X#``!.`P``^@````````#R`@```````.(#``!4````````````````
M`````````(<!````````$00````@("`@("!#8SH@`"`@("`@(%1O.B``("`@
M($1A=&4Z(``@("`@1G)O;3H@`"`H06-C97-S:V5Y("5S*0`@4W5B:F5C=#H@
M`"!I;B``(P`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`"5D($UE<W-A9V5S
M`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+@`E9"!M97-S86=E<R!H
M879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D
M(&%S(&YO="!S<&%M+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S
M86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2X`)60@=&\@)60@;V8@
M)60@365S<V%G97,`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD
M97(@=V%S(&YO="!R96YA;65D+@`E<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!M86EL8F]X+@`E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T
M:&4@<W1A<G0@;V8@=&AE(&UO;G1H+@`E<R!H87,@86-C97!T960N`"5S(&AA
M<R!C86YC96QL960@)7,N`"5S(&AA<R!D96-L:6YE9"X`)7,@:&%S(')E<&QI
M960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="X`)7,@:&%S(')E<&QI960@=&\@
M=&AE(&EN=FET871I;VX@=&\@)7,N`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U
M<WD@:6YF;W)M871I;VXN`"5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"X`
M)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(')E
M<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@(B5S(BX`)7,@=VES:&5S('1O(&%M;65N9"`E<RX`)7,@
M=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E<R!W:7-H97,@=&\@
M<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+@`E<SH@
M)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!<'!L>2!T:&5S92!C
M:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A<F0@86QL
M(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*0`H
M2%1-3"D`*%!L86EN(%1E>'0I`"A2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R
M965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N
M("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A
M<'!L:65D+BD`*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA
M;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S
M8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"H@061D('1H97-E(&)Y(&-L
M:6-K:6YG($]+("H`*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("H`,2!M
M97-S86=E(&AA<R!B965N(&1E;&5T960N`#$@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN
M`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@8F5E;B!R97!O
M<G1E9"!A<R!S<&%M+@`Q,#`@8VAA<F%C=&5R<P`Q,#`P(&-H87)A8W1E<G,`
M,C0@:&]U<G,`,C4P(&-H87)A8W1E<G,`-3`P(&-H87)A8W1E<G,`02!L87)G
M92!I;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N
M`$$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E
M='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@<F5C:7!I96YT+@!!32]030!!
M3D0`06-C97!T(')E<75E<W0`06-C97!T(')E<75E<W0@86YD(&%D9"!I="!T
M;R!M>2!C86QE;F1A<@!!8V-E<'1E9`!!8V-E<'1E9#H@`$%C8V]U;G0G<R!N
M86UE.@!!8W1I;VYS`$%D9"`E<R!T;R!M>2!!9&1R97-S($)O;VL`061D(&$@
M;F5W('5S97(Z`$%D9"!P86ER`$%D9"!S;W5R8V4`061D('1H:7,@=&\@;7D@
M8V%L96YD87(`061D('5S97(`061D960@(B5S(B!A<R!A;B!A='1A8VAM96YT
M+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@:&5A9&5R
M<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@96YT
M97(@96%C:"!H96%D97(@;VX@82!N97<@;&EN92D\+V5M/@!!9&1I=&EO;F%L
M(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N`$%D9&ET:6]N86P@:6YF
M;W)M871I;VX@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<P!!
M9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!
M9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<P!!9&1I=&EO;F%L(&UE
M<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1R97-S
M`$%D9')E<W,@0F]O:P!!9&1R97-S($)O;VMS`$%D9')E<W-E<R!T;R!"0T,@
M86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E
M<W,@;VX@82!N97<@;&EN92D\+V5M/@!!9&1R97-S97,@=&\@97AP;&EC:71L
M>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@
M96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3X`061M:6YI<W1R871I
M;VX`06QI87,`06QL`$%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE
M.@!!;&P@;65S<V%G97,@:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N
M("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W
M:6QL(&)E(&1E;&5T960N`$%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R
M92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&P@<FEG
M:'1S(&]N(&9O;&1E<B`B)7,B('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U
M<V5R("(E<R(N`$%L;&]W($9O;&1E<B!#<F5A=&EO;C\`06QL;W<@9FEL=&5R
M(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_`$%L=&5R;F%T
M:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ`$%L=V%Y<P!!;'=A>7,@<V%V
M92!A='1A8VAM96YT<P!!;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I
M;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B!S
M86ED.B``06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG
M('1H92!N97<@;F]T92X`06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE
M(&-R96%T:6YG('1H92!N97<@=&%S:RX`06YS=V5R960`06YS=V5R960@;65S
M<V%G97,`07!P;'D@1FEL=&5R<P!!<'!L>2!&:6QT97)S('1O("5S`$%P<&QY
M(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_`$%P<&QY(&9I;'1E<B!R
M=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/P!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@
M:7,@3D]4(')E8V]M;65N9&5D(2D`07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,
M62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT/P!!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F;VQD97(_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@9F]L9&5R/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD
M97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE
M=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R
M97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/P!!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/P!!<G)I
M=F%L(%1I;64`07-C96YD:6YG`$%S:P!!='1A8V@`071T86-H($9I;&5S`$%T
M=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE
M<W-A9V4_`$%T=&%C:&5D($9I;&4Z`$%T=&%C:&5D(&9I;&4@(B5S(B!E>&-E
M961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A
M8VAE9"X`071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E
M<W0@>6]U('-E;G0N`$%T=&%C:&UE;G0`071T86-H;65N="!S=')I<'!E9#H@
M3W)I9VEN86P@871T86-H;65N="!T>7!E`$%T=&%C:&UE;G1S`$%T=&5N9&5E
M<P!!='1E;G1I;VX`075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T;VUA=&EC86QL>2!S:&]W(&EM86=E<R!I;B!(5$U,
M(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2!A9&1R97-S8F]O
M:S\`079A:6QA8FQE($%D9')E<W,@8F]O:W,Z`$%V86EL86)L92!F:65L9',Z
M`$%W86ET:6YG(%)E<W!O;G-E`$)A8U]K('1O("5S`$)A8VL@=&\@)7,`0F%C
M:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@`0F%C:R!T;R!4:')E
M860@1&ES<&QA>0!"860@;W(@;6%L9F]R;65D(')E<75E<W0N(%-E<G9E<B!2
M97-P;VYD960Z("5S`$)C8P!"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE
M('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+@!":7)T:&1A>0!";&%C:VQI
M<W0`0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@
M87)E('-P96-I9FEC86QL>2!R97%U97-T960_`$)O9'D`0F]T:`!";W1H($AE
M861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4`0U]H87)S970`0V%L
M96YD87(`0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V
M97(N`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R
M.B``0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T
M<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@;6%I;&)O>"X`0V%N
M8V5L`$-A;F-E;"!-97-S86=E`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YC
M96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@
M:71S(&-O;G1E;G1S+@!#8P!#96QL(%!H;VYE`$-E<G1I9FEC871E(&EM<&]R
M="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE
M9"!O;B!T:&ES('-E<G9E<BX`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@
M06QL`$-H86YG92!&;VQD97(`0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H
M(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N
M9"!H;W<@;65S<V%G97,@87)E('-O<G1E9"X`0VAA;F=E(&UA:6P@<V5R=F5R
M(&%N9"!F;VQD97(@<V5T=&EN9W,N`$-H86YG92!T:&4@;F%M92P@861D<F5S
M<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6PN`$-H87)A8W1E<G,@=&\@9&ES
M<&QA>3H`0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!#:&5C:R!?06QL
M+TYO;F4`0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C
M:"!M86EL(&9R;VTZ`$-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@
M;65S<V%G93\`0VAO;W-E($%C=&EO;CH`0VAO;W-E(&$@;6%I;"!S97)V97(Z
M`$-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I
M9VAT.@!#:&]O<V4@86X@86-T:6]N.@!#:&]O<V4@=&AE(&%D9')E<W,@8F]O
M:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+@!#:&]O<V4@=&AE(&]R
M9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD:6YG
M(&%D9')E<W-E<RX`0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL
M92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RX`0VQI8VL@
M)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+@!#;&EC:R`E<R!T;R!G;R!T;R`E
M<R!M86YA9V5M96YT('!A9V4N`$-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT
M96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W(&$@
M=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N`$-L:6-K("5S('1O('9I97<@=&AE
M(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N`$-L:6-K("5S('1O
M('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A
M=&4@=VEN9&]W+@!#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM86=E<P!#;&EC
M:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T
M:&5N('-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"X`0VQI8VL@=&\@4V%V
M92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:P!#;&EC:R!T
M;R!3879E(%,O34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E
M<W,@0F]O:P!#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@
M82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R`$-L:6-K:6YG(&]N('1H92!A
M9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D`$-L;W-E
M`$-L;W-E(%=I;F1O=P!#;&]S92!T:&ES('=I;F1O=P!#;&]S960@1F]L9&5R
M`$-O;&QA<'-E`$-O;&QA<'-E($%L;`!#;VQL87!S92!!;&P@1F]L9&5R<P!#
M;VQL87!S92!&;VQD97(`0V]L;W(@26YD:6-A=&]R.B``0V]M;65N=`!#;VUP
M86YY`$-O;7!L971E9`!#;VUP;W-E(&%N;W1H97(@;65S<V%G90!#;VUP;W-E
M(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!#;VUP;W-E(&UE<W-A
M9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H:68@8G)O=W-E<B!S
M=7!P;W)T<R!T:&4@9F5A='5R92D_`$-O;F9I9W5R92!H;W<@;65S<V%G97,@
M87)E(&1I<W!L87EE9"X`0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS
M+@!#;VYF:7)M(%!A<W-W;W)D`$-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0
M('-E<G9E<BX`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D`$-O;G1R;VP@
M4$=0('-U<'!O<G0@9F]R("5S+@!#;VYT<F]L(%,O34E-12!S=7!P;W)T(&9O
M<B`E<RX`0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E
M87)C:&EN9RX`0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME
M9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U('=H96X@
M:70@87)R:79E<RX`0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R
M87!H:6-A;"!O;F5S/P!#;W!Y`$-O<'D@=&\@9F]L9&5R`$-O<G)E8W0`0V]R
M<F5C=&5D(%1E>'0`0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E87-O
M;B!':79E;CH@)7,`0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z
M("5S`$-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E
M<G9E<B!S86ED.B`E<P!#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O
M<&5R871I;VYS+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!#;W5L9"!N;W0@97AT
M<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O
M=6QD(&YO="!R971R:65V92!N86UE<W!A8V4@:6YF;W)M871I;VX@9G)O;2!)
M34%0('-E<G9E<BX`0W)E871E`$-R96%T92!&;VQD97(`0W)E871E($ME>7,`
M0W)E871E(%9I<G1U86P@1F]L9&5R`$-R96%T92!A($YE=R!!8V-O=6YT`$-R
M96%T92!A(&YE=R!3<&%M(&9O;&1E<@!#<F5A=&4@82!N97<@9')A9G1S(&9O
M;&1E<@!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@82!N
M97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G
M86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R
M<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@;F5W('-T871I;VYE<GD`0W)E
M871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+@!#=7)R96YT(&%C
M8V5S<R!T;R`E<P!#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA
M:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RX`0W5S=&]M:7IE(&AO=R!Y;W4@<V5N
M9"!M86EL+@!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N`$1$`$1A:6QY`$1A=%]E`$1A=&4`1&5C;&EN960`1&5C;&EN960Z(`!$
M969A=6QT`$1E9F%U;'0@261E;G1I='D`1&5F875L="!396%R8V@@1FEE;&0`
M1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER
M96-T:6]N.@!$96QE9V%T960`1&5L971E`$1E;&5T92`E<R!0=6)L:6,@2V5Y
M`$1E;&5T92!#=7)R96YT($ME>7,`1&5L971E($9O;&1E<BAS*0!$96QE=&4@
M4V5L96-T960@1F]L9&5R<P!$96QE=&4@4W1A=&EO;F5R>0!$96QE=&4@5FER
M='5A;"!&;VQD97(`1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO
M=&4@<V5R=F5R/P!$96QE=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E
M;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/P!$96QE=&4@<W!A;2!M97-S86=E<P!$96QE=&5D`$1E;&5T960@;65S
M<V%G97,`1&5L971E9"!T:&4@871T86-H;65N="`B)7,B+@!$96QE=&EN9R!A
M;F0@36]V:6YG($UE<W-A9V5S`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@
M9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;@!$97-C96YD:6YG`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',`1&EM('-I9VYA='5R
M97,_`$1I<W!L87D`1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN
M9R!A(&UE<W-A9V4_`$1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E`$1I<W!L
M87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\`1&ES<&QA>2!T
M:&4@(D5M<'1Y(%-P86TB(&QI;FL@:6X@=&AE(&UE;G5B87(_`$1I<W!L87D@
M=&AE(")%;7!T>2!4<F%S:"(@;&EN:R!I;B!T:&4@;65N=6)A<C\`1&ES<&]S
M:71I;VX`1&\@3D]4(&UA=&-H`$1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R
M($YE=R!-86EL`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M
M;@!$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/P!$;VXG="!H879E
M(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O;F4`1&]W;FQO860@)7,@:6X@+GII
M<"!&;W)M870`1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I
M;&4I`$1O=VYL;V%D($9O;&1E<BAS*0!$;W=N;&]A9"!&;VQD97(H<RD@6RYZ
M:7`@9F]R;6%T70!$;W=N;&]A9"!I;B`N>FEP($9O<FUA=`!$<F%F=`!$<F%F
M="!F;VQD97(`1')A9G1S(&9O;&1E<CH`12UM86EL($%D9')E<W,`14Y$`$52
M4D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`161I
M=`!%9&ET($)L86-K;&ES=`!%9&ET($9I;'1E<G,`161I="!6:7)T=6%L($9O
M;&1E<@!%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$5D
M:70@5VAI=&5L:7-T`$5D:70@>6]U<B!B;&%C:VQI<W0`161I="!Y;W5R(&9I
M;'1E<B!R=6QE<P!%9&ET('EO=7(@<')E9F5R96YC97,@9F]R(&%C8V5S<VEN
M9R!O=&AE<B!M86EL(&%C8V]U;G1S+@!%9&ET('EO=7(@=VAI=&5L:7-T`$5M
M86EL`$5M86EL($%D9')E<W,`16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E
M<RX`16UP='D@1F]L9&5R*',I`$5M<'1Y(%-E;&5C=&5D($9O;&1E<G,`16UP
M='D@5')A<V@@9F]L9&5R`$5M<'1Y(%]3<&%M`$5M<'1Y(%]4<F%S:`!%;7!T
M>2!R97-U;'0N`$5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\`16YA8FQE(%,O
M34E-12!F=6YC=&EO;F%L:71Y/P!%;F%B;&4@;65S<V%G92!P<F5V:65W<S\`
M16YC<E]Y<'1I;VX@3W!T:6]N<P!%;F0`16YD(&9O<G=A<F1E9"!M97-S86=E
M`$5N9"!M97-S86=E`$5N9"!M97-S86=E(&9R;VT@)7,`16YT97(@4&%S<W!H
M<F%S90!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(`
M16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(`16YT
M97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(`16YT
M97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<@!%;G1I<F4@
M365S<V%G90!%;G1R>2`B)7,B('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M=&AE(&%D9')E<W,@8F]O:P!%<G)O<@!%<G)O<B!C;VYN96-T:6YG('1O($E-
M05`@<V5R=F5R+B`E<R`Z("5S+@!%<G)O<B!S96YD:6YG(')E<&QY.B`E<RX`
M179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`
M179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`
M17AP86YD`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N9"!&
M;VQD97(`17AP86YD($YA;65S`$5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S
M92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\`17AP
M86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@
M9F]L9&5R<R!V:65W/P!%>'!A;F1I;F<`1E]E=&-H($UA:6P`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&971C:"!-86EL`$9E=&-H
M($UA:6P@:6X@82!S97!A<F%T92!W:6YD;W<_`$9E=&-H(&UE<W-A9V5S('5P
M;VX@;&]G9VEN9R!O;C\`1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S`$9E
M=&-H960@,2!M97-S86=E(&9R;VT@)7,`1F5T8VAM86EL.B``1F5T8VAM86EL
M.B!N;R!N97<@;65S<V%G97,N`$9I7VQT97)S`$9I;&4`1FEL92!-86YA9V5R
M`$9I;'1E<B!/<'1I;VYS`$9I;'1E<B!3971T:6YG<P!&:6QT97(@;65S<V%G
M92!C;VYT96YT(&9O<B!P<F]F86YI='D_`$9I;'1E<B!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+@!&:6QT97)S`$9I;'1E<G,@3D]4($%C
M=&EV90!&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4`1FEN9`!&:7)S="!-
M86EL8F]X(%!A9V4`1FER<W0@4&%G90!&;U]R=V%R9`!&;VQD97(@06-T:6]N
M<R`M($-O;F9I<FUA=&EO;@!&;VQD97(@3F%V:6=A=&]R`$9O;&1E<B!3=6UM
M87)Y`$9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+@!&;VQD97(@=7-E
M(&ES(&YO="!E;F%B;&5D+@!&;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T
M:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A>0!&;W)W
M87)D`$9O<G=A<F0Z`$9O<G=A<F1E9"!M97-S86=E`$9O<G=A<F1E9"!M97-S
M86=E(&9R;VT@)7,`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O0G5S>2!2
M97!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S="!297-P
M;VYS90!&<F]?;0!&<F]M`$9R;VT@061D<F5S<P!&=V0Z`$9W9#H@`$9W9#H@
M)74@1F]R=V%R9&5D($UE<W-A9V5S`$=E;F5R86P@3W!T:6]N<P!'970@;VYL
M>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI`$=O`$=O('1O($UE<W-A9V4`
M1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F("(E<R(`1W)A;G0@86-C97-S
M`$A%4D4`2%1-3`!(5$U,(%9E<G-I;VX@;V8@365S<V%G90!(96%D97)S`$AE
M;'``2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP;W-I;F<Z`$AI
M9&1E;@!(:61D96X@:6X@5&AR96%D(%9I97<`2&ED92!$96QE=&5D`$AI9&4@
M56YS=6)S8W)I8F5D`$AI9V@`2&EG:"!0<FEO<FET>0!(:6=H97-T`$AO;64@
M061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO=R!D;R!Y;W4@=V%N="!T;R!D
M:7-P;&%Y(&%T=&%C:&UE;G1S/P!(;W<@=&\@871T<FEB=71E('%U;W1E9"!L
M:6YE<R!I;B!A(')E<&QY`$E-05``24U!4"`H075T;R!$971E8W0@4')O=&]C
M;VQS*0!)34%0(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E
M<B!297-P;VYD960Z("5S`$E-05`@;W9E<B!34TP`24U!4"!O=F5R(%-33"`H
M<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I`$E-05`@;W9E<B!34TP@*'-E;&8M
M<VEG;F5D*0!)34%0('-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN`$E-
M05`L(&YO(%1,4P!)34%0+U!/4#,@36%I;"!397)V97)S`$E.0D]8`$EF('5S
M:6YG(%-33"!O<B!43%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L
M(&5X=&5N<VEO;B!L;V%D960N`$EF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A
M9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(0!)9VYO<F4`26=N
M;W)E($%L;`!);6%G90!);7!O<G0`26UP;W)T($ME>0!);7!O<G0@2V5Y<&%I
M<@!);7!O<G0@365S<V%G97,`26UP;W)T(%!'4"!+97D`26UP;W)T(%!E<G-O
M;F%L($-E<G1I9FEC871E`$EM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+
M97D`26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!097)S
M;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S`$EM<&]R="!0=6)L:6,@2V5Y`$EM
M<&]R="!0=6)L:6,@4$=0($ME>0!);7!O<G0@4'5B;&EC(%,O34E-12!+97D`
M26UP;W)T(%,O34E-12!+97D`26UP;W)T(&UB;W@@1FEL90!);7!O<G0@;6)O
M>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+@!);7!O<G1A;G0`26UP;W)T86YT
M(&UE<W-A9V5S`$EM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@)7,N`$EM<&]R
M=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`26YB
M;W@`26YC;'5D92!A(&)R:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A
M(')E<&QY/P!);F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\`
M26YF;P!);F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y`$EN9F]R;6%T:6]N
M(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O
M;F%L(%!U8FQI8R!+97D`26YL:6YE`$EN<V5R="!#97)T:69I8V%T92!(97)E
M`$EN<V5R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R90!);G-E<G0@
M4&5R<V]N86P@4'5B;&EC(%!'4"!+97D@2&5R90!);G-E<G0@4'5B;&EC(%!'
M4"!+97D@2&5R90!);G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C
M;VUP;VYE;G0N`$EN=F%L:60@061D<F5S<P!);G9A;&ED(%)E;6]T92!-86EL
M8F]X`$EN=F%L:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RX`
M26YV86QI9"!K97D`26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN
M`$EN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN`$EN=F5R=`!+0@!+
M97D@3&5N9W1H`$ME>2!G96YE<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE
M('1O(&-O;7!L971E+B`@0V]N=&EN=64@=VET:"!K97D@9V5N97)A=&EO;C\`
M2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N
M;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BX`2V5Y(&EM<&]R="!I<R!N;W0@
M879A:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T
M;R!A9&0@>6]U<B!C;VYT86-T<RX`2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!,86YG=6%G90!,87-T($UA:6QB;W@@
M4&%G90!,87-T(%!A9V4`3&E?;FL@071T86-H;65N=',`3&EN:V5D(&%T=&%C
M:&UE;G1S(&%R92!F;W)B:61D96XN`$QI;FMS('=I;&P@97AP:7)E(&]N("5S
M`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D
M:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I
M;&P@;VYL>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L
M:6-I=&QY*0!,:7-T:6YG(&EN('1H92!(96%D97(`3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`3&]C86P@36%I;&)O>#H`3&]C871I;VX`3&]G(&EN`$QO
M9R!I;B!T;R`E<P!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO=P!,;W<@
M4')I;W)I='D`3&]W97-T`$U-`$UA8VEN=&]S:"!&:6QE`$UA:6P`36%I;"!0
M<F5V:65W<P!-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z`$UA:6QB
M;W@`36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T:6]N<P!-87)K($%L
M;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;@!-87)K($%L;"!-97-S86=E
M<R!I;B!&;VQD97(@87,@56YS965N`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT
M(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`36%R
M:R!M97-S86=E<R!A<R!S965N/R`H24U!4"!O;FQY*0!-87)K('-I;7!L92!M
M87)K=7`_`$UA=&-H($%L;"!1=65R:65S`$UA=&-H($%N>2!1=65R>0!-871C
M:&EN9R!F:65L9',`36%X:6UU;2!!='1A8VAM96YT(%-I>F4`36%X:6UU;2!.
M=6UB97(@;V8@1F]L9&5R<P!-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT
M<R!R96%C:&5D+@!-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C
M:&5D+@!-965T:6YG($-A;F-E;&QA=&EO;@!-965T:6YG($EN9F]R;6%T:6]N
M`$UE971I;F<@4')O<&]S86P`365E=&EN9R!297!L>0!-965T:6YG(%5P9&%T
M90!-965T:6YG(%5P9&%T92!297%U97-T`$UE;G4@1F]L9&5R($QI<W0`365S
M<V%G90!-97-S86=E($-O;7!O<VET:6]N`$UE<W-A9V4@1&%T90!-97-S86=E
M($]P=&EO;G,`365S<V%G92!396%R8V@`365S<V%G92!3:7IE`$UE<W-A9V4@
M4V]U<F-E`$UE<W-A9V4@5FEE=VEN9P!-97-S86=E(&9L86=S`$UE<W-A9V4@
M9F]L9&5R<P!-97-S86=E(&9R;VT@)7,`365S<V%G92!H87,@871T86-H;65N
M=',`365S<V%G92!I<R!E;F-R>7!T960`365S<V%G92!I<R!S:6=N960`365S
M<V%G92!M871C:&5S`$UE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN
M`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V960@=&\@
M)7,`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2X`365S<V%G97,@<&5R('!A
M9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`36]D:69Y`$UO
M;G1H;'D`36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"`B
M)7,B+@!-;W9E`$UO=F4@9&]W;@!-;W9E('-P86T@;65S<V%G97,@=&\@<W!A
M;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8`$UO=F4@
M=&\@9F]L9&5R`$UO=F4@=7``375L=&EP87)T+V%L=&5R;F%T:79E`$UU;'1I
M<&QE($UE<W-A9V4@5FEE=P!.3TY%`$Y/5$4`3F%M90!.86UE(&%N9"]O<B!E
M;6%I;"!C86X@;F]T(&)E(&5M<'1Y`$YE961S($%C=&EO;@!.971W;W)K`$YE
M=F5R`$YE=F5R('-A=F4@871T86-H;65N=',`3F5W`$YE=R!&;VQD97(`3F5W
M($UA:6P`3F5W($UE<W-A9V4@=&\@)7,`3F5W(&UE<W-A9V5S`$YE=W,`3F5X
M=`!.97AT($UE<W-A9V4`3F5X="!086=E`$YO`$YO($-E<G1I9FEC871E(&9O
M=6YD`$YO($5N8W)Y<'1I;VX`3F\@2V5Y<R!I;B!+97ER:6YG`$YO($UE<W-A
M9V5S`$YO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!097)S;VYA;"!#
M97)T:69I8V%T92!0<F5S96YT`$YO(%!R979I97<@5&5X=`!.;R!0=6)L:6,@
M2V5Y<R!&;W5N9`!.;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@
M871T86-H;65N=',@9F]U;F0N`$YO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T
M960@:6X@=&AE('!U8FQI8R!K97DN`$YO(&9O;&1E<B!S96QE8W1E9"X`3F\@
M9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN`$YO(&9O
M;&1E<G,@=V5R92!S<&5C:69I960`3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S
M86=E<P!.;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S`$YO(&UE<W-A
M9V4@8F]D>2!T97AT`$YO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N
M`$YO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"X`3F\@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N`$YO('!E<G-O;F%L(%,O
M34E-12!C97)T:69I8V%T97,@:6UP;W)T960N`$YO('-P96QL8VAE8VMI;F<@
M<')O9W)A;2!C;VYF:6=U<F5D+@!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G
M9V5S=&EO;G,`3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T
M:&]D(&-O=6QD(&)E(&9O=6YD+@!.;R!U<V5R('-P96-I9FEE9"X`3F]N(%!A
M<G1I8VEP86YT`$YO;F4`3F]R;6%L`$YO="!$96QE=&5D`$YO="!$<F%F=`!.
M;W0@26UP;W)T86YT`$YO="!097)S;VYA;`!.;W0@82!V86QI9"!P=6)L:6,@
M:V5Y+@!.;W0@9&5L971E9"!M97-S86=E<P!.;W0@:6UP;W)T86YT(&UE<W-A
M9V5S`$YO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM90!.;W1E<P!.
M;W1H:6YG`$YU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T
M=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E<B!O9B!O;&0@
M<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY
M+@!/2P!/4@!/;&0@;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E
M:6YG('!U<F=E9"X`3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E860@
M;65S<V%G97,@:6X@=&AE;3\`3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S
M96QE8W1E9"!F;W(@=&AI<R!A8W1I;VXN`$]P96X@1F]?;&1E<@!/<&5N960@
M1F]L9&5R`$]P=&EO;F%L(%!A<G1I8VEP86YT`$]T:&5R($UA:6P@06-C;W5N
M=',`3W1H97(@3W!T:6]N<P!/=71B;W5N9"!397)V97(`4$=0`%!'4"!%;F-R
M>7!T($UE<W-A9V4`4$=0($5R<F]R.B``4$=0($5R<F]R.B!.965D('!A<W-P
M:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!01U`@3W!T:6]N<P!0
M1U`@4&%S<W!H<F%S92!);G!U=`!01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P
M;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!01U`@4'5B
M;&EC($ME>2!497AT`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,@*"5S*2(@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0(%!U8FQI8R!+97D@9F]R("(E<R(@
M=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!01U`@4'5B;&EC($ME>7)I;F<`
M4$=0(%-I9VX@365S<V%G90!01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4`4$=0
M('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0('!U8FQI8R!K
M97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@<W5P<&]R="!I<R!D:7-A8FQE
M9"!O;B!T:&ES('-Y<W1E;2X`4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L
M>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T
M;R!B92!V97)I9FEE9"X`4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A
M8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E
M9"X`4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U
M<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2!S970@=&\@9&ES
M86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T
M:6YG(&]R(&5L<V4@=&AE(%!'4"!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O
M<G)E8W1L>2X`4$]0,P!03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I`%!/
M4#,@;W9E<B!34TP`4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF
M:6-A=&4I`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D*0!03U`S+"!N;R!4
M3%,`4&%G92`E9"!O9B`E9`!086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-
M97-S86=E`%!A9V4@=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G90!087)T
M*',I`%!A<W-P:')A<V4`4&%S<W!H<F%S92`H06=A:6XI`%!A<W-P:')A<V4@
M<W5C8V5S<V9U;&QY('5N;&]A9&5D+@!087-S<&AR87-E.@!087-S<&AR87-E
M<R!C86X@;F]T(&)E(&5M<'1Y`%!A<W-P:')A<V5S(&1O(&YO="!M871C:`!0
M87-S=V]R9`!087-S=V]R9',@;75S="!M871C:"X`4&5R9F]R;2!-86EN=&5N
M86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\`4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C86X@;F]T
M(&)E(&-H86YG960N`%!E<G-O;F%L`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E
M<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!E
M<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)S;VYA
M;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@`%!E<G-O;F%L
M(%,O34E-12!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!0:&]N90!0;&%C
M92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_
M`%!L86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4`4&QA>2!S;W5N9"!O;B!N
M97<@;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O
M<G0@96UB961D960@<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I
M;F1O=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL(')E<75I
M<F4@82!P;'5G:6XN`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD
M97(Z`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!E;G1E<B!T
M:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W
M:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P
M97(@)7,@<V5S<VEO;BX`4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O
M<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D
M('1O(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N
M+@!0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U
M<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R!C;V]K:65S($%.1"!Y
M;W4@87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y
M;W4@=VEL;"!H879E('1O(&QO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN
M9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2!H
M:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N
M>2!I;F-O;G9E;FEE;F-E+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64N`%!L96%S92!R97-O;'9E(&%M8FEG
M=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E(')E=FEE=R!T:&4@
M9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T
M:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@82!F;VQD
M97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS+@!0;&5A<V4@<V5L
M96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L
M96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+@!0;&5A<V4@<V5L
M96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN`%!L96%S
M92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#H`4&]W
M97)E9"!B>2!(;W)D90!0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S
M:&5S("@G+2T@)RD_`%!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D
M+@!0<F5V:65W`%!R979I;W5S($UE<W-A9V4`4')E=FEO=7,@4&%G90!0<FEN
M=`!0<FEO<FET>0!0<FEV871E($ME>2!087-S=V]R9`!0<F]B;&5M($1E<V-R
M:7!T:6]N`%!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N
M=#L@9&5F875L="!T;R!.3P!0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM
M96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453`%!R;W1O8V]L.@!0=6)L:6,@
M4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+@!0=7)?
M9V4@1&5L971E9`!0=7)G92!$96QE=&5D`%!U<F=E($9O;&1E<BAS*0!0=7)G
M92!4<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O
M;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N`%!U<F=E(&]L
M9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/P!0=7)G:6YG("5D(&UE
M<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+@!0=7)G:6YG(#$@;65S<V%G92!F
M<F]M(%1R87-H(&9O;&1E<BX`475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F
M34(@("@E+C)F)24I`%%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250`
M475O=&$@<W1A='5S.B!.3R!,24U)5`!1=6]T:6YG("5F.@!295]Q=65S="!$
M96QI=F5R>2!#;VYF:7)M871I;VX`4F5C96EV960@3VX`4F5C96EV960@4VEN
M8V4`4F5C96EV960@56YT:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T
M($UE<W-A9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A
M:6QE9"X`4F5F<F5S:`!2969R97-H($9O;&1E<B!6:65W<SH`4F5L;V%D`%)E
M;&]A9"!6:65W`%)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E($UA:6QB;W@Z`%)E;6]V
M92!&:65L9"!&<F]M(%-E87)C:`!296UO=F4@<&%I<@!296UO=F4@<V]U<F-E
M`%)E;F%M92!&;VQD97(H<RD`4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@
M8F5G:6YN:6YG(&]F(&UO;G1H/P!296YA;6EN9R`B)7,B('1O("(E<R(@9F%I
M;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%)E<&Q?>2!T;R!,
M:7-T`%)E<&QA8V4@=VET:#H`4F5P;'D`4F5P;'D@4V5N="X`4F5P;'D@=&\@
M06QL`%)E<&QY('1O($%L;#H`4F5P;'D@=&\@3&ES=`!297!L>2!T;R!,:7-T
M.@!297!L>2!T;R!?06QL`%)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S
M86=E`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+@!2
M97!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E
M<&QY+51O`%)E<&QY+51O.B``4F5P;'DZ`%)E<&]R="!A<R!);FYO8V5N=`!2
M97!O<G0@87,@4W!A;0!297%U97-T(&$@7U)E860@4F5C96EP=`!297%U97-T
M(&1E;&EV97)Y(&-O;F9I<FUA=&EO;C\`4F5Q=65S="!R96%D(')E8V5I<'1S
M/P!297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N`%)E<75I<F5D(%!A<G1I
M8VEP86YT`%)E<V5T`%)E<W!O;F1E;G0@4W1A='5S(%5P9&%T960N`%)E<W5M
M90!297-U;64@>6]U<B!S97-S:6]N`%)E='5R;B!T;R`B365S<V%G92!#;VUP
M;W-I=&EO;B(`4F5T=7)N('1O($9E=&-H($UA:6P`4F5T=7)N('1O($]P=&EO
M;G,`4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I
M;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%)O;&4`4R]-24U%
M`%,O34E-12!%;F-R>7!T($UE<W-A9V4`4R]-24U%($5R<F]R.B``4R]-24U%
M($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@
M:V5Y+@!3+TU)344@3W!T:6]N<P!3+TU)344@4&%S<W!H<F%S92!);G!U=`!3
M+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+@!3+TU)344@4'5B;&EC($ME>2!F;W(@(B5S
M(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%,O34E-12!0=6)L:6,@2V5Y
M('-U8V-E<W-F=6QL>2!A9&1E9"X`4R]-24U%(%!U8FQI8R!+97ER:6YG`%,O
M34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E
M9"X`4R]-24U%(%-I9VX@365S<V%G90!3+TU)344@4VEG;B]%;F-R>7!T($UE
M<W-A9V4`4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T
M96TN`%,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@96YA8FQE9"!S
M;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+@!3+TU)
M344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@
M=&AI<R!S:6=N960@;65S<V%G92!C86X@;F]T(&)E(&1I<W!L87EE9"X`4R]-
M24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG
M;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4R]-24U%('-U<'!O
M<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U
M<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W
M:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@
M=&AE(%,O34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`
M4TU44`!37W5B:F5C=`!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S`%-A=F4`
M4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O
M;&1E<C\`4V%V92!$<F%F=`!3879E($EM86=E`%-A=F4@26UA9V4@:6X@1V%L
M;&5R>0!3879E($]P=&EO;G,`4V%V92!3=&%T:6]N97)Y`%-A=F4@7T1R869T
M`%-A=F4@87,`4V%V92!D<F%F=',@87,@=6YS965N/P!3879E(')E8VEP:65N
M=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_
M`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_`%-A=F4@<V5N="!M
M86EL/P!3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@)7,`4V5A<F-H`%-E87)C:"`E<P!396%R8V@@3W!T
M:6]N<P!396%R8V@@4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@06YO=&AE
M<B!!8V-O=6YT`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9FEE;&0`4V5L96-T
M(&$@<W1A=&EO;F5R>3H`4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O
M<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+@!396QE8W0@
M86QL`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!N;VYE`%-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M
M870Z`%-E;&5C="!T:&4@9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BX`
M4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E`%-E;&5C="!T:&4@=&EM92!F
M;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W1E9"!!
M9&1R97-S(&)O;VMS.@!396YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R`%-E
M;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E;F0@365S<V%G90!396YD(%!R;V)L
M96T@4F5P;W)T`%-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y
M('1H92!S96YD97(_`%-E;G0@;6%I;"!F;VQD97(`4V5N="!M86EL(&9O;&1E
M<CH`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N`%-E<G9E
M<CH`4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@
M;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+@!3970@=&AE(%@M4')I;W)I='D@
M:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/P!3:&%R92!&;VQD97)S
M`%-H87)E(&UA:6P@9F]L9&5R<P!3:&%R92!Y;W5R(&UA:6P@9F]L9&5R<R!W
M:71H(&]T:&5R('5S97)S+@!3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E
M9"!T97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@
M8F4@=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N`%-H;W5L
M9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@
M9F]R(%!'4"!D871A/P!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L
M;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=6QD('EO=7(@4$=0('!U
M8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D
M969A=6QT/P!3:&]W($%L;"!&;VQD97)S`%-H;W<@06QL($AE861E<G,`4VAO
M=R!$96QE=&5D`%-H;W<@3&EM:71E9"!(96%D97)S`%-H;W<@36%I;&EN9R!,
M:7-T($EN9F]R;6%T:6]N`%-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,`
M4VAO=R!5;G-U8G-C<FEB960`4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP
M<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/P!3:&]W(&QE9V5N
M9"!I;B!T:&4@;6%I;&)O>"!V:65W/P!3:&]W('!R979I97=S(&9O<B!U;G)E
M860@;65S<V%G97,@;VYL>3\`4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\`
M4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H92!M96YU8F%R/P!3:&]W
M('1H92!);6%G97,`4VAO=R!T:&4@9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B
M87(_`%-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O;&1E<C\`4VAO
M=VX`4VE?>F4`4VEG;F5D`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;W)T(&)Y
M($%R<FEV86P`4V]R="!B>2!$871E`%-O<G0@8GD@1G)O;2!!9&1R97-S`%-O
M<G0@8GD@365S<V%G92!3:7IE`%-O<G0@8GD@4W5B:F5C=`!3;W)T(&)Y(%1H
M<F5A9`!3;W)T(&)Y(%1O($%D9')E<W,`4W!A;2!F;VQD97(Z`%-P96-I86P@
M0VAA<F%C=&5R($EN<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5C:6%L(%9I
M<G1U86P@1F]L9&5R<R!C86X@;F]T(&)E(&5D:71E9"X`4W!E;&P@0VAE8VL`
M4W!E;&P@0VAE8VME<@!3<&5L;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E
M<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+@!3=&%R=`!3
M=&%T:6]N97)Y`%-T871I;VYE<GD@;F%M93H`4W1A=&EO;F5R>2!T>7!E.@!3
M=&%T:6]N97)Y.@!3=&%T=7,`4W1R:7`@071T86-H;65N=`!3=')I<"!L:6YE
M8G)E86MS/P!3=6)?:F5C=`!3=6)J96-T`%-U8FIE8W0@1FEE;&0`4W5B;6ET
M`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5C8V5S<P!3=6=G97-T:6]N<P!3
M=6UM87)Y`%-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0`4W=I=&-H('1O($A4
M34P@8V]M<&]S:71I;VX`4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I
M;VX`5&%S:W,`5&5?>'0`5&5N=&%T:79E.B``5&5N=&%T:79E;'D@06-C97!T
M(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5R;7,@;V8@4V5R=FEC
M92!F:6QE(&YO="!S<&5C:69I960@:6X@8V]N9BYP:'``5&5X=`!4:&4@1G)O
M;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z`%1H
M92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@
M875T:&5N=&EC871I;VX@;65T:&]D('-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C
M="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4:&4@36%C:6YT;W-H(')E
M<V]U<F-E(&9O<FL`5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(&-A;B!B
M92!D;W=N;&]A9&5D("5S+@!4:&4@86-C;W5N="`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!A8V-O=6YT("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!A
M='1A8VAM96YT('=A<R!N;W0@9F]U;F0N`%1H92!C86QE;F1A<B!D871A(&ES
M(&EN=F%L:60`5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@
M4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O
M<'5P('=I;F1O=W,_`%1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I
M;&4@87)E(&)E;&]W+@!4:&4@8W5R<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL
M(&)E(')E;F%M960@=&\@(B5S(BX`5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R
M<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T
M<FEE=F5D`%1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@(B5S(B!F
M;VQD97(N`%1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BX`
M5&AE(&9I96QD("(E<R(@8V%N)W0@8F4@97AP86YD960N`%1H92!F;VQD97(@
M(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L9&5R("(E<R(@8V]N=&%I;G,@
M:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@
M<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N
M;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!D96QE
M=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N`%1H
M92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@9&5L971E
M9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E
M<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@
M=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S
M('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!F;VQL;W=I;F<@
M9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z`%1H92!I;6%G92!S
M879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V
M92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H
M92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R
M(&ES('!R97-E;G0@:6X@>6]U<B!A9&1R97-S8F]O:RX`5&AE(&UA:6P@<V5R
M=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z`%1H
M92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA
M=&EO;F%L(&UE<W-A9V4Z`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE
M(&9O;&QO=VEN9R!M97-S86=E.@!4:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y
M(&5M<'1Y+@!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B`H)60@8GET97,I
M(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="X`5&AE(&UE<W-A9V4@8F5I;F<@
M8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG+@!4:&4@;65S<V%G
M92!H87,@8F5E;B!D96QE=&5D+@!4:&4@;65S<V%G92!H87,@8F5E;B!V97)I
M9FEE9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@
M)7,N`%1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E
M<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B;&]C:R!P;W!U
M<"!W:6YD;W=S/P!4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y
M(&-A;B!B92!V:65W960@)7,N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO
M="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!4:&4@<F5Q=65S
M=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM96YT
M+@!4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@
M365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@9G)O;2!Y;W4@=VAE
M;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S
M('1O('-E;F0@=&AE(&YO=&EF:6-A=&EO;B!M97-S86=E+@!4:&4@<V5R=F5R
M('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I
M;6%G92X`5&AE('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N`%1H
M92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"X`5&AE('-P
M96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X:7-T+@!4:&4@<W1A=&EO;F5R>2`B
M)7,B(&AA<R!B965N(&%D9&5D+@!4:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!S=&%T:6]N97)Y("(E<R(@:&%S(&)E96X@=7!D
M871E9"X`5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES
M="X`5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE(&UE
M<W-A9V4@8V%N(&)E('9I97=E9"`E<RX`5&AE('1E>'0@;V8@=&AE(')E='5R
M;F5D(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@
M8V%N(&)E('9I97=E9"`E<RX`5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G
M90!4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W960@
M)7,N`%1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E
M<W-F=6QL>2!S=&]R960N`%1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@;F\@
M;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+@!4:&5R92!I<R!N;R!T97AT('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E('=A<R!A('!R;V)L
M96T@97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4
M:&4@<V5R=F5R('-A:60Z("5S`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG
M:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@(B5S
M(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E
M('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD
M97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B
M)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H
M92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M
M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RX`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S
M86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G
M92!A<R!A(&1R869T+@!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R
M(&UE<W-A9V4Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M979E;G0Z("5S+@!4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@
M<&%R=`!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN
M(&ET+@!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN
M(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92!T:&ES.B``5&AI<R!0
M1U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N`%1H
M:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO
M="!Y970@:6UP;&5M96YT960N`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G
M92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+@!4:&ES(&UE<W-A9V4@8V]N
M=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S
M:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T
M=&%C:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN
M9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B!T:&ES(&UE<W-A9V4@:7,@
M=6YK;F]W;BX`5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z(`!4:&ES(&UE
M<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'
M4"!F;W)M870@*&%C8V]R9&EN9R!T;R!21D,@,C`Q-2DN`%1H:7,@;65S<V%G
M92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%
M(&9O<FUA="X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N
M960@=FEA(%!'4"X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S
M:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y
M<'1E9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP
M=&5D('=I=&@@4$=0+@!4:&ES(&UE<W-A9V4@=&\`5&AI<R!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RX`5&AR96%D($1I
M<W!L87D`5&AR96%D(%9I97<`5&ET;&4`5&\`5&\@061D<F5S<P!4;R!S96QE
M8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I('=H:6QE(&-L:6-K:6YG+@!4;R!U<V4@82!4
M3%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@
M;V8@4$A0(#4N,"XV(&]R(&AI9VAE<BX`5&]T86P@071T86-H;65N=',@4VEZ
M93H`5')A<V@@9F]L9&5R`%1R87-H(&9O;&1E<CH`55),`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!R971R:65V92!Q=6]T
M80!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%N
M<W=E<F5D`%5N86YS=V5R960@;65S<V%G97,`56YD96QE=&4`56YD:7-C;&]S
M960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`56YH86YD;&5D(&-O;7!O;F5N
M="!O9B!T>7!E.B`E<P!5;FMN;W=N($1A=&4`56YK;F]W;B!)34%0(')E<W!O
M;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,`56YK
M;F]W;B!-965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N;&]A9"!087-S<&AR
M87-E`%5N;F%M960`56YS965N`%5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I
M`%5P9&%T92!!='1A8VAM96YT($EN9F]R;6%T:6]N`%5P9&%T92!R97-P;VYD
M96YT('-T871U<P!5<&QO860`57-E($1E9F%U;'0@5F%L=64`57-E($E-05`@
M9F]L9&5R('-U8G-C<FEP=&EO;G,_`%5S92!6:7)T=6%L(%1R87-H($9O;&1E
M<C\`57-E<@!5<V5R("(E<R(@<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C
M:69I960@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(N`%5S97)N86UE`%5S
M97)N86UE.@!5<V5R<R!I;B!T:&4@<WES=&5M.@!6:65W`%9I97<@)7,`5FEE
M=R`E<R!0=6)L:6,@2V5Y`%9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W`%9I97<@365S<V%G97,`5FEE=R!097)S;VYA;"!0<FEV871E
M($ME>0!6:65W(%!E<G-O;F%L(%!U8FQI8R!+97D`5FEE=R!4:')E860`5FEE
M=R!4:'5M8FYA:6P`5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN
M9&]W`%9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W(&5V
M96YT`%9I97<@;65S<V%G97,@:6X@)7,`5FEE=R!O<B!M86EL8F]X('1O(&1I
M<W!L87D@869T97(@;&]G:6XZ`%9I97<@=&%S:P!6:65W('1H92!);6%G97,`
M5FER='5A;"!&;VQD97(@(B5S(B!C<F5A=&5D('-U8V-E<V9U;&QY+@!6:7)T
M=6%L($9O;&1E<G,`5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"X`
M5FER='5A;"!)3D)/6`!6:7)T=6%L($E.0D]8($9O;&1E<@!6:7)T=6%L(%1R
M87-H`%9I<G1U86P@5')A<V@@1F]L9&5R`%9I<G1U86P@9F]L9&5R(&QA8F5L
M`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5VAA
M="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@
M:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@;W(@:6YN;V-E;G0_`%=H96X@
M9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O
M;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@=&AE;2!A<R!D96QE=&5D/P!7:&5N
M(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N
M="!T;R!S=&%R="!O;C\`5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@
M=V4@<V%V92!A='1A8VAM96YT(&1A=&$_`%=H96X@<V5N9&EN9R!M86EL(&]R
M(&5X<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A
M<'!E;F0@=&\@=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S
M97,@=VET:&]U="`B0"(I/P!7:&ET96QI<W0`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`65D`665A<FQY`%EE<P!9;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M
M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O=6YT*',I.@!9;W4@87)E(&%T
M=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@
M=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN`%EO=2!A<F4@871T96UP=&EN9R!T
M;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN`%EO=2!A<F4@8V]P
M>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+@!9;W4@87)E(&-R96%T:6YG
M(&$@<W5B+69O;&1E<B!T;R``66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E
M;"!F;VQD97(N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E
M<G,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!F;VQD97)S+@!9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z(`!9;W4@
M8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M("(E<R(N`%EO=2!C86X@=7-E('1H
M92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&EN('1H92!S=&%T:6]N97)Y('1E
M>'0Z("5C(&9O<B!T:&4@8W5R<F5N="!M97-S86=E(&-O;G1E;G0[("5S(&9O
M<B!T:&4@<VEG;F%T=7)E+@!9;W4@9&ED(&YO="!A9W)E92!T;R!T:&4@5&5R
M;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O('EO=2!W97)E(&YO="!A;&QO
M=V5D('1O(&QO9VEN+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C
M:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R`%EO=2!F;W)W87)D960@=&AI
M<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z
M("5S+@!9;W4@:&%V92`E<R!N97<@;65S<V%G97,N`%EO=2!H879E(#$@;F5W
M(&UE<W-A9V4N`%EO=2!H879E(&%L<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G
M92X`66]U(&AA=F4@870@;&5A<W0@;VYE(&%T=&%C:&UE;G0@<V5L96-T960@
M=&AA="!Y;W4@9&ED;B=T('5P;&]A9"!Y970N($%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!S96YD('1H:7,@;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C
M:&UE;G1S/P!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<CH`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD
M97)S.@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@
M870@;&5A<W0@;VYE(')E8VEP:65N="X`66]U(&UU<W0@96YT97(@=&AE('!A
M<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI
M<R!M97-S86=E`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y
M;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9
M;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="X`66]U(&UU
M<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<V5L96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A="!L
M96%S="!O;F4@;65S<V%G92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E
M8VEP:65N="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92X`66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@9FEL92!T;R!A='1A
M8V@N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&YE960@=&\@:&%V92`B)7,B(&5N86)L960@:6X@>6]U<B!M86EN=&5N86YC
M92!O<'1I;VYS+@!9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@
M;VX@)25S+@!9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N`%EO
M=2!W97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N($AE<F4@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M
M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@
M<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S(@!9;W4@=V5R92!S=6-C
M97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(@!9;W5R($YA;64`66]U
M<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<P!9;W5R(%!R:79A=&4@2V5Y`%EO
M=7(@4'5B;&EC($ME>0!9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P
M=&EO;F%L*3PO96T^`%EO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I
M9FEC871E<P!9;W5R(&%C8V]U;G1S.@!9;W5R(&%L:6%S(&%D9')E<W-E<SH@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI
M;F4I/"]E;3X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM
M86=E('1Y<&4N`%EO=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE
M<W-A9V5S.@!9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E
M;F1I;F<@;65S<V%G97,Z`%EO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY
M(&1E;&EV97)E9"X`66]U<B!S:6=N871U<F4Z`%M.;R!3=6)J96-T70!;4')O
M8FQE;2!297!O<G1=`%]"8V,`7T)L86-K;&ES=`!?0V,`7T1E;&5T90!?1F]L
M9&5R<P!?261E;G1I='D`7TEN8F]X`%],;V<@;W5T`%]-97-S86=E(%-O=7)C
M90!?3F5W($UE<W-A9V4`7U!R:6YT`%]0<FEO<FET>0!?4F5F<F5S:"`E<P!?
M4F5P;'D`7U-E87)C:`!?4V5N9"!-97-S86=E`%]4:')E860`7U1O`%]5;F1E
M;&5T90!?5FEE=R!4:')E860`7U=H:71E;&ES=`!A9&1R97-S964@=6YK;F]W
M;@!A='1A8VAM96YT`&%T=&%C:&UE;G1S+GII<`!B>71E<P!C86YN;W0@8W)E
M871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-O;6UA;F0@;&EN
M92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y
M<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`96YT<GD@;F]T
M(&9O=6YD`&9R;VT`:&]S="!N86UE('5N:VYO=VX`:6YP=70O;W5T<'5T(&5R
M<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&ME>0!M86EL8F]X(&9I;&4`
M;F%M90!N;VYE`&]R`'!E<FUI<W-I;VX@9&5N:65D`')E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;`!S97)V:6-E('5N879A:6QA8FQE`'-P96QL:6YG(&5R<F]R
M`'-P96QL:6YG(&5R<F]R<P!S>7-T96T@97)R;W(`=&5M<&]R87)Y(&9A:6QU
M<F4`>6]U<B!B;&%C:VQI<W0`>6]U<B!W:&ET96QI<W0`4')O:F5C="U)9"U6
M97)S:6]N.B!)35`@-"XQ+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,3`M,#D@,3,Z
M,C8K,#(P,`I,87-T+51R86YS;&%T;W(Z($)R:6%N(%1R=65L<V5N(#QH;W)D
M92MI,3AN0&)R:6%N=')U96QS96XN9&L^"DQA;F=U86=E+51E86TZ($1A;FES
M:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`@("`@($-C.B``("`@
M("`@5&EL.B``("`@($1A=&\Z(``@("`@1G)A.B``("A!8V-E<W-K97D@)7,I
M`"!%;6YE.B``(&D@`",`)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0`E9"!B
M97-K961E<@`E9"!B97-K961E<B!E<B!B;&5V970@<VQE='1E="X`)60@8F5S
M:V5D97(@97(@8FQE=F5T('-E;F1T(&EN9"!S;VT@96HM<W!A;2!T:6P@9&EN
M('-Y<W1E;6%D;6EN:7-T<F%T;W(N`"5D(&)E<VME9&5R(&5R(&)L979E="!I
M;F1B97)E='1E="!S;VT@<W!A;2X`)60@8F5S:V5D97(@97(@8FQE=F5T(&EN
M9&)E<F5T=&5T('-O;2!S<&%M('1I;"!D:6X@<WES=&5M861M:6YI<W1R871O
M<BX`)60@8F5S:V5D97(@97(@8FQE=F5T(&EN9&)E<F5T=&5T('-O;2!S<&%M
M+@`E9"!T:6P@)60@868@)60@8F5S:V5D97(`)7,@2T(`)7,@5F5D;&EG96AO
M;&1E;'-E("T@0F5K<N9F=&5L<V4`)7,@9FEN9&5S(&%L;&5R961E+B!-87!P
M96X@)7,@8FQE=B!I:VME(&]M9/AB="X`)7,@<WEN97,@:6MK92!A="!VYG)E
M(&5N(&=Y;&1I9R!B<F5V8F%K:V4N`$UA<'!E;B`E<R!V:6P@8FQI=F4@;VUD
M^&)T(&D@<W1A<G1E;B!A9B!H=F5R(&WE;F5D+@`E<R!H87(@86-C97!T97)E
M="X`)7,@:&%R(&%F;'ES="`E<RX`)7,@:&%R(&[F9W1E="X`)7,@:&%R('-V
M87)E="!PY2!E;B!L961I9R]O<'1A9V5T+6%N;6]D;FEN9RX`)7,@:&%R('-V
M87)E="!PY2!I;G9I=&%T:6]N('1I;"`E<RX`)7,@:&%R('-E;F1T(&QE9&EG
M+V]P=&%G970M:6YF;W)M871I;VX@=&EL(&1I9RX`)7,@:&%R(&%C8V5P=&5R
M970@=&5N=&%T:79T+@`E<R!A;FUO9&5R(&]M(&1I;F4@;&5D:6<O;W!T86=E
M="UI;F9O<FUA=&EO;F5R+@`E<R!A;FUO9&5R(&]M(&1I;B!T:6QS=&5D97;F
M<F5L<V4@9&5N("5S+@`E<R!E<B!S=6-C97-F=6QD="!B;&5V970@=&EL9OAJ
M970@=&EL("(E<R(N`"5S(/AN<VME<B!A="!J=7-T97)E("5S+@`E<R#X;G-K
M97(@870@9_AR92!D:6<@;W!MYG)K<V]M('#E("5S+@`E<R#X;G-K97(@870@
M;6]D=&%G92!S96YE<W1E(&EN9F]R;6%T:6]N(&]M("5S+@`E<SH@)7,`)7,Z
M("5S("@E9"9N8G-P.V%F)FYB<W`[)60I`"A';V1K96YD(.9N9')I;F=E<FYE
M(&]G(&?E('1I;"!NYG-T92!S:^9R;2XI`"A!;FYU;&QE<B!A;&QE(.9N9')I
M;F=E<B!O9R!GY2!T:6QB86=E('1I;"!S:W)I=FYI;F<@868@8F5S:V5D97(N
M*0`H2%1-3"D`*%)E;B!T96MS="D`*$?E('1I;&)A9V4@=&EL('-K<FEV;FEN
M9R!A9B!B97-K960@969T97(@870@:&%V92!G96UT(.9N9')I;F=E<B!L879E
M="!I;F1T:6P@;G4N(,9N9')I;F=E<B!PY2!D96X@86MT=65L;&4@<VED92!V
M:6P@:6MK92!B;&EV92!G96UT+BD`*%-E;F0@8F5S:V5D(&5F=&5R(&%T(&AA
M=F4@9V5M="#F;F1R:6YG97(@;&%V970@:6YD=&EL(&YU+B#&;F1R:6YG97(@
M<.4@9&5N(&%K='5E;&QE('-I9&4@=FEL(&EK:V4@8FQI=F4@9V5M="XI`"H@
M5&EL9OAJ(&1I<W-E('9E9"!A="!C;&EC:V4@3TL@*@`J(%;F;&<@=F5N;&EG
M<W0@861R97-S92AR*2`J`#$@8F5S:V5D(&5R(&)L979E="!S;&5T=&5T+@`Q
M(&)E<VME9"!E<B!B;&5V970@:6YD8F5R971T970@<V]M(&5J+7-P86T@=&EL
M(&1I;B!S>7-T96UA9&UI;FES=')A=&]R+@`Q(&)E<VME9"!E<B!B;&5V970@
M:6YD8F5R971T970@<V]M(&5J+7-P86TN`#$@8F5S:V5D(&5R(&)L979E="!I
M;F1B97)E='1E="!S;VT@<W!A;2!T:6P@9&EN('-Y<W1E;6%D;6EN:7-T<F%T
M;W(N`#$@8F5S:V5D(&5R(&)L979E="!I;F1B97)E='1E="!S;VT@<W!A;2X`
M,3`P('1E9VX`,3`P,"!T96=N`#(T('1I;65R`#(U,"!T96=N`#4P,"!T96=N
M`$5T('-T;W(@8FEL;&5D92!B96[F=FYT("5S(&5R(&CF9G1E="!V960@9&5N
M;F4@8F5S:V5D+@!%;B!B97-K960L('-O;2!D=2!H87(@<V5N9'0L(&AA<B!R
M97-U;'1E<F5T(&D@(G)E='5R;B!N;W1I9FEC871I;VXB(&9R82!M;V1T86=E
M<F5N+@!!32]030!/1P!!8V-E<'3I<B!A;FUO9&YI;F<`06-C97!TZ7(@86YM
M;V1N:6YG(&]G('1I;&;X:B!T:6P@:V%L96YD97(`06-C97!T97)E=`!!8V-E
M<'1E<F5T.B``3F%V;B!PY2!K;VYT;SH`2&%N9&QI;F=E<@!4:6QF^&H@)7,@
M=&EL(&UI="!A9')E<W-E:V%R=&]T96L`3W!R971T92!E;B!N>2!B<G5G97(Z
M`$]P<F5T('!A<@!4:6QF^&H@:VEL9&4`1OAJ('1I;"!K86QE;F1E<@!/<')E
M="!B<G5G97(`5&EL9OAJ970@(B5S(B!S;VT@=F5D:.9F=&5L<V4N`$]P<F5T
M=&5L<V4@868@8G)U9V5R92!E<B!S;.5E="!F<F$`661E<FQI9V5R92!F96QT
M97(@9&5R('9I<V5S('5N9&5R(&SF<VYI;F<Z(#QE;3XH=F%L9V9R:2P@970@
M9F5L="!P<BX@;&EN:64I/"]E;3X`661E<FQI9V5R92!I;F9O<FUA=&EO;B!K
M86X@<V5S("5S+@!99&5R;&EG97)E(&)E<VME9"UD971A:6QE<@!99&5R;&EG
M97)E(&)E<VME9"UD971A;&IE<@!99&5R;&EG97)E(&)E<VME9"UD971A;&IE
M<B!K86X@<V5S("5S+@!99&5R;&EG97)E(&1E=&%L:F5R(&]M(&)E<VME9"UF
M96IL`%ED97)L:6=E<F4@9&5T86QJ97(@;VT@8F5S:V5D+69E:FP@8V%N('-E
M<R`E<RX`061R97-S90!!9')E<W-E:V%R=&]T96L`061R97-S96MA<G1O=&5K
M97(`0D-#(&%L;&4@8F5S:V5D97(@=&EL(&1I<W-E(&%D<F5S<V5R.B`\96T^
M*'9A;&=F<FDL(.EN(&%D<F5S<V4@<'(N(&QI;FEE*3PO96T^`$%D<F5S<V5R
M+"!S;VT@96MS<&QI8VET(&MN>71T97,@=&EL(&1E;FYE(&ED96YT:71E=#H@
M/&5M/BAV86QG9G)I+"#I;B!A9')E<W-E('!R+B!L:6YI92D\+V5M/@!!9&UI
M;FES=')A=&EO;@!+86QD96YA=FX`06QL90!!;&QE(&)E<VME9&5R(&D@9&4@
M9OAL9V5N9&4@;6%P<&4H<BD@=FEL(&)L:79E(&=E;70@:2!E;B!E;FME;'0@
M34)/6"!F:6PZ`$%L;&4@8F5S:V5D97(@:2!D:6X@(B5S(B!M87!P92P@<V]M
M(&5R(.9L9')E(&5N9"`E<R!D86=E('9I;"!B;&EV92!S;&5T=&5T+@!!;&QE
M(&=A;6QE(')E9F5R97)E9&4@=F5D:.9F=&5L<V5R+"!D97(@97(@YFQD<F4@
M96YD("5S(&WE;F5D97(@=FEL(&)L:79E('-L971T970N`$%L;&4@9V%M;&4@
M<V5N9'1E(&)E<VME9&5R+"!D97(@97(@YFQD<F4@96YD("5S(&WE;F5D97(@
M=FEL(&)L:79E('-L971T970N`$%L;&4@<F5T=&EG:&5D97(@=&EL(&UA<'!E
M;B`B)7,B(&5R(&)L978@9FIE<FYE="!F;W(@8G)U9V5R("(E<R(N`%1I;&QA
M9"!O<')E='1E;'-E(&%F(&UA<'!E<C\`5&EL;&%D(&%T(&9I;'1E<BUR96=L
M97(@<.5F^')E<R!V:6QKY7)L:6=E(&)R979B86MK97(_`$%L=&5R;F%T:79E
M(&1E;&4@=&EL(&1E='1E(&%F<VYI=#H`06QT:60`1V5M(&%L=&ED('9E9&CF
M9G1E;'-E<BX`16X@9F5J;"!O<'-T;V0@=6YD97(@9F]R<_AG970@<.4@870@
M<VMRYFQL92!V961HYF9T96QS96X@868N($E-05`M<V5R=F5R96X@;65L9'1E
M.B``1&5R('-K971E(&5N('5K96YD="!F96IL('5N9&5R('1I;&;X:F5L<V5N
M(&%F(&1E="!N>64@;F]T:71S+@!$97(@<VME=&4@96X@=6ME;F1T(&9E:FP@
M=6YD97(@=&EL9OAJ96QS96X@868@9&5T(&YY92!O<&=A=F4N`$)E<W9A<F5T
M`$)E<W9A<F5D92!B97-K961E<@!0Y6;X<B!F:6QT<F4`4.5F^'(@(B5S(B!F
M:6QT<F4`4.5F^'(@9FEL=')E+"!NY7(@9'4@;&]G9V5R(&EN9"X`4.5F^'(@
M9FEL=&5R<F5G;&5R+"!NY7(@9&EN(&EN9&)A:VME(&)L:79E<B!V:7-T+@!%
M<B!D=2!S:6MK97(@<.4L(&%T(&1U('9I;"!S;&5T=&4@9&5N;F4@;V9F96YT
M;&EG92!N^&=L93\`17(@9'4@<VEK:V5R('#E+"!A="!D=2!V:6P@<VQE='1E
M(&1I="!N^&=L97!A<C\@*$1E='1E(&MA;B!)2TM%(&%N8F5F86QE<R$I`$5R
M(&1U(%-)2TM%4BP@870@9'4@=FEL(&9O<G1SYG1T93\`17(@9'4@<VEK:V5R
M+"!A="!D=2!V:6P@<VQE='1E(&1I<W-E(&)E<VME9&5R/P!%<B!D=2!S:6MK
M97(L(&%T(&1U('9I;"!015)-04Y%3E0@<VQE='1E(&1E;FYE('9E9&CF9G1E
M;'-E<C\`17(@9'4@<VEK:V5R+"!A="!D=2!V:6P@=/AM;64@9&5N;F4@;6%P
M<&4_`$5R(&1U('-I:VME<BP@870@9'4@=FEL('3X;6UE(&1I;B!S<&%M+6UA
M<'!E/P!%<B!D=2!S:6MK97(L(&%T(&1U('9I;"!T^&UM92!D:6X@<VMR86QD
M97-P86YD/P!%<B!D=2!S:6MK97(@<.4L(&%T(&1U('9I;"!S;&5T=&4@9&ES
M<V4@8F5S:V5D97(@<&5R;6%N96YT/P!%<B!D=2!S:6MK97(L(&%T(&1U('9I
M;"!I;F1R87!P;W)T97)E(&1E;FYE(&)E<VME9"!S;VT@:&%R;6SX<S\`17(@
M9'4@<VEK:V5R+"!A="!D=2!V:6P@:6YD8F5R971T970@9&5N;F4@8F5S:V5D
M('-O;2!S<&%M/P!-;V1T86=E=`!3=&EG96YD90!3</AR9P!6961HYF9T`%9E
M9&CF9G0@9FEL97(`2.9F="!E;B!K;W!I(&%F(&1I;B!O9F9E;G1L:6=E(%!'
M4"UN^&=L92!V960@9&EN(&)E<VME9#\`5F5D:.9F=&5T(&9I;#H`4W3X<G)E
M;'-E(&%F(&9I;&5N("(E<R(@;W9E<G-T:6=E<B!B96=RYFYS;FEN9V5N+B!&
M:6QE;B!)2TM%('9E9&CF9G1E="X`1&5R(&5R('9E9&CF9G1E="!E="!S=F%R
M('1I;"!E;B!K86QE;F1E<BUA;FUO9&YI;F<L('-O;2!D=2!H87(@<V5N9'0N
M`%9E9&CF9G1E;'-E`%9E9&CF9G1E;'-E;B!T86=E="!A9CH@3W!R:6YD96QI
M9R!T>7!E(&%F('9E9&CF;F<`5F5D:.9F=&5L<V5R`$1E;'1A9V5R90!"96WF
M<FL`075T:%]I;7`Z($MRYG9E="!)34%0('5D=FED9&5L<V4@:6MK92!F=6YD
M970N`%-K86P@8FEL;&5D97(@:2!(5$U,+6)E<VME9&5R('9I<V5S(&%U=&]M
M871I<VLL(&AV:7,@869S96YD97)E;B!S=.5R(&D@;6ET(&%D<F5S<V5K87)T
M;W1E:S\`061R97-S96MA<G1O=&5K97(L(&1E<B!S=.5R('1I;"!RY61I9VAE
M9#H`1F5L=&5R('1I;"!RY61I9VAE9#H`069V96YT97(@<F5A:W1I;VX`5&EL
M8F%G92!T:6P@)7,`5&EL8F%G92!T:6P@)7,`5&EL8F%G92!T:6P@;W9E<G-I
M9W1S=FES;FEN9P!4:6QB86=E('1I;"!T<N5D+79I<VYI;F<`1.5R;&EG(&5L
M;&5R(')I;F=E(&9O<FUU;&5R970@86YM;V1N:6YG+B!397)V97)E;B!R96%G
M97)E9&4@;65D.B`E<P!"8V,`3F5D96YF;W(@9F]R969I;F1E<R!RY71E:W-T
M96X@868@<W1A='5S(&)E<VME9&5N+@!&^&1S96QS9&%G`$)L86-K;&ES=&4`
M0FQO:^ER(&)I;&QE9&5R(&D@2%1-3"UB97-K961E<B!M960@;6EN9')E(&1E
M(&%N;6]D97,@<W!E8VEF:6MT/P!"97-K960`0F5G9V4`0N5D92!B97-K961E
M;G,@9F5L="UL:7-T92!O9R!B<OAD=&5K<W0`5&5G;G/F=`!+86QE;F1E<@!+
M=6YN92!I:VME(&;E(&9O<F)I;F1E;'-E('1I;"!M86EL+7-E<G9E<F5N+@!+
M86X@:6MK92!F;W)B:6YD92!T:6P@9FIE<FX@;6%I;"US97)V97(Z(`!+86X@
M:6MK92!V:7-E<R`M(&AA<B!K=6X@9G5N9&5R("5S(&%F("5S(&1E;&4@868@
M9&5N;F4@8F5S:V5D(&D@9&5N(&%K='5E;&QE(&)R979B86MK92X`06YN=6QL
M97(`06YN=6QL97(@8F5S:V5D`$%F8G)Y9"!R97!O<G1E<FEN9R!A9B!P<F]B
M;&5M`$AV:7,@9'4@86YN=6QL97)E<B!D96YN92!B97-K960L(&UI<W1E<B!D
M=2!I;F1H;VQD970@<&5R;6%N96YT+@!#8P!-;V)I;`!);7!O<G0@868@8V5R
M=&EF:6MA="!I:VME(&UU;&EG+B!(96YT;FEN9R!A9B!F:6QE<B!E<B!I:VME
M('-LY65T('1I;"!PY2!D96YN92!S97)V97(N`$WX9&5L961E<@#&;F1R90#&
M;F1R92!A;&QE`%-K:69T(&UA<'!E`$AE<B!K86X@9'4@YFYD<F4@;>5D96X@
M9&EN92!B97-K961E<B!B;&EV97(@=FES="!PY2P@<V]M(&8N96MS+B!H=F]R
M(&UA;F=E(&)E<VME9&5R(&1E<B!V:7-E<R!PY2!H=F5R('-I9&4L('-A;70@
M:'9O<F1A;B!D92!S;W)T97)E<RX`2&5R(&MA;B!D=2#F;F1R92!O<'/F=&YI
M;F=E;B!T:6P@;6%I;'-E<G9E<B!O9R!M87!P97(N`$AE<B!K86X@9'4@YFYD
M<F4@;F%V;BP@861R97-S92!O9R!D96X@<VEG;F%T=7(L('-O;2!A;F1R92!S
M97(L(&[E<B!D92!LYG-E<B!O9R!S=F%R97(@<.4@9&EN92!E+6UA:6PN`%1E
M9VX@=&EL('9I<VYI;F<Z`$MO;G1R;VQL97(@;6%P<&4H<BD@9F]R(&YY92!E
M+6UA:6P`2&%K(&%L;&4O:6YG96X@868`2&%R(&%L;&4@;6%I;"US97)V97)E
M;BP@<V]M(&1U('9I;"!H96YT92!E+6UA:6P@9G)A+"!A9CH`2V]N=')O;&SI
M<B!S=&%V;FEN9R!F^'(@869S96YD96QS92!A9B!B97-K960_`%;F;&<@:&%N
M9&QI;F<Z`%;F;&<@;6%I;"US97)V97(Z`%;F;&<@96X@<&%S;FEN9R!E;&QE
M<B!R970@861R97-S96X@=&EL(&CX:G)E.@!6YFQG(&AA;F1L:6YG.@!6YFQG
M(&1E;B!A9')E<W-E:V%R=&]T96LL('-O;2!D97(@<VMA;"!K=6YN92!T:6QF
M^&IE<R!A9')E<W-E<B!T:6PN`%;F;&<@9&5N('+F:VME9OAL9V4@<V]M(&%D
M<F5S<V5K87)T;W1E:V5R(&)L:79E<B!G96YN96US^&=T(&DL(&[E<B!D=2!S
M;.5R(&%D<F5S<V5R(&]P+@!#;&EC:R`E<R!F;W(@870@;VUSYG1T92!B:6QL
M961F:6QE;B!T:6P@970@9F]R;6%T+"!S;VT@9&EN(&)R;W=S97(@:V%N('9I
M<V4N`$-L:6-K("5S(&9O<B!A="!H96YT92!B:6QL961E="X`0VQI8VL@)7,@
M9F]R(&%T(&MO;6UE('1I;"`E<R!V961L:6=E:&]L9&5L<V5S<VED96XN`$-L
M:6-K("5S(&9O<B!A="!S92!(5$U,(&EN9&AO;&0@:2!E="!S97!A<F%T('9I
M;F1U92X`0VQI8VL@)7,@9F]R(&%T('-E(&5N(&9R:6WF<FME=61G879E(&%F
M(&)I;&QE9&5T+@!#;&EC:R`E<R!F;W(@870@<V4@=F5D:.9F=&5L<V5N(&D@
M970@<V5P87)A="!V:6YD=64N`$-L:6-K("5S(&9O<B!A="!S92!D96YN92`\
M96T^;75L=&EP87)T+W)E;&%T960\+V5M/B!D96P@:2!E="!S97!A<F%T('9I
M;F1U92X`0VQI8VL@:&5R(&9O<B!A="!625-%(&)I;&QE9&5R;F4`2VQI:R!P
MY2!E;B!A9B!D92!V86QG=&4@861R97-S96MA<G1O=&5K97(@;V<@=N9L9R!D
M92!F96QT97(L(&1E<B!S:V%L('/X9V5S(&DN`$-L:6-K(&9O<B!A="!G96UM
M92!O9F9E;G1L:6<@4$=0+6[X9VQE(&D@9&ET(&%D<F5S<V5K87)T;W1E:P!#
M;&EC:R!F;W(@870@9V5M;64@4R]-24U%+6-E<G1I9FEK870@9F]R("5S(&D@
M9&ET(&%D<F5S<V5K87)T;W1E:P!3:W)I=B!E="!N>70@8G)E=B!T:6P@869S
M96YD97)E;B!V960@870@8VQI8VME('#E(&%D<F5S<V5N`$)E<VME9&5N('9I
M;"!B;&EV97(@Y6)N970@=&EL(&SF<VYI;F<@=F5D(&%T(&-L:6-K92!PY2!A
M9')E<W-E;@!,=6L`3'5K('9I;F1U90!,=6L@=FEN9'5E`$QU:VME="!M87!P
M90!,=6L@86QL90!,=6L@86QL90!,=6L@86QL92!M87!P97(`3'5K(&UA<'!E
M`$9A<G9E:6YD:6MA=&]R.B``2V]M;65N=&%R`$9I<FUA`$%F<VQU='1E=`!3
M:W)I=B!E;B!A;F1E;B!B97-K960`4VMR:78@8F5S:V5D97(@:2!E="!S97!E
M<F%T('9I;F1U93\`4VMR:79E(&)E<VME9&5R(&UE9"!E;B!(5$U,+7-N:71F
M;&%D92!S;VT@<W1A;F1A<F0@*&)R;W=S97(@<VMA;"!U;F1E<G-T^'1T92!M
M=6QI9VAE9&5N*3\`26YD<W1I;"!H=F]R9&%N(&)E<VME9&5R('-K86P@=FES
M97,N`$MO;F9I9W5RZ7(@92UM86EL+6=L:6UT(&EN9'-T:6QL:6YG97(N`$)E
M:W+F9G0@:V]D96]R9`!&;W)B:6YD96QS96X@8FQE=B!A9F)R=61T(&%F($E-
M05`M<V5R=F5R+@!&;W)B:6YD96QS92!T:6P@<V5R=F5R(&9E:FQE9&4`2V]N
M=')O;&SI<B!01U`M=6YD97)S=/AT=&5L<V4@9F]R("5S+@!+;VYT<F]L;.ER
M(%,O34E-12!U;F1E<G-T^'1T96QS92!F;W(@)7,N`$MO;G1R;VQLZ7(@:6YD
M<W1I;&QI;F=E<B!V961R^')E;F1E('/X9VYI;F<@868@8F5S:V5D97(N`$EN
M9'-T:6P@:'9O<F[E<B!D97(@8VAE8VME<R!F;W(@;GEE(&UA:6PL('-A;70@
M;VT@;V<@:'9O<F1A;B!D=2!S:V%L(&]P;>9R:W-O;2!PY2!N>64@8F5S:V5D
M97(N`$]M<^9T('1E:W-T+3QE;3YS;6EL97ES/"]E;3X@=&EL(&=R869I<VME
M/P!+;W!I97(`2V]P:>ER('1I;"!M87!P90!+;W)R:6=E<@!+;W)R:6=E<F5T
M('1E:W-T`$MU;FYE(&EK:V4@9G5L9&;X<F4@86YM;V1N:6YG+B#%<G-A9SH@
M)7,`2W5N;F4@:6MK92!O<')E='1E(#QE;3Y61E,@8F%C:V5N9#H\+V5M/B`E
M<P!+=6YN92!I:VME('-L971T92!B97-K961E<B!F<F$@(B5S(BX@4V5R=F5R
M96X@;65L9'1E.B`E<P!+=6YN92!I:VME('5D9OAR92!V961L:6=E:&]L9&5L
M<V5S;W!G879E<BX`2W5N;F4@:6MK92!U9&1R86=E(&1E;B!A;FUO9&5D92!F
M:6P@9G)A($U3+51.148M=F5D:.9F=&5L<V5N+@!+=6YN92!I:VME('5D9')A
M9V4@9&5N(&%N;6]D961E(&9I;&4@9G)A(%II<"UA<FMI=F5T+@!+=6YN92!I
M:VME(.5B;F4@;6]D=6P@=&EL('9E9&QI9V5H;VQD96QS92`E<P!+=6YN92!I
M:VME(&EN9&AE;G1E(#QE;3YN86UE<W!A8V4\+V5M/BUI;F9O<FUA=&EO;B!F
M<F$@24U!4"US97)V97)E;BX`3W!R970`3W!R970@;6%P<&4`3W!R970@;OAG
M;&5R`$]P<F5T('9I<G1U96P@;6%P<&4`3W!R970@96X@;GD@:V]N=&\`3W!R
M970@96X@;GD@<W!A;2UM87!P90!/<')E="!E;B!N>2!M87!P92!T:6P@:VQA
M9&1E<@!/<')E="!E;B!N>2!M87!P92!T:6P@869S96YD=&4@8F5S:V5D97(`
M3W!R970@96X@;GD@<VMR86QD97-P86YD('1I;"!S;&5T=&5D92!B97-K961E
M<@!/<')E="!F:6QT97)R96=L97(@9&5R('-O<G1E<F5R(&YY92!E+6UA:6QS
M+"!F;'ET=&5R(&1E;2!I(&UA<'!E<B!O9R!S;&5T=&5R(%-004TN`$]P<F5T
M(&5N(&YY="!B<F5V<&%P:7(`3W!R970@8G)E=G!A<&ER(&]G(&9O<FUU;&%R
M+7-V87(N`$%K='5E;"!A9&=A;F<@=&EL("5S`%1I;')E="!K;VYT:2!T:6P@
M:&5N=&YI;F<@868@92UM86EL(&9R82!A;F1R92!K;VYT:2X`5&EL<&%S(&AV
M;W)D86X@9'4@<V5N9&5R(&4M;6%I;"X`5&EL<&%S(&]P9V%V97(L(&1E<B!B
M;&EV97(@=61F^')T+"!NY7(@9'4@;&]G9V5R(&EN9"!I("5S+@!$1`!$86=L
M:6<`1&%T;P!$871O`$%F=FES=`!!9G9I<W0Z(`!3=&%N9&%R9`!3=&%N9&%R
M9"UI9&5N=&ET970`4W1A;F1A<F0@<_AG969E;'0`4W1A;F1A<F1K<FET97)I
M92!F;W(@<V]R=&5R:6YG.@!-Y61E;BP@9&5R('-K86P@<V]R=&5R97,@<.4Z
M`$1E;&5G97)E=`!3;&5T`%-L970@)7,@;V9F96YT;&EG92!N^&=L90!3;&5T
M(&%K='5E;"!N^&=L90!3;&5T(&UA<'!E*'(I`%-L970@=F%L9W1E(&UA<'!E
M<@!3;&5T(&)R979P87!I<@!3;&5T('9I<G1U96P@;6%P<&4`4VQE="!H96YT
M961E(&)E<VME9&5R(&9R82!F:F5R;B!S97)V97(_`%-L970@9G)A(&UI;B!K
M86QE;F1E<@!3;&5T(&=A;6QE(')E9F5R97)E9&4@=F5D:.9F=&5L<V5R(&D@
M<W1A<G1E;B!A9B!MY6YE9&5N/P!3;&5T(&=A;6QE(&UA<'!E<B!F;W(@869S
M96YD=&4@8F5S:V5D97(@:2!S=&%R=&5N(&%F(&WE;F5D96X_`%-L970@<W!A
M;2UB97-K961E<@!3;&5T=&5T`%-L971T961E(&)E<VME9&5R`%9E9&CF9G1E
M;'-E;B`B)7,B('-L971T970N`%-L971N:6YG(&]G(&9L>71N:6YG(&%F(&)E
M<VME9&5R`$%F=FES(&%N;6]D;FEN9P!!9G9I<R!A;FUO9&YI;F<@;VT@;&5D
M:6<O;W!T86=E="UI;F9O<FUA=&EO;@!&86QD96YD90!"97-K<FEV('!R;V)L
M96UE=`!"97-K<FEV96QS90!$971A;&IE<@!3;/AR('-I9VYA='5R97(_`%9I
M<P!6:7,@8F5K<N9F=&5L<V4@969T97(@869S96YD96QS92!A9B!E;B!B97-K
M960_`%9I<R!I(&)R^&1T96MS="!A9B!B97-K960`5FES(&5T('!O<'5P('9I
M;F1U92!V960@;GEE(&4M;6%I;"X`5FES(")4^&T@<W!A;2(@:&5N=FES;FEN
M9V5N(&D@;65N=6QI;FEE;C\`5FES(")4^&T@<VMR86QD97-P86YD(B!H96YV
M:7-N:6YG96X@:2!M96YU;&EN:65N/P!&;W)M`%!A<R!)2TM%('1I;`!#:&5C
M:R!I:VME(&UA<'!E*'(I(&9O<B!N>64@92UM86EL`$1U(&WE(&EK:V4@:V%L
M9&4@;6%I;G1E;F%N8V4N<&AP(&1I<F5K=&4`1V5N97+I<B!I:VME(&AE;G9I
M<VYI;F<@:2!&<F$Z(&MO;&]N;F5N`%9I;"!D=2#E8FYE(&1E;FYE(&UA<'!E
M/P!(87(@9'4@:6MK92!N;V=E;B!K;VYT;S\@365L9"!D:6<@=&EL+@!&YG)D
M:6<`2&5N="`E<R!I("YZ:7`M9F]R;6%T`$AE;G0@86QL92!V961HYF9T96QS
M97(@*&D@+GII<"UF:6PI`$AE;G0@;6%P<&4H<BD`2&5N="!M87!P92AR*2!;
M+GII<"!U9&=A=F5=`$AE;G0@:2`N>FEP+69O<FUA=`!+;&%D9&4`2VQA9&1E
M<@!-87!P92!T:6P@:VQA9&1E<CH`92UM86EL+6%D<F5S<V4`4TQ55`!&14I,
M.B!$:6X@8F5S:V5D(&MU;FYE(&EK:V4@869L979E<F5S+@#&;F1R90#&;F1R
M92!B;&%C:VQI<W1E`,9N9')E(&9I;'1R90!2970@=FER='5E;"!M87!P90#&
M;F1R92!V:7)T=65L(&UA<'!E(&1E9FEN:71I;VYE;B!F;W(@)7,`4F5T('!O
M<VET:79L:7-T90#&;F1R92!D:6X@8FQA8VML:7-T90#&;F1R92!D:6YE(&9I
M;'1E<G)E9VQE<@!2970@9&EN92!P<N9F97)E;F-E<B!V961R^')E;F1E('1I
M;&=A;F<@=&EL(&%N9')E(&4M;6%I;"UK;VYT:2X`QFYD<F4@9&EN('!O<VET
M:79L:7-T90!E36%I;`!E+6UA:6PM861R97-S90!!;&QE(&)E<VME9&5R(&9J
M97)N970@9G)A("5S`%3X;2!M87!P92AR*0!4^&T@=F%L9W1E(&UA<'!E<@!4
M^&T@<VMR86QD97-P86YD`%3X;2!S<&%M`%3X;2!S:W)A;&1E<W!A;F0`26YT
M970@<F5S=6QT870N`$%K=&EVZ7(@4$=0+69U;FMT:6]N86QI=&5T/P!!:W1I
M=NER(%,O34E-12UF=6YK=&EO;F%L:71E=#\`06MT:7;I<B!B97-K960M9VQI
M;70_`$MR>7!T97)I;F=S:6YD<W1I;&QI;F=E<@!3;'5T`%-L=70@868@=FED
M97)E<V5N9'0@8F5S:V5D`$%F<VQU="!B97-K960`069S;'5T(&)E<VME9"!F
M<F$@)7,`26YD=&%S="!L^'-E;@!);F1T87-T(&YA=FYE="!T:6P@9&5N(&YY
M92!M87!P92P@9'4@=FEL(&)R=6=E('-O;2!S<&%M+6UA<'!E`$EN9'1A<W0@
M;F%V;F5T('1I;"!D96X@;GEE(&UA<'!E+"!D=2!V:6P@9V5M;64@:VQA9&1E
M<B!I`$EN9'1A<W0@;F%V;F5T('1I;"!D96X@;GEE(&UA<'!E+"!D=2!V:6P@
M9V5M;64@<V5N9'1E(&4M;6%I;"!I`$EN9'1A<W0@;F%V;F5T('1I;"!D96X@
M;GEE(&UA<'!E+"!D=2!V:6P@8G)U9V4@<V]M('-K<F%L9&5S<&%N9`!(96QE
M(&)E<VME9&5N`"(E<R(@8FQE=B!T:6QF^&IE="!T:6P@861R97-S96MA<G1O
M=&5K970`1F5J;`!+=6YN92!I:VME(&9O<F)I;F1E('1I;"!)34%0('-E<G9E
M<BX@)7,@.B`E<P!&96IL('9E9"!S=F%R9F]R<V5N9&5L<V4Z("5S+@!(YFYD
M96QS96X@<VQE='1E="X`2'9E<B!K=F%R=&5R`$AV97(@:&%L=F4@;6EN=70`
M2'9E<B`U+B!M:6YU=`!!;'1I9"!V960@;&]G:6X`2'9E<B!H86QV92!T:6UE
M`$AV97(@;6EN=70`16MS96UP96QVYG)D:65R.@!59'9I9`#%8F5N(&%L;&4`
MQ6)E;B!A;&QE(&UA<'!E<@#%8F5N(&UA<'!E`$QA=B!E="!O<'-L86<@<.4@
M;F%V;F5N90!%:W-P86YDZ7(@875T;VUA=&ES:R!N879N92!I('-K<FEV;FEN
M9W-V:6YD=65T(&)A9R!TYG!P970_`,5B96X@86QL92!M87!P97(@:2!O=F5R
M<VEG=&5N('-O;2!S=&%N9&%R9"X`561V:61D97(`2&5N="!E+6UA:6P`2W5N
M;F4@:6MK92!FY2!F;W)B:6YD96QS92!T:6P@3$1!4"!S97)V97)E;BX`1F%X
M`$AE;G0@92UM86EL`$AE;G0@8F5S:V5D(&D@970@<V5P97)A="!V:6YD=64_
M`$AE;G0@8F5S:V5D97(L(&[E<B!D=2!L;V=G97(@:6YD/P`E9"!B97-K961E
M<B!H96YT970@9G)A("5S`#$@8F5S:V5D(&AE;G1E="!F<F$@)7,`1F5T8VAM
M86EL.B``1F5T8VAM86EL.B!I;F=E;B!N>64@8F5S:V5D97(N`$9I;'1R90!&
M:6P`1FEL:.5N9'1E<FEN9P!&:6QT97(M:6YD<W1I;&QI;F=E<@!&:6QT97(M
M;W!SYG1N:6YG`$9I;'1R97(@8F5S:V5D96YS(&EN9&AO;&0@9F]R('-TYG)K
M92!O<F0N`$9I;'1E<BUU;F1E<G-T^'1T96QS92!E<B!S;.5E="!F<F$@<.4@
M9&5T=&4@<WES=&5M+@!&:6QT<F4`1FEL=')E($E+2T4@86MT:79E<F5D90!&
M:6QT<F4Z("5S(&CE;F1T97)I;F=S<VED90!&:6YD`$;X<G-T92!S:61E`$;X
M<G-T92!S:61E`%9I9&5R97-E;F0`36%P<&4M:&%N9&QI;F=E<B`M($)E:W+F
M9G1E;'-E`$UA<'!E;F%V:6=A=&]R`$]P<W5M;65R:6YG(&%F(&UA<'!E`$1E
M;&EN9R!A9B!M87!P97(@:6MK92!A:W1I=F5R970N`$%N=F5N9&5L<V4@868@
M;6%P<&5R(&5R(&EK:V4@86MT:79E<F5T+@!&;W)M871E="!A9B!D871O97(@
M:2!B<F5V8F%K:V4M=FES;FEN9R!F;W(@8F5S:V5D97(@9&%T97)E="!I(&1A
M9P!6:61E<F5S96YD`%9I9&5R97-E;F0Z`%9I9&5R97-E;F1T(&)E<VME9`!6
M:61E<F5S96YD="!B97-K960@9G)A("5S`$9R:2]O<'1A9V5T+6EN9F]R;6%T
M:6]N`$QE9&EG+V]P=&%G970M<W9A<@!,961I9R]O<'1A9V5T+6%N;6]D;FEN
M9P!,961I9R]O<'1A9V5T+6%N;6]D;FEN9W,M<W9A<@!&<F$`1G)A`$9R82!A
M9')E<W-E`$9W9#H`5E,Z(`!64SH@)74@=FED97)E<V5N9'1E(&)E<VME9&5R
M`$=R=6YD;.9G9V5N9&4@:6YD<W1I;&QI;F=E<@!(96YT(&MU;B!N>64@8F5S
M:V5D97(_("A+=6X@24U!4"D`561F^'(`3N9S=&4@8F5S:V5D`%9I<R`B)7,B
M(&D@861R97-S96MA<G1O=&5K`%1I;&1E;"!A9&=A;F<`2$52`$A434P`2%1-
M3"UU9&=A=F4@868@8F5S:V5D`$]V97)S:W)I9G1E<@!(:N9L<`!(97(@97(@
M8F5S:V5D96XL('-O;2!D=2!S:W)E=CH`4VMJ=6QT`%-K:G5L="!I('1RY60M
M=FES;FEN9P!3:VIU;"!S;&5T=&5D90!3:VIU;"!D96%K=&EV97)E9&4`2/AJ
M`$CX:B!P<FEO<FET970`2/AJ<W0`061R97-S92`H:&IE;2D`5&5L969O;B`H
M:&IE;2D`2&]R9&4`2'9O<F1A;B!V:6P@9'4@=FES92!V961HYF9T96QS97(_
M`$AV:6QK970@<'+F9FEK<R!SYG1T97,@9F]R86X@9&5N(&-I=&5R961E('1E
M:W-T(&D@970@<W9A<CH`24U!4`!)34%0("AO<&1A9R!P<F]T;VMO;&QE<B!A
M=71O;6%T:7-K*0!)34%0+7-E<G9E<B!L=6MK961E(&9O<F)I;F1E;'-E;BX@
M4V5R=F5R('-V87)E9&4Z("5S`$E-05`@;W9E<B!34TP`24U!4"!O=F5R(%-3
M3"`H<V5L=BUS:6=N97)E="!C97)T:69I:V%T*0!)34%0(&]V97(@4U-,("AS
M96QV+7-I9VYE<F5T*0!)34%0+7-E<G9E<B!L=6MK961E(&9O<F)I;F1E;'-E
M;BX`24U!4"P@:6YG96X@5$Q3`$E-05`O4$]0,R!M86EL+7-E<G9E<F4`26YD
M8F%K:V4`2'9I<R!34TP@96QL97(@5$Q3(&)E;GET=&5S+"!S:V%L(&1U(&AA
M=F4@4$A0(&]P96YS<VP@=61V:61D96QS96X@;.9S<V5T+@!(=FES(&1U(&9O
M<G1SYG1T97(L('9I;"!D=2!M:7-T92!A;&QE(&)E<VME9&5R(&D@;6%P<&5N
M+VUA<'!E<FYE(0!)9VYO<F5R`$EG;F]R97(@86QT`$)I;&QE9&4`26UP;W)T
MZ7(`26UP;W)TZ7(@;OAG;&4`26UP;W)TZ7(@;OAG;&5P87(`26UP;W)TZ7(@
M8F5S:V5D97(`26UP;W)TZ7(@4$=0+6[X9VQE`$EM<&]R=.ER(&5G970@8V5R
M=&EF:6MA=`!);7!O<G3I<B!E9V5N+"!P<FEV871E(%!'4"UN^&=L90!);7!O
M<G3I<B!E9V5N+"!O9F9E;G1L:6=E(%!'4"UN^&=L90!);7!O<G3I<B!E9VYE
M(%,O34E-12!C97)T:69I:V%T97(`26UP;W)TZ7(@;V9F96YT;&EG(&[X9VQE
M`$EM<&]R=.ER(&]F9F5N=&QI9R!01U`M;OAG;&4`26UP;W)TZ7(@;V9F96YT
M;&EG(%,O34E-12UN^&=L90!);7!O<G3I<B!3+TU)344M;OAG;&4`26UP;W)T
MZ7(@;6)O>"UF:6P`26UP;W)TZ7(@;6)O>"UF:6P@)7,@:6YD(&D@;6%P<&4@
M)7,N`%9I9W1I9W0`5FEG=&EG92!B97-K961E<@`E9"!B97-K961E<B!I;7!O
M<G1E<F5T(&9R82`E<RX`26UP;W)T97)E9&4@9F5L=&5R.B`E<P!);7!O<G1E
M<F5D92!F96QT97(Z`%!R;V-E<W-E;B!K^')E<@!);F1B86MK90!-961T86<@
M96X@:V]R="!S86UM96YD<F%G(&%F(&)R979H;W9E9&5R(&D@96X@8F5S=F%R
M96QS93\`365D=&%G(&]P<FEN9&5L:6<@8F5S:V5D(&D@96X@8F5S=F%R96QS
M93\`26YF;P!);F9O<FUA=&EO;B!O;2`E<R!O9F9E;G1L:6<@;OAG;&4`26YF
M;W)M871I;VX@;VT@96=E;BP@<')I=F%T92!N^&=L90!);F9O<FUA=&EO;B!O
M;2!E9V5N+"!O9F9E;G1L:6<@;OAG;&4`26YD;&5J<F5T`$EN9'/F="!C97)T
M:69I:V%T(&AE<@!);F1SYG0@96=E;BP@<')I=F%T(%!'4"UN^&=L92!H97(`
M26YD<^9T(&5G96XL(&]F9F5N=&QI9R!01U`M;OAG;&4@:&5R`$EN9'/F="!O
M9F9E;G1L:6<@4$=0+6[X9VQE(&AE<@!59WEL9&EG(&AA;F1L:6YG('9A;&=T
M(&9O<B!D96YN92!K;VUP;VYE;G0N`%5G>6QD:6<@861R97-S90!59WEL9&EG
M(&9J97)N(&)R979B86MK90!59WEL9&EG="!T96=N(&D@92UM86EL+6%D<F5S
M<V4Z("5S+@!59WEL9&EG(&[X9VQE`%5G>6QD:6<@96=E;BP@<')I=F%T(%!'
M4"UN^&=L92X`56=Y;&1I9R!E9V5N+"!O9F9E;G1L:6<@4$=0+6[X9VQE+@!)
M;G9E<G3I<@!+0@!.^&=L96SF;F=D90!.^&=L92UG96YE<F5R:6YG(&MA;B!T
M86=E(&UE9V5T(&QA;F<@=&ED+B`@1F]R='/F="!M960@;OAG;&4M9V5N97)E
M<FEN9S\`3OAG;&4M:6UP;W)T97)I;F<@:6MK92!T:6QGYFYG96QI9RX@($AE
M;G1N:6YG(&%F(&9I;&5R(&5R(&EK:V4@86MT:79E<F5T('#E(&1E;FYE('-E
M<G9E<BX`3OAG;&4M:6UP;W)T97)I;F<@:6MK92!T:6QGYFYG96QI9RX@1'4@
M:&%R(&EK:V4@9&5F:6YE<F5T(&YO9V5T(&%D<F5S<V5K87)T;W1E:RP@:'9O
M<B!D:6YE(&MO;G1A:W1E<B!T:6P@=&EL9OAJ97,N`$[X9VQE(&5R('-E;F1T
M('1I;"!O9F9E;G1L:6<@;OAG;&4M<V5R=F5R+@!3<')O9P!3:61S=&4@92UM
M86EL('-I9&4`4VED<W1E('-I9&4`4F5F97+I<B!V961HYF9T96QS97(`4F5F
M97)E<F5D92!V961HYF9T96QS97(@97(@9F]R8G5D="X`2&5N=FES;FEN9V5R
M('5D;/AB97(@9&5N("5S`$]P;&ES=&YI;F<@868@:&KF;'!E96UN97(`3&ES
M="!A;&QE(&MO;G1A:W1E<BP@;N5R(&MO;G1A:W0M<VED96X@:&5N=&5S/R`H
M:'9I<R!S;.5E="!F<F$@=FEL(&1U(&MU;B!S92!D92!K;VYT86MT97(L('-O
M;2!D=2!S^&=E<B!E9G1E<BD`1F]R=&5G;F5L<V4@:6)L86YD="!B<F5V:&]V
M961E<FYE`%9I<VYI;F<@868@8G)U9V5R92!E<B!S;.5E="!F<F$N`$QO:V%L
M('!O<W1K87-S90!3=&5D`$QO9R!I;F0`3&]G(&EN9"!PY2`E<P!,;V<@=60`
M3&]G(&EN9`!,;V=I;BUO<&=A=F5R`$QA=@!,878@<')I;W)I=&5T`$QA=F5S
M=&4`34T`36%C:6YT;W-H+69I;`!-86EL`$4M;6%I;"!G;&EM=`!4>7!E(&%F
M(&UA:6PM<V5R=F5R(&%T(&9O<F)I;F1E('1I;#H`36%I;&)O>`!);F1S=&EL
M;&EN9V5R;F4@9F]R(&4M;6%I;"T@;V<@;6%P<&4M=FES;FEN9P!-87)KZ7(@
M86QL92!B97-K961E<B!I(&UA<'!E('-O;2!S970`36%R:^ER(&%L;&4@8F5S
M:V5D97(@:2!M87!P92!S;VT@=7-E=`!-87)K97(@<V]M.@!-87)KZ7(@9F]R
M<VME;&QI9V4@8VET870M;FEV96%U97(@;65D(&9O<G-K96QL:6=E(&9A<G9E
M<C\`36%R:^ER(&)E<VME9"!S;VT@<V5T/R`H2W5N($E-05`I`$UA<FOI<B!S
M:6UP;&EF:6-E<F5T(&]P;>9R:VYI;F<_`%!A<W-E<B!T:6P@86QL92!F;W)E
M<W#X<F=S;&5R`%!A<W-E<B!T:6P@;F]G96X@868@9F]R97-P^')G<VQE<FYE
M`$]V97)E;G-P87-S96YD92!F96QT97(`4W3X<G)E;'-E('#E('-T^')S=&4@
M=F5D:.9F=&5L<V4`36%K<VEM86QT(&%N=&%L(&UA<'!E<@!-86MS:6UA;'0@
M86YT86P@=F5D:.9F=&5L<V5R(&[E970N`$UA:W-I;6%L="!T;W1A;"!S=/AR
M<F5L<V4@868@=F5D:.9F=&5L<V4@;N5E="X`069L>7-N:6YG(&%F(&WX9&4`
M3?AD92UI;F9O<FUA=&EO;@!-^&1E+69O<G-L86<`3?AD92US=F%R`$WX9&4M
M;W!D871E<FEN9P!!;FUO9&YI;F<@;VT@;W!D871E<FEN9R!A9B!M^&1E`$UE
M;G4M;6%P<&4M;&ES=&4`0F5S:V5D`%-K<FEV;FEN9R!A9B!N>2!B97-K960`
M1&%T;P!"97-K960M:6YD<W1I;&QI;F=E<@!3^&=N:6YG`%-T^')R96QS90!/
M<')I;F1E;'-E`%9I<VYI;F<`36%R:V5R:6YG97(`36%P<&5R`$)E<VME9"!F
M<F$@)7,`0F5S:V5D(&AA<B!V961HYF9T96QS97(`0F5S:V5D(&5R(&MR>7!T
M97)E=`!"97-K960@97(@<VEG;F5R970`0F5S:V5D('!A<W-E<@!"97-K960@
M;VUA9')E<W-E<F5T+@!"97-K961E;B!B;&5V('-E;F1T+"!M96X@:W5N;F4@
M:6MK92!G96UM97,@:2`E<P!"97-K961E;B!E<B!S96YD="X`0F5S:V5D97(@
M<&5R('-I9&4@:2!M86EL8F]X=FES;FEN9V5N+@!"97-K961E<B!T:6P`QFYD
M<F4`3>5N961L:6<`1&5R(&)L978@9G5N9&5T(&9L97)E(&5N9"#I;B!A9')E
M<W-E(&9O<B!F96QT970@(B5S(BX`1FQY=`!&;'ET(&YE9`!&;'ET('-P86TM
M8F5S:V5D97(@=&EL('-P86TM;6%P<&4@;V<@;W)D96YT;&EG92!B97-K961E
M<B!T:6P@26YD8F%K:V4`5N9L9R!M87!P90!&;'ET(&]P`$UU;'1I<&%R="]A
M;'1E<FYA=&EV90!6:7-N:6YG:2!M960@;75L=&EP;&4@8F5S:V5D97(`24Y'
M14X`0D5-QE)+`$YA=FX`3F%V;B!O9R]E;&QE<B!E+6UA:6P@:V%N(&EK:V4@
M=N9R92!T;VUM90!(86YD;&EN9R!N^&1V96YD:6<`3F5T=N9R:P!!;&1R:6<`
M1V5M(&%L9')I9R!V961HYF9T96QS97(`3GD`3GD@;6%P<&4`3GEE(&)E<VME
M9&5R`$YY92!B97-K961E<B!T:6P@)7,`3GEE(&)E<VME9&5R`$YY:&5D97(`
M3N9S=&4`3N9S=&4@8F5S:V5D`$[F<W1E('-I9&4`3F5J`$EN=&5T(&-E<G1I
M9FEK870@9G5N9&5T`$EN9V5N(&MR>7!T97)I;F<`26YG96X@;OAG;&5R(&D@
M;OAG;&5R:6YG`$EN9V5N(&)E<VME9&5R`$EN9V5N(&]F9F5N=&QI9R!01U`M
M;OAG;&4@:6UP;W)T97)E="X`16=E="!C97)T:69I:V%T(&9O<F5F:6YD97,@
M:6MK90!);G1E="!T96MS="UG;&EM=`!);F=E;B!O9F9E;G1L:6=E(&[X9VQE
M<B!F=6YD970`26YG96X@;V9F96YT;&EG92!3+TU)344M;OAG;&5R(&EM<&]R
M=&5R970N`$EN9V5N('9E9&CF9G1E;'-E<B!F=6YD970N`$EN9V5N(&4M;6%I
M;"UI;F9O<FUA=&EO;B!L;VMA;&ES97)E="!I(&]F9F5N=&QI9R!N^&=L92X`
M26YG96X@;6%P<&4@=F%L9W0N`$EN9V5N(&UA<'!E<B!B;&EV97(@8VAE8VME
M="!F;W(@;GD@<&]S="X`26YG96X@;6%P<&5R(&%N9VEV970`26YG96X@;6%P
M<&5R(&UE9"!N>64@8F5S:V5D97(`26YG96X@;6%P<&5R(&UE9"!U;.9S=&4@
M8F5S:V5D97(`26YG96X@8G+X9'1E:W-T`$1I;B!S^&=N:6YG(&=A=B!I;F=E
M;B!B97-K961E<@!);F=E;B!E9V5N+"!P<FEV870@4$=0+6[X9VQE(&EM<&]R
M=&5R970N`$EN9V5N(&5G96XL(&]F9F5N=&QI9R!01U`M;OAG;&4@:6UP;W)T
M97)E="X`26YT970@96=E="!3+TU)344M8V5R=&EF:6-A="!I;7!O<G1E<F5T
M+@!$97(@97(@:6MK92!K;VYF:6=U<F5R970@;F]G970@<')O9W)A;2!T:6P@
M<W1A=F5K;VYT<F]L+@!);F=E;B!S=&%V969E:FP`26YG96X@9F]R<VQA9P!)
M;F=E;B!U;F1E<G-T^'1T970@24U!4"#F9W1N:6YG<VUE=&]D92!F=6YD970N
M`$EN9V5N(&)R=6=E<B!A;F=I=F5T+@!%:B!D96QT86=E<@!);F=E;@!.;W)M
M86P`26MK92!S;&5T=&5T`$EK:V4@:VQA9&1E`$EK:V4@=FEG=&EG=`!):VME
M('!E<G-O;FQI9W0`26MK92!E;B!G>6QD:6<@;V9F96YT;&EG(&[X9VQE`$EK
M:V4@<VQE='1E9&4@8F5S:V5D97(`26MK92!V:6=T:6=E(&)E<VME9&5R`$)E
M;>9R:R!A="!D971T92!K86X@=&%G92!S:6X@=&ED`$YO=&5R`$EN9V5N=&EN
M9P!!;G1A;"!MY6YE9&5R(')E9F5R97)E9&4@=F5D:.9F=&5L<V5R('-K86P@
M9V5M;65S+"!NY7(@9&5R('-L971T97,@;>5N961L:6=T+@!!;G1A;"!A9B!G
M86UL92!M87!P97(@9F]R('-E;F1T(&4M;6%I;"P@9&5R('-K86P@8F5H;VQD
M97,L(&[E<B!D97(@<VQE='1E<R!MY6YE9&QI9RX`3TL`14Q,15(`1V%M;&4@
M8F5S:V5D97(`1V%M;&4@;6%P<&5R(&UE9"!S96YD="!E+6UA:6P@8FQI=F5R
M(&9J97)N970N`%9I<R!K=6X@;6%P<&5R(&UE9"!U;.9S=&4@8F5S:V5D/P!6
MYFQG('9E;FQI9W-T(&MU;B!E;B!M87!P92!F;W(@9&5N;F4@:&%N9&QI;F<N
M`,5B96X@;6%P<&4`Q6)N970@;6%P<&4`5F%L9V9R:2!D96QT86=E<@!!;F1R
M92!M86EL+6MO;G1I`$%N9')E(&EN9'-T:6QL:6YG97(`561GY65N9&4@<V5R
M=F5R`%!'4`!01U`M:W)Y<'3I<B!B97-K960`4$=0+69E:FPZ(`!01U`M9F5J
M;#H@0F5H^'9E<B!L^'-E;B!F;W(@96=E;BP@<')I=F%T(&[X9VQE+@!01U`M
M:6YD<W1I;&QI;F=E<@!);F1T87-T;FEN9R!A9B!01U`M;/AS96X`56YD97)S
M=/AT=&5L<V4@868@96=N92!01U`M;OAG;&5SYG0@:W+F=F5R('-I:VME<B!W
M96(M9F]R8FEN9&5L<V4N`$]F9F5N=&QI9R!01U`M;OAG;&5T96MS=`!/9F9E
M;G1L:6<@4$=0+6[X9VQE(&9O<B`B)7,@*"5S*2(@=&EL9OAJ970N`$]F9F5N
M=&QI9R!01U`M;OAG;&4@9F]R("(E<R(@=&EL9OAJ970N`$]F9F5N=&QI9R!0
M1U`M;OAG;&5R:6YG`%!'4"US:6=NZ7(@8F5S:V5D`%!'4"US:6=NZ7(O:W)Y
M<'3I<B!B97-K960`4')I=F%T92!01U`M;OAG;&4@=&EL9OAJ970N`$]F9F5N
M=&QI9R!01U`M;OAG;&4@=&EL9OAJ970N`%5N9&5R<W3X='1E;'-E(&%F(%!'
M4"!E<B!S;.5E="!F<F$@<.4@9&5T=&4@<WES=&5M+@!5;F1E<G-T^'1T96QS
M92!A9B!01U`@97(@:2#X:F5B;&EK:V5T('-LY65T(&9R82!SY2!D96X@9&EG
M:71A;&4@<VEG;F%T=7(@:V%N(&EK:V4@=F5R:69I8V5R97,N`%!'4"UU;F1E
M<G-T^'1T96QS92!E<B!I:VME(&%K=&EV97)E="P@<^4@8F5S:V5D96X@:V%N
M(&EK:V4@9&5K<GEP=&5R97,N`%5N9&5R<W3X='1E;'-E(&%F(%!'4"!K<N9V
M97(@86YV96YD96QS92!A9B!P;W!U<"UV:6YD=65R+B`@2'9I<R!D:6X@8G)O
M=W-E<B!E<B!S870@=&EL(&%T(&9O<FAI;F1R92!P;W!U<"UV:6YD=65R(&)L
M:79E<B!D=2!N^&1T('1I;"!A="#F;F1R92!O<'/F=&YI;F<@9F]R(&%T(%!'
M4"UF86-I;&ET971E<FYE(&MA;B!V:7)K97(@:V]R<F5K="X`4$]0,P!03U`S
M("AB97-T96UT('!R;W1O:V]L;&5R(&%U=&]M871I<VLI`%!/4#,@;W9E<B!3
M4TP`4$]0,R!O=F5R(%-33"`H<V5L=BUS:6=N97)E="!C97)T:69I:V%T*0!0
M3U`S(&]V97(@4U-,("AS96QV+7-I9VYE<F5T*0!03U`S+"!I;F=E;B!43%,`
M4VED92`E9"!A9B`E9`!3:61E(&UE9"!F^')S=&4@=7-E=&4@8F5S:V5D`%-I
M9&4@;65D('-I9'-T92!U<V5T92!B97-K960`1&5L*&4I`$SX<V5N`$SX<V5N
M("AI9V5N*0!,^'-E;B!F:F5R;F5T+@!,^'-E;CH`3/AS96X@:V%N(&EK:V4@
M=N9R92!T;VUT`$SX<V5N97)N92!S:V%L(';F<F4@96YS`$MO9&5O<F0`2V]D
M96]R9&5N92!S:V%L(';F<F4@96YS+@!59&;X<B!V961L:6=E:&]L9&5L<V4`
M561F^'(@=F5D;&EG96AO;&1E;'-E('9E9"!L;V<@:6YD/P!4:6QL861E;'-E
M<FYE(&9O<B!D96YN92!B<G5G97(@:V%N(&EK:V4@YFYD<F5S+@!097)S;VYL
M:6<`4')O9FEL97(`16=E;B!01U`M;OAG;&5P87(@9V5N97)E<F5T(&UE9"!S
M=6-C97,N`$5G;F4@4$=0+6[X9VQE<B!S;&5T=&5T+@!%9VYE(%,O34E-12UC
M97)T:69I:V%T97(@24M+12!I;7!O<G1E<F5T.B``16=N92!3+TU)344M;OAG
M;&5R('-L971T970N`%1E;&5F;VX`4^9T(&1I;B!S:6=N871U<B!F;W)A;B!S
M=F%R(&]G('9I9&5R97-E;F1E;'-E<C\`4F5N=&5K<W0M=61G879E(&%F(&)E
M<VME9`!!9G-P:6P@;'ED('9E9"!N>2!B97-K960_($1E='1E(&MRYG9E<BP@
M870@9&EN(&)R;W=S97(@=6YD97)S=/AT=&5R(&EN9&QE:G)E9&4@;'ED+69I
M;&5R+B`@3VUT<F5N="!A;&QE(&?X<B!U;F1E<B!7:6YD;W=S(&]G($UA8RP@
M;65N(&%N9')E('!L871F;W)M92!K<N9V97(@970@<&QU9VEN+@!);F1T87-T
M('9E;FQI9W-T(&5T(&YA=FX@=&EL(&1E;B!N>64@;6%P<&4Z`$EN9'1A<W0@
M=F5N;&EG<W0@;F%V;F5T('1I;"!D96X@;GEE(&UA<'!E.@!!;F=I=B!V96YL
M:6=S="!D970@;GEE(&YA=FXZ`$EN9'1A<W0@=F5N;&EG<W0@970@;/AS96X@
M=&EL(&1I;B!P<FEV871E(%!'4"UN^&=L92X@($1U('9I;"!K=6X@<VMU;&QE
M(&EN9'1A<W1E(&1E='1E(&SX<V5N(.EN(&=A;F<@)7,@<V5S<VEO;BX`26YD
M=&%S="!E="!L^'-E;B!T:6P@9&EN('!R:79A=&4@4R]-24U%+6[X9VQE+B`@
M1'4@=FEL(&MU;B!S:W5L;&4@:6YD=&%S=&4@9&5T=&4@;/AS96X@Z6X@9V%N
M9R!P<B`E<R!S97-S:6]N+@!,;V<@:6YD(&EG96X@9F]R(&%T(&9O<G1SYG1T
M92!S:W)I=FYI;F<N("!(=FES(&1U($E+2T4@8F5N>71T97(@8V]O:VEE<R!/
M1R!D=2!S:W)I=F5R(&D@970@<&]P=7`M=FEN9'5E+"!S:V%L(&1U(&]G<^4@
M;&]G9V4@:6YD(&D@9&ET(&AO=F5D+79I;F1U92X@1&5T=&4@97(@;OAD=F5N
M9&EG="!F;W(@870@9F]R:&EN9')E(&%N9W)I8F5R92!I(&%T(&MA8G)E(&1I
M="!S97-S:6]N+4E$+B!6:2!B96ML86=E<B!PY6;X<G1E('5L96UP97(N`%-K
M<FEV('9E;FQI9W-T+"!H=F%D('!R;V)L96UE="!GY7(@=60@<.4@;V<@:'9A
M9"!D97(@<VME<BX`26YD=&%S="!V96YL:6=S="!D:70@:V]D96]R9"X`26YD
M=&%S="!V96YL:6=S="!B<G5G97)N879N(&]G(&MO9&5O<F0`26YD=&%S="!V
M96YL:6=S="!D:70@8G)U9V5R;F%V;BX`4F5T('9E;FQI9W-T(&1E;B!U='ED
M:6=E(&5L;&5R('5G>6QD:6=E(&%D<F5S<V4N`$=E;FYE;6?E(&;X;&=E;F1E
M(&EN9F]R;6%T:6]N(&]G(';F;&<@96X@:&%N9&QI;F<@9G)A(&UE;G5E;B!N
M961E;F9O<BX`1'4@<VMA;"!VYFQG92!E;B!M87!P92P@9OAR(&1U(&MA;B!U
M9&;X<F4@96X@:&%N9&QI;F<N`%;F;&<@=F5N;&EG<W0@96X@:&%N9&QI;F<@
M9G)A(&UE;G5E;B!N961E;F9O<BX`5N9L9R!M:6YD<W0@96X@;6%P<&4L('-O
M;2!D=2!V:6P@<_AG92!I+@!6YFQG('9E;FQI9W-T(&MU;B!E;B!M87!P92!F
M;W(@9&5N;F4@;W!G879E+@!6YFQG('9E;FQI9W-T(&5L;&5R(')E9&EG97(@
M:2!B;VMS96X@=&EL(&CX:G)E.@!0;W=E<F5D(&)Y($AO<F1E`%/F="!B:6YD
M97-T<F5G97(@*"<M+2`G*2!F;W)A;B!D:6X@<VEG;F%T=7(_`%!RYF9E<F5N
M8V5R;F4@;W!D871E<F5T+@!';&EM=`!&;W)R:6=E(&)E<VME9`!&;W)R:6=E
M('-I9&4`561S:W)I=@!0<FEO<FET970`2V]D96]R9"!T:6P@<')I=F%T(&[X
M9VQE`%!R;V)L96UB97-K<FEV96QS90!3</AR9R!H=F5R(&=A;F<@96X@=F5D
M:.9F=&5L<V4@<V5N9&5S.R!N;W)M86QE;B!E<B!.14H`4W#X<F<@:'9E<B!G
M86YG(&5N('9E9&CF9G1E;'-E('-E;F1E<SL@;F]R;6%L96X@97(@2D$`4')O
M=&]K;VPZ`%5N9&5R<W3X='1E;'-E(&%F(&]F9F5N=&QI9R!01U`M;OAG;&5S
M97)V97(@97(@<VSE970@9G)A+@!&:F5R;B!S;&5T=&5D90!&:F5R;B!S;&5T
M=&5D90!3;&5T(&UA<'!E*'(I`%3X;2!S:W)A;&1E<W!A;F1E;B!H=F]R('1I
M=#H`1FIE<FX@8F5S:V5D97(@:2!S:W)A;&1E<W!A;F1E;BP@9&5R(&5R(.9L
M9')E(&5N9"!D971T92!A;G1A;"!D86=E+@!&:F5R;B!G86UL92!B97-K961E
M<B!I('-K<F%L9&5S<&%N9&5N/P!&:F5R;F5R("5D(&)E<VME9'(@9G)A('-K
M<F%L9&5S<&%N9"X`1FIE<FYE<B`Q(&)E<VME9"!F<F$@<VMR86QD97-P86YD
M+@!+=F]T97-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0!+=F]T
M97-T871U<SH@)2XR9DU"("\@24Y4150@3$]&5`!+=F]T97-T871U<SH@24Y4
M150@3$]&5`!#:71A="!A9B`E9CH`06YM;V0@;VT@8F5K<N9F=&5L<V4@=F5D
M(&%F;&5V97)I;F<N`$UO9'1A9V5T(&1E;@!-;V1T86=E="!S:61E;@!-;V1T
M86=E="!F^'(`3VUA9')E<W-E<@!/;6%D<F5S<V5R`$]M861R97-S97(@8F5S
M:V5D`$]M861R97-S97(@9&5N;F4@8F5S:V5D`$]M861R97-S97)I;F<@;6ES
M;'EK:V5D97,N`$]P9&%T97(`3W!D871E<B!V:7-N:6YG97)N92!A9B!M87!P
M97(Z`$=E;F]P9G)I<VL`3W!D871E<B!V:7-N:6YG`$AU<VL@;&5D:6<O;W!T
M86=E="UI;F9O<FUA=&EO;F5N+@!(=7-K(&1E;B!S:61S=&4@=FES;FEN9P!!
M9G-I9&5S(&)R979B86MK90!&:F5R;B!F96QT(&9R82!S^&=N:6YG`%-L970@
M<&%R`$9J97)N(&MI;&1E`$]M9/AB(&UA<'!E*'(I`$]M9/AB(&UA<'!E(&9O
M<B!S96YD=&4@8F5S:V5D97(@:2!S=&%R=&5N(&%F(&WE;F5D96X_`$]M9/AB
M;FEN9R!A9B`B)7,B('1I;"`B)7,B(&UI<VQY:VME9&5S+B!&^&QG96YD92!B
M97-K960@:V]M(&9R82!S97)V97)E;@!3=F%R('1I;"!L:7-T90!%<G-T870@
M;65D.@!3=F%R`%-V87(@<V5N9'0N`%-V87(@=&EL(&%L;&4`4W9A<B!T:6P@
M86QL93H`4W9A<B!T:6P@;&ES=&4`4W9A<B!T:6P@;&ES=&4Z`%-V87(@=&EL
M(&%L;&4`4W9A<B!M960@:6MK92UU;F1E<G-T^'1T970M8F5S:V5D`%-V87(@
M;65D(&QE9&EG+V]P=&%G970@9F]R(&[F<W1E(#(@;>5N961E<BX`4W9A<B!M
M960@86YM;V1E="!L961I9R]O<'1A9V5T+6EN9F]R;6%T:6]N+@!297!L>2U4
M;P!297!L>2U4;SH@`%)E<&QY.@!!;FUE;&0@<V]M(&5J+7-P86T`06YM96QD
M('-O;2!34$%-`$%N;6]D(&]M(&MV:71T97)I;F<@9F]R(&SF<VYI;F<`06YM
M;V0@;VT@8F5K<N9F=&5L<V4@=F5D(&%F;&5V97)I;F<_`$%N;6]D(&]M(&MV
M:71T97)I;F<@9F]R(&SF<VYI;F<`1F]R97-P=7)G=&4@8F5S:V5D(&EK:V4@
M9G5N9&5T+@!+<N9V970@9&5L=&%G97(`3G5L<W1I;`!297-P;VYD96YT+7-T
M871U<R!O<&1A=&5R970N`$9O<G1SYG0`1F]R='/F="!D:6X@<V5S<VEO;@!6
M96YD('1I;&)A9V4@=&EL(")3:W)I=FYI;F<@868@;GD@8F5S:V5D(@!4:6QB
M86=E('1I;"!I;F1S=&EL;&EN9V5R;F4@9F]R(")&971C:"!-86EL(@!4:6QB
M86=E('1I;"!I;F1S=&EL;&EN9V5R;F4`1^4@=&EL8F%G92!T:6P@;6%I;&)O
M>&5N(&5F=&5R('-L971N:6YG+"!F;'ET;FEN9R!E;&QE<B!K;W!I97)I;F<@
M868@8F5S:V5D/P!296=E;`!3+TU)344`4R]-24U%+6MR>7!T97)E="!B97-K
M960`4R]-24U%+69E:FPZ(`!3+TU)344M9F5J;#H@3/AS96X@=&EL(&5G96XL
M('!R:79A="!N^&=L92!N^&1V96YD:6<N`%,O34E-12UI;F1S=&EL;&EN9V5R
M`$EN9'1A<W0@4R]-24U%+6SX<V5N`%5N9&5R<W3X='1E;'-E(&%F(&5G96X@
M4R]-24U%(&[X9VQE<&%R(&MRYG9E<B!S:6MK97(@=V5B+69O<F)I;F1E;'-E
M+@!/9F9E;G1L:6<@4R]-24U%+6[X9VQE(&9O<B`B)7,B('-L971T970N`$]F
M9F5N=&QI9R!3+TU)344@;OAG;&4@=&EL9OAJ970N`$]F9F5N=&QI9R!3+TU)
M344@;OAG;&5R:6YG`$]F9F5N=&QI9R]P<FEV870@4R]-24U%(&[X9VQE<&%R
M('1I;&;X:F5T+@!3+TU)344M<VEG;NER(&)E<VME9`!3+TU)344@<VEG;NER
M+VMR>7!TZ7(@8F5S:V5D`%5N9&5R<W3X='1E;'-E(&%F(%,O34E-12!S;.5E
M="!F<F$@<.4@9&5T=&4@<WES=&5M+@!5;F1E<G-T^'1T96QS92!A9B!3+TU)
M344@97(@:6MK92!A:W1I=F5R970L('/E(&)E<VME9&5N(&MA;B!I:VME(&1E
M:W)Y<'1E<F5S+@!5;F1E<G-T^'1T96QS92!A9B!3+TU)344@97(@:6MK92!A
M:W1I=F5R970L('/E(&EN9&AO;&1E="!A9B!D96YN92!S:6=N97)E9&4@8F5S
M:V5D(&MA;B!I:VME('9I<V5S+@!5;F1E<G-T^'1T96QS92!A9B!3+TU)344@
M97(@:6MK92!A:W1I=F5R970L('/E(&1E;B!D:6=I=&%L92!S:6=N871U<B!K
M86X@:6MK92!V97)I9FEC97)E<RX`56YD97)S=/AT=&5L<V4@868@4R]-24U%
M(&MRYG9E<B!A;G9E;F1E;'-E(&%F('!O<'5P+79I;F1U97(N("!(=FES(&1I
M;B!B<F]W<V5R(&5R('-A="!T:6P@870@8FQO:VME<F4@<&]P=7`M=FEN9'5E
M<BP@8FQI=F5R(&1U(&[X9'0@=&EL(&%T(.9N9')E(&1E;FYE(&EN9'-T:6QL
M:6YG.R!E;&QE<G,@=FEL(%,O34E-12UF=6YK=&EO;F5R(&EK:V4@=FER:V4@
M:V]R<F5K="X`4TU44`!%;6YE`$=E;2!E;B!K;W!I(&D@`$=E;2!S;VT`1V5M
M`$=E;2!V961HYF9T96QS97(@;65D(&)E<VME9&5R(&D@(E-E;F1T('!O<W0B
M+6UA<'!E;C\`1V5M(&ML861D90!'96T@8FEL;&5D90!'96T@8FEL;&5D92!I
M(&=A;&QE<FD`1V5M;64@26YD<W1I;&QI;F=E<@!'96UM92!B<F5V<&%P:7(`
M1V5M(&ML861D90!'96T@<V]M`$=E;2!K;&%D9&5R('-O;2!U;.9S=#\`1V5M
M(&UO9'1A9V5R92!A=71O;6%T:7-K(&D@9&5T(&YO<FUA;&4@861R97-S96MA
M<G1O=&5K/P!'96T@<_AG;FEN9R!S;VT@96X@=FER='5E;"!M87!P93\`1V5M
M('-E;F1T(&)E<VME9#\`1V5M;FEN9R!A9B!K;&%D9&4@;6ES;'EK:V5D97,N
M($;X;&=E;F1E(&)E<VME9"!K;VT@9G)A('-E<G9E<F5N.B`E<P!3^&<`4_AG
M(&5F=&5R("5S`%/X9V4M:6YD<W1I;&QI;F=E<@!3^&=E<F5S=6QT871E<@!3
M970`5N9L9P!6YFQG(&5N(&%N9&5N(&MO;G1O`%;F;&<@96X@9&%T;P!6YFQG
M(&5T(&9E;'0`5N9L9R!B<F5V<&%P:7(Z`%;F;&<@861R97-S96MA<G1O=&5K
M97(@9F]R(&]P<F5T=&5L<V4@;V<@<_AG;FEN9R!A9B!A9')E<W-E<BX`5N9L
M9R!A;&QE`%;F;&<@86QL92!F96QT97(@<V]M('-K86P@9V5N;F5M<_AG97,L
M(&[E<B!A9')E<W-E<B!E:W-P86YD97)E<RX`5N9L9R!E;B!K;VYT;P!6YFQG
M(&EN9V5N`%;F;&<@9&%T;RUA9'-K:6QL97)E;CH`5N9L9R!D871O9F]R;6%T
M.@!6YFQG(&=A;&QE<FDL(&AV;W)I(&)I;&QE9&5T('-K86P@9V5M;65S+@!6
MYFQG(&UA:6PM<V5R=F5R+71Y<&5N`%;F;&<@=&ED<V9O<FUA=#H`5N9L9R!T
M;R!F96QT97(L(&1E<B!S=F%R97(@=&EL(&AI;F%N9&5N+@!686QG=&4@861R
M97-S96MA<G1O=&5K97(Z`%-E;F0@;OAG;&4@=&EL(&]F9F5N=&QI9R!N^&=L
M97-E<G9E<@!396YD="!S96YE<W1E(&EN9F]R;6%T:6]N`%-E;F0@8F5S:V5D
M`%-E;F0@<')O8FQE;6)E<VMR:79E;'-E`%-E;F0@;.9S="UK=FET=&5R:6YG
M(&[E<B!A;FUO9&5T(&%F(&%F<V5N9&5R/P!-87!P92!F;W(@<V5N9'1E(&)E
M<VME9&5R`$UA<'!E(&9O<B!S96YD=&4@92UM86EL<SH`4V5R=F5R`%-E<G9E
M<BT@;V<@;6%P<&4M:6YF;W)M871I;VX`4V5R=F5R.@!);F1S=&EL;&EN9V5R
M(&9O<B!H=F%D(&1E<B!S:V5R+"!NY7(@9'4@9FQY='1E<B!E;&QE<B!S;&5T
M=&5R(&)E<VME9&5R+@!3YG0@8G)E=FAO=F5D970@6"U0<FEO<FET>2!V960@
M<VMR:79N:6YG(&%F(&)E<VME9&5R/P!$96P@;6%P<&5R`$1E;"!B97-K960M
M;6%P<&5R`$1E;"!D:6YE('!O<W1M87!P97(@;65D(&%N9')E(&)R=6=E<F4N
M`%-K86P@<W1O<F4@:VQU;7!E<B!A9B!C:71E<F5T('1E:W-T(';F<F4@<WEN
M;&EG(&5L;&5R('-K:G5L="!S;VT@<W1A;F1A<F0_("!(=F%D(&5N=&5N(&1U
M(';F;&=E<B!E<B!D970@;F5M="!A="!S:VEF=&4N`%-K86P@8G+X9'1E:W-T
M96X@868@=&5X="]P;&%I;B!B97-K961E<B!G96YN96US^&=E<R!F;W(@4$=0
M+61A=&$_`%-K86P@=FEN9'5E="!M960@9&5N(&YY92!B97-K960@;'5K:V5S
M(&5F=&5R(&=E;6YI;F<@868@:VQA9&1E/P!3:V%L(&1E="!VYG)E(&YO<FUA
M;&5N+"!A="!D:6X@4$=0+6[X9VQE('9E9&CF9G1E<R!B97-K961E<C\`5FEL
M(&%L;&4@;6%P<&5R`%9I<R!A;&QE(&)R979H;W9E9&5R`%9I<R!S;&5T=&5D
M90!6:7,@;F]R;6%L92!B<F5V:&]V961E<@!6:7,@;6%I;&QI<W1E+6EN9F]R
M;6%T:6]N`%9I<R!K=6X@86MT:79E<F5D92!M87!P97(`5FES(&1E86MT:79E
M<F5D90!6:7,@970@<&EC=&]G<F%M('-O;2!G:79E<B!A9&=A;F<@=&EL(&%T
M(&9J97)N92!V961HYF9T96QS92!F<F$@8F5S:V5D97(_`%9I<R!S>6UB;VQF
M;W)K;&%R:6YG(&D@;6%I;&)O>'9I<VYI;F=E;C\`5FD@:W5N(&=L:6UT(&%F
M('5LYG-T92!B97-K961E<C\`5FES(&=L:6UT(&D@/&5M/G1O;VQT:7!S/"]E
M;3X_`%9I<R`B1F5T8V@@36%I;"(@:VYA<'!E;B!I(&UE;G5E;C\`5FES(&)I
M;&QE9&5R;F4`5FES(")&:6QT97(B(&MN87!P96X@:2!M96YU96X_`%9I('1O
M=&%L="!A;G1A;"!B97-K961E<B!I(&UA<'!E/P!6:7-T`%-T<BX`4VEG;F5R
M970`4W3X<G)E;'-E`%-P<FEN9R!V961L:6=E:&]L9&5L<V4@;W9E<@!3;W)T
MZ7(@969T97(@;6]D=&%G96QS97-T:61S<'5N:W0`4V]R=.ER(&5F=&5R(&1A
M=&\`4V]R=.ER(&5F=&5R(&%F<V5N9&5R+6%D<F5S<V4`4V]R=.ER(&5F=&5R
M('-T^')R96QS90!3;W)T97(@969T97(@96UN90!3;W)T97(@969T97(@='+E
M9`!3;W)TZ7(@969T97(@;6]D=&%G97)A9')E<W-E`$UA<'!E('1I;"!S<&%M
M+6)E<VME9&5R.@!);F1T87-T;FEN9R!F;W(@<W!E8VEA;&MA<F%K=&5R`%-P
M96-I96QL92!T96=N`%-P96-I96QL92!V:7)T=65L;&4@;6%P<&5R(&UA;B!I
M:VME(.9N9')E<RX`4W1A=F5K;VYT<F]L`%-T879E:V]N=')O;`!3=&%V96MO
M;G1R;VP@869S;'5T=&5T`%-T879E9F5J;"!P<BX@<VOF<FTL(&[E<B!D97(@
M:_AR97,@<W1A=F5K;VYT<F]L+@!3=&%R=`!"<F5V<&%P:7(`0G)E=G!A<&ER
M;F%V;CH`0G)E=G!A<&ER='EP93H`0G)E=G!A<&ER.@!3=&%T=7,`1FIE<FX@
M=F5D:.9F=&5L<V4`1FIE<FX@;VUB<GED;FEN9S\`16UN90!%;6YE`$9E;'0@
M9F]R($5M;F4`069L97;I<@!!:W1I=F5R(&UA<'!E*'(I`%5D9OAR=`!&;W)S
M;&%G`$EN9&AO;&0`4VMI9G0@<VMR:79N:6YG<VUE=&]D90!3:VEF="!T:6P@
M2%1-3"US:W)I=FYI;F<`4VMI9G0@=&EL(')E;B!T96MS='-K<FEV;FEN9P!/
M<&=A=F5R`%1E:W-T`$9O<F5L^&)I9SH@`$%C8V5P=.ER(&%N;6]D;FEN9R!F
M;W)E;/AB:6=T`$9O<F5L^&)I9W0@86-C97!T97)E=`!"971I;F=E;'-E<V9I
M;"!I:VME(&%N9VEV97,@:2!C;VYF+G!H<`!496MS=`!"97-K961E;G,@1G)A
M+6MO;&]N;F4@<VMA;"!R969E<F5R97,Z`$E-05`M<V5R=F5R96X@<WEN97,@
M:6MK92!A="!U;F1E<G-T^'1T92!D96X@=F%L9W1E(.9G=&YI;F=S;65T;V1E
M+B!+;VYT86MT(&1I;B!S>7-T96UA9&UI;FES=')A=&]R+@`\96T^36%C:6YT
M;W-H(')E<V]U<F-E(&9O<FL\+V5M/@`\/&5M/DUA8VEN=&]S:"!R97-O=7)C
M92!F;W)K/"]E;3X@:V%N(&AE;G1E<R`E<RX`2V]N=&]E;B`B)7,B(&5R('-L
M971T970N`$MO;G1O96X@(B5S(B!E<B!G96UT+@!6961HYF9T96QS96X@:6MK
M92!F=6YD970N`$MA;&5N9&5R+61A=&$@97(@=6=Y;&1I9P!3:W)I=FYI;F=S
M=FEN9'5E="!K86X@:6MK92#E8FYE<RX@($5R(&1I;B!P;W`M=7`M8FQO:VME
M<B!A:W1I=F5R970_`$EN9&AO;&1E="!A9B!-86-I;G1O<V@M9FEL96X@9F]R
M969I;F1E<R!N961E;F9O<BX`1&4H;BD@86MT=65L;&4@;6%P<&4H<BD@(B5S
M(B!V:6P@8FQI=F4@;VUD^&)T('1I;"`B)7,B+@!$96X@86MT=65L;&4@;&ES
M=&4@;W9E<B!B<G5G97)E+"!S;VT@:&%R(&%D9V%N9R!T:6P@9&5N;F4@;6%P
M<&4L(&MU;FYE(&EK:V4@:&5N=&5S`$ML861D96X@97(@9V5M="!I("(E<R(@
M;6%P<&5N+@!(YFYD96QS96X@97(@:6YD<V%T(&D@9&EN(&MA;&5N9&5R+@!&
M96QT970@(B5S(B!K86X@:6MK92!E:W-P86YD97)E<RX`36%P<&5N("(E<R(@
M9FEN9&5S(&%L;&5R961E`$UA<'!E;B`B)7,B(&EN9&AO;&1E<B!U;&]V;&EG
M92!T96=N(&D@;F%V;F5T+B!$971T92!K86X@9OAR92!T:6P@<')O8FQE;65R
M+B!+;VYT86MT('9E;FQI9W-T(&1I;B!S>7-T96UA9&UI;FES=')A=&]R+@!-
M87!P96X@(B5S(B!B;&5V(&]P<F5T=&5T+"!M96X@9&5N(&)L978@:6MK92!A
M:W1I=F5R970N`$UA<'!E;B`B)7,B(&)L978@<VQE='1E="P@;65N(&1E;B!K
M=6YN92!I:VME(&1E86MT:79E<F5S+@!-87!P96X@(B5S(B!B;&5V(&EK:V4@
M;W!R971T970N(%-E<G9E<F5N<R!B97-K960@:V]M;65R(&AE<@!-87!P96X@
M(B5S(B!B;&5V(&EK:V4@<VQE='1E="X@4V5R=F5R96YS(&)E<VME9"!K;VUM
M97(@:&5R`$UA<'!E;B`B)7,B(&5R(&)L979E="!O<')E='1E="X`36%P<&5N
M("(E<R(@97(@8FQE=F5T('-L971T970N`$UA<'!E;B`B)7,B(&)L978@;VUD
M^&)T('1I;"`B)7,B+@!&^&QG96YD92!F:6QE<B!E<B!HYF9T970@=&EL(&1E
M;FYE(&1E;#H`5FEN9'5E="!T:6P@;&%G<FEN9R!A9B!B:6QL961E<B!K=6YN
M92!I:VME(.5B;F5S+B`@17(@9&EN('!O<'5P+6)L;VMK97(@86MT:79E<F5T
M/P!":6QL961E<FYE('9I;"!B;&EV92!V:7,@9F]R9&D@869S96YD97)E;B!F
M:6YD97,@:2!D:70@861R97-S96MA<G1O=&5K+@!-86EL+7-E<G9E<F5N(&=E
M;F5R97)E9&4@9OAL9V5N9&4@9F5J;"UB97-K960Z`$UA:6PM<V5R=F5R96X@
M9&%N;F5D92!D96YN92!I;F9O<FUA=&EV92!M961D96QE;'-E.@!-86EL+7-E
M<G9E<F5N(&=E;F5R97)E9&4@9OAL9V5N9&4@8F5S:V5D.@!-87!P96X@)7,@
M86QL97)E9&4@=&]M+@!"97-K961E;B`B)7,B(&9R82`B)7,B("@E9"!B>71E
M*2!O=F5R<VMR:61E<B!S=/AR<F5L<V5S9W+F;G-E;B!V960@:&5N=&YI;F<N
M`$)E<VME9&5N+"!D97(@<VMR:79E<R!PY2P@97(@;'5K:V5T+B!!9G-L=71T
M97(N`$)E<VME9&5N(&5R('-L971T970N`$)E<VME9&5N(&5R('9E<FEF:6-E
M<F5T+@!"97-K961E;B!E<B!V97)I9FEC97)E="X@069S96YD97(Z("5S+@!,
M^'-E;BUV:6YD=65T(&MU;FYE(&EK:V4@Y6)N97,N("!%<B!D:6X@<&]P=7`M
M8FQO:VME<B!S;.5E="!T:6P_`%+E=&5K<W1E;B!A9B!D96X@;V9F96YT;&EG
M92!01U`M;OAG;&4@8V%N('9I<V5S("5S+@!$96X@9F]R97-P=7)G=&4@9FEL
M(&9I;F1E<R!I:VME(&D@35,M5$Y%1BUV961HYFYG970N`$1E;B!F;W)E<W!U
M<F=T92!F:6P@9FEN9&5S(&EK:V4@:2!::7`M=F5D:.9N9V5T+@!!9G-E;F1E
M<F5N(&%F(&1E;FYE(&)E<VME9"!A;FUO9&5R(&]M(&5N(#QE;3Y-97-S86=E
M($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`H341.*3PO96T^(&9R82!D:6<L
M(&[E<B!D=2!H87(@;.9S="!B97-K961E;BX@($-L:6-K("5S(&9O<B!A="!A
M9G-E;F1E(&YO=&ET<V5N+@!397)V97)E;B!K=6YN92!I:VME(&1A;FYE(&5T
M(&9R:6WF<FME(&%F(&)I;&QE9&5T+@!$:6X@<VEG;F%T=7(@:W5N;F4@:6MK
M92!E<G-T871T97,N`$1I;B!S:6=N871U<B!E<B!B;&5V970@<F5T=&5T+@!$
M96X@9F]R97-P=7)G=&4@9FEL92!F:6YD97,@:6MK92X`0G)E=G!A<&ER970@
M(B5S(B!E<B!T:6QF^&IE="X`0G)E=G!A<&ER970@(B5S(B!E<B!S;&5T=&5T
M+@!"<F5V<&%P:7)E="`B)7,B(&5R(.9N9')E="X`3W!G879E;B!T:6P@<V%T
M('#E(&1I;B!O<&=A=F5L:7-T92X`0G+X9'1E:W-T96X`0F5S:V5D96YS(&)R
M^&1T96MS="!K86X@<V5S("5S+@!$96X@<F5T=7)N97)E9&4@8F5S:V5D<R!B
M<OAD=&5K<W0`1&5N(')E='5R;F5R961E(&)E<VME9',@8G+X9'1E:W-T(&MA
M;B!S97,@)7,N`$)R^&1T96MS=&5N(&%F(&1E;B!S96YD=&4@8F5S:V5D`$1E
M;B!A9G-E;F1T92!B97-K961S(&)R^&1T96MS="!K86X@<V5S("5S+@!"<G5G
M97)E;G,@;&5D:6<O;W!T86=E="UI;F9O<FUA=&EO;B!E<B!G96UT+@!$97(@
M9FEN9&5S(&EK:V4@;F]G96X@86QT97)N871I=B!D96PL('-O;2!K86X@=FES
M97,@:6YD;&5J<F5T+@!$97(@97(@:6YG96X@8F5S:V5D97(@:6X@9&5N;F4@
M;6%I;&)O>"X`1&5R(&9I;F1E<R!I;F=E;B!B<OAD=&5K<W0L('-O;2!K86X@
M=FES97,@:6YD;&5J<F5T+@!$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@
M=/AM;FEN9R!A9B`E<RX@1&5T=&4@97(L(&AV860@<V5R=F5R96X@<W9A<F5D
M90!$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@=/AM;FEN9R!A9B!M86EL
M8F]X96XN(%-E<G9E<F5N('-V87)E9&4Z("5S`$1E<B!O<'-T;V0@970@<')O
M8FQE;2!U;F1E<B!T^&UN:6YG(&%F(&UA:6QB;WAE;BX@1&5T=&4@97(L(&AV
M860@<V5R=F5R96X@<W9A<F5D90!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@
M:V]P:65R:6YG(&%F(&)E<VME9&5R(&9R82`B)7,B('1I;"`B)7,B+B!397)V
M97)E;B!S:W)I=F5R`$1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!S;&5T;FEN
M9V5N(&%F(&)E<VME9&5N(&9R82!M87!P96X@(B5S(BX@2&5R(&5R(&)E<VME
M9&5N(&9R82!S97)V97)E;@!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@<VQE
M=&YI;F=E;B!A9B!B97-K961E<B!I(&UA<'!E;B`B)7,B+B!(97(@97(@8F5S
M:V5D96X@9G)A('-E<G9E<F5N`$1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!S
M;&5T;FEN9R!A9B!B97-K961E<BX@4V5R=F5R96X@<VMR978Z("5S`$1E<B!O
M<'-T;V0@96X@9F5J;"!U;F1E<B!S;&5T;FEN9R!A9B!HYFYD96QS96XZ("5S
M+@!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@=FES;FEN9R!A9B!D96YN92!B
M97-K961D96P`1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&UA<FME<FEN9R!A
M9B!B97-K961E<B!I(&UA<'!E;B`B)7,B+B!$971T92!E<B!B97-K961E;F9R
M82!S97)V97)E;@!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T97)I
M;F=E;B!A9B`E<RX`1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R
M:6YG96X@868@:.9N9&5L<V4Z("5S+@!$97(@;W!S=&]D(&5N(&9E:FP@=6YD
M97(@:6UP;W)T97)I;F=E;B!A9B!O<&=A=F5N.B`E<RX`1&5R(&]P<W1O9"!E
M;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG96X@868@8G)U9V5R<PIL961I9R]O
M<'1A9V5T(&EN9F]R;6%T:6]N.B`E<P!$97(@;W!S=&]D(&5N(&9E:FP@=6YD
M97(@9FQY=&YI;F=E;B!A9B!B97-K961E<B!F<F$@(B5S(B!T:6P@(B5S(BX*
M4V5R=F5R96X@<VMR978`1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&QA9W)I
M;F<@868@9&5N;F4@8F5S:V5D('-O;2!K;&%D9&4N`$1E<B!O<'-T;V0@96X@
M9F5J;"!U;F1E<B!A9G-E;F1E;'-E;B!A9B!D:6X@8F5S:V5D.B`E<P!$97(@
M;W!S=&]D(&5N(&9E:FP@=6YD97(@YFYD<FEN9V5N(&%F(&CF;F1E;'-E;CH@
M)7,N`$1E<B!V87(@:6YG96X@=&5K<W0@:2!D96YN92!D96P@868@8F5S:V5D
M96X`2%1-3"UB97-K961E;B!H87(@:6YD;&5J<F5D92!B:6QL961E<BX`1&5N
M;F4@2%1-3"UB97-K960@:&%R(&EN9&QE:G)E9&4@8FEL;&5D97(N("!";&]K
M:V5R961E(&)I;&QE9&5R('9I<V5S('/E;&5D97,Z(`!$96YN92!O9F9E;G1L
M:6=E(%!'4"UN^&=L92!E<B!HYF9T970@=F5D(&)E<VME9&5N+@!$96YN92!H
M86YD;&EN9R!E<B!I:VME('5N9&5R<W3X='1E="X`1&5N;F4@:&%N9&QI;F<@
M97(@96YD;G4@:6MK92!I;7!L96UE;G1E<F5T+@!$971T92!T86=E<B!N;VL@
M;F]G970@=&ED+B!%<B!D=2!S:6MK97(@<.4L(&%T(&1U('9I;"!F;W)T<^9T
M=&4@/P!"97-K961E;B!I;F1E:&]L9&5R(&5N($UA8VEN=&]S:"UF:6PN`$)E
M<VME9&5N(&UE9&)R:6YG97(@96X@=F5D:.9F=&5L<V4L('-O;2!E<B!D:6=I
M=&%L="!S:6=N97)E="!V:6$@4R]-24U%+@!"97-K961E;B!M961B<FEN9V5R
M(&5N('9E9&CF9G1E;'-E+"!S;VT@97(@:W)Y<'1E<F5T('9I82!3+TU)344N
M`$)E<VME9&5N(&EN9&5H;VQD97(@/&5M/FUA:6P@9&5L:79E<GD@<W1A='5S
M/"]E;3X@:6YF;W)M871I;VXL(&UE;B!F;W)M871E="!A9B!B97-K961E;B!E
M<B!U:V5N9'0N`$)E<VME9&5N('-Y;F5S(&EK:V4@870@=N9R92!E;B!G>6QD
M:6<@4$=0+6MR>7!T97)E="!B97-K960N("!&96IL.B``0F5S:V5D96X@<WEN
M97,@:6MK92!A="!VYG)E(&D@:V]R<F5K="!01U`M9F]R;6%T("AJYG9N9OAR
M(%)&0R`R,#$U*2X`0F5S:V5D96X@<WEN97,@:6MK92!A="!VYG)E(&D@:V]R
M<F5K="!3+TU)344M9F]R;6%T+@!"97-K961E;B!E<B!D:6=I=&%L="!S:6=N
M97)E="!V:6$@4$=0+@!"97-K961E;B!E<B!D:6=I=&%L="!S:6=N97)E="!V
M:6$@4R]-24U%+@!"97-K961E;B!E<B!K<GEP=&5R970@=FEA(%,O34E-12X`
M0F5S:V5D96X@97(@:W)Y<'1E<F5T(&UE9"!01U`N`$1E;FYE(&)E<VME9"!T
M:6P`1&5N;F4@<V5R=F5R('5N9&5R<W3X='1E<B!I:VME(&1E;&EN9R!A9B!M
M87!P97(N`$1E='1E('9I;F1U92!S:V%L(&%N<N5B97,@9G)A(&5N('-K<FEV
M;FEN9W-V:6YD=64N`%1RY61E="!V:7-N:6YG`%1RY61E="!V:7-N:6YG`%1I
M=&5L`%1I;`!4;SH@061R97-S90!&;W(@870@;6%R:V5R92!F;&5R92!F96QT
M97(@<VMA;"!D=2!H;VQD92!#=')L("A00RD@96QL97(@0V]M;6%N9"`H36%C
M*2!N961E+"!M961E;G,@9'4@:VQI:VME<BX`1F]R(&%T(&)R=6=E(&5N(%1,
M4RUF;W)B:6YD96QS92!S:V%L(&1U(&%N=F5N9&4@4$A0(#4N,"XV(&5L;&5R
M(&CX:F5R92X`5F5D:.9F=&5L<V5R<R!T;W1A;&4@<W3X<G)E;'-E.@!3:W)A
M;&1E<W!A;F0`4VMR86QD97-P86YD.@!54DP`2W5N;F4@:6MK92!FY2!F;W)B
M:6YD96QS92!T:6P@4U%,('-E<G9E<F5N+@!+=6YN92!I:VME(&AE;G1E(&MV
M;W1E`$MU;FYE(&EK:V4@;W9E<G/F='1E(&1E='1E(%=O<F0@9&]K=6UE;G0`
M56)E<W9A<F5T`%5B97-V87)E9&4@8F5S:V5D97(`1F]R=')Y9"!S;&5T;FEN
M9P!):VME('9I<W1E(&UO9'1A9V5R90!&;W)T<GED(.9N9')I;F=E<@!5:.5N
M9'1E<F5T(&MO;7!O;F5N="!A9B!T>7!E.B`E<P!5:V5N9'0@9&%T;P!5:V5N
M9'0@24U!4"!R97-P;VYS(&9R82!S97)V97)E;BX@4V5R=F5R(&UE;&1T93H@
M)7,`56ME;F1T(&WX9&4`56ME;F1T(&UO9'1A9V5R`$]P:.9V(&SX<V5N`$EK
M:V4@;F%V;F=I=F5T`%5LYG-T`$1E86MT:79E<B!M87!P92AR*0!/<&1A=.ER
M(&EN9F]R;6%T:6]N(&]M('9E9&CF9G1E;'-E`$]P9&%TZ7(@<W1A='5S(&]N
M(')E<W!O;F1E;G0`57!L;V%D`$)R=6<@<W1A;F1A<F1VYG)D:0!"<G5G($E-
M05`@;6%P<&4@86MT:79E<FEN9V5R/P!!;G9E;F0@=FER='5E;"!S:W)A;&1E
M<W!A;F0_`$)R=6=E<@!"<G5G97(@(B5S(B!T:6QD96QT(&1E(&=I=FYE(')E
M='1I9VAE9&5R('1I;"!M87!P92`B)7,B+@!"<G5G97)N879N`$)R=6=E<FYA
M=FXZ`$)R=6=E<F4@:2!S>7-T96UE=#H`4V4`5FES("5S`%-E("5S(&]F9F5N
M=&QI9R!N^&=L90!392!(5$U,+6EN9&AO;&0@:2!E="!S97!E<F%T('9I;F1U
M90!392!B97-K961E<@!392!E9V5N('!R:79A="!N^&=L90!392!E9V5N(&]F
M9F5N=&QI9R!N^&=L90!392!T<N5D`%-E(&9R:6WF<FME`%-E('9E9&CF9G1E
M;'-E<B!I(&5T('-E<&5R870@=FEN9'5E`%-E(&EN9&AO;&0@:2!E="!S97!E
M<F%T('9I;F1U92X`4V4@:.9N9&5L<V4`4V4@8F5S:V5D(&D@)7,`5FES;FEN
M9R!E;&QE<B!B<F5V8F%K:V4L('-O;2!V:7-E(&5F=&5R(&QO9VEN.@!392!O
M<&=A=F4`4V4@8FEL;&5D97)N90!6:7)T=65L(&UA<'!E("(E<R(@97(@9&%N
M;F5T+@!6:7)T=65L;&4@;6%P<&5R`%9I<G1U96QL92!M87!P97(@:W+F=F5R
M(&5N('9I9VYE="X`5FER='5E;"!I;F1B86MK90!6:7)T=65L(&EN9&)A:VME
M(&UA<'!E`%9I<G1U96P@<VMR86QD97-P86YD`%9I<G1U96P@<VMR86QD97-P
M86YD`%9I<G1U96P@;6%P<&4@=FEG;F5T`$%D=F%R<V5L`%5G96YT;&EG`%9E
M;&MO;6UE;B!T:6P@)7,`5F5L:V]M;65N+"`E<P!(=F%D('-K86P@9&5R('-K
M92!M960@<W!A;2UB97-K961E<B!E9G1E<B!A="!D92!E<B!I;F1B97)E='1E
M="!S;VT@<W!A;2!E;&QE<B!U<VMY;&1I9S\`3N5R(&1U('-L971T97(@8F5S
M:V5D97(L('-K86P@9&4@9FQY='1E<R!T:6P@<VMR86QD97-P86YD96X@:2!S
M=&5D970@9F]R(&%T(&UA<FME<F4@9&5M('-O;2!S;&5T=&5T/P!(=FEL:V5N
M('-I9&4@^&YS:V5R(&1U('/E(&%T('-T87)T92!PY2!V960@Y6)N:6YG(&%F
M(&5N(&YY(&)R979B86MK93\`4VMA;"!V961HYF9T96QS97(@9V5M;65S('9E
M9"!L86=R:6YG(&%F(&%F<V5N9'0@92UM86EL/P!(=FEL:V5T(&1O;>9N92!S
M:V%L(&5F=&5R<VMR:79E<R!U9G5L9'-TYFYD:6=E(&%D<F5S<V5R("AE+6UA
M:6PM861R97-S97(@=61E;B`B0"(I('9E9"!A9G-E;F1E;'-E(&%F(&4M;6%I
M;"!E;&QE<B!U9'9I9&1E;'-E(&%F(&%D<F5S<V5R/P!0;W-I=&EV;&ES=&4`
M061R97-S92`H87)B96ID92D`5&5L969O;B`H87)B96ID92D`Q<4`Q7)L:6<`
M2F$`1'4@97(@=F5D(&%T(&AE;G1E(&4M;6%I;"!F<F$@9OAL9V5N9&4@:V]N
M=&\O:V]N=&DZ`$1U(&5R('9E9"!A="!S;&5T=&4@86QL92!B97-K961E<B!I
M;F1E:&]L9'0@:2!F^&QG96YD92!M87!P92X`1'4@97(@=F5D(&%T('-L971T
M92!D92AN*2!F^&QG96YD92!M87!P92AR*2X`1'4@97(@=F5D(&%T(&MO<&EE
M<F4O9FQY='1E('1I;"!E;B!N>2!M87!P92X`1'4@97(@=F5D(&%T(&]P<F5T
M=&4@96X@=6YD97)M87!P92!T:6P@`$1U(&5R('9E9"!A="!O<')E='1E(&5N
M(&UA<'!E('#E(&CX:F5S=&4@;FEV96%U+@!$=2!H87(@:6MK92!T:6QL861E
M;'-E('1I;"!A="!D86YN92!M87!P97(N`$1U(&AA<B!I:VME('1I;&QA9&5L
M<V4@=&EL(&%T(&1A;FYE(&9L97)E(&5N9"`E9"!M87!P97(N`$1U(&5R('9E
M9"!A="!O;63X8F4@;6%P<&5N.B``1'4@:V%N(&EK:V4@9&5A:W1I=F5R92`B
M)7,B+@!$=2!K86X@8F5N>71T92!D:7-S92!E<G-T871N:6YG97(@:2!B<F5V
M<&%P:7(M=&5K<W1E;CH@)6,@9F]R(&1E;B!A:W1U96QL92!B<OAD=&5K<W0[
M("5S(&9O<B!S:6=N871U<F5N+@!$=2!A8V-E<'1E<F5D92!I:VME(&)R=6=S
M8F5T:6YG96QS97)N92P@:'9O<G9E9"!D=2!E<B!B;&5V970@;N9G=&5T(&%D
M9V%N9RX`1'4@:&%R(&EK:V4@=&EL;&%D96QS92!T:6P@870@YFYD<F4@861G
M86YG('1I;"!D96YN92!M87!P90!$=2!V:61E<F5S96YD=&4@9&5N;F4@8F5S
M:V5D(&1E;B`E)7,@=&EL(&;X;&=E;F1E(&UO9'1A9V5R93H@)7,N`$1U(&AA
M<B`E<R!N>64@8F5S:V5D97(N`$1U(&AA<B`Q(&YY(&)E<VME9"X`1&5N;F4@
M<VED92!E<B!A;&QE<F5D92!A9G-E;F1T+@!$=2!H87(@;6EN9'-T(.EN('9E
M9&CF9G1E;'-E(&UA<FME<F5T+"!S;VT@9'4@96YD;G4@:6MK92!H87(@:&5N
M=&5T+B`@17(@9'4@<VEK:V5R('#E+"!A="!V:6P@<V5N9&4@8F5S:V5D('5D
M96X@9&ES<V4@=F5D:.9F=&5L<V5R/P!$=2!H87(@;GEE(&)E<VME9&5R(&D@
M9OAL9V5N9&4@;6%P<&4Z`$1U(&AA<B!N>64@8F5S:V5D97(@:2!F^&QG96YD
M92!M87!P97(Z`$1U(&)L:79E<B!N^&0@=&EL(&%T(&QA=F4@96X@<')O8FQE
M;6)E<VMR:79E;'-E+"!F^'(@9'4@:V%N('-E;F1E(&1E;B!I;F0N`$1E<B!S
M:V%L(&%N9VEV97,@;6EN9'-T(&5N(&UO9'1A9V5R+@!$=2!S:V%L(&%N9VEV
M92!L^'-E;F5T('1I;"!D:6X@<')I=F%T92!01U`M;OAG;&4@9F]R(&%T('-E
M(&1E;FYE(&)E<VME9`!$=2!S:V%L(&%N9VEV92!L^'-E;F5T('1I;"!D:6X@
M<')I=F%T92!3+TU)344M;OAG;&4@9F]R(&%T('-E(&1E;FYE(&)E<VME9`!6
MYFQG(&UA:6QB;W@@9OAR<W0L('-O;2!S:V%L(&%N=F5N9&5S+@!$=2!S:V%L
M(';F;&=E(&5N(&MO;G1O+"!S;VT@9'4@=FEL('-L971T92X`1'4@<VMA;"!F
M^')S="!VYFQG92!E;B!A9')E<W-E+@!$=2!S:V%L(';F;&=E(&UI;F1S="!E
M;B!B97-K960@9OAR<W0N`$1U('-K86P@86YG:79E(&5N(&UO9'1A9V5R+@!$
M=2!S:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D=2!V:6P@9FIE<FYE
M+@!$=2!S:V%L(&%N9VEV92!M:6YD<W0@Z6X@9FEL+"!D97(@<VMA;"!V961H
MYF9T97,N`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I
M;"!T:6QF^&IE+@!$=2!B;&EV97(@;OAD="!T:6P@870@:&%V92`B)7,B('-L
MY65T('1I;"!I(&1I;F4@=F5D;&EG96AO;&1E;'-E<VEN9'-T:6QL:6YG97(N
M`$1U(&]M861R97-S97)E9&4@9&5N;F4@8F5S:V5D('1I;"`E<R!D96X@)25S
M+@!$=2!B97-V87)E9&4@9&5N;F4@8F5S:V5D(&1E;B`E<RX`(B5S(B!B;&5V
M(&EK:V4@86MT:79E<F5T+B!(97(@97(@8F5S:V5D96X@9G)A('-E<G9E<F5N
M`"(E<R(@8FQE=B!I:VME(&1E86MT:79E<F5T+B!(97(@97(@8F5S:V5D96X@
M9G)A('-E<G9E<F5N`"(E<R(@8FQE=B!A:W1I=F5R970`(B5S(B!B;&5V(&1E
M86MT:79E<F5T`$1I="!N879N`$1I;F4@;V9F96YT;&EG92]P<FEV871E(%!'
M4"UN^&=L97(`1&EN('!R:79A=&4@;OAG;&4`1&EN(&]F9F5N=&QI9V4@;OAG
M;&4`92UM86EL+6%D<F5S<V5N+"!S;VT@86YD<F4@<V5N9&5R('-V87(@=&EL
M("A297!L>2UT;SHI(#QE;3XH=F%L9V9R:2D\+V5M/@!$:6YE(&]F9F5N=&QI
M9V4O<')I=F%T92!3+TU)344M8V5R=&EF:6MA=&5R`$1I;F4@:V]N=&DZ`$1I
M;F4@86QI87,M861R97-S97(Z(#QE;3XH=F%L9V9R:2P@Z6X@861R97-S92!P
M<BX@;&EN:64I/"]E;3X`1&EN(&%U=&]R:7-A=&EO;G,M8F%C:V5N9"!U;F1E
M<G-T^'1T97(@:6MK92!O<&QI<W1N:6YG96X@868@8G)U9V5R92!E;&QE<B!E
M<B!D96X@9G5N:W1I;VX@868@96X@96QL97(@86YD96X@9W)U;F0@8FQE=F5T
M('-LY65T(&9R82X`1&EN(&)R;W=S97(@=6YD97)S=/AT=&5R(&EK:V4@:6YD
M;&5J<F5T('9I<VYI;F<@868@9&5T=&4@8FEL;&5D9F]R;6%T+@!$:70@;F]R
M;6%L92!T96=N<^9T('1I;"!A9G-E;F1E;'-E(&%F(&)E<VME9&5R.@!$:6X@
M;F]R;6%L92!K<GEP=&5R:6YG<VUE=&]D92!T:6P@869S96YD96QS92!A9B!B
M97-K961E<CH`1&EN(&)E<VME9"!E<B!A9FQE=F5R970N`$1I;B!S:6=N871U
M<CH`6TEN=&5T(&5M;F5=`%M0<F]B;&5M8F5S:W)I=F5L<V5=`$)C8P!";&%C
M:VQI<W1E`$-C`%-L970`36%P<&5R`%!R;V9I;`!);F1B86MK90!,;V<@=60`
M2VEL9&5T96MS=`!.>64@8F5S:V5D`%5D<VMR:78`4')I;W)I=&5T`$=E;F]P
M9G)I<VL@)7,`4W9A<@!3^&<`069S96YD(&)E<VME9`!4<N5D`%1I;`!&;W)T
M<GED('-L971N:6YG`%-E('1RY60`4&]S:71I=FQI<W1E`&%D<F5S<V5N="!U
M:V5N9'0`=F5D:.9F=&5L<V4`=F5D:.9F=&5L<V5R+GII<`!O:W1E=&5R`&MA
M;B!I:VME(&1A;FYE('5D9&%T82UF:6P`:V%N(&EK:V4@Y6)N92!I;F1D871A
M`&9E:FP@=F5D(&%N=F5N9&5L<V4@868@:V]M;6%N9&\M;&EN:64`:V]N9FEG
M=7)A=&EO;G-F96IL`&UA;F=L97(@:W)I=&ES:R!S>7-T96UF:6P`9F5J;"!I
M(&1A=&%F;W)M870`:6YD9V%N9R!I:VME(&9U;F1E=`!F<F$`=6ME;F1T(&UA
M<VMI;FYA=FX`:6YD9&%T82]U9&1A=&$M9F5J;`!I;G1E<FX@<V]F='=A<F4M
M9F5J;`!N^&=L90!B<F5V8F%K:V4M9FEL`&YA=FX`:6YG96X`96QL97(`=&EL
M;&%D96QS92!NYF=T970`9F5J;"!I('!R;W1O:V]L(&9R82!F:F5R;B!S:61E
M`'1J96YE<W1E('5T:6QGYFYG96QI9P!S=&%V969E:FP`<W1A=F5F96IL`'-Y
M<W1E;69E:FP`;6ED;&5R=&ED:6<@9F5J;'1I;'-T86YD`&1I;B!B;&%C:VQI
M<W1E`&1I;B!P;W-I=&EV;&ES=&4`````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+VQO8V%L92]D85]$2R]H96QP+GAM;```````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#$R-C4T,0`Q,#0Q-S,V,C<V,``P,C$P-S``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]X;6P@
M=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,2(_/@H\(2TM("1(
M;W)D93H@:6UP+VQO8V%L92]D85]$2R]H96QP+GAM;"QV(#$N,38N-BXT(#(P
M,#8O,#$O,S`@,34Z-3@Z,#0@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](F-O;7!O<V4M8G5T=&]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@
M/'1I=&QE/DYY(&UE9&1E;&5L<V4Z($AA;F1L:6YG97(\+W1I=&QE/@H@("`@
M/&AE861I;F<^2&%N9&QI;F=E<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M)U-E;F0@;65D9&5L96QS92<@<V5N9&5R(&1I;B!B97-K960@=&EL(&1E(&UO
M9'1A9V5R92!D=2!H87(@86YG:79E="X@5N9R('-I:VME<B!PY2!D=2!V:6P@
M<V5N9&4@9OAR(&1U(&ML:6MK97(L(&9O<B!NY7(@9'4@:&%R(&ML:6MK970@
M:V%N(&1U(&EK:V4@YFYD<F4@;F]G970N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@("='96T@:VQA9&1E)R!P;&%C97)E<B!E;B!U9N9R9&EG(&UE9&1E
M;&5L<V4@:2!D96X@;6%P<&4@9'4@:&%R('9A;&=T(&D@("=);F1S=&EL;&EN
M9V5R+29G=#M3:W)I=B!M961D96QE;'-E)RX@1'4@:V%N('/E(&;F<F1I9V?X
M<F4@;65D9&5L96QS96X@<V5N97)E('9E9"!A="!GY2!T:6P@)TML861D92<@
M;6%P<&5N+"!K;&EK:V4@<.4@9&5N(&=E;71E(&UE9&1E;&5L<V4@;V<@<^4@
M:VQI:VME('#E("=F;W)T<^9T)RX@4_AR9R!F;W(@870@<VMR:79E(&5N("=%
M;6YE.B<@;&EN:64@9OAR(&1U(&=E;6UE<B!D96X@<^4@9'4@;F5M="!K86X@
M9FEN9&4@9&5N(&EG96X@:2`G2VQA9&1E)R!M87!P96XN($5F=&5R(&1U(&AA
M<B!G96UT(&UE9&1E;&5L<V5N(&D@)TML861D92<@;6%P<&5N(')E='5R;F5R
M97,@9'4@=&EL(&1I;B!)3D1"04M+12!E;&QE<B!D96X@;6%P<&4@9'4@<VED
M<W0@8F5F86YD="!D:6<@:2X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M)T%N;G5L;&5R(&UE9&1E;&5L<V4G('-M:61E<B!M961D96QE;'-E;B!VYFL@
M;V<@<F5T=7)N97)E<B!D:6<@=&EL(&1I;B!)3D1"04M+12!E;&QE<B!D96X@
M;6%P<&4@9'4@<VED<W0@8F5F86YD="!D:6<@:2X*("`@(#PO<&%R83X*/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@06-T:6]N<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY!8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!396YD($UE<W-A9V4@;&%U;F-H97,@>6]U<B!E;6%I;"!T;R!T:&4@
M:6YT96YD960@<F5C:7!I96YT*',I+B!"92!S=7)E('EO=2!W86YT('1O('-E
M;F0@8F5F;W)E(&-L:6-K:6YG(&AE<F4@87,@;VYC92!S96YT(&ET(&-A;FYO
M="!B92!T86ME;B!B86-K+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3
M879E($1R869T('!L86-E<R!A;B!U;F9I;FES:&5D(&UE<W-A9V4@:6X@82!F
M;VQD97(@8V%L;&5D("=$<F%F=',G"F%C8V5S<VEB;&4@8GD@=&AE('!O<"UD
M;W=N(&)O>"!O;B!T:&4@<FEG:'0@<VED92!O9B!T:&4@8FQU92!N879I9V%T
M:6]N(&)A<B!A="!T;W`N(%EO=2!C86X@=&AE;B!F:6YI<V@@=&AE(&UE<W-A
M9V4@;&%T97(@8GD@<W=I=&-H:6YG('1O('1H92`G1')A9G1S)R!F;VQD97(L
M(&-L:6-K:6YG(&]N('1H92!S879E9"!M97-S86=E('1O(&]P96X@:70L(&%N
M9"!T:&5N(&-L:6-K:6YG(&]N("=297-U;64G+B!"92!S=7)E('1O('!U="!A
M('-U8FIE8W0@;VX@=&AE(&5M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A
M9G0@<V\@=&AA="!Y;W4@8V%N(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S
M86=E('EO=2!W86YT('=I=&AI;B!T:&4@1')A9G1S(&9O;&1E<BX@069T97(@
M<V%V:6YG(&%S(&$@1')A9G0L('EO=2!A<F4@<F5T=7)N960@=&\@>6]U<B!)
M3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#86YC96P@365S<V%G92!D
M<F]P<R!T:&4@;65S<V%G92!I;B!P<F]G<F5S<R!A;F0@<VEM<&QY(')E='5R
M;G,@>6]U('1O('1H92!)3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E
M<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB('-T871E/2)U;FMN;W=N
M(CX*("`@(#QT:71L93Y.>2!M961D96QE;'-E.B!&<F$\+W1I=&QE/@H@("`@
M/&AE861I;F<^(D9R82(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E='1E
M(&9E;'0@8G)U9V5S('1I;"!A="#F;F1R92!D:6X@869S96YD97)A9')E<W-E
M+B!&96QT970@97(@:W5N('1I;&?F;F=E;&EG="!H=FES(&1I;B!S>7-T96T@
M861M:6YI<W1R871O<B!I:VME(&AA<B!S<.9R<F5T(&1E="X*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@2'9I<R!D=2!I("));F1S=&EL;&EN9V5R)F=T
M.U!R;V9I;&5R(B!H87(@9FQE<F4@<')O9FEL97(@:V%N(&1U(';F;&=E(&D@
M;&ES=&5N(&AV:6QK96X@<')O9FEL(&1E<B!V:6P@9G)E;7-TY2!S;VT@869S
M96YD97(N($AV:7,@9'4@=FEL(&%N9VEV92!E;B!H96QT(&YY(&%F<V5N9&5R
M(&MA;B!D=2!B96YY='1E('1E:W-T9F5L=&5T+B`*("`@(#PO<&%R83X*/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M9G)O;2(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@1G)O;3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SXF<75O=#M&<F]M)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!%;G1E<B!Y;W5R(&-O<G)E8W0@96UA:6P@861D<F5S<RX@66]U
M<B!E;6%I;"!A9&1R97-S(&ES(&%U=&]M871I8V%L;'D@96YT97)E9"!F;W(@
M>6]U(&9O;&QO=VEN9R`F<75O=#M&<F]M.B9Q=6]T.R!I;B!O=71G;VEN9R!E
M;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UT;R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/DYY(&UE9&1E;&5L<V4Z(%1I;#PO=&ET;&4^"B`@("`\:&5A9&EN9SXB5&EL
M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@2&5R(&MA;B!D=2!S:W)I=F4@
M861R97-S96X@<.4@<&5R<V]N97(@9&5R('-K86P@;6]D=&%G92!D:6X@;65D
M9&5L96QS92X@2'9I<R!D=2!V:6P@<V5N9&4@=&EL(&9L97)E(&UO9'1A9V5R
M92!S:V%L(&1E<F5S(&%D<F5S<V5R(&%D<VMI;&QE<R!M960@:V]M;6$L(&5L
M;&5R<R!O<'-TY7(@9&5R(&5N(&9E:FPN"B`@("`\+W!A<F$^"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+71O(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!4;SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SXF<75O=#M4;R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT
M97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@
M<F5C96EV92!Y;W5R(&UE<W-A9V4N(%EO=2!M=7-T('-E<&%R871E(&5A8V@@
M861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R('!U;F-T=6%T:6]N('=I;&P@
M<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[
M5&\Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN("`*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UC8R(@<W1A
M=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DYY(&UE9&1E;&5L<V4Z($MO<&D@
M=&EL("A#8SHI/"]T:71L93X*("`@(#QH96%D:6YG/B)+;W!I('1I;"`H0V,Z
M*2(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($AE<B!K86X@9'4@<VMR:79E
M(&%D<F5S<V5N('#E('!E<G-O;F5R(&1U(/AN<VME<B!S:V%L(&UO9'1A9V4@
M96X@:V]P:2`H0V,Z(#T@0V%R8F]N($-O<'DI(&%F(&1I;B!M961D96QE;'-E
M+B!!9'-K:6P@;6]D=&%G97)N92!M960@970@:V]M;6$N($MO<&EE<B!E<B!S
M;VT@<F5G96P@<V5N9'0@=&EL('!E<G-O;F5R('-O;2!E<B!K=6X@:6YD:7)E
M:W1E(&)E<OAR="!A9B!I;F1H;VQD970@868@;65D9&5L96QS96XN($%L;&4@
M;6]D=&%G97)E(&D@)U1I;#HG(&]G("=#8SHG(&MA;B!S92!A;&QE(&%N9')E
M(&UO9'1A9V5R92!I(&1I<W-E(&9E;'1E<BX*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8V,B/@H@("`@/'1I
M=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($-C/"]T:71L93X*("`@(#QH96%D
M:6YG/B9Q=6]T.T-C)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%
M;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T
M;R!R96-E:79E(&$@8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E+B!397!A
M<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA+B!9;W5R(&5N=')Y(&9O
M;&QO=W,@)G%U;W0[0V,Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN($-A<F)O
M;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA
M;B!T:&4@;VYE*',I(&)E:6YG('=R:71T96X@=&\@9&ER96-T;'D@8G5T(&%R
M92!I;7!O<G1A;G0@<F5C:7!I96YT<R!O9B!T:&4@96UA:6P@87,@=V5L;"P@
M=7-U86QL>2!S;VUE;VYE(&EN9&ER96-T;'D@8V]N8V5R;F5D(&%B;W5T('1H
M92!S=6)J96-T(&]F('1H92!E;6%I;"X@($%L;"`G5&\Z)R!R96-I<&EE;G1S
M(&%N9"`G0V,Z)R!R96-I<&EE;G1S(&-A;B!S964@=&AE(&5N=&ER92!L:7-T
M(&]F(&)O=&@@:VEN9',@;V8@<F5C:7!I96YT<RX*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UB8V,B('-T
M871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y.>2!M961D96QE;'-E.B!3:VIU
M;'0@:V]P:2!T:6P@*$)C8SHI/"]T:71L93X*("`@(#QH96%D:6YG/B)3:VIU
M;'0@:V]P:2(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($AE<B!K86X@9'4@
M<VMR:79E(&%D<F5S<V5R;F4@<.4@<&5R<V]N97(@9'4@^&YS:V5R('-K86P@
M;6]D=&%G92!E;B!S:VIU;'0@:V]P:2`H0F-C(#T@0FQI;F0@0V%R8F]N($-O
M<'DI(&%F(&)E<VME9&5N+B`B4VMJ=6QT(&MO<&DB(&UE9&1E;&5L<V5R(&5R
M('-O;2!R96=E;"!S96YD="!T:6P@<&5R<V]N97(@86YD<F4@96YD(&1E(&1I
M<F5K=&4@;V<@:6YD:7)E:W1E(&UO9'1A9V5R92`H5&EL.B!O9R!#8SHI('-O
M;2!H87(@8F5H;W8@9F]R(&%T(&SF<V4@;65D9&5L96QS96X@541%3B!A="!D
M92!A;F1R92!M;V1T86=E<F4@=F5D(&%T(&1E(&;E<B!M961D96QE;'-E;BX@
M1'9S+B`G4VMJ=6QT)R!B971Y9&5R(&%T(&ED96YT:71E=&5N(&%F(&1I<W-E
M(&UO9'1A9V5R92!E<B!S:VIU;'0@9G)A(&%L;&4@86YD<F4@;6]D=&%G97)E
M(&%F(&UE9&1E;&5L<V5N+"!O9R!A="!K=6X@9'4@;V<@9&4@=F5D(&%T(&1E
M(&UO9'1O9R!E;B!K;W!I+B!$971T92!E<B!T>7!I<VL@8G)U9W0@:2!S:71U
M871I;VYE<B!H=F]R(&1U(/AN<VME<B!A="!F;W)TYFQL92!E;B!A=71O<FET
M970@;F]G970@=61E;B!A="!P97)S;VYE;B!S;VT@9'4@<V5N9&5R(&UE9&1E
M;&5L<V5N('1I;"!B;&EV97(@86QA<FUE<F5T+@H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UB8V,B/@H@("`@
M/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($)C8SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SXF<75O=#M"8V,F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H
M;W-E('1O(')E8V5I=F4@82!B;&EN9"!C87)B;VX@8V]P>2!O9B!Y;W5R(&UE
M<W-A9V4N(%EO=2!M=7-T('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@
M8V]M;6$[(&]T:&5R('!U;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R
M<F]R+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[0F-C.B9Q=6]T.R!I;B!O
M=71G;VEN9R!M86EL+B!";&EN9"!C87)B;VX@8V]P:65S(&%R92!U<W5A;&QY
M('-E;G0@=&\@<&5O<&QE(&]T:&5R('1H86X@9&ER96-T(&%N9"!I;F1I<F5C
M="!R96-I<&EE;G1S("@F<75O=#M4;SHF<75O=#L@86YD("9Q=6]T.T-C.B9Q
M=6]T.R!R96-I<&EE;G1S*2!W:&\@;F5E9"!T;R!R96%D('=H870@:7,@8F5I
M;F<@=W)I='1E;B!A<R!W96QL(%=)5$A/550@=&AE(&]T:&5R(')E8VEP:65N
M=',@:VYO=VEN9R!T:&%T('1H97D@87)E(')E8V5I=FEN9R!T:&4@96UA:6PN
M(%1H=7,@)V)L:6YD)R!M96%N<R!T:&%T('1H92!I9&5N=&ET>2!O9B!T:&5S
M92!R96-I<&EE;G1S(&ES(&AI9&1E;B!F<F]M(&%L;"!O=&AE<B!R96-I<&EE
M;G1S(&]F('1H92!E;6%I;"P@86YD(&]N;'D@>6]U(&%N9"!T:&5Y(&MN;W<@
M=&AE>2!G;W0@82!C;W!Y+B!9;W4@='EP:6-A;&QY('5S92!T:&ES('1O('1E
M;&P@86X@875T:&]R:71Y(&9I9W5R92!T:&%T('EO=2!A<F4@=&5L;&EN9R!S
M;VUE;VYE('-O;65T:&EN9R!W:71H;W5T(&%L87)M:6YG('1H92!P97)S;VX@
M>6]U(&%R92!S96YD:6YG('1H92!A8W1U86P@96UA:6P@=&\N"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M<W5B:F5C="(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DYY(&UE9&1E
M;&5L<V4Z($5M;F4\+W1I=&QE/@H@("`@/&AE861I;F<^(D5M;F4B/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!3:W)I=B!E;6YE="!PY2!D:6X@;65D9&5L
M96QS92X@3&%V(&1E;B!K;W)T+"!S:6UP96P@;V<@:6YF;W)M871I=BX@16UN
M96QI;FEE;B!E<B!D96X@;F5M;65S=&4@;>5D92!F;W(@9&EG(&]G(&1I;F4@
M:V]R<F5S<&]N9&%N8V5P87)T;F5R92!A="!H=7-K92!H=F%D(&1E<B!V87(@
M:2!E36%I;&5N(&]G(&?X<B!D970@;&5T=&5R92!A="!F;W(@9&EG(&%T(&AO
M;&1E('-T>7(@<.4@9&EN('!O<W0N($[E<B!D=2`B0F5S=F%R97(B(&5L;&5R
M(")6:61E<F5S96YD97(B(&5-86EL96X@8FQI=F5R(&5M;F4@;&EN:65N(&MO
M<&EE<F5T(&]G('#E(&1E;FYE(&WE9&4@97(@9&5T(&YE;70@870@9OAL9V4@
M96X@='+E9"!I(&MO;G9E<G-A=&EO;F5N+B!-96X@:'9I<R!D:6X@8F5S=F%R
M96QS92!E;&QE<B!V:61E<F5S96YD:6YG(&EN9&5H;VQD97(@;GEE(&EDZ65R
M(&MA;B!D=2#F;F1R92!I(&5M;F5L:6YI96X@<^4@;6]D=&%G97)N92!K86X@
M9OAL9V4@;65D(&D@:'9O<F[E<B!D:7-K=7-S:6]N<V9O<FSX8F5T(.9N9')E
M<B!S:6<N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+7-U8FIE8W0B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ(%-U8FIE8W0\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[
M4W5B:F5C="9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@
M=&AE('-U8FIE8W0@;V8@>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y(&9O;&QO
M=W,@)G%U;W0[4W5B:F5C=#HF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@2V5E
M<"!I="!S:&]R="P@<VEM<&QE(&%N9"!D97-C<FEP=&EV92X@(%1H92!S=6)J
M96-T(&QI;F4@:7,@=&AE(&5A<VEE<W0@=V%Y(&9O<B!Y;W4@86YD('EO=7(@
M8V]R<F5S<&]N9&5N=',@=&\@<F5M96UB97(@=VAA="!W87,@:6X@=&AE(&5M
M86EL(&%N9"!T:'5S(&ES('9E<GD@:6UP;W)T86YT(&EN(&]R9V%N:7II;F<@
M>6]U<B!E;6%I;"!A;F0@9FEN9&EN9R!I;7!O<G1A;G0@;VYE<R!L871E<BX@
M($%L<V\L('=H96X@>6]U("=297!L>2<@;W(@)T9O<G=A<F0G(&%N9"!E;6%I
M;"!T:&ES('-U8FIE8W0@;&EN92!I<R!C;W!I960@;W9E<B!I;G1O('1H92!N
M97<@;65S<V%G92!A;F0@<V\@:7,@82!V86QU86)L92!W87D@;V8@=&5L;&EN
M9R!W:&%T(&UE<W-A9V5S(&=O('1O9V5T:&5R('1O(&9O<FT@82`F<75O=#MT
M:')E860F<75O=#L@;V8@82!C;VYV97)S871I;VXN("!(;W=E=F5R+"!I9B!T
M:&4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@8V]N=&%I;G,@;F5W(&ED96%S+"!Y
M;W4@;6%Y('=A;G0@=&\@861D('-I;7!L92!M;V1I9FEC871I;VYS('1O('1H
M92`G4W5B:F5C="<@;&EN92!S;R!T:&4@<F5C:7!I96YT*',I(&-A;B!F;VQL
M;W<@=&AE('!R;V=R97-S:6]N(&]F('1H92`F<75O=#MT:')E860N)G%U;W0[
M"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60]
M(F-O;7!O<V4M;W!T:6]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/DYY(&UE9&1E;&5L<V4Z($EN9'-T:6QL:6YG97(\+W1I=&QE/@H@("`@/&AE
M861I;F<^(DEN9'-T:6QL:6YG97(B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!$:7-S92!I;F1S=&EL;&EN9V5R(&=I=F5R(&1I9R!E:W-T<F$@9G5N:W1I
M;VYE<B!T:6P@;W!R971T96QS92!A9B!D:6X@;65D9&5L96QS92X*("`@(#PO
M<&%R83X*("`@($[E<B!D=2!K;&EK:V5R('#E("),878@970@;W!S;&%G('#E
M(&YA=FYE;F4B('9I;"!D92!A9')E<W-E<FYE('#E(&1E(&YA=FYE+"!D=2!H
M87(@:6YD=&%S=&5T(&D@5&EL.BP@0V,Z(&]G($)C8SH@8FQI=F4@<_AG="!I
M(&%D<F5S<V5K87)T;W1E:V5T+B`*("`@(#QP87)A/@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!+;&EK('#E(")3=&%V96MO;G1R;VPB(&9O<B!A="!U
M9&;X<F4@<W1A=F5K;VYT<F]L+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!+;&EK('#E(")6961HYF9T96QS97(B(&9O<B!A="!S92!E;B!L:7-T92!A
M9B!F:6QE<B!V961HYF9T970@=&EL(&UE9&1E;&5L<V5N+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("!+;&EK('#E(&-H96-K+6MN87!P96X@=F5D('-I
M9&5N(&%F(")'96T@:V]P:2(@9F]R(&%T(&=E;6UE(&5N(&MO<&D@868@9&5N
M;F4@;65D9&5L96QS92!I(&1I;B!F;VQD97(@9F]R(")396YD=&4@;65D9&5L
M96QS97(B+B!'96T@:V]P:65R(&%F('9I9W1I9V4@94UA:6QS(&1U('-E;F1E
M<BP@<^4@9'4@:&%R(&YO9V5T(&%T(')E9F5R97)E('1I;"!S96YE<F4@;V<@
M9F]R(&%T('9E9&QI9V5H;VQD92!E="!A<FMI=B!O=F5R(&AV860@9&5R(&)L
M978@<V5N9'0N(%9I(&%N8F5F86QE<B!I:VME(&%T(&1U(&=E;6UE<B!A;&QE
M(&5-86EL<R!D82!D:6X@9&ES:VMV;W1A('9I;"!B;&EV92!B<G5G="!H=7)T
M:6=T("AS<&5C:65L="!H=FES(&1U('-E;F1E<B!V961HYF9T96QS97(@;65D
M*2!O9R!D:6X@<&]S=&MA<W-E('9I;"!B;&EV92!F>6QD="!O9R!U9&4@868@
M<W1A;F0@=&EL(&%T(&UO9'1A9V4@;GD@<&]S="X@365N+"!D=2!K86X@<VSE
M(&1E;FYE(&UU;&EG:&5D('1I;"!S;VT@<W1A;F1A<F0@=FEA(")0<F]F:6QE
M<B(@:2`B26YD<W1I;&QI;F=E<B(N(`H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("!+;&EK('#E(&-H96-K+6MN87!P96X@=F5D('-I9&5N(&%F(")!;FUO
M9"!O;2!K=FET=&5R:6YG(&9O<B!M;V1T86=E;'-E(B!F;W(@870@9N4@96X@
M:W9I='1E<FEN9RP@;N5R(&1I;B!M961D96QE;'-E(&5R(&UO9'1A9V5T(&%F
M(&1E;B!S;VT@9'4@<V5N9&5R(&1E;B!T:6PN"B`@("`\+W!A<F$^"CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($]P=&EO;G,\+W1I=&QE
M/@H@("`@/&AE861I;F<^)G%U;W0[3W!T:6]N<R9Q=6]T.SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AE<V4@3W!T:6]N<R!H96QP('EO=2!P<F5P87)E
M('EO=7(@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI
M8VL@)G%U;W0[4W!E;&P@0VAE8VLF<75O=#L@=&\@8VAE8VL@>6]U<B!S<&5L
M;&EN9RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI8VL@)G%U;W0[
M071T86-H;65N=',F<75O=#L@=&\@=FEE=R!A="!T:&4@8F]T=&]M(&]F('1H
M92!P86=E(&$@;&ES="!O9B!F:6QE<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A
M9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%C=&EV871E('1H92!C
M:&5C:RUB=71T;VX@;F5X="!T;R`F<75O=#M3879E(&-O<'DF<75O=#L@=&\@
M<V%V92!A(&-O<'D@;V8@=&AI<R!M97-S86=E(&EN('EO=7(@)G%U;W0[4V5N
M="!-86EL)G%U;W0[(&9O;&1E<BX@4V%V92!C;W!I97,@;V8@:6UP;W)T86YT
M(&5M86EL<R!Y;W4@<V5N9"!S;R!T:&%T('EO=2!H879E('-O;65T:&EN9R!T
M;R!R969E<B!B86-K('1O(&QA=&5R(&%N9"!T;R!K965P(&%N(&%C8W5R871E
M(')E8V]R9"!O9B!W:&%T('=A<R!S86ED+B!792!D;R!N;W0@<F5C;VUM96YD
M('EO=2!S879E(&5V97)Y(&5M86EL('-I;F-E('1H96X@>6]U<B!D:7-K('-T
M;W)A9V4@<75O=&$@=VEL;"!B92!U<V5D('5P('%U:6-K;'D@*&5S<&5C:6%L
M;'D@=VAE;B!Y;W4@<V5N9"!A='1A8VAM96YT<RD@86YD('EO=7(@;6%I;&)O
M>"!W:6QL(&)E(&9U;&P@86YD('5N86)L92!T;R!R96-E:79E(&YE=R!I;F-O
M;6EN9R!E;6%I;"X@66]U(&-A;BP@:&]W979E<BP@='5R;B!T:&ES(&9E871U
M<F4@)V]N)R!A<R!Y;W5R(&1E9F%U;'0@=VET:&EN('EO=7(@261E;G1I='DL
M(&)Y(&=O:6YG('1O($]P=&EO;G,M)F=T.U!E<G-O;F%L($EN9F]R;6%T:6]N
M+29G=#M%9&ET('EO=7(@:61E;G1I=&EE<RX@0F4@8V%R969U;"!W:&5N('5S
M:6YG('1H:7,@;6]D:69I960@9&5F875L="!A<R!Y;W4@=VEL;"!N965D('1O
M('!E<FEO9&EC86QL>2!P=7)G92!Y;W5R("9Q=6]T.U-E;G0@36%I;"9Q=6]T
M.R!F;VQD97(@;W(@:70@=VEL;"!E=F5N='5A;&QY(&UA:V4@>6]U<B!M86EL
M8F]X(&9U;&P@86YD('5N=7-E86)L92X*("`@(#PO<&%R83X*/"]E;G1R>3XM
M+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B('-T871E
M/2)U;FMN;W=N(CX*("`@(#QT:71L93Y.>2!M961D96QE;'-E.B!6961HYF9T
M96QS97(\+W1I=&QE/@H@("`@/&AE861I;F<^(E9E9&CF9G1E;'-E<B(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@("`@("!$=2!K86X@=F5D:.9F=&4@9FEL
M97(@=&EL(&1I;B!M961D96QE;'-E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M,3H@4VMR:78@96YT96X@<W1I96X@;V<@;F%V;F5T('#E(&9I;&5N(&1U(/AN
M<VME<B!A="!V961HYF9T92P@96QL97(@:VQI:R!PY2`B1V5N;F5M<V4B(&5L
M;&5R(")"<F]W<V4B(&MN87!P96X@;V<@=N9L9R!D96X@^&YS:V5D92!F:6PN
M(%-T:65N(&]G(&YA=FYE="!PY2!F:6QE;B!V:6P@;G4@:W5N;F4@<V5S(&D@
M8F]K<V5N(&9O<B!V961HYF9T96QS97(N(`H@("`@/"]P87)A/@H@("`@/'!A
M<F$^,CH@2VQI:R!PY2`B5F5D:.9F="(@:VYA<'!E;BX@1FEL;F%V;F5T(&]G
M('-T^')R96QS96X@<.4@9FEL96X@=FEL(&)L:79E('1I;&;X:F5T(&QI<W1E
M;B!O=F5R('9E9&CF9G1E;'-E<BX@0F5MYG)K('9E;FQI9W-T(&%T(&9O<B!S
M=&]R92!F:6QE<B!O9R]E;&QE<B!E;B!L86YG<V]M($EN=&5R;F5T9F]R8FEN
M9&5L<V4@:V%N(&?X<F4L(&%T('!R;V-E<W-E;B!M960@;W9E<F;X<G-E;"!O
M9R!V961HYF9T96QS92!T:6P@;65D9&5L96QS96X@=&%G92!N;V=E="!T:60N
M(%;F<B!TY6QM;V1I9R!O9R!K;&EK(&EK:V4@<.4@86YD970@;65N<R!D=2!V
M96YT97(N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+6%T=&%C:"(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@071T86-H/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T%T
M=&%C:"9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA>2!A
M='1A8V@@9FEL97,@=&\@>6]U<B!M97-S86=E.R!O;FQY(&]N92!F:6QE(&UA
M>2!B92!A='1A8VAE9"!A="!A('1I;64N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83Y3=&5P(#$Z($5I=&AE<BP@='EP92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A
M(&9I;&4@=&AA="!Y;W4@=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@
M;W(@8VQI8VL@)G%U;W0[0G)O=W-E)G%U;W0[(&)U='1O;B!A;F0@<V5L96-T
M('1H92!F:6QE('1O(&)E(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD(&YA;64@
M;V8@=&AA="!F:6QE(&YO=R!A<'!E87)S(&EN('1H92!!='1A8VAM96YT(&)O
M>"X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,CH@1&5C:61E('=H971H
M97(@>6]U('=A;G0@=&AE(&9I;&4@=&\@8F4@=FEE=V5D(&%S(&%N(&%T=&%C
M:&UE;G0@;W(@:6YL:6YE9"!W:71H('1H92!R97-T(&]F('1H92!M97-S86=E
M+B!4:&4@<F5C96EV:6YG('!E<G-O;BAS*2!M86EL(')E861I;F<@<V]F='=A
M<F4@;75S="!B92!A8FQE('1O(&AA;F1L92!T:&4@9FEL92!T>7!E(&EN;&EN
M93L@:68@;F]T+"!T:&ES('!A<G0@=VEL;"!B92!V:65W960@87,@86X@871T
M86-H;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`S
M.B!#;&EC:R`F<75O=#M!='1A8V@F<75O=#L@8G5T=&]N+B!4:&4@9FEL92!N
M86UE(&%N9"!S:7IE('=I;&P@8F4@861D960@=&\@>6]U<B!L:7-T(&]F($%T
M=&%C:&UE;G1S+B!0;&5A<V4@;F]T92!T:&%T(&9O<B!L87)G92!F:6QE<R!A
M;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O;FYE8W1I;VYS+"!T:&4@<')O8V5S
M<R!O9B!U<&QO861I;F<@86YD(&%T=&%C:&EN9R!Y;W5R(&9I;&4@=&\@=&AE
M(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N(%!L96%S92!B92!P871I96YT(&%N
M9"!D;R!N;W0@8VQI8VL@;W1H97(@=&AI;F=S('=H:6QE('EO=2!A<F4@=V%I
M=&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/DYY(&UE9&1E;&5L<V4Z(%9E9&CF9G1E;'-E<VQI<W1E/"]T
M:71L93X*("`@(#QH96%D:6YG/B)6961HYF9T96QS97-L:7-T92(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($1E;FYE(&QI<W1E('9I<V5R(&1E('9E9&CF
M9G1E;'-E<B!D=2!H87(@9F]R971A9V5T('1I;"!D96X@86MT=65L;&4@;65D
M9&5L96QS92X@1F]R(&%T('-L971T92!E;B!V961HYF9T970@9FEL('-K86P@
M9'4Z"B`@("`\+W!A<F$^"B`@("`\<&%R83XQ.B!!:W1I=F5R92`B8VAE8VLM
M:VYA<'!E;B(@=F5D('-I9&5N(&%F(&1E;B!V961HYF9T961E(&9I;"!D=2#X
M;G-K97(@870@<VQE='1E+@H@("`@/"]P87)A/B`*("`@(#QP87)A/C(Z($ML
M:6L@<.4@(D9J97)N(&UA<FME<F5D92(N"B`@("`\+W!A<F$^"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8VAM96YT<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M!='1A8VAM96YT<R9Q=6]T.SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S96-T:6]N(&1I<W!L87ES
M(&$@;&ES="!O9B!F:6QE<R!A;')E861Y(&%T=&%C:&5D('1O('EO=7(@;65S
M<V%G92X@5&\@1&5L971E(&%N(&%T=&%C:&5D(&9I;&4Z"B`@("`\+W!A<F$^
M"B`@("`\<&%R83Y3=&5P(#$Z($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@
M;F5X="!T;R!T:&4@871T86-H960@9FEL96YA;64@>6]U('=A;G0@=&\@1&5L
M971E+@H@("`@/"]P87)A/B`*("`@(#QP87)A/E-T97`@,CH@0VQI8VL@)G%U
M;W0[1&5L971E($%T=&%C:&UE;G0H<RDF<75O=#LN"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<')I;W)I
M='DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I
M;VXZ(%!R:6]R:71Y/"]T:71L93X*("`@(#QH96%D:6YG/B)0<FEO<FET>2(\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@<V5T<R!T:&4@(E@M4')I
M;W)I='DB(&AE861E<B!O;B!Y;W5R(&]U=&=O:6YG(&UE<W-A9V4N(%1H92`B
M6"U0<FEO<FET>2(@=&%G(&ES(&$@<V]R="!O9B`B<'-E=61O('-T86YD87)D
M(B!T:&%T($YE='-C87!E+"!-;WII;&QA+"!/<&5R82P@86YD($]U=&QO;VL@
M;6%I;"!C;&EE;G1S(&%P<&5A<B!T;R!A9W)E92!O;BX@06YY(&UA:6P@8VQI
M96YT<R!T:&%T(&1O(&YO="!H86YD;&4@=&AI<R!H96%D97(@=VEL;"!S:6UP
M;'D@:6=N;W)E(&ET+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92US879E+6%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!3879E($%T=&%C:&UE;G1S
M/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H
M92!A='1A8VAM96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N(&%R92!S879E9"!W
M:71H('1H92!M97-S86=E('=H96X@<W1O<F5D(&EN('1H92!S96YT+6UA:6P@
M9F]L9&5R+B`@268@(EEE<R(L('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B
M92!S879E9"X@($EF(").;R(L('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B
M92!S=')I<'!E9"!F<F]M('1H92!M97-S86=E(&%F=&5R(&ET(&ES('-E;G0@
M=&\@86QL(')E8VEP:65N=',N("!#:&]O<VEN9R`B3F\B('=I;&P@:&5L<"!C
M;VYS97)V92!D:7-K('-P86-E(&)Y(')E;6]V:6YG("AP;W1E;G1I86QL>2!L
M87)G92D@871T86-H;65N="!I;F9O<FUA=&EO;B!F<F]M('1H92!S879E9"!M
M97-S86=E<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O
M;7!O<V4M;&EN:RUA='1A8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^365S<V%G92!#;VUP;W-I=&EO;CH@3&EN:R!!='1A8VAM96YT<SPO=&ET
M;&4^"B`@("`\<&%R83X*("`@($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T
M86-H;65N=',@:6X@>6]U<B!C;VUP;W-I=&EO;B!A<F4@<V5N="!A<R!A('!A
M<G0@;V8@=&AE(&UA:6P@;65S<V%G92!O<B!W:&5T:&5R('1H;W-E(&%T=&%C
M:&UE;G1S(&%R92!K97!T(&]N(&$@;&]C86P@<V5R=F5R+B`@268@871T86-H
M;65N=',@87)E(&QI;FME9"P@=&AE(')E8VEP:65N="AS*2!O9B!Y;W5R(&UE
M<W-A9V4@=VEL;"!B92!P<F]V:61E9"!A('=E8FQI;FL@=VAE<F4@=&AE>2!C
M86X@9&]W;FQO860@=&AE(&%T=&%C:&UE;G0H<RDN("!,:6YK:6YG(&%T=&%C
M:&UE;G1S(&AA<R!T:&4@861V86YT86=E(&]F('1R96UE;F1O=7-L>2!R961U
M8VEN9R!T:&4@<VEZ92!O9B!O=71G;VEN9R!M97-S86=E<RX@($QI;FMI;F<@
M871T86-H;65N=',@:&%S('1H92!D:7-A9'9A;G1A9V4@=&AA="!T:&4@8V]N
M=&5N="!O9B!T:&4@871T86-H;65N=',@8V%N(&YO="!B92!G=6%R86YT965D
M('1O(&)E(&%V86EL86)L92!I;B!T:&4@9G5T=7)E('-I;F-E('1H92!A='1A
M8VAM96YT(&1A=&$@:7,@;F]T(&QO8V%T960@=VET:&EN('1H92!E+6UA:6P@
M;65S<V%G92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-E
M87)C:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E/X9VYI;F<\+W1I
M=&QE/@H@("`@/&AE861I;F<^4_AG96MR:71E<FEE<CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@("`@("!);F=E;B!H:N9L<&5T96MS="!T:6P@<N5D:6=H
M960N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)S96%R8V@B/@H@("`@/'1I=&QE/DUE<W-A9V4@4V5A<F-H/"]T:71L93X*
M("`@(#QH96%D:6YG/E-E87)C:"!#<FET97)I83PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@66]U(&UA>2!S96%R8V@@9F]R(&UE<W-A9V5S(&9R;VT@>6]U
M<B!F;VQD97)S('5S:6YG(&1I9F9E<F5N="!S96%R8V@@8W)I=&5R:6$N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5N=&5R('1E>'0@=&\@=&AE
M(&9I96QD<R!Y;W4@=V%N="!T;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R
M:6$N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($-H;V]S92!T:&4@
M;65S<V%G92!F;&%G*',I('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C<FET97)I
M82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,SH@0VAO;W-E('1H92!F
M;VQD97(H<RD@9G)O;2!W:&EC:"!T;R!S96%R8V@@9F]R('1H92!M97-S86=E
M<RX*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@-#H@0VQI8VL@)G%U;W0[
M4V5A<F-H)G%U;W0[+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!)9B!A
M;GD@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"!C<FET97)I82P@=&AE
M;B!T:&4@<W5B:F5C=',@;V8@=&AE<V4@;65S<V%G97,@=VEL;"!B92!S:&]W
M;B!I;B!T:&4@)G%U;W0[4V5A<F-H(%)E<W5L=',F<75O=#L@=FEE=RX*("`@
M(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]L
M9&5R+6]P=&EO;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y&;VQD
M97)N879I9V%T;W(\+W1I=&QE/@H@("`@/&AE861I;F<^2.5N9'1E<FEN9R!A
M9B!F;VQD97)E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$=2!K86X@=N9L
M9V4@96X@9F]L9&5R('9E9"!A="!K;&EK:V4@<.4@96X@868@<F%D:6]K;F%P
M<&5R;F4@:2!V96YS=')E('/X:FQE+B!.Y7(@9'4@:&%R(&=J;W)T(&1E="!K
M86X@9'4@=N9L9V4@9&5N(&AA;F1L:6YG(&1U(/AN<VME<B!U9&;X<G0@<.4@
M;6%P<&5N('9I82`B5N9L9R!H86YD;&EN9R(@<'5L;&1O=VXM;65N=65N(&9O
M<F]V96X@=&EL('9E;G-T<F4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M($AE<B!H87(@9'4@<^4@>61E<FQI9V5R92!M=6QI9VAE9&5R+B!6YG(@9F]R
M<VEG=&EG(&UE9"`B4VQE="!F;VQD97(H92DB(&9U;FMT:6]N96XL(&1A(&1E
M;B!K86X@;65D9OAR92!A="!D=2!M:7-T97(@86QL92!M961D96QE;'-E<B!I
M(&5N(&9O;&1E<BP@:'9I<R!D=2!S;&5T=&5R(&9O;&1E<F5N('9E9"!E;B!F
M96IL("$*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@
M:60](F9O;&1E<BUO<'1I;VYS(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E
M;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY&;VQD97(@3W!T:6]N<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("!9;W4@8V%N('-E;&5C="!A(&9O;&1E
M<B!B>2!U<VEN9R!T:&4@<F%D:6\@8G5T=&]N<R!A;&]N9R!T:&4@;&5F="!C
M;VQU;6XN("!/;F-E('EO=2!H879E(&1O;F4@=&AI<RP@<V5L96-T('1H92!O
M<'1I;VX@>6]U('=I<V@@=&\@<&5R9F]R;2!O;B!T:&4@9F]L9&5R('9I82!T
M:&4@<V5L96-T(&)O>"!T;R!T:&4@;&5F="X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@("!9;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@9G5R=&AE<B!O
M<'1I;VYS+B`@0F4@8V%R969U;"!W:71H('1H92!D96QE=&4@;W!T:6]N+"!A
M<R!Y;W4@8V%N(&QO<V4@86QL('1H92!M97-S86=E<R!I;B!A(&9O;&1E<B!I
M9B!Y;W4@9&5L971E(&ET(&)Y(&UI<W1A:V4A"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY);7!O<G0@;6)O>"!&:6QE/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("`@(%1H:7,@;W!T:6]N('=I;&P@:6UP;W)T(&$@;6)O>"!F;W)M870@
M9FEL92!I;G1O('1H92!F;VQD97(@;V8@>6]U<B!C:&]I8V4N($-H;V]S92`Q
M("AO;F4I(&9O;&1E<B!T;R!I;7!O<G0@=&AE(&UE<W-A9V5S(&EN=&\@86YD
M('1H96X@<V5L96-T('1H:7,@;W!T:6]N+B!9;W4@=VEL;"!T:&5N(&)E('1A
M:V5N('1O(&$@<&%G92!T:&%T('=I;&P@<')O;7!T(&9O<B!T:&4@;6)O>"!F
M:6QE('1O(&EM<&]R="X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9F]L9&5R+7=I9&=E=',B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M96YT.B!$:7-P;&%Y/"]T:71L93X*
M("`@(#QH96%D:6YG/E-H;W<O2&ED92!5;G-U8G-C<FEB960\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EF('5S:6YG($E-05`@9F]L9&5R('-U8G-C<FEP
M=&EO;G,L('-H;W<O:&ED92!T:&4@=6YS=6)S8W)I8F5D(&9O;&1E<G,N("!4
M;R!S=6)S8W)I8F4O=6YS=6)S8W)I8F4@=&\@82!F;VQD97(L('-E;&5C="!T
M:&4@8VAE8VMB;W@@;F5X="!T;R!T:&4@9F]L9&5R;F%M92!A;F0@=7-E('1H
M92!3=6)S8W)I8F4O56YS=6)S8W)I8F4@;W!T:6]N(&EN('1H92!&;VQD97(@
M06-T:6]N(&1R;W`M9&]W;B!M96YU+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^17AP86YD($%L;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17AP86YD
M(&%L;"!F;VQD97(@96YT<FEE<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/D-O;&QA<'-E($%L;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0V]L;&%P
M<V4@86QL(&9O;&1E<B!E;G1R:65S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I
M=&QE/D9I;'1E<G)E9VQE<CH@561F^'(\+W1I=&QE/@H@("`@/&AE861I;F<^
M561F^'(@9FEL=&5R<F5G;&5R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!+
M;&EK('#E(")59&;X<B!F:6QT<F4B(&EK;VYE="!V960@<VED96X@868@9F]L
M9&5R;F%V;F5T(&D@<&]S=&MA<W-E=FEN9'5E="!F;W(@870@9FEL=')E<F4@
M86QL92!M961D96QE;'-E<B!I(&]V97)E;G-S=&5M;65L<V4@;65D(&1E;B!S
M<&5C:69I8V5R961E(')E9V5L+B!%;&QE<B!K;&EK('#E(")59&;X<B!A;&QE
M(')E9VQE<B(@:2!M96YU96X@9F]R(&9I;'1R92!U;F1E<B`B26YD<W1I;&QI
M;F=E<B(N($)E;>9R:R!A="!U9&;X<F5L<V4@868@9FEL=&5R<F5G;&5R(&EK
M:V4@<VME<B!A=71O;6%T:7-K+"!M961M:6YD<F4@9'4@:&%R(&%K=&EV97)E
M="!D92!M=6QI9VAE9&5R+"!D97(@97(L(&D@;65N=65N(&9O<B!F:6QT<F4N
M"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F
M:6QT97)S(CX*("`@(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-L:6-K(&]N('1H92`F<75O=#M!<'!L>2!&:6QT97(F<75O
M=#L@:6-O;B!N97AT('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X
M('9I97<@=&\@9FEL=&5R(&%L;"!U;F1E;&5T960@;65S<V%G97,@86-C;W)D
M:6YG('1O('1H92!S<&5C:69I960@<G5L97,N("!/<BP@86QT97)N871E=FQY
M+"!C;&EC:R!O;B`F<75O=#M!<'!L>2!!;&P@4G5L97,F<75O=#L@:6X@=&AE
M(&9I;'1E<B!M96YU+B`@3F]T92!T:&%T(&9I;'1E<FEN9R!I<R!N;W0@9&]N
M92!A=71O;6%T:6-A;&QY+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UR=6QE<R(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!&:6QT97(@4G5L97,\+W1I
M=&QE/@H@("`@/&AE861I;F<^161I="!9;W5R($9I;'1E<B!2=6QE<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!F:6QT
M97(@<G5L97,B('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A
M;B!A9&0L(&1E;&5T92P@86YD(&5D:70@=&AE(&-U<G)E;G1L>2!A8W1I=F4@
M<V5T(&]F(&9I;'1E<B!R=6QE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F9I;'1E<BUE9&ET+6)L86-K;&ES="(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!";&%C:VQI<W0\+W1I=&QE/@H@
M("`@/&AE861I;F<^161I="!9;W5R($)L86-K;&ES=#PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!B;&%C:VQI<W0B('1O
M('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T
M92P@86YD(&5D:70@=&AE(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y;W4@
M04Q705E3(')E9G5S92!M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UW:&ET96QI<W0B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@5VAI=&5L:7-T/"]T:71L
M93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!7:&ET96QI<W0\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@=VAI=&5L:7-T
M(B!T;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D
M96QE=&4L(&%N9"!E9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@
M>6]U($%,5T%94R!A8V-E<'0@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y&:6QT97)S.B!&:6QT97(@;VX@3&]G:6X\+W1I=&QE
M/@H@("`@/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S(%5P;VX@3&]G;VX_
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T
M;R!A;'=A>7,@87!P;'D@9FEL=&5R<R!W:&5N(&9I<G-T(&QO9V=I;F<@;VYT
M;R!)35`N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT
M97(M;VXM9&ES<&QA>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R
M<SH@1FEL=&5R(&]N(%)E9G)E<V@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P
M;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N('1O
M(&%L=V%Y<R!A<'!L>2!F:6QT97)S('=H96YE=F5R('EO=7(@=FEE=R!T:&4@
M24Y"3U@_"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT
M97(M86YY+6UA:6QB;W@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E
M<G,Z($9I;'1E<B!A;GD@36%I;&)O>#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA:6QB;W@_/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!I9B!Y;W4@=V%N="!T
M;R!B92!A;&QO=V5D('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@;6%I
M;&)O>"X@3F]R;6%L;'DL(&9I;'1E<FEN9R!R=6QE<R!A<F4@;VYL>2!A<'!L
M:65D('1O(&YE=R!M86EL('1H870@:7,@9&5L:79E<F5D('1O('EO=7(@24Y"
M3U@N("!)9B!T:&ES(&]P=&EO;B!I<R!C:&5C:V5D+"!A;B!I8V]N('=I;&P@
M87!P96%R(&]N(&%L;"!M86EL8F]X('!A9V=E<R!T:&%T('=I;&P@86QL;W<@
M>6]U('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!T:&4@;65S<V%G97,@:6X@
M=&AE(&-U<G)E;G0@;6%I;&)O>"X@($Y/5$4Z($9I;'1E<FEN9R!I;B!M86EL
M8F]X97,@;W1H97(@=&AA;B!)3D)/6"!M87D@<')O9'5C92!S=')A;F=E("AE
M+F<N('1H92!F:6QT97(@;6%Y(&-A=7-E(&$@8V]P>2!O9B!M97-S86=E<R!T
M;R!B92!D96QI=F5R960@=&\@=&AE('-A;64@;6%I;&)O>"D@86YD+V]R('5N
M9&5S:7)E9"!R97-U;'1S("AE+F<N(&ET(&UA>2!C875S92!M97-S86=E<R!T
M;R!B92!M;W9E9"]D96QE=&5D(&EF(&YE=R!F:6QT97)I;F<@<G5L97,@:&%V
M92!B965N(&EM<&QE;65N=&5D('-I;F-E('1H92!M97-S86=E(&AA<R!B965N
M(&1E;&EV97)E9"!T;R!T:&4@8W5R<F5N="!M86EL8F]X*2X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C:"UP
M=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@071T86-H(%!U
M8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^071T86-H(%!U8FQI8R!+
M97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@
M82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T<RP@
M=VEL;"!B92!A='1A8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X@(%EO
M=2!C86X@<V5T('1H92!D969A=6QT(&)E:&%V:6]R('9I82!T:&4@4$=0($]P
M=&EO;G,@<V-R965N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+6]P=&EO;BUS8V%N+6)O9'DB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@4V-A;B!497AT($)O9&EE<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY38V%N(%1E>'0@0F]D:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)
M9B!S96QE8W1E9"!T:&5N($E-4"!W:6QL('-C86X@=&AE(&)O9'D@;V8@86QL
M('1E>'0@;65S<V%G97,@9F]R(%!'4"!D871A+"!A;F0@9&ES<&QA>2!T:&4@
M<F5S=6QT<R!I9B!A;GD@9&%T82!I<R!F;W5N9"X@($YO=&4@=&AA="!T:&ES
M(&UA>2!S;&]W(&1O=VX@=&AE('-Y<W1E;2!A<R!E=F5R>2!T97AT(&UE<W-A
M9V4@;75S="!B92!S8V%N;F5D(&EN(&ET<R!E;G1I<F5T>2!F;W(@4$=0(&1A
M=&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E
M+6]P=&EO;G,M96YC<GEP="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^0V]M
M<&]S93H@16YC<GEP=&EO;B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG
M/DYO($5N8W)Y<'1I;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@
M=&AE(&UE<W-A9V4@=VET:"!N;R!E;F-R>7!T:6]N("AC;&5A<G1E>'0I+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0($5N8W)Y<'0@365S<V%G93PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!E;F-R
M>7!T('1H92!C=7)R96YT(&UE<W-A9V4L('5S:6YG(%!'4"!A;F0@=&AE(')E
M8VEP:65N=',@<&5R<V]N86P@<'5B;&EC(&ME>2P@86YD('1H96X@<V5N9"!I
M="X@66]U(&-A;B!O;FQY('-E;F0@82!M97-S86=E('1O(&$@<VEN9VQE('!E
M<G-O;B!U<VEN9R!T:&ES(&]P=&EO;BX@66]U($U54U0@:&%V92!T:&4@<'5B
M;&EC(&ME>2!O9B!T:&4@<F5C:7!I96YT('-T;W)E9"!I;B!Y;W5R(&%D9')E
M<W-B;V]K(&]R(&5L<V4@=&AI<R!O<'1I;VX@=VEL;"!F86EL+B!)9B!Y;W4@
M:&%V92!T:&4@<'5B;&EC(&ME>2!F;W(@=&AE(')E8VEP:65N="!I;B!Y;W5R
M(&%D9')E<W-B;V]K(&%N9"!A<F4@<W1I;&P@<F5C96EV:6YG(&5R<F]R<RP@
M=F5R:69Y('1H870@=&AE(&4M;6%I;"!A9&1R97-S(&EN('1H92!R96-I<&EE
M;G0@9FEE;&0@;6%T8VAE<R!T:&4@92UM86EL(&%D9')E<W,@=VAE<F4@=&AE
M('!U8FQI8R!K97D@:7,@<W1O<F5D+B!4:&4@96YC<GEP=&5D(&1A=&$@=VEL
M;"!B92!A='1A8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/E!'4"!3:6=N($UE<W-A9V4\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@9&EG:71A;&QY('-I
M9VX@=&AE(&-U<G)E;G0@;65S<V%G92!U<VEN9R!01U`@86YD('EO=7(@<&5R
M<V]N86P@<')I=F%T92!K97DN($EF('EO=2!H879E(&YO="!A;')E861Y(&5N
M=&5R960@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@<')I=F%T92!K97D@9'5R
M:6YG('1H:7,@<V5S<VEO;B!Y;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@:70N
M("!4:&4@<F5C96EP:65N="!M=7-T(&AA=F4@82!C;W!Y(&]F('EO=7(@<'5B
M;&EC(&ME>2!T;R!D:6=I=&%L;'D@=F5R:69Y('EO=7(*("`@('-I9VYA='5R
M92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!3:6=N+T5N8W)Y<'0@
M365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@
M=VEL;"!F:7)S="!D:6=I=&%L;'D@<VEG;B!Y;W5R(&UE<W-A9V4@86YD('1H
M96X@=VEL;"!E;F-R>7!T('1H92!R97-U;'1I;F<@;W5T<'5T+B!3964@=&AE
M("=01U`@16YC<GEP="!-97-S86=E)R!A;F0@)U!'4"!3:6=N($UE<W-A9V4G
M(&5N=')I97,@9F]R(&9U<G1H97(@:6YF;W)M871I;VXN"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY3+TU)344@16YC<GEP="!-97-S86=E/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY3+TU)344@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG;B]%
M;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R=FEE
M=R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!/=F5R=FEE=SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY7:&%T(&ES(%!'4#\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%!'4"!I<R!A('1O;VP@9F]R('-E8W5R92!C;VUM=6YI8V%T
M:6]N(&%N9"!D871A('-T;W)A9V4L(&5S<&5C:6%L;'D@9F]R('5S92!W:71H
M(&4M;6%I;"X@270@8V%N(&)E('5S960@=&\@96YC<GEP="!D871A(&%N9"!T
M;R!C<F5A=&4@9&EG:71A;"!S:6=N871U<F5S+B!)35`@=7-E<R!';G501R`H
M1TY5(%!R:79A8WD@1W5A<F0I('1O('!R;W9I9&4@=&AI<R!F=6YC=&EO;F%L
M:71Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16YA8FQE(%!'4"!F=6YC
M=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=&AI<R!O
M<'1I;VX@:7,@<V5L96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@8W)E871E
M+W9I97<@>6]U<B!P97)S;VYA;"!01U`@:V5Y<RP@861D+V1E;&5T92!P=6)L
M:6,@:V5Y<R!F<F]M(&]T:&5R(&EN9&EV:61U86QS+"!R96%D(&5N8W)Y<'1E
M9"!M86EL+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@96YC
M<GEP="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I;VXM871T86-H+7!U8FME>2(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!/<'1I;VYS("T@071T86-H
M(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^3W!T:6]N<R`M($%T
M=&%C:"!0=6)L:6,@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S
M96QE8W1E9"!T:&5N(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I
M9B!I="!E>&ES=',L('=I;&P@8GD@9&5F875L="!B92!A='1A8VAE9"!T;R!A
M;&P@;W5T9V]I;F<@;65S<V%G97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@("`@
M/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H
M:7,@<V-R965N(&QI<W1S(&%L;"!O9B!T:&4@8W5R<F5N="!U<V5R<R!I;B!Y
M;W5R(&%D9')E<W-B;V]K('1H870@:&%V92!01U`@<'5B;&EC(&ME>7,N(%1H
M97-E('5S97)S(&%R92!T:&4@3TY,62!U<V5R<R!T:&%T('EO=2!C86X@96ET
M:&5R(#$I('-E;F0@86X@96YC<GEP=&5D(&UE<W-A9V4@=&\@+4]2+2`R*2!V
M97)I9GD@82!D:6=I=&%L('-I9VYA='5R92X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS(&$@
M=VEN9&]W('1O('9I97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<'5B;&EC
M(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T:&4@<'5B;&EC(&ME>2!F<F]M
M('EO=7(@861D<F5S<V)O;VLN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M:6UP;W)T+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME>7,@+2!);7!O<G0\+W1I=&QE
M/@H@("`@/&AE861I;F<^26UP;W)T(%!U8FQI8R!+97ES/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!4:&ES(&)U='1O;B!W:6QL(&]P96X@82!W:6YD;W<@
M=VAE<F4@>6]U(&-A;B!M86YU86QL>2!I;7!O<G0@82!01U`@<'5B;&EC(&ME
M>2X@(%1H92!K97D@8V%N(&5I=&AE<B!B92!P87-T960@:6YT;R!A('1E>'1F
M:65L9"!O<BP@:68@=&AE(&ME>2!R97-I9&5S(&EN(&$@9FEL92!O;B!Y;W5R
M(&QO8V%L(&-O;7!U=&5R+"!Y;W4@8V%N(&EM<&]R="!I="X@($EF('1H92!K
M97D@:7,@=F%L:60@:70@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@861D
M<F5S<V)O;VL@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A
M;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I
M;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M;W9E<G9I97<M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,\+W1I=&QE/@H@("`@/&AE
M861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('EO
M=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&UE<W-A9V5S(&]R(&5N86)L92!O
M=&AE<G,@=&\@<V5N9"!Y;W4@96YC<GEP=&5D(&UE<W-A9V5S+"!Y;W4@;75S
M="!H879E('EO=7(@;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%!'4"!K
M97EP86ER+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0=6)L:6,@
M2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!U8FQI8R!K97D@
M<VAO=6QD(&)E(&UA9&4@879A:6QA8FQE('1O(&%N>2!P97)S;VX@=&AA="!Y
M;W4@=V%N="!T;R!B92!A8FQE('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M97-S
M86=E<R!T:&%T(&]N;'D@64]5(&-A;B!D96-R>7!T("AU<VEN9R!Y;W5R('!R
M:79A=&4@:V5Y*2X@061D:71I;VYA;&QY+"!Y;W5R('!U8FQI8R!K97D@;F5E
M9',@=&\@8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY8F]D>2!Y;W4@<V5N9"!A
M(&1D:6=I=&%L;'D@<VEG;F5D(&UE<W-A9V4@=&\@+2!T:&4@<'5B;&EC(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE(&1I9VET86P@<VEG;F%T=7)E
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0<FEV871E($ME>3PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U<B!P<FEV871E(&ME>2!I<R!N
M96-E<W-A<GD@=&\@9&5C<GEP="!A;GD@;65S<V%G92!E;F-R>7!T960@=7-I
M;F<@>6]U<B!P=6)L:6,@:V5Y+B!!9&1I=&EO;F%L;'DL('EO=7(@<')I=F%T
M92!K97D@:7,@;F5E9&5D(&EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N
M(&$@;65S<V%G92X@66]U<B!P<FEV871E(&ME>2!W:6QL(&)E('!R;W1E8W1E
M9"!V:6$@82!P87-S<&AR87-E(&-R96%T960@=VAE;B!T:&4@:V5Y<R!A<F4@
M9V5N97)A=&5D+B!4:'5S+"!T;R!P97)F;W)M(&%N>2!A8W1I=FET>2!T:&%T
M(')E<75I<F5S('EO=7(@<')I=F%T92!K97DL($E-4"!W:6QL('!R;VUP="!Y
M;W4@9F]R('EO=7(@<&%S<W!H<F%S92X@66]U(&]N;'D@;F5E9"!T;R!I;G-E
M<G0@>6]U<B!P87-S<&AR87-E(&]N8V4@<&5R('-E<W-I;VX@+2!)35`@=VEL
M;"!S=&]R92!Y;W5R('!A<W-P:')A<V4@=6YT:6P@>6]U(&QO9V]U="`H4V\@
M8F4@<W5R92!T;R!L;V=O=70A*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP=6)L:6,B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!0=6)L
M:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P
M=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS
M(&%B;W5T('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP<FEV871E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES
M("T@4')I=F%T92!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^16YT97(@4&%S
M<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@=&AE('!A
M<W-P:')A<V4@9&EA;&]G('=I;F1O=RX@5&AE('!A<W-P:')A<V4@96YT97)E
M9"P@:68@8V]R<F5C="P@=VEL;"!B92!S=&]R960@8GD@24U0('5N=&EL('EO
M=7(@<V5S<VEO;B!E;F1S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^56YL
M;V%D(%!A<W-P:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%)E;6]V
M97,@=&AE('-T;W)E9"!P87-S<&AR87-E(&9R;VT@24U0("T@86YY(&%D9&ET
M:6]N86P@=7-A9V4@;V8@=&AE('!R:79A=&4@:V5Y('=I;&P@<F5Q=6ER92!Y
M;W4@=&\@<F5E;G1E<B!T:&4@<&%S<W!H96%S92X*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS
M(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P<FEV871E(&ME>2X@1$\@3D]4
M(%-%3D0@5$A)4R!+15D@5$\@04Y93TY%("T@=&AI<R!O<'1I;VX@:7,@<W1R
M:6-T;'D@<V\@=&AA="!Y;W4@8V%N(&5X<&]R="!Y;W5R($E-4"!P97)S;VYA
M;"!P<FEV871E(&ME>2!F;W(@=7-E(&EN(&%N;W1H97(@<')O9W)A;2X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0
M('!R:79A=&4@:V5Y+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M($1E;&5T93PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@2V5Y<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!D96QE=&4@>6]U
M<B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER(&9R;VT@24U0)W,@
M<')E9F5R96YC97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6YA;64B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($YA;64\+W1I
M=&QE/@H@("`@/&AE861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@5&AE(&YA;64@>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S;VYA
M;"!K97ES+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UC;VUM96YT
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA
M;"!+97D@+2!#;VUM96YT/"]T:71L93X*("`@(#QH96%D:6YG/D-O;6UE;G0\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@8V]M;65N="!S=')I;F<@>6]U
M('=A;G0@96UB961D960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!;B!O<'1I
M;VYA;"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M96UA:6PB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($4M;6%I;"!!
M9&1R97-S/"]T:71L93X*("`@(#QH96%D:6YG/D4M;6%I;"!!9&1R97-S/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@92UM86EL(&%D9')E<W,@>6]U
M('=A;G0@87-S;V-I871E9"!W:71H('EO=7(@<&5R<V]N86P@:V5Y<RX@02!R
M97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M:V5Y;&5N9W1H(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!+
M97EL96YG=&@\+W1I=&QE/@H@("`@/&AE861I;F<^2V5Y;&5N9W1H/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@:V5Y;&5N9W1H+"!I;B!B>71E<RP@
M;V8@>6]U<B!G96YE<F%T960@:V5Y+B!4:&4@9W)E871E<B!T:&4@=F%L=64L
M('1H92!G<F5A=&5R('1H92!P<F]T96-T:6]N("AA;F0@86QS;R!G<F5A=&5R
M(&=E;F5R871I;VX@=&EM92!A;F0@96YC<GEP=&EO;B!T:6UE*2X@,3`R-"!B
M>71E<R!I<R!T:&4@9&5F875L="`M('1H:7,@=F%L=64@<')O=FED97,@97AC
M96QL96YT('!R;W1E8W1I;VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+7!A<W-P:')A<V4B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME
M>2`M(%!A<W-P:')A<V4\+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AE('!A<W-P:')A<V4@=7-E9"!T;R!P
M<F]T96-T+V5N8W)Y<'0@>6]U<B!P97)S;VYA;"!P<FEV871E(&ME>2X@5&AI
M<R!S:&]U;&0@8F4@050@3$5!4U0@-B!C:&%R86-T97)S+"!S:&]U;&0@3D]4
M(&)E('1H92!S86UE(&%S('EO=7(@;&]G:6X@<&%S<W=O<F0L('-H;W5L9"!.
M3U0@8F4@8F%S960@;VX@82!D:6-T:6]N87)Y('=O<F0L(&%N9"!S:&]U;&0@
M:6YC;'5D92!B;W1H(&YU;6)E<G,@86YD(&QE='1E<G,N(%EO=2!M=7-T(&5N
M=&5R('1H:7,@<&%S<W!H<F%S92!T=VEC92!F;W(@=F5R:69I8V%T:6]N('!U
M<G!O<V5S+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UA8W1I;VYS
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA
M;"!+97D@+2!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D-R96%T92!+
M97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#<F5A=&4@86YD('-T;W)E
M('EO=7(@<&5R<V]N86PO<')I=F%T92!K97EP86ER+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^26UP;W)T($ME>7!A:7(\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($EM<&]R="!A('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX@5&AI
M<R!B=71T;VX@;W!E;G,@82!W:6YD;W<@=VAE<F4@>6]U(&-A;B!M86YU86QL
M>2!I;7!O<G0@>6]U<B!E>&ES=&EN9R!01U`@<&5R<V]N86P@<'5B;&EC+W!R
M:79A=&4@:V5Y<&%I<BX@(%1H92!K97ES(&-A;B!E:71H97(@8F4@<&%S=&5D
M(&EN=&\@82!T97AT9FEE;&0@;W(L(&EF('1H92!K97ES(')E<VED92!I;B!A
M(&9I;&4@;VX@>6]U<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@
M=&AE;2X@($EF('1H92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS
M97)T960@:6YT;R!Y;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I
M;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL
M(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E,O34E-13H@3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE
M861I;F<^5VAA="!I<R!3+TU)344_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!3+TU)344@:7,@82!P<FEV871E+W!U8FQI8R!K97D@<&%I<B!S>7-T96T@
M=VAI8V@@<')O=FED97,@9&EG:71A;"!S:6=N871U<F5S+"!M97-S86=E('!R
M:79A8WDL(&%N9"!T86UP97(@9&5T96-T:6]N(&EN(&$@;W!E;BP@:6YT97)O
M<&5R86)L92!W87DN("!3+TU)344@8V%N('!R;W9I9&4@;65S<V%G92!P<FEV
M86-Y(&)Y(&5N8W)Y<'1I;F<@;65S<V%G97,@=&AA="!O;FQY('1H92!S96YD
M97(@86YD('1H92!I;G1E;F1E9"!R96-I<&EE;G1S(&-A;B!D96-O9&4N("!)
M="!A;&QO=W,@>6]U('1O(&ED96YT:69Y('1H92!S96YD97(@;V8@82!M97-S
M86=E('9I82!A(&1I9VET86P@<VEG;F%T=7)E+B`@5&]G971H97(L('1H:7,@
M96YC<GEP=&EO;B!A;F0@9&EG:71A;"!S:6=N:6YG(&AE;'`@<')O=FED92!T
M86UP97(@9&5T96-T:6]N+"!A;&QO=VEN9R!R96-I<&EE;G1S('1O(&1E=&5R
M;6EN92!W:&5T:&5R(&$@;65S<V%G92!W87,@86QT97)E9"!A9G1E<B!I="!W
M87,@<V5N="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!3+TU)
M344@9G5N8W1I;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF
M('1H:7,@;W!T:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O
M(&EM<&]R="!Y;W5R('!E<G-O;F%L(%,O34E-12!K97ES+"!R96%D(&5N8W)Y
M<'1E9"!M86EL+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@
M96YC<GEP="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W+7!E<G-O;F%L
M:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z(%!E<G-O;F%L
M($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N
M(&]R(&5N8W)Y<'0@;65S<V%G97,@>6]U(&UU<W0@:&%V92!Y;W5R(&]W;B!P
M97)S;VYA;"!P=6)L:6,O<')I=F%T92!3+TU)344@:V5Y<&%I<BX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6EM<&]R="UP97)S
M;VYA;"UC97)T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!)
M;7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH96%D
M:6YG/DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($EM<&]R="!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O
M;2!A(%!+0U,@(S$R(&9O<FUA="!F:6QE+B!02T-3(",Q,B!F:6QE<R!I<R!T
M:&4@9FEL92!U<W5A;&QY(&=E;F5R871E9"!W:&5N(&5X<&]R=&EN9R!A(&ME
M>2!F<F]M(&$@8G)O=W-E<B`H92YG+B!);G1E<FYE="!%>'!L;W)E<BP@1FER
M969O>"D@;W(@9G)O;2!A(&-E<G1I9FEC871E('-T;W)E(&UA:6YT86EN960@
M8GD@86X@3W!E<F%T:6YG(%-Y<W1E;2`H92YG+B!7:6YD;W=S(%A0*2X@268@
M=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E9"!I;G1O
M('EO=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@
M:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N
M960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)S;6EM92UD96QE=&4M<&5R<V]N86PM8V5R=',B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E,O34E-13H@1&5L971E(%!E<G-O;F%L($-E<G1I
M9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@
M0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&4@
M>6]U<B!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!Y;W5R('!R969E<F5N
M8V5S+B`@66]U('=I;&P@;F\@;&]N9V5R(&)E(&%B;&4@=&\@<VEG;B!3+TU)
M344@;65S<V%G97,@;W(@=FEE=R!A;GD@4R]-24U%(&5N8W)Y<'1E9"!M97-S
M86=E<R!A9&1R97-S960@=&\@>6]U+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<VUI;64M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE
M/@H@("`@/&AE861I;F<^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($UA;F%G92!Y;W5R(%,O34E-12!P=6)L
M:6,@:V5Y(&QI<W0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W('1H92!R87<@=&5X="!O9B!T
M:&4@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I
M;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&5C:&YI8V%L(&1E
M=&%I;',@;V8@=&AE('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY$96QE=&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T97,@
M=&AE('-E;&5C=&5D('!U8FQI8R!K97D@9G)O;2!S=&]R86=E+B`@1&5L971I
M;F<@82!P=6)L:6,@:V5Y(&9O<B!A('5S97(@=VEL;"!P<F5V96YT('EO=7(@
M9G)O;2!E;F-R>7!T:6YG(&$@;65S<V%G92!T;R!T:&%T('5S97(N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<FEN=&EN9R(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')I;G1I;F<\+W1I=&QE/@H@("`@/&AE861I
M;F<^4')I;G0@82!M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M;R!P<FEN="!A(&UE<W-A9V4@>6]U(&%R92!V:65W:6YG+"!C;&EC:R!O;B!T
M:&4@(E!R:6YT(B!L:6YK(&%T(&5I=&AE<B!T:&4@=&]P(&]R(&)O='1O;2!O
M9B!T:&4@;65S<V%G92X@5&AE(&UE<W-A9V4@=VEL;"!O<&5N(&EN(&$@;F5W
M('=I;F1O=R!F;W)M871E9"!F;W(@<')I;G1I;F<N("!$97!E;F1I;F<@;VX@
M>6]U<B!W96(@8G)O=W-E<B!A;F0@;W!E<F%T:6YG('-Y<W1E;2P@=&AE('!R
M:6YT(&1I86QO9R!B;W@@;6%Y(&]P96X@9F]R('EO=2X@($EF(&ET(&1O97,@
M;F]T(&]P96XL('1H96X@<'5L;"!D;W=N('1H92!W96(@8G)O=W-E<B=S(")&
M:6QE(B!M96YU(&%N9"!C:&]O<V4@(E!R:6YT(B!T;R!O<&5N('1H92!P<FEN
M="!D:6%L;V<@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<V]R=&EN9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4V]R=&EN9R!A
M;F0@5&AR96%D:6YG/"]T:71L93X*("`@(#QH96%D:6YG/E-O<G1I;F<@16YT
M<FEE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5VAE;B!V:65W:6YG(&$@
M;&ES="!O9B!M97-S86=E<RP@>6]U(&-A;B!S;W)T('1H92!M97-S86=E<R!B
M>2!A;GD@8V]L=6UN(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T92!C
M;VQU;6X@:&5A9&EN9RX@(%1O('-W:71C:"!C;VQU;6YS(&)E='=E96X@87-C
M96YD:6YG(&%N9"!D97-C96YD:6YG(&]R9&5R+"!C;&EC:R!O;B!T:&4@87)R
M;W<@:6-O;B!I;B!T:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY4:')E861I;F<\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1O(&=R;W5P(&UE<W-A9V5S(&)Y('1H<F5A9',@*'-U8FIE8W0I+"!S;R!E
M86-H(&UE<W-A9V4@:7,@9W)O=7!E9"!W:71H(&%L;"!I=',@<F5P;&EE<RP@
M8VQI8VL@=&AE(%M4:')E861=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L=6UN
M(&AE861I;F<N("!4;R!R971U<FX@=&\@;F]R;6%L('-U8FIE8W0@<V]R=&EN
M9RP@8VQI8VL@;VX@=&AE(%M3=6)J96-T72!L:6YK(&EN('1H92!S=6)J96-T
M(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB86QT97)N871I=F4M;7-G(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y-=6QT:7!A<G0O06QT97)N871I=F4@365S<V%G97,\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!3;VUE(&UE<W-A9V4@:&%V92!B965N('-E;G0@87,@82`B
M;75L=&EP87)T+V%L=&5R;F%T:79E(B!T>7!E(&)Y('1H92!S96YD97(N(%1H
M97-E(&UE<W-A9V5S(&AA=F4@<V5V97)A;"!P87)T<RP@86QL(&1I<W!L87EI
M;F<@=&AE(%-!344@0T].5$5.5"!B=70@:6X@1$E&1D5214Y4($9/4DU!5%,N
M(%1H92!M86EL(&%G96YT('=I;&P@9&ES<&QA>2!T:&4@;&%S="!P87)T(&EN
M('1H92!L:7-T('1H870@8V%N(&)E('-U8V-E<W-F=6QL>2!D:7-P;&%Y960@
M:6YL:6YE(&EN('1H92!B<F]W<V5R+"!I9B!A;GDN($%L;"!O=&AE<B!F;W)M
M871S('=I;&P@87!P96%R('5N9&5R('1H92!H96%D:6YG(")!;'1E<FYA=&EV
M92!P87)T<R!F;W(@=&AI<R!S96-T:6]N(B!A;F0@8V%N(&)E('9I97=E9"!O
M<B!D;W=N;&]A9&5D('-E<&%R871E;'DN($ET(&ES(&EM<&]R=&%N="!T;R!N
M;W1E('1H870@=&AE<V4@86QT97)N871I=F4@<&%R=',@8V]N=&%I;B!T:&4@
M4T%-12!#3TY414Y44R!A<R!T:&4@<&%R="!T:&%T(&ES('-H;W=N("T@=&AE
M>2!A<F4@<VEM<&QY(&EN(&$@9&EF9F5R96YT(&UE9&EA(&9O<FUA="`H92YG
M+B!T97AT('9S+B!(5$U,(&]U='!U="DN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUR96YA;65?<V5N=&UA:6Q?;6]N=&AL>2(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!296YA;64@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*
M("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U
M;&0@;&EK92!T;R!R96YA;64@>6]U<B!S96YT+6UA:6P@9F]L9&5R(&%T('1H
M92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&4@9F]L9&5R('=I;&P@
M8F4@<F5N86UE9"`H=&\@82!N86UE('1H870@8V]N=&%I;G,@=&AE(&UO;G1H
M(&%N9"!Y96%R*2!A;F0@82!N97<@<V5N="UM86EL(&9O;&1E<B!W:6QL(&)E
M(&-R96%T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@4V5N
M="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@("`@
M5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!D96QE
M=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T('1H92!B96=I;FYI;F<@;V8@
M979E<GD@;6]N=&@N("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA=F4@
M82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K965P
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E
M;F%N8V4Z($1E;&5T92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D@+2`C(&]F
M($9O;&1E<G,@=&\@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO
M=2!A<F4@9&5L971I;F<@;VQD('-E;G0M;6%I;"!F;VQD97)S(&5V97)Y(&UO
M;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@;VQD(&9O;&1E<G,@9&\@>6]U("!W
M86YT('1O(&ME97`_("!!;GD@9F]L9&5R<R!O;&1E<B!T:&%N('1H:7,@;6%N
M>2!M;VYT:',@=VEL;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H
M;'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN
M=&5N86YC93H@1&5L971E($QI;FME9"!!='1A8VAM96YT<R!-;VYT:&QY/"]T
M:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y
M;W4@=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!A="!T:&4@8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AI<R!M87D@
M8F4@=7-E9G5L(&EF('EO=2!H879E(&$@<75O=&$L(&9O<B!E>&%M<&QE+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E
M7V%T=&%C:&UE;G1S7VUO;G1H;'E?:V5E<"(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN:V5D
M($%T=&%C:&UE;G1S($UO;G1H;'D@+2`C(&]F($UO;G1H<R!T;R!+965P/"]T
M:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O;&0@
M;&EN:V5D(&%T=&%C:&UE;G1S(&5V97)Y(&UO;G1H+"!H;W<@;6%N>2!M;VYT
M:',@;V8@;VQD(&%T=&%C:&UE;G1S(&1O('EO=2`@=V%N="!T;R!K965P/R`@
M06YY(&%T=&%C:&UE;G1S(&]L9&5R('1H86X@=&AI<R!M86YY(&UO;G1H<R!W
M:6QL(&)E(&1E;&5T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($1O('EO=2!W86YT('1O('!U<F=E('EO=7(@
M=')A<V@@9F]L9&5R(&5V97)Y('-O(&]F=&5N+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:6YT97)V86PB
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@4'5R9V4@5')A<V@@26YT97)V86P\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!)9B!Y;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L(&AO
M=R!O9G1E;B!S:&]U;&0@:70@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:V5E<"(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!0=7)G92!4<F%S:"!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@
M>6]U(&%R92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R+"!M97-S86=E(&]L
M9&5R('1H86X@:&]W(&UA;GD@9&%Y<R!S:&]U;&0@8F4@<'5R9V5D/PH@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB7W1E
M>'0B('-T871E/2)N97<B/@H@("`@(#QT:71L93Y0<F5F97)E;F-E<SH@365S
M<V%G92!#;VUP;W-I=&EO;CH@071T<FEB=71I;VX@5&5X=#PO=&ET;&4^"B`@
M("`@/'!A<F$^"B`@("`@2&5R92!Y;W4@8V%N(&5N=&5R('1H92!P:')A<V4@
M=&AA="!Y;W4@=VES:"!T;R!A<'!E87(@8F5F;W)E(&%N>2!Q=6]T960@=&5X
M="!I;B!A(')E<&QY('1H870@>6]U('-E;F0N"B`@("`@/"]P87)A/@H@("`@
M(#QP87)A/@H@("`@(%EO=2!C86X@:6YC;'5D92!O;F4@;W(@;6]R92!S<&5C
M:6%L('!L86-E:&]L9&5R<R!T;R!I;G-E<G0@:6YF;W)M871I;VX@86)O=70@
M=&AE(&UE<W-A9V4@=&\@=VAI8V@@>6]U(&%R92!R97!L>6EN9RX@4&QA8V5H
M;VQD97)S(&-O;G-I<W0@;V8@82`G)2<@9F]L;&]W960@8GD@82!S:6YG;&4@
M;&5T=&5R+B!4:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!A<F4@879A:6QA
M8FQE.@H@("`@(#PO<&%R83X*"B`@("`@/'!A<F$^("5F(#H@5&AE('-E;F1E
M<B=S(&YA;64@86YD(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^
M("5A(#H@5&AE('-E;F1E<B=S(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@
M/'!A<F$^("5P(#H@5&AE('-E;F1E<B=S(&YA;64\+W!A<F$^"B`@("`@/'!A
M<F$^("5R(#H@5&AE(&9U;&P@4D9#(#(X,C(@<W1Y;&4@9&%T92!A;F0@=&EM
M92!Z;VYE/"]P87)A/@H@("`@(#QP87)A/B`E9"`Z(%1H92!D871E(&%S('=W
M=RP@9&0@;6UM(%E965D\+W!A<F$^"B`@("`@/'!A<F$^("5X(#H@5&AE(&1A
M=&4@:6X@=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^
M("5C(#H@5&AE(&1A=&4@86YD('1I;64@:6X@=&AE(&QO8V%L92=S(&1E9F%U
M;'0\+W!A<F$^"B`@("`@/'!A<F$^("5M(#H@5&AE($UE<W-A9V4M240\+W!A
M<F$^"B`@("`@/'!A<F$^("5S(#H@5&AE('-U8FIE8W0\+W!A<F$^"B`@("`@
M/'!A<F$^("5N(#H@02!N97<@;&EN93PO<&%R83X*("`@("`\<&%R83X@)24@
M.B!4:&4@)R4G(&-H87)A8W1E<CPO<&%R83X*"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7W)E860B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!297%U97-T(%)E860@4F5C
M96EP=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!A(%)E860@
M4F5C96EP="(@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G1S(&]F
M('1H:7,@;65S<V%G92!T;R!N;W1I9GD@>6]U('=H96X@=&AI<R!M97-S86=E
M(&ES(&]P96YE9"!B>2!T:&4@<F5C:7!I96YT<RX@3F]T(&%L;"!C;&EE;G1S
M('-U<'!O<G0@+R!H;VYO<B!T:&ES+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<V5N9%]M9&XB('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!396YD($U$3CPO=&ET
M;&4^"B`@("`\<&%R83X*("`@(")396YD(&$@341.(B!S96YD<R!A($UE<W-A
M9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("AA;'-O(&MN;W=N(&%S(&$@
M<F5A9"!R96-E:7!T*2!W:&5N('EO=2!V:65W(&$@;65S<V%G92!I;B!W:&EC
M:"!T:&4@=7-E<B!H87,@<F5Q=65S=&5D('1H870@=&AE>2!R96-E:79E(&YO
M=&EF:6-A=&EO;B!T:&%T('EO=2!H879E(')E860@=&AE(&UE<W-A9V4N($EN
M(&UO<W0@8V%S97,L('1H:7,@=VEL;"!H87!P96X@875T;VUA=&EC86QL>2!W
M:71H;W5T('!R;VUP=&EN9R!Y;W4N($EN(&-E<G1A:6X@:7-O;&%T960@8V%S
M97,L('EO=2!M87D@:&%V92!T;R!M86YU86QL>2!D96-I9&4@=&\@<V5N9"!T
M:&4@;F]T:69I8V%T:6]N(&)Y(&-L:6-K:6YG(&]N(&$@;&EN:RX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N
M7W)E<75E<W1?9&5L:79E<GDB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!297%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;CPO=&ET
M;&4^"B`@("`\<&%R83X*("`@(")297%U97-T($1E;&EV97)Y($-O;F9I<FUA
M=&EO;B(@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@<V5R=F5R('1O(&YO=&EF>2!Y;W4@=VAE;B!I="!H87,@9&5L:79E<F5D
M('1H92!M97-S86=E('1O('1H92!R96-I<&EE;G0G<R!M86EL8F]X+B!)="!D
M;V5S;B=T(&UE86X@=&AE(&UE<W-A9V4@:&%S(&)E96X@<V5E;BP@:G5S="!T
M:&%T(&ET)W,@<VET=&EN9R!I;B!A(&UA:6QB;W@@<V]M97=H97)E+B!.;W0@
M86QL(&UA:6P@<V5R=F5R<R!S=7!P;W)T('1H:7,N(`H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7W-P86U?869T97)?
M<F5P;W)T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M1&5L971E(%-P86T@069T97(@4F5P;W)T:6YG/"]T:71L93X*("`@(#QP87)A
M/@H@("`@66]U(&UA>2!E;&5C="!T;R!D;R!O;F4@;V8@=&AR964@:71E;7,@
M869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!E:71H97(@<W!A;2!O<B!I
M;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@1FER<W0L('EO
M=2!C86X@9&5C:61E('1O(&1O(&YO=&AI;F<@+2!T:&4@;65S<V%G92!W:6QL
M(&)E(')E<&]R=&5D(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C96YT(&)U="!W
M:6QL(&]T:&5R=VES92!R96UA:6X@=6YC:&%N9V5D(&EN('EO=7(@;6%I;&)O
M>"X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V5C;VYD+"!I9B!R97!O
M<G1I;F<@82!M97-S86=E(&%S('-P86TL('EO=2!C86X@:6YS=&5A9"!H879E
M('1H92!M97-S86=E(&)E(&EM;65D:6%T96QY(&1E;&5T960N("!4:&ES('-E
M='1I;F<@:&%S(&YO(&5F9F5C="!O;B!R97!O<G1I;F<@82!M97-S86=E(&%S
M(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!4:&ER9"P@
M869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!S<&%M('1H92!M97-S86=E
M('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD
M(&UO=F5D('1O('EO=7(@<W!A;2!F;VQD97(N("!!;'1E<FYA=&EV96QY+"!I
M9B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT('1H92!M97-S86=E
M('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD
M(&UO=F5D('1O('EO=7(@24Y"3U@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUH=&UL7VEM86=E7W)E<&QA8V5M96YT(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G92!2
M97!L86-E;65N=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($9O<B!(5$U,(&UE
M<W-A9V5S(&1I<W!L87EE9"!I;FQI;F4L('-H;W5L9"!A;&P@:6UA9V4@=&%G
M<R!B92!B;&]C:V5D('5N=&EL('EO=2!S<&5C:69I8V%L;'D@9&5C:61E('1O
M('9I97<@=&AO<V4@:6UA9V5S/R!.;W1E('1H870L(&EF('9I97=I;F<@86X@
M2%1-3"!A='1A8VAM96YT+"!T:&4@:6UA9V5S('=I;&P@86QW87ES(&)E(&1I
M<W!L87EE9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+6AT;6Q?:6UA9V5?861D<F)O;VLB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!(5$U,($EM86=E(%)E<&QA8V5M96YT+T%D9')E
M<W-B;V]K(%-H;W<\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!B;&]C:VEN
M9R!I;6%G97,@9F]R(&EN;&EN92!(5$U,(&UE<W-A9V5S+"!S:&]U;&0@=V4@
M875T;VUA=&EC86QL>2!D:7-P;&%Y('1H96T@:6YS=&5A9"!I9B!T:&4@<V5N
M9&5R(&%P<&5A<G,@:6X@>6]U<B!A9&1R97-S8F]O:S\*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A<G0B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EL8F]X(%-T
M87)T(%!A9V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H
M:6-H('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=R!W:6QL(&)E(&1I<W!L87EE
M9"!W:&5N('EO=2!A8V-E<W,@82!M86EL8F]X(&9O<B!T:&4@9FER<W0@=&EM
M92X@3F]T92!T:&%T('1H92`G=6YS965N)R!M97-S86=E(&]P=&EO;G,@9&\@
M;F]T('=O<FL@=VET:"!T:&4@)U1H<F5A9"<@<V]R=&EN9R!O<'1I;VX@+2!I
M;G-T96%D+"!Y;W4@=VEL;"!B92!S96YT('1O('1H92!L87-T('!A9V4N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E7V%T
M=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@4V%V92!!='1A8VAM96YT<R!O;B!396YT($UE<W-A9V5S/"]T:71L93X*
M("`@(#QP87)A/@H@("`@268@<V%V:6YG(&$@8V]M<&]S960@;65S<V%G92!I
M;B!A('-E;G0M;6%I;"!F;VQD97(L(&1E=&5R;6EN92!I9B!A;&P@871T86-H
M;65N="!D871A(&ES('-A=F5D+B!4:&4@9F]L;&]W:6YG(&]P=&EO;G,@87)E
M(&%V86EL86)L93H*("`@(#PO<&%R83X*"B`@("`\<&%R83XJ(")!;'=A>7,@
M<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A='1A
M8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S(&%R
M92!!3%=!65,@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"B`@("`@
M/'!A<F$^*B`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S
M96YT.R!D969A=6QT('1O(%E%4R(@+2!!3%=!65,@<')O;7!T('1O('-A=F4@
M871T86-H;65N=',@:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F875L
M="!I<R!T;R!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R83XJ
M(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E
M9F%U;'0@=&\@3D\B("T@04Q705E3('!R;VUP="!T;R!S879E(&%T=&%C:&UE
M;G1S(&EN('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@:7,@=&\@
M;F]T('-A=F4@871T86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@(DYE
M=F5R('-A=F4@871T86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A=F4@
M871T86-H;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT
M<R!A<F4@3D5615(@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7VEN8F]X(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@26YB;W@\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)U=&%L($EN8F]X(&ES(&$@<V%V
M960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@=&\@<V5A
M<F-H(&5V97)Y(&UA:6QB;W@@9F]R(&UE<W-A9V5S(&UA<FME9"!A<R!N97<N
M("!);G-T96%D+"!A;&P@8W5R<F5N=&QY('-U8G-C<FEB960@;6%I;&)O>&5S
M(&%R92!S96%R8VAE9"!F;W(@;F5W(&UE<W-A9V5S(&%N9"!T:&4@<F5S=6QT
M<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7W1R87-H(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@
M5')A<V@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)T=6%L(%1R87-H(&ES
M(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@
M9F]R(&$@<V5P87)A=&4@5')A<V@@9F]L9&5R+B`@26YS=&5A9"!O9B!M;W9I
M;F<@;65S<V%G97,@=&\@82!C96YT<F%L:7IE9"!T<F%S:"!F;VQD97(L(&UE
M<W-A9V5S(&%R92!S:6UP;'D@;6%R:V5D(&%S(&1E;&5T960@:6X@=&AE(&-U
M<G)E;G0@9F]L9&5R('1H97D@;&EV92!I;BX@(%=H96X@)W-H;W<@9&5L971E
M9"!M97-S86=E<R<@:7,@='5R;F5D(&]F9BP@=&AI<R!R97-U;'1S(&EN('1H
M97-E(&UE<W-A9V5S(&YO="!A<'!E87)I;F<@:6X@82!M86EL8F]X('9I97<N
M("!7:&5N(&$@=7-E<B!C;&EC:W,@;VX@5FER='5A;"!4<F%S:"P@*F%L;"H@
M;6%I;&)O>&5S(&%L;"!S96%R8VAE9"!F;W(@;65S<V%G97,@=&AA="!A<F4@
M9FQA9V=E9"!D96QE=&5D(&%N9"!T:&5S92!M97-S86=E<R!A<F4@9&ES<&QA
M>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"CPO:&5L<#X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+V1E7T1%+P``````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8P
M`#`Q-S0P-@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O9&5?
M1$4O3$-?34534T%'15,O````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-C``,#(Q,3<S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+VQO8V%L92]D95]$12],0U]-15-304=%4R]I;7`N;6\`````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#<R,3(W,@`Q,#0Q-S,V,C<V,``P,C(S,C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````WA($E0``
M``"("P``'````%Q<``!G#P``G+@````````X]@``"@```#GV```*````1/8`
M``H```!/]@``"@```%KV```.````9?8```\```!T]@``#0```(3V```(````
MDO8```L```";]@``#````*?V```*````M/8```0```"_]@``!````,3V```8
M````R?8``!L```#B]@``+0```/[V```=````+/<``"0```!*]P``*0```&_W
M```9````F?<```$```"S]P``&0```+7W```F````S_<```P```#V]P``"P``
M``/X```D````#_@``!X````T^```2````%/X```K````G/@``$0```#(^```
M)P````WY```7````-?D```\```!-^0``"P```%WY```.````:?D```4```!X
M^0``*````'[Y```(````I_D```H```"P^0``%0```+OY```2````T?D``#(`
M``#D^0``"P```!?Z```I````(_H``#(```!-^@``$````(#Z```6````D?H`
M`!````"H^@``)@```+GZ```I````X/H``"8````*^P``'````#'[``"%````
M3OL```X```#4^P``"@```./[```-````[OL``"<```#\^P``(@```"3\```.
M````1_P``"(```!6_```&0```'G\```D````D_P``#<```"X_```$0```/#\
M```-`````OT```P````0_0``#0```!W]```&````*_T``!L````R_0``E```
M`$[]```N````X_T``#<````2_@``!@```$K^```,````4?X``'P```!>_@``
M;````-O^```<````2/\``!T```!E_P``"@```(/_```/````CO\``!@```">
M_P``#````+?_```;````Q/\``$4```#@_P``*````"8``0!!````3P`!`"0`
M``"1``$`#@```+8``0`/````Q0`!``X```#5``$`#@```.0``0`(````\P`!
M``X```#\``$`#@````L!`0`)````&@$!`"X````D`0$`&@```%,!`0`S````
M;@$!`%$```"B`0$`,@```/0!`0`X````)P(!`%0```!@`@$`40```+4"`0!:
M````!P,!`%<```!B`P$`-````+H#`0`)````[P,!``T```#Y`P$`!P````<$
M`0`*````#P0!``\````:!`$`!0```"H$`0`#````,`0!``8````T!`$`$0``
M`#L$`0`(````300!``D```!6!`$`"0```&`$`0`=````:@0!``X```"(!`$`
M"````)<$`0`*````H`0!`"4```"K!`$`(````-$$`0`3````\@0!`!`````&
M!0$`#P```!<%`0`/````)P4!``H````W!0$`!P```$(%`0`#````2@4!`!D`
M``!.!0$`#P```&@%`0`4````>`4!``D```"-!0$`#0```)<%`0`2````I04!
M`!D```"X!0$`'@```-(%`0`/````\04!``H````!!@$`#P````P&`0`(````
M'`8!``H````E!@$`)````#`&`0`7````508!`!0```!M!@$`%@```((&`0`2
M````F08!``@```"L!@$`'````+4&`0!.````T@8!`"T````A!P$`&0```$\'
M`0!@````:0<!`"@```#*!P$`'@```/,'`0`:````$@@!`"P````M"`$`(```
M`%H(`0`R````>P@!``<```"N"`$`#````+8(`0`-````PP@!`%0```#1"`$`
M8P```"8)`0`L````B@D!``X```"W"0$``P```,8)`0`+````R@D!``<```#6
M"0$`!P```-X)`0`%````Y@D!``4```#L"0$`"@```/()`0`#````_0D!`!<`
M```!"@$`"@```!D*`0`/````)`H!``X````T"@$`3@```$,*`0!0````D@H!
M`$,```#C"@$`0@```"<+`0`]````:@L!`!8```"H"P$`,````+\+`0`8````
M\`L!`",````)#`$`#@```"T,`0`4````/`P!`!<```!1#`$`%P```&D,`0`7
M````@0P!`!,```"9#`$`#P```*T,`0`C````O0P!``8```#A#`$`%P```.@,
M`0`.``````T!`%$````/#0$`'P```&$-`0`=````@0T!`#4```"?#0$`-0``
M`-4-`0`'````"PX!``8````3#@$`"````!H.`0`/````(PX!``8````S#@$`
M"````#H.`0`1````0PX!``H```!5#@$`$P```&`.`0`+````=`X!`!````"`
M#@$`%0```)$.`0`-````IPX!`!,```"U#@$`(P```,D.`0`O````[0X!`!4`
M```=#P$`!P```#,/`0`0````.P\!``4```!,#P$`%0```%(/`0`1````:`\!
M``P```!Z#P$`/P```(</`0`P````QP\!`$@```#X#P$`(0```$$0`0`[````
M8Q`!`#L```"?$`$`/````-L0`0`X````&!$!`"L```!1$0$`,````'T1`0`Q
M````KA$!`#L```#@$0$`.0```!P2`0`U````5A(!``D```",$@$`!P```)82
M`0`4````GA(!``P```"S$@$``P```,`2`0`%````Q!(!``D```#*$@$`$```
M`-02`0`)````Y1(!`!,```#O$@$``P````,3`0`Y````!Q,!`!(```!!$P$`
M#````%03`0`U````81,!``X```"7$P$`20```*83`0`S````\!,!``H````D
M%`$`%@```"\4`0`6````1A0!`"T```!=%`$`"P```(L4`0`G````EQ0!`"P`
M``"_%`$`*@```.P4`0`E````%Q4!``D````]%0$`"0```$<5`0`*````414!
M``8```!<%0$`"0```&,5`0`'````;14!`"\```!U%0$`-P```*45`0`N````
MW14!`%4````,%@$`+0```&(6`0`L````D!8!`"T```"]%@$`/0```.L6`0`_
M````*1<!`"T```!I%P$`0````)<7`0`C````V!<!`",```#\%P$`0````"`8
M`0`M````81@!`#,```"/&`$`)0```,,8`0`5````Z1@!`!D```#_&`$`*0``
M`!D9`0`D````0QD!`"@```!H&0$`4````)$9`0`8````XAD!`!$```#[&0$`
M$0````T:`0`*````'QH!``P````J&@$`"P```#<:`0`*````0QH!`",```!.
M&@$`%@```'(:`0`*````B1H!`!````"4&@$`%@```*4:`0`6````O!H!`!L`
M``#3&@$`+@```.\:`0`0````'AL!``<````O&P$`!P```#<;`0`4````/QL!
M``H```!4&P$`"````%\;`0`G````:!L!``@```"0&P$``P```)D;`0`'````
MG1L!``<```"E&P$`!@```*T;`0`X````M!L!``4```#M&P$`!P```/,;`0`&
M````^QL!``@````"'`$`"0````L<`0`I````%1P!``X````_'`$`"@```$X<
M`0!%````61P!``0```"?'`$`!````*0<`0`'````J1P!``D```"Q'`$`!@``
M`+L<`0`1````PAP!``<```#4'`$`%@```-P<`0`$````\QP!`"<```#X'`$`
M"````"`=`0`&````*1T!``T````P'0$`!@```#X=`0`>````11T!`!$```!D
M'0$`"````'8=`0`-````?QT!``P```"-'0$`!P```)H=`0`#````HAT!`$8`
M``"F'0$``P```.T=`0`7````\1T!`!,````)'@$`"````!T>`0`=````)AX!
M``@```!$'@$`!````$T>`0`(````4AX!``@```!;'@$`*@```&0>`0`K````
MCQX!`%,```"['@$`00````\?`0`:````41\!`"L```!L'P$`(````)@?`0`5
M````N1\!``8```#/'P$`!@```-8?`0`.````W1\!`!4```#L'P$`/@````(@
M`0`8````02`!`"(```!:(`$`+@```'T@`0`=````K"`!`"$```#*(`$`5```
M`.P@`0`I````02$!``H```!K(0$`!P```'8A`0`'````?B$!`!4```"&(0$`
M#@```)PA`0`"````JR$!``H```"N(0$`#P```+DA`0`-````R2$!``\```#7
M(0$`#0```.<A`0`)````]2$!`!0```#_(0$`!@```!0B`0`8````&R(!`!T`
M```T(@$`$P```%(B`0`1````9B(!`!0```!X(@$`3P```(TB`0`$````W2(!
M``P```#B(@$`!@```.\B`0`*````]B(!``T````!(P$`%`````\C`0!B````
M)",!`"<```"'(P$`5````*\C`0!?````!"0!`&0```!D)`$`!````,DD`0`6
M````SB0!``X```#E)`$`'````/0D`0`/````$24!`#,````A)0$`*````%4E
M`0`%````?B4!``4```"$)0$`&P```(HE`0`:````IB4!``X```#!)0$`$P``
M`-`E`0`5````Y"4!`#````#Z)0$`$0```"LF`0`1````/28!`!P```!/)@$`
M*@```&PF`0`U````ER8!`$4```#-)@$`$````!,G`0`A````)"<!``4```!&
M)P$`$P```$PG`0`+````8"<!`!(```!L)P$`"@```'\G`0`/````BB<!``T`
M``":)P$`1P```*@G`0`?````\"<!`"4````0*`$`,P```#8H`0`K````:B@!
M`#4```"6*`$`0@```,PH`0`=````#RD!`%$````M*0$`$0```'\I`0`Q````
MD2D!`#L```##*0$`$P```/\I`0!`````$RH!`#@```!4*@$`!0```(TJ`0`,
M````DRH!`!$```"@*@$`#0```+(J`0`&````P"H!``P```#'*@$`!@```-0J
M`0`7````VRH!``@```#S*@$`#````/PJ`0`4````"2L!``\````>*P$`$```
M`"XK`0`1````/RL!``@```!1*P$`!0```%HK`0`1````8"L!``P```!R*P$`
M$````'\K`0`%````D"L!``T```"6*P$`!@```*0K`0`'````JRL!``T```"S
M*P$`!P```,$K`0`+````R2L!``<```#5*P$`!P```-TK`0`)````Y2L!`!<`
M``#O*P$`)@````<L`0!/````+BP!``D```!^+`$`"0```(@L`0`*````DBP!
M`!D```"=+`$`/0```+<L`0`=````]2P!``P````3+0$`)0```"`M`0`?````
M1BT!`!````!F+0$`!0```'<M`0`E````?2T!`"(```"C+0$`$@```,8M`0`3
M````V2T!`"L```#M+0$`.P```!DN`0`@````52X!`!L```!V+@$`"````)(N
M`0`V````FRX!`"$```#2+@$`$````/0N`0`(````!2\!`!L````.+P$`'@``
M`"HO`0`O````22\!`%P```!Y+P$`+@```-8O`0`,````!3`!``8````2,`$`
M!````!DP`0`/````'C`!``X````N,`$`#@```#TP`0`'````3#`!``X```!4
M,`$`!P```&,P`0`*````:S`!``T```!V,`$`'P```(0P`0`<````I#`!`"$`
M``#!,`$`'@```.,P`0`9`````C$!`!X````<,0$`&P```#LQ`0`L````5S$!
M`"$```"$,0$`+@```*8Q`0`F````U3$!`"0```#\,0$`'````"$R`0`>````
M/C(!`!P```!=,@$`)@```'HR`0`V````H3(!`"L```#8,@$`,P````0S`0`I
M````.#,!`$$```!B,P$`.@```*0S`0`F````WS,!`"L````&-`$`.````#(T
M`0`=````:S0!`!4```")-`$`+P```)\T`0`@````SS0!`!(```#P-`$`*0``
M``,U`0`>````+34!`#T```!,-0$`(````(HU`0`2````JS4!`*(```"^-0$`
M%@```&$V`0`C````>#8!`"@```"<-@$`*0```,4V`0`Z````[S8!`"@````J
M-P$`'P```%,W`0`5````<S<!`"````")-P$`)0```*HW`0`H````T#<!`"T`
M``#Y-P$`,````"<X`0"2````6#@!`"$```#K.`$`%@````TY`0`<````)#D!
M`"8```!!.0$`*@```&@Y`0!!````DSD!`$0```#5.0$`#````!HZ`0`'````
M)SH!``<````O.@$`!@```#<Z`0`-````/CH!``L```!,.@$`%````%@Z`0`-
M````;3H!`!@```![.@$`&@```)0Z`0`0````KSH!`!T```#`.@$`&0```-XZ
M`0!=````^#H!`!4```!6.P$`)0```&P[`0`2````DCL!`!,```"E.P$`$@``
M`+D[`0`'````S#L!``0```#4.P$`$````-D[`0`0````ZCL!``P```#[.P$`
M#@````@\`0`-````%SP!``\````E/`$`%````#4\`0`3````2CP!``T```!>
M/`$`.0```&P\`0`<````ICP!`"@```##/`$``P```.P\`0`-````\#P!``8`
M``#^/`$`$0````4]`0`7````%ST!`!L````O/0$`#@```$L]`0`"````6CT!
M`$D```!=/0$`!0```*<]`0`%````K3T!`!````"S/0$`#P```,0]`0`$````
MU#T!``T```#9/0$`#@```.<]`0`#````]CT!``X```#Z/0$`"`````D^`0`/
M````$CX!``@````B/@$`"@```"L^`0`/````-CX!``<```!&/@$`#0```$X^
M`0`0````7#X!`!0```!M/@$`#0```((^`0`9````D#X!`!H```"J/@$`"P``
M`,4^`0`)````T3X!``8```#;/@$`%````.(^`0`+````]SX!`!,````#/P$`
M$````!<_`0`,````*#\!``H````U/P$`$0```$`_`0`7````4C\!`!$```!J
M/P$`%0```'P_`0`G````DC\!`!D```"Z/P$`"P```-0_`0`-````X#\!`"(`
M``#N/P$`*P```!%``0`7````/4`!``\```!50`$`-````&5``0`S````FD`!
M`!L```#.0`$`-````.I``0`*````'T$!`!@````J00$`%````$-!`0`2````
M6$$!`!D```!K00$`%@```(5!`0`'````G$$!`!````"D00$`(@```+5!`0`<
M````V$$!`!P```#U00$`#0```!)"`0`'````($(!``P````H0@$`)@```#5"
M`0`*````7$(!`!0```!G0@$`"P```'Q"`0`'````B$(!`"(```"00@$`+P``
M`+-"`0`+````XT(!``D```#O0@$`&0```/E"`0`+````$T,!`"H````?0P$`
M#P```$I#`0`7````6D,!`!<```!R0P$`"0```(I#`0`'````E$,!`!8```"<
M0P$`#P```+-#`0`M````PT,!`!D```#Q0P$`%@````M$`0`.````(D0!`!H`
M```Q1`$`*````$Q$`0`M````=40!`"X```"C1`$`"P```-)$`0`8````WD0!
M``@```#W1`$`#`````!%`0`C````#44!``T````Q10$`)@```#]%`0`J````
M9D4!`"````"110$`0P```+)%`0`(````]D4!`!(```#_10$`'P```!)&`0`$
M````,D8!``@````W1@$`"P```$!&`0`:````3$8!`"<```!G1@$`$@```(]&
M`0`@````HD8!`"\```##1@$`%P```/-&`0`%````"T<!``P````11P$`#@``
M`!Y'`0`.````+4<!``4````\1P$`!@```$)'`0`.````24<!`$4```!81P$`
M`P```)Y'`0`#````HD<!`"L```"F1P$`!P```-)'`0`$````VD<!``X```#?
M1P$`"@```.Y'`0`,````^4<!``H````&2`$`#P```!%(`0`0````(4@!`!<`
M```R2`$`$0```$I(`0`3````7$@!`"4```!P2`$`#@```)9(`0`1````I4@!
M`!D```"W2`$`%P```-%(`0`3````Z4@!`!8```#]2`$`.````!1)`0`3````
M34D!``D```!A20$`!0```&M)`0`+````<4D!``H```!]20$``@```(A)`0`%
M````BTD!``T```"120$`&P```)])`0`7````NTD!`!0```#320$`"0```.A)
M`0`=````\DD!`"\````02@$`#P```$!*`0`6````4$H!`!(```!G2@$`"P``
M`'I*`0`,````ADH!``X```"32@$`#0```*)*`0`2````L$H!`!D```##2@$`
M'````-U*`0`X````^DH!`!@````S2P$`(````$Q+`0`3````;4L!``D```"!
M2P$``P```(M+`0`5````CTL!``L```"E2P$`$P```+%+`0`(````Q4L!``X`
M``#.2P$`$````-U+`0![````[DL!`!@```!J3`$`&````(-,`0`G````G$P!
M`"D```#$3`$`+````.Y,`0`H````&TT!``X```!$30$`-0```%--`0`1````
MB4T!``<```";30$`!0```*--`0`I````J4T!`!@```#330$`'@```.Q-`0`;
M````"TX!`!D````G3@$`&````$%.`0`;````6DX!`!D```!V3@$`$P```)!.
M`0`'````I$X!``@```"L3@$`!@```+5.`0`&````O$X!`!L```##3@$`$```
M`-].`0`/````\$X!`!``````3P$`#P```!%/`0`+````(4\!``\````M3P$`
M#````#U/`0`/````2D\!``<```!:3P$`!@```&)/`0`*````:4\!`!(```!T
M3P$`#0```(=/`0`,````E4\!``X```"B3P$`0P```+%/`0`]````]4\!``D`
M```S4`$`#````#U0`0`H````2E`!``\```!S4`$`"````(-0`0`(````C%`!
M`!,```"54`$`"P```*E0`0`>````M5`!`"$```#44`$`(````/90`0`9````
M%U$!`!<````Q40$`)0```$E1`0`7````;U$!`!8```"'40$`!````)Y1`0`;
M````HU$!``T```"_40$`#````,U1`0`#````VE$!``4```#>40$`"````.11
M`0`*````[5$!``P```#X40$`"@````52`0`@````$%(!`!\````Q4@$`&P``
M`%%2`0`9````;5(!``L```"'4@$`&P```)-2`0`+````KU(!`!````"[4@$`
M"````,Q2`0`,````U5(!``X```#B4@$`"P```/%2`0`$````_5(!``0````"
M4P$`$P````=3`0`4````&U,!``P````P4P$`"0```#U3`0`.````1U,!``L`
M``!64P$`&P```&)3`0`.````?E,!``\```"-4P$`)0```)U3`0`J````PU,!
M``<```#N4P$`$@```/93`0`;````"50!``0````E5`$`!P```"I4`0`*````
M,E0!`!(````]5`$`"@```%!4`0`-````6U0!``D```!I5`$`!````'-4`0`%
M````>%0!``@```!^5`$``P```(=4`0`8````BU0!`!T```"D5`$`$````,)4
M`0`.````TU0!`!X```#B5`$`&@````%5`0`*````'%4!``0````G50$`)@``
M`"Q5`0`.````4U4!`'P```!B50$`%0```-]5`0!$````]54!``4````Z5@$`
M!P```$!6`0`,````2%8!``@```!55@$`"@```%Y6`0`&````:58!``<```!P
M5@$`"````'A6`0`1````@58!`!D```"35@$`"````*U6`0`"````ME8!``8`
M``"Y5@$`!@```,!6`0`4````QU8!`!H```#<5@$`#0```/=6`0`0````!5<!
M`!L````65P$`!0```#)7`0`$````.%<!``P````]5P$`"0```$I7`0`0````
M5%<!``D```!E5P$`"0```&]7`0`$````>5<!``4```!^5P$`&@```(17`0`%
M````GU<!`!H```"E5P$`"````,!7`0`&````R5<!``\```#05P$`&0```.!7
M`0`.````^E<!``<````)6`$`!P```!%8`0`B````&5@!``4````\6`$`"0``
M`$)8`0`*````3%@!``X```!76`$``@```&98`0`-````:5@!`"````!W6`$`
M!@```)A8`0`+````GU@!``T```"K6`$`#````+E8`0`)````QE@!``8```#0
M6`$`$@```-=8`0`)````ZE@!``<```#T6`$`%````/Q8`0`=````$5D!`$(`
M```O60$`)0```')9`0`E````F%D!``8```"^60$`"@```,59`0`$````T%D!
M``D```#560$`"````-]9`0`1````Z%D!``D```#Z60$`!@````1:`0`-````
M"UH!``8````96@$`!````"!:`0`$````)5H!`!<````J6@$`.0```$):`0`]
M````?%H!`#H```"Z6@$`'@```/5:`0`%````%%L!``X````:6P$`!````"E;
M`0`&````+EL!``<````U6P$`(0```#U;`0`-````7UL!`!4```!M6P$`!@``
M`(-;`0`$````BEL!`!$```"/6P$`!@```*%;`0`*````J%L!`"(```"S6P$`
M)P```-9;`0`&````_EL!`!4````%7`$`#````!M<`0`1````*%P!``0````Z
M7`$`#0```#]<`0`'````35P!``4```!57`$`'0```%M<`0`$````>5P!``P`
M``!^7`$`#@```(M<`0`*````FEP!``@```"E7`$`"0```*Y<`0`%````N%P!
M`#H```"^7`$`,````/E<`0`U````*ET!`"D```!@70$`1P```(I=`0`X````
MTET!`"D````+7@$`/P```#5>`0`N````=5X!`"T```"D7@$`'P```-)>`0`/
M````\EX!`!(````"7P$`"P```!5?`0`F````(5\!`"<```!(7P$`*0```'!?
M`0`D````FE\!`"8```"_7P$`*````.9?`0`(````#V`!``H````88`$`"0``
M`"-@`0`'````+6`!``0````U8`$`'````#I@`0`W````5V`!`"````"/8`$`
M(````+!@`0`F````T6`!``T```#X8`$`)P````9A`0`;````+F$!`"(```!*
M80$`#````&UA`0`6````>F$!``H```"180$`&0```)QA`0`I````MF$!`!8`
M``#@80$`$@```/=A`0`'````"F(!``H````28@$`#````!UB`0`/````*F(!
M`!`````Z8@$`0````$MB`0!$````C&(!`#P```#18@$`<`````YC`0!F````
M?V,!``8```#F8P$`"@```.UC`0`%````^&,!``X```#^8P$`"0````UD`0`*
M````%V0!`!(````B9`$`$P```#5D`0`,````260!``8```!69`$`!@```%UD
M`0`*````9&0!``X```!O9`$`#P```'YD`0`.````CF0!`!L```"=9`$`'P``
M`+ED`0`>````V60!`",```#X9`$`$0```!QE`0`5````+F4!`!@```!$90$`
M$0```%UE`0`0````;V4!`",```"`90$`#P```*1E`0`)````M&4!`!(```"^
M90$`'0```-%E`0`2````[V4!`!`````"9@$`"@```!-F`0`1````'F8!``4`
M```P9@$`,0```#9F`0`D````:&8!`!P```"-9@$`(P```*IF`0!J````SF8!
M``\````Y9P$`!0```$EG`0`0````3V<!``D```!@9P$`!````&IG`0`+````
M;V<!`"````![9P$`'````)QG`0`C````N6<!`"(```#=9P$`!@````!H`0`4
M````!V@!`!<````<:`$`#````#1H`0`D````06@!`",```!F:`$`&@```(IH
M`0`,````I6@!``\```"R:`$`%0```,)H`0`I````V&@!`"H````":0$`)@``
M`"UI`0`G````5&D!`"D```!\:0$`*@```*9I`0`9````T6D!`$(```#K:0$`
M$0```"YJ`0`2````0&H!`!,```!3:@$`%````&=J`0`/````?&H!`!8```",
M:@$`%P```*-J`0`0````NVH!`!$```#,:@$`-````-YJ`0`3````$VL!`!(`
M```G:P$`-0```#IK`0`4````<&L!``<```"%:P$`#````(UK`0`K````FFL!
M``\```#&:P$`%@```-9K`0`@````[6L!`!`````.;`$`%````!]L`0`1````
M-&P!`"@```!&;`$`%P```&]L`0`<````AVP!`!,```"D;`$`"P```+AL`0`4
M````Q&P!`!H```#9;`$`$0```/1L`0`:````!FT!`!X````A;0$`&@```$!M
M`0`3````6VT!`"$```!O;0$`(````)%M`0`5````LFT!`!$```#(;0$`%P``
M`-IM`0`4````\FT!`!<````';@$`%0```!]N`0`)````-6X!``8````_;@$`
M$````$9N`0`9````5VX!``0```!Q;@$`!P```'9N`0`+````?FX!`!$```"*
M;@$`!@```)QN`0`&````HVX!``8```"J;@$`!0```+%N`0`'````MVX!``<`
M``"_;@$`!0```,=N`0`6````S6X!``8```#D;@$`!@```.MN`0`$````\FX!
M``0```#W;@$`!P```/QN`0`.````!&\!``P````3;P$`#````"!O`0`-````
M+6\!``(````[;P$`"@```#YO`0`.````26\!``4```!8;P$`*````%YO`0`.
M````AV\!``P```"6;P$`#P```*-O`0`*````LV\!``@```"^;P$`"0```,=O
M`0`K````T6\!`$\```#];P$`1P```$UP`0!3````E7`!`"X```#I<`$`!```
M`!AQ`0`(````'7$!`"8````F<0$`$@```$UQ`0`/````8'$!``8```!P<0$`
M"@```'=Q`0`'````@G$!``@```"*<0$`(````)-Q`0`)````M'$!`!$```"^
M<0$`"0```-!Q`0`4````VG$!``P```#O<0$`#0```/QQ`0`.````"G(!`!8`
M```9<@$`$0```#!R`0`&````0G(!``,```!)<@$`!@```$UR`0`9````5'(!
M``<```!N<@$`!````'9R`0`+````>W(!``L```"'<@$`!P```)-R`0`%````
MFW(!``<```"A<@$`%@```*ER`0`-````P'(!``T```#.<@$`"@```-QR`0`0
M````YW(!``\```#X<@$`$0````AS`0`7````&G,!``H````R<P$`$0```#US
M`0`(````3W,!``0```!8<P$`$0```%US`0`/````;W,!`#H```!_<P$`(0``
M`+IS`0`%````W',!`!<```#B<P$`#````/IS`0`>````!W0!``X````F=`$`
M$````#5T`0`+````1G0!`'P```!2=`$`#````,]T`0`)````W'0!``<```#F
M=`$`"@```.YT`0`)````^70!``X````#=0$`$````!)U`0`5````(W4!`!L`
M```Y=0$`&````%5U`0`:````;G4!``H```")=0$`"0```)1U`0`*````GG4!
M``X```"I=0$`#````+AU`0`/````Q74!``@```#5=0$`!@```-YU`0`,````
MY74!`!P```#R=0$`!P````]V`0`%````%W8!``L````==@$`1P```"EV`0`-
M````<78!``D```!_=@$`!````(EV`0`#````CG8!``P```"2=@$`$P```)]V
M`0`3````LW8!`!,```#'=@$`!@```-MV`0`*````XG8!``(```#M=@$`!```
M`/!V`0`E````]78!``,````;=P$`!0```!]W`0`J````)7<!``X```!0=P$`
M"@```%]W`0`%````:G<!``0```!P=P$`"@```'5W`0`-````@'<!`!\```".
M=P$`!P```*YW`0`B````MG<!``T```#9=P$`!@```.=W`0`(````[G<!``@`
M``#W=P$`!`````!X`0`%````!7@!`&@````+>`$`"0```'1X`0`,````?G@!
M`!````"+>`$`!0```)QX`0`&````HG@!`",```"I>`$`)0```,UX`0`(````
M\W@!`#<```#\>`$`(@```#1Y`0`3````5WD!`!L```!K>0$`+P```(=Y`0`0
M````MWD!``H```#(>0$`$0```--Y`0`/````Y7D!``\```#U>0$`"@````5Z
M`0`)````$'H!`!,````:>@$`&P```"YZ`0`8````2GH!`!<```!C>@$`%P``
M`'MZ`0`9````DWH!`!\```"M>@$`#@```,UZ`0`F````W'H!`"8````#>P$`
M`P```"I[`0`'````+GL!``@````V>P$`!P```#][`0`0````1WL!``H```!8
M>P$`"P```&-[`0`'````;WL!`!,```!W>P$`#````(M[`0`/````F'L!``X`
M``"H>P$`#````+=[`0`.````Q'L!`%$```#3>P$`#P```"5\`0`0````-7P!
M``T```!&?`$`#P```%1\`0`/````9'P!`!<```!T?`$`%````(Q\`0`1````
MH7P!``\```"S?`$`(````,-\`0`N````Y'P!`!H````3?0$`#````"Y]`0`F
M````.WT!``L```!B?0$`#0```&Y]`0`:````?'T!`$H```"7?0$`&0```.)]
M`0`&````_'T!`!H````#?@$`)0```!Y^`0`&````1'X!``8```!+?@$`'P``
M`%)^`0`&````<GX!``D```!Y?@$`&````(-^`0`7````G'X!`"@```"T?@$`
M!@```-U^`0`-````Y'X!`"(```#R?@$`5P```!5_`0`3````;7\!`",```"!
M?P$`$P```*5_`0`"````N7\!``L```"\?P$`"````,A_`0`-````T7\!``8`
M``#??P$`"@```.9_`0`'````\7\!`!0```#Y?P$`!@````Z``0`(````%8`!
M``X````>@`$`!P```"V``0`*````-8`!``L```!`@`$`,@```$R``0`K````
M?X`!``<```"K@`$`#````+.``0`-````P(`!`!<```#.@`$`#````.:``0`$
M````\X`!``D```#X@`$`"0````*!`0`*````#($!``<````7@0$`"0```!^!
M`0!`````*8$!``X```!J@0$`!P```'F!`0`*````@8$!`!L```",@0$`#P``
M`*B!`0`5````N($!`!4```#.@0$`$@```.2!`0`*````]X$!`!8````"@@$`
M"0```!F"`0`0````(X(!``<````T@@$`$@```#R"`0`$````3X(!``0```!4
M@@$`!````%F"`0`A````7H(!``<```"`@@$`!0```(B"`0`,````CH(!``4`
M``";@@$`"P```*&"`0`4````K8(!`!$```#"@@$`&@```-2"`0`6````[X(!
M`!0````&@P$`%P```!N#`0`8````,X,!`!P```!,@P$`&0```&F#`0`'````
M@X,!``4```"+@P$`%@```)&#`0`#````J(,!``T```"L@P$`#````+J#`0`*
M````QX,!``@```#2@P$`"P```-N#`0`1````YX,!``@```#Y@P$`%P````*$
M`0`+````&H0!``P````FA`$`#````#.$`0`?````0(0!`!H```!@A`$`$P``
M`'N$`0`$````CX0!``H```"4A`$`!````)^$`0`-````I(0!``P```"RA`$`
M"0```+^$`0`,````R80!``4```#6A`$`"0```-R$`0`%````YH0!``<```#L
MA`$`!0```/2$`0`$````^H0!``(```#_A`$`%`````*%`0`-````%X4!`!(`
M```EA0$`"P```#B%`0`;````1(4!`!\```!@A0$`#P```("%`0`4````D(4!
M`!X```"EA0$`%0```,2%`0`X````VH4!`"P````3A@$`$@```$"&`0`I````
M4X8!`#(```!]A@$`"@```+"&`0`L````NX8!`"X```#HA@$`,P```!>'`0`S
M````2X<!`#@```!_AP$`#P```+B'`0`8````R(<!`"\```#AAP$`$````!&(
M`0`3````(H@!`"H````VB`$`&0```&&(`0`<````>X@!`!\```"8B`$`#P``
M`+B(`0`3````R(@!`!4```#<B`$`%````/*(`0`4````!XD!`!0````<B0$`
M(````#&)`0`2````4HD!`!0```!EB0$`%0```'J)`0`M````D(D!`"T```"^
MB0$`,0```.R)`0`N````'HH!`"\```!-B@$`+````'V*`0!B````JHH!`!,`
M```-BP$`)0```"&+`0`D````1XL!`"D```!LBP$`2````):+`0`-````WXL!
M``@```#MBP$`%P```/:+`0`(````#HP!`"0````7C`$`$@```#R,`0`,````
M3XP!``X```!<C`$`-P```&N,`0`K````HXP!`!(```#/C`$`(0```.*,`0`:
M````!(T!``D````?C0$`10```"F-`0!!````;XT!``\```"QC0$`!````,&-
M`0`3````QHT!`!0```#:C0$`#@```.^-`0`&````_HT!`!,````%C@$`&```
M`!F.`0`&````,HX!``D````YC@$`"@```$..`0`+````3HX!``D```!:C@$`
M#0```&2.`0`,````<HX!``\```!_C@$`%P```(^.`0`4````IXX!`!````"\
MC@$`%@```,V.`0`'````Y(X!``X```#LC@$`(0```/N.`0`%````'8\!``<`
M```CCP$`&P```"N/`0`J````1X\!``@```!RCP$`!@```'N/`0`4````@H\!
M`!$```"7CP$`1````*F/`0`\````[H\!``X````KD`$`.````#J0`0`"````
M<Y`!``(```!VD`$`!@```'F0`0`.````@)`!``4```"/D`$`!P```)60`0`.
M````G9`!``8```"LD`$`*````+.0`0`,````W)`!``P```#ID`$`'````/:0
M`0`C````$Y$!``0````WD0$`*0```#R1`0`R````9I$!`!<```"9D0$`'P``
M`+&1`0`S````T9$!`%P````%D@$`#````&*2`0`4````;Y(!`#X```"$D@$`
M#0```,.2`0`?````T9(!`!````#QD@$`%`````*3`0`'````%Y,!``X````?
MDP$`#````"Z3`0`,````.Y,!`!,```!(DP$`"@```%R3`0`=````9Y,!`!D`
M``"%DP$`!0```)^3`0`1````I9,!`!,```"WDP$`#0```,N3`0`/````V9,!
M`!$```#IDP$`)````/N3`0`2````()0!``,````SE`$`%0```#>4`0`3````
M390!`!(```!AE`$`"P```'24`0`T````@)0!``L```"UE`$`%````,&4`0`^
M````UI0!``X````5E0$`$P```"25`0`T````.)4!`#$```!ME0$`$@```)^5
M`0`0````LI4!`!@```##E0$`&0```-R5`0`C````]I4!`"(````:E@$`)P``
M`#V6`0!6````998!`$T```"\E@$`N0````J7`0`(````Q)<!``D```#-EP$`
M#0```->7`0`'````Y9<!``H```#MEP$`!P```/B7`0`/`````)@!``8````0
MF`$`"P```!>8`0`$````(Y@!`!P````HF`$`#0```$68`0`G````4Y@!`!L`
M``![F`$`#````)>8`0`:````I)@!``H```"_F`$`!P```,J8`0`-````TI@!
M`"(```#@F`$`(0````.9`0`(````)9D!``4````NF0$`'P```#29`0`&````
M5)D!`!````!;F0$`"````&R9`0`'````=9D!``T```!]F0$`"@```(N9`0`2
M````EID!`"$```"IF0$`"P```,N9`0`;````UYD!`!@```#SF0$`"`````R:
M`0`>````%9H!`!(````TF@$`+````$>:`0`:````=)H!``D```"/F@$`"@``
M`)F:`0`5````I)H!``4```"ZF@$`%````,":`0`$````U9H!`!````#:F@$`
M!@```.N:`0`'````\IH!`!X```#ZF@$`*````!F;`0`*````0IL!`!P```!-
MFP$`$0```&J;`0`+````?)L!`!H```"(FP$`+````*.;`0`(````T)L!`!0`
M``#9FP$`+````.Z;`0`G````&YP!`"L```!#G`$`*@```&^<`0`$````FIP!
M``0```"?G`$`"P```*2<`0`%````L)P!``8```"VG`$`"````+V<`0`&````
MQIP!`#$```#-G`$`'````/^<`0`*````')T!`*(````GG0$`&P```,J=`0`T
M````YIT!`#0````;G@$`(````%">`0`I````<9X!`"<```";G@$`(````,.>
M`0!!````Y)X!`!H````FGP$`*````$&?`0`:````:I\!`'8```"%GP$`>0``
M`/R?`0`<`0``=J`!`"@```"3H0$`'0```+RA`0`I````VJ$!`!T````$H@$`
M4````"*B`0`N````<Z(!`#8```"BH@$`+````-FB`0`Q````!J,!`"X````X
MHP$`(@```&>C`0`&````BJ,!``@```"1HP$`!0```)JC`0`(````H*,!`!D`
M``"IHP$`&0```,.C`0`J````W:,!`!`````(I`$`*P```!FD`0`C````1:0!
M`!D```!II`$`(0```(.D`0`N````I:0!`#0```#4I`$`"`````FE`0`7````
M$J4!``H````JI0$`!P```#6E`0`A````/:4!`!````!?I0$`#0```'"E`0`0
M````?J4!``4```"/I0$`#@```)6E`0`(````I*4!``L```"MI0$`%````+FE
M`0`'````SJ4!`!,```#6I0$`"````.JE`0`V````\Z4!`#<````JI@$`"P``
M`&*F`0`)````;J8!``H```!XI@$`%````(.F`0`/````F*8!`"\```"HI@$`
M,@```-BF`0`+````"Z<!``X````7IP$`#0```":G`0`/````-*<!`!8```!$
MIP$`#@```%NG`0`^````:J<!`"<```"IIP$`)@```-&G`0`D````^*<!``4`
M```=J`$`!0```".H`0`%````*:@!`"<````OJ`$`'P```%>H`0`6````=Z@!
M``L```".J`$`%P```)JH`0`/````LJ@!``0```#"J`$`"@```,>H`0`)````
MTJ@!``L```#<J`$`#0```.BH`0`,````]J@!``X````#J0$`!0```!*I`0`$
M````&*D!``T````=J0$`,@```"NI`0!%````7JD!`!,```"DJ0$`"P```+BI
M`0`.````Q*D!``X```#3J0$`"0```.*I`0`(````[*D!`!````#UJ0$`%0``
M``:J`0`3````'*H!`!<````PJ@$`!P```$BJ`0`>````4*H!`!4```!OJ@$`
M%````(6J`0`%````FJH!`!0```"@J@$`!@```+6J`0`+````O*H!``<```#(
MJ@$`(P```-"J`0`6````]*H!``\````+JP$`#@```!NK`0`J````*JL!``8`
M``!5JP$`#````%RK`0`8````::L!``T```""JP$`$0```)"K`0`+````HJL!
M`#8```"NJP$`#0```.6K`0`*````\ZL!`"(```#^JP$`"P```"&L`0`/````
M+:P!`!`````]K`$`+@```$ZL`0`Z````?:P!``X```"XK`$`#0```,>L`0`%
M````U:P!``L```#;K`$`#````.>L`0`-````]*P!``T````"K0$`#@```!"M
M`0`-````'ZT!`"`````MK0$`)P```$ZM`0`K````=JT!``@```"BK0$`"@``
M`*NM`0`&````MJT!`!(```"]K0$`#@```-"M`0`7````WZT!`#(```#WK0$`
M%@```"JN`0`<````0:X!`"4```!>K@$`,````(2N`0`Q````M:X!`"T```#G
MK@$`#@```!6O`0`4````)*\!``4````YKP$`#@```#^O`0`3````3J\!`!H`
M``!BKP$`$@```'VO`0`'````D*\!``8```"8KP$`$P```)^O`0`?````LZ\!
M`!0```#3KP$`$0```.BO`0!+````^J\!`!,```!&L`$`!P```%JP`0`4````
M8K`!`!@```!WL`$`!P```)"P`0`%````F+`!``P```">L`$`#````*NP`0`2
M````N+`!``0```#+L`$`!P```-"P`0`*````V+`!``L```#CL`$`#````.^P
M`0`.````_+`!``X````+L0$`!0```!JQ`0`%````(+$!`"X````FL0$`)@``
M`%6Q`0`C````?+$!``,```"@L0$`$@```*2Q`0`&````M[$!``8```"^L0$`
M'@```,6Q`0`6````Y+$!`!@```#[L0$`#@```!2R`0`W````([(!``X```!;
ML@$`%P```&JR`0!!````@K(!`#0```#$L@$`)0```/FR`0`5````'[,!`#$`
M```ULP$`$P```&>S`0`;````>[,!`"H```"7LP$`40```,*S`0!9````%+0!
M`%````!NM`$`OP```+^T`0`E````?[4!``T```"EM0$`!````+.U`0`)````
MN+4!`!\```#"M0$``P```.*U`0`'````YK4!``H```#NM0$`"````/FU`0`"
M`````K8!`!`````%M@$`"````!:V`0`,````'[8!`!4````LM@$`"P```$*V
M`0`9````3K8!`"````!HM@$`$@```(FV`0`%````G+8!``H```"BM@$`%0``
M`*VV`0`2````P[8!``P```#6M@$`!````..V`0`)````Z+8!``<```#RM@$`
M,@```/JV`0`*````+;<!``H````XMP$`%0```$.W`0`,````6;<!``\```!F
MMP$`"P```':W`0`'````@K<!`!8```"*MP$`4@```*&W`0`Z````]+<!`"``
M```ON`$`#P```%"X`0`7````8+@!`"0```!XN`$`.0```)VX`0`2````U[@!
M``<```#JN`$`!@```/*X`0`)````^;@!``X````#N0$`#@```!*Y`0`.````
M(;D!``0````PN0$`!@```#6Y`0`6````/+D!``P```!3N0$`#0```&"Y`0`.
M````;KD!`!4```!]N0$`$@```).Y`0`/````IKD!`!0```"VN0$`%````,NY
M`0!#````X+D!``H````DN@$`&P```"^Z`0`U````2[H!`!$```"!N@$`$```
M`).Z`0`+````I+H!`&D```"PN@$`&@```!J[`0`7````-;L!`"@```!-NP$`
M)P```':[`0`;````GKL!`!H```"ZNP$`%P```-6[`0`;````[;L!`!D````)
MO`$`'P```".\`0`7````0[P!`!P```!;O`$`%P```'B\`0`,````D+P!`!,`
M``"=O`$`"````+&\`0`?````NKP!`"\```#:O`$`!P````J]`0`(````$KT!
M`!`````;O0$`$0```"R]`0`)````/KT!`!4```!(O0$`#0```%Z]`0`&````
M;+T!`!T```!SO0$`(P```)&]`0`'````M;T!``T```"]O0$`$P```,N]`0`(
M````W[T!``,```#HO0$`1@```.R]`0!#````,[X!`#(```!WO@$`/P```*J^
M`0`W````ZKX!`%<````BOP$`!0```'J_`0`?````@+\!`"\```"@OP$`"@``
M`-"_`0`-````V[\!`!(```#IOP$`*0```/R_`0`(````)L`!``T````OP`$`
M+0```#W``0!P````:\`!`#\```#<P`$`.0```!S!`0!&````5L$!``0```"=
MP0$`$````*+!`0`0````L\$!``P```#$P0$`%````-'!`0`=````YL$!`!P`
M```$P@$`$0```"'"`0`]````,\(!`$\```!QP@$`)0```,'"`0`@````Y\(!
M`!P````(PP$`"P```"7#`0`G````,<,!`!H```!9PP$`'P```'3#`0`=````
ME,,!`"@```"RPP$`#P```-O#`0`E````Z\,!`"`````1Q`$`)````#+$`0`D
M````5\0!`"````!\Q`$`)0```)W$`0`+````P\0!``<```#/Q`$`#0```-?$
M`0`,````Y<0!`!<```#RQ`$`!0````K%`0`&````$,4!`#D````7Q0$`!0``
M`%'%`0`,````5\4!``<```!DQ0$`"0```&S%`0`3````=L4!``8```"*Q0$`
M"0```)'%`0`$````F\4!`!````"@Q0$`"````+'%`0`(````NL4!``0```##
MQ0$`"P```,C%`0`,````U,4!`!(```#AQ0$`$0```/3%`0`,````!L8!`!H`
M```3Q@$`#P```"[&`0`'````/L8!``T```!&Q@$`#P```%3&`0`,````9,8!
M`!0```!QQ@$`%````(;&`0`/````F\8!``X```"KQ@$`$@```+K&`0`4````
MS<8!``X```#BQ@$`#````/'&`0`;````_L8!`"P````:QP$`$P```$?'`0`<
M````6\<!`"@```!XQP$`!@```*''`0`'````J,<!`!,```"PQP$`!0```,3'
M`0`$````RL<!``P```#/QP$`%P```-S'`0`2````],<!`"D````'R`$`"P``
M`#'(`0`-````/<@!`!0```!+R`$`+P```&#(`0`*````D,@!``P```";R`$`
M"0```*C(`0`&````LL@!``D```"YR`$`"````,/(`0`)````S,@!``4```#6
MR`$`"@```-S(`0`1````Y\@!``H```#YR`$`$`````3)`0`0````%<D!``L`
M```FR0$`!@```#+)`0`.````.<D!``X```!(R0$`#0```%?)`0`+````9<D!
M`!````!QR0$`'0```(+)`0`1````H,D!``L```"RR0$``@```+[)`0`(````
MP<D!`!P```#*R0$`!P```.?)`0`-````[\D!``8```#]R0$`9`````3*`0`6
M````:<H!``D```"`R@$`!P```(K*`0`F````DLH!`#@```"YR@$`&@```/+*
M`0`J````#<L!`#L````XRP$`*````'3+`0`T````G<L!`!D```#2RP$`%0``
M`.S+`0`%`````LP!``L````(S`$`!P```!3,`0`(````',P!``<````ES`$`
M!0```"W,`0`'````,\P!``X````[S`$`"0```$K,`0`&````5,P!``@```!;
MS`$`"P```&3,`0`'````<,P!``@```!XS`$`!P```(',`0`6````B<P!``D`
M``"@S`$`!@```*K,`0`9````L<P!`!H```#+S`$`(````.;,`0`+````!\T!
M`!`````3S0$`!@```"3-`0`<````*\T!`!0```!(S0$`!P```%W-`0`1````
M9<T!``@```!WS0$`#@```(#-`0`(````C\T!`!````"8S0$`"0```*G-`0`0
M````L\T!``8```#$S0$`&0```,O-`0`*````Y<T!`!P```#PS0$`!P````W.
M`0`%````%<X!``4````;S@$`$````"'.`0`4````,LX!``L```!'S@$`#0``
M`%/.`0`H````8<X!`!@```"*S@$`%P```*/.`0`+````N\X!`!H```#'S@$`
M%````.+.`0`O````]\X!``0````GSP$`"0```"S/`0`*````-L\!``<```!!
MSP$``@```$G/`0`.````3,\!``@```!;SP$`(P```&3/`0`Q````B,\!`!\`
M``"ZSP$`.````-K/`0!X````$]`!`"8```",T`$`&P```+/0`0`Q````S]`!
M`#$````!T0$`)P```#/1`0`B````6]$!`"````!^T0$`9````)_1`0`=````
M!-(!`!0````BT@$`'````#?2`0!5````5-(!`#@```"JT@$`+0```./2`0`S
M````$=,!`$L```!%TP$`2@```)'3`0!;````W-,!`"@````XU`$`+````&'4
M`0`X````CM0!`"4```#'U`$`(0```.W4`0`H````#]4!`"P````XU0$`)@``
M`&75`0`;````C-4!`!X```"HU0$`=0```,?5`0`^````/=8!`$(```!\U@$`
M/0```+_6`0`]````_=8!`"D````[UP$`*0```&77`0`Q````C]<!`#X```#!
MUP$`+P````#8`0"I`0``,-@!`",```#:V0$`8@```/[9`0!/````8=H!`!<`
M``"QV@$`2````,G:`0`V````$ML!`#X```!)VP$`,````(C;`0`@````N=L!
M`#\```#:VP$`-````!K<`0`L````3]P!`!T```!\W`$`'@```)K<`0`J````
MN=P!`(4```#DW`$`,````&K=`0`E````F]T!`$$```#!W0$`6P````/>`0!)
M````7]X!`#$```"IW@$`-````-O>`0`\````$-\!`#@```!-WP$`'0```(;?
M`0`8````I-\!`*<```"]WP$`*P```&7@`0`A````D>`!`!\```"SX`$`/```
M`-/@`0`D````$.$!`"@````UX0$`*P```%[A`0`B````BN$!`"8```"MX0$`
M(P```-3A`0`E````^.$!`"4````>X@$`*0```$3B`0`G````;N(!`!<```"6
MX@$`*0```*[B`0`@````V.(!`#(```#YX@$`'````"SC`0`N````2>,!`#H`
M``!XXP$`'0```+/C`0`1````T>,!`#,```#CXP$`)0```!?D`0`X````/>0!
M`"<```!VY`$`(````)[D`0`\````O^0!`"8```#\Y`$`'P```"/E`0`P````
M0^4!`&D```!TY0$`+@```-[E`0`Q````#>8!`$$````_Y@$`/@```('F`0`S
M````P.8!`"4```#TY@$`/0```!KG`0!E````6.<!`$T```"^YP$`4P````SH
M`0!7````8.@!`%4```"XZ`$`1@````[I`0`J````5>D!`"\```"`Z0$`50``
M`+#I`0`@````!NH!`"X````GZ@$`*P```%;J`0`P````@NH!`"H```"SZ@$`
M/@```-[J`0!4````'>L!`%(```!RZP$`6@```,7K`0`R````(.P!`"L```!3
M[`$`2````'_L`0!*````R.P!`"H````3[0$`+````#[M`0!.````:^T!`#(`
M``"Z[0$`,````.WM`0`=````'NX!`",````\[@$`+P```&#N`0`L````D.X!
M`"T```"][@$`<0```.ON`0!F````7>\!`&\```#$[P$`LP```#3P`0`7````
MZ/`!`"4`````\0$`,@```";Q`0`I````6?$!`#X```"#\0$`(@```,+Q`0!2
M````Y?$!`"4````X\@$`"P```%[R`0"Q````:O(!`#L````<\P$`)P```%CS
M`0!.````@/,!`$<```#/\P$`8@```!?T`0!)````>O0!`%4```#$]`$`0```
M`!KU`0`O````6_4!`#(```"+]0$`*P```+[U`0`I````ZO4!``\````4]@$`
M10```"3V`0`A````:O8!`#````",]@$`+0```+WV`0`E````Z_8!`!P````1
M]P$`,0```"[W`0`Q````8/<!``X```"2]P$`"P```*'W`0`'````K?<!``<`
M``"U]P$`!````+WW`0`-````PO<!``L```#0]P$`#@```-SW`0`+````Z_<!
M``4```#W]P$`$````/WW`0`"````#O@!``H````1^`$`5@```!SX`0!9````
M<_@!`$X```#-^`$`!0```!SY`0`2````(OD!``0````U^0$`!P```#KY`0`(
M````0OD!``4```!+^0$`,````%'Y`0`#````@OD!`!````"&^0$`%P```)?Y
M`0`,````K_D!``P```"\^0$`#0```,GY`0`3````U_D!``T```#K^0$``@``
M`/GY`0`'````_/D!``8````$^@$`%`````OZ`0`,````(/H!`!@````M^@$`
M!@```$;Z`0`2````3?H!``P```!@^@$``P```&WZ`0`J````<?H!``0```"<
M^@$`!@```*'Z`0`'````J/H!`!\```"P^@$`-0```-#Z`0`N````!OL!`"\`
M```U^P$`%P```&7[`0`B````??L!`"4```"@^P$`(````,;[`0`;````Y_L!
M`!@````#_`$`)````!S\`0`?````0?P!`!H```!A_`$`(0```'S\`0`@````
MGOP!`!H```"__`$`,@```-K\`0`:````#?T!`"\````H_0$`*P```%C]`0`?
M````A/T!`",```"D_0$`'P```,C]`0`:````Z/T!`"$````#_@$`)0```"7^
M`0`F````2_X!`"4```!R_@$`)````)C^`0`8````O?X!`!T```#6_@$`)```
M`/3^`0`8````&?\!`"(````R_P$`+````%7_`0`O````@O\!`!4```"R_P$`
M)0```,C_`0`\````[O\!`!\````K``(`(P```$L``@`?````;P`"`"````"/
M``(`&@```+```@`8````RP`"`!@```#D``(`)@```/T``@`>````)`$"`"D`
M``!#`0(`'@```&T!`@`Q````C`$"``H```"^`0(`$P```,D!`@`(````W0$"
M``D```#F`0(`%@```/`!`@`,````!P("`!<````4`@(`+P```"P"`@`X````
M7`("`#<```"5`@(`,0```,T"`@`D````_P("``<````D`P(`'P```"P#`@`/
M````3`,"`!0```!<`P(`#@```'$#`@`-````@`,"`"0```".`P(`!0```+,#
M`@`'````N0,"``P```#!`P(`.P```,X#`@`/````"@0"`!$````:!`(`(@``
M`"P$`@`E````3P0"`!H```!U!`(`'0```)`$`@`:````K@0"`!$```#)!`(`
M!P```-L$`@#'````XP0"``8```"K!0(`"P```+(%`@`:````O@4"`!4```#9
M!0(`!@```.\%`@`)````]@4"`!@`````!@(`"P```!D&`@`-````)08"`!<`
M```S!@(`!@```$L&`@`S````4@8"`!,```"&!@(`$P```)H&`@`'````K@8"
M``\```"V!@(`$0```,8&`@`>````V`8"``<```#W!@(`&0```/\&`@`R````
M&0<"``0```!,!P(`1@```%$'`@`A````F`<"`!,```"Z!P(`#````,X'`@`1
M````VP<"`#(```#M!P(`%@```"`(`@`(````-P@"`!T```!`"`(`"0```%X(
M`@`*````:`@"`!0```!S"`(`"@```(@(`@`=````DP@"``@```"Q"`(`'P``
M`+H(`@`(````V@@"`!H```#C"`(`)P```/X(`@`&````)@D"`!4````M"0(`
M!P```$,)`@`(````2PD"``D```!4"0(`/P```%X)`@`'````G@D"``\```"F
M"0(`#@```+8)`@`0````Q0D"``D```#6"0(`"0```.`)`@`(````Z@D"`!,`
M``#S"0(`!`````<*`@`'````#`H"`!(````4"@(`)@```"<*`@`-````3@H"
M`!D```!<"@(`&````'8*`@`+````CPH"``X```";"@(`&0```*H*`@`*````
MQ`H"`"0```#/"@(`(0```/0*`@`*````%@L"`!,````A"P(`)P```#4+`@`)
M````70L"``\```!G"P(`%P```'<+`@`4````CPL"`"@```"D"P(`#P```,T+
M`@`@````W0L"``T```#^"P(`%`````P,`@`-````(0P"`!0````O#`(`%```
M`$0,`@`*````60P"``P```!D#`(`%P```'$,`@`$````B0P"`"H```".#`(`
M#````+D,`@`1````Q@P"``<```#8#`(``@```.`,`@`0````XPP"`!@```#T
M#`(`"P````T-`@`#````&0T"``@````=#0(`!@```"8-`@`'````+0T"``T`
M```U#0(`"P```$,-`@`4````3PT"`!4```!D#0(`#@```'H-`@`O````B0T"
M`"````"Y#0(`'````-H-`@!7````]PT"`%H```!/#@(`/P```*H.`@`V````
MZ@X"`'X````A#P(`%0```*`/`@`,````M@\"`#$```###P(`"0```/4/`@`%
M````_P\"`!(````%$`(`/P```!@0`@`2````6!`"``H```!K$`(`!@```'80
M`@`$````?1`"``0```""$`(`"@```(<0`@`3````DA`"``4```"F$`(`!@``
M`*P0`@`&````LQ`"``@```"Z$`(`!````,,0`@`,````R!`"``H```#5$`(`
M.0```.`0`@`N````&A$"`"D```!)$0(`!0```',1`@`8````>1$"`!D```"2
M$0(`'P```*P1`@`=````S!$"`!$```#J$0(``@```/P1`@`$````_Q$"``H`
M```$$@(`!@````\2`@`%````%A("``,````<$@(`#````"`2`@`[````+1("
M`$\```!I$@(`-0```+D2`@`G````[Q("`"$````7$P(`)````#D3`@!%````
M7A,"`"8```"D$P(`,@```,L3`@`S````_A,"`!H````R%`(`'0```$T4`@!X
M````:Q0"`#0```#D%`(`(0```!D5`@!6````.Q4"`"@```"2%0(`4P```+L5
M`@`Z````#Q8"`$(```!*%@(`&0```(T6`@`7````IQ8"`"4```"_%@(`&0``
M`.46`@`J````_Q8"`"L````J%P(`<@```%87`@`@````R1<"`#4```#J%P(`
M(0```"`8`@!%````0A@"`"8```"(&`(`,````*\8`@!+````X!@"`$X````L
M&0(`)P```'L9`@`I````HQD"`"$```#-&0(`*````.\9`@`K````&!H"`!T`
M``!$&@(`*0```&(:`@`F````C!H"`"4```"S&@(`*````-D:`@`H`````AL"
M`"(````K&P(`.@```$X;`@`K````B1L"`"D```"U&P(`(@```-\;`@`]````
M`AP"`$$```!`'`(`*````((<`@`L````JQP"`#````#8'`(`$@````D=`@`3
M````'!T"`!`````P'0(`>0```$$=`@`)````NQT"`!P```#%'0(`$````.(=
M`@`/````\QT"`"L````#'@(`)P```"\>`@`.````5QX"`$L```!F'@(`H0``
M`+(>`@!S````5!\"`'P```#('P(`0````$4@`@`K````AB`"`%0```"R(`(`
M%P````<A`@`J````'R$"`#0```!*(0(`)P```'\A`@`6````IR$"``\```"^
M(0(`KP```,XA`@`7````?B("`"@```"6(@(`'P```+\B`@!`````WR("`!\`
M```@(P(`'````$`C`@!1````72,"`!H```"O(P(`%````,HC`@`/````WR,"
M``H```#O(P(`!0```/HC`@`&`````"0"``@````')`(`!0```!`D`@`0````
M%B0"`!(````G)`(`#````#HD`@`0````1R0"`!$```!8)`(`$P```&HD`@`=
M````?B0"`"````"<)`(`#P```+TD`@`/````S20"``0```#=)`(`"@```.(D
M`@`$````[20"``,```#R)`(`"0```/8D`@`'`````"4"``L````()0(`"```
M`!0E`@`'````'24"``4````E)0(`"0```"LE`@`4````-24"``8```!*)0(`
M!P```%$E`@`(````624"``\```!B)0(`#P```'(E`@`,````@B4"``@```"/
M)0(`#````)@E`@`&````I24"``D```"L)0(`"P```+8E`@`/````PB4"``8`
M``#2)0(`!P```-DE`@`-````X24"``8```#O)0(`%````/8E`@`'````"R8"
M``,````3)@(`"0```!<F`@`&````(28"``P````H)@(`"@```#4F`@`,````
M0"8"`!$```!-)@(`"@```%\F`@`/````:B8"``4```!Z)@(`"````(`F`@`$
M````B28"`!D```".)@(`$0```*@F`@`*````NB8"`!@```#%)@(`$P```-XF
M`@`<````\B8"`!$````/)P(`!````"$G`@`/````)B<"``<````V)P(`!```
M`#XG`@`$````0R<"`!D```!()P(`!P```&(G`@`"````:B<"``(```!M)P(`
M$0```'`G`@`)````@B<"``8```",)P(`$@```),G`@`7````IB<"``,```"^
M)P(`!@```,(G`@`,````R2<"`"<```#6)P(``@```/XG`@`$`````2@"``0`
M```&*`(`#P````LH`@`3````&R@"``<````O*`(``@```#<H`@`'````.B@"
M`!$```!"*`(`!@```%0H`@`+````6R@"`!@```!G*`(`!@```(`H`@`3````
MAR@"`!````";*`(`$@```*PH`@`.````OR@"``\```#.*`(``@```-XH`@`&
M````X2@"``P```#H*`(`"0```/4H`@`1````_R@"`"(````1*0(`!P```#0I
M`@`'````/"D"``L```!$*0(`!0```%`I`@`"````5BD"``L```!9*0(`#@``
M`&4I`@`.````="D"`%8!``"#*0(`#````-HJ`@`,````YRH"``P```#T*@(`
M#`````$K`@`/````#BL"`!,````>*P(`#@```#(K`@`(````02L"``D```!*
M*P(`"@```%0K`@`,````7RL"``4```!L*P(`!````'(K`@`:````=RL"`!\`
M``"2*P(`,@```+(K`@`P````Y2L"`"D````6+`(`*````$`L`@`>````:2P"
M``,```"(+`(`&0```(PL`@`S````IBP"``P```#:+`(`#@```.<L`@`G````
M]BP"`!\````>+0(`2P```#XM`@`L````BBT"`$8```"W+0(`)P```/XM`@`<
M````)BX"`!(```!#+@(`#````%8N`@`0````8RX"``4```!T+@(`(0```'HN
M`@`0````G"X"`!````"M+@(`%@```+XN`@`5````U2X"`#H```#K+@(`#```
M`"8O`@`L````,R\"`"X```!@+P(`$@```(\O`@`5````HB\"`!$```"X+P(`
M,0```,HO`@`M````_"\"`#(````J,`(`'````%TP`@"%````>C`"`!``````
M,0(`"@```!$Q`@`2````'#$"`"T````O,0(`)P```%TQ`@`0````A3$"`"D`
M``"6,0(`%@```,`Q`@`I````US$"`#@````!,@(`#@```#HR`@`,````23("
M``X```!6,@(`$0```&4R`@`&````=S("`!P```!^,@(`P0```)LR`@`V````
M73,"`$D```"4,P(`!@```-XS`@`0````Y3,"`(D```#V,P(`=0```(`T`@`K
M````]C0"`!X````B-0(`!P```$$U`@`+````234"`!H```!5-0(`#P```'`U
M`@`;````@#4"`$<```"<-0(`*0```.0U`@!"````#C8"`"0```!1-@(`"P``
M`'8V`@`,````@C8"`!$```"/-@(`$0```*$V`@`*````LS8"``L```"^-@(`
M"P```,HV`@`'````UC8"`"P```#>-@(`)`````LW`@!(````,#<"`%L```!Y
M-P(`50```-4W`@!A````*S@"`'D```"-.`(`>`````<Y`@!\````@#D"`'L`
M``#].0(`6````'DZ`@`1````TCH"`!D```#D.@(`$````/XZ`@`2````#SL"
M`!@````B.P(`!0```#L[`@`#````03L"``8```!%.P(`$@```$P[`@`'````
M7SL"``T```!G.P(`#0```'4[`@`U````@SL"`!,```"Y.P(`"@```,T[`@`,
M````V#L"`#<```#E.P(`+@```!T\`@`2````3#P"``T```!?/`(`$@```&T\
M`@`*````@#P"``L```"+/`(`"````)<\`@`*````H#P"`"(```"K/`(`&P``
M`,X\`@`;````ZCP"`!`````&/0(`%@```!<]`@`6````+CT"`!X```!%/0(`
M'@```&0]`@`E````@ST"`!$```"I/0(`&@```+L]`@`/````UCT"`!$```#F
M/0(`*@```/@]`@`=````(SX"`!H```!!/@(`'P```%P^`@`=````?#X"`!,`
M``":/@(`'````*X^`@!Z````RSX"`$(```!&/P(`+P```(D_`@"#````N3\"
M`#8````]0`(`'P```'1``@`>````E$`"`#L```"S0`(`&0```.]``@`V````
M"4$"``<```!`00(`"@```$A!`@`,````4T$"`&T```!@00(`<@```,Y!`@`P
M````04("``X```!R0@(`!P```(%"`@`+````B4("``@```"50@(`"````)Y"
M`@`)````IT("``L```"Q0@(`#````+U"`@`$````RD("`!0```#/0@(`#```
M`.1"`@`+````\4("`!````#]0@(`50````Y#`@!7````9$,"`$8```"\0P(`
M6P````-$`@!-````7T0"`!\```"M1`(`-0```,U$`@`9`````T4"`"8````=
M10(`$0```$1%`@`:````5D4"`!H```!Q10(`'@```(Q%`@`8````JT4"`!0`
M``#$10(`$@```-E%`@`=````[$4"``4````*1@(`%P```!!&`@`2````*$8"
M`%(````[1@(`)P```(Y&`@`G````MD8"`$0```#>1@(`1@```"-'`@`'````
M:D<"``8```!R1P(`"````'E'`@`.````@D<"``<```"11P(`"P```)E'`@`8
M````I4<"``D```"^1P(`$P```,A'`@`)````W$<"``\```#F1P(`%0```/9'
M`@`5````#$@"`!P````B2`(`)````#](`@`W````9$@"`!@```"<2`(`"@``
M`+5(`@`/````P$@"``4```#02`(`%P```-9(`@`+````[D@"``H```#Z2`(`
M60````5)`@!(````7TD"`$X```"H20(`+0```/=)`@!+````)4H"`$8```!Q
M2@(`0@```+A*`@!%````^TH"`#<```!!2P(`.0```'E+`@`X````LTL"`$8`
M``#L2P(`1P```#-,`@!"````>TP"``L```"^3`(`"````,I,`@`5````TTP"
M``P```#I3`(`!0```/9,`@`%````_$P"``L````"30(`$`````Y-`@`+````
M'TT"`!<````K30(`"@```$--`@`N````3DT"`!````!]30(`$````(Y-`@!(
M````GTT"`!$```#H30(`80```/I-`@!0````7$X"``8```"M3@(`&0```+1.
M`@`4````SDX"`"8```#C3@(`!P````I/`@`]````$D\"`#P```!03P(`/P``
M`(U/`@`_````S4\"``H````-4`(`!P```!A0`@`)````(%`"``8````J4`(`
M"@```#%0`@`*````/%`"`$$```!'4`(`/0```(E0`@!`````QU`"`'$````(
M40(`/P```'I1`@`^````NE$"`$,```#Y40(`4P```#U2`@!0````D5("`#\`
M``#B4@(`40```")3`@`S````=%,"`#<```"H4P(`5P```.!3`@`_````.%0"
M`$,```!X5`(`*@```+Q4`@`@````YU0"`!P````(50(`/0```"55`@`I````
M8U4"`"D```"-50(`7P```+=5`@`8````%U8"`!(````P5@(`$P```$-6`@`-
M````5U8"``T```!E5@(`#0```'-6`@`,````@58"`!L```".5@(`%@```*I6
M`@`+````P58"`!````#-5@(`&P```-Y6`@`?````^E8"`"0````:5P(`-0``
M`#]7`@`6````=5<"``<```",5P(`!P```)17`@`6````G%<"``L```"S5P(`
M"````+]7`@`M````R%<"``H```#V5P(``P````%8`@`*````!5@"``<````0
M6`(`!@```!A8`@!*````'U@"``4```!J6`(`"````'!8`@`&````>5@"``H`
M``"`6`(`#P```(M8`@`M````FU@"`!(```#)6`(`"````-Q8`@!/````Y5@"
M``0````U60(`!````#I9`@`(````/UD"``L```!(60(`!````%19`@`,````
M65D"``8```!F60(`$P```&U9`@`&````@5D"`"D```"(60(`"````+)9`@`%
M````NUD"``L```#!60(`"0```,U9`@`I````UUD"`!$````!6@(`"0```!-:
M`@`3````'5H"``P````Q6@(`!P```#Y:`@`#````1EH"`$<```!*6@(``P``
M`)):`@`7````EEH"`!<```"N6@(`#````,9:`@`W````TUH"``@````+6P(`
M"0```!1;`@`*````'EL"``<````I6P(`.@```#%;`@`[````;%L"`%\```"H
M6P(`8P````A<`@`L````;%P"`#H```"97`(`/````-1<`@`J````$5T"``8`
M```\70(`"0```$-=`@`3````35T"`!@```!A70(`1@```'I=`@`L````P5T"
M`"4```#N70(`-@```!1>`@`R````2UX"`#,```!^7@(`D0```+)>`@!(````
M1%\"``D```"-7P(`"P```)=?`@`(````HU\"`!T```"L7P(`#0```,I?`@`"
M````V%\"``P```#;7P(`$P```.A?`@`-````_%\"`!,````*8`(`#@```!Y@
M`@`,````+6`"`!8````Z8`(`"0```%%@`@`<````6V`"`!T```!X8`(`$0``
M`)9@`@`2````J&`"`!4```"[8`(`;0```-%@`@`&````/V$"`!(```!&80(`
M!@```%EA`@`+````8&$"``\```!L80(`%P```'QA`@"6````E&$"`$4````K
M8@(`A````'%B`@"2````]F("`'L```")8P(`!P````5D`@`5````#60"`!,`
M```C9`(`)@```#=D`@`5````7F0"`$L```!T9`(`/0```,!D`@`%````_F0"
M``4````$90(`'P````IE`@`>````*F4"`!$```!)90(`%````%ME`@`>````
M<&4"`"\```"/90(`%P```+]E`@`>````UV4"`#0```#V90(`+P```"MF`@!.
M````6V8"`%D```"J9@(`#P````1G`@`H````%&<"``8````]9P(`&````$1G
M`@`4````76<"`!D```!R9P(`%0```(QG`@`5````HF<"`!$```"X9P(`6P``
M`,IG`@`L````)F@"`#````!3:`(`10```(1H`@`Z````RF@"`$`````%:0(`
M7@```$9I`@`B````I6D"`'````#(:0(`"@```#EJ`@!0````1&H"`$X```"5
M:@(`$P```.1J`@!8````^&H"`#0```!1:P(`"0```(9K`@`1````D&L"`!@`
M``"B:P(`%````+MK`@`&````T&L"``L```#7:P(`!P```.-K`@`+````ZVL"
M``D```#W:P(`#P````%L`@`5````$6P"`!`````G;`(`#@```#AL`@`7````
M1VP"``D```!?;`(`!0```&EL`@`0````;VP"``L```"`;`(`"````(QL`@`(
M````E6P"`!0```">;`(`!@```+-L`@`&````NFP"``P```#!;`(`"0```,YL
M`@`0````V&P"``<```#I;`(`!0```/%L`@`(````]VP"`!L`````;0(`,```
M`!QM`@!D````36T"``@```"R;0(`"P```+MM`@`+````QVT"`!H```#3;0(`
M1````.YM`@`K````,VX"`!````!?;@(`,0```'!N`@`Y````HFX"`!,```#<
M;@(`!0```/!N`@`<````]FX"`"@````3;P(`&@```#QO`@`;````5V\"`#T`
M``!S;P(`3````+%O`@`H````_F\"`"0````G<`(`"````$QP`@`]````57`"
M`"0```"3<`(`#P```+AP`@`&````R'`"`"<```#/<`(`*@```/=P`@`?````
M(G$"`($```!"<0(`)@```,1Q`@`+````ZW$"``8```#W<0(`"````/YQ`@`;
M````!W("`!`````C<@(`#0```#1R`@`*````0G("`!$```!-<@(`"0```%]R
M`@`*````:7("``X```!T<@(`.0```(-R`@`Y````O7("`#L```#W<@(`.P``
M`#-S`@`K````;W,"`"H```";<P(`+````,9S`@!`````\W,"`"H````T=`(`
M0@```%]T`@`O````HG0"`#(```#2=`(`+@````5U`@`P````-'4"`"@```!E
M=0(`+P```(YU`@`T````OG4"`#P```#S=0(`/@```#!V`@`W````;W8"`$D`
M``"G=@(`10```/%V`@`T````-W<"`#$```!L=P(`.0```)YW`@`O````V'<"
M`#(````(>`(`1@```#MX`@`P````@G@"`!\```"S>`(`.@```--X`@`N````
M#GD"`$H````]>0(`.P```(AY`@`?````Q'D"`-P```#D>0(`'P```,%Z`@`N
M````X7H"`#$````0>P(`,@```$)[`@!,````=7L"`#4```#">P(`,````/A[
M`@`N````*7P"`#$```!8?`(`.0```(I\`@`\````Q'P"`$0````!?0(`/```
M`$9]`@#%````@WT"`"\```!)?@(`(@```'E^`@`O````G'X"`#,```#,?@(`
M/@````!_`@!D````/W\"`%T```"D?P(`#@````*``@`$````$8`"``4````6
M@`(`"0```!R``@`0````)H`"`!,````W@`(`%P```$N``@`.````8X`"`!\`
M``!R@`(`)P```)*``@`6````NH`"`#0```#1@`(`+0````:!`@!W````-($"
M`!0```"L@0(`,P```,&!`@`5````]8$"``\````+@@(`$@```!N"`@`(````
M+H("``0````W@@(`$0```#R"`@`1````3H("``T```!@@@(`$````&Z"`@`1
M````?X("`!````"1@@(`%@```**"`@`8````N8("``X```#2@@(`1P```.&"
M`@`Q````*8,"`%$```!;@P(`#````*V#`@`4````NH,"``8```#/@P(`$P``
M`-:#`@`9````ZH,"`!X````$A`(`%0```".$`@`"````.80"`$L````\A`(`
M!P```(B$`@`&````D(0"`!````"7A`(`$````*B$`@`%````N80"``T```"_
MA`(`#0```,V$`@`#````VX0"``\```#?A`(`"````.^$`@`&````^(0"``D`
M``#_A`(`"P````F%`@`1````%84"``@````GA0(`#0```#"%`@`1````/H4"
M`!````!0A0(`#0```&&%`@`3````;X4"`!````"#A0(`#````)2%`@`)````
MH84"``<```"KA0(`(0```+.%`@`-````U84"`!L```#CA0(`#@```/^%`@`.
M````#H8"``L````=A@(`#@```"F&`@`:````.(8"``\```!3A@(`&0```&.&
M`@`<````?88"`"$```":A@(`#0```+R&`@`.````RH8"`"8```#9A@(`,```
M``"'`@`=````,8<"`!,```!/AP(`+P```&.'`@`^````DX<"`!<```#2AP(`
M+0```.J'`@`-````&(@"`!T````FB`(`&````$2(`@`3````78@"`!L```!Q
MB`(`&@```(V(`@`(````J(@"`!4```"QB`(`+@```,>(`@`?````]H@"`",`
M```6B0(`$0```#J)`@`(````3(D"`!````!5B0(`+P```&:)`@`*````EHD"
M`!L```"AB0(`#````+V)`@`'````RHD"`"(```#2B0(`,````/6)`@`+````
M)HH"``@````RB@(`'0```#N*`@`*````68H"`#0```!DB@(`%0```)F*`@`5
M````KXH"`!4```#%B@(`"P```-N*`@`'````YXH"`",```#OB@(`%0```!.+
M`@`X````*8L"`!\```!BBP(`&0```(*+`@`-````G(L"`!X```"JBP(`,P``
M`,F+`@`Q````_8L"`#8````OC`(`"@```&:,`@`3````<8P"``D```"%C`(`
M#P```(^,`@`L````GXP"``T```#,C`(`+P```-J,`@`H````"HT"`"$````S
MC0(`40```%6-`@`(````IXT"`!<```"PC0(`(@```,B-`@`&````ZXT"``T`
M``#RC0(`$`````".`@`>````$8X"`"H````PC@(`%````%N.`@`D````<(X"
M`#0```"5C@(`&P```,J.`@`'````YHX"``\```#NC@(`$````/Z.`@`,````
M#X\"``8````<CP(`!0```"./`@`,````*8\"`$L````VCP(`!````(*/`@`&
M````AX\"`#8```".CP(`!P```,6/`@`*````S8\"`!H```#8CP(`$````/./
M`@`1````!)`"`!$````6D`(`$0```"B0`@`1````.I`"`!H```!,D`(`%@``
M`&>0`@`<````?I`"`!\```";D`(`%P```+N0`@`=````TY`"`!H```#QD`(`
M&`````R1`@`:````)9$"`!<```!`D0(`.P```%B1`@`7````E)$"``<```"L
MD0(`!P```+21`@`+````O)$"``H```#(D0(``@```-.1`@`%````UI$"``P`
M``#<D0(`)0```.F1`@`5````#Y("`!8````ED@(`!P```#R2`@`A````1)("
M`#@```!FD@(`#0```)^2`@`9````K9("`!$```#'D@(`#````-F2`@`2````
MYI("`!````#YD@(`$`````J3`@`4````&Y,"`!H````PDP(`'0```$N3`@`[
M````:9,"`!\```"EDP(`)P```,63`@`?````[9,"``T````-E`(`!````!N4
M`@`C````()0"`!(```!$E`(`&0```%>4`@`'````<90"`!$```!YE`(`$0``
M`(N4`@"7````G90"`!D````UE0(`(P```$^5`@`U````<Y4"`#D```"IE0(`
M90```..5`@`]````298"`!$```"'E@(`/0```)F6`@`1````UY8"``<```#I
ME@(`!@```/&6`@!"````^)8"`"8````[EP(`,@```&*7`@`P````E9<"`"0`
M``#&EP(`)0```.N7`@`D````$9@"`!T````VF`(`'P```%28`@`'````=)@"
M``D```!\F`(`"0```(:8`@`&````D)@"`!P```"7F`(`#P```+28`@`.````
MQ)@"`!````#3F`(`#@```.28`@`3````\Y@"`!$````'F0(`$````!F9`@`.
M````*ID"``D````YF0(`"@```$.9`@`,````3ID"`!(```!;F0(`#0```&Z9
M`@`,````?)D"``X```")F0(`4P```)B9`@`H````[)D"``4````5F@(`#```
M`!N:`@`]````*)H"``T```!FF@(`"````'2:`@`0````?9H"`",```".F@(`
M$P```+*:`@`S````QIH"`"<```#ZF@(`)@```"*;`@`O````29L"`"D```!Y
MFP(`-@```*.;`@`L````VIL"`!4````'G`(`!@```!V<`@`.````))P"``8`
M```SG`(`$````#J<`@`#````2YP"``0```!/G`(`!P```%2<`@`3````7)P"
M`!4```!PG`(`$P```(:<`@`N````FIP"`"4```#)G`(`(P```.^<`@`@````
M$YT"`!4````TG0(`-@```$J=`@`3````@9T"`!D```"5G0(`!P```*^=`@`*
M````MYT"``X```#"G0(`"P```-&=`@`'````W9T"``4```#EG0(`$````.N=
M`@`2````_)T"``P````/G@(`"0```!R>`@`,````)IX"``\````SG@(`,0``
M`$.>`@`4````=9X"`!0```"*G@(`,````)^>`@`]````T)X"``8````.GP(`
M&P```!6?`@`5````,9\"``4```!'GP(`"````$V?`@`,````5I\"`!$```!C
MGP(`"P```'6?`@`.````@9\"`!<```"0GP(`"````*B?`@`(````L9\"``T`
M``"ZGP(`!0```,B?`@`B````SI\"`!P```#QGP(`$0````Z@`@`/````(*`"
M`#4````PH`(`+@```&:@`@`,````E:`"``4```"BH`(`*@```*B@`@`0````
MTZ`"`'$```#DH`(`$P```%:A`@`[````:J$"``D```"FH0(`"@```+"A`@`-
M````NZ$"``L```#)H0(`#0```-6A`@`%````XZ$"``P```#IH0(`#0```/:A
M`@`9````!*("`"`````>H@(`#0```#^B`@`"````3:("``8```!0H@(`"@``
M`%>B`@`7````8J("`"````!ZH@(`$P```)NB`@`6````KZ("`#$```#&H@(`
M!````/BB`@`#````_:("``L````!HP(`!`````VC`@`9````$J,"``@````L
MHP(`$@```#6C`@`$````2*,"``0```!-HP(`(@```%*C`@`%````=:,"`!D`
M``![HP(`"````)6C`@`&````GJ,"`!@```"EHP(`&0```+ZC`@`.````V*,"
M``@```#GHP(`"P```/"C`@`H````_*,"``4````EI`(`"0```"ND`@`'````
M-:0"`!@````]I`(``P```%:D`@`3````6J0"`!X```!NI`(`!@```(VD`@`+
M````E*0"``P```"@I`(`$````*VD`@`*````OJ0"``P```#)I`(`%P```-:D
M`@`(````[J0"``<```#WI`(`$0```/^D`@`C````$:4"`%`````UI0(`-@``
M`(:E`@`Z````O:4"``<```#XI0(`"@````"F`@`$````"Z8"``D````0I@(`
M"````!JF`@`*````(Z8"``D````NI@(`!@```#BF`@`-````/Z8"``8```!-
MI@(`!````%2F`@`$````6:8"`!H```!>I@(`.P```'FF`@`^````M:8"`#T`
M``#TI@(`)@```#*G`@`%````6:<"`!````!?IP(`!@```'"G`@`+````=Z<"
M``P```"#IP(`&0```)"G`@`0````JJ<"`!@```"[IP(`!````-2G`@`%````
MV:<"``L```#?IP(`!0```.NG`@`*````\:<"`!X```#\IP(`/P```!NH`@`)
M````6Z@"`!X```!EJ`(`$P```(2H`@`@````F*@"``0```"YJ`(`#@```+ZH
M`@`'````S:@"``L```#5J`(`#````.&H`@`*````[J@"``X```#YJ`(`#P``
M``BI`@`.````&*D"``@````GJ0(`"0```#"I`@`%````.JD"`#,```!`J0(`
M,P```'2I`@`\````J*D"`"\```#EJ0(`3@```!6J`@!(````9*H"`#4```"M
MJ@(`5@```..J`@`[````.JL"`$P```!VJP(`,````,.K`@`1````]*L"`!D`
M```&K`(`"P```""L`@!#````+*P"`"0```!PK`(`+P```)6L`@`B````Q:P"
M`"X```#HK`(`*@```!>M`@`0````0JT"`!(```!3K0(`!P```&:M`@`&````
M;JT"``0```!UK0(`)@```'JM`@!"````H:T"`#$```#DK0(`,0```!:N`@`X
M````2*X"``T```"!K@(`)@```(^N`@`;````MJX"`#````#2K@(`#0````.O
M`@`5````$:\"``H````GKP(`&P```#*O`@`I````3J\"`!\```!XKP(`$P``
M`)BO`@`&````K*\"``H```"SKP(`#````+ZO`@`/````RZ\"`!D```#;KP(`
M7P```/6O`@!6````5;`"`%H```"LL`(`?0````>Q`@!Z````A;$"``H`````
ML@(`#P````NR`@`$````&[("``T````@L@(`"````"ZR`@`)````-[("`!``
M``!!L@(`$0```%*R`@`.````9+("``8```!SL@(`"P```'JR`@`5````AK("
M`!D```"<L@(`%P```+:R`@`9````SK("`",```#HL@(`+P````RS`@`S````
M/+,"`"H```!PLP(`(@```)NS`@`F````OK,"`"D```#ELP(`'`````^T`@`7
M````++0"`"L```!$M`(`%P```'"T`@`'````B+0"`!0```"0M`(`(0```*6T
M`@`5````Q[0"`!,```#=M`(`#@```/&T`@`4`````+4"``L````5M0(`*```
M`"&U`@`J````2K4"`!L```!UM0(`*@```)&U`@"5````O+4"`!$```!2M@(`
M!@```&2V`@`1````:[8"``H```!]M@(`"P```(BV`@`-````E+8"`",```"B
MM@(`+````,:V`@`V````\[8"`#H````JMP(`!P```&6W`@`6````;;<"`!@`
M``"$MP(`#P```)VW`@`Q````K;<"`#4```#?MP(`*````!6X`@`0````/K@"
M``T```!/N`(`%P```%VX`@`L````=;@"`"L```"BN`(`*P```,ZX`@`J````
M^K@"`#8````EN0(`-0```%RY`@`<````DKD"`$\```"ON0(`%0```/^Y`@`4
M````%;H"`!8````JN@(`%0```$&Z`@`6````5[H"`!8```!NN@(`%0```(6Z
M`@`5````F[H"`!0```"QN@(`,P```,:Z`@`8````^KH"`!@````3NP(`.P``
M`"R[`@`2````:+L"``@```![NP(`%````(2[`@`Q````F;L"`!$```#+NP(`
M$P```-V[`@`C````\;L"`!0````5O`(`%````"J\`@`3````/[P"`"L```!3
MO`(`&0```'^\`@`6````F;P"`!8```"PO`(`%````,>\`@`;````W+P"`!D`
M``#XO`(`%````!*]`@`?````)[T"`"(```!'O0(`%0```&J]`@`5````@+T"
M`"\```"6O0(`,P```,:]`@`7````^KT"`!4````2O@(`&@```"B^`@`=````
M0[X"`!L```!AO@(`&````'V^`@`(````EKX"``@```"?O@(`$````*B^`@`8
M````N;X"``0```#2O@(`!@```->^`@`+````WKX"`!0```#JO@(`!@```/^^
M`@`*````!K\"``8````1OP(`!P```!B_`@`'````(+\"``8````HOP(`!0``
M`"^_`@`7````-;\"``8```!-OP(`"0```%2_`@`$````7K\"``0```!COP(`
M"0```&B_`@`*````<K\"``D```!]OP(`$````(>_`@`1````F+\"``(```"J
MOP(`"@```*V_`@`5````N+\"``4```#.OP(`-0```-2_`@`/````"L`"`!(`
M```:P`(`'````"W``@`.````2L`"``P```!9P`(`#@```&;``@!)````=<`"
M`%,```"_P`(`:P```!/!`@"*````?\$"`$L````*P@(`!@```%;"`@`(````
M7<("`"$```!FP@(`#@```(C"`@`3````E\("``8```"KP@(`"P```++"`@`)
M````OL("``<```#(P@(`!````-#"`@`-````U<("`!(```#CP@(`#````/;"
M`@`7`````\,"``\````;PP(`%@```"O#`@`4````0L,"`!L```!7PP(`&@``
M`'/#`@`(````CL,"``8```"7PP(`!@```)[#`@`=````I<,"``<```##PP(`
M!0```,O#`@`1````T<,"``L```#CPP(`!P```._#`@`%````]\,"``<```#]
MPP(`!@````7$`@`-````#,0"``H````:Q`(`#@```"7$`@`3````-,0"`!4`
M``!(Q`(`%````%[$`@`;````<\0"`!,```"/Q`(`%0```*/$`@`(````N<0"
M``0```#"Q`(`$@```,?$`@`2````VL0"`!<```#MQ`(`(P````7%`@`%````
M*<4"`"`````OQ0(`$0```%#%`@`E````8L4"`!0```"(Q0(`%@```)W%`@`1
M````M,4"`(\```#&Q0(`#0```%;&`@`,````9,8"``D```!QQ@(`#P```'O&
M`@`.````B\8"`!````":Q@(`$````*O&`@`<````O,8"`#````#9Q@(`,```
M``K'`@`L````.\<"``D```!HQP(`!P```'+'`@`'````>L<"``\```""QP(`
M$````)+'`@`0````H\<"``,```"TQP(`"````+C'`@`/````P<<"`"````#1
MQP(`"````/+'`@`(````^\<"``\````$R`(`:0```!3(`@`9````?L@"``L`
M``"8R`(`!0```*3(`@`'````JL@"`!(```"RR`(`&@```,7(`@`:````X,@"
M`!,```#[R`(`"@````_)`@`)````&LD"``(````DR0(`!````"?)`@`D````
M+,D"``<```!1R0(`!0```%G)`@`O````7\D"``\```"/R0(`"@```)_)`@`%
M````JLD"``<```"PR0(`%````+C)`@`3````S<D"`!\```#AR0(`!@````'*
M`@`Y````",H"`!````!"R@(`!@```%/*`@`(````6LH"``D```!CR@(`!```
M`&W*`@`%````<LH"`'0```!XR@(`"P```.W*`@`.````^<H"`!@````(RP(`
M!````"'+`@`,````)LL"`#`````SRP(`,@```&3+`@`.````E\L"`$@```"F
MRP(`+0```._+`@`B````'<P"`"8```!`S`(`-0```&?,`@`.````G<P"``H`
M``"LS`(`#P```+?,`@`/````Q\P"`!(```#7S`(`"P```.K,`@`)````]LP"
M`!D`````S0(`*````!K-`@`I````0\T"`"@```!MS0(`%````);-`@`:````
MJ\T"`"````#&S0(`#@```.?-`@`E````]LT"`"H````<S@(``P```$?.`@`.
M````2\X"``<```!:S@(`"@```&+.`@`0````;<X"``H```!^S@(`%````(G.
M`@`)````GLX"``X```"HS@(`$0```+?.`@`9````R<X"`!$```#CS@(`$0``
M`/7.`@`*````!\\"`%H````2SP(`$@```&W/`@`<````@,\"`!$```"=SP(`
M$0```*_/`@`0````P<\"`!8```#2SP(`&````.G/`@`9`````M`"`!0````<
MT`(`)P```#'0`@!#````6=`"`"8```"=T`(`#@```,30`@`5````T]`"`!``
M``#IT`(`#````/K0`@`;````!]$"`$P````CT0(`'0```'#1`@`'````CM$"
M`"0```"6T0(`,````+O1`@`(````[-$"``8```#UT0(`(@```/S1`@`%````
M']("``<````ET@(`*0```"W2`@`H````5]("`#0```"`T@(`"````+72`@`-
M````OM("`!X```#,T@(`8@```.O2`@`8````3M,"`!8```!GTP(`%0```'[3
M`@`"````E-,"``L```"7TP(`!0```*/3`@`.````J=,"``8```"XTP(`#@``
M`+_3`@`'````SM,"``\```#6TP(`!@```.;3`@`(````[=,"``X```#VTP(`
M"0````74`@`*````#]0"``H````:U`(`-P```"74`@`Z````7=0"``<```"8
MU`(`$@```*#4`@`3````L]0"`!X```#'U`(`$@```.;4`@`+````^=0"``H`
M```%U0(`"@```!#5`@`+````&]4"``D````GU0(`"@```#'5`@!=````/-4"
M`!````":U0(`"0```*O5`@`(````M=4"`!\```"^U0(`$0```-[5`@`5````
M\-4"`!\````&U@(`#P```";6`@`*````-M8"``H```!!U@(`"P```$S6`@`1
M````6-8"``4```!JU@(`&0```'#6`@`$````BM8"``<```"/U@(`!````)?6
M`@`Y````G-8"``<```#6U@(`!0```-[6`@`/````Y-8"``4```#TU@(`"P``
M`/K6`@`8````!M<"`!(````?UP(`&0```#+7`@`;````3-<"`"(```!HUP(`
M%@```(O7`@`7````HM<"`!(```"ZUP(`%@```,W7`@`(````Y-<"``,```#M
MUP(`%0```/'7`@`#````!]@"``T````+V`(`#@```!G8`@`,````*-@"`!(`
M```UV`(`#@```$C8`@`4````5]@"``<```!LV`(`'0```'38`@`*````DM@"
M`!````"=V`(`#@```*[8`@`F````O=@"`"L```#DV`(`%@```!#9`@`+````
M)]D"``L````SV0(`!@```#_9`@`0````1MD"`!$```!7V0(`"0```&G9`@`5
M````<]D"``<```")V0(`"0```)'9`@`%````F]D"``<```"AV0(`!@```*G9
M`@`$````L-D"``0```"UV0(`&````+K9`@`5````T]D"`"````#IV0(`$0``
M``K:`@`T````'-H"`"8```!1V@(`$0```'C:`@`E````BMH"`#<```"PV@(`
M%P```.C:`@!``````-L"`#H```!!VP(`%````'S;`@`S````D=L"`#L```#%
MVP(`$0````'<`@!,````$]P"`#H```!@W`(`2P```)O<`@!+````Y]P"`%$`
M```SW0(`%P```(7=`@`9````G=T"`#8```"WW0(`%P```.[=`@`7````!MX"
M`#8````>W@(`%0```%7>`@`B````:]X"`"@```".W@(`%0```+?>`@`=````
MS=X"`!,```#KW@(`%````/_>`@`9````%-\"`!H````NWP(`+P```$G?`@`4
M````>=\"`!<```".WP(`'````*;?`@`W````P]\"`#<```#[WP(`.P```#/@
M`@`X````;^`"`#D```"HX`(`-@```.+@`@!U````&>$"`",```"/X0(`/0``
M`+/A`@!!````\>$"`#<````SX@(`9````&OB`@`I````T.("``P```#ZX@(`
M'`````?C`@`,````).,"`#`````QXP(`$P```&+C`@`4````=N,"`!````"+
MXP(`2````)SC`@`T````Y>,"`!@````:Y`(`+````#/D`@`P````8.0"``L`
M``"1Y`(`7````)WD`@!6````^N0"``\```!1Y0(`!0```&'E`@`9````9^4"
M`!8```"!Y0(`#````)CE`@`&````I>4"`!0```"LY0(`$@```,'E`@`(````
MU.4"``H```#=Y0(`"0```.CE`@`.````\N4"``P````!Y@(`#0````[F`@`0
M````'.8"`!`````MY@(`)0```#[F`@`;````9.8"`!0```"`Y@(`&@```)7F
M`@`0````L.8"`!(```#!Y@(`.0```-3F`@`'````#N<"``8````6YP(`)0``
M`!WG`@`J````0^<"``@```!NYP(`!````'?G`@`2````?.<"`!(```"/YP(`
M<@```*+G`@!A````%>@"`!$```!WZ`(`+P```(GH`@`"````N>@"``0```"\
MZ`(`!@```,'H`@`/````R.@"``D```#8Z`(`!P```.+H`@`<````ZN@"``0`
M```'Z0(`.P````SI`@`0````2.D"``X```!9Z0(`&````&CI`@`V````@>D"
M``0```"XZ0(`+P```+WI`@`[````[>D"`!D````IZ@(`'P```$/J`@`U````
M8^H"`%X```"9Z@(`$````/CJ`@`7````">L"`$<````AZP(`$0```&GK`@`I
M````>^L"``T```"EZP(`%0```+/K`@`-````R>L"`!0```#7ZP(`$0```.SK
M`@`,````_NL"`!8````+[`(`#````"+L`@`=````+^P"`!8```!-[`(`"```
M`&3L`@`4````;>P"`!(```""[`(`%@```)7L`@`3````K.P"``X```#`[`(`
M*@```,_L`@`2````^NP"``,````-[0(`&0```!'M`@`3````*^T"`!@````_
M[0(`#````%CM`@!/````9>T"`!$```"U[0(`$P```,?M`@!>````V^T"`!H`
M```Z[@(`)````%7N`@!*````>NX"`$(```#%[@(`'@````CO`@`3````)^\"
M`"4````[[P(`*P```&'O`@`X````C>\"`#P```#&[P(`.@````/P`@!N````
M/O`"`&8```"M\`(`]P```!3Q`@`(````#/("``D````5\@(`&0```!_R`@`1
M````.?("`!,```!+\@(`$@```%_R`@`9````<O("`!$```",\@(`%````)[R
M`@`$````L_("`"8```"X\@(`#0```-_R`@`F````[?("`!L````4\P(`#0``
M`##S`@`;````/O,"``H```!:\P(`#````&7S`@`/````<O,"`"H```""\P(`
M*P```*WS`@`(````V?,"``4```#B\P(`(0```.CS`@`&````"O0"``\````1
M]`(`"````"'T`@`'````*O0"`!$````R]`(`"````$3T`@`6````3?0"`"X`
M``!D]`(`"0```)/T`@`A````G?0"`"0```"_]`(`"````.3T`@`>````[?0"
M`!$````,]0(`.0```![U`@`8````6/4"``D```!Q]0(`"@```'OU`@`B````
MAO4"``@```"I]0(`'P```++U`@`$````TO4"`!P```#7]0(`"````/3U`@`'
M````_?4"`!P````%]@(`,````"+V`@`&````4_8"`"````!:]@(`$@```'OV
M`@`&````CO8"`!````"5]@(`/````*;V`@`*````X_8"`!,```#N]@(`/```
M``+W`@`[````/_<"`#P```![]P(`/@```+CW`@`$````]_<"``D```#\]P(`
M"P````;X`@`'````$O@"``4````:^`(`"````"#X`@`%````*?@"`$`````O
M^`(`&0```'#X`@`+````BO@"`.H```"6^`(`'P```('Y`@`^````H?D"`$P`
M``#@^0(`)P```"WZ`@`V````5?H"`#0```",^@(`)P```,'Z`@!5````Z?H"
M`"<````_^P(`,@```&?[`@`?````FOL"`'\```"Z^P(`@@```#K\`@!A`0``
MO?P"`#<````?_@(`(````%?^`@`W````>/X"`"<```"P_@(`BP```-C^`@`V
M````9/\"`$$```";_P(`-````-W_`@`R````$@`#`"\```!%``,`*````'4`
M`P`%````G@`#``<```"D``,`"````*P``P`(````M0`#`!L```"^``,`'0``
M`-H``P`J````^``#`!`````C`0,`*@```#0!`P`J````7P$#`"8```"*`0,`
M,0```+$!`P!`````XP$#`$8````D`@,`"0```&L"`P`7````=0(#``L```"-
M`@,`"````)D"`P`X````H@(#`!,```#;`@,`#````.\"`P`6````_`(#``<`
M```3`P,`$````!L#`P`)````+`,#`!(````V`P,`'P```$D#`P`(````:0,#
M`!,```!R`P,`"````(8#`P`G````CP,#`"4```"W`P,`#0```-T#`P`*````
MZP,#`!8```#V`P,`)P````T$`P`H````-00#`$T```!>!`,`0P```*P$`P`+
M````\`0#`!$```#\!`,`$0````X%`P`0````(`4#`"L````Q!0,`'0```%T%
M`P!!````>P4#`#$```"]!0,`)@```.\%`P`C````%@8#``4````Z!@,`!P``
M`$`&`P`8````2`8#`#(```!A!@,`,P```)0&`P`J````R`8#``T```#S!@,`
M(P````$'`P`,````)0<#``4````R!P,`"@```#@'`P`,````0P<#``P```!0
M!P,`"P```%T'`P`:````:0<#``H```"$!P,`"@```(\'`P`%````F@<#`!$`
M``"@!P,`20```+('`P!=````_`<#`!<```!:"`,`#````'((`P`.````?P@#
M``T```"."`,`"0```)P(`P`(````I@@#`!(```"O"`,`&````,((`P`9````
MVP@#`!X```#U"`,`#````!0)`P`F````(0D#`!X```!("0,`'````&<)`P`2
M````A`D#`!,```"7"0,`#0```*L)`P`6````N0D#``L```#0"0,`(@```-P)
M`P`9````_PD#``X````9"@,`$````"@*`P`M````.0H#``D```!G"@,`#0``
M`'$*`P`<````?PH#``X```"<"@,`%@```*L*`P`,````P@H#`#X```#/"@,`
M$`````X+`P`(````'PL#`"D````H"P,`$````%(+`P`4````8PL#`!$```!X
M"P,`/````(H+`P!0````QPL#`!`````8#`,`#P```"D,`P`)````.0P#`!(`
M``!##`,`#P```%8,`P`0````9@P#``\```!W#`,`$````(<,`P`0````F`P#
M`"P```"I#`,`1@```-8,`P`S````'0T#``H```!1#0,`#````%P-`P`*````
M:0T#`!0```!T#0,`$````(D-`P`:````F@T#`$4```"U#0,`'````/L-`P`D
M````&`X#`#,````]#@,`-P```'$.`P`T````J0X#`#````#>#@,`$`````\/
M`P`9````(`\#``P````Z#P,`%0```$</`P`>````70\#`"4```!\#P,`%P``
M`*(/`P`*````N@\#``L```#%#P,`'0```-$/`P`:````[P\#`!\````*$`,`
M%P```"H0`P!4````0A`#`!X```"7$`,`!P```+80`P`:````OA`#`!P```#9
M$`,`!@```/80`P`&````_1`#`!(````$$0,`#````!<1`P`7````)!$#``4`
M```\$0,`"````$(1`P`.````2Q$#`!$```!:$0,`$@```&P1`P`3````?Q$#
M`!,```"3$0,`!P```*<1`P`&````KQ$#`"@```"V$0,`&P```-\1`P`:````
M^Q$#``<````6$@,`%0```!X2`P`&````-!(#``8````[$@,`(P```$(2`P`6
M````9A(#`",```!]$@,`#P```*$2`P!2````L1(#`!0````$$P,`%@```!D3
M`P!>````,!,#`$4```"/$P,`/P```-43`P`A````%10#`$0````W%`,`%@``
M`'P4`P`H````DQ0#`#T```"\%`,`:0```/H4`P"$````9!4#`'$```#I%0,`
M_0```%L6`P`K````61<#``L```"%%P,`!````)$7`P`)````EA<#`",```"@
M%P,``P```,07`P`&````R!<#``H```#/%P,`"````-H7`P`"````XQ<#`!0`
M``#F%P,`#P```/L7`P`,````"Q@#`!4````8&`,`"P```"X8`P`9````.A@#
M`"````!4&`,`%P```'48`P`%````C1@#``H```"3&`,`%0```)X8`P`2````
MM!@#``T```#'&`,`"0```-48`P`.````WQ@#``P```#N&`,`3P```/L8`P`1
M````2QD#``X```!=&0,`&0```&P9`P`7````AAD#`!$```">&0,`$@```+`9
M`P`/````PQD#`"````#3&0,`6````/09`P`V````31H#`"8```"$&@,`(```
M`*L:`P`=````S!H#`#0```#J&@,`2@```!\;`P`4````:AL#``P```!_&P,`
M!0```(P;`P`,````DAL#``T```"?&P,`$0```*T;`P`.````OQL#``<```#.
M&P,`!P```-8;`P`7````WAL#`!$```#V&P,`#P````@<`P`7````&!P#`"``
M```P'`,`&````%$<`P`0````:AP#`!(```!['`,`(@```(X<`P!2````L1P#
M``X````$'0,`)@```!,=`P!#````.AT#``\```!^'0,`$````(X=`P`0````
MGQT#`)$```"P'0,`(@```$(>`P`<````91X#`#\```""'@,`,0```,(>`P`<
M````]!X#`"`````1'P,`&@```#(?`P`L````31\#`!H```!Z'P,`(P```)4?
M`P`9````N1\#`#,```#3'P,`(`````<@`P`&````*"`#`!D````O(`,`#P``
M`$D@`P`K````62`#`#8```"%(`,`!P```+P@`P`(````Q"`#`"````#-(`,`
M(0```.X@`P`)````$"$#`!8````:(0,`#````#$A`P`,````/B$#`"8```!+
M(0,`*@```'(A`P`'````G2$#`!(```"E(0,`%@```+@A`P`)````SR$#``P`
M``#9(0,`>P```.8A`P!4````8B(#`#8```"W(@,`5````.XB`P!%````0R,#
M`'````")(P,`#0```/HC`P`E````""0#`"P````N)`,`"@```%LD`P`1````
M9B0#`!$```!X)`,`+0```(HD`P`'````N"0#`!4```#`)`,`0@```-8D`P"H
M````&24#`$$```#")0,`4@````0F`P!7````5R8#``8```"O)@,`%````+8F
M`P`$````RR8#``\```#0)@,`!P```.`F`P`,````Z"8#`"$```#U)@,`'@``
M`!<G`P`[````-B<#`%0```!R)P,`,````,<G`P`J````^"<#`"(````C*`,`
M$@```$8H`P`Q````62@#`",```"+*`,`)0```*\H`P`J````U2@#`"H`````
M*0,`#P```"LI`P`O````.RD#`"D```!K*0,`+P```)4I`P`G````Q2D#`"4`
M``#M*0,`+@```!,J`P`5````0BH#``<```!8*@,`#````&`J`P`.````;2H#
M`!<```!\*@,`"0```)0J`P`+````GBH#`#T```"J*@,`!@```.@J`P`,````
M[RH#``P```#\*@,`"`````DK`P`3````$BL#``X````F*P,`"````#4K`P`%
M````/BL#`!T```!$*P,`"````&(K`P`)````:RL#``8```!U*P,`#0```'PK
M`P`-````BBL#`!(```"8*P,`%````*LK`P`,````P"L#`!@```#-*P,`#0``
M`.8K`P`(````]"L#`!$```#]*P,`%@````\L`P`4````)BP#`!<````[+`,`
M%````%,L`P`6````:"P#`!0```!_+`,`&````)0L`P`>````K2P#`!````#,
M+`,`"0```-TL`P`:````YRP#`"P````"+0,`$P```"\M`P`M````0RT#`"T`
M``!Q+0,`#0```)\M`P`'````K2T#``@```"U+0,`!P```+XM`P`$````QBT#
M``P```#++0,`%0```-@M`P`-````[BT#`#<```#\+0,`#P```#0N`P`3````
M1"X#`!L```!8+@,`.0```'0N`P`,````KBX#``T```"[+@,`#````,DN`P`%
M````UBX#``D```#<+@,`"````.8N`P`)````[RX#``8```#Y+@,`"0`````O
M`P`8````"B\#``@````C+P,`#0```"PO`P`,````.B\#``@```!'+P,`!@``
M`%`O`P`.````5R\#``8```!F+P,`#P```&TO`P`,````?2\#`!````"*+P,`
M(````)LO`P`9````O"\#``H```#6+P,``@```.$O`P`(````Y"\#`"4```#M
M+P,`!P```!,P`P`,````&S`#``H````H,`,`B@```#,P`P`1````OC`#``P`
M``#0,`,`!@```-TP`P`C````Y#`#`#0````(,0,`(````#TQ`P`@````7C$#
M`%<```!_,0,`,0```-<Q`P`T````"3(#`",````^,@,`(````&(R`P`%````
M@S(#``H```"),@,`#P```)0R`P`-````I#(#``\```"R,@,`!@```,(R`P`-
M````R3(#`!,```#7,@,`#P```.LR`P`/````^S(#`!$````+,P,`#````!TS
M`P`'````*C,#``<````R,P,`"````#HS`P`6````0S,#``D```!:,P,`"```
M`&0S`P`7````;3,#`!<```"%,P,`%P```)TS`P`'````M3,#`!P```"],P,`
M!@```-HS`P`=````X3,#`!D```#_,P,`"````!DT`P`3````(C0#``@````V
M-`,`#0```#\T`P`)````330#`!4```!7-`,`!P```&TT`P`5````=30#``8`
M``"+-`,`&P```)(T`P`-````KC0#`!P```"\-`,`!0```-DT`P`(````WS0#
M``4```#H-`,`#0```.XT`P`?````_#0#``H````<-0,`#````"<U`P`I````
M-#4#`!P```!>-0,`$@```'LU`P`1````CC4#`!H```"@-0,`%````+LU`P`[
M````T#4#``0````,-@,`"````!$V`P`+````&C8#``D````F-@,``@```#`V
M`P`6````,S8#``@```!*-@,`)@```%,V`P`V````>C8#`"8```"Q-@,`/@``
M`-@V`P!_````%S<#`"\```"7-P,`&P```,<W`P`[````XS<#`#0````?.`,`
M.@```%0X`P`>````CS@#`"$```"N.`,`;P```-`X`P`@````0#D#``D```!A
M.0,`'P```&LY`P!L````BSD#`#L```#X.0,`,@```#0Z`P`U````9SH#`&0`
M``"=.@,`4P````([`P!R````5CL#`"D```#).P,`+0```/,[`P!'````(3P#
M`"P```!I/`,`,@```)8\`P`O````R3P#`#$```#Y/`,`-````"L]`P`?````
M8#T#`"$```"`/0,`B0```*(]`P`]````+#X#`#T```!J/@,`1P```*@^`P!(
M````\#X#`"L````Y/P,`*P```&4_`P`V````D3\#`#X```#(/P,`,`````=`
M`P#H`0``.$`#`"(````A0@,`G````$1"`P!1````X4(#``D````S0P,`20``
M`#U#`P`T````AT,#`#(```"\0P,`,````.]#`P`?````($0#`&D```!`1`,`
M0P```*I$`P`W````[D0#`!T````F10,`+````$1%`P`Z````<44#`*@```"L
M10,`*P```%5&`P`U````@48#`$,```"W1@,`=@```/M&`P!(````<D<#`$(`
M``"[1P,`2````/Y'`P`\````1T@#`#@```"$2`,`%````+U(`P`*````TD@#
M`+(```#=2`,`/0```)!)`P`?````SDD#`"(```#N20,`.P```!%*`P`I````
M34H#`"<```!W2@,`,````)]*`P`E````T$H#`"H```#V2@,`(P```"%+`P`@
M````14L#`"0```!F2P,`,@```(M+`P`I````ODL#`!,```#H2P,`+@```/Q+
M`P`C````*TP#`$(```!/3`,`(0```)),`P`^````M$P#`%````#S3`,`$@``
M`$1-`P`(````5TT#`$@```!@30,`-P```*E-`P!)````X4T#`"H````K3@,`
M)P```%9.`P!)````?DX#`#$```#(3@,`)@```/I.`P`K````(4\#`&@```!-
M3P,`*P```+9/`P!#````XD\#`$8````F4`,`<P```&U0`P!"````X5`#`#L`
M```D40,`4````&!1`P!M````L5$#`%@````?4@,`9P```'A2`P!A````X%(#
M`&$```!"4P,`5@```*13`P`X````^U,#`$$````T5`,`8P```'94`P`S````
MVE0#`#T````.50,`/````$Q5`P!`````B54#`#P```#*50,`3P````=6`P!F
M````5U8#`&D```"^5@,`>````"A7`P!'````H5<#`#L```#I5P,`<````"58
M`P!P````EE@#`#X````'60,`,@```$99`P!4````>5D#`#@```#.60,`0@``
M``=:`P`D````2EH#`"H```!O6@,`+@```)I:`P`N````R5H#`#````#X6@,`
M@P```"E;`P!X````K5L#`'\````F7`,`TP```*9<`P`:````>ET#`"P```"5
M70,`-@```,)=`P`K````^5T#`%@````E7@,`+0```'Y>`P!7````K%X#`"H`
M```$7P,`#````"]?`P"^````/%\#`%,```#[7P,`+0```$]@`P!2````?6`#
M`$D```#08`,`:@```!IA`P!(````A6$#`$X```#.80,`00```!UB`P`U````
M7V(#`#@```"58@,`+P```,YB`P`L````_F(#`!0````K8P,`70```$!C`P`C
M````GF,#`#@```#"8P,`,P```/MC`P`G````+V0#`"````!79`,`10```'AD
M`P!#````OF0#``L````"90,`#0````YE`P`&````'&4#``<````C90,`!```
M`"ME`P`-````,&4#``H````^90,`"P```$EE`P`+````564#``4```!A90,`
M$````&=E`P`"````>&4#`!````![90,`7P```(QE`P!?````[&4#`%T```!,
M9@,`!0```*IF`P`<````L&8#``0```#-9@,`!P```-)F`P`&````VF8#``4`
M``#A9@,`.@```.=F`P`$````(F<#`!<````G9P,`&````#]G`P`-````6&<#
M`!,```!F9P,`%````'IG`P`3````CV<#`!````"C9P,``@```+1G`P`(````
MMV<#``8```#`9P,`%0```,=G`P`,````W6<#`!<```#J9P,`!@````)H`P`.
M````"6@#``H````8:`,`"````"-H`P`N````+&@#``@```!;:`,`!@```&1H
M`P`'````:V@#`#@```!S:`,`7````*QH`P!(````"6D#`$D```!2:0,`,@``
M`)QI`P`P````SVD#`#,`````:@,`.````#1J`P`O````;6H#`"H```"=:@,`
M-@```,AJ`P`Q````_VH#`"L````Q:P,`-@```%UK`P`M````E&L#`"T```#"
M:P,`0@```/!K`P`D````,VP#`#\```!8;`,`.@```)AL`P`Q````TVP#`#4`
M```%;0,`,````#MM`P`K````;&T#`#8```"8;0,`,@```,]M`P`V`````FX#
M`#4````Y;@,`*P```&]N`P`M````FVX#`#````#);@,`.P```/IN`P`K````
M-F\#`"@```!B;P,`1@```(MO`P!)````TF\#`"<````<<`,`-````$1P`P!/
M````>7`#`#(```#)<`,`-@```/QP`P`Q````,W$#`#(```!E<0,`+````)AQ
M`P`T````Q7$#`"D```#Z<0,`+@```"1R`P`S````4W(#`$8```"'<@,`+P``
M`,YR`P!@````_G(#`!$```!?<P,`'@```'%S`P`0````D',#``T```"A<P,`
M%````*]S`P`<````Q',#`"(```#A<P,`00````1T`P`Z````1G0#`#<```"!
M=`,`,P```+ET`P`E````[70#`!`````3=0,`*@```"1U`P`/````3W4#`!P`
M``!?=0,`%@```'QU`P`2````DW4#`"0```"F=0,`"0```,MU`P`)````U74#
M`!$```#?=0,`-@```/%U`P`6````*'8#`!4````_=@,`)0```%5V`P`H````
M>W8#`"<```"D=@,`)P```,QV`P`D````]'8#`!0````9=P,`"0```"YW`P`#
M`0``.'<#``T````\>`,`$@```$IX`P`1````77@#`!T```!O>`,`#@```(UX
M`P`0````G'@#`",```"M>`,`%@```-%X`P`8````Z'@#`!\````!>0,`"0``
M`"%Y`P!.````*WD#`!H```!Z>0,`$P```)5Y`P`'````J7D#`!4```"Q>0,`
M%@```,=Y`P`?````WGD#``P```#^>0,`'P````MZ`P!9````*WH#``@```"%
M>@,`6P```(YZ`P`I````ZGH#`!(````4>P,`%0```"=[`P`5````/7L#`#X`
M``!3>P,`'````))[`P`,````KWL#`"@```"\>P,`#0```.5[`P`.````\WL#
M`!4````"?`,`"@```!A\`P`D````(WP#``L```!(?`,`&0```%1\`P`*````
M;GP#`!T```!Y?`,`+0```)=\`P`%````Q7P#`"<```#+?`,`!P```/-\`P`'
M````^WP#``D````#?0,`3`````U]`P`'````6GT#`!$```!B?0,`"P```'1]
M`P`7````@'T#``D```"8?0,`"0```*)]`P`'````K'T#`!8```"T?0,`"```
M`,M]`P`+````U'T#`"(```#@?0,`*P````-^`P`5````+WX#`"@```!%?@,`
M+````&Y^`P`.````FWX#`!$```"J?@,`'@```+Q^`P`/````VWX#`"8```#K
M?@,`)@```!)_`P`/````.7\#`!H```!)?P,`0@```&1_`P`0````IW\#``\`
M``"X?P,`&````,A_`P`<````X7\#`#(```#^?P,`$````#&``P`J````0H`#
M`!8```!M@`,`'0```(2``P`5````HH`#`!4```"X@`,`&P```,Z``P`%````
MZH`#``<```#P@`,`&0```/B``P`'````$H$#`#$````:@0,`#0```$R!`P`1
M````6H$#``<```!L@0,``@```'2!`P`0````=X$#``\```"(@0,`"P```)B!
M`P`#````I($#``<```"H@0,`"P```+"!`P`*````O($#`!$```#'@0,`#@``
M`-F!`P`;````Z($#`!P````$@@,`"@```"&"`P`V````+((#`"0```!C@@,`
M*@```(B"`P!=````LX(#`&@````1@P,`2````'J#`P!4````PX,#`(H````8
MA`,`%P```*.$`P`-````NX0#`#X```#)A`,`#`````B%`P`&````%84#`!<`
M```<A0,`0````#2%`P`.````=84#``<```"$A0,`!P```(R%`P`$````E(4#
M``0```"9A0,`"0```)Z%`P`>````J(4#``4```#'A0,`!@```,V%`P`(````
MU(4#``P```#=A0,`!@```.J%`P`4````\84#`!0````&A@,`0````!N&`P`T
M````7(8#`"X```"1A@,`#````,"&`P`>````S88#`"$```#LA@,`+P````Z'
M`P`I````/H<#`!0```!HAP,``@```'V'`P`$````@(<#``P```"%AP,`"```
M`)*'`P`%````FX<#``(```"AAP,`$0```*2'`P!"````MH<#`#X```#YAP,`
M*0```#B(`P`O````8H@#`",```"2B`,`'P```+:(`P!A````UH@#`"(````X
MB0,`+@```%N)`P`N````BHD#`!H```"YB0,`(0```-2)`P!U````]HD#`#H`
M``!LB@,`(0```*>*`P!=````R8H#`"\````GBP,`7@```%>+`P!2````MHL#
M`$H````)C`,`'@```%2,`P`;````<XP#`"H```"/C`,`%@```+J,`P`S````
MT8P#`#0````%C0,`?0```#J-`P`I````N(T#`%8```#BC0,`*0```#F.`P!`
M````8XX#`"X```"DC@,`/@```-..`P!D````$H\#`&<```!WCP,`*0```-^/
M`P`Q````"9`#`"<````[D`,`-0```&.0`P`T````F9`#`",```#.D`,`3```
M`/*0`P`U````/Y$#`#<```!UD0,`.0```*V1`P`?````YY$#`"X````'D@,`
M.@```#:2`P`R````<9(#`#0```"DD@,`,````-F2`P!6````"I,#`$<```!A
MDP,`+P```*F3`P`O````V9,#`$`````)E`,`$@```$J4`P`2````790#``P`
M``!PE`,`B0```'V4`P`(````!Y4#`"@````0E0,`%@```#F5`P`:````4)4#
M`#D```!KE0,`+0```*65`P`,````TY4#`%<```#@E0,`Q@```#B6`P!Q````
M_Y8#`(L```!QEP,`-@```/V7`P`M````-)@#`&4```!BF`,`%P```,B8`P`]
M````X)@#`$<````>F0,`)@```&:9`P`7````C9D#`!<```"EF0,`P````+V9
M`P`:````?IH#`"P```"9F@,`)````,::`P!#````ZYH#`"8````OFP,`(```
M`%:;`P!K````=YL#`!P```#CFP,`#`````"<`P`.````#9P#``L````<G`,`
M!0```"B<`P`&````+IP#``@````UG`,`!0```#Z<`P`5````1)P#`!8```!:
MG`,`#@```'&<`P`0````@)P#`!0```"1G`,`%0```*:<`P`@````O)P#`"(`
M``#=G`,`$0````"=`P`/````$IT#``0````BG0,`$````">=`P`-````.)T#
M``,```!&G0,`"0```$J=`P`(````5)T#``X```!=G0,`!P```&R=`P`(````
M=)T#``8```!]G0,`"@```(2=`P`5````CYT#``P```"EG0,`"0```+*=`P`)
M````O)T#``H```#&G0,`$P```-&=`P`/````Y9T#``X```#UG0,`!P````2>
M`P`(````#)X#``H````5G@,`$````"">`P`2````,9X#``H```!$G@,`!@``
M`$^>`P`'````5IX#``X```!>G@,`&0```&V>`P`&````AYX#``,```".G@,`
M$0```)*>`P`)````I)X#``\```"NG@,`#````+Z>`P`*````RYX#`!(```#6
MG@,`!@```.F>`P`,````\)X#``4```#]G@,`"`````.?`P`)````#)\#`"D`
M```6GP,`(@```$"?`P`0````8Y\#`"4```!TGP,`%````)J?`P`;````KY\#
M`!$```#+GP,`"@```-V?`P`6````Z)\#``<```#_GP,`!0````>@`P`#````
M#:`#`!4````1H`,`!````">@`P`"````+*`#``(````OH`,`$@```#*@`P`&
M````1:`#``8```!,H`,`$@```%.@`P`7````9J`#``D```!^H`,`!P```(B@
M`P`+````D*`#`#H```"<H`,``@```->@`P`$````VJ`#``4```#?H`,`$P``
M`.6@`P`8````^:`#``H````2H0,`!````!VA`P`'````(J$#`!(````JH0,`
M!0```#VA`P`*````0Z$#`!D```!.H0,`"````&BA`P`7````<:$#`!4```")
MH0,`$P```)^A`P`2````LZ$#`!(```#&H0,``@```-FA`P`.````W*$#``P`
M``#KH0,`#0```/BA`P`6````!J(#`#H````=H@,`!P```%BB`P`)````8*(#
M`!$```!JH@,`!0```'RB`P`"````@J(#``L```"%H@,`%0```)&B`P`2````
MIZ(#``$```"=!0````````````!@"0``(0<``#0(``#=!P``L0$````````L
M!P``G0<``-\'``````````````````#0"@```````,8*````````BP,`````
M``#U"```*`H```````!D`0``*@$``"D)````````Y`<``#0$```O"0``E```
M`.\#``"R`0``%@```+4)```9`@``+@@`````````````S`(``&X!``"["```
M8@$``,T`````````6`(````````Q`P```````-0$``"4"`````````````"%
M!@``&P4``"P(``!I!0``K00`````````````````````````````M@4``"L&
M``#Q"@``L`4````````.`0````````T```#\!0````````````#Z"@``,@H`
M``````!U!0``#PD``&P+``#'!0``;`,``)4#```K"0````````````#^"0``
M'PH``-D'```("```Q`4```````#4"```Y@(``&4)``!,`0````````````!=
M"@```````'@*``#@`@``F`(``$,&``!:!@``````````````````D@8``-`%
M````````H@```/X"``!5"0```````&<(``"(`0``?`L``/T*````````9@L`
M`/<%``")`P```````,4(``!-`P``*P,`````````````8@@```0(``"4!0``
M:@L``)@(``"+"0``8`8``.D!```Y!@``Q@$``-L&``#``@```````"(%````
M````(00``#P(``#/!0``5`(``%0```#F"@``8`0``$`(``!<`0``"P(``%\)
M``"E`0``!`L``,0)````````-0D``-X%``!^"0````````````"?"@``&04`
M`*,'```!`@````````````!?`@``*0(``+D$``#-"0```````"$*``#1`P``
MLP<```D)````````%@,```(&``#9`P``BP0``'@"```W"@``)`L``#X(``#(
M````.0``````````````%00``#L+````````&````!D!``"I"```'PD``$4"
M``":!```&`$```````">`@``Q`(``"\&``!I"P``@0(``"4!``!U`@``!0$`
M```````R!@``QP@``)4'```/!@```P0``(<#```X!0```````&@`````````
MZ@H``+D(``#[`0``@0,``*L*`````````````!0#``"C`@``;04``$<#``!#
M!```0@0``(,#``"A"@``(P0`````````````'`L```````!!`P``,@```&T*
M```>"P``W@$``````````````````!L(``"7"0``%0H``&\(``#C!P``R@``
M`&`%``!@"@``H````)D%````````4`,``/$#````````O@$````````3"@``
M``````````"="0``2P$`````````````5@<``$`"`````````````+$$````
M```````````````Z"P``N@```*D*``!("P``V@(``$`$``!8!P``&PD``.`*
M```S"P``(@@``+X(``#M!0``WPD``&P"``#H!@``2@L```````!&!0``U@D`
M``````"Z`P```````"0(``"$`@``````````````````WP```"@"``#W````
M`````,4$```=`@``I`0``+8```#=!````````-<```"*"@``4@8`````````
M````PPH``'X$```;!@``X0<``.<`````````U`H``/@)``#\`@``<04``-,!
M``!P"0``T`8``/X*````````>@H``#<$````````(0```#P`````````.0@`
M`!T```!;!0``*04``)D$``#%!P````````````#F`0````````T'```&`P``
M`````!T%``#G"0``80@``+('``!0`0```````.,%```M"@``-@<``.L)````
M````Y0,``'8)``!E!P```````,$```!%!P``[`@```````"T````9PD``"X&
M``#_!```D`4``!D)``"]`0``W@@``,X%````````8P@``(`!````````]@<`
M``````!F`0``!P(``.H%``#B!0``M@<``-P'````````=@```#4+``!7!```
M`````"<*````````.0D``'D+``!V!```OP@```8```#*`@``1P@``"T+``#3
M!@```````&P*````````?PD```````#!"@``KP0``&4%``!I!P``Q@,``$8(
M````````&P<``&<$````````F`<``#T%``"J"@``+@0`````````````6@,`
M``\%``!U````<`L``',&``#)````APH``#@```!2"@``8````*0#``"G"0``
MZ`H``````````````````.\"````````VPH``,X"```G!```C`H``&L%````
M`````````(,```#""```BP@`````````````+@```&@$``#`!```NP(``#H%
M``#,"```Q`8``#T(``!]!P``/`(```P+```="@```````)`$````````````
M`)L'````````900``````````````````%D'```6"```N`4```H$````````
MB0H``*H'```Z`P```````$T*```_!P``.04``"4+``"=````408`````````
M````[@``````````````W`@``"H"```E!P``NP0```````"R"@```````"X"
M```L"P``B00``````````````````'`&````````=@,```````!X"0``APL`
M```!``#5!P``^`,````````M!````````.D)``"6`P```````*`*``#V`@``
M4@4``*H)```I"```:0```)$&``!;`P````````````"6"0``````````````
M`````````,P$``"O"@``A0,```````"2!0``9`````(+``##`````````$H"
M````````-0,``'P)``#T!@```````)$%``#C`P````````````!R!```3```
M`!`+```O`0```````+`!``#K!P``>00``-@$``"?`@``ZP4``-P%````````
MX````!H)```!"0``S04``)T*``"6"@``@`8``&$$``"Q`@````````8+```0
M"````````(<&``"0`P```````(L&````````A`D``$0)``#>!@``Q@0``-<&
M```B!```$@4``,(!```+"P```````/<*```]`0``H00`````````````````
M`*@(``!Z`@````````@&``#+"@``4P4``$0'````````@`H``,,%``"2!```
MP@4``*<$````````0P(``',*````````QPH``)8&``!F!```6`$``,D'``#9
M!```!@4```````#K````"0L``"\%````````5P@``&0(``!"`P``"@H``&\$
M``````````````````!L!0``P0,``*4'````````50```*@$``#.!```QP``
M`/("```?`````````'$!````````S@<``(8*```B!P``90L`````````````
M-P,```````!!"P```````'@#```G!@``L04````````6`0``4`(`````````
M``````````````````````````@#``"V!`````````````!#!0``<`<`````
M````````000``````````````````)0#```X`@``O@4``$<&````````QP$`
M`*L%``!["0```````(4```!A"0```````-@(````````3P,```````#8`0``
MY`@``)(#```C"0``(`4``*0'````````F`8``),$````````Y`0``/,(````
M`````````*\%``!C`0``!0L``+$(``"H!@````````L%``"`"P``UPD`````
M````````H0```,P!````````10,```4&``!`"0``X`0`````````````?P,`
M``````"O`0``S0<``(T"``"-"```Z0<```````!R!@``YP<```X'````````
M`````-$$``![!```Z0```&\#``!U!@`````````````P!P```````*0%``#]
M````O`(``*T)``"O"0``8`<```8)`````````````$`&```R!P``,`,`````
M```@`@``Z0H``&<+``"N"0``_`H``)H#``!C"@``-P<``#`(``#U!```]08`
M`&@!``"0"@``=@(``(`$```\"@```````)@#``!1`0``^`@````````3!@``
M<0<``%@$````````$P``````````````B0(``.P*````````O08```````"`
M````W@D``,0'``"M`P``%`0```(```#X!0````````4```#:`P``DP,`````
M``#-`@```````$D!``#K`0``:08``%X#``#<!@``GP```*L)``!F!@``?@(`
M``````````````````````#5`P``R0@``/\#``"O`@``\P<``,\$````````
M\P```)4%``#(!P``&@0``,8'``"0`@``B`@``)<(````````@@$``"0*``!'
M"P``'@```+L#``#W`@``5P$``,@%``#P`P``508``.X%``!G!0``=P@`````
M``"7`@``,@D``.('````````J`4````````I!P``N@<``$8*``#`!@``3P$`
M``````"W"```CP@``$(%``"[!0``$0D``!D```"A"0``X`8```<+``!E````
M3P0``!4'`````````````#D*```.!0``7PH````````:`@````````D'``"%
M`@``!`(``&\```#/"0``+@4``($+````````CP<```````!``0``10L``.4*
M``!0"P``%P$``!L"``",````^@```!(*``!2"0```````$@(````````!PH`
M`$H*``","```Z`4``+L&```_`0``A@D``.(#``"S"```S0,``!<*``">!```
M/@H``&T#``"""P``+@<``(`#``"H`0````````````"B"```<0L``"8&````
M`````````.4%```!`0``*`$``````````````````$$'```"!```!`,``'$*
M```>"```$PD```````!O!P``]`$``+`"```M`P``PP8``.X*```^!P``````
M`#H(````````W0@`````````````X@(``-<!``!+!```O`H```@+````````
M`````````````````````'(*`````````````,\!``#3`@``-P$``'X+``!"
M`0```04``,0!``!.`@``;0(```P%``#=!0``=0<``%\$``"*`````````+,&
M```^"P````````````#[!@``N0<``(D(``````````````````!T"P``H04`
M`/<!``"("@``IP4``!<&``!-````2PH``!T!``#)!0``^P@``-D"``!<````
M"`(``(,+```.!@```````.4'``##"```G@4``","``"/!@``3`H``%D!```C
M"```_````$0"``#R`P```````/(*`````````````($)```G`P``>P(``"H&
M````````Y`D``%`&``!I"0``,0````,#``#V`P``?P4``*H(```'````-0(`
M``D"``!D"@``-`8``#X````B`P``_0$``)8!```<`P``L0<```````!3!P``
M!0(```````!4!0``6@H``````````````````'P(``"E"0```````#P!``!<
M"```D0H``&\!``#_`@``_08``-(!````````DP$``*P"```\!0``6@(``.H!
M``!D!@``70,```````````````````````!!"````````'H#``!B````DPD`
M`+8&``#["@```````(L!```9`P``&`4``-,$````````K0@``!L+```9"P``
M`````&L*``#\!@```````*`'````````OP$```````!S!P``J0(``/`*```U
M````Z0,``%X"``":`````````/`)``````````````````#H!```30(``.0%
M``#F!@``9P,````````/`@``V`H``"4)````````1`0``"H'``!Y`@``````
M```````;`0```````&$!``"'"0````````````!C"P``8`L```$#``#O"@``
M/@D```````")`0```````,,"``"#!0``P0@`````````````VP@``/<)``!P
M"@``)@L```````#O``````````P'````````E0(````````4`````````!$"
M``"&!```H@0``#T+`````````````+4*``"Y!@``*@D`````````````)04`
M`$(&``#3!0``"@@``,()``#'`P``7P4``,D)```-"@``:@<````````+`P``
M!````.D%``#-!@``>P4`````````````T@(``-@```#^`0``%@D```````#3
M"@``5`@```````!T!@``5@,``$0%``"W`0``'P0``,$'``"N`P``CP```'`(
M`````````````$P+``"K!P``;P4``!<+``"A!P```````/8(``!W!```7@``
M`&(#``#?!0``CP4``-\"``#*`0``G@D``+D!``"(!0``N`````T$````"```
M````````````````U08``#8"```A`P``O@H``,D$``"B!P``EP0``.\&``!U
M`P``C0H``%T)``"F`P`````````````;`P```````+\)``!Z!@``-`(``#8)
M`````````````%H(````````E`$```````!G`````````&@%````````H0$`
M``````"L!```4P8``-4"``#C"@```````#`%```2"````````(T%``!4"P``
M`````/D)``"_!0``GP8``)8'``#>````````````````````?0L``(0&``#[
M!0```````!4````P`@``00(```````!*!@```````!4&``!G`@```````+\$
M``!@`0``D0(``.L(```_`@``N@D`````````````````````````````````
M`-D*``!_!```\@D``'T```"X!@``F@4````````M`@``7@8``(D'``"2"```
MB````'8+````````!@$```````#=`0```````+@#``#T!0``R`D``/4%````
M````EP<``"D!``!?"P```````(H%```"`@``E0`````````+"0```````.L$
M``#2!0```````%$$``#4````[@(```````#4`@`````````````="P``I@D`
M`#0)``#V"0```````($&````````B08``"H$``#N`0``NP<``'D%``#0"```
M\`<``.@!``"5`0```````+P%````````@PD``",&``#%"@```````'P&```F
M"0``=PD``/D&``!?!P``&0H``$<*``"H````[00```````!(!0```08`````
M``!>!```^P```+P$```1!0``````````````````(PL``"0"``#6!@``40<`
M`"8!````````M0(``',!```H"P``;0$``&,)``#Z"```*@4``*P'````````
M`````+8!``#(!```U@H``"0#``#*"@``3`,``(D)````````\`@``'``````
M``````````````!L!```%P(``"@&``"`!P``A@L``/0'``#T"@````````L`
M```^`0``-`L``$D````\!@``S`H``%@%```T`````````-P#``"I!```$PL`
M`'H(``#M`0```````.H(``".!P```````)L(```]!```1P$``)@%````````
M'00```X"```9!```>`0```````"S`````````*,$``#&````30@``,(*````
M````$@````````#<`0``=00``"4"``"D"```V`(``'8'``!("@``[`4``$D$
M``"B`0```````"P#```."```4@(``%(```!6`@``;@4``%L```!*"```3@,`
M`&8"``#H`P``KP<``!@(``````````````````!3`@``R`$``%D&``#;!```
M`````$$)````````%0,``&D$``"S"0``CP(```````#+!@```````'('````
M````T`,``+($``"J!```<PL``-()````````(04``"H+``!#`P``<@D`````
M``"E!@```````,0*``#6````N@0``((#``#?`0``G@<``$X'``"`"```.00`
M`!,$````````#`8``.,!````````<P(``#P$``#Y"@``9@```)T#``!D!0``
M`````'D&``"^!```'@(```````!G!P``?@4``-$&```I"P```````.@"``#-
M`0``0PD``&X&```4!P````````````!W`0``````````````````BP``````
M``"O`P``70(``#,$````````````````````````BP<``$D%``"C"@``)P4`
M````````````>`4``.,```"8````$@$`````````````;`$``*<"``"5"@``
M?````"@$```[!`````````0'```%"```%`8``"\'``!5!0``'`0``/X%````
M````K@(``/0#``#+`@``+`$``(D%```K!0``LP4``"H*```I!@``+@L``!@#
M``!M!```D@D``$$%``!9"P``&0@```````"!`````````#8%``!C`P``````
M```````6!0``<@L```````"<`0``R0,``%<&````````$P$``%D"``#1"@``
MK08``%4#```Z`0```````.8````$!0``9@4````````7!P``N0(```````!;
M!```:`(``/$&````````(`<``'X```#S!```T0<`````````````EP,`````
M```'!0``!@<``(P&````````2@4``-X$`````````````.`)``#^````````
M`/L)``#E"```M`H``/4'``"2`@``MP```",*``#.!@``?P(``/,)````````
M30D``&,$``"C"```````````````````@0H``#L)``#2!````````%@(``"E
M`@``A`$``/$`````````Q@(``$L`````````Y@0``-`'````````K`D``/($
M```-"P``[@,`````````````C08``$<````@"```<`,```````"I`P``<`$`
M`*D'``".`0``#0@``(,'```V!@``W0(``#D!``"M!0````````````"F`@``
M`````'<#```E!```,`8``-\#```@"0``10```(L%``#W"```X04```````!)
M"````````!,#``!8`P```````!$&``!Q"0````````````"W!```=PL`````
M````````L@4``$T$``!K`0```````%\#``"!`0``A@```&8(````````:@,`
M`#L(``",`@``7@4``%`$``!""@``[0```#T)``#Q!P``.P8``*,)````````
M?@H```````#T!```````````````````FP0```````"P`P``#`0``/('``"'
M"```$`(``!L*```\"0``CPH``/D!```2"P``IP8``'X&``!$````1P0`````
M``!7````JP@``$(```"M````?`0``+4&``"%!P```````%L'```6`@``\P(`
M`)`)````````F@$```````"R"```'P8``$T!```1`P``&`0``$()``"]!0``
M`````+4#```:`0``"`0```````!E`P``/P4```````#(`@``?@<``*X$``#5
M"@``/P@``)P&````````5`8``#$&``!+!@```````'<&``#@!P``````````
M```4"@``#```````````````.`D``+@'```>!0``1P(``*D!``!Y"@``P```
M`/`&````````"P$`````````````)08``+(`````````A00``'X!``!("0``
M?PH``$D*``"F`0``&`8```````#>`@``JP(``!`)``#_`0``10H``.()````
M````>P8```D&```B"0``Q0D``#,!``!,"```3@$``!0"`````````````,<&
M``!W!P``>@<``&$```````````````````#0`0``!P$``)$)``!6!@``YP@`
M`$,```"%"0``!P@````````7!0``4`<``%0'``"/`P``,P,`````````````
M5@$``$@!``#V!0```````.D&``!`````D0$``(H"``",!0```P```%8(```X
M"P``'P$``$H#``"'!````````/(!````````Z@8````````!!P``7`<``/D'
M``"="```1@```(8#````````F0D``.$&``!B"0``````````````````-@H`
M`/@&``"0!@```````$('`````````````%(#``#7"@``D`@``%(!``"K````
MT0@```D```"(!@``M@,``#@$``#R!@`````````````(!0``>0````\+````
M````'@0``#4&```&!@``C@@``-((``#,"0``M`(``+P'```T!P``C@``````
M``#L!@``*P$```````"&`@``1P<``,H(``!#"@``^04``-8'```@`P``VP(`
M``\$````````"0$``'P*````````0PL``#,(``"P!P```P<```X*``!N!P``
M#@```.<$``!3"@``>@````````"E!0```````"@)``""````7@<``'0)```Z
M!@``R@D``#\$``#F!P```````.<"```<!P``M`4``-D%``":"0``!PD``,H&
M```$"0``P0(```P!``"V`@``50H``+D```"U!```M@D``.$```!<`P``````
M`#L%````````V@$``#4!```A`@``]0$``&L#``!>"@``]P<`````````````
MC0$``````````````````*`"``#O!```.`@``%@&``"-!```K@H``$0#```[
M````[`<``.(*```<"@``"@````````#8!@``7@$``/4`````````UP0`````
M``#M!@``"`H```````#$"```8P8``&T(````````E@0``-\$```!"@``$P@`
M`&H$``"+"@``(0$``)8(``"%!0```````.$*```V`0``6@L``"$(```/"```
M`````&L$``#E!```I0H``&0'```E"@``F`D`````````````6@D``&L(```8
M`@``3P4``$X$``#A!```P`4```````!U"```:0H``%8$``"Z"@``^P0``/T#
M``#2`````````/<&```K!```9@D``+X&```@"P```````-@#``!9`P``^@8`
M`,@*``!L"0``'P@``,\'``!5`@``)`$``'0'``!%`0``^@,``"H#``##`P``
MG0$```````!$!@``+P0``)L``````````````$X+``"A`P``D`<``'0*``"!
M!P``````````````````=`@``#\)```M"0``P`H```````"]"@``(@L```H'
M````````L0,``'(`````````Y`8``$H$``"W!@``(`````4)```G"P``X@``
M```````@!```````````````````K0H``*<'````````60@``)H&```W"```
M``````````!)"P``$@8``)L)``!K!@``````````````````*PH``+<%``#G
M!0``@P@```````!<"0``EPH``*X(``#H"````````&H&````````FP(``"8'
M``#3"0```````-('``````````````````!,"0``J0````````"D"@``FP4`
M``````"G"```/`L``/4*````````-@@``-0#````````!P8``+T$``#-!```
M!00``&D"``"L!0``5@H``'H!``![!P``Y@,``!H```!S````HP4```````#Z
M!```:@@``'<*````````"@L``*8%``!D"P``,0<```0!``"H`@```@,`````
M````````8@0```````!O`@``+`D````````Q"P```````.X$``#!"0``E0@`
M`-(#``#J`P``U`4``/T"```````````````````#"0``<0(``*<!``"D!@``
M``````````!F`P``$@,``,\#````````P@```$8#`````````````+<'``""
M"0``L`8``"D#```8"@```````'((```#"P```````',)````````ZP(``%H!
M``!8"@``E0D``&T&```G!P``NP```#$"```@!@``5P4``*H"``"(!```)P(`
M```````L`@``.P(```````"<`@`````````````*`0``$0``````````````
M"P8``,,'``!3"0``2P(``$X)``"1!P```````#```````P``&P```+<#````
M````N@4``#`*``#U`P``C0<``/D(``#T````]`@```````"T"```,@L``'H)
M`````````````&(&````````F08```T#``#M`P``1P4```````#3````@PH`
M`.X(````````!P,``*8'```/!P``)`8``!T'``"-"0``H0@``-L'``!\!P``
M;@@``&X```!/"P``O````$L%````````=0$``/H)``#!`0``4P```'$$```V
M"P``M`D```````!(!```U00```````!K`@``_`<```````!S"```V@4``!<$
M``"P!```H`D```````#Z`0``R`,``/@"````````K`$``#(#``"(!P``9`(`
M`(\$``#+`0```````$L+``"F"@``3`4````````H!P``)0,``+8*``#`"0``
M5P(```````"@`0```````-<"``#]"0``S@D``%\(````````90(``.8%``"F
M````,@@``#\```!P!````````$("```F!0``2@```%<'``#E"0``GP$`````
M``#+`P```````/T(``#O!0````````````"("0``&@<``'T#```X`P``'0@`
M`.T'``"2!P``]P,``/0"``!9`````````&L'``#Q!0``B`,```````#\`P``
M.@0``-4(``"$"```'@D``-X*`````````````&H!``#/`@``!P<``,4%```8
M!P``E`<```````!A"P``.@(``)`!````````3P<``$T%```]!@``S@,``!$+
M````````;0<````````R!````````#D#``!A"@``SP@``-$)````````W0D`
M``````#'"0``H0(```````!3"P``7`H``,D&````````9P8```````#7"```
M`````/,%``"C`P``+`8``!,"``"6````T`````````"/`0``;`<``.$!````
M````7P```+,*```^!```K@4``",!```#"```;PD``%,$```&!```.@``````
M````````6`L```````"$"P``%@8```````!2"````````*$&```8"0``````
M```````0!0````````````!O!@``MPD``)P'```V`P``#@D``+4(``"!"```
M,@(``%,#``!R!0``=````(0````T`P``C0,``-4)````````+08``(<"```^
M!@``F0(``'(!``!)"0``+@$``/H%``!J"0```````*H```!V`0``(P<``,$$
M````````M`0````'``"!!```!`8``)X&`````````````*`#````````H`8`
M`$,'``"M`@``-@0`````````````9`0``'`%``#0`@````````````!1"0``
M4@L``````````````````$0(``!J````704``*@)``"3"@``H@8``-8"```N
M"@``H@H```````"1"```8P4``````````````````!,%``"4"@``E`D``#`+
M````````/@(```````!(`@``A`4``*4````]!P``FP8```````#"!P``80<`
M`"(&``"7````8P(``"$)``#E`````````%('```O`@```````,4!``!6!0``
MX`$``/4"`````````````%P&``!9!```?P$```D*``"P"0``2@$``(T`````
M````[@<``+D*``!;"```500``.X&```]"@```````,D!``!]!@```````#`$
M`````````````%T&``":!P``8P<``-D```"%`0`````````````:"P``700`
M`,`(```?!P```````)P%```#`@````````````!E`0``:PD``&X+````````
M[`(```````#``P````````````"Q````F`H``$`%`````````````+\'``#@
M`P```````/4)``";"@```````%0*``"H"@``O0@``%4(```Z"0``````````
M``#]!0```````#8`````````2PD``%P"```_"P``_`@``+T'```4!0```0L`
M``````````````````````"=!```"````,X`````````G@@``%\&``!$"@``
M``````````!/"```Q0(``````````````````$0+``!&!P``%0@``,0```!/
M`@``,P```/@*``">"@``9P$``/8!``#%!@``B@<``*P#``"F"```/`,`````
M``"H!P``^P(``+4'``!T!```90H``(`)``!;!@``@@4``.L&```D!P``U`D`
M`/@$``!Z!```'`$``+@$```>"@``;0```-,(`````````@D```````#0!```
MS@@``&X#````````4`H``!4"````````(@(``(`%```W"0``@@@``!P"``#J
M"0``[`0````````U!0``_P```,4#``!4!```0P$``/@```"B`P``1@0`````
M``#D````+`0```````#H`````````&D!``!1`@``VPD````$``#J`@``7`0`
M`&T+````````.P<`````````````EP$``'\````]````20<``&(%``!*"0``
M%PD``$T&``!>"0``4P$``!`#````````'`D``*P*``","0``=`,``,$%```R
M`0``+PL``*X'`````````````$8)``#+!P``#0(``.D"```>!@``S`4``(H(
M```4"0```````/X&``#*!0``@04```````#Q"0``RP@``!,'``#P`0``````
M`-L#```*`P``,PD``.,&``"."0```````)P*``#-"@````````````!:!0``
M``````````"Z"````````*("``"T!@``X0@```````#``0```````+P!````
M````I0@``&@(``"<`P``?00``-8$````````@@8``+P&```%!0```````.$"
M``"["0```````(8&``"O"```'0D``!8+``!?`0``*0H``#D"``"J`P``<0``
M```````>`0``)@H``%`(``#("```G`D``.0"```0````>0<```````"*`P``
M``````````"4!```5PD```````"%"@``'0,``%X(````````QP<``+T```!5
M!P``Q`0``'@&``#:!P``@P0````````I````>@4``/P)````````0`,`````
M````````7@L``*0"``#P!````````-,#``"'!0``GP@`````````````(@$`
M`.H'``!%!0```````#,'``"S!```I`D``(@"``"8!```````````````````
MZ00``"0```"9`````````)$```"#`0``R0(``$,(``"9"@``O@```"0%``!^
M"```V@```/\*``!8````K`@``-,'``"%"```@@H```````!H!P``N`$``!X#
M``!B`@``$@D``(H&````````"@8```````!`!P``M04``$D&````````A`<`
M`#T"``#J!```)@````````#1````_P8```````!N`@```````"(```"4`@``
M``````D$```:"````````!0(``!(!@```````)H"````````>`$``"D$``"J
M!0``N@$```<$``!U"P``K0<``"P%``````````8``*L$```O`P``````````
M````````60H```````"8`0``&@H``-P)````````2`````````#A`P``LP$`
M`+\```"I"0``3`(```````"9"```L````*,!````````=`$`````````````
MA`H``,,)```0!```Z`<``-0&``#+!```_@,```T!`````````````*0````X
M!@``!@H``"<)``#>`P``I`$``#X%``"?!0``4````)8"````````:@4``%$%
M``#]!````````.,(``!W`@``IP,````+````````<@,``#4(``#?!@``(0L`
M`+$&``#2"@``C@,``'`"````````K@```#4*```?"P``````````````````
M/0,````````````````````````%"@``$`<``$L'``!1"P``F0<```````!=
M`0``"`<``,L%``!7"P``C@H``%T```#L"0``L@D```````#&!0```````&X)
M````````7`4``*(%``#@"```W08```````!=!P```````/<$``":"@``````
M``\```!B"P``@@<``.D(````````^0```+P(````````U04``'L(```0`0``
MA@@``-$%````````%P,``$L(``#&!@``I@8``!\"``#M"@````H``(X$``!;
M`@``?0$``.\(``#9!@``QP0``"8"``#P!0``O0D```````"X"@``!@@``),'
M````````D@```(8!````````>0,``-D)``"<!``````````````"!0``80(`
M`-T*````````.P$``````````````````*\```!E!@```````,4```#A"0``
M-0<``'8*```1"@``8`,``-4!``#C"0``ZP,``%L*``#V!@``"@4``,T(``"^
M`P``=P4``),%``#P`@``+0````````!U"0```````)0&`````````````$@'
M``#1`@``^@<``!\#`````````@$````````,"```)@0``/D#``#S!@``$0$`
M`)(!````````#`,``+\#``"3`@``&0<``.,$``!J`@```````%<#``!X!P``
MGPD``%H````&`@``#P,``/L#```-!@```````'@```!0!0``#PH``+P#``!!
M!@``?P8``"@#```)`P``.P,``(\)``!N!``````````````Q`0``%0D`````
M````````*@@````````F"```N0,``)L#``"E`P``_@<``#@!```P"0``[`,`
M````````````*P<``!$(``#8!P``C`0```4#````````/P8``"4```#,`P``
M;`@``,0#``#Q`@```````&`(``#M"```"P0``,(&``!^`P````````D%````
M``````````````!L!@```````/\%``"0````6PL```````"*"0``VP```!8$
M```;!```MP(``(("```,"0``G`@``&$#````````3PH``&$&```.!```````
M`!$$``")````S`<``,@&``!I"```[@D``+T"``#<!```B`L``#H*``!Y"0``
M"P@``,8)``#?"````````!`&`````````PH``-0'``"5!@```````&@)``"1
M!````````/(%``!-!P``V`D```X#``!&`0``10@``*`(``!H`P``````````
M```)"```%0$``/P!````````M`<``,\*```7"```AP$``"`!``"?!P``5@``
M`)4$```<"```P@,```````"_!@``<@(``/\(````````D0,```````".!@``
M0`L``(0$`````````````/,#````````,0@``!P%``````````````````"N
M!@``=`4``,8(``!7"@```````.\!```K`@``,P(`````````````3PD``),&
M````````YP,``$X%``!["@``V@@``+T#``!M"0``J@8``'@+``![````BP(`
M`.((``!&!@````````````"T`0```````&4(``#[!P``3`0``$$!``"6!0``
M1`$``"L(``#_!P``Y`,``%H$````````3@@``!H#`````````````/8$``"C
M````O@<``,H$```H````4P@````````,`@```````'8&``#D`0```````*T!
M```%!P``(`H``.L*```2!P``\PH``!4%```2`@``DP```%P+``#]!P``L@8`
M`"T!``!B"@``[P<``````````````````.(&``"9`0``S@$``'$&``!S`P``
ML`@`````````````(P```.(!````````W0```'L!```:!0``[`````````",
M`P``+04```````"B"0``0`H``$\`````````P08``%4!```Q"@``````````
M``#*`P````````````!)`P``"`$``'@(``"<````N@8```````!O"@``'`8`
M`/,!```D"0``O@(``/8*``#L`0``LP(```````"R`@``YP$`````````````
MJ04``!D&``!/!@``"@(``*,&```5"P```````%H'```G"```S`````````#6
M!0``>@L``/P$`````@````4``)D#```S!@``L0H``.\)``"?`P``"`D``-H*
M`````````````"P*``#C`@```````!0!```>!P``#P$``"P`````````````
M````````````S`8``%$(```B"@``A@<```````#+````)0@``&,`````````
M```````````$"@``#04``!P``````````````/$(``!Y`0````````````!.
M!@``V`4``+P)``"&!0``!`0```````"["@``5@D````````4"P```````+0#
M````"0```````$8"``".`@``*`@```````!8"0``AP<``(X%``">`0``````
M`!\%```"!P`````````````0"@``OP(``$T+``!N"@```````+@)``!D"0``
M``````````"J`0``5`,```````#6"````````/((``!1``````````````#_
M"0``6P$``)<&```#`0``+P```)\$``!F"@```````%$*``"_"@``YPH`````
M``````````````,&``"G````?P@``,\&``#M`@``JP$``$<)``#;!0``W0,`
M`/@'``#E`@``-P(``,,$``!S!```-P8``,("````````:`H``/D$``!\`@``
M`````,\`````````K@$``/8```!]"`````````````#."@```````-<%```!
M!```:`8``'4*```*"0``C`<``%D)````````-`$``$((````````VP$```T)
M``!1`P``100``-`)```W!0``DP@```((``##`0```````&('````````"P<`
M`#\*``#^!```,0D``#P'``"#!@``3`<````````N`P````````````">````
M-00````````K"P``4`D``,($``#9`0``10D``-<'``!@`@``U`$``#<+``#J
M`````P4``"T'````````U@$``.4!````````^0(``$$```"=`@``3@H`````
M````````?0D``!H&``"@!0``50L``/0)``#Q!```<0,``)L!``"L````````
M```````_`P``$@0``'T*```P`0``&`L``,`'````````M@@``)H(``!%!@``
MN0D`````````````B@$```````#X`0``N`(```````!L``````````````#R
M````LP,``*\&``!Q"```9@<``.($````````(P,```````"@!```.0<``"0$
M````````9`,``/H"````````L0D``-(&``"K!@```````#$%``">`P``M0$`
M`*@#``"W"@``@@0``.T)```G`0``%P```.4&`````````````'\'````````
M`````'P!``!O"P``Y@@``',%``#:"0```````$(+```["@``:@H``%8+``!)
M`@``O@D``(0#````````UP,``%($``#6`P``W`H``%0!````````70L``#0%
M``#<`@``I@0```````#Q`0``:PL`````````````M0```,<"``!V"```+0@`
M`+D%``"2"@```````"\*```C!0``9PH``!8'``!I`P```````*<*````````
M=`(``#0*``#:!```J08```````!&"P``.`H````````Q!```G08``%T(````
M````?`4``.0*````````W@<``-4````A!@```````-H&````````L@,``-P`
M``!]`@``NP$``.`%```^`P``Z`D``*L#```H!0``#`H```(*````````A0L`
M```````."P```````/```````````````'<`````````B@0```````#?"@``
MR0H```````!.````N`@````````F`P``R@<`````````````RPD``!T&``![
M"P``.`<``&$%````````-P```.8)``"'````I00``'T%``!!"@``3`8``-$!
M```+"@``2P,```````#9"````````)<%``"Z`@```````'8%```Y"P``)P``
M``````![`P```````"X)``!K````K`8``(P!````````$0<``"\(``!;"0``
M2@<``"H```#^"```,P4``$@#````````?PL``'D(``"#`@`````````````K
M````%@H`````````````,@4``#,*````````?`,``(`"```!"````````%D%
M``"P"@``5`D``&@+``#G!@``.@<`````````("`@("`@0V,Z(``@("`@("!4
M;SH@`"`@("!$871E.B``("`@($9R;VTZ(``@*"5S(&1A>7,@86=O*0`@*$%C
M8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W
M*0`@*'EE<W1E<F1A>2D`(%-U8FIE8W0Z(``@870@`"!I;B``(B5S(B!I<R!N
M;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B
M)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`
M(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@
M=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P
M97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`
M(P`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`"4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!-97-S86=E
M<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60@;65S
M<V%G97,@:&%V92!B965N(&1E;&5T960N`"5D(&UE<W-A9V5S(&AA=F4@8F5E
M;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T
M('-P86TN`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`"5D(&UE<W-A9V5S(&AA
M=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M+@`E9"!T;R`E9"!O9B`E9"!-97-S
M86=E<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I
M;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N
M=``E<R!A;')E861Y(&5X:7-T<RX`)7,@86QR96%D>2!E>&ES=',N(%EO=7(@
M)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE9"X`)7,@870@)7,@)7,`)7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R
M(&)E:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"X`)7,@
M:&%S(&%C8V5P=&5D+@`E<R!H87,@8V%N8V5L;&5D("(E<R(N`"5S(&AA<R!D
M96-L:6YE9"X`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S
M="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@(B5S(BX`
M)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S
M('1E;G1A=&EV96QY(&%C8V5P=&5D+@`E<R!I<R!R96%D>2!T;R!P97)F;W)M
M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H
M96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I
M;F9O<FUA=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`B)7,B
M+@`E<R!T;R`E<R!O9B`E<P`E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M("(E<R(N`"5S('=I<VAE<R!T;R!A;6UE;F0@(B5S(BX`)7,@=VES:&5S('1O
M(&UA:V4@>6]U(&%W87)E(&]F("(E<R(N`"5S('=I<VAE<R!T;R!R96-E:79E
M('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@(B5S(BX`)7,G<R!!9&1R
M97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K
M;&ES=``E<SH@)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"5S.B!4
M:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O
M(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BX`*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X
M="!S8W)E96XN*0`H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O
M('1H92!C;VUP;W-E('-C<F5E;BXI`"A(5$U,*0`H4&QA:6X@5&5X="D`*%)E
M='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL
M(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E
M;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*0`H4V5N9"!M97-S86=E
M(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#
M:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L
M:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S
M96QE8W0@861D<F5S<RAE<RD@*@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E
M<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@;65S
M<V%G92!H87,@8F5E;B!D96QE=&5D+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P
M;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BX`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`Q
M(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@<W!A;2X`,3`P(&-H87)A8W1E<G,`,3`P,"!C:&%R86-T97)S`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#(U,"!C:&%R
M86-T97)S`#4P,"!C:&%R86-T97)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D`$$@;&%R9V4@:6UA9V4@;F%M960@)7,@:7,@871T
M86-H960@=&\@=&AI<R!M97-S86=E+@!!(&UE<W-A9V4@>6]U(&AA=F4@<V5N
M="!H87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@
M=&AE(')E8VEP:65N="X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT
M(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]0
M30!!3D0`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O
M='1O;0!!8G-M:61D;&4`06-C97!T(&%N9"!A9&0@=&\@;7D@8V%L96YD87(`
M06-C97!T(')E<75E<W0`06-C97!T960`06-C97!T960Z(`!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!0
M87-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N="=S(&YA;64Z`$%C8V]U
M;G1I;F<`06-T:6]N<P!!9&0`061D("5S('1O(&UY($%D9')E<W,@0F]O:P!!
M9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z
M`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD
M(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B
M`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!
M9&0@<&%I<@!!9&0@<V]U<F-E`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<@!!9&0@=&AI<R!T;R!M>2!C86QE;F1A<@!!9&0@=&\@861D
M<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!T;R!M>2!C
M86QE;F1A<@!!9&0@=7-E<@!!9&1E9"`B)7,B(&%S(&%N(&%T=&%C:&UE;G0N
M`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@
M861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES<&QA
M>2!W:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@:&5A
M9&5R(&]N(&$@;F5W(&QI;F4I/"]E;3X`061D:71I;VYA;"!I;F9O<FUA=&EO
M;B!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E
M=&%I;',`061D:71I;VYA;"!M97-S86=E(&1E=&%I;',`061D:71I;VYA;"!M
M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`061D:71I;VYA;"!M
M97-S86=E(&5R<F]R(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E(&5R<F]R
M(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`061D<F5S<P!!9&1R97-S($)O
M;VL`061D<F5S<R!";V]K<P!!9&1R97-S97,@=&\@0D-#(&%L;"!M97-S86=E
M<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W
M(&QI;F4I/"]E;3X`061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H
M:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S
M<R!O;B!A(&YE=R!L:6YE*3PO96T^`$%D;6EN:7-T97(@+2!S970@<&5R;6ES
M<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H
M86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT
M.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@
M4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL(&UE<W-A9V5S(&EN('1H
M92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O
M(&]N92!-0D]8(&9I;&4Z`$%L;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L
M9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E
M;&5T960N`$%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E
M<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL(&]L9"!S96YT+6UA
M:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E
M;&5T960N`$%L;"!R:6=H=',@;VX@9F]L9&5R("(E<R(@<W5C8V5S<V9U;&QY
M(')E;6]V960@9F]R('5S97(@(B5S(BX`06QL;W<@1F]L9&5R($-R96%T:6]N
M/P!!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I
M;&)O>#\`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%L=&5R;F%T:79E('!A
M<G1S(&9O<B!T:&ES('-E8W1I;VXZ`$%L=V%Y<P!!;'=A>7,@<V%V92!A='1A
M8VAM96YT<P!!;65R:6-A;B!386UO80!!;B!E<G)O<B!O8V-U<F5D('=H:6QE
M(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0
M('-E<G9E<B!S86ED.B``06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D
M+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;B!U;FMN;W=N(&5R
M<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N;W1E+@!!;B!U
M;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T
M87-K+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`
M06YS=V5R`$%N<W=E<F5D`$%N<W=E<F5D(&UE<W-A9V5S`$%N=&%R8W1I8V$`
M06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,
M:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!&:6QT97)S`$%P<&QY
M($9I;'1E<G,@=&\@)7,`07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN
M9R!O;C\`07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I
M<W!L87EE9#\`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X
M:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AI<R!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N/P!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME
M>3\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A
M:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I`$%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!D;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H97-E(&UE<W-A
M9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L
M971E('1H:7,@871T86-H;65N=#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/P!!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\`07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/P!!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E
M(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H
M:7,@;65S<V%G92!A<R!I;FYO8V5N=#\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\`07)G96YT:6YA`$%R
M;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)R:79A;"!4:6UE`$%R=`!!
M<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I
M82]086-I9FEC(%)E9VEO;@!!<VL`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@
M8V]L=6UN<P!!='1A8V@@1FEL97,`071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'
M4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\`071T86-H960@1FEL93H`
M071T86-H960@9FEL92`B)7,B(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ
M92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+@!!='1A8VAE9"!I<R!A(')E
M<&QY('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N="X`071T86-H;65N
M=`!!='1A8VAM96YT("5S(&1E;&5T960N`$%T=&%C:&UE;G0@26YF;W)M871I
M;VX`071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N="!T
M>7!E`$%T=&%C:&UE;G1S`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+@!!='1E;F1E97,`071T96YT:6]N`$%T=')I8G5T97,`075G=7-T`$%U<W1R
M86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VEM<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!
M=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H
M7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T
M:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T
M:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`075T;VUA=&EC86QL>2!S
M:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I
M<R!I;B!M>2!A9&1R97-S8F]O:S\`079A:6QA8FQE($%D9')E<W,@8F]O:W,Z
M`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ
M86X`0D]&2"!%>&-U<V5S`$)A8U]K('1O("5S`$)A8VL@=&\@)7,`0F%C:R!T
M;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@`0F%C:R!T;R!4:')E860@
M1&ES<&QA>0!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A9"!L;V=I
M;B!N86UE(&]R('!A<W-W;W)D+@!"860@;W(@;6%L9F]R;65D(')E<75E<W0N
M(%-E<G9E<B!297-P;VYD960Z("5S`$)A9"!R97%U97-T.B`E<RX`0F%H86UA
M<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R
M8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`$)A<V5L:6YE`$)C8P!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;&]W(&ES
M('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A
M9V4N`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L86-K;&ES=`!"
M;&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C
M:R!3971T:6YG<P!";&]C:R!4>7!E`$)L;V-K(&EM86=E<R!I;B!(5$U,(&UE
M<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D
M/P!";V1Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T
M:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H
M`$)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G90!";W1S
M=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I
M86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA
M`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-204TM
M340U(&]R($1)1T535"U-1#4@<F5Q=6ER97,@=&AE($%U=&A?4T%33"!P86-K
M86=E('1O(&)E(&EN<W1A;&QE9"X`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0U]H87)S970`0V%C:&4@:6YI="!W
M87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE
M<F]O;@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E
M<BX`0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z
M(`!#86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S
M(&]F('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="!M86EL8F]X+@!#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#
M86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL
M92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!-97-S86=E`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E
M<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+@!#86YN;W0@9&5L971E
M(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T
M96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-C`$-E;&P@4&AO
M;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T
M:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM
M,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T
M:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#97)T:69I8V%T
M92!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T
M(&5N86)L960@;VX@=&AI<R!S97)V97(N`$-H860`0VAA:7(@4&5R<V]N`$-H
M86YG90!#:&%N9V4@06QL`$-H86YG92!&;VQD97(`0VAA;F=E(%EO=7(@4&%S
M<W=O<F0`0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY
M(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G
M97,@87)E('-O<G1E9"X`0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@
M<V5T=&EN9W,N`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E
M;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA
M:6QS+@!#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P
M;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAA<F%C=&5R<R!T;R!D:7-P
M;&%Y.@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-
M86EL`$-H96-K(%]!;&PO3F]N90!#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO
M=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O;3H`0VAE8VL@<W!E;&QI;F<@8F5F
M;W)E('-E;F1I;F<@82!M97-S86=E/P!#:&EL90!#:&EN80!#:&EN97-E(%-I
M;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`
M0VAO;W-E($%C=&EO;CH`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!M
M86EL('-E<G9E<CH`0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S
M<R!T;R!T:&4@<FEG:'0Z`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI
M<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@
M861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N`$-H
M;V]S92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE
M;B!E>'!A;F1I;F<@861D<F5S<V5S+@!#:')I<W1M87,@27-L86YD`$-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F
M9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A
M<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K("5S
M('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R
M(&)R;W=S97(@8V%N('9I97<N`$-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I
M;6%G92X`0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+@!#
M;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I
M;F1O=RX`0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM
M86=E+@!#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T
M+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@:&5R
M92!T;R!32$]7('1H92!);6%G97,`0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L
M96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD
M<R!T;R!S96%R8V@N`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K('1O(%-A=F4@
M4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VL`0VQI8VL@=&\@
M4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S
M($)O;VL`0VQI8VMA=&5L;"!V:6$@2%144`!#;&EC:VEN9R!O;B!T:&4@861D
M<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R
M`$-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G
M92!T;R!B92!R96%D`$-L;W-E`$-L;W-E(%=I;F1O=P!#;&]S92!T:&ES('=I
M;F1O=P!#;&]S960@1F]L9&5R`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y
M`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E`$-O;&QA<'-E($%L
M;`!#;VQL87!S92!!;&P@1F]L9&5R<P!#;VQL87!S92!&;VQD97(`0V]L;&%P
M<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#
M;VQO<B!);F1I8V%T;W(Z(`!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO
M;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@
M4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M
M<&QE=&5D`$-O;7!O<V4@86YO=&AE<B!M97-S86=E`$-O;7!O<V4@;65S<V%G
M97,@:6X@82!S97!A<F%T92!W:6YD;W<_`$-O;7!O<V4@;65S<V%G97,@=VET
M:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S
M('1H92!F96%T=7)E*3\`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS
M`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@
M<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#
M;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N
M9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+@!#;VYF:6=U<F4@
M;6%I;"!P<F5V:65W(&]P=&EO;G,N`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T
M:6]N(&1R;W!P960@8GD@24U!4"!S97)V97(N`$-O;FYE8W1I;VX@9F%I;&5D
M+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@
M9F%I;&5D`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M
M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;VYT
M<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!3+TU)344@<W5P<&]R
M="!F;W(@)7,N`$-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E
M<R!S96%R8VAI;F<N`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H
M96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W
M:&5N(&ET(&%R<FEV97,N`$-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT
M;R!G<F%P:&EC86P@;VYE<S\`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O
M<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W!Y('1O(&9O;&1E<@!#
M;W)R96-T`$-O<G)E8W1E9"!497AT`$-O<W0@240`0V]S=&$@4FEC80!#;W1E
M(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N
M`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L
M9"!N;W0@8V]M<&QE=&4@<F5Q=65S="X@4F5A<V]N($=I=F5N.B`E<P!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@8W)E871E('1H
M92!61E,@8F%C:V5N9#H@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z
M(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N
M(%1H92!S97)V97(@<V%I9#H@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&5X96-U=&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RX`0V]U;&0@;F]T(&5X=')A8W0@=&AE
M(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="X`
M0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE
M(%II<"!A<F-H:79E+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S
M<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D
M:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E
M<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U
M8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B
M)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!O<&5N('-E8W5R92!C;VYN
M96-T:6]N('1O('1H92!)34%0('-E<G9E<BX@)7,@.B`E<RX`0V]U;&0@;F]T
M(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O
M=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@
M=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@
M04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E
M=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R
M+@!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O
M=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER
M("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K
M(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N
M`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I
M;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X
M=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!&;VQD97(`0W)E871E
M($ME>7,`0W)E871E(&$@3F5W($%C8V]U;G0`0W)E871E(&$@;&EN:P!#<F5A
M=&4@82!N97<@4W!A;2!F;VQD97(`0W)E871E(&$@;F5W(&1R869T<R!F;VQD
M97(`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O
M;&1E<@!#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I
M;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T
M(&ET(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@;F5W
M('-T871I;VYE<GD`0W)E871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N
M<V5S+@!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#
M<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S
M97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@
M:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!A8V-E
M<W,@=&\@)7,`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U
M<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R
M(&%C8V]U;G1S+@!#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN`$-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S
M96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C
M:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A
M:6QY`$1A=%]E`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A
M=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#
M;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8VQI
M;F5D.B``1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$
M969A=6QT($ED96YT:71Y`$1E9F%U;'0@4V5A<F-H($9I96QD`$1E9F%U;'0@
M4VAE;&P`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I
M;F<@9&ER96-T:6]N.@!$969I;FET:6]N<P!$96QE9V%T960`1&5L971E`$1E
M;&5T92`E<R!0=6)L:6,@2V5Y`$1E;&5T92!#96QL`$1E;&5T92!#=7)R96YT
M($ME>7,`1&5L971E($9O;&1E<BAS*0!$96QE=&4@1W)O=7``1&5L971E($QO
M9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@4V5L96-T960@1F]L9&5R<P!$
M96QE=&4@4W1A=&EO;F5R>0!$96QE=&4@5FER='5A;"!&;VQD97(`1&5L971E
M(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE
M=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!F971C:&5D
M(&UE<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\`1&5L971E(&9R;VT@;7D@
M8V%L96YD87(`1&5L971E(&UE<W-A9V5S`$1E;&5T92!O;&0@;&EN:V5D(&%T
M=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(&]L9"!S
M96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L
M971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S<&%M(&UE<W-A9V5S`$1E
M;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E
M;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9`!$96QE=&5D(&UE<W-A9V5S
M`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L971E9"!T
M:&4@871T86-H;65N="`B)7,B+@!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A
M9V5S`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$96YY(')E<75E<W0`1&5N>2!R
M97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VX`1&5S8V5N9&EN9P!$
M97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS`$1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`
M1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT
M.B``1&ED(&YO="!A='1A8V@@(B5S(B!A<R!T:&4@9FEL92!W87,@96UP='DN
M`$1I;2!S:6=N871U<F5S/P!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E
M8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&-O;F9I
M<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\`1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@
M9F]R;6%T`$1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E`$1I<W!L87D@<&]P
M+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\`1&ES<&QA>2!T:&4@(D5M
M<'1Y(%-P86TB(&QI;FL@:6X@=&AE(&UE;G5B87(_`$1I<W!L87D@=&AE(")%
M;7!T>2!4<F%S:"(@;&EN:R!I;B!T:&4@;65N=6)A<C\`1&ES<&]S:71I;VX`
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O($Y/5"!M871C
M:`!$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!$;R!N;W0@
M9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M`$1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;@!$
M;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/P!$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H
M879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O;F4`1&]W;FQO860`1&]W;FQO
M860@)7,`1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870`1&]W;FQO860@06QL
M($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I`$1O=VYL;V%D($9O;&1E<BAS
M*0!$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T70!$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$;W=N;&]A
M9"!I;B`N>FEP($9O<FUA=`!$<F%F=`!$<F%F="!F;VQD97(`1')A9G1S(&9O
M;&1E<CH`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$4M;6%I;"!!9&1R
M97-S`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S
M('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%3D0`15)2`$524D]2.B!9
M;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`16-U861O<@!%
M9&ET`$5D:70@0FQA8VML:7-T`$5D:70@0FQO8VL`161I="!&:6QT97)S`$5D
M:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!396%R8V@@475E<GD`161I="!6
M:7)T=6%L($9O;&1E<@!%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@
M9F]R("5S`$5D:70@5VAI=&5L:7-T`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`
M161I="!Y;W5R(&)L86-K;&ES=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D
M:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@
M86-C;W5N=',N`$5D:70@>6]U<B!W:&ET96QI<W0`161U8V%T:6]N`$5G>7!T
M`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S
M<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF
M:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1I
M960@86QL(&UE<W-A9V5S(&9R;VT@)7,N`$5M<'1I960@86QL(&UE<W-A9V5S
M(&9R;VT@5FER='5A;"!4<F%S:"!&;VQD97(N`$5M<'1Y($9O;&1E<BAS*0!%
M;7!T>2!396QE8W1E9"!&;VQD97)S`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T
M>2!?4W!A;0!%;7!T>2!?5')A<V@`16UP='D@;65S<V%G92X`16UP='D@<F5S
M=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(%!'4"!F=6YC=&EO;F%L
M:71Y/P!%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!M97-S86=E('!R979I97=S/P!%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/P!%;F-R7WEP=&EO;B!/<'1I;VYS`$5N8W)Y<'1E9`!%
M;F0`16YD(&9O<G=A<F1E9"!M97-S86=E`$5N9"!M97-S86=E`$5N9"!M97-S
M86=E(&9R;VT@)7,`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@4&%S
M<W!H<F%S90!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT
M97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W
M.@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(`16YT
M97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(`16YT97(@
M=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(`16YT97(@
M=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<@!%;G1I<F4@365S
M<V%G90!%;G1R>2`B)7,B('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE
M(&%D9')E<W,@8F]O:P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R
M`$5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S(#H@)7,N`$5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R
M<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%
M=&AN:6,`175R;W!E`$5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+@!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S
M`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%
M>'!A;F0@06QL`$5X<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L9&5R`$5X
M<&%N9"!.86UE<P!%>'!A;F0@4VED96)A<@!%>'!A;F0@;F%M97,@:6X@=&AE
M(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U
M;F0_`$5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@
M:6X@=&AE(&9O;&1E<G,@=FEE=S\`17AP86YD:6YG`$5X<&5C=&5D("<I)P!%
M>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER
M871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E
M='5P`$9?971C:"!-86EL`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B
M)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E
M(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N
M`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S
M("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A
M>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=&-H($UA
M:6P`1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\`1F5T8V@@;65S
M<V%G97,@=7!O;B!L;V=G:6YG(&]N/P!&971C:&5D("5D(&UE<W-A9V5S(&9R
M;VT@)7,`1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<P!&971C:&UA:6PZ(`!&
M971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RX`1F5W(%-H;W=E<G,`1F5W(%-N
M;W<@4VAO=V5R<P!&:5]L=&5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#
M2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`
M1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&
M:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"X`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%-E='1I;F=S`$9I;'1E
M<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\`1FEL=&5R('-U<'!O
M<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`$9I;'1E<G,`1FEL=&5R
M<R!.3U0@06-T:79E`$9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G90!&:6YD
M`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!-86EL8F]X(%!A9V4`1FER<W0@
M4&%G90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O7W)W
M87)D`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]L9&5R($%C=&EO
M;G,@+2!#;VYF:7)M871I;VX`1F]L9&5R($YA=FEG871O<@!&;VQD97(@4W5M
M;6%R>0!&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"X`1F]L9&5R('5S
M92!I<R!N;W0@96YA8FQE9"X`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@
M<&%S<W=O<F0_`$9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL
M8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y`$9O<FUS`$9O<G1U
M;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O
M<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R9&5D(&UE
M<W-A9V4@9G)O;2`E<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC
M92P@365T<F]P;VQI=&%N`$9R964O0G5S>2!297%U97-T(%)E<W!O;G-E`$9R
M96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,`1G)O7VT`1G)O;0!&<F]M($%D9')E<W,`1G)O;2!T:&4@
M`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=V0Z`$9W
M9#H@`$9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S`$=A8F]N`$=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%L($]P
M=&EO;G,`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D
M90!'96]R9VEA`$=E<FUA;GD`1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!
M4"!O;FQY*0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T
M:6]N<P!';P!';R!T;R!-97-S86=E`$=O('1O(&%D9')E<W,@8F]O:R!E;G1R
M>2!O9B`B)7,B`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R
M86YT(&%C8V5S<P!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW
M*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D
M96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I
M;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2$52
M10!(5$U,`$A434P@5F5R<VEO;B!O9B!-97-S86=E`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A
M9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(
M96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&5R92!I<R!T:&4@;65S
M<V%G92!Y;W4@=V5R92!C;VUP;W-I;F<Z`$AI9&1E;@!(:61D96X@:6X@5&AR
M96%D(%9I97<`2&ED92!$96QE=&5D`$AI9&4@56YS=6)S8W)I8F5D`$AI9V@`
M2&EG:"!0<FEO<FET>0!(:6=H97-T`$AO7VUE`$AO;'D@4V5E("A6871I8V%N
M($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y
M`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO
M;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@
M;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@
M;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK
M;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A
M9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A
M<V4@<F5P;W)T(2D`2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H
M;65N=',_`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@=&\@871T
M<FEB=71E('%U;W1E9"!L:6YE<R!I;B!A(')E<&QY`$AU;6ED:71Y`$AU;6ED
M:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4`!)34%0("A!=71O($1E=&5C
M="!0<F]T;V-O;',I`$E-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO
M;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,`24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!O
M=F5R(%-33`!)34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T
M92D`24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960I`$E-05`@<V5R=F5R(&-L
M;W-E9"!T:&4@8V]N;F5C=&EO;BX`24U!4"P@;F\@5$Q3`$E-05`O4$]0,R!-
M86EL(%-E<G9E<G,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC
M96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT
M`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!U<VEN
M9R!34TP@;W(@5$Q3+"!Y;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E
M>'1E;G-I;VX@;&]A9&5D+@!)9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E
M<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S="$`268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26=N;W)E`$EG;F]R92!!;&P`26UA
M9V4`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@
M9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0`26UP;W)T($ME>0!);7!O<G0@2V5Y<&%I<@!);7!O
M<G0@365S<V%G97,`26UP;W)T(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L($-E
M<G1I9FEC871E`$EM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D`26UP
M;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!3
M+TU)344@0V5R=&EF:6-A=&5S`$EM<&]R="!0=6)L:6,@2V5Y`$EM<&]R="!0
M=6)L:6,@4$=0($ME>0!);7!O<G0@4'5B;&EC(%,O34E-12!+97D`26UP;W)T
M(%,O34E-12!+97D`26UP;W)T(&UB;W@@1FEL90!);7!O<G0@;6)O>"!F:6QE
M("5S(&EN=&\@9F]L9&5R("5S+@!);7!O<G0L(%-T97`@)60`26UP;W)T86YT
M`$EM<&]R=&%N="!M97-S86=E<P!);7!O<G1E9"`E9"!M97-S86=E<R!F<F]M
M("5S+@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);B!0
M<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8F]X`$EN8VQU9&4@82!B<FEE
M9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\`26YC;'5D92!O
M<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD
M:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);F9O<FUA=&EO;B!O;B`E
M<R!0=6)L:6,@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@
M2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97D`26YL:6YE
M`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!#97)T:69I8V%T92!(97)E
M`$EN<V5R="!);6%G90!);G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y
M($AE<F4`26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS
M97)T(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS97)T(%1A8FQE`$EN<V5R="!7
M96(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T
M97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R
M96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@
M96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE
M=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F
M;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`
M26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T
M('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W
M(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C
M=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO
M9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G
M97(`26YT96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T
M:&ES(&-O;7!O;F5N="X`26YV86QI9"!!9&1R97-S`$EN=F%L:60@4F5M;W1E
M($UA:6QB;W@`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A
M=&-H($E$+@!);G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@
M)7,N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I
M;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&ME>0!)
M;G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D
M+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED
M+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!E
M<G-O;F%L(%!'4"!P<FEV871E(&ME>2X`26YV86QI9"!P97)S;VYA;"!01U`@
M<'5B;&EC(&ME>2X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O
M=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@
M;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D
M92!D871A+@!);G9E;G1O<GD`26YV97)T`$EN=F5R="!S96QE8W1I;VX`27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-
M86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A
M;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*
M4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E
M;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`
M2T(`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S
M`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@
M5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@
M=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y(&=E;F5R871I
M;VX_`$ME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@
M:7,@;F]T(&5N86)L960@;VX@=&AI<R!S97)V97(N`$ME>2!I;7!O<G0@:7,@
M;F]T(&%V86EL86)L92X@66]U(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN
M960@=&\@861D('EO=7(@8V]N=&%C=',N`$ME>2!S=6-C97-S9G5L;'D@<V5N
M="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P
M=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA
M7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L
M:6,`3&%S="!(86QF`$QA<W0@36%I;&)O>"!086=E`$QA<W0@4&%G90!,87-T
M(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S
M`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA
M`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT
M(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R
M`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO
M=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK($%T=&%C:&UE;G1S/P!,:6YK
M('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M
M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK960@871T86-H;65N=',@
M87)E(&9O<F)I9&1E;BX`3&EN:W,`3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,`
M3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,
M:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI
M<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R
M965N/R`H:68@9&ES86)L960L('EO=2!W:6QL(&]N;'D@<V5E(&-O;G1A8W1S
M('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2D`3&ES="U!<F-H:79E
M`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M
M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!I;B!T:&4@2&5A
M9&5R`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A
M='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!-86EL8F]X.@!,;V-A
M;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@
M:6X@=&\@)7,`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T
M`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=R!0<FEO<FET
M>0!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W
M97(@<F]M86X@;G5M8F5R<P!,;W=E<W0`3'5X96UB;W5R9P!-30!-3U1$`$U3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O
M`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-
M86-I;G1O<V@@1FEL90!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI
M;@!-86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T
M;SH`36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS
M`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`
M36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-
M87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K($%L;"!-97-S86=E
M<R!I;B!&;VQD97(@87,@4V5E;@!-87)K($%L;"!-97-S86=E<R!I;B!&;VQD
M97(@87,@56YS965N`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O
M9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`36%R:R!M97-S86=E
M<R!A<R!S965N/R`H24U!4"!O;FQY*0!-87)K('-I;7!L92!M87)K=7`_`$UA
M<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S
M`$UA<G1I;FEQ=64`36%T8V@@06QL(%%U97)I97,`36%T8V@@06YY(%%U97)Y
M`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL
M;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!!='1A8VAM96YT(%-I>F4`36%X:6UU;2!.=6UB97(@;V8@1F]L
M9&5R<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@
M;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N
M`$UA>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE(')E86-H960N`$UA>0!-
M87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!&;VQD97(@3&ES=`!-96YU
M(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!#;VUP;W-I=&EO
M;@!-97-S86=E($1A=&4`365S<V%G92!/<'1I;VYS`$UE<W-A9V4@4V5A<F-H
M`$UE<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9E<FEF:65D
M(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O
M=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!6:65W:6YG`$UE<W-A9V4@
M97AP:7)E9"X`365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G
M92!F<F]M("5S`$UE<W-A9V4@:&%S(&%T=&%C:&UE;G1S`$UE<W-A9V4@:7,@
M96YC<GEP=&5D`$UE<W-A9V4@:7,@<VEG;F5D`$UE<W-A9V4@;6%T8VAE<P!-
M97-S86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY+@!-97-S86=E('-E;G0@
M<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S`$UE<W-A9V4@<V5N
M="!S=6-C97-S9G5L;'DN`$UE<W-A9V4@='EP90!-97-S86=E<R!P97(@<&%G
M92!I;B!T:&4@;6%I;&)O>"!V:65W+@!-97-S86=E<R!T;P!-971A<B!796%T
M:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T
M:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F
M:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER
M<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%
M05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL
M92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y`$UO9&EF>2!5
M4DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L
M:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA
M<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N`$UO<F4@=&AA;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE
M;&0@(B5S(BX`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-
M;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T;'D@4W5N;GD`36]V90!-;W9E
M($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`
M36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO8V5N
M="!M97-S86=E<R!T;R!)3D)/6`!-;W9E('1O(&9O;&1E<@!-;W9E('5P`$UO
M>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P
M(%5+(&UA<`!-=6QT:7!A<G0O86QT97)N871I=F4`375L=&EP;&4@365S<V%G
M92!6:65W`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U
M;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA
M;FUA<@!.3RP@22!$;R!.3U0@06=R964`3D].10!.3U1%`$YA;64`3F%M92!A
M;F0O;W(@96UA:6P@8V%N;F]T(&)E(&5M<'1Y`$YA;6EB:6$`3F%U<G4`3F5E
M9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL
M;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=F5R('-A=F4@871T
M86-H;65N=',`3F5W`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!&
M;VQD97(`3F5W($UA:6P`3F5W($UE<W-A9V4`3F5W($UE<W-A9V4@=&\@)7,`
M3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`
M3F5W(&UE<W-A9V5S`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E
M>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W
M:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H
M87-E<P!.97AT($UE<W-A9V4`3F5X="!086=E`$YE>'0@;W!T:6]N<P!.97AT
M/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO($-E
M<G1I9FEC871E(&9O=6YD`$YO($5N8W)Y<'1I;VX`3F\@2V5Y<R!I;B!+97ER
M:6YG`$YO($UE<W-A9V5S`$YO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.
M;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT`$YO(%!R979I97<@5&5X
M=`!.;R!0=6)L:6,@2V5Y<R!&;W5N9`!.;R!3+TU)344@<'5B;&EC(&ME>2!I
M;7!O<G1E9"X`3F\@871T86-H;65N=',@9F]U;F0N`$YO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO
M(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO
M(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-
M0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A
M;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@
M<W5P<&QI960N`$YO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE
M('!U8FQI8R!K97DN`$YO(&9I;&4@=7!L;V%D960`3F\@9F]L9&5R('-E;&5C
M=&5D+@!.;R!F;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I
M;"X`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!F;VQD97)S('=I=&@@
M;F5W(&UE<W-A9V5S`$YO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,`
M3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I
M;VX@<')O=FED960N`$YO(&UE<W-A9V4@8F]D>2!T97AT`$YO(&UE<W-A9V4@
M<F5T=7)N960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&UE<W-A9V5S(&UA
M=&-H960@>6]U<B!S96%R8V@N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB
M97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H
M92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!P97)S;VYA;"!0
M1U`@<')I=F%T92!K97D@:6UP;W)T960N`$YO('!E<G-O;F%L(%!'4"!P=6)L
M:6,@:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A
M=&5S(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!P<FEV871E(&ME>2!E>&ES=',@
M<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`3F\@
M<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.
M;R!S:61E<P!.;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"X`
M3F\@<W!E;&QI;F<@97)R;W)S`$YO('-U8V@@9FEL90!.;R!S=6=G97-T:6]N
M<P!.;R!S=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U
M;&0@8F4@9F]U;F0N`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92X`3F\@=7-E<B!S<&5C:69I960N`$YO('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE
M9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO;B!087)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I
M;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`
M3F]R;6%L`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)
M<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@1&5L971E
M9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&$@
M9&ER96-T;W)Y`$YO="!A('9A;&ED('!U8FQI8R!K97DN`$YO="!D96QE=&5D
M(&UE<W-A9V5S`$YO="!I;7!L96UE;G1E9"X`3F]T(&EM<&]R=&%N="!M97-S
M86=E<P!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&4@=&AA="!T:&ES(&-A
M;B!T86ME('-O;64@=&EM90!.;W1E<P!.;W1H:6YG`$YO=&AI;F<@=&\@8G)O
M=W-E+"!G;R!B86-K+@!.;W1I9FEC871I;VXZ($QI;FME9"!A='1A8VAM96YT
M(&1O=VYL;V%D960`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T
M97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!M;VYT:',@=&\@:V5E
M<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN
M`$YU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D
M96QE=&EN9R!M;VYT:&QY+@!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S
M<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/
M2P!/4@!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E
M;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+@!/;&0@;65S<V%G97,`3VQD('!A<W-W;W)D`$]L9"!P
M87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VQD('-E;G0M;6%I;"!F;VQD97)S
M(&)E:6YG('!U<F=E9"X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+@!/;FQY(&1I<W!L87D@9F]L9&5R<R!W:71H('5N
M<F5A9"!M97-S86=E<R!I;B!T:&5M/P!/;FQY(&]F9F5N<VEV92!F;W)T=6YE
M<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE(&9O
M;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+@!/;FQY
M('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E
M(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/
M<&5N($9O7VQD97(`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="X`3W!E;F5D($9O;&1E<@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T
M:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C;W5N=',`
M3W1H97(@3W!T:6]N<P!/=71B;W5N9"!397)V97(`3W=N97(@4&5R;6ES<VEO
M;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z
M.DUA:6P@8F%C:V5N9`!01U``4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%
M;F-R>7!T($UE<W-A9V4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!%<G)O<CH@
M`%!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV
M871E(&ME>2X`4$=0($]P=&EO;G,`4$=0(%!A<W-P:')A<V4@26YP=70`4$=0
M(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`4$=0(%!U8FQI8R!+97D`4$=0(%!U8FQI8R!+97D@
M5&5X=`!01U`@4'5B;&EC($ME>2!F;W(@(B5S("@E<RDB('=A<R!S=6-C97-S
M9G5L;'D@861D960N`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@9&5L971E9"X`4$=0(%!U8FQI8R!+97ER:6YG`%!'4"!3:6=N
M($UE<W-A9V4`4$=0(%-I9VXO16YC<GEP="!-97-S86=E`%!'4"!3:6=N960O
M16YC<GEP=&5D($1A=&$`4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A
M9&1E9"X`4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@
M<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`4$=0('-U<'!O
M<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG
M;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4$=0('-U<'!O<G0@
M:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA
M8FQE('1O(&)E(&1E8W)Y<'1E9"X`4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P
M=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U
M<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S
M="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"!F96%T=7)E
M<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`4$A0($-O9&4`4$A0(%-H96QL
M`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@
M4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U`S`%!/4#,@*$%U
M=&\@1&5T96-T(%!R;W1O8V]L<RD`4$]0,R!O=F5R(%-33`!03U`S(&]V97(@
M4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92D`4$]0,R!O=F5R(%-33"`H
M<V5L9BUS:6=N960I`%!/4#,L(&YO(%1,4P!03U-)6"!E>'1E;G-I;VX@:7,@
M;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%G92`E9"!O9B`E9`!086=E
M('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E`%!A9V4@=VET:"!T:&4@
M3&%S="!5;G-E96X@365S<V%G90!086MI<W1A;@!086QA=0!086QE<W1I;FEA
M;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A
M`%!A<F%G=6%Y`%!A<G0H<RD`4&%R=&QY($-L;W5D>0!087-S<&AR87-E`%!A
M<W-P:')A<V4@*$%G86EN*0!087-S<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO
M861E9"X`4&%S<W!H<F%S93H`4&%S<W!H<F%S97,@8V%N;F]T(&)E(&5M<'1Y
M`%!A<W-P:')A<V5S(&1O(&YO="!M871C:`!087-S=V]R9`!087-S=V]R9"!C
M:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W
M;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A
M<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R
M9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R
M;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E
M<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS
M`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O<B!T
M:&ES('5S97(@8V%N;F]T(&)E(&-H86YG960N`%!E<G-O;F%L`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN`%!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S
M<V9U;&QY+@!097)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O
M<G1E9#H@`%!E<G-O;F%L(%,O34E-12!K97ES(&1E;&5T960@<W5C8V5S<V9U
M;&QY+@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A
M:7)N`%!I>&5L<P!0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE
M<R!A;F0@9F]R=V%R9',_`%!L86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4`
M4&QA=&ET=61E<P!0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@5&AI<R!R97%U
M:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E9"!S;W5N9"!F
M:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A;F0@36%C+"!B=70@
M;W1H97(@<&QA=&9O<FUS('=I;&P@<F5Q=6ER92!A('!L=6=I;BX`4&QE87-E
M(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@
M96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D
M<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU
M;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92X`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L
M9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.@!0;&5A<V4@96YT97(@
M=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@
M=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@
M<&5R("5S('-E<W-I;VXN`%!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F
M;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E
M9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO
M;BX`4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG('EO
M=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@8V]O:VEE<R!!3D0@
M>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@
M>6]U('=I;&P@:&%V92!T;R!L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I
M;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@
M:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A
M;GD@:6YC;VYV96YI96YC92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D+@!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE+@!0;&5A<V4@<F5A9"!T:&4@9F]L
M;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O
M('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@
M:6YV86QI9"!A9&1R97-S97,N`%!L96%S92!S96QE8W0@82!F;VQD97(@8F5F
M;W)E('EO=2!P97)F;W)M('1H:7,@86-T:6]N+@!0;&5A<V4@<V5L96-T(&%T
M(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+@!0;&5A<V4@<V5L96-T(&]N
M;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN`%!L96%S92!S96QE
M8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#H`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0;W=E<F5D(&)Y($AO<F1E`%!R96-E9&4@>6]U
M<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\`4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC90!0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E
M.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`
M4')E=FEO=7,@365S<V%G90!0<F5V:6]U<R!086=E`%!R979I;W5S(&]P=&EO
M;G,`4')I;G0`4')I;G0@9&]C=6UE;G0`4')I;W)I='D`4')I=F%T92!+97D`
M4')I=F%T92!+97D@4&%S<W=O<F0`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@
M:7,@<V5N=#L@9&5F875L="!T;R!.3P!0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453`%!R;VUP="!T97AT
M`%!R;W1O8V]L.@!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U
M8FQI8R!+97D@26YF;P!0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA
M<R!B965N(&1I<V%B;&5D+@!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)?9V4@1&5L
M971E9`!0=7)G92!$96QE=&5D`%!U<F=E($9O;&1E<BAS*0!0=7)G92!4<F%S
M:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S`%!U<F=E(&UE<W-A9V5S(&EN
M(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N
M`%!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/P!0=7)G
M:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+@!0=7)G:6YG(#$@
M;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BX`46%T87(`475E<GD`475O=&$`
M475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`%%U;W1A
M('-T871U<SH@)2XR9DU"("\@3D\@3$E-250`475O=&$@<W1A='5S.B!.3R!,
M24U)5`!1=6]T:6YG("5F.@!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I
M;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H
M;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N
M90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E8G5I;&0@1F]L9&5R(%1R964`4F5C96EV960@3VX`
M4F5C96EV960@4VEN8V4`4F5C96EV960@56YT:6P`4F5D:7)E8U]T`%)E9&ER
M96-T`%)E9&ER96-T($UE<W-A9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E
M9&ER96-T:6YG(&9A:6QE9"X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F
M<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!&
M;VQD97(@5FEE=W,Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T
M:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296QO860@5FEE=P!296UA<FMS`%)E
M;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E;65M8F5R('1H
M92!L87-T('9I97<`4F5M;W1E($UA:6QB;W@Z`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!&:65L9"!&<F]M(%-E87)C:`!296UO
M=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V
M92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!296UO=F4@<V]U<F-E`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D
M92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@
M)7,`4F5N86UE($9O;&1E<BAS*0!296YA;64@<V5N="UM86EL(&9O;&1E<B!A
M="!B96=I;FYI;F<@;V8@;6]N=&@_`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F
M86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;%]Y('1O
M($QI<W0`4F5P;&%C92!W:71H.@!297!L>0!297!L>2!396YT+@!297!L>2!T
M;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2!T;R!,:7-T`%)E<&QY('1O($QI
M<W0Z`%)E<&QY('1O(%]!;&P`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE
M<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N
M`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`
M4F5P;'DM5&\`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S($EN;F]C96YT
M`%)E<&]R="!A<R!3<&%M`%)E<75E<W0@82!?4F5A9"!296-E:7!T`%)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`4F5Q=65S=&5D(&UE<W-A9V4@;F]T
M(&9O=6YD+@!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297%U:7)E9"!087)T:6-I<&%N
M=`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E
M<W!O;F1E;G0@4W1A='5S(%5P9&%T960N`%)E<W1O<F4@3&%S="!1=65R>0!2
M97-U;'1S`%)E<W5M90!297-U;64@>6]U<B!S97-S:6]N`%)E='5R;B!T;R`B
M365S<V%G92!#;VUP;W-I=&EO;B(`4F5T=7)N('1O($9E=&-H($UA:6P`4F5T
M=7)N('1O($]P=&EO;G,`4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@
M869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_
M`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A
M=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2
M:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2
M;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG
M:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&
M961E<F%T:6]N`%)W86YD80!3+TU)344`4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T($UE<W-A9V4`4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E`%,O34E-12!%<G)O<CH@`%,O34E-12!%<G)O<CH@3F5E
M9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4R]-24U%
M($]P=&EO;G,`4R]-24U%(%!A<W-P:')A<V4@26YP=70`4R]-24U%(%!E<G-O
M;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BX`4R]-24U%(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E
M<W-F=6QL>2!D96QE=&5D+@!3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L
M;'D@861D960N`%,O34E-12!0=6)L:6,@2V5Y<FEN9P!3+TU)344@4'5B;&EC
M+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N`%,O34E-12!3
M:6=N($UE<W-A9V4`4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E`%,O34E-
M12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!3+TU)344@
M<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE<W-A
M9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`4R]-24U%('-U<'!O<G0@
M:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D
M(&UE<W-A9V4@8V%N;F]T(&)E(&1I<W!L87EE9"X`4R]-24U%('-U<'!O<G0@
M:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N
M86)L92!T;R!B92!V97)I9FEE9"X`4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@
M<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES
M(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@
M;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%,O34E-12!F
M96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%--5%``
M4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(
M`%-50T-%4U,`4U]13"!3:&5L;`!37W5B:F5C=`!380!385]V92!A(&-O<'D@
M:6X@`%-A7W9E(&%S`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V
M:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L
M9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T
M96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3
M879E("5S`%-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M
M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`4V%V92!);6%G90!3879E($EM86=E
M(&EN($=A;&QE<GD`4V%V92!/<'1I;VYS`%-A=F4@4W1A=&EO;F5R>0!3879E
M(%]$<F%F=`!3879E(&%S`%-A=F4@9')A9G1S(&%S('5N<V5E;C\`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E(')E8VEP:65N
M=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_
M`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_`%-A=F4@<V5N="!M
M86EL/P!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@(B5S(BX`4V%V:6YG('1H92!D<F%F="!F86EL960N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%-C871T97)E9"!4
M+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@)7,`4V5A<F-H($5N9VEN
M97,`4V5A<F-H($]P=&EO;G,`4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`
M4V5L96-T($%N;W1H97(@06-C;W5N=`!396QE8W0@1FEL97,`4V5L96-T(&$@
M9&%T90!396QE8W0@82!F:65L9`!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L
M96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!S=&%T
M:6]N97)Y.@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@861D<F5S<R!B
M;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R
M97-S97,N`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A
M9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!A;B!O8FIE8W0`
M4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@
M9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BX`4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@;6%I;"!S97)V
M97(@='EP90!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;&5C=&5D($%D9')E<W,@8F]O:W,Z`%-E;F0@2V5Y('1O
M(%!U8FQI8R!+97ES97)V97(`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N
M9"!-97-S86=E`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N9"!M
M97-S86=E('=I=&AO=70@82!3=6)J96-T/P!396YD(')E860@<F5C96EP="!W
M:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/P!396YE9V%L`%-E;G-O<CH@
M`%-E;G0@;6%I;"!F;VQD97(`4V5N="!M86EL(&9O;&1E<CH`4V5P=&5M8F5R
M`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<@!3
M97)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO;@!397)V97(@9&%T82!W<F]N
M9R!O<B!N;W0@879A:6QA8FQE+@!397)V97(Z`%-E<W-I;VX@061M:6X`4V5S
M<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+@!3970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W
M:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N`%-E="!T:&4@6"U0
M<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F4@1F]L9&5R<P!3
M:&%R92!M86EL(&9O;&1E<G,`4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET
M:"!O=&AE<B!U<V5R<RX`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@
M86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=6QD
M(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D
M96X@8GD@9&5F875L=#\@270@8V%N(&)E('1O9V=L960@96%S:6QY('=H:6-H
M979E<B!Y;W4@8VAO;W-E+@!3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I
M;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\`4VAO=6QD('1H
M92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A
M9G0_`%-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D
M('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\`4VAO=P!3:&]W($%L;"!&
M;VQD97)S`%-H;W<@06QL($AE861E<G,`4VAO=R!$96QE=&5D`%-H;W<@3&EM
M:71E9"!(96%D97)S`%-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N`%-H
M;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,`4VAO=R!5;G-U8G-C<FEB960`
M4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT
M<R!F<F]M(&UE<W-A9V5S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`
M4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('!R979I97=S(&9O
M<B!U;G)E860@;65S<V%G97,@;VYL>3\`4VAO=R!P<F5V:65W<R!I;B!T;V]L
M=&EP<S\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!&971C:"!-86EL(&EC
M;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE($EM86=E<P!3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\`
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T;W1A;"!N
M=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/P!3:&]W('5P;&]A9`!3:&]W97)S
M`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y`%-H;W=N`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I
M;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VE?>F4`4VEE<G)A
M($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`
M4VEG;F5D`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K
M:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO
M=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z
M(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`
M4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@8GD@07)R:79A;`!3;W)T(&)Y
M($1A=&4`4V]R="!B>2!&<F]M($%D9')E<W,`4V]R="!B>2!-97-S86=E(%-I
M>F4`4V]R="!B>2!3=6)J96-T`%-O<G0@8GD@5&AR96%D`%-O<G0@8GD@5&\@
M061D<F5S<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3
M;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H
M97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E
M<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&%M
M(&9O;&1E<CH`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!E8VEA;"!#:&%R
M86-T97)S`%-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;FYO="!B92!E9&ET
M960N`%-P96QL($-H96-K`%-P96QL($-H96-K97(`4W!E;&P@8VAE8VL@8V]M
M<&QE=&4`4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C
M:&5C:VEN9RX`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P
M;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T`%-T87)T
M('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A=&EO;F5R>0!3=&%T:6]N97)Y
M(&YA;64Z`%-T871I;VYE<GD@='EP93H`4W1A=&EO;F5R>3H`4W1A='5S`%-T
M;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R
M:6YG(&QI<W0`4W1R:7`@071T86-H;65N=`!3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<P!3=')I<"!L:6YE8G)E86MS/P!3='EL92!;0U-370!3=0!3
M=6)?:F5C=`!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`
M4W5B:F5C="!&:65L9`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D
M("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@
M>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I8F4@=&\@
M1F]L9&5R*',I`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E
M9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A
M=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL
M>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O
M;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A
M=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V
M960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY
M('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5G
M9V5S=&EO;G,`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I
M<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3
M=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71C:"!#;VUP;W-I
M=&EO;B!-971H;V0`4W=I=&-H('1O($A434P@8V]M<&]S:71I;VX`4W=I=&-H
M('1O('!L86EN('1E>'0@8V]M<&]S:71I;VX`4W=I='IE<FQA;F0`4WEN8R!L
M;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I
M;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE(%!R
M;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5?>'0`5&5L97!H
M;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!4
M96UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D
M;6EN:7-T<F%T:6]N`%1E;G1A=&EV93H@`%1E;G1A=&EV96QY($%C8V5P="!R
M97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E<FUS(&]F(%-E<G9I8V4@
M9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP`%1E>'0`5&5X="!/;FQY
M`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N
M9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@1G)O
M;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z`%1H
M92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE
M($E-05`@<V5R=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A
M=71H96YT:6-A=&EO;B!M971H;V0@<V5L96-T960N(%!L96%S92!C;VYT86-T
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!)35-0(&QO9R!C;W5L
M9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86-I;G1O<V@@<F5S;W5R8V4@
M9F]R:P!4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL
M;V%D960@)7,N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N
M($5X:71I;F<N`%1H92!A8V-O=6YT("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4
M:&4@871T86-H;65N="!W87,@;F]T(&9O=6YD+@!4:&4@8F]T=&]M('-I9&4@
M;VYL>0!4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED`%1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE
M(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N`%1H
M92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N86UE9"!T;R`B
M)7,B+@!4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O
M('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960`5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N`%1H92!D<F%F="!H87,@8F5E;B!S879E9"!T
M;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E=F5N="!W87,@
M861D960@=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9I96QD("(E<R(@8V%N)W0@
M8F4@97AP86YD960N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQD97(@(B5S
M(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L9&5R("(E<R(@8V]N=&%I;G,@:6QL
M96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@<')O
M8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`
M5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@
M<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!D96QE=&5D
M(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N`%1H92!F
M;VQD97(@(B5S(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@9&5L971E9"X@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@
M=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S
M('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U
M8V-E<W-F=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M`%1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A
M<G0Z`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!I;6%G92!S879E('=I;F1O=R!C86X@;F]T
M(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R
M('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!I;6%G97,@=VEL;"!B92!D
M:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U
M<B!A9&1R97-S8F]O:RX`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M86EL('-E<G9E<B!G96YE<F%T
M960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@;6%I;"!S97)V
M97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S
M86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@
M;65S<V%G93H`5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2X`5&AE
M(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@*"5D(&)Y=&5S*2!E>&-E961S(&9E
M=&-H('-I>F4@;&EM:70N`%1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA
M<R!B965N(&-L;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A9V4@9&]E<R!N;W0@
M:&%V92!A(%-U8FIE8W0@96YT97)E9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@
M9&5L971E9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N`%1H92!M
M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+@!4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B
M965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@
M;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L
M(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE
M.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A
M=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL
M;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@
M<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M`%1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I
M97=E9"`E<RX`5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N`%1H92!R97%U97-T960@9FEL92!D
M;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N`%1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL
M>0!4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@
M365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@9G)O;2!Y;W4@=VAE
M;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S
M('1O('-E;F0@=&AE(&YO=&EF:6-A=&EO;B!M97-S86=E+@!4:&4@<V5P87)A
M=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!S97)V97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A
M('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!4:&4@<VEG;F%T=7)E(&-O=6QD
M(&YO="!B92!R97!L86-E9"X`5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U
M;&QY(')E<&QA8V5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B
M965N(')E;6]V960N`%1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES
M="X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE
M('-T871I;VYE<GD@(B5S(B!H87,@8F5E;B!A9&1E9"X`5&AE('-T871I;VYE
M<GD@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<W1A=&EO;F5R>2`B)7,B
M(&AA<R!B965N('5P9&%T960N`%1H92!T87-K(&AA<R!B965N(&%D9&5D('1O
M('EO=7(@=&%S:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@
M;F]T(&5X:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G90!4:&4@=&5X="!O
M9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T
M:&4@<F5T=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@
M;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T:&4@<V5N
M="!M97-S86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RX`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C
M:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T
M82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I
M<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&%L=&5R;F%T
M:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E
M(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N`%1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R
M92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@
M)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R
M("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!E
M>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@8V]P>6EN9R!M97-S
M86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@
M9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN
M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%1H97)E('=A<R!A;B!E<G)O
M<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R
M;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@=&%S:SH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R
M;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@<V%V
M:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T+@!4:&5R92!W87,@86X@97)R
M;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RX`5&AI<R!(
M5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X`5&AI<R!(
M5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO8VME
M9"!I;6%G97,@87!P96%R(&QI:V4@=&AI<SH@`%1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@4$=0(%!U
M8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O('1H92!M97-S86=E+@!4:&ES(&%C
M=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@>65T
M(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H
M92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU
M;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES
M(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E
M<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T
M:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V
M86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E
M<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A
M('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO
M<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q
M,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T
M+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@
M8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F
M;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S
M92!V:7-I="`E<P!4:&ES(&UA>2!T86ME('-O;64@=&EM92X@07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&-O;G1I;G5E/P!4:&ES(&UE<W-A9V4@8V]N=&%I
M;G,@82!-86-I;G1O<V@@9FEL92X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N
M(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I
M82!3+TU)344N`%1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT
M('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N`%1H:7,@;65S
M<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO
M;BP@8G5T('1H92!F;W)M870@;V8@=&AI<R!M97-S86=E(&ES('5N:VYO=VXN
M`%1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!0
M1U`@96YC<GEP=&5D(&UE<W-A9V4N($5R<F]R.B``5&AI<R!M97-S86=E(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T
M("AA8V-O<F1I;F<@=&\@4D9#(#(P,34I+@!4:&ES(&UE<W-A9V4@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F;W)M870N
M`%1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!0
M1U`N`%1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I
M82!3+TU)344N`%1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA
M(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H
M(%!'4"X`5&AI<R!M97-S86=E('1O`%1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V
M97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A(&-O;7!O<V4@=VEN9&]W+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H<F5A9"!$:7-P;&%Y`%1H
M<F5A9"!6:65W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`
M5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`
M5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!!9&1R97-S`%1O('-E;&5C="!M=6QT
M:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@=VAI;&4@8VQI8VMI;F<N`%1O('-E;&5C="!M=6QT:7!L
M92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N
M9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O('5S92!A(%1,4R!C;VYN
M96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@
M-2XQ+C`@;W(@:&EG:&5R+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G
M:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?
M=&]P*0!4;W1A;"!!='1A8VAM96YT<R!3:7IE.@!4<F%N<VQA=&EO;G,`5')A
M<V@@9F]L9&5R`%1R87-H(&9O;&1E<CH`5')I;FED860@86YD(%1O8F%G;P!4
M<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX
M.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`
M5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%52
M3"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ
M`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL
M92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T
M92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O
M(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N
M`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE
M('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X
M=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@
M9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`
M56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@
M=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO
M;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4N`%5N86)L92!T;R!R971R:65V92!Q=6]T80!5;F%B;&4@=&\@<G5N("=M
M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N`%5N86YS=V5R960`56YA;G-W97)E9"!M
M97-S86=E<P!5;F1E;&5T90!5;F1E<FQI;F4`56YD:7-C;&]S960@4F5C:7!I
M96YT<P!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;R!!551(14Y424-!
M5$4@8V]M;6%N9"X`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;R!$:6=E<W0M340U(')E<W!O;G-E+@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O($Q/1TE.(&-O;6UA;F0N`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N9&QE9"!C;VUP;VYE
M;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M
M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK
M;F]W;B!$871E`%5N:VYO=VX@24U!4"!R97-P;VYS92!F<F]M('1H92!S97)V
M97(N(%-E<G9E<B!297-P;VYD960Z("5S`%5N:VYO=VX@365E=&EN9P!5;FMN
M;W=N(%)E8VEP:65N=`!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YL;V%D(%!A
M<W-P:')A<V4`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@
M86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C
M=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N
M;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL
M;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5E;@!5
M;G-E="!C;VQO<@!5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS*0!5;G-U<'!O
M<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N
M9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E
M('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T
M:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE
M='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT
M.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@24U!4"!F;VQD97(@<W5B<V-R
M:7!T:6]N<S\`57-E(%-33`!5<V4@5FER='5A;"!4<F%S:"!&;VQD97(_`%5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N`%5S97(`57-E<B`B)7,B('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E
M8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B+@!5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5
M<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I
M;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O
M=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@
M97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES
M=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L
M:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E
M<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@
M<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L
M(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6
M:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<`5FEE=R`E<P!6:65W
M("5S(%!U8FQI8R!+97D`5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<`5FEE=R!-97-S86=E<P!6:65W(%!E<G-O;F%L(%!R:79A=&4@
M2V5Y`%9I97<@4&5R<V]N86P@4'5B;&EC($ME>0!6:65W(%1H<F5A9`!6:65W
M(%1H=6UB;F%I;`!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@
M)7,`5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I97<@
M8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W(&5V96YT`%9I97<@
M;65S<V%G97,@:6X@)7,`5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T
M97(@;&]G:6XZ`%9I97<@=&%S:P!6:65W('1H92!);6%G97,`5FER9VEN($ES
M;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FER='5A;"!&
M;VQD97(@(B5S(B!C<F5A=&5D('-U8V-E<V9U;&QY+@!6:7)T=6%L($9O;&1E
M<G,`5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"X`5FER='5A;"!)
M3D)/6`!6:7)T=6%L($E.0D]8($9O;&1E<@!6:7)T=6%L(%1R87-H`%9I<G1U
M86P@5')A<V@@1F]L9&5R`%9I<G1U86P@9F]L9&5R(&QA8F5L`%9I<VEB:6QI
M='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`
M5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)
M3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H
M97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N
M8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S
M`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T
M:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M(&]R(&EN;F]C96YT/P!7
M:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S
M:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@87,@9&5L971E9#\`
M5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U
M('=A;G0@=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO
M=6QD('=E('-A=F4@871T86-H;65N="!D871A/P!7:&5N('-E;F1I;F<@;6%I
M;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@
M=V4@87!P96YD('1O('5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D
M<F5S<V5S('=I=&AO=70@(D`B*3\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H
M:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:61T:`!7:61T:"!I;B!#4U,@
M=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7
M:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P
M965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E9
M65D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9
M;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN
M9R!A8V-O=6YT*',I.@!9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L
M;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H
M<RDN`%EO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN
M9R!F;VQD97(H<RDN`%EO=2!A<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@
M9F]L9&5R+@!9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R``66]U
M(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N`%EO=2!A<F4@:6X@
M5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C
M:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!F
M;VQD97)S+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@9F]L9&5R<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"X`66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B``66]U(&-A;B!U<V4@
M=&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@
M=&5X=#H@)6,@9F]R('1H92!C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@
M9F]R('1H92!S:6=N871U<F4N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A;FYO="!U;G-U8G-C
M<FEB92!F<F]M("(E<R(N`%EO=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M
M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W
M960@=&\@;&]G:6XN`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@
M861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I
M;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E
M<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S
M<R!T;R!T:&ES(&9O;&1E<@!9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O
M;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RX`66]U(&AA
M=F4@)7,@;F5W(&UE<W-A9V5S+@!9;W4@:&%V92`Q(&YE=R!M97-S86=E+@!9
M;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N`%EO=2!H879E
M(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R<SH`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="X`
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'
M4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9;W4@;75S="!E
M;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K
M97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4`66]U(&UU<W0@<V5L96-T(&$@=&%R
M9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I
M<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G92!F:7)S="X`
M66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R
M9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@
M;F5E9"!T;R!H879E("(E<R(@96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E
M(&]P=&EO;G,N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(`66]U(')E9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N
M("4E<RX`66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S+@!9;W4@
M=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(97)E(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2`B
M)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E('-U
M8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`66]U('=E<F4@<W5C8V5S
M<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@
M061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U
M<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<P!9;W5R(%!R:79A=&4@2V5Y`%EO
M=7(@4'5B;&EC($ME>0!9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P
M=&EO;F%L*3PO96T^`%EO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I
M9FEC871E<P!9;W5R(&%C8V]U;G1S.@!9;W5R(&%L:6%S(&%D9')E<W-E<SH@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI
M;F4I/"]E;3X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D
M:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92X`66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#
M;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`
M66]U<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO
M=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S
M86=E<SH`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@
M;&EN:V5D(&%T=&%C:&UE;G0@:&%S(&)E96X@9&]W;FQO861E9"!B>2!A="!L
M96%S="!O;F4@=7-E<BX*"D%T=&%C:&UE;G0@;F%M93H@)7,*071T86-H;65N
M="!D871E.B`E<PH*0VQI8VL@;VX@=&AE(&9O;&QO=VEN9R!L:6YK('1O('!E
M<FUA;F5N=&QY(&1E;&5T92!T:&4@871T86-H;65N=#H*)7,`66]U<B!L;V=I
M;B!H87,@97AP:7)E9"X`66]U<B!M97-S86=E('=A<R!S=6-C97-S9G5L;'D@
M9&5L:79E<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9;W5R('-I9VYA='5R93H`
M675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@
M061D<F5S<V5S70!;2&ED92!1=6]T960@5&5X=%T`6TYO(%-U8FIE8W1=`%M0
M<F]B;&5M(%)E<&]R=%T`6U-H;W<@061D<F5S<V5S("T`6U-H;W<@475O=&5D
M(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;4VAO=R!A
M9&1R97-S97,@+2`E<R!R96-I<&EE;G1S70!;;&EN92`E<R!O9B`E<UT`7T%D
M;6EN:7-T<F%T:6]N`%]"8V,`7T)L86-K;&ES=`!?0TQ)`%]#8P!?1&%T851R
M964`7T1E;&5T90!?1&5L971E(%)O=P!?1F]L9&5R<P!?1W)O=7!S`%](96QP
M`%])9&5N=&ET>0!?26UA9V4@4')O<&5R=&EE<RXN+@!?26YB;W@`7TQO9R!I
M;@!?3&]G(&]U=`!?365S<V%G92!3;W5R8V4`7TUO9&EF>2!,:6YK+BXN`%].
M97<@365S<V%G90!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U!R:6YT`%]0<FEO
M<FET>0!?4F5F<F5S:"`E<P!?4F5M;W9E($QI;FLN+BX`7U)E<&QY`%]396%R
M8V@`7U-E;F0@365S<V%G90!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`
M7U1H<F5A9`!?5&\`7U5N9&5L971E`%]5<V5R<P!?5FEE=R!4:')E860`7U=H
M:71E;&ES=`!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`871T86-H
M;65N=`!A='1A8VAM96YT<RYZ:7``8GET97,`8V%L96YD87(`8V%L;0!C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K
M(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O
M;0!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S
M="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@
M97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`:V5Y`&QI;F5S70!M86EL
M8F]X(&9I;&4`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)
M4T\N`&UM`&YA;64`;F]N90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L
M96UE;G1E9`!N;W1E<&%D`&]R`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`
M<&EX96QS`')E8VEP:65N='-=`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R
M:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M
M<S)E;6%I;"!V:6$@2%144`!S<&5L;&EN9R!E<G)O<@!S<&5L;&EN9R!E<G)O
M<G,`<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y
M(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U
M;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC
M;VT`>6]U<B!B;&%C:VQI<W0`>6]U<B!W:&ET96QI<W0`4')O:F5C="U)9"U6
M97)S:6]N.B!)35`@-"XQ+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTP
M-B`Q,CHT-RLP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z
M-3(K,#$P,`I,87-T+51R86YS;&%T;W(Z($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"DQA;F=U86=E+51E86TZ($=E<FUA;B`\9&5V0&QI<W1S+FAO
M<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@."UB:70*`"`@("`@("`@0V,Z(``@("`@("`@($%N.B``("`@
M("!$871U;3H@`"`@("`@("!6;VXZ(``@*'9O<B`E<R!486=E;BD`("A:=6=R
M:69F<W1A<W1E("5S*0`@*&EN("5S(%1A9V5N*0`@*&AE=71E*0`@*&UO<F=E
M;BD`("AG97-T97)N*0`@("!"971R969F.B``(&UI="``(&EN(``B)7,B(&ES
M="!K96EN(%9E<GIE:6-H;FES+@`B)7,B(&ES="!K96EN92!G_&QT:6=E($%U
M<W=A:&PN`"(E<R(@:7-T(&EN(&1E<B!(;W)D92!296=I<W1R>2!N:6-H="!K
M;VYF:6=U<FEE<G0N`$1E<B!"875M+5)E;F1E<F5R(&;\<B`B)7,B('=U<F1E
M(&YI8VAT(&=E9G5N9&5N+@`B)7,B('=U<F1E('IU;2!'<G5P<&5N<WES=&5M
M(&AI;GIU9V5F_&=T+@`B)7,B('=U<F1E('IU;2!296-H=&5S>7-T96T@:&EN
M>G5G96;\9W0N`"(E<R(@=W5R9&4@;FEC:'0@97)S=&5L;'0Z("5S+@!.<BX`
M)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0`E+C)F34(@*"4S)"XR9B4E*2!V
M;VX@)3(D+C)F34(@97)L875B=&5N('9E<F)R875C:'0`)60@)7,@=6YD("5S
M`"5D($YA8VAR:6-H=&5N`$EN("5D(%1A9V5N('=I<F0@26AR(%!A<W-W;W)T
M('5N9_QL=&EG+@`E9"!.86-H<FEC:'1E;B!W=7)D96X@9V5L]G-C:'0N`"5D
M($YA8VAR:6-H=&5N('=U<F1E;B!B96D@26AR96T@4WES=&5M861M:6YI<W1R
M871O<B!A;',@:V5I;B!3<&%M(&=E;65L9&5T+@`E9"!.86-H<FEC:'1E;B!W
M=7)D92!A;',@:V5I;B!3<&%M(&=E;65L9&5T+@`E9"!.86-H<FEC:'1E;B!W
M=7)D96X@8F5I($EH<F5M(%-Y<W1E;6%D;6EN:7-T<F%T;W(@86QS(%-P86T@
M9V5M96QD970N`"5D($YA8VAR:6-H=&5N('=U<F1E(&%L<R!3<&%M(&=E;65L
M9&5T+@`E9"!B:7,@)60@=F]N("5D($YA8VAR:6-H=&5N`"5D+51A9V4M5F]R
M:&5R<V%G90`E<R`M($AI;G=E:7,`)7,@1FEN9V5R86)D<G5C:P`E<R!+0@`E
M<R!787)T=6YG<V%R8F5I=&5N("T@0F5S=.1T:6=U;F<`)7,M2V]N9FEG=7)A
M=&EO;@`E<R!296=I<W1R:65R=6YG`"5S($YU='IU;F=S8F5D:6YG=6YG96X`
M)7,@97AI<W1I97)T(&)E<F5I=',N`"5S(&5X:7-T:65R="!B97)E:71S+B!$
M97(@3W)D;F5R("5S('=U<F1E(&YI8VAT('5M8F5N86YN="X`)7,@;6ET("5S
M("5S`"5S(&ES="!A;G-C:&5I;F5N9"!K96EN(&?\;'1I9V5R($]R9&YE<FYA
M;64N`$1E<B!/<F1N97(@)7,@=VER9"!Z=6T@36]N871S8F5G:6YN('5M8F5N
M86YN="X`)7,@:&%T('IU9V5S=&EM;70N`"5S(&AA="`B)7,B(&%B9V5S86=T
M+@`E<R!H870@86)G96QE:&YT+@`E<R!H870@875F(&5I;F4@1G)E:2]'96)U
M8VAT+4%N9G)A9V4@9V5A;G1W;W)T970N`"5S(&AA="!A=68@9&EE($5I;FQA
M9'5N9R!Z=2`B)7,B(&=E86YT=V]R=&5T+@`E<R!H870@26AN96X@1G)E:2]'
M96)U8VAT+4EN9F]R;6%T:6]N96X@9V5S8VAI8VMT+@`E<R!H870@=F]R;.1U
M9FEG('IU9V5S=&EM;70N`"5S('=I<F0@9&EE(%=A<G1U;F=S87)B96ET96X@
M9'5R8VAF_&AR96XL(&1I92!U;G1E;B!M87)K:65R="!S:6YD+B!-87)K:65R
M96X@4VEE(&%L;&4@075F9V%B96XL(&1I92!J971Z="!D=7)C:&=E9OQH<G0@
M=V5R9&5N('-O;&QE;BX`)7,@:7-T(&YO='=E;F1I9P`E<R!-:6YU=&5N`"5S
M(&YI8VAT(&=E9G5N9&5N+@`E<R!B:71T970@=6T@26AR92!&<F5I+T=E8G5C
M:'0M26YF;W)M871I;VYE;BX`)7,@8FET=&5T('5M($EH<F4@06YW97-E;FAE
M:70@8F5I("(E<R(N`"5S(&)I<R`E<R!V;VX@)7,`)7,@=W5R9&4@97)F;VQG
M<F5I8V@@>G4@(B5S(B!H:6YZ=6=E9OQG="X`)7,@;?9C:'1E("(E<R(@Y&YD
M97)N+@`E<R!M]F-H=&4@4VEE(&%U9B`B)7,B(&%U9FUE<FMS86T@;6%C:&5N
M+@`E<R!M]F-H=&4@9&EE(&YE=65S=&5N($EN9F]R;6%T:6]N96X@_&)E<B`B
M)7,B(&5R:&%L=&5N+@`E<W,@061R97-S8G5C:``E<W,@2V%L96YD97(`)7-S
M($YO=&EZ8FQO8VL`)7-S($%U9F=A8F5N;&ES=&4`)7,Z("5S`"5S.B`E<R`H
M)60F;F)S<#MV;VXF;F)S<#LE9"D`)7,Z($1I97-E($YA8VAR:6-H="!S=&%M
M;70@=6YT97(@56US=.1N9&5N(&YI8VAT('9O;B!D96T@86YG96=E8F5N96X@
M06)S96YD97(N($9O;&=E;B!3:64@:V5I;F5N($QI;FMS(&EN(&1I97-E<B!.
M86-H<FEC:'0@=6YD(&C\=&5N(%-I92!S:6-H(&1A=F]R+"!D96T@06)S96YD
M97(@<&5R<_9N;&EC:&4@1&%T96X@<')E:7-Z=6=E8F5N+@`HQ&YD97)U;F=E
M;B!A;G=E;F1E;B!U;F0@>G5R(&[D8VAS=&5N(%-E:71E('-P<FEN9V5N+BD`
M*$%L;&4@Q&YD97)U;F=E;B!V97)W97)F96X@=6YD('IU<B!.86-H<FEC:'1E
M;F5R<W1E;&QU;F<@>G5R_&-K('-P<FEN9V5N*0`H2%1-3"D`*$5I;F9A8VAE
M<B!497AT*0`H06QL92!B:7-H97)I9V5N(,1N9&5R=6YG96X@86YW96YD96X@
M=6YD('IU<B!.86-H<FEC:'1E;F5R<W1E;&QU;F<@>G5R_&-K('-P<FEN9V5N
M+B#$;F1E<G5N9V5N(&%U9B!D:65S97(@4V5I=&4@=V5R9&5N($Y)0TA4(&%N
M9V5W96YD970N*0`H06QL92!B:7-H97)I9V5N(,1N9&5R=6YG96X@86YW96YD
M96X@=6YD($YA8VAR:6-H="!V97)S8VAI8VME;BX@Q&YD97)U;F=E;B!A=68@
M9&EE<V5R(%-E:71E('=E<F1E;B!.24-(5"!A;F=E=V5N9&5T+BD`*B!!=68@
M3TL@:VQI8VME;BP@=6T@075S=V%H;"!H:6YZ=7IU9OQG96X@*@`J($)I='1E
M($%D<F5S<V4H;BD@875S=^1H;&5N("H`+"!B]FEG(``L(&)I9R`E<R`E<P`L
M('-C:'=A;FME;F0@=F]N("5S(&)I<R`E<P`M+2!!=7-WY&AL96X@+2T`,2!.
M86-H<FEC:'0@=W5R9&4@9V5L]G-C:'0N`#$@3F%C:')I8VAT('=U<F1E(&)E
M:2!):')E;2!3>7-T96UA9&UI;FES=')A=&]R(&%L<R!K96EN(%-P86T@9V5M
M96QD970N`#$@3F%C:')I8VAT('=U<F1E(&%L<R!K96EN(%-P86T@9V5M96QD
M970N`#$@3F%C:')I8VAT('=U<F1E(&)E:2!):')E;2!3>7-T96UA9&UI;FES
M=')A=&]R(&%L<R!3<&%M(&=E;65L9&5T+@`Q($YA8VAR:6-H="!W=7)D92!A
M;',@4W!A;2!G96UE;&1E="X`,3`P(%IE:6-H96X`,3`P,"!:96EC:&5N`#$R
M+5-T=6YD96XM1F]R;6%T`#(T+5-T=6YD96XM1F]R;6%T`#(T(%-T=6YD96X`
M,C4P(%IE:6-H96X`-3`P(%IE:6-H96X`/%IU<OQC:P!&<B!D:65S96X@0FQO
M8VL@=VER9"!E:6YE($1A=&5N8F%N:R!B96YT:6=T+@!%:6X@<V-H=V5R97(@
M1F5H;&5R(&ES="!A=69G971R971E;CH`16EN(&=R;]]E<R!":6QD(&UI="!D
M97(@0F5Z96EC:&YU;F<@)7,@:7-T(&%N(&1I97-E($YA8VAR:6-H="!A;F=E
M:.1N9W0N`$5I;F4@3F%C:')I8VAT+"!D:64@4VEE('9E<G-C:&EC:W0@:&%B
M96XL(&;\:')T92!Z=2!E:6YE<B!%;7!F86YG8F5S=.1T:6=U;F<@=F]M($5M
M<&;D;F=E<BX`16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L('=I<F0@
M9OQR(&1I92!697)S8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T
M:6=T+@!%:6X@]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P@=VER9"!F_'(@
M9&EE(-QB97)P<OQF=6YG(&5I;F5R('5N=&5R>F5I8VAN971E;B!.86-H<FEC
M:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E
M<B!01U`M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D
M:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`
M16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%!'4"U38VAL_'-S
M96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H
M;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H
M97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L('-O=VEE(&5I
M;B!087-S=V]R="!W:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R
M($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN
M('!R:79A=&5R(%,O34E-12U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T
M('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@
M8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@4R]-24U%+5-C:&S\<W-E;"!W
M:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B
M96[V=&EG="X`5F]R;6ET=&%G<R!7;VQK96X`5F]R;6ET=&%G<R!L96EC:'1E
M<B!296=E;@!6;W)M:71T86=S(%)E9V5N`%9O<FUI='1A9W,@4V-H875E<@!6
M;W)M:71T86=S(%-C:&YE97-C:&%U97(`04TO4$T`54Y$`$%022!)1`#<8F5R
M(&1I97-E;B!%9&ET;W(`26YF;RXN+@!!8G-O;'5T(%5N=&5N`$%B<V]L=70@
M36ET=&4`06YF<F%G92!A:WIE<'1I97)E;B!U;F0@>G4@;65I;F5M($MA;&5N
M9&5R(&AI;GIU9OQG96X`06YF<F%G92!A:WIE<'1I97)E;@!!;F=E;F]M;65N
M`$%N9V5N;VUM96XZ(`!:=6=R:69F('9E<G=E:6=E<G0@8F5I;2!!;FQE9V5N
M(&1E<R!61E,M5F5R>F5I8VAN:7-S97,N`%IU9W)I9F8@=F5R=V5I9V5R="!B
M96EM($%N;&5G96X@9&5R(%9&4RU$871E:2X`2V]N=&]I;F9O<FUA=&EO;F5N
M`$MO;G1O<&%S<W=O<G0`2V]N=&\@96EN9V5F<F]R96XN`$MO;G1O;F%M93H`
M0G5C:&AA;'1U;F<`06MT:6]N96X`2&EN>G5F_&=E;@`E<R!Z=2!M96EN96T@
M061R97-S8G5C:"!H:6YZ=6;\9V5N`$YE=64@56YT97)G<G5P<&4@:&EN>G5F
M_&=E;@!.975E(%5N=&5R<F5C:'1E(&AI;GIU9OQG96X`2&EE<B!H:6YZ=6;\
M9V5N.@!.975E($=R=7!P92!H:6YZ=6;\9V5N`$YE=64@4F5C:'1E(&AI;GIU
M9OQG96X`56YT97)G<G5P<&4@>G4@(B5S(B!H:6YZ=6;\9V5N`%5N=&5R<F5C
M:'1E('IU("(E<R(@:&EN>G5F_&=E;@!&_&=E;B!3:64@96EN96X@;F5U96X@
M0F5N=71Z97(@:&EN>G4Z`%-P86QT92!H:6YZ=6;\9V5N`$YE=64@36ET9VQI
M961E<B!H:6YZ=6;\9V5N`%!A87(@:&EN>G5F_&=E;@!1=65L;&4@:&EN>G5F
M_&=E;@!$87,@)7,M365N_"!Z=7(@36]Z:6QL82!3:61E8F%R(&AI;GIU9OQG
M96X`6G4@;65I;F5M($MA;&5N9&5R(&AI;GIU9OQG96X`6G5M($%D<F5S<V)U
M8V@@:&EN>G5F_&=E;CH`6G4@;65I;F5M($%D<F5S<V)U8V@@:&EN>G5F_&=E
M;@!:=2!M96EN96T@2V%L96YD97(@:&EN>G5F_&=E;@!"96YU='IE<B!H:6YZ
M=6;\9V5N`"(E<R(@86QS($%N:&%N9R!H:6YZ=6=E9OQG="X`(B5S(B!W=7)D
M92!Z=6T@4WES=&5M(&AI;GIU9V5F_&=T+"!A8F5R(&1I92!Z=7/D='IL:6-H
M96X@4F5G:7-T<FEE<G5N9W-I;F9O<FUA=&EO;F5N(&MO;FYT96X@;FEC:'0@
M9V5S<&5I8VAE<G0@=V5R9&5N.B`E<RX`(B5S(B!W=7)D92!Z=6T@4WES=&5M
M(&AI;GIU9V5F_&=T+B!3:64@:_9N;F5N('-I8V@@:F5T>G0@86YM96QD96XN
M`$1A<R!(:6YZ=6;\9V5N('9O;B!"96YU='IE<FX@:7-T(&YI8VAT(&WV9VQI
M8V@N`$EN(&1E<B!.86-H<FEC:'1E;F%N<VEC:'0@>G5SY'1Z;&EC:"!A;GIU
M>F5I9V5N9&4@2V]P9F5I;G1RY&=E.B`\96T^*&]P=&EO;F%L+"!J961E;B!%
M:6YT<F%G(&EN(&5I;F5R(&5I9V5N96X@6F5I;&4@96EN=')A9V5N*3PO96T^
M`%IU<^1T>FQI8VAE($EN9F]R;6%T:6]N96X@:_9N;F5N("5S(&5I;F=E<V5H
M96X@=V5R9&5N+@!:=7/D='IL:6-H92!$971A:6QI;F9O<FUA=&EO;F5N`%IU
M<^1T>FQI8VAE($YA8VAR:6-H=&5N9&5T86EL<P!:=7/D='IL:6-H92!.86-H
M<FEC:'1E;F1E=&%I;',@:_9N;F5N("5S(&%N9V5S8VAA=70@=V5R9&5N+@!:
M=7/D='IL:6-H92!&96AL97)D971A:6QS`%IU<^1T>FQI8VAE($9E:&QE<F1E
M=&%I;',@:_9N;F5N("5S(&%N9V5S8VAA=70@=V5R9&5N+@!!9')E<W-E`$%D
M<F5S<V)U8V@`061R97-S8OQC:&5R`$%D<F5S<V5N(&;\<B!"8V,M2V]P:65N
M(&%L;&5R($YA8VAR:6-H=&5N.B`\96T^*&]P=&EO;F%L+"!J961E($%D<F5S
M<V4@:6X@96EN97(@96EG96YE;B!:96EL92!E:6YT<F%G96XI/"]E;3X`061R
M97-S96XL(&1I92!A;B!D:65S92!)9&5N=&ETY'0@9V5B=6YD96X@<VEN9#H@
M/&5M/BAO<'1I;VYA;"P@:F5D92!!9')E<W-E(&EN(&5I;F5R(&5I9V5N96X@
M6F5I;&4@96EN=')A9V5N*3PO96T^`%9E<G=A;'1E;B`M(%)E8VAT92!F_'(@
M86YD97)E($)E;G5T>F5R(&9E<W1L96=E;@!!9&UI;FES=')A=&EO;@!797)B
M=6YG`$%F9VAA;FES=&%N`$%L8F%N:65N`$%L9V5R:65N`%-P:71Z;F%M90!!
M=7-R:6-H='5N9P!!=7-R:6-H='5N9SH`06QL90!!;F=E;65L9&5T92!"96YU
M='IE<@!!;&QE($=R=7!P96X`06QL92!296-H=&4`06QL92!V:65R(%-E:71E
M;@!!;&QE($YA8VAR:6-H=&5N(&EN(&1E;B!F;VQG96YD96X@3W)D;F5R;B!W
M97)D96X@86QS(&5I;F4@34)/6"U$871E:2!H97)U;G1E<F=E;&%D96XZ`$%L
M;&4@3F%C:')I8VAT96X@:6T@3W)D;F5R("(E<R(L(&1I92#D;'1E<B!A;',@
M)7,@5&%G92!S:6YD+"!W97)D96X@96YD9_QL=&EG(&=E;/9S8VAT+@!!;&QE
M('9E<FQI;FMT92!!;FCD;F=E+"!D:64@Y&QT97(@86QS("5S($UO;F%T92!S
M:6YD+"!W97)D96X@9V5L]G-C:'0N`$%L;&4@86QT96X@3W)D;F5R(&;\<B!G
M97-E;F1E=&4@3F%C:')I8VAT96XL(&1I92#D;'1E<B!A;',@)7,@36]N871E
M('-I;F0L('=E<F1E;B!G96SV<V-H="X`06QL92!296-H=&4@=F]N($)E;G5T
M>F5R("(E,B1S(B!A;2!/<F1N97(@(B4Q)',B('=U<F1E;B!E<F9O;&=R96EC
M:"!E;G1F97)N="X`17)S=&5L;&5N('9O;B!/<F1N97)N(&5R;&%U8F5N/P!!
M;G=E;F1U;F<@=F]N($9I;'1E<G)E9V5L;B!I;B!A;&QE;B!/<F1N97)N(&5R
M;&%U8F5N/P!-96AR97)E($%D<F5S<V5N(&5R;&%U8F5N`$9O<FUA="!V;VX@
M;G5M;65R:65R=&5N($QI<W1E;B#D;F1E<FX_`$5X:7-T:65R="!B97)E:71S
M`$%L=&5R;F%T:79E($E-4U`M06YM96QD=6YG`$%L=&5R;F%T:79E<R!)35-0
M+5!A<W-W;W)T`$%L=&5R;F%T:79E<B!)35-0+4)E;G5T>F5R;F%M90!!;'1E
M<FYA=&EV92!%;6%I;&%D<F5S<V4`06QT97)N871I=F4@5F]R;&%G96X`06QT
M97)N871I=F5R(%1E>'0Z`$%L=&5R;F%T:79E($YA8VAR:6-H=&5N=&5I;&4Z
M`$EM;65R`$%N:.1N9V4@:6UM97(@<W!E:6-H97)N`$%M97)I:V%N:7-C:"U3
M86UO80!"96EM($5N=&9E<FYE;B!D97,@06YH86YG<R!I<W0@96EN($9E:&QE
M<B!A=69G971R971E;BX@365L9'5N9R!D97,@16UA:6PM4V5R=F5R<SH@`$5S
M('=U<F1E(&5I;B!U;F?\;'1I9V5R(%=E<G0@86YG96=E8F5N+@!%:6X@=6YB
M96MA;FYT97(@1F5H;&5R(&ES="!A=69G971R971E;BX`0F5I;2!!;FQE9V5N
M(&1E<B!N975E;B!.;W1I>B!I<W0@96EN('5N8F5K86YN=&5R($9E:&QE<B!A
M=69G971R971E;BX`0F5I;2!!;FQE9V5N(&1E<B!N975E;B!!=69G86)E(&ES
M="!E:6X@=6YB96MA;FYT97(@1F5H;&5R(&%U9F=E=')E=&5N+@!!;F1O<G)A
M`$%N9V]L80!!;F=U:6QL80!!;F]N>6UE<B!0<F]X>0!!;G1W;W)T`$)E86YT
M=V]R=&5T`$)E86YT=V]R=&5T92!.86-H<FEC:'1E;@!!;G1A<FMT:7,`06YT
M:6=U82!U;F0@0F%R8G5D80!!;G=E;F1U;F<`06YW96YD=6YG<VQI<W1E`$%N
M=V5N9'5N9R!I<W0@8F5R96ET+@!&:6QT97)R96=E;&X@86YW96YD96X`1FEL
M=&5R<F5G96QN(&%U9B`E<R!A;G=E;F1E;@!&:6QT97)R96=E;&X@8F5I;2!!
M;FUE;&1E;B!A;G=E;F1E;C\`1FEL=&5R<F5G96QN(&EM;65R(&%N=V5N9&5N
M+"!W96YN($E.0D]8(&%N9V5Z96EG="!W:7)D/P!!=68@56YT97)R96-H=&4@
M86YW96YD96X`0F5S=.1T:6=E;@!5;F=E9N1H<F4@1W+VWV4`07!R:6P`07)A
M8FES8V@@*%=I;F1O=W,M,3(U-BD`07)C:&EV9W+VWV4`07)C:&EV;F%M90!3
M:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I92!3=6-H:W)I=&5R:65N(&;\
M<B!D:65S96X@5FER='5E;&QE;B!/<F1N97(@;/9S8VAE;B!M]F-H=&5N/P!3
M:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I97-E;B#V9F9E;G1L:6-H96X@
M4V-H;/QS<V5L(&SV<V-H96X@;?9C:'1E;C\`4VEN9"!3:64@<VEC:&5R+"!D
M87-S(%-I92!):'(@4V-H;/QS<V5L<&%A<B!L]G-C:&5N('=O;&QE;C\@*$Y)
M0TA4(&5M<&9O:&QE;B$I`%-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@9F]R
M=&9A:')E;B!M]F-H=&5N/P!3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I
M92!296=I<W1R:65R=6YG<V%N9G)A9V4@=F]N("5S(&SV<V-H96X@;?9C:'1E
M;C\`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D:65S92!.86-H<FEC:'1E
M;B!%3D1'W$Q424<@;/9S8VAE;B!M]F-H=&5N/P!3:6YD(%-I92!S:6-H97(L
M(&1A<W,@4VEE(&1I97-E;B!!;FAA;F<@14Y$1]Q,5$E'(&SV<V-H96X@;?9C
M:'1E;C\`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92`B)7,B('5N9"!A;&QE
M(%5N=&5R9W)U<'!E;B!L]G-C:&5N(&WV8VAT96X_`%-I;F0@4VEE('-I8VAE
M<BP@9&%S<R!3:64@9&EE<V5N($]R9&YE<B!L965R96X@;?9C:'1E;C\`4VEN
M9"!3:64@<VEC:&5R+"!D87-S(%-I92!D96X@4W!A;2U/<F1N97(@;&5E<F5N
M(&WV8VAT96X_`%-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@9&5N(%!A<&EE
M<FMO<F(@;&5E<F5N(&WV8VAT96X_`%-I;F0@4VEE('-I8VAE<BP@9&%S<R!3
M:64@9&EE<V4@3F%C:')I8VAT96X@96YD9_QL=&EG(&SV<V-H96X@;?9C:'1E
M;C\`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D:65S92!.86-H<FEC:'0@
M86QS(&ME:6X@4W!A;2!M96QD96X@;?9C:'1E;C\`4VEN9"!3:64@<VEC:&5R
M+"!D87-S(%-I92!D:65S92!.86-H<FEC:'0@86QS(%-P86T@;65L9&5N(&WV
M8VAT96X_`$%R9V5N=&EN:65N`$%R;65N:65N`$%R;65N:7-C:"`H05)-4T-)
M22TX*0!%:6YG86YG<WIE:70`2W5N<W0`07)U8F$`075F<W1E:6=E;F0`07-C
M96YS:6]N+4EN<V5L;@!!4T-)22U+=6YS=`!!<VEE;B]087II9FES8VAE(%)E
M9VEO;@!.86-H9G)A9V5N`$%N<W1E:&5N9&4@5V%R='5N9W-A<F)E:71E;B!B
M97-TY'1I9V5N(&QA<W-E;C\`6G5O<F1N=6YG<V9E;&1E<@!$871E:65N(&%N
M:.1N9V5N`$5I;F4@2V]P:64@26AR97,@]F9F96YT;&EC:&5N(%!'4"U38VAL
M_'-S96QS(&%N($EH<F4@3F%C:')I8VAT(&%N:.1N9V5N/P!!;F=E:.1N9W1E
M($1A=&5I.@!$:64@1&%T96D@(B5S(B!H870@9&EE(&5R;&%U8G1E($=R]M]E
M(&;\<B!!;FCD;F=E(/QB97)S8VAR:71T96XN($1I92!$871E:2!W=7)D92!.
M24-(5"!A;F=E:.1N9W0N`$EM($%N:&%N9R!F:6YD96X@4VEE(&5I;F4@06YW
M;W)T(&%U9B!E:6YE(%1E<FUI;F%N9G)A9V4L(&1I92!3:64@9V5S=&5L;'0@
M:&%B96XN`$%N:&%N9P!!;FQA9V4@)7,@=W5R9&4@9V5L]G-C:'0N`$%N:&%N
M9W-I;F9O<FUA=&EO;F5N`$%N:&%N9R!E;G1F97)N=#H@16AE;6%L:6=E<B!!
M;FAA;F=S='EP`$%N:.1N9V4`17,@=W5R9&4@=F5R<W5C:'0L(&5I;F4@;FEC
M:'0@97AI<W1I97)E;F1E($=R=7!P92!Z=2!L]G-C:&5N+@!%<R!W=7)D92!V
M97)S=6-H="P@96EN(&YI8VAT(&5X:7-T:65R96YD97,@4F5C:'0@>G4@;/9S
M8VAE;BX`17,@=W5R9&4@=F5R<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N
M9&5S(%)E8VAT('IU(&)E87)B96ET96XN`$5S('=U<F1E('9E<G-U8VAT+"!E
M:6X@;FEC:'0@97AI<W1I97)E;F1E<R!296-H="!Z=2!B96%R8F5I=&5N+@!4
M96EL;F5H;65R`$%C:'1U;F<`071T<FEB=71E`$%U9W5S=`!!=7-T<F%L:65N
M`-9S=&5R<F5I8V@`075T:%]C>7)S<6PZ($1I92!B96[V=&EG=&4@24U!4"U%
M<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]C>7)U<SH@
M1&%S($)A8VME;F0@:&%T(&YI8VAT(&1I92!B96[V=&EG=&5N($;D:&EG:V5I
M=&5N+@!!=71H7V-Y<G5S.B!$:64@8F5N]G1I9W1E($E-05`M17)W96ET97)U
M;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?9G1P.B!$:64@8F5N]G1I
M9W1E($944"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX@2V]M
M<&EL:65R96X@4VEE(%!(4"!M:70@9&5M("TM96YA8FQE+69T<"!087)A;65T
M97(N`$%U=&A?:6UA<#H@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG
M('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7VEM<#H@1&EE(&)E;O9T:6=T
M92!)34%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H
M7VMR8C4Z($1I92!B96[V=&EG=&4@2V5R8F5R;W,M17)W96ET97)U;F<@=W5R
M9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?;&1A<#H@1&%S($AI;GIU9OQG96X@
M=F]N($)E;G5T>F5R;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT
M('5N=&5R<W3\='IT`$%U=&A?;&1A<#H@1&%S($SV<V-H96X@=F]N($)E;G5T
M>F5R;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT('5N=&5R<W3\
M='IT`$%U=&A?;&1A<#H@1&EE(&)E;O9T:6=T92!,1$%0+45R=V5I=&5R=6YG
M('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7VQD87`Z($1E<B!"96YU='IE
M<B`E<R!K;VYN=&4@;FEC:'0@:&EN>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG
M(&1E<R!397)V97)S.B``075T:%]L9&%P.B!"96YU='IE<B`E<R!K;VYN=&4@
M;FEC:'0@9V5L]G-C:'0@=V5R9&5N`$%U=&A?;&1A<#H@0F5N=71Z97(@)7,@
M:V]N;G1E(&YI8VAT(&%K='5A;&ES:65R="!W97)D96X`075T:%]L9&%P.B!$
M87,@06MT=6%L:7-I97)E;B!V;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV
M92!$:7)E8W1O<GD@;FEC:'0@=6YT97)S=/QT>G0N`$%U=&A?;6-A;#H@1&EE
M(&)E;O9T:6=T92!-0T%,+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N
M9&5N+@!!=71H7W-M8F%U=&@Z($1I92!B96[V=&EG=&4@4V%M8F$M17)W96ET
M97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%N;65L9'5N9R!B96EM($E-
M05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+@!!=71H96YT:69I>FEE<G5N9R!F
M96AL9V5S8VAL86=E;@!!;FUE;&1U;F<@9F5H;&=E<V-H;&%G96XN("5S`$1I
M92!!=71H96YT:69I>FEE<G5N9R!W=7)D92!V;VT@4D%$2553+5-E<G9E<B!Z
M=7+\8VMG97=I97-E;BX`06YM96QD=6YG(&)E:6T@1E10+5-E<G9E<B!F96AL
M9V5S8VAL86=E;BX`06YM96QD=6YG(&)E:6T@4TU"+5-E<G9E<B!F96AL9V5S
M8VAL86=E;BX`075T;VUA=&ES8V@@0FEL9&5R(&EN($A434PM3F%C:')I8VAT
M96X@86YZ96EG96XL('=E;FX@<VEC:"!D97(@06)S96YD97(@:6T@061R97-S
M8G5C:"!B969I;F1E=#\`5F5R9OQG8F%R92!!9')E<W-B_&-H97(Z`%9E<F;\
M9V)A<F4@1F5L9&5R.@!!=68@06YT=V]R="!W87)T96YD`$%S97)B86ED<V-H
M86X`0D]&2"U!=7-R961E;@!?6G5R_&-K('IU("5S`%IU<OQC:R!Z=2`E<P!:
M=7+\8VL@>G5M($YA8VAR:6-H=&5N:6YD97@`6G5R_&-K('IU<B!4:&5M96YL
M:7-T90!(:6YT97)G<G5N9`!(:6YT97)G<G5N9&9A<F)E`$9A;'-C:&5S($ME
M<F)E<F]S+5!A<W-W;W)T+@!&86QS8VAE<B!+97)B97)O<RU"96YU='IE<FYA
M;64N`$9A;'-C:&5R($)E;G5T>F5R;F%M92!O9&5R(%!A<W-W;W)T+@!5;F?\
M;'1I9V4@;V1E<B!F96AL97)H869T92!!;F9R86=E+B!397)V97)A;G1W;W)T
M.B`E<P!5;F?\;'1I9V4@06YF<F%G93H@)7,N`$)A:&%M87,`0F%H<F5I;@!"
M86QT:7-C:"`H25-/+3@X-3DM,3,I`$)A;F=L861E<V-H`$)A<F)A9&]S`$)A
M<VES+4)I;&1E<BU697)Z96EC:&YI<R`B)7,B(&YI8VAT(&=E9G5N9&5N+@!'
M<G5N9&QI;FEE`$)C8P!796G?<G5L86YD`$)E;&=I96X`0F5L:7IE`%5N=&5N
M(&)E9FEN9&5T('-I8V@@9&5R(%%U96QL=&5X="!D97(@3F%C:')I8VAT(&UI
M="!D97(@4W1A='5S:6YF;W)M871I;VXN`$)E;FEN`$)E<FUU9&%S`$)H=71A
M;@!'96)U<G1S=&%G`$%U<W-C:&QU<W-L:7-T90!";&]C:R`B)7,B(&1E<B!!
M;G=E;F1U;F<@(B5S(B!N:6-H="!G969U;F1E;BX`0FQO8VME:6YS=&5L;'5N
M9V5N`$)L;V-K='EP`$ME:6YE($)I;&1E<B!I;B!(351,+4YA8VAR:6-H=&5N
M(&%N>F5I9V5N+"!A==]E<B!W96YN(&%U<V1R_&-K;&EC:"!A;F=E9F]R9&5R
M=#\`5&5X=`!&971T`$)O;&EV:65N`$QE<V5Z96EC:&5N`%)A;F0`4F%H;65N
M9&EC:V4Z`%+D;F1E<@!";W-N:65N+4AE<GIE9V]W:6YA`$)E:61E<P!);2!.
M86-H<FEC:'1E;FMO<&8@=6YD(&EM($YA8VAR:6-H=&5N=&5X=`!";W1S=V%N
M80!5;G1E;@!";W5V971I;G-E;`!"<F%S:6QI96X`0G)I=&ES8VAE<R!497)R
M:71O<FEU;2!I;2!);F1I<V-H96X@3WIE86X`0G)U;F5I($1A<G5S<V%L86T`
M0G5L9V%R:65N`%5N;G5M;65R:65R=&4@3&ES=&4`0G5R:VEN82!&87-O`$)U
M<G5N9&D`0TU3`$;\<B!#4D%-+4U$-2!O9&5R($1)1T535"U-1#4@;75S<R!D
M87,@075T:%]305-,+5!A:V5T(&EN<W1A;&QI97)T('-E:6XN`$-20P!#4DP@
M1&ES=')I8G5T:6]N<W-T96QL90!?6F5L;&5N96EG96YS8VAA9G1E;BXN+@!?
M6F5I8VAE;G-A='H`1&5R(%IW:7-C:&5N<W!E:6-H97(@:V]N;G1E(&YI8VAT
M(&EN:71I86QI<VEE<G0@=V5R9&5N+@!+86QE;F1E<@!7:6YD<W1I;&P`2V%M
M8F]D<V-H80!+86UE<G5N`%9E<F)I;F1U;F<@>G5M($5M86EL+5-E<G9E<B!K
M86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;BX`5F5R8FEN9'5N9R!Z=6T@
M16UA:6PM4V5R=F5R(&MA;FX@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N.B``
M1&%R<W1E;&QU;F<@;FEC:'0@;?9G;&EC:"`M(&YU<B`E<R!V;VX@)7,@5&5I
M;&5N(&1I97-E<B!.86-H<FEC:'0@:6T@86MT=65L;&5N($]R9&YE<B!G969U
M;F1E;BX`4&%S<W=O<G0@:V%N;B!N:6-H="!A=71O;6%T:7-C:"!Z=7+\8VMG
M97-E='IT('=E<F1E;BP@8FET=&4@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N
M($%D;6EN:7-T<F%T;W(N`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V5S
M<&5I8VAE<G0@=V5R9&5N`$5X=&5R;F4@4V5S<VEO;BU(86YD;&5R(&OV;FYE
M;B!N:6-H="!A9&UI;FES=')I97)T('=E<F1E;BX`5F5R8FEN9'5N9R!Z=6T@
M24U!4"U397)V97(@:V%N;B!N:6-H="!H97)G97-T96QL="!W97)D96XZ("5S
M`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!+
M86YA9&$`06)B<F5C:&5N`$YA8VAR:6-H="!V97)W97)F96X`4')O8FQE;6)E
M<FEC:'0@86)B<F5C:&5N`%=E;FX@4VEE(&1I97-E($YA8VAR:6-H="!V97)W
M97)F96XL(&=E:'0@9&5R($EN:&%L="!E;F?\;'1I9R!V97)L;W)E;BX`1&EE
M($1A=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`2V5I
M;B!T96UP;W+D<F5S(%9E<GIE:6-H;FES(&=E9G5N9&5N+@!&;W)T<V5T>G5N
M9R!O:&YE(")T87)G971&:6QE(BU087)A;65T97(@;FEC:'0@;?9G;&EC:"X`
M1&%S(%9E<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E
M<F1E;BX`2V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;BP@)60@2VEN9&5R
M(&5X:7-T:65R96XN`%5M<V]R=&EE<F5N(&YI8VAT(&WV9VQI8V@N($1I92!!
M;GIA:&P@9&5R($5I;G1RY&=E+"!D:64@=6US;W)T:65R="!W97)D96X@<V]L
M;&5N+"!S=&EM;70@;FEC:'0@;6ET(&1E<B!!;GIA:&P@9&5R(&=E<W!E:6-H
M97)T96X@16EN='+D9V4@_&)E<F5I;BX`1&EE($YA8VAR:6-H="!K;VYN=&4@
M;FEC:'0@86X@9&EE(&%N9V5G96)E($YU;6UE<B!W96ET97)G96QE:71E="!W
M97)D96XN`$MA<"!697)D90#<8F5R<V-H<FEF=`!0<F]V:61E<@!+871E9V]R
M:65N('5N9"!"97-C:')I9G1U;F=E;@!#87EM86XM26YS96QN`$-C`$UO8FEL
M=&5L969O;@!:96QL96YE:6=E;G-C:&%F=&5N`$EN;F5N86)S=&%N9#H`6F5L
M;&5N96EG96YS8VAA9G1E;@!:96QL96YA8G-T86YD.@!-;V)I;'1E;&5F;VX`
M2V5L=&ES8V@@*$E33RTX.#4Y+3$T*0!:96YT<FEE<G0`6F5N=')A;&%F<FEK
M86YI<V-H92!297!U8FQI:P!-:71T96QE=7)O<.1I<V-H("A)4T\M.#@U.2TR
M*0!:97)T:69I:V%T9&5T86EL<P!:97)T:69I:V%T8F5S:71Z97(`6F5R=&EF
M:6MA=')I8VAT;&EN:65N`%-I92!K]FYN96X@:V5I;F4@6F5R=&EF:6MA=&4@
M:6UP;W)T:65R96XL('=E:6P@9&%S($AO8VAL861E;B!V;VX@1&%T96EE;B!A
M=68@9&EE<V5N(%-E<G9E<B!N:6-H="!M]F=L:6-H(&ES="X`5'-C:&%D`$)E
M<W!R96-H=6YG<VQE:71E<@#$;F1E<FX`06QL92#$;F1E<FX`3W)D;F5R('=E
M8VAS96QN`,1N9&5R;B!3:64@26AR(%!A<W-W;W)T`,1N9&5R;B!3:64@9&EE
M($5I;G-T96QL=6YG96X@9OQR(&1I92!!;GIE:6=E+"!Z+D(N('=I92!V:65L
M92!.86-H<FEC:'1E;B!P<F\@4V5I=&4@86YG97IE:6=T('=E<F1E;B!U;F0@
M=V]N86-H(&1I92!.86-H<FEC:'1E;B!S;W)T:65R="!W97)D96X@<V]L;&5N
M+@#$;F1E<FX@4VEE(&1I92!%:6YS=&5L;'5N9V5N('IU($EH<F5M($5M86EL
M+5-E<G9E<B!U;F0@26AR96X@3W)D;F5R;BX`Q&YD97)N(%-I92!D96X@3F%M
M96X@;V1E<B!D:64@16UA:6QA9')E<W-E+"!D:64@9&EE($5M<&;D;F=E<B!)
M:')E<B!%;6%I;',@<V5H96XL('=E;FX@9&EE<V4@26AR92!%;6%I;',@;&5S
M96X@;V1E<B!D87)A=68@86YW;W)T96XN`,1N9&5R;B!3:64@9&5N($YA;65N
M+"!D:64@16UA:6QA9')E<W-E(&]D97(@9&EE(%-I9VYA='5R+"!D:64@9&EE
M($5M<&;D;F=E<B!):')E<B!%;6%I;',@<V5H96XL('=E;FX@9&EE<V4@26AR
M92!%;6%I;',@;&5S96X@;V1E<B!D87)A=68@86YW;W)T96XN`$1A<R#$;F1E
M<FX@26AR97,@4&%S<W=O<G1S('=I<F0@=F]N(&1I97-E;2!3>7-T96T@>G5R
M(%IE:70@;FEC:'0@=6YT97)S=/QT>G0N($)I='1E('=E;F1E;B!3:64@<VEC
M:"!A;B!):')E;B!!9&UI;FES=')A=&]R+@!:96EC:&5N`$%N>G5Z96EG96YD
M92!:96EC:&5N.@!,:6YK(/QB97)?<'+\9F5N+BXN`$]R9&YE<B!A=68@;F5U
M92!.86-H<FEC:'1E;B#\8F5R<'+\9F5N`%]!;&QE+TME:6YE(&%U<W?D:&QE
M;@!-87)K:65R96X@4VEE(&%L;&4@16UA:6QS97)V97(L('9O;B!D96YE;B!3
M:64@16UA:6QS(&AE<G5N=&5R;&%D96X@;?9C:'1E;CH`4F5C:'1S8VAR96EB
M=6YG('9O<B!D96T@5F5R<V5N9&5N('9O;B!.86-H<FEC:'1E;B#\8F5R<'+\
M9F5N/P!#:&EL90!#:&EN80!#:&EN97-I<V-H('9E<F5I;F9A8VAT("A'0C(S
M,3(I`$-H:6YE<VES8V@@=')A9&ET:6]N96QL("A":6<U*0!!:W1I;VX@875S
M=^1H;&5N.@!!;G=E;F1U;F<@875S=^1H;&5N.@!7Y&AL96X@4VEE(&5I;F5N
M($5M86EL+5-E<G9E<CH`0FET=&4@=^1H;&5N(%-I92!A=7,@;V1E<B!E9&ET
M:65R96X@4VEE(')E8VAT<SH`5^1H;&5N(%-I92!E:6X@4&%S<W=O<G0`5^1H
M;&5N(%-I92!E:6YE;B!"96YU='IE<FYA;65N`$QE9V5N(%-I92!F97-T+"!W
M:64@9&%S($1A='5M(&%N9V5Z96EG="!W97)D96X@<V]L;#H`3&ES=&5N9F]R
M;6%T(&%U<W?D:&QE;B`H9OQR(&YU;6UE<FEE<G1E($QI<W1E;BD`5^1H;&5N
M(%-I92!D87,@061R97-S8G5C:"!A=7,L('IU(&1E;2!N975E($%D<F5S<V5N
M(&AI;GIU9V5F_&=T('=E<F1E;B!S;VQL96XN`%?D:&QE;B!3:64@9&EE(%)E
M:6AE;F9O;&=E(&1E<B!!9')E<W-B_&-H97(@875S+"!I;B!D96YE;B!N86-H
M($YA;65N(&=E<W5C:'0@=V5R9&5N('-O;&PN`%=E:6AN86-H='-I;G-E;`!+
M;&%S<V5N9&5F:6YI=&EO;B!F_'(@)7,@;FEC:'0@9V5F=6YD96XN`$AE:71E
M<@!-4RU/9F9I8V4M5&%G<R!E;G1F97)N96X`06)F<F%G92!Z=7+\8VMS971Z
M96X`0F5N=71Z97)D871E;B!L]G-C:&5N.B`E<P!"96YU='IE<F1A=&5N(&SV
M<V-H96X`0F5N=71Z97)D871E;B!L]G-C:&5N`%-PY'1E<B!!=69K;&%R96YD
M`$ML:6-K96X@4VEE("5S+"!U;2!D:64@0FEL9&1A=&5I(&EN(&5I;B!&;W)M
M870@=6UZ=7=A;F1E;&XL(&1A<R!):'(@0G)O=W-E<B!D87)S=&5L;&5N(&MA
M;FX`2VQI8VME;B!3:64@)7,L('5M(&1A<R!":6QD(&AE<G5N=&5R>G5L861E
M;BX`2VQI8VME;B!3:64@)7,L('5M('IU("5S+59E<G=A;'1U;F<@>G4@9V5L
M86YG96XN`$ML:6-K96X@4VEE("5S+"!U;2!D96X@2%1-3"U);FAA;'0@:6X@
M96EN96T@;F5U96X@1F5N<W1E<B!A;GIU>F5I9V5N+@!+;&EC:V5N(%-I92`E
M<RP@=6T@96EN92!6;W)S8VAA=2!D:65S97,@0FEL9&5S(&%N>G5Z96EG96XN
M`$ML:6-K96X@4VEE("5S+"!U;2!D96X@06YH86YG(&EN(&5I;F5M(&YE=65N
M($9E;G-T97(@86YZ=7IE:6=E;BX`2VQI8VME;B!3:64@)7,L('5M(&1I97-E
M;B!M=6QT:7!A<G0O<F5L871E9"!.86-H<FEC:'1E;G1E:6P@:6X@96EN96T@
M;F5U96X@1F5N<W1E<B!A;GIU>F5I9V5N+@!(:65R(&ML:6-K96XL('5M($)I
M;&1E<B!A;GIU>F5I9V5N`$ML:6-K96X@4VEE(&%U9B!E:6YE<R!D97(@875S
M9V5WY&AL=&5N($%D<F5S<V+\8VAE<B!U;F0@;6%R:VEE<F5N(%-I92!A;&QE
M($9E;&1E<BP@9&EE(&1U<F-H<W5C:'0@=V5R9&5N('-O;&QE;BX`1F]R=&9A
M:')E;@!(:65R(&ML:6-K96XL('5M(&1E;B#V9F9E;G1L:6-H96X@4$=0+5-C
M:&S\<W-E;"!I;B!):')E;2!!9')E<W-B=6-H('IU('-P96EC:&5R;@!(:65R
M(&ML:6-K96XL('5M(&1A<R!3+TU)344M6F5R=&EF:6MA="!V;VX@)7,@:6X@
M26AR96T@061R97-S8G5C:"!Z=2!S<&5I8VAE<FX`0VQI8VMA=&5L;"!P97(@
M2%144`!+;&EC:R!A=68@9&EE($%D<F5S<V4@]F9F;F5T($9E;G-T97(@>G5M
M($5R<W1E;&QE;B!E:6YE<B!N975E;B!.86-H<FEC:'0@86X@9&5N($%B<V5N
M9&5R`$ML:6-K(&%U9B!D:64@061R97-S92#V9F9N970@9&EE($YA8VAR:6-H
M="!Z=6T@3&5S96X`4V-H;&EEWV5N`$9E;G-T97(@<V-H;&EEWV5N`$1I97-E
M<R!&96YS=&5R('-C:&QI9=]E;@!'97-C:&QO<W-E;F5R($]R9&YE<@!7;VQK
M96X`1G+\:"!7;VQK96X`0F5W]FQK=`!+;VMO<VEN<V5L;@!38VAL:67?96X`
M06QL92!S7V-H;&EEWV5N`$%L;&4@3W)D;F5R('-C:&QI9=]E;@!/<F1N97(@
M<V-H;&EEWV5N`$UE;OP@96EN9F%H<F5N`%IU<V%M;65N:.1N9V5N9&4@4F%H
M;65N`$MO;'5M8FEE;@!&87)B90!&87)B;6%R:VEE<G5N9SH@`$9A<F)A=7-W
M86AL`$9A<F)W86AL`%-P86QT96XZ`%-P86QT96[\8F5R<V-H<FEF=&5N`$-O
M;6EC<P!"969E:&P`0F5F96AL<WIE:6QE`$MO;6UE;G1A<@!%:6YD975T:6=E
M<B!.86UE`$MO;6]R96X`1FER;6$`17)L961I9W0`5V5I=&5R92!.86-H<FEC
M:'0@=F5R9F%S<V5N`$YE=64@3F%C:')I8VAT96X@:6X@<V5P87)A=&5M($9E
M;G-T97(@=F5R9F%S<V5N/P!.86-H<FEC:'1E;B!S=&%N9&%R9&WDWVEG(&UI
M="!E:6YE;2!765-)5UE'+45D:71O<B!E<G-T96QL96X@*&9A;&QS(&1E<B!"
M<F]W<V5R(&1I97-E;B!U;G1E<G-T_'1Z="D_`$-O;7!U=&5R`$)E9&EN9W5N
M9V5N`$)E9&EN9W5N9V5N`$MO;F9I9W5R871I;VYS=6YT97)S8VAI961E`$MO
M;F9I9W5R871I;VX@9&5R(%-Y;F-H<F]N:7IA=&EO;B!M:70@4$1!<RP@4VUA
M<G1P:&]N97,@=6YD($]U=&QO;VLN`$1I92!+;VYF:6=U<F%T:6]N(&UU<W,@
M86MT=6%L:7-I97)T('=E<F1E;BX`)7,@:V]N9FEG=7)I97)E;@!,96=E;B!3
M:64@9F5S="P@=VEE($YA8VAR:6-H=&5N(&%N9V5Z96EG="!W97)D96XN`,1N
M9&5R;B!3:64@9&EE($5I;G-T96QL=6YG96X@9OQR(&1I92!.86-H<FEC:'1E
M;G9O<G-C:&%U+@!087-S=V]R="!B97-TY'1I9V5N`$MO;F=O`$1E;6]K<F%T
M:7-C:&4@4F5P=6)L:6,@2V]N9V\`5F5R8FEN9'5N9R!Z=6T@24U!4"U397)V
M97(@=6YT97)B<F]C:&5N+@!697)B:6YD=6YG(&9E:&QG97-C:&QA9V5N+@!6
M97)B:6YD=6YG(&9E:&QG97-C:&QA9V5N.B``5F5R8FEN9'5N9R!Z=6T@]F9F
M96YT;&EC:&5N(%-C:&S\<W-E;'-E<G9E<B!W=7)D92!A8F=E=VEE<V5N+@!6
M97)B:6YD=6YG('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U
M<F1E(&%B9V5W:65S96XN($=R=6YD.B`E<R`H)7,I`%9E<F)I;F1U;F<@>G5M
M($944"U397)V97(@9F5H;&=E<V-H;&%G96X`5F5R8FEN9'5N9R!Z=6T@4V5R
M=F5R(&9E:&QG97-C:&QA9V5N`$MO;G1A:W1E`$1I92!+;VYT86MT92!W=7)D
M96X@97)F;VQG<F5I8V@@26AR96T@061R97-S8G5C:"!H:6YZ=6=E9OQG="X`
M26YH86QT<W1Y<"!D97(@:V]M<')I;6EE<G1E;B!$871E:3H@`$EN:&%L="!V
M;VX@(B5S(@!796ET97(`4$=0+55N=&5R<W3\='IU;F<@9OQR("5S(&MO;F9I
M9W5R:65R96XN`%,O34E-12U5;G1E<G-T_'1Z=6YG(&;\<B`E<R!K;VYF:6=U
M<FEE<F5N+@!.86-H<FEC:'1E;G-U8VAE(&MO;F9I9W5R:65R96XN`$QE9V5N
M(%-I92!F97-T+"!W:64@;V9T(&%U9B!N975E($YA8VAR:6-H=&5N(/QB97)P
M_&9T('=E<F1E;B!S;VQL+"!U;F0@;V(@4VEE(/QB97(@;F5U92!.86-H<FEC
M:'1E;B!B96YA8VAR:6-H=&EG="!W97)D96X@=V]L;&5N+@!497AT+45M;W1I
M8V]N<R!I;B!G<F%F:7-C:&4@=6UW86YD96QN/P!#;V]K+4EN<V5L;@!#;V]K
M:64`7TMO<&EE<F4`2V]P:65R96X@9F5H;&=E<V-H;&%G96XZ("5S`$%U<W=A
M:&P@:V]P:65R96X`2V]P:65R96X@;F%C:`!+;W)R:6=I97)E`$MO<G)I9VEE
M<G1E<B!497AT`$MO<W1E;BU)1`!#;W-T82!2:6-A`$5L9F5N8F5I;FO\<W1E
M`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!01U`@=F5R<V-H;/QS
M<V5L="!W97)D96XZ(`!$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@
M4$=0('5N=&5R>F5I8VAN970@=V5R9&5N.B``1&EE($YA8VAR:6-H="!K;VYN
M=&4@;FEC:'0@;6ET(%,O34E-12!V97)S8VAL_'-S96QT('=E<F1E;BX`1&EE
M($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%,O34E-12!U;G1E<GIE:6-H
M;F5T('=E<F1E;BX`2V]N=&%K="!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@
M=V5R9&5N+B`E<P!697)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!F96AL9V5S
M8VAL86=E;BX`2V]N=&]S=&%N9"!K;VYN=&4@;FEC:'0@_&)E<G!R_&9T('=E
M<F1E;BX@)7,`06YF<F%G92!K;VYN=&4@;FEC:'0@86)G97-C:&QO<W-E;B!W
M97)D96XN($%N9V5G96)E;F5R($=R=6YD.B`E<P!697)B:6YD=6YG('IU;2!,
M1$%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`1E10+59E<F)I;F1U;F<@>G5M
M(%-E<G9E<B`B)7,B(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W97)D96XZ
M("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D
M96XN("5S`$1A<R!61E,M0F%C:V5N9"!K;VYN=&4@;FEC:'0@875F9V5R=69E
M;B!W97)D96XZ("5S`%!'4"U$871E;B!K;VYN=&5N(&YI8VAT(&5N='-C:&S\
M<W-E;'0@=V5R9&5N.B``4R]-24U%+41A=&5N(&MO;FYT96X@;FEC:'0@96YT
M<V-H;/QS<V5L="!W97)D96XN`$MO;G1A:W0@:V]N;G1E(&YI8VAT(&=E;/9S
M8VAT('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&=E
M;/9S8VAT('=E<F1E;BX@)7,`3F%C:')I8VAT96X@:V]N;G1E;B!N:6-H="!A
M=7,@)7,@9V5L]G-C:'0@=V5R9&5N.B`E<P!$87,@06MT=6%L:7-I97)U;F=S
M<VMR:7!T("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`1&EE
M($5M86EL861R97-S92!D97,@16UP9N1N9V5R<R!K;VYN=&4@;FEC:'0@97)M
M:71T96QT('=E<F1E;BX`1&EE(%=A<G1U;F=S875F9V%B96X@:V]N;G1E;B!N
M:6-H="!D=7)C:&=E9OQH<G0@=V5R9&5N+@!$:64@875S9V5WY&AL=&4@1&%T
M96D@:V]N;G1E(&YI8VAT(&%U<R!D96T@35,M5$Y%1BU!;FAA;F<@9V5L97-E
M;B!W97)D96XN`$1I92!A=7-G97?D:&QT92!$871E:2!K;VYN=&4@;FEC:'0@
M875S(&1E;2!:25`M07)C:&EV(&=E;&5S96X@=V5R9&5N+@!$87,@061R97-S
M8G5C:"!K;VYN=&4@;FEC:'0@:V]M<&QE='0@9V5L97-E;B!W97)D96XN`%9E
M<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@
M)7,`3&ES=&4@9&5R(%9E<G1E:6QE<FQI<W1E;B!K;VYN=&4@;FEC:'0@875S
M9V5L97-E;B!W97)D96XN`$1I92!3=')A=&5G:64@(B5S(B!K;VYN=&4@;FEC
M:'0@9V5L861E;B!W97)D96XN`$1A<R!697)Z96EC:&YI<R`B)7,B(&MO;FYT
M92!N:6-H="!A;F=E;&5G="!W97)D96XN`-9F9F5N=&QI8VAE<B!38VAL_'-S
M96P@:V]N;G1E(&YI8VAT('9O;2!38VAL_'-S96QS97)V97(@9V5H;VQT('=E
M<F1E;BX`(B5S(B!K;VYN=&4@;FEC:'0@>G5M(%-C:')E:6)E;B!G9?9F9FYE
M="!W97)D96XN`"5S(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX`1&%S
M($UA:6YT96YA;F-E7U1A<VL@36]D=6P@)7,@:V]N;G1E(&YI8VAT(&=E]F9F
M;F5T('=E<F1E;@!697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!G9?9F
M9FYE="!W97)D96XN`%-I8VAE<F4@5F5R8FEN9'5N9R!Z=6T@24U!4"U397)V
M97(@:V%N;B!N:6-H="!H97)G97-T96QL="!W97)D96XN("5S(#H@)7,N`%9E
M<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&MO;FYT92!N:6-H="!H97)G97-T
M96QL="!W97)D96XN`"5S(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX`
M1&%S(%!A<W-W;W)T(&;\<B!D96X@86YG96=E8F5N96X@0F5N=71Z97(@:V]N
M;G1E(&YI8VAT('IU<OQC:V=E<V5T>G0@=V5R9&5N+"!W96EL(&5I;FEG92!!
M;F=A8F5N(&YI8VAT(')I8VAT:6<@=V%R96XN(%9E<G-U8VAE;B!3:64@97,@
M97)N975T(&]D97(@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T
M<F%T;W(L('=E;FX@4VEE('=E:71E<F4@2&EL9F4@8F5N]G1I9V5N+@!!0TP@
M:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N`$1A<R!!9')E<W-B=6-H(&MO
M;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@
M:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<P!697)T96EL97)L
M:7-T96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<P!$:64@
M3F%M97-P86-E+4EN9F]R;6%T:6]N96X@:V]N;G1E;B!N:6-H="!V;VT@24U!
M4"U397)V97(@875S9V5L97-E;B!W97)D96XN`$1I92!397)V97)FY&AI9VME
M:71E;B!K;VYN=&5N(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N`$MO;F9I9W5R
M871I;VX@:V]N;G1E(&YI8VAT('IU<OQC:V=E<V5T>G0@=V5R9&5N+@!697)Z
M96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`"5S
M+4MO;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E
M;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P
M96EC:&5R="!W97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B!K;VYN
M=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N.B`E<P!$87,@06MT=6%L:7-I
M97)U;F=S<VMR:7!T(&MO;FYT92!N:6-H="!N86-H("(E<R(@9V5S<&5I8VAE
M<G0@=V5R9&5N+@!"86-K=7`@9&5R($MO;F9I9W5R871I;VX@)7,@:V]N;G1E
M(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`1&EE($MO;F9I9W5R871I;VX@
M)7,@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX@4VEE(&OV;FYE
M;B!E;G1W961E<B!E:6YE(&1E<B!-]F=L:6-H:V5I=&5N('5N=&5R("5S('9E
M<G=E;F1E;BP@=6T@9&5N($-O9&4@>G4@<W!E:6-H97)N+"!O9&5R(&1E;B!U
M;G1E;G-T96AE;F1E;B!#;V1E(&UA;G5E;&P@;F%C:"`E<R!K;W!I97)E;BX`
M1&5R($Q$05`M4V5R=F5R(&MO;FYT92!N:6-H="!D=7)C:'-U8VAT('=E<F1E
M;BX`(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!$97(@2V]N
M=&%K="!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B`E<P!697)T
M96EL97)L:7-T92!K;VYN=&4@;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;BX@
M)7,`1&EE($MO;F9I9W5R871I;VX@9OQR("(E<R(@:V]N;G1E(&YI8VAT(&=E
M<W!E:6-H97)T('=E<F1E;CH@)7,`1&EE($UO>FEL;&$@4VED96)A<B!K;VYN
M=&4@;FEC:'0@9V5F=6YD96X@=V5R9&5N+B!3=&5L;&5N(%-I92!S:6-H97(L
M(&1A<W,@9&EE(%-I9&5B87(@9V7V9F9N970@:7-T+@!$96T@0F5N=71Z97(@
M(B5S(B!K;VYN=&5N(&1I92!F;VQG96YD92!296-H=&4@9OQR(&1E;B!/<F1N
M97(@(B5S(B!N:6-H="!Z=6=E=VEE<V5N('=E<F1E;CH@)7,`1V5ZY&AL=&5R
M(%1E>'0`3&%N9`!+=7)S90!%<G-T96QL96X`3W)D;F5R(&5R<W1E;&QE;@!3
M8VAL_'-S96P@97)S=&5L;&5N`$5I;B!N975E<R!+;VYT;R!A;FQE9V5N`$QI
M;FL@97)S=&5L;&5N`$5I;F5N(&YE=65N(%-P86TM3W)D;F5R(&%N;&5G96X`
M16EN96X@;F5U96X@3W)D;F5R(&;\<B!%;G1W_')F92!A;FQE9V5N`$YE=64@
M261E;G1I=.1T(&%N;&5G96X`16EN96X@;F5U96X@3W)D;F5R(&;\<B!G97-E
M;F1E=&4@3F%C:')I8VAT96X@86YL96=E;@!%:6YE;B!N975E;B!/<F1N97(@
M9OQR(&1E;B!087!I97)K;W)B(&%N;&5G96X`3&5G96X@4VEE($9I;'1E<G)E
M9V5L;B!A;BP@=6T@26AR92!E:6YG96AE;F1E;B!.86-H<FEC:'1E;B!Z=2!O
M<F=A;FES:65R96XL(&EN($]R9&YE<B!Z=2!S;W)T:65R96X@=6YD(%-P86T@
M>G4@;/9S8VAE;BX`3F5U92!6;W)L86=E(&%N;&5G96X`17)S=&5L;&5N(%-I
M92!&;W)M871V;W)L86=E;B!U;F0@4W1A;F1A<F1A;G1W;W)T96XN`%5N=&5R
M;W)D;F5R(&5R<W1E;&QE;@!%<G-T96QL97)R96-H=&4`2W)E9&ET:V%R=&5N
M;G5M;65R`$MR;V%T:65N`$MU8F$`06MT=65L;&4@-"!0:&%S96X`06MT=65L
M;&4@4V5S<VEO;G,`06MT=65L;&4@6F5I=`!!:W1U96QL92!54DP@:7-T`$%K
M='5E;&QE($)E;G5T>F5R`$%K='5E;&QE<R!7971T97(`06MT=65L;&4@4F5C
M:'1E('9O;B`E<P!$97)Z96ET:6=E($)E9&EN9W5N9V5N.B``06MT=65L;&5R
M(%-T:6P`3&5G96X@4VEE(&1I92!+;VYT96X@9F5S="P@=F]N(&1E;F5N($5M
M86EL<R!E:6YG97-A;6UE;'0@=V5R9&5N('-O;&QE;BX`3&5G96X@4VEE(&9E
M<W0L('=I92!.86-H<FEC:'1E;B!V97)S96YD970@=V5R9&5N+@!,96=E;B!3
M:64@9F5S="P@=V5L8VAE($%U9F=A8F5N(&YA8V@@9&5R($%N;65L9'5N9R!B
M96D@)7,@97)L961I9W0@=V5R9&5N('-O;&QE;BX`075S<V-H;F5I9&5N`$%U
M<W=A:&P@875S<V-H;F5I9&5N`%IY<&5R;@!+>7)I;&QI<V-H("A+3TDX+5(I
M`$MY<FEL;&ES8V@@*%=I;F1O=W,M,3(U,2D`2WER:6QL:7-C:"]5:W)A:6YI
M<V-H("A+3TDX+54I`%1S8VAE8VAI<V-H92!297!U8FQI:P!45`!$4TX@*'-I
M96AE(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`5.1G;&EC:`!$871?=6T`1&%T851R
M964@0G)O=W-E<@!$871E;F)A;FMA8F9R86=E`$1A='5M`$5M<&9A;F=S9&%T
M=6T`1&%T=6US875S=V%H;`!486<`4W!A;'1E(%]L]G-C:&5N`$1E>F5M8F5R
M`%IA:&QE;@!!8F=E;&5H;G0`06)G96QE:&YT.B``16EN>G5G('9E<G)I;F=E
M<FX`4W1A;F1A<F0`4W1A;F1A<F1F87)B90!3=&%N9&%R9&ED96YT:73D=`!3
M=&%N9&%R9'-U8VAF96QD`%-T86YD87)D<VAE;&P`4V]R=&EE<G)E:6AE;F9O
M;&=E.@!3;W)T:65R<FEC:'1U;F<Z`$1E9FEN:71I;VYE;@!$96QE9VEE<G0`
M3/9S8VAE;@#69F9E;G1L:6-H96X@4V-H;/QS<V5L("5S(&SV<V-H96X`6F5L
M;&4@;/9S8VAE;@!!:W1U96QL96X@4V-H;/QS<V5L(&SV<V-H96X`3W)D;F5R
M(&SV<V-H96X`1W)U<'!E(&SV<V-H96X`3&]G(&SV<V-H96X`4F5C:'1E(&SV
M<V-H96X`075S9V5WY&AL=&4@3W)D;F5R(&SV<V-H96X`5F]R;&%G92!L]G-C
M:&5N`%9I<G1U96QL96X@3W)D;F5R(&SV<V-H96X`5FER='5E;&QE;B!/<F1N
M97(@)7,@;/9S8VAE;@!.86-H<FEC:'1E;B!L]G-C:&5N('5N9"!E;G1F97)N
M96X`6F5L;&4@;/9S8VAE;@!3<&%L=&4@;/9S8VAE;@!"97-T96AE;F1E(&%L
M=&5R;F%T:79E(%9O<FQA9V4@;/9S8VAE;@!6;VT@4V5R=F5R(&AE<G5N=&5R
M9V5L861E;F4@3F%C:')I8VAT96X@;/9S8VAE;C\`075S(&UE:6YE;2!+86QE
M;F1E<B!E;G1F97)N96X`3F%C:')I8VAT96X@;/9S8VAE;@!!;'1E('9E<FQI
M;FMT92!!;FCD;F=E(&%M($UO;F%T<V)E9VEN;B!L]G-C:&5N/P!!;'1E($]R
M9&YE<B!F_'(@9V5S96YD971E($YA8VAR:6-H=&5N(&%M($UO;F%T<V)E9VEN
M;B!L]G-C:&5N/P!296-H=&4@9OQR("(E<R(@;/9S8VAE;@!296-H=&4@9OQR
M("(E<R(@=6YD(&%L;&4@56YT97)R96-H=&4@;/9S8VAE;C\`6F5I;&4@;/9S
M8VAE;@!!=7-G97?D:&QT92!)9&5N=&ETY'0@;/9S8VAE;@!3<&%M+4YA8VAR
M:6-H=&5N(&SV<V-H96X`56YT97)O<F1N97(@;/9S8VAE;@!$:64@86MT=65L
M;&4@4W!A;'1E(&SV<V-H96X`1&EE(&%K='5E;&QE(%IE:6QE(&SV<V-H96X`
M1V5L]G-C:'0`1V5L]G-C:'1E($YA8VAR:6-H=&5N`$1A<R!!:W1U86QI<VEE
M<G5N9W-S:W)I<'0@(B5S(B!W=7)D92!G96SV<V-H="X`1&5R($%N:&%N9R`B
M)7,B('=U<F1E(&=E;/9S8VAT+@!.86-H<FEC:'1E;B!L]G-C:&5N('5N9"!V
M97)S8VAI96)E;@!!=7-L:65F97)U;F=S>F5I=`!$Y&YE;6%R:P!!;F9R86=E
M(&%B;&5H;F5N`$%N9G)A9V4@9OQR($9R96DO1V5B=6-H="U);F9O<FUA=&EO
M;F5N(&%B;&5H;F5N`$%B<W1E:6=E;F0`0F5S8VAR96EB96X@4VEE(&1A<R!0
M<F]B;&5M`$)E<V-H<F5I8G5N9P!$971A:6QS`$1E=&%I;',@*&%U8V@@:6X@
M2&]R9&5S($QO9V1A=&5I*3H`1&5T86EL<R!W=7)D96X@9OQR(&1E;B!!9&UI
M;FES=')A=&]R(&UI=&=E;&]G9W0N`$5N='=I8VML=6YG`%1A=7!U;FMT`%1A
M=7!U;FMT(&1E<B!L971Z=&5N(%-T=6YD93H@`%1A=7!U;FMT.B``(B5S(B!W
M=7)D92!N:6-H="!A;F=E:.1N9W0L('=E:6P@9&EE($1A=&5I(&QE97(@=V%R
M+@!3:6=N871U<F5N(&%B8FQE;F1E;C\`5F]N(&QI;FMS(&YA8V@@<F5C:'1S
M`%9O;B!R96-H=',@;F%C:"!L:6YK<P!697)Z96EC:&YI<P!!;GIE:6=E`%IE
M:70@:6T@,C0M4W1U;F1E;BU&;W)M870@86YZ96EG96X_`$%N>F5I9V4M16EN
M<W1E;&QU;F=E;@!"97-TY'1I9W5N9R!N86-H(&1E;2!697)S96YD96X@=F]N
M($YA8VAR:6-H=&5N(&%N>F5I9V5N/P!$971A:6QI97)T92!6;W)H97)S86=E
M(&%N>F5I9V5N`%9O<FAE<G-A9V4@*%1!1BD@86YZ96EG96X`06YZ96EG969O
M<FUA=`!%:6YG96)E='1E="!I;2!.86-H<FEC:'1E;G1E>'0`075F(&YE=64@
M3F%C:')I8VAT96X@9'5R8V@@4&]P=7`M1F5N<W1E<B!H:6YW96ES96X_`")3
M<&%M($SV<V-H96XB+45I;G1R86<@:6X@9&5R($UE;OQZ96EL92!A;GIE:6=E
M;C\`(E!A<&EE<FMO<F(@;&5E<F5N(BU%:6YT<F%G(&EN(&1E<B!-96[\>F5I
M;&4@86YZ96EG96X_`$5I;F)I;F1U;F<`16UP9F%N9W-B97-TY'1I9W5N9P!$
M<V-H:6)U=&D`5')I9F9T($Y)0TA4('IU`$]R9&YE<B!N:6-H="!A=68@;F5U
M92!.86-H<FEC:'1E;B#\8F5R<'+\9F5N`$YI8VAT(&SV<V-H96X`1W)E:69E
M;B!3:64@;FEC:'0@9&ER96MT(&%U9B!M86EN=&5N86YC92YP:'`@>G4`2V5I
M;B!697)W96ES(&EN(&1E<B!6;VXZ(%-P86QT92!E<GIE=6=E;@!-]F-H=&5N
M(%-I92!D:65S96X@3W)D;F5R(/9F9FYE;C\`16YT:.1L="!D:64@97)S=&4@
M6F5I;&4@9&EE($9E;&1N86UE;C\@5V5N;B!J82P@9&EE<V5S($%U<W=A:&QK
MY'-T8VAE;B!M87)K:65R96XZ`$1O;6EN:6-A`$1O;6EN:6MA;FES8VAE(%)E
M<'5B;&EK`$YO8V@@:V5I;F5N(%IU9V%N9S\@2&EE<B!A;FUE;&1E;BX`1F5R
M=&EG`$AE<G5N=&5R;&%D96X`)7,@2&5R=6YT97)L861E;@`E<R!A;',@6DE0
M+41A=&5I(&AE<G5N=&5R;&%D96X`06QL92!!;FCD;F=E("AA;',@6DE0+41A
M=&5I*2!H97)U;G1E<FQA9&5N`$]R9&YE<B!H97)U;G1E<FQA9&5N`$]R9&YE
M<B!H97)U;G1E<FQA9&5N("AA;',@6DE0+41A=&5I*0!%<GIE=6=T92!+;VYF
M:6=U<F%T:6]N(&%L<R!02%`M4VMR:7!T(&AE<G5N=&5R;&%D96XN`$%L<R!:
M25`M1&%T96D@:&5R=6YT97)L861E;@!%;G1W=7)F`$5N='?\<F9E+4]R9&YE
M<@!%;G1W_')F92U/<F1N97(Z`$%U<W=A:&QL:7-T90!$<F]G96X`16UA:6P`
M16UA:6QA9')E<W-E`$5M86EL+6YA8V@M4TU3+6=A=&5W87D@9OQR(%!R;W9I
M9&5R+"!D:64@96EN96X@<V]L8VAE;B!$:65N<W0@=6YT97)S=/QT>F5N+@!%
M3D1%`$9%2$Q%4@!&14A,15(Z($EH<F4@3F%C:')I8VAT(&MO;FYT92!N:6-H
M="!V97)S8VAI8VMT('=E<F1E;BX`16-U861O<@!"96%R8F5I=&5N`$%U<W-C
M:&QU<W-L:7-T92!B96%R8F5I=&5N`$)L;V-K(&)E87)B96ET96X`1FEL=&5R
M(&)E87)B96ET96X`1W)U<'!E(&)E87)B96ET96X`4F5C:'1E(&)E87)B96ET
M96X`4F5C:'1E(&)E87)B96ET96X`4F5C:'1E(&;\<B`G)7,G(&)E87)B96ET
M96X`4W5C:&%N9G)A9V4@8F5A<F)E:71E;@!6:7)T=65L;&5N($]R9&YE<B!B
M96%R8F5I=&5N`%9I<G1U96QL96X@3W)D;F5R("5S(&)E87)B96ET96X`4&]S
M:71I=FQI<W1E(&)E87)B96ET96X`16EN<W1E;&QU;F=E;B!B96%R8F5I=&5N
M(&;\<CH`4F5C:'1E(&;\<B`B)7,B(&)E87)B96ET96X`4F5C:'1E(&;\<B`E
M<R!B96%R8F5I=&5N`$%U<W-C:&QU<W-L:7-T92!B96%R8F5I=&5N`$9I;'1E
M<G)E9V5L;B!B96%R8F5I=&5N`$5I;G-T96QL=6YG96X@9OQR(&1E;B!:=6=R
M:69F(&%U9B!A;F1E<F4@2V]N=&5N(&)E87)B96ET96XN`%!O<VET:79L:7-T
M92!B96%R8F5I=&5N`$)I;&1U;F<`Q&=Y<'1E;@!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL861R97-S90!$:64@16UA:6QA9')E<W-E
M;B!M_'-S96X@9VQE:6-H('-E:6XN`$5M86EL(&UI="!"97-TY'1I9W5N9P!%
M;6%I;"UN86-H+5--4RU'871E=V%Y`%-M:6QE>7,`06QL92!.86-H<FEC:'1E
M;B!A=7,@)7,@9V5L]G-C:'0N`$%L;&4@3F%C:')I8VAT96X@875S(&1E;2!6
M:7)T=65L;&5N(%!A<&EE<FMO<F(@9V5L]G-C:'0N`$]R9&YE<B!L965R96X`
M075S9V5WY&AL=&4@3W)D;F5R(&QE97)E;@!087!I97)K;W)B(&QE97)E;@!3
M<&%M(&SV<V-H96X`4&%P7VEE<FMO<F(@;&5E<F5N`$QE97)E($YA8VAR:6-H
M="X`3&5E<F5S($5R9V5B;FES+@!3=6-H8F5G<FEF9F4@;/9S8VAE;@!01U`M
M1G5N:W1I;VYE;B!A:W1I=FEE<F5N/P!3+TU)344M1G5N:W1I;VYE;B!A:W1I
M=FEE<F5N/P!%:6YF_&=E;B!V;VX@0FEL9&5R;B!A=7,@1F]T;V=A;&5R:65N
M(&EN(&1E;B!497AT(&5R;&%U8F5N/P!.86-H<FEC:'1E;G9O<G-C:&%U(&%K
M=&EV:65R96X_`$MO;G1E>'1M96[\(&)E:2!296-H='-K;&EC:R!A:W1I=FEE
M<F5N/P!?5F5R<V-H;/QS<V5L=6YG<RU%:6YS=&5L;'5N9V5N`%9E<G-C:&S\
M<W-E;'0`16YD90!%;F1E(&1E<B!W96ET97)G96QE:71E=&5N($YA8VAR:6-H
M=`!%;F1E(&1E<B!.86-H<FEC:'0`16YD92!D97(@3F%C:')I8VAT('9O;B`E
M<P!%;F1J86AR`$5D:71O<B!V97)G<O;?97)N`%!A<W-W;W)T(&5I;F=E8F5N
M`$=E8F5N(%-I92!E:6YE(%-I8VAE<FAE:71S9G)A9V4@96EN+"!D:64@26AN
M96X@9V5S=&5L;'0@=VER9"P@=V5N;B!3:64@26AR(%!A<W-W;W)T('IU<OQC
M:W-E='IE;B!M]F-H=&5N+"!Z+B!"+B`B5VEE(&QA=71E="!D97(@3F%M92!)
M:')E<R!(875S=&EE<G,_(CH`2&EE<B!D:64@0FEL9"U54DP@86YG96)E;@!'
M96)E;B!S:64@9&EE($)U8VAS=&%B96X@=6YT96X@96EN.@!'96)E;B!3:64@
M96EN96X@3F%M96X@9OQR($EH<F5N(&YE=65N(%-P86TM3W)D;F5R(&5I;@!'
M96)E;B!3:64@96EN96X@3F%M96X@9OQR($EH<F5N(&YE=65N($5N='?\<F9E
M+4]R9&YE<B!E:6X`1V5B96X@4VEE(&5I;F5N($YA;65N(&;\<B!D96X@3W)D
M;F5R(&%N+"!I;B!D96T@26AR92!G97-E;F1E=&5N($YA8VAR:6-H=&5N(&=E
M<W!E:6-H97)T('=E<F1E;B!S;VQL96X`1V5B96X@4VEE(&5I;F5N($YA;65N
M(&;\<B!):')E;B!N975E;B`B4&%P:65R:V]R8B(M3W)D;F5R(&5I;@!'97-A
M;71E($YA8VAR:6-H=`!$97(@16EN=')A9R`B)7,B('=U<F1E(&5R9F]L9W)E
M:6-H(&1E;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T`,1Q=6%T;W)I86PM1W5I
M;F5A`$5R:71R96$`1F5H;&5R`%9E<F)I;F1U;F<@>G5M($E-05`M4V5R=F5R
M(&MA;FX@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N+B`E<R`Z("5S+@!&96AL
M97(@8F5I;2!%<G-T96QL96X@96EN97,@0FQO8VMS.B`E<P!&96AL97(@8F5I
M;2!,]G-C:&5N(&1E<R!3>6YC:')O;FES871I;VYS86YK97)S.B`E<P!&96AL
M97(@8F5I;2!,]G-C:&5N(&1E<R!3>6YC:')O;FES871I;VYS;&]G<SH@)7,`
M1F5H;&5R(&)E:6T@17)Z975G96X@9&5S($EN:&%L=',Z("5S`$9E:&QE<B!B
M96EM(%9E<G-E;F1E;B!D97(@06YT=V]R=#H@)7,`1F5H;&5R(&)E:6T@Q&YD
M97)N(&1E<R!087-S=V]R=',Z("5S`$9E:&QE<B!I;B!D97(@16UA:6QN86-H
M<FEC:'0N`$9E:&QE<B!B96EM(%-C:')E:6)E;B!V;VX@(B5S(BX`17-T;&%N
M9`#$=&AI;W!I96X`171N:7-C:&5S`$5U<F]P80!497)M:6X@97)F;VQG<F5I
M8V@@9V5L]G-C:'0N`$%L;&4@,34@36EN=71E;@!!;&QE(#(@36EN=71E;@!!
M;&QE(#,P(%-E:W5N9&5N`$%L;&4@-2!-:6YU=&5N`$)E:2!J961E<B!!;FUE
M;&1U;F<`06QL92!H86QB92!3='5N9&4`06QL92`V,"!396MU;F1E;@!"96ES
M<&EE;'=E<G1E.@!!=7-F_&AR96X`5F5R9W+VWV5R;@!!;&QE(/9?9F9N96X`
M06QL92!/<F1N97(@]F9F;F5N`$]R9&YE<B#V9F9N96X`3F%M96X@<W5C:&5N
M`$UE;OP@875S9F%H<F5N`$YA;65N(&)E:6T@17)S=&5L;&5N(&YE=65R($YA
M8VAR:6-H=&5N(&%U=&]M871I<V-H(&EM($AI;G1E<F=R=6YD('9E<G9O;&QS
M=.1N9&EG96X_`$EN(&1E<B!/<F1N97)A;G-I8VAT(&%L;&4@3W)D;F5R(/9F
M9FYE;C\`4W5C:&4`)RDG(&5R=V%R=&5T`$5I;GIE;&YE<R!7;W)T(&]D97(@
M4W5C:&)E9W)I9F8@:6X@06YF_&AR=6YG<WIE:6-H96X@97)W87)T970`5F5R
M9F%L;'-D871U;0!%>'!O;F5N=`!6;W)D97)G<G5N9&9A<F)E`$AO8VAL861E
M;B!D97(@2V]N9FEG=7)A=&EO;B!P97(@1E10`$YA8VAR:6-H=&5N('-A;6UE
M;&X`0F5N=71Z97)E:6YS=&5L;'5N9V5N(&MO;FYT96X@;FEC:'0@9V5L861E
M;B!W97)D96XN`%9E<F)I;F1U;F<@>G5M($Q$05`@4V5R=F5R(&=E<V-H96ET
M97)T+@!697)B:6YD=6YG('IU;2!334(M4V5R=F5R(&=E<V-H96ET97)T+@!%
M<R!K;VYN=&4@:V5I;F4@2V]P:64@=F]N("(E<R(@97)S=&5L;'0@=V5R9&5N
M+@!%<R!K;VYN=&4@;FEC:'0@;F%C:"`B)7,B(&MO<&EE<G0@=V5R9&5N+@!!
M=69B874@96EN96X@;F5U96X@4T%33"U697)B:6YD=6YG(&ES="!F96AL9V5S
M8VAL86=E;BX`17,@:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!V97)S8VAO8F5N
M('=E<F1E;BX`1F5H;&5R(&)E:6T@3&5S96XZ("5S`$AE:71E<@!&86QK;&%N
M9&EN<V5L;@!&87+V97(`4V-H=V5R97(@1F5H;&5R.@!&87@`1F%X90!&96)R
M=6%R`$=E9OQH;'1E(%1E;7!E<F%T=7(`1V5F_&AL=&4@5&5M<&5R871U<CH@
M`$YA8VAR:6-H=&5N('-A;6UE;&X`3F%C:')I8VAT96X@:6X@96EN96T@;F5U
M96X@1F5N<W1E<B!E:6YS86UM96QN/P!.86-H<FEC:'1E;B!B96EM($%N;65L
M9&5N(&5I;G-A;6UE;&X_`"5D($YA8VAR:6-H=&5N('9O;B`E<R!E:6YG97-A
M;6UE;'0N`#$@3F%C:')I8VAT('9O;B`E<R!E:6YG97-A;6UE;'0N`$YA8VAR
M:6-H=&5N('-A;6UE;&XZ(`!.86-H<FEC:'1E;B!S86UM96QN.B!3:64@:&%B
M96X@:V5I;F4@;F5U92!.86-H<FEC:'1E;BX`5F5R96EN>F5L=&4@4V-H875E
M<@!697)E:6YZ96QT92!38VAN965S8VAA=65R`%]&:6QT97(`1F5L9&UA=')I
M>`!&:6=L970@0T%05$-(00!&:6=L970M1F]N=`!&:61S8VAI`$1A=&5I`$%N
M>F%H;#H@)7,@1&%T96D`06YZ86AL.B`E<R!$871E:65N`$1A=&5I;6%N86=E
M<@!$871E:6YA;64`1&%T96EA=7-W86AL`$1A=&5I+4AO8VAL861E;@!$87,@
M2&]C:&QA9&5N('9O;B!$871E:65N('=I<F0@;FEC:'0@=6YT97)S=/QT>G0N
M`$9I;'1E<BU%:6YS=&5L;'5N9V5N`$9I;'1E<BU%:6YS=&5L;'5N9V5N`$YA
M8VAR:6-H=&5N(&YA8V@@=6YE<G?\;G-C:'1E;B!);FAA;'1E;B!F:6QT97)N
M/P!$:64@1FEL=&5R+55N=&5R<W3\='IU;F<@=W5R9&4@875F(&1I97-E;2!3
M>7-T96T@9&5A:W1I=FEE<G0N`$9I;'1E<@!&:6QT97(@<VEN9"!.24-(5"!A
M:W1I=FEE<G0`1FEL=&5R.B`E<RU697)W86QT=6YG`%-U8VAE`$9I;FYL86YD
M`$5R<W1E($CD;&9T90!%<G-T92!/<F1N97)S96ET90!%<G-T92!396ET90!%
M<G-T97,@5FEE<G1E;`!697)HY&QT;FES('IU<OQC:W-E='IE;@!5;61R96AE
M;@!497AT9FQUWP!?5V5I=&5R;&5I=&5N`$YE8F5L`$1A<R!697)Z96EC:&YI
M<R`E<R!E>&ES=&EE<G0@;FEC:'0`3W)D;F5R86MT:6]N96X@+2!"97-TY'1I
M9W5N9P!/<F1N97(@3F%V:6=A=&EO;@!/<F1N97+\8F5R<VEC:'0`1&EE(&=E
M;65I;G-A;64@3G5T>G5N9R!V;VX@3W)D;F5R;B!I<W0@;FEC:'0@;?9G;&EC
M:"X`1&EE($)E;G5T>G5N9R!V;VX@3W)D;F5R;B!I<W0@;FEC:'0@86MT:79I
M97)T+@!38VAR:69T9F%R8F4`17-S96X`1OQR($)R;W=S97(L(&1I92!K96EN
M92!":6QD97(@=6YT97)S=/QT>F5N`%9O<FAE<G-A9V4@*%1!1BD`5F]R:&5R
M9V5S86=T92!486=E("A6;W)H97)S86=E;B!E;G1H86QT96X@5&%G92!U;F0@
M3N1C:'1E+"!E:6X@:&]H97(@5V5R="!K86YN('IU(&5I;F5M('-E:'(@9W)O
MWV5N($)L;V-K(&;\:')E;BD`4&%S<W=O<G0@=F5R9V5S<V5N/P!$871U;7-F
M;W)M870@9OQR($YA8VAR:6-H=&5N('9O;B!H975T92!I;B!D97(@3W)D;F5R
M86YS:6-H=`!&;W)M=6QA<F4`1VS\8VMS:V5K<P!';/QC:W-K96MS='EP`$=L
M_&-K<VME:W-E`$=L_&-K<VME:W-E(#(`1F]R96X`5V5I=&5R;&5I=&5N`%=E
M:71E<FQE:71E;CH`5V5I=&5R9V5L96ET971E($YA8VAR:6-H=`!796ET97)G
M96QE:71E=&4@3F%C:')I8VAT('9O;B`E<P!796ET97)L96ET=6YG`$9R`%)A
M:&UE;@!&<F%N:W)E:6-H`$5U<F]PY&ES8VAE<R!&<F%N:W)E:6-H`$%N='=O
M<G0@875F($9R96DO1V5B=6-H="U!;F9R86=E`$9R86YZ]G-I<V-H+4=U87EA
M;F$`1G)A;GKV<VES8V@M4&]L>6YE<VEE;@!&<F%N>O9S:7-C:&4@1V5B:65T
M92!I;2!S_&1L:6-H96X@26YD:7-C:&5N($]Z96%N`%]6;VX`5F]N`%9O;B!!
M9')E<W-E`$%U<R``5F]L;'-TY&YD:6=E($)E<V-H<F5I8G5N9P!6;VQL;6]N
M9`!6;VQL<W3D;F1I9V5R($YA;64`1G=D.@!71SH@`%='.B`E=2!W96ET97)G
M96QE:71E=&4@3F%C:')I8VAT96X`1V%B=6X`0FEL9&5R(&%U<R!D:65S97(@
M1V%L97)I90!'86QE<FEE.@!'86UB:6$`06QL9V5M96EN92!%:6YS=&5L;'5N
M9V5N`"5S+4MO;F9I9W5R871I;VX@97)Z975G96X`17)Z975G=&5R($-O9&4`
M1V5O<F=I96X`1&5U='-C:&QA;F0`3G5R(&YE=64@3F%C:')I8VAT96X@86)R
M=69E;C\@*&YU<B!)34%0*0!':&%N80!':6)R86QT87(`5F]R;F%M90!!;&QG
M96UE:6YE($5I;G-T96QL=6YG96X`3&]S`%IU(&1I97-E<B!.86-H<FEC:'0`
M6G5M($%D<F5S<V)U8VAE:6YT<F%G('9O;B`B)7,B`$=O961E;`!';V]G;&4@
M36%P<P!';V]G;&4@4W5C:&4`6G5G<FEF9B!E<FQA=6)E;@!'<F%U<W1U9F5N
M`$=R:65C:&5N;&%N9`!'<FEE8VAI<V-H("A)4T\M.#@U.2TW*0!'<O9N;&%N
M9`!'<F5N861A`$=R=7!P96YV97)W86QT=6YG`$=R=7!P96YN86UE;B!D_')F
M96X@;FEC:'0@;&5E<B!S96EN`$=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@
M:V]N;G1E(&YI8VAT(&AI;GIU9V5F_&=T('=E<F1E;BX@365L9'5N9R!D97,@
M4V5R=F5R<SH@`$=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@:V]N;G1E(&YI
M8VAT(&=E;/9S8VAT('=E<F1E;@!'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S
M(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N`$=R=7!P96X`1W5A
M9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'87-T<F5C:'1E`$?D
M<W1E8G5C:`!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2$E%4@!(5$U,
M`$A434PM5F5R<VEO;B!D97(@3F%C:')I8VAT`$1E<B!%9&ET;W(@:V%N;B!D
M:64@;&5T>G1E(%IE;&QE(&5I;F5R(%IE:6QE(&YI8VAT(&SV<V-H96XN`$1E
M<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%-P86QT92!E:6YE<B!486)E;&QE
M(&YI8VAT(&SV<V-H96XN`$1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%IE
M:6QE(&5I;F5R(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BX`2%144"U!=71H96YT
M:69I>FEE<G5N9R!N:6-H="!G969U;F1E;BX`2&%I=&D`2&%S:"U!;&=O<FET
M:&UU<P!$:65S:6<`W&)E<G-C:')I9G0`2V]P9F5I;G1RY&=E`$AE87)D+2!U
M;F0@36-$;VYA;&1I;G-E;&X`4V-H=V5R92!'97=I='1E<@!(96)RY&ES8V@@
M*$E33RTX.#4Y+3@M22D`2/9H90!(:6QF90!%9&ET;W)H:6QF90!(:6QF90!(
M96UI<W!H97)E`$1I97,@:7-T(&1E<B!"96=I;FX@9&5R($1A=&5I.@!(:65R
M(&9I;F1E;B!3:64@9&5N(%1E>'0@9&5R($YA8VAR:6-H="P@9&EE(%-I92!E
M<G-T96QL="!H86)E;CH`5F5R<W1E8VMT`%9E<G-T96-K="!I;B!D97(@5&AE
M;65N86YS:6-H=`!697)S=&5C:V4@9V5L]G-C:'1E`%]!=7-G96)L96YD971E
M($]R9&YE<B!V97)S=&5C:V5N`$AO8V@`2&]H92!0<FEO<FETY'0`2/9C:'-T
M90!?4W1A<G1S96ET90!6871I:V%N<W1A9'0`4W1A<G1S96ET90!!9')E<W-E
M('!R:79A=`!(96EM=F5R>F5I8VAN:7,`5&5L969O;B!P<FEV870`2&]N9'5R
M87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!5;F?\;'1I9V4@)7,M
M6$U,+41A=&5N(&EN($YA8VAR:6-H="`E<P!(;W)D92]+;VQA8CH@17,@<&%S
M<W0@:V5I;F4@3F%C:')I8VAT('IU;2!/8FIE:W0@)7,`2&]R9&4O2V]L86(Z
M($ME:6X@3V)J96MT('9O;2!4>7`@)7,@:6X@3F%C:')I8VAT("5S(&=E9G5N
M9&5N`$AO<F1E+TMO;&%B.B`E<R`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&5N
M=&9E<FYT`$AO<F1E+TMO;&%B.B!$:64@26YT96=R871I;VYS9G5N:W1I;VYE
M;B!B96[V=&EG96X@9&EE(")D;VUX;6PB(%!(4"U%<G=E:71E<G5N9P!(;W)D
M92]+;VQA8CH@1OQR(&1A<R!/8FIE:W0@)7,@:V]N;G1E(&ME:6X@;F5U97(@
M6$U,+4)A=6T@97)Z975G="!W97)D96X`2&]R9&4O2V]L86(Z("5S("(E<R(@
M:V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z
M($1I92!-24U%+4E$(&1E<R!!8G-C:&YI='1S('9O;2!4>7`@)7,@:V]N;G1E
M(&YI8VAT(&AE<F%U<V=E9G5N9&5N('=E<F1E;BX`2&]R9&4O2V]L86(Z("5S
M("(E<R(@:V]N;G1E(&YI8VAT('-Y;F-H<F]N:7-I97)T('=E<F1E;CH@)7,`
M2&]R9&4O2V]L86(Z($1I92!G96UE:6YS86UE;B!/8FIE:W1E(&MO;FYT96X@
M;FEC:'0@<WEN8VAR;VYI<VEE<G0@=V5R9&5N.B`E<P!(;W)D92]+;VQA8CH@
M56YB96MA;FYT97,@9V5M96EN<V%M97,@3V)J96MT("(E<R(`2&]R:7IO;G1A
M;&4@3&EN:64`2&]R:7IO;G1A;&5R($EN;F5N86)S=&%N9`!(;W)I>F]N=&%L
M.@!7:64@<VEN9"!3:64@:&EE<FAE<F=E;&%N9W0_($)I='1E(&%N(&1I92!%
M;G1W:6-K;&5R('IU<OQC:VUE;&1E;B$I`%=I92!S;VQL96X@06YHY&YG92!A
M;F=E>F5I9W0@=V5R9&5N/P!7:64@=FEE;&4@4W!A;'1E;B!S;VQL96X@>G5S
M86UM96YG96;\9W0@=V5R9&5N/P!7:65V:65L92!&96QD97(@*%-P86QT96XI
M(&=I8G0@97,_`%=I92!V:65L92!:96EL96X@<V]L;&5N('IU<V%M;65N9V5F
M_&=T('=E<F1E;C\`5VEE('-O;&QE;B!::71A=&%N='=O<G1E;B!M87)K:65R
M="!W97)D96X_`$QU9G1F975C:'1I9VME:70`3'5F=&9E=6-H=&EG:V5I=#H@
M`$MO;6EK97(`56YG87)N`$E-05``24U!4"`H075T;VUA=&ES8VAE(%!R;W1O
M:V]L;&5R:V5N;G5N9RD`1&5R($E-05`M4V5R=F5R(&AA="!D:64@5F5R8FEN
M9'5N9R!U;G1E<F)R;V-H96XN(%-E<G9E<F%N='=O<G0Z("5S`$%N;&5G96X@
M9&5S($E-05`M4&]S=&9A8VAS(&ES="!F96AL9V5S8VAL86=E;CH@)7,`3/9S
M8VAE;B!D97,@24U!4"U0;W-T9F%C:',@:7-T(&9E:&QG97-C:&QA9V5N.B`E
M<P!&97-T;&5G96X@9&5R($E-05`M4&]S=&9A8V@M475O=&$@:7-T(&9E:&QG
M97-C:&QA9V5N.B`E<P!)34%0(/QB97(@4U-,`$E-05`@_&)E<B!34TP@*'-E
M;&8M<VEG;F5D(%IE<G1I9FEK870I`$E-05`@_&)E<B!34TP@*'-E;&8M<VEG
M;F5D*0!$97(@24U!4"U397)V97(@:&%T(&1I92!697)B:6YD=6YG('5N=&5R
M8G)O8VAE;BX`24U!4"!O:&YE(%1,4P!)34%0+U!/4#,@16UA:6QS97)V97(`
M25`M061R97-S90!)4"U!9')E<W-E(&YI8VAT('9E<F;\9V)A<BX`25`M061R
M97-S92!N:6-H="!I;2!E<FQA=6)T96X@0TE$4BU";&]C:RX`5F5R;&5T>G5N
M9R!D97(@9F5S=&=E;&5G=&5N($E0+@!:96EL92!E:6YF_&=E;B!?=F]R`$ES
M;&%N9`!.=7(@0FEL9&5R`$EC;VYS(&;\<B`E<P!":6QD97(@=6YD(%1E>'0`
M0F5Z96EC:&YU;F<@9&5R($ED96YT:73D=`!796YN('-I92!N:6-H="!K;W)R
M96MT(&%N9V5Z96EG="!W:7)D+"`E<RP@=6T@<VEE(&EN(&5I;F5M(&YE=65N
M($9E;G-T97(@86YG97IE:6=T('IU(&)E:V]M;65N+@!5;2!34TP@;V1E<B!4
M3%,@8F5N=71Z96X@>G4@:_9N;F5N+"!M=7-S(&1I92!/<&5N4U-,+45R=V5I
M=&5R=6YG(&;\<B!02%`@9V5L861E;B!S96EN+@!796YN(%-I92!F;W)T9F%H
M<F5N+"!W97)D96X@86QL92!.86-H<FEC:'1E;B!I;B!D96T@3W)D;F5R+V1E
M;B!/<F1N97)N(&5N9&?\;'1I9R!G96SV<V-H="$`5V5N;B!3:64@;6ET(&1E
M;2!);G1E<FYE="!%>'!L;W)E<B!K96EN92!3>6UB;VQE('-E:&5N+"!M_'-S
M96X@4VEE(&1I97-E<R!+Y'-T8VAE;B!M87)K:65R96XL('5M(%!.1RU4<F%N
M<&%R96YZ(&%U<WIU<W1E;&QE;BX`5V5N;B!3:64@9&EE<V4@3F%C:')I8VAT
M(&%N(%-T96QL92!E:6YE($)I;&1E<R!S96AE;BP@:V%N;B!):'(@0G)O=W-E
M<B!D87,@0FEL9"P@9&%S(%-I92!H;V-H;&%D96X@;?9C:'1E;B!N:6-H="!A
M;GIE:6=E;BX`26=N;W)I97)E;@!!;&QE($EG;F]R:65R96X`0FEL9`!":6QD
M=F]R<V-H874Z`$)I;&0M55),`$)I;&0M55),.@!":6QD('9O;B!'86QE<FEE
M`$)I;&0@=F]N($=A;&5R:64Z`$)I;&0M2&]C:&QA9&5N`$)I;&1E<@!);7!O
M<G1I97)E;@!38VAL_'-S96P@:6UP;W)T:65R96X`4V-H;/QS<V5L<&%A<B!I
M;7!O<G1I97)E;@!.86-H<FEC:'1E;B!I;7!O<G1I97)E;@!01U`M4V-H;/QS
M<V5L(&EM<&]R=&EE<F5N`%!E<G/V;FQI8VAE<R!:97)T:69I:V%T(&EM<&]R
M=&EE<F5N`%!E<G/V;FQI8VAE;B!P<FEV871E;B!01U`M4V-H;/QS<V5L(&EM
M<&]R=&EE<F5N`%!E<G/V;FQI8VAE;B#V9F9E;G1L:6-H96X@4$=0+5-C:&S\
M<W-E;"!I;7!O<G1I97)E;@!097)S]FYL:6-H97,@4R]-24U%+5IE<G1I9FEK
M870@:6UP;W)T:65R96X`UF9F96YT;&EC:&5N(%-C:&S\<W-E;"!I;7!O<G1I
M97)E;@#69F9E;G1L:6-H96X@4$=0+5-C:&S\<W-E;"!I;7!O<G1I97)E;@#6
M9F9E;G1L:6-H96X@4R]-24U%+5-C:&S\<W-E;"!I;7!O<G1I97)E;@!3+TU)
M344M4V-H;/QS<V5L(&EM<&]R=&EE<F5N`$YA8VAR:6-H=&5N(&EM<&]R=&EE
M<F5N`$UB;W@M1&%T96D@)7,@:6X@9&5N($]R9&YE<B`E<R!I;7!O<G1I97)E
M;BX`26UP;W)T:65R96XL(%-C:')I='0@)60`5VEC:'1I9P!7:6-H=&EG92!.
M86-H<FEC:'1E;@`E9"!.86-H<FEC:'1E;B!A=7,@)7,@:6UP;W)T:65R="X`
M26UP;W)T:65R=&5S($9E;&0Z("5S`$EM<&]R=&EE<G1E($9E;&1E<CH`26X@
M0F5A<F)E:71U;F<`6F5I;&4@96EN9OQG96X@7VYA8V@`4&]S=&5I;F=A;F<`
M3F%C:')I8VAT96YK;W!F(&EN(&1I92!!;G1W;W)T(&5I;F;\9V5N/P!/<FEG
M:6YA;&YA8VAR:6-H="!I;B!D:64@06YT=V]R="!E:6YF_&=E;C\`56YG_&QT
M:6=E($%K=&EO;B!A;F=E9V5B96XN`%5N9_QL=&EG97(@0F5N=71Z97)N86UE
M('5N9"]O9&5R(%!A<W-W;W)T+@!&86QS8VAE<B!"96YU='IE<FYA;64@;V1E
M<B!%;6%I;&%D<F5S<V4N(%9E<G-U8VAE;B!3:64@97,@97)N975T(&]D97(@
M=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N(%-Y<W1E;6%D;6EN:7-T<F%T;W(L
M('=E;FX@4VEE('=E:71E<F4@2&EL9F4@8F5N]G1I9V5N+@!%:6YZ=6<@=F5R
M9W+VWV5R;@!);F1I96X`16EN>F5L;F4@0F5N=71Z97(`26YD;VYE<VEE;@!)
M;F9O<FUA=&EO;@!);F9O<FUA=&EO;F5N`$EN9F]R;6%T:6]N96X@;FEC:'0@
M;65H<B!V97)F_&=B87(N`$EN9F]R;6%T:6]N96X@_&)E<B`E<R#V9F9E;G1L
M:6-H96X@4V-H;/QS<V5L`$EN9F]R;6%T:6]N96X@_&)E<B!D96X@<&5R<_9N
M;&EC:&5N('!R:79A=&5N(%-C:&S\<W-E;`!);F9O<FUA=&EO;F5N(/QB97(@
M9&5N('!E<G/V;FQI8VAE;B#V9F9E;G1L:6-H96X@4V-H;/QS<V5L`$EM(%1E
M>'0`7U-P86QT92!D879O<B!E:6YF_&=E;@!:97)T:69I:V%T(&AI97(@96EN
M9OQG96X`0FEL9"!H:6YZ=6;\9V5N`%!E<G/V;FQI8VAE;B!P<FEV871E;B!0
M1U`M4V-H;/QS<V5L(&AI97(@96EN9OQG96X`4&5R<_9N;&EC:&5N(/9F9F5N
M=&QI8VAE;B!01U`M4V-H;/QS<V5L(&AI97(@96EN9OQG96X`UF9F96YT;&EC
M:&5N(%!'4"U38VAL_'-S96P@:&EE<B!E:6YF_&=E;@!486)E;&QE(&5I;F;\
M9V5N`$QI;FL@96EN9OQG96X`4U]P86QT92!D86YA8V@@96EN9OQG96X`16EN
M92!N975E(%-P86QT92!N86-H(&1E<B!A:W1U96QL96X@96EN9OQG96X`16EN
M92!N975E(%-P86QT92!V;W(@9&5R(&%K='5E;&QE;B!E:6YF_&=E;@!%:6YE
M(&YE=64@6F5I;&4@;F%C:"!D97(@86MT=65L;&5N(&5I;F;\9V5N`$5I;F4@
M;F5U92!:96EL92!V;W(@9&5R(&%K='5E;&QE;B!E:6YF_&=E;@!%:6YE;B!N
M975E;B!!8G-A='H@;F%C:"!D96T@86MT=65L;&5N($5L96UE;G0@96EN9OQG
M96X`16EN96X@;F5U96X@06)S871Z('9O<B!D96T@86MT=65L;&5N($5L96UE
M;G0@96EN9OQG96X`06QT97)N871I=F4@5F]R;&%G92!E:6YF_&=E;@!'96)E
M;B!3:64@96EN92!%;6%I;&%D<F5S<V4@86XL(&%N(&1I92!D87,@;F5U92!0
M87-S=V]R="!G97-C:&EC:W0@=V5R9&5N('-O;&PZ`%IE;&QE(&1A;F%C:"!E
M:6YF_&=E;@!:96QL92!D879O<B!E:6YF_&=E;@!3<&%L=&4@9&%N86-H(&5I
M;F;\9V5N`%-P86QT92!D879O<B!E:6YF_&=E;@!.86-H<FEC:'1E;B!H:6YZ
M=6;\9V5N`$%B<V%T>B!D86YA8V@@96EN9OQG96X`06)S871Z(&1A=F]R(&5I
M;F;\9V5N`%IE:6QE(&1A;F%C:"!E:6YF_&=E;@!:96EL92!D879O<B!E:6YF
M_&=E;@!'96)E;B!3:64@9&EE($%N='=O<G0@875F(&1I92!3:6-H97)H96ET
M<V9R86=E(&5I;CH`0FEL9"!E:6YF_&=E;B]B96%R8F5I=&5N`$QI;FL@96EN
M9OQG96XO8F5A<F)E:71E;@!:=2!W96YI9R!'=71H86)E;BP@=6T@86X@9&EE
M(%9E<G1E:6QE<FQI<W1E('IU('9E<G-C:&EC:V5N+@!:=2!W96YI9R!'=71H
M86)E;BX`1V%N>GIA:&P`3&ES=&4@=F]N($=A;GIZ86AL96X`56YG_&QT:6=E
M($%K=&EO;B!F_'(@9&EE<V4@2V]M<&]N96YT92!A=7-G97?D:&QT+@!5;F?\
M;'1I9V4@061R97-S90!5;F?\;'1I9V5S(%!O<W1F86-H`%5N9_QL=&EG97(@
M541(+B`H57-E<B!$871A($AE861E<BDN`%5N9_QL=&EG92!:25`M1&%T96XN
M`%5N9_QL=&EG92!!;G=E;F1U;F<N`%5N9_QL=&EG92!"871C:"U)1"X`56YG
M_&QT:6=E<R!:96EC:&5N(&EN(&1E<B!%;6%I;&%D<F5S<V4Z("5S+@!5;F?\
M;'1I9V4@1&%T96X@96EN9V5B96XN`%5N9_QL=&EG92!::65L861R97-S92X`
M56YG_&QT:6=E<R!$871E:69O<FUA=`!5;F?\;'1I9V5R(%-C:&S\<W-E;`!5
M;F?\;'1I9V5R($QI>F5N>G-C:&S\<W-E;"X`56YG_&QT:6=E<B!/<G0@86YG
M96=E8F5N+@!5;F?\;'1I9V5R(&US9U]T>7!E+@!5;F?\;'1I9V4@;V1E<B!F
M96AL96YD92!A<&E?:60N`%5N9_QL=&EG92!O9&5R(&9E:&QE;F1E(%!A<F%M
M971E<BX`56YG_&QT:6=E<R#<8F5R<F5C:'0N`%5N9_QL=&EG92!087)T;F5R
M+4E$+@!5;F?\;'1I9V5R('!E<G/V;FQI8VAE<B!P<FEV871E<B!01U`M4V-H
M;/QS<V5L+@!5;F?\;'1I9V5R('!E<G/V;FQI8VAE<B#V9F9E;G1L:6-H97(@
M4$=0+5-C:&S\<W-E;"X`56YG_&QT:6=E<B!0<F]D=6MT8V]D92X`56YG_&QT
M:6=E<R!0<F]T;VMO;&PN`%5N9_QL=&EG97(@16UP9N1N9V5R.B`B)7,B`%5N
M9_QL=&EG97,@9V5M96EN<V%M97,@3V)J96MT`%5N9_QL=&EG92!5<G-P<G5N
M9W-A9')E<W-E+@!5;F?\;'1I9V4@56YI8V]D92U$871E;BX`26YV96YT87(`
M56UK96AR96X`075S=V%H;"!U;6ME:')E;@!)<VQA;6ES8VAE(%)E<'5B;&EK
M($ER86X`27)A:P!)<FQA;F0`27-L92!O9B!-86X`5F5R96EN>F5L=&4@1V5W
M:71T97(`27-R865L`$%U<W-T96QL97(`2W5R<VEV`$ET86QI96X`2F%M86EK
M80!*86YU87(`2F%P86X`2F%P86YI<V-H("A)4T\M,C`R,BU*4"D`2F5R<V5Y
M`$IO<F1A;FEE;@!*=6QI`$IU;FD`0FQO8VMS871Z`%IE;G1R:65R96X`0FQO
M8VMS871Z`$QI;FMS(&%U<W)I8VAT96X`4F5C:'1S(&%U<W)I8VAT96X`2T(`
M2V%S86-H<W1A;@!/<FEG:6YA;"!B96EB96AA;'1E;C\`2V5N:6$`2V5R8F5R
M;W,M4V5R=F5R(&AA="!!=71H96YT:69I>FEE<G5N9R!Z=7+\8VMG97=I97-E
M;BX`2V5R;F5L+4YE=6QI;F=E`%-C:&S\<W-E;&5R>F5U9W5N9P!&:6YG97)A
M8F1R=6-K(&1E<R!38VAL_'-S96QS`%-C:&S\<W-E;&SD;F=E`%-C:&S\<W-E
M;'1Y<`!38VAL_'-S96QZ=V5C:P!$97(@4V-H;/QS<V5L(&)E9FEN9&5T('-I
M8V@@8F5R96ET<R!A=68@9&5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V
M97(N`$1I92!%<GIE=6=U;F<@=F]N(%-C:&S\<W-E;&X@:V%N;B!S96AR(&QA
M;F=E(&1A=65R;BX@4V-H;/QS<V5L97)Z975G=6YG(&9O<G1S971Z96X_`%-I
M92!K]FYN96X@:V5I;F4@4V-H;/QS<V5L(&EM<&]R=&EE<F5N+"!W96EL(&1A
M<R!(;V-H;&%D96X@=F]N($1A=&5I96X@875F(&1I97-E;B!397)V97(@;FEC
M:'0@;?9G;&EC:"!I<W0N`%-I92!K]FYN96X@:V5I;F4@4V-H;/QS<V5L(&EM
M<&]R=&EE<F5N+"!W96EL(%-I92!K96EN($%D<F5S<V)U8V@@86YG96=E8F5N
M(&AA8F5N+"!D87,@>G5M($AI;GIU9OQG96X@;F5U97(@2V]N=&%K=&4@=F5R
M=V5N9&5T('=E<F1E;B!S;VQL+@!$97(@4V-H;/QS<V5L('=U<F1E(&5R9F]L
M9W)E:6-H('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R(&=E<V-H
M:6-K="X`2VEN9&5R`$MI<FEB871I`$1E;6]K<F%T:7-C:&4@5F]L:W-R97!U
M8FQI8R!+;W)E80!297!U8FQI:R!+;W)E80!+;W)E86YI<V-H("A%54,M2U(I
M`$MU=V%I=`!+:7)G:7-I<W1A;@!!;E]P87-S96X`4W!R86-H90!,86]S`$QE
M='IT92!(Y&QF=&4`3&5T>G1E($]R9&YE<G-E:71E`$QE='IT92!396ET90!,
M971Z=&4@4&%S<W=O<G3D;F1E<G5N9P!,971Z=&5S(%9I97)T96P`3&5T>G1E
M($%K='5A;&ES:65R=6YG.@!,971Z=&4@06YM96QD=6YG.B`E<P!,971Z=&4@
M06YM96QD=6YG.B`E<R!V;VX@)7,`3&5T>G1E($%N;65L9'5N9SH@3F]C:"!N
M:64`3&5T=&QA;F0`1V5S971Z`$9O<FUA=`!,965R(&QA<W-E;B!F_'(@:V5I
M;F5N(%)A:&UE;@!,:6)A;F]N`$QI;FMS`$QI;FME(-QB97)S8VAR:69T`$QI
M;FME(%=E<G1E`$QE<V]T:&\`16)E;F4`3&EB97)I80!,:6)Y96X`3&EE8VAT
M96YS=&5I;@!3<'+\:')E9V5N`$QE:6-H=&5R(%)E9V5N`$9R_&@@;&5I8VAT
M97(@4F5G96X`4W#D=&5R($QE:6-H=&5R(%)E9V5N`$QE:6-H=&4@4F5G96YS
M8VAA=65R`$QE:6-H=&5R(%)E9V5N(&UI="!'97=I='1E<@!,96EC:'1E<B!3
M8VAN965F86QL`$QE:6-H=&4@4V-H;F5E<V-H875E<@!,:6UE<FEC:P!,:6YK
M`$%N:.1N9V4@=F5R;&EN:V5N/P!,:6YK('9E<G=E:7-T(&%U9CH`16UA:6QA
M9')E<W-E('9E<FQI;FME;C\`5F5R;&EN:W1E($%N:.1N9V4@<VEN9"!D96%K
M=&EV:65R="X`3&EN:W,`1&EE($QI;FMS('-I;F0@8FES('IU;2`E<R!G_&QT
M:6<`3&EN=7@M1VS\8VMS:V5K<V4`3&ES="`M($)E;G5T>F5R(&MA;FX@9&5N
M($]R9&YE<B!S96AE;@!$871E;F)A;FME;B!A;GIE:6=E;@!(:6QF965I;G1R
MY&=E(&%N>F5I9V5N`%1A8F5L;&5N(&%N>F5I9V5N`$%L;&4@2V]N=&%K=&4@
M8F5I;2#69F9N96X@9&5R($MO;G1A:W1L:7-T92!A;GIE:6=E;C\@*$9A;&QS
M(&1E86MT:79I97)T+"!W97)D96X@;G5R(&1I92!+;VYT86MT92!A;F=E>F5I
M9W0L(&YA8V@@9&5N96X@4VEE(&%U<V1R_&-K;&EC:"!S=6-H96XI`$QI<W1E
M;BU!<F-H:78`3&ES=&5N+4AI;&9E`$QI<W1E;BU)9`!,:7-T96XM0F5S:71Z
M97(`3&ES=&5N+4%D<F5S<V4`3&ES=&5N+4%N;65L9'5N9P!,:7-T96XM06)M
M96QD=6YG`$%L<R!,:7-T92!I;2!.86-H<FEC:'1E;FMO<&8`1&%S($%N>F5I
M9V5N(&1E<B!397-S:6]N<R!I<W0@9F5H;&=E<V-H;&%G96XZ("5S`$1A<R!!
M;GIE:6=E;B!D97(@0F5N=71Z97(@:7-T(&9E:&QG97-C:&QA9V5N.B`E<P!$
M87,@06YZ96EG96X@9&5R($)E;G5T>F5R(&ES="!N:6-H="!M]F=L:6-H+@!,
M:71E<F%T=7(`3&ET875E;@!,861E+BXN`$QO:V%L97(@3W)D;F5R.@!,;VMA
M;&4@56AR>F5I=#H@`%-P<F%C:&4@=6YD(%IE:70`3W)T`$%N;65L9&5N`$%N
M;65L9&5N(&)E:2`E<P!,;V<@9&5R(&QE='IT96X@4WEN8VAR;VYI<V%T:6]N
M+@!!8FUE;&1E;@!!;FUE;&1E;@!!;FUE;&1E875F9V%B96X`1&EE($%N;65L
M9'5N9R!I<W0@9F5H;&=E<V-H;&%G96XL('=E:6P@4VEE($EH<F5N($)E;G5T
M>F5R;F%M96X@;V1E<B!):'(@4&%S<W=O<G0@9F%L<V-H(&5I;F=E9V5B96X@
M:&%B96XN`$%N;65L9'5N9R!F96AL9V5S8VAL86=E;BX`3&%N9V5R(%1E>'0`
M3&EE8F4`3FEE9')I9P!.:65D<FEG92!0<FEO<FETY'0`2VPN(&=R:65C:&ES
M8VAE($)U8VAS=&%B96X`2VPN(&QA=&5I;FES8VAE($)U8VAS=&%B96X`2VPN
M('+V;6ES8VAE(%IA:&QE;@!.:65D<FEG<W1E`$QU>&5M8G5R9P!-30!-3U1$
M`$U3+51.148M06YH86YG(&5N=&AI96QT(&ME:6YE($1A=&5N+@!(24Y714E3
M`$UA8V%O`$1I92!E:&5M86QI9V4@2G5G;W-L87=I<V-H92!297!U8FQI:R!-
M87IE9&]N:65N`$UA8VEN=&]S:"U$871E:0!-861A9V%S:V%R`$UA9VEE`%=E
M8FUA:6P`16UA:6P@061M:6YI<W1R871I;VX`3F%C:')I8VAT96YV;W)S8VAA
M=0!:=2!V97)W96YD96YD97(@16UA:6QS97)V97)T>7`Z`$]R9&YE<@!!;GIE
M:6=E96EN<W1E;&QU;F=E;B!F_'(@9&EE($]R9&YE<F%N<VEC:'0@=6YD("W\
M8F5R<VEC:'0`3&EN:R!?86YL96=E;BXN+@!-86QA=VD`36%L87ES:6$`36%L
M:61I=F5N`$UA;&D`36%L=&$`5F5R=V%L=&5N(%-I92!D:64@2V%T96=O<FEE
M;BP@;6ET(&1E;F5N(%-I92!%;&5M96YT92!U;F0@16EN='+D9V4@:V5N;GIE
M:6-H;F5N(&OV;FYE;BP@<V]W:64@9&EE('IU9V5H]G)I9V5N($9A<F)E;BX`
M36%P,C0M2V%R=&4`36%P475E<W0M2V%R=&4`6G5O<F1N=6YG96X@9V5S<&5I
M8VAE<G0N`$WD<GH`077?96YA8G-T86YD`$%L;&4@3F%C:')I8VAT96X@:6T@
M3W)D;F5R(&%L<R!G96QE<V5N(&UA<FMI97)E;@!!;&QE($YA8VAR:6-H=&5N
M(&EM($]R9&YE<B!A;',@=6YG96QE<V5N(&UA<FMI97)E;@!-87)K:65R96X@
M86QS.@!5;G1E<G-C:&EE9&QI8VAE(%II=&%T96EN<OQC:W5N9V5N(&EN('5N
M=&5R<V-H:65D;&EC:&5N($9A<F)E;B!A;GIE:6=E;C\`3F%C:')I8VAT96X@
M86QS(&=E;&5S96X@;6%R:VEE<F5N/R`H;G5R($E-05`I`$5I;F9A8VAE($%U
M<WIE:6-H;G5N9R!H97)V;W)H96)E;C\`36ET($=E;&5S96XM+U5N9V5L97-E
M;BU3=&%T=7,@=F5R<V5H96X`36ET(&%N9&5R96T@4W1A='5S('9E<G-E:&5N
M("AZ+D(N(%=I8VAT:6<O0F5A;G=O<G1E="D`36%R<VAA;&QI;G-E;&X`36%R
M=&EN:7%U90!A;&QE;B!+<FET97)I96X`96EN96T@2W)I=&5R:75M`%IU9V5O
M<F1N971E($9E;&1E<@!-875R971A;FEE;@!-875R:71I=7,`36%X:6UA;"!E
M<FQA=6)T97(@2W)E9&ET+@!-87AI;6%L92!.86-H=&EC:'1E;G1E:6QE(/QB
M97)S8VAR:71T96XN`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT96X@,C0@
M4W1U;F1E;CH@`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT96X@-B!3='5N
M9&5N.B``36%X:6UA;&4@06YH86YG9W+VWV4`36%X:6UA;&4@06YZ86AL(&%N
M($]R9&YE<FX`36%X:6UA;&4@06YZ86AL(&%N(%!O<G1A;&)L]F-K96X`36%X
M:6UA;&4@3.1N9V4`36%X:6UA;&4@06YZ86AL(&1E<B!!;FCD;F=E(&5R<F5I
M8VAT+@!-87AI;6%L92!'97-A;71G<O;?92!D97(@06YHY&YG92!E<G)E:6-H
M="X`36%I`$UA>6]T=&4@27-L86YD`$UE9&EZ:6X`36ET9VQI961E<@!-96[\
M+4]R9&YE<FQI<W1E`$UE;OQM;V1U<SH`6F5L;&5N('IU<V%M;65N9OQG96X`
M3F%C:')I8VAT`$YE=64@3F%C:')I8VAT`$YA8VAR:6-H=&5N($1A='5M`$YA
M8VAR:6-H=&5N+45I;G-T96QL=6YG96X`3F%C:')I8VAT96X@4W5C:&4`3F%C
M:')I8VAT96X@1W+VWV4`7U%U96QL=&5X=`!$:64@3F%C:')I8VAT(&MO;FYT
M92!E<F9O;&=R96EC:"#\8F5R<'+\9G0@=V5R9&5N(&%B97(@;FEC:'0@9&%S
M(%IE<G1I9FEK870@9&5S($%B<V5N9&5R<RX`3F%C:')I8VAT96YA;G-I8VAT
M`$YA8VAR:6-H="!N:6-H="!M96AR(&?\;'1I9RX`3F%C:')I8VAT96YS=&%T
M=7,`3F%C:')I8VAT96YO<F1N97(`3F%C:')I8VAT('9O;B`E<P!.86-H<FEC
M:'0@;6ET($%N:.1N9V5N`%9E<G-C:&S\<W-E;'1E($YA8VAR:6-H=`!5;G1E
M<G-C:')I96)E;F4@3F%C:')I8VAT`$YA8VAR:6-H="!E;G1S<')I8VAT`$YA
M8VAR:6-H="!W=7)D92!E<F9O;&=R96EC:"!U;6=E;&5I=&5T+@!.86-H<FEC
M:'0@=W5R9&4@97)F;VQG<F5I8V@@=F5R<V5N9&5T+"!A8F5R(&YI8VAT(&EN
M("5S(&=E<W!E:6-H97)T`$YA8VAR:6-H="!W=7)D92!E<F9O;&=R96EC:"!V
M97)S96YD970N`$YA8VAR:6-H=&5N='EP`$YA8VAR:6-H=&5N('!R;R!396ET
M90!.86-H<FEC:'1E;B!N86-H`$UE=&%R(%=E='1E<@!-971A<F)L;V-K(&YI
M8VAT('9E<F;\9V)A<BX`365T87)B;&]C:R!N:6-H="!V97)F_&=B87(N($1E
M=&%I;',@=W5R9&5N(&;\<B!D96X@061M:6YI<W1R871O<B!M:71G96QO9V=T
M+@!+96EN92!697)B:6YD=6YG('IU<B!-971A<D1"+@!-971H;V1E`$1I92!-
M971H;V1E("(E<R(@:7-T(&YI8VAT(&1E9FEN:65R=`!-971H;V1E(&YI8VAT
M(&1E9FEN:65R="X@075F9V5R=69E;F4@365T:&]D93H@)7,`365T<FES8V@`
M365X:6MO`$;V9&5R:65R=&4@4W1A871E;B!V;VX@36EK<F]N97-I96X`36ET
M=&4`36EM971Y<`!4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T
M=6YD96XZ(`!4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#8@4W1U;F1E
M;CH@`$1A<R!M:6YI;6%L92!087-S=V]R=&%L=&5R(&ES="!N;V-H(&YI8VAT
M(&%B9V5L875F96X`4W!I96=E;&X`5F5R<V-H:65D96YE<P!014%2+5!A:V5T
M($A45%!?4F5Q=65S="!F96AL="X`1F5H;&5N9&4@2V]N9FEG=7)A=&EO;BX@
M4VEE(&W\<W-E;B!D:65S92!J971Z="!E<GIE=6=E;BP@=V5N;B!3:64@9&EE
M($%N=V5N9'5N9R!V97)W96YD96X@;?9C:'1E;BX`1F5H;&5N9&4@3F%C:')I
M8VAT96XM240N`%!%05(M4&%K970@36%I;"!F96AL="X`1F5H;&5N9&4@4VET
M>G5N9W,M240N`$UO`$5M86EL($UO8FEL`$WDWVEG`,1N9&5R=6YG<V1A='5M
M`,1N9&5R90!54DP@8F5A<F)E:71E;@!-;V1U;'5S`%)E<'5B;&EK($UO;&1A
M=0!-;VYA8V\`36]N9V]L96D`36]N870@=6YD($IA:'(`36]N871L:6-H`$UO
M;G1S97)R870`36]N9'!H87-E;@!-96AR($9E;&1E<B!I;B!:96EL92`E9"!A
M;',@9&EE(&5R=V%R=&5T96X@)60@9V5F=6YD96XN`$5S('=U<F1E(&UE:'(@
M86QS(&5I;F4@061R97-S92!F_'(@9&%S("(E<R(M1F5L9"!G969U;F1E;BX`
M36%R;VMK;P#<8F5R=VEE9V5N9"!H96ET97(`W&)E<G=I96=E;F0@0F5W]FQK
M=`#<8F5R=VEE9V5N9"!"97?V;&MT('5N9"!7:6YD:6<`W&)E<G=I96=E;F0@
M4V]N;FEG`%9E<G-C:&EE7V)E`$YA8V@@=6YT96X`3F%C:"!L:6YK<P!.86-H
M(')E8VAT<P!.86-H(&]B96X`3F%C:"!U;G1E;@!3<&%M+4YA8VAR:6-H=&5N
M(&EN(&1E;B!3<&%M+4]R9&YE<B!U;F0@3FEC:'0M4W!A;2U.86-H<FEC:'1E
M;B!I;B!D96X@4&]S=&5I;F=A;F<@=F5R<V-H:65B96X`5F5R<V-H:65B96X@
M;F%C:`!.86-H(&]B96X`36]S86UB:6L`075S=V%H;&QI<W1E(&EN(&UE:')E
M<F5N($5B96YE;@!-=6QT:6UA<"U52RU+87)T90!-=6QT:7!A<G0O86QT97)N
M871I=F4`06YS:6-H="!F_'(@;65H<F5R92!.86-H<FEC:'1E;@!-96AR9F%C
M:&%U<W=A:&P`365I;B!+;VYT;P!-96EN($MO;G1O`$UE:6X@4&]R=&%L`$UE
M:6X@4&]R=&%L;&%Y;W5T`$)U<FUA`$Y%24XL(&EC:"!S=&EM;64@3DE#2%0@
M>G4`2T5)3@!(24Y714E3`$YA;64`1&5R($YA;64@=6YD+V]D97(@9&EE($5M
M86EL861R97-S92!D_')F96X@;FEC:'0@;&5E<B!S96EN`$YA;6EB:6$`3F%U
M<G4`06MT:6]N(&)E;O9T:6=T`$YE<&%L`$YI961E<FQA;F1E`$YI961E<FSD
M;F1I<V-H92!!;G1I;&QE;@!.971S8V%P92U"87-I<RU54DP`3F5T<V-A<&4M
M0T$M4W!E<G)U;F=S+5523`!.971S8V%P92U#02U2:6-H=&QI;FEE;BU54DP`
M3F5T<V-A<&4M6F5T:69I:V%T<V5R;F5U97)U;F=S+5523`!.971S8V%P92U3
M<&5R<G5N9W,M55),`$YE='-C87!E+5-33"U397)V97)N86UE`$YE='-C87!E
M+4MO;6UE;G1A<@!.971S8V%P92U:97)T:69I:V%T='EP`$YE='IW97)K`$YI
M90!!;FCD;F=E(&YI92!S<&5I8VAE<FX`3F5U`$YE=6MA;&5D;VYI96X`3F5U
M92!+871E9V]R:64`3F5U97(@3W)D;F5R`$YA8VAR:6-H=&5N96EN9V%N9P!.
M975E($YA8VAR:6-H=`!.975E($YA8VAR:6-H="!A;B`E<P!.975M;VYD`$YE
M=65R($)E;G5T>F5R;F%M92`H;W!T:6]N86PI`$YE=7-E96QA;F0`3F5U92!.
M86-H<FEC:'1E;@!.975E<R!087-S=V]R=`!$87,@;F5U92!087-S=V]R9"!W
M:7)D(&%M("5X(&%B;&%U9F5N+@!$:64@;F5U96X@4&%S<W?V<G1E<B!S=&EM
M;65N(&YI8VAT(/QB97)E:6XN`$YE=65S($9E;G-T97(@*%]B;&%N:RD`3F%C
M:')I8VAT96X`3F5W<V=R=7!P96X`5V5I=&5R`$[D8VAS=&4@-"!0:&%S96X`
M3N1C:'-T92!.86-H<FEC:'0`4V5I=&4@=F]R`$[D8VAS=&4@16EN<W1E;&QU
M;F=E;@!796ET97(^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YA8VAT<P!.
M:75E`$YE:6X`2V5I;B!:97)T:69I:V%T(&=E9G5N9&5N`$ME:6YE(%9E<G-C
M:&S\<W-E;'5N9P!+96EN92!38VAL_'-S96P@:6T@4V-H;/QS<V5L8G5N9`!+
M96EN92!.86-H<FEC:'1E;@!%<R!W=7)D92!K96EN(/9F9F5N=&QI8VAE<B!0
M1U`M4V-H;/QS<V5L(&EM<&]R=&EE<G0N`$ME:6X@<&5R<_9N;&EC:&5S(%IE
M<G1I9FEK870@=F]R:&%N9&5N`$ME:6X@5F]R<V-H875T97AT`$ME:6YE(/9F
M9F5N=&QI8VAE;B!38VAL_'-S96P@9V5F=6YD96X`17,@=W5R9&4@:V5I;B#V
M9F9E;G1L:6-H97(@4R]-24U%+5-C:&S\<W-E;"!I;7!O<G1I97)T+@!+96EN
M92!!;FCD;F=E(&=E9G5N9&5N+@!+96EN92!+;VYF:6=U<F%T:6]N<V1A=&5N
M('9E<F;\9V)A<BP@=6T@56YT97)S8VAI961E(&%N>G5Z96EG96XN`$ME:6YE
M(%-T<F%T96=I92!Z=6T@17)S=&5L;&5N('9O;B!)4T\M06)B:6QD97)N('9E
M<F;\9V)A<BX`2V5I;F4@0F%T8V@M5F]R;&%G92X`17,@97AI<W1I97)T(&ME
M:6X@0FQO8VL@86X@9&5R(&%N9V5G96)E;F5N(%!O<VET:6]N`$ME:6X@2V%L
M96YD97)N86UE(&;\<B!D:64@34-!3"U!=71H96YT:69I>FEE<G5N9R!A;F=E
M9V5B96XN`$ME:6YE(,1N9&5R=6YG96XN`%5N=&5R:&%L8B!D:65S97(@16)E
M;F4@:_9N;F5N(&ME:6YE('=E:71E<F5N(%5N=&5R<F5C:'1E(&AI;GIU9V5F
M_&=T('=E<F1E;BX`1OQR("5S('=U<F1E;B!K96EN92!+;VYF:6=U<F%T:6]N
M<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+@!&_'(@9&5N($944"U61E,M5')E
M:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N
M(&%N9V5G96)E;BX`1OQR(&1E;B!344PM5D93+51R96EB97(@=W5R9&5N(&ME
M:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN`$;\
M<B!D96X@4U%,+41A=&5I+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF
M:6=U<F%T:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+@!+96EN($MR961I
M="!M96AR(/QB<FEG+@!+96EN($5M<&;D;F=E<B!A;F=E9V5B96XN`$ME:6YE
M($5M86EL861R97-S92!I;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L(&=E9G5N
M9&5N+@!+96EN92!$871E:2!H;V-H9V5L861E;@!+96EN($]R9&YE<B!A=7-G
M97?D:&QT+@!%<R!W97)D96X@:V5I;F4@3W)D;F5R(&%U9B!N975E($YA8VAR
M:6-H=&5N(/QB97)P<OQF="X`2V5I;B!/<F1N97(@86YG96=E8F5N`$ME:6YE
M($]R9&YE<B!M:70@;F5U96X@3F%C:')I8VAT96X`2V5I;F4@3W)D;F5R(&UI
M="!U;F=E;&5S96YE;B!.86-H<FEC:'1E;@!+96EN92!)8V]N<R!G969U;F1E
M;BX`17,@=W5R9&4@:V5I;B!/<G0@9F5S=&=E;&5G="X`2V5I;B!/<G0@86YG
M96=E8F5N+@!+96EN($YA8VAR:6-H=&5N=&5X=`!+96EN92!.86-H<FEC:'0@
M9V5F=6YD96XN`$ME:6YE($YA8VAR:6-H="!A;F=E9V5B96XN`$5S('=U<F1E
M;B!K96EN92!P87-S96YD96X@3F%C:')I8VAT96X@9V5F=6YD96XN`$ME:6X@
M3F%M92!A;F=E9V5B96XN`$ME:6YE($YU;6UE<B!A;F=E9V5B96XN`$ME:6YE
M(&%N<W3VWVEG96X@1VS\8VMS:V5K<V4`2V5I;B!087-S=V]R="!F_'(@9&EE
M($A45%`M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+96EN(%!A<W-W
M;W)T(&;\<B!D:64@24U!4"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN
M`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!+97)B97)O<RU!=71H96YT:69I>FEE
M<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!,;V=I;BU!
M=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR
M(&1I92!005-35T0M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+96EN
M(%!A<W-W;W)T(&;\<B!D:64@4TU"+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G
M96)E;BX`2V5I;B!09F%D('IU;2!/<&5N4U-,+5!R;V=R86UM(&%N9V5G96)E
M;BX@1&%S($]P96Y34TPM4')O9W)A;6T@=VER9"!B96[V=&EG="P@=6T@4$M#
M4RTQ,BU$871E;B!V97)A<F)E:71E;B!Z=2!K]FYN96XN`$ME:6YE(&%U<W-T
M96AE;F1E;B!296=I<W1R:65R=6YG96XN`$5S('=U<F1E(&ME:6X@<&5R<_9N
M;&EC:&5R('!R:79A=&5R(%!'4"U38VAL_'-S96P@:6UP;W)T:65R="X`17,@
M=W5R9&4@:V5I;B!P97)S]FYL:6-H97(@]F9F96YT;&EC:&5R(%!'4"U38VAL
M_'-S96P@:6UP;W)T:65R="X`17,@=W5R9&5N(&ME:6YE('!R:79A=&5N(%,O
M34E-12U:97)T:69I:V%T92!I;7!O<G1I97)T+@!3:64@:&%B96X@>G5R(%IE
M:70@:V5I;F5N('!R:79A=&5N(%-C:&S\<W-E;"P@<V\@9&%S<R!D:64@3F%C
M:')I8VAT(&YI8VAT(&5N='-C:&S\<W-E;'0@=V5R9&5N(&MA;FXN`$ME:6X@
M4W!E:6-H97)P;&%T>BU+;VYT:6YG96YT(&9E<W1G96QE9W0N`$ME:6YE(%)A
M:&UE;@!+96EN(%1R96YN>F5I8VAE;B!A;F=E9V5B96XN`$ME:6YE(%-E:71E
M;@!%<R!W=7)D92!K96EN(%)E8VAT<V-H<F5I8G!R;V=R86UM(&MO;F9I9W5R
M:65R="X`2V5I;F4@4V-H<F5I8F9E:&QE<@!$871E:2!N:6-H="!G969U;F1E
M;@!+96EN92!6;W)S8VALY&=E`$5S('=U<F1E(&ME:6YE('5N=&5R<W3\='IT
M92!!=71H96YT:69I>FEE<G5N9W-M971H;V1E(&;\<B!)34%0(&=E9G5N9&5N
M+@!+96EN92!T96UP;W+D<F5S(%9E<GIE:6-H;FES(&;\<B!D96X@0V%C:&4@
M9V5F=6YD96XN`$ME:6X@0F5N=71Z97(@86YG96=E8F5N+@!+96EN($)E;G5T
M>F5R;F%M92!U;F0O;V1E<B!087-S=V]R="!A;F=E8F5N+@!%<R!W=7)D96X@
M:V5I;F4@9_QL=&EG96X@6$U,+41A=&5N('IU<OQC:V=E9V5B96X`2V5I;F4@
M5V5R=&4`2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@9&5R($]R:6=I;F%L:V]N
M9FEG=7)A=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE($EH<F4@2V]N9FEG
M=7)A=&EO;BX`2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@26AR97(@2V]N9FEG
M=7)A=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE($EH<F4@2V]N9FEG=7)A
M=&EO;BX`2V5I;B!496EL;F5H;65R`$ME:6YE`$ME:6YS("A3=&%N9&%R9"!B
M96YU='IE;BD`3F]R9&ES8V@@*$E33RTX.#4Y+3$P*0!.;W)F;VQK:6YS96P`
M3F]R;6%L`$[V<F1L:6-H92!(96UI<W!H97)E`$[V<F1L:6-H92!-87)I86YE
M;@!.;W)W96=E;@!'_&QT:6<@8FES`$?\;'1I9R!A8@!.:6-H="!G96SV<V-H
M=`!+96EN($5N='=U<F8`3FEC:'0@=VEC:'1I9P!.:6-H="!P97)S]FYL:6-H
M`$ME:6X@5F5R>F5I8VAN:7,`2V5I;B!G_&QT:6=E<B#V9F9E;G1L:6-H97(@
M4V-H;/QS<V5L+@!.:6-H="!G96SV<V-H=&4@3F%C:')I8VAT96X`3FEC:'0@
M:6UP;&5M96YT:65R="X`3FEC:'0@=VEC:'1I9V4@3F%C:')I8VAT96X`3FEC
M:'0@9F5S=&=E;&5G=`!.:6-H="!U;G1E<G-T_'1Z="X`0F5A8VAT96X@4VEE
M+"!D87-S(&1I97-E<B!6;W)G86YG(&5I;FEG92!:96ET(&1A=65R;B!K86YN
M`$YO=&EZ96X`3FEC:'1S`$YI8VAT<R!A;GIU>F5I9V5N+"!B:71T92!Z=7+\
M8VMG96AE;BX`2&EN=V5I<SH@5F5R;&EN:W1E<B!!;FAA;F<@:&5R=6YT97)G
M96QA9&5N`$YO=F5M8F5R`%IA:&P`06YZ86AL(&1E<B!:96EC:&5N`$%N>F%H
M;"!D97(@4W!A;'1E;@!!;GIA:&P@9&5R($UO;F%T92P@9OQR(&1I92!A;'1E
M('9E<FQI;FMT92!!;FCD;F=E(&%U9F=E:&]B96X@=V5R9&5N('-O;&QE;BP@
M9F%L;',@9&EE<V4@;6]N871L:6-H(&=E;/9S8VAT('=E<F1E;BX`06YZ86AL
M(&1E<B!/<F1N97(@9OQR(&=E<V5N9&5T92!.86-H<FEC:'1E;BP@9&EE(&)E
M:2!M;VYA=&QI8VAE<B!,]G-C:'5N9R!B96AA;'1E;B!W97)D96X@<V]L;&5N
M+@!!;GIA:&P@9&5R(%IE:6QE;@!+96EN92!.=6UM97)N(&;\<B!D:64@5F5R
M=&5I;&5R;&ES=&4@86YG96=E8F5N+@!/2P!/1$52`$]B:F5K=`!/8FIE:W1E
M<G-T96QL97(`3VMT86QZ86AL`$]K=&]B97(`1FEL=&5R(&;\<B!A;G-T]M]I
M9V4@26YH86QT90!"_')O`$EH<B!N975E<R!087-S=V]R="!M=7-S('-I8V@@
M=F]N($EH<F5M(&%L=&5N('5N=&5R<V-H96ED96XN`$%L=&4@3F%C:')I8VAT
M96X`06QT97,@4&%S<W=O<G0`1F%L<V-H97,@86QT97,@4&%S<W=O<G0N`$]R
M9&YE<B!F_'(@9V5S96YD971E($YA8VAR:6-H=&5N+"!D:64@9V5L]G-C:'0@
M=V5R9&5N+@!/;6%N`$YU<B!)34%0+5-E<G9E<B!U;G1E<G-T_'1Z96X@9V5M
M96EN<V%M92!/<F1N97(N`$YU<B!/<F1N97(L(&1I92!U;F=E;&5S96YE($YA
M8VAR:6-H=&5N(&5N=&AA;'1E;BP@86YZ96EG96X_`$YU<B!A;G-T]M]I9V4@
M1VS\8VMS:V5K<V4`3G5R(&5I;F4@16UA:6PM061R97-S92!E<FQA=6)T+@!&
M_'(@9&EE<V4@06MT:6]N(&1A<F8@;G5R(&5I;B!/<F1N97(@875S9V5WY&AL
M="!S96EN+@!.=7(@9&5R($)E<VET>F5R(&]D97(@9&5R(%-Y<W1E;6%D;6EN
M:7-T<F%T;W(@:V%N;B!D96X@0F5S:71Z97(@;V1E<B!D:64@0F5S:71Z97)R
M96-H=&4@Y&YD97)N`$]R7V1N97(@86YZ96EG96X`26X@;F5U96T@1F5N<W1E
M<B#V9F9N96X`3W!E;E-33"U&96AL97(Z(%-I9VYI97)T92!3+TU)344M1&%T
M96X@:V]N;G1E;B!N:6-H="!E>'1R86AI97)T('=E<F1E;BX`1V7V9F9N971E
M<B!/<F1N97(`1&EE<V5N($QI;FL@:6X@96EN96T@;F5U96T@1F5N<W1E<B#V
M9F9N96X`0F5T<FEE8G-Y<W1E;0!/<'1I;VYA;&5R(%1E:6QN96AM97(`16EN
M<W1E;&QU;F=E;@!%:6YS=&5L;'5N9V5N(&;\<B`E<P!.=6UM97)I97)T92!,
M:7-T90!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N<V%B=&5I;'5N9P!/<F=A
M;FES:65R96X`3W)I9VEN86QV;W)L86=E(&1E<B!!;G=E;F1U;F<`3W)I9VEN
M86QV;W)L86=E(&EN("5S.@!3;VYS=&EG90!!;F1E<F4@26YF;W)M871I;VYE
M;@!!;F1E<F4@16UA:6QK;VYT96X`4V]N<W1I9V4@16EN<W1E;&QU;F=E;@!0
M;W-T875S9V%N9W,M4V5R=F5R`$)E<VET>F5R<F5C:'1E`%!!32U!=71H96YT
M:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!014%2.CI-86EL+4)A
M8VME;F0`4$=0`$1I9VET86QE(%!'4"U5;G1E<G-C:')I9G0`5F5R<V-H;/QS
M<V5L;B`H4$=0*0!01U`M=F5R<V-H;/QS<V5L=&4@1&%T96X`4$=0+49E:&QE
M<CH@`%!'4"!&96AL97(Z($;\<B!D96X@<&5R<_9N;&EC:&5N('!R:79A=&5N
M(%-C:&S\<W-E;"!W:7)D(&5I;B!087-S=V]R="!B96[V=&EG="X`4$=0+45I
M;G-T96QL=6YG96X`4$=0(%!A<W-W;W)T96EN9V%B90!&_'(@9&5N(%IU9W)I
M9F8@875F(&1A<R!P97)S]FYL:6-H92!38VAL_'-S96QP86%R('=I<F0@96EN
M92!S:6-H97)E(%-E<G9E<G9E<F)I;F1U;F<@8F5N]G1I9W0N`-9F9F5N=&QI
M8VAE<B!01U`M4V-H;/QS<V5L`%1E>'0@9&5S(/9F9F5N=&QI8VAE;B!01U`M
M4V-H;/QS<V5L<P!$97(@]F9F96YT;&EC:&4@4$=0+5-C:&S\<W-E;"!F_'(@
M(B5S("@E<RDB('=U<F1E(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+@!$97(@
M]F9F96YT;&EC:&4@4$=0+5-C:&S\<W-E;"!F_'(@(B5S(B!W=7)D92!E<F9O
M;&=R96EC:"!G96SV<V-H="X`UF9F96YT;&EC:&5R(%!'4"U38VAL_'-S96QB
M=6YD`%5N=&5R>F5I8VAN96X@*%!'4"D`56YT97)Z96EC:&YE;B!U;F0@=F5R
M<V-H;/QS<V5L;B`H4$=0*0!-:70@4$=0('5N=&5R>F5I8VAN971E+W9E<G-C
M:&S\<W-E;'1E($1A=&5N`$1E<B!P<FEV871E(%!'4"U38VAL_'-S96P@=W5R
M9&4@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N`$1E<B#V9F9E;G1L:6-H92!0
M1U`M4V-H;/QS<V5L('=U<F1E(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+@!$
M:64@4$=0+55N=&5R<W3\='IU;F<@=W5R9&4@875F(&1I97-E;2!3>7-T96T@
M9&5A:W1I=FEE<G0N`$1I92!01U`M56YT97)S=/QT>G5N9R!I<W0@>G5R(%IE
M:70@9&5A:W1I=FEE<G0L('-O(&1A<W,@9&EE(&1I9VET86QE(%5N=&5R<V-H
M<FEF="!N:6-H="#\8F5R<'+\9G0@=V5R9&5N(&MA;FXN`$1I92!01U`M56YT
M97)S=/QT>G5N9R!I<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0L('-O(&1A<W,@
M9&EE($YA8VAR:6-H="!N:6-H="!E;G1S8VAL_'-S96QT('=E<F1E;B!K86YN
M+@!$:64@4$=0+55N=&5R<W3\>G5N9R!B96[V=&EG="!0;W!U<"U&96YS=&5R
M+"!U;2!Z=2!F=6YK=&EO;FEE<F5N+B!796YN($EH<B!"<F]W<V5R('IU<B!:
M96ET('-O(&5I;F=E<W1E;&QT(&ES="P@9&%S<R!0;W!O<"U&96YS=&5R('5N
M=&5R9'+\8VMT('=E<F1E;BP@;?QS<V5N('-I92!D:65S92!%:6YS=&5L;'5N
M9R#D;F1E<FXL(&]D97(@9&EE(%!'4"U&=6YK=&EO;F5N('=E<F1E;B!N:6-H
M="!R:6-H=&EG(&9U;FMT:6]N:65R96XN`%!(4"!#;V1E`%!(4"!3:&5L;`!6
M;W)M:71T86=S(&QE:6-H=&5R(%)E9V5N`$YA8VAM:71T86=S(%)E9V5N`$YA
M8VAM:71T86=S(%-C:&%U97(`3F%C:&UI='1A9W,@4V-H;F5E`$YA8VAM:71T
M86=S(%-C:&YE97-C:&%U97(`3F%C:&UI='1A9W,@4V]N;F4`3F%C:&UI='1A
M9W,@1V5W:71T97(`4$]0,P!03U`S("A!=71O;6%T:7-C:&4@4')O=&]K;VQL
M97)K96YN=6YG*0!03U`S(/QB97(@4U-,`%!/4#,@_&)E<B!34TP@*'-E;&8M
M<VEG;F5D(%IE<G1I9FEK870I`%!/4#,@_&)E<B!34TP@*'-E;&8M<VEG;F5D
M*0!03U`S(&]H;F4@5$Q3`$1I92!03U-)6"U%<G=E:71E<G5N9R!F96AL=`!?
M4$A0(%-H96QL`$EN;F5N86)S=&%N9`!396ET92`E9"!V;VX@)60`4V5I=&4@
M;6ET(&1E<B!E<G-T96X@=6YG96QE<V5N96X@3F%C:')I8VAT`%-E:71E(&UI
M="!D97(@;&5T>G1E;B!U;F=E;&5S96YE;B!.86-H<FEC:'0`4&%K:7-T86X`
M4&%L874`0F5S971Z=&4@4&%LY'-T:6YE;G-I<V-H92!'96)I971E`%!A;F%M
M80!087!U82U.975G=6EN96$`4&%R86=U87D`5&5I;"AE*0!496EL=V5I<V4@
M0F5W]FQK=`!087-S=V]R=`!087-S=V]R="`H5VEE9&5R:&]L96XI`$1A<R!0
M87-S=V]R="!W=7)D92!F_'(@9&EE<V4@4VET>G5N9R!G96SV<V-H="X`4&%S
M<W=O<G0Z`%!A<W-W]G)T97(@9/QR9F5N(&YI8VAT(&QE97(@<V5I;@!$:64@
M4&%S<W?V<G1E<B!S=&EM;65N(&YI8VAT(/QB97)E:6X`4&%S<W=O<G0`4&%S
M<W=O<G0@97)F;VQG<F5I8V@@9V7D;F1E<G0N`$9A;'-C:&5S(%!A<W-W;W)T
M`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!2041)55,M075T:&5N=&EF:7II97)U
M;F<@86YG96=E8F5N+@!087-S=V]R="!M:70@0F5S=.1T:6=U;F<`4&%S<W=O
M<G0Z`%!A<W-W;W)T.B``1&EE(%!A<W-W]G)T97(@;?QS<V5N(&=L96EC:"!S
M96EN+@!%:6YF_&=E;@!6;VX@9&5R(%IW:7-C:&5N86)L86=E(&5I;F;\9V5N
M`%!F860`075S<W1E:&5N9&4@4F5G:7-T<FEE<G5N9V5N.@!097)S;VYE;@!0
M<F]Z96YT`%=A<G1U;F=S87)B96ET96X@9'5R8VAF_&AR96X`5V%R='5N9W-A
M<F)E:71E;B!N86-H(&1E<B!!;FUE;&1U;F<@9'5R8VAF_&AR96X_`%)E8VAT
M90!296-H="`B)7,B('=U<F1E(&YI8VAT(&=E;/9S8VAT+@!:=6=R:69F('9E
M<G=E:6=E<G0`4F5C:'1E`%)E8VAT979E<G=A;'1U;F<`1&EE(%)E8VAT92!F
M_'(@9&EE<V5N($)E;G5T>F5R(&OV;FYE;B!N:6-H="!G9>1N9&5R="!W97)D
M96XN`%!E<G/V;FQI8V@`4&5R<_9N;&EC:&4@06YG86)E;@!$87,@<&5R<_9N
M;&EC:&4@4$=0+5-C:&S\<W-E;'!A87(@=W5R9&4@97)F;VQG<F5I8V@@97)Z
M975G="X`1&EE('!E<G/V;FQI8VAE;B!01U`M4V-H;/QS<V5L('=U<F1E;B!E
M<F9O;&=R96EC:"!G96SV<V-H="X`17,@=W5R9&5N($M%24Y%('!E<G/V;FQI
M8VAE;B!3+TU)344M6F5R=&EF:6MA=&4@:6UP;W)T:65R=#H@`$1I92!P97)S
M]FYL:6-H96X@4R]-24U%+5-C:&S\<W-E;"!W=7)D96X@97)F;VQG<F5I8V@@
M9V5L]G-C:'0N`%!E<G4`2&%U<W1I97)E`%!H:6QI<'!I;F5N`%1E;&5F;VX`
M1F]T;W,`4&ET8V%I<FX`4&EX96P`4VEG;F%T=7(@=F]R($%N='=O<G1E;B!U
M;F0@=V5I=&5R9V5L96ET971E;B!.86-H<FEC:'1E;B!E:6YF_&=E/P!497AT
M=F5R<VEO;B!D97(@3F%C:')I8VAT`%!L871T:&5I=&5N`$%U9&EO<VEG;F%L
M(&)E:2!N975E;B!.86-H<FEC:'1E;B!A8G-P:65L96X_($1A>G4@8F5N]G1I
M9V5N(%-I92!E:6YE;B!"<F]W<V5R+"!D97(@96EN9V5B971T971E($%U9&EO
M9&%T96EE;B!U;G1E<G-T_'1Z="X@1F%S="!A;&QE(%=I;F1O=W,M('5N9"!-
M86,M0G)O=W-E<B!K]FYN96X@9&EE<RP@875F(&%N9&5R96X@4&QA='1F;W)M
M96X@=V5R9&5N('5N=&5R(%5M<W3D;F1E;B!0;'5G:6YS(&)E;O9T:6=T+@!"
M:71T92!K;&EC:V5N(%-I92!I;B!E:6YE(%IE;&QE`$)I='1E(&)E<W3D=&EG
M96X@4VEE+"!D87-S(%-I92!D:65S97,@16QE;65N="!L]G-C:&5N(&WV8VAT
M96XZ`$)I='1E(&)E=.1T:6=E;B!3:64L(&1A<W,@4VEE(&1E;B!,:6YK('9O
M;B!D:65S96T@16QE;65N="!E;G1F97)N96X@;?9C:'1E;BX`0FET=&4@96EN
M96X@36]N870@=6YD(&5I;B!*86AR(&%N9V5B96XN`$)I='1E(&=E8F5N(%-I
M92!E:6YE;B!.86UE;B!F_'(@9&EE(&YE=64@2V%T96=O<FEE(&%N.@!":71T
M92!G96)E;B!3:64@96EN96X@3F%M96X@9OQR(&1E;B!N975E;B!/<F1N97(@
M86XZ`$)I='1E(&5I;F4@9_QL=&EG92!)4"U!9')E<W-E(&5I;F=E8F5N+@!"
M:71T92!G96)E;B!3:64@96EN(&?\;'1I9V5S($1A='5M(&%N.R#\8F5R<'+\
M9F5N(%-I92!D:64@6F%H;"!D97(@5&%G92!I;B!D96T@36]N870N`$)I='1E
M(&5I;F5N(&?\;'1I9V5N(%IE:71W97)T(&5I;F=E8F5N+@!":71T92!G96)E
M;B!3:64@9&5N($YA;65N(&;\<B!D96X@;F5U96X@3W)D;F5R(&%N.@!":71T
M92!D96X@;F5U96X@3F%M96X@96EN9V5B96XZ`$)I='1E(&=E8F5N(%-I92!D
M87,@4&%S<W=O<G0@9OQR($EH<F5N('!R:79A=&5N(%!'4"U38VAL_'-S96P@
M86XN(%-I92!M_'-S96X@9&EE<V5S(%!A<W-W;W)T(&YU<B!E:6YM86P@<')O
M("5S+5-I='IU;F<@86YG96)E;BX`0FET=&4@9V5B96X@4VEE(&1A<R!087-S
M=V]R="!F_'(@26AR96X@<')I=F%T96X@4R]-24U%+5-C:&S\<W-E;"!A;BX@
M4VEE(&W\<W-E;B!D:65S97,@4&%S<W=O<G0@;G5R(&5I;FUA;"!P<F\@)7,M
M4VET>G5N9R!A;F=E8F5N+@!":71T92!M96QD96X@4VEE('-I8V@@=VEE9&5R
M(&%N+"!U;2!D87,@4V-H<F5I8F5N(&1E<B!.86-H<FEC:'0@9F]R='IU<V5T
M>F5N+B!796YN(%-I92!+14E.12!#;V]K:65S('IU;&%S<V5N(%5.1"!D:64@
M3F%C:')I8VAT(&EN(&5I;F5M(&5I9V5N96X@1F5N<W1E<B!E<G-T96QL96XL
M(&W\<W-E;B!3:64@<VEC:"!A=6-H(&EM($AA=7!T9F5N<W1E<B!W:65D97(@
M86YM96QD96XN($1I97,@:7-T(&[V=&EG+"!U;2!P;W1E;G1I96QL92!!;F=R
M96EF97(@9&%V;VX@86)Z=6AA;'1E;B!):')E(%-I='IU;F<@>G4@_&)E<FYE
M:&UE;BX@0FET=&4@96YT<V-H=6QD:6=E;B!3:64@9&EE<V4@56YA;FYE:&UL
M:6-H:V5I=&5N+@!":71T92!G96)E;B!3:64@96EN92!:=7-A;6UE;F9A<W-U
M;F<@26AR97,@4')O8FQE;7,@86XN`$)I='1E(&=E8F5N(%-I92!):'(@4&%S
M<W=O<G0@86XN`$)I='1E(&=E8F5N(%-I92!):')E;B!"96YU='IE<FYA;65N
M('5N9"!):'(@4&%S<W=O<G0@86X`0FET=&4@9V5B96X@4VEE($EH<F5N($)E
M;G5T>F5R;F%M96X@86XN`$)I='1E(&QE<V5N(%-I92!S:6-H(&1E;B!F;VQG
M96YD96X@5&5X="!S;W)G9N1L=&EG(&1U<F-H+B!3:64@3=Q34T5.(&1I97-E
M;B!"961I;F=U;F=E;B!Z=7-T:6UM96XL('=E;FX@4VEE(&1I97-E<R!3>7-T
M96T@8F5N=71Z96X@;?9C:'1E;BX`0FET=&4@;65H<F1E=71I9V4@;V1E<B!U
M;F?\;'1I9V4@061R97-S96X@:V]R<FEG:65R96XN`$)I='1E(&5I;F5N($]R
M9&YE<B!A=7-WY&AL96XL(&)E=F]R(%-I92!D:65S92!!:W1I;VX@9'5R8VAF
M_&AR96XN`$)I='1E(&UI;F1E<W1E;G,@96EN96X@3W)D;F5R(&;\<B!D:64@
M4W5C:&4@86YG96)E;BX`0FET=&4@;G5R(&5I;F5N($]R9&YE<B!F_'(@9&EE
M<V4@06MT:6]N(&%U<W?D:&QE;BX`0FET=&4@=^1H;&5N(%-I92!A=7,@;V1E
M<B!E9&ET:65R96X@4VEE(')E8VAT<SH`0FET=&4@9&5N(&YE=65N($MA=&5G
M;W)I96YA;65N(&5I;F=E8F5N.@!0;VQE;@!0;VQI=&EK`%5M9G)A9V5N`%!O
M<G1U9V%L`%!O<VET:6]N:65R=6YG(&1I97-E($)I;&1E<P!0;W-I=&EO;FEE
M<G5N9R!D:65S97(@5&%B96QL90!396YD96X@86X@9&EE<V5N($]R9&YE<B`H
M;FEC:'0@9'5R8V@@24U!4"D`4&]W97)E9"!B>2!(;W)D90!3=')I8VAE("@G
M+2T@)RD@=F]R(&1E<B!3:6=N871U<B!E:6YF_&=E;C\`3FEE9&5R<V-H;&%G
M(&EN(&1E;B!L971Z=&5N("5S(%-T=6YD92AN*3H@`$YI961E<G-C:&QA9W,M
M/&)R("\^=V%H<G-C:&5I;FQI8VAK96ET`$1I92!%:6YS=&5L;'5N9V5N('=U
M<F1E;B!E<F9O;&=R96EC:"!G97-P96EC:&5R="X`4')E9G-?;&1A<#H@1&EE
M(&)E;O9T:6=T92!,1$%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N
M9&5N+@!0<F5F<U]S97-S:6]N.B!$:64@8F5N]G1I9W1E(%-E<W-I;VXM17)W
M96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$QU9G1D<G5C:P!,=69T
M9')U8VL@875F(%-E96CV:&4Z(`!,=69T9')U8VLZ(`!6;W)S8VAA=0!%:6YE
M(%9O<G-C:&%U(&1E<R!":6QD97,@:6X@96EN96T@;F5U96T@1F5N<W1E<B!A
M;GIE:6=E;@!6;W)H97)I9V4@3F%C:')I8VAT`%-E:71E('IU<OQC:P!6;VAE
M<FEG92!%:6YS=&5L;'5N9V5N`$1R=6-K96X`1&]K=6UE;G0@9')U8VME;@!0
M<FEO<FETY'0`4')I=F%T97(@4V-H;/QS<V5L`%!A<W-W;W)T(&;\<B!P<FEV
M871E;B!38VAL_'-S96P`4')O8FQE;64`4')O8FQE;6)E<V-H<F5I8G5N9P!0
M<F]J96MT90!*961E<VUA;"!N86-H9G)A9V5N.R!S=&%N9&%R9&WDWVEG($Y%
M24X`2F5D97-M86P@;F%C:&9R86=E;CL@<W1A;F1A<F1MY-]I9R!*00!.86-H
M9G)A9V5T97AT`%!R;W1O:V]L;#H`UF9F96YT;&EC:&5R(%-C:&S\<W-E;`!!
M;&=O<FET:&UU<R!D97,@]F9F96YT;&EC:&5N(%-C:&S\<W-E;',`26YF;W)M
M871I;VYE;B!Z=6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E;`!$:64@56YT97)S
M=/QT>G5N9R!F_'(@]F9F96YT;&EC:&4@4$=0+5-C:&S\<W-E;'-E<G9E<B!I
M<W0@9&5A:W1I=FEE<G0@=V]R9&5N+@!$87,@]F9F96YT;&EC:&4O<')I=F%T
M92!38VAL_'-S96QP86%R(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96XN
M`%!U97)T;R!2:6-O`$5N9&?\;'1I9R!L]G-C:&5N`$5N9&?\;'1I9R!L]G-C
M:&5N`$]R9&YE<B!A=69RY'5M96X`5VEE(&]F="!S;VQL(&1E<B!087!I97)K
M;W)B(&=E;&5E<G0@=V5R9&5N.@!.86-H<FEC:'1E;B!E;F1G_&QT:6<@;/9S
M8VAE;@!.86-H<FEC:'1E;B!I;2!087!I97)K;W)B(&YA8V@@<V\@=FEE;&5N
M(%1A9V5N(&5N9&?\;'1I9R!L]G-C:&5N+@!!;'1E($YA8VAR:6-H=&5N(&EM
M(%!A<&EE<FMO<F(@96YD9_QL=&EG(&SV<V-H96X_`"5D($YA8VAR:6-H=&5N
M(&EM(%!A<&EE<FMO<F(@9V5L]G-C:'0N`#$@3F%C:')I8VAT(&EM(%!A<&EE
M<FMO<F(@9V5L]G-C:'0N`$MA=&%R`$%B9G)A9V4`4W!E:6-H97)P;&%T>BU+
M;VYT:6YG96YT`%-P96EC:&5R<&QA='HM2V]N=&EN9V5N=#H@)2XR9DU"("\@
M)2XR9DU"("@E+C)F)24I`%-P96EC:&5R<&QA='HM2V]N=&EN9V5N=#H@)2XR
M9DU"("\@2V5I;F4@0F5G<F5N>G5N9P!3<&5I8VAE<G!L871Z+4MO;G1I;F=E
M;G0Z($ME:6YE($)E9W)E;GIU;F<`6FET870@=F]N("5F.@#69F9E;G1L:6-H
M97(@4E-!(%-C:&S\<W-E;"`H)60@0FET*0!!=7-W86AL:VYO<&8`4F5G96X`
M1G+\:"!296=E;@!3<.1T97(@4F5G96X`4F5G96YS8VAA=65R`%-C:&YE97)E
M9V5N`%)E9V5N(&EN(%-C:&YE92#\8F5R9V5H96YD`$=L_&-K<VME:W,`5F5R
M:.1L=&YI<P!,97-E;@!.86-H<FEC:'1E;B!L97-E;@`E<R!W:7)K;&EC:"!L
M]G-C:&5N/R!$:65S97(@5F]R9V%N9R!K86YN(&YI8VAT('+\8VMGY&YG:6<@
M9V5M86-H="!W97)D96XN`$1A=&5N(&1E<R!"96YU='IE<G,@)7,@=VER:VQI
M8V@@;/9S8VAE;C\@1&EE<V5R(%9O<F=A;F<@:V%N;B!N:6-H="!R_&-K9^1N
M9VEG(&=E;6%C:'0@=V5R9&5N+@!/<F1N97)B875M(&YE=2!A=69B875E;@!%
M;7!F86YG96X@86T`16UP9F%N9V5N('-E:70`16UP9F%N9V5N(&)I<P!?56UL
M96ET96X`56UL96ET96X`3F%C:')I8VAT('5M;&5I=&5N`$1I97-E($YA8VAR
M:6-H="!U;6QE:71E;@!5;6QE:71U;F<@9F5H;&=E<V-H;&%G96XN`$;\:')T
M(&QE='IT92!!:W1I;VX@97)N975T(&%U<P!!:W1U86QI<VEE<F4`1'EN86UI
M<V-H92!-96[\96QE;65N=&4@86MT=6%L:7-I97)E;CH`3W)D;F5R_&)E<G-I
M8VAT(&%K='5A;&ES:65R96XZ`%!O<G1A;&%N<VEC:'0@86MT=6%L:7-I97)E
M;CH`4F5G=6SD<F5R($%U<V1R=6-K`%9E<F)I;F1U;F=S+4)R;W=S97(`06MT
M=6%L:7-I97)E;@!!;G-I8VAT(&%?:W1U86QI<VEE<F5N`$)E;65R:W5N9V5N
M`$9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N(&UE<FME;BX`1&EE(&QE='IT
M92!!;G-I8VAT(&UE<FME;@!397)V97(M3W)D;F5R.@!%;G1F97)N=&4@4V5R
M=F5R`%-E<G9E<F%D<F5S<V4@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.@!%;G1F97)N96X`0FQO8VL@;/9S8VAE;@!&96QD('9O;B!D97(@4W5C
M:&4@96YT9F5R;F5N`%-P86QT92!L]G-C:&5N`$9O<FUA=&EE<G5N9R!E;G1F
M97)N96X`4&%A<B!L]G-C:&5N`$=E<W!E:6-H97)T97,@4VMR:7!T(&%U<R!D
M96T@=&5M<&]RY')E;B!697)Z96EC:&YI<R!E;G1F97)N96XN`%%U96QL92!E
M;G1F97)N96X`16YT9F5R;F4`1&EE<V5S($5L96UE;G0@875S(&1E;2!$;VMU
M;65N="!E;G1F97)N96X`0F5N=71Z97(@;/9S8VAE;@!"96YU='IE<B!L]G-C
M:&5N.B`E<P!/<F1N97(@=6UB96YE;FYE;@!/<F1N97(@9OQR(&=E<V5N9&5T
M92!.86-H<FEC:'1E;B!A;2!-;VYA='-B96=I;FX@=6UB96YE;FYE;C\`1&EE
M(%5M8F5N96YN=6YG('9O;B`B)7,B(&YA8V@@(B5S(B!I<W0@9F5H;&=E<V-H
M;&%G96XN($UE;&1U;F<@9&5S($5M86EL+5-E<G9E<G,`3%]I<W1E($%N='=O
M<G1E;@!E<G-E='IE;B!D=7)C:#H`06YT=V]R=&5N`$%N='=O<G0@=F5R<V5N
M9&5T+@!!;&QE;B!!;G1W;W)T96X`06QL96X@06YT=V]R=&5N.@!,:7-T92!!
M;G1W;W)T96X`3&ES=&4@06YT=V]R=&5N.@!?06QL96X@06YT=V]R=&5N`$UI
M="`B3FEC:'0@=6YT97)S=/QT>G0B+4YA8VAR:6-H="!A;G1W;W)T96XN`$UI
M="!&<F5I+T=E8G5C:'0M26YF;W)M871I;VYE;B!F_'(@9&EE(&[D8VAS=&5N
M('IW96D@36]N871E(&%N='=O<G1E;BX`36ET(&5R9G)A9W1E;B!&<F5I+T=E
M8G5C:'0M26YF;W)M871I;VYE;B!A;G1W;W)T96XN`$%N='=O<G0@86X`06YT
M=V]R="!A;CH@`$%N='=O<G1E;CH`06QS(&ME:6X@4W!A;2!M96QD96X`06QS
M(%-P86T@7VUE;&1E;@!?3&5S96)E<W3D=&EG=6YG(&%N9F]R9&5R;@!!;F9R
M86=E(&MO;FYT92!N:6-H="!B96%N='=O<G1E="!W97)D96XN(%IU<OQC:V=E
M9V5B96YE<B!&96AL97)C;V1E.B``3&5S96)E<W3D=&EG=6YG96X@86YF;W)D
M97)N/P!!;F=E9V5B96YE($YA8VAR:6-H="!N:6-H="!G969U;F1E;BX`1&5R
M(&=E=_QN<V-H=&4@1&EE;G-T(&MO;FYT92!N:6-H="!G969U;F1E;B!W97)D
M96XN`"(E<R(@=W5R9&4@:6X@9&5R($MO;F9I9W5R871I;VX@9OQR("5S(&YI
M8VAT(&%N9V5G96)E;BX`(B5S(B!W=7)D92!I;B!D97(@5D93+4MO;F9I9W5R
M871I;VX@;FEC:'0@86YG96=E8F5N+@`B)7,B('=U<F1E(&EN(&1E<B!+;VYF
M:6=U<F%T:6]N(&YI8VAT(&%N9V5G96)E;BX`3F]T=V5N9&EG97,@1F5L9`!%
M<F9O<F1E<FQI8VAE<B!496EL;F5H;65R`%IU<OQC:W-E='IE;@!087-S=V]R
M="!Z=7+\8VMS971Z96X`4V5T>F5N(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K
M`%-T871U<R!D97,@06YT=V]R=&5N9&5N(&%K='5A;&ES:65R="X`3&5T>G1E
M($%B9G)A9V4@96EN9OQG96X`17)G96)N:7-S90!?1F]R=&;\:')E;@!7:65D
M97)H97)S=&5L;'5N9R!D97(@4VET>G5N9P!:=7+\8VL@>G4@(DYE=64@3F%C
M:')I8VAT(@!:=7+\8VL@>G4@)TYA8VAR:6-H=&5N('-A;6UE;&XG`%IU<OQC
M:R!Z=2!%:6YS=&5L;'5N9V5N`$YA8V@@9&5M($SV<V-H96XL(%9E<G-C:&EE
M8F5N(&]D97(@2V]P:65R96X@=F]N($YA8VAR:6-H=&5N('IU;2!/<F1N97(@
M>G5R_&-K:V5H<F5N/P!.975E<R!087-S=V]R="!E<FYE=70@96EN9V5B96X`
M4NEU;FEO;@!+;VYF:6=U<F%T:6]N('IU<OQC:W-E='IE;@!765-)5UE'+45D
M:71O<B!%:6YS=&5L;'5N9V5N`%+D='-E;`!296-H=',`4F5C:'1E(-QB97)S
M8VAR:69T`%)E8VAT92!797)T90!?6F5I;&5N96EG96YS8VAA9G1E;BXN+@!2
M;VQL90!2=6WD;FEE;@!5;2`Q.#"P(&1R96AE;@!.86-H(&QI;FMS(&1R96AE
M;@!.86-H(')E8VAT<R!D<F5H96X`6F5I;&5N96EG96YS8VAA9G1E;@!:96EL
M96YE:6=E;G-C:&%F=&5N`%IE:6QE;CH`4F5G96QN`%)A:&UE;B!Z=VES8VAE
M;B!A;&QE;B!:96EL96X@=6YD(%-P86QT96X`4F%H;65N(&YU<B!Z=VES8VAE
M;B!3<&%L=&5N`%)A:&UE;B!N=7(@>G=I<V-H96X@6F5I;&5N`%-T87)T96X`
M4G5S<VES8VAE($;V<F1E<F%T:6]N`%)U86YD80!3+TU)344`4R]-24U%(&MR
M>71O9W)A<&AI<V-H92!5;G1E<G-C:')I9G0`5F5R<V-H;/QS<V5L;B`H4R]-
M24U%*0!-:70@4R]-24U%('9E<G-C:&S\<W-E;'1E($YA8VAR:6-H=`!3+TU)
M344M1F5H;&5R.B``4R]-24U%($9E:&QE<CH@1OQR(&1E;B!P97)S]FYL:6-H
M96X@<')I=F%T96X@4V-H;/QS<V5L('=I<F0@96EN(%!A<W-W;W)T(&)E;O9T
M:6=T+@!3+TU)344M16EN<W1E;&QU;F=E;@!3+TU)344@4&%S<W=O<G1E:6YG
M86)E`$;\<B!D96X@6G5G<FEF9B!A=68@9&%S('!E<G/V;FQI8VAE(%-C:&S\
M<W-E;'!A87(@=VER9"!E:6YE('-I8VAE<F4@4V5R=F5R=F5R8FEN9'5N9R!B
M96[V=&EG="X`1&5R(/9F9F5N=&QI8VAE(%,O34E-12U38VAL_'-S96P@9OQR
M("(E<R(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N`$1E<B#V9F9E;G1L
M:6-H92!3+TU)344M4V-H;/QS<V5L('=U<F1E(&5R9F]L9W)E:6-H(&=E<W!E
M:6-H97)T+@#69F9E;G1L:6-H97(@4R]-24U%+5-C:&S\<W-E;&)U;F0`1&%S
M(/9F9F5N=&QI8VAE+W!R:79A=&4@4V-H;/QS<V5L<&%A<B!W=7)D92!E<F9O
M;&=R96EC:"!G97-P96EC:&5R="X`56YT97)Z96EC:&YE;B`H4R]-24U%*0!5
M;G1E<GIE:6-H;F5N('5N9"!V97)S8VAL_'-S96QN("A3+TU)344I`$1I92!3
M+TU)344M56YT97)S=/QT>G5N9R!W=7)D92!A=68@9&EE<V5M(%-Y<W1E;2!D
M96%K=&EV:65R="X`1&EE(%,O34E-12U5;G1E<G-T_'1Z=6YG(&ES="!Z=7(@
M6F5I="!D96%K=&EV:65R="P@<V\@9&%S<R!D:64@3F%C:')I8VAT(&YI8VAT
M(&5N='-C:&S\<W-E;'0@=V5R9&5N(&MA;FXN`$1I92!3+TU)344M56YT97)S
M=/QT>G5N9R!I<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0L('-O(&1A<W,@9&5R
M($EN:&%L="!D:65S97(@=6YT97)S8VAR:65B96YE;B!.86-H<FEC:'0@;FEC
M:'0@86YG97IE:6=T('=E<F1E;B!K86YN+@!$:64@4R]-24U%+55N=&5R<W3\
M='IU;F<@:7-T('IU<B!:96ET(&1E86MT:79I97)T+"!S;R!D87-S(&1I92!D
M:6=I=&%L92!5;G1E<G-C:')I9G0@;FEC:'0@_&)E<G!R_&9T('=E<F1E;B!K
M86YN+@!$:64@4R]-24U%+55N=&5R<W3\>G5N9R!B96[V=&EG="!0;W!U<"U&
M96YS=&5R+"!U;2!Z=2!F=6YK=&EO;FEE<F5N+B!796YN($EH<B!"<F]W<V5R
M('IU<B!:96ET('-O(&5I;F=E<W1E;&QT(&ES="P@9&%S<R!0;W!O<"U&96YS
M=&5R('5N=&5R9'+\8VMT('=E<F1E;BP@;?QS<V5N('-I92!D:65S92!%:6YS
M=&5L;'5N9R#D;F1E<FXL(&]D97(@9&EE(%,O34E-12U&=6YK=&EO;F5N('=E
M<F1E;B!N:6-H="!R:6-H=&EG(&9U;FMT:6]N:65R96XN`%-!4TPM075T:&5N
M=&EF:7II97)U;F<@:7-T(&YI8VAT('9E<F;\9V)A<BX`4TU3+59E<G-A;F0`
M4TU44`!344P@4VAE;&P`4U%,+4%N=V5I<W5N9R!Z=7(@06)F<F%G92!D97(@
M5V5R=&4`4U-(`$521D],1P!37U%,(%-H96QL`$)E=')E7V9F`%-A`%]+;W!I
M92!S<&5I8VAE<FX@:6X@`%-P96EC:&5R;B!U;G1E<@!386EN="!(96QE;F$`
M4V%I;G0@2VET=',@=6YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R
M92!U;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!U;F0@9&EE($=R96YA9&EN
M96X`1VQE:6-H97(@4F%H;65N("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!U;F0@4')I;F-I<&4`4V%T96QL:71E;G!R;W9I9&5R`%-A=61I
M+4%R86)I96X`4W!E:6-H97)N`"(E<R(@<W!E:6-H97)N`"5S('-P96EC:&5R
M;@!!;FCD;F=E('IU<V%M;65N(&UI="!.86-H<FEC:'1E;B!I;2!/<F1N97(@
M9OQR(&=E<V5N9&5T92!.86-H<FEC:'1E;B!S<&5I8VAE<FX_`$5N='=U<F8@
M<W!E:6-H97)N`$)I;&0@<W!E:6-H97)N`$)I;&0@:6X@1V%L97)I92!S<&5I
M8VAE<FX`16EN<W1E;&QU;F=E;B!S<&5I8VAE<FX`5F]R;&%G92!S<&5I8VAE
M<FX`7T5N='=U<F8@<W!E:6-H97)N`%-P96EC:&5R;B!U;G1E<@!%;G?\<F9E
M(&%L<R!U;F=E;&5S96X@<W!E:6-H97)N/P!%<GIE=6=T92!+;VYF:6=U<F%T
M:6]N(&%L<R!02%`M4VMR:7!T(&EM('1E;7!O<N1R96X@5F5R>F5I8VAN:7,@
M26AR97,@4V5R=F5R<R!S<&5I8VAE<FXN`$5M<&;D;F=E<B!A=71O;6%T:7-C
M:"!I;2!3=&%N9&%R9&%D<F5S<V)U8V@@<W!E:6-H97)N/P!3=6-H92!A;',@
M=FER='5E;&QE;B!/<F1N97(@<W!E:6-H97)N/P!'97-E;F1E=&4@3F%C:')I
M8VAT96X@<W!E:6-H97)N/P`E<RU+;VYF:6=U<F%T:6]N(&=E<W!E:6-H97)T
M+@!$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T('=U<F1E(&EN("(E<R(@9V5S
M<&5I8VAE<G0N`$1E<B!%;G1W=7)F(&MO;FYT92!N:6-H="!G97-P96EC:&5R
M="!W97)D96XN($UE;&1U;F<@9&5S($5M86EL+5-E<G9E<G,Z("5S`%9E<F5I
M;GIE;'1E($=E=VET=&5R`%=I<W-E;G-C:&%F=`!3=6-H90!3=6-H96X@:6X@
M)7,`4W5C:&UA<V-H:6YE;@!3=6-H96EN<W1E;&QU;F=E;@!3=6-H97)G96)N
M:7-S90!'96QE<V5N`$%U<W=A:&P`06YD97)E<R!+;VYT;R!A=7-WY&AL96X`
M1&%T96EE;B!A=7-WY&AL96X`1&%T=6T@875S=^1H;&5N`%?D:&QE;B!3:64@
M96EN($9E;&0@875S`$AI;GIU>G5F_&=E;F1E($=R=7!P96X@875S=^1H;&5N
M`$YE=65N($)E<VET>F5R(&%U<W?D:&QE;@!397)V97(@875S=^1H;&5N`%9O
M<FQA9V4@875S=^1H;&5N.@!(:6YZ=7IU9OQG96YD96X@0F5N=71Z97(@875S
M=^1H;&5N`%?D:&QE;B!3:64@9&EE($%D<F5S<V+\8VAE<B!Z=6T@4W5C:&5N
M(&YA8V@@=6YD($AI;GIU9OQG96X@=F]N(&YE=65N($%D<F5S<V5N(&%U<RX`
M06QL92!A=7-WY&AL96X`3&5G96X@4VEE(&%L;&4@1&%T=6US:V]M<&]N96YT
M96X@9F5S="X`5^1H;&5N(%-I92!D:64@1F5L9&5R(&%U<RP@:6X@9&5N96X@
M;F%C:"!.86UE;B!G97-U8VAT('=E<F1E;B!S;VQL+@!+;VYT;R!A=7-WY&AL
M96X`3V)J96MT(&%U<W?D:&QE;@!+96EN96X@875S=^1H;&5N`%?D:&QE;B!3
M:64@9&EE(&)E;O9T:6=T96X@6F5I8VAE;B!A=7,@9&5N(&IE=V5I;&EG96X@
M1F5L9&5R;B!A=7,N($1A;FX@:_9N;F5N(%-I92!D:65S92!A=7,@9&5M(%1E
M>'1F96QD(&MO<&EE<F5N('5N9"!I;B!):')E($YA8VAR:6-H="!E:6YF_&=E
M;BX`5^1H;&5N(%-I92!D87,@1&%T=6US=')E;FYZ96EC:&5N.@!7Y&AL96X@
M4VEE(&1A<R!$871U;7-F;W)M870Z`%?D:&QE;B!3:64@9&EE($=A;&5R:64L
M(&EN(&1E<B!D87,@0FEL9"!G97-P96EC:&5R="!W97)D96X@<V]L;`!7Y&AL
M96X@4VEE(&1I92!)9&5N=&ETY'0L(&1I92!3:64@Y&YD97)N(&WV8VAT96XZ
M`%?D:&QE;B!3:64@9&5N(%-E<G9E<G1Y<"!A=7,`5^1H;&5N(%-I92!D87,@
M6F5I='1R96YN>F5I8VAE;CH`5^1H;&5N(%-I92!D87,@6F5I=&9O<FUA=#H`
M5^1H;&5N(%-I92!Z=V5I('IU<V%M;65N9V5H]G)I9V4@1F5L9&5R(&%U<RX`
M5^1H;&5N(%-I92!E:6X@1F%R8G-C:&5M82X`5^1H;&5N(%-I92!):')E(&)E
M=F]R>G5G=&4@4W!R86-H93H`075S9V5WY&AL=&4@061R97-S8OQC:&5R.@!3
M8VAL_'-S96P@>G5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(@<V-H
M:6-K96X`06MT=65L;&4@26YF;W)M871I;VYE;B!V97)S96YD96X`4V5N9&5N
M`%!R;V)L96UB97)I8VAT(&%B<V-H:6-K96X`4TU3('9E<G-C:&EC:V5N`$1I
M92!.86-H<FEC:'0@;VAN92!E:6X@0F5T<F5F9B!V97)S8VAI8VME;C\`3&5S
M96)E<W3D=&EG=6YG('-C:&EC:V5N+"!W96YN('9O;2!!8G-E;F1E<B!G97?\
M;G-C:'0_`%-E;F5G86P`4V5N<V]R.B``3W)D;F5R(&;\<B!G97-E;F1E=&4@
M3F%C:')I8VAT96X`3W)D;F5R(&;\<B!G97-E;F1E=&4@3F%C:')I8VAT96XZ
M`%-E<'1E;6)E<@!397)B:65N('5N9"!-;VYT96YE9W)O`%-E<FEE;FYU;6UE
M<@!%;6%I;"U397)V97(`16UA:6PM4V5R=F5R+2!U;F0@3W)D;F5R+45I;G-T
M96QL=6YG96X`4V5R=F5R9&%T96X@=6YG_&QT:6<@;V1E<B!N:6-H="!V97)F
M_&=B87(N`%-E<G9E<CH`4V5S<W-I;VYV97)W86QT=6YG`%-E<W-I;VXM240@
M86)G96QA=69E;BX`4VET>G5N9V5N`$%U<W=A:&PM4V%T>@!,96=E;B!3:64@
M9&EE($5I;G-T96QL=6YG96X@9F5S="P@9&EE(&5S($EH;F5N(&5R;&%U8F5N
M($EH<B!087-S=V]R="!Z=7+\8VMZ=7-E='IE;BP@9F%L;',@<VEE(&5S(&5I
M;FUA;"!V97)G97-S96X@<V]L;'1E;BX`3&5G96X@4VEE(&9E<W0L('=A<R!N
M86-H(&1E;2!,]G-C:&5N('5N9"!697)S8VAI96)E;B!V;VX@3F%C:')I8VAT
M96X@<&%S<VEE<F5N('-O;&PN`%!R:6]R:73D="!B96EM($5R<W1E;&QE;B!V
M;VX@;F5U96X@3F%C:')I8VAT96X@<V5T>F5N/P!,96=E;B!3:64@96YT9F5R
M;G1E(%-E<G9E<B!F97-T+"!A=68@9&EE(%-I92!V;VX@26AR96T@4&]R=&%L
M(&%U<R!Z=6=R96EF96X@;?9C:'1E;BX`5^1H;&5N(%-I92!):')E(&)E=F]R
M>G5G=&4@4W!R86-H92P@6F5I='IO;F4@=6YD($1A='5M<V5I;G-T96QL=6YG
M96XN`$QE9V5N(%-I92!D87,@9&EE(%-T87)T86YW96YD=6YG+"!D87,@1F%R
M8G-C:&5M82P@9&EE(%-E:71E;F%K='5A;&ES:65R=6YG('5N9"!A;F1E<F4@
M06YZ96EG965I;G-T96QL=6YG96X@9F5S="X`2V]N9FEG=7)A=&EO;@!!:W1U
M86QI<VEE<G5N9W-S:W)I<'1E('-I;F0@=F5R9OQG8F%R`$UE:')E<F4@<&%S
M<V5N9&4@3W)T92!M:70@9&EE<V5M(%!A<F%M971E<CH@`%-E>6-H96QL96X`
M1V5M96EN<V%M92!/<F1N97(`1V5M96EN<V%M92!/<F1N97(`5&5I;&5N(%-I
M92!):')E($]R9&YE<B!M:70@86YD97)E;B!"96YU='IE<FXN`$5I;FMA=68`
M2W5R>F4@6G5S86UM96YF87-S=6YG`%-O;&QE;B!487-T96YK;VUB:6YA=&EO
M;F5N(&;\<B!D:64@;65I<W1E;B!,:6YK<R!A:W1I=FEE<G0@=V5R9&5N/P!3
M;VQL96X@9W+VWV5R92!!8G-C:&YI='1E('II=&EE<G1E;B!497AT97,@<W1A
M;F1A<F1MY-]I9R!A;F=E>F5I9W0@;V1E<B!V97)S=&5C:W0@=V5R9&5N/R!3
M:64@:_9N;F5N(&1I92!!;G-I8VAT(&EM(%1E>'0@=6US8VAA;'1E;BP@96=A
M;"!W96QC:&4@16EN<W1E;&QU;F<@4VEE('?D:&QE;BX`4V]L;"!I;2!);FAA
M;'0@=F]N(%1E>'1N86-H<FEC:'1E;B!N86-H(%!'4"U$871E;B!G97-U8VAT
M('=E<F1E;C\`4V]L;"!D87,@3F%C:')I8VAT96YF96YS=&5R(&YA8V@@9&5M
M(%-P96EC:&5R;B!E:6YE<R!%;G1W=7)F97,@9V5S8VAL;W-S96X@=V5R9&5N
M/P!3;VQL($EH<B#V9F9E;G1L:6-H97(@4$=0+5-C:&S\<W-E;"!S=&%N9&%R
M9&WDWVEG(&%N($EH<F4@3F%C:')I8VAT96X@86YG96CD;F=T('=E<F1E;C\`
M6F5I9V5N`$%L;&4@3W)D;F5R(&%N>F5I9V5N`$%L;&4`6F5I9V4@9V5L]G-C
M:'1E`$5I;F9A8V@`36%I;&EN9VQI<W1E`$YU<B!E:6YG96)L96YD971E($]R
M9&YE<B!A;GIE:6=E;@!!=7-G95]B;&5N9&5T92!/<F1N97(@86YZ96EG96X`
M4WEM8F]L('IU;2!%;G1F97)N96X@=F]N($%N:.1N9V5N(&5I;F5R($YA8VAR
M:6-H="!A;GIE:6=E;C\`56YT97)S8VAI961E('IW:7-C:&5N(&1E<B!A:W1U
M96QL96X@=6YD(&1E<B!G97)A9&4@97)Z975G=&5N($MO;F9I9W5R871I;VX@
M86YZ96EG96XN`$%N>F5I9V5N+"!W86YN(&1I92!L971Z=&4@06YM96QD=6YG
M(&5R9F]L9W0@:7-T/P!&87)B;&5G96YD92!I;B!D97(@3W)D;F5R86YS:6-H
M="!A;GIE:6=E;C\`17)H86QT96X@9&5S($]R:6=I;F%L<R!E<FWV9VQI8VAE
M;@!!=7-WY&AL97(@86YZ96EG96X`5F]R<V-H874@;G5R(&;\<B!U;F=E;&5S
M96YE($YA8VAR:6-H=&5N(&%N>F5I9V5N/P!6;W)S8VAA=2!I;B!E:6YE;2!4
M;V]L=&EP(&%N>F5I9V5N/P!797)K>F5U9VQE:7-T92!F_'(@5&%B96QL96X@
M86YZ96EG96X_`$1A<R`E<RU-96[\(&%U9B!D97(@;&EN:V5N(%-E:71E(&%N
M>F5I9V5N/P`B2V]N=&5N(BU3>6UB;VP@:6X@9&5R($UE;OQZ96EL92!A;GIE
M:6=E;C\`0FEL9&5R(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YZ96QL
M96YE:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YE
M:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YZ96EL
M96YE:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$9I;'1E<G-Y;6)O;"!I;B!D97(@
M365N_'IE:6QE(&%N>F5I9V5N/P!$:6%L;V<@9OQR($)I;&1E:6=E;G-C:&%F
M=&5N(&%N>F5I9V5N`$=E<V%M='IA:&P@9&5R($YA8VAR:6-H=&5N(&EM($]R
M9&YE<B!A;GIE:6=E;C\`2&]C:&QA9&5N(&5R;?9G;&EC:&5N`%-C:&%U97(`
M1G+\:"!38VAA=65R`%-PY'1E<B!38VAA=65R`%-C:&%U97(@:6X@9&5R(%5M
M9V5B=6YG`$%N9V5Z96EG=`!697)K;&5I;F5R;@!697)K;&5I;F5R;B!O9&5R
M('9E<G-C:&EE8F5N(%-I92!E<G-T(&1I92!B96YA8VAB87)T96X@0FSV8VME
M`%]'<O;?90!3:65R<F$@3&5O;F4`4F5G:7-T<FEE<F5N`%-I9VYA='5R`%-I
M9VYA='5R86QG;W)I=&AM=7,`56YT97)S8VAR:65B96X`4VEN9V%P=7(`1W+V
MWV4`5V%R='5N9W-A<F)E:71E;B#\8F5R<W!R:6YG96X`4VQO=V%K96D`4VQO
M=V5N:65N`%-C:&YE90!38VAN965S8VAA=65R`%-C:&YE97-C:&%U97(`1G+\
M:"!38VAN965S8VAA=65R`%-PY'1E<B!38VAN965S8VAA=65R`%-C:&YE96CV
M:&4Z(`!38VAN965M96YG92!A;',@5V%S<V5R.B``4V]L;VUO;FEN<V5L;@!3
M;VUA;&EE;@!,:65D97(@)B!'961I8VAT90!3;W)T:65R96X@;F%C:"!!;FMU
M;F9T`%-O<G1I97)E;B!N86-H($1A='5M`%-O<G1I97)E;B!N86-H($%B<V5N
M9&5R`%-O<G1I97)E;B!N86-H($=R]M]E`%-O<G1I97)E;B!N86-H($)E=')E
M9F8`4V]R=&EE<F5N(&YA8V@@5&AE;6$`4V]R=&EE<F5N(&YA8V@@16UP9N1N
M9V5R`$%U<W=A:&P@9&5R(%-O<G1I97)R96EH96YF;VQG90!5<G-P<G5N9W-A
M9')E<W-E`%/\9&%F<FEK80!3_&1E=7)O<.1I<V-H("A)4T\M.#@U.2TS*0!3
M_&1G96]R9VEE;B!U;F0@9&EE(%/\9&QI8VAE;B!386YD=VEC:&EN<V5L;@!3
M_&1L:6-H92!(96UI<W!H97)E`$%B<W1A;F0@>G=I<V-H96X@875F96EN86YD
M97(@9F]L9V5N9&5N(%IE;&QE;@!!8G-T86YD('IW:7-C:&5N($EN:&%L="!U
M;F0@4F%H;65N('9O;B!:96QL96X`06)S=&%N9&AA;'1E<@!!8G-T86YD`$%B
M<W3D;F1E`%-P86YI96X`4W!A;0!3<&%M+4]R9&YE<CH`4V]N9&5R>F5I8VAE
M;BU%:6YG86)E`%-O;F1E<GIE:6-H96X`5FER='5E;&QE(%-P97II86QO<F1N
M97(@:_9N;F5N(&YI8VAT(&)E87)B96ET970@=V5R9&5N+@!296-H='-C:')E
M:6)U;F<`4F5C:'1S8VAR96EB<'+\9G5N9P!296-H='-C:')E:6)P<OQF=6YG
M(&)E96YD970`4F5C:'1S8VAR96EB9F5H;&5R('!R;R!396ET92!B96D@9&5R
M(%)E8VAT<V-H<F5I8G!R_&9U;F<N`%IE;&QE('1E:6QE;@!3<&%L=&4@=&5I
M;&5N`%IE:6QE('1E:6QE;@!3<&]R=`!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A
M<B!4<F5K`$)E9VEN;@!3=&%R=&IA:'(`0G5N9&5S<W1A870@;V1E<B!0<F]V
M:6YZ`%9O<FQA9V5N`%9O<FQA9V5N;F%M93H`5F]R;&%G96YT>7`Z`%9O<FQA
M9V4Z`%-T871U<P!3<&5I8VAE<F9O<FUA=`!3=')AWV4`1'5R8VAG97-T<FEC
M:&5N`%IE:6-H96YL:7-T90!!;FAA;F<@96YT9F5R;F5N`$1O;6%I;B!A=7,@
M9&5R($%D<F5S<V4@96YT9F5R;F5N`%IE:6QE;OQM8G+\8VAE(&5N=&9E<FYE
M;C\`4W1I;"!;0U-370!3;P!"971?<F5F9@!5;G1E<G9E<GIE:6-H;FES("(E
M<R(@;FEC:'0@9V5F=6YD96XN`$)E=')E9F8`0F5T<F5F9GIE:6QE`$%B<V-H
M:6-K96X`1&EE(%)E9VES=')I97)U;F=S86YF<F%G92!F_'(@(B5S(B!W=7)D
M92!A8F=E<V-H:6-K="X@4VEE(&OV;FYE;B!S:6-H(&YO8V@@;FEC:'0@86YM
M96QD96XL('-O;&%N9V4@9&EE($%N9G)A9V4@;F]C:"!N:6-H="!B97-TY'1I
M9W0@=W5R9&4N`$]R9&YE<B!E:6YB;&5N9&5N`%1I969G97-T96QL=`!%<F9O
M;&<`(B5S(B!W=7)D92!E<F9O;&=R96EC:"!H:6YZ=6=E9OQG="X`1&%T96X@
M9&5S($)E;G5T>F5R<R`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&=E;/9S8VAT
M+@`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&=E;/9S8VAT+@`B)7,B('=U<F1E
M(&5R9F]L9W)E:6-H(&=E;/9S8VAT+@!+;VYF:6=U<F%T:6]N(&5R9F]L9W)E
M:6-H('IU<OQC:V=E<V5T>G0N(%-E:71E(&YE=2!L861E;BP@=6T@9&EE(,1N
M9&5R=6YG96X@86YZ=7IE:6=E;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N
M(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+@!"86-K=7`@9&5R($MO;F9I9W5R
M871I;VX@)7,@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N`"(E<R(@=W5R9&4@
M97)F;VQG<F5I8V@@86MT=6%L:7-I97)T`"5S('=U<F1E(&5R9F]L9W)E:6-H
M(&=E<W!E:6-H97)T`%-U9&%N`%9O<G-C:&SD9V4`6G5S86UM96YF87-S=6YG
M`%-O;FYE;F%U9F=A;F<`4V]N;F5N=6YT97)G86YG`%-O;FYI9P!3;VYN96YA
M=69G86YG`%-O;FYE;F%U9B]U;G1E<F=A;F<`4V]N;F5N875F9V%N9SH@`%-O
M;FYE;G5N=&5R9V%N9P!3;VYN96YU;G1E<F=A;F<Z(`!(;V-H9V5S=&5L;'0`
M4W5P<&]R=`!3=7)I;F%M`$YA8VAN86UE`%-V86QB87)D('5N9"!*86X@36%Y
M96X`4W=A<VEL86YD`%-C:'=E9&5N`$5D:71I97)M;V1U<R!U;7-C:&%L=&5N
M`%IU;2!(5$U,+4UO9'5S('=E8VAS96QN`%IU;2!497AT+4UO9'5S('=E8VAS
M96QN`%-C:'=E:7H`4WEN8VAR;VYI>F%T:6]N<VQO9R!G96SV<V-H=`!3>6YC
M34P`1F]R;6%T9F5H;&5R(&EN(%-U8VAB96=R:69F96X`07)A8FES8VAE(%)E
M<'5B;&EK(%-Y<FEE;@!'97=I='1E<@!'97=I='1E<B!U;F0@5VEN9&EG`$=E
M=VET=&5R`$9R_&@@1V5W:71T97(`5%-6+41A=&5I`%1A8F5L;&5N96EG96YS
M8VAA9G1E;@!486)E;&QE`%1A8F5L;&5N96EG96YS8VAA9G1E;@!486EW86X`
M5&%I=V%N+"!C:&EN97-I<V-H92!0<F]V:6YZ`%1A9'-C:&EK:7-T86X`5F5R
M96EN:6=T92!297!U8FQI:R!486YS86YI80!::65L.@!!=69G86)E;@!?5&5X
M=`!496QE9F]N;G5M;65R`%1E;7!E<F%T=7(@9&5R(&QE='IT96X@4W1U;F1E
M.B``5&5M<&5R871U<@!496UP97)A='5R.B``5&5M<&5R871U<CQB<B`O/B@E
M<TUA>"5S+R5S36EN)7,I("9D96<[)7,`5F]R;&%G92`B)7,B(&YI8VAT(&=E
M9G5N9&5N+@!6;W)L86=E;G9E<G=A;'1U;F<`56YT97(@5F]R8F5H86QT.B``
M06YF<F%G92!V;W)LY'5F:6<@86YN96AM96X`5F]R;.1U9FEG(&%N9V5N;VUM
M96X`1&EE($YU='IU;F=S8F5D:6YG=6YG96X@=W5R9&5N(&EN(&-O;F8N<&AP
M(&YI8VAT(&%N9V5G96)E;BX`5&5X=`!.=7(@5&5X=`!!=7-R:6-H='5N9P!4
M97AT($]B96X`1&\`5&AA:6SD;F1I<V-H("A425,M-C(P*0!4:&%I;&%N9`!$
M:64@1E10+45X=&5N<VEO;B!I<W0@;FEC:'0@=F5R9OQG8F%R+@!$:64@5F]N
M.B!3<&%L=&4@9&5R($YA8VAR:6-H="!S;VQL('-O('9E<FQI;FMT('=E<F1E
M;CH`1&EE($-H<F]N:6L@<W1E:'0@;FEC:'0@>G5R(%9E<F;\9W5N9RX`1&EE
M($AO<F1E+TMO;&%B($EN=&5G<F%T:6]N<V9U;FMT:6]N96X@=6YT97)S=/QT
M>F5N("(E<R(@;FEC:'0`1&5R($E-05`M4V5R=F5R('-C:&5I;G0@9&EE(&%U
M<V=E=^1H;'1E($%N;65L9&5M971H;V1E(&YI8VAT('IU('5N=&5R<W3\='IE
M;BX@0FET=&4@:V]N=&%K=&EE<F5N(%-I92!):')E;B!3>7-T96UA9&UI;FES
M=')A=&]R+@!$:64@24U34"U,;V=D871E:2!K;VYN=&4@;FEC:'0@97)S=&5L
M;'0@=V5R9&5N+@!$:64@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL`1&EE($UA
M8VEN=&]S:"!R97-O=7)C92!F;W)K(&MA;FX@)7,@:&5R=6YT97)G96QA9&5N
M('=E<F1E;BX`1&EE($UA:6YT96YA;F-E.CH@2VQA<W-E(&MO;FYT92!N:6-H
M="!G96QA9&5N('=E<F1E;@!$87,@16EN<W1E;&QU;F=E;BU&96YS=&5R(&ES
M="!G97-C:&QO<W-E;B!W;W)D96XN($%B8G)U8V@N`$1A<R!+;VYT;R`B)7,B
M('=U<F1E(&=E;/9S8VAT+@!$87,@2V]N=&\@(B5S(B!W=7)D92!G97-P96EC
M:&5R="X`1&5R($%D;6EN:7-T<F%T;W(@;75S<R!E:6X@<&5R;6%N96YT97,@
M4F5C:'1E+4)A8VME;F0@96EN<FEC:'1E;BP@=V5N;B!3:64@9&EE(%)E8VAT
M979E<G=A;'1U;F<@;G5T>F5N(&WV8VAT96XN`$1E<B!!;FAA;F<@=W5R9&4@
M;FEC:'0@9V5F=6YD96XN`$YU<B!U;G1E;@!$:64@2V%L96YD97)D871E;B!S
M:6YD('5N9_QL=&EG`$1I92!)1"U.=6UM97(@9&5S($MO;G1A:W1S('=U<F1E
M(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D97(@:V]N;G1E(&EN(&1E<B!$
M871E;F)A;FL@;FEC:'0@9V5F=6YD96X@=V5R9&5N+@!$97(@2V]N=&%K="!W
M=7)D92!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T
M+@!$97(@26YH86QT(&1E<B!-86-I;G1O<VAD871E:2!B969I;F1E="!S:6-H
M('5N=&5N+@!$:64@86MT=65L;&5N($]R9&YE<B`B)7,B('=E<F1E;B!N86-H
M("(E<R(@=6UB96YA;FYT+@!$:64@86MT=65L;&4@3&ES=&4@9&5R($)E;G5T
M>F5R+"!D:64@6G5G<FEF9B!A=68@9&EE<V5N($]R9&YE<B!H86)E;BP@:V]N
M;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N`$1E<B!01U`M4VEG;F%T=7)B
M;&]C:R!W:7)D(&)E;O9T:6=T+"!U;2!D:64@=6YT97)Z96EC:&YE=&4@3F%C
M:')I8VAT('IU(/QB97)P<OQF96XN`$1I92!)1"U.=6UM97(@9&5R(%9E<G1E
M:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D97(@
M:V]N;G1E(&EN(&1E<B!$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@=V5R9&5N
M+@!$:64@5F5R=&5I;&5R;&ES=&4@=W5R9&4@;FEC:'0@86YG96=E8F5N+@!$
M97(@16YT=W5R9B!W=7)D92!I;2!/<F1N97(@(B5S(B!G97-P96EC:&5R="X`
M1&EE(%9E<G-C:&S\<W-E;'5N9W-F=6YK=&EO;F5N(&)E;O9T:6=E;B!E:6YE
M('-I8VAE<F4@4V5R=F5R=F5R8FEN9'5N9RX`1&5R(%1E<FUI;B!W=7)D92!)
M:')E;2!+86QE;F1E<B!H:6YZ=6=E9OQG="X`1&%S("(E<R(M1F5L9"!K;VYN
M=&4@;FEC:'0@=F5R=F]L;'-TY&YD:6=T('=E<F1E;BX`1&EE($1A=&5I("5S
M('-O;&QT92!E:6YE;B`E<R!%:6YT<F%G(&5N=&AA;'1E;BX`1&EE($1A=&5I
M("5S('-O;&QT92!E:6YI9V4@)7,@16EN='+D9V4@96YT:&%L=&5N+@!$:64@
M1&%T96D@:V%N;B!N:6-H="!A=68@<VEC:"!S96QB<W0@:V]P:65R="!W97)D
M96XN`$1I92!$871E:2!E;G1H:65L="!K96EN92!$871E;BX`1&5R($]R9&YE
M<B`B)7,B(&5X:7-T:65R="!B97)E:71S`$1E<B!.86UE(&1E<R!/<F1N97)S
M("(E<R(@96YT:.1L="!U;F?\;'1I9V4@6F5I8VAE;BP@=V%S('IU(%!R;V)L
M96UE;B!F_&AR96X@:_9N;G1E+B!":71T92!W96YD96X@4VEE('-I8V@@86X@
M26AR96X@4WES=&5M+4%D;6EN:7-T<F%T;W(N`$1E<B!/<F1N97(@(B5S(B!W
M=7)D92!E<G-T96QL="P@86)E<B!N;V-H(&YI8VAT(&5I;F=E8FQE;F1E="X`
M1&5R($]R9&YE<B`B)7,B('=U<F1E(&=E;/9S8VAT+"!A8F5R(&YO8V@@;FEC
M:'0@875S9V5B;&5N9&5T+@!$97(@3W)D;F5R("(E<R(@:V]N;G1E(&YI8VAT
M(&5R<W1E;&QT('=E<F1E;BX@365L9'5N9R!D97,@16UA:6PM4V5R=F5R<P!$
M97(@3W)D;F5R("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX@
M365L9'5N9R!D97,@16UA:6PM4V5R=F5R<SH`1&5R($]R9&YE<B`B)7,B('=U
M<F1E(&5R9F]L9W)E:6-H(&5R<W1E;&QT+@!$97(@3W)D;F5R("(E<R(@=W5R
M9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N`$1E<B!/<F1N97(@(B5S(B!W=7)D
M92!E<F9O;&=R96EC:"!N86-H("(E<R(@=6UB96YA;FYT+@!(:65R('-I;F0@
M9&EE($MO<&9E:6YT<N1G92!F_'(@9&EE<V4@;65S<V%G92]R9F,X,C(@3F%C
M:')I8VAT+@!&;VQG96YD92!$871E:65N('=A<F5N(&%N(&1I97-E;B!496EL
M(&%N9V5HY&YG=#H`1&5R(%9O;&QB:6QD;6]D=7,@=F5R=7)S86-H="!A=68@
M1W)U;F0@=F]N($9E:&QE<FX@:6T@26YT97)N970@17AP;&]R97(@8F5K86YN
M=&5R;6'?96X@4')O8FQE;64@;6ET(&1I97-E;2!"<F]W<V5R+"!D:64@=VER
M(&YI8VAT('5M9V5H96X@:_9N;F5N+B!5;G1E<B!5;7-TY&YD96X@97)H86QT
M96X@4VEE(&5I;F4@9F5H;&5R:&%F=&4@06YZ96EG92P@9F5H;&5N($5D:71O
M<F9U;FMT:6]N96XL(&]D97(@9&5R($)R;W=S97(@<W3\<GIT(&%B+B!!=68@
M96EN96T@5VEN9&]W(#EX(%-Y<W1E;2!W97)D96X@4VEE('9E<FUU=&QI8V@@
M96EN92`G06QL9V5M96EN92!38VAU='IV97)L971Z=6YG)R!E<FAA;'1E;B!U
M;F0@;?QS<V5N(&1E;B!296-H;F5R(&YE=2!S=&%R=&5N+EQN7&Y3:64@=W5R
M9&5N(&=E=V%R;G0N($)I='1E(&1R_&-K96X@4VEE(&%U9B!/2RP@=V5N;B!3
M:64@;F]C:"!I;6UE<B!D96X@5F]L;&)I;&1M;V1U<R!V97)W96YD96X@;?9C
M:'1E;BX`1&EE($ED96YT:73D="`B)7,B('=U<F1E(&=E;/9S8VAT+@!$87,@
M1&EA;&]G9F5N<W1E<B!Z=6T@4W!E:6-H97)N(&1E<R!":6QD97,@:V]N;G1E
M(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX@5FEE;&QE:6-H="!H86)E;B!3:64@
M26AR96X@0G)O=W-E<B!S;R!E:6YG97-T96QL="P@9&%S<R!E<B!0;W!U<"U&
M96YS=&5R(&)L;V-K:65R=#\`1&EE($)I;&1E<B!W97)D96X@86YG97IE:6=T
M+"!W96EL('-I8V@@9&5R($%B<V5N9&5R(&EN($EH<F5M($%D<F5S<V)U8V@@
M8F5F:6YD970N`$YU<B!L:6YK<P!$97(@3W)T(&1E<R!';G501RU0<F]G<F%M
M;7,@;75S<R!D97(@0W)Y<'1?<&=P.CH@2VQA<W-E(/QB97)G96)E;B!W97)D
M96XN`$1E<B!%;6%I;"U397)V97(@:&%T(&9O;&=E;F1E($9E:&QE<FUE;&1U
M;F<@97)Z975G=#H`1&5R($5M86EL+5-E<G9E<B!H870@9F]L9V5N9&4@3F%C
M:')I8VAT(&=E;F5R:65R=#H`1&5R($5M86EL+5-E<G9E<B!H870@9F]L9V5N
M9&4@3F%C:')I8VAT(&5R>F5U9W0Z`$1E<B!/<F1N97(@)7,@:7-T(&)E<F5I
M=',@;&5E<BX`1&EE($YA8VAR:6-H="`B)7,B('9O;B`B)7,B("@E9"!">71E
M<RD@_&)E<G-C:')E:71E="!D:64@;6%X:6UA;&4@1W+VWV4@9OQR(&AE<G5N
M=&5R>G5L861E;F4@3F%C:')I8VAT96XN`$1I92!.86-H<FEC:'0L(&1I92!E
M<G-T96QL="!W=7)D92P@:7-T(&=E<V-H;&]S<V5N('=O<F1E;BX@06)B<G5C
M:"X`4VEE(&AA8F5N(&;\<B!D:65S92!.86-H<FEC:'0@:V5I;F5N($)E=')E
M9F8@86YG96=E8F5N+@!$:64@3F%C:')I8VAT('=U<F1E(&=E;/9S8VAT+@!$
M:64@3F%C:')I8VAT('=U<F1E(/QB97)P<OQF="!U;F0@8F5S=.1T:6=T+@!$
M:64@3F%C:')I8VAT('=U<F1E(/QB97)P<OQF="!U;F0@8F5S=.1T:6=T+B!!
M8G-E;F1E<CH@)7,N`$1I92!.86-H<FEC:'0@;6ET(&1E;2!"971R969F("(E
M,R1S(BP@9&EE(&%M("4Q)',@86X@)3(D<R!G97-C:&EC:W0@=W5R9&4L(&ES
M="!A;F=E>F5I9W0@=V]R9&5N+@I$87,@:&5IWW0@;FEC:'0L(&1A<W,@9&EE
M($YA8VAR:6-H="!A=6-H(&=E;&5S96X@;V1E<B!V97)S=&%N9&5N('=U<F1E
M+@!.86UE(&;\<B!D96X@3&EN:R!Z=7(@3F%C:')I8VAT96YE<G-T96QL=6YG
M`$1I92!!;GIA:&P@9&5R($9E;&1E<B!M=7-S(&%L<R!:86AL(&%N9V5G96)E
M;B!W97)D96XN`$1A<R!/<&5N4U-,+4UO9'5L('=I<F0@9OQR(&1I92!(;W)D
M95]#<GEP=%]S;6EM93HZ($ML87-S92!B96[V=&EG="X`1&EE($)E;G5T>F5R
M96EN<W1E;&QU;F<@(B5S(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N+"!W96EL(&EH<F4@1&%T96X@9&EE(&UA>&EM86P@97)L875B=&4@1W+V
MWV4@_&)E<G-C:')E:71E;@!$87,@4')O9W)A;6T@9OQR(&1I92!!;GIE:6=E
M(&1I97-E<R!$871E:71Y<',@*"5S*2!W=7)D92!N:6-H="!G969U;F1E;BX`
M1&%S($%N9OQH<G5N9W-Z96EC:&5N(&UU<W,@86QS(&5I;GIE;&YE<R!:96EC
M:&5N(&%N9V5G96)E;B!W97)D96XN`$1E<B!1=65L;'1E>'0@9&5S(/9F9F5N
M=&QI8VAE;B!01U`M4V-H;/QS<V5L<R!K86YN("5S(&5I;F=E<V5H96X@=V5R
M9&5N+@!$:64@875S9V5WY&AL=&4@1&%T96D@97AI<W1I97)T(&YI8VAT(&EN
M(&1E;2!-4RU43D5&+4%N:&%N9RX`1&EE(&%U<V=E=^1H;'1E($1A=&5I(&5X
M:7-T:65R="!N:6-H="!I;B!D96T@6DE0+4%N:&%N9RX`3G5R(&QI;FMS('5N
M9"!R96-H=',`3G5R(')E8VAT<P!$97(@06)S96YD97(@9&EE<V5R($YA8VAR
M:6-H="!M]F-H=&4@9V5R;F4@96EN92!%;7!F86YG<V)E<W3D=&EG=6YG(&5R
M:&%L=&5N+"!W96YN(%-I92!D:65S92!.86-H<FEC:'0@9V5L97-E;B!H86)E
M;BX@0FET=&4@:VQI8VME;B!3:64@)7,L('5M(&1I92!"97-TY'1I9W5N9R!Z
M=7+\8VL@>G4@<V-H:6-K96XN`$1A<R!4<F5N;GIE:6-H96X@;75S<R!A;',@
M96EN>F5L;F5S(%IE:6-H96X@86YG96=E8F5N('=E<F1E;BX`1&5R(%-E<G9E
M<B`B)7,B('=U<F1E(&5N=&9E<FYT+@!$97(@4V5R=F5R("(E<R(@=W5R9&4@
M9V5S<&5I8VAE<G0N`$1E<B!397)V97(@:V]N;G1E(&ME:6YE(%9O<G-C:&%U
M(&1I97-E<R!":6QD97,@>G4@97)Z975G96XN`$1I92!3:6=N871U<B!K;VYN
M=&4@;FEC:'0@97)S971Z="!W97)D96XN`$1I92!3:6=N871U<B!W=7)D92!E
M<F9O;&=R96EC:"!E<G-E='IT+@!$:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E
M('9O;B`E<R!W=7)D92!E;G1F97)N="X`1&EE(&%N9V5G96)E;F4@1&%T96D@
M97AI<W1I97)T(&YI8VAT+@!$:64@86YG96=E8F5N92!:96EL92`H)60I(&5X
M:7-T:65R="!N:6-H="X`1&EE(%9O<FQA9V4@(B5S(B!W=7)D92!H:6YZ=6=E
M9OQG="X`1&EE(%9O<FQA9V4@(B5S(B!W=7)D92!G96SV<V-H="X`1&EE(%9O
M<FQA9V4@(B5S(B!W=7)D92!A:W1U86QI<VEE<G0N`$1I92!!=69G86)E('=U
M<F1E($EH<F5R($%U9F=A8F5N;&ES=&4@:&EN>G5G96;\9W0N`$1I92!T96UP
M;W+D<F4@1&%T96D@(B5S(B!E>&ES=&EE<G0@;FEC:'0N`$1E<B!.86-H<FEC
M:'1E;G1E>'0`1&5R($YA8VAR:6-H=&5N=&5X="!K86YN("5S(&5I;F=E<V5H
M96X@=V5R9&5N+@!$97(@5&5X="!D97(@86)G97=I97-E;F5N($YA8VAR:6-H
M=`!$97(@5&5X="!D97(@>G5R_&-K9V5W:65S96YE;B!.86-H<FEC:'0@:V%N
M;B`E<R!E:6YG97-E:&5N('=E<F1E;BX`1&5R(%1E>'0@9&5R(&=E<V5N9&5T
M96X@3F%C:')I8VAT`$1E<B!497AT(&1E<B!V97)S8VAI8VMT96X@3F%C:')I
M8VAT(&MA;FX@)7,@96EN9V5S96AE;B!W97)D96XN`$1E<B!497AT+"!D96X@
M4VEE(&%N9V5G96)E;B!H86)E;BP@96YT<W!R:6-H="!N:6-H="!D96T@5&5X
M="!A=68@9&5M($)I;&1S8VAI<FTN`$YU<B!O8F5N('5N9"!U;G1E;@!.=7(@
M;V)E;@!$:64@:&]C:&=E;&%D96YE;B!$871E;B!S:6YD(&YA8V@@9&5M(&QE
M='IT96X@4V-H<FET="!V97)L;W)E;B!G96=A;F=E;BX`1&EE(&AO8VAG96QA
M9&5N92!$871E:2!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$
M:64@1G)E:2]'96)U8VAT+4EN9F]R;6%T:6]N(&1E<R!"96YU='IE<G,@=W5R
M9&4@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N`$1E<B!W96%T:&5R+F-O;2!"
M;&]C:R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!4:&5M96XM5F5R>F5I8VAN:7,@
M(B5S(B!N:6-H="!G969U;F1E;BX`17,@9VEB="!K96EN92!A;'1E<FYA=&EV
M96X@3F%C:')I8VAT96YT96EL92P@9&EE(&%N9V5Z96EG="!W97)D96X@:_9N
M;F5N+@!);B!D:65S96T@3W)D;F5R('-I;F0@:V5I;F4@3F%C:')I8VAT96X@
M=F]R:&%N9&5N`$5S('-I;F0@:V5I;F4@16EN<W1E;&QU;F=E;B!V97)F_&=B
M87(N`$5S(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@3F%C:')I8VAT96YT96EL
M92X`1&EE<V5S($9E;&0@96YT:.1L="!Z=2!V:65L92!:96EC:&5N+B!3:64@
M:&%B96X@)7,@6F5I8VAE;B!A;F=E9V5B96X[(%-I92!M_'-S96X@=V5N:6=E
M<B!A;',@)7,@86YG96)E;BX`17,@9VEB="!K96EN92!A;GIE:6=B87)E;B!.
M86-H<FEC:'1E;G1E:6QE+@!"96EM($AI;GIU9OQG96X@=F]N("(E<R(@>G5M
M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ("5S`$)E:6T@
M3/9S8VAE;B!D97(@1&%T96X@=F]N($)E;G5T>F5R("(E<R(@:7-T(&5I;B!0
M<F]B;&5M(&%U9F=E=')E=&5N.B``0F5I;2!E;F1G_&QT:6=E;B!,]G-C:&5N
M(&1E<B!.86-H<FEC:'1E;B!I;2!D:65S96T@3W)D;F5R(&ES="!E:6X@1F5H
M;&5R(&%U9F=E=')E=&5N+B!-96QD=6YG(&1E<R!%;6%I;"U397)V97)S.B`E
M<P!"96EM($SV<V-H96X@=F]N("(E<R(@875S(&1E;2!3>7-T96T@:7-T(&5I
M;B!0<F]B;&5M(&%U9F=E=')E=&5N.B``0F5I;2!!:W1U86QI<VEE<F5N('9O
M;B`B)7,B(&ES="!E:6X@4')O8FQE;2!A=69G971R971E;CH@)7,`0F5I;2!(
M;V-H;&%D96X@9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N
M+B`E<R!W=7)D92!N:6-H="!H;V-H9V5L861E;BX`0F5I;2!(;V-H;&%D96X@
M9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W87(@
M9W+VWV5R(&%L<R!D:64@;6%X:6UA;"!E<FQA=6)T92!'<O;?92`H)60@0GET
M97,I+@!"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&96AL97(@
M875F9V5T<F5T96XN("5S('=U<F1E(&YU<B!T96EL=V5I<V4@:&]C:&=E;&%D
M96XN`$)E:6T@2V]P:65R96X@=F]N($YA8VAR:6-H=&5N(&YA8V@@(B5S(B!N
M86-H("(E<R(@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($UE;&1U;F<@
M9&5S($5M86EL+5-E<G9E<G,`0F5I;2!,]G-C:&5N('9O;B!.86-H<FEC:'1E
M;B!I;2!/<F1N97(@(B5S(B!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@
M365L9'5N9R!D97,@16UA:6PM4V5R=F5R<P!"96EM($SV<V-H96X@=F]N($YA
M8VAR:6-H=&5N(&EM($]R9&YE<B`B)7,B(&ES="!E:6X@1F5H;&5R(&%U9F=E
M=')E=&5N+B!-96QD=6YG(&1E<R!%;6%I;"U397)V97)S`$)E:6T@3/9S8VAE
M;B!V;VX@3F%C:')I8VAT96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN
M($UE;&1U;F<@9&5S($5M86EL+5-E<G9E<G,Z("5S`$)E:6T@3/9S8VAE;B!D
M97,@5&5R;6EN<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;CH@)7,N`$)E
M:6T@06YZ96EG96X@9&EE<V5S($YA8VAR:6-H=&5N=&5I;',@:7-T(&5I;B!&
M96AL97(@875F9V5T<F5T96XN`$)E:6T@36%R:VEE<F5N('9O;B!.86-H<FEC
M:'1E;B!I;2!/<F1N97(@(B5S(B!I<W0@96EN($9E:&QE<B!A=69G971R971E
M;BX@365L9'5N9R!D97,@16UA:6PM4V5R=F5R<P!"96EM($EM<&]R=&EE<F5N
M('9O;B`E<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`0F5I;2!);7!O
M<G1I97)E;B!D97(@2V]N=&%K=&1A=&5N(&ES="!E:6X@1F5H;&5R(&%U9F=E
M=')E=&5N+@!"96EM($EM<&]R=&EE<F5N(&1E<R!497)M:6YS(&ES="!E:6X@
M1F5H;&5R(&%U9F=E=')E=&5N.B`E<RX`0F5I;2!);7!O<G1I97)E;B!D97(@
M:4-A;&5N9&%R($1A=&5N(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+@!"
M96EM($EM<&]R=&EE<F5N(&1E<B!!=69G86)E(&ES="!E:6X@1F5H;&5R(&%U
M9F=E=')E=&5N.B`E<RX`0F5I;2!);7!O<G1I97)E;B!D97(@1G)E:2]'96)U
M8VAT+4EN9F]R;6%T:6]N96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XZ
M("5S+@!$87,@2V]N9FEG=7)A=&EO;G,M1F]R;75L87(@96YT:&EE;'0@96EN
M96X@1F5H;&5R+B!6:65L;&5I8VAT(&AA8F5N(%-I92!E:6X@4&9L:6-H=&9E
M;&0@;&5E<B!G96QA<W-E;BX`0F5I;2!697)S8VAI96)E;B!D97(@3F%C:')I
M8VAT96X@=F]N("(E<R(@;F%C:"`B)7,B(&ES="!E:6X@1F5H;&5R(&%U9F=E
M=')E=&5N+B!-96QD=6YG(&1E<R!%;6%I;"U397)V97)S`$)E:6T@075S9OQH
M<F5N(&1E<B!A;F=E9V5B96YE;B!!9')E<W-B=6-H9G5N:W1I;VX@:7-T(&5I
M;B!&96AL97(@875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@
M<W#D=&5R(&YO8V@@96EN;6%L+@!"96EM(%-P96EC:&5R;B!D:65S97(@3F%C
M:')I8VAT(&%L<R!%;G1W=7)F(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N
M+@!"96EM(%9E<G-E;F1E;B!D97(@3F%C:')I8VAT(&ES="!E:6X@1F5H;&5R
M(&%U9F=E=')E=&5N.B`E<P!"96D@9&5R($%K='5A;&ES:65R=6YG(&1E<B!+
M;VYT86MT9&5T86EL<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET
M=&4@=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`$)E:2!D
M97(@06MT=6%L:7-I97)U;F<@9&5R(%9E<G1E:6QE<FQI<W1E(&ES="!E:6X@
M1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92!V97)S=6-H96X@4VEE(&5S('-P
MY'1E<B!N;V-H(&5I;FUA;"X`0F5I;2!!:W1U86QI<VEE<F5N(&1E<R!497)M
M:6YS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N.B`E<RX`26X@9&EE<V4@
M2%1-3"U.86-H<FEC:'0@=W5R9&5N($)I;&1E<B!E:6YG96)E='1E="X`26X@
M9&EE<V4@2%1-3"U.86-H<FEC:'0@=W5R9&5N($)I;&1E<B!E:6YG96)E='1E
M="X@0FQO8VMI97)T92!":6QD97(@97)S8VAE:6YE;B!S;SH@`$1I97-E<B!)
M34%0+5-E<G9E<B!U;G1E<G-T_'1Z="!K96EN92!G96UE:6YS86UE;B!/<F1N
M97(N`$1I97-E<B#V9F9E;G1L:6-H92!01U`M4V-H;/QS<V5L('=U<F1E(&%N
M(&1I92!.86-H<FEC:'0@86YG96CD;F=T+@!$:65S92!!:W1I;VX@=VER9"!N
M:6-H="!U;G1E<G-T_'1Z="X`1&EE<V4@06MT:6]N(&ES="!N;V-H(&YI8VAT
M(&EM<&QE;65N=&EE<G0N`$1I97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%)!
M4BU!<F-H:78@>G4@<V5I;BX`1&EE<R!S8VAE:6YT(&ME:6X@9_QL=&EG97,@
M6DE0+4%R8VAI=B!Z=2!S96EN+@!$:65S('-C:&5I;G0@:V5I;F4@9_QL=&EG
M92!+87)T96YN=6UM97(@>G4@<V5I;BX`1&EE<V5R(%1R96EB97(@97)L875B
M="!D87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!#
M;&EC:V%T96QL+4=A=&5W87D@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@;6ET
M($AI;&9E(&1E<B!(5%10+4%022X`1&EE<V5R(%1R96EB97(@97)L875B="!D
M87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!724XM
M1V%T97=A>2`H:'1T<#HO+W=I;G!L8RYC;VTI(&UI="!(:6QF92!D97(@2%14
M4"U!4$DN`$1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N
M('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D96X@<VUS,FUA:6PM1V%T97=A>2`H
M:'1T<#HO+W-M<S)M86EL+F-O;2D@;6ET($AI;&9E(&1E<B!(5%10+4%022X`
M1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@=F]N($YA
M8VAR:6-H=&5N('!E<B!33510(&1U<F-H(&1E;B!6;V1A9F]N92U)=&%L:65N
M+4=A=&5W87D@875S<V-H;&EEWVQI8V@@86X@5F]D869O;F4M3G5M;65R;BX@
M1&%F_'(@=VER9"!E:6X@16UA:6QK;VYT;R!B96D@5F]D869O;F4@271A;&EE
M;B`H:'1T<#HO+W=W=RXQ.3`N:70I(&)E;O9T:6=T+@!$:65S97,@1F5L9"!I
M<W0@;F]T=V5N9&EG+@!$:65S97,@1F5L9"!D87)F(&YU<B!G86YZ92!:86AL
M96X@96YT:&%L=&5N+@!$:65S97,@1F5L9"!D87)F(&YU<B!:86AL96X@=6YD
M(&5I;F5N(%!U;FMT(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@9&%R9B!N=7(@
M3VMT86QZ86AL96X@96YT:&%L=&5N+@!$:65S97,@1F5L9"!M=7-S(&5I;F4@
M:V]M;6$M(&]D97(@;&5E<GIE:6-H96YG971R96YN=&4@3&ES=&4@=F]N(&=A
M;GIE;B!:86AL96X@96YT:&%L=&5N`$1I97-E<R!&96QD(&UU<W,@96EN92!G
M_&QT:6=E(%IA:&P@96YT:&%L=&5N+@!$:65S97,@1F5L9"!M=7-S(&5I;F5N
M($9A<F)W97)T(&EM(&AE>&%D97II;6%L96X@4D="+49O<FUA="!E;G1H86QT
M96XL('HN($(N("<C,3(S-&%F)RX`1&EE<V5S($9O<FUU;&%R('=U<F1E(&)E
M<F5I=',@=F5R87)B96ET970N`$1I97,@:7-T("5S+@!$:64@:7-T(&5I;B!+
M;VQA8BU'<F]U<'=A<F4M3V)J96MT+B!5;2!D:65S97,@3V)J96MT(&%N>G5Z
M96EG96XL(&)E;O9T:6=E;B!3:64@96EN($5M86EL<')O9W)A;6TL(&1A<R!D
M87,@2V]L86(M1W)O=7!W87)E+49O<FUA="!U;G1E<G-T_'1Z="X@16EN92!,
M:7-T92!S;VQC:&5R(%!R;V=R86UM92!F:6YD96X@4VEE('5N=&5R("5S`$1I
M97-E<B!6;W)G86YG(&MA;FX@96EN92!796EL92!D875E<FXN(%-I;F0@4VEE
M('-I8VAE<BP@9&%S<R!3:64@9F]R=&9A:')E;B!W;VQL96X_`$1I97-E($YA
M8VAR:6-H="!E;G1HY&QT(&5I;F4@36%C:6YT;W-H+41A=&5I+@!$:65S92!.
M86-H<FEC:'0@96YT:.1L="!E:6YE;B!!;FAA;F<L(&1E<B!M:70@4R]-24U%
M(&1I9VET86P@=6YT97)S8VAR:65B96X@=W5R9&4N`$1I97-E($YA8VAR:6-H
M="!E;G1HY&QT(&5I;F5N($%N:&%N9RP@9&5R(&UI="!3+TU)344@=F5R<V-H
M;/QS<V5L="!W=7)D92X`1&EE<V4@3F%C:')I8VAT(&5N=&CD;'0@4W1A='5S
M:6YF;W)M871I;VYE;B!Z=7(@075S;&EE9F5R=6YG(&5I;F5R($5M86EL(&%B
M97(@:6X@96EN96T@=6YB96MA;FYT96X@1F]R;6%T+@!$:65S('-C:&5I;G0@
M:V5I;F4@9_QL=&EG92!01U`M=F5R<V-H;/QS<V5L=&4@3F%C:')I8VAT('IU
M('-E:6XN($9E:&QE<CH`1&EE<V4@3F%C:')I8VAT(&ES="!A;G-C:&5I;F5N
M9"!N:6-H="!I;2!K;W)R96MT96X@4$=0+49O<FUA="`H;F%C:"!21D,@,C`Q
M-2DN`$1I97-E($YA8VAR:6-H="!S8VAE:6YT(&YI8VAT(&EM(&MO<G)E:W1E
M;B!3+TU)344M1F]R;6%T('IU('-E:6XN`$1I97-E($YA8VAR:6-H="!W=7)D
M92!M:70@4$=0(&1I9VET86P@=6YT97)S8VAR:65B96XN`$1I97-E($YA8VAR
M:6-H="!W=7)D92!M:70@4R]-24U%(&1I9VET86P@=6YT97)S8VAR:65B96XN
M`$1I97-E($YA8VAR:6-H="!W=7)D92!M:70@4R]-24U%('9E<G-C:&S\<W-E
M;'0N`$1I97-E($YA8VAR:6-H="!W=7)D92!M:70@4$=0('9E<G-C:&S\<W-E
M;'0N`&1I97-E($YA8VAR:6-H="!N86-H`$1I97-E($YA8VAR:6-H="!W=7)D
M92!I;B!E:6YE;2!:96EC:&5N<V%T>B`H)7,I(&5R<W1E;&QT+"!D97(@;FEC
M:'0@26AR96T@96EG96YE;B!E;G1S<')I8VAT+@!$:65S92!:86AL(&UU<W,@
M,2!O9&5R(&=R]M]E<B!S96EN+@!$:65S97(@4V5R=F5R(&MA;FX@6DE0+2!U
M;F0@1UI)4"U$871E:6X@;FEC:'0@96YT<&%C:V5N+@!$:65S97(@4V5R=F5R
M('5N=&5R<W3\='IT(&ME:6YE(&=E;65I;G-A;65N($]R9&YE<BX`1&EE<V5S
M(%-Y<W1E;2!I<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0N`$1I97-E<B!797)T
M(&UU<W,@96EN92!:86AL('-E:6XN`$1I97-E<R!&96YS=&5R(&UU<W,@=F]M
M($9E;G-T97(@9OQR(&YE=64@3F%C:')I8VAT96X@9V7V9F9N970@=V5R9&5N
M+@!$:65S97,@1F5N<W1E<B!M=7-S('9O;B!E:6YE;2!%:6YS=&5L;'5N9V5N
M+49E;G-T97(@9V7V9F9N970@=V5R9&5N`%1H96UE;FQI<W1E`%1H96UE;F%N
M<VEC:'0`1&]N;F5R`%1I8VME=',`6F5I=`!:96ET97)F87-S=6YG`%IE:71F
M;W)M870`6F5I=&%U<W=A:&P`5&EM;W(M3&5S=&4`5&ET96P`5&ET96P@*%1O
M;VQT:7`I.@!!;@!%;7!FY&YG97)A9')E<W-E`$AA;'1E;B!3:64@8F5I;2!+
M;&EC:V5N(%-T<F<@*%!#*2!B>G<N($-O;6UA;F0@*$UA8RD@9V5D<OQC:W0L
M('5M(&UE:')E<F4@16EN='+D9V4@875S>G5WY&AL96XN`$AA;'1E;B!3:64@
M8F5I;2!+;&EC:V5N(%-T<F<@8GIW+B`H4$,I($-O;6UA;F0@*$UA8RD@9V5D
M<OQC:W0L('5M(&UE:')E<F4@16EN='+D9V4@875S>G5WY&AL96XN`%5M(&5I
M;F4@5$Q3+59E<F)I;F1U;F<@8F5N=71Z96X@>G4@:_9N;F5N+"!M_'-S96X@
M4VEE(%!(4"!697)S:6]N(#4N,2XP(&]D97(@:/9H97(@96EN<V5T>F5N+@!(
M975T90!:=2!(5$U,+5%U96QL8V]D92!U;7-C:&%L=&5N`%1O9V\`5&]K96QA
M=0!-;W)G96X`5&]N9V$`6G4@=FEE;&4@=6YG_&QT:6=E($%N;65L9&5V97)S
M=6-H92!I;B!D96X@;&5T>G1E;B!-:6YU=&5N+@!/8F5N`,1UWV5R<W1E<B!2
M86AM96X@*%]T;W`I`$=E<V%M=&=R]M]E(&1E<B!!;FCD;F=E.@#<8F5R<V5T
M>G5N9V5N`")087!I97)K;W)B(BU/<F1N97(`(E!A<&EE<FMO<F(B+4]R9&YE
M<CH`5')I;FED860@=6YD(%1O8F%G;P!786AR(&]D97(@9F%L<V-H`$1I`%1U
M;F5S:65N`%3\<FME:0!4_')K:7-C:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS+2!U;F0@0V%I8V]S:6YS96QN`%1U=F%L=0!):')E($%U<W=A
M:&PZ(`!55BU);F1E>#H@`$AO;65P86=E`%523"!):')E<R!3:W)I<'1S(&;\
M<B!D96X@5F5R<V%N9'-T871U<V)E<FEC:'0`061R97-S93H`56=A;F1A`%5K
M<F%I;F4`075F(&1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('IU
M9V5G<FEF9F5N('=E<F1E;BX`1&EE('IU<^1T>FQI8VAE;B!"96YU='IE<FEN
M9F]R;6%T:6]N96X@:V]N;G1E;B!B96D@9&5R(%)E9VES=')I97)U;F<@;FEC
M:'0@:&EN>G5F_&=T('=E<F1E;BX`1&EE(%IU9W)I9F9S<F5C:'1E(&;\<B!D
M:64@5D93+41A=&5I("(E<R(@:V]N;G1E;B!N:6-H="!G9>1N9&5R="!W97)D
M96XN`$1I92!:=6=R:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`E<R\E
M<R!K;VYN=&5N(&YI8VAT(&=EY&YD97)T('=E<F1E;BX`17,@:V%N;B!N:6-H
M="!I;B!697)Z96EC:&YI<R`E<R!G97=E8VAS96QT('=E<F1E;BX`1&EE($=R
M]M]E('9O;B`B)7,B(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN`$1I
M92!'<O;?92!V;VX@(B5S+R5S(B!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R
M9&5N+@!697)B:6YD=6YG('IU;2!344P@4V5R=F5R(&MA;FX@;FEC:'0@:&5R
M9V5S=&5L;'0@=V5R9&5N+@!34TPM5F5R8FEN9'5N9R!K;VYN=&4@;FEC:'0@
M:&5R9V5S=&5L;'0@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H
M="!K;W!I97)T('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO
M;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN
M:7,@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`1&EE(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@!$87,@5D93+59E<GIE
M:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`3&5E
M<F4@5D93+41A=&5I(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$1I
M92!$871E;B!K;VYN=&5N(&YI8VAT(&1E:V]M<')I;6EE<G0@=V5R9&5N+@`B
M)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC
M:&YI<R!I<W0@;FEC:'0@;&5E<BX`(B5S(B!K86YN(&YI8VAT(&=E;/9S8VAT
M('=E<F1E;CH@)7,N`"5S(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL
M(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC:'0@;&5E<@!$87,@5D93+59E<GIE
M:6-H;FES(&MO;FYT92!N:6-H="!R96MU<G-I=B!G96SV<V-H="!W97)D96XN
M`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E
M<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@9V5L]G-C
M:'0@=V5R9&5N.B`E<RX`1&EE(%9&4RU$871E:2`B)7,B(&MO;FYT92!N:6-H
M="!G96SV<V-H="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT
M(&=E;/9S8VAT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1A<R!61E,@:V]N;G1E(&YI
M8VAT(')E:W5R<VEV(&=E;/9S8VAT('=E<F1E;CH@)7,N`$1A<R!A:W1U96QL
M92!697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!$
M:64@6F5R=&EF:6MA=&1E=&%I;',@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N
M('=E<F1E;@!$97(@)7,M5')E:6)E<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W
M97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT('9E<G-C:&]B96X@
M=V5R9&5N+@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E]F9F
M;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@>G5M($)E
M<V-H<F5I8F5N(&=E]F9F;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN
M=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!$87,@07)C:&EV(&MO;FYT92!N
M:6-H="!G9?9F9FYE="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI
M8VAT(&=E;&5S96X@=V5R9&5N("AF:6QE<VEZ92@I(&9E:&QG97-C:&QA9V5N
M*2X`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96X@
M*&=E=$9I;&53:7IE*"D@9F5H;&=E<V-H;&%G96XI+@!$:64@1&%T96D@:V]N
M;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N.B``1&%S('9F<W)O;W0M5F5R>F5I
M8VAN:7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N+@`E<R!K;VYN=&4@
M;FEC:'0@;F%C:"`E<R!U;6)E;F%N;G0@=V5R9&5N.B!$87,@6FEE;'9E<GIE
M:6-H;FES(&5X:7-T:65R="!B97)E:71S`$1A<R!61E,M5F5R>F5I8VAN:7,@
M:V]N;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XN`$1A<R!61E,M5F5R>F5I
M8VAN:7,@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XZ("5S+@!$:64@
M5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XN
M`$1I92!61E,M1&%T96D@)7,O)7,@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W
M97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W
M97)D96XN`%-P96EC:&5R<&QA='HM2V]N=&EN9V5N="!K;VYN=&4@;FEC:'0@
M9V5L97-E;B!W97)D96X`(FUK:7-O9G,B(&MO;FYT92!N:6-H="!A=7-G96;\
M:')T('=E<F1E;BX`1&EE<V5S(%=O<F0M1&]K=6UE;G0@;.1S<W0@<VEC:"!N
M:6-H="!A;GIE:6=E;@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT
M(&=E<W!E:6-H97)T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V5S8VAR:65B96X@=V5R9&5N("AC;W!Y*"D@9F5H;&=E<V-H;&%G96XI
M+@!$:64@5D93+41A=&5N(&MO;FYT96X@;FEC:'0@9V5S8VAR:65B96X@=V5R
M9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G97-C:')I96)E;B!W
M97)D96XL(&1A<R!3<&5I8VAE<G!L871Z+4MO;G1I;F=E;G0@=_QR9&4@_&)E
M<G-C:')I='1E;BX`3FEC:'0@8F5A;G1W;W)T970`3FEC:'0@8F5A;G1W;W)T
M971E($YA8VAR:6-H=&5N`%=I961E<FAE<G-T96QL96X`56YT97)S=')I8VAE
M;@!5;F)E:V%N;G1E($5M<&;D;F=E<@#$;F1E<G5N9V5N('+\8VMGY&YG:6<@
M;6%C:&5N`$UA8VAT(&1I92!L971Z=&4@06MT:6]N('+\8VMGY&YG:6<`56YG
M_&QT:6=E(%+\8VMM96QD=6YG('9O;2!397)V97(@8F5I;2!(97)S=&5L;&5N
M(&1E<B!697)B:6YD=6YG.B``56YE<G=A<G1E=&4@06YT=V]R="!D97,@4V5R
M=F5R<R!A=68@05542$5.5$E#051%($MO;6UA;F1O+@!5;F5R=V%R=&5T92!!
M;G1W;W)T(&1E<R!397)V97)S(&%U9B!$:6=E<W0M340U($%N9G)A9V4N`%5N
M97)W87)T971E($%N='=O<G0@9&5S(%-E<G9E<G,@875F($Q/1TE.($MO;6UA
M;F1O+@!5;F5R=V%R=&5T92!!;G1W;W)T(&1E<R!397)V97)S(&%U9CH@`$YI
M8VAT('IU9V5O<F1N970`3FEC:'0@=F5R87)B96ET971E($MO;7!O;F5N=&4@
M9&5S(%1Y<',Z("5S`%5N:6-O9&4@*%541BTX*0!697)E:6YI9W1E($%R86)I
M<V-H92!%;6ER871E`%9E<F5I;FEG=&5S($OV;FEG<F5I8V@`5F5R96EN:6=T
M92!3=&%A=&5N`$ML96EN97)E($%M97)I:V%N:7-C:&4@W&)E<G-E96EN<V5L
M;@!%:6YH96ET96X`56YB96MA;FYT`%5N8F5K86YN=&5S($1A='5M`%5N8F5K
M86YN=&4@24U!4"U!;G1W;W)T(&1E<R!397)V97)S+B!397)V97)A;G1W;W)T
M.B`E<P!5;F)E:V%N;G1E($)E<W!R96-H=6YG`%5N8F5K86YN=&5R($5M<&;D
M;F=E<@!5;F)E:V%N;G1E(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N
M8F5K86YN=&4@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`17,@=W5R
M9&4@96EN('5N8F5K86YN=&5R($]R="!A;F=E9V5B96XN`%5N8F5K86YN=&5R
M($)E;G5T>F5R;F%M92!O9&5R(%!A<W-W;W)T+@!,:6YK('9O;2!A:W1U96QL
M96X@16QE;65N="!E;G1F97)N96X`4&%S<W=O<G0@(G9E<F=E<W-E;B(`56YB
M96YA;FYT`$%U<R!3:6-H97)H96ET<V=R_&YD96X@9/QR9F5N('5N875T;W)I
M<VEE<G1E(%-K<FEP=&4@;FEC:'0@875S8VAN96ED96XL(&MO<&EE<F5N('5N
M9"!E:6YF_&=E;BX@2VQI8VME;B!3:64@875F($]++"!U;2!E:6YE;B!(:6YW
M96ES(&%U9B!M;WII;&QA+F]R9R!A;F=E>F5I9W0@>G4@8F5K;VUM96XL(&1E
M<B!B97-C:')E:6)T+"!W:64@4VEE(&5I;F5M(%-K<FEP="!D96X@6G5G<FEF
M9B!A=68@9&EE(%IW:7-C:&5N86)L86=E(&5R;&%U8F5N(&OV;FYE;BX`3FEC
M:'0@9V5L97-E;@!&87)B92!Z=7+\8VMS971Z96X`3W)D;F5R(&%U<V)L96YD
M96X`17)W96ET97)U;F<@;FEC:'0@=6YT97)S=/QT>G0`06MT=6%L:7-I97)U
M;F<`)7,@86MT=6%L:7-I97)E;@!3=&%T=7,@9&5R(%1E:6QN96AM97(@86MT
M=6%L:7-I97)E;@!"96YU='IE<B!A:W1U86QI<VEE<F5N`"(E<R(@=W5R9&4@
M86MT=6%L:7-I97)T+@!!:W1U86QI<VEE<G5N9W-S:W)I<'0@9V5L]G-C:'0N
M`$AO8VAL861E;@!$:64@2V]N9FEG=7)A=&EO;G-D871E:65N(&%L;&5R($%N
M=V5N9'5N9V5N('=U<F1E;B!A=68@9&5N(%-E<G9E<B!H;V-H9V5L861E;BX`
M1W(N(&QA=&5I;FES8VAE($)U8VAS=&%B96X`1W(N('+V;6ES8VAE(%IA:&QE
M;@!5<G5G=6%Y`$%K='5E;&QE(&)E;G5T>F5N.B`E<P!3=&%N9&%R9'=E<G0@
M=F5R=V5N9&5N`$E-05`@3W)D;F5R86)O;FYE;65N="!B96YU='IE;C\`4U-,
M(&)E;G5T>F5N`%9I<G1U96QL96X@4&%P:65R:V]R8B!B96YU='IE;C\`0FET
M=&4@875S9OQL;&5N+"!W96YN(%-I92!E:6YE;B!A;F1E<F5N($)E;G5T>F5R
M;F%M96XO4&%S<W=O<G0@9OQR(&1E;B!)35-0+5-E<G9E<B!H86)E;BX`0F5N
M=71Z97(`1&5M($)E;G5T>F5R("(E<R(@=W5R9&5N(&5R9F]L9W)E:6-H(&1I
M92!A;F=E9V5B96YE;B!296-H=&4@9OQR(&1E;B!/<F1N97(@(B5S(B!Z=6=E
M=VEE<V5N+@!"96YU='IE<B`E<R!I<W0@9OQR("5S(&YI8VAT(&%U=&]R:7-I
M97)T+@!"96YU='IE<G9E<G=A;'1U;F<`0F5N=71Z97)E:6YS=&5L;'5N9V5N
M`$)E;G5T>F5R<F5G:7-T<FEE<G5N9P!$:64@0F5N=71Z97)R96=I<W1R:65R
M=6YG('=U<F1E(&%U9B!D:65S96T@4WES=&5M(&1E86MT:79I97)T+@!"96YU
M='IE<FMO;G1O(&YI8VAT(&=E9G5N9&5N`$)E;G5T>F5R;F%M90!$97(@0F5N
M=71Z97)N86UE("(E<R(@97AI<W1I97)T(&)E<F5I=',N`$)E;G5T>F5R;F%M
M93H`0F5N=71Z97)N86UE.B``0F5N=71Z97(@9&5S(%-Y<W1E;7,Z`%5S8F5K
M:7-T86X`1&%S(%9&4RU697)Z96EC:&YI<R!E>&ES=&EE<G0@;FEC:'0N`$%B
M=V5S96YH96ET`%!A<W-E;F1E(&=E9G5N9&5N92!/<G1E.B``1_QL=&EG:V5I
M=`!797)T(&EN($UI;G5T96X@=F]N(&IE='IT(&%N+@!$97(@5V5R="!I<W0@
M_&)E<B!D97(@;6%X:6UA;&5N($SD;F=E('9O;B`E<RX`5V5R=&4`5V5R=&4L
M(&%U<R!D96YE;B!A=7-G97?D:&QT('=E<F1E;B!K86YN`%9A;G5A='4`1')E
M:&5N9`!696YE>G5E;&$`W&)E<G!R_&9U;F<@9F5H;&=E<V-H;&%G96X@+2!D
M:65S92!.86-H<FEC:'0@:_9N;G1E(&UA;FEP=6QI97)T('=O<F1E;B!S96EN
M+@!697)S:6]N`%9E<G-I;VYS:V]N=')O;&QE`$%U<W)I8VAT=6YG`%9E<G1I
M:V%L97(@26YN96YA8G-T86YD`%9E<G1I:V%L.@!396AR($AO8V@`5FEE=&YA
M;0!6:65T;F%M97-I<V-H("A625-#24DI`$%N>F5I9V5N`"5S(&%N>F5I9V5N
M`-9F9F5N=&QI8VAE;B`E<R!38VAL_'-S96P@86YZ96EG96X`2%1-3"U);FAA
M;'0@:6X@96EN96T@;F5U96X@1F5N<W1E<B!A;GIE:6=E;@!.86-H<FEC:'1E
M;B!A;E]Z96EG96X`4&5R<_9N;&EC:&5N('!R:79A=&5N(%-C:&S\<W-E;"!A
M;GIE:6=E;@!097)S]FYL:6-H96X@]F9F96YT;&EC:&5N(%-C:&S\<W-E;"!A
M;GIE:6=E;@!4:&5M82!!;GIE:6=E;@!6;W)S8VAA=2!A;GIE:6=E;@!%:6YE
M(&5X=&5R;F4@5V5B<V5I=&4@86YZ96EG96X`06YZ96EG96X@86QS("5S`$%N
M:&%N9R!I;B!E:6YE;2!N975E;B!&96YS=&5R(&%N>F5I9V5N`$EN:&%L="!I
M;B!E:6YE;2!N975E;B!&96YS=&5R(&%N>F5I9V5N`%1E<FUI;B!A;GIE:6=E
M;@!.86-H<FEC:'1E;B!I;B`E<R!A;GIE:6=E;@!!;G-I8VAT(&]D97(@3W)D
M;F5R+"!D97(@;F%C:"!D97(@06YM96QD=6YG(&%N9V5Z96EG="!W97)D96X@
M<V]L;#H`075F9V%B92!A;GIE:6=E;@!":6QD97(@86YZ96EG96X`0G)I=&ES
M8VAE($IU;F=F97)N:6YS96QN`$%M97)I:V%N:7-C:&4@2G5N9V9E<FYI;G-E
M;&X`5FER='5E;&QE<B!/<F1N97(@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!E
M<G-T96QL="X`5FER='5E;&QE($]R9&YE<@!6:7)T=65L;&4@3W)D;F5R(&W\
M<W-E;B!E:6YE;B!.86UE;B!H86)E;BX`5FER='5E;&QE<B!0;W-T96EN9V%N
M9P!6:7)T=65L;&5R(%!O<W1E:6YG86YG<V]R9&YE<@!6:7)T=65L;&5R(%!A
M<&EE<FMO<F(`5FER='5E;&QE<B!087!I97)K;W)B`$YA;64@9&5S('9I<G1U
M96QL96X@3W)D;F5R<P!3:6-H=`!3:6-H=#H@`%9O9&%F;VYE($ET86QI96X@
M<&5R(%--5%``5T%23E5.1P!705).54Y'(2$A($S64T-(14X@4TE%($1!4R!3
M2U))4%0@34%.545,3"!!55,@)7,N`%=)3B#\8F5R($A45%``5V%L;&ES('5N
M9"!&=71U;F$`5V%R;G5N9P!-:0!7971T97)V;W)H97)S86=E`%=E='1E<F1A
M=&5N('9O;@!796%T:&5R+F-O;0!796(`5V5B<VET90!7]F-H96YT;&EC:`!7
M:6QL:V]M;65N`%=I;&QK;VUM96X@8F5I("5S`%=I;&QK;VUM96XL("5S`%=E
M<W1E=7)O<.1I<V-H("A)4T\M.#@U.2TQ*0!797-T975R;W#D:7-C:"`H25-/
M+3@X-3DM,34I`%=E<W1S86AA<F$`5V5L8VAE($%N=V5N9'5N9R!S;VQL("5S
M(&YA8V@@9&5M($%N;65L9&5N(&%N9V5Z96EG96X_`%=E;&-H97,@5')E;FYZ
M96EC:&5N('=I<F0@=F5R=V5N9&5T/P!796QC:&4@06YF_&AR=6YG<WIE:6-H
M96X@=V5R9&5N('9E<G=E;F1E=#\`5V%S('-O;&P@;6ET($YA8VAR:6-H=&5N
M(&=E<V-H96AE;BP@;F%C:&1E;2!S:64@86QS(%-P86T@;V1E<B!K96EN(%-P
M86T@9V5M96QD970@=V]R9&5N('-I;F0_`$)E:6T@3/9S8VAE;B!V;VX@3F%C
M:')I8VAT96X@9&EE<V4@:6X@9&5N(%!A<&EE<FMO<F(@=F5R<V-H:65B96XL
M(&%N<W1A='0@<VEE(&%L<R!G96SV<V-H="!Z=2!M87)K:65R96X_`%=E;FX@
M4VEE(&5I;F5N($]R9&YE<B#V9F9N96XL('=E;&-H92!396ET92!S;VQL('IU
M97)S="!A;F=E>F5I9W0@=V5R9&5N/P!3;VQL96X@06YHY&YG92!M:71G97-P
M96EC:&5R="!W97)D96XL('=E;FX@9V5S96YD971E($YA8VAR:6-H=&5N(&=E
M<W!E:6-H97)T('=E<F1E;C\`5V5L8VAE($1O;6%I;B!S;VQL(&)E:6T@5F5R
M<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N(&]D97(@4W5C:&5N('9O;B!!9')E
M<W-E;B!A;B!U;G9O;&QS=.1N9&EG92!!9')E<W-E;B`H;VAN92`B0"(M6F5I
M8VAE;BD@9V5HY&YG="!W97)D96X_`%=H97)E:7,M075S=')A;&EA+4MA<G1E
M`%=E;&-H92!0:&%S96X`5V5L8VAE(%!L=6=I;G,@9OQR(&1E;B!765-)5UE'
M+45D:71O<B!S;VQL96X@86MT:79I97)T('=E<F1E;C\`4&]S:71I=FQI<W1E
M`$)R96ET90!"<F5I=&4@:6X@0U-3+45I;FAE:71E;@!"<F5I=&4@9&5S("5S
M+4UE;OQS(&QI;FMS("AW:7)K<V%M(&YA8V@@9&5R(&[D8VAS=&5N($%N;65L
M9'5N9RDZ`%1A8F5L;&5N8G)E:71E`$5I;FAE:70`0G)E:71E.@!7:6MI`%=I
M;F0`1G+\:"!7:6YD`%=I;F1G97-C:'=I;F1I9W1K96ET(&EN($MN;W1E;@!7
M:6YD.@!7:6YD.B``5V5I<VAE:70`5W5N<V-H>F5T=&5L`$%R8F5I=`!!9')E
M<W-E(&=E<V-HY&9T;&EC:`!496QE9F]N(&=E<V-HY&9T;&EC:`!&86QS8VAE
M($%N>F%H;"!A;B!&96QD97)N(&EN(%IE:6QE("5D+B`E9"!E<G=A<G1E="P@
M)60@9V5F=6YD96XN`$9A;'-C:&4@06YZ86AL(&%N($9E;&1E<FXN("5D(&5R
M=V%R=&5T+"`E9"!G969U;F1E;BX`56YG_&QT:6=E<B!/9F9S970@)60@8F5I
M;2!,97-E;B!D97(@5D93+41A=&5I+@!1=65R=F5R=V5I<V4`6#4P.78S($=E
M;F5R96QL92!%:6YS8VARY&YK=6YG`%@U,#EV,R!%<G=E:71E<G1E<B!38VAL
M_'-S96QZ=V5C:P!8-3`Y=C,@06QT97)N871I=F5R($YA;64@9&5S(%IE<G1I
M9FEK871I;FAA8F5R<P!8-3`Y=C,@261E;G1I=.1T(&1E<R!:97)T:69I:V%T
M<V-H;/QS<V5L<P!8-3`Y=C,@17)W96ET97)U;F=E;@!*2@!*2DI*`%EA:&]O
M(2!+87)T90!*Y&AR;&EC:`!*96UE;@!*80!*82P@:6-H('-T:6UM92!Z=0!3
M:64@<VEN9"!I;2!"96=R:69F($YA8VAR:6-H=&5N('9O;B!F;VQG96YD96X@
M2V]N=&5N(&5I;GIU<V%M;65L;CH`4VEE('9E<G-U8VAE;B!A;&QE($YA8VAR
M:6-H=&5N(&EN(&9O;&=E;F1E;B!/<F1N97(@>G4@;/9S8VAE;BX`4VEE('9E
M<G-U8VAE;B!F;VQG96YD92!/<F1N97(@>G4@;/9S8VAE;BX`4VEE(&MO<&EE
M<F5N+W9E<G-C:&EE8F5N('IU(&5I;F5M(&YE=65N($]R9&YE<BX`4VEE(&5R
M>F5U9V5N(&5I;F5N(%5N=&5R;W)D;F5R('9O;B``4VEE(&5R>F5U9V5N(&5I
M;F5N($AA=7!T;W)D;F5R+@!3:64@8F5F:6YD96X@<VEC:"!I;2!497AT;6]D
M=7,N($)E;G5T>F5N(%-I92!D96X@6SP^72!+;F]P9BP@=6T@:6X@9&5N(%=9
M4TE724<M36]D=7,@>G4@=V5C:'-E;&XN`%-I92!D_')F96X@:V5I;F4@3W)D
M;F5R(&5R<W1E;&QE;BX`4VEE(&3\<F9E;B!N:6-H="!M96AR(&%L<R`E9"!"
M;/9C:V4@97)S=&5L;&5N+@!3:64@9/QR9F5N(&YI8VAT(&UE:'(@86QS("5D
M($]R9&YE<B!E<G-T96QL96XN`%-I92!S:6YD(&YI8VAT(&%N9V5M96QD970N
M`%-I92!B96YE;FYE;B!F;VQG96YD96X@3W)D;F5R('5M.@!3:64@:_9N;F5N
M(&9O;&=E;F1E(%!L871Z:&%L=&5R(&EM(%9O<FQA9V5N=&5X="!V97)W96YD
M96XZ("5C(&;\<B!D96X@86MT=65L;&5N($YA8VAR:6-H=&5N=&5X=#L@)7,@
M9OQR(&1I92!3:6=N871U<BX`4VEE(&3\<F9E;B!D87,@6F5I8VAE;B`G7"<@
M;FEC:'0@:6X@26AR96T@3F%M96X@=F5R=V5N9&5N+@!3:64@:_9N;F5N("(E
M<R(@;FEC:'0@875S8FQE;F1E;BX`4VEE(&AA8F5N(&1E;B!"96YU='IU;F=S
M8F5D:6YG=6YG96X@;FEC:'0@>G5G97-T:6UM="!U;F0@9/QR9F5N('-I8V@@
M9&5S=V5G96X@;FEC:'0@86YM96QD96XN`%-I92!H86)E;B!K96EN92!G_&QT
M:6=E($5M86EL861R97-S92!A;F=E9V5B96XN`%-I92!H86)E;B!K96EN92!&
M96QD97(@875S(&1E;B!I;7!O<G1I97)T96X@1&%T96X@9&5N(&5N='-P<F5C
M:&5N9&5N($9E;&1E<FX@:6X@)7,@>G5G96]R9&YE="X`4VEE(&AA8F5N('-E
M;&)S="!N:6-H="!G96[\9V5N9"!296-H=&4L('5M(&1I92!296-H=&4@9OQR
M(&1I97-E;B!/<F1N97(@>G4@Y&YD97)N+@!3:64@:&%B96X@9&EE<V4@3F%C
M:')I8VAT(&%M("4E<R!A;B!F;VQG96YD92!%;7!FY&YG97(@=V5I=&5R9V5L
M96ET970Z("5S+@!3:64@:&%B96X@)7,@;F5U92!.86-H<FEC:'1E;BX`4VEE
M(&AA8F5N(#$@;F5U92!.86-H<FEC:'0N`%-I92!H86)E;B!D:65S92!396ET
M92!B97)E:71S(&%B9V5S8VAI8VMT+@!3:64@=W5R9&5N(&%B9V5M96QD970N
M`%-I92!H86)E;B!N975E($YA8VAR:6-H=&5N(&EN(&1E;2!F;VQG96YD96X@
M3W)D;F5R.@!3:64@:&%B96X@;F5U92!.86-H<FEC:'1E;B!I;B!D96X@9F]L
M9V5N9&5N($]R9&YE<FXZ`%-I92!M_'-S96X@96EN92!G_&QT:6=E($UO8FEL
M=&5L969O;FYU;6UE<B!A;F=E8F5N+"!N=7(@875S(%IA:&QE;B!U;F0@9V=F
M+B!E:6YE;2`B*R(@9OQR(&EN=&5R;F%T:6]N86QE(%9O<G=A:&QE;B!B97-T
M96AE;F0N`%-I92!M_'-S96X@96EN96X@9_QL=&EG96X@5V5R="!A;F=E9V5B
M96XN`%-I92!M_'-S96X@96EN($1A=&%4<F5E+4)A8VME;F0@:V]N9FEG=7)I
M97)E;BP@=6T@4F5G:7-T<FEE<G5N9V5N('9E<G=E;F1E;B!Z=2!K]FYN96XN
M`%-I92!M_'-S96X@96EN(%9&4RU"86-K96YD(&MO;F9I9W5R:65R96XN`%-I
M92!M_'-S96X@9&%S(%!R;V)L96T@8F5S8VAR96EB96XL('5M(&1E;B!"97)I
M8VAT(&%B>G5S8VAI8VME;BX`4VEE(&W\<W-E;B!M:6YD97-T96YS(&5I;F5N
M($5M<&;D;F=E<B!A;F=E8F5N+@!3:64@;?QS<V5N(&1I92!54DP@86YG96)E
M;BP@875F(&1I92!D:65S97(@3&EN:R!V97)W96ES96X@<V]L;`!3:64@;?QS
M<V5N(&1A<R!087-S=V]R="!F_'(@26AR96X@<')I=F%T96X@4$=0+5-C:&S\
M<W-E;"!A;F=E8F5N+"!U;2!D:65S92!.86-H<FEC:'0@;&5S96X@>G4@:_9N
M;F5N`%-I92!M_'-S96X@9&%S(%!A<W-W;W)T(&;\<B!):')E;B!P<FEV871E
M;B!3+TU)344M4V-H;/QS<V5L(&%N9V5B96XL('5M(&1I97-E($YA8VAR:6-H
M="!L97-E;B!Z=2!K]FYN96X`4VEE(&W\<W-E;B!E<G-T(&5I;F5N(%II96QO
M<F1N97(@86YG96)E;BX`4VEE(&W\<W-E;B!E<G-T(&1A<R!Z=2!L]G-C:&5N
M9&4@2V]N=&\@875S=^1H;&5N+@!3:64@;?QS<V5N(&5R<W0@96EN92!!9')E
M<W-E(&%U<W?D:&QE;BX`4VEE(&W\<W-E;B!E<G-T(&1E;B!Z=2!E;G1F97)N
M96YD96X@4V5R=F5R(&%U<W?D:&QE;BX`4VEE(&W\<W-E;B!E<G-T(&UI;F1E
M<W1E;G,@96EN92!.86-H<FEC:'0@875S=^1H;&5N+@!3:64@;?QS<V5N(&5I
M;F5N($5M<&;D;F=E<B!A;F=E8F5N+@!3:64@;?QS<V5N(&5I;F5N($)E;G5T
M>F5R;F%M96X@86YG96)E;BP@9&5S<V5N($1A=&5N(&=E;/9S8VAT('=E<F1E
M;B!S;VQL96XN`%-I92!M_'-S96X@96EN96X@>G4@;/9S8VAE;F1E;B!"96YU
M='IE<FYA;65N(&%N9V5B96XN`%-I92!M_'-S96X@96EN96X@:&EN>G5Z=6;\
M9V5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BX`4VEE(&W\<W-E;B!D96X@
M>G4@86MT=6%L:7-I97)E;F1E;B!"96YU='IE<FYA;65N(&%N9V5B96XN`%-I
M92!M_'-S96X@96EN92!!:W1I;VX@86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE
M;B!N975E;B!+871E9V]R:65N86UE;B!A;F=E8F5N+@!3:64@;?QS<V5N("(E
M<R(@:6X@26AR96X@5V%R='5N9W-E:6YS=&5L;'5N9V5N(&%K=&EV:65R96XN
M`%-I92!M_'-S96X@96EN92!)=&%L:65N:7-C:&4@5&5L969O;FYU;6UE<B!A
M;F=E8F5N`%-I92!H86)E;B!D:65S92!.86-H<FEC:'0@86T@)25S(&YA8V@@
M)7,@=6UG96QE:71E="X`4VEE(&AA8F5N(&%U9B!D:65S92!.86-H<FEC:'0@
M86T@)7,@9V5A;G1W;W)T970N`$)E:6T@16EN8FQE;F1E;B!D97,@3W)D;F5R
M<R`B)7,B(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!-96QD=6YG(&1E
M<R!%;6%I;"U397)V97)S`$1E<B!/<F1N97(@(B5S(B!W=7)D92!N:6-H="!A
M=7-G96)L96YD970N($1I92!-96QD=6YG(&1E<R!%;6%I;"U397)V97)S`$1E
M<B!/<F1N97(@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!E:6YG96)L96YD970N
M`$1E<B!/<F1N97(@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!A=7-G96)L96YD
M970N`$EH<F4@)7,M4V5S<VEO;B!I<W0@86)G96QA=69E;BX@0FET=&4@;65L
M9&5N(%-I92!S:6-H(&5R;F5U="!A;BX`26AR92!%;6%I;"U!9')E<W-E`$EH
M<F4@5F]N.B!!9')E<W-E.@!):')E($%N9V%B96X`26AR92!);G1E<FYE=&%D
M<F5S<V4@:&%T('-I8V@@9V7D;F1E<G0L('-E:70@4VEE(&1I92`E<RU3:71Z
M=6YG(&)E9V]N;F5N(&AA8F5N+B!:=6T@4V-H=71Z($EH<F5R(%-I8VAE<FAE
M:70@;?QS<V5N(%-I92!S:6-H(&YE=2!A;FUE;&1E;BX`26AR($YA;64`26AR
M92#V9F9E;G1L:6-H96XO<')I=F%T96X@4$=0+5-C:&S\<W-E;`!):'(@<')I
M=F%T97(@4V-H;/QS<V5L`$EH<B#V9F9E;G1L:6-H97(@4V-H;/QS<V5L`$EH
M<F4@)G%U;W0[06YT=V]R="!A;CHF<75O=#L@061R97-S93H@/&5M/BAO<'1I
M;VYA;"D\+V5M/@!):')E(/9F9F5N=&QI8VAE;B]P<FEV871E;B!3+TU)344M
M6F5R=&EF:6MA=&4`26AR92!+;VYT96XZ`$EH<F4@06QI87,M061R97-S96XZ
M(#QE;3XH;W!T:6]N86PL(&IE9&4@061R97-S92!I;B!E:6YE<B!E:6=E;F5N
M(%IE:6QE(&5I;G1R86=E;BD\+V5M/@!):'(@075T:&5N=&EF:7II97)U;F=S
M<WES=&5M(&5R;&%U8G0@:V5I;B!(:6YZ=6;\9V5N('9O;B!N975E;B!"96YU
M='IE<FXN(%=E;FX@4VEE($AO<F1E(&)E;G5T>F5N(&WV8VAT96XL('5M($EH
M<F4@0F5N=71Z97(@>G4@=F5R=V%L=&5N+"!M_'-S96X@4VEE(&5I;F5N(&%N
M9&5R96X@075T:&5N=&EF:7II97)U;F=S=')E:6)E<B!B96YU='IE;BX`26AR
M($%U=&AE;G1I9FEZ:65R=6YG<W-Y<W1E;2!E<FQA=6)T(&1A<R!!;GIE:6=E
M;B!D97(@0F5N=71Z97(@;FEC:'0L(&]D97(@9&EE<V4@3?9G;&EC:&ME:70@
M=W5R9&4@875S9V5S8VAA;'1E="X`26AR($)R;W=S97(@:&%T('-I8V@@86YS
M8VAE:6YE;F0@9V7D;F1E<G0@<V5I="!3:64@9&EE("5S+5-I='IU;F<@8F5G
M;VYN96X@:&%B96XN(%IU;2!38VAU='H@26AR97(@4VEC:&5R:&5I="!M_'-S
M96X@4VEE('-I8V@@;F5U(&%N;65L9&5N+@!):'(@0G)O=W-E<B!K86YN(&1I
M97-E;B!":6QD='EP(&YI8VAT(&1I<F5K="!A;GIE:6=E;BX`26AR($)R;W=S
M97(@=6YT97)S=/QT>G0@9&EE<V4@1G5N:W1I;VX@;FEC:'0N`$EH<B!"<F]W
M<V5R('5N=&5R<W3\='IT(&1I97-E($1R=6-K9G5N:W1I;VX@;FEC:'0N($)I
M='1E(&1R_&-K96X@4VEE(%-T<F<O2V]M;6%N9&\@*R!0('5M('IU(&1R=6-K
M96XN`$EH<F4@86MT=65L;&4@6F5I='IO;F4Z`$EH<B!3=&%N9&%R9'IE:6-H
M96YS871Z(&)E:6T@17)S=&5L;&5N('9O;B!N975E;B!.86-H<FEC:'1E;CH`
M26AR92!3=&%N9&%R9"U697)S8VAL_'-S96QU;F=S;65T:&]D92!B96EM(%9E
M<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;CH`26AR92!3=&%N9&%R9&ED96YT
M:73D="!W=7)D92!G9>1N9&5R="X`26AR92!3=&%N9&%R9&ED96YT:73D=#H`
M26AR('9O;&QS=.1N9&EG97(@3F%M93H`26AR('9E<FQI;FMT97(@06YH86YG
M('=U<F1E('9O;B!M:6YD97-T96YS(&5I;F5R(%!E<G-O;B!H97)U;G1E<F=E
M;&%D96XN"@I.86UE(&1E<R!!;FAA;F=S.B`E<PI$871U;2!D97,@06YH86YG
M<SH@)7,*"DML:6-K96X@4VEE(&%U9B!D96X@9F]L9V5N9&5N($QI;FLL('5M
M(&1E;B!!;FAA;F<@96YD9_QL=&EG('IU(&SV<V-H96XZ"B5S`$EH<B!:=6=A
M;F<@:7-T(&%B9V5L875F96XN`$EH<F4@3F%C:')I8VAT('=U<F1E(&5R9F]L
M9W)E:6-H('9E<G-C:&EC:W0N`$EH<B!N975E<R!087-S=V]R="!F_'(@)7,@
M;&%U=&5T.B`E<P!):')E($5I;G-T96QL=6YG96X@=W5R9&5N(&;\<B!D:64@
M1&%U97(@9&EE<V5R(%-I='IU;F<@9V5S<&5I8VAE<G0N`$EH<F4@16EN<W1E
M;&QU;F=E;B!W=7)D96X@9V5S<&5I8VAE<G0N`$EH<B!087-S=V]R="!W=7)D
M92!Z=7+\8VMG97-E='IT`$EH<B!087-S=V]R="!W=7)D92!Z=7+\8VMG97-E
M='IT+B!2=69E;B!3:64@26AR92!%;6%I;',@86(@=6YD(&UE;&1E;B!3:64@
M<VEC:"!M:70@26AR96T@;F5U96X@4&%S<W=O<G0@86XN`$EH<B!087-S=V]R
M="!I<W0@86)G96QA=69E;BX`26AR92!397)V97(Z`$EH<F4@4VEG;F%T=7(Z
M`$IU9V]S;&%W:65N`%IA:7)E`%-A;6)I80!3:6UB86)W90!::7!P>0!;061R
M97-S96X@=F5R<W1E8VME;ET`6UII=&%T=&5X="!V97)S=&5C:V5N70!;2V5I
M;B!"971R969F70!;4')O8FQE;6)E<FEC:'1=`%M!9')E<W-E;B!A;GIE:6=E
M;B`M`%M::71A='1E>'0@86YZ96EG96X@+0!;6FET871T97AT(&%N>F5I9V5N
M("T@)7,@6F5I;&5N70!;061R97-S96X@86YZ96EG96X@+2`E<R!%;7!FY&YG
M97)=`%M:96EL92`E<R!V;VX@)7-=`%]!9&UI;FES=')A=&EO;@!?0F-C`$%U
M<W-?8VAL=7-S;&ES=&4`0F5?9F5H;'-Z96EL90!?0V,`7T1A=&%4<F5E`%],
M]G-C:&5N`%IE:6QE(%]L]G-C:&5N`%]/<F1N97(`7T=R=7!P96X`7TAI;&9E
M`%])9&5N=&ETY'0`7T)I;&1E:6=E;G-C:&%F=&5N+BXN`%]0;W-T96EN9V%N
M9P!!;E]M96QD96X`06)?;65L9&5N`%]1=65L;'1E>'0`3&EN:R!?8F5A<F)E
M:71E;BXN+@!?3F5U92!.86-H<FEC:'0`7T5I;G-T96QL=6YG96X`7U)E8VAT
M90!$7W)U8VME;@!?4')I;W)I=.1T`$%?:W1U86QI<VEE<F4@)7,`3&EN:R!?
M96YT9F5R;F5N+BXN`$%N7W1W;W)T96X`7U-U8VAE`%]396YD96X`7TMO;F9I
M9W5R871I;VX`7U1A8F5L;&5N96EG96YS8VAA9G1E;BXN+@!?5&AE;6$`7T%N
M`%=?:65D97)H97)S=&5L;&5N`%]"96YU='IE<@!4:&5M82!!;GIE:5]G96X`
M4&]S:71I=FQI<W1E`$%D<F5S<V)U8V@`061R97-S870@=6YB96MA;FYT`$%N
M:&%N9P!A;FAA96YG92YZ:7``0GET97,`2V%L96YD97(`=VEN9'-T:6QL`$%U
M<V=A8F5D871E:2!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N`$5I;F=A
M8F4@:V%N;B!N:6-H="!G9?9F9FYE="!W97)D96X`:VQI8VME;B!3:64@:&EE
M<@!5;F?\;'1I9V4@0F5N=71Z=6YG(&1E<B!+;VUM86YD;WIE:6QE`$MO;F9I
M9W5R871I;VYS9F5H;&5R`$MR:71I<V-H92!3>7-T96UD871E:2!F96AL=`!$
M871E;F9O<FUA=&9E:&QE<@!B96%R8F5I=&5N`$5I;G1R86<@;FEC:'0@9V5F
M=6YD96X`9F%L;&5N9`!$871E:0!V;VX`875S("5S("@E<RD@;6ET("5S("5S
M`&+V:6<`:#H`:&@`2&]S=&YA;64@=6YB96MA;FYT`'-O9F]R=`!);FQI;F4`
M16EN+2]!=7-G86)E9F5H;&5R`$EN=&5R;F5R(%-O9G1W87)E9F5H;&5R`%-C
M:&S\<W-E;`!:96EL96Y=`$]R9&YE<F1A=&5I`&UK:7-O9G,M1F5H;&5R8V]D
M92`E9"!B96D@9&5R($5R<W1E;&QU;F<@9&5S($E33RU!8F)I;&1E<RX`;6T`
M3F%M90!K96EN90!N:6-H="!I;7!L96UE;G1I97)T`$YO8V@@;FEC:'0@:6UP
M;&5M96YT:65R=`!.;W1I>F)L;V-K`&]D97(`4')O>F5N=`!:=6=R:69F('9E
M<G=E:6=E<G0`4&EX96P`16UP9N1N9V5R70!296UO=&5F96AL97(@:6T@4')O
M=&]K;VQL`'-T96EG96YD`%-E<G9I8V4@;FEC:'0@=F5R9OQG8F%R`%5N=&5R
M<V-H:65D92!A;GIE:6=E;@!S;7,R96UA:6P@_&)E<B!(5%10`%)E8VAT<V-H
M<F5I8F9E:&QE<@!296-H='-C:')E:6)F96AL97(`<W,`9VQE:6-H8FQE:6)E
M;F0`4WES=&5M9F5H;&5R`$%U9F=A8F5N;&ES=&4`5F]R_&)E<F=E:&5N9&5R
M($9E:&QE<@!G96)E;B!3:64@9&%S(%!A<W-W;W)T(&5I;B!Z=V5I=&5S($UA
M;"!Z=7(@0F5S=.1T:6=U;F<@96EN`'5N:69I960`=6YB96YA;FYT`&)E;G5T
M>F5R9&5F:6YI97)T`'9#87)D`&(Z`'=E871H97(N8V]M`$EH<F5R($%U<W-C
M:&QU<W-L:7-T90!):')E<B!0;W-I=&EV;&ES=&4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O9&5?1$4O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S0V-3``,3`T
M,3<S-C(W-C``,#(Q,#8V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES
M;RTX.#4Y+3$B/SX*/"$M+2`D2&]R9&4Z(&EM<"]L;V-A;&4O9&5?1$4O:&5L
M<"YX;6PL=B`Q+C(T+C0N-B`R,#`V+S`Q+S,P(#$U.C4V.C`V(&IA;B!%>'`@
M)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6)U='1O;G,B('-T
M871E/2)U<'1O9&%T92(@;60U/2(S,C4Y8F$P,&$Q.3@U-3EC-V9A83<V93<X
M-C<V,#!D.2(^"B`@("`\=&ET;&4^3F5U92!.86-H<FEC:'0Z($%K=&EO;F5N
M/"]T:71L93X*("`@(#QH96%D:6YG/D%K=&EO;F5N/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("`@(")396YD96XB('9E<G-C:&EC:W0@26AR92!.86-H<FEC
M:'0@86X@9&5N(&]D97(@9&EE(&%N9V5G96)E;F5N"B`@("`@($5M<&;D;F=E
M<BX@0F5V;W(@4VEE(&AI97)A=68@:VQI8VME;BP@<V]L;'1E;B!3:64@<VEC
M:&5R('-E:6XL(&1A<W,@4VEE"B`@("`@(&1I92!.86-H<FEC:'0@=VER:VQI
M8V@@<V5N9&5N(&WV8VAT96XL(&1A('-I92!S:6-H(&YA8V@@9&5M($%B<V5N
M9&5N"B`@("`@(&YI8VAT(&UE:'(@>G5R_&-K<G5F96X@;.1S<W0N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@("`@(D5N='=U<F8@<W!E:6-H97)N(B!S
M<&5I8VAE<G0@96EN92!U;G9O;&QS=.1N9&EG92!.86-H<FEC:'0@:6X@9&5M
M"B`@("`@($]R9&YE<BP@9&5N(%-I92!U;G1E<B`B16EN<W1E;&QU;F=E;BTF
M9W0[3F5U92!.86-H<FEC:'0B(&1A9OQR"B`@("`@('9O<F=E<V5H96X@:&%B
M96XN(%-I92!K]FYN96X@875F(&1I97-E;B!/<F1N97(@_&)E<B!D:64@075S
M=V%H;&QI<W1E"B`@("`@('IU9W)E:69E;BP@9&EE('-I8V@@<F5C:'1S(&]B
M96X@:6X@9&5R($UE;OQL96ES=&4@8F5F:6YD970N(%=E;FX@4VEE(&1I90H@
M("`@("!.86-H<FEC:'0@<W#D=&5R(&9E<G1I9W-T96QL96X@=V]L;&5N+"!W
M96-H<V5L;B!3:64@96EN9F%C:"!Z=6T@9&EE<V5M"B`@("`@($]R9&YE<BP@
M:VQI8VME;B!A=68@9&EE(&=E<W!E:6-H97)T92!.86-H<FEC:'0@=6YD(&%N
M<V-H;&EEWV5N9"!A=68*("`@("`@(D9O<G1F_&AR96XB+B!!8VAT96X@4VEE
M(&1A<F%U9B!E:6YE;B!"971R969F(&%N>G5G96)E;BP@=V5N;B!3:64@9&EE
M"B`@("`@($YA8VAR:6-H="!S<&5I8VAE<FX@=V]L;&5N+B!3;R!S=&5L;&5N
M(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I90H@("`@("!E;G1S<')E8VAE;F1E
M($YA8VAR:6-H="!I;2!D96T@3W)D;F5R('-PY'1E<B!P<F]B;&5M;&]S('=I
M961E<F9I;F1E;BX*("`@(#PO<&%R83X*("`@(#QT:7`^"B`@("`@($IE(&YA
M8VAD96TL('=I92!):'(@4WES=&5M(&5I;F=E<FEC:'1E="!W=7)D92P@:_9N
M;F5N(%-I92!E:6YS=&5L;&5N+"!O8@H@("`@("!3:64@;F%C:"!D96T@4W!E
M:6-H97)N(&1E<R!%;G1W=7)F<R!Z=6T@;&5T>G1E;B!/<F1N97(@;V1E<B!Z
M=2!D97(*("`@("`@3F%C:')I8VAT+"!D:64@4VEE(&=E<F%D92!G97-P96EC
M:&5R="!H86)E;BP@>G5R_&-K:V5H<F5N+@H@("`@/"]T:7`^"B`@("`\<&%R
M83X*("`@("`@(DYA8VAR:6-H="!V97)W97)F96XB(&)E96YD970@9&EE($)E
M87)B96ET=6YG(&1E<B!.86-H<FEC:'0L(&]H;F4@9&EE<V4*("`@("`@>G4@
M<W!E:6-H97)N(&]D97(@86)Z=7-C:&EC:V5N+@H@("`@/"]P87)A/@H@(#PO
M96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB('-T871E/2)U<'1O
M9&%T92(@;60U/2(X,F-F,C1D,S%A-C8W835B.31E-#@Q8V0U,3<Y8S4R.2(^
M"B`@("`\=&ET;&4^3F5U92!.86-H<FEC:'0Z(%9O;CPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY6;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@2F4@;F%C
M:&1E;2P@=VEE($EH<B!3>7-T96T@96EN9V5R:6-H=&5T('=U<F1E+"!K]FYN
M96X@4VEE(&%U<R!D97(*("`@("`@075S=V%H;&QI<W1E(&5I;F4@261E;G1I
M=.1T(&%U<W?D:&QE;BP@9&EE(%-I92!U;G1E<@H@("`@("`B16EN<W1E;&QU
M;F=E;BTF9W0[4&5R<_9N;&EC:&4@06YG86)E;B(@97)S=&5L;'0@:&%B96XL
M(&]D97(@9&EE"B`@("`@($5M86EL861R97-S92!I;B!E:6YE;2!497AT9F5L
M9"!E:6YG96)E;BP@9&EE(&%L<R!!8G-E;F1E<B!I;B!D97(*("`@("`@3F%C
M:')I8VAT(&5R<V-H96EN96X@<V]L;"X*("`@(#PO<&%R83X*("`\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UT;R(@<W1A=&4](G5P=&]D871E(B!M
M9#4](C,Q8V)A,3=F,38Y-3<R8S,V-V%A.#`Q-#@S,65B.&8X(CX*("`@(#QT
M:71L93Y.975E($YA8VAR:6-H=#H@06X\+W1I=&QE/@H@("`@/&AE861I;F<^
M06X\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@2&EE<B!G96)E;B!3:64@
M9&EE($5M86EL+4%D<F5S<V5N(&1E<B!%;7!FY&YG97(@86XN(%=E;FX@4VEE
M(&UE:')E<F4*("`@("`@061R97-S96X@86YG96)E;B!M]F-H=&5N+"!M_'-S
M96X@4VEE(&1I97-E(&1U<F-H($MO;6UA<R!T<F5N;F5N+B!!;F1E<F4*("`@
M("`@5')E;FYZ96EC:&5N(&;\:')E;B!Z=2!&96AL97)N+@H@("`@/"]P87)A
M/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6-C(B!S=&%T93TB
M=7!T;V1A=&4B(&UD-3TB.3<U-S$T,S-A8C`S-V5F.6,T9#$P,6$U-F)F-S1E
M,C4B/@H@("`@/'1I=&QE/DYE=64@3F%C:')I8VAT.B!#8SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY#8SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!(:65R
M(&OV;FYE;B!3:64@9&EE($5M86EL+4%D<F5S<V5N('9O;B!Z=7/D='IL:6-H
M96X@16UP9N1N9V5R(&%N9V5B96XL"B`@("`@(&1I92!E:6YE($MO<&EE("A#
M87)B;VX@8V]P>2D@9&5R($YA8VAR:6-H="!E<FAA;'1E;B!S;VQL96XN(%=E
M;FX@4VEE"B`@("`@(&UE:')E<F4@061R97-S96X@86YG96)E;B!M]F-H=&5N
M+"!M_'-S96X@4VEE(&1I97-E(&1U<F-H($MO;6UA<PH@("`@("!T<F5N;F5N
M+B!!;F1E<F4@5')E;FYZ96EC:&5N(&;\:')E;B!Z=2!&96AL97)N+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("`@($1I97-E<R!&96QD('9E<G=E;F1E
M="!M86X@_&)L:6-H97)W96ES92!F_'(@4&5R<V]N96XL(&1I92!N:6-H="!Z
M=2!D96X*("`@("`@96EG96YT;&EC:&5N($%D<F5S<V%T96X@9&5R($5M86EL
M(&=E:/9R96XL(&%B97(@>BY"+B!I;F1I<F5K="!V;VX@9&5M"B`@("`@($EN
M:&%L="!B971R;V9F96X@<VEN9"X@06QL92!%;7!FY&YG97(L(&1I92!I;B!D
M96X@1F5L9&5R;B`B06XB(&]D97(@(D-C(@H@("`@("!S=&5H96XL(&OV;FYE
M;B!D:64@:V]M<&QE='1E($QI<W1E(&1E<B!%;7!FY&YG97(@875S(&)E:61E
M;B!&96QD97)N"B`@("`@('-E:&5N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^
M"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6)C8R(@<W1A=&4](G5P=&]D871E(B!M
M9#4](F%A.&8Y93)D-#1F9&(W-&1E9C!F83$U,C0P9F8V.#=B(CX*("`@(#QT
M:71L93Y.975E($YA8VAR:6-H=#H@0F-C/"]T:71L93X*("`@(#QH96%D:6YG
M/D)C8SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!(:65R(&OV;FYE;B!3
M:64@9&EE($5M86EL+4%D<F5S<V5N('9O;B!Z=7/D='IL:6-H96X@16UP9N1N
M9V5R(&%N9V5B96XL"B`@("`@(&1I92!E:6YE($)L:6YD:V]P:64@*$)L:6YD
M(&-A<F)O;B!C;W!Y*2!D97(@3F%C:')I8VAT(&5R:&%L=&5N"B`@("`@('-O
M;&QE;BX@5V5N;B!3:64@;65H<F5R92!!9')E<W-E;B!A;F=E8F5N(&WV8VAT
M96XL(&W\<W-E;B!3:64@9&EE<V4*("`@("`@9'5R8V@@2V]M;6%S('1R96YN
M96XN($%N9&5R92!4<F5N;GIE:6-H96X@9OQH<F5N('IU($9E:&QE<FXN"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@1&%M:70@:&%B96X@4VEE(&1I
M92!-]F=L:6-H:V5I="P@96EN92!+;W!I92!D97(@3F%C:')I8VAT(&%N('=E
M:71E<F4*("`@("`@877?97(@9&5N(&1I<F5K=&5N('5N9"!I;F1I<F5K=&5N
M($%D<F5S<V%T96X@>G4@<V-H:6-K96XL($](3D4@9&%S<PH@("`@("!D:65S
M92!D879O;B!E<F9A:')E;BP@875C:"!N:6-H="!D:64@(D)C8R(M16UP9N1N
M9V5R('5N=&5R96EN86YD97(N($1I90H@("`@("!!9')E<W-E;B!I;B!D96T@
M(D)C8R(M1F5L9"!K]FYN96X@;G5R(%-I92!U;F0@9&EE(&5N='-P<F5C:&5N
M9&5N"B`@("`@($5M<&;D;F=E<B!S96AE;BX*("`@(#PO<&%R83X*("`\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB,#8S.6$X-SDP93,P-F%C8SEE,3EB-&0Q8V4S-#)D-3,B
M/@H@("`@/'1I=&QE/DYE=64@3F%C:')I8VAT.B!"971R969F/"]T:71L93X*
M("`@(#QH96%D:6YG/D)E=')E9F8\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M("`@2&EE<B!K]FYN96X@4VEE(&1E;B!"971R969F+"!D87,@5&AE;6$@9&5R
M($YA8VAR:6-H=`H@("`@("!A;F=E8F5N+B!&;W)M=6QI97)E;B!3:64@9&5N
M($)E=')E9F8@:W5R>BP@96EN9F%C:"!U;F0*("`@("`@875S<V%G96MRY&9T
M:6<N($%N:&%N9"!D97(@0F5T<F5F9GIE:6QE(&OV;FYE;B!3:64@=6YD($EH
M<F4*("`@("`@2V]R<F5S<&]N9&5N>G!A<G1N97(@86T@96EN9F%C:'-T96X@
M97)K96YN96XL('=E;&-H96X@26YH86QT(&1I90H@("`@("!.86-H<FEC:'0@
M:&%T=&4@8GIW+B!H870N($1A9'5R8V@@;&%S<V5N('-I8V@@96EN9V5G86YG
M96YE($YA8VAR:6-H=&5N"B`@("`@(&QE:6-H=&5R(&]R9V%N:7-I97)E;B!U
M;F0@<W#D=&5R(&5I;F9A8VAE<B!W:65D97)F:6YD96XN"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@("`@5V5N;B!3:64@875F($YA8VAR:6-H=&5N(&%N
M='=O<G1E;B!O9&5R(&1I97-E('=E:71E<FQE:71E;BP@8FQE:6)T(&1E<@H@
M("`@("!"971R969F(&5R:&%L=&5N+"!S;R!D87-S(&UA;B!L96EC:'0@<V5H
M96X@:V%N;BP@=V5L8VAE($YA8VAR:6-H=&5N('IU"B`@("`@(&5I;F5M($1I
M<VMU<W-I;VYS9F%D96X@9V5H]G)E;BX@06QL97)D:6YG<R!S;VQL=&5N(%-I
M92!D96X@0F5T<F5F9B!A=6-H"B`@("`@(&5N='-P<F5C:&5N9"#D;F1E<FXL
M('=E;FX@<VEC:"!D97(@1&ES:W5S<VEO;G-V97)L875F(&=EY&YD97)T(&AA
M="X*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UO<'1I;VYS(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-68Q9#4P83<S,V,X
M8C=E-#9A96-E8V4R.#@R,F9F-S`B/@H@("`@/'1I=&QE/DYE=64@3F%C:')I
M8VAT.B!%:6YS=&5L;'5N9V5N/"]T:71L93X*("`@(#QH96%D:6YG/D5I;G-T
M96QL=6YG96X\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@1&EE<V4@16EN
M<W1E;&QU;F=E;B!B:65T96X@>G5SY'1Z;&EC:&4@1G5N:W1I;VYE;B!F_'(@
M9&%S($5R<W1E;&QE;B!V;VX*("`@("`@3F%C:')I8VAT96XN"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@("`@2VQI8VME;B!3:64@875F(")296-H='-C
M:')E:6)U;F<B+"!U;2!D96X@3F%C:')I8VAT96YT97AT(&%U9B!K;W)R96MT
M90H@("`@("!296-H='-C:')E:6)U;F<@>G4@_&)E<G!R_&9E;BX*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@("!796YN(%-I92!A=68@(D%N:.1N9V4B
M(&ML:6-K96XL('=I<F0@9&%S($9E;G-T97(@=V5I=&5R(&YA8V@@=6YT96X*
M("`@("`@9V5S8W)O;&QT+"!W;R!3:64@9&5R($YA8VAR:6-H="!!;FCD;F=E
M(&AI;GIU9OQG96X@:_9N;F5N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("`@($IE(&YA8VAD96TL('=I92!):'(@4WES=&5M(&5I;F=E<FEC:'1E="!I
M<W0L(&5R<V-H96EN="!E:6X@1F5L9"`B16EN90H@("`@("!+;W!I92!S<&5I
M8VAE<FXB+B`@5V5N;B!3:64@9&EE<V5S($9E;&0@;6%R:VEE<F5N+"!W:7)D
M(&YA8V@@9&5M"B`@("`@(%9E<G-E;F1E;B!D97(@3F%C:')I8VAT(&5I;F4@
M2V]P:64@:6X@9&5M($]R9&YE<B!G97-P96EC:&5R="P@9&5N(%-I90H@("`@
M("!F_'(@9&EE<V5N(%IW96-K('5N=&5R(")%:6YS=&5L;'5N9V5N+29G=#M0
M97)S]FYL:6-H90H@("`@("!!;F=A8F5N+29G=#M)9&5N=&ETY'1E;B(@875S
M9V5WY&AL="!H86)E;BX@1F%L;',@96EN(&5N='-P<F5C:&5N9&5S"B`@("`@
M($%U<W=A:&QF96QD('9O<FAA;F1E;B!I<W0L(&OV;FYE;B!3:64@86)E<B!A
M=6-H(&5I;F5N(&%N9&5R96X@3W)D;F5R"B`@("`@(&1A<F%U<R!A=7-WY&AL
M96XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@4VEE(&OV;FYE;B!M
M:70@9&EE<V5R($9U;FMT:6]N('=I8VAT:6=E($YA8VAR:6-H=&5N('-P96EC
M:&5R;BP@9&%M:70@4VEE"B`@("`@('-PY'1E<B!G9V8N(&1A<F%U9B!Z=7+\
M8VMG<F5I9F5N(&OV;FYE;BX@4VEE(&OV;FYE;B!I;B!):')E;B!)9&5N=&ET
MY'1E;@H@("`@("!U;G1E<B`B16EN<W1E;&QU;F=E;BTF9W0[4&5R<_9N;&EC
M:&4@06YG86)E;BTF9W0[261E;G1I=.1T96X@8F5A<F)E:71E;B(*("`@("`@
M9F5S=&QE9V5N+"!D87-S(&1I97-E($9U;FMT:6]N('-T86YD87)D;>3?:6<@
M86MT:79I97)T('-E:6X@<V]L;"X@26X@9&5N"B`@("`@($5I;G-T96QL=6YG
M96X@:&%B96X@4VEE(&%U8V@@9&EE($WV9VQI8VAK96ET(%=A<G1U;F=S87)B
M96ET96X*("`@("`@96EN>G5R:6-H=&5N+"!D:64@9&EE<V5N($]R9&YE<B!R
M96=E;&WDWVEG(&QE97)E;B!O9&5R('5M8F5N96YN96XN"B`@("`\+W!A<F$^
M"B`@("`\=V%R;CX*("`@("`@4VEE('-O;&QT96X@86QL97)D:6YG<R!N:6-H
M="!A;&QE(&=E<V5N9&5T96X@3F%C:')I8VAT96X@<W!E:6-H97)N+"!D80H@
M("`@("!S;VYS="!D:64@4W!E:6-H97)P;&%T>F)E9W)E;GIU;F<@26AR97,@
M4&]S=&9A8VAE<R!A=7-G97-C:/9P9G0@=V5R9&5N"B`@("`@(&OV;FYT92`H
M:6YS8F5S;VYD97)E(&)E:6T@5F5R<V5N9&5N('9O;B!G<O;?97)E;B!$871E
M:65N*2!U;F0@4VEE(&1A;FX*("`@("`@:V5I;F4@=V5I=&5R96X@3F%C:')I
M8VAT96X@;65H<B!E;7!F86YG96X@:_9N;F5N+@H@("`@/"]W87)N/@H@(#PO
M96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:"(@<W1A=&4](G5P
M=&]D871E(B!M9#4](F4X,#9E-64Q-C0Q9F(R-3,Q8V,Y-60R9&8R-S<X-3%F
M(CX*("`@(#QT:71L93Y.975E($YA8VAR:6-H=#H@06YHY&YG93PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY!;FCD;F=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("`@(%-I92!K]FYN96X@8F5L:65B:6=E($1A=&5I96X@>G4@26AR97(@3F%C
M:')I8VAT(&%L<R!!;FAA;F<*("`@("`@:&EN>G5F_&=E;BX@1&%B96D@;?QS
M<V5N(%-I92!J961E($1A=&5I(&5I;GIE;&X@86YHY&YG96XN"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@("`@4V-H<FET="`Q.B!'96)E;B!3:64@96YT
M=V5D97(@9&5N($YA;65N(&1E<B!$871E:2P@9&EE(%-I92!A;FCD;F=E;@H@
M("`@("!M]F-H=&5N+"!M:70@9&5M('9O;&QS=.1N9&EG96X@4&9A9"!I;B!D
M87,@5&5X=&9E;&0@96EN+"!O9&5R(&ML:6-K96X*("`@("`@4VEE(&%U9B`B
M1'5R8VAS=6-H96XN+BXB('5N9"!WY&AL96X@4VEE(&1I92!E;G1S<')E8VAE
M;F1E($1A=&5I"B`@("`@(&%U<RX@1&%N;B!W:7)D(&1E<B!09F%D('5N9"!D
M97(@3F%M92!D:65S97(@1&%T96D@875T;VUA=&ES8V@@:6X@9&%S"B`@("`@
M(%1E>'1F96QD(&5I;F=E9OQG="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@("!38VAR:71T(#(Z($5N='-C:&5I9&5N(%-I92P@;V(@9&EE($1A=&5I
M(&%L<R!!;FAA;F<@;V1E<B!I;FYE<FAA;&(@9&5R"B`@("`@($YA8VAR:6-H
M="!A;F=Z96EG="!W97)D96X@<V]L;"X@1&%Z=2!M=7-S(&1A<R!%;6%I;"U0
M<F]G<F%M;2!D97,*("`@("`@16UP9N1N9V5R<R!A;&QE<F1I;F=S(&EN(&1E
M<B!,86=E('-E:6XL($1A=&5I96X@:6YN;F5R:&%L8B!D97(@3F%C:')I8VAT
M"B`@("`@(&%N>G5Z96EG96XN($ES="!D87,@;FEC:'0@9&5R($9A;&PL('=I
M<F0@9&EE($1A=&5I(&=A;GH@;F]R;6%L(&%L<PH@("`@("!!;FAA;F<@9&%R
M9V5S=&5L;'0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@4V-H<FET
M="`S.B!+;&EC:V5N(%-I92!A=68@(D%N:.1N9V5N(BX@1&5R($YA;64@=6YD
M(&1I92!'<O;?90H@("`@("!D97(@1&%T96D@97)S8VAE:6YT(&%N<V-H;&EE
MWV5N9"!I;B!D97(@3&ES=&4@=6YT97)H86QB(&1E<@H@("`@("!%:6YG86)E
M9F5L9&5R+@H@("`@/"]P87)A/@H@("`@/'1I<#X*("`@("`@2F4@;F%C:&1E
M;2P@=VEE(&=R;]\@9&5R($%N:&%N9R!U;F0@=VEE('-C:&YE;&P@26AR92!)
M;G1E<FYE='9E<F)I;F1U;F<*("`@("`@:7-T+"!K86YN(&5S(&5I;F4@5V5I
M;&4@9&%U97)N+"!B:7,@9&EE($1A=&5I(&AO8VAG96QA9&5N(&ES="X@0FET
M=&4*("`@("`@:VQI8VME;B!3:64@:6X@9&EE<V5R(%IE:70@875F(&ME:6YE
M(&%N9&5R96X@4V-H86QT9FSD8VAE;BX*("`@(#PO=&EP/@H@(#PO96YT<GD^
M"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB.&%C,#,R8S1A8S$X,F8S9C!D-C0T-F,R,&8P,#@Y9&0B
M/@H@("`@/'1I=&QE/DYE=64@3F%C:')I8VAT.B!!;FAA;F=L:7-T93PO=&ET
M;&4^"B`@("`\:&5A9&EN9SXB06YH86YG;&ES=&4B/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("`@($EN(&1I97-E<B!,:7-T92!B969I;F1E;B!S:6-H(&%L
M;&4@06YHY&YG92P@9&EE(%-I92!B97)E:71S(&%N(&1I90H@("`@("!.86-H
M<FEC:'0@86YG96CD;F=T(&AA8F5N+B!5;2!E:6YE;B!!;FAA;F<@=VEE9&5R
M('IU(&5N=&9E<FYE;BP@9V5H96X@4VEE"B`@("`@(&)I='1E('=I92!F;VQG
M="!V;W(Z"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@4V-H<FET="`Q
M.B!-87)K:65R96X@4VEE(&%L;&4@06YHY&YG92P@9&EE(%-I92!E;G1F97)N
M96X@;?9C:'1E;BP@9'5R8V@*("`@("`@9&%S($%K=&EV:65R96X@9&5S($OD
M<W1C:&5N<R!H:6YT97(@(DSV<V-H96X_(BX*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@("!38VAR:71T(#(Z($ML:6-K96X@4VEE(&%U9B`B06YH86YG
M<VEN9F]R;6%T:6]N96X@86MT=6%L:7-I97)E;B(N"B`@("`\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<')I;W)I='DB('-T871E
M/2)U<'1O9&%T92(@;60U/2)B,#(S,S8W8S,V9&4S8V4Q-38W9#(W8V-A830U
M-C0P8R(^"B`@("`\=&ET;&4^3F5U92!.86-H<FEC:'0Z(%!R:6]R:73D=#PO
M=&ET;&4^"B`@("`\:&5A9&EN9SXB4')I;W)I=.1T(CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@("!$86UI="!K]FYN96X@4VEE(&1E;B`B6"U0<FEO<FET
M>2U%:6YT<F%G(B!U;F0@9&%M:70@9&EE(%=I8VAT:6=K96ET"B`@("`@($EH
M<F5R($YA8VAR:6-H="!F97-T;&5G96XN($1I97-E<B!%:6YT<F%G(&ES="!E
M:6X@475A<VDM4W1A;F1A<F0L(&1E<@H@("`@("!O9F9E;G-I8VAT;&EC:"!V
M;VX@3F5T<V-A<&4L($UO>FEL;&$L($]P97)A('5N9"!/=71L;V]K('9E<G-T
M86YD96X*("`@("`@=VER9"X@16UA:6QP<F]G<F%M;64L(&1I92!D:65S96X@
M16EN=')A9R!N:6-H="!K96YN96XL(&EG;F]R:65R96X@:6AN"B`@("`@(&5I
M;F9A8V@N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](F-O
M;7!O<V4M<V%V92UA='1A8VAM96YT<R(@<W1A=&4](G5P=&]D871E(B!M9#4]
M(F1B.#DY-S)C-&5B8C!B-#%A8C8Y,6(V83<W-#1A.#%D(CX*("`@(#QT:71L
M93Y.975E($YA8VAR:6-H=#H@06YHY&YG92!3<&5I8VAE<FX\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("`@($AI97)M:70@:_9N;F5N(%-I92!F97-T;&5G96XL
M(&]B($%N:.1N9V4L(&1I92!3:64@9&5R($YA8VAR:6-H=`H@("`@("!H:6YZ
M=6=E9OQG="!H86)E;BP@>G5S86UM96X@;6ET(&1I97-E<B!.86-H<FEC:'0@
M:6X@26AR96T@3W)D;F5R(&;\<B`*("`@("`@9V5S96YD971E($YA8VAR:6-H
M=&5N(&=E<W!E:6-H97)T('=E<F1E;BX@5V5N;B!3:64@(DIA(B!A=7-WY&AL
M96XL"B`@("`@('=E<F1E;B!D:64@06YHY&YG92!M:70@9V5S<&5I8VAE="X@
M5^1H;&5N(%-I92`B3F5I;B(L('=E<F1E;B!D:64@06YHY&=E"B`@("`@(&%U
M<R!D97(@3F%C:')I8VAT(&5N=&9E<FYT+"!N86-H9&5M(&1I97-E(&%N(&1I
M92!%;7!FY&YG97(@=F5R<V5N9&5T"B`@("`@('=U<F1E+B`B3F5I;B(@875S
M>G5WY&AL96X@:&EL9G0@4W!E:6-H97)P;&%T>B!Z=2!S<&%R96XL('=E:6P*
M("`@("`@;?9G;&EC:&5R=V5I<V4@<F5C:'0@9W)OWV4@1&%T96EE;B!N:6-H
M="!M:70@9&5N(&=E<V5N9&5T96X@3F%C:')I8VAT96X*("`@("`@9V5S<&5I
M8VAE<G0@=V5R9&5N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y
M(&ED/2)C;VUP;W-E+6QI;FLM871T86-H;65N=',B('-T871E/2)U<'1O9&%T
M92(@;60U/2)A-V)B,#0Q,F(P,S-A8F1B8F$R9C4U8CAB.#1D-F,W-B(^"B`@
M("`\=&ET;&4^3F5U92!.86-H<FEC:'0Z($%N:.1N9V4@5F5R;&EN:V5N/"]T
M:71L93X*("`@(#QP87)A/@H@("`@("!,96=T(&9E<W0L(&]B($%N:.1N9V4L
M(&1I92!3:64@8F5I;2!38VAR96EB96X@26AR97(@3F%C:')I8VAT(&%N9V5B
M96XL"B`@("`@(&%L<R!496EL(&1E<B!.86-H<FEC:'0@=F5R<V-H:6-K="!W
M97)D96X@;V1E<B!A=68@9&5M(%-E<G9E<@H@("`@("!V97)B;&5I8F5N+B!7
M96YN(%-I92!D:64@06YHY&=E(&YU<B!V97)L:6YK="!V97)S8VAI8VME;BP@
M97)HY&QT(&1E<@H@("`@("!%;7!FY&YG97(@9&5R($YA8VAR:6-H="!E:6X@
M;V1E<B!M96AR97)E($QI;FMS+"#\8F5R(&1I92!):')E($%N:.1N9V4*("`@
M("`@:&5R=6YT97)G96QA9&5N('=E<F1E;B!K]FYN96XN($1E<B!6;W)T96EL
M('9O;B!V97)L:6YK=&5N($%N:.1N9V5N"B`@("`@(&)E<W1E:'0@9&%R:6XL
M(&1A<W,@9&EE($=R]M]E(&1E<B!V97)S96YD971E;B!.86-H<FEC:'1E;B!D
M975T;&EC:`H@("`@("!R961U>FEE<G0@=VER9"X@1&5R($YA8VAT96EL(&ES
M="P@9&%S<R!N:6-H="!G87)A;G1I97)T('=E<F1E;B!K86YN+`H@("`@("!D
M87-S(&1E<B!!;FAA;F<@875F(&%L;&4@6F5I="!V97)F_&=B87(@<V5I;B!W
M:7)D+"!W96EL(&1I92!!;FCD;F=E"B`@("`@(&YI8VAT(&EN(&1I92!.86-H
M<FEC:'0@96EN9V5B971T970@<VEN9"X*("`@(#PO<&%R83X*("`\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<V5A<F-H(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M.#9B,F5F-3=B,3$Y-#@Y,#@S,V0Y9&0T.65B8SEB,S(B/@H@("`@/'1I=&QE
M/DYA8VAR:6-H=&5N<W5C:&4\+W1I=&QE/@H@("`@/&AE861I;F<^4W5C:&MR
M:71E<FEE;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!3:64@:_9N;F5N
M($EH<F4@3W)D;F5R(&YA8V@@3F%C:')I8VAT96X@86YH86YD('9O;B!U;G1E
M<G-C:&EE9&QI8VAE;@H@("`@("!3=6-H:W)I=&5R:65N(&1U<F-H<W5C:&5N
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%-C:')I='0@,3H@1V5B
M96X@4VEE(&1E;B!497AT(&EN(&1I92!.86-H<FEC:'1E;F9E;&1E<B!E:6XL
M(&1E;B!3:64@>G4*("`@("`@9&5N(%-U8VAK<FET97)I96X@:&EN>G5F_&=E
M;B!W;VQL96XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@4V-H<FET
M="`R.B!-87)K:65R96X@4VEE(&1E;B!.86-H<FEC:'1E;G-T871U<R`H365H
M<F9A8VAA=7-W86AL"B`@("`@(&WV9VQI8V@I+"!D96X@4VEE('IU('IU(&1E
M;B!3=6-H:W)I=&5R:65N(&AI;GIU9OQG96X@=V]L;&5N+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("`@(%-C:')I='0@,SH@5^1H;&5N(%-I92!D:64@
M3F%C:')I8VAT96YO<F1N97(@875S+"!I;B!D96YE;B!3:64@;F%C:"!D96X*
M("`@("`@3F%C:')I8VAT96X@<W5C:&5N('=O;&QE;BX*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@("!38VAR:71T(#0Z($ML:6-K96X@4VEE(&%U9B`B
M4W5C:&4B+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%=E;FX@3F%C
M:')I8VAT96X@9V5F=6YD96X@=W5R9&5N+"!D:64@26AR96X@4W5C:&MR:71E
M<FEE;B!E;G1S<')A8VAE;BP*("`@("`@=V5R9&5N(&1I97-E($YA8VAR:6-H
M=&5N(&EN(&5I;F5R($QI<W1E(&UI="!D96X@4W5C:&5R9V5B;FES<V5N"B`@
M("`@(&%N9V5Z96EG="X*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB9F]L9&5R+6]P=&EO;G,B('-T871E/2)U<'1O9&%T92(@;60U/2(S
M,#8X-V5C-#<U-S8U8F$T-#8W9#)E9C9D8V5C-#!C,R(^"B`@("`\=&ET;&4^
M3W)D;F5R($YA=FEG871I;VX\+W1I=&QE/@H@("`@/&AE861I;F<^06MT:6]N
M96X\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@36%R:VEE<F5N(%-I92!E
M<G-T(&%L;&4@3W)D;F5R+"!M:70@9&5N96X@4VEE(&5I;F4@06MT:6]N(&1U
M<F-H9OQH<F5N"B`@("`@(&WV8VAT96XL(&%N(&1E;B!+Y'-T8VAE;B!V;W(@
M9&5N($]R9&YE<FYA;65N+B!!;G-C:&QI9=]E;F0@:_9N;F5N(%-I90H@("`@
M("!A=7,@9&5R($%U<W=A:&QL:7-T92!D:64@96YT<W!R96-H96YD92!!:W1I
M;VX@=^1H;&5N+B!'96=E8F5N96YF86QL<PH@("`@("!W97)D96X@;F]C:"!W
M96ET97)E($%N9V%B96X@=F]N($EH;F5N(&5R9G)A9W0N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@("`@0F5N=71Z96X@4VEE(&1I92!!:W1I;VX@(D]R
M9&YE<B!L]G-C:&5N(B!M:70@9W)OWV5R(%9O<G-I8VAT(2!$97(@3W)D;F5R
M"B`@("`@('5N9"!A;&QE(&1A<FEN(&5N=&AA;'1E;F5N($YA8VAR:6-H=&5N
M('=E<F1E;B!U;G=I961E<F)R:6YG;&EC:`H@("`@("!G96SV<V-H="X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/DYA8VAR:6-H=&5N(&EM<&]R=&EE<F5N
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@($UI="!D:65S97(@06MT:6]N
M(&OV;FYE;B!3:64@96EN92!$871E:2!I;2!-8F]X+2!O9&5R("YE;6PM1F]R
M;6%T(&EN"B`@("`@(&5I;F5N(&)E;&EE8FEG96X@3W)D;F5R(&EM<&]R=&EE
M<F5N+B!-87)K:65R96X@4VEE(&1A>G4@96EN96X@3W)D;F5R('5N9`H@("`@
M("!WY&AL96X@4VEE(&%N<V-H;&EEWV5N9"!D:65S92!!:W1I;VX@875S(&1E
M<B!!=7-W86AL;&ES=&4@875S+B!3:64*("`@("`@9V5L86YG96X@9&%N86-H
M(&%U9B!E:6YE(&%N9&5R92!396ET92P@875F(&1E<B!3:64@9&EE('IU(&EM
M<&]R=&EE<F5N9&4*("`@("`@36)O>"T@;V1E<B`N96UL+41A=&5I(&%U<W?D
M:&QE;B!K]FYN96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](F9O;&1E<BUW:61G971S(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB8CEB
M8S8X.30P,F8W-3<U-S<Q9#<T-3<P93=F-F8X,&$B/@H@("`@/'1I=&QE/D]R
M9&YE<B!.879I9V%T:6]N.B!!;GIE:6=E/"]T:71L93X*("`@(#QH96%D:6YG
M/D]R9&YE<B!E:6XM+V%U<V)L96YD96X\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@("`@5V5N;B!3:64@24U!4"U/<F1N97)A8F]N;F5M96YT<R!V97)W96YD
M96XL(&OV;FYE;B!S:64@96EN>F5L;F4@3W)D;F5R"B`@("`@(&5I;BT@=6YD
M(&%U<V)L96YD96XN(%5M(&5I;F5N($]R9&YE<B!E:6XM(&]D97(@875S>G5B
M;&5N9&5N+"!M87)K:65R96X*("`@("`@4VEE(&1E;B!E;G1S<')E8VAE;F1E
M;B!/<F1N97(@86X@9&5M($OD<W1C:&5N('9O<B!D96T@3W)D;F5R;F%M96X@
M=6YD"B`@("`@(&)E;G5T>F5N(%-I92`B3W)D;F5R(&5I;F)L96YD96XB(&)Z
M=RX@(D]R9&YE<B!A=7-B;&5N9&5N(B!A=7,@9&5R"B`@("`@($%K=&EO;G-L
M:7-T92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D%L;&4@]F9F;F5N/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("`@($1I92!G97-A;71E($]R9&YE<G-T
M<G5K='5R('=I<F0@875F9V5K;&%P<'0N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY!;&QE('-C:&QI9=]E;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M("!$:64@9V5S86UT92!/<F1N97)S=')U:W1U<B!W:7)D(&5I;F=E:VQA<'!T
M+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97)S
M(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-65F-C`W.#8W-C=E-C,X9F)F-6)A
M.&9C-6)D-60Y9#(B/@H@("`@/'1I=&QE/D9I;'1E<G)E9V5L;CH@06YW96YD
M96X\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@(%=E;FX@4VEE(&%U9B!D87,@
M1FEL=&5R<WEM8F]L(&YE8F5N(&1E;2!/<F1N97)N86UE;B!K;&EC:V5N+"!W
MY&AR96YD"B`@("`@('-I8V@@:6X@96EN96T@3W)D;F5R(&)E9FEN9&5N+"!W
M97)D96X@86QL92!U;F=E;/9S8VAT96X@3F%C:')I8VAT96X*("`@("`@9V5M
MY-\@9&5R(%)E9V5L;BP@9&EE(%-I92!F97-T9V5L96=T(&AA8F5N+"!G969I
M;'1E<G0N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](F9I
M;'1E<BUE9&ET+7)U;&5S(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-6)A834W
M,#AA8SDT-#EE-SDW9CDV-S,Q,V$Y93%A,C<B/@H@("`@/'1I=&QE/D9I;'1E
M<G)E9V5L;CH@1FEL=&5R<F5G96QN(&)E87)B96ET96X\+W1I=&QE/@H@("`@
M/&AE861I;F<^1FEL=&5R<F5G96QN(&)E87)B96ET96X\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@("`@2VQI8VME;B!3:64@875F(")&:6QT97)R96=E;&X@
M8F5A<F)E:71E;B(L('5M('IU(&1E<B!396ET92!Z=2!G96QA;F=E;BP*("`@
M("`@875F(&1E<B!3:64@1FEL=&5R<F5G96QN(&AI;GIU9OQG96XL(&SV<V-H
M96X@=6YD(&)E87)B96ET96X@:_9N;F5N+@H@("`@/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UB;&%C:VQI<W0B('-T871E
M/2)U<'1O9&%T92(@;60U/2(X,&9F-S@P,V,V-C4Y.6,W,#,U9C=F.#@Q,60R
M,3AC8R(^"B`@("`\=&ET;&4^1FEL=&5R<F5G96QN.B!!=7-S8VAL=7-S;&ES
M=&4@8F5A<F)E:71E;CPO=&ET;&4^"B`@("`\:&5A9&EN9SY!=7-S8VAL=7-S
M;&ES=&4@8F5A<F)E:71E;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!+
M;&EC:V5N(%-I92!A=68@(D%U<W-C:&QU<W-L:7-T92!B96%R8F5I=&5N(BP@
M=6T@>G4@9&5R(%-E:71E('IU"B`@("`@(&=E;&%N9V5N+"!A=68@9&5R(%-I
M92!D:64@3&ES=&4@9&5R($5M86EL861R97-S96X@8F5A<F)E:71E;B!K]FYN
M96XL('9O;@H@("`@("!D96X@4VEE($Y)12!.86-H<FEC:'1E;B!E<FAA;'1E
M;B!M]F-H=&5N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)F:6QT97(M961I="UW:&ET96QI<W0B('-T871E/2)U<'1O9&%T92(@;60U
M/2(S,S!C,V$X9F%D,3DX8S=A9F4X-35C,3`Q8S8S8V0P9B(^"B`@("`\=&ET
M;&4^1FEL=&5R<F5G96QN.B!0;W-I=&EV;&ES=&4@8F5A<F)E:71E;CPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY0;W-I=&EV;&ES=&4@8F5A<F)E:71E;CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("!+;&EC:V5N(%-I92!A=68@(E!O<VET
M:79L:7-T92!B96%R8F5I=&5N(BP@=6T@>G4@9&5R(%-E:71E('IU(&=E;&%N
M9V5N+`H@("`@("!A=68@9&5R(%-I92!D:64@3&ES=&4@9&5R($5M86EL861R
M97-S96X@8F5A<F)E:71E;B!K]FYN96XL(&1E<F5N"B`@("`@($YA8VAR:6-H
M=&5N(%-I92!)34U%4B!A;FYE:&UE;B!M]F-H=&5N+@H@("`@/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM;&]G:6XB('-T871E
M/2)U<'1O9&%T92(@;60U/2(S-V0Y,CDW9#%C8V$T-C0S-64S-F(V93,X930U
M9&-D8B(^"B`@("`\=&ET;&4^1FEL=&5R<F5G96QN.B!&:6QT97)N(&)E:2!D
M97(@06YM96QD=6YG/"]T:71L93X*("`@(#QH96%D:6YG/D9I;'1E<G)E9V5L
M;B!B96D@9&5R($%N;65L9'5N9R!A;G=E;F1E;C\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@("`@36%R:VEE<F5N(%-I92!D:65S97,@2^1S=&-H96XL(&9A
M;&QS(&1I92!&:6QT97)R96=E;&X@:6UM97(@86YG97=E;F1E=`H@("`@("!W
M97)D96X@<V]L;&5N+"!W96YN(%-I92!S:6-H(&%N;65L9&5N+@H@("`@/"]P
M87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM9&ES<&QA
M>2(@<W1A=&4](G5P=&]D871E(B!M9#4](F8U869C,S`U-#`R968U,F)A9#$P
M.#DS,V8S9C,S,CDQ(CX*("`@(#QT:71L93Y&:6QT97)R96=E;&XZ($9I;'1E
M<FX@8F5I;2!!:W1U86QI<VEE<F5N/"]T:71L93X*("`@(#QH96%D:6YG/D9I
M;'1E<G)E9V5L;B!A;G=E;F1E;BP@=V5N;B!D97(@4&]S=&5I;F=A;F<@86YG
M97IE:6=T"B`@("`@('=I<F0_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@
M($UA<FMI97)E;B!3:64@9&EE<V5S($OD<W1C:&5N+"!F86QL<R!D:64@1FEL
M=&5R<F5G96QN(&EM;65R(&%N9V5W96YD970*("`@("`@=V5R9&5N('-O;&QE
M;BP@=V5N;B!3:64@<VEC:"!D96X@4&]S=&5I;F=A;F<@*$E.0D]8*2!A;GIE
M:6=E;B!L87-S96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](F9I;'1E<BUA;GDM;6%I;&)O>"(@<W1A=&4](G5P=&]D871E(B!M9#4]
M(C<Q8S4Q93@S.3`Y9CED,&)D-#0P9#(R,#<W,F5E,V,V(CX*("`@(#QT:71L
M93Y&:6QT97)R96=E;&XZ($%L;&4@3W)D;F5R(&9I;'1E<FX\+W1I=&QE/@H@
M("`@/&AE861I;F<^06YW96YD=6YG(&1E<B!&:6QT97)R96=E;&X@:6X@86QL
M96X@3W)D;F5R;C\\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@36%R:VEE
M<F5N(%-I92!D:65S92!!=7-W86AL+"!W96YN(%-I92!D:64@1FEL=&5R<F5G
M96QN(&EN(&%L;&5N($]R9&YE<@H@("`@("!A;G=E;F1E;B!K]FYN96X@;?9C
M:'1E;BX@3F]R;6%L97)W96ES92!W97)D96X@1FEL=&5R<F5G96QN(&YU<B!A
M=68@;F5U90H@("`@("!.86-H<FEC:'1E;B!I;2!0;W-T96EN9V%N9R!A;F=E
M=V5N9&5T+B!796YN(&1I92!%:6YS=&5L;'5N9R!A:W1I=FEE<G0*("`@("`@
M:7-T+"!E<G-C:&5I;G0@:6X@86QL96X@3W)D;F5R;B!E:6X@4WEM8F]L+"!D
M87,@26AN96X@97)L875B="P@9&EE"B`@("`@($9I;'1E<G)E9V5L;B!A=68@
M86QL92!.86-H<FEC:'1E;B!I;B!D:65S96T@3W)D;F5R(&%N>G5W96YD96XN
M($%#2%153D<Z"B`@("`@($9I;'1E<FX@:6X@86YD97)E;B!/<F1N97)N(&%L
M<R!D96T@4&]S=&5I;F=A;F<@:V%N;B!Z=2!S96QT<V%M96X*("`@("`@*'HN
M0BX@:V%N;B!D97(@1FEL=&5R($MO<&EE;B!V;VX@3F%C:')I8VAT96X@:6X@
M9&5M($]R9&YE<B!E<GIE=6=E;BD*("`@("`@=6YD+V]D97(@=6YE<G?\;G-C
M:'1E;B!297-U;'1A=&5N("AZ+D(N(&OV;FYE;B!.86-H<FEC:'1E;B!V97)S
M8VAO8F5N"B`@("`@(&]D97(@9V5L]G-C:'0@=V5R9&5N+"!W96YN(&YE=64@
M1FEL=&5R<F5G96QN(&%N9V5L96=T('=U<F1E;BP@;F%C:&1E;0H@("`@("!D
M:64@3F%C:')I8VAT96X@:6X@9&5N($]R9&YE<B!G96QA;F=T96XI(&;\:')E
M;BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6-O
M;7!O<V4M871T86-H+7!U8FME>2(@<W1A=&4](G5P=&]D871E(B!M9#4](CDW
M-#0V9&)B8C(W-C$V8C1F83,Y8F4X,#%E,3!D9C)D(CX*("`@(#QT:71L93Y0
M1U`Z(-9F9F5N=&QI8VAE;B!38VAL_'-S96P@06YHY&YG96X\+W1I=&QE/@H@
M("`@/&AE861I;F<^UF9F96YT;&EC:&5N(%-C:&S\<W-E;"!!;FCD;F=E;CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!796YN(&1I97-E($5I;G-T96QL
M=6YG(&%K=&EV:65R="!I<W0L('=I<F0@26AR(/9F9F5N=&QI8VAE<@H@("`@
M("!01U`M4V-H;/QS<V5L+"!S;V9E<FX@96EN97(@97AI<W1I97)T+"!A;B!A
M=7-G96AE;F1E($YA8VAR:6-H=&5N"B`@("`@(&=E:.1N9W0N(%-I92!K]FYN
M96X@9&%S(%-T86YD87)D=F5R:&%L=&5N(&EN(&1E;B!01U`M16EN<W1E;&QU
M;F=E;@H@("`@("!F97-T;&5G96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UO<'1I;VXM<V-A;BUB;V1Y(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB-F)A86%D83!D-#9D8S%A8C`Y-#$P.#=F,C,U9C,U.6(B
M/@H@("`@/'1I=&QE/E!'4#H@26T@3F%C:')I8VAT96YI;FAA;'0@4W5C:&5N
M/"]T:71L93X*("`@(#QH96%D:6YG/DEM($YA8VAR:6-H=&5N:6YH86QT(%-U
M8VAE;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!796YN(&1I97-E($5I
M;G-T96QL=6YG(&%K=&EV:65R="!I<W0L('=E<F1E;B!D:64@5&5X=&4@86QL
M97(@3F%C:')I8VAT96X*("`@("`@;F%C:"!01U`M1&%T96X@9'5R8VAS=6-H
M="P@=6YD(&1I97-E(&=E9V5B96YE;F9A;&QS(&%N9V5Z96EG="X@0F5A8VAT
M96X*("`@("`@4VEE+"!D87-S(&1I97,@>G4@96EN97(@5F5R;&%N9W-A;75N
M9R!D97,@4WES=&5M(&;\:')E;B!K86YN+"!W96EL(&IE9&4*("`@("`@96EN
M>F5L;F4@3F%C:')I8VAT(&MO;7!L971T(&YA8V@@9&5N(%!'4"U$871E;B!D
M=7)C:'-U8VAT('=E<F1E;B!M=7-S+@H@("`@/"]P87)A/@H@(#PO96YT<GD^
M"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,M96YC<GEP="(@<W1A=&4]
M(G5P=&]D871E(B!M9#4](C$P,3(Q-#1F-S0Y9C$Y9C5A,C1C968S.#8P,61A
M83<Q(CX*("`@(#QT:71L93Y.975E($YA8VAR:6-H=#H@5F5R<V-H;/QS<V5L
M=6YG<V5I;G-T96QL=6YG96X\+W1I=&QE/@H@("`@/&AE861I;F<^2V5I;F4@
M5F5R<V-H;/QS<V5L=6YG/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@($1I
M92!.86-H<FEC:'0@=VER9"!O:&YE(%9E<G-C:&S\<W-E;'5N9RP@86QS;R!I
M;2!+;&%R=&5X="!V97)S96YD970N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY697)S8VAL_'-S96QN("A01U`I/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("`@($UI="!D:65S97(@16EN<W1E;&QU;F<@=VER9"!D:64@3F%C:')I8VAT
M(&UI="!D96T@]F9F96YT;&EC:&5N"B`@("`@('!E<G/V;FQI8VAE;B!38VAL
M_'-S96P@9&5S($5M<&;D;F=E<G,@<&5R(%!'4"!V97)S8VAL_'-S96QT('5N
M9"!D86YN"B`@("`@('9E<G-E;F1E="X@36ET(&1I97-E<B!%:6YS=&5L;'5N
M9R!K]FYN96X@4VEE(&YU<B!.86-H<FEC:'1E;B!A;B!E:6YZ96QN90H@("`@
M("!097)S;VYE;B!V97)S96YD96XN(%-I92!-W%-314X@9&5N(/9F9F5N=&QI
M8VAE;B!38VAL_'-S96P@9&5S($5M<&;D;F=E<G,*("`@("`@:6X@26AR96T@
M061R97-S8G5C:"!H86)E;BP@=V5N;B!D:65S92!%:6YS=&5L;'5N9R!F=6YK
M=&EO;FEE<F5N"B`@("`@('-O;&PN(%=E;FX@4VEE($9E:&QE<FUE;&1U;F=E
M;B!E<FAA;'1E;BP@;V)W;VAL('-I8V@@9&5R(/9F9F5N=&QI8VAE"B`@("`@
M(%-C:&S\<W-E;"!D97,@16UP9N1N9V5R<R!I;B!):')E;2!!9')E<W-B=6-H
M(&)E9FEN9&5T+"#\8F5R<'+\9F5N(%-I92P*("`@("`@;V(@9&EE($5M86EL
M861R97-S92!I;2`B06XB+49E;&0@9V5N874@;6ET(&1E<B!!9')E<W-E(/QB
M97)E:6YS=&EM;70L"B`@("`@('5N=&5R(&1E<B!D97(@4V-H;/QS<V5L(&=E
M<W!E:6-H97)T(&ES="X@1&EE('9E<G-C:&S\<W-E;'1E;B!$871E;@H@("`@
M("!W97)D96X@86X@9&EE(&%U<V=E:&5N9&4@3F%C:')I8VAT(&%N9V5HY&YG
M="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5N=&5R>F5I8VAN96X@*%!'
M4"D\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@36ET(&1I97-E<B!%:6YS
M=&5L;'5N9R!W:7)D(&1I92!.86-H<FEC:'0@;6ET($EH<F5M('!E<G/V;FQI
M8VAE;@H@("`@("!P<FEV871E;B!38VAL_'-S96P@<&5R(%!'4"!D:6=I=&%L
M('5N=&5R<V-H<FEE8F5N+B!796YN(%-I92!WY&AR96YD(&1E<@H@("`@("!A
M:W1U96QL96X@4VET>G5N9R!):'(@4&%S<W=O<G0@;F]C:"!N:6-H="!A;F=E
M9V5B96X@:&%B96XL('=E<F1E;B!3:64*("`@("`@9&%Z=2!A=69G969O<F1E
M<G0N($1E<B!%;7!FY&YG97(@;75S<R!E:6YE($MO<&EE($EH<F5S(/9F9F5N
M=&QI8VAE;@H@("`@("!38VAL_'-S96QS(&)E<VET>F5N+"!U;2!):')E(%5N
M=&5R<V-H<FEF="#\8F5R<'+\9F5N('IU(&OV;FYE;BX*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/E5N=&5R>F5I8VAN96X@=6YD('9E<G-C:&S\<W-E;&X@
M*%!'4"D\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@36ET(&1I97-E<B!%
M:6YS=&5L;'5N9R!W:7)D(&1I92!.86-H<FEC:'0@97)S="!D:6=I=&%L('5N
M=&5R<V-H<FEE8F5N"B`@("`@('5N9"!D87,@17)G96)N:7,@86YS8VAL:67?
M96YD('9E<G-C:&S\<W-E;'0N(%-I96AE(&1I92!%:6YT<N1G90H@("`@("`B
M5F5R<V-H;/QS<V5L;B`H4$=0*2(@=6YD(")5;G1E<GIE:6-H;F5N("A01U`I
M(B!F_'(@=V5I=&5R90H@("`@("!);F9O<FUA=&EO;F5N+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^5F5R<V-H;/QS<V5L;B`H4R]-24U%*3PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY5;G1E<GIE:6-H;F5N("A3+TU)344I/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("`@(%1/1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5N=&5R
M>F5I8VAN96X@=6YD('9E<G-C:&S\<W-E;&X@*%,O34E-12D\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@5$]$3PH@("`@/"]P87)A/@H@(#PO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<B('-T871E/2)U<'1O9&%T92(@
M;60U/2(R-&(U,3,X8C1B-3-F-S-B-68R9C(W,SEE-&,Q.#4X9"(^"B`@("`\
M=&ET;&4^4$=0.B#<8F5R<VEC:'0\+W1I=&QE/@H@("`@/&AE861I;F<^5V%S
M(&ES="!01U`_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%!'4"!I<W0@
M96EN(%=E<FMZ975G('IU<B!S:6-H97)E;B!+;VUM=6YI:V%T:6]N('5N9"!$
M871E;G-P96EC:&5R=6YG+`H@("`@("!I;G-B97-O;F1E<F4@9OQR(&1E;B!%
M;6%I;'9E<FME:'(@=6YD(&MA;FX@>G5M(%9E<G-C:&S\<W-E;&X@=F]N($1A
M=&5N"B`@("`@('5N9"!Z=7(@17)S=&5L;'5N9R!D:6=I=&%L97(@56YT97)S
M8VAR:69T96X@=F5R=V5N9&5T('=E<F1E;BX@2&EE<B!W:7)D"B`@("`@($=N
M=7!01R`H1TY5(%!R:79A8WD@1W5A<F0I('9E<G=E;F1E="P@=6T@9&EE<V4@
M1G5N:VEO;F5N('IU<B!697)F_&=U;F<*("`@("`@>G4@<W1E;&QE;BX*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"U&=6YK=&EO;F5N(&%K=&EV:65R
M96X_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%=E;FX@9&EE<V4@16EN
M<W1E;&QU;F<@86MT:79I97)T(&ES="P@:_9N;F5N(%-I92!):')E('!E<G/V
M;FQI8VAE;@H@("`@("!01U`M4V-H;/QS<V5L(&5I;G-E:&5N('5N9"!B96%R
M8F5I=&5N+"#V9F9E;G1L:6-H92!38VAL_'-S96P@=F]N(&%N9&5R96X*("`@
M("`@:&EN>G5F_&=E;B!U;F0@;/9S8VAE;BP@=F5R<V-H;/QS<V5L=&4@3F%C
M:')I8VAT96X@;&5S96XL(&1I9VET86P*("`@("`@=6YT97)S8VAR:65B96YE
M($YA8VAR:6-H=&5N(/QB97)P<OQF96X@<V]W:64@875S9V5H96YD92!.86-H
M<FEC:'1E;@H@("`@("!V97)S8VAL_'-S96QN('5N9"]O9&5R(&1I9VET86P@
M=6YT97)S8VAR96EB96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UO<'1I;VXM871T86-H+7!U8FME>2(@<W1A=&4](G5P=&]D
M871E(B!M9#4](C4V,6-E-#,S-S!A8S1A9F)C8S-F.3@Q.&,X9F)C,F8V(CX*
M("`@(#QT:71L93Y01U`Z($5I;G-T96QL=6YG96X@+2#69F9E;G1L:6-H96X@
M4V-H;/QS<V5L(&%N:.1N9V5N/"]T:71L93X*("`@(#QH96%D:6YG/D5I;G-T
M96QL=6YG96X@+2#69F9E;G1L:6-H96X@4V-H;/QS<V5L(&%N:.1N9V5N/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%=E;FX@4VEE(&1I97-E($5I;G-T
M96QL=6YG(&%K=&EV:65R96XL('=I<F0@26AR(/9F9F5N=&QI8VAE<@H@("`@
M("!01U`M4V-H;/QS<V5L+"!S;V9E<FX@96EN97(@97AI<W1I97)T+"!S=&%N
M9&%R9&WDWVEG(&%N(&%L;&4@875S9V5H96YD96X*("`@("`@3F%C:')I8VAT
M96X@86YG96CD;F=T+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P9W`M;6%N86=E+7!U8FME>2(@<W1A=&4](G5P=&]D871E(B!M9#4]
M(F(R.#EE834X,C1B-V8V.68S-6,P-S4Q-#DW9C1E,6,S(CX*("`@(#QT:71L
M93Y01U`Z(-9F9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L8G5N9#PO=&ET;&4^
M"B`@("`\:&5A9&EN9S[<8F5R<VEC:'0\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@("`@26X@9&EE<V5R($QI<W1E(&)E9FEN9&5N('-I8V@@86QL92!097)S
M;VYE;B!A=7,@26AR96T@061R97-S8G5C:"!D:64*("`@("`@4$=0+5-C:&S\
M<W-E;"!B97-I='IE;BX@1&EE<R!S:6YD(&1I92!%24Y:24=%3B!097)S;VYE
M;BP@86X@9&EE(%-I90H@("`@("!E;G1W961E<B!V97)S8VAL_'-S96QT92!.
M86-H<FEC:'1E;B!V97)S96YD96XL(&]D97(@9&5R96X@9&EG:71A;&4*("`@
M("`@56YT97)S8VAR:69T(%-I92#\8F5R<'+\9F5N(&OV;FYE;BX*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D%N>F5I9V5N/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("`@(-9F9FYE="!E:6X@1F5N<W1E<BP@9&%S(&1E;B#V9F9E;G1L
M:6-H96X@4$=0+5-C:&S\<W-E;"!A;GIE:6=T+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!:
M96EG="!E:6YI9V4@1&5T86EL<R!D97,@]F9F96YT;&EC:&5N(%!'4"U38VAL
M_'-S96QS(&%N+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^3/9S8VAE;CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!,]G-C:'0@9&5N(/9F9F5N=&QI
M8VAE;B!01U`M4V-H;/QS<V5L(&%U<R!):')E;2!!9')E<W-B=6-H+@H@("`@
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M:6UP;W)T+7!U
M8FME>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C9E93$Q,S!B-#9E.69F,6-A
M.6%D,V$S830W93=B,S@R(CX*("`@(#QT:71L93Y01U`Z(-9F9F5N=&QI8VAE
M<B!01U`M4V-H;/QS<V5L8G5N9"`M($EM<&]R=&EE<F5N/"]T:71L93X*("`@
M(#QH96%D:6YG/M9F9F5N=&QI8VAE;B!38VAL_'-S96P@:6UP;W)T:65R96X\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@36ET(&1I97-E<B!38VAA;'1F
M;.1C:&4@=VER9"!E:6X@;F5U97,@1F5N<W1E<B!G9?9F9FYE="P@:6X@9&5M
M(%-I90H@("`@("!E:6YE;B#V9F9E;G1L:6-H96X@4$=0+5-C:&S\<W-E;"!I
M;7!O<G1I97)E;B!K]FYN96XN($1E<B!38VAL_'-S96P@:V%N;@H@("`@("!E
M;G1W961E<B!I;B!E:6X@5&5X=&9E;&0@:V]P:65R="!O9&5R(&AO8VAG96QA
M9&5N('=E<F1E;BP@9F%L;',@97(@86QS"B`@("`@($1A=&5I(&%U9B!):')E
M;2!L;VMA;&5N($-O;7!U=&5R('9O<FQI96=T+B!796YN(&5S('-I8V@@=6T@
M96EN96X*("`@("`@9_QL=&EG96X@4V-H;/QS<V5L(&AA;F1E;'0L('=I<F0@
M9&EE<V5R('IU($EH<F5M($%D<F5S<V)U8V@@:&EN>G5G96;\9W0*("`@("`@
M=6YD(&1A<R!&96YS=&5R(&=E<V-H;&]S<V5N+B!!;F1E<F5N9F%L;',@=VER
M9"!E:6YE($9E:&QE<FUE;&1U;F<*("`@("`@86YG97IE:6=T+"!D:64@97)K
M;.1R="P@=V%R=6T@9&5R(%-C:&S\<W-E;"!N:6-H="!I;7!O<G1I97)T('=E
M<F1E;@H@("`@("!K;VYN=&4N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UO=F5R=FEE=RUP97)S;VYA;&ME>2(@<W1A=&4](G5P
M=&]D871E(B!M9#4](C(R,&%F,F(W-&$U.&8T,S!E9F0W,F0V9#9B,68Y.3-F
M(CX*("`@(#QT:71L93Y01U`Z($EH<F4@]F9F96YT;&EC:&5N+W!R:79A=&5N
M(%!'4"U38VAL_'-S96P\+W1I=&QE/@H@("`@/&AE861I;F<^W&)E<F)L:6-K
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%=E;FX@4VEE($YA8VAR:6-H
M=&5N(&1I9VET86P@=6YT97)S8VAR96EB96X@;V1E<B!A;F1E<F5N(&5R;?9G
M;&EC:&5N"B`@("`@(&WV8VAT96XL($EH;F5N('9E<G-C:&S\<W-E;'1E($YA
M8VAR:6-H=&5N('IU('-C:')E:6)E;BP@;?QS<V5N(%-I92!E:6X*("`@("`@
M96EG96YE<R!01U`M4V-H;/QS<V5L<&%A<B!H86)E;BX*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/DEH<B#V9F9E;G1L:6-H97(@4V-H;/QS<V5L/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("`@($EH<B#V9F9E;G1L:6-H97(@4V-H;/QS
M<V5L(&UU<W,@86QL96X@4&5R<V]N96X@>G5GY&YG;&EC:"!G96UA8VAT"B`@
M("`@('=E<F1E;BP@9&EE($EH;F5N('9E<G-C:&S\<W-E;'1E($YA8VAR:6-H
M=&5N('-C:&EC:V5N(&WV8VAT96XL(&1I92!N=7(*("`@("`@4TE%("AM:70@
M26AR96T@<')I=F%T96X@4V-H;/QS<V5L*2!E;G1S8VAL_'-S96QN(&OV;FYE
M;BX@6G5SY'1Z;&EC:`H@("`@("!B96[V=&EG="!J961E<BP@9&5M(%-I92!E
M:6YE(&1I9VET86P@=6YT97)S8VAR:65B96YE($YA8VAR:6-H="!S8VAI8VME
M;BP*("`@("`@26AR96X@]F9F96YT;&EC:&5N(%-C:&S\<W-E;"P@=6T@26AR
M92!D:6=I=&%L92!5;G1E<G-C:')I9G0@_&)E<G!R_&9E;@H@("`@("!Z=2!K
M]FYN96XN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY):'(@<')I=F%T97(@
M4V-H;/QS<V5L/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@($EH<B!P<FEV
M871E<B!38VAL_'-S96P@:7-T(&[V=&EG+"!U;2!.86-H<FEC:'1E;B!E;G1S
M8VAL_'-S96QN('IU"B`@("`@(&OV;FYE;BP@9&EE(&UI="!):')E;2#V9F9E
M;G1L:6-H96X@4V-H;/QS<V5L('9E<G-C:&S\<W-E;'0*("`@("`@=W5R9&5N
M+B!!==]E<F1E;2!B96[V=&EG96X@4VEE($EH<F5N('!R:79A=&5N(%-C:&S\
M<W-E;"P@=6T@3F%C:')I8VAT96X*("`@("`@9&EG:71A;"!Z=2!U;G1E<G-C
M:')E:6)E;BX@26AR('!R:79A=&5R(%-C:&S\<W-E;"!I<W0@;6ET(&5I;F5M
M(%!A<W-W;W)T"B`@("`@(&=E<V-H_'1Z="P@9&%S(%-I92!B96EM($5R>F5U
M9V5N($EH<F5S(%-C:&S\<W-E;'!A87)E<R!A;F=E9V5B96X*("`@("`@:&%B
M96XN($1A:&5R(&ES="!D:65S97,@4&%S<W=O<G0@8F5I(&IE9&5R($%K=&EO
M;B!N]G1I9RP@9&EE($EH<F5N"B`@("`@('!R:79A=&5N(%-C:&S\<W-E;"!V
M97)W96YD970N(%-I92!M_'-S96X@9&%S(%!A<W-W;W)T(&%L;&5R9&EN9W,@
M;G5R"B`@("`@(&5I;FUA;"!P<F\@4VET>G5N9R!A;F=E8F5N+"!D82!E<R!B
M:7,@>G5M($%B;65L9&5N(&=E<W!E:6-H97)T"B`@("`@(&)L96EB="X@06QS
M;R!!8FUE;&1E;B!N:6-H="!V97)G97-S96XA"B`@("`\+W!A<F$^"B`@/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP=6)L:6,B('-T
M871E/2)U<'1O9&%T92(@;60U/2(S8S@T-&0T9F8X9F1D83-E,&0T-#9B-#=A
M-C,Q,3=E,"(^"B`@("`\=&ET;&4^4$=0.B!):')E(/9F9F5N=&QI8VAE;B]P
M<FEV871E;B!01U`M4V-H;/QS<V5L("T@UF9F96YT;&EC:&5R"B`@("!38VAL
M_'-S96P\+W1I=&QE/@H@("`@/&AE861I;F<^06YZ96EG96X\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@UF9F;F5T(&5I;B!&96YS=&5R+"!I;B!D96T@
M26AR92#V9F9E;G1L:6-H96X@4$=0+41A=&5N(&%N9V5Z96EG="!W97)D96XN
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("`@(%IE:6=T(&5I;FEG92!$971A:6QS('IU($EH<F5M
M(/9F9F5N=&QI8VAE;B!01U`M4V-H;/QS<V5L(&%N+@H@("`@/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T
M92(@<W1A=&4](G5P=&]D871E(B!M9#4](C$X-3%B-C=A,6%E968Q,C0R9F,S
M83)B.31A9C<U8S`S(CX*("`@(#QT:71L93Y01U`Z($EH<F4@]F9F96YT;&EC
M:&5N+W!R:79A=&5N(%!'4"U38VAL_'-S96P@+2!0<FEV871E<@H@("`@4V-H
M;/QS<V5L/"]T:71L93X*("`@(#QH96%D:6YG/E!A<W-W;W)T(&5I;F=E8F5N
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(-9F9FYE="!E:6X@1&EA;&]G
M9F5N<W1E<BP@:6X@9&5M(%-I92!):'(@4&%S<W=O<G0@96EN9V5B96X@:_9N
M;F5N+B!796YN"B`@("`@(&1A<R!087-S=V]R="!K;W)R96MT(&ES="P@=VER
M9"!E<R!I;B!):')E<B!3:71Z=6YG(&=E<W!E:6-H97)T+"!B:7,@4VEE"B`@
M("`@('-I8V@@=VEE9&5R(&%B;65L9&5N+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^4&%S<W=O<G0@(G9E<F=E<W-E;B(\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@("`@16YT9F5R;G0@9&%S(&=E<W!E:6-H97)T92!087-S=V]R="P@
M<V\@9&%S<R!3:64@97,@97)N975T(&5I;F=E8F5N"B`@("`@(&W\<W-E;BP@
M=V5N;B!3:64@26AR96X@<')I=F%T96X@4V-H;/QS<V5L(&)E;G5T>F5N(&WV
M8VAT96XN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY!;GIE:6=E;CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("#69F9N970@96EN($9E;G-T97(L(&EN
M(&1E;2!):')E('!R:79A=&5N(%!'4"U$871E;B!A;F=E>F5I9W0*("`@("`@
M=V5R9&5N+B!'14)%3B!3244@1$E%4T5.(%-#2$S<4U-%3"!!3B!.245-04Y$
M14X@5T5)5$52("T@9&EE<V4@1G5N:W1I;VX*("`@("`@9&EE;G0@875S<V-H
M;&EEWVQI8V@@9&%Z=2P@26AR96X@<')I=F%T96X@4V-H;/QS<V5L('IU(&5X
M<&]R=&EE<F5N+`H@("`@("!D86UI="!3:64@9&EE<V5N(&EN(&5I;F5M(&%N
M9&5R96X@4')O9W)A;6T@=F5R=V5N9&5N(&OV;FYE;BX*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M("`@6F5I9W0@96EN:6=E($1E=&%I;',@>G4@26AR96T@<')I=F%T96X@4$=0
M+5-C:&S\<W-E;"!A;BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(@<W1A=&4](G5P=&]D871E
M(B!M9#4](F1B9#AC8F4V8F-E-S%C-&9B-3DR9&0Q8C-B,C=B-V-E(CX*("`@
M(#QT:71L93Y01U`Z($EH<F4@]F9F96YT;&EC:&5N+W!R:79A=&5N(%!'4"U3
M8VAL_'-S96P@+2!,]G-C:&5N/"]T:71L93X*("`@(#QH96%D:6YG/D%K='5E
M;&QE;B!38VAL_'-S96P@;/9S8VAE;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@("!(:65R;6ET(&OV;FYE;B!3:64@26AR('!E<G/V;FQI8VAE<R!38VAL
M_'-S96QP86%R(&%U<R!D96X@16EN<W1E;&QU;F=E;@H@("`@("!L]G-C:&5N
M+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R
M<V]N86QK97DM8W)E871E+6YA;64B('-T871E/2)U<'1O9&%T92(@;60U/2(W
M-#AC8C$R-&(W9F8U,C@R,#<Y,F4R-S@P,S=A.&,R-R(^"B`@("`\=&ET;&4^
M4$=0.B!097)S]FYL:6-H96X@4V-H;/QS<V5L(&5R<W1E;&QE;B`M($EH<B!.
M86UE/"]T:71L93X*("`@(#QH96%D:6YG/DEH<B!.86UE/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("`@($1E<B!.86UE+"!D97(@:6X@26AR96T@<&5R<_9N
M;&EC:&5N(%-C:&S\<W-E;"!V97)W96YD970@=V5R9&5N('-O;&PN($5I;@H@
M("`@("!09FQI8VAT9F5L9"X*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UC;VUM96YT(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB938V-F5B.68P964T8C0Y9F4P-&8W-&9C,3AD
M8C@V-#`B/@H@("`@/'1I=&QE/E!'4#H@4&5R<_9N;&EC:&5N(%-C:&S\<W-E
M;"!E<G-T96QL96X@+2!+;VUM96YT87(\+W1I=&QE/@H@("`@/&AE861I;F<^
M2V]M;65N=&%R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@($5I;B!+;VUM
M96YT87)T97AT+"!D96X@4VEE(&EN($EH<F5N('!E<G/V;FQI8VAE;B!38VAL
M_'-S96P@:6YT96=R:65R96X*("`@("`@:_9N;F5N+B!%:6X@9G)E:7=I;&QI
M9V5S($9E;&0N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M96UA:6PB('-T871E/2)U<'1O9&%T
M92(@;60U/2)C-S(Y9C<P9F1B,V$W,V-B8C=B835E9C4X.#AE,S`Y,B(^"B`@
M("`\=&ET;&4^4$=0.B!097)S]FYL:6-H96X@4V-H;/QS<V5L(&5R<W1E;&QE
M;B`M($5M86EL861R97-S93PO=&ET;&4^"B`@("`\:&5A9&EN9SY%;6%I;&%D
M<F5S<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@1&EE($5M86EL861R
M97-S92P@9&EE($EH<F5M('!E<G/V;FQI8VAE;B!38VAL_'-S96P@>G5G96]R
M9&YE="!S96EN"B`@("`@('-O;&PN($5I;B!09FQI8VAT9F5L9"X*("`@(#PO
M<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y
M+6-R96%T92UK97EL96YG=&@B('-T871E/2)U<'1O9&%T92(@;60U/2(R-&-A
M-C0Q8S8S9F(U9F8S,3!A,SEE93!D,V(Q964U-2(^"B`@("`\=&ET;&4^4$=0
M.B!097)S]FYL:6-H96X@4V-H;/QS<V5L(&5R<W1E;&QE;B`M(%-C:&S\<W-E
M;&SD;F=E/"]T:71L93X*("`@(#QH96%D:6YG/E-C:&S\<W-E;&SD;F=E/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("`@($1I92!38VAL_'-S96QLY&YG92!)
M:')E<R!Z=2!E<G-T96QL96YD96X@4V-H;/QS<V5L(&EN($)I="X@2F4@9W+V
MWV5R"B`@("`@(&1E<B!797)T+"!D97-T;R!S=.1R:V5R(&ES="!):'(@4V-H
M;/QS<V5L(&=E<V-H_'1Z="P@86)E<B!D97-T;R!LY&YG97(*("`@("`@9&%U
M97)T(&%U8V@@9&EE(%-C:&S\<W-E;&5R<W1E;&QU;F<@=6YD('-PY'1E<B!D
M87,@5F5R<V-H;/QS<V5L;BX@,3`R-`H@("`@("!":70@<VEN9"!D:64@4W1A
M;F1A<F1E:6YS=&5L;'5N9R!U;F0@8FEE=&5N(&5I;F5N(&AE<G9O<G)A9V5N
M9&5N"B`@("`@(%-C:'5T>BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UP87-S<&AR87-E(B!S
M=&%T93TB=7!T;V1A=&4B(&UD-3TB,F9B.3,W,CDW,&)F,S-F-3%E.3@X8F$S
M.61B9#<Q.3,B/@H@("`@/'1I=&QE/E!'4#H@4&5R<_9N;&EC:&5N(%-C:&S\
M<W-E;"!E<G-T96QL96X@+2!087-S=V]R=#PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY087-S=V]R=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!$87,@4&%S
M<W=O<G0L(&UI="!D96T@26AR('!E<G/V;FQI8VAE<B!P<FEV871E<B!38VAL
M_'-S96P@=F5R<V-H;/QS<V5L=`H@("`@("!U;F0@9&%M:70@9V5S8VC\='IT
M('=I<F0N($5S('-O;&QT92!-24Y$15-414Y3(#8@6F5I8VAE;B!L86YG('5N
M9"!.24-(5`H@("`@("!D87,@9VQE:6-H92!W:64@26AR(%!A<W-W;W)T('IU
M<B!!;FUE;&1U;F<@<V5I;BP@<V]L;'1E($M%24X@96-H=&5S(%=O<G0*("`@
M("`@<V5I;B!U;F0@<V]W;VAL(%IA:&QE;B!A;',@875C:"!"=6-H<W1A8F5N
M(&5N=&AA;'1E;BX@4VEE(&W\<W-E;B!D87,*("`@("`@4&%S<W=O<G0@>G5R
M(%9O<G-I8VAT('IW96EM86P@86YG96)E;BX@16EN(%!F;&EC:'1F96QD+@H@
M("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N
M86QK97DM8W)E871E+6%C=&EO;G,B('-T871E/2)U<'1O9&%T92(@;60U/2(P
M9C@R,S0Y,S5B.38T8S@S-3,S8C1E8S1C,35E8C<Q,B(^"B`@("`\=&ET;&4^
M4$=0.B!097)S]FYL:6-H96X@4V-H;/QS<V5L(&5R<W1E;&QE;B`M($%K=&EO
M;F5N/"]T:71L93X*("`@(#QH96%D:6YG/E-C:&S\<W-E;"!E<G-T96QL96X\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@17)Z975G="!U;F0@<W!E:6-H
M97)T($EH<B!P97)S]FYL:6-H97,@4V-H;/QS<V5L<&%A<BX*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/E-C:&S\<W-E;'!A87(@:6UP;W)T:65R96X\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@("`@26UP;W)T:65R="!E:6X@<&5R<_9N
M;&EC:&5S(%-C:&S\<W-E;'!A87(N($1I97-E<B!+;F]P9B#V9F9N970@96EN
M"B`@("`@($9E;G-T97(L(&EN(&1E;2!3:64@96EN(&)E<F5I=',@=F]R:&%N
M9&5N97,@<&5R<_9N;&EC:&5S(%-C:&S\<W-E;'!A87(*("`@("`@:6UP;W)T
M:65R96X@:_9N;F5N+B!$:64@4V-H;/QS<V5L(&OV;FYE;B!E;G1W961E<B!I
M;B!E:6X@5&5X=&9E;&0*("`@("`@:6UP;W)T:65R="!O9&5R(&AO8VAG96QA
M9&5N('=E<F1E;BP@9F%L;',@9&EE<V4@86QS($1A=&5I(&%U9B!):')E;0H@
M("`@("!L;VMA;&5N($-O;7!U=&5R('9O<FQI96=E;BX@5V5N;B!E<R!S:6-H
M('5M(&?\;'1I9V4@4V-H;/QS<V5L(&AA;F1E;'0L"B`@("`@('=E<F1E;B!D
M:65S92!I;B!):')E;B!%:6YS=&5L;'5N9V5N(&=E<W!E:6-H97)T('5N9"!D
M87,@1F5N<W1E<@H@("`@("!G97-C:&QO<W-E;BX@06YD97)E;F9A;&QS('=I
M<F0@96EN92!&96AL97)M96QD=6YG(&%N9V5Z96EG="P@9&EE"B`@("`@(&5R
M;.1U=&5R="P@=V%R=6T@9&5R($EM<&]R="!N:6-H="!G96ML87!P="!H870N
M"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6]V
M97)V:65W(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB9#-C-S4R8C$S-#5F8C)E
M8V-F934W-6,P-S0V,3DV,V8B/@H@("`@/'1I=&QE/E,O34E-13H@W&)E<F)L
M:6-K/"]T:71L93X*("`@(#QH96%D:6YG/E=A<R!I<W0@4R]-24U%/SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("!3+TU)344@:7-T(&5I;B!38VAL_'-S
M96QP86%R+5-Y<W1E;2P@9&%S(&1I9VET86QE(%5N=&5R<V-H<FEF=&5N+`H@
M("`@("!V97)S8VAL_'-S96QT92!.86-H<FEC:'1E;B!U;F0@9&EE($5N=&1E
M8VMU;F<@=F]N($UA;FEP=6QA=&EO;F5N(&%U9@H@("`@("!O9F9E;F4@=6YD
M(&EN=&5R;W!E<F%B;&4@5V5I<V4@=6YT97)S=/QT>G0N(%,O34E-12!E<FQA
M=6)T(&=E<V-H_'1Z=&4*("`@("`@2V]M;75N:6MA=&EO;BP@:6YD96T@3F%C
M:')I8VAT96X@<V\@=F5R<V-H;/QS<V5L="!W97)D96XL(&1A<W,@9&EE<V4@
M;G5R"B`@("`@('9O;2!!8G-E;F1E<B!U;F0@9&5N($5M<&;D;F=E<FX@9V5L
M97-E;B!W97)D96X@:_9N;F5N+B!!==]E<F1E;2!K86YN(&1I90H@("`@("!)
M9&5N=&ETY'0@96EN97,@06)S96YD97)S(&%N:&%N9"!E:6YE<B!D:6=I=&%L
M96X@56YT97)S8VAR:69T(/QB97)P<OQF=`H@("`@("!W97)D96XN($)E:61E
M<R!Z=7-A;6UE;B!H:6QF="!B96D@9&5R($5N9&5C:W5N9R!V;VX@36%N:7!U
M;&%T:6]N96X@=6YD"B`@("`@(&5R;&%U8G0@9&5N($5M<&;D;F=E<FX@9F5S
M='IU<W1E;&QE;BP@;V(@9&EE($YA8VAR:6-H="!N86-H(&1E;0H@("`@("!6
M97)S96YD96X@=F5RY&YD97)T('=U<F1E+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^4R]-24U%+49U;FMT:6]N96X@86MT:79I97)E;C\\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@5V5N;B!D:65S92!%:6YS=&5L;'5N9R!A:W1I
M=FEE<G0@:7-T+"!K]FYN96X@4VEE($EH<F4@<&5R<_9N;&EC:&5N"B`@("`@
M(%,O34E-12U38VAL_'-S96P@:6UP;W)T:65R96XL('9E<G-C:&S\<W-E;'1E
M($YA8VAR:6-H=&5N(&QE<V5N+"!D:6=I=&%L"B`@("`@('5N=&5R<V-H<FEE
M8F5N92!.86-H<FEC:'1E;B#\8F5R<'+\9F5N('-O=VEE(&%U<V=E:&5N9&4@
M3F%C:')I8VAT96X*("`@("`@=F5R<V-H;/QS<V5L;B!U;F0O;V1E<B!D:6=I
M=&%L('5N=&5R<V-H<F5I8F5N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@
M/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=RUP97)S;VYA;&ME>2(@<W1A=&4]
M(G5P=&]D871E(B!M9#4](CEF-&8S-F%E-S)C8C1A8F,W,S$P-C=D,S,X8F4S
M8CDX(CX*("`@(#QT:71L93Y3+TU)344Z($EH<F4@]F9F96YT;&EC:&5N+W!R
M:79A=&5N(%,O34E-12U:97)T:69I:V%T93PO=&ET;&4^"B`@("`\:&5A9&EN
M9S[<8F5R8FQI8VL\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@5V5N;B!3
M:64@3F%C:')I8VAT96X@9&EG:71A;"!U;G1E<G-C:')E:6)E;B!O9&5R(&%N
M9&5R96X@97)M]F=L:6-H96X*("`@("`@;?9C:'1E;BP@26AN96X@=F5R<V-H
M;/QS<V5L=&4@3F%C:')I8VAT96X@>G4@<V-H<F5I8F5N+"!M_'-S96X@4VEE
M(&5I;@H@("`@("!E:6=E;F5S(%,O34E-12U38VAL_'-S96QP86%R(&AA8F5N
M+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UI
M;7!O<G0M<&5R<V]N86PM8V5R=',B('-T871E/2)U<'1O9&%T92(@;60U/2)C
M9C!E9#)E,V4R-&0S,&1E9&8X8V9E9C)C,C8T-3<U.2(^"B`@("`\=&ET;&4^
M4R]-24U%.B!097)S]FYL:6-H92!:97)T:69I:V%T92!I;7!O<G1I97)E;CPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY097)S]FYL:6-H92!:97)T:69I:V%T92!I
M;7!O<G1I97)E;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!(:65R;6ET
M(&OV;FYE;B!3:64@<&5R<_9N;&EC:&4@6F5R=&EF:6MA=&4@:6UP;W)T:65R
M96XL(&1I92!I;B!E:6YE<@H@("`@("!$871E:2!I;2!02T-3(",Q,BU&;W)M
M870@=F]R;&EE9V5N+B!02T-3(",Q,BU$871E:65N('-I;F0@9&EE($1A=&5I
M96XL"B`@("`@(&1I92!N;W)M86QE<G=E:7-E('9E<G=E;F1E="!W97)D96XL
M('=E;FX@4VEE(&5I;F5N(%-C:&S\<W-E;"!A=7,@96EN96T*("`@("`@0G)O
M=W-E<B`H>BY"+B!);G1E<FYE="!%>'!L;W)E<B!O9&5R($9I<F5F;W@I+"!O
M9&5R(&1E;0H@("`@("!:97)T:69I:V%T<W!E:6-H97(@9&5S($)E=')I96)S
M<WES=&5M<R`H>BY"+B!7:6YD;W=S(%A0*0H@("`@("!E>'!O<G1I97)E;BX@
M5V5N;B!E<R!S:6-H('5M(&?\;'1I9V4@4V-H;/QS<V5L(&AA;F1E;'0L('=E
M<F1E;B!D:65S92!I;@H@("`@("!):')E;B!%:6YS=&5L;'5N9V5N(&=E<W!E
M:6-H97)T('5N9"!D87,@1F5N<W1E<@H@("`@("!G97-C:&QO<W-E;BX@06YD
M97)E;F9A;&QS('=I<F0@96EN92!&96AL97)M96QD=6YG(&%N9V5Z96EG="P@
M9&EE"B`@("`@(&5R;.1U=&5R="P@=V%R=6T@9&5R($EM<&]R="!N:6-H="!G
M96ML87!P="!H870N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](G-M:6UE+61E;&5T92UP97)S;VYA;"UC97)T<R(@<W1A=&4](G5P=&]D
M871E(B!M9#4](C`Q.&)B-F(V,6$W930Q-C@Y,F1E,C@X860Q8S@X,&8T(CX*
M("`@(#QT:71L93Y3+TU)344Z(%!E<G/V;FQI8VAE(%IE<G1I9FEK871E(&SV
M<V-H96X\+W1I=&QE/@H@("`@/&AE861I;F<^4&5R<_9N;&EC:&4@6F5R=&EF
M:6MA=&4@;/9S8VAE;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!,]G-C
M:'0@26AR92!P97)S]FYL:6-H96X@6F5R=&EF:6MA=&4@875S($EH<F5N($5I
M;G-T96QL=6YG96XN($1A;F%C:`H@("`@("!K]FYN96X@4VEE(&ME:6YE($YA
M8VAR:6-H=&5N(&UE:'(@;6ET(%,O34E-12!U;G1E<G-C:')E:6)E;B!O9&5R
M(&%N(%-I90H@("`@("!G97)I8VAT971E('5N9"!M:70@4R]-24U%('9E<G-C
M:&S\<W-E;'1E($YA8VAR:6-H=&5N(&QE<V5N+@H@("`@/"]P87)A/@H@(#PO
M96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB.&(V8S8S-C@T9#-D-S-B,V0P.#0P,C5A-SAF
M93=E.#@B/@H@("`@/'1I=&QE/E,O34E-13H@UF9F96YT;&EC:&5R(%,O34E-
M12U38VAL_'-S96QB=6YD/"]T:71L93X*("`@(#QH96%D:6YG/E,O34E-13H@
MUF9F96YT;&EC:&5R(%,O34E-12U38VAL_'-S96QB=6YD/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("`@($AI97)M:70@:_9N;F5N(%-I92!):')E($QI<W1E
M(/9F9F5N=&QI8VAE<B!3+TU)344M4V-H;/QS<V5L('9E<G=A;'1E;BX*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D%N>F5I9V5N/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("`@(-9F9FYE="!E:6X@1F5N<W1E<BP@9&%S(&1E;B#V9F9E
M;G1L:6-H96X@4R]-24U%+5-C:&S\<W-E;"!I;B!2;VAF;W)M"B`@("`@(&%N
M>F5I9W0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("`@(%IE:6=T(&5I;FEG92!T96-H;FES8VAE
M($1E=&%I;',@9&5S(/9F9F5N=&QI8VAE;B!3+TU)344M4V-H;/QS<V5L<R!A
M;BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DSV<V-H96X\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@3/9S8VAT(&1E;B#V9F9E;G1L:6-H96X@4R]-
M24U%+5-C:&S\<W-E;"!A=7,@26AR96T@061R97-S8G5C:"X@1&%N86-H"B`@
M("`@(&OV;FYE;B!3:64@:V5I;F4@=F5R<V-H;/QS<V5L=&4@3F%C:')I8VAT
M(&UE:'(@86X@9&EE<V4@4&5R<V]N"B`@("`@('-C:')E:6)E;BX*("`@(#PO
M<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')I;G1I;F<B('-T871E
M/2)U<'1O9&%T92(@;60U/2)F,C,S8S$Q8C9B-&$V8F5D96(V.&8Q9#5A,F$Y
M-S9D8B(^"B`@("`\=&ET;&4^1')U8VME;CPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY$<G5C:V5N(&5I;F5R($YA8VAR:6-H=#PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@("!5;2!D:64@3F%C:')I8VAT+"!D:64@4VEE('-I8V@@9V5R861E
M(&%N<V-H875E;BP@875S>G5D<G5C:V5N+"!K;&EC:V5N"B`@("`@(%-I92!A
M=68@9&5N(")$<G5C:V5N(BU,:6YK(&]B97(M(&]D97(@=6YT97)H86QB(&1E
M<B!.86-H<FEC:'0N($1A;6ET"B`@("`@(/9F9FYE;B!3:64@96EN(&YE=65S
M($9E;G-T97(L(&EN(&1E;2!D:64@3F%C:')I8VAT+"!S<&5Z:65L;"!F_'(@
M9&5N"B`@("`@($%U<V1R=6-K(&9O<FUA=&EE<G0L(&%N9V5Z96EG="!W:7)D
M+B!*92!N86-H('9E<G=E;F1E=&5N($)R;W=S97(@=6YD"B`@("`@($)E=')I
M96)S<WES=&5M(/9F9FYE="!S:6-H(&%U8V@@9VQE:6-H(&1E<B!$<G5C:V1I
M86QO9RX@1F%L;',@;FEC:'0L"B`@("`@(')U9F5N(%-I92!D:64@1')U8VMF
M=6YK=&EO;B!):')E<R!"<F]W<V5R<R#\8F5R(&1A<R!-96[\"B`@("`@(")$
M871E:2(M)F=T.R)$<G5C:V5N(B!A=68N"B`@("`\+W!A<F$^"B`@/"]E;G1R
M>3X*("`\96YT<GD@:60](G-O<G1I;F<B('-T871E/2)U<'1O9&%T92(@;60U
M/2(Q.&-D96%C,S@P,C=F935C-#)B86(V.3-F,F$T,C8P82(^"B`@("`\=&ET
M;&4^4V]R=&EE<F5N('5N9"!4:&5M96X\+W1I=&QE/@H@("`@/&AE861I;F<^
M3F%C:')I8VAT96X@4V]R=&EE<F5N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("`@(%-I92!K]FYN96X@3F%C:')I8VAT96YL:7-T96X@;F%C:"!E:6YE<B!B
M96QI96)I9V5N(%-P86QT92!S;W)T:65R96XL"B`@("`@(&EN9&5M(%-I92!A
M=68@9&EE(&5N='-P<F5C:&5N9&4@4W!A;'1E;OQB97)S8VAR:69T(&ML:6-K
M96XN(%5M(&1I90H@("`@("!3;W)T:65R<FEC:'1U;F<@>G4@Y&YD97)N(&ML
M:6-K96X@4VEE(&5R;F5U="!A=68@9&EE(-QB97)S8VAR:69T(&]D97(*("`@
M("`@875F(&1A<R!K;&5I;F4@4&9E:6QS>6UB;VP@9&%N96)E;BX*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/E1H96UE;CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@("!5;2!.86-H<FEC:'1E;B!N86-H(%1H96UE;B`H0F5T<F5F9G,I
M('IU('-O<G1I97)E;BP@<V\@9&%S<R!E:6YE"B`@("`@($YA8VAR:6-H="!Z
M=7-A;6UE;B!M:70@86QL96X@06YT=V]R=&5N(&1A<F%U9B!G<G5P<&EE<G0@
M=VER9"P@:VQI8VME;@H@("`@("!3:64@875F(&1E;B!;5&AE;6%=+4QI;FL@
M:6X@9&5R(-QB97)S8VAR:69T(&1E<B!"971R969F<W!A;'1E+B!5;2!Z=7(*
M("`@("`@;F]R;6%L96X@0F5T<F5F9G-O<G1I97)U;F<@>G5R_&-K>G5K96AR
M96XL(&OV;FYE;B!S:64@875F(&1E;@H@("`@("!;0F5T<F5F9ETM3&EN:R!I
M;B!D97(@W&)E<G-C:')I9G0@9&5R($)E=')E9F9S<&%L=&4@:VQI8VME;BX*
M("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB86QT97)N871I
M=F4M;7-G(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-#DW.#`W,V8W-CDW-V(V
M868V8C8Y.#$P931D,C)A-C4B/@H@("`@/'1I=&QE/DUU;'1I<&%R="]!;'1E
M<FYA=&EV92!.86-H<FEC:'1E;CPO=&ET;&4^"B`@("`\<&%R83X*("`@("`@
M16EN:6=E($YA8VAR:6-H=&5N('=E<F1E;B!I;2`B;75L=&EP87)T+V%L=&5R
M;F%T:79E(B!&;W)M870*("`@("`@=F5R<V-H:6-K="X@1&EE<V4@3F%C:')I
M8VAT96X@96YT:&%L=&5N(&UE:')E<F4@5&5I;&4L(&1I92!A;&QE(&1E;@H@
M("`@("!'3$5)0TA%3B!)3DA!3%0L(&%B97(@:6X@54Y415)30TA)141,24-(
M14X@1D]234%414X@86YZ96EG96XN($1I97-E<PH@("`@("!0<F]G<F%M;2!Z
M96EG="!D96X@;&5T>G1E;B!D:65S97(@5&5I;&4@86XL(&1E<B!K;W)R96MT
M(&EM($)R;W=S97(*("`@("`@9&%R9V5S=&5L;'0@=V5R9&5N(&MA;FXN($%L
M;&4@86YD97)E;B!&;W)M871E('=E<F1E;B!U;G1E<B!D97(*("`@("`@W&)E
M<G-C:')I9G0@(D%L=&5R;F%T:79E($YA8VAR:6-H=&5N=&5I;&4B(&%U9F=E
M;&ES=&5T('5N9"!K]FYN96X*("`@("`@<V5P87)A="!B971R86-H=&5T(&]D
M97(@:&5R=6YT97)G96QA9&5N('=E<F1E;BX@0F5A8VAT96X@4VEE+"!D87-S
M(&1I97-E"B`@("`@(&%L=&5R;F%T:79E;B!.86-H<FEC:'1E;G1E:6QE(&1E
M;B!'3$5)0TA%3B!)3DA!3%0@=VEE(&1E<B!A;F=E>F5I9W1E"B`@("`@(%1E
M:6P@96YT:&%L=&5N+"!N=7(@:6X@96EN96T@86YD97)E;B!&;W)M870L('HN
M0BX@86QS(%1E>'0@86X@4W1E;&QE('9O;@H@("`@("!(5$U,+@H@("`@/"]P
M87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUR96YA;65?<V5N
M=&UA:6Q?;6]N=&AL>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C4S,&9A,C!E
M,&%F8F,R-69F9#0P.#<W.30X.#,R.#DY(CX*("`@(#QT:71L93Y%:6YS=&5L
M;'5N9V5N.B!!;FUE;&1E875F9V%B96XZ($]R9&YE<B!F_'(@9V5S96YD971E
M($YA8VAR:6-H=&5N(&%M"B`@("!-;VYA='-B96=I;FX@=6UB96YE;FYE;CPO
M=&ET;&4^"B`@("`\<&%R83X*("`@("`@06MT:79I97)E;B!3:64@9&EE<V4@
M16EN<W1E;&QU;F<L('=E;FX@4VEE(&WV8VAT96XL(&1A<W,@26AR92!/<F1E
M<B!F_'(*("`@("`@9V5S96YD971E($YA8VAR:6-H=&5N('IU;2!-;VYA='-B
M96=I;FX@=6UB96YA;FYT('=E<F1E;BX@1&EE($]R9&YE<@H@("`@("!W97)D
M96X@=6UB96YA;FYT(&EN(&5I;F5N($]R9&YE<FYA;65N+"!D97(@9&5N($UO
M;F%T('5N9"!D87,@2F%H<@H@("`@("!E;G1HY&QT+"!U;F0@;F5U92!/<F1N
M97(@9OQR(&=E<V5N9&5T92!.86-H<FEC:'1E;B!W97)D96X@86YG96QE9W0N
M"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E
M;&5T95]S96YT;6%I;%]M;VYT:&QY(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M,&)E960Q-F1F9#8X93)F,C5E,&,V-C@W,69D-30V9&8B/@H@("`@/'1I=&QE
M/D5I;G-T96QL=6YG96XZ($%N;65L9&5A=69G86)E;CH@06QT92!/<F1N97(@
M9OQR(&=E<V5N9&5T90H@("`@3F%C:')I8VAT96X@86T@36]N871S8F5G:6YN
M(&SV<V-H96X\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@($%K=&EV:65R96X@
M4VEE(&1I97-E($5I;G-T96QL=6YG+"!W96YN(%-I92!M]F-H=&5N+"!D87-S
M(&%L=&4@3W)D;F5R(&;\<@H@("`@("!G97-E;F1E=&4@3F%C:')I8VAT96X@
M>G5M($UO;F%T<V)E9VEN;B!G96SV<V-H="!W97)D96XN($1I97,@:V%N;B!Z
M=6T*("`@("`@0F5I<W!I96P@;OQT>FQI8V@@<V5I;BP@=V5N;B!3:64@96EN
M(%-P96EC:&5R<&QA='HM2V]N=&EN9V5N="!H86)E;BP@9&%S"B`@("`@(&YI
M8VAT(/QB97)S8VAR:71T96X@=V5R9&5N(&1A<F8N"B`@("`\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]S96YT;6%I;%]M
M;VYT:&QY7VME97`B('-T871E/2)U<'1O9&%T92(@;60U/2(W,65D,6,R96%B
M-#AB.3%A,C5B-6)C9#1B,31C8V5A.2(^"B`@("`\=&ET;&4^16EN<W1E;&QU
M;F=E;CH@06YM96QD96%U9F=A8F5N.B!!;GIA:&P@9&5R($]R9&YE<B!F_'(@
M9V5S96YD971E"B`@("!.86-H<FEC:'1E;BP@9&EE(&)E:2!M;VYA=&QI8VAE
M<B!,]G-C:'5N9R!B96AA;'1E;B!W97)D96X@<V]L;&5N/"]T:71L93X*("`@
M(#QP87)A/@H@("`@("!796YN(%-I92!A;'1E($]R9&YE<B!F_'(@9V5S96YD
M971E($YA8VAR:6-H=&5N(&UO;F%T;&EC:"!L]G-C:&5N+"!W:64*("`@("`@
M=FEE;&4@36]N871E(&%N(&%L=&5N($]R9&YE<FX@;?9C:'1E;B!3:64@8F5H
M86QT96X_($%L;&4@3W)D;F5R(.1L=&5R"B`@("`@(&%L<R!D:64@86YG96=E
M8F5N96X@36]N871E('=E<F1E;B!G96SV<V-H="X*("`@(#PO<&%R83X*("`\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S
M7VUO;G1H;'DB('-T871E/2)U<'1O9&%T92(@;60U/2(S-S-E83`R961E-F1F
M-69C,S0U8V%F-C,R93$Y83<U9B(^"B`@("`\=&ET;&4^16EN<W1E;&QU;F=E
M;CH@06YM96QD96%U9F=A8F5N.B!!;'1E('9E<FQI;FMT92!!;FCD;F=E(&%M
M"B`@("!-;VYA='-B96=I;FX@;/9S8VAE;CPO=&ET;&4^"B`@("`\<&%R83X*
M("`@("`@06MT:79I97)E;B!3:64@9&EE<V4@16EN<W1E;&QU;F<L('=E;FX@
M4VEE(&%L=&4@=F5R;&EN:W1E($%N:.1N9V4@>G5M"B`@("`@($UO;F%T<V)E
M9VEN;B!L]G-C:&5N(&WV8VAT96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY
M7VME97`B('-T871E/2)U<'1O9&%T92(@;60U/2(Q8C,T,&$V,#(Q-&1F9F0P
M-&%E8S`R8V,Q,3(W9&8U9"(^"B`@("`\=&ET;&4^16EN<W1E;&QU;F=E;CH@
M06YM96QD96%U9F=A8F5N.B!!;GIA:&P@9&5R($UO;F%T92P@9OQR(&1I92!A
M;'1E"B`@("!V97)L:6YK=&4@06YHY&YG92!A=69G96AO8F5N('=E<F1E;B!S
M;VQL96XL(&9A;&QS(&1I97-E(&UO;F%T;&EC:"!G96SV<V-H=`H@("`@=V5R
M9&5N/"]T:71L93X*("`@(#QP87)A/@H@("`@("!796YN(%-I92!A;'1E('9E
M<FQI;FMT92!!;FCD;F=E(&UO;F%T;&EC:"!L]G-C:&5N+"!W:64@=FEE;&4@
M36]N871E(&%N"B`@("`@(&%L=&5N($%N:.1N9V5N(&WV8VAT96X@4VEE(&)E
M:&%L=&5N/R!!;&QE($%N:.1N9V4@Y&QT97(@86QS(&1I90H@("`@("!A;F=E
M9V5B96YE;B!-;VYA=&4@=V5R9&5N(&=E;/9S8VAT+@H@("`@/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@<W1A
M=&4](G5P=&]D871E(B!M9#4](F1C-S$X-S$Q-#9B93-E-#9A9&4P,#@W83AC
M9C$X,C<S(CX*("`@(#QT:71L93Y%:6YS=&5L;'5N9V5N.B!!;FUE;&1E875F
M9V%B96XZ($%L=&4@3F%C:')I8VAT96X@:6T@4&%P:65R:V]R8@H@("`@96YD
M9_QL=&EG(&SV<V-H96X\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@(%-O;&P@
M9&5R(%!A<&EE<FMO<F(@<F5G96QMY-]I9R!G96QE97)T('=E<F1E;C\*("`@
M(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?
M=')A<VA?:6YT97)V86PB('-T871E/2)U<'1O9&%T92(@;60U/2(W8F4Y,69B
M96(P-6(R9#@W,C@Y9#1C-38P,F0U83,R9B(^"B`@("`\=&ET;&4^16EN<W1E
M;&QU;F=E;CH@06YM96QD96%U9F=A8F5N.B!7:64@;V9T('-O;&P@9&5R(%!A
M<&EE<FMO<F(@9V5L965R=`H@("`@=V5R9&5N/"]T:71L93X*("`@(#QP87)A
M/@H@("`@("!796YN(&1E<B!087!I97)K;W)B(')E9V5L;>3?:6<@9V5L965R
M="!W:7)D+"!W:64@;V9T('-O;&P@97(@9V5L965R=`H@("`@("!W97)D96X_
M"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U
M<F=E7W1R87-H7VME97`B('-T871E/2)U<'1O9&%T92(@;60U/2(S8V(U83)B
M-6(X,&(W86,Q,3<Y864P,#5F.3@S.3<P92(^"B`@("`\=&ET;&4^16EN<W1E
M;&QU;F=E;CH@06YM96QD96%U9F=A8F5N.B!.86-H<FEC:'1E;B!I;2!087!I
M97)K;W)B(&YA8V@@<V\*("`@('9I96QE;B!486=E;B!E;F1G_&QT:6<@;/9S
M8VAE;CPO=&ET;&4^"B`@("`\<&%R83X*("`@("`@5V5N;B!D97(@4&%P:65R
M:V]R8B!R96=E;&WDWVEG(&=E;&5E<G0@=VER9"P@=VEE('9I96QE(%1A9V4@
M86X*("`@("`@9V5L]G-C:'1E;B!.86-H<FEC:'1E;B!S;VQL96X@:6T@4&%P
M:65R:V]R8B!V97)B;&5I8F5N/PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUA='1R:6)?=&5X="(@<W1A=&4](G5P=&]D871E
M(B!M9#4](C<R,6$P.60W8V$P,CAC.3=E,V)D,F(S.&,U.3=F9F8W(CX*("`@
M("`\=&ET;&4^16EN<W1E;&QU;F=E;CH@3F5U92!.86-H<FEC:'0Z(%=I92!S
M;VQL96X@6FET871A;G1W;W)T96X@;6%R:VEE<G0*("`@("!W97)D96X\+W1I
M=&QE/@H@("`@(#QP87)A/@H@("`@("`@2&EE<B!K]FYN96X@4VEE(&%N9V5B
M96XL('=E;&-H97(@5&5X="!Z:71I97)T96X@3F%C:')I8VAT96XL(&1I92!3
M:64*("`@("`@(&)E86YT=V]R=&5N+"!V;W)A;F=E<W1E;&QT('=E<F1E;B!S
M;VQL+@H@("`@(#PO<&%R83X*("`@("`\<&%R83X*("`@("`@(%-I92!K]FYN
M96X@96EN96X@;V1E<B!M96AR97)E('-P97II96QL92!0;&%T>FAA;'1E<B!I
M;B!D:65S96X@5&5X=`H@("`@("`@96EN9OQG96XL(&1I92!D=7)C:"!!;F=A
M8F5N(&%U<R!D97(@=7)S<'+\;F=L:6-H96X@3F%C:')I8VAT(&5R<V5T>G0*
M("`@("`@('=E<F1E;BX@4&QA='IH86QT97(@8F5S=&5H96X@875S(&5I;F5M
M("(E(BP@9V5F;VQG="!V;VX@96EN96T*("`@("`@($)U8VAS=&%B96XN($9O
M;&=E;F1E(%!L871Z:&%L=&5R('-T96AE;B!Z=7(@5F5R9OQG=6YG.@H@("`@
M(#PO<&%R83X*"B`@("`@/'!A<F$^("5F(#H@1&5R($YA;64@=6YD(&1I92!%
M;6%I;&%D<F5S<V4@9&5S($%B<V5N9&5R<SPO<&%R83X*("`@("`\<&%R83X@
M)6$@.B!$:64@16UA:6QA9')E<W-E(&1E<R!!8G-E;F1E<G,\+W!A<F$^"B`@
M("`@/'!A<F$^("5P(#H@1&5R($YA;64@9&5S($%B<V5N9&5R<SPO<&%R83X*
M("`@("`\<&%R83X@)7(@.B!$87,@1&%T=6T@=6YD(&1I92!:96ET>F]N92!I
M;2!21D,M,C@R,BU3=&EL/"]P87)A/@H@("`@(#QP87)A/B`E9"`Z($1A<R!$
M871U;2!I;2!&;W)M870@=W=W+"!T="!M;6T@2DI*2CPO<&%R83X*("`@("`\
M<&%R83X@)7@@.B!$87,@1&%T=6T@:6T@1F]R;6%T(&1E<B!G97?D:&QT96X@
M4W!R86-H93PO<&%R83X*("`@("`\<&%R83X@)6,@.B!$87,@1&%T=6T@=6YD
M(&1I92!:96ET(&EM($9O<FUA="!D97(@9V5WY&AL=&5N(%-P<F%C:&4\+W!A
M<F$^"B`@("`@/'!A<F$^("5M(#H@1&EE($YA8VAR:6-H=&5N+4E$/"]P87)A
M/@H@("`@(#QP87)A/B`E<R`Z($1E<B!"971R969F/"]P87)A/@H@("`@(#QP
M87)A/B`E;B`Z($5I;B!:96EL96YU;6)R=6-H/"]P87)A/@H@("`@(#QP87)A
M/B`E)2`Z($1A<R`B)2(@6F5I8VAE;CPO<&%R83X*("`\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]R96%D(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB.#EE.3)C-&0V.#(R-&(R,S0U8C4Y.34Y.#<X
M83<Q-S0B/@H@("`@/'1I=&QE/D5I;G-T96QL=6YG96XZ($QE<V5B97-TY'1I
M9W5N9V5N(&%N9F]R9&5R;CPO=&ET;&4^"B`@("`\<&%R83X*("`@("`@36ET
M("),97-E8F5S=.1T:6=U;F=E;B!A;F9O<F1E<FXB('=E<F1E;B!D:64@16UP
M9N1N9V5R($EH<F5R($YA8VAR:6-H=&5N"B`@("`@(&%U9F=E9F]R9&5T+"!"
M97-TY'1I9W5N9V5N('IU<OQC:WIU<V-H:6-K96XL('=E;FX@9&EE($YA8VAR
M:6-H="!G9?9F9FYE=`H@("`@("!W=7)D92X@3FEC:'0@86QL92!%;6%I;'!R
M;V=R86UM92!U;G1E<G-T_'1Z96X@9&EE<V4@075F9F]R9&5R=6YG96X@;V1E
M<@H@("`@("!R96%G:65R96X@9&%R875F+@H@("`@/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S96YD7VUD;B(@
M<W1A=&4](G5P=&]D871E(B!M9#4](C%F93`T935D8S-D938X9#$W,F1A,C@T
M.#DU.3<S96$Y(CX*("`@(#QT:71L93Y%:6YS=&5L;'5N9V5N.B!,97-E8F5S
M=.1T:6=U;F<@<V-H:6-K96X\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@($UI
M="`B3&5S96)E<W3D=&EG=6YG('-C:&EC:V5N(B!W:7)D(&5I;F4@365S<V%G
M92!$:7-P;W-I=&EO;@H@("`@("!.;W1I9FEC871I;VX@*&5I;F4@3&5S96)E
M<W3D=&EG=6YG*2!A;B!D96X@06)S96YD97(@96EN97(@3F%C:')I8VAT"B`@
M("`@(&=E<V-H:6-K="P@9F%L;',@97(@9&EE<V4@86YG969O<F1E="!H870@
M=6YD(%-I92!D:64@3F%C:')I8VAT(&=E;&5S96X*("`@("`@:&%B96XN($EN
M(&1E;B!M96ES=&5N($;D;&QE;B!G97-C:&EE:'0@9&%S(&%U=&]M871I<V-H
M+"!O:&YE(&1A<W,@4VEE"B`@("`@(&5I;F=R96EF96X@;?QS<V5N+B!);B!B
M97-T:6UM=&5N($;D;&QE;B!K86YN(&5S(&IE9&]C:"!V;W)K;VUM96XL(&1A
M<W,*("`@("`@4VEE(&5I;F4@3F%C:&9R86=E(&5R:&%L=&5N('5N9"!S96QB
M97(@96YT<V-H96ED96X@;?QS<V5N+"!O8B!3:64@9&EE<V4*("`@("`@0F5S
M=.1T:6=U;F<@=F5R<V-H:6-K96X@;?9C:'1E;BP@:6YD96T@4VEE(&%U9B!E
M:6YE;B!,:6YK(&ML:6-K96XN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7V1E;&EV97)Y(B!S
M=&%T93TB=7!T;V1A=&4B(&UD-3TB,C8U.3AE,CEA9C`U83`W9&4U93$S-C0T
M-C8Y8F4W,3(B/@H@("`@/'1I=&QE/D5I;G-T96QL=6YG96XZ($5M<&9A;F=S
M8F5S=.1T:6=U;F=E;B!A;F9O<F1E<FX\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("`@($UI="`B16UP9F%N9W-B97-TY'1I9W5N9V5N(&%N9F]R9&5R;B(@=V5R
M9&5N(&1I92!%;6%I;'-E<G9E<B!D97(*("`@("`@16UP9N1N9V5R($EH<F5R
M($YA8VAR:6-H=&5N(&%U9F=E9F]R9&5T+"!"97-TY'1I9W5N9V5N('IU<OQC
M:WIU<V-H:6-K96XL"B`@("`@('=E;FX@9&EE($YA8VAR:6-H="!I;B!D87,@
M4&]S=&9A8V@@9&5S($5M<&;D;F=E<G,@875S9V5L:65F97)T"B`@("`@('=U
M<F1E+B!$87,@8F5D975T970@;FEC:'0L(&1A<W,@9&EE($YA8VAR:6-H="!G
M96QE<V5N('=U<F1E+"!S;VYD97)N"B`@("`@(&YU<BP@9&%S<R!S:64@:6X@
M:7)G96YD96EN96T@4&]S=&9A8V@@86YG96MO;6UE;B!I<W0N($YI8VAT(&%L
M;&4*("`@("`@16UA:6QS97)V97(@=6YT97)S=/QT>F5N(&1I97-E($%U9F9O
M<F1E<G5N9V5N+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD96QE=&5?<W!A;5]A9G1E<E]R97!O<G0B('-T871E/2)U<'1O
M9&%T92(@;60U/2)C969A.&(U,F4P.6(P861A.3!E,#@X.6$S.34Y969E82(^
M"B`@("`\=&ET;&4^16EN<W1E;&QU;F=E;CH@0F5H86YD;'5N9R!V;VX@4W!A
M;3PO=&ET;&4^"B`@("`\<&%R83X*("`@("`@4VEE(&OV;FYE;B!A=7,@96EN
M97(@=F]N(&1R96D@06MT:6]N96X@=^1H;&5N+"!D:64@875S9V5F_&AR="!W
M97)D96X*("`@("`@<V]L;"P@=V5N;B!3:64@96EN92!.86-H<FEC:'0@86QS
M(%-P86T@;V1E<B!K96EN(%-P86T@9V5M96QD970@:&%B96XN"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@("`@17)S=&5N<RP@;FEC:'0@9V5S8VAI96AT
M("T@9&EE($YA8VAR:6-H="!W:7)D(&%L<R!3<&%M(&]D97(@:V5I;B!3<&%M
M"B`@("`@(&=E;65L9&5T+"!A8F5R(&)L96EB="!U;G9E<N1N9&5R="!I;B!)
M:')E;2!/<F1N97(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@6G=E
M:71E;G,@:V%N;B!D:64@3F%C:')I8VAT+"!D:64@4VEE(&=E<F%D92!A;',@
M4W!A;2!G96UE;&1E="!H86)E;BP*("`@("`@<V]F;W)T(&=E;/9S8VAT('=E
M<F1E;BX@1&EE<V4@16EN<W1E;&QU;F<@:&%T(&ME:6YE;B!%:6YF;'7?(&%U
M9@H@("`@("!.86-H<FEC:'1E;B!D:64@86QS(&ME:6X@4W!A;2!G96UE;&1E
M="!W=7)D96XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@6G=E:71E
M;G,@:V%N;B!D:64@3F%C:')I8VAT+"!D:64@4VEE(&=E<F%D92!A;',@4W!A
M;2!G96UE;&1E="!H86)E;BP@:6X*("`@("`@26AR96X@4W!A;2U/<F1N97(@
M=F5R<V-H;V)E;B!W97)D96XN($9A;&QS(%-I92!E:6YE($YA8VAR:6-H="!A
M;',@:V5I;@H@("`@("!3<&%M(&=E;65L9&5T(&AA8F5N+"!W:7)D(&1I97-E
M('9O;2!A:W1U96QL96X@3W)D;F5R(&EN($EH<F5N"B`@("`@(%!O<W1E:6YG
M86YG('9E<G-C:&]B96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+6AT;6Q?:6UA9V5?<F5P;&%C96UE;G0B('-T871E/2)U
M<'1O9&%T92(@;60U/2(R.&4Q8V8P.&4S,C@S-#5A.&4W,C<T8S@U,S0Y,F0T
M9B(^"B`@("`\=&ET;&4^16EN<W1E;&QU;F=E;CH@17)S971Z96X@=F]N($)I
M;&1E<FX@:6X@2%1-3#PO=&ET;&4^"B`@("`\<&%R83X*("`@("`@5V5N;B!(
M5$U,+4YA8VAR:6-H=&5N(&EN;F5R:&%L8B!D97,@4')O9W)A;6US(&%N9V5Z
M96EG="!W97)D96XL('-O;&QE;@H@("`@("!A;&QE($)I;&1E<B!B;&]C:VEE
M<G0@=V5R9&5N+"!B:7,@4VEE(&%U<V1R_&-K;&EC:"!D:64@0FEL9&5R(&YA
M8VAL861E;C\*("`@("`@0F5A8VAT96X@4VEE+"!D87-S($)I;&1E<B!I;6UE
M<B!A;F=E>F5I9W0@=V5R9&5N+"!W96YN(%-I92!S:6-H"B`@("`@($A434PM
M3F%C:')I8VAT96X@:6X@96EN96T@;F5U96X@1F5N<W1E<B!A;GIE:6=E;B!L
M87-S96XN"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+6AT;6Q?:6UA9V5?861D<F)O;VLB('-T871E/2)U<'1O9&%T92(@;60U
M/2(W-3EF83-D9C(T93!A,V-D.#EF,S(P,3`R,C4R9CDQ82(^"B`@("`\=&ET
M;&4^16EN<W1E;&QU;F=E;CH@17)S971Z96X@=F]N($)I;&1E<FX@:6X@2%1-
M3"]!9')E<W-B=6-H<W5C:&4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@(%=E
M;FX@0FEL9&5R('9O;B!(5$U,+4YA8VAR:6-H=&5N+"!D:64@:6YN97)H86QB
M(&1E<R!0<F]G<F%M;7,@86YG97IE:6=T"B`@("`@('=E<F1E;BP@875T;VUA
M=&ES8V@@8FQO8VMI97)T('=E<F1E;BP@<V]L;"!E:6YE($%U<VYA:&UE(&=E
M;6%C:'0@=V5R9&5N+`H@("`@("!W96YN('-I8V@@9&5R($%B<V5N9&5R(&1E
M<B!.86-H<FEC:'0@:6X@26AR96T@061R97-S8G5C:"!B969I;F1E=#\*("`@
M(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M;6%I;&)O
M>%]S=&%R="(@<W1A=&4](G5P=&]D871E(B!M9#4](C-D,3$Y-F8R-C5D.&(W
M8V,T-C5E8F8R,34Q,F%C8S`U(CX*("`@(#QT:71L93Y%:6YS=&5L;'5N9V5N
M.B!3=&%R='-E:71E(&EN($]R9&YE<FX\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("`@($QE9W0@9F5S="P@=V5L8VAE(%-E:71E(&EN(&1E<B!/<F1N97)A;G-I
M8VAT(&%N9V5Z96EG="!W:7)D+"!W96YN(%-I90H@("`@("!E:6YE;B!/<F1N
M97(@]F9F;F5N+B`@0F5A8VAT96X@4VEE+"!D87-S(&1I92!%:6YS=&5L;'5N
M9V5N(&;\<@H@("`@("`B=6YG96QE<V5N92!.86-H<FEC:'1E;B(@;FEC:'0@
M9G5N:W1I;VYI97)E;BP@=V5N;B!3:64@26AR92!.86-H<FEC:'1E;@H@("`@
M("!N86-H(")4:&5M96XB('-O<G1I97)T(&AA8F5N+@H@("`@/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E7V%T=&%C:&UE;G1S
M(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,S5B-#8S,S1C9&-C-V9A-#$V8CEF
M.69C834X-S1E.#`B/@H@("`@/'1I=&QE/D5I;G-T96QL=6YG96XZ($%N:.1N
M9V4@;6ET(&=E<V5N9&5T96X@3F%C:')I8VAT96X@<W!E:6-H97)N/"]T:71L
M93X*("`@(#QP87)A/@H@("`@("!796YN(&5I;F4@;F5U92!.86-H<FEC:'0@
M:6T@3W)D;F5R(&;\<B!G97-E;F1E=&4@3F%C:')I8VAT96X@9V5S<&5I8VAE
M<G0*("`@("`@=VER9"P@:_9N;F5N(%-I92!F97-T;&5G96XL(&]B(&5V96YT
M=65L;&4@06YHY&YG92!M:71G97-P96EC:&5R=`H@("`@("!W97)D96XN($9O
M;&=E;F1E($5I;G-T96QL=6YG96X@<W1E:&5N('IU<B!697)F_&=U;F<N"B`@
M("`\+W!A<F$^"@H@("`@/'!A<F$^*B`B06YHY&YG92!I;6UE<B!S<&5I8VAE
M<FXB("T@3DE%(&)E:6T@4V-H<F5I8F5N(&YE=65R($YA8VAR:6-H=&5N"B`@
M("`@;F%C:&9R86=E;BP@;V(@9&EE($%N:.1N9V4@;6ET9V5S<&5I8VAE<G0@
M=V5R9&5N('-O;&QE;CL@1&EE($%N:.1N9V4*("`@("!W97)D96X@24U-15(@
M;6ET9V5S<&5I8VAE<G0N/"]P87)A/@H@("`@(#QP87)A/BH@(DIE9&5S;6%L
M(&YA8VAF<F%G96X[('-T86YD87)D;>3?:6<@2D$B("T@24U-15(@8F5I;2!3
M8VAR96EB96X*("`@("!N975E<B!.86-H<FEC:'1E;B!N86-H9G)A9V5N+"!O
M8B!D:64@06YHY&YG92!M:71G97-P96EC:&5R="!W97)D96X*("`@("!S;VQL
M96X[($1I92!3=&%N9&%R9&5I;G-T96QL=6YG(&QA=71E="!D:64@06YHY&YG
M92!M:71Z=7-P96EC:&5R;BX\+W!A<F$^"B`@("`@/'!A<F$^*B`B2F5D97-M
M86P@;F%C:&9R86=E;CL@<W1A;F1A<F1MY-]I9R!.14E.(B`M($E-3452(&)E
M:6T@4V-H<F5I8F5N"B`@("`@;F5U97(@3F%C:')I8VAT96X@;F%C:&9R86=E
M;BP@;V(@9&EE($%N:.1N9V4@;6ET9V5S<&5I8VAE<G0@=V5R9&5N"B`@("`@
M<V]L;&5N.R!$:64@4W1A;F1A<F1E:6YS=&5L;'5N9R!L875T970@9&EE($%N
M:.1N9V4@;FEC:'0*("`@("!M:71Z=7-P96EC:&5R;BX\+W!A<F$^"B`@("`\
M<&%R83XJ(")!;FCD;F=E(&YI92!S<&5I8VAE<FXB("T@3DE%(&)E:6T@4V-H
M<F5I8F5N(&YE=65R($YA8VAR:6-H=&5N"B`@("`@;F%C:&9R86=E;BP@;V(@
M9&EE($%N:.1N9V4@;6ET9V5S<&5I8VAE<G0@=V5R9&5N('-O;&QE;CL@1&EE
M($%N:.1N9V4*("`@("!W97)D96X@3DE%(&UI=&=E<W!E:6-H97)T+CPO<&%R
M83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]I;F)O>"(@<W1A
M=&4](G5P=&]D871E(B!M9#4](C1D,3DV.64V-#!F-F4P8F5D-&8X.34X9C`Q
M.&,R9#`W(CX*("`@(#QT:71L93Y6:7)T=65L;&4@3W)D;F5R.B!6:7)T=65L
M;&5R(%!O<W1E:6YG86YG/"]T:71L93X*("`@(#QP87)A/@H@("`@("!$97(@
M5FER='5E;&QE(%!O<W1E:6YG86YG(&ES="!E:6YE(&=E<W!E:6-H97)T92!3
M=6-H86)F<F%G92P@9&EE(&5S"B`@("`@($EH;F5N(&%B;FEM;70L(&EN(&%L
M;&5N($]R9&YE<FX@;F%C:"!N975E;B!.86-H<FEC:'1E;B!Z=0H@("`@("!S
M8VAA=65N+B!3=&%T=&1E<W-E;B!W97)D96X@86QL92!/<F1N97(L(&1I92!3
M:64@9OQR(&1I97-E;B!:=V5C:R!I;B!D97(*("`@("`@/')E9B!M;V1U;&4]
M(FEM<"(@96YT<GD](F9O;&1E<BUO<'1I;VYS(CY/<F1N97(@3F%V:6=A=&EO
M;CPO<F5F/@H@("`@("!A=7-G97?D:&QT(&AA8F5N+"!A=71O;6%T:7-C:"!N
M86-H(&YE=65N($YA8VAR:6-H=&5N(&1U<F-H<W5C:'0@=6YD(&EN"B`@("`@
M(&5I;F5R(&5I;GII9V5N(-QB97)S:6-H="!A;F=E>F5I9W0N"B`@("`\+W!A
M<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U86Q?=')A<V@B('-T
M871E/2)U<'1O9&%T92(@;60U/2(Q,68Y,3@Q,6(Y8C)A9CDP9F4V.#<T,&8V
M83@V8V5F-B(^"B`@("`\=&ET;&4^5FER='5E;&QE($]R9&YE<CH@5FER='5E
M;&QE<B!087!I97)K;W)B/"]T:71L93X*("`@(#QP87)A/@H@("`@("!$97(@
M5FER='5E;&QE(%!A<&EE<FMO<F(@:7-T(&5I;F4@9V5S<&5I8VAE<G1E(%-U
M8VAA8F9R86=E+"!D:64@96EN96X*("`@("`@<V5P87)A=&5N(%!A<&EE<FMO
M<F(M3W)D;F5R('5N;O9T:6<@;6%C:'0N($%N<W1A='0@9V5L]G-C:'1E($YA
M8VAR:6-H=&5N"B`@("`@(&EN(&5I;F5N('-P97II96QL96X@3W)D;F5R('IU
M('9E<G-C:&EE8F5N+"!W97)D96X@<VEE(&YU<B!A;',@9V5L]G-C:'0*("`@
M("`@;6%R:VEE<G0@=6YD(&EN(&1E;B!J97=E:6QI9V5N($]R9&YE<FXL(&EN
M(&1E;F5N('-I92!S:6-H(&)E9FEN9&5N+`H@("`@("!A=7-G96)L96YD970N
M(`H@("`@("!796YN(%-I92!D96X@5FER='5E;&QE;B!087!I97)K;W)B(/9F
M9FYE;BP@=V5R9&5N(&%L;&4@26AR92!/<F1N97(@;F%C:`H@("`@("!G96SV
M<V-H=&5N($YA8VAR:6-H=&5N(&1U<F-H<W5C:'0@=6YD(&EN(&5I;F5R(&5I
M;GII9V5N(-QB97)S:6-H=`H@("`@("!A;F=E>F5I9W0N(`H@("`@/"]P87)A
M/@H@(#PO96YT<GD^"CPO:&5L<#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+VQO8V%L92]C<U]#6B\`````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,``P,3<T-#<`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+V-S7T-:+TQ#7TU%4U-!1T53
M+P``````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S8P`#`R,3(S-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O
M8W-?0UHO3$-?34534T%'15,O:6UP+FUO````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`U-C0Q,S$`,3`T,3<S-C(W-C``,#(R,S8U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````(0H``!P````D40``
M@0T``"RB````````,-@```H````QV```"@```#S8```*````1]@```X```!2
MV```#P```&'8```-````<=@```@```!_V```"P```(C8```,````E-@```H`
M``"AV```!````*S8```$````L=@```$```"VV```&0```+C8```,````TM@`
M`$@```#?V```*P```"C9``!$````5-D``"<```"9V0``%P```,'9```/````
MV=D```L```#IV0``#@```/79```%````!-H``"@````*V@``"````#/:```*
M````/-H``!4```!'V@``$@```%W:```R````<-H```L```"CV@``*0```*_:
M```R````V=H``!`````,VP``%````!W;```0````,ML``"8```!#VP``)P``
M`&K;```F````DML``!P```"YVP``#@```-;;```*````Y=L```T```#PVP``
M)P```/[;```@````)MP```X```!'W```%P```%;<```B````;MP``#4```"1
MW```$0```,?<```-````V=P```P```#GW```#0```/3<```&`````MT``!L`
M```)W0``+@```"7=```W````5-T``'P```",W0``;`````G>```<````=MX`
M`!T```"3W@``#P```+'>```8````P=X```P```#:W@``10```.?>```H````
M+=\``$$```!6WP``)````)C?```.````O=\```\```#,WP``#@```-S?```.
M````Z]\```@```#ZWP``#@````/@```.````$N```"X````AX```&@```%#@
M```S````:^```%$```"?X```,@```/'@```X````).$``%0```!=X0``40``
M`++A``!:````!.(``%<```!?X@``-````+?B```'````[.(```H```#TX@``
M#P```/_B```%````#^,```,````5XP``!@```!GC```1````(.,```@````R
MXP``"0```#OC```)````1>,```X```!/XP``"````%[C```*````9^,``"4`
M``!RXP``(````)CC```0````N>,```\```#*XP``#P```-KC```*````ZN,`
M``<```#UXP```P```/WC```/`````>0``!0````1Y```"0```";D```-````
M,.0``!(````^Y```#P```%'D```*````8>0```\```!LY```"````'SD```*
M````A>0``"0```"0Y```%P```+7D```4````S>0``!8```#BY```"````/GD
M```<`````N4``!D````?Y0``*````#GE```>````8N4``!H```"!Y0``+```
M`)SE```@````R>4``#(```#JY0``!P```!WF```,````)>8```T````RY@``
M+````$#F```.````;>8```,```!\Y@``"P```(#F```'````C.8```<```"4
MY@``!0```)SF```%````HN8```H```"HY@```P```+/F```7````M^8```H`
M``#/Y@``#P```-KF```.````ZN8``$X```#YY@``4````$CG``!#````F><`
M`$(```#=YP``,````"#H```8````4>@``",```!JZ```#@```([H```4````
MG>@``!<```"RZ```%P```,KH```7````XN@``!,```#ZZ```#P````[I```C
M````'ND```8```!"Z0``%P```$GI```.````8>D``%$```!PZ0``'P```,+I
M```U````XND```<````8Z@``!@```"#J```(````)^H```\````PZ@``!@``
M`$#J```(````1^H``!$```!0Z@``"@```&+J```3````;>H```L```"!Z@``
M$````(WJ```5````GNH```T```"TZ@``$P```,+J```C````UNH``"\```#Z
MZ@``%0```"KK```'````0.L``!````!(ZP``!0```%GK```5````7^L``!$`
M``!UZP``#````(?K```P````E.L``$@```#%ZP``(0````[L```[````,.P`
M`#L```!L[```/````*CL```K````Y>P``#$````1[0``.P```$/M```Y````
M?^T``#4```"Y[0``"0```._M```'````^>T``!0````![@``#````!;N```#
M````(^X```4````G[@``"0```"WN```0````-^X```D```!([@``$P```%+N
M```#````9NX``#D```!J[@``$@```*3N```&````M^X```P```"^[@``-0``
M`,ON```.`````>\``$D````0[P``,P```%KO```*````CN\``"T```"9[P``
M"P```,?O```G````T^\``"P```#[[P``*@```"CP```E````4_````D```!Y
M\```"0```(/P```*````C?````8```"8\```"0```)_P```'````J?```"\`
M``"Q\```-P```.'P```N````&?$``%4```!(\0``+0```)[Q```L````S/$`
M`"T```#Y\0``+0```"?R``!`````5?(``",```"6\@``(P```+KR```M````
MWO(``#,````,\P``%0```$#S```9````5O,``"D```!P\P``)````)KS``!0
M````O_,``!@````0]```$0```"GT```1````._0```H```!-]```#````%CT
M```+````9?0```H```!Q]```"@```'ST```0````A_0``!8```"8]```%@``
M`*_T```'````QO0```<```#.]```%````-;T```*````Z_0```@```#V]```
M"````/_T```#````"/4```<````,]0``!P```!3U```&````'/4``#@````C
M]0``!0```%SU```'````8O4```8```!J]0``"````''U```)````>O4``"D`
M``"$]0``#@```*[U```*````O?4``$4```#(]0``!`````[V```$````$_8`
M``<````8]@``"0```"#V```&````*O8``!$````Q]@``!P```$/V```6````
M2_8```0```!B]@``)P```&?V```(````C_8```8```"8]@``#0```)_V```&
M````K?8``!X```"T]@``$0```-/V```(````Y?8```T```#N]@``#````/SV
M```'````"?<```,````1]P```P```!7W```7````&?<``!,````Q]P``"```
M`$7W```(````3O<```0```!7]P``"````%SW```(````9?<``"H```!N]P``
M*P```)GW``!3````Q?<``$$````9^```(````%OX```&````?/@```8```"#
M^```#@```(KX```5````F?@``#X```"O^```&````.[X```B````!_D``"X`
M```J^0``'0```%GY```A````=_D``%0```"9^0``*0```.[Y```*````&/H`
M``<````C^@``%0```"OZ```.````0?H```(```!0^@``"@```%/Z```/````
M7OH```T```!N^@``#P```'SZ```-````C/H```D```":^@``%````*3Z```&
M````N?H``!@```#`^@``'0```-GZ```3````]_H``!0````+^P``!````"#[
M```,````)?L```8````R^P``"@```#G[```-````1/L``&(```!2^P``)P``
M`+7[``!4````W?L``%\````R_```!````)+\```6````E_P```X```"N_```
M'````+W\```/````VOP``#,```#J_```*````![]```%````1_T```4```!-
M_0``&P```%/]```:````;_T```X```"*_0``%0```)G]```1````K_T``!$`
M``#!_0``$0```-/]```<````Y?T``"H````"_@``-0```"W^``!%````8_X`
M`!````"I_@``(0```+K^```%````W/X``!,```#B_@``$@```/;^```*````
M"?\```\````4_P``1P```"3_```?````;/\``"4```",_P``,P```++_```K
M````YO\``#4````2``$`0@```$@``0`=````BP`!`%$```"I``$`$0```/L`
M`0`Q````#0$!`#L````_`0$`$P```'L!`0!`````CP$!`#@```#0`0$`!0``
M``D"`0`,````#P(!`!$````<`@$`#0```"X"`0`&````/`(!``8```!#`@$`
M%P```$H"`0`(````8@(!``P```!K`@$`%````'@"`0`/````C0(!`!````"=
M`@$`$0```*X"`0`(````P`(!``4```#)`@$`$0```,\"`0`,````X0(!`!``
M``#N`@$`!0```/\"`0`-````!0,!``8````3`P$`!P```!H#`0`-````(@,!
M``<````P`P$`"P```#@#`0`'````1`,!``<```!,`P$`"0```%0#`0`7````
M7@,!`"8```!V`P$`3P```)T#`0`)````[0,!``H```#W`P$`&0````($`0`,
M````'`0!`"4````I!`$`'P```$\$`0`0````;P0!``4```"`!`$`)0```(8$
M`0`2````K`0!`!,```"_!`$`*P```-,$`0`[````_P0!`"`````[!0$`&P``
M`%P%`0`V````>`4!``@```"O!0$`&P```+@%`0`>````U`4!`%P```#S!0$`
M+@```%`&`0`,````?P8!``8```",!@$`!````),&`0`.````F`8!``X```"G
M!@$`!P```+8&`0`.````O@8!``H```#-!@$`#0```-@&`0`>````Y@8!`!L`
M```%!P$`(0```"$'`0`>````0P<!`!D```!B!P$`'@```'P'`0`;````FP<!
M`"8```"W!P$`)````-X'`0`;`````P@!`!X````?"`$`'````#X(`0`F````
M6P@!`#8```"""`$`,P```+D(`0`I````[0@!`$$````7"0$`.@```%D)`0`F
M````E`D!`"L```"["0$`.````.<)`0`O````(`H!`!(```!0"@$`*0```&,*
M`0`2````C0H!`*(```"@"@$`%@```$,+`0`C````6@L!`"@```!^"P$`*0``
M`*<+`0`H````T0L!`!\```#Z"P$`(````!H,`0`E````.PP!`#````!A#`$`
M(0```)(,`0`<````M`P!`"8```#1#`$`00```/@,`0`,````.@T!``<```!'
M#0$`!P```$\-`0`&````5PT!``T```!>#0$`"P```&P-`0`5````>`T!``T`
M``".#0$`&@```)P-`0`0````MPT!`!T```#(#0$`&0```.8-`0!=``````X!
M`!(```!>#@$`$P```'$.`0`2````A0X!``<```"8#@$`!````*`.`0`,````
MI0X!``X```"R#@$`#P```,$.`0`4````T0X!`!,```#F#@$`#0```/H.`0`Y
M````"`\!`!P```!"#P$`*````%\/`0`#````B`\!``T```",#P$`!@```)H/
M`0`1````H0\!`!<```"S#P$`&P```,L/`0`.````YP\!``(```#V#P$`!0``
M`/D/`0`%````_P\!`!`````%$`$`!````!80`0`-````&Q`!``X````I$`$`
M`P```#@0`0`.````/!`!``@```!+$`$`#P```%00`0`(````9!`!``H```!M
M$`$`#P```'@0`0`-````B!`!`!````"6$`$`&0```*<0`0`:````P1`!``L`
M``#<$`$`"0```.@0`0`&````\A`!`!0```#Y$`$`$P````X1`0`0````(A$!
M``P````S$0$`$0```$`1`0`5````4A$!`!D```!H$0$`"P```((1`0`-````
MCA$!`"(```"<$0$`*P```+\1`0`7````ZQ$!`#0````#$@$`,P```#@2`0`*
M````;!(!`!@```!W$@$`&0```)`2`0`6````JA(!``<```#!$@$`$````,D2
M`0`<````VA(!`!P```#W$@$`#0```!03`0`'````(A,!``P````J$P$`)@``
M`#<3`0`*````7A,!`!0```!I$P$`"P```'X3`0`'````BA,!`"(```"2$P$`
M+P```+43`0`+````Y1,!``D```#Q$P$`&0```/L3`0`+````%10!``\````A
M%`$`%P```#$4`0`7````210!``D```!A%`$`!P```&L4`0`6````<Q0!``\`
M``"*%`$`+0```)H4`0`6````R!0!``X```#?%`$`&@```.X4`0`H````"14!
M``L````R%0$`&````#X5`0`(````5Q4!``P```!@%0$`(P```&T5`0`-````
MD14!`"8```"?%0$`*@```,85`0`@````\14!`$,````2%@$`"````%86`0`2
M````7Q8!``0```!R%@$`"````'<6`0`+````@!8!`!H```",%@$`)P```*<6
M`0`2````SQ8!`"````#B%@$`+P````,7`0`7````,Q<!``4```!+%P$`#```
M`%$7`0`.````7A<!``X```!M%P$`!0```'P7`0`&````@A<!``X```")%P$`
M`P```)@7`0`K````G!<!``<```#(%P$`!````-`7`0`.````U1<!``H```#D
M%P$`#````.\7`0`*````_!<!``\````'&`$`$````!<8`0`7````*!@!`!,`
M``!`&`$`)0```%08`0`.````>A@!`!$```")&`$`%P```)L8`0`3````LQ@!
M`!8```#'&`$`.````-X8`0`3````%QD!``D````K&0$`!0```#49`0`+````
M.QD!``H```!'&0$``@```%(9`0`%````51D!``T```!;&0$`&P```&D9`0`7
M````A1D!``D```"=&0$`'0```*<9`0`/````Q1D!`!(```#5&0$`#````.@9
M`0`.````]1D!``T````$&@$`$@```!(:`0`9````)1H!`!P````_&@$`.```
M`%P:`0`8````E1H!`"````"N&@$`$P```,\:`0`#````XQH!`!4```#G&@$`
M"P```/T:`0`3````"1L!``@````=&P$`#@```"8;`0`0````-1L!`'L```!&
M&P$`&````,(;`0`I````VQL!`"P````%'`$`*````#(<`0`U````6QP!`!$`
M``"1'`$`!P```*,<`0`%````JQP!`!@```"Q'`$`&0```,H<`0`'````Y!P!
M``@```#L'`$`!@```/4<`0`&````_!P!`!L````#'0$`$````!\=`0`/````
M,!T!`!````!`'0$`#P```%$=`0`+````81T!``\```!M'0$`#````'T=`0`/
M````BAT!``<```":'0$`!@```*(=`0`*````J1T!`!(```"T'0$`#0```,<=
M`0`,````U1T!``X```#B'0$`0P```/$=`0`]````-1X!``D```!S'@$`#```
M`'T>`0`H````BAX!``\```"S'@$`"````,,>`0`(````S!X!`!,```#5'@$`
M'@```.D>`0`A````"!\!`"`````J'P$`&0```$L?`0`7````91\!`"4```!]
M'P$`%P```*,?`0`$````NQ\!`!L```#`'P$`#0```-P?`0`,````ZA\!``,`
M``#W'P$`"````/L?`0`*````!"`!``P````/(`$`"@```!P@`0`@````)R`!
M`!\```!((`$`"P```&@@`0`;````="`!``L```"0(`$`$````)P@`0`(````
MK2`!``P```"V(`$`!````,,@`0`$````R"`!`!,```#-(`$`%````.$@`0`,
M````]B`!``D````#(0$`#@````TA`0`+````'"$!`!L````H(0$`#@```$0A
M`0`/````4R$!`"4```!C(0$`*@```(DA`0`'````M"$!`!(```"\(0$`&P``
M`,\A`0`$````ZR$!``<```#P(0$`"@```/@A`0`2`````R(!``H````6(@$`
M#0```"$B`0`)````+R(!``0````Y(@$`!0```#XB`0`(````1"(!``,```!-
M(@$`&````%$B`0`0````:B(!``X```![(@$`'@```(HB`0`:````J2(!``H`
M``#$(@$`!````,\B`0`F````U"(!``X```#[(@$`?`````HC`0`5````AR,!
M`$0```"=(P$`!0```.(C`0`'````Z",!``P```#P(P$`"````/TC`0`*````
M!B0!``8````1)`$`!P```!@D`0`(````("0!`!$````I)`$`&0```#LD`0`(
M````520!``(```!>)`$`!@```&$D`0`&````:"0!`!0```!O)`$`%0```(0D
M`0`/````FB0!`!$```"J)`$`&@```+PD`0`-````UR0!`!````#E)`$`&P``
M`/8D`0`%````$B4!``0````8)0$`#````!TE`0`)````*B4!`!`````T)0$`
M"0```$4E`0`)````3R4!``0```!9)0$`!0```%XE`0`:````9"4!``4```!_
M)0$`&@```(4E`0`(````H"4!``8```"I)0$`#P```+`E`0`9````P"4!``X`
M``#:)0$`!P```.DE`0`'````\24!`"(```#Y)0$`!0```!PF`0`)````(B8!
M``H````L)@$`#0```#<F`0`&````128!``T```!,)@$`#````%HF`0`)````
M9R8!``8```!Q)@$`$@```'@F`0`)````BR8!``<```"5)@$`%````)TF`0`=
M````LB8!``8```#0)@$`"@```-<F`0`$````XB8!``D```#G)@$`"````/$F
M`0`1````^B8!``D````,)P$`!@```!8G`0`-````'2<!``8````K)P$`!```
M`#(G`0`$````-R<!`!<````\)P$`.0```%0G`0`]````CB<!`#H```#,)P$`
M'@````<H`0`%````)B@!``X````L*`$`!````#LH`0`&````0"@!``<```!'
M*`$`(0```$\H`0`5````<2@!``8```"'*`$`!````(XH`0`1````DR@!``8`
M``"E*`$`"@```*PH`0`B````MR@!`"<```#:*`$`!@````(I`0`5````"2D!
M``P````?*0$`$0```"PI`0`$````/BD!``T```!#*0$`!P```%$I`0`%````
M62D!`!T```!?*0$`!````'TI`0`,````@BD!``H```"/*0$`"````)HI`0`)
M````HRD!``4```"M*0$`.@```+,I`0`P````[BD!`#4````?*@$`*0```%4J
M`0!'````?RH!`#@```#'*@$`*0`````K`0`_````*BL!`"X```!J*P$`+0``
M`)DK`0`?````QRL!``\```#G*P$`$@```/<K`0`+````"BP!`"8````6+`$`
M)P```#TL`0`I````92P!`"0```"/+`$`)@```+0L`0`H````VRP!``@````$
M+0$`"@````TM`0`)````&"T!``<````B+0$`!````"HM`0`<````+RT!`"``
M``!,+0$`(````&TM`0`F````CBT!``T```"U+0$`)P```,,M`0`;````ZRT!
M``P````'+@$`%@```!0N`0`%````*RX!``H````Q+@$`&0```#PN`0`I````
M5BX!`!8```"`+@$`$@```)<N`0`'````JBX!``H```"R+@$`#````+TN`0`/
M````RBX!`!````#:+@$`0````.LN`0!P````+"\!`&8```"=+P$`!@````0P
M`0`*````"S`!``X````6,`$`"0```"4P`0`*````+S`!`!(````Z,`$`$P``
M`$TP`0`,````83`!``8```!N,`$`!@```'4P`0`*````?#`!``X```"',`$`
M#P```)8P`0`.````IC`!`!\```"U,`$`'@```-4P`0`C````]#`!`!$````8
M,0$`%0```"HQ`0`8````0#$!`!$```!9,0$`$````&LQ`0`C````?#$!``\`
M``"@,0$`"0```+`Q`0`2````NC$!`!T```#-,0$`$@```.LQ`0`0````_C$!
M``H````/,@$`$0```!HR`0`%````+#(!`#$````R,@$`)````&0R`0`<````
MB3(!`",```"F,@$`:@```,HR`0`/````-3,!``4```!%,P$`$````$LS`0`)
M````7#,!``0```!F,P$`"P```&LS`0`<````=S,!`",```"4,P$`(@```+@S
M`0`&````VS,!`!0```#B,P$`%P```/<S`0`,````#S0!`"0````<-`$`(P``
M`$$T`0`:````930!``P```"`-`$`#P```(TT`0`5````G30!`"D```"S-`$`
M*@```-TT`0`F````"#4!`"<````O-0$`*0```%<U`0`J````@34!`!D```"L
M-0$`0@```,8U`0`1````"38!`!(````;-@$`$P```"XV`0`4````0C8!``\`
M``!7-@$`%@```&<V`0`7````?C8!`!````"6-@$`$0```*<V`0`T````N38!
M`!,```#N-@$`$@````(W`0`U````%3<!`!0```!+-P$`!P```&`W`0`,````
M:#<!`"L```!U-P$`#P```*$W`0`6````L3<!`"````#(-P$`%````.DW`0`1
M````_C<!`"@````0.`$`%P```#DX`0`<````43@!`!,```!N.`$`"P```((X
M`0`1````CC@!`!H```"@.`$`'@```+LX`0`:````VC@!`"$```#U.`$`(```
M`!<Y`0`1````.#D!`!0```!*.0$`%P```%\Y`0`5````=SD!``D```"-.0$`
M!@```)<Y`0`9````GCD!``0```"X.0$`!P```+TY`0`+````Q3D!`!$```#1
M.0$`!@```.,Y`0`&````ZCD!``8```#Q.0$`!0```/@Y`0`'````_CD!``<`
M```&.@$`!0````XZ`0`6````%#H!``8````K.@$`!@```#(Z`0`$````.3H!
M``0````^.@$`!P```$,Z`0`.````2SH!``P```!:.@$`#````&<Z`0`-````
M=#H!``(```"".@$`"@```(4Z`0`.````D#H!``4```"?.@$`*````*4Z`0`.
M````SCH!``P```#=.@$`#P```.HZ`0`*````^CH!``@````%.P$`"0````X[
M`0`K````&#L!`"X```!$.P$`!````',[`0`(````>#L!`"8```"!.P$`$@``
M`*@[`0`/````NSL!``8```#+.P$`"@```-([`0`'````W3L!``@```#E.P$`
M(````.X[`0`)````#SP!`!$````9/`$`"0```"L\`0`,````-3P!``T```!"
M/`$`#@```%`\`0`6````7SP!`!$```!V/`$`!@```(@\`0`#````CSP!``8`
M``"3/`$`&0```)H\`0`'````M#P!``0```"\/`$`"P```,$\`0`+````S3P!
M``<```#9/`$`$0```.$\`0`'````\SP!`!8```#[/`$`#0```!(]`0`-````
M(#T!``H````N/0$`$````#D]`0`/````2CT!`!$```!:/0$`%P```&P]`0`*
M````A#T!`!$```"//0$`"````*$]`0`$````JCT!``\```"O/0$`.@```+\]
M`0`A````^CT!``4````</@$`%P```"(^`0`,````.CX!`!X```!'/@$`#@``
M`&8^`0`0````=3X!``L```"&/@$`?````)(^`0`,````#S\!``D````</P$`
M!P```"8_`0`*````+C\!``D````Y/P$`#@```$,_`0`0````4C\!`!4```!C
M/P$`&@```'D_`0`*````E#\!``D```"?/P$`"@```*D_`0`.````M#\!``P`
M``##/P$`#P```-`_`0`(````X#\!``8```#I/P$`#````/`_`0`'````_3\!
M``4````%0`$`"P````M``0!'````%T`!``T```!?0`$`"0```&U``0`$````
M=T`!``,```!\0`$`#````(!``0`3````C4`!`!,```"A0`$`$P```+5``0`&
M````R4`!``H```#00`$``@```-M``0`$````WD`!`"4```#C0`$``P````E!
M`0`%````#4$!`"H````300$`#@```#Y!`0`*````34$!``4```!800$`!```
M`%Y!`0`*````8T$!``T```!N00$`'P```'Q!`0`'````G$$!`"(```"D00$`
M#0```,=!`0`&````U4$!``@```#<00$`"````.5!`0`$````[D$!``4```#S
M00$`:````/E!`0`)````8D(!``P```!L0@$`!0```'E"`0`&````?T(!`",`
M``"&0@$`)0```*I"`0`(````T$(!`#<```#90@$`(@```!%#`0`3````-$,!
M`!L```!(0P$`+P```&1#`0`0````E$,!``H```"E0P$`$0```+!#`0`/````
MPD,!``\```#20P$`"@```.)#`0`)````[4,!`!,```#W0P$`&P````M$`0`8
M````)T0!`!<```!`1`$`%P```%A$`0`.````<$0!`"8```!_1`$`)@```*9$
M`0`#````S40!``<```#11`$`"````-E$`0`4````XD0!`!,```#W1`$`$```
M``M%`0`-````'$4!``X````J10$`%@```#E%`0`'````4$4!`!````!810$`
M"@```&E%`0`+````=$4!``<```"`10$`$P```(A%`0`,````G$4!``\```"I
M10$`#@```+E%`0`,````R$4!``X```#510$`40```.1%`0`/````-D8!`!``
M``!&1@$`#0```%=&`0`/````948!``\```!U1@$`#P```(5&`0`@````E48!
M`"X```"V1@$`&@```.5&`0`,`````$<!`"8````-1P$`"P```#1'`0`-````
M0$<!`!H```!.1P$`2@```&E'`0`&````M$<!``8```"[1P$`!@```,)'`0`?
M````R4<!``8```#I1P$`"0```/!'`0`8````^D<!`!<````32`$`!@```"M(
M`0`-````,D@!`"(```!`2`$`5P```&-(`0`3````NT@!`",```#/2`$`$P``
M`/-(`0`"````!TD!``L````*20$`"````!9)`0`-````'TD!``8````M20$`
M"@```#1)`0`'````/TD!`!0```!'20$`!@```%Q)`0`(````8TD!``X```!L
M20$`!P```'M)`0`*````@TD!``L```".20$`!P```)I)`0`,````HDD!``T`
M``"O20$`#````+U)`0`$````RDD!``D```#/20$`"0```-E)`0`*````XTD!
M``<```#N20$`"0```/9)`0`.`````$H!``<````/2@$`"@```!=*`0`;````
M(DH!`!4````^2@$`$@```%1*`0`*````9TH!``D```!R2@$`$````'Q*`0`'
M````C4H!`!(```"52@$`!````*A*`0`$````K4H!`"(```"R2@$`!P```-5*
M`0`%````W4H!``P```#C2@$`!0```/!*`0`+````]DH!`!0````"2P$`$0``
M`!=+`0`:````*4L!`!8```!$2P$`%````%M+`0`7````<$L!`!@```"(2P$`
M'````*%+`0`9````ODL!``<```#82P$`!0```.!+`0`6````YDL!``,```#]
M2P$`#0````%,`0`,````#TP!``H````<3`$`"````"=,`0`(````,$P!`!<`
M```Y3`$`"P```%%,`0`,````74P!`!,```!J3`$`!````'Y,`0`*````@TP!
M``0```".3`$`#````)-,`0`)````H$P!``P```"J3`$`"0```+=,`0`%````
MP4P!``<```#'3`$`!0```,],`0`$````U4P!``(```#:3`$`%````-U,`0`-
M````\DP!`!(`````30$`"P```!--`0`;````'TT!`!\````[30$`%````%M-
M`0`>````<$T!`!4```"/30$`.````*5-`0`L````WDT!`!(````+3@$`*0``
M`!Y.`0`R````2$X!``H```![3@$`+````(9.`0`N````LTX!`#,```#B3@$`
M,P```!9/`0`X````2D\!``\```"#3P$`&````)-/`0`0````K$\!`!,```"]
M3P$`*@```-%/`0`9````_$\!`!P````64`$`'P```#-0`0`/````4U`!`!,`
M``!C4`$`%````'=0`0`4````C%`!`"````"A4`$`$@```,)0`0`4````U5`!
M`!4```#J4`$`+0````!1`0`M````+E$!`#$```!<40$`+@```(Y1`0`O````
MO5$!`"P```#M40$`8@```!I2`0`3````?5(!`"4```"14@$`)````+=2`0`I
M````W%(!``@````&4P$`"`````]3`0`D````&%,!`!(````]4P$`#@```%!3
M`0`K````7U,!`!(```"+4P$`(0```)Y3`0`:````P%,!``D```#;4P$`10``
M`.53`0!!````*U0!``\```!M5`$`!````'U4`0`3````@E0!`!0```"65`$`
M#@```*M4`0`&````NE0!`!,```#!5`$`&````-54`0`&````[E0!``D```#U
M5`$`"@```/]4`0`+````"E4!``D````650$`#0```"!5`0`,````+E4!``\`
M```[50$`%P```$M5`0`4````8U4!`!````!X50$`%@```(E5`0`'````H%4!
M``X```"H50$`(0```+=5`0`%````V54!`!L```#?50$`"````/M5`0`&````
M!%8!`!0````+5@$`$0```"!6`0!$````,E8!`#P```!W5@$`#@```+16`0`X
M````PU8!``(```#\5@$``@```/]6`0`&`````E<!``X````)5P$`!0```!A7
M`0`'````'E<!``X````F5P$`!@```#57`0`,````/%<!`",```!)5P$`!```
M`&U7`0`I````<E<!`#(```"<5P$`%P```,]7`0`?````YU<!`#,````'6`$`
M7````#M8`0`4````F%@!`#X```"M6`$`#0```.Q8`0`?````^E@!`!`````:
M60$`%````"M9`0`'````0%D!``X```!(60$`#````%=9`0`,````9%D!`!,`
M``!Q60$`"@```(59`0`=````D%D!`!D```"N60$`!0```,A9`0`1````SED!
M`!,```#@60$`#0```/19`0`1`````EH!`"0````46@$``P```#E:`0`5````
M/5H!`!,```!36@$`$@```&=:`0`+````>EH!`#0```"&6@$`"P```+M:`0`4
M````QUH!`#X```#<6@$`#@```!M;`0`3````*EL!`#0````^6P$`,0```'-;
M`0`2````I5L!`!````"X6P$`&````,E;`0`9````XEL!`",```#\6P$`(@``
M`"!<`0`G````0UP!`%8```!K7`$`30```,)<`0`(````$%T!``D````970$`
M#0```"-=`0`*````,5T!``<````\70$`#P```$1=`0`+````5%T!``0```!@
M70$`'````&5=`0`-````@ET!`"<```"070$`&P```+A=`0`,````U%T!``H`
M``#A70$`!P```.Q=`0`-````]%T!`"(````"7@$`(0```"5>`0`(````1UX!
M``4```!07@$`'P```%9>`0`&````=EX!`!````!]7@$`"````(Y>`0`'````
MEUX!``T```"?7@$`"@```*U>`0`2````N%X!`"$```#+7@$`"P```.U>`0`<
M````^5X!`!@````67P$`"````"]?`0`2````.%\!`"P```!+7P$`&@```'A?
M`0`)````DU\!``H```"=7P$`%0```*A?`0`%````OE\!`!0```#$7P$`!```
M`-E?`0`0````WE\!``8```#O7P$`!P```/9?`0`>````_E\!`"@````=8`$`
M"@```$9@`0`:````46`!`"T```!L8`$`"````)I@`0`4````HV`!`"P```"X
M8`$`)P```.5@`0`K````#6$!`"H````Y80$`!````&1A`0`$````:6$!``L`
M``!N80$`!0```'IA`0`&````@&$!``@```"'80$`!@```)!A`0`Q````EV$!
M`!P```#)80$`"@```.9A`0`;````\6$!`#0````-8@$`-````$)B`0`@````
M=V(!`"D```"88@$`)P```,)B`0`@````ZF(!`$$````+8P$`&@```$UC`0`H
M````:&,!`!H```"18P$`=@```*QC`0!Y````(V0!`!P!``"=9`$`*````+IE
M`0`=````XV4!`"D````!9@$`'0```"MF`0`N````268!`%<```!X9@$`-@``
M`-!F`0`L````!V<!`"P````T9P$`,0```&%G`0`N````DV<!`"(```#"9P$`
M!@```.5G`0`(````[&<!``4```#U9P$`"````/MG`0`9````!&@!`!D````>
M:`$`*@```#AH`0`0````8V@!`"L```!T:`$`(P```*!H`0`A````Q&@!`"X`
M``#F:`$`-````!5I`0`(````2FD!`!<```!3:0$`"@```&MI`0`'````=FD!
M`"$```!^:0$`$````*!I`0`-````L6D!`!````"_:0$`!0```-!I`0`.````
MUFD!``@```#E:0$`"P```.YI`0`4````^FD!``<````/:@$`$P```!=J`0`(
M````*VH!`#8````T:@$`-P```&MJ`0`+````HVH!``D```"O:@$`"@```+EJ
M`0`4````Q&H!`"\```#9:@$`,@````EK`0`+````/&L!``X```!(:P$`#0``
M`%=K`0`/````96L!`!8```!U:P$`/@```(QK`0`G````RVL!``4```#S:P$`
M!0```/EK`0`G````_VL!`!\````G;`$`%@```$=L`0`+````7FP!`!<```!J
M;`$`#P```()L`0`$````DFP!``H```"7;`$`"0```*)L`0`+````K&P!``T`
M``"X;`$`#````,9L`0`.````TVP!``4```#B;`$`'@```.AL`0`$````!VT!
M``T````,;0$`,@```!IM`0!%````36T!``L```"3;0$`#@```)]M`0`.````
MKFT!``D```"];0$`"````,=M`0`0````T&T!`!4```#A;0$`$P```/=M`0`7
M````"VX!``<````C;@$`'@```"MN`0`5````2FX!`!0```!@;@$`!0```'5N
M`0`4````>VX!``8```"0;@$`"P```)=N`0`'````HVX!`",```"K;@$`%@``
M`,]N`0`/````YFX!``X```#V;@$`*@````5O`0`&````,&\!``P````W;P$`
M&````$1O`0`-````76\!`!$```!K;P$`"P```'UO`0`V````B6\!``T```#`
M;P$`"@```,YO`0`B````V6\!``L```#\;P$`#P````AP`0`0````&'`!`"X`
M```I<`$`.@```%AP`0`.````DW`!``T```"B<`$`!0```+!P`0`+````MG`!
M``P```#"<`$`#0```,]P`0`-````W7`!``X```#K<`$`#0```/IP`0`@````
M"'$!`"<````I<0$`*P```%%Q`0`(````?7$!``H```"&<0$`!@```)%Q`0`2
M````F'$!``X```"K<0$`%P```+IQ`0`R````TG$!`!X````%<@$`%@```"1R
M`0`<````.W(!``X```!8<@$`%````&=R`0`%````?'(!``X```""<@$`$P``
M`)%R`0`:````I7(!``<```#`<@$`!@```,AR`0`3````SW(!`!0```#C<@$`
M$0```/AR`0!+````"G,!``<```!6<P$`%````%YS`0`8````<W,!``<```",
M<P$`!0```)1S`0`,````FG,!``P```"G<P$`$@```+1S`0`$````QW,!``<`
M``#,<P$`"@```-1S`0`+````WW,!``P```#K<P$`#@```/AS`0`.````!W0!
M``4````6=`$`!0```!QT`0`N````(G0!`"8```!1=`$`(P```'AT`0`#````
MG'0!`!(```"@=`$`!@```+-T`0`&````NG0!`!X```#!=`$`%@```.!T`0`8
M````]W0!``X````0=0$`-P```!]U`0`.````5W4!`!<```!F=0$`00```'YU
M`0`T````P'4!`"4```#U=0$`%0```!MV`0`Q````,78!`!,```!C=@$`&P``
M`'=V`0`J````DW8!`%$```"^=@$`4````!!W`0`E````87<!``T```"'=P$`
M"0```)5W`0`#````GW<!``<```"C=P$`"@```*MW`0`(````MG<!``(```"_
M=P$`$````,)W`0`(````TW<!``P```#<=P$`%0```.EW`0`+````_W<!`!D`
M```+>`$`(````"5X`0`2````1G@!``4```!9>`$`"@```%]X`0`5````:G@!
M`!(```"`>`$`#````)-X`0`$````H'@!``<```"E>`$`,@```*UX`0`*````
MX'@!``P```#K>`$`"P```/AX`0`'````!'D!`!8````,>0$`4@```"-Y`0`Z
M````=GD!`"````"Q>0$`#P```-)Y`0`7````XGD!`#D```#Z>0$`!P```#1Z
M`0`&````/'H!``D```!#>@$`#@```$UZ`0`.````7'H!``0```!K>@$`!@``
M`'!Z`0`6````=WH!``P```".>@$`#0```)MZ`0`.````J7H!`!4```"X>@$`
M$@```,YZ`0`/````X7H!`!0```#Q>@$`0P````9[`0`*````2GL!`!L```!5
M>P$`-0```'%[`0`1````IWL!`!````"Y>P$`"P```,I[`0!I````UGL!`!H`
M``!`?`$`%P```%M\`0`G````<WP!`!L```";?`$`&@```+=\`0`7````TGP!
M`!L```#J?`$`&0````9]`0`?````('T!`!<```!`?0$`'````%A]`0`7````
M=7T!``P```"-?0$`$P```)I]`0`(````KGT!``<```"W?0$`"````+]]`0`0
M````R'T!`!$```#9?0$`"0```.M]`0`5````]7T!``T````+?@$`!@```!E^
M`0`=````('X!``<````^?@$`$P```$9^`0`#````6GX!`$8```!>?@$`0P``
M`*5^`0`R````Z7X!`#\````<?P$`-P```%Q_`0!7````E'\!``4```#L?P$`
M'P```/)_`0`O````$H`!``H```!"@`$`#0```$V``0`2````6X`!`"D```!N
M@`$`"````)B``0`-````H8`!`"T```"O@`$`<````-V``0`_````3H$!`#D`
M``".@0$`1@```,B!`0`$````#X(!`!`````4@@$`$````"6"`0`,````-H(!
M`!0```!#@@$`'0```%B"`0`<````=H(!`!$```"3@@$`/0```*6"`0!/````
MXX(!`"4````S@P$`(````%F#`0`<````>H,!``L```"7@P$`)P```*.#`0`:
M````RX,!`!\```#F@P$`'0````:$`0`H````)(0!``\```!-A`$`)0```%V$
M`0`@````@X0!`"0```"DA`$`)````,F$`0`@````[H0!`"4````/A0$`"P``
M`#6%`0`'````084!``T```!)A0$`#````%>%`0`7````9(4!``4```!\A0$`
M!@```(*%`0`Y````B84!``4```##A0$`#````,F%`0`'````UH4!``D```#>
MA0$`$P```.B%`0`&````_(4!``D````#A@$`!`````V&`0`0````$H8!``@`
M```CA@$`"````"R&`0`$````-88!``L````ZA@$`#````$:&`0`2````4X8!
M`!$```!FA@$`#````'B&`0`:````A88!``\```"@A@$`!P```+"&`0`-````
MN(8!``\```#&A@$`#````-:&`0`4````XX8!`!0```#XA@$`#P````V'`0`.
M````'8<!`!(````LAP$`%````#^'`0`.````5(<!``P```!CAP$`&P```'"'
M`0`L````C(<!`!,```"YAP$`'````,V'`0`H````ZH<!``8````3B`$`!P``
M`!J(`0`3````(H@!``4````VB`$`!````#R(`0`,````08@!`!<```!.B`$`
M$@```&:(`0`+````>8@!``T```"%B`$`%````).(`0`O````J(@!``H```#8
MB`$`#````..(`0`)````\(@!``8```#ZB`$`"0````&)`0`(````"XD!``D`
M```4B0$`!0```!Z)`0`*````)(D!`!$````OB0$`!@```$&)`0`.````2(D!
M``X```!7B0$`#0```&:)`0`+````=(D!`!````"`B0$`'0```)&)`0`1````
MKXD!``L```#!B0$``@```,V)`0`(````T(D!``<```#9B0$`#0```.&)`0`&
M````[XD!`!8```#VB0$`"0````V*`0`'````%XH!`#L````?B@$`*````%N*
M`0`T````A(H!`!4```"YB@$`!0```,^*`0`+````U8H!``<```#AB@$`"```
M`.F*`0`'````\HH!``4```#ZB@$`!P````"+`0`.````"(L!``D````7BP$`
M!@```"&+`0`(````*(L!``L````QBP$`!P```#V+`0`(````18L!``<```!.
MBP$`%@```%:+`0`)````;8L!``8```!WBP$`&0```'Z+`0`:````F(L!`"``
M``"SBP$`"P```-2+`0`<````X(L!`!0```#]BP$`!P```!*,`0`(````&HP!
M``@````CC`$`!0```"R,`0`0````,HP!`!````!#C`$`!@```%2,`0`9````
M6XP!``H```!UC`$`'````(",`0`'````G8P!``4```"EC`$`!0```*N,`0`0
M````L8P!`!0```#"C`$`"P```->,`0`-````XXP!`!<```#QC`$`"P````F-
M`0`:````%8T!`!0````PC0$`+P```$6-`0`)````=8T!``H```!_C0$`!P``
M`(J-`0`"````DHT!``X```"5C0$`"````*2-`0`?````K8T!`",```#-C0$`
M,0```/&-`0`X````(XX!`!L```!<C@$`,0```'B.`0`Q````JHX!`"<```#<
MC@$`(@````2/`0`@````)X\!`&0```!(CP$`'0```*V/`0`4````RX\!`!P`
M``#@CP$`70```/V/`0!5````6Y`!`#@```"QD`$`+0```.J0`0`S````&)$!
M`$L```!,D0$`2@```)B1`0!;````XY$!`"@````_D@$`+````&B2`0`X````
ME9(!`"4```#.D@$`*````/22`0`L````'9,!`"<```!*DP$`&P```'*3`0`>
M````CI,!`'4```"MDP$`/@```".4`0!"````8I0!`#T```"EE`$`/0```..4
M`0`I````(94!`"D```!+E0$`,0```'65`0`^````IY4!`"\```#FE0$`J0$`
M`!:6`0`C````P)<!`$\```#DEP$`%P```#28`0!(````3)@!`#8```"5F`$`
M/@```,R8`0`P````"YD!`"`````\F0$`/P```%V9`0`T````G9D!`!T```#2
MF0$`'@```/"9`0`J````#YH!`(4````ZF@$`,````,":`0!!````\9H!`&``
M```SFP$`6P```)2;`0!)````\)L!`#0````ZG`$`/````&^<`0`X````K)P!
M`!T```#EG`$`&`````.=`0"G````')T!`"$```#$G0$`'P```.:=`0`\````
M!IX!`"0```!#G@$`*````&B>`0`K````D9X!`"(```"]G@$`(0```.">`0`I
M`````I\!`"<````LGP$`%P```%2?`0`I````;)\!`"````"6GP$`,@```+>?
M`0`<````ZI\!`"X````'H`$`'0```#:@`0`1````5*`!`#,```!FH`$`)0``
M`)J@`0`X````P*`!`"<```#YH`$`/````"&A`0`F````7J$!`!\```"%H0$`
M,````*6A`0!I````UJ$!`#X```!`H@$`/@```'^B`0!'````OJ(!`#T````&
MHP$`90```$2C`0!-````JJ,!`%,```#XHP$`5P```$RD`0!5````I*0!`$8`
M``#ZI`$`*@```$&E`0`O````;*4!`%4```"<I0$`(````/*E`0`N````$Z8!
M`"L```!"I@$`,````&ZF`0`J````GZ8!`#X```#*I@$`5`````FG`0!2````
M7J<!`%H```"QIP$`,@````RH`0`K````/Z@!`$@```!KJ`$`2@```+2H`0`J
M````_Z@!`"8````JJ0$`+````%&I`0!.````?JD!`#(```#-J0$`,`````"J
M`0`=````,:H!`",```!/J@$`+P```'.J`0`L````HZH!`"T```#0J@$`<0``
M`/ZJ`0!O````<*L!`+,```#@JP$`%P```)2L`0`E````K*P!`#(```#2K`$`
M*0````6M`0`^````+ZT!`"(```!NK0$`4@```)&M`0`E````Y*T!``L````*
MK@$`L0```!:N`0`[````R*X!`"<````$KP$`3@```"RO`0!'````>Z\!`&(`
M``##KP$`20```":P`0!5````<+`!`$````#&L`$`+P````>Q`0`R````-[$!
M`"L```!JL0$`*0```):Q`0`/````P+$!`$4```#0L0$`(0```!:R`0`P````
M.+(!`"T```!IL@$`)0```)>R`0`<````O;(!`#$```#:L@$`,0````RS`0`+
M````/K,!``<```!*LP$`!P```%*S`0`$````6K,!``T```!?LP$`"P```&VS
M`0`.````>;,!``L```"(LP$`!0```)2S`0`0````FK,!``(```"KLP$`"@``
M`*ZS`0!6````N;,!`%D````0M`$`!0```&JT`0`2````<+0!``0```"#M`$`
M!P```(BT`0`(````D+0!``4```"9M`$``P```)^T`0`0````H[0!`!<```"T
MM`$`#````,RT`0`,````V;0!``T```#FM`$`$P```/2T`0`-````"+4!``(`
M```6M0$`!P```!FU`0`&````(;4!`!0````HM0$`#````#VU`0`8````2K4!
M``8```!CM0$`$@```&JU`0`,````?;4!``,```"*M0$`*@```(ZU`0`$````
MN;4!``8```"^M0$`!P```,6U`0`?````S;4!`#4```#MM0$`+@```".V`0`O
M````4K8!`!<```""M@$`(````)JV`0`;````N[8!`!@```#7M@$`)````/"V
M`0`?````%;<!`!H````UMP$`(````%"W`0`:````<;<!`#(```",MP$`+P``
M`+^W`0`K````[[<!`!\````;N`$`(P```#NX`0`?````7[@!`!H```!_N`$`
M)0```)JX`0`F````P+@!`"4```#GN`$`)`````VY`0`8````,KD!`!T```!+
MN0$`)````&FY`0`8````CKD!`"(```"GN0$`)0```,JY`0`\````\+D!`!\`
M```MN@$`(P```$VZ`0`?````<;H!`"````"1N@$`&@```+*Z`0`8````S;H!
M`!@```#FN@$`)@```/^Z`0`>````)KL!`"D```!%NP$`'@```&^[`0`*````
MCKL!`!,```"9NP$`"````*V[`0`)````MKL!`!8```#`NP$`#````->[`0`7
M````Y+L!`"\```#\NP$`)````"R\`0`'````4;P!`!\```!9O`$`#P```'F\
M`0`4````B;P!``X```">O`$`#0```*V\`0`D````N[P!``4```#@O`$`!P``
M`.:\`0`,````[KP!``\```#[O`$`$0````N]`0`B````';T!`"4```!`O0$`
M'0```&:]`0`:````A+T!`!$```"?O0$`!P```+&]`0#'````N;T!``8```"!
MO@$`"P```(B^`0`:````E+X!`!4```"OO@$`!@```,6^`0`)````S+X!`!T`
M``#6O@$`&````/2^`0`+````#;\!`!<````9OP$`!@```#&_`0`S````.+\!
M`!,```!LOP$`$P```("_`0`'````E+\!``\```"<OP$`$0```*R_`0`>````
MOK\!``<```#=OP$`,@```.6_`0`$````&,`!`"$````=P`$`$P```#_``0`,
M````4\`!`!$```!@P`$`,@```'+``0`(````I<`!``D```"NP`$`"@```+C`
M`0`4````P\`!``H```#8P`$`'0```./``0`(`````<$!`!\````*P0$`"```
M`"K!`0`:````,\$!``8```!.P0$`%0```%7!`0`'````:\$!``@```!SP0$`
M"0```'S!`0`_````AL$!``<```#&P0$`#P```,[!`0`.````WL$!`!````#M
MP0$`"0```/[!`0`)````",(!``@````2P@$`$P```!O"`0`$````+\(!``<`
M```TP@$`$@```#S"`0`F````3\(!`!D```!VP@$`&````)#"`0`+````J<(!
M``X```"UP@$`&0```,3"`0`*````WL(!`"0```#IP@$`(0````[#`0`*````
M,,,!`!,````[PP$`)P```$_#`0`)````=\,!``\```"!PP$`%P```)'#`0`4
M````J<,!`"@```"^PP$`#P```.?#`0`@````]\,!`!0````8Q`$`"@```"W$
M`0`,````.,0!`!<```!%Q`$`!````%W$`0`J````8L0!`!$```"-Q`$`!P``
M`)_$`0`"````I\0!`!````"JQ`$`&````+O$`0`+````U,0!``,```#@Q`$`
M"````.3$`0`&````[<0!``<```#TQ`$`#0```/S$`0`+````"L4!`!0````6
MQ0$`%0```"O%`0`.````0<4!`"\```!0Q0$`(````(#%`0`<````H<4!`%H`
M``"^Q0$`/P```!G&`0`V````6<8!``P```"0Q@$`,0```)W&`0`)````S\8!
M``4```#9Q@$`$@```-_&`0`_````\L8!`!(````RQP$`"@```$7'`0`&````
M4,<!``0```!7QP$`!````%S'`0`*````8<<!`!,```!LQP$`!0```(#'`0`&
M````AL<!``8```"-QP$`!````)3'`0`,````F<<!``H```"FQP$`!0```+''
M`0`8````M\<!`!D```#0QP$`'P```.K'`0`=````"L@!`!$````HR`$``@``
M`#K(`0`$````/<@!``H```!"R`$`!@```$W(`0`%````5,@!``,```!:R`$`
M#````%[(`0`[````:\@!`"<```"GR`$`(0```,_(`0`D````\<@!`$4````6
MR0$`&@```%S)`0`=````=\D!`#4```"5R0$`5@```,O)`0`H````(LH!`%,`
M``!+R@$`.@```)_*`0!"````VLH!`!D````=RP$`%P```#?+`0"+````3\L!
M`!D```#;RP$`*@```/7+`0`K````(,P!`'(```!,S`$`(````+_,`0`U````
MX,P!`"$````6S0$`10```#C-`0`F````?LT!`#````"ES0$`2P```-;-`0!.
M````(LX!`"<```!QS@$`*0```)G.`0`A````P\X!`"@```#ES@$`*P````[/
M`0`=````.L\!`"D```!8SP$`)@```(+/`0`M````J<\!`"4```#7SP$`*```
M`/W/`0`H````)M`!`"(```!/T`$`*0```'+0`0`B````G-`!`#T```"_T`$`
M00```/W0`0`H````/]$!`"P```!HT0$`,````)71`0`2````QM$!`!,```#9
MT0$`$````.W1`0!Y````_M$!``D```!XT@$`'````(+2`0`0````G](!``\`
M``"PT@$`)P```,#2`0`.````Z-(!`',```#WT@$`?````&O3`0!`````Z-,!
M`"L````IU`$`%P```%74`0`J````;=0!`#0```"8U`$`%@```,W4`0`/````
MY-0!`"@```#TU`$`'P```!W5`0!`````/=4!`!\```!^U0$`'````)[5`0!1
M````N]4!`!0````-U@$`#P```"+6`0`*````,M8!``4````]U@$`!@```$/6
M`0`(````2M8!``4```!3U@$`$@```%G6`0`,````;-8!`!````!YU@$`$P``
M`(K6`0`=````GM8!``\```"\U@$`#P```,S6`0`$````W-8!``H```#AU@$`
M!````.S6`0`#````\=8!``D```#UU@$`!P```/_6`0`+````!]<!``@````3
MUP$`!P```!S7`0`%````)-<!``D````JUP$`%````#37`0`&````2=<!``<`
M``!0UP$`"````%C7`0`/````8=<!``\```!QUP$`"````('7`0`,````BM<!
M``8```"7UP$`"0```)[7`0`+````J-<!``\```"TUP$`!@```,37`0`'````
MR]<!``T```#3UP$`!@```.'7`0`4````Z-<!``<```#]UP$``P````78`0`)
M````"=@!``8````3V`$`#````!K8`0`*````)]@!``P````RV`$`"@```#_8
M`0`/````2M@!``4```!:V`$`"````&#8`0`$````:=@!``H```!NV`$`!P``
M`'G8`0`$````@=@!``0```"&V`$`&0```(O8`0`"````I=@!``D```"HV`$`
M!@```++8`0`#````N=@!``8```"]V`$`#````,38`0`G````T=@!``0```#Y
MV`$`!````/[8`0`/`````]D!`!,````3V0$`!P```"?9`0`"````+]D!``<`
M```RV0$`!@```#K9`0`&````0=D!`!````!(V0$`$@```%G9`0`.````;-D!
M``\```![V0$`!@```(O9`0`)````DMD!`"(```"<V0$`!P```+_9`0`'````
MQ]D!``L```#/V0$`!0```-O9`0`"````X=D!``L```#DV0$`#@```/#9`0`.
M````_]D!`,@!```.V@$`#````-?;`0`+````Y-L!``@```#PVP$`#@```/G;
M`0`5````"-P!``T````>W`$`!P```"S<`0`(````--P!``@````]W`$`"@``
M`$;<`0`*````4=P!``,```!<W`$``0```&#<`0`9````8MP!``H```!\W`$`
M50```(?<`0`Q````W=P!`%@````/W0$`-````&C=`0`3````G=T!`!(```"Q
MW0$`#0```,3=`0`(````TMT!``4```#;W0$`'0```.'=`0`,````_]T!``T`
M```,W@$`%0```!K>`0`0````,-X!`"X```!!W@$`"P```'#>`0`8````?-X!
M`"X```"5W@$`#0```,3>`0`0````TMX!``\```#CW@$`)````//>`0`A````
M&-\!`",````ZWP$`%P```%[?`0`0````=M\!``@```"'WP$`$P```)#?`0`@
M````I-\!`!L```#%WP$`#0```.'?`0`6````[]\!`"`````&X`$`+````"?@
M`0`*````5.`!``L```!?X`$`"P```&O@`0`/````=^`!``8```"'X`$`&@``
M`([@`0`R````J>`!`$T```#<X`$`C@```"KA`0!B````N>$!`!\````<X@$`
M*0```#SB`0`0````9N(!`!8```!WX@$`"P```([B`0!5````FN(!`#$```#P
MX@$`6````"+C`0`T````>^,!``D```"PXP$`"@```+KC`0`2````Q>,!`!(`
M``#8XP$`"````.OC`0`)````].,!``D```#^XP$`+0````CD`0`9````-N0!
M`#T```!0Y`$`+0```([D`0`X````O.0!`$$```#UY`$`4P```#?E`0!1````
MB^4!`%D```#=Y0$`5P```#?F`0`[````C^8!``H```#+Y@$`#@```-;F`0`6
M````Y>8!``4```#\Y@$``0````+G`0`&````!.<!`!D````+YP$`#````"7G
M`0`4````,N<!`!<```!'YP$`$@```%_G`0`'````<N<!``@```!ZYP$`)P``
M`(/G`0`F````J^<!`!$```#2YP$`'P```.3G`0`+````!.@!``\````0Z`$`
M!````"#H`0`$````)>@!`!$````JZ`$`$````#SH`0`'````3>@!`!0```!5
MZ`$`$0```&KH`0`8````?.@!``X```"5Z`$`$0```*3H`0`*````MN@!``P`
M``#!Z`$`*0```,[H`0`@````^.@!`!,````9Z0$`%P```"WI`0`0````1>D!
M`!D```!6Z0$`(P```'#I`0`G````E.D!`!@```"\Z0$`%@```-7I`0`N````
M[.D!`"`````;Z@$`.````#SJ`0`&````=>H!``<```!\Z@$`"````(3J`0!*
M````C>H!``P```#8Z@$`"````.7J`0`+````[NH!``<```#ZZ@$`"`````+K
M`0`/````"^L!``@````;ZP$`"@```"3K`0`#````+^L!`!D````SZP$`#P``
M`$WK`0`9````7>L!`!0```!WZP$`30```(SK`0!+````VNL!`%0````F[`$`
M3````'OL`0`]````R.P!`!(````&[0$`*````!GM`0`,````0NT!`"<```!/
M[0$`%P```'?M`0`C````C^T!`!T```"S[0$`$@```-'M`0`2````Y.T!`!X`
M``#W[0$`!````!;N`0`4````&^X!``X````P[@$`40```#_N`0`?````D>X!
M`#$```"Q[@$`!@```./N`0`&````ZNX!``@```#Q[@$`#@```/KN`0`'````
M">\!``H````1[P$`$0```!SO`0`*````+N\!`!$````Y[P$`"````$OO`0`/
M````5.\!`!8```!D[P$`#0```'OO`0`3````B>\!`#4```"=[P$`-0```-/O
M`0`:````"?`!``@````D\`$`$@```"WP`0`%````0/`!`!8```!&\`$`'@``
M`%WP`0`-````?/`!`#0```"*\`$`5````+_P`0`C````%/$!`#`````X\0$`
M.````&GQ`0`\````HO$!`#````#?\0$`,````!#R`0`X````0?(!`$$```!Z
M\@$`1````+SR`0`)`````?,!``<````+\P$`%````!/S`0`,````*/,!``4`
M```U\P$`!0```#OS`0`)````0?,!`!````!+\P$`"P```%SS`0`:````:/,!
M``D```"#\P$`,P```(WS`0`/````P?,!``@```#1\P$`$````-KS`0`Q````
MZ_,!``\````=]`$`6P```"WT`0`N````B?0!``<```"X]`$`*0```,#T`0`'
M````ZO0!`"8```#R]`$`,P```!GU`0`Q````3?4!`#````!_]0$`"0```+#U
M`0`%````NO4!``@```#`]0$`!0```,GU`0`)````S_4!``@```#9]0$`.0``
M`.+U`0`M````'/8!`#@```!*]@$`4P```(/V`0`W````U_8!`#8````/]P$`
M-P```$;W`0`V````?O<!`#<```"U]P$`)0```.WW`0`J````$_@!`#<````^
M^`$`/0```';X`0`/````M/@!`!,```#$^`$`)P```-CX`0`<`````/D!`%$`
M```=^0$`$@```&_Y`0`.````@OD!`!$```"1^0$`"P```*/Y`0`,````K_D!
M``L```"\^0$`"@```,CY`0`&````T_D!``P```#:^0$`&@```.?Y`0`F````
M`OH!``8````I^@$`!P```##Z`0`6````./H!``D```!/^@$`"````%GZ`0`&
M````8OH!``P```!I^@$`"0```';Z`0`&````@/H!``4```"'^@$`,P```(WZ
M`0`%````P?H!``<```#'^@$`!@```,_Z`0`*````UOH!``T```#A^@$`)0``
M`._Z`0`/````%?L!``D````E^P$`/````"_[`0`$````;/L!``4```!Q^P$`
M!P```'?[`0`'````?_L!``4```"'^P$`#0```(W[`0`&````F_L!`!,```"B
M^P$``P```+;[`0`C````NOL!``@```#>^P$`"@```.?[`0`-````\OL!``@`
M````_`$`(P````G\`0`1````+?P!``D````__`$`$@```$G\`0`,````7/P!
M``<```!I_`$``P```''\`0`#````=?P!`!0```!Y_`$`%````([\`0`-````
MH_P!``@```"Q_`$`"````+K\`0`(````P_P!``<```#,_`$`,@```-3\`0`T
M````!_T!`%<````\_0$`5P```)3]`0`D````[/T!``8````1_@$`!@```!C^
M`0`-````'_X!`!<````M_@$`2````$7^`0`:````COX!`!P```"I_@$`+```
M`,;^`0`;````\_X!`"X````/_P$`<@```#[_`0`E````L?\!``H```#7_P$`
M!P```.+_`0`2````ZO\!`!$```#]_P$`!0````\``@`/````%0`"``X````E
M``(`%````#0``@`0````20`"`!0```!:``(`#P```&\``@`5````?P`"``4`
M``"5``(`%P```)L``@`;````LP`"`!<```#/``(`%````.<``@`#````_``"
M``P``````0(`!@````T!`@`*````%`$"``T````?`0(`8P```"T!`@`M````
MD0$"`&@```"_`0(`3P```"@"`@`$````>`("`!0```!]`@(`%@```)("`@`L
M````J0("`!<```#6`@(`/````.X"`@`L````*P,"``4```!8`P(`!````%X#
M`@`>````8P,"`!@```""`P(`#````)L#`@`7````J`,"``P```#``P(`&```
M`,T#`@`,````Y@,"`!@```#S`P(`+0````P$`@`U````.@0"`$D```!P!`(`
M#@```+H$`@`B````R00"``@```#L!`(`&@```/4$`@`8````$`4"`!,````I
M!0(`'````#T%`@!+````6@4"`"$```"F!0(`.````,@%`@`V`````08"`#4`
M```X!@(`,@```&X&`@`\````H08"`"(```#>!@(`5P````$'`@`8````60<"
M`#0```!R!P(`.````*<'`@`4````X`<"`#T```#U!P(`,@```#,(`@`'````
M9@@"``L```!N"`(`$0```'H(`@`.````C`@"``@```";"`(`!P```*0(`@`0
M````K`@"``D```"]"`(`#0```,<(`@`8````U0@"`!````#N"`(`%0```/\(
M`@`0````%0D"``@````F"0(`!0```"\)`@`1````-0D"``L```!'"0(`#```
M`%,)`@`(````8`D"``T```!I"0(`!P```'<)`@`&````?PD"`!$```"&"0(`
M"````)@)`@`,````H0D"``<```"N"0(`!0```+8)`@`)````O`D"`!4```#&
M"0(`'0```-P)`@!*````^@D"``@```!%"@(`"````$X*`@`3````5PH"``L`
M``!K"@(`&@```'<*`@`C````D@H"``X```"V"@(`!0```,4*`@`=````RPH"
M`!````#I"@(`$0```/H*`@`T````#`L"`$0```!!"P(`'P```(8+`@`;````
MI@L"`#$```#""P(`"@```/0+`@`;````_PL"`!X````;#`(`40```#H,`@`P
M````C`P"``\```"]#`(`!P```,T,`@`)````U0P"``\```#?#`(`$P```.\,
M`@`'`````PT"``T````+#0(`"0```!D-`@`1````(PT"`"$````U#0(`(0``
M`%<-`@`D````>0T"`"0```">#0(`&````,,-`@`A````W`T"`!L```#^#0(`
M)0```!H.`@`>````0`X"`!H```!?#@(`'0```'H.`@`8````F`X"`",```"Q
M#@(`.0```-4.`@`I````#P\"`!T````Y#P(`-@```%</`@`R````C@\"`!L`
M``#!#P(`)@```-T/`@`P````!!`"`"X````U$`(`$0```&00`@`I````=A`"
M``X```"@$`(`L````*\0`@`0````8!$"`!@```!Q$0(`(P```(H1`@`D````
MKA$"`!\```#3$0(`&P```/,1`@`@````#Q("`"$````P$@(`+@```%(2`@`<
M````@1("`!X```">$@(`*0```+T2`@!+````YQ("``\````S$P(`!````$,3
M`@`2````2!,"``@```!;$P(`#P```&03`@`.````=!,"`!D```"#$P(`#@``
M`)T3`@`J````K!,"``X```#7$P(`*0```.83`@`=````$!0"`'$````N%`(`
M$@```*`4`@`+````LQ0"`!0```"_%`(`"@```-04`@`$````WQ0"``P```#D
M%`(`#P```/$4`@`/`````14"`!8````1%0(`$P```"@5`@`,````/!4"`#P`
M``!)%0(`(@```(85`@`X````J14"``L```#B%0(`$0```.X5`@`$`````!8"
M``\````%%@(`%0```!46`@`8````*Q8"``\```!$%@(``@```%06`@`%````
M5Q8"``8```!=%@(`$@```&06`@`%````=Q8"``L```!]%@(`#````(D6`@`#
M````EA8"``\```":%@(`"````*H6`@`8````LQ8"``@```#,%@(`"@```-46
M`@`0````X!8"`!````#Q%@(`$P````(7`@`9````%A<"`!4````P%P(`"```
M`$87`@`)````3Q<"``8```!9%P(`%@```&`7`@`4````=Q<"`!````",%P(`
M#@```)T7`@`,````K!<"`!<```"Y%P(`&````-$7`@`,````ZA<"``X```#W
M%P(`(P````88`@`L````*A@"`!<```!7&`(`.@```&\8`@`[````JA@"``P`
M``#F&`(`'@```/,8`@`7````$AD"`!4````J&0(`!P```$`9`@`.````2!D"
M`!4```!7&0(`&@```&T9`@`,````B!D"``8```"5&0(`$P```)P9`@`L````
ML!D"``@```#=&0(`#@```.89`@`%````]1D"``<```#[&0(`)P````,:`@`_
M````*QH"``4```!K&@(`"0```'$:`@`>````>QH"``L```":&@(`$P```*8:
M`@`3````NAH"`!,```#.&@(`!P```.(:`@`(````ZAH"`!D```#S&@(`$@``
M``T;`@`E````(!L"`!@```!&&P(`$````%\;`@`6````<!L"`"(```"'&P(`
M"0```*H;`@`5````M!L"``@```#*&P(`#````-,;`@`F````X!L"``@````'
M'`(`)@```!`<`@`@````-QP"`!L```!8'`(`2````'0<`@`(````O1P"`!8`
M``#&'`(`"0```-T<`@`'````YQP"``H```#O'`(`&@```/H<`@`I````%1T"
M`!(````_'0(`(P```%(=`@`Q````=AT"`!<```"H'0(`$````,`=`@`;````
MT1T"`!P```#M'0(`#P````H>`@`%````&AX"``8````@'@(`$````"<>`@`#
M````.!X"`"$````\'@(`!P```%X>`@`'````9AX"`!8```!N'@(`#````(4>
M`@`;````DAX"``\```"N'@(`#0```+X>`@`-````S!X"`!0```#:'@(`&```
M`.\>`@`H````"!\"`!4````Q'P(`%0```$<?`@`4````71\"`!8```!R'P(`
M&P```(D?`@`V````I1\"`!4```#<'P(`!0```/(?`@`%````^!\"``L```#^
M'P(`"`````H@`@`"````$R`"``4````6(`(`#P```!P@`@`A````+"`"`!(`
M``!.(`(`$````&$@`@`?````<B`"`!0```"2(`(`%0```*<@`@`.````O2`"
M``\```#,(`(`$0```-P@`@`>````[B`"``P````-(0(`#P```!HA`@`Q````
M*B$"`!8```!<(0(`+0```',A`@`3````H2$"``4```"U(0(`%P```+LA`@`,
M````TR$"`!(```#@(0(`"@```/,A`@`.````_B$"``T````-(@(`BP```!LB
M`@`6````IR("`"T```"^(@(`+````.PB`@`@````&2,"`"T````Z(P(`$```
M`&@C`@`'````>2,"``4```"!(P(`*0```(<C`@`A````L2,"``@```#3(P(`
M!P```-PC`@`'````Y","``8```#L(P(`'0```/,C`@`0````$20"``X````B
M)`(`$0```#$D`@`/````0R0"`!L```!3)`(`$0```&\D`@`-````@20"`!<`
M``"/)`(`!P```*<D`@`(````KR0"``P```"X)`(`%P```,4D`@`/````W20"
M``L```#M)`(`%````/DD`@`O````#B4"`$(````^)0(`"0```($E`@`-````
MBR4"`#L```"9)0(`&0```-4E`@`(````[R4"``T```#X)0(`'0````8F`@`9
M````)"8"`"$````^)@(`(````&`F`@`:````@28"`!L```"<)@(`)0```+@F
M`@`:````WB8"``4```#Y)@(`'0```/\F`@`0````'2<"``X````N)P(``P``
M`#TG`@`$````02<"``T```!&)P(`#@```%0G`@`.````8R<"`!P```!R)P(`
M*0```(\G`@`.````N2<"`"$```#()P(`#P```.HG`@`7````^B<"``<````2
M*`(`"P```!HH`@`$````)B@"``8````K*`(`&````#(H`@`9````2R@"``\`
M``!E*`(`#0```'4H`@`-````@R@"``X```"1*`(`'P```*`H`@`/````P"@"
M`!````#0*`(`)````.$H`@`C````!BD"``8````J*0(`&````#$I`@`>````
M2BD"``@```!I*0(`!@```'(I`@`.````>2D"`!8```"(*0(`#0```)\I`@`.
M````K2D"``T```"\*0(`"````,HI`@`(````TRD"``H```#<*0(`!````.<I
M`@`4````["D"`!`````!*@(`#@```!(J`@`=````(2H"`!T````_*@(`"P``
M`%TJ`@`%````:2H"`"0```!O*@(`#P```)0J`@!K````I"H"`!H````0*P(`
M/0```"LK`@`)````:2L"``8```!S*P(`"@```'HK`@`&````A2L"``@```",
M*P(`!````)4K`@`)````FBL"``H```"D*P(`$0```*\K`@`7````P2L"``H`
M``#9*P(``@```.0K`@`$````YRL"``<```#L*P(`%0```/0K`@`5````"BP"
M`!$````@+`(`$````#(L`@`;````0RP"`!(```!?+`(`%````'(L`@`:````
MARP"``,```"B+`(``@```*8L`@`)````J2P"``(```"S+`(`#@```+8L`@`&
M````Q2P"``H```#,+`(`!0```-<L`@`&````W2P"`!L```#D+`(`!0`````M
M`@`9````!BT"``@````@+0(`!@```"DM`@`2````,"T"`!<```!#+0(`$```
M`%LM`@`)````;"T"``<```!V+0(`)P```'XM`@`%````IBT"``D```"L+0(`
M#0```+8M`@`-````Q"T"``8```#2+0(`&0```-DM`@`/````\RT"``L````#
M+@(`!0````\N`@`2````%2X"``<````H+@(`!P```#`N`@`8````."X"`!T`
M``!1+@(`!P```&\N`@`*````=RX"``0```""+@(`"0```(<N`@`(````D2X"
M``L```":+@(`"P```*8N`@`&````LBX"``T```"Y+@(`!@```,<N`@`#````
MSBX"``0```#2+@(`$0```-<N`@`W````Z2X"`$$````A+P(`.````&,O`@`F
M````G"\"``4```##+P(`#P```,DO`@`&````V2\"``@```#@+P(`"````.DO
M`@`?````\B\"`!H````2,`(`!0```"TP`@`(````,S`"`!,````\,`(`"```
M`%`P`@`)````63`"`!<```!C,`(`)````'LP`@`&````H#`"`"0```"G,`(`
M#0```,PP`@`/````VC`"``8```#J,`(`$0```/$P`@`'`````S$"``8````+
M,0(`%0```!(Q`@`%````*#$"``L````N,0(`#````#HQ`@`(````1S$"``D`
M``!0,0(`!0```%HQ`@`N````8#$"`#0```"/,0(`/````,0Q`@`G`````3("
M`#X````I,@(`.````&@R`@`H````H3("`#(```#*,@(`+0```/TR`@`U````
M*S,"`"@```!A,P(`$@```(HS`@`3````G3,"``T```"Q,P(`,0```+\S`@`@
M````\3,"`!P````2-`(`'````"\T`@`:````3#0"`!\```!G-`(`!P```(<T
M`@`(````CS0"``<```"8-`(`"````*`T`@`$````J30"`"0```"N-`(`)@``
M`-,T`@`D````^C0"`#$````?-0(`#0```%$U`@`K````7S4"`"L```"+-0(`
M#0```+<U`@`:````Q34"``4```#@-0(`"0```.8U`@`8````\#4"`"@````)
M-@(`%@```#(V`@`2````238"``8```!<-@(`"P```&,V`@`,````;S8"``X`
M``!\-@(`#P```(LV`@`X````FS8"`(````#4-@(`9@```%4W`@`)````O#<"
M``T```#&-P(`#P```-0W`@`+````Y#<"``P```#P-P(`$0```/TW`@`2````
M#S@"``X````B.`(`!P```#$X`@`*````.3@"``\```!$.`(`%@```%0X`@`1
M````:S@"`!,```!].`(`)P```)$X`@`F````N3@"`"<```#@.`(`%P````@Y
M`@`;````(#D"`"(````\.0(`%@```%\Y`@`6````=CD"`"<```"-.0(`#P``
M`+4Y`@`(````Q3D"``\```#..0(`'@```-XY`@`4````_3D"`!$````2.@(`
M"0```"0Z`@`/````+CH"``4````^.@(`,P```$0Z`@`I````>#H"`!X```"B
M.@(`,````,$Z`@!]````\CH"`!````!P.P(`!0```($[`@`4````ASL"``D`
M``"<.P(`"0```*8[`@`)````L#L"`!T```"Z.P(`*0```-@[`@`H`````CP"
M``8````K/`(`$@```#(\`@`5````13P"``X```!;/`(`)P```&H\`@`F````
MDCP"`!L```"Y/`(`#@```-4\`@`3````Y#P"`!4```#X/`(`'P````X]`@`A
M````+CT"`!T```!0/0(`'P```&X]`@`@````CCT"`"(```"O/0(`&````-(]
M`@`W````ZST"``\````C/@(`$0```#,^`@`1````13X"`!,```!7/@(`#0``
M`&L^`@`2````>3X"`!0```",/@(`#P```*$^`@`1````L3X"`#(```##/@(`
M%@```/8^`@`4````#3\"`#P````B/P(`%````%\_`@`*````=#\"`!,```!_
M/P(`,````),_`@`/````Q#\"`!H```#4/P(`(@```.\_`@`2````$D`"`"@`
M```E0`(`)0```$Y``@`9````=$`"`!D```".0`(`%P```*A``@`-````P$`"
M`!(```#.0`(`'P```.%``@`B`````4$"`!H````D00(`*0```#]!`@`H````
M:4$"`!(```"200(`%P```*5!`@`<````O4$"`!8```#:00(`"````/%!`@`'
M````^D$"`!@````"0@(`!````!M"`@`%````($("``L````F0@(`$````#)"
M`@`&````0T("``P```!*0@(`!P```%="`@`&````7T("``<```!F0@(`!0``
M`&Y"`@`(````=$("`!@```!]0@(`!@```)9"`@`)````G4("``@```"G0@(`
M!@```+!"`@`(````MT("`!$```#`0@(`$@```-)"`@`/````Y4("`!````#U
M0@(``@````9#`@`*````"4,"`!$````40P(`!````"9#`@`A````*T,"``\`
M``!-0P(`#P```%U#`@`6````;4,"``L```"$0P(`"0```)!#`@`+````FD,"
M`"\```"F0P(`,P```-9#`@`$````"D0"``@````/1`(`!````!A$`@`%````
M'40"`!$````C1`(`!@```#5$`@`*````/$0"``H```!'1`(`!0```%)$`@`C
M````6$0"``X```!\1`(`&0```(M$`@`0````I40"`!$```"V1`(`%0```,A$
M`@`7````WD0"`!P```#V1`(`&@```!-%`@`%````+D4"``4````T10(`"0``
M`#I%`@`9````1$4"``<```!>10(`!@```&9%`@`-````;44"``X```![10(`
M!P```(I%`@`2````DD4"``<```"E10(`!0```*U%`@`/````LT4"``X```##
M10(`"@```-)%`@`0````W44"`!(```#N10(`%`````%&`@`4````%D8"``T`
M```K1@(`%@```#E&`@`(````4$8"``4```!91@(`$@```%]&`@!(````<D8"
M`"P```"[1@(`!@```.A&`@`;````[T8"``\````+1P(`(P```!M'`@`/````
M/T<"`!4```!/1P(`#@```&5'`@"*````=$<"``T```#_1P(`#P````U(`@`)
M````'4@"``\````G2`(`#P```#=(`@`1````1T@"`!````!92`(`$````&I(
M`@`>````>T@"``H```":2`(`"````*5(`@`,````KD@"`!8```"[2`(`#```
M`-)(`@`,````WT@"``4```#L2`(`#````/)(`@`2````_T@"``D````220(`
M#````!Q)`@`>````*4D"`&<```!(20(`$P```+!)`@`+````Q$D"``4```#0
M20(`!0```-9)`@`0````W$D"`!(```#M20(`%`````!*`@`3````%4H"``@`
M```I2@(`"P```#)*`@`"````/DH"``H```!!2@(`+P```$Q*`@`#````?$H"
M``4```"`2@(`)@```(9*`@`;````K4H"``H```#)2@(`!0```-1*`@`%````
MVDH"`!,```#@2@(`#0```/1*`@`E`````DL"``@````H2P(`)````#%+`@`2
M````5DL"``8```!I2P(`"````'!+`@`'````>4L"``0```"!2P(`!0```(9+
M`@!N````C$L"``H```#[2P(`#0````9,`@`&````%$P"``4````;3`(`,0``
M`"%,`@`S````4TP"``T```"'3`(`+````)5,`@`M````PDP"`!P```#P3`(`
M*0````U-`@`R````-TT"`!$```!J30(`"@```'Q-`@`7````ATT"`!@```"?
M30(`$0```+A-`@`*````RDT"``D```#530(`&0```-]-`@`G````^4T"`"D`
M```A3@(`*````$M.`@`:````=$X"``\```"/3@(`(P```)].`@`H````PTX"
M``8```#L3@(`!P```/-.`@`(````^TX"``X````$3P(`$@```!-/`@`/````
M)D\"`!$````V3P(`$@```$A/`@`?````6T\"``<```![3P(`%@```(-/`@`.
M````FD\"``P```"I3P(`!@```+9/`@`/````O4\"``P```#-3P(`#@```-I/
M`@`/````Z4\"``\```#Y3P(`$P````E0`@!%````'5`"`!````!C4`(`$```
M`'10`@`*````A5`"`!$```"04`(`#````*)0`@`1````KU`"`"$```#!4`(`
M-@```.-0`@`=````&E$"``H````X40(`)@```$-1`@`)````:E$"``8```!T
M40(`'````'M1`@!A````F%$"``8```#Z40(`"`````%2`@`&````"E("`!0`
M```14@(`"0```"92`@`(````,%("`"D````Y4@(`*````&-2`@`)````C%("
M``4```"64@(`*P```)Q2`@!G````R%("`"D````P4P(`+@```%I3`@`8````
MB5,"``(```"B4P(`#0```*53`@`%````LU,"`!0```"Y4P(`!@```,Y3`@`*
M````U5,"``4```#@4P(`"````.93`@`&````[U,"``D```#V4P(`"P````!4
M`@`'````#%0"``@````45`(`"P```!U4`@`&````*50"``X````P5`(`$```
M`#]4`@`1````4%0"``D```!B5`(`#0```&Q4`@`/````>E0"`!````"*5`(`
M#P```)M4`@`-````JU0"`!,```"Y5`(`#P```,U4`@`(````W50"`!X```#F
M5`(`&0````55`@`3````'U4"``@````S50(`"@```#Q5`@`6````1U4"``<`
M``!>50(`#P```&95`@`(````=E4"``4```!_50(`)P```(55`@`'````K54"
M``4```"U50(`#@```+M5`@`%````RE4"``@```#050(`$0```-E5`@`1````
MZU4"`!H```#]50(`%@```!A6`@`4````+U8"`!<```!$5@(`&@```%Q6`@`?
M````=U8"`!@```"75@(``P```+!6`@`%````M%8"`!$```"Z5@(`!````,Q6
M`@`.````T58"``X```#@5@(`"P```.]6`@`*````^U8"`!8````&5P(`(@``
M`!U7`@`+````0%<"``L```!,5P(`%````%A7`@`'````;5<"``H```!U5P(`
M!0```(!7`@`,````AE<"``T```"35P(`#@```*%7`@`)````L%<"``4```"Z
M5P(`!P```,!7`@`#````R%<"``0```#,5P(``@```-%7`@`8````U%<"``T`
M``#M5P(`&P```/M7`@`,````%U@"`"@````D6`(`)0```$U8`@`@````<U@"
M`"L```"46`(`&````,!8`@`^````V5@"`#0````860(`%````$U9`@`J````
M8ED"`$4```"-60(`"@```--9`@`L````WED"`#,````+6@(`.````#]:`@`X
M````>%H"`#T```"Q6@(`%````.]:`@`:````!%L"`!L````?6P(`'````#M;
M`@`Z````6%L"`!H```"36P(`(P```*Y;`@`L````TEL"`!P```#_6P(`&P``
M`!Q<`@`4````.%P"`!\```!-7`(`-0```&U<`@`;````HUP"`!L```"_7`(`
M#@```-M<`@`P````ZEP"`#`````;70(`-````$Q=`@`]````@5T"`#(```"_
M70(`+P```/)=`@!R````(EX"`"8```"57@(`/@```+Q>`@`]````^UX"`"H`
M```Y7P(`#````&1?`@`*````<5\"`"H```!\7P(`%@```*=?`@`,````OE\"
M`#,```#+7P(`'````/]?`@`U````'&`"`"<```!28`(`#0```'I@`@!$````
MB&`"`#\```#-8`(`#P````UA`@`%````'6$"`!L````C80(`%@```#]A`@`2
M````5F$"``@```!I80(`$0```')A`@`9````A&$"``8```">80(`!P```*5A
M`@`)````K6$"``X```"W80(`%@```,9A`@`-````W6$"``L```#K80(`#@``
M`/=A`@`6````!F("`!$````=8@(`%````"]B`@`1````1&("``X```!68@(`
M$0```&5B`@`J````=V("``@```"B8@(`'@```*MB`@`(````RF("``4```#3
M8@(`"P```-EB`@`-````Y6("`%H```#S8@(`7@```$YC`@`+````K6,"`#H`
M``"Y8P(``@```/1C`@`$````]V,"``8```#\8P(`#@````-D`@`)````$F0"
M``4````<9`(`$@```")D`@`(````-60"``P````^9`(`-@```$MD`@`$````
M@F0"`#,```"'9`(`+@```+MD`@`.````ZF0"`"D```#Y9`(`+0```"-E`@!0
M````464"`!4```"B90(`.@```+AE`@`/````\V4"`"`````#9@(`#P```"1F
M`@`/````-&8"``@```!$9@(`#P```$UF`@`/````768"``H```!M9@(`%```
M`'AF`@`,````C68"`!H```":9@(`%0```+5F`@`'````RV8"`!$```#39@(`
M$P```.5F`@`.````^68"`!$````(9P(`(0```!IG`@`#````/&<"`!0```!`
M9P(`%````%5G`@`2````:F<"``L```!]9P(`.0```(EG`@`,````PV<"`!``
M``#09P(`2````.%G`@`0````*F@"`!@````[:`(`,@```%1H`@`N````AV@"
M`!@```"V:`(`&@```,]H`@`C````ZF@"`",````.:0(`)0```#)I`@`D````
M6&D"`!T```!]:0(`,P```)MI`@`M````SVD"``<```#]:0(`"P````5J`@`4
M````$6H"`!(````F:@(`$0```#EJ`@`:````2VH"`!````!F:@(`!````'=J
M`@`D````?&H"``T```"A:@(`*P```*]J`@`K````VVH"``T````':P(`#```
M`!5K`@`'````(FL"``\````J:P(`)@```#IK`@`I````86L"``@```"+:P(`
M!0```)1K`@`A````FFL"``8```"\:P(`$0```,-K`@`(````U6L"``<```#>
M:P(`#@```.9K`@`%````]6L"``P```#[:P(`'@````AL`@`&````)VP"`!D`
M```N;`(`$@```$AL`@`%````6VP"``\```!A;`(`+P```'%L`@`2````H6P"
M``8```"T;`(`!P```+ML`@`7````PVP"``8```#;;`(`$@```.)L`@`%````
M]6P"`!4```#[;`(`!````!%M`@`'````%FT"`!8````>;0(`,0```#5M`@`%
M````9VT"`!,```!M;0(`)@```(%M`@`&````J&T"`!````"O;0(`,````,!M
M`@`K````\6T"`"T````=;@(`+@```$MN`@`$````>FX"``X```!_;@(`"```
M`(YN`@`'````EVX"``H```"?;@(`"````*IN`@`&````LVX"`$,```"Z;@(`
M%````/YN`@`%````$V\"`"`````9;P(`-0```#IO`@`U````<&\"`!L```"F
M;P(`)````,)O`@`A````YV\"`",````)<`(`/P```"UP`@`;````;7`"`"$`
M``")<`(`&@```*MP`@!C````QG`"`&8````J<0(`$0$``)%Q`@`F````HW("
M`!H```#*<@(`+0```.5R`@`F````$W,"`#(````Z<P(`4P```&US`@`S````
MP7,"`"H```#U<P(`,0```"!T`@`S````4G0"`"H```"&=`(`)````+%T`@`&
M````UG0"``@```#==`(`"0```.9T`@`+````\'0"`!<```#\=`(`$````!1U
M`@`N````)74"`!$```!4=0(`)P```&9U`@`D````CG4"`"0```"S=0(`-```
M`-AU`@`X````#78"`!$```!&=@(`(@```%AV`@`2````>W8"``8```".=@(`
M&P```)5V`@`0````L78"`!$```#"=@(`$@```-1V`@`$````YW8"`!$```#L
M=@(`"@```/YV`@`-````"7<"`!<````7=P(`!P```"]W`@`.````-W<"``@`
M``!&=P(`-0```$]W`@`V````A7<"``L```"\=P(`"0```,AW`@`,````TG<"
M`!L```#?=P(`-0```/MW`@`T````,7@"``D```!F>`(`$0```'!X`@`0````
M@G@"`!(```"3>`(`(@```*9X`@!&````R7@"`",````0>0(`!0```#1Y`@`)
M````.GD"`"4```!$>0(`'P```&IY`@`6````BGD"``H```"A>0(`&@```*QY
M`@`1````QWD"``0```#9>0(`"@```-YY`@`+````Z7D"`!````#U>0(`#@``
M``9Z`@`,````%7H"`!8````B>@(`!0```#EZ`@`<````/WH"``4```!<>@(`
M#P```&)Z`@`L````<GH"`$L```"?>@(`"0```.MZ`@`*````]7H"``H`````
M>P(`#`````M[`@`+````&'L"`!(````D>P(`%P```#=[`@`5````3WL"`!8`
M``!E>P(`!P```'Q[`@`=````A'L"`!D```"B>P(`&@```+Q[`@`%````UWL"
M`!````#=>P(`!P```.Y[`@`1````]GL"``<````(?`(`)0```!!\`@`A````
M-GP"`!(```!8?`(`$0```&M\`@`L````?7P"``D```"J?`(`#@```+1\`@`<
M````PWP"`!$```#@?`(`%0```/)\`@`-````"'T"`#D````6?0(`#P```%!]
M`@`)````8'T"`!T```!J?0(`$P```(A]`@`7````G'T"`!4```"T?0(`.P``
M`,I]`@`]````!GX"`!(```!$?@(`"0```%=^`@`)````87X"`!8```!K?@(`
M#@```()^`@`/````D7X"`!$```"A?@(`$@```+-^`@`/````QGX"`!X```#6
M?@(`*@```/5^`@`L````('\"``X```!-?P(`$````%Q_`@`(````;7\"`!H`
M``!V?P(`'0```)%_`@`<````KW\"`"\```#,?P(`'````/Q_`@`<````&8`"
M`"(````V@`(`#P```%F``@`4````:8`"`!$```!^@`(`%P```)"``@`>````
MJ(`"`"4```#'@`(`"````.V``@`*````]H`"`!,````!@0(`&0```!6!`@`2
M````+X$"`$4```!"@0(`!P```(B!`@`4````D($"`!H```"E@0(`!P```,"!
M`@`'````R($"`!````#0@0(`#P```.&!`@`1````\8$"``4````#@@(`"```
M``F"`@`-````$H("``T````@@@(`#@```"Z"`@`0````/8("`!````!.@@(`
M!@```%^"`@`(````9H("`"X```!O@@(`)@```)Z"`@`D````Q8("``<```#J
M@@(`#@```/*"`@`&`````8,"``8````(@P(`%P````^#`@`7````)X,"`!<`
M```_@P(`#@```%>#`@`\````9H,"``\```"C@P(`$P```+.#`@!B````QX,"
M`#`````JA`(`)P```%N$`@`;````@X0"`#<```"?A`(`%P```->$`@`A````
M[X0"`"`````1A0(`.````#*%`@`^````:X4"`"(```"JA0(`"@```,V%`@`+
M````V(4"``,```#DA0(`!@```.B%`@`,````[X4"``@```#\A0(``@````6&
M`@`1````"(8"``P````:A@(`#````">&`@`3````-(8"``L```!(A@(`&0``
M`%2&`@`@````;H8"`!(```"/A@(`!0```**&`@`*````J(8"`!4```"SA@(`
M$0```,F&`@`.````VX8"``8```#JA@(`"0```/&&`@`X````^X8"`!@````T
MAP(`#P```$V'`@`9````78<"``L```!WAP(`+0```(.'`@!*````L8<"`#4`
M``#\AP(`)P```#*(`@`7````6H@"`!<```!RB`(`1@```(J(`@`$````T8@"
M``L```#6B`(`#@```.*(`@`4````\8@"`!0````&B0(`"P```!N)`@`&````
M)XD"`!`````NB0(`#@```#^)`@`,````3HD"``L```!;B0(`(@```&>)`@`7
M````BHD"``T```"BB0(`(P```+")`@`X````U(D"``H````-B@(`'````!B*
M`@`V````-8H"``L```!LB@(`#0```'B*`@`)````AHH"`&(```"0B@(`(@``
M`/.*`@`6````%HL"`"L````MBP(`'0```%F+`@`@````=XL"`!0```"8BP(`
M'@```*V+`@`6````S(L"`!\```#CBP(`%P````.,`@`G````&XP"`!\```!#
MC`(`#@```&.,`@`8````<HP"``H```"+C`(`!P```):,`@`'````GHP"`!D`
M``"FC`(`&@```,",`@`$````VXP"`!,```#@C`(`#0```/2,`@`&`````HT"
M`!X````)C0(`!P```"B-`@`1````,(T"``@```!"C0(`00```$N-`@`Y````
MC8T"`#$```#'C0(`/````/F-`@!"````-HX"`&````!YC@(`"0```-J.`@`^
M````Y(X"`"\````CCP(`"@```%./`@`.````7H\"`!8```!MCP(`*@```(2/
M`@`*````KX\"``X```"ZCP(`.P```,F/`@!_````!9`"`#````"%D`(`1```
M`+:0`@!"````^Y`"``@````^D0(`%P```$>1`@`9````7Y$"`!````!YD0(`
M'````(J1`@`L````IY$"`"````#4D0(`$@```/61`@`N````")("`#@````W
MD@(`+@```'"2`@`F````GY("`"(```#&D@(`#P```.F2`@`M````^9("`!H`
M```GDP(`*0```$*3`@`8````;),"`"P```"%DP(`$````+*3`@`P````PY,"
M`"(```#TDP(`*````!>4`@`G````0)0"`"(```!HE`(`)P```(N4`@`/````
MLY0"``@```##E`(`#@```,R4`@`/````VY0"`!````#KE`(`!P```/R4`@`'
M````!)4"`#T````,E0(`"0```$J5`@`,````5)4"``X```!AE0(`!@```'"5
M`@`5````=Y4"``D```"-E0(`"````)>5`@`(````H)4"``\```"IE0(`"0``
M`+F5`@`)````PY4"``<```#-E0(`$````-65`@`0````YI4"`!8```#WE0(`
M%P````Z6`@`1````)I8"`!L````XE@(`$P```%26`@`(````:)8"``T```!Q
ME@(`'@```'^6`@`3````GI8"`"$```"RE@(`'P```-26`@`7````])8"`!H`
M```,EP(`'@```">7`@`,````1I<"``\```!3EP(`#````&.7`@`9````<)<"
M`"P```"*EP(`#P```+>7`@`?````QY<"`"@```#GEP(`"````!"8`@`&````
M&9@"`!`````@F`(`"0```#&8`@`$````.Y@"`!````!`F`(`&````%&8`@`.
M````:I@"`!(```!YF`(`$P```(R8`@`<````H)@"`"4```"]F`(`#@```..8
M`@`0````\I@"``X````#F0(`!0```!*9`@`)````&)D"``@````BF0(`"0``
M`"N9`@`'````-9D"``L````]F0(`$0```$F9`@`$````6YD"``X```!@F0(`
M!0```&^9`@`+````=9D"``X```"!F0(`$0```)"9`@`A````HID"`!0```#$
MF0(`"@```-F9`@`"````Y)D"``@```#GF0(`!P```/"9`@`,````^)D"``4`
M```%F@(`$P````N:`@`+````'YH"``<````KF@(`,@```#.:`@`D````9IH"
M`#$```"+F@(`%P```+V:`@`%````U9H"``8```#;F@(`!P```.*:`@`'````
MZIH"``P```#RF@(`"````/^:`@`-````")L"`!,````6FP(`#P```"J;`@`,
M````.IL"``X```!'FP(`"P```%:;`@`'````8IL"``@```!JFP(`"````'.;
M`@`6````?)L"``D```"3FP(`!P```)V;`@`:````I9L"`!H```#`FP(`'@``
M`-N;`@`)````^IL"`"`````$G`(`!0```"6<`@`&````*YP"``8````RG`(`
M"@```#F<`@`'````1)P"`!(```!,G`(`$@```%^<`@`&````<IP"`!8```!Y
MG`(`"P```)"<`@`;````G)P"``0```"XG`(`!0```+V<`@`%````PYP"``\`
M``#)G`(`'````-F<`@`'````]IP"``D```#^G`(`%0````B=`@`,````'IT"
M`!L````KG0(`%````$>=`@`Z````7)T"``H```"7G0(`#P```**=`@`*````
MLIT"``(```"]G0(`$0```,"=`@`'````TIT"`!X```#:G0(`'@```/F=`@`A
M````&)X"`#,````ZG@(`'0```&Z>`@`T````C)X"`"4```#!G@(`*0```.>>
M`@`5````$9\"`!4````GGP(`70```#V?`@`8````FY\"`!,```"TGP(`'@``
M`,B?`@!I````YY\"`%0```!1H`(`+@```*:@`@`L````U:`"`#(````"H0(`
M-P```#6A`@!!````;:$"`%X```"OH0(`(`````ZB`@`L````+Z("`$H```!<
MH@(`*0```*>B`@`H````T:("`#(```#ZH@(`(P```"VC`@`=````4:,"`!<`
M``!OHP(`?````(>C`@`P````!*0"`#(````UI`(`-0```&BD`@`S````GJ0"
M`",```#2I`(`(0```/:D`@`N````&*4"`"P```!'I0(`,````'2E`@#N`0``
MI:4"`!L```"4IP(`/P```+"G`@`4````\*<"`$8````%J`(`-@```$RH`@`Y
M````@Z@"`"X```"]J`(`&P```.RH`@!#````"*D"`"<```!,J0(`%0```'2I
M`@`4````BJD"`"0```"?J0(`A0```,2I`@`_````2JH"`#$```"*J@(`7@``
M`+RJ`@!+````&ZL"`#@```!GJP(`,````*"K`@`O````T:L"`"L````!K`(`
M'````"VL`@`5````2JP"`)0```!@K`(`&````/6L`@`7````#JT"`#<````F
MK0(`&0```%ZM`@`A````>*T"`"L```":K0(`'0```,:M`@`<````Y*T"`"@`
M```!K@(`'P```"JN`@`+````2JX"`!\```!6K@(`%0```':N`@`I````C*X"
M`!,```"VK@(`)P```,JN`@`3````\JX"``P````&KP(`+P```!.O`@`>````
M0Z\"`#<```!BKP(`'P```)JO`@`N````NJ\"`"8```#IKP(`(0```!"P`@!"
M````,K`"`%````!UL`(`.P```,:P`@!%`````K$"`$$```!(L0(`-0```(JQ
M`@!A````P+$"`$8````BL@(`2P```&FR`@!)````M;("`$<```#_L@(`.P``
M`$>S`@`F````@[,"`"\```"JLP(`2@```-JS`@`=````);0"`"<```!#M`(`
M*P```&NT`@`L````E[0"`"@```#$M`(`1````.VT`@!'````,K4"`$<```!Z
MM0(`4````,*U`@`Q````$[8"`"L```!%M@(`00```'&V`@!.````L[8"`"L`
M```"MP(`*P```"ZW`@`B````6K<"`$D```!]MP(`+0```,>W`@`N````];<"
M`!4````DN`(`)````#JX`@`E````7[@"`"4```"%N`(`)@```*NX`@!J````
MTK@"`&@````]N0(`K@```*:Y`@`;````5;H"`"H```!QN@(`-@```)RZ`@`O
M````T[H"`$4````#NP(`(````$F[`@!1````:KL"`"$```"\NP(`"P```-Z[
M`@"U````ZKL"`#P```"@O`(`*0```-V\`@!`````![T"`#8```!(O0(`1P``
M`'^]`@`_````Q[T"`#H````'O@(`+````$*^`@`N````;[X"`#$```">O@(`
M)P```-"^`@`C````^+X"``X````<OP(`/````"N_`@`B````:+\"`"H```"+
MOP(`*````+:_`@`K````W[\"`!P````+P`(`-P```"C``@`O````8,`"`!L`
M``"0P`(`!@```*S``@`&````L\`"``,```"ZP`(`#@```+[``@`+````S<`"
M``H```#9P`(`"P```.3``@`%````\,`"``P```#VP`(`!`````/!`@`)````
M",$"`',````2P0(`;@```(;!`@`$````]<$"`!8```#ZP0(`!````!'"`@`'
M````%L("``4````>P@(`!0```"3"`@`$````*L("`!`````OP@(`&````$#"
M`@`(````6<("``L```!BP@(`#````&["`@`1````>\("`!,```"-P@(``@``
M`*'"`@`'````I,("``<```"LP@(`%````+3"`@`,````R<("`!8```#6P@(`
M!@```.W"`@`3````],("``P````(PP(``P```!7#`@`H````&<,"``0```!"
MPP(`!@```$?#`@`(````3L,"`!L```!7PP(`-````'/#`@`G````J,,"`"@`
M``#0PP(`$P```/G#`@`@````#<0"`!T````NQ`(`&P```$S$`@`@````:,0"
M`!L```")Q`(`&@```*7$`@`B````P,0"`!0```#CQ`(`,0```/C$`@`O````
M*L4"`"8```!:Q0(`&@```('%`@`>````G,4"`!X```"[Q0(`&0```-K%`@`C
M````],4"`!T````8Q@(`*````#;&`@`:````7\8"`!L```!ZQ@(`(````);&
M`@`C````M\8"`!D```#;Q@(`(0```/7&`@`>````%\<"`#8````VQP(`'@``
M`&W'`@`B````C,<"`"(```"OQP(`(P```-+'`@`=````]L<"`!,````4R`(`
M&````"C(`@`B````0<@"`"$```!DR`(`,@```(;(`@`@````N<@"``T```#:
MR`(`%````.C(`@`/````_<@"``H````-R0(`$````!C)`@`+````*<D"`!8`
M```UR0(`*````$S)`@`=````=<D"``H```"3R0(`'0```)[)`@`/````O,D"
M`!<```#,R0(`#@```.3)`@`6````\\D"`"$````*R@(`"````"S*`@`'````
M-<H"``T````]R@(`#@```$O*`@`0````6LH"`"(```!KR@(`)0```([*`@`E
M````M,H"`!8```#:R@(`#````/'*`@`*````_LH"`-P````)RP(`"@```.;+
M`@`1````\<L"`!4````#S`(`%0```!G,`@`,````+\P"``\````\S`(`(```
M`$S,`@`@````;<P"`!8```".S`(`(P```*7,`@`&````R<P"`$````#0S`(`
M%0```!'-`@`4````)\T"``<````\S0(`$P```$3-`@`9````6,T"`!P```!R
MS0(`"@```(_-`@`W````FLT"``@```#2S0(`*0```-O-`@`6````!<X"`!0`
M```<S@(`%````#'.`@`Q````1LX"`!$```!XS@(`$@```(K.`@`3````G<X"
M`!$```"QS@(`"@```,/.`@`7````SLX"``@```#FS@(`(````._.`@`(````
M$,\"`!,````9SP(`!P```"W/`@`1````-<\"``<```!'SP(`"````$_/`@`)
M````6,\"`#8```!BSP(`!0```)G/`@`/````G\\"`!0```"OSP(`$0```,3/
M`@`+````UL\"``P```#BSP(`!P```._/`@`3````]\\"``@````+T`(`"P``
M`!30`@`8````(-`"`"(````YT`(`'0```%S0`@`<````>M`"`!,```"7T`(`
M$@```*O0`@`;````OM`"`!````#:T`(`'@```.O0`@`=````"M$"`!`````H
MT0(`%````#G1`@`L````3M$"``T```![T0(`$````(G1`@`:````FM$"`!<`
M``"UT0(`+````,W1`@`0````^M$"`",````+T@(`&0```"_2`@`+````2=("
M``P```!5T@(`&````&+2`@`)````>]("`"H```"%T@(`$0```+#2`@`*````
MPM("``(```#-T@(`$````-#2`@`7````X=("``L```#YT@(``P````73`@`*
M````"=,"``4````4TP(`!P```!K3`@`,````(M,"``L````OTP(`%````#O3
M`@`5````4-,"``X```!FTP(`.````'73`@`8````KM,"`!@```#'TP(`3@``
M`.#3`@`S````+]0"`#$```!CU`(`"@```)74`@`E````H-0"``P```#&U`(`
M!0```-/4`@`6````V=0"`#P```#PU`(`#0```"W5`@`.````.]4"``8```!*
MU0(`!````%'5`@`$````5M4"``H```!;U0(`%P```&;5`@`%````?M4"``8`
M``"$U0(`"````(O5`@`%````E-4"`!0```":U0(`%0```*_5`@`%````Q=4"
M`!<```#+U0(`'@```./5`@`?`````M8"`!H````BU@(`$````#W6`@`"````
M3M8"``0```!1U@(`"P```%;6`@`%````8M8"``4```!HU@(``P```&[6`@`.
M````<M8"`#````"!U@(`)0```++6`@`;````V-8"`"0```#TU@(`3````!G7
M`@`<````9M<"`!<```"#UP(`*@```)O7`@!1````QM<"`"8````8V`(`3@``
M`#_8`@`\````CM@"`#T```#+V`(`%0````G9`@`4````']D"`'$````TV0(`
M'P```*;9`@`@````QMD"`"0```#GV0(`70````S:`@`=````:MH"`$<```"(
MV@(`(````-#:`@`Q````\=H"`"8````CVP(`,P```$K;`@!.````?ML"`%$`
M``#-VP(`)P```!_<`@`H````1]P"`"<```!PW`(`*````)C<`@`L````P=P"
M`!8```#NW`(`-`````7=`@`V````.MT"`"H```!QW0(`-````)S=`@`P````
MT=T"`"@````"W@(`(@```"O>`@`J````3MX"`"0```!YW@(`-@```)[>`@`X
M````U=X"`",````.WP(`)0```#+?`@`X````6-\"`!0```"1WP(`%0```*;?
M`@`.````O-\"`&$```#+WP(`"@```"W@`@`?````..`"`!$```!8X`(`$```
M`&K@`@`H````>^`"``H```"DX`(`8P```*_@`@!I````$^$"`$8```!]X0(`
M)P```,3A`@`;````[.$"`#$````(X@(`-0```#KB`@`8````<.("`!$```")
MX@(`(@```)OB`@`=````ON("`#D```#<X@(`(@```!;C`@`;````.>,"`&H`
M``!5XP(`%@```,#C`@`/````U^,"``H```#GXP(`!````/+C`@`&````]^,"
M``@```#^XP(`!0````?D`@`5````#>0"``\````CY`(`$@```#/D`@`9````
M1N0"`",```!@Y`(`#P```(3D`@`-````E.0"``T```"BY`(`#@```+#D`@`$
M````O^0"``8```#$Y`(`"0```,OD`@`'````U>0"``T```#=Y`(`!P```.OD
M`@`(````\^0"``D```#\Y`(`"0````;E`@`6````$.4"``8````GY0(`"P``
M`"[E`@`*````.N4"`!0```!%Y0(`%0```%KE`@`)````<.4"``8```!ZY0(`
M!0```('E`@`+````A^4"``L```"3Y0(`$P```)_E`@`*````L^4"``D```"^
MY0(`#@```,CE`@`*````U^4"`!8```#BY0(`"P```/GE`@`%````!>8"`!``
M```+Y@(`"@```!SF`@`4````)^8"``T````\Y@(`!P```$KF`@`'````4N8"
M``L```!:Y@(`!````&;F`@`(````:^8"``@```!TY@(`#````'WF`@`&````
MBN8"``8```"1Y@(``@```)CF`@`9````F^8"``(```"UY@(`"````+CF`@`&
M````P>8"``0```#(Y@(`!@```,WF`@`/````U.8"`"D```#DY@(`!0````[G
M`@`%````%.<"`!,````:YP(`&0```"[G`@`(````2.<"``0```!1YP(`!P``
M`%;G`@`&````7N<"``H```!EYP(`$````'#G`@`9````@><"`!$```";YP(`
M$0```*WG`@`(````O^<"``P```#(YP(`(P```-7G`@`*````^><"``D````$
MZ`(`$`````[H`@`%````'^@"``(````EZ`(`"P```"CH`@`2````-.@"`!$`
M``!'Z`(``0```+$```"\!```2P(``"````#K````+`D```````#M`P``Z```
M`'8(``!D!P``V`0``'8&``#U!0``X00``,($````````?04```````#Y`0``
M_@$```(%``"U`@``_P4``+X"````````9PD```````#>!0``?0```*4$````
M````R0(``.D&```.````E`4``,D$``"0!@``#P<``.(#``"]"```````````
M``!Q`P``:P0``"P$```5!@``)04````````*!@``YP``````````````````
M`$P```#I`P``U@$``-\#```^!```,```````````````:`@```````#?!0``
M``````````!7````E0@``+0)```W"0``_@<```````#Q"```?@$``&,&```4
M"0``T@4``(`%````````\P<``#8)``",`0``DP8``&T#``!O"```````````
M````````IP$``(@!``!1`````````/`%```G!```UP(``/D$```6!```WP0`
M`/L#````````TP(``+X&```J!0```````,P"``"I````EP4``/8)```W`@``
M"04``/0)``![!P``1@0``````````````````$$!````````^04```P#``#W
M`P```````&\'```."0``,@@``,0'``#(`0``!`@``,@'````````EP```*0!
M```7"@``2P$``(L```"%`P```````"$$```)!P``J````,8)````````````
M`!<#```<`@```````(D#``"3!0``X@```)T#``#H!````````+<&``"A"```
M?@4``*X&``"C!0```````)(`````````-@4``)<!``#P!```#`8``)0#``#)
M`P``]0D``!<&````````3P,````````]"0``VP4``,L&``"&`0``9`0``$D&
M```:`0```````#H%`````````0,`````````````#0D``'X'``!Z"0``````
M`%('````````_`$``'4(``!S`P``^P$``-8(``"$!P``"08``*P)``"Y!0``
MU@4````````>"0``(`8``)\$````````@P(``"8(``#'!0``J`8``'D!````
M````KP@```````!O`P``]@$``%<"```P`0``I0,``$H%``#*`P``)`0``!H`
M``#M"```1P(``!L(``!+"0``.P(``+T"```!`@``;`D``,@#``"+`@``O`4`
M`&L%```-`@``I0D``#@&````````[0(``%L%``!)!P``Z0````````#="0``
ML0$``````````````````*\!``#O````90,``$8%``"%!@``M`4``#($````
M`````````'0"``![`0``4P8`````````````7@0```````"V`0```P(``.,'
M`````````````,,)```-!P``V@D``/H&````````<0(```````!T!```'00`
M`%4!``!5`@```````$D(````````XP4``#X(``!!````%P$``(T%````````
M`````)`(``"`!P```````"`(``!:`P``3P0```````"Z"0``/@8``,4#``#H
M!P``M`(``+$)``!U!```*P@```````#]`@``O`D``+4(``#,!0``'`,``#H#
M``!""0```````'T)``!,!@``?`(````````W`P``````````````````)`@`
M`#`(````````2`D``!X"``!9!P``_08```````#:!0``/0$````````M!0``
M%P(``"<'``#A!0``LP0``'(%``"3"```-P$``%8$``#\`@``UP4````````C
M!```YP(`````````````$0D```````#D`P``*````$,%```V!@``$P,`````
M`````0``.P<```````"T!@``8`D```````#Y!P``1@8``&4'``!Y````E0$`
M`&@#``#:`P```````-<)````````108``+`!``!7"0``R@$``!\)````````
M<`$```````"C`0``#P```$($``#E"````````'P&``"0`@``6P(``!@%``!!
M!P```````(0!```&!@```````/8&``"2`@``````````````````C`<```<`
M``#R!P``-0D```````#M````S0@``.,"```(!0``^0D`````````````````
M```````.!```7`(``,T$```_"0``]0$```D*````````80,````````?````
M[@$```````#3"```/@<``,4)````````%@@``)\)``"&`P```````+(#```0
M!0``L`(```````````````````````````````````````"S`0``#@H``-,!
M``"/!@``RP@```````#)`0``Y@0```````#>"````````+("````````G0``
M`)@&``"#`P```````!(!``#T!0``AP,``-@```"+`P``:00```````#C````
MA@D``%\````#"0``:@$```````##!0```````-,`````````FP4``.4$````
M````Z@$``&<&``#L"```80```)X!```?!0``L@4``%D(````````[P<``#D`
M```$`0``5@```,X#````````S@<``)`)```?"```)`(``'()````````'@<`
M````````````0P8``"$%````````4P@``,L#```7````````````````````
M`````*H!``````````````````#A"````````*8#``#H"```\@0``#\#``"S
M"```R`D``-`$``!*`0```````-`"``"7`@``-`$``($'``":!0``H0```%D!
M``!3`0```````)\!``"`"````````+\````R`````````&L#````"@``````
M```````+"````````,<(``!C"0``T@$``*<#``"I!P```````(P%````````
M``````````#5"0``W0(``#,```!.`0```````(<``````````````$T$``";
M`P``^`````````#P`@```````($%```D!@``"P<``+`&``"X`0``8P,`````
M``"R!P``%`<``*,"```G"0``Q@4```````"'!P```````"0)````````X`0`
M`"$(````````4```````````````8@$``.4````3!0``````````````````
M$@D```````!P!0``?`0``$D"``````````````L"```9!0``+@$```````!9
M"0``.0@```H*``!J"0``X0(``&,'```A`P``VP8``.`%``#5`@``S0D``,`"
M``"!`P``K@,``)D&```Y!@``#@,```````!B!0``!`,```````#S````'P8`
M`*0%````````?PD``&T!``!J!@```````$P'``!3!P``A0<```\*``#3!```
MM@<``#H`````````H08``%X(````````W`<``-`(```%!@``[@(``,P&``!>
M!P``9`$``-`!````````G`8`````````````2`````````!<````U@<``!,&
M````````Q0<``+<)````````E`0``'X)```U`P```@D``+@#```1!```B```
M`(H&``!>`P``+@<``#T&``"F!@``:````%(%``!$!0``L@````````!U````
M:`<````````L!0``,P(``)\'````````/`@``(H(````````:`4`````````
M````(P8``+<%``!8````T08``/$$``!3`P``7P0``/P'````````VP0``&D`
M``!%````>`$``!\"```-````*P4``,@(````````H@8```````#W!P``@@$`
M`/,#``````````````T#```H"```;08``&<```#!`P```````"4$``"U!```
MX@@```````"3!```H0$``%0"```4"````````)$```#E`P```````(8$``"J
M!````````/$"``#P"```*@<```````!%`0``+P4```````!K"```6`4``*<%
M```+`0``4`0``(L(``#/!@``KP<``$0"```9"0``E08``!4$````````````
M``8!``"@!0````,```````#:!P```````#0(````````904``.H#``#H`P``
MIP0``'<)```;"0``K@(``%$(``#-`````````+P#``!`!P``6`$``",)```L
M````+`,``)H&```N!```-P````````!`"0```````%8"````````C0$``#@"
M```Y`0```````%D&`````````````.@"``#>`0``^0(``)0)````````-P<`
M`#T````,`@``)0@``(@%``#E!0```````%@"`````````````*L"``##!@``
MR@4``,````!1`0``PP0``$\%``!*````L````)T!`````````````+<'``#I
M`@``JP,``+L!``"U!@``0@<``#<%```*"0```````*$%````````.`D``'@%
M``#/!````````$,!````````?`,``-L#``"1`@```````$T!``#%````7@(`
M`"L)````````J0@``)()``"9!P``90```/,$````````S@$```````#,"```
MM0,```````!Z!P``@0@``)T)```]"````````)P(``!_`0``8`0``*H%``"9
M`````````&L'``!%!```L`<``-0)``"M"0```````-X$``#]!P````````@)
M``#Z`@````````````"K!P``10<``-$)`````````````.X&````````````
M`)8(````````NP<``#,$```1!@``10(```````"$`@```````)D"``";`0``
ME@(``%L(``!,!0``>0@``&@!```="````````$D#``"N"0``,P<``"P&``#C
M"0``!@D``"H```"B`````````)@$```["0``N@0``%@)``#J!@``````````
M``"["```M0<``$@"``"^"```&`,``),'``#"`@``I`8```````"6`0``?P(`
M`&@)``"L`@``MP,```````"M`@``V04``,`#``#5`0``````````````````
M[P@``-0!````````F`(``-\)``#*!```\P4````````-!0```````(``````
M`````P$````````]`@``;@$```````!H!```O@<`````````````3P8`````
M``!=!0``+0```*X!````````@0(``!8'````````F`@```````!@!@``K0$`
M`*(!``!D!@``P`$``*@%``"<`P``-`D``"`$``!D````T0(```````"Z!P``
MQ08```````#Z"0````````````#K!0``N`@``"@&``!*"```0`,``+4````*
M!P```````!8%``!]`@``G````/T!```\`0``N@,``#\!``"Z`@```@```&P&
M``#"`P``Z@0``/L"``#;`0``@`$``.,!````````\@8``%8'``!P`P``````
M`*('``!Q!@``Y@$``)L```"6"0``?P8````````K!```R@```#T'``!L````
M[04```````#)````]P```%8&``#S`0``H`@```````!X`P``<P8```````#!
M"```1`0```````")`````````-,&```/!```Y0D``.D(```[!0```````&,"
M````````=P4``'`&````````X@8```D!````````B0<````````(`0``GP4`
M`+8%``"4!P```````&`(``"P"```?P4``)X```!+!```?@@``-0&```2`P``
M&0(``#0#```*`````````.8)``!2!@``8`,```$'````````M`@``/$#```>
M`P``*P```)H!````````R0<``%0```!="0``Q@0``$@'```Q`@```````'<"
M```O"```.@$``!$!```O!```````````````````"P4``&8"```)"0``=@<`
M`"8&````````0P0``!L'``!1!@``3`$```````````````````````"+!0``
M(`(``"8!````````$@H``$@%``!E!```=P,``'D%```]!````````!4"``!A
M"0``*@D````````<!P```````,@```!-!0``KP```(H%```B`@``L@$``-L"
M``!.`@```````$\!````````I@$``$\'`````````````+L%``#P"0``-00`
M`'L"```@!P``6P```.H(````````&@(```````#<`P```````/4&``!!!@``
MD`````````!R`@```````!`*```0````\@`````````&!P```````"4'``#`
M!P`````````'```6`@```````(`"````````Z0D`````````````3PD``(X"
M``#K!@``N0,``/0!````````0@8```````"7!```"`<``*8'``#6`@``(0$`
M`#X#``!S`@``X@(```0)`````````````%@#``#4````-0$``!H#````````
M#`4``-\(`````````````,H"````````&`8``+<(``#]"0```````#(!```\
M!0``0`4``%`!````````#00`````````````+@D``-$$``"$"```70,`````
M``"/`P```````,0)````````90D``$X)``#F!P``(@0``,4!``#H"0``````
M``````!?`P```````+$"`````````````!H(``#F`P``'`@``,T&``#0!P``
MJP8``%H$```L"```%@$``'(````Z!P``J@(``,`)``"J"```/P8``$T)``#"
M!P``-0(```\!``#0````1@@``(D$``!4`0``M`0``,$"```K`P``U@```.T)
M``!N!0``'`8```````!N!```)P```(,$``!N!@``OP,``!$````A"0``````
M`/,&``````````````````"-"```U0@``(D&``#,`````````#D%``"D`@``
MW@<``&P#``#Z!`````````````#M!```2@<```````""`@``;0```-H&``#?
M````Q@@``)`%``#,`0```````+8```#G!```D@,``+$$``"1!0``<04``'0#
M``"9`P``;`(`````````````500``$@$``"8!0``A0$`````````````,P4`
M`'0(``!E"```@`8```````">!0``:0D``%4&````````&0,```````".!0``
M````````````````&@H``*,&```'"```$`0``!$'``#Q!@``````````````
M````X@D``#`$``!1!P``.`0``-`&````````F``````````<````C`@``*X(
M``!F`0``600```$)```C`0``E0(``&0#``#K`@``C@8``(X!````````!@@`
M`)D(````````$0(``.\%```B"0``,PD`````````````9@0`````````````
M,@<````````*!0``!@(`````````````G00``*$#``#@"0``X`8```,%````
M````7P<```L``````````````$L%``#[!`````````````#/`0```````#D$
M``#D`0``N0@``$<'```(`P``/P0``,L$``"G!P``!0@```````#D!P``(0``
M`!D```#T"```5P,``'@(``"C````T@8``/H'``#>``````````````!W`0``
MJ`@``-<#``"!"0``$P```,X&````````A`,``*@#``#O"0``F00``&\!``""
M````%@,``!,'``!)````-`4``)`#``"L!0``````````````````X0``````
M``````````````````"+`0``=0$```````!V!`````````("``!,"0``````
M`!((``#<````P@@``,D)``">"0``SP,``%H)`````````````,L)````````
MT@,``.<&````````^`D``'P%``#""0``_0```(P#``!R"```W@D``'H```!]
M!```````````````````\P(``,8```"G````S`<``(8"``#L`P``H0<`````
M``"E````%0H```````"1!@``*`(````````A`@``3@<``$4%``"(`@``#P8`
M`'X"``#G"```3@0```````!#`@``JP0``'H%``!@!0``````````````````
M`````%`'```I`@``]@0``````````````````%<(```'`@``20$```````!5
M````9P0````````,"```=`8`````````````T0````H$``!L!P``P`@``$8"
M``#/!P``1@D``(T"``"*!P```````(T```#^`P``P`4``$4(``"(!```]`<`
M`.$)``#4`P``K00``#$&````````'04``!8*````````L@8``+`$``#;````
MU0,``/`'``#K!P``V`<``+4!``"@`@``N@@```````#W!@```````(4```",
M"0``^`<```````#=!```QP(``'H#``#B!P``:@````````#,`P``AP0``#X"
M``#9"```!`4``(,)`````````````'`(``#V!0``RP```*0)```P!P``E`8`
M`)`!``"``P``'P,``,L"```8"0````````````"C`P``UP@``-D'``!,`@``
M3@``````````````OP<```$$``!U`@```````&(#``"\`0``F`<``&($``#Q
M!P``!@,``/<!``"7!P```````#@!``!Y!```)@D```````#/!0``0@@``"@%
M``#G!0``0P<``$T&```6````J0D``$$#``".````^`@``&0(````````[`8`
M`&`"``#_````;@@```,*``#L`0``X`,``+D'``"5`````````#X%``![`P``
M```````````_````9@D``'````"E`0```@@``.4'`````````````,H&``"M
M"````````(0$``"Q!P``5P4``"`)``!I`0``\04``"8```"K!0``AP4``'$)
M````````<P$``$P$``!9````8@<``"\)``"-"0``%04``+L"````````````
M`'4#````````0@(````````%!0``>@(``/<(``!5`P``"`0``%P%```F`@``
MM`,``"H#``"3`0``G@8``$T#``!L!0``N`(``,$!``"4`0``?P<``'T#````
M````W0$````````````````````````!"@```````!4'````````1PD`````
M``!5!0```````*D"``#$````````````````````T@(``/T(``!1!0``````
M`*,)``#J`@``=@,```````"L`P``DPD```,```"G`@``=@(``(X'````````
M%@D``/X$````````!0,``$L(```M"0````````\"``!I!0```````$@!```Q
M!P```````````````````````!T#``!@`````04``*(%```S`0```````"8$
M```Z"0``#P,``.\#``#=!0``7P(``!X(``````````````````";!@```P@`
M`'$!``!_`P``5`,``````````````````,<!````````P0D``!0!```O!@``
MW0@``"X%````````9`(``,H(``"8`0``]@@``$@&``"I!````08```````!G
M!P``!`(````````````````````````/"0```````&T%`````````````!`'
M````````:@@````````M`@``V`4``)$(``#D!@``)P8````````G`0``````
M``X"``!+!P```````)X#```I!0``P08``%$$````````_@@```````!'"```
MU0```'`"```V!P``M@8```````!-````!P$``,L!```9"```B`<``*<&````
M`````````.P```!)!```'P<``%<!``!9`P``EP@````````N!@```````"D'
M``!@`0``QP8```````!=!```/0,```````!0!@```````-D!``"("```00@`
M`*D&````````G0(``+8#``"@````8@8``#L!````````X08```D$````````
M`````(X$``#@"```_P@``(D(``"J`P```````%L#``!#"0``RP<``+4%```P
M!0``J@```'8)```;"@``KP0``',%```X````^`(``!T*```V`P``1`<``+\"
M``!K!@``'@4``)T(``"J"0``SP```-D&``"A!````````!@(``"R"0``)08`
M````````````NP0``"@'``!<`0``M0D``$,(`````````````,X"````````
M"@$``-P$``"8"0``V0,``"\!````````Y0$``&4!``#]!```R`8```````!#
M````^P<````````%````O0D``)8```"Y`@``&P(``/4```#Q"0``=04``"((
M``"]!```K@4```````#"`0``>0<``-D$``"S`P```````#P'``!>`0``40D`
M``````#6!@```````&8```#-!P````````````"%`@``DP(```````#,"0``
M;P4````````8!```E@8``&D#``!'`P``@@,``'X#`````````````.T!``"A
M"0``W`@``"T(```@`0``G@0``(<!``":!P``.P@```X&```H"0``7@8```,'
M````````FP0``#(%```Z!@``5P<```````!P!P``:0(``(T&```R`P``````
M`-T&`````````````#0````/!0``O`<``#T%``#"!@``N````)8%``#B!```
MZP$``)<#```""@``(0<``#0'````````W0<``+0!``"7!@``^@@````````3
M`0```````%T````.`0``GP@``'0```"H!P````@``,@$``!U!@``I```````
M````````N@8``*D!``#K"0``&0$``/0``````````````"T'````````#0$`
M`,<)````````1P0```````"1`P``I@@``$0(```Z`@``PP````````"2!@``
MQ04``$0)```+"@``R08``'`$``!W!P``TP<```````!``@``U`4``"D#``#@
M`@```````$L#````````B@```#8!```=````\@4``*`)```4````]P(`````
M````````>`8``&T$``"^!0```````%L$``!*"0````````````"!!```X@$`
M````````````U@0``$T"``";`@``7`,``,4(``"(!@``?@```$``````````
M"0(`````````````D`<````````A"@``$PD``.<'``#Z`0``5`8``%L'``!J
M!0``5@D````````U!P``T@D```````!W!````````%8#``#7`0``>`<```H#
M``#1!0``@P`````````K!@``"@(``!T)```````````````````9"@``#0@`
M`/D(`````````````.P$``!A`@``6@```*L)````````]0,`````````````
MK`8``$0!````````7P@``&H$``#X!0```````*P!``!G`@``<PD````````<
M!0```````#`)````````^08```````!/`@```````'(#``"%!0```````#,#
M``#.!0``9`D``,`&``"G"0``DP```+\)``!!"0``<@8``-H"``"Y!@````D`
M`','``#:````604``-0'````````M@0```````#U!```T@<``)\&``![!```
M?@0```P````2!P``(@8``&X#``#G`P``@P4``%($````````+`$``&8'````
M````4P```*$"````````Z@4``/0#``"2!0``-P8``+L&````````X0,`````
M```(````(P(``(X(``#F````<`D``!("``#$`0``5`D```4!``"2!P``WP(`
M`.4&``"1`0``)````*P(`````````````#8$``#H`0``Y0(``#$(``";!P``
M!P0``%`(````````\@(``+T%``"!!@``*`0```````#K!```!00```````#_
M!P``8@@``-@&``"P"0``^@```,L%``````````````````!G!0```````,T"
M``"7"0```````#\%````````]@```(@#````````C0,``+L#````````````
M`"4````Y"0``S@```-4&```.!P``O@,```````"N````9P,``-`%```F!P``
M3@@```````!%"0``F04``'('```;````XP8``)H(```;`P``VP@````````'
M"@``A0@``"D&```G"````````$(```"#`0``.`<``/8#````````J`$``",'
M``!*`P``Z`8``,H'``!_"```Z04``%\!``#C"```]PD``'D"``!L`0``````
M`"(````Q"0``+P(``"L'``!2`@``8@D``*@)```K`@``YP$`````````````
MK08``(`)``#/`@``2`,``(\````?"@``[@0``*4&```0"0````````````"6
M!P`````````````Q`0``'@````,$``"_!```B`D``(<)``#Y````7PD``"8%
M``"$!0````````````"]!P```````````````````````(X)``!"!0```0$`
M`(H$``#`!````````/\!````````$P@``/L(``"E!P``)P4``!4(````````
M1@$````````%"@``H`$`````````````>P@``%@'````````W`(``%H(``"F
M`@``708``'P'``"Y````#P@``.0$``"'!@``JP@```D#``#A`0```````&$(
M```M`P``"`H``#L``````````````)T%``#/"```<@$``)P$``"!````LP(`
M`+T#````````LP8``(4$``!V!0``6@8`````````````O`(`````````````
M_@8```<%``#D````!`H``-$!`````````````"X```"4`@``<P```(((``#-
M!0``````````````````+P,```````#*"0``_`8```4'```_"```N0D``!(%
M```#!@``_@````````"2`0``Q@8``*8%```9!````````&8&```9!P````4`
M````````````S`0```````#M!P``:P(``)H#````````UP<``,,'``#I`0``
MTPD```````"["0``GP(``.X'``#?!P``*@8```````!Q"`````````(&``#7
M````-04``"X#``#N"0``E@,``````````````@,``/P(````````2P8``%X`
M``"-!P``800``%\&```&`````````"H!``"8`P``Y`(``(()``!@!P``004`
M`%8(```%"0`````````````$!@``5P8`````````````CP@``/<%```L`@``
MMP(``#`"```=!P``2P```,$%````````6@$``*8$``#%!```(`4``$D%```-
M"@``=P8```````!*!@``V`$``*<(````````0`0``%P)``"5"0``R0@`````
M``!2"0``0@$`````````````^PD``!<(```D`0``A@8```````#1!P````(`
M```````+!```4P(``'D)```8"@``:0<```````!&!P``[P$``*@$``#(`@``
M8P4``"L!``"1!````````-H(````````A@4``-X&``!=`@``?`$```````#(
M!0``-0@``-D)``"<!P``-@(``/<$``"_"```;@<``&P$``#.!```7`@`````
M``#/"0``20D``'L&````````KP4```````!,"```K0,``.<)``#)!0``^`$`
M`%T!``"C!```'P$``/4(``"3`P``O`@```````#X!@``V`,``.`'``"M!0``
M$P(`````````````/P(````$```7!0```````#\'`````````````,<$``"R
M!```V@0``%`)``#I!```OP8``/(!``!Y`P````````L&``!S!```T@0``'4)
M```I`0``.P8``&$!``"=!@``AP@``$X#```J"```]0<````````S!@``50D`
M`*\&``"S!0```````-P&```X"```C`(``#P)``!A!0``5@$``(($``!<!@``
M!P<`````````````:0@``#@%``#R"````````+T&``#4"```_@4````````"
M`0``=@```-@"``!8"```S0,`````````````;`@``"`#``!-!P``````````
M``!<!```!`<```D```"^"0``1`8``&,```#Q````KP,``(D%````````HP<`
M`&\)``!7!```40(``%0$```%`@```````*8)````````0P,``"4#``#A!P``
MN`<``+L```"\!@```````(L)````````4P4``+X$``!N``````````````"S
M"0``(P``````````````-@``````````````(@4``.X(```:!0``\@D``,0(
M````````&`(``+0'````````GP```+$(``!\````PP@``&L!```:!P``````
M``````#&`P``BP0`````````````$`8``#L$````````1P```)P)``!5"```
MUP8``*0(``!Y!@``8P0``&H"```````````````````Q!```<@0``#$`````
M````!P8``/T#`````````````,<#``#=`````@0``%`#``!H!@``%`H`````
M`````````````*()``#H!0``3P@```P$`````````````%(!````````W`$`
M`!8&`````````````"0'``#^"0``Q`4``*T`````````3@8``.H````>!```
MD@0``"`*````````>@@``+\%``"@!@``)0D``+`%``!V`0``M````"D```!`
M`0``V`@``!P)``!X"0```````%$#``"*"0```````/@#``#M!@``(P,`````
M````````/@```(H"``"#!@````````````#K"````````#0"``"5!```U`(`
M`%`"``#_!```7P4``+H```"X!```MP```!P!``````````````$(````````
M`````.P%```````````````````1"@``%0,``*4%``!M"0``F@````````!;
M`0``O0$``'H$``"Y!```J@8``"X(``!5!P`````````````I"0``W@,`````
M``#3!0```````)L(`````````````)T'```9!@``+P<``&X"``"\````>@8`
M`'0%```$````B@$``%(```!*`@```````!$(``````````````X%```>"@``
M(@,``/`!```,`0```````#L#``!B`@```````+<$````````?0$``,<'``";
M"0``?P```*`$```3!```]@<``,$```#L"0```````&(````,"@``````````
M``"C"````````````````````````&D&```\!```$`$``/H#``##`P``F@D`
M```````:!@``-P0```````#^`@``2@0```@(``!3!```_P8```T&````````
MPP$``%D"``#L`@``+0$`````````````_04````````,"0``N@$``(H#``!\
M"```H@(``)P!``!M`@``<0```#`#```&"@``(P4``-$#``!;!@```````!(`
M``"5!0``!PD``!T&``#%`@``\```````````````S0$``*H'``!T`0``?0<`
M`$$$``",``````````````#7!````````%8%``#<"0``W@(```L#``"M!P``
M$@0``.(%```<"@``"@@``((%``!N"0``L`,````````&!0```````.0%```N
M`@``*@(``,(%``!O`@``N`D``!$%```J!```(08``-\&``"B!````````#(&
M````````7`<``&8%````````N`8``/4"```R`@``BP<``*(#``#T!@``?0@`
M`!\$``!E!@``5`@````````I!```_`4``)X"````````&P0``)H$``!:!P``
MK`0``*D%```2!@``]`(``*`#``#:`0``H`<``',(```V"```'`0``&H#``#Y
M`P```````)P"``">"```W`4``#()``!:!0``C@,``$<%````````;0<``/\)
M``!.!0````````````"K````A`8`````````````>P4``+$&```3"@``.@0`
M`$<!```S"````````/`&```."```9P$```````#'````Y`D``.0(```;!@``
MA`D``!H$``#F!@``[@4``+((``#S"```_P,`````````````G`4```````#8
M"0```````/P#``"/`0```````(,(``"^`0``0@,`````````````;P0``+T`
M`````````````.\$```````````````````G`@``808``+X```"D`P``I@``
M````````````,04``)$'``!H`@```````.D'````````J`(`````````````
M[@```(\$``#\`````````"0%```:"0``WP$``&<(``"&"```B0D```````!2
M`P````````D(`````````````$8``````````````!@!``!2"```-`8``+H%
M```1`P``F0$``+\!``#&`0``+P```)$)``##`@``G@<``%@&```0"```+08`
M`(\"``#\!```]@(```````!`!@``C`8``%T'``#S"0``@0$`````````````
M'0$``#X!````````A@```-4$``"9"0``V0(```````"V`@`````````````;
M!0``[P(`````````````%`4``-4'``#."0``/`(```````!>"0``C`0``!4)
M````````ZP,``)0````Y`P``!`0``&L)``""!P``S@@``"8#``!["0``F@(`
M`.8(``"?`P``(@$``'H!```Z"```[@,``!0#```(!@`````````````7"0``
M\@,```````!="```MP$```````#6`P``P@```'T&```T!````````!L!``#5
M!0``)P,``*0$``#[!@``/@D```,#``"O"0````8````````Y!P``T@```!0&
M``!F"```W0,``#P&````````9@,``#@#``!J!P``?P0``(,'```L!P``````
M`.H'``"%"0``T@@``!T"``!U!P```````(T$````````.0(``.H)```H`P``
MKP(````````0`P```````,0&``#O!@``*0@``",(``#&!P``U@D``)8$```U
M!@``````````````````^@4````````>`0``%P<``(D"``#$`P```````!@'
M``!`"```_`D``*P'````````^P```&4"`````````````)`$````````````
M```````H`0``H@@```L)``"/!P``D@@``!0"````````;0@``)0(``"Q!0``
M7@4``,$'``!$````V0```'$$``""!@``?@8``)4#```"!P``/`,``'0'````
M````VPD`````````````-0```%0'``!&`P``A````'$'``!\"0``X````/L%
M``#_`@``!P,```````"X!0```````$\`````````L0,``+D!````````B0$`
M````````````]`0``$P#``````````````````!O!@``U`0``%`%``#F`@``
M1`,``.`!````````TP,``&\`````````>````$$"``#Q`0```````-$(````
M`````````,0"``#0`P``P00``-L'```5````BP8``$T(``"S`````````+8)
M``!T"0``,0,``,0$``#L!P````````8$```(`@``@`0``&L```!%`P``````
M`(<"````````I0(``$@(````````80<``"4"``!C"```J0,``&0%````````
M``````````"5!P``LP<````````\````+00``%0%````````JP$``*X'``"/
M!0```````!4!```E`0``K````(\)```D`P``A@<``!X&``"N!```6`0``*0'
M``!3"0``6PD``#<(```0`@``8P$```P'``!W"`````````````#C`P``>`(`
M`.8%````````1P8```````"E"```\`,``/@$```B!P``>`0```````![````
MM@@``,8"```4!````````.,$```P!@``=P```!@```#0"0``````````````
M````6@(``!<$```````````````@("`@("!4;SH@`"`@("!$871E.B``("`@
M($9R;VTZ(``@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E
M<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(%-U
M8FIE8W0Z(``@870@`"!I;B``(P`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I
M`"5D("5S(&%N9"`E<P`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@
M;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`E9"!M
M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P
M;W)T960@87,@<W!A;2X`)60@=&\@)60@;V8@)60@365S<V%G97,`)60M9&%Y
M(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T
M=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D
M>2!E>&ES=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W
M87,@;F]T(')E;F%M960N`"5S(&%T("5S("5S`"5S(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R96YA
M;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S(&AA<R!A8V-E<'1E
M9"X`)7,@:&%S(&-A;F-E;&QE9"`E<RX`)7,@:&%S(&1E8VQI;F5D+@`E<R!H
M87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E<R!H87,@<F5P
M;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S('-E;G0@>6]U
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S('1E;G1A=&EV96QY(&%C
M8V5P=&5D+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S
M(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('1O("5S(&]F("5S
M`"5S('=I<VAE<R!T;R!A;6UE;F0@)7,N`"5S('=I<VAE<R!T;R!M86ME('EO
M=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S
M="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S($)O;VL`)7,G
M<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`
M)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!<'!L>2!T:&5S92!C:&%N
M9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A<F0@86QL(&-H
M86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*0`H4F5T
M=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@
M8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R<F5N
M="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"A396YD(&UE<W-A9V4@
M869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H
M86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI
M960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J`"H@4&QE87-E('-E
M;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@;65S<V%G92!H87,@8F5E
M;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P
M86TN`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!S<&%M+@`Q,#`@8VAA<F%C=&5R<P`Q,#`P(&-H87)A8W1E
M<G,`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`,C4P
M(&-H87)A8W1E<G,`-3`P(&-H87)A8W1E<G,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9`!!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D
M('1O('1H:7,@;65S<V%G92X`02!M97-S86=E('EO=2!H879E('-E;G0@:&%S
M(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H92!R
M96-I<&EE;G0N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3
M;F]W(%-H;W=E<G,`04TO4$T`04Y$`$%022!)1`!!8F]U="!T:&ES(&5D:71O
M<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P="!R97%U97-T
M`$%C8V5P=&5D`$%C8V5P=&5D.B``06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT)W,@
M;F%M93H`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@0VAI;&0@1W)O=7``
M061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``
M061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN
M`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@<V]U<F-E`$%D9"!T:&4@
M)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&AI<R!T;R!M>2!C
M86QE;F1A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@87,@86X@871T86-H;65N="X`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(&EN9F]R;6%T
M:6]N(&-A;B!B92!V:65W960@)7,N`$%D9&ET:6]N86P@:6YF;W)M871I;VX@
M9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<P!!9&1I=&EO;F%L
M(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L
M(&UE<W-A9V4@97)R;W(@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@97)R
M;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1R97-S`$%D9')E<W,@
M0F]O:P!!9&1R97-S($)O;VMS`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO
M;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI
M<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!
M;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R
M;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL(&UE<W-A9V5S(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N
M92!-0D]8(&9I;&4Z`$%L;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R
M(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T
M960N`$%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M
M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T
M960N`$%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M
M86EL8F]X/P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06QT97)N871I=F4@
M<&%R=',@9F]R('1H:7,@<V5C=&EO;CH`06QW87ES`$%L=V%Y<R!S879E(&%T
M=&%C:&UE;G1S`$%M97)I8V%N(%-A;6]A`$%N(&5R<F]R(&]C8W5R960@=VAI
M;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE($E-
M05`@<V5R=F5R('-A:60Z(`!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T
M:&4@;F5W('1A<VLN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U
M<R!0<F]X>0!!;G-W97(`06YS=V5R960`06YS=V5R960@;65S<V%G97,`06YT
M87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI
M8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY($9I;'1E
M<G,`07!P;'D@1FEL=&5R<R!T;R`E<P!!<'!L>2!F:6QT97(@<G5L97,@=7!O
M;B!L;V=G:6YG(&]N/P!!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"
M3U@@:7,@9&ES<&QA>65D/P!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V
M90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V
M*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I
M<R!.3U0@<F5C;VUM96YD960A*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&\@=&AI<S\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T
M=&%C:&UE;G0_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES
M(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@
M=')A<V@@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N
M96YT;'D@9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\`07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@
M<W!A;3\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`
M07)R:79A;"!4:6UE`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES
M;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL`07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8V@`071T86-H($9I;&5S
M`$%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R
M(&UE<W-A9V4_`$%T=&%C:&5D($9I;&4Z`$%T=&%C:&5D(&9I;&4@(B5S(B!E
M>&-E961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A
M='1A8VAE9"X`071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E
M<75E<W0@>6]U('-E;G0N`$%T=&%C:&UE;G0`071T86-H;65N="!S=')I<'!E
M9#H@3W)I9VEN86P@871T86-H;65N="!T>7!E`$%T=&%C:&UE;G1S`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E;F1E97,`071T96YT:6]N
M`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@
M=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`075T;VUA=&EC86QL>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE
M<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2!A9&1R97-S8F]O:S\`
M079A:6QA8FQE($%D9')E<W,@8F]O:W,Z`$%V86EL86)L92!F:65L9',Z`$%W
M86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8U]K
M('1O("5S`$)A8VL@=&\@)7,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87)B861O<P!"87-E;&EN90!"8V,`0F5L87)U<P!"96QG:75M`$)E
M;&EZ90!"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE('-T871U<R!I;F9O
M<FUA=&EO;B!M97-S86=E+@!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A
M>0!";&%C:VQI<W0`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO
M="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";&]C:R!I;6%G
M97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A
M;&QY(')E<75E<W1E9#\`0F]D>0!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O
M<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$`0F]T:`!";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F
M($UE<W-A9V4`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL
M`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S
M86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O
M<&5R=&EE<RXN+@!#7VAA<G-E=`!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R
M=F5R+@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E
M<CH@`$-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R
M=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT(&UA:6QB;W@N`$-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R
M;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-C`$-E;&P@4&AO;F4`0V5L;"!0
M<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@
M<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E
M<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%D`$-H86ER(%!E<G-O;@!#:&%N9V4`0VAA;F=E($%L;`!#
M:&%N9V4@1F]L9&5R`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H
M;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W
M(&UE<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!M86EL('-E<G9E<B!A;F0@
M9F]L9&5R('-E='1I;F=S+@!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG
M;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;"X`0VAA<@!#:&%R86-T97)S('1O(&1I<W!L87DZ
M`$-H96-?:R!,:6YK+BXN`$-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`
M0VAE8VL@7T%L;"].;VYE`$-H96-K(&%L;"!M86EL('-E<G9E<G,@>6]U('=A
M;G0@=&\@9F5T8V@@;6%I;"!F<F]M.@!#:&5C:R!S<&5L;&EN9R!B969O<F4@
M<V5N9&EN9R!A(&UE<W-A9V4_`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O
M<V4@06-T:6]N.@!#:&]O<V4@82!M86EL('-E<G9E<CH`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O
M;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E<W-E<RX`0VAO;W-E('1H92!O
M<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`
M0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A
M`$-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O
M<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N`$-L:6-K("5S('1O(&1O=VYL
M;V%D('1H92!I;6%G92X`0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N
M="!P86=E+@!#;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E
M<&%R871E('=I;F1O=RX`0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O
M9B!T:&ES(&EM86=E+@!#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT
M(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W('1H:7,@
M;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RX`
M0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,`0VQI8VL@;VX@;VYE(&]F
M('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@
M86QL(&9I96QD<R!T;R!S96%R8V@N`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K
M('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VL`
M0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U
M<B!!9&1R97-S($)O;VL`0VQI8VMA=&5L;"!V:6$@2%144`!#;&EC:VEN9R!O
M;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T
M:&4@<V5N9&5R`$-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T
M:&4@;65S<V%G92!T;R!B92!R96%D`$-L;W-E`$-L;W-E(%=I;F1O=P!#;&]S
M92!T:&ES('=I;F1O=P!#;&]S960@1F]L9&5R`$-L;W5D<P!#;&]U9'D`0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4`0V]L;&%P<V4@06QL`$-O
M;&QA<'-E($%L;"!&;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VQL87!S92!3
M:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R
M($EN9&EC871O<CH@`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O
M;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L
M;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;&5T
M960`0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4`0V]M<&]S92!M97-S86=E<R!I
M;B!A('-E<&%R871E('=I;F1O=S\`0V]M<&]S92!M97-S86=E<R!W:71H(&%N
M($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE
M(&9E871U<F4I/P!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:6=U<F4@:&]W(&UE<W-A
M9V5S(&%R92!D:7-P;&%Y960N`$-O;F9I9W5R92!M86EL('!R979I97<@;W!T
M:6]N<RX`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN
M96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D
M`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!#;VYT:6YU90!#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E
M<RX`0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@=VAE
M;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O
M<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O;G9E<G0@
M=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\`0V]O:R!)
M<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'D@=&\@9F]L
M9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]S=&$@4FEC80!#;W1E(&0G
M279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T
M(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&-R96%T
M92!T:&4@5D93(&)A8VME;F0Z("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D
M871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T
M(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@
M)7,N(%1H92!S97)V97(@<V%I9#H@)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!E>&5C
M=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N`$-O=6QD(&YO="!E>'1R86-T
M('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE
M;G0N`$-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M
M('1H92!::7`@87)C:&EV92X`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`
M0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R
M96%T92!&;VQD97(`0W)E871E($ME>7,`0W)E871E(%9I<G1U86P@1F]L9&5R
M`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E
M871E(&$@;F5W(&]N90!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#
M<F5A=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L
M97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN
M=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O
M871I80!#=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT
M(%=E871H97(`0W5R<F5N="!A8V-E<W,@=&\@)7,`0W5R<F5N="!C;VYD:71I
M;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T
M8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+@!#=7-T;VUI>F4@:&]W
M('EO=2!S96YD(&UA:6PN`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L
M;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC
M("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871?
M90!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E('-E
M;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N
M=6UB97)S`$1E8VQI;F5D`$1E8VQI;F5D.B``1&5C<F5A<V4@26YD96YT`$1E
M9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@
M8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I
M;VYS`$1E;&5G871E9`!$96QE=&4`1&5L971E("5S(%!U8FQI8R!+97D`1&5L
M971E($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E;&5T92!'<F]U
M<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@5FER='5A;"!&;VQD97(`1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L
M=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E
M(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/P!$96QE=&4@
M9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!O;&0@<V5N="UM86EL
M(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/P!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9`!$96QE=&5D(&UE
M<W-A9V5S`$1E;&5T960@=&AE(&%T=&%C:&UE;G0@(B5S(BX`1&5L971I;F<@
M86YD($UO=FEN9R!-97-S86=E<P!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5N
M>2!R97%U97-T`$1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I
M;VX`1&5T86EL<P!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@`$1E=R!P;VEN=#H@`$1I;2!S:6=N871U<F5S/P!$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O
M<GD`1&ES<&QA>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T
M:6]N<P!$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S
M<V%G93\`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$
M:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G90!$:7-P;&%Y('!O<"UU<"!N;W1I
M9FEC871I;VX@;V8@;F5W(&UA:6P_`$1I<W!O<VET:6]N`$1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!.3U0@;6%T8V@`1&\@3F]T($-H
M96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1E;&5T90!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!N;W0@9V5N
M97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6X`1&\@>6]U('=A;G0@
M=&\@;W!E;B!T:&%T(&9O;&1E<C\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$
M;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N90!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA=`!$;W=N;&]A9"!!
M;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92D`1&]W;FQO860@1F]L9&5R
M*',I`$1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=`$1O=VYL;V%D
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O=VYL
M;V%D(&EN("YZ:7`@1F]R;6%T`$1R869T`$1R869T(&9O;&1E<@!$<F%F=',@
M9F]L9&5R.@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`12UM86EL($%D
M9')E<W,`15)2`$524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E
M;&EV97)E9"X`16-U861O<@!%9&ET`$5D:70@0FQA8VML:7-T`$5D:70@0FQO
M8VL`161I="!&:6QT97)S`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D
M:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!6
M:7)T=6%L($9O;&1E<@!%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@
M9F]R("5S`$5D:70@5VAI=&5L:7-T`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@>6]U<B!B;&%C:VQI<W0`161I="!Y
M;W5R(&9I;'1E<B!R=6QE<P!%9&ET('EO=7(@<')E9F5R96YC97,@9F]R(&%C
M8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+@!%9&ET('EO=7(@=VAI=&5L
M:7-T`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M
M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T
M8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T:65D
M(&%L;"!M97-S86=E<R!F<F]M("5S+@!%;7!T>2!&;VQD97(H<RD`16UP='D@
M5')A<V@@9F]L9&5R`$5M<'1Y(%]4<F%S:`!%;7!T>2!M97-S86=E+@!%;7!T
M>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@4$=0(&9U;F-T
M:6]N86QI='D_`$5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\`16YA8FQE
M(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@
M=&5X=#\`16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N8W)?>7!T:6]N($]P=&EO;G,`16YD`$5N
M9"!F;W)W87)D960@;65S<V%G90!%;F0@;65S<V%G90!%;F0@;65S<V%G92!F
M<F]M("5S`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(%!A<W-P:')A
M<V4`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H
M92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N
M="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A
M<V@@9F]L9&5R`$5N=')Y("(E<R(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!T:&4@861D<F5S<R!B;V]K`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`
M17)R;W(`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92X`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V
M96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+@!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@06QL`$5X<&%N
M9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.86UE<P!%>'!A
M;F0@4VED96)A<@!%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W
M(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_`$5X<&%N9"!T:&4@
M96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@
M=FEE=S\`17AP86YD:6YG`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O
M;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I
M;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B
M+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE
M9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R
M>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&971C:"!-86EL`$9E=&-H($UA
M:6P@:6X@82!S97!A<F%T92!W:6YD;W<_`$9E=&-H(&UE<W-A9V5S('5P;VX@
M;&]G9VEN9R!O;C\`1F5T8VAM86EL.B``1F5T8VAM86EL.B!N;R!N97<@;65S
M<V%G97,N`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FE?;'1E<G,`
M1FEE;&0@;6%T<FEX`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I
M;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL
M92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N`$9I;'1E<B!/<'1I;VYS`$9I;'1E<B!3971T:6YG<P!&:6QT97(@
M;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_`$9I;'1E<B!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!&:6QT97)S`$9I;'1E<G,@
M3D]4($%C=&EV90!&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4`1FEN9`!&
M:6YL86YD`$9I<G-T($AA;&8`1FER<W0@36%I;&)O>"!086=E`$9I<G-T(%!A
M9V4`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;U]R=V%R
M9`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;&1E<B!.879I9V%T
M;W(`1F]L9&5R(%-U;6UA<GD`1F]L9&5R('-H87)I;F<@:7,@;F]T(&5N86)L
M960N`$9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N`$9O;G0@0V]L;W(`1F]O
M9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E
M8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M870@;V8@;65S<V%G92!D871E
M<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A
M>0!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE
M<R`R`$9O<G5M<P!&;W)W87)D`$9O<G=A<F0Z`$9O<G=A<F1E9"!M97-S86=E
M`$9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,`1F]R=V%R9',`1G(`1G)A;65S
M`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E+T)U<WD@26YF;W)M
M871I;VX`1G)E92]"=7-Y(%)E<&QY`$9R964O0G5S>2!297%U97-T`$9R964O
M0G5S>2!297%U97-T(%)E<W!O;G-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O
M;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O7VT`1G)O
M;0!&<F]M($%D9')E<W,`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L
M;"!-;V]N`$9U;&P@3F%M90!&=V0Z`$9W9#H@`$9W9#H@)74@1F]R=V%R9&5D
M($UE<W-A9V5S`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A
M;&QE<GDZ`$=A;6)I80!'96YE<F%L($]P=&EO;G,`1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1V5T
M(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*0!':&%N80!':6)R86QT
M87(`1VEV96X@3F%M90!';R!T;R!-97-S86=E`$=O961E;`!';V]G;&4@4V5A
M<F-H`$=R86YT(&%C8V5S<P!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M
M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO
M;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5A9&5L
M;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N
M<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A%4D4`
M2%1-3`!(5$U,(%9E<G-I;VX@;V8@365S<V%G90!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E
M<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(
M96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E
M9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.@!(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O
M;7!O<VEN9SH`2&ED9&5N`$AI9&1E;B!I;B!4:')E860@5FEE=P!(:61E($1E
M;&5T960`2&ED92!5;G-U8G-C<FEB960`2&EG:`!(:6=H(%!R:6]R:71Y`$AI
M9VAE<W0`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N
M=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C
M="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z
M(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE
M`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@9&\@>6]U('=A;G0@=&\@
M9&ES<&QA>2!A='1A8VAM96YT<S\`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'D`
M2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0`$E-
M05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RD`24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@
M)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!
M4"!O=F5R(%-33`!)34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I
M8V%T92D`24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960I`$E-05`L(&YO(%1,
M4P!)34%0+U!/4#,@36%I;"!397)V97)S`$E.0D]8`$E0($%D9')E<W,`25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?
M;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BX`26=N;W)E`$EG;F]R92!!;&P`26UA9V4@4')E=FEE=SH`26UA9V4@55),
M`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L
M;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0`26UP;W)T($ME>0!)
M;7!O<G0@2V5Y<&%I<@!);7!O<G0@365S<V%G97,`26UP;W)T(%!'4"!+97D`
M26UP;W)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>0!);7!O<G0@4&5R<V]N
M86P@4'5B;&EC(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T
M:69I8V%T97,`26UP;W)T(%!U8FQI8R!+97D`26UP;W)T(%!U8FQI8R!01U`@
M2V5Y`$EM<&]R="!0=6)L:6,@4R]-24U%($ME>0!);7!O<G0@4R]-24U%($ME
M>0!);7!O<G0@;6)O>"!&:6QE`$EM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F
M;VQD97(@)7,N`$EM<&]R="P@4W1E<"`E9`!);7!O<G1A;G0`26UP;W)T86YT
M(&UE<W-A9V5S`$EM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@)7,N`$EM<&]R
M=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?
M<V5R="!2;W<@069T97(`26YB;W@`26YC;'5D92!A(&)R:65F('-U;6UA<GD@
M;V8@=&AE(&AE861E<B!I;B!A(')E<&QY/P!);F-L=61E(&]R:6=I;F%L(&UE
M<W-A9V4@:6X@82!R97!L>3\`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S
M97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&]N
M("5S(%!U8FQI8R!+97D`26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T
M92!+97D`26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC($ME>0!);FQI
M;F4`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($-E<G1I9FEC871E($AE
M<F4`26YS97)T($EM86=E`$EN<V5R="!097)S;VYA;"!0<FEV871E(%!'4"!+
M97D@2&5R90!);G-E<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D@2&5R90!)
M;G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R90!);G-E<G0@5&%B;&4`26YS97)T
M(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@
M8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@
M8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U
M<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A
M;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@
M;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B
M969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R
M90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E
M<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R
M;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S
M96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O
M36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H
M92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT
M96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R
M('1H:7,@8V]M<&]N96YT+@!);G9A;&ED($%D9')E<W,`26YV86QI9"!296UO
M=&4@36%I;&)O>`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!)
M;G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED
M(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N`$EN=F%L:60@9&%T
M82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV
M86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&ME>0!);G9A;&ED(&US9U]T>7!E
M+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV
M86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN`$EN=F%L:60@<&5R<V]N
M86P@4$=0('!U8FQI8R!K97DN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@
M<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@
M=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T`$ER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D
M(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`
M2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*
M;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF
M>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$M"`$MA>F%K:'-T
M86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I
M;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S
M86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX`2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+
M4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!-86EL
M8F]X(%!A9V4`3&%S="!086=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z
M`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L
M;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU
M97,`3&5S;W1H;P!,:5]N:R!!='1A8VAM96YT<P!,:6)E<FEA`$QI8GEA;B!!
M<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI
M9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG
M:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@
M4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I
M;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FME9"!A='1A8VAM96YT<R!A<F4@
M9F]R8FED9&5N+@!,:6YK<P!,:6YK<R!W:6QL(&5X<&ER92!O;B`E<P!,:6YU
M>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="!A
M;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E96X_
M("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@;VYL>2!S964@8V]N=&%C=',@=&AA
M="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*0!,:7-T+4%R8VAI=F4`3&ES
M="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S
M8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG(&EN('1H92!(96%D97(`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N
M:6$`3&]A9&EN9RXN+@!,;V-A;"!-86EL8F]X.@!,;V-A;"!T:6UE.B``3&]C
M86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@:6X@=&\@)7,`3&]G
M(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y
M;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C
M=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W<@4')I
M;W)I='D`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S
M`$QO=V5R(')O;6%N(&YU;6)E<G,`3&]W97-T`$QU>&5M8F]U<F<`34T`34]4
M1`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-
M86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8`36%C:6YT;W-H($9I;&4`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@
M061M:6X`36%I;"!0<F5V:65W<P!-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE
M8W0@=&\Z`$UA:6QB;W@`36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T
M:6]N<P!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M
M87``36%R8V@`36%R9VEN`$UA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A
M<R!3965N`$UA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96X`
M36%R:R!A<SH`36%R:R!D:69F97)E;G0@;&5V96QS(&]F('%U;W1I;F<@=VET
M:"!D:69F97)E;G0@8V]L;W)S/P!-87)K(&UE<W-A9V5S(&%S('-E96X_("A)
M34%0(&]N;'DI`$UA<FL@<VEM<&QE(&UA<FMU<#\`36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-
M871C:"!!;&P@475E<FEE<P!-871C:"!!;GD@475E<GD`36%T8VAI;F<@9FEE
M;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($%T=&%C
M:&UE;G0@4VEZ90!-87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!A
M='1A8VAM96YT<R!R96%C:&5D+@!-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@
M<VEZ92!R96%C:&5D+@!-87D`36%Y;W1T90!-961I8VEN90!-965T:6YG($-A
M;F-E;&QA=&EO;@!-965T:6YG($EN9F]R;6%T:6]N`$UE971I;F<@4')O<&]S
M86P`365E=&EN9R!297!L>0!-965T:6YG(%5P9&%T90!-965T:6YG(%5P9&%T
M92!297%U97-T`$UE;6)E<G,`365N=2!&;VQD97(@3&ES=`!-96YU(&UO9&4Z
M`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!#;VUP;W-I=&EO;@!-97-S
M86=E($1A=&4`365S<V%G92!/<'1I;VYS`$UE<W-A9V4@4V5A<F-H`$UE<W-A
M9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92!V97)I9FEE9"X`365S<V%G92!6:65W:6YG`$UE<W-A9V4@97AP:7)E
M9"X`365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G92!F<F]M
M("5S`$UE<W-A9V4@;6%T8VAE<P!-97-S86=E(')E9&ER96-T960@<W5C8V5S
M<V9U;&QY+@!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A
M=F5D('1O("5S`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN`$UE<W-A9V4@
M='EP90!-97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W+@!-
M97-S86=E<R!T;P!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-
M971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`
M36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN
M('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S
M:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF
M:65D($1A=&4`36]D:69Y`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!2
M97!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N
M=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`36]S=&QY($-L
M96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4`36]V92!$;W=N
M`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@
M=&\@9F]L9&5R`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',`375L=&EP87)T+V%L=&5R;F%T:79E`$UU;'1I<&QE('-E
M;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T
M`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$Y/5$4`3F%M90!.86UE(&%N
M9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y`$YA;6EB:6$`3F%U<G4`3F5E
M9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL
M;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=F5R('-A=F4@871T
M86-H;65N=',`3F5W`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!&
M;VQD97(`3F5W($UA:6P`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA
M;"D`3F5W(%IE86QA;F0`3F5W(&UE<W-A9V5S`$YE=R!W:6YD;W<@*%]B;&%N
M:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!-97-S86=E`$YE>'0@4&%G
M90!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`
M3FEU90!.;P!.;R!#97)T:69I8V%T92!F;W5N9`!.;R!%;F-R>7!T:6]N`$YO
M($ME>7,@:6X@2V5Y<FEN9P!.;R!-97-S86=E<P!.;R!01U`@<'5B;&EC(&ME
M>2!I;7!O<G1E9"X`3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N=`!.
M;R!0=6)L:6,@2V5Y<R!&;W5N9`!.;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O
M<G1E9"X`3F\@871T86-H;65N=',@9F]U;F0N`$YO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A
M=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@9F]L9&5R('-E;&5C=&5D+@!.
M;R!F;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"X`3F\@
M9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!F;VQD97)S('=I=&@@;F5W(&UE
M<W-A9V5S`$YO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,`3F\@:6-O
M;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;65S<V%G92!B;V1Y
M('1E>'0`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;65S<V%G97,@;6%T8VAE
M9"!Y;W5R('-E87)C:"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S
M<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P
M96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q
M,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('!E<G-O;F%L(%!'4"!P
M<FEV871E(&ME>2!I;7!O<G1E9"X`3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K
M97D@:6UP;W)T960N`$YO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@
M:6UP;W)T960N`$YO(')U;&5S`$YO('-I9&5S`$YO('-P96QL8VAE8VMI;F<@
M<')O9W)A;2!C;VYF:6=U<F5D+@!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G
M9V5S=&EO;G,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+@!.;R!U<V5R('-P96-I9FEE9"X`3F\@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO
M('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F]N(%!A<G1I8VEP86YT`$YO;F4`3F]N92`H=7-E(&EM<&QI
M8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)M
M86P`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N
M9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!$96QE=&5D`$YO
M="!$<F%F=`!.;W0@26UP;W)T86YT`$YO="!097)S;VYA;`!.;W0@82!D:7)E
M8W1O<GD`3F]T(&$@=F%L:60@<'5B;&EC(&ME>2X`3F]T(&1E;&5T960@;65S
M<V%G97,`3F]T(&EM<&QE;65N=&5D+@!.;W0@:6UP;W)T86YT(&UE<W-A9V5S
M`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T92!T:&%T('1H:7,@8V%N('1A
M:V4@<V]M92!T:6UE`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK
M960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F
M(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO
M;G1H;'DN`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]2`$]B:F5C
M=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R
M`$]F9FEC90!/;&0@;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E
M:6YG('!U<F=E9"X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H
M87)E9"!F;VQD97)S+@!/;FQY(&1I<W!L87D@9F]L9&5R<R!W:71H('5N<F5A
M9"!M97-S86=E<R!I;B!T:&5M/P!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE(&9O;&1E
M<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+@!/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N
M(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT
M<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N960@1F]L
M9&5R`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG
M(%-Y<W1E;0!/<'1I;VYA;"!087)T:6-I<&%N=`!/<'1I;VYS`$]P=&EO;G,@
M9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N
M86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF
M;W)M871I;VX`3W1H97(@36%I;"!!8V-O=6YT<P!/=&AE<B!/<'1I;VYS`$]W
M;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!01U``4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T
M($UE<W-A9V4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!%<G)O<CH@`%!'4"!%
M<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME
M>2X`4$=0($]P=&EO;G,`4$=0(%!A<W-P:')A<V4@26YP=70`4$=0(%!E<G-O
M;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BX`4$=0(%!U8FQI8R!+97D`4$=0(%!U8FQI8R!+97D@5&5X=`!0
M1U`@4'5B;&EC($ME>2!F;W(@(B5S("@E<RDB('=A<R!S=6-C97-S9G5L;'D@
M861D960N`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,B('=A<R!S=6-C97-S9G5L
M;'D@9&5L971E9"X`4$=0(%!U8FQI8R!+97ER:6YG`%!'4"!3:6=N($UE<W-A
M9V4`4$=0(%-I9VXO16YC<GEP="!-97-S86=E`%!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$`4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`
M4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@<W5P<&]R
M="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`4$=0('-U<'!O<G0@:7,@
M;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E
M(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4$=0('-U<'!O<G0@:7,@;F]T
M(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O
M(&)E(&1E8W)Y<'1E9"X`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A
M:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!4+5-T
M;W)M<P!03U`S`%!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RD`4$]0,R!O
M=F5R(%-33`!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T
M92D`4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I`%!/4#,L(&YO(%1,4P!0
M7TA0(%-H96QL`%!A9&1I;F<`4&%G92`E9"!O9B`E9`!086=E('=I=&@@=&AE
M($9I<G-T(%5N<V5E;B!-97-S86=E`%!A9V4@=VET:"!T:&4@3&%S="!5;G-E
M96X@365S<V%G90!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y
M`%!A<G0H<RD`4&%R=&QY($-L;W5D>0!087-S<&AR87-E`%!A<W-P:')A<V4@
M*$%G86EN*0!087-S<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"X`4&%S
M<W!H<F%S93H`4&%S<W!H<F%S97,@8V%N(&YO="!B92!E;7!T>0!087-S<&AR
M87-E<R!D;R!N;W0@;6%T8V@`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T
M`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R
M9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L
M:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R
M(&-A;B!N;W0@8F4@8VAA;F=E9"X`4&5R<V]N86P`4&5R<V]N86P@26YF;W)M
M871I;VX`4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2X`4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN
M`%!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B``
M4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN`%!E
M<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX
M96QS`%!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F
M;W)W87)D<S\`4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G90!0;&%T:71U
M9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N
M="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H
M96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E
M;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T
M:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N97<@;F%M93H`4&QE
M87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E
M(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N=&5R('1H:7,@<&%S<W!H
M<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A<V4@96YT97(@=&AE('!A
M<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL
M;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R
M("5S('-E<W-I;VXN`%!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O
M;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG(&-O
M;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P
M('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@;&]G(&EN(&%G86EN(&EN('EO
M=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C
M:V5R<R!F<F]M(&AI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO
M9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N`%!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!P
M87-S=V]R9"X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92X`4&QE87-E(')E
M<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+@!0;&5A<V4@
M<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E
M;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('-E
M;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N
M`%!L96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N
M`%!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N
M`%!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A
M=&EO;BX`4&QE87-E('-E;&5C="!O<B!E9&ET(&EN('1H92!B;W@@=&\@=&AE
M(')I9VAT.@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O
M;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!O=V5R960@8GD@
M2&]R9&4`4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM
M("<I/P!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F
M97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S
M=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE
M=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@
M365S<V%G90!0<F5V:6]U<R!086=E`%!R979I;W5S(&]P=&EO;G,`4')I;G0`
M4')I;G0@9&]C=6UE;G0`4')I;W)I='D`4')I=F%T92!+97D`4')I=F%T92!+
M97D@4&%S<W=O<F0`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE
M8W1S`%!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@
M9&5F875L="!T;R!.3P!0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT
M(&ES('-E;G0[(&1E9F%U;'0@=&\@6453`%!R;VUP="!T97AT`%!R;W1O8V]L
M.@!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!01U`@
M:V5Y<V5R=F5R('-U<'!O<G0@:&%S(&)E96X@9&ES86)L960N`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U
M97)T;R!2:6-O`%!U<E]G92!$96QE=&5D`%!U<F=E($1E;&5T960`4'5R9V4@
M1F]L9&5R*',I`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S<V%G
M97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@
M9&%Y<RX`4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_
M`%%A=&%R`%%U97)Y`%%U;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H
M)2XR9B4E*0!1=6]T82!S=&%T=7,Z("4N,F9-0B`O($Y/($Q)34E4`%%U;W1A
M('-T871U<SH@3D\@3$E-250`475O=&EN9R`E9CH`4E-!(%!U8FQI8R!+97D@
M*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN
M($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`
M4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5?<75E<W0@1&5L:79E<GD@0V]N9FER
M;6%T:6]N`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5C96EV960@3VX`4F5C96EV960@4VEN8V4`4F5C96EV
M960@56YT:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T($UE<W-A9V4`
M4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE9"X`4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SH`4F5F<F5S:"!&;VQD97(@5FEE=W,Z`%)E9G)E<V@@
M4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A
M9`!296QO860@5FEE=P!296UA<FMS`%)E;65M8F5R('1H92!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E($UA
M:6QB;W@Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!&:65L9"!&<F]M(%-E87)C:`!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M
M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@<V]U<F-E`%)E
M;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!2
M96UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5N86UE($9O;&1E<BAS*0!2
M96YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`4F5P;%]Y('1O($QI<W0`4F5P;&%C92!W:71H.@!2
M97!L>0!297!L>2!396YT+@!297!L>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!2
M97!L>2!T;R!,:7-T`%)E<&QY('1O($QI<W0Z`%)E<&QY('1O(%]!;&P`4F5P
M;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E
M+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DM5&\`4F5P;'DM5&\Z(`!2
M97!L>3H`4F5P;W)T(&%S($EN;F]C96YT`%)E<&]R="!A<R!3<&%M`%)E<75E
M<W0@82!?4F5A9"!296-E:7!T`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R
M960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W0@9&5L:79E<GD@8V]N
M9FER;6%T:6]N/P!297%U97-T(')E860@<F5C96EP=',_`%)E<75E<W1E9"!M
M97-S86=E(&YO="!F;W5N9"X`4F5Q=6ER960@1FEE;&0`4F5Q=6ER960@4&%R
M=&EC:7!A;G0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-P;VYD96YT(%-T871U<R!5<&1A=&5D+@!297-U;'1S`%)E<W5M
M90!297-U;64@>6]U<B!S97-S:6]N`%)E='5R;B!T;R!&971C:"!-86EL`%)E
M='5R;B!T;R!/<'1I;VYS`%)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG
M(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E
M/P!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V
M86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@
M,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2
M;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O
M34E-10!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N
M8W)Y<'0@365S<V%G90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4R]-24U%
M($5R<F]R.B``4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E
M<G-O;F%L('!R:79A=&4@:V5Y+@!3+TU)344@3W!T:6]N<P!3+TU)344@4&%S
M<W!H<F%S92!);G!U=`!3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T
M(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!3+TU)344@4'5B
M;&EC($ME>2!F;W(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%,O
M34E-12!0=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`4R]-24U%(%!U
M8FQI8R!+97ER:6YG`%,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U
M8V-E<W-F=6QL>2!A9&1E9"X`4R]-24U%(%-I9VX@365S<V%G90!3+TU)344@
M4VEG;B]%;F-R>7!T($UE<W-A9V4`4R]-24U%('-U<'!O<G0@:7,@9&ES86)L
M960@;VX@=&AI<R!S>7-T96TN`%,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R
M96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@
M9&5C<GEP=&5D+@!3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T
M:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E('9E<FEF:65D
M+@!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-
M97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4U]U
M8FIE8W0`4V$`4V%?=F4@82!C;W!Y(&EN(`!385]V92!A<P!386EN="!(96QE
M;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!
M<F%B:6$`4V%V90!3879E("5S`%-A=F4@071T86-H;65N=',@=VET:"!M97-S
M86=E(&EN('-E;G0M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`4V%V92!/<'1I
M;VYS`%-A=F4@7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@87,@=6YS965N
M/P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F4@
M<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E
M<W,@8F]O:S\`4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E<C\`4V%V
M92!S96YT(&UA:6P_`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=FEN9R!T
M:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`E<P!38VEE;F-E`%-E87)C:`!396%R8V@@)7,`4V5A<F-H($5N9VEN97,`
M4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`4V5L96-T($%N;W1H97(@06-C
M;W5N=`!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!F:65L
M9`!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E
M;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@861D
M<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O
M<B!A9&1R97-S97,N`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O
M;F5N=',N`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N
M9&EN9R!A9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!A;B!O
M8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N
M965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A
M;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE
M(&UA:6P@<V5R=F5R('1Y<&4`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`
M4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.@!396QE8W1E9"!!9&1R97-S(&)O;VMS.@!3
M96YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R`%-E;F0@3&%T97-T($EN9F]R
M;6%T:6]N`%-E;F0@365S<V%G90!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@
M4TU3`%-E;F5G86P`4V5N<V]R.B``4V5N="!M86EL(&9O;&1E<@!396YT(&UA
M:6P@9F]L9&5R.@!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E
M<FEA;"!.=6UB97(`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T
M:6]N`%-E<G9E<CH`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO
M;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U
M(&5V97(@9F]R9V5T(&ET+@!3970@<')E9F5R96YC97,@9F]R('=H870@:&%P
M<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N`%-E="!T
M:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_
M`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S
M<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R
M861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F4@1F]L
M9&5R<P!3:&%R92!M86EL(&9O;&1E<G,`4VAA<F4@>6]U<B!M86EL(&9O;&1E
M<G,@=VET:"!O=&AE<B!U<V5R<RX`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`
M4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O
M<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E('1O9V=L960@96%S:6QY
M('=H:6-H979E<B!Y;W4@8VAO;W-E+@!3:&]U;&0@=&AE(&)O9'D@;V8@=&5X
M="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\`4VAO
M=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG
M(&$@9')A9G0_`%-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T
M=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\`4VAO=P!3:&]W
M($%L;"!&;VQD97)S`%-H;W<@06QL($AE861E<G,`4VAO=R!$96QE=&5D`%-H
M;W<@3&EM:71E9"!(96%D97)S`%-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T
M:6]N`%-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,`4VAO=R!5;G-U8G-C
M<FEB960`4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A
M8VAM96YT<R!F<F]M(&UE<W-A9V5S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\`4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!O
M<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('!R979I
M97=S(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\`4VAO=R!P<F5V:65W<R!I
M;B!T;V]L=&EP<S\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3
M:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!&971C:"!-
M86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE($EM86=E<P!3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N
M=6)A<C\`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/P!3:&]W('5P;&]A9`!3
M:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y`%-H;W=N`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VE?>F4`
M4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O
M<FET:&T`4VEG;F5D`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`
M4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E
M<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@
M9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES
M;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@8GD@07)R:79A;`!3
M;W)T(&)Y($1A=&4`4V]R="!B>2!&<F]M($%D9')E<W,`4V]R="!B>2!-97-S
M86=E(%-I>F4`4V]R="!B>2!3=6)J96-T`%-O<G0@8GD@5&AR96%D`%-O<G0@
M8GD@5&\@061D<F5S<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D
M<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A
M;0!3<&%M(&9O;&1E<CH`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!E8VEA
M;"!#:&%R86-T97)S`%-P96QL($-H96-K`%-P96QL($-H96-K97(`4W!E;&P@
M8VAE8VL@8V]M<&QE=&4`4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE
M;B!S<&5L;"!C:&5C:VEN9RX`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L
M:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T
M87)T`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A
M9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG
M(&QI<W0`4W1R:7`@071T86-H;65N=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@
M861D<F5S<P!3=')I<"!L:6YE8G)E86MS/P!3='EL92!;0U-370!3=0!3=6)?
M:F5C=`!3=6)J96-T`%-U8FIE8W0@1FEE;&0`4W5B;6ET`%-U8G-C<FEB92!T
M;R!&;VQD97(H<RD`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`
M4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C
M97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6=G97-T:6]N<P!3
M=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E
M+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T
M`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA
M>65N`%-W87II;&%N9`!3=V5D96X`4W=I=&-H($-O;7!O<VET:6]N($UE=&AO
M9`!3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO;@!3=VET8V@@=&\@<&QA:6X@
M=&5X="!C;VUP;W-I=&EO;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3
M=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P
M<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A
M:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z
M`%1A<VMS`%1E7WAT`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H
M;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI
M;FES=')A=&EO;@!496YT871I=F4Z(`!496YT871I=F5L>2!!8V-E<'0@<F5Q
M=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497)M<R!O9B!397)V:6-E(&9I
M;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<`!497AT($]N;'D`5&5X="!A
M;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H86YK
M('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92X`5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S
M<V%G92!S:&]U;&0@8F4@;&EN:V5D.@!4:&4@2&]R9&4O2V]L86(@:6YT96=R
M871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%C:6YT
M;W-H(')E<V]U<F-E(&9O<FL`5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K
M(&-A;B!B92!D;W=N;&]A9&5D("5S+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@86-C;W5N="`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!A8V-O=6YT("(E<R(@:&%S(&)E96X@<V%V960N
M`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!0
M97)M:7-S:6]N<RX`5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N9"X`5&AE
M(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI
M9`!4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S
M('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@<&]P=7`@=VEN
M9&]W<S\`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!4:&4@8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S:"!F
M:6QE(&%R92!B96QO=RX`5&AE(&-U<G)E;G0@9F]L9&5R*',I("(E<R(@=VEL
M;"!B92!R96YA;65D('1O("(E<R(N`%1H92!C=7)R96YT(&QI<W0@;V8@=7-E
M<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E
M=')I979E9`!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&1R869T
M(&AA<R!B965N('-A=F5D('1O('1H92`B)7,B(&9O;&1E<BX`5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BX`5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+@!4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE
M(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82X`5&AE(&9O;&1E<B`B)7,B(&%L<F5A9'D@97AI<W1S
M`%1H92!F;VQD97(@(B5S(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@
M:6X@:71S(&YA;64N($ET(&UA>2!C875S92!P<F]B;&5M<RX@4&QE87-E('-E
M92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4:&4@9F]L9&5R("(E<R(@
M=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET
M+@!4:&4@9F]L9&5R("(E<R(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO
M="!U;G-U8G-C<FEB960@9G)O;2!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!N
M;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@
M9F]L9&5R("(E<R(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY
M(&-R96%T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E
M;&5T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M
M960@=&\@(B5S(BX`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9O;&QO=VEN9R!F
M:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R=#H`5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E
M<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N
M8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD
M97(@:7,@<')E<V5N="!I;B!Y;W5R(&%D9')E<W-B;V]K+@!4:&4@;&5F="UH
M86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R
M>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE
M(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R(&UE
M<W-A9V4Z`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN
M9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z`%1H92!M86EL('-E<G9E<B!G96YE
M<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.@!4:&4@;6%I;&)O>"`E<R!I
M<R!A;')E861Y(&5M<'1Y+@!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B`H
M)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="X`5&AE(&UE<W-A
M9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG+@!4
M:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+@!4:&4@;65S<V%G92!H87,@
M8F5E;B!V97)I9FEE9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N
M(%-E;F1E<CH@)7,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET
M:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO
M(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@
M=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T
M:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E
M9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P87-S
M<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA
M=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/P!4
M:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE
M`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')A=R!T97AT(&]F
M('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+@!4:&4@<F5Q
M=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE($U3+51.148@871T
M86-H;65N="X`5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!::7`@871T86-H;65N="X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S96YD97(@;V8@
M=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B!F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@
M=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@;F]T
M:69I8V%T:6]N(&UE<W-A9V4N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S
M97)V97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T
M:&ES(&EM86=E+@!4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E
M9"X`5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+@!4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="X`5&AE('-P96-I9FEE
M9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T87-K(&AA<R!B965N(&%D9&5D
M('1O('EO=7(@=&%S:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O
M97,@;F]T(&5X:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G90!4:&4@=&5X
M="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O
M9B!T:&4@<F5T=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@<F5T=7)N
M960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T:&4@
M<V5N="!M97-S86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N
M(&)E('9I97=E9"`E<RX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`
M5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"X`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!A;'1E<FYA
M=&EV92!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+@!4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@
M8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S
M(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE
M<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@
M=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&$@
M<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E
M<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@
M97)R;W(@8V]P>6EN9R!M97-S86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S
M`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+@!4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M=`!4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE
M(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO
M;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD
M+@!4:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@(B5S
M(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R
M92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T
M+@!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A
M:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&5V96YT.B`E<RX`5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E
M('!A<G0`5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I
M;B!I="X`5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I
M;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@=&AI<SH@`%1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M`%1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O('1H92!M97-S
M86=E+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C=&EO
M;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E
M96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L
M;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A
M;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R
M,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`
M5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E
M('9I<VET("5S`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G92!C;VYT86EN
M<R!A($UA8VEN=&]S:"!F:6QE+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@
M871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA
M(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@
M=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S
M86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N
M+"!B=70@=&AE(&9O<FUA="!O9B!T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BX`
M5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'
M4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z(`!4:&ES(&UE<W-A9V4@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@
M*&%C8V]R9&EN9R!T;R!21D,@,C`Q-2DN`%1H:7,@;65S<V%G92!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="X`
M5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'
M4"X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA
M(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@
M4R]-24U%+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@
M4$=0+@!4:&ES(&UE<W-A9V4@=&\`5&AI<R!M97-S86=E('=A<R!W<FET=&5N
M(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&$@8V]M<&]S92!W:6YD;W<N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AR96%D(%9I97<`5&AU;F1E
M<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE
M('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ
M`%1O`%1O($%D9')E<W,`5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL
M92!C;&EC:VEN9RX`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL
M92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K
M96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4;W1A
M;"!!='1A8VAM96YT<R!3:7IE.@!4<F%N<VQA=&EO;G,`5')A<V@@9F]L9&5R
M`%1R87-H(&9O;&1E<CH`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A
M;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U
M<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y
M<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5
M:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U
M<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@
M=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')E=')I979E
M('%U;W1A`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A
M;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@
M9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86YS
M=V5R960`56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T90!5;F1E<FQI;F4`
M56YD:7-C;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`56YD;V5S('EO
M=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@`%5N9FEL960`56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E
M.B`E<P!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI
M=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R
M($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N($1A=&4`
M56YK;F]W;B!-965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FQO860@4&%S<W!H<F%S
M90!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@
M0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R
M96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@
M;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C
M<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS965N`%5N<V5T(&-O
M;&]R`%5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I`%5N<W5P<&]R=&5D($5X
M=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!!='1A8VAM96YT($EN
M9F]R;6%T:6]N`%5P9&%T92!R97-P;VYD96YT('-T871U<P!5<&1A=&4@=7-E
M<@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL
M(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R
M(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S
M92!#=7)R96YT.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@24U!4"!F;VQD
M97(@<W5B<V-R:7!T:6]N<S\`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R
M9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N
M`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R;F%M
M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5
M>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T
M:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`
M5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S
M96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@
M86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I
M970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=P!6:65W("5S`%9I97<@
M)7,@4'5B;&EC($ME>0!6:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E
M('=I;F1O=P!6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y`%9I97<@4&5R<V]N
M86P@4'5B;&EC($ME>0!6:65W(%1H<F5A9`!6:65W(%1H=6UB;F%I;`!6:65W
M(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!A='1A8VAM
M96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I97<@8V]N=&5N="!I;B!A('-E
M<&%R871E('=I;F1O=P!6:65W(&5V96YT`%9I97<@;65S<V%G97,@:6X@)7,`
M5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ`%9I97<@
M=&%S:P!6:65W('1H92!);6%G97,`5FER9VEN($ES;&%N9',L($)R:71I<V@`
M5FER9VEN($ES;&%N9',L(%4N4RX`5FER='5A;"!&;VQD97(@(B5S(B!C<F5A
M=&5D('-U8V-E<V9U;&QY+@!6:7)T=6%L($9O;&1E<G,`5FER='5A;"!&;VQD
M97)S(')E<75I<F4@82!L86)E;"X`5FER='5A;"!F;VQD97(@;&%B96P`5FES
M:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``
M5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C
M87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`
M5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ
M-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5N(&1E
M;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD
M97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@87,@9&5L971E9#\`5VAE;B!O
M<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A;G0@
M=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD('=E
M('-A=F4@871T86-H;65N="!D871A/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:&ET
M96QI<W0`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK
M:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7
M:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`6"U2
M968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!9
M60!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R
M964`66]U(&%R92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL
M;W=I;F<@86-C;W5N="AS*3H`66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A
M(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O
M(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BX`66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO=2!C86X@;F]T(&AA
M=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D
M:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N
M="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@=&\@;&]G:6XN`%EO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<@!9;W4@
M9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN
M9R!R96-I<&EE;G1S.B`E<RX`66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+@!9
M;W4@:&%V92`Q(&YE=R!M97-S86=E+@!9;W4@:&%V92!A="!L96%S="!O;F4@
M871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@=7!L;V%D('EE
M="X@07)E('EO=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI<R!M97-S86=E
M('=I=&AO=70@=&AE<V4@871T86-H;65N=',_`%EO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F
M;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L
M9&5R<SH`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U
M(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E
M(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9;W4@;75S="!E;G1E<B!T:&4@
M<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE
M=R!T:&ES(&UE<W-A9V4`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB
M;W@@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E
M;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T
M('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G92!F:7)S="X`66]U(&UU<W0@
M<W!E8VEF>2!A(')E8VEP:65N="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@9FEL
M92!T;R!A='1A8V@N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(')E9&ER96-T
M960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RX`66]U(')E<&QI960@=&\@
M=&AI<R!M97-S86=E(&]N("5S+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T
M;R`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E
M(&YO="!U;G-U8G-C<FEB960@9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%EO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D
M('1O("(E<R(`66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F
M<F]M("(E<R(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!01U`@4'5B;&EC+U!R:79A=&4@
M2V5Y<P!9;W5R(%!R:79A=&4@2V5Y`%EO=7(@4'5B;&EC($ME>0!9;W5R(%,O
M34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,`66]U<B!A8V-O=6YT
M<SH`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92X`66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U
M<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N
M9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&5N8W)Y<'1I;VX@;65T:&]D
M(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M`%EO=7(@9G5L;"!N86UE.@!9;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL
M>2!D96QI=F5R960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I
M;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G
M(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E
M<G,Z`%EO=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!:
M:6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6TYO(%-U8FIE8W1=
M`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN
M:7-T<F%T:6]N`%]"8V,`7T)L86-K;&ES=`!?0TQ)`%]#8P!?1&%T851R964`
M7T1E;&5T90!?1&5L971E(%)O=P!?1F]L9&5R<P!?1W)O=7!S`%](96QP`%])
M9&5N=&ET>0!?26UA9V4@4')O<&5R=&EE<RXN+@!?26YB;W@`7TQO9R!I;@!?
M3&]G(&]U=`!?365S<V%G92!3;W5R8V4`7TUO9&EF>2!,:6YK+BXN`%]/<'1I
M;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U!R:6]R:71Y`%]2969R97-H("5S
M`%]296UO=F4@3&EN:RXN+@!?4F5P;'D`7U-E87)C:`!?4V5N9"!-97-S86=E
M`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?5&AR96%D`%]4;P!?56YD
M96QE=&4`7U5S97)S`%]6:65W(%1H<F5A9`!?5VAI=&5L:7-T`&%D9')E<W,@
M8F]O:P!A='1A8VAM96YT`&%T=&%C:&UE;G1S+GII<`!B>71E<P!C86QE;F1A
M<@!C86QM`&-L:6-K(&AE<F4`9F%L;&EN9P!F:6QE`&9R;VT`9G)O;2!T:&4@
M)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&ME>0!L:6YE
M<UT`;6%I;&)O>"!F:6QE`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!N86UE`&YO;F4`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@
M:6UP;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT`'!I>&5L<P!R:7-I;F<`
M<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W!E;&QI;F<@
M97)R;W(`<W!E;&QI;F<@97)R;W)S`'-T96%D>0!T87-K(&QI<W0`='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`
M=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`>6]U<B!B;&%C:VQI
M<W0`>6]U<B!W:&ET96QI<W0`4')O:F5C="U)9"U697)S:6]N.B!)35`@-"XP
M+C,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2
M979I<VEO;BU$871E.B`@,C`P,2TP-RTR-B`Q-#HU-BTP.3`P"DQA<W0M5')A
M;G-L871O<CH@36EL;W,@5VEM;65R(#QW:6UM97)`>F-U+F-Z/@I,86YG=6%G
M92U496%M.B!#>F5C:"`\9&5V0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S
M:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E3
M3RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*4&QU
M<F%L+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]/3$@)B8@;B4Q
M,#`A/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@;B4Q,#P]-"`F)B`H;B4Q,#`\,3`@
M?'P@;B4Q,#`^/3(P*2`_(#$@.B`R*3L*`"`@("`@($MO;74Z(``@("`@1&%T
M=6TZ(``@("`@3V0Z(``@*'#X960@)7,@9&YY*0`@*%#X[7-T=7!O=OT@:VSM
MZ"`E<RD`("AV("5S(&1N96-H*0`@*&1N97,I`"`H>NUT<F$I`"`H=NAE<F$I
M`"!0^&5D;>QT.B``(')Y8VAL;W-T(``@=B``(P`E+C)F34(@+R`E+C)F34(@
M("@E+C)F)24I`"5D("5S(&$@)7,`)60@>G!RX78@8GEL;R!N86ALX;EE;F\@
M5F&Y96UU('-Y<W3I;6]VZ6UU(&%D;6EN:7-T<N%T;W)O=FD@:F%K;R!C:'3L
M;ND@>G!RX79Y("AH86TI+@`E9"!Z<'+A=B!B>6QO(&YA:&SAN65N;R!J86MO
M(&-H=.QNZ2!Z<'+A=GD@*&AA;2DN`"5D('IP<N%V(&)Y;&\@;F%H;.&Y96YO
M(%9AN65M=2!S>7-TZ6UO=NEM=2!A9&UI;FES='+A=&]R;W9I(&IA:V\@;F5C
M:'3L;ND@>G!RX79Y("AS<&%M*2X`)60@>G!RX78@8GEL;R!N86ALX;EE;F\@
M:F%K;R!N96-H=.QNZ2!Z<'+A=GD@*'-P86TI+@`E9"!AOB`E9"!Z("5D('IP
M<N%V`"5D+61E;F[M('#X961P;W;L[P`E<R`M(&]Z;N%M96[M`"5S(&]T:7-K
M`"5S($M"`"5S(&]P97)A8V4@^F1ROF)Y("T@<&]T=G)Z96[M`"5S(&YA<W1A
M=F5N[0`E<R!R96=I<W1R86-E`"5S('!O9&WM;FMY('!O=;[M=N%N[0`E<R!J
M:;X@97AI<W1U:F4N`"5S('6^(&5X:7-T=6IE+B!3;&^^:V$@)7,@;F5B>6QA
M('#X96IM96YO=N%N82X`)7,@;F$@)7,@)7,`)7,@;F5N[2!P;&%T;N$@<V-H
M<N%N:V$N`$YA('IAZ.%T:W4@;>QS[6-E(&)U9&4@<VQOOFMA("5S('#X96IM
M96YO=N%N82X`)7,@</AI:F%L*&$I+@`E<R!Z<G6Y:6PH82D@)7,N`"5S(&]D
M;>UT;G5L*&$I+@`E<R!O9'!O=NQD[&PH82D@;F$@ON%D;W-T(&9R964O8G5S
M>2X`)7,@;V1P;W;L9.QL*&$I(&YA('!O>G;A;FMU(&L@)7,N`"5S('IA<VQA
M;"AA*2!I;F9O<FUA8VD@;R!F<F5E+V)U<WDN`"5S('#X961B[+YN["!P^&EJ
M86PH82DN`"5S(&IE('!OOF%D;W;A;F\`)7,@;6EN=70`)7,@;F5B>6QO(&YA
M;&5Z96YO+@`E<R"^X63A(&\@:6YF;W)M86-I(&\@9G)E92]B=7-Y+@`E<R"^
MX63A(&\@5F&Y:2#ZZ&%S="!N82`E<RX`)7,@8;X@)7,@>B`E<P`E<R!S:2!P
M^&5J92#Z<')A=G4@)7,N`"5S('-I('#X96IE(%;A<R!U<&]Z;W)N:70@;F$@
M)7,N`"5S('-I('#X96IE(&]B9'*^970@86MT=>%L;NT@:6YF;W)M86-E(&\@
M)7,N`"5S(&%D<F5SX?@`)7,@:V%L96YDX?@`)7,@>N%P:7-N[6L`)7,@<V5Z
M;F%M(/IK;VSY`"5S.B`E<P`E<SH@)7,@*"5D)FYB<W`[>B9N8G-P.R5D*0`H
M06MT:79O=F%T('IM[&YY(&$@</AE<W5N;W5T('-E(&YA(&1A;+GM('-T<N%N
M:W4N*0`H6G)UN6ET(':Y96-H;GD@>FWL;GD@82!P^&5S=6YO=70@<V4@;F$@
M<W1RX6YK=2P@:V1E('-E('9Y=';A^.T@;F]VX2!Z<'+A=F$N*0`H4/AE<W7R
M('-E(&YA('-T<N%N:W4L(&MD92!S92!V>71VX?CM(&YO=N$@>G!RX79A('!O
M=.D@8V\@<V4@86MT=6%L:7IU:NT@=KEE8VAN>2!D;W-A=F%D;NT@>FWL;GDN
M("!:;>QN>2!N82!S;W7H87-NZ2!S='+A;F-E($Y%0E5$3U4@<&]UOFET>2XI
M`"A0;W-L870@>G!RX79U('!O(&%K=&EV;W;A;NT@=KEE8VAN>2!D;W-A=F%D
M;NUC:"!Z;>QN+B!:;>QN>2!N82!S;W7H87-NZ2!S='+A;F-E($Y%0E5$3U4@
M<&]UOFET>2XI`"H@4/AI9&%T('1Y=&\@:VQI:VYU=.UM(&YA($]+("H`*B!0
M<F]S[6T@=GEB97)T92!E;6%I;&]V;W4HZ2D@861R97-U*'DI("H`+"!NX7)A
M>F]V_2`E<R`E<P`L('!R;VWL;F[A(&]D("5S(&1O("5S`"TM(';]8NQR("TM
M`#$@>G!RX79A(&)Y;&$@;F%H;.&Y96YA(%9AN65M=2!S>7-TZ6UO=NEM=2!A
M9&UI;FES='+A=&]R;W9I(&IA:V\@8VAT[&[A('IP<N%V82`H:&%M*2X`,2!Z
M<'+A=F$@8GEL82!N86ALX;EE;F$@:F%K;R!C:'3L;N$@>G!RX79A("AH86TI
M+@`Q('IP<N%V82!B>6QA(&YA:&SAN65N82!68;EE;74@<WES=.EM;W;I;74@
M861M:6YI<W1RX71O<F]V:2!J86MO(&YE8VAT[&[A('IP<N%V82`H<W!A;2DN
M`#$@>G!RX79A(&)Y;&$@;F%H;.&Y96YA(&IA:V\@;F5C:'3L;N$@>G!RX79A
M("AS<&%M*2X`,3`P('IN86OY`#$P,#`@>FYA:_D`,3(@:&]D:6YO=OT@9F]R
M;>%T`#(T(&AO9&EN;W;](&9O<FWA=``R-"!H;V1I;@`R-3`@>FYA:_D`-3`P
M('IN86OY`%!R;R!T96YT;R!B;&]K(&IE('9YOF%D;W;A;B!D871A8N%Z;W;]
M('ID<F]J+@!6>7-K>71L82!S92!ZX79AOF[A(&-H>6)A`%IP<N%V82!O8G-A
M:'5J92!P^.UL;VAU('9E(&9O<FWL('9E;&OI:&\@;V)RX7IK=2!S(&[A>G9E
M;2`E<RX`5N%M:2!Z87-L86[A('IP<N%V82!B>6QA('!O='9R>F5N82!P^.UJ
M96UC96TN`%!R;R!Z8;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT
M('9E^&5J;OT@4$=0(&ML[>@N`%!R;R!V97)I9FEK86-I('!O9&5P<V%NZ2!Z
M<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@N`%!R;R!D
M9;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0
M(&ML[>@L('!R:7;A=&[M(%!'4"!K;.WH(&$@:&5S;&\N`%!R;R!P;V1E<'/A
M;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+"!P
M<FEVX71N[2!01U`@:VSMZ"!A(&AE<VQO+@!0<F\@9&6Y:69R;W;A;NT@>G!R
MX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEV
MX71N[2!3+TU)344@:VSMZ"!A(&AE<VQO+@!0<F\@<&]D97!SX6[M('IP<N%V
M>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!3+TU)344@:VSMZ"P@<')I=N%T
M;NT@4R]-24U%(&ML[>@@82!H97-L;RX`4')O('IAN6EF<F]VX6[M('IP<N%V
M>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!3+TU)344@:VSMZ"X`4F%N;NT@
M9.FYNP!286YN[2!P^&5HX?)K>0!286YN[2!S;NQH;W;I('#X96CA\FMY`$%-
M+U!-`$$`05!)($E$`$EN9F]R;6%C92!O('1O;71O(&5D:71O<G4`26YF;W)M
M86-E+BXN`%1E>'0@9&]L^2!D;R!O8G+A>FMU`%1E>'0@9&]P<F]S=/AE9"!O
M8G+A>FMU`%#X:6IM;W5T('!OOF%D879E:P!0^&EJ871O`%#X:6IA=&\Z`%9Y
M='9O^&5N[2!61E,@861R87/A^&4@;F5B>6QO('!O=F]L96YO+@!6>71V;_AE
M;NT@5D93('-O=6)O<G4@;F5B>6QO('!O=F]L96YO+@!5OFEV871E;'-KZ2!H
M97-L;P!5OFEV871E;&O](/KH970@8GEL('IA8FQO:V]VX6XN`$[A>F5V(/KH
M='4Z`%6^:79A=&5L:^D@^NAT>0!!:V-E`%9L;[X`4/AI9&%T('!O9'-K=7!I
M;G4`4/AI9&%T('!O9"UP<N%V80!0^&ED870Z`%#X:61A="!N;W9O=2!S:W5P
M:6YU`%#X:61A="!N;W;A('!RX79A`%#X:61A="!N;W;I:&\@=;YI=F%T96QE
M.@!0^&ED870@<VQO=7!E8P!0^&ED870@;F]VZ2#H;&5N>0!0^&ED870@<.%R
M`%#X:61A="!Z9')O:@!0^&ED870@)7,@;65N=2!J86MO(&)OZ&[M('-L;W5P
M96,@36]Z:6QL>0!0^&ED870@='5T;R!P;VQOOFMU(&1O(&MA;&5N9.'X90!0
M^&ED870@9&\@861R97/A^&4Z`%#X:61A="!D;R!MZ6AO(&%D<F5SX?AE`%#X
M:61A="!UOFEV871E;&4`4/AI9&%T("(E<R(@:F%K;R!P^.UL;VAU+@!0^&ED
MX7;A;NT@=;YI=F%T96SY(&IE('IA8FQO:V]VX6YO+@!$86RY[2!I;F9O<FUA
M8V4@;6]H;W4@8OUT('IO8G)A>F5N>2`E<RX`1&%LN>T@:6YF;W)M8>AN[2!D
M971A:6QY`$1A;+GM(&1E=&%I;'D@;R!Z<'+A=NP`1&%LN>T@9&5T86EL>2!O
M('IP<N%V["!M;VAO=2!B_70@>F]B<F%Z96YY("5S+@!$86RY[2!D971A:6QY
M(&\@8VAY8F]VZ6T@:&SAN65N[0!$86RY[2!D971A:6QY(&\@8VAY8F]VZ6T@
M:&SAN65N[2!M;VAO=2!B_70@>F]B<F%Z96YY("5S+@!!9')E<V$`061R97/A
M^`!!9')E<^'X90!6>6MO;N%V870@861M:6YI<W1R86-I("T@;F%S=&%V96[M
M('#X[7-T=7!O=OUC:"!P<N%V('!R;R!O<W1A=&[M('6^:79A=&5L90!!9&UI
M;FES=')A8V4`26YZ97+A='D`069G:.%N:7-TX6X`06QBX6YI90!!;+[M<G-K
M;P!0^&5Z9.UV:V$O06QI87,`6F%R;W9N870`6F%R;W9NX6[M.@!6N64`5KEI
M8VAN:2!O=NSX96[M('6^:79A=&5LZ0!6N65C:&YY('-K=7!I;GD`5KEE8VAN
M82!UOFEV871E;'-KX2!P<N%V80!6N65C:&YY(.AT>?AI('-T<F%N>0!6N65C
M:&YY('IP<N%V>2!V(&[A<VQE9'5J[6/M('-L;[YC92!B=61O=2!P^&5M[7-T
M[&YY(&1O(&IE9&YO:&\@34)/6"!S;W5B;W)U.@!6N65C:&YY('IP<N%V>2!V
M92!68;GM("(E<R(@<VQOOF-E('-T87*Y[2!N9;X@)7,@9&[M(&)U9&]U('1R
M=F%L92!V>6UA>N%N>2X`5KEE8VAN>2!P^.UL;VAY('5L;[YE;ND@:F%K;R!O
M9&MA>BP@:W1E<ND@:G-O=2!S=&%RN>T@;NR^("5S(&WL<^UC^2P@8G5D;W4@
M=GEM87KA;GDN`%:Y96-H;GD@<W1A<ND@<VQOOFMY(',@;V1E<VQA;F]U('!O
MN71O=2!S=&%RN>T@;NR^("5S(&WL<^UC^2!B=61O=2!V>6UA>N%N>2X`1&]V
M;VQI="!P;W6^:73M(&9I;'1R;W9A8^UC:"!P<F%V:61E;"!N82!J86MO=6MO
M;&EV('-C:'+A;FMU/P!0;W9O;&ET(';M8V4@861R97,`4&]V;VQI="!N87-T
M879E;NT@='EP=2!S973X[63L;OT@<V5Z;F%M/P!*:;X@97AI<W1U:F4`06QT
M97)N871I=F[M($E-4U`@</AI:&SAN65N[2!D;R!S>7-TZ6UU`$%L=&5R;F%T
M:79N[2!)35-0(&AE<VQO`$%L=&5R;F%T:79N[2!)35-0('6^:79A=&5L<VOI
M(&IMZ6YO`$%L=&5R;F%T:79N[2!E+6UA:6QO=N$@861R97-A`$%L=&5R;F%T
M:79N[2!V>F]R>0!!;'1E<FYA=&EV;NT@=&5X=#H`06QT97)N871I=F[M(.CA
M<W1I('3I=&\@<V5K8V4Z`%:^9'D`5KYD>2!U;&^^:70@</CM;&]H=2X`06UE
M<FEC:^$@4V%M;V$`3F%S=&%L82!C:'EB82!P^&D@<&]K=7-U(&\@;V1S=')A
M;NQN[2!P^.UL;VAY('IE('IP<N%V>2X@2&SAN65N[2!Z($E-05`@<V5R=F5R
M=3H@`$)Y;&$@>F%DX6YA(&YE<&]V;VQE;N$@:&]D;F]T82X`4/AI('IA:VSA
M9.%N[2!N;W;I:&\@^FMO;'4@9&^Y;&\@:R!N97INX6WI(&-H>6+L+@!!;F1O
M<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6[M('!R;WAY`$]D<&]V[.\`3V1P
M;W;L>F5NZ0!/9'!O=NQZ96[I('IP<N%V>0!!;G1A<FMT:6MA`$%N=&EG=6$@
M82!"87)B=61A`$%P;&EK86-E`%-E>FYA;2!A<&QI:V%C[0!!<&QI:V%C92!J
M92!P^&EP<F%V96YA`%!O=;[M="!F:6QT<GD`4&]UONUT(&9I;'1R>2!N82`E
M<P!0;W6^[70@9FEL=')O=F%C[2!P<F%V:61L82!P^&D@</AI:&SAN65N[2!D
M;R!S>7-TZ6UU/P!0;W6^[70@9FEL=')O=F%C[2!P<F%V:61L82!VOF1Y('#X
M:2!Z;V)R87IE;NT@24Y"3UAU/P!0;W6^[70@<')O(&3L9&GH;ND@<V3M;&5N
M[0!38VAVX6QI=`!0^&EB;&F^;N$@=F5L:6MO<W0`1'5B96X`07)A8G-K>2`H
M5VEN9&]W<RTQ,C4V*0!696QI:V]S="!A<F-H:79O=F%NZ6AO('-O=6)O<G4`
M2FWI;F\@87)C:&EV=0!*<W1E('-I(&II<W3M+""^92!C:&-E=&4@=GEM87IA
M="!T96YT;R!V9?AE:F[](&ML[>@_`$IS=&4@<VD@:FES=.TL(+YE(&-H8V5T
M92!V>6UA>F%T('1E;G1O(&ML[>AO=OT@<.%R/R`H5&]T;R!N96[M(&1O<&]R
M=>AE;F\@<')O=N%D['0A*0!*<W1E('-I(&II<W3M+""^92!T;R!C:&-E=&4@
M=63L;&%T/P!5<NAI=.P@8VAC971E('9Y;6%Z870@ON%D;W-T(&\@</AI:&SA
MN65N[2!D;R`E<S\`2G-T92!S:2!J:7-T[2P@OF4@8VAC971E(%!%4DU!3D5.
M5$[,('-M87IA="!T>71O('IP<N%V>3\`2G-T92!S:2!J:7-T[2P@OF4@<VD@
M8VAC971E(%!%4DU!3D5.5$[,('-M87IA="!T=71O('#X[6QO:'4_`$IS=&4@
M<VD@:FES=.TL(+YE(&-H8V5T92!V>7!RX7ID;FET('1U=&\@<VQOOFMU/P!*
M<W1E('-I(&II<W3M+""^92!C:&-E=&4@=GEP<N%Z9&YI="!S;&^^:W4@:V^Y
M93\`2G-T92!S:2!J:7-T[2P@OF4@8VAC971E(%!%4DU!3D%.5$[,('-M87IA
M="!T>71O('IP<N%V>3\`2G-T92!S:2!J:7-T[2P@OF4@8VAC971E(&YA:&SA
M<VET('1U=&\@>G!RX79U(&IA:V\@8VAT[&YO=2`H:&%M*3\`2G-T92!S:2!J
M:7-T[2P@OF4@8VAC971E(&YA:&SA<VET('1U=&\@>G!RX79U(&IA:V\@;F5C
M:'3L;F]U("AS<&%M*3\`07)G96YT:6YA`$%R;>EN:64`07)MZ6YS:_T@*$%2
M35-#24DM."D`R&%S(&1O<G7H96[M`%5M[&[M`$%R=6)A`%9Z97-T=7!N[`!!
M<V-E;G-I;VX@27-L86YD`$%S8VEI('5M[&[M`$%S:64O<F5G:6]N(%1I8VCI
M:&\@;V-EX6YU`%IE<'1A="!S90!0;[[A9&%T(&\@<&]T=G)Z96[M('#X960@
M<')O=F5D96[M;2!O<&5R86/M(/ID<KYB>3\`4VQO=7!C92!S(/IK;VQY`%#X
M:6QOOFET`%#X:6QOOFET('-O=6)O<GD`4/AI;&^^:70@:V]P:6D@5F&Y96AO
M(%!'4"!K;.WH92!K('IA<VQA;ND@>G!RX7;L/P!0^&EL;[YI="!S;W5B;W(`
M4/AI;&^^96[I('-O=6)O<GD@(B5S(B!P^&5S86AU:NT@<&]V;VQE;OT@;&EM
M:70@<')O('9E;&EK;W-T('#X[6QO:"X@4V]U8F]R($Y%0EE,('#X:6QOOF5N
M+@!0^&EL;[YE;F$@:F4@;V1P;W;L[R!68;GM(+[A9&]S=&D@>B!K86QE;F3A
M^&4N`%#X[6QO:&$`4/CM;&]H82!O9'-T<F%N[&YA.B!/<FEG;N%L;NT@='EP
M('#X[6QO:'D`4/CM;&]H>0!0;VMU<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC
M[2!S:W5P:6YY+@!0;VMU<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC[6-H('6^
M:79A=&5L<VO]8V@@<'+A=BX`4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J[6/M
M8V@@=;YI=F%T96QS:_UC:"!P<N%V+@!0;VMU<R!O(/IP<F%V=2!N965X:7-T
M=6KM8^UH;R!S9.UL96[I:&\@;V)J96MT=2X`VNAA<W1N[6-I`%!O>F]R`$%T
M<FEB=71Y`%-R<&5N`$%U<W1RX6QI90!286MO=7-K;P!!=71H7V-Y<G-Q;#H@
M3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:6UA<"X`
M075T:%]C>7)U<SH@6F1R;VH@;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN
M`$%U=&A?8WER=7,Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O
M;F$@<')O(&EM87`N`$%U=&A?9G1P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O
M=F%NX2!P^.UP;VYA('!R;R!F='`N($MO;7!I;'5J=&4@4$A0(',@+2UE;F%B
M;&4M9G1P`$%U=&A?:6UA<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@
M</CM<&]N82!P<F\@24U!4"X`075T:%]I;7`Z($YE8GEL82!N86QE>F5N82!P
M;[YA9&]V86[A('#X[7!O;F$@<')O($E-05`N`$%U=&A?:W)B-3H@3F5B>6QA
M(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:W)B-2X`075T:%]L
M9&%P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!,
M1$%0`$%U=&A?;&1A<#H@3F5L>F4@</AI9&%T('6^:79A=&5L92`E<RX@2&SA
MN65N[2!S97)V97)U.B``075T:%]L9&%P.B!.96QZ92!V>6UA>F%T('6^:79A
M=&5L92`E<P!!=71H7VQD87`Z($YE;'IE(&%K='5A;&EZ;W9A="!UOFEV871E
M;&4@)7,`075T:%]M8V%L.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P
M^.UP;VYA('!R;R!-0T%,+@!!=71H7W-M8F%U=&@Z($YE8GEL82!N86QE>F5N
M82!P;[YA9&]V86[A('#X[7!O;F$@<')O('-M8F%U=&@N`$]V[/AE;NT@<V5L
M:&%L;P!/=NSX96[M('-E;&AA;&\N("5S`$]V[/AE;NT@8GEL;R!Z86WM=&YU
M=&\@4D%$2553('-E<G9E<F5M+@!396QH86QO(&]V[/AE;NT@1E10('-E=F5R
M96TN`$%U=&]M871I8VMY('IO8G)A>FET(&]B<N%Z:WD@=B!(5$U,('IP<N%V
MX6-H+"!P;VMU9"!J92!O9&5S[6QA=&5L('8@;>EM(&%D<F5SX?AI/P!$;W-T
M=7!NZ2!A9')E<^'X93H`1&]S='5P;N$@<&]L93H`3^AE:^%V86[A(&]D<&]V
M[.\`07IE<F)A:F2^X6X`0D]&2"!V_6UL=79Y`%IP[%]T(&1O("5S`%IP['0@
M9&\@)7,`4&]Z863M`$)A<G9A('!O>F%D[0"I<&%T;ND@:&5S;&\@<')O(&ME
M<F)E<F]S+@"I<&%T;ND@=;YI=F%T96QS:^D@:FWI;F\@<')O(&ME<F)E<F]S
M+@!"86AA;7D`0F%H<F%I;@!"86QT:6-KZ2`H25-/+3@X-3DM,3,I`$)A;F=L
M863IN0!"87)B861O<P!:X6ML860`4VMR>73A($MO<&EE`$+L;&]R=7-K;P!"
M96QG:64`0F5L:7H`3NV^92!J92!U=F5D96YA(&1O<VQO=F[A(&EN9F]R;6'H
M;NT@>G!RX79A(&\@<W1A=G4N`$)E;FEN`$)E<FUU9'D`0FCZ=.%N`$YA<F]Z
M96YI;GD`R&5R;N$@;&ES=&EN80!.96QZ92!N86SI>G0@Z.%S="`B)7,B(&%P
M;&EK86-E("(E<R(N`$YA<W1A=F5N[2!B;&]K=0!4>7`@8FQO:W4`0FQO:V]V
M870@;V)RX7IK>2!V($A434P@>G!RX7;A8V@L('!O:W5D(&YE:G-O=2!J:6YA
M:R"^X63A;GD_`%3L;&\`5'7H;NP`0F]L[79I90!:X6QOOFMY`$]K<F%J`*GM
M^&MA(&]K<F%J93H`3VMR86IE`$)O<VYA(&$@2&5R8V5G;W9I;F$`3V)A`$]B
M;VKM("T@<V5Z;F%M(&AL879IZ&5K(&$@=.QL('IP<N%V`$)O='-W86YA`$1O
M;&[M(.CA<W0`0F]U=F5T($ES;&%N9`!"<F%Z[6QI90!"<FET<VOA('1E<FET
M;W)I82!V($EN9&EC:^EM(&]C9>%N[`!"<G5N96D@1&%R=7-S86QA;0!"=6QH
M87)S:V\`4V5Z;F%M(',@;V1RX;YK86UI`$)U<FMI;F$@1F%S;P!"=7)U;F1A
M`$--4P!#4D,`0U),(&1I<W1R:6)UZ&[M(&)O9'D`5FQA<W1N;W-T:2!B7W7R
M:WDN+BX`6E]N86MO=N$@4V%D80!+86QE;F3A^`!"97IV['3X[0!+86UB;V2^
M80!+86UE<G5N`$YE;'IE('-E('#X:7!O:FET(&ME('9Z9.%L96[I;74@<&^Y
M=&]V;NUM=2!S97)V97)U`$YE;'IE('-E('#X:7!O:FET(&ME('9Z9.%L96[I
M;74@<&^Y=&]V;NUM=2!S97)V97)U.B``3F5L>F4@>F]B<F%Z:70@+2!B>6QO
M(&YA;&5Z96YO('!O=7IE("5S(.CA<W3M('H@)7,@<')O('1U=&\@>G!RX79U
M('8@<V]UZ&%S;ND@<V-H<N%N8V4N`$AE<VQO(&YE;'IE(&YA<W1A=FET(&%U
M=&]M871I8VMY+"!P<F]S[6T@:V]N=&%K='5J=&4@5F&Y96AO('-Y<W3I;6]V
MZ6AO(&%D;6EN:7-T<N%T;W)A+@!.96QZ92!S92!P^&EP;VII="!K($E-05`@
M<V5R=F5R=3H@)7,`2V%N861A`%IR=;EI=`!:<G6Y:70@>G!RX79U`%-T;W)N
M;R!H;.&Y96[M('!R;V)LZ6UU`%IR=;EE;NT@=.ET;R!Z<'+A=GD@8G5D92!M
M[70@>F$@;N%S;&5D96L@:V]M<&QE=&[M('IT<N%T=2!J96KM:&\@;V)S86AU
M+@!.96QZ92!V>6UA>F%T('-O=6)O<B`B)7,B+@!.96QZ92!N86KM="!D;^AA
M<V[](&%D<F5SX?@N`$YE;'IE('!O:W)AZ&]V870@8F5Z('!A<F%M971R=2`G
M=&%R9V5T1FEL92<N`$YE;'IE('9Y;6%Z870@861R97/A^"`B)7,B+@!.96QZ
M92!V>6UA>F%T+"!P<F]T;[YE(&5X:7-T=6KM('!O9'-K=7!I;GD@)60N`$YE
M;'IE('!R;W;I<W0@>FWL;G4@=7-P;_CA9.%N[2P@<&_H970@<&]S:WET;G5T
M_6-H('!O;&^^96L@<')O(&YO=ND@=7-P;_CA9.%N[2!N96]D<&]V[63A('!O
MZ'1U('5L;[YE;OUC:"!P;VQOOF5K+@!.96QZ92!Z87-L870@>G!RX79U(&YA
M('IA9&%NZ2#H[7-L;RX@`$-A<&4@5F5R9&4`5&ET=6QK>0!+871E9V]R:64@
M82!Z;F'H:WD`2V%J;6%N<VOI(&]S=')O=GD`2V]P:64`36]B:6QN[2!T96QE
M9F]N`$UOOFYO<W1I(&)U\FMY`$]D<W1U<"!M97II(&)U\FMA;6DZ`%9L87-T
M;F]S=&D@8G7R:WD`365Z97)Y(&UE>FD@8G7R:V%M:3H`36]B:6QN[2!T96QE
M9F]N`$ME;'1S:_T@*$E33RTX.#4Y+3$T*0!3=/AE9`!3=/AE9&]A9G)I8VOA
M(')E<'5B;&EK80!3=/AE9&]E=G)O<'-K_2`H25-/+3@X-3DM,BD`4&]D<F]B
M;F]S=&D@8V5R=&EF:6OA='4`4&]D;>UN:WD@8V5R=&EF:6OA='4`R&%D`%#X
M961S961A:NUC[0!:;>QN:70`6FWL;FET(':Y90!:;>QN:70@<VQOOFMU`$YA
M<W1A=F5N[2!V;&%S=&YO<W3M('IO8G)A>F5N[2!J86MO(&YA</@N(&MO;&EK
M('IP<N%V(&)U9&4@;F$@:F5D;ND@<W1RX6YC92!A(&IA:R!B=61O=2!U<W!O
M^.%DX6YY+@!.87-T879E;NT@5F&Y96AO('!ON71O=F[M:&\@<V5R=F5R=2!A
M('-L;[YE:RX`3F%S=&%V96[M(&IMZ6YA(&$@96UA:6QO=ND@861R97-Y+B!4
M>71O('!O;&^^:WD@;&EDZ2!U=FED[2P@:V1YOB!S:2#H=&]U(&YE8F\@;V1P
M;W;M9&%J[2!N82!68;EE('IP<N%V>2X`3F%S=&%V96[M(&IMZ6YA+"!E;6%I
M;&]VZ2!A9')E<WD@82!S:6=N871U<GDL(&MT97+I('9I9.T@</CM:F5M8VD@
M5F&Y:6-H('IP<N%V+@!:;F%K`%IN86MY('!R;R!Z;V)R87IE;NTZ`%IK;VYT
M7W)O;&]V870@;V1K87HN+BX`6FMO;G1R;VQO=F%T(&YO=F]U('!ON71U('9E
M('-L;[YC92AS;&^^:^%C:"D`6FMO;G1R;VQO=F%T(%]VN64OON%D;ND`6FMO
M;G1R;VQO=F%T(':Y96-H;GD@<&^Y=&]V;NT@<V5R=F5R>2!K92!S=&&^96[M
M(&YO=ND@<&^Y='DZ`%IK;VYT<F]L;W9A="!P<F%V;W!I<R!P^&5D(&]D97-L
MX6[M;2!Z<'+A=GD_`$-H:6QE`,CM;F$`R.UNN71I;F$@>FIE9&YO9'6Y96[A
M("A'0C(S,3(I`%1R861IZ&[M(.CM;KET:6YA("A":6<U*0!6>6)R870@86MC
M:3H`5GEB<F%T('!ON71O=F[M('-E<G9E<CH`6G9O;'1E(&AE<VQO`%IV;VQT
M92!UOFEV871E;'-KZ2!J;>EN;P!6>6)R870@86MC:3H`5GEB<F%T('IO8G)A
M>F5N[2!D871U;74Z`%9Y8G)A="!T>7`@<W1Y;'4@<V5Z;F%M=2`H<')O(/AA
M>F5NZ2!S97IN86UY*0!6>6)R870@861R97/A^"P@:W1E<OT@8G5D92!P;W6^
M:70@</AI('IA9.%VX6[M(&%D<F5S+@!6>6)R870@<&_X863M(&%D<F5SX?CY
M+"!V(&IA:^EM(&)U9&]U('!R;VAL963A=N%N>2!P^&D@97AP86YD;W;A;NT@
M861R97,N`%;A;F_H;NT@;W-T<F]V`$YE8GEL82!N86QE>F5N82!D969I;FEC
M92!T^.UD>2`E<RX`5GGH:7-T:70`5GGH:7-T:70@>FYAZ&MY('H@35-/9F9I
M8V4`3V1S=')A;NQN[2!UOFEV871E;&4Z("5S`$]D<W1R86YI="!UOFEV871E
M;&4`3V1S=')A;NQN[2#Z9&%J^2!O('6^:79A=&5L:0!+;&EK;NQT92!N82`E
M<R!P<F\@:V]N=F5R>FD@;V)RX7IK;W;I:&\@<V]U8F]R=2!N82!T>7`L(&MT
M97+](&QZ92!Z;V)R87II="X`2VQI:V[L=&4@;F$@)7,@:R!S=&&^96[M(&]B
M<N%Z:W4N`$ML:6MN['1E(&YA("5S('!R;R!P^&5C:&]D(&YA("5S('-T<N%N
M:W4@<R!M86YA9V5M96YT96TN`$ML:6MN['1E(&YA("5S('!R;R!Z;V)R87IE
M;NT@2%1-3"!O8G-A:'4@=B!N;W;I;2!O:V[L+@!+;&EK;NQT92!N82`E<R!P
M<F\@>F]B<F%Z96[M(&UI;FEA='5R>2!T;VAO=&\@;V)RX7IK=0!+;&EK;NQT
M92!N82`E<R!P<F\@>F]B<F%Z96[M('#X[6QO:'D@=B!N;W;I;2!O:V[L+@!+
M;&EK;NQT92!N82`E<R!P<F\@>F]B<F%Z96[M('-O=79I<V5J[6/M(.CA<W1I
M('8@;F]VZ6T@;VMN["X`2VQI:V[L=&4@>F1E('!R;R!:3T)205I%3LT@;V)R
MX7IK^0!+;&EK;NQT92!N82!J961E;B!Z(%9AN6EC:"!A9')E<^'X^2!A('9Y
M8F5R=&4@=KEE8VAN82!P;VQE+"!K=&5RX2!S92!B=61O=2!P<F]H;&5DX79A
M="X`2VQI:V[L=&4@<')O('!O:W)AZ&]VX6[M`$ML:6MN=73M;2!U;&^^[71E
M(%!'4"!V9?AE:F[](&ML[>@@9&\@<W;I:&\@861R97/A^&4`2VQI:VYU=.UM
M('5L;[[M=&4@4R]-24U%(&-E<G1I9FEKX70@)7,@9&\@<W;I:&\@861R97/A
M^&4`0VQI8VMA=&5L;"!P^&5S($A45%``2VQI:VYU=.UM(&YA(&%D<F5S=2!L
M>F4@=GET=F_X:70@;F]V;W4@>G!RX79U('!R;R!O9&5S[6QA=&5L90!+;&EK
M;G5T[6T@;F$@861R97-U(&QZ92!Z;V)R87II="!Z<'+A=G4@:R!P^&7H=&5N
M[0!5>F%V^.UT`%IA=OCM="!O:VYO`%5Z87;X[70@=&]T;R!O:VYO`%5Z87;X
M[70@<VQOOFMU`%IA=&&^96YO`$]B;&'H;F\`2V]K;W-O=ND@;W-T<F]V>0!3
M:VQA<&YO=70`4VML87!N;W5T(':Y90!3:VQA<&YO=70@=KEE8VAN>2!S;&^^
M:WD`4VML87!N;W5T('-L;[YK=0!3:VQA<&YO=70@8F_H;NT@;&FY='4`4VML
M87!N;W5T(&]K<F%J90!+;VQU;6)I90!"87)V80!);F1I:^%T;W(@8F%R978Z
M(`!6_6+L<B!B87)E=@!086QE=&$@8F%R978`4VQO=7!C93H`3N%Z=GD@<VQO
M=7!C90!+;VUI:W-Y`%#X[6MA>@!0^.UK87IO=N$@:V]N>F]L80!0;WINX6UK
M80!/8F5C;ND@:FWI;F\`2V]M;W)O<P!&:7)M80!$;VMO;NAE;F\`5GET=F_X
M:70@9&%LN>T@>G!RX79U`%9Y='9O^&ET('IP<N%V>2!V(&YO=NEM(&]K;NP_
M`$EM<&QI8VET;NP@=GET=N'X970@>G!RX79Y('8@2%1-3"!'54D@*'!O9'!O
M<G5J92UL:2!P<F]H;.V^9>@@='5T;R!V;VQB=2D_`%!OZ.UT8>AE`%!O9&WM
M;FMY`%)O>F3M;'D@=B!N87-T879E;NT`3F%S=&%V:70@)7,`3F%S=&%V96[M
M('IO8G)A>F5N[2!Z<'+A=BX`3F%S=&%V:70@;6^^;F]S=&D@<')O(&[A:&QE
M9"!Z<'+A=BX`4&]T=G)D:70@:&5S;&\`2V]N9V\`2V]N9V\L($1E;6]K<F%T
M:6-KX2!R97!U8FQI:V$`4W!O:F5N[2!S96QH86QO+@!3<&]J96[M('-E;&AA
M;&\Z(`!">6QO('IA;>UT;G5T;R!S<&]J96[M(',@=F7X96IN_6T@:VSMZ&]V
M_6T@<V5R=F5R96TN`$)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE:F[]
M;2!K;.WH;W;];2!S97)V97)E;2X@1/EV;V0@.B`E<R`H)7,I`%-E;&AA;&\@
M<W!O:F5N[2!S($944"!S97)V97)E;2X`4W!O:F5N[2!S92!S97)V97)E;2!S
M96QH86QO`$MO;G1A:W1Y(&)Y;'D@^G-P[+EN["!P^&EDX6YY(&1O(%9AN65H
M;R!A9')E<^'X92X`4&]K<F'H;W9A=`!.87-T879E;NT@<&]D<&]R>2!01U`@
M=B`E<RX`3F%S=&%V96[M('!O9'!O<GD@4R]-24U%('8@)7,N`$YA<W1A=F5N
M[2!K;VYT<F]L>2!N;W;L('#X[6-H;WKM8V@@>G!RX78@82!Z</ES;V)U(&EN
M9F]R;6]VX6[M(&\@:F5J:6-H('#X[6-H;V1U+@!+;VYV97)T;W9A="!I:V]N
M:WD@<R!E;6]C96UI('H@=&5X='4@9&\@9W)A9FEK>3\`0V]O:V]V>2!O<W1R
M;W9Y`$MO;.'H96L`2V]P[7)O=F%T`$MO<.UR;W9A="!V_6+L<@!+;W#M<F]V
M870@9&\@<VQOOFMY`%5P<F%V:70`57!R879E;OT@=&5X=`!+;W-T87)I:V$`
M4&]B^&6^[2!S;&]N;W9I;GD`6G!RX79U(&YE;'IE(+EI9G)O=F%T('!O;6]C
M[2!01U`N`%IP<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@4$=0+@!:<'+A
M=G4@;F5L>F4@N6EF<F]V870@<&]M;V/M(%,O34E-12X`6G!RX79U(&YE;'IE
M('!O9&5P<V%T('!O;6]C[2!3+TU)344N`$YE;'IE('#X:61A="!K;VYT86MT
M+B`E<P!.96QZ92!S92!P^&EP;VII="!K($Q$05`@<V5R=F5R=2X`3F5L>F4@
M>FMO;G1R;VQO=F%T(/KH970N("5S`$YE;'IE('9Y='9O^&ET(&1I<W1R:6)U
MZ&[M('-E>FYA;2X@)7,`3F5L>F4@=GET=F_X:70@5D93(&)A8VME;F0Z("5S
M`$YE;'IE(&1EN6EF<F]V870@4$=0(&1A=&$N`$YE;'IE(&1EN6EF<F]V870@
M4R]-24U%(&1A=&$N`$YE;'IE('-M87IA="!K;VYT86MT+B`E<P!.96QZ92!S
M;6%Z870@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!V>6UA>F%T('IP
M<N%V>2!Z("5S+B!4;W1O(&IE(&ALX;EE;NT@>F4@<V5R=F5R=3H@)7,`3F5L
M>F4@>FII<W1I="!E+6UA:6QO=F]U(&%D<F5S=2!P^.UJ96UC92X`3F5L>F4@
M<')O=NES="!O<&5R86-E(/ID<KYB>2X`3F5L>F4@>NUS:V%T('!OOF%D;W9A
M;OT@<V]U8F]R('H@</CM;&]H>2!T>7!U($U3+51.148N`$YE;'IE('KM<VMA
M="!P;[YA9&]V86[]('-O=6)O<B!Z('#X[6QO:'D@='EP=2!::7`N`$YE;'IE
M('KM<VMA="#Z<&QN_2!A9')E<^'X+@!.96QZ92!Z[7-K870@^G!L;OT@9&ES
M=')I8G7H;NT@<V5Z;F%M+@!.96QZ92!Z[7-K870@^G!L;OT@<V5Z;F%M(&1I
M<W1R:6)UZ&[M8V@@<V5Z;F%M^2X`3F5L>F4@>NUS:V%T('9E^&5J;OT@:VSM
MZ"!Z(&ML[>AO=NEH;R!S97)V97)U+@!.96QZ92!O=&5V^.UT("5S+@!.96QZ
M92!P<F]VZ7-T(&]P97)A8V4@^F1ROF)Y('!R;R!M;V1U;"`E<P!.96QZ92#H
M[7-T("5S+@!.96QZ92!R97-E=&]V870@:&5S;&\@<')O(&1A;NEH;R!UOFEV
M871E;&4N(%:Y96-H;GD@;F5B;R!N[&MT97+I('H@<&]D<F]B;F]S=.T@;F5B
M>6QY('-P<N%V;NP@>F%DX6YY+B!::W5S=&4@=&\@>FYO=G4@;F5B;R!P;VMU
M9"!P;W3X96)U:F5T92!P;VUO8RP@:V]N=&%K='5J=&4@<W!RX79C92!S>7-T
MZ6UU+@!.96QZ92!Z[7-K870@04-,`$YE;'IE('KM<VMA="!A9')E<^'X+B`E
M<P!.96QZ92!Z[7-K870@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!Z
M[7-K870@9&ES=')I8G7H;NT@<V5Z;F%M>2X@)7,`3F5L>F4@>NUS:V%T('-C
M:&]P;F]S=&D@<V5R=F5R=0!.96QZ92!P^&5P;F]U="!K;VYF:6=U<F%C:2X`
M3F5L>F4@=6QOOFET(&MO;F9I9W5R86-I('!R;R`E<RX`3F5L>F4@=6QOOFET
M('KA;&^^;NT@:V]N9FEG=7)A8VDN`$YE;'IE('5L;[YI="!ZX6QO:'4@:V]N
M9FEG=7)AZ&[M:&\@<V]U8F]R=2`E<RX`3F5L>F4@:&QE9&%T('8@3$1!4"!S
M97)V97)U+@!.96QZ92!A:W1U86QI>F]V870@:V]N=&%K="X@)7,`3F5L>F4@
M86MT=6%L:7IO=F%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,`3F5L>F4@;F%L
MZ7IT(&)OZ&[M(&QIN71U('!R;R!-;WII;&QU+B!0<F]S[6T@</AE<W;L9.AT
M92!S92P@OF4@:F4@;W1E=OAE;N$N`$]D<&_H[71A;OT@=&5X=`!:96WL`%9Y
M=>AO=F%C[2!P^&5D;>QT>0!6>71V;_AI=`!6>71V;_AI="!S;&^^:W4`5GET
M=F_X:70@:VSMZ&4`5GET=F_X:70@=FER='7A;&[M('-L;[YK=0!6>71V;_AI
M="!O9&MA>@!6>71V;_AI="!N;W9O=2!S;&^^:W4@<')O(')O>F5P<V%NZ2!Z
M<'+A=GD`5GET=F_X:70@;F]V;W4`5GET=F_X:70@;F]V;W4@<VQOOFMU('!R
M;R!O9&5S;&%NZ2!Z<'+A=GD`5GET=F_X:70@;F]V;W4@<VQOOFMU('!R;R!K
M;[D`1FEL=')O=F%C[2!P<F%V:61L82!P<F\@;W)G86YI>F]VX6[M('#X[6-H
M;WKM8V@@>G!RX78L(&IE:FEC:"!T^.UD[&[M(&1O('-L;[YE:R!A(&UA>N%N
M[2!N96-H=.QN_6-H('IP<N%V("AS<&%M*2X`5GET=F_X:70@<&]D<VQOOFMY
M`%1V^7)C92!P<N%V`,CM<VQO(&MR961I=&[M(&MA<G1Y`$-H;W)V871S:V\`
M2W5B80!!:W1UX6QN[2#H87,`06MT=>%L;NT@55),(&IE`$%K='7A;&[M('!O
MZ&%S[0!3;W7H87-N_2!P^.US='5P(&1O("5S`$%K='7A;&[M('!O9&WM;FMY
M.B``3GEN[&JY[2!S='EL`$YA<W1A=FET(/KH='D@<')O('-T86AO=N%N[2!Z
M<'+A=B!Z(&1A;+GM8V@@<&^Y=&]V;NUC:"#ZZ'3Y+@!.87-T879E;NT@>G#Y
M<V]B=2!O9&5S[6SA;NT@>G!RX78N`$YA<W1A=F5N[2#Z:V]L^2!P<F]VX63L
M;OUC:"!P^&D@</AI:&SAN65N[2!D;R!M;V1U;'4@)7,N`%9Y<W3X:6AN;W5T
M`%9Y<W3X:6AN;W5T(';]8NQR`$MY<'(`07IB=6MA("A+3TDX+5(I`$%Z8G5K
M82`H5VEN9&]W<RTQ,C4Q*0!!>F)U:V$O56MR86II;F$@*$M/23@M52D`R&5S
M:^$@<F5P=6)L:6MA`$1$`$1E;F[L`$1A='5?;0!$871A5')E92!P<F]H;.V^
M9>@`1&%T=6T`4/AI:F%T;R!D;F4`5OUB['(@9&%T=6UU`$1E;@!3;6%?>F%T
M('-L;W5P96,`4')O<VEN96,`R.US;&$@9&5S[71K;W;I('-O=7-T879Y`%IA
M;>UT;G5T`%IA;>UT;G5T.B``6FUE;KEI="!O9'-A>F5N[0!);7!L:6-I=&[M
M(&)A<G9A`$EM<&QI8VET;NT@:61E;G1I=&$`5OUC:&]Z[2!T^.UD[6/M(&MR
M:73I<FEA.@!6_6-H;WKM('-M['(@=/CM9.QN[3H`1&5F:6YI8V4`4/AI9.QL
M96YO`%-M87IA=`!3;6%Z870@)7,@=F7X96IN_2!K;.WH`%-M87IA="!S;W7H
M87-N_2!K;.WH`%-M87IA="!S;&^^:W4H>2D`4VUA>F%T('-K=7!I;G4`4VUA
M>F%T('!RX79A`%-M87IA="!V:7)T=>%L;NT@<VQOOFMU`%-M87IA="!A('9Y
MZ&ES=&ET('IP<N%V>0!3;6%Z870@8G7R:W4`4VUA>F%T('-L;W5P96,`4VUA
M>F%T(&5X:7-T=6KM8^T@86QT97)N871I=F[M('9Z;W(`4VUA>F%T('-T8;YE
M;ND@>G!RX79Y('IE('9Z9.%L96[I:&\@<V5R=F5R=3\`4VUA>F%T('H@;>EH
M;R!K86QE;F3A^&4`4VUA>F%T('-T87+I('#X[6QO:'D@=6QOOF5NZ2!J86MO
M(&]D:V%Z(&YA('IAZ.%T:W4@;>QS[6-E/P!3;6%Z870@<W1A<ND@<V-H<N%N
M:WD@<R!O9&5S;&%N;W4@<&^Y=&]U(&YA('IAZ.%T:W4@;>QS[6-E/P!3;6%Z
M870@^.%D96L`4VUA>F%T('9Y8G)A;F]U*.DI(&ED96YT:71U*'DI`%-M87IA
M="!S;W7H87-N_2!S;&]U<&5C`%-M87IA="!S;W7H87-N_2#XX61E:P!3;6%Z
MX6YO`%-M87IA;ND@>G!RX79Y`%-M87IA;N$@</CM;&]H82`B)7,B+@!3;6%Z
MX6[M(&$@</AE<V]U=N%N[2!Z<'+A=@#(87,@9&]R=>AE;NT`1.%N<VMO`%IA
M;>UT;F]U="!P;[YA9&%V96L`6F%M[71N;W5T('!OOF%D879E:R!N82!I;F9O
M<FUA8VD@;R!F<F5E+V)U<WD`4V5S='5P;NP`4&]P<V%T('!R;V)LZ6T`4&]P
M:7,`1&5T86EL>0!0;V1R;V)N;W-T:2`H=&%KZ2!V(&QO9R!S;W5B;W)U($AO
M<F1E*3H`4&]D<F]B;F]S=&D@8GEL>2!Z87IN86UE;N%N>2!D;R!L;V<@<V]U
M8F]R=2!P<F\@861M:6YI<W1RX71O<F$N`%;]=F]J`%)O<V[](&)O9`!2;W-N
M_2!B;V0@>F$@<&]S;&5D;NT@:&]D:6YU.B``4F]S;OT@8F]D.B``6F%S=.UN
M:70@<VEG;F%T=7)Y/P!3;>QR('H@;&5V82!D;W!R879A`%-M['(@>B!P<F%V
M82!D;VQE=F$`061R97/A^`!:;V)R87II=`!:;V)R87II="`R-"UH;V1I;F]V
M_2#H87,_`$UOOFYO<W1I('IO8G)A>F5N[0!:;V)R87II="!P;W1V<GIE;NT@
M;R!O9&5S;.%N[2!Z<'+A=GD_`%IO8G)A>FET('#X961P;W;L[R`H5$%&*0!&
M;W)MX70@>F]B<F%Z96[M`%IO8G)A>FET('8@=.QL92!Z<'+A=GD`6F]B<F%Z
M:70@=7!O>F]R;NQN[2!O(&YO=ND@>G!RX7;L/P!$:7-P;WII8V4`1&ES<&]Z
M:>AN[2!U<&]Z;W)N[&[M`$1J:6)O=71I`$Y%4TA/1%5*S2!S90!.96MO;G1R
M;VQO=F%T('-L;[YK=2AY*2!N82!N;W;I('IP<N%V>0!.97-M87IA=`!.97#X
M:7-T=7!O=F%T('#X[6UO(&1O(&UA:6YT96YA;F-E+G!H<`!.979Y=';A^&5T
M(&]D:V%Z>2!V92!S;&]U<&-I($]D.@!#:&-E=&4@;W1E=OCM="!T=71O('-L
M;[YK=3\`3V)S86AU:F4@<')V;NT@^.%D96L@;N%Z978@<VQO=7!C^3\@4&]K
M=60@86YO+"!Z8;EK<G1N['1E('1E;G1O('+A;67H96LZ`$1O;6EN:6MA`$1O
M;6EN:6OA;G-KX2!R97!U8FQI:V$`1&]K;V[H96YO`%-T8;YE;NT`4W1AOF5N
M[2`E<P!3=&%H;F]U="`E<R!V("YZ:7`@9F]R;>%T=0!3=&%H;W9A="!VN65C
M:&YY('#X[6QO:'D@*'8@+GII<"!S;W5B;W)U*0!3=&%H;F]U="!S;&^^:W4H
M>2D`4W1A:&]V870@<VQOOFMU*'DI(%MV("YZ:7`@9F]R;>%T=5T`4W1A:&YO
M=70@9V5N97)O=F%N;W4@:V]N9FEG=7)A8VD@:F%K;R!02%`@<VMR:7!T+@!3
M=&%H;W9A="!V("YZ:7`@9F]R;>%T=0!2;WIE<'-A;N$@>G!RX79A`%-L;[YK
M82!P<F\@<F]Z97!S86[I('IP<N%V>0!3;&^^:V$@<')O(')O>F5P<V%NZ2!Z
M<'+A=GDZ`%)O;&5T;W;]('-E>FYA;0!$<F]G>0!%+6UA:6P`12UM86EL;W;A
M(&%D<F5S80!%4E(`0TA90D$Z(%9AN>T@>G!RX79U(&YE;'IE(&1O<G7H:70N
M`$5K=N%D;W(`57!R879I=`!5<')A=FET(.AE<FYO=2!L:7-T:6YU`%5P<F%V
M:70@8FQO:P!5<')A=FET(&9I;'1R;W9A8^T@<')A=FED;&$`57!R879I="!S
M:W5P:6YU`%5P<F%V:70@<'+A=F$`57!R879I="!P<N%V80!5<')A=FET('!R
MX79A('!R;R`E<P!5<')A=FET('9I<G1UX6QN[2!S;&^^:W4`57!R879I="!D
M969I;FEC:2!V:7)T=>%L;NT@<VQOOFMY('!R;R`E<P!5<')A=FET(&+M;&]U
M(&QI<W1I;G4`57!R879I="!M;[YN;W-T:2!P<F\Z`%5P<F%V:70@<'+A=F$@
M<')O("5S`%5P<F%V:70@Z&5R;F]U(&QI<W1I;G4`57!R879I="!P<F%V:61L
M82!F:6QT<F]VX6[M`%5P<F%V:70@;F%S=&%V96[M('!R;R!P^.US='5P(&L@
M:FEN_6T@<&^Y=&]V;NUM(/KH=/EM+@!5<')A=FET(&+M;&]U(&QI<W1I;G4`
M5OUU:V$`16=Y<'0`16P@4V%L=F%D;W(`4')V96LN+BX`16T`16UA:6P`16UA
M:6QO=N$@861R97-A`$5M86EL;W;I(&%D<F5S>2!S92!M=7/M('-H;V1O=F%T
M+@!%;6%I;"!S('!O='9R>F5N[6T`26MO;FMY(',@96UO8V5M:0!6>7!RX7ID
M;FET(':Y96-H;GD@>G!RX79Y(&]D("5S`%9Y<'+A>F1N:70@<VQOOFMU*'DI
M`%9Y<'+A>F1I="!S;&^^:W4@:V^Y90!6>7!RX7ID:70@7VMON0!0<N%Z9&[A
M('IP<N%V82X`4'+A>F1N_2!V_7-L961E:RX`4'+A>F1N_2!T97)M[6X@<')O
M('9Y:&QE9.%VX6[M`%IA<&YO=70@4$=0/P!:87!N;W5T(%,O34E-13\`4&]V
M;VQI="!V:VSA9.%N[2!O8G)A>FOY('H@9F]T;R!G86QE<FGM(&1O('1E>'1U
M/P!5;6^^;FET(&[A:&QE9'D@>G!RX78_`$%K=&EV;W9A="!P<F%VZ2!K;&EK
M;G5T[2!P<F\@:V]N=&5X=&]VZ2!M96YU/P!-;[YN;W-T:2"Y:69R;U]VX6[M
M`$MO;F5C`$MO;F5C('#X97!O<VQA;ND@>G!RX79Y`$MO;F5C('IP<N%V>0!+
M;VYE8R!Z<'+A=GD@;V0@)7,`2V]N96,@<F]K=0!:=NQTN6ET(&5D:71O<@!:
M861E:G1E(&AE<VQO`%IA9&5J=&4@8F5Z<&7H;F]S=&[M(&]TX7IK=2P@;F$@
M:W1E<F]U(&)U9&5T92!M=7-E="!O9'!O=NQD['0@<&]K=60@<VD@8G5D971E
M(&-H=.UT(')E<V5T;W9A="!S=ND@:&5S;&\L(&YA</@N("=*86OI(&IE(&IM
MZ6YO(%9AN65H;R!P<V$_)SH`6F1E('9L;[YI="!54DP@;V)RX7IK=0!6;&^^
M=&4@:FWI;F\@;F]VZ2!S;&^^:WD@<')O(')O>F5P<V%NZ2!Z<'+A=GD`5FQO
MOG1E(&IMZ6YO(&YO=ND@<VQOOFMY('!R;R!O9&5S;&%NZ2!Z<'+A=GD`5FQO
MOG1E(&IMZ6YO(&YO=ND@<VQOOFMY('!R;R!K;[D`4&]L;[YK82`B)7,B(&)Y
M;&$@^G-P[+EN["!P^&EDX6YA(&1O(&%D<F5SX?AE`%)O=F[M:V]VX2!'=6EN
M96$`17)I=')E80!#:'EB80!.87-T86QA(&-H>6)A('#X:2!O9&5S[6SA;NT@
M;V1P;W;L9&DZ("5S+@!.87-T86QA(&-H>6)A(',@<&^Y=&]V;NT@>G!RX79O
M=2X`17-T;VYS:V\`171I;W!I90!%=&YI8VOI`$5V<F]P80!59.%L;W-T(&)Y
M;&$@^G-P[+EN["!S;6%ZX6YA+@!+8;YD_6-H(#$U(&UI;G5T`$MAOF3I(#(@
M;6EN=71Y`$MAOF3]8V@@,S`@<V5K=6YD`$MAOF3]8V@@-2!M:6YU=`!+8;YD
MZ2!P^&EH;.&Y96[M(&1O('-Y<W3I;74`2V&^9&]U('#Y;"!H;V1I;G4`2V&^
M9&]U(&UI;G5T=0!6>F]R;W;]('#X[6ML860@:&]D;F]T.@!0<F]VZ7-T`%)O
M>F)A;&ET`%)O>F)A;&ET(':Y90!2;WIB86QI="!VN65C:&YY('-L;[YK>0!2
M;WIB86QI="!S;&^^:W4`1&]P;/(@:FWI;F$`4F]Z8F%L:70@8F_H;NT@;&FY
M='4`075T;VUA=&EC:WD@9&]P;&YI="!J;>EN82!P^&D@=GET=N'X96[M('IP
M<N%V>3\`26UP;&EC:71N["!R;WIB86QO=F%T(&-E;&]U('-T<G5K='5R=2!S
M;&^^96L@</AI(&IE:FEC:"!Z;V)R87IE;NT_`%)O>F)A;'5J:0!/Z&5KX7;A
M;F$@)RDG`$_H96OA=N%N;R!S86UO<W1A=&[I('-L;W9O(&YE8F\@:&QE9&%N
M_2!T97)M[6X@=B!U=F]Z;W9KX6-H`$1A='5M('!R;R!K;VYE8R!P;&%T;F]S
M=&D`17AP;VYE;G0`0F%R=F$@<&]P^&5D[0!0^&5N;W,@:V]N9FEG=7)A8V4@
M<&]M;V/M($944`!396QH86QO('KM<VOA;NT@;6^^;F]S=.TN`$YE;'IE('-E
M('#X:7!O:FET(&L@3$1!4"!S97)V97)U+@!.96QZ92!S92!P^&EP;VII="!K
M(%--0B!S97)V97)U+@!396QH86QO(&MO<.UR;W;A;NT@>B`B)7,B+@!396QH
M86QO(&MO<.UR;W;A;NT@9&\@(B5S(BX`4V5L:&%L;R!Z86QOOF5N[2!N;W;I
M:&\@4T%33"!S<&]J96[M+@!396QH86QO('#X97-U;G5T[2!D;R`B)7,B+@!$
M;V)RZ0!&86QK;&%N9'-KZ2!O<W1R;W9Y("A-86QV:6YY*0!&87)I:G-KZ2!O
M<W1R;W9Y`%KA=F&^;N$@8VAY8F$Z`$9A>`#:;F]R`$/M=&ET('-E(&IA:V\`
M0^UT:70@<V4@:F%K;SH`4W3A:&YO=70@<&^Y='4`4W1A:&]V870@<&^Y='4@
M=B!N;W;I;2!O:V[L/P!3=&%H;W9A="!P;[ET=2!P^&D@</AI:&SAN65N[2!D
M;R!S>7-TZ6UU/P!3=&&^96[A('!ON71A.@!3=&&^96[A('!ON71A.B"^X61N
MZ2!N;W;I('IP<N%V>2X`1')O8F[I('#X96CA\FMY`$1R;V)NZ2!S;NQH;W;I
M('#X96CA\FMY`$9I7VQT<GD`36%T:6-E('!O;&4`1FEJ:0!3;W5B;W(`4&_H
M970@<V]U8F]R^3H@)7,@<V]U8F]R`%!OZ&5T('-O=6)O<ODZ("5S('-O=6)O
M<OD`4W!RX79C92!S;W5B;W+Y`$[A>F5V('-O=6)O<G4`5OUB['(@<V]U8F]R
M=0!0^&5NZ7-T('-O=6)O<@!0^&5N;W,@<V]U8F]R^2!N96[M('!O9'!O<F]V
MX6XN`$UOOFYO<W1I(&9I;'1R^0!.87-T879E;NT@9FEL='+Y`$]D9FEL=')O
M=F%T(&YE=FAO9&[A('-L;W9A('IE('IP<N%V/P!496YT;R!S>7-TZ6T@;F5U
M;6^^\G5J92!F:6QT<F]VX6[M+@!&:6QT<GD`1FEL=')Y($Y%2E-/52!A:W1I
M=F]VX6YY`$9I;'1R>3H@)7,@<W1RX6YK82!M86YA9V5M96YT=0!6>6AL961A
M=`!&:6YS:V\`4')V;NT@<&]L;W9I;F$`4')V;NT@<W1RX6YK82!S8VARX6YK
M>0!0<G9N[2!S='+A;FMA`%!R=F[M(.AT=G)T:6YA`%!E=F[I(&WL^.UT:V\`
M4/AE:&]D:70`4&QO=F]U8^T`4/A?97!O<VQA=`!-;&AA`%-L;[YK82`E<R!N
M965X:7-T=6IE`$YA=FEGX71O<B!S;&^^96L`4VAR;G5T[2!S;&^^96L`4V3M
M;&5N[2!S;&^^96L@;F5N[2!P;W9O;&5N;RX`4&]UOFET[2!S;&^^96L@;F5N
M[2!P;W9O;&5N;RX`0F%R=F$@<.US;6$`2NUD;&\`4')O('!R;VAL[;YEZ&4@
M;F5P;V1P;W)U:NUC[2!O8G+A>FMY`%#X961P;W;L[R`H5$%&*0!0^&5D<&]V
M[.\@<&_H87/M('!R;R!D;GD@*'!O>F[A;6MA.B!P^&5D<&]V[.\@:F4@<')O
M(&1N>2!I(&YO8VD[('1O=&\@;?F^92!V>71V;_AI="!P;VWL<F[L(&]B<^%H
M;/T@<V5Z;F%M+@!:87!O;6[L;&D@:G-T92!68;EE(&AE<VQO/P!&;W)MX70@
M9&%T=6UU('8@>F]B<F%Z96[M('-C:'+A;FMY('!R;R!D;F6Y;NT@</CM8VAO
M>NT@>G!RX79Y`$9O<FUU;.'X90"I=.QS=.T`5'EP(+ET['-T[0"I=.QS=.T`
MJ73L<W3M(#(`1O-R80!0^&5P;W-L870`4/AE<&]S;&%T.@!0^&5P;W-L86[A
M('IP<N%V80!0^&5P;W-L86[A('IP<N%V82!O9"`E<P!0^&5P;W-LX6[M`%#A
M`%+A;7D`1G)A;F-I90!&<F%N8VEE+"!M971R;W!O;&ET;NT`26YF;W)M86-E
M(&\@1G)E92]"=7-Y`$9R964O0G5S>2!O9'!O=NSO`$9R964O0G5S>2"^X61O
M<W0`1G)E92]"=7-Y(&]D<&]V[.\@;F$@ON%D;W-T`$9R86YC;W5S:^$@1W5A
M:>%N80!&<F%N8V]U<VOA(%!O;'ENZ7-I90!&<F%N8V]U<VOA(&IIOF[M('1E
M<FET;W)I80!/7V0`3V0`061R97-A($]D`$]D`%!O9')O8F[]('!O<&ES`-IP
M;&[L:P!#96SI(&IMZ6YO`%#X97`Z`%#X97`Z(`!0^&5P.B`E=2!P^&5P;W-L
M86[]8V@@>G!RX78`1V%B;VX`1V%L97)I92!P<F\@=OUB['(@;V)RX7IK^0!'
M86QE<FEE.@!'86UB:64`5KEE;V)E8V[I(&UOOFYO<W1I`%9Y='9O^&ET("5S
M(&MO;F9I9W5R86-I`%9Y9V5N97)O=F%N_2!K\V0`1W)U>NUN<VMO`$[L;65C
M:V\`6NUS:V%T(&IE;B!N;W;I('IP<N%V>3\@*'!O=7IE('4@24U!4'4I`$=H
M86YA`$=I8G)A;'1A<@!+^&5S=&[M(&IMZ6YO`$KM="!N82!Z<'+A=G4`1V]E
M9&5L`%9Y:&QE9.%VX6[M('!O;6]C[2!';V]G;'4`4&]V;VQI="!P^.US='5P
M`%-T=7!N[""Y961I`-AE8VMO`-AE8VOI("A)4T\M.#@U.2TW*0!'<O-N<VMO
M`$=R96YA9&$`061M:6YI<W1R86-E('!R;R!S:W5P:6YY`$UU<^T@8OUT('IA
M9.%N;R!J;>EN;R!S:W5P:6YY`%-K=7!I;GD`1W5A9&5L;W5P90!'=6%M`$=U
M871E;6%L80!'=65R;G-E>0!0<N%V82!H;W-T^0!+;FEH82!H;W-T^0!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`6D1%`$A434P`2%1-3"!V97)Z92!Z
M<'+A=GD`2%1-3$%R96$@>F)A8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M
M(&)U\FMU(&YA(/CA9&MU+@!(5$U,07)E82!Z8F%B[&QE(&]D;>UTX2!S;6%Z
M870@<&]S;&5D;NT@8G7R:W4@=F4@<VQO=7!C:2!T86)U;&MY+@!(5$U,07)E
M82!Z8F%B[&QE(&]D;>UTX2!S;6%Z870@<&]S;&5D;NT@^.%D96L@=B!T86)U
M;&-E+@!/=NSX;W;A;NT@<&]M;V/M($A45%`@;F5B>6QO(&YA;&5Z96YO+@!(
M86ET:0!(87-H+6%L9V]R:71M=7,`36QH879O`$AL879IZ&MA`$AL879IZ&MY
M`$AE87)D($ES;&%N9"!A($UC1&]N86QD($ES;&%N9',`2&5B<F5JN71I;F$@
M*$E33RTX.#4Y+3@M22D`5OVY:V$`3N%P;W;L9&$`3N%P;W;L9&$@<')O(&5D
M:71O<@!0;VUO8V[M:P!(96UI<V;I<F$`6F1E(&IE('IAZ.%T96L@<V]U8F]R
M=3H`5&]T;R!J92!Z<'+A=F$L(&MT97)O=2!J<W1E(&YA<'-A;&DZ`%5K<GET
M_0!5:W)Y=/T@=B!Z;V)R87IE;NT@<&]D;&4@<V]U=FES;&]S=&D`56MR_70@
M<VUA>F%NZ0!5:W+]="!N96%K=&EV;NT`5GES;VOA`%9Y<V]KX2!D^6QEOFET
M;W-T`$YE:G9YN>T`7TAO<F1E`%-V873I($WL<W1O("A6871I:^%N*0!(;W)D
M90!!9')E<V$@9&]M^0!496QE9F]N(&1O;?D`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<F1E+TMO;&%B.B!.97!L871NZ2`E<R!834P@9&%T82!V92!Z
M<'+A=NP@)7,`2&]R9&4O2V]L86(Z(*[A9&[A('IP<N%V82!S92!N97-H;V1U
M:F4@<R!O8FIE:W1E;2`E<P!(;W)D92]+;VQA8CH@3F5B>6P@;F%L97IE;B"^
MX61N_2!O8FIE:W0@='EP=2`E<R!V92!Z<'+A=NP@)7,`2&]R9&4O2V]L86(Z
M(-IS<.RY;ND@;V1S=')A;NQN[2`E<R`B)7,B`$AO<F1E+TMO;&%B.B!);G1E
M9W)AZ&[M(&[A<W1R;VH@<&]T^&5B=6IE(%!(4"!P^.UP;VYU("=D;VUX;6PG
M`$AO<F1E+TMO;&%B.B!.96QZ92!V>71V;_AI="!N;W;]('-T<F]M(%A-3"!P
M<F\@;V)J96MT("5S`$AO<F1E+TMO;&%B.B!.96QZ92!O9'-T<F%N:70@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YE;'IE('KM<VMA="!-24U%($E$('!R
M;R#HX7-T('1Y<'4@)7,`2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO
M=F%T("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.96QZ92!S>6YC:')O;FEZ
M;W9A="!S9.UL96[I(&]B:F5K='DZ("5S`$AO<F1E+TMO;&%B.B!.97INX6W]
M('-D[6QE;OT@;V)J96MT("(E<R(`5F]D;W)O=F[I('!R87;M=&MO`$AO<FEZ
M;VYTX6QN[2!O9'-T=7``2&]R:7IO;G3A;&[M.@!*86L@:G-T92!S92!S96T@
M9&]S=&%L:3\@*%IAN6QE=&4@<')O<^UM('IP<N%V=2$I`$IA:R!S:2!P^&5J
M971E('IO8G)A>FET('#X[6QO:'D_`$MO;&EK('-L;W5P8_D@8VAC971E('-P
M;VII=#\`2V]L:6L@:F4@=&%M('!O;.T@*'-L;W5P8_DI/P!+;VQI:R#XX61K
M^2!C:&-E=&4@<W!O:FET/P!*86L@;WIN8>AI="!C:71A8V4@=B!O9'!O=NQD
M[6-H`%9L:&MO<W0`5FQH:V]S=#H`2'5M;W)NZ0!-8>]A<G-K;P!)34%0`$E-
M05`@*$%U=&]M871I8VOA(&1E=&5K8V4@<')O=&]K;VQU*0!396QH86QO('9Y
M='9O^&5N[2!)34%0;W;I('-C:'+A;FMY.B`E<P!396QH86QO('-M87KA;NT@
M24U!4&]VZ2!S8VARX6YK>3H@)7,`4V5L:&%L;R!N87-T879E;NT@:W;S='D@
M<')O($E-05!O=F]U('-C:'+A;FMU.B`E<P!)34%0('#X97,@4U-,`$E-05`@
M</AE<R!34TP@*',@;F5O9FEC:>%L;NUM(&-E<G1I9FEKX71E;2D`24U!4"!P
M^&5S(%-33"`H<R!N96]F:6-IX6QN[6T@8V5R=&EF:6OA=&5M*0!)34%0+"!B
M97H@5$Q3`$E-05`O4$]0,R!P;[ET;W9N[2!S97)V97)Y`$E.0D]8`$E0(&%D
M<F5S80!)4"!A9')E<V$@;F5N[2!D;W-T=7!NX2X`25`@861R97-A(&YE;NT@
M=B!P;W9O;&5NZ6T@0TE$4B!R;WIS86AU+@!0;W)UN65N[2!I;G1E9W)I='D@
M25`N`%9?;&^^=&4@^.%D96L@</AE9`!)<VQA;F0`4&]U>F4@:6MO;GD`26MO
M;GD@<')O("5S`$EK;VYY(',@=&5X=&5M`$[A>F5V(&ED96YT:71Y.@!0;VMU
M9"!Z;V)R87IE;NT@;F5N[2!V('!O^.%D:W4L("5S(&]T97;X[70@=B!N;W;I
M;2!O:V[L+@!0;VMU9"!P;W6^[7;A=&4@26YT97)N970@17AP;&]R97(@82!N
M979I9.UT92"^X61NZ2!I:V]N>2P@>OAE:FWL('!O=/AE8G5J971E(&]Z;F'H
M:70@=&5N=&\@<N%M9>AE:R!P<F\@=GEP;G5T[2!03D<@=')A;G-P87)E;F-E
M+@!0;VMU9"!V:63M=&4@='5T;R!Z<'+A=G4@;>US=&\@;V)RX7IK=2P@;V)R
MX7IE:R!K=&5R_2!C:&-E=&4@</AE;NES="!N96QZ92!68;GM;2!P<F]H;.V^
M9>AE;2!Z;V)R87II="X`26=N;W)O=F%T`$EG;F]R;W9A="!VN64`3N%H;&5D
M(&]B<N%Z:W4Z`%523"!O8G+A>FMU`%523"!O8G+A>FMU.@!/8G+A>F5K('H@
M9V%L97)I90!/8G+A>F5K('H@9V%L97)I93H`4/AE;F]S(&]B<N%Z:W4`3V)R
MX7IK>0!);7!O<G1O=F%T`$EM<&]R=&]V870@:VSMZ`!);7!O<G1O=F%T(&ML
M[>AO=OT@<.%R`$EM<&]R=&]V870@>G!RX79Y`$EM<&]R=&]V870@4$=0(&ML
M[>@`26UP;W)T;W9A="!6X;D@;W-O8F[M('!R:7;A=&[M(%!'4"!K;.WH`$EM
M<&]R=&]V870@5N&Y(&]S;V)N[2!V9?AE:F[](%!'4"!K;.WH`$EM<&]R=&]V
M870@5N&Y(&]S;V)N[2!3+TU)344@8V5R=&EF:6OA=`!);7!O<G1O=F%T('9E
M^&5J;OT@:VSMZ`!);7!O<G1O=F%T('9E^&5J;OT@4$=0(&ML[>@`26UP;W)T
M;W9A="!6X;D@=F7X96IN_2!3+TU)344@:VSMZ`!);7!O<G1O=F%T(%,O34E-
M12!K;.WH`$EM<&]R=&]V870@;6)O>"!S;W5B;W(`26UP;W)T;W9A="!M8F]X
M('-O=6)O<B`E<R!D;R!S;&^^:WD@)7,N`$EM<&]R="P@:W)O:R`E9`!$^6QE
MOFETZ0!$^6QEOFETZ2!Z<'+A=GD`26UP;W)T;W;A;F\@)60@>G!RX78H82D@
M;V0@)7,N`$EM<&]R=&]V86[I('!O;&4Z("5S`$EM<&]R=&]V86[A('!O;&4Z
M`%8@<')O8V5S=0!6;&^^:70@^.%D:W4@>F$`24Y"3U@`6F%H<FYO=70@<W1R
M=>ANZ2!S:')N=73M(&AL879IZ&5K(&1O(%9AN>T@;V1P;W;L9&D_`%IA:')N
M;W5T('#Y=F]D;NT@>G!RX79U(&1O(%9AN>T@;V1P;W;L9&D_`$)Y;"!Z863A
M;B!N97-P<N%V;OT@86OH;NT@:_-D+@!.97-P<N%V;NP@>F%D86[I('6^:79A
M=&5L<VOI(&IMZ6YO(&$O;F5B;R!H97-L;RX`3F5S<'+A=F[I('6^:79A=&5L
M<VOI(&IMZ6YO(&YE8F\@86QT97)N871I=F[M(&%D<F5S82X@6FMU<W1E(&IE
MN73L(&IE9&YO=2!N96)O(&MO;G1A:W1U:G1E(%9AN65H;R!S>7-TZ6UO=NEH
M;R!A9&UI;FES='+A=&]R82X`6G;L=+EI="!O9'-A>F5N[0!);F1I90!*961N
M;W1L:7;M('6^:79A=&5LZ0!);F1O;NES:64`26YF;W)M86-E`$EN9F]R;6%C
M90!);F9O<FUA8V4@;R`E<R!V9?AE:F[I;2!K;.WH:0!);F9O<FUA8V4@;R!6
M8;EE;2!O<V]B;NUM('!R:7;A=&[M;2!K;.WH:0!);F9O<FUA8V4@;R!68;EE
M;2!O<V]B;NUM('9E^&5J;NEM(&ML[>AI`%5V;FET^`!6;&^^:70@<U]L;W5P
M96,@>F$`6F1E('9L;[YI="!C97)T:69I:^%T`%9L;[YI="!O8G+A>F5K`%ID
M92!V;&^^:70@5N&Y(&]S;V)N[2!P<FEVX71N[2!01U`@:VSMZ`!:9&4@=FQO
MOFET(%;AN2!O<V]B;NT@=F7X96IN_2!01U`@:VSMZ`!:9&4@=FQOOFET('9E
M^&5J;OT@4$=0(&ML[>@`5FQOOFET('1A8G5L:W4`5FQOOFET('=E8F]V_2!O
M9&MA>@!6;&^^:70@7W-L;W5P96,@</AE9"``5FQOOFET(&YO=OT@<VQO=7!E
M8R!Z82!S;W7H87-N_0!6;&^^:70@;F]V_2!S;&]U<&5C('#X960@<V]UZ&%S
M;OT`5FQOOFET(&YO=OT@^.%D96L@>F$@<V]UZ&%S;OT`5FQOOFET(&YO=OT@
M^.%D96L@</AE9"!S;W7H87-N_0!6;&^^:70@;V1S=&%V96,@>F$@<V]UZ&%S
M;OT@=7IE;`!6;&^^:70@;V1S=&%V96,@</AE9"!S;W7H87-N_2!U>F5L`%9L
M;[YI="!A;'1E<FYA=&EV;NT@=GIO<@!6;&^^=&4@96UA:6QO=F]U(&%D<F5S
M=2P@;F$@:W1E<F]U(&]B9'*^[71E(&YO=ND@:&5S;&\Z`%9L;[YI="!B=?)K
M=2!Z80!6;&^^:70@8G7R:W4@</AE9`!6;&^^:70@<VQO=7!E8R!Z80!6;&^^
M:70@<VQO=7!E8R!P^&5D`%9L;[YI="!Z<'+A=GD`5FQOOFET(&]D<W1A=F5C
M('IA`%9L;[YI="!O9'-T879E8R!P^&5D`%9L;[YI="#XX61E:R!Z80!6;&^^
M:70@^.%D96L@</AE9`!6;&^^=&4@<&^^861O=F%N;W4@;V1P;W;L[R!N82!B
M97IP9>AN;W-T;NT@;W3A>FMU.@!6;&^^:70O=7!R879I="!O8G+A>F5K`%9L
M;[YI="]U<')A=FET(&]D:V%Z`$YE9&]S=&%T9>AN_2!K<F5D:70@:R!O9&5S
M;.%N[2!Z<'+A=GD@;F$@9&ES=')I8G7H;NT@<V5Z;F%M+@!.961O<W1A=&7H
M;OT@:W)E9&ET+@!#96SI(.CM<VQO`%-E>FYA;2!C96S]8V@@Z.US96P`0GEL
M82!V>6)RX6YA(&YE<W!RX79NX2!A:V-E('!R;R!T=71O(&MO;7!O;F5N='4N
M`$YE<&QA=&[A(&%D<F5S80!.97!L871NX2!V>F3A;&5NX2!S8VARX6YK80!.
M97-P<N%V;ND@541(+B`H57-E<B!$871A($AE861E<BDN`$YE<&QA=&[A(&%P
M;&EK86-E+@!.97!L871NZ2!I9&5N=&EF:6MAZ&[M(.CM<VQO("A)1"D@9.%V
M:WDN`$YE<&QA=&[]('IN86L@=B!E+6UA:6QO=ND@861R97-E.B`E<RX`0GEL
M82!Z863A;F$@;F5P;&%T;N$@9&%T80!.97!L871NX2!A9')E<V$@</CM:F5M
M8V4N`$YE<&QA=&[](&9O<FWA="!S;W5B;W)U`$YE<&QA=&[](&ML[>@`3F5P
M;&%T;OT@;7-G7W1Y<&4N`$YE<&QA=&[I(&YE8F\@8VAY8NQJ[6/M(&%P:5]I
M9"X`3F5P;&%T;ND@;F5B;R!C:'EB[&KM8^T@<&%R86UE=')Y+@!.97!L871N
MX2!V;&%S=&YI8VOA('!RX79A+@!6X;D@;W-O8F[M('!R:7;A=&[M(%!'4"!K
M;.WH(&IE(&YE<&QA=&[]+@!6X;D@;W-O8F[M('9E^&5J;OT@4$=0(&ML[>@@
M:F4@;F5P;&%T;OTN`$YE<&QA=&[]('!R;W1O:V]L+@!.97!L871N_2!S9.UL
M96[](&]B:F5K=`!.97!L871NX2!A9')E<V$@;V1E<^UL871E;&4N`$YE<&QA
M=&[A(&1A=&$@=6YI8V]D92X`26YV96YTX?@`3V)RX71I=`#-<N%N+"!)<VSA
M;7-KX2!R97!U8FQI:V$`27+A:P!)<G-K;P!/<W1R;W8@;76^90!/:F5D:6[L
M;.D@8F]U^&MY`$ES<F%E;`!0;W-K>71O=F%T96P`2W5R>NUV80!)=.%L:64`
M2F%M86IK80!,961E;@!*87!O;G-K;P!*87!O;KET:6YA("A)4T\M,C`R,BU*
M4"D`5')I:V]T`$IO<F3A;G-K;P#(97)V96YE8P#(97)V96X`6F%R;W9N870`
M6F%R;W9N870@;F$@<W3X960`6F%R;W9N870@=GEP;&[L;NUM`%IA<F]V;F%T
M(&1O;&5V80!:87)O=FYA="!D;W!R879A`$M"`$MA>F%C:'-TX6X`56-H;W9A
M="!O<FEG:6[A;#\`2V7R80!+97)B97)O<R!S97)V97(@>F%M[71N=6P@;W;L
M^&5N[2X`3F]VX>AC:2!K97)N96QU`%9Y='9O^&5N[2!K;.WH90!6>71V;_AE
M;NT@;W1I<VMU(&ML[>AE`$3I;&MA(&ML[>AE`%1Y<"!K;.WH90!5OFET[2!K
M;.WH90!+;.WH(&IIOB!E>&ES='5J92!N82!V9?AE:F[I;2!K;.WH;W;I;2!S
M97)V97)U+@!+;.WH(&)Y;"#Z<W#LN6[L(&]D97-LX6X@;F$@=F7X96IN_2!K
M;.WH;W;]('-E<G9E<BX`1.QT:0!+:7)I8F%T:0!+3$12`$MO<F5A`$MO<F5J
M<VMY("A%54,M2U(I`$MU=F%J=`!+>7)G:7IS=.%N`%]2;WIL;[YE;NT`2F%Z
M>6L`3&%O<RP@3&ED;W;L($1E;6]K<F%T:6-K82!297!U8FQI:V$`1')U:.$@
M<&]L;W9I;F$`4&]S;&5D;NT@<W1RX6YK82!S8VARX6YK>0!0;W-L961N[2!S
M='+A;FMA`%!O<VQE9&[M(.AT=G)T:6YA`%!O<VQE9&[M(&%K='5A;&EZ86-E
M.@!0;W-L961N[2!P^&EH;.&Y96[M.B`E<P!0;W-L961N[2!P^&EH;.&Y96[M
M.B`E<R!Z("5S`%!O<VQE9&[M('#X:6ALX;EE;NTZ($YI:V1Y`$QI='9A`%!R
MX79O`%)O>FQOOF5N[0!.96-H870@<'+A>F1NZ2!B97H@;VMR86IE`$QI8F%N
M;VX`1&]L979A`$QE=N$@:&QA=FGH:V$`2&]D;F]T>2!N86QE=F\`3&5S;W1H
M;P!,:5]N:V]V86[I('#X[6QO:'D`3&EBZ7)I90!,:6)I90!,:6-H=&5NN71E
M:FYS:V\`3&5H:^D@;7)H;VQE;NT`3&5H:_T@9.FYNP!"<GIK_2!L96AK_2!D
MZ;F[`%!O>F3L:FD@;&5H:_T@9.FYNP!,96AKZ2!D9;F[;W;I('-RX;YK>0!,
M96AK_2!DZ;F[(',@:/AM[&[M;0!,96AKZ2!S;NR^96[M`$QE:&OI('-N[&AO
M=ND@</AE:.'R:WD`3&EM97)I8VL`3V1K87H`3V1K87IY('5K87IU:NT@;F$Z
M`%!O=;[M="!O9&MA>GD@;F$@96UA:6QO=ND@861R97-Y('#X:2!Z;V)R87IO
M=N%N[2!S='+A;FMY('!R;R!P<V%N[2!Z<'+A=@!0^.UL;VAY('5L;[YE;ND@
M:F%K;R!O9&MA>GD@;F5J<V]U('!O=F]L96YY+@!/9&MA>GD`3V1K87IY(&)U
M9&]U(&5X<&ER;W9A="!V("5S`$QI;G5X;W;I(&-O;VMI90!397IN86T@+2!U
MOFEV871E;"!M^;YE('9I9.QT('-L;[YK=0!397IN86T@9&%T86+A>NT`4V5Z
M;F%M('3I;6%T(&[A<&]V[&1Y`%-E>FYA;2!T86)U;&5K`%IO8G)A>FET('-E
M>FYA;2!VN65C:"!K;VYT86MT^2!P^&D@<')O:&SMOF5N[2!K;VYT86MT^3\@
M*'!O:W5D(&YE;FD@86MT:79O=N%N;RP@=79I9.UT92!P;W5Z92!K;VYT86MT
M>2P@:W1E<ND@:G-T92!Z861A;&D@<')O('9Y:&QE9.%VX6[M*0!397IN86TM
M07)C:&EV`%-E>FYA;2U.X7!O=NQD80!397IN86TM260`4V5Z;F%M+59L87-T
M;NUK`%-E>FYA;2U/9&5S;.%N[0!397IN86TM4/AI:&SAN65N[0!397IN86TM
M3V1H;.&Y96[M`%;]<&ES('8@:&QA=FGH8V4`5OUP:7,@=;YI=F%T96SY(&YE
M;NT@9&]S='5P;OTN`$QI=&5R871U<F$`3&]T>;ES:V\`3F%H<N%VX6[M+BXN
M`$QO:^%L;NT@<V-H<N%N:V$@<&^Y='D`3>US=&[M(.AA<SH@`$QO8V%L92!A
M(.AA<P!-[7-T;P!0^&EH;.%S:70@<V4`4/AI:&SA<VET('-E(&1O("5S`$]D
M:&SAN65N[0!0^&EH;.%S:70@<V4`VFMO;'D@<')O=N%D[&[I('#X:2!P^&EH
M;.&Y96[M`%-E;&AA;&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU+B!0<F%V9.QP
M;V1O8F[L(%9AN64@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO(&YE
M8GEL;R!S<'+A=F[L('IA9.%N;RX`4/AI:&SAN65N[2!S96QH86QO+@!$;&]U
M:/T@=&5X=`!,X7-K80!.[7IKX0!.[7IKX2!D^6QEOFET;W-T`$UA;.$@^&5C
M:^$@<.US;65N80!-86SA('1I<VMA8^T@<.US;65N80!-86SI(/CM;7-KZ2#H
M[7-L:6-E`$YE:FYIOKGM`$QU8V5M8G5R<VMO`$U-`%IP<N%V82!D;F4`4/AI
M<&]J96[]('-O=6)O<B!-4RU.5$5&(&YE;V)S86AU:F4@ON%D;N$@9&%T82X`
M35-'`$UA:V%O`$UA:V5D;VYI92P@8OUV86SA(%)E<'5B;&EK82!*=6=O<VSA
M=FEE`%-O=6)O<B!P;V-HX7KM('H@36%C:6YT;W-H90!-861A9V%S:V%R`$UA
M9VEE`%!ON71A`$%D;6EN:7-T<N%T;W(@<&^Y='D`3N%H;&5D>2!P;[ET>0!4
M>7`@<&^Y=&]V;NUH;R!S97)V97)U('!R;R!P^&EP;VIE;NTZ`%-C:'+A;FMA
M`$UOOFYO<W1I('IO8G)A>F5N[2!S8VARX6YE:R!A('-L;[YE:P!6>71V;_AI
M="!O9%]K87HN+BX`36%L87=I`$UA;&%J<VEE`$UA;&1I=GD`36%L:0!-86QT
M80!0<F\@=6UOOF[L;NT@;W9LX63A;NT@:V%T96=O<FGM(&IE('IA<&]T^&5B
M[2!O>FYAZ&ET('!O;&^^:WD@8F%R=F%M:2P@:W1E<ND@:G-O=2!P^&GX87IE
M;GD@:R!T[&UT;R!K871E9V]R:>UM+@!-87!A($UA<#(T`$UA<&$@36%P475E
M<W0`0OAE>F5N`$]K<F%J`$]Z;F'H:70@=KEE8VAN>2!Z<'+A=GD@=F4@<VQO
MOF-E(&IA:V\@<')O:&SI9&YU=.D`3WIN8>AI="!VN65C:&YY('IP<N%V>2!V
M92!S;&^^8V4@:F%K;R!N97!R;VALZ61N=73I`$]Z;F'H:70@:F%K;SH`3WIN
M8>AI="!R^7INZ2#Z<F]V;NP@8VETX73Y('+Y>F[];6D@8F%R=F%M:3\`3WIN
M8>AI="!Z<'+A=GD@:F%K;R!P<F]H;.ED;G5TZ3\@*'!O=7IE($E-05`I`$]Z
M;F'H:70@:F5D;F]D=6-H;W4@>FYAZ&MO=3\`3WIN8>AI="!Z;F'H:V]U(%!R
M;VALZ61N=71O+TYE<')O:&SI9&YU=&\`3WIN8>AI="!J:6[];6D@>FYAZ&MA
M;6D@*&IA:V\@1/EL9;YI=.DO3V1P;W;L>F5NZ2D`36%RN6%L<VOI($]S=')O
M=GD`36%R=&EN:7%U90!:86-H>71I="!VN65C:&YY(&1O=&%Z>0!:86-H>71I
M="!J86O]:V]L:78@9&]T87H`4VAO9'5J[6/M('-E('!O;&4`36%U<F5TX6YI
M90!-875R:6-I=7,`36%X:6UA;&[M('!O=F]L96[](&MR961I=`!">6QA('#X
M96MR;^AE;F$@;6%X:6UA;&[M(&3I;&MA('IP<N%V>2X`3F5J=GFYN>T@=&5P
M;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``3F5J=GFYN>T@=&5P;&]T
M82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!-87AI;>%L;NT@=F5L:6MO<W0@
M</CM;&]H>0!-87AI;>%L;NT@9.EL:V$`0GEL(&1O<V&^96X@;6%X:6WA;&[M
M('!OZ&5T('#X[6QO:"X`0GEL82!D;W-AOF5N82!M87AI;>%L;NT@=F5L:6MO
M<W0@</CM;&]H+@!+=NQT96X`36%Y;W1T90!-961I8^UN80!:<G6Y96[M('-C
M:/EZ90!);F9O<FUA8V4@;R!S8VCY>FD`3N%V<F@@;F$@<V-H^7II`$]D<&]V
M[.\@;F$@<V-H^7II`$%K='5A;&EZ86-E('-C:/EZ90!0;[YA9&%V96L@;F$@
M86MT=6%L:7IA8VD@<V-H^7IE`,AL96YO=ND`365N=2!P<F\@<V5Z;F%M('-L
M;[YE:P!-\V1Y('!R;R!M96YU.@!3<&]J:70@8G7R:WD`6G!RX79A`%9Y='9O
M^&ET('IP<N%V=0!$871U;2!Z<'+A=GD`36^^;F]S=&D@>G!RX78`5GEH;&5D
M870@>G!RX79U`%9E;&EK;W-T('IP<N%V>0!:9')O:F]V_2!K\V0@>G!RX79Y
M`%IP<N%V82!B>6QA(&]V[/AE;F$@=B!P;_CA9&MU+"!A;&4@;F5L>F4@;W;L
M^&ET('!O9'!I<V]V_2!C97)T:69I:^%T+@!:;V)R87IE;NT@>G!RX79Y`%IP
M<N%V82!P<F]P861L82X`5'EP('IP<N%V>0!3;&^^:WD@<')O('IP<N%V=0!:
M<'+A=F$@;V0@)7,`6G!RX79A('-E('-H;V1U:F4`6G!RX79A(&)Y;&$@^G-P
M[+EN["!P^&5S;>QR;W;A;F$N`%IP<N%V82!B>6QA(/IS<.RY;NP@;V1E<VSA
M;F$L(&%L92!N96)Y;&$@=6QOOF5N82!D;R`E<P!:<'+A=F$@8GEL82#Z<W#L
MN6[L(&]D97-LX6YA+@!4>7`@>G!RX79Y`%IP<N%V(&YA('-T<N%N:W4@=B!Z
M;V)R87IE;NT@<V-H<N%N:WDN`%IP<N%V>2!D;P!0;^AA<^T`0FQO:R!O('!O
MZ&%S[2!N96[M(&1O<W1U<&[]+@!";&]K(&\@<&_H87/M(&YE;NT@9&]S='5P
M;OTN(%!O9')O8FYO<W1I(&)Y;'D@>F%Z;F%M96[A;GD@<')O('-Y<W3I;6]V
MZ6AO(&%D;6EN:7-T<N%T;W)A(&1O(&QO9W4N`$UE=&]D80!-971R:6-K_0!-
M97AI:V\`36EK<F]NZ7-I92P@1F5D97)A8V4`57!R;W-T^&5D`%1Y<"!-:6UE
M`$YE:FYIOKGM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`R-"!H;V1I;CH@`$YE
M:FYIOKGM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`V(&AO9&EN.B``6G)C861L
M;W;L`%+Y>F[I`%!R;V=R86UO=OT@8F%L[6L@2%144%]297%U97-T(&-H>6+M
M('8@4$5!4BX`0VAY8NQJ[6/M(&MO;F9I9W5R86-E+B!0;VMU9"!S:2!P^&5J
M971E('!O=;[M=F%T('1U=&\@87!L:6MA8VDL(&UU<^UT92!V>6=E;F5R;W9A
M="!K;VYF:6=U<F'H;NT@<V]U8F]R+@!#:'EB[&KM8^T@240@>G!RX79Y("AI
M9&5N=&EF:6MAZ&[M(.CM<VQO*0!0;[YA9&]V86[]('!R;V=R86UO=OT@8F%L
M[6L@36%I;"!C:'EB[2!V(%!%05(N`$-H>6+L:NUC[2!)1"!P<F\@<F5L86-I
M+@!0;P!-;V)I;&[M('!ON71A`$WM<F[]`$1A='5M('!O<VQE9&[M('IM[&YY
M`%IM[&YI=`!:;>SR:70@55),`$UO9'5L`$UO;&3A=FEE`$UO;F%K;P!-;VYG
M;VQS:V\`3>QS[6,@82!R;VL`3>QS[>AN[`!-;VYS97)A=`!&X7IE($WL<^UC
M90!-87)O:V\`4/AE=N&^;NP@:F%S;F\`4/AE=N&^;NP@;V)L8>AN;P!0^&5V
MX;YN["!S;'5N9>AN;P!0^&5S=6YO=70`4&]S=6YO=70@9&]L^0!0;W-U;F]U
M="!D;VQE=F$`4&]S=6YO=70@9&]P<F%V80!0;W-U;F]U="!N86AO<G4`4&]S
M=6YO=70@9&]L^0!0^&5S=6YO=70@9&\@<VQOOFMY`%!O<W5N;W5T(&YA:&]R
M=0!-;W-A;6)I:P!6[6-E+?IR;W;R;W;I(')O;&5T;W;I('-E>FYA;7D`5NUC
M92#HX7-T[2`O(&%L=&5R;F%T:79N[0!6[6-E;N%S;V)NX2!S96QE:V-E`$WY
M:B#ZZ&5T`$WY:B!P;W)TX6P`36]J92!R;WIL;[YE;NT@<&]R=.%L=0!->6%N
M;6%R`$Y%+"!.15-/54A,05/-30!03UI.P4U+00!*;>EN;P!.96QZ92!N96-H
M870@:FWI;F\@82]N96)O(&5M86EL('!RX7ID;ND`3F%M:6)I90!.875R=0!0
M;W3X96)U:F4@86MC:0!.97#A;`!.:7IO>F5M[0!.:7IO>F5M<VOI($%N=&EL
M>0!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%52
M3`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),
M`$YE='-C87!E(%)E=F]C871I;VX@55),`$IMZ6YO($YE='-C87!E(%-33"!S
M97)V97)U`%!O>F[A;6MA(&L@8V5R=&EF:6OA='4@3F5T<V-A<'4`5'EP(&-E
M<G1I9FEKX71U($YE='-C87!U`%/MNP!.:6MD>0!.975K;.%D870@</CM;&]H
M>0!.;W;A`$YO=N$@2V%L961O;FEE`$YO=N$@:V%T96=O<FEE`$YO=N$@<VQO
MOFMA`$YO=N$@<&^Y=&$`3>QS[6,@=B!P<G9N[2#H='9R=&EN[`!.;W;I('6^
M:79A=&5L<VOI(&IMZ6YO("AN97!O=FEN;NDI`$YO=OT@6NEL86YD`$YO=ND@
M>G!RX79Y`$YO=ND@;VMN;R`H7W!RX7ID;NDI`$YO=FEN:WD`3F5W<V=R;W5P
M<P!$86RY[0!$86RY[2!Z<'+A=F$`1&%LN>T@<W1RX6YK80!$86RY[2!M;[YN
M;W-T:0!.:6MA<F%G=6$`3FEG97(`3FEGZ7)I90!.;V,`3FEU90!.90!.96)Y
M;"!N86QE>F5N(&-E<G1I9FEKX70`0F5Z(+EI9G)O=N%N[0"NX61NZ2!K;.WH
M92!N96IS;W4@9&]S='5P;ND`KN%D;ND@>G!RX79Y`*[A9&[]('9E^&5J;OT@
M4$=0(&ML[>@@;F5B>6P@:6UP;W)T;W;A;BX`KN%D;OT@;W-O8F[M(&-E<G1I
M9FEKX70@;F5B>6P@;F%L97IE;@"NX61N_2!V9?AE:F[](&ML[>@@;F5B>6P@
M;F%L97IE;@"NX61N_2!V9?AE:F[](%,O34E-12!K;.WH(&YE8GEL(&EM<&]R
M=&]VX6XN`%#X[6QO:&$@;F5B>6QA(&YA;&5Z96YA+@"N861NX2!K;VYF:6=U
M<F'H;NT@9&%T82!N96IS;W4@9&]S='5P;N$@<')O('IO8G)A>F5N[2!R;WID
M[6SY+@!.96[M(&1O<W1U<&[A(+[A9&[A('-T<F%T96=I92!P<F\@='9O<F)U
M($E33R!O8G)A>ODN`$)E>B!DX79K;W;I:&\@=GIO<G4N`$YA('!OOF%D;W9A
M;ND@<&]Z:6-I(&YE97AI<W1U:F4@ON%D;OT@8FQO:P!.96)Y;&\@<&]S:WET
M;G5T;R"^X61NZ2!J;>EN;R!P<F\@:V%L96YDX?@@</AI(&]V[/AO=N%N[2!P
M;VUO8^T@34-!3"X`0F5Z('IM[&YY+@!.96QZ92!P^&ED870@ON%D;N$@<&]D
M+7!RX79A(&L@=.QM=&\@<'+A=OEM+@!.96)Y;'D@=79E9&5N>2"^X61NZ2!K
M;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R`E<RX`3F5B>6QY('5V961E;GD@
MON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@1E10(%9&4RX`3F5B
M>6QY('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@
M4U%,(%9&4RX`3F5B>6QY('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN
M9F]R;6%C92!P<F\@4U%,+49I;&4@5D93+@!.96WA=&4@ON%D;OT@:W)E9&ET
M+@!.96)Y;"!P;W-K>71N=70@ON%D;OT@8^UL+@"NX61N_2!S;W5B;W(@;F5B
M>6P@</AE;F5S96X`3F5B>6QA('9Y8G+A;F$@ON%D;N$@<VQOOFMA+@"NX61N
MX2!S;&^^:V$@;F5N[2!K;VYT<F]L;W;A;F$@;F$@</CM=&]M;F]S="!N;W;]
M8V@@>G!RX78N`*[A9&[A('-L;[YK82!N96)Y;&$@=7+H96YA`*[A9&[A('-L
M;[YK82!N96]B<V%H=6IE(&YO=ND@>G!RX79Y`*[A9&[A('-L;[YK82!N96]B
M<V%H=6IE(&YE<')O:&SI9&YU=.D@>G!RX79Y`$YE8GEL>2!N86QE>F5N>2"^
MX61NZ2!I:V]N>2X`3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US=&\N`*[A9&[]
M('1E>'0@=F4@>G!RX7;L`$YE8GEL>2!P;W-K>71N=71Y(+[A9&[I('IP<N%V
M>2X`5F&Y:6T@=GEH;&5DX79A8^UM(&MR:73I<FGM;2!N96]D<&]V[63A(+[A
M9&[A('IP<N%V82X`3F5B>6QO('5V961E;F\@ON%D;ND@:FWI;F\N`$YE8GEL
M;R!U=F5D96YO(+[A9&[I(.CM<VQO+@!"97H@;F5S;'6Y;OUC:`!.96)Y;&\@
M<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@2%144"X`3F5B
M>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M($E-05`N
M`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!+
M97)B97)O<RX`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@
M</AI:&SAN65N[2!S92!D;R!S>7-TZ6UU+@!.96)Y;&\@<&]S:WET;G5T;R!H
M97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@4$%34U=$+@!.96)Y;&\@<&]S:WET
M;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@4TU"+@!.96)Y;&$@<&]S
M:WET;G5T82!C97-T82!K(&)I;N%R;NUM=2!S;W5B;W)U($]P96Y34TPN($)I
M;N%R;NT@<V]U8F]R($]P96Y34TP@:F4@>F%P;W3X96+M('!R;R!P<N%C:2!S
M(%!+0U,@,3(@9&%T>2X`KN%D;ND@;F5V>?CM>F5NZ2"^X61O<W1I(&\@</AI
M:&SAN65N[2X`KN%D;OT@>B!68;EI8V@@;W-O8F[M8V@@<')I=N%T;NUC:"!0
M1U`@:VSMZ/D@;F5B>6P@:6UP;W)T;W;A;BX`KN%D;OT@>B!68;EI8V@@;W-O
M8F[M8V@@=F7X96IN_6-H(%!'4"!K;.WH^2!N96)Y;"!I;7!O<G1O=N%N+@"N
MX61N_2!O<V]B;NT@4R]-24U%(&ML[>@@;F5B>6P@:6UP;W)T;W;A;BX`0F5Z
M('!R879I9&5L`$)E>B!O:W)A:OD`KN%D;N$@:V]N=')O;&$@<')A=F]P:7-U
M(&YE;NT@:R!D:7-P;WII8VDN`*[A9&[I('!R879O<&ES;ND@8VAY8GD`KN%D
M;ND@;N%V<FAY`*[A9&[]('H@9&_H87-N_6-H(&%D<F5SX?CY(&YE;NT@9&]S
M='5P;OT@<')O(&-A8VAE+@!.96)Y;"!U=F5D96X@ON%D;OT@=;YI=F%T96PN
M`$YE8GEL;R!O9&5S;.%N;R"^X61NZ2!UOFEV871E;'-KZ2!J;>EN;R!A+VYE
M8F\@:&5S;&\N`$YE8GEL82!N879RX6-E;F$@ON%D;N$@<&QA=&[A(%A-3"!D
M871A+@"NX61NZ2!H;V1N;W1Y`%8@;W)I9VENX6QN[2!K;VYF:6=U<F%C:2!N
M96)Y;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V=&4@:V]N9FEG=7)A8VDN`%9E
M(%9AN>T@:V]N9FEG=7)A8VD@;F5B>6QA(&YA;&5Z96YA('9E<GIE+B!/8FYO
M=G1E(&MO;F9I9W5R86-I+@!.96[M(/KH87-T;NUK96T`KN%D;OT`KN%D;OT@
M*'!O=;YI:G1E(&EM<&QI8VET;NTI`%-E=F5R<VO]("A)4T\M.#@U.2TQ,"D`
M3F]R9F]L:W-KZ2!O<W1R;W9Y`$YO<FWA;&[M`%-E=F5R;NT@<&]L;VMO=6QE
M`%-E=F5R;NT@36%R:>%N<VOI(&]S=')O=GD`3F]R<VMO`$YE;NT@<&\`3F5N
M[2!P^&5D`$YE8GEL;R!S;6%ZX6YO`*[A9&[A(')O>F5P<V%NX2!Z<'+A=F$`
M3F5N[2!D^6QEOFETZ0!.96[M(&]S;V)N[0!.96[M(&%D<F5SX?AE;0!.97!L
M871N_2!V9?AE:F[](&ML[>@N`$YE=GEM87IA;ND@>G!RX79Y`$YE;NT@:6UP
M;&5M96YT;W;A;F\N`$YE9/EL9;YI=.D@>G!RX79Y`$YE;NT@;F%S=&%V96YO
M`$YE;NT@<&]D<&]R;W;A;F\N`%5P;WIO<F[L;NTZ(%1A=&\@;W!E<F%C92!M
M^;YE('1R=F%T(&1L;W5H;P!0;WINX6UK80!.:6,@:R!P<F]H;.ED;G5T[2P@
M8NR^=&4@>G#L="X`3&ES=&]P860`R.US;&\`4&_H970@>FYA:_D`4&_H970@
M<VQO=7!C^0!0;^AE="!M['/M8_DL('!O(&MT97+I(&)U9&5M92!U8VAO=N%V
M870@</CM;&]H>2!U;&^^96[I(&IA:V\@;V1K87IY('#X:2!M['/MZ&[M8V@@
MZ&FY=.QN[2X`4&_H970@<W1A<OUC:"!S;&^^96L@<R!O9&5S;&%N_6UI('IP
M<N%V86UI+"!K=&5RZ2!B>2!N96WL;'D@8OUT('9Y;6%ZX6YY("AV>6UA>N%V
MX6[M(&WL<^WH;NPI+@!0;^AE="#XX61K^0!.96)Y;&$@>F%DX6YA(.CM<VQA
M('!R;R!A:W1U86QI>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA;74N`$]+`$Y%
M0D\`3V)J96MT`%1V^7)C92!O8FIE:W3Y`$]S;6GH:V]V_0#8[6IE;@!&:6QT
M<F]V870@;F5S;'6Y;ND`2V%N8V5LX?@`4W1A<ND@>G!RX79Y`%-T87+I('-L
M;[YK>2!S(&]D97-L86YO=2!P;[ET;W4L(&MT97+I('-E('9Y<')A>F3R=6KM
M+@!/;>%N`%-D[6QE;ND@<VQOOFMY(&IS;W4@<&]S:WET;W;A;GD@<&]U>F4@
M24U!4"!S97)V97)Y+@!:;V)R87II="!P;W5Z92!S;&^^:WD@<R!N97#X9>AT
M96[];6D@>G!RX79A;6D_`%!O=7IE(&YE<VQUN6[I`$IE('!O=F]L96YA('!O
M=7IE(&IE9&YA(&4M;6%I;&]VX2!A9')E<V$N`%1U=&\@86MC:2!L>F4@<')O
M=NES="!P;W5Z92!S(&IE9&YO=2!S;&^^:V]U+@!0;W5Z92!V;&%S=&[M:R!N
M96)O('-Y<W3I;6]V_2!A9&UI;FES='+A=&]R(&WYOF4@;>QN:70@<'+A=F$@
M<')O('-D[6QE;OT@;V)J96MT+@!/=&5V^.UT('8@;F]VZ6T@;VMN["X`0VAY
M8F$@3W!E;E-33#H@3F5L>F4@>NUS:V%T(&1A=&$@>B!P;V1E<'-A;ND@Z.%S
M=&D@4R]-24U%+@!3;&^^:V$@;W1E=OAE;F$`3W1E=OCM="!T96YT;R!O9&MA
M>B!V(&YO=NEM(&]K;NP`3W!E<F'H;NT@<WES=.EM`$UOOF[M(/KH87-T;NUC
M:0!-;[YN;W-T:0!-;[YN;W-T:2!P<F\@)7,`4V7X87IE;OT@<V5Z;F%M`$]R
M9V%N:7IA8V4`3W)G86YI>F'H;NT@:F5D;F]T:V$`3W)G86YI>F]VX6[M`$]R
M:6=I;N%L;NT@=GIO<B!P<F\@ON%D;W-T`$]R:6=I;N%L;NT@=GIO<B!V("5S
M.@!/<W1A=&[M`$]S=&%T;NT@:6YF;W)M86-E`$1A;+GM('!ON71O=F[M(/KH
M='D`1&%LN>T@;6^^;F]S=&D`5;YI=F%T96QS:^$@<'+A=F$`3W;L^&5N[2!P
M;VUO8^T@4$%-(&YE;NT@9&]S='5P;NDN`%!'4`!01U`@9&EG:73A;&[M('!O
M9'!I<P!01U`@N6EF<F]VX6[M('IP<N%V>0!01U`@N6EF<F]V86[A(&1A=&$`
M4$=0(&-H>6)A.B``4$=0(&-H>6)A.B!*92!P;W3X96)A(&AE<VQO('!R;R!6
MX;D@;W-O8F[M('!R:7;A=&[M(&ML[>@N`$UOOFYO<W1I(%!'4`!6;&^^:70@
M4$=0(&AE<VQO`%!O=;YI=.T@4$=0(&]S;V)N[6AO(&ML[>AO=NEH;R!PX7)U
M('9YOF%D=6IE(&)E>G!EZ&[I('#X:7!O:F5N[2`H2%144%,I+@!69?AE:F[]
M(%!'4"!K;.WH`%1E>'0@=F7X96INZ6AO(%!'4"!K;.WH90!69?AE:F[](%!'
M4"!K;.WH('!R;R`B)7,@*"5S*2(@8GEL(/IS<.RY;NP@</AI9.%N+@!69?AE
M:F[](%!'4"!K;.WH('!R;R`B)7,B(&)Y;"#Z<W#LN6[L('9Y;6%ZX6XN`%9E
M^&5J;OT@<W9A>F5K(%!'4"!K;.WH^0!0;V1E<'-A="!Z<'+A=G4@<&]M;V/M
M(%!'4`!0;V1E<'-A="^Y:69R;W9A="!Z<'+A=G4@<&]M;V/M(%!'4`!$871A
M('!O9&5P<V%NX2^Y:69R;W9A;N$@<&]M;V/M(%!'4`!01U`@<')I=N%T;NT@
M:VSMZ"!B>6P@^G-P[+EN["!P^&EDX6XN`%!'4"!V9?AE:F[](&ML[>@@8GEL
M(/IS<.RY;NP@</AI9.%N+@!496YT;R!S>7-TZ6T@;F5P;V1P;W)U:F4@4$=0
M+@!01U`@;F5N[2!A:W1I=F]VX6YO+"!D:6=I=.%L;NT@<&]D<&ES(&YE;'IE
M(&]V[/AI="X`4$=0(&YE;NT@86MT:79O=N%N;RP@>G!RX79U(&YE;'IE(&1E
MN6EF<F]V870N`%!(4"!K\V0`4$A0(&MO;GIO;&$`3V1P;VQE9&[M(&QE:&O]
M(&3IN;L`3V1P;VQE9&[M('#X96CA\FMY`$]D<&]L961N[2!S;NR^96[M`$]D
M<&]L961N[2!S;NQH;W;I('#X96CA\FMY`$]D<&]L961N[2!B;W7X:WD`4$]0
M,P!03U`S("A!=71O;6%T:6-KX2!D971E:V-E('!R;W1O:V]L^2D`4$]0,R!P
M^&5S(%-33`!03U`S('#X97,@4U-,("AS(&YE;V9I8VGA;&[M;2!C97)T:69I
M:^%T96TI`%!/4#,@</AE<R!34TP@*',@;F5O9FEC:>%L;NUM(&-E<G1I9FEK
MX71E;2D`4$]0,RP@8F5Z(%1,4P!07TA0(&MO;GIO;&$`3V1S='5P>0!3='+A
M;FMA("5D('H@)60`4W1RX6YK82!S('!R=F[M(&YE<')O:&SI9&YU=&]U('IP
M<N%V;W4`4W1RX6YK82!S('!O<VQE9&[M(&YE<')O:&SI9&YU=&]U('IP<N%V
M;W4`4.%K:7-TX6X`4&%L874`4&%L97-T:6YS:^D@=&5R:71O<FEU;2P@;VMU
M<&]V86[I`%!A;F%M80!087!U82!.;W;A($=U:6YE80!087)A9W5A>0#(X7-T
M*&DI`$WM<W1Y('IA=&&^96YO`$AE<VQO`$AE<VQO("AO<.QT*0!(97-L;R!B
M>6QO(/IS<.RY;NP@<&]S:WET;G5T;RX`2&5S;&\Z`$YE;'IE('IA9&%T('!R
MX7ID;ND@:&5S;&\`2&5S;&$@<V4@;F5S:&]D=6KM`$AE<VQO`$YE<W!RX79N
MZ2!H97-L;P!0<F\@;W;L^&5N[2!P;VUO8^T@4D%$54E3(&IE(&YU=&YO('IA
M9&%T(&AE<VQO+@!(97-L;R!S('!O='9R>F5N[6T`2&5S;&\Z`$AE<VQO.B``
M2&5S;&$@<V4@;75S[2!S:&]D;W9A="X`5FQOOFET`%9L;[YI="!Z92!S8VAR
MX6YK>0!#97-T80"NX61O<W1I(&\@</AI:&SAN65N[3H`3&EDZ0!0<F]C96YT
M`%!R;W;I<W0@;W!E<F%C92#Z9'*^8GD`4')O=NES="!O<&5R86-E(/ID<KYB
M>2!P^&D@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!0<N%V80!!9&UI;FES=')A
MZ&[M('!RX79A`$YE;'IE('IM[&YI="!P<N%V82!P<F\@=&]H;R!UOFEV871E
M;&4N`$]S;V)N[0!/<V]B;NT@:6YF;W)M86-E`%;AN2!O<V]B;NT@4$=0(&ML
M[>AO=OT@<.%R(&)Y;"#Z<W#LN6[L('9Y='9O^&5N+@!68;EE(&]S;V)N[2!0
M1U`@:VSMZ&4@8GEL>2#Z<W#LN6[L('-M87KA;GDN`$]S;V)N[2!3+TU)344@
M8V5R=&EF:6OA='D@3D5"64Q9(&EM<&]R=&]VX6YY.@!68;EE(&]S;V)N[2!3
M+TU)344@:VSMZ&4@8GEL>2#Z<W#LN6[L('-M87KA;GDN`%!E<G4`1&]MX6/M
M('IV[?AA=&$`1FEL:7#M;GD`5&5L969O;@!&;W1O9W)A9FEE`%!I=&-A:7)N
M`%!I>&5L^0!5;>US=.UT(%9AN6D@<VEG;F%T=7)U('#X960@;V1P;W;L[R!A
M('1A:^D@</AE9"!P^&5P;W-L86YO=2!Z<'+A=G4_`%1E>'1O=N$@=F5R>F4@
M>G!RX79Y`$9RX7IE`%!R;W/M;2!K;&EK;NQT92!N82!N[&IA:V]U(&)U\FMU
M`%!R;W/M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N
M=&\@<')V96LZ`%!R;W/M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T
M<F%N:70@=&5N=&\@<')V96LN`%!R;W/M;2!Z861E:G1E(&WL<^UC(&$@<F]K
M+@!0<F]S[6T@>F%D96IT92!NX7IE=B!N;W;I(&MA=&5G;W)I93H`4')O<^UM
M('IA9&5J=&4@;N%Z978@;F]VZ2!S;&^^:WDZ`%!R;W/M;2!Z861E:G1E('-P
M<N%V;F]U($E0(&%D<F5S=2XN`%!R;W/M;2!Z861E:G1E('-P<N%V;OT@9&%T
M=6T@82!Z:V]N=')O;'5J=&4@<&_H970@9&[M('8@;>QS[6-I+@!0<F]S[6T@
M>F%D96IT92!S<'+A=F[](.AA<RX`4')O<^UM('IA9&5J=&4@;N%Z978@;F]V
MZ2!S;&^^:WDZ`%!R;W/M;2!Z861E:G1E(&YO=ND@:FWI;F\Z`%!R;W/M;2!Z
M861E:G1E(&AE<VQO(&L@5F&Y96UU('!R:7;A=&[M;74@4$=0(&ML[>AI+B!(
M97-L;R!J92!N=71NZ2!Z861A="!P;W5Z92!J961N;W4@>F$@)7,@<F5L86-I
M+@!0<F]S[6T@>F%D96IT92!H97-L;R!K(%9AN65M=2!P<FEVX71N[6UU(%,O
M34E-12!K;.WH:2X@2&5S;&\@:F4@;G5T;ND@>F%D870@<&]U>F4@:F5D;F]U
M('IA("5S(')E;&%C:2X`4')O<^UM(&]P['0@<V4@</AI:&QAN71E+"!P;VMU
M9"!C:&-E=&4@<&]K<F'H;W9A="!V92!V>71VX?AE;NT@>G!RX79Y+B!0;VMU
M9"!N97!O=;[M=N%T92!C;V]K:65S(&$@=GET=N'X[71E('IP<N%V=2!V('!O
M<'5P(&]K;NPL(&)U9&5T92!S92!M=7-E="!P^&EH;.%S:70@=&%KZ2!V92!6
M8;EE;2!H;&%V;NUM(&]K;NPN(%1A:V]VZ71O(&YA<W1A=F5N[2!Z86)R8?)U
M:F4@^G1OZ&[M:_EM('IM;V-N:70@<V4@5F&Y[2!R96QAZ&[M($E$+B!$[&MU
M:F5M92!Z82!P;V-H;W!E;NTN`%!R;W/M;2!U=F7O=&4@<VAR;G5T[2!68;EE
M:&\@<')O8FSI;74N`%!R;W/M;2!Z861E:G1E(%9AN64@:&5S;&\N`%!R;W/M
M;2!Z861E:G1E(%9AN64@=;YI=F%T96QS:^D@:FWI;F\@82!H97-L;P!0<F]S
M[6T@>F%D96IT92!68;EE('6^:79A=&5L<VOI(&IMZ6YO+@!0<F]S[6T@;W!R
M879T92!N96IE9&YO>FYAZ&[I(&YE8F\@;F5P;&%T;ND@861R97-Y+@!0<F]S
M[6T@>FMO;G1R;VQU:G1E(&[A<VQE9'5J[6/M(&EN9F]R;6%C92!A('!A:R!V
M>6)E<G1E(&%K8VD@>B!N[;YE('5V961E;NEH;R!M96YU+@!0<F]S[6T@=GEB
M97)T92!N96ID^.UV92!S;&^^:W4@82!P86L@<')O=F7O=&4@86MC:2X`4')O
M<^UM('9Y8F5R=&4@86MC:2!Z(&[MOF4@=79E9&5NZ6AO(&UE;G4N`%!R;W/M
M;2!V>6)E<G1E(&YE:FWI;NP@:F5D;G4@<VQOOFMU(&L@<')O:&QE9.%N[2X`
M4')O<^UM('9Y8F5R=&4@<&]U>F4@:F5D;G4@<VQOOFMU('!R;R!T=71O(&]P
M97)A8VDN`%!R;W/M;2!V>6)E<G1E(&YE8F\@=7!R879T92!V(&)O>'4@=G!R
M879O.@!0<F]S[6T@>F%D96IT92!N;W;](&[A>F5V(&MA=&5G;W)I93H`4&]L
M<VMO`%!O;&ET:6MA`$AL87-O=N%N[0!0;W)T=6=A;'-K;P!5;>US=.QN[2!T
M;VAO=&\@;V)RX7IK=0!5;>US=.QN[2!T86)U;&MY`%IA<VQA="!D;R!TZ71O
M('-L;[YK>2`H;F5N[2!P;W-K>71N=71O($E-05!E;2D`6F%L;[YE;F\@;F$@
M2&]R9&4`4/AE9&-HX7IE="!S:6=N871U<G4@<&]M;.AK86UI("@G+2T@)RD_
M`%-RX;YK>2!Z82!P;W-L961N[2AC:"D@)7,@:&]D:6XH=2DZ(`!68;EE(&YA
M<W1A=F5N[2!B>6QA(/IS<.RY;NP@=6QOOF5N82X`4')E9G-?;&1A<#H@3F5B
M>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!,1$%0+@!0<F5F<U]S
M97-S:6]N.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('-E
M:V-E+@!"87)O;65T<FEC:_T@=&QA:P!"87)O;65T<FEC:_T@=&QA:R!N82#Z
M<F]V;FD@;6_X93H@`$)A<F]M971R:6-K_2!T;&%K.@!.X6AL960`3N%H;&5D
M(&]B<N%Z:W4@=B!N;W;I;2!O:V[L`%#X961C:&]Z[2!Z<'+A=F$`4/AE9&-H
M;WKM('-T<N%N:V$`4/AE9&-H;WKM(&UOOFYO<W1I`%1I<VL`5&ES:VYO=70@
M9&]K=6UE;G0`1/EL9;YI=&]S=`!0<FEVX71N[2!K;.WH`$AE<VQO('!R;R!P
M<FEVX71N[2!K;.WH`%!R;V)LZ6T`4&]P:7,@<')O8FSI;74`4')O:F5K='D`
M6F5P=&%T('-E('!O:V&^9.D@</AI('!O<^ULX6[M('#X[6QO:'DL(&EM<&QI
M8VET;NP@3D4`6F5P=&%T('-E('!O:V&^9.D@</AI('!O<^ULX6[M('#X[6QO
M:'DL(&EM<&QI8VET;NP@04Y/`%!R;VUP="!T97AT`%!R;W1O:V]L.@!69?AE
M:F[](&ML[>@`06QG;W)I=&UU<R!P<F\@=F7X96IN_2!K;.WH`%!O9'!O<F$@
M=F7X96IN_6-H(%!'4"!K;.WH;W;]8V@@<V5R=F5R^2!B>6QA('9Y<&YU=&$N
M`%9E^&5J;OTO<')I=N%T;NT@:VSMZ&]V_2!PX7(@;F5B>6P@^G-P[+EN["!V
M>71V;_AE;BX`4&]R=&]R:6MO`%9YZ%]I<W1I="!S;6%Z86[I`%9YZ&ES=&ET
M('-M87IA;ND`5GGH:7-T:70@<VQOOFMU*'DI`$IA:R#H87-T;R!V>7!R87ID
M\F]V870@<VQOOFMU(&MON3H`4VUA>F%T('IE('-L;[YK>2!K;[EE('IP<N%V
M>2P@:W1E<ND@:G-O=2!S=&%RN>T@;F6^('5V961E;OT@<&_H970@9&[M+@!3
M;6%Z870@<W1A<ND@>G!RX79Y('IE('-L;[YK>2!K;[EE/P!+871A<@!6>6AL
M963A;NT`4W1A=B!K=O-T>3H@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0!3
M=&%V(&MV\W1Y.B`E+C)F34(@+R!"15H@3$E-2515`%-T878@:W;S='DZ($)%
M6B!,24U)5%4`0VET=6II("5F.@!24T$@=F7X96IN_2!K;.WH("@E9"!B:73Y
M*0!3</AAOF5NZ2!T;&'H[71K;P!$Z;F[`$)R>FO](&3IN;L`4&]Z9&[M(&3I
MN;L`1&6YNV]VZ2!P^&5HX?)K>0!$Z;F[('-E('-N[&AE;0!$Z;F[(&&^('-N
M[6@`3N%H;V1N["!V>6)R86[I(+ET['-T[0!0;VWL<@"NX5]D;W-T(&\@<&]T
M=G)Z96[M(&1O<G7H96[M`,AT96/M`%#X9>AT96[I('IP<N%V>0!/<')A=F1U
M('-M87IA="`E<S\@5&%T;R!O<&5R86-E(&IE(&YE=G)A=&[A+@!/<')A=F1U
M('-M87IA="!UOFEV871E;'-KX2!D871A('!R;R!UOFEV871E;&4@)7,_(%1A
M=&\@;W!E<F%C92!J92!N979R871NX2X`4/AI:F%T;R!V`%#X:6IA=&\@;V0`
M4/AI:F%T;R!D;P!0^&5S;>QR;W9A7W0`4/AE<VWL<F]V870`4/AE<VWL<F]V
M870@>G!RX79U`%#X97-M[')O=F%T('1U=&\@>G!RX79U`%#X97-M[')O=N%N
M[2!S96QH86QO+@!/<&%K;W9A="!P;W-L961N[2!A:V-I`$]B;F]V:70`3V)N
M;W9I="!D>6YA;6EC:^D@<')V:WD@;65N=3H`3V)N;W9I="!Z;V)R87IE;NT@
M<VQOOF5K.@!/8FYO=F$@>F]B<F%Z96[M('!O<G3A;'4Z(`!296=E>`!0<F]H
M;.V^9>@@=GIT86CY`$]B;F]V:70`3V)N;W9I="!Z;V)R87IE;NT`2&]D;F]T
M>0!:87!O;6%T;W9A="!S:2!I;F9O<FUA8VD@;R!F<F5E+V)U<WDN`%IA<&]M
M871O=F%T('-I('!O<VQE9&[M('IO8G)A>F5N[0!6>F3A;&5NX2!S8VARX6YK
M83H`5GIDX6QE;ND@<V5R=F5R>2X`5GIDX6QE;N$@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`3V1S=')A;FET`$]D<W1R86YI="!B;&]K
M`$]D<W1R86YI="!P;VQE('H@=GEH;&5DX7;A;NT`3V1S=')A;FET('-L;W5P
M96,`3V1S=')A;FET(&9O<FWA=&]VX6[M`$]D<W1R86YI="!PX7(`3V1S=')A
M=&ET('5L;[YE;OT@<VMR:7!T('H@9&_H87-NZ6AO(&%D<F5SX?AE(&YA('-E
M<G9E<G4N`$]D<W1R86YI="!Z9')O:@!/9'-T<F%N:70`3V1S=')A;FET('1U
M=&\@Z.%S="!D;VMU;65N='4`3V1S=')A;FET('6^:79A=&5L90!/9'-T<F%N
M:70@=;YI=F%T96QE.B`E<P!0^&5J;65N;W9A="!S;&^^:W4H>2D`4/AE:FUE
M;F]V870@<VQOOFMU(',@;V1E<VQA;OUM:2!Z<'+A=F%M:2!N82!Z8>CA=&MU
M(&WL<^UC93\`4/AE:FUE;F]VX6[M("(E<R(@;F$@(B5S(B!S96QH86QO+B!4
M;W1O(&IE(&ALX;EE;NT@;V0@<V5R=F5R=0!/9'!O7W;L9.QT('-E>FYA;74`
M3F%H<F%D:70Z`$]D<&]V[&3L=`!/9'!O=NSO(&)Y;&$@;V1E<VSA;F$N`$]D
M<&]V[&3L="!VN65M`$]D<&]V[&3L="!VN65M.@!/9'!O=NQD['0@<V5Z;F%M
M=0!/9'!O=NQD['0@<V5Z;F%M=3H`3V1P;W;L9.QT(%]VN65M`$]D<&]V[.\@
M<R!N97-T86YD87)D;NT@>G!RX79O=0!/9'!O=NQD['0@;F$@9G)E92]B=7-Y
M(&YA('#X[;ET[2`R(&WL<^UC92X`3V1P;W;L9.QT(',@<&^^861O=F%N;W4@
M:6YF;W)M86/M(&9R964O8G5S>2X`3V1P;W;L9.QT+6MO;74`3V1P;W;L9.QT
M+6MO;74Z(`!/9'!O=NSO.@!.86ALX7-I="!J86MO(&-H=.QNZ2`H:&%M*0!.
M86ALX7-I="!J86MO(&YE8VAT[&[I("AS<&%M*0"NX61O<W0@;R!?<&]T=G)Z
M96[M('#X9>AT96[M`$YE;'IE(&]D<&]V[&3L="!N82!P;[YA9&%V96LN($-H
M>6)O=ND@:&SAN65N[3H@`*[A9&]S="!O('!O='9R>F5N[2!D;W)UZ&5N[3\`
MKN%D;W-T(&\@<&]T=G)Z96[M('#X9>AT96[M/P!0;[YA9&]V86[A('IP<N%V
M82!N96)Y;&$@;F%L97IE;F$N`%!OOF%D;W9A;ND@<&]L90!0;[YA9&]V86[M
M(/KH87-T;NUC:0!6_6-H;WKM(&YA<W1A=F5N[0!6_6-H;WKM(&YA<W1A=F5N
M[2!H97-L80!6_6-H;WKM(&YA<W1A=F5N[2!68;EE:&\@:&5S;&$`4W1A=B!O
M9'!O=NUD86KM8^UC:"!B>6P@86MT=6%L:7IO=N%N+@!6_7-L961K>0!0;VMR
M8>AO=F%T`%!O:W)AZ&]V870@=B!R96QA8VD`3N%V<F%T(&ME('-T86AO=N%N
M[2!P;[ET>0!.X79R870@9&\@;6^^;F]S=.T`5G+A=&ET('-E(&1O('-C:'+A
M;FMY('!O('-M87KA;NTL('#X97-U;G5T[2P@;F5B;R!Z:V]P[7)O=N%N[2!Z
M<'+A=GD_`%)E=6YI;VX`4/AE<&YO=70@:V]N9FEG=7)A8VD`36^^;F]S=&D@
M4FEC:"!497AT(&5D:71O<G4`2.%D86YK>0!$;W!R879A`$AL879IZ&MA(&YA
M<')A=F\`2&]D;F]T>2!N87!R879O`%9L87-T;F]S=&D@^.%?9&MU`-IL;VAA
M`%)U;75N<VMO`$]T;^AI="!O(#$X,+``3W1OZ&ET(&1O;&5V80!/=&_H:70@
M9&]P<F%V80!6;&%S=&YO<W1I(/CA9&MU`%9L87-T;F]S=&D@^.%D:W4`V.%D
M:WDZ`%!R879I9&QA`%!R879I9&QA('-E('5P;&%T;NT@;65Z:2!VN65M:2#X
MX61K>2!A('-L;W5P8VD`4')A=FED;&$@<V4@=7!L871N[2!P;W5Z92!M97II
M('-L;W5P8VD`4')A=FED;&$@<V4@=7!L871N[2!P;W5Z92!M97II(/CA9&MY
M`%!R;W;I<W0`4G5S:^$@9F5D97)A8V4`4G=A;F1A`%,O34E-10!3+TU)344@
MN6EF<F]V86[]('!O9'!I<P!3+TU)344@N6EF<F]V86[A('IP<N%V80!3+TU)
M344@N6EF<F]V86[A('IP<N%V80!3+TU)344@8VAY8F$Z(`!3+TU)344@8VAY
M8F$Z($IE('!O=/AE8F$@:&5S;&\@<')O(%;AN2!O<V]B;NT@<')I=N%T;NT@
M:VSMZ"X`36^^;F]S=&D@4R]-24U%`%9L;[YI="!3+TU)344@:&5S;&\`2F4@
M<&]T^&5B82!B97IP9>ANZ6AO('#X:7!O:F5N[2!K('/M=&D@*$A45%!3*2P@
M86)Y<W1E(&UO:&QI('!O=;[M="!6X;D@;W-O8F[M(%,O34E-12!K;.WH;W;]
M('#A<BX`4R]-24U%('9E^&5J;OT@:VSMZ"!P<F\@(B5S(B!B>6P@^G-P[+EN
M["!S;6%ZX6XN`%,O34E-12!V9?AE:F[](&ML[>@@8GEL(/IS<.RY;NP@</AI
M9.%N+@!3+TU)344@=F7X96IN_2!S=F%Z96L@:VSMZ/D`4R]-24U%('9E^&5J
M;OTO<')I=N%T;NT@:VSMZ&]V_2!PX7(@8GEL(/IS<.RY;NP@</AI9.%N+@!3
M+TU)344@<&]D97!S86[A('IP<N%V80!3+TU)344@<&]D97!S86[A+[EI9G)O
M=F%NX2!Z<'+A=F$`5&5N=&\@<WES=.EM(&YE<&]D<&]R=6IE(%,O34E-12X`
M4&]D<&]R82!3+TU)344@;F5N[2!A:W1I=F]VX6YA+"!Z<'+A=G4@;F5L>F4@
M9&6Y:69R;W9A="X`4&]D<&]R82!3+TU)344@;F5N[2!A:W1I=F]VX6YA+"!D
M:6=I=.%L;NT@<&]D<&ES(&YE;'IE(&]V[/AI="X`3W;L^&5N[2!P;VUO8^T@
M4T%33"!N96[M(&1O<W1U<&[I+@!335,@>G!RX79Y`%-13"!K;VYZ;VQA`%-3
M2`#:4U#,0T@`4U]13"!K;VYZ;VQA`%]0^&5D;>QT`%-O`%5L7V^^:70@:V]P
M:6D@9&\@`%5L7V^^:70@:F%K;P!3=F%TX2!(96QE;F$`4W9A=/T@2VET=',@
M82!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N
M`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-T96IN_2!RX6T@
M*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP
M90!6;&%S=&[M:R!S871E;&ET=0!3875D<VOA($%RX6)I90!5;&^^:70`56QO
MOFET("5S`%5L;[YI="!P^.UL;VAY('-E('IP<N%V;W4@=F4@<VQOOF-E('!R
M;R!O9&5S;&%N;W4@<&^Y='4_`%5L;[YI="!R;WIE<'-A;F]U('IP<N%V=0!5
M;&^^:70@;6^^;F]S=&D`56QOOFET(%]R;WIE<'-A;F]U('IP<N%V=0!5;&^^
M:70@:F%K;P!5;&^^:70@<F]Z97!S86YO=2!Z<'+A=G4@:F%K;R!N97!R;VAL
MZ61N=71O=3\`56QOOFET('9Y='9O^&5N_2!K;VYF:6=U<F'H;NT@4$A0('-K
M<FEP="!D;R!D;^AA<V[I:&\@861R97/A^&4@;F$@<V5R=F5R=2X`56QOOFET
M(&%U=&]M871I8VMY('#X[6IE;6-E(&1O(&EM<&QI8VET;NUH;R!A9')E<^'X
M93\`56QOOFET('9Y:&QE9.%VX6[M(&1O('9I<G1UX6QN[2!S;&^^:WD_`%5L
M;[YI="!O9&5S;&%N;W4@<&^Y='4_`$MO;F9I9W5R86-E("5S('5L;[YE;F$N
M`$YE<&]D8?AI;&\@<V4@=6QOOFET(')O>F5P<V%N;W4@>G!RX79U+B!4;W1O
M(&IE(&ALX;EE;NT@>F4@<V5R=F5R=3H@)7,`5NQD80!6>6AL963A=N%N[0!6
M>6AL963A=N%N[2`E<P!6>6AL963A=F%C[2!NX7-T<F]J90!6_7-L961K>2!V
M>6AL963A=N%N[0!0<F]H;.ED;G5TZ0!6>6)R870`5GEB<F%T(&II;OT@^NAE
M=`!6>6)R870@<V]U8F]R>0!6>6)R870@9&%T=6T`5GEB<F%T('!O;&4`5GEB
M<F%T('-K=7!I;G4L(&MT97+A(&)U9&4@</AI9.%N80!6>6)R870@;F]VZ6AO
M('9L87-T;NUK80!6>6)R870@<V5R=F5R`%9Y8G)A="!UOFEV871E;&4L(&MT
M97+](&)U9&4@</AI9.%N`%9O;&)A('ID<F]J^2!A9')E<^'X92!P<F\@</AI
M9.%V86[M(&$@=GEH;&5DX7;A;NT@861R97,N`%9Y8G)A="!6N64`5GEB<F%T
M(':Y96-H;GD@Z.%S=&D@9&%T=6UU+@!6>6)R870@=KEE8VAN82!P;VQE('!R
M;R!V>6AL963A=N%N[2!P^&D@97AP86YZ:2!A9')E<RX`5GEB<F%T(/KH970`
M5GEB<F%T(&]B:F5K=`!.979Y8G+A;F\`5GEB97)T92!P;W3X96)NZ2!Z;F%K
M>2!Z(&[MOF4@=79E9&5N_6-H(&)O>/DN(%!O=.D@:F4@;?F^971E(&MO<.UR
M;W9A="!A('9L;[YI="!Z('1E>'1O=ND@;V)L87-T:2X`5GEB97)T92!O9&3L
M;&]V86/M('IN86L@<')O(&1A='5M.@!6>6)E<G1E(&9O<FWA="!D871U;74Z
M`%9Y8F5R=&4@:61E;G1I='4L(&MT97)O=2!S:2!P^&5J971E('IM[&YI=#H`
M5GEB<F%T('1Y<"!P;[ET;W9N[6AO('-E<G9E<G4`5GEB97)T92!O9&3L;&]V
M86/M('IN86L@<')O(.AA<SH`5GEB97)T92!F;W)MX70@Z&%S=3H`5GEB97)T
M92!D=NP@;V1P;W;M9&%J[6/M('!O;&4N`%9Y8F5R=&4@8F%R979N_2!M;W1I
M=BX`5GEB97)T92!6X6UI('!R969E<F]V86[](&IA>GEK.@!6>6)R86[]('ID
M<F]J(&%D<F5SX?CY.@!0;W-L870@:VSMZ"!V9?AE:F[I;74@:VSMZ&]VZ6UU
M('-E<G9E<G4`4&]S;&%T(&YE:F%K='7A;&[L:KGM(&EN9F]R;6%C90!/9&5S
M;&%T('IP<N%V=0!0;W-L870@>G!RX79U(&\@<')O8FSI;74`4&]S;&%T(%--
M4P!396YE9V%L`%-E;G-O<CH`4VQOOFMA(',@;V1E<VQA;F]U('!ON71O=0!3
M;&^^:V$@<R!O9&5S;&%N;W4@<&^Y=&]U.@!:X?CM`%-R8G-K;R!A(,AE<F[A
M($AO<F$`4^ER:6]VZ2#H[7-L;P!397)V97(`26YF;W)M86-E(&\@<V5R=F5R
M=2!A('-L;[YKX6-H`%-E<G9E<CH`240@<V5K8V4@>F%N:6ML;RX`3F%S=&%V
M:70`3F%S=&%V:70@;6^^;F]S=&D@<')O('!O=F]L96[M(')E<V5T=2!H97-L
M82P@<&]K=60@:&\@>F%P;VUE;F5T92X`3F%S=&%V96[M(&%K8^T@<')O=N%D
M[&[]8V@@</AI('#X97-O=7;A;NT@82!M87KA;NT@>G!RX78N`$YA<W1A=FET
M('#X:2!V>71VX?AE;NT@>G!RX78@:&QA=FGH:W4@6"U0<FEO<FET>3\`3F%S
M=&%V:70@=GIDX6QE;ND@<V5R=F5R>2!T86LL(+YE(&)U9&]U('#X[7-T=7!N
MZ2!Z('!O<G3A;'4N`$YA<W1A=F5N[2!6X6UI('!R969E<F]V86[I:&\@:F%Z
M>6MA+"#H87-O=NEH;R!PX7-M82!A('1Y<'4@9&%T=6UU+@!.87-T879E;NT@
M<&_HX71EZ&[M(&%P;&EK86-E+"!B87)E=F[I:&\@;6]T:79U+"!O8FYO=F]V
MX6[M('-T<N%N96L@82!D86RY[6-H(&UOOFYO<W3M('IO8G)A>F5N[2X`3F%S
M=&%V96[M`$YA<W1A=F]V86/M(&MO;F9I9W5R8>AN[2!S:W)I<'1Y('!R;R!A
M:W1U86QI>F%C:2!J<V]U(&1O<W1U<&[I`$[L:W1E<N$@;>US=&$@;'IE(&YA
M<W1A=FET(',@=.UM=&\@<&%R86UE=')E;3H@`%-E>6-H96QL97,`4V3M;&5N
MZ2!S;&^^:WD`4V3M;&5T('!ON71O=F[M('-L;[YK>0!39.UL970@<&^Y=&]V
M;NT@<VQOOFMY(',@:FEN_6UI('6^:79A=&5L:2X`3F%K=7!O=N%N[0!+<N%T
M:^D@<VAR;G5T[0!-[&QY(&)Y(&+]="!P^.US='5P;W;I(&ML[>AE(&1E9FEN
M;W;A;GD@<')O(';L=+EI;G4@;V1K87KY/P!-X2!B_70@:6UP;&EC:71N[2!N
M87-T879E;NT@<')O('9E;&OI(&)L;VMY(&-I=&]V86[I:&\@=&5X='4@>F]B
M<F%Z96[I(&YE8F\@=6MR>73I/R!,>F4@:F5D;F]D=;EE('#X97!N;W5T(&)E
M>B!O:&QE9'4@;F$@=OUB['(N`$UA:NT@<V4@:&QE9&%T(%!'4"!D871A('8@
M=.QL92!T97AT+W!L86EN('IP<N%V/P!-X2!S92!O:VYO('!R;R!V>71V;_AE
M;NT@>G!RX79Y('5Z87;X[70@<&\@=6QOOF5N[2!R;WIE<'-A;ND@>G!RX79Y
M/P!-X2!B_70@5N&Y('9E^&5J;OT@4$=0(&ML[>@@:6UP;&EC:71N["!P^&EP
M;VIO=N%N(&L@5F&Y:6T@>G!RX7;A;3\`6F]B<F%Z:70`6F]B<F%Z:70@=KEE
M8VAN>2!S;&^^:WD`6F]B<F%Z:70@=KEE8VAN>2!H;&%V:>AK>0!:;V)R87II
M="!S;6%Z86[I`%IO8G)A>FET(')E9'5K;W9A;ND@:&QA=FGH:WD`6F]B<F%Z
M:70@:6YF;W)M86-E(&\@96QE:W1R;VYI8VOI(&MO;F9E<F5N8VD`6F]B<F%Z
M:70@<&]U>F4@86MT:79O=F%NZ2!S;&^^:WD`6F]B<F%Z:70@;F5A:W1I=F[M
M`%IO8G)A>FET(&EK;VYU('!R;R!O9'-T<F%N[&[M('#X[6QO:"!Z92!Z<'+A
M=C\`6F]B<F%Z:70@<F]Z9.UL>2!M97II('-O=>AA<VYO=2!A('#X961C:&]Z
M[2!K;VYF:6=U<F%C[2X`6F]B<F%Z:70@Z&%S('!O<VQE9&[M:&\@</AI:&SA
MN65N[2!D;R!S>7-TZ6UU/P!:;V)R87II="!L96=E;F1U('8@>F]B<F%Z96[M
M('-C:'+A;FMY/P!:;V)R87II="!M;[YN;W-T('5D<KYE;NT@;W)I9VENX6QU
M`%IO8G)A>FET('-B[')AZ`!:;V)R87II="!NX6AL961Y('!O=7IE('!R;R!N
M97#X9>AT96[I('IP<N%V>3\`6F]B<F%Z:70@;N%H;&5D>2!V('1I<&5C:#\`
M6F]B<F%Z:70@;65N=2!O<&5R8>AN[2!L:;ET=2!P<F\@=&%B=6QK>3\`6F]B
M<F%Z:70@)7,@;65N=2!N86QE=F\_`%IO8G)A>FET(&EK;VYU('-T86AO=N%N
M[2!P;[ET>2!V(&QIN73L(&UE;G4_`%IO8G)A>FET(&]B<N%Z:WD`6F]B<F%Z
M:70@9&EA;&]G('!R;R!V;&%S=&YO<W1I(&)U;NQK('8@=&%B=6QKX6-H`%IO
M8G)A>FET(&1I86QO9R!V;&%S=&YO<W3M('1A8G5L96L`6F]B<F%Z:70@9&EA
M;&]G('9L87-T;F]S=.T@^.%D96L@=&%B=6QE:P!:;V)R87II="!I:V]N=2!F
M:6QT<F]VX6[M('8@;&FY=.P@;65N=3\`6F]B<F%Z:70@9&EA;&]G('9L87-T
M;F]S=.T@;V)RX7IK^0!:;V)R87II="!C96QK;W;]('!OZ&5T('IP<N%V('9E
M('-L;[YC93\`6F]B<F%Z:70@</AE;F]S`%#X96CA\FMY`$)R>FOI('#X96CA
M\FMY`%!O>F1N[2!P^&5HX?)K>0!0^&5HX?)K>2!V(&]K;VSM`%5KX7KA;F\`
M6FUE;KEI=`!:;65NN6ET(&YE8F\@<&]S=6YO=70@9&\@<V]U<V5D;NUH;R!B
M;&]K=2CY*2P@>B!C97-T>2!P<G9N[6UU`%9E7VQI:V]S=`!3:65R<F$@3&5O
M;F4`4F5G:7-T<F]V870@<V4`4&]D<&ES`$%L9V]R:71M=7,@<')O('!O9'!I
M<P!0;V1E<'-A;N$`4VEN9V%P=7(`5F5L:6MO<W0`5GEN96-H870@^F1ROF)U
M`%-L;W9E;G-K;P!3;&]V:6YS:V\`4V[LOF5N[0!3;NQH;W;A('#X96CA\FMA
M`%-N[&AO=ND@</AE:.'R:WD`4F%N;NT@<V[L:&]VZ2!P^&5HX?)K>0!0;WID
M;NT@<V[L:&]VZ2!P^&5HX?)K>0!3;NQH;W;A('!O:W+]=FMA.@!6;V1N[2!E
M:W9I=F%L96YT('!R;R!S;NUH.B``J6%L86UO=6YO=GD@;W-T<F]V>0!3;VWA
M;'-K;P!0[7-N["!A(&+A<V[L`%-E=/CM9&ET('!O9&QE('!O^&%D[2!D;W)U
MZ&5N[0!3973X[61I="!P;V1L92!D871A`%-E=/CM9&ET('!O9&QE(&%D<F5S
M>2!O9&5S[6QA=&5L90!3973X[61I="!P;V1L92!V96QI:V]S=&D@>G!RX79Y
M`%-E=/CM9&ET('!O9&QE('#X961M['1U`%-E=/CM9&ET('!O9&QE('-O=79I
M<VQO<W1I`%-E=/CM9&ET('!O9&QE(&%D<F5S>2!P^.UJ96UC90!3;>QR('3X
M[63L;NT`6F1R;VIO=N$@861R97-A`$IIOF[M($%F<FEK80!*:6AO979R;W!S
M:_T@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S`$IIOF[M('!O;&]K;W5L90!0<F]S=&]R(&UE>FD@
M<V]U<V5D;NUM:2!B=?)K86UI`%!R;W-T;W(@;65Z:2!O8G-A:&5M(&$@:')A
M;FEC96UI('8@8G7R8V4`365Z97)N[6L`365Z97)Y`$]D<W1U<'D@82!M97IE
M<GD`J7!A;NQL<VMO`%-P86T`4VQOOFMA('!R;R!S<&%M.@!6<W1U<"!P<F\@
M>G9LX;ET;NT@>FYA:WD`6G9LX;ET;NT@>FYA:WD`2V]N=')O;&$@<')A=F]P
M:7-U`$MO;G1R;VQO<B!P<F%V;W!I<W4`2V]N=')O;&$@<')A=F]P:7-U(&1O
M:V]NZ&5N80!.86QE>F5NZ2!P<F%V;W!I<V[I(&-H>6)Y(&YA('-T<N%N8V4N
M`%)O>F3L;&ET(&)U\FMU`%)O>F3L;&ET('-L;W5P96,`4F]Z9.QL:70@^.%D
M96L`4W!O<G0`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!:8>CA=&5K
M`%)O:R!Z8>CA=&MU`%-TX70@Z&D@<')O=FEN8VEE`%-T878`1F]R;>%T('5L
M;[YE;NT`56QI8V4`4/AEN6MR=&YU=/T`4V5Z;F%M(/AE=.QZ8V4`3V1S=')A
M;FET('#X[6QO:'4`3V1S=')A;FET(&1O;>EN;W;I(&IMZ6YO('H@861R97-Y
M`$]D<W1R86YI="#XX61K;W;A;NT_`%-T>6P@6T-34UT`3F4`4/AE7V1M['0`
M4/AE9&WL=`!0;VQE('#X961M['0`4&]D870`06MT:79O=F%T('-L;[YK=2AY
M*0!$;VQN[2!I;F1E>`#:<W#LN6[L`$MO;F9I9W5R86-E(&)Y;&$@^G-P[+EN
M["!Z;>QN[&YA+B!/8FYO=G1E('-T<N%N:W4N`-IS<.RY;ND@=6QOOF5N[2!Z
MX6QOOF[M(&MO;F9I9W5R86-E+@#:<W#LN6[I('5L;[YE;NT@>N%L;VAY(&MO
M;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N`"5S(&)Y;&\@^G-P[+EN["!Z87!S
MX6YO`%-U9.%N`$[A=G)H>0!3:')N=73M`%-V[73A;NT`6N%P860@4VQU;F-E
M`%-L=6YEZ&YO`%;]8VAO9"!3;'5N8V4`5OUC:&]D+WKA<&%D(%-L=6YC90!6
M_6-H;V0@4VQU;F-E.B``6N%P860@4VQU;F-E`%KA<&%D(%-L=6YC93H@`$AO
M<F[M(&EN9&5X`%!O9'!O<F$`4W5R:6YA;64`4/CM:FUE;NT`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QS:V\`J7;I9'-K;P!0^&5P;F]U="!K;VUP
M;WIIZ&[M(&UE=&]D=0!0^&5P;F]U="!N82!(5$U,(&MO;7!O>FEC:0!0^&5P
M;F]U="!N82!T97AT;W9O=2!K;VUP;WII8VD`J7;]8V%R<VMO`%-Y;G1A>&]V
MX2!C:'EB82!V(&AL961A;NEM('1E>'1U`%/]<FEE`$)O=?AK80!";W7X:WD`
M5%-6('-O=6)O<@!486)U;&MA`%9L87-T;F]S=&D@=&%B=6QK>0!6;&%S=&YO
M<W1I('1A8G5L:WD`5&%I=V%N`%1A:7=A;BP@<')O=FEN8VEE(,CM;GD`5&%D
MOFEK:7-TX6X`5&%N>N%N:64L(%-P;VIE;N$@<F5P=6)L:6MA`$/M;#H`VFMO
M;'D`5&5?>'0`5&5L969O;F[M(.CM<VQO`%1E<&QO=&$@>F$@<&]S;&5D;NT@
M:&]D:6YU.B``5&5P;&]T80!497!L;W1A.B``5GIO<B!P<F\@861M:6YI<W1R
M86-I`%!R;WIA=.UM;NTZ(`!0<F]Z873M;6[L('!O='9R>F5NX2"^X61O<W0`
M4')O>F%T[6UN["!P;W1V<GIE;F\`4V]U8F]R(&1E9FEN=6KM8^T@<&]D;>UN
M:WD@<&]UOFET[2!N96[M(&]B<V&^96X@=B!C;VYF+G!H<`!0;W5Z92!T97AT
M`%IA<F]V;N%N[2!T97AT=0!6<F-H('1E>'1U`,AT`%1H86IS:WD@*%1)4RTV
M,C`I`%1H86IS:V\`1.QK=6IE;64@>F$@<&]UONUVX6[M('-Y<W3I;74N`%#X
M[7!O;F$@<')O($944"!N96[M(&1O<W1U<&[A+@!3;&]U<&5C($]D.B!B>2!M
M[&P@8OUT(&]D:V%Z;W;A;CH`26YT96=R8>AN[2!A;&=O<FET;7D@=B!(;W)D
M92]+;VQA8B!N97!O9'!O<G5J[2`B)7,B`$UA8VEN=&]S:"!Z9')O:F]VZ2!R
M;WID=F]J96[M`$UA8VEN=&]S:"!Z9')O:F]VZ2!R;WID=F]J96[M(&WYOF4@
M8OUT('-T8;YE;F\@>B`E<RX`3F7Z<W#LN6[I(&YAZ'1E;NT@=/CM9'D@36%I
M;G1E;F%N8V4Z.@!">6QO('5Z87;X96YO(&]K;F\@<R!M;[YN;W-T;6DN(%5K
M;V[H96YO+@#:Z&5T("(E<R(@8GEL('-M87KA;BX`VNAE="`B)7,B(&)Y;"!U
M;&^^96XN`$%D;6EN:7-T<NUT;W(@<&]T^&5B=6IE(&YA:V]N9FEG=7)O=F%T
M('1R=F%LX2!P<N%V82!V('-Y<W3I;74L('!O:W5D('-I('#X96IE=&4@<&]U
MONUT('!RX79A+@!0^.UL;VAA(&YE8GEL82!N86QE>F5N82X`4&]U>F4@<W!O
M9&[M('-T<F%N80!$871A('8@:V%L96YDX?AI(&IS;W4@;F5P;&%T;N$`3VMN
M;R!P<F\@=GET=N'X96[M('IP<N%V(&YE;'IE(&]T97;X[70N(%KX96IM["!J
M<W1E(&YA<W1A=FEL:2!6X;D@<')O:&SMOF7H('1A:RP@86)Y(&)L;VMO=F%L
M('!O<'5P(&]K;F$_`$YE8GEL;R!U=F5D96YO($E$('!R;R!K;VYT86MT+"!N
M96)Y;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O(&)Y;&\@^G!L;NP@=GEN
M96-HX6YO+@!+;VYT86MT(&)Y;"#Z<W#LN6[L('#X:63A;B!D;R!68;EE:&\@
M861R97/A^&4N`$]B<V%H('-O=6)O<G4@>B!-86-I;G1O<VAE(&IE('IO8G)A
M>F5N(&[MOF4N`%-O=>AA<V[A('-L;[YK82AY*2`B)7,B(&)U9&4@</AE:FUE
M;F]VX6YA(&YA("(E<R(N`$YE;'IE('KM<VMA="!S97IN86T@=;YI=F%T96SY
M(',@</CM<W1U<&5M(&L@=.ET;R!S;&^^8V4`2R!O=NSX96[M('!O9&5P<V%N
MZ2!Z<'+A=GD@:F4@=/AE8F$@;V1D[&QE;OT@8FQO:R!S(%!'4"!P;V1P:7-E
M;2X`3F5B>6QO('5V961E;F\@240@9&ES=')I8G7H;NUH;R!S97IN86UU+"!N
M96)Y;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O(&)Y;&\@^G!L;NP@=GEN
M96-HX6YO+@!.96)Y;"!U=F5D96X@9&ES=')I8G7H;NT@<V5Z;F%M+@!2;WIE
M<'-A;N$@>G!RX79A(&)Y;&$@=6QOOF5N82!V("(E<R(@<VQOOF-E+@"I:69R
M;W9A8^T@;6^^;F]S=&D@;'IE('9Y=;[M="!P;W5Z92!P^&D@8F5Z<&7H;NEM
M('-P;VIE;NT@<R!W96)E;2`H:'1T<',I+@!59.%L;W-T(&)Y;&$@</AI9.%N
M82!D;R!68;EE:&\@:V%L96YDX?AE+@!3;W5B;W(@)7,@8GD@;>QL(&]B<V%H
M;W9A="!N87-T879E;NT@)7,N`%-O=6)O<B`E<R!B>2!M[&P@;V)S86AO=F%T
M(&[L:W1E<N$@>B!N87-T879E;NT@)7,N`%-O=6)O<B!N96QZ92!K;W#M<F]V
M870@<^%M(&1O('-E8F4N`%-O=6)O<B!N96]B<V%H=6IE(+[A9&[A(&1A=&$N
M`%-L;[YK82`B)7,B('6^(&5X:7-T=6IE`$[A>F5V('-L;[YK>2`B)7,B(&]B
M<V%H=6IE(&YE<&]V;VQE;ND@>FYA:WDN(%1O(&WYOF4@>G#Y<V]B:70@<')O
M8FSI;7DN(%!R;W/M;2!K;VYT86MT=6IT92!S=NEH;R!S>7-TZ6UO=NEH;R!A
M9&UI;FES='+A=&]R82X`4VQOOFMA("(E<R(@8GEL82!V>71V;_AE;F$L(&%L
M92!N96[M(&%K=&EV;W;A;F$N`%-L;[YK82`B)7,B(&)Y;&$@<VUA>N%N82P@
M86QE(&YE8GEL82!D96%K=&EV;W;A;F$N`%-L;[YK82`B)7,B(&YE8GEL82!V
M>71V;_AE;F$N(%1O=&\@:F4@:&SAN65N[2!S97)V97)U`%-L;[YK82`B)7,B
M(&YE8GEL82!S;6%ZX6YA+B!4;W1O(&IE(&ALX;EE;NT@<V5R=F5R=0!3;&^^
M:V$@(B5S(B!B>6QA(/IS<.RY;NP@=GET=F_X96YA+@!3;&^^:V$@(B5S(B!B
M>6QA(/IS<.RY;NP@<VUA>N%N82X`4VQOOFMA("(E<R(@8GEL82#Z<W#LN6[L
M('#X96IM96YO=N%N82!N82`B)7,B+@!.X7-L961U:NT@:&QA=FGH:WD@<')O
M(&UE<W-A9V4O<F9C.#(R('IP<N%V=0!.X7-L961U:NUC[2!S;W5B;W)Y(&)Y
M;'D@</AI;&^^96YY(&L@=.ET;R#HX7-T:3H`2F4@>F[A;>DL(+YE(&WS9"!P
M^&5S(&-E;&]U(&]B<F%Z;W9K=2!V($EN=&5R;F5T($5X<&QO<F5R=2!P^7-O
M8NT@<')O8FSI;7DL('!R;W1OOF4@<V4@=B!N[&T@=GES:WET=6IE(&-H>6)A
M+"!K=&5RZ2!S92!N96QZ92!V>6AN;W5T+B!*86MO(&[A<VQE9&5K(&WYOF4@
M8OUT(&[A:&]D;ND@>FAR;W5C96[M('1O:&]T;R!P<F]G<F%M=2P@8VAY8NQJ
M[6/M(&9U;FMC92!E9&ET;W)U(&YE8F\@;F5S<'+A=F[I('IO8G)A>F]VX6[M
M+B!0;VMU9"!J92!6X;D@<WES=&5MZ6T@5VEN;V1W<R`Y>"P@:F4@=F5L;6D@
M<')A=F3L<&]D;V)NZ2P@OF4@<V4@;V)J97;M(&-H>6)O=ND@:&SAN65N[2`G
M1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A(&)U9&5T92!M=7-E="!R97-T
M87)T;W9A="!P;^CM=&'H+EQN7&Y">6QI(&IS=&4@=F%R;W;A;FDN(%!R;W/M
M;2!S=&ES:V[L=&4@3TL@<&]K=60@<VD@</AE:F5T92!P;VMR8>AO=F%T('8@
M;?-D=2!P^&5S(&-E;&]U(&]B<F%Z;W9K=2X`261E;G1I=&$@(B5S(B!B>6QA
M('-M87KA;F$N`$]B<N%Z96L@8G5D92!Z;V)R87IE;BP@<')O=&^^92!O9&5S
M[6QA=&5L(&IE('9E(%9AN65M(&%D<F5SX?AI+@!0;W5Z92!N82!L97;I('-T
M<F%N[`!5;>US=.QN[2!B:6[A<F[M:&\@<V]U8F]R=2!';G501R!M=7/M(&+]
M="!Z863A;F\@9&\@=/CM9'D@0W)Y<'1?<&=P.CHN`%!ON71O=F[M('-E<G9E
M<B!G96YE<F]V86P@;N%S;&5D=6KM8^T@8VAY8F]VZ2!H;.&Y96[M.@!0;[ET
M;W9N[2!S97)V97(@9V5N97)O=F%L(&[A<VQE9'5J[6/M(&EN9F]R;6'H;NT@
M:&SAN65N[3H`4&^Y=&]V;NT@<V5R=F5R(&=E;F5R;W9A;"!NX7-L961U:NUC
M[2!H;.&Y96[M.@!38VARX6YK82`E<R!J92!J:;X@<'+A>F1NX2X`6G!RX79A
M("(E<R(@;V0@(B5S(B`H)60@8GET^2D@</AE:W)OZ&EL82!L:6UI="!P<F\@
M<W1A:&]VX6[M('!ON71Y+@!6>71VX?AE;N$@>G!RX79A(&)Y;&$@=7IA=OAE
M;F$N($MO;NCM;2X`6G!RX79A(&)Y;&$@=GEM87KA;F$N`%IP<N%V82!B>6QA
M(&]V[/AE;F$N`%IP<N%V82!B>6QA(&]V[/AE;F$N($]D97/M;&%T96PZ("5S
M+@!:<'+A=F$@>F%S;&%NX2!V("5S(&L@)7,@<R!P^&5D;>QT96T@(B5S(B!B
M>6QA('IO8G)A>F5N82X*5&]T;R!N97IA<G7H=6IE+""^92!Z<'+A=F$@8GEL
M82!P^&7H=&5N82!N96)O(+YE(&KM(&%D<F5SX70H:V$I(')O>G5M[&PH82DN
M`$[A>F5V+"!K=&5R_2!B=61E('!O=;YI="!P^&D@;V1K87IO=N%N[2!N82!S
M='+A;F-E('1V;W)B>2!Z<'+A=@!4^.UD82!(;W)D95]#<GEP=%]S;6EM93HZ
M('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN`$YE;'IE(&]T97;X[70@;VMN;R!S
M(&AE<VQE;2X@6OAE:FWL(&IS=&4@;F%S=&%V:6QI(%;AN2!P<F]H;.V^9>@@
M=&%K+"!A8GD@8FQO:V]V86P@<&]P=7`@;VMN83\`3F5L>F4@=6QOOFET(&YA
M<W1A=F5N[2`B)7,B+"!P<F]T;[YE(&IE:&\@=F5L:6MO<W0@</AE<^%H;&$@
M<&]V;VQE;OT@;&EM:70N`$YE8GEL82!N86QE>F5N82!A<&QI:V%C92!P<F\@
MZ'1E;NT@=&]H;W1O('1Y<'4@9&%T("@E<RDN`%1E>'0@4$=0('9E^&5J;NEH
M;R!K;.WH92!M^;YE(&+]="!P<F]H;.ED;G5T("5S+@!0;[YA9&]V86[]('-O
M=6)O<B!V($U3+51.148@</CM;&]Z92!N965X:7-T=6IE+@!0;[YA9&]V86[]
M('-O=6)O<B!V('II<"!P^.UL;WIE(&YE97AI<W1U:F4N`%!O=7IE(&YA('!R
M87;I(&$@;&5VZ2!S=')A;NP`4&]U>F4@;F$@<')A=ND@<W1R86[L`$]D97/M
M;&%T96P@=.ET;R!Z<'+A=GD@;V0@5N%S('!OOF%D=6IE('!O='9R>F5N[2`H
M365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXI('!O('#X9>AT96[M
M('IP<N%V>2X@4')O<^UM(&ML:6MN['1E("5S('!R;R!O9&5S;.%N[2!TZ71O
M('IP<N%V>2X`4V5R=F5R("(E<R(@8GEL('9Y;6%ZX6XN`%-E<G9E<B`B)7,B
M(&)Y;"!U;&^^96XN`%-E<G9E<B!N96)Y;"!S8VAO<&5N('9Y='9O^&ET(&UI
M;FEA='5R=2!T;VAO=&\@;V)RX7IK=2X`3F5L>F4@;F%H<F%D:70@<VEG;F%T
M=7)U+@!3:6=N871U<F$@8GEL82#Z<W#LN6[L(&YA:')A>F5N82X`0GEL82!O
M9'-T<F%N[&YA(+[A9&]S="!O('#X:6ALX;EE;NT@<')O("5S+@!0;[YA9&]V
M86[]('-O=6)O<B!N965X:7-T=6IE+@!0;[YA9&]V86[](/CA9&5K(&YE97AI
M<W1U:F4N`-IK;VP@8GEL('#X:63A;B!D;R!68;EE:&\@<V5Z;F%M=2#Z:V]L
M^2X`1&_H87-N_2!S;W5B;W(@(B5S(B!N965X:7-T=6IE+@!497AT('IP<N%V
M>0!497AT('IP<N%V>2!L>F4@<')O:&SI9&YO=70@)7,N`%1E>'0@;F%V<N%C
M96[I('IP<N%V>0!497AT(&YA=G+A8V5NZ2!Z<'+A=GD@;'IE('!R;VALZ61N
M;W5T("5S+@!497AT('IA<VQA;ND@>G!RX79Y`%1E>'0@>F%S;&%NZ2!Z<'+A
M=GD@;'IE('!R;VALZ61N;W5T("5S+@!0;W5Z92!N86AO^&4@82!D;VQE`%!O
M=7IE(&YA:&_X90!:=')A=&EL82!S92!P^&5N97-E;N$@9&%T82!Z('#X961C
M:&]Z[6AO(&MR;VMU+@!0^&5N97-E;OT@<V]U8F]R(&YE;'IE('5L;[YI="X`
M5;YI=F%T96QO=F$@:6YF;W)M86-E(&\@9G)E92]B=7-Y(&)Y;&$@^G-P[+EN
M["!U;&^^96YA+@!";&]K('=E871H97(N8V]M(&YE;NT@9&]S='5P;OTN`*[A
M9&[I(&II;ND@Z.%S=&D@;F5L>F4@=79N:73X('IP<N%V>2!Z;V)R87II="X`
M5&%T;R!S8VARX6YK82!N96]B<V%H=6IE(+YA9&[I('IP<N%V>2X`KN%D;ND@
M>B!M;[YN;W-T[2!N96IS;W4@9&]S='5P;NDN`$YE8GEL>2!N86QE>F5N>2"^
MX61NZ2#HX7-T:2P@:W1E<ND@8GD@8GEL;R!M;[YN;R!Z;V)R87II="!V(/CA
M9&MU+@!0^.UL:;D@;6YO:&\@>FYA:_D@=B!P;VQI+B!:861A;&D@:G-T92`E
M<R!Z;F%K^3L@;75S[71E('IA9&%T(&WI;NP@;F6^("5S('IN86OY+@!0^&D@
M=GEP<F%Z9/)O=N%N[2`E<R!D;[EL;R!K(&-H>6+L+B!4;W1O(&IE(&ALX;EE
M;NT@<V5R=F5R=0!0^&D@=GEP<F%Z9/)O=N%N[2!S8VARX6YK>2!D;[EL;R!K
M(&-H>6+L+B!4;W1O(&IE(&ALX;EE;NT@<V5R=F5R=3H@)7,`4/AI('9Y<')A
M>F3R;W;A;NT@<V-H<N%N:WD@9&^Y;&\@:R!C:'EB["X@5&]T;R!J92!H;.&Y
M96[M('-E<G9E<G4`3F%S=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U
M.B`E<R!N96)Y;"!P^&5N97-E;BX`3F%S=&%L82!C:'EB82!P^&D@</AE;F]S
M=2!S;W5B;W)U+B`E<R!N96WYOF4@8OUT(';L=+GM(&YEOB!M87AI;>%L;NT@
M<&]V;VQE;N$@=F5L:6MO<W0@*"5D(&)Y=/DI+@!.87-T86QA(&-H>6)A('#X
M:2!P^&5N;W-U('-O=6)O<G4Z(&)Y;&$@</AE;F5S96YA(&IE;B#HX7-T('-O
M=6)O<G4@)7,N`%#X:2!K;W#M<F]VX6[M('IP<N%V>2!Z("(E<R(@9&\@(B5S
M(B!D;[EL;R!K(&-H>6+L+B!4;W1O(&IE(&ALX;EE;NT@<V5R=F5R=0!0^&D@
M;6%ZX6[M('IP<N%V*'DI('IE('-L;[YK>2`B)7,B(&1ON6QO(&L@8VAY8NPN
M(%1O=&\@:F4@:&SAN65N[2!S97)V97)U`%#X:2!M87KA;NT@>G!RX79Y('IE
M('-L;[YK>2`B)7,B(&1ON6QO(&L@8VAY8NPN(%1O=&\@:F4@:&SAN65N[2!S
M97)V97)U`%#X:2!M87KA;NT@>G!RX78@9&^Y;&\@:R!C:'EB["X@5&]T;R!J
M92!H;.&Y96[M('-E<G9E<G4Z("5S`$YA<W1A;&$@8VAY8F$@</AI(&UA>N%N
M[2!U9.%L;W-T:3H@)7,N`$1ON6QO(&L@8VAY8NP@</AI('IO8G)A>F]VX6[M
M('3I=&\@Z.%S=&D@>G!RX79Y`%#X:2!O>FYAZ&]VX6[M('IP<N%V('9E('-L
M;[YC92`B)7,B(&1ON6QO(&L@8VAY8NPN(%1O=&\@:F4@:&SAN65N[2!S97)V
M97)U`%#X:2!I;7!O<G1U("5S(&1ON6QO(&L@8VAY8NPN`$YA<W1A;&$@8VAY
M8F$@</AI(&EM<&]R=&]VX6[M(&MO;G1A:W1U+@!.87-T86QA(&-H>6)A('#X
M:2!I;7!O<G1O=N%N[2!U9.%L;W-T:3H@)7,N`%#X:2!I;7!O<G1O=N%N[2!I
M0V%L96YD87(@9&%T(&1ON6QO(&L@8VAY8NPN`$YA<W1A;&$@8VAY8F$@</AI
M(&EM<&]R=&]VX6[M(/IK;VQU.B`E<RX`3F%S=&%L82!C:'EB82!P^&D@:6UP
M;W)T;W;A;NT@=;YI=F%T96QO=GD@:6YF;W)M86-E(&\@9G)E92]B=7-Y.B`E
M<RX`0VAY8F$@=B!K;VYF:6=U<F'H;NUM(&9O<FUU;.'X:2X@6OAE:FWL(&IS
M=&4@=GEN96-H86QI('!OOF%D;W9A;ND@<&]L92X`4/AI('#X97-U;G4@>G!R
MX78@>B`B)7,B(&1O("(E<R(@9&^Y;&\@:R!C:'EB["X@5&]T;R!J92!H;.&Y
M96[M('-E<G9E<G4`3F%S=&%L82!C:'EB82!P^&D@<')O=N%D[&[M('IA9&%N
MZ2!O<&5R86-E('8@861R97/A^&DN(%!R;W/M;2!Z:W5S=&4@=&\@<&]Z9.QJ
M:2X`4/AI('5K;.%DX6[M('3I=&\@<F]Z97!S86[I('IP<N%V>2!D;[EL;R!K
M(&-H>6+L+@!0^&D@;V1E<^ULX6[M(%9AN>T@>G!RX79Y.B`E<R!D;[EL;R!K
M(&-H>6+L`$YA<W1A;&$@8VAY8F$@</AI(&%K='5A;&EZ86-I(&MO;G1A:W1U
M+B!0<F]S[6T@>FMU<W1E('1O('!O>F3L:FDN`$YA<W1A;&$@8VAY8F$@</AI
M(&%K='5A;&EZ86-I(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2X@4')O<^UM('IK
M=7-T92!T;R!P;WID[&II+@!.87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C
M:2!U9.%L;W-T:3H@)7,N`%IP<N%V82!N96]B<V%H;W9A;&$@=B!TZ71O(.CA
M<W1I(+[A9&[]('1E>'0`5&%T;R!(5$U,('IP<N%V82!O8G-A:'5J92!O8G+A
M>FMY+@!4871O($A434P@>G!RX79A(&]B<V%H=6IE(&]B<N%Z:WDN($)L;VMO
M=F%NZ2!O8G+A>FMY('9Y<&%D86KM(&[A<VQE9&]V;NPZ`%1E;G1O($E-05`@
M<V5R=F5R(&YE<&]D<&]R=6IE('-D[6QE;NT@<VQOOF5K+@!496YT;R!V9?AE
M:F[](%!'4"!K;.WH(&)Y;"!P^&EL;[YE;B!K92!Z<'+A=NPN`%1A=&\@86MC
M92!N96[M(&UOOF[A+@!4871O(&%K8V4@;F5N[2!D;W-U9"!I;7!L96UE;G1O
M=N%N82X`5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!R87(@87)C:&EV+@!4
M;W1O(&YE=GEP863A(&IA:V\@<&QA=&[]('II<"!S;W5B;W(N`%1O=&\@;F5V
M>7!A9.$@:F%K;R!P;&%T;ND@Z.US;&\@:V%R='DN`%1E;G1O(&]V;&%D8>@@
M=6UOOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@8G+A;GD@</AI('!O=;YI=.T@2%144"!!
M4$D`5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO
M8^T@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@8G+A;GD@</AI
M('!O=;YI=.T@2%144"!!4$D`5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M
M;.%N[2!Z<'+A=B!P;VUO8^T@4TU44"!D;R!6;V1A9F]N92!)=&%L>2!B<N%N
M>2!P;W5Z92!P<F\@Z.US;&$@<&]S:WET;G5TZ2!6;V1A9F]N96TN($UU<^UT
M92!M[70@96UA:6QO=OT@^NAE="!U(%9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN`%1O=&\@<&]L92!J92!N=71NZ2!V>7!L;FET+@!4;W1O
M('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L82X`5&]T;R!P
M;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&-E;.$@Z.US;&$@82!D=F]J=&7H
M:W4N`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!O<VUIZ&MO=ND@
MZ.US;&$N`%1O=&\@<&]L92!M=7/M(&+]="!S97IN86T@8V5L_6-H(.CM<V5L
M(&]D9.QL96[]8V@@Z.%R:V]U(&YE8F\@;65Z97)O=0!4;W1O('!O;&4@;75S
M[2!B_70@<&QA=&[I(.CM<VQO+@!4;W1O('!O;&4@;75S[2!P8G-A:&]V870@
M8F%R979N_2!K\V0@=B"Y97-T;N%C:V]VZ6T@4D="(&9O<FWA='4L(&YA</@N
M("<C,3(S-&%F)RX`5&5N=&\@9F]R;75LX?@@:FF^(&)Y;"!Z<')A8V]VX6XN
M`%1O=&\@:F4@)7,N`%1O=&\@:F4@;V)J96MT($MO;&%B($=R;W5P=V%R=2X@
M2R!Z:&SI9&YU=.T@=&]H;W1O(&]B:F5K='4@:F4@>F%P;W3X96+M(&WM="!P
M;[ET;W9N[6AO(&ML:65N=&$L(&MT97+](')O>G5M[2!F;W)MX71U($MO;&%B
M($=R;W5P=V%R=2X@4')O('-E>FYA;2!T86MO=OUC:"!K;&EE;G3Y('!R;W/M
M;2!N87:Y=&EV=&4@)7,`5&]T;R!M^;YE(&-H=NUL:2!T<G9A="X@2G-T92!S
M:2!J:7-T[2P@OF4@8VAC971E('!O:W)AZ&]V870_`%1A=&\@>G!RX79A(&]B
M<V%H=6IE('-O=6)O<B!Z($UA8VEN=&]S:&4N`%1A=&\@>G!RX79A(&]B<V%H
M=6IE('#X[6QO:'4@9&EG:73A;&[L('!O9&5P<V%N;W4@<&]M;V/M(%,O34E-
M12X`5&%T;R!Z<'+A=F$@;V)S86AU:F4@</CM;&]H=2"Y:69R;W9A;F]U('!O
M;6]C[2!3+TU)344N`%1A=&\@>G!RX79A(&]B<V%H=6IE(&EN9F]R;6%C:2!O
M('-T879U(&1O<G7H96[M+"!A;&4@;>$@;F5Z;N%M_2!F;W)MX70N`%1A=&\@
M>G!RX79A(&YE=GEP863A(&IA:V\@<W!RX79N["!01U`@N6EF<F]V86[A('IP
M<N%V82X@0VAY8F$Z(`!4871O('IP<N%V82!N96[M('9E('-P<N%V;NEM(%!'
M4"!F;W)MX71U("AP;V1L92!21D,@,C`Q-2DN`%1A=&\@>G!RX79A(&YE;NT@
M=F4@<W!RX79NZ6T@4R]-24U%(&9O<FWA='4N`%1A=&\@>G!RX79A(&IE(&1I
M9VETX6QN["!P;V1E<'-A;N$@<&]M;V/M(%!'4"X`5&%T;R!Z<'+A=F$@:F4@
M9&EG:73A;&[L('!O9&5P<V%NX2!P;VUO8^T@4R]-24U%+@!4871O('IP<N%V
M82!J92"Y:69R;W9A;N$@<&]M;V/M(%,O34E-12X`5&%T;R!Z<'+A=F$@:F4@
MN6EF<F]V86[A('!O;6]C[2!01U``5&%T;R!Z<'+A=F$@9&\`5&%T;R!Z<'+A
M=F$@8GEL82!N87!SX6YA('8@:FENZ2!Z;F%K;W;I('-A9.P@*"5S*2!N9;X@
M5F&Y[2X@`%1O=&\@Z.US;&\@;75S[2!B_70@;F5J;>EN["!J961N82X`4V5R
M=F5R(&YE;?F^92!R;WIB86QI="!Z:7`@82!G>FEP('-O=6)O<GDN`%1E;G1O
M('-E<G9E<B!N97!O9'!O<G5J92!S9.UL96[M('-L;[YE:RX`5&5N=&\@<WES
M=.EM(&IE('8@<V]UZ&%S;F]S=&D@9&5A:W1I=F]V86[]+@!4871O(&AO9&YO
M=&$@;75S[2!B_70@Z.US;&\N`%1O=&\@;VMN;R!M=7/M(&+]="!V;VSA;F\@
M<&]U>F4@>B!O:VYA('9Y=';A^&5N[2!Z<'+A=BX`5&]T;R!O:VYO(&UUOF4@
M8OUT('9O;.%N;R!P;W5Z92!Z(&]K;F$@;6^^;F]S=.T`6F]B<F%Z96[M('!O
M9&QE('-O=79I<VQO<W1I`$CX;>QN[0!,[7-T:WD`R&%S`%-L961O=N%N[2#H
M87-U`$9O<FWA="#H87-U`%;]8NQR(.AA<W4`5&EM;W(M3&5S=&4`5&ET=6P`
M5&ET=6P@*'1I<"DZ`$MO;74`3F$@861R97-U`%!O:W5D('-I('#X96IE=&4@
M=GEB<F%T(';M8V4@<&]L[2P@>FWAZ&MN['1E(&$@9'*^=&4@:VSA=F5S=2!#
M;VYT<F]L("A00RD@;F5B;R!#;VUM86YD("A-86,I(&$@:VQI:V[L=&4@;F$@
M<&]L;[YK=2X`4&]K=60@<VD@</AE:F5T92!V>6)R870@=NUC92!P;VQOOF5K
M+"!Z;>'H:V[L=&4@:VSA=F5S=2!#;VYT<F]L("A00RD@;F5B;R!#;VUM86YD
M("A-86,I(&$@:VQI:V[L=&4@;F$@<&]L;[YK=2X`1&YE<P!0^&5P;F]U="!N
M82!(5$U,('ID<F]J`%1O9V\`5&]K96QA=0!:[71R80!4;VYG80!6<F-H`$AO
M<F[M('+A;2`H7W1O<"D`0V5L:V]VX2!V96QI:V]S="!P^.UL;V@Z`%#X96ML
M861Y`%-L;[YK82!K;[EE`%-L;[YK82!K;[EE.@!4<FEN:61A9"!A(%1O8F%G
M;P!3<'+A=F[L(&YE8F\@N7!A=&[L`-IT`%1U;FES:V\`5'5R96-K;P!4=7)E
M8VMY("A)4T\M.#@U.2TY*0!4=7)K;65N:7-TX6X`5'5R:W,@82!#86EC;W,@
M;W-T<F]V>0!4=79A;'4`3F%P:;ET92!68;EI('9O;&)U.@!5+E8N(&EN9&5X
M.B``55),`%523"!P<F\@>G!RX79U(&\@<W1A=G4@>F%S;&%NZ6AO('-K<FEP
M='4`55),.@!59V%N9&$`56MR86II;F$`5D93(&%D<F5SX?@@:F4@;F5P^.US
M='5P;OTN`%#X:2!R96=I<W1R86-I(&YE;'IE('#X:61A="!E>'1R82!UOFEV
M871E;'-KZ2#Z9&%J92X`3F5L>F4@>FWL;FET('!RX79A('!R;R!61E,@<V]U
M8F]R("(E<R(N`$YE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O<B`E
M<R\E<RX`3F5L>F4@>FWL;FET(&YA("5S+@!.96QZ92!S92!P^&EP;VII="!K
M(%-13"!S97)V97)U+@!.96QZ92!S92!P^&EP;VII="!P;VUO8^T@4U-,+@!.
M96QZ92!K;W#M<F]V870@5D93('-O=6)O<BX`3F5L>F4@=GET=F_X:70@5D93
M(&%D<F5SX?@@(B5S(BX`3F5L>F4@=GET=F_X:70@5D93(&%D<F5SX?@N`$YE
M;'IE('9Y='9O^&ET(%9&4R!S;W5B;W(N`$YE;'IE('9Y='9O^&ET('!RX7ID
M;OT@5D93('-O=6)O<BX`3F5L>F4@<F]Z8F%L:70@9&%T82X`3F5L>F4@=GEM
M87IA="`B)7,B+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P<N%Z9&[]+@!.96QZ
M92!V>6UA>F%T("5S+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P<N%Z9&[]+@!.
M96QZ92!R96MU<GII=NP@;V1S=')A;FET(%9&4R!A9')E<^'X+@!.96QZ92!V
M>6UA>F%T(%9&4R!A9')E<^'X+@!.96QZ92!V>6UA>F%T(%9&4R!A9')E<^'X
M.B`E<RX`3F5L>F4@=GEM87IA="!61E,@<V]U8F]R("(E<R(N`$YE;'IE('9Y
M;6%Z870@5D93('-O=6)O<BX`3F5L>F4@<F5K=7)Z:79N["!O9'-T<F%N:70@
M5D93.B`E<RX`3F5L>F4@=7+H:70@86MT=>%L;NT@861R97/A^"X`3F5L>F4@
M>FII<W1I="!P;V1R;V)N;W-T:2!O(&-E<G1I9FEKX71U+@!$969I;FEC92`E
M<R!N96[M(&1O<W1U<&[A+@!.96QZ92!P^&5S=6YO=70@5D93('-O=6)O<BX`
M3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(@(B5S(BX`5D93('-O=6)O<B!N
M96QZ92!O=&5V^.UT('!R;R!ZX7!I<RX`3F5L>F4@;W1E=OCM="!61E,@<V]U
M8F]R+@!.96QZ92!O=&5V^.UT(&%R8VAI=F]V86[]('-O=6)O<BX`3F5L>F4@
MZ.US="!Z('9F<W)O;W0@861R97/A^&4N`$YE;'IE('#X96IM96YO=F%T("5S
M(&YA("5S.B!C[6QO=N$@<VQOOFMA(&IIOB!E>&ES='5J90!61E,@861R97/A
M^"!N96QZ92!P^&5J;65N;W9A="X`5D93(&%D<F5SX?@@;F5L>F4@</AE:FUE
M;F]V870Z("5S+@!.96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R("(E<R(N
M`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(@)7,O)7,N`$YE;'IE('#X
M96IM96YO=F%T(%9&4R!S;W5B;W(N`$YE;'IE('IJ:7-T:70@:W;S='4`3F5L
M>F4@<')O=NES="`G;6MI<V]F<R<N`%1E;G1O(&1O:W5M96YT(%=O<F0@;F5L
M>F4@</AE;&^^:70`3F5L>F4@>F%P<V%T(&1O(%9&4R!S;W5B;W)U("(E<R(N
M`$YE;'IE('IA<'-A="!D871A(&1O(%9&4R!S;W5B;W)U("AS96QH86QO(&-O
M<'DH*2DN`$YE;'IE('IA<'-A="!D871A(&1O(%9&4R!S;W5B;W)U`$YE>F]D
M<&]V['IE;ND`3F5Z;V1P;W;L>F5NZ2!Z<'+A=GD`3V)N;W9I="!S;6%Z86[I
M`%!O9'1R:&YU=.D`571A:F5N[2!P^.UJ96UC:0!3=&]R;F\@>FWL;@!3=&]R
M;F]V870@<&]S;&5N[2!A:V-I`$YE;^AE:^%V86[A(&]D<&]V[.\@<V5R=F5R
M=2!N82!S<&]J96[M.B``3F5OZ&5KX79A;N$@;V1P;W;L[R!S97)V97)U.B``
M3F5V>7!L;NQN;P!.96]V;.%DX6[](&MO;7!O;F5N="!T>7!U.B`E<P!5;FEC
M;V1E("A55$8M."D`4W!O:F5NZ2!!<F%B<VOI($5M:7+A='D`5F5L:^$@0G)I
M=.%N:64`4W!O:F5NZ2!3=.%T>2!!;65R:6-KZ0!3<&]J96[I(%-TX71Y($UE
M;KEI;F]V_6-H(&]S=')O=OD`2F5D;F]T:WD`3F5Z;N%MZ0!.97INX6WI(&1A
M='5M`$YE>F[A;>$@<V-H^7IE`$YE>F[A;?T@</CM:F5M8V4`3F5Z;N%MZ2!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!.97INX6WI(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN`$YE>F[A;>D@=;YI=F%T96QS:^D@:FWI;F\@
M;F5B;R!H97-L;RX`3V1P;VII="!S;W7H87-N_2!P<G9E:P!5;FQO860@:&5S
M;&\`0F5Z96IM96YNZ0!.97!R:79I;&5G;W9A;ND@<VMR:7!T>2!N96UO:&]U
M('9Y=;[M=F%T(&9U;FMC82!6>6IM;W5T+TMO<.UR;W9A="]6;&^^('H@8F5Z
M<&7H;F]S=&[M8V@@9/EV;V3Y+B!+;&EK;NQT92!N82!/2R!A8GES=&4@=FED
M[&QI('1E8VAN:6-K;W4@>G!RX79U('H@;6]Z:6QL82YO<F<L(&MT97+A('9Y
M<W;L=&QU:F4L(&IA:R!N87-T879I="!S:W)I<'0@<')O('#X[7-T=7`@:V4@
M<V-H<N%N8V4N`$YE</AEZ'1E;ND`3F5N87-T879E;N$@8F%R=F$`1&5A:W1I
M=F]V870@<VQOOFMU*'DI`$YE<&]D<&]R;W9A;N$@</CM<&]N80!!:W1U86QI
M>F]V870`06MT=6%L:7IO=F%T("5S`$%K='5A;&EZ;W9A="!I;F9O<FUA8V4@
M;R!P^.UL;WIE`$%K='5A;&EZ;W9A="!S=&%V(&]D<&]V[61A:NUC[6AO`$%K
M='5A;&EZ;W9A="!UOFEV871E;&4`4VMR:7!T('!R;R!A:W1U86QI>F%C:2!B
M>6P@=GEM87KA;BX`4/AE;F]S`%:Y96-H;GD@<V]U8F]R>2!P<F\@;F%S=&%V
M96[M(&%P;&EK86/M(&)Y;'D@</AE;F5S96YY(&YA('-E<G9E<BX`5F5L:^$@
M=&ES:V%C[2!P[7-M96YA`%9E;&OI(/CM;7-KZ2#H[7-L:6-E`%5R=6=U87D`
M4&]UONUT(&%K='7A;&[M.B`E<P!0;W6^[70@:6UP;&EC:71N[2!H;V1N;W1U
M`%!O=;[M="!)34%0(&%K=&EV86-I('-L;[YE:S\`4&]UONUT(%-33`!0;W6^
M[70@<&]K=60@:FWI;F\O:&5S;&\@:G-O=2!J:6[I(&YEOB!P<F\@24U34"!S
M97)V97(N`%6^:79A=&5L`%6^:79A=&5L("5S(&YE;NT@;W!RX79N[&X@:R!P
M;W6^[7;A;NT@)7,N`$%D;6EN:7-T<F%C92!UOFEV871E;/D`5;YI=F%T96QS
M:^D@;6^^;F]S=&D`4F5G:7-T<F%C92!UOFEV871E;/D`3F$@=&]M=&\@<V5R
M=F5R=2!N96[M(&UOOF[A(')E9VES=')A8V4@=;YI=F%T96SY+@!5OFEV871E
M;'-KZ2!J;>EN;P!5OFEV871E;'-KZ2!J;>EN;SH`5;YI=F%T96QS:^D@:FWI
M;F\Z(`!397IN86T@=;YI=F%T96SY.@!5>F)E:VES=.%N`%9&4R!A9')E<^'X
M(&YE97AI<W1U:F4N`$1O=F]L96[A`$YA;&5Z96[A('!L871NX2!M[7-T82!Z
M86AR;G5J[3H@`%!L871N;W-T`$AO9&YO=&$@=B!M:6YU=.%C:"X`2&]D;F]T
M>0!6>6)R86[I(&AO9&YO='D@>@!686YU871U`%!R;VWL;F[I`%9E;F5Z=65L
M80!396QH86QA('9E<FEF:6MA8V4@+2!T871O('IP<N%V82!M;VAL82!B_70@
M>F9A;+EO=N%N82X`5F5R>F4`5F5R<VEO;B!#;VYT<F]L`%9E<G1I:^%L;NT@
M>F%R;W9NX6[M`%9E<G1I:^%L;NT@;V1S='5P`%9E<G1I:^%L;NTZ`%9E;&UI
M('9Y<V]KX0!6:65T;F%M`%9I971N86US:WD@*%9)4T-)22D`6F]B<F%Z:70`
M>F]B<F%Z:70@)7,`6F]B<F%Z:70@)7,@=F7X96IN_2!K;.WH`%IO8G)A>F5N
M[2!(5$U,(&]B<V%H=2!V(&YO=NEM(&]K;NP`6F]B<F%Z:70@;W-O8F[M('!R
M:7;A=&[M(&ML[>@`6F]B<F%Z:70@;W-O8F[M('9E^&5J;OT@:VSMZ`!:;V)R
M87II="!S;W5V:7-L;W-T`%IO8G)A>FET(&UI;FEA='5R>0!:;V)R87II="!E
M>'1E<F[M('=E8G-T<N%N:W4`6F]B<F%Z:70@:F%K;R`E<P!:;V)R87IE;NT@
M</CM;&]H>2!V(&YO=NEM(&]K;NP`6F]B<F%Z96[M(&]B<V%H=2!V(&YO=NEM
M(&]K;NP`6F]B<F%Z:70@=63A;&]S=`!:;V)R87II="!Z<'+A=GD@=B`E<P!:
M;V)R87IE;NT@<V-H<N%N96L@<&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU.@!:
M;V)R87II="#Z:V]L`%IO8G)A>FET(&]B<N%Z:WD`4&%N;F5N<VOI($]S=')O
M=GDL($)R:71S:^D`4&%N;F5N<VOI($]S=')O=GDL(%4N4RX`5FER='7A;&[M
M('-L;[YK82`B)7,B(&)Y;&$@^G-P[+EN["!Z86QOOF5N82X`5FER='7A;&[M
M('-L;[YK>0!6:7)T=>%L;NT@<VQOOFMY('9YOF%D=6KM(&]Z;F'H96[M+@!/
M>FYAZ&5N[2!V:7)T=>%L;NT@<VQOOFMY`%9I9&ET96QN;W-T`%9I9&ET96QN
M;W-T.@!6;V1A9F]N92!)=&%L>2!P^&5S(%--5%``55!/6D]23DE4`%503UI/
M4D[,3LTA(2$@3T135%)!TE1%(%-+4DE05"!25<A.S"!:("5S+@!786QL:7,@
M86YD($9U='5N80!5<&]Z;W)N[&[M`%-T`%#X961P;W;L[R!P;^AA<^T`1&%T
M82!O('!OZ&%S[2!P;W-K>71U:F4`5V5A=&AE<BYC;VT`5V5B`%=E8B!S97)V
M97(`5/UD;NP`5NUT96IT90!6[71E:G1E('8@)7,`5NUT96IT92P@)7,`6N%P
M861N[2`H25-/+3@X-3DM,2D`6N%P861N[2`H25-/+3@X-3DM,34I`%KA<&%D
M;NT@4V%H87)A`$MT97)O=2!A<&QI:V%C:2!MX2`E<R!Z;V)R87II="!P;R!P
M^&EH;.&Y96[M(&1O('-Y<W3I;74_`$IA:_T@:F4@;V1D[&QO=F%C[2!Z;F%K
M/P!*86O](&IE('IN86L@<')O(&-I=&%C:3\`4/AI(&UA>N%N[2!Z<'+A=B!P
M^&5S=6YO=70@>G!RX79Y(&1O('-L;[YK>2!K;[EE(&WM<W1O(&]Z;F'H96[M
M(&IA:V\@=GEM87IA;ND_`$YA(&MT97+I('-T<N%N8V4@>F'H[70@</AI('IO
M8G)A>F5N[2!N;W;I('-C:'+A;FMY/P!5:VSA9&%T('1A:^D@</CM;&]H>2!P
M^&D@=6MLX63A;NT@;V1E<VQA;ND@<&^Y='D_`$MT97+I(&;A>F4`5F]L8F$@
M<F]ZN>WX96[M('!R;R!2:6-H(%1E>'0@961I=&]R+@!"[6SA(&QI<W1I;F$`
MJ>WX:V$`J>WX:V$@=B!#4U,@:F5D;F]T:^%C:`"I[?AK82`E<R!M96YU('9L
M979O("AZ;>QN82!S92!O8FIE=NT@</AI(&1A;+GM;2!P^&EH;.&Y96[M*3H`
MJ>WX:V$@=&%B=6QK>0!*961N;W1K82"Y[?AK>0"I[?AK83H`5VEK:0!6[71R
M`%)A;F[M(';M='(`4GEC:&QO<W0@=NQT<G4@=B!U>FQE8V@`5NUT<CH`5NUT
M<CH@`$UO=61R;W-T`%!RX6-E`$%D<F5S82!D;R!Z86WL<W1NX6[M`%1E;&5F
M;VX@9&\@>F%M['-T;N%N[0!8+5)E9@!8-3`Y=C,@>N%K;&%D;NT@;VUE>F5N
M[0!8-3`Y=C,@<F]ZN>WX96[I('!O=;YI=.T@:VSMZ&4`6#4P.78S(&%L=&5R
M;F%T:79N[2!J;>EN;R!O<V]B>0!8-3`Y=C,@:61E;G1I9FEKX71O<B!K;.WH
M90!8-3`Y=C,@<F]ZN>WX96[M`%)2`%)24E(`36%P82!986AO;R$`4F_H;NP`
M2F5M96X`06YO`$%N;RP@<V]U:&QA<^UM`%-N8;[M=&4@<V4@<W3A:&YO=70@
M>G!RX79Y('H@;N%S;&5D=6KM8^UC:"#ZZ'3Y.@!+;W#M<F]VX6[M+W#X97-O
M=7;A;NT@9&\@;F]VZ2!S;&^^:WDN`%9Y=';A^.UT92!P;V1S;&^^:W4@=79N
M:73X(`!6>71VX?CM=&4@<VQOOFMU(&YA(&YE:G9YN;GM(/IR;W9N:2X`2G-T
M92!V(%1%6%1/5LE-($W31%4N(%!O=;YI:G1E(%L\/ET@=&QAZ.UT:V$@:R!Z
M<.QT;NEM=2!P^&5P;G5T[2!D;R!765-)5UE'+@!.96)Y;&D@:G-T92!S<'+A
M=F[L(&]V[/AE;FDN`%#X96IM96YO=N%VX71E('-L;[YK=3H@`%IN86L@)UPG
M(&YE;?F^92!B_70@<V]UZ.%S=.T@5F&Y96AO(&IMZ6YA+@!.97-O=6AL87-I
M;&D@:G-T92!Z('1E<FWM;GD@<&]UOFET[2!T;VAO('1O('-Y<W3I;74L('!R
M;W1O('-E(&YE;?F^971E('#X:6ALX7-I="X`0GEL82!Z863A;F$@;F5P;&%T
M;N$@92UM86EL;W;A(&%D<F5S82X`3F5M87!O=F%L:2!J<W1E(+[A9&[A('!O
M;&4@>B!I;7!O<G1O=F%NZ6AO('-O=6)O<G4@:R!O9'!O=NUD86KM8^UM('!O
M;.UM('8@)7,N`$YE;>%T92!O<'+A=F[L;NT@<')O('IM[&YU('#X[7-T=7!O
M=OUC:"!P<N%V('!R;R!T=71O('-L;[YK=0!4871O('IP<N%V82!B>6QA('#X
M97!O<VSA;F$@=B`E)7,@;N%S;&5D=6KM8^UM('#X[6IE;6/Y;3H@)7,N`$WA
M=&4@)7,@;F]V_6-H('IP<N%V+@!-X71E(#$@;F]V;W4@>G!RX79U+@!-X71E
M(&%L97-P;_(@:F5D;G4@</CM;&]H=2P@:W1E<F]U(&IS=&4@9&]S=60@;F5P
M^&5N97-L:2X@2G-T92!S:2!J:7-T[2P@OF4@8VAC971E('!O<VQA="!T=71O
M('IP<N%V=2!B97H@</CM;&]H/P!">6QI(&IS=&4@;V1H;.&Y96YI('IE('-Y
M<W3I;74N`$YO=N$@<&^Y=&$@=B!NX7-L961U:NUC[2!S;&^^8V4Z`$YO=N$@
M<&^Y=&$@=B!NX7-L961U:NUC[6-H('-L;[YKX6-H.@!6;&^^=&4@Z.US;&\@
M;6]B:6QN[6AO('1E;&5F;VYU+"!P;W6^:6IT92!J96X@Z.US;&EC(&YE8F\@
M</CM<&%D;NP@)RLG('!R;R!M97II;N%R;V1N[2#H:7-L82X`375S[71E('IA
M9&%T('!L871N;W4@:&]D;F]T=2X`375S[71E(&MO;F9I9W5R;W9A="!D871A
M8N%Z:2!D870L('!O:W5D('-I('#X96IE=&4@<&]UONUV870@4F5G:7-T<F%C
M92X`375S[71E(&MO;F9I9W5R;W9A="!61E,@8F%C:V5N9"X`375S[71E(&YE
M:F3X[79E('!O<'-A="!P<F]B;.EM(&$@<&]TZ2!H;R!O9&5S;&%T+@!-=7/M
M=&4@>F%D870@86QE<W!O\B!J961N;VAO('#X[6IE;6-E+@!-=7/M=&4@>F%D
M870@55),(&YA(&MT97+I(&)U9&4@=&5N=&\@;V1K87H@=6MA>F]V870`0VAC
M971E+6QI('#X9>CM<W0@='5T;R!Z<'+A=G4L(&UU<^UT92!Z861A="!H97-L
M;R!68;EE:&\@<')I=N%T;NUH;R!01U`@:VSMZ&4N`$-H8V5T92UL:2!P^&7H
M[7-T('1U=&\@>G!RX79U+"!M=7/M=&4@>F%D870@:&5S;&\@5F&Y96AO('!R
M:7;A=&[M:&\@4R]-24U%(&ML[>AE+@!-=7/M=&4@;F5J<')V92!V>6)R870@
M8^UL;W9O=2!S8VARX6YK=2X`375S[71E('9Y8G)A="#ZZ&5T+"!K=&5R_2!C
M:&-E=&4@<VUA>F%T+@!-=7/M=&4@;F5J<')V92!V>6)R870@96UA:6QO=F]U
M(&%D<F5S=2X`375S[71E('9Y8G)A="!S97)V97(L(&MT97+](&)U9&4@<VUA
M>N%N+@!-=7/M=&4@;F5J9/CM=F4@=GEB<F%T(&%L97-P;_(@:F5D;G4@>G!R
MX79U+@!-=7/M=&4@>F%D870@</CM:F5M8V4N`$UU<^UT92!V>6)R870@=;YI
M=F%T96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@<VUA>N%N;RX`375S[71E('IA
M9&%T('6^:79A=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B=61E(&]D<W1R86[L;F\N
M`$UU<^UT92!Z861A="!A;&5S<&_R(&IE9&5N('-O=6)O<B!P^.UL;VAY+@!.
M975V961L:2!J<W1E('6^:79A=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B=61E('#X
M:63A;F\N`$YE=79E9&QI(&IS=&4@=;YI=F%T96QS:^D@:FWI;F\@<')O(&%K
M='5A;&EZ86-I+@!-=7/M=&4@>F%D870@86MC:2P@:W1E<N$@8G5D92!P<F]V
M961E;F$N`$UU<^UT92!Z861A="!J;>EN;R!N;W;I(&MA=&5G;W)I92X`5&%T
M;R!Z<'+A=F$@8GEL82!P^&5S;>QR;W;A;F$@;F$@)7,@=B`E)7,N`$YA('1U
M=&\@>G!RX79U(&)Y;&\@;V1P;W;L>F5N;R!V("5S+@!3;&^^:V$@(B5S(B!N
M96)Y;&$@86MT:79O=N%N82X@5&]T;R!J92!H;.&Y96[M('-E<G9E<G4`4VQO
MOFMA("(E<R(@;F5B>6QA(&1E86MT:79O=N%N82X@5&]T;R!J92!H;.&Y96[M
M('-E<G9E<G4`VG-P[+EN["!J<W1E(&%K=&EV;W9A;&D@<VQOOFMU("(E<R(`
MVG-P[+EN["!J<W1E(&1E86MT:79O=F%L:2!S;&^^:W4@(B5S(@!68;EE("5S
M(')E;&%C92!B>6QA('5K;V[H96YA+B!/<.QT('-E('#X:6AL8;ET92P@<')O
M<^UM+@!68;EE(&5M86EL;W;A(&%D<F5S80!68;EE($]D+6MO:&\Z(&%D<F5S
M83H`5F&Y92!I;F9O<FUA8V4`5B!R96QA8VD@)7,@<V4@>FWL;FEL82!68;EE
M(&EN=&5R;F5T;W;A(&%D<F5S82X@6B!B97IP9>AN;W-T;NUC:"!D^79O9/D@
M<V4@;75S[71E(&]P['0@</AI:&SA<VET+@!68;EE(&IMZ6YO`%9AN64@4$=0
M('9E^&5J;NDO<')I=N%T;NT@:VSMZ&4`5N&Y('!R:7;A=&[M(&ML[>@`5N&Y
M('9E^&5J;OT@:VSMZ`!68;EE(%,O34E-12!V9?AE:F[I+W!R:7;A=&[M(&-E
M<G1I9FEKX71Y`%9AN64@^NAT>3H`5N&Y(&]V[/AO=F%C[2!S>7-TZ6T@;F5P
M;V1P;W)U:F4@=OUP:7,@=;YI=F%T96SY(&%N96)O('1A=&\@;6^^;F]S="!N
M96[M('#X[7-T=7!NX2!Z(&II;OUC:"!D^79O9/DN`%IDX2!S92P@OF4@=B!P
M<OEB[&AU(')E;&%C92`E<R!S92!Z;>QN:6P@5N&Y('!R;VAL[;YEZ"X@6B!B
M97IP9>AN;W-T;NUC:"!D^79O9/D@<V4@;75S[71E(&]P['0@</AI:&SA<VET
M+@!6X;D@<')O:&SMOF7H(&YE<&]D<&]R=6IE('IO8G)A>F5N[2!T;VAO=&\@
M='EP=2!O8G+A>FMU('8@=.QL92!Z<'+A=GDN`%;AN2!P<F]H;.V^9>@@;F5P
M;V1P;W)U:F4@='5T;R!M;[YN;W-T+@!68;EE('-O=>AA<V[I(.AA<V]VZ2!P
MX7-M;SH`5F&Y92!I;7!L:6-I=&[M('IN86MO=N$@<V%D82!P<F\@;V1E<^UL
MX6[M('IP<N%V.@!68;EE(&EM<&QI8VET;NT@;65T;V1A(+EI9G)O=N%N[2!P
M<F\@;V1E<^ULX6[M('IP<N%V.@!68;EE(&EM<&QI8VET;NT@:61E;G1I=&$`
M5F&Y92#Z<&QNZ2!J;>EN;SH`5F&Y92!Z<'+A=F$@8GEL82#Z<W#LN6[L(&1O
M<G7H96YA+@!68;EE(&YO=ND@:&5S;&\@<')O("5S(&IE.B`E<P!68;EE(&YA
M<W1A=F5N[2!B>6QO(&%K='5A;&EZ;W;A;F\@<')O('1R=N%N[2!TZ71O(')E
M;&%C92X`5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI>F]VX6YO+@!68;EE
M(&AE<VQO(&)Y;&\@<F5S971O=N%N;RX`5F&Y92!H97-L;R!B>6QO(')E<V5T
M;W;A;F\L('IK;VYT<F]L=6IT92!S:2!Z<'+A=GD@96QE:W1R;VYI8VOI('!O
MN71Y(&$@</AI:&QAN71E('-E(',@5F&Y[6T@;F]V_6T@:&5S;&5M+@!68;EE
M('9Z9.%L96[I('-E<G9E<GDZ`%9AN64@<VEG;F%T=7)A.@!*=6=O<VSA=FEE
M`%IA:7(`6F%M8FEE`%II;6)A8G9E`%II<'!Y`%M5:W+]="!C:71O=F%N_2!T
M97AT70!;KN%D;OT@</AE9&WL=%T`6TALX;EE;NT@<')O8FSI;75=`%M:;V)R
M87II="!C:71O=F%N_2!T97AT("T`6UIO8G)A>FET(&-I=&]V86[]('1E>'0@
M+2`E<R#XX61K^5T`6_CA9&5K("5S('H@)7-=`%]!9&UI;FES=')A8V4`7U-K
M<GETX2!K;W!I90#(95]R;N$@;&ES=&EN80!?0TQ)`%]+;W!I90!?1&%T851R
M964`4VUA>F%?=`!?4VUA>F%T(/CA9&5K`%]3;&^^:WD`7U-K=7!I;GD`7T[A
M<&]V[&1A`%])9&5N=&ET80!?5FQA<W1N;W-T:2!O8G+A>FMU+BXN`%]0;[ET
M80!?4/AI:&SAN65N[0!?3V1H;.&Y96[M`%]:9')O:F]V_2!K\V0@>G!RX79Y
M`%]-;V1I9FEK;W9A="!O9&MA>BXN+@!?36^^;F]S=&D`7U!RX79A`%]4:7-K
M`%]$^6QEOFET;W-T`$]?8FYO=FET("5S`%]/9'-T<F%N:70@;V1K87HN+BX`
M7T]D<&]V[&3L=`!6>5]H;&5D870`7UIA<VQA="!Z<'+A=G4`7TYA<W1A=F5N
M[0!?5FQA<W1N;W-T:2!T86)U;&MY+BXN`%]3;W5V:7-L;W-T`%]+;VUU`%]/
M8FYO=FET('-M87IA;ND`7U6^:79A=&5LZ0!?6F]B<F%Z:70@<V]U=FES;&]S
M=`!"[6SA(%]L:7-T:6YA`&%D<F5SX?@`</CM;&]H80!P<FEL;VAY+GII<`!B
M>73Y`&MA;&5N9.'X`&)E>G;L=/CM`&ML:6MN;W5T('ID90!S<N&^:WD`<V]U
M8F]R`&]D`'H@)7,@*"5S*2!R>6-H;&]S=.T@)7,@)7,`:#H`;VMA;;YI=.P`
M=B#X863L`&ML[>@`^.%D:_E=`'-O=6)O<B!S8VARX6YK>0!C:'EB;W;](&OS
M9"!M:VES;V9S("5D('#X:2!V>71VX?AE;NT@25-/+@!J;>EN;P"^X61N_0!N
M96[M(&EM<&QE;65N=&]VX6YO`&YE;NT@9&]S=60@:6UP;&5M96YT;W;A;F\`
M>N%P:7-N[6L`;F5B;P!P<F]C96YT`'!I>&5L^0!S=&]U<&%J[6/M`'IO8G)A
M>FET(')O>F3M;'D`<VUS,F5M86EL('IA('!O=;YI=.T@2%144`!C:'EB82!V
M('!R879O<&ES=0!C:'EB>2!V('!R879O<&ES=0!V>71R=F%LZ0!S97IN86T@
M^FMO;/D`<')O('!O='9R>F5N[2!N87!IN71E(&AE<VQO(&1V86MRX70`<VIE
M9&YO8V5N_0!B97H@;N%Z=G4`=GEB<F%T('6^:79A=&5L90!V0V%R9`!W.@!W
M96%T:&5R+F-O;0!68;EE(.AE<F[A(&QI<W1I;F$`5F&Y92!B[6SA(&QI<W1I
M;F$`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O;&]C86QE+V-S7T-:+VAE;'`N>&UL````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,34T-C<R`#$P-#$W,S8R-S8P`#`R,3$S-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/WAM;"!V
M97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TR(C\^"CPA+2T@)$AO
M<F1E.B!I;7`O;&]C86QE+V-S7T-:+VAE;'`N>&UL+'8@,2XQ."XV+C0@,C`P
M-B\P,2\S,"`Q-3HU.#HP-"!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UB=71T;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\
M=&ET;&4^5GET=F_X96[M(%IP<N%V>3H@VFMO;GD\+W1I=&QE/@H@("`@/&AE
M861I;F<^VFMO;GD\+VAE861I;F<^"B`@("`\<&%R83X*"5IA<VQA="!:<'+A
M=G4@>F&Y;&4@5N&Y(&5M86EL(':Y96T@</CM:F5M8_EM+B!*86MM:6QE(&ML
M:6MN971E(&YA(%IA<VQA="!:<'+A=G4L(%;AN2!E;6%I;"!J92!I:&YE9"!P
M;W-LX6X@82!N96QZ92!J[70@>G#L="X*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H)56QOOFET($1R869T('5L;[[M(&YE9&]K;V[H96YO=2!Z<'+A=G4@9&\@
M<V-H<N%N:WD@<R!NX7IV96T@)T1R869T>2<L(&1O(&MT97+I('-E(&QZ92!P
M^&5P;F]U="!P;VUO8^T@<F]L971O=NEH;R!M96YU:2!V(&QE=ND@Z.%S=&D@
M;6]D<NEH;R!N879I9V'H;NUH;R!P86YE;'4@=B!H;W)N[2#HX7-T:2!68;GM
M(')E;&%C92X@5'5T;R!Z<'+A=G4@;'IE(&1O:V]NZ&ET('!O>F3L:FDL('#X
M97!N=73M;2!S92!D;R!S8VARX6YK>2`G1')A9G1Y)RP@:VQI;G5T[6T@;F$@
M9&%N;W4@=6QOOF5N;W4@>G!RX79U+"!A('!A:R!K;&EK;G5T[6T@;F$@)U!O
M:W)AZ&]V870G+B!!8GD@<V4@5N%M('IP<N%V82!LZ7!E('9Y:&QE9.%V86QA
M('8@1')A9G1E8V@@:F4@=FAO9&[I(&YA<'-A="!0^&5D;>QT('IP<N%V>2!P
M^&5D('5L;[YE;NUM('IP<N%V>2!D;R!$<F%F=/DN(%!O('5L;[YE;NT@>G!R
MX79Y(&)U9&5T92!N879RX6-E;FD@9&\@4/CM8VAO>NT@6G!RX78@;F5B;R!D
M;R!S8VARX6YK>2!V92!K=&5RZ2!J<W1E(&)Y;&D@;F%P;W-L961Y+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"@E:<G6Y:70@6G!RX79U(&IE9&YO9'6Y92!Z
M<G6Y[2!Z<'+A=G4@82!N879RX73M(%;A<R!D;R!0^.UC:&]Z[2!:<'+A=B!N
M96)O(&1O('-C:'+A;FMY('9E(&MT97+I(&IS=&4@8GEL:2!N87!O<VQE9'DN
M"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C
M;VUP;W-E+6)U='1O;G,B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I
M;VXZ($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^06-T:6]N<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@4V5N9"!-97-S86=E(&QA=6YC:&5S('EO
M=7(@96UA:6P@=&\@=&AE(&EN=&5N9&5D(')E8VEP:65N="AS*2X@0F4@<W5R
M92!Y;W4@=V%N="!T;R!S96YD(&)E9F]R92!C;&EC:VEN9R!H97)E(&%S(&]N
M8V4@<V5N="!I="!C86YN;W0@8F4@=&%K96X@8F%C:RX*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@4V%V92!$<F%F="!P;&%C97,@86X@=6YF:6YI<VAE
M9"!M97-S86=E(&EN(&$@9F]L9&5R(&-A;&QE9"`G1')A9G1S)PIA8V-E<W-I
M8FQE(&)Y('1H92!P;W`M9&]W;B!B;W@@;VX@=&AE(')I9VAT('-I9&4@;V8@
M=&AE(&)L=64@;F%V:6=A=&EO;B!B87(@870@=&]P+B!9;W4@8V%N('1H96X@
M9FEN:7-H('1H92!M97-S86=E(&QA=&5R(&)Y('-W:71C:&EN9R!T;R!T:&4@
M)T1R869T<R<@9F]L9&5R+"!C;&EC:VEN9R!O;B!T:&4@<V%V960@;65S<V%G
M92!T;R!O<&5N(&ET+"!A;F0@=&AE;B!C;&EC:VEN9R!O;B`G4F5S=6UE)RX@
M0F4@<W5R92!T;R!P=70@82!S=6)J96-T(&]N('1H92!E;6%I;"!B969O<F4@
M>6]U('-A=F4@=&AE(&1R869T('-O('1H870@>6]U(&-A;B!E87-I;'D@:61E
M;G1I9GD@=VAI8V@@;65S<V%G92!Y;W4@=V%N="!W:71H:6X@=&AE($1R869T
M<R!F;VQD97(N($%F=&5R('-A=FEN9R!A<R!A($1R869T+"!Y;W4@87)E(')E
M='5R;F5D('1O('EO=7(@24Y"3U@@;W(@=VAA=&5V97(@9F]L9&5R('EO=2!W
M97)E('9I97=I;F<@;&%S="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M0V%N8V5L($UE<W-A9V4@9')O<',@=&AE(&UE<W-A9V4@:6X@<')O9W)E<W,@
M86YD('-I;7!L>2!R971U<FYS('EO=2!T;R!T:&4@24Y"3U@@;W(@=VAA=&5V
M97(@9F]L9&5R('EO=2!W97)E('9I97=I;F<@;&%S="X*("`@(#PO<&%R83X*
M/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UF<F]M
M(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^5GET=F_X96[M(%IP<N%V
M>3H@3V0\+W1I=&QE/@H@("`@/&AE861I;F<^(D]D(CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H)5FQOOG1E('ID92!68;EI('-P<N%V;F]U(&5M86EL;W9O=2!A
M9')E<W4N(%9AN64@96UA:6QO=N$@861R97-A(&)U9&4@<&]UOFET82!P^&D@
M;V1E<^ULX6[M('IP<F%V>2!V(&MO;&]N8V4@(D]D.B(N"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB
M/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($9R;VT\+W1I=&QE
M/@H@("`@/&AE861I;F<^)G%U;W0[1G)O;29Q=6]T.SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@16YT97(@>6]U<B!C;W)R96-T(&5M86EL(&%D9')E<W,N
M(%EO=7(@96UA:6P@861D<F5S<R!I<R!A=71O;6%T:6-A;&QY(&5N=&5R960@
M9F]R('EO=2!F;VQL;W=I;F<@)G%U;W0[1G)O;3HF<75O=#L@:6X@;W5T9V]I
M;F<@96UA:6PN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](F-O;7!O<V4M=&\B('-T871E/2)U;FMN;W=N(CX*("`@(#QT
M:71L93Y6>71V;_AE;NT@6G!RX79Y.B!+;VUU/"]T:71L93X*("`@(#QH96%D
M:6YG/B)+;VUU(CPO:&5A9&EN9SX*("`@(#QP87)A/@H)6F1E('9L;[YT92!E
M;6%I;&]V;W4HZ2D@861R97-U*'DI('3L8V@@8V\@8GD@;>QL:2!O8F1ROF5T
M(%;AN2!E;6%I;"X@4&]UOFEJ=&4@Z.%R:W4@:R!O9&3L;&5N[2!E;6%I;&]V
M_6-H(&%D<F5S+"!J[6[I(&EN=&5R<'5N:^AN[2!Z;F%K>2!Z</ES;V+](&-H
M>6)O=ND@:&SAN65N[2X@5'ET;R!A9')E<WD@<V4@;V)J97;M('8@:V]L;VYC
M92`B2V]M=3HB('8@;V1E<VQA;ND@>G!RX7;L+@H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UT;R(^"B`@("`\
M=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@5&\\+W1I=&QE/@H@("`@/&AE
M861I;F<^)G%U;W0[5&\F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E
M('1O(')E8V5I=F4@>6]U<B!M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E
M86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W
M:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q
M=6]T.U1O.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL+B`@"B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M8V,B
M('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y6>71V;_AE;NT@6G!RX79Y
M.B!+;W!I93PO=&ET;&4^"B`@("`\:&5A9&EN9SXB2V]P:64B/"]H96%D:6YG
M/@H@("`@/'!A<F$^"@E:9&4@=FQOOG1E(&5M86EL;W9O=2CI*2!A9')E<W4H
M>2D@=.QC:"!C;R!B>2!M[&QI(&]B9'*^970@:V]P:6D@5N&Y96AO(&5M86EL
M=2X@4&]UOFEJ=&4@Z.%R:W4@:R!O9&3L;&5N[2!E;6%I;&]V_6-H(&%D<F5S
M+B!4>71O(&%D<F5S>2!S92!O8FIE=NT@=B!K;VQO;F-E(")+;W!I93HB('8@
M;V1E<VQA;ND@>G!RX7;L+B!+;W!I92!S92!O8GGH96IN["!P;W/M;.$@;&ED
M96T@<R!N97#X[6W];2!ZX6IM96TL(&IE;B!P<F\@:6YF;W)M86-I+B!6N6EC
M:&YI(&%D<F5SX71I('IA:')N=73M('8@(DMO;74Z(B!A('8@(DMO<&EE.B(@
M<V4@8G5D;W4@=FED['0@:V1O(&)Y;"!Z86AR;G5T('8@;V)O=2!K;VQO;FOA
M8V@N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)C;VUP;W-E+6-C(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N
M.B!#8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M#8R9Q=6]T.SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@
M861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&-A<F)O;B!C;W!Y
M(&]F('EO=7(@;65S<V%G92X@4V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@
M82!C;VUM82X@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T-C.B9Q=6]T.R!I
M;B!O=71G;VEN9R!M86EL+B!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E
M;G0@=&\@<&5O<&QE(&]T:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET
M=&5N('1O(&1I<F5C=&QY(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@
M;V8@=&AE(&5M86EL(&%S('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C
M=&QY(&-O;F-E<FYE9"!A8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN
M("!!;&P@)U1O.B<@<F5C:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C
M86X@<V5E('1H92!E;G1I<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP
M:65N=',N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT
M<GD@:60](F-O;7!O<V4M8F-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET
M;&4^5GET=F_X96[M(%IP<N%V>3H@4VMR>73A($MO<&EE/"]T:71L93X*("`@
M(#QH96%D:6YG/B)3:W)Y=.$@2V]P:64B/"]H96%D:6YG/@H@("`@/'!A<F$^
M"@E:9&4@=FQOOG1E(&5M86EL;W9O=2CI*2!A9')E<W4H>2D@=.QC:"!C;R!B
M>2!M[&QI(&]B9'*^970@<VMR>71O=2!K;W!I:2!6X;EE:&\@96UA:6QU+B!0
M;W6^:6IT92#HX7)K=2!K(&]D9.QL96[M(&5M86EL;W;]8V@@861R97,L(&KM
M;ND@:6YT97)P=6YKZ&[M('IN86MY('IP^7-O8OT@8VAY8F]VZ2!H;.&Y96[M
M+B!4>71O(&%D<F5S>2!S92!O8FIE=NT@=B!K;VQO;F-E(")3:W)Y=.$@2V]P
M:64Z(B!V(&]D97-L86[I('IP<N%V["X@4VMR>73I(&MO<&EE(&IS;W4@>F%S
M;.%N>2!L:61E;2P@:W1E^.T@8GD@<VD@='5T;R!Z<'+A=G4@;>QL:2!P^&7H
M[7-T($)%6B!6S$1/3<T@;W-T871N[6-H(&%D<F5SX73Y("AZ86AR;G5T_6-H
M('8@(DMO;74Z(B!A('8@(DMO<&EE.B(I+B!0;W5Z92!6>2!A(&%D<F5SX71I
M('9E(")3:W)Y=.D@2V]P:6DB(';M(&\@4VMR>73I(&MO<&EI('1O:&]T;R!E
M;6%I;'4N(%1O=&\@<V4@8NR^;NP@<&]UONUVX2!P<F\@:6YF;W)M;W;A;NT@
M5F&Y:6-H(&YA9/CM>F5N[6-H(&\@:V]M=6YI:V%C:2!S(&II;OUM:2P@86YI
MOB!B>6II;N$@<W1R86YA(&\@=&]M(';L9.QL82X*("`@(#PO<&%R83X*/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8F-C(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@
M/&AE861I;F<^)G%U;W0[0F-C)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T
M:&]S92!T;R!R96-E:79E(&$@8FQI;F0@8V%R8F]N(&-O<'D@;V8@>6]U<B!M
M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A
M(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E
M<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T)C8SHF<75O=#L@:6X@
M;W5T9V]I;F<@;6%I;"X@0FQI;F0@8V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL
M>2!S96YT('1O('!E;W!L92!O=&AE<B!T:&%N(&1I<F5C="!A;F0@:6YD:7)E
M8W0@<F5C:7!I96YT<R`H)G%U;W0[5&\Z)G%U;W0[(&%N9"`F<75O=#M#8SHF
M<75O=#L@<F5C:7!I96YT<RD@=VAO(&YE960@=&\@<F5A9"!W:&%T(&ES(&)E
M:6YG('=R:71T96X@87,@=V5L;"!7251(3U54('1H92!O=&AE<B!R96-I<&EE
M;G1S(&MN;W=I;F<@=&AA="!T:&5Y(&%R92!R96-E:79I;F<@=&AE(&5M86EL
M+B!4:'5S("=B;&EN9"<@;65A;G,@=&AA="!T:&4@:61E;G1I='D@;V8@=&AE
M<V4@<F5C:7!I96YT<R!I<R!H:61D96X@9G)O;2!A;&P@;W1H97(@<F5C:7!I
M96YT<R!O9B!T:&4@96UA:6PL(&%N9"!O;FQY('EO=2!A;F0@=&AE>2!K;F]W
M('1H97D@9V]T(&$@8V]P>2X@66]U('1Y<&EC86QL>2!U<V4@=&AI<R!T;R!T
M96QL(&%N(&%U=&AO<FET>2!F:6=U<F4@=&AA="!Y;W4@87)E('1E;&QI;F<@
M<V]M96]N92!S;VUE=&AI;F<@=VET:&]U="!A;&%R;6EN9R!T:&4@<&5R<V]N
M('EO=2!A<F4@<V5N9&EN9R!T:&4@86-T=6%L(&5M86EL('1O+@H@("`@/"]P
M87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E
M+7-U8FIE8W0B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y6>71V;_AE
M;NT@6G!RX79Y.B!0^&5D;>QT/"]T:71L93X*("`@(#QH96%D:6YG/B)0^&5D
M;>QT(CPO:&5A9&EN9SX*("`@(#QP87)A/@H)6F1E('9L;[YT92!P^&5D;>QT
M(%9AN>T@>G!RX79Y+B!496YT;R!T97AT('-E(&]B:F5V[2!V(&MO;&]N8V4@
M(E#X961M['0Z(B!V(&]D97-L86[I('IP<N%V["X@4VYAOG1E('-E(&+]="!S
M=')UZ&[M(&$@=OUS=&F^;NTN(%#X961M['0@5F&Y[2!Z<'+A=GD@:F4@;F5J
M961N;V1UN>T@<VD@>F%P86UA=&]V870@:F%K('!R;R!6X7,@=&%K('!R;R!P
M^.UJ96UC92!A('1A:^D@:&\@;'IE('!O>F3L:FD@=GEUONUT('!R;R!T^.UD
M[&[M('IP<N%V(.AI('9Y:&QE9.%VX6[M(&EN9F]R;6%C[2X@4&]K=60@<&]U
MOFEJ971E(")/9'!O=NQD['0B(.AI(")0^&5P;W-L870B+"!P^&5D;>QT('1O
M:&\@=&\@96UA:6QU('-E(&YE;>QN[2!A(&IE(&MO<.UR;W;A;B!D;R!D86RY
M[6-H(&]D<&]V[&3M+"!A;&4@=GD@<W3A;&4@;?F^971E('#X:63A=F%T(&[L
M:F%KZ2!P;WINX6UK>2!D;R`B4/AE9&WL='4B+B!4;W1O(&IE('9E;&UI(&3Y
M;&6^:73I('!R;R!V>76^[7;A;NT@(E-O=79I<VQO<W1I(BP@>F%L;[YE;ND@
M;F$@(E#X961M['1U(B!P<F\@=/CM9.QN[2!68;EI8V@@>G!RX78N"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E
M+7-U8FIE8W0B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%-U
M8FIE8W0\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[4W5B:F5C="9Q=6]T
M.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE('-U8FIE8W0@
M;V8@>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[4W5B
M:F5C=#HF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@2V5E<"!I="!S:&]R="P@
M<VEM<&QE(&%N9"!D97-C<FEP=&EV92X@(%1H92!S=6)J96-T(&QI;F4@:7,@
M=&AE(&5A<VEE<W0@=V%Y(&9O<B!Y;W4@86YD('EO=7(@8V]R<F5S<&]N9&5N
M=',@=&\@<F5M96UB97(@=VAA="!W87,@:6X@=&AE(&5M86EL(&%N9"!T:'5S
M(&ES('9E<GD@:6UP;W)T86YT(&EN(&]R9V%N:7II;F<@>6]U<B!E;6%I;"!A
M;F0@9FEN9&EN9R!I;7!O<G1A;G0@;VYE<R!L871E<BX@($%L<V\L('=H96X@
M>6]U("=297!L>2<@;W(@)T9O<G=A<F0G(&%N9"!E;6%I;"!T:&ES('-U8FIE
M8W0@;&EN92!I<R!C;W!I960@;W9E<B!I;G1O('1H92!N97<@;65S<V%G92!A
M;F0@<V\@:7,@82!V86QU86)L92!W87D@;V8@=&5L;&EN9R!W:&%T(&UE<W-A
M9V5S(&=O('1O9V5T:&5R('1O(&9O<FT@82`F<75O=#MT:')E860F<75O=#L@
M;V8@82!C;VYV97)S871I;VXN("!(;W=E=F5R+"!I9B!T:&4@)U)E<&QY)R!O
M<B`G1F]R=V%R9"<@8V]N=&%I;G,@;F5W(&ED96%S+"!Y;W4@;6%Y('=A;G0@
M=&\@861D('-I;7!L92!M;V1I9FEC871I;VYS('1O('1H92`G4W5B:F5C="<@
M;&EN92!S;R!T:&4@<F5C:7!I96YT*',I(&-A;B!F;VQL;W<@=&AE('!R;V=R
M97-S:6]N(&]F('1H92`F<75O=#MT:')E860N)G%U;W0["B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;W!T
M:6]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E9Y='9O^&5N[2!:
M<'+A=GDZ($UOOFYO<W1I/"]T:71L93X*("`@(#QH96%D:6YG/B)-;[YN;W-T
M:2(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(`E4>71O(&UOOFYO<W1I(%;A
M;2!P;VUO:&]U="!V>71V;_AI="!Z<'+A=G4N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*"5!O:W5D('-I('#X96IE=&4@>FMO;G1R;VQO=F%T('!R879O<&ES
M+"!K;&EK;NQT92!N82`B2V]N=')O;&$@4')A=F]P:7-U(BX*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H)4&]K=60@<VD@</AE:F5T92!V:63L="!S97IN86T@
M</CM;&]H(&ME('IP<N%V["P@:VQI:V[L=&4@;F$@(E#X[6QO:'DB+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"@E0;VMU9"!S:2!P^&5J971E('5L;[YI="!K
M;W!I:2!68;GM('IP<N%V>2!D;R!S8VARX6YK>2`B4&]S;&%NZ2!:<'+A=GDB
M('IA=')H;NQT92!RX6UEZ&5K('9E9&QE(")5;&^^:70@2V]P:6DB+B!5;&^^
M=&4@<VD@:V]P:64@9/EL9;YI=/UC:"!Z<'+A=BP@8G5D;W4@<V4@5N%M(&AO
M9&ET('8@8G5D;W5C;G4L('!O:W5D(&)U9&5T92!C:'3M="!Z:FES=&ET(&MD
M;R!C;R#X96ML+B!.96[M(&1O<&]R=>AE;F\@=6MLX61A="!K8;YD;W4@>G!R
MX79U+"!J96QI:V^^(&QZ92!V96QM:2!J961N;V1UN64@</AE<^%H;F]U="!6
MX;D@;&EM:70@;F$@9&ES:W4@*&]B>G9LX;ET["!P;VMU9"!S<&]S[6SA=&4@
M</CM;&]H>2!S(&]B<N%Z:WD@82!V:61E;2DL(&$@=.UM('IN96UOOFYI="!P
M^.UJ96T@9&]V_6-H('IP<N%V+B!0;VMU9"!S:2!P^&5J971E('5K;.%D870@
M:V&^9&]U('!O<VQA;F]U('IP<N%V=2P@;'IE('1U=&\@9G5K8VD@86MT:79O
M=F%T('8@;F%S=&%V96[M(%9AN>T@261E;G1I='D@*$UOOFYO<W1I("TF9W0[
M($]S;V)N[2!);F9O<FUA8V4@+29G=#L@57!R879I="!)9&5N=&ET=2DN($1B
M96H@=&4@;F$@<&5R:6]D:6-KZ2!V>7!R87ID\F]VX6[M('3I=&\@<V-H<N%N
M:WD@*")0;W-L86[I(%IP<N%V>2(I+"!J:6YA:R!68;EE('-C<N%N:V$@8G5D
M92!N97!O=;YI=&5L;N$L(&IA:VUI;&4@<V4@=F5L:_UM(&UN;[YS=';M;2!Z
M<'+A=B!Z87!L;NTN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*
M/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B/@H@("`@/'1I=&QE/DUE<W-A
M9V4@0V]M<&]S:71I;VXZ($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^
M)G%U;W0[3W!T:6]N<R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5&AE<V4@3W!T:6]N<R!H96QP('EO=2!P<F5P87)E('EO=7(@;65S<V%G92X*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI8VL@)G%U;W0[4W!E;&P@
M0VAE8VLF<75O=#L@=&\@8VAE8VL@>6]U<B!S<&5L;&EN9RX*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@0VQI8VL@)G%U;W0[071T86-H;65N=',F<75O
M=#L@=&\@=FEE=R!A="!T:&4@8F]T=&]M(&]F('1H92!P86=E(&$@;&ES="!O
M9B!F:6QE<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X
M="!T;R`F<75O=#M3879E(&-O<'DF<75O=#L@=&\@<V%V92!A(&-O<'D@;V8@
M=&AI<R!M97-S86=E(&EN('EO=7(@)G%U;W0[4V5N="!-86EL)G%U;W0[(&9O
M;&1E<BX@4V%V92!C;W!I97,@;V8@:6UP;W)T86YT(&5M86EL<R!Y;W4@<V5N
M9"!S;R!T:&%T('EO=2!H879E('-O;65T:&EN9R!T;R!R969E<B!B86-K('1O
M(&QA=&5R(&%N9"!T;R!K965P(&%N(&%C8W5R871E(')E8V]R9"!O9B!W:&%T
M('=A<R!S86ED+B!792!D;R!N;W0@<F5C;VUM96YD('EO=2!S879E(&5V97)Y
M(&5M86EL('-I;F-E('1H96X@>6]U<B!D:7-K('-T;W)A9V4@<75O=&$@=VEL
M;"!B92!U<V5D('5P('%U:6-K;'D@*&5S<&5C:6%L;'D@=VAE;B!Y;W4@<V5N
M9"!A='1A8VAM96YT<RD@86YD('EO=7(@;6%I;&)O>"!W:6QL(&)E(&9U;&P@
M86YD('5N86)L92!T;R!R96-E:79E(&YE=R!I;F-O;6EN9R!E;6%I;"X@66]U
M(&-A;BP@:&]W979E<BP@='5R;B!T:&ES(&9E871U<F4@)V]N)R!A<R!Y;W5R
M(&1E9F%U;'0@=VET:&EN('EO=7(@261E;G1I='DL(&)Y(&=O:6YG('1O($]P
M=&EO;G,M)F=T.U!E<G-O;F%L($EN9F]R;6%T:6]N+29G=#M%9&ET('EO=7(@
M:61E;G1I=&EE<RX@0F4@8V%R969U;"!W:&5N('5S:6YG('1H:7,@;6]D:69I
M960@9&5F875L="!A<R!Y;W4@=VEL;"!N965D('1O('!E<FEO9&EC86QL>2!P
M=7)G92!Y;W5R("9Q=6]T.U-E;G0@36%I;"9Q=6]T.R!F;VQD97(@;W(@:70@
M=VEL;"!E=F5N='5A;&QY(&UA:V4@>6]U<B!M86EL8F]X(&9U;&P@86YD('5N
M=7-E86)L92X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B('-T871E/2)U;FMN;W=N(CX*("`@
M(#QT:71L93Y6>71V;_AE;NT@6G!RX79Y.B!0^&EL;[YI=#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SXB4/AI;&^^:70B/"]H96%D:6YG/@H@("`@/'!A<F$^"@E,
M>F4@</AI;&^^:70@<V]U8F]R>2!K(%9AN>T@>G!RX7;L+"!AZ&MO;&EV('!O
M=7IE(&IE9&5N('!O(&IE9&YO;2X*("`@(#PO<&%R83X*("`@(#QP87)A/DMR
M;VL@,3H@0G7O(&YA<&FY=&4@8V5S='4@82!J;>EN;R!S;W5B;W5R=2P@:W1E
M<OT@<VD@</AE:F5T92!P^&EL;[YI="!K92!Z<'+A=NP@;F5B;R!K;&EK;NQT
M92!N82!T;&'H[71K;R!0<F]H;.V^970@82!V>6)E<G1E(+[A9&%N_2!S;W5B
M;W(N($-E<W1A(&$@:FWI;F\@=&]H;R!T;R!S;W5B;W5R=2!B=61E('8@8F]X
M=2!0<FEL;[YI="X*("`@(#PO<&%R83X*("`@(#QP87)A/DMR;VL@,CH@5GEB
M97)T92!Z9&$@<V]U8F]R(&WA(&+]="!P^&EL;[YE;B!K92!Z<'+A=F4@:F%K
M;R!P^.UL;VAA+"#H:2!MX2!B_70@</CM;6\@=F4@>G!RX7;L+B!!9')E<^%T
M('3I=&\@>G!RX79Y(&UU<^T@;>UT(&5M86EL;W;]('!R;V=R86TL(&MT97+]
M(&UU('5M;[YN[2!P<F]H;.V^970@>G!RX79Y(',@</CM;&]H;W4@=B!T97AT
M=2!Z<'+A=GDL('!O:W5D(&YE;>$@=&%K;W;]('!R;V=R86TL('IP<N%V82!V
M>7!A9&%T(&IA:V4@<R!P^.UL;VAO=2!P^.UL;VAU+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^2W)O:R`S.B!+;&EK;NQT92!N82!T;&'H[71K;R`B4/AI;&^^
M(BX@3N%Z978@<V]U8F]R=2!A(&IE:&\@=F5L:6MO<W0@8G5D92!Z;V)R87IE
M;F$@=B!S97IN86UU('#X[6QO:"X@4GEC:&QO<W0@</AI9.%VX6[M('-O=6)O
M<OD@9&\@=&]H;W1O('-E>FYA;74@>N%L9;[M(&YA(')Y8VAL;W-T:2!68;EE
M:&\@<W!O:F5N[2!A;&4@=&%KZ2!N82!V96QI:V]S=&D@</AI:VSA9&%NZ6AO
M('-O=6)O<G4N(%!R;W/M;2!B=>]T92!T<G#L;&EV_2!A('9YZ&ME:G1E(&&^
M('-E('!R;V-E<W,@9&]K;V[H[2!A(&YE:VQI:V5J=&4@;F$@9&%LN>T@=&QA
MZ.UT:V$N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+6%T=&%C:"(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@071T86-H/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T%T
M=&%C:"9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA>2!A
M='1A8V@@9FEL97,@=&\@>6]U<B!M97-S86=E.R!O;FQY(&]N92!F:6QE(&UA
M>2!B92!A='1A8VAE9"!A="!A('1I;64N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83Y3=&5P(#$Z($5I=&AE<BP@='EP92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A
M(&9I;&4@=&AA="!Y;W4@=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@
M;W(@8VQI8VL@)G%U;W0[0G)O=W-E)G%U;W0[(&)U='1O;B!A;F0@<V5L96-T
M('1H92!F:6QE('1O(&)E(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD(&YA;64@
M;V8@=&AA="!F:6QE(&YO=R!A<'!E87)S(&EN('1H92!!='1A8VAM96YT(&)O
M>"X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,CH@1&5C:61E('=H971H
M97(@>6]U('=A;G0@=&AE(&9I;&4@=&\@8F4@=FEE=V5D(&%S(&%N(&%T=&%C
M:&UE;G0@;W(@:6YL:6YE9"!W:71H('1H92!R97-T(&]F('1H92!M97-S86=E
M+B!4:&4@<F5C96EV:6YG('!E<G-O;BAS*2!M86EL(')E861I;F<@<V]F='=A
M<F4@;75S="!B92!A8FQE('1O(&AA;F1L92!T:&4@9FEL92!T>7!E(&EN;&EN
M93L@:68@;F]T+"!T:&ES('!A<G0@=VEL;"!B92!V:65W960@87,@86X@871T
M86-H;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`S
M.B!#;&EC:R`F<75O=#M!='1A8V@F<75O=#L@8G5T=&]N+B!4:&4@9FEL92!N
M86UE(&%N9"!S:7IE('=I;&P@8F4@861D960@=&\@>6]U<B!L:7-T(&]F($%T
M=&%C:&UE;G1S+B!0;&5A<V4@;F]T92!T:&%T(&9O<B!L87)G92!F:6QE<R!A
M;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O;FYE8W1I;VYS+"!T:&4@<')O8V5S
M<R!O9B!U<&QO861I;F<@86YD(&%T=&%C:&EN9R!Y;W5R(&9I;&4@=&\@=&AE
M(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N(%!L96%S92!B92!P871I96YT(&%N
M9"!D;R!N;W0@8VQI8VL@;W1H97(@=&AI;F=S('=H:6QE('EO=2!A<F4@=V%I
M=&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/E9Y='9O^&5N[2!:<'+A=GDZ(%#X[6QO:'D\+W1I=&QE/@H@
M("`@/&AE861I;F<^(E#X[6QO:'DB/"]H96%D:6YG/@H@("`@/'!A<F$^"@E4
M871O('-E:V-E('IO8G)A>NT@<V5Z;F%M(':Y96-H('#X[6QO:"!V92!68;GM
M('IP<N%V["X@4&]K=60@<VD@</AE:F5T92!O9'-T<F%N:70@</CM;&^^96[]
M('-O=6)O<CH*("`@(#PO<&%R83X*("`@(#QP87)A/DMR;VL@,3H@6F%T<FAN
M['1E('+A;67H96L@=F5L9&QE('-O=6)O<G4L(&MT97+]('-I('#X96IE=&4@
M;V1S=')A;FET+@H@("`@/"]P87)A/@H@("`@/'!A<F$^2W)O:R`R.B!+;&EK
M;NQT92!N82`B3V1S=')A;FET(%#X[6QO:'4H>2DB"B`@("`\+W!A<F$^"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE
M;G1S(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8VAM
M96YT<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M!='1A8VAM96YT<R9Q
M=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S96-T:6]N(&1I
M<W!L87ES(&$@;&ES="!O9B!F:6QE<R!A;')E861Y(&%T=&%C:&5D('1O('EO
M=7(@;65S<V%G92X@5&\@1&5L971E(&%N(&%T=&%C:&5D(&9I;&4Z"B`@("`\
M+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($%C=&EV871E('1H92!C:&5C:RUB
M=71T;VX@;F5X="!T;R!T:&4@871T86-H960@9FEL96YA;64@>6]U('=A;G0@
M=&\@1&5L971E+@H@("`@/"]P87)A/B`*("`@(#QP87)A/E-T97`@,CH@0VQI
M8VL@)G%U;W0[1&5L971E($%T=&%C:&UE;G0H<RDF<75O=#LN"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M<')I;W)I='DB('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y6>71V;_AE
M;NT@6G!RX79Y.B!0<FEO<FET83PO=&ET;&4^"B`@("`\:&5A9&EN9SXB4')I
M;W)I=&$B/"]H96%D:6YG/@H@("`@/'!A<F$^"@E4871O(&UOOFYO<W0@;F%S
M=&%V[2`B6"U0<FEO<FET>2(@:&QA=FGH:W4@=F4@5N%M>2!P;W-L86[I('IP
M<N%V["X@(E@M4')I;W)I='DB(&IE(")P<V5U9&\@<W1A;F1A<F0B(&MT97+]
M(&IE('!O=;[M=N%N(&5M86EL;W;];6D@<')O9W)A;7D@:F%K;R!.971S8V%P
M92P@36]Z:6QL82P@3W!E<F$@82!/=71L;V]K('!R;R!U9.%N[2!P<FEO<FET
M>2#H:2!U<F=E;G1N;W-T:2!Z<'+A=GDN($5M86EL;W;I('!R;V=R86UY+"!K
M=&5RZ2!T;W1O(&YE<&]UONUV86KM+"!B=61E('1U=&\@Z.%S="!I9VYO<F]V
M870N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)C;VUP;W-E+7!R:6]R:71Y(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!0<FEO<FET>3PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M0
M<FEO<FET>29Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S
M971S('1H92`F<75O=#M8+5!R:6]R:71Y)G%U;W0[(&AE861E<B!O;B!Y;W5R
M(&]U=&=O:6YG(&UE<W-A9V4N(%1H92`F<75O=#M8+5!R:6]R:71Y)G%U;W0[
M('1A9R!I<R!A('-O<G0@;V8@)G%U;W0[<'-E=61O('-T86YD87)D)G%U;W0[
M('1H870@3F5T<V-A<&4L($UO>FEL;&$L($]P97)A+"!A;F0@3W5T;&]O:R!M
M86EL(&-L:65N=',@87!P96%R('1O(&%G<F5E(&]N+B!!;GD@;6%I;"!C;&EE
M;G1S('1H870@9&\@;F]T(&AA;F1L92!T:&ES(&AE861E<B!W:6QL('-I;7!L
M>2!I9VYO<F4@:70N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*
M("`\96YT<GD@:60](F-O;7!O<V4M<V%V92UA='1A8VAM96YT<R(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@4V%V92!!
M='1A8VAM96YT<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R;6EN97,@
M=VAE=&AE<B!T:&4@871T86-H;65N=',@:6X@>6]U<B!C;VUP;W-I=&EO;B!A
M<F4@<V%V960@=VET:"!T:&4@;65S<V%G92!W:&5N('-T;W)E9"!I;B!T:&4@
M<V5N="UM86EL(&9O;&1E<BX@($EF(")997,B+"!T:&4@871T86-H;65N="!D
M871A('=I;&P@8F4@<V%V960N("!)9B`B3F\B+"!T:&4@871T86-H;65N="!D
M871A('=I;&P@8F4@<W1R:7!P960@9G)O;2!T:&4@;65S<V%G92!A9G1E<B!I
M="!I<R!S96YT('1O(&%L;"!R96-I<&EE;G1S+B`@0VAO;W-I;F<@(DYO(B!W
M:6QL(&AE;'`@8V]N<V5R=F4@9&ES:R!S<&%C92!B>2!R96UO=FEN9R`H<&]T
M96YT:6%L;'D@;&%R9V4I(&%T=&%C:&UE;G0@:6YF;W)M871I;VX@9G)O;2!T
M:&4@<V%V960@;65S<V%G97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)C;VUP;W-E+6QI;FLM871T86-H;65N=',B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($QI;FL@071T86-H
M;65N=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H971H
M97(@=&AE(&%T=&%C:&UE;G1S(&EN('EO=7(@8V]M<&]S:71I;VX@87)E('-E
M;G0@87,@82!P87)T(&]F('1H92!M86EL(&UE<W-A9V4@;W(@=VAE=&AE<B!T
M:&]S92!A='1A8VAM96YT<R!A<F4@:V5P="!O;B!A(&QO8V%L('-E<G9E<BX@
M($EF(&%T=&%C:&UE;G1S(&%R92!L:6YK960L('1H92!R96-I<&EE;G0H<RD@
M;V8@>6]U<B!M97-S86=E('=I;&P@8F4@<')O=FED960@82!W96)L:6YK('=H
M97)E('1H97D@8V%N(&1O=VYL;V%D('1H92!A='1A8VAM96YT*',I+B`@3&EN
M:VEN9R!A='1A8VAM96YT<R!H87,@=&AE(&%D=F%N=&%G92!O9B!T<F5M96YD
M;W5S;'D@<F5D=6-I;F<@=&AE('-I>F4@;V8@;W5T9V]I;F<@;65S<V%G97,N
M("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA<R!T:&4@9&ES861V86YT86=E('1H
M870@=&AE(&-O;G1E;G0@;V8@=&AE(&%T=&%C:&UE;G1S(&-A;B!N;W0@8F4@
M9W5A<F%N=&5E9"!T;R!B92!A=F%I;&%B;&4@:6X@=&AE(&9U='5R92!S:6YC
M92!T:&4@871T86-H;65N="!D871A(&ES(&YO="!L;V-A=&5D('=I=&AI;B!T
M:&4@92UM86EL(&UE<W-A9V4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)S96%R8V@B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y6
M>6AL963A=N%N[2!:<'+A=GD\+W1I=&QE/@H@("`@/&AE861I;F<^5GEH;&5D
MX79A8^T@2W)I=.ER:6$\+VAE861I;F<^"B`@("`\<&%R83X*"59Y:&QE9.%V
MX6[M('IP<N%V('9E(%9AN6EC:"!S8VARX6YKX6-H(&QZ92!P<F]VZ7-T(&[L
M:V]L:6MA('+Y>F[];7D@>G#Y<V]B>2!V>6AL963A=N%N[2X*("`@(#PO<&%R
M83X*("`@(#QP87)A/DMR;VL@,3H@5FQOOG1E('1E>'0@9&\@<&]L[>AE:RP@
M:W1E<ND@<VD@</AE:F5T92!Z86AR;F]U="!D;R!V>6AL963A=F%C[6-H(&MR
M:73I<FGM+@H@("`@/"]P87)A/@H@("`@/'!A<F$^2W)O:R`R.B!6>6)E<G1E
M('1Y<"AY*2!Z<'+A=GDL(&MT97+I('-I('#X96IE=&4@>F%H<FYO=70@9&\@
M=GEH;&5DX79A8^UC:"!K<FETZ7)I[2X*("`@(#PO<&%R83X*("`@(#QP87)A
M/DMR;VL@,SH@5GEB97)T92!S8VARX6YK=2AY*2!K=&5RZ2!S:2!P^&5J971E
M('IA:')N;W5T(&1O('9Y:&QE9.%V86/M8V@@:W)I=.ER:>TN"B`@("`\+W!A
M<F$^"B`@("`\<&%R83Y+<F]K(#0Z($ML:6MN['1E(")6>6AL961A="(N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*"5!O:W5D(&[L:F%KX2!Z92!Z<'+A=B!O
M9'!O=NUDX2!V>6AL863A=F%C[6T@:W)I=.ER:>UM+"!P86L@</AE9&WL="!T
MZ71O('IP<N%V>2!B=61E('IO8G)A>F5N('9E(")6_7-L961C[6-H(%9Y:&QE
M9.%VX6[M(BX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT
M<GD@:60](G-E87)C:"(^"B`@("`\=&ET;&4^365S<V%G92!396%R8V@\+W1I
M=&QE/@H@("`@/&AE861I;F<^4V5A<F-H($-R:71E<FEA/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!9;W4@;6%Y('-E87)C:"!F;W(@;65S<V%G97,@9G)O
M;2!Y;W5R(&9O;&1E<G,@=7-I;F<@9&EF9F5R96YT('-E87)C:"!C<FET97)I
M82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,3H@16YT97(@=&5X="!T
M;R!T:&4@9FEE;&1S('EO=2!W86YT('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C
M<FET97)I82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,CH@0VAO;W-E
M('1H92!M97-S86=E(&9L86<H<RD@=&\@861D('1O('EO=7(@<V5A<F-H(&-R
M:71E<FEA+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`S.B!#:&]O<V4@
M=&AE(&9O;&1E<BAS*2!F<F]M('=H:6-H('1O('-E87)C:"!F;W(@=&AE(&UE
M<W-A9V5S+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`T.B!#;&EC:R`F
M<75O=#M396%R8V@F<75O=#LN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M($EF(&%N>2!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H(&-R:71E<FEA
M+"!T:&5N('1H92!S=6)J96-T<R!O9B!T:&5S92!M97-S86=E<R!W:6QL(&)E
M('-H;W=N(&EN('1H92`F<75O=#M396%R8V@@4F5S=6QT<R9Q=6]T.R!V:65W
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)F;VQD97(M;W!T:6]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/E-P<N%V82!38VARX6YE:SPO=&ET;&4^"B`@("`\:&5A9&EN9SY-;[YN;W-T
M:2!S8W+A;FMY/"]H96%D:6YG/@H@("`@/'!A<F$^"@E,97;]('-L;W5P96,@
M;V)S86AU:F4@=&QAZ.UT:V$@<')O(';]8NQR('-C:'+A;F5K+"!P;W3I(&-O
M(&IS=&4@=GEB<F%L:2!S8VARX6YK=2!J92!M;[YN;R!P<F]VZ7-T(&1A;ND@
M=GEH;&5DX7;A;NTN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*"5-Y<W3I;2!6
MX6T@;F%B[61D;F4@9&%LN>T@;6^^;F]S=&DN($)U[W1E(&]B>G9LX;ET["!O
M<&%T<F[M(',@;6^^;F]S=.T@<')O(&UA>N%N[2!Z<'+A=BP@<&]K=60@8VAY
M8F[L('6^:6IE=&4@=.ET;R!M;[YN;W-T:2P@</AI:F1E=&4@;R!68;EE('IP
M<N%V>2P@:W1E<ND@8G5D;W4@;V1P;W;M9&%T(&MR:73I<FEU(0H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^26UP;W)T;W9A="!M8F]X(%-O=6)O<CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H)5&%T;R!M;[YN;W-T('!R;W9E9&4@:6UP;W)T
M('-O=6)O<G4@*&9O<FWA='4@;6)O>"D@9&\@>G9O;&5NZ2!S8VARX6YK>2X@
M5GEB97)T92`Q("AJ961N=2D@<V-H<N%N:W4L(&1O(&MT97+I(&)U9&4@:6UP
M;W)T;W9A="!Z<'+A=GDL(&$@<&%K('9Y8F5R='EE('1U=&\@;6^^;F]S="X@
M4WES=&5M('-E('IE<'3A+"!K=&5R_2!M8F]X('-O=6)O<B!S:2!P^&5J971E
M(&EM<&]R=&]V870N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*
M/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(^"B`@("`\=&ET;&4^1F]L9&5R
M($UA;F%G96UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($]P=&EO
M;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@
M82!F;VQD97(@8GD@=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE
M(&QE9G0@8V]L=6UN+B`@3VYC92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C
M="!T:&4@;W!T:6]N('EO=2!W:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E
M<B!V:6$@=&AE('-E;&5C="!B;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@("`@66]U('=I;&P@8F4@<')O;7!T960@9F]R(&9U
M<G1H97(@;W!T:6]N<RX@($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P
M=&EO;BP@87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F
M;VQD97(@:68@>6]U(&1E;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^26UP;W)T(&UB;W@@1FEL93PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@("!4:&ES(&]P=&EO;B!W:6QL(&EM<&]R="!A(&UB;W@@
M9F]R;6%T(&9I;&4@:6YT;R!T:&4@9F]L9&5R(&]F('EO=7(@8VAO:6-E+B!#
M:&]O<V4@,2`H;VYE*2!F;VQD97(@=&\@:6UP;W)T('1H92!M97-S86=E<R!I
M;G1O(&%N9"!T:&5N('-E;&5C="!T:&ES(&]P=&EO;BX@66]U('=I;&P@=&AE
M;B!B92!T86ME;B!T;R!A('!A9V4@=&AA="!W:6QL('!R;VUP="!F;W(@=&AE
M(&UB;W@@9FEL92!T;R!I;7!O<G0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^
M/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUW:61G971S(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E;65N=#H@1&ES<&QA>3PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY3:&]W+TAI9&4@56YS=6)S8W)I8F5D/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!U<VEN9R!)34%0(&9O;&1E<B!S
M=6)S8W)I<'1I;VYS+"!S:&]W+VAI9&4@=&AE('5N<W5B<V-R:6)E9"!F;VQD
M97)S+B`@5&\@<W5B<V-R:6)E+W5N<W5B<V-R:6)E('1O(&$@9F]L9&5R+"!S
M96QE8W0@=&AE(&-H96-K8F]X(&YE>'0@=&\@=&AE(&9O;&1E<FYA;64@86YD
M('5S92!T:&4@4W5B<V-R:6)E+U5N<W5B<V-R:6)E(&]P=&EO;B!I;B!T:&4@
M1F]L9&5R($%C=&EO;B!D<F]P+61O=VX@;65N=2X*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/D5X<&%N9"!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($5X<&%N9"!A;&P@9F]L9&5R(&5N=')I97,N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY#;VQL87!S92!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($-O;&QA<'-E(&%L;"!F;VQD97(@96YT<FEE<RX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](F9I;'1E<G,B('-T871E/2)U;FMN;W=N(CX*
M("`@(#QT:71L93Y&:6QT<GDZ(%!O=;YI=.T\+W1I=&QE/@H@("`@/&AE861I
M;F<^4&]UONUVX6[M($9I;'1R;W9A8^UC:"!0<F%V:61E;#PO:&5A9&EN9SX*
M("`@(#QP87)A/@H)2VQI:V[L=&4@;F$@:6MO;FMU(")0;W6^[70@1FEL='(B
M('9E9&QE(&[A>G9U(")0^.UC:&]Z[2!:<'+A=GDB('8@>F]B<F%Z96[M('-C
M:'+A;FMY(',@4/CM8VAO>NUM:2!Z<'+A=F%M:2P@86)Y(&IS=&4@;V1F:6QT
M<F]V86QI('IP<N%V>2!V('-O=6QA9'4@<R!68;EI;6D@9FEL=')O=F%C[6UI
M('!R879I9&QY+B!.96)O('1A:^D@:VQI:V[L=&4@;F$@(E!O=;[M="!6N65C
M:&YY(%!R879I9&QA(B!V92!F:6QT<F]V86/M;2!M96YU+B!&:6QT<F]VX6[M
M(&YE;NT@<')O=N%D[&YO(&%U=&]M871I8VMY+@H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB9FEL=&5R<R(^"B`@("`\=&ET
M;&4^1FEL=&5R<SH@07!P;'D\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@
M1FEL=&5R(%)U;&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O
M;B!T:&4@)G%U;W0[07!P;'D@1FEL=&5R)G%U;W0[(&EC;VX@;F5X="!T;R!T
M:&4@24Y"3U@@;F%M92!I;B!T:&4@;6%I;&)O>"!V:65W('1O(&9I;'1E<B!A
M;&P@=6YD96QE=&5D(&UE<W-A9V5S(&%C8V]R9&EN9R!T;R!T:&4@<W!E8VEF
M:65D(')U;&5S+B`@3W(L(&%L=&5R;F%T979L>2P@8VQI8VL@;VX@)G%U;W0[
M07!P;'D@06QL(%)U;&5S)G%U;W0[(&EN('1H92!F:6QT97(@;65N=2X@($YO
M=&4@=&AA="!F:6QT97)I;F<@:7,@;F]T(&1O;F4@875T;VUA=&EC86QL>2X*
M("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M9FEL=&5R+65D:70M<G5L97,B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I
M;'1E<G,Z($5D:70@1FEL=&5R(%)U;&5S/"]T:71L93X*("`@(#QH96%D:6YG
M/D5D:70@66]U<B!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($-L:6-K(&]N(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(B!T;R!P<F]C
M965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L(&%N
M9"!E9&ET('1H92!C=7)R96YT;'D@86-T:79E('-E="!O9B!F:6QT97(@<G5L
M97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M
M961I="UB;&%C:VQI<W0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E
M<G,Z($5D:70@0FQA8VML:7-T/"]T:71L93X*("`@(#QH96%D:6YG/D5D:70@
M66]U<B!";&%C:VQI<W0\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K
M(&]N(")%9&ET('EO=7(@8FQA8VML:7-T(B!T;R!P<F]C965D('1O('1H92!P
M86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L(&%N9"!E9&ET('1H92!L
M:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U($%,5T%94R!R969U<V4@;6%I
M;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL
M=&5R+65D:70M=VAI=&5L:7-T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&
M:6QT97)S.B!%9&ET(%=H:71E;&ES=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY%
M9&ET(%EO=7(@5VAI=&5L:7-T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#
M;&EC:R!O;B`B161I="!Y;W5R('=H:71E;&ES="(@=&\@<')O8V5E9"!T;R!T
M:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E+"!A;F0@961I="!T
M:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S('EO=2!!3%=!65,@86-C97!T
M(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(F9I;'1E<BUO;BUL;V=I;B(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL
M=&5R<SH@1FEL=&5R(&]N($QO9VEN/"]T:71L93X*("`@(#QH96%D:6YG/D%P
M<&QY($9I;'1E<B!2=6QE<R!5<&]N($QO9V]N/SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@=&\@86QW87ES(&%P<&QY(&9I
M;'1E<G,@=VAE;B!F:7)S="!L;V=G:6YG(&]N=&\@24U0+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+61I<W!L87DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!O;B!2969R
M97-H/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY(&9I;'1E<B!R=6QE<R!W
M:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T;R!A;'=A>7,@87!P;'D@9FEL
M=&5R<R!W:&5N979E<B!Y;W5R('9I97<@=&AE($E.0D]8/PH@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6%N>2UM86EL8F]X(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!&:6QT97(@86YY($UA
M:6QB;W@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@9FEL=&5R(')U;&5S
M('1O(&%N>2!M86EL8F]X/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE
M8VL@=&AI<R!O<'1I;VX@:68@>6]U('=A;G0@=&\@8F4@86QL;W=E9"!T;R!A
M<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA:6QB;W@N($YO<FUA;&QY+"!F
M:6QT97)I;F<@<G5L97,@87)E(&]N;'D@87!P;&EE9"!T;R!N97<@;6%I;"!T
M:&%T(&ES(&1E;&EV97)E9"!T;R!Y;W5R($E.0D]8+B`@268@=&AI<R!O<'1I
M;VX@:7,@8VAE8VME9"P@86X@:6-O;B!W:6QL(&%P<&5A<B!O;B!A;&P@;6%I
M;&)O>"!P86=G97,@=&AA="!W:6QL(&%L;&]W('EO=2!T;R!A<'!L>2!F:6QT
M97(@<G5L97,@=&\@=&AE(&UE<W-A9V5S(&EN('1H92!C=7)R96YT(&UA:6QB
M;W@N("!.3U1%.B!&:6QT97)I;F<@:6X@;6%I;&)O>&5S(&]T:&5R('1H86X@
M24Y"3U@@;6%Y('!R;V1U8V4@<W1R86YG92`H92YG+B!T:&4@9FEL=&5R(&UA
M>2!C875S92!A(&-O<'D@;V8@;65S<V%G97,@=&\@8F4@9&5L:79E<F5D('1O
M('1H92!S86UE(&UA:6QB;W@I(&%N9"]O<B!U;F1E<VER960@<F5S=6QT<R`H
M92YG+B!I="!M87D@8V%U<V4@;65S<V%G97,@=&\@8F4@;6]V960O9&5L971E
M9"!I9B!N97<@9FEL=&5R:6YG(')U;&5S(&AA=F4@8F5E;B!I;7!L96UE;G1E
M9"!S:6YC92!T:&4@;65S<V%G92!H87,@8F5E;B!D96QI=F5R960@=&\@=&AE
M(&-U<G)E;G0@;6%I;&)O>"DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M<'5B:V5Y(B!S=&%T93TB=6YK
M;F]W;B(^"B`@("`\=&ET;&4^4$=0.B!0^&EL;[YI="!69?AE:F[]($ML[>@\
M+W1I=&QE/@H@("`@/&AE861I;F<^4/AI;&^^:70@5F7X96IN_2!+;.WH/"]H
M96%D:6YG/@H@("`@/'!A<F$^"@E0;VMU9"!S:2!V>6)E<F5T92!T=71O(&UO
MOFYO<W0L(%;AN2!01U`@=F7X96IN_2!K;.WH(&)U9&4@</AI;&^^96X@:R!6
M8;GM(&]D97/M;&%NZ2!Z<'+A=NP@*'!O:W5D('1E;G1O(&ML[>@@97AI<W1U
M:F4I+B!);7!L:6-I=&[M(&-H;W;A;NT@;'IE(&YA<W1A=FET('8@4$=0(&UO
MOFYO<W1E8V@N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N
M=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M<'5B:V5Y(CX*("`@(#QT:71L
M93Y01U`Z($%T=&%C:"!0=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG
M/D%T=&%C:"!0=6)L:6,@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)
M9B!S96QE8W1E9"!T:&5N(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y
M+"!I9B!I="!E>&ES=',L('=I;&P@8F4@871T86-H960@=&\@=&AE(&]U=&=O
M:6YG(&UE<W-A9V4N("!9;W4@8V%N('-E="!T:&4@9&5F875L="!B96AA=FEO
M<B!V:6$@=&AE(%!'4"!/<'1I;VYS('-C<F5E;BX*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO;BUS8V%N
M+6)O9'DB('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y01U`Z(%9Y:&QE
M9.%VX6[M('8@5&5X='4@6G!RX79Y/"]T:71L93X*("`@(#QH96%D:6YG/E9Y
M:&QE9.%VX6[M('8@5&5X='4@6G!RX79Y/"]H96%D:6YG/@H@("`@/'!A<F$^
M"@E0;VMU9"!J92!T871O('9O;&)A('9Y8G+A;F$L($E-4"!B=61E('9Y:&QE
M9.%V870@4$=0(&1A=&$@=B!T97AT=2!Z<'+A=GD@82!B=61O=2!Z;V)R87IE
M;GD@=B!P^.UP863L(&[A;&5Z=2X@5&5N=&\@<')O8V5S(&WYOF4@>G!O;6%L
M:70@8V5L_2!S>7-TZ6TL('!R;W1OOF4@:V&^9.$@>G!RX79A(&)U9&4@:V]M
M<&QE=&[L('!R;VAL963A;F$L('ID86QI(&]B<V%H=6QE(%!'4"!D871A+@H@
M("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<&=P
M+6]P=&EO;BUS8V%N+6)O9'DB/@H@("`@/'1I=&QE/E!'4#H@4V-A;B!497AT
M($)O9&EE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY38V%N(%1E>'0@0F]D:65S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N($E-
M4"!W:6QL('-C86X@=&AE(&)O9'D@;V8@86QL('1E>'0@;65S<V%G97,@9F]R
M(%!'4"!D871A+"!A;F0@9&ES<&QA>2!T:&4@<F5S=6QT<R!I9B!A;GD@9&%T
M82!I<R!F;W5N9"X@($YO=&4@=&AA="!T:&ES(&UA>2!S;&]W(&1O=VX@=&AE
M('-Y<W1E;2!A<R!E=F5R>2!T97AT(&UE<W-A9V4@;75S="!B92!S8V%N;F5D
M(&EN(&ET<R!E;G1I<F5T>2!F;W(@4$=0(&1A=&$N"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;W!T:6]N
M<RUE;F-R>7!T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y#;VUP;W-E.B!%
M;F-R>7!T:6]N($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^3F\@16YC
M<GEP=&EO;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5N9"!T:&4@;65S
M<V%G92!W:71H(&YO(&5N8W)Y<'1I;VX@*&-L96%R=&5X="DN"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY01U`@16YC<GEP="!-97-S86=E/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL(&5N8W)Y<'0@=&AE
M(&-U<G)E;G0@;65S<V%G92P@=7-I;F<@4$=0(&%N9"!T:&4@<F5C:7!I96YT
M<R!P97)S;VYA;"!P=6)L:6,@:V5Y+"!A;F0@=&AE;B!S96YD(&ET+B!9;W4@
M8V%N(&]N;'D@<V5N9"!A(&UE<W-A9V4@=&\@82!S:6YG;&4@<&5R<V]N('5S
M:6YG('1H:7,@;W!T:6]N+B!9;W4@35535"!H879E('1H92!P=6)L:6,@:V5Y
M(&]F('1H92!R96-I<&EE;G0@<W1O<F5D(&EN('EO=7(@861D<F5S<V)O;VL@
M;W(@96QS92!T:&ES(&]P=&EO;B!W:6QL(&9A:6PN($EF('EO=2!H879E('1H
M92!P=6)L:6,@:V5Y(&9O<B!T:&4@<F5C:7!I96YT(&EN('EO=7(@861D<F5S
M<V)O;VL@86YD(&%R92!S=&EL;"!R96-E:79I;F<@97)R;W)S+"!V97)I9GD@
M=&AA="!T:&4@92UM86EL(&%D9')E<W,@:6X@=&AE(')E8VEP:65N="!F:65L
M9"!M871C:&5S('1H92!E+6UA:6P@861D<F5S<R!W:&5R92!T:&4@<'5B;&EC
M(&ME>2!I<R!S=&]R960N(%1H92!E;F-R>7!T960@9&%T82!W:6QL(&)E(&%T
M=&%C:&5D('1O('1H92!O=71G;VEN9R!M97-S86=E+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^4$=0(%-I9VX@365S<V%G93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!D:6=I=&%L;'D@<VEG;B!T:&4@
M8W5R<F5N="!M97-S86=E('5S:6YG(%!'4"!A;F0@>6]U<B!P97)S;VYA;"!P
M<FEV871E(&ME>2X@268@>6]U(&AA=F4@;F]T(&%L<F5A9'D@96YT97)E9"!T
M:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!P<FEV871E(&ME>2!D=7)I;F<@=&AI
M<R!S97-S:6]N('EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!I="X@(%1H92!R
M96-E:7!I96YT(&UU<W0@:&%V92!A(&-O<'D@;V8@>6]U<B!P=6)L:6,@:V5Y
M('1O(&1I9VET86QL>2!V97)I9GD@>6]U<@H@("`@<VEG;F%T=7)E+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^4$=0(%-I9VXO16YC<GEP="!-97-S86=E
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL(&9I
M<G-T(&1I9VET86QL>2!S:6=N('EO=7(@;65S<V%G92!A;F0@=&AE;B!W:6QL
M(&5N8W)Y<'0@=&AE(')E<W5L=&EN9R!O=71P=70N(%-E92!T:&4@)U!'4"!%
M;F-R>7!T($UE<W-A9V4G(&%N9"`G4$=0(%-I9VX@365S<V%G92<@96YT<FEE
M<R!F;W(@9G5R=&AE<B!I;F9O<FUA=&EO;BX*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E,O34E-12!%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-
M12!3:6=N($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-12!3:6=N+T5N8W)Y<'0@
M365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5$]$3PH@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]V97)V:65W(B!S=&%T
M93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4$=0.B!0^&5H;&5D/"]T:71L93X*
M("`@(#QH96%D:6YG/D-O(&IE(%!'4#\\+VAE861I;F<^"B`@("`\<&%R83X*
M"5!'4"!J92!NX7-T<F]J('5M;[[R=6KM8^T@8F5Z<&7H;F]U(&MO;75N:6MA
M8VD@82!U<VML861N[&[M(&1A="!O8GIV;.&Y=.P@=B!O8FQA<W1I(&5M86EL
M^2X@3?F^92!B_70@<&]UOFET;R!P<F\@:_-D;W;A;NT@9&%T(.AI('9Y='9O
M^&5N[2!D:6=I=.%L;NUH;R!S:6=N871U<GDN($E-4"!P;W6^[7;A($=N=5!'
M("A'3E4@4')I=F%C>2!'=6%R9"D@:R!Z86IIN73L;NT@=.QC:'1O(&9U;FMC
M[2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5M;[YN:70@9G5N:V-I(%!'
M4#\\+VAE861I;F<^"B`@("`\<&%R83X*"51A=&\@;6^^;F]S="!6X6T@=6UO
MOF[M('9Y='9O^&ET+W!R;VALZ61N;W5T(%;AN64@;W-O8F[M(%!'4"!K;.WH
M92P@</AI9&%T(.AI('9Y;6%Z870@=F7X96INZ2!K;.WH92!J:6[]8V@@;&ED
M[2P@Z.US="!K\V1O=F%NZ2!E;6%I;'DL(&]V[/AI="!D:6=I=.%L;NT@;WIN
M8>AE;ND@96UA:6QY(&$@=&%KZ2!K\V1O=F%T+V]Z;F'H:70@5N&Y92!E;6%I
M;'DN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)P9W`M;W9E<G9I97<B/@H@("`@/'1I=&QE/E!'4#H@3W9E<G9I97<\+W1I
M=&QE/@H@("`@/&AE861I;F<^5VAA="!I<R!01U`_/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!01U`@:7,@82!T;V]L(&9O<B!S96-U<F4@8V]M;75N:6-A
M=&EO;B!A;F0@9&%T82!S=&]R86=E+"!E<W!E8VEA;&QY(&9O<B!U<V4@=VET
M:"!E+6UA:6PN($ET(&-A;B!B92!U<V5D('1O(&5N8W)Y<'0@9&%T82!A;F0@
M=&\@8W)E871E(&1I9VET86P@<VEG;F%T=7)E<RX@24U0('5S97,@1VYU4$<@
M*$=.52!0<FEV86-Y($=U87)D*2!T;R!P<F]V:61E('1H:7,@9G5N8W1I;VYA
M;&ET>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!01U`@9G5N
M8W1I;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@
M;W!T:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&-R96%T
M92]V:65W('EO=7(@<&5R<V]N86P@4$=0(&ME>7,L(&%D9"]D96QE=&4@<'5B
M;&EC(&ME>7,@9G)O;2!O=&AE<B!I;F1I=FED=6%L<RP@<F5A9"!E;F-R>7!T
M960@;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N
M8W)Y<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I;VXM871T
M86-H+7!U8FME>2(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E!'4#H@
M36^^;F]S=&D@+2!0^&EL;[YI="!69?AE:F[]($ML[>@\+W1I=&QE/@H@("`@
M/&AE861I;F<^36^^;F]S=&D@+2!0^&EL;[YI="!69?AE:F[]($ML[>@\+VAE
M861I;F<^"B`@("`\<&%R83X*"5!O:W5D('9Y8F5R971E('1U=&\@;6^^;F]S
M="P@:V&^9.$@;V1E<VQA;N$@>G!RX79A(&)U9&4@;V)S86AO=F%T(%;AN2!0
M1U`@5F7X96IN_2!+;.WH+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB<&=P+6]P=&EO;BUA='1A8V@M<'5B:V5Y(CX*("`@
M(#QT:71L93Y01U`Z($]P=&EO;G,@+2!!='1A8V@@4'5B;&EC($ME>3PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY/<'1I;VYS("T@071T86-H(%!U8FQI8R!+97D\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@82!C
M;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T<RP@=VEL
M;"!B>2!D969A=6QT(&)E(&%T=&%C:&5D('1O(&%L;"!O=71G;VEN9R!M97-S
M86=E<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+6UA;F%G92UP=6)K97DB('-T871E/2)U;FMN;W=N(CX*("`@
M(#QT:71L93Y01U`Z(%-P<N%V82!69?AE:F[]8V@@2VSMZ/D\+W1I=&QE/@H@
M("`@/&AE861I;F<^4/AE:&QE9#PO:&5A9&EN9SX*("`@(#QP87)A/@H)5&]T
M;R!Z;V)R87KM(':Y96-H;GD@:V]N=&%K='D@=F4@5F&Y:6-H($MO;G1A:W1E
M8V@L(&MT97+I(&UA:FD@4$=0('9E^&5J;ND@:VSMZ&4N(%1O=&\@5N%M('5M
M;[YN[2`Q*2!Z87/M;&%T(&OS9&]V86[I(&5M86EL>2!T[&UT;R!L:61E;2`M
M;F5B;RT@,BD@;W;L^&]V870@9&EG:73M;&[M('-I9VYA='5R>2!T[&-H=&\@
M;&ED[2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EIO8G)A>F5N[3PO:&5A
M9&EN9SX*("`@(#QP87)A/@H)3W1E=OAE(&]K;F\@82!Z;V)R87KM('8@;NQM
M(%!'4"!V9?AE:F[](&ML[>@N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$
M971A:6QY/"]H96%D:6YG/@H@("`@/'!A<F$^"@E:;V)R87KM(&1E=&%I;'D@
M;VAL961N["!01U`@=F7X96INZ6AO(&ML[>AE+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^5GEM87IA=#PO:&5A9&EN9SX*("`@(#QP87)A/@H)5GEM8;YE
M(%!'4"!V9?AE:F[](&ML[>@@>B!68;EI8V@@2V]N=&%K=/DN"B`@("`\+W!A
M<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)P9W`M;6%N86=E
M+7!U8FME>2(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME>7,\
M+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H:7,@<V-R965N(&QI<W1S(&%L;"!O9B!T:&4@8W5R<F5N
M="!U<V5R<R!I;B!Y;W5R(&%D9')E<W-B;V]K('1H870@:&%V92!01U`@<'5B
M;&EC(&ME>7,N(%1H97-E('5S97)S(&%R92!T:&4@3TY,62!U<V5R<R!T:&%T
M('EO=2!C86X@96ET:&5R(#$I('-E;F0@86X@96YC<GEP=&5D(&UE<W-A9V4@
M=&\@+4]2+2`R*2!V97)I9GD@82!D:6=I=&%L('-I9VYA='5R92X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P=6)L:6,@:V5Y
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H
M92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E
M;&5T93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T:&4@<'5B
M;&EC(&ME>2!F<F]M('EO=7(@861D<F5S<V)O;VLN"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UI;7!O<G0M<'5B
M:V5Y(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4$=0.B!3<'+A=F$@
M5F7X96IN_6-H($ML[>CY("T@26UP;W)T/"]T:71L93X*("`@(#QH96%D:6YG
M/DEM<&]R="!69?AE:F[]8V@@2VSMZ/D\+VAE861I;F<^"B`@("`\<&%R83X*
M"51O=&\@=&QAZ.UT:V\@5N%M('5M;[YN[2!V;&^^:70@4$=0('9E^&5J;OT@
M:VSMZ"!M86YUX6QN["!D;R!N;W;L(&]T97;X96[I:&\@;VMN82X@2VSMZ"!T
M86T@;?F^92!B_70@>FMO<.UR;W;A;B!D;R!T97AT;W;I:&\@<&]L92P@;F5B
M;R!P;VMU9"!J92!U;&^^96X@=B!S;W5B;W)U(&YA(%9AN65M(&QO:^%L;NUM
M('!OZ.UT8>AI+"!L>F4@:&\@:6UP;W)T;W9A="!J86MO('-O=6)O<BX@4&]K
M=60@:F4@:VSMZ"!P;&%T;OT@8G5D92!U;&^^96X@9&\@5F&Y:6-H($MO;G1A
M:W3Y(&$@;VMN;R!S92!U>F%V^&4N(%!O:W5D(&ML[>@@;F5N[2!P;&%T;OT@
M;V)J97;M('-E(&-H>6)O=ND@:&SAN65N[2!S('9Y<W;L=&QE;NUM+@H@("`@
M/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<&=P+6EM
M<&]R="UP=6)K97DB/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+
M97ES("T@26UP;W)T/"]T:71L93X*("`@(#QH96%D:6YG/DEM<&]R="!0=6)L
M:6,@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!B=71T;VX@
M=VEL;"!O<&5N(&$@=VEN9&]W('=H97)E('EO=2!C86X@;6%N=6%L;'D@:6UP
M;W)T(&$@4$=0('!U8FQI8R!K97DN("!4:&4@:V5Y(&-A;B!E:71H97(@8F4@
M<&%S=&5D(&EN=&\@82!T97AT9FEE;&0@;W(L(&EF('1H92!K97D@<F5S:61E
M<R!I;B!A(&9I;&4@;VX@>6]U<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I
M;7!O<G0@:70N("!)9B!T:&4@:V5Y(&ES('9A;&ED(&ET('=I;&P@8F4@:6YS
M97)T960@:6YT;R!Y;W5R(&%D9')E<W-B;V]K(&%N9"!T:&4@=VEN9&]W('=I
M;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL
M(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N
M=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<M<&5R
M<V]N86QK97DB('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y01U`Z(%-P
M<N%V82!69?AE:F[]8V@@2VSMZ/D\+W1I=&QE/@H@("`@/&AE861I;F<^4/AE
M:&QE9#PO:&5A9&EN9SX*("`@(#QP87)A/@H)4&]K=7,@<VD@</AE:F5T92!D
M:6=I=.%L;NP@;WIN8>AI="!Z<'+A=GD@;F5B;R!U;6^^;FET(&]S=&%T;NUM
M('!O<^ULX6[M(&OS9&]V86[]8V@@>G!RX78L(&UU<^UT92!M[70@5N&Y(&]S
M;V)N[2!69?AE:F[]+T]S;V)N[2!01U`@:VSMZ&]V_2!PX7(N"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY6X;D@5F7X96IN_2!+;.WH/"]H96%D:6YG/@H@
M("`@/'!A<F$^"@E6X;D@=F7X96IN_2!K;.WH(&)Y(&WL;"!B_70@:R!D:7-P
M;WII8VD@:V]M=6MO;&EV(&MD;R!6X6T@8VAC92!P;W/M;&%T(&OS9&]V86[I
M('IP<N%V>2P@:W1E<ND@<&]U>F4@5ED@;?F^971E(&1E:_-D;W9A="`H<&]U
MOFET[6T@5F&Y96AO(&]S;V)N[6AO(&ML[>AE*2X@02!T86OI+"!6X;D@=F7X
M96IN_2!K;.WH(&)Y(&WL;"!B_70@:R!D:7-P;WII8VD@:V]M=6MO;&EV(&MD
M;R!P^&EJ[6WA(%9AN64@>G!RX79Y+"!K=&5RZ2!J<V]U(&1I9VETX6QN["!O
M>FYAZ&5NZ2`M('9E^&5J;OT@:VSMZ"!J92!P;W3X96)A(&L@;W;L^&5N[2!D
M:6=I=.%L;NUH;R!O>FYAZ&5N[2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/E;AN2!/<V]B;NT@2VSMZ#PO:&5A9&EN9SX*("`@(#QP87)A/@H)5N&Y(&]S
M;V)N[2!K;.WH(&IE('!O=/AE8F$@:R!D96OS9&]VX6[M('IP<N%V(&OS9&]V
M86[]8V@@5F&Y[6T@=F7X96IN_6T@:VSMZ&5M+B!!('1A:^DL(%;AN2!O<V]B
M;NT@:VSMZ"!J92!P;W3X96)A(&L@9&EG:73A;&[M;74@;WIN8>AE;NT@>G!R
MX78N(%;AN2!O<V]B;NT@:VSMZ"!J92!C:'+A;NQN(&AE<VQE;2P@:W1E<ND@
M8GEL;R!Z863A;F\@</AI('9Y='9O^&5N[2!T;VAO=&\@:VSMZ&4N(%#X:2!J
M86OI:V]L:78@;6%N:7!U;&%C:2!S(%9AN>UM(&]S;V)N[6T@:VSMZ&5M(&)U
M9&5T92!P;[[A9.%N:2!O(&AE<VQO(&L@5F&Y96UU(&]S;V)N[6UU(&ML[>AI
M+B!)35`@<VD@>F%P86UA='5J92!T;W1O(&AE<VQO(&)O(&1O8G4@5F&Y[2!R
M96QA8V4@*&1O:W5D('-E(&YE;V1H;.%S[71E('IE('-Y<W3I;74I+"!T86N^
M92!S92!N97IA<&]M9?)T92!O9&ALX7-I="X*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G!G<"UO=F5R=FEE=RUP97)S;VYA
M;&ME>2(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@268@>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@;65S<V%G
M97,@;W(@96YA8FQE(&]T:&5R<R!T;R!S96YD('EO=2!E;F-R>7!T960@;65S
M<V%G97,L('EO=2!M=7-T(&AA=F4@>6]U<B!O=VX@<&5R<V]N86P@<'5B;&EC
M+W!R:79A=&4@4$=0(&ME>7!A:7(N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY9;W5R(%!U8FQI8R!+97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO
M=7(@<'5B;&EC(&ME>2!S:&]U;&0@8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY
M('!E<G-O;B!T:&%T('EO=2!W86YT('1O(&)E(&%B;&4@=&\@<V5N9"!Y;W4@
M96YC<GEP=&5D(&UE<W-A9V5S('1H870@;VYL>2!93U4@8V%N(&1E8W)Y<'0@
M*'5S:6YG('EO=7(@<')I=F%T92!K97DI+B!!9&1I=&EO;F%L;'DL('EO=7(@
M<'5B;&EC(&ME>2!N965D<R!T;R!B92!M861E(&%V86EL86)L92!T;R!A;GEB
M;V1Y('EO=2!S96YD(&$@9&1I9VET86QL>2!S:6=N960@;65S<V%G92!T;R`M
M('1H92!P=6)L:6,@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@9&EG
M:71A;"!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY9;W5R
M(%!R:79A=&4@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!R
M:79A=&4@:V5Y(&ES(&YE8V5S<V%R>2!T;R!D96-R>7!T(&%N>2!M97-S86=E
M(&5N8W)Y<'1E9"!U<VEN9R!Y;W5R('!U8FQI8R!K97DN($%D9&ET:6]N86QL
M>2P@>6]U<B!P<FEV871E(&ME>2!I<R!N965D960@:68@>6]U('=A;G0@=&\@
M9&EG:71A;&QY('-I9VX@82!M97-S86=E+B!9;W5R('!R:79A=&4@:V5Y('=I
M;&P@8F4@<')O=&5C=&5D('9I82!A('!A<W-P:')A<V4@8W)E871E9"!W:&5N
M('1H92!K97ES(&%R92!G96YE<F%T960N(%1H=7,L('1O('!E<F9O<FT@86YY
M(&%C=&EV:71Y('1H870@<F5Q=6ER97,@>6]U<B!P<FEV871E(&ME>2P@24U0
M('=I;&P@<')O;7!T('EO=2!F;W(@>6]U<B!P87-S<&AR87-E+B!9;W4@;VYL
M>2!N965D('1O(&EN<V5R="!Y;W5R('!A<W-P:')A<V4@;VYC92!P97(@<V5S
M<VEO;B`M($E-4"!W:6QL('-T;W)E('EO=7(@<&%S<W!H<F%S92!U;G1I;"!Y
M;W4@;&]G;W5T("A3;R!B92!S=7)E('1O(&QO9V]U="$I+@H@("`@/"]P87)A
M/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N
M86QK97DM<'5B;&EC(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4$=0
M.B!3<'+A=F$@3W-O8F[M8V@@2VSMZ/D@+2!69?AE:F[]($ML[>@\+W1I=&QE
M/@H@("`@/&AE861I;F<^6F]B<F%Z96[M/"]H96%D:6YG/@H@("`@/'!A<F$^
M"@E/=&5V^&4@;VMN;R!A('IO8G)A>NT@=B!N[&T@4$=0('9E^&5J;OT@:VSM
MZ"X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;'D\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@("!:;V)R87KM(&1E=&%I;'D@;VAL961N["!0
M1U`@=F7X96INZ6AO(&ML[>AE+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@
M96YT<GDZ"CQE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!U8FQI8R(^"B`@
M("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M(%!U8FQI8R!+
M97D\+W1I=&QE/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!U8FQI
M8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O
M=70@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM
M/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T
M92(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E!'4#H@4W!RX79A($]S
M;V)N[6-H($ML[>CY("T@3W-O8F[M($ML[>@\+W1I=&QE/@H@("`@/&AE861I
M;F<^5FQOOFET(&AE<VQO/"]H96%D:6YG/@H@("`@/'!A<F$^"@E/=&5V^&4@
M;VMN;R!P<F\@>F%DX6[M(&AE<VQA+B!0;R#Z<W#LN6[I;2!Z863A;NT@:&5S
M;&$@<VD@24U0('1O=&\@:&5S;&\@>F%P86UA='5J92!P;R!D;V)U('1R=N%N
M[2!R96QA8V4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY:8F%V:70@<V4@
M2&5S;&$\+VAE861I;F<^"B`@("`\<&%R83X*"4E-4"!S92!Z8F%V[2!Z87!A
M;6%T;W9A;NEH;R!H97-L82P@</AI(&IA:^EK;VQI=B!D86RY[2!M86YI<'5L
M86-I(',@;W-O8F[M;2!K;.WH96T@24U0('!OON%DX2!O('IN;W9U('9L;[YE
M;NT@:&5S;&$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY:;V)R87IE;NT\
M+VAE861I;F<^"B`@("`\<&%R83X*"5IO8G)A>NT@4$=0(&]S;V)N[2!K;.WH
M+B!.15!/4\U,14I412!414Y43R!+3,W(($Y)2T]-52`M('1A=&\@9G5K8V4@
M:F4@>F1E('!O=7IE('!R;R!U;6^^;NQN[2!E>'!O<G1U('1O:&\@=&\@:VSM
MZ&4@9&\@:FEN_6-H('!R;V=R86WY(.AI(&%P;&EK86/M+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^1&5T86EL>3PO:&5A9&EN9SX*("`@(#QP87)A/@H)
M6F]B<F%Z[2!D971A:6QY(%9AN65H;R!01U`@;W-O8F[M:&\@:VSMZ&4N"B`@
M("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)P9W`M
M<&5R<V]N86QK97DM<')I=F%T92(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@
M4&5R<V]N86P@2V5Y<R`M(%!R:79A=&4@2V5Y/"]T:71L93X*("`@(#QH96%D
M:6YG/D5N=&5R(%!A<W-P:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($]P96YS('1H92!P87-S<&AR87-E(&1I86QO9R!W:6YD;W<N(%1H92!P87-S
M<&AR87-E(&5N=&5R960L(&EF(&-O<G)E8W0L('=I;&P@8F4@<W1O<F5D(&)Y
M($E-4"!U;G1I;"!Y;W5R('-E<W-I;VX@96YD<RX*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E5N;&]A9"!087-S<&AR87-E/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!296UO=F5S('1H92!S=&]R960@<&%S<W!H<F%S92!F<F]M($E-
M4"`M(&%N>2!A9&1I=&EO;F%L('5S86=E(&]F('1H92!P<FEV871E(&ME>2!W
M:6QL(')E<75I<F4@>6]U('1O(')E96YT97(@=&AE('!A<W-P:&5A<V4N"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@<')I=F%T
M92!K97DN($1/($Y/5"!314Y$(%1(25,@2T59(%1/($%.64].12`M('1H:7,@
M;W!T:6]N(&ES('-T<FEC=&QY('-O('1H870@>6]U(&-A;B!E>'!O<G0@>6]U
M<B!)35`@<&5R<V]N86P@<')I=F%T92!K97D@9F]R('5S92!I;B!A;F]T:&5R
M('!R;V=R86TN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@
M86)O=70@=&AE(%!'4"!P<FEV871E(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R
M>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E
M;&5T92(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E!'4#H@4W!RX79A
M($]S;V)N[6-H($ML[>CY("T@5GEM87KA;NT\+W1I=&QE/@H@("`@/&AE861I
M;F<^5GEM87IA="!/<V]B;NT@2VSMZ&4\+VAE861I;F<^"B`@("`\<&%R83X*
M"51O=&\@=&QAZ.UT:V\@=GEM8;YE('9E^&5J;OTO;W-O8F[M:&\@:VSMZ&]V
MZ6AO('#A<G4@>B!N87-T879E;NT@=B!)35!U+@H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E
M;&5T92(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M
M($1E;&5T93PO=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@
M2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL
M;"!D96QE=&4@>6]U<B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER
M(&9R;VT@24U0)W,@<')E9F5R96YC97,N"B`@("`\+W!A<F$^"CPO96YT<GD^
M+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A
M=&4M;F%M92(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E!'4#H@5GET
M=F_X96[M($]S;V)N[6AO($ML[>AE("T@2FWI;F\\+W1I=&QE/@H@("`@/&AE
M861I;F<^2FWI;F\\+VAE861I;F<^"B`@("`\<&%R83X*"4IMZ6YO+"!K=&5R
MZ2!S:2!P^&5J971E('IA:')N;W5T(&1O(%9AN6EC:"!O<V]B;NUC:"!K;.WH
M^2X@4&^^861O=F%NZ2!P;VQE+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@
M96YT<GDZ"CQE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UN86UE
M(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!.86UE
M/"]T:71L93X*("`@(#QH96%D:6YG/DYA;64\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%1H92!N86UE('EO=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R
M<V]N86P@:V5Y<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y
M+6-R96%T92UC;VUM96YT(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M4$=0.B!6>71V;_AE;NT@3W-O8F[M:&\@2VSMZ&4@+2!0;WINX6UK83PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY0;WINX6UK83PO:&5A9&EN9SX*("`@(#QP87)A
M/@H)4&]Z;N%M:V$L(&MT97)O=2!S:2!P^&5J971E('IA:')N;W5T(&1O(%9A
MN6EC:"!O<V]B;NUC:"!K;.WH^2X@3F5V>;YA9&]V86[I('!O;&4N"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)P9W`M<&5R
M<V]N86QK97DM8W)E871E+6-O;6UE;G0B/@H@("`@/'1I=&QE/E!'4#H@0W)E
M871E(%!E<G-O;F%L($ME>2`M($-O;6UE;G0\+W1I=&QE/@H@("`@/&AE861I
M;F<^0V]M;65N=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@02!C;VUM96YT
M('-T<FEN9R!Y;W4@=V%N="!E;6)E9&1E9"!I;B!Y;W5R('!E<G-O;F%L(&ME
M>7,N($%N(&]P=&EO;F%L(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM
M/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E
M+65M86EL(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4$=0.B!6>71V
M;_AE;NT@3W-O8F[M:&\@2VSMZ&4@+2!%;6%I;&]VX2!!9')E<V$\+W1I=&QE
M/@H@("`@/&AE861I;F<^16UA:6QO=N$@061R97-A/"]H96%D:6YG/@H@("`@
M/'!A<F$^"@E%;6%I;&]VX2!A9')E<V$L(&MT97)O=2!S:2!P^&5J971E('-P
M;VII="!S(%9AN6EM:2!O<V]B;NUM:2!K;.WH:2X@4&^^861O=F%NZ2!P;VQE
M+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB
M<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UE;6%I;"(^"B`@("`\=&ET;&4^4$=0
M.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@12UM86EL($%D9')E<W,\+W1I=&QE
M/@H@("`@/&AE861I;F<^12UM86EL($%D9')E<W,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H92!E+6UA:6P@861D<F5S<R!Y;W4@=V%N="!A<W-O8VEA
M=&5D('=I=&@@>6]U<B!P97)S;VYA;"!K97ES+B!!(')E<75I<F5D(&9I96QD
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"(@<W1A=&4](G5N
M:VYO=VXB/@H@("`@/'1I=&QE/E!'4#H@5GET=F_X96[M($]S;V)N[6AO($ML
M[>AE("T@1.EL:V$@2VSMZ&4\+W1I=&QE/@H@("`@/&AE861I;F<^1.EL:V$@
M2VSMZ&4\+VAE861I;F<^"B`@("`\<&%R83X*"5IA9&5J=&4@9.EL:W4@5F&Y
M96AO(&ML[>AE('8@0GET96-H+B#([6T@=NQTN>T@:&]D;F]T82P@=.UM(';L
M=+GM(&]C:')A;F$@*'1A:^D@9&5LN>T@Z&%S(&=E;F5R;W;A;NT@82!K\V1O
M=N%N[2DN($EM<&QI8VET;NT@:&]D;F]T82!J92`Q,#(T(&)Y=/DL('1A=&\@
M:&]D;F]T82!P;W-K>71U:F4@=OUB;W)N;W4@;V-H<F%N=2X*("`@(#PO<&%R
M83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G!G<"UP97)S;VYA
M;&ME>2UC<F5A=&4M:V5Y;&5N9W1H(CX*("`@(#QT:71L93Y01U`Z($-R96%T
M92!097)S;VYA;"!+97D@+2!+97EL96YG=&@\+W1I=&QE/@H@("`@/&AE861I
M;F<^2V5Y;&5N9W1H/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@:V5Y
M;&5N9W1H+"!I;B!B>71E<RP@;V8@>6]U<B!G96YE<F%T960@:V5Y+B!4:&4@
M9W)E871E<B!T:&4@=F%L=64L('1H92!G<F5A=&5R('1H92!P<F]T96-T:6]N
M("AA;F0@86QS;R!G<F5A=&5R(&=E;F5R871I;VX@=&EM92!A;F0@96YC<GEP
M=&EO;B!T:6UE*2X@,3`R-"!B>71E<R!I<R!T:&4@9&5F875L="`M('1H:7,@
M=F%L=64@<')O=FED97,@97AC96QL96YT('!R;W1E8W1I;VXN"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S
M;VYA;&ME>2UC<F5A=&4M<&%S<W!H<F%S92(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/E!'4#H@5GET=F_X96[M($]S;V)N[6AO($ML[>AE("T@2&5S
M;&\\+W1I=&QE/@H@("`@/&AE861I;F<^3N%Z978\+VAE861I;F<^"B`@("`\
M<&%R83X*"4AE<VQO('-L;W6^[2!K(&]C:')A;NPO:_-D;W;A;NT@5F&Y96AO
M(&]S;V)N[6AO(&ML[>AE+B!-[&QO(&)Y(&+]="!.14I-R4[,(#8@>FYA:_D@
M9&QO=6CI+"!N96WL;&\@8GD@8OUT('-T96INZ2!J86MO(%9AN64@:&5S;&\@
M:R#ZZ'1U+"!N96WL;&\@8GD@8OUT('IA;&^^96YO(&YA('-L;W;L('IE('-L
M;W9N[6MU(&$@;>QL;R!B>2!O8G-A:&]V870@:F%K(.CM<VQI8V4@=&%K('#M
M<VUE;F$N(%1O=&\@:&5S;&\@;75S[2!B_70@<&]S:WET;G5T;R!D=F%K<N%T
M("AO=NSX96[M('!R;W1I('#X96ML97#Y;2DN(%!OOF%D;W9A;ND@<&]L92X*
M("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G!G
M<"UP97)S;VYA;&ME>2UC<F5A=&4M<&%S<W!H<F%S92(^"B`@("`\=&ET;&4^
M4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@4&%S<W!H<F%S93PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY.86UE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M:&4@<&%S<W!H<F%S92!U<V5D('1O('!R;W1E8W0O96YC<GEP="!Y;W5R('!E
M<G-O;F%L('!R:79A=&4@:V5Y+B!4:&ES('-H;W5L9"!B92!!5"!,14%35"`V
M(&-H87)A8W1E<G,L('-H;W5L9"!.3U0@8F4@=&AE('-A;64@87,@>6]U<B!L
M;V=I;B!P87-S=V]R9"P@<VAO=6QD($Y/5"!B92!B87-E9"!O;B!A(&1I8W1I
M;VYA<GD@=V]R9"P@86YD('-H;W5L9"!I;F-L=61E(&)O=&@@;G5M8F5R<R!A
M;F0@;&5T=&5R<RX@66]U(&UU<W0@96YT97(@=&AI<R!P87-S<&AR87-E('1W
M:6-E(&9O<B!V97)I9FEC871I;VX@<'5R<&]S97,N($$@<F5Q=6ER960@9FEE
M;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M86-T:6]N<R(@<W1A=&4](G5N
M:VYO=VXB/@H@("`@/'1I=&QE/E!'4#H@5GET=F_X96[M($]S;V)N[6AO($ML
M[>AE("T@06MC93PO=&ET;&4^"B`@("`\:&5A9&EN9SY6>71V;_AE;NT@2VSM
MZ/D\+VAE861I;F<^"B`@("`\<&%R83X*"59Y='9O^&ET(&$@=6QOOFET(&]S
M;V)N[2]V9?AE:F[]('#A<B!K;.WH^2X*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/DEM<&]R=&]V870@2VSMZ&]V_2!0X7(\+VAE861I;F<^"B`@("`\<&%R
M83X*"4EM<&]R=&]V870@;W-O8F[M+W9E^&5J;OT@:VSMZ&]V_2!PX7(N(%1O
M=&\@=&QAZ.UT:V\@;W1E=OAE(&]K;F\@82!A('!A:R!L>F4@;6%N=>%L;NP@
M:6UP;W)T;W9A="!E>&ET=6KM8^T@4$=0(&]S;V)N[2]V9?AE:F[](&ML[>AO
M=OT@<.%R+B!+;.WH92!M;VAO=2!B_70@>FMO<.UR;W;A;GD@9&\@=&5X=&]V
MZ6AO('!O;&4L('!O:W5D(&ML[>AE('-E(&YA8VCA>NT@=B!S;W5B;W)U(&YA
M(%9AN65M(&QO:^%L;NUM('!OZ.UT8>AI+"!T86L@:F4@;?F^971E(&EM<&]R
M=&]V870@>B!N[&AO+B!0;VMU9"!J<V]U(&ML[>AE('!L871NZ2!B=61O=2!U
M;&^^96YY('9E(%9AN6EC:"!M;[YN;W-T96-H(&YA<W1A=F5N[2!A(&]K;F\@
M<V4@>F%V^&4L('!O:W5D(&YE8G5D;W4@<&QA=&[I(&]B:F5V[2!S92!C:'EB
M;W;A(&ALX;EK82!S('9Y<W;L=&QE;NUM+@H@("`@/"]P87)A/@H\(2TM($5N
M9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T
M92UA8W1I;VYS(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+
M97D@+2!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D-R96%T92!+97ES
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#<F5A=&4@86YD('-T;W)E('EO
M=7(@<&5R<V]N86PO<')I=F%T92!K97EP86ER+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^26UP;W)T($ME>7!A:7(\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($EM<&]R="!A('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX@5&AI<R!B
M=71T;VX@;W!E;G,@82!W:6YD;W<@=VAE<F4@>6]U(&-A;B!M86YU86QL>2!I
M;7!O<G0@>6]U<B!E>&ES=&EN9R!01U`@<&5R<V]N86P@<'5B;&EC+W!R:79A
M=&4@:V5Y<&%I<BX@(%1H92!K97ES(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN
M=&\@82!T97AT9FEE;&0@;W(L(&EF('1H92!K97ES(')E<VED92!I;B!A(&9I
M;&4@;VX@>6]U<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@=&AE
M;2X@($EF('1H92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS97)T
M960@:6YT;R!Y;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I;&P@
M8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E
M(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y
M/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=R(@<W1A
M=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E,O34E-13H@4/AE:&QE9#PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY#;R!J92!3+TU)344_/"]H96%D:6YG/@H@("`@
M/'!A<F$^"@E3+TU)344@:F4@<WES=.EM('!R;R!O<V]B;NTO=F7X96IN_2!K
M;.WH;W;]('#A<BP@:W1E<OT@=6UOOO)U:F4@<&]UONUT(&1I9W3A;&[M('-I
M9VYA='5R>2P@<V]U:W)O;>D@>G!RX79Y+"!D971E:V-I(&9A;+EO=N%N[2X@
M4R]-24U%('!O<VMY='5J92!O8VAR86YU('5T86IE;NT@>G!RX79Y('!O;6]C
M[2!K\V1U+"!K=&5R_2!P;W5Z92!P^.UJ96UC:2!A(&]D97-I;&%T96P@;6]H
M;W4@9&5K\V1O=F%T+B!4;W1O('5M;[[R=6IE(&ED96YT:69I:V%C:2!O9&5S
M[6QA=&5L92!P;VUO8^T@:F5H;R!D:6=I=.%L;NT@<VEG;F%T=7)Y+B!4>71O
M(&UOOFYO<W1I('!O<VMY='5J[2!P^.UJ96UC:2!D971E:V-I('ID82!Z<'+A
M=F$@8GEL82!O8FWL;NQN82!P;W3I(&-O(&)Y;&$@>F%S;.%N82X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/E5M;[YN:70@9G5N:V-I(%,O34E-13\\+VAE
M861I;F<^"B`@("`\<&%R83X*"51A=&\@9G5N:V-E(%;A;2!U;6^^;NT@:6UP
M;W)T;W9A="!3+TU)344@:VSMZ&4L(.CM<W0@:_-D;W9A;ND@>G!RX79Y+"!O
M=NSX:70@9&EG:73A;&[L(&]Z;F'H96YO=2!Z<'+A=G4L(&OS9&]V870O;WIN
M8>AI="!686UI('IA<^UL86[I('IP<N%V>2X*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G-M:6UE+6]V97)V:65W(CX*("`@
M(#QT:71L93Y3+TU)344Z($]V97)V:65W/"]T:71L93X*("`@(#QH96%D:6YG
M/E=H870@:7,@4R]-24U%/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4R]-
M24U%(&ES(&$@<')I=F%T92]P=6)L:6,@:V5Y('!A:7(@<WES=&5M('=H:6-H
M('!R;W9I9&5S(&1I9VET86P@<VEG;F%T=7)E<RP@;65S<V%G92!P<FEV86-Y
M+"!A;F0@=&%M<&5R(&1E=&5C=&EO;B!I;B!A(&]P96XL(&EN=&5R;W!E<F%B
M;&4@=V%Y+B`@4R]-24U%(&-A;B!P<F]V:61E(&UE<W-A9V4@<')I=F%C>2!B
M>2!E;F-R>7!T:6YG(&UE<W-A9V5S('1H870@;VYL>2!T:&4@<V5N9&5R(&%N
M9"!T:&4@:6YT96YD960@<F5C:7!I96YT<R!C86X@9&5C;V1E+B`@270@86QL
M;W=S('EO=2!T;R!I9&5N=&EF>2!T:&4@<V5N9&5R(&]F(&$@;65S<V%G92!V
M:6$@82!D:6=I=&%L('-I9VYA='5R92X@(%1O9V5T:&5R+"!T:&ES(&5N8W)Y
M<'1I;VX@86YD(&1I9VET86P@<VEG;FEN9R!H96QP('!R;W9I9&4@=&%M<&5R
M(&1E=&5C=&EO;BP@86QL;W=I;F<@<F5C:7!I96YT<R!T;R!D971E<FUI;F4@
M=VAE=&AE<B!A(&UE<W-A9V4@=V%S(&%L=&5R960@869T97(@:70@=V%S('-E
M;G0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;F%B;&4@4R]-24U%(&9U
M;F-T:6]N86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!T:&ES
M(&]P=&EO;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@86)L92!T;R!I;7!O
M<G0@>6]U<B!P97)S;VYA;"!3+TU)344@:V5Y<RP@<F5A9"!E;F-R>7!T960@
M;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N8W)Y
M<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO96YT
M<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W+7!E
M<G-O;F%L:V5Y(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4R]-24U%
M.B!/<V]B;NT@2VSMZ&4\+W1I=&QE/@H@("`@/&AE861I;F<^4/AE:&QE9#PO
M:&5A9&EN9SX*("`@(#QP87)A/@H)4&]K=60@<VD@</AE:F5T92!O>FYAZ&ET
M(.AI('IA:_-D;W9A="!Z<'+A=GDL(&UU<^UT92!M[70@=FQA<W1N[2!V9?AE
M:F[]+V]S;V)N[2!3+TU)344@:VSMZ&]V_2!PX7(N"B`@("`\+W!A<F$^"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=RUP
M97)S;VYA;&ME>2(^"B`@("`\=&ET;&4^4R]-24U%.B!097)S;VYA;"!+97ES
M/"]T:71L93X*("`@(#QH96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!O<B!E
M;F-R>7!T(&UE<W-A9V5S('EO=2!M=7-T(&AA=F4@>6]U<B!O=VX@<&5R<V]N
M86P@<'5B;&EC+W!R:79A=&4@4R]-24U%(&ME>7!A:7(N"B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6EM<&]R
M="UP97)S;VYA;"UC97)T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-
M24U%.B!);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@
M(#QH96%D:6YG/DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($EM<&]R="!P97)S;VYA;"!C97)T:69I8V%T
M97,@9G)O;2!A(%!+0U,@(S$R(&9O<FUA="!F:6QE+B!02T-3(",Q,B!F:6QE
M<R!I<R!T:&4@9FEL92!U<W5A;&QY(&=E;F5R871E9"!W:&5N(&5X<&]R=&EN
M9R!A(&ME>2!F<F]M(&$@8G)O=W-E<B`H92YG+B!);G1E<FYE="!%>'!L;W)E
M<BP@1FER969O>"D@;W(@9G)O;2!A(&-E<G1I9FEC871E('-T;W)E(&UA:6YT
M86EN960@8GD@86X@3W!E<F%T:6YG(%-Y<W1E;2`H92YG+B!7:6YD;W=S(%A0
M*2X@268@=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E
M9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C
M;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@
M<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)S;6EM92UD96QE=&4M<&5R<V]N86PM8V5R=',B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@1&5L971E(%!E<G-O;F%L
M($-E<G1I9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R
M<V]N86P@0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$
M96QE=&4@>6]U<B!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!Y;W5R('!R
M969E<F5N8V5S+B`@66]U('=I;&P@;F\@;&]N9V5R(&)E(&%B;&4@=&\@<VEG
M;B!3+TU)344@;65S<V%G97,@;W(@=FEE=R!A;GD@4R]-24U%(&5N8W)Y<'1E
M9"!M97-S86=E<R!A9&1R97-S960@=&\@>6]U+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;6%N86=E+7!U8FME>2(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\
M+W1I=&QE/@H@("`@/&AE861I;F<^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME
M>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($UA;F%G92!Y;W5R(%,O34E-
M12!P=6)L:6,@:V5Y(&QI<W0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6
M:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W('1H92!R87<@=&5X
M="!O9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&5C:&YI
M8V%L(&1E=&%I;',@;V8@=&AE('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY$96QE=&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E
M;&5T97,@=&AE('-E;&5C=&5D('!U8FQI8R!K97D@9G)O;2!S=&]R86=E+B`@
M1&5L971I;F<@82!P=6)L:6,@:V5Y(&9O<B!A('5S97(@=VEL;"!P<F5V96YT
M('EO=7(@9G)O;2!E;F-R>7!T:6YG(&$@;65S<V%G92!T;R!T:&%T('5S97(N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<FEN=&EN9R(@
M<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E1I<VL\+W1I=&QE/@H@("`@
M/&AE861I;F<^5&ES:VYO=70@6G!RX79U/"]H96%D:6YG/@H@("`@/'!A<F$^
M"@E0;VMU9"!S:2!P^&5J971E('9Y=&ES:VYO=70@<'+A=NP@<')O:&SMOF5N
M;W4@>G!RX79U+"!K;&EK;NQT92!N82!L:6YK=2`B5&ES:R(@=F4@=G)C:&[M
M(&YE8F\@<W!O9&[M(.CA<W1I('IP<N%V>2X@3W1E=OAE('-E(&YO=ND@;VMN
M;R!F;W)MX71O=F%NZ2!P<F\@=&ES:RX@6F1A;&D@<V4@;W1E=OAE(&1I86QO
M9R!P<F\@=&ES:R!ZX6QEONT@;F$@='EP=2!68;EE:&\@;W!E<F'H;NUH;R!S
M>7-TZ6UU(&$@='EP=2!68;EE:&\@<')O:&SMOF7H92!I;G1E<FYE='4N(%!O
M:W5D('-E(&1I86QO9R!N96]T97;X92P@<&]UOFEJ=&4@;F%B[71K;W9O=2!L
M:;ET=2!V>6)E<G1E(")3;W5B;W(B("TF9W0[(")4:7-K(B!K(&]T97;X96[M
M(&1I86QO9W4@<')O('1I<VLN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E
M;G1R>3H*/&5N=')Y(&ED/2)P<FEN=&EN9R(^"B`@("`\=&ET;&4^4')I;G1I
M;F<\+W1I=&QE/@H@("`@/&AE861I;F<^4')I;G0@82!M97-S86=E/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!4;R!P<FEN="!A(&UE<W-A9V4@>6]U(&%R
M92!V:65W:6YG+"!C;&EC:R!O;B!T:&4@)G%U;W0[4')I;G0F<75O=#L@;&EN
M:R!A="!E:71H97(@=&AE('1O<"!O<B!B;W1T;VT@;V8@=&AE(&UE<W-A9V4N
M(%1H92!M97-S86=E('=I;&P@;W!E;B!I;B!A(&YE=R!W:6YD;W<@9F]R;6%T
M960@9F]R('!R:6YT:6YG+B`@1&5P96YD:6YG(&]N('EO=7(@=V5B(&)R;W=S
M97(@86YD(&]P97)A=&EN9R!S>7-T96TL('1H92!P<FEN="!D:6%L;V<@8F]X
M(&UA>2!O<&5N(&9O<B!Y;W4N("!)9B!I="!D;V5S(&YO="!O<&5N+"!T:&5N
M('!U;&P@9&]W;B!T:&4@=V5B(&)R;W=S97(G<R`F<75O=#M&:6QE)G%U;W0[
M(&UE;G4@86YD(&-H;V]S92`F<75O=#M0<FEN="9Q=6]T.R!T;R!O<&5N('1H
M92!P<FEN="!D:6%L;V<@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)S;W)T:6YG(B!S=&%T93TB=6YK;F]W;B(^
M"B`@("`\=&ET;&4^5/CM9.QN[2!A(%-O=79I<VQO<W1I/"]T:71L93X*("`@
M(#QH96%D:6YG/E1Y<'D@5/CM9.QN[3PO:&5A9&EN9SX*("`@(#QP87)A/@H)
M4/AI('!R;VAL[;YE;NT@5F&Y:6-H('IP<N%V(&QZ92!P;W6^[70@=/CM9.QN
M[2P@<&]D;&4@:F%K96AO:V]L:78@<VQO=7!C92P@:VQI:VYU=.UM(&YA(&AL
M879IZ&MU(&1A;F[I:&\@<VQO=7!C92X@4/AE<.UNX6[M(&UE>FD@=GIE<W1U
M<&[];2!A('-E<W1U<&[];2!T^.UD[&[M;2!L>F4@9&]SX6AN;W5T('!O;6]C
M[2!K;&EK;G5T[2!N82!M86QO=2!I:V]N:W4@N6EP:WD@=B!H;&%V:>AC92!D
M86YNZ6AO('-L;W5P8V4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3;W5V
M:7-L;W-T:3PO:&5A9&EN9SX*("`@(#QP87)A/@H)4&]K=60@<VD@</AE:F5T
M92!S9?AA>F5N[2!Z<'+A=B!P;V1L92!S;W5V:7-L;W-T:2!P^&5D;>QT^2P@
M8V^^('IN86UE;N$@OF4@:V&^9.$@>G!RX79A(&IE('IA^&%Z96YA(&1O('-K
M=7!I;GD@>G!RX78@;V)S86AU:NUC[2!VN65C:&YY(&]D<&]V[&1I+"!K;&EK
M;NQT92!N82!L:6YK=2!;4V]U=FES;&]S=%T@=B!H;&%V:>AC92!S;&]U8V4@
M</AE9&WL="X@3F%V<N%C96[M(&1O(&YO<FWA;&[M:&\@<&_X863M(&QZ92!P
M<F]VZ7-T(&ML:6MN=73M;2!N82!L:6YK=2!;4/AE9&WL=%T@=B!H;&%V:>AC
M92!S;&]U8V4@</AE9&WL="X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N
M=')Y.@H\96YT<GD@:60](G-O<G1I;F<B/@H@("`@/'1I=&QE/E-O<G1I;F<@
M86YD(%1H<F5A9&EN9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3;W)T:6YG($5N
M=')I97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%=H96X@=FEE=VEN9R!A
M(&QI<W0@;V8@;65S<V%G97,L('EO=2!C86X@<V]R="!T:&4@;65S<V%G97,@
M8GD@86YY(&-O;'5M;B!B>2!C;&EC:VEN9R!O;B!T:&4@87!P<F]P<FEA=&4@
M8V]L=6UN(&AE861I;F<N("!4;R!S=VET8V@@8V]L=6UN<R!B971W965N(&%S
M8V5N9&EN9R!A;F0@9&5S8V5N9&EN9R!O<F1E<BP@8VQI8VL@;VX@=&AE(&%R
M<F]W(&EC;VX@:6X@=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^5&AR96%D:6YG/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4;R!G<F]U<"!M97-S86=E<R!B>2!T:')E861S("AS=6)J96-T*2P@<V\@
M96%C:"!M97-S86=E(&ES(&=R;W5P960@=VET:"!A;&P@:71S(')E<&QI97,L
M(&-L:6-K('1H92!;5&AR96%D72!L:6YK(&EN('1H92!S=6)J96-T(&-O;'5M
M;B!H96%D:6YG+B`@5&\@<F5T=7)N('1O(&YO<FUA;"!S=6)J96-T('-O<G1I
M;F<L(&-L:6-K(&]N('1H92!;4W5B:F5C=%T@;&EN:R!I;B!T:&4@<W5B:F5C
M="!C;VQU;6X@:&5A9&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB86QT97)N871I=F4M;7-G(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y-=6QT:7!A<G0O06QT97)N871I=F4@365S<V%G97,\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3;VUE(&UE<W-A9V4@:&%V92!B965N
M('-E;G0@87,@82`B;75L=&EP87)T+V%L=&5R;F%T:79E(B!T>7!E(&)Y('1H
M92!S96YD97(N(%1H97-E(&UE<W-A9V5S(&AA=F4@<V5V97)A;"!P87)T<RP@
M86QL(&1I<W!L87EI;F<@=&AE(%-!344@0T].5$5.5"!B=70@:6X@1$E&1D52
M14Y4($9/4DU!5%,N(%1H92!M86EL(&%G96YT('=I;&P@9&ES<&QA>2!T:&4@
M;&%S="!P87)T(&EN('1H92!L:7-T('1H870@8V%N(&)E('-U8V-E<W-F=6QL
M>2!D:7-P;&%Y960@:6YL:6YE(&EN('1H92!B<F]W<V5R+"!I9B!A;GDN($%L
M;"!O=&AE<B!F;W)M871S('=I;&P@87!P96%R('5N9&5R('1H92!H96%D:6YG
M(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N(B!A;F0@8V%N
M(&)E('9I97=E9"!O<B!D;W=N;&]A9&5D('-E<&%R871E;'DN($ET(&ES(&EM
M<&]R=&%N="!T;R!N;W1E('1H870@=&AE<V4@86QT97)N871I=F4@<&%R=',@
M8V]N=&%I;B!T:&4@4T%-12!#3TY414Y44R!A<R!T:&4@<&%R="!T:&%T(&ES
M('-H;W=N("T@=&AE>2!A<F4@<VEM<&QY(&EN(&$@9&EF9F5R96YT(&UE9&EA
M(&9O<FUA="`H92YG+B!T97AT('9S+B!(5$U,(&]U='!U="DN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUR96YA;65?<V5N=&UA
M:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6YT96YA;F-E.B!296YA;64@4V5N="UM86EL($9O;&1E<B!-;VYT
M:&QY/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O
M;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!R96YA;64@>6]U<B!S96YT+6UA:6P@
M9F]L9&5R(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&4@
M9F]L9&5R('=I;&P@8F4@<F5N86UE9"`H=&\@82!N86UE('1H870@8V]N=&%I
M;G,@=&AE(&UO;G1H(&%N9"!Y96%R*2!A;F0@82!N97<@<V5N="UM86EL(&9O
M;&1E<B!W:6QL(&)E(&-R96%T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!$96QE=&4@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@
M(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@
M;&EK92!T;R!D96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T('1H92!B
M96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&ES(&UA>2!B92!U<V5F=6P@
M:68@>6]U(&AA=F4@82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?
M;6]N=&AL>5]K965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T92!396YT+6UA:6P@1F]L9&5R($UO
M;G1H;'D@+2`C(&]F($9O;&1E<G,@=&\@2V5E<#PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($EF('EO=2!A<F4@9&5L971I;F<@;VQD('-E;G0M;6%I;"!F;VQD
M97)S(&5V97)Y(&UO;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@;VQD(&9O;&1E
M<G,@9&\@>6]U("!W86YT('1O(&ME97`_("!!;GD@9F]L9&5R<R!O;&1E<B!T
M:&%N('1H:7,@;6%N>2!M;VYT:',@=VEL;"!B92!D96QE=&5D+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C
M:&UE;G1S7VUO;G1H;'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E($QI;FME9"!!='1A8VAM96YT
M<R!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P
M=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD(&QI;FME
M9"!A='1A8VAM96YT<R!A="!T:&4@8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H
M+B`@5&AI<R!M87D@8F4@=7-E9G5L(&EF('EO=2!H879E(&$@<75O=&$L(&9O
M<B!E>&%M<&QE+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'E?:V5E<"(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$
M96QE=&4@3&EN:V5D($%T=&%C:&UE;G1S($UO;G1H;'D@+2`C(&]F($UO;G1H
M<R!T;R!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R92!D
M96QE=&EN9R!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&5V97)Y(&UO;G1H+"!H
M;W<@;6%N>2!M;VYT:',@;V8@;VQD(&%T=&%C:&UE;G1S(&1O('EO=2`@=V%N
M="!T;R!K965P/R`@06YY(&%T=&%C:&UE;G1S(&]L9&5R('1H86X@=&AI<R!M
M86YY(&UO;G1H<R!W:6QL(&)E(&1E;&5T960N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G
M92!4<F%S:#PO=&ET;&4^"B`@("`\<&%R83X*("`@($1O('EO=2!W86YT('1O
M('!U<F=E('EO=7(@=')A<V@@9F]L9&5R(&5V97)Y('-O(&]F=&5N+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A
M<VA?:6YT97)V86PB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N
M8V5S.B!-86EN=&5N86YC93H@4'5R9V4@5')A<V@@26YT97)V86P\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S
M:"!F;VQD97(L(&AO=R!O9G1E;B!S:&]U;&0@:70@8F4@<'5R9V5D/PH@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A
M<VA?:V5E<"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:"!+965P/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U(&%R92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R
M+"!M97-S86=E(&]L9&5R('1H86X@:&]W(&UA;GD@9&%Y<R!S:&]U;&0@8F4@
M<'5R9V5D/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M871T<FEB7W1E>'0B('-T871E/2)N97<B/@H@("`@(#QT:71L93Y0<F5F
M97)E;F-E<SH@365S<V%G92!#;VUP;W-I=&EO;CH@071T<FEB=71I;VX@5&5X
M=#PO=&ET;&4^"B`@("`@/'!A<F$^"B`@("`@2&5R92!Y;W4@8V%N(&5N=&5R
M('1H92!P:')A<V4@=&AA="!Y;W4@=VES:"!T;R!A<'!E87(@8F5F;W)E(&%N
M>2!Q=6]T960@=&5X="!I;B!A(')E<&QY('1H870@>6]U('-E;F0N"B`@("`@
M/"]P87)A/@H@("`@(#QP87)A/@H@("`@(%EO=2!C86X@:6YC;'5D92!O;F4@
M;W(@;6]R92!S<&5C:6%L('!L86-E:&]L9&5R<R!T;R!I;G-E<G0@:6YF;W)M
M871I;VX@86)O=70@=&AE(&UE<W-A9V4@=&\@=VAI8V@@>6]U(&%R92!R97!L
M>6EN9RX@4&QA8V5H;VQD97)S(&-O;G-I<W0@;V8@82`G)2<@9F]L;&]W960@
M8GD@82!S:6YG;&4@;&5T=&5R+B!4:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R
M<R!A<F4@879A:6QA8FQE.@H@("`@(#PO<&%R83X*"B`@("`@/'!A<F$^("5F
M(#H@5&AE('-E;F1E<B=S(&YA;64@86YD(&5M86EL(&%D9')E<W,\+W!A<F$^
M"B`@("`@/'!A<F$^("5A(#H@5&AE('-E;F1E<B=S(&5M86EL(&%D9')E<W,\
M+W!A<F$^"B`@("`@/'!A<F$^("5P(#H@5&AE('-E;F1E<B=S(&YA;64\+W!A
M<F$^"B`@("`@/'!A<F$^("5R(#H@5&AE(&9U;&P@4D9#(#(X,C(@<W1Y;&4@
M9&%T92!A;F0@=&EM92!Z;VYE/"]P87)A/@H@("`@(#QP87)A/B`E9"`Z(%1H
M92!D871E(&%S('=W=RP@9&0@;6UM(%E965D\+W!A<F$^"B`@("`@/'!A<F$^
M("5X(#H@5&AE(&1A=&4@:6X@=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A<F$^
M"B`@("`@/'!A<F$^("5C(#H@5&AE(&1A=&4@86YD('1I;64@:6X@=&AE(&QO
M8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^("5M(#H@5&AE($UE
M<W-A9V4M240\+W!A<F$^"B`@("`@/'!A<F$^("5S(#H@5&AE('-U8FIE8W0\
M+W!A<F$^"B`@("`@/'!A<F$^("5N(#H@02!N97<@;&EN93PO<&%R83X*("`@
M("`\<&%R83X@)24@.B!4:&4@)R4G(&-H87)A8W1E<CPO<&%R83X*"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7W)E
M860B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!297%U
M97-T(%)E860@4F5C96EP=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`B4F5Q
M=65S="!A(%)E860@4F5C96EP="(@<V5N9',@82!R97%U97-T('1O('1H92!R
M96-I<&EE;G1S(&]F('1H:7,@;65S<V%G92!T;R!N;W1I9GD@>6]U('=H96X@
M=&AI<R!M97-S86=E(&ES(&]P96YE9"!B>2!T:&4@<F5C:7!I96YT<RX@3F]T
M(&%L;"!C;&EE;G1S('-U<'!O<G0@+R!H;VYO<B!T:&ES+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<V5N
M9%]M9&XB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!3
M96YD($U$3CPO=&ET;&4^"B`@("`\<&%R83X*("`@(")396YD(&$@341.(B!S
M96YD<R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("AA;'-O
M(&MN;W=N(&%S(&$@<F5A9"!R96-E:7!T*2!W:&5N('EO=2!V:65W(&$@;65S
M<V%G92!I;B!W:&EC:"!T:&4@=7-E<B!H87,@<F5Q=65S=&5D('1H870@=&AE
M>2!R96-E:79E(&YO=&EF:6-A=&EO;B!T:&%T('EO=2!H879E(')E860@=&AE
M(&UE<W-A9V4N($EN(&UO<W0@8V%S97,L('1H:7,@=VEL;"!H87!P96X@875T
M;VUA=&EC86QL>2!W:71H;W5T('!R;VUP=&EN9R!Y;W4N($EN(&-E<G1A:6X@
M:7-O;&%T960@8V%S97,L('EO=2!M87D@:&%V92!T;R!M86YU86QL>2!D96-I
M9&4@=&\@<V5N9"!T:&4@;F]T:69I8V%T:6]N(&)Y(&-L:6-K:6YG(&]N(&$@
M;&EN:RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+61I<W!O<VET:6]N7W)E<75E<W1?9&5L:79E<GDB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!297%U97-T($1E;&EV97)Y($-O;F9I
M<FUA=&EO;CPO=&ET;&4^"B`@("`\<&%R83X*("`@(")297%U97-T($1E;&EV
M97)Y($-O;F9I<FUA=&EO;B(@<V5N9',@82!R97%U97-T('1O('1H92!R96-I
M<&EE;G0G<R!E+6UA:6P@<V5R=F5R('1O(&YO=&EF>2!Y;W4@=VAE;B!I="!H
M87,@9&5L:79E<F5D('1H92!M97-S86=E('1O('1H92!R96-I<&EE;G0G<R!M
M86EL8F]X+B!)="!D;V5S;B=T(&UE86X@=&AE(&UE<W-A9V4@:&%S(&)E96X@
M<V5E;BP@:G5S="!T:&%T(&ET)W,@<VET=&EN9R!I;B!A(&UA:6QB;W@@<V]M
M97=H97)E+B!.;W0@86QL(&UA:6P@<V5R=F5R<R!S=7!P;W)T('1H:7,N(`H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E
M7W-P86U?869T97)?<F5P;W)T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@1&5L971E(%-P86T@069T97(@4F5P;W)T:6YG/"]T:71L
M93X*("`@(#QP87)A/@H@("`@66]U(&UA>2!E;&5C="!T;R!D;R!O;F4@;V8@
M=&AR964@:71E;7,@869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!E:71H
M97(@<W!A;2!O<B!I;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@1FER<W0L('EO=2!C86X@9&5C:61E('1O(&1O(&YO=&AI;F<@+2!T:&4@
M;65S<V%G92!W:6QL(&)E(')E<&]R=&5D(&%S(&5I=&AE<B!S<&%M(&]R(&EN
M;F]C96YT(&)U="!W:6QL(&]T:&5R=VES92!R96UA:6X@=6YC:&%N9V5D(&EN
M('EO=7(@;6%I;&)O>"X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V5C
M;VYD+"!I9B!R97!O<G1I;F<@82!M97-S86=E(&%S('-P86TL('EO=2!C86X@
M:6YS=&5A9"!H879E('1H92!M97-S86=E(&)E(&EM;65D:6%T96QY(&1E;&5T
M960N("!4:&ES('-E='1I;F<@:&%S(&YO(&5F9F5C="!O;B!R97!O<G1I;F<@
M82!M97-S86=E(&%S(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("!4:&ER9"P@869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!S<&%M
M('1H92!M97-S86=E('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT
M(&UA:6QB;W@@86YD(&UO=F5D('1O('EO=7(@<W!A;2!F;VQD97(N("!!;'1E
M<FYA=&EV96QY+"!I9B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT
M('1H92!M97-S86=E('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT
M(&UA:6QB;W@@86YD(&UO=F5D('1O('EO=7(@24Y"3U@N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUH=&UL7VEM86=E7W)E<&QA
M8V5M96YT(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M2%1-3"!);6%G92!297!L86-E;65N=#PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($9O<B!(5$U,(&UE<W-A9V5S(&1I<W!L87EE9"!I;FQI;F4L('-H;W5L9"!A
M;&P@:6UA9V4@=&%G<R!B92!B;&]C:V5D('5N=&EL('EO=2!S<&5C:69I8V%L
M;'D@9&5C:61E('1O('9I97<@=&AO<V4@:6UA9V5S/R!.;W1E('1H870L(&EF
M('9I97=I;F<@86X@2%1-3"!A='1A8VAM96YT+"!T:&4@:6UA9V5S('=I;&P@
M86QW87ES(&)E(&1I<W!L87EE9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+6AT;6Q?:6UA9V5?861D<F)O;VLB('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!(5$U,($EM86=E(%)E<&QA
M8V5M96YT+T%D9')E<W-B;V]K(%-H;W<\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!)9B!B;&]C:VEN9R!I;6%G97,@9F]R(&EN;&EN92!(5$U,(&UE<W-A9V5S
M+"!S:&]U;&0@=V4@875T;VUA=&EC86QL>2!D:7-P;&%Y('1H96T@:6YS=&5A
M9"!I9B!T:&4@<V5N9&5R(&%P<&5A<G,@:6X@>6]U<B!A9&1R97-S8F]O:S\*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6UA:6QB
M;WA?<W1A<G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!-86EL8F]X(%-T87)T(%!A9V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$
M971E<FUI;F5S('=H:6-H('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=R!W:6QL
M(&)E(&1I<W!L87EE9"!W:&5N('EO=2!A8V-E<W,@82!M86EL8F]X(&9O<B!T
M:&4@9FER<W0@=&EM92X@3F]T92!T:&%T('1H92`G=6YS965N)R!M97-S86=E
M(&]P=&EO;G,@9&\@;F]T('=O<FL@=VET:"!T:&4@)U1H<F5A9"<@<V]R=&EN
M9R!O<'1I;VX@+2!I;G-T96%D+"!Y;W4@=VEL;"!B92!S96YT('1O('1H92!L
M87-T('!A9V4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUS879E7V%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@4V%V92!!='1A8VAM96YT<R!O;B!396YT($UE<W-A
M9V5S/"]T:71L93X*("`@(#QP87)A/@H@("`@268@<V%V:6YG(&$@8V]M<&]S
M960@;65S<V%G92!I;B!A('-E;G0M;6%I;"!F;VQD97(L(&1E=&5R;6EN92!I
M9B!A;&P@871T86-H;65N="!D871A(&ES('-A=F5D+B!4:&4@9F]L;&]W:6YG
M(&]P=&EO;G,@87)E(&%V86EL86)L93H*("`@(#PO<&%R83X*"B`@("`\<&%R
M83XJ(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P<F]M<'0@
M=&\@<V%V92!A='1A8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T
M=&%C:&UE;G1S(&%R92!!3%=!65,@<V%V960@=VET:"!T:&4@;65S<V%G92X\
M+W!A<F$^"B`@("`@/'!A<F$^*B`B4')O;7!T(&5V97)Y('1I;64@86X@871T
M86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4R(@+2!!3%=!65,@<')O
M;7!T('1O('-A=F4@871T86-H;65N=',@:6X@=&AE(&-O;7!O<V4@<V-R965N
M.R!T:&4@9&5F875L="!I<R!T;R!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*
M("`@("`\<&%R83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT
M(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B("T@04Q705E3('!R;VUP="!T;R!S
M879E(&%T=&%C:&UE;G1S(&EN('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E
M9F%U;'0@:7,@=&\@;F]T('-A=F4@871T86-H;65N=',N/"]P87)A/@H@("`@
M(#QP87)A/BH@(DYE=F5R('-A=F4@871T86-H;65N=',B("T@3D5615(@<')O
M;7!T('1O('-A=F4@871T86-H;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H
M92!A='1A8VAM96YT<R!A<F4@3D5615(@<V%V960@=VET:"!T:&4@;65S<V%G
M92X\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7VEN8F]X
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I
M<G1U86P@26YB;W@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)U=&%L($EN
M8F]X(&ES(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE
M(&YE960@=&\@<V5A<F-H(&5V97)Y(&UA:6QB;W@@9F]R(&UE<W-A9V5S(&UA
M<FME9"!A<R!N97<N("!);G-T96%D+"!A;&P@8W5R<F5N=&QY('-U8G-C<FEB
M960@;6%I;&)O>&5S(&%R92!S96%R8VAE9"!F;W(@;F5W(&UE<W-A9V5S(&%N
M9"!T:&4@<F5S=6QT<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB
M;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L
M7W1R87-H(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E
M<G,Z(%9I<G1U86P@5')A<V@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)T
M=6%L(%1R87-H(&ES(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I
M=&@@=&AE(&YE960@9F]R(&$@<V5P87)A=&4@5')A<V@@9F]L9&5R+B`@26YS
M=&5A9"!O9B!M;W9I;F<@;65S<V%G97,@=&\@82!C96YT<F%L:7IE9"!T<F%S
M:"!F;VQD97(L(&UE<W-A9V5S(&%R92!S:6UP;'D@;6%R:V5D(&%S(&1E;&5T
M960@:6X@=&AE(&-U<G)E;G0@9F]L9&5R('1H97D@;&EV92!I;BX@(%=H96X@
M)W-H;W<@9&5L971E9"!M97-S86=E<R<@:7,@='5R;F5D(&]F9BP@=&AI<R!R
M97-U;'1S(&EN('1H97-E(&UE<W-A9V5S(&YO="!A<'!E87)I;F<@:6X@82!M
M86EL8F]X('9I97<N("!7:&5N(&$@=7-E<B!C;&EC:W,@;VX@5FER='5A;"!4
M<F%S:"P@*F%L;"H@;6%I;&)O>&5S(&%L;"!S96%R8VAE9"!F;W(@;65S<V%G
M97,@=&AA="!A<F4@9FQA9V=E9"!D96QE=&5D(&%N9"!T:&5S92!M97-S86=E
M<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]E;%]'4B\`
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<V,``P,3<T,S8`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O;&]C86QE+V5L7T=2+TQ#7TU%4U-!1T53+P``````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8P`#`R,3(R,P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O96Q?1U(O3$-?34534T%'15,O
M:6UP+FUO````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S`T-C8`,3`T,3<S-C(W
M-C``,#(R,S4W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-X2!)4`````@@$``!P````L#```"0(``#P8````````8"````H`
M``!A(```"@```&P@```*````=R````H```""(```!````(T@```!````DB``
M`!<```"4(```*````*P@```R````U2```"D````((0``,@```#(A```;````
M92$``"X```"!(0``-P```+`A``!\````Z"$``!P```!E(@``'0```((B```(
M````H"(```4```"I(@``"````*\B```'````N"(```P```#`(@``!0```,TB
M```#````TR(``$X```#7(@``4````"8C``!"````=R,``!\```"Z(P``"```
M`-HC```1````XR,``",```#U(P``(0```!DD```[````.R0``"L```!W)```
M,0```*,D```,````U20```D```#B)```!@```.PD```*````\R0```L```#^
M)```$0````HE```*````'"4```,````G)0``"````"LE```)````-"4```0`
M```^)0``!````$,E```&````2"4```X```!/)0``%0```%XE```^````="4`
M``(```"S)0``"@```+8E```&````P24```H```#()0``#0```-,E``!B````
MX24``%\```!$)@``'````*0F```.````P28``!4```#0)@``#````.8F```-
M````\R8```P````!)P``%`````XG```/````(R<```<````S)P``)@```#LG
M``!<````8B<```0```"_)P``!P```,0G```.````S"<```8```#;)P``#0``
M`.(G```:````\"<``!T````+*```&0```"DH``!=````0R@``"@```"A*```
M`@```,HH```%````S2@```0```#3*```$````-@H```9````Z2@``!H````#
M*0``!@```!XI```0````)2D``#,````V*0``!P```&HI```0````<BD``!P`
M``"#*0``"@```*`I```4````JRD``"\```#`*0``#P```/`I```'`````"H`
M``\````(*@``*````!@J```C````02H``"8```!E*@``(````(PJ```$````
MK2H``!(```"R*@``!0```,4J```.````RRH```0```#:*@``%@```-\J```%
M````]BH```T```#\*@``#P````HK```2````&BL```T````M*P``%0```#LK
M```I````42L``"P```![*P``*````*@K```%````T2L``!````#7*P``$```
M`.@K```/````^2L```L````)+```#P```!4L```,````)2P```\````R+```
M"@```$(L```2````32P```T```!@+```#````&XL```]````>RP``!X```"Y
M+```(0```-@L```#````^BP``"4```#^+```!P```"0M```$````+"T```H`
M```Q+0``$````#PM```'````32T```@```!5+0``&0```%XM```$````>"T`
M``P```!]+0``!````(HM```$````CRT```P```"4+0``$0```*$M```,````
MLRT```H```#`+0``!0```,LM```%````T2T```H```#7+0``#P```.(M```&
M````\BT```H```#Y+0``"0````0N```2````#BX``!(````A+@``$````#0N
M```D````12X```@```!J+@``"0```',N```0````?2X```8```".+@``#```
M`)4N```'````HBX```L```"J+@```@```+8N```'````N2X```@```#!+@``
M-P```,HN```/`````B\```H````2+P``!P```!TO```3````)2\```P````Y
M+P``#@```$8O```,````52\```X```!B+P``#P```'$O```-````@2\```\`
M``"/+P``)@```)\O```+````QB\```8```#2+P``!P```-DO```$````X2\`
M``0```#F+P``!0```.LO```#````\2\```H```#U+P``"``````P```,````
M"3````0````6,```#````!LP```)````*#````(````R,```&0```#4P```2
M````3S````X```!B,```!````'$P```+````=C````D```"",```#0```(PP
M```,````FC```!0```"G,```%@```+PP```%````TS```#P```#9,````@``
M`!8Q```,````&3$``",````F,0``!P```$HQ```1````4C$```T```!D,0``
M#0```'(Q```'````@#$```@```"(,0``'@```)$Q```H````L#$```@```#9
M,0``%````.(Q```%````]S$``#$```#],0``)P```"\R```H````5S(``!H`
M``"`,@``*````)LR```I````Q#(``"X```#N,@``-@```!TS```L````5#,`
M`#$```"!,P``$````+,S```-````Q#,```4```#2,P``$P```-@S```-````
M[#,``!8```#Z,P``/@```!$T```(````4#0``!````!9-```%0```&HT```3
M````@#0```<```"4-```%0```)PT```+````LC0``!8```"^-```"P```-4T
M```N````X30``#H````0-0``#0```$LU```%````634```P```!?-0``#0``
M`&PU```*````>C4```8```"%-0``#@```(PU```%````FS4```8```"A-0``
M$0```*@U``!+````NC4```H````&-@``#````!$V```'````'C8``#D````F
M-@``!@```&`V```.````9S8```0```!V-@``!@```'LV```*````@C8```L`
M``"--@``&@```)DV```7````M#8``!<```#,-@``&P```.0V```?`````#<`
M``P````@-P``$P```"TW```1````03<```8```!3-P``0P```%HW```Y````
MGC<```P```#8-P``$0```.4W```@````]S<```0````8.```$````!TX```7
M````+C@``!(```!&.```"P```%DX```-````93@``!0```!S.```+P```(@X
M```'````N#@```T```#`.```%@```,XX```'````Y3@```L```#M.```!0``
M`/DX```$````_S@```D````$.0``,P````XY```>````0CD``'4```!A.0``
M/@```-<Y``!"````%CH``#T```!9.@``/0```)<Z```I````U3H``"D```#_
M.@``,0```"D[```H````6SL``"8```"$.P``/@```*L[``!'````ZCL``%<`
M```R/```50```(H\```O````X#P``%4````0/0``*P```&8]```[````DCT`
M``\```#./0``(0```-X]```<`````#X```L````=/@``!0```"D^```"````
M+SX```T````R/@```P```$`^```@````1#X``"8```!E/@``"@```(P^```3
M````ESX```@```"K/@``%@```+0^```,````RSX```<```#8/@``!@```.`^
M```:````YSX``!$````"/P``'@```!0_```,````,S\```@```!`/P``!P``
M`$D_```G````43\```<```!Y/P``!@```($_```-````B#\```L```"6/P``
M6@```*(_```,````_3\```H````*0````@```!5````&````&$````,````?
M0```)P```"-````A````2T```"0```!M0```'0```))````9````L$```!<`
M``#*0```*@```.)````K````#4$``$4````Y00``)P```']!```A````IT$`
M`"L```#)00``'0```/5!```]````$T(``$$```!10@``*````)-"```L````
MO$(``#````#I0@``$````!I#```?````*T,```\```!+0P``#````%M#```0
M````:$,```\```!Y0P``!````(E#```$````CD,```(```"30P``#@```)9#
M```/````I4,```4```"U0P``:@$``+M#```)````)D4```L````P10``"```
M`#Q%```&````144```0```!,10```0```%%%```9````4T4``"<```!M10``
M+P```)5%```D````Q44``"X```#J10``'````!E&```_````-D8``$@```!V
M1@``=P```+]&```A````-T<``"<```!91P``"P```(%'```%````C4<``!``
M``"31P``"0```*1'```0````KD<```D```"_1P```P```,E'``!+````S4<`
M`%<````92```3P```'%(```B````P4@```H```#D2```$P```.](```[````
M`TD``#H````_20``0````'I)```W````NTD``#````#S20``"0```"1*```'
M````+DH```D````V2@``"0```$!*```)````2DH``!````!42@``$````&5*
M```1````=DH```@```"(2@``%P```)%*```1````J4H```H```"[2@``!P``
M`,9*```1````SDH``!P```#@2@``00```/U*```+````/TL```\```!+2P``
M!@```%M+```+````8DL```X```!N2P``B@```'U+``"4````"$P``"0```"=
M3```$@```,),```B````U4P``!(```#X3```$`````M-```-````'$T``!D`
M```J30``$````$1-```'````54T``#,```!=30``6@```)%-```)````[$T`
M``4```#V30``$@```/Q-```*````#TX``!(````:3@``(@```"U.```E````
M4$X``"4```!V3@``=@```)Q.``!*````$T\```(```!>3P``"````&%/```*
M````:D\``!<```!U3P``(P```(U/```E````L4\```@```#73P``%````.!/
M``!$````]4\```L````Z4```%````$90```?````6U````@```![4```&0``
M`(10```U````GE````\```#44```"````.10```2````[5```#8`````40``
M/0```#=1``!`````=5$``"0```"V40``!0```-M1```3````X5$```@```#U
M40``$@```/Y1```+````$5(``!\````=4@``#````#U2```7````2E(``!0`
M``!B4@``'````'=2```>````E%(``!L```"S4@``*P```,]2```L````^U(`
M`"L````H4P``!0```%13```-````6E,```T```!H4P``#````'93```D````
M@U,```T```"H4P``"@```+93```6````P5,```T```#84P``&0```.93```0
M`````%0``!$````15```-P```"-4```W````6U0``"P```"35````P```,!4
M``!&````Q%0```8````+50``"0```!)5```.````'%4``!$````K50``"```
M`#U5```)````1E4``!D```!050```P```&I5```3````;E4```<```""50``
M!P```(I5```5````DE4``!8```"H50``$0```+]5```0````T54```T```#B
M50``"P```/!5```.````_%4``!4````+5@``"0```"%6```/````*U8```D`
M```[5@``$@```$56```5````6%8``!4```!N5@``,0```(16```&````ME8`
M`!````"]5@``%@```,Y6```'````Y58```X```#M5@``!@```/Q6```I````
M`U<```(````M5P``#P```#!7```1````0%<``#4```!25P``%````(A7```0
M````G5<```8```"N5P``$0```+57```4````QU<``!,```#<5P``$0```/!7
M```/`````E@``!$````26```+0```"18```8````4E@``#8```!K6```!```
M`*)8```+````IU@```<```"S6```"````+M8```%````Q%@```0```#*6```
M`P```,]8```0````TU@```H```#D6```#````.]8```'````_%@```X````$
M60``#@```!-9```#````(ED``!D````F60``'0```$!9```6````7ED```8`
M``!U60``#@```'Q9```+````BUD```P```"760``#````*19```7````L5D`
M`!4```#)60``"@```-]9```]````ZED```<````H6@``#@```#!:```O````
M/UH```@```!O6@``$0```'A:```.````BEH``!````"96@``"````*I:```'
M````LUH``!\```"[6@``1````-M:```)````(%L``!8````J6P``"````$%;
M``!<````2EL``"P```"G6P``*0```-1;```?````_EL``"P````>7```,0``
M`$M<```^````?5P``#\```"\7```.@```/Q<```[````-UT``!(```!S70``
M$@```(9=```(````F5T``!4```"B70``$0```+A=```9````RET``%@```#D
M70``#0```#U>```7````2UX``"$```!C7@``&````(5>```(````GEX``!H`
M``"G7@``$0```,)>```@````U%X``!````#U7@``.`````9?``!4````/U\`
M`!$```"47P``"````*9?```1````KU\``!(```#!7P``#@```-1?```)````
MXU\``!L```#M7P``$0````E@```(````&V```!<````D8```5````#Q@```7
M````D6```!,```"I8```#0```+U@``!6````RV````D````B80``%P```"QA
M```*````1&$```<```!/80``#````%=A```/````9&$``",```!T80``+```
M`)AA```E````Q6$``"(```#K80``%P````YB```2````)F(``!T````Y8@``
M'P```%=B```+````=V(``#$```"#8@``3P```+5B```5````!6,``"D````;
M8P``/````$5C```'````@F,``!(```"*8P``&P```)UC```2````N6,``!0`
M``#,8P``%0```.%C```A````]V,``#X````99```!````%AD```.````760`
M`!<```!L9```"````(1D```)````C60```@```"79```!P```*!D```,````
MJ&0``#(```"U9```&@```.AD``")`````V4``#L```"-90``/````,EE``!&
M````!F8``$,```!-9@``*0```)%F```F````NV8``#$```#B9@``)P```!1G
M```Q````/&<``$H```!N9P``7````+EG``!L````%F@``&D```"#:```/0``
M`.UH``!H````*VD``#````"4:0``5@```,5I```3````'&H``#`````P:@``
M)````&%J```/````AFH```8```"6:@``!````)UJ```4````HFH``!4```"W
M:@``+@```,UJ```O````_&H```T````L:P``%@```#IK```)````46L``!8`
M``!;:P``#P```')K```5````@FL```T```"8:P``'@```*9K```;````Q6L`
M`#$```#A:P``#P```!-L```,````(VP```L````P;```2P```#QL```-````
MB&P```L```"6;```#@```*)L```/````L6P``&L```#!;```$@```"UM```1
M````0&T```(```!2;0``!@```%5M```#````7&T``"<```!@;0``)0```(AM
M```H````KFT``"D```#7;0``%@````%N```3````&&X``"@````L;@``+0``
M`%5N``!!````@VX``"4```#%;@``*````.MN```Q````%&\``"8```!&;P``
M/@```&UO``!!````K&\``"$```#N;P``(P```!!P``!!````-'```!(```!V
M<```(@```(EP```/````K'```!(```"\<```%0```,]P```2````Y7````,`
M``#X<```!@```/QP```!`````W$``!$````%<0``$````!=Q```-````*'$`
M``$```#]````<0```#(```!R`0````````````!T`0``@`$``"H!```A````
M4P```!8!```2`0``=0```,@```!*`0``/`$``%P```!@````DP```(,```!A
M`0```````'H```!8`````````$8```"O`````````$H`````````"`$``*T`
M``"A````!P```$@`````````B0```.<````I`0``J0````D````;`0``````
M``$!```P`0`````````````Y`0``10``````````````,P````````!]`0``
M`````!4```!S````8@````@`````````5``````````Q`0````````````!^
M````'`$````!```?````#0````````!,`0``"P$``!@````#````;0$`````
M````````+`$``"X````B`0``````````````````1@$``-X```!K`0``U0``
M`,````"``````````#,!```%````,````(0````B````;`````````!_`0``
ML0```#L`````````2`$`````````````90$```````"1````M0```!<````R
M`0``VP```%$`````````````````````````;@```'L!```T`0``7@$`````
M``!#`````````````````````````#4```!"````E0```,D`````````#@$`
M``````!Z`0``1P$``%H````$`0``0P$``*H```!D````K````$T!``#*````
M@@````````"4`````````/````"F````/P```````````````````+````"G
M`````````'$!`````````````/,````=`0``D@```"4!``#B````=@````H!
M``"C````2P````````!%`0```````!0````Y````&@$``(H```!=`0``````
M``````!W`````````'L```#W`````````*L```#&````V0```/4````H````
M`````,,```!)````'@$`````````````G````%(```"B````/````!(```#Z
M````/0```%T````/`````````,L```""`0``>0$```````!F````;@$``%`!
M````````"@```+D````T````!P$``'4!``!7````O````)@```#0````/0$`
M`*````#@````5@$``.\````:````````````````````#`````````#_````
M;P```!$````0````5`$````````9``````````````#[````#0$``%(!``!9
M````:0$``"T```!9`0``Y@````````!E`````````(@```!5````Q````-8`
M````````*`$`````````````6`$``!$!`````````````*@```!1`0``````
M```````O`0`````````````_`0``$`$`````````````[````%````!$````
M<````'@```!)`0````````4!``#D````)`````````"!````/@```&(!```#
M`0``'@```&8!``!;`````````-(````U`0``G@```#H!```F````_````/X`
M```+````#@```'P```"?````3@````````"9````C0`````````5`0``W0``
M`(4````D`0``Q0````8`````````8P$```````#I````>`$``,P`````````
M#`$``,T````@`0``3````.H`````````AP``````````````V````!\!``#!
M````:`````````"N````8`$``+X`````````+````)T````[`0``I0```'<!
M``",`````````)L````I````SP```!@!````````4P$``)H```#1````3@$`
M`"L!``"+````.`$``-P````X````^0`````````&`0``N````!<!```W````
MXP```&H!``!G````NP```/8````Z````+P```$$!``"T`````````&L```!R
M``````````````"6````80```"8!````````````````````````I`````(!
M``#"````8P```+,```!D`0``+@$``#<!```J````A@```,<````6````````
M`&@!``#N````<P$```````!?````[0````````!"`0``&P```($!```<````
M`````"$!```G````\@```.4```"W`````````$````"R````00```%<!``!/
M````;`$```````!/`0``````````````````EP```+8```!-````&0$``'D`
M```=`````````-0```!+`0``WP````(```"]`````````%L!````````?`$`
M`/0```#Q````9P$```0```!M````?0```'0```!<`0```````%H!```/`0``
M%`$`````````````UP```,X```"/````?P```%X`````````50$``.$```!I
M````7P$``"L```!^`0``;P$```````!V`0```````````````````````"T!
M```V`0``$P```-,``````````````#$```````````````````#:````(```
M`+\`````````1P```%8````C````C@````````!J````)0`````````3`0``
M0`$```D!``!$`0``^`````````"0````(P$``'`!```^`0``)P$``#8```"Z
M````ZP````````#H`````"`@("`@(%1O.B``("`@($1A=&4Z(``@("`@1G)O
M;3H@`"!3=6)J96-T.B``(&EN(``C`"5D('1O("5D(&]F("5D($UE<W-A9V5S
M`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@
M86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE
M9"X`)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"X`
M)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M
M;VYT:"X`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!<'!L>2!T:&5S
M92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A<F0@
M86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN
M*0`H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN
M9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@
M8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"H@061D('1H
M97-E(&)Y(&-L:6-K:6YG($]+("H`*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H
M97,I("H`,C0@:&]U<G,`04TO4$T`061D('!A:7(`061D<F5S<P!!9&1R97-S
M($)O;VL`06QI87,`06QL`$%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG
M(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F
M:6QE.@!!;&P@;65S<V%G97,@:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T
M:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@
M;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD
M('=I;&P@8F4@9&5L971E9"X`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+@!!;G-W97)E9`!!;G-W97)E9"!M97-S86=E<P!!<'!L>2!F:6QT97(@
M<G5L97,@=7!O;B!L;V=G:6YG(&]N/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@9&\@=&AI<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.
M5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_`$%R<FEV86P@5&EM90!!
M<V-E;F1I;F<`071T86-H`$%T=&%C:&UE;G0`071T86-H;65N=',`079A:6QA
M8FQE(&9I96QD<SH`0F%C:R!T;R`E<P!"8V,`0FER=&AD87D`0FQA8VML:7-T
M`$)O9'D`0F]T:`!#86YC96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N
M96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N`$-C`$-E;&P@4&AO;F4`0VAA
M;F=E`$-H86YG92!!;&P`0VAA;F=E($9O;&1E<@!#:&%N9V4@9&ES<&QA>2!O
M<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E
M86-H('!A9V4@86YD(&AO=R!M97-S86=E<R!A<F4@<V]R=&5D+@!#:&%N9V4@
M=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#
M:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$-H;V]S92!!8W1I;VXZ`$-H
M;V]S92!A(&UA:6P@<V5R=F5R.@!#;&]S92!7:6YD;W<`0VQO<V5D($9O;&1E
M<@!#;VQL87!S92!!;&P`0V]L;&%P<V4@06QL($9O;&1E<G,`0V]L;&%P<V4@
M1F]L9&5R`$-O;7!A;GD`0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E
M('=I;F1O=S\`0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME
M9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U('=H96X@
M:70@87)R:79E<RX`0V]P>0!#;W)R96-T`$-O<G)E8W1E9"!497AT`$-R96%T
M90!#<F5A=&4@1F]L9&5R`$-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R`$-R
M96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE=R!T<F%S
M:"!F;VQD97(`0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y
M;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"!A;F0@
M9&5L971E('-P86TN`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RX`1$0`1&%I;'D`1&%T90!$969A=6QT($ED96YT:71Y`$1E9F%U
M;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO
M;CH`1&5L971E`$1E;&5T92!&;VQD97(H<RD`1&5L971E(&]L9"!S96YT+6UA
M:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T960`1&5L
M971E9"!M97-S86=E<P!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E
M<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&EM('-I9VYA='5R
M97,_`$1I<W!L87D`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@<&]P+75P(&YO
M=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\`1&\@3F]T($-H96-K($9O;&1E<BAS
M*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'``1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\`1&]N
M90!$;W=N;&]A9"!&;VQD97(H<RD`1')A9G0`1')A9G1S(&9O;&1E<CH`161I
M=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5M86EL`$5M86EL($%D9')E<W,`
M16UP='D@1F]L9&5R*',I`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T>2!R97-U
M;'0N`$5N9"!F;W)W87)D960@;65S<V%G90!%;G1E<B!T:&4@;F%M92!F;W(@
M>6]U<B!N97<@9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@<V5N="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@=')A<V@@9F]L9&5R`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E
M<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E
M<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AP
M86YD($%L;`!%>'!A;F0@06QL($9O;&1E<G,`17AP86YD($9O;&1E<@!%>'!A
M;F0@3F%M97,`17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F
M875L="!I;B!T:&4@9F]L9&5R<R!V:65W/P!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A>`!&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_`$9I
M;'1E<G,`1FEN9`!&:7)S="!086=E`$9O;&1E<B!.879I9V%T;W(`1F]R=V%R
M9`!&;W)W87)D.@!&;W)W87)D960@;65S<V%G92!F<F]M("5S`$9R;VT`1G)O
M;2!!9&1R97-S`$9W9#H`2&5L<`!(:61E($1E;&5T960`2&ED92!5;G-U8G-C
M<FEB960`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`24Y"3U@`26-O
M;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`26=N;W)E`$EG;F]R92!!;&P`26UP
M;W)T86YT`$EM<&]R=&%N="!M97-S86=E<P!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@
M82!R97!L>3\`3&%N9W5A9V4`3&%S="!086=E`$QI<W0@2&5L<"!4;W!I8W,`
M3&]G(&EN`$QO9R!I;B!T;R`E<P!,;V<@;W5T`$QO9VEN(%1A<VMS`$U-`$UA
M:6QB;W@`36%R:R!A<SH`36%R:R!D:69F97)E;G0@;&5V96QS(&]F('%U;W1I
M;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/P!-871C:&EN9R!F:65L9',`365N
M=2!M;V1E.@!-97-S86=E`$UE<W-A9V4@0V]M<&]S:71I;VX`365S<V%G92!$
M871E`$UE<W-A9V4@4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C
M90!-97-S86=E(%9I97=I;F<`365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E
M<G,`365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S
M<V%G97,@=&\`36]D:69Y`$UO;G1H;'D`36]V90!.86UE`$YE=F5R`$YE=P!.
M97<@1F]L9&5R`$YE=R!-86EL`$YE=R!M97-S86=E<P!.97AT`$YE>'0@365S
M<V%G90!.97AT(%!A9V4`3F\`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9`!.
M;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S=&EO;G,`3F]N90!.;W0@1&5L
M971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T
M(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.;W1E
M<P!.=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@
M9&5L971I;F<@;6]N=&AL>2X`3TL`3VQD(&UE<W-A9V5S`$]L9"!S96YT+6UA
M:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]P=&EO;G,`3W1H97(@26YF;W)M
M871I;VX`3W1H97(@3W!T:6]N<P!086=E("5D(&]F("5D`%!A<G0H<RD`4&%S
M<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R<V]N86P`4&5R
M<V]N86P@26YF;W)M871I;VX`4&AO;F4`4&QA8V4@>6]U<B!S:6=N871U<F4@
M8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/P!0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N86UE
M(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE
M.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S
M92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE
M87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C
M=&EO;G,N`%!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S
M96%R8V@N`%!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES
M(&]P97)A=&EO;BX`4')E=FEO=7,@365S<V%G90!0<F5V:6]U<R!086=E`%!R
M:6YT`%!R;V)L96T@1&5S8W)I<'1I;VX`4'5R9V4@1&5L971E9`!0=7)G92!4
M<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E
M<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N`%)E9&ER96-T`%)E
M9&ER96-T($UE<W-A9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T
M:6YG(&9A:6QE9"X`4F5F<F5S:`!2969R97-H($9O;&1E<B!6:65W<SH`4F5L
M;V%D(%9I97<`4F5M96UB97(@=&AE(&QA<W0@=FEE=P!296UO=F4@<&%I<@!2
M96YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`4F5P;&%C92!W:71H.@!297!L>0!297!L>2!T;R!!
M;&P`4F5P;'D@=&\@06QL.@!297!L>2U4;SH@`%)E<&QY.@!297!O<G0@87,@
M4W!A;0!297-E=`!297-U;64`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O
M('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@
M;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%-A=F4@1')A9G0`4V%V92!/<'1I;VYS
M`%-A=F4@87,`4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("5S`%-E87)C:`!396%R8V@@4F5S=6QT<P!3
M965N`%-E;&5C=`!396QE8W0@86QL`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@365S<V%G
M90!396YD(%!R;V)L96T@4F5P;W)T`%-E;G0@;6%I;"!F;VQD97(Z`%-E<G9E
M<@!3970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M
M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N`%-H;W5L9"!T:&4@8V]M<&]S92!W
M:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/P!3:&]W($1E
M;&5T960`4VAO=R!5;G-U8G-C<FEB960`4VAO=R!L96=E;F0@:6X@=&AE(&UA
M:6QB;W@@=FEE=S\`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5L;"!#:&5C:P!3
M<&5L;"!#:&5C:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R
M<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-U8FIE8W0`
M4W5B:F5C="!&:65L9`!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U8V-E<W,`
M4W5G9V5S=&EO;G,`5&%S:W,`5&5X=`!497AT($]N;'D`5&AE(&-U<G)E;G0@
M9F]L9&5R*',I("(E<R(@=VEL;"!B92!R96YA;65D('1O("(E<R(N`%1H92!F
M;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L9&5R("(E<R(@8V]N
M=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@
M8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A=&5D(&)U="!Y;W4@
M=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O;&1E<B`B)7,B('=A
M<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@
M:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@
M9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L
M9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R
M("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E
M<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!S:6=N
M871U<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"X`5&AE<F4@87)E(&YO
M(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B`B)7,B+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&9L
M86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN
M9R!Y;W5R(&UE<W-A9V4Z("5S`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G
M92!T;P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:')E860@5FEE=P!4:71L90!4;P!4
M<F%S:"!F;VQD97(Z`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%N<W=E<F5D`%5N86YS=V5R960@;65S<V%G97,`56YD96QE=&4`56YD:7-C
M;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`56YN86UE9`!5;G-E96X`
M56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RD`57-E($1E9F%U;'0@5F%L=64`
M57-E($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_`%5S97(@3W!T:6]N<P!5
M<V5R;F%M90!6:65W("5S`%9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN.@!787)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y
M;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@=&AE;2!A<R!D
M96QE=&5D/P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S
M`%EO=2!A<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+@!9;W4@
M87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R``66]U(&%R92!C<F5A=&EN
M9R!A('1O<"UL979E;"!F;VQD97(N`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O
M;&1E<CH@`%EO=2!H879E("5S(&YE=R!M97-S86=E<RX`66]U(&AA=F4@,2!N
M97<@;65S<V%G92X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN
M9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@
M9F]L9&5R<SH`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T('-E
M;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+@!9;W4@;75S="!S96QE8W0@
M86X@861D<F5S<R!F:7)S="X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N
M92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT
M+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(97)E(&ES('=H
M870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@
M9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W
M97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`66]U('=E<F4@
M<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@
M26YF;W)M871I;VX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9
M;W5R('-I9VYA='5R93H`6TYO(%-U8FIE8W1=`%M0<F]B;&5M(%)E<&]R=%T`
M6VQI;F4@)7,@;V8@)7-=`&9R;VT`;F]N90!O<@!S<&5L;&EN9R!E<G)O<@!S
M<&5L;&EN9R!E<G)O<G,`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!)35`Z
M(#,N,BUC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P
M,`I03RU2979I<VEO;BU$871E.B`R,#`Q+3`U+3`U(#$U.C`P*S`R,#`*3&%S
M="U4<F%N<VQA=&]R.B!3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-U<'!O<G1?
M=V5B;6%I;$!T96EA=&@N9W(^"DQA;F=U86=E+51E86TZ($=R965K(#QD979`
M;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM-PI#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`("`@(-#Q[_(Z`,?LY?'O[.?MW^$Z
M`"`@("#!\/PZ`"#(W>SA.@`@\^4@`",`)60@W?GR("5D(.'P_"`E9"#,Y^W]
M[.'TX0`E<R#+Y>GT[_7QX]_E\B#3]>WTWO'G\^?R("T@Q?#IXN7BX=_Y\^<`
M)7,@]?#<\??EZ2#>Y.<N(,\@)7,@]MSJY>OO\B#DY>T@[.7T[^WO[-SS].?J
MY2X`)7,@Y.7M(.7?[>'I(-WCZO7Q[R#C\>'L[.'T[^KIXO[TZ>\N`"5S(/;<
MZN7K[_(@Z.$@[.7T[^WO[.'S].7?(//TY^T@X?'WWB#T[_4@[-[MX2X`)7,Z
M("5S("@E9"9N8G-P.^'P_"9N8G-P.R5D*0`HQ?;A\>SOX]X@X?7T_NT@]/GM
M(.'KZ^'C_NT@ZN'I(.SE].'JW^WG\^<@\_3G[2#E\/SLY>WG(._H_.WG+BD`
M*,'P_/'QZ?CG(/SK^>T@]/GM(.'KZ^'C_NT@ZN'I(.7PZ?/T\>_VWB#S].?M
M(._H_.WG(//][>CE\^?R(.SG[?WLX?3O\BXI`"C%\.GS]/'O]MX@\_3G[2#O
MZ/SMYR#S_>WHY?/G\B#A]N_](-WW[_7M(.7VX?'L[_/TY=\@_.OE\B#OZ2#A
MZ^OAX]WR+B#/Z2#AZ^OAX]WR(//E(.'U]-X@].?M(._H_.WG(,3%S2#HX2#E
M]N'Q[._S]._][2XI`"H@T/'O\^C>ZN<@X?7T_NT@Y?#IZ]WC[^WTX?(@S\H@
M*@`J(-#A\>'JX>O^(.7PZ>O=[O3E(/3G(.3IY?WH]>WSYRCEZ?(I("H`,C3^
M\><@[._Q]MX`T,POS,P`T/'O\^C>ZN<@YN7]X^_U\@#$Z>7]Z/7M\^<`Q.GE
M]>CU[?/I[^/QW/;O\@#8Y?7D_NWU[.\`3^OA`+SKX2#TX2#LY^W][.'TX2#S
M]._M*._U\BD@X>K\Z^_UZ.\@]MSJY>OO*._U\BGHX2#LY?3A]MWQ[_7M(//E
M(-WMX2#VW.KEZ^\@.@"\Z^$@].$@[.?M_>SA].$@\_3O(/;<ZN7K[R`B)7,B
M(/#O]2#EW^WAZ2#PX>OI_/3E\>$@X?#\("5S(.?LW?'E\B#HX2#DZ>'C\>'V
M[_WM(.S\[>GLX2X`O.OOZ2#OZ2#VW.KEZ^_I(.SE(.'PY?/TX>OLW>WA(/#O
M]2#EW^WAZ2#PX>OI_/3E\>_I(.'P_"`E<R#LWNWE\B#HX2#DZ>'C\>'V[_WM
M+@#/\=_S].?JY2#LW^$@[.<@Y?#I]/'E\/SLY>WG(/3I[-XN`,'PX>WTY^S=
M[>$`P?#A[?3G[-WMX2#LY^W][.'TX0#%]N'Q[._CWB#T^>T@ZN'M_.WY[2#V
MW^OT\?GM(.K<Z.4@]N_QW"#P[_4@ZMSMY?3E(.7I\^'C^>/>.P#%W_/TY2#S
MW^/O]?'OZ2#P^?(@Z-WKY?3E(.WA(.7J].7KW?/E].4@X?7TWB#TY^T@Y>W=
M\>/EZ>$[`,7?\_3E(//?X^_U\>_I(/#Y\B#HW>OE].4@[>$@Y.GAX_'<^.7T
MY2#A]?3<(/3A(.SG[?WLX?3A(,S/S<G,P3L`Q=_S].4@\]_C[_7Q[^D@\/GR
M(.C=Z^7TY2#MX2#AY.7IW//E].4@X?7T_"#T[^T@]MSJY>OO.P#%W_/TY2#S
MW^/O]?'OZ2#P^?(@Z-WKY?3E(.WA(.'DY>G<\^7TY2#T[^T@ZMSD[SL`O_'A
M(,O>^.?R`,'][N_U\^$`Q?#I\_WMX?CG`-/U[>?L[-WM[P#3]>WG[.S=[>$`
MQ.GAZ-WSZ>SA(-#EY-_A.@#%\.GS]/'O]MX@\_3A("5S`,KQ]?;>(,KOZ>WO
M\._?Y_/G`,/E[=WHZ^GA`,7M[_?KY_3IZMX@P>OKY^OOX_'A]M_A`,KEW^SE
M[>\@S.?M_>SA]._R`,KAZ2#TX2#D_>\`P>K]\?GSYP#!ZOWQ^?/G(,SG[?WL
MX?3O\@#!ZOWQ^?/G(,'MX?;O\=SR(-#Q[^+KWNSA]._R`,'J]?'^[>_M].'R
M(.'U]/P@].\@[-[M]>SA(.CA(/?AZ._][2#O\>GS].GJW"#TX2#PY?'IY??\
M[.7MX2#T[_4N`,KOZ>WO\._?Y_/G`,KI[>?T_"#4Y^O=]OGM[P#!Z^OAX]X`
MP>OKX>/>(+SK^>T`P>OKX>/>(-;AZMWK[_4`S/#O\>7?].4@[>$@X>OKW.[E
M].4@].GR(.7PZ>OOX]WR(.7L]MSMZ?/G\BP@_/#Y\B#EW^WAZ2#O(.'QZ>CL
M_/(@[.?M]>S<]/GM(/#O]2#BZ]WPY?3E(.'MW"#SY>O?Y.$@ZN'I(.\@]/'\
M\._R(/3A[NGM_.SG\^?R(/3Y[2#LY^WU[-ST^>TN`,SP[_'EW_3E(.WA(.'K
MZ]SNY?3E(/3O(/SM[^SA+"#TYR#DZ>7]Z/7M\^<@ZN'I(/3G[2#U\._C\>'V
MWB#SX?(L(//T[^GWY=_A(/#O]2#BZ]WP[_7M(._I(/#A\>'KWO#TY?(@\^'R
M(/STX>T@Y.GAXMSF[_7M(-X@X?#A[?3<[>4@\_3A(.SG[?WLX?3<(//A\BX`
MN.OEX_?O\B#6X>K=Z^_U*/GM*2#CZ>$@S=WA(,SG[?WLX?3A`,7PZ>O=[O3E
M(,7MW?'CY>GA.@#%\.GKW>[TY2#$Z>'J[^SI\_3>(,'KZ^?K[^/QX?;?X?(Z
M`,KKY=_SZ>SO(-#A\=SH]?'O]0#*Z^7I\_3\\B#6W.KEZ^_R`,'MW/#T]>[G
M(/SK^>T`P>W<\/3U[N<@_.OY[2#T^>T@UN'JW>OY[0#![=SP]/7NYR#6X>K=
MZ^_U`,7TX>GQW^$`QR#S_>WHY?/G(/3Y[2#LY^WU[-ST^>T@[>$@X]_MY?3A
MZ2#SY2#MW>\@\.'QW.CU\>\[`,7PZ>O=[O3E(.K<Z.4@\/STY2#CW^WE].'I
M(-WKY>/W[_(@X^GA(.W=X2#LY^W][.'TX2P@ZN'I(.'M(.CA(.7IY._P[^GE
MW_/TY2#\].'M(-WQ]^_M].'I+@#![?3IX_'A]MX`T_GS]/P`Q.GO\>CY[-WM
M[R#*Y=_LY>WO`,3G[.GO]?'CW^$`Q.?LZ>_U\>/?X2#6X>K=Z^_U`,3G[.GO
M]?'CW^$@S=WO]2#6X>K=Z^_U("?0\?SWY>GQX2<`Q.?LZ>_U\>/?X2#-W>_U
M(-;AZMWK[_4@)\'PY?/TX>OLW>WA)P#$Y^SI[_7QX]_A(,W=[_4@UN'JW>OO
M]2`GQ.GAX_'A[.S=[>$G`,3G[.GO]?'CW^$@]M_K]/'Y[2#CZ>$@].?M(._Q
MX]SM^?/G(/3Y[2#EZ?/E\??\[.7M^>T@[.?M]>S<]/GM(//E(/;AZMWK[_7R
M(.KAZ2#DZ>'C\>'VWB#A[>7PZ>C][.?T^>T@[.?M]>S<]/GM("AS<&%M*2X`
MT?WH[.GSYR#T^>T@Y>WE\>/EZ?[M(/#O]2#HX2#EZO3EZ^_][?3AZ2#JX?3<
M(/3G[2#EW_/OY.\@\_3G[2#U\.?QY?/?X2`E<RX`1$0`Q^SE\=[SZ>$`Q^SE
M\>_LY^W?X0#0\>_E\.GKY>/LW>WG(-3A]?3\].?TX0#0\>_E\.GKY>/LW>WA
M(.KQZ?3>\>GA(/3A[NGM_.SG\^?R.@#0\>_E\.GKY>/LW>WG(.KA].7]Z/7M
M\^<@].'NZ>W\[.?SY_(Z`,3IX>/QX?;>`,3IX>/QX?;>(-;AZMWK[_4H^>TI
M`,WA(.3IX>/QW/;O[?3AZ2#OZ2#PX>OI[]\@ZN'TW.OOX^_I(,'0Q=/4P<O,
MQ<W!(//TY^T@X?'WWB#JW.CE(.S>[>$_`,3IX>/QX>SLW>WA`,3IX>/QX>SL
MW>WA(.SG[?WLX?3A`,3IX>/QX?;>(.KAZ2#,Y?3A]N_QW"#,Y^WU[-ST^>T`
MUNC?[>_U\^$`T.7QZ>/QX?;>(/3O]2#0\>_BZ][LX?3O\@#/Z2#KY?#T[^S=
M\>7IY?(@W??O]>T@ZN'TX>/QX?;EWR#CZ>$@]._M(.3IX??EZ?'I\_3>+@#'
M(/7P[^/QX?;>(//A\CL`Q>SVW.WI\^<`Q?#IZ^_CW?(@Q>SVW.WI\^?R`,7L
M]MSMZ?/G(.7IY._P[]_G\^?R(.KA]-P@].?M(/#A\>'KX>+>(.W=^>T@[.?M
M]>S<]/GM.P#-X2#LY^T@X]_MY?3AZ2"XZ^7C]^_R(//T[^TH[_7R*2#6W.KE
MZ^\H[_7R*2#CZ>$@[=WA(.SG[?WLX?3A`,SG[2#E\.GWY>GQWO/E].4@[>$@
MX>WOW^[E].4@X?#E]>CEW^'R(/3O(.'Q]^7?[R!M86EN=&5N86YC92YP:'``
MR-WKY?3E(.WA(.'M[]_NY?3E(.'U]/SM(/3O[2#VW.KEZ^\[`+CCZ>WE`-;<
MZN7K[_(@P>WAZO3G[-WM^>T`T/'\]^7I\>$`UMSJY>OO\B#0\?SWY>GQ^>TZ
M`,7PY>[E\>/A\]_A`,7PY>[E\>/A\]_A(/3Y[2#JX>W\[?GM(/;?Z_3Q^>T`
MP>OKY^OOX_'A]M_A`,3IY?WH]>WSYR#!Z^OGZ^_C\>'VW^'R`*+DY>GA\^SA
M(-;AZMWK[_4H^>TI`*+DY>GA\^SA(-;AZMWK[_4@Q.GAX_'A[.S=[>$`Q.7M
M(.7PZ?/T\=SVY^KA[2#!\._TY>O=\^SA].$N`-3=Z^_R(/#Q[_GHY^S=[>_U
M(.SG[?WLX?3O\@#$_O/TY2#T[R#\[>_LX2#CZ>$@].\@[=WO(/;<ZN7K[R`G
MT/'\]^7I\>$G`,3^\_3E(/3O(/SM[^SA(./IX2#T[R#MW>\@]MSJY>OO(,'P
MY?/TX>OLW>WA`,3^\_3E(/3O(/SM[^SA(./IX2#T[R#MW>\@]MSJY>OO("?0
M\?SWY>GQX2<`R]SH[_(`RMSHY2`Q-2#+Y?#TW`#*W.CE(#,P(,OE\/3<`,K<
MZ.4@-2#+Y?#TW`#*W.CE(/;O\=P@\._U(.SPX=_MY?3E(//TY^T@]?#G\>7S
MW^$`RMSHY2#LZ?/>(/[QX0#*W.CE(.OE\/3\`-#A\>'DY>GC[.'TZ>K=\B#T
MZ>S=\CH`P>W<\/3U[N<@O.OY[0#![=SP]/7NYR"\Z_GM(/3Y[2#6X>K=Z_GM
M`,'MW/#T]>[G(-;AZMWK[_4`P>W<\/3U[N<@S^WO[-ST^>T`S>$@X]_MY?3A
MZ2#PW.WTX2#A[=SP]/7NYR#\Z^_U(/3O]2#DW>WT\>_U(/3Y[2#VX>K=Z_GM
M.P#!\._T]???X2#JX?3<(/3G[2#P\>_S\-SHY>GA(.'MW.KTY_/G\B#T^>T@
M\/'O].GLWO/E^>TN`,'P[_3U]]_A(//][>3E\^?R(//T[^T@Y.GAZN_LZ?/T
MWB#*X?3AZ_SC[_4N`-;!S@#-X2#6Z>OT\=SQY?3AZ2#T[R#PY?'IY??\[.7M
M[R#T^>T@[.?M]>S<]/GM(./IX2#UXO'I\_3IZOP@\.7QZ>7W_.SE[>\[`-;?
MZ_3QX0#![>'FWO3G\^<`P?'WZ>K>(-/EZ]_DX2``UMSJY>OO\B!.879I9V%T
M;W(`T/'O_NCG\^<`T/'O_NCG\^<Z`-#Q[_[HY_/G(.SG[?WLX?3O\B#A\/P@
M)7,`P?#\`,3IY?WH]>WSYR#!\._S]._KW>$`T/'O_N@N.@#"[][HY>GA`,'P
M_.KQ]?CG(,3IY>/QX>SLW>WY[0#!\/SJ\?7XYR#LWB#S]>WDY>S=[?GM`,3I
MY?WH]>WSYR#3\.GTZ>_]`-3GZ]WV^>WO(-/PZ?3I[_T`P?'WZ>K>(-/EZ]_D
MX0#%Z?/E\??\[.7MX0#,_.WO(,7IZN_MW^3IX0#%Z>KO[=_DZ>$@ZN'I(,KE
MW^SE[>\`T.'QW.+KY?CG`-#A\=SBZ^7XYR`GO.OY[0#3Y^SA[?3IZMP`T^?L
MX>WTZ>K<(.SG[?WLX?3A`-#EY-_O(/#O]2#EZ?/>]^CG.B`E<P#0Y>3?X2#P
M[_4@Y>GSWO?HY_/A[3H`Q>WS^>S<]/GSYR#T[_4@X?'WZ>KO_2#LY^W][.'T
M[_(@\_3I\B#A\.'M]-[SY>GR.P##Z_[S\^$`U.7KY?7TX=_A(-/EZ]_DX0#+
MW_/TX2#HY>S<]/GM(,+OWNCEZ>'R`,7?\^_D[_(`Q=_S[^3O\B#S].\@)7,`
MN.[OY._R`,7MW?'CY>GE\B#P[_4@Y>KTY>OO_>WTX>D@ZN'TW"#TY^T@Y=_S
M[^3O`,S,`,/QX>SLX?3OZNGB_O3I[P#7X?'AZO3G\>GS[/SR(/GR.@#-X2#E
M[/;A[=_F[^WTX>D@[^D@X?#A[?3>\^7I\B#LY2#DZ>'V[_'E].GJW"#W\?[L
MX?3A.P#0Y>3?X2#P[_4@].'I\>G<YN_U[0#*X?3<\_3A\^<@S.7M[_TZ`,S>
M[?7LX0#3_>WHY?/G(,SG[?WLX?3O\@#'[.7Q[^SG[=_A(,SG[?WLX?3O\@#!
M[>'FWO3G\^<@S.?M]>S<]/GM`,S=X^7H[_(@S.?M_>SA]._R`-#GX^'?[_(@
MRO[DZ>KA\@#0\>_B[^O>(,SG[?WLX?3O\@#![>'FWO3G\^<@\_WL]OGMX2#L
MY2#TYR#SWNSA[?/G(/3O]2#LY^W][.'T[_(`P>WAYM[TY_/G(//T[_7R(/;A
MZMWK[_7R`,SG[?WLX?3A(.'MW"#SY>O?Y.$@\_3G[2#P\>_B[^O>(/3O]2##
M\>'L[.'T[^KIXO[TZ>_U+@#P\>_R`-3Q[_#O\._?Y_/G`,SG[>GAW^$`S.7T
MX?;O\=P`O.WO[.$`T._TW0#-W>$`Q>GSX>/YX]X@UN'JW>OO]0#-W>\@S-[M
M]>SA`,W=X2#LY^W][.'TX0#%\/SLY>WO`,7P_.SE[>\@S-[M]>SA`,7P_.SE
M[><@T^7KW^3A`+SWZ0#$Y>T@W??O]>T@[_'I\_3EWR#VW.KEZ^_I`,3E[2#U
M\-SQ]^_U[2#O\>COX_'A]NGJW"#KW.CG`,3E[2#U\-SQ]^_U[2#0\>_TW//E
MZ?(`RN'MW>WA`,SG(,3IX>/QX>SLW>WA`,SG(-#Q_/?EZ?'A`,SG(//G[.'M
M].GJW`#,YR#P\>_S^?#IZMP`S.<@Q.GAX_'A[.S=[>$@[.?M_>SA].$`S.<@
M\^?LX>WTZ>K<(.SG[?WLX?3A`-/G[.7I_O/EZ?(`P?'IZ.S\\B#VX>K=Z_GM
M(,'0Q=/4P<O,Q<W!(/#O]2#DY>T@Z.$@Y.GAX_'<]N_M].'I(.'MW"#LWNWA
M+@#%[?3<[N7I`-#AZ^G<(,SG[?WLX?3A`-#AZ^GOWR#6W.KEZ^_I(.SE(.'P
MY?/TX>OLW>WA(/#O]2#DZ>'C\=SV[^WTX>DN`,7PZ>OOX]WR`,'KZ^7R(-#K
MY_'O]N_QW^7R`,'KZ^7R(,7PZ>OOX]WR`-/EZ]_DX2`E9"#A\/P@)60`S-WQ
M[_(HYRD`ROGDZ>K\\@#%ZO3=Z^7SYR#+Y>GT[_7QX^G^[2#3]>WTWO'G\^?R
M`,WA(.7J].7K[_WM].'I(.OEZ?3O]?'CW^7R(//U[?3>\>?SY_(@ZN'TW"#T
MY^T@Y=_S[^3O(//TY^T@]?#G\>7SW^$[`-#Q[_/Y\.GJW`#0\>_S^?#IZMWR
M(-#KY_'O]N_QW^7R`-3GZ]WV^>WO`,WA(/3O\._HY?3EW_3AZ2#G(/7P[^/Q
MX?;>(//A\B#P\>GM(.'P_"#TZ?(@X?#A[?3>\^7I\B#JX>D@].GR(/#Q[_GH
MWO/EZ?(@]/GM(.SG[?7LW/3Y[2#SX?([`-#A\>'JX>O^(.3^\_3E(-WMX2#\
M[>_LX2#CZ>$@]._M(.W=[R#VW.KEZ^\Z`-#A\>'JX>O^(.3^\_3E(/3O(/SM
M[^SA(/3O]2#MW>_U(/;AZMWK[_4Z`-#A\>'JX>O^(.7I\]SCY?3E(/3O(.W=
M[R#\[>_LX3H`T.'QX>KAZ_X@Y/[S].4@[-_A(/#E\=_KY_CG(/3O]2#P\>_B
MZ][LX?3O\BX`T.'QX>KAZ_X@Y/[S].4@].\@O.WO[.$@U_'>\_3G(.KAZ2#T
M[^T@ZOGDZ>K\(//A\@#0X?'AZN'K_B#DZ>_QZ/[S].4@].?M(.3IY?WH]>WS
MYRP@Y=_MX>D@\.GHX>W\].'TX2#KX>WHX?/LW>WG+@#0X?'AZN'K_B#E\.GK
MW>[E].4@W>WA(/;<ZN7K[R#P\>GM(.K<[>7TY2#O\._IX>3>\._TY2#E[=WQ
MX^7IX2X`T.'QX>KAZ_X@Y?#IZ]WNY?3E(/3O]>O<]^GS]._M(-WMX2#JX?3<
MZ^_C[R#CZ>$@X>WAYM[TY_/G+@#0X?'AZN'K_B#E\.GKW>[TY2#L_.WO(-WM
MX2#VW.KEZ^\@X^GA(.'U]-[M(/3G[2#KY>GT[_7QX]_A+@#0\>_GX^_][.7M
M[R#,WNWU[.$`T/'OY^/O_>SE[><@T^7KW^3A`,7J]/WP^?/G`-#E\>GC\>'V
MWB#0\>_BZ][LX?3O\@#/\>GS].GJWB#$Z>'C\>'VW@#-X2#!Y.7IW.;EZ2#O
M(.K<Y._R(.K<Z.4Z`,WA(.3IX>/QW/;O[?3AZ2#TX2#LY^W][.'TX2#A\/P@
M]._M(.K<Y.\@\._U(.7?[>'I(/#AZ^G\].7QX2#A\/P@X?7T_"#T[^T@X?'I
MZ.S\(.?LY?'^[2X`P>WAZN'TY?WH]>WSYP#![>'JX?3E_>CU[?/G(,SG[?WL
MX?3O\@#![>'JX?3E_>CU[?/G(.'U]._](/3O]2#,Y^W][.'T[_(`QR#A[>'J
MX?3E_>CU[?/G(.'PW?3U]^4N`,'MX>W=^?/G`,'MX>W=^?/G(-#Q[^+OZ][R
M(-;AZMWK^>TZ`,'MX>W=^?/G(-#Q[^+OZ][R`,WA(/#A\>'LW>WEZ2#G(/3E
MZ^7U].'?X2#P\>_B[^O>`,'VX=_QY?/G(.;E_>/O]?(`S.7T[^WO[.'SW^$@
M]._U(/;AZMWK[_4@P=#%T]3!R\S%S<$@\_3G[2#A\??>(.K<Z.4@[-[MX3L`
MQR#LY?3O[>_LX?/?X2#T[_4@]N'JW>OO]2`B)7,B(//E("(E<R(@X?#=]/7W
MY2X@U.\@\_WS].?LX2#=XN/AZ^4@].\@X>K\Z^_UZ.\@[-[M]>SA`,'M].GJ
MX?3<\_3A\^<@[.4Z`,'PW.WTY_/G`,'PW.WTY_/G(//E(/SK[_7R`,'PW.WT
MY_/G(//E(/SK[_7R.@#!\-SM].?SYRW0\>_R.@#!\-SM].?SYSH`P>WA]N_Q
MW"#LY^W][.'T[_(@^?(@)U-P86TG`,KAZ.'QZ?/L_/(@UOSQ[.'R`-/U[=WW
MY>GA`,7PZ?/T\>_VWB#S].GR(,7PZ>OOX]WR`,7PZ?/T\>_VWB#S]._M(/;<
MZN7K[R#%Z?/E\??\[.7MX2#LY?3<(.'P_"#DZ>'C\>'VWBP@[.7TX?;O\=P@
MWB#A[?3IX_'A]MX@[.?M_>SA]._R/P#!\._HWNKE]?/G(//T[R#0\?SWY>GQ
M[P#!\._HWNKE]?/G(,7PZ>OOX_[M`,'P[^C>ZN7U\^<@^?(`QR#A\._HWNKE
M]?/G(/3O]2#P\?SWY>GQ[_4@[.?M_>SA]._R(.'PW?3U]^4N(-3O(//]\_3G
M[.$@W>+CX>OE(/3O(.'J_.OO]>CO(.S>[?7LX3H@)7,`P>WAYM[TY_/G`,'P
M[_3EZ]WS[.'TX2#![>'FWO3G\^?R`,3IX>+A\^S=[>$`Q?#IZ^_CW@#%\.GK
M[^/>(/SK^>T`Q?#IZ^_CWB#JX>WE[?SR`,7PZ>OOX]X@]._U(.3IX??Y\>GS
M]-X@Y^SE\>_LY^W?X?(Z`,7PZ>OOX]X@].?R(.SO\?;>\B#P[_4@Z.$@W??E
MZ2#G(.?LY?'O[.?MW^$Z`,7PZ>OOX]X@].?R(.SO\?;>\B#P[_4@Z.$@W??E
MZ2#G(/[QX3H`Q?#IZ]WN].4@Y/WO(/#EY-_A(/#O]2#TX>GQZ=SF[_7M+@#%
M\.GKW>[TY2#TYR#CZ_[S\^$@\^'R.@#!\._S]._KWB#,Y^W][.'T[_(`P?#O
M\_3OZ]X@P>WA]N_QW/(@T/'OXNO>[.'T[_(`UMSJY>OO\B#!\.7S].'K[-WM
M^>T@S.?M]>S<]/GM.@#$Z>'J[^SI\_3>\@#1]>CLW_/EZ?(@X^GA(/3G(.SE
M].'V[_'<(.KAZ2#DZ>'C\>'VWB#LY^WU[-ST^>TN`,WA(.KKY=_MY>D@].\@
M\.'QW.CU\>\@\_WMZ.7SY_(@[.7TW"#TY^T@X?#OZ-[JY?7SYR#T[_4@[.?M
M_>SA]._R(//TX2#P\?SWY>GQX3L`Q>SVW.WI\^<@Q.GAX_'A[.S=[?GM`,'P
M_.KQ]?CG(.'S_>WDY?3Y[2`H56YS=6)S8W)I8F5D*2#VX>K=Z_GM`,WA(.7L
M]N'MW^;E].'I(.<@Y?#IX_'A]MX@\_3G[2#P\>_B[^O>(/3O]2##\>'L[.'T
M[^KIXO[TZ>_U.P#,W>/EZ._R`,'J_?'Y\^<@T_7M]-[QY_/G\@#%Z?/AX_GC
MWB#%Z>3IZO[M(-?A\>'J]-[Q^>T`Q>GDZ>KOWR#WX?'AZO3>\>7R`,_QZ._C
M\>'VZ>K\\B"XZ^7C]^_R`,_QZ._C\>'VZ>K\\B#%Z^7CZO3>\@#/\>COX_'A
M]NGJ_/(@W>OEX_?O\B#OZ^_JZ^?Q_NCGZN4`S_'H[^/QX?;IZMP@Z]SHYR#A
M[=P@\^7KW^3A(/STX>T@X]_MY?3AZ2#O\>COX_'A]NGJ_/(@W>OEX_?O\BX`
MR-WLX0#(W>SA(.SG[?WLX?3O\@#3_>WDY?/G(//T[R#6W.KEZ^\H[_7R*0#%
M\.GT]???X0#0\>_TW//EZ?(`Q?'CX?/?Y?(`RN7?[.7M[P#,_.WO(,KEW^SE
M[>\`SR#T\=WW^>T@]MSJY>OO\BCOZ2D@(B5S(B#HX2#LY?3O[>_LX?/TY=\@
M\^4@(B5S(BX`SR#VW.KEZ^_R("(E<R(@]?#<\??EZ2#>Y.<`U.\@_.WO[.$@
M]._U(/;AZMWK[_4@(B5S(B#PY?'IW??EZ2#LYR#E\.GT\>7P_.SE[>_U\B#W
MX?'AZO3>\>7R+B#,\._QY=\@[>$@]?#<\>[O]>T@\/'OXNO>[.'TX2X@Q>WG
M[.7Q_O/TY2#T[R#DZ>'WY>GQZ?/TWB#T[_4@\_7S]-[LX?3O\BX`SR#VW.KE
MZ^_R("(E<R(@Y.?LZ>_U\>/>Z.?JY2#AZ^O<(.3E[2#S]>WDY>C>ZN'TY2#S
MY2#A]?3\[2X`SR#VW.KEZ^_R("(E<R(@Y.GAX_'<]N?JY2#AZ^O<(.3E[2#A
M\._S]>WDY>C>ZN'TY2#A\/P@X?7T_.TN`,\@]MSJY>OO\B`B)7,B(.3E[2#D
MY^SI[_7QX][HY^KE+B#4[R#S_?/TY^SA(-WBX^'KY2#T[R#AZOSK[_7H[R#L
MWNWU[.$`SR#VW.KEZ^_R("(E<R(@Y.7M(.3IX>/QW/;GZN4N(-3O(//]\_3G
M[.$@W>+CX>OE(/3O(.'J_.OO]>CO(.S>[?7LX0#/(/;<ZN7K[_(@(B5S(B#D
MY^SI[_7QX][HY^KE(.SE(.7PZ?3U]]_A+@#/(/;<ZN7K[_(@(B5S(B#DZ>'C
M\=SVY^KE(.SE(.7PZ?3U]]_A+@#/(/;<ZN7K[_(@(B5S(B#LY?3O[>_LW//T
MY^KE(.SE(.7PZ?3U]]_A(//E("(E<R(N`,<@]?#OX_'A]MX@X>WTZ>KA].'S
M]-SHY^KE(.SE(.7PZ?3U]]_A+@#$Y>T@]?#<\??O]>T@[.?M_>SA].$@\^4@
MX?7T_"#T[R#C\>'L[.'T[^KIXO[TZ>\N`-#A\>_U\^G<\_3GZN4@\_;<Z^SA
M(//TYR#DZ>'C\>'VWB`E<RX@U.\@\_WS].?LX2#=XN/AZ^4@].\@X>K\Z^_U
MZ.\@[-[M]>SA`-#A\>_U\^G<\_3GZN4@\_;<Z^SA(//TYR#DZ>'C\>'VWB#T
M[_4@X_'A[.SA]._JZ>+Y]-_O]2X@U.\@\_WS].?LX2#=XN/AZ^4@].\@X>K\
MZ^_UZ.\@[-[M]>SA`-#A\>_U\^G<\_3GZN4@\_;<Z^SA(.KA]-P@].<@Y.GA
MX_'A]MX@]/GM(.SG[?7LW/3Y[2#A\/P@].\@]MSJY>OO("(E<R(N(-3O(//]
M\_3G[.$@W>+CX>OE(/3O(.'J_.OO]>CO(.S>[?7LX0#0X?'O]?/IW//TY^KE
M(//VW.OLX2#JX?3<(/3G(.3IX>/QX?;>(/3Y[2#LY^WU[-ST^>T@\_3O(/;<
MZN7K[R`B)7,B+B#4[R#S_?/TY^SA(-WBX^'KY2#T[R#AZOSK[_7H[R#LWNWU
M[.$`U?#>\>[E(.O<Z._R(.KA]-P@].?M(.7L]MSMZ?/G(.'U]._](/3O]2#L
MW?'O]?(@]._U(.SG[?WLX?3O\@#0X?'O]?/IW//TY^KE(//VW.OLX2#JX?3<
M(/3G(//>[.'M\^<@]/GM(.SG[?7LW/3Y[2#S].\@]MSJY>OO("(E<R(N(-3O
M(//]\_3G[.$@W>+CX>OE(/3O(.'J_.OO]>CO(.S>[?7LX0#5\-[Q[N4@Z]SH
M[_(@ZN'TW"#TY^T@X?#O\_3OZ]X@]._U(.SG[?WLX?3O\CH@)7,`P?7TWB#G
M(.7MW?'CY>GA(.7MY-WWY?3AZ2#MX2#JX>CU\_3E\=[SY>DN(,7?\_3E(//?
MX^_U\>_R*.<I(/STZ2#HW>OE].4@[>$@\_7MY???\^7TY3L`P?7T_"#T[R#L
MWNWU[.$@\/'O\@#!]?3\\B#O(.'QZ>CL_/(@\/'=\.7I(.WA(.7?[>'I(/3O
M]>O<]^GS]._M(-WMX2X`P?7TWB#G(/3I[-X@\/'=\.7I(.WA(.7?[>'I(.'Q
MZ>CL_/(N`-#Q[^+OZ]X@[>?LW/3Y[0#4W_3K[_(`T/'O\@#6W.KEZ^_R(,3I
MX>/QX>SLW>WA.@#'Z^7J]/'O[>GJWB#$Z>7]Z/7M\^<`Q.7M(.7?[>'I(.3U
M[>'TWB#G(//][>3E\^<@\_3O(.3IX>KO[.GS]-X@4U%,+@#$Y>T@[/#\\>7S
MY2#MX2#LY?3A]O'A\_3EWR#A]?3\(/3O(-WCX_'A]N\@5V]R9`#,YR#A\.'M
M].?LW>WA`,SG(.'PX>WTY^S=[>$@[.?M_>SA].$`Q?#A[>'V[_'<`,SG(-7P
MX?'J]._?(-#A\>'KWO#TY?(`P>K]\?GSYR#!Z^OAX_[M`*+C[?GS].<@S._Q
M]MX@P?'WY=_O]0#,YR#DZ>'BX?/LW>WA`,'P[_/][>3E\^<@X?#\(/3O[2#V
MW.KEZ^\H[_7R*0#7\=[SYR#P\>_JX>CO\>GS[-WMY_(@].GLWO(`U_'G\^GL
M[_#OZ=[S].4@].<@\_7MY/'O[-X@\_3O]?(@ZN'TX>O\X^_U\B!)34%0.P#%
M\.GK[^/=\B#7\=[S].<`O.WO[.$@U_'>\_3G`,7L]MSMZ?/G("5S`-#Q[^+O
MZ]X@WB##\>'L[.'T[^KIXO[TZ>\@\._U(.CA(.7L]N'MW^;E].'I(.SE]-P@
M].?M(.7?\^_D[R#S].?M(/7PY_'E\]_A.@#0\>_EZ>3O\._?Y_/G`,7BY._L
MX>3IX=_A`,KAZ_GSWO'HX?3E("5S`,KAZ_[R(-[KZ.7R+"`E<P"\].'M(.3I
MX>/QW/;O[?3AZ2#LY^W][.'TX2P@[>$@[.7TX?;=\>_M].'I(//T[^T@]MSJ
MY>OO(.3IX>/QX>SLW>WA(.'M]-\@[>$@]^'QX>KTY_'?YN_M].'I(/GR(.3I
MX>/QX>SLW>WA.P#$Z>7]Z/7M\^<@Q?'CX?/?X?(`U.?KW?;Y[>\@Q?'CX?/?
MX?(`65D`Q?3>\^GA`,WAZ0#![?3IX_'<]N7TY2`O(.SE].'VW?'E].4@\^4@
M[=WO(/;<ZN7K[RX`Q.?LZ>_U\>/EW_3E(-WMX2#VW.KEZ^\@ZMST^2#A\/P@
M]._M(`#$Y^SI[_7QX^7?].4@W>WA(/;<ZN7K[R#P\?[T[_4@Y?#I\-WD[_4N
M`+CWY?3E(.7PZ>O=[N7I(.WA(.SE]._M[^S<\^7TY2#T[R#VW.KEZ^\Z`+CW
MY?3E("5S(,W=X2#LY^W][.'TX2X`N/?E].4@,2#-W>\@[-[M]>SA+@"X]^7T
MY2#MW>$@[.?M_>SA].$@\_3O[2#AZOSK[_7H[R#VW.KEZ^\Z`+CWY?3E(.W=
MX2#LY^W][.'TX2#S]._U\B#AZOSK[_7H[_7R(/;AZMWK[_7R.@#0\=WPY>D@
M[>$@\.7QZ>/QW/CE].4@].\@\/'\XNOG[.$@\/'I[2#S].7?Z^7TY2#A[>'V
M[_'<(./IX2#A]?3\+@#0\=WPY>D@\/'^].$@[>$@Y?#IZ]WNY?3E(-WMX2#V
MW.KEZ^\N`-#QW?#EZ2#P\?[TX2#MX2#E\.GKW>[E].4@[.GA(.3IY?WH]>WS
MYRX`T/'=\.7I(/#Q_O3A(.WA(.7PZ>O=[N7TY2#T[_7KW/?I\_3O[2#=[>$@
M[-[M]>SA+@#0\=WPY>D@[>$@\/'O\^3I[_'?\^7TY2#=[>$@\.'QX>O>\/3G
M+@#$Y>T@\_7MY.7HWNKA].4@\_3O("(E<R(N(-3O(//]\_3G[.$@W>+CX>OE
M(/3O(.'J_.OO]>CO(.S>[?7LX0#$Y>T@X?#O\_7MY.7HWNKA].4@X?#\("(E
M<R(N(-3O(//]\_3G[.$@W>+CX>OE(/3O(.'J_.OO]>CO(.S>[?7LX0"X]^7T
MY2#E\.GT]??^\B#S]>WDY>CEWR#S].\@(B5S(BX`N/?E].4@Y?#I]/7W_O(@
MX?#O\_7MY.7HY=\@X?#\("(E<R(`QR#S_>WDY?/G(//A\B`E<R#DZ>'J_/#G
MZN4N(-#A\>'JX>O^(.3OZNGLW//TY2#MX2#NX>WA\_7MY.7HY=_TY2X`S^D@
MT.OG\>_V[_'?Y?(@\^'R`,_I(.7PZ>OOX]WR(//A\B#=]^_U[2#A\._HY^KE
M]?3EWRX`QR#U\._C\>'VWB#SX?(Z`%O$Y>T@]?#<\??EZ2#HW>SA70!;P>WA
M]N_QW"#0\>_BZ][LX?3O\ET`6^/QX>SLWB`E<R#A\/P@)7-=`,'P_`#JX>W=
M[>$`W@#O\>COX_'A]NGJ_"#KW.CO\@#O\>COX_'A]NGJW"#KW.CG`-CG]NGA
MZMX@RMSQ].$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]E;%]'4B]H96QP+GAM;```````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R-C(S,``Q,#0Q-S,V,C<V,``P
M,C$Q,3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM-R(_
M/@H\(2TM("1(;W)D93H@:6UP+VQO8V%L92]E;%]'4B]H96QP+GAM;"QV(#$N
M,3@N-BXT(#(P,#8O,#$O,S`@,34Z-3@Z,#,@:F%N($5X<"`D("TM/@H\:&5L
M<#X*("`\96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/M/][>CE\^<@S.?M_>SA]._R.B#%[=WQX^7IY?(\
M+W1I=&QE/@H@("`@/&AE861I;F<^Q>W=\>/EZ>7R/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("#'(,'P[_/T[^O>(,SG[?WLX?3O\B#S]-WK[>7I(/3O(&4M
M;6%I;"#SX?(@\_3O]?(@\._U(-WWY?3E(.7PZ>O=[N7I+B#%]OSS[^T@\.'T
MWO/E].4@].\@\.O>ZO3Q[R`BP?#O\_3OZ]X@S.?M_>SA]._R(B#T[R#LWNWU
M[.$@\^'R(.'P[_/TW>OKY?3AZ2#S]._U\B#P\>_O\>GS[._]\B#P[_4@W??E
M].4@Y?#IZ]WNY>DL(.'P_"#A]?3\(/3O(//G[.7?[R#JX>D@[.7TW"#G(.'P
M[_/T[^O>(.3E[2#L\._QY=\@[>$@X>KU\?GHY=\N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@(,<@(L'J_?'Y\^<@S.?M_>SA]._R(B#S].'LX?3<Y>D@
M].\@S-[M]>SA(/#O]2#C\=SVX?3E(.KAZ2#A\.O^\B#SX?(@Y?#I\_3QW?;E
MZ2#S]._M(.KA]-SK[^/O(,7I\^7Q]_SLY>WA+"#>(//E(._P[^GOY-[P[_3E
M(-SKZ^\@ZN'TW.OOX^\@XO'I\^K\\^'S].'M(/3EZ^7U].'?[RX*("`@(#PO
M<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M
M8G5T=&]N<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@06-T
M:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY!8W1I;VYS/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!396YD($UE<W-A9V4@;&%U;F-H97,@>6]U<B!E;6%I
M;"!T;R!T:&4@:6YT96YD960@<F5C:7!I96YT*',I+B!"92!S=7)E('EO=2!W
M86YT('1O('-E;F0@8F5F;W)E(&-L:6-K:6YG(&AE<F4@87,@;VYC92!S96YT
M(&ET(&-A;FYO="!B92!T86ME;B!B86-K+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("!3879E($1R869T('!L86-E<R!A;B!U;F9I;FES:&5D(&UE<W-A
M9V4@:6X@82!F;VQD97(@8V%L;&5D("=$<F%F=',G"F%C8V5S<VEB;&4@8GD@
M=&AE('!O<"UD;W=N(&)O>"!O;B!T:&4@<FEG:'0@<VED92!O9B!T:&4@8FQU
M92!N879I9V%T:6]N(&)A<B!A="!T;W`N(%EO=2!C86X@=&AE;B!F:6YI<V@@
M=&AE(&UE<W-A9V4@;&%T97(@8GD@<W=I=&-H:6YG('1O('1H92`G1')A9G1S
M)R!F;VQD97(L(&-L:6-K:6YG(&]N('1H92!S879E9"!M97-S86=E('1O(&]P
M96X@:70L(&%N9"!T:&5N(&-L:6-K:6YG(&]N("=297-U;64G+B!"92!S=7)E
M('1O('!U="!A('-U8FIE8W0@;VX@=&AE(&5M86EL(&)E9F]R92!Y;W4@<V%V
M92!T:&4@9')A9G0@<V\@=&AA="!Y;W4@8V%N(&5A<VEL>2!I9&5N=&EF>2!W
M:&EC:"!M97-S86=E('EO=2!W86YT('=I=&AI;B!T:&4@1')A9G1S(&9O;&1E
M<BX@069T97(@<V%V:6YG(&%S(&$@1')A9G0L('EO=2!A<F4@<F5T=7)N960@
M=&\@>6]U<B!)3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE
M=VEN9R!L87-T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#86YC96P@
M365S<V%G92!D<F]P<R!T:&4@;65S<V%G92!I;B!P<F]G<F5S<R!A;F0@<VEM
M<&QY(')E='5R;G,@>6]U('1O('1H92!)3D)/6"!O<B!W:&%T979E<B!F;VQD
M97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H\+V5N=')Y
M/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB('-T871E
M/2)U;FMN;W=N(CX*("`@(#QT:71L93[3_>WHY?/G(,SG[?WLX?3O\CH@P?#O
M\_3OZ]WA\CPO=&ET;&4^"B`@("`\:&5A9&EN9SXBP?#O\_3OZ]WA\B(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(,/QW/CTY2#TYR#S^?/TWB!E+6UA:6P@
MY.GE_>CU[?/>(//A\BX@QR#$Z>7]Z/7M\]X@\^'R(.CA(.+QW_/JY?3AZ2#L
MY?3<(/3O[2#TW_3K[R`BP?#O\_3OZ]WA\CHB(//T[R#E[N7Q]_SLY>WO(,S>
M[?7LX2X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@
M:60](F-O;7!O<V4M9G)O;2(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@1G)O;3PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M&<F]M)G%U
M;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!Y;W5R(&-O<G)E
M8W0@96UA:6P@861D<F5S<RX@66]U<B!E;6%I;"!A9&1R97-S(&ES(&%U=&]M
M871I8V%L;'D@96YT97)E9"!F;W(@>6]U(&9O;&QO=VEN9R`F<75O=#M&<F]M
M.B9Q=6]T.R!I;B!O=71G;VEN9R!E;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R
M>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UT;R(@<W1A=&4]
M(G5N:VYO=VXB/@H@("`@/'1I=&QE/M/][>CE\^<@S.?M_>SA]._R.B#0X?'A
MZ][P].?R/"]T:71L93X*("`@(#QH96%D:6YG/B+0X?'AZ][P].?R(CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@P_'<^/3E(/3G(//Y\_3>(.3IY?WH]>WS
MYR#>(.3IY?7H_>WSY>GR(/3Y[2#PX?'AZ^?P]/[M(//T[_7R(._P[]_O]?(@
MZ-WKY?3E(.WA(//TY=_KY?3E(&4M;6%I;"X@RMSHY2#DZ>7]Z/7M\^<@\/'=
M\.7I(.WA(.3IX??Y\=_FY?3AZ2#A\/P@].GR(/7P_.OOZ?#E\B#LY2#T[R#W
MX?'AZO3>\>$@)SLG+"#O\._I[_/DWO#O].4@W.OK[_(@Y.GA]_GQZ?/TZ>K\
M\B#WX?'AZO3>\>'R(.CA(.3G[.GO]?'CWO/EZ2#KW.CO\BX@S^D@Q.GE]>C]
M[?/EZ?(@\._U(.CA(./QW/CE].4@Z.$@XO'?\^KO[?3AZ2#LY2#TX2#T[^T@
M]-_TZ^\@(M#A\>'KWO#TY_(Z(B#S].\@Y>[E\??\[.7M[R#,WNWU[.$N"B`@
M("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP
M;W-E+71O(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!4;SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M4;R9Q=6]T.SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S
M<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!Y;W5R(&UE<W-A9V4N(%EO=2!M
M=7-T('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R
M('!U;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N
M=')Y(&9O;&QO=W,@)G%U;W0[5&\Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN
M("`*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UC8R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/M/]
M[>CE\^<@S.?M_>SA]._R.B#*[^GM[_#OW^?SYSPO=&ET;&4^"B`@("`\:&5A
M9&EN9S[*[^GM[_#OW^?SYSPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@P_'<
M^/3E(/3G(//Y\_3>(.3IY?WH]>WSYR#>(.3IY?7H_>WSY>GR(/3Y[2#PX?'A
MZ^?P]/[M(//T[_7R(._P[]_O]?(@Z-WKY?3E(.WA(//TY=_KY?3E(-WMX2#A
M[?3?X_'A]N\@]._U(.SG[?WLX?3O\BX@T_7MWNCY\B#OZ2#PX?'AZ][P].7R
M(.'U]._?(.3E[2#EW^WAZ2#OZ2#<[.7SX2#E[>3IX?;E\?SLY>WOZ2#CZ>$@
M].\@[-[M]>SA(.'KZ]P@W>SLY?/A(.7MY.GA]N7Q_.SE[>_I+B#/Z2#DZ>7U
MZ/WM\^7I\B#A]?3=\B#HX2#E[/;A[=_F[^WTX>D@\_3O(.S>[?7LX2#SX?(@
M[.7TW"#A\/P@]._M(/3?].OO("+*[^GM[_#OW^?SYR(N"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6-C(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!#8SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SXF<75O=#M#8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@
M=&AO<V4@=&\@<F5C96EV92!A(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G
M92X@4V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM82X@66]U<B!E
M;G1R>2!F;VQL;W=S("9Q=6]T.T-C.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL
M+B!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O<&QE(&]T
M:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET=&5N('1O(&1I<F5C=&QY
M(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@;V8@=&AE(&5M86EL(&%S
M('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C=&QY(&-O;F-E<FYE9"!A
M8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN("!!;&P@)U1O.B<@<F5C
M:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C86X@<V5E('1H92!E;G1I
M<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP:65N=',N"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M8F-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^T_WMZ.7SYR#,Y^W]
M[.'T[_(Z(,KQ]?;>(,KOZ>WO\._?Y_/G/"]T:71L93X*("`@(#QH96%D:6YG
M/LKQ]?;>(,KOZ>WO\._?Y_/G/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("##
M\=SX].4@].<@\_GS]-X@Y.GE_>CU[?/G(-X@Y.GE]>C][?/EZ?(@]/GM(/#A
M\>'KY_#T_NT@\_3O]?(@[_#OW^_U\B#HW>OE].4@[>$@\_3EW^OE].4@W>WA
M(.KQ]?;\(.'M]-_C\>'V[R#T[_4@[.?M_>SA]._R+B#3Y2#A]?3\(/3O(/#E
MY-_O(.CA(.+<Z^7TY2#T[_7R(/#A\>'KWO#TY?(@\._U(.CA(.C=Z^'TY2#M
MX2#PW/'O]>T@W>WA(.'M]-_C\>'V_"#T[_4@[.?M_>SA]._R(//A\BP@U]G1
MR=,@_.SY\B#OZ2#U\/SK[^GP[^D@\.'QX>O>\/3E\B#P[_4@W??E].4@Y?#I
MZ]WNY>D@\_3A(/#EY-_A("+0\>_R(B#JX>D@(LKOZ>WO\._?Y_/G(B#MX2#D
M[_7M(/STZ2#=]^7TY2#S].7?Z^7I(-WMX2#A[?3?X_'A]N\@ZN'I(.K<\._U
M(.'KZ^_]+B#,Y2#A]?3\(/3O[2#T\?SP[R#L_.WO(.7SY=_R(.KAZ2#OZ2#P
MX?'AZ][P].7R(/#O]2#=]^7TY2#E\.GKW>[EZ2#S].\@\.7DW^\@(LKQ]?;>
M(,KOZ>WO\._?Y_/G(B#HX2#NW?'O]>T@_/3I(/3O]?(@W??E].4@\_3EW^OE
MZ2#=[>$@X>WTW^/QX?;O(/3O]2#LY^W][.'T[_(N"B`@("`\+W!A<F$^"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6)C8R(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@0F-C/"]T:71L93X*("`@
M(#QH96%D:6YG/B9Q=6]T.T)C8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@
M=&AO<V4@=&\@<F5C96EV92!A(&)L:6YD(&-A<F)O;B!C;W!Y(&]F('EO=7(@
M;65S<V%G92X@66]U(&UU<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@
M82!C;VUM83L@;W1H97(@<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@
M97)R;W(N(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O=#M"8V,Z)G%U;W0[(&EN
M(&]U=&=O:6YG(&UA:6PN($)L:6YD(&-A<F)O;B!C;W!I97,@87)E('5S=6%L
M;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!D:7)E8W0@86YD(&EN9&ER
M96-T(')E8VEP:65N=',@*"9Q=6]T.U1O.B9Q=6]T.R!A;F0@)G%U;W0[0V,Z
M)G%U;W0[(')E8VEP:65N=',I('=H;R!N965D('1O(')E860@=VAA="!I<R!B
M96EN9R!W<FET=&5N(&%S('=E;&P@5TE42$]55"!T:&4@;W1H97(@<F5C:7!I
M96YT<R!K;F]W:6YG('1H870@=&AE>2!A<F4@<F5C96EV:6YG('1H92!E;6%I
M;"X@5&AU<R`G8FQI;F0G(&UE86YS('1H870@=&AE(&ED96YT:71Y(&]F('1H
M97-E(')E8VEP:65N=',@:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R(')E8VEP
M:65N=',@;V8@=&AE(&5M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H97D@:VYO
M=R!T:&5Y(&=O="!A(&-O<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H:7,@=&\@
M=&5L;"!A;B!A=71H;W)I='D@9FEG=7)E('1H870@>6]U(&%R92!T96QL:6YG
M('-O;65O;F4@<V]M971H:6YG('=I=&AO=70@86QA<FUI;F<@=&AE('!E<G-O
M;B!Y;W4@87)E('-E;F1I;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*("`@(#PO
M<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92US=6)J96-T(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^T_WMZ.7S
MYR#,Y^W][.'T[_(Z(,C=[.$\+W1I=&QE/@H@("`@/&AE861I;F<^(NC=[.$B
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("##\=SX].4@].\@R-WLX2#T[_4@
MS.?M_>SA]._R(//A\BX@S_3IY-[P[_3E(./QW/CE].4@Z.$@Y>SVX>W?YN7T
MX>D@[.7TW"#T[^T@]-_TZ^\@(LC=[.$Z(B#S].\@Y>[E\??\[.7M[R#,WNWU
M[.$N(,KAZ_P@Z.$@Y=_MX>D@[>$@Y=_MX>D@\_WM]._L[RP@X?#K_"#JX>D@
M\.7QZ>/QX?;IZOPN("#'(./QX>SLWB#T[_4@Z-WLX?3O\B#EW^WAZ2#O(/#O
MZ>\@Y?WJ[^OO\B#T\?SP[_(@X^GA(.7SW/(@ZN'I(./IX2#T[_7R(/#A\>'K
MWO#TY?(@\^'R(.WA(.CU[._][?3AZ2#TZ2#PY?'IY=_WY2#T[R!E+6UA:6P@
M\/'<X^SA(/#O]2#EW^WAZ2#P[^O](//G[.'M].GJ_"#CZ>$@].?M(._QX]SM
M^?/G(.KAZ2#TY^T@Y?WQY?/G(/3Y[2!E+6UA:6P@\^'R(.'QX_STY?'A+B#%
M\-_SY_(L(/STX>T@X?#A[?3<].4@WB#P\>_YZ.7?].4@W>WA(,S>[?7LX2#T
M[R#HW>SA(/#Q[_/TW^CE].'I(//T[R#HW>SA(/3O]2#MW>_U(,SG[?WLX?3O
M\BX@P?7T_"#SX?(@XN_GZ-P@[>$@[_'CX>W^[>7TX>D@].$@92UM86EL(//A
M\B#TX2#O\._?X2#S]^?LX?3?YN_U[2#LW^$@(O/UYM[TY_/G(BX@P>T@_.SY
M\B#S].?M(,'PW.WTY_/G(-X@].?M(-#Q[_[HY_/G(.7M_/(@S.?M_>SA]._R
M(.C=Z^7TY2#MX2#P\>_SZ-WSY?3E(.K<].D@ZN'I[>_]\>/I[RP@[/#O\>7?
M].4@X?#K_O(@[>$@\/'O\^C=\^7TY2#JW/3I(//TYR#C\>'L[-X@]._U(,C=
M[.'T[_(@W?3SZ2#^\_3E(._I(/#A\>'KWO#TY?(@\^'R(.WA(.KA].'KX>+A
MW^WO]>T@].GR(.'KZ^'CW?(N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E
M;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+7-U8FIE8W0B/@H@("`@/'1I=&QE
M/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%-U8FIE8W0\+W1I=&QE/@H@("`@/&AE
M861I;F<^)G%U;W0[4W5B:F5C="9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@16YT97(@=&AE('-U8FIE8W0@;V8@>6]U<B!M97-S86=E+B!9;W5R
M(&5N=')Y(&9O;&QO=W,@)G%U;W0[4W5B:F5C=#HF<75O=#L@:6X@;W5T9V]I
M;F<@;6%I;"X@2V5E<"!I="!S:&]R="P@<VEM<&QE(&%N9"!D97-C<FEP=&EV
M92X@(%1H92!S=6)J96-T(&QI;F4@:7,@=&AE(&5A<VEE<W0@=V%Y(&9O<B!Y
M;W4@86YD('EO=7(@8V]R<F5S<&]N9&5N=',@=&\@<F5M96UB97(@=VAA="!W
M87,@:6X@=&AE(&5M86EL(&%N9"!T:'5S(&ES('9E<GD@:6UP;W)T86YT(&EN
M(&]R9V%N:7II;F<@>6]U<B!E;6%I;"!A;F0@9FEN9&EN9R!I;7!O<G1A;G0@
M;VYE<R!L871E<BX@($%L<V\L('=H96X@>6]U("=297!L>2<@;W(@)T9O<G=A
M<F0G(&%N9"!E;6%I;"!T:&ES('-U8FIE8W0@;&EN92!I<R!C;W!I960@;W9E
M<B!I;G1O('1H92!N97<@;65S<V%G92!A;F0@<V\@:7,@82!V86QU86)L92!W
M87D@;V8@=&5L;&EN9R!W:&%T(&UE<W-A9V5S(&=O('1O9V5T:&5R('1O(&9O
M<FT@82`F<75O=#MT:')E860F<75O=#L@;V8@82!C;VYV97)S871I;VXN("!(
M;W=E=F5R+"!I9B!T:&4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@8V]N=&%I;G,@
M;F5W(&ED96%S+"!Y;W4@;6%Y('=A;G0@=&\@861D('-I;7!L92!M;V1I9FEC
M871I;VYS('1O('1H92`G4W5B:F5C="<@;&EN92!S;R!T:&4@<F5C:7!I96YT
M*',I(&-A;B!F;VQL;W<@=&AE('!R;V=R97-S:6]N(&]F('1H92`F<75O=#MT
M:')E860N)G%U;W0["B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*
M("`\96YT<GD@:60](F-O;7!O<V4M;W!T:6]N<R(@<W1A=&4](G5N:VYO=VXB
M/@H@("`@/'1I=&QE/M/][>CE\^<@S.?M_>SA]._R.B#%\.GK[^/=\CPO=&ET
M;&4^"B`@("`\:&5A9&EN9S[%\.GK[^/=\CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@T.'T_NWTX?(@].\@(M/U[>?L[-WMX2(@[/#O\>7?].4@[>$@Y.7?
M].4@].<@Z]_S].$@[.4@].$@X?'WY=_A(/#O]2#=]^7TY2#E\.GS]>W<^.7I
M(.KAZ2#A[2#HW>OE].4@[>$@\/'O\^C=\^7TY2#>(.WA(.3IX>/QW/CE].4@
MZMSP[^GO(.'P_"#A]?3<+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"LSE(/3G
M[2#E\.GK[^/>("+!\._HWNKE]?/G(//T[R#VW.KEZ^\@P?#E\_3AZ^S=[>$B
M(.SP[_'EW_3E(.WA(.KQX?3>\^7TY2#=[>$@X>WTW^/QX?;O(/3O]2#LY^W]
M[.'T[_(@\._U(//TW>OMY?3E(//T[R#VW.KEZ^\@(L'PY?/TX>OLW>WA(@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"LSE(/3G[2#E\.GK[^/>("+-X2#FY_3G
MZ.7?(.7PZ>+EXN'?^?/G(/#A\>'KX>+>\B(@[R#PX?'AZ][P].?R(//A\B#A
M[2#HW>OEZ2#HX2#S].7?Z^7I(-WMX2!E+6UA:6P@[.4@].\@[_#OW^\@Z.$@
M\^'R(.7MY^SE\?[MY>D@_/3I(/3O(.S>[?7LX2#P[_4@\_3EW^OA].4@W??E
MZ2#V]-SSY>D@\_3O[2#P\>_O\>GS[/P@]._U+@H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UO<'1I;VYS(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!/<'1I;VYS/"]T:71L
M93X*("`@(#QH96%D:6YG/B9Q=6]T.T]P=&EO;G,F<75O=#L\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1H97-E($]P=&EO;G,@:&5L<"!Y;W4@<')E<&%R
M92!Y;W5R(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-L
M:6-K("9Q=6]T.U-P96QL($-H96-K)G%U;W0[('1O(&-H96-K('EO=7(@<W!E
M;&QI;F<N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-L:6-K("9Q=6]T
M.T%T=&%C:&UE;G1S)G%U;W0[('1O('9I97<@870@=&AE(&)O='1O;2!O9B!T
M:&4@<&%G92!A(&QI<W0@;V8@9FEL97,@871T86-H960@=&\@=&AI<R!M97-S
M86=E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!8W1I=F%T92!T:&4@
M8VAE8VLM8G5T=&]N(&YE>'0@=&\@)G%U;W0[4V%V92!C;W!Y)G%U;W0[('1O
M('-A=F4@82!C;W!Y(&]F('1H:7,@;65S<V%G92!I;B!Y;W5R("9Q=6]T.U-E
M;G0@36%I;"9Q=6]T.R!F;VQD97(N(%-A=F4@8V]P:65S(&]F(&EM<&]R=&%N
M="!E;6%I;',@>6]U('-E;F0@<V\@=&AA="!Y;W4@:&%V92!S;VUE=&AI;F<@
M=&\@<F5F97(@8F%C:R!T;R!L871E<B!A;F0@=&\@:V5E<"!A;B!A8V-U<F%T
M92!R96-O<F0@;V8@=VAA="!W87,@<V%I9"X@5V4@9&\@;F]T(')E8V]M;65N
M9"!Y;W4@<V%V92!E=F5R>2!E;6%I;"!S:6YC92!T:&5N('EO=7(@9&ES:R!S
M=&]R86=E('%U;W1A('=I;&P@8F4@=7-E9"!U<"!Q=6EC:VQY("AE<W!E8VEA
M;&QY('=H96X@>6]U('-E;F0@871T86-H;65N=',I(&%N9"!Y;W5R(&UA:6QB
M;W@@=VEL;"!B92!F=6QL(&%N9"!U;F%B;&4@=&\@<F5C96EV92!N97<@:6YC
M;VUI;F<@96UA:6PN(%EO=2!C86XL(&AO=V5V97(L('1U<FX@=&AI<R!F96%T
M=7)E("=O;B<@87,@>6]U<B!D969A=6QT('=I=&AI;B!Y;W5R($ED96YT:71Y
M+"!B>2!G;VEN9R!T;R!/<'1I;VYS+29G=#M097)S;VYA;"!);F9O<FUA=&EO
M;BTF9W0[161I="!Y;W5R(&ED96YT:71I97,N($)E(&-A<F5F=6P@=VAE;B!U
M<VEN9R!T:&ES(&UO9&EF:65D(&1E9F%U;'0@87,@>6]U('=I;&P@;F5E9"!T
M;R!P97)I;V1I8V%L;'D@<'5R9V4@>6]U<B`F<75O=#M396YT($UA:6PF<75O
M=#L@9F]L9&5R(&]R(&ET('=I;&P@979E;G1U86QL>2!M86ME('EO=7(@;6%I
M;&)O>"!F=6QL(&%N9"!U;G5S96%B;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^
M+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M871T86-H(B!S=&%T
M93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^T_WMZ.7SYR#,Y^W][.'T[_(Z(,7P
MZ?/][>'XYSPO=&ET;&4^"B`@("`\:&5A9&EN9SXBQ?#I\_WMX?CG(CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("`@(+CWY?3E(/3G(.3U[>'T_/3G].$@
M[.'FWR#LY2#T[R#LWNWU[-P@\^'R(.WA(//TY=_KY?3E(.KAZ2#JW/#OZ>\@
MX?'WY=_O(.'P_"#T[^T@]?#OZ^_CZ?/TWB#SX?(N(,/IX2#MX2#E\.GS]>W<
M^.7TY2#=[>$@X?'WY=_O(.K<[>7TY2#TZ?(@X>K\Z^_UZ.7R(.7MW?'CY>GE
M\CH*("`@(#PO<&%R83X*("`@(#QP87)A/C'O(,+>[.$Z(,SP[_'EW_3E(.WA
M(/#KY^KT\>_K[^/>\^7TY2#TYR#DZ>'D\>_LWBAP871H*2#\\._U(.+QW_/J
MY?3AZ2#T[R#A\??EW^\@ZN'I(/3O(/SM[^SA(/3O]2#>(.WA(/?QY_/I[._P
M[^G>\^7TY2#T[R#PZ][J]/'O("+![>'FWO3G\^<B(.KAZ2#MX2#E\.GKW>[E
M].4@].\@X?'WY=_O(/#O]2#HW>OE].4@X?#\(-WMX2#PX?'<Z/7Q[R#LY2#T
MX2#A\??EW^$@]._U(/7P[^OOX^GS]-X@\^'R+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^,N\@PM[LX3H@T.'TWO/TY2#T[R#PZ][J]/'O("+%\.GS_>WA^.<B
M+B#4[R#\[>_LX2#T[_4@X?'WY=_O]2#JX>D@].\@[-WCY>CO\B#T[_4@Z.$@
MY>SVX>WI\_3O_>T@\_3G(.O?\_3A(.SE(/3A(//U[>?L[-WMX2#A\??EW^$@
M\^'R+@H@("`@/"]P87)A/@H@("`@/'!A<F$^T/'O\^_WWB$@P>T@Z-WKY?3E
M(.WA(.7PZ?/U[=SXY?3E(.'Q]^7?X2#LY>/<Z^_U(.SEX]WH[_7R(.7M_B#=
M]^7TY2#A\>/>(//][>3E\^<L(.<@Y>W=\>/EZ>$@X?7TWB#HX2#=]^7I(.SE
MX]SKYR#JX>CU\_3=\>?SYRX@T.7QZ>S=[>7TY2#CZ>$@Z]_C[R#JX>D@[.?M
M(.K<[>7TY2#<Z^OE\B#E[=WQX^7IY?(@\._U(.CA(.7PY_'EW//O]>T@].?M
M(/3A]_WTY_3A(/3G\B#S_>WDY?/>\B#SX?(N"B`@("`\+W!A<F$^"CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:"(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H/"]T:71L93X*
M("`@(#QH96%D:6YG/B9Q=6]T.T%T=&%C:"9Q=6]T.SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@66]U(&UA>2!A='1A8V@@9FEL97,@=&\@>6]U<B!M97-S
M86=E.R!O;FQY(&]N92!F:6QE(&UA>2!B92!A='1A8VAE9"!A="!A('1I;64N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5I=&AE<BP@='EP92!T
M:&4@<&%T:"!A;F0@;F%M92!O9B!A(&9I;&4@=&AA="!Y;W4@=V%N="!A='1A
M8VAE9"!T;R!T:&ES(&UE<W-A9V4@;W(@8VQI8VL@)G%U;W0[0G)O=W-E)G%U
M;W0[(&)U='1O;B!A;F0@<V5L96-T('1H92!F:6QE('1O(&)E(&%T=&%T8VAE
M9"X@5&AE('!A=&@@86YD(&YA;64@;V8@=&AA="!F:6QE(&YO=R!A<'!E87)S
M(&EN('1H92!!='1A8VAM96YT(&)O>"X*("`@(#PO<&%R83X*("`@(#QP87)A
M/E-T97`@,CH@1&5C:61E('=H971H97(@>6]U('=A;G0@=&AE(&9I;&4@=&\@
M8F4@=FEE=V5D(&%S(&%N(&%T=&%C:&UE;G0@;W(@:6YL:6YE9"!W:71H('1H
M92!R97-T(&]F('1H92!M97-S86=E+B!4:&4@<F5C96EV:6YG('!E<G-O;BAS
M*2!M86EL(')E861I;F<@<V]F='=A<F4@;75S="!B92!A8FQE('1O(&AA;F1L
M92!T:&4@9FEL92!T>7!E(&EN;&EN93L@:68@;F]T+"!T:&ES('!A<G0@=VEL
M;"!B92!V:65W960@87,@86X@871T86-H;65N="!I;G-T96%D+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^4W1E<"`S.B!#;&EC:R`F<75O=#M!='1A8V@F<75O
M=#L@8G5T=&]N+B!4:&4@9FEL92!N86UE(&%N9"!S:7IE('=I;&P@8F4@861D
M960@=&\@>6]U<B!L:7-T(&]F($%T=&%C:&UE;G1S+B!0;&5A<V4@;F]T92!T
M:&%T(&9O<B!L87)G92!F:6QE<R!A;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O
M;FYE8W1I;VYS+"!T:&4@<')O8V5S<R!O9B!U<&QO861I;F<@86YD(&%T=&%C
M:&EN9R!Y;W5R(&9I;&4@=&\@=&AE(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N
M(%!L96%S92!B92!P871I96YT(&%N9"!D;R!N;W0@8VQI8VL@;W1H97(@=&AI
M;F=S('=H:6QE('EO=2!A<F4@=V%I=&EN9RX*("`@(#PO<&%R83X*/"]E;G1R
M>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT
M<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/M/][>CE\^<@S.?M_>SA
M]._R.B#3]>WG[.S=[>$\+W1I=&QE/@H@("`@/&AE861I;F<^T_7MY^SLW>WA
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("#%[/;A[=_FY?3AZ2#LW^$@Z]_S
M].$@[.4@].\@X?'WY=_A(/#O]2#=]^7TY2#E\.GS]>W<^.7I(//T[R#LWNWU
M[.$N(,/IX2#MX2#DZ>'C\=SXY?3E(-WMX2#A\??EW^\@X?#\(/3A(//U[>?L
M[-WMX2#JW.WTY2#TZ?(@X>K\Z^_UZ.7R(.7MW?'CY>GE\CH*("`@(,7PZ>O=
M[O3E(/3O(.'Q]^7?[R#JX>D@\.'TWO/TY2#T[R`BP>K]\?GSYR#%\.GKY>/L
MW>WY[2(N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(CX*("`@(#QT:71L93Y-97-S86=E
M($-O;7!O<VET:6]N.B!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SXF<75O=#M!='1A8VAM96YT<R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AI<R!S96-T:6]N(&1I<W!L87ES(&$@;&ES="!O9B!F:6QE<R!A
M;')E861Y(&%T=&%C:&5D('1O('EO=7(@;65S<V%G92X@5&\@1&5L971E(&%N
M(&%T=&%C:&5D(&9I;&4Z"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z
M($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R!T:&4@871T86-H
M960@9FEL96YA;64@>6]U('=A;G0@=&\@1&5L971E+@H@("`@/"]P87)A/B`*
M("`@(#QP87)A/E-T97`@,CH@0VQI8VL@)G%U;W0[1&5L971E($%T=&%C:&UE
M;G0H<RDF<75O=#LN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*
M("`\96YT<GD@:60](F-O;7!O<V4M<')I;W)I='DB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%!R:6]R:71Y/"]T:71L
M93X*("`@(#QH96%D:6YG/B)0<FEO<FET>2(\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%1H:7,@<V5T<R!T:&4@(E@M4')I;W)I='DB(&AE861E<B!O;B!Y
M;W5R(&]U=&=O:6YG(&UE<W-A9V4N(%1H92`B6"U0<FEO<FET>2(@=&%G(&ES
M(&$@<V]R="!O9B`B<'-E=61O('-T86YD87)D(B!T:&%T($YE='-C87!E+"!-
M;WII;&QA+"!/<&5R82P@86YD($]U=&QO;VL@;6%I;"!C;&EE;G1S(&%P<&5A
M<B!T;R!A9W)E92!O;BX@06YY(&UA:6P@8VQI96YT<R!T:&%T(&1O(&YO="!H
M86YD;&4@=&AI<R!H96%D97(@=VEL;"!S:6UP;'D@:6=N;W)E(&ET+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US879E+6%T
M=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!3879E($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A
M/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y
M;W5R(&-O;7!O<VET:6]N(&%R92!S879E9"!W:71H('1H92!M97-S86=E('=H
M96X@<W1O<F5D(&EN('1H92!S96YT+6UA:6P@9F]L9&5R+B`@268@(EEE<R(L
M('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S879E9"X@($EF(").;R(L
M('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S=')I<'!E9"!F<F]M('1H
M92!M97-S86=E(&%F=&5R(&ET(&ES('-E;G0@=&\@86QL(')E8VEP:65N=',N
M("!#:&]O<VEN9R`B3F\B('=I;&P@:&5L<"!C;VYS97)V92!D:7-K('-P86-E
M(&)Y(')E;6]V:6YG("AP;W1E;G1I86QL>2!L87)G92D@871T86-H;65N="!I
M;F9O<FUA=&EO;B!F<F]M('1H92!S879E9"!M97-S86=E<RX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;&EN:RUA='1A8VAM
M96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@3&EN:R!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\<&%R83X*("`@
M($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@:6X@>6]U<B!C
M;VUP;W-I=&EO;B!A<F4@<V5N="!A<R!A('!A<G0@;V8@=&AE(&UA:6P@;65S
M<V%G92!O<B!W:&5T:&5R('1H;W-E(&%T=&%C:&UE;G1S(&%R92!K97!T(&]N
M(&$@;&]C86P@<V5R=F5R+B`@268@871T86-H;65N=',@87)E(&QI;FME9"P@
M=&AE(')E8VEP:65N="AS*2!O9B!Y;W5R(&UE<W-A9V4@=VEL;"!B92!P<F]V
M:61E9"!A('=E8FQI;FL@=VAE<F4@=&AE>2!C86X@9&]W;FQO860@=&AE(&%T
M=&%C:&UE;G0H<RDN("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA<R!T:&4@861V
M86YT86=E(&]F('1R96UE;F1O=7-L>2!R961U8VEN9R!T:&4@<VEZ92!O9B!O
M=71G;VEN9R!M97-S86=E<RX@($QI;FMI;F<@871T86-H;65N=',@:&%S('1H
M92!D:7-A9'9A;G1A9V4@=&AA="!T:&4@8V]N=&5N="!O9B!T:&4@871T86-H
M;65N=',@8V%N(&YO="!B92!G=6%R86YT965D('1O(&)E(&%V86EL86)L92!I
M;B!T:&4@9G5T=7)E('-I;F-E('1H92!A='1A8VAM96YT(&1A=&$@:7,@;F]T
M(&QO8V%T960@=VET:&EN('1H92!E+6UA:6P@;65S<V%G92X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-E87)C:"(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/L'MX>;>].?SYR#,Y^WU[-ST^>T\+W1I=&QE/@H@
M("`@/&AE861I;F<^RO'I]-[QZ>$@Q?#IZ^_CWO(\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(,/IX2#MX2#B\>7?].4@W>WA(.S>[?7LX2#HX2#P\=WPY>D@
M[>$@\_7L\.OG\?[SY?3E(.K<\._I[R#A\/P@].$@\.7DW^$@(L'P_"(L("+0
M\>_R(BP@(LC=[.$B(-X@(LKEW^SE[>\@S.?M_>SA]._R(B#LY2#T[R#WX?'A
MZO3G\>GS].GJ_"#P[_4@W??EZ2#T[R#LWNWU[.$@\._U(/C<]^WE].4N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@(,KA]/SPZ>T@Y?#IZ]WCY?3E(.'M
M(.CA(/#QW?#EZ2#MX2#I\_?][_7M(/3A(.KQZ?3>\>GA(,K!R2#S].$@]-WS
M\^7QX2#PY>3?X2`HY?#IZ^_CWCH@(KSKX2#TX2#PY>3?X2(I(-X@X>T@Z.$@
MZ?/W_>_U[2#TX2#J\>GTWO'IX2#O\._UY-[P[_3E(/#EY-_O]2#A\/P@].$@
M]-WS\^7QX2`HY?#IZ^_CWB`BS_#OZ>_DWO#O].4@T.7DW^\B*2X*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@S.7TW"#P\=WPY>D@[>$@Y?#IZ]WNY?3E
M(/3G[2#JX?3GX^_QW^$@]/GM(.SG[?7LW/3Y[2#P[_4@Z-WKY?3E(.WA(/C<
M[N7TY2X@P>T@Y=_MX>D@[=WA(.SG[?WLX?3A(-X@X>T@Z-WKY?3E(.WA(.+Q
MY=_TY2#JW/#OZ>\@X?#\(/3A(.SG[?WLX?3A(/#O]2#=]^7TY2#A\.'M]-[S
MY>DN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(-3=Z^_R(.SP[_'EW_3E
M(.WA(.7PZ>O=[N7TY2#JX>D@\^4@\._I[_7R(.KA].'K_./O]?(@Z-WKY?3E
M(.WA(./?[>7I(.<@X>WAYM[TY_/G(.SA\>K<\>_M].'R(/3O(/#EY-_O(/#Q
MZ>T@X?#\(/3O[2#JW.CE(.KA]-SK[^/O+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("#4_O'A(.CA(/#A]-[SY?3E(/3O(/#KWNKT\>\@(L'MX>;>].?S
MYR(@X^GA(.WA(.[EZNGMWO/EZ2#G(.'MX>;>].?SYR#T^>T@[.?M]>S<]/GM
M+B#,_.OI\B#OZ^_JZ^?Q^>CEWR#HX2#E[/;A[>GS].7?(.S?X2#SY>O?Y.$@
M\_3G[2#O\._?X2#HX2#U\-SQ]^_U[2#TX2#LY^W][.'TX2#P[_4@].'I\>G<
MYN_U[2#S].$@ZO'I]-[QZ>$@Y?#IZ^_CWO(@\^'R+@H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<V5A<F-H(CX*("`@(#QT
M:71L93Y-97-S86=E(%-E87)C:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY396%R
M8V@@0W)I=&5R:6$\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=2!M87D@
M<V5A<F-H(&9O<B!M97-S86=E<R!F<F]M('EO=7(@9F]L9&5R<R!U<VEN9R!D
M:69F97)E;G0@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^4W1E<"`Q.B!%;G1E<B!T97AT('1O('1H92!F:65L9',@>6]U('=A;G0@
M=&\@861D('1O('EO=7(@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^4W1E<"`R.B!#:&]O<V4@=&AE(&UE<W-A9V4@9FQA9RAS*2!T
M;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#,Z($-H;V]S92!T:&4@9F]L9&5R*',I(&9R;VT@=VAI
M8V@@=&\@<V5A<F-H(&9O<B!T:&4@;65S<V%G97,N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#0Z($-L:6-K("9Q=6]T.U-E87)C:"9Q=6]T.RX*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@268@86YY(&UE<W-A9V5S(&UA=&-H
M960@>6]U<B!S96%R8V@@8W)I=&5R:6$L('1H96X@=&AE('-U8FIE8W1S(&]F
M('1H97-E(&UE<W-A9V5S('=I;&P@8F4@<VAO=VX@:6X@=&AE("9Q=6]T.U-E
M87)C:"!297-U;'1S)G%U;W0[('9I97<N"B`@("`\+W!A<F$^"CPO96YT<GD^
M+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUO<'1I;VYS(B!S=&%T
M93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^Q.GA]^7?\>GSYR#6X>K=Z_GM/"]T
M:71L93X*("`@(#QH96%D:6YG/L7PZ>OOX]X@UN'JW>OO]3PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@S/#O\>7?].4@[>$@Y?#IZ]WNY?3E(/3O(/;<ZN7K
M[R#S]._M(._P[]_O(.C=Z^7TY2#MX2#LY?3AXN7?].4L(.'P_"#TYR#KW_/T
MX2#P[_4@XO'?\^KE].'I(//T[R#E\-SM^2#DY>[?(.S=\>_R(/3G\B#SY>O?
MY.'R+B#*X?3\\.GM(.CA(/#A]-[SY?3E(/3O("*B[>_IX^SA(/;AZMWK[_4B
M(/#O]2#B\=_SZN7TX>D@Y-_PZ^$@X?#\(/3G(.O?\_3A(.SE(/3O]?(@]N'J
MW>OO]?(@X^GA(.WA(.3EW_3E(/3A(.SG[?WLX?3A(/#O]2#U\-SQ]^_U[2#S
M].\@]MSJY>OO"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N
M=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(^"B`@("`\=&ET;&4^1F]L9&5R($UA
M;F%G96UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($]P=&EO;G,\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@82!F
M;VQD97(@8GD@=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE(&QE
M9G0@8V]L=6UN+B`@3VYC92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C="!T
M:&4@;W!T:6]N('EO=2!W:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E<B!V
M:6$@=&AE('-E;&5C="!B;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@("`@66]U('=I;&P@8F4@<')O;7!T960@9F]R(&9U<G1H
M97(@;W!T:6]N<RX@($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO
M;BP@87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD
M97(@:68@>6]U(&1E;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^26UP;W)T(&UB;W@@1FEL93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@("!4:&ES(&]P=&EO;B!W:6QL(&EM<&]R="!A(&UB;W@@9F]R
M;6%T(&9I;&4@:6YT;R!T:&4@9F]L9&5R(&]F('EO=7(@8VAO:6-E+B!#:&]O
M<V4@,2`H;VYE*2!F;VQD97(@=&\@:6UP;W)T('1H92!M97-S86=E<R!I;G1O
M(&%N9"!T:&5N('-E;&5C="!T:&ES(&]P=&EO;BX@66]U('=I;&P@=&AE;B!B
M92!T86ME;B!T;R!A('!A9V4@=&AA="!W:6QL('!R;VUP="!F;W(@=&AE(&UB
M;W@@9FEL92!T;R!I;7!O<G0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E
M;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUW:61G971S(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E;65N=#H@1&ES<&QA>3PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY3:&]W+TAI9&4@56YS=6)S8W)I8F5D/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!)9B!U<VEN9R!)34%0(&9O;&1E<B!S=6)S
M8W)I<'1I;VYS+"!S:&]W+VAI9&4@=&AE('5N<W5B<V-R:6)E9"!F;VQD97)S
M+B`@5&\@<W5B<V-R:6)E+W5N<W5B<V-R:6)E('1O(&$@9F]L9&5R+"!S96QE
M8W0@=&AE(&-H96-K8F]X(&YE>'0@=&\@=&AE(&9O;&1E<FYA;64@86YD('5S
M92!T:&4@4W5B<V-R:6)E+U5N<W5B<V-R:6)E(&]P=&EO;B!I;B!T:&4@1F]L
M9&5R($%C=&EO;B!D<F]P+61O=VX@;65N=2X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/D5X<&%N9"!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5X
M<&%N9"!A;&P@9F]L9&5R(&5N=')I97,N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY#;VQL87!S92!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-O
M;&QA<'-E(&%L;"!F;VQD97(@96YT<FEE<RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](F9I;'1E<G,B('-T871E/2)U;FMN;W=N(CX*("`@
M(#QT:71L93[6W^OT\>$Z(,7VX?'L[^/>/"]T:71L93X*("`@(#QH96%D:6YG
M/L7VX?'L[^/>(+SK^>T@]/GM(,KA[?SM^>T\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(-#A]-[S].4@].\@RN_U[/#?("+%]N'Q[._CWB#\Z_GM(/3Y[2#J
MX>W\[?GM(B#P[_4@XO'?\^KE].'I(//T[R#E\-SM^2#LW?'O\B#T[_4@[.7M
M[_T@]/GM(/;?Z_3Q^>T@_O/TY2#MX2#EZO3EZ^7S]._][2#TX2#VW^OT\>$@
M\._U(-WWY?3E(.3G[.GO]?'CWO/EZ2P@\_3A(.SG[?WLX?3A(/#O]2#B\=_S
MZN_M].'I(//T[^T@]MSJY>OO("+%Z?/E\??\[.7MX2(N"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F:6QT97)S(CX*("`@
M(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L
M:6-K(&]N('1H92`F<75O=#M!<'!L>2!&:6QT97(F<75O=#L@:6-O;B!N97AT
M('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X('9I97<@=&\@9FEL
M=&5R(&%L;"!U;F1E;&5T960@;65S<V%G97,@86-C;W)D:6YG('1O('1H92!S
M<&5C:69I960@<G5L97,N("!/<BP@86QT97)N871E=FQY+"!C;&EC:R!O;B`F
M<75O=#M!<'!L>2!!;&P@4G5L97,F<75O=#L@:6X@=&AE(&9I;'1E<B!M96YU
M+B`@3F]T92!T:&%T(&9I;'1E<FEN9R!I<R!N;W0@9&]N92!A=71O;6%T:6-A
M;&QY+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)F:6QT97(M961I="UR=6QE<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^1FEL=&5R<SH@161I="!&:6QT97(@4G5L97,\+W1I=&QE/@H@("`@/&AE
M861I;F<^161I="!9;W5R($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!F:6QT97(@<G5L97,B('1O
M('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T
M92P@86YD(&5D:70@=&AE(&-U<G)E;G1L>2!A8W1I=F4@<V5T(&]F(&9I;'1E
M<B!R=6QE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I
M;'1E<BUE9&ET+6)L86-K;&ES="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M1FEL=&5R<SH@161I="!";&%C:VQI<W0\+W1I=&QE/@H@("`@/&AE861I;F<^
M161I="!9;W5R($)L86-K;&ES=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M0VQI8VL@;VX@(D5D:70@>6]U<B!B;&%C:VQI<W0B('1O('!R;V-E960@=&\@
M=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@
M=&AE(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y;W4@04Q705E3(')E9G5S
M92!M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)F:6QT97(M961I="UW:&ET96QI<W0B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/D9I;'1E<G,Z($5D:70@5VAI=&5L:7-T/"]T:71L93X*("`@(#QH96%D
M:6YG/D5D:70@66]U<B!7:&ET96QI<W0\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($-L:6-K(&]N(")%9&ET('EO=7(@=VAI=&5L:7-T(B!T;R!P<F]C965D
M('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L(&%N9"!E
M9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U($%,5T%94R!A
M8V-E<'0@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y&:6QT97)S.B!&:6QT97(@;VX@3&]G:6X\+W1I=&QE/@H@("`@/&AE861I
M;F<^07!P;'D@1FEL=&5R(%)U;&5S(%5P;VX@3&]G;VX_/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T;R!A;'=A>7,@87!P
M;'D@9FEL=&5R<R!W:&5N(&9I<G-T(&QO9V=I;F<@;VYT;R!)35`N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM9&ES<&QA
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&]N
M(%)E9G)E<V@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@9FEL=&5R(')U
M;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N('1O(&%L=V%Y<R!A<'!L
M>2!F:6QT97)S('=H96YE=F5R('EO=7(@=FEE=R!T:&4@24Y"3U@_"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M86YY+6UA:6QB
M;W@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!A
M;GD@36%I;&)O>#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!F:6QT97(@
M<G5L97,@=&\@86YY(&UA:6QB;W@_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!#:&5C:R!T:&ES(&]P=&EO;B!I9B!Y;W4@=V%N="!T;R!B92!A;&QO=V5D
M('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@;6%I;&)O>"X@3F]R;6%L
M;'DL(&9I;'1E<FEN9R!R=6QE<R!A<F4@;VYL>2!A<'!L:65D('1O(&YE=R!M
M86EL('1H870@:7,@9&5L:79E<F5D('1O('EO=7(@24Y"3U@N("!)9B!T:&ES
M(&]P=&EO;B!I<R!C:&5C:V5D+"!A;B!I8V]N('=I;&P@87!P96%R(&]N(&%L
M;"!M86EL8F]X('!A9V=E<R!T:&%T('=I;&P@86QL;W<@>6]U('1O(&%P<&QY
M(&9I;'1E<B!R=6QE<R!T;R!T:&4@;65S<V%G97,@:6X@=&AE(&-U<G)E;G0@
M;6%I;&)O>"X@($Y/5$4Z($9I;'1E<FEN9R!I;B!M86EL8F]X97,@;W1H97(@
M=&AA;B!)3D)/6"!M87D@<')O9'5C92!S=')A;F=E("AE+F<N('1H92!F:6QT
M97(@;6%Y(&-A=7-E(&$@8V]P>2!O9B!M97-S86=E<R!T;R!B92!D96QI=F5R
M960@=&\@=&AE('-A;64@;6%I;&)O>"D@86YD+V]R('5N9&5S:7)E9"!R97-U
M;'1S("AE+F<N(&ET(&UA>2!C875S92!M97-S86=E<R!T;R!B92!M;W9E9"]D
M96QE=&5D(&EF(&YE=R!F:6QT97)I;F<@<G5L97,@:&%V92!B965N(&EM<&QE
M;65N=&5D('-I;F-E('1H92!M97-S86=E(&AA<R!B965N(&1E;&EV97)E9"!T
M;R!T:&4@8W5R<F5N="!M86EL8F]X*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C:"UP=6)K97DB('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@071T86-H(%!U8FQI8R!+97D\+W1I
M=&QE/@H@("`@/&AE861I;F<^071T86-H(%!U8FQI8R!+97D\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@82!C;W!Y(&]F('EO
M=7(@4$=0('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T<RP@=VEL;"!B92!A='1A
M8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X@(%EO=2!C86X@<V5T('1H
M92!D969A=6QT(&)E:&%V:6]R('9I82!T:&4@4$=0($]P=&EO;G,@<V-R965N
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO
M;BUS8V%N+6)O9'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@4V-A
M;B!497AT($)O9&EE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY38V%N(%1E>'0@
M0F]D:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T
M:&5N($E-4"!W:6QL('-C86X@=&AE(&)O9'D@;V8@86QL('1E>'0@;65S<V%G
M97,@9F]R(%!'4"!D871A+"!A;F0@9&ES<&QA>2!T:&4@<F5S=6QT<R!I9B!A
M;GD@9&%T82!I<R!F;W5N9"X@($YO=&4@=&AA="!T:&ES(&UA>2!S;&]W(&1O
M=VX@=&AE('-Y<W1E;2!A<R!E=F5R>2!T97AT(&UE<W-A9V4@;75S="!B92!S
M8V%N;F5D(&EN(&ET<R!E;G1I<F5T>2!F;W(@4$=0(&1A=&$N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,M96YC
M<GEP="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^0V]M<&]S93H@16YC<GEP
M=&EO;B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/DYO($5N8W)Y<'1I
M;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@=&AE(&UE<W-A9V4@
M=VET:"!N;R!E;F-R>7!T:6]N("AC;&5A<G1E>'0I+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^4$=0($5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!E;F-R>7!T('1H92!C=7)R
M96YT(&UE<W-A9V4L('5S:6YG(%!'4"!A;F0@=&AE(')E8VEP:65N=',@<&5R
M<V]N86P@<'5B;&EC(&ME>2P@86YD('1H96X@<V5N9"!I="X@66]U(&-A;B!O
M;FQY('-E;F0@82!M97-S86=E('1O(&$@<VEN9VQE('!E<G-O;B!U<VEN9R!T
M:&ES(&]P=&EO;BX@66]U($U54U0@:&%V92!T:&4@<'5B;&EC(&ME>2!O9B!T
M:&4@<F5C:7!I96YT('-T;W)E9"!I;B!Y;W5R(&%D9')E<W-B;V]K(&]R(&5L
M<V4@=&AI<R!O<'1I;VX@=VEL;"!F86EL+B!)9B!Y;W4@:&%V92!T:&4@<'5B
M;&EC(&ME>2!F;W(@=&AE(')E8VEP:65N="!I;B!Y;W5R(&%D9')E<W-B;V]K
M(&%N9"!A<F4@<W1I;&P@<F5C96EV:6YG(&5R<F]R<RP@=F5R:69Y('1H870@
M=&AE(&4M;6%I;"!A9&1R97-S(&EN('1H92!R96-I<&EE;G0@9FEE;&0@;6%T
M8VAE<R!T:&4@92UM86EL(&%D9')E<W,@=VAE<F4@=&AE('!U8FQI8R!K97D@
M:7,@<W1O<F5D+B!4:&4@96YC<GEP=&5D(&1A=&$@=VEL;"!B92!A='1A8VAE
M9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E!'4"!3:6=N($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1H:7,@;W!T:6]N('=I;&P@9&EG:71A;&QY('-I9VX@=&AE(&-U<G)E
M;G0@;65S<V%G92!U<VEN9R!01U`@86YD('EO=7(@<&5R<V]N86P@<')I=F%T
M92!K97DN($EF('EO=2!H879E(&YO="!A;')E861Y(&5N=&5R960@=&AE('!A
M<W-P:')A<V4@9F]R('EO=7(@<')I=F%T92!K97D@9'5R:6YG('1H:7,@<V5S
M<VEO;B!Y;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@:70N("!4:&4@<F5C96EP
M:65N="!M=7-T(&AA=F4@82!C;W!Y(&]F('EO=7(@<'5B;&EC(&ME>2!T;R!D
M:6=I=&%L;'D@=F5R:69Y('EO=7(*("`@('-I9VYA='5R92X*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!F:7)S="!D
M:6=I=&%L;'D@<VEG;B!Y;W5R(&UE<W-A9V4@86YD('1H96X@=VEL;"!E;F-R
M>7!T('1H92!R97-U;'1I;F<@;W5T<'5T+B!3964@=&AE("=01U`@16YC<GEP
M="!-97-S86=E)R!A;F0@)U!'4"!3:6=N($UE<W-A9V4G(&5N=')I97,@9F]R
M(&9U<G1H97(@:6YF;W)M871I;VXN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY3+TU)344@16YC<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG
M;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A
M9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R=FEE=R(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4$=0.B!/=F5R=FEE=SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY7:&%T(&ES(%!'4#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%!'
M4"!I<R!A('1O;VP@9F]R('-E8W5R92!C;VUM=6YI8V%T:6]N(&%N9"!D871A
M('-T;W)A9V4L(&5S<&5C:6%L;'D@9F]R('5S92!W:71H(&4M;6%I;"X@270@
M8V%N(&)E('5S960@=&\@96YC<GEP="!D871A(&%N9"!T;R!C<F5A=&4@9&EG
M:71A;"!S:6=N871U<F5S+B!)35`@=7-E<R!';G501R`H1TY5(%!R:79A8WD@
M1W5A<F0I('1O('!R;W9I9&4@=&AI<R!F=6YC=&EO;F%L:71Y+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=&AI<R!O<'1I;VX@:7,@<V5L
M96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@8W)E871E+W9I97<@>6]U<B!P
M97)S;VYA;"!01U`@:V5Y<RP@861D+V1E;&5T92!P=6)L:6,@:V5Y<R!F<F]M
M(&]T:&5R(&EN9&EV:61U86QS+"!R96%D(&5N8W)Y<'1E9"!M86EL+"!V97)I
M9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@96YC<GEP="]S:6=N('EO
M=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UO<'1I;VXM871T86-H+7!U8FME>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4$=0.B!/<'1I;VYS("T@071T86-H(%!U8FQI8R!+97D\
M+W1I=&QE/@H@("`@/&AE861I;F<^3W!T:6]N<R`M($%T=&%C:"!0=6)L:6,@
M2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N
M(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L
M('=I;&P@8GD@9&5F875L="!B92!A='1A8VAE9"!T;R!A;&P@;W5T9V]I;F<@
M;65S<V%G97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0
M.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E
M<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@<V-R965N(&QI
M<W1S(&%L;"!O9B!T:&4@8W5R<F5N="!U<V5R<R!I;B!Y;W5R(&%D9')E<W-B
M;V]K('1H870@:&%V92!01U`@<'5B;&EC(&ME>7,N(%1H97-E('5S97)S(&%R
M92!T:&4@3TY,62!U<V5R<R!T:&%T('EO=2!C86X@96ET:&5R(#$I('-E;F0@
M86X@96YC<GEP=&5D(&UE<W-A9V4@=&\@+4]2+2`R*2!V97)I9GD@82!D:6=I
M=&%L('-I9VYA='5R92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I97<\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O('9I
M97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@
M<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@1&5L971E<R!T:&4@<'5B;&EC(&ME>2!F<F]M('EO=7(@861D<F5S
M<V)O;VLN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M
M:6UP;W)T+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-
M86YA9V4@4'5B;&EC($ME>7,@+2!);7!O<G0\+W1I=&QE/@H@("`@/&AE861I
M;F<^26UP;W)T(%!U8FQI8R!+97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4:&ES(&)U='1O;B!W:6QL(&]P96X@82!W:6YD;W<@=VAE<F4@>6]U(&-A
M;B!M86YU86QL>2!I;7!O<G0@82!01U`@<'5B;&EC(&ME>2X@(%1H92!K97D@
M8V%N(&5I=&AE<B!B92!P87-T960@:6YT;R!A('1E>'1F:65L9"!O<BP@:68@
M=&AE(&ME>2!R97-I9&5S(&EN(&$@9FEL92!O;B!Y;W5R(&QO8V%L(&-O;7!U
M=&5R+"!Y;W4@8V%N(&EM<&]R="!I="X@($EF('1H92!K97D@:7,@=F%L:60@
M:70@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@861D<F5S<V)O;VL@86YD
M('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O
M<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<M
M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N
M86=E(%!E<G-O;F%L($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I
M97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('EO=2!W86YT('1O(&1I
M9VET86QL>2!S:6=N(&UE<W-A9V5S(&]R(&5N86)L92!O=&AE<G,@=&\@<V5N
M9"!Y;W4@96YC<GEP=&5D(&UE<W-A9V5S+"!Y;W4@;75S="!H879E('EO=7(@
M;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%!'4"!K97EP86ER+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0=6)L:6,@2V5Y/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!9;W5R('!U8FQI8R!K97D@<VAO=6QD(&)E(&UA
M9&4@879A:6QA8FQE('1O(&%N>2!P97)S;VX@=&AA="!Y;W4@=V%N="!T;R!B
M92!A8FQE('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M97-S86=E<R!T:&%T(&]N
M;'D@64]5(&-A;B!D96-R>7!T("AU<VEN9R!Y;W5R('!R:79A=&4@:V5Y*2X@
M061D:71I;VYA;&QY+"!Y;W5R('!U8FQI8R!K97D@;F5E9',@=&\@8F4@;6%D
M92!A=F%I;&%B;&4@=&\@86YY8F]D>2!Y;W4@<V5N9"!A(&1D:6=I=&%L;'D@
M<VEG;F5D(&UE<W-A9V4@=&\@+2!T:&4@<'5B;&EC(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE(&1I9VET86P@<VEG;F%T=7)E+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^66]U<B!0<FEV871E($ME>3PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@66]U<B!P<FEV871E(&ME>2!I<R!N96-E<W-A<GD@=&\@
M9&5C<GEP="!A;GD@;65S<V%G92!E;F-R>7!T960@=7-I;F<@>6]U<B!P=6)L
M:6,@:V5Y+B!!9&1I=&EO;F%L;'DL('EO=7(@<')I=F%T92!K97D@:7,@;F5E
M9&5D(&EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&$@;65S<V%G92X@
M66]U<B!P<FEV871E(&ME>2!W:6QL(&)E('!R;W1E8W1E9"!V:6$@82!P87-S
M<&AR87-E(&-R96%T960@=VAE;B!T:&4@:V5Y<R!A<F4@9V5N97)A=&5D+B!4
M:'5S+"!T;R!P97)F;W)M(&%N>2!A8W1I=FET>2!T:&%T(')E<75I<F5S('EO
M=7(@<')I=F%T92!K97DL($E-4"!W:6QL('!R;VUP="!Y;W4@9F]R('EO=7(@
M<&%S<W!H<F%S92X@66]U(&]N;'D@;F5E9"!T;R!I;G-E<G0@>6]U<B!P87-S
M<&AR87-E(&]N8V4@<&5R('-E<W-I;VX@+2!)35`@=VEL;"!S=&]R92!Y;W5R
M('!A<W-P:')A<V4@=6YT:6P@>6]U(&QO9V]U="`H4V\@8F4@<W5R92!T;R!L
M;V=O=70A*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UP97)S;VYA;&ME>2UP=6)L:6,B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!0=6)L:6,@2V5Y/"]T:71L
M93X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!0
M1U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UP<FEV871E(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@4')I=F%T92!+
M97D\+W1I=&QE/@H@("`@/&AE861I;F<^16YT97(@4&%S<W!H<F%S93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@=&AE('!A<W-P:')A<V4@9&EA
M;&]G('=I;F1O=RX@5&AE('!A<W-P:')A<V4@96YT97)E9"P@:68@8V]R<F5C
M="P@=VEL;"!B92!S=&]R960@8GD@24U0('5N=&EL('EO=7(@<V5S<VEO;B!E
M;F1S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^56YL;V%D(%!A<W-P:')A
M<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%)E;6]V97,@=&AE('-T;W)E
M9"!P87-S<&AR87-E(&9R;VT@24U0("T@86YY(&%D9&ET:6]N86P@=7-A9V4@
M;V8@=&AE('!R:79A=&4@:V5Y('=I;&P@<F5Q=6ER92!Y;W4@=&\@<F5E;G1E
M<B!T:&4@<&%S<W!H96%S92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I
M97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O
M('9I97<@=&AE(%!'4"!P<FEV871E(&ME>2X@1$\@3D]4(%-%3D0@5$A)4R!+
M15D@5$\@04Y93TY%("T@=&AI<R!O<'1I;VX@:7,@<W1R:6-T;'D@<V\@=&AA
M="!Y;W4@8V%N(&5X<&]R="!Y;W5R($E-4"!P97)S;VYA;"!P<FEV871E(&ME
M>2!F;W(@=7-E(&EN(&%N;W1H97(@<')O9W)A;2X*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1I
M<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!R:79A=&4@:V5Y
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O
M;F%L:V5Y+61E;&5T92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-
M86YA9V4@4&5R<V]N86P@2V5Y<R`M($1E;&5T93PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY$96QE=&4@4&5R<V]N86P@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AI<R!B=71T;VX@=VEL;"!D96QE=&4@>6]U<B!P97)S;VYA;"!P
M=6)L:6,O<')I=F%T92!K97EP86ER(&9R;VT@24U0)W,@<')E9F5R96YC97,N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N
M86QK97DM8W)E871E+6YA;64B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'
M4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($YA;64\+W1I=&QE/@H@("`@/&AE
M861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&YA;64@
M>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!(')E
M<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UC;VUM96YT(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!#;VUM
M96YT/"]T:71L93X*("`@(#QH96%D:6YG/D-O;6UE;G0\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($$@8V]M;65N="!S=')I;F<@>6]U('=A;G0@96UB961D
M960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!;B!O<'1I;VYA;"!F:65L9"X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA
M;&ME>2UC<F5A=&4M96UA:6PB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'
M4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($4M;6%I;"!!9&1R97-S/"]T:71L
M93X*("`@(#QH96%D:6YG/D4M;6%I;"!!9&1R97-S/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!4:&4@92UM86EL(&%D9')E<W,@>6]U('=A;G0@87-S;V-I
M871E9"!W:71H('EO=7(@<&5R<V]N86P@:V5Y<RX@02!R97%U:7)E9"!F:65L
M9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S
M;VYA;&ME>2UC<F5A=&4M:V5Y;&5N9W1H(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!+97EL96YG=&@\+W1I
M=&QE/@H@("`@/&AE861I;F<^2V5Y;&5N9W1H/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4:&4@:V5Y;&5N9W1H+"!I;B!B>71E<RP@;V8@>6]U<B!G96YE
M<F%T960@:V5Y+B!4:&4@9W)E871E<B!T:&4@=F%L=64L('1H92!G<F5A=&5R
M('1H92!P<F]T96-T:6]N("AA;F0@86QS;R!G<F5A=&5R(&=E;F5R871I;VX@
M=&EM92!A;F0@96YC<GEP=&EO;B!T:6UE*2X@,3`R-"!B>71E<R!I<R!T:&4@
M9&5F875L="`M('1H:7,@=F%L=64@<')O=FED97,@97AC96QL96YT('!R;W1E
M8W1I;VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M
M<&5R<V]N86QK97DM8W)E871E+7!A<W-P:')A<V4B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M(%!A<W-P:')A
M<V4\+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&AE('!A<W-P:')A<V4@=7-E9"!T;R!P<F]T96-T+V5N8W)Y
M<'0@>6]U<B!P97)S;VYA;"!P<FEV871E(&ME>2X@5&AI<R!S:&]U;&0@8F4@
M050@3$5!4U0@-B!C:&%R86-T97)S+"!S:&]U;&0@3D]4(&)E('1H92!S86UE
M(&%S('EO=7(@;&]G:6X@<&%S<W=O<F0L('-H;W5L9"!.3U0@8F4@8F%S960@
M;VX@82!D:6-T:6]N87)Y('=O<F0L(&%N9"!S:&]U;&0@:6YC;'5D92!B;W1H
M(&YU;6)E<G,@86YD(&QE='1E<G,N(%EO=2!M=7-T(&5N=&5R('1H:7,@<&%S
M<W!H<F%S92!T=VEC92!F;W(@=F5R:69I8V%T:6]N('!U<G!O<V5S+B!!(')E
M<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UA8W1I;VYS(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!!8W1I
M;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D-R96%T92!+97ES/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#<F5A=&4@86YD('-T;W)E('EO=7(@<&5R<V]N
M86PO<')I=F%T92!K97EP86ER+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M26UP;W)T($ME>7!A:7(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EM<&]R
M="!A('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX@5&AI<R!B=71T;VX@;W!E
M;G,@82!W:6YD;W<@=VAE<F4@>6]U(&-A;B!M86YU86QL>2!I;7!O<G0@>6]U
M<B!E>&ES=&EN9R!01U`@<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I
M<BX@(%1H92!K97ES(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT
M9FEE;&0@;W(L(&EF('1H92!K97ES(')E<VED92!I;B!A(&9I;&4@;VX@>6]U
M<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@=&AE;2X@($EF('1H
M92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS97)T960@:6YT;R!Y
M;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF
M(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D
M(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<VUI;64M;W9E<G9I97<B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E,O34E-13H@3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE861I;F<^5VAA="!I
M<R!3+TU)344_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3+TU)344@:7,@
M82!P<FEV871E+W!U8FQI8R!K97D@<&%I<B!S>7-T96T@=VAI8V@@<')O=FED
M97,@9&EG:71A;"!S:6=N871U<F5S+"!M97-S86=E('!R:79A8WDL(&%N9"!T
M86UP97(@9&5T96-T:6]N(&EN(&$@;W!E;BP@:6YT97)O<&5R86)L92!W87DN
M("!3+TU)344@8V%N('!R;W9I9&4@;65S<V%G92!P<FEV86-Y(&)Y(&5N8W)Y
M<'1I;F<@;65S<V%G97,@=&AA="!O;FQY('1H92!S96YD97(@86YD('1H92!I
M;G1E;F1E9"!R96-I<&EE;G1S(&-A;B!D96-O9&4N("!)="!A;&QO=W,@>6]U
M('1O(&ED96YT:69Y('1H92!S96YD97(@;V8@82!M97-S86=E('9I82!A(&1I
M9VET86P@<VEG;F%T=7)E+B`@5&]G971H97(L('1H:7,@96YC<GEP=&EO;B!A
M;F0@9&EG:71A;"!S:6=N:6YG(&AE;'`@<')O=FED92!T86UP97(@9&5T96-T
M:6]N+"!A;&QO=VEN9R!R96-I<&EE;G1S('1O(&1E=&5R;6EN92!W:&5T:&5R
M(&$@;65S<V%G92!W87,@86QT97)E9"!A9G1E<B!I="!W87,@<V5N="X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!3+TU)344@9G5N8W1I;VYA
M;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@;W!T:6]N
M(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&EM<&]R="!Y;W5R
M('!E<G-O;F%L(%,O34E-12!K97ES+"!R96%D(&5N8W)Y<'1E9"!M86EL+"!V
M97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@96YC<GEP="]S:6=N
M('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G-M:6UE+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y3+TU)344Z(%!E<G-O;F%L($ME>7,\+W1I=&QE
M/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&]R(&5N8W)Y<'0@
M;65S<V%G97,@>6]U(&UU<W0@:&%V92!Y;W5R(&]W;B!P97)S;VYA;"!P=6)L
M:6,O<')I=F%T92!3+TU)344@:V5Y<&%I<BX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G-M:6UE+6EM<&]R="UP97)S;VYA;"UC97)T<R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!);7!O<G0@4&5R<V]N
M86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH96%D:6YG/DEM<&]R="!0
M97)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($EM<&]R="!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!A(%!+0U,@(S$R
M(&9O<FUA="!F:6QE+B!02T-3(",Q,B!F:6QE<R!I<R!T:&4@9FEL92!U<W5A
M;&QY(&=E;F5R871E9"!W:&5N(&5X<&]R=&EN9R!A(&ME>2!F<F]M(&$@8G)O
M=W-E<B`H92YG+B!);G1E<FYE="!%>'!L;W)E<BP@1FER969O>"D@;W(@9G)O
M;2!A(&-E<G1I9FEC871E('-T;W)E(&UA:6YT86EN960@8GD@86X@3W!E<F%T
M:6YG(%-Y<W1E;2`H92YG+B!7:6YD;W=S(%A0*2X@268@=&AE(&ME>7,@87)E
M('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@<')E9F5R
M96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED
M+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN
M9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM
M92UD96QE=&4M<&5R<V]N86PM8V5R=',B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E,O34E-13H@1&5L971E(%!E<G-O;F%L($-E<G1I9FEC871E<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@0V5R=&EF:6-A=&5S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&4@>6]U<B!P97)S;VYA
M;"!C97)T:69I8V%T97,@9G)O;2!Y;W5R('!R969E<F5N8V5S+B`@66]U('=I
M;&P@;F\@;&]N9V5R(&)E(&%B;&4@=&\@<VEG;B!3+TU)344@;65S<V%G97,@
M;W(@=FEE=R!A;GD@4R]-24U%(&5N8W)Y<'1E9"!M97-S86=E<R!A9&1R97-S
M960@=&\@>6]U+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<VUI;64M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@("`@/&AE861I
M;F<^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($UA;F%G92!Y;W5R(%,O34E-12!P=6)L:6,@:V5Y(&QI<W0N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!6:65W('1H92!R87<@=&5X="!O9B!T:&4@<'5B;&EC(&ME
M>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%9I97<@=&5C:&YI8V%L(&1E=&%I;',@;V8@=&AE
M('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T97,@=&AE('-E;&5C=&5D
M('!U8FQI8R!K97D@9G)O;2!S=&]R86=E+B`@1&5L971I;F<@82!P=6)L:6,@
M:V5Y(&9O<B!A('5S97(@=VEL;"!P<F5V96YT('EO=7(@9G)O;2!E;F-R>7!T
M:6YG(&$@;65S<V%G92!T;R!T:&%T('5S97(N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<FEN=&EN9R(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')I;G1I;F<\+W1I=&QE/@H@("`@/&AE861I;F<^4')I;G0@82!M
M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4;R!P<FEN="!A(&UE
M<W-A9V4@>6]U(&%R92!V:65W:6YG+"!C;&EC:R!O;B!T:&4@(E!R:6YT(B!L
M:6YK(&%T(&5I=&AE<B!T:&4@=&]P(&]R(&)O='1O;2!O9B!T:&4@;65S<V%G
M92X@5&AE(&UE<W-A9V4@=VEL;"!O<&5N(&EN(&$@;F5W('=I;F1O=R!F;W)M
M871E9"!F;W(@<')I;G1I;F<N("!$97!E;F1I;F<@;VX@>6]U<B!W96(@8G)O
M=W-E<B!A;F0@;W!E<F%T:6YG('-Y<W1E;2P@=&AE('!R:6YT(&1I86QO9R!B
M;W@@;6%Y(&]P96X@9F]R('EO=2X@($EF(&ET(&1O97,@;F]T(&]P96XL('1H
M96X@<'5L;"!D;W=N('1H92!W96(@8G)O=W-E<B=S(")&:6QE(B!M96YU(&%N
M9"!C:&]O<V4@(E!R:6YT(B!T;R!O<&5N('1H92!P<FEN="!D:6%L;V<@8F]X
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V]R=&EN9R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4V]R=&EN9R!A;F0@5&AR96%D:6YG
M/"]T:71L93X*("`@(#QH96%D:6YG/E-O<G1I;F<@16YT<FEE<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5VAE;B!V:65W:6YG(&$@;&ES="!O9B!M97-S
M86=E<RP@>6]U(&-A;B!S;W)T('1H92!M97-S86=E<R!B>2!A;GD@8V]L=6UN
M(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T92!C;VQU;6X@:&5A9&EN
M9RX@(%1O('-W:71C:"!C;VQU;6YS(&)E='=E96X@87-C96YD:6YG(&%N9"!D
M97-C96YD:6YG(&]R9&5R+"!C;&EC:R!O;B!T:&4@87)R;W<@:6-O;B!I;B!T
M:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY4
M:')E861I;F<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1O(&=R;W5P(&UE
M<W-A9V5S(&)Y('1H<F5A9',@*'-U8FIE8W0I+"!S;R!E86-H(&UE<W-A9V4@
M:7,@9W)O=7!E9"!W:71H(&%L;"!I=',@<F5P;&EE<RP@8VQI8VL@=&AE(%M4
M:')E861=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L=6UN(&AE861I;F<N("!4
M;R!R971U<FX@=&\@;F]R;6%L('-U8FIE8W0@<V]R=&EN9RP@8VQI8VL@;VX@
M=&AE(%M3=6)J96-T72!L:6YK(&EN('1H92!S=6)J96-T(&-O;'5M;B!H96%D
M:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB86QT97)N
M871I=F4M;7-G(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-=6QT:7!A<G0O
M06QT97)N871I=F4@365S<V%G97,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3
M;VUE(&UE<W-A9V4@:&%V92!B965N('-E;G0@87,@82`B;75L=&EP87)T+V%L
M=&5R;F%T:79E(B!T>7!E(&)Y('1H92!S96YD97(N(%1H97-E(&UE<W-A9V5S
M(&AA=F4@<V5V97)A;"!P87)T<RP@86QL(&1I<W!L87EI;F<@=&AE(%-!344@
M0T].5$5.5"!B=70@:6X@1$E&1D5214Y4($9/4DU!5%,N(%1H92!M86EL(&%G
M96YT('=I;&P@9&ES<&QA>2!T:&4@;&%S="!P87)T(&EN('1H92!L:7-T('1H
M870@8V%N(&)E('-U8V-E<W-F=6QL>2!D:7-P;&%Y960@:6YL:6YE(&EN('1H
M92!B<F]W<V5R+"!I9B!A;GDN($%L;"!O=&AE<B!F;W)M871S('=I;&P@87!P
M96%R('5N9&5R('1H92!H96%D:6YG(")!;'1E<FYA=&EV92!P87)T<R!F;W(@
M=&AI<R!S96-T:6]N(B!A;F0@8V%N(&)E('9I97=E9"!O<B!D;W=N;&]A9&5D
M('-E<&%R871E;'DN($ET(&ES(&EM<&]R=&%N="!T;R!N;W1E('1H870@=&AE
M<V4@86QT97)N871I=F4@<&%R=',@8V]N=&%I;B!T:&4@4T%-12!#3TY414Y4
M4R!A<R!T:&4@<&%R="!T:&%T(&ES('-H;W=N("T@=&AE>2!A<F4@<VEM<&QY
M(&EN(&$@9&EF9F5R96YT(&UE9&EA(&9O<FUA="`H92YG+B!T97AT('9S+B!(
M5$U,(&]U='!U="DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUR96YA;65?<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!296YA;64@
M4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@
M("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!R
M96YA;64@>6]U<B!S96YT+6UA:6P@9F]L9&5R(&%T('1H92!B96=I;FYI;F<@
M;V8@979E<GD@;6]N=&@N("!4:&4@9F]L9&5R('=I;&P@8F4@<F5N86UE9"`H
M=&\@82!N86UE('1H870@8V]N=&%I;G,@=&AE(&UO;G1H(&%N9"!Y96%R*2!A
M;F0@82!N97<@<V5N="UM86EL(&9O;&1E<B!W:6QL(&)E(&-R96%T960N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?
M<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@4V5N="UM86EL($9O;&1E
M<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P
M=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD('-E;G0M
M;6%I;"!F;VQD97)S(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N
M("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@9F]R
M(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K965P(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T
M92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D@+2`C(&]F($9O;&1E<G,@=&\@
M2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@9&5L971I
M;F<@;VQD('-E;G0M;6%I;"!F;VQD97)S(&5V97)Y(&UO;G1H+"!H;W<@;6%N
M>2!M;VYT:',@;V8@;VQD(&9O;&1E<G,@9&\@>6]U("!W86YT('1O(&ME97`_
M("!!;GD@9F]L9&5R<R!O;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT:',@=VEL
M;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DB('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L
M971E($QI;FME9"!!='1A8VAM96YT<R!-;VYT:&QY/"]T:71L93X*("`@(#QP
M87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK
M92!T;R!D96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!T:&4@8F5G
M:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AI<R!M87D@8F4@=7-E9G5L(&EF
M('EO=2!H879E(&$@<75O=&$L(&9O<B!E>&%M<&QE+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S
M7VUO;G1H;'E?:V5E<"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE;G1S
M($UO;G1H;'D@+2`C(&]F($UO;G1H<R!T;R!+965P/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O;&0@;&EN:V5D(&%T=&%C
M:&UE;G1S(&5V97)Y(&UO;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@;VQD(&%T
M=&%C:&UE;G1S(&1O('EO=2`@=V%N="!T;R!K965P/R`@06YY(&%T=&%C:&UE
M;G1S(&]L9&5R('1H86X@=&AI<R!M86YY(&UO;G1H<R!W:6QL(&)E(&1E;&5T
M960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP
M=7)G95]T<F%S:"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:#PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($1O('EO=2!W86YT('1O('!U<F=E('EO=7(@=')A<V@@9F]L9&5R
M(&5V97)Y('-O(&]F=&5N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:6YT97)V86PB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@4'5R9V4@
M5')A<V@@26YT97)V86P\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L(&AO=R!O9G1E;B!S:&]U
M;&0@:70@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:V5E<"(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S
M:"!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R92!P=7)G
M:6YG('EO=7(@=')A<V@@9F]L9&5R+"!M97-S86=E(&]L9&5R('1H86X@:&]W
M(&UA;GD@9&%Y<R!S:&]U;&0@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB7W1E>'0B('-T871E/2)N
M97<B/@H@("`@(#QT:71L93Y0<F5F97)E;F-E<SH@365S<V%G92!#;VUP;W-I
M=&EO;CH@071T<FEB=71I;VX@5&5X=#PO=&ET;&4^"B`@("`@/'!A<F$^"B`@
M("`@2&5R92!Y;W4@8V%N(&5N=&5R('1H92!P:')A<V4@=&AA="!Y;W4@=VES
M:"!T;R!A<'!E87(@8F5F;W)E(&%N>2!Q=6]T960@=&5X="!I;B!A(')E<&QY
M('1H870@>6]U('-E;F0N"B`@("`@/"]P87)A/@H@("`@(#QP87)A/@H@("`@
M(%EO=2!C86X@:6YC;'5D92!O;F4@;W(@;6]R92!S<&5C:6%L('!L86-E:&]L
M9&5R<R!T;R!I;G-E<G0@:6YF;W)M871I;VX@86)O=70@=&AE(&UE<W-A9V4@
M=&\@=VAI8V@@>6]U(&%R92!R97!L>6EN9RX@4&QA8V5H;VQD97)S(&-O;G-I
M<W0@;V8@82`G)2<@9F]L;&]W960@8GD@82!S:6YG;&4@;&5T=&5R+B!4:&4@
M9F]L;&]W:6YG('!L86-E:&]L9&5R<R!A<F4@879A:6QA8FQE.@H@("`@(#PO
M<&%R83X*"B`@("`@/'!A<F$^("5F(#H@5&AE('-E;F1E<B=S(&YA;64@86YD
M(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^("5A(#H@5&AE('-E
M;F1E<B=S(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^("5P(#H@
M5&AE('-E;F1E<B=S(&YA;64\+W!A<F$^"B`@("`@/'!A<F$^("5R(#H@5&AE
M(&9U;&P@4D9#(#(X,C(@<W1Y;&4@9&%T92!A;F0@=&EM92!Z;VYE/"]P87)A
M/@H@("`@(#QP87)A/B`E9"`Z(%1H92!D871E(&%S('=W=RP@9&0@;6UM(%E9
M65D\+W!A<F$^"B`@("`@/'!A<F$^("5X(#H@5&AE(&1A=&4@:6X@=&AE(&QO
M8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^("5C(#H@5&AE(&1A
M=&4@86YD('1I;64@:6X@=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@
M("`@/'!A<F$^("5M(#H@5&AE($UE<W-A9V4M240\+W!A<F$^"B`@("`@/'!A
M<F$^("5S(#H@5&AE('-U8FIE8W0\+W!A<F$^"B`@("`@/'!A<F$^("5N(#H@
M02!N97<@;&EN93PO<&%R83X*("`@("`\<&%R83X@)24@.B!4:&4@)R4G(&-H
M87)A8W1E<CPO<&%R83X*"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD
M:7-P;W-I=&EO;E]R97%U97-T7W)E860B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!297%U97-T(%)E860@4F5C96EP=',\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!A(%)E860@4F5C96EP="(@<V5N
M9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G1S(&]F('1H:7,@;65S<V%G
M92!T;R!N;W1I9GD@>6]U('=H96X@=&AI<R!M97-S86=E(&ES(&]P96YE9"!B
M>2!T:&4@<F5C:7!I96YT<RX@3F]T(&%L;"!C;&EE;G1S('-U<'!O<G0@+R!H
M;VYO<B!T:&ES+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&ES<&]S:71I;VY?<V5N9%]M9&XB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!396YD($U$3CPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(")396YD(&$@341.(B!S96YD<R!A($UE<W-A9V4@1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N("AA;'-O(&MN;W=N(&%S(&$@<F5A9"!R96-E:7!T
M*2!W:&5N('EO=2!V:65W(&$@;65S<V%G92!I;B!W:&EC:"!T:&4@=7-E<B!H
M87,@<F5Q=65S=&5D('1H870@=&AE>2!R96-E:79E(&YO=&EF:6-A=&EO;B!T
M:&%T('EO=2!H879E(')E860@=&AE(&UE<W-A9V4N($EN(&UO<W0@8V%S97,L
M('1H:7,@=VEL;"!H87!P96X@875T;VUA=&EC86QL>2!W:71H;W5T('!R;VUP
M=&EN9R!Y;W4N($EN(&-E<G1A:6X@:7-O;&%T960@8V%S97,L('EO=2!M87D@
M:&%V92!T;R!M86YU86QL>2!D96-I9&4@=&\@<V5N9"!T:&4@;F]T:69I8V%T
M:6]N(&)Y(&-L:6-K:6YG(&]N(&$@;&EN:RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?9&5L
M:79E<GDB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!2
M97%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;CPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(")297%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(@<V5N9',@
M82!R97%U97-T('1O('1H92!R96-I<&EE;G0G<R!E+6UA:6P@<V5R=F5R('1O
M(&YO=&EF>2!Y;W4@=VAE;B!I="!H87,@9&5L:79E<F5D('1H92!M97-S86=E
M('1O('1H92!R96-I<&EE;G0G<R!M86EL8F]X+B!)="!D;V5S;B=T(&UE86X@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<V5E;BP@:G5S="!T:&%T(&ET)W,@<VET
M=&EN9R!I;B!A(&UA:6QB;W@@<V]M97=H97)E+B!.;W0@86QL(&UA:6P@<V5R
M=F5R<R!S=7!P;W)T('1H:7,N(`H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&5L971E7W-P86U?869T97)?<F5P;W)T(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@1&5L971E(%-P86T@
M069T97(@4F5P;W)T:6YG/"]T:71L93X*("`@(#QP87)A/@H@("`@66]U(&UA
M>2!E;&5C="!T;R!D;R!O;F4@;V8@=&AR964@:71E;7,@869T97(@<F5P;W)T
M:6YG(&$@;65S<V%G92!A<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@1FER<W0L('EO=2!C86X@9&5C:61E
M('1O(&1O(&YO=&AI;F<@+2!T:&4@;65S<V%G92!W:6QL(&)E(')E<&]R=&5D
M(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C96YT(&)U="!W:6QL(&]T:&5R=VES
M92!R96UA:6X@=6YC:&%N9V5D(&EN('EO=7(@;6%I;&)O>"X*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@4V5C;VYD+"!I9B!R97!O<G1I;F<@82!M97-S
M86=E(&%S('-P86TL('EO=2!C86X@:6YS=&5A9"!H879E('1H92!M97-S86=E
M(&)E(&EM;65D:6%T96QY(&1E;&5T960N("!4:&ES('-E='1I;F<@:&%S(&YO
M(&5F9F5C="!O;B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!4:&ER9"P@869T97(@<F5P;W)T
M:6YG(&$@;65S<V%G92!A<R!S<&%M('1H92!M97-S86=E('=I;&P@8F4@9&5L
M971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D('1O('EO
M=7(@<W!A;2!F;VQD97(N("!!;'1E<FYA=&EV96QY+"!I9B!R97!O<G1I;F<@
M82!M97-S86=E(&%S(&EN;F]C96YT('1H92!M97-S86=E('=I;&P@8F4@9&5L
M971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D('1O('EO
M=7(@24Y"3U@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUH=&UL7VEM86=E7W)E<&QA8V5M96YT(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G92!297!L86-E;65N=#PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($9O<B!(5$U,(&UE<W-A9V5S(&1I<W!L
M87EE9"!I;FQI;F4L('-H;W5L9"!A;&P@:6UA9V4@=&%G<R!B92!B;&]C:V5D
M('5N=&EL('EO=2!S<&5C:69I8V%L;'D@9&5C:61E('1O('9I97<@=&AO<V4@
M:6UA9V5S/R!.;W1E('1H870L(&EF('9I97=I;F<@86X@2%1-3"!A='1A8VAM
M96YT+"!T:&4@:6UA9V5S('=I;&P@86QW87ES(&)E(&1I<W!L87EE9"X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6AT;6Q?:6UA
M9V5?861D<F)O;VLB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N
M8V5S.B!(5$U,($EM86=E(%)E<&QA8V5M96YT+T%D9')E<W-B;V]K(%-H;W<\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!B;&]C:VEN9R!I;6%G97,@9F]R
M(&EN;&EN92!(5$U,(&UE<W-A9V5S+"!S:&]U;&0@=V4@875T;VUA=&EC86QL
M>2!D:7-P;&%Y('1H96T@:6YS=&5A9"!I9B!T:&4@<V5N9&5R(&%P<&5A<G,@
M:6X@>6]U<B!A9&1R97-S8F]O:S\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A<G0B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EL8F]X(%-T87)T(%!A9V4\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H:6-H('!A9V4@:6X@
M=&AE(&UA:6QB;W@@=FEE=R!W:6QL(&)E(&1I<W!L87EE9"!W:&5N('EO=2!A
M8V-E<W,@82!M86EL8F]X(&9O<B!T:&4@9FER<W0@=&EM92X@3F]T92!T:&%T
M('1H92`G=6YS965N)R!M97-S86=E(&]P=&EO;G,@9&\@;F]T('=O<FL@=VET
M:"!T:&4@)U1H<F5A9"<@<V]R=&EN9R!O<'1I;VX@+2!I;G-T96%D+"!Y;W4@
M=VEL;"!B92!S96YT('1O('1H92!L87-T('!A9V4N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E7V%T=&%C:&UE;G1S(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4V%V92!!='1A
M8VAM96YT<R!O;B!396YT($UE<W-A9V5S/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@<V%V:6YG(&$@8V]M<&]S960@;65S<V%G92!I;B!A('-E;G0M;6%I
M;"!F;VQD97(L(&1E=&5R;6EN92!I9B!A;&P@871T86-H;65N="!D871A(&ES
M('-A=F5D+B!4:&4@9F]L;&]W:6YG(&]P=&EO;G,@87)E(&%V86EL86)L93H*
M("`@(#PO<&%R83X*"B`@("`\<&%R83XJ(")!;'=A>7,@<V%V92!A='1A8VAM
M96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A='1A8VAM96YT<R!I;B!C
M;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S(&%R92!!3%=!65,@<V%V
M960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"B`@("`@/'!A<F$^*B`B4')O
M;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT
M('1O(%E%4R(@+2!!3%=!65,@<')O;7!T('1O('-A=F4@871T86-H;65N=',@
M:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F875L="!I<R!T;R!S879E
M(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R83XJ(")0<F]M<'0@979E
M<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B
M("T@04Q705E3('!R;VUP="!T;R!S879E(&%T=&%C:&UE;G1S(&EN('1H92!C
M;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@:7,@=&\@;F]T('-A=F4@871T
M86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@(DYE=F5R('-A=F4@871T
M86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A=F4@871T86-H;65N=',@
M:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT<R!A<F4@3D5615(@
M<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)V:7)T=6%L7VEN8F]X(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@26YB;W@\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!6:7)U=&%L($EN8F]X(&ES(&$@<V%V960@<V5A<F-H('1H
M870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@=&\@<V5A<F-H(&5V97)Y(&UA
M:6QB;W@@9F]R(&UE<W-A9V5S(&UA<FME9"!A<R!N97<N("!);G-T96%D+"!A
M;&P@8W5R<F5N=&QY('-U8G-C<FEB960@;6%I;&)O>&5S(&%R92!S96%R8VAE
M9"!F;W(@;F5W(&UE<W-A9V5S(&%N9"!T:&4@<F5S=6QT<R!A<F4@9&ES<&QA
M>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)V:7)T=6%L7W1R87-H(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@5')A<V@\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!6:7)T=6%L(%1R87-H(&ES(&$@<V%V960@<V5A
M<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@9F]R(&$@<V5P87)A
M=&4@5')A<V@@9F]L9&5R+B`@26YS=&5A9"!O9B!M;W9I;F<@;65S<V%G97,@
M=&\@82!C96YT<F%L:7IE9"!T<F%S:"!F;VQD97(L(&UE<W-A9V5S(&%R92!S
M:6UP;'D@;6%R:V5D(&%S(&1E;&5T960@:6X@=&AE(&-U<G)E;G0@9F]L9&5R
M('1H97D@;&EV92!I;BX@(%=H96X@)W-H;W<@9&5L971E9"!M97-S86=E<R<@
M:7,@='5R;F5D(&]F9BP@=&AI<R!R97-U;'1S(&EN('1H97-E(&UE<W-A9V5S
M(&YO="!A<'!E87)I;F<@:6X@82!M86EL8F]X('9I97<N("!7:&5N(&$@=7-E
M<B!C;&EC:W,@;VX@5FER='5A;"!4<F%S:"P@*F%L;"H@;6%I;&)O>&5S(&%L
M;"!S96%R8VAE9"!F;W(@;65S<V%G97,@=&AA="!A<F4@9FQA9V=E9"!D96QE
M=&5D(&%N9"!T:&5S92!M97-S86=E<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN
M9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+V9A7TE2+P``````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S8P`#`Q-S0R-@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M;V-A;&4O9F%?25(O3$-?34534T%'15,O````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C``,#(Q,C$S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]F85])4B],0U]-15-304=%4R]I;7`N
M;6\````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<P,C,T,@`Q,#0Q-S,V,C<V,``P
M,C(S-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````"!"0``'````"1,``"S#```+)@```````#XR@``"@```/G*
M```*````!,L```H````/RP``"@```!K+```.````)<L```\````TRP``#0``
M`$3+```(````4LL```L```!;RP``#````&?+```*````=,L```0```!_RP``
M!````(3+```D````B<L``"D```"NRP``&0```-C+```!````\LL``!D```#T
MRP``)@````[,```,````-<P``"0```!"S```'@```&?,``!(````ALP``"L`
M``#/S```1````/O,```G````0,T``!<```!HS0``#P```(#-```+````D,T`
M``X```"<S0``!0```*O-```H````L<T```@```#:S0``"@```./-```5````
M[LT``!(````$S@``,@```!?.```+````2LX``"D```!6S@``,@```(#.```0
M````L\X``!0```#$S@``$````-G.```F````ZLX``"<````1SP``)@```#G/
M```<````8,\``(4```!]SP``#@````/0```*````$M````T````=T```)P``
M`"O0```@````4]````X```!TT```%P```(/0```B````F]```#4```"^T```
M$0```/30```-````!M$```P````4T0``#0```"'1```&````+]$``!L````V
MT0``+@```%+1```W````@=$```8```"YT0``#````,#1``!\````S=$``&P`
M``!*T@``'````+?2```=````U-(```H```#RT@``#P```/W2```8````#=,`
M``P````FTP``&P```#/3``!%````3],``"@```"5TP``00```+[3```D````
M`-0```X````EU```#P```#34```.````1-0```X```!3U```"````&+4```.
M````:]0```X```!ZU```+@```(G4```:````N-0``#,```#3U```40````?5
M```R````6=4``#@```",U0``5````,75``!1````&M8``%H```!LU@``5P``
M`,?6```T````']<```T```!4UP``!P```&+7```*````:M<```\```!UUP``
M!0```(77```#````B]<``!$```"/UP``"````*'7```)````JM<```D```"T
MUP``#@```+[7```(````S=<```H```#6UP``)0```.'7```@````!]@``!,`
M```HV```$````#S8```/````3=@```\```!=V```"@```&W8```'````>-@`
M``,```"`V```#P```(38```4````E-@```D```"IV```#0```+/8```2````
MP=@``!X```#4V```#P```//8```*`````]D```\````.V0``"````![9```*
M````)]D``"0````RV0``%P```%?9```4````;]D``!8```"$V0``"````)O9
M```<````I-D``!D```#!V0``8````-O9```H````/-H``!X```!EV@``&@``
M`(3:```L````G]H``"````#,V@``,@```.W:```'````(-L```P````HVP``
M#0```#7;``!4````0]L``&,```"8VP``+````/S;```.````*=P```,````X
MW```!0```#S<```%````0MP```H```!(W````P```%/<```7````5]P```H`
M``!OW```#P```'K<```.````BMP``$X```"9W```4````.C<``!#````.=T`
M`$(```!]W0``%@```,#=```P````U]T``!@````(W@``(P```"'>```.````
M1=X``!0```!4W@``%P```&G>```7````@=X``!<```"9W@``$P```+'>```/
M````Q=X``",```#5W@``!@```/G>```7`````-\``%$````8WP``'P```&K?
M```U````BM\```\```#`WP``!@```-#?```(````U]\``!$```#@WP``"P``
M`/+?```0````_M\``!4````/X```#0```"7@```3````,^```",```!'X```
M+P```&O@```5````F^````<```"QX```$````+G@```%````RN```!4```#0
MX```$0```.;@```,````^.```#`````%X0``2````#;A```A````?^$``#L`
M``"AX0``.P```-WA```\````&>(``"L```!6X@``,````(+B```Q````L^(`
M`#L```#EX@``.0```"'C```U````6^,``!0```"1XP``#````*;C```#````
ML^,```D```"WXP```P```,'C```Y````Q>,``!(```#_XP``!@```!+D```,
M````&>0``#4````FY```#@```%SD``!)````:^0``#,```"UY```"@```.GD
M```M````].0```L````BY0``)P```"[E```L````5N4``"H```"#Y0``)0``
M`*[E```)````U.4```D```#>Y0``"@```.CE```&````\^4``"\```#ZY0``
M-P```"KF```N````8N8``%4```"1Y@``+0```.?F```L````%><``"T```!"
MYP``+0```'#G``!`````GN<``",```#?YP``(P````/H```M````)^@``#,`
M``!5Z```%0```(GH```9````G^@``"D```"YZ```)````./H``!0````".D`
M`!@```!9Z0``$0```'+I```1````A.D```L```"6Z0``"@```*+I```C````
MK>D``!8```#1Z0``"@```.CI```0````\^D``!8````$Z@``%@```!OJ```4
M````,NH```@```!'Z@```P```%#J```X````5.H```D```"-Z@``*0```)?J
M```.````P>H```H```#0Z@``10```-OJ```$````(>L```0````FZP``"0``
M`"OK```&````->L``!$````\ZP``!P```$[K```$````5NL``"<```!;ZP``
M!@```(/K```-````BNL```,```"8ZP```P```)SK```7````H.L``!,```"X
MZP``"````,SK```(````U>L```0```#>ZP``*@```./K```K````#NP``%,`
M```Z[```00```([L```:````T.P``"````#K[```%0````SM```&````(NT`
M``X````I[0``%0```#CM```^````3NT``!@```"-[0``(@```*;M```N````
MR>T``!T```#X[0``(0```!;N``!4````..X``"D```"-[@``!P```+?N```'
M````O^X``!4```#'[@```@```-WN```*````X.X```\```#K[@``#0```/ON
M```/````">\```T````9[P``"0```"?O```4````,>\```8```!&[P``'0``
M`$WO```3````:^\``!0```!_[P``3P```)3O```,````Y.\```8```#Q[P``
M"@```/CO```-`````_```!0````1\```8@```";P```G````B?```%0```"Q
M\```7P````;Q``!D````9O$```0```#+\0``%@```-#Q```.````Y_$``!P`
M``#V\0``#P```!/R```S````(_(``"@```!7\@``!0```(#R```;````AO(`
M`!H```"B\@``#@```+WR```5````S/(``#````#B\@``$0```!/S```1````
M)?,``!$````W\P``'````$GS```J````9O,``#4```"1\P``10```,?S```A
M````#?0```4````O]```$P```#7T```2````2?0```H```!<]```#P```&?T
M``!'````=_0``!\```"_]```)0```-_T```S````!?4``"L````Y]0``-0``
M`&7U``!"````F_4``!T```#>]0``40```/SU```1````3O8``#$```!@]@``
M.P```)+V```3````SO8``$````#B]@``.````"/W```%````7/<```P```!B
M]P``$0```&_W```-````@?<```8```"/]P``!@```);W```(````G?<```P`
M``"F]P``%````+/W```/````R/<``!````#8]P``$0```.GW```%````^_<`
M`!$````!^```#````!/X```0````(/@```4````Q^```#0```#?X```&````
M1?@```<```!,^```#0```%3X```'````8O@```L```!J^```!P```';X```)
M````?O@``!<```"(^```)@```*#X``!/````Q_@```D````7^0``"0```"'Y
M```*````*_D``!D````V^0``#````%#Y```E````7?D``!\```"#^0``$```
M`*/Y```2````M/D``!,```#'^0``*P```-OY```[````!_H``"````!#^@``
M&P```&3Z```(````@/H``#8```")^@``"````,#Z```;````R?H``!X```#E
M^@``7`````3[```N````8?L```8```"0^P``!````)?[```.````G/L```X`
M``"K^P``!P```+K[```.````POL``!X```#1^P``&P```/#[```A````#/P`
M`!X````N_```&0```$W\```>````9_P``!T```"&_```&P```*3\```@````
MP/P``"8```#A_```)`````C]```;````+?T``!X```!)_0``'````&C]```F
M````A?T``#8```"L_0``,P```./]```I````%_X``$$```!!_@``.@```(/^
M```F````OOX``"L```#E_@``.````!'_```O````2O\``!(```!Z_P``*0``
M`(W_```2````M_\``*(```#*_P``%@```&T``0`C````A``!`"@```"H``$`
M*0```-$``0`H````^P`!`!\````D`0$`(````$0!`0`E````90$!`"@```"+
M`0$`,````+0!`0"2````Y0$!`"$```!X`@$`'````)H"`0`F````MP(!`$$`
M``#>`@$`#````"`#`0`'````+0,!``<````U`P$`!@```#T#`0`-````1`,!
M``L```!2`P$`%0```%X#`0`-````=`,!`!@```""`P$`&@```)L#`0`0````
MM@,!`!T```#'`P$`&0```.4#`0!=````_P,!`!4```!=!`$`)0```',$`0`2
M````F00!`!,```"L!`$`$@```,`$`0`,````TP0!``X```#@!`$`#P```.\$
M`0`4````_P0!`!,````4!0$`#0```"@%`0`Y````-@4!`!P```!P!0$`*```
M`(T%`0`#````M@4!``T```"Z!0$`$0```,@%`0`7````V@4!`!L```#R!0$`
M`@````X&`0`%````$08!``4````7!@$`$````!T&`0`$````+@8!``T````S
M!@$`#@```$$&`0`#````4`8!``X```!4!@$`"````&,&`0`/````;`8!``@`
M``!\!@$`"@```(4&`0`/````D`8!``T```"@!@$`$````*X&`0`-````OP8!
M`!D```#-!@$`&@```.<&`0`+`````@<!``D````.!P$`!@```!@'`0`4````
M'P<!`!,````T!P$`$````$@'`0`,````60<!`!$```!F!P$`%P```'@'`0`1
M````D`<!`!4```"B!P$`&0```+@'`0`+````T@<!``T```#>!P$`(@```.P'
M`0`K````#P@!`!<````["`$`-````%,(`0`S````B`@!`!L```"\"`$`-```
M`-@(`0`*````#0D!`!@````8"0$`%````#$)`0`9````1@D!`!8```!@"0$`
M!P```'<)`0`0````?PD!`!P```"0"0$`'````*T)`0`-````R@D!``P```#8
M"0$`)@```.4)`0`*````#`H!`!0````7"@$`"P```"P*`0`'````.`H!`"(`
M``!`"@$`+P```&,*`0`+````DPH!``D```"?"@$`&0```*D*`0`+````PPH!
M``\```#/"@$`%P```-\*`0`7````]PH!``D````/"P$`!P```!D+`0`6````
M(0L!``\````X"P$`+0```$@+`0`9````=@L!`!8```"0"P$`#@```*<+`0`:
M````M@L!`"@```#1"P$`+0```/H+`0`N````*`P!``L```!7#`$`&````&,,
M`0`,````?`P!`",```")#`$`#0```*T,`0`F````NPP!`"H```#B#`$`(```
M``T-`0!#````+@T!`!\```!R#0$`!````)(-`0`(````EPT!``L```"@#0$`
M&@```*P-`0`G````QPT!`!(```#O#0$`(`````(.`0`O````(PX!`!<```!3
M#@$`!0```&L.`0`,````<0X!``X```!^#@$`#@```(T.`0`%````G`X!``8`
M``"B#@$`#@```*D.`0`#````N`X!``,```"\#@$`*P```,`.`0`$````[`X!
M``X```#Q#@$`"@`````/`0`,````"P\!``H````8#P$`#P```",/`0`0````
M,P\!`!<```!$#P$`$P```%P/`0`E````<`\!``X```"6#P$`$0```*4/`0`9
M````MP\!`!<```#1#P$`$P```.D/`0`6````_0\!`#@````4$`$`$P```$T0
M`0`)````81`!``H```!K$`$``@```'80`0`%````>1`!``T```!_$`$`&P``
M`(T0`0`7````J1`!``D```#!$`$`'0```,L0`0`/````Z1`!`!8```#Y$`$`
M$@```!`1`0`+````(Q$!``P````O$0$`#@```#P1`0`-````2Q$!`!(```!9
M$0$`&0```&P1`0`<````AA$!`#@```"C$0$`&````-P1`0`@````]1$!`!,`
M```6$@$``P```"H2`0`5````+A(!``L```!$$@$`$P```%`2`0`(````9!(!
M``X```!M$@$`$````'P2`0![````C1(!`!@````)$P$`)P```"(3`0`I````
M2A,!`"P```!T$P$`*````*$3`0`U````RA,!``4`````%`$`&`````84`0`9
M````'Q0!`!@````Y%`$`&P```%(4`0`9````;A0!``8```"(%`$`!@```(\4
M`0`;````EA0!`!````"R%`$`#P```,,4`0`0````TQ0!``\```#D%`$`"P``
M`/04`0`/`````!4!``P````0%0$`#P```!T5`0`'````+14!``8````U%0$`
M"@```#P5`0`2````1Q4!``T```!:%0$`#````&@5`0`.````=14!`$,```"$
M%0$`/0```,@5`0`)````!A8!``P````0%@$`#P```!T6`0`(````+18!``@`
M```V%@$`$P```#\6`0`>````4Q8!`"$```!R%@$`(````)06`0`9````M18!
M`!<```#/%@$`)0```.<6`0`7````#1<!``0````E%P$`#````"H7`0`#````
M-Q<!``@````[%P$`"@```$07`0`@````3Q<!`!\```!P%P$`&P```)`7`0`9
M````K!<!``L```#&%P$`&P```-(7`0`+````[A<!`!````#Z%P$`"`````L8
M`0`$````%!@!`!,````9&`$`%````"T8`0`,````0A@!``D```!/&`$`#@``
M`%D8`0`+````:!@!`!L```!T&`$`#@```)`8`0`/````GQ@!`"4```"O&`$`
M*@```-48`0`'`````!D!`!(````(&0$`&P```!L9`0`$````-QD!``H````\
M&0$`$@```$<9`0`*````6AD!``T```!E&0$`"0```',9`0`%````?1D!``@`
M``"#&0$``P```(P9`0`8````D!D!`!T```"I&0$`$````,<9`0`.````V!D!
M`!X```#G&0$`&@````8:`0`*````(1H!``0````L&@$`)@```#$:`0`.````
M6!H!`!4```!G&@$`1````'T:`0`%````PAH!``<```#(&@$`#````-`:`0`(
M````W1H!``H```#F&@$`!@```/$:`0`'````^!H!``@`````&P$`$0````D;
M`0`9````&QL!``@````U&P$``@```#X;`0`&````01L!`!4```!(&P$`#P``
M`%X;`0`1````;AL!`!H```"`&P$`!0```)L;`0`$````H1L!``P```"F&P$`
M"0```+,;`0`0````O1L!``D```#.&P$`"0```-@;`0`$````XAL!``4```#G
M&P$`&@```.T;`0`:````"!P!``@````C'`$`#P```"P<`0`9````/!P!``X`
M``!6'`$`(@```&4<`0`*````B!P!``T```"3'`$`(````*$<`0`-````PAP!
M``P```#0'`$`"0```-T<`0`2````YQP!`!0```#Z'`$`'0````\=`0`&````
M+1T!`!$````T'0$`"0```$8=`0`$````4!T!``0```!5'0$`%P```%H=`0`Y
M````<AT!`#T```"L'0$`.@```.H=`0`>````)1X!``X```!$'@$`!````%,>
M`0`&````6!X!``<```!?'@$`%0```&<>`0`&````?1X!``0```"$'@$`$0``
M`(D>`0`&````FQX!``H```"B'@$`(@```*T>`0`G````T!X!``8```#X'@$`
M%0```/\>`0`,````%1\!`!$````B'P$`!````#0?`0`-````.1\!``<```!'
M'P$`!0```$\?`0`$````51\!``P```!:'P$`#@```&<?`0`*````=A\!``4`
M``"!'P$`.@```(<?`0`P````PA\!`#4```#S'P$`*0```"D@`0`X````4R`!
M`"D```",(`$`/P```+8@`0`N````]B`!`"T````E(0$`'P```%,A`0`/````
M<R$!`!(```"#(0$`"P```)8A`0`F````HB$!`"<```#)(0$`*0```/$A`0`D
M````&R(!`"8```!`(@$`*````&<B`0`(````D"(!``H```"9(@$`!````*0B
M`0`<````J2(!`"````#&(@$`(````.<B`0`F````"",!``T````O(P$`)P``
M`#TC`0`;````92,!``P```"!(P$`%@```(XC`0`%````I2,!``H```"K(P$`
M&0```+8C`0`I````T",!`!(```#Z(P$`"@````TD`0`,````&"0!``\````E
M)`$`$````#4D`0!`````1B0!`#P```"')`$`<````,0D`0!F````-24!``8`
M``"<)0$`"@```*,E`0`%````KB4!``X```"T)0$`"0```,,E`0`*````S24!
M`!(```#8)0$`$P```.LE`0`,````_R4!``8````,)@$`!@```!,F`0`*````
M&B8!``X````E)@$`#P```#0F`0`.````1"8!`!L```!3)@$`'P```&\F`0`>
M````CR8!`",```"N)@$`$0```-(F`0`5````Y"8!`!@```#Z)@$`$0```!,G
M`0`0````)2<!`",````V)P$`#P```%HG`0`)````:B<!`!(```!T)P$`'0``
M`(<G`0`2````I2<!`!````"X)P$`"@```,DG`0`1````U"<!``4```#F)P$`
M,0```.PG`0`D````'B@!`!P```!#*`$`(P```&`H`0!J````A"@!``\```#O
M*`$`$````/\H`0`$````$"D!``L````5*0$`(````"$I`0`<````0BD!`",`
M``!?*0$`(@```(,I`0`&````IBD!`!0```"M*0$`%P```,(I`0`,````VBD!
M`"0```#G*0$`(P````PJ`0`:````,"H!``P```!+*@$`#P```%@J`0`5````
M:"H!`"D```!^*@$`*@```*@J`0`F````TRH!`"<```#Z*@$`*0```"(K`0`J
M````3"L!`!D```!W*P$`0@```)$K`0`1````U"L!`!(```#F*P$`$P```/DK
M`0`4````#2P!``\````B+`$`%@```#(L`0`7````22P!`!````!A+`$`$0``
M`'(L`0`T````A"P!`!,```"Y+`$`$@```,TL`0`U````X"P!`!0````6+0$`
M!P```"LM`0`,````,RT!`"L```!`+0$`#P```&PM`0`6````?"T!`"````"3
M+0$`%````+0M`0`1````R2T!`"@```#;+0$`%P````0N`0`<````'"X!`!,`
M```Y+@$`"P```$TN`0`1````62X!`!H```!K+@$`'@```(8N`0`:````I2X!
M`"$```#`+@$`(````.(N`0`1`````R\!`!<````5+P$`%````"TO`0`7````
M0B\!`!4```!:+P$`"0```'`O`0`&````>B\!`!````"!+P$`$0```)(O`0`&
M````I"\!``8```"K+P$`!P```+(O`0`6````NB\!``8```#1+P$`!````-@O
M`0`$````W2\!``<```#B+P$`#@```.HO`0`,````^2\!``P````&,`$`#0``
M`!,P`0`"````(3`!``X````D,`$`*````#,P`0`,````7#`!``\```!I,`$`
M"@```'DP`0`(````A#`!``D```"-,`$`*P```)<P`0!'````PS`!`%,````+
M,0$`+@```%\Q`0`$````CC$!``\```"3,0$`!P```*,Q`0`(````JS$!``D`
M``"T,0$`$0```+XQ`0`)````T#$!`!0```#:,0$`#````.\Q`0`-````_#$!
M``X````*,@$`%@```!DR`0`1````,#(!``,```!",@$`!@```$8R`0`$````
M33(!``L```!2,@$`"P```%XR`0`1````:C(!``T```!\,@$`"@```(HR`0`0
M````E3(!``\```"F,@$`$0```+8R`0`7````R#(!``H```#@,@$`$0```.LR
M`0`$````_3(!``\````",P$`.@```!(S`0`A````33,!``4```!O,P$`%P``
M`'4S`0`,````C3,!`!X```":,P$`#@```+DS`0`0````R#,!``L```#9,P$`
M?````.4S`0`,````8C0!``D```!O-`$`!P```'DT`0`*````@30!``D```",
M-`$`#@```)8T`0`0````I30!`!4```"V-`$`&@```,PT`0`*````YS0!``H`
M``#R-`$`#@```/TT`0`,````##4!``\````9-0$`"````"DU`0`&````,C4!
M``P````Y-0$`!P```$8U`0`%````3C4!``L```!4-0$`1P```&`U`0`-````
MJ#4!``D```"V-0$`!````,`U`0`#````Q34!``P```#)-0$`$P```-8U`0`3
M````ZC4!`!,```#^-0$`!@```!(V`0`"````&38!``0````<-@$`)0```"$V
M`0`#````1S8!``X```!+-@$`!0```%HV`0`$````8#8!``H```!E-@$`#0``
M`'`V`0`?````?C8!``<```">-@$`(@```*8V`0`-````R38!`&@```#7-@$`
M"0```$`W`0`,````2C<!``4```!7-P$`!@```%TW`0`C````9#<!`"4```"(
M-P$`"````*XW`0`W````MS<!`"(```#O-P$`$P```!(X`0`;````)C@!`"\`
M``!".`$`$0```'(X`0`/````A#@!``\```"4.`$`$P```*0X`0`;````N#@!
M`!@```#4.`$`%P```.TX`0`7````!3D!`!D````=.0$`#@```#<Y`0`F````
M1CD!`"8```!M.0$``P```)0Y`0`(````F#D!`!0```"A.0$`$P```+8Y`0`0
M````RCD!``T```#;.0$`#@```.DY`0`6````^#D!``<````/.@$`$````!<Z
M`0`*````*#H!``L````S.@$`!P```#\Z`0`3````1SH!``P```!;.@$`#P``
M`&@Z`0`.````>#H!``P```"'.@$`#@```)0Z`0!1````HSH!``\```#U.@$`
M$`````4[`0`-````%CL!``\````D.P$`#P```#0[`0`7````1#L!`!0```!<
M.P$`$0```'$[`0`/````@SL!`"````"3.P$`+@```+0[`0`:````XSL!``P`
M``#^.P$`)@````L\`0`+````,CP!``T````^/`$`&@```$P\`0!*````9SP!
M``8```"R/`$`!@```+D\`0`&````P#P!``D```#'/`$`&````-$\`0`7````
MZCP!``8````"/0$`#0````D]`0!7````%ST!`!,```!O/0$`$P```(,]`0`"
M````EST!``L```":/0$`"````*8]`0`-````KST!``8```"]/0$`"@```,0]
M`0`.````SST!``<```#>/0$`"P```.8]`0`,````\CT!``T```#_/0$`#```
M``T^`0`$````&CX!``D````?/@$`"0```"D^`0`*````,SX!``<````^/@$`
M"0```$8^`0!`````4#X!``X```"1/@$`!P```*`^`0`;````J#X!`!4```#$
M/@$`%0```-H^`0`2````\#X!``H````#/P$`%@````X_`0`)````)3\!`!``
M```O/P$`$@```$`_`0`$````4S\!``0```!8/P$`(@```%T_`0`,````@#\!
M`!$```"-/P$`&@```)\_`0`6````NC\!`!0```#1/P$`%P```.8_`0`<````
M_C\!`!D````;0`$`!P```#5``0`%````/4`!`!8```!#0`$``P```%I``0`,
M````7D`!``H```!K0`$`"````'9``0`(````?T`!`!<```"(0`$`#````*!`
M`0`,````K4`!`!\```"Z0`$`&@```-I``0`3````]4`!``0````)00$`"@``
M``Y!`0`$````&4$!``P````>00$`"0```"M!`0`,````-4$!``4```!"00$`
M`@```$A!`0`4````2T$!``T```!@00$`$@```&Y!`0`+````@4$!`!L```"-
M00$`'P```*E!`0`/````R4$!`!0```#900$`'@```.Y!`0`5````#4(!`#@`
M```C0@$`+````%Q"`0`2````B4(!`"D```"<0@$`,@```,9"`0`*````^4(!
M`"P````$0P$`+@```#%#`0`S````8$,!`#,```"40P$`.````,A#`0`/````
M`40!`!@````11`$`$````"I$`0`3````.T0!`"H```!/1`$`&0```'I$`0`<
M````E$0!`!\```"Q1`$`#P```-%$`0`3````X40!`!0```#U1`$`%`````I%
M`0`@````'T4!`!(```!`10$`%````%-%`0`5````:$4!`"T```!^10$`+0``
M`*Q%`0`Q````VD4!`"X````,1@$`+P```#M&`0`L````:T8!`!,```"81@$`
M)0```*Q&`0`D````TD8!`"D```#W1@$`"````"%'`0`7````*D<!``@```!"
M1P$`)````$M'`0`2````<$<!``X```"#1P$`*P```))'`0`2````OD<!`"$`
M``#11P$`&@```/-'`0`)````#D@!`$4````82`$`00```%Y(`0`/````H$@!
M``0```"P2`$`$P```+5(`0`4````R4@!``8```#>2`$`$P```.5(`0`)````
M^4@!``H````#20$`"P````Y)`0`)````&DD!``T````D20$`#````#))`0`/
M````/TD!`!<```!/20$`%````&=)`0`0````?$D!`!8```"-20$`!P```*1)
M`0`.````K$D!`"$```"[20$`!0```-U)`0`'````XTD!`!L```#K20$`"```
M``=*`0`&````$$H!`!0````72@$`$0```"Q*`0!$````/DH!`#P```"#2@$`
M#@```,!*`0`X````STH!``(````(2P$``@````M+`0`&````#DL!``X````5
M2P$`!0```"1+`0`'````*DL!``X````R2P$`!@```$%+`0`H````2$L!``P`
M``!Q2P$`#````'Y+`0`<````BTL!`",```"H2P$`*0```,Q+`0`R````]DL!
M`!<````I3`$`'P```$%,`0`S````84P!`%P```"53`$`%````/),`0`-````
M!TT!`!\````530$`$````#5-`0`4````1DT!``<```!;30$`#@```&--`0`,
M````<DT!``P```!_30$`$P```(Q-`0`*````H$T!`!T```"K30$`&0```,E-
M`0`%````XTT!`!$```#I30$`$P```/M-`0`-````#TX!`!$````=3@$`)```
M`"].`0`#````5$X!`!4```!83@$`$P```&Y.`0`2````@DX!``L```"53@$`
M-````*%.`0`+````UDX!`!0```#B3@$`/@```/=.`0`.````-D\!`!,```!%
M3P$`-````%E/`0`Q````CD\!`!(```#`3P$`$````--/`0`8````Y$\!`!D`
M``#]3P$`(P```!=0`0`B````.U`!`"<```!>4`$`5@```(90`0!-````W5`!
M`+D````K40$`"````.51`0`)````[E$!``T```#X40$`"@````92`0`'````
M$5(!``\````94@$`"P```"E2`0`$````-5(!`!P````Z4@$`#0```%=2`0`G
M````95(!`!L```"-4@$`#````*E2`0`:````ME(!``H```#14@$`!P```-Q2
M`0`-````Y%(!`"(```#R4@$`(0```!53`0`'````-U,!``T````_4P$`"@``
M`$U3`0`2````6%,!`"$```!K4P$`"P```(U3`0`<````F5,!`!@```"V4P$`
M"````,]3`0`>````V%,!`!(```#W4P$`+`````I4`0`:````-U0!``D```!2
M5`$`"@```%Q4`0`5````9U0!``4```!]5`$`%````(-4`0`$````F%0!`!``
M``"=5`$`!@```*Y4`0`'````M50!`!X```"]5`$`*````-Q4`0`*````!54!
M`!P````050$`"P```"U5`0`:````.54!`"T```!450$`"````()5`0`4````
MBU4!`"P```"@50$`)P```,U5`0`K````]54!`"H````A5@$`!````$Q6`0`%
M````458!``8```!75@$`!@```%Y6`0`Q````958!`!P```"75@$`H@```+16
M`0`;````5U<!`#0```!S5P$`-````*A7`0`@````W5<!`"D```#^5P$`)P``
M`"A8`0`@````4%@!`$$```!Q6`$`&@```+-8`0`H````SE@!`!H```#W6`$`
M=@```!)9`0!Y````B5D!`!P!```#6@$`*````"!;`0`=````25L!`"D```!G
M6P$`'0```)%;`0!0````KUL!`"X`````7`$`5P```"]<`0`V````AUP!`"P`
M``"^7`$`+````.M<`0`Q````&%T!`"X```!*70$`(@```'E=`0`(````G%T!
M``4```"E70$`&0```*M=`0`9````Q5T!`"H```#?70$`$`````I>`0`K````
M&UX!`",```!'7@$`(0```&M>`0`N````C5X!`#0```"\7@$`"````/%>`0`7
M````^EX!``H````27P$`!P```!U?`0`A````)5\!`!````!'7P$`#0```%A?
M`0`0````9E\!``4```!W7P$`#@```'U?`0`(````C%\!``L```"57P$`%```
M`*%?`0`'````ME\!`!,```"^7P$`"````-)?`0`V````VU\!`#<````28`$`
M"P```$I@`0`)````5F`!``H```!@8`$`%````&M@`0`O````@&`!`#(```"P
M8`$`#@```.-@`0`-````\F`!``\`````80$`%@```!!A`0`^````)V$!`"<`
M``!F80$`)@```(YA`0`D````M6$!``4```#:80$`!0```.!A`0`G````YF$!
M`!\````.8@$`%@```"YB`0`+````16(!`!<```!18@$`#P```&EB`0`$````
M>6(!``H```!^8@$`"0```(EB`0`+````DV(!``T```"?8@$`#````*UB`0`.
M````NF(!``4```#)8@$`'@```,]B`0`$````[F(!``T```#S8@$`,@````%C
M`0!%````-&,!``L```!Z8P$`#@```(9C`0`.````E6,!``D```"D8P$`"```
M`*YC`0`0````MV,!`!4```#(8P$`$P```-YC`0`7````\F,!``<````*9`$`
M'@```!)D`0`5````,60!`!0```!'9`$`%````%QD`0`&````<60!``L```!X
M9`$`!P```(1D`0`C````C&0!`!8```"P9`$`#P```,=D`0`.````UV0!`"H`
M``#F9`$`!@```!%E`0`,````&&4!`!@````E90$`#0```#YE`0`1````3&4!
M``L```!>90$`-@```&IE`0`-````H64!``H```"O90$`(@```+IE`0`+````
MW64!``\```#I90$`$````/EE`0`N````"F8!`#H````Y9@$`#@```'1F`0`-
M````@V8!``4```"19@$`"P```)=F`0`,````HV8!``T```"P9@$`#0```+YF
M`0`.````S&8!``T```#;9@$`(````.EF`0`G````"F<!`"L````R9P$`"```
M`%YG`0`*````9V<!``8```!R9P$`$@```'EG`0`.````C&<!`!<```";9P$`
M,@```+-G`0`>````YF<!`!8````%:`$`'````!QH`0`.````.6@!`!0```!(
M:`$`!0```%UH`0`.````8V@!`!,```!R:`$`&@```(9H`0`'````H6@!``8`
M``"I:`$`$P```+!H`0`?````Q&@!`!0```#D:`$`$0```/EH`0!+````"VD!
M`!,```!7:0$`!P```&MI`0`4````<VD!`!@```"(:0$`!P```*%I`0`%````
MJ6D!``P```"O:0$`#````+QI`0`2````R6D!``0```#<:0$`"@```.%I`0`+
M````[&D!``P```#X:0$`#@````5J`0`.````%&H!``4````C:@$`!0```"EJ
M`0`N````+VH!`"8```!>:@$`(P```(5J`0`#````J6H!``8```"M:@$`%@``
M`+1J`0`8````RVH!``X```#D:@$`-P```/-J`0`.````*VL!`!<````Z:P$`
M00```%)K`0`T````E&L!`"4```#):P$`%0```.]K`0`Q````!6P!`!,````W
M;`$`&P```$ML`0`J````9VP!`%$```"2;`$`6@```.1L`0!0````/VT!`+\`
M``"0;0$`)0```%!N`0`-````=FX!``D```"$;@$``P```(YN`0`'````DFX!
M``H```":;@$`"````*5N`0`"````KFX!`!````"Q;@$`"````,)N`0`2````
MRVX!``0```#>;@$`!P```.-N`0`R````ZVX!``H````>;P$`"@```"EO`0`5
M````-&\!``P```!*;P$`#P```%=O`0`+````9V\!``<```!S;P$`%@```'MO
M`0!2````DF\!`#H```#E;P$`(````"!P`0`/````07`!`!<```!1<`$`.0``
M`&EP`0`'````HW`!``8```"K<`$`"0```+)P`0`.````O'`!``X```#+<`$`
M!````-IP`0`&````WW`!`!8```#F<`$`#````/UP`0`-````"G$!``X````8
M<0$`%0```"=Q`0`2````/7$!``\```!0<0$`%````&!Q`0`4````=7$!`$,`
M``"*<0$`"@```,YQ`0`;````V7$!`#4```#U<0$`$0```"MR`0`0````/7(!
M``L```!.<@$`:0```%IR`0`:````Q'(!`!<```#?<@$`*````/=R`0`G````
M(',!`!L```!(<P$`&@```&1S`0`7````?W,!`!L```"7<P$`&0```+-S`0`?
M````S7,!`!<```#M<P$`'`````5T`0`7````(G0!``P````Z=`$`$P```$=T
M`0`(````6W0!`"\```!D=`$`"````)1T`0`0````G70!`!$```"N=`$`"0``
M`,!T`0`-````RG0!``8```#8=`$`'0```-]T`0`'````_70!`!,````%=0$`
M`P```!EU`0!&````'74!`$,```!D=0$`,@```*AU`0`_````VW4!`#<````;
M=@$`5P```%-V`0`%````JW8!`!\```"Q=@$`+P```-%V`0`-`````7<!`!(`
M```/=P$`*0```")W`0`(````3'<!``T```!5=P$`+0```&-W`0!P````D7<!
M`#\````">`$`.0```$)X`0!&````?'@!``0```##>`$`$````,AX`0`0````
MV7@!``P```#J>`$`%````/=X`0`=````#'D!`!P````J>0$`$0```$=Y`0`]
M````67D!`$\```"7>0$`)0```.=Y`0`@````#7H!`!P````N>@$`"P```$MZ
M`0`G````5WH!`!H```!_>@$`'P```)IZ`0`=````NGH!`"@```#8>@$`#P``
M``%[`0`E````$7L!`"`````W>P$`)````%A[`0`D````?7L!`"````"B>P$`
M)0```,-[`0`+````Z7L!``<```#U>P$`#0```/U[`0`,````"WP!``4````8
M?`$`!@```!Y\`0`Y````)7P!``4```!??`$`!P```&5\`0`)````;7P!`!,`
M``!W?`$`!@```(M\`0`$````DGP!`!````"7?`$`!````*A\`0`+````K7P!
M``P```"Y?`$`$@```,9\`0`1````V7P!``P```#K?`$`&@```/A\`0`-````
M$WT!``\````A?0$`#````#%]`0`4````/GT!`!0```!3?0$`#P```&A]`0`.
M````>'T!`!(```"'?0$`%````)I]`0`.````KWT!`!L```"^?0$`$P```-I]
M`0`<````[GT!`"@````+?@$`!@```#1^`0`'````.WX!`!,```!#?@$`!```
M`%=^`0`,````7'X!`!<```!I?@$`$@```(%^`0`J````E'X!``L```"_?@$`
M#0```,M^`0`4````V7X!`"\```#N?@$`"@```!Y_`0`,````*7\!``D````V
M?P$`!@```$!_`0`(````1W\!``D```!0?P$`!0```%I_`0`*````8'\!`!$`
M``!K?P$`"@```'U_`0`0````B'\!`!````"9?P$`"P```*I_`0`&````MG\!
M``X```"]?P$`#@```,Q_`0`+````VW\!`!````#G?P$`$0```/A_`0`+````
M"H`!``(````6@`$`"````!F``0`'````(H`!``T````J@`$`!@```#B``0`6
M````/X`!``D```!6@`$`!P```&"``0`:````:(`!`#L```"#@`$`*````+^`
M`0`T````Z(`!`!4````=@0$`"P```#.!`0`'````/X$!``@```!'@0$`!P``
M`%"!`0`%````6($!``<```!>@0$`#@```&:!`0`)````=8$!``8```!_@0$`
M"````(:!`0`+````CX$!``<```";@0$`!P```*.!`0`9````JX$!`!H```#%
M@0$`(````."!`0`<`````8(!``<````>@@$`"````":"`0`(````+X(!``4`
M```X@@$`$````#Z"`0`0````3X(!``<```!@@@$`!0```&B"`0`%````;H(!
M`!````!T@@$`%````(6"`0`+````FH(!``T```"F@@$`%P```+2"`0`+````
MS((!`!H```#8@@$`%````/."`0`O````"(,!``0````X@P$`"0```#V#`0`*
M````1X,!``<```!2@P$``@```%J#`0`.````78,!`!\```!L@P$`(P```(R#
M`0`Q````L(,!`#$```#B@P$`)P```!2$`0`B````/(0!`"````!?A`$`9```
M`("$`0`=````Y80!`!0````#A0$`'````!B%`0!=````-84!`%4```"3A0$`
M.````.F%`0`M````(H8!`#,```!0A@$`2P```(2&`0!*````T(8!`%L````;
MAP$`*````'>'`0`L````H(<!`#@```#-AP$`)0````:(`0`H````+(@!`"P`
M``!5B`$`)P```(*(`0`;````JH@!`!X```#&B`$`=0```.6(`0`^````6XD!
M`$(```":B0$`/0```-V)`0`]````&XH!`"D```!9B@$`*0```(.*`0`Q````
MK8H!`"\```#?B@$`J0$```^+`0`C````N8P!`&(```#=C`$`3P```$"-`0`7
M````D(T!`#8```"HC0$`/@```-^-`0`P````'HX!`"````!/C@$`/P```'".
M`0`T````L(X!`!T```#EC@$`'@````./`0`J````(H\!`(4```!-CP$`,```
M`-./`0`E````!)`!`&`````JD`$`6P```(N0`0!)````YY`!`#0````QD0$`
M/````&:1`0`X````HY$!`!T```#<D0$`&````/J1`0"G````$Y(!`"L```"[
MD@$`(0```.>2`0`?````"9,!`#P````IDP$`)````&:3`0`H````BY,!`"L`
M``"TDP$`(@```."3`0`A`````Y0!`",````EE`$`)0```$F4`0`E````;Y0!
M`"D```"5E`$`)P```+^4`0`7````YY0!`"D```#_E`$`(````"F5`0`R````
M2I4!`!P```!]E0$`+@```)J5`0`=````R94!`!$```#GE0$`,P```/F5`0`E
M````+98!`#@```!3E@$`)P```(R6`0`\````M)8!`"8```#QE@$`'P```!B7
M`0`P````.)<!`&D```!IEP$`/@```-.7`0`^````$I@!`$<```!1F`$`/0``
M`)F8`0!E````UY@!`$T````]F0$`4P```(N9`0!7````WYD!`%4````WF@$`
M1@```(V:`0`J````U)H!`"\```#_F@$`50```"^;`0`@````A9L!`"X```"F
MFP$`*P```-6;`0`P`````9P!`"H````RG`$`/@```%V<`0!4````G)P!`%(`
M``#QG`$`6@```$2=`0`R````GYT!`"L```#2G0$`2````/Z=`0!*````1YX!
M`"H```"2G@$`)@```+V>`0`L````Y)X!`$X````1GP$`,@```&"?`0`P````
MDY\!`!T```#$GP$`(P```.*?`0`O````!J`!`"P````VH`$`+0```&.@`0`7
M````D:`!`"4```"IH`$`,@```,^@`0`I`````J$!`#X````LH0$`(@```&NA
M`0`+````CJ$!`#L```":H0$`)P```-:A`0!.````_J$!`$<```!-H@$`8@``
M`)6B`0!)````^*(!`%4```!"HP$`0````)BC`0`O````V:,!`#(````)I`$`
M*P```#RD`0`I````:*0!``\```"2I`$`10```**D`0`A````Z*0!`#`````*
MI0$`+0```#NE`0`E````::4!`!P```"/I0$`,0```*RE`0`Q````WJ4!``X`
M```0I@$`"P```!^F`0`'````*Z8!``<````SI@$`!````#NF`0`-````0*8!
M``L```!.I@$`#@```%JF`0`%````::8!`!````!OI@$``@```("F`0`*````
M@Z8!`%8```".I@$`60```.6F`0`%````/Z<!``@```!%IP$``P```$ZG`0`0
M````4J<!`!<```!CIP$`#````'NG`0`,````B*<!``T```"5IP$`#0```*.G
M`0`"````L:<!`!0```"TIP$`$@```,FG`0`,````W*<!``,```#IIP$`!```
M`.VG`0`?````\J<!`#4````2J`$`+@```$BH`0`O````=Z@!`!<```"GJ`$`
M(````+^H`0`;````X*@!`!@```#\J`$`)````!6I`0`?````.JD!`!H```!:
MJ0$`(````'6I`0`:````EJD!`#(```"QJ0$`&@```.2I`0`O````_ZD!`"L`
M```OJ@$`'P```%NJ`0`C````>ZH!`!\```"?J@$`&@```+^J`0`E````VJH!
M`"8`````JP$`)0```">K`0`D````3:L!`!@```!RJP$`'0```(NK`0`D````
MJ:L!`!@```#.JP$`(@```.>K`0`E````"JP!`#P````PK`$`'P```&VL`0`C
M````C:P!`!\```"QK`$`(````-&L`0`:````\JP!`!@````-K0$`&````":M
M`0`F````/ZT!`!X```!FK0$`*0```(6M`0`>````KZT!``H```#.K0$`$P``
M`-FM`0`(````[:T!``D```#VK0$`%@````"N`0`,````%ZX!`!<````DK@$`
M+P```#RN`0`D````;*X!``<```"1K@$`'P```)FN`0`/````N:X!``4```#)
MK@$`!P```,^N`0`,````UZX!``\```#DK@$`$0```/2N`0`=````!J\!`!H`
M```DKP$`$0```#^O`0`'````4:\!`,<```!9KP$`!@```"&P`0`+````*+`!
M`!H````TL`$`%0```$^P`0`&````9;`!``D```!LL`$`'0```':P`0`8````
ME+`!``L```"ML`$`#0```+FP`0`7````Q[`!``8```#?L`$`,P```.:P`0`3
M````&K$!`!,````NL0$`#P```$*Q`0`1````4K$!`!X```!DL0$`!P```(.Q
M`0`9````B[$!`#(```"EL0$`!````-BQ`0`A````W;$!`!,```#_L0$`#```
M`!.R`0`1````(+(!`#(````RL@$`%@```&6R`0`(````?+(!``D```"%L@$`
M"@```(^R`0`4````FK(!`!T```"OL@$`"````,VR`0`?````UK(!``@```#V
ML@$`&@```/^R`0`G````&K,!``8```!"LP$`%0```$FS`0`(````7[,!``<`
M``!HLP$`#P```'"S`0`.````@+,!`!````"/LP$`"0```*"S`0`)````JK,!
M`!,```"TLP$`!````,BS`0`'````S;,!`!(```#5LP$`)@```.BS`0`-````
M#[0!`!D````=M`$`&````#>T`0`+````4+0!``X```!<M`$`&0```&NT`0`*
M````A;0!`"0```"0M`$`(0```+6T`0`*````U[0!`!,```#BM`$`)P```/:T
M`0`)````'K4!``\````HM0$`*````#BU`0`/````8;4!`"````!QM0$`#0``
M`)*U`0`4````H+4!``T```"UM0$`%````,.U`0`4````V+4!``H```#MM0$`
M#````/BU`0`J````!;8!``<````PM@$``@```#BV`0`0````.[8!`!@```!,
MM@$`"P```&6V`0`#````<;8!``@```!UM@$`!@```'ZV`0`'````A;8!``T`
M``"-M@$`"P```)NV`0`4````I[8!`!4```"\M@$`+P```-*V`0`@`````K<!
M`!P````CMP$`5P```$"W`0!:````F+<!`#\```#SMP$`-@```#.X`0!^````
M:K@!``P```#IN`$`,0```/:X`0`)````*+D!``4````RN0$`$@```#BY`0`_
M````2[D!`!(```"+N0$`"@```)ZY`0`&````J;D!``0```"PN0$`!````+6Y
M`0`*````NKD!`!,```#%N0$`!0```-FY`0`&````W[D!``8```#FN0$`!```
M`.VY`0`,````\KD!``H```#_N0$``@````JZ`0`$````#;H!``8````2N@$`
M`P```!FZ`0`,````';H!`#L````JN@$`3P```&:Z`0`U````MKH!`"<```#L
MN@$`(0```!2[`0`D````-KL!`$4```!;NP$`)@```*&[`0`S````R+L!`!H`
M``#\NP$`'0```!>\`0`U````-;P!`"(```!KO`$`>````(Z\`0!6````![T!
M`"@```!>O0$`4P```(>]`0`Z````V[T!`$(````6O@$`&0```%F^`0`7````
M<[X!`(L```"+O@$`&0```!>_`0`J````,;\!`"L```!<OP$`<@```(B_`0`@
M````^[\!`#4````<P`$`(0```%+``0!%````=,`!`"8```"ZP`$`,````.'`
M`0!+````$L$!`$X```!>P0$`)P```*W!`0`I````U<$!`"$```#_P0$`*```
M`"'"`0`K````2L(!`!T```!VP@$`*0```)3"`0`F````OL(!`"T```#EP@$`
M)0```!/#`0`H````.<,!`"@```!BPP$`(@```(O#`0`I````KL,!`"(```#8
MPP$`/0```/O#`0!!````.<0!`"@```![Q`$`+````*3$`0`P````T<0!`!(`
M```"Q0$`$P```!7%`0`0````*<4!`'D````ZQ0$`"0```+3%`0`<````OL4!
M`!````#;Q0$`#P```.S%`0`K````_,4!`"<````HQ@$`#@```%#&`0!+````
M7\8!`',```"KQ@$`?````!_'`0!`````G,<!`"L```#=QP$`%P````G(`0`J
M````(<@!`#0```!,R`$`%@```('(`0`/````F,@!`!<```"HR`$`*````,#(
M`0`?````Z<@!`$`````)R0$`'P```$K)`0`<````:LD!`%$```"'R0$`&@``
M`-G)`0`4````],D!``\````)R@$`$@```!G*`0`,````+,H!`!`````YR@$`
M$P```$K*`0`=````7LH!``\```!\R@$`#P```(S*`0`$````G,H!``H```"A
MR@$`!````*S*`0`#````L<H!``D```"UR@$`!P```+_*`0`+````Q\H!``@`
M``#3R@$`!P```-S*`0`%````Y,H!``D```#JR@$`%````/3*`0`&````"<L!
M``<````0RP$`"````!C+`0`/````(<L!``\````QRP$`"````$'+`0`,````
M2LL!``8```!7RP$`"0```%[+`0`+````:,L!``\```!TRP$`!@```(3+`0`'
M````B\L!``T```"3RP$`!@```*'+`0`4````J,L!``<```"]RP$``P```,7+
M`0`)````R<L!``8```#3RP$`#````-K+`0`*````Y\L!``P```#RRP$`"@``
M`/_+`0`/````"LP!``4````:S`$`"````"#,`0`$````*<P!``H````NS`$`
M!````#G,`0`$````/LP!`!D```!#S`$`!P```%W,`0`"````9<P!``D```!H
MS`$`!@```'+,`0`#````><P!``8```!]S`$`#````(3,`0`$````D<P!``0`
M``"6S`$`#P```)O,`0`3````J\P!``<```"_S`$``@```,?,`0`'````RLP!
M``8```#2S`$`!@```-G,`0`0````X,P!``X```#QS`$`#P````#-`0`&````
M$,T!``P````7S0$`"0```"3-`0`1````+LT!`"(```!`S0$`!P```&/-`0`'
M````:\T!``L```!SS0$`!0```'_-`0`"````A<T!``L```"(S0$`#@```)3-
M`0`.````H\T!`'4!``"RS0$`$P```"C/`0`*````/,\!``T```!'SP$`"@``
M`%7/`0`3````8,\!`!H```!TSP$`$````(_/`0`-````H,\!``L```"NSP$`
M#0```+K/`0`-````R,\!``8```#6SP$`!@```-W/`0`X````Y,\!`#8````=
MT`$`)````%30`0`!````>=`!`!D```![T`$`.@```)70`0`+````T-`!`#H`
M``#<T`$`(@```!?1`0!J````.M$!`$D```"ET0$`:@```._1`0!"````6M(!
M`!T```"=T@$`'````+O2`0`-````V-(!`!0```#FT@$`$P```/O2`0`K````
M#],!`!\````[TP$`$````%O3`0`6````;-,!`"````"#TP$`:P```*33`0`-
M````$-0!`$L````>U`$`1P```&K4`0`?````LM0!`"$```#2U`$`%0```/34
M`0!(````"M4!`"P```!3U0$`3````(#5`0`W````S=4!`,,````%U@$`&P``
M`,G6`0`-````Y=8!`!(```#SU@$`20````;7`0`U````4-<!`!(```"&UP$`
M+P```)G7`0`Z````R=<!`%8````$V`$`&@```%O8`0`-````=M@!``P```"$
MV`$`&````)'8`0`&````JM@!`!,```"QV`$`1P```,78`0!C````#=D!``8`
M``!QV0$`$0```'C9`0#.````BMD!`+(```!9V@$`30````S;`0`X````6ML!
M``D```"3VP$`#P```)W;`0`?````K=L!``X```#-VP$`)````-S;`0!S````
M`=P!`$L```!UW`$`;````,'<`0!$````+MT!`!$```!SW0$`$P```(7=`0`8
M````F=T!`!@```"RW0$`#P```,O=`0`1````V]T!`!$```#MW0$`4@```/_=
M`0`I````4MX!`%<```!\W@$`8@```-3>`0!=````-]\!`&\```"5WP$`E```
M``7@`0".````FN`!`)(````IX0$`D0```+SA`0!;````3N(!`"````"JX@$`
M&0```,OB`0`9````Y>(!`!<```#_X@$`#0```!?C`0`"````)>,!`"0````H
MXP$`#P```$WC`0`3````7>,!``\```!QXP$`'0```('C`0`5````G^,!`!8`
M``"UXP$`.````,SC`0`\````!>0!`!<```!"Y`$`%@```%KD`0`3````<>0!
M`!,```"%Y`$`$````)GD`0`0````JN0!`!,```"[Y`$`)0```,_D`0`H````
M]>0!`!L````>Y0$`)0```#KE`0`E````8.4!`#0```"&Y0$`+0```+OE`0`<
M````Z>4!`"<````&Y@$`&@```"[F`0`A````2>8!`%0```!KY@$`+P```,#F
M`0`Q````\.8!`#4````BYP$`'@```%CG`0`L````=^<!`#0```"DYP$`J@``
M`-GG`0!'````A.@!`"8```#,Z`$`(@```//H`0!0````%ND!`"L```!GZ0$`
M60```)/I`0`(````[>D!`!@```#VZ0$`'P````_J`0"D````+^H!`)P```#4
MZ@$`3````''K`0`.````ONL!``X```#-ZP$`"@```-SK`0`1````Y^L!``D`
M``#YZP$`!@````/L`0`X````"NP!`!8```!#[`$`%@```%KL`0`8````<>P!
M`'0```"*[`$`GP```/_L`0!=````G^T!`&\```#][0$`)0```&WN`0!2````
MD^X!`!P```#F[@$`20````/O`0`=````3>\!`!P```!K[P$`(0```(CO`0`G
M````JN\!`#$```#2[P$`(`````3P`0`6````)?`!`#4````\\`$`"@```'+P
M`0`K````??`!`%X```"I\`$`-0````CQ`0!>````/O$!``P```"=\0$`"```
M`*KQ`0`8````L_$!`"D```#,\0$`(````/;Q`0`O````%_(!`!X```!'\@$`
M&0```&;R`0`A````@/(!`$L```"B\@$`C0```.[R`0`R````?/,!``H```"O
M\P$`&0```+KS`0`*````U/,!`!4```#?\P$`)````/7S`0`1````&O0!`&``
M```L]`$`BP```(WT`0!0````&?4!`'0```!J]0$`=````-_U`0!P````5/8!
M`%<```#%]@$`<@```!WW`0!E````D/<!`'0```#V]P$`=P```&OX`0!X````
MX_@!`!0```!<^0$`$P```''Y`0`&````A?D!``H```",^0$`"````)?Y`0!<
M````H/D!`!D```#]^0$`"@```!?Z`0`G````(OH!`&8```!*^@$`*````+'Z
M`0!Z````VOH!`%@```!5^P$`"@```*[[`0`R````N?L!``X```#L^P$`1```
M`/O[`0!$````0/P!`$H```"%_`$`3@```-#\`0`:````'_T!``@````Z_0$`
M$0```$/]`0`*````5?T!`#H```!@_0$`70```)O]`0`V````^?T!`#8````P
M_@$`-P```&?^`0`V````G_X!`#@```#6_@$`.`````__`0!W````2/\!`#$`
M``#`_P$`/````/+_`0`X````+P`"`#X```!H``(`*P```*<``@`O````TP`"
M`$@````#`0(`0@```$P!`@"D````CP$"`"\````T`@(`)0```&0"`@`3````
MB@("`!0```">`@(`%````+,"`@`_````R`("`#,````(`P(`$0```#P#`@`8
M````3@,"`",```!G`P(`)P```(L#`@`4````LP,"``T```#(`P(`%0```-8#
M`@!0````[`,"`!$````]!`(`10```$\$`@`7````E00"``\```"M!`(`D@``
M`+T$`@`(````4`4"``@```!9!0(`#0```&(%`@`&````<`4"`!(```!W!0(`
M#0```(H%`@`)````F`4"`#<```"B!0(`"@```-H%`@`:````Y04"``,`````
M!@(``P````0&`@`7````"`8"`!H````@!@(`&0```#L&`@`*````508"``@`
M``!@!@(`5P```&D&`@!8````P08"`'X````:!P(`E@```)D'`@`Q````,`@"
M`$\```!B"`(`-@```+((`@`&````Z0@"`!$```#P"`(`)P````()`@!J````
M*@D"`#@```"5"0(`.````,X)`@!3````!PH"`#(```!;"@(`0P```(X*`@#!
M````T@H"`%$```"4"P(`"@```.8+`@`(````\0L"`"$```#Z"P(`#````!P,
M`@`,````*0P"`!<````V#`(`$P```$X,`@`7````8@P"`"````!Z#`(`#```
M`)L,`@`4````J`P"``@```"]#`(`'0```,8,`@`8````Y`P"`!L```#]#`(`
MA@```!D-`@`(````H`T"``H```"I#0(`$0```+0-`@`3````Q@T"`"T```#:
M#0(`D`````@.`@!,````F0X"`)````#F#@(`D````'</`@"D````"!`"``H`
M``"M$`(`)P```+@0`@`8````X!`"`#8```#Y$`(`(````#`1`@"<````41$"
M`&L```#N$0(``P```%H2`@`;````7A("`!H```!Z$@(`%````)42`@`Y````
MJA("`$T```#D$@(`'P```#(3`@`E````4A,"`!D```!X$P(`,````)(3`@!*
M````PQ,"`'$````.%`(`7````(`4`@`F````W10"``8````$%0(`(P````L5
M`@`?````+Q4"`!H```!/%0(`)0```&H5`@"5````D!4"`#D````F%@(`3@``
M`&`6`@!E````KQ8"`%<````5%P(`8P```&T7`@!K````T1<"`$(````]&`(`
MM0```(`8`@`G````-AD"`&4```!>&0(`7````,09`@`=````(1H"`&(````_
M&@(`7@```*(:`@`(`````1L"`!,````*&P(`&@```!X;`@`:````.1L"``H`
M``!4&P(`"````%\;`@`(````:!L"``\```!Q&P(`(0```($;`@`1````HQL"
M`"$```"U&P(`&P```-<;`@`&````\QL"`!````#Z&P(`'@````L<`@`3````
M*AP"``T````^'`(`&0```$P<`@`(````9AP"``H```!O'`(`%0```'H<`@`*
M````D!P"`!$```";'`(`"````*T<`@`/````MAP"`",```#&'`(`40```.H<
M`@"Y````/!T"`!,```#V'0(`!@````H>`@`*````$1X"`"$````<'@(`$P``
M`#X>`@`W````4AX"`$4```"*'@(`&````-`>`@`@````Z1X"`"`````*'P(`
M.@```"L?`@!-````9A\"`#8```"T'P(`,@```.L?`@`,````'B`"`%\````K
M(`(`"@```(L@`@`L````EB`"`"X```##(`(`40```/(@`@!,````1"$"``@`
M``"1(0(`#````)HA`@`V````IR$"`!H```#>(0(`"````/DA`@`>`````B("
M`#T````A(@(`.0```%\B`@!`````F2("`#P```#:(@(`.````!<C`@`T````
M4","`#,```"%(P(`,@```+DC`@`V````[","`#\````C)`(`/0```&,D`@`^
M````H20"`$$```#@)`(`,P```"(E`@!"````5B4"`%P```"9)0(`7@```/8E
M`@!"````528"`%\```"8)@(`6P```/@F`@!'````5"<"`$<```"<)P(`5@``
M`.0G`@!7````.R@"`"<```"3*`(`3````+LH`@`D````""D"`"@!```M*0(`
M.0```%8J`@!1````D"H"`%$```#B*@(`40```#0K`@!5````ABL"`#H```#<
M*P(`/````!<L`@!$````5"P"`$D```"9+`(`5````.,L`@`B`0``."T"`#H`
M``!;+@(`/@```)8N`@!,````U2X"`(,````B+P(`&````*8O`@`(````OR\"
M``\```#(+P(`"@```-@O`@`3````XR\"`!<```#W+P(`'@````\P`@`:````
M+C`"`#<```!),`(`-0```($P`@`:````MS`"`$D```#2,`(`+````!PQ`@"Y
M````23$"`"D````#,@(`,P```"TR`@`@````83("`"0```"",@(`(@```*<R
M`@`1````RC("`!,```#<,@(`&0```/`R`@`?````"C,"`!4````J,P(`#P``
M`$`S`@!A````4#,"`#L```"R,P(`40```.XS`@`*````0#0"`!<```!+-`(`
M$0```&,T`@`7````=30"`!L```"--`(``@```*DT`@`,````K#0"``H```"Y
M-`(`'@```,0T`@`*````XS0"`!X```#N-`(`%P````TU`@`&````)34"``\`
M```L-0(`#````#PU`@`5````234"``H```!?-0(`"P```&HU`@`<````=C4"
M`!0```"3-0(`&````*@U`@`:````P34"`#$```#<-0(`)P````XV`@`,````
M-C8"``X```!#-@(`!@```%(V`@`=````638"`",```!W-@(`%0```)LV`@`/
M````L38"``\```#!-@(`+````-$V`@`<````_C8"`!H````;-P(`)P```#8W
M`@`/````7C<"``\```!N-P(`*P```'XW`@!+````JC<"`"(```#V-P(`7P``
M`!DX`@!M````>3@"`"(```#G.`(`1P````HY`@`-````4CD"`"4```!@.0(`
M'````(8Y`@`8````HSD"`!8```"\.0(`#0```-,Y`@`>````X3D"`!T`````
M.@(`)0```!XZ`@`3````1#H"``\```!8.@(`4````&@Z`@`*````N3H"``\`
M``#$.@(`"@```-0Z`@`,````WSH"``\```#L.@(`10```/PZ`@`*````0CL"
M`!$```!-.P(`,````%\[`@`3````D#L"`",```"D.P(`'@```,@[`@`>````
MYSL"``@````&/`(`"@````\\`@`Z````&CP"`!X```!5/`(`6P```'0\`@`H
M````T#P"`!L```#Y/`(`$P```!4]`@`E````*3T"`&````!//0(`;````+`]
M`@!H````'3X"``H```"&/@(`$0```)$^`@`1````HSX"`#T```"U/@(`#P``
M`/,^`@!``````S\"`#L```!$/P(`/P```(`_`@"$````P#\"`"X```!%0`(`
M$0```'1``@`.````AD`"`!$```"50`(`)````*=``@!"````S$`"`!T````/
M00(`+0```"U!`@!2````6T$"`"$```"N00(`#P```-!!`@`:````X$$"`!\`
M``#[00(`'````!M"`@`,````.$("`!T```!%0@(`*````&-"`@`*````C$("
M``,```"70@(`-````)M"`@`,````T$("`!X```#=0@(`%0```/Q"`@`;````
M$D,"`!4````N0P(`%0```$1#`@`9````6D,"`"4```!T0P(`)0```)I#`@`P
M````P$,"`"````#Q0P(`(0```!)$`@`J````-$0"`"@```!?1`(`)P```(A$
M`@`K````L$0"`&<```#<1`(`)P```$1%`@`.````;$4"``L```![10(``@``
M`(=%`@`=````BD4"`"@```"H10(`4@```-%%`@`O````)$8"``X```!41@(`
M,P```&-&`@`@````ET8"`#<```"X1@(`)P```/!&`@`G````&$<"`",```!`
M1P(`'0```&1'`@`<````@D<"`"<```"?1P(`*0```,='`@`L````\4<"`%4`
M```>2`(`/0```'1(`@!+````LD@"`"4```#^2`(`"@```"1)`@`L````+TD"
M`!<```!<20(`'P```'1)`@`3````E$D"`"(```"H20(`(@```,M)`@"[````
M[DD"`#````"J2@(`20```-M*`@!(````)4L"`%P```!N2P(`0P```,M+`@!0
M````#TP"``8```!@3`(`'@```&=,`@`@````ADP"`"8```"G3`(`,0```,Y,
M`@`V`````$T"``H````W30(`"@```$)-`@`N````34T"`!P```!\30(`%```
M`)E-`@`4````KDT"`!8```##30(`$@```-I-`@`4````[4T"``\````"3@(`
M%@```!).`@`(````*4X"``\````R3@(`%0```$).`@`E````6$X"`!<```!^
M3@(`&0```)9.`@`B````L$X"`',```#33@(`<P```$=/`@`/````NT\"`!D`
M``#+3P(`%P```.5/`@`.````_4\"`!H````,4`(`$P```"=0`@`R````.U`"
M`#@```!N4`(`.````*=0`@`V````X%`"`#<````740(`/P```$]1`@`M````
MCU$"``@```"]40(`$0```,91`@`&````V%$"``H```#?40(`$P```.I1`@!-
M````_E$"`#T```!,4@(`*0```(I2`@`G````M%("`!0```#<4@(`/@```/%2
M`@`3````,%,"``\```!$4P(`#@```%13`@`/````8U,"`"@```!S4P(`*```
M`)Q3`@`5````Q5,"`!,```#;4P(`&0```.]3`@`7````"50"`#H````A5`(`
M'@```%Q4`@`9````>U0"`%T```"55`(`30```/-4`@`.````054"`"<```!0
M50(`*@```'A5`@`0````HU4"``\```"T50(`)````,15`@`1````Z54"``T`
M``#[50(`$0````E6`@`,````&U8"``H````H5@(`#P```#-6`@`@````0U8"
M`"(```!D5@(`%0```(=6`@`5````G58"`#L```"S5@(`,````.]6`@`-````
M(%<"``8````N5P(`5P```#57`@`0````C5<"`#T```">5P(`6@```-Q7`@`*
M````-U@"``@```!"6`(`#P```$M8`@`,````6U@"``\```!H6`(`#@```'A8
M`@`*````AU@"``L```"26`(`'````)Y8`@`D````NU@"``X```#@6`(`"```
M`.]8`@`0````^%@"`"(````)60(`'````"Q9`@`B````25D"`"L```!L60(`
M!````)A9`@`$````G5D"``T```"B60(`!0```+!9`@`/````MED"``\```#&
M60(`#P```-99`@`+````YED"``L```#R60(`,0```/Y9`@`L````,%H"``L`
M``!=6@(`'@```&E:`@`>````B%H"`!8```"G6@(`2P```+Y:`@`6````"EL"
M`!P````A6P(`-````#Y;`@`5````<UL"`!L```")6P(`%P```*5;`@`2````
MO5L"`!<```#06P(`+````.A;`@`4````%5P"`!D````J7`(`&P```$1<`@`*
M````8%P"``0```!K7`(`'P```'!<`@!)````D%P"`$D```#:7`(`20```"1=
M`@`L````;ET"`!4```";70(`#P```+%=`@`*````P5T"``X```#,70(`%0``
M`-M=`@`*````\5T"``P```#\70(`,P````E>`@`1````/5X"``\```!/7@(`
M.````%]>`@!"````F%X"`!,```#;7@(`.````.]>`@`K````*%\"`"<```!4
M7P(`"````'Q?`@`5````A5\"`!````";7P(`"````*Q?`@`(````M5\"`!$`
M``"^7P(`$P```-!?`@`<````Y%\"``@````!8`(`6@````I@`@!'````96`"
M`$X```"M8`(`-@```/Q@`@!:````,V$"`#(```".80(`7````,%A`@!"````
M'F("`$L```!A8@(`+P```*UB`@`3````W6("`"````#Q8@(`"0```!)C`@!0
M````'&,"`"D```!M8P(`/@```)=C`@`N````UF,"`#P````%9`(`2@```$)D
M`@`*````C60"``P```"89`(`!````*5D`@`_````JF0"`#P```#J9`(`.```
M`"=E`@!-````8&4"``\```"N90(`+````+YE`@`K````ZV4"``\````79@(`
M0P```"=F`@`%````:V8"``L```!Q9@(`*@```'UF`@!+````J&8"`"@```#T
M9@(`%0```!UG`@`:````,V<"`!H```!.9P(`$@```&EG`@!X````?&<"`&X`
M``#U9P(`F````&1H`@#@````_6@"`!<```#>:0(`'@```/9I`@`*````%6H"
M`!T````@:@(`#@```#YJ`@`/````36H"`!H```!=:@(`&P```'AJ`@`5````
ME&H"``P```"J:@(`$0```+=J`@`:````R6H"`"$```#D:@(`(`````9K`@`>
M````)VL"`"L```!&:P(`,@```')K`@`S````I6L"`#(```#9:P(`)0````QL
M`@`I````,FP"`"T```!<;`(`(0```(IL`@`H````K&P"`#X```#5;`(`'0``
M`!1M`@`&````,FT"`!<````Y;0(`+````%%M`@`E````?FT"`"L```"D;0(`
M%@```-!M`@`H````YVT"``4````0;@(`0P```!9N`@`W````6FX"`#4```"2
M;@(`-0```,AN`@#=````_FX"`!L```#<;P(`%0```/AO`@`.````#G`"``X`
M```=<`(`,````"QP`@`Q````77`"`#<```"/<`(`-P```,=P`@`)````_W`"
M`!L````)<0(`*@```"5Q`@`1````4'$"`$8```!B<0(`0````*EQ`@`W````
MZG$"``\````B<@(`%@```#)R`@`H````27("`$0```!R<@(`1````+=R`@!`
M````_'("`$`````]<P(`00```'YS`@!!````P',"`"`````"=`(`9@```"-T
M`@`6````BG0"`!8```"A=`(`%@```+AT`@`6````SW0"`!$```#F=`(`'@``
M`/AT`@`>````%W4"`!4````V=0(`%````$QU`@!1````874"`!P```"S=0(`
M'````-!U`@!*````[74"`!D````X=@(`#P```%)V`@`:````8G8"`$\```!]
M=@(`&0```,UV`@`P````YW8"`!(````8=P(`+````"MW`@`:````6'<"`$H`
M``!S=P(`*P```+YW`@`@````ZG<"`"8````+>`(`&0```#)X`@`@````3'@"
M`$````!M>`(`.@```*YX`@`>````Z7@"`#@````(>0(`,0```$%Y`@`;````
M<WD"`",```"/>0(`/0```+-Y`@`D````\7D"`"4````6>@(`#````#QZ`@`*
M````27H"`!\```!4>@(`"````'1Z`@`5````?7H"``T```"3>@(`#````*%Z
M`@`6````KGH"`!0```#%>@(`"@```-IZ`@`(````Y7H"`!@```#N>@(`&```
M``=[`@`:````('L"`!8````[>P(`&P```%)[`@`0````;GL"`",```!_>P(`
M/0```*-[`@`3````X7L"`!H```#U>P(`#P```!!\`@`/````('P"`!4````P
M?`(`2P```$9\`@!\````DGP"`),````/?0(`6````*-]`@`0````_'T"``\`
M```-?@(`#@```!U^`@`(````+'X"`!$````U?@(`(P```$=^`@`1````:WX"
M`",```!]?@(`#0```*%^`@`>````KWX"`!<```#.?@(`(````.9^`@`=````
M!W\"``@````E?P(`#@```"Y_`@`$````/7\"``\```!"?P(`$0```%)_`@`9
M````9'\"`!8```!^?P(`%0```)5_`@`F````JW\"`"8```#2?P(`(P```/E_
M`@`H````'8`"``T```!&@`(`&P```%2``@`*````<(`"`!D```![@`(`@```
M`)6``@`O````%H$"`!$```!&@0(`.P```%B!`@`5````E($"`$(```"J@0(`
M'@```.V!`@`D````#(("`!4````Q@@(`\P```$>"`@`5````.X,"`!<```!1
M@P(`#0```&F#`@`3````=X,"`!,```"+@P(`%P```)^#`@`>````MX,"`"$`
M``#6@P(`-````/B#`@`,````+80"`!$````ZA`(`&P```$R$`@`3````:(0"
M`!@```!\A`(`#````)6$`@`(````HH0"`!````"KA`(`"````+R$`@`(````
MQ80"`!,```#.A`(`=````.*$`@`?````5X4"``\```!WA0(`!@```(>%`@`*
M````CH4"`!<```"9A0(`'@```+&%`@`<````T(4"`"````#MA0(`&`````Z&
M`@`"````)X8"`!$````JA@(`0````#R&`@`#````?88"`!H```"!A@(`"```
M`)R&`@`=````I88"`!4```##A@(`(@```-F&`@!2````_(8"`!$```!/AP(`
M/````&&'`@`8````GH<"`(,```"WAP(`"0```#N(`@`,````18@"``@```!2
MB`(`"@```%N(`@!<````9H@"`%X```##B`(`(P```"*)`@!J````1HD"`&4`
M``"QB0(`-P```!>*`@!.````3XH"`%P```">B@(`*0```/N*`@`?````)8L"
M`!X```!%BP(`(@```&2+`@`T````AXL"`#,```"\BP(`,0```/"+`@`H````
M(HP"`"D```!+C`(`$P```'6,`@`X````B8P"`$,```#"C`(`!`````:-`@`*
M````"XT"`!H````6C0(`&P```#&-`@`D````38T"`!4```!RC0(`'P```(B-
M`@`N````J(T"``H```#7C0(`(@```.*-`@`6````!8X"`!<````<C@(`"@``
M`#2.`@`5````/XX"`!4```!5C@(`'@```&N.`@`7````BHX"`!D```"BC@(`
M&0```+R.`@"&````UHX"`!D```!=CP(`&@```'>/`@`9````DH\"`!P```"L
MCP(`$@```,F/`@`H````W(\"`"D````%D`(`)````"^0`@`;````5)`"`$(`
M``!PD`(`3P```+.0`@`T`````Y$"`!$````XD0(`20```$J1`@`3````E)$"
M`!8```"HD0(`*P```+^1`@!Q````ZY$"``8```!=D@(`$P```&22`@`&````
M>)("``L```!_D@(`+P```(N2`@`M````NY("``@```#ID@(`#````/*2`@"O
M````_Y("`"(```"ODP(`(0```-*3`@`,````]),"`!$````!E`(`$P```!.4
M`@`@````)Y0"``H```!(E`(`#@```%.4`@`0````8I0"``P```!SE`(`$P``
M`("4`@`1````E)0"`!,```"FE`(`%P```+J4`@`,````TI0"`!P```#?E`(`
M&@```/R4`@`:````%Y4"`!H````RE0(`'````$V5`@!9````:I4"`!H```#$
ME0(`&@```-^5`@`L````^I4"`!X````GE@(`)````$:6`@`5````:Y8"``T`
M``"!E@(`'````(^6`@`/````K)8"`!X```"\E@(`(0```-N6`@`(````_98"
M``8````&EP(`70````V7`@`:````:Y<"`!4```"&EP(`&@```)R7`@`6````
MMY<"`!0```#.EP(`%P```..7`@`>````^Y<"`!H````:F`(`"````#68`@`(
M````/I@"`"D```!'F`(`"````'&8`@`1````>I@"`!,```",F`(`$P```*"8
M`@`+````M)@"`"T```#`F`(`&0```.Z8`@`6````")D"`"T````?F0(`,@``
M`$V9`@`>````@)D"``H```"?F0(`&@```*J9`@`(````Q9D"`!,```#.F0(`
M$P```.*9`@`<````]ID"``0````3F@(`!@```!B:`@`F````'YH"`!<```!&
MF@(`,P```%Z:`@`5````DIH"`#D```"HF@(`+@```.*:`@`C````$9L"`"\`
M```UFP(`/````&6;`@`C````HIL"`&D```#&FP(`3P```#"<`@`E````@)P"
M`$8```"FG`(`60```.V<`@`3````1YT"`%H```!;G0(`0@```+:=`@!'````
M^9T"`$<```!!G@(`3````(F>`@`I````UIX"`",`````GP(`+@```"2?`@`J
M````4Y\"`$4```!^GP(`)@```,2?`@`W````ZY\"`#X````CH`(`)@```&*@
M`@`E````B:`"`"4```"OH`(`)0```-6@`@!"````^Z`"`!\````^H0(`+0``
M`%ZA`@`D````C*$"`$X```"QH0(`3@````"B`@!2````3Z("`%(```"BH@(`
M4````/6B`@!-````1J,"`$(```"4HP(`20```->C`@!"````(:0"`#P```!D
MI`(`$P```*&D`@`S````M:0"``\```#II`(`20```/FD`@`P````0Z4"`!D`
M``!TI0(`.0```(ZE`@`E````R*4"`$0```#NI0(`10```#.F`@`3````>:8"
M`'(```"-I@(`>0````"G`@`<````>J<"``X```"7IP(`-````*:G`@`4````
MVZ<"``@```#PIP(`&````/FG`@`+````$J@"``L````>J`(`#P```"JH`@`6
M````.J@"``T```!1J`(`#P```%^H`@`6````;Z@"`"(```"&J`(`(````*FH
M`@`>````RJ@"`!X```#IJ`(`$P````BI`@`9````'*D"`$$````VJ0(`$@``
M`'BI`@`-````BZD"`#P```"9J0(`#````-:I`@`&````XZD"`!P```#JJ0(`
M%P````>J`@!W````'ZH"`(T```"7J@(`%0```"6K`@!2````.ZL"``\```".
MJP(`!````)ZK`@`&````HZL"`!P```"JJP(`#````,>K`@`*````U*L"`!P`
M``#?JP(`#P```/RK`@!1````#*P"`!L```!>K`(`&````'JL`@`M````DZP"
M`$````#!K`(`8P````*M`@!Y````9JT"`"````#@K0(`0@````&N`@!*````
M1*X"`)X```"/K@(`*P```"ZO`@`8````6J\"`#T```!SKP(`$P```+&O`@`7
M````Q:\"`!8```#=KP(`%@```/2O`@`8````"[`"``P````DL`(`%P```#&P
M`@`2````2;`"`#$```!<L`(`(````(ZP`@`(````K[`"`!<```"XL`(`(```
M`-"P`@`<````\;`"`!H````.L0(`.````"FQ`@`#````8K$"`"(```!FL0(`
M)@```(FQ`@`F````L+$"``X```#7L0(`8P```.:Q`@`7````2K("`"8```!B
ML@(`8````(FR`@`8````ZK("`!X````#LP(`4````"*S`@!'````<[,"`"``
M``"[LP(`(@```-RS`@`V````_[,"`#8````VM`(`.P```&VT`@`]````J;0"
M`$$```#GM`(`D0```"FU`@"#````N[4"`-`````_M@(`"````!"W`@`.````
M&;<"`"0````HMP(`&0```$VW`@`5````9[<"`!<```!]MP(`"````)6W`@`$
M````GK<"`#````"CMP(`#P```-2W`@`M````Y+<"`"(````2N`(`#P```#6X
M`@`K````1;@"``X```!QN`(`%P```("X`@`5````F+@"`#D```"NN`(`.0``
M`.BX`@`,````(KD"`!,````ON0(`$0```$.Y`@`@````5;D"`#@```!VN0(`
M$@```*^Y`@`X````PKD"`"L```#[N0(`#0```">Z`@`X````-;H"`"(```!N
MN@(`0@```)&Z`@`>````U+H"``\```#SN@(`$`````.[`@`S````%+L"``X`
M``!(NP(`(P```%>[`@`(````>[L"`"(```"$NP(`"````*>[`@`(````L+L"
M`"8```"YNP(`30```."[`@`(````+KP"`!P````WO`(`#````%2\`@`;````
M8;P"`$D```!]O`(`"````,>\`@`7````T+P"`$(```#HO`(`00```"N]`@`Z
M````;;T"`$0```"HO0(`&0```.V]`@`(````![X"``H````0O@(`#@```!N^
M`@!3````*KX"`"D```!^O@(`T@```*B^`@`U````>[\"`%T```"QOP(`:P``
M``_``@`X````>\`"`$$```"TP`(`0P```/;``@`U````.L$"`'0```!PP0(`
M-0```.7!`@!#````&\("`#(```!?P@(`J0```)+"`@"L````/,,"`+X!``#I
MPP(`0P```*C%`@`X````[,4"`$X````EQ@(`/P```'3&`@"'````M,8"`$T`
M```\QP(`A@```(K'`@!B````$<@"`$T```!TR`(`30```,+(`@!,````$,D"
M`$L```!=R0(`.P```*G)`@`.````Y<D"``@```#TR0(`*P```/W)`@`I````
M*<H"`!L```!3R@(`&@```&_*`@!+````BLH"`"P```#6R@(`0P````/+`@`Y
M````1\L"`#\```"!RP(`"````,'+`@`?````RLL"``H```#JRP(`$P```/7+
M`@`]````"<P"`!,```!'S`(`$P```%O,`@`<````;\P"``8```",S`(`#0``
M`)/,`@`,````H<P"`!$```"NS`(`(0```,#,`@`(````XLP"`!,```#KS`(`
M$0```/_,`@!K````$<T"`&T```!]S0(`$0```.O-`@`-````_<T"`!,````+
MS@(`)````!_.`@!6````1,X"`$T```";S@(`(P```.G.`@`C````#<\"`!T`
M```QSP(`1````$_/`@![````E,\"`%X````0T`(`/@```&_0`@!`````KM`"
M``\```#OT`(`"@```/_0`@`S````"M$"`$(````^T0(`,0```('1`@`1````
ML]$"`"0```#%T0(`%P```.K1`@`*`````M("`!L````-T@(`&P```"G2`@`8
M````1=("`!0```!>T@(`%@```'/2`@`5````BM("``@```"@T@(`*@```*G2
M`@`,````U-("`!P```#AT@(`2@```/[2`@!V````2=,"`!@```#`TP(`&```
M`-G3`@`8````\M,"`!,````+U`(`$P```!_4`@`>````,]0"`"4```!2U`(`
M*0```'C4`@`M````HM0"``X```#0U`(`.@```-_4`@`E````&M4"`",```!`
MU0(`(P```&35`@`9````B-4"`"````"BU0(`#@```,/5`@`V````TM4"`#,`
M```)U@(`(````#W6`@`B````7M8"``,```"!U@(`!@```(76`@`/````C-8"
M`!\```"<U@(`#P```+S6`@`8````S-8"``T```#EU@(`40```//6`@`3````
M1=<"``8```!9UP(`(````&#7`@`1````@=<"`!4```"3UP(`(````*G7`@!V
M````RM<"`'````!!V`(`&````++8`@`=````R]@"``D```#IV`(`&````//8
M`@`4````#-D"`!4````AV0(`&````#?9`@`9````4-D"`!0```!JV0(`,@``
M`'_9`@!!````LMD"`$0```#TV0(`#0```#G:`@`/````1]H"``D```!7V@(`
M)0```&':`@`F````A]H"`"D```"NV@(`5P```-C:`@!"````,-L"`#0```!S
MVP(`+@```*C;`@`@````U]L"`!H```#XVP(`$````!/<`@`>````)-P"`#,`
M``!#W`(`-P```'?<`@`*````K]P"`!,```"ZW`(`)````,[<`@`G````\]P"
M`"4````;W0(`(P```$'=`@"7````9=T"`"X```#]W0(`$````"S>`@`E````
M/=X"`"L```!CW@(`#````(_>`@`(````G-X"`!,```"EW@(`%0```+G>`@`8
M````S]X"``8```#HW@(`&````._>`@`2````"-\"`!8````;WP(`%0```#+?
M`@`5````2-\"``L```!>WP(`"@```&K?`@!2````==\"`$L```#(WP(`20``
M`!3@`@`(````7N`"``8```!GX`(`(0```&[@`@`K````D.`"`!$```"\X`(`
M5@```,[@`@`:````)>$"`"D```!`X0(`9P```&KA`@!*````TN$"`$`````=
MX@(`)0```%[B`@!0````A.("`",```#5X@(`.@```/GB`@!$````-.,"`'P`
M``!YXP(`>@```/;C`@!V````<>0"`-<```#HY`(`.0```,#E`@`.````^N4"
M``X````)Y@(``P```!CF`@`0````'.8"``X````MY@(`"@```#SF`@`(````
M1^8"`!T```!0Y@(`$@```&[F`@`@````@>8"``8```"BY@(`$@```*GF`@!J
M````O.8"`!8````GYP(`$0```#[G`@`A````4.<"`!@```!RYP(`'````(OG
M`@`6````J.<"`!(```"_YP(`7@```-+G`@"!````,>@"`&(```"SZ`(`3```
M`!;I`@`W````8^D"`!\```";Z0(`:@```+OI`@`&````)NH"``H````MZ@(`
M#0```#CJ`@`0````1NH"`!4```!7Z@(`$P```&WJ`@`,````@>H"`",```".
MZ@(`(````++J`@`<````T^H"`!H```#PZ@(`-P````OK`@`C````0^L"`!X`
M``!GZP(`*````(;K`@`Y````K^L"`&P```#IZP(`$P```%;L`@`T````:NP"
M`&D```"?[`(`&@````GM`@`6````).T"`!H````[[0(`\````%;M`@`E````
M1^X"`"$```!M[@(`,@```(_N`@!'````PNX"`$`````*[P(`)0```$OO`@`?
M````<>\"`"4```"1[P(`(0```+?O`@`M````V>\"`"P````'\`(`.0```#3P
M`@`D````;O`"`!4```"3\`(`%0```*GP`@`.````O_`"`'<```#.\`(`"@``
M`$;Q`@`O````4?$"`#````"!\0(`#@```++Q`@`7````P?$"``P```#9\0(`
M)P```.;Q`@`-````#O("`"0````<\@(`"@```$'R`@"2````3/("`%D```#?
M\@(`50```#GS`@"1````C_,"`%(````A]`(`@````'3T`@`:````]?0"`%,`
M```0]0(`/@```&3U`@`<````H_4"`"<```#`]0(`30```.CU`@`(````-O8"
M`!4````_]@(`9````%7V`@#+````NO8"`&,```"&]P(`:````.KW`@!H````
M4_@"``H```"\^`(`(P```,?X`@`B````Z_@"`!\````.^0(`+0```"[Y`@`T
M````7/D"`"H```"1^0(`'@```+SY`@!D````V_D"`&L```!`^@(`5P```*SZ
M`@!D````!/L"`#L```!I^P(`(@```*7[`@!R````R/L"`%8````[_`(`5```
M`)+\`@!#````Y_P"`%8````K_0(`%P```(+]`@`]````FOT"`"\```#8_0(`
M-@````C^`@!-````/_X"`#$```"-_@(`3P```+_^`@`5````#_\"``@````E
M_P(`&P```"[_`@`;````2O\"`!,```!F_P(`#0```'K_`@`Y````B/\"``P`
M``#"_P(`#0```,__`@`*````W?\"`!L```#H_P(`#P````0``P`,````%``#
M`"`````A``,`!@```$(``P`(````20`#``@```!2``,`&P```%L``P`;````
M=P`#``\```"3``,`'0```*,``P`:````P0`#`"@```#<``,`*@````4!`P`W
M````,`$#`#D```!H`0,`*@```*(!`P`E````S0$#`#0```#S`0,`)0```"@"
M`P`5````3@(#`!L```!D`@,`&````(`"`P`M````F0(#`#8```#'`@,`%0``
M`/X"`P`*````%`,#`"L````?`P,`#@```$L#`P`:````6@,#`",```!U`P,`
M&@```)D#`P!'````M`,#`!<```#\`P,`&0```!0$`P`E````+@0#`$\```!4
M!`,`$P```*0$`P`3````N`0#`!$```#,!`,`"@```-X$`P`2````Z00#``H`
M``#\!`,`"`````<%`P`/````$`4#`!H````@!0,`%0```#L%`P`=````404#
M`!T```!O!0,`%@```(T%`P`-````I`4#`!P```"R!0,`%0```,\%`P`3````
MY04#`!$```#Y!0,`(@````L&`P`.````+@8#``P````]!@,`"@```$H&`P`*
M````508#`!,```!@!@,`"@```'0&`P`>````?P8#``X```">!@,`$````*T&
M`P`F````O@8#`)````#E!@,`00```'8'`P!1````N`<#`"@````*"`,`$@``
M`#,(`P`*````1@@#`!,```!1"`,`$P```&4(`P`,````>0@#``@```"&"`,`
M$0```(\(`P`*````H0@#``@```"L"`,`"@```+4(`P`0````P`@#`!````#1
M"`,`%P```.((`P`@````^@@#`!D````;"0,`+P```#4)`P`L````90D#``@`
M``"2"0,`"````)L)`P`0````I`D#``@```"U"0,`%P```+X)`P`7````U@D#
M``<```#N"0,`"@```/8)`P`&`````0H#`!,````("@,`'````!P*`P`3````
M.0H#`!4```!-"@,`&0```&,*`P`.````?0H#`#H```","@,`)@```,<*`P!.
M````[@H#``8````]"P,`#0```$0+`P`/````4@L#`!$```!B"P,`#@```'0+
M`P`.````@PL#`$D```"2"P,`)P```-P+`P!!````!`P#`#T```!&#`,`-@``
M`(0,`P`B````NPP#`"(```#>#`,`GP````$-`P`:````H0T#`!H```"\#0,`
M+0```-<-`P#$````!0X#`&4```#*#@,`5````#`/`P!'````A0\#`$P```#-
M#P,`>0```!H0`P!O````E!`#`&$````$$0,`,````&81`P`Y````EQ$#`&0`
M``#1$0,`/````#82`P`Z````<Q(#`#P```"N$@,`20```.L2`P`T````-1,#
M`"T```!J$P,`[````)@3`P!<````A10#`&T```#B%`,`9````%`5`P!@````
MM14#`#4````6%@,`,0```$P6`P!3````?A8#`%$```#2%@,`#@$``"07`P`D
M````,Q@#`,(```!8&`,`?````!L9`P`4````F!D#`&4```"M&0,`;0```!,:
M`P!<````@1H#`#@```#>&@,`7````!<;`P`]````=!L#`!\```"R&P,`)P``
M`-(;`P`[````^AL#`+P````V'`,`;0```/,<`P`X````81T#`)X```":'0,`
M?````#D>`P"S````MAX#`$X```!J'P,`3@```+D?`P!+````""`#`"````!4
M(`,`&````'4@`P`3`0``CB`#`#,```"B(0,`)@```-8A`P`F````_2$#`&4`
M```D(@,`-P```(HB`P`T````PB(#`$4```#W(@,`-0```#TC`P`L````<R,#
M`#,```"@(P,`+P```-0C`P`[````!"0#`%<```!`)`,`,````)@D`P`1````
MR20#`#$```#;)`,`+0````TE`P!7````.R4#`"<```"3)0,`4````+LE`P`F
M````#"8#`!@````S)@,`30```$PF`P!`````FB8#`%<```#;)@,`,0```#,G
M`P!A````92<#`#,```#')P,`,@```/LG`P!2````+B@#`,H```"!*`,`<P``
M`$PI`P!?````P"D#`(0````@*@,`4@```*4J`P"+````^"H#`((```"$*P,`
ME0````<L`P")````G2P#`(D````G+0,`>````+$M`P`\````*BX#`$@```!G
M+@,`F````+`N`P!"````22\#`%$```",+P,`4````-XO`P!5````+S`#`$H`
M``"%,`,`=0```-`P`P"(````1C$#`(X```#/,0,`E````%XR`P!:````\S(#
M`$D```!.,P,`=@```)@S`P!X````#S0#`$@```"(-`,`+P```-$T`P`S````
M`34#`'<````U-0,`5````*TU`P!(`````C8#`"X```!+-@,`/````'HV`P!&
M````MS8#`$@```#^-@,`2@```$<W`P`H````DC<#`$4```"[-P,`3`````$X
M`P!.````3C@#`(@```"=.`,`.````"8Y`P`9````7SD#`'$```!Y.0,`0@``
M`.LY`P!^````+CH#`&@```"M.@,`@@```!8[`P!Y````F3L#`'$````3/`,`
M5@```(4\`P!6````W#P#`%D````S/0,`.@```(T]`P`W````R#T#`!8`````
M/@,`CP```!<^`P`O````ISX#`%$```#7/@,`5@```"D_`P`_````@#\#`"H`
M``#`/P,`8````.L_`P!9````3$`#`!X```"F0`,`'P```,5``P`&````Y4`#
M``P```#L0`,`"````/E``P`5`````D$#`!$````800,`%P```"I!`P`*````
M0D$#`",```!-00,`!````'%!`P`5````=D$#`)L```",00,`CP```"A"`P`*
M````N$(#``@```##0@,`"````,Q"`P`@````U4(#`"D```#V0@,`$0```"!#
M`P`5````,D,#`!8```!(0P,`'0```%]#`P`-````?4,#`!0```"+0P,`*P``
M`*!#`P`0````S$,#``,```#=0P,`!````.%#`P`R````YD,#`&H````91`,`
M4````(1$`P!6````U40#`"L````L10,`-````%A%`P`H````C44#`$8```"V
M10,`/````/U%`P`W````.D8#`#L```!R1@,`0````*Y&`P`N````[T8#`#H`
M```>1P,`+@```%E'`P`X````B$<#`%````#!1P,`,P```!)(`P`X````1D@#
M`#P```!_2`,`-P```+Q(`P!,````]$@#`#P```!!20,`1@```'Y)`P`U````
MQ4D#`#L```#[20,`/````#=*`P!)````=$H#`#<```"^2@,`.@```/9*`P`R
M````,4L#`&P```!D2P,`/````-%+`P!!````#DP#`$4```!03`,`1@```)9,
M`P!`````W4P#`$,````>30,`,@```&)-`P`]````E4T#`#<```#330,`,@``
M``M.`P`[````/DX#`!H```!Z3@,`*P```)5.`P`.````P4X#`!,```#03@,`
M&P```.1.`P`A`````$\#`"L````B3P,`1@```$Y/`P`T````E4\#``\```#*
M3P,`*P```-I/`P`/````!E`#``P````64`,`&0```"-0`P`9````/5`#`!L`
M``!74`,`'0```'-0`P`X````D5`#`",```#*4`,`(````.Y0`P`-````#U$#
M`),!```=40,`%0```+%2`P`:````QU(#`"4```#B4@,`(`````A3`P`2````
M*5,#`!4````\4P,`+````%)3`P`F````?U,#`!T```"F4P,`'````,13`P`T
M````X5,#``H````65`,`<P```"%4`P`<````E50#`"````"R5`,`'````--4
M`P`L````\%0#`$8````=50,`%P```&15`P!$````?%4#`&0```#!50,`"@``
M`"96`P!`````,58#`!D```!R5@,`'@```(Q6`P`8````JU8#`$P```#$5@,`
M(P```!%7`P`1````-5<#`!(```!'5P,`$P```%I7`P`<````;E<#`"````"+
M5P,`#@```*Q7`P!$````NU<#``P`````6`,`*`````U8`P!!````-E@#``P`
M``!X6`,`)P```(58`P`,````K5@#``@```"Z6`,`$P```,-8`P`3````UU@#
M`"(```#K6`,`"P````Y9`P`1````&ED#`!,````L60,`!@```$!9`P`-````
M1UD#`"$```!560,`/````'=9`P`=````M%D#`"<```#260,`)P```/I9`P`9
M````(EH#`"4````\6@,`)@```&):`P`:````B5H#`#\```"D6@,`-P```.1:
M`P`7````'%L#`"$````T6P,`6````%9;`P`9````KUL#`!<```#)6P,`0```
M`.%;`P`A````(EP#`#P```!$7`,`.0```(%<`P`Y````NUP#`!P```#U7`,`
M(P```!)=`P`@````-ET#`!D```!770,`&P```'%=`P!/````C5T#``P```#=
M70,`$````.I=`P`8````^UT#`#T````47@,`"P```%)>`P`$````7EX#``T`
M``!C7@,`"@```'%>`P`1````?%X#`!H```".7@,`%@```*E>`P`4````P%X#
M`!4```#57@,`6@```.M>`P`C````1E\#`"@```!J7P,`>````)-?`P"P````
M#&`#`'0```"]8`,`>0```#)A`P"8````K&$#``\```!%8@,`;````%5B`P`3
M````PF(#``8```#68@,`'````-UB`P!=````^F(#`!,```!88P,`$0```&QC
M`P`)````?F,#``0```"(8P,`!P```(UC`P`9````E6,#`"\```"O8P,`!P``
M`-]C`P`(````YV,#``8```#P8P,`!@```/=C`P`6````_F,#`!8````59`,`
M!0```"QD`P`$````,F0#``P````W9`,`!@```$1D`P`5````2V0#`'````!A
M9`,`30```-)D`P`\````(&4#`%X```!=90,`/````+QE`P!&````^64#`'(`
M``!`9@,`-0```+-F`P!$````Z68#`"<````N9P,`.0```%9G`P!B````D&<#
M`#0```#S9P,`O@```"AH`P"1````YV@#`%,```!Y:0,`C````,UI`P!)````
M6FH#`%T```"D:@,`*`````)K`P`J````*VL#`.D```!6:P,`&````$!L`P`]
M````66P#`#T```"7;`,`L0```-5L`P!)````AVT#`'H```#1;0,`4P```$QN
M`P!*````H&X#`#X```#K;@,`:````"IO`P"+````DV\#`(X````?<`,`2@``
M`*YP`P!,````^7`#`#X```!&<0,`4@```(5Q`P!+````V'$#`#,````D<@,`
M4P```%AR`P!1````K'(#`%X```#^<@,`5P```%US`P!>````M7,#`%$````4
M=`,`/P```&9T`P!7````IG0#`$````#^=`,`.P```#]U`P!-````>W4#`#8`
M``#)=0,`/0````!V`P!6````/G8#`"0```"5=@,`(````+IV`P`5````VW8#
M`+T```#Q=@,`#0```*]W`P`R````O7<#`!@```#P=P,`&@````EX`P`X````
M)'@#`$8```!=>`,`%@```*1X`P!V````NW@#`-H````R>0,`N0````UZ`P!F
M````QWH#`$P````N>P,`-P```'M[`P!2````LWL#`$X````&?`,`(````%5\
M`P`7````=GP#`"@```".?`,`-P```+=\`P`U````[WP#`%P````E?0,`.P``
M`()]`P`T````OGT#`*$```#S?0,`+@```)5^`P`M````Q'X#`!(```#R?@,`
M,0````5_`P`5````-W\#`!8```!-?P,`*0```&1_`P`R````CG\#`!,```#!
M?P,`#@```-5_`P`5````Y'\#`!,```#Z?P,``P````Z``P`,````$H`#`!$`
M```?@`,`!@```#&``P`-````.(`#`!0```!&@`,`%````%N``P`,````<(`#
M``0```!]@`,`'````(*``P`%````GX`#``@```"E@`,`"````*Z``P`7````
MMX`#`!@```#/@`,`$0```.B``P`,````^H`#``8````'@0,`#`````Z!`P`1
M````&X$#`!0````M@0,`"````$*!`P`*````2X$#`!D```!6@0,`&@```'"!
M`P`:````BX$#``H```"F@0,`!````+&!`P`.````MH$#``X```#%@0,`%0``
M`-2!`P`3````ZH$#`!@```#^@0,`"@```!>"`P`2````(H(#``L````U@@,`
M"@```$&"`P`(````3((#`"$```!5@@,`#````'>"`P`$````A((#`!<```")
M@@,`!@```*&"`P`"````J((#``H```"K@@,`"````+:"`P`(````OX(#``D`
M``#(@@,`(P```-*"`P`&````]H(#``T```#]@@,`'`````N#`P`L````*(,#
M``<```!5@P,`!````%V#`P`(````8H,#``X```!K@P,`"````'J#`P`9````
M@X,#`!4```"=@P,`&0```+.#`P`/````S8,#`!4```#=@P,`%0```/.#`P`3
M````"80#`$,````=A`,`$0```&&$`P`+````<X0#`!<```!_A`,`!0```)>$
M`P`"````G80#``L```"@A`,`&@```*R$`P`:````QX0#``$```!Q`0``R@8`
M`+L%``!G`P```````-\$```Y!0```````(`"```5`@````(````````!"0``
M(P0``+$````%!```'@@``*\!````````&P4```````"2"```I`$``!X#``#=
M!@``<@(``!P&```0`0````````$&````````M@,``,T'```["```$@```*4%
M``#_!P``300``'P%``"0````.P<``&T#``">`0``2PD``+T&```%!0``"@D`
M``````"0`@``@`4```@%``#@`P```````%D!````````````````````````
M3`,``"T$``#&"````````($!``#A`P``(@4``.\!``!2!P```````$,'``!,
M"```(04````````_`P``<`$``+`(``!P"`````````````!T````K@0``%4"
M``#3`@````````````"1!P``QP(``!L!``#C`@``X````$(&```_````Z@4`
M`'@(````````+`,``*,(``"H`P```P8``!L)``#4"```-@(``%0)````````
M`````+``````````P`0``%P)``#$`@``=P<``!@"````````"`$```````"^
M`0``B@(``!P%``"<`P``M@4``,X$``#!!P``MP<```````"R!P```````*D(
M``!?`0``X`(````````5"0``AP```/('``#2!P``]@@``.,````@`0``4P``
M`)T%````!0```````'H!``"+`0``108``)<&```=!```Y@(``)`'``"J"```
MIP<```````!X````S`$``!L(`````````````/`$```5````200``.<!````
M````50@``$P$`````````````#D'````````(0,``$@'``"6````&`,``,H`
M`````````@(````````F````8`4```````#J`0``E@(``-X%```5"```````
M`,P&````````;P,``$T!``"/!@```````'T(``#3!@```````)@!``#[!P``
M1P<```````#T````Z0```-P#````````(`<``+(&```)!P``@`$``#@`````
M``````````````"F`P``D`@`````````````P````'\"```:"0``U@$``($(
M``!:!@```````$@!``"P!```,0(``$,%``"\!@``]0````````"T`P``%@,`
M`&@#```I`@``TP,``#4)`````````````/T(``#(`@```````.('```S"0``
M9PD```````!Y!P``Q@(````````/`P``708``$T%`````````````*0````W
M!0``#````!\#``#-`0``*`8``(0'```E!0````````````!<"```5P8``)D"
M``"B!P``C04``,4'``!N!0``L`,```\$``#X!P`````````````8"0``OP8`
M``````!9`@```````,P(``#.!0``:P```(T$``"%`@``V`,`````````````
M804``#(```!6"0``<@0```````"Z`P``70,``"T"````````Z@(``&P'```)
M`0````````````!Z````W`4``/8$````````F@,`````````````FP0``'(#
M``!1!```N`0````````4!````````-D%``"X`0``3`````````"9!```*@(`
M``X"````````^@$``(@```!V`0``1P$`````````````#08```````!,"0``
M^08```````#F!```,P(``+`'````````````````````````_@```/<'``"@
M!P``)@,``+8$``"O!@``I`,``,("```Q!```R@,```D%```W!```M@8``.X"
M``#"`P``*`@``%D&``"&`@``T0(``!('``":!```2P$``$L```#T`0``.`4`
M```````["0``$0@``*H'``"2!@``:`(```````#F!@``10$``)\```#\!P``
M+`D``$$&``!N`P``(@````````!1`0```````&X!````````?08``,$(````
M````104``(H(``!#`@````````````#^`P``;0```.L&``![!P``NP$``%P!
M````````'@8```````#P````^04``-D#````````U@4````````!!P``1@(`
M`)T&`````````````$<#``"G!0``^@<`````````````,@@``+(%``!]`0``
MO0,```````#B`@``S@<``"<``````````````+<$````````"0(``.4%````
M````^0,``(X&````````8P@``"8"````````>@,```````!6!```*0,`````
M``"H````C@0````````.````-`D```0!`````````````.D(``"1!@``<@4`
M`,0!`````````````&<'``"O````G@(```````!S`P``'0```'`'````````
M```````````V!0``/`@``!P(````````Q@,```T'``!S"````````'8$```3
M`P```````"0%````````$@4`````````````,0@``"$````X"```5`0`````
M``#0````)@<``),(``"=`@``0PD``*P"``#E`@``:@4```````!4!0``````
M`"$$````````#0(``-<```!I`0``1`8```D$``!P!```'0$``*\#````````
M'0(``.X#``!C!P``,@D``((#```V!@``O@@`````````````/0$``%L'````
M````X`0```\``````````````,,'````````]@```-P&````````^P8``'T)
M```1"0``-`<``$$````I!P```````)`#```F!0``?`,```````#/!P```PD`
M`-<!``!5!0```````($#``!!!0``5````.0```";````D0```%X(````````
MPP8``-`!``"C`@``9@$``/4#``#<`@``F0,``%0(````````S@@```````#1
M!0``_`@``,L!``"/!P```````*H$``#\````\@```$0(``#Q````T`8`````
M``#I`@``G0@``%T$``!P`P``L`$```````!A`@``2@(``'8%````````'P``
M`"L)``!'!```>`D``),!``#>!@``'04``````````````````$D)````````
MX@````````!?`P``G@@``````````````````&<$```U`@``%@0``'<"```V
M````>0(``*\$``"+!@```P,```````"B!@``+`<`````````````3@``````
M```M"0``.0@```````!P!@``)`<``!L"``````````````0(``#@!@``7`8`
M````````````P`<```````!L!0```````)8#``!E`0``G````*(%```E"```
M`````'X$````````G@<``,L&``!2`0``-00``*@(``"O"```7P8``.P#````
M`````````#X$```!!```@`@``/@#``"'!0``N0<```<'```K`0``>0@``(``
M```;````I@0```L(``!(``````````````!T`0``40,`````````````F@4`
M`,('``!-`@````````````#N"```_@<````````0`P```````%$(````````
M_0,``-T%```U`P``/0D``"@```!8!```L0<``.L"`````````````%P```"=
M!```7@,``+4$``!L`P``M`<``#8$````````(`,``-<%```T!0``K`@``,8%
M``#T!P``A0```/P#``#N!P```````"H$````````H@````````#2!```?P4`
M`(8```#A`0```````*P'```R`@```````#X!``!N!````````-H'``"<"```
MR0<``.T`````````9`0``-8&``##````>P0``#@&````````H@(``"$(```C
M"````````$`)``"'`P``U04``*X'``"U!0``6P4``(0````F"```.@<``!T'
M````````O@```#$#``"8`@```````"('```@"```Z@<```4'````````````
M`)X%```7"0``;@````````"A!@```````/\&```N!````````$D!``"E!```
MC@<``(\$``"F`@``D@,``'4'``!B!P``=`<``$((``"0!```J0,``+,$``!Y
M!```*`D``.$(```$!P``'0@```8#``#/`P``^`0``#D"``!B"```5`<`````
M````````40<``$H!``#N!@``/P0```8)``#G!P```````(4$````````00@`
M`'`%``"W!0``^0(``.L$`````````````#0(``!8!0``F04``-<&````````
MY@@``(P#``!1"0``?`8``%L$```E`@``:P<```````""`0``,P4``,T#``!S
M!```L@(``%()``!]!P```````````````````````&X"````````:00``$<(
M``#*"```U`(```<```!W!0``10<```````!?``````````````"Y`@``P@``
M```````7`0`````````````N!P```````($&````````N`8``(D'````````
M`````-@(````````Y@<``&P&``"?`0```````((&````````O@8``&,!```;
M!P```````(P(``!Q`P``&@4``+H$````````K0@```````#'`0```````*`$
M``"Q`P``4@8````````.!P````````````!T!@``M0,``,<&````!P``_`4`
M`*4#````"0``.`(``"X"``"M!P````````````#=!```D0@``)$%```H`0``
M`````'$(```Z"````````,8&``!Y!0``I`@``&(&````````````````````
M````>@4``%@#```O`P``/@D```````#E!P``W@0``-\(```T!@``+PD``*(#
M``````````````T%``")!```F`8``$P"``#?!@``$P4```````"X!0``````
M````````````0P```%<%``"T`@``G0$``*4'``"9"```T`,``$$'```D`@``
M`````.@```#%`0``G0`````(````````B`,````````1````+P0`````````
M````M`4`````````````,P,``"((```:`P``IP$````````6"```8`8``$@#
M``#G!```,P0``%4'````````"@0``'X(``#+````;@<```````#>`P``````
M``````!/`@```````-D```#?`@``:P(``,@&``!`````'`,``-H$````````
M+0$``,L$```R`P````````L#```1!@``AP<````````9`````P<``'X'```(
M"```6P(``$(#``!2!0``4`$``"$'``!V`P``IP````````"/`P```````'4&
M```8"```"08``%,%`````````````%H```"L````O0$``&0!````````:`@`
M``````#)`````````-P(````````:`8```H(``#%"```BP```+D```#M!0``
MGP(``.0!``#-````;P4`````````````80@``(,'``!=````A`8```````#Y
M!P``R08```````#6"```/@,``!<'``"I`@``F08```````"K`@``OP@``$<%
M``"N`@``S`0``(,(````````Y0$``'<#``!6`@``9`D``%D'````````F`4`
M`-(```!5`P``_`8```````````````````````!W`0``QP<``$0#````````
M````````````````'0,``&@)````````````````````````@P0`````````
M`````````"@"````````HP$``+X"``!L"0``GP8``"H```!?"0````````P(
M```Z!0``Z@````````!A````E`````P!```C`0``O`0```L```"Q`@``I0$`
M`$,!``"<`@``/00``````````````````"L"``!<!0``=@``````````````
M\P8```T$``!C!@```````!D#````````H04```````!%"```G`4`````````
M````$`(```````#;`0``Y`(```T)``#]`0``E`<``#T"````````2P,``.P&
M````````````````````````>P$``&H&``#'`P```````&,#```Z`0``````
M`"L$```W"0``9P(``%X%``!B`P``R`,``-$'``!M`0``9`4```````#Y!```
MC@@``*T"``"K"````````-`(```#!```OP0``/`"``!C!0``'`D``)L"``!T
M`P``+P```#L```!^!@``30<```````#L`````````+L&````````]0@``-$&
M``#H!@```````$$"`````````````/4!``![`@``V`$``,<````Z````<P``
M````````````G`0```````#1````-@D```````!B````(PD``'H$```Y"0``
M%00``)H'`````````````-P'```"`P``V0<```````"L`P``(@,``"8&``!'
M`````````%D#```T`0``]P8``-0'``!3"````````#P$``"=!P``Q0(``%4)
M``#N!```>`4`````````````M0<```L&``#5!```X`4``)4'````````Z0$`
M``````#[!0``]P```.<#``"S`0```````(@'`````````````-L&``!A"0``
M0`$``),&``!Q!0``]`(``%0&``!>`0``O@4``%<'``"6!0`````````````2
M"```J04``/<%``!`!```3`4``-$#``"6`0```````$`'````````B@0``"L%
M````````E@0``/8"``!U!```````````````````E08````````Y!```0@<`
M``\)```X!```6P8``)8&``!2!```H`,``#T&``#<!```E0@```````#/!0``
M,`(``*@&``#3!P````````````!1`@``-@<``/4&``"Z"```!@@``.D#``"I
M!@``-0@``!$#```Y`````````+,```"Z!P``204````````I!0```````'@$
M``#L!```?@,``-P!```N````*@4``'0(```Z`@``B@8```````!3`P``````
M`(<(``"(!````````#4'````````$0(``-X````=!@``AP0``#`&````````
MP`8``%<(``#H`P``H`@``)(%````````9P$`````````````<0(````````U
M````E0(```@```!M!0``$P$``(0(```4`0``(P4``,\!```.!0``HP,``!()
M``!5!```````````````````?P8```````"S"```=P```"<'```%"```&`$`
M`'4"````````^@```+$(``"%"``````````````7!@``[08``'$````<!```
M#@@``$<&``!=!0``;P``````````````:0<``.@"``#Q!```Z`0```````!"
M`0``>PD``"4'``!#"```1`4``%4````D"0``TP4```````"^!```FP<``%8'
M```&````CP4``#8#``!J!P``````````````````\0,``%(```"+!0``F`,`
M`&D#```6`@``+0<```````!W"```%P,``"`$``#B!@```````&`#``!0!P``
MH@0``','```$````?`````T#``!D````:````!D(```G!@```````-L```!8
M"```PP(```L!````````C````````````````````,P```!``P``Q04`````
M``!M`@``X@@``/H#``````````````````"Y!`````````````!3`@``````
M`!4!``"S!@``J@(``"0(``#B!0``Q@$````````+`@``H@$``$L%``#T!@``
M.@8``"P!````````BP@```````!8````)P$```````!0!0```````!<```!Y
M`0```````((```#R`P```````-,(``#P!P`````````````""0``````````
M``#C"```U0$``,<(`````````````/0%``!U````O0@``#(%``"P`@``?`(`
M`,(!```%`0``4@(``"$"``#"!0``M`$``&8"````````^P$````````E`0``
M``````````#L`0```````#0$``!1!0``2P(```\%```I!```9@```)$#``!J
M`@``/`D```````!E!@``'@```$0!``!("```7@D``+8'````````5P```'\$
M``!K`0```````````````````````)X#``!$`@``#P@````````7"```!P(`
M`*8%```D!```(`D``%<)````````V`8``*`!```C````2`8``(H```!+"```
M``````````!\!```\0<``$\!``":!@``P08``/X$``"$`0``A`0````````S
M`0```````#````!]````T@8``#L$``#C!P``4`@```````#%!@``&`8``"T#
M``"N````:P4```````!8`0``R0@``````````````````!H!````!```FP4`
M```````]!0``%`D````````T`@``,08``!H$``#F!0``%@8``/`(``#Q!0``
M;00``*\"````````;P<``"\(``#)!0``Y@$````````9`0``M@$```````!.
M"```@`0``*H#``",!```%`,``(4'`````````````%,'```N`P``;P0``/4"
M````````K`4``"X!```E"0``U`0```$!``!_`````````/("``",!P``-@$`
M`*T%`````````````%\(``!B!0``V@8```````#>!P``UP0``!<%````````
MX@,```4&``#M`@``[P0``/(!``"B"```,`<``"(!````````&00``+H"``#D
M!0``-@@``(,%``#R!```^@(``#L#````````B08``,0&`````````````&D`
M```"!@``#P<``'0"``!/"0``!`,``)@(```9!P```````*L````M"```+P8`
M`*`&````````&````.X```"Y"````````````````````````&,)``"C!P``
M+@8``!P"``!3!@```````/8#````````+@D``+T"``````````````````!0
M!@``$@(```````#J`P``<P$```````#!`0``-0$``"L````-``````$``*@"
M````````;@@``$8&``"?!0``50$````````"````'@(``,$$````````,0D`
M`)`%```="0``>0,``!(&````````*P8``&P"``"3!0``A@8``&\"```0"0``
M`````!H(```8!0``TP```#<'``!J`P``/P8```````!H!```^@8``(X```#(
M!0``I@@```````!I!@``,`4``+@```!.!@``6@@``%,!``"!"0``"P<``#X"
M``!<`P``@P,````````!`P``?@(``&$#``#]!```#@,``#(!```"!```W@$`
M`$T#``!/"````````'$$```L!0``>@@``)D!``#-!0``:P0````````5!P``
MEP@```````#.`P``O0```"X(``"Z`0```````&`"``"[`@```````&P(````
M````F@(``(0"``"4"```8@D``+`&```."0``1@```*8&``!L````MP$`````
M``#;`P``^P0``"X%``````````````````#U!0``/@```#($``#O"```O`4`
M`&D(``#$"`````````````"2````M08``&P$````````=`D``(8!``"6"```
M8@(````````D`P``$`@``%8%````````B@$``$8!``!U"0``#P8````````L
M!````````&``````````A`,`````````````[0$``/$&``!>!```$@0``-4&
M``#W`P``NP,```````##!0```````$4$```'"0```P(``&X)````````@P``
M```````_`@``V@$``#D!``"N`0````````\"``"W````J`$`````````````
M.`,``'P)``#L"```+08``$8$```K"```9P4`````````````>P@```````"A
M!P```````(L'```""```%@4``*<(``"K`0``$P0````````G`@``4`,``*H&
M````````2@,``*P$````````%@<``,X"``#(!P``EP$```4`````````U`$`
M`)4#```.!`````````````#^"`````````````"9!P``ZP<`````````````
M`````%T"````````;08````````3"```808``&\)````````Q0,``-`'``#O
M!0``)P,``'X)``#4!@```````(P&````````9@4``%<"````````X`$`````
M``#P!@```````(T!``"\`@``NP@``,$%```B`@``\P<````````1!```LP,`
M`*0&``"'`0``(P<```8'````````DP(```````"&"```SP8```0&````````
M"@````P)```W`@``V`<````````G"```Q`4``%8&````````_P0``!4&``!/
M!@````````$%````````)`$```````"%!0``0@0``($"```A!@``T`4``+\%
M``"K`P```````/D!```S!P``[`(``.4#````````N0$``#\)````````LP(`
M``````"A`0``\P4``,P'``#B`0``9`8````````L`@``3P,``+P`````````
MU0```(H#````````_P,``*\'```O!P``@0<``)P&``#D!```6P,``'<&```"
M!0``80$```````"9`````````'4%``#E"```````````````````@@<``.4&
M````````3@4``',"````````D00````````+"0````````H&``"A`@``EP,`
M`&T(``#=!P``_P$``$D'``!&"0````````L$``"R`````````'H'``"_!P``
M`````'D```!]`P``P@@``%\"````````/`4``/,#``"7!0``P`(`````````
M````&@```*,$``!Q"0``8`$``)H``````````````!8!````````>`(`````
M``!6`0``"0```",&`````````````$\$```Q!0``@`<``&\!````````<P4`
M````````````C0(``,@(``!Y"0``0@4``$(```##`P```````&@!``#C!@``
ML00``"4&```J"0``AP(``)4!````````)@0````````%`P``\P(`````````
M````.@D``%P"``#:"```M0(````````<!P```````-T"``!^!0``&0(``(`&
M``#6````DP```.<(``#:!0```````)H(```#!0``/0,```````#K`P``W@@`
M`#('``!.`0``@`,``)8'`````````````'<$```4`````````-L%```^!@``
M<`(``(4!``"7!P``PP$``#`)```;`P``M````%D)```F"0``.08``%L)```(
M"0``\@@``"````#-!```7`0``$\%``!V"0``D@(``$\'``!2"```UP@``$`%
M``"[!```H0,```H#``#)`0```````&<```#"!@``%P(``%@'``!R````R0(`
M``````#@"```[@$``,`(```>`0```````+<&``":`0``9`<````````1!P``
M0P0``,D$``">````+`@``&`)````````60````````#G!@``CP`````````3
M"0``;P8``-4#``#9"```6@0```````"?"```>@D``#X%``#``0``>@(``'(&
M````````[0<``%0#``"R`P``U0(``$D(```Z`P```````(D"``!\!P``^`(`
M`-(!```)"```J@4``,0'``#.!@``O@,````````M````M`@``#P```#_`@``
M!@0``!`%``#5!P``=@@```P%``"C````D`$``-T!``"7`@``*@@``.P'``#M
M!```'P$``$8'``"Z````>P4``!D)```)"0``)00``,\"``#9!@```````.,$
M``#G````7@(``)L(``!:"0``)@$``!X)````````K0,```````"N!0``R@<`
M``````#J"```10,````````O!0``#P$``(($``#;!P``!0(``)$"``!*"0``
M`````+(!````````SP@``+\!````````Z0<``+$!````````MP,```````#&
M!P``Z`@``(T(``!G"```#0$``-@````.`0``MP@``*L&``#\`0``2`4``%T!
M``#:````UP(``-<'````````Z`<```````#?!0``>`8``/P$````````K08`
M`'L`````````YP4````````6````P0,``/\%```\!@```````$<"``"N!@``
M8`@```````!7`0```````$H%````````P`,``*4&`````````````)T#````
M````@00``````````````````,\`````````J`<```H'``!M"0``]@8```<(
M```E`P``M@(``&`$```,!P``U@(``.($``!""0``@0``````````````````
M`-\!`````````````(\(````````L04``.$'````````.`$``!@$``!E````
M```````````(!P```````#\'``!*!P``9`@``&\(``!Z!@````````<#````
M````_0<```````#P`0```````%H"`````````````*P!``!]`@```````(D#
M``#K!0```````!\)``##"```N0,``"H!``"C!0``9P8`````````````)`8`
M``````"("```]@<``-H"````````P0```)L#``````````````D#``"E`@``
M`````*$(```U!0```````$L'``"#!@```````,H!``!W"0``4P0``%8#``">
M!@``&@(``+@"``"E"```H`4``)\#``"G!```,P8``/H$``!_`P``&`<``(\"
M````````$0$``+T$``!%"0```````'@!```<`0``[P8``/,$````````BP0`
M`!0(``!U`P``4@,```0%``!J````7@``````````````0`(```````!I`@``
M``````````#'!```?00``#L!``!\`0``A`4``!\&````````D@$``$D#``#D
M`P```````&($``#W`0``]P@``"P&``!]!0``E`4`````````````R`0``*0'
M```H!P```````#0#``#J!@```````)('``"G`@``^@4``(,!``#9`0``X00`
M`#X'````````/`<``#@'``#Y"```\P```+0$``````````````````#-`@``
M`````/`#``#Z"`````````````"+`P``V00``/D`````````XP,``!L&````
M``````````````#L!0```````,H"````````5P,```````#H!0```````%\%
M``""!0``*`0```,!``##!```KP4``$H(``!E!P``,`$``-T```!9!```````
M`/0$``#^`@``*0```#,(``!N!@``NP<``-L$``#Q"```^P@```````"\!P``
M`````"($```#"`````````````!B`0``SP0``````````````````*8'``#2
M`@``:0D```````#S`0``2`D``),$````````_@8```````"S!0``Q```````
M``"1`0``_`(``&,```!*!@```````*8```"J`0``]`,``&L#``!P"0``!`D`
M`$L$``#[````````````````````[0@```````#!`@``+P(``,4````X"0``
M#`,``&L)``"M````#`8``/T`````````Y`@``!D%````````_P@``-\````R
M!@``10(``(T&``"&`P```````$P&```[!@``.0,```````#8`@``B0@``,L#
M``"5!0``?PD```````#+`@``=@8``#<&``"?!P``S@```*T!````````````
M`),'````````^`8``.D%````````Y00``+@#````````6P@```````!5!@``
M:P8``"$!````````R@4```````!.!````````/T%``!Y!@```````(X%``!.
M!P```````/$!``!<!P``%`4``#T(``!A!```,`,```8"``#?`P``C0<`````
M``"(`@``_08``'8"``"4!@``MP(``!\(````````604`````````````````
M````````````^``````````5!0``)P0```X&``!:!P``<`````@"````````
M3`$``.H$``"""```4`D``*$```"F`0``0P,```0$```P!```7P<```````!D
M`@``000``,($``"%`P``````````````````?P<``*<&``![!@```@<``.$&
M````````_@$``!H'````````U@0````````,!```U@<```````"]!P``T@,`
M`&4%````````K@,``!``````````^P,```````!J"````````,8$````````
M3@,``!P`````````V`4```````")!0``90,``-$$``"\"```LP<``*0%``#O
M`P``5P0``$D"````````*`,``)<````I`0``C`4``$`(```D````;`$``.,!
M``#D!@``'@4``,`%``"'!@``JP4`````````````-P```#L"``!$!```L08`
M`+P#``#)`P``E`0````````3`@``Z08```````!3"0``Y@```/X%``!E`@``
M`````.$"```#````&P0``%D(``#_````2@````H"``"H!0``Z00``'\(``"D
M!```[0,``/`%``!$`````````$X"``",`@```````````````P``6@$```0"
M``!6````B0```'X```"-`P```````%L!``"U`0``X0```%@&````````U`4`
M``````!!`P``Y0```!0'````````B`8``+L```"4`P``W@(``!(#````````
M`````'L#```S`````````#P"``!&`P``*@8``+8(``#6`P````````````"D
M`@``T@4``"\!```]!P``408``-`$``"P!0``?@$``'@#`````````````.@!
M``!$"0``?P$``$T(``"K!```9@8``,<%`````````````&4$```6"0``0@(`
M``````"3`P``^`$`````````````C`$````````&!@``V@,```````"_`P``
M:@0``&8)``#G`@``80<``/@(``#U!P``A08``!\%``!V!P``"P4`````````
M````V0(```````!Q!P``*@<```8!```L````8P0``%T'``!I!0``$@$``+($
M``!(`@````````<%``#8!```*P,``$T)``"I!P``>`<``&@%``!E"```F`<`
M`(8%``"X!P```````)`&```I"0``'@0```````#U!```(`4``#\(```0!P``
M`````&H)````````M0```+X'``!#!@``3`<``-0#``!1````/`$``$8(``!Q
M!@``S`(``!<$```G!0``L@@``#<#``".`P``$`0````````^"```````````
M``"Y!0``"`8``%`$````!@````````@$```>!P``VP@```````!H!P``J00`
M```````!`@``9@,``*L'````````+04```````#1`0``3@D``.`'```-"```
MB@<``/<$``"@`@``K@@```````!@!P``H00```H%```@`@```````/(%````
M````I0```',)``#V!0```````*T$``#Q`@```````#\%````````^`4``"(&
M```3!P``!@4``'0$``!U`0``7@8``$D&``"I`0``CP$``-`"``#K`0``@`D`
M`!\'``#,`P``GP0``)X$``!8"0``2`0``#$'````````N@8``-4(``!!`0``
MTP0``&8$````````.P4``*````!8`@``[P(```(!``#K````]@$``&0#````
M````J0```-<#``"5!```BP(``"L'``")`0``VP(``.0'````````(P(``&T'
M```*`0``=0@``)4`````````N08````````H!0````````P"``"8!```6P``
M`!4#```Q````B`4``)($``!`!@`````````````J`P``TP$``+4(``!&!0``
M`````#\!``"4`0```````/0(`````````````/(&````````00D``#0`````
M`````````-$(````````(@D``(8$``"H!````````'(!``"\`0```````!$%
M````````70D``,L(````````W````*H`````````Q@````````"<!P``%`8`
M`+\```#]`@``:P@``%8(````````<@<```````#.`0``,`@``#H$````````
M,0$``#<(```%"0``W0@```$(```E```````````````'!@```````!`&``"V
M````````````````````C@(`````````````2P8```````#S"```20```',&
M``"]!0``!P0```````!T!0``(P,`````````````%`(``-((``"C!@``RP4`
M`.X%```]````F````+\"````````Q`0``+@(``"T!@``4````"D&````````
MXP4``)<$```A"0``7P0``!\$````````5`$``%X'``#K"```3P````````#O
M!P``^P(``"`&```3````K`8``)0"``".`0``G`$```````!%````2@0``&,"
M``!\"```Q00``-T#``#W`@``308```<!```I"```&@8``,@!```(`P``R```
M`&H!``!0`@``-08``)L&``"&!P``Q`,``(@!``#-!@``R@0``)L!````````
M@04``#<!``!4`@``````````````````1PD``#P#````````)PD``.8#```?
M`@``6@,```````!E"0``IP,``(("``"Z!0``30```'()```9!@``1`<``,T(
M``#A!0``S`4``(,"````````WP<``-0``````````````!,&``!R"```B@4`
M`,L'``!="```9@<``&8(``"-````6@4```````#O`````"`@("`@($-C.B``
M("`@("`@5&\Z(``@("`@1&%T93H@`"`@("!&<F]M.B``("@E<R!D87ES(&%G
M;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"!3=6)J96-T.B``(&%T(``@:6X@`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@
M8W)E871E9#H@)7,N`",`)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0`E+C)F
M34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@
M)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D(&UE
M<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+@`E9"!M97-S86=E<R!H879E(&)E
M96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BX`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO
M="!S<&%M+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A
M;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S86=E<R!H
M879E(&)E96X@<F5P;W)T960@87,@<W!A;2X`)60@=&\@)60@;V8@)60@365S
M<V%G97,`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R
M:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE
M;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R
M("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&%T("5S("5S`"5S(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E
M<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S
M(&AA<R!A8V-E<'1E9"X`)7,@:&%S(&-A;F-E;&QE9"`E<RX`)7,@:&%S(&1E
M8VQI;F5D+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T
M+@`E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@
M:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S('1E
M;G1A=&EV96QY(&%C8V5P=&5D+@`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K
M('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`
M)7,@;F]T(&9O=6YD+@`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RX`)7,@
M=&\@)7,@;V8@)7,`)7,@=VES:&5S('1O(&%M;65N9"`E<RX`)7,@=VES:&5S
M('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E<R!W:7-H97,@=&\@<F5C96EV
M92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+@`E<R=S($%D9')E
M<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML
M:7-T`"5S.B`E<P`E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"D`*$%P<&QY
M('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*0`H1&ES
M8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C
M<F5E;BXI`"A(5$U,*0`H4&QA:6X@5&5X="D`*%)E='5R;B!T;R!T:&4@8V]M
M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T
M:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@
M3D]4(&)E(&%P<&QI960N*0`H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG
M(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C
M=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE
M<V4@8GD@8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE
M<RD@*@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@;65S<V%G92!H87,@8F5E;B!D
M96QE=&5D+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P
M86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`,2!M97-S86=E(&AA
M<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`Q(&UE<W-A9V4@:&%S(&)E
M96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2X`,3`P
M(&-H87)A8W1E<G,`,3`P,"!C:&%R86-T97)S`#$R($AO=7(@1F]R;6%T`#(T
M($AO=7(@1F]R;6%T`#(T(&AO=7)S`#(U,"!C:&%R86-T97)S`#4P,"!C:&%R
M86-T97)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!L87)G92!I
M;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N`$$@
M;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R
M;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@<F5C:7!I96YT+@!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H
M;W=E<G,`04TO4$T`04Y$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B
M<V)O='1O;0!!8G-M:61D;&4`06-C97!T(')E<75E<W0`06-C97!T960`06-C
M97!T960Z(`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF
M;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C
M;W5N="=S(&YA;64Z`$%C8V]U;G1I;F<`06-T:6]N<P!!9&0`061D($-H:6QD
M($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W
M($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE
M=R!M96UB97)S`$%D9"!P86ER`$%D9"!S;W5R8V4`061D('1H92`E<R!-96YU
M(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R
M`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`
M061D('5S97(`061D960@(B5S(B!A<R!A;B!A='1A8VAM96YT+@!!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P
M;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H
M96%D97(@;VX@82!N97<@;&EN92D\+V5M/@!!9&1I=&EO;F%L(&EN9F]R;6%T
M:6]N(&-A;B!B92!V:65W960@)7,N`$%D9&ET:6]N86P@:6YF;W)M871I;VX@
M9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<P!!9&1I=&EO;F%L
M(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L
M(&UE<W-A9V4@97)R;W(@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@97)R
M;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1R97-S`$%D9')E<W,@
M0F]O:P!!9&1R97-S($)O;VMS`$%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A
M9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N
M97<@;&EN92D\+V5M/@!!9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@
M=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R
M97-S(&]N(&$@;F5W(&QI;F4I/"]E;3X`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%L
M:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S
M97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S
M`$%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL
M(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE.@!!;&P@;65S<V%G
M97,@:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL
M;"!B92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD(&QI;FME9"!A='1A
M8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T
M960N`$%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO
M;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&QO=R!&;VQD97(@0W)E871I
M;VX_`$%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M
M86EL8F]X/P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06QT97)N871I=F4@
M<&%R=',@9F]R('1H:7,@<V5C=&EO;CH`06QW87ES`$%L=V%Y<R!S879E(&%T
M=&%C:&UE;G1S`$%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T
M;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE($E-05`@<V5R=F5R('-A:60Z
M(`!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@
M97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN`$%N
M;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`06YS=V5R960@;65S<V%G
M97,`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I
M<R!R96%D>2X`07!P;'D@1FEL=&5R<P!!<'!L>2!&:6QT97)S('1O("5S`$%P
M<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_`$%P<&QY(&9I;'1E
M<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`
M07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI
M=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@
M<'5B;&EC(&ME>3\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y
M;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H
M97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.
M14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE
M<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@
M;65S<V%G92!A<R!I;FYO8V5N=#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\`07)M96YI86X@*$%235-#
M24DM."D`07)R:79A;"!4:6UE`$%R=`!!<V-E;F1I;F<`07-K`$%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T86-H`$%T=&%C:"!&:6QE<P!!
M='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M
M97-S86=E/P!!='1A8VAE9"!&:6QE.@!!='1A8VAE9"!F:6QE("(E<R(@97AC
M965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T
M86-H960N`$%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U
M97-T('EO=2!S96YT+@!!='1A8VAM96YT`$%T=&%C:&UE;G0@<W1R:7!P960Z
M($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP90!!='1A8VAM96YT<P!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD965S`$%T=&5N=&EO;@!!
M='1R:6)U=&5S`$%U9W5S=`!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@
M;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E
M<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W
M:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I
M<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]I;7`Z(%)E<75I
M<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U
M:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@
M4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&]M871I8V%L
M;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD
M97(@:7,@:6X@;7D@861D<F5S<V)O;VL_`$%V86EL86)L92!!9&1R97-S(&)O
M;VMS.@!!=F%I;&%B;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!"86-?
M:R!T;R`E<P!"86-K('1O("5S`$)A8VL@=&\@375L=&EP;&4@365S<V%G92!6
M:65W($EN9&5X`$)A8VL@=&\@5&AR96%D($1I<W!L87D`0F%C:V=R;W5N9`!"
M86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME
M<F)E<F]S('5S97)N86UE+@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"87-E;&EN
M90!"8V,`0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF
M;W)M871I;VX@;65S<V%G92X`0FQA8VML:7-T`$)L;V-K("(E<R(@;V8@87!P
M;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K
M(%1Y<&4`0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H
M97D@87)E('-P96-I9FEC86QL>2!R97%U97-T960_`$)O9'D`0F]L9`!";V]K
M;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]T:`!"
M;W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4`0F]T=&]M
M`$)U;&QE=&5D($QI<W0`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<P!#7V5L;"!0<F]P97)T:65S+BXN`$-?:&%R<V5T`$-A;&5N9&%R`$-A;&T`
M0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N`$-A
M;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B``0V%N
M(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O9B!T
M:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@;6%I;&)O>"X`0V%N(&YO="!R
M97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E
M<R(N`$-A;F-E;`!#86YC96P@365S<V%G90!#86YC96P@4')O8FQE;2!297!O
M<G0`0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D
M:7-C87)D(&ET<R!C;VYT96YT<RX`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S
M=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V,`
M0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL
M('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)
M4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y
M+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`
M0V5R=&EF:6-A=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L
M;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+@!#:&%I<B!097)S
M;VX`0VAA;F=E`$-H86YG92!!;&P`0VAA;F=E($9O;&1E<@!#:&%N9V4@66]U
M<B!087-S=V]R9`!#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W
M(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD(&AO=R!M
M97-S86=E<R!A<F4@<V]R=&5D+@!#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O
M;&1E<B!S971T:6YG<RX`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B!E;6%I;',N`$-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA
M='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@96UA:6PN`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&%R86-T97)S('1O
M(&1I<W!L87DZ`$-H96-?:R!,:6YK+BXN`$-H96-K($9O;&1E<BAS*2!F;W(@
M3F5W($UA:6P`0VAE8VL@7T%L;"].;VYE`$-H96-K(&%L;"!M86EL('-E<G9E
M<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.@!#:&5C:R!S<&5L;&EN
M9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_`$-H:6QE`$-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#
M:&]O<V4@06-T:6]N.@!#:&]O<V4@82!M86EL('-E<G9E<CH`0VAO;W-E(&$@
M;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z`$-H;V]S
M92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I
M;VXZ`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D
M<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N`$-H;V]S
M92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E
M>'!A;F1I;F<@861D<F5S<V5S+@!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@
M=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@)7,@
M=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@
M8G)O=W-E<B!C86X@=FEE=RX`0VQI8VL@)7,@=&\@9&]W;FQO860@=&AE(&EM
M86=E+@!#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M96YT('!A9V4N`$-L
M:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN
M9&]W+@!#;&EC:R`E<R!T;R!V:65W(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA
M9V4N`$-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A
M<F%T92!W:6YD;W<N`$-L:6-K("5S('1O('9I97<@=&AI<R!M=6QT:7!A<G0O
M<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R!H97)E
M('1O(%-(3U<@=&AE($EM86=E<P!#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE
M8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S
M('1O('-E87)C:"X`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VL@=&\@4V%V92!0
M1U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:P!#;&EC:R!T;R!3
M879E(%,O34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E<W,@
M0F]O:P!#;&EC:V%T96QL('9I82!(5%10`$-L:6-K:6YG(&]N('1H92!A9&1R
M97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(`
M0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E
M('1O(&)E(')E860`0VQO<V4`0VQO<V4@5VEN9&]W`$-L;W-E('1H:7,@=VEN
M9&]W`$-L;W-E9"!&;VQD97(`0VQO=61S`$-L;W5D>0!#;VQL87!S90!#;VQL
M87!S92!!;&P`0V]L;&%P<V4@06QL($9O;&1E<G,`0V]L;&%P<V4@1F]L9&5R
M`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L
M;W(@26YD:6-A=&]R.B``0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H
M96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M<&%N>0!#;VUP;&5T960`0V]M
M<&]S92!A;F]T:&5R(&UE<W-A9V4`0V]M<&]S92!M97-S86=E<R!I;B!A('-E
M<&%R871E('=I;F1O=S\`0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@
M1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE(&9E871U
M<F4I/P!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FEG=7)E(&AO=R!M
M97-S86=E<R!A<F4@9&ES<&QA>65D+@!#;VYF:6=U<F4@;6%I;"!P<F5V:65W
M(&]P=&EO;G,N`$-O;F9I<FT@4&%S<W=O<F0`0V]N;F5C=&EO;B!F86EL960N
M`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!#;VYN96-T:6]N('1O('-E<G9E<B!F
M86EL960`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1I;G5E`$-O;G1R;VP@4$=0
M('-U<'!O<G0@9F]R("5S+@!#;VYT<F]L(%,O34E-12!S=7!P;W)T(&9O<B`E
M<RX`0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L
M(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U('=H96X@:70@87)R
M:79E<RX`0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A
M;"!O;F5S/P!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W!Y('1O(&9O
M;&1E<@!#;W)R96-T`$-O<G)E8W1E9"!497AT`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U
M;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)
M344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T
M;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&-R96%T92!T:&4@
M5D93(&)A8VME;F0Z("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#
M;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H
M92!S97)V97(@<V%I9#H@)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!E>&5C=71E(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,N`$-O=6QD(&YO="!E>'1R86-T('1H92!R
M97%U97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N`$-O
M=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!:
M:7`@87)C:&EV92X`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@
M8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@
M9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S
M(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M.B`E<P!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`
M0W)E871E($9O;&1E<@!#<F5A=&4@2V5Y<P!#<F5A=&4@5FER='5A;"!&;VQD
M97(`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@4W!A;2!F;VQD97(`0W)E
M871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E871E(&$@;F5W(&]N90!#<F5A
M=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@82!N97<@=')A<V@@
M9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U
M<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@86YD(&1E
M;&5T92!S<&%M+@!#<F5A=&4@;F5W('-T871I;VYE<GD`0W)E871E('-T871I
M;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+@!#<F5A=&4@<W5B(&9O;&1E<G,`
M0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT
M(&%C8V5S<R!T;R`E<P!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y
M;&4`0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@
M;W1H97(@86-C;W5N=',N`$-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"X`
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`
M0W5T('-E;&5C=&EO;@!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`1$0`1&%I
M;'D`1&%T7V4`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`
M1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E
M8VEM86P@;G5M8F5R<P!$96-L:6YE9`!$96-L:6YE9#H@`$1E8W)E87-E($EN
M9&5N=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3
M:&5L;`!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN
M9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5G871E9`!$96QE=&4`1&5L
M971E("5S(%!U8FQI8R!+97D`1&5L971E($-U<G)E;G0@2V5Y<P!$96QE=&4@
M1F]L9&5R*',I`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE
M=&4@4V5L96-T960@1F]L9&5R<P!$96QE=&4@4W1A=&EO;F5R>0!$96QE=&4@
M5FER='5A;"!&;VQD97(`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4`1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO
M=&4@<V5R=F5R/P!$96QE=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E
M;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI
M<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE
M=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W!A;2!M
M97-S86=E<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@
M8W5R<F5N="!R;W<`1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T960@
M=&AE(&%T=&%C:&UE;G0@(B5S(BX`1&5L971I;F<@86YD($UO=FEN9R!-97-S
M86=E<P!$96QI=F5R>2!T:6UE`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@
M9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;@!$97-C96YD:6YG`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',`1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I
M;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:6T@
M<VEG;F%T=7)E<S\`1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N
M(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!C;VYF:7)M871I
M;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_`$1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA
M=`!$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G90!$:7-P;&%Y('!O<"UU<"!N
M;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_`$1I<W!L87D@=&AE(")%;7!T>2!3
M<&%M(B!L:6YK(&EN('1H92!M96YU8F%R/P!$:7-P;&%Y('1H92`B16UP='D@
M5')A<V@B(&QI;FL@:6X@=&AE(&UE;G5B87(_`$1I<W!O<VET:6]N`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$;R!.3U0@;6%T8V@`1&\@3F]T($-H96-K
M($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1E;&5T90!$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!N;W0@9V5N97)A
M=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6X`1&\@>6]U('=A;G0@=&\@
M;W!E;B!T:&%T(&9O;&1E<C\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@
M=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VXG
M="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O;F4`1&]W;FQO860`1&]W
M;FQO860@)7,`1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870`1&]W;FQO860@
M06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I`$1O=VYL;V%D($9O;&1E
M<BAS*0!$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T70!$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$;W=N
M;&]A9"!I;B`N>FEP($9O<FUA=`!$<F%F=`!$<F%F="!F;VQD97(`1')A9G1S
M(&9O;&1E<CH`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$4M;6%I;"!!
M9&1R97-S`$5.1`!%4E(`15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@
M8F4@9&5L:79E<F5D+@!%9&ET`$5D:70@0FQA8VML:7-T`$5D:70@0FQO8VL`
M161I="!&:6QT97)S`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@
M4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!6:7)T
M=6%L($9O;&1E<@!%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R
M("5S`$5D:70@5VAI=&5L:7-T`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I
M="!Y;W5R(&)L86-K;&ES=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D:70@
M>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C
M;W5N=',N`$5D:70@>6]U<B!W:&ET96QI<W0`161U8V%T:6]N`$5L96UE;G0N
M+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M
M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N`$5M<'1Y($9O;&1E<BAS*0!%
M;7!T>2!396QE8W1E9"!&;VQD97)S`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T
M>2!?4W!A;0!%;7!T>2!?5')A<V@`16UP='D@;65S<V%G92X`16UP='D@<F5S
M=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(%!'4"!F=6YC=&EO;F%L
M:71Y/P!%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!M97-S86=E('!R979I97=S/P!%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/P!%;F-R7WEP=&EO;B!/<'1I;VYS`$5N9`!%;F0@9F]R
M=V%R9&5D(&UE<W-A9V4`16YD(&UE<W-A9V4`16YD(&UE<W-A9V4@9G)O;2`E
M<P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!087-S<&AR87-E`$5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P86T@
M9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L
M9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L
M9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(`
M16YT<GD@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R
M97-S(&)O;VL`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R
M(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N
M`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N`$5T:&YI8P!%=7)O<&4`179E;G0@<W5C8V5S<V9U;&QY(&1E
M;&5T960N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y
M(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y
M(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U
M=&4`17AP86YD`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N
M9"!&;VQD97(`17AP86YD($YA;65S`$5X<&%N9"!3:61E8F%R`$5X<&%N9"!N
M86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T
M:&4@8F%C:V=R;W5N9#\`17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@
M8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/P!%>'!A;F1I;F<`17AP
M96-T960@)RDG`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&
M5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O
M;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E
M<R(N`$9A:7(`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&971C:"!-86EL
M`$9E=&-H($UA:6P@:6X@82!S97!A<F%T92!W:6YD;W<_`$9E=&-H(&UE<W-A
M9V5S('5P;VX@;&]G9VEN9R!O;C\`1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M
M("5S`$9E=&-H960@,2!M97-S86=E(&9R;VT@)7,`1F5T8VAM86EL.B``1F5T
M8VAM86EL.B!N;R!N97<@;65S<V%G97,N`$9E=R!3:&]W97)S`$9E=R!3;F]W
M(%-H;W=E<G,`1FE?;'1E<G,`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I
M;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL
M92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N`$9I;'1E<B!/<'1I;VYS`$9I;'1E<B!3971T:6YG<P!&:6QT97(@
M;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_`$9I;'1E<B!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!&:6QT97)S`$9I;'1E<G,@
M3D]4($%C=&EV90!&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4`1FEN9`!&
M:7)S="!(86QF`$9I<G-T($UA:6QB;W@@4&%G90!&:7)S="!086=E`$9I<G-T
M(%%U87)T97(`1FEX(')A=&EO`$9L;V%T`$9O7W)W87)D`$9O9P!&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0`1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I
M;VX`1F]L9&5R($YA=FEG871O<@!&;VQD97(@4W5M;6%R>0!&;VQD97(@<VAA
M<FEN9R!I<R!N;W0@96YA8FQE9"X`1F]L9&5R('5S92!I<R!N;W0@96YA8FQE
M9"X`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U
M<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F=O="!Y;W5R('!A<W-W
M;W)D/P!&;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I;&)O>"!V
M:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A>0!&;W)M<P!&;W)T=6YE`$9O
M<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D
M`$9O<G=A<F0Z`$9O<G=A<F1E9"!M97-S86=E`$9O<G=A<F1E9"!M97-S86=E
M(&9R;VT@)7,`1F]R=V%R9',`1G(`1G)A;65S`$9R964O0G5S>2!);F9O<FUA
M=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`1G)E92]"
M=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)O7VT`1G)O;0!&<F]M($%D9')E<W,`
M1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M
M90!&=V0Z`$9W9#H@`$9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S`$=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=E;F5R86P@3W!T:6]N
M<P!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E
M="!O;FQY(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2D`1VEV96X@3F%M90!'
M;R!T;R!-97-S86=E`$=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B`B)7,B
M`$=O;V=L92!396%R8V@`1W)A;G0@86-C97-S`$=R87ES8V%L90!'<F5E:R`H
M25-/+3@X-3DM-RD`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='D`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U
M97-T8F]O:P!(15)%`$A434P`2%1-3"!697)S:6]N(&]F($UE<W-A9V4`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%S:"U!;&=O<FET:&T`2&%Z
M90!(96%D97(`2&5A9&5R<P!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT
M`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R
M92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(97)E(&ES('1H92!M
M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SH`2&ED9&5N`$AI9&1E;B!I;B!4
M:')E860@5FEE=P!(:61E($1E;&5T960`2&ED92!5;G-U8G-C<FEB960`2&EG
M:`!(:6=H(%!R:6]R:71Y`$AI9VAE<W0`2&]?;64`2&]M90!(;VUE($%D9')E
M<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;W)D90!(;W)D92]+;VQA
M8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E
M("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U
M;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U
M(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!D;R!Y;W4@=V%N="!T
M;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/P!(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\`2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R97!L
M>0!(=6UI9&ET>0!(=6UI9&ET>3H@`$E-05``24U!4"`H075T;R!$971E8W0@
M4')O=&]C;VQS*0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&]V97(@4U-,`$E-05`@
M;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*0!)34%0(&]V97(@
M4U-,("AS96QF+7-I9VYE9"D`24U!4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL
M(%-E<G9E<G,`24Y"3U@`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO
M8VLN`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E
M<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N`$EF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H
M92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(0!)9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N
M8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE
M(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@
M8GD@>6]U<B!B<F]W<V5R+@!)9VYO<F4`26=N;W)E($%L;`!);6%G90!);6%G
M92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A
M;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S
M`$EM<&]R=`!);7!O<G0@2V5Y`$EM<&]R="!+97EP86ER`$EM<&]R="!-97-S
M86=E<P!);7!O<G0@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A
M=&4`26UP;W)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>0!);7!O<G0@4&5R
M<V]N86P@4'5B;&EC(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L(%,O34E-12!#
M97)T:69I8V%T97,`26UP;W)T(%!U8FQI8R!+97D`26UP;W)T(%!U8FQI8R!0
M1U`@2V5Y`$EM<&]R="!0=6)L:6,@4R]-24U%($ME>0!);7!O<G0@4R]-24U%
M($ME>0!);7!O<G0@;6)O>"!&:6QE`$EM<&]R="!M8F]X(&9I;&4@)7,@:6YT
M;R!F;VQD97(@)7,N`$EM<&]R="P@4W1E<"`E9`!);7!O<G1A;G0`26UP;W)T
M86YT(&UE<W-A9V5S`$EM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@)7,N`$EM
M<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`
M26Y?<V5R="!2;W<@069T97(`26YB;W@`26YC;'5D92!A(&)R:65F('-U;6UA
M<GD@;V8@=&AE(&AE861E<B!I;B!A(')E<&QY/P!);F-L=61E(&]R:6=I;F%L
M(&UE<W-A9V4@:6X@82!R97!L>3\`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I=FED=6%L(%5S97)S
M`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL
M86)L92X`26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>0!);F9O<FUA=&EO
M;B!O;B!097)S;VYA;"!0<FEV871E($ME>0!);F9O<FUA=&EO;B!O;B!097)S
M;VYA;"!0=6)L:6,@2V5Y`$EN;&EN90!);G-E<G0@0U]O;'5M;B!!9G1E<@!)
M;G-E<G0@0V5R=&EF:6-A=&4@2&5R90!);G-E<G0@26UA9V4`26YS97)T(%!E
M<G-O;F%L(%!R:79A=&4@4$=0($ME>2!(97)E`$EN<V5R="!097)S;VYA;"!0
M=6)L:6,@4$=0($ME>2!(97)E`$EN<V5R="!0=6)L:6,@4$=0($ME>2!(97)E
M`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@
M0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL
M(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R
M`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@
M<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R
M="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U
M:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O
M36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@
M8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U
M9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED
M($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN=F%L:60@
M061D<F5S<P!);G9A;&ED(%)E;6]T92!-86EL8F]X`$EN=F%L:60@541(+B`H
M57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L
M:60@8F%T8V@@240N`$EN=F%L:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R
M97-S.B`E<RX`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M:V5Y`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E
M(&ME>2X`26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`26YV86QI
M9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S
M:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U
M;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0`26YV97)T('-E;&5C=&EO
M;@!)<V]L871E9"!4+5-T;W)M<P!)<W-U97(`271A;&EC`$IA;G5A<GD`2F%P
M86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2G5L>0!*=6YE`$IU<W1I9GD`
M2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T
M:69Y(%)I9VAT`$M"`$ME97`@;W)I9VEN86P_`$ME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG
M97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$ME>2!I;7!O
M<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L
M960@;VX@=&AI<R!S97)V97(N`$ME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L
M92X@66]U(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO
M=7(@8V]N=&%C=',N`$ME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`2VED<P!+;W)E86X@*$550RU+4BD`3&%?>6]U=`!,
M86YG=6%G90!,87-T($AA;&8`3&%S="!-86EL8F]X(%!A9V4`3&%S="!086=E
M`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T
M960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S
M="!L;V=I;CH@3F5V97(`3&%W`$QA>6]U=`!,969T`$QE9G0@:&5A9&5R`$QE
M9G0@=F%L=65S`$QI7VYK($%T=&%C:&UE;G1S`$QI9VAT($1R:7IZ;&4`3&EG
M:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H
M="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3
M;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI
M;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N
M(&1I<W!L87EI;F<`3&EN:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B:61D96XN
M`$QI;FMS`$QI;FMS('=I;&P@97AP:7)E(&]N("5S`$QI;G5X($-O;VMI90!,
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`
M3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T(&%L;"!C;VYT86-T
M<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B
M;&5D+"!Y;W4@=VEL;"!O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R
M8V@@9F]R(&5X<&QI8VET;'DI`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES
M="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T
M+55N<W5B<V-R:6)E`$QI<W1I;F<@:6X@=&AE($AE861E<@!,:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QO861I;F<N+BX`3&]C86P@
M36%I;&)O>#H`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO
M;@!,;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S
M:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,
M;VYG('1E>'0`3&]V90!,;W<`3&]W(%!R:6]R:71Y`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$QO=V5S=`!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82X`35-'`$UA8VEN=&]S:"!&:6QE`$UA9VEC`$UA:6P`36%I;"!!
M9&UI;@!-86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C
M="!T;SH`36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I
M;VYS`$UA:V4@;&EN7VLN+BX`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!!;&P@365S<V%G97,@:6X@
M1F]L9&5R(&%S(%-E96X`36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S
M(%5N<V5E;@!-87)K(&%S.@!-87)K(&1I9F9E<F5N="!L979E;',@;V8@<75O
M=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA<FL@;65S<V%G97,@87,@
M<V5E;C\@*$E-05`@;VYL>2D`36%R:R!S:6UP;&4@;6%R:W5P/P!-87)K('=I
M=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%T8V@@06QL(%%U97)I97,`36%T
M8V@@06YY(%%U97)Y`$UA=&-H:6YG(&9I96QD<P!-87@@86QL;W=E9"!C<F5D
M:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!!
M='1A8VAM96YT(%-I>F4`36%X:6UU;2!.=6UB97(@;V8@1F]L9&5R<P!-87AI
M;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C
M:&5D+@!-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+@!-
M87D`365D:6-I;F4`365E=&EN9R!#86YC96QL871I;VX`365E=&EN9R!);F9O
M<FUA=&EO;@!-965T:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P;'D`365E=&EN
M9R!5<&1A=&4`365E=&EN9R!5<&1A=&4@4F5Q=65S=`!-96UB97)S`$UE;G4@
M1F]L9&5R($QI<W0`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE
M<W-A9V4@0V]M<&]S:71I;VX`365S<V%G92!$871E`$UE<W-A9V4@3W!T:6]N
M<P!-97-S86=E(%-E87)C:`!-97-S86=E(%-I>F4`365S<V%G92!3;W5R8V4`
M365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G
M<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@
M5FEE=VEN9P!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@9FQA9W,`365S<V%G
M92!F;VQD97)S`$UE<W-A9V4@9G)O;2`E<P!-97-S86=E(&AA<R!A='1A8VAM
M96YT<P!-97-S86=E(&ES(&5N8W)Y<'1E9`!-97-S86=E(&ES('-I9VYE9`!-
M97-S86=E(&UA=&-H97,`365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL
M>2X`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T
M;R`E<P!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+@!-97-S86=E('1Y<&4`
M365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G
M97,@=&\`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC
M`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI
M<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@
M;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S
M:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE
M($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD`36]D:69Y(%52
M3`!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;VX@4&AA<V5S`$UO<W1L>2!#
M;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W
M;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E
M('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE
M<W-A9V5S('1O($E.0D]8`$UO=F4@=&\@9F]L9&5R`$UO=F4@=7``375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I<&%R="]A;'1E<FYA=&EV90!-
M=6QT:7!L92!-97-S86=E(%9I97<`375L=&EP;&4@<V5L96-T:6]N`$UY($%C
M8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R
M=&%L($QA>6]U=`!.3RP@22!$;R!.3U0@06=R964`3D]410!.86UE`$YA;64@
M86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='D`3F5E9',@06-T:6]N`$YE
M='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE
M='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T
M<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`
M3F5V97(@<V%V92!A='1A8VAM96YT<P!.97<`3F5W($-A=&5G;W)Y`$YE=R!&
M;VQD97(`3F5W($UA:6P`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA
M;"D`3F5W(&UE<W-A9V5S`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE
M=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!-
M97-S86=E`$YE>'0@4&%G90!.97AT(&]P=&EO;G,`3FEG:'0`3F\`3F\@0V5R
M=&EF:6-A=&4@9F]U;F0`3F\@16YC<GEP=&EO;@!.;R!+97ES(&EN($ME>7)I
M;F<`3F\@365S<V%G97,`3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N`$YO
M(%!E<G-O;F%L($-E<G1I9FEC871E(%!R97-E;G0`3F\@4')E=FEE=R!497AT
M`$YO(%!U8FQI8R!+97ES($9O=6YD`$YO(%,O34E-12!P=6)L:6,@:V5Y(&EM
M<&]R=&5D+@!.;R!A='1A8VAM96YT<R!F;W5N9"X`3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@
M8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!F;VQD97(@<V5L96-T960N
M`$YO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M86EL+@!.
M;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&9O;&1E<G,@=VET:"!N97<@
M;65S<V%G97,`3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<P!.;R!I
M8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E(&)O
M9'D@=&5X=`!.;R!M97-S86=E('-U<'!L:65D+@!.;R!M97-S86=E<R!M871C
M:&5D('EO=7(@<V5A<F-H+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R
M('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN
M`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<&5R<V]N86P@4$=0('!R:79A=&4@
M:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O
M<G1E9"X`3F\@<&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!I;7!O<G1E
M9"X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`
M3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N`$YO('-P96QL
M:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N<P!.;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97(@<W!E8VEF:65D+@!.
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`3F]N
M90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO
M<FUA;`!.;W)T:&5R;B!(96UI<W!H97)E`$YO="!!9G1E<@!.;W0@0F5F;W)E
M`$YO="!$96QE=&5D`$YO="!$<F%F=`!.;W0@26UP;W)T86YT`$YO="!097)S
M;VYA;`!.;W0@82!D:7)E8W1O<GD`3F]T(&$@=F%L:60@<'5B;&EC(&ME>2X`
M3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&QE;65N=&5D+@!.;W0@:6UP
M;W)T86YT(&UE<W-A9V5S`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T92!T
M:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE`$YO=&5S`$YO=&AI;F<`3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB
M97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@
M;6]N=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE
M=&EN9R!M;VYT:&QY+@!.=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S
M('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F(')O=W,`
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="X`3TL`3U(`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L
M`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A
M<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD(&UE<W-A9V5S`$]L9"!P
M87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]N;'D@24U!4"!S97)V97)S
M('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@9&ES<&QA>2!F;VQD97)S
M('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_`$]N;'D@;V9F96YS:79E
M(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL
M>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I
M;VXN`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A
M('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96YE9"!&;VQD97(`3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M
M`$]P=&EO;F%L(%!A<G1I8VEP86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`
M3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET
M`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO
M;@!/=&AE<B!-86EL($%C8V]U;G1S`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R
M;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%!'4`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'0@365S<V%G
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0($5R<F]R.B``4$=0($5R<F]R.B!.
M965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!01U`@
M3W!T:6]N<P!01U`@4&%S<W!H<F%S92!);G!U=`!01U`@4&5R<V]N86P@2V5Y
M<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+@!01U`@4'5B;&EC($ME>0!01U`@4'5B;&EC($ME>2!497AT`%!'4"!0=6)L
M:6,@2V5Y(&9O<B`B)7,@*"5S*2(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"X`
M4$=0(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE
M=&5D+@!01U`@4'5B;&EC($ME>7)I;F<`4$=0(%-I9VX@365S<V%G90!01U`@
M4VEG;B]%;F-R>7!T($UE<W-A9V4`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M80!01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@<'5B
M;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N`%!'4"!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R
M<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA
M8FQE('1O(&)E('9E<FEF:65D+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C
M<GEP=&5D+@!01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O
M(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T
M;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES
M('-E='1I;F<@;W(@96QS92!T:&4@4$=0(&9E871U<F5S('=I;&P@;F]T('=O
M<FL@8V]R<F5C=&QY+@!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I
M;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%0M4W1O
M<FUS`%!/4#,`4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*0!03U`S(&]V
M97(@4U-,`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E
M*0!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"D`4$]0,RP@;F\@5$Q3`%!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!0
M86=E("5D(&]F("5D`%!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A
M9V4`4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E`%!A<G0H<RD`
M4&%R=&QY($-L;W5D>0!087-S<&AR87-E`%!A<W-P:')A<V4@*$%G86EN*0!0
M87-S<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"X`4&%S<W!H<F%S93H`
M4&%S<W!H<F%S97,@8V%N(&YO="!B92!E;7!T>0!087-S<&AR87-E<R!D;R!N
M;W0@;6%T8V@`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@
M4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C
M:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I
M9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!0
M97)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)M:7-S
M:6]N<R!F;W(@=&AI<R!U<V5R(&-A;B!N;W0@8F4@8VAA;F=E9"X`4&5R<V]N
M86P`4&5R<V]N86P@26YF;W)M871I;VX`4&5R<V]N86P@4$=0(&ME>7!A:7(@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4&5R<V]N86P@4$=0(&ME>7,@9&5L
M971E9"!S=6-C97-S9G5L;'DN`%!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T
M97,@3D]4(&EM<&]R=&5D.B``4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E
M9"!S=6-C97-S9G5L;'DN`%!E=',`4&AO;F4`4&AO=&]S`%!I>&5L<P!0;&%C
M92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_
M`%!L86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4`4&QA>2!S;W5N9"!O;B!N
M97<@;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O
M<G0@96UB961D960@<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I
M;F1O=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL(')E<75I
M<F4@82!P;'5G:6XN`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE
M;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H
M:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!E;G1E<B!T:&4@
M;F%M92!O9B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N97<@
M;F%M93H`4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'
M4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N=&5R('1H
M:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A<V4@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y
M+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P87-S<&AR87-E
M(&]N8V4@<&5R("5S('-E<W-I;VXN`%!L96%S92!L;V<@:6X@86=A:6X@=&\@
M<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4
M('5S:6YG(&-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S
M(&EN('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@;&]G(&EN(&%G
M86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K
M965P(&%T=&%C:V5R<R!F<F]M(&AI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N
M(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N`%!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I
M9&4@>6]U<B!P87-S=V]R9"X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M92!A;F0@<&%S<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92X`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E
M<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+@!0;&5A<V4@
M<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E
M;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('-E
M;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N
M`%!L96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N
M`%!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N
M`%!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A
M=&EO;BX`4&QE87-E('-E;&5C="!O<B!E9&ET(&EN('1H92!B;W@@=&\@=&AE
M(')I9VAT.@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O
M;&ET:6-S`%!O;&QS`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"D`4&]W97)E9"!B>2!(;W)D90!0<F5C961E('EO
M=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_`%!R96-I<&ET871I
M;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969E<F5N8V5S('-U8V-E<W-F
M=6QL>2!U<&1A=&5D+@!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@
M<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!-97-S86=E`%!R979I;W5S
M(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0<FEN=`!0<FEN="!D;V-U;65N=`!0
M<FEO<FET>0!0<FEV871E($ME>0!0<FEV871E($ME>2!087-S=V]R9`!0<F]B
M;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T(&5V97)Y
M('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/`%!R
M;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L
M="!T;R!915,`4')O;7!T('1E>'0`4')O=&]C;VPZ`%!U8FQI8R!+97D`4'5B
M;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R
M="!H87,@8F5E;B!D:7-A8FQE9"X`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5R7V=E($1E;&5T960`4'5R
M9V4@1&5L971E9`!0=7)G92!&;VQD97(H<RD`4'5R9V4@5')A<V@@:&]W(&]F
M=&5N.@!0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA
M;B!T:&ES(&%M;W5N="!O9B!D87ES+@!0=7)G92!O;&0@;65S<V%G97,@:6X@
M=&AE(%1R87-H(&9O;&1E<C\`4'5R9VEN9R`E9"!M97-S86=E<R!F<F]M(%1R
M87-H(&9O;&1E<BX`4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD
M97(N`%%U97)Y`%%U;W1A`%%U;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"
M("`H)2XR9B4E*0!1=6]T82!S=&%T=7,Z("4N,F9-0B`O($Y/($Q)34E4`%%U
M;W1A('-T871U<SH@3D\@3$E-250`475O=&EN9R`E9CH`4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!2
M86EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N
M;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5?<75E<W0@1&5L:79E<GD@0V]N
M9FER;6%T:6]N`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5C96EV960@3VX`4F5C96EV960@4VEN8V4`4F5C
M96EV960@56YT:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T($UE<W-A
M9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE9"X`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!&;VQD97(@5FEE=W,Z`%)E9G)E
M<V@@4&]R=&%L(%9I97<Z`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!2
M96QO860@5FEE=P!296UA<FMS`%)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E($UA:6QB
M;W@Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!&
M:65L9"!&<F]M(%-E87)C:`!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T
M:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@<V]U<F-E`%)E;6]V
M92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO
M=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5N86UE($9O;&1E<BAS*0!296YA
M;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_`%)E
M;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`4F5P;%]Y('1O($QI<W0`4F5P;&%C92!W:71H.@!297!L
M>0!297!L>2!396YT+@!297!L>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L
M>2!T;R!,:7-T`%)E<&QY('1O($QI<W0Z`%)E<&QY('1O(%]!;&P`4F5P;'D@
M=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U
M<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DM5&\`4F5P;'DM5&\Z(`!297!L
M>3H`4F5P;W)T(&%S($EN;F]C96YT`%)E<&]R="!A<R!3<&%M`%)E<75E<W0@
M82!?4F5A9"!296-E:7!T`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N
M(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W0@9&5L:79E<GD@8V]N9FER
M;6%T:6]N/P!297%U97-T(')E860@<F5C96EP=',_`%)E<75E<W1E9"!M97-S
M86=E(&YO="!F;W5N9"X`4F5Q=6ER960@1FEE;&0`4F5Q=6ER960@4&%R=&EC
M:7!A;G0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R
M9`!297-P;VYD96YT(%-T871U<R!5<&1A=&5D+@!297-U;'1S`%)E<W5M90!2
M97-U;64@>6]U<B!S97-S:6]N`%)E='5R;B!T;R`B365S<V%G92!#;VUP;W-I
M=&EO;B(`4F5T=7)N('1O($9E=&-H($UA:6P`4F5T=7)N('1O($]P=&EO;G,`
M4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L
M(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%)E='EP92!N97<@<&%S
M<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG
M:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O=&%T92`Q.#``
M4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P
M<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'D`4G5N`%,O34E-10!3+TU)344@16YC<GEP="!-97-S86=E`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!3+TU)344@17)R;W(Z(`!3+TU)344@
M17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K
M97DN`%,O34E-12!/<'1I;VYS`%,O34E-12!087-S<&AR87-E($EN<'5T`%,O
M34E-12!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN`%,O34E-12!0=6)L:6,@2V5Y(&9O<B`B)7,B
M('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"X`4R]-24U%(%!U8FQI8R!+97D@
M<W5C8V5S<V9U;&QY(&%D9&5D+@!3+TU)344@4'5B;&EC($ME>7)I;F<`4R]-
M24U%(%!U8FQI8R]0<FEV871E($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D
M+@!3+TU)344@4VEG;B!-97-S86=E`%,O34E-12!3:6=N+T5N8W)Y<'0@365S
M<V%G90!3+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E
M;2X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O
M('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N`%,O34E-
M12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT96YT<R!O9B!T
M:&ES('-I9VYE9"!M97-S86=E(&-A;B!N;W0@8F4@9&ES<&QA>65D+@!3+TU)
M344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N
M871U<F4@:7,@=6YA8FQE('1O(&)E('9E<FEF:65D+@!3+TU)344@<W5P<&]R
M="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R
M(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I
M;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T
M:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+@!3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S
M86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4U]U8FIE
M8W0`4V$`4V%?=F4@82!C;W!Y(&EN(`!385]V92!A<P!386UE(&9R86UE("A?
M<V5L9BD`4V%V90!3879E("5S`%-A=F4@071T86-H;65N=',@=VET:"!M97-S
M86=E(&EN('-E;G0M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`4V%V92!);6%G
M90!3879E($EM86=E(&EN($=A;&QE<GD`4V%V92!/<'1I;VYS`%-A=F4@4W1A
M=&EO;F5R>0!3879E(%]$<F%F=`!3879E(&%S`%-A=F4@9')A9G1S(&%S('5N
M<V5E;C\`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E(')E8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A
M9&1R97-S(&)O;VL_`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_
M`%-A=F4@<V5N="!M86EL/P!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879I
M;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@)7,`4V-I96YC90!396%R8V@`4V5A<F-H("5S`%-E87)C:"!%;F=I
M;F5S`%-E87)C:"!297-U;'1S`%-E96X`4V5L96-T`%-E;&5C="!!;F]T:&5R
M($%C8V]U;G0`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@
M9FEE;&0`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE
M<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@<W1A=&EO;F5R>3H`4V5L96-T
M(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O
M<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+@!396QE8W0@
M86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86QL(&9I
M96QD<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+@!396QE
M8W0@86X@86-C;W5N=`!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V
M92!T:&4@:6UA9V4@:6XN`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.@!396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4`4V5L96-T
M('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396QE
M8W1E9"!!9&1R97-S(&)O;VMS.@!396YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R
M=F5R`%-E;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E;F0@365S<V%G90!396YD
M(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F0@<F5A9"!R96-E:7!T('=H
M96X@<F5Q=65S=&5D(&)Y('1H92!S96YD97(_`%-E;G-O<CH@`%-E;G0@;6%I
M;"!F;VQD97(`4V5N="!M86EL(&9O;&1E<CH`4V5P=&5M8F5R`%-E<FEA;"!.
M=6UB97(`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N`%-E
M<G9E<CH`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+@!3970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W
M:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N`%-E="!T:&4@6"U0
M<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-H87)E($9O;&1E<G,`4VAA<F4@;6%I;"!F
M;VQD97)S`%-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E
M<G,N`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W5L9"!L87)G92!B;&]C
M:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U
M;'0_($ET(&-A;B!B92!T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H
M;V]S92X`4VAO=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@
M8F4@<V-A;FYE9"!F;W(@4$=0(&1A=&$_`%-H;W5L9"!T:&4@8V]M<&]S92!W
M:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/P!3:&]U;&0@
M>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE
M<W-A9V5S(&)Y(&1E9F%U;'0_`%-H;W<`4VAO=R!!;&P@1F]L9&5R<P!3:&]W
M($%L;"!(96%D97)S`%-H;W<@1&5L971E9`!3:&]W($QI;6ET960@2&5A9&5R
M<P!3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;@!3:&]W($]N;'D@4W5B
M<V-R:6)E9"!&;VQD97)S`%-H;W<@56YS=6)S8W)I8F5D`%-H;W<@86X@:6-O
M;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S
M86=E<S\`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E
M9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W
M(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;&5G96YD
M(&EN('1H92!M86EL8F]X('9I97<_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I
M9VEN86P`4VAO=R!P:6-K97(`4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE
M<W-A9V5S(&]N;'D_`%-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_`%-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H92!M
M96YU8F%R/P!3:&]W('1H92!);6%G97,`4VAO=R!T:&4@5&%B;&4@0V5L;"!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&]T86P@;G5M8F5R(&]F(&UA
M:6QS(&EN(&9O;&1E<C\`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A
M<FQY`%-H;W=E<G,@3&%T90!3:&]W;@!3:')I;FL`4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I
M7WIE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEG
M;F5D`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;F]W`%-N;W<@4VAO=V5R`%-N
M;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA
M=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O
M;F=S("8@4&]E;7,`4V]R="!B>2!!<G)I=F%L`%-O<G0@8GD@1&%T90!3;W)T
M(&)Y($9R;VT@061D<F5S<P!3;W)T(&)Y($UE<W-A9V4@4VEZ90!3;W)T(&)Y
M(%-U8FIE8W0`4V]R="!B>2!4:')E860`4V]R="!B>2!4;R!!9&1R97-S`%-O
M<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($5U<F]P
M96%N("A)4T\M.#@U.2TS*0!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P
M861D:6YG`%-P86T`4W!A;2!F;VQD97(Z`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5C:6%L(%9I<G1U86P@1F]L9&5R
M<R!C86X@;F]T(&)E(&5D:71E9"X`4W!E;&P@0VAE8VL`4W!E;&P@0VAE8VME
M<@!3<&5L;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C
M<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+@!3<&QI="!C96QL`%-P;&ET(&-O
M;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-T86YD87)D`%-T87(@5')E:P!3=&%R
M=`!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871I;VYE<GD`4W1A
M=&EO;F5R>2!N86UE.@!3=&%T:6]N97)Y('1Y<&4Z`%-T871I;VYE<GDZ`%-T
M871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I;F<@;&ES
M=`!3=')I<"!!='1A8VAM96YT`%-T<FEP(&QI;F5B<F5A:W,_`%-T>6QE(%M#
M4U-=`%-U`%-U8E]J96-T`%-U8FIE8W0`4W5B:F5C="!&:65L9`!3=6)M:70`
M4W5B<V-R:6)E('1O($9O;&1E<BAS*0!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C
M8V5S<V9U;&QY('=R;W1E("5S`%-U9V=E<W1I;VYS`%-U;6UA<GD`4W5N(%)I
M<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I
M<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)N
M86UE`%-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0`4W=I=&-H('1O($A434P@
M8V]M<&]S:71I;VX`4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I;VX`
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!4+5-T;W)M`%0M4W1O<FUS
M`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R
M=&EE<P!487)G970Z`%1A<VMS`%1E7WAT`%1E;&5P:&]N92!.=6UB97(`5&5M
M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!4
M96UP;&%T92!!9&UI;FES=')A=&EO;@!496YT871I=F4Z(`!496YT871I=F5L
M>2!!8V-E<'0@<F5Q=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497)M<R!O
M9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<`!497AT
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R
M,"D`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@1G)O;3H@8V]L=6UN(&]F
M('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z`%1H92!-86EN=&5N86YC
M93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A8V-O=6YT("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E
M;B!S879E9"X`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E
M(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@
M=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@871T86-H;65N="!W87,@;F]T(&9O
M=6YD+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V%L96YD87(@9&%T82!I
M<R!I;G9A;&ED`%1H92!C;VUP;W-E('=I;F1O=R!C86XG="!B92!O<&5N960N
M(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B;&]C:R!P
M;W!U<"!W:6YD;W=S/P!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!C;VYT96YT<R!O9B!T:&4@36%C
M:6YT;W-H(&9I;&4@87)E(&)E;&]W+@!4:&4@8W5R<F5N="!F;VQD97(H<RD@
M(B5S(B!W:6QL(&)E(')E;F%M960@=&\@(B5S(BX`5&AE(&-U<G)E;G0@;&ES
M="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N
M;W0@8F4@<F5T<FEE=F5D`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L
M;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N
M`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4
M:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE("(E<R(@9F]L9&5R+@!4
M:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+@!4:&4@979E;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L96YD
M87(N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`
M5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L9&5R("(E<R(@86QR96%D
M>2!E>&ES=',`5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL;&5G86P@8VAA
M<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E('!R;V)L96US+B!0
M;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!F;VQD
M97(@(B5S(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB
M960@=&\@:70N`%1H92!F;VQD97(@(B5S(B!W87,@9&5L971E9"!B=70@>6]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@9F]L9&5R("(E
M<R(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@8W)E871E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S
M9G5L;'D@9&5L971E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L
M;'D@<F5N86UE9"!T;R`B)7,B+@!4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@
M871T86-H960@=&\@=&AI<R!P87)T.@!4:&4@9G5L;"!S8W)E96X@;6]D92!I
M<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO
M<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE
M('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O
M=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N
M97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4
M:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@:6UA9V4@
M<V%V92!W:6YD;W<@8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA
M=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/P!4
M:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E
M<B!I<R!P<F5S96YT(&EN('EO=7(@861D<F5S<V)O;VLN`%1H92!L969T+6AA
M;F0@<VED92!O;FQY`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O
M;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A
M=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.@!4:&4@
M;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93H`
M5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2X`5&AE(&UE<W-A9V4@
M(B5S(B!F<F]M("(E<R(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@
M;&EM:70N`%1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L
M;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"X`
M5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N`%1H92!M97-S86=E(&AA
M<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+@!4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L
M87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H
M87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F
M(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!P87-S<&AR87-E('=I;F1O
M=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@
M8G)O=W-E<B!T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/P!4:&4@<')E9F5R96YC
M92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M
M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U
M;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')A=R!T97AT(&]F('1H92!01U`@4'5B
M;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+@!4:&4@<F5Q=65S=&5D(&9I;&4@
M9&]E<R!N;W0@97AI<W0@:6X@=&AE($U3+51.148@871T86-H;65N="X`5&AE
M(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T
M86-H;65N="X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY`%1H92!S96YD97(@;V8@=&AI<R!M97-S86=E
M(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;B!F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E
M+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@;F]T:69I8V%T:6]N(&UE
M<W-A9V4N`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-E<G9E<B!W87,@;F]T
M(&%B;&4@=&\@8W)E871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N`%1H
M92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+@!4:&4@<VEG;F%T
M=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N`%1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!F
M:6QE(&1O97,@;F]T(&5X:7-T+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO
M="!E>&ES="X`5&AE('-T871I;VYE<GD@(B5S(B!H87,@8F5E;B!A9&1E9"X`
M5&AE('-T871I;VYE<GD@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<W1A
M=&EO;F5R>2`B)7,B(&AA<R!B965N('5P9&%T960N`%1H92!T87-K(&AA<R!B
M965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G
M90!4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4
M:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T
M:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X
M="!O9B!T:&4@<V5N="!M97-S86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE
M<W-A9V4@8V%N(&)E('9I97=E9"`E<RX`5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('5S97(G<R!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE('=E
M871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N
M;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+@!4:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!E
M>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@
M8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R
M92!W87,@86X@97)R;W(@8V]P>6EN9R!M97-S86=E<R!F<F]M("(E<R(@=&\@
M(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E
M<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&4@979E
M;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G
M97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I
M<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S
M(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A
M<R!A(&1R869T+@!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE
M<W-A9V4Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N
M=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI
M<R!M97-S86=E('!A<G0`5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E
M;6)E9&1E9"!I;B!I="X`5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E
M;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@=&AI
M<SH@`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N`%1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O
M('1H92!M97-S86=E+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4
M:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU
M<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@:7,@)7,N`%1H:7,@;6%Y('1A
M:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN
M=64_`%1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+@!4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B
M965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E
M(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R>7!T
M960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L
M:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B!T
M:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BX`5&AI<R!M97-S86=E(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@
M17)R;W(Z(`!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN
M('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R!21D,@,C`Q
M-2DN`%1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE
M(&-O<G)E8W0@4R]-24U%(&9O<FUA="X`5&AI<R!M97-S86=E(&AA<R!B965N
M(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"X`5&AI<R!M97-S86=E(&AA<R!B
M965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E
M(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@
M:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+@!4:&ES(&UE<W-A9V4@=&\`
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<`5&AR96%D($1I<W!L87D`5&AR96%D(%9I97<`5&AU;F1E<@!4:6-K
M971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C
M=&EO;@!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O($%D9')E<W,`5&\@
M<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92!C;&EC:VEN9RX`5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`
M5&]M;W)R;W<`5&]P`%1O<"!F<F%M92`H7W1O<"D`5&]T86P@071T86-H;65N
M=',@4VEZ93H`5')A;G-L871I;VYS`%1R87-H(&9O;&1E<@!4<F%S:"!F;VQD
M97(Z`%1R=64@;W(@9F%L<V4`5'4`5'5R:VES:"`H25-/+3@X-3DM.2D`5'EP
M92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),.@!5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@
M(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@
M9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I
M=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92X`56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L
M92!T;R!R971R:65V92!Q=6]T80!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+@!5;F%N<W=E<F5D`%5N86YS=V5R960@;65S<V%G97,`56YD96QE
M=&4`56YD97)L:6YE`%5N9&ES8VQO<V5D(%)E8VEP:65N=',`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N9&QE9"!C;VUP
M;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!$871E`%5N:VYO=VX@365E=&EN9P!5;FMN;W=N(%)E8VEP
M:65N=`!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FQO860@4&%S<W!H<F%S90!5;FYA;65D`%5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"X`56YS965N`%5N<V5T(&-O;&]R`%5N<W5B<V-R
M:6)E(&9R;VT@1F]L9&5R*',I`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A
M=&4`57!D871E("5S`%5P9&%T92!!='1A8VAM96YT($EN9F]R;6%T:6]N`%5P
M9&%T92!R97-P;VYD96YT('-T871U<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E
M<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A
M;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P
M97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S92!#=7)R
M96YT.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@24U!4"!F;VQD97(@<W5B
M<V-R:7!T:6]N<S\`57-E(%-33`!5<V4@5FER='5A;"!4<F%S:"!&;VQD97(_
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`
M57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!687)I86)L
M90!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T
M:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE=&YA;65S92`H
M5DE30TE)*0!6:65W`%9I97<@)7,`5FEE=R`E<R!0=6)L:6,@2V5Y`%9I97<@
M2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I97<@365S<V%G
M97,`5FEE=R!097)S;VYA;"!0<FEV871E($ME>0!6:65W(%!E<G-O;F%L(%!U
M8FQI8R!+97D`5FEE=R!4:')E860`5FEE=R!4:'5M8FYA:6P`5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I97<@871T86-H;65N="!I
M;B!A('-E<&%R871E('=I;F1O=P!6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<`5FEE=R!E=F5N=`!6:65W(&UE<W-A9V5S(&EN("5S`%9I97<@
M;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.@!6:65W('1A<VL`
M5FEE=R!T:&4@26UA9V5S`%9I<G1U86P@1F]L9&5R("(E<R(@8W)E871E9"!S
M=6-C97-F=6QL>2X`5FER='5A;"!&;VQD97)S`%9I<G1U86P@1F]L9&5R<R!R
M97%U:7)E(&$@;&%B96PN`%9I<G1U86P@24Y"3U@`5FER='5A;"!)3D)/6"!&
M;VQD97(`5FER='5A;"!4<F%S:`!6:7)T=6%L(%1R87-H($9O;&1E<@!6:7)T
M=6%L(&9O;&1E<B!L86)E;`!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%R;FEN
M9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B
M>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!7
M97-T97)N("A)4T\M.#@U.2TQ-2D`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@
M)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&%T
M('-H;W5L9"!W92!D;R!W:71H('-P86T@;65S<V%G97,@869T97(@=&AE>2!H
M879E(&)E96X@<F5P;W)T960@87,@<W!A;2!O<B!I;FYO8V5N=#\`5VAE;B!D
M96QE=&EN9R!M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L
M9&5R(&EN<W1E860@;V8@;6%R:VEN9R!T:&5M(&%S(&1E;&5T960_`%=H96X@
M;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT
M('1O('-T87)T(&]N/P!7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W
M92!S879E(&%T=&%C:&UE;G0@9&%T83\`5VAE;B!S96YD:6YG(&UA:6P@;W(@
M97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P
M<&5N9"!T;R!U;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E
M<R!W:71H;W5T(")`(BD_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7
M:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@
M;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I
M9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`
M5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7
M:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!965E9`%EE
M87)L>0!997,`665S+"!)($%G<F5E`%EO=2!A<F4@86)O=70@=&\@9F5T8V@@
M96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ`%EO=2!A<F4@
M871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I
M;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!A='1E;7!T:6YG
M('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!C
M;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E871I
M;F<@82!S=6(M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE
M=F5L(&9O;&1E<BX`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\
M/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N`%EO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+@!9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+@!9;W4@87)E(')E;F%M:6YG('1H92!F;VQD
M97(Z(`!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+@!9;W4@8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M("(E
M<R(N`%EO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&EN
M('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@8W5R<F5N="!M97-S
M86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T=7)E+@!9;W4@9&ED(&YO
M="!A9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O
M('EO=2!W97)E(&YO="!A;&QO=V5D('1O(&QO9VEN+@!9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N
M>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S
M<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!D;R!N;W0@:&%V92!P97)M:7-S
M:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(`66]U(&9O<G=A
M<F1E9"!T:&ES(&UE<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C
M:7!I96YT<SH@)7,N`%EO=2!H879E("5S(&YE=R!M97-S86=E<RX`66]U(&AA
M=F4@,2!N97<@;65S<V%G92X`66]U(&AA=F4@870@;&5A<W0@;VYE(&%T=&%C
M:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T('5P;&]A9"!Y970N($%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD('1H:7,@;65S<V%G92!W:71H
M;W5T('1H97-E(&%T=&%C:&UE;G1S/P!9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R
M.@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z
M`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@
M9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E
M<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B
M86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F
M;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T
M(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N`%EO=2!M=7-T(&5N=&5R
M('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!E
M;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@
M=&\@=FEE=R!T:&ES(&UE<W-A9V4`66]U(&UU<W0@96YT97(@=&AE('!A<W-P
M:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI
M<R!M97-S86=E`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I
M<G-T+@!9;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D
M+@!9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="X`66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S96QE
M8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N`%EO=2!M=7-T('-P96-I
M9GD@82!R96-I<&EE;G0N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I;&4@=&\@
M871T86-H+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U
M(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S
M="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!R961I<F5C=&5D('1H
M:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N`%EO=2!R97!L:65D('1O('1H:7,@
M;65S<V%G92!O;B`E<RX`66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@(B5S
M(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!N;W0@
M=6YS=6)S8W)I8F5D(&9R;VT@(B5S(BX@2&5R92!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!9;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R`B
M)7,B`%EO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2`B
M)7,B`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S
M.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BX`66]U<B!.86UE`%EO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,`
M66]U<B!0<FEV871E($ME>0!9;W5R(%!U8FQI8R!+97D`66]U<B!297!L>2UT
M;SH@861D<F5S<SH@/&5M/BAO<'1I;VYA;"D\+V5M/@!9;W5R(%,O34E-12!0
M=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,`66]U<B!A8V-O=6YT<SH`66]U
M<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@
M861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^`%EO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O
M9B!T:&ES(&EM86=E('1Y<&4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO=7(@
M9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E
M<SH`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U
M<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!M97-S86=E('=A<R!S=6-C97-S
M9G5L;'D@9&5L:79E<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9;W5R('-I9VYA
M='5R93H`6TAI9&4@475O=&5D(%1E>'1=`%M.;R!3=6)J96-T70!;4')O8FQE
M;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO
M;@!?0F-C`%]";&%C:VQI<W0`7T-,20!?0V,`7T1A=&%4<F5E`%]$96QE=&4`
M7T1E;&5T92!2;W<`7T9O;&1E<G,`7T=R;W5P<P!?2&5L<`!?261E;G1I='D`
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TEN8F]X`%],;V<@:6X`7TQO9R!O=70`
M7TUE<W-A9V4@4V]U<F-E`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R
M;6ES<VEO;G,`7U!R:6YT`%]0<FEO<FET>0!?4F5F<F5S:"`E<P!?4F5M;W9E
M($QI;FLN+BX`7U)E<&QY`%]396%R8V@`7U-E;F0@365S<V%G90!?4V5T=7``
M7U1A8FQE(%!R;W!E<G1I97,N+BX`7U1H<F5A9`!?5&\`7U5N9&5L971E`%]5
M<V5R<P!?5FEE=R!4:')E860`7U=H:71E;&ES=`!A9&1R97-S(&)O;VL`871T
M86-H;65N=`!A='1A8VAM96YT<RYZ:7``8GET97,`8V%L96YD87(`8V%L;0!C
M;&EC:R!H97)E`&9I;&4`9G)O;0!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M`&=U<W1I;F<`:#H`:6UM961I871E`&EN;&EN90!K97D`;&EN97-=`&UA:6QB
M;W@@9FEL90!N86UE`&YO;F4`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP
M;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO
M=R!D:69F97)E;F-E<P!S<&5L;&EN9R!E<G)O<@!S<&5L;&EN9R!E<G)O<G,`
M<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU
M<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`>6]U
M<B!B;&%C:VQI<W0`>6]U<B!W:&ET96QI<W0`4')O:F5C="U)9"U697)S:6]N
M.B!)35`@-"!!3%!(00I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ
M,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#<M,#D@,34Z,C<K,#(P
M,`I,87-T+51R86YS;&%T;W(Z($%M:7)K86)I<B!-971A;F5T=V]R:VEN9R!L
M=&0N(#QP97)S:6%N+6AO<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*3&%N9W5A
M9V4M5&5A;3H@4&5R<VEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M
M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U55$8M.`I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@V+'9
MB-F&V8C8M-BJ(-BHV8<Z`-BHV8<Z("`@("``V*K8I]BQVXS8KCH@(`#8I]BR
M.B`@("`@`"`HV+'9B-BR(-F"V*C9A"`E<RD`*-JIV83;C-BO(-BOV+/8JMBQ
MV+/;C"`E<RD`*-BOV+$@)7,@V+'9B-BR*0`@*-BGV878L=F(V+(I`"`HV8'8
ML=BOV*<I`"`HV*_;C-BQV8C8LBD`V+G9AMF(V*?9ACH@(``@V*_8L2``(-BO
MV+$@`"(E<R(@V*C9AR#:K]BQV8C9A^*`C-F'V*?;C"#8L]BGV878I]F&V8<@
MV*?8MMBGV8'9AR#8M-BO`"(E<R(@V*C9AR#8L]BGV878I]F&V8<@V878K-F(
MV++B@(S9A]BG(-BGV+;8I]F!V8<@V+38KP`B)7,B(-BGVXS8K-BGV*\@V8;8
MM-BOV8<@V*C9B-BO.B`E<RX`(P`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I
M`"4N,F9-0B#8I]BSV*K9@=BGV*_9AR#8M-BOV8<@V*?8LB`E+C)F34(@V878
MK-BGV+(@*"4N,F9-0BD`)60@)7,@V8@@)7,`V*?8L]F%(-BQV878LB#8M-F%
MV*<@)60@V+'9B-BR(-BOVXS:K]BQ(-F%V+G8JMBHV+$@V*?8L]BJ+@`E9"#9
MOMN,V+K8I]F%(-BMV+#9@2#8M-BOV8<@V*?8L]BJ`"5D(-F^VXS8NMBGV84@
MV*C8N=F&V8C8I]F&(-F'V+'8LMF&V*?9A=F'(-BHV8<@V+/8L=F^V+'8L]BJ
M(-BSV*?9A=BGV8;9A]F4(-BTV878IR#:K]BRV*?8L=BT(-BTV*_9AR#8I]BS
MV*H`)60@V;[;C-BZV*?9A2#8J-BYV8;9B-BGV88@V+K;C-BQ(-F'V+'8LMF&
MV*?9A=F'(-JOV++8I]BQV+0@V+38K]F'(-BGV+/8J@`E9"#9OMN,V+K8I]F%
M(-BHV+G9AMF(V*?9AB#9A]BQV++9AMBGV879AR#8J-F'(-BSV+'9OMBQV+/8
MJB#8L]BGV878I]F&V8?9E"#8M-F%V*<@VJ_8LMBGV+'8M"#8M-BOV8<@V*?8
ML]BJ`"5D(-F^VXS8NMBGV84@V*C8N=F&V8C8I]F&(-F'V+'8LMF&V*?9A=F'
M(-JOV++8I]BQV+0@V+38K]F'(-BGV+/8J@`E9"#8JMBG("5D(-BGV+(@)60@
MV;[;C-BZV*?9A0#9OMN,V+3"K=BHVXS9AMN,("5D+=BQV8C8LMF'`"5S("T@
MV*K9B-BLV8<`V*?8J]BQ(-BGV8;:K]BTV*H@)7,`VJG;C-F$V8C8J-BGVXS8
MJB`E<P`E<R#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQVXP@+2#8JMBCVXS;
MC-BO`"#8L=BGV8<F(W@R,#!C.]BGV8;8K]BGV++;C"`E<R``)7,@V*O8J-BJ
M(-F&V*?9A0#8M-BQV8C8MR#8JMF(V*?9@=F"("5S`"5S(-BGV+(@V8+8J-F$
M(-F%V8C8K-F(V*\@V*?8L]BJ`"5S(-BOV+$@V*W8I]F$(-BMV*?8MMBQ(-F%
MV8C8K-F(V*\@V87;C.*`C-BHV*?8M-BO+MF^V8C8M-F'("5S(-BTV878IR#8
MJMF!VXS;C-BQ(-F&V*?9A2#9AMN,V*?9@=BJV8<@V*?8L]BJ`"5S(-BOV+$@
M)7,@)7,`)7,@V*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V8;8
MI]F%V8?B@(S8K]BGV88@V878N=BJV*C8L=N,(-BHV*?8M-BO`-F^V8C8M-F'
M)7,@V*_8L2#8I]BHV*K8K]BGVXP@V878I]F'(-BJV8';C-N,V+$@V8;8I]F%
M(-N,V*?9@=BJV8<@V*?8L]BJ`"5S(-F^V+#;C-BQV8'8JMF'(-BTV*_9AR#8
MI]BSV*H`)7,@)7,@V+'8IR#9A-BZV8@@VJG8L=BOV8<@V*?8L]BJ`"5S(-BQ
MV*\@V+38K]F'(-BGV+/8J@`E<R#8J-F'(-N,VJD@V*_8L=BNV8C8I]BSV*H@
MV*+8LMBGV*\OV878M-BZV8C9A"#9OMBGV+/8KB#8K]BGV*_9AR#8I]BSV*H`
M)7,@V*C9AR#8K]BYV8C8JB`E<R#9OMBGV+/8KB#8K]BGV*_9AR#8I]BSV*H`
M)7,@V*?8M]F$V*?8N=BGV*H@V*+8LMBGV*\OV878M-BZV8C9A"#8L=BG(-BH
MV8<@V+39A=BG(-F!V+'8L]BJV*?8K]F'(-BGV+/8J@`E<R#8J-BWV8C8L2#8
MHMBRV878I]N,V+3;C"#9OMBPVXS8L=F!V*K9AR#8M-BOV8<@V*?8L]BJ`"5S
M(-BBV878I]BOV8<@V*?8K-BQV*?;C"#8N=F%V83;C-BGV*H@V8;:K]F'V*_8
MI]BQVXP@V*?9AMBJV*[8I]BH(-BTV*_9AR#8I]BSV*HN(-BLV+G8J-F'(-F'
MV+$@V+G9A=F$VXS8I]BJVXP@V+'8IR#:J=F'(-F'V84@V*?:J=F&V8C9AB#9
MA=N,XH",V*[9B-BGV8?;C-BO(-BGV*S8L=BG(-JIV8;;C-BO(-BYV838I]F%
MV*H@V*C8LMF&VXS8KP`E<R#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`)7,@
MV*_9@MN,V8+9AP`E<R#9OMN,V*_8IR#9AMBTV*\`)7,@V*?8M]F$V*?8N=BG
MV*H@V*+8LMBGV*\OV878M-BZV8C9A"#8M-F%V*<@V+'8IR#8K]BQV*[9B-BG
MV+/8JB#8K]BGV+'8KP`E<R#8K=BVV8C8L2#8M-F%V*<@V+'8IR#8K]BQ("5S
M(-BNV8C8I]BSV*K8I]BQ(-BGV+/8J@`E<R#8J-F'("5S(-BGV+(@)7,`)7,@
MV878I]N,V80@V*?8L]BJ("`E<R#8L=BG(-BGV+79A-BGV*T@V+/8I]BRV*\`
M)7,@V878I]N,V80@V*?8L]BJ(-BTV878IR#8L=BG(-BGV+(@)7,@V*C8I]BN
MV*C8L2#8L]BGV++8KP`E<R#9A=BGVXS9A"#8I]BSV*H@V*+8KMBQVXS9AB#8
MI]BWV838I]BYV*?8JB#8L=BGV*S8N2#8J-F'("5S(-BQV*<@V*_8L=N,V*?9
M@=BJ(-JIV8;8KP#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR`E<P#8JMF"V8C;
MC-F%("5S`"5S)W,@3F]T97!A9`#9@=F'V+'8L]BJ(-F(V+C8I]N,V8$@)7,`
M)7,Z("5S`"5S.B`E<R`H)60@V*?8LB`E9"D`*-BGV+G9A=BGV80@V*?;C-F&
M(-BJV8';C-N,V+'8I]BJ(-F((-BGV8;8JMF"V*?9A"#8J-F'(-BUV8'8K=F'
M(-BHV+G8KRD`*-F%V838NMN,(-JIV+'8K]F&(-BJV878I]F%VXP@V*K8NMN,
MVXS8L=BGV*H@V8@@V*C8I]BRVJ_8M-BJ(-BHV8<@V+79@=BMV8?9E"#8I]N,
MV*S8I]BO(-F^VXS8NMBGV84I`"A(5$U,*0`HV878JMF&(-BSV*?8K]F'*0`H
MV*C8I]BRVJ_8M-BJ(-BHV8<@V+79@=BMV8<@V*?;C-BLV*?8KR#9OMN,V+K8
MI]F%(-BHV+G8KR#8I]BR(-BGV+G9A=BGV80@V*K9A=BGV87;C"#8JMBZVXS;
MC-BQV*?8JMN,(-JIV8<@V*K8I]JIV8;9B-F&(-BGV8;8K-BGV84@V+38K]F'
M(-BJV+K;C-N,V+'8I]BJ(-BOV+$@V+79@=BMV8<@VJG9AMF(V8;;C"#8I]BY
MV878I]F$(-F&V*[9B-BGV8?8KR#8M-BO*`#8I]BQV+/8I]F$(-F^VXS8NMBG
MV84@V*C8N=BO(-BGV+(@V*?8N=F%V*?9A"#8JMF%V*?9A=N,(-BJV+K;C-N,
MV+'8I]BJVXP@VJG9AR#8JMBGVJG9AMF(V88@V*?9AMBLV*?9A2#8M-BOV8<@
MV*K8NMN,VXS8L=BGV*H@V*_8L=BUV8'8K=F'*2#:J=F&V8C9AMN,(-BGV+G9
MA=BGV80@V8;8KMF(V*?9A]BO(-BTV*\H`"H@V*?8MMBGV8'9AR#:J=BQV*_9
MAB#8I]N,V8;9A]BG(-BHV*<@V8'8M-BGV+$@V*_8I]BOV88@V*_:J=F%V8<@
MV*K8H]N,VXS8KR`J`"H@V838M]F!V*?9BR#8HMBOV+'8LRC9A]BG*2#8L=BG
M(-BGV8;8JMBNV*?8J"#:J=F&VXS8KR`J`-B,(-BHV*?8KP#8C"#8J-BGV*\@
M)7,@)7,`V(P@V878JMBZVXS;C-BQ(-BGV+(@)7,@V*C9AR`E<P`@V*?9AMBJ
MV*[8I]BH(`#;C-JI(-F^VXS8NMBGV84@V*W8L-F!(-BTV*_9AR#8I]BSV*H`
MVXS:J2#9OMN,V+K8I]F%(-BHV+G9AMF(V*?9AB#8NMN,V+$@V8?8L=BRV8;8
MI]F%V8<@V*C9AR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'V90@V+39A=BG
M(-JOV++8I]BQV+0@V+38K]F'(-BGV+/8J@#;C-JI(-F^VXS8NMBGV84@V*C8
MN=F&V8C8I]F&(-BZVXS8L2#9A]BQV++9AMBGV879AR#:K]BRV*?8L=BT(-BT
MV*_9AR#8I]BSV*H`VXS:J2#9OMN,V+K8I]F%(-BHV+G9AMF(V*?9AB#9A]BQ
MV++9AMBGV879AR#8J-F'(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8?9E"#8
MM-F%V*<@VJ_8LMBGV+'8M"#8M-BOV8<@V*?8L]BJ`-N,VJD@V;[;C-BZV*?9
MA2#8J-BYV8;9B-BGV88@V8?8L=BRV8;8I]F%V8<@VJ_8LMBGV+'8M"#8M-BO
MV8<@V*?8L]BJ`-NQV[#;L"#9AMF(VXS8L]F'`-NQV[#;L-NP(-F&V8C;C-BS
MV8<`V8+8I]F$V*@@V[';LB#8L]BGV+G8JMN,`-F"V*?9A-BH(-NRV[0@V+/8
MI]BYV*K;C`#;LMNT(-BSV*?8N=BJV8<`V[+;M=NP(-F&V8C;C-BSV8<`V[7;
ML-NP(-F&V8C;C-BSV8<`VXS:J2#9OMBTV*K;C-BHV*?9AB#8K]BGV*_:K]BG
MV88@V*C8L=BGVXP@V*?;C-F&(-BHV838I]JI(-F%V8C8L=BO(-F&VXS8I]BR
M(-BGV+/8J@#;C-JI(-BNV+?8I]N,(-BLV*_;C"#8L=BN(-BOV*?8K]F'(-BG
MV+/8J@#;C-JI(-BJV+79B-N,V+$@V*C8LMBQVJ\@V*C9AR#9AMBGV84@)7,@
MV*C9AR#9OMN,V+K8I]F%(-BTV878IR#9OMN,V8C8L]BJ(-BTV*_9AR#8I]BS
MV*H`V8;8JMN,V*S9AR#8I]BQV+/8I]F$(-F^VXS8NMBGV84@V+39A=BG(-N,
MVJD@V+'8L]N,V*\@V*?8LB#8K]BQVXS8I]F!V*H@VJG9AMF&V*_9AR#9A=N,
MXH",V*C8I]BTV*\`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'4"#8J-BQ
MV*?;C"#8L=F%V++8J-F&V*_;C"#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@
MV8;;C-BGV+(@V*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@
MV*C8L=BGVXP@V*C8I]BRV*C;C-F&VXP@VXS:J2#9OMN,V+K8I]F%(-BGV878
MMMBGV*$@V+38K]F'(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JI
MV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@
M4$=0(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V+'9A=BR
MVJ_8M-BGVXS;C"#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@
MV*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@VJG9A-N,
MV*\@V*[8M=F(V+7;C"!01U`@V8@@VXS:J2#8N=BHV*?8L=BJ(-JOV+#8L2#8
MJ-BQV*?;C"#8I]F%V+;8I]BA(-N,VJD@V;[;C-BZV*?9A2#9A=F(V+'8KR#9
MAMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,V(P@VXS:
MJ2#:J=F$VXS8KR#8KMBUV8C8M=N,(%,O34E-12#9B"#;C-JI(-BYV*C8I]BQ
MV*H@VJ_8L-BQ(-BHV+'8I]N,(-BQV878LMJOV+38I]N,VXP@V;[;C-BZV*?9
MA2#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%
MV8C9A=N,V(P@VXS:J2#:J=F$VXS8KR#8KMBUV8C8M=N,(%,O34E-12#9B"#;
MC-JI(-BYV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-BGV878MMBGV*$@VXS:
MJ2#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JI
MV83;C-BO(-BYV879B-F%VXP@4R]-24U%(-BHV+'8I]N,(-BQV878LMBHV8;8
MK]N,(-F^VXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-BHV*?8
ML=BGV88@V+/8J-JI(-BUV*C8K=JOV*?9A]N,`-BHV*?8L=BGV88@V+78J-BM
MVJ_8I]F'VXP`V+':K]BHV*?8L2#8M=BHV*W:K]BGV8?;C`#8JMJOV+':KR#8
MM=BHV*W:K]BGV8?;C`#8M=BHV*TOV+G8M=BQ`-F(`-BOV+'8J-BGV+'9AR#8
MI]N,V88@V8C;C-BQV*?8L]BJV*?8L0#8K]BQV*C8I]BQV8<N+BX`V;[8I]N,
MVXS9AB#9A=BWV839@@#9B-BSV+<@V878M]F$V8(`V;[8L-N,V+'9@=BJV88@
MV*_8L=BNV8C8I]BSV*H`V;[8L-N,V+'9@=BJV8<@V+38K]F'`-F^V+#;C-BQ
MV8'8JMF'(-BTV*_9ASH`V*?;C-BLV*?8KR#8M-BGV*[9AR!61E,@V878K-F(
MV+(@V*_8L]BJV+'8L]N,(-F&V*_8I]BQV*\`V*?;C-BLV*?8KR#9OMBQV8C9
MAMBOV8<@5D93(-F%V*S9B-BR(-BOV+/8JMBQV+/;C"#9AMBOV*?8L=BO`-BG
MV+?9A-BGV+G8I]BJ(-BMV+/8I]BH`-BGV+/9A2#8L=F%V+(@V*W8L]BGV*@`
MV*W8L]BGV*@@V878L]BOV8C8KP#9AMBGV84@V*W8L]BGV*CB@(PZ`-BMV+/8
MI]BHV*_8I]BQVXP`V8'8N=BGV83;C-BJV8?8IP#8I]BVV*?9@=F'(-JIV+'8
MK]F&`-BGV+;8I]F!V8<@VJG8L=BOV88@VJ_8L=F(V8<@V8'8L=BYVXP`V*?8
MMMBGV8'9AR#:J=BQV*_9AB#9A=BLV8C8LB#9@=BQV+G;C.*`C`#8I]N,V8;8
MK-BG(-BGV+;8I]F!V8<@VJG9ACH`V*?8MMBGV8'9AR#:J=BQV*_9AB#:K]BQ
MV8C9AR#8K-BOVXS8KP#8I]BVV*?9@=F'(-JIV+'8K]F&(-F%V*S9B-BR(-BL
MV*_;C-BO`-BGV+;8I]F!V8<@VJG8L=BOV88@VXS:J2#9A=BLV8C8LB#9@=BQ
MV+G;C"#8J-F'("(E<R(`V*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI(-JIV*?8
ML=BHV+$@V*S8K]N,V*\Z`-BGV+;8I]F!V8<@VJG8L=BOV88@V+/8JMF(V88`
MV*?8MMBGV8'9AR#:J=BQV*_9AB#8I]BYV+;8I]N,(-BLV*_;C-BO`-BGV+;8
MI]F!V8<@VJG8L=BOV88@V++9B-BL`-BGV+;8I]F!V8<@VJG8L=BOV88@V+/8
ML=J&V+39A=F'(``@V*?8MMBGV8'9AR#:J=BQV*_9AB#:K]BRVXS9AMJOV*?9
MAB`E<R#8J-BYV8;9B-BGV88@V8;9B-BGV+$@V*S8I]F&V*C;C"#9A=F(V++;
MC-F$V*<`V*?8MMBGV8'9AR#:J=BQV*_9AB#8I]N,V88@V*C9AR#8JMF"V8C;
MC-F%(-F%V88`V*?8MMBGV8'9AR#:J=BQV*_9AB#8J-F'(-JIV*K8I]BHVH;9
MA]F4(-BBV*_8L=BS.@#8I]BVV*?9@=F'(-JIV+'8K]F&(-BHV8<@VJG8JMBG
MV*C:AMF'V90@V*+8K]BQV+,@V879A@#8I]BVV*?9@=F'(-F#V+'8K]F&(-JI
MV*?8L=BHV+$`(B5S(B#8J-BYV8;9B-BGV88@V;[;C-F(V+/8JB#8I]BVV*?9
M@=F'(-BTV*\`V*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQV*?9AB#9
M@=BYV*?9A"#9AMN,V+/8J@#8L]BQV*+9A=BOV8?8I]N,(-BGV+;8I]F!VXP@
MV*C8L=BGVXP@V8;9A=BGVXS8M"#8J-F'(-F'V8;:K]BGV84@V878M-BGV8?8
MK]F'.B`\96T^("C9A]BQ(-BSV+'8HMF%V*\@V+'8IR#8K]BQ(-N,VJD@V*[8
MMR#8K-BOVXS8KR#9B-BGV+'8KR#:J=F&VXS8K]B,(-BGV*[8JMN,V*?8L=N,
M*2`\+V5M/@#8I]BWV838I]BYV*?8JB#8I]BVV*?9@=N,(-F%VXSB@(S8JMF(
MV*?9AMF&V*\@V*_8L2`E<R#8K]N,V*_9AR#8M-F(V8;8KP#8K-BRV*;;C-BG
MV*H@V*?8MMBGV8';C"#8I]BWV838I]BYV*?8J@#8K-BRV*;;C-BGV*H@V*?8
MMMBGV8';C"#9OMN,V+K8I]F%`-BLV++8IMN,V*?8JB#8I]BVV*?9@=N,(-F^
MVXS8NMBGV84@V87;C.*`C-BJV8C8I]F&V8;8KR#8K]BQ("5S(-BOVXS8K]F'
M(-BTV8C9AMBO`-BLV++8IMN,V*?8JB#8I]BVV*?9@=N,(-BNV+?8I]N,(-F^
MVXS8NMBGV84`V*S8LMBFVXS8I]BJ(-BGV+;8I]F!VXP@V*[8M]BGVXP@V;[;
MC-BZV*?9A2#9A=N,XH",V*K9B-BGV8;9AMBO(-BOV+$@)7,@V*_;C-BOV8<@
MV+39B-F&V*\`V*+8K]BQV+,`VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@`-JI
MV*K8I]BHVH;9A^*`C-F'V*?;C"#8HMBOV+'8LR``V*+8K]BQV+/9A]BGVXS;
MC"#8J-BQV*?;C"#8L=F(V8;9B-BTV*H@V878KMF!VXP@V*K9A=BGV84@V;[;
MC-BZV*?9A=F'V*<Z(#QE;3XHV8?8L2#8L]BQV*+9A=BO(-BQV*<@V*_8L2#;
MC-JI(-BNV+<@V*S8K]N,V*\@V8C8I]BQV*\@VJG9AMN,V*_8C"#8I]BNV*K;
MC-BGV+';C"D@/"]E;3X`V*+8K]BQV+/9A]BGVXS;C"#8J-BQV*?;C"#9A=BJ
MV+79A"#8M-BOV88@V*C9AR#8I]N,V88@V878M-BNV+79ASH@/&5M/BC9A]BQ
M(-BSV+'8HMF%V*\@V+'8IR#8K]BQ(-N,VJD@V*[8MR#8K-BOVXS8KR#9B-BG
MV+'8KR#:J=F&VXS8K]B,(-BGV*[8JMN,V*?8L=N,*3PO96T^`-BSV+'9OMBQ
MV+/8JB#8L]BGV878I]F&V8<M(-BJV+G;C-N,V88@V878K-F(V++9A]BGVXP@
MVJG8I]BQV*C8L=BGV88@V*_;C-JOV+$`V+/8L=F^V+'8L]BJVXP`V*K8J-F$
MVXS8NMBGV*H`V878N=BGV*_9A`#8JMBQV*?8LB#:J=BQV*_9A@#8JMBQV*?8
MLCH`V8?9A=F'`-BJV878I]F%VXP@VJG8I]BQV*C8L=BGV88@V*K8H]N,VXS8
MKR#8M=F$V*?8K=N,V*H@V+38K]F'`-F'V879AR#:K]BQV8C9A^*`C-F'V*<`
MV8?9A=F'(-F%V*S9B-BRXH",V8?8IP#9A]F%V8?9E"#:AMF'V*?8L2#8L]F%
MV*H`V*K9A=BGV87;C"#9OMN,V+K8I]F%V8?8IR#8K]BQ(-BGVXS9AB#9OMF(
MV+39ARC9A]BG*2#8K]BQ(-N,VJD@(-F&V*?9A=F'XH",V*_8I]F&(-BGV+/8
MJMF"V+'8I]BQ(-BNV8C8I]F'V*\@VXS8I]F!V*H`(-BJV878I]F%VXP@V;[;
MC-BZV*?9A=F'V*?;C"#8M-F%V*<@V*_8L2#9OMF(V+39AR`@(B5S(B`@VJG9
MAR#9@MBOVXS9A=N,XH",V*K8L>*`C"#8I]BR("`E<R#8L=F(V+(@V*C8I]BT
MV8;8KR#8J-F'(-BWV8C8L2#9A]F%VXS8M-JOVXP@V*W8L-F!(-BNV8C8I]F'
MV8;8KR#8M-BO`-BJV878I]F%VXP@V+;9A=N,V879A^*`C-F'V*?;C"#9@MBO
MVXS9A=N,XH",V*K8L>*`C"#8I]BR("`E<R`@V878I]F'(-BMV+#9@2#8KMF(
MV*?9A]F&V*\@V+38KP#8JMF%V*?9A=N,(-F&V*?9A=F'XH",V8?8I]N,(-BG
MV+'8L]BGV80@V+38K]F'V90@V8+8K]N,V87;C.*`C-BJV+'B@(P@V*?8LB`@
M)7,@(-F%V*?9AR#8K=BPV8$@V*[9B-BGV8?9AMBO(-BTV*\`V*?;C-BLV*?8
MKR#9OMF(V+39AR#9A=BLV*?8LB#8I]BSV*K8GP#8HMN,V*<@V*C8L=BGVXP@
MV8?8L2#9AMBGV879A^*`C-BOV*?9AB#9@MF(V*?9AMN,V88@V8';C-F$V*K8
ML2#8I]BYV878I]F$(-BTV8C8K]B?`-BGV*S8I]BRV8<@VH;9AMBO(-BBV*_8
ML=BSVXP`V*+;C-BG(-BGV*S8I]BRV8<@V*K9AMBXVXS9A2#9AMF(V+D@V8'9
MA]BQV+/8JB#9A=BQV*K8J"#8K]BGV*_9AR#8M-F(V*_8GP#8I]BR(-F"V*C9
MA"#9A=F(V*S9B-BO(-BGV+/8J@#9B-BQV8C8KR!)35-0(-BLV*?;C-JOV++;
MC-F&`-BGV+/9A2#8L=F%V+(@24U34"#8K-BGVXS:K]BRVXS9A@#9AMBGV84@
MVJG8I]BQV*C8L=N,($E-4U`@V*S8I]N,VJ_8LMN,V88`V*+8K]BQV+,@V;[8
ML]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8K-BGVXS:K]BRVXS9A@#8I]F$VJ_9
MB.*`C-F'V*?;C"#8K-BGVXS:K]BRVXS9A@#9A=BJV88@V*S8I]N,VJ_8LMN,
MV88Z`-BHV*[8M-F'V*?;C"#8K-BGVXS:K]BRVXS9AB#8J-BQV*?;C"#8I]N,
MV88@V8+8L]F%V*HZ`-F'V87;C-BTV8<`V8?9A=F(V*?8L=F'(-F^VXS9B-BS
MV*K9A]BG(-BMV8'8N"#8M-F(V8;8KP#:J=BGV+'8L]BGV+(@24U!4"#:K]F!
MV*K9AR#8I]BSV*HZ(-BNV+?8I]N,VXP@V*_8L2#:K]BQV8'8JMF&(-BVV87;
MC-F%V8<@V+'8KB#8K]BGV*_9AR#8I]BSV*H@`-N,VJD@V879@MBOV*?8L2#9
MAMBGV*_8L=BSV*H@V*K8N=N,VXS9AB#8M-BOV8<@V*C9B-BO`-BNV+?8I]N,
MVXP@V8;8I]BTV8;8I]BS(-BOV+$@V*W;C-F&(-BGVXS8K-BGV*\@VXS:J2#9
MB-BXVXS9@=F'V90@V*S8K]N,V*\@V+'8KB#8K]BGV*_9AR#8I]BSV*H`V;[;
MC-BTVJG8I]BQ`-F^V*?8L]BN`-F^V*?8L]BN(-BOV*?8K]F'(-BTV*_9AP#9
MOMN,V+K8I]F%V8?8I]N,(-F^V*?8L]BN(-BOV*?8K]F'(-BTV*_9AP#8J-BQ
MV8;8I]F%V8?9E.*`C"#:J=BGV+'8J-BQV*_;C`#9@=F'V+'8L]BJ(-BHV+'9
MAMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C`#8J-BQV8;8I]F%V8<@
MV*+9A=BGV*_9AR#8I]BSV*H`V*?8N=F%V*?9A"#9@=N,V838JMBQV8?8IP#8
MI]BYV878I]F$(-F!VXS9A-BJV+'9A]BG(-BHV8<@)7,`V*+;C-BG(-F"V8C8
MI]F&VXS9AB#9@=N,V838JMBQ(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#8
MI]BYV878I]F$(-BTV8C8K]B?`-BBVXS8IR#9@MF(V*?9AMN,V88@V8';C-F$
MV*K8L2#8K]BQ(-F'V8;:K]BGV87;C"#:J=F'(-F^VXS8NMBGV879A]BGVXP@
MV*_8L=N,V*?9@=BJVXP@V8;9A=BGVXS8M"#8K]BGV*_9AR#9A=N,XH",V+39
MB-BOV(P@V*?8N=F%V*?9A"#8M-F(V*_8GP#8I]BYV878I]F$(-BHV+$@V+'9
MB-N,(-BGV+38JMBQV*?:J=F'V*?;C"#9@=BQV+G;C`#8JMBUV8C;C-BH`-BG
MV8;8K]BGV++9AR#8JMF"V+';C-BHVXP`V*+9B-BQVXS9A`!!<F%B:6,@*%=I
M;F1O=W,M,3(U-BD`V*?9AMBOV*?8LMF'(-F^V+'9B-F&V*_9AR#8HMBQV+3;
MC-F(`-F&V*?9A2#8HMBQV+3;C-F(`-BBVXS8IR#9A=BWV878IMF&VXS8KR#:
MJ=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?;C-F&(-JIV83;C-BO(-BYV879
MB-F%VXP@V+'8IR#8K=BPV8$@VJG9AMN,V*_8GP#8HMN,V*<@V878M]F%V*;9
MAMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BLV8'8JB#:J=F$VXS8
MKR#8KMF(V*\@V+'8IR#8K=BPV8$@VJG9AMN,V*_8GR`HV*?;C-F&(-JIV*?8
ML2#9OMN,V+39AMF'V*?8KR#9AMF%VXSB@(S8M-F(V*\I`-F%V+?9A=BFV8;;
MC-BO(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]N,V88@VJG8I]BQ(-BQ
MV*<@V*?9AMBLV*?9A2#8K]F'VXS8K]B?`-BBVXS8IR#8M-F%V*<@V878M]F%
MV*;9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV+?9A-BGV+G8
MI]BJ(-BGV8'8JMBJV*?8K2#8K=BSV*?8J"`E<R#8L=BG(-F^V*?:J2#:J=F&
MVXS8K]B?`-BBVXS8IR#9A=BWV878IMF&VXS8KR#:J=F'(-BHV8<@V+?9B-BQ
M(-F'V87;C-BTVJ_;C"#9A=N,XH",V*[9B-BGV8?;C-BO(-BGVXS9AB#9OMN,
MV+K8I]F%V8?8IR#8L=BG(-BMV+#9@2#:J=F&VXS8K]B?`-BBVXS8IR#9A=BW
MV878IMF&VXS8KR#:J=F'(-BHV8<@V+?9B-BQ(-F'V87;C-BTVJ_;C"#9A=N,
MXH",V*[9B-BGV8?;C-BO(-BGVXS9AB#9OMN,V8C8L]BJ(-BQV*<@V*W8L-F!
M(-JIV8;;C-BOV)\`V*+;C-BG(-F%V+?9A=BFV8;;C-BO(-JIV8<@V87;C.*`
MC-BNV8C8I]F'VXS8KR#8I]N,V88@V;[9B-BTV8<@V+'8IR#8KMBGV83;C"#:
MJ=F&VXS8K]B?`-BBVXS8IR#9A=BWV878IMF&VXS8KR#:J=F'(-F%VXSB@(S8
MKMF(V*?9A]N,V*\@V;[9B-BTV8?9E"#9A]BQV++9AMBGV879A^*`C-F'V*?;
MC"#8KMF(V*\@V+'8IR#8KMBGV83;C"#:J=F&VXS8K]B?(`#8HMN,V*<@V878
MM]F%V*;9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-F^V8C8M-F'
MV90@V*+8M-BZV*?9A"#8KMF(V*\@V+'8IR#8KMBGV83;C"#:J=F&VXS8K]B?
M(`#8HMN,V*<@V878M]F%V*;9AMN,V*\@VJG9AR#8J-F'(-BWV8C8L2#9A]F%
MVXS8M-JOVXP@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]N,V88@V;[;C-BZV*?9
MA=F'V*<@V+'8IR#8K=BPV8$@VJG9AMN,V*_8GP#8HMN,V*<@V878M]F%V*;9
MAMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGVXS9AB#9OMN,V+K8
MI]F%(-BQV*<@V*C8N=F&V8C8I]F&(-BHVXSB@(S8MMBQV+$@VJ_8LMBGV+'8
MM"#:J=F&VXS8K]B?(`#8HMN,V*<@V878M]F%V*;9AMN,V*\@VJG9AR#9A=N,
MXH",V*[9B-BGV8?;C-BO(-BGVXS9AB#9OMN,V+K8I]F%(-BQV*<@V*C8N=F&
MV8C8I]F&(-F'V+'8LMF&V*?9A=F'(-JOV++8I]BQV+0@VJG9AMN,V*_8GR``
M07)M96YI86X@*$%235-#24DM."D`V++9A=BGV88@V+'8L]N,V*_9A@#9A]F&
MV+$`V+78N=F(V*_;C`#9OMBQV+/8M`#8HMN,V*<@V8+8J-F$(-BGV+(@V+G9
MA=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(-BHV+'8I]N,(-BJV*/;C-N,V*\@
MV*+9AB#8L]BFV8C8I]F$(-BTV8C8K]B?(`#8I]F&V*K8L]BGV*@@V+/8JMF(
MV8;9A]BG`-F^VXS9B-BSV*H`V;[;C-F(V+/8JB#:J=BQV*_9AB#9OMBQV8C9
MAMBOV8?B@(S9A]BG`-BBVXS8IR#;C-JI(-BQV8C9AMF(V+38JB#8I]BR(-JI
MV83;C-BO(-BYV879B-F%VXP@4$=0(-BTV878IR#8J-F'(-F^VXS8NMBGV878
MJMBGV88@V;[;C-F(V+/8JB#8M-F(V*_8GP#9OMBQV8C9AMBOV8?B@(S9A]BG
MVXP@V;[;C-F(V+/8JB#8M-BOV8<Z`-F^V+'9B-F&V*_9A]F4XH",(-F^VXS9
MB-BSV*H@V+38K]F'V90@(B5S(B#8I]BR(-BGV8;8K]BGV++9AR#9A=BLV*?8
MLB#8J-N,V+38JMBQ(-BGV+/8JBX@V;[8L=F(V8;8K]F'XH",(-F^VXS9B-BS
MV*H@V8;8M-BO`-F^VXS9B-BSV*H@V;[8I]BSV*X@V*C9AR#8K]BQV*[9B-BG
MV+/8JB#8JMF"V8C;C-F%VXP@V*?8L]BJ(-JIV8<@V+39A=BG(-F!V+'8L]BJ
MV*?8K]N,V*\`V;[;C-F(V+/8J@#9OMN,V8C8L]BJ(-BGV*[8L"#8M-BO.B#9
MAMF(V+D@V*?8M=F$VXP@V;[;C-F(V+/8J@#9OMN,V8C8L]BJV8?8IP#8L]BY
MVXP@V*_8L2#8K=BPV8$@VJ_8L=F(V8?;C"#8M-BOV8<@V*?8L]BJ(-JIV8<@
MV879B-BLV8C8KR#9AMN,V+/8J@#8L]BYVXP@V*_8L2#8K=BPV8$@V878K-F(
MV++;C"#8M-BOV8<@V*?8L]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8J@#8
ML]BYVXP@V*_8L2#9B-N,V+'8I]N,V+0@V878K-F(V++;C"#8M-BOV8<@V*?8
ML]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8J@#8L]BYVXP@V*_8L2#9B-N,
MV+'8I]N,V+0@V*?8M-BJV+'8I]JIVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%
MV8C8K-F(V*\@V8;;C-BSV*H`V+38L=JIV*H@VJG9AMF&V*_9A^*`C-F'V*<`
MV*K9B-BLV8<`XH",V8C;C-J8VJ_;C-F'V*<`V*+:K]F(V+/8J@!!=71H7V-Y
M<G-Q;#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@
MV8;8M-BO`$%U=&A?8WER<W%L.B#8L]BGV878I]F&V8<@V;[8M-BJVXS8J-BG
MV88@V8+8I]BHV83;C-BJV8?8I]N,(-F%V8C8L=BO(-F&VXS8I]BR(-BQV*<@
MV8;8K]BGV+'8KP!!=71H:6UP.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@
M24U!4"#9OMN,V*_8IR#9AMBTV*\`075T:%]F='`Z(-BHV+/8MR#9A=F(V+'8
MKR#9AMN,V*?8LB!&5%`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?:6UP.B#8J-BS
MV+<@V879B-BQV*\@V8;;C-BGV+(@24U!4"#9OMN,V*_8IR#9AMBTV*\`075T
M:&EM<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@
MV8;8M-BO`$%U=&A?:W)B-3H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR(&MR
M8C4@V;[;C-BOV*<@V8;8M-BO`$%U=&A?;&1A<#H@V*C8L]BW(-F%V8C8L=BO
M(-F&VXS8I]BR($Q$05`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?;&1A<#K8I]BV
MV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BS
MV*HN(-BGVXS9AB#:AMN,V++;C"#8I]BSV*H@VJG9AR#:J=BGV+'8L]BGV+(@
MVJ_9@=BJV8<@V*?8L]BJ`$%U=&A?;&1A<#K8K=BPV8$@VJG8I]BQV*C8L2`E
M<R#9A=F%VJG9AB#9AMN,V+/8JB``075T:%]L9&%P.MBHV+'9B-BRV+'8L]BG
MV8;;C"#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ`$%U=&A?;6-A
M;#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($U#04P@V;[;C-BOV*<@V8;8
MM-BO`$%U=&A?<VUB875T:#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR('-M
M8F%U=&@@V;[;C-BOV*<@V8;8M-BO`-BJV+78K]N,V8(@V8?9B-N,V9'8JB#9
MAMBGV879B-F!V9'9@B#8J-F(V*\`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&
MV*?9A=F(V8'9D=F"(-BHV8C8KRX@)7,`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M(-BGV+(@V+?8L=F!(-JIV*?8L=BSV*?8LB!2041)55,@V+'8KR#8M-BOV8<@
MV*?8L]BJ`-BJV+78K]N,V8(@V8?9B-N,V9'8JB#8K]BQ(-JIV*?8L=BSV*?8
MLB!&5%`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(`#8HMN,V*<@V8C9@MBJVXP@
MV8'8L=BSV*K9AMBOV8<@V*_8L2#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#9
MA=F&(-BHV*?8M-BO(-BJV+78I]F(VXS8L2#8J-BWV8C8L2#8KMF(V*_:J=BG
MV+$@V*_8L2#9OMN,V+K8I]F%V8?8I]N,($A434P@V8;8M-BGV88@V*_8I]BO
MV8<@V+39B-F&V*_8GP#:J=BJV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,@
MV*_8L2#8K]BSV*K8L=BS.@#9@=N,V838K]F'V*?;C"#9@MBGV*C9A"#8K]BS
MV*K8L=BSVXPZ`-F%V8;8JMBXV+$@V;[8I]BSV*X`V*C8I]BRVJ_8M-BJ(-BH
MV8<@)7,`V*C8I]BRVJ_8M-BJ(-BHV8<@)7,`V*C8I]BRVJ_8M-BJ(-BHV8<@
MV+38I]BNV+4@V8;9A=BGVXP@VH;9AMBOVJ_8I]F&V8?9E"#9OMN,V+K8I]F%
M`-BHV*?8LMJOV+38JB#8J-F'(-F%V*\@V8;9A=BGVXS8M"#8L]F$V+/9A^*`
MC-BGVXS;C`#9OMBSXH",V++9A=N,V8;9AP#8L=F&VJ\@V;[8L^*`C-BRV87;
MC-F&V8<`V*?8L]F%(-BQV878LB#9AMBGV*_8L=BSV*H@:V5R8F5R;W,`V8;8
MI]F%(-JIV*?8L=BHV+$@V8;8I]BOV+'8L]BJ(&ME<F)E<F]S`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`-BNV+<@V878J-F&V*<`V+'9B-F&V8C8M-BJ(-F%V*[9
M@=N,`-BOV+$@V++;C-BQ(-F%V*K9AMN,(-BGV+(@V*?8M]F$V*?8N=BGV*H@
MV8C8MMBYVXS8JB#9OMN,V+K8I]F%(-F(V*S9B-BO(-BOV*?8L=BO`-F$VXS8
ML]BJ(-BSVXS8I]F'`-BHV839B-JI("(E<R(@V*?8LB#8J-BQV8;8I]F%V8?9
ME"#:J=BGV+'8J-BQV*_;C"`B)7,B(-N,V*?9@=BJ(-F&V+38KP#8JMF&V+C;
MC-F%V*?8JB#8J-F$V8C:J0#9AMF(V+D@V*C9A-F(VJD`V*+;C-BG(-BJV+78
MI]F(VXS8L2#8K]BQ(-F^VXS8NMBGV879A]BGVXP@2%1-3"#8J-BLV+(@V*_8
ML2#9A=F(V*?8L=BOVXP@VJG9AR#9A=BTV*[8M=BGV8L@V*_8L=BNV8C8I]BS
MV*H@V8;8M-BOV8?B@(S8I]F&V*_8C"#8J-F$V8C:J=F'(-BTV8C9AMBOV)\`
MV*C8K]F&V8<`V+/;C-BGV8<`VH;9B-BH(-BGV839@0#9A-BHV8<`V;[9A]F&
MV*?;C"#9A-BHV8<Z`-F$V*C9A^*`C-F'V*<`V8?8L2#8K]F(`-F!V8?8L=BS
MV*H@V+/8L=BBV878KR#9B"#8J-BOV8;9AR#9OMN,V+K8I]F%V(P@V8?8L=BO
MV8@`V;[8I]N,VXS9A@#9A-N,V+/8JB#8J-F(V838JN*`C-BOV*?8L0!#35,`
M0U)#`-F&V8+8I]BW(-BJV8C8LMN,V+D@0U),`-BNV+79B-BUVXS8I]BJ(-BS
MV839B-F$+BXN`-F%V*S9A=F(V+G9A]F4(-F&V8C;C-BSV8<`V*K9@MF(VXS9
MA0#8HMBQV*?9A0#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8
MLB#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BQV*?9AR#8K]F(V+$@V8C8
MM=F$(-BTV*\`V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@
MV;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8L=BGV8<@V*_9B-BQ(-F(V+79
MA"#8M-BO.@#9AMF%VXSB@(S8JMF(V*?9AB#9AMF%V*?;C-BT(-BOV*?8KR`M
M(-BJV8;9A]BG("5S(-BGV+(@)7,@V*C8KMBT(-BGVXS9AB#9OMN,V+K8I]F%
M(-BOV+$@V*?;C-F&(-F&V*?9A=F'XH",V*_8I]F&(-F^VXS8K]BG(-BTV*\`
MV8;9A=N,XH",V*K9B-BGV88@V*?8L]F%(-BQV878LB#8L=BG(-BHV+?9B-BQ
M(-BNV8C8K]JIV*?8L2#8K]F(V*C8I]BQV8<@V*C8I]BRV8;8M-BGV8;8K]B,
M(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8KMF(V*\@V*K9A=BG
MV+,@V*C:K]N,V+';C-BO`-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(
MV8;8K]F'("(E<R(@V8;9B-BTV*H`V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:
MJ=BGV+'8L]BGV+(@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#9A=BJV+79
MA"#8M-BO.B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@(B5S
M(B#8L=BG(-BHV*?8LB#:J=BQV*\`V838NMF(`-F$V+K9B"#9OMN,V+K8I]F%
M`-BGV8;8M=BQV*?9@2#8I]BR(-BGV+'8L]BGV80@VJ_8LMBGV+'8M`#9A-BZ
MV8@@V*?;C-F&(-F^VXS8NMBGV84@V*C8M]F(V+$@VJG8I]F%V80@V*K9A=BG
MV87;C"#9A=BMV*K9B-BGVXP@V*+9AB#8L=BG(-BGV+(@V*C;C-F&(-BNV8C8
MI]F'V*\@V*C8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR`B
M)7,B(-BQV*<@V*W8L-F!(-JIV+'8KR`@`-F&V87;C.*`C-BJV8C8I]F&(-N,
MVJD@V+38I]BNV8<@V879B-F"V*H@V;[;C-BOV*<@VJG8L=BO`-F&V87;C.*`
MC-BJV8C8I]F&(-BHV*_9B-F&(-F^V*?8L=BGV878JMBQ("?9OMBQV8C9AMBO
MV8<@V879@MBUV*\G(-BGV*_8I]F%V8<@V*_8I]BO`-F&V87;C.*`C-BJV8C8
MI]F&(-BTV*?8KMF'("(E<R+8L=BG(-BMV+#9@2#:J=BQV*\@`-F&V87;C.*`
MC-BJV8C8I]F&(-BMV+#9@2#9AMF%V8C8K]B,("5D(-F!V+'8LMF&V*\@V879
MB-BLV8C8KR#8I]BSV*H`V8;9A=N,XH",V*K9B-BGV88@V*_9B-BHV*?8L=F'
M(-F%V+'8JMBH(-F&V879B-BOV(P@V*C8L=BNVXP@V*?8LB#9B-BQV8C8K]N,
MV8?8I]N,(-F!V+'8I]F'V84@V+38K]F'(-BHV+'8I]N,(-F%V+'8JMBH(-BS
MV*?8LMN,(-BHV*<@V+39A=BGV+'9A^*`C-F'V*?;C"#8L-BNVXS8L=F'(-BT
MV*_9A]B,(-BSV*?8LMJOV*?8L2#9AMN,V+/8J@#9AMF%VXSB@(S8JMF(V*?9
MAB#9OMN,V+K8I]F%(-BQV*<@V*C9AR#8M-F%V*?8L=F'(-BJV+G;C-N,V88@
MV+38K]F'(-JOV+#8L2#8K]BGV*\`V+G9AMF(V*?9A@#8K=BGV879A`#:K]BQ
MV8C9A^*`C-F'V*<@V8@@V*C8L=J&V+/8J-F'V*<`V+'9B-F&V8C8M-BJ`-F%
MV8C8J-BGVXS9A`#8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A`#9@=BGV+79A-F'
M(-BSV839B-F$`-BNV+79B-BUVXS8I]BJ(-BSV839B-F$`-F!V*?8M=F$V8?B
M@(S:K]BPV*?8L=N,(-BSV839B-F$`-F%V8C8J-BGVXS9A`!#96QT:6,@*$E3
M3RTX.#4Y+3$T*0#9A=BQVJG8L@!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*0#8K-BRV*;;C-BGV*H@VJ_9B-BGV8?;C"``V+/;C-BGV+/8JMF'V*?;
MC"#:K]F(V*?9A]N,`-BOV+'9B-F&XH",V*C8L=BO(-JOV8C8I]F'VXP@V*_8
ML2#8K]BSV*K8L=BS(-F&V87;C.*`C-BHV*?8M-BO+B#8I]BQV+/8I]F$(-F!
MV*?;C-F$(-BHV+$@V+'9B-N,(-BGVXS9AB#:J=BGV+'8L]BGV+(@V879A=JI
MV88@V8;;C-BSV*HN`-F%V*_;C-BQ`-BJV+K;C-N,V+$`V*K8NMN,VXS8L2#9
MA]F%V8<`V*K8NMN,VXS8L2#9OMF(V+39AP#8I]BSV84@V+'9A=BR(-BNV8C8
MKR#8L=BG(-BJV+K;C-N,V+$@V*_9A]N,V*\`V*K8NMN,VXS8L2#:K]BRVXS9
MAMF'XH",V8?8I]N,(-F&V878I]N,V+0@V878I]F&V8;8KR#8JMBYV*_8I]BO
M(-F^VXS8NMBGV879A]BG(-BOV+$@V8?8L2#8M=F!V*W9AR#9B"#:AMJOV8C9
MAMJOVXP@V878L=BJV*@@V+38K]F&(-F^VXS8NMBGV879A]BG`-BJV+K;C-N,
MV+$@V*K9AMBXVXS9A=BGV*H@VJG8I]BQV+/8I]BR(-F^V+/8JB#8I]F$VJG8
MJMBQV8C9AMN,VJD@V8@@V;[9B-BTV8<`V*K8NMN,VXS8L=BOV*?8K]F&(-F&
MV*?9A2#9B"#8HMBOV+'8L]N,(-JIV8<@V*?9@=BQV*?8KR#9A]F&VJ_8I]F%
M(-BNV8C8I]F&V*_9AB#9B"#9OMBGV+/8KB#8K]BGV*_9AB#8J-F'(-F&V*?9
MA=F'V90@V+39A=BG(-BNV8C8I]F'V8;8KR#8K]N,V*\@`-BJV+K;C-N,V+'8
MK]BGV*_9AB#9AMBGV84@V8@@V*+8K]BQV+/;C"#:J=F'(-BGV8'8L=BGV*\@
MV8?9AMJOV*?9A2#8KMF(V*?9AMBOV88@V8@@V;[8I]BSV*X@V*_8I]BOV88@
MV*C9AR#9AMBGV879A]F4(-BTV878IR#8KMF(V*?9A]F&V*\@V*_;C-BO(`#8
MJMBZVXS;C-BQV*_8I]BOV88@V*?8L]F%(-BQV878LB#8M-F%V*<@V*_8L2#9
MOMN,VJG8L=BHV8;8K]N,(-F!V+G9A-N,(-F^V+38JMN,V*C8I]F&VXP@V8;9
MA=N,XH",V+39B-BO+B#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@
MV*[9B-BO(-BJV878I]BS(-BHVJ_;C-BQVXS8KP#9AMF(VXS8L]F'`-F&V8C;
MC-BSV8?B@(S9A]BG(-BHV+'8I]N,(-F&V878I]N,V+0Z(`#8J-BQV+'8L]N,
M(-F^VXS9B-F&V*\N+BX`V*C8L=BQV+/;C"#9OMF(V+39ARC9A]BG*2#8J-BQ
MV*?;C"#9AMBGV879A]F4(-BLV*_;C-BO`-BHV+'8L=BSVXP@V8?9A=F'+R#9
MA]N,VH;B@(S;C-JI`-BHV+'8L=BSVXP@V*K9A=BGV87;C"#:J=BGV+'8L]BG
MV++B@(S9A]BGVXP@V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C.*`
MC-BGVXS;C"#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V8;8I]F%V8?B@(P@
MV*?8LB#8HMF&V8?8IR#9B-BGVJG8M-N,(-JIV8;;C-BO.@#8HMN,V*<@V8+8
MJ-F$(-BGV+(@V*?;C-F&VJG9AR#9OMN,V+K8I]F%(-F!V+'8L]BJV*?8K]F'
M(-BTV8C8KR#8I]BR(-F&V+C8L2#8I]F%V838I]N,VXP@V*C8L=BQV+/;C"#8
MM-F(V*_8GP#B@(P`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE
M<V4@5')A9&ET:6]N86P@*$)I9S4I`-BGV8;8JMBNV*?8J"#8N=F%V80Z`-BG
MV8;8JMBNV*?8J"#;C-JI(-JIV*?8L=BSV*?8LB#9OMBSV*H@V*?9A-JIV*K8
ML=F(V8;;C-JI.@#9A-BWV8'8I]F+(-BGV8;8JMBNV*?8J"#:J=F&VXS8KR#9
MB"#;C-BG(-BBV*_8L=BS(-BQV*<@V8C;C-BQV*?;C-BT(-JIV8;;C-BO.@#8
MI]F&V*K8KMBGV*@@VXS:J2#8I]BSV84@V+'9A=BR`-BGV8;8JMBNV*?8J"#;
MC-JI(-F&V*?9A2#:J=BGV+'8J-BQVXP`V*?9AMBJV*[8I]BH(-N,VJD@V+G9
MA=F$.@#8I]F&V*K8KMBGV*@@VH;:K]F(V8;:K]N,(-F&V878I]N,V+0@V*K8
MI]BQVXS8KCH`V*?9AMBJV*[8I]BH(-F&V8C8N2#8L]BHVJD@V8'9A]BQV+/8
MJB`HV*C8L=BGVXP@V8'9A]BQV+/8JMF'V*?;C"#9A=BQV*K8J"D`V*?9AMBJ
MV*[8I]BH(-N,VJD@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V*C8L=BGVXP@
MV8?9AMJOV*?9A=N,(-JIV8<@V*+8K]BQV+/9A]BG(-BQV*<@V*?8MMBGV8'9
MAR#9A=N,XH",VJG9AMN,V*\`V*?9AMBJV*[8I]BH(-BJV+'8JMN,V*C;C"#8
MJ-BQV*?;C"#:J=BJV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,@V*_8L2#9
MA]F&VJ_8I]F%(-BLV+/8JMBLV8@`V*K8N=BQVXS9@2#:J=F$V*?8LR`E<R#;
MC-BGV8'8JB#9AMBTV*\`V+78I]F!`-F^V*?:J2#:J=BQV*_9AB#8JMJOV8?8
MI]N,($U33V9F:6-E`-F^V*?:J2#:J=BQV*_9AB#:J=BGV+'8J-BQ(#H@)7,`
MV;[8I]JI(-JIV+'8K]F&(-JIV*?8L=BHV+$`V;[8I]JI(-JIV+'8K]F&(-BO
MV*?8K]F'V90@VJG8I]BQV*C8L0#8J-BQV*?;C"#8JMBHV*_;C-F$(-F^V+'9
MB-F&V*_9A]F4XH",(-BJV+79B-N,V+$@V*C9AR#9@MBGV838J-N,(-JIV8<@
MV878L=F(V+':K]BQ(-BTV878IR#8J-BJV8C8I]F&V*\@V*+9AMBQV*<@V*C8
MJ-N,V8;8KR`E<R#8L=BG(-JIV83;C-JI(-JIV8;;C-BO(`#8J-BQV*?;C"#:
MK]BQV8'8JMF&(-BJV+79B-N,V+$@)7,@+MBQV*<@V8'8M-BGV+$@V*_9A]N,
MV*\`V*C8L2#8L=F(VXP@)7,@VJG9A-N,VJD@VJG9AMN,V*\@V*K8IR#8J-F'
M(-BUV8'8K=F'(-F%V*_;C-BQVXS8JB`E<R#8J-BQV8C;C-BO`-BHV+'8I]N,
M(-BOVXS8K]F&(-F%V*W8JMF(V*?;C"!(5$U,(-BOV+$@VXS:J2#9OMF&V*S8
ML=F'V90@V*S8K]BGVJ_8I]F&V8?8C"`E<R#8L=BG(-JIV83;C-JI(-JIV8;;
MC-BO`"#8J-BQV*?;C"#8K]N,V*_9AB#8JMBUV8C;C-BQ(-JIV8C:AMJI(-BG
MV+(@V*?;C-F&(-BJV+79B-N,V+$@)7,@V+'8IR#:J=F$VXS:J2#:J=F&VXS8
MKP#8J-BQV*?;C"#8K]N,V*_9AB#9A=BMV*K9B-BGVXP@2%1-3"#8K]BQ(-N,
MVJD@V;[9AMBLV+'9A]F4(-BLV*_8I]JOV*?9AMF'("5S(-BQV*<@VJG9A-N,
MVJD@VJG9AMN,V*\`V*C8L=BGVXP@V*_;C-BOV88@V8+8L]F%V*K9A]BGVXP@
MV878KMBJV839@2#8K]BQ(-N,VJD@V;[9AMBLV+'9A]F4(-BLV*_8I]JOV*?9
MAMF'("5S(-BQV*<@VJG9A-N,VJD@VJG9AMN,V*\`V*?;C-F&V*S8IR#8L=BG
M(-BHV+'8I]N,(-F&V878I]N,V+0@V*K8M=BGV8C;C-BQ(-JIV83;C-JI(-JI
MV8;;C-BO`-BHV+$@V+'9B-N,(-N,VJG;C"#8I]BR(-JIV*K8I]BHVH;9A^*`
MC-F'V*?;C"#8HMBOV+'8LR#8I]F&V*K8KMBGV*@@V+38K]F'(-JIV83;C-JI
M(-JIV8;;C-BO(-F((-BSV;[8LR`@V8';C-F$V*_9A]BGVXP@V879B-BQV*\@
MV8;8N-BQ(-BQV*<@V*C8L=BGVXP@V*S8L]BJV*S9B"#8I]F&V*K8KMBGV*@@
MVJG9AMN,V*\`V*C8L=BGVXP@V*?8K]BGV879A]B,(-JIV83;C-JI(-JIV8;;
MC-BO`-BHV+'8I]N,(-BMV8'8N"#:J=F$VXS8K]F'V*?;C"#8N=F%V8C9A=N,
M(%!'4"#8K]BQ(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BNV8C8K]B,(-JI
MV83;C-JI(-JIV8;;C-BO`-BHV+'8I]N,(-BMV8'8N"#:K]F(V*?9A]N,(%,O
M34E-12`E<R#8K]BQ(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BNV8C8K]B,
M(-JIV83;C-JI(-JIV8;;C-BO`$-L:6-K871E;&P@V*?8LB#8M]BQVXS9@B!(
M5%10`"#:J=F$VXS:J2#:J=BQV*_9AB#8L=F(VXP@V*+8K]BQV+/8C"#8M=F!
MV*W9AR#8I]N,V*S8I]BO(-F^VXS8NMBGV84@V+'8IR#8J-BGV838IR#9A=N,
MXH",V*+9B-BQV*\@`-JIV83;C-JI(-JIV+'8K]F&(-BQV8C;C"#8HMBOV+'8
ML]B,(-F^VXS8NMBGV84@V+'8IR#8J-BQV*?;C"#8KMF(V*?9AMBOV88@V*C8
MI]BR(-F%VXSB@(S:J=F&V*\`V*C8L]BJV88`V*C8L]BJV88@V;[9AMBLV+'9
MAP#8J-BSV*K9AB#8I]N,V88@V;[9AMBLV+'9AP#9OMF(V+39A]F4(-BHV+/8
MJMF'(-BTV*_9AP#8I]BHV+'9A]BG`-BGV*C8L=N,`-BHV+/8JMF&`-BHV+/8
MJMF&(-F'V879AP#8J-BSV*K9AB#9A]F%V8?9E"#9OMF(V+39A^*`C-F'V*<`
MV*C8L]BJV88@V;[9B-BTV8<`V*S9A=BY(-BTV*_9AB#9AMF(V*?8L2#:J=F&
MV*?8L=N,`-J&V878N2#8M-BOV88@V838J-F'XH",V8?8IP#8L=F&VJ\`V+38
MI]BNV+4@V+'9AMJO.@#8I]F&V*K8KMBGV*@@VJG9AMF&V*_9AR#8L=F&VJ\`
MV*?9AMBJV*[8I]BH(-BQV8;:KP#8L]BJV8C9AMF'V*<Z`-BYV8;8I]F(VXS9
MAB#8L]BJV8C9AMF'V*<`V878MMBMVJD`V8'8L=F%V*?9A@#9OMF(V+/8JMF'
M(-F!V+'9A=BGV88`V*K9B-BVVXS8K0#9AMBGV84@V+G9A=F(V87;C`#8M-BQ
MVJG8J@#:J=BGV879A"#8M-BOV8<`V*?;C-BLV*?8KR#;C-JI(-F^VXS8NMBG
MV84@V*_;C-JOV+$`V*+;C-BG(-F^VXS8NMBGV879A]BG(-BOV+$@VXS:J2#9
MOMF&V*S8L=F'V90@V*S8K]BGVJ_8I]F&V8<@V*?;C-BLV*?8KR#8M-F(V8;8
MK]B?`"#8HMN,V*<@V;[;C-BZV*?9A=F'V*<@V*C8M]F(V+$@V;[;C-BT(-F!
MV+'8MB#8J-BG(-N,VJD@V8C8I]BSV+<@VJ_8L=BGV8';C-JIVXP@V878J-BJ
MV8;;C"#8J-BQ($A434P@V*?;C-BLV*?8KR#8M-F(V*\HV*?:K]BQ(-F%V+'9
MB-BQVJ_8L2#9A=BTV*[8M=F'(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#B@(S:
MJ=F&V*\IV)\@`-BQV*?;C-BGV8;9A^*`C-F'V*<`V+38L=BW`-BTV+'8I]N,
MV+<`V*K9@=BGV8C8JMF'V*?;C"#9OMN,VJG8L=BHV8;8K]N,`-F^VXS:J=BQ
MV*C9AMBOVXP@)7,`V;[;C-JIV+'8J-F&V*_;C"#:AMJOV8C9AMJOVXP@V8;9
MA=BGVXS8M"#9OMN,V+K8I]F%V8?8IP#9OMN,VJG8L=BHV8;8K]N,(-JOV++;
MC-F&V8?B@(SB@(S9A]BGVXP@V;[;C-BTXH",V8;9A=BGVXS8M"`@V8;8I]F%
MV8<`V*K8H]N,VXS8KR#8I]BSV84@V+'9A=BR`-BGV*K8M=BGV80@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO`-BGV*K8M=BGV80@V8;8I]F%V8C9@=F1V8(@V*C9
MB-BO`-BGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@VJG9A-N,V*\@V+G9
MA=F(V87;C"#8L=BO(-BTV*\`V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8
MLB#:J=F$VXS8KR#8N=F%V8C9A=N,(-BQV*\@V+38KRX@V*_9A-N,V80Z("5S
M("@E<RD`V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB!&5%`@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO`-BGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@
MV8;8I]F%V8C9@=F1V8(@V*C9B-BO`-F&V878I]BSV8?8IP#8JMF%V*?8L]F'
MV*<@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@VJG8JMBGV*C:AMF'V90@
MV*+8K]BQV+,@V+39A=BG(-BGV+;8I]F!V8<@V+38K]F'(-BHV8C8KP#8I]BO
MV*?9A=F'`-JIV8;8JMBQV80@V;[8M-BJVXS8J-BGV8;;C"!01U`@V*C8L=BG
MVXP@)7,N`-JIV8;8JMBQV80@V;[8M-BJVXS8J-BGV8;;C"!3+TU)344@V*C8
ML=BGVXP@)7,`VJG9AMBJV+'9A"#9B-BUV8C9A"#9AMBGV879A]F4(-BLV*_;
MC-BO(-F((-BGV+'8I]BFV8?9E"#8JMBPVJG8L=F'V*?;C"#9A=BQV*K8J-BW
M`-BBVXS8IR#8I]BMV+/8I]BSV*?8JB#9AMF(V+38JMBGV+';C"#8J-F'(-JO
MV+'8I]F!VXS:J=N,(-BJV*C8K]N,V80@V+39B-BOV)\`VJG9B-JIVXP`V+'9
MB-F&V8C8M-BJ`-BQV8C9AMF(V+38JB#8J-BQV*_8I]BTV*K9AB#8I]BR(-BH
MV*[8M"#8I]F&V*K8KMBGV*C;C`#8L=F(V8;9B-BTV*H@V*_8L2#9OMF(V+39
MAP#8M=BMVXS8K0#9A=BJV8;9A]BGVXP@V*K8M=BMVXS8K2#8M-BOV8<`V8;9
MA=N,XH",V*K9B-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V+'9A=BRV*C9AMBO
MVXP@VJG9AMBO(%!'4`#9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@
MV+'8IR#8I]F%V+;8I]BA(-JIV8;8KR!01U``V8;9A=N,XH",V*K9B-BGV8;8
MKR#9OMN,V+K8I]F%(-BQV*<@V+'9A=BRV*C9AMBOVXP@VJG9AMBO(%,O34E-
M10#9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8I]F%V+;8
MI]BA(-JIV8;8KR!3+TU)344`V8;9A=N,XH",V*K9B-BGV88@V*K9A=BGV+/9
MA]BG(-BQV*<@V*?8MMBGV8'9AR#:J=BQV*\@)7,`V8;9A=N,XH",V*K9B-BG
MV88@V*C9AR#:J=BGV+'8L]BGV+(@3$1!4"#9OMN,V8C8L]BJ(`#9AMF%VXSB
M@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!L9&%P(-F^VXS9B-BSV*H`
MV8;9A=N,XH",V*K9B-BGV88@V*C8I]F$V*?9AMBS(-BQV*<@VH;:J2#:J=BQ
MV*\@)7,`V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@;&1A
M<"#9A=BJV+79A"#8M-BO`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@
MV*K9B-BRVXS8N=N,(-BGVXS8K-BGV*\@VJG8L=BO+B`E<P#9AMF%VXSB@(S8
MJMF(V*?9AB#9OMBTV*K;C-BGV88@5D93(-BQV*<@V*?;C-BLV*?8KR#:J=BQ
MV*\Z("5S`-F&V87;C.*`C-BJV8C8I]F&(-BOV*?8K]F'(%!'4"#8L=BG(-BQ
MV878LMJOV+38I]N,VXP@V8;9A=F(V*\@`-F&V87;C.*`C-BJV8C8I]F&(-BO
MV*?8K]F'(%,O34E-12#8L=BG(-BQV878LMJOV+38I]N,VXP@V8;9A=F(V*\@
M`-F&V87;C.*`C-BJV8C8I]F&(-BJV878I]BS(-BQV*<@V*W8L-F!(-F&V879
MB-BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,
MV+G;C"#8L=BG(-BMV+#9@2#9AMF%V8C8KRX@)7,`V8;9A=N,XH",V*K9B-BG
MV88@V;[;C-BZV*?9A=F'V*<@V+'8IR#8I]BR("5S(-BMV+#9@2#:J=BQV*\N
M(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*HZ)7,`V8;9A=N,XH",V*K9
MB-BGV88@V*+8K]BQV+,@VJ_;C-BQV8;8K]F'(-F&V*?9A=F'V90@V*?9A-JI
MV*K8L=F(V8;;C-JIVXP@V+'8IR#8JMBTV*[;C-BU(-BOV*?8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQVXP@V+'8IR#8
MI]BLV+'8IR#:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'
MXH",(-BNV8C8I]BSV*K9AR#8M-BOV8<@V+'8IR#8I]BR(-F^VXS9B-BSV*H@
M35,M5$Y%1B#8J-BGV++:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(
MV8;8K]F'XH",(-BNV8C8I]BSV*K9AR#8M-BOV8<@V+'8IR#8I]BR(-BBV+'8
MM-N,V8@@6FEP(-BHV*?8LMJIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=F$
M(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BQV*<@V8C8I]JIV+3;C"#9AMF%
MV8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=F$(-F!V8?8L=BSV*H@V*K9B-BR
MVXS8N=N,(-BQV*<@V8C8I]JIV+3;C"#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(
MV*?9AB#9@=F'V+'8L]BJ(-JIV*?9A=F$(-F!V8?8L=BSV*H@V*K9B-BRVXS8
MN=N,(-BQV*<@V8C8I]JIV+3;C"#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9
MAB#:J=F$VXS8KR#8N=F%V8C9A=N,(-BQV*<@V*?8LB#:J=BGV+'8L]BGV+(@
MVJG9A-N,V*\@V*C8K]BSV*H@V*+9B-BQV*\`V8;9A=N,XH",V*K9B-BGV88@
M)7,@V+'8IR#8J-BGV+(@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F%V*_9
MB-F$(-F(V+C8I]N,V8$@V8;:K]F'V*_8I]BQVXP@)7,@V+'8IR#8J-BGV+(@
MV8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8KMF(V*?9AMBO
M`-F&V87;C.*`C-BJV8C8I]F&(-BGV+/9A2#8L=F%V+(@V+'8IR#8J-BQV*?;
MC"#:J=BGV+'8J-BQ(-F%V8C8L=BO(-F&V+C8L2#8J-BGV++9AMBTV*?9AMBO
M+B#8J-BYV+;;C"#;C-BG(-F'V879AR#8K-BRV*;;C-BGV*H@V878L=BHV8C8
MMR#8J-F'(-BBV88@V8;8I]BOV+'8L]BJ(-F%VXSB@(S8J-BGV+38KRX@V*_9
MB-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KR#;C-BG(-BHV+'8I]N,(-JIV87:
MJ2#8J-N,V+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8
MKMF(V*\@V*K9A=BGV+,@V*C:K]N,V+';C-BO`-F&V87;C.*`C-BJV8C8I]F&
M($%#3"#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8L=BG(-BO
MV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,`V8;9A=N,XH",V*K9
MB-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8K]F(V*C8I]BQ
MV8<@V*C8K]BSV*H@V*+9B-BQV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-F!
MV8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8
ML]BJ(-BBV8C8L=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9@MBGV*C9A-N,
MV*K9A]BGVXP@VJG8I]BQV+/8I]BR(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8
ML]BJ(-BBV8C8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBO
MVXP@V+'8IR#8J-BGV++:K]BQV*_8I]F&V*\`V8;9A=N,XH",V*K9B-BGV88@
MV;[;C-JIV+'8J-F&V*_;C"`E<R#8L=BG(-BOV*[;C-BQV8<@VJG8L=BO`-F&
MV87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@V;[8M-BJVXS8J-BG
MV88@V+'8IR#8K=F!V+@@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^VXS:
MJ=BQV*C9AMBOVXP@V;[8M-BJVXS8J-BGV88@V+'8IR#8K=F!V+@@VJG8L=BO
M.B`E<R``V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(-F^V+38JMN,
MV*C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8IR#8K=F!V+@@VJG8L=BO
M`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#9OMN,VJG8L=BHV8;8
MK]N,("5S(-BQV*<@V*W9@=BX(-F&V879B-BO+B#8M-F%V*<@V87;C"#8JMF(
MV*?9AMN,V*\@V*?8LB#;C-JIVXP@V*?8LB#:K]BRVXS9AMF'XH",V8?8IR#8
MJ-BQV*?;C"#8K=F!V+@@VJG8KR#8J-BQ(-BQV8C;C"`E<R#8I]BSV*K9@=BG
MV*_9AR#9AMF%V*?;C-N,V*\@V8@@VXS8IR#8I]N,V8;:J=F'(-BGV+(@VJG8
MKR#8J-F'(-BUV8C8L=BJ(-BOV+/8JMN,(-BOV+$E<R#8L=F(V8;9B-BTV*H@
MV*K9A]N,V8<@V8;9A=BGVXS;C-BO`-F&V87;C.*`C-BJV8C8I]F&(-JIV*?8
ML=BSV*?8LB!,1$%0(-BQV*<@V*S8L]BJV*S9B"#:J=BQV*\`V8;9A=N,XH",
MV*K9B-BGV88@V*K9A=BGV+,@(-BQV*<@V*C8L=F(V++8L=BSV*?9AMN,(-JI
MV+'8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;
MC-BYVXP@V+'8IR#8J-BQV8C8LMBQV+/8I]F&VXP@VJG8L=BO+B`E<P#9AMF%
MVXSB@(S8JMF(V*?9AB#9AMF(V*?8L2#8K-BGV8;8J-N,(-F%V8C8LMN,V838
MIR#8L=BG(-F^VXS8K]BG(-JIV+'8KRX@V878M]F%V*;9AB#8M-F(VXS8KR#:
MJ=F'(-F&V8C8I]BQ(-BLV*?9AMBHVXP@V*C8I]BR(-BGV+/8J@#9A=BJV88@
MV+39A=BGV+'8M"#8M-BOV8<`VJG8M-F(V+$`V*_9B-BQV8?B@(S9A]BG`-BG
MVXS8K-BGV*\`V*?;C-BLV*?8KR#9OMF(V+39AP#8I]N,V*S8I]BO(-JIV83;
MC-BOV8?8IP#8I]N,V*S8I]BO(-F^V8C8M-F'(-F%V*S8I]BRVXP`V*?;C-BL
MV*?8KR#;C-JI(-F^VXS9B-F&V*\`V*?;C-BLV*?8KR#;C-JI(-F^V8C8M-F'
M(-BLV*_;C-BO(-F'V+'8LMF&V*?9A=F'XH",V8?8IP#8I]N,V*S8I]BO(-N,
MVJD@V;[9B-BTV8<@V*S8K]N,V*\@V;[;C-BT(-F&V8C;C-BSV8?8IP#8I]N,
MV*S8I]BO(-N,VJG;C"#8K-BOVXS8KP#8I]N,V*S8I]BO(-N,VJD@V;[9B-BT
MV8<@V*S8K]N,V*\@V*C8L=BGVXP@V8;8I]F%V8?B@(S9A]BGVXP@V*?8L=BS
MV*?9A-N,`-BGVXS8K-BGV*\@VXS:J2#9OMF(V+39AR#8K-BOVXS8KR#8HMBT
MV+K8I]F$`"#8I]N,V*S8I]BO(-F"V8C8I]F&VXS9AB#9@=N,V838JMBQ(-BH
MV+'8I]N,(-BSV*?8LMF%V*?9AMBOV8?;C"#9AMBGV879A^*`C-F'V*?;C"#8
MK]BQVXS8I]F!V*K;C-B,(-F%V+'8JMBH(-BSV*?8LMN,(-F&V*?9A=F'XH",
MV8?8IR#8K]BQ(-F^V8C8M-F'XH",V8?8IR#9B"#8K=BPV8$@V8?8L=BRV8;8
MI]F%V8?B@(S9A]BG`-BGVXS8K-BGV*\@V8;9B-BTV*KB@(S8I]F!V++8I]BQ
M(-BLV*_;C-BO`-BGVXS8K-BGV*\@V8;9B-BTV*KB@(S8I]F!V++8I]BQ(-F(
M(-F!V+'9A2#9OMBGV+/8K@#8I]N,V*S8I]BO(-BRVXS8L=F^V8C8M-F'XH",
MV8?8IP#9A=BLV8C8LMF'V*?;C"#8I]N,V*S8I]BO(-JIV8;9AMBOV8<`V+39
MA=BGV+'9AR#:J=BGV+'8JB#8I]BYV*K8J-BGV+';C`#8L]BGV+G8JB#9@=BY
MV83;C`!54DP@V8'8N=F$VXP@V8?8L]BJ`-BBV*@@V8@@V8?9B-BGVXP@V8'8
MN=F$VXP`V*_8L]BJV+'8L]N,(-JIV8;9B-F&VXP@V*C9AR`E<P#8M-BQV*?;
MC-BW(-F!V+G9A-N,.B``V+/8J-JI(-F!V+G9A-N,`-BHV8?;C-F&V8<@V+/8
MI]BRVXP@V*W8L]BGV*C9A]BG(-BHV+'8I]N,(-F(V*?:J=BTVXP@V8;8I]F%
MV8?B@(S9A]BG(-BGV+(@V*W8L]BGV*C9A]BGVXP@V*_;C-JOV+$`V*C9A]N,
MV8;9AR#8L]BGV++;C"#:AMJOV8C9AMJOVXP@V*?8L=BSV*?9A"#9AMBGV879
MA^*`C-F'V*<`V*C9A]N,V8;9AR#8L]BGV++;C"#9B-BXV*?;C-F!(-BHV+'8
MI]N,(-BGV*S8L=BG(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#8J-F'("5S
M`-BHV+';C-BOV88`V*C8L=N,V*_9AB#8I]F&V*K8KMBGV*@`0WER:6QL:6,@
M*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR
M86EN:6%N("A+3TDX+54I`$1$`-BQV8C8LMBGV8;9AP#8JMBGV+';C-BN`-F%
MV+'9B-BQVJ_8L2#8K]BQV*[8JB#8K]BGV*_9AP#8JMBGV+';C-BN`-BJV*?8
ML=N,V*X@V*_8L=N,V*?9@=BJ(-BTV*_9AP#8JMBGV+';C-BN(-BGV8;8JMBN
MV*?8J`#8L=F(V+(`V*W8L-F!(-BSV*K9B-F&`-BOV+/8I]F%V*C8L0#8I]BY
MV*_8I]BO(-BOV8?8K]F'VXP`V+'8K]BTV*_9AP#8L=BOV+38K]F'.@#:J=F%
M(-JIV+'8K]F&(-BJV8C8L=F!V*K:K]N,`-BQV8;:KR#9OMN,V+0@V8'8L=BV
M`-F'V8C;C-F1V*H@V;[;C-BT(-F!V+'8M@#9OMF(V+/8JMF'V90@V;[;C-BT
M(-F!V+'8M@#9A=BYVXS8I]BQV8?8I]N,(-F^VXS8M"#9@=BQV+8@V878L=BJ
MV*@@V+/8I]BRVXPZ`-BLV8?8JB#9A=BQV*K8J"#8L]BGV++;C"#9OMN,V+0@
MV8'8L=BV.@#8JMBYV*?8L=N,V8$`V8;9A=BGVXS9AMBOV8<`V*W8L-F!`-BM
MV+#9@2#:J=F$VXS8KR#8N=F%V8C9A=N,("5S`-BMV+#9@2#:J=F$VXS8K^*`
MC-F'V*?;C"#:J=F&V8C9AMN,`-BMV+#9@2#9OMF(V+39ARC9A]BG*0#8K=BP
MV8$@VJ_8L=F(V8<`V*W8L-F!(-F%V*S9B-BR`-BMV+#9@2#9OMF(V+39A^*`
MC-F'V*?;C"#8I]F&V*K8KMBGV*@@V+38K]F'`-BMV+#9@2#9AMF(V+38JN*`
MC-BGV8'8LMBGV+$`V*W8L-F!(-F^V8C8M-F'(-F%V*S8I]BRVXP`V*W8L-F!
M(-F((-F^V*?:J=BSV*?8LMN,(-F^VXS8NMBGV879A]BG`-BMV+#9@2#8L]F$
MV8C9A`#8K=BPV8$@V+/8JMF(V88`V*W8L-F!(-BGV83:K]F(VXP@V*S8I]N,
MVJ_8LMN,V88@V879B-BLV8C8KP#8HMN,V*<@V;[;C-BZV*?9A=F'V*?;C"#9
MB-BGVJG8M-N,(-BTV*_9AR#8I]BR(-JIV*?8L=BSV*?8LB#8K=BPV8$@V+39
MB-BOV)\`V*?8LB#8JMF"V8C;C-F%(-F%V88@V*W8L-F!(-BTV8C8KP#8HMN,
MV*<@V;[;C-F(V8;8K]F'V*?;C"#9OMN,V8C8L]BJ(-F"V*_;C-F%VXS8C"#8
MK]BQ(-BGV*C8JMBOV*?;C"#9A]BQ(-F%V*?9AR#8K=BPV8$@V+39B-F&V*_8
MGP#8HMN,V*<@V8;8I]F%V8?B@(S9A]BGVXP@V8'8L=BSV*K8I]BOV8<@V+38
MK]F'V90@V8+8K]N,V87;C-B,(-BOV+$@V*?8J-BJV*_8I]N,(-F'V+$@V878
MI]F'(-BMV+#9@2#8M-F(V8;8K]B?`-BMV+#9@2#9A=BLV8C8LMF'V*<@V*C8
ML=BGVXP@("(E<R(`V*+;C-BG(-F%V*S9B-BRV8?8IR#9B"#8LMN,V+'9A=BL
MV8C8LMF'V*<@V*C8L=BGVXP@(B5S(B#8K=BPV8$@V+39B-BOV)\`V*W8L-F!
M(-BSV+?8L0#8K=BPV8$@V8?9B-N,V9'8JB#8I]F&V*K8KMBGV*@@V+38K]F'
M`-BMV+#9@2#9A]BQV++9AMBGV879A^*`C-F'V*<`V*W8L-F!(-BSV*K9B-F&
M(-F!V+G9A-N,`-BMV+#9@2#8L]BWV+$@V8'8N=F$VXP`V*W8L-F!(-BTV*_9
MAP#9OMN,V+K8I]F%V8?8I]N,(-BMV+#9@2#8M-BOV8<`V;[;C-F(V+/8JB`B
M)7,B(-BMV+#9@2#8M-BOV8<`V*W8L-F!(-F((-BGV8;8JMF"V*?9A"#9OMN,
MV+K8I]F%V8?8IP#8LMF%V*?9AB#8I]BQV+/8I]F$`-BQV*\@V*K9@MBGV+;8
MIP#8K]BQV*[9B-BGV+/8JB#8J-BQV*?;C"#8I]BWV838I]BYV*?8JB#8HMBR
MV*?8KR_9A=BTV+K9B-F$(-F^V+#;C-BQV8'8JMF'(-F&V+38KP#9AMBRV8C9
MA-N,`-BTV+'8K2#9A=BTVJG9A`#8JMF(V+;;C-BM`-BLV++8IMN,V*?8J@#8
MK-BRV9#8IMN,V*?8JCH`(-BLV++8IMN,V*?8JB#8J-BQV*?;C"#8L]BQV;[8
ML=BSV*H@V+/8I]F%V*?9AMF'(-BKV*C8JB#8M-BOV8<@V*?8L]BJ`-JOV+/8
MJMBQV+0`V8;9@MBWV8<@V+38J-F&V84`V8;9@MBWV8<@V+38J-F&V84@V*C8
ML=BGVXP@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@`-F&V8+8M]F'(-BTV*C9AMF%
M.B``V*?9A=BVV*?8H>*`C-F'V*<@V*K8I]BQ(-BTV8C9AMBOV)\`V*S9A]BJ
M(-BGV+(@VH;9OB#8J-F'(-BQV*?8L]BJ`-BLV8?8JB#8I]BR(-BQV*?8L]BJ
M(-BHV8<@VH;9O@#8M-BGV*[9AP#9AMF%V*?;C-BT`-BBVXS8IR#8LMF%V*?9
MAB`R-"#8L]BGV+G8JMF'(-F&V878I]N,V+0@V*_8I]BOV8<@V+39B-BOV)\`
MVJ_8LMN,V8;9A^*`C-F'V*?;C"#9AMF%V*?;C-BT`-BBVXS8IR#8J-BYV*\@
MV*?8LB#9@=BQV+/8JMBGV*_9AB#9OMN,V+K8I]F%V(P@V*K8H]N,VXS8KR#8
MHMF&(-F&V878I]N,V+0@V*_8I]BOV8<@V+39B-BOV)\`V8;9A=BGVXS8M"#8
MK-BRV*;;C-BGV*H@V;[;C-BTPJW8J-N,V8;;C`#9AMF%V*?;C-BT(-F^VXS8
MM,*MV*C;C-F&VXP`V8;9A=BGVXS8M"#9@MBGV838J`#9AMF%V*?;C-BT(-BO
MV+$@V*C8K]F&V8?9E"#9OMN,V+K8I]F%`-BBVXS8IR#8JMBPVJG8L=F'V*?;
MC"#:K]BTV8C8K]F&VXP@V*C8L=BGVXP@V8;8I]F%V8?B@(S9E"#8K-BOVXS8
MKR#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?(`#8HMN,V*<@V;[;C-F(
MV8;8KR`GV*[8I]F$VXP@VJG8L=BOV88@V8?8L=BRV8;8I]F%V8?B@(S9A]BG
M)R#8K]BQ(-JOV++;C-F&VJ_8I]F&(-F&V878I]N,V+0@V*_8I]BOV8<@V+39
MB-BOV)\`V*+;C-BG(-F^VXS9B-F&V*\@)]BNV*?9A-N,(-JIV+'8K]F&(-BS
MV+?9A"#8HMBTV+K8I]F$)R#8K]BQ(-JOV++;C-F&VJ_8I]F&(-F&V878I]N,
MV+0@V*_8I]BOV8<@V+39B-BOV)\`V*K8L=BJVXS8J`#8K=BGV838JB#8JMBP
MVJG8L0#8N=BOV84@V*K8M]BGV*C9@@#8N=BOV84@V*C8L=BQV+/;C"#9OMF(
MV+39ARC9A]BG*2#8J-BQV*?;C"#9AMBGV879A]F4(-BLV*_;C-BO`-BMV+#9
M@2#9AMBTV8C8KP#8K]BSV*K8L=BSVXP@V878L]BJV8+;C-F%(-BHV8<@;6%I
M;G1E;F%N8V4N<&AP(-F%V87:J=F&(-F&VXS8L]BJ`-BOV+$@V+/8JMF(V88@
MV8'8L=BSV*K9AMBOV8<@V;[;C-F(V8;8K]N,(-BGVXS8K-BGV*\@V8;:J=F&
M`-BBVXS8IR#9A=N,XH",V*[9B-BGV8?;C-BO(-BBV88@V;[9B-BTV8<@V+'8
MIR#8J-BGV+(@VJG9AMN,V*_8GP#8HMN,V*<@V+/8M]BQ(-BGV8C9A"#8M-BG
MV879A"#9@=N,V838KR#9AMBGV84@V87;C.*`C-BHV*?8M-BOV)\@V*?:K]BQ
M(-J&V8;;C-F&(-BGV+/8JMB,(-BGVXS9AB#8K-BYV*C9AR#8L=BG(-BYV838
MI]F%V*H@V*C8LMF&VXS8KSH`V*+;C-BG(-BMV+/8I]BHVXP@V8;8K]BGV+';
MC-BOV)\@V*O8J-BJ(-F&V*?9A0#8I]F&V*S8I]F%(-BTV*_9AP#8I]BSV*K9
M@MBQV*?8L0#8I]BSV*K9@MBQV*?8L2`E<P#8I]BSV*K9@MBQV*?8L2`E<R#8
MK]BQ(-F"V*?9A-BH("YZ:7``V*?8L]BJV8+8L=BGV+$@V*K9A=BGV87;C"#9
MOMN,V8C8L]BJV8?8IRC8K]BQ(-F^V+'9B-F&V*_9A]F4("YZ:7`I`-BGV+/8
MJMF"V+'8I]BQ(-F^V8C8M-F'*-F'V*<I`-BGV+/8JMF"V+'8I]BQ(-F^V8C8
MM-F'*-F'V*<I(%O9@MBGV838J"`N>FEP70#8I]BSV*K9@MBQV*?8L2#9OMN,
MVJG8L=BHV8;8K]N,(-BJV8C9A-N,V*\@V+38K]F'(-BHV+G9AMF(V*?9AB#8
MK]BSV*H@V8;9B-N,V+,@4$A0`-BGV+/8JMF"V+'8I]BQ(-BOV+$@V8+8I]F$
MV*@@+GII<`#9OMN,V+0@V8;9B-N,V+,`V;[9B-BTV8?9E"#9OMN,V+0@V8;9
MB-N,V+,`V;[9B-BTV8?9E"#9OMN,V+0@V8;9B-N,V+/9A]BG.@#9@=F'V+'8
ML]BJ(-F^V*?;C-N,V8;B@(S9OMBQ`-BOV*?8L=F(V8?8IP#9AMBGV879AR#8
MI]F$VJG8JMBQV8C9AMN,VJG;C`#8HMBOV+'8LR#9AMBGV879A]F4(-BGV83:
MJ=BJV+'9B-F&VXS:J=N,`-BNV*?8JMF%V8<`15)2`-BNV+?8ISH@V;[;C-BZ
MV*?9A2#8M-F%V*<@V*K8K=F(VXS9A"#8K]BGV*_9AR#9AMBTV*\`V8C;C-BQ
MV*?;C-BT`-F(VXS8L=BGVXS8M"#9A-N,V+/8JB#8L]N,V*?9AP#9B-N,V+'8
MI]N,V+0@V*C9A-F(VJD`V8C;C-BQV*?;C-BT(-F!VXS9A-BJV+'9A]BG`-F(
MVXS8L=BGVXS8M"#:K]BQV8C9AP#9B-N,V+'8I]N,V+0@V878K-F(V+(`V8C;
MC-BQV*?;C-BT(-F%V*S9B-BRV8?8IP#9B-N,V+'8I]N,V+0@V878K-F(V++9
MA]BG(-BHV+'8I]N,("5S`-F(VXS8L=BGVXS8M"#9OMF(V+39A^*`C-F4(-F%
MV*S8I]BRVXP`V8C;C-BQV*?;C-BT(-BJV+G8L=N,V8$@V;[9B-BTV8?9E"#9
MA=BLV*?8LMN,("5S`-F(VXS8L=BGVXS8M"#9@=F'V+'8L]BJ(-BSV8';C-BO
M`-JOV++;C-F&V8?B@(S9A]BGVXP@V8C;C-BQV*?;C-BT.@#9B-N,V+'8I]N,
MV+0@V878K-F(V++B@(S9A]BG(-BHV+'8I]N,("(E<R(`V8C;C-BQV*?;C-BT
M(-F%V*S9B-BRXH",V8?8IR#8J-BQV*?;C"`E<P#9B-N,V+'8I]N,V+0@V8'9
MA]BQV+/8JB#8L]N,V*?9AR#8M-F%V*<`V8C;C-BQV*?;C-BT(-F"V8C8I]F&
MVXS9AB#9@=N,V838JMBQ(-BTV878IP#9B-N,V+'8I]N,V+0@VJ_8LMN,V8;9
MA^*`C-F'V*?;C"#8M-F%V*<@V*C8L=BGVXP@V*_8L]BJVXS8I]BHVXP@V*C9
MAR#8K=BSV*?8J-F'V*?;C"#9AMBGV879A]F4(-BOVXS:K]BQ`-F(VXS8L=BG
MVXS8M"#9@=F'V+'8L]BJ(-BSV8';C-BO(-BTV878IP#8JMBMV+7;C-F$V*?8
MJ@#8N=F&V+78L2XN+@!%;0#9AMBGV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;
MC`#8HMBOV+'8LR#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,`-BB
MV*_8L=BSV8?8I]N,(-F&V*?9A=F'XH",V8?8I]N,(-BGV83:J=BJV+'9B-F&
MVXS:J=N,(-BHV*?;C-BO(-F%V8;8M]BHV8(@V*C8I]BTV*\`V8;8I]F%V8?9
ME"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8J-BG(-BJV*/;C-N,V*\`V*?8K=BS
MV*?8L]BGV*H`V*K9A=BGV87;C"#9OMN,V+K8I]F%V8?8IR#8I]BR("5S(-BN
MV*?9A-N,(-BTV*_9AMBO`-BNV*?9A-N,(-JIV+'8K]F&(-F^V8C8M-F'*-F'
MV*<I`-BNV*?9A-N,(-JIV+'8K]F&(-F^V8C8M-F'XH",V8?8I]N,(-BGV8;8
MJMBNV*?8J"#8M-BOV8<`V*[8I]F$VXP@VJG8L=BOV88@V;[9B-BTV8?9E"#8
MHMBTV+K8I]F$`-BNV*?9A-N,(-JIV+'8K]F&(-F'V+'8LMF&V*?9A=F'XH",
MV8?8IP#8KMBGV83;C"#:J=BQV*_9AB#8L]BWV80@V*+8M-BZV*?9A`#8KMBG
MV83;C"#:J=BQV*_9AB#9OMN,V+K8I]F%(`#8KMBGV83;C"#:J=BQV*_9AB#9
MAMBJVXS8K-F'`-BNV*?9A-N,(-JIV+'8K]F&(-F%V8C8I]BQV*\@V*S8L]BJ
MV*S9B`#8HMN,V*<@V8+8I]BHV83;C-BJ(%!'4"#9@=BYV*?9A"#8M-F(V*_8
MGP#8HMN,V*<@V8+8I]BHV83;C-BJ(%,O34E-12#9@=BYV*?9A"#8M-F(V*_8
MGP#8HMN,V*<@V*_8L=BL(-BJV+78I]F(VXS8L2#8I]BR(-JOV*?9A-BQVXS9
MA]BGVXP@V+G:J=BS(-BOV+$@V878JMF&(-F!V+G8I]F$(-BTV8C8K]B?`-BB
MVXS8IR#9OMN,V+3B@(S9AMF%V*?;C-BTV8?8I]N,(-F^VXS8NMBGV84@V8'8
MN=BGV80@V+39B-BOV)\`V*+;C-BG(-JOV++;C-F&VJ_8I]F&(-BRV87;C-F&
MV8<@V+'9B-N,(-JIV83;C-JI(-BQV*?8L]BJ(-F!V+G8I]F$(-BTV8C8K]B?
M`-JOV++;C-F&V8?B@(SB@(S9A]BGVXP@V+'9A=BRV*C9AMBOVXP`V*?9AMBJ
MV8?8IP#8I]F&V*K9A]BGVXP@V;[;C-BZV*?9A>*`C"#8I]BQV*S8I]BY(-BT
MV*_9AP#8I]F&V*K9A]BGVXP@V;[;C-BZV*?9A0#8I]F&V*K9A]BGVXP@V;[;
MC-BZV*?9A2#8I]BR("5S`-BGV8;8JMF'V*?;C"#8L]BGV80`V*C8LMBQVJ\@
MVJG8L=BOV88@V8C;C-BQV*?8L]BJV*?8L0#9B-BGV+'8K]JIV+'8K]F&(-BY
MV*C8I]BQV*H@VJ_8L-BQ`-N,VJD@V+/8IMF(V*?9A"#8I]F%V8;;C-BJVXP@
MV*C8L=BGVXP@V;[8L=BSV+0@V*?8LB#8M-F%V*<@V*C9AR#9A]F&VJ_8I]F%
M(-BHV*?8LMF&V+38I]F&V*_9AB#8I]BSV84@V+'9A=BR(-F(V*?8L=BO(-JI
MV8;;C-BOV(P@V878J]F$V*?9DB`GV8;8I]F%(-BMVXS9B-BGV88@V*[8I]F&
MVJ_;C"#8M-F%V*<@VH;;C-BSV*K8GR<`55),(-BJV+79B-N,V+$@V+'8IR#8
MI]N,V8;8K-BG(-F(V*?8L=BO(-JIV8;;C-BO`-F&V*?9A2#9OMF(V+39A]F4
M(-F'V+'8LMF&V*?9A=F'V90@V*S8K]N,V*\@V*[9B-BO(-BQV*<@V8C8I]BQ
MV*\@VJG9AMN,V*\`V8;8I]F%(-F^V8C8M-F'V90@V;[;C-BT(-F&V8C;C-BS
M(-BLV*_;C-BO(-BNV8C8KR#8L=BG(-F(V*?8L=BO(-JIV8;;C-BO`-F&V*?9
MA2#9OMF(V+39A]F4(-F&V*?9A=F'XH",V8?8I]N,(-BGV+'8L]BGV80@V+38
MK]F'(-BLV*_;C-BO(-BNV8C8KR#8L=BG(-F(V*?8L=BO(-JIV8;;C-BO`-F&
MV*?9A2#9OMF(V+39A]F4(-BBV+38NMBGV80@V*S8K]N,V*\@V*[9B-BO(-BQ
MV*<@V8C8I]BQV*\@VJG9AMN,V*\`V8C8L=F(V*_;C"`E<R#8J-BG(-F%V8C9
M@=F1V8+;C-F1V*H@V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8I]BV
MV*?9@=F'(-BTV*\`V*[8M]BG`-BHV839B-JI(-BGVXS8K-BGV*\@V*[8M]BG
M.B`E<P#8KMBWV*<@V*_8L2#:J=BSV*@@V878K=BJV8C8ISHE<P#8KMBWV*<@
MV*_8L2#9@=BQV+/8JMBGV*_9AB#9OMBGV+/8KCHE<P#8KMBWV*<@V*_8L2#8
MJ-BQV8C8LMBQV+/8I]F&VXP@V*?8L]F%(-BQV878LB`Z("5S`-BNV+?8IR#8
MJ-BG(-F^VXS8NMBGV84@V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;
MC`#8N=BJVXS9@MF'`-BGV+'9B-F^V*<`V+'9B-N,V*_8I]BO(-BHV*<@V879
MB-F!V9'9@MN,V9'8JB#8K=BPV8$@V+38KP#9A]BQ(-F^V*?9AMBRV*_9AR#8
MK]F"VXS9@MF'`-F'V+$@V*_9B"#8K]F"VXS9@MF'`-F'V+$@V+/;C"#8K]F"
MVXS9@MF'`-F'V+$@V;[9AMBL(-BOV8+;C-F"V8<`V*_8L2#9A]BQ(-F(V+'9
MB-BO`-F'V+$@V8;;C-F%(-BSV*?8N=BJ`-F'V+$@V*_9@MN,V8+9AP#9A=F"
MV*?8K]N,V+$@V878J]BGV80Z`-BGV*S8L=BG`-BHV*?8LB#:J=BQV*_9A@#8
MJ-BGV++:J=BQV*_9AB#9A]F%V8<`V*C8I]BRVJG8L=BOV88@V8?9A=F'(-F^
MV8C8M-F'XH",V8?8IP#8J-BGV++:J=BQV*_9AB#9OMF(V+39AP#8J-BGV++:
MJ=BQV*_9AB#8I]BSV879A]BG`-BHV*?8LMJIV+'8K]F&(-F&V8C8I]BQ(-JI
MV8;8I]BQVXP`V*+;C-BG(-BGV+/8I]F%VXP@V*C8M]F(V+$@V*[9B-BOVJG8
MI]BQ(-BOV+$@V;[8L^*`C-BRV87;C-F&V8?9E"#8M=BZV*W9A]F4(-BGVXS8
MK-BGV*\@V;[;C-BZV*?9A2#8J-BGV+(@V+39B-F&V*_8GP#8HMN,V*<@V*C8
MM]F(V+$@V;[;C-BT(-F!V+'8MB#8K]BQ(-BHV*[8M"#9AMF%V*?;C-BT(-F^
MV8C8M-F'XH",V8?8I]B,(-BJV878I]F%VXP@V*_8L=BNV*H@V;[9B-BTV8<@
MV*C8I]BR(-BTV8C8K]B?`-BHV*?8LB#:J=BQV*_9A@#8I]F&V*K8N-BGV+$@
MV*C8L=BGVXP@)R@G`-BJV*?8L=N,V*X@V*?9AMF"V+;8I]BA`-F&V878I]N,
MV8;8K]F'`-BQV8;:KR#9OMN,V+3B@(S8LMF%VXS9AMF'`$944"!U<&QO860@
M;V8@<V5T=7``(-BHV*?8LMN,V*?8J-N,(-BJV8+8K]F%V*?8JB#9AMBGV879
MB-F!V9'9@B#8J-F(V*\`(-BGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@
M3$1!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\`(-BGV*K8M=BGV80@V*C9AR#:
MJ=BGV+'8L]BGV+(@4TU"(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR``(-BJV8?;
MC-F'(-BQV8C9AMF(V+38JB#8I]BR("(E<R(@V8;8I]F%V8C9@=F1V8(@V*C9
MB-BO`-BGVXS8K-BGV*\@V+'9B-F&V8C8M-BJ(-BOV+$@(B5S(B#9AMBGV879
MB-F!V9'9@B#8J-F(V*\`(-BGVXS8K-BGV*\@VXS:J2#8I]BJV+78I]F$(-BL
MV*_;C-BO(%-!4TP@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`"#8I]F&V*K9@MBG
MV80@V*C9AR`B)7,B(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP#9A-BWVXS9@0#8
MKMBWV*?;C"#8K-BOVXPZ(`#9@=JIV+,`V8'9B-BQVXS9AP#9B-BGVJG8M-N,
M(-F&V*?9A=F'`-BBVXS8IR#9AMBGV879AR#8K]BQ(-F^V8;8K-BQV8?9E"#8
MK-BOV*?:K]BGV8;9A^*`C-BGVXS;C"#9B-BGVJG8M-N,(-BTV8C8K]B?`-BB
MVXS8IR#9OMN,V+K8I]F%V8?8IR#8J-F%V*W8MB#9B-BQV8C8KR#9B-BGVJG8
MM-N,(-BTV8C9AMBOV)\`)60@V;[;C-BZV*?9A2#8I]BR("5S(-F(V*?:J=BT
MVXP@V+38K]F&V*\`VXS:J2#9OMN,V+K8I]F%(-BGV+(@)7,@V8C8I]JIV+3;
MC"#8M-BO`-F(V*?:J=BTVXP@V8;8I]F%V8<Z`-F(V*?:J=BTVXP@V8;8I]F%
MV8<Z(-F&V*?9A=F'V90@V*S8K]N,V*_;C"#9B-BLV8C8KR#9AMBOV*?8L=BO
M`-BQVJ_8J-BGV+$@V*[9@=N,V8$`VJG9A=N,(-BJVJ_8L=JO`-F!VXS9A-BJ
MV+'9A]BG`-F^V+'9B-F&V*_9A^*`C`#8M-F%V*?8L=BT(-F^V+'9B-F&V*_9
MASH@)7,@V;[8L=F(V8;8K]F'`-BTV878I]BQV+0@V;[8L=F(V8;8K]F'.B`E
M<R#9OMBQV8C9AMBOV8<`V878K]N,V+$@V;[8L=F(V8;8K]F'`-F&V*?9A2#9
MOMBQV8C9AMBOV8<`V*?9AMBJV*[8I]BH(-F^V+'9B-F&V*_9AP#8I]BQV+/8
MI]F$(-F^V+'9B-F&V*_9AP#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#9OMBT
MV*K;C-BHV*?9AMN,(-F&V87;C.*`C-BTV8C8KRXN`-JOV++;C-F&V8?B@(S9
MA]BGVXP@V8';C-F$V*K8L0#8JMF&V+C;C-F%V*?8JB#9@=N,V838JMBQ`-BB
MVXS8IR#9A=BVV879B-F&(-F^VXS8NMBGV84@V*C8L=BGVXP@V*C;C.*`C-BM
MV+'9A=BJVXP@V*C9AR#9A=F"V*_8L]BGV*H@V8';C-F$V*K8L2#8M-F(V*_8
MGP#9OMBTV*K;C-BHV*?9AMN,(-F!VXS9A-BJV+$@V*C8L2#8L=F(VXP@V*?;
MC-F&(-BSV*?9A=BGV8;9AR#9@=BYV*?9A"#9AMN,V+/8J@#9@=N,V838JMBQ
MV8?8IP#9@=N,V838JMBQXH",V8?8IR#9@=BYV*?9A"#9AMN,V+/8JMF&V*\`
MV8';C-F$V*K8L=F'V*<Z("5S(-BUV8'8K=F'V90@V878K]N,V+';C-BJ`-F^
MVXS8K]BGVJG8L=BOV88`V8;;C-F%V8<@V*?9B-F$`-BUV8'8K=F'V90@V*?9
MB-F$(-F&V*?9A=F'XH",V*_8I]F&(`#8M=F!V*W9A]F4(-BGV8C9A`#8L=BH
MV+D@V*?9B-F$`-F&V+/8J-BJ(-BKV*?8J-BJ`-BGV+G8M-BGV+';C`#8I]BQ
MV*S8I]BY`-F%V8?B@(S8HMF$V8C8KP#9OMF(V+39AR`E<R#9A=F(V*S9B-BO
M(-F&VXS8L]BJ(`#8N=F%V83;C-BGV*H@V;[9B-BTV8<@+2#8JMBCVXS;C-BO
M`-F&V*?9B-BTVJ_8L2#9OMF(V+39AP#8KMF$V*?8M=F'V90@V;[9B-BTV8<`
MV*C9AR#8I]BTV*K8L=BGVJD@VJ_8L-BGV+38JMF&(-F^V8C8M-F'(-F%V8+8
MK]F(V+$@V8;;C-BSV*H`V*?8L]BJV8'8I]BOV8<@V*?8LB#9OMF(V+39AR#9
MA=F"V*_9B-BQ(-F&VXS8L]BJ`-BQV8;:KR#9@MF$V84`V+K8L-BG`-BHV+'8
MI]N,(-F%V+'9B-BQVJ_8L=F'V*?;C-N,(-JIV8<@V*K8M=BGV8C;C-BQ(-BQ
MV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V8;8KP#9OMN,V+3"
MK=BHVXS9AMN,`-BGV+/9A2#8L=F%V+(@V*[9B-BO(-BQV*<@V8'8L=BGV879
MB-BT(-JIV+'8K]F'XH",V*?B@(S;C-BOV)\`V8'8L=F%V*H@V*K8I]BQVXS8
MKB#9AMBGV879AR#8K]BQ(-F&V*?9A=F'XH",V*_8I]F&(-BHV+'8I]N,(-F&
MV*?9A=F'XH",V8?8I]N,(-BGV878L=F(V+(@`-F!V+'9A=F'V*<`V+?8I]F$
MV+D`V8;9B-BY(-BWV*?9A-BY`-BWV*?9A-BYV8?8IP#8M]BGV838N=F'V*<@
MV[(`V*?9AMBLV879AMF'V*<`V*?8L=BLV*?8N0`ZV*?8L=BLV*?8N0#9OMN,
MV+K8I]F%(-BGV+'8K-BGV+D@V+38K]F'`-F^VXS8NMBGV84@V*?8L=BLV*?8
MN2#8M-BOV8<@V*?8LB`E<P#8I]BQV*S8I]BYV8?8IP#8K-F%V+G9AP#:AMBG
MV+':AMF(V*C9A]BG`-BGV+?9A-BGV+G8I]BJ(-BBV++8I]BO+]F%V+38NMF(
MV80`V;[8I]BSV*X@V*+8LMBGV*\OV878M-BZV8C9A`#8K]BQV*[9B-BGV+/8
MJB#8HMBRV*?8KR_9A=BTV+K9B-F$`-F^V*?8L]BN(-BOV+'8KMF(V*?8L]BJ
M(-BBV++8I]BO+]F%V+38NMF(V80`V*?8L@#8I]BR`-BGV+(@V*+8K]BQV+,`
MV*?8LB``V+38L=BM(-JIV*?9A=F$`-F%V*?9AR#:J=BGV879A`#9AMBGV84@
MVJG8I]F%V80`V*?8L=BLV*?8N3H`V*?8L=BLV*?8N3H`V*?8L=BLV*?8N3H@
M)74@V;[;C-BZV*?9A=F'V*?;C"#8I]BQV*S8I]BY(-BTV*_9AP#:K]BGV838
ML=N,(-BHV+'8I]N,(-BOV+';C-BGV8'8JB#8JMBUV8C;C-BQ(`#:K]BGV838
ML=N,.@#:K]BRVXS9AMF'XH",V8?8I]N,(-BYV879B-F%VXP`V*K9B-F$VXS8
MKR#9OMN,VJG8L=BHV8;8K]N,("5S`-JIV*\@V*K9B-F$VXS8KR#8M-BOV8<`
MV*+;C-BG(-F!V8+8MR#9OMN,V+K8I]F%V8?8I]N,(-BLV*_;C-BO(-JOV+'9
M@=BJV8<@V+39B-F&V*_8GR`HV8'9@MBW($E-05`I`-F&V*?9A2#8K]BGV*_9
MAR#8M-BOV8<`V*C8I]BRVJ_8M-BJ(-BHV8<@V;[;C-BZV*?9A0#8J-BQV8@@
MV*C9AR#9B-BQV8C8K]N,(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS("(E<R(@
M`-BLV+/9AMBLV8C;C"#:K]F(VJ_9A`#9B-BGVJ_8L-BGV+';C"#8K]BSV*K8
ML=BSVXP`V*_8L=BLV8<@V*[8I]JIV+/8JMBQVXP`1W)E96L@*$E33RTX.#4Y
M+3<I`-BSV+'9OMBQV+/8JMN,(-JOV+'9B-F'`-F&V*?9A2#:K]BQV8C9AR#9
MAMBHV*?;C-BO(-BNV*?9A-N,(-BHV*?8M-BO`-JOV+'9B-F')B-X,C`P8SO9
MA]BG`-F%V*S9B-BRV8?8I]N,(-F%V8?9A=BGV88`VJG8JMBGV*C:AMF'V90@
MVXS8I]BOV*C9B-BO`-BGVXS9AMBLV*<`2%1-3`#9AMBSV*[9A]F4($A434P@
MV*?8LB#9OMN,V+K8I]F%`$A434Q!<F5A(-BMV+#9@2#8HMBNV+';C-F&(-BS
MV839B-F$(-BQV*<@V*_8L2#8L=BOVXS9@2#8L=BO(-F%VXSB@(S:J=F&V*\`
M2%1-3$%R96$@V*W8L-F!(-BBV*[8L=N,V88@V+/8JMF(V88@V+'8IR#8K]BQ
M(-BLV*_9B-F$(-BQV*\@V87;C.*`C-JIV8;8KP!(5$U,07)E82#8K=BPV8$@
MV*+8KMBQVXS9AB#8L=BOVXS9@2#8L=BG(-BOV+$@V*S8K]F(V80@V+'8KR#9
MA=N,XH",VJG9AMBO`-BJV+78K]N,V8(@V8?9B-N,V9'8JB!(5%10(-N,V*?9
M@=BJV8<@V8;8M-BO`-BGV83:K]F(V+';C-BJV84@2&%S:`#9A=F'XH",V*+9
MA-F(V*\`V+/8L=BBV878KP#8L]BQV*+9A=BOV8?8IP!(96)R97<@*$E33RTX
M.#4Y+3@M22D`V*C9A-F&V*_;C`#8L=BGV8?9AMF%V*<`V+'8I]F'V8;9A=BG
MVXP@V*?8L]BJV8'8I]BOV8<@V*?8LB#9B-N,V+'8I]N,V+3:K]BQ`-JIV87:
MJ2#:J=F&V8;8K]F'`-F&VXS9A>*`C-JIV+'9AP#8I]N,V8;8K-BG(-BGV*C8
MJMBOV*?;C"#9OMBQV8C9AMBOV8?B@(P@V87;C.*`C-BHV*?8M-BO.@#8I]N,
MV8;8K-BG(-F^VXS8NMBGV87;C"#8I]BSV*H@VJG9AR#8M-F%V*<@V8;9B-BT
MV*K9A^*`C-BGXH",VXS8KSH`V;[9AMF'V*?9AB#:J=BQV*_9A@#9OMF&V8?8
MI]F&(-JIV+'8K]F&(-BOV+$@V8;9A=BGVXS8M"#8L]F$V+/9A-F'XH",V*?;
MC-N,(`#B@(W9OMF&V8?8I]F&(-JIV+'8K]F&(-BMV+#9@2#8M-BOV8?B@(S9
MA]BG`-F^V8;9A]BGV88@VJG8L=BOV88@V+K;C-BQV+G8MMF(XH",V8?8IP#8
MJ-BGV838IP#8I]F(V839B-N,V*H@V*C8I]F$V*<`V*C8I]F$V*?8JMBQVXS9
MA@#8KMBGV8;9AP#8KMBGV8;9AP#8HMBOV+'8LR#8KMBGV8;9AP#8M-BGV*[9
MA]F4(-BGV+79A-N,`-BTV878I]BQV8<@V*K9A-F!V88@V879AMBRV80`V8?9
MB-BQV*\`2&]R9&4O2V]L86(Z("5S(-BHV*<@V*_8I]BOV8<@V8;8I]BOV+'8
ML]BJ(%A-3"#8K]BQ(-F^VXS8NMBGV84@)7,@V879B-BGV*S9AR#8M-BOV8<@
MV*?8L]BJ`$AO<F1E+TMO;&%B.B#9A]N,VH8@V;[;C-BZV*?9A=N,(-F%V+?8
MI]BHV8+8JB#8J-BG(-BTVXS8H2`E<R#9AMBOV*?8L=BO`$AO<F1E+TMO;&%B
M.B#9A]N,VH8@V+3;C-BFVXP@V*?8LB#9AMF(V+D@)7,@V*_8L2#9OMN,V+K8
MI]F%("5S(-N,V*?9@=BJ(-F&V+38KP!(;W)D92]+;VQA8CH@V*C8IR#9A=F(
MV8'9D=F"VXS9D=BJ("5S("(E<R(@V*W8L-F!(-BTV*\`2&]R9&4O2V]L86(Z
M(-BJV8C9A-N,V*\@VXS:J2#8K]BQV*[8JB#8K-BOVXS8KR!834P@V*C8L=BG
MVXP@V+3;C-BA("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@`$AO<F1E+TMO;&%B
M.B#8K=BPV8$@)7,@(B5S(CHE<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ`$AO<F1E
M+TMO;&%B.B#8J-BGV++;C-BGV*C;C"`@34E-12!)1"#8J-BQV*?;C"#9@MBS
MV878JMN,(-BGV+(@V8;9B-BY("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@`$AO
M<F1E+TMO;&%B.B#8L]F&VJG8L=F(V88@VJG8L=BOV88@)7,@(B5S(CH@)7,@
MV879@MBOV8C8L2#9AMN,V+/8J@!(;W)D92]+;VQA8CH@V+/9AMJIV+'9B-F&
M(-JIV+'8K]F&(-BGV+38JMBQV*?:J=F'V*<@V879@MBOV8C8L2#9AMN,V+/8
MJCH@)7,`2&]R9&4O2V]L86(Z(-BGV+38JMBQV*?:J2#9AMBGV+39AMBGV*[8
MJMF'("(E<R(`V8+8I]F&V8C9AB#8I]F!V8+;C`#9@=BGV+79A-F'XH",VJ_8
ML-BGV+';C"#8I]F!V8+;C``ZV*?9@=F"VXP`VH;:K]F(V8;9AR#8J-BG(-BG
MVXS9AMBLV*<@V*+8M-F&V*<@V+38K]N,V*_8GR`HV838M]F!V*?9BR#:K]BR
MV*?8L=BT(-BOV8?;C-BO*2$`VH;:K]F(V8;:K]N,(-F&V878I]N,V+0@V;[;
MC-F(V+/8JN*`C-F'V*<`VH;9AMBO(-BSV*K9B-F&(-BQV*<@V87;C.*`C-BN
MV8C8I]F'VXS8KR#8I]BOV+K8I]F%(-JIV8;;C-BOV)\`VH;9AMBO(-F!VXS9
MA-BO("C8L]BJV8C9ABD@V8C8K-F(V*\@V*_8I]BQV*_8GP#:AMF&V*\@V+/8
MM]BQ(-BQV*<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BOV+K8I]F%(-JIV8;;
MC-BOV)\`VH;:K]F(V8;:K]N,(-F%V+38KMBU(-JIV+'8K]F&(-BNV+?9A]BG
MVXP@V8;9@MF$(-F"V8C9A"#8K]BQ(-N,VJD@V;[8I]BSV*X`V+'8M]F(V*C8
MJ@#8L=BWV8C8J-BJ.B``24U!4`!)34%0("C9OMN,V*_8IR#:J=BQV*_9AB#9
MOMBQV8C8JMJIV839A]BG(-BHV+?9B-BQ(-BNV8C8K]JIV*?8L2D`V*?;C-BL
MV*?8KR#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BH
MV8C8KSH@("5S`-BMV+#9@2#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9
MA=F(V8'9D=F"(-BHV8C8KR`Z("5S`-BGVXS8K-BGV*\@V878K=BOV8C8K]N,
MV9'8JB#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BH
MV8C8KR`Z("5S`$E-05`@V+'9B-N,(%-33`!)34%0(-BHV+$@4U-,("C:K]F(
MV*?9A]N,(-BNV8C8K]BGV878MMBGV*$I(`!)34%0(-BHV+$@4U-,*-JOV8C8
MI]F'VXP@V*[9B-BOV*?9A=BVV*?8H2D@`$E-05`@V(S9AMF'(%1,4P#:J=BG
MV+'8L]BGV++9A]BGVXP@V8;8I]F%V8?B@(S9A]BGVXP@V*?9A-JIV*K8L=F(
MV8;;C-JIVXP@24U!4"]03U`S`$E.0D]8`-BBV*_8L=BS($E0`-BBV*_8L=BS
M($E0(-F"V*?8J-F$(-BOV+/8JMBQV+/;C"#9AMN,V+/8J@#8HMBOV+'8LR!)
M4"#8K]BQ(-BOV*?8KMF$(-BHV839B-JI($-)1%(@V*?8K-BGV++9AR#8K]BG
MV*_9AR#9AMF%VXSB@(S8M-F(V*\`V*?8J-BJV*_8IR#8L]BWV+$@V+'8IR#9
MB-BGV+'8KR#:J=F&VXS8KP#9@=F"V+<@V*+;C-JIV8C9AMF'V*<`V*+;C-JI
MV8C9AMF'V*<@V*C8L=BGVXP@)7,`V*+;C-JIV8C9AMF'V*<@V*C8IR#9A=BJ
MV88`V8;8I]F%(-F'V8C;C-F1V*HZ`-BGVJ_8L2#8HMF&(-BHV8<@V*_8L=BS
MV*K;C"#9AMF%V*?;C-BT(-BOV*?8K]F'(-F&V+38K]B,("5S("#8J-BQV*?;
MC"#8J-BGV+(@VJG8L=BOV88@V*+9AB#8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8
MK-BOVXS8KP#8K]BQ(-BUV8C8L=BJ(-BGV*_8I]F%V8?8C"#8JMF%V*?9A=N,
M(-F^VXS8NMBGV879A]BG(-BOV+$@V*?;C-F&(-F^V8C8M-F'*-F'V*<I(-BG
MV+(@V*C;C-F&(-BNV8C8I]F'V*\@V+'9@=BJ(0#8I]JOV+$@V+39A=BG(-F'
MVXS:AB#8HMN,VJG9B-F&VXP@V+'8IR#8K]BQ(-F%V+'9B-BQVJ_8L2#9AMBH
MVXS9AMN,V*_8C"#9A=F%VJG9AB#8I]BSV*H@V838I]BRV84@V*C8I]BTV*\@
MVJG9AR!03D<@5')A;G-P87)E;F-Y(-BQV*<@V*[8I]F%V8C8M"#:J=F&VXS8
MKP#8I]JOV+$@V+39A=BG(-BGVXS9AB#9OMN,V+K8I]F%(-BQV*<@V878M-BG
MV8?8K]F'(-JIV8;;C-BO(-BGV878IR#8JMBUV8C;C-BQVXP@V+'8IR#9A=BT
MV*?9A]BOV8<@V8;:J=F&VXS8K]B,(-BGVXS9AB#8J-F'(-BGVXS9AB#8N=F$
MV*H@V*[9B-BGV8?8KR#8J-F(V*\@VJG9AR#9A=BQV8C8L=JOV+$@V+39A=BG
M(-F!V*?8K]BQ(-BHV8<@V8;9A=BGVXS8M"#8JMBUV8C;C-BQ(-F&VXS8L]BJ
M(`#9AMBGV*_;C-BOV8<@VJ_8L=F!V*K9A@#9AMBGV*_;C-BOV8<@VJ_8L=F!
MV*K9AB#9A]F%V8<`V*K8M=F(VXS8L0#9OMN,V+3B@(S9AMF%V*?;C"#8JMBU
MV8C;C-BQ.@!54DP@V*K8M=F(VXS8L0!54DP@V*K8M=F(VXS8L3H`V*K8M=F(
MVXS8L2#8I]BR(-JOV*?9A-BQVXP`V*K8M=F(VXS8L2#8I]BR(-JOV*?9A-BQ
MVXPZ`-BGV+'8L]BGV80@V*K8M=F(VXS8L0#8JMBUV*?9B-N,V+$`V*_8L=F(
MV8;B@(S8J-BQV*\`V*_8L=F(V8;B@(S8J-BQV*\@VJG9A-N,V*\`V*_8L=F(
MV8;B@(S8J-BQV*\@V*S9@=BJ(-JIV83;C-BO`-BOV+'9B-F&XH",V*C8L=BO
M(-F^VXS8NMBGV879A]BG`-BOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(%!'
M4`#8K]BQV8C9AN*`C-BHV+'8KR#:K]F(V*?9A]N,V8?8I]N,(-BTV*[8M=N,
M`-BOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(-BNV+79B-BUVXP@V+38KMBU
MVXP@4$=0`-BOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(-BYV879B-F%VXP@
MV+38KMBUVXP@4$=0(`#8K]BQV8C9AN*`C-BHV+'8KR#:K]F(V*?9A]N,V8?8
MI]N,(%,O34E-12#8M-BNV+7;C`#8K]BQV8C9AN*`C-BHV+'8KR#:J=F$VXS8
MKR#8N=F%V8C9A=N,`-BOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(-BYV879
MB-F%VXP@4$=0`-BOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(%,O34E-12#8
MN=F%V8C9A=N,(`#8K]BQV8C9AN*`C-BHV+'8KR#:J=F$VXS8KR!3+TU)344`
MV*_8L=F(V8;B@(S8J-BQV*\@V;[8L=F(V8;8K]F'V93B@(P@;6)O>`#8K]BQ
MV8C9AN*`C-BHV+'8KR#9OMBQV8C9AMBOV8?9E.*`C"`E<R!M8F]X(-BOV+$@
MV;[9B-BTV8?9E"`E<P#8K]BQV8C9AN*`C-BHV+'8K]B,(-JOV*?9A2`E9`#9
MA=F'V84`V;[;C-BZV*?9A=F'V*?;C"#9A=F'V84`)60@V;[;C-BZV*?9A2#8
MI]BR("5S(-BOV+'9B-F&XH",V*C8L=BO(-BTV*\`V8';C-F$V*\@V*_8L=F(
MV8;B@(S8J-BQV*\@V+38K]F'.B`E<P#9@=N,V838K^*`C-F'V*?;C"#8K]BQ
MV8C9AN*`C-BHV+'8KR#8M-BOV8<Z`-BOV+$@V*W8I]F$(-BGV8;8K-BGV84`
MV*C8N=BOV*?9BR#8L]BWV+$@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KP!);F)O
M>`#8HMN,V*<@V;[8I]BSV*X@V+38I]F%V80@VXS:J2#8KMF$V*?8M=F'(-BG
MV+(@V+/8L=BBV878KR#8J-BGV+38K]B?`-BBVXS8IR#9OMBGV+/8KB#8M-BG
MV879A"#9OMN,V+K8I]F%(-BGV+79A-N,(-BHV*?8M-BOV)\`VJG8KR#8N=F%
MV83:J=BQV*\@V8;8I]BOV+'8L]BJ(-BOV*?8K]F'(-BTV*_9AR#8I]BSV*H`
M(-F&V*?9A2#:J=BGV+'8J-BQ+]BGV+/9A2#8L=F%V+(@(-F&V*?8K]BQV+/8
MJB#8I]BSV*H`V8;8I]F%(-JIV*?8L=BHV+$@VXS8IR#8HMBOV+'8LR#8K-BG
MVXS:K]BRVXS9AB#9AMBGV*_8L=BSV*H@V87;C.*`C-BHV*?8M-BO+B#9A-BW
MV8'8IR#9A=BLV*_8K]BGV9(@V+/8N=N,(-JIV8;;C-BO(-F((-N,V*<@V*_8
ML2#8M=F(V+'8JB#9AMN,V*?8LB#8J-F'(-JIV87:J2#8J-N,V+38JMBQ(-BH
MV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8JMF%V*?8LR#8J-JOVXS8
ML=N,V*\`V*?9@=BRV*?;C-BT(-BJV8C8L=F!V*K:K]N,`-JIV*?8L=BHV+'8
MI]F&(-BNV*?8M0#8I]BWV838I]BYV*?8J@#8I]BWV838I]BYV*?8J@#8I]BW
MV838I]BYV*?8JB#8K]N,VJ_8L2#8K]BQ(-BOV+/8JMBQV+,@V8;;C-BSV*H`
MV*?8M]F$V*?8N=BGV*H@V*C8L2#8L=F(VXP@VJG9A-N,V*\@V+G9A=F(V87;
MC"`E<P#8I]BWV838I]BYV*?8JB#8J-BQ(-BQV8C;C"#:J=F$VXS8KR#8KMBU
MV8C8M=N,(-BTV*[8M=N,`-BGV+?9A-BGV+G8I]BJ(-BHV+$@V+'9B-N,(-JI
MV83;C-BO(-BYV879B-F%VXP@V+38KMBUVXP`V*_8L2#8KMBW`-BOV+'8K"#8
ML]BJV8C9AB#8J-BYV*\@V*?8L@#:K]F(V*?9A]N,(-BQV*<@V*?;C-F&V*S8
MIR#8K]BQV*P@VJG9AMN,V*\`V*_8L=BL(-BJV+79B-N,V+$`VJG9A-N,V*\@
MV878K=BQV878I]F&V8?9E"#8M-BNV+7;C"!01U`@V+'8IR#8I]N,V8;8K-BG
M(-BOV+'8K"#:J=F&VXS8KP#:J=F$VXS8KR#8N=F%V8C9A=N,(-BTV*[8M=N,
M(%!'4"#8L=BG(-BGVXS9AMBLV*<@V*_8L=BL(-JIV8;;C-BO`-JIV83;C-BO
M(-BYV879B-F%VXP@4$=0(-BQV*<@V*?;C-F&V*S8IR#8K]BQV*P@VJG9AMN,
MV*\`V*_8L=BL(-BLV*_9B-F$`-BOV+'8K"#9OMN,V8C9AMBO(-F(V*@`V*?8
MJ-BJV*_8IR#8L]BJV8C9AB#8L=BG(-BOV+'8K"#:J=F&VXS8KP#;C-JI(-BS
MV*K9B-F&(-BLV*_;C-BO(-BHV+G8KR#8I]BR(-BSV*K9B-F&(-F!V+G9A-N,
M(-BOV+'8K"#:J=F&VXS8KP#;C-JI(-BSV*K9B-F&(-BLV*_;C-BO(-F"V*C9
MA"#8I]BR(-BSV*K9B-F&(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KP#;C-JI
M(-BSV+?8L2#8K-BOVXS8KR#8J-BYV*\@V*?8LB#8L]BWV+$@V8'8N=F$VXP@
MV*_8L=BL(-JIV8;;C-BO`-N,VJD@V+/8M]BQ(-BLV*_;C-BO(-F"V*C9A"#8
MI]BR(-BSV+?8L2#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\`VXS:J2#9OMBG
MV+'8I]JOV+'8I]F!(-BHV+G8KR#8I]BR(-JOV+'9AR#9@=BYV83;C"#8K]BQ
MV*P@VJG9AMN,V*\`VXS:J2#9OMBGV+'8I]JOV+'8I]F!(-F"V*C9A"#8I]BR
M(-JOV+'9AR#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\`V*_8L=BL(-BGV83:
MK]F(VXP@V*S8I]N,VJ_8LMN,V88`VXS:J2#8HMBOV+'8LR#9OMBSV*H@V*?9
MA-JIV*K8L=F(V8;;C-JI(-BHV+'8I]N,(-BOV+';C-BGV8'8JB#8I]BSV84@
MV+'9A=BR("#8K-BOVXS8KR#8K]BQV*P@VJG9AMN,V*\@`-BOV+'8K"#8L]F$
MV8C9A"#8J-BYV*\`V*_8L=BL(-BSV839B-F$(-F"V*C9A`#8K]BQV*P@V+/8
MJMF(V88@V*C8N=BO`-BOV+'8K"#8L]BJV8C9AB#9@MBHV80`V*_8L=BL(-F^
MVXS8NMBGV84`V*_8L=BL(-F^V*?8L=BGVJ_8L=BGV8$@V*C8N=BO`-BOV+'8
MK"#9OMBGV+'8I]JOV+'8I]F!(-F"V*C9A`#8K]BQV*P@V+/8M]BQ(-BHV+G8
MKR``V*_8L=BL(-BSV+?8L2#9@MBHV80`V;[8I]BSV*X@V879B-BQV*\@V8;;
MC-BGV+(@V+'8IR#8J-BQV*?;C"#8L]BFV8C8I]F$(-BGV879AMN,V*K;C"#8
MK]BQV*P@VJG9AMN,V*\Z`-BOV+'8K"_8JMBZVXS;C-BQ(-BJV+79B-N,V+$`
MV*_8L=BL+]BJV+K;C-N,V+$@V;[;C-F(V8;8KP#8I]BYV*K8J-BGV+$@V8;8
MI]JIV*?9@=N,(-BHV+'8I]N,(-BGV+'8L]BGV80@V*C9AR#9@=F'V+'8L]BJ
M(-BJV8C8LMN,V+G;C`#8I]BYV*K8J-BGV+$@V8;8I]JIV*?9@=N,`-BYV*_8
MKR#8M=BMVXS8K0#9@=F'V+'8L]BJ(-BYV*_8KR#8M=BMVXS8K0#8N=F%V80@
MV+K;C-BQV878N=BJV*C8L=N,(-BHV+'8I]N,(-BGVXS9AB#9A=BDV839@=F'
M(-BGV8;8JMBNV*?8J"#8M-BOV8<@V*?8L]BJ`-BBV*_8L=BS(-BZVXS8L=F%
MV+G8JMBHV+$`V8;8I]F%V8?B@(S8K]BGV88@V+'8I]F'(-BOV8C8L2#8NMN,
MV+'9A=BYV*K8J-BQ`%5$2"#9AMBGV878N=BJV*C8L0#8J-BQV8;8I]F%V8?9
ME"#:J=BGV+'8J-BQV*_;C"#9AMBGV878N=BJV*C8L0#8K]BSV*K9AR!)1"#9
MAMBGV878N=BJV*C8L0#9AMF(VXS8L]F'V90@V+K;C-BQV878N=BJV*C8L2#8
MK]BQ(-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@.B`E<P#8
MK]BGV*_9A]F4(-F&V*?9A=BYV*K8J-BQ(-BGV+'8I]BFV8<@V+38K]F'`-BB
MV*_8L=BS(-F%V8+8M=BO(-F&V*?9A=BYV*K8J-BQ`-F"V*?9A-BH(-F^V+'9
MB-F&V*_9A]F4(-F&V*?9A=BYV*K8J-BQ`-JIV83;C-BO(-BZVXS8L=F%V+G8
MJMBHV+$`V8;9B-BY(-F^VXS8NMBGV84@V8;8I]F%V+G8JMBHV+$`87!I7VED
M(-F&V*?9A=BYV*K8J-BQ(-BGV+/8JB#9B"#;C-BG(-BGV+(@V*C;C-F&(-BQ
MV8'8JMF'(-BGV+/8J@#9OMBGV+'8I]F%V*K8L2#9AMBGV878N=BJV*C8L2#9
MB"#;C-BG(-BGV+(@V*C;C-F&(-BQV8'8JMF'`-F%V*S9B-BR(-F^V*_8L2#9
MAMBGV878N=BJV*C8L0#:J=F$VXS8KR#8NMN,V+'9A=BYV*K8J-BQ(-F%V*W8
ML=F%V*?9AMF'V90@V+38KMBUVXP@4$=0(`#:J=F$VXS8KR#8NMN,V+'9A=BY
MV*K8J-BQ(-BYV879B-F%VXP@V+38KMBUVXP@4$=0`-F^V+'9B-BJVJG9A"#9
MAMBGV878N=BJV*C8L0#:K]N,V+'9AMBOV8?9E"#9AMBGV878N=BJV*C8L3H@
M(B5S(@#8M-N,V*$@V*C9AR#8I]BTV*K8L=BGVJD@VJ_8L-BGV+38JMF'(-BT
MV*_9A]F4(-F&V*?9A=BYV*K8J-BQ`-BBV*_8L=BS(-BSV+':AMBTV879AR#9
MAMBGV878N=BJV*C8L0#8K]BGV*_9AR#;C-F(V8;;C-JIV*\@V8;8I]F%V+G8
MJMBHV+$@`-F%V8C8K-F(V*_;C`#9A=BYVJG9B-BS`-BHV+':K]BQV*_8I]F&
MV*_9AB#8I]F&V*K8KMBGV*@`5"U3=&]R;7,`V879AMBJV+38L2#:J=F&V8;8
MK]F'`-BMV+'9B-F!(-JIV*P`VIC8I]F&V8C;C-F'`$IA<&%N97-E("A)4T\M
M,C`R,BU*4"D`V++;C-BQV;[;C-BQV*?9A]F&VXP`VIC9B-BFVXS9AP#:F-F(
MV*;9A@#9A]F%XH",V*K8L=BGV+(@VJG8L=BOV88`V8?9A>*`C-BJV+'8I]BR
MVXP@V8C8L]BW`-F'V87B@(S8JMBQV*?8LMN,(-JIV*?9A=F$`-F'V87B@(S8
MJMBQV*?8LMN,(-J&V;X`V8?9A>*`C-BJV+'8I]BRVXP@V+'8I]BSV*H@`-JI
MVXS9A-F(V*C8I]N,V*H`V*?8M=F$VXP@V8;:K]F'(-BOV*?8M-BJV8<@V+39
MB-BOV)\`VJG8I]BQV+/8I]BR(&ME<F)E<F]S92#8JMBUV*_;C-F"(-F'V8C;
MC-F1V*H@V+'8IR#8L=BO(-JIV+'8KP#8I]N,V*S8I]BO(-JIV83;C-BO`-BG
MV*O8L2#8I]F&VJ_8M-BJ(-JIV83;C-BO`-BWV8C9A"#:J=F$VXS8KP#9AMF(
MV+D@VJG9A-N,V*\`VJG8I]BQV*C8L=BO(-JIV83;C-BO`-JIV83;C-BO(-F"
MV*C9A-BGV8L@V*_8L2#:J=BGV+'8L]BGV+(@V+G9A=F(V87;C"#:J=F$VXS8
MKR#9A=F(V*S9B-BO(-BGV+/8J@#8K]BQV8C9AN*`C-BHV+'8KR#:J=F$VXS8
MKR#8K]BQ(-BOV+/8JMBQV+,@V8;;C-BSV*HN(-BGV+'8L]BGV80@V8'8I]N,
MV80@V*C8L2#8L=F(VXP@V*?;C-F&(-JIV*?8L=BSV*?8LB#9A=F"V*_9B-BQ
M(-F&VXS8L]BJ`-BOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(-BOV+$@V*_8
ML]BJV+'8LR#9AMN,V+/8JBX@V+39A=BG(-JIV*K8I]BHVH;9A]F4(-BBV*_8
ML=BSVXP@V*C8L=BGVXP@V*K9A=BGV+/9A]BGVXP@V*[9B-BO(-F%V+38KMBU
M(-F&V8;9A=F(V*_9A^*`C-BGVXS8KP#:J=F$VXS8KR#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*C9AR#:J=BGV+'8L]BGV+(@VJG9A-N,V*\@V+G9A=F(V87;
MC"#9@=BQV+/8JMBGV*_9AR#8M-BO`.*`C-BHVH;9A^*`C-F'V*<`2V]R96%N
M("A%54,M2U(I`-BLV*?9AMF%V*?;C-N,`-BRV*C8I]F&`-F&VXS9A=F'V90@
MV*+8KMBQ`-BUV8'8K=F'V90@V*+8KMBQ(-F&V*?9A=F'XH",V*_8I]F&`-BU
MV8'8K=F'V90@V*+8KMBQ`-BJV+K;C-N,V+$@V*+8KMBQVXS9AB#8I]BSV84@
MV+'9A=BR`-BQV*C8N2#8HMBNV+$`V*+8KMBQVXS9AB#8J-BQV8C8LMBQV+/8
MI]F&VXPZ`-BBV*[8L=N,V88@V8C8L=F(V*\Z("5S`-BBV*[8L=N,V88@V8C8
ML=F(V*\@.B`E<R#8I]BR("5S`-BBV*[8L=N,V88@V8C8L=F(V*\Z(-F'V+':
MK]BR`-BMV8+9B-F"`-BLV*?9AMF%V*?;C-N,`-J&V;X`V+/8L=BBV878KR#:
MAMF^`-F%V8+8I]BOVXS8L2#:AMF^`-F^VXS9B-F&V*\@V;[;C-F(V+/8JMF'
MV*<`V8;9A>*`C-F&V84@V*C8I]BQV*?9A@#8J-BGV+'9AMBOVJ_;C"#8L]BH
MVJD`V*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BRV8C8K]F'V8;:K]BGV84`V*C8
MI]BQV8;8K]JOVXP@V+/8J-JI(-BOVXS8L=F'V8;:K]BGV84`V*C8I]BQV8;8
MK]JOVXP@V8@@V+':K]BHV*?8L2#8L]BHVJD`V*C8I]BQV*?9AB#8L]BHVJD@
MV*C9AR#9A]F%V+'8I]F'(-BQV+G8KP#8J-BQV8$@V+/8J-JI`-BHV+'9@2#9
MB"#8L=JOV*C8I]BQ(-BSV*C:J0#9OMN,V8C9AMBO`-F&V8+8I]BW(-F^VXS9
MB-F&V*\@V*C9ASH`V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:
MJ2#8L=BG(-BHV8<@V+79@=BMV8<@V*?;C-BLV*?8KR#9OMN,V+K8I]F%V(P@
MV*C9AR#9A]F&VJ_8I]F%(-F%V+38I]F'V*_9A]B,(-F^VXS9B-F&V*\@V*_9
MA]N,V*\`V;[;C-F(V+/8JMF'V*?;C"#9OMN,V8C9AMBOVXP@V878K-BGV+(@
MV8;;C-BSV*H`V;[;C-F(V8;8K^*`C-F'V*<`V;[;C-F(V8;8K]F'V*<@V*C8
ML2#8L=F(VXP@)7,@V879AMF"V+;;C"#8KMF(V*?9A]F&V*\@V+38KRX`VJG9
MB-JIVXP@V83;C-F&V8C:J=BS`-F!V8?8L=BSV*H@+2#:J=BGV+'8J-BQ(-F%
MVXSB@(S8JMF(V*?9AMBO(-F^V8C8M-F'(-BQV*<@V*C8J-N,V8;8KP#9@=F'
MV+'8L]BJ(-BOV*?8K]JOV*?9AMF'V*?B@(P`V8'9A]BQV+/8JB#8N=F&V*?9
MB-N,V88@V+'8I]F'V8;9A=BG`-F!V8?8L=BSV*H@V*S8K]BGV8C9A`#8HMN,
MV*<@V8?9AMJOV*?9A=N,(-JIV8<@V+79@=BMV8?9E"#8JMF%V*?8L]F'V*<@
MV*C8I]BQ(-F%VXSB@(S8M-F(V*\@V*K9A=BGV87;C"#8JMF%V*?8L]F'V*<@
MV8'9A]BQV+/8JB#8M-F(V8;8K]B?("C8K]BQ(-BZVXS8L2#8I]N,V8;8M=F(
MV+'8JB#8JMF&V8?8IR#8M-F%V*<@V*K9A=BGV+/9A]BGVXS;C"#8L=BG(-F%
MVXSB@(S8J-N,V8;;C-BO(-JIV8<@V*C8M]F(V+$@V+78L=N,V*T@V*S8L]BJ
MV*S9B"#:J=F&VXS8KRD`V8'9A]BQV+/8JB#8HMBQV+3;C-F(`-F!V8?8L=BS
MV*H@V+'8I]F'V8;9A=BG`-F!V8?8L=BSV*H@260`V8'9A]BQV+/8JB#9A=BG
MV83:J0#9@=F'V+'8L]BJ(-F^V+/8JMN,`-F!V8?8L=BSV*H@V+G8MMF(VXS9
MD=BJ`-F!V8?8L=BSV*H@V+G8K]F%(-BYV+;9B-N,V9'8J@#9@=F'V+'8L]BJ
M(-BTV*_9AB#8K]BQ(-BSV+'8HMF%V*\`V8'9A]BQV+/8JB#:J=BGV+'8J-BQ
MV*?9AB#9@=BYV*?9A"#9AMF%VXSB@(S8J-BGV+38KP#8I]BOV*C;C-BGV*H`
MV*C8I]BQVJG8L=BOV88N+BX`V8;8I]F%V8?B@(S8K]BGV88@V878K=F$VXPZ
M`-BSV*?8N=BJ(-F%V*W9A-N,.B``V878K=F$VXS9D=BJ(-F((-BSV*?8N=BJ
M`-F%V8C9@MBYVXS8J@#9B-BQV8C8KP#9B-BQV8C8KR#8J-F'("5S`-BNV+'9
MB-BL`-F(V+'9B-BO`-F(V+C8I]N,V8$@V8C8L=F(V*\`V8C8L=F(V*\@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO(-BRVXS8L=BG(-F&V*?9A2#:J=BGV+'8J-BQ
M(-F((-N,V*<@V*?8L]F%(-BQV878LB#9B-BGV+'8KR#8M-BOV8<@V*?8M-BJ
MV*C8I]F'(-BHV8C8KR``V8C8L=F(V*\@V8;8I]F%V8C9@=F1V8(@V*C9B-BO
M+@#9A=BJV88@V*C9A-F&V*\`V+G8M-F"`-F^V*?;C-N,V88`V*?9B-F$V8C;
MC-BJ(-F^V*?;C-N,V88`V*W8L=F(V8$@VJG9B-J&VJD@VXS9B-F&V*?9AMN,
M`-BMV+'9B-F!(-JIV8C:AMJI(-F$V*?8JMN,V88`V*?8N=BOV*?8KR#:J=F(
MVH;:J2#;C-F(V8;8I]F&VXP`V;[8I]N,VXS9AN*`C-BJV+'B@(S;C-F&`$U-
M`-F^VXS8NMBGV84@V+'9B-BR`-F^VXS9B-BSV*H@35,M5$Y%1B#8M-BGV879
MA"#9A]N,VH8@V*_8I]BOV8?B@(S8I^*`C-N,VXP@V8;;C-BSV*H`35-'`-F^
MV+'9B-F&V*_9A^*`C"!-86-I;G1O<V@@`-BLV*?8K]F(`-F&V*?9A=F'(-BG
MV83:J=BJV+'9B-F&VXS:J=N,`-BSV+'9OMBQV+/8JB#9AMBGV879AP#9OMN,
MV+3B@(S9AMF%V*?;C-BTV8?8I]N,(-F&V*?9A=F'`-F&V8C8N2#:J=BGV+'8
ML]BGV+(@V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8J-BQV*?;
MC"#9A=BJV+79A"#8M-BOV88@V*C9ASH`V8;8I]F%V8?B@(S8K]BGV88`VJ_8
MLMN,V8;9A^*`C-F'V*?;C"#9AMF%V*?;C-BT(-F&V*?9A=F'XH",V*_8I]F&
M(-F((-F^V8C8M-F'`-BSV*?8KMBJV88@V;[;C-F(V8;8KRXN+@#9A=BOVXS8
ML=N,V*H@V8@@V*K8N=N,VXS9AB#8L=F&VJ\@V*_8L]BJV8?B@(S9A]BGVXS;
MC"#:J=F'(-BTV878IR#9A=F(V*?8L=BO(-BQV*<@V*C8IR#8HMF&V8?8IR#9
MAMBGV87B@(S:K]BPV*?8L=N,(-F%VXSB@(S:J=F&VXS8KP!-87`R-"!M87``
M36%P475E<W0@;6%P`-F%V*?8L=BS`-BMV*?8M-N,V8<`V+G9A-BGV878JB#:
MK]BPV*?8L=N,(-BJV878I]F%(-F^VXS8NMBGV879A]BGVXP@V;[9B-BTV8<@
MV*C9AR#8N=F&V8C8I]F&(-F%V+38I]F'V*_9AR#8M-BOV8<`V+G9A-BGV878
MJB#:K]BPV*?8L=N,(-BJV878I]F%(-F^VXS8NMBGV879A]BGVXP@V;[9B-BT
MV8<@V*C9AR#8N=F&V8C8I]F&(-F%V+38I]F'V*_9AR#9AMBTV*_9AP#8N=F$
MV*?9A=BJ(-JOV+#8I]BQVXP@V*C8N=F&V8C8I]F&.@#8HMN,V*<@V+/8M]F(
MV*T@V878KMBJV839@2#9AMF"V80@V8+9B-F$V8?8I]B,(-BHV*<@V+'9AMJO
MV8?8I]N,(-F%V*[8JMF$V8$@V+G9A-BGV878JB#:K]BPV*?8L=N,(-BTV8C8
MK]B?`-BBVXS8IR#9OMN,V+K8I]F%V8?8IR#8J-BYV8;9B-BGV88@V878M-BG
MV8?8K]F'(-BTV*_9AR#8N=F$V*?9A=BJ(-JOV+#8I]BQVXP@V+39B-F&V*_8
MGR`HV8'9@MBW($E-05`I`-BYV838I]BFV84@V+/8I]BOV8<@V+G9A-BGV878
MJB#B@(S:K]BPV*?8L=N,(-BTV8C9AMBOV)\`V+G9A-BGV878JB#:K]BPV*?8
ML=N,(-BHV*<@V;[8L=J&V84@V878M-BGV8?8K]F'(-BTV*_9AR\@V878M-BG
MV8?8K]F'(-F&V+38K]F'`"#8N=F$V*?9A=BJ(-JOV+#8I]BQVXP@V*C8IR#8
MN=F$V*?8IMF%(-BOVXS:K]BQ("C9A=BGV8;9AMBO(-F%V8?9A2_9OMBGV+/8
MKB#8K]BGV*_9AR#8M-BOV8<I`-BJV+?8J-N,V8(@V*K9A=BGV87;C"#9OMBQ
MV+/B@(S9B-BLV8C9A]BG`-BJV+?8J-N,V8(@V8?8L2#9OMBQV+/B@(S9B-BL
MV8@`V8';C-F$V*_B@(S9A]BGVXP@V*?9AMBWV*C8I]F"`-BHVXS8M-N,V8;9
MAR#8I]BYV*K8J-BGV+$@V878K-BGV+(`V*K8KMBWVXP@V*?8LB#8J-N,V+3;
MC-F&V8<@V8+8L]F%V*K9A]BGVXP@V;[;C-BZV*?9A0#8J-N,V+3;C-F&V8<@
MV*_9A=BG(-BOV+$@V[+;M"#8L]BGV+G8JB#:K]BPV+38JMF'.B``V*C;C-BT
MVXS9AMF'(-BOV878IR#8K]BQ(-NV(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z(`#8
MJ-N,V+3;C-F&V8?9E"#8I]F&V*_8I]BRV8?9E"#9OMN,V8C8L]BJ`-BHVXS8
MM-N,V8;9A]F4(-BJV+G8K]BGV*\@V;[9B-BTV8?B@(S9A]BG`-BHVXS8M-N,
MV8;9AR#8M]F(V80`V+'8L]N,V*_9AB#8J-F'(-BHVXS8M-N,V8;9A]F4(-BJ
MV+G8K]BGV*\@V;[;C-F(V+/8JMF'V*<`V+'8L]N,V*_9AB#8J-F'(-BHVXS8
MM-N,V8;9A]F4(-F%V*S9A=F(V+D@V*?9AMBOV*?8LMF'V90@V;[;C-F(V+/8
MJ@#9A=N,`-F^V++8M-JIVXP`V838NMF((-BTV*_9AB#9A=F$V*?9@MBGV*H`
MV*?8M]F$V*?8N=BGV*H@V879A-BGV8+8I]BJ`-BWV+'8K2#9OMN,V+39AMF'
MV*?8K]N,(-F%V838I]F"V*?8J@#9OMBGV+/8KB#9A=F$V*?9@MBGV*H`V*C8
ML=F(V++8L=BSV*?9AMN,(-F%V838I]F"V*?8J@#8K]BQV*[9B-BGV+/8JB#8
MJ-BQV8C8LMBQV+/8I]F&VXP@V879A-BGV8+8I]BJ`-BGV+G8MMBGV*$`VJ_8
MLMN,V8;:K]BGV88@V8'9A]BQV+/8JB#9OMF(V+39AP#9A=BO(-JOV++;C-F&
MVJ_8I]F&VXPZ`-BGV*_8NMBGV84@V+/9A-F(V839A]BG`-F^VXS8NMBGV84`
MV*?;C-BLV*?8KR#9OMN,V+K8I]F%`-BJV*?8L=N,V*X@V;[;C-BZV*?9A0#:
MK]BRVXS9AMF'XH",V8?8I]N,(-F^VXS8NMBGV84`V*S8L]BJV*S9B-N,(-F^
MVXS8NMBGV84`V*?9AMBOV*?8LMF'V90@V;[;C-BZV*?9A0#8L]BQVH;8M-F%
MV8?9E"#9OMN,V+K8I]F%`-F^VXS8NMBGV84@V*C8IR#9A=F(V8'9D=F"VXS9
MD=BJ(-BHV*?8LMBHVXS9AMN,(-BTV*\@V*?9A=BG(-JOV8C8I]F'VXP@V*?9
MA=BVV*?8H2#:J=F&V8;8K]F'(-F&V87;C.*`C-BJV8C8I]F&V*\@V*C8I]BR
MV*C;C-F&VXP@V+39B-BO`-F%V+38I]F'V*_9A]F4(-F^VXS8NMBGV84`V;[;
MC-BZV*?9A2#9A=F&V8+8MMN,(-BTV*\`V;[8L=J&V879A]BGVXP@V;[;C-BZ
MV*?9A0#9OMF(V+39A^*`C-F'V*?;C"#9OMN,V+K8I]F%`-F^VXS8NMBGV84@
MV*?8LB`E<P`@V;[;C-BZV*?9A2#8K]BGV+'8I]N,(-F^VXS9B-BSV*H@V*?8
ML]BJ`"#9OMN,V+K8I]F%(-BQV878LB#8J-F&V*_;C"#9A=N,XH",V+39B-BO
M`"#9OMN,V+K8I]F%(-BGV878MMBGV*$@V87;C.*`C-BTV8C8KP#8JMBWV*C;
MC-F"V8?8I]N,(-F^VXS8NMBGV84`V;[;C-BZV*?9A2#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*K8NMN,VXS8L2#9A=BSVXS8L2#8K]BGV*_9AR#8M-BO`-F^
MVXS8NMBGV84@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BGV+'8L]BGV80@V+38
MK]B,(-BGV878IR#8K]BQ("5S(-BMV8'8N"#9AMBTV*\`V;[;C-BZV*?9A2#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V8'8L=BSV*K8I]BOV8<@V+38KP#9AMF(
MV+D@V;[;C-BZV*?9A0#8JMBYV*_8I]BO(-F^VXS8NMBGV879A]BG(-BOV+$@
MV8?8L2#8M=F!V*W9AR#9AMF%V*?;C-BT(-F&V*?9A=F'XH",V*_8I]F&`-F^
MVXS8NMBGV879A]BG(-BHV8<`V*+8J"#9B"#9A]F(V*?;C"!-971A<@#8J-F$
MV8C:J2!-971A<B#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ`-BHV839
MB-JI($UE=&%R(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;C-BSV*HN(-BLV++8
MIMN,V*?8JB#8J-BQV*?;C"#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BK
MV*C8JB#8M-BOV8<@V*?8L]BJ`-BQV8C8M`#8I]F&V*_8I]BRV8?B@(S8I]N,
M`-F(V+/8MP#9AMF(V+D@36EM90`@VJG9A=N,V8;9AR#8K]F%V*?;C"#;LMNT
M(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z(``@VJG9A=N,V8;9AR#8K]F%V*?;C"#;
MMB#8L]BGV+G8JB#:K]BPV+38JMF'.B``V*+;C-F&V8<`V878JMF!V+'9@MF'
M`-F^VXS:J=BQV*C9AMBOVXP@V879B-BLV8C8KR#9AMN,V+/8JBX@V+39A=BG
M(-BGVJ_8L2#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV+(@V*?;C-F&(-BHV+'9
MAMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(-BGV+/8JMF!V*?8K]F'(-JIV8;;
MC-BO(-BHV*?;C-BO(-BBV8;8L=BG(-BJV8C9A-N,V*\@VJG9AMN,V*\`V*?8
MLB#8J-N,V88@V+'9@=BJV88@240@V;[;C-BZV*?9A0#8I]BR(-BHVXS9AB#8
ML=F!V*K9AB!)1"#9AMBTV+/8JB``V*_9B-BTV8;8J-F'`-F^V+/8JB#8L]F$
MV8C9A-N,`-F%V+G8JMBOV80@VJG8L=BOV88`V*K8I]BQVXS8KB#8JMBZVXS;
MC-BQ(-N,V*?9@=BJV8<`V*K8NMN,VXS8L0#8JMBZVXS;C-BQ(%523`#9A=BG
MV8<@V8@@V+/8I]F$`-F%V*?9A]BGV8;9AP#9@=BGV++9A]BGVXP@V878I]F'
M`-BHVXS8M-BJV+$@V+78I]F!`-BHVXS8M-BJV+$@V*?8J-BQVXP`V*C;C-BT
MV*K8L2#8HMF!V*K8I]BHVXP`V*?9AMBJV8+8I]F$`-BGV8;8JMF"V*?9A"#8
MJ-F'(-F^V*?;C-N,V88`V*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<`V*?9
MAMBJV8+8I]F$(-BHV8<@V+'8I]BSV*H`V*?9AMBJV8+8I]F$(-BHV8<@V*C8
MI]F$V*<`V*?9AMBJV8+8I]F$(-BHV8<@V;[8I]N,VXS9A@#8I]F&V*K9@MBG
MV80@V8?8L=BRV8;8I]F%V8?B@(S9A]BG(-F((-F&V*?9A=F'XH",V8?8IR#8
MJ-F'(-F^V8C8M-F'XH",V8?8I]N,(-F%V+'8J-F(V+?9AP#8I]F&V*K9@MBG
MV80@V*C9AR#9OMF(V+39AP#8I]F&V*K9@MBGV80@V*C9AR#8J-BGV838IP#9
M@=F'V+'8L]BJ(-F^V*?;C-N,V8;B@(S9OMBQ(-J&V8;8KR#8L]BWV*W;C`#:
MAMF&V*\@V*C8KMBTVXPOV*S8I]N,VJ_8LMN,V88`V8;9A=BGVXP@VH;9AMBO
MVJ_8I]F&V8?9E"#9OMN,V+K8I]F%`-J&V8;8KR#8I]F&V*K8KMBGV*C;C`#8
MK=BSV*?8J"#9A=F&`-BGV+?9A-BGV+G8I]BJ(-BMV+/8I]BH(-F%V88`V*_8
ML=JOV*?9AR#9A=F&`-BLV*?9AMF%V*?;C-N,(-BOV+':K]BGV8<@V879A@#9
MAMF'V(P@V879AB#9A=F(V*?9@=F"(-F&VXS8L]BJV84`V*K9B-BLV8<`V8;8
MI]F%`-F&V*?9A2#9B"_;C-BG(-BBV*_8L=BS(-F&V*?9A=F'V90@V*?9A-JI
MV*K8L=F(V8;;C-JIVXP@V8;9A=N,XH",V*K9B-BGV8;8KR#8KMBGV83;C"#8
MJ-BGV+38KP#9AMN,V*?8LB#8J-F'(-F!V+G8I]F$VXS8J@!54DP@V;[8I]N,
MV8<@3F5T<V-A<&4`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P
M92!2979O8V%T:6]N(%523`#8JMF(V+;;C-BM(-JOV8C8I]F'VXP@3F5T<V-A
M<&4`V8;9B-BY(-JOV8C8I]F'VXP@3F5T<V-A<&4`V+38J-JIV8<`V8?8L=JO
MV+(`V8?8L=JOV+(@V;[;C-F(V+/8JMF'V*<@V*W9@=BX(-F&V+39B-F&V*\`
MV*S8K]N,V*\`V*_8L]BJV8<@V*S8K]N,V*\`V;[9B-BTV8?9E"#8K-BOVXS8
MKP#9AMBGV879A]F4(-BLV*_;C-BO`-F%V*?9AR#9AMF(`-F&V*?9A2#:J=BG
MV+'8J-BQVXP@V*S8K]N,V*\@*-BGV*[8JMN,V*?8L=N,*0#9OMN,V+K8I]F%
MV8?8I]N,(-BLV*_;C-BO`-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\`V*?8L]F%
M(-BQV878LB#9A-BZV8@@V*[9B-BGV8?8KR#8M-BO(-BOV+$@)7@@`-BGV+/9
MA2#8L=F%V++9A]BGVXP@V*S8K]N,V*\@V*K8M]BGV*C9@B#9AMBOV*?8L=BO
M`-F^V8;8K-BQV8<@V*S8K]N,V*\@*-BNV*?9A-N,*0#8I]BNV*C8I]BQ`-JO
MV+'9B-F'XH",V8?8I]N,(-BNV*C8L=N,`-BHV+G8K]N,`-F^VXS8NMBGV84@
MV*C8N=BOVXP`V+79@=BMV8?9E"#8J-BYV*_;C`#:K]BRVXS9AMF'XH",V8?8
MI]N,(-BHV+G8K]N,`-BTV*@`V*[;C-BQ`-JOV8C8I]F'VXSB@(S8I^*`C-N,
MVXP@V;[;C-BOV*<@V8;8M-BO`-BHV*_9B-F&(-BQV878LMBHV8;8K]N,`-F'
MVXS:AB#:J=F$VXS8K]N,(-BOV+$@V*W9A-F"V8?9E"#:J=F$VXS8KR#9AMN,
MV+/8J@#9OMN,V+K8I]F%VXP@V8;;C-BSV*H`V8?;C-J&(-JIV83;C-BO(-BY
MV879B-F%VXP@4$=0(-BOV+'9B-F&XH",V*C8L=BO(-F&V+38K]F'`-F'VXS:
MAB#:K]F(V*?9A]N,(-BTV*[8M=N,(-F(V*S9B-BO(-F&V*_8I]BQV*\`V*C8
MK]F(V88@V;[;C-BTXH",V8;9A=BGVXS8M"#9A=BJV88`VJG9A-N,V*\@V+G9
MA=F(V87;C.*`C-BGXH",VXS;C"#9OMN,V*_8IR#9AMBTV*\`V8?;C-J&(-JI
MV83;C-BO(-BYV879B-F%VXP@4R]-24U%(-BOV+'9B-F&XH",V*C8L=BO(-F&
MV+38K]F'`-F'VXS:AB#9OMN,V8C8L]BJVXP@V;[;C-BOV*<@V8;8M-BO`-BO
MV*?8K]F'(-F^VXS:J=BQV*C9AMBOVXP@V*_8L2#8K]BSV*K8L=BSVXP@V*C8
ML=BGVXP@V8;8M-BGV88@V*_8I]BOV88@V*K9@=BGV8C8JMF'V*<@V8C8K-F(
MV*\@V8;8K]BGV+'8KP!)4T\@V8;;C-BSV*H@V*?8L]BJV+'8I]BJVIC;C"#8
MK]BQ(-BOV+/8JMBQV+/;C"#8J-BQV*?;C"#8L]BGV*[8JMF&(-BJV+79B-N,
MV+$@`-BGV83:K]F(VXP@V*_8L]BJV8?B@(S8I]N,VXP@V8;;C-BSV*H`V*C9
MA-BGVJG;C"#8K]BQ(-F%V8C9@MBYVXS8JB#8K]BQV*[9B-BGV+/8JB#8M-BO
MV8<@V879B-BLV8C8KR#9AMN,V+/8J@#9A]N,VH8@V8;8I]F%(-BJV8+9B-N,
MV87;C"#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@34-!3"#9@=BQ
MV*?9A]F%(-F&V+38K]F'(-BGV+/8J@#8J-BOV8C9AB#8JMBZVXS;C-BQ`-F'
MVXS:AB#9A=BLV8C8LB#9@=BQV+G;C.*`C-BGVXP@V8;9A=N,XH",V*K9B-BG
MV8;8KR#8J-F'(-BGVXS9AB#9A=BLV8C8LB#8I]BVV*?9@=F'(-BTV8C8KP#9
MA]N,VH8@V*?8M]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;
MC"`E<R#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^
MVXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@1E10(%9&4R#9A=BTV*[8M2#9AMBT
MV*\`V8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8
ML=BGVXP@4U%,(%9&4R#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BGV+?9A-BG
MV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@4U%,+49I;&4@5D93
M(-F%V+38KMBU(-F&V+38KP#9A]N,VH8@V*?8N=BJV*C8I]BQVXP@V*C8I]F"
MVXP@V8;9A=BGV8;8KP#9A]N,VH8@V879@MBUV*_;C"#9@=BQV*?9A]F%(-F&
MV+38KP#9A]N,VH8@V;[8L=F(V8;8K]F'XH",V*?;C-N,(-BGV+'8L]BGV80@
MV8;8M-BO`-F'VXS:AB#9OMF(V+39A^*`C-BGVXP@V*?9AMBJV*[8I]BH(-F&
MV+38KP#9A]N,VH8@V;[9B-BTV8?B@(S8I]N,(-BHV+'8I]N,(-F&V*?9A=F'
MV90@V*S8K]N,V*\@V*S8L]BJV*S9B"#9AMBTV*\`V8?;C-J&(-F^V8C8M-F'
MXH",V*?;C"#9A=BTV*[8M2#9AMBTV*\`V;[9B-BTV8?B@(S8I]N,(-BHV*<@
MV;[;C-BZV*?9A=F'V*?;C"#8K-BOVXS8KR#9AMN,V+/8J@#9OMF(V+39A^*`
MC-BGVXP@V*C8IR#9OMN,V+K8I]F%(-F%V+38I]F'V*_9AR#9AMBTV*_9AR#9
MAMN,V+/8J@#9A]N,VH8@V*+;C-JIV8C9AMN,XH",(-F^VXS8K]BG(-F&V+38
MKP#9A]N,VH8@V87:J=BGV8;;C"#8JMF&V+C;C-F%(-F&V+38K]F'`-F%V*K9
MAB#8J-BOV8;9A]F4(-F^VXS8NMBGV84@V8;;C-BSV*H`V8?;C-J&(-F^VXS8
MNMBGV87;C"#9@=BQV*?9A]F%(-F&V+38KP#9A]N,VH8@V;[;C-BZV*?9A=N,
M(-BHV*<@V*S8L]BJV*S9B-N,(-BTV878IR#8JMBWV*?8J-F"(-F&V*_8I]BQ
MV*\`V8?;C-J&(-F&V*?9A=N,(-F%V+38KMBU(-F&V+38KP#9A]N,VH8@V+39
MA=BGV+'9A^*`C-BGXH",VXS;C"#9A=BTV*[8M2#9AMBTV*\`V*+;C-F&V*_9
MAR#9AMBGV878M]BHV8C8N=N,(-F&VXS8L]BJ`-BHV+'8I]N,(-BJV+78K]N,
MV8(@V8?9B-N,V9'8JB!(5%10(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%
M(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@24U!4"#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8
MI]BSV*H`V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($ME<F)E<F]S
M(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8J@#8
MJ-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V8C8L=F(V*\@V*?8L]F%
M(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8I]N,
M(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!005-35T0@V*?8L]F%(-BQV878LMN,
M(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8I]N,(-BJV+78K]N,
MV8(@V8?9B-N,V9'8JB!334(@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@
MV8;8M-BOV8<@V*?8L]BJ`-BJV8+8I]BVV*?;C"#8J]BHV*H@V8;8I]F%VXP@
MV*_8L2#8I]F&V*K8N-BGV+$@V*K8H]N,VXS8KR#9AMN,V+/8J@#9A]N,VH8@
MVJG9A-N,V*\@4$=0(-BNV+79B-BUVXP@V+38KMBUVXSB@(S8I]N,(-BOV+'9
MB-F&XH",V*C8L=BO(-F&V+38K]F'`-F'VXS:AB#:J=F$VXS8KR!01U`@V+G9
MA=F(V87;C"#8M-BNV+7;C"#8K]BQV8C9AN*`C-BHV+'8KR#9AMBTV*_9AP#9
MA]N,VH8@VJ_9B-BGV8?;C"!3+TU)344@V+38KMBUVXP@V*_8L=F(V8;B@(S8
MJ-BQV*\@V8;8M-BOV8<`V*C8K]F(V88@V8+9B-BGV+G8KP#9A]N,VH8@V*S8
MK]BGVJG9AMF&V*_9A^*`C-BGXH",VXS;C"#9A=BTV*[8M2#9AMBTV*\`V*C8
MK]F(V88@V+/9A=BJ`-F'VXS:AB#8J-BQV8;8I]F%V8?9E"#8KMBWV*?;C-BG
MV*@@V*?9A=F$V*?;C-N,(-F^VXS:J=BQV*C9AMBOVXP@V8;8M-BOV8<`V8?;
MC-J&(-BNV+?8I]N,(-BGV879A-BGVXS;C"#9B-BLV8C8KR#9AMBOV*?8L=BO
M`-F^VXS8M-F&V8?8I]BOVXP@V8;;C-BSV*H`V+38I]BNV8<@V879B-F"V*K;
MC"#8J-BQV*?;C"#:J=BGV+39AR#9A=F(V*S9B-BO(-F&VXS8L]BJ`-F'VXS:
MAB#:J=BGV+'8J-BQVXP@V878M-BNV+4@V8;8M-BOV8<`V8?;C-J&(-F&V*?9
MA2#:J=BGV+'8J-BQVXP@V8@@VXS8IR#8I]BSV84@V+'9A=BRVXP@V*?8L=BS
MV*?9A"#9AMBTV*\`V8?;C-J&(-BOV*?8K]F'(%A-3"#9A=BYV*K8J-BQVXP@
MV*C8I]BRVJ_8L=BOV*?9AMBOV8<@V8;8M-BOV8<@V*?8L]BJ`-BHV*_9B-F&
M(-F%V8+8K]BGV+$`V8;8L]BNV8?B@(P@V*_8L2#9OMN,VJG8L=BHV8;8K]N,
M(-BGV+79A-N,(-F^VXS8K]BG(-F&V+38KRX@V;[;C-JIV+'8J-F&V*_;C"#8
ML=BG(-BOV8C8J-BGV+'9AR#8JMF(V83;C-BO(-JIV8;;C-BO`-F&V+/8KMF'
MXH",(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#8M-F%V*<@V;[;C-BOV*<@V8;8
MM-BOV8<@V*?8L]BJ+B#9OMN,VJG8L=BHV8;8K]N,(-BQV*<@V*_9B-BHV*?8
ML=F'(-BJV8C9A-N,V*\@VJG9AMN,V*\`V*C8K]F(V88@V+38L=JIV*H@VJG9
MAMF&V*_9AP#9A]N,VH;:J=BOV*?9A0#9A]N,VH;B@(S:J=BOV*?9A2`HV+;9
MA=F&VXP@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\I`$YO<F1I8R`H25-/+3@X
M-3DM,3`I`-BYV*?8K]N,`-F&VXS9A2#:J=BQV8<@V+39A=BGV83;C`#9AMF'
M(-BHV+G8KP#9AMF'(-F"V*C9A`#8K=BPV8$@V8;8M-BOV8<`V+K;C-BQ(-F^
MVXS8M"#9AMF(VXS8LP#8NMN,V+$@V879A]F%`-BZVXS8L2#8M-BNV+7;C`#;
MC-JI(-BTV*?8KMF'(-F&VXS8L]BJ`-JIV83;C-BO(-BYV879B-F%VXP@V8;8
MI]F%V+G8JMBHV+$`V;[;C-BZV*?9A=F'V*?;C"#8K=BPV8$@V8;8M-BOV8<`
MV;[;C-BGV*_9A^*`C-BSV*?8LMN,(-F&V+38K]F'`-F^VXS8NMBGV879A]BG
MVXP@V+K;C-BQ(-F%V8?9A0#8JMF&V+C;C-F%(-F&V+38K]F'`-F^V+38JMN,
MV*C8I]F&VXP@V8;8M-BOV8<`V*K9B-BLV8<@VJG9AMN,V*\@VJG9AR#8I]N,
MV88@V87;C.*`C-BJV8C8I]F&V*\@V++9A=BGV88@V*C8J-BQV*\`VXS8I]BO
MV*_8I]BTV*K9A]BG`-F'VXS:AB#:AMN,V+(`VH;;C-BRVXP@V*C8L=BGVXP@
MV878L=F(V+$@V8;;C-BSV*K8C"#8J-F'(-BYV8+8J"#8J-BQVJ_8L=BO`-F&
MV8C8I]F%V*C8L0#8N=BOV*\`V*K8N=BOV*?8KR#9AMF(VXS8L]F'XH",V8?8
MIP#8JMBYV*_8I]BO(-BSV*K9B-F&V8?8IP#8JMBYV*_8I]BO(-F%V*?9A^*`
MC-F'V*?;C"#9AMJOV8?8K]BGV+';C"#9AMBGV879A^*`C-F'V*?;C"#9@MBO
MVXS9A=N,V(P@V*?:K]BQ(-BBV8;9A]BG(-F%V*?9A]N,V*?9AMF'(-BMV+#9
M@2#8M-F(V8;8KP#8JMBYV*_8I]BO(-F^V8C8M-F'XH",V8?8I]N,(-F&V*?9
MA=F'XH",V8?8I]N,(-BGV+'8L]BGV83;C"#9@MBOVXS9A=N,(-BHV+'8I]N,
M(-F&VJ_9A]BOV*?8L=N,V(P@V*?:K]BQ(-BBV8;9A]BG(-F%V*?9A]N,V*?9
MAMF'(-BMV+#9@2#8M-F(V*\`V*K8N=BOV*?8KR#8L]BWV+'9A]BG`-BGV+G8
MK]BGV*\@V*C8L=BGVXP@V*C8L=F(V++8L=BSV*?9AMN,(-F!V8?8L=BSV*H@
MV*K9B-BRVXS8N=N,(-F%V+38KMBU(-F&V+38K]F&V*\`V+78K=N,V*T@V*?8
ML]BJ`-N,V*<`V+3;C-BA`-BGVXS8K-BGV*\@VJG9AMF&V*_9AR#8M-N,V*$`
MV8?8M-BJV*?;C-N,`-BGVJG8JMBHV+$`V8';C-F$V*K8L2#8J-N,XH",V*W8
ML=F%V*K;C`#8K]F!V*K8L2#:J=BGV+$`V*?8L]F%(-BQV878LB#8K-BOVXS8
MKR#9B"#8I]BSV84@V+'9A=BR(-F!V+G9A-N,(-BHV*?;C-BO(-F%V*K9@=BG
MV8C8JB#8J-BGV+39AMBO`-F^VXS8NMBGV879A]BGVXP@V8+8K]N,V87;C`#8
MI]BSV84@V+'9A=BR(-F"V*_;C-F%VXP`V*?8L]F%(-BQV878LB`@V8+8K]N,
MV87;C"#9AMBGV*_8L=BSV*H@V*?8L]BJ`-F^V8C8M-F'V90@V8;8I]F%V8?B
M@(S9A]BGVXP@V8'8L=BSV*K8I]BOV8<@V+38K]F'(-BNV*?9A-N,(-BTV*\`
MV*K9AMF'V*<@VJG8I]BQV+/8I]BRV8?8I]N,($E-05#9OMF(V+39A^*`C-F'
MV*?;C"#9A=BTV*K8L=JI(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9A=N,XH",
MVJG9AMF&V*\@`-BBVXS8IR#8JMF&V8?8IR#9OMF(V+39A^*`C-F'V*?;C-N,
M(-JIV8<@V;[;C-BZV*?9A=F'V*?;C"#8KMF(V*?9AMBOV8<@V8;8M-BOV8<@
MV*_8I]BQV8;8KR#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C9AMBOV)\`V8'9
M@MBW(-BBVXS9AMBOV8<@V8;8I]F%V+?8J-F(V+D`V*K9AMF'V*<@VXS:J2#8
MHMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V878K-BGV+(@
MV*?8L]BJ`-BHV+'8I]N,(-BGVXS9AB#8N=F%V80@V*K9AMF'V*<@VXS:J2#9
MOMF(V+39AR#8J-BGVXS8KR#8I]F&V*K8KMBGV*@@V+39B-BO`-BJV8;9A]BG
M(-F%V*?9A-JI(-N,V*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#9A=N,
MXH",V*K9B-BGV8;8KR#9A=BGV83:J=N,V*H@VXS8IR#9A=BLV8C8LMF'V*?;
MC"#9A=BGV83:J2#8L=BG(-BHV+'8I]N,(-N,VJD@V*?8M-BJV+'8I]JI(-BJ
MV+K;C-N,V+$@V*_9A]BO`-BOV+$@VXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO
M(-BHV*?8LB#8M-F(V*\`V;[9B-BTV8?9E"#8J-BGV+(@V+38K]F'`-BGVXS9
MAB#9OMN,V8C9AMBO(-BOV+$@VXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO(-BH
MV*?8LB#8M-F(V*\`V+/;C-BSV*K9A2#8N=BGV879A`#8M-BQVXS:J2#8I]F&
MV*K8KMBGV*C;C`#:K]BRVXS9AMF')B-X,C`P8SO9A]BG`-JOV++;C-F&V8?B
M@(S9A]BGVXP@)7,`V83;C-BSV*H@V878L=BJV*@@V+38K]F'`-BSV*?8LMF%
MV*?9A@#9B-BGV*W8KR#8L]BGV++9A=BGV8;;C`#8L]BGV++9A=BGV8;8K]F'
MVXP`V*?9A-JOV8C;C"#8I]BUV83;C"#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8
MJ-BQV*_;C`#8I]F$VJ_9B-F'V*?;C"#8I]BUV83;C"#8K]BQ("5S.@#8K]N,
MVJ_8L0#8I]BWV838I]BYV*?8JB#8K]N,VJ_8L0#8J-F"VXS9AR#8K=BSV*?8
MJ-F'V*?;C"#9OMBSV*K;C`#:K]BRVXS9AMF'XH",V8?8I]N,(-BOVXS:K]BQ
M`-F%V*S9B-BRXH",V8?8I]N,(-F%V*?9A-JI`-BJV+78K]N,V8(@V8?9B-N,
MV9'8JB!004T@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&VXS8L]BJ`%!'4`#8
MI]F%V+;8I]BAXH",(-BOVXS8K-N,V*K8I]F$VXP@4$=0`-F^VXS8NMBGV84@
MV+'9A=BRV*C9AMBOVXP@V+38K]F'V90@4$=0`-F^VXS8NMBGV84@V+'9A=BR
MV*C9AMBOVXP@V+38K]F'V90@4$=0`-BNV+?8I]N,(%!'4#H@`-BNV+?8I]N,
M(%!'4#H@V*C9AR#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#:J=F$VXS8
MKR#8KMBUV8C8M=N,(-BTV*[8M=N,(-F&VXS8I]BR(-F%VXSB@(S8J-BGV+38
MKP#:K]BRVXS9AMF'XH",V8?8I]N,(%!'4`#9B-BGV+'8K]JIV+'8K]F&(-BY
MV*C8I]BQV*H@VJ_8L-BQ4$=0(`#9OMBTV*K;C-BHV*?9AMN,(-BLV8'8JB#:
MJ=F$VXS8KR#8M-BNV+7;C"!01U`@V*C9AR#;C-JI(-BGV*K8M=BGV80@V*?9
MA=F&(-F(V*@@V8;;C-BGV+(@V*_8I]BQV*\`(-JIV83;C-BO(-BYV879B-F%
MVXP@4$=0`-F%V*K9AB#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'4`#:J=F$VXS8
MKR#8N=F%V8C9A=N,(%!'4"#8J-BQV*?;C"`B)7,@*"5S*2(@V*C8IR#9A=F(
MV8'9D=F"VXS9D=BJ(-BGV+;8I]F!V8<@V+38KP#:J=F$VXS8KR#8N=F%V8C9
MA=N,(%!'4"#8J-BQV*?;C"`B)7,B(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8
MK=BPV8$@V+38KP#8K=F$V8+9AR#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'4`#9
MOMN,V+K8I]F%(-BGV878MMBGV*$@V+38K]F'V90@4$=0`-F^VXS8NMBGV84@
MV*?9A=BVV*?8H2#8M-BOV8<OV+'9A=BRV*C9AMBOVXP@V+38K]F'(%!'4`#9
MOMN,V+K8I]F%(-BQV878LMBHV8;8K]N,(-BTV*_9AR_8I]F%V+;8I]BA(-BT
MV*_9AR!01U``VJG9A-N,V*\@V+38KMBUVXP@4$=0(-BHV*<@V879B-F!V9'9
M@MN,V9'8JB#8I]BVV*?9@=F'(-BTV*\`VJG9A-N,V*\@V+G9A=F(V87;C"!0
M1U`@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BGV+;8I]F!V8<@V+38KP#9OMBT
MV*K;C-BHV*?9AMN,(%!'4"#8L=F(VXP@V*?;C-F&(-BSV*?9A=BGV8;9AR#9
M@=BYV*?9A"#9AMN,V+/8J@#9OMBTV*K;C-BHV*?9AMN,(%!'4"#8K]BQ(-BM
MV*?9A"#8K=BGV+;8L2#9@=BYV*?9A"#9AMF%VXSB@(S8J-BGV+38KR#8I]BR
M(-BGVXS9AMBQV8@@V*?9A=BVV*?;C"#8K]N,V*S;C-BJV*?9A-N,(-F"V*?8
MJ-F$(-BHV*?8LMBHVXS9AMN,(-F&VXS8L]BJ`-F^V+38JMN,V*C8I]F&VXP@
M4$=0(-BOV+$@V*W8I]F$(-BMV*?8MMBQ(-F!V+G8I]F$(-F&V87;C.*`C-BH
MV*?8M-BO(-BGV+(@V*?;C-F&V+'9B"#9OMN,V+K8I]F%(-F"V*?8J-F$(-BQ
MV878LMJOV+38I]N,VXP@V8;;C-BSV*H@`%!'4"#8J-BQV*?;C"#8N=F%V83:
MJ=BQV*\@V+78K=N,V*T@V*[9B-BO(-BGV+(@V;[9AMBLV+'9A^*`C-F'V*?;
MC"#:K]BTV8C8K]F&VXP@V*?8L]BJV8'8I]BOV8<@V87;C.*`C-JIV8;8KRX@
MV878L=F(V+':K]BQ(-BNV8C8KR#8L=BG(-BHV+'8I]N,(-BGV+/8JMF!V*?8
MK]F'(-BGV+(@V*?;C-F&(-F^V8;8K-BQV8?B@(S9A]BG(-BJV8;8N-N,V84@
MVJG9AMN,V*\`VJG8KR!02%``V;[9B-BSV*K9AR!02%``V*C8I]BQV8;8K]JO
MVXP@V+/8J-JI(-BYV+78L=JOV*?9A]N,`-BQVJ_8J-BGV+$@V+G8M=BQVJ_8
MI]F'VXP`V*C8L=F!(-BYV+78L=JOV*?9A]N,`-BJVJ_8L=JO(-BYV+78L=JO
MV*?9A]N,`%0M4W1O<FUS`%!/4#,`4$]0,R`HV*K8M-BNVXS8M2#8KMF(V*_:
MJ=BGV+$@V;[8L=F(V*K:J=F$V8?8IRD@`%!/4#,@V+'9B-N,(%-33`!03U`S
M(-BQV8C;C"!34TP@*-JOV8C8I]F'VXP@V*[9B-BOV*?9A=BVV*?8H2D`4$]0
M,R#8L=F(VXP@4U-,("C8KMF(V*_8I]F%V+;8I]BA*0!03U`SV(P@V8;9AR!4
M3%,`V*C8L]BW(%!/4TE8(-BGV+(@V*C;C-F&(-BQV8'8JMF'(.*`C-BGV+/8
MJ@#9OMF(V+/8JMF'(%!(4`#9@=BGV+79A-F'XH",VJ_8L-BGV+';C`#8M=F!
MV*W9A]F4("5D(-BGV+(@)60`V+79@=BMV8<@V*C8IR#8I]F(V83;C-F&(-F^
MVXS8NMBGV84@V878M-BGV8?8K]F'(-F&V+38K]F'`-BUV8'8K=F'(-BHV*<@
MV*+8KMBQVXS9AB#9OMN,V+K8I]F%(-F%V+38I]F'V*_9AR#9AMBTV*_9AP#8
MJ-BNV+0HV8?8IRD`V8+8L]F%V*K;C"#8I]BHV+';C`#8N=BHV*?8L=BJ(-JO
MV+#8L0#8N=BHV*?8L=BJ(-JOV+#8L2`HV*_9B-BHV*?8L=F'*0`@V+G8J-BG
MV+'8JB#:K]BPV+$@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BGV+'8L]BGV80@
MV+38KP#8N=BHV*?8L=BJ(-JOV+#8L3H`(-BYV*C8I]BQV*H@VJ_8L-BQ(-F&
MV87;C.*`C-BJV8C8I]F&V*\@V*[8I]F$VXP@V*C8I]BTV*\`V+G8J-BGV+'8
MI]BJ(-JOV+#8L2#9A=F&V+?8J-F"(-F&VXS8L]BJV8;8KP#8I]BSV84@V+'9
MA=BR`-BGV+/9A2#8L=F%V+(@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BJV+K;
MC-N,V+$@VXS8I]F!V*HN`-BGV+/9A2#8L=F%V+(@(-F&V*?8K]BQV+/8JB#8
MI]BSV*H`V*?8L]F%(-BQV878LB`@V*C9AR#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@4D%$2553(-F&VXS8I]BR(-BOV*?8L=BO`-BGV+/9A2#8L=F%V+(@(-BH
MV*<@V*K8H]N,VXS8KP#8I]BSV84@V+'9A=BR(#H`V*?8L]F%(-BQV878LB`Z
M(`#8I]BSV84@V+'9A=BRXH",V8?8IR#8J-BGVXS8KR#9A=F&V+?8J-F"(-BH
MV*?8M-F&V*\`VH;8L]BHV*?9AMBOV88`VH;8L]BHV*?9AMBOV88@V*?8LB#8
MJMBNV*K9AR#8L=BSV84`V878L]N,V+$`V*O8J-BJ(-F&V*?9A=F'V*?;C"#9
MAMBGV878N=F$V8C9A0#9A=BQV*_9A0#8K]BQV+78KP#8I]BLV+'8I]N,(-BY
MV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C`#8HMN,V*<@V+G9A=F$VXS8I]BJ
M(-F&VJ_9A]BOV*?8L=N,(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#8I]BL
MV+'8IR#8M-F(V*_8GP#9A=BLV8C8L@#9A=BLV8C8LB`@(B5S(B#8K=BPV8$@
MV8;8M-BO`-F%V*S9B-BRV8?8IP#8L]BQV;[8L=BSV*K;C"#9A=BLV8C8LMF'
MV*<`V878K-F(V++9A]BGVXP@V*?;C-F&(-JIV*?8L=BHV+$@V+'8IR#9AMF%
MVXSB@(S8JMF(V*?9AB#8JMBZVXS;C-BQ(-BOV*?8KP#8M-BNV+7;C`#8I]BW
MV838I]BYV*?8JB#8M-BNV+7;C`#8K-F!V*H@VJG9A-N,V*\@V+38KMBUVXP@
M4$=0(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8JMF(V83;C-BO(-BTV*\`VJG9
MA-N,V*_9A]BGVXP@V+38KMBUVXP@4$=0(-BHV*<@V879B-F!V9'9@MN,V9'8
MJB#8K=BPV8$@V+38K]F&V*\`VJ_9B-BGV8?;C-F'V*?;C"#8M-BNV+7;C"!3
M+TU)344@V*_8L=F(V8;B@(S8J-BQV*\@V8;8M-BO.@#:J=F$VXS8K]F'V*?;
MC"#8M-BNV+7;C"!3+TU)344@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BMV+#9
M@2#8M-BOV8;8KP#8K=N,V8C8I]F&V*?8JB#8KMBGV8;:K]N,`-BJV839@=F&
M`-BYVJG8L]F'V*<`V;[;C-JIV+/9A-F'V*<`V*+;C-BG(-F"V*C9A"#8I]BR
M(-F^V*?8L]BN(-F((-BGV+'8K-BGV+D@V*?9A=BVV*?;C"#8M-F%V*<@VJ_9
MAMBLV*?9AMBOV8<@V+39B-BOV)\`V8;8L]BNV8?9E"#9A=BJV88@V878N=F%
MV8C9A-N,(-F^VXS8NMBGV84`V*+;C-BG(-F^V*[8M"#8M=BOV*<@V*C8L2#8
ML=F(VXP@V8;8I]F%V8?9E"#8K-BOVXS8KR#8M=F(V+'8JB#:K]N,V+'8K]B?
M(-BHV+'8I]N,(-BGVXS9AB#9A=F&V+C9B-BQ(-F%VXSB@(S8J-BGVXS8L]BJ
M(-F%V+'9B-BQVJ_8L2#8M-F%V*<@V*?8LB#8I]N,V8;:K]F(V8;9AR#9@=BG
MVXS9A-F'V*?;C"#8M=F(V*K;C"#9OMBTV*K;C-BHV*?9AMN,(-F&V878I]N,
MV*\N`-F$V+?9@=BGV8L@V*_8I]BNV80@VH;9AMBO(-BSV839B-F$(-JIV83;
MC-JI(-JIV8;;C-BO`-F$V+?9@=BGV8L@V*K8H]N,VXS8KR#:J=F&VXS8KR#:
MJ=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?;C-F&(-BYV8;8M=BQ(-BQV*<@
MV*W8L-F!(-JIV8;;C-BO.@#9A-BWV8'8I]F+(-BJV*/;C-N,V*\@VJG9AMN,
MV*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-F^VXS9B-F&V*\@V*?;C-F&
M(-BYV8;8M=BQV8?8IR#8L=BG(-F"V+?8N2#:J=F&VXS8KP#9A-BWV8'8I]F+
M(-N,VJD@V878I]F'(-F((-N,VJD@V+/8I]F$(-F(V*?8L=BO(-JIV8;;C-BO
M+@#9A-BWV8'8I]F+(-F&V*?9A=N,(-BHV+'8I]N,(-BOV+/8JMF'(-BLV*_;
MC-BO(-F(V*?8L=BO(-JIV8;;C-BO.@#9A-BWV8'8I]F+(-F&V*?9A=N,(-BH
MV+'8I]N,(-F^V8C8M-F'V90@V*S8K]N,V*\@V8C8I]BQV*\@VJG9AMN,V*\Z
M`-F$V+?9@=BGV8L@V*+8K]BQV+,@25`@V878N=BJV*C8L=N,(-F(V*?8L=BO
M(-JIV8;;C-BO`-F$V+?9@=BGV8L@VXS:J2#8JMBGV+';C-BN(-F%V+G8JMBH
MV+$@V8C8I]BQV*\@VJG9AMN,V*_8C"#8JMBYV*_8I]BO(-BQV8C8LMF'V*<@
MV*_8L2#9A=BGV8<@V+'8IR#:J=F&V*K8L=F$(-JIV8;;C-BO`-F$V+?9@=BG
MV8L@VXS:J2#8LMF%V*?9AB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BO
M`-F$V+?9@=BGV8L@V8;8I]F%VXP@V*C8L=BGVXP@V;[9B-BTV8?9E"#8K-BO
MVXS8KR#9B-BGV+'8KR#:J=F&VXS8KSH`V838M]F!V*?9BR#9AMBGV84@V*S8
MK]N,V*\@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KSH`V838M]F!V*?9BR#8N=BH
MV*?8L=BJ(-JOV+#8L2#8L=BG(-BHV+'8I]N,(-JIV83;C-BO(-BNV+79B-BU
MVXP@4$=0(-BNV8C8KR#9B-BGV+'8KR#:J=F&VXS8KRX@V+39A=BG(-BHV8<@
MV*?;C-F&(-BYV879A"#8JMF&V8?8IR#8K]BQ(-F'V+$@)7,@V8;8M-BSV*H@
MV8;;C-BGV+(@V*_8I]BQVXS8KP#9A-BWV8'8I]F+(-BYV*C8I]BQV*H@VJ_8
ML-BQ(-BQV*<@V*C8L=BGVXP@VJG9A-N,V*\@V*[8M=F(V+7;C"!3+TU)344@
MV*[9B-BO(-F(V*?8L=BO(-JIV8;;C-BO+B#8M-F%V*<@V*C9AR#8I]N,V88@
MV+G9A=F$(-BJV8;9A]BG(-BOV+$@V8?8L2`E<R#9AMBTV+/8JB#9AMN,V*?8
MLB#8K]BGV+';C-BO`-F$V+?9@=BGV8L@V*C8L=BGVXP@V*?8K]BGV879AR#8
MN=F%V80@V*?8L=BSV*?9A"#9OMN,V+K8I]F%(-BOV8C8J-BGV+'9AR#9B-BG
MV+'8KR#8M-F(VXS8KRX@V++;C-BQV*<@V*?:K]BQ(-BTV878IR#8I]BR(-JI
MV8C:J=N,V8?8IR#8I]BSV*K9@=BGV*_9AR#9AMJIV8;;C-BO(-F((-BUV8'8
MK=F'(-BJV8C9A-N,V*\@V;[;C-BZV*?9A2#8M-F%V*<@V*_8L2#;C-JI(-F^
MV8;8K-BQV8<@VJ_8M-F(V*_9AMN,(-BHV*?8M-BOV(P@V+39A=BG(-F%V*S8
MJ-F(V+$@V*C9AR#9B-BQV8C8KR#8K]F(V*C8I]BQV8<@V*_8L2#9OMF&V*S8
ML=F'V90@V*?8M=F$VXP@V*[9B-BGV8?;C-BO(-BHV8C8KR#9B"#8I]N,V88@
MV*?9A=BQ(-F%VXSB@(S8JMF(V*?9AMBO(-BHV*?8N=BK(-BOV++8K]N,V*_9
MAB!)1"#9AMBTV+/8JB`@V+39A=BG(-BJV8C8L]BW(-F&V8'9B-BPVJ_8L=BG
MV88@V+39B-BO`-F$V+?9@=BGV8L@V*[9A-BGV+79A^*`C-BGXH",VXS;C"#8
MI]BR(-F%V+3:J=F$(-BQV*<@V*C9AMF(VXS8L]N,V*\`V838M]F!V*?9BR#8
MI]BSV84@V+'9A=BR(-BNV8C8KR#8L=BG(-BBV878I]BOV8<@VJG9AMN,V*\`
MV838M]F!V*?9BR#9AMBGV84@VJG8I]BQV*C8L2#9B"#8I]BSV84@V+'9A=BR
M("#8KMF(V*\@V+'8IR#8HMF%V*?8K]F'(-JIV8;;C-BO`-F$V+?9@=BGV8L@
MV8;8I]F%(-JIV*?8L=BHV+';C"#8KMF(V*\@V+'8IR#8HMF%V*?8K]F'(-JI
MV8;;C-BO.@#9A-BWV8'8I]F+(-F%V*K9AB#8LMN,V+$@V+'8IR#8J-BNV8C8
MI]F&VXS8KRX@V+39A=BG(-BHV+'8I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@
MV+/8I]F%V*?9AMF'(-BHV*?;C-BO(-BTV+'9B-BW(-BQV*<@V8+8J-F(V80@
MVJG9AMN,V*\`V838M]F!V*?9BR#8I]BHV8?8I]F%(-N,V*<@V*+8K]BQV+,@
MV+K;C-BQV878N=BJV*C8L2#8L=BG(-BHV+'8M]BQV8$@VJG9AMN,V*\`V838
MM]F!V*?9BR#8I]BWV838I]BYV*?8JB#8LMN,V+$@V+'8IR#9A=BQV8C8L2#:
MJ=BQV*_9A]B,(-F((-BSV;[8LR#;C-JI(-F!V+G8I]F$VXS8JB#8I]BR(-JO
MV++;C-F&VJ_8I]F&(-BRVXS8L2#8L=BG(-BHV+':K]BRVXS9AMN,V*\`V838
MM]F!V*?9BR#9@MBHV80@V*?8LB#8I]F&V*S8I]F%(-F'V+$@VJ_9B-F&V8<@
MV8'8N=BGV83;C-BJVXP@VXS:J2#9OMF(V+39AR#8I]F&V*K8KMBGV*@@VJG9
MAMN,V*\`V838M]F!V*?9BR#;C-JI(-F!V+G8I]F$VXS8JB#8I]BR(-JOV++;
MC-F&VJ_8I]F&(-BRVXS8L2#8L=BG(-BHV+':K]BRVXS9AMN,V*\`V838M]F!
MV*?9BR#8K=BOV*?9@MF$(-N,VJD@V+38I]BNV8<@V*C8L=BGVXP@V*S8L]BJ
MV*S9B"#8I]F&V*K8KMBGV*@@VJG9AMN,V*\`V838M]F!V*?9BR#8J-BQV*?;
MC"#8I]N,V88@V+G9A=F$(-F!V8+8MR#;C-JI(-F^V8C8M-F'(-BGV8;8JMBN
MV*?8J"#:J=F&VXS8KP#9A-BWV8'8I]F+(-BOV+$@V*S8N=BHV8?9E"#:AMF^
M(-BGV8;8JMBNV*?8J"#9B"#;C-BG(-F(VXS8L=BGVXS8M"#:J=F&VXS8KSH`
MV838M]F!V*?9BR#9AMBGV84@V*_8L]BJV8<@V*S8K]N,V*\@V+'8IR#9B-BG
MV+'8KR#:J=F&VXS8KSH`V+/;C-BGV+/8JMF'V*<`V*+8L=BGV*$`V878K=F$
M(-F"V+'8I]BQVJ_8L=F!V*K9AB#8I]N,V88@V*K8M=F(VXS8L0#9A=BMV80@
MV8+8L=BGV+':K]BQV8'8JMF&(-BGVXS9AB#8K-BOV8C9A`#9OMBSV*H@V*C9
MAR#8I]N,V88@V;[9B-BTV8<`V*_8L2#8I]BNV*K;C-BGV+$@V8?9B-BQV*\`
MV8+8J-F$(-BGV+(@V*?9A=BVV*?;C"#8M-F%V*<@V*[8MR#9@=BGV+79A-F'
M("@G+2T@)RD@VJ_8L-BGV+38JMF'(-BTV8C8K]B?`-BOV+'8M=BO(-BQV+?9
MB-BHV*H@V*_8L2`E<R#8L]BGV+G8JB#9@MBHV80Z`-JOV++;C-F&V8?B@(S9
MA]BG(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-BQV8C8LMBQV+/8I]F&VXP@
MV+38K]F&V*\`4')E9G-?;&1A<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR
M($Q$05`@V;[;C-BOV*<@V8;8M-BO`%!R969S7W-E<W-I;VXZ(-BHV+/8MR#9
MA=F(V+'8KR#9AMN,V*?8LB!S97-S:6]N(-F^VXS8K]BG(-F&V+38KP#9@=BT
MV*?8L0#9@=BTV*?8L2#8K]BQ(-BSV+?8K2#8K]BQVXS8ISH@`-F!V+38I]BQ
M.B``V;[;C-BTXH",V8;9A=BGVXS8M`#9OMN,V+3B@(S9AMF%V*?;C-BT(-BJ
MV+79B-N,V+$@V*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@`-F^VXS8
MNMBGV84@V8+8J-F$VXP`V+79@=BMV8?9E"#9@MBHV83;C`#:K]BRVXS9AMF'
MXH",V8?8I]N,(-F"V*C9A-N,`-J&V*?9O@#:AMBGV;X@V+/9AMBO`-BGV8C9
MA-F(VXS8J@#:J=F$VXS8KR#8M-BNV+7;C`#8I]BSV84@V+'9A=BR(-JIV83;
MC-BO(-BNV+79B-BUVXP`V878M-JIV80`V*K9B-BVVXS8K2#9A=BTVJG9A`#9
MOMBQV8C:F-F'XH",V8?8IP#8I]BYV838I]F&(-BRV878I]F&VXP@VJG9AR#;
MC-JI(-F^VXS9B-BSV*H@V*?8L=BSV*?9A"#9A=N,XH",VJ_8L=BOV*\Z(-F%
MV8+8K]BGV+$@V;[;C-BT(-F!V+'8MB#9AMF'(-BGV+/8J@#8I]BYV838I]F&
M(-BRV878I]F&VXP@VJG9AR#;C-JI(-F^VXS9B-BSV*H@V*?8L=BSV*?9A"#9
MA=N,XH",VJ_8L=BOV*\Z(-F%V8+8K]BGV+$@V;[;C-BT(-F!V+'8MB#8J-F$
MV8<@V*?8L]BJ`-F%V*K9AB#8I]BYV838I]F&`-F^V+'9B-BJVJG9A#H`VJG9
MA-N,V*\@V+G9A=F(V87;C`#8I]F$VJ_9B-BQVXS8JMF%(-JIV83;C-BO(-BY
MV879B-F%VXP`V;[8M-BJVXS8J-BGV8;;C"#:J=BGV+'8L]BGV+(@VJG9A-N,
MV*\@V+G9A=F(V87;C"#B@(Q01U`@V+K;C-BQ(-F!V+G8I]F$(-BTV*_9AR#8
MI]BSV*H`V*S9@=BJ(-JIV83;C-BO(-BYV879B-F%VXPOV*[8M=F(V+7;C"#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V*K9B-F$VXS8KR#9AMBTV*\`V;[8I]JI
MV+/8I]BRVXP@V*W8L-F!(-BTV*_9A^*`C-F'V*<`V;[8I]JIV+/8I]BRVXP@
MV*W8L-F!(-BTV*_9A^*`C-F'V*<`V;[8I]JIV+/8I]BRVXP@V;[9B-BTV8<H
MV8?8IRD`(-F^V*?:J=BSV*?8LMN,(-BSV+?9A"#8HMBTV+K8I]F$(-BOV+$@
MV*C8I]BRV8?B@(S9A]BGVXP@V++9A=BGV8;;C#H`V;[8I]JIV+/8I]BRVXP@
MV;[;C-BZV*?9A=F'V*?;C"#9OMF(V+39A]F4(-BSV+?9A"#8HMBTV+K8I]F$
M(-JIV8<@V*?8LB#8I]N,V88@VH;9AMBO(-BQV8C8LB#9@MBOVXS9A=N,XH",
MV*K8L>*`C"#8J-BGV+39AMBO`-BBVXS8IR#9OMN,V+K8I]F%V8?8I]N,(-F"
MV*_;C-F%VXP@V*_8L2#9OMF(V+39A]F4(-BSV+?9A"#8HMBTV+K8I]F$(-F^
MV*?:J=BSV*?8LMN,(-BTV8C9AMBOV)\`V;[8I]JIV+/8I]BRVXP@)60@V;[;
MC-BZV*?9A2#8I]BR(-F^V8C8M-F'V90@V+/8M]F$(-BBV+38NMBGV80`V;[8
MI]JIV+/8I]BRVXP@VXS:J2#9OMN,V+K8I]F%(-BGV+(@V;[9B-BTV8?9E"#8
ML]BWV80@V*+8M-BZV*?9A`#9OMBQV+/B@(S9B-BLV8@`V+/9A]F%VXS9AP#9
MB-BVV+G;C-BJXH",(-BSV8?9A=N,V8<Z("4N,F9-0B`O("4N,F9-0B`@*"4N
M,F8E)2D`V8C8MMBYVXS8JB#8L]F'V87;C-F'.B`E+C)F(-F%VJ_8I]BHV*?;
MC-BJ+]BHV*_9B-F&(-F%V*W8K]F(V*_;C-BJ`-F(V+;8N=N,V*KB@(P@V+/9
MA]F%VXS9ASH@V*C8K]F(V88@V878K=BOV8C8K]N,V*H`V8;9@MF$(-F"V8C9
MA"`E9CH`(-JIV83;C-BO(-BYV879B-F%VXP@4E-!("@E9"#8J-N,V*HI`-BG
MV8;8JMBNV*?8J"#8L=BGV*_;C-F(`-BHV*?8L=BGV88`V*C8I]BQV*?9AB#8
MLMF(V*_9A]F&VJ_8I]F%`-BHV*?8L=BGV88@V*_;C-BQV8?9AMJOV*?9A0#8
MJ-BGV+'8I]F&(-F((-BQVJ_8J-BGV+$`V*C8I]BQV*?9AB#9B"#8J-BQV8$`
MV*C8I]BQV*?9AB#8J-F'(-BHV+'9@0#8M]BGV838N2#8JMBUV*?8K]F!VXP`
MV8;8L]BHV*H`V*_8L=BNV8C8I]BSV*H@V*K8I]BFVXS8K]N,V8?9E"#8JMBM
MV8C;C-F$`-BNV8C8I]F&V*_9A@#8KMF(V*?9AMBOV88@V;[;C-BZV*?9A=F'
MV*<@`-F(V*?9@MBYV*?9DB`E<R#8K=BPV8$@V+39B-BOV)\@V*?;C-F&(-BY
MV879A"#9@MBGV*C9A"#9B-BGVJ_8L=BO(-F&VXS8L]BJ`-F(V*?9@MBYV*?9
MBR#8K]BGV*_9A]F4(-JIV*?8L=BHV+';C"#8J-BQV*?;C"#:J=BGV+'8J-BQ
M("5S(-BMV+#9@2#8M-F(V*_8GR#8I]N,V88@V+G9A=F$(-F"V*?8J-F$(-F(
MV*?:K]BQV*\@V8;;C-BSV*H`V*_8L=N,V*?9@=BJ(-BTV*_9AR#8J-BQ`-BO
MV+';C-BGV8'8JB#8M-BOV8<@V*?8L@#8K]BQVXS8I]F!V*H@V+38K]F'(-BJ
MV*<`V*K8NMN,VXS8L2#9A=BSVXS8L0#8JMBZVXS;C-BQ(-F%V+/;C-BQ`-BJ
MV+K;C-N,V+$@V878L]N,V+$@V;[;C-BZV*?9A0#8JMBZVXS;C-BQ(-F%V+/;
MC-BQ(-BGVXS9AB#9OMN,V+K8I]F%`-BJV+K;C-N,V+$@V878L]N,V+$@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO`-BGV8;8K-BGV84@V*+8KMBQVXS9AB#8N=F%
MV80@V+39A=BG(-BGV+(@V8;9B`#8J-BGV++8HMF(V+';C`#8J-BGV++8HMF(
MV+';C"#8N=F&V*?8M=BQ(-JOV++;C-F&VJ_8I]F&(-BOVXS9AMBGV87;C-JI
MVXPZ`-BHV*?8LMBBV8C8L=N,(-F&V878I]F'V*?;C"#9OMF(V+39ASH`V*C8
MI]BRV*+9B-BQVXP@V8;9A=BGVXP@V*_8L=JOV*?9ASH`V878L=F(V+':K]BQ
M(-BQV*?8J-BWV8?B@(S8I^*`C-N,VXP`V*C8I]BQVJ_8L-BGV+';C"#9A=BL
MV*_8KP#8J-BGV+':K]BPV*?8L=N,(-F%V*S8K]BO(-F&V878IP#8JMF(V+;;
MC-BMV*?8J@#8J-F'(-N,V*?8K]BBV8C8L=N,(-BGV+?9A-BGV+G8I]BJ(-BB
MV++8I]BO+]F%V+38NMF(V80`V*C9AR#B@(S;C-BGV*_8HMF(V+';C"#8HMBN
MV+';C-F&(-F!V+'9A2#9AMF%V*?;C-BT`-F&V*?9A=F'XH",V*_8I]F&(-BQ
MV*?9AR#8K]F(V+$Z`-JIV*?8L=BSV*?8LMF'V*?;C"#8L=BGV8?B@(S8K]F(
MV+$`55),`-BMV+#9@0#8K=BPV8$@V*C9A-F(VJD`V*W8L-F!(-F!VXS9A-BO
M(-BGV+(@V*S8L]BJV*S9B`#8K=BPV8$@V+/8JMF(V88`V*W8L-F!(-F"V*?9
MA-BH(-BHV8;8K]N,`-BMV+#9@2#8LMF(V*P`V*W8L-F!(-BOV+/8JB#B@(S9
MAMF(VXS8L]F'V*?;C"#8K=F!V+@@V+38K]F'(-BOV+$@V+38I]BNV8<@V879
MB-F"V*H@VJG8I]BQV+/8I]BR`-BMV+#9@2#8L]BQVH;8M-F%V8<`V*W8L-F!
M`-BMV+#9@2#8I]N,V88@VJ_8L=F'(-BGV+(@V+/9AMBO`-BMV+#9@2#:J=BG
MV+'8J-BQ`-BMV+#9@2#:J=BGV+'8J-BQ.B`E<P#8JMBZVXS;C-BQ(-F&V*?9
MA2#9OMF(V+39ARC9A]BG*0#8HMN,V*<@V;[9B-BTV8?9E"#9AMBGV879A^*`
MC-F'V*?;C"#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V*_8L2#8I]BHV*K8K]BG
MVXP@V878I]F'(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8K]F'(-BTV8C8K]B?
M`-BJV+K;C-N,V+$@V8;8I]F%("(E<R(@V*C9AR`B)7,B(-F&V*?9A=F(V8'9
MD=F"(-BHV8C8KRX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JIV*?8
ML=BSV*?8LB#:K]F!V*K9AR#8I]BSV*H`V;[8I]BSV*X@V*C9AR#9@=F'V+'8
ML]BJ`-BLV*?;C-JOV++;C-F&(-JIV+'8K]F&(-BHV*<Z`-F^V*?8L]BN(`#9
MOMBGV+/8KB#8I]BQV+/8I]F$(-BTV*\`V;[8I]BSV*X@V*C9AR#9A]F%V8<`
MV;[8I]BSV*X@V*C9AR#9A]F%V8<Z`-F^V*?8L]BN(-BHV8<@V8'9A]BQV+/8
MJ@`ZV;[8I]BSV*X@V*C9AR#9@=F'V+'8L]BJ`-F^V*?8L]BN(-BHV8<@V8?9
MA=F'`-F^V*?8L]BN(-BHV*<@V;[;C-BZV*?9A2#9OMBTV*K;C-BHV*?9AMN,
M(-F&V+38K]F'`-F^V*?8L]BN(-BHV*<@V*+8LMBGV*\OV878M-BZV8C9A"#8
MJ-BQV*?;C"#8K]F((-F%V*?9AR#8HMN,V8;8K]F'`-F^V*?8L]BN(-BHV*<@
MV*?8M]F$V*?8N=BGV*H@V*+8LMBGV*\OV878M-BZV8C9A"#8KMF(V*?8L]BJ
MV8<@V+38K]F'`-F^V*?8L]BN(-BHV8<`V;[8I]BSV*X@V*C9ASH@`-F^V*?8
ML]BN.@#:K]BRV*?8L=BT(-BHV+G9AMF(V*?9AB#8J-N,XH",V+;8L=BQ`-JO
MV++8I]BQV+0@V*C8N=F&V8C8I]F&(-F'V+'8LMF&V*?9A=F'`-BOV+'8KMF(
MV*?8L]BJ(-N,VJD@V+'8L]N,V*\@V878M]BGV838N=F'`-BJV8+8I]BVV*<@
MV8+8I]BHV80@V;[8I]BSV*[:K]F(VXS;C"#9AMN,V+/8JBX@VJG8KR#8KMBW
MV*?;C"#8J-BQVJ_8L=BOV*?9AMBOV8<@V+38K]F'.@`@V*+;C-BG(-BHV+'8
MI]N,(-BJV*W9B-N,V80@V*K8I]BFVXS8K]N,V8<@V*_8L=BNV8C8I]BSV*H@
MV+39B-BOV)\`V*+;C-BG(-BQV+/;C-BO(-F%V+?8I]F$V+G9AR#8K]BQV*[9
MB-BGV+/8JB#8M-F(V*_8GP#9OMN,V+K8I]F%(-BNV8C8I]BSV*K9AR#8M-BO
MV8<@V;[;C-BOV*<@V8;8M-BO`-F!VXS9A-BOV8?8I]N,(-F%V8C8L=BO(-F&
MVXS8I]BR`-BTV+';C-JI(-F%V8C8L=BO(-F&VXS8I]BR`-BHV*?8LMF&V+38
MI]F&VXP`V*C8I]BRV8;8M-BGV8;;C"#8I]BSV84@V+'9A=BR`-BGV+/9A2#8
ML=F%V+(@V*[9B-BO(-BQV*<@V*C8I]BRV8;8M-BGV8;;C"#:J=F&VXS8KP#8
MK=BGV838I]BJ(-F^V*?8L]BNVJ_9B-N,VXP@V*C8L=F(V++8L=BSV*?9AMN,
M(-BTV*_9AMBO`-F&V*K8I]N,V*P`V*?8LB#8L]BQVJ_8L=F!V*K9A@#8I]BR
M(-BSV+$@VJ_8L=F!V*K9AB#9AMBTV+/8JB#8M-F%V*<`V*C8I]BRVJ_8M-BJ
M(-BHV8<@V*?;C-BLV*?8KR#9OMN,V+K8I]F%`-BHV*?8LMJOV+38JB#8J-F'
M(-F(V*?:J=BTVXP@V8;8I]F%V8<`V*C8I]BRVJ_8M-BJ(-BHV8<@VJ_8LMN,
MV8;9A^*`C-F'V*<`V*+;C-BG(-BHV+G8KR#8I]BR(-BMV+#9@=B,(-BGV8;8
MJMF"V*?9A"#9B"#;C-BG(-BQV8C9AMF(V+38JB#:K]BQV8'8JMF&(-BGV+(@
MVXS:J2#9OMN,V+K8I]F%V(P@V*C9AR#9@=F'V+'8L]BJ(-F&V*?9A=F'XH",
MV*_8I]F&(-BHV*?8LMJOV+38JB#8M-F(V*_8GP#8JMBGVXS9OB#8K]F(V*C8
MI]BQV8<@V*?8L]F%(-BQV878LB`@V*S8K]N,V*\@`-JOV+'8K]F'V878I]N,
MVXP`V*C8I]BRVJ_8L=BOV*?9AMBOV88@V;[;C-JIV+'8J-F&V*_;C`#:K]BR
MVXS9AMF'XH",V8?8I]N,(-F(VXS8L=BGVXS8M-JOV+$@V878JMF&`-F%V+G9
MA=BGV8?8IP#8L=BGV+/8J@#8L]BQV*+9A=BO(-BQV*?8L]BJ`-F%V8+8I]BO
MVXS8L2#8L=BGV+/8J@#8KMBUV8C8M=N,V*?8JB#8L]BWV+$N+BX`V8;9@MBT
M`-J&V+'8KMBT(-NQV[C;L"#8K]BQV*S9AP#:AMBQV*[8M"#8J-F'(-J&V;X`
MVH;8L=BNV+0@V*C9AR#8L=BGV+/8J@#8KMBUV8C8M=N,V*?8JB#8L]BWV+$`
MV*[8M=F(V+7;C-BGV*H@V+/8M]BQ`-BSV+?8L=F'V*<Z`-F"V8C8I]BYV*\`
MV8+9B-BGV+G8KR#8J-N,V88@V*K9A=BGV84@V+/8M]BQV8?8IR#9B"#8L]BJ
MV8C9AMF'V*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@V+38KP#9@MF(V*?8
MN=BO(-F!V8+8MR#8J-N,V88@V*K9A=BGV84@V+/8JMF(V8;9A]BG(-F&V878
MI]N,V*?9AB#8KMF(V*?9A]BO(-BTV*\`V8+9B-BGV+G8KR#9@=F"V+<@V*C;
MC-F&(-BJV878I]F%(-BSV+?8L=F'V*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'
MV*\@V+38KP#8I]BLV+'8IP!3+TU)344`V;[;C-BZV*?9A2#8L=F%V++8J-F&
MV*_;C"!3+TU)344@`-F^VXS8NMBGV84@V+'9A=BRV*C9AMBOVXP@(-BTV*_9
MA]F4(%,O34E-12``V*[8M]BGVXP@4R]-24U%.B``V*[8M]BGVXP@4R]-24U%
M.B#9AMN,V*?8LB#8J-F'(-BYV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-JI
MV83;C-BO(-BNV+79B-BUVXP@V+38KMBUVXP`VJ_8LMN,V8;9A^*`C-F'V*?;
MC"!3+TU)344`V8C8I]BQV*_:J=BQV*_9AB!3+TU)344@V+G8J-BGV+'8JB#:
MK]BPV+$`V;[8M-BJVXS8J-BGV8;;C"#8K-F!V*H@VJG9A-N,V*\@V+38KMBU
MVXP@4R]-24U%(-BHV8<@VXS:J2#8I]BJV+78I]F$(-BGV879AB#9B-BH(-F&
MVXS8I]BRV879AMBO(-BGV+/8J@#:J=F$VXS8KR#8N=F%V8C9A=N,(%,O34E-
M12#8J-BQV*?;C"`B)7,B(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=BPV8$@
MV+38KP#:J=F$VXS8KR#8N=F%V8C9A=N,(%,O34E-12#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*?8MMBGV8'9AR#8M-BO`-BMV839@MF'V90@VJG9A-N,V*\@
MV+G9A=F(V87;C"!3+TU)344`V*S9@=BJ(-JIV83;C-BO(-BYV879B-F%VXPO
MV+38KMBUVXP@4R]-24U%(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]BVV*?9
M@=F'(-BTV*\`V*?9A=BVV*?8H2#8M-BOV8<@4R]-24U%(-F^VXS8NMBGV84`
MV;[;C-BZV*?9A2#8L=F%V++8J-F&V*_;C"#8M-BOV8<OV*?9A=BVV*?8H2#8
MM-BOV8<@4R]-24U%(`#9OMBTV*K;C-BHV*?9AMN,(%,O34E-12#8L=F(VXP@
MV*?;C-F&(-BSV*?9A=BGV8;9AR#9@=BYV*?9A"#9AMN,V+/8J@#9OMBTV*K;
MC-BHV*?9AMN,(%,O34E-12#8K]BQ(-BMV*?9A"#8K=BGV+;8L2#9@=BYV*?9
MA"#9AMN,V+/8JB#8I]BR(-BGVXS9AMBQV8@@V;[;C-BZV*?9A2#9@MBGV*C9
MA"#8L=F%V++:K]BTV*?;C-N,(-F&VXS8L]BJ`-F^V+38JMN,V*C8I]F&VXP@
M4R]-24U%(-F!V+G8I]F$(-F&VXS8L]BJ(-BGV+(@V*?;C-F&V+'9B"#9A=BJ
MV88@V;[;C-BZV*?9A2#9AMF%VXSB@(S8JMF(V*?9AMBO(-F&V878I]N,V+0@
MV*_8I]BOV8<@V+39B-BO`-F^V+38JMN,V*C8I]F&VXP@4R]-24U%(-F!V+G8
MI]F$(-F&VXS8L]BJ(-BGV+(@V*?;C-F&V+'9B"#8I]F%V+;8I]N,(-BOVXS8
MK-N,V*K8I]F$VXP@V8+8I]BHV80@V*C8I]BRV*C;C-F&VXP@V8;;C-BSV*H`
MV;[8M-BJVXS8J-BGV8;;C"!3+TU)344@V*C8L=BGVXP@V+G9A=F$VJG8L=BO
M(-BUV*W;C-BM(-BNV8C8KR#9AMN,V*?8LB#8J-F'(-F^V8;8K-BQV8?B@(S9
MA]BGVXP@VJ_8M-F(V*_9AMN,(-BOV*?8L=BO(-F%V+'9B-BQVJ_8L=BNV8C8
MKR#8L=BG(-BHV+'8I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V*?;C-F&(-F^
MV8;8K-BQV8?B@(S9A]BG(-BJV8;8N-N,V84@VJG9AMN,V*\`V*K8M=BOVXS9
M@B#9A]F(VXS9D=BJ(%-!4TP@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&VXS8
ML]BJ`-F^VXS8NMBGV84@4TU3`-F^V8C8L]BJV8<@4U%,`%-32`#9A=F(V8'9
MD=F"VXS9D=BJ`-F^V8C8L]BJV8<@4U%,`-BYV8;9B-BGV88`V+39AMBHV8<`
MV*W9@=BX(-N,VJD@V+'9B-F&V8C8M-BJ(-BOV+$`V*W9@=BX(-BHV*<@V8;8
MI]F%`-F'V878I]F&(-J&V*?8L=J&V8C8J"`HV*[9B-BOV+0I`-BMV8'8N`#8
MK=F!V+@@VJG8L=BOV88@)7,`V*+;C-BG(-F^VXS9B-BSV*K9A]BGVXP@V;[;
MC-BZV*?9A2#8K]BQ(-F^V8C8M-F'V90@V8;8I]F%V8?B@(S9A]BGVXP@V8'8
ML=BSV*K8I]BOV8<@V+38K]F'(-BMV8'8N"#8M-F(V*_8GP#8K=F!V+@@V;[;
MC-BT(-F&V8C;C-BS`-BMV8'8N"#8JMBUV8C;C-BQ`-BMV8'8N"#8JMBUV8C;
MC-BQ(-BOV+$@VJ_8I]F$V+';C`#8K=F!V+@@VJ_8LMN,V8;9A^*`C-F'V*<`
MV*W9@=BX(-F&V8C8M-BJXH",V*?9@=BRV*?8L0#8K=F!V+@@V;[;C-BT(-F&
MV8C;C-BS`-BMV8'8N"#8J-BG(-F&V*?9A0#8HMN,V*<@V;[;C-BT(-F&V8C;
MC-BSV8?8IR#8J-BYV8;9B-BGV88@V;[;C-BZV*?9A=F'V*?;C"#9A=BTV*?9
MA]BOV8<@V8;8M-BOV8<@V*W9@=BX(-BTV8C8K]B?`-F^VXS:J=BQV*C9AMBO
MVXP@V*K9B-F$VXS8KR#8M-BOV8<@V*C8N=F&V8C8I]F&(-BOV+/8JB#B@(S9
MAMF(VXS8LR!02%`@V*_8L2#8M-BGV*[9A]F4(-F%V8C9@MBJ(-JIV*?8L=BS
MV*?8LB#8M-F%V*<@V*W9@=BX(-BTV8C8KP#8HMN,V*<@VJ_;C-BQV8;8K]F'
MXH",V8?8IR#8J-F'(-BWV8C8L2#8KMF(V*_:J=BGV+$@V*_8L2#:J=BJV*?8
MJ-J&V8?9E"#8HMBOV+'8LR#8K=F!V+@@V+39B-F&V*_8GP#8HMN,V*<@V*S8
ML]BJV*S9B"#8J-F'(-BYV8;9B-BGV88@VXS:J2#9OMF(V+39A]F4(-F%V*S8
MI]BRVXP@V*W9@=BX(-BTV8C8K]B?`-BBVXS8IR#9AMBGV879A]F4(-F!V+'8
ML]BJV*?8K]F'(-BTV*_9AR#8K=F!V+@@V+39B-BOV)\`V;[;C-JIV+'8J-F&
MV*_;C"`E<R#8K=F!V+@@V+38KP#8K=F!V+@@V;[;C-BT(-F&V8C;C-BS(-F&
MV*?9A=F(V8'9D=F"(-BHV8C8KRX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:
MJ=F'(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*HZ("5S`-BYV839A0#8
MK-BSV*K8K-F(`-BLV+/8JMBLV8@@)7,`V*S9B-N,V+3:K]BQV8?8IP#9AMBJ
MV*?;C-BL(-BLV+/8JMBLV8@`V878M-BGV8?8K]F'(-BTV*_9AP#8I]F&V*K8
MKMBGV*@`V*?9AMBJV*[8I]BH(-N,VJD@V*W8L]BGV*@@V*_;C-JOV+$`V*?9
MAMBJV*[8I]BH(-F^V+'9B-F&V*_9A^*`C-F'V*<`V*?9AMBJV*[8I]BH(-N,
MVJD@V*K8I]BQVXS8K@#8I]F&V*K8KMBGV*@@VXS:J2#9@=N,V838KP#8I]F&
MV*K8KMBGV*@@VXS:J2#:K]BQV8C9AR#8J-BQV*?;C"#8I]BVV*?9@=F'(-JI
MV+'8K]F&`-BGV8;8JMBNV*?8J"#;C-JI(-F%V*?9A-JI(-BLV*_;C-BO`-BG
MV8;8JMBNV*?8J"#;C-JI(-JIV*?8L=BSV*?8L@#8I]F&V*K8KMBGV*@@VXS:
MJ2#9AMF(V+38JN*`C-BGV8'8LMBGV+$Z`-BGV8;8JMBNV*?8J"#;C-JI(-JI
MV*?8L=BHV+$@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9A@#8I]F&V*K8
MKMBGV*@@VJG8JMBGV*C:AMF'XH",V8?8I]N,(-BBV*_8L=BS(-BGV+79A-N,
M(-BHV+'8I]N,(-BLV+/8JMBLV8@@V8@@V*?8MMBGV8'9AR#:J=BQV*_9AB#8
MHMBOV+'8L]F'V*<`V*?9AMBJV*[8I]BH(-F'V879AP#8I]F&V*K8KMBGV*@@
MV*K9A=BGV84@V878I-F$V8'9A^*`C-F'V*?;C"#8JMBGV+';C-BN`-BGV8;8
MJMBNV*?8J"#8JMF%V*?9A=N,(-F!VXS9A-BOXH",V8?8IR#8J-BQV*?;C"#8
MK-BSV*K8K-F((-F(V8+8JMN,(-BBV*_8L=BSV8?8IR#8J-BGV+(@V87;C.*`
MC-BTV8C9AMBO(`#8I]F&V*K8KMBGV*@@VXS:J2#8K=BSV*?8J`#8I]F&V*K8
MKMBGV*@@VXS:J2#8M-BF`-BGV8;8JMBNV*?8J"#9A]N,VH;B@(S;C-JI`-F&
MV8C;C-BSV8?B@(S9A]BGVXS;C"#:J=F'(-F$V*?8LMF%(-BOV*?8L=N,V*\@
MV+'8IR#8I]BR(-BLV+G8J-F'(-BRVXS8L2#8I]F&V*K8KMBGV*@@VJG9AMN,
MV*\N(-BSV;[8LR#8M-F%V*<@V87;C.*`C-BJV8C8I]F&VXS8KR#8I]BR(-BB
MV8;9A]BG(-BOV+$@V879AMBWV8+9AR#9A=BJV88@V8;8L]BNV8?B@(S8J-BQ
MV*_8I]BQVXP@VJG8L=BOV8<@V8@@V*_8L2#9A=BMV80@V*_;C-JOV+$@V*C:
MAMBSV*C8I]F&VXS8KP#8I]F&V*K8KMBGV*@@V878K=BOV8C8K]F'(-BJV*?8
ML=N,V*XZ`-BGV8;8JMBNV*?8J"#9@MBGV838J"#8JMBGV+';C-BN.@#8I]F&
MV*K8KMBGV*@@VJ_8I]F$V+';C"#8J-BQV*?;C"#8K=F!V+@@V*K8M=F(VXS8
ML0#8I]F&V*K8KMBGV*@@V8?9B-N,V9'8JMN,(-JIV8<@V87;C.*`C-BNV8C8
MI]F'VXS8KR#8JMBZVXS;C-BQ(-BOV8?;C-BO.@#8I]F&V*K8KMBGV*@@V8;9
MB-BY(-JIV*?8L=BSV*?8LB#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:
MJ=N,`-BGV8;8JMBNV*?8J"#9A=BMV*_9B-BOV8?9E"#8LMF%V*?9ACH`V*?9
MAMBJV*[8I]BH(-F"V*?9A-BH(-BRV878I]F&.@#8I]F&V*K8KMBGV*@@V*_9
MB"#9@=N,V838KR#9A=F&V+?8J-F"`-BGV8;8JMBNV*?8J"#8M]BQV*T@V+'9
MAMJO(-BTV878IP#8I]F&V*K8KMBGV*@@V++8J-BGV88@V879B-BQV*\@V8;8
MN-BQ(-BTV878ISH`V*?9AMBJV*[8I]BH(-JIV*K8I]BHVH;9A^*`C-F'V*?;
MC"#8HMBOV+'8LSH`V*?8L=BSV*?9A"#:J=F$VXS8KR#8J-F'(-JIV*?8L=BS
MV*?8LB#:J=F$VXS8KR#8N=F%V8C9A=N,`-BGV+'8L]BGV80@V*+8KMBQVXS9
MAB#8I]BWV838I]BYV*?8J@#8I]BQV+/8I]F$(-F^VXS8NMBGV84`V*?8L=BS
MV*?9A"#:K]BRV*?8L=BT`-BGV+'8L]BGV80@4TU3`"#8HMN,V*?8L=BSVXS8
MKR#9A=BWV*?9A-BYV8<@V8?9AMJOV*?9A=N,(-JIV8<@V*?8L=BSV*?9A"#:
MJ=F&V8;8K]F'(-BOV+'8KMF(V*?8L]BJ(-F%VXSB@(S:J=F&V*_8C"#8I]BQ
MV+/8I]F$(-BTV8C8K]B?`-BMV+/:K]BQ.B``V;[9B-BTV8<@V;[;C-BZV*?9
MA=F'V*?;C"#9@=BQV+/8JMBGV*_9AR#8M-BOV8<`V;[9B-BTV8<@V;[;C-BZ
MV*?9A=F'V*?;C"#9@=BQV+/8JMBGV*_9AR#8M-BOV8<Z`-BSV;[8JMBGV878
MJ-BQ`-BGV+G8K]BGV*\@V*K8L=BJVXS8J-N,`-JIV*?8L=BSV*?8L@#8I]BW
MV838I]BYV*?8JB#:J=BGV+'8L]BGV+(@V8@@V;[9B-BTV8<`VJG8I]BQV+/8
MI]BR.@!)1"#9AMBTV+/8JB#9A=F&V8+8MMN,(-BTV*_9AR#8I]BSV*H`V*K9
MAMBXVXS9A0#8JMF&V+C;C-F%(-JOV++;C-F&V8?B@(S9A]BG(-BHV+'8I]N,
M(-BGV*S8I]BRV8<@V*_8I]BOV88@V*C9AR#8M-F%V*<@V*C8L=BGVXP@V*C8
MI]BRV8;8M-BGV8;;C"#8I]BSV84@V+'9A=BR(-BHV8<@V8?9AMJOV*?9A2#9
M@=BQV*?9A=F(V+3;C"#8HMF&(`#8JMF&V+C;C-F%(-JOV++;C-F&V8?B@(S9
MA]BG(-BHV+'8I]N,(-BRV878I]F&(-BMV+#9@2#9B"#;C-BG(-BGV8;8JMF"
MV*?9A"#9OMN,V+K8I]F%V8?8IP#8HMN,V*<@V+/8L=BBV878KR!8+5!R:6]R
M:71Y(-F'V8;:K]BGV84@V*?;C-BLV*?8KR#9OMN,V+K8I]F%V8?8IR#8JMF&
MV+C;C-F%(-BTV8C8K]B?`-BJV8;8N-N,V84@VJG8I]BQV+/8I]BRV8?8I]N,
M(-BQV*?9AR#8K]F(V+';C"#:J=F'(-BTV878IR#9A=N,XH",V*[9B-BGV8?;
MC-BO(-BGV+(@V*_8L=JOV*?9AR#8KMF(V*\@V*C9AR#8HMF&(-BOV+/8JMBQ
MV+/;C"#8K]BGV+38JMF'(-BHV*?8M-N,V*\`V*?9AMBJV*[8I]BH(-BRV*C8
MI]F&(-F%V8C8L=BO(-F&V+C8L=B,(-BSV*?8N=BJ(-F((-JOV++;C-F&V8?B
M@(S9A]BGVXP@V*K8I]BQVXS8K@#8I]F&V*K8KMBGV*@@V*C8L=F&V*?9A=F'
M(-BRV878I]F&(-BTV+'9B-BYV(P@V+?8L=BM(-BQV8;:K]B,(-BHV*?8LMBB
MV8C8L=N,(-BUV8'8K=F'(-F((-BHV8+;C-F'(-JOV++;C-F&V8?B@(S9A]BG
MVXP@V8;9A=BGVXS8M`#8L=BGV8<F(W@R,#!C.]BGV8;8K]BGV++;C`#8K]BS
MV*H@XH",V8;9B-N,V+,@(-BHV+'9B-BRV+'8L]BGV8;;C"#8L=BGV8?B@(S8
MI]F&V*_8I]BRVXP@V*_8L2#8K]BSV*K8L=BS(-BGV+/8J@#:AMF&V*_;C-F&
M(-F%V8C9@MBYVXS9D=BJ(-BHV*<@V;[8I]BQV*?9A=BJV+$@V879A=JIV88@
MV*?8L]BJ.@#9OMF(V+39A^*`C-F'V*?;C"#9A=BTV*K8L=JI`-F^V8C8M-F'
MXH",V8?8I]N,(-F&V*?9A=F'V90@V878M-BJV+':J0#8I]BTV*K8L=BGVJD@
MV;[9B-BTV8?B@(S9A]BGVXP@V8;8I]F%V8?9E"#8M-F%V*<@V*C8IR#:J=BG
MV+'8J-BQV*?9AB#8K]N,VJ_8L0#8KMBQVXS8KP#8KMF$V*?8M=F'(-JIV8C8
MJMBGV8<`V*+;C-BG(-JIV83;C-BOV8?8I]N,(-BOV+/8JMBQV+/;C"#8J-BG
MVXS8KR#8J-BQV*?;C"#8J-N,V+38JMBQ(-F^VXS9B-F&V*_9A]BG(-BJV+G8
ML=N,V8$@V+39B-F&V*_8GP#8HMN,V*<@V*C9A-F(VJG9A]BGVXP@V*C8LMBQ
MVJ\@V8;9@MF$(-F"V8C9A"#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C9AMBO
MV(P@VXS8IR#9OMF&V8?8I]F&(-BTV8C9AMBOV)\@V*?;C-F&("#8JMF&V+C;
MC-F%(-BHV8<@V+'8I]BMV*K;C"#8K]BQ(-F'V+$@V++9A=BGV88@VJG9AR#8
MJ-BNV8C8I]F'VXS8KR#9@MBGV*C9A"#8JMBZVXS;C-BQ(-BGV+/8J@#8HMN,
MV*<@V*C8K]F&V8?9E"#9OMN,V+K8I]F%V8?8IR#8J-BG(-F%V*K9AB#8L]BG
MV*_9AR#8J-BQV*?;C"#8K]BGV*_9AR!01U`@V;[9B-N,VXS8K]F'(-BTV8C9
MAMBOV)\`V*+;C-BG(-BUV8'8K=F'(-BGVXS8K-BGV*\@V;[;C-BZV*?9A2#8
MJ-BGVXS8KR#8J-BYV*\@V*?8LB#8K=F!V+@@VXS:J2#9OMN,V+0@V8;9B-N,
MV+,@V*C8L]BJV8<@V+39B-BOV)\`V*+;C-BG(-JIV83;C-BO(-BYV879B-F%
MVXP@4$=0(-BHV*?;C-BO(-BHV+?9B-BQ(-BNV8C8K]JIV*?8L2#8J-F'(-F^
MVXS8NMBGV84@V+39A=BG(-F^VXS9B-BSV*H@V+39B-BOV)\`V8;9A=BGVXS8
MM`#9AMF%V*?;C-BT(-F'V879A]F4(-F^V8C8M-F'XH",V8?8IP#9AMF%V*?;
MC-BT(-F'V879A]F4(-BSV+'8HMF%V*_9A]BG`-F&V878I]N,V+0@V*W8L-F!
M(-BTV*_9A^*`C-F'V*<`V8;9A=BGVXS8M"#8L]BQV*+9A=BOV8?8I]N,(-F%
MV*W8K]F(V*\@V+38K]F'`-F&V878I]N,V+0@V*?8M]F$V*?8N=BGV*H@V8'9
MA]BQV+/8JB#9AMBGV879A^*`C-F'V*<`V8'9@MBW(-F&V878I]N,V+0@V;[9
MB-BTV8?B@(S9A]BGVXP@V+G8MMF(`-F&V878I]N,V+0@V+K;C-BQV+G8MMF(
MXH",V8?8IP#8HMN,V*<@VXS:J2#8HMN,VJG9B-F&(-BHV+'8I]N,(-BGV*[8
ML"#9OMN,V8C8L]BJV8?8IR#8I]BR(-F^VXS8NMBGV879A]BG(-F&V+38I]F&
M(-BOV*?8K]F'(-BTV8C8K]B?`"#9AMF%V*?;C-BT(-BJV8'8I]F(V*K9A]BG
MVXP@V87;C-BGV88@V;[;C-JIV+'8J-F&V*_;C"#8K=F!V+@@V+38K]F'(-F!
MV+G9A-N,(-F((-BJV8C9A-N,V*\@V+38K]F'(-BLV*_;C-BO`-BBVXS8IR#8
MLMF%V*?9AB#8HMBNV+';C-F&(-F(V+'9B-BO(-BHV8<@V8?9AMJOV*?9A2#9
MB-BQV8C8KR#9AMBTV*?9AB#8K]BGV*_9AR#8M-F(V*_8GP#8HMN,V*<@V+38
ML=BM(-F^VXS8NMBGV879A]BG(-BHV8<@V8?9AMJOV*?9A2#9AMF%V*?;C-BT
M(-F&V*?9A=F'XH",V*_8I]F&(-F&V+38I]F&(-BOV*?8K]F'(-BTV8C8K]B?
M`-F&V878I]N,V+0@VJ_8LMN,V8;9A^*`C-F'V*<@V*C8L=BGVXP@V8;:K]F'
MV*_8I]BQVXP@V*?8M=F$`-BGV8;8JMBNV*?8J"#9@]F&V8;8K]F'(-F&V878
MI]N,V+0`V*+;C-BG(-F^VXS8M.*`C-F&V878I]N,V+39A]BG(-F!V8+8MR#8
MJ-BQV*?;C"#9OMN,V+K8I]F%V8?8I]N,(-BNV8C8I]F&V*_9AR#9AMBTV*_9
MAR#9AMBTV*?9AB#8K]BGV*_9AR#8M-F(V8;8K]B?`-BBVXS8IR#9OMN,V+0@
MV8;9A=BGVXS8M-F'V*<@V*_8L2#8L=BGV8?9AMF%V*?;C"#8HMF&VXP@V8;9
MA=BGVXS8M"#8K]BGV*_9AR#8M-F(V8;8K]B?`-BBVXS8IR#9A=N,V839AR#:
MK]BRVXS9AMJOV*?9AB#8N=F%V83;C-BGV*H@V*S8K]F(V83B@(P@V8;9A=BG
MVXS8M"#8K]BGV*_9AR#8M-F(V*_8GP#8HMN,V*<@VJ_8LMN,V8;:K]BGV88@
M)7,@V+/9A=BJ(-BQV*?8L]BJ(-F&V+38I]F&(-BOV*?8K]F'(-BTV8C8K]B?
M`-BBVXS8IR#8HMN,VJG9B-F&(-F(V*?:J=BTVXP@V8;8I]F%V8<@V*_8L2#:
MK]BRVXS9AMJOV*?9AB#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?`-F&
MV878I]N,V+0@V*K8M=BGV8C;C-BQ`-F&V878I]N,V+0@VJ_9@=BJXH",V8C:
MK]F(VXP@V*[8M=F(V+7;C-BGV*H@V+/9A-F(V80@V*S8K]F(V80`V8;9A=BG
MVXS8M"#:K]F!V*K:K]F(VXP@V*[8M=F(V+7;C-BGV*H@V*S8K]F(V80`V8;9
MA=BGVXS8M"#:K]F!V*K:K]F(VXP@V*[8M=F(V+7;C-BGV*H@V+/8M]BQ(-BL
MV*_9B-F$`-BBVXS8IR#8HMN,VJG9B-F&(-F!VXS9A-BJV+$@V*_8L2#:K]BR
MVXS9AMJOV*?9AB#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?`-F&V878
MI]N,V+0@VJ_9@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BJV+79B-N,V+$`
MV*+;C-BG(-BJV+G8K]BGV*\@VJG9A"#9AMBGV879A^*`C-F'V*<@V*_8L2#9
MOMF(V+39AR#9AMBTV*?9AB#8K]BGV*_9AR#8M-F(V*_8GP#9AMF%V*?;C-BT
M(-BGV+'8L]BGV80`V*K:K]BQVJ\`V+':K]BHV*?8L2#8LMF(V*_9A]F&VJ_8
MI]F%`-BQVJ_8J-BGV+$@V*_;C-BQV8?9AMJOV*?9A0#9AMF%V*?;C-BT(-BO
MV*?8K]F&`-BLV878N2#8M-BOV88`V*S9A=BY(-BTV*_9AB#;C-BG(-BGV8;8
MJMF"V*?9A"#8J-F$V8C:J=F'V*?;C"#9A=BLV*?9B-BQ`-BGV8;8K]BGV++9
MAP#8J]BHV*H@V8;8I]F%`-BGV878MMBGV*$`V*?9A-JOV8C8L=N,V*K9A2#8
MI]F%V+;8I]BA`-BGV878MMBG(-BTV*_9AP#8I]F&V*_8I]BRV8<`V+78L=F!
MV8;8N-BQ(-BGV+(@V8;:K]F'V*_8I]BQVXP`V*C8L=F!`-BJVJ_8L=JO`-BJ
MVJ_8L=JO`-BQVJ_8J-BGV+$@V++9B-BOV8?9AMJOV*?9A0#8L=JOV*C8I]BQ
M(-BOVXS8L=F'V8;:K]BGV84`V+G9A=F"(-BHV+'9@3H@`-F%V+G8I]BOV80@
MV*C8L=F!(-BOV+$@V*+8J#H@`-BTV+G8L=F'V*<@V8@@V*+9B-BGV++9A]BG
M`-F%V+'8JMBH(-BSV*?8LMN,(-BHV+$@V*?8L]BGV+,@V8C8L=F(V*\`V878
ML=BJV*@@V+/8I]BRVXP@V*C8L2#8I]BSV*?8LR#8JMBGV+';C-BN`-F%V+'8
MJMBH(-BSV*?8LMN,(-BHV+$@V*?8L]BGV+,@V*+8K]BQV+,@V8'8L=BSV*K9
MAMBOV8<`V878L=BJV*@@V+/8I]BRVXP@V*C8L2#8I]BSV*?8LR#8I]F&V*_8
MI]BRV8?9E"#9OMN,V+K8I]F%`-F%V+'8JMBH(-BSV*?8LMN,(-BHV+$@V*?8
ML]BGV+,@V+G9AMF(V*?9A@#9A=BQV*K8J"#8L]BGV++;C"#8L]F$V+/9A-F'
MXH",V*?;C-N,`-F%V+'8JMBH(-BSV*?8LMN,(-BHV+'8I]BSV*?8LR#8HMBO
MV+'8LR#:K]N,V+'9AMBOV8<`V*?9AMBJV*[8I]BH(-BLV8?8JB#9A=BQV*K8
MJ"#8L]BGV++;C`#8HMBOV+'8LR#8L]BQVH;8M-F%V8<`4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I`-F&VXS9A2#:J=BQV8<@V*S9AMF(V*C;C`#9@=BG
MV+79A-F'V90@V*C;C-F&(-BSV839B-F$V8?8I]N,(-F%V*S8I]F(V+$`V8'8
MI]BUV839A]F4(-BHVXS9AB#9A=BMV*K9B-BG(-F((-F$V*C9AR#8K]BQ(-BS
MV839B-F$`-F!V*?8M=F$V8?B@(S:K]BPV*?8L0#9@=BGV+79A-F'`-F!V*?8
MM=F$V8?B@(S:K]BPV*?8L=N,(-F((-BOV+'8LMJOV+#8I]BQVXP`V8?8L=BR
MV8;8I]F%V8<`V;[9B-BTV8?9E"#9A]BQV++9AMBGV879ASH`VJG8I]BQV*?:
MJ=BJV+$@V*[8I]BU(-F(V*?8L=BO(-BTV*\`V8;9B-N,V+/9A^*`C-F'V*?;
MC"#8KMBGV+4`V;[9B-BTV8?B@(S9A]BGVXP@V878K-BGV++;C"#8KMBGV+4@
MV8+8I]BHV80@V8C;C-BQV*?;C-BT(-F&VXS8L]BJV8;8KR``V*C8L=BQV+/;
MC"#8I]F%V838I]N,VXP`V*[8M]BGVXS8I]BH(-BGV879A-BGVXS;C`#8J-BQ
MV+'8L]N,(-BGV879A-BGVXS;C"#:J=BGV879A"#8M-BO`-BNV+?8I]F'V*?;
MC"#8I]F%V838I]N,VXP@V*_8L2#9A]BQ(-BUV8'8K=F'(-F'V8;:K]BGV84@
MV*C8L=BQV+/;C"#8I]F%V838I]N,VXP`V*K9@MBSVXS9A2#8L]F$V8C9A`#8
MJMF"V+/;C-F%(-BSV*K9B-F&`-BJV8+8L]N,V84@V+/8M]BQ`-F(V+'8LMBT
MVXP`V*?8L]BJV*?9AMBOV*?8L=BO`-BSV*K8I]BQV8<`V+38L=F(V+D`V+/8
MI]F$(-BTV+'9B-BY`-F(V+;8N=N,V*H@V*W9B-BRV8?B@(S9A]BG`-F&V8C8
MM-BJXH",V*?9@=BRV*?8L0#9AMBGV84@V8;9B-BTV*KB@(S8I]F!V++8I]BQ
M.@#9AMF(V+D@V8;9B-BTV*KB@(S8I]F!V++8I]BQ.@#9AMF(V+38JN*`C-BG
MV8'8LMBGV+$Z`-F(V+;8N=N,V*KB@(P`V8+8I]F$V*@@V+#8KMN,V+'9AR#8
ML]BGV++;C`#8HMBOV+'8LR#8KMN,V*?8J-BGV88`V8'9A]BQV+/8JB#8L=BT
MV*K9AP#8K=BPV8$@V;[;C-F(V+/8J@#8K=BPV8$@V*S8K]BGVJG9AMF&V*_9
MA]F4(-BNV+?9B-BW`-BTVXS9B-F'(%M#4U-=`-N,VJG8M-F&V*C9AP#8N=F&
MV8C8I]F&`-BYV8;9B-BGV88`V8';C-F$V*\@V+G9AMF(V*?9A@#8I]BQV*?8
MIMF'`-BYV+;9B-N,V*H@V*_8L2#9OMF(V+39ARC9A]BG*0#8LMN,V+'9AMF(
MVXS8LP#9A=F(V8'9D=F"VXS9D=BJ`"(E<R(@V*C8IR#9A=F(V8'9D=F"VXS9
MD=BJ(-BMV+#9@2#8M-BO`-F^VXS:J=BQV*C9AMBOVXP@V*C8IR#9A=F(V8'9
MD=F"VXS9D=BJ(-BHV*?8LMJOV+'8K]BGV8;8K]F'(-BTV*\N(-BHV+'8I]N,
M(-F%V+38I]F'V*_9AR#8JMBZVXS;C-BQV*?8JB#9A=BLV*_8K]BGV9(@V*+9
MAMBQV*<@V*C8I]BQ(-F&V878I]N,VXS8KP#9OMN,VJG8L=BHV8;8K]N,(-F^
MV+38JMN,V*C8I]F&(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=F!V+@@V+38
MKP#9OMBQV8C9AMBOV8<@V;[8M-BJVXS8J-BGV88@V;[;C-JIV+'8J-F&V*_;
MC"`E<R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W9@=BX(-BTV*\`)7,@V*C8
MIR#9A=F(V8'9D=F"VXS9D=BJ(-F&V8C8M-BJV8<@V+38KP#9OMN,V+39AMF'
MV*?8K]BGV*H`V*[9A-BGV+79AP#8M]F$V8C8N2#8HMF!V*K8I]BH`-BZV+'9
MB-BH(-BBV8'8JMBGV*@`V*+9@=BJV*?8J-N,`-BWV839B-BY`-BWV839B-BY
M+]BZV+'9B-BH`-BWV839B-BY.B``V+K8L=F(V*@`V+K8L=F(V*@Z(`#8J-BG
MV838I]F&V8C;C-BS`-F^V+38JMN,V*C8I]F&VXP`V8;8I]F%(-BNV*?9AMF(
MV*?8K]JOVXP`V*K8N=F(VXS8MB#8M-N,V8C9A]F4(-BGV8;8M-BGV*$`V*K8
MN=F(VXS8MB#8J-F'(-F%V*\@2%1-3`#8JMBYV8C;C-BV(-BHV8<@V878KR#8
MI]F&V+38I]N,(-F%V*K9AB#8L]BGV*_9AP#8KMBWV*?;C"#9AMBMV8C;C"#8
MK]BQ(-F%V8C8I]BQV*\@V*S8L]BJV*S9B`!4+5-T;W)M<P!4+5-T;W)M<P#9
MOMBQV8C9AMBOV8<@5%-6`-BLV*_9B-F$`-BNV+79B-BUVXS8I]BJ(-BLV*_9
MB-F$`-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$`-F'V*_9@3H`V8C8N-BGVXS9
M@0#9A=BJV88`V+39A=BGV+'9AR#8JMF$V8'9A@#8K]F%V*?;C"#8L]BGV+G8
MJB#8I]BNVXS8L3H@`-BOV+'8K-F'(-BMV+'8I]BQV*H`V*_8L=BLV8<@V*W8
ML=BGV+'8JCH@`-BGV83:K]F(VXP@V+/8L=F^V+'8L]BJVXP`V*+8LMF%V*?;
MC-BTVXP`V*_8L=BNV8C8I]BSV*H@V*C8M]F(V+$@V*+8LMF%V*?;C-BTVXP@
MV;[8L-N,V+'9@=BJV8<@V+38KP#9OMBPVXS8L=F!V*K9AR#8M-BOV8?9E"#8
MHMBRV878I]N,V+3;C`#9A=F(V*?8L=BO(-F^V+'9B-F&V*_9A]F4XH",(-BS
MV+'9B-N,V+,@V*_8L2!C;VYF+G!H<"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BS
MV*H`V878JMF&`-F!V8+8MR#9A=BJV88`V*K8L=BGV+(@V878JMF&`-BHV*?9
MA-BGVXP@V878JMF&`-F^V8;8K-BTV8;8J-F'`%1H86D@*%1)4RTV,C`I`-BG
MV+(@V+39A=BG(-BHV8<@V*[8I]BWV+$@V*?8L]BJV8'8I]BOV8<@V*?8LB#8
ML]BGV878I]F&V8<@V878JMBTVJG8L=N,V84`V*C8L]BW($944"#9@MBGV*C9
MA"#8K]BSV*K8L=BS(-F&VXS8L]BJ`-BSV*K9B-F&(-F!V+'8L]BJV8;8K]F'
MV90@V;[;C-BZV*?9A2#8J-BGVXS8KR#9OMN,V8C9AMBO(-BTV8C8KSH@`-F&
MVJ_9A]BOV*?8L=N,.CH@VJG9A-BGV+,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ
M(-BHV*?8L2#9AMBTV*\`V;[9AMBLV+'9A]F4(-JOV++;C-F&V8?B@(S9A]BG
M(-BHV+/8JMF'(-BTV*\N(-BNV+'9B-BL`-BMV+/8I]BH("(E<R(@V*W8L-F!
M(-BTV*_9AR#8I]BSV*H`V*W8L]BGV*@@(B5S(B#8K=F!V+@@V+38K]F'(-BG
MV+/8J@#8L]BQV;[8L=BSV*H@V*C8I]N,V*\@VXS:J2#9OMBTV*K;C-BHV*?9
MAB#9A=BLV8C8LMF'V*<@V+'8I]B,("#8K]BQ(-BUV8C8L=BJ(-BJV878I]N,
MV80@V+39A=BG(-BHV8<@V*?8L]BJV8'8I]BOV8<@V*?8LB#9A=BLV8C8LMF'
MV*?8C"#9OMN,VJG8L=BHV8;8K]N,(-JIV8;8KRX`V;[;C-F(V+/8JB#9OMN,
MV*_8IR#9AMBTV*\`V*K9AMF'V*<@V+/9A=BJ(-F^V*?;C-N,V88`(-BOV*?8
MK]F'V90@V*K9@MF(VXS9A2#9AMBGV878N=BJV*C8L2#8I]BSV*H@`-BUV8'8
MK=F'V90@V*K9B-F$VXS8KR#9OMN,V+K8I]F%(-F&V87;C.*`C-BJV8C8I]F&
MV*\@V*C8I]BR(-BTV8C8KRX@V+38I]N,V*\@V+39A=BG(-F%V+'9B-BQVJ_8
ML2#8KMF(V+$@V+'8IR#8J-BQV*?;C"#8J-BGV++9AMJIV+'8K]F&(-F^V8;8
MK-BQV8?B@(S9A]BGVXP@VJ_8M-F(V*_9AMN,(-BJV8;8N-N,V84@VJG8L=BO
MV8?B@(S;C-BOV)\`V+39A=BGV+'9AR!)1"#8JMF%V*?8LR#9A=BTV*[8M2#9
MAMBTV*_9AR#8I]BSV*K8C"#8I]N,V88@V+39A=BGV+'9AR#8K]BQ(-BOV*?8
MK]JOV*?9AB#;C-BGV8'8JB#9AMBTV*\`V*K9A=BGV+,@("5S(-BHV*<@V879
MB-F!V9'9@MN,V9'8JB#8J-F'(-JIV*K8I]BHVH;9AR#8HMBOV+'8LR#8M-F%
MV*<@V*?8MMBGV8'9AR#8M-BO`-F%V*W8JMF(VXS8I]BJ(-F^V+'9B-F&V*_9
MA]F4XH",($UA8VEN=&]S:"#8K]BQ(-BPVXS9A"#8HMF%V*_9AR#8I]BSV*HN
M`-F^V8C8M-F'*-F'V*<IVXP@V*S8I]BQVXP@(B5S(B#8J-F'("(E<R(@V*K8
MNMN,VXS8L2#9AMBGV84@VXS8I]F!V*K9AR#8I]BSV*H`V8'9A]BQV+/8JB#:
MJ=F&V8C9AMN,(-JIV*?8L=BHV+'8I]F&(-BHV*<@V*?8K-BGV++9A]F4(-BO
MV+/8JMBQV+/;C"#8J-F'(-BGVXS9AB#9OMF(V+39AR#9@MBGV*C9A"#8J-BG
MV++;C-BGV*C;C"#9AMN,V+/8J@#;C-JI(-BHV839B-JI(-BGV878MMBGVXP@
M4$=0(-BHV+'8I]N,(-BHV*?8LMBHVXS9AMN,(-N,VJD@V;[;C-BZV*?9A2#8
MI]F%V+;8I]BA(-BTV*_9AR#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`240@
MV8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8<@V*?8
ML]BJ(-F((-N,V*<@V*_8L2#8K]BGV*_:K]BGV88@V879B-BLV8C8KR#9AMN,
MV+/8J@#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#9A=BTV*[8M2#9AMBTV*_9
MAR#8I]BSV*H`V;[;C-BT(-F&V8C;C-BS(-BOV+$@V;[9B-BTV8?9E"`B)7,B
M(-BMV8'8N"#8M-BOV8<@V*?8L]BJ`-F%V+38KMBUV8?B@(SB@(S9A]BGVXP@
MV+'9A=BRV*C9AMBOVXP@V8;;C-BGV++9A=F&V*\@VXS:J2#8I]BQV*K8M=BG
MV80@V*?9A=F&(-F(V*@@V87;C.*`C-BHV*?8M-F&V*\`V+'9B-N,V*_8I]BO
M(-BHV8<@V*K9@MF(VXS9A2#8M-F%V*<@V*?8MMBGV8'9AR#8M-BOV8<@V*C9
MB-BO`-F^V+'9B-F&V*_9AR`E<R#8J-BGVXS8KR#8K]BGV+'8I]N,(-BJV8;8
MN-N,V84@)7,@V*C8I]BTV*\`V;[8L=F(V8;8K]F'("5S(-BHV*?;C-BO(-BM
MV*?9B-N,(-BJV8;8N-N,V878I]BJ("5S(-BHV*?8M-BO`-F^V+'9B-F&V*_9
MAR#8J-BQ(-BQV8C;C"#8KMF(V*_8M"#9AMF%VXSB@(S8JMF(V*?9AMBO(-BQ
MV8C9AMF(V+38JB#8M-F(V*\`V;[8L=F(V8;8K]F'(-BMV*?9B-N,(-BOV*?8
MK]F'XH",V*?B@(S;C-N,(-F&VXS8L]BJ(`#9OMF(V+39A]F4("(E<R(@V*?8
MLB#9@MBHV80@V879B-BLV8C8KR#8I]BSV*H`V8;8I]F%(-F^V8C8M-F'V90@
M(B5S(B#8M-BGV879A"#9AMF(VXS8L]F'XH",V8?8I]N,(-BZVXS8L2#9A=BL
MV*?8LB#9A=N,XH",V*C8I]BTV*\@VJG9AR#8I]N,V88@V878L]BFV839AR#9
MA=N,XH",V*K9B-BGV8;8KR#9A=BTVJG9A-BGV*K;C"#8L=BG(-BGVXS8K-BG
MV*\@VJG9AMBO+B#9A-BWV8'8I]F+(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9
MA=BGV8;9A]F4(-BNV8C8KR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\`V;[9B-BT
MV8?9E"`B)7,B(-BGVXS8K-BGV*\@V+38K]F'(-BGV+/8JB#8I]F%V*<@V+39
MA=BG(-BOV+$@V*+9AB#8N=BVV8@@V8;9A=N,XH",V*C8I]BTVXS8KR``V;[9
MB-BTV8?9E"`B)7,B(-BMV+#9@2#8M-BOV8<@V*?8L]BJ(-BGV878IR#8M-F%
MV*<@V+G8MMF(VXS8JB#8KMF(V*\@V+'8IR#8K]BQ(-BBV88@V838NMF((-F&
MVJG8L=BOV8?B@(S;C-BO(`#9OMF(V+39A]F4("(E<R(@V*?;C-BLV*?8KR#9
MAMBTV*_9AR#8J-F(V*\N(-BGVXS9AB#:AMN,V++;C"#8I]BSV*H@VJG9AR#:
MJ=BGV+'8L]BGV+(@VJ_9@=BJV8<@V*?8L]BJ`-F^V8C8M-F'V90@)R5S)R#8
MK=BPV8$@V8;8M-BOV8<@V*C9B-BO+B#8I]N,V88@VH;;C-BRVXP@V*?8L]BJ
M(-JIV8<@VJG8I]BQV+/8I]BR(-JOV8'8JMF'(-BGV+/8J@#9OMF(V+39A]F4
M("(E<R(@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BGVXS8K-BGV*\@V+38KP#9
MOMF(V+39A]F4("(E<R(@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BMV+#9@2#8
MM-BO`-F^V8C8M-F'V90@(B5S(B#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C9
MAR`B)7,B(-BJV+K;C-N,V+$@V8;8I]F%(-N,V*?9@=BJV8<@V*?8L]BJ`-F^
MV+'9B-F&V*_9A^*`C.*`C-F'V*?;C"#8LMN,V+$@V*C9AR#8I]N,V88@V8+8
ML]F%V*H@V;[;C-F(V+/8JB#8M-BOV8?B@(P@V*?8L]BJ.@#9A=BO(-BJV878
MI]F%(-BUV8'8K=F'(-BHV*<@244@V878M-JIV80@V*_8I]BQV*\@V8@@V*?;
MC-F&(-BGV+(@V878M-JIV838I]BJ(-F%V+'9B-BQVJ_8L2#9A=N,XH",V*C8
MI]BTV*\N(-BGVJ_8L2#9A]F&V8C8LB#9A=N,XH",V*[9B-BGV8?;C-BO(-BM
MV*?9A-BJ(-F(VXS8L=BGVXS8M-JOV+$@V*K9A=BGV84@V+79@=BMV8<@V+'8
MIR#8I]F%V*K8K=BGV88@VJG9AMN,V*_8C"#9A-BWV8'8I]F+(-JIV83;C-BO
M(-BJV*/;C-N,V*\@V+'8IR#9@=BTV*?8L2#8K]F'VXS8KR``V8?9B-N,V9'8
MJB`B)7,B(-BMV+#9@2#8M-BOV8<@V*?8L]BJ`-F^V8;8K-BQV8?9E"#8K=F!
MV+@@V*K8M=F(VXS8L2#9AMF%VXSB@(S8JMF(V*?9AMBO(-BHV*?8LB#8M-F(
MV*\N(-BTV*?;C-BO(-BTV878IR#9A=BQV8C8L=JOV+$@V*[9B-BQ(-BQV*<@
MV*C8L=BGVXP@V*C8I]BRV8;:J=BQV*_9AB#9OMF&V*S8L=F'XH",V8?8I]N,
M(-JOV+39B-BOV8;;C"#8JMF&V+C;C-F%(-JIV+'8K]F'XH",VXS8K]B?`-BJ
MV+79B-N,V+'9A]BG(-F&V878I]N,V+0@V*_8I]BOV8<@V87;C.*`C-BTV8C9
MAMBO(-J&V8C9AB#9@=BQV+/8JMF&V*_9AR#8K]BQ(-JIV*K8I]BHVH;9A]F4
M(-BBV*_8LR#8M-F%V*<@V8C8K-F(V*\@V*_8I]BQV*\`V*K9AMF'V*<@V+/9
MA=BJ(-J&V;X`VJG8I]BQV+/8I]BR(-F&V*?9A=F'V90@V*?9A-JIV*K8L=F(
MV8;;C-JIVXP@V;[;C-BZV*?9A=F'V*?;C"#8KMBWV*?;C"#8LMN,V+$@V+'8
MIR#8JMF(V83;C-BO(-JIV+'8KSH`VJG8I]BQV+/8I]BR(-F&V*?9A=F'V90@
MV*?9A-JIV*K8L=F(V8;;C-JIVXP@V;[;C-BZV*?9A=F'V*?;C"#8I]BWV838
MI]BYV*?8JMN,(-BRVXS8L2#8L=BG(-BJV8C9A-N,V*\@VJG8L=BO.@#:J=BG
MV+'8L]BGV+(@V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#9OMN,
MV+K8I]F%V8?8I]N,(-BRVXS8L2#8L=BG(-BJV8C9A-N,V*\@VJG8L=BO.@#9
MAMBGV879A^*`C-BOV*?9AB`E<R#9@MBHV838I]F+(-BNV*?9A-N,(-BHV8C8
MK]F'(-BGV+/8J@#9OMN,V+K8I]F%("(E<R(@V*?8LB`B)7,B("@E9"#8J-BG
MVXS8JBD@V*K8K-BGV8C8LB#8I]BR(-BMV*_8I]JIV*O8L2#8I]F&V*_8I]BR
MV8<@V8C8I]JIV+3;C`#9OMN,V+K8I]F%(-BGVXS8K-BGV*\@V+38K]F'(-BH
MV+/8JMF'(-BTV*_9AR#8I]BSV*HZ(-BNV+'9B-BL`-F^VXS8NMBGV84@V*W8
ML-F!(-BTV*_9AR#8I]BSV*H`V;[;C-BZV*?9A2#8J-BGV++8J-N,V8;;C"#8
MM-BOV8<@V*?8L]BJ`-F^VXS8NMBGV84@V*C8I]BRV*C;C-F&VXP@V+38K]F'
M(-BGV+/8JBX@V8'8L=BSV*K9AMBOV8<Z("5S`-F^VXS8NMBGV84@V8'8L=BS
MV*K8I]BOV8<@V+38K]F'(-BQV8C;C"`E<R#8J-F'("5S(-BHV*<@V879B-BV
MV8C8N2`B)7,B(-F&V878I]N,V+0@V*_8I]BOV8<@V+38K]F'(-BGV+/8JBX*
MV*K8MMF%VXS9AMN,(-BHV+'8I]N,(-BNV8C8I]F&V*_9AR#8M-BOV88@V8@@
MVXS8IR#8K]BQVJD@V*+9AB#9B-BLV8C8KR#9AMBOV*?8L=BO`-F&V*?9A=N,
M(-JIV8<@V*C9AR#9A]F&VJ_8I]F%(-F^VXS9B-F&V*_8K]F'VXP@V*C9AR#8
MM=F!V*W9AR#8I]N,V*S8I]BO(-F&V*?9A=F'(-BGV+/8JMF!V*?8K]F'(-F%
MVXSB@(S8M-F(V*\`V*K8N=BOV*?8KR#9@=N,V838K^*`C-F'V*<@V*C8I]N,
MV*\@VXS:J2#8N=BOV*\@V*C8I]BTV*\`V;[9AMBLV+'9A]F4(-BYV*C8I]BQ
MV*H@VJ_8L-BQ(-F"V*?8K]BQ(-BHV8<@V*C8I]BR(-BTV*_9AB#9AMN,V+/8
MJBX@V+38I]N,V*\@V+39A=BG(-F%V+'9B-BQVJ_8L2#8KMF(V*\@V+'8IR#8
MI]N,V8;:K]F(V8;9AR#8JMF&V+C;C-F%(-JIV+'8K]F'XH",V*?B@(S;C-BO
MV)\`V*?9B-F$V8C;C-BJ("(E<R(@V8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!
MV+@@VJ_8L=BOV*\@V++;C-BQV*<@V879@MBOV*?8L2#8K]BGV*_9AR#8HMF&
M(-BGV+(@V*W8KR#9A=BLV*?8LB#8J-N,V+38JMBQ(-BGV+/8J@#8J-BQV8;8
MI]F%V8?B@(S8I^*`C-N,VXP@VJG9AR#8J-BQV*?;C"#9A=BTV*?9A]BOV8<@
MV*?;C-F&(-F&V8C8N2#8K]BGV*_9AR`H)7,I(-F"V*C9A-BGV8L@V879B-BQ
MV*\@V*?8L]BJV8'8I]BOV8<@V8+8L=BGV+$@V87;C.*`C-JOV+'9@=BJV(P@
MV*_8L2#8L]BGV878I]F&V8<@V879B-BLV8C8KR#9AMN,V+/8J@#9A=BJV88@
MV*[8I]F%(-JIV83;C-BO(-BYV879B-F%VXP@4$=0(-F%VXSB@(S8JMF(V*?9
MAMBO(-F%V+38I]F'V*_9AR#8M-F(V*\@)7,`V;[8L=F(V8;8K]F'V93B@(P@
MV*_8L=BNV8C8I]BSV*K;C"#8K]BQ(-F^VXS9B-BSV*H@35,M5$Y%1B#9B-BL
MV8C8KR#9AMBOV*?8L=BO`-F^V+'9B-F&V*_9A]F4XH",(-BOV+$@V*[9B-BG
MV+/8JMN,(-BOV+$@V;[;C-F(V+/8JB!::7`@V8C8K-F(V*\@V8;8K]BGV+'8
MKP#8JMF&V8?8IR#8L]F%V*H@V+'8I]BSV*H@V8@@VH;9O@#8JMF&V8?8IR#8
ML]F%V*H@V+'8I]BSV*H`V8'8L=BSV*K9AMBOV8<@V*?;C-F&(-F^VXS8NMBG
MV84@V*K9@MBGV+;8IR#8K]BGV+'8KR#:J=F'(-N,VJD@V*K8H]BFVXS8K]N,
MV8<@V*C8L=BGVXP@V*[9B-BGV8;8K]F&(-F^VXS8NMBGV84@V*_8L=N,V*?9
M@=BJ(-JIV8;8KR#9A-BWV8'8I]F+(-F'V8;:K]BGV87;C"#:J=F'(-BGVXS9
MAB#9OMN,V+K8I]F%(-BQV*<@V*[9B-BGV8;8K]N,V*\@V*C8L2#8L=F(VXP@
M)7,@VJG9A-N,VJD@VJG9AMN,V*\@V*K8IR#8I]N,V88@V*K8H]BFVXS8K]N,
MV8<@V*?8L=BSV*?9A"#8M-F(V*\`V*S8K]BG(-JIV8;9AMBOV8<@V*C8I]N,
MV*\@VXS:J2#9AMF(VXS8L]F'(-BHV*?8M-BO`-JIV*?8L=BSV*?8LB`B)7,B
M(-BMV+#9@2#8M-BOV8<@V*?8L]BJ`-JIV*?8L=BSV*?8LB`B)7,B(-BMV8'8
MN"#8M-BOV8<@V*?8L]BJ`"#:J=BGV+'8L]BGV+(@V8;9A=N,XH",V*K9B-BG
MV8;8KR#8JMBUV8C;C-BQ(-JIV8C:AMJIVXP@V*?8LB#8I]N,V88@V*K8M=F(
MVXS8L2#8L=BG(-BGVXS8K-BGV*\@VJG9AMBO`-BGV878MMBGV*$@V+'8IR#9
MAMF%VXSB@(S8JMF(V*?9AB#8K-BGVXS:K]BRVXS9AB#:J=BQV*\`V*?9A=BV
MV*?8H2#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*S8I]N,VJ_8LMN,V88@V+38
MKP#8K]BQV*[9B-BGV+/8JB#8I]F!V*K8JMBGV*T@V*W8L]BGV*@@V*C8L=BG
MVXP@)7,@V*W8L-F!(-BTV*_9AR#8I]BSV*H`V;[8L=F(V8;8K]F'V93B@(P@
MV878M-BNV+4@V+38K]F'(-F(V*S9B-BO(-F&V*_8I]BQV*\`V+'8K]N,V8$@
MV878M-BNV+4@V+38K]F'(-F(V*S9B-BO(-F&V*_8I]BQV*\`V8;9B-BTV*KB
M@(S8I]F!V++8I]BQ("(E<R(@V*?8MMBGV8'9AR#8M-BOV8<@V*?8L]BJ`-F&
MV8C8M-BJXH",V*?9@=BRV*?8L2`B)7,B(-BMV+#9@2#8M-BOV8<@V*?8L]BJ
M`-F&V8C8M-BJXH",V*?9@=BRV*?8L2`B)7,B(-BHV+'9B-BRV+'8L]BGV8;;
MC"#8M-BOV8<@V*?8L]BJ`-F(V+C;C-F!V8?9E"#9A=F(V+'8KR#9AMBXV+$@
MV*C9AR#9@=F'V+'8L]BJ(-F(V+C8I]N,V8$@V+39A=BG(-BGV+;8I]F!V8<@
MV+38K]F'(-BGV+/8J@#9OMBQV8C9AMBOV8<@V879B-F"V*K;C"`@(B5S(MF%
MV8C8K-F(V*\@V8;;C-BSV*H`V878JMF&(-F^VXS8NMBGV84`V878JMF&(-F^
MVXS8NMBGV84@V8+8I]BHV80@V878M-BGV8?8K]F'(-BGV+/8JB`E<P#9A=BJ
MV88@V;[;C-BZV*?9A2#8J-BQVJ_8L=F&V*_8I]F&V*_9AR#8M-BOV8<`(-F%
MV*K9AB#9OMN,V+K8I]F%(-BHV+':K]BQV8;8K]BGV8;8K]F'(-BTV*_9AR#9
MA=N,XH",V*K9B-BGV8;8KR#9A=BTV*?9A]BOV8<@V+39B-BO("5S`-F%V*K9
MAB#9OMN,V+K8I]F%(-F!V+'8L]BJV*?8K]F'(-BTV*_9AP#9A=BJV88@V;[;
MC-BZV*?9A2#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V87;C.*`C-BJV8C8I]F&
MV*\@V878M-BGV8?8K]F'(-BTV8C8KR`E<P#8JMF&V8?8IR#8L]F%V*H@V*C8
MI]F$V*<@V8@@V;[8I]N,VXS9A@#8JMF&V8?8IR#8L]F%V*H@V*C8I]F$V*<`
MV*_8I]BOV8?9E"#8I]BQV+/8I]F$(-BTV*_9AR#8I]BR(-JOV*?9A2#9@MBH
MV83;C"#8I]BR(-BOV+/8JB#8L=F!V*K9AR#8I]BSV*H`V;[8L=F(V8;8K]F'
M(-BGV+'8L]BGV80@V+38K]F'(-F&V87;C.*`C-BJV8C8I]F&V*\@V*W9@=BX
M(-BTV8C8KP#8I]BWV838I]BYV*?8JB#8HMBRV*?8KR_9A=BTV+K9B-F$(-JI
MV*?8L=BHV+'8I]F&(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8L-BNVXS8L=F'
M(-BTV*\`V*C9A-F(VJD@=V5A=&AE<BYC;VT@V8+8I]BHV80@V*_8L]BJV+'8
MLR#9AMN,V+/8J@#8J-BNV+0@V*S8I]N,VJ_8LMN,V8;;C"#:J=F'(-BHV*K9
MB-BGV8;8KR#8K]BQV*[8MR#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8KR#9
MA=F(V*S9B-BO(-F&VXS8L]BJ`-F^VXS8NMBGV87;C"#8K]BQ(-BGVXS9AB#9
MAMBGV879A^*`C-BOV*?9AB#9AMN,V+/8J@#:K]BRVXS9AMF'XH",V*?B@(SB
M@(S;C-N,(-BOV+$@V*_8L]BJV+'8LR#9AMN,V+/8J@#8J-BNV+3;C"#:J=F'
M(-BHV*K9B-BGV8;8KR#8J-BQV*[8MR#9AMF%V*?;C-BT(-BOV*?8K]F'(-BT
MV8C8KR#9A=F(V*S9B-BO(-F&VXS8L]BJ`-F&V8C;C-BSV8?B@(S9A]BGVXP@
MV++;C-BGV*_;C"#8K]BQ(-BGVXS9AB#9@=N,V838KR#9@MBQV*?8L2#8K]BG
MV+'8KRX@V+39A=BG("5S(-F&V8C;C-BSV8<@V8C8I]BQV*\@VJG8L=BOV8?B
M@(S8I^*`C-N,V*\@V*_8L2#8K=BGV83;C"#:J=F'(-BTV878IR#8J-BGVXS8
MKR#:J=F%V*K8L2#8I]BR("5S(-F&V8C;C-BSV8<@V8C8I]BQV*\@VJG9AMN,
MV*\`V*[8M]BGVXS;C"#8K]BQ(-F^V*?:J2#:J=BQV*_9AB`E<R#8L=BN(-BO
MV*?8K]F'(-BGV+/8JBX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JI
MV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*HZ(`#8KMBWV*?;C-N,(-BOV+$@
MV;[8I]JI(-JIV+'8K]F&(-F&V*?9A=F'XH",V*_8I]F&(-BQV*X@V*_8I]BO
MV8<@V*?8L]BJ+B#:J=BGV+'8L]BGV+(@VJ_9@=BJ.B`E<P#8KMBWV*?;C-N,
M(-BOV+$@V;[8I]JI(-JIV+'8K]F&(-F&V*?9A=F'XH",V*_8I]F&(-BQV*X@
MV*_8I]BOV8<@V*?8L]BJ+B#8I]N,V88@VH;;C-BRVXP@V*?8L]BJ(-JIV8<@
MVJG8I]BQV+/8I]BR(-JOV8'8JMF'(-BGV+/8JCH@)7,`V878M-JIV83;C"#8
MK]BQ(-BGV+'8L]BGV80@V;[8L=F(V8;8K]F'(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJ.B`E<R#8I]BQV+/8I]F$(-F&V+38KP#9A=BTVJG9A-N,(-BOV+$@V*?8
ML=BSV*?9A"#9OMBQV8C9AMBOV8<@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ(-BG
MV8;8K]BGV++9AR`E<R#8J-N,V+38JMBQ(-BGV+(@V*W8KR#9A=BLV*?8LB#8
MJ-F(V*_9AR#8I]BSV*H@*"`E9"#8J-BGVXS8JBDN`-F%V+3:J=F$VXP@V*_8
ML2#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#9B-BLV8C8KR#8K]BGV+38JMF'
M(-BGV+/8JCH@("5S(-BHV8<@V+79B-BQV*H@V*K:J=F'XH",V*?B@(S;C-N,
M(-BGV+'8L]BGV80@V+38K]F'(-BGV+/8JB``V*[8M]BGVXS;C"#8K]BQ(-BJ
MV8?;C-F'V90@V+'9B-F&V8C8M-BJ(-F^VXS8NMBGV84@V*?8LB`B)7,B(-BH
MV8<@(B5S(B#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V*?;C-F&(-J&VXS8LMN,
M(-BGV+/8JB#:J=F'(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*H`V*[8
MM]BGVXS;C"#8K]BQ(-BMV+#9@2#9OMN,V+K8I]F%V8?8IR#8I]BR(-F^V8C8
MM-F'V90@(B5S(B#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V*?;C-F&(-J&VXS8
MLMN,(-BGV+/8JB#:J=F'(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*H`
MV*[8M]BGVXS;C"#8K]BQ(-BMV+#9@2#9OMN,V+K8I]F%V8?8IR#8K]BQ(-F^
MV8C8M-F'V90@(B5S(B#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V*?;C-F&(-J&
MVXS8LMN,(-BGV+/8JB#:J=F'(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BS
MV*H`V*[8M]BGVXS;C"#8K]BQ(-BMV+#9@2#9OMN,V+K8I]F%V8?8IR#8L=BN
M(-BOV*?8K]F'(-BGV+/8JBX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'
M(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*HZ("5S`-BNV+?8I]N,VXP@
MV*_8L2#8K=BPV8$@V+'9B-N,V*_8I]BO(-BQV*X@V*_8I]BOV8<@V*?8L]BJ
M.B`E<P#8KMBWV*?;C-N,(-BOV+$@V8;9A=BGVXS8M"#8I]N,V88@V*C8KMBT
M(-F^VXS8NMBGV84@V+'8KB#8K]BGV*_9AR#8I]BSV*H`V*[8M]BGVXS;C"#8
MK]BQ(-F^V+':AMF%XH",VJ_8L-BGV+';C"#9OMN,V+K8I]F%V8?8IR#8K]BQ
M(-F^V8C8M-F'V90@(B5S(B#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V*?;C-F&
M(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8
MI]BSV*H`V*[8M]BGVXS;C"#8K]BQ(-BOV+'9B-F&XH",V*C8L=BO(-JIV+'8
MK]F&("5S(-BQV*X@V*_8I]BOV8<@V*?8L]BJ`-BNV+?8I]N,VXP@V*_8L2#8
MK]BQV8C9AN*`C-BHV+'8KR#:J=BQV*_9AB#8K]BGV*_9AR#8JMF%V*?8LR#8
ML=BN(-BOV*?8K]F'(-BGV+/8J@#8KMBWV*?;C-N,(-BOV+$@V*_8L=F(V8;B
M@(S8J-BQV*\@VJG8L=BOV88@V+'9B-N,V*_8I]BO(-BQV*X@V*_8I]BOV8<@
MV*?8L]BJ.B`E<P#8KMBWV*?;C-N,(-BOV+$@V*_8L=F(V8;B@(S8J-BQV*\@
MVJG8L=BOV88@V*_8I]BOV8?9E"#8JMF"V8C;C-F%(-BQV*X@V*_8I]BOV8<@
MV*?8L]BJ`-BNV+?8I]N,VXP@V*_8L2#8K]BQV8C9AN*`C-BHV+'8KR#:J=BQ
MV*_9AB#:J=BGV+$@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ("5S`-BNV+?8I]N,
MVXP@V*_8L2#8K]BQV8C9AN*`C-BHV+'8KR#:J=BQV*_9AB#8I]BWV838I]BY
MV*?8JB#8HMBRV*?8KR_9A=BTV+K9B-F$(-JIV*?8L=BHV+'8I]F&(-BQV*X@
MV*_8I]BOV8<@V*?8L]BJ.B`E<P#8KMBWV*?;C-N,(-BOV+$@V;[;C-JIV+'8
MJ-F&V*_;C"#9@=BQV84@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-BTV*?;C-BO
M(-F!VXS9A-BO(-F%V8C8L=BO(-F&VXS8I]BRVXP@V+'8IR#8K-BG(-BGV8;8
MK]BGV*[8JMF'XH",V*?B@(S;C-BO`-BNV+?8I]N,VXP@V*_8L2#8I]F&V*K9
M@MBGV80@V;[;C-BZV*?9A=F'V*<@V*?8LB`B)7,B(-BHV8<@(B5S(B#8L=BN
M(-BOV*?8K]F'(-BGV+/8JBX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'
M(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*H`V*[8M]BGVXS;C"#8K]BQ
M(-BGV*S8L=BG(-JIV+'8K]F&(-BYV879A-N,V*?8JB#9A=BTV*[8M2#8M-BO
MV8?9E"#:J=BJV*?8J-J&V8<@V*+8K]BQV+,@V+'8KB#8K]BGV*_9AR#8I]BS
MV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KP#8
MKMBWV*?;C-N,(-BOV+$@V*W9@=BX(-F^VXS8NMBGV84@V*C8N=F&V8C8I]F&
M(-N,VJD@V;[;C-BT(-F&V8C;C-BS(-BQV8C;C"#8K]BGV*_9AR#8I]BSV*H`
MV*[8M]BGVXS;C"#8K]BQ(-F!V+'8L]BJV*?8K]F&(-F^VXS8NMBGV84@V+39
MA=BG(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<P#8KMBWV*?;C-N,(-BOV+$@
MV*C8L=F(V++8L=BSV*?9AMN,(-BLV++8IMN,V*?8JB#8JMF%V*?8LR#8L=BN
M(-BOV*?8K]F'(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8
MN=N,(-JIV8;;C-BO`-BNV+?8I]N,VXP@V*_8L2#8J-BQV8C8LMBQV+/8I]F&
MVXP@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8KB#8K]BGV*_9AR#8I]BS
MV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KP#8
MKMBWV*?;C-N,(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-BQV8C;C-BOV*?8
MKR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,`V878JMF&VXP@V*_8L2#8I]N,
MV88@V*C8KMBT(-F^VXS8NMBGV84@V8;;C-BSV*H`V*?;C-F&(-F^VXS8NMBG
MV84@2%1-3"#8M-BGV879A"#8JMBUV*?9B-N,V+$@V*?8L]BJ`-BGVXS9AB#9
MOMN,V+K8I]F%($A434P@V+38I]F%V80@V*K8M=BGV8C;C-BQ(-BGV+/8JBX@
MV*C9A-F(VJD@V*K8M=BGV8C;C-BQ(-BTV*C;C-F'(-BHV8<@V*?;C-F&(-BX
MV*?9A]BQ(-F%VXSB@(S8M-F(V*\Z`"#:J=BGV+'8L]BGV+(@24U!4-F^V8C8
MM-F'XH",V8?8I]N,(-F%V+38JMBQVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,
M(-F&V87;C.*`C-JIV8;8KP#8I]N,V88@VJG9A-N,V*\@V+G9A=F(V87;C"!0
M1U`@V*C9AR#9OMN,V+K8I]F%(-F^VXS9B-BSV*H@(-BTV*_9AR#8J-F(V*\`
MV*?;C-F&(-BYV879A"#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-BTV8C8
MKP#8I]N,V88@V+G9A=F$(-F'V8;9B-BR(-F^VXS8I]BOV8?B@(S8L]BGV++;
MC"#9AMBTV*_9AR#8I]BSV*H`(-BHV8<@V8;8N-BQ(-F&V87;C.*`C-BQV+/8
MKR#:J=F'(-BBV+'8M-N,V8@@<F%R(-F%V+G8JMBHV+';C"#8J-BGV+38KP`@
MV*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V;[8L=F(V8;8K]F'
M('II<"#9A=BYV*K8J-BQVXP@V*C8I]BTV*\`V*C9AR#9AMBXV+$@V8;9A=N,
MXH",V+'8L]BO(-JIV8<@V+39A=BGV+'9AR#:J=BGV+'8JB#9A=BYV*K8J-BQ
MVXP@V*C8I]BTV*\`V*?;C-F&(-F!VXS9A-BO(-F%V8C8L=BO(-F&VXS8I]BR
M(-BGV+/8J@#8I]N,V88@V8';C-F$V*\@V879A=JIV88@V*?8L]BJ(-BTV*?9
MA=F$(-BGV+G8K]BGV*\@V+78K=N,V*T@V*C8I]BTV*\`V*?;C-F&(-F!VXS9
MA-BO(-F%V87:J=F&(-BGV+/8JB#8M-BGV879A"#8I]BYV*_8I]BO(-F((-F(
MVXS8L=JOV8C9A"#8J-BGV+38KP#8I]N,V88@V8';C-F$V*\@V879A=JIV88@
MV*?8L]BJ(-BTV*?9A=F$(-F%V8+8I]BOVXS8L2#9A]BTV*H@V8?8M-BJVXP@
MV*C8I]BTV*\`V*?;C-F&(-F!VXS9A-BO(-BHV*?;C-BO(-BMV*?9B-N,(-JI
MV*?9A=BG(-F((-N,V*<@V8'9A]BQV+/8JMN,(-BGV+(@V*?8N=BOV*?8KR#8
MM=BMVXS8K2#8K-BOV*<@V+38K]F'(-BHV*<@V8;9B-N,V+/9AR#8KMBGV83;
MC"#8J-BGV+38KP#8I]N,V88@V8';C-F$V*\@V*C8I]N,V*\@VXS:J2#8N=BO
MV*\@V878N=BJV*C8L2#8J-BGV+38KP#8I]N,V88@)7,@V87;C.*`C-BHV*?8
MM-BO`-BGVXS9AB#8N=F%V80@VJG9A=N,(-BRV878I]F&(-F%VXSB@(S8J-BQ
MV*\N(-BBVXS8IR#9A=BWV878IMF&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9
MA]N,V*\@V*?8K]BGV879AR#8K]F'VXS8K]B?`-BGVXS9AB#9OMN,V+K8I]F%
M(-BTV*?9A=F$(-N,VJD@V;[8L=F(V8;8K]F'V93B@(P@36%C:6YT;W-H(-BG
MV+/8J@#8I]N,V88@V;[;C-BZV*?9A2#8M-BGV879A"#;C-JI(-F^VXS9B-BS
MV*H@V*?8L]BJ(-JIV8<@V*?8LB#8M]BQVXS9@B!3+TU)344@V*C8M]F(V+$@
MV*_;C-BLVXS8JMBGV83;C"#8I]F%V+;8I]BA(-BTV*_9AR#8I]BSV*H`V*?;
MC-F&(-F^VXS8NMBGV84@V*W8I]F(VXP@VXS:J2#9OMN,V8C8L]BJ(-BGV+/8
MJB#:J=F'(-BGV+(@V+?8L=N,V8(@4R]-24U%(-BQV878LMBHV8;8K]N,(-BT
MV*_9AR#8I]BSV*H`V*?;C-F&(-F^VXS8NMBGV84@V*W8I]F(VXP@V*?8M]F$
MV*?8N=BGV*H@V8C8MMBYVXS8JB#8JMBMV8C;C-F$(-F%VXSB@(S8J-BGV+38
MKR#8I]F%V*<@V8+8I]F$V*@@V;[;C-BZV*?9A2#9AMBGV+39AMBGV*[8JMF'
M(-BGV+/8J@#8I]N,V88@V;[;C-BZV*?9A2#8J-F&V+C8L2#9AMF%VXSB@(S8
ML=BSV*\@VJG9AR#;C-JI(-F^VXS8NMBGV84@V878N=BJV*C8L2#8L=F%V++8
MJ-F&V*_;C"#8M-BOV8?9E"!01U`@V*C8I]BTV*\N(-BNV+?8ISH@`-BHV8;8
MN-BQ(-F&V87;C.*`C-BQV+/8KR#:J=F'(-BGVXS9AB#9OMN,V+K8I]F%(-BO
MV+$@V8+8I]F$V*@@V+78K=N,V*T@4$=0(-BHV*?8M-BO("@@V*C8I]BJV8C8
MK-F'(-BHV8=21D,@,C`Q-2D@`-BHV8;8N-BQ(-F&V87;C.*`C-BQV+/8KR#:
MJ=F'(-BGVXS9AB#9OMN,V+K8I]F%(-BOV+$@V8+8I]F$V*@@V+78K=N,V*T@
M4R]-24U%(-BHV*?8M-BO`-BGVXS9AB#9OMN,V+K8I]F%(-BGV+(@V+?8L=N,
MV8(@4$=0(-BHV+?9B-BQ(-BOVXS8K-N,V*K8I]F$VXP@V*?9A=BVV*?8H2#8
MM-BOV8<@V*?8L]BJ`-BGVXS9AB#9OMN,V+K8I]F%(-BGV+(@V+?8L=N,V8(@
M4R]-24U%(-BHV+?9B-BQ(-BOVXS8K-N,V*K8I]F$VXP@V*?9A=BVV*?8H2#8
MM-BOV8<@V*?8L]BJ`-BGVXS9AB#9OMN,V+K8I]F%(-BHV*<@4R]-24U%(-BQ
MV878LMBHV8;8K]N,(-BTV*_9AR#8I]BSV*H`V*?;C-F&(-F^VXS8NMBGV84@
MV*C8IR!01U`@V+'9A=BRV*C9AMBOVXP@V+38K]F'(-BGV+/8J@#8I]N,V88@
MV;[;C-BZV*?9A2#8J-F'`-BGVXS9AB#9OMN,V+K8I]F%(-BHV*<@V878K-F%
MV8C8N=F'(-JIV*?8L=BGVJG8JMBQ("5S(-F&V8C8M-BJV8<@V+38K]F'(-BG
MV+/8JB#:J=F'(-BHV*<@V878K-F%V8C8N=F'(-JIV*?8L=BGVJG8JMBQ(-BT
MV878IR#9A=BJV8'8I]F(V*H@V*?8L]BJ`-BGVXS9AB#8N=BOV*\@V*W8K]BG
MV8+9A"#8J-BGVXS8KR#;C-JI(-BHV*?8M-BO`-BGVXS9AB#:J=BGV+'8L]BG
MV+(@V;[8L=F(V8;8K]F'XH",V8?8I]N,('II<"#9B"!G>FEP(-BQV*<@V*C8
MI]BR(-F&V87;C.*`C-JIV8;8KP#8I]N,V88@VJG8I]BQV+/8I]BR(-F^V8C8
MM-F'XH",V8?8I]N,(-F%V+38JMBQVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,
M(-F&V87;C.*`C-JIV8;8KP#8I]N,V88@V+/8I]F%V*?9AMF'(-BOV+$@V*W8
MI]F$(-BMV*?8MMBQ(-BZVXS8L2#9@=BYV*?9A"#8I]BSV*H`V*?;C-F&(-F%
MV8+8K]BGV+$@V*C8I]N,V*\@V+G8K]BO(-BHV*?8M-BO`-BGVXS9AB#9OMF&
MV*S8L=F'(-BHV*?8J-N,V*\@V*?8LB#8M]BQVXS9@B#;C-JI(-F^V8;8K-BQ
MV8?9E"#8I]N,V*S8I]BO(-F^VXS8NMBGV84@V+78K]BG(-BTV8C8KP#8I]N,
MV88@V;[9AMBLV+'9AR#8J-BGVXS8KR#8I]BR(-F^V8;8K-BQV8?9E"#:K]BR
MVXS9AMF'XH",XH",V8?8IR#9@=BQV*?8KMF(V*?9AMN,(-BTV8C8KP#9AMF%
MV*?;C-BT(-BSV838L]F$V8?B@(S8I]N,VXP`V8;9A=BGVXS8M"#8L]F$V+/9
MA-F'XH",V*?;C-N,(`#8L=BYV*\`V*C9A-N,V+?9A]BG`-BRV878I]F&`-BQ
MV*_;C-BGV*C;C"#8LMF%V*?9A@#9@MBGV838J"#8LMF%V*?9A@`@V*?9AMBJ
MV*[8I]BH(-BRV878I]F&(`#8N=F&V8C8I]F&`-BYV8;9B-BGV88@*-BQV*?9
MA]F&V878I]N,(-BBV8;;C"DZ`-BHV8<`V*+8K]BQV+,@VJ_;C-BQV8;8K]F'
M`-BHV+'8I]N,(-BGV8;8JMBNV*?8J"#:AMF&V*\@V8';C-F$V*_8C"#8K]JI
MV879AR!#=')L(-BQV*<@V+'9B-N,("A00RD@VXS8IR!#;VUM86YD(-BQV*<@
MV+'8IR#8L=F(VXP@*$UA8RG8C"#8K]BQ(-F%V*_8JB#:J=F$VXS:J2#:J=BQ
MV*_9AB#9AMJOV8?8K]BGV+';C-BO`-BHV+'8I]N,(-BGV8;8JMBNV*?8J"#:
MAMF&V*\@V8';C-F$V*_8C"#8K]JIV879AR!#=')L(-BQV8C;C"`H4$,I(-N,
MV*<@0V]M;6%N9"#8L=F(VXP@*$UA8RD@V+'8IR#8K]BQ(-F%V*_8JB#:J=F$
MVXS:J2#:J=BQV*_9AB#9AMJOV8?8K]BGV+';C-BO`-BGV878L=F(V+(`V8'8
ML=BOV*<`V*C8I]F$V*<`VH;8I]BQVH;9B-BH(-BHV*?9A-BG("C8J-BGV838
MIRD`V878K-F%V8C8N2#8I]F&V*_8I]BRV8?9E"#9OMN,V8C8L]BJV8?8ISH`
MV*K8L=BLV879A^*`C-F'V*<`V;[9B-BTV8?9E"#8HMBTV+K8I]F$`-F^V8C8
MM-F'V90@V*+8M-BZV*?9A#H`V*_8L=BSV*H@V8@@VXS8IR#9AMBGV*_8L=BS
MV*H`V+/9AR#8M-F&V*C9AP!4=7)K:7-H("A)4T\M.#@U.2TY*0#8I]F&V*K8
MKMBGV*@@V*[9B-BO(-BQV*<@V*K8I]N,V;X@VJG9AMN,V*\Z`-BTV*?8KMBU
M(%4N5BX@.B``55),`%523#H`V*?9A=JIV*?9AB#8K]BSV*K8L=BSVXP@V*C9
MAR#8M-BGV*[9AR!61E,@V8;;C-BSV*H`V*?9A=JIV*?9AB#8I]BVV*?9@=F'
M(-JIV+'8K]F&(-BGV+?9A-BGV+G8I]BJ(-BGV+;8I]F!VXP@VJG8I]BQV*C8
ML2#8J-F'(-F'V8;:K]BGV84@V*O8J-BJ(-F&V*?9A2#9AMN,V+/8J@#9AMF%
MVXSB@(S8JMF(V*?9AB#9A=BLV8C8LMF'V*<@V+'8IR#8J-BQV*?;C"#9OMBQ
MV8C9AMBOV8<@(B5S(B#8JMBZVXS;C-BQ(-BOV*?8KP#9AMF%VXSB@(S8JMF(
MV*?9AB#9A=BLV8C8LMF'V*<@V+'8IR#8J-BQV*?;C"#9OMBQV8C9AMBOV8<@
M)7,O)7,@5D93("#8JMBZVXS;C-BQ(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9
MAB#8K]BQ("5S(-BJV+K;C-N,V+$@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&
M(-BHV8<@VJG8I]BQV+/8I]BR(%-13-F%V*K8M=F$(-BTV*\`V8;9A=N,XH",
MV*K9B-BGV88@V*C8IR!34TP@V878JMBUV80@V+38KP#9AMF%VXSB@(S8JMF(
MV*?9AB#8I]BR(-F^V+'9B-F&V*_9AR!61E,@V+'9B-F&V8C8M-BJ(-BJV8?;
MC-F'(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R`B
M)7,B(-BQV*<@V*?;C-BLV*?8KR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9
MAB#8M-BGV*[9AR!61E,@V+'8IR#8I]N,V*S8I]BO(-F&V879B-BO`-F&V87;
MC.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8I]N,V*S8I]BO
M(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#8KMBG
MV83;C"!61E,@(-BGVXS8K-BGV*\@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BG
MV88@V*_8I]BOV8<@V+'8IR#8J-BGV+(@VJG8L=BO(`#8K=BPV8$@(B5S(B#9
MA=F%VJG9AB#9AMN,V+/8JMB,(-BTV*?8KMF'(-BNV*?9A-N,(-F&VXS8L]BJ
M`-F&V87;C.*`C-BJV8C8I]F&("(E<R(@V+'8IR#8K=BPV8$@VJG8L=BO.B`E
M<RX`V*W8L-F!("5S(-F%V87:J=F&(-F&VXS8L]BJV(P@V+38I]BNV8<@V*[8
MI]F$VXP@V8;;C-BSV*H`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93
M(-BQV*<@V*C9AR#8M=F(V+'8JB#8JMF((-BOV+$@V*K9B"#8K=BPV8$@V8;9
MA=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*W8
ML-F!(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8
ML=BG(-BMV+#9@2#9AMF%V8C8KSH@)7,N`-F&V87;C.*`C-BJV8C8I]F&(-F^
MV+'9B-F&V*_9AR!61E,@(B5S(B#8L=BG(-BMV+#9@2#9AMF%V8C8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*W8L-F!(-F&
MV879B-BO`-F&V87;C.*`C-BJV8C8I]F&(%9&4R#8L=BG(-BHV8<@V+79B-BQ
MV*H@V*K9B"#8K]BQ(-BJV8@@V*W8L-F!(-F&V879B-BO.B`E<RX`V8;9A=N,
MXH",V*K9B-BGV88@V+38I]BNV8?9E"#9@=BYV83;C"#8L=BG(-BJV+38KMN,
MV+4@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-BLV++8IMN,V*?8JB#:K]F(
MV*?9A]N,(-BQV*<@V*?8L]BJV*[8L=BGV*P@V8;9A=F(V*\`V8;9A=N,XH",
MV*K9B-BGV88@V*K8N=BQVXS9@2`E<R`@V+'8IR#8J-BGV+$@V8;9A=F(V*\`
MV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BGV8;8
MJMF"V*?9A"#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'
M(%9&4R`B)7,B(-BQV*<@V*C8I]BR(-F&V879B-BO`-F&V87;C.*`C-BJV8C8
MI]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8J-BQV*?;C"#9AMF(V+38JMF&
M(-BHV*?8LB#:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'
M(%9&4R#8L=BG(-BHV*?8LB#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8
MHMBQV+3;C-F((-F!V+38L=BOV8<@V+'8IR#8J-BGV+(@VJG8L=BO`-F&V87;
MC.*`C-BJV8C8I]F&(-BTV*?8KMF'('9F<W)O;W0@V+'8IR#8KMF(V*?9AMBO
M`-F&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*C9AR`E<R`@V*K8NMN,VXS8
ML2#9AMBGV84@V*_8I]BO.B#9OMF(V+39AR#9A=F"V+78KR#8I]BR(-F"V*C9
MA"#9A=F(V*S9B-BO(-BGV+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9
MAR!61E,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\`V8;9A=N,XH",
MV*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@
MV*_8I]BO.B`E<RX`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&
M4R`B)7,B(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO`-F&V87;C.*`
MC-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@)7,O)7,@V+'8IR#8JMBZVXS;
MC-BQ(-F&V*?9A2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8
MK]F'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#9A=F"V*_8I]BQ(-BSV8?9A=N,V8<@V+'8IR#8J-BGV++;
MC-BGV*C;C"#:J=BQV*\@`-F&V87;C.*`C-BJV8C8I]F&("=M:VES;V9S)R#8
ML=BG(-BGV*S8L=BG(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BGVXS9
MAB#8L]F&V*\@5V]R9"#8L=BG(-BJV+'8K-F%V8<@V8;9A=F(V*\`(-F&V87;
MC.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'("(E<R(@5D93("#9AMF(
MV+38J@`@V8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@5D93
M(-F&V8C8M-BJ+@#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9
MA]F4(-BOV*?8K]F'(%9&4R#9AMF(V+38J@#9OMBGV+/8KB#8K]BGV*_9AR#9
MAMBTV*_9AP#9OMN,V+K8I]F%V8?8I]N,(-F^V*?8L]BN(-BOV*?8K]F'(-F&
MV+38K]F'`-BHV*?8LMN,V*?8J-N,`-BRVXS8L=BNV+?B@(S8K]BGV+$`VJ_;
MC-BQV8;8K]F'V90@V8;8I]BTV8;8I]BS`-F(V*?:K]BQV*_8I]F&V*_9AB#8
MJMBZVXS;C-BQV*?8J@#9B-BGVJ_8L=BOV*?9AMBOV88@V*+8KMBQVXS9AB#8
MN=F%V80@V+39A=BG`-F^V*?8L]BN(-BZVXS8L2#9A=F&V*K8N-BQV8<@V*?8
MLB#:J=BGV+'8L]BGV+(@V*C8L2#8L=F(VXP@V*?8JMBUV*?9A#H`V;[8I]BS
MV*X@V+K;C-BQ(-F%V8;8JMBXV+'9AR#8I]BR(-JIV*?8L=BSV*?8LB#8J-F'
M.@#8NMN,V+$@V*W9B-BRV8<`V878I-F$V8'9A]F4("#8J-BOV8C9AB#9OMBT
MV*K;C-BHV*?9AMN,.B`E<P!5;FEC;V1E("A55$8M."D`V8C8I]BMV*_9A]BG
M`-BOV*?8K]F'(-F&V*?8M-F&V*?8KMBJV8<`V*K8I]BQVXS8KB#9AMBGV878
MN=F$V8C9A0#9A=F$V*?9@MBGV*H@V8;8I]F%V+G9A-F(V84`VJ_;C-BQV8;8
MK]F'V90@V8;8I]F%V+G9A-F(V84`V8;8I]F%(-JIV*?8L=BHV+$@V8@@VXS8
MIR#8I]BSV84@V+'9A=BR(-F&V*?8M-F&V*?8KMBJV8<`V8+8M]BY(-F^VXS9
MB-F&V*\@V+G9AMBUV+$@V8'8N=F$VXP`V*C8L=BOV*?8M-BJV88@V+G8J-BG
MV+'8JB#:K]BPV+$`V*C;C.*`C-F&V*?9A0#8K]BSV*H@XH",V8;9B-N,V+/9
MA]BGVXP@V*C8K]F(V88@V*?9A=BJVXS8I]BR(-BHV8<@V*_9A-N,V80@V*?9
MA=F&VXS8JMN,(-F&V87;C.*`C-BJV8C8I]F&V8;8KR#8I]BR(-BWV+';C-F"
M(-BHV+'9AMBGV879AR#9AMF(VXS8L]N,(-BHV+';C-BOV8<OV+'9B-F&V8C8
MM-BJ(-JOV+'9@=BJV8<OVH;8L]BHVXS8K]F'(-BTV8C9AMBO+B#:J=F$VXS8
MKR#8JMBCVXS;C-BO(-BQV*<@V8'8M-BGV+$@V*_9A]N,V*\@V*K8IR#9A=BJ
MV88@V8'9AMN,XH",V*?B@(S;C-N,(-BQV*<@V*_8L2!M;WII;&QA+F]R9R#8
MJ-BG(-BYV8;9B-BGV88@VH;:K]F(V8;:K]N,(-BOV+/8JMBQV+/;C"#;C-JI
M(-BOV+/8JB#B@(S9AMF(VXS8LR#8J-F'(-BJV*[8JMF'V90@V+'8L]F%(-BQ
MV*<@V878M-BGV8?8K]F'(-JIV8;;C-BO`-F%V+38I]F'V*_9AR#9AMBTV*_9
MAP#8L=F&VJ\@V*K9AMBXVXS9A2#9AMBTV*_9AP#9A-BZV8@@V+G8MMF(VXS8
MJB#8I]BR(-F^V8C8M-F'*-F'V*<I`-BHV+/8MR#8J-BOV8C9AB#9OMBTV*K;
MC-BHV*?9AMN,`-BHV+'9B-BRV+'8L]BGV8;;C`#8J-BQV8C8LMBQV+/8I]F&
MVXP@)7,`V*C8L=F(V++8L=BSV*?9AMN,(-BGV+?9A-BGV+G8I]BJ(-F^VXS9
MB-BSV*H`V*C8L=F(V++8L=BSV*?9AMN,(-F(V+;8N=N,V*H@V;[8I]BSV*X`
MV*C8L=F(V++8L=BSV*?9AMN,(-JIV*?8L=BHV+$`(B5S(B#8J-BQV8C8LMBQ
MV+/8I]F&VXP@V+38KP#8K]BSV*KB@(P@V8;9B-N,V+,@V*C9A]N,V8;9A^*`
MC-BSV*?8LMN,(-BMV+#9@2#8M-BO`-BGV+'8L]BGV80`V*K9A=BGV84@V;[8
ML=F(V8;8K]F'XH",XH",V8?8I]N,(-BJV8;8N-N,V84@V*C8L=F&V*?9A=F'
MXH",V8?8I]N,(-JIV*?8L=BHV+'8K]N,(-BHV8<@VJG8I]BQV+/8I]BR(-BG
MV+'8L]BGV80@V+38KP#8K=BQV8C9@2#8J-BRV+':KR#9A-BGV*K;C-F&`-BG
MV+G8K]BGV*\@VXS9B-F&V*?9AMN,(-BHV++8L=JO`"#8I]BSV*K9@=BGV*_9
MAR#9@=BYV83;C#H@)7,`V*?8L]BJV8'8I]BOV8<@V*?8LB#9A=F"V*_8I]BQ
M(-F^VXS8M"#9@=BQV+8`V*+;C-BG(-BGV+(@V+G8MMF(VXS8JB#9OMF(V+39
MA^*`C-F'V*?;C"!)34%0(-BGV+/8JMF!V*?8K]F'(-BTV8C8K]B?(`#8I]BS
MV*K9@=BGV*_9AR#8I]BR(%-33`#8HMN,V*<@V*?8LB#9OMF(V+39A]F4(-BB
MV+38NMBGV80@V878K-BGV++;C"#8I]BSV*K9@=BGV*_9AR#8M-F(V*_8GP#8
MI]JOV+$@V8;8I]F%+]BGV+/9A2#8L=F%V+(@V*C8L=BGVXP@VJG8I]BQV+/8
MI]BR($E-4U`@V878JMF!V*?9B-BJ(-BGV+/8JMB,(-BGV+/8JMF!V*?8K]F'
M(-JIV8;;C-BO`-JIV*?8L=BHV+$`VJG8I]BQV*C8L2`E<R`@V*C8L=BGVXP@
M)7,@V*?8K=BQV*?8LB#9A]F(VXS9D=BJ(-F&V+38K]F'(-BGV+/8J@#8L]BQ
MV;[8L=BSV*K;C"#:J=BGV+'8J-BQ`-JOV++;C-F&V8?B@(S9A]BGVXP@VJG8
MI]BQV*C8L0#8J]BHV*H@V8;8I]F%(-JIV*?8L=BHV+$`V*O8J-BJ(-JIV*?8
ML=BHV+$@V*C8L=BGVXP@V*?;C-F&(-F^V*?;C-JOV*?9AR#8NMN,V+$@V8'8
MN=BGV80@V+38K]F'(-BGV+/8J@#8K=BSV*?8J"#:J=BGV+'8J-BQ(-F^VXS8
MK]BG(-F&V+38KP#9AMBGV84@VJG8I]BQV*C8L0#9AMBGV84@VJG8I]BQV*C8
ML3H`V8;8I]F%(-JIV*?8L=BHV+$Z(`#:J=BGV+'8J-BQV*?9AB#8L]BGV878
MI]F&V8<Z`-BTV*?8KMF'(%9&4R#9B-BLV8C8KR#9AMBOV*?8L=BO`-BJV+G8
MM]N,V838I]BJ`-F%V8C9@MBYVXS8JMF'V*?;C"#9A=BYV*K8J-BQ(-N,V*?9
M@=BJV8<@V+38K]F'(-BYV*C8I]BQV*K9AMBO(-BGV+(Z`-BGV+G8JMBHV*?8
ML0#9A=F"V*_8I]BQ(-BHV8<@V*_9@MN,V8+9AR#8I]BR(-BMV*?9A-BG`-F%
MV8+8K]BGV+$@V*?8LB#8J-N,V+3;C-F&V8<@V+?9B-F$(-F%V*S8I]BR("5S
M(-BHVXS8M-BJV+$@V*?8L]BJ`-F%V8+8I]BOVXS8L0#9A=F"V*?8K]N,V+$@
MV*C8L=BGVXP@V*?9AMBJV*[8I]BH(-BGV+(`V878JMBZVXS;C-BQ`-F&V+/8
MKMF'`-JIV8;8JMBQV80@V8;8L]BNV8<`V*K8L=BGV+(@V+G9A=F(V*_;C`#9
M@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8N=F%V8C8K]N,`-BYV879B-BOVXPZ
M`-BNVXS9A-N,(-BHV*?9A-BG`%9I971N86UE<V4@*%9)4T-)22D`V8;9A=BG
M`-F&V878I]N,V+0@)7,`V8;9A=BGVXS8M"#:J=F$VXS8KR#8N=F%V8C9A=N,
M("5S`-F&V878I]N,V+0@V878JMF&($A434P@V*_8L2#;C-JI(-F^V8;8K-BQ
MV8?9E"#8K-BOV*?:K]BGV8;9AP#9A=BTV*?9A]BOV8?9E"#9OMN,V+K8I]F%
MV8?8IP#9AMF%V*?;C-BT(-JIV83;C-BO(-BNV+79B-BUVXP@V+38KMBUVXP`
MV8;9A=BGVXS8M"#:J=F$VXS8KR#8N=F%V8C9A=N,(-BTV*[8M=N,`-F&V878
MI]N,V+0@V+/9A-BSV839A^*`C"``V8;9A=BGVXS8M"#8JMBUV8C;C-BQ(-JI
MV8C:AMJI(-BTV*_9AP#9AMF%V*?;C"#;C-JI(-BUV8'8K=F'(-F(V*@@V*[8
MI]BQV*S;C``@V8;9A=BG(-BHV8<@V+G9AMF(V*?9AB`E<P#9AMF%V*?;C-BT
M(-F^VXS9B-BSV*K9A]BG(-BOV+$@VXS:J2#9OMF&V*S8L=F'V90@V*S8K]BG
MVJ_8I]F&V8<`V8;9A=BGVXS8M"#9A=BJV88@V*_8L2#;C-JI(-F^V8;8K-BQ
MV8?9E"#8K-BOV*?:K]BGV8;9AP#9AMF%V*?;C-BT(-BQV8C;C-BOV*?8KP#9
MAMF%V*?;C-BT(-F^VXS8NMBGV879A]BG(-BOV+$@)7,`V878M-BGV8?8K]F'
M(-F&V*?9A=F'(-F((-N,V*<@V8;8I]F%V8?B@(S8K]BGV88@V*C8L=BGVXP@
MV8;9A=BGVXS8M"#8J-BYV*\@V*?8LB#9B-BQV8C8KP#9A=BTV*?9A]BOV8?9
ME"#9B-BXVXS9@=F'`-F&V878I]N,V+0@V*K8M=BGV8C;C-BQ`-F^V8C8M-F'
MV90@V878K-BGV++;C"`B)7,B(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]N,
MV*S8I]BO(-BTV*\`V;[9B-BTV8<F(W@R,#!C.]F'V*?;C"#9A=BLV*?8LMN,
M`-F^V8C8M-F'V90@V878K-BGV++;C"#8J-F'(-N,VJD@V*C8L=J&V+/8J"#9
MAMN,V*?8LB#8K]BGV+'8KP#9OMF(V+39A]F4XH",(-F%V*S8I]BRVXP@V8;8
MI]F%V8?B@(S9A]BGVXP@V*_8L=N,V*?9@=BJVXP`V;[9B-BTV8?B@(S9E"#9
MA=BLV*?8LMN,(-F&V*?9A=F'XH",V8?8I]N,(-BOV+';C-BGV8'8JMN,`-BS
MV+?9A"#8HMBTV+K8I]F$(-F%V*S8I]BRVXP`V;[9B-BTV8?B@(S9E"#9A=BL
MV*?8LMN,(-BBV+38NMBGV80`V*C8L=J&V+/8J"#9OMF(V+39A]F4(-F%V*S8
MI]BRVXP`V8+8I]BHV83;C-BJ(-F%V+38I]F'V*_9AP#9@MBGV*C9A-N,V*H@
MV878M-BGV8?8K]F'.B``V*?8KMBWV*?8L2$A(2#8K]BSV*H@XH",V8;9B-N,
MV+,@V+'8IR#8J-BWV8C8L2#8K]BSV*K;C"#8I]BR("5S(-BMV+#9@2#:J=F&
MVXS8KP#8I]BNV+?8I]BQ.B``VH;9A]BGV+'8M-F&V*C9AP#9OMN,V+3B@(S8
MJ-N,V8;;C"#9A]F(V*<`V*_8I]BOV8<@V*+8J"#9B"#9A]F(V*?;C-N,(-F!
MV+'8I]F'V84@V+38K]F'(-BHV8<@V8C8L]N,V839AP!W96%T:&5R+F-O;0#9
MB-BH`-F(V*CB@(S:K]BGV8<`V8?9@=BJVJ_;C`#8KMF(V+0@V*+9A=BOVXS8
MKP#8J-F'("5S(-BNV8C8M"#8HMF%V*_;C-BO(``E<]B,(-BNV8C8M"#8HMF%
MV*_;C-BO`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0#:AMF'(-BHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(-BQV*<@
M)7,@V*C8I]N,V*\@V*C8N=BO(-BGV+(@V8C8L=F(V*\@V8;8M-BGV88@V*_9
MA]BOV)\`V8;9B-N,V+/9A]F4XH",(-BMV*?8IMF$(-J&VXS8L]BJV)\`V8;9
MB-N,V+/9A^*`C-N,(-F&V8+9A"#9@MF(V80@VH;;C-BSV*K8GP#8HMN,V*<@
MV8?8L=BRV8;8I]F%V8?B@(S9A]BG(-BHV+G8KR#8I]BR(-BGVXS9AMJIV8<@
MV*C9AR#8N=F&V8C8I]F&(-F'V+'8LMF&V*?9A=F'(-JOV++8I]BQV+0@V+38
MK]F&V*\@V*W8L-F!(-BTV8C9AMBOV)\`V*+;C-BG(-BOV+$@V8?9AMJOV*?9
MA2#8K=BPV8$@V;[;C-BZV*?9A=F'V*?8C"#8J-BLV*?;C"#8N=F$V*?9A=BJ
M(-JOV+#8I]BQVXP@V*+9AMF'V*<@V*C8N=F&V8C8I]F&(-BMV+#9@2#8M-BO
MV8<@V*C9AR#8L]BWV80@V*+8M-BZV*?9A"#8M-F%V*<@V*?9AMBJV8+8I]F$
M(-BOV*?8K]F'(-BTV8C9AMBOV)\`V*_8L2#9A]F&VJ_8I]F%(-BHV*?8LMJI
MV+'8K]F&(-N,VJD@V8;8I]F%V8?B@(S8K]BGV88@V*S8K]N,V*_8C"#:J=BO
MV*?9A2#8M=F!V*W9AR#8J-BQV*?;C"#8M-BQV8C8N2#8J-BGV+(@V+39B-BO
MV)\`V*+;C-BG(-F'V8;:K]BGV87;C"#:J=F'(-F&V*?9A=F'V90@V8'8L=BS
MV*K8I]BOV8<@V+38K]F'(-BMV8'8N"#9A=N,XH",V+39B-BOV(P@V*C8I]N,
MV*\@V;[;C-F(V+/8JB#9A]F%(-BMV8'8N"#8M-F(V*_8GP#8J-F'(-F'V8;:
MK]BGV84@V*?8L=BSV*?9A"#9OMN,V+K8I]F%V(P@VH;9AR#9AMBGV84@V*W9
MB-BRV8?B@(S8I]N,VXP@V+'8IR#8J-BGVXS8KR#8J-F'(-BBV*_8L=BSV8?8
MI]N,(-BZVXS8L2#:J=BGV879A"`HV*C8K]F(V88@0"D@V*?8MMBGV8'9AR#9
MAMF%V8C8KP#:J=BOV*?9A2#9@=BGV+(`VJG8K]BGV84@V*C8L=F&V*?9A=F'
MXH",V8?8I]N,(-F%V*K8M=F$XH",VJG9AMF&V*_9AR#B@(S8J-BQV*?;C"#9
MB-N,V+'8I]N,V+3:K]BQ(-F%V*K9AB#9@=BYV*?9A"#8J-BGV+39AMBO`-F!
MV8?8L=BSV*H@V+/9@=N,V*\`V+G8L=BV`"#9OMF'V8;8IR#8K]BQ(-F(V*?8
MK=BO($-34R``V;[9A]F&V*?;C"#:K]BRVXS9AMJOV*?9AB`E<R#8K]BQ(-BQ
MV*?8L]BJ("C8K]BQ(-F(V+'9B-BO(-BHV+G8K]N,(-F%V8C8J]BQ(-F%VXSB
M@(S:K]BQV*_8KRDZ`-F^V8?9AMBGVXP@V*S8K]F(V80`V8C8I]BMV*\@V;[9
MA]F&V*<`V;[9A]F&V*<Z`%=I:VD`V*C8I]BO.@#8J-BGV*\@V++9B-BOV8?9
MAMJOV*?9A3H@`-BSV+'8N=BJ(-BHV*?8KR#8J-BQV*W8L]BH(-F!V8C8JB#8
MJ-BQ(-BSV*?8N=BJ`-BHV*?8KSH`V*C8I]BO.B``V+G9@MF$`-JIV*?8L0#8
MHMBOV+'8LR#9A=BMV80@VJG8I]BQ`-BJV839@=F&(-F%V*W9A"#:J=BGV+$`
MXH",65D`65E960#8L]BGV838I]F&V8<`V*C9A-F'`-BHV839A]B,(-F%V8C8
MI]F!V8+9A0#8M-F%V*<@V*_8L2#8M=BOV*\@V8C8I]JIV+3;C"#9AMBGV879
MA^*`C-F'V*?;C"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8I]BR(-BMV+/8I]BH
MXH",*-F'V*?;C"D@V++;C-BQ(-F'V+/8JMN,V*\Z`-BTV878IR#8K]BQ(-F^
MVXP@V*W8L-F!(-F^VXS8NMBGV879A]BGVXP@V;[9B-BTV8?B@(S9A]BGVXP@
MV++;C-BQ(-F'V+/8JMN,V*\Z`-BTV878IR#8K]BQ(-F^VXP@V*W8L-F!(-F^
MV8C8M-F'XH",V8?8I]N,(-BRVXS8L2#9A]BSV*K;C-BO.@#8M-F%V*<@V*_8
ML2#8K=BGV80@V+'9B-F&V8C8M-BJ(-JOV+'9@=BJV88OV*?9AMBJV8+8I]F$
M(-BHV8<@VXS:J2#9OMF(V+39AR#8K-BOVXS8KR#9A]BSV*K;C-BO`-BTV878
MIR#8K]BQ(-BMV*?9A"#8L]BGV*[8JMF&(-N,VJD@V++;C-BQV;[9B-BTV8<@
MV8?8L]BJVXS8KP#8M-F%V*<@V*_8L2#8K=BGV80@V*?;C-BLV*?8KR#;C-JI
M(-F^V8C8M-F'(-BSV+?8K2#8J-BGV838IR#9A]BSV*K;C-BO`-BTV878IR#8
MK]BQ(-F%V*\@V878JMF&(-F'V+/8JMN,V*\N(-BGV+(@V*_:J=F%V8<@(%L\
M/ET@V*C8L=BGVXP@V*C8L=JOV+38JMF&(-BHV8<@5UE325=91R#8I]BSV*K9
M@=BGV*_9AR#:J=F&VXS8KP#8M-F%V*<@V878K-F(V+(@V*?;C-BLV*?8KR#9
MOMF(V+39AR#8L=BG(-F&V*_8I]BQVXS8KP#8M-F%V*<@V878K-F(V+(@V*?;
MC-BLV*?8KR#8J-N,V+0@V*?8LB`E9"#9OMF(V+39AR#8L=BG(-F&V*_8I]BQ
MVXS8KP#8M-F%V*<@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&V+38K]N,V*\`
MV+39A=BG(-BOV+$@V*W8I]F$(-BJV+K;C-N,V+$@V8;8I]F%(-F^V8C8M-F'
M(-F'V+/8JMN,V*\Z`-BTV878IR#9AMF%VXSB@(S8JMF(V*?9AMN,V*\@V8;9
MB-N,V+/9AR`G7"<@V+'8IR#8K]BQ(-F&V*?9A2#:J=BGV879A"#8KMF(V*\@
MV*_8I]BTV*K9AR#8J-BGV+3;C-BO`-F$V+K9B"#8N=BVV8C;C-BJ(-BTV878
MIR#8I]BR("(E<R(@V879A=JIV88@V8;;C-BSV*H`V+39A=BG(-BGV+(@V*K8
ML=JIVXS8J-BGV*H@V++;C-BQ(-BOV+$@V8;9B-BTV*KB@(S8I]F!V++8I]BQ
M(-F%VXSB@(S8JMF(V*?9AMN,V*\@V*?8L]BJV8'8I]BOV8<@V8;9A=BGVXS;
MC-BO.B`E8R#8J-BQV*?;C"#8I]BTV*?8L=F'(-BHV8<@V878JMF&(-F^VXS8
MNMBGV84@V8'8N=F$VXP@V8@@)7,@V*C8L=BGVXP@V*?9A=BVV*?8H0#8M-F%
MV*<@V*C8IR#8M-BQVXS8MR#8JMF(V*?9@=F"VXP@V*[8K]F%V*K:K]BRV*?8
ML2#9A=F(V*?9@=F"V*H@V8;:J=BQV*_9A^*`C-BGXH",VXS8K]B,(-BHV8;8
MI]BHV+'8I]N,V88@V+39A=BG(-BGV*S8I]BRV8<@V8C8L=F(V*\@V8;8K]BG
MV+';C-BO`-BTV878IR#8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;
MC-JI(-F%V+G8JMBHV+';C"#9B-BGV+'8KR#9AMJIV+'8K]F'XH",V*?;C-BO
M`-BTV878IR#9A]N,VH8@V8';C-F$V*_;C"#8L=BG(-BOV+$@V;[8L=F(V8;8
MK]F'(-BOV+'9B-F&XH",V*C8L=BO(-BTV*_9AR#8J-F'(-F!VXS9A-BO(-F%
MV*K9@MBGV*C9A-N,(-BOV+$@)7,@V8;:K]BGV+38JB#9AMJIV+'8K]F'XH",
MV*?;C-BO`-BTV878IR#9A=BLV8C8LB#8JMBZVXS;C-BQ(-BOV+/8JMBQV+/;
MC"#8I]N,V88@V;[9B-BTV8<@V+'8IR#9AMBOV*?8L=N,V*\`V+39A=BG(-BG
MVXS9AB#9OMN,V+K8I]F%(-BQV*<@V*C8L2`E)7,@V*C9AR#:K]N,V+'9AMBO
MVJ_8I]F&(-BRVXS8L2#8I]BQV*S8I]BY(-JIV+'8K]N,V*\Z("5S`-BTV878
MIR`E<R#9OMN,V+K8I]F%(-BLV*_;C-BO(-BOV*?8L=N,V*\`V+39A=BG(-N,
MVJD@V;[;C-BZV*?9A2#8K-BOVXS8KR#8K]BGV+';C-BO`-BTV878IR#8K=BO
MV*?9@MF$(-N,VJD@V;[;C-F(V+/8JB#8I]F&V*K8KMBGV*@@V+38K]F'(-BO
MV*?8L=N,V*\@VJG9AR#9A]F&V8C8LB#8HMF&V+'8IR#8I]BQV+/8I]F$(-F&
MVJG8L=BOV8?B@(S8I^*`C-N,V*\N(-BBVXS8IR#9A=BWV878IMF&VXS8KR#:
MJ=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*C8K]F(V88@V*?;C-F&(-F^VXS9
MB-BSV*K9A]BG(-F^VXS8NMBGV84@V+'8IR#8J-F!V+'8L]BJVXS8K]B?`-BT
MV878IR#8KMBGV+'8K"#8M-BOVXS8KP#8M-F%V*<@V*_8L2#9OMF(V+39A]F4
M(-BRVXS8L2#9OMN,V+K8I]F%(-BLV*_;C-BO(-BOV*?8L=N,V*\Z`-BTV878
MIR#8K]BQ(-F^V8C8M-F'V90@V++;C-BQ(-F^VXS8NMBGV84@V*S8K]N,V*\@
MV*_8I]BQVXS8KSH`V+39A=BG(-F%V*S8J-F(V+$@V8?8L]BJVXS8KR#;C-JI
M(-BTV878I]BQV8<@V*K9A-F!V88@V878N=BJV*C8L2#9B-BGV+'8KR#:J=F&
MVXS8K]B,(-BGV+(@V+G9A-BGV878JB`G*R<@V*C8L=BGVXP@V+39A=BGV+'9
MA^*`C-F'V*?;C"#8J-N,V88@V*?9A-F%V839A-N,(-BGV+/8JMF!V*?8K]F'
M(-JIV8;;C-BO`-BTV878IR#9A=BLV*C9B-BQ(-F'V+/8JMN,V*\@VXS:J2#9
MA=F"V*_8I]BQ(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMN,V*\`V+39A=BG
M(-BHV*?;C-BO(-N,VJD@V;[8M-BJVXS8J-BGV88@V*_8L=BNV*H@V*_8I]BO
MV8<@V*C8L=BGVXP@V*?8L]BJV8'8I]BOV8<@V*?8LB#8J]BHV*H@V8;8I]F%
M(-F^VXS:J=BQV*C9AMBOVXP@VJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(-N,
MVJD@V+/8I]F%V*?9AMF'(-F^V+38JMN,V*C8I]F&(%9&4R#8L=BG(-F^VXS:
MJ=BQV*C9AMBOVXP@VJG9AMN,V*\`V8+8J-F$(-BGV+(@V*?8L=BSV*?9A"#:
MK]BRV*?8L=BTV(P@V*C8I]N,V*\@V878M-JIV80@V+'8IR#8M-BQV*T@V*_9
MA]N,V*\`V+39A=BG(-BHV*?;C-BO(-BMV*_8I]F"V80@VXS:J2#:K]N,V+'9
MAMBOV8<@V8C8I]BQV*\@VJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(%523-BG
MVXP@VJG9AR#8I]N,V88@V;[;C-F(V8;8KR#8J-F'(-BBV88@V*?8M-BGV+'9
MAR#9A=N,XH",VJG9AMBO(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\`V+39A=BG
M(-BHV*?;C-BO(-BYV*C8I]BQV*H@VJ_8L-BQ(-BQV*<@V*C8L=BGVXP@VJG9
MA-N,V*\@V*[8M=F(V+7;C"!01U`@V*[9B-BO(-F(V*?8L=BO(-JIV8;;C-BO
M(-BJV*<@V;[;C-BZV*?9A2#8L=BG(-F%V+38I]F'V*_9AR#:J=F&VXS8KP#8
MM-F%V*<@V*C8I]N,V*\@V+G8J-BGV+'8JB#:K]BPV+$@V+'8IR#8J-BQV*?;
MC"#:J=F$VXS8KR#8KMBUV8C8M=N,(%,O34E-12#8KMF(V*\@V8C8I]BQV*\@
MVJG9AMN,V*\@V*K8IR#9OMN,V+K8I]F%(-BQV*<@V878M-BGV8?8K]F'(-JI
MV8;;C-BO`-BTV878IR#8I]BHV*K8K]BG(-BHV*?;C-BO(-N,VJD@V8;8I]F%
MV8<@V*_8I]F&(-F%V8+8M=BO(-F%V+38KMBU(-JIV8;;C-BO`-BTV878IR#8
MJ-BGVXS8KR#;C-JI(-BMV+/8I]BH(-BHV+'8I]N,(-BMV+#9@2#:J=BQV*_9
MAB#8I]F&V*K8KMBGV*@@VJG9AMN,V*\`V+39A=BG(-BGV*C8JMBOV*<@V*C8
MI]N,V*\@VXS:J2#8HMBOV+'8LR#8I]F&V*K8KMBGV*@@VJG9AMN,V*\`V+39
MA=BG(-BHV*?;C-BO(-N,VJD@VJG8I]BQV+/8I]BRV(P@V*C8L=BGVXP@V*W8
ML-F!(-JIV+'8K]F&(-BGV8;8JMBNV*?8J"#:J=F&VXS8KP#8M-F%V*<@V*?8
MJ-BJV*_8IR#8J-BGVXS8KR#8K=BOV*?9@MF$(-N,VJD@V;[;C-BZV*?9A2#8
MI]F&V*K8KMBGV*@@VJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(-N,VJD@VJ_;
MC-BQV8;8K]F'(-F%V+38KMBU(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;
MC-JI(-F&V*?9A2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*W8L-F!(-JIV+'8
MK]F&(-F%V+38KMBU(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-F&
MV*?9A2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*W8L-F!(-BTV*_9AB#9A=BT
MV*[8M2#:J=F&VXS8KP#8M-F%V*<@V*W8K]BGV8+9A"#8J-BGVXS8KR#;C-JI
M(-F^V+'9B-F&V*_9A^*`C"#8J-BQV*?;C"#9OMN,V8C8L]BJ(-JIV+'8K]F&
M(-F%V+38KMBU(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-F&V*?9
MA2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9AB#9
MA=BTV*[8M2#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#8M-F&V*?8
ML]F'(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8J-BQV8C8LMBQV+/8I]F&VXP@
MV*?9AMBJV*[8I]BH(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#9A=BTV*[8
MM2#:J=F&VXS8KR#:J=F'(-J&V8<@V+G9A=F$VXP@V*C8I]N,V*\@V*?9AMBL
MV*?9A2#:K]N,V+'8KP#8M-F%V*<@V*C8I]N,V*\@V8;8I]F%(-BLV*_;C-BO
M(-BOV+/8JMF'(-BQV*<@V*K8I]N,V;X@VJG9AMN,V*\`V+39A=BG(-BGVXS9
MAB#9OMN,V+K8I]F%(-BQV*<@V*C9AR`E<R#8J-BQ("4E<R#8JMBZVXS;C-BQ
M(-F%V+/;C-BQ(-BOV*?8K]F'XH",V*?B@(S;C-BO`-BTV878IR#8J-F'(-BG
MVXS9AB#9OMN,V+K8I]F%(-BOV+$@)7,@V;[8I]BSV*X@V*_8I]BOV8?B@(S8
MI]N,V*\`VJG8I]BQV+/8I]BR(-JOV8'8JB#:J=F'(-BTV878IR#8N=BVV8@@
M(B5S(B#9AMBHV8C8K^*`C-N,V*\`VJG8I]BQV+/8I]BR(-JOV8'8JB#:J=F'
M(-BYV+;9B-N,V9'8JB#8M-F%V*<@V*_8L2`B)7,B(-F$V+K9B"#9AMBTV*_9
MAR#8J-F(V*\`V+39A=BG(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K]BQ("(E
M<R(@V+G8MMF((-BTV*_;C-BO`-BYV+;9B-N,V*H@V+39A=BG(-BHV*<@V879
MB-F!V9'9@MN,V9'8JB#8I]BR("(E<R(@V838NMF((-BTV*\`V8;8M-BSV*H@
M)7,@V+39A=BG(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8JBX@V838M]F!V*?9
MBR#8K]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,V*\`V*+8K]BQV+,@V*?9
MA-JIV*K8L=F(V8;;C-JIVXP@V+39A=BG`-BBV*_8L=BS(-F!V+'8L]BJV8;8
MK]F'.B#8M-F%V*<Z`-BGV+?9A-BGV+G8I]BJ(-BTV878IP#8HMBOV+'8LR#8
MI]N,V8;8JMBQV8;8JMN,(-BTV878IR#9AMBSV*C8JB#8J-F'(-BGV*C8JMBO
MV*?;C"#9AMBTV+/8JB`E<R#8M-F%V*<@V*K8NMN,VXS8L2#:J=BQV*_9AR#8
MI]BSV*HNV*C8L=BGVXP@V+'8N=BGVXS8JB#9A=BSV*?8IMF$(-BGV879AMN,
MV*K;C"#8J-BGVXS8KR#8K]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,V*\`
MV8;8I]F%(-BTV878IP#:J=F$VXS8K^*`C-F'V*?;C"#8N=F%V8C9A=N,+]BN
MV+79B-BUVXP@4$=0(-BTV878IP#:J=F$VXS8KR#8M-BNV+7;C"#8M-F%V*<`
MVJG9A-N,V*\@V+G9A=F(V87;C"#8M-F%V*<`V;[8I]BSV*X@V+39A=BG(-BH
MV8<Z(-BBV*_8L=BS(#QE;3XHV*?8KMBJVXS8I]BQVXPI/"]E;3X`VJ_9B-BG
MV8?;C-F'V*?;C"#:J=F$VXS8K^*`C-F'V*?;C"#8N=F%V8C9A=N,+]BNV+79
MB-BUVXP@4R]-24U%(-BTV878IP#8K=BSV*?8J-F'V*?;C"#8M-F%V*<Z`-BB
MV*_8L=BS(-F%V+/8JMBYV*?8L2#8M-F%V*<Z(#QE;3XHV*?8KMBJVXS8I]BQ
MVXS8C"#9A]BQ(-BBV*_8L=BS(-BQV*<@V*_8L2#;C-JI(-BNV+<@V*S8K]N,
MV*\@V8C8I]BQV*\@VJG9AMN,V*\I/"]E;3X`V+/8I]F%V*?9AMF'(-F^V+38
MJMN,V*C8I]F&(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#8M-F%V*<@V8'9A]BQ
MV+/8JB#:J=BQV*_9AB#:J=BGV+'8J-BQV*?9AB#8L=BG(-F^V+38JMN,V*C8
MI]F&VXP@V8;9A=N,XH",VJG9AMBOV(P@VXS8IR#8M-BGVXS8KR#8J-F&V*<@
MV*C9AR#8K]F$VXS9A"#8K]N,VJ_8L=N,(-BGVXS9AB#:J=BGV+$@V*?9AMBL
MV*?9A2#9AMF%VXSB@(S8M-F(V*\`V+C8I]F'V+$@V878L=F(V+':K]BQ(-BT
MV878IR#9AMBSV*C8JB#8J-F'(-BGV*C8JMBOV*?;C"#9AMBTV+/8JB`E<R#8
MM-F%V*<@V*K8NMN,VXS8L2#:J=BQV*_9AR#8I]BSV*HNV*C8L=BGVXP@V+'8
MN=BGVXS8JB#9A=BSV*?8IMF$(-BGV879AMN,V*K;C"#8J-BGVXS8KR#8K]F(
MV*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,V*\`V878L=F(V+':K]BQ(-BTV878
MIR#9AMF%V*?;C-BT(-BOV+'8KMBW(-BGVXS9AB#9AMF(V+D@V*K8M=F(VXS8
ML2#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9AMBO`-F%V+'9
MB-BQVJ_8L2#8M-F%V*<@V*?;C-F&(-F%V+38KMBUV8<@V+'8IR#9OMBTV*K;
MC-BHV*?9AMN,(-F&V87;C.*`C-JIV8;8KRX`V++9A=BGV88@V8'8N=F$VXP@
MV879AMBWV8+9AR#8K-BZV+'8I]F!VXS8I]N,VXP@V+39A=BG.@#9A=BLV879
MB-BYV8<@V8;9B-N,V+/9A]F4(-F^VXS8M"#9@=BQV+8@V+39A=BG(-BHV+'8
MI]N,(-BGV+'8L]BGV80@V;[;C-BZV*?9A=F'V*<Z`-BTVXS9B-F'V90@V+'9
MA=BRV*C9AMBOVXP@V;[;C-BT(-F!V+'8MB#8M-F%V*<@V*C8L=BGVXP@V*?8
ML=BSV*?9A"#9OMN,V+K8I]F%.@#9A]F(VXS9D=BJ(-F^VXS8M"#9@=BQV+8@
MV+39A=BG.@#9AMBGV84@VJG8I]F%V80@V+39A=BG.@#9B-BQV8C8KR#8M-F%
MV*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ`-F^VXS8NMBGV84@V+39A=BG
M(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]BQV+/8I]F$(-BTV*\`V*?8L]F%
M(-BQV878LB`@V*S8K]N,V*\@V+39A=BG(-BHV+'8I]N,("5S(-F'V+/8JCH@
M)7,`VJ_8LMN,V8;9A^*`C-F'V*?;C"#8M-F%V*<@V*C8L=BGVXP@V+?9B-F$
M(-BGVXS9AB#9AMBTV+/8JB#8J-BQV8C8LMBQV+/8I]F&VXP@V+38K]F'(-BG
MV+/8JB``VJ_8LMN,V8;9A^*`C-F'V*?;C"#8M-F%V*<@V*C8L=F(V++8L=BS
MV*?9AMN,(-BTV*_9AR#8I]BSV*H`V*?8L]F%(-BQV878LB`@V+39A=BG(-BH
MV*?8LMF&V+38I]F&VXP@V+38K]F'(-BGV+/8J@#8I]BSV84@V+'9A=BR(-BT
MV878IR#8J-BGV++9AMBTV*?9AMN,(-BTV*_9AR#8I]BSV*K8C"#9OMBSV*H@
MV*?9A-JIV*K8L=F(V8;;C-JI(-BNV8C8KR#8L=BG(-J&VJD@VJG9AMN,V*\@
MV8@@V*C8IR#8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-BNV8C8KR#9B-BGV+'8
MKR#8M-F(VXS8KP#8I]BSV84@V+'9A=BR("#8M-F%V*<@V879AMF"V+;;C"#8
MM-BOV8<@V*?8L]BJ`-JIV*?8L=BSV*?8LN*`C-F'V*?;C"#8L=BGV8?B@(S8
MK]F(V+$@V+39A=BG.@#8I]F%V+;8I]N,(-BTV878ISH`6]F^V8;9A]BGV88@
MVJG8L=BOV88@V878JMF&(-F&V8+9A"#9@MF(V80@V+38K]F'70!;V*C8K]F(
MV88@V+G9AMF(V*?9AET`6]JOV++8I]BQV+0@V878M-JIV81=(`!;V8;9A=BG
MVXS8M"#9A=BJV88@V8;9@MF$(-F"V8C9A"#8M-BOV8<@+0#9AMF%V*?;C-BT
M(-F%V*K9AB#9AMF"V80@V8+9B-F$(-BTV*_9AUL@+2`E<R#8KMBW70!;V*[8
MMR`E<R#8I]BR("5S(%T@`-BSV+'9OMBQV+/8JMN,`-BQV8C9AMF(V+38JB#9
MA=BNV8';C`#9@=F'V+'8L]BJ(-BSVXS8I]F'`$-,20#8L=F(V8;9B-BTV*H`
MV*_8L=BNV*H@V*_8I]BOV8<`V*W8L-F!`-BMV+#9@2#8L]BWV+$`V;[9B-BT
MV8<F(W@R,#!C.]F'V*<`VJ_8L=F(V8<F(W@R,#!C.]F'V*<`V+'8I]F'V8;9
MA=BG`-BGV+(`V*[8M=F(V+7;C-BGV*H@V*K8M=F(VXS8L2XN+@!);F)O>`#9
MB-BQV8C8KP#8KMBQV8C8K`#8L]BQVH;8M-F%V8<@V;[;C-BZV*?9A0#8JMBZ
MVXS;C-BQ(-F^VXS9B-F&V*\N+BX`VJ_8LMN,V8;9A^*`C-F'V*<`V878K-F(
MV++9A]BG`-J&V*?9O@#8I]F(V839B-N,V*H`V*C8I]BRV*+9B-BQVXP@)7,`
MV*W8L-F!(-F^VXS9B-F&V*\N+BX`V;[8I]BSV*X`V*S8L]BJV*S9B`#9@=BQ
MV+/8JMBGV*_9AB#9OMN,V+K8I]F%`-BQV*?9AR8C>#(P,&,[V*?9AMBOV*?8
MLMN,`-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$+BXN`-BSV838L]F$V8<`V*C9
MAP#8J-BGV++;C-BGV*C;C`#:J=BGV+'8J-BQV*?9A@#9AMF%V*?;C-BT(-BS
MV838L]F$V8<`V8'9A]BQV+/8JB#8L]F!VXS8KP#:J=BJV*?8J-J&V8?9E"#8
MHMBOV+'8LR``V;[;C-F(V+/8J@#9OMN,V8C8L]BJV8?8IRYZ:7``V*C8I]N,
MV*KB@(P`V*K9@MF(VXS9A0#8HMBQV*?9A0#8I]N,V8;8K-BG(-BQV*<@V8'8
MM-BGV+$@V*_9A]N,V*\`V;[8L=F(V8;8K]F'`-BGV+(`V*?8LB`E<R`H)7,I
M(-BOV+$@)7,@)7,`V*C8I]BO`&@Z`-F!V8C8L=BGV8L`V*_8L=BNV+<`VJG9
MA-N,V*\`V*[8M]F(V+==`-F^V+'9B-F&V*_9A]F4XH",(-F&V*?9A=F'XH",
MV*_8I]F&`-F&V*?9A0#9A]N,VH;B@(S;C-JI`-F^VXS8I]BOV8<@V+/8I]BR
MVXP@V8;8M-BOV8<`V8?9AMF(V+(@V;[;C-BGV*_9AR#8L]BGV++;C"#9AMBT
MV*_9AR#8I]BSV*H`;F]T97!A9`#;C-BG`-BOV+'8M=BO`-F^VXS:J=BSV839
MA]BG`-BWV839B-BY`-F&V878I]N,V+0@V*K9@=BGV8C8JMF'V*<`V*[8M]BG
MVXP@V*?9A=F$V*?;C-N,`-BNV+?8I]F'V*?;C"#8I]F%V838I]N,VXP`V;[;
MC.*`C-BOV+'9OMN,`-BNV+?8I]N,(-BSV*?9A=BGV8;9AP#9@=F'V+'8L]BJ
M(-F(V+C;C-F!V8<`V+3:J=BSV*H@V879B-F"V*K;C`#8I]BSV84@V+'9A=BR
M(-BQV*<@V*C8L=BGVXP@V*K8H]N,VXS8KR#8K]F(V*C8I]BQ(-F(V*?8L=BO
M(-JIV8;;C-BO`-N,VJ_8I]F&V8<@V+38K]F'`-BHVXP@V8;8I]F%`-BGV8;8
MJMBNV*?8J"#:J=BGV+'8J-BQ`'9#87)D`'<Z`'=E871H97(N8V]M`-F!V8?8
ML=BSV*H@V+/;C-BGV8<@V+39A=BG`-F!V8?8L=BSV*H@V+/9@=N,V*\@V+39
MA=BG````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]L;V-A;&4O9F%?25(O:&5L<"YX;6P`````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`T,C$V-#8`,3`T,3<S-C(W-C``,#(Q,3$R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_>&UL('9E
M<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:6UP+VQO8V%L92]F85])4B]H
M96QP+GAM;"QV(#$N,2XR+C4@,C`P-B\P,2\S,"`Q-3HU.#HP,B!J86X@17AP
M("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UB=71T;VYS(B!M
M9#4](C,R-3EB83`P83$Y.#4U.6,W9F%A-S9E-S@V-S8P,&0Y(B!S=&%T93TB
M=7!T;V1A=&4B/@H@(#QT:71L93XF(W@V,C<[)B-X-C1!.R8C>#8R0SLF(W@V
M,C<[)B-X-C)&.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U
M.R`Z("8C>#8S.3LF(W@V-#4[)B-X-C0T.R8C>#8T03LF(W@V,C<[)B-X-C)!
M.SPO=&ET;&4^(`H@(#QH96%D:6YG/B8C>#8S.3LF(W@V-#4[)B-X-C0T.R8C
M>#8T03LF(W@V,C<[)B-X-C)!.SPO:&5A9&EN9SX@"B`@/'!A<F$^(B8C>#8R
M-SLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8W13LF(W@V-$$[
M)B-X-C-!.R8C>#8R-SLF(W@V-#4[(B`F(W@V,$,[("8C>#8R-SLF(W@V,S([
M("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V,S<[)B-X-C,Q.R8C>#8T03LF
M(W@V-#([("8C>#8T-3LF(W@V0T,[)B-X,C`P0SLF(W@V,D$[)B-X-C0X.R8C
M>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8R1CL@)B-X-C=%.R8C>#8T03LF(W@V
M,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C)%
M.R8C>#8T.#LF(W@V,D8[("8C>#8S,3LF(W@V,C<[("8C>#8R.#LF(W@V-#<[
M("8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C>#8T-CLF(W@V,D8[)B-X,C`P0SLF
M(W@V048[)B-X-C(W.R8C>#8T-CL@)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X
M-C(W.R8C>#8T-#L@)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T
M03LF(W@V,D8[("8C>#8R-SLF(W@V-#4[)B-X-C(W.R`F(W@V-#4[)B-X-D-#
M.R8C>#(P,$,[)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C,S.R8C>#8R03L@
M)B-X-C0R.R8C>#8R.#LF(W@V-#0[("8C>#8R-SLF(W@V,S([("8C>#8R-SLF
M(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8R-SLF(W@V,S([("8C
M>#8R,CLF(W@V-#8[)B-X-C@V.R8C>#8T-SL@)B-X-D$Y.R8C>#8T-SL@)B-X
M-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#L@)B-X-C0U.R8C>#9#
M0SLF(W@R,#!#.R8C>#9!1CLF(W@V,S$[)B-X-C)&.R8C>#8R1CL@)B-X-C(W
M.R8C>#8S-SLF(W@V-#4[)B-X-C1!.R8C>#8T-CLF(W@V,C<[)B-X-C0V.R`F
M(W@V03D[)B-X-C(W.R8C>#8T,3LF(W@V0T,[("8C>#9!.3LF(W@V,S,[)B-X
M-C(X.R`F(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R
M1CL@)B-X-C,R.R8C>#8T03LF(W@V,S$[)B-X-C(W.R`F(W@V,C<[)B-X-C1!
M.R8C>#8T-CL@)B-X-C,Y.R8C>#8T-3LF(W@V-#0[("8C>#8R.#LF(W@V,S$[
M)B-X-D%&.R8C>#8S-#LF(W@V,D$[("8C>#8W13LF(W@V,S`[)B-X-C1!.R8C
M>#8S,3L@)B-X-C0V.R8C>#8T03LF(W@V,S,[)B-X-C)!.RX\+W!A<F$^(`H@
M(#QP87)A/B(F(W@V,S`[)B-X-C)%.R8C>#8T03LF(W@V,S$[)B-X-C0W.R`F
M(W@V-T4[)B-X-C1!.R8C>#8S-#L@)B-X-C0V.R8C>#8T.#LF(W@V-$$[)B-X
M-C,S.R(@)B-X-C!#.R`F(W@V-#([)B-X-C,Q.R8C>#8R-SLF(W@V,S$[)B-X
M-C)&.R8C>#8R-SLF(W@V,D8[)B-X-C0V.R`F(W@V-T4[)B-X-C1!.R8C>#8S
M03LF(W@V,C<[)B-X-C0U.R8C>#9#0SL@)B-X-D$Y.R8C>#8T-SL@)B-X-C(W
M.R8C>#8T03LF(W@V,D,[)B-X-C(W.R8C>#8R1CL@)B-X-C(R.R8C>#8T-CL@
M)B-X-C)%.R8C>#8R-SLF(W@V,D$[)B-X-C0U.R8C>#8T-SL@)B-X-C0V.R8C
M>#8T03LF(W@V,C<[)B-X-C0Q.R8C>#8R03LF(W@V-#<[("8C>#8R-SLF(W@V
M,S,[)B-X-C)!.R`F(W@V,D8[)B-X-C,Q.R`F(W@V-T4[)B-X-C0X.R8C>#8S
M-#LF(W@V-#<[)B-X,C`P0SLF(W@V,C<[)B-X-C1!.R8C>#8T03L@)B-X-C(X
M.R8C>#8T-SL@)B-X-C0V.R8C>#8R-SLF(W@V-#4[(")D<F%F=',B("X@)B-X
M-C0T.R8C>#8S-SLF(W@V-#$[)B-X-C(W.R8C>#8U,CL@)B-X-C0R.R8C>#8R
M.#LF(W@V-#0[("8C>#8R-SLF(W@V,S([("8C>#8R1#LF(W@V-#$[)B-X-C,X
M.R`F(W@V-T4[)B-X-C1!.R8C>#8S-#LF(W@R,#!#.R8C>#8T-CLF(W@V-#@[
M)B-X-C1!.R8C>#8S,SL@)B-X-C0V.R8C>#8R-SLF(W@V-#4[)B-X-D-#.R`F
M(W@V,D8[)B-X-C,Q.R`F(W@V,SD[)B-X-C0V.R8C>#8T.#LF(W@V,C<[)B-X
M-C0V.R`F(W@V,C([)B-X-C0V.R`F(W@V-#([)B-X-C,Q.R8C>#8R-SLF(W@V
M,S$[("8C>#8R1CLF(W@V-#<[)B-X-C1!.R8C>#8R1CL@)B-X-C)!.R8C>#8R
M-SL@)B-X-C)!.R8C>#9!.3LF(W@V-#4[)B-X-C1!.R8C>#8T-#L@)B-X-C(R
M.R8C>#8T-CL@)B-X-C,Q.R8C>#8R-SLF(W@V,D0[)B-X-C)!.R8C>#(P,$,[
M)B-X,C`P0SLF(W@V,D$[)B-X-C,Q.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF
M(W@V,D$[("8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C>#8R1CLN("8C>#8R-SLF
M(W@V-$$[)B-X-C0V.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[("8C
M>#8R-SLF(W@V,S([("8C>#8S-SLF(W@V,S$[)B-X-C1!.R8C>#8T,CL@)B-X
M-D%&.R8C>#8S,CLF(W@V-$$[)B-X-C0V.R8C>#8T-SLF(W@R,#!#.R8C>#8T
M-SLF(W@V,C<[)B-X-D-#.R`F(W@V048[)B-X-C,T.R8C>#8T.#LF(W@V,D8[
M)B-X-C0V.R8C>#9#0SL@)B-X-C(X.R8C>#8R-SLF(W@V,S([)B-X-D$Y.R8C
M>#8S,3LF(W@V,D8[)B-X-C0V.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V
M-#<[)B-X-C!#.R`F(W@V-#4[)B-X-C0X.R8C>#8R0SLF(W@V-#@[)B-X-C)&
M.R`F(W@V,D8[)B-X-C,Q.R`F(W@V,C@[)B-X-C(W.R8C>#8T-#LF(W@V,C<[
M)B-X-D-#.R`F(W@V,S,[)B-X-C0U.R8C>#8R03L@)B-X-C,Q.R8C>#8R-SLF
M(W@V,S,[)B-X-C)!.R`F(W@V,S4[)B-X-C0Q.R8C>#8R1#LF(W@V-#<[)B-X
M-C!#.R`F(W@V-#([)B-X-C(W.R8C>#8R.#LF(W@V-#0[("8C>#8R-SLF(W@V
M-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V,C<[)B-X-C,S
M.R8C>#8R03LN("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V-#4[)B-X-D-#
M.R8C>#(P,$,[)B-X-C)!.R8C>#8T.#LF(W@V,C<[)B-X-C0V.R8C>#8T03LF
M(W@V,D8[("8C>#8R.#LF(W@V,C<[("8C>#8S,3LF(W@V-#$[)B-X-C)!.R8C
M>#8T-CL@)B-X-C(X.R8C>#8T-SL@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C
M>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SL@)B-X-C0X.R`F(W@V,C@[)B-X
M-C(W.R8C>#8S,CL@)B-X-D$Y.R8C>#8S,3LF(W@V,D8[)B-X-C0V.R`F(W@V
M-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V-#4[)B-X-C0X
M.R8C>#8S,3LF(W@V,D8[("8C>#8T-CLF(W@V,S@[)B-X-C,Q.R8C>#8P0SL@
M)B-X-C(R.R8C>#8T-CLF(W@V,S$[)B-X-C(W.R`F(W@V,D$[)B-X-D$Y.R8C
M>#8T-3LF(W@V-$$[)B-X-C0T.R`F(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V
M-$$[)B-X-C1!.R8C>#8R1CLN/"]P87)A/B`*("`\=&EP/B8C>#8R.#LF(W@V
M,S,[)B-X-C)!.R8C>#8T-SL@)B-X-C(X.R8C>#8T-SL@)B-X-C0V.R8C>#8T
M.#LF(W@V,SD[("8C>#8T-CLF(W@V,S4[)B-X-C(X.R8C>#8P0SL@)B-X-C,T
M.R8C>#8T-3LF(W@V,C<[("8C>#8T-3LF(W@V0T,[)B-X,C`P0SLF(W@V,D$[
M)B-X-C0X.R8C>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8R1CL@)B-X-C)!.R8C
M>#8S,3LF(W@V,D,[)B-X-C1!.R8C>#8R1#L@)B-X-C)%.R8C>#8T.#LF(W@V
M,D8[("8C>#8S,3LF(W@V,C<[("8C>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#9#
M0SL@)B-X-C(X.R8C>#8R-SLF(W@V,S([)B-X-D%&.R8C>#8S-#LF(W@V,D$[
M("8C>#8R.#LF(W@V-#<[("8C>#8R,CLF(W@V,D4[)B-X-C,Q.R8C>#8T03LF
M(W@V-#8[("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SLF(W@V-30[("8C
M>#8T-3LF(W@V,S0[)B-X-C(W.R8C>#8T-SLF(W@V,D8[)B-X-C0W.R`F(W@V
M,S0[)B-X-C)&.R8C>#8T-SL@)B-X-C0X.R`F(W@V-$$[)B-X-C(W.R`F(W@V
M-#4[)B-X-C,T.R8C>#8R-SLF(W@V-#<[)B-X-C)&.R8C>#8T-SL@)B-X-C0W
M.R8C>#8T-3LF(W@V,C<[)B-X-C0V.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF
M(W@V,C<[)B-X-C0U.R8C>#9#0SL@)B-X-D$Y.R8C>#8T-SL@)B-X-C=%.R8C
M>#8T03LF(W@V,S0[)B-X,C`P0SLF(W@V-#8[)B-X-C0X.R8C>#8T03LF(W@V
M,S,[("8C>#8R,CLF(W@V-#8[)B-X-C,Q.R8C>#8R-SL@)B-X-C)$.R8C>#8T
M,3LF(W@V,S@[("8C>#9!.3LF(W@V,S$[)B-X-C)&.R8C>#8T-SLF(W@R,#!#
M.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V,C@[)B-X-C,Y.R8C>#8R1CL@
M)B-X-C(W.R8C>#8S,CL@)B-X-C(W.R8C>#8T-CLF(W@V,D,[)B-X-C(W.R8C
M>#8T-3L@)B-X-C,Y.R8C>#8T-3LF(W@V-#0[("8C>#8S,#LF(W@V,D4[)B-X
M-C1!.R8C>#8S,3LF(W@V-#<[("8C>#8S,SLF(W@V,C<[)B-X-C,R.R8C>#9#
M0SLF(W@V,$,[("8C>#8R03LF(W@V,SD[)B-X-C1!.R8C>#8T03LF(W@V-#8[
M("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&.RX\
M+W1I<#X@"B`@/'!A<F$^(B8C>#8R-SLF(W@V-#8[)B-X-C,U.R8C>#8S,3LF
M(W@V,C<[)B-X-C0Q.R`F(W@V,C<[)B-X-C,R.R`F(W@V,C<[)B-X-C,Q.R8C
M>#8S,SLF(W@V,C<[)B-X-C0T.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V
M,C<[)B-X-C0U.R(@)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T
M-#L@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@)B-X-C,Q
M.R8C>#8R-SL@)B-X-C0U.R8C>#8T-#LF(W@V,T$[)B-X-D-#.R`F(W@V-#8[
M)B-X-C0U.R8C>#8T.#LF(W@V,D8[)B-X-C0W.R`F(W@V-#@[("8C>#8S-#LF
M(W@V-#4[)B-X-C(W.R`F(W@V,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C0W.R`F
M(W@V,C([)B-X-C)%.R8C>#8S,3LF(W@V-$$[)B-X-C0V.R`F(W@V-T4[)B-X
M-C0X.R8C>#8S-#LF(W@V-#<[)B-X,C`P0SLF(W@V,C<[)B-X-C1!.R8C>#8T
M03L@)B-X-D$Y.R8C>#8T-SL@)B-X-C)&.R8C>#8S,3L@)B-X-C)$.R8C>#8R
M-SLF(W@V-#0[("8C>#8T-3LF(W@V,S0[)B-X-C(W.R8C>#8T-SLF(W@V,D8[
M)B-X-C0W.R`F(W@V,C([)B-X-C0V.R`F(W@V,C@[)B-X-C0X.R8C>#8R1CLF
M(W@V-#<[)B-X,C`P0SLF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C
M>#8S,3LF(W@V-#4[)B-X-D-#.R8C>#(P,$,[)B-X-D%&.R8C>#8S,3LF(W@V
M,D8[)B-X-C(W.R8C>#8T-CLF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB(&UD-3TB.#)C9C(T9#,Q838V-V$U
M8CDT930X,6-D-3$W.6,U,CDB('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE
M/B8C>#8R-SLF(W@V-$$[)B-X-C)#.R8C>#8R-SLF(W@V,D8[("8C>#8W13LF
M(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[(#H@)B-X-C0Q.R8C>#8S,3LF
M(W@V,S,[)B-X-C)!.R8C>#8T-CLF(W@V,D8[)B-X-C0W.SPO=&ET;&4^(`H@
M(#QH96%D:6YG/B8C>#8T,3LF(W@V,S$[)B-X-C,S.R8C>#8R03LF(W@V-#8[
M)B-X-C)&.R8C>#8T-SL\+VAE861I;F<^(`H@(#QP87)A/B8C>#8R-SLF(W@V
M048[)B-X-C,Q.R`F(W@V,D$[)B-X-C0X.R8C>#8S,SLF(W@V,S<[("8C>#8S
M,SLF(W@V,S$[)B-X-C=%.R8C>#8S,3LF(W@V,S,[)B-X-C)!.R`F(W@V,S,[
M)B-X-C(W.R8C>#8T-3LF(W@V,C<[)B-X-C0V.R8C>#8T-SLF(W@V-30[("8C
M>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V,C<[)B-X-C)#.R8C>#8R-SLF(W@V
M,S([)B-X-C0W.R`F(W@V,D8[)B-X-C(W.R8C>#8R1CLF(W@V-#<[("8C>#8S
M-#LF(W@V-#@[)B-X-C)&.R8C>#8P0SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[
M("8C>#8T-3LF(W@V0T,[)B-X,C`P0SLF(W@V,D$[)B-X-C0X.R8C>#8R-SLF
M(W@V-#8[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X
M-D-#.R`F(W@V-T4[)B-X-C,Q.R`F(W@V03D[)B-X-C,Q.R8C>#8R1CLF(W@V
M-#8[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V-#$[)B-X-C1!.R8C>#8T
M-#LF(W@V,D8[("8C>#8R-SLF(W@V,S([("8C>#8T,3LF(W@V-#<[)B-X-C,Q
M.R8C>#8S,SLF(W@V,D$[("8C>#9!1CLF(W@V,S0[)B-X-C0X.R8C>#8R1CLF
M(W@V-#8[)B-X-D-#.R`F(W@V,C<[)B-X-C,S.R8C>#8R03LF(W@V-#$[)B-X
M-C(W.R8C>#8R1CLF(W@V-#<[("8C>#9!.3LF(W@V,S$[)B-X-C)&.R8C>#8T
M-SL@)B-X-C0X.R`F(W@V-$$[)B-X-D$Y.R8C>#9#0SL@)B-X-C(W.R8C>#8S
M,CL@)B-X-C0W.R8C>#8T.#LF(W@V-$$[)B-X-C)!.R8C>#8T-SLF(W@V,C<[
M)B-X-C1!.R8C>#8T03L@)B-X-C,Q.R8C>#8R-SL@)B-X-D$Y.R8C>#8T-SL@
M)B-X-C)&.R8C>#8S,3L@)B-X-C(X.R8C>#8R13LF(W@V,S0[("8C>#9!1CLF
M(W@V,S([)B-X-C1!.R8C>#8T-CLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X
M-C(W.R8C>#9#0SL@)B-X-C(W.R8C>#8S-SLF(W@V-#0[)B-X-C(W.R8C>#8S
M.3LF(W@V,C<[)B-X-C)!.R`F(W@V,S0[)B-X-C)%.R8C>#8S-3LF(W@V0T,[
M("8C>#8T.#LF(W@V,C<[)B-X-C,Q.R8C>#8R1CL@)B-X-D$Y.R8C>#8S,3LF
M(W@V,D8[)B-X-C0W.R8C>#(P,$,[)B-X-C(W.R8C>#8T03LF(W@V,D8[("8C
M>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V
M-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CL@)B-X-C0X
M.R`F(W@V-$$[)B-X-C(W.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CLF(W@V03D[
M)B-X-C0W.R`F(W@V,C([)B-X-C)&.R8C>#8S,3LF(W@V,S,[("8C>#8R13LF
M(W@V-#@[)B-X-C)&.R`F(W@V,S$[)B-X-C(W.R`F(W@V,D8[)B-X-C,Q.R`F
M(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C0Q.R8C>#8T03LF(W@V-#0[)B-X
M-C)&.R`F(W@V,D8[)B-X-C,Q.R8C>#8R0SL@)B-X-C0V.R8C>#8T-3LF(W@V
M,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+71O(B!M9#4](C,Q8V)A,3=F,38Y-3<R8S,V
M-V%A.#`Q-#@S,65B.&8X(B!S=&%T93TB=7!T;V1A=&4B/@H@(#QT:71L93XF
M(W@V,C<[)B-X-C1!.R8C>#8R0SLF(W@V,C<[)B-X-C)&.R`F(W@V-T4[)B-X
M-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`Z("8C>#8R.#LF(W@V-#<[/"]T
M:71L93X@"B`@/&AE861I;F<^5&\\+VAE861I;F<^(`H@(#QP87)A/B8C>#8R
M1CLF(W@V,S$[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V-#$[)B-X-C1!
M.R8C>#8T-#LF(W@V,D8[("8C>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#9#0SL@
M)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#L@)B-X-C,U.R8C
M>#8R1#LF(W@V-$$[)B-X-C)$.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V
M,C<[)B-X-C0U.R`F(W@V,C@[)B-X-C0W.R`F(W@V-$$[)B-X-D$Y.R`F(W@V
M048[)B-X-C1!.R8C>#8S,3LF(W@V-#8[)B-X-C)&.R8C>#8T-SLF(W@V,$,[
M("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V,C@[)B-X-C(W.R8C>#8T03LF
M(W@V,D8[("8C>#8R,CLF(W@V,D8[)B-X-C,Q.R8C>#8S,SLF(W@V-#<[)B-X
M-C(W.R8C>#9#0SL@)B-X-C=%.R8C>#8S,SLF(W@V,D$[("8C>#8R-SLF(W@V
M-#0[)B-X-D$Y.R8C>#8R03LF(W@V,S$[)B-X-C0X.R8C>#8T-CLF(W@V-$$[
M)B-X-D$Y.R8C>#9#0SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(X.R8C>#8T-SL@
M)B-X-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V,S4[)B-X-C)$.R8C
M>#8T03LF(W@V,D0[("8C>#8T.#LF(W@V,C<[)B-X-C,Q.R8C>#8R1CL@)B-X
M-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[+B`F(W@V
M-#<[)B-X-C0U.R8C>#8X-CLF(W@V-#8[)B-X-C1!.R8C>#8T-CL@)B-X-C)&
M.R8C>#8S,3L@)B-X-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V-#@[
M)B-X-C(W.R8C>#8S,3LF(W@V,D8[("8C>#9!.3LF(W@V,S$[)B-X-C)&.R8C
M>#8T-CL@)B-X-C(X.R8C>#8T03LF(W@V,S0[("8C>#8R-SLF(W@V,S([("8C
M>#8T03LF(W@V03D[("8C>#8R,CLF(W@V,D8[)B-X-C,Q.R8C>#8S,SLF(W@V
M,$,[("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C(R.R8C>#8R
M1CLF(W@V,S$[)B-X-C,S.R8C>#8T-SLF(W@V,C<[("8C>#8S,3LF(W@V,C<[
M("8C>#8R.#LF(W@V,C<[("8C>#8T-CLF(W@V-#@[)B-X-C1!.R8C>#8S,SLF
M(W@V-#<[)B-X-C4T.R`F(W@V03D[)B-X-C(W.R8C>#8T-3LF(W@V,C<[("8C
M>#8R-SLF(W@V,S([("8C>#8T03LF(W@V03D[)B-X-C)&.R8C>#8T03LF(W@V
M048[)B-X-C,Q.R`F(W@V,D,[)B-X-C)&.R8C>#8R-SL@)B-X-D$Y.R8C>#8T
M-CLF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UC8R(@;60U/2(Y-S4W,30S,V%B,#,W968Y8S1D,3`Q834V
M8F8W-&4R-2(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^)B-X-C(W.R8C
M>#8T03LF(W@V,D,[)B-X-C(W.R8C>#8R1CL@)B-X-C=%.R8C>#8T03LF(W@V
M,T$[)B-X-C(W.R8C>#8T-3L@.B`F(W@V,S$[)B-X-C0X.R8C>#8T-CLF(W@V
M-#@[)B-X-C,T.R8C>#8R03L\+W1I=&QE/B`*("`\:&5A9&EN9SXF(W@V,S$[
M)B-X-C0X.R8C>#8T-CLF(W@V-#@[)B-X-C,T.R8C>#8R03L\+VAE861I;F<^
M(`H@(#QP87)A/B8C>#8R1CLF(W@V,S$[("8C>#8R-SLF(W@V-$$[)B-X-C0V
M.R`F(W@V-#$[)B-X-C1!.R8C>#8T-#LF(W@V,D8[("8C>#8R.#LF(W@V,S$[
M)B-X-C(W.R8C>#9#0SL@)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C
M>#8T-#L@)B-X-C,U.R8C>#8R1#LF(W@V-$$[)B-X-C)$.R`F(W@V,S$[)B-X
M-C0X.R8C>#8T-CLF(W@V-#@[)B-X-C,T.R8C>#8R03LF(W@V0T,[("8C>#8R
M-SLF(W@V,S([("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[
M("8C>#8R.#LF(W@V-#<[("8C>#8T03LF(W@V03D[("8C>#9!1CLF(W@V-$$[
M)B-X-C,Q.R8C>#8T-CLF(W@V,D8[)B-X-C0W.R`F(W@V,D8[)B-X-C1!.R8C
M>#9!1CLF(W@V,S$[)B-X-C!#.R`F(W@V,C@[)B-X-C(W.R8C>#8T03LF(W@V
M,D8[("8C>#8R,CLF(W@V,D8[)B-X-C,Q.R8C>#8S,SLF(W@V-#<[)B-X-C(W
M.R8C>#9#0SL@)B-X-C=%.R8C>#8S,SLF(W@V,D$[("8C>#8R-SLF(W@V-#0[
M)B-X-D$Y.R8C>#8R03LF(W@V,S$[)B-X-C0X.R8C>#8T-CLF(W@V-$$[)B-X
M-D$Y.R8C>#9#0SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X
M-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V,S4[)B-X-C)$.R8C>#8T
M03LF(W@V,D0[("8C>#8T.#LF(W@V,C<[)B-X-C,Q.R8C>#8R1CL@)B-X-C0V
M.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[+B`F(W@V-#<[
M)B-X-C0U.R8C>#8X-CLF(W@V-#8[)B-X-C1!.R8C>#8T-CL@)B-X-C)&.R8C
M>#8S,3L@)B-X-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V-#@[)B-X
M-C(W.R8C>#8S,3LF(W@V,D8[("8C>#9!.3LF(W@V,S$[)B-X-C)&.R8C>#8T
M-CL@)B-X-C(X.R8C>#8T03LF(W@V,S0[("8C>#8R-SLF(W@V,S([("8C>#8T
M03LF(W@V03D[("8C>#8R,CLF(W@V,D8[)B-X-C,Q.R8C>#8S,SLF(W@V,$,[
M("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C(R.R8C>#8R1CLF
M(W@V,S$[)B-X-C,S.R8C>#8T-SLF(W@V,C<[("8C>#8S,3LF(W@V,C<[("8C
M>#8R.#LF(W@V,C<[("8C>#8T-CLF(W@V-#@[)B-X-C1!.R8C>#8S,SLF(W@V
M-#<[)B-X-C4T.R`F(W@V03D[)B-X-C(W.R8C>#8T-3LF(W@V,C<[("8C>#8R
M-SLF(W@V,S([("8C>#8T03LF(W@V03D[)B-X-C)&.R8C>#8T03LF(W@V048[
M)B-X-C,Q.R`F(W@V,D,[)B-X-C)&.R8C>#8R-SL@)B-X-D$Y.R8C>#8T-CLF
M(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H@(#QP87)A/B8C>#8S,3LF(W@V-#@[
M)B-X-C0V.R8C>#8T.#LF(W@V,S0[)B-X-C)!.R8C>#(P,$,[)B-X-C0W.R8C
M>#8R-SL@)B-X-C0U.R8C>#8S.3LF(W@V-#4[)B-X-C0X.R8C>#8T-#LF(W@V
M,C<[("8C>#8R.#LF(W@V-#<[("8C>#8R-SLF(W@V-#$[)B-X-C,Q.R8C>#8R
M-SLF(W@V,D8[)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[
M)B-X-C0T.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C,T.R8C>#8T.#LF
M(W@V-#8[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F(W@V-#8[)B-X-C1!.R8C
M>#8R-SLF(W@V,S([)B-X-D-#.R`F(W@V,C@[)B-X-C0W.R`F(W@V,C<[)B-X
M-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R`F(W@V-#4[)B-X-C,S.R8C>#8R
M03LF(W@V-#([)B-X-C1!.R8C>#8T-3L@)B-X-C=%.R8C>#8T03LF(W@V,T$[
M)B-X-C(W.R8C>#8T-3L@)B-X-C(X.R8C>#8T-SL@)B-X-C(R.R8C>#8T-CLF
M(W@V-#<[)B-X-C(W.R`F(W@V-#8[)B-X-C1!.R8C>#8S,SLF(W@V,D$[)B-X
M-C!#.R`F(W@V,C@[)B-X-C0T.R8C>#9!.3LF(W@V-#<[("8C>#8R.#LF(W@V
M,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C)!.R8C>#8T-CLF(W@V-#<[)B-X-C(W
M.R`F(W@V,C<[)B-X-C,R.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[
M)B-X-C0T.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F
M(W@V,C<[)B-X-C,W.R8C>#8T-#LF(W@V,C<[)B-X-C,Y.R`F(W@V,D0[)B-X
M-C(W.R8C>#8S-3LF(W@V-#0[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T
M03LF(W@V-#8[)B-X-C)&.RX@)B-X-C0T.R8C>#8R-SLF(W@V,S([)B-X-C0U
M.R`F(W@V,C@[)B-X-C0W.R`F(W@V,D$[)B-X-C,P.R8C>#9!.3LF(W@V,S$[
M("8C>#8R-SLF(W@V,S,[)B-X-C)!.R`F(W@V03D[)B-X-C0W.R`F(W@V048[
M)B-X-C1!.R8C>#8S,3LF(W@V-#8[)B-X-C)&.R8C>#9!1CLF(W@V,C<[)B-X
M-C0V.R`F(W@V,C<[)B-X-C,U.R8C>#8T-#LF(W@V0T,[("8C>#8T.#L@)B-X
M-D%&.R8C>#8T03LF(W@V,S$[)B-X-C0V.R8C>#8R1CLF(W@V048[)B-X-C(W
M.R8C>#8T-CL@)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C0X.R8C>#8S-#LF
M(W@V,D$[("8C>#8R.#LF(W@V,C<[("8C>#8T-3LF(W@V,S0[)B-X-C(W.R8C
M>#8T-SLF(W@V,D8[)B-X-C0W.R8C>#8U-#L@)B-X-C0V.R8C>#8R-SLF(W@V
M-#4[)B-X-C0W.R8C>#8P0SL@)B-X-C(W.R8C>#8S,CL@)B-X-C1!.R8C>#9!
M.3LF(W@V,D8[)B-X-C1!.R8C>#9!1CLF(W@V,S$[("8C>#8R-SLF(W@V,S<[
M)B-X-C0T.R8C>#8R-SLF(W@V,SD[("8C>#8R1#LF(W@V,C<[)B-X-C,U.R8C
M>#8T-#L@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8T-CLF(W@V
M,D8[("8C>#8T-CLF(W@V-#4[)B-X-C0X.R8C>#8R1CLN/"]P87)A/B`*/"]E
M;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M8F-C(B!M9#4](F%A.&8Y93)D
M-#1F9&(W-&1E9C!F83$U,C0P9F8V.#=B(B!S=&%T93TB=7!T;V1A=&4B/@H@
M(#QT:71L93XF(W@V,C<[)B-X-C1!.R8C>#8R0SLF(W@V,C<[)B-X-C)&.R`F
M(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`Z("8C>#8S,3LF
M(W@V-#@[)B-X-C0V.R8C>#8T.#LF(W@V,S0[)B-X-C)!.R`F(W@V-#4[)B-X
M-C)%.R8C>#8T,3LF(W@V0T,[/"]T:71L93X@"B`@/&AE861I;F<^)B-X-C,Q
M.R8C>#8T.#LF(W@V-#8[)B-X-C0X.R8C>#8S-#LF(W@V,D$[("8C>#8T-3LF
M(W@V,D4[)B-X-C0Q.R8C>#9#0SL\+VAE861I;F<^(`H@(#QP87)A/B8C>#8R
M1CLF(W@V,S$[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V-#$[)B-X-C1!
M.R8C>#8T-#LF(W@V,D8[("8C>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#9#0SL@
M)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#L@)B-X-C,U.R8C
M>#8R1#LF(W@V-$$[)B-X-C)$.R`F(W@V,S$[)B-X-C0X.R8C>#8T-CLF(W@V
M-#@[)B-X-C,T.R8C>#8R03LF(W@V0T,[("8C>#8T-3LF(W@V,D4[)B-X-C0Q
M.R8C>#9#0SL@)B-X-C(W.R8C>#8S,CL@)B-X-C=%.R8C>#8T03LF(W@V,T$[
M)B-X-C(W.R8C>#8T-3L@)B-X-C(X.R8C>#8T-SL@)B-X-C1!.R8C>#9!.3L@
M)B-X-D%&.R8C>#8T03LF(W@V,S$[)B-X-C0V.R8C>#8R1CLF(W@V-#<[)B-X
M-C!#.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C(X.R8C>#8R-SLF(W@V
M-$$[)B-X-C)&.R`F(W@V,C([)B-X-C)&.R8C>#8S,3LF(W@V,S,[)B-X-C0W
M.R8C>#8R-SLF(W@V0T,[("8C>#8W13LF(W@V,S,[)B-X-C)!.R`F(W@V,C<[
M)B-X-C0T.R8C>#9!.3LF(W@V,D$[)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X
M-C1!.R8C>#9!.3LF(W@V0T,[("8C>#8S,3LF(W@V,C<[("8C>#8R.#LF(W@V
M-#<[("8C>#8S-3LF(W@V-#@[)B-X-C,Q.R8C>#8R03L@)B-X-C,U.R8C>#8R
M1#LF(W@V-$$[)B-X-C)$.R`F(W@V-#@[)B-X-C(W.R8C>#8S,3LF(W@V,D8[
M("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&.RX@
M)B-X-C0W.R8C>#8T-3LF(W@V.#8[)B-X-C0V.R8C>#8T03LF(W@V-#8[("8C
M>#8R1CLF(W@V,S$[("8C>#8S-3LF(W@V-#@[)B-X-C,Q.R8C>#8R03L@)B-X
M-C0X.R8C>#8R-SLF(W@V,S$[)B-X-C)&.R`F(W@V03D[)B-X-C,Q.R8C>#8R
M1CLF(W@V-#8[("8C>#8R.#LF(W@V-$$[)B-X-C,T.R`F(W@V,C<[)B-X-C,R
M.R`F(W@V-$$[)B-X-D$Y.R`F(W@V,C([)B-X-C)&.R8C>#8S,3LF(W@V,S,[
M)B-X-C!#.R`F(W@V,C@[)B-X-C(W.R8C>#8T03LF(W@V,D8[("8C>#8R,CLF
M(W@V-#8[)B-X-C0W.R8C>#8R-SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(X.R8C
M>#8R-SL@)B-X-C0V.R8C>#8T.#LF(W@V-$$[)B-X-C,S.R8C>#8T-SLF(W@V
M-30[("8C>#9!.3LF(W@V,C<[)B-X-C0U.R8C>#8R-SL@)B-X-C(W.R8C>#8S
M,CL@)B-X-C1!.R8C>#9!.3LF(W@V,D8[)B-X-C1!.R8C>#9!1CLF(W@V,S$[
M("8C>#8R0SLF(W@V,D8[)B-X-C(W.R`F(W@V03D[)B-X-C0V.R8C>#8T03LF
M(W@V,D8[+CPO<&%R83X@"B`@/'!A<F$^)B-X-C,Q.R8C>#8T.#LF(W@V-#8[
M)B-X-C0X.R8C>#8S-#LF(W@V,D$[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R8C
M>#9#0SL@)B-X-C0U.R8C>#8R13LF(W@V-#$[)B-X-D-#.R`F(W@V,SD[)B-X
M-C0U.R8C>#8T.#LF(W@V-#4[)B-X-C(W.R8C>#8U,CL@)B-X-C(X.R8C>#8T
M-SL@)B-X-C(W.R8C>#8T,3LF(W@V,S$[)B-X-C(W.R8C>#8R1CLF(W@V0T,[
M("8C>#8R-SLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8T-3LF
M(W@V-$$[)B-X,C`P0SLF(W@V048[)B-X-C,Q.R8C>#8R1CLF(W@V,D8[("8C
M>#9!.3LF(W@V-#<[("8C>#8T-#LF(W@V,C<[)B-X-C,R.R8C>#8T-3L@)B-X
M-C(W.R8C>#8S,SLF(W@V,D$[("8C>#8R-SLF(W@V,S([("8C>#8T-3LF(W@V
M-#$[)B-X-C(W.R8C>#8R1CL@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W
M.R8C>#8T-3L@)B-X-C(W.R8C>#8S-SLF(W@V-#0[)B-X-C(W.R8C>#8S.3L@
M)B-X-C1!.R8C>#8R-SLF(W@V,C@[)B-X-C0V.R8C>#8R1CL@)B-X-C0X.R8C
M>#8T-#LF(W@V0T,[("8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C>#8T-CLF(W@V
M,D8[)B-X-D%&.R8C>#8R-SLF(W@V-#8[("8C>#8R1CLF(W@V-$$[)B-X-D%&
M.R8C>#8S,3L@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@
M)B-X-C0V.R8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C(W.R8C
M>#8S,CL@)B-X-C)&.R8C>#8S,3LF(W@V-$$[)B-X-C(W.R8C>#8T,3LF(W@V
M,D$[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[("8C>#8R
M03LF(W@V-#@[)B-X-C,S.R8C>#8S-SL@)B-X-C(R.R8C>#8T-CLF(W@V-#<[
M)B-X-C(W.R`F(W@V,C<[)B-X-C,W.R8C>#8T-#LF(W@V,C<[)B-X-C,Y.R`F
M(W@V-$$[)B-X-C(W.R8C>#8R.#LF(W@V-#8[)B-X-C)&.RX\+W!A<F$^(`H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T(B!M9#4](C`V
M,SEA.#<Y,&4S,#9A8V,Y93$Y8C1D,6-E,S0R9#4S(B!S=&%T93TB=7!T;V1A
M=&4B/@H@(#QT:71L93XF(W@V,C<[)B-X-C1!.R8C>#8R0SLF(W@V,C<[)B-X
M-C)&.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`Z("8C
M>#8T-3LF(W@V-#@[)B-X-C,V.R8C>#8T.#LF(W@V,SD[/"]T:71L93X@"B`@
M/&AE861I;F<^)B-X-C0U.R8C>#8T.#LF(W@V,S8[)B-X-C0X.R8C>#8S.3L\
M+VAE861I;F<^(`H@(#QP87)A/B8C>#8R1CLF(W@V,S$[("8C>#8R-SLF(W@V
M-$$[)B-X-C0V.R`F(W@V-#$[)B-X-C1!.R8C>#8T-#LF(W@V,D8[("8C>#8T
M-3LF(W@V-#@[)B-X-C,V.R8C>#8T.#LF(W@V,SD[("8C>#8W13LF(W@V-$$[
M)B-X-C-!.R8C>#8R-SLF(W@V-#4[("8C>#8R1CLF(W@V,S$[)B-X-C)#.R`F
M(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-D%&.R8C>#8S,3LF(W@V,D8[)B-X
M-C)&.RX@)B-X-C0U.R8C>#8T.#LF(W@V,S8[)B-X-C0X.R8C>#8S.3L@)B-X
M-C0V.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R`F(W@V,C@[)B-X-C(W.R8C>#8T
M03LF(W@V,D8[("8C>#8S,SLF(W@V,C<[)B-X-C)&.R8C>#8T-SL@)B-X-C0X
M.R`F(W@V03D[)B-X-C0X.R8C>#8R03LF(W@V,C<[)B-X-C0W.R`F(W@V,C@[
M)B-X-C0X.R8C>#8R1CLF(W@V-#<[("8C>#8T.#L@)B-X-C0U.R8C>#8S.3LF
M(W@V,S$[)B-X-C0Q.R`F(W@V,C@[)B-X-C)&.R8C>#8T-CLF(W@V-#<[)B-X
M-C4T.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V
M,C@[)B-X-C(W.R8C>#8S-#LF(W@V,D8[("8C>#8S,CLF(W@V-$$[)B-X-C,Q
M.R8C>#8R-SL@)B-X-C)&.R8C>#8S,3L@)B-X-C(W.R8C>#8T03LF(W@V-#8[
M("8C>#8S-3LF(W@V-#@[)B-X-C,Q.R8C>#8R03L@)B-X-C)&.R8C>#8S,SLF
M(W@V,D$[)B-X-C0W.R8C>#(P,$,[)B-X-C(X.R8C>#8T-CLF(W@V,D8[)B-X
M-D-#.R`F(W@V-#@[("8C>#8T03LF(W@V,C<[)B-X-C0Q.R8C>#8R03LF(W@V
M-#8[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C0W
M.R8C>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X-C(R.R8C>#8S,SLF(W@V,C<[
M)B-X-C0V.R8C>#9#0SL@)B-X-C0U.R8C>#8T-3LF(W@V03D[)B-X-C0V.R`F
M(W@V,D4[)B-X-C0X.R8C>#8R-SLF(W@V-#<[)B-X-C)&.R`F(W@V,C@[)B-X
M-C0X.R8C>#8R1CLN/"]P87)A/B`*("`\<&%R83XF(W@V-#<[)B-X-C0U.R8C
M>#8X-CLF(W@V-#8[)B-X-C1!.R8C>#8T-CL@)B-X-C0W.R8C>#8T-CLF(W@V
M048[)B-X-C(W.R8C>#8T-3LF(W@V0T,[("8C>#9!.3LF(W@V-#<[("8C>#8S
M-#LF(W@V-#4[)B-X-C(W.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[
M)B-X-C0U.R`F(W@V,S$[)B-X-C(W.R`F(W@V-T4[)B-X-C(W.R8C>#8S,SLF
M(W@V,D4[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D8[)B-X-C0W.R8C
M>#8T03LF(W@V,D8[("8C>#8T.#L@)B-X-C1!.R8C>#8R-SL@)B-X-C(X.R8C
M>#8T-SL@)B-X-C)&.R8C>#8T03LF(W@V048[)B-X-C,Q.R8C>#8R-SLF(W@V
M-#8[("8C>#8R-SLF(W@V,S$[)B-X-C)#.R8C>#8R-SLF(W@V,SD[("8C>#8T
M-3LF(W@V-$$[)B-X,C`P0SLF(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[
M)B-X-C1!.R8C>#8R1CLF(W@V,$,[("8C>#8T-3LF(W@V-#@[)B-X-C,V.R8C
M>#8T.#LF(W@V,SD[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V
M-#4[("8C>#8S.3LF(W@V-$$[)B-X-C0V.R8C>#8R-SLF(W@V-3([("8C>#8R
M1CLF(W@V,S$[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[
M("8C>#8R0SLF(W@V,D8[)B-X-C1!.R8C>#8R1CL@)B-X-C,Q.R8C>#8T.#LF
M(W@V-#8[)B-X-C0X.R8C>#8S-#LF(W@V,D$[("8C>#8T-3LF(W@V-$$[)B-X
M,C`P0SLF(W@V,S0[)B-X-C0X.R8C>#8R1CLF(W@V,$,[("8C>#8R.#LF(W@V
M-#<[("8C>#8T-SLF(W@V-#4[)B-X-C1!.R8C>#8T-CL@)B-X-C)&.R8C>#8T
M-#LF(W@V-$$[)B-X-C0T.R`F(W@V,C<[)B-X-D%&.R8C>#8S,3L@)B-X-C=%
M.R8C>#8R-SLF(W@V,S,[)B-X-C)%.R`F(W@V-#@[("8C>#8T03LF(W@V,C<[
M("8C>#8R-SLF(W@V,S$[)B-X-C)#.R8C>#8R-SLF(W@V,SD[)B-X-D-#.R`F
M(W@V,D0[)B-X-C(W.R8C>#8T.#LF(W@V0T,[("8C>#8R-SLF(W@V-$$[)B-X
M-C)&.R8C>#8T-SLF(W@V-30[("8C>#8R0SLF(W@V,D8[)B-X-C1!.R8C>#8R
M1CLF(W@V0T,[("8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8R1CL@)B-X-C(X
M.R8C>#8T-SLF(W@V,D$[)B-X-C,Q.R`F(W@V,C<[)B-X-C,S.R8C>#8R03L@
M)B-X-D$Y.R8C>#8T-SL@)B-X-C0U.R8C>#8T.#LF(W@V,S8[)B-X-C0X.R8C
M>#8S.3L@)B-X-C(R.R8C>#8T-CLF(W@V,S$[)B-X-C(W.R`F(W@V,D$[)B-X
M-C-!.R8C>#8T03LF(W@V-$$[)B-X-C,Q.R`F(W@V,D8[)B-X-C0W.R8C>#8T
M03LF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6]P=&EO;G,B(&UD-3TB-68Q9#4P83<S,V,X8C=E-#9A96-E8V4R.#@R
M,F9F-S`B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/B8C>#8R-SLF(W@V
M-$$[)B-X-C)#.R8C>#8R-SLF(W@V,D8[("8C>#8W13LF(W@V-$$[)B-X-C-!
M.R8C>#8R-SLF(W@V-#4[(#H@)B-X-D%&.R8C>#8S,CLF(W@V-$$[)B-X-C0V
M.R8C>#8T-SLF(W@R,#!#.R8C>#8T-SLF(W@V,C<[/"]T:71L93X@"B`@/&AE
M861I;F<^)B-X-D%&.R8C>#8S,CLF(W@V-$$[)B-X-C0V.R8C>#8T-SLF(W@R
M,#!#.R8C>#8T-SLF(W@V,C<[/"]H96%D:6YG/B`*("`\<&%R83XF(W@V048[
M)B-X-C,R.R8C>#8T03LF(W@V-#8[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C
M>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C
M>#9!.3LF(W@V-#4[)B-X-D$Y.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X
M-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T-CLF(W@V,D8[("8C>#8R
M03LF(W@V,C<[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[
M("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,S$[)B-X-C(W.R`F(W@V,C([
M)B-X-C0U.R8C>#8R-SLF(W@V,D8[)B-X-C0W.R`F(W@V-#8[)B-X-C0U.R8C
M>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CLN/"]P87)A/B`*("`\<&%R83XF
M(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C>#8R.#LF(W@V,S$[)B-X
M-C,Q.R8C>#8S,SLF(W@V0T,[("8C>#8R-SLF(W@V-#4[)B-X-C0T.R8C>#8R
M-SLF(W@V-$$[)B-X-C1!.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[
M)B-X-C0U.R`F(W@V,D4[)B-X-C0X.R8C>#8R1CL@)B-X-C(X.R8C>#8R-SLF
M(W@V-$$[)B-X-C)&.R`F(W@V,C@[)B-X-C,Q.R`F(W@V,S$[)B-X-C0X.R8C
M>#9#0SL@(B8C>#8R.#LF(W@V,S$[)B-X-C,Q.R8C>#8S,SLF(W@V0T,[("8C
M>#9!.3LF(W@V-#8[)B-X-C0V.R8C>#8R1CLF(W@V-#<[)B-X-C4T.R`F(W@V
M,C<[)B-X-C0U.R8C>#8T-#LF(W@V,C<[)B-X-C1!.R8C>#8T03LB("8C>#9!
M.3LF(W@V-#0[)B-X-C1!.R8C>#9!.3L@)B-X-C0V.R8C>#8T-3LF(W@V,C<[
M)B-X-C1!.R8C>#8T03LF(W@V,D8[+CPO<&%R83X@"B`@/'!A<F$^)B-X-C(X
M.R8C>#8R-SL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-D$Y.R`F(W@V03D[
M)B-X-C,Q.R8C>#8R1CLF(W@V-#8[("8C>#8R.#LF(W@V,S$[("8C>#8S,3LF
M(W@V-#@[)B-X-D-#.R`B)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C
M>#8R03LF(W@V-#<[)B-X-C(W.R(@)B-X-C(X.R8C>#8T-SL@)B-X-C(W.R8C
M>#8T-CLF(W@V,D$[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8S-3LF(W@V
M-#$[)B-X-C)$.R8C>#8T-SLF(W@V,$,[("8C>#8R0SLF(W@V,C<[)B-X-C1!
M.R8C>#8T03L@)B-X-D$Y.R8C>#8T-SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[
M("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D$[)B-X-C0X.R8C>#8R-SLF
M(W@V-#8[)B-X-C1!.R8C>#8R1CL@)B-X-C=%.R8C>#8S,3LF(W@V-#@[)B-X
M-C0V.R8C>#8R1CLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R`F(W@V
M,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C0W.R`F(W@V-T4[)B-X-C1!.R8C>#8S
M03LF(W@V,C<[)B-X-C0U.R`F(W@V,D4[)B-X-C0X.R8C>#8R1CL@)B-X-C=%
M.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03L@)B-X-C0V.R8C>#8T-3LF
M(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[)B-X-C!#.R`F(W@V,S$[)B-X
M-C(W.R8C>#8T-SLF(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!
M.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C,T.R8C>#8T.#LF(W@V-$$[
M)B-X-C)&.RX\+W!A<F$^(`H@(#QP87)A/B8C>#8R-SLF(W@V048[)B-X-C,Q
M.R`F(W@V,D0[)B-X-C0Q.R8C>#8S.#L@)B-X-C=%.R8C>#8T03LF(W@V,T$[
M)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C(W.R8C
M>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#LF(W@V0T,[("8C>#8R03LF(W@V
M-#@[)B-X-C,S.R8C>#8S-SL@)B-X-C,S.R8C>#8S,3LF(W@V-T4[)B-X-C,Q
M.R8C>#8S,SLF(W@V,D$[("8C>#8S,SLF(W@V,C<[)B-X-C0U.R8C>#8R-SLF
M(W@V-#8[)B-X-C0W.R8C>#8U-#L@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C
M>#8T,3LF(W@V,SD[)B-X-C(W.R8C>#8T-#L@)B-X-C(X.R8C>#8R-SLF(W@V
M,S0[)B-X-C)&.R8C>#8P0SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T
M-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D$[)B-X-C0X.R8C>#8R-SLF(W@V-#8[
M)B-X-C1!.R8C>#8R1CL@)B-X-C)&.R8C>#8S,3L@)B-X-C,U.R8C>#8T.#LF
M(W@V,S$[)B-X-C)!.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X
M-C(W.R8C>#8R.#L@)B-X-D%&.R8C>#8S,CLF(W@V-$$[)B-X-C0V.R8C>#8T
M-SLF(W@V-30[("(F(W@V,S`[)B-X-C)%.R8C>#9#0SLF(W@V,S$[)B-X-C0W
M.R8C>#8U-#L@)B-X-C1!.R8C>#9!.3L@)B-X-C=%.R8C>#9#0SLF(W@V-#@[
M)B-X-C,S.R8C>#8R03LB("8C>#8T03LF(W@V03D[("8C>#8T-CLF(W@V,S,[
M)B-X-C)%.R8C>#8T-SL@)B-X-C(W.R8C>#8S,CL@)B-X-C=%.R8C>#8T03LF
M(W@V,T$[)B-X-C(W.R8C>#8T-3L@)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X
M-C(W.R8C>#8T-#LF(W@V0T,[("8C>#8S,3LF(W@V,C<[("8C>#8R1CLF(W@V
M,S$[("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SLF(W@V-30[("8C>#8W
M13LF(W@V-$$[)B-X-C,T.R8C>#(P,$,[)B-X-C0Q.R8C>#8S,3LF(W@V,S8[
M("8C>#8T.#L@)B-X-C1!.R8C>#8R-SL@)B-X-C=%.R8C>#8T.#LF(W@V,S0[
M)B-X-C0W.R8C>#(P,$,[)B-X-C(W.R8C>#8T03LF(W@V-$$[("8C>#9!.3LF
M(W@V-#<[("8C>#8R1CLF(W@V,S$[("8C>#9!1CLF(W@V,S([)B-X-C1!.R8C
M>#8T-CLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X
M-C(W.R8C>#8S-SLF(W@V-#0[)B-X-C(W.R8C>#8S.3LF(W@V,C<[)B-X-C)!
M.R`F(W@V,S0[)B-X-C)%.R8C>#8S-3LF(W@V0T,[("8C>#8S-#LF(W@V-#4[
M)B-X-C(W.R8C>#8P0SL@)B-X-C0U.R8C>#8S-#LF(W@V,D4[)B-X-C,U.R`F
M(W@V,S0[)B-X-C)&.R8C>#8T-SL@)B-X-C(W.R8C>#8S,SLF(W@V,D$[("8C
M>#8S,#LF(W@V,D4[)B-X-D-#.R8C>#8S,3LF(W@V-#<[("8C>#9!.3LF(W@V
M-#8[)B-X-C1!.R8C>#8R1CLN("8C>#8T-SLF(W@V-#4[)B-X-C@V.R8C>#8T
M-CLF(W@V-$$[)B-X-C0V.R`F(W@V,C<[)B-X-D%&.R8C>#8S,3L@)B-X-C,S
M.R8C>#8S,3LF(W@V-T4[)B-X-C,Q.R8C>#8S,SLF(W@V,D$[("8C>#8S,SLF
M(W@V,C<[)B-X-C0U.R8C>#8R-SLF(W@V-#8[)B-X-C0W.R8C>#8U-#L@)B-X
M-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8R-SLF(W@V,D,[)B-X-C(W.R8C>#8S
M,CLF(W@V-#<[("8C>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[
M)B-X-C(X.R`F(W@V,C@[)B-X-C1!.R8C>#8S-#L@)B-X-C(W.R8C>#8S,CL@
M)B-X-C1!.R8C>#9!.3L@)B-X-C=%.R8C>#8T.#LF(W@V,S0[)B-X-C0W.R`F
M(W@V,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C
M>#8S,#LF(W@V,D4[)B-X-C1!.R8C>#8S,3LF(W@V-#<[)B-X-C4T.R`F(W@V
M-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[
M)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R8C
M>#9#0SL@)B-X-C)&.R8C>#8R-SLF(W@V,D8[)B-X-C0W.R`F(W@V,C@[)B-X
M-C(W.R8C>#8S-#LF(W@V,D8[)B-X-C!#.R`F(W@V,S0[)B-X-C0U.R8C>#8R
M-SL@)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8R03LF(W@V-#@[)B-X-C(W
M.R8C>#8T-CLF(W@V-$$[)B-X-C)&.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF
M(W@V-#<[)B-X-C4T.R`F(W@V-#4[)B-X-C0X.R8C>#8S,3LF(W@V,D8[("8C
M>#8T-CLF(W@V,S@[)B-X-C,Q.R`F(W@V,D4[)B-X-C0X.R8C>#8R1CL@)B-X
M-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#8S,CL@)B-X-C,W.R8C>#8S,3LF(W@V
M-$$[)B-X-C0R.R`F(W@V-$$[)B-X-D$Y.R`F(W@V-#$[)B-X-C0W.R8C>#8S
M,3LF(W@V,S,[)B-X-C)!.R`F(W@V048[)B-X-C,T.R8C>#8T.#LF(W@V,D8[
M)B-X-C0V.R8C>#9#0SL@)B-X-D$Y.R8C>#8T-SL@)B-X-C)&.R8C>#8S,3L@
M)B-X-D$Y.R8C>#8T-CLF(W@V,C<[)B-X-C,Q.R`F(W@V048[)B-X-C,R.R8C
M>#8T03LF(W@V-#8[)B-X-C0W.R8C>#8U-#L@)B-X-C,P.R8C>#8R13LF(W@V
M-$$[)B-X-C,Q.R8C>#8T-SL@)B-X-C1!.R8C>#9!.3L@)B-X-C=%.R8C>#9#
M0SLF(W@V-#@[)B-X-C,S.R8C>#8R03L@)B-X-C0R.R8C>#8S,3LF(W@V,C<[
M)B-X-C,Q.R`F(W@V,D4[)B-X-C0X.R8C>#8R-SLF(W@V-#<[)B-X-C)&.R`F
M(W@V,D8[)B-X-C(W.R8C>#8S-#LF(W@V,D$[("8C>#8R-SLF(W@V-#8[)B-X
M-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V-#8[)B-X-C0U.R8C>#8R
M-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CLN/"]P87)A/B`*("`\<&%R83XF(W@V
M,D8[)B-X-C,Q.R`F(W@V-#([)B-X-C,S.R8C>#8T-3LF(W@V,D$[("8C>#9!
M1CLF(W@V,S([)B-X-C1!.R8C>#8T-CLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[
M)B-X-C(W.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C0U.R8C>#8T03LF
M(W@R,#!#.R8C>#8R03LF(W@V-#@[)B-X-C(W.R8C>#8T-CLF(W@V-$$[)B-X
M-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T-#LF(W@V-$$[)B-X-C(W.R8C>#8R
M03L@)B-X-C0V.R8C>#9!1CLF(W@V-#<[)B-X-C)&.R8C>#8R-SLF(W@V,S$[
M)B-X-D-#.R8C>#(P,$,[)B-X-C(W.R8C>#8T03LF(W@V-$$[("8C>#8S,3LF
M(W@V,C<[("8C>#8R03LF(W@V-#8[)B-X-C,X.R8C>#8T03LF(W@V-#4[("8C
M>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&.R`F(W@V
M03D[)B-X-C0W.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C=%.R8C>#8T
M.#LF(W@V,S0[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SL@)B-X-C,Q
M.R8C>#8R-SL@)B-X-C(X.R8C>#8R-SL@)B-X-C1!.R8C>#9!.3L@)B-X-C)!
M.R8C>#8S,3LF(W@V,D$[)B-X-C1!.R8C>#8R.#L@)B-X-C,R.R8C>#8T-3LF
M(W@V,C<[)B-X-C0V.R8C>#9#0SL@)B-X-C0U.R8C>#8S-#LF(W@V,D4[)B-X
M-C,U.R`F(W@V,D4[)B-X-C(W.R8C>#8T-#LF(W@V0T,[("8C>#9!.3LF(W@V
M,S$[)B-X-C)&.R8C>#8T-SL@)B-X-C0X.R`F(W@V-$$[)B-X-C(W.R`F(W@V
M,D$[)B-X-C-!.R8C>#8T03LF(W@V-$$[)B-X-C,Q.R`F(W@V-#8[)B-X-C(W
M.R8C>#8T-3L@)B-X-C)&.R8C>#8T-SLF(W@V,D8[+B`F(W@V-#8[)B-X-D%&
M.R8C>#8T-SLF(W@V,D8[)B-X-C(W.R8C>#8S,3LF(W@V0T,[("8C>#8T03LF
M(W@V03D[("8C>#8T-CLF(W@V,S,[)B-X-C)%.R8C>#8T-SL@)B-X-C0X.R`F
M(W@V-$$[)B-X-C(W.R`F(W@V,S$[)B-X-C0X.R8C>#8T-CLF(W@V-#@[)B-X
M-C,T.R8C>#8R03L@)B-X-C(W.R8C>#8S,CL@)B-X-C1!.R8C>#9!.3L@)B-X
M-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@)B-X-C(X.R8C>#8T
M-SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8R1CLF(W@V,S$[("8C>#8R
M1CLF(W@V-#8[)B-X-C(X.R8C>#8R-SLF(W@V-#0[("8C>#8T-CLF(W@V-#4[
M)B-X-C0X.R8C>#8R1CLF(W@V-#8[("8C>#8R.#LF(W@V,D0[)B-X-C)".R8C
M>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8R1CLF(W@V,S$[("8C
M>#8R0SLF(W@V,S$[)B-X-C1!.R8C>#8R-SLF(W@V-#8[)B-X-C!#.R`F(W@V
M03D[)B-X-C0U.R8C>#9!.3L@)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8T
M-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V,D8[+CPO<&%R83X@"B`@/'=A
M<FX^)B-X-C0U.R8C>#8T-3LF(W@V03D[)B-X-C0V.R`F(W@V,C<[)B-X-C,S
M.R8C>#8R03L@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8R.#LF(W@V-#<[
M("8C>#8R13LF(W@V,C<[)B-X-C,W.R8C>#8S,3L@)B-X-C0X.R8C>#8R0SLF
M(W@V-#@[)B-X-C)&.R`F(W@V-#4[)B-X-C)$.R8C>#8R1CLF(W@V-#@[)B-X
M-C)&.R8C>#8T03LF(W@V,D$[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8S
M,#LF(W@V,D4[)B-X-C1!.R8C>#8S,3LF(W@V-#<[)B-X,C`P0SLF(W@V,S,[
M)B-X-C(W.R8C>#8S,CLF(W@V0T,[)B-X-C!#.R`F(W@V-#4[)B-X-C(W.R8C
M>#8T03LF(W@V-#0[("8C>#8R.#LF(W@V-#<[("8C>#8S,#LF(W@V,D4[)B-X
M-C1!.R8C>#8S,3LF(W@V-#<[("8C>#8R03LF(W@V-#4[)B-X-C(W.R8C>#8T
M-3L@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[
M)B-X-C(W.R8C>#8P0SL@)B-X-C(X.R8C>#8T-SL@)B-X-C)%.R8C>#8S-3LF
M(W@V-#@[)B-X-C,U.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X
M-C0U.R8C>#8T-SLF(W@V,C<[)B-X-C1!.R8C>#8T03L@)B-X-D$Y.R8C>#8T
M-SL@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03LF(W@V-#<[
M)B-X-C(W.R8C>#9#0SL@)B-X-C(X.R8C>#8S,CLF(W@V,S$[)B-X-D%&.R8C
M>#9#0SL@)B-X-C)&.R8C>#8R-SLF(W@V,S$[)B-X-C0V.R8C>#8R1CL@)B-X
M-C0V.R8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8T03LF(W@V,D8[("8C>#8S
M,CLF(W@V-$$[)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#9!1CLF(W@V,S$[
M("8C>#8T,3LF(W@V,S8[)B-X-C(W.R8C>#9#0SL@)B-X-C)&.R8C>#8S,3L@
M)B-X-C(W.R8C>#8R13LF(W@V,D$[)B-X-C1!.R8C>#8R-SLF(W@V,S$[("8C
M>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V,D$[)B-X-C0X.R8C>#8S,SLF(W@V
M,S<[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V-T4[)B-X-C1!.R8C>#8S
M03LF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[("8C>#8R-SLF(W@V,S0[
M)B-X-C-!.R8C>#8R-SLF(W@V-#0[("8C>#8S-#LF(W@V-#@[)B-X-C)&.R`F
M(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C)&.R8C>#8T03LF(W@V048[)B-X
M-C,Q.R`F(W@V-#([)B-X-C(W.R8C>#8R1CLF(W@V,S$[("8C>#8R.#LF(W@V
M-#<[("8C>#8R1CLF(W@V,S$[)B-X-C1!.R8C>#8R-SLF(W@V-#$[)B-X-C)!
M.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V,D,[
M)B-X-C)&.R8C>#8T03LF(W@V,D8[("8C>#8T-CLF(W@V,D4[)B-X-C0X.R8C
M>#8R-SLF(W@V-#<[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C>#8T.#LF(W@V
M,D8[+CPO=V%R;CX@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T
M=&%C:"(@;60U/2(Y.&1D,S!F,S)A9C%F83@V83EF,&9E83,Q,C1C-&5E,2(@
M<W1A=&4](F-H86YG960B/@H@(#QT:71L93XF(W@V,C<[)B-X-C1!.R8C>#8R
M0SLF(W@V,C<[)B-X-C)&.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[
M)B-X-C0U.R`Z("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[
M/"]T:71L93X@"B`@/&AE861I;F<^)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X
M-C,S.R8C>#8R03L\+VAE861I;F<^(`H@(#QP87)A/B8C>#8S-#LF(W@V-#4[
M)B-X-C(W.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C)!.R8C>#8T.#LF
M(W@V,C<[)B-X-C0V.R8C>#8T03LF(W@V,D8[("8C>#8W13LF(W@V,S$[)B-X
M-C0X.R8C>#8T-CLF(W@V,D8[)B-X-C0W.R8C>#(P,$,[)B-X-C(W.R8C>#8T
M03LF(W@V-$$[("8C>#8S,3LF(W@V,C<[("8C>#8R.#LF(W@V-#<[("8C>#8W
M13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[("8C>#8R13LF(W@V-#@[
M)B-X-C)&.R`F(W@V-T4[)B-X-D-#.R8C>#8T.#LF(W@V,S,[)B-X-C)!.R`F
M(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V,C8[)B-X-D-#.R8C>#8R1CLN("8C
M>#8R1CLF(W@V,S$[("8C>#8S-3LF(W@V-#@[)B-X-C,Q.R8C>#8R03L@)B-X
M-C=%.R8C>#8S-#LF(W@V,D$[)B-X-C1!.R8C>#8R.#LF(W@V,C<[)B-X-C0V
M.R8C>#9#0SL@)B-X-C0U.R8C>#8S,3LF(W@V-#@[)B-X-C,Q.R8C>#9!1CLF
M(W@V,S$[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R8C>#8P0SL@)B-X-C)&.R8C
M>#8S,3L@)B-X-C(R.R8C>#8T-CL@)B-X-C0X.R8C>#8R-SLF(W@V,D0[)B-X
M-C)&.R`F(W@V,D4[)B-X-C0X.R8C>#8R-SLF(W@V-#<[)B-X-C1!.R8C>#8R
M1CL@)B-X-C)!.R8C>#8T.#LF(W@V,C<[)B-X-C0V.R8C>#8S,SLF(W@V,D$[
M("8C>#8R.#LF(W@V-$$[)B-X-C,T.R`F(W@V,C<[)B-X-C,R.R`F(W@V-$$[
M)B-X-D$Y.R`F(W@V-T4[)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C)&.R8C
M>#8T-SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X
M-C(W.R8C>#8T-#L@)B-X-D$Y.R8C>#8T-CLF(W@V-$$[)B-X-C)&.RX\+W!A
M<F$^(`H@(#QP87)A/B8C>#9!1CLF(W@V,C<[)B-X-C0U.R`F(W@V,C<[)B-X
M-C0X.R8C>#8T-#LZ("8C>#8T-CLF(W@V,C<[)B-X-C0U.R`F(W@V-#@[("8C
M>#8T-3LF(W@V,S,[)B-X-C1!.R8C>#8S,3L@)B-X-D$Y.R8C>#8R-SLF(W@V
M-#4[)B-X-C0T.R`F(W@V-T4[)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C)&
M.R8C>#8T-SLF(W@V-30[("8C>#8T-3LF(W@V-#@[)B-X-C,Q.R8C>#8R1CL@
M)B-X-C0V.R8C>#8S.#LF(W@V,S$[("8C>#8S,3LF(W@V,C<[("8C>#8R1CLF
M(W@V,S$[("8C>#8T,3LF(W@V-$$[)B-X-C0T.R8C>#8R1CL@)B-X-C0V.R8C
M>#8R-SLF(W@V-#4[("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V
M,D$[("8C>#8T.#LF(W@V,C<[)B-X-C,Q.R8C>#8R1CL@)B-X-C0V.R8C>#8T
M-3LF(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[("8C>#8T.#L@)B-X-C1!
M.R8C>#8R-SL@)B-X-C(X.R8C>#8R-SL@)B-X-C0Q.R8C>#8S-#LF(W@V,S$[
M)B-X-C)&.R8C>#8T-CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`B
M)B-X-C0U.R8C>#8S,3LF(W@V-#@[)B-X-C,Q.R(@)B-X-C(W.R8C>#8S,CL@
M)B-X-C0Q.R8C>#8T-SLF(W@V,S$[)B-X-C,S.R8C>#8R03L@)B-X-C0U.R8C
M>#8S-#LF(W@V,C<[)B-X-C0W.R8C>#8R1CLF(W@V-#<[("8C>#8S-#LF(W@V
M,D8[)B-X-C0W.R`F(W@V-T4[)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C)&
M.R8C>#8T-SLF(W@V-30[("8C>#8T-3LF(W@V-#@[)B-X-C,Q.R8C>#8R1CL@
M)B-X-C0V.R8C>#8S.#LF(W@V,S$[("8C>#8S,3LF(W@V,C<[("8C>#8R-SLF
M(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V-#8[)B-X
M-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CLN/"]P87)A/B`*("`\
M<&%R83XF(W@V048[)B-X-C(W.R8C>#8T-3L@)B-X-C)&.R8C>#8T.#LF(W@V
M-#4[.B`F(W@V,D8[)B-X-C,Q.R`F(W@V-#4[)B-X-C0X.R8C>#8S,3LF(W@V
M,D8[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R8C>#9!.3LF(W@V-#<[("8C>#8T
M-3LF(W@V,C<[)B-X-C1!.R8C>#8T-#L@)B-X-C0W.R8C>#8S,SLF(W@V,D$[
M)B-X-C1!.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-SL@)B-X-C=%.R8C>#8S,3LF
M(W@V-#@[)B-X-C0V.R8C>#8R1CLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X
M-C(W.R`F(W@V,C@[)B-X-C0W.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V
M,D$[("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[("8C>#8T
M-SLF(W@V-#4[)B-X-C,Q.R8C>#8R-SLF(W@V-#<[("8C>#8W13LF(W@V-$$[
M)B-X-C-!.R8C>#8R-SLF(W@V-#4[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F
M(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R`F(W@V,S0[)B-X
M-C0X.R8C>#8T-CLF(W@V,D8[("8C>#8T.#L@)B-X-C1!.R8C>#8R-SL@)B-X
M-C(W.R8C>#8T03LF(W@V-#8[)B-X-D$Y.R8C>#8T-SL@)B-X-C)&.R8C>#8S
M,3L@)B-X-C(X.R8C>#8R1CLF(W@V-#8[)B-X-C0W.R`F(W@V-T4[)B-X-C1!
M.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V-#([)B-X-C,Q.R8C>#8R-SLF
M(W@V,S$[("8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C>#8T-CLF(W@V,D8[("8C
M>#8R03LF(W@V,S4[)B-X-C0U.R8C>#8T03LF(W@V-#4[)B-X,C`P0SLF(W@V
M048[)B-X-C1!.R8C>#8S,3LF(W@V0T,[("8C>#8T-CLF(W@V-#4[)B-X-C(W
M.R8C>#8T03LF(W@V-$$[)B-X-C)&.RX@)B-X-C(W.R8C>#8T-#LF(W@V,C@[
M)B-X-C)!.R8C>#8T-SL@)B-X-C)&.R8C>#8S,3L@)B-X-C,U.R8C>#8T.#LF
M(W@V,S$[)B-X-C)!.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X
M-C(W.R8C>#8R.#L@)B-X-C)$.R8C>#8R-SLF(W@V-#0[)B-X-C)!.R`F(W@V
M,C([)B-X-C)%.R8C>#8S,3LF(W@V,$,[("8C>#8R.#LF(W@V,S$[)B-X-C0V
M.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R8C>#8U-#L@)B-X-C)&.R8C>#8S,3LF
M(W@V-$$[)B-X-C(W.R8C>#8T,3LF(W@V,D$[("8C>#9!.3LF(W@V-#8[)B-X
M-C0V.R8C>#8R1CLF(W@V-#<[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R
M-SLF(W@V-#4[("8C>#8R1CLF(W@V,S$[("8C>#8S,SLF(W@V-#4[)B-X-C)!
M.R`F(W@V048[)B-X-C1!.R8C>#8S,3LF(W@V-#8[)B-X-C)&.R8C>#8T-SL@
M)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V,C<[)B-X-C1!.R8C
M>#8T-CL@)B-X-C0Q.R8C>#8S,3LF(W@V-#4[("8C>#8T-CLF(W@V-#4[)B-X
M-C(W.R8C>#8T03LF(W@V,S0[("8C>#8S,3LF(W@V,C<[("8C>#8W13LF(W@V
M,S0[)B-X-C)!.R8C>#8T03LF(W@V,C@[)B-X-C(W.R8C>#8T-CLF(W@V0T,[
M("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V,D8[("8C>#8S,CLF
M(W@V-$$[)B-X-C,Q.R8C>#8R-SL@)B-X-C)&.R8C>#8S,3L@)B-X-C-!.R8C
M>#8T03LF(W@V,S$[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R8C>#8S-3LF(W@V
M-#@[)B-X-C,Q.R8C>#8R03L@)B-X-C=%.R8C>#8S,3LF(W@V-#@[)B-X-C0V
M.R8C>#8R1CLF(W@V-#<[("8C>#8R.#LF(W@V-#<[("8C>#8S-3LF(W@V-#@[
M)B-X-C,Q.R8C>#8R03L@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C
M>#8R03L@)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8S-#L@)B-X
M-C)&.R8C>#8R-SLF(W@V,D8[)B-X-C0W.R`F(W@V,D4[)B-X-C0X.R8C>#8R
M-SLF(W@V-#<[)B-X-C)&.R`F(W@V,S0[)B-X-C)&.RX\+W!A<F$^(`H@(#QP
M87)A/B8C>#9!1CLF(W@V,C<[)B-X-C0U.R`F(W@V,S,[)B-X-C0X.R8C>#8T
M-3LZ("8C>#8R.#LF(W@V,S$[("8C>#8S,3LF(W@V-#@[)B-X-D-#.R`F(W@V
M03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[("(F(W@V-T4[)B-X-D-#.R8C>#8T
M.#LF(W@V,S,[)B-X-C)!.R(@)B-X-C0Q.R8C>#8S-#LF(W@V,C<[)B-X-C,Q
M.R`F(W@V,D8[)B-X-C0W.R8C>#8T03LF(W@V,D8[("8C>#8R03LF(W@V,C<[
M("8C>#8T-CLF(W@V,C<[)B-X-C0U.R`F(W@V-#@[("8C>#8R-SLF(W@V-#8[
M)B-X-C)&.R8C>#8R-SLF(W@V,S([)B-X-C0W.R`F(W@V-T4[)B-X-C,Q.R8C
M>#8T.#LF(W@V-#8[)B-X-C)&.R8C>#8T-SLF(W@V-30[("8C>#8W13LF(W@V
M0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[("8C>#8S-#LF(W@V,D8[)B-X-C0W
M.R`F(W@V,C@[)B-X-C0W.R`F(W@V-#$[)B-X-C0W.R8C>#8S,3LF(W@V,S,[
M)B-X-C)!.R`F(W@V-T4[)B-X-D-#.R8C>#8T.#LF(W@V,S,[)B-X-C)!.R8C
M>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V
M,C<[)B-X-C0U.R`F(W@V,C<[)B-X-C0Q.R8C>#8S,CLF(W@V-#@[)B-X-C)&
M.R8C>#8T-SL@)B-X-C,T.R8C>#8T.#LF(W@V,D8[+CPO<&%R83X@"B`@/'1I
M<#XF(W@V-#0[)B-X-C,W.R8C>#8T,3LF(W@V,C<[)B-X-C4R.R`F(W@V,D$[
M)B-X-C0X.R8C>#8R0SLF(W@V-#<[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C
M>#8T03LF(W@V-$$[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F(W@V-#@[)B-X
M-C)#.R8C>#8T.#LF(W@V,D8[("8C>#8W13LF(W@V,S$[)B-X-C0X.R8C>#8T
M-CLF(W@V,D8[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V-$$[
M)B-X-C1!.R`F(W@V,C@[)B-X-C(W.R`F(W@V,C<[)B-X-C0V.R8C>#8R1CLF
M(W@V,C<[)B-X-C,R.R8C>#8T-SLF(W@V-30[("8C>#8R.#LF(W@V,S([)B-X
M-C,Q.R8C>#9!1CL@)B-X-C0X.R`F(W@V-#0[)B-X-C1!.R8C>#8T-CLF(W@V
M03D[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#9!.3LF(W@V-#4[("8C>#8S
M,SLF(W@V,S$[)B-X-C,Y.R8C>#8R03L@)B-X-C(W.R8C>#8T03LF(W@V-#8[
M)B-X-C)!.R8C>#8S,3LF(W@V-#8[)B-X-C)!.R`F(W@V,C@[)B-X-C(W.R8C
M>#8S.3LF(W@V,D([("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V048[)B-X
M-C,Q.R8C>#8R1CLF(W@V,D8[("8C>#9!.3LF(W@V-#<[("8C>#8W13LF(W@V
M,S$[)B-X-C0X.R8C>#8S,SLF(W@V-#<[)B-X-C4T.R`F(W@V,C<[)B-X-C,Q
M.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R`F(W@V-T4[)B-X-C,Q.R8C>#8T.#LF
M(W@V-#8[)B-X-C)&.R8C>#8T-SLF(W@R,#!#.R8C>#8T-SLF(W@V,C<[("8C
M>#8R.#LF(W@V,C<[("8C>#9!.3LF(W@V-#8[)B-X-C)&.R8C>#9#0SL@)B-X
M-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V048[)B-X-C1!.R8C>#8S
M,3LF(W@V,D8[("8C>#8R.#LF(W@V-#<[("8C>#8T-SLF(W@V-#4[)B-X-C1!
M.R8C>#8T-CL@)B-X-C)&.R8C>#8T-#LF(W@V-$$[)B-X-C0T.R`F(W@V,C@[
M)B-X-C(W.R8C>#8T03LF(W@V,D8[("8C>#8S-3LF(W@V,C@[)B-X-C0X.R8C
M>#8S,3L@)B-X-C(X.R8C>#8T.#LF(W@V,D8[("8C>#8T.#L@)B-X-C)&.R8C
M>#8S,3L@)B-X-C0U.R8C>#8R1CLF(W@V,D$[("8C>#8R-SLF(W@V,S$[)B-X
M-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8W13LF(W@V,S$[)B-X-C0X.R8C>#8T
M-CLF(W@V,D8[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SL@)B-X-C(X
M.R8C>#8S,3L@)B-X-C,Q.R8C>#8T.#LF(W@V0T,[("8C>#9!.3LF(W@V-#0[
M)B-X-C1!.R8C>#8R1CLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C)&.R8C
M>#8T03LF(W@V048[)B-X-C,Q.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V
M03D[("8C>#8T-CLF(W@V-#8[)B-X-C0U.R8C>#8T.#LF(W@V,D8[+CPO=&EP
M/B`*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M871T
M86-H(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8V@\
M+W1I=&QE/@H@("`@/&AE861I;F<^071T86-H/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!9;W4@;6%Y(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4@
M:68@>6]U<B!B<F]W<V5R('-U<'!O<G1S('5P;&]A9&EN9R!O9B!F:6QE<RX@
M36]R92!T:&%N(#$@9FEL92!C86X@8F4@=7!L;V%D960@870@;VYC92X*("`@
M(#PO<&%R83X*("`@(#QP87)A/E-T97`@,3H@16ET:&5R('1Y<&4@=&AE('!A
M=&@@86YD(&YA;64@;V8@82!F:6QE('1H870@>6]U('=A;G0@871T86-H960@
M=&\@=&AI<R!M97-S86=E(&]R(&-L:6-K('1H92`B0G)O=W-E(B!B=71T;VX@
M86YD('-E;&5C="!T:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H
M(&%N9"!N86UE(&]F('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T
M86-H;65N="!B;W@N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($1E
M8VED92!W:&5T:&5R('EO=2!W86YT('1H92!F:6QE('1O(&)E('9I97=E9"!A
M<R!A;B!A='1A8VAM96YT(&]R(&EN;&EN92!W:71H('1H92!R97-T(&]F('1H
M92!M97-S86=E+B!4:&4@<F5C:7!I96YT)W,@;6%I;"!R96%D:6YG('-O9G1W
M87)E(&UU<W0@8F4@86)L92!T;R!H86YD;&4@=&AE(&EN;&EN92!D:7-P;&%Y
M(&]F('1H92!F:6QE('1Y<&4L(&]T:&5R=VES92!T:&ES('!A<G0@=VEL;"!B
M92!V:65W960@87,@86X@871T86-H;65N="!I;G-T96%D+@H@("`@/"]P87)A
M/@H@("`@/'1I<#X*("`@(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I
M;&5S(&%N9"]O<B!S;&]W97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P
M<F]C97-S(&]F('5P;&]A9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T
M;R!T:&4@96UA:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE
M;G0@86YD(&1O(&YO="!C;&EC:R!O=&AE<B!L:6YK<R!O<B!B=71T;VYS('=H
M:6QE('EO=2!A<F4@=V%I=&EN9R!F;W(@82!F:6QE('1O('5P;&]A9"X*("`@
M(#PO=&EP/@H\+V5N=')Y/BTM/CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+6%T=&%C:"(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@071T86-H/"]T:71L93X*("`@(#QH96%D:6YG/D%T=&%C:#PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA>2!A='1A8V@@9FEL97,@
M=&\@>6]U<B!M97-S86=E(&EF('EO=7(@8G)O=W-E<B!S=7!P;W)T<R!U<&QO
M861I;F<@;V8@9FEL97,N($UO<F4@=&AA;B`Q(&9I;&4@8V%N(&)E('5P;&]A
M9&5D(&%T(&]N8V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5I
M=&AE<B!T>7!E('1H92!P871H(&%N9"!N86UE(&]F(&$@9FEL92!T:&%T('EO
M=2!W86YT(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92!O<B!C;&EC:R!T:&4@
M(D)R;W=S92(@8G5T=&]N(&%N9"!S96QE8W0@=&AE(&9I;&4@=&\@8F4@871T
M871C:&5D+B!4:&4@<&%T:"!A;F0@;F%M92!O9B!T:&%T(&9I;&4@;F]W(&%P
M<&5A<G,@:6X@=&AE($%T=&%C:&UE;G0@8F]X+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^4W1E<"`R.B!$96-I9&4@=VAE=&AE<B!Y;W4@=V%N="!T:&4@9FEL
M92!T;R!B92!V:65W960@87,@86X@871T86-H;65N="!O<B!I;FQI;F4@=VET
M:"!T:&4@<F5S="!O9B!T:&4@;65S<V%G92X@5&AE(')E8VEP:65N="=S(&UA
M:6P@<F5A9&EN9R!S;V9T=V%R92!M=7-T(&)E(&%B;&4@=&\@:&%N9&QE('1H
M92!I;FQI;F4@9&ES<&QA>2!O9B!T:&4@9FEL92!T>7!E+"!O=&AE<G=I<V4@
M=&AI<R!P87)T('=I;&P@8F4@=FEE=V5D(&%S(&%N(&%T=&%C:&UE;G0@:6YS
M=&5A9"X*("`@(#PO<&%R83X*("`@(#QT:7`^"B`@("!0;&5A<V4@;F]T92!T
M:&%T(&9O<B!L87)G92!F:6QE<R!A;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O
M;FYE8W1I;VYS+"!T:&4@<')O8V5S<R!O9B!U<&QO861I;F<@86YD(&%T=&%C
M:&EN9R!Y;W5R(&9I;&4@=&\@=&AE(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N
M(%!L96%S92!B92!P871I96YT(&%N9"!D;R!N;W0@8VQI8VL@;W1H97(@;&EN
M:W,@;W(@8G5T=&]N<R!W:&EL92!Y;W4@87)E('=A:71I;F<@9F]R(&$@9FEL
M92!T;R!U<&QO860N"B`@("`\+W1I<#X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(@;60U/2(X86,P,S)C
M-&%C,3@R9C-F,&0V-#0V8S(P9C`P.#ED9"(@<W1A=&4](G5P=&]D871E(CX*
M("`\=&ET;&4^)B-X-C(W.R8C>#8T03LF(W@V,D,[)B-X-C(W.R8C>#8R1CL@
M)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@.B`F(W@V-T4[
M)B-X-D-#.R8C>#8T.#LF(W@V,S,[)B-X-C)!.R8C>#8T-SLF(W@V,C<[/"]T
M:71L93X@"B`@/&AE861I;F<^)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S
M.R8C>#8R03LF(W@V-#<[)B-X-C(W.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X
M-C)&.R8C>#8S,3L@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#8R.#LF(W@V
M,D4[)B-X-C,T.R`F(W@V-#$[)B-X-C0W.R8C>#8S,3LF(W@V,S,[)B-X-C)!
M.R8C>#9#0SL@)B-X-C(W.R8C>#8S,CL@)B-X-C=%.R8C>#8S,3LF(W@V-#@[
M)B-X-C0V.R8C>#8R1CLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R8C
M>#8T03LF(W@V-$$[("8C>#9!.3LF(W@V-#<[("8C>#8T,CLF(W@V,C@[)B-X
M-C0T.R8C>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X-C=%.R8C>#8T03LF(W@V
M,T$[)B-X-C(W.R8C>#8T-3L@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8W
M13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[("8C>#8S-#LF(W@V,D8[
M)B-X-C0W.R`F(W@V,C<[)B-X-C,S.R8C>#8R03L@)B-X-C0U.R8C>#8S-#LF
M(W@V,C<[)B-X-C0W.R8C>#8R1CLF(W@V-#<[("8C>#8T-3LF(W@V-$$[)B-X
M,C`P0SLF(W@V048[)B-X-C,Q.R8C>#8R1CLF(W@V,D8[+CPO<&%R83X@"B`@
M/&AE861I;F<^)B-X-C)$.R8C>#8S,#LF(W@V-#$[("8C>#8W13LF(W@V,S$[
M)B-X-C0X.R8C>#8T-CLF(W@V,D8[)B-X-C0W.R@F(W@V-#<[)B-X-C(W.R8C
M>#9#0SLI("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[("8C
M>#8S-#LF(W@V,D8[)B-X-C0W.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(X
M.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V,D0[)B-X-C,P.R8C>#8T,3L@
M)B-X-C0V.R8C>#8T-3LF(W@V-#@[)B-X-C)&.R8C>#8T-CL@)B-X-C=%.R8C
M>#8S,3LF(W@V-#@[)B-X-C0V.R8C>#8R1CLF(W@V-#<[*"8C>#8T-SLF(W@V
M,C<[)B-X-D-#.RD@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R
M03L@)B-X-C,T.R8C>#8R1CLF(W@V-#<[("8C>#8R.#LF(W@V,C<[)B-X-C1!
M.R8C>#8R1CLZ/"]P87)A/B`*("`\<&%R83XF(W@V048[)B-X-C(W.R8C>#8T
M-3L@)B-X-C(W.R8C>#8T.#LF(W@V-#0[.B`F(W@V048[)B-X-C,R.R8C>#8T
M03LF(W@V-#8[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[
M("8C>#9!.3LF(W@V-#8[)B-X-C(W.R8C>#8S,3L@)B-X-C0V.R8C>#8R-SLF
M(W@V-#4[("8C>#8W13LF(W@V,S$[)B-X-C0X.R8C>#8T-CLF(W@V,D8[)B-X
M-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R`F(W@V
M03D[)B-X-C0W.R`F(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-#0[("8C>#8R
M.#LF(W@V-#<[("8C>#8R1#LF(W@V,S`[)B-X-C0Q.R`F(W@V,C([)B-X-C0V
M.R8C>#8T-SLF(W@V,C<[("8C>#8T-SLF(W@V,S,[)B-X-C)!.R8C>#8T03LF
M(W@V,D8[("8C>#8S,3LF(W@V,C<[)B-X-C!#.R`F(W@V,C<[)B-X-C0V.R8C
M>#8R03LF(W@V,D4[)B-X-C(W.R8C>#8R.#L@)B-X-C0V.R8C>#8T-3LF(W@V
M,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[+CPO<&%R83X@"B`@/'!A<F$^)B-X
M-D%&.R8C>#8R-SLF(W@V-#4[("8C>#8R1CLF(W@V-#@[)B-X-C0U.SH@)B-X
M-C(X.R8C>#8S,3L@)B-X-C,Q.R8C>#8T.#LF(W@V0T,[("8C>#9!.3LF(W@V
M-#0[)B-X-C1!.R8C>#8R1CL@(B8C>#8R.#LF(W@V,S$[)B-X-C0X.R8C>#8S
M,CLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#8[)B-X-D-#.R`F(W@V,C<[
M)B-X-C,W.R8C>#8T-#LF(W@V,C<[)B-X-C,Y.R8C>#8R-SLF(W@V,D$[("8C
M>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[)B-X-C0W.R8C>#8R
M-SLB("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#9!.3L@)B-X-C0V.R8C>#8T
M-3LF(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[+CPO<&%R83X@"B`@/&AE
M861I;F<^)B-X-C)!.R8C>#8S03LF(W@V-$$[)B-X-C1!.R8C>#8S,3L@)B-X
M-C)$.R8C>#8R-SLF(W@V-#0[)B-X-C)!.R`F(W@V-T4[)B-X-D-#.R8C>#8T
M.#LF(W@V,S,[)B-X-C)!.R8C>#8T-SLF(W@V,C<[/"]H96%D:6YG/B`*("`\
M<&%R83XF(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C>#8R03LF(W@V
M,T$[)B-X-C1!.R8C>#8T03LF(W@V,S$[("8C>#8R1#LF(W@V,C<[)B-X-C0T
M.R8C>#8R03L@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03LF
M(W@V-#<[)B-X-C(W.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X
M-C0U.R`F(W@V,D4[)B-X-C0X.R8C>#8R1CL@)B-X-C(X.R8C>#8R-SLF(W@V
M-$$[)B-X-C)&.SH\+W!A<F$^(`H@(#QP87)A/B8C>#9!1CLF(W@V,C<[)B-X
M-C0U.R`F(W@V,C<[)B-X-C0X.R8C>#8T-#LZ("8C>#8R1#LF(W@V,C<[)B-X
M-C0T.R8C>#8R03L@)B-X-C0W.R8C>#8S,3L@)B-X-C=%.R8C>#9#0SLF(W@V
M-#@[)B-X-C,S.R8C>#8R03L@)B-X-C,Q.R8C>#8R-SL@)B-X-C)&.R8C>#8S
M,3L@)B-X-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V,D$[)B-X-C0U
M.R8C>#8R-SLF(W@V-$$[)B-X-C0T.R`F(W@V,C@[)B-X-C0W.R`F(W@V,S4[
M)B-X-C0X.R8C>#8S,3LF(W@V,D$[("(F(W@V-T4[)B-X-D-#.R8C>#8T.#LF
M(W@V,S,[)B-X-C)!.R(@)B-X-C0X.R`F(W@V-$$[)B-X-C(W.R`B)B-X-C(X
M.R8C>#8S,3LF(W@V,D4[)B-X-C,W.R(@)B-X-C)&.R8C>#8S,3LF(W@V,C([
M)B-X-C0X.R8C>#8S,3LF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H@(#QP87)A
M/B8C>#9!1CLF(W@V,C<[)B-X-C0U.R`F(W@V,D8[)B-X-C0X.R8C>#8T-3LZ
M("8C>#8R.#LF(W@V,S$[("8C>#8S,3LF(W@V-#@[)B-X-D-#.R`F(W@V03D[
M)B-X-C0T.R8C>#8T03LF(W@V,D8[("(F(W@V,C@[)B-X-C,Q.R8C>#8T.#LF
M(W@V,S([)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0V.R8C>#9#0SL@)B-X
M-C(W.R8C>#8S-SLF(W@V-#0[)B-X-C(W.R8C>#8S.3LF(W@V,C<[)B-X-C)!
M.R`F(W@V-T4[)B-X-D-#.R8C>#8T.#LF(W@V,S,[)B-X-C)!.R8C>#8T-SLF
M(W@V,C<[(B`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V03D[("8C>#8T-CLF
M(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H@
M(#QH96%D:6YG/B8C>#8R03LF(W@V,T$[)B-X-C1!.R8C>#8T03LF(W@V,S$[
M("8C>#8R03LF(W@V-#@[)B-X-C,V.R8C>#8T03LF(W@V,D0[)B-X-C(W.R8C
M>#8R03L@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03LF(W@V
M-#<[)B-X-C(W.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(X.R8C>#8S,3LF
M(W@V,C<[)B-X-D-#.R`F(W@V,D$[)B-X-C-!.R8C>#8T03LF(W@V-$$[)B-X
M-C,Q.R`F(W@V,D$[)B-X-C0X.R8C>#8S-CLF(W@V-$$[)B-X-C)$.R8C>#8R
M-SLF(W@V,D$[("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[
M)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8R13LF(W@V-#@[)B-X-C)&.R@@
M)B-X-C0U.R8C>#8T-CLF(W@V,S@[)B-X-C0X.R8C>#8S,3L@)B-X-C(W.R8C
M>#8S,CL@)B-X-C)!.R8C>#8T.#LF(W@V,S8[)B-X-C1!.R8C>#8R1#LF(W@V
M,C<[)B-X-C)!.R8C>#8P0SL@)B-X-C0U.R8C>#8R03LF(W@V-#8[)B-X-D-#
M.R`F(W@V,C<[)B-X-C,S.R8C>#8R03L@)B-X-D$Y.R8C>#8T-SL@)B-X-D%&
M.R8C>#8T03LF(W@V,S$[)B-X-C0V.R8C>#8R1CLF(W@V-#<[("8C>#8R.#LF
M(W@V-#<[("8C>#8S.3LF(W@V-#8[)B-X-C0X.R8C>#8R-SLF(W@V-#8[("8C
M>#8R03LF(W@V-#@[)B-X-C,V.R8C>#8T03LF(W@V,D0[)B-X-D-#.R`F(W@V
M,C@[)B-X-C,Q.R`F(W@V-T4[)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C)&
M.R8C>#8T-SLF(W@V-30[("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF
M(W@V,D$[("8C>#8S-#LF(W@V,D8[)B-X-C0W.R`F(W@V,D8[)B-X-C,Q.R8C
M>#8T03LF(W@V,C<[)B-X-C0Q.R8C>#8R03L@)B-X-C)%.R8C>#8T.#LF(W@V
M,C<[)B-X-C0W.R8C>#8R1CL@)B-X-C0V.R8C>#8T-3LF(W@V-#@[)B-X-C)&
M.RD@)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&.SH\+W!A<F$^(`H@(#QP
M87)A/B8C>#9!1CLF(W@V,C<[)B-X-C0U.R`F(W@V,C<[)B-X-C0X.R8C>#8T
M-#LZ("8C>#8R03LF(W@V-#@[)B-X-C,V.R8C>#8T03LF(W@V,D0[)B-X-D-#
M.R`F(W@V,S$[)B-X-C(W.R`F(W@V,D8[)B-X-C,Q.R`F(W@V-#$[)B-X-C1!
M.R8C>#8T-#LF(W@V,D8[("8C>#8R03LF(W@V-#@[)B-X-C,V.R8C>#8T03LF
M(W@V,D0[)B-X-C(W.R8C>#8R03L@)B-X-C)&.R8C>#8S,3LF(W@V,D,[("8C
M>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&.RX\+W!A
M<F$^(`H@(#QP87)A/B8C>#9!1CLF(W@V,C<[)B-X-C0U.R`F(W@V,D8[)B-X
M-C0X.R8C>#8T-3LZ("8C>#8R.#LF(W@V,S$[("8C>#8S,3LF(W@V-#@[)B-X
M-D-#.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[("(F(W@V,C@[)B-X
M-C,Q.R8C>#8T.#LF(W@V,S([)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0V
M.R8C>#9#0SL@)B-X-C(W.R8C>#8S-SLF(W@V-#0[)B-X-C(W.R8C>#8S.3LF
M(W@V,C<[)B-X-C)!.R`F(W@V-T4[)B-X-D-#.R8C>#8T.#LF(W@V,S,[)B-X
M-C)!.R8C>#8T-SLF(W@V,C<[(B`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V
M03D[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&
M.RX\+W!A<F$^(`H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UP<FEO
M<FET>2(@;60U/2)B,#(S,S8W8S,V9&4S8V4Q-38W9#(W8V-A830U-C0P8R(@
M<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^)B-X-C(W.R8C>#8T03LF(W@V
M,D,[)B-X-C(W.R8C>#8R1CL@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W
M.R8C>#8T-3L@.B`F(W@V,C<[)B-X-C0X.R8C>#8T-#LF(W@V-#@[)B-X-C1!
M.R8C>#8U,3LF(W@V,D$[/"]T:71L93X@"B`@/&AE861I;F<^)B-X-C(W.R8C
M>#8T.#LF(W@V-#0[)B-X-C0X.R8C>#8T03LF(W@V-3$[)B-X-C)!.SPO:&5A
M9&EN9SX@"B`@/'!A<F$^)B-X-C(W.R8C>#8T.#LF(W@V-#0[)B-X-C0X.R8C
M>#8T03LF(W@V-3$[)B-X-C)!.R8C>#8T-SLF(W@V,C<[("8C>#8R1CLF(W@V
M,S$[("8C>#8T.#LF(W@V,C<[)B-X-C0R.R8C>#8S.3L@)B-X-C(W.R8C>#8S
M-#LF(W@V,C<[)B-X-C,Q.R8C>#8T-SL@)B-X-C(X.R8C>#8S,3L@)B-X-C,S
M.R8C>#8S,3LF(W@V,C([)B-X-C0U.R8C>#8R1CL@(E@M4')I;W)I='DB("8C
M>#8R-SLF(W@V,S([("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V
M-#4[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8R-SLF(W@V,S$[)B-X-C,S
M.R8C>#8R-SLF(W@V-#0[)B-X-D-#.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@
M)B-X-C)&.R8C>#8R-SLF(W@V,S$[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F
M(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C,S.R8C>#8S,3LF(W@V,C([)B-X
M-C0U.R8C>#8R1CL@)B-X-C)&.R8C>#8S,3L@)B-X-C0X.R8C>#8R-SLF(W@V
M-#([)B-X-C,Y.R`F(W@V,S0[)B-X-C(X.R8C>#8T-SL@)B-X-C(W.R8C>#8S
M,SLF(W@V,D$[)B-X-C(W.R8C>#8T-CLF(W@V,D8[)B-X-C(W.R8C>#8S,3LF
M(W@V,D8[)B-X-D-#.R`F(W@V,C<[)B-X-C,S.R8C>#8R03L@)B-X-D$Y.R8C
M>#8T-SL@)B-X-C)!.R8C>#8T.#LF(W@V,S,[)B-X-C,W.R`F(W@V-#4[)B-X
M-C,Q.R8C>#8T.#LF(W@V,S$[)B-X-D%&.R8C>#8S,3LF(W@V-#<[)B-X-C(W
M.R8C>#9#0SL@)B-X-C0U.R8C>#8T.#LF(W@V,S([)B-X-C1!.R8C>#8T-#LF
M(W@V,C<[)B-X-C!#.R`F(W@V-#8[)B-X-C)!.R8C>#(P,$,[)B-X-C(W.R8C
M>#8S,SLF(W@V03D[)B-X-C1!.R8C>#8W13LF(W@V,$,[("8C>#8R-SLF(W@V
M-T4[)B-X-C,Q.R8C>#8R-SL@)B-X-C0X.R`N+BX@)B-X-C=%.R8C>#8S,#LF
M(W@V-$$[)B-X-C,Q.R8C>#8T,3LF(W@V,D$[)B-X-C0W.R`F(W@V,S0[)B-X
M-C)&.R8C>#8T-SL@)B-X-C(W.R8C>#8S,SLF(W@V,D$[+B`F(W@V-#4[)B-X
M-C,Q.R8C>#8T.#LF(W@V,S$[)B-X-D%&.R8C>#8S,3LF(W@V-#<[)B-X-C(W
M.R8C>#8T03LF(W@V-$$[("8C>#9!.3LF(W@V-#<[("8C>#8R-SLF(W@V,S([
M("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V,S0[)B-X-C(X.R8C>#8T-SL@
M)B-X-C(W.R8C>#8S,SLF(W@V,D$[)B-X-C(W.R8C>#8T-CLF(W@V,D8[)B-X
M-C(W.R8C>#8S,3LF(W@V,D8[("8C>#8W13LF(W@V,S0[)B-X-C)!.R8C>#8T
M03LF(W@V,C@[)B-X-C(W.R8C>#8T-CLF(W@V0T,[("8C>#8T-CLF(W@V-#4[
M)B-X-C1!.R8C>#(P,$,[)B-X-D$Y.R8C>#8T-CLF(W@V-#8[)B-X-C)&.R8C
M>#8P0SL@)B-X-C)!.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R`F(W@V,C([)B-X
M-C0V.R8C>#8S,3LF(W@V,C<[("8C>#8T-CLF(W@V,C<[)B-X-C)&.R8C>#8T
M03LF(W@V,D8[)B-X-C0W.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-D%&
M.R8C>#8T03LF(W@V,S$[)B-X-C0V.R8C>#8R1CLN/"]P87)A/B`*/"]E;G1R
M>3X*("`\96YT<GD@:60](F-O;7!O<V4M<V%V92UA='1A8VAM96YT<R(@;60U
M/2)D8C@Y.3<R8S1E8F(P8C0Q86(V.3%B-F$W-S0T83@Q9"(@<W1A=&4](G5P
M=&]D871E(CX*("`\=&ET;&4^)B-X-C(W.R8C>#8T03LF(W@V,D,[)B-X-C(W
M.R8C>#8R1CL@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@
M.B`F(W@V,S`[)B-X-C)%.R8C>#8T03LF(W@V,S$[)B-X-C0W.R`F(W@V,S8[
M)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C0U.SPO=&ET;&4^(`H@(#QP87)A
M/B8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V048[)B-X-C,R.R8C>#8T03LF
M(W@V-#8[)B-X-C0W.R`F(W@V,D$[)B-X-C,Y.R8C>#8T03LF(W@V-$$[)B-X
M-C0V.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C0V.R8C>#8T-3LF(W@V
M,C<[)B-X-C1!.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-SL@)B-X-C(R.R8C>#8T
M03LF(W@V,C<[("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[
M)B-X-C0W.R8C>#8R-SL@)B-X-C0V.R8C>#8T03LF(W@V,S([("8C>#8R.#LF
M(W@V-#<[("8C>#8T-SLF(W@V-#8[)B-X-D%&.R8C>#8R-SLF(W@V-#4[("8C
M>#8S,#LF(W@V,D4[)B-X-C1!.R8C>#8S,3LF(W@V-#<[)B-X-C4T.R`F(W@V
M-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[
M)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R8C
M>#9#0SL@)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V,D8[)B-X
M-C,Q.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[)B-X-C4T.R`F(W@V
M-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[
M)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R8C
M>#9#0SL@)B-X-C,P.R8C>#8R13LF(W@V-$$[)B-X-C,Q.R8C>#8T-SL@)B-X
M-D%&.R8C>#8S,3LF(W@V,D8[)B-X-C0V.R8C>#8R1CL@)B-X-C0X.R`F(W@V
M-$$[)B-X-C(W.R`F(W@V,D4[)B-X-C1!.R8C>#8S,3LN("8C>#8R-SLF(W@V
M-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V-#4[)B-X-C0X
M.R8C>#8S,3LF(W@V,D8[("8C>#8R,CLF(W@V,D4[)B-X-C,Q.R`F(W@V,C@[
M)B-X-C0W.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C)&.R8C>#8S,3L@
M)B-X-C)$.R8C>#8T,3LF(W@V,S@[("8C>#8T,3LF(W@V,S8[)B-X-C(W.R8C
M>#9#0SL@)B-X-C)&.R8C>#8T03LF(W@V,S,[)B-X-D$Y.R`F(W@V,D8[)B-X
M-C,Q.R8C>#8R-SLF(W@V,D4[)B-X-C)!.R8C>#8T03LF(W@V,C<[)B-X-C,Q
M.R8C>#8R03LF(W@V,C<[)B-X-C0V.R`F(W@V03D[)B-X-C0U.R8C>#9!.3L@
M)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C
M>#8T03LF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C
M;VUP;W-E+6QI;FLM871T86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($QI;FL@071T86-H;65N=',\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H971H97(@=&AE(&%T
M=&%C:&UE;G1S(&EN('EO=7(@8V]M<&]S:71I;VX@87)E('-E;G0@87,@82!P
M87)T(&]F('1H92!M86EL(&UE<W-A9V4@;W(@=VAE=&AE<B!T:&]S92!A='1A
M8VAM96YT<R!A<F4@:V5P="!O;B!A(&QO8V%L('-E<G9E<BX@($EF(&%T=&%C
M:&UE;G1S(&%R92!L:6YK960L('1H92!R96-I<&EE;G0H<RD@;V8@>6]U<B!M
M97-S86=E('=I;&P@8F4@<')O=FED960@82!W96)L:6YK('=H97)E('1H97D@
M8V%N(&1O=VYL;V%D('1H92!A='1A8VAM96YT*',I+B`@3&EN:VEN9R!A='1A
M8VAM96YT<R!H87,@=&AE(&%D=F%N=&%G92!O9B!T<F5M96YD;W5S;'D@<F5D
M=6-I;F<@=&AE('-I>F4@;V8@;W5T9V]I;F<@;65S<V%G97,N("!,:6YK:6YG
M(&%T=&%C:&UE;G1S(&AA<R!T:&4@9&ES861V86YT86=E('1H870@=&AE(&-O
M;G1E;G0@;V8@=&AE(&%T=&%C:&UE;G1S(&-A;B!N;W0@8F4@9W5A<F%N=&5E
M9"!T;R!B92!A=F%I;&%B;&4@:6X@=&AE(&9U='5R92!S:6YC92!T:&4@871T
M86-H;65N="!D871A(&ES(&YO="!L;V-A=&5D('=I=&AI;B!T:&4@92UM86EL
M(&UE<W-A9V4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S
M96%R8V@B(&UD-3TB.#9B,F5F-3=B,3$Y-#@Y,#@S,V0Y9&0T.65B8SEB,S(B
M('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/B8C>#8R0SLF(W@V,S,[)B-X
M-C)!.R8C>#8R0SLF(W@V-#@[)B-X-D-#.R`F(W@V-T4[)B-X-C1!.R8C>#8S
M03LF(W@V,C<[)B-X-C0U.SPO=&ET;&4^(`H@(#QH96%D:6YG/B8C>#8R1#LF
M(W@V-#@[)B-X-C,R.R8C>#8T-SLF(W@V-30[("8C>#8R0SLF(W@V,S,[)B-X
M-C)!.R8C>#8R0SLF(W@V-#@[/"]H96%D:6YG/B`*("`\<&%R83XF(W@V,S0[
M)B-X-C0U.R8C>#8R-SL@)B-X-C0U.R8C>#8T-3LF(W@V03D[)B-X-C0V.R`F
M(W@V,C<[)B-X-C,S.R8C>#8R03L@)B-X-C(X.R8C>#8S,3L@)B-X-C,Q.R8C
M>#8T.#LF(W@V0T,[("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SLF(W@R
M,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,D4[)B-X-C0X.R8C>#8R
M1CL@)B-X-C)&.R8C>#8S,3L@)B-X-C)$.R8C>#8T.#LF(W@V,S([)B-X-C0W
M.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8T-3LF(W@V,D4[
M)B-X-C)!.R8C>#8T-#LF(W@V-#$[)B-X-D-#.R`F(W@V,D,[)B-X-C,S.R8C
M>#8R03LF(W@V,D,[)B-X-C0X.R`F(W@V,C<[)B-X-C0V.R8C>#8R0SLF(W@V
M,C<[)B-X-C0U.R`F(W@V,D8[)B-X-C0W.R8C>#8T03LF(W@V,D8[+CPO<&%R
M83X@"B`@/'!A<F$^)B-X-D%&.R8C>#8R-SLF(W@V-#4[("8C>#8R-SLF(W@V
M-#@[)B-X-C0T.SH@)B-X-C)&.R8C>#8S,3L@)B-X-C0Q.R8C>#8T03LF(W@V
M-#0[)B-X-C)&.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V03D[)B-X-C0W
M.R`F(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-#0[("8C>#8R.#LF(W@V-#<[
M("8C>#8R0SLF(W@V,S,[)B-X-C)!.R8C>#8R0SLF(W@V-#@[)B-X-D-#.R`F
M(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V-#<[)B-X
M-C,S.R8C>#8R03LF(W@V-$$[)B-X-C)&.R`F(W@V-#4[)B-X-C0X.R8C>#8R
M-SLF(W@V,S$[)B-X-C)&.R`F(W@V-#4[)B-X-C0X.R8C>#8S,3LF(W@V,D8[
M("8C>#8T-CLF(W@V,S@[)B-X-C,Q.R`F(W@V,D4[)B-X-C0X.R8C>#8R1CL@
M)B-X-C,Q.R8C>#8R-SL@)B-X-C)&.R8C>#8S,3LF(W@V,D,[("8C>#8T-CLF
M(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H@
M(#QP87)A/B8C>#9!1CLF(W@V,C<[)B-X-C0U.R`F(W@V,D8[)B-X-C0X.R8C
M>#8T-3LZ("8C>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X
M-C(X.R`F(W@V,SD[)B-X-C0T.R8C>#8R-SLF(W@V-#4[)B-X-C)!.R`F(W@V
M-#8[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W
M.R`F(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C>#8R-SLF(W@V-#$[
M)B-X-C,R.R8C>#8T.#LF(W@V,D8[)B-X-C0V.R`F(W@V,C@[)B-X-C0W.R`F
M(W@V,D0[)B-X-C0X.R8C>#8S,CLF(W@V-#<[)B-X-C4T.R`F(W@V,D,[)B-X
M-C,S.R8C>#8R03LF(W@V,D,[)B-X-C0X.RX\+W!A<F$^(`H@(#QP87)A/B8C
M>#9!1CLF(W@V,C<[)B-X-C0U.R`F(W@V,S,[)B-X-C0X.R8C>#8T-3LZ("8C
M>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V
M-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W
M.R8C>#8T03LF(W@V0T,[("8C>#9!.3LF(W@V-#<[("8C>#8T-3LF(W@V,C<[
M)B-X-C1!.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,D8[)B-X-C,Q.R`F
M(W@V,C([)B-X-C0V.R8C>#8T-SLF(W@V,C<[("8C>#8R0SLF(W@V,S,[)B-X
M-C)!.R8C>#8R0SLF(W@V-#@[("8C>#8R-SLF(W@V-#8[)B-X-C)#.R8C>#8R
M-SLF(W@V-#4[("8C>#8W13LF(W@V,S`[)B-X-C1!.R8C>#8S,3LF(W@V,D8[
M+CPO<&%R83X@"B`@/'!A<F$^)B-X-D%&.R8C>#8R-SLF(W@V-#4[("8C>#8X
M-CLF(W@V-#<[)B-X-C(W.R8C>#8S,3LF(W@V-#4[.B`F(W@V-#$[)B-X-C,T
M.R8C>#8S,3LF(W@V,D8[)B-X-C0V.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF
M(W@V,D8[("(F(W@V,D,[)B-X-C,S.R8C>#8R03LF(W@V,D,[)B-X-C0X.R(@
M+CPO<&%R83X@"B`@/'!A<F$^)B-X-C(W.R8C>#9!1CLF(W@V,S$[("8C>#8W
M13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R8C>#8R-SLF
M(W@V-$$[)B-X-C1!.R`F(W@V-#4[)B-X-C0V.R8C>#8S-SLF(W@V,C@[)B-X
M-C0R.R`F(W@V,C@[)B-X-C(W.R`F(W@V,D0[)B-X-C0X.R8C>#8S,CLF(W@V
M-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C0U.R8C>#8T
M.#LF(W@V,S$[)B-X-C)&.R`F(W@V,D,[)B-X-C,S.R8C>#8R03LF(W@V,D,[
M)B-X-C0X.R8C>#9#0SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T03LF
M(W@V,C<[)B-X-C0Q.R8C>#8R03LF(W@V-#<[("8C>#8S-#LF(W@V-#@[)B-X
M-C)&.R8C>#8P0SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T-3LF(W@V
M-$$[)B-X,C`P0SLF(W@V,D$[)B-X-C0X.R8C>#8R-SLF(W@V-#8[)B-X-C1!
M.R8C>#8R1CL@)B-X-C)&.R8C>#8S,3L@)B-X-C(X.R8C>#8R13LF(W@V,S0[
M("(F(W@V-#8[)B-X-C)!.R8C>#8R-SLF(W@V-$$[)B-X-C)#.R`F(W@V,D,[
M)B-X-C,S.R8C>#8R03LF(W@V,D,[)B-X-C0X.R(@)B-X-C,Y.R8C>#8T-CLF
M(W@V,C<[)B-X-C0X.R8C>#8T03LF(W@V-#8[("8C>#8R,CLF(W@V-#8[)B-X
M-C0W.R8C>#8R-SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C0U.R8C>#8S-#LF(W@V
M,C<[)B-X-C0W.R8C>#8R1CLF(W@V-#<[("8C>#9!.3LF(W@V-#8[)B-X-C1!
M.R8C>#8R1CLN/"]P87)A/B`*/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E
M<BUO<'1I;VYS(B!M9#4](C,P-C@W96,T-S4W-C5B830T-C=D,F5F-F1C96,T
M,&,S(B!S=&%T93TB=7!T;V1A=&4B/@H@(#QT:71L93XF(W@V-#4[)B-X-C,Q
M.R8C>#8T.#LF(W@V,S$[)B-X-D%&.R8C>#8S,3L@)B-X-C=%.R8C>#8T.#LF
M(W@V,S0[)B-X-C0W.R`Z("8C>#8S.3LF(W@V-#4[)B-X-C0T.R8C>#8T03LF
M(W@V,C<[)B-X-C)!.SPO=&ET;&4^(`H@(#QH96%D:6YG/B8C>#8S.3LF(W@V
M-#4[)B-X-C0T.R8C>#8T03LF(W@V,C<[)B-X-C)!.R`F(W@V-T4[)B-X-C0X
M.R8C>#8S-#LF(W@V-#<[/"]H96%D:6YG/B`*("`\<&%R83XF(W@V,S0[)B-X
M-C0U.R8C>#8R-SL@)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8R03LF(W@V
M-#@[)B-X-C(W.R8C>#8T-CLF(W@V-$$[)B-X-C)&.R`F(W@V-$$[)B-X-D$Y
M.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[("8C>#8S,3LF(W@V,C<[
M("8C>#8R.#LF(W@V-#<[("8C>#9!.3LF(W@V-#4[)B-X-D$Y.R`F(W@V03D[
M)B-X-C0T.R8C>#8T03LF(W@V,D8[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C
M>#8S,3LF(W@V,C<[)B-X-C)&.R8C>#8T03LF(W@V-#@[)B-X-C1!.R8C>#9#
M0SL@)B-X-C0U.R8C>#8T.#LF(W@V,D,[)B-X-C0X.R8C>#8R1CL@)B-X-C)&
M.R8C>#8S,3L@)B-X-C,S.R8C>#8R03LF(W@V-#@[)B-X-C0V.R`F(W@V,S,[
M)B-X-C0U.R8C>#8R03L@)B-X-C,Q.R8C>#8R-SLF(W@V,S,[)B-X-C)!.R`F
M(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W.R8C>#8R.#L@)B-X
M-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[+B`F(W@V
M,C@[)B-X-C,Y.R8C>#8R1CL@)B-X-C(W.R8C>#8S,CL@)B-X-C(R.R8C>#8T
M-CLF(W@V,$,[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V-#4[)B-X-C1!
M.R8C>#(P,$,[)B-X-C)!.R8C>#8T.#LF(W@V,C<[)B-X-C0V.R8C>#8T03LF
M(W@V,D8[("8C>#8S.3LF(W@V-#4[)B-X-C0T.R8C>#8T03LF(W@V,C<[)B-X
M-C)!.R8C>#8T03L@)B-X-C,Q.R8C>#8R-SL@)B-X-D$Y.R8C>#8T-SL@)B-X
M-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C0T.R`F(W@V,C@[)B-X-C0W.R`F(W@V
M,C<[)B-X-C)#.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V,C([)B-X-C0V
M.R`F(W@V,C@[)B-X-C,Q.R`F(W@V,S$[)B-X-C0X.R8C>#9#0SL@)B-X-C(W
M.R8C>#8T03LF(W@V-#8[("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SL@
M)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C
M>#8T03LF(W@V,D8[("8C>#8R.#LF(W@V-#<[("8C>#9!.3LF(W@V-#4[)B-X
M-D$Y.R`F(W@V,D,[)B-X-C,Y.R8C>#8R.#LF(W@V-#<[("8C>#8R-SLF(W@V
M-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R8C>#9#0SL@)B-X-C0U
M.R8C>#8T.#LF(W@V,D,[)B-X-C0X.R8C>#8R1CL@)B-X-C)&.R8C>#8S,3L@
M)B-X-C,S.R8C>#8T-3LF(W@V,D$[("8C>#8S,3LF(W@V,C<[)B-X-C,S.R8C
M>#8R03LF(W@V,$,[("8C>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V
M,C<[)B-X-C(X.R`F(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!
M.R8C>#8R1CLN/"]P87)A/B`*("`\<&%R83XF(W@V048[)B-X-C,R.R8C>#8T
M03LF(W@V-#8[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[
M("8C>#8S,CLF(W@V-$$[)B-X-C(W.R8C>#8R1CLF(W@V0T,[("8C>#8S,3LF
M(W@V,C<[("8C>#8T-3LF(W@V-#4[)B-X-D$Y.R8C>#8T-CL@)B-X-C(W.R8C
M>#8S,SLF(W@V,D$[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V,C<[)B-X
M-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W.R8C>#8R.#L@)B-X-C0V.R8C>#8T
M-3LF(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[)B-X-C!#.R8C>#8R-SLF
M(W@V-#4[)B-X-C(W.R`F(W@V,C@[)B-X-C(W.R8C>#8T03LF(W@V,D8[("8C
M>#8R1CLF(W@V,S$[("8C>#8T-3LF(W@V-#@[)B-X-C,Q.R8C>#8R1CL@)B-X
M-C(W.R8C>#8T-CLF(W@V,D$[)B-X-C)%.R8C>#8R-SLF(W@V,C@[("8C>#9!
M1CLF(W@V,S([)B-X-C1!.R8C>#8T-CLF(W@V-#<[)B-X-C4T.R`F(W@V,D0[
M)B-X-C,P.R8C>#8T,3L@)B-X-C)&.R8C>#8T,CLF(W@V,D$[("8C>#8T-CLF
M(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&.R`F(W@V,S([)B-X
M-C1!.R8C>#8S,3LF(W@V,C<[("8C>#8R.#LF(W@V,C<[)B-X-C,Y.R8C>#8R
M0CL@)B-X-C(W.R8C>#8S,CL@)B-X-C(X.R8C>#8T03LF(W@V-#8[("8C>#8S
M,3LF(W@V-#$[)B-X-C)!.R8C>#8T-CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[
M)B-X-C0W.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R8C
M>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X
M-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8R1CL@)B-X-C,T.R8C>#8R
M1CLN/"]P87)A/B`*("`\:&5A9&EN9SXF(W@V,D8[)B-X-C,Q.R8C>#8T03LF
M(W@V,C<[)B-X-C0Q.R8C>#8R03L@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X
M-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.SPO:&5A9&EN9SX@"B`@/'!A<F$^
M)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#9!1CLF(W@V,S([)B-X-C1!.R8C
M>#8T-CLF(W@V-#<[("8C>#8T,3LF(W@V,C<[)B-X-C1!.R8C>#8T-#LF(W@V
M-#<[)B-X-C(W.R8C>#8T03LF(W@V-$$[("8C>#8R.#LF(W@V,C<[("8C>#8R
M-SLF(W@V-#8[)B-X-C,T.R8C>#8S.3LF(W@V,C<[)B-X-C(X.R!E;6P@)B-X
M-C,Q.R8C>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X-C=%.R8C>#8T.#LF(W@V
M,S0[)B-X-C0W.R8C>#8U-#L@)B-X-C(W.R8C>#8T-CLF(W@V,D$[)B-X-C)%
M.R8C>#8R-SLF(W@V,C@[)B-X-D-#.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@
M)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#L@)B-X-C)%.R8C
M>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8R1CL@)B-X-C0V.R8C>#8T-3LF(W@V
M-#@[)B-X-C)&.RX@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V
M,C<[)B-X-C0V.R8C>#8R0SLF(W@V,C<[)B-X-C0U.R`F(W@V,C<[)B-X-C1!
M.R8C>#8T-CL@)B-X-D$Y.R8C>#8R-SLF(W@V,S$[)B-X-C!#.R`F(W@V,C<[
M)B-X-C(X.R8C>#8R03LF(W@V,D8[)B-X-C(W.R`F(W@V,C@[)B-X-C(W.R8C
M>#8T03LF(W@V,D8[("8C>#8T03LF(W@V03D[("8C>#8W13LF(W@V-#@[)B-X
M-C,T.R8C>#8T-SL@)B-X-C(W.R8C>#8T-CLF(W@V,D$[)B-X-C)%.R8C>#8R
M-SLF(W@V,C@[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[
M)B-X-C)&.R`F(W@V-#@[("8C>#8S,SLF(W@V-T4[)B-X-C,S.R`F(W@V,C<[
M)B-X-C1!.R8C>#8T-CL@)B-X-D%&.R8C>#8S,CLF(W@V-$$[)B-X-C0V.R8C
M>#8T-SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#8T-CLF(W@V,D$[)B-X
M-C)%.R8C>#8R-SLF(W@V,C@[("8C>#9!.3LF(W@V-#8[)B-X-C1!.R8C>#8R
M1CL@)B-X-C)!.R8C>#8R-SL@)B-X-C(X.R8C>#8R03LF(W@V-#@[)B-X-C(W
M.R8C>#8T-CLF(W@V-$$[)B-X-C)&.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF
M(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,D8[)B-X
M-C,Q.R8C>#8T03LF(W@V,C<[)B-X-C0Q.R8C>#8R03L@)B-X-C,T.R8C>#8R
M1CLF(W@V-#<[("8C>#8S,3LF(W@V,C<[("8C>#8R1CLF(W@V,S$[("8C>#8R
M-SLF(W@V-$$[)B-X-C0V.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[
M("8C>#8T-3LF(W@V,S0[)B-X-C(W.R8C>#8T-SLF(W@V,D8[)B-X-C0W.R`F
M(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CLN/"]P
M87)A/B`*/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUW:61G971S(B!M
M9#4](F(Y8F,V.#DT,#)F-S4W-3<W,60W-#4W,&4W9C9F.#!A(B!S=&%T93TB
M=7!T;V1A=&4B/@H@(#QT:71L93XF(W@V-#4[)B-X-C,Q.R8C>#8T.#LF(W@V
M,S$[)B-X-D%&.R8C>#8S,3L@)B-X-C=%.R8C>#8T.#LF(W@V,S0[)B-X-C0W
M.R`Z("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V,S0[/"]T:71L
M93X@"B`@/&AE861I;F<^)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C
M>#8S-#LO)B-X-C=%.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R8C>#8T-CL@)B-X
M-C0V.R8C>#8T-3LF(W@V-#@[)B-X-C)&.R8C>#8T-CL@)B-X-C,Y.R8C>#8R
M1CLF(W@V-#4[("8C>#8S.3LF(W@V,S8[)B-X-C0X.R8C>#8T03LF(W@V-3$[
M)B-X-C)!.U-H;W<O2&ED92!5;G-U8G-C<FEB960\+VAE861I;F<^(`H@(#QP
M87)A/B8C>#8R-SLF(W@V048[)B-X-C,Q.R`F(W@V,C<[)B-X-C,R.R`F(W@V
M,SD[)B-X-C,V.R8C>#8T.#LF(W@V-$$[)B-X-C)!.R`F(W@V,D8[)B-X-C,Q
M.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[)B-X,C`P0SLF(W@V-#<[
M)B-X-C(W.R8C>#9#0SL@24U!4"`F(W@V,C<[)B-X-C,S.R8C>#8R03LF(W@V
M-#$[)B-X-C(W.R8C>#8R1CLF(W@V-#<[("8C>#8T-3LF(W@V-$$[)B-X,C`P
M0SLF(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CLF
M(W@V,$,[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D$[)B-X-C0X.R8C
M>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8R1CL@)B-X-C=%.R8C>#8T.#LF(W@V
M,S0[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8S
M03LF(W@V-$$[)B-X-C,Q.R`F(W@V,SD[)B-X-C,V.R8C>#8T.#L@)B-X-C,Q
M.R8C>#8R-SL@)B-X-C=%.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R8C>#8T-CLO
M)B-X-C)$.R8C>#8R-SLF(W@V,S8[)B-X-C,Q.R`F(W@V-#8[)B-X-C0U.R8C
M>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CLN("8C>#8R.#LF(W@V,S$[)B-X
M-C(W.R8C>#9#0SL@)B-X-C,Y.R8C>#8S-CLF(W@V-#@[)B-X-C1!.R8C>#8U
M,3LF(W@V,D$[("8C>#8T03LF(W@V,C<[("8C>#8S.3LF(W@V,D8[)B-X-C0U
M.R`F(W@V,SD[)B-X-C,V.R8C>#8T.#LF(W@V-$$[)B-X-C4Q.R8C>#8R03L@
M)B-X-C1!.R8C>#9!.3L@)B-X-C=%.R8C>#8T.#LF(W@V,S0[)B-X-C0W.R`F
M(W@V,C@[)B-X-C(W.R`F(W@V,SD[)B-X-C0T.R8C>#8R-SLF(W@V-#4[)B-X
M-C)!.R`F(W@V048[)B-X-C,P.R8C>#8R-SLF(W@V,S$[)B-X-D-#.R`F(W@V
M,D8[)B-X-C,Q.R`F(W@V,D,[)B-X-C,Y.R8C>#8R.#LF(W@V-#<[("8C>#9!
M.3LF(W@V-#8[)B-X-C(W.R8C>#8S,3LF(W@V0T,[("8C>#8T-SLF(W@V,S$[
M("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SLF(W@V,$,[("8C>#8R-SLF
M(W@V,S([("8C>#8T,3LF(W@V-#<[)B-X-C,Q.R8C>#8S,SLF(W@V,D$[("8C
M>#8S.3LF(W@V-#4[)B-X-C0T.R8C>#8T03LF(W@V,C<[)B-X-C)!.R`F(W@V
M-#4[)B-X-C0X.R8C>#8R0SLF(W@V-#@[)B-X-C)&.R`F(W@V,C@[)B-X-C,Q
M.R8C>#8R-SLF(W@V0T,[("8C>#8T-SLF(W@V,S$[("8C>#8W13LF(W@V-#@[
M)B-X-C,T.R8C>#8T-SL@)B-X-C,Y.R8C>#8T-3LF(W@V-#0[("8C>#8T-3LF
M(W@V-#@[)B-X-C,Q.R8C>#8R1CL@)B-X-C0V.R8C>#8S.#LF(W@V,S$[("8C
M>#8S,3LF(W@V,C<[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D$[)B-X
M-C0X.R8C>#8R-SLF(W@V-#8[("8C>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#9#
M0SL@)B-X-C(R.R8C>#8T-CL@)B-X-C=%.R8C>#8T.#LF(W@V,S0[)B-X-C0W
M.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W.R8C>#8R.#L@
M)B-X-C0V.R8C>#8T-3LF(W@V-#@[)B-X-C)&.RX\+W!A<F$^(`H@(#QH96%D
M:6YG/B8C>#8R.#LF(W@V,C<[)B-X-C,R.R`F(W@V03D[)B-X-C,Q.R8C>#8R
M1CLF(W@V-#8[("8C>#8T-SLF(W@V-#4[)B-X-C0W.SPO:&5A9&EN9SX@"B`@
M/'!A<F$^)B-X-C(X.R8C>#8R-SLF(W@V,S([("8C>#9!.3LF(W@V,S$[)B-X
M-C)&.R8C>#8T-CL@)B-X-C1!.R8C>#8R-SL@)B-X-D%&.R8C>#8S,SLF(W@V
M,D$[)B-X-C,Q.R8C>#8R1CLF(W@V-#8[("8C>#8R03LF(W@V-#4[)B-X-C(W
M.R8C>#8T-3L@)B-X-C0X.R8C>#8S,3LF(W@V-#@[)B-X-C)&.R8C>#9#0SLF
M(W@R,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V-T4[)B-X-C0X.R8C
M>#8S-#LF(W@V-#<[+CPO<&%R83X@"B`@/&AE861I;F<^)B-X-C(X.R8C>#8S
M,SLF(W@V,D$[)B-X-C0V.R`F(W@V-#<[)B-X-C0U.R8C>#8T-SL\+VAE861I
M;F<^(`H@(#QP87)A/B8C>#8R.#LF(W@V,S,[)B-X-C)!.R8C>#8T-CL@)B-X
M-C0W.R8C>#8T-3LF(W@V-#<[("8C>#8T.#LF(W@V,S$[)B-X-C0X.R8C>#8R
M1CLF(W@V0T,[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C=%
M.R8C>#8T.#LF(W@V,S0[)B-X-C0W.SPO<&%R83X@"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)F:6QT97)S(B!M9#4](C5E9C8P-S@V-S8W938S.&9B9C5B83AF
M8S5B9#5D.60R(B!S=&%T93TB=7!T;V1A=&4B/@H@(#QT:71L93XF(W@V-#$[
M)B-X-C1!.R8C>#8T-#LF(W@V,D$[)B-X-C,Q.R8C>#8T-SLF(W@V,C<[(#H@
M)B-X-C(W.R8C>#8S.3LF(W@V-#4[)B-X-C(W.R8C>#8T-#L\+W1I=&QE/B`*
M("`\:&5A9&EN9SXF(W@V,C<[)B-X-C,Y.R8C>#8T-3LF(W@V,C<[)B-X-C0T
M.R`F(W@V-#([)B-X-C0X.R8C>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8T-CL@
M)B-X-C0Q.R8C>#8T03LF(W@V-#0[)B-X-C)!.R8C>#8S,3L@)B-X-D$Y.R8C
M>#8S,3LF(W@V,D8[)B-X-C0V.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(X
M.R8C>#8S,3L@)B-X-C,Q.R8C>#8T.#LF(W@V0T,[("8C>#8R,CLF(W@V-$$[
M)B-X-D$Y.R8C>#8T.#LF(W@V-#8[("(F(W@V,C<[)B-X-C,Y.R8C>#8T-3LF
M(W@V,C<[)B-X-C0T.R`F(W@V-#$[)B-X-C1!.R8C>#8T-#LF(W@V,D$[)B-X
M-C,Q.R(@)B-X-C)&.R8C>#8S,3L@)B-X-C0U.R8C>#8R0SLF(W@V,C<[)B-X
M-C0X.R8C>#8S,3LF(W@V,D$[("8C>#9!.3LF(W@V-#0[)B-X-C0U.R8C>#8T
M-SL@24Y"3U@@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-D$Y.R`F(W@V-#8[
M)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CL@)B-X-C)!.R8C
M>#8R-SL@)B-X-C,W.R8C>#8R.#LF(W@V-#([("8C>#8T,CLF(W@V-#@[)B-X
M-C(W.R8C>#8T-CLF(W@V-$$[)B-X-C0V.R`F(W@V-#4[)B-X-C,T.R8C>#8R
M13LF(W@V,S4[("8C>#8S-#LF(W@V,D8[)B-X-C0W.R8C>#8P0SL@)B-X-C0Q
M.R8C>#8T03LF(W@V-#0[)B-X-C)!.R8C>#8S,3LF(W@V-$$[)B-X-C0V.R8C
M>#9!1CL@)B-X-C(X.R8C>#8S,3L@)B-X-C,Q.R8C>#8T.#LF(W@V0T,[("8C
M>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R8C>#8R
M-SLF(W@V0T,[("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SL@)B-X-C(W
M.R8C>#8S.3LF(W@V-#4[)B-X-C(W.R8C>#8T-#L@)B-X-C,T.R8C>#8T.#LF
M(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M
M961I="UR=6QE<R(@;60U/2(U8F%A-3<P.&%C.30T.64W.3=F.38W,S$S83EE
M,6$R-R(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^)B-X-C0Q.R8C>#8T
M03LF(W@V-#0[)B-X-C)!.R8C>#8S,3LF(W@V-#<[)B-X-C(W.R`Z("8C>#8T
M.#LF(W@V-$$[)B-X-C,Q.R8C>#8R-SLF(W@V-$$[)B-X-C,T.R`F(W@V-#([
M)B-X-C0X.R8C>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8T-CL@)B-X-C0Q.R8C
M>#8T03LF(W@V-#0[)B-X-C)!.R8C>#8S,3L@)B-X-D$Y.R8C>#8S,3LF(W@V
M,D8[)B-X-C0V.SPO=&ET;&4^(`H@(#QH96%D:6YG/B8C>#8T.#LF(W@V-$$[
M)B-X-C,Q.R8C>#8R-SLF(W@V-$$[)B-X-C,T.R`F(W@V-#([)B-X-C0X.R8C
M>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8T-CL@)B-X-C0Q.R8C>#8T03LF(W@V
M-#0[)B-X-C)!.R8C>#8S,3L@)B-X-D$Y.R8C>#8S,3LF(W@V,D8[)B-X-C0V
M.R`F(W@V,D4[)B-X-C0X.R8C>#8R1CL\+VAE861I;F<^(`H@(#QP87)A/B8C
M>#8R.#LF(W@V,S$[("8C>#8S,3LF(W@V-#@[)B-X-D-#.R`F(W@V03D[)B-X
M-C0T.R8C>#8T03LF(W@V,D8[("(F(W@V-#@[)B-X-C1!.R8C>#8S,3LF(W@V
M,C<[)B-X-C1!.R8C>#8S-#L@)B-X-C0R.R8C>#8T.#LF(W@V,C<[)B-X-C0V
M.R8C>#8T03LF(W@V-#8[("8C>#8T,3LF(W@V-$$[)B-X-C0T.R8C>#8R03LF
M(W@V,S$[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R(@)B-X-D$Y.R8C>#8T-#LF
M(W@V-$$[)B-X-D$Y.R`F(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X
M-C1!.R8C>#8R1CL@)B-X-C)!.R8C>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X
M-C,U.R8C>#8T,3LF(W@V,D0[)B-X-C0W.R8C>#(P,$,[)B-X-C(W.R8C>#8T
M03LF(W@V-$$[("8C>#8S,3LF(W@V-#<[)B-X-C0V.R8C>#8T-3LF(W@V-#@[
M)B-X-C0V.R`F(W@V,S0[)B-X-C0X.R8C>#8T03LF(W@V,D8[("8C>#9!.3LF
M(W@V-#<[("8C>#8R1CLF(W@V,S$[("8C>#8R,CLF(W@V-#8[("8C>#8T,CLF
M(W@V,C<[)B-X-C)&.R8C>#8S,3L@)B-X-C(X.R8C>#8T-SL@)B-X-C)$.R8C
M>#8S,#LF(W@V-#$[)B-X-C!#.R`F(W@V,C<[)B-X-C,V.R8C>#8R-SLF(W@V
M-#$[)B-X-C0W.R`F(W@V-#@[("8C>#8T.#LF(W@V-$$[)B-X-C,Q.R8C>#8R
M-SLF(W@V-$$[)B-X-C,T.R`F(W@V-#([)B-X-C0X.R8C>#8R-SLF(W@V-#8[
M)B-X-C1!.R8C>#8T-CL@)B-X-C0Q.R8C>#8T03LF(W@V-#0[)B-X-C)!.R8C
M>#8S,3LF(W@V-$$[)B-X-C0V.R8C>#9!1CL@)B-X-C0Q.R8C>#8S.3LF(W@V
M,C<[)B-X-C0T.R`F(W@V-#$[)B-X-C,Y.R8C>#8T-#LF(W@V-$$[("8C>#8R
M13LF(W@V-#@[)B-X-C(W.R8C>#8T-SLF(W@V-$$[)B-X-C)&.R`F(W@V,C@[
M)B-X-C0X.R8C>#8R1CLN/"]P87)A/B`*/"]E;G1R>3X*("`\96YT<GD@:60]
M(F9I;'1E<BUE9&ET+6)L86-K;&ES="(@;60U/2(X,&9F-S@P,V,V-C4Y.6,W
M,#,U9C=F.#@Q,60R,3AC8R(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^
M)B-X-C0Q.R8C>#8T03LF(W@V-#0[)B-X-C)!.R8C>#8S,3LF(W@V-#<[)B-X
M-C(W.R`Z("8C>#8T.#LF(W@V-$$[)B-X-C,Q.R8C>#8R-SLF(W@V-$$[)B-X
M-C,T.R`F(W@V-#0[)B-X-C1!.R8C>#8S,SLF(W@V,D$[("8C>#8S,SLF(W@V
M-$$[)B-X-C(W.R8C>#8T-SL\+W1I=&QE/B`*("`\:&5A9&EN9SXF(W@V-#@[
M)B-X-C1!.R8C>#8S,3LF(W@V,C<[)B-X-C1!.R8C>#8S-#L@)B-X-C0T.R8C
M>#8T03LF(W@V,S,[)B-X-C)!.R`F(W@V,S,[)B-X-C1!.R8C>#8R-SLF(W@V
M-#<[("8C>#8S-#LF(W@V-#4[)B-X-C(W.SPO:&5A9&EN9SX@"B`@/'!A<F$^
M)B-X-C(X.R8C>#8S,3L@)B-X-C,Q.R8C>#8T.#LF(W@V0T,[("8C>#9!.3LF
M(W@V-#0[)B-X-C1!.R8C>#8R1CL@(B8C>#8T.#LF(W@V-$$[)B-X-C,Q.R8C
M>#8R-SLF(W@V-$$[)B-X-C,T.R`F(W@V-#0[)B-X-C1!.R8C>#8S,SLF(W@V
M,D$[("8C>#8S,SLF(W@V-$$[)B-X-C(W.R8C>#8T-SL@)B-X-C,T.R8C>#8T
M-3LF(W@V,C<[(B`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V03D[("8C>#8T
M-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&.R`F(W@V,D$[
M)B-X-C(W.R`F(W@V,C@[)B-X-C0W.R`F(W@V,S4[)B-X-C0Q.R8C>#8R1#LF
M(W@V-#<[)B-X,C`P0SLF(W@V,C<[)B-X-C1!.R8C>#8T03L@)B-X-C,Q.R8C
M>#8R-SLF(W@V-#<[)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T
M03L@)B-X-C,T.R8C>#8T.#LF(W@V-$$[)B-X-C)&.R`F(W@V03D[)B-X-C0W
M.R`F(W@V,D8[)B-X-C,Q.R`F(W@V,C([)B-X-C0V.R`F(W@V-#([)B-X-C(W
M.R8C>#8R1CLF(W@V,S$[("8C>#8R.#LF(W@V-#<[("8C>#8R1#LF(W@V,S`[
M)B-X-C0Q.R8C>#8P0SL@)B-X-C(W.R8C>#8S-CLF(W@V,C<[)B-X-C0Q.R8C
M>#8T-SL@)B-X-C0X.R`F(W@V-#@[)B-X-C1!.R8C>#8S,3LF(W@V,C<[)B-X
M-C1!.R8C>#8S-#L@)B-X-C(R.R8C>#8R1CLF(W@V,S$[)B-X-C,S.R8C>#8T
M-SLF(W@V,C<[)B-X-C1!.R8C>#8T03L@)B-X-C)%.R8C>#8T.#LF(W@V,C<[
M)B-X-C0W.R8C>#8T03LF(W@V,D8[("8C>#8R.#LF(W@V-#@[)B-X-C)&.R`F
M(W@V03D[)B-X-C0W.R`F(W@V,D$[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X
M-C0T.R8C>#9#0SL@)B-X-C(X.R8C>#8T-SL@)B-X-C)&.R8C>#8S,3LF(W@V
M-$$[)B-X-C(W.R8C>#8T,3LF(W@V,D$[("8C>#8W13LF(W@V-$$[)B-X-C-!
M.R8C>#8R-SLF(W@V-#4[("8C>#8R-SLF(W@V,S([("8C>#8R,CLF(W@V-#8[
M)B-X-C0W.R8C>#8R-SL@)B-X-C0V.R8C>#8R1CLF(W@V,C<[)B-X-C,Q.R8C
M>#8T03LF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F
M:6QT97(M961I="UW:&ET96QI<W0B(&UD-3TB,S,P8S-A.&9A9#$Y.&,W869E
M.#4U8S$P,6,V,V-D,&8B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/B8C
M>#8T,3LF(W@V-$$[)B-X-C0T.R8C>#8R03LF(W@V,S$[)B-X-C0W.R8C>#8R
M-SL@.B`F(W@V-#@[)B-X-C1!.R8C>#8S,3LF(W@V,C<[)B-X-C1!.R8C>#8S
M-#L@)B-X-C0T.R8C>#8T03LF(W@V,S,[)B-X-C)!.R`F(W@V,S,[)B-X-C0Q
M.R8C>#8T03LF(W@V,D8[/"]T:71L93X@"B`@/&AE861I;F<^)B-X-C0X.R8C
M>#8T03LF(W@V,S$[)B-X-C(W.R8C>#8T03LF(W@V,S0[("8C>#8T-#LF(W@V
M-$$[)B-X-C,S.R8C>#8R03L@)B-X-C,S.R8C>#8T,3LF(W@V-$$[)B-X-C)&
M.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL\+VAE861I;F<^(`H@(#QP87)A/B8C
M>#8R.#LF(W@V,S$[("8C>#8S,3LF(W@V-#@[)B-X-D-#.R`F(W@V03D[)B-X
M-C0T.R8C>#8T03LF(W@V,D8[("(F(W@V-#@[)B-X-C1!.R8C>#8S,3LF(W@V
M,C<[)B-X-C1!.R8C>#8S-#L@)B-X-C0T.R8C>#8T03LF(W@V,S,[)B-X-C)!
M.R`F(W@V,S,[)B-X-C0Q.R8C>#8T03LF(W@V,D8[("8C>#8S-#LF(W@V-#4[
M)B-X-C(W.R(@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-D$Y.R`F(W@V-#8[
M)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R8C>#8R1CL@)B-X-C)!.R8C
M>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X-C,U.R8C>#8T,3LF(W@V,D0[)B-X
M-C0W.R8C>#(P,$,[)B-X-C(W.R8C>#8T03LF(W@V-$$[("8C>#8S,3LF(W@V
M,C<[)B-X-C0W.R8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[
M("8C>#8S-#LF(W@V-#@[)B-X-C1!.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-SL@
M)B-X-C)&.R8C>#8S,3L@)B-X-C(R.R8C>#8T-CL@)B-X-C0R.R8C>#8R-SLF
M(W@V,D8[)B-X-C,Q.R`F(W@V,C@[)B-X-C0W.R`F(W@V,D0[)B-X-C,P.R8C
M>#8T,3LF(W@V,$,[("8C>#8R-SLF(W@V,S8[)B-X-C(W.R8C>#8T,3LF(W@V
M-#<[("8C>#8T.#L@)B-X-C0X.R8C>#8T03LF(W@V,S$[)B-X-C(W.R8C>#8T
M03LF(W@V,S0[("8C>#8R,CLF(W@V,D8[)B-X-C,Q.R8C>#8S,SLF(W@V-#<[
M)B-X-C(W.R8C>#8T03LF(W@V-$$[("8C>#8R13LF(W@V-#@[)B-X-C(W.R8C
M>#8T-SLF(W@V-$$[)B-X-C)&.R`F(W@V,C@[)B-X-C0X.R8C>#8R1CL@)B-X
M-D$Y.R8C>#8T-SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T-SLF(W@V
M-#4[)B-X-C0X.R8C>#8R-SLF(W@V,S$[)B-X-C0W.R`F(W@V,D$[)B-X-C0U
M.R8C>#8R-SLF(W@V-$$[)B-X-C0T.R`F(W@V,C@[)B-X-C0W.R`F(W@V,D8[
M)B-X-C,Q.R8C>#8T03LF(W@V,C<[)B-X-C0Q.R8C>#8R03L@)B-X-C=%.R8C
M>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@)B-X-C,Q.R8C>#8R-SL@)B-X
M-C(W.R8C>#8S,CL@)B-X-C(R.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R`F(W@V
M,D8[)B-X-C(W.R8C>#8S,3LF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!M9#4](C,W9#DR
M.3=D,6-C830V-#,U93,V8C9E,SAE-#5D8V1B(B!S=&%T93TB=7!T;V1A=&4B
M/@H@(#QT:71L93XF(W@V-#$[)B-X-C1!.R8C>#8T-#LF(W@V,D$[)B-X-C,Q
M.R8C>#8T-SLF(W@V,C<[(#H@)B-X-C0Q.R8C>#8T03LF(W@V-#0[)B-X-C)!
M.R8C>#8S,3LF(W@V-$$[)B-X-C0V.R8C>#9!1CL@)B-X-C,R.R8C>#8T-3LF
M(W@V,C<[)B-X-C0V.R`F(W@V-#@[)B-X-C,Q.R8C>#8T.#LF(W@V,D8[/"]T
M:71L93X@"B`@/&AE861I;F<^)B-X-C(R.R8C>#8T03LF(W@V,C<[("8C>#8T
M,CLF(W@V-#@[)B-X-C(W.R8C>#8T-CLF(W@V-$$[)B-X-C0V.R`F(W@V-#$[
M)B-X-C1!.R8C>#8T-#LF(W@V,D$[)B-X-C,Q.R8C>#8T-SLF(W@V,C<[("8C
M>#8R1CLF(W@V,S$[("8C>#8S,CLF(W@V-#4[)B-X-C(W.R8C>#8T-CL@)B-X
M-C0X.R8C>#8S,3LF(W@V-#@[)B-X-C)&.R`F(W@V,C<[)B-X-C,Y.R8C>#8T
M-3LF(W@V,C<[)B-X-C0T.R`F(W@V048[)B-X-C,Q.R8C>#8R1CLF(W@V,D8[
M)B-X-C%&.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(W.R8C>#8T-CLF(W@V
M,D$[)B-X-C)%.R8C>#8R-SLF(W@V,C@[("8C>#8R-SLF(W@V-$$[)B-X-C0V
M.R`F(W@V048[)B-X-C,R.R8C>#8T03LF(W@V-#8[)B-X-C0W.R`F(W@V,C@[
M)B-X-C(W.R8C>#8S.3LF(W@V,D([("8C>#8R-SLF(W@V,SD[)B-X-C0U.R8C
M>#8R-SLF(W@V-#0[("8C>#8T,3LF(W@V-$$[)B-X-C0T.R8C>#8R03LF(W@V
M,S$[)B-X-C0W.R8C>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X-C0W.R8C>#8T
M-CLF(W@V048[)B-X-C(W.R8C>#8T-3L@)B-X-C0X.R8C>#8S,3LF(W@V-#@[
M)B-X-C)&.R`F(W@V,C@[)B-X-C0W.R!)35`@)B-X-C0U.R8C>#9#0SLF(W@R
M,#!#.R8C>#9!1CLF(W@V,S$[)B-X-C)&.R8C>#8R1CLN/"]P87)A/B`*/"]E
M;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUO;BUD:7-P;&%Y(B!M9#4](F8U
M869C,S`U-#`R968U,F)A9#$P.#DS,V8S9C,S,CDQ(B!S=&%T93TB=7!T;V1A
M=&4B/@H@(#QT:71L93XF(W@V-#$[)B-X-C1!.R8C>#8T-#LF(W@V,D$[)B-X
M-C,Q.R8C>#8T-SLF(W@V,C<[(#H@)B-X-C0Q.R8C>#8T03LF(W@V-#0[)B-X
M-C)!.R8C>#8S,3LF(W@V-$$[)B-X-C0V.R8C>#9!1CL@)B-X-C)&.R8C>#8S
M,3L@)B-X-C0W.R8C>#8S,3L@)B-X-C(X.R8C>#8S,3LF(W@V-#@[)B-X-C,R
M.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-CLF(W@V-$$[/"]T:71L93X@
M"B`@/&AE861I;F<^)B-X-C(R.R8C>#8T03LF(W@V,C<[("8C>#8T,CLF(W@V
M-#@[)B-X-C(W.R8C>#8T-CLF(W@V-$$[)B-X-C0V.R`F(W@V-#$[)B-X-C1!
M.R8C>#8T-#LF(W@V,D$[)B-X-C,Q.R8C>#8T-SLF(W@V,C<[("8C>#8R1CLF
M(W@V,S$[("8C>#8T-SLF(W@V,S$[("8C>#8S,CLF(W@V-#4[)B-X-C(W.R8C
M>#8T-CL@)B-X-D$Y.R8C>#8T-SL@24Y"3U@@)B-X-C0V.R8C>#8T-3LF(W@V
M,C<[)B-X-C1!.R8C>#8S-#L@)B-X-C)&.R8C>#8R-SLF(W@V,D8[)B-X-C0W
M.R`F(W@V-#4[)B-X-D-#.R8C>#(P,$,[)B-X-C,T.R8C>#8T.#LF(W@V,D8[
M("8C>#8R-SLF(W@V,SD[)B-X-C0U.R8C>#8R-SLF(W@V-#0[("8C>#9!1CLF
M(W@V,S$[)B-X-C)&.R8C>#8R1CLF(W@V,48[/"]H96%D:6YG/B`*("`\<&%R
M83XF(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-D%&.R8C>#8S,CLF(W@V-$$[
M)B-X-C0V.R8C>#8T-SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#8T-CLF
M(W@V,D$[)B-X-C)%.R8C>#8R-SLF(W@V,C@[("8C>#9!.3LF(W@V-#8[)B-X
M-C1!.R8C>#8R1CL@)B-X-C)!.R8C>#8R-SL@)B-X-C)&.R8C>#8S,3L@)B-X
M-C0W.R8C>#8S,3L@)B-X-C,R.R8C>#8T-3LF(W@V,C<[)B-X-C0V.R`F(W@V
M03D[)B-X-C0W.R!)3D)/6"`F(W@V,S$[)B-X-C(W.R`F(W@V-#4[)B-X-C,T
M.R8C>#8R-SLF(W@V-#<[)B-X-C)&.R8C>#8T-SL@)B-X-C0U.R8C>#9#0SLF
M(W@R,#!#.R8C>#9!.3LF(W@V-#8[)B-X-C1!.R8C>#8R1CLF(W@V,$,[("8C
M>#8T,3LF(W@V-$$[)B-X-C0T.R8C>#8R03LF(W@V,S$[)B-X-C0W.R8C>#8R
M-SL@)B-X-C(W.R8C>#8S.3LF(W@V-#4[)B-X-C(W.R8C>#8T-#L@)B-X-C,T
M.R8C>#8T.#LF(W@V-#8[)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB9FEL=&5R+6%N>2UM86EL8F]X(B!M9#4](C<Q8S4Q93@S.3`Y
M9CED,&)D-#0P9#(R,#<W,F5E,V,V(B!S=&%T93TB=7!T;V1A=&4B/@H@(#QT
M:71L93XF(W@V-#$[)B-X-C1!.R8C>#8T-#LF(W@V,D$[)B-X-C,Q.R8C>#8T
M-SLF(W@V,C<[(#H@)B-X-C0Q.R8C>#8T03LF(W@V-#0[)B-X-C)!.R8C>#8S
M,3L@)B-X-D$Y.R8C>#8S,3LF(W@V,D8[)B-X-C0V.R`F(W@V-#8[)B-X-C(W
M.R8C>#8T-3LF(W@V-#<[)B-X,C`P0SLF(W@V,D8[)B-X-C(W.R8C>#8T-CL\
M+W1I=&QE/B`*("`\:&5A9&EN9SXF(W@V,C([)B-X-C1!.R8C>#8R-SL@)B-X
M-C0R.R8C>#8T.#LF(W@V,C<[)B-X-C0V.R8C>#8T03LF(W@V-#8[("8C>#8T
M,3LF(W@V-$$[)B-X-C0T.R8C>#8R03LF(W@V,S$[)B-X-C0W.R8C>#8R-SL@
M)B-X-C(X.R8C>#8T-SL@)B-X-C0W.R8C>#8S,3L@)B-X-C0V.R8C>#8R-SLF
M(W@V-#4[)B-X-C0W.R8C>#(P,$,[)B-X-C)&.R8C>#8R-SLF(W@V-#8[("8C
M>#8R-SLF(W@V,SD[)B-X-C0U.R8C>#8R-SLF(W@V-#0[("8C>#8S-#LF(W@V
M-#@[)B-X-C0V.R8C>#8R1CLF(W@V,48[/"]H96%D:6YG/B`*("`\<&%R83XF
M(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W.R8C>#8R.#L@)B-X
M-C(W.R8C>#8T03LF(W@V-#8[("8C>#9!1CLF(W@V,S([)B-X-C1!.R8C>#8T
M-CLF(W@V-#<[("8C>#8R.#LF(W@V,C<[)B-X-C,Y.R8C>#8R0CL@)B-X-C0U
M.R8C>#8T03LF(W@R,#!#.R8C>#8S-#LF(W@V-#@[)B-X-C)&.R`F(W@V,D$[
M)B-X-C(W.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C(X.R8C>#8R03LF
M(W@V-#@[)B-X-C(W.R8C>#8T-CLF(W@V-$$[)B-X-C)&.R`F(W@V-#([)B-X
M-C0X.R8C>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8T-CL@)B-X-C0Q.R8C>#8T
M03LF(W@V-#0[)B-X-C)!.R8C>#8S,3LF(W@V-#<[)B-X-C(W.R`F(W@V,S$[
M)B-X-C(W.R`F(W@V,C@[)B-X-C0W.R`F(W@V-#<[)B-X-C,Q.R`F(W@V-#8[
M)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X,C`P0SLF(W@V,D8[)B-X-C(W.R8C
M>#8T-CL@)B-X-C(W.R8C>#8S.3LF(W@V-#4[)B-X-C(W.R8C>#8T-#L@)B-X
M-D$Y.R8C>#8T-CLF(W@V-$$[)B-X-C)&.R@@)B-X-C(X.R8C>#8R-SL@)B-X
M-C(W.R8C>#8T-CLF(W@V,D$[)B-X-C)%.R8C>#8R-SLF(W@V,C@[("8C>#8R
M-SLF(W@V-$$[)B-X-C0V.R`F(W@V048[)B-X-C,R.R8C>#8T03LF(W@V-#8[
M)B-X-C0W.R8C>#8P0SL@)B-X-C(R.R8C>#8T03LF(W@V03D[)B-X-C0X.R8C
M>#8T-CLF(W@V0T,[("8C>#8R1CLF(W@V,S$[("8C>#9!.3LF(W@V-#8[)B-X
M-C(W.R8C>#8S,3L@)B-X-C0W.R8C>#8S,3L@)B-X-C0V.R8C>#8R-SLF(W@V
M-#4[)B-X-C0W.R8C>#(P,$,[)B-X-C)&.R8C>#8R-SLF(W@V-#8[("8C>#8T
M-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V,S0[("8C>#8R1CLF(W@V,C<[
M)B-X-C)&.R8C>#8T-SL@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C
M>#8R1CL@)B-X-C,T.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-SL@)B-X-C(X.R8C
M>#8T-SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8R-SLF(W@V,D,[)B-X
M-C(W.R8C>#8S,CLF(W@V-#<[("8C>#8R-SLF(W@V,SD[)B-X-C0U.R8C>#8R
M-SLF(W@V-#0[("8C>#8T,CLF(W@V-#@[)B-X-C(W.R8C>#8T-CLF(W@V-$$[
M)B-X-C0V.R`F(W@V-#$[)B-X-C1!.R8C>#8T-#LF(W@V,D$[)B-X-C,Q.R`F
M(W@V,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C,Q.R`F(W@V,S$[)B-X-C0X.R8C
M>#9#0SL@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V
M-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C(R.R8C>#8T-CL@)B-X-C=%.R8C>#8T
M.#LF(W@V,S0[)B-X-C0W.R`F(W@V,S$[)B-X-C(W.R8C>#8P0SL@)B-X-C)%
M.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8R1CL@)B-X-C)&.R8C>#8R-SLF
M(W@V,D8[*2X@)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V,D$[
M)B-X-C0X.R8C>#8R0SLF(W@V-#<[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C
M>#8T03LF(W@V-$$[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F(W@V,C@[)B-X
M-C0W.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V,D$[("8C>#8W13LF(W@V
M-$$[)B-X-C,T.R8C>#(P,$,[)B-X-C0Q.R8C>#8S,3LF(W@V,S8[("8C>#8T
M,3LF(W@V-$$[)B-X-C0T.R8C>#8R03LF(W@V,S$[)B-X-C0W.R8C>#8R-SL@
M)B-X-C)!.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R`F(W@V,C@[)B-X-C,Q.R`F
M(W@V,S$[)B-X-C0X.R8C>#9#0SL@)B-X-C0V.R8C>#8R-SLF(W@V-#4[)B-X
M-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8S,3LF(W@V
M,S,[)B-X-C1!.R8C>#8R1CLF(W@V-#<[("8C>#8R-SLF(W@V,SD[)B-X-C0U
M.R8C>#8R-SLF(W@V-#0[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,S0[
M)B-X-C0X.R8C>#8T-CLF(W@V,D8[("8C>#8S,CLF(W@V-$$[)B-X-C,Q.R8C
M>#8R-SL@)B-X-C(W.R8C>#8S.3LF(W@V-#4[)B-X-C(W.R8C>#8T-#L@)B-X
M-C0Q.R8C>#8T03LF(W@V-#0[)B-X-C)!.R8C>#8S,3LF(W@V-#<[)B-X-C(W
M.R`F(W@V,C@[)B-X-C,Q.R`F(W@V,S$[)B-X-C0X.R8C>#9#0SL@)B-X-C=%
M.R8C>#8T.#LF(W@V,S0[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF
M(W@V0T,[("8C>#8R1CLF(W@V-$$[)B-X-D%&.R8C>#8S,3L@)B-X-C0V.R8C
M>#8R03LF(W@V,C<[)B-X-C1!.R8C>#8R0SL@)B-X-C-!.R8C>#8T03LF(W@V
M,S$[("8C>#8T-3LF(W@V-#8[)B-X-C)!.R8C>#8S.#LF(W@V,S$[)B-X-C0W
M.R8C>#(P,$,[)B-X-C(W.R8C>#8T03LF(W@V-$$[("8C>#8T-SLF(W@V-#4[
M)B-X-C@V.R8C>#8T.#LF(W@V-#8[("8C>#8R-SLF(W@V-#8[)B-X-C)!.R8C
M>#8T,CLF(W@V,C<[)B-X-C0T.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V
M,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[)B-X-C!#.R`F(W@V,D0[)B-X-C,P
M.R8C>#8T,3L@)B-X-C-!.R8C>#8T03LF(W@V,S$[("8C>#8T-3LF(W@V-#8[
M)B-X-C)!.R8C>#8S.#LF(W@V,S$[)B-X-C0W.R`F(W@V,C([)B-X-C0V.R8C
M>#8T-SLF(W@V,C<[("8C>#8T.#L@)B-X-C1!.R8C>#8R-SLN+BX@)B-X-C0U
M.R8C>#9#0SLF(W@R,#!#.R8C>#8R03LF(W@V-#@[)B-X-C(W.R8C>#8T-CLF
M(W@V,D8[("8C>#8R1CLF(W@V,C<[)B-X-C,T.R8C>#8R03LF(W@V-#<[("8C
M>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8R1CLN/"]P87)A/B`*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C:"UP=6)K97DB(&UD-3TB
M.3<T-#9D8F)B,C<V,39B-&9A,SEB93@P,64Q,&1F,F0B('-T871E/2)U<'1O
M9&%T92(^"B`@/'1I=&QE/E!'4"`Z("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C
M>#8S,SLF(W@V,D$[("8C>#8T-CLF(W@V-#4[)B-X-C0X.R8C>#8R1CLF(W@V
M-#8[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,Y.R8C>#8T
M-3LF(W@V-#@[)B-X-C0U.R8C>#9#0SL\+W1I=&QE/B`*("`\:&5A9&EN9SXF
M(W@V-T4[)B-X-D-#.R8C>#8T.#LF(W@V,S,[)B-X-C)!.R`F(W@V-#8[)B-X
M-C0U.R8C>#8T.#LF(W@V,D8[)B-X-C0V.R`F(W@V03D[)B-X-C0T.R8C>#8T
M03LF(W@V,D8[("8C>#8S.3LF(W@V-#4[)B-X-C0X.R8C>#8T-3LF(W@V0T,[
M/"]H96%D:6YG/B`*("`\<&%R83XF(W@V,C<[)B-X-D%&.R8C>#8S,3L@)B-X
M-C(W.R8C>#8T03LF(W@V-#8[("8C>#9!1CLF(W@V,S([)B-X-C1!.R8C>#8T
M-CLF(W@V-#<[("8C>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[
M)B-X-C(X.R`F(W@V,S0[)B-X-C0X.R8C>#8R1CLF(W@V,$,[("8C>#8T03LF
M(W@V03D[("8C>#8T-CLF(W@V,S,[)B-X-C)%.R8C>#8T-SL@)B-X-C(W.R8C
M>#8S,CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,SD[)B-X
M-C0U.R8C>#8T.#LF(W@V-#4[)B-X-D-#.R!01U`@)B-X-C(X.R8C>#8T-SL@
M)B-X-C0W.R8C>#8T-3LF(W@V,S$[)B-X-C(W.R8C>#8T-SL@)B-X-C0V.R8C
M>#8R-SLF(W@V-#4[)B-X-C0W.R`F(W@V,D4[)B-X-C(W.R8C>#8S,3LF(W@V
M,D,[("8C>#8S-#LF(W@V,D8[)B-X-C0W.R8C>#8P0SL@)B-X-C(W.R8C>#8S
M,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#L@)B-X-C0U.R8C>#9#0SLF(W@R,#!#
M.R8C>#9!1CLF(W@V,S$[)B-X-C)&.R8C>#8R1CLN("8C>#8S-SLF(W@V,S$[
M)B-X-C1!.R8C>#8T,CLF(W@V-#<[("8C>#8S.3LF(W@V-#4[)B-X-C0T.R8C
M>#9!.3LF(W@V,S$[)B-X-C)&.R`F(W@V-T4[)B-X-C1!.R8C>#8S-#LF(W@R
M,#!#.R8C>#8T,3LF(W@V,S$[)B-X-C,V.R`F(W@V,S$[)B-X-C(W.R`F(W@V
M,C<[)B-X-C,R.R`F(W@V,S<[)B-X-C,Q.R8C>#8T03LF(W@V-#([("8C>#8S
M-3LF(W@V-#$[)B-X-C)$.R8C>#8T-SL@)B-X-D%&.R8C>#8S,CLF(W@V-$$[
M)B-X-C0V.R8C>#8T-SLF(W@R,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R!0
M1U`@)B-X-C0U.R8C>#9#0SLF(W@R,#!#.R8C>#8R03LF(W@V-#@[)B-X-C(W
M.R8C>#8T-CL@)B-X-C)!.R8C>#8T-CLF(W@V,S@[)B-X-C1!.R8C>#8T-3L@
M)B-X-C0V.R8C>#8T-3LF(W@V-#@[)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO;BUS8V%N+6)O9'DB(&UD-3TB-F)A
M86%D83!D-#9D8S%A8C`Y-#$P.#=F,C,U9C,U.6(B('-T871E/2)U<'1O9&%T
M92(^"B`@/'1I=&QE/E!'4"`Z("8C>#8R.#LF(W@V,S$[)B-X-C,Q.R8C>#8S
M,SLF(W@V-$$[("8C>#8R.#LF(W@V,D8[)B-X-C0V.R8C>#8T-SLF(W@V-30[
M("8C>#8T-3LF(W@V,D$[)B-X-C0V.SPO=&ET;&4^(`H@(#QH96%D:6YG/B8C
M>#8R.#LF(W@V,S$[)B-X-C,Q.R8C>#8S,SLF(W@V-$$[("8C>#8R.#LF(W@V
M,D8[)B-X-C0V.R8C>#8T-SLF(W@V-30[("8C>#8T-3LF(W@V,D$[)B-X-C0V
M.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(W.R8C>#9!1CLF(W@V,S$[("8C
M>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V048[)B-X-C,R.R8C>#8U,#LF(W@V
M-$$[)B-X-C0V.R8C>#8T-SL@)B-X-C(W.R8C>#8T-CLF(W@V,D$[)B-X-C)%
M.R8C>#8R-SLF(W@V,C@[("8C>#8S-#LF(W@V-#@[)B-X-C)&.R8C>#8P0SL@
M24U0("8C>#8R.#LF(W@V,D8[)B-X-C0V.R8C>#8T-SLF(W@V-30[("8C>#8R
M03LF(W@V-#4[)B-X-C(W.R8C>#8T-3L@)B-X-C=%.R8C>#8T03LF(W@V,T$[
M)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R`F(W@V,S$[)B-X-C(W.R`F
M(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C>#8T03LF(W@V,C<[)B-X
M-C0Q.R8C>#8R03LF(W@V-#8[("8C>#8R1CLF(W@V,C<[)B-X-C)&.R8C>#8T
M-SL@4$=0("8C>#8R0SLF(W@V,S,[)B-X-C)!.R8C>#8R0SLF(W@V-#@[("8C
M>#9!.3LF(W@V,S$[)B-X-C)&.R8C>#8T-SL@)B-X-C0X.R`F(W@V-#8[)B-X
M-C)!.R8C>#8R-SLF(W@V-$$[)B-X-C)#.R`F(W@V,S$[)B-X-C(W.R`F(W@V
M-#8[)B-X-C,T.R8C>#8R-SLF(W@V-#8[("8C>#8R13LF(W@V-#@[)B-X-C(W
M.R8C>#8T-SLF(W@V,D8[("8C>#8R1CLF(W@V,C<[)B-X-C)&.RX@)B-X-C(X
M.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V,D$[)B-X-C0X.R8C>#8R0SLF
M(W@V-#<[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X
M-C)&.R`F(W@V03D[)B-X-C0W.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V
M,D4[)B-X-C(W.R8C>#8R.#L@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#9!
M1CLF(W@V,S([)B-X-C1!.R8C>#8T-CLF(W@V-#<[("8C>#8R.#LF(W@V,C<[
M)B-X-C,Y.R8C>#8R0CL@)B-X-D$Y.R8C>#8T-CLF(W@V,D8[)B-X-D-#.R`F
M(W@V,S,[)B-X-C(W.R8C>#8T-3LF(W@V,C<[)B-X-C0V.R8C>#8T-SL@)B-X
M-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8R1CL@)B-X-D%&.R8C>#8S
M-#LF(W@V,D$[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6]P=&EO;G,M96YC<GEP="(@;60U/2(Q,#$R,30T9C<T.68Q.68U83(T
M8V5F,S@V,#%D86$W,2(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^)B-X
M-C(W.R8C>#8T03LF(W@V,D,[)B-X-C(W.R8C>#8R1CL@)B-X-C=%.R8C>#8T
M03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@.B`F(W@V048[)B-X-C,R.R8C>#8T
M03LF(W@V-#8[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[
M("8C>#8S,3LF(W@V-#4[)B-X-C,R.R8C>#8R.#LF(W@V-#8[)B-X-C)&.R8C
M>#9#0SL\+W1I=&QE/B`*("`\:&5A9&EN9SXF(W@V,C@[)B-X-C)&.R8C>#8T
M.#LF(W@V-#8[("8C>#8S,3LF(W@V-#4[)B-X-C,R.R8C>#8R.#LF(W@V-#8[
M)B-X-C)&.R8C>#9#0SL\+VAE861I;F<^(`H@(#QP87)A/B8C>#8R-SLF(W@V
M,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8T-3LF(W@V,D$[)B-X-C0V
M.R`F(W@V,C@[)B-X-C)&.R8C>#8T.#LF(W@V-#8[("8C>#8S,3LF(W@V-#4[
M)B-X-C,R.R8C>#8R.#LF(W@V-#8[)B-X-C)&.R8C>#9#0SL@.B`F(W@V-#4[
M)B-X-C)!.R8C>#8T-CL@)B-X-C,S.R8C>#8R-SLF(W@V,D8[)B-X-C0W.SPO
M<&%R83X@"B`@/&AE861I;F<^)B-X-C,Q.R8C>#8T-3LF(W@V,S([)B-X-C(X
M.R8C>#8T-CLF(W@V,D8[)B-X-D-#.R!01U`@)B-X-C=%.R8C>#8T03LF(W@V
M,T$[)B-X-C(W.R8C>#8T-3L\+VAE861I;F<^(`H@(#QP87)A/B8C>#8R-SLF
M(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V,C<[)B-X
M-C1!.R8C>#8T-CL@)B-X-D%&.R8C>#8S,CLF(W@V-$$[)B-X-C0V.R8C>#8T
M-SL@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@)B-X-C0Q
M.R8C>#8S.3LF(W@V-#0[)B-X-D-#.R`F(W@V,S$[)B-X-C(W.R`F(W@V,C@[
M)B-X-C(W.R`F(W@V,C<[)B-X-C,S.R8C>#8R03LF(W@V-#$[)B-X-C(W.R8C
M>#8R1CLF(W@V-#<[("8C>#8R-SLF(W@V,S([(%!'4"`F(W@V-#@[("8C>#9!
M.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,Y.R8C>#8T-3LF(W@V-#@[
M)B-X-C0U.R8C>#9#0SL@)B-X-C,T.R8C>#8R13LF(W@V,S4[)B-X-D-#.R`F
M(W@V048[)B-X-C1!.R8C>#8S,3LF(W@V-#8[)B-X-C)&.R8C>#8T-SL@)B-X
M-C,Q.R8C>#8T-3LF(W@V,S([("8C>#8T-CLF(W@V-#4[)B-X-C0X.R8C>#8R
M1CLF(W@V-#<[("8C>#8T.#L@)B-X-C,S.R8C>#8W13LF(W@V,S,[("8C>#8R
M,CLF(W@V-#8[)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#8S,3LF(W@V,S,[
M)B-X-C(W.R8C>#8T-#L@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C
M>#8R1CL@)B-X-D$Y.R8C>#8S,3LF(W@V,D8[+B`F(W@V,D8[)B-X-C,Q.R`F
M(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C)$.R8C>#8R-SLF(W@V-#0[)B-X
M-C)!.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C)!.R8C>#8T-CLF(W@V
M-#<[)B-X-C(W.R`F(W@V-#([)B-X-C(W.R8C>#8R1CLF(W@V,S$[("8C>#8R
M.#LF(W@V-#<[("8C>#8R-SLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[
M("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[("8C>#8R.#LF
M(W@V-#<[("8C>#8T03LF(W@V03D[("8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C
M>#8T-CLF(W@V,D8[)B-X-C0W.R`F(W@V,D4[)B-X-C0X.R8C>#8R-SLF(W@V
M-#<[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C>#8T.#LF(W@V,D8[+B`F(W@V
M,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&
M.R`F(W@V,D0[)B-X-C)!.R8C>#8T-3LF(W@V,C<[)B-X-C4R.R`F(W@V03D[
M)B-X-C0T.R8C>#8T03LF(W@V,D8[("8C>#8S.3LF(W@V-#4[)B-X-C0X.R8C
M>#8T-3LF(W@V0T,[("8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C>#8T-CLF(W@V
M,D8[)B-X-C0W.R`F(W@V,S$[)B-X-C(W.R`F(W@V,D8[)B-X-C,Q.R`F(W@V
M03D[)B-X-C)!.R8C>#8R-SLF(W@V,C@[)B-X-C@V.R8C>#8T-SLF(W@V-30[
M("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,D8[)B-X-C(W.R8C>#8S-#LF
M(W@V,D$[)B-X-C0W.R`F(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V-$$[)B-X
M-C)&.R`F(W@V,D$[)B-X-C(W.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V
M,C<[)B-X-C0U.R`F(W@V,C@[)B-X-C0W.R`F(W@V,D8[)B-X-C,Q.R8C>#8S
M,SLF(W@V,D$[)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[
M)B-X-C0T.R`F(W@V,S0[)B-X-C0X.R8C>#8R1CLN/"]P87)A/B`*("`\:&5A
M9&EN9SXF(W@V,C<[)B-X-C0U.R8C>#8S-CLF(W@V,C<[)B-X-C(Q.R!01U`@
M)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L\+VAE861I;F<^
M(`H@(#QP87)A/B8C>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[
M)B-X-C(X.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-D%&.R8C>#8S,CLF
M(W@V-$$[)B-X-C0V.R8C>#8T-SL@)B-X-C(X.R8C>#8R-SLF(W@V,SD[)B-X
M-C)".R`F(W@V-#4[)B-X-D-#.R8C>#(P,$,[)B-X-C,T.R8C>#8T.#LF(W@V
M,D8[("8C>#8R03LF(W@V,C<[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R
M-SLF(W@V-#4[("8C>#8R0SLF(W@V,C<[)B-X-C,Q.R8C>#9#0SL@)B-X-C(X
M.R8C>#8R-SL@)B-X-C(W.R8C>#8S,SLF(W@V,D$[)B-X-C0Q.R8C>#8R-SLF
M(W@V,D8[)B-X-C0W.R`F(W@V,C<[)B-X-C,R.R!01U`@)B-X-C0X.R`F(W@V
M03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[("8C>#8R13LF(W@V,S4[)B-X-C0X
M.R8C>#8S-3LF(W@V0T,[("8C>#8S-#LF(W@V,D4[)B-X-C,U.R8C>#9#0SL@
M)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8R-SLF(W@V-#4[)B-X-C,V.R8C
M>#8R-SLF(W@V,C$[("8C>#9!1CLF(W@V,S$[)B-X-C)&.R8C>#8R1CLN("8C
M>#9!1CLF(W@V-$$[)B-X-C,Q.R8C>#8T-CLF(W@V,D8[)B-X-C0W.R8C>#8U
M-#L@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@)B-X-C(X
M.R8C>#8R-SL@)B-X-D$Y.R8C>#8T-3LF(W@V03D[("8C>#9!.3LF(W@V-#0[
M)B-X-C1!.R8C>#8R1CL@)B-X-C,Y.R8C>#8T-3LF(W@V-#@[)B-X-C0U.R8C
M>#9#0SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T,CLF(W@V,C<[)B-X
M-C)&.R8C>#8S,3L@)B-X-C(X.R8C>#8T-SL@)B-X-C,T.R8C>#8T-CLF(W@V
M,C<[)B-X-C,S.R8C>#8R-SLF(W@V-$$[)B-X-C1!.R`F(W@V,S0[)B-X-C0U
M.R8C>#8R-SL@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8R1CL@
M)B-X-C(X.R8C>#8T.#LF(W@V,D8[+CPO<&%R83X@"B`@/&AE861I;F<^)B-X
M-C(W.R8C>#8T-3LF(W@V,S8[)B-X-C(W.R8C>#8R,3LO)B-X-C,Q.R8C>#8T
M-3LF(W@V,S([)B-X-C(X.R8C>#8T-CLF(W@V,D8[)B-X-D-#.R!01U`@)B-X
M-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L\+VAE861I;F<^(`H@
M(#QP87)A/B8C>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X
M-C(X.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-D%&.R8C>#8S,CLF(W@V
M-$$[)B-X-C0V.R8C>#8T-SL@)B-X-C(W.R8C>#8R.#LF(W@V,D$[)B-X-C)&
M.R8C>#8R-SL@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@
M)B-X-C,Q.R8C>#8R-SL@)B-X-C(X.R8C>#8T-SL@)B-X-C,U.R8C>#8T.#LF
M(W@V,S$[)B-X-C)!.R`F(W@V,D8[)B-X-C1!.R8C>#8R0SLF(W@V-$$[)B-X
M-C)!.R8C>#8R-SLF(W@V-#0[)B-X-D-#.R`F(W@V,C<[)B-X-C0U.R8C>#8S
M-CLF(W@V,C<[)B-X-C(Q.R`F(W@V03D[)B-X-C,Q.R8C>#8R1CLF(W@V-#<[
M("8C>#8T.#L@)B-X-C,S.R8C>#8W13LF(W@V,S,[("8C>#8T-CLF(W@V,D$[
M)B-X-C1!.R8C>#8R0SLF(W@V-#<[("8C>#8S,3LF(W@V,C<[("8C>#8S,3LF
M(W@V-#4[)B-X-C,R.R`F(W@V-#4[)B-X-D-#.R8C>#(P,$,[)B-X-C0V.R8C
M>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8R1CLN/"]P87)A/B`*("`\:&5A9&EN
M9SXF(W@V,S$[)B-X-C0U.R8C>#8S,CLF(W@V,C@[)B-X-C0V.R8C>#8R1CLF
M(W@V0T,[(%,O34E-12`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X
M-C0U.SPO:&5A9&EN9SX@"B`@/'!A<F$^5$]$3SPO<&%R83X@"B`@/&AE861I
M;F<^)B-X-C(W.R8C>#8T-3LF(W@V,S8[)B-X-C(W.R8C>#8R,3L@4R]-24U%
M("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[/"]H96%D:6YG
M/B`*("`\<&%R83Y43T1//"]P87)A/B`*("`\:&5A9&EN9SXF(W@V,C<[)B-X
M-C0U.R8C>#8S-CLF(W@V,C<[)B-X-C(Q.R\F(W@V,S$[)B-X-C0U.R8C>#8S
M,CLF(W@V,C@[)B-X-C0V.R8C>#8R1CLF(W@V0T,[(%,O34E-12`F(W@V-T4[
M)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.SPO:&5A9&EN9SX@"B`@/'!A
M<F$^5$]$3SPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E
M<G9I97<B(&UD-3TB,C1B-3$S.&(T8C4S9C<S8C5F,F8R-S,Y931C,3@U.&0B
M('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/E!'4"`Z("8C>#8T-3LF(W@V
M,S$[)B-X-C0X.R8C>#8S,3L\+W1I=&QE/B`*("`\:&5A9&EN9SY01U`@)B-X
M-C@V.R8C>#8T03LF(W@V,S,[)B-X-C)!.R8C>#8Q1CL\+VAE861I;F<^(`H@
M(#QP87)A/E!'4"`F(W@V,C<[)B-X-C(X.R8C>#8S,CLF(W@V,C<[)B-X-C,Q
M.R8C>#9#0SL@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V,C<[
M)B-X-C,Q.R8C>#8R03LF(W@V,C@[)B-X-C(W.R8C>#8S-SLF(W@V,C<[)B-X
M-C)!.R`F(W@V-#@[("8C>#8S,#LF(W@V,D4[)B-X-C1!.R8C>#8S,3LF(W@V
M-#<[)B-X,C`P0SLF(W@V,S,[)B-X-C(W.R8C>#8S,CLF(W@V0T,[("8C>#8R
M-SLF(W@V-#4[)B-X-C0V.R`F(W@V,C<[)B-X-C,W.R8C>#8T-#LF(W@V,C<[
M)B-X-C,Y.R8C>#8R-SLF(W@V,D$[("8C>#8T-3LF(W@V0T,[)B-X,C`P0SLF
M(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V,D8[("8C>#9!.3LF(W@V-#<[("8C
M>#8R13LF(W@V,S4[)B-X-C0X.R8C>#8S-3LF(W@V,C<[("8C>#8R1CLF(W@V
M,S$[("8C>#8W13LF(W@V,S,[)B-X-C)!.R`F(W@V,C<[)B-X-C0T.R8C>#9!
M.3LF(W@V,D$[)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C1!.R8C>#9!.3L@
M)B-X-C(X.R8C>#8T-SL@)B-X-D$Y.R8C>#8R-SLF(W@V,S$[("8C>#9!1CLF
M(W@V,S$[)B-X-C0Q.R8C>#8R03LF(W@V-#<[("8C>#8T-3LF(W@V0T,[)B-X
M,C`P0SLF(W@V,S0[)B-X-C0X.R8C>#8R1CLN("8C>#8R-SLF(W@V,S([("8C
M>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V,C<[)B-X-C(X.R8C>#8S,CLF(W@V
M,C<[)B-X-C,Q.R`F(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C>#8S
M,3LF(W@V-#4[)B-X-C,R.R8C>#8R.#LF(W@V-#8[)B-X-C)&.R8C>#9#0SL@
M)B-X-C0X.R`F(W@V,C<[)B-X-C0U.R8C>#8S-CLF(W@V,C<[)B-X-C(Q.R`F
M(W@V,D8[)B-X-C1!.R8C>#8R0SLF(W@V-$$[)B-X-C)!.R8C>#8R-SLF(W@V
M-#0[)B-X-D-#.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U
M.R`F(W@V,C<[)B-X-C,S.R8C>#8R03LF(W@V-#$[)B-X-C(W.R8C>#8R1CLF
M(W@V-#<[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,S0[)B-X-C0X.R8C
M>#8R1CLN($E-4"`F(W@V,C<[)B-X-C,R.R!';G501R`F(W@V,C@[)B-X-C,Q
M.R8C>#8R-SLF(W@V0T,[("8C>#8T,3LF(W@V,S$[)B-X-C(W.R8C>#8T-SLF
M(W@V-#4[("8C>#8T-CLF(W@V-#4[)B-X-C0X.R8C>#8R1CLF(W@V-#8[("8C
M>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V,C<[)B-X-C0U.R8C>#9!.3LF(W@V
M,C<[)B-X-C0V.R`F(W@V,C<[)B-X-C,S.R8C>#8R03LF(W@V-#$[)B-X-C(W
M.R8C>#8R1CLF(W@V-#<[("8C>#8T-3LF(W@V0T,[)B-X,C`P0SLF(W@V-#8[
M)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H@(#QH96%D
M:6YG/B8C>#8R,CLF(W@V-$$[)B-X-C(W.R`F(W@V,C<[)B-X-C0U.R8C>#9!
M.3LF(W@V,C<[)B-X-C0V.R8C>#8R-SLF(W@V,D$[(%!'4"`F(W@V-#$[)B-X
M-C,Y.R8C>#8R-SLF(W@V-#0[("8C>#8S-#LF(W@V-#@[)B-X-C)&.R8C>#8Q
M1CL\+VAE861I;F<^(`H@(#QP87)A/B8C>#8R-SLF(W@V048[)B-X-C,Q.R`F
M(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-D%&.R8C>#8S,CLF(W@V-$$[)B-X
M-C0V.R8C>#8T-SL@)B-X-C0Q.R8C>#8S.3LF(W@V,C<[)B-X-C0T.R`F(W@V
M,S0[)B-X-C0X.R8C>#8R1CL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T
M,CLF(W@V,C<[)B-X-C)&.R8C>#8S,3L@)B-X-C(X.R8C>#8T-SL@)B-X-C(W
M.R8C>#8T03LF(W@V,D,[)B-X-C(W.R8C>#8R1CLO)B-X-C0U.R8C>#8S-#LF
M(W@V,C<[)B-X-C0W.R8C>#8R1CLF(W@V-#<[("8C>#9!.3LF(W@V-#0[)B-X
M-C1!.R8C>#8R1CLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@4$=0("8C>#8R13LF
M(W@V-#@[)B-X-C)&.R8C>#8P0SL@)B-X-C(W.R8C>#8T,3LF(W@V,S([)B-X
M-C0X.R8C>#8R1CLF(W@V-#8[("8C>#8T.#L@)B-X-C)$.R8C>#8S,#LF(W@V
M-#$[("8C>#9!.3LF(W@V,S$[)B-X-C)&.R8C>#8T-CL@)B-X-D$Y.R8C>#8T
M-#LF(W@V-$$[)B-X-C)&.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,SD[
M)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-D-#.R`F(W@V,D8[)B-X-C1!.R8C
M>#9!1CLF(W@V,S$[)B-X-C(W.R8C>#8T-CLF(W@V,$,[("8C>#8R13LF(W@V
M-#@[)B-X-C(W.R8C>#8T-CLF(W@V,D8[)B-X-C0V.R`F(W@V-T4[)B-X-C1!
M.R8C>#8S03LF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F
M(W@V,S$[)B-X-C0U.R8C>#8S,CL@)B-X-C,T.R8C>#8R1CLF(W@V-#<[)B-X
M-C4T.R`F(W@V,C([)B-X-C0V.R8C>#8T-SLF(W@V,C<[)B-X-C!#.R`F(W@V
M,D$[)B-X-C,T.R8C>#8R13LF(W@V-$$[)B-X-C,U.R`F(W@V,C<[)B-X-C0U
M.R8C>#8S-CLF(W@V,C<[)B-X-C(Q.R`F(W@V,D8[)B-X-C1!.R8C>#8R0SLF
M(W@V-$$[)B-X-C)!.R8C>#8R-SLF(W@V-#0[)B-X-D-#.R`F(W@V,C([)B-X
M-C0V.R8C>#8T-SLF(W@V,C<[("8C>#8T.#L@)B-X-C,Q.R8C>#8T-3LF(W@V
M,S([)B-X-C(X.R8C>#8T-CLF(W@V,D8[)B-X-D-#.R`F(W@V-#@[("8C>#8R
M-SLF(W@V-#4[)B-X-C,V.R8C>#8R-SLF(W@V,C$[("8C>#8T-CLF(W@V-#4[
M)B-X-C0X.R8C>#8R1CLF(W@V-#8[("8C>#8R1CLF(W@V-$$[)B-X-C)#.R8C
M>#8T03LF(W@V,D$[)B-X-C(W.R8C>#8T-#LF(W@V0T,[("8C>#8W13LF(W@V
M-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R8C>#8R-SLF(W@V0T,[
M("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,D4[)B-X-C0X.R8C>#8R-SLF
M(W@V-#<[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C>#8T.#LF(W@V,D8[+CPO
M<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C
M:"UP=6)K97DB(&UD-3TB-38Q8V4T,S,W,&%C-&%F8F-C,V8Y.#$X8SAF8F,R
M9C8B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/E!'4"`Z("8C>#9!1CLF
M(W@V,S([)B-X-C1!.R8C>#8T-CLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X
M-C(W.RT@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03L@)B-X
M-C0V.R8C>#8T-3LF(W@V-#@[)B-X-C)&.R8C>#8T-CL@)B-X-D$Y.R8C>#8T
M-#LF(W@V-$$[)B-X-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[
M)B-X-D-#.SPO=&ET;&4^(`H@(#QH96%D:6YG/B8C>#9!1CLF(W@V,S([)B-X
M-C1!.R8C>#8T-CLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R`Z("T@
M)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03L@)B-X-C0V.R8C
M>#8T-3LF(W@V-#@[)B-X-C)&.R8C>#8T-CL@)B-X-D$Y.R8C>#8T-#LF(W@V
M-$$[)B-X-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-D-#
M.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(W.R8C>#9!1CLF(W@V,S$[("8C
M>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V048[)B-X-C,R.R8C>#8T03LF(W@V
M-#8[)B-X-C0W.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W
M.R8C>#8R.#L@)B-X-C,T.R8C>#8T.#LF(W@V,D8[)B-X-C!#.R`F(W@V,D8[
M)B-X-C,Q.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V,D$[("8C>#8T.#LF
M(W@V,D,[)B-X-C0X.R8C>#8R1CLF(W@V,$,[("8C>#8T03LF(W@V03D[("8C
M>#8T-CLF(W@V,S,[)B-X-C)%.R8C>#8T-SL@)B-X-C(W.R8C>#8S,CL@)B-X
M-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T
M.#LF(W@V-#4[)B-X-D-#.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C(X
M.R8C>#8T-SL@)B-X-C0V.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R8C>#(P,$,[
M)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8R-SLF(W@V,S$[)B-X-C,S.R8C
M>#8R-SLF(W@V-#0[)B-X-D-#.R`F(W@V-T4[)B-X-D-#.R8C>#8T.#LF(W@V
M,S,[)B-X-C)!.R`F(W@V,D4[)B-X-C0X.R8C>#8R-SLF(W@V-#<[)B-X-C)&
M.R`F(W@V,S0[)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+6UA;F%G92UP=6)K97DB(&UD-3TB8C(X.65A-3@R-&(W9C8Y9C,U
M8S`W-3$T.3=F-&4Q8S,B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/E!'
M4"`Z("8C>#8T-3LF(W@V,D8[)B-X-C1!.R8C>#8S,3LF(W@V-$$[)B-X-C)!
M.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[)B-X-C0W.R8C>#8R-SLF
M(W@V0T,[("8C>#8S.3LF(W@V-#4[)B-X-C0X.R8C>#8T-3LF(W@V0T,[/"]T
M:71L93X@"B`@/&AE861I;F<^)B-X-C0U.R8C>#8S,3LF(W@V-#@[)B-X-C,Q
M.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C
M>#8S-3LF(W@V-#$[)B-X-C)$.R8C>#8T-SL@)B-X-C0Q.R8C>#8T-SLF(W@V
M,S$[)B-X-C,S.R8C>#8R03LF(W@V0T,[("8C>#8R-SLF(W@V,S([("8C>#9!
M.3LF(W@V,C<[)B-X-C,Q.R8C>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#8T-CL@
M)B-X-C0Q.R8C>#8S.3LF(W@V-#0[)B-X-D-#.R`F(W@V,S$[)B-X-C(W.R`F
M(W@V,D8[)B-X-C,Q.R`F(W@V03D[)B-X-C)!.R8C>#8R-SLF(W@V,C@[)B-X
M-C@V.R8C>#8T-SLF(W@V-30[("8C>#8R,CLF(W@V,D8[)B-X-C,Q.R8C>#8S
M,SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[)B-X-C!#.R`F(W@V03D[)B-X-C0W
M.R`F(W@V,D8[)B-X-C(W.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V03D[
M)B-X-C0T.R8C>#8T03LF(W@V,D8[("8C>#8S.3LF(W@V-#4[)B-X-C0X.R8C
M>#8T-3LF(W@V0T,[(%!'4"`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C(X
M.R8C>#8R-SLF(W@V,S0[)B-X-C0V.R8C>#8R1CLF(W@V,$,[("8C>#8R-SLF
M(W@V,S$[)B-X-C(W.R8C>#8R-CLF(W@V-#<[("8C>#8T-3LF(W@V-$$[)B-X
M,C`P0SLF(W@V,D8[)B-X-C0W.R8C>#8R1CLN("8C>#8R.#LF(W@V,C<[)B-X
M-C1!.R8C>#8R1CL@)B-X-C)!.R8C>#8T.#LF(W@V,D,[)B-X-C0W.R`F(W@V
M,D8[)B-X-C(W.R8C>#8S-#LF(W@V,D$[("8C>#9!.3LF(W@V-#<[("8C>#8R
M-SLF(W@V-$$[)B-X-C0V.R`F(W@V-#$[)B-X-C0W.R8C>#8S,3LF(W@V,S,[
M)B-X-C)!.R`F(W@V,D$[)B-X-C0V.R8C>#8T-SLF(W@V,C<[("8C>#8R1#LF
M(W@V,C<[)B-X-C0X.R8C>#9#0SL@)B-X-D$Y.R8C>#8R-SLF(W@V,S$[)B-X
M-C(X.R8C>#8S,3LF(W@V,C<[)B-X-C0V.R8C>#9#0SL@)B-X-C(W.R8C>#8S
M,SLF(W@V,D$[("8C>#9!.3LF(W@V-#<[(#$I)B-X-C,T.R8C>#8T-3LF(W@V
M,C<[("8C>#8R.#LF(W@V-#<[("8C>#8R,CLF(W@V-#8[)B-X-C0W.R8C>#8R
M-SL@)B-X-C1!.R8C>#9!.3L@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W
M.R8C>#8T-3L@)B-X-C,Q.R8C>#8T-3LF(W@V,S([("8C>#8S-#LF(W@V,D8[
M)B-X-C0W.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R`F
M(W@V03D[)B-X-C,Q.R8C>#8R1CLF(W@V-#<[)B-X,C`P0SLF(W@V,C<[)B-X
M-C1!.R8C>#8R1CL@+2`F(W@V-#@[("8C>#8T03LF(W@V,C<[("T@,BD@)B-X
M-C(W.R8C>#8T-3LF(W@V,S8[)B-X-C(W.R8C>#8R,3L@)B-X-C)&.R8C>#8T
M03LF(W@V,D,[)B-X-C1!.R8C>#8R03LF(W@V,C<[)B-X-C0T.R8C>#8T03L@
M)B-X-C(R.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R`F(W@V,S$[)B-X-C(W.R`F
M(W@V,S0[)B-X-C0V.R8C>#8R-SLF(W@V,S,[)B-X-C(W.R8C>#8T03LF(W@V
M-$$[("8C>#9!.3LF(W@V,S$[)B-X-C)&.R8C>#8T-SLF(W@R,#!#.R8C>#8R
M-SLF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H@(#QH96%D:6YG/B8C>#8T-3LF
M(W@V,S0[)B-X-C(W.R8C>#8T-SLF(W@V,D8[)B-X-C0W.SPO:&5A9&EN9SX@
M"B`@/'!A<F$^)B-X-C(X.R8C>#8R-SLF(W@V,S([)B-X-D$Y.R8C>#8S,3LF
M(W@V,D8[)B-X-C0V.R`F(W@V-$$[)B-X-D$Y.R`F(W@V-T4[)B-X-C0V.R8C
M>#8R0SLF(W@V,S$[)B-X-C0W.R`F(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V
M0T,[("8C>#8T-3LF(W@V,S0[)B-X-C(W.R8C>#8T-SLF(W@V,D8[)B-X-C0W
M.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[)B-X-C0W.R8C>#8R-SLF
M(W@V0T,[("8C>#8S.3LF(W@V-#4[)B-X-C0X.R8C>#8T-3LF(W@V0T,[(%!'
M4"X\+W!A<F$^(`H@(#QH96%D:6YG/B8C>#8R0SLF(W@V,S([)B-X-C(V.R8C
M>#8T03LF(W@V,C<[)B-X-C)!.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C0V
M.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8S-#L@)B-X-C(X.R8C>#8S,3LF
M(W@V,D4[)B-X-D-#.R`F(W@V,C<[)B-X-C,R.R`F(W@V,D,[)B-X-C,R.R8C
M>#8R-CLF(W@V-$$[)B-X-C(W.R8C>#8R03L@)B-X-C)&.R8C>#8S,3L@)B-X
M-C0U.R8C>#8T.#LF(W@V,S$[)B-X-C)&.R`F(W@V03D[)B-X-C0T.R8C>#8T
M03LF(W@V,D8[("8C>#8S.3LF(W@V-#4[)B-X-C0X.R8C>#8T-3LF(W@V0T,[
M(%!'4"X\+W!A<F$^(`H@(#QH96%D:6YG/B8C>#8R1#LF(W@V,S`[)B-X-C0Q
M.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C)$.R8C>#8S,#LF(W@V-#$[("8C
M>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,Y.R8C>#8T-3LF(W@V
M-#@[)B-X-C0U.R8C>#9#0SL@)B-X-C(W.R8C>#8S,CL@)B-X-D$Y.R8C>#8R
M03LF(W@V,C<[)B-X-C(X.R8C>#8X-CLF(W@V-#<[)B-X-C4T.R`F(W@V,C([
M)B-X-C)&.R8C>#8S,3LF(W@V,S,[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M:6UP;W)T+7!U8FME>2(@;60U/2(V964Q,3,P8C0V93EF
M9C%C83EA9#-A,V$T-V4W8C,X,B(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET
M;&4^4$=0(#H@)B-X-C0U.R8C>#8R1CLF(W@V-$$[)B-X-C,Q.R8C>#8T03LF
M(W@V,D$[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CLF(W@V-#<[)B-X
M-C(W.R8C>#9#0SL@)B-X-C,Y.R8C>#8T-3LF(W@V-#@[)B-X-C0U.R8C>#9#
M0SL@+2`F(W@V,D8[)B-X-C,Q.R8C>#8T03LF(W@V,C<[)B-X-C0Q.R8C>#8R
M03L\+W1I=&QE/B`*("`\:&5A9&EN9SXF(W@V,D8[)B-X-C,Q.R8C>#8T03LF
M(W@V,C<[)B-X-C0Q.R8C>#8R03L@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X
M-C)&.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,SD[)B-X-C0U.R8C>#8T
M.#LF(W@V-#4[)B-X-D-#.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(W.R8C
M>#8T03LF(W@V-#8[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X
M-C=%.R8C>#8T-CLF(W@V,D,[)B-X-C,Q.R8C>#8T-SLF(W@R,#!#.R8C>#8R
M-SLF(W@V-$$[)B-X-C1!.R`F(W@V,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C(W
M.R8C>#8S,CL@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8R1CL@
M)B-X-C0V.R8C>#8T-3LF(W@V-#@[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F
M(W@V,D8[)B-X-C,Q.R`F(W@V,C([)B-X-C0V.R`F(W@V,S0[)B-X-C0U.R8C
M>#8R-SL@)B-X-C0R.R8C>#8R-SLF(W@V,D8[)B-X-C,Q.R`F(W@V,C@[)B-X
M-C0W.R`F(W@V,D([)B-X-C(X.R8C>#8R03L@)B-X-D$Y.R8C>#8T-#LF(W@V
M-$$[)B-X-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-D-#
M.R!01U`@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8T03LF(W@V
M,D8[("8C>#8R.#LF(W@V-#@[)B-X-C)&.RX@)B-X-C(W.R8C>#8T03LF(W@V
M-#8[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C0U.R8C>#8T
M03LF(W@R,#!#.R8C>#8R03LF(W@V-#@[)B-X-C(W.R8C>#8T-CLF(W@V,D8[
M("8C>#8R1CLF(W@V,S$[)B-X-C0X.R8C>#8T-CL@)B-X-C0Q.R8C>#8T03LF
M(W@V-#0[)B-X-C)&.R`F(W@V-#4[)B-X-C)!.R8C>#8T-CL@)B-X-C)&.R8C
M>#8S,3LF(W@V,D,[("8C>#8S-#LF(W@V-#@[)B-X-C)&.R`F(W@V-#@[("8C
M>#8T03LF(W@V,C<[("8C>#8R.#LF(W@V-#<[("8C>#8S-3LF(W@V-#@[)B-X
M-C,Q.R8C>#8R03L@)B-X-C1!.R8C>#9!.3L@)B-X-C=%.R8C>#8S,3LF(W@V
M-#@[)B-X-C0V.R8C>#8R1CLF(W@V-#<[("8C>#8R1CLF(W@V,S$[("8C>#8S
M,3LF(W@V,C<[)B-X-C1!.R8C>#8R-SLF(W@V-#8[)B-X-C0W.R`F(W@V,S0[
M)B-X-C)%.R8C>#8S-3LF(W@V0T,[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F
M(W@V-#([)B-X-C,Q.R8C>#8R-SLF(W@V,S$[("8C>#8R1CLF(W@V,C<[)B-X
M-C,T.R8C>#8R03LF(W@V-#<[("8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8R
M1CLN("8C>#8R1CLF(W@V,S$[("8C>#8T-SLF(W@V,S$[("8C>#8R1#LF(W@V
M,C<[)B-X-C0T.R8C>#8P0SL@)B-X-C@V.R8C>#8T-CLF(W@V,C<[)B-X-C0V
M.R8C>#8X-CLF(W@V-#<[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@
M)B-X-C0U.R8C>#8S.3LF(W@V,D$[)B-X-C(X.R8C>#8S,3L@)B-X-C(X.R8C
M>#8R-SLF(W@V,S0[)B-X-C)&.R8C>#8P0SL@)B-X-C(X.R8C>#8T-SL@)B-X
M-D$Y.R8C>#8R03LF(W@V,C<[)B-X-C(X.R8C>#8X-CLF(W@V-#<[)B-X-C4T
M.R`F(W@V,C([)B-X-C)&.R8C>#8S,3LF(W@V,S,[("8C>#8S-#LF(W@V-#4[
M)B-X-C(W.R`F(W@V,C<[)B-X-C0Q.R8C>#8S,CLF(W@V-#@[)B-X-C)&.R8C
M>#8T-SL@)B-X-C,T.R8C>#8R1CLF(W@V-#<[("8C>#8T.#L@)B-X-C=%.R8C
M>#8T-CLF(W@V,D,[)B-X-C,Q.R8C>#8T-SLF(W@V-30[("8C>#8R.#LF(W@V
M,C<[)B-X-C,R.R`F(W@V,S0[)B-X-C)&.R8C>#8T-SL@)B-X-C(X.R8C>#8S
M,SLF(W@V,D$[)B-X-C0W.R`F(W@V-#4[)B-X-D-#.R8C>#(P,$,[)B-X-C,T
M.R8C>#8T.#LF(W@V,D8[("8C>#8T.#L@)B-X-C)&.R8C>#8S,3L@)B-X-C-!
M.R8C>#8T03LF(W@V,S$[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R8C>#8S-3LF
M(W@V-#@[)B-X-C,Q.R8C>#8R03L@)B-X-C)&.R8C>#8T-#LF(W@V,C<[)B-X
M-C1!.R8C>#8T-#L@)B-X-C,Y.R8C>#8R1CLF(W@V-#4[("8C>#8R-SLF(W@V
M,SD[)B-X-C)!.R8C>#8R.#LF(W@V,C<[)B-X-C,Q.R`F(W@V03D[)B-X-C0T
M.R8C>#8T03LF(W@V,D8[("8C>#8R.#LF(W@V-$$[)B-X-C(W.R8C>#8T-CL@
M)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#9!1CLF(W@V,S$[)B-X-C)&.R8C
M>#8R1CLN/"]P87)A/B`*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R
M=FEE=RUP97)S;VYA;&ME>2(@;60U/2(R,C!A9C)B-S1A-3AF-#,P969D-S)D
M-F0V8C%F.3DS9B(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^4$=0(#H@
M)B-X-C0U.R8C>#8R1CLF(W@V-$$[)B-X-C,Q.R8C>#8T03LF(W@V,D$[("8C
M>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CLF(W@V-#<[)B-X-C(W.R8C>#9#
M0SL@)B-X-C,T.R8C>#8R13LF(W@V,S4[)B-X-D-#.SPO=&ET;&4^(`H@(#QH
M96%D:6YG/B8C>#8T-3LF(W@V,S$[)B-X-C0X.R8C>#8S,3L\+VAE861I;F<^
M(`H@(#QP87)A/B8C>#8R-SLF(W@V048[)B-X-C,Q.R`F(W@V,S0[)B-X-C0U
M.R8C>#8R-SL@)B-X-C(X.R8C>#8R13LF(W@V-#@[)B-X-C(W.R8C>#8T-SLF
M(W@V-$$[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F(W@V-T4[)B-X-C1!.R8C
M>#8S03LF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V
M,D4[)B-X-C0X.R8C>#8R1CL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(X.R8C>#8T
M-SL@)B-X-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V,D8[)B-X-C1!
M.R8C>#8R0SLF(W@V-$$[)B-X-C)!.R8C>#8R-SLF(W@V-#0[)B-X-C1!.R`F
M(W@V,C<[)B-X-C0U.R8C>#8S-CLF(W@V,C<[)B-X-C(Q.R`F(W@V03D[)B-X
M-C0V.R8C>#8T03LF(W@V,D8[("8C>#8T.#L@)B-X-C1!.R8C>#8R-SL@)B-X
M-C(W.R8C>#8T03LF(W@V-#8[)B-X-D$Y.R8C>#8T-SL@)B-X-C=%.R8C>#8T
M03LF(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R8C>#9#0SL@
M)B-X-C,Q.R8C>#8T-3LF(W@V,S([("8C>#8S-#LF(W@V,D8[)B-X-C0W.R`F
M(W@V,C<[)B-X-C,R.R`F(W@V,D8[)B-X-C1!.R8C>#9!1CLF(W@V,S$[)B-X
M-C(W.R8C>#8T-CL@)B-X-C)&.R8C>#8S,3LF(W@V-$$[)B-X-C(W.R8C>#8T
M,3LF(W@V,D$[("8C>#8R1CLF(W@V,C<[)B-X-C,Q.R8C>#8T03LF(W@V,D8[
M("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C,R.R8C>#8T.#LF
M(W@V,D,[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,Y.R8C
M>#8T-3LF(W@V-#@[)B-X-C0U.R8C>#8T03L@+R`F(W@V,D4[)B-X-C,U.R8C
M>#8T.#LF(W@V,S4[)B-X-C1!.R`F(W@V,D4[)B-X-C0X.R8C>#8R1CL@)B-X
M-C,Q.R8C>#8R-SL@)B-X-C)&.R8C>#8R-SLF(W@V,S0[)B-X-C)!.R8C>#8T
M-SL@)B-X-C(X.R8C>#8R-SLF(W@V,S0[)B-X-C1!.R8C>#8R1CLN/"]P87)A
M/B`*("`\:&5A9&EN9SXF(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[("8C
M>#8S.3LF(W@V-#4[)B-X-C0X.R8C>#8T-3LF(W@V0T,[("8C>#8S-#LF(W@V
M-#4[)B-X-C(W.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-D$Y.R8C>#8T-#LF
M(W@V-$$[)B-X-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X
M-C1!.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C(X.R8C>#8R-SLF(W@V
M-$$[)B-X-C)&.R`F(W@V,D8[)B-X-C,Q.R`F(W@V,D8[)B-X-C,S.R8C>#8R
M03LF(W@V,S$[)B-X-C,S.R`F(W@V-#<[)B-X-C,Q.R`F(W@V-#$[)B-X-C,Q
M.R8C>#8R1CLF(W@V0T,[("8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8R1CL@
M)B-X-D$Y.R8C>#8T-SL@)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C0T.R`F
M(W@V,C@[)B-X-C0W.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X
M-C0T.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V
M,S$[)B-X-C0U.R8C>#8S,CL@)B-X-C(X.R8C>#8T-SL@)B-X-C,T.R8C>#8T
M-3LF(W@V,C<[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,C@[)B-X-C(W
M.R8C>#8S-#LF(W@V,D8[+B`F(W@V-#<[)B-X-C0U.R8C>#8X-CLF(W@V-#8[
M)B-X-C1!.R8C>#8T-CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F
M(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-C1!.R`F(W@V,S0[)B-X
M-C0U.R8C>#8R-SL@)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V
M,D8[)B-X-C,Q.R`F(W@V,D8[)B-X-C,S.R8C>#8R03LF(W@V,S$[)B-X-C,S
M.R`F(W@V,C<[)B-X-C0Q.R8C>#8S,3LF(W@V,C<[)B-X-C)&.R8C>#9#0SL@
M)B-X-D$Y.R8C>#8T-SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T-3LF
M(W@V,C<[)B-X-C1!.R8C>#8T-#L@)B-X-C(X.R8C>#8T-SL@)B-X-C(W.R8C
M>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#L@)B-X-C=%.R8C>#8T03LF(W@V
M,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R8C>#8T03LF(W@V-$$[
M("8C>#8R.#LF(W@V,C<[("8C>#8R-SLF(W@V-#4[)B-X-C,V.R8C>#8R-SLF
M(W@V0T,[("8C>#8R1CLF(W@V-$$[)B-X-C)#.R8C>#8T03LF(W@V,D$[)B-X
M-C(W.R8C>#8T-#LF(W@V-$$[("8C>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#9#
M0SL@)B-X-C(R.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R`F(W@V-#4[)B-X-C1!
M.R8C>#(P,$,[)B-X-C(X.R8C>#8R-SLF(W@V,S0[)B-X-C1!.R8C>#8R1CL@
M)B-X-C0V.R8C>#8T03LF(W@V,S([("8C>#8T,CLF(W@V,S$[)B-X-C(W.R8C
M>#8S,3L@)B-X-D%&.R8C>#8T03LF(W@V,S$[)B-X-C)&.R`F(W@V,S([)B-X
M-C1!.R8C>#8S,3LF(W@V,C<[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R
M1CL@)B-X-C,Y.R8C>#8T-3LF(W@V-#@[)B-X-C0U.R8C>#8T03L@)B-X-C,T
M.R8C>#8T-3LF(W@V,C<[)B-X-C!#.R`F(W@V-#4[)B-X-C0X.R8C>#8S,3LF
M(W@V,D8[("8C>#8T-CLF(W@V-$$[)B-X-C(W.R8C>#8S,CL@)B-X-C(W.R8C
M>#8S,SLF(W@V,D$[+CPO<&%R83X@"B`@/&AE861I;F<^)B-X-D$Y.R8C>#8T
M-#LF(W@V-$$[)B-X-C)&.R`F(W@V,D4[)B-X-C,U.R8C>#8T.#LF(W@V,S4[
M)B-X-D-#.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL\+VAE861I;F<^(`H@(#QP
M87)A/B8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C)%.R8C>#8S
M-3LF(W@V-#@[)B-X-C,U.R8C>#8T03L@)B-X-C,T.R8C>#8T-3LF(W@V,C<[
M("8C>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#9#0SL@)B-X-C,Q.R8C>#8T-3LF
M(W@V,S([("8C>#9!1CLF(W@V,S0[)B-X-C(W.R8C>#8T03LF(W@V-$$[("8C
M>#8T-SLF(W@V,S$[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V
M-#4[("8C>#8S,3LF(W@V-#4[)B-X-C,R.R`F(W@V,S0[)B-X-C)&.R8C>#8T
M-SL@)B-X-C(X.R8C>#8R-SL@)B-X-C(W.R8C>#8S,SLF(W@V,D$[)B-X-C0Q
M.R8C>#8R-SLF(W@V,D8[)B-X-C0W.R`F(W@V,C<[)B-X-C,R.R`F(W@V03D[
M)B-X-C0T.R8C>#8T03LF(W@V,D8[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R8C
M>#8P0SL@)B-X-C0U.R8C>#8T.#LF(W@V,S$[)B-X-C)&.R`F(W@V-#8[)B-X
M-C1!.R8C>#8R-SLF(W@V,S([("8C>#8R-SLF(W@V,S,[)B-X-C)!.RX@)B-X
M-C(X.R8C>#8T-SL@)B-X-C,Y.R8C>#8T-#LF(W@V,C<[)B-X-C0X.R8C>#8T
M-SL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,D4[)B-X-C,U
M.R8C>#8T.#LF(W@V,S4[)B-X-C1!.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@
M)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V,C<[)B-X-C0V.R8C
M>#8R0SLF(W@V,C<[)B-X-C0U.R`F(W@V,C<[)B-X-C0U.R8C>#8S-CLF(W@V
M,C<[)B-X-D-#.R`F(W@V,D8[)B-X-C1!.R8C>#8R0SLF(W@V-$$[)B-X-C)!
M.R8C>#8R-SLF(W@V-#0[)B-X-C1!.R`F(W@V-$$[)B-X-D$Y.R`F(W@V-T4[
M)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V-#8[)B-X-C1!.R8C
M>#8S,CL@)B-X-C0U.R8C>#8T.#LF(W@V,S$[)B-X-C)&.R`F(W@V,C<[)B-X
M-C,S.R8C>#8R03LF(W@V-#$[)B-X-C(W.R8C>#8R1CLF(W@V-#<[("8C>#8T
M,CLF(W@V,S$[)B-X-C(W.R8C>#8S,3L@)B-X-C0U.R8C>#8T03LF(W@R,#!#
M.R8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C>#8R1CLN("8C>#9!.3LF(W@V-#0[
M)B-X-C1!.R8C>#8R1CL@)B-X-C)%.R8C>#8S-3LF(W@V-#@[)B-X-C,U.R8C
M>#8T03L@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8R-SLF(W@V,S([("8C
M>#8S-SLF(W@V,S$[)B-X-C1!.R8C>#8T,CL@<&%S<W!H<F%S92`F(W@V-#8[
M)B-X-D%&.R8C>#8R-SLF(W@V-#<[)B-X-C)&.R8C>#8R-SLF(W@V,S$[)B-X
M-D-#.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C,T.R8C>#8T.#LF(W@V
M,D8[("8C>#8T.#L@)B-X-C)&.R8C>#8S,3L@)B-X-C0W.R8C>#8S,3L@)B-X
M-C0V.R8C>#8S-#LF(W@V,S,[)B-X-C)!.R!)35`@)B-X-C,T.R8C>#8T-3LF
M(W@V,C<[("8C>#8R03LF(W@V-#8[)B-X-C0W.R8C>#8R-SL@)B-X-C1!.R8C
M>#9!.3LF(W@V,C@[)B-X-C(W.R8C>#8S,3L@)B-X-C0U.R8C>#8R0SLF(W@V
M,C@[)B-X-C0X.R8C>#8S,3L@)B-X-C(X.R8C>#8T-SL@)B-X-C0X.R8C>#8R
M-SLF(W@V,S$[)B-X-C)&.R`F(W@V03D[)B-X-C,Q.R8C>#8R1CLF(W@V-#8[
M('!A<W-P:')A<V4@)B-X-C)%.R8C>#8T.#LF(W@V,D8[)B-X-C!#.R`F(W@V
M,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C>#8R-SLF(W@V,SD[)B-X-C0T
M.R8C>#8R-SLF(W@V-#8[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@
M)B-X-C)%.R8C>#8S-3LF(W@V-#@[)B-X-C,U.R8C>#8T03L@)B-X-C)%.R8C
M>#8T.#LF(W@V,D8[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,C@[)B-X
M-C(W.R8C>#8S-#LF(W@V-$$[)B-X-C)&.RX@)B-X-C(X.R8C>#8T-SL@)B-X
M-C0W.R8C>#8T-3LF(W@V-$$[)B-X-C0V.R`F(W@V,D8[)B-X-C0T.R8C>#8T
M03LF(W@V-#0[("8C>#8R1CLF(W@V,S$[("8C>#8R-SLF(W@V-#8[)B-X-C)!
M.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V-$$[)B-X-D$Y.R`F(W@V-#8[
M)B-X-C,T.R8C>#8S,SLF(W@V,D$[("8C>#8R1#LF(W@V,D$[)B-X-C0U.R8C
M>#8R-SLF(W@V-$([("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X
M-C(W.R8C>#8S,CL@24U0("8C>#8R13LF(W@V,C<[)B-X-C,Q.R8C>#8R0SL@
M)B-X-C,T.R8C>#8T.#LF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!U8FQI8R(@;60U/2(S
M8S@T-&0T9F8X9F1D83-E,&0T-#9B-#=A-C,Q,3=E,"(@<W1A=&4](G5P=&]D
M871E(CX*("`\=&ET;&4^4$=0(#H@)B-X-C0U.R8C>#8R1CLF(W@V-$$[)B-X
M-C,Q.R8C>#8T03LF(W@V,D$[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R
M1CLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C,T.R8C>#8R13LF(W@V,S4[
M)B-X-D-#.R`M("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,Y
M.R8C>#8T-3LF(W@V-#@[)B-X-C0U.R8C>#9#0SL\+W1I=&QE/B`*("`\:&5A
M9&EN9SXF(W@V-#4[)B-X-C,T.R8C>#8R-SLF(W@V-#<[)B-X-C)&.R8C>#8T
M-SL\+VAE861I;F<^(`H@(#QP87)A/B8C>#8T03LF(W@V03D[("8C>#8W13LF
M(W@V-#8[)B-X-C)#.R8C>#8S,3LF(W@V-#<[("8C>#8R.#LF(W@V,S$[)B-X
M-C(W.R8C>#9#0SL@)B-X-C0U.R8C>#8S-#LF(W@V,C<[)B-X-C0W.R8C>#8R
M1CLF(W@V-#<[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,Y
M.R8C>#8T-3LF(W@V-#@[)B-X-C0U.R8C>#9#0SL@4$=0("8C>#8R.#LF(W@V
M,C<[)B-X-C,R.R`F(W@V-#4[)B-X-D-#.R8C>#(P,$,[)B-X-D$Y.R8C>#8T
M-CLF(W@V,D8[+CPO<&%R83X@"B`@/&AE861I;F<^)B-X-C)#.R8C>#8S,CLF
M(W@V,C8[)B-X-C1!.R8C>#8R-SLF(W@V,D$[/"]H96%D:6YG/B`*("`\<&%R
M83XF(W@V,D,[)B-X-C,R.R8C>#8R-CLF(W@V-$$[)B-X-C(W.R8C>#8R03LF
M(W@V0T,[("8C>#8S,3LF(W@V,C<[("8C>#8R1CLF(W@V,S$[("8C>#8T-3LF
M(W@V-#@[)B-X-C,Q.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X
M-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-D-#.R!01U`@
M)B-X-C0V.R8C>#8S-#LF(W@V,C<[)B-X-C0V.R`F(W@V-#4[)B-X-D-#.R8C
M>#(P,$,[)B-X-C)&.R8C>#8T-SLF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T92(@;60U/2(Q
M.#4Q8C8W83%A965F,3(T,F9C,V$R8CDT868W-6,P,R(@<W1A=&4](G5P=&]D
M871E(CX*("`\=&ET;&4^4$=0(#H@)B-X-C0U.R8C>#8R1CLF(W@V-$$[)B-X
M-C,Q.R8C>#8T03LF(W@V,D$[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R
M1CLF(W@V-#<[)B-X-C(W.R`M("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R
M1CL@)B-X-C)%.R8C>#8S-3LF(W@V-#@[)B-X-C,U.R8C>#9#0SL\+W1I=&QE
M/B`*("`\:&5A9&EN9SXF(W@V-#@[)B-X-C(W.R8C>#8S,3LF(W@V,D8[("8C
M>#9!.3LF(W@V,S$[)B-X-C)&.R8C>#8T-CL@)B-X-C,Y.R8C>#8R.#LF(W@V
M,C<[)B-X-C,Q.R8C>#8R03L@)B-X-D%&.R8C>#8S,#LF(W@V,S$[/"]H96%D
M:6YG/B`*("`\<&%R83XF(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C
M>#8T.#LF(W@V,C<[)B-X-C,Q.R8C>#8R1CL@)B-X-D$Y.R8C>#8S,3LF(W@V
M,D8[)B-X-C0V.R`F(W@V,SD[)B-X-C(X.R8C>#8R-SLF(W@V,S$[)B-X-C)!
M.R`F(W@V048[)B-X-C,P.R8C>#8S,3L@)B-X-C(X.R8C>#8R-SLF(W@V-$$[
M)B-X-C)&.R`F(W@V-T4[)B-X-C0V.R8C>#8R0SLF(W@V,S$[)B-X-C0W.R8C
M>#8U-#L@)B-X-C,Y.R8C>#8R.#LF(W@V,C<[)B-X-C,Q.R8C>#8R03L@)B-X
M-D%&.R8C>#8S,#LF(W@V,S$[("8C>#8S,3LF(W@V,C<[("8C>#8R.#LF(W@V
M,C<[)B-X-C,R.R`F(W@V03D[)B-X-C0V.R8C>#8T03LF(W@V,D8[+B`F(W@V
M,SD[)B-X-C(X.R8C>#8R-SLF(W@V,S$[)B-X-C)!.R`F(W@V048[)B-X-C,P
M.R8C>#8S,3L@)B-X-C,Q.R8C>#8R-SL@)B-X-C0X.R8C>#8R-SLF(W@V,S$[
M)B-X-C)&.R`F(W@V03D[)B-X-C0V.R8C>#8T03LF(W@V,D8[+B`F(W@V,C<[
M)B-X-D%&.R8C>#8S,3L@)B-X-C,U.R8C>#8R1#LF(W@V-$$[)B-X-C)$.R`F
M(W@V,C@[)B-X-C0X.R8C>#8R1CLF(W@V,$,[($E-4"`F(W@V,C([)B-X-C0V
M.R8C>#8S,3LF(W@V,C<[("8C>#8R03LF(W@V,C<[("8C>#8R-SLF(W@V-#8[
M)B-X-C)!.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V-#8[)B-X-C,T.R8C
M>#8S,SLF(W@V,D$[("8C>#8T-CLF(W@V048[)B-X-C(W.R8C>#8T-SL@)B-X
M-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8R1CLF(W@V,C<[)B-X-C,Q.R8C>#8R
M1CLN/"]P87)A/B`*("`\:&5A9&EN9SXF(W@V,D0[)B-X-C,P.R8C>#8T,3L@
M)B-X-C,Y.R8C>#8R.#LF(W@V,C<[)B-X-C,Q.R8C>#8R03L@)B-X-D%&.R8C
M>#8S,#LF(W@V,S$[/"]H96%D:6YG/B`*("`\<&%R83XF(W@V,C@[)B-X-C(W
M.R`F(W@V,D0[)B-X-C,P.R8C>#8T,3L@)B-X-C,Y.R8C>#8R.#LF(W@V,C<[
M)B-X-C,Q.R8C>#8R03L@)B-X-D%&.R8C>#8S,#LF(W@V,S$[("8C>#8S,#LF
M(W@V,D4[)B-X-C1!.R8C>#8S,3LF(W@V-#<[("8C>#8S-#LF(W@V,D8[)B-X
M-C0W.R`F(W@V,D8[)B-X-C,Q.R!)35`F(W@V,$,[("8C>#8T-SLF(W@V,S$[
M("8C>#8W13LF(W@V,S$[)B-X-C0X.R8C>#8S,SLF(W@V-#<[("8C>#8R0SLF
M(W@V,D8[)B-X-C1!.R8C>#8R1CLF(W@V0T,[("8C>#9!.3LF(W@V-#<[("8C
M>#8T-CLF(W@V-$$[)B-X-C(W.R8C>#8S,CL@)B-X-C(X.R8C>#8T-SL@)B-X
M-C(R.R8C>#8T-CL@)B-X-C)&.R8C>#8R-SLF(W@V,S0[)B-X-C)!.R8C>#8T
M-SL@)B-X-C(X.R8C>#8R-SLF(W@V,S0[)B-X-C)&.R8C>#8P0SL@)B-X-C0X
M.R8C>#8R-SLF(W@V,S$[)B-X-C)&.R`F(W@V03D[)B-X-C,Q.R8C>#8R1CLF
M(W@V-#8[("8C>#8R,CLF(W@V-#8[)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C
M>#8S,CL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8R1CLF(W@V,S$[("8C
M>#8R13LF(W@V-#@[)B-X-C(W.R8C>#8S,SLF(W@V,D$[("8C>#8T-3LF(W@V
M-$$[)B-X,C`P0SLF(W@V03D[)B-X-C0V.R8C>#8R1CLN/"]P87)A/B`*("`\
M:&5A9&EN9SXF(W@V-#4[)B-X-C,T.R8C>#8R-SLF(W@V-#<[)B-X-C)&.R8C
M>#8T-SL\+VAE861I;F<^(`H@(#QP87)A/B8C>#8T-3LF(W@V-$$[)B-X,C`P
M0SLF(W@V,D$[)B-X-C0X.R8C>#8R-SLF(W@V-#8[("8C>#8W13LF(W@V-#8[
M)B-X-C)#.R8C>#8S,3LF(W@V-#<[)B-X,C`P0SLF(W@V,C<[)B-X-C1!.R8C
M>#8T03L@)B-X-C,Q.R8C>#8R-SL@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X
M-D-#.R`F(W@V-#4[)B-X-C,T.R8C>#8R-SLF(W@V-#<[)B-X-C)&.R8C>#8T
M-SL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,D4[)B-X-C,U
M.R8C>#8T.#LF(W@V,S4[)B-X-C1!.R!01U`@)B-X-C(X.R8C>#8R-SLF(W@V
M,S([("8C>#9!.3LF(W@V,S$[)B-X-C)&.R`F(W@V-#@[)B-X-C0T.R8C>#8T
M03L@)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V,D8[)B-X-C0R
M.R8C>#8R03L@)B-X-D$Y.R8C>#8T-CLF(W@V-$$[)B-X-C)&.R`F(W@V03D[
M)B-X-C0W.R`F(W@V-#<[)B-X-C,Q.R`F(W@V048[)B-X-C,R.R`F(W@V03D[
M)B-X-C0T.R8C>#8T03LF(W@V,D8[("8C>#8R13LF(W@V,S4[)B-X-C0X.R8C
M>#8S-3LF(W@V-$$[("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,S$[)B-X
M-C(W.R`F(W@V,C@[)B-X-C0W.R`F(W@V,S0[)B-X-C)%.R8C>#8S-3L@)B-X
M-C)&.R8C>#8T03LF(W@V048[)B-X-C,Q.R8C>#9#0SL@)B-X-C(W.R8C>#8S
M,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#L@)B-X-C0V.R8C>#9!.3LF(W@V-#8[
M)B-X-C1!.R8C>#8R1CLN/"]P87)A/B`*("`\:&5A9&EN9SXF(W@V,D,[)B-X
M-C,R.R8C>#8R-CLF(W@V-$$[)B-X-C(W.R8C>#8R03L\+VAE861I;F<^(`H@
M(#QP87)A/B8C>#8R0SLF(W@V,S([)B-X-C(V.R8C>#8T03LF(W@V,C<[)B-X
M-C)!.R8C>#9#0SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C,Q.R8C>#8R-SLF(W@V
M,D,[)B-X-C,Y.R`F(W@V,C@[)B-X-C0W.R`F(W@V03D[)B-X-C0T.R8C>#8T
M03LF(W@V,D8[("8C>#8R13LF(W@V,S4[)B-X-C0X.R8C>#8S-3LF(W@V0T,[
M("8C>#8T-CLF(W@V,S0[)B-X-C(W.R8C>#8T-CL@)B-X-C0U.R8C>#9#0SLF
M(W@R,#!#.R8C>#8R1CLF(W@V-#<[)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(@;60U/2)D
M8F0X8V)E-F)C93<Q8S1F8C4Y,F1D,6(S8C(W8C=C92(@<W1A=&4](G5P=&]D
M871E(CX*("`\=&ET;&4^4$=0(#HF(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V
M,D8[)B-X-C0W.R8C>#8R-SL@)B-X-C0U.R8C>#8R1CLF(W@V-$$[)B-X-C,Q
M.R8C>#8T03LF(W@V,D$[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CLF
M(W@V-#<[)B-X-C(W.R`M("8C>#8R1#LF(W@V,S`[)B-X-C0Q.SPO=&ET;&4^
M(`H@(#QH96%D:6YG/B8C>#8R1#LF(W@V,S`[)B-X-C0Q.R`F(W@V03D[)B-X
M-C0T.R8C>#8T03LF(W@V,D8[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8S
M-#LF(W@V,D4[)B-X-C,U.R8C>#9#0SL\+VAE861I;F<^(`H@(#QP87)A/B8C
M>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V
M,D8[("8C>#8S,CLF(W@V-#@[)B-X-C)#.R`F(W@V03D[)B-X-C0T.R8C>#8T
M03LF(W@V,D8[("8C>#8R13LF(W@V,S4[)B-X-C0X.R8C>#8S-3LF(W@V-$$[
M+R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-C1!.R`F(W@V,S0[
M)B-X-C0U.R8C>#8R-SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#8S,CM)
M35`@)B-X-C)$.R8C>#8S,#LF(W@V-#$[("8C>#8T-3LF(W@V-$$[)B-X,C`P
M0SLF(W@V03D[)B-X-C0V.R8C>#8R1CLN/"]P87)A/B`*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M;F%M92(@;60U/2(W
M-#AC8C$R-&(W9F8U,C@R,#<Y,F4R-S@P,S=A.&,R-R(@<W1A=&4](G5P=&]D
M871E(CX*("`\=&ET;&4^4$=0(#H@)B-X-C(W.R8C>#8T03LF(W@V,D,[)B-X
M-C(W.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V
M,S0[)B-X-C)%.R8C>#8S-3LF(W@V0T,[("T@)B-X-C0V.R8C>#8R-SLF(W@V
M-#4[/"]T:71L93X@"B`@/&AE861I;F<^)B-X-C0V.R8C>#8R-SLF(W@V-#4[
M/"]H96%D:6YG/B`*("`\<&%R83XF(W@V-#8[)B-X-C(W.R8C>#8T-3LF(W@V
M-$$[("8C>#9!.3LF(W@V-#<[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V
M-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W
M.R8C>#8T03LF(W@V,D8[("8C>#8R.#LF(W@V-#<[("8C>#8T-SLF(W@V-#4[
M)B-X-C,Q.R8C>#8R-SLF(W@V-#<[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C
M>#8R1CL@)B-X-C)%.R8C>#8S-3LF(W@V-#@[)B-X-C,U.R8C>#8T03L@)B-X
M-C)%.R8C>#8T.#LF(W@V,D8[("8C>#8R1CLF(W@V,S$[)B-X-C)#.R`F(W@V
M03D[)B-X-C0V.R8C>#8T03LF(W@V,D8[("@F(W@V,C<[)B-X-C)#.R8C>#8R
M.#LF(W@V,C<[)B-X-C,Q.R8C>#9#0SLI/"]P87)A/B`*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N="(@;60U
M/2)E-C8V96(Y9C!E931B-#EF93`T9C<T9F,Q.&1B.#8T,"(@<W1A=&4](G5P
M=&]D871E(CX*("`\=&ET;&4^4$=0(#H@)B-X-C(W.R8C>#8T03LF(W@V,D,[
M)B-X-C(W.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F
M(W@V,S0[)B-X-C)%.R8C>#8S-3LF(W@V0T,[("T@)B-X-C)!.R8C>#8T.#LF
M(W@V,S8[)B-X-C1!.R8C>#8R1#LF(W@V,C<[)B-X-C)!.SPO=&ET;&4^(`H@
M(#QH96%D:6YG/B8C>#8R03LF(W@V-#@[)B-X-C,V.R8C>#8T03LF(W@V,D0[
M)B-X-C(W.R8C>#8R03L\+VAE861I;F<^(`H@(#QP87)A/B8C>#8R03LF(W@V
M-#@[)B-X-C,V.R8C>#8T03LF(W@V,D0[)B-X-D-#.R`F(W@V03D[)B-X-C0W
M.R`F(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-#0[("8C>#8R.#LF(W@V-#<[
M("8C>#8R1CLF(W@V,S$[)B-X-C)#.R`F(W@V,C([)B-X-C0V.R`F(W@V,C@[
M)B-X-C0W.R`F(W@V-#<[)B-X-C0U.R8C>#8S,3LF(W@V,C<[)B-X-C0W.R`F
M(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[("8C>#8R13LF(W@V,S4[)B-X
M-C0X.R8C>#8S-3LF(W@V-$$[("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V
M-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C(X.R8C>#8R-SLF(W@V,S0[)B-X-C1!
M.R8C>#8R1CLH)B-X-C(W.R8C>#8R13LF(W@V,D$[)B-X-C1!.R8C>#8R-SLF
M(W@V,S$[)B-X-D-#.RDN/"]P87)A/B`*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M96UA:6PB(&UD-3TB8S<R.68W,&9D
M8C-A-S-C8F(W8F$U968U.#@X93,P.3(B('-T871E/2)U<'1O9&%T92(^"B`@
M/'1I=&QE/E!'4"`Z("8C>#8R-SLF(W@V-$$[)B-X-C)#.R8C>#8R-SLF(W@V
M,D8[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,T.R8C>#8R
M13LF(W@V,S4[)B-X-D-#.R`M("8C>#8R,CLF(W@V,D8[)B-X-C,Q.R8C>#8S
M,SLF(W@R,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V-T4[)B-X-C,S
M.R8C>#8R03L@)B-X-C(W.R8C>#8T-#LF(W@V03D[)B-X-C)!.R8C>#8S,3LF
M(W@V-#@[)B-X-C0V.R8C>#8T03LF(W@V03D[/"]T:71L93X@"B`@/&AE861I
M;F<^)B-X-C(R.R8C>#8R1CLF(W@V,S$[)B-X-C,S.R8C>#8T-SLF(W@V,C<[
M)B-X-D-#.R`F(W@V-T4[)B-X-C,S.R8C>#8R03L@)B-X-C(W.R8C>#8T-#LF
M(W@V03D[)B-X-C)!.R8C>#8S,3LF(W@V-#@[)B-X-C0V.R8C>#8T03LF(W@V
M03D[/"]H96%D:6YG/B`*("`\<&%R83XF(W@V,C([)B-X-C)&.R8C>#8S,3LF
M(W@V,S,[("8C>#8W13LF(W@V,S,[)B-X-C)!.R`F(W@V,C<[)B-X-C0T.R8C
M>#9!.3LF(W@V,D$[)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C1!.R8C>#9!
M.3LF(W@V0T,[("8C>#9!.3LF(W@V-#<[("8C>#8S-#LF(W@V-#4[)B-X-C(W
M.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C)%.R8C>#8T.#LF(W@V,C<[
M)B-X-C0W.R8C>#8T03LF(W@V,D8[("8C>#8R.#LF(W@V,C<[("8C>#9!.3LF
M(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C)%.R8C>#8S-3LF(W@V-#@[)B-X
M-C,U.R8C>#8T03L@)B-X-C)%.R8C>#8T.#LF(W@V,D8[("8C>#8T-3LF(W@V
M,S$[)B-X-C)!.R8C>#8R.#LF(W@V,S<[("8C>#8T-CLF(W@V-#4[)B-X-C(W
M.R8C>#8T03LF(W@V-#8[)B-X-C)&.R`H)B-X-C(W.R8C>#8R0SLF(W@V,C@[
M)B-X-C(W.R8C>#8S,3LF(W@V0T,[*3PO<&%R83X@"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"(@;60U
M/2(R-&-A-C0Q8S8S9F(U9F8S,3!A,SEE93!D,V(Q964U-2(@<W1A=&4](G5P
M=&]D871E(CX*("`\=&ET;&4^4$=0(#H@)B-X-C(W.R8C>#8T03LF(W@V,D,[
M)B-X-C(W.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F
M(W@V,S0[)B-X-C)%.R8C>#8S-3LF(W@V0T,[("T@)B-X-C,W.R8C>#8T.#LF
M(W@V-#0[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL\+W1I=&QE/B`*
M("`\:&5A9&EN9SXF(W@V,S<[)B-X-C0X.R8C>#8T-#L@)B-X-D$Y.R8C>#8T
M-#LF(W@V-$$[)B-X-C)&.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C,W.R8C
M>#8T.#LF(W@V-#0[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X
M-C)!.R8C>#8T.#LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,T.R8C>#8R
M1CLF(W@V-#<[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V,C@[)B-X-C0W
M.R`F(W@V,C@[)B-X-C(W.R8C>#8T03LF(W@V,D$[+B`F(W@V-#<[)B-X-C,Q
M.R`F(W@V.#8[)B-X-C0W.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C,W
M.R8C>#8T.#LF(W@V-#0[("8C>#8R.#LF(W@V,S([)B-X-C,Q.R8C>#9!1CLF
M(W@V,D$[)B-X-C,Q.R`F(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V,D8[)B-X
M-C!#.R`F(W@V,C<[)B-X-C,Q.R8C>#8R03LF(W@V,C@[)B-X-C(W.R8C>#8S
M-SL@)B-X-C(W.R8C>#8T-3LF(W@V-#8[("8C>#8R03LF(W@V,S$[("8C>#8R
M13LF(W@V-#@[)B-X-C(W.R8C>#8T-SLF(W@V,D8[("8C>#8R.#LF(W@V-#@[
M)B-X-C)&.RX@)B-X-C(W.R8C>#8T-#LF(W@V,C@[)B-X-C)!.R8C>#8T-SL@
M)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V,D$[)B-X-C0X.R8C
M>#8R0SLF(W@V-#<[("8C>#9!.3LF(W@V-#8[)B-X-C1!.R8C>#8R1CL@)B-X
M-D$Y.R8C>#8T-SL@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#8R-SLF(W@V
M-#4[)B-X-C,Q.R`F(W@V,C@[)B-X-C(W.R8C>#8S.3LF(W@V,D([("8C>#8R
M.#LF(W@V,C<[)B-X-C0T.R8C>#8R-SLF(W@V,S$[)B-X-C0Q.R8C>#8R03LF
M(W@V-#8[("8C>#8S,CLF(W@V-#4[)B-X-C(W.R8C>#8T-CL@)B-X-C)!.R8C
M>#8T.#LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-#LF(W@V
M-$$[)B-X-C)&.R`F(W@V-#@[("8C>#8T-SLF(W@V-#4[)B-X-C@V.R8C>#8T
M-CLF(W@V-$$[)B-X-C0V.R`F(W@V,S([)B-X-C0U.R8C>#8R-SLF(W@V-#8[
M("8C>#8S,3LF(W@V-#4[)B-X-C,R.R8C>#8R.#LF(W@V-#8[)B-X-C)&.R8C
M>#9#0SL@)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#9!1CLF(W@V,S$[)B-X
M-C)&.R8C>#8R1CLN("8C>#8S-SLF(W@V-#@[)B-X-C0T.R`Q,#(T("8C>#8R
M.#LF(W@V,C<[)B-X-C1!.R8C>#8R03L@)B-X-C,W.R8C>#8T.#LF(W@V-#0[
M("8C>#8W13LF(W@V-$$[)B-X-C,T.R8C>#(P,$,[)B-X-C0Q.R8C>#8S,3LF
M(W@V,S8[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,C@[)B-X-C(W.R8C
M>#8S-#LF(W@V,D8[("8C>#9!.3LF(W@V-#<[("8C>#8R-SLF(W@V-#4[)B-X
M-C0V.R8C>#8T03LF(W@V,D$[("8C>#8R13LF(W@V-#@[)B-X-C(X.R8C>#8T
M03L@)B-X-C,Q.R8C>#8R-SL@)B-X-C0Q.R8C>#8S,3LF(W@V,C<[)B-X-C0W
M.R8C>#8T-3L@)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8R,CLF(W@V-#@[
M)B-X-C,Q.R8C>#8R1CLN/"]P87)A/B`*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M<&%S<W!H<F%S92(@;60U/2(R9F(Y
M,S<R.3<P8F8S,V8U,64Y.#AB83,Y9&)D-S$Y,R(@<W1A=&4](G5P=&]D871E
M(CX*("`\=&ET;&4^4$=0(#H@)B-X-C(W.R8C>#8T03LF(W@V,D,[)B-X-C(W
M.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,S0[
M)B-X-C)%.R8C>#8S-3LF(W@V0T,[("T@)B-X-C,Y.R8C>#8R.#LF(W@V,C<[
M)B-X-C,Q.R8C>#8R03L@)B-X-D%&.R8C>#8S,#LF(W@V,S$[/"]T:71L93X@
M"B`@/&AE861I;F<^)B-X-C,Y.R8C>#8R.#LF(W@V,C<[)B-X-C,Q.R8C>#8R
M03L@)B-X-D%&.R8C>#8S,#LF(W@V,S$[/"]H96%D:6YG/B`*("`\<&%R83XF
M(W@V,C<[)B-X-C,R.R`F(W@V,SD[)B-X-C(X.R8C>#8R-SLF(W@V,S$[)B-X
M-C)!.R`F(W@V048[)B-X-C,P.R8C>#8S,3L@)B-X-C(X.R8C>#8S,3LF(W@V
M,C<[)B-X-D-#.R`F(W@V-#4[)B-X-C)$.R8C>#8R-SLF(W@V-#$[)B-X-C,X
M.R8C>#8R03L@)B-X-C0X.R`F(W@V,S$[)B-X-C0U.R8C>#8S,CLF(W@V-#8[
M)B-X-D%&.R8C>#8R-SLF(W@V,S$[)B-X-D-#.R`F(W@V03D[)B-X-C0T.R8C
M>#8T03LF(W@V,D8[("8C>#8R13LF(W@V,S4[)B-X-C0X.R8C>#8S-3LF(W@V
M-$$[("8C>#8R-SLF(W@V,S,[)B-X-C)!.R8C>#8T,3LF(W@V,C<[)B-X-C)&
M.R8C>#8T-SL@)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8S-#LF(W@V-#@[
M)B-X-C)&.RX@)B-X-C,Y.R8C>#8R.#LF(W@V,C<[)B-X-C,Q.R8C>#8R03L@
M)B-X-D%&.R8C>#8S,#LF(W@V,S$[("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C
M>#8R1CL@)B-X-C)$.R8C>#8R1CLF(W@V,C<[)B-X-C0R.R8C>#8T-#L@-B`F
M(W@V-#8[)B-X-C0X.R8C>#8T03LF(W@V,S,[)B-X-C0W.R`F(W@V,C@[)B-X
M-C(W.R8C>#8S-#LF(W@V,D8[+B`F(W@V,D$[)B-X-C0X.R8C>#8R0SLF(W@V
M-#<[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&
M.R`F(W@V03D[)B-X-C0W.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C,Y
M.R8C>#8R.#LF(W@V,C<[)B-X-C,Q.R8C>#8R03L@)B-X-C0V.R8C>#8R.#LF
M(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C0U.R8C>#8S.3LF(W@V,C<[)B-X
M-C)&.R8C>#8T-#L@)B-X-C1!.R8C>#9!.3L@)B-X-D$Y.R8C>#8T-#LF(W@V
M-#4[)B-X-C0W.R`F(W@V,D8[)B-X-C,Q.R`F(W@V,D8[)B-X-C1!.R8C>#9!
M.3LF(W@V,S0[)B-X-C0V.R8C>#8S,3LF(W@V0T,[("8C>#8R.#LF(W@V-#@[
M)B-X-C)&.R8C>#8T-SL@)B-X-C0X.R`F(W@V-#<[)B-X-C0U.R8C>#8X-CLF
M(W@V-#8[)B-X-C1!.R8C>#8T-CLF(W@V-$$[("8C>#8T-CLF(W@V,C@[)B-X
M-C(W.R8C>#8T03LF(W@V,D8[("8C>#8T-3LF(W@V,SD[)B-X-C(W.R8C>#8R
M1CLF(W@V-#0[("8C>#8R-SLF(W@V,S,[)B-X-C0U.R`F(W@V,S$[)B-X-C0U
M.R8C>#8S,CL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8R.#LF(W@V,C<[
M)B-X-C,T.R8C>#8R1CL@)B-X-C0X.R`F(W@V,C@[)B-X-C(W.R8C>#8T03LF
M(W@V,D8[("8C>#8T-SLF(W@V-#4[("8C>#8S-#LF(W@V,C<[)B-X-C0U.R8C
M>#8T-#L@)B-X-C0V.R8C>#8T.#LF(W@V-$$[)B-X-C,S.R8C>#8T-SLF(W@R
M,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,D0[)B-X-C,Q.R8C>#8T
M,3LF(W@V-$$[("8C>#8T.#L@)B-X-C0W.R8C>#8T-3L@)B-X-C0V.R8C>#8T
M.#LF(W@V-$$[)B-X-C,S.R8C>#8T-SLF(W@R,#!#.R8C>#8T-SLF(W@V,C<[
M)B-X-C1!.R`F(W@V,SD[)B-X-C)&.R8C>#8R1CLF(W@V0T,[("8C>#8R.#LF
M(W@V,C<[)B-X-C,T.R8C>#8R1CLN("8C>#8T-#LF(W@V,C<[)B-X-C,R.R8C
M>#8T-3L@)B-X-C(X.R8C>#8T-SL@)B-X-C,P.R8C>#9!.3LF(W@V,S$[("8C
M>#8R-SLF(W@V,S,[)B-X-C)!.R`F(W@V03D[)B-X-C0W.R`F(W@V,SD[)B-X
M-C(X.R8C>#8R-SLF(W@V,S$[)B-X-C)!.R`F(W@V048[)B-X-C,P.R8C>#8S
M,3L@)B-X-C,Q.R8C>#8R-SL@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-D-#
M.R`F(W@V,D$[)B-X-C(S.R8C>#8T03LF(W@V-$$[)B-X-C)&.R8C>#8P0SL@
M)B-X-C)&.R8C>#8T.#LF(W@V,C@[)B-X-C(W.R8C>#8S,3L@)B-X-C(X.R8C
M>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V-#@[)B-X-C(W.R8C>#8S,3LF(W@V
M,D8[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-#8[)B-X-C)&
M.R`H)B-X-C(W.R8C>#8R0SLF(W@V,C@[)B-X-C(W.R8C>#8S,3LF(W@V0T,[
M*3PO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK
M97DM8W)E871E+6%C=&EO;G,B(&UD-3TB,&8X,C,T.3,U8CDV-&,X,S4S,V(T
M96,T8S$U96(W,3(B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/E!'4"`Z
M("8C>#8R-SLF(W@V-$$[)B-X-C)#.R8C>#8R-SLF(W@V,D8[("8C>#9!.3LF
M(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,T.R8C>#8R13LF(W@V,S4[)B-X
M-D-#.R`M("8C>#8S.3LF(W@V-#4[)B-X-C0T.R8C>#8T03LF(W@V,C<[)B-X
M-C)!.SPO=&ET;&4^(`H@(#QH96%D:6YG/B8C>#8R-SLF(W@V-$$[)B-X-C)#
M.R8C>#8R-SLF(W@V,D8[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CLF
M(W@V-#<[)B-X-C(W.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C,R.R8C>#8T
M.#LF(W@V,D,[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C)%
M.R8C>#8S-3LF(W@V-#@[)B-X-C,U.R8C>#8T03L@)B-X-C0X.R`F(W@V,SD[
M)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-C1!.R`F(W@V,S0[)B-X-C0U.R8C
M>#8R-SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#8T03LF(W@V,D,[)B-X
M-C(W.R8C>#8R1CL@)B-X-C0X.R`F(W@V,S`[)B-X-C)%.R8C>#8T03LF(W@V
M,S$[)B-X-C0W.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-D$Y.R8C>#8T
M-CLF(W@V,D8[+CPO<&%R83X@"B`@/&AE861I;F<^)B-X-C)&.R8C>#8S,3LF
M(W@V-$$[)B-X-C(W.R8C>#8T,3LF(W@V,D$[("8C>#8S,CLF(W@V-#@[)B-X
M-C)#.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[/"]H96%D:6YG/B`*
M("`\<&%R83XF(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-D$Y.R8C>#8T-#LF
M(W@V-$$[)B-X-C)&.R`F(W@V-$$[)B-X-D$Y.R`F(W@V,S([)B-X-C0X.R8C
M>#8R0SL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,D4[)B-X
M-C,U.R8C>#8T.#LF(W@V,S4[)B-X-C1!.R`O("8C>#8S.3LF(W@V-#4[)B-X
M-C0X.R8C>#8T-3LF(W@V-$$[("8C>#8S,3LF(W@V,C<[("8C>#8R1CLF(W@V
M,S$[)B-X-C1!.R8C>#8R-SLF(W@V-#$[)B-X-C)!.R`F(W@V-#4[)B-X-C1!
M.R8C>#(P,$,[)B-X-D$Y.R8C>#8T-CLF(W@V,D8[("8C>#8T.#L@)B-X-C(X
M.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@
M)B-X-C0U.R8C>#8T-CLF(W@V,S@[)B-X-C0X.R8C>#8S,3L@)B-X-C1!.R8C
M>#9!.3L@)B-X-C=%.R8C>#8T-CLF(W@V,D,[)B-X-C,Q.R8C>#8T-SL@)B-X
M-C,Q.R8C>#8R-SL@)B-X-C(X.R8C>#8R-SLF(W@V,S([("8C>#8T-3LF(W@V
M-$$[)B-X,C`P0SLF(W@V03D[)B-X-C0V.R8C>#8R1CL@)B-X-D$Y.R8C>#8T
M-SL@)B-X-C)&.R8C>#8S,3L@)B-X-C(R.R8C>#8T-CL@)B-X-C,T.R8C>#8T
M-3LF(W@V,C<[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D$[)B-X-C0X
M.R8C>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C>#8T-SL@
M)B-X-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V,D8[)B-X-C,S.R8C
M>#8R03LF(W@V-$$[("8C>#8S,CLF(W@V-#@[)B-X-C)#.R`F(W@V03D[)B-X
M-C0T.R8C>#8T03LF(W@V,D8[("8C>#8R13LF(W@V,S4[)B-X-C0X.R8C>#8S
M-3LF(W@V-$$[("\@)B-X-C,Y.R8C>#8T-3LF(W@V-#@[)B-X-C0U.R8C>#8T
M03L@)B-X-C0U.R8C>#8T.#LF(W@V,D,[)B-X-C0X.R8C>#8R1CL@)B-X-C)%
M.R8C>#8T.#LF(W@V,D8[("8C>#8S,3LF(W@V,C<[("8C>#8T-3LF(W@V,SD[
M)B-X-C,Q.R8C>#8T,3LF(W@V-$$[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C
M>#8T03LF(W@V-#8[)B-X-C)&.RX@)B-X-C,R.R8C>#8T.#LF(W@V,D,[("8C
M>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CLF(W@V-#<[)B-X-C(W.R`F(W@V
M,C@[)B-X-C0W.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V,D$[("8C>#8T
M-3LF(W@V,D$[)B-X-C0V.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C)!
M.R8C>#8T.#LF(W@V,C<[)B-X-C0V.R8C>#8T-CLF(W@V,D8[("8C>#8R1CLF
M(W@V,S$[)B-X-C)#.R`F(W@V,S0[)B-X-C0X.R8C>#8T-CLF(W@V,D8[("8C
M>#8T03LF(W@V,C<[("8C>#8R-SLF(W@V048[)B-X-C,Q.R`F(W@V,D8[)B-X
M-C(W.R8C>#8R13LF(W@V-#0[("8C>#8T03LF(W@V03D[("8C>#8W13LF(W@V
M,S$[)B-X-C0X.R8C>#8T-CLF(W@V,D8[)B-X-C0W.R`F(W@V,C@[)B-X-C,Q
M.R`F(W@V,S$[)B-X-C0X.R8C>#9#0SL@)B-X-D$Y.R8C>#8R-SLF(W@V-#4[
M)B-X-C=%.R8C>#8T03LF(W@V-#@[)B-X-C)!.R8C>#8S,3L@)B-X-C0U.R8C
M>#8R1#LF(W@V-#0[)B-X-C4Q.R8C>#8T03L@)B-X-C,T.R8C>#8T-3LF(W@V
M,C<[("8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8T-CLF(W@V,D8[("8C>#8T
M-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D$[)B-X-C0X.R8C>#8R-SLF(W@V-#8[
M)B-X-C1!.R8C>#8R1CL@)B-X-C)!.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R`F
M(W@V-#8[)B-X-C(W.R8C>#8T-3L@)B-X-C=%.R8C>#8S,3LF(W@V-#@[)B-X
M-C0V.R8C>#8R1CLF(W@V-#<[("8C>#8S,3LF(W@V,C<[("8C>#8R1CLF(W@V
M,S$[)B-X-C)#.R`F(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C1!
M.R8C>#8R1CLN("8C>#8X-CLF(W@V-#8[)B-X-C(W.R8C>#8T-CLF(W@V.#8[
M)B-X-C0W.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[)B-X-C0W.R8C
M>#8R-SL@)B-X-C,U.R8C>#8R1#LF(W@V-$$[)B-X-C)$.R`F(W@V,C@[)B-X
M-C(W.R8C>#8S-#LF(W@V-#8[)B-X-C)&.R`F(W@V-T4[)B-X-C0V.R8C>#8R
M0SLF(W@V,S$[)B-X-C0W.R`F(W@V,C@[)B-X-C,S.R8C>#8R03LF(W@V-#<[
M("8C>#8R13LF(W@V-#@[)B-X-C(W.R8C>#8T-SLF(W@V,D8[("8C>#8S-#LF
M(W@V,D8[("8C>#8T.#L@)B-X-C)&.R8C>#8S,3L@)B-X-C-!.R8C>#8T03LF
M(W@V,S$[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V,S4[)B-X-C0X.R8C
M>#8S,3LF(W@V,D$[("8C>#8T03LF(W@V03D[("8C>#8W13LF(W@V-$$[)B-X
M-C-!.R8C>#8R-SLF(W@V-#4[("8C>#8R13LF(W@V,S<[)B-X-C(W.R`F(W@V
M03D[)B-X-C0W.R`F(W@V-#8[)B-X-C0X.R8C>#8S.3L@)B-X-C)%.R8C>#8S
M-SLF(W@V,C<[("8C>#8R1CLF(W@V,S$[("8C>#8R,CLF(W@V-#8[("8C>#8R
M03LF(W@V-#@[)B-X-C,V.R8C>#8T03LF(W@V,D0[("8C>#8R1CLF(W@V,C<[
M)B-X-C)&.R8C>#8T-SL@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C
M>#8R1CL@)B-X-C,T.R8C>#8R1CLF(W@V,$,[("8C>#8T-3LF(W@V,S0[)B-X
M-C(W.R8C>#8T-SLF(W@V,D8[)B-X-C0W.R`F(W@V-#4[)B-X-D-#.R8C>#(P
M,$,[)B-X-D%&.R8C>#8S,3LF(W@V,D8[)B-X-C)&.RX\+W!A<F$^(`H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<B(&UD-3TB9#-C-S4R
M8C$S-#5F8C)E8V-F934W-6,P-S0V,3DV,V8B('-T871E/2)U<'1O9&%T92(^
M"B`@/'1I=&QE/E,O34E-12`Z("8C>#8T-3LF(W@V,S$[)B-X-C0X.R8C>#8S
M,3L\+W1I=&QE/B`*("`\:&5A9&EN9SY3+TU)344@)B-X-C@V.R8C>#8T03LF
M(W@V,S,[)B-X-C)!.R8C>#8Q1CL\+VAE861I;F<^(`H@(#QP87)A/E,O34E-
M12`F(W@V-$$[)B-X-D$Y.R`F(W@V,S,[)B-X-C1!.R8C>#8S,SLF(W@V,D$[
M)B-X-C0U.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[("8C>#8R13LF
M(W@V,S4[)B-X-C0X.R8C>#8S-3LF(W@V-$$[+R8C>#8S.3LF(W@V-#4[)B-X
M-C0X.R8C>#8T-3LF(W@V-$$[("8C>#8R-SLF(W@V,S,[)B-X-C)!.R`F(W@V
M03D[)B-X-C0W.R`F(W@V,C<[)B-X-C0V.R8C>#8R0SLF(W@V,C<[)B-X-C0U
M.R`F(W@V,C<[)B-X-C0U.R8C>#8S-CLF(W@V,C<[)B-X-D-#.R`F(W@V,D8[
M)B-X-C1!.R8C>#8R0SLF(W@V-$$[)B-X-C)!.R8C>#8R-SLF(W@V-#0[)B-X
M-C1!.R`F(W@V,S$[)B-X-C(W.R`F(W@V-#4[)B-X-C0U.R8C>#9!.3LF(W@V
M-#8[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V-#8[)B-X-C0U.R8C>#8R
M-SLF(W@V-$$[)B-X-C)&.RX@)B-X-C0W.R8C>#8T-3LF(W@V.#8[)B-X-C0V
M.R8C>#8T03LF(W@V-#8[(%,O34E-12`F(W@V-#([)B-X-C(W.R8C>#8R1CLF
M(W@V,S$[("8C>#8R.#LF(W@V-#<[("8C>#8S,3LF(W@V-#4[)B-X-C,R.R8C
M>#8R.#LF(W@V-#8[)B-X-C)&.R8C>#9#0SL@)B-X-C=%.R8C>#8T03LF(W@V
M,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R`F(W@V-#@[("8C>#8R
M13LF(W@V,S4[)B-X-C0X.R8C>#8S-3LF(W@V-$$[("8C>#8S,SLF(W@V,C<[
M)B-X-C,R.R8C>#9#0SL@)B-X-C(R.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R`F
M(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C>#8T,3LF(W@V,S$[)B-X
M-C,S.R8C>#8R03LF(W@V-#8[)B-X-C)&.R8C>#9!1CLF(W@V,C<[)B-X-C0V
M.R`F(W@V-#@[("8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C>#8T-CLF(W@V,D8[
M)B-X-D%&.R8C>#8R-SLF(W@V-#8[("8C>#8R.#LF(W@V-#@[)B-X-C)&.R8C
M>#8T-SL@)B-X-C0X.R`F(W@V-#<[)B-X-C0U.R8C>#8X-CLF(W@V-#8[)B-X
M-C1!.R8C>#8T-CL@)B-X-C0R.R8C>#8R-SLF(W@V,D8[)B-X-C,Q.R`F(W@V
M,C@[)B-X-C0W.R`F(W@V,D$[)B-X-C,T.R8C>#8R13LF(W@V-$$[)B-X-C,U
M.R`F(W@V,D$[)B-X-C)$.R8C>#8S,3LF(W@V-$$[)B-X-C0Q.R8C>#8T-SLF
M(W@V,C<[)B-X-D-#.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V,D$[("8C
M>#9!1CLF(W@V,S$[)B-X-C0Q.R8C>#8R03LF(W@V-#<[("8C>#8R1CLF(W@V
M,S$[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C0W
M.R8C>#8R-SL@)B-X-C(X.R8C>#8S.3LF(W@V,D8[("8C>#8R-SLF(W@V,S([
M("8C>#8R-SLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8R,CLF
M(W@V-#8[)B-X-C0W.R8C>#8R-SLF(W@V,$,[("8C>#8T-3LF(W@V-$$[)B-X
M,C`P0SLF(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V,D8[+CPO<&%R83X@"B`@
M/&AE861I;F<^)B-X-C(R.R8C>#8T03LF(W@V,C<[("8C>#8T,CLF(W@V,C<[
M)B-X-C(X.R8C>#8T-#LF(W@V-$$[)B-X-C)!.R8C>#8T-SLF(W@V,C<[)B-X
M-D-#.R!3+TU)344@)B-X-C0Q.R8C>#8S.3LF(W@V,C<[)B-X-C0T.R`F(W@V
M,S0[)B-X-C0X.R8C>#8R1CLF(W@V,48[/"]H96%D:6YG/B`*("`\<&%R83XF
M(W@V,C<[)B-X-D%&.R8C>#8S,3L@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C
M>#9!1CLF(W@V,S([)B-X-C1!.R8C>#8T-CLF(W@V-#<[("8C>#8R-SLF(W@V
M-#8[)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V,S0[)B-X-C0X
M.R8C>#8R1CLF(W@V,$,[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V-#([
M)B-X-C(W.R8C>#8R1CLF(W@V,S$[("8C>#8R.#LF(W@V-#<[("8C>#8T.#LF
M(W@V,C<[)B-X-C,Q.R8C>#8R1CL@)B-X-D$Y.R8C>#8S,3LF(W@V,D8[)B-X
M-C0V.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V,D8[)B-X-C0W.R8C>#8R
M-SLF(W@V0T,[("8C>#8S-#LF(W@V,D4[)B-X-C,U.R8C>#8T03L@4R]-24U%
M("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,D4[)B-X-C0X.R8C>#8R-SLF
M(W@V-#<[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C>#8T.#LF(W@V,D8[("8C
M>#9!.3LF(W@V-#<[("8C>#8R.#LF(W@V-#<[("8C>#8S-SLF(W@V,C@[)B-X
M-C,Y.R`F(W@V,C([)B-X-C0V.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X
M-C0R.R8C>#8R-SLF(W@V,D8[)B-X-C,Q.R`F(W@V,C@[)B-X-C0W.R`F(W@V
M,D4[)B-X-C0X.R8C>#8R-SLF(W@V-#8[)B-X-C)&.R8C>#8T-CL@)B-X-C=%
M.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R8C
M>#9#0SL@)B-X-C,Q.R8C>#8T-3LF(W@V,S([("8C>#8S-#LF(W@V,D8[)B-X
M-C0W.R8C>#8P0SL@)B-X-C)!.R8C>#8S-#LF(W@V,D4[)B-X-C1!.R8C>#8S
M-3L@)B-X-C(W.R8C>#8T-3LF(W@V,S8[)B-X-C(W.R8C>#8T-SLF(W@V,C<[
M)B-X-D-#.R`F(W@V,D8[)B-X-C1!.R8C>#8R0SLF(W@V-$$[)B-X-C)!.R8C
M>#8R-SLF(W@V-#0[)B-X-C1!.R`F(W@V-#$[)B-X-C,Q.R8C>#8S,SLF(W@V
M,D$[)B-X-C0V.R8C>#8R1CLF(W@V048[)B-X-C(W.R8C>#8T-CL@)B-X-C0X
M.R`F(W@V-#<[)B-X-C0U.R8C>#8X-CLF(W@V-#8[)B-X-C1!.R8C>#8T-CL@
M)B-X-C,Q.R8C>#8T-3LF(W@V,S([)B-X-C(X.R8C>#8T-CLF(W@V,D8[)B-X
M-D-#.R`F(W@V-#@[("8C>#8R-SLF(W@V-#4[)B-X-C,V.R8C>#8R-SLF(W@V
M,C$[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C0W
M.R8C>#8R-SLF(W@V0T,[("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,D4[
M)B-X-C0X.R8C>#8R-SLF(W@V-#<[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C
M>#8T.#LF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S
M;6EM92UO=F5R=FEE=RUP97)S;VYA;&ME>2(@;60U/2(Y9C1F,S9A93<R8V(T
M86)C-S,Q,#8W9#,S.&)E,V(Y."(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET
M;&4^4R]-24U%(#H@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R8C>#8T
M-SLF(W@V,C<[)B-X-D-#.R`F(W@V,S0[)B-X-C)%.R8C>#8S-3LF(W@V0T,[
M/"]T:71L93X@"B`@/&AE861I;F<^)B-X-C0U.R8C>#8S,3LF(W@V-#@[)B-X
M-C,Q.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(W.R8C>#9!1CLF(W@V,S$[
M("8C>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V,C@[)B-X-C)%.R8C>#8T.#LF
M(W@V,C<[)B-X-C0W.R8C>#8T03LF(W@V,D8[("8C>#9!.3LF(W@V-#<[("8C
M>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C1!.R`F(W@V
M,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C0W.R`F(W@V,S4[)B-X-C0X.R8C>#8S
M,3LF(W@V,D$[("8C>#8R1CLF(W@V-$$[)B-X-C)#.R8C>#8T03LF(W@V,D$[
M)B-X-C(W.R8C>#8T-#LF(W@V-$$[("8C>#8R-SLF(W@V-#4[)B-X-C,V.R8C
M>#8R-SLF(W@V,C$[("8C>#9!.3LF(W@V-#8[)B-X-C1!.R8C>#8R1CLF(W@V
M,$,[("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C,R.R8C>#8T
M.#LF(W@V,D,[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C)%
M.R8C>#8S-3LF(W@V-#@[)B-X-C,U.R8C>#8T03LO)B-X-C,Y.R8C>#8T-3LF
M(W@V-#@[)B-X-C0U.R8C>#8T03L@4R]-24U%("8C>#8R13LF(W@V-#@[)B-X
M-C)&.R`F(W@V,S$[)B-X-C(W.R`F(W@V,D8[)B-X-C(W.R8C>#8S-#LF(W@V
M,D$[)B-X-C0W.R`F(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V-$$[)B-X-C)&
M.RX\+W!A<F$^(`H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M:6UP;W)T
M+7!E<G-O;F%L+6-E<G1S(B!M9#4](F-F,&5D,F4S93(T9#,P9&5D9CAC9F5F
M,F,R-C0U-S4Y(B!S=&%T93TB=7!T;V1A=&4B/@H@(#QT:71L93Y3+TU)344@
M.B`F(W@V,D8[)B-X-C,Q.R8C>#8T03LF(W@V,C<[)B-X-C0Q.R8C>#8R03L@
M)B-X-D%&.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#9#0SLF(W@R,#!#.R8C
M>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,S0[)B-X-C)%.R8C>#8S-3LF(W@V
M0T,[/"]T:71L93X@"B`@/&AE861I;F<^)B-X-C)&.R8C>#8S,3LF(W@V-$$[
M)B-X-C(W.R8C>#8T,3LF(W@V,D$[("8C>#9!1CLF(W@V-#@[)B-X-C(W.R8C
M>#8T-SLF(W@V0T,[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X
M-C,T.R8C>#8R13LF(W@V,S4[)B-X-D-#.SPO:&5A9&EN9SX@"B`@/'!A<F$^
M)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C
M>#8R1CLF(W@V,$,[("8C>#9!1CLF(W@V-#@[)B-X-C(W.R8C>#8T-SLF(W@V
M-$$[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8R03LF(W@V,C,[)B-X-C1!
M.R8C>#8T03LF(W@V,D8[("8C>#8S-#LF(W@V,D4[)B-X-C,U.R8C>#8T03L@
M)B-X-C)%.R8C>#8T.#LF(W@V,D8[("8C>#8S,3LF(W@V,C<[("8C>#8R-SLF
M(W@V,S([("8C>#8T03LF(W@V03D[("8C>#8W13LF(W@V,S$[)B-X-C0X.R8C
M>#8T-CLF(W@V,D8[)B-X-C0W.R`F(W@V,C@[)B-X-C(W.R`F(W@V-#$[)B-X
M-C,Q.R8C>#8T-3LF(W@V,D$[(%!+0U,C,3(@)B-X-C)&.R8C>#8S,3LF(W@V
M-$$[)B-X-C(W.R8C>#8T,3LF(W@V,D$[("8C>#8T-3LF(W@V-$$[)B-X,C`P
M0SLF(W@V03D[)B-X-C0V.R8C>#8R1CLN("8C>#8R-SLF(W@V-$$[)B-X-C0V
M.R`F(W@V-#$[)B-X-C,Q.R8C>#8T-3LF(W@V,D$[("8C>#8S03LF(W@V,C<[
M)B-X-C0T.R8C>#8R.#LF(W@V,C<[("8C>#8R03LF(W@V-#@[)B-X-C,S.R8C
M>#8S-SL@)B-X-C0U.R8C>#8S,3LF(W@V-#@[)B-X-C,Q.R8C>#9!1CLF(W@V
M,S$[)B-X-C0W.R8C>#8R-SL@)B-X-C0X.R`F(W@V-$$[)B-X-C(W.R`F(W@V
M,C@[)B-X-C,Q.R8C>#8R13LF(W@V-$$[("8C>#8R-SLF(W@V,S([("8C>#8S
M,SLF(W@V-$$[)B-X-C,S.R8C>#8R03LF(W@V-#4[("8C>#8S.3LF(W@V,C<[
M)B-X-C0U.R8C>#8T-#LF(W@V-#<[)B-X-C(W.R`H("8C>#8T-3LF(W@V,C<[
M)B-X-C0V.R8C>#8T-CLF(W@V,D8[("8C>#8T.#LF(W@V-$$[)B-X-C0V.R8C
M>#8R1CLF(W@V-#@[)B-X-C,R.R!84"`I("8C>#8R-SLF(W@V,S,[)B-X-C)!
M.R8C>#8T,3LF(W@V,C<[)B-X-C)&.R8C>#8T-SL@)B-X-C0U.R8C>#8T03LF
M(W@R,#!#.R8C>#8S-#LF(W@V-#@[)B-X-C)&.RX@)B-X-C(W.R8C>#9!1CLF
M(W@V,S$[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CLF(W@V-#<[)B-X
M-C(W.R8C>#9#0SL@)B-X-C0U.R8C>#8T.#LF(W@V,D,[)B-X-C0X.R8C>#8R
M1CL@)B-X-C)&.R8C>#8S,3L@)B-X-C=%.R8C>#8S,3LF(W@V-#@[)B-X-C0V
M.R8C>#8R1CLF(W@V-#<[("8C>#8T-3LF(W@V,SD[)B-X-C)!.R8C>#8R.#LF
M(W@V,S$[("8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8T-CLF(W@V,D8[)B-X
M-C!#.R`F(W@V,D([)B-X-C(X.R8C>#8R03L@)B-X-C,T.R8C>#8R1CLF(W@V
M-#<[("8C>#8T.#L@)B-X-C=%.R8C>#8T-CLF(W@V,D,[)B-X-C,Q.R8C>#8T
M-SL@)B-X-C(X.R8C>#8S,SLF(W@V,D$[)B-X-C0W.R`F(W@V-#4[)B-X-C1!
M.R8C>#(P,$,[)B-X-C,T.R8C>#8T.#LF(W@V,D8[("8C>#8R1CLF(W@V,S$[
M("8C>#8S03LF(W@V-$$[)B-X-C,Q.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@
M)B-X-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V-T4[)B-X-C1!.R8C
M>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V,D4[)B-X-C,W.R8C>#8R-SL@)B-X
M-C0U.R8C>#8S-#LF(W@V,C<[)B-X-C0W.R8C>#8R1CLF(W@V-#<[("8C>#8R
M13LF(W@V-#@[)B-X-C(W.R8C>#8T-SLF(W@V,D8[("8C>#8S-#LF(W@V,D8[
M+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UD96QE=&4M
M<&5R<V]N86PM8V5R=',B(&UD-3TB,#$X8F(V8C8Q83=E-#$V.#DR9&4R.#AA
M9#%C.#@P9C0B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/E,O34E-12`Z
M("8C>#8R1#LF(W@V,S`[)B-X-C0Q.R`F(W@V048[)B-X-C0X.R8C>#8R-SLF
M(W@V-#<[)B-X-D-#.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C
M>#8S-#LF(W@V,D4[)B-X-C,U.R8C>#9#0SL\+W1I=&QE/B`*("`\:&5A9&EN
M9SXF(W@V,D0[)B-X-C,P.R8C>#8T,3L@)B-X-D%&.R8C>#8T.#LF(W@V,C<[
M)B-X-C0W.R8C>#9#0SLF(W@R,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F
M(W@V,S0[)B-X-C)%.R8C>#8S-3LF(W@V0T,[/"]H96%D:6YG/B`*("`\<&%R
M83XF(W@V,C@[)B-X-C(W.R`F(W@V,D0[)B-X-C,P.R8C>#8T,3L@)B-X-D%&
M.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8T03LF(W@V-#<[)B-X-C(W.R8C
M>#9#0SL@)B-X-C)!.R8C>#8R,SLF(W@V0T,[)B-X-C1!.R8C>#8R1CL@)B-X
M-C,T.R8C>#8R13LF(W@V,S4[)B-X-C1!.R8C>#8P0SL@)B-X-C,T.R8C>#8T
M-3LF(W@V,C<[("8C>#8R1CLF(W@V-$$[)B-X-D%&.R8C>#8S,3L@)B-X-C0R
M.R8C>#8R-SLF(W@V,D8[)B-X-C,Q.R`F(W@V,C@[)B-X-C0W.R`F(W@V,C<[
M)B-X-C0U.R8C>#8S-CLF(W@V,C<[)B-X-D-#.R!3+TU)344@)B-X-C=%.R8C
M>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R8C>#9#
M0SL@)B-X-C)%.R8C>#8T.#LF(W@V,D8[("8C>#8T-CLF(W@V,D4[)B-X-C0X
M.R8C>#8R-SLF(W@V-#<[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C>#8T.#LF
M(W@V,D8[("8C>#8T.#L@)B-X-C0W.R8C>#8T-3LF(W@V.#8[)B-X-C0V.R8C
M>#8T03LF(W@V-#8[("8C>#8T-SLF(W@V-$$[)B-X-C@V.R`F(W@V-T4[)B-X
M-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V,S$[)B-X-C0U.R8C>#8S
M,CL@)B-X-C,T.R8C>#8R1CLF(W@V-#<[)B-X,C`P0SL@4R]-24U%("8C>#8S
M,3LF(W@V,C<[("8C>#8T-CLF(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C)!
M.R8C>#8T.#LF(W@V,C<[)B-X-C0V.R8C>#8T03LF(W@V,D8[("8C>#8T-3LF
M(W@V,S0[)B-X-C(W.R8C>#8T-SLF(W@V,D8[)B-X-C0W.R`F(W@V03D[)B-X
M-C0V.R8C>#8T03LF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y(B!M9#4](CAB-F,V,S8X-&0S9#<S
M8C-D,#@T,#(U83<X9F4W93@X(B!S=&%T93TB=7!T;V1A=&4B/@H@(#QT:71L
M93Y3+TU)344@.B`F(W@V-#4[)B-X-C)&.R8C>#8T03LF(W@V,S$[)B-X-C1!
M.R8C>#8R03L@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R8C>#8T-SLF
M(W@V,C<[)B-X-D-#.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X
M-D-#.SPO=&ET;&4^(`H@(#QH96%D:6YG/E,O34E-12`Z("8C>#8T-3LF(W@V
M,D8[)B-X-C1!.R8C>#8S,3LF(W@V-$$[)B-X-C)!.R`F(W@V03D[)B-X-C0T
M.R8C>#8T03LF(W@V,D8[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8S.3LF
M(W@V-#4[)B-X-C0X.R8C>#8T-3LF(W@V0T,[/"]H96%D:6YG/B`*("`\<&%R
M83XF(W@V-#4[)B-X-C)&.R8C>#8T03LF(W@V,S$[)B-X-C1!.R8C>#8R03L@
M)B-X-C0Q.R8C>#8T-SLF(W@V,S$[)B-X-C,S.R8C>#8R03L@)B-X-D$Y.R8C
M>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V
M-#4[)B-X-D-#.R!3+TU)344@)B-X-C,T.R8C>#8T-3LF(W@V,C<[/"]P87)A
M/B`*("`\:&5A9&EN9SXF(W@V-#4[)B-X-C,T.R8C>#8R-SLF(W@V-#<[)B-X
M-C)&.R8C>#8T-SL\+VAE861I;F<^(`H@(#QP87)A/B8C>#8T-3LF(W@V,S0[
M)B-X-C(W.R8C>#8T-SLF(W@V,D8[)B-X-C0W.R8C>#8U-#L@)B-X-C0U.R8C
M>#8R03LF(W@V-#8[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X
M-C,Y.R8C>#8T-3LF(W@V-#@[)B-X-C0U.R8C>#9#0SL\+W!A<F$^(`H@(#QH
M96%D:6YG/B8C>#8R0SLF(W@V,S([)B-X-C(V.R8C>#8T03LF(W@V,C<[)B-X
M-C)!.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C0U.R8C>#8S-#LF(W@V,C<[
M)B-X-C0W.R8C>#8R1CLF(W@V-#<[)B-X-C4T.R`F(W@V,D,[)B-X-C,R.R8C
M>#8R-CLF(W@V-$$[)B-X-C(W.R8C>#8R03L@)B-X-C0Q.R8C>#8T-CLF(W@V
M0T,[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#8R1CL@)B-X-C,Y.R8C>#8T
M-3LF(W@V-#@[)B-X-C0U.R8C>#9#0SL\+W!A<F$^(`H@(#QH96%D:6YG/B8C
M>#8R1#LF(W@V,S`[)B-X-C0Q.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(X
M.R8C>#8R-SL@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#8R-SLF(W@V-#8[
M)B-X-C)!.R8C>#8R13LF(W@V,C<[)B-X-C(X.R8C>#8P0SL@)B-X-D$Y.R8C
M>#8T-#LF(W@V-$$[)B-X-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V
M-#4[)B-X-D-#.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W
M.R8C>#8R.#L@)B-X-C,T.R8C>#8R1CLF(W@V-#<[("8C>#8R-SLF(W@V,S([
M("8C>#8R1CLF(W@V-$$[)B-X-C,S.R8C>#9!.3L@)B-X-C,T.R8C>#8T-3LF
M(W@V,C<[("8C>#8R1#LF(W@V,S`[)B-X-C0Q.R`F(W@V-#4[)B-X-D-#.R8C
M>#(P,$,[)B-X-C,T.R8C>#8T.#LF(W@V,D8[+B`F(W@V,C@[)B-X-C(W.R`F
M(W@V,D0[)B-X-C,P.R8C>#8T,3L@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X
M-C)&.R`F(W@V,SD[)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-C1!.R`F(W@V
M-$$[)B-X-D$Y.R`F(W@V03D[)B-X-C(W.R8C>#8S,3LF(W@V,C@[)B-X-C,Q
M.R8C>#8P0SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T,CLF(W@V,C<[
M)B-X-C)&.R8C>#8S,3L@)B-X-C(X.R8C>#8T-SL@)B-X-C(W.R8C>#8S,3LF
M(W@V,S,[)B-X-C(W.R8C>#8T-#L@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X
M-C(W.R8C>#8T-3L@)B-X-C,Q.R8C>#8T-3LF(W@V,S([("8C>#8S-#LF(W@V
M,D8[)B-X-C0W.R`F(W@V,C@[)B-X-C0W.R`F(W@V,C([)B-X-C0V.R`F(W@V
M03D[)B-X-C(W.R8C>#8S,3LF(W@V,C@[)B-X-C,Q.R`F(W@V-#8[)B-X-C)%
M.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8T03LF(W@V,D8[("8C>#8R.#LF
M(W@V-#@[)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')I;G1I;F<B(&UD-3TB9C(S,V,Q,6(V8C1A-F)E9&5B-CAF,60U83)A.3<V
M9&(B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/B8C>#8X-CLF(W@V,C<[
M)B-X-C=%.SPO=&ET;&4^(`H@(#QH96%D:6YG/B8C>#8X-CLF(W@V,C<[)B-X
M-C=%.R`F(W@V-$$[)B-X-D$Y.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V
M,C<[)B-X-C0U.SPO:&5A9&EN9SX@"B`@/'!A<F$^)B-X-C(X.R8C>#8S,3LF
M(W@V,C<[)B-X-D-#.R`F(W@V.#8[)B-X-C(W.R8C>#8W13L@)B-X-C=%.R8C
M>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V-$$[("8C>#9!.3LF(W@V
M-#<[("8C>#8T-3LF(W@V,S0[)B-X-C(W.R8C>#8T-SLF(W@V,D8[)B-X-C0W
M.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-D$Y.R8C>#8T-CLF(W@V-$$[
M)B-X-C)&.R`F(W@V,C@[)B-X-C,Q.R`F(W@V,S$[)B-X-C0X.R8C>#9#0SL@
M)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-C)&.R`B)B-X-C@V.R8C>#8R-SLF
M(W@V-T4[(B8C>#8P0SL@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[)B-X-D$Y.R`F
M(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V,C8[)B-X-C1!.R8C>#8R1CLN("8C
M>#8R.#LF(W@V,S,[)B-X-C)!.R8C>#8T-SL@)B-X-C(X.R8C>#8T-SL@)B-X
M-C0V.R8C>#8T.#LF(W@V,SD[("8C>#8T-3LF(W@V,S$[)B-X-C0X.R8C>#8S
M,3LF(W@V048[)B-X-C,Q.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C=%
M.R8C>#8T-CLF(W@V,D,[)B-X-C,Q.R8C>#8T-SLF(W@V-30[("8C>#8X-CLF
M(W@V,C<[)B-X-C=%.R`F(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V0T,[("8C
M>#8S-#LF(W@V-#4[)B-X-C(W.R`F(W@V048[)B-X-C,T.R8C>#8T.#LF(W@V
M,D8[)B-X-C0W.R`F(W@V,D4[)B-X-C0X.R8C>#8R-SLF(W@V-#<[)B-X-C)&
M.R`F(W@V,S0[)B-X-C)&.RX@)B-X-C(W.R8C>#9!1CLF(W@V,S$[("8C>#8R
M-SLF(W@V,D0[)B-X-C1!.R8C>#8R-SLF(W@V-#8[)B-X-C(W.R8C>#8U,CL@
M)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#8W13LF(W@V-#8[)B-X-C)#.R8C
M>#8S,3LF(W@V-#<[("8C>#8R.#LF(W@V,C<[)B-X-C,R.R`F(W@V-#8[)B-X
M-C,T.R8C>#8R1CLF(W@V,$,[("8C>#8R-SLF(W@V,S([("8C>#9!1CLF(W@V
M,S([)B-X-D-#.R8C>#8T-CLF(W@V048[)B-X-C(W.R8C>#8T-CL@)B-X-C=%
M.R8C>#8S,3LF(W@V-#@[)B-X-C0V.R8C>#8R1CLF(W@V-#<[)B-X-C4T.R`F
M(W@V-#4[)B-X-C0X.R8C>#8R0SLF(W@V-#@[)B-X-C)&.R`F(W@V,D8[)B-X
M-C,Q.R`F(W@V-#4[)B-X-C,Q.R8C>#8T.#LF(W@V,S$[)B-X-D%&.R8C>#8S
M,3L@)B-X-C)%.R8C>#8T.#LF(W@V,D8[("8C>#8R.#LF(W@V,S$[)B-X-C(W
M.R8C>#9#0SL@)B-X-C0Q.R8C>#8S.3LF(W@V,C<[)B-X-C0T.R`F(W@V03D[
M)B-X-C,Q.R8C>#8R1CLF(W@V-#8[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F
M(W@V-T4[)B-X-C0V.R8C>#8R0SLF(W@V,S$[)B-X-C0W.R`F(W@V,C<[)B-X
M-C,S.R8C>#8R03LF(W@V-#$[)B-X-C(W.R8C>#8R1CLF(W@V-#<[("8C>#9!
M.3LF(W@V-#8[)B-X-C1!.R8C>#8R1CLN/"]P87)A/B`*/"]E;G1R>3X*("`\
M96YT<GD@:60](G-O<G1I;F<B(&UD-3TB,3AC9&5A8S,X,#(W9F4U8S0R8F%B
M-CDS9C)A-#(V,&$B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/B8C>#8T
M-3LF(W@V,S$[)B-X-C)!.R8C>#8R.#L@)B-X-C,S.R8C>#8R-SLF(W@V,S([
M)B-X-D-#.R`O("8C>#9!1CLF(W@V,S$[)B-X-C0X.R8C>#8T-SL@)B-X,C`P
M0SLF(W@V,C@[)B-X-C0V.R8C>#8R1CLF(W@V0T,[/"]T:71L93X@"B`@/&AE
M861I;F<^)B-X-C0U.R8C>#8S,3LF(W@V,D$[)B-X-C(X.R`F(W@V03D[)B-X
M-C,Q.R8C>#8R1CLF(W@V-#8[("8C>#8T.#LF(W@V,S$[)B-X-C0X.R8C>#8R
M1CLF(W@V0T,[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.SPO:&5A9&EN9SX@"B`@
M/'!A<F$^)B-X-C0W.R8C>#8T-CLF(W@V048[)B-X-C(W.R8C>#8T-3LF(W@V
M-$$[("8C>#9!.3LF(W@V-#<[("8C>#8T,3LF(W@V-#<[)B-X-C,Q.R8C>#8S
M,SLF(W@V,D$[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[
M)B-X-C0W.R8C>#8R-SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C0U.R8C>#8S-#LF
M(W@V,C<[)B-X-C0W.R8C>#8R1CLF(W@V-#<[("8C>#8T-3LF(W@V-$$[)B-X
M,C`P0SLF(W@V03D[)B-X-C0V.R8C>#8T03LF(W@V,D8[)B-X-C!#.R`F(W@V
M-#([)B-X-C(W.R8C>#8R1CLF(W@V,S$[("8C>#8R.#LF(W@V-#<[("8C>#8T
M-3LF(W@V,S$[)B-X-C)!.R8C>#8R.#L@)B-X-D$Y.R8C>#8S,3LF(W@V,D8[
M)B-X-C0V.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R8C
M>#8T-SLF(W@V,C<[("8C>#8R.#LF(W@V,S$[("8C>#8R-SLF(W@V,S,[)B-X
M-C(W.R8C>#8S,SL@)B-X-C)!.R8C>#8T-3LF(W@V,C<[)B-X-C0U.R`F(W@V
M,S,[)B-X-C)!.R8C>#8T.#LF(W@V-#8[)B-X-C0W.R8C>#8R-SL@)B-X-C)%
M.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8T03LF(W@V,D8[("8C>#8R.#LF
M(W@V-#@[)B-X-C)&.RX@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F
M(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C0U.R8C>#8T-CLF(W@V,S@[)B-X
M-C0X.R8C>#8S,3L@)B-X-C)!.R8C>#8T-CLF(W@V-#<[)B-X-C(W.R`F(W@V
M,C@[)B-X-C(W.R8C>#8T03LF(W@V,D8[("8C>#8R.#LF(W@V,S$[("8C>#8S
M,3LF(W@V-#@[)B-X-D-#.R`F(W@V,SD[)B-X-C0V.R8C>#8T.#LF(W@V,C<[
M)B-X-C0V.R`F(W@V,S,[)B-X-C)!.R8C>#8T.#LF(W@V-#8[("8C>#9!.3LF
M(W@V-#0[)B-X-C1!.R8C>#9!.3L@)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X
M-C1!.R8C>#8T-CLF(W@V,D8[+B`F(W@V-#<[)B-X-C0U.R8C>#8X-CLF(W@V
M-#8[)B-X-C1!.R8C>#8T-CL@)B-X-C(X.R8C>#8R-SL@)B-X-C(W.R8C>#8T
M-CLF(W@V,D,[)B-X-C(W.R8C>#8T-3L@)B-X-D$Y.R8C>#8T-#LF(W@V-$$[
M)B-X-D$Y.R`F(W@V,C@[)B-X-C,Q.R`F(W@V,S$[)B-X-C0X.R8C>#9#0SL@
M)B-X-C,Y.R8C>#8T-#LF(W@V,C<[)B-X-C0U.R8C>#8R03L@)B-X-C0Q.R8C
M>#8T-#LF(W@V,S0[("8C>#9!.3LF(W@V-#8[)B-X-C(W.R8C>#8S,3L@)B-X
M-C0W.R8C>#8S,3L@)B-X-C,S.R8C>#8R03LF(W@V-#@[)B-X-C0V.R`F(W@V
M-#4[)B-X-D-#.R8C>#(P,$,[)B-X-C)!.R8C>#8T.#LF(W@V,C<[)B-X-C0V
M.R`F(W@V-#4[)B-X-C,Q.R8C>#8R03LF(W@V,C@[("8C>#8S,SLF(W@V,C<[
M)B-X-C,R.R8C>#9#0SL@)B-X-C,Q.R8C>#8R-SL@)B-X-C(W.R8C>#8S,CL@
M)B-X-C,U.R8C>#8S.3LF(W@V-#@[)B-X-C)&.R8C>#9#0SL@)B-X-C(X.R8C
M>#8T-SL@)B-X-C0V.R8C>#8S,CLF(W@V-#@[)B-X-C0T.R8C>#8T03L@)B-X
M-C0X.R`F(W@V-$$[)B-X-C(W.R`F(W@V,C@[)B-X-C,Q.R`F(W@V,SD[)B-X
M-D$Y.R8C>#8S,SLF(W@V,$,[("8C>#8R03LF(W@V,T$[)B-X-C1!.R8C>#8T
M03LF(W@V,S$[("8C>#8R1CLF(W@V,C<[)B-X-C)&.RX\+W!A<F$^(`H@(#QH
M96%D:6YG/B8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#9#0SLF(W@V,S0[("8C
M>#8S,SLF(W@V-#0[)B-X-C,S.R8C>#8T-#LF(W@V-#<[)B-X,C`P0SLF(W@V
M,C<[)B-X-D-#.R8C>#9#0SL\+VAE861I;F<^(`H@(#QP87)A/B8C>#8R.#LF
M(W@V,S$[)B-X-C(W.R8C>#9#0SL@)B-X-D%&.R8C>#8S,3LF(W@V-#@[)B-X
M-C0W.R8C>#(P,$,[)B-X-C(X.R8C>#8T-CLF(W@V,D8[)B-X-D-#.R`F(W@V
M-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@V,C<[
M("8C>#8R.#LF(W@V,S$[("8C>#8R-SLF(W@V,S,[)B-X-C(W.R8C>#8S,SL@
M)B-X-C0U.R8C>#8T.#LF(W@V,S8[)B-X-C0X.R8C>#8S.3L@*"`F(W@V-#<[
M)B-X-C,Q.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F
M(W@V,D0[)B-X-C)&.R8C>#8R-SLF(W@V-#([)B-X-C0T.R`F(W@V,C@[)B-X
M-C(W.R`F(W@V-T4[)B-X-C(W.R8C>#8S,SLF(W@V,D4[)B-X-C0W.R8C>#8R
M-SLF(W@V0T,[("8C>#8T-3LF(W@V,S$[)B-X-C(X.R8C>#8T.#LF(W@V,S<[
M("8C>#8R.#LF(W@V-#<[("8C>#8R,CLF(W@V-#8[("8C>#8W13LF(W@V-$$[
M)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C!#.R`F(W@V048[)B-X-C,Q.R8C
M>#8T.#LF(W@V-#<[("8C>#8R.#LF(W@V-#8[)B-X-C)&.R8C>#9#0SL@)B-X
M-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8S-#LF(W@V-#@[)B-X-C)&.RDF(W@V
M,$,[("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C(X.R8C>#8S
M,3L@)B-X-C,Q.R8C>#8T.#LF(W@V0T,[("8C>#8W13LF(W@V-$$[)B-X-C0X
M.R8C>#8T-CLF(W@V,D8[(%LF(W@V,S,[)B-X-C(W.R8C>#8S,SLF(W@V-#0[
M)B-X-C0W.R8C>#(P,$,[)B-X-C(W.R8C>#9#0SLF(W@V0T,[72`F(W@V03D[
M)B-X-C0W.R`F(W@V,D8[)B-X-C,Q.R`F(W@V,S,[)B-X-C)!.R8C>#8T.#LF
M(W@V-#8[("8C>#8T,CLF(W@V,S$[)B-X-C(W.R8C>#8S,3L@)B-X-C)&.R8C
M>#8R-SLF(W@V,D8[)B-X-C!#.R`F(W@V03D[)B-X-C0T.R8C>#8T03LF(W@V
M03D[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V-$$[)B-X-C)&
M.RX@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V,C<[)B-X-C,R
M.R`F(W@V,C@[)B-X-C1!.R8C>#8T-CL@)B-X-C(X.R8C>#8S,3LF(W@V,D8[
M)B-X-C0V.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C0V.R8C>#8R1#LF
M(W@V-#@[)B-X-C0W.R8C>#8U-#L@)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X
M-D-#.R8C>#8S-#L@)B-X-C(X.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V
M,C@[)B-X-C,Q.R8C>#8S,3LF(W@V-#@[)B-X-D-#.R`F(W@V-T4[)B-X-C1!
M.R8C>#8T.#LF(W@V-#8[)B-X-C)&.R!;)B-X-C0U.R8C>#8T.#LF(W@V,S8[
M)B-X-C0X.R8C>#8S.3M=("8C>#8R1CLF(W@V,S$[("8C>#8S,SLF(W@V,D$[
M)B-X-C0X.R8C>#8T-CL@)B-X-C0U.R8C>#8T.#LF(W@V,S8[)B-X-C0X.R8C
M>#8S.3LF(W@V,$,[("8C>#9!.3LF(W@V-#0[)B-X-C1!.R8C>#9!.3L@)B-X
M-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[+CPO<&%R
M83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)A;'1E<FYA=&EV92UM<V<B(&UD
M-3TB-#DW.#`W,V8W-CDW-V(V868V8C8Y.#$P931D,C)A-C4B('-T871E/2)U
M<'1O9&%T92(^"B`@/'1I=&QE/B8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R
M-SLF(W@V-#4[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8X-CLF(W@V-#8[
M)B-X-C)&.R8C>#8T,CLF(W@V,S,[)B-X-C0U.R8C>#8R03LF(W@V0T,[+R8C
M>#8R0SLF(W@V,C<[)B-X-C1!.R8C>#9!1CLF(W@V,S([)B-X-C1!.R8C>#8T
M-CL\+W1I=&QE/B`*("`\<&%R83XF(W@V,C@[)B-X-C,Q.R8C>#8R13LF(W@V
M-$$[("8C>#8R-SLF(W@V,S([("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R
M-SLF(W@V-#4[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R`F(W@V,C@[)B-X-C0W
M.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V,D$[("8C>#8X-CLF(W@V-#8[
M)B-X-C)&.R`F(W@V-#([)B-X-C,S.R8C>#8T-3LF(W@V,D$[)B-X-C1!.R\F
M(W@V,D,[)B-X-C(W.R8C>#8T03LF(W@V048[)B-X-C,R.R8C>#8T03LF(W@V
M-#8[("8C>#8R-SLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8T
M-3LF(W@V-$$[)B-X,C`P0SLF(W@V048[)B-X-C,Q.R8C>#8R1CLF(W@V-#8[
M)B-X-C)&.RX@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#8W13LF(W@V-$$[
M)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R8C>#8R-SL@)B-X-C)$.R8C
M>#8R-SLF(W@V-#@[)B-X-D-#.R`F(W@V.#8[)B-X-C0V.R8C>#8R1CL@)B-X
M-C0R.R8C>#8S,SLF(W@V-#4[)B-X-C)!.R`F(W@V-#4[)B-X-C1!.R8C>#(P
M,$,[)B-X-C(X.R8C>#8R-SLF(W@V,S0[)B-X-C0V.R8C>#8R1CL@)B-X-D$Y
M.R8C>#8T-SL@)B-X-C)&.R8C>#8S,3L@)B-X-C(R.R8C>#8T-CLF(W@V-#<[
M)B-X-C(W.R`F(W@V,D$[)B-X-C0U.R8C>#8R-SLF(W@V-#4[("8C>#8T,CLF
M(W@V,S,[)B-X-C0U.R8C>#8R03LF(W@V-#<[)B-X-C(W.R8C>#8P0SL@)B-X
M-C0U.R8C>#8R1#LF(W@V,D$[)B-X-C0X.R8C>#8R-SLF(W@V0T,[("8C>#8T
M03LF(W@V03D[)B-X-C,S.R8C>#8R-SLF(W@V-#8[("8C>#8R.#LF(W@V,C<[
M("8C>#8T,CLF(W@V,C<[)B-X-C0T.R8C>#8R.#LF(W@V-#<[)B-X-C(W.R8C
M>#9#0SL@)B-X-C0U.R8C>#8R03LF(W@V-#$[)B-X-C(W.R8C>#8T.#LF(W@V
M,D$[)B-X-C1!.R`F(W@V,S$[)B-X-C(W.R`F(W@V-#8[)B-X-C0U.R8C>#8R
M-SLF(W@V-$$[)B-X-C,T.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C)&
M.R8C>#8T-SLF(W@V-#8[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F(W@V,SD[
M)B-X-C0U.R8C>#8T.#LF(W@V-#4[)B-X-C(W.R8C>#8U,CL@)B-X-C)!.R8C
M>#8T-CLF(W@V-#<[)B-X-C(W.R`F(W@V-#([)B-X-C,S.R8C>#8T-3LF(W@V
M,D$[("8C>#8R,CLF(W@V,D4[)B-X-C,Q.R`F(W@V,D$[)B-X-C0X.R8C>#8S
M,SLF(W@V,S<[("8C>#8T-3LF(W@V,S$[)B-X-C0X.R8C>#8S,3LF(W@V048[
M)B-X-C,Q.R`F(W@V-#8[)B-X-C,T.R8C>#8R-SLF(W@V-#8[("8C>#8R1CLF
M(W@V,C<[)B-X-C)&.R8C>#8T-SL@)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C
M>#8S-#LF(W@V-#@[)B-X-C)&.R`H("8C>#8R03LF(W@V-#$[)B-X-C(W.R8C
M>#8T.#LF(W@V,D$[("8C>#8T,CLF(W@V,C<[)B-X-C0T.R8C>#8R.#L@)B-X
M-C(W.R8C>#8T03LF(W@V-#8[("8C>#8T,CLF(W@V,S,[)B-X-C0U.R8C>#8R
M03LF(W@V-#<[)B-X-C(W.R`F(W@V-#4[)B-X-C)".R8C>#8T-#LF(W@V,C<[
M("8C>#8R1CLF(W@V,S$[("8C>#8T,CLF(W@V,C<[)B-X-C0T.R8C>#8R.#L@
M)B-X-C0U.R8C>#8R03LF(W@V-#8[("8C>#8T.#L@)B-X-C1!.R8C>#8R-SL@
M)B-X-C0R.R8C>#8R-SLF(W@V-#0[)B-X-C(X.R!(5$U,("8C>#8W13LF(W@V
M-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[("8C>#8T.#L@+BXN("8C>#8T-3LF
M(W@V-$$[)B-X,C`P0SLF(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V,D8[*2X\
M+W!A<F$^(`H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<F5N86UE7W-E
M;G1M86EL7VUO;G1H;'DB(&UD-3TB-3,P9F$R,&4P869B8S(U9F9D-#`X-S<Y
M-#@X,S(X.3DB('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/B8C>#8R03LF
M(W@V,S$[)B-X-C)#.R8C>#8T03LF(W@V,D0[)B-X-C(W.R8C>#8R03L@.B`F
M(W@V-#8[)B-X-D%&.R8C>#8T-SLF(W@V,D8[)B-X-C(W.R8C>#8S,3LF(W@V
M0T,[(#H@)B-X-C)!.R8C>#8S03LF(W@V-$$[)B-X-C1!.R8C>#8S,3L@)B-X
M-C0V.R8C>#8R-SLF(W@V-#4[("8C>#8T-3LF(W@V,C<[)B-X-C0W.R8C>#8R
M-SLF(W@V-#8[)B-X-C0W.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[
M)B-X-C4T.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R8C
M>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V
M,C<[)B-X-C0T.R`F(W@V,S0[)B-X-C)&.R8C>#8T-SL\+W1I=&QE/B`*("`\
M<&%R83XF(W@V,C<[)B-X-D%&.R8C>#8S,3L@)B-X-C,T.R8C>#8T-3LF(W@V
M,C<[("8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T-#L@)B-X-C(X.R8C>#8T
M-SL@)B-X-C)!.R8C>#8S03LF(W@V-$$[)B-X-C1!.R8C>#8S,3L@)B-X-C0V
M.R8C>#8R-SLF(W@V-#4[("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SLF
M(W@V-30[("8C>#8T-CLF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@R,#!#.R8C
M>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V
M,C<[)B-X-C0T.R`F(W@V,S0[)B-X-C)&.R8C>#8T-SL@)B-X-C)&.R8C>#8S
M,3L@)B-X-C(W.R8C>#8R.#LF(W@V,D$[)B-X-C)&.R8C>#8R-SLF(W@V0T,[
M("8C>#8T-SLF(W@V,S$[("8C>#8T-3LF(W@V,C<[)B-X-C0W.R`F(W@V-#4[
M)B-X-C1!.R8C>#(P,$,[)B-X-C(X.R8C>#8R-SLF(W@V,S0[)B-X-C1!.R8C
M>#8R1CLF(W@V,$,[("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X
M-C(W.R8C>#8T03LF(W@V-#8[("8C>#9!1CLF(W@V,S([)B-X-C1!.R8C>#8T
M-CLF(W@V-#<[("8C>#8S,3LF(W@V,C<[("8C>#8R-SLF(W@V-#8[)B-X-C)!
M.R8C>#8R13LF(W@V,C<[)B-X-C(X.R`F(W@V-#8[)B-X-C0U.R8C>#8R-SLF
M(W@V,C8[)B-X-C1!.R8C>#8R1CLN("8C>#8R1CLF(W@V,S$[("8C>#8R-SLF
M(W@V-$$[)B-X-C0V.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V,D$[("8C
M>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V
M-#<[("8C>#8R.#LF(W@V-#<[("8C>#8T-CLF(W@V,C<[)B-X-C0U.R8C>#8T
M03L@)B-X-C)!.R8C>#8S03LF(W@V-$$[)B-X-C1!.R8C>#8S,3L@)B-X-C0V
M.R8C>#8R-SLF(W@V-#4[("8C>#8R1CLF(W@V,C<[)B-X-C)&.R8C>#8T-SL@
M)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C>#8R1CL@)B-X-C,T.R8C
M>#8R1CL@)B-X-D$Y.R8C>#8T-SL@)B-X-C)$.R8C>#8R-SLF(W@V-#@[)B-X
M-D-#.R`F(W@V-#8[)B-X-C(W.R8C>#8T-3L@)B-X-C0U.R8C>#8R-SLF(W@V
M-#<[("8C>#8T.#L@)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8R.#LF(W@V
M,C<[)B-X-C,T.R8C>#8R1CL@)B-X-C0X.R`F(W@V-$$[)B-X-D$Y.R`F(W@V
M-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[)B-X-C4T.R`F(W@V,D,[)B-X-C)&
M.R8C>#8T03LF(W@V,D8[("8C>#8T-CLF(W@V,C<[)B-X-C0U.R8C>#8T-SLF
M(W@R,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C
M>#8S,SLF(W@V,C<[)B-X-C0T.R8C>#8T03L@)B-X-C0V.R8C>#8T03LF(W@V
M,S([("8C>#8R-SLF(W@V-$$[)B-X-C)#.R8C>#8R-SLF(W@V,D8[("8C>#8R
M13LF(W@V-#@[)B-X-C(W.R8C>#8T-SLF(W@V,D8[("8C>#8S-#LF(W@V,D8[
M+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?
M<V5N=&UA:6Q?;6]N=&AL>2(@;60U/2(P8F5E9#$V9&9D-CAE,F8R-64P8S8V
M.#<Q9F0U-#9D9B(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^)B-X-C)!
M.R8C>#8S,3LF(W@V,D,[)B-X-C1!.R8C>#8R1#LF(W@V,C<[)B-X-C)!.R`Z
M("8C>#8T-CLF(W@V048[)B-X-C0W.R8C>#8R1CLF(W@V,C<[)B-X-C,Q.R8C
M>#9#0SL@.B`F(W@V,D0[)B-X-C,P.R8C>#8T,3L@)B-X-C=%.R8C>#8T.#LF
M(W@V,S0[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C
M>#8T-CLF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@R,#!#.R8C>#8T-SLF(W@V
M,C<[)B-X-D-#.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T
M.R8C>#8T03L@)B-X-C(X.R8C>#8T-SL@)B-X-C,U.R8C>#8T.#LF(W@V,S$[
M)B-X-C)!.R`F(W@V-#4[)B-X-C(W.R8C>#8T-SLF(W@V,C<[)B-X-C0V.R8C
M>#8T-SL\+W1I=&QE/B`*("`\<&%R83XF(W@V,C<[)B-X-D%&.R8C>#8S,3L@
M)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C
M>#8T-#L@)B-X-C(X.R8C>#8T-SL@)B-X-C)$.R8C>#8S,#LF(W@V-#$[("8C
M>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SLF(W@V-30[("8C>#8T-CLF(W@V
M,C<[)B-X-C0U.R8C>#8T-SLF(W@R,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#
M.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R8C>#8T03L@
M)B-X-C)&.R8C>#8S,3L@)B-X-C(W.R8C>#8R.#LF(W@V,D$[)B-X-C)&.R8C
M>#8R-SLF(W@V0T,[("8C>#8T-SLF(W@V,S$[("8C>#8T-3LF(W@V,C<[)B-X
M-C0W.R`F(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V-$$[)B-X-C)&.R`F(W@V
M,C@[)B-X-C(W.R8C>#8T03LF(W@V,D8[("8C>#8R-SLF(W@V-$$[)B-X-C0V
M.R`F(W@V048[)B-X-C,R.R8C>#8T03LF(W@V-#8[)B-X-C0W.R`F(W@V,S$[
M)B-X-C(W.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W.R8C
M>#8R.#L@)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C(V.R8C>#8T03LF(W@V
M,D8[+B`F(W@V.#8[)B-X-C0V.R8C>#8R-SLF(W@V-#8[)B-X-C@V.R8C>#8T
M-SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T-3LF(W@V,D0[)B-X-C)&
M.R8C>#8T.#LF(W@V,D8[)B-X-C1!.R8C>#8U,3LF(W@V,D$[("8C>#8R1CLF
M(W@V,S$[("8C>#8T,3LF(W@V,S8[)B-X-C(W.R8C>#9#0SL@)B-X-C)&.R8C
M>#8T03LF(W@V,S,[)B-X-D$Y.R`F(W@V-#4[)B-X-C0X.R8C>#8S,3LF(W@V
M,D8[("8C>#8R-SLF(W@V,S,[)B-X-C)!.R8C>#8T,3LF(W@V,C<[)B-X-C)&
M.R8C>#8T-SL@)B-X-C)%.R8C>#8T.#LF(W@V,D8[("8C>#8R1CLF(W@V,C<[
M)B-X-C,T.R8C>#8R03LF(W@V-#<[("8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C
M>#8T03LF(W@V,D8[)B-X-C!#.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V
M,D4[)B-X-C(W.R8C>#8R.#L@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#9!
M1CLF(W@V,S([)B-X-C1!.R8C>#8T-CLF(W@V-#<[("8C>#8T-3LF(W@V-#$[
M)B-X-C1!.R8C>#8R1CL@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C0W.R8C
M>#8R1CL@)B-X-C(X.R8C>#8T.#LF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K
M965P(B!M9#4](C<Q960Q8S)E86(T.&(Y,6$R-6(U8F-D-&(Q-&-C96$Y(B!S
M=&%T93TB=7!T;V1A=&4B/@H@(#QT:71L93XF(W@V,D$[)B-X-C,Q.R8C>#8R
M0SLF(W@V-$$[)B-X-C)$.R8C>#8R-SLF(W@V,D$[(#H@)B-X-C0V.R8C>#9!
M1CLF(W@V-#<[)B-X-C)&.R8C>#8R-SLF(W@V,S$[)B-X-D-#.R`Z("8C>#8R
M1#LF(W@V,S`[)B-X-C0Q.R`F(W@V-T4[)B-X-C0X.R8C>#8S-#LF(W@V-#<[
M)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C0V.R8C>#8R-SLF
M(W@V-#4[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C
M>#8R-SLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[)B-X-C1!.R`F(W@V
M,C@[)B-X-C0W.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V,D$[("8C>#8T
M-3LF(W@V,C<[)B-X-C0W.R8C>#8R-SLF(W@V-#8[)B-X-C0W.R`M("8C>#8T
M-3LF(W@V,C<[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R-SLF(W@V0T,[
M("8C>#8T-CLF(W@V048[)B-X-C0W.R8C>#8R1CLF(W@V,C<[)B-X-C,Q.R8C
M>#9#0SL\+W1I=&QE/B`*("`\<&%R83XF(W@V,C<[)B-X-D%&.R8C>#8S,3L@
M)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C
M>#8T-#L@)B-X-C(X.R8C>#8T-SL@)B-X-C)$.R8C>#8S,#LF(W@V-#$[("8C
M>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SLF(W@R,#!#.R8C>#8T-SLF(W@V
M,C<[)B-X-D-#.R`F(W@V-#8[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X,C`P
M0SLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C(W.R8C>#8S,3LF(W@V,S,[
M)B-X-C(W.R8C>#8T-#LF(W@V-$$[("8C>#8T,CLF(W@V,D8[)B-X-C1!.R8C
M>#8T-3LF(W@V-$$[("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,C@[)B-X
M-C(W.R8C>#8S-#LF(W@V-$$[)B-X-C)&.R8C>#8P0SL@)B-X-C(X.R8C>#8R
M-SLF(W@V-$$[)B-X-C)&.R`F(W@V-#4[)B-X-C0T.R8C>#8R-SLF(W@V03D[
M("8C>#8S,CLF(W@V-#4[)B-X-C(W.R8C>#8T-CLF(W@V0T,[("8C>#8R13LF
M(W@V-#@[)B-X-C)&.R`F(W@V,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C,Q.R8C
M>#8R-SLF(W@V0T,[("8C>#8T,CLF(W@V,D8[)B-X-C0U.R8C>#8R03L@)B-X
M-C=%.R8C>#8T.#LF(W@V,S0[)B-X-C0W.R8C>#(P,$,[)B-X-C0W.R8C>#8R
M-SL@)B-X-C)!.R8C>#8S.3LF(W@V-$$[)B-X-C1!.R8C>#8T-CL@)B-X-C0V
M.R8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T03LF(W@V,D8[+B`F(W@V,C@[
M)B-X-C,Y.R8C>#8R1CL@)B-X-C(W.R8C>#8S,CL@)B-X-C)!.R8C>#8S.3LF
M(W@V-$$[)B-X-C1!.R8C>#8T-CL@)B-X-C)!.R8C>#8S.3LF(W@V,D8[)B-X
M-C(W.R8C>#8R1CL@)B-X-C0U.R8C>#8R-SLF(W@V-#<[)B-X-C0W.R8C>#8R
M-SL@)B-X-C0X.R`F(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W
M.R8C>#8R.#L@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#9!1CLF(W@V,S([
M)B-X-C1!.R8C>#8T-CLF(W@V-#<[)B-X-C!#.R`F(W@V-T4[)B-X-C0X.R8C
M>#8S-#LF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X
M-C0R.R8C>#8R1CLF(W@V-$$[)B-X-C0U.R8C>#8T03L@)B-X-C)$.R8C>#8S
M,#LF(W@V-#$[("8C>#8R13LF(W@V-#@[)B-X-C(W.R8C>#8T-SLF(W@V-#8[
M)B-X-C)&.R`F(W@V,S0[)B-X-C)&.RX\+W!A<F$^(`H@(#PO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL>2(@
M;60U/2(S-S-E83`R961E-F1F-69C,S0U8V%F-C,R93$Y83<U9B(@<W1A=&4]
M(G5P=&]D871E(CX*("`\=&ET;&4^)B-X-C)!.R8C>#8S,3LF(W@V,D,[)B-X
M-C1!.R8C>#8R1#LF(W@V,C<[)B-X-C)!.R`Z("8C>#8T-CLF(W@V048[)B-X
M-C0W.R8C>#8R1CLF(W@V,C<[)B-X-C,Q.R8C>#9#0SL@.B`F(W@V,D0[)B-X
M-C,P.R8C>#8T,3L@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R
M03LF(W@V-#<[)B-X-C(W.R`F(W@V,C@[)B-X-C0W.R`F(W@V,S4[)B-X-C0X
M.R8C>#8S,3LF(W@V,D$[("8C>#8T-3LF(W@V,C<[)B-X-C0W.R8C>#8T-CLF
M(W@V,C<[)B-X-C0U.R8C>#8T-SL\+W1I=&QE/B`*("`\<&%R83XF(W@V,C<[
M)B-X-D%&.R8C>#8S,3L@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8T-3LF
M(W@V,C<[)B-X-C1!.R8C>#8T-#L@)B-X-C(X.R8C>#8T-SL@)B-X-C)$.R8C
M>#8S,#LF(W@V-#$[("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V
M,D$[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8T,CLF(W@V,D8[)B-X-C1!
M.R8C>#8T-3LF(W@V-$$[("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,D8[
M)B-X-C,Q.R`F(W@V,C<[)B-X-C(X.R8C>#8R03LF(W@V,D8[)B-X-C(W.R8C
M>#9#0SL@)B-X-C0W.R8C>#8S,3L@)B-X-C0U.R8C>#8R-SLF(W@V-#<[("8C
M>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8T03LF(W@V,D8[)B-X-C!#.R`F(W@V
M-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C)!.R8C>#8T.#LF(W@V,C<[)B-X-C0V
M.R8C>#8T03LF(W@V,D8[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V048[
M)B-X-C,R.R8C>#8T03LF(W@V-#8[)B-X-C0W.R`F(W@V,S$[)B-X-C(W.R`F
M(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W.R8C>#8R.#L@)B-X
M-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C(V.R8C>#8T03LF(W@V,D8[+B`F(W@V
M,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W.R8C>#8R.#L@)B-X-C(W
M.R8C>#8T03LF(W@V-#8[("8C>#9!1CLF(W@V,S([)B-X-C1!.R8C>#8T-CLF
M(W@V-#<[("8C>#8X-CLF(W@V-#8[)B-X-C(W.R8C>#8T-CLF(W@V.#8[)B-X
M-C0W.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C0U.R8C>#8R1#LF(W@V
M,D8[)B-X-C0X.R8C>#8R1CLF(W@V-$$[)B-X-C4Q.R8C>#8R03L@)B-X-C)&
M.R8C>#8S,3L@)B-X-C0Q.R8C>#8S-CLF(W@V,C<[)B-X-D-#.R`F(W@V,D8[
M)B-X-C1!.R8C>#8S,SLF(W@V03D[("8C>#8R1CLF(W@V,S$[("8C>#8R1CLF
M(W@V,S,[)B-X-C)!.R8C>#8S,3LF(W@V,S,[("8C>#8R13LF(W@V-#@[)B-X
M-C)&.R`F(W@V,D8[)B-X-C(W.R8C>#8S-#LF(W@V,D$[)B-X-C0W.R`F(W@V
M,C@[)B-X-C(W.R8C>#8S-#LF(W@V-$$[)B-X-C)&.R8C>#8P0SL@)B-X-C0U
M.R8C>#8T,3LF(W@V-$$[)B-X-C)&.R`F(W@V,C<[)B-X-C,S.R8C>#8R03LN
M/"]P87)A/B`*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]A
M='1A8VAM96YT<U]M;VYT:&QY7VME97`B(&UD-3TB,6(S-#!A-C`R,31D9F9D
M,#1A96,P,F-C,3$R-V1F-60B('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE
M/B8C>#8R03LF(W@V,S$[)B-X-C)#.R8C>#8T03LF(W@V,D0[)B-X-C(W.R8C
M>#8R03L@.B`F(W@V-#8[)B-X-D%&.R8C>#8T-SLF(W@V,D8[)B-X-C(W.R8C
M>#8S,3LF(W@V0T,[(#H@)B-X-C)$.R8C>#8S,#LF(W@V-#$[("8C>#8W13LF
M(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[)B-X-C0W.R8C>#8R-SL@)B-X
M-C(X.R8C>#8T-SL@)B-X-C,U.R8C>#8T.#LF(W@V,S$[)B-X-C)!.R`F(W@V
M-#4[)B-X-C(W.R8C>#8T-SLF(W@V-#8[)B-X-C(W.R8C>#8T-3LF(W@V-#<[
M("T@)B-X-C0U.R8C>#8R-SLF(W@V-#<[)B-X,C`P0SLF(W@V-#<[)B-X-C(W
M.R8C>#9#0SL@)B-X-C0V.R8C>#9!1CLF(W@V-#<[)B-X-C)&.R8C>#8R-SLF
M(W@V,S$[)B-X-D-#.SPO=&ET;&4^(`H@(#QP87)A/B8C>#8R-SLF(W@V048[
M)B-X-C,Q.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C0U.R8C>#8R-SLF
M(W@V-$$[)B-X-C0T.R`F(W@V,C@[)B-X-C0W.R`F(W@V,D0[)B-X-C,P.R8C
M>#8T,3L@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03LF(W@V
M-#<[)B-X-C(W.R8C>#9#0SL@)B-X-C0R.R8C>#8R1CLF(W@V-$$[)B-X-C0U
M.R8C>#8T03L@)B-X-C)%.R8C>#8T.#LF(W@V,D8[("8C>#8R1CLF(W@V,S$[
M("8C>#8T-SLF(W@V,S$[("8C>#8T-3LF(W@V,C<[)B-X-C0W.R`F(W@V,C@[
M)B-X-C(W.R8C>#8S-#LF(W@V-$$[)B-X-C)&.R8C>#8P0SL@)B-X-C(X.R8C
M>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V-#4[)B-X-C0T.R8C>#8R-SLF(W@V
M03D[("8C>#8S,CLF(W@V-#4[)B-X-C(W.R8C>#8T-CLF(W@V0T,[("8C>#8T
M,CLF(W@V,D8[)B-X-C0U.R8C>#8R03L@)B-X-C=%.R8C>#9#0SLF(W@V-#@[
M)B-X-C,S.R8C>#8R03LF(W@V-#<[)B-X-C(W.R`F(W@V,S$[)B-X-C(W.R`F
M(W@V,C@[)B-X-C0W.R`F(W@V-#4[)B-X-C(W.R8C>#8T-SL@)B-X-C0U.R8C
M>#8S-#LF(W@V,D4[)B-X-C,U.R`F(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V
M,C8[)B-X-C1!.R8C>#8R1CLN("8C>#8R1CLF(W@V,S$[("8C>#8R-SLF(W@V
M-$$[)B-X-C0V.R`F(W@V,S4[)B-X-C0X.R8C>#8S,3LF(W@V,D$[("8C>#8W
M13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[)B-X-C0W.R8C>#8R-SLF
M(W@V0T,[("8C>#9!.3LF(W@V-#<[("8C>#8T,CLF(W@V,D8[)B-X-C1!.R8C
M>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D$[)B-X-C,Q.R`F(W@V,C<[)B-X
M-C,R.R`F(W@V-#4[)B-X-C0T.R8C>#8R-SLF(W@V03D[("8C>#8T-3LF(W@V
M,S0[)B-X-C)%.R8C>#8S-3L@)B-X-C,T.R8C>#8R1CLF(W@V-#<[("8C>#8R
M03LF(W@V-#@[)B-X-C,S.R8C>#8S-SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[
M("8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8T-CLF(W@V,D8[)B-X-C!#.R`F
M(W@V,D0[)B-X-C,P.R8C>#8T,3L@)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X
M-C0W.R8C>#8T-CLF(W@V,D8[("8C>#8S-#LF(W@V,D8[+CPO<&%R83X@"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@;60U/2)D
M8S<Q.#<Q,30V8F4S930V861E,#`X-V$X8V8Q.#(W,R(@<W1A=&4](G5P=&]D
M871E(CX*("`\=&ET;&4^)B-X-C)!.R8C>#8S,3LF(W@V,D,[)B-X-C1!.R8C
M>#8R1#LF(W@V,C<[)B-X-C)!.R`Z("8C>#8T-CLF(W@V048[)B-X-C0W.R8C
M>#8R1CLF(W@V,C<[)B-X-C,Q.R8C>#9#0SL@.B`F(W@V,D4[)B-X-C(W.R8C
M>#8T-#LF(W@V0T,[("8C>#9!.3LF(W@V,S$[)B-X-C)&.R8C>#8T-CL@)B-X
M-C,S.R8C>#8S-SLF(W@V-#0[("8C>#8R,CLF(W@V,S0[)B-X-C-!.R8C>#8R
M-SLF(W@V-#0[/"]T:71L93X@"B`@/'!A<F$^)B-X-C(R.R8C>#8T03LF(W@V
M,C<[("8C>#8T-3LF(W@V,C<[)B-X-C1!.R8C>#8T-#L@)B-X-C(X.R8C>#8T
M-SL@)B-X-C)%.R8C>#8R-SLF(W@V-#0[)B-X-C1!.R`F(W@V03D[)B-X-C,Q
M.R8C>#8R1CLF(W@V-#8[("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SL@
M)B-X-C(R.R8C>#8S-#LF(W@V,T$[)B-X-C(W.R8C>#8T-#L@)B-X-C)%.R8C
M>#8T.#LF(W@V,D8[("8C>#8R1CLF(W@V,S$[("8C>#8T03LF(W@V03D[("8C
M>#8R03LF(W@V,S$[)B-X-C)!.R8C>#8T03LF(W@V,C@[("8C>#8S,CLF(W@V
M-#4[)B-X-C(W.R8C>#8T-CLF(W@V-$$[("8C>#8T-3LF(W@V-$$[)B-X,C`P
M0SLF(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V-$$[)B-X-C)&.RX\+W!A<F$^
M(`H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:6YT
M97)V86PB(&UD-3TB-V)E.3%F8F5B,#5B,F0X-S(X.60T8S4V,#)D-6$S,F8B
M('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/B8C>#8R03LF(W@V,S$[)B-X
M-C)#.R8C>#8T03LF(W@V,D0[)B-X-C(W.R8C>#8R03L@.B`F(W@V-#8[)B-X
M-D%&.R8C>#8T-SLF(W@V,D8[)B-X-C(W.R8C>#8S,3LF(W@V0T,[(#H@)B-X
M-C)!.R8C>#8S,3LF(W@V,D$[)B-X-C1!.R8C>#8R.#L@)B-X-C,R.R8C>#8T
M-3LF(W@V,C<[)B-X-C0V.R8C>#9#0SL@)B-X-C)%.R8C>#8R-SLF(W@V-#0[
M)B-X-D-#.R`F(W@V03D[)B-X-C,Q.R8C>#8R1CLF(W@V-#8[("8C>#8S,SLF
M(W@V,S<[)B-X-C0T.R`F(W@V,C([)B-X-C,T.R8C>#8S03LF(W@V,C<[)B-X
M-C0T.SPO=&ET;&4^(`H@(#QP87)A/B8C>#8X-CLF(W@V-#8[)B-X-C(W.R8C
M>#8T-CLF(W@V.#8[)B-X-C0W.R`F(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V
M-#0[("8C>#8R.#LF(W@V-#<[("8C>#8R13LF(W@V,C<[)B-X-C0T.R8C>#8T
M03L@)B-X-D$Y.R8C>#8S,3LF(W@V,D8[)B-X-C0V.R`F(W@V-T4[)B-X-C0X
M.R8C>#8S-#LF(W@V-#<[("8C>#8R,CLF(W@V,S0[)B-X-C-!.R8C>#8R-SLF
M(W@V-#0[("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,D8[)B-X-C,Q.R`F
M(W@V-$$[)B-X-D$Y.R`F(W@V,D$[)B-X-C,Q.R8C>#8R03LF(W@V-$$[)B-X
M-C(X.R`F(W@V,S([)B-X-C0U.R8C>#8R-SLF(W@V-#8[)B-X-C1!.R`F(W@V
M,C@[)B-X-C(W.R8C>#8S-#LF(W@V-$$[)B-X-C)&.R8C>#8P0SL@)B-X-C(X
M.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@
M)B-X-C)!.R8C>#8S,3LF(W@V,D$[)B-X-C1!.R8C>#8R.#L@)B-X-C,R.R8C
M>#8T-3LF(W@V,C<[)B-X-C0V.R8C>#8T03L@)B-X-C,Q.R8C>#8R-SL@)B-X
M-C0U.R8C>#8S-#LF(W@V,D4[)B-X-C,U.R`F(W@V03D[)B-X-C0V.R8C>#8T
M03LF(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUP=7)G95]T<F%S:%]K965P(B!M9#4](C-C8C5A,F(U8C@P8C=A8S$Q-SEA
M93`P-68Y.#,Y-S!E(B!S=&%T93TB=7!T;V1A=&4B/@H@(#QT:71L93XF(W@V
M,D$[)B-X-C,Q.R8C>#8R0SLF(W@V-$$[)B-X-C)$.R8C>#8R-SLF(W@V,D$[
M(#H@)B-X-C0V.R8C>#9!1CLF(W@V-#<[)B-X-C)&.R8C>#8R-SLF(W@V,S$[
M)B-X-D-#.R`Z("8C>#8T-3LF(W@V,D8[)B-X-C)!.R`F(W@V,S([)B-X-C0U
M.R8C>#8R-SLF(W@V-#8[("8C>#8T-CLF(W@V048[)B-X-C0W.R8C>#8R1CLF
M(W@V,C<[)B-X-C,Q.R8C>#9#0SL@)B-X-C(R.R8C>#8S-#LF(W@V,T$[)B-X
M-C(W.R8C>#8T-#LF(W@V-#<[)B-X-C(W.SPO=&ET;&4^(`H@(#QP87)A/B8C
M>#8R-SLF(W@V048[)B-X-C,Q.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X
M-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C0T.R`F(W@V,C@[)B-X-C0W.R`F(W@V
M,D4[)B-X-C(W.R8C>#8T-#LF(W@V-$$[("8C>#9!.3LF(W@V,S$[)B-X-C)&
M.R8C>#8T-CL@)B-X-C=%.R8C>#8T.#LF(W@V,S0[)B-X-C0W.R8C>#8U-#L@
M)B-X-C(R.R8C>#8S-#LF(W@V,T$[)B-X-C(W.R8C>#8T-#L@)B-X-C)%.R8C
M>#8T.#LF(W@V,D8[("8C>#8T-SLF(W@V,S,[)B-X-C)!.R8C>#8T03LF(W@V
M,D8[("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X-C0U.R8C>#8T
M-#LF(W@V,C<[)B-X-D$Y.R`F(W@V,S([)B-X-C0U.R8C>#8R-SLF(W@V-#8[
M)B-X-D-#.R`F(W@V-#([)B-X-C)&.R8C>#8T-3LF(W@V,D$[("8C>#8W13LF
M(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R8C>#8R-SLF(W@V
M0T,[("8C>#8T-3LF(W@V-#@[)B-X-C)#.R8C>#8T.#LF(W@V,D8[("8C>#8R
M1CLF(W@V,S$[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V-T4[)B-X-C0X
M.R8C>#8S-#LF(W@V-#<[("8C>#8S,3LF(W@V,C<[("@F(W@V,C@[)B-X-C0W
M.R`F(W@V,S$[)B-X-C0X.R8C>#8S,CLI("8C>#8T-3LF(W@V,S0[)B-X-C)%
M.R8C>#8S-3L@)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C(V.R8C>#8T03LF
M(W@V,D8[+CPO<&%R83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUA
M='1R:6)?=&5X="(@;60U/2(W,C%A,#ED-V-A,#(X8SDW93-B9#)B,SAC-3DW
M9F9F-R(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^)B-X-C)!.R8C>#8S
M,3LF(W@V,D,[)B-X-C1!.R8C>#8R1#LF(W@V,C<[)B-X-C)!.R`Z("8C>#8R
M-SLF(W@V-$$[)B-X-C)#.R8C>#8R-SLF(W@V,D8[("8C>#8W13LF(W@V-$$[
M)B-X-C-!.R8C>#8R-SLF(W@V-#4[(#H@)B-X-C)!.R8C>#8S,3LF(W@V03D[
M)B-X-C1!.R8C>#8R.#LF(W@R,#!#.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F
M(W@V,D4[)B-X-C(W.R8C>#8S-3L\+W1I=&QE/B`*("`\<&%R83XF(W@V,C<[
M)B-X-C1!.R8C>#8T-CLF(W@V,D,[)B-X-C(W.R`F(W@V,S0[)B-X-C0U.R8C
M>#8R-SL@)B-X-C0U.R8C>#8T03LF(W@R,#!#.R8C>#8R03LF(W@V-#@[)B-X
M-C(W.R8C>#8T-CLF(W@V-$$[)B-X-C)&.R`F(W@V,SD[)B-X-C(X.R8C>#8R
M-SLF(W@V,S$[)B-X-C)!.R8C>#8T03L@)B-X-C,Q.R8C>#8R-SL@)B-X-D$Y
M.R8C>#8T-SL@)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C0T.R`F(W@V,C@[
M)B-X-C0W.R`F(W@V,S@[)B-X-C(W.R8C>#8T-SLF(W@V,S$[("8C>#8S-#LF
M(W@V,D8[)B-X-C0V.R`F(W@V,C([)B-X-C0V.R`F(W@V-#([)B-X-C(X.R8C
M>#8T-#L@)B-X-C(W.R8C>#8S,CL@)B-X-C0W.R8C>#8S,3L@)B-X-C0U.R8C
M>#8R03LF(W@V-#8[("8C>#8T-CLF(W@V-#([)B-X-C0T.R`F(W@V-#([)B-X
M-C0X.R8C>#8T-#L@)B-X-C,T.R8C>#8R1CLF(W@V-#<[("8C>#8R1CLF(W@V
M,S$[("8C>#8W13LF(W@V,C<[)B-X-C,S.R8C>#8R13LF(W@V-#<[)B-X-C(W
M.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C(X.R8C>#8R-SLF(W@V,S0[
M)B-X-C1!.R8C>#8R1CL@)B-X-C,Q.R8C>#8R-SLF(W@V,$,[("8C>#8T.#LF
M(W@V,C<[)B-X-C,Q.R8C>#8R1CL@)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X
M-C(V.R8C>#8T03LF(W@V,D8[+CPO<&%R83X@"B`@/'!A<F$^)B-X-C,T.R8C
M>#8T-3LF(W@V,C<[("8C>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V,D$[)B-X
M-C0X.R8C>#8R-SLF(W@V-#8[)B-X-C1!.R8C>#8R1CL@)B-X-C(W.R8C>#8S
M,CL@)B-X-C1!.R8C>#9!.3L@)B-X-C1!.R8C>#8R-SL@)B-X-C@V.R8C>#8T
M-CLF(W@V,D8[("8C>#8R03LF(W@V,S$[)B-X-D$Y.R8C>#8T03LF(W@V,C@[
M("8C>#8R13LF(W@V,C<[)B-X-C,U.R`F(W@V,D8[)B-X-C,Q.R`F(W@V,D8[
M)B-X-C(W.R8C>#8R13LF(W@V-#0[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C
M>#8R-SLF(W@V-#4[("8C>#8R13LF(W@V-#@[)B-X-C)&.R`F(W@V,C@[)B-X
M-C0W.R`F(W@V-#<[)B-X-C0V.R8C>#9!1CLF(W@V,C<[)B-X-C0U.R`F(W@V
M,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R`F(W@V-T4[)B-X-C(W
M.R8C>#8S,SLF(W@V,D4[("8C>#8R-SLF(W@V,S,[)B-X-C)!.R8C>#8T,3LF
M(W@V,C<[)B-X-C)&.R8C>#8T-SL@)B-X-C0V.R8C>#8T-3LF(W@V,C<[)B-X
M-C(V.R8C>#8T03LF(W@V,D8[+B`F(W@V,D8[)B-X-C,Q.R`F(W@V,S([)B-X
M-C1!.R8C>#8S,3L@)B-X-C0Q.R8C>#8T-SLF(W@V,S$[)B-X-C,S.R8C>#8R
M03LF(W@V-$$[("8C>#8R-SLF(W@V,S([("8C>#8R-SLF(W@V-$$[)B-X-C0V
M.R`F(W@V,D$[)B-X-C,Q.R8C>#9!.3LF(W@V-$$[)B-X-C(X.R8C>#8R-SLF
M(W@V,D$[("8C>#8S,3LF(W@V,C<[("8C>#8T-3LF(W@V,S0[)B-X-C(W.R8C
M>#8T-SLF(W@V,D8[)B-X-C0W.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X
M-C0V.R8C>#8T-3LF(W@V,C<[)B-X-C(V.R8C>#8T03LF(W@V,D8[.CPO<&%R
M83X@"B`@/'!A<F$^9B4@.B`F(W@V-#8[)B-X-C(W.R8C>#8T-3L@)B-X-C0X
M.R`F(W@V,C([)B-X-C)&.R8C>#8S,3LF(W@V,S,[("8C>#8T-CLF(W@V,C<[
M)B-X-C0U.R8C>#8T-SL@)B-X-C(W.R8C>#8T-#LF(W@V03D[)B-X-C)!.R8C
M>#8S,3LF(W@V-#@[)B-X-C0V.R8C>#8T03LF(W@V03D[)B-X-D-#.R`F(W@V
M-#$[)B-X-C,Q.R8C>#8S,SLF(W@V,D$[)B-X-C0V.R8C>#8R1CLF(W@V-#<[
M/"]P87)A/B`*("`\<&%R83YA)2`Z("8C>#8R,CLF(W@V,D8[)B-X-C,Q.R8C
M>#8S,SL@)B-X-C0V.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R`F(W@V,C<[)B-X
M-C0T.R8C>#9!.3LF(W@V,D$[)B-X-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C1!
M.R8C>#9!.3LF(W@V0T,[("8C>#8T,3LF(W@V,S$[)B-X-C,S.R8C>#8R03LF
M(W@V-#8[)B-X-C)&.R8C>#8T-SL\+W!A<F$^(`H@(#QP87)A/G`E(#H@)B-X
M-C0V.R8C>#8R-SLF(W@V-#4[("8C>#8T,3LF(W@V,S$[)B-X-C,S.R8C>#8R
M03LF(W@V-#8[)B-X-C)&.R8C>#8T-SL\+W!A<F$^(`H@(#QP87)A/G(E(#H@
M)B-X-C0Q.R8C>#8S,3LF(W@V-#4[)B-X-C)!.R`F(W@V03D[)B-X-C(W.R8C
M>#8T-3LF(W@V-#0[("8C>#8R03LF(W@V,C<[)B-X-C,Q.R8C>#8T03LF(W@V
M,D4[("8C>#8T.#L@)B-X-C,R.R8C>#8T-3LF(W@V,C<[)B-X-C0V.R`F(W@V
M,D8[)B-X-C,Q.R!21D,@)B-X-D8R.R8C>#9&.#LF(W@V1C([)B-X-D8R.SPO
M<&%R83X@"B`@/'!A<F$^9"4@.B`F(W@V,D$[)B-X-C(W.R8C>#8S,3LF(W@V
M-$$[)B-X-C)%.R`F(W@V,D8[)B-X-C,Q.R`F(W@V-#$[)B-X-C,Q.R8C>#8T
M-3LF(W@V,D$[(&1D(&UM;2!Y>7EY/"]P87)A/B`*("`\<&%R83YX)2`Z("8C
M>#8S,CLF(W@V-#4[)B-X-C(W.R8C>#8T-CL@)B-X-C)&.R8C>#8S,3L@)B-X
M-C0U.R8C>#8R1#LF(W@V-#0[)B-X-C4Q.R8C>#8T03LF(W@V,D$[("8C>#8R
M0SLF(W@V,C<[)B-X-C,Q.R8C>#9#0SL\+W!A<F$^(`H@(#QP87)A/F,E(#H@
M)B-X-C)!.R8C>#8R-SLF(W@V,S$[)B-X-C1!.R8C>#8R13L@)B-X-C0X.R`F
M(W@V,S([)B-X-C0U.R8C>#8R-SLF(W@V-#8[("8C>#8R1CLF(W@V,S$[("8C
M>#8T-3LF(W@V,D0[)B-X-C0T.R8C>#8U,3LF(W@V-$$[)B-X-C)!.R`F(W@V
M,D,[)B-X-C(W.R8C>#8S,3LF(W@V0T,[/"]P87)A/B`*("`\<&%R83YM)2`Z
M("8C>#8T-3LF(W@V,S0[)B-X-C)%.R8C>#8S-3LF(W@V-#<[("A)1"D@)B-X
M-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L\+W!A<F$^(`H@(#QP
M87)A/G,E(#H@)B-X-C0U.R8C>#8T.#LF(W@V,S8[)B-X-C0X.R8C>#8S.3L\
M+W!A<F$^(`H@(#QP87)A/FXE(#H@)B-X-C)%.R8C>#8S-SL@)B-X-C)#.R8C
M>#8R1CLF(W@V-$$[)B-X-C)&.SPO<&%R83X@"B`@/'!A<F$^)24@.B`F(W@V
M-#8[)B-X-C0X.R8C>#8T03LF(W@V,S,[)B-X-C0W.R`F(W@V-D$[/"]P87)A
M/B`*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E
M<75E<W1?<F5A9"(@;60U/2(X.64Y,F,T9#8X,C(T8C(S-#5B-3DY-3DX-SAA
M-S$W-"(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^)B-X-C)!.R8C>#8S
M,3LF(W@V,D,[)B-X-C1!.R8C>#8R1#LF(W@V,C<[)B-X-C)!.R`Z("8C>#8R
M1CLF(W@V,S$[)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C,S.R8C>#8R03L@
M)B-X-C,Q.R8C>#8S,SLF(W@V-$$[)B-X-C)&.R`F(W@V-#4[)B-X-C,W.R8C
M>#8R-SLF(W@V-#0[)B-X-C,Y.R8C>#8T-SL\+W1I=&QE/B`*("`\<&%R83XF
M(W@V,C<[)B-X-C0V.R8C>#8R03LF(W@V,D4[)B-X-C(W.R8C>#8R.#L@)B-X
M-D%&.R8C>#8S,CLF(W@V-$$[)B-X-C0V.R8C>#8T-SL@(B8C>#8R1CLF(W@V
M,S$[)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C,S.R8C>#8R03L@)B-X-C,Q
M.R8C>#8S,SLF(W@V-$$[)B-X-C)&.R`F(W@V-#4[)B-X-C,W.R8C>#8R-SLF
M(W@V-#0[)B-X-C,Y.R8C>#8T-SLB)B-X-C!#.R`F(W@V,D8[)B-X-C,Q.R`F
M(W@V-#@[)B-X-C(W.R8C>#8T,CLF(W@V,SD[("8C>#8T03LF(W@V03D[("8C
M>#8R1CLF(W@V,S$[)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C,S.R8C>#8R
M03L@)B-X-C(X.R8C>#8T-SL@)B-X-D%&.R8C>#8T03LF(W@V,S$[)B-X-C0V
M.R8C>#8R1CLF(W@V048[)B-X-C(W.R8C>#8T-CL@)B-X-C=%.R8C>#8T03LF
M(W@V,T$[)B-X-C(W.R8C>#8T-3L@)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X
M-C(W.R8C>#8T-#L@)B-X-D$Y.R8C>#8S,3LF(W@V,D8[)B-X-C0W.R`F(W@V
M-#@[("8C>#8R-SLF(W@V,S([("8C>#8R,CLF(W@V-#8[)B-X-C0W.R8C>#8R
M-SL@)B-X-C)&.R8C>#8S,3LF(W@V,D4[)B-X-C0X.R8C>#8R-SLF(W@V,S,[
M)B-X-C)!.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-D$Y.R8C>#8T-CLF
M(W@V,D8[("8C>#9!.3LF(W@V-#<[("8C>#8R.#LF(W@V-#<[("8C>#8T-SLF
M(W@V-#8[)B-X-D%&.R8C>#8R-SLF(W@V-#4[("8C>#8T-3LF(W@V,S<[)B-X
M-C(W.R8C>#8T-#LF(W@V,SD[)B-X-C0W.R`F(W@V,C<[)B-X-C0X.R8C>#8T
M-#LF(W@V-$$[)B-X-C0W.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[
M)B-X-C0U.R8C>#8P0SL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8S,3LF
M(W@V,C<[("8C>#8R-SLF(W@V,S([("8C>#8R,CLF(W@V-#8[("8C>#8T-3LF
M(W@V,S<[)B-X-C0T.R8C>#8S.3L@)B-X-C,S.R8C>#8R-SLF(W@V,S([)B-X
M-C0V.R8C>#8R1CLN("8C>#8R.#LF(W@V,C<[)B-X-C1!.R8C>#8R1CL@)B-X
M-C)!.R8C>#8T.#LF(W@V,D,[)B-X-C0W.R`F(W@V-#8[)B-X-C0U.R8C>#8R
M-SLF(W@V,C8[)B-X-C1!.R8C>#8R1CL@)B-X-D$Y.R8C>#8T-SL@)B-X-C)!
M.R8C>#8T-3LF(W@V,C<[)B-X-C0U.R8C>#8T03L@)B-X-D$Y.R8C>#8R-SLF
M(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V,S([)B-X-C0W.R8C>#8R-SLF(W@V
M0T,[("8C>#8T-CLF(W@V,C<[)B-X-C0U.R8C>#8T-SL@)B-X-C(W.R8C>#8T
M-#LF(W@V03D[)B-X-C)!.R8C>#8S,3LF(W@V-#@[)B-X-C0V.R8C>#8T03LF
M(W@V03D[)B-X-C1!.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C,Y.R8C
M>#8T-3LF(W@V-#0[("8C>#8S,3LF(W@V,C<[("8C>#8W13LF(W@V,S0[)B-X
M-C)!.R8C>#8T03LF(W@V,C@[)B-X-C(W.R8C>#8T-CLF(W@V-$$[("8C>#8T
M-CLF(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-D$Y.R8C>#8T-CLF(W@V-#8[
M)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M9&ES<&]S:71I;VY?<V5N9%]M9&XB(&UD-3TB,69E,#1E-61C,V1E-CAD,3<R
M9&$R.#0X.34Y-S-E83DB('-T871E/2)U<'1O9&%T92(^"B`@/'1I=&QE/B8C
M>#8R03LF(W@V,S$[)B-X-C)#.R8C>#8T03LF(W@V,D0[)B-X-C(W.R8C>#8R
M03L@.B`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R!-1$X\
M+W1I=&QE/B`*("`\<&%R83XF(W@V048[)B-X-C,R.R8C>#8T03LF(W@V-#8[
M)B-X-C0W.R`B)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#L@
M341.(B8C>#8P0SL@)B-X-C1!.R8C>#9!.3L@)B-X-C)!.R8C>#8S,#LF(W@V
M03D[)B-X-C4Q.R8C>#8S,3L@341.("@F(W@V,D0[)B-X-C(W.R8C>#8T-#LF
M(W@V,D$[("8C>#8W13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[*2`F
M(W@V,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C0W.R`F(W@V-#$[)B-X-C,Q.R8C
M>#8S,SLF(W@V,D$[)B-X-C0V.R8C>#8R1CLF(W@V-#<[)B-X-C4T.R`F(W@V
M-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V,C<[)B-X-C,Q
M.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[
M)B-X-D$Y.R8C>#8T-CLF(W@V,D8[+B`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@
M)B-X-C)!.R8C>#8S,#LF(W@V03D[)B-X-C4Q.R8C>#8S,3L@)B-X-C0U.R8C
M>#8R-SLF(W@V-#8[)B-X-C0V.R8C>#8R1CL@)B-X-C)&.R8C>#8S,3LF(W@V
M,D4[)B-X-C0X.R8C>#8R-SLF(W@V,S,[)B-X-C)!.R`F(W@V,S$[)B-X-C,S
M.R8C>#8T03LF(W@V,D8[("8C>#8T-3LF(W@V,S<[)B-X-C(W.R8C>#8T-#LF
M(W@V,SD[)B-X-C0W.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C(X.R8C
M>#8R-SLF(W@V,S0[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F(W@V048[)B-X
M-C(W.R8C>#8T-SLF(W@V-$$[("8C>#8R.#LF(W@V-#<[("8C>#8S-SLF(W@V
M-#@[)B-X-C,Q.R`F(W@V,C<[)B-X-C)!.R8C>#8T.#LF(W@V-#4[)B-X-C(W
M.R8C>#8R03LF(W@V-$$[)B-X-D$Y.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF
M(W@V,C<[)B-X-C0T.R`F(W@V,S0[)B-X-C)&.R8C>#8T-SL@)B-X-C0X.R`F
M(W@V048[)B-X-C(W.R8C>#8T-SLF(W@V-$$[("8C>#8T-CLF(W@V-$$[)B-X
M-C,R.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C0U.R8C>#8T03LF(W@R
M,#!#.R8C>#8R03LF(W@V-#@[)B-X-C(W.R8C>#8T-CLF(W@V-$$[)B-X-C)&
M.R`F(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R`F(W@V,C([
M)B-X-C0V.R8C>#8S,3LF(W@V,C<[("8C>#8R.#LF(W@V-#<[("8C>#8S-3LF
M(W@V-#@[)B-X-C,Q.R8C>#8R03L@)B-X-C)&.R8C>#8S,SLF(W@V,D$[)B-X
M-C1!.R`F(W@V-#4[)B-X-C0T.R8C>#8S03LF(W@V-$$[("8C>#8T-CLF(W@V
M-#4[)B-X-C(W.R8C>#8R-CLF(W@V-$$[)B-X-C)&.RX\+W!A<F$^(`H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]D
M96QI=F5R>2(@;60U/2(R-C4Y.&4R.6%F,#5A,#=D935E,3,V-#0V-CEB93<Q
M,B(@<W1A=&4](G5P=&]D871E(CX*("`\=&ET;&4^)B-X-C)!.R8C>#8S,3LF
M(W@V,D,[)B-X-C1!.R8C>#8R1#LF(W@V,C<[)B-X-C)!.R`Z("8C>#8R1CLF
M(W@V,S$[)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X-C,S.R8C>#8R03L@)B-X
M-C)!.R8C>#8R,SLF(W@V-$$[)B-X-C1!.R8C>#8R1CL@)B-X-C)!.R8C>#8R
M1#LF(W@V-#@[)B-X-C1!.R8C>#8T-#L\+W1I=&QE/B`*("`\<&%R83XB)B-X
M-C)&.R8C>#8S,3LF(W@V,D4[)B-X-C0X.R8C>#8R-SLF(W@V,S,[)B-X-C)!
M.R`F(W@V,D$[)B-X-C(S.R8C>#9#0SLF(W@V-$$[)B-X-C)&.R`F(W@V,C<[
M)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C0T.R(F(W@V,$,[("8C>#8T03LF
M(W@V03D[("8C>#8R1CLF(W@V,S$[)B-X-C)%.R8C>#8T.#LF(W@V,C<[)B-X
M-C,S.R8C>#8R03L@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F(W@V
M03D[)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8S,CL@)B-X-C=%
M.R8C>#8S,SLF(W@V,D$[("8C>#8R-SLF(W@V-#0[)B-X-D$Y.R8C>#8R03LF
M(W@V,S$[)B-X-C0X.R8C>#8T-CLF(W@V-$$[)B-X-D$Y.R8C>#8T03L@)B-X
M-D%&.R8C>#8T03LF(W@V,S$[)B-X-C0V.R8C>#8R1CLF(W@V-#<[("8C>#8R
M-SLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8T-3LF(W@V-$$[
M)B-X,C`P0SLF(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C)&.R`F
M(W@V,D$[)B-X-C(W.R`F(W@V-#$[)B-X-C,Q.R8C>#8S,SLF(W@V,D$[)B-X
M-C0V.R8C>#8R1CLF(W@V-#<[("8C>#8S,3LF(W@V,C<[("8C>#8R-SLF(W@V
M,S([("8C>#8R-SLF(W@V,S$[)B-X-C,S.R8C>#8R-SLF(W@V-#0[("8C>#8W
M13LF(W@V-$$[)B-X-C-!.R8C>#8R-SLF(W@V-#4[("8C>#8R.#LF(W@V-#<[
M("8C>#8T-CLF(W@V,C<[)B-X-C0U.R8C>#8T-SLF(W@R,#!#.R8C>#8R1CLF
M(W@V,C<[)B-X-C0V.R`F(W@V048[)B-X-C1!.R8C>#8S,3LF(W@V-#8[)B-X
M-C)&.R8C>#8T-SL@)B-X-C(R.R8C>#9!1CLF(W@V,C<[)B-X-C0W.R`F(W@V
M-#8[)B-X-C0U.R8C>#8R-SLF(W@V-$$[)B-X-C)&.RX@)B-X-C(W.R8C>#8T
M-#LF(W@V,C@[)B-X-C)!.R8C>#8T-SL@)B-X-C)&.R8C>#8S,3LF(W@V-$$[
M)B-X-C(W.R8C>#8T,3LF(W@V,D$[("8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F
M(W@V,S$[)B-X-C,S.R8C>#8T03LF(W@V,D8[("8C>#8R.#LF(W@V-#<[("8C
M>#8T-3LF(W@V,SD[)B-X-C0V.R8C>#8T03L@)B-X-C)%.R8C>#8T.#LF(W@V
M,C<[)B-X-C0V.R8C>#8R1CLF(W@V-#<[("8C>#8S-#LF(W@V,D8[)B-X-C0V
M.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X-C0U.R`F(W@V,D$[
M)B-X-C0X.R8C>#8S,SLF(W@V,S<[("8C>#9!1CLF(W@V-$$[)B-X-C,Q.R8C
M>#8T-CLF(W@V,D8[)B-X-C0W.R`F(W@V-#8[)B-X-C1!.R8C>#8S,SLF(W@V
M,D$[+B`F(W@V,C@[)B-X-C,Q.R8C>#8R13LF(W@V-$$[("8C>#8R-SLF(W@V
M,S([("8C>#9!.3LF(W@V,C<[)B-X-C,Q.R8C>#8S,SLF(W@V,C<[)B-X-C,R
M.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V-#8[)B-X-C(W.R8C>#8T-3LF
M(W@V-#<[)B-X-C4T.R`F(W@V,C<[)B-X-C0T.R8C>#9!.3LF(W@V,D$[)B-X
M-C,Q.R8C>#8T.#LF(W@V-#8[)B-X-C1!.R8C>#9!.3LF(W@V-$$[("8C>#8R
M-SLF(W@V-$$[)B-X-C0V.R`F(W@V-#([)B-X-C(W.R8C>#8R.#LF(W@V-#0[
M)B-X-C1!.R8C>#8U,3LF(W@V,D$[("8C>#8S,3LF(W@V,C<[("8C>#8W13LF
M(W@V,S0[)B-X-C)!.R8C>#8T03LF(W@V,C@[)B-X-C(W.R8C>#8T-CLF(W@V
M-$$[("8C>#8T-CLF(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-D$Y.R8C>#8T
M-CLF(W@V-#8[)B-X-C)&.RX\+W!A<F$^(`H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M9&5L971E7W-P86U?869T97)?<F5P;W)T(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@1&5L971E(%-P86T@069T97(@
M4F5P;W)T:6YG/"]T:71L93X*("`@(#QP87)A/@H@("`@66]U(&UA>2!E;&5C
M="!T;R!D;R!O;F4@;V8@=&AR964@:71E;7,@869T97(@<F5P;W)T:6YG(&$@
M;65S<V%G92!A<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="X*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@1FER<W0L('EO=2!C86X@9&5C:61E('1O(&1O
M(&YO=&AI;F<@+2!T:&4@;65S<V%G92!W:6QL(&)E(')E<&]R=&5D(&%S(&5I
M=&AE<B!S<&%M(&]R(&EN;F]C96YT(&)U="!W:6QL(&]T:&5R=VES92!R96UA
M:6X@=6YC:&%N9V5D(&EN('EO=7(@;6%I;&)O>"X*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@4V5C;VYD+"!I9B!R97!O<G1I;F<@82!M97-S86=E(&%S
M('-P86TL('EO=2!C86X@:6YS=&5A9"!H879E('1H92!M97-S86=E(&)E(&EM
M;65D:6%T96QY(&1E;&5T960N("!4:&ES('-E='1I;F<@:&%S(&YO(&5F9F5C
M="!O;B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("!4:&ER9"P@869T97(@<F5P;W)T:6YG(&$@
M;65S<V%G92!A<R!S<&%M('1H92!M97-S86=E('=I;&P@8F4@9&5L971E9"!F
M<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D('1O('EO=7(@<W!A
M;2!F;VQD97(N("!!;'1E<FYA=&EV96QY+"!I9B!R97!O<G1I;F<@82!M97-S
M86=E(&%S(&EN;F]C96YT('1H92!M97-S86=E('=I;&P@8F4@9&5L971E9"!F
M<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D('1O('EO=7(@24Y"
M3U@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUH
M=&UL7VEM86=E7W)E<&QA8V5M96YT(B!M9#4](C(X93%C9C`X93,R.#,T-6$X
M93<R-S1C.#4S-#DR9#1F(B!S=&%T93TB=7!T;V1A=&4B/@H@(#QT:71L93XF
M(W@V,D$[)B-X-C,Q.R8C>#8R0SLF(W@V-$$[)B-X-C)$.R8C>#8R-SLF(W@V
M,D$[(#H@)B-X-C)#.R8C>#8R-SLF(W@V-$$[)B-X-D%&.R8C>#8S,#LF(W@V
M,C<[)B-X-C,Q.R8C>#9#0SL@)B-X-C)!.R8C>#8S-3LF(W@V-#@[)B-X-C1!
M.R8C>#8S,3L@)B-X-C)&.R8C>#8S,3L@2%1-3#PO=&ET;&4^(`H@(#QP87)A
M/B8C>#8R,CLF(W@V-$$[)B-X-C(W.R`F(W@V-#<[)B-X-C0V.R8C>#9!1CLF
M(W@V,C<[)B-X-C0U.R8C>#8T03L@)B-X-D$Y.R8C>#8T-SL@)B-X-C1!.R8C
M>#9!.3L@)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3L@)B-X
M-C,Q.R8C>#8R-SL@)B-X-C)&.R8C>#8S,3L@)B-X-C0Q.R8C>#8S,3LF(W@V
M-#4[)B-X-C)!.R!(5$U,("8C>#8T-3LF(W@V,S0[)B-X-C(W.R8C>#8T-SLF
M(W@V,D8[)B-X-C0W.R`F(W@V-#4[)B-X-C1!.R8C>#(P,$,[)B-X-C0V.R8C
M>#8T-3LF(W@V,C<[)B-X-C(V.R8C>#8T03LF(W@V,D8[+B`F(W@V,D$[)B-X
M-C,U.R8C>#8R-SLF(W@V-#@[)B-X-C1!.R8C>#8S,3L@)B-X-C(X.R8C>#8T
M-#LF(W@V-#@[)B-X-D$Y.R8C>#8T-SL@)B-X-C(X.R8C>#8R-SLF(W@V,S0[
M)B-X-C0V.R8C>#8R1CL@)B-X-C)!.R8C>#8R-SL@)B-X-C,T.R8C>#8T-3LF
M(W@V,C<[("8C>#8T-CLF(W@V-#4[)B-X-C(W.R8C>#8T03LF(W@V,S0[("8C
M>#8R,CLF(W@V-#8[)B-X-C0W.R8C>#8R-SL@)B-X-C,Q.R8C>#8R-SL@)B-X
M-C)!.R8C>#8R,SLF(W@V0T,[)B-X-C1!.R8C>#8R1CL@)B-X-D$Y.R8C>#8T
M-CLF(W@V-$$[)B-X-C)&.R8C>#8Q1CL\+W!A<F$^(`H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]A9&1R8F]O:R(@;60U/2(W-3EF
M83-D9C(T93!A,V-D.#EF,S(P,3`R,C4R9CDQ82(@<W1A=&4](G5P=&]D871E
M(CX*("`\=&ET;&4^)B-X-C)!.R8C>#8S,3LF(W@V,D,[)B-X-C1!.R8C>#8R
M1#LF(W@V,C<[)B-X-C)!.R`Z("8C>#8R0SLF(W@V,C<[)B-X-C1!.R8C>#9!
M1CLF(W@V,S`[)B-X-C(W.R8C>#8S,3LF(W@V0T,[("8C>#8R03LF(W@V,S4[
M)B-X-C0X.R8C>#8T03LF(W@V,S$[("8C>#8R1CLF(W@V,S$[2%1-3"`O("8C
M>#8R1#LF(W@V,S8[)B-X-C0X.R8C>#8S,3L@)B-X-C)&.R8C>#8S,3L@)B-X
M-D$Y.R8C>#8R03LF(W@V,C<[)B-X-C(X.R8C>#8X-CLF(W@V-#<[)B-X-C4T
M.R`F(W@V,C([)B-X-C)&.R8C>#8S,3LF(W@V,S,[/"]T:71L93X@"B`@/'!A
M<F$^)B-X-C(W.R8C>#9!1CLF(W@V,S$[("8C>#8S-#LF(W@V-#4[)B-X-C(W
M.R`F(W@V,D$[)B-X-C,U.R8C>#8R-SLF(W@V-#@[)B-X-C1!.R8C>#8S,3L@
M)B-X-C=%.R8C>#8T03LF(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X
M-C(W.R8C>#9#0SL@2%1-3"`F(W@V,S$[)B-X-C(W.R`F(W@V,C@[)B-X-C0T
M.R8C>#8T.#LF(W@V03D[)B-X-C0W.R`F(W@V03D[)B-X-C,Q.R8C>#8R1CLF
M(W@V-#<[("8C>#8R.#LF(W@V,C<[)B-X-C,T.R8C>#8T03LF(W@V,D8[)B-X
M-C!#.R`F(W@V,C([)B-X-C1!.R8C>#8R-SL@)B-X-C0U.R8C>#8R-SLF(W@V
M-$$[)B-X-C0T.R`F(W@V-#<[)B-X-C,S.R8C>#8R03LF(W@V-$$[)B-X-C)&
M.R`F(W@V03D[)B-X-C0W.R`F(W@V,C<[)B-X-C1!.R8C>#8T-CL@)B-X-C0U
M.R8C>#8S,SLF(W@V,C8[)B-X-C0T.R8C>#8T-SL@)B-X-C(X.R8C>#8S,3LF
M(W@V,C<[)B-X-D-#.R`F(W@V-#$[)B-X-C,Q.R8C>#8S,SLF(W@V,D$[)B-X
M-C0V.R8C>#8R1CLF(W@V048[)B-X-C(W.R8C>#8T-CLF(W@V-$$[("8C>#9!
M.3LF(W@V-#<[("8C>#8R1CLF(W@V,S$[("8C>#9!.3LF(W@V,D$[)B-X-C(W
M.R8C>#8R.#LF(W@V.#8[)B-X-C0W.R8C>#8U-#L@)B-X-C(R.R8C>#8R1CLF
M(W@V,S$[)B-X-C,S.R`F(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C0X.R8C
M>#8R0SLF(W@V-#@[)B-X-C)&.R`F(W@V,D8[)B-X-C(W.R8C>#8S,3LF(W@V
M-#8[)B-X-C)&.R`F(W@V-#4[)B-X-C,S.R8C>#8R03LF(W@V,D([)B-X-C0V
M.R8C>#8T03L@)B-X-C,T.R8C>#8T.#LF(W@V,D8[)B-X-C%&.SPO<&%R83X@
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUM86EL8F]X7W-T87)T(B!M
M9#4](C-D,3$Y-F8R-C5D.&(W8V,T-C5E8F8R,34Q,F%C8S`U(B!S=&%T93TB
M=7!T;V1A=&4B/@H@(#QT:71L93XF(W@V,D$[)B-X-C,Q.R8C>#8R0SLF(W@V
M-$$[)B-X-C)$.R8C>#8R-SLF(W@V,D$[(#H@)B-X-C,U.R8C>#8T,3LF(W@V
M,D0[)B-X-C0W.R8C>#8U-#L@)B-X-C(R.R8C>#8S03LF(W@V,C<[)B-X-C,R
M.R8C>#8T03LF(W@V-#8[("8C>#8T-CLF(W@V,C<[)B-X-C0U.R8C>#8T-SLF
M(W@R,#!#.R8C>#8R1CLF(W@V,C<[)B-X-C0V.SPO=&ET;&4^(`H@(#QP87)A
M/B8C>#8R-SLF(W@V-$$[)B-X-C0V.R`F(W@V048[)B-X-C,R.R8C>#8T03LF
M(W@V-#8[)B-X-C0W.R`F(W@V-#4[)B-X-C,T.R8C>#8R13LF(W@V,S4[("8C
M>#8T-3LF(W@V-$$[)B-X,C`P0SLF(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V
M-$$[)B-X-C)&.R`F(W@V03D[)B-X-C0W.R`F(W@V03D[)B-X-C)&.R8C>#8R
M-SLF(W@V-#4[("8C>#8S-3LF(W@V-#$[)B-X-C)$.R8C>#8T-SL@)B-X-C)&
M.R8C>#8S,3L@)B-X-C0V.R8C>#8R-SLF(W@V-#4[)B-X-C0W.R8C>#(P,$,[
M)B-X-C)&.R8C>#8R-SLF(W@V-#8[("8C>#8S-#LF(W@V-#4[)B-X-C(W.R8C
M>#8P0SL@)B-X-C0W.R8C>#8T-CLF(W@V048[)B-X-C(W.R8C>#8T-3LF(W@V
M-$$[("8C>#9!.3LF(W@V-#<[("8C>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#9#
M0SL@)B-X-C(X.R8C>#8R-SLF(W@V,S$[("8C>#8R-SLF(W@V-#@[)B-X-C0T
M.R`F(W@V,C@[)B-X-C0W.R`F(W@V,C([)B-X-C0V.R`F(W@V,D8[)B-X-C,S
M.R8C>#8R03LF(W@V,S$[)B-X-C,S.R8C>#8T03L@)B-X-C0U.R8C>#8T03LF
M(W@R,#!#.R8C>#8T03LF(W@V,C<[)B-X-C(X.R8C>#8T03LF(W@V,D8[)B-X
M-C!#.R`F(W@V,C@[)B-X-C(W.R8C>#8T03LF(W@V,D8[("8C>#8T-CLF(W@V
M-#4[)B-X-C(W.R8C>#8T03LF(W@V,S0[("8C>#8R1CLF(W@V,C<[)B-X-C)&
M.R8C>#8T-SL@)B-X-C,T.R8C>#8T.#LF(W@V,D8[)B-X-C%&.SPO<&%R83X@
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E7V%T=&%C:&UE;G1S
M(B!M9#4](C,U8C0V,S,T8V1C8S=F830Q-F(Y9CEF8V$U.#<T93@P(B!S=&%T
M93TB=7!T;V1A=&4B/@H@(#QT:71L93XF(W@V,D$[)B-X-C,Q.R8C>#8R0SLF
M(W@V-$$[)B-X-C)$.R8C>#8R-SLF(W@V,D$[(#H@)B-X-C,P.R8C>#8R13LF
M(W@V-$$[)B-X-C,Q.R8C>#8T-SLF(W@V-30[("8C>#8W13LF(W@V0T,[)B-X
M-C0X.R8C>#8S,SLF(W@V,D$[)B-X-C0W.R8C>#8R-SL@)B-X-C=%.R8C>#8T
M03LF(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R8C>#9#0SL@
M)B-X-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#LF(W@V0T,[/"]T
M:71L93X@"B`@/'!A<F$^)B-X-C(W.R8C>#9!1CLF(W@V,S$[("8C>#8S-#LF
M(W@V-#4[)B-X-C(W.R`F(W@V-T4[)B-X-C1!.R8C>#8S03LF(W@V,C<[)B-X
M-C0U.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,C<[)B-X-C1!.R8C>#8R
M0SLF(W@V,C<[)B-X-C)&.R`F(W@V,S0[)B-X-C)&.R8C>#8T-SL@)B-X-C)%
M.R8C>#8T.#LF(W@V,D8[("8C>#8S,3LF(W@V,C<[("8C>#8R1CLF(W@V,S$[
M("8C>#8W13LF(W@V-#@[)B-X-C,T.R8C>#8T-SL@)B-X-C=%.R8C>#8T03LF
M(W@V,T$[)B-X-C(W.R8C>#8T-3LF(W@V-#<[)B-X-C(W.R8C>#9#0SL@)B-X
M-C(W.R8C>#8S,3LF(W@V,S,[)B-X-C(W.R8C>#8T-#LF(W@V-$$[("8C>#8S
M,#LF(W@V,D4[)B-X-C1!.R8C>#8S,3LF(W@V-#<[("8C>#8T-3LF(W@V-$$[
M)B-X,C`P0SLF(W@V-#8[)B-X-C0U.R8C>#8R-SLF(W@V,C8[)B-X-C1!.R8C
M>#8R1CLF(W@V,$,[("8C>#8R,CLF(W@V-$$[)B-X-C(W.R`F(W@V,C@[)B-X
M-C(W.R8C>#8T03LF(W@V,D8[("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S
M,SLF(W@V,D$[)B-X-C0W.R8C>#8R-SLF(W@V0T,[("8C>#8R,CLF(W@V-#8[
M)B-X-C0W.R8C>#8R-SL@)B-X-C0V.R8C>#8T03LF(W@V,S([("8C>#8S,#LF
M(W@V,D4[)B-X-C1!.R8C>#8S,3LF(W@V-#<[("8C>#8S-#LF(W@V-#@[)B-X
M-C0V.R8C>#8R1CLF(W@V,48[("8C>#8R-SLF(W@V-#8[)B-X-C)!.R8C>#8R
M13LF(W@V,C<[)B-X-C(X.R8C>#8T-SLF(W@V,C<[)B-X-D-#.R`F(W@V,S([
M)B-X-C1!.R8C>#8S,3L@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-D-#.R`F
M(W@V,S0[)B-X-C0U.R8C>#8R-SL@)B-X-C0X.R8C>#8R0SLF(W@V-#@[)B-X
M-C)&.R`F(W@V,D8[)B-X-C(W.R8C>#8S,3LF(W@V,D8[.CPO<&%R83X@"B`@
M/'!A<F$^*B`B)B-X-C0W.R8C>#8T-3LF(W@V-#@[)B-X-C(W.R8C>#8S,3LF
M(W@V-#<[("8C>#8W13LF(W@V0T,[)B-X-C0X.R8C>#8S,SLF(W@V,D$[)B-X
M-C0W.R8C>#8R-SL@)B-X-C,P.R8C>#8R13LF(W@V-$$[)B-X-C,Q.R8C>#8T
M-SL@)B-X-C,T.R8C>#8T.#LF(W@V-#8[)B-X-C)&.R(@)B-X,C`Q,SL@)B-X
M-C)&.R8C>#8S,3L@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C>#8R1#LF(W@V
M,C<[)B-X-C0T.R8C>#8R03L@)B-X-C(X.R8C>#8S,3LF(W@V,C<[)B-X-C1!
M.R`F(W@V,S`[)B-X-C)%.R8C>#8T03LF(W@V,S$[)B-X-C0W.R8C>#8U-#L@
M)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03L@)B-X-C(W.R8C
M>#8S,CL@)B-X-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8S,SLF(W@V-#@[)B-X
M-C(W.R8C>#8T-#L@)B-X-C0V.R8C>#8R13LF(W@V-#@[)B-X-C(W.R8C>#8T
M-SLF(W@V,D8[("8C>#8S-#LF(W@V,D8[+CPO<&%R83X@"B`@/'!A<F$^*B`B
M)B-X-C0W.R8C>#8T-3LF(W@V-#@[)B-X-C(W.R8C>#8S,3LF(W@V-#<[("8C
M>#8R.#LF(W@V,S$[)B-X-C(W.R8C>#8T03L@)B-X-C,P.R8C>#8R13LF(W@V
M-$$[)B-X-C,Q.R8C>#8T-SLF(W@V-30[("8C>#8W13LF(W@V0T,[)B-X-C0X
M.R8C>#8S,SLF(W@V,D$[)B-X-C0W.R8C>#8R-SL@)B-X-C,S.R8C>#8R-#LF
M(W@V,C<[)B-X-C0T.R`F(W@V,S0[)B-X-C0X.R8C>#8R1CL@)B-X-C0X.R`F
M(W@V,D,[)B-X-C0X.R8C>#8R-SLF(W@V,C@[("8C>#8W13LF(W@V-$$[)B-X
M-C,T.R8C>#(P,$,[)B-X-C0Q.R8C>#8S,3LF(W@V,S8[("8C>#8R.#LF(W@V
M-#0[)B-X-C0W.R`F(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V,D8[+B(\+W!A
M<F$^(`H@(#QP87)A/BH@(B8C>#8T-SLF(W@V-#4[)B-X-C0X.R8C>#8R-SLF
M(W@V,S$[)B-X-C0W.R`F(W@V,C@[)B-X-C,Q.R8C>#8R-SLF(W@V-$$[("8C
M>#8S,#LF(W@V,D4[)B-X-C1!.R8C>#8S,3LF(W@V-#<[)B-X-C4T.R`F(W@V
M-T4[)B-X-D-#.R8C>#8T.#LF(W@V,S,[)B-X-C)!.R8C>#8T-SLF(W@V,C<[
M("8C>#8S,SLF(W@V,C0[)B-X-C(W.R8C>#8T-#L@)B-X-C,T.R8C>#8T.#LF
M(W@V,D8[("8C>#8T.#L@)B-X-C)#.R8C>#8T.#LF(W@V,C<[)B-X-C(X.R`F
M(W@V-T4[)B-X-C1!.R8C>#8S-#LF(W@R,#!#.R8C>#8T,3LF(W@V,S$[)B-X
M-C,V.R`F(W@V-#8[)B-X-C0W.R`F(W@V,C@[)B-X-C(W.R8C>#8S-#LF(W@V
M,D8[+B(\+W!A<F$^(`H@(#QP87)A/BH@(B8C>#8T-SLF(W@V,S$[)B-X-D%&
M.R8C>#8S,CL@)B-X-C=%.R8C>#9#0SLF(W@V-#@[)B-X-C,S.R8C>#8R03LF
M(W@V-#<[)B-X-C(W.R`F(W@V,S`[)B-X-C)%.R8C>#8T03LF(W@V,S$[)B-X
M-C0W.R`F(W@V-#8[)B-X-C,T.R8C>#8T.#LF(W@V-#8[)B-X-C)&.R(@)B-X
M,C`Q,SL@)B-X-C)&.R8C>#8S,3L@)B-X-C(W.R8C>#8T03LF(W@V-#8[("8C
M>#8R1#LF(W@V,C<[)B-X-C0T.R8C>#8R03L@)B-X-C(W.R8C>#8S,CL@)B-X
M-C,T.R8C>#8T-3LF(W@V,C<[("8C>#8S,SLF(W@V,C0[)B-X-C(W.R8C>#8T
M-#LF(W@V-$$[("8C>#8T-CLF(W@V,S0[)B-X-C)&.R8C>#8T-SL@)B-X-C0X
M.R`F(W@V-T4[)B-X-D-#.R8C>#8T.#LF(W@V,S,[)B-X-C)!.R8C>#8T-SLF
M(W@V,C<[("8C>#8T-SLF(W@V,S$[)B-X-D%&.R8C>#8S,CL@)B-X-C,P.R8C
M>#8R13LF(W@V-$$[)B-X-C,Q.R8C>#8T-SL@)B-X-C0V.R8C>#8T-3LF(W@V
M-$$[)B-X,C`P0SLF(W@V,S0[)B-X-C0X.R8C>#8T-CLF(W@V,D8[+CPO<&%R
M83X@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7VEN8F]X(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@
M26YB;W@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)U=&%L($EN8F]X(&ES
M(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@
M=&\@<V5A<F-H(&5V97)Y(&UA:6QB;W@@9F]R(&UE<W-A9V5S(&UA<FME9"!A
M<R!N97<N("!);G-T96%D+"!A;&P@8W5R<F5N=&QY('-U8G-C<FEB960@;6%I
M;&)O>&5S(&%R92!S96%R8VAE9"!F;W(@;F5W(&UE<W-A9V5S(&%N9"!T:&4@
M<F5S=6QT<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7W1R87-H
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I
M<G1U86P@5')A<V@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)T=6%L(%1R
M87-H(&ES(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE
M(&YE960@9F]R(&$@<V5P87)A=&4@5')A<V@@9F]L9&5R+B`@26YS=&5A9"!O
M9B!M;W9I;F<@;65S<V%G97,@=&\@82!C96YT<F%L:7IE9"!T<F%S:"!F;VQD
M97(L(&UE<W-A9V5S(&%R92!S:6UP;'D@;6%R:V5D(&%S(&1E;&5T960@:6X@
M=&AE(&-U<G)E;G0@9F]L9&5R('1H97D@;&EV92!I;BX@(%=H96X@)W-H;W<@
M9&5L971E9"!M97-S86=E<R<@:7,@='5R;F5D(&]F9BP@=&AI<R!R97-U;'1S
M(&EN('1H97-E(&UE<W-A9V5S(&YO="!A<'!E87)I;F<@:6X@82!M86EL8F]X
M('9I97<N("!7:&5N(&$@=7-E<B!C;&EC:W,@;VX@5FER='5A;"!4<F%S:"P@
M*F%L;"H@;6%I;&)O>&5S(&%L;"!S96%R8VAE9"!F;W(@;65S<V%G97,@=&AA
M="!A<F4@9FQA9V=E9"!D96QE=&5D(&%N9"!T:&5S92!M97-S86=E<R!A<F4@
M9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"CPO:&5L<#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M;&]C86QE+V5N7U53+P``````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8P`#`Q-S0U-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O96Y?55,O:&5L<"YX;6P`````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3`W-S$`,3`T,3<S-C(W-C``
M,#(Q,3,U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_>&UL('9E<G-I;VX])S$N,"<_/@H\(2TM("1(;W)D93H@:6UP+VQO
M8V%L92]E;E]54R]H96QP+GAM;"QV(#$N-3,N-BXV(#(P,#4O,3$O,#<@,#@Z
M-#8Z-#$@:F%N($5X<"`D("TM/@H\:&5L<#X*"CQE;G1R>2!I9#TB8V]M<&]S
M92UB=71T;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!
M8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D%C=&EO;G,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("9Q=6]T.U-E;F0@365S<V%G929Q=6]T.R!T<F%N
M<VUI=',@>6]U<B!E;6%I;"!M97-S86=E('1O('1H92!I;G1E;F1E9"!R96-I
M<&EE;G0H<RDN($UA:V4@<W5R92!Y;W4@9&\@=V%N="!T;R!S96YD('EO=7(@
M;65S<V%G92!A<R!T:&ES(&%C=&EO;B!I<R!F:6YA;"!A;F0@8V%N(&YO="!B
M92!R979E<G-E9"X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@)G%U;W0[
M4V%V92!$<F%F="9Q=6]T.R!P;&%C97,@86X@=6YF:6YI<VAE9"!M97-S86=E
M(&EN(&$@9F]L9&5R(&-A;&QE9"`F<75O=#M$<F%F=',F<75O=#L@86-C97-S
M:6)L92!T:')O=6=H('1H92!F;VQD97(@9')O<"UD;W=N(&)O>"!A="!T:&4@
M=&]P+7)I9VAT(&]F('EO=7(@<V-R965N+B!9;W4@8V%N('1H96X@9FEN:7-H
M('1H92!M97-S86=E(&QA=&5R(&)Y('-W:71C:&EN9R!T;R!T:&4@)G%U;W0[
M1')A9G1S)G%U;W0[(&9O;&1E<BP@8VQI8VMI;F<@;VX@=&AE('-A=F5D(&UE
M<W-A9V4@=&\@;W!E;B!I="P@86YD('1H96X@8VQI8VMI;F<@;VX@)G%U;W0[
M4F5S=6UE)G%U;W0[+B!"92!S=7)E('1O('!U="!A('-U8FIE8W0@;VX@=&AE
M(&5M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A9G0@<V\@=&AA="!Y;W4@
M8V%N(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S86=E('EO=2!W86YT('=I
M=&AI;B!T:&4@1')A9G1S(&9O;&1E<BX*("`@(#PO<&%R83X*("`@(#QT:7`^
M"B`@("!$97!E;F1I;F<@;VX@>6]U<B!I;G-T86QL871I;VXL('EO=2!C86X@
M8VAA;F=E(&EN('EO=7(@<')E9F5R96YC97,@=VAE=&AE<B!Y;W4@87)E(')E
M='5R;F5D('1O('1H92!L87-T(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&]R
M(&)A8VL@=&\@=&AE('-A;64@;65S<V%G92!A9G1E<B!S879I;F<@82!M97-S
M86=E(&%S(&$@9')A9G0N"B`@("`\+W1I<#X*("`@(#QP87)A/@H@("`@)G%U
M;W0[0V%N8V5L($UE<W-A9V4F<75O=#L@9')O<',@=&AE(&UE<W-A9V4@:6X@
M<')O9W)E<W,@86YD('-I;7!L>2!R971U<FYS('EO=2!T;R!T:&4@;&%S="!F
M;VQD97(@>6]U('=E<F4@=FEE=VEN9RX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M"CQE;G1R>2!I9#TB8V]M<&]S92UF<F]M(CX*("`@(#QT:71L93Y-97-S86=E
M($-O;7!O<VET:6]N.B!&<F]M/"]T:71L93X*("`@(#QH96%D:6YG/D9R;VT\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF(&5N86)L960@8GD@>6]U<B!A
M9&UI;FES=')A=&]R('EO=2!C86X@8VAO;W-E(&9R;VT@82!D<F]P+61O=VX@
M;&ES="!A;B!I9&5N=&ET>2!T:&%T('EO=2!E;G1E<F5D('5N9&5R(#QQ=#Y/
M<'1I;VYS+29G=#M097)S;VYA;"!);F9O<FUA=&EO;CPO<70^+"!O<B!Y;W4@
M8V%N(&5N=&5R('1H92!M86EL(&%D9')E<W,@:6X@82!T97AT(&9I96QD('1H
M870@>6]U('=A;G0@=&\@=7-E(&%S('1H92!S96YD97(@;V8@=&AI<R!M97-S
M86=E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)C;VUP;W-E
M+71O(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!4;SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY4;SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<R!F;W(@=&AE(')E8VEP
M:65N="!O9B!Y;W5R(&UE<W-A9V4N(%1O(&5N=&5R(&UU;'1I<&QE(')E8VEP
M:65N=',L('-E<&%R871E('1H92!E;6%I;"!A9&1R97-S97,@=VET:"!C;VUM
M87,N(%5S92!O9B!A;GD@;W1H97(@<'5N8W1U871I;VX@=&\@<V5P87)A=&4@
M;75L=&EP;&4@96UA:6P@861D<F5S<V5S('=I;&P@<F5S=6QT(&EN(&%N(&5R
M<F]R+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)C;VUP;W-E
M+6-C(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!#8SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY#8SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<R!F;W(@=&AE(&-A<F)O
M;B!C;W!Y(')E8VEP:65N="!O9B!Y;W5R(&UE<W-A9V4N(%1O(&5N=&5R(&UU
M;'1I<&QE(')E8VEP:65N=',L('-E<&%R871E('1H92!E;6%I;"!A9&1R97-S
M97,@=VET:"!C;VUM87,N(%5S92!O9B!A;GD@;W1H97(@<'5N8W1U871I;VX@
M=&\@<V5P87)A=&4@;75L=&EP;&4@96UA:6P@861D<F5S<V5S('=I;&P@<F5S
M=6QT(&EN(&%N(&5R<F]R+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#
M87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@=&\@<F5C:7!I96YT<R!W
M:&\@;F5E9"!N;W0@8F4@=&AE(&1I<F5C="!R96-I<&EE;G1S(&]F('1H92!M
M97-S86=E+"!B=70@;6%Y(&YE960@=&\@<F5C96EV92!T:&4@;65S<V%G92!F
M;W(@=&AE:7(@:6YF;W)M871I;VXL('5S=6%L;'D@:6YD:7)E8W1L>2!C;VYC
M97)N960@86)O=70@=&AE('-U8FIE8W0@;V8@=&AE(&5M86EL+B!!;&P@)G%U
M;W0[5&\Z)G%U;W0[(')E8VEP:65N=',@86YD("9Q=6]T.T-C.B9Q=6]T.R!R
M96-I<&EE;G1S(&-A;B!S964@=&AE(&5N=&ER92!L:7-T(&]F(&)O=&@@:VEN
M9',@;V8@<F5C:7!I96YT<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R
M>2!I9#TB8V]M<&]S92UB8V,B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ($)C8SPO=&ET;&4^"B`@("`\:&5A9&EN9SY"8V,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E
M<W,@9F]R('1H92!B;&EN9"!C87)B;VX@8V]P>2!R96-I<&EE;G0@;V8@>6]U
M<B!M97-S86=E+B!4;R!E;G1E<B!M=6QT:7!L92!R96-I<&EE;G1S+"!S97!A
M<F%T92!T:&4@96UA:6P@861D<F5S<V5S('=I=&@@8V]M;6%S+B!5<V4@;V8@
M86YY(&]T:&5R('!U;F-T=6%T:6]N('1O('-E<&%R871E(&UU;'1I<&QE(&5M
M86EL(&%D9')E<W-E<R!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@0FQI;F0@8V%R8F]N(&-O<&EE<R!A<F4@
M=7-U86QL>2!S96YT('1O(')E8VEP:65N=',@=VAO(&UA>2!N965D('1O(')E
M860@=VAA="!I<R!B96EN9R!W<FET=&5N(%=)5$A/550@=&AE(&]T:&5R(')E
M8VEP:65N=',@:VYO=VEN9R!T:&%T('1H97D@87)E(')E8V5I=FEN9R!T:&4@
M96UA:6PN(%1H=7,@)G%U;W0[8FQI;F0F<75O=#L@;65A;G,@=&AA="!T:&4@
M:61E;G1I='D@;V8@=&AE<V4@<F5C:7!I96YT<R!I<R!H:61D96X@9G)O;2!A
M;&P@;W1H97(@<F5C:7!I96YT<R!O9B!T:&4@96UA:6PN($]N;'D@>6]U('1H
M92!S96YD97(@86YD('1H92`F<75O=#M"8V,F<75O=#L@<F5C:7!I96YT<R!W
M:6QL(&MN;W<@=&AA="!T:&5Y(')E8V5I=F5D(&$@8V]P>2X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!3=6)J96-T/"]T:71L93X*
M("`@(#QH96%D:6YG/E-U8FIE8W0\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($5N=&5R('1H92!S=6)J96-T(&]F('EO=7(@;65S<V%G92X@270@:7,@8F5S
M="!T;R!K965P('1H92!S=6)J96-T('-H;W)T+"!S:6UP;&4@86YD(&1E<V-R
M:7!T:79E+B!4:&4@<W5B:F5C="!L:6YE(&ES('1H92!E87-I97-T('=A>2!F
M;W(@>6]U(&%N9"!Y;W5R(&-O<G)E<W!O;F1E;G1S('1O(')E;65M8F5R('=H
M870@=V%S(&EN('1H92!E;6%I;"P@=&AU<R!I<R!V97)Y(&EM<&]R=&%N="!I
M;B!O<F=A;FEZ:6YG('EO=7(@96UA:6P@86YD(&9I;F1I;F<@:6UP;W)T86YT
M(&]N97,@;&%T97(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%L<V\L
M('=H96X@>6]U("9Q=6]T.U)E<&QY)G%U;W0[(&]R("9Q=6]T.T9O<G=A<F0F
M<75O=#L@86X@96UA:6PL('1H:7,@<W5B:F5C="!L:6YE(&ES(&-O<&EE9"!O
M=F5R(&EN=&\@=&AE(&YE=R!M97-S86=E('-O('1H870@:7,@8F5C;VUE<R!A
M('9A;'5A8FQE('=A>2!O9B!I9&5N=&EF>6EN9R!W:&EC:"!M97-S86=E<R!G
M;R!T;V=E=&AE<B!T;R!F;W)M(&$@)G%U;W0[=&AR96%D)G%U;W0[('1O(&%N
M(&5M86EL(&-O;G9E<G-A=&EO;BX@07,@82!S=6=G97-T:6]N+"!I9B!A(')E
M<&QI960@;W(@9F]R=V%R9&5D(&UE<W-A9V4@8V]N=&%I;G,@;F5W(&ED96%S
M+"!Y;W4@;6%Y('=A;G0@=&\@86QT97(@<VQI9VAT;'D@=&AE("9Q=6]T.U-U
M8FIE8W0F<75O=#L@;&EN92!S;R!T:&%T(')E8VEP:65N=',@8V%N(&9O;&QO
M=R!T:&4@<')O9W)E<W-I;VX@;V8@=&AE("9Q=6]T.W1H<F5A9"9Q=6]T.RX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB8V]M<&]S92UO<'1I
M;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!/<'1I;VYS
M/"]T:71L93X*("`@(#QH96%D:6YG/D]P=&EO;G,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H97-E($]P=&EO;G,@:&5L<"!Y;W4@<')E<&%R92!Y;W5R
M(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-L:6-K("9Q
M=6]T.U-P96QL($-H96-K)G%U;W0[('1O(&-H96-K('EO=7(@<W!E;&QI;F<N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-L:6-K("9Q=6]T.T%T=&%C
M:&UE;G1S)G%U;W0[('1O(&=O('1O('1H92!B;W1T;VT@;V8@=&AE('!A9V4@
M=VAE<F4@>6]U(&-A;B!A='1A8V@@9FEL97,@=&\@=&AI<R!M97-S86=E+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!)9B!S879I;F<@;V8@<V5N="!M
M86EL(&AA<R!B965N(&5N86)L960@8GD@>6]U<B!A9&UI;FES=')A=&]R+"!Y
M;W4@8V%N(&%C=&EV871E('1H92!C:&5C:V)O>"!N97AT('1O("9Q=6]T.U-A
M=F4@82!C;W!Y)G%U;W0[('1O(&ME97`@82!C;W!Y('EO=7(@=&AI<R!M97-S
M86=E('EO=2!S96YD+B!4:&4@9&5S=&EN871I;VX@9F]L9&5R('=I;&P@8F4@
M96ET:&5R('1H92!D969A=6QT(&]R('1H92!O;F4@>6]U('-E;&5C=&5D(&9O
M<B!T:&ES('!U<G!O<V4@=6YD97(@)G%U;W0[3W!T:6]N<RTF9W0[4&5R<V]N
M86P@26YF;W)M871I;VXM)F=T.TED96YT:71I97,F<75O=#LN($EF('EO=7(@
M861D;6EN<W1R871O<B!H87,@86-T:79A=&5D('1H92!S96QE8W1I;VX@;V8@
M82!S96YT(&UA:6P@9&5S=&EN871I;VXL('EO=2!W:6QL(&)E(&%B;&4@=&\@
M8VAO;W-E('1H92!F;VQD97(@9G)O;2!A(&1R;W`M9&]W;B!L:7-T(&YE>'0@
M=&\@=&AI<R!O<'1I;VXN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-A
M=FEN9R!C;W!I97,@;V8@:6UP;W)T86YT(&5M86EL<R!Y;W4@<V5N9"!C;W5L
M9"!B92!U<V5F=6P@9F]R(')E8V]R9"!K965P:6YG(&]F('=H870@=V%S(&1I
M<V-U<W-E9"X@66]U(&-A;BP@:&]W979E<BP@='5R;B!T:&ES(&9E871U<F4@
M)G%U;W0[;VXF<75O=#L@87,@>6]U<B!D969A=6QT('=I=&AI;B!Y;W5R($ED
M96YT:71Y+"!B>2!G;VEN9R!T;R`F<75O=#M/<'1I;VYS+29G=#M097)S;VYA
M;"!);F9O<FUA=&EO;BTF9W0[161I="!Y;W5R(&ED96YT:71I97,F<75O=#LN
M($EN('EO=7(@;W!T:6]N<R!Y;W4@8V%N(&%L<V\@<V5T=7`@;6%I;G1E;F%N
M8V4@=&%S:W,@=&AA="!E;7!T>2!O<B!R96YA;64@=&AE<V4@9F]L9&5R<R!P
M97)I;V1I8V%L;'DN"B`@("`\+W!A<F$^"B`@("`\=V%R;CX*("`@(%EO=2!M
M87D@;F]T('=A;G0@=&\@<V%V92!E=F5R>2!E;6%I;"!S:6YC92!Y;W4@8V]U
M;&0@:&%V92!P<F]B;&5M<R!W:71H('EO=7(@9&ES:R!S=&]R86=E('%U;W1A
M(&)E:6YG('5S960@=7`@<75I8VML>2P@97-P96-I86QL>2!W:&5N('EO=2!S
M96YD(&QA<F=E(&%T=&%C:&UE;G1S+B!!(&UA:6QB;W@@=VET:"!F=6QL('-T
M;W)A9V4@<75O=&$@=VEL;"!N;W0@8F4@86)L92!T;R!R96-E:79E(&YE=R!I
M;F-O;6EN9R!E;6%I;"X*("`@(#PO=V%R;CX*/"]E;G1R>3X*"CQE;G1R>2!I
M9#TB8V]M<&]S92UA='1A8V@B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!='1A8V@\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%EO=2!M87D@871T86-H(&9I;&5S('1O
M('EO=7(@;65S<V%G92!I9B!Y;W5R(&)R;W=S97(@<W5P<&]R=',@=7!L;V%D
M:6YG(&]F(&9I;&5S+B!-;W)E('1H86X@,2!F:6QE(&-A;B!B92!U<&QO861E
M9"!A="!O;F-E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`Q.B!%:71H
M97(@='EP92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A(&9I;&4@=&AA="!Y;W4@
M=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@;W(@8VQI8VL@=&AE("9Q
M=6]T.T)R;W=S929Q=6]T.R!B=71T;VX@86YD('-E;&5C="!T:&4@9FEL92!T
M;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N86UE(&]F('1H870@9FEL
M92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N="!B;W@N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83Y3=&5P(#(Z($1E8VED92!W:&5T:&5R('EO=2!W86YT
M('1H92!F:6QE('1O(&)E('9I97=E9"!A<R!A;B!A='1A8VAM96YT(&]R(&EN
M;&EN92!W:71H('1H92!R97-T(&]F('1H92!M97-S86=E+B!4:&4@<F5C:7!I
M96YT)W,@;6%I;"!R96%D:6YG('-O9G1W87)E(&UU<W0@8F4@86)L92!T;R!H
M86YD;&4@=&AE(&EN;&EN92!D:7-P;&%Y(&]F('1H92!F:6QE('1Y<&4L(&]T
M:&5R=VES92!T:&ES('!A<G0@=VEL;"!B92!V:65W960@87,@86X@871T86-H
M;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@/'1I<#X*("`@(%!L96%S
M92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S(&%N9"]O<B!S;&]W97(@26YT
M97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C97-S(&]F('5P;&]A9&EN9R!A
M;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T:&4@96UA:6P@;6%Y('1A:V4@
M82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@86YD(&1O(&YO="!C;&EC:R!O
M=&AE<B!L:6YK<R!O<B!B=71T;VYS('=H:6QE('EO=2!A<F4@=V%I=&EN9R!F
M;W(@82!F:6QE('1O('5P;&]A9"X*("`@(#PO=&EP/@H\+V5N=')Y/@H*/&5N
M=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(CX*("`@(#QT:71L93Y-97-S
M86=E($-O;7!O<VET:6]N.B!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY!='1A8VAM96YT<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI
M<R!S96-T:6]N(&1I<W!L87ES(&$@;&ES="!O9B!F:6QE<R!A;')E861Y(&%T
M=&%C:&5D('1O('EO=7(@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/D1E;&5T92!A='1A8VAE9"!F:6QE*',I/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4;R!D96QE=&4@86X@871T86-H960@9FEL92AS*3H*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@4W1E<"`Q.B!!8W1I=F%T92!T:&4@8VAE
M8VLM8G5T=&]N(&YE>'0@=&\@=&AE(&%T=&%C:&5D(&9I;&5N86UE*',I('EO
M=2!W86YT('1O(&1E;&5T92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M4W1E<"`R.B!#;&EC:R`F<75O=#M5<&1A=&4@071T86-H;65N="!);F9O<FUA
M=&EO;B9Q=6]T.RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D-H86YG92!!
M='1A8VAM96YT($1I<W!O<VET:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4;R!C:&%N9V4@=&AE(&1I<W!O<VET:6]N(&9O<B!Y;W5R(&%T=&%C:&UE
M;G1S.@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3=&5P(#$Z($-H86YG
M92!E86-H(&%T=&%C:&UE;G0G<R!D:7-P;W-I=&EO;B`M(&5I=&AE<B`F<75O
M=#MI;FQI;F4F<75O=#L@;W(@)G%U;W0[871T86-H;65N="9Q=6]T.R`M('1O
M('1H92!D97-I<F5D('9A;'5E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!3=&5P(#(Z($-L:6-K("9Q=6]T.U5P9&%T92!!='1A8VAM96YT($EN9F]R
M;6%T:6]N)G%U;W0[+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^0VAA;F=E
M($%T=&%C:&UE;G0@1&5S8W)I<'1I;VX\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1O(&-H86YG92!T:&4@9&5S8W)I<'1I;VX@9F]R('EO=7(@871T86-H
M;65N=',@*'1H92!T97AT('1H92!R96-I<&EE;G0@=VEL;"!S964@=&AA="!D
M97-C<FEB97,@=&AE(&%T=&%C:&UE;G0I.@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("!3=&5P(#$Z($5N=&5R(&$@9&5S8W)I<'1I;VX@:6YT;R!T:&4@
M1&5S8W)I<'1I;VX@9FEE;&0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M(%-T97`@,CH@0VQI8VL@)G%U;W0[57!D871E($%T=&%C:&UE;G0@26YF;W)M
M871I;VXF<75O=#LN"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60]
M(F-O;7!O<V4M<')I;W)I='DB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ(%!R:6]R:71Y/"]T:71L93X*("`@(#QH96%D:6YG/E!R:6]R:71Y
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES('-E=',@=&AE("9Q=6]T
M.U@M4')I;W)I='DF<75O=#L@:&5A9&5R(&]N('EO=7(@;W5T9V]I;F<@;65S
M<V%G92X@5&AE("9Q=6]T.U@M4')I;W)I='DF<75O=#L@=&%G(&ES(&$@<V]R
M="!O9B`F<75O=#MP<V5U9&\@<W1A;F1A<F0F<75O=#L@=&AA="!.971S8V%P
M92P@36]Z:6QL82P@3W!E<F$L(&%N9"!/=71L;V]K(&UA:6P@8VQI96YT<R!A
M<'!E87(@=&\@86=R964@;VXN($%N>2!M86EL(&-L:65N=',@=&AA="!D;R!N
M;W0@:&%N9&QE('1H:7,@:&5A9&5R('=I;&P@<VEM<&QY(&EG;F]R92!I="X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB8V]M<&]S92US879E
M+6%T=&%C:&UE;G1S(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N
M.B!3879E($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T
M97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y;W5R(&-O;7!O
M<VET:6]N(&%R92!S879E9"!W:71H('1H92!M97-S86=E('=H96X@<W1O<F5D
M(&EN('1H92!S96YT+6UA:6P@9F]L9&5R+B!)9B`F<75O=#M997,F<75O=#LL
M('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S879E9"X@268@)G%U;W0[
M3F\F<75O=#LL('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S=')I<'!E
M9"!F<F]M('1H92!M97-S86=E(&%F=&5R(&ET(&ES('-E;G0@=&\@86QL(')E
M8VEP:65N=',N($-H;V]S:6YG("9Q=6]T.TYO)G%U;W0[('=I;&P@:&5L<"!C
M;VYS97)V92!D:7-K('-P86-E(&)Y(')E;6]V:6YG("AP;W1E;G1I86QL>2!L
M87)G92D@871T86-H;65N="!I;F9O<FUA=&EO;B!F<F]M('1H92!S879E9"!M
M97-S86=E<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB8V]M
M<&]S92UL:6YK+6%T=&%C:&UE;G1S(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!,:6YK($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A
M/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y
M;W5R(&-O;7!O<VET:6]N(&%R92!S96YT(&%S(&$@<&%R="!O9B!T:&4@;6%I
M;"!M97-S86=E(&]R('=H971H97(@=&AO<V4@871T86-H;65N=',@87)E(&ME
M<'0@;VX@82!L;V-A;"!S97)V97(N("!)9B!A='1A8VAM96YT<R!A<F4@;&EN
M:V5D+"!T:&4@<F5C:7!I96YT*',I(&]F('EO=7(@;65S<V%G92!W:6QL(&)E
M('!R;W9I9&5D(&$@=V5B;&EN:R!W:&5R92!T:&5Y(&-A;B!D;W=N;&]A9"!T
M:&4@871T86-H;65N="AS*2X@($QI;FMI;F<@871T86-H;65N=',@:&%S('1H
M92!A9'9A;G1A9V4@;V8@=')E;65N9&]U<VQY(')E9'5C:6YG('1H92!S:7IE
M(&]F(&]U=&=O:6YG(&UE<W-A9V5S+B`@3&EN:VEN9R!A='1A8VAM96YT<R!H
M87,@=&AE(&1I<V%D=F%N=&%G92!T:&%T('1H92!C;VYT96YT(&]F('1H92!A
M='1A8VAM96YT<R!C86X@;F]T(&)E(&=U87)A;G1E960@=&\@8F4@879A:6QA
M8FQE(&EN('1H92!F=71U<F4@<VEN8V4@=&AE(&%T=&%C:&UE;G0@9&%T82!I
M<R!N;W0@;&]C871E9"!W:71H:6X@=&AE(&4M;6%I;"!M97-S86=E+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)S96%R8V@B/@H@("`@/'1I
M=&QE/DUE<W-A9V4@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG/E-E87)C
M:"!#<FET97)I83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA>2!S
M96%R8V@@9F]R(&UE<W-A9V5S(&9R;VT@>6]U<B!F;VQD97)S('5S:6YG(&1I
M9F9E<F5N="!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@("`@("!3=&5P(#$Z($5N=&5R('1E>'0@=&\@=&AE(&9I96QD<R!Y
M;W4@=V%N="!T;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@("`@("!3=&5P(#(Z($-H;V]S92!T:&4@
M;65S<V%G92!F;&%G*',I('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C<FET97)I
M82X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("`@(%-T97`@,SH@0VAO
M;W-E('1H92!F;VQD97(H<RD@9G)O;2!W:&EC:"!T;R!S96%R8V@@9F]R('1H
M92!M97-S86=E<RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("`@(%-T
M97`@-#H@0VQI8VL@)G%U;W0[4V5A<F-H)G%U;W0[+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!)9B!A;GD@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E
M87)C:"!C<FET97)I82P@=&AE;B!T:&4@<W5B:F5C=',@;V8@=&AE<V4@;65S
M<V%G97,@=VEL;"!B92!S:&]W;B!I;B!T:&4@)G%U;W0[4V5A<F-H(%)E<W5L
M=',F<75O=#L@=FEE=RX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I
M9#TB9F]L9&5R+6]P=&EO;G,B/@H@("`@/'1I=&QE/D9O;&1E<B!.879I9V%T
M;W(Z($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($%C=&EO
M;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@
M82!F;VQD97(@8GD@=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE
M(&QE9G0@8V]L=6UN+B!/;F-E('EO=2!H879E(&1O;F4@=&AI<RP@<V5L96-T
M('1H92!A8W1I;VX@>6]U('=I<V@@=&\@<&5R9F]R;2!O;B!T:&4@9F]L9&5R
M('9I82!T:&4@<V5L96-T(&)O>"!T;R!T:&4@;&5F="X*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@("!9;W4@;6%Y(&)E('!R;VUP=&5D(&9O<B!F=7)T
M:&5R(&]P=&EO;G,N($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO
M;BP@87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD
M97(@:68@>6]U(&1E;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^26UP;W)T($UE<W-A9V5S/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("`@(%1H:7,@;W!T:6]N('=I;&P@:6UP;W)T(&UB;W@@9F]R;6%T
M(&]R("YE;6P@9FEL97,@:6YT;R!T:&4@9F]L9&5R(&]F('EO=7(@8VAO:6-E
M+B!#:&]O<V4@;VYE(&9O;&1E<B!T;R!I;7!O<G0@=&AE(&UE<W-A9V5S(&EN
M=&\@86YD('1H96X@<V5L96-T('1H:7,@;W!T:6]N+B!9;W4@=VEL;"!T:&5N
M(&)E('1A:V5N('1O(&$@<&%G92!T:&%T('=I;&P@<')O;7!T(&9O<B!T:&4@
M;6)O>"!O<B`N96UL(&9I;&4@=&\@:6UP;W)T+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H*/&5N=')Y(&ED/2)F;VQD97(M=VED9V5T<R(^"B`@("`\=&ET;&4^
M1F]L9&5R($YA=FEG871O<CH@1&ES<&QA>3PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY3:&]W+TAI9&4@56YS=6)S8W)I8F5D/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!)9B!U<VEN9R!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS+"!S:&]W
M+VAI9&4@=&AE('5N<W5B<V-R:6)E9"!F;VQD97)S+B!4;R!S=6)S8W)I8F4O
M=6YS=6)S8W)I8F4@=&\@82!F;VQD97(L('-E;&5C="!T:&4@8VAE8VMB;W@@
M;F5X="!T;R!T:&4@9F]L9&5R;F%M92!A;F0@=7-E('1H92!3=6)S8W)I8F4O
M56YS=6)S8W)I8F4@86-T:6]N(&EN('1H92!&;VQD97(@06-T:6]N(&1R;W`M
M9&]W;B!M96YU+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^17AP86YD($%L
M;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17AP86YD(&%L;"!F;VQD97(@
M96YT<FEE<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D-O;&QA<'-E($%L
M;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0V]L;&%P<V4@86QL(&9O;&1E
M<B!E;G1R:65S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)F
M:6QT97)S(CX*("`@(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-L:6-K(&]N('1H92`F<75O=#M!<'!L>2!&:6QT97(F<75O
M=#L@:6-O;B!N97AT('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X
M('9I97<@=&\@9FEL=&5R(&%L;"!M97-S86=E<R!A8V-O<F1I;F<@=&\@=&AE
M('-P96-I9FEE9"!R=6QE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R
M>2!I9#TB9FEL=&5R+65D:70M<G5L97,B/@H@("`@/'1I=&QE/D9I;'1E<G,Z
M($5D:70@1FEL=&5R(%)U;&5S/"]T:71L93X*("`@(#QH96%D:6YG/D5D:70@
M66]U<B!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L
M:6-K(&]N("9Q=6]T.T5D:70@>6]U<B!F:6QT97(@<G5L97,F<75O=#L@=&\@
M<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E
M+"!A;F0@961I="!T:&4@8W5R<F5N=&QY(&%C=&EV92!S970@;V8@9FEL=&5R
M(')U;&5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)F:6QT
M97(M961I="UB;&%C:VQI<W0B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@
M0FQA8VML:7-T/"]T:71L93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!";&%C
M:VQI<W0\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N("9Q=6]T
M.T5D:70@>6]U<B!B;&%C:VQI<W0F<75O=#L@=&\@<')O8V5E9"!T;R!T:&4@
M<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E+"!A;F0@961I="!T:&4@
M;&ES="!O9B!E+6UA:6P@861D<F5S<V5S('EO=2!!3%=!65,@<F5F=7-E(&UA
M:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB9FEL
M=&5R+65D:70M=VAI=&5L:7-T(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET
M(%=H:71E;&ES=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@5VAI
M=&5L:7-T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`F<75O
M=#M%9&ET('EO=7(@=VAI=&5L:7-T)G%U;W0[('1O('!R;V-E960@=&\@=&AE
M('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@=&AE
M(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y;W4@04Q705E3(&%C8V5P="!M
M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](F9I
M;'1E<BUO;BUL;V=I;B(^"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&]N
M($QO9VEN/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE
M<R!5<&]N($QO9V]N/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@
M=&AI<R!O<'1I;VX@=&\@86QW87ES(&%P<&QY(&9I;'1E<G,@=VAE;B!F:7)S
M="!L;V=G:6YG(&]N=&\@24U0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N
M=')Y(&ED/2)F:6QT97(M;VXM9&ES<&QA>2(^"B`@("`\=&ET;&4^1FEL=&5R
M<SH@1FEL=&5R(&]N(%)E9G)E<V@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P
M;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N('1O
M(&%L=V%Y<R!A<'!L>2!F:6QT97)S('=H96YE=F5R('EO=7(@=FEE=R!T:&4@
M24Y"3U@_"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](F9I;'1E
M<BUA;GDM;6%I;&)O>"(^"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&%N
M>2!-86EL8F]X/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY(&9I;'1E<B!R
M=6QE<R!T;R!A;GD@;6%I;&)O>#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($-H96-K('1H:7,@;W!T:6]N(&EF('EO=2!W86YT('1O(&)E(&%L;&]W960@
M=&\@87!P;'D@9FEL=&5R(')U;&5S('1O(&%N>2!M86EL8F]X+B!.;W)M86QL
M>2P@9FEL=&5R:6YG(')U;&5S(&%R92!O;FQY(&%P<&QI960@=&\@;F5W(&UA
M:6P@=&AA="!I<R!D96QI=F5R960@=&\@>6]U<B!)3D)/6"X@268@=&AI<R!O
M<'1I;VX@:7,@8VAE8VME9"P@86X@:6-O;B!W:6QL(&%P<&5A<B!O;B!A;&P@
M;6%I;&)O>"!P86=G97,@=&AA="!W:6QL(&%L;&]W('EO=2!T;R!A<'!L>2!F
M:6QT97(@<G5L97,@=&\@=&AE(&UE<W-A9V5S(&EN('1H92!C=7)R96YT(&UA
M:6QB;W@N($Y/5$4Z($9I;'1E<FEN9R!I;B!M86EL8F]X97,@;W1H97(@=&AA
M;B!)3D)/6"!M87D@<')O9'5C92!S=')A;F=E("AE+F<N('1H92!F:6QT97(@
M;6%Y(&-A=7-E(&$@8V]P>2!O9B!M97-S86=E<R!T;R!B92!D96QI=F5R960@
M=&\@=&AE('-A;64@;6%I;&)O>"D@86YD+V]R('5N9&5S:7)E9"!R97-U;'1S
M("AE+F<N(&ET(&UA>2!C875S92!M97-S86=E<R!T;R!B92!M;W9E9"]D96QE
M=&5D(&EF(&YE=R!F:6QT97)I;F<@<G5L97,@:&%V92!B965N(&EM<&QE;65N
M=&5D('-I;F-E('1H92!M97-S86=E(&AA<R!B965N(&1E;&EV97)E9"!T;R!T
M:&4@8W5R<F5N="!M86EL8F]X*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE
M;G1R>2!I9#TB<&=P+6-O;7!O<V4M871T86-H+7!U8FME>2(^"B`@("`\=&ET
M;&4^4$=0.B!!='1A8V@@4'5B;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY!='1A8V@@4'5B;&EC($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M268@<V5L96-T960@=&AE;B!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME
M>2P@:68@:70@97AI<W1S+"!W:6QL(&)E(&%T=&%C:&5D('1O('1H92!O=71G
M;VEN9R!M97-S86=E+B!9;W4@8V%N('-E="!T:&4@9&5F875L="!B96AA=FEO
M<B!V:6$@=&AE(%!'4"!/<'1I;VYS('-C<F5E;BX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*"CQE;G1R>2!I9#TB<&=P+6]P=&EO;BUS8V%N+6)O9'DB/@H@("`@
M/'1I=&QE/E!'4#H@4V-A;B!497AT($)O9&EE<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY38V%N(%1E>'0@0F]D:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!)9B!S96QE8W1E9"!T:&5N($E-4"!W:6QL('-C86X@=&AE(&)O9'D@;V8@
M86QL('1E>'0@;65S<V%G97,@9F]R(%!'4"!D871A+"!A;F0@9&ES<&QA>2!T
M:&4@<F5S=6QT<R!I9B!A;GD@9&%T82!I<R!F;W5N9"X@3F]T92!T:&%T('1H
M:7,@;6%Y('-L;W<@9&]W;B!T:&4@<WES=&5M(&%S(&5V97)Y('1E>'0@;65S
M<V%G92!M=7-T(&)E('-C86YN960@:6X@:71S(&5N=&ER971Y(&9O<B!01U`@
M9&%T82X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB8V]M<&]S
M92UO<'1I;VYS+65N8W)Y<'0B/@H@("`@/'1I=&QE/D-O;7!O<V4Z($5N8W)Y
M<'1I;VX@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY.;R!%;F-R>7!T
M:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD('1H92!M97-S86=E
M('=I=&@@;F\@96YC<GEP=&EO;B`H8VQE87)T97AT*2X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/E!'4"!%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@96YC<GEP="!T:&4@8W5R
M<F5N="!M97-S86=E+"!U<VEN9R!01U`@86YD('1H92!R96-I<&EE;G1S('!E
M<G-O;F%L('!U8FQI8R!K97DL(&%N9"!T:&5N('-E;F0@:70N(%EO=2!C86X@
M;VYL>2!S96YD(&$@;65S<V%G92!T;R!A('-I;F=L92!P97)S;VX@=7-I;F<@
M=&AI<R!O<'1I;VXN(%EO=2!-55-4(&AA=F4@=&AE('!U8FQI8R!K97D@;V8@
M=&AE(')E8VEP:65N="!S=&]R960@:6X@>6]U<B!A9&1R97-S8F]O:R!O<B!E
M;'-E('1H:7,@;W!T:6]N('=I;&P@9F%I;"X@268@>6]U(&AA=F4@=&AE('!U
M8FQI8R!K97D@9F]R('1H92!R96-I<&EE;G0@:6X@>6]U<B!A9&1R97-S8F]O
M:R!A;F0@87)E('-T:6QL(')E8V5I=FEN9R!E<G)O<G,L('9E<FEF>2!T:&%T
M('1H92!E+6UA:6P@861D<F5S<R!I;B!T:&4@<F5C:7!I96YT(&9I96QD(&UA
M=&-H97,@=&AE(&4M;6%I;"!A9&1R97-S('=H97)E('1H92!P=6)L:6,@:V5Y
M(&ES('-T;W)E9"X@5&AE(&5N8W)Y<'1E9"!D871A('=I;&P@8F4@871T86-H
M960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY01U`@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!4:&ES(&]P=&EO;B!W:6QL(&1I9VET86QL>2!S:6=N('1H92!C=7)R
M96YT(&UE<W-A9V4@=7-I;F<@4$=0(&%N9"!Y;W5R('!E<G-O;F%L('!R:79A
M=&4@:V5Y+B!)9B!Y;W4@:&%V92!N;W0@86QR96%D>2!E;G1E<F5D('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R('!R:79A=&4@:V5Y(&1U<FEN9R!T:&ES('-E
M<W-I;VX@>6]U('=I;&P@8F4@<')O;7!T960@9F]R(&ET+B!4:&4@<F5C96EP
M:65N="!M=7-T(&AA=F4@82!C;W!Y(&]F('EO=7(@<'5B;&EC(&ME>2!T;R!D
M:6=I=&%L;'D@=F5R:69Y('EO=7(*("`@('-I9VYA='5R92X*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!F:7)S="!D
M:6=I=&%L;'D@<VEG;B!Y;W5R(&UE<W-A9V4@86YD('1H96X@=VEL;"!E;F-R
M>7!T('1H92!R97-U;'1I;F<@;W5T<'5T+B!3964@=&AE("9Q=6]T.U!'4"!%
M;F-R>7!T($UE<W-A9V4F<75O=#L@86YD("9Q=6]T.U!'4"!3:6=N($UE<W-A
M9V4F<75O=#L@96YT<FEE<R!F;W(@9G5R=&AE<B!I;F9O<FUA=&EO;BX*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-12!%;F-R>7!T($UE<W-A9V4\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E,O34E-12!3:6=N($UE<W-A9V4\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-
M12!3:6=N+T5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@5$]$3PH@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P9W`M
M;W9E<G9I97<B/@H@("`@/'1I=&QE/E!'4#H@3W9E<G9I97<\+W1I=&QE/@H@
M("`@/&AE861I;F<^5VAA="!I<R!01U`_/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!01U`@:7,@82!T;V]L(&9O<B!S96-U<F4@8V]M;75N:6-A=&EO;B!A
M;F0@9&%T82!S=&]R86=E+"!E<W!E8VEA;&QY(&9O<B!U<V4@=VET:"!E+6UA
M:6PN($ET(&-A;B!B92!U<V5D('1O(&5N8W)Y<'0@9&%T82!A;F0@=&\@8W)E
M871E(&1I9VET86P@<VEG;F%T=7)E<RX@24U0('5S97,@1VYU4$<@*$=.52!0
M<FEV86-Y($=U87)D*2!T;R!P<F]V:61E('1H:7,@9G5N8W1I;VYA;&ET>2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!01U`@9G5N8W1I;VYA
M;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@;W!T:6]N
M(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&-R96%T92]V:65W
M('EO=7(@<&5R<V]N86P@4$=0(&ME>7,L(&%D9"]D96QE=&4@<'5B;&EC(&ME
M>7,@9G)O;2!O=&AE<B!I;F1I=FED=6%L<RP@<F5A9"!E;F-R>7!T960@;6%I
M;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N8W)Y<'0O
M<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"@H\96YT<GD@:60](G!G<"UO<'1I;VXM871T86-H+7!U8FME>2(^"B`@("`\
M=&ET;&4^4$=0.B!/<'1I;VYS("T@071T86-H(%!U8FQI8R!+97D\+W1I=&QE
M/@H@("`@/&AE861I;F<^3W!T:6]N<R`M($%T=&%C:"!0=6)L:6,@2V5Y/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N(&$@8V]P
M>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L('=I;&P@
M8GD@9&5F875L="!B92!A='1A8VAE9"!T;R!A;&P@;W5T9V]I;F<@;65S<V%G
M97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](G!G<"UM86YA
M9V4M<'5B:V5Y(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!S8W)E96X@;&ES=',@86QL(&]F('1H92!C=7)R
M96YT('5S97)S(&EN('EO=7(@861D<F5S<V)O;VL@=&AA="!H879E(%!'4"!P
M=6)L:6,@:V5Y<RX@5&AE<V4@=7-E<G,@87)E('1H92!/3DQ9('5S97)S('1H
M870@>6]U(&-A;B!E:71H97(@,2D@<V5N9"!A;B!E;F-R>7!T960@;65S<V%G
M92!T;R`M3U(M(#(I('9E<FEF>2!A(&1I9VET86P@<VEG;F%T=7)E+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!U8FQI8R!K
M97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@
M=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M1&5L971E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&5S('1H92!P
M=6)L:6,@:V5Y(&9R;VT@>6]U<B!A9&1R97-S8F]O:RX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*"CQE;G1R>2!I9#TB<&=P+6EM<&]R="UP=6)K97DB/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES("T@26UP;W)T/"]T:71L
M93X*("`@(#QH96%D:6YG/DEM<&]R="!0=6)L:6,@2V5Y<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!O<&5N(&$@=VEN9&]W
M('=H97)E('EO=2!C86X@;6%N=6%L;'D@:6UP;W)T(&$@4$=0('!U8FQI8R!K
M97DN(%1H92!K97D@8V%N(&5I=&AE<B!B92!P87-T960@:6YT;R!A('1E>'1F
M:65L9"!O<BP@:68@=&AE(&ME>2!R97-I9&5S(&EN(&$@9FEL92!O;B!Y;W5R
M(&QO8V%L(&-O;7!U=&5R+"!Y;W4@8V%N(&EM<&]R="!I="X@268@=&AE(&ME
M>2!I<R!V86QI9"!I="!W:6QL(&)E(&EN<V5R=&5D(&EN=&\@>6]U<B!A9&1R
M97-S8F]O:R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L;W-E.R!I9B!N;W0@=F%L
M:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R971U<FYE9"!E>'!L86EN
M:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB<&=P
M+6]V97)V:65W+7!E<G-O;F%L:V5Y(CX*("`@(#QT:71L93Y01U`Z($UA;F%G
M92!097)S;VYA;"!+97ES/"]T:71L93X*("`@(#QH96%D:6YG/D]V97)V:65W
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V%N="!T;R!D:6=I
M=&%L;'D@<VEG;B!M97-S86=E<R!O<B!E;F%B;&4@;W1H97)S('1O('-E;F0@
M>6]U(&5N8W)Y<'1E9"!M97-S86=E<RP@>6]U(&UU<W0@:&%V92!Y;W5R(&]W
M;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!01U`@:V5Y<&%I<BX*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4'5B;&EC($ME>3PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@66]U<B!P=6)L:6,@:V5Y('-H;W5L9"!B92!M861E
M(&%V86EL86)L92!T;R!A;GD@<&5R<V]N('1H870@>6]U('=A;G0@=&\@8F4@
M86)L92!T;R!S96YD('EO=2!E;F-R>7!T960@;65S<V%G97,@=&AA="!O;FQY
M(%E/52!C86X@9&5C<GEP="`H=7-I;F<@>6]U<B!P<FEV871E(&ME>2DN($%D
M9&ET:6]N86QL>2P@>6]U<B!P=6)L:6,@:V5Y(&YE961S('1O(&)E(&UA9&4@
M879A:6QA8FQE('1O(&%N>6)O9'D@>6]U('-E;F0@82!D:6=I=&%L;'D@<VEG
M;F5D(&UE<W-A9V4@=&\@+2!T:&4@<'5B;&EC(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@=&AE(&1I9VET86P@<VEG;F%T=7)E+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^66]U<B!0<FEV871E($ME>3PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@66]U<B!P<FEV871E(&ME>2!I<R!N96-E<W-A<GD@=&\@9&5C
M<GEP="!A;GD@;65S<V%G92!E;F-R>7!T960@=7-I;F<@>6]U<B!P=6)L:6,@
M:V5Y+B!!9&1I=&EO;F%L;'DL('EO=7(@<')I=F%T92!K97D@:7,@;F5E9&5D
M(&EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&$@;65S<V%G92X@66]U
M<B!P<FEV871E(&ME>2!W:6QL(&)E('!R;W1E8W1E9"!V:6$@82!P87-S<&AR
M87-E(&-R96%T960@=VAE;B!T:&4@:V5Y<R!A<F4@9V5N97)A=&5D+B!4:'5S
M+"!T;R!P97)F;W)M(&%N>2!A8W1I=FET>2!T:&%T(')E<75I<F5S('EO=7(@
M<')I=F%T92!K97DL($E-4"!W:6QL('!R;VUP="!Y;W4@9F]R('EO=7(@<&%S
M<W!H<F%S92X@66]U(&]N;'D@;F5E9"!T;R!I;G-E<G0@>6]U<B!P87-S<&AR
M87-E(&]N8V4@<&5R('-E<W-I;VX@+2!)35`@=VEL;"!S=&]R92!Y;W5R('!A
M<W-P:')A<V4@=6YT:6P@>6]U(&QO9V]U="`H4V\@8F4@<W5R92!T;R!L;V=O
M=70A*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB<&=P+7!E
M<G-O;F%L:V5Y+7!U8FQI8R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R
M<V]N86P@2V5Y<R`M(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^
M5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@82!W:6YD;W<@
M=&\@=FEE=R!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$:7-P
M;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK
M97DM<')I=F%T92(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@
M2V5Y<R`M(%!R:79A=&4@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D5N=&5R
M(%!A<W-P:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS('1H
M92!P87-S<&AR87-E(&1I86QO9R!W:6YD;W<N(%1H92!P87-S<&AR87-E(&5N
M=&5R960L(&EF(&-O<G)E8W0L('=I;&P@8F4@<W1O<F5D(&)Y($E-4"!U;G1I
M;"!Y;W5R('-E<W-I;VX@96YD<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/E5N;&]A9"!087-S<&AR87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!2
M96UO=F5S('1H92!S=&]R960@<&%S<W!H<F%S92!F<F]M($E-4"`M(&%N>2!A
M9&1I=&EO;F%L('5S86=E(&]F('1H92!P<FEV871E(&ME>2!W:6QL(')E<75I
M<F4@>6]U('1O(')E96YT97(@=&AE('!A<W-P:&5A<V4N"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/
M<&5N<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@<')I=F%T92!K97DN($1/
M($Y/5"!314Y$(%1(25,@2T59(%1/($%.64].12`M('1H:7,@;W!T:6]N(&ES
M('-T<FEC=&QY('-O('1H870@>6]U(&-A;B!E>'!O<G0@>6]U<B!)35`@<&5R
M<V]N86P@<')I=F%T92!K97D@9F]R('5S92!I;B!A;F]T:&5R('!R;V=R86TN
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE
M(%!'4"!P<FEV871E(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R
M>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(^"B`@("`\=&ET;&4^4$=0
M.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M($1E;&5T93PO=&ET;&4^"B`@("`\
M:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@2V5Y<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!D96QE=&4@>6]U<B!P97)S;VYA
M;"!P=6)L:6,O<')I=F%T92!K97EP86ER(&9R;VT@24U0)W,@<')E9F5R96YC
M97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](G!G<"UP97)S
M;VYA;&ME>2UC<F5A=&4M;F%M92(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@
M4&5R<V]N86P@2V5Y("T@3F%M93PO=&ET;&4^"B`@("`\:&5A9&EN9SY.86UE
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@;F%M92!Y;W4@=V%N="!E
M;6)E9&1E9"!I;B!Y;W5R('!E<G-O;F%L(&ME>7,N($$@<F5Q=6ER960@9FEE
M;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](G!G<"UP97)S
M;VYA;&ME>2UC<F5A=&4M8V]M;65N="(^"B`@("`\=&ET;&4^4$=0.B!#<F5A
M=&4@4&5R<V]N86P@2V5Y("T@0V]M;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY#;VUM96YT/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!(&-O;6UE;G0@
M<W1R:6YG('EO=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@:V5Y
M<RX@06X@;W!T:6]N86P@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\
M96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M96UA:6PB/@H@("`@
M/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($4M;6%I;"!!9&1R
M97-S/"]T:71L93X*("`@(#QH96%D:6YG/D4M;6%I;"!!9&1R97-S/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@92UM86EL(&%D9')E<W,@>6]U('=A
M;G0@87-S;V-I871E9"!W:71H('EO=7(@<&5R<V]N86P@:V5Y<RX@02!R97%U
M:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB
M<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UK97EL96YG=&@B/@H@("`@/'1I=&QE
M/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($ME>6QE;F=T:#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY+97EL96YG=&@\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1H92!K97EL96YG=&@L(&EN(&)I="P@;V8@>6]U<B!G96YE<F%T960@
M:V5Y+B!4:&4@9W)E871E<B!T:&4@=F%L=64L('1H92!G<F5A=&5R('1H92!P
M<F]T96-T:6]N("AA;F0@86QS;R!G<F5A=&5R(&=E;F5R871I;VX@=&EM92!A
M;F0@96YC<GEP=&EO;B!T:6UE*2X@,3`R-"!B:70@:7,@=&AE(&1E9F%U;'0@
M+2!T:&ES('9A;'5E('!R;W9I9&5S(&5X8V5L;&5N="!P<F]T96-T:6]N+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK
M97DM8W)E871E+7!A<W-P:')A<V4B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E
M(%!E<G-O;F%L($ME>2`M(%!A<W-P:')A<V4\+W1I=&QE/@H@("`@/&AE861I
M;F<^4&%S<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE('!A
M<W-P:')A<V4@=7-E9"!T;R!P<F]T96-T+V5N8W)Y<'0@>6]U<B!P97)S;VYA
M;"!P<FEV871E(&ME>2X@5&AI<R!S:&]U;&0@8F4@050@3$5!4U0@-B!C:&%R
M86-T97)S+"!S:&]U;&0@3D]4(&)E('1H92!S86UE(&%S('EO=7(@;&]G:6X@
M<&%S<W=O<F0L('-H;W5L9"!.3U0@8F4@8F%S960@;VX@82!D:6-T:6]N87)Y
M('=O<F0L(&%N9"!S:&]U;&0@:6YC;'5D92!B;W1H(&YU;6)E<G,@86YD(&QE
M='1E<G,N(%EO=2!M=7-T(&5N=&5R('1H:7,@<&%S<W!H<F%S92!T=VEC92!F
M;W(@=F5R:69I8V%T:6]N('!U<G!O<V5S+B!!(')E<75I<F5D(&9I96QD+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK
M97DM8W)E871E+6%C=&EO;G,B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E
M<G-O;F%L($ME>2`M($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^0W)E
M871E($ME>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-R96%T92!A;F0@
M<W1O<F4@>6]U<B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^26UP;W)T($ME>7!A:7(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($EM<&]R="!A('!E<G-O;F%L+W!R:79A=&4@
M:V5Y<&%I<BX@5&AI<R!B=71T;VX@;W!E;G,@82!W:6YD;W<@=VAE<F4@>6]U
M(&-A;B!M86YU86QL>2!I;7!O<G0@>6]U<B!E>&ES=&EN9R!01U`@<&5R<V]N
M86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<BX@5&AE(&ME>7,@8V%N(&5I=&AE
M<B!B92!P87-T960@:6YT;R!A('1E>'1F:65L9"!O<BP@:68@=&AE(&ME>7,@
M<F5S:61E(&EN(&$@9FEL92!O;B!Y;W5R(&QO8V%L(&-O;7!U=&5R+"!Y;W4@
M8V%N(&EM<&]R="!T:&5M+B!)9B!T:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W
M:6QL(&)E(&EN<V5R=&5D(&EN=&\@>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE
M('=I;F1O=R!W:6QL(&-L;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE
M<W-A9V4@=VEL;"!B92!R971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<B/@H@
M("`@/'1I=&QE/E,O34E-13H@3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE861I
M;F<^5VAA="!I<R!3+TU)344_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3
M+TU)344@:7,@82!P<FEV871E+W!U8FQI8R!K97D@<&%I<B!S>7-T96T@=VAI
M8V@@<')O=FED97,@9&EG:71A;"!S:6=N871U<F5S+"!M97-S86=E('!R:79A
M8WDL(&%N9"!T86UP97(@9&5T96-T:6]N(&EN(&$@;W!E;BP@:6YT97)O<&5R
M86)L92!W87DN(%,O34E-12!C86X@<')O=FED92!M97-S86=E('!R:79A8WD@
M8GD@96YC<GEP=&EN9R!M97-S86=E<R!T:&%T(&]N;'D@=&AE('-E;F1E<B!A
M;F0@=&AE(&EN=&5N9&5D(')E8VEP:65N=',@8V%N(&1E8V]D92X@270@86QL
M;W=S('EO=2!T;R!I9&5N=&EF>2!T:&4@<V5N9&5R(&]F(&$@;65S<V%G92!V
M:6$@82!D:6=I=&%L('-I9VYA='5R92X@5&]G971H97(L('1H:7,@96YC<GEP
M=&EO;B!A;F0@9&EG:71A;"!S:6=N:6YG(&AE;'`@<')O=FED92!T86UP97(@
M9&5T96-T:6]N+"!A;&QO=VEN9R!R96-I<&EE;G1S('1O(&1E=&5R;6EN92!W
M:&5T:&5R(&$@;65S<V%G92!W87,@86QT97)E9"!A9G1E<B!I="!W87,@<V5N
M="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!3+TU)344@9G5N
M8W1I;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@
M;W!T:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&EM<&]R
M="!Y;W5R('!E<G-O;F%L(%,O34E-12!K97ES+"!R96%D(&5N8W)Y<'1E9"!M
M86EL+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@96YC<GEP
M="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*"CQE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<M<&5R<V]N86QK97DB/@H@
M("`@/'1I=&QE/E,O34E-13H@4&5R<V]N86P@2V5Y<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@;W(@96YC<GEP="!M97-S86=E
M<R!Y;W4@;75S="!H879E('EO=7(@;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV
M871E(%,O34E-12!K97EP86ER+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N
M=')Y(&ED/2)S;6EM92UI;7!O<G0M<&5R<V]N86PM8V5R=',B/@H@("`@/'1I
M=&QE/E,O34E-13H@26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!);7!O<G0@<&5R<V]N86P@8V5R
M=&EF:6-A=&5S(&9R;VT@82!02T-3(",Q,B!F;W)M870@9FEL92X@4$M#4R`C
M,3(@9FEL97,@:7,@=&AE(&9I;&4@=7-U86QL>2!G96YE<F%T960@=VAE;B!E
M>'!O<G1I;F<@82!K97D@9G)O;2!A(&)R;W=S97(@*&4N9RX@26YT97)N970@
M17AP;&]R97(L($9I<F5F;W@I(&]R(&9R;VT@82!C97)T:69I8V%T92!S=&]R
M92!M86EN=&%I;F5D(&)Y(&%N($]P97)A=&EN9R!3>7-T96T@*&4N9RX@5VEN
M9&]W<R!84"DN($EF('1H92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@
M:6YS97)T960@:6YT;R!Y;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W
M('=I;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W
M:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H*/&5N=')Y(&ED/2)S;6EM92UD96QE=&4M<&5R<V]N86PM8V5R
M=',B/@H@("`@/'1I=&QE/E,O34E-13H@1&5L971E(%!E<G-O;F%L($-E<G1I
M9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@
M0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&4@
M>6]U<B!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!Y;W5R('!R969E<F5N
M8V5S+B`@66]U('=I;&P@;F\@;&]N9V5R(&)E(&%B;&4@=&\@<VEG;B!3+TU)
M344@;65S<V%G97,@;W(@=FEE=R!A;GD@4R]-24U%(&5N8W)Y<'1E9"!M97-S
M86=E<R!A9&1R97-S960@=&\@>6]U+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*
M/&5N=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y(CX*("`@(#QT:71L93Y3
M+TU)344Z($UA;F%G92!0=6)L:6,@2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY3+TU)344Z($UA;F%G92!0=6)L:6,@2V5Y<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@36%N86=E('EO=7(@4R]-24U%('!U8FQI8R!K97D@;&ES="X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%9I97<@=&AE(')A=R!T97AT(&]F('1H92!P=6)L:6,@:V5Y
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5FEE=R!T96-H;FEC86P@9&5T86EL<R!O9B!T:&4@
M<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T:&4@<V5L96-T960@
M<'5B;&EC(&ME>2!F<F]M('-T;W)A9V4N("!$96QE=&EN9R!A('!U8FQI8R!K
M97D@9F]R(&$@=7-E<B!W:6QL('!R979E;G0@>6]U<B!F<F]M(&5N8W)Y<'1I
M;F<@82!M97-S86=E('1O('1H870@=7-E<BX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*"CQE;G1R>2!I9#TB<')I;G1I;F<B/@H@("`@/'1I=&QE/E!R:6YT:6YG
M/"]T:71L93X*("`@(#QH96%D:6YG/E!R:6YT(&$@;65S<V%G93PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5&\@<')I;G0@82!M97-S86=E('EO=2!A<F4@
M=FEE=VEN9RP@8VQI8VL@;VX@=&AE("9Q=6]T.U!R:6YT)G%U;W0[(&QI;FL@
M870@96ET:&5R('1H92!T;W`@;W(@8F]T=&]M(&]F('1H92!M97-S86=E+B!4
M:&4@;65S<V%G92!W:6QL(&]P96X@:6X@82!N97<@=VEN9&]W(&9O<FUA=&5D
M(&9O<B!P<FEN=&EN9RX@1&5P96YD:6YG(&]N('EO=7(@=V5B(&)R;W=S97(@
M86YD(&]P97)A=&EN9R!S>7-T96TL('1H92!P<FEN="!D:6%L;V<@8F]X(&UA
M>2!O<&5N(&9O<B!Y;W4N($EF(&ET(&1O97,@;F]T(&]P96XL('1H96X@<'5L
M;"!D;W=N('1H92!W96(@8G)O=W-E<B=S("9Q=6]T.T9I;&4F<75O=#L@;65N
M=2!A;F0@8VAO;W-E("9Q=6]T.U!R:6YT)G%U;W0[('1O(&]P96X@=&AE('!R
M:6YT(&1I86QO9R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@
M:60](G-O<G1I;F<B/@H@("`@/'1I=&QE/E-O<G1I;F<@86YD(%1H<F5A9&EN
M9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3;W)T:6YG($5N=')I97,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%=H96X@=FEE=VEN9R!A(&QI<W0@;V8@;65S
M<V%G97,L('EO=2!C86X@<V]R="!T:&4@;65S<V%G97,@8GD@86YY(&-O;'5M
M;B!B>2!C;&EC:VEN9R!O;B!T:&4@87!P<F]P<FEA=&4@8V]L=6UN(&AE861I
M;F<N(%1O('-W:71C:"!C;VQU;6YS(&)E='=E96X@87-C96YD:6YG(&%N9"!D
M97-C96YD:6YG(&]R9&5R+"!C;&EC:R!O;B!T:&4@87)R;W<@:6-O;B!I;B!T
M:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY4
M:')E861I;F<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1O(&=R;W5P(&UE
M<W-A9V5S(&)Y('1H<F5A9',@*'-U8FIE8W0I+"!S;R!E86-H(&UE<W-A9V4@
M:7,@9W)O=7!E9"!W:71H(&%L;"!I=',@<F5P;&EE<RP@8VQI8VL@=&AE(%M4
M:')E861=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L=6UN(&AE861I;F<N(%1O
M(')E='5R;B!T;R!N;W)M86P@<W5B:F5C="!S;W)T:6YG+"!C;&EC:R!O;B!T
M:&4@6U-U8FIE8W1=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L=6UN(&AE861I
M;F<N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](F%L=&5R;F%T
M:79E+6US9R(^"B`@("`\=&ET;&4^375L=&EP87)T+T%L=&5R;F%T:79E($UE
M<W-A9V5S/"]T:71L93X*("`@(#QP87)A/@H@("`@4V]M92!M97-S86=E(&AA
M=F4@8F5E;B!S96YT(&%S(&$@)G%U;W0[;75L=&EP87)T+V%L=&5R;F%T:79E
M)G%U;W0[('1Y<&4@8GD@=&AE('-E;F1E<BX@5&AE<V4@;65S<V%G97,@:&%V
M92!S979E<F%L('!A<G1S+"!A;&P@9&ES<&QA>6EN9R!T:&4@4T%-12!#3TY4
M14Y4(&)U="!I;B!$249&15)%3E0@1D]234%44RX@5&AE(&UA:6P@86=E;G0@
M=VEL;"!D:7-P;&%Y('1H92!L87-T('!A<G0@:6X@=&AE(&QI<W0@=&AA="!C
M86X@8F4@<W5C8V5S<V9U;&QY(&1I<W!L87EE9"!I;FQI;F4@:6X@=&AE(&)R
M;W=S97(L(&EF(&%N>2X@06QL(&]T:&5R(&9O<FUA=',@=VEL;"!A<'!E87(@
M=6YD97(@=&AE(&AE861I;F<@)G%U;W0[06QT97)N871I=F4@<&%R=',@9F]R
M('1H:7,@<V5C=&EO;B9Q=6]T.R!A;F0@8V%N(&)E('9I97=E9"!O<B!D;W=N
M;&]A9&5D('-E<&%R871E;'DN($ET(&ES(&EM<&]R=&%N="!T;R!N;W1E('1H
M870@=&AE<V4@86QT97)N871I=F4@<&%R=',@8V]N=&%I;B!T:&4@4T%-12!#
M3TY414Y44R!A<R!T:&4@<&%R="!T:&%T(&ES('-H;W=N("T@=&AE>2!A<F4@
M<VEM<&QY(&EN(&$@9&EF9F5R96YT(&UE9&EA(&9O<FUA="`H92YG+B!T97AT
M('9S+B!(5$U,(&]U='!U="DN"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT
M<GD@:60](G!R969S+7)E;F%M95]S96YT;6%I;%]M;VYT:&QY(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%)E;F%M92!396YT+6UA
M:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N
M('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(')E;F%M92!Y
M;W5R('-E;G0M;6%I;"!F;VQD97(@870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R
M>2!M;VYT:"X@5&AE(&9O;&1E<B!W:6QL(&)E(')E;F%M960@*'1O(&$@;F%M
M92!T:&%T(&-O;G1A:6YS('1H92!M;VYT:"!A;F0@>65A<BD@86YD(&$@;F5W
M('-E;G0M;6%I;"!F;VQD97(@=VEL;"!B92!C<F5A=&5D+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?
M;6]N=&AL>2(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!$96QE=&4@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@
M(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@
M;&EK92!T;R!D96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T('1H92!B
M96=I;FYI;F<@;V8@979E<GD@;6]N=&@N(%1H:7,@;6%Y(&)E('5S969U;"!I
M9B!Y;W4@:&%V92!A('%U;W1A+"!F;W(@97AA;7!L92X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*"CQE;G1R>2!I9#TB<')E9G,M9&5L971E7W-E;G1M86EL7VUO
M;G1H;'E?:V5E<"(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!$96QE=&4@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY("T@(R!O9B!&
M;VQD97)S('1O($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M87)E(&1E;&5T:6YG(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!E=F5R>2!M;VYT
M:"P@:&]W(&UA;GD@;6]N=&AS(&]F(&]L9"!F;VQD97)S(&1O('EO=2`@=V%N
M="!T;R!K965P/R`@06YY(&9O;&1E<G,@;VQD97(@=&AA;B!T:&ES(&UA;GD@
M;6]N=&AS('=I;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M"CQE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DB
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E
M($QI;FME9"!!='1A8VAM96YT<R!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A
M/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T
M;R!D96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!T:&4@8F5G:6YN
M:6YG(&]F(&5V97)Y(&UO;G1H+B!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U
M(&AA=F4@82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"@H\96YT<GD@:60](G!R969S+61E;&5T95]A='1A8VAM96YT<U]M;VYT
M:&QY7VME97`B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@1&5L971E($QI;FME9"!!='1A8VAM96YT<R!-;VYT:&QY("T@(R!O9B!-
M;VYT:',@=&\@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A
M<F4@9&5L971I;F<@;VQD(&QI;FME9"!A='1A8VAM96YT<R!E=F5R>2!M;VYT
M:"P@:&]W(&UA;GD@;6]N=&AS(&]F(&]L9"!A='1A8VAM96YT<R!D;R!Y;W4@
M('=A;G0@=&\@:V5E<#\@($%N>2!A='1A8VAM96YT<R!O;&1E<B!T:&%N('1H
M:7,@;6%N>2!M;VYT:',@=VEL;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:#PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($1O('EO=2!W86YT('1O('!U<F=E('EO
M=7(@=')A<V@@9F]L9&5R(&5V97)Y('-O(&]F=&5N+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]I;G1E<G9A
M;"(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G
M92!4<F%S:"!);G1E<G9A;#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO
M=2!A<F4@<'5R9VEN9R!Y;W5R('1R87-H(&9O;&1E<BP@:&]W(&]F=&5N('-H
M;W5L9"!I="!B92!P=7)G960_"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT
M<GD@:60](G!R969S+7!U<F=E7W1R87-H7VME97`B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@4'5R9V4@5')A<V@@2V5E<#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@<'5R9VEN9R!Y;W5R('1R
M87-H(&9O;&1E<BP@;65S<V%G92!O;&1E<B!T:&%N(&AO=R!M86YY(&1A>7,@
M<VAO=6QD(&)E('!U<F=E9#\*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R
M>2!I9#TB<')E9G,M871T<FEB7W1E>'0B/@H@("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@365S<V%G92!#;VUP;W-I=&EO;CH@071T<FEB=71I;VX@5&5X=#PO
M=&ET;&4^"B`@("`@/'!A<F$^"B`@("`@2&5R92!Y;W4@8V%N(&5N=&5R('1H
M92!P:')A<V4@=&AA="!Y;W4@=VES:"!T;R!A<'!E87(@8F5F;W)E(&%N>2!Q
M=6]T960@=&5X="!I;B!A(')E<&QY('1H870@>6]U('-E;F0N"B`@("`@/"]P
M87)A/@H@("`@(#QP87)A/@H@("`@(%EO=2!C86X@:6YC;'5D92!O;F4@;W(@
M;6]R92!S<&5C:6%L('!L86-E:&]L9&5R<R!T;R!I;G-E<G0@:6YF;W)M871I
M;VX@86)O=70@=&AE(&UE<W-A9V4@=&\@=VAI8V@@>6]U(&%R92!R97!L>6EN
M9RX@4&QA8V5H;VQD97)S(&-O;G-I<W0@;V8@82`F87!O<SLE)F%P;W,[(&9O
M;&QO=V5D(&)Y(&$@<VEN9VQE(&QE='1E<BX@5&AE(&9O;&QO=VEN9R!P;&%C
M96AO;&1E<G,@87)E(&%V86EL86)L93H*("`@("`\+W!A<F$^"@H@("`@(#QP
M87)A/B`E9B`Z(%1H92!S96YD97(F87!O<SMS(&YA;64@86YD(&5M86EL(&%D
M9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^("5A(#H@5&AE('-E;F1E<B9A<&]S
M.W,@96UA:6P@861D<F5S<SPO<&%R83X*("`@("`\<&%R83X@)7`@.B!4:&4@
M<V5N9&5R)F%P;W,[<R!N86UE/"]P87)A/@H@("`@(#QP87)A/B`E<B`Z(%1H
M92!F=6QL(%)&0R`R.#(R('-T>6QE(&1A=&4@86YD('1I;64@>F]N93PO<&%R
M83X*("`@("`\<&%R83X@)60@.B!4:&4@9&%T92!A<R!W=W<L(&1D(&UM;2!9
M65E9/"]P87)A/@H@("`@(#QP87)A/B`E>"`Z(%1H92!D871E(&EN('1H92!L
M;V-A;&4F87!O<SMS(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^("5C(#H@
M5&AE(&1A=&4@86YD('1I;64@:6X@=&AE(&QO8V%L929A<&]S.W,@9&5F875L
M=#PO<&%R83X*("`@("`\<&%R83X@)6T@.B!4:&4@365S<V%G92U)1#PO<&%R
M83X*("`@("`\<&%R83X@)7,@.B!4:&4@<W5B:F5C=#PO<&%R83X*("`@("`\
M<&%R83X@)6X@.B!!(&YE=R!L:6YE/"]P87)A/@H@("`@(#QP87)A/B`E)2`Z
M(%1H92`F87!O<SLE)F%P;W,[(&-H87)A8W1E<CPO<&%R83X*"CPO96YT<GD^
M"@H\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?<F5A9"(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E<75E<W0@4F5A9"!296-E:7!T
M<SPO=&ET;&4^"B`@("`\<&%R83X*("`@("9Q=6]T.U)E<75E<W0@82!296%D
M(%)E8V5I<'0F<75O=#L@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE
M;G1S(&]F('1H:7,@;65S<V%G92!T;R!N;W1I9GD@>6]U('=H96X@=&AI<R!M
M97-S86=E(&ES(&]P96YE9"!B>2!T:&4@<F5C:7!I96YT<RX@3F]T(&%L;"!C
M;&EE;G1S('-U<'!O<G0@+R!H;VYO<B!T:&ES+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S96YD7VUD;B(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%-E;F0@341./"]T:71L93X*("`@
M(#QP87)A/@H@("`@)G%U;W0[4V5N9"!A($U$3B9Q=6]T.R!S96YD<R!A($UE
M<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("AA;'-O(&MN;W=N(&%S
M(&$@<F5A9"!R96-E:7!T*2!W:&5N('EO=2!V:65W(&$@;65S<V%G92!I;B!W
M:&EC:"!T:&4@=7-E<B!H87,@<F5Q=65S=&5D('1H870@=&AE>2!R96-E:79E
M(&YO=&EF:6-A=&EO;B!T:&%T('EO=2!H879E(')E860@=&AE(&UE<W-A9V4N
M($EN(&UO<W0@8V%S97,L('1H:7,@=VEL;"!H87!P96X@875T;VUA=&EC86QL
M>2!W:71H;W5T('!R;VUP=&EN9R!Y;W4N($EN(&-E<G1A:6X@:7-O;&%T960@
M8V%S97,L('EO=2!M87D@:&%V92!T;R!M86YU86QL>2!D96-I9&4@=&\@<V5N
M9"!T:&4@;F]T:69I8V%T:6]N(&)Y(&-L:6-K:6YG(&]N(&$@;&EN:RX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I
M;VY?<F5Q=65S=%]D96QI=F5R>2(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M(%)E<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N/"]T:71L93X*("`@(#QP
M87)A/@H@("`@)G%U;W0[4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VXF
M<75O=#L@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@<V5R=F5R('1O(&YO=&EF>2!Y;W4@=VAE;B!I="!H87,@9&5L:79E<F5D
M('1H92!M97-S86=E('1O('1H92!R96-I<&EE;G0G<R!M86EL8F]X+B!)="!D
M;V5S;B=T(&UE86X@=&AE(&UE<W-A9V4@:&%S(&)E96X@<V5E;BP@:G5S="!T
M:&%T(&ET)W,@<VET=&EN9R!I;B!A(&UA:6QB;W@@<V]M97=H97)E+B!.;W0@
M86QL(&UA:6P@<V5R=F5R<R!S=7!P;W)T('1H:7,N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"@H\96YT<GD@:60](G!R969S+61E;&5T95]S<&%M7V%F=&5R7W)E
M<&]R="(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($1E;&5T92!3<&%M($%F
M=&5R(%)E<&]R=&EN9SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%EO=2!M87D@
M96QE8W0@=&\@9&\@;VYE(&]F('1H<F5E(&ET96US(&%F=&5R(')E<&]R=&EN
M9R!A(&UE<W-A9V4@87,@96ET:&5R('-P86T@;W(@:6YN;V-E;G0N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@($9I<G-T+"!Y;W4@8V%N(&1E8VED92!T
M;R!D;R!N;W1H:6YG("T@=&AE(&UE<W-A9V4@=VEL;"!B92!R97!O<G1E9"!A
M<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="!B=70@=VEL;"!O=&AE<G=I<V4@
M<F5M86EN('5N8VAA;F=E9"!I;B!Y;W5R(&UA:6QB;W@N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@(%-E8V]N9"P@:68@<F5P;W)T:6YG(&$@;65S<V%G
M92!A<R!S<&%M+"!Y;W4@8V%N(&EN<W1E860@:&%V92!T:&4@;65S<V%G92!B
M92!I;6UE9&EA=&5L>2!D96QE=&5D+B`@5&AI<R!S971T:6YG(&AA<R!N;R!E
M9F9E8W0@;VX@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I;FYO8V5N="X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@5&AI<F0L(&%F=&5R(')E<&]R=&EN
M9R!A(&UE<W-A9V4@87,@<W!A;2!T:&4@;65S<V%G92!W:6QL(&)E(&1E;&5T
M960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M;W9E9"!T;R!Y;W5R
M('-P86T@9F]L9&5R+B`@06QT97)N871I=F5L>2P@:68@<F5P;W)T:6YG(&$@
M;65S<V%G92!A<R!I;FYO8V5N="!T:&4@;65S<V%G92!W:6QL(&)E(&1E;&5T
M960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M;W9E9"!T;R!Y;W5R
M($E.0D]8+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F
M<RUH=&UL7VEM86=E7W)E<&QA8V5M96YT(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@2%1-3"!);6%G92!297!L86-E;65N=#PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($9O<B!(5$U,(&UE<W-A9V5S(&1I<W!L87EE9"!I;FQI;F4L('-H
M;W5L9"!A;&P@:6UA9V4@=&%G<R!B92!B;&]C:V5D('5N=&EL('EO=2!S<&5C
M:69I8V%L;'D@9&5C:61E('1O('9I97<@=&AO<V4@:6UA9V5S/R!.;W1E('1H
M870L(&EF('9I97=I;F<@86X@2%1-3"!A='1A8VAM96YT+"!T:&4@:6UA9V5S
M('=I;&P@86QW87ES(&)E(&1I<W!L87EE9"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*"CQE;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]A9&1R8F]O:R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P;&%C96UE;G0O
M061D<F5S<V)O;VL@4VAO=SPO=&ET;&4^"B`@("`\<&%R83X*("`@($EF(&)L
M;V-K:6YG(&EM86=E<R!F;W(@:6YL:6YE($A434P@;65S<V%G97,L('-H;W5L
M9"!W92!A=71O;6%T:6-A;&QY(&1I<W!L87D@=&AE;2!I;G-T96%D(&EF('1H
M92!S96YD97(@87!P96%R<R!I;B!Y;W5R(&%D9')E<W-B;V]K/PH@("`@/"]P
M87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUM86EL8F]X7W-T87)T
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;&)O>"!3=&%R="!086=E
M/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&EC:"!P86=E
M(&EN('1H92!M86EL8F]X('9I97<@=VEL;"!B92!D:7-P;&%Y960@=VAE;B!Y
M;W4@86-C97-S(&$@;6%I;&)O>"!F;W(@=&AE(&9I<G-T('1I;64N($YO=&4@
M=&AA="!T:&4@)G%U;W0[=6YS965N)G%U;W0[(&UE<W-A9V4@;W!T:6]N<R!D
M;R!N;W0@=V]R:R!W:71H('1H92`F<75O=#M4:')E860F<75O=#L@<V]R=&EN
M9R!O<'1I;VX@+2!I;G-T96%D+"!Y;W4@=VEL;"!B92!S96YT('1O('1H92!L
M87-T('!A9V4N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](G!R
M969S+7-A=F5?871T86-H;65N=',B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!3879E($%T=&%C:&UE;G1S(&]N(%-E;G0@365S<V%G97,\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!)9B!S879I;F<@82!C;VUP;W-E9"!M97-S86=E(&EN
M(&$@<V5N="UM86EL(&9O;&1E<BP@9&5T97)M:6YE(&EF(&%L;"!A='1A8VAM
M96YT(&1A=&$@:7,@<V%V960N(%1H92!F;VQL;W=I;F<@;W!T:6]N<R!A<F4@
M879A:6QA8FQE.@H@("`@/"]P87)A/@H*("`@(#QP87)A/BH@)G%U;W0[06QW
M87ES('-A=F4@871T86-H;65N=',F<75O=#L@+2!.159%4B!P<F]M<'0@=&\@
M<V%V92!A='1A8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C
M:&UE;G1S(&%R92!!3%=!65,@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A
M<F$^"B`@("`@/'!A<F$^*B`F<75O=#M0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453)G%U;W0[("T@04Q7
M05E3('!R;VUP="!T;R!S879E(&%T=&%C:&UE;G1S(&EN('1H92!C;VUP;W-E
M('-C<F5E;CL@=&AE(&1E9F%U;'0@:7,@=&\@<V%V92!A='1A8VAM96YT<RX\
M+W!A<F$^"B`@("`@/'!A<F$^*B`F<75O=#M0<F]M<'0@979E<GD@=&EM92!A
M;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\F<75O=#L@+2!!
M3%=!65,@<')O;7!T('1O('-A=F4@871T86-H;65N=',@:6X@=&AE(&-O;7!O
M<V4@<V-R965N.R!T:&4@9&5F875L="!I<R!T;R!N;W0@<V%V92!A='1A8VAM
M96YT<RX\+W!A<F$^"B`@("`@/'!A<F$^*B`F<75O=#M.979E<B!S879E(&%T
M=&%C:&UE;G1S)G%U;W0[("T@3D5615(@<')O;7!T('1O('-A=F4@871T86-H
M;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT<R!A<F4@
M3D5615(@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"CPO96YT<GD^
M"@H\96YT<GD@:60](G9I<G1U86Q?:6YB;W@B/@H@("`@/'1I=&QE/E9I<G1U
M86P@1F]L9&5R<SH@5FER='5A;"!);F)O>#PO=&ET;&4^"B`@("`\<&%R83X*
M("`@(%9I<G5T86P@26YB;W@@:7,@82!S879E9"!S96%R8V@@=&AA="!D;V5S
M(&%W87D@=VET:"!T:&4@;F5E9"!T;R!S96%R8V@@979E<GD@;6%I;&)O>"!F
M;W(@;65S<V%G97,@;6%R:V5D(&%S(&YE=RX@($EN<W1E860L(&%L;"!C=7)R
M96YT;'D@<W5B<V-R:6)E9"!M86EL8F]X97,@87)E('-E87)C:&5D(&9O<B!N
M97<@;65S<V%G97,@86YD('1H92!R97-U;'1S(&%R92!D:7-P;&%Y960@:6X@
M82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R
M>2!I9#TB=FER='5A;%]T<F%S:"(^"B`@("`\=&ET;&4^5FER='5A;"!&;VQD
M97)S.B!6:7)T=6%L(%1R87-H/"]T:71L93X*("`@(#QP87)A/@H@("`@5FER
M='5A;"!4<F%S:"!I<R!A('-A=F5D('-E87)C:"!T:&%T(&1O97,@87=A>2!W
M:71H('1H92!N965D(&9O<B!A('-E<&%R871E(%1R87-H(&9O;&1E<BX@($EN
M<W1E860@;V8@;6]V:6YG(&UE<W-A9V5S('1O(&$@8V5N=')A;&EZ960@=')A
M<V@@9F]L9&5R+"!M97-S86=E<R!A<F4@<VEM<&QY(&UA<FME9"!A<R!D96QE
M=&5D(&EN('1H92!C=7)R96YT(&9O;&1E<B!T:&5Y(&QI=F4@:6XN("!7:&5N
M("=S:&]W(&1E;&5T960@;65S<V%G97,G(&ES('1U<FYE9"!O9F8L('1H:7,@
M<F5S=6QT<R!I;B!T:&5S92!M97-S86=E<R!N;W0@87!P96%R:6YG(&EN(&$@
M;6%I;&)O>"!V:65W+B`@5VAE;B!A('5S97(@8VQI8VMS(&]N(%9I<G1U86P@
M5')A<V@L("IA;&PJ(&UA:6QB;WAE<R!A;&P@<V5A<F-H960@9F]R(&UE<W-A
M9V5S('1H870@87)E(&9L86=G960@9&5L971E9"!A;F0@=&AE<V4@;65S<V%G
M97,@87)E(&1I<W!L87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H*/"]H96QP/@H`````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O;&]C86QE+V5S7T53+P``````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8P`#`Q
M-S0T-``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O97-?15,O
M3$-?34534T%'15,O````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-C``,#(Q,C,Q`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+VQO8V%L92]E<U]%4R],0U]-15-304=%4R]I;7`N;6\`````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#<Q,#$P,0`Q,#0Q-S,V,C<V,``P,C(S-3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````WA($E0````"(
M"P``'````%Q<``!G#P``G+@````````X]@``"@```#GV```*````1/8```H`
M``!/]@``"@```%KV```.````9?8```\```!T]@``#0```(3V```(````DO8`
M``L```";]@``#````*?V```*````M/8```0```"_]@``!````,3V```8````
MR?8``!L```#B]@``+0```/[V```=````+/<``"0```!*]P``*0```&_W```9
M````F?<```$```"S]P``&0```+7W```F````S_<```P```#V]P``"P````/X
M```D````#_@``!X````T^```2````%/X```K````G/@``$0```#(^```)P``
M``WY```7````-?D```\```!-^0``"P```%WY```.````:?D```4```!X^0``
M*````'[Y```(````I_D```H```"P^0``%0```+OY```2````T?D``#(```#D
M^0``"P```!?Z```I````(_H``#(```!-^@``$````(#Z```6````D?H``!``
M``"H^@``)@```+GZ```I````X/H``"8````*^P``'````#'[``"%````3OL`
M``X```#4^P``"@```./[```-````[OL``"<```#\^P``(@```"3\```.````
M1_P``"(```!6_```&0```'G\```D````D_P``#<```"X_```$0```/#\```-
M`````OT```P````0_0``#0```!W]```&````*_T``!L````R_0``E````$[]
M```N````X_T``#<````2_@``!@```$K^```,````4?X``'P```!>_@``;```
M`-O^```<````2/\``!T```!E_P``"@```(/_```/````CO\``!@```">_P``
M#````+?_```;````Q/\``$4```#@_P``*````"8``0!!````3P`!`"0```"1
M``$`#@```+8``0`/````Q0`!``X```#5``$`#@```.0``0`(````\P`!``X`
M``#\``$`#@````L!`0`)````&@$!`"X````D`0$`&@```%,!`0`S````;@$!
M`%$```"B`0$`,@```/0!`0`X````)P(!`%0```!@`@$`40```+4"`0!:````
M!P,!`%<```!B`P$`-````+H#`0`)````[P,!``T```#Y`P$`!P````<$`0`*
M````#P0!``\````:!`$`!0```"H$`0`#````,`0!``8````T!`$`$0```#L$
M`0`(````300!``D```!6!`$`"0```&`$`0`=````:@0!``X```"(!`$`"```
M`)<$`0`*````H`0!`"4```"K!`$`(````-$$`0`3````\@0!`!`````&!0$`
M#P```!<%`0`/````)P4!``H````W!0$`!P```$(%`0`#````2@4!`!D```!.
M!0$`#P```&@%`0`4````>`4!``D```"-!0$`#0```)<%`0`2````I04!`!D`
M``"X!0$`'@```-(%`0`/````\04!``H````!!@$`#P````P&`0`(````'`8!
M``H````E!@$`)````#`&`0`7````508!`!0```!M!@$`%@```((&`0`2````
MF08!``@```"L!@$`'````+4&`0!.````T@8!`"T````A!P$`&0```$\'`0!@
M````:0<!`"@```#*!P$`'@```/,'`0`:````$@@!`"P````M"`$`(````%H(
M`0`R````>P@!``<```"N"`$`#````+8(`0`-````PP@!`%0```#1"`$`8P``
M`"8)`0`L````B@D!``X```"W"0$``P```,8)`0`+````R@D!``<```#6"0$`
M!P```-X)`0`%````Y@D!``4```#L"0$`"@```/()`0`#````_0D!`!<````!
M"@$`"@```!D*`0`/````)`H!``X````T"@$`3@```$,*`0!0````D@H!`$,`
M``#C"@$`0@```"<+`0`]````:@L!`!8```"H"P$`,````+\+`0`8````\`L!
M`",````)#`$`#@```"T,`0`4````/`P!`!<```!1#`$`%P```&D,`0`7````
M@0P!`!,```"9#`$`#P```*T,`0`C````O0P!``8```#A#`$`%P```.@,`0`.
M``````T!`%$````/#0$`'P```&$-`0`=````@0T!`#4```"?#0$`-0```-4-
M`0`'````"PX!``8````3#@$`"````!H.`0`/````(PX!``8````S#@$`"```
M`#H.`0`1````0PX!``H```!5#@$`$P```&`.`0`+````=`X!`!````"`#@$`
M%0```)$.`0`-````IPX!`!,```"U#@$`(P```,D.`0`O````[0X!`!4````=
M#P$`!P```#,/`0`0````.P\!``4```!,#P$`%0```%(/`0`1````:`\!``P`
M``!Z#P$`/P```(</`0`P````QP\!`$@```#X#P$`(0```$$0`0`[````8Q`!
M`#L```"?$`$`/````-L0`0`X````&!$!`"L```!1$0$`,````'T1`0`Q````
MKA$!`#L```#@$0$`.0```!P2`0`U````5A(!``D```",$@$`!P```)82`0`4
M````GA(!``P```"S$@$``P```,`2`0`%````Q!(!``D```#*$@$`$````-02
M`0`)````Y1(!`!,```#O$@$``P````,3`0`Y````!Q,!`!(```!!$P$`#```
M`%03`0`U````81,!``X```"7$P$`20```*83`0`S````\!,!``H````D%`$`
M%@```"\4`0`6````1A0!`"T```!=%`$`"P```(L4`0`G````EQ0!`"P```"_
M%`$`*@```.P4`0`E````%Q4!``D````]%0$`"0```$<5`0`*````414!``8`
M``!<%0$`"0```&,5`0`'````;14!`"\```!U%0$`-P```*45`0`N````W14!
M`%4````,%@$`+0```&(6`0`L````D!8!`"T```"]%@$`/0```.L6`0`_````
M*1<!`"T```!I%P$`0````)<7`0`C````V!<!`",```#\%P$`0````"`8`0`M
M````81@!`#,```"/&`$`)0```,,8`0`5````Z1@!`!D```#_&`$`*0```!D9
M`0`D````0QD!`"@```!H&0$`4````)$9`0`8````XAD!`!$```#[&0$`$0``
M``T:`0`*````'QH!``P````J&@$`"P```#<:`0`*````0QH!`",```!.&@$`
M%@```'(:`0`*````B1H!`!````"4&@$`%@```*4:`0`6````O!H!`!L```#3
M&@$`+@```.\:`0`0````'AL!``<````O&P$`!P```#<;`0`4````/QL!``H`
M``!4&P$`"````%\;`0`G````:!L!``@```"0&P$``P```)D;`0`'````G1L!
M``<```"E&P$`!@```*T;`0`X````M!L!``4```#M&P$`!P```/,;`0`&````
M^QL!``@````"'`$`"0````L<`0`I````%1P!``X````_'`$`"@```$X<`0!%
M````61P!``0```"?'`$`!````*0<`0`'````J1P!``D```"Q'`$`!@```+L<
M`0`1````PAP!``<```#4'`$`%@```-P<`0`$````\QP!`"<```#X'`$`"```
M`"`=`0`&````*1T!``T````P'0$`!@```#X=`0`>````11T!`!$```!D'0$`
M"````'8=`0`-````?QT!``P```"-'0$`!P```)H=`0`#````HAT!`$8```"F
M'0$``P```.T=`0`7````\1T!`!,````)'@$`"````!T>`0`=````)AX!``@`
M``!$'@$`!````$T>`0`(````4AX!``@```!;'@$`*@```&0>`0`K````CQX!
M`%,```"['@$`00````\?`0`:````41\!`"L```!L'P$`(````)@?`0`5````
MN1\!``8```#/'P$`!@```-8?`0`.````W1\!`!4```#L'P$`/@````(@`0`8
M````02`!`"(```!:(`$`+@```'T@`0`=````K"`!`"$```#*(`$`5````.P@
M`0`I````02$!``H```!K(0$`!P```'8A`0`'````?B$!`!4```"&(0$`#@``
M`)PA`0`"````JR$!``H```"N(0$`#P```+DA`0`-````R2$!``\```#7(0$`
M#0```.<A`0`)````]2$!`!0```#_(0$`!@```!0B`0`8````&R(!`!T````T
M(@$`$P```%(B`0`1````9B(!`!0```!X(@$`3P```(TB`0`$````W2(!``P`
M``#B(@$`!@```.\B`0`*````]B(!``T````!(P$`%`````\C`0!B````)",!
M`"<```"'(P$`5````*\C`0!?````!"0!`&0```!D)`$`!````,DD`0`6````
MSB0!``X```#E)`$`'````/0D`0`/````$24!`#,````A)0$`*````%4E`0`%
M````?B4!``4```"$)0$`&P```(HE`0`:````IB4!``X```#!)0$`$P```-`E
M`0`5````Y"4!`#````#Z)0$`$0```"LF`0`1````/28!`!P```!/)@$`*@``
M`&PF`0`U````ER8!`$4```#-)@$`$````!,G`0`A````)"<!``4```!&)P$`
M$P```$PG`0`+````8"<!`!(```!L)P$`"@```'\G`0`/````BB<!``T```":
M)P$`1P```*@G`0`?````\"<!`"4````0*`$`,P```#8H`0`K````:B@!`#4`
M``"6*`$`0@```,PH`0`=````#RD!`%$````M*0$`$0```'\I`0`Q````D2D!
M`#L```##*0$`$P```/\I`0!`````$RH!`#@```!4*@$`!0```(TJ`0`,````
MDRH!`!$```"@*@$`#0```+(J`0`&````P"H!``P```#'*@$`!@```-0J`0`7
M````VRH!``@```#S*@$`#````/PJ`0`4````"2L!``\````>*P$`$````"XK
M`0`1````/RL!``@```!1*P$`!0```%HK`0`1````8"L!``P```!R*P$`$```
M`'\K`0`%````D"L!``T```"6*P$`!@```*0K`0`'````JRL!``T```"S*P$`
M!P```,$K`0`+````R2L!``<```#5*P$`!P```-TK`0`)````Y2L!`!<```#O
M*P$`)@````<L`0!/````+BP!``D```!^+`$`"0```(@L`0`*````DBP!`!D`
M``"=+`$`/0```+<L`0`=````]2P!``P````3+0$`)0```"`M`0`?````1BT!
M`!````!F+0$`!0```'<M`0`E````?2T!`"(```"C+0$`$@```,8M`0`3````
MV2T!`"L```#M+0$`.P```!DN`0`@````52X!`!L```!V+@$`"````)(N`0`V
M````FRX!`"$```#2+@$`$````/0N`0`(````!2\!`!L````.+P$`'@```"HO
M`0`O````22\!`%P```!Y+P$`+@```-8O`0`,````!3`!``8````2,`$`!```
M`!DP`0`/````'C`!``X````N,`$`#@```#TP`0`'````3#`!``X```!4,`$`
M!P```&,P`0`*````:S`!``T```!V,`$`'P```(0P`0`<````I#`!`"$```#!
M,`$`'@```.,P`0`9`````C$!`!X````<,0$`&P```#LQ`0`L````5S$!`"$`
M``"$,0$`+@```*8Q`0`F````U3$!`"0```#\,0$`'````"$R`0`>````/C(!
M`!P```!=,@$`)@```'HR`0`V````H3(!`"L```#8,@$`,P````0S`0`I````
M.#,!`$$```!B,P$`.@```*0S`0`F````WS,!`"L````&-`$`.````#(T`0`=
M````:S0!`!4```")-`$`+P```)\T`0`@````SS0!`!(```#P-`$`*0````,U
M`0`>````+34!`#T```!,-0$`(````(HU`0`2````JS4!`*(```"^-0$`%@``
M`&$V`0`C````>#8!`"@```"<-@$`*0```,4V`0`Z````[S8!`"@````J-P$`
M'P```%,W`0`5````<S<!`"````")-P$`)0```*HW`0`H````T#<!`"T```#Y
M-P$`,````"<X`0"2````6#@!`"$```#K.`$`%@````TY`0`<````)#D!`"8`
M``!!.0$`*@```&@Y`0!!````DSD!`$0```#5.0$`#````!HZ`0`'````)SH!
M``<````O.@$`!@```#<Z`0`-````/CH!``L```!,.@$`%````%@Z`0`-````
M;3H!`!@```![.@$`&@```)0Z`0`0````KSH!`!T```#`.@$`&0```-XZ`0!=
M````^#H!`!4```!6.P$`)0```&P[`0`2````DCL!`!,```"E.P$`$@```+D[
M`0`'````S#L!``0```#4.P$`$````-D[`0`0````ZCL!``P```#[.P$`#@``
M``@\`0`-````%SP!``\````E/`$`%````#4\`0`3````2CP!``T```!>/`$`
M.0```&P\`0`<````ICP!`"@```##/`$``P```.P\`0`-````\#P!``8```#^
M/`$`$0````4]`0`7````%ST!`!L````O/0$`#@```$L]`0`"````6CT!`$D`
M``!=/0$`!0```*<]`0`%````K3T!`!````"S/0$`#P```,0]`0`$````U#T!
M``T```#9/0$`#@```.<]`0`#````]CT!``X```#Z/0$`"`````D^`0`/````
M$CX!``@````B/@$`"@```"L^`0`/````-CX!``<```!&/@$`#0```$X^`0`0
M````7#X!`!0```!M/@$`#0```((^`0`9````D#X!`!H```"J/@$`"P```,4^
M`0`)````T3X!``8```#;/@$`%````.(^`0`+````]SX!`!,````#/P$`$```
M`!<_`0`,````*#\!``H````U/P$`$0```$`_`0`7````4C\!`!$```!J/P$`
M%0```'P_`0`G````DC\!`!D```"Z/P$`"P```-0_`0`-````X#\!`"(```#N
M/P$`*P```!%``0`7````/4`!``\```!50`$`-````&5``0`S````FD`!`!L`
M``#.0`$`-````.I``0`*````'T$!`!@````J00$`%````$-!`0`2````6$$!
M`!D```!K00$`%@```(5!`0`'````G$$!`!````"D00$`(@```+5!`0`<````
MV$$!`!P```#U00$`#0```!)"`0`'````($(!``P````H0@$`)@```#5"`0`*
M````7$(!`!0```!G0@$`"P```'Q"`0`'````B$(!`"(```"00@$`+P```+-"
M`0`+````XT(!``D```#O0@$`&0```/E"`0`+````$T,!`"H````?0P$`#P``
M`$I#`0`7````6D,!`!<```!R0P$`"0```(I#`0`'````E$,!`!8```"<0P$`
M#P```+-#`0`M````PT,!`!D```#Q0P$`%@````M$`0`.````(D0!`!H````Q
M1`$`*````$Q$`0`M````=40!`"X```"C1`$`"P```-)$`0`8````WD0!``@`
M``#W1`$`#`````!%`0`C````#44!``T````Q10$`)@```#]%`0`J````9D4!
M`"````"110$`0P```+)%`0`(````]D4!`!(```#_10$`'P```!)&`0`$````
M,D8!``@````W1@$`"P```$!&`0`:````3$8!`"<```!G1@$`$@```(]&`0`@
M````HD8!`"\```##1@$`%P```/-&`0`%````"T<!``P````11P$`#@```!Y'
M`0`.````+4<!``4````\1P$`!@```$)'`0`.````24<!`$4```!81P$``P``
M`)Y'`0`#````HD<!`"L```"F1P$`!P```-)'`0`$````VD<!``X```#?1P$`
M"@```.Y'`0`,````^4<!``H````&2`$`#P```!%(`0`0````(4@!`!<````R
M2`$`$0```$I(`0`3````7$@!`"4```!P2`$`#@```)9(`0`1````I4@!`!D`
M``"W2`$`%P```-%(`0`3````Z4@!`!8```#]2`$`.````!1)`0`3````34D!
M``D```!A20$`!0```&M)`0`+````<4D!``H```!]20$``@```(A)`0`%````
MBTD!``T```"120$`&P```)])`0`7````NTD!`!0```#320$`"0```.A)`0`=
M````\DD!`"\````02@$`#P```$!*`0`6````4$H!`!(```!G2@$`"P```'I*
M`0`,````ADH!``X```"32@$`#0```*)*`0`2````L$H!`!D```##2@$`'```
M`-U*`0`X````^DH!`!@````S2P$`(````$Q+`0`3````;4L!``D```"!2P$`
M`P```(M+`0`5````CTL!``L```"E2P$`$P```+%+`0`(````Q4L!``X```#.
M2P$`$````-U+`0![````[DL!`!@```!J3`$`&````(-,`0`G````G$P!`"D`
M``#$3`$`+````.Y,`0`H````&TT!``X```!$30$`-0```%--`0`1````B4T!
M``<```";30$`!0```*--`0`I````J4T!`!@```#330$`'@```.Q-`0`;````
M"TX!`!D````G3@$`&````$%.`0`;````6DX!`!D```!V3@$`$P```)!.`0`'
M````I$X!``@```"L3@$`!@```+5.`0`&````O$X!`!L```##3@$`$````-].
M`0`/````\$X!`!``````3P$`#P```!%/`0`+````(4\!``\````M3P$`#```
M`#U/`0`/````2D\!``<```!:3P$`!@```&)/`0`*````:4\!`!(```!T3P$`
M#0```(=/`0`,````E4\!``X```"B3P$`0P```+%/`0`]````]4\!``D````S
M4`$`#````#U0`0`H````2E`!``\```!S4`$`"````(-0`0`(````C%`!`!,`
M``"54`$`"P```*E0`0`>````M5`!`"$```#44`$`(````/90`0`9````%U$!
M`!<````Q40$`)0```$E1`0`7````;U$!`!8```"'40$`!````)Y1`0`;````
MHU$!``T```"_40$`#````,U1`0`#````VE$!``4```#>40$`"````.11`0`*
M````[5$!``P```#X40$`"@````52`0`@````$%(!`!\````Q4@$`&P```%%2
M`0`9````;5(!``L```"'4@$`&P```)-2`0`+````KU(!`!````"[4@$`"```
M`,Q2`0`,````U5(!``X```#B4@$`"P```/%2`0`$````_5(!``0````"4P$`
M$P````=3`0`4````&U,!``P````P4P$`"0```#U3`0`.````1U,!``L```!6
M4P$`&P```&)3`0`.````?E,!``\```"-4P$`)0```)U3`0`J````PU,!``<`
M``#N4P$`$@```/93`0`;````"50!``0````E5`$`!P```"I4`0`*````,E0!
M`!(````]5`$`"@```%!4`0`-````6U0!``D```!I5`$`!````'-4`0`%````
M>%0!``@```!^5`$``P```(=4`0`8````BU0!`!T```"D5`$`$````,)4`0`.
M````TU0!`!X```#B5`$`&@````%5`0`*````'%4!``0````G50$`)@```"Q5
M`0`.````4U4!`'P```!B50$`%0```-]5`0!$````]54!``4````Z5@$`!P``
M`$!6`0`,````2%8!``@```!55@$`"@```%Y6`0`&````:58!``<```!P5@$`
M"````'A6`0`1````@58!`!D```"35@$`"````*U6`0`"````ME8!``8```"Y
M5@$`!@```,!6`0`4````QU8!`!H```#<5@$`#0```/=6`0`0````!5<!`!L`
M```65P$`!0```#)7`0`$````.%<!``P````]5P$`"0```$I7`0`0````5%<!
M``D```!E5P$`"0```&]7`0`$````>5<!``4```!^5P$`&@```(17`0`%````
MGU<!`!H```"E5P$`"````,!7`0`&````R5<!``\```#05P$`&0```.!7`0`.
M````^E<!``<````)6`$`!P```!%8`0`B````&5@!``4````\6`$`"0```$)8
M`0`*````3%@!``X```!76`$``@```&98`0`-````:5@!`"````!W6`$`!@``
M`)A8`0`+````GU@!``T```"K6`$`#````+E8`0`)````QE@!``8```#06`$`
M$@```-=8`0`)````ZE@!``<```#T6`$`%````/Q8`0`=````$5D!`$(````O
M60$`)0```')9`0`E````F%D!``8```"^60$`"@```,59`0`$````T%D!``D`
M``#560$`"````-]9`0`1````Z%D!``D```#Z60$`!@````1:`0`-````"UH!
M``8````96@$`!````"!:`0`$````)5H!`!<````J6@$`.0```$):`0`]````
M?%H!`#H```"Z6@$`'@```/5:`0`%````%%L!``X````:6P$`!````"E;`0`&
M````+EL!``<````U6P$`(0```#U;`0`-````7UL!`!4```!M6P$`!@```(-;
M`0`$````BEL!`!$```"/6P$`!@```*%;`0`*````J%L!`"(```"S6P$`)P``
M`-9;`0`&````_EL!`!4````%7`$`#````!M<`0`1````*%P!``0````Z7`$`
M#0```#]<`0`'````35P!``4```!57`$`'0```%M<`0`$````>5P!``P```!^
M7`$`#@```(M<`0`*````FEP!``@```"E7`$`"0```*Y<`0`%````N%P!`#H`
M``"^7`$`,````/E<`0`U````*ET!`"D```!@70$`1P```(I=`0`X````TET!
M`"D````+7@$`/P```#5>`0`N````=5X!`"T```"D7@$`'P```-)>`0`/````
M\EX!`!(````"7P$`"P```!5?`0`F````(5\!`"<```!(7P$`*0```'!?`0`D
M````FE\!`"8```"_7P$`*````.9?`0`(````#V`!``H````88`$`"0```"-@
M`0`'````+6`!``0````U8`$`'````#I@`0`W````5V`!`"````"/8`$`(```
M`+!@`0`F````T6`!``T```#X8`$`)P````9A`0`;````+F$!`"(```!*80$`
M#````&UA`0`6````>F$!``H```"180$`&0```)QA`0`I````MF$!`!8```#@
M80$`$@```/=A`0`'````"F(!``H````28@$`#````!UB`0`/````*F(!`!``
M```Z8@$`0````$MB`0!$````C&(!`#P```#18@$`<`````YC`0!F````?V,!
M``8```#F8P$`"@```.UC`0`%````^&,!``X```#^8P$`"0````UD`0`*````
M%V0!`!(````B9`$`$P```#5D`0`,````260!``8```!69`$`!@```%UD`0`*
M````9&0!``X```!O9`$`#P```'YD`0`.````CF0!`!L```"=9`$`'P```+ED
M`0`>````V60!`",```#X9`$`$0```!QE`0`5````+F4!`!@```!$90$`$0``
M`%UE`0`0````;V4!`",```"`90$`#P```*1E`0`)````M&4!`!(```"^90$`
M'0```-%E`0`2````[V4!`!`````"9@$`"@```!-F`0`1````'F8!``4````P
M9@$`,0```#9F`0`D````:&8!`!P```"-9@$`(P```*IF`0!J````SF8!``\`
M```Y9P$`!0```$EG`0`0````3V<!``D```!@9P$`!````&IG`0`+````;V<!
M`"````![9P$`'````)QG`0`C````N6<!`"(```#=9P$`!@````!H`0`4````
M!V@!`!<````<:`$`#````#1H`0`D````06@!`",```!F:`$`&@```(IH`0`,
M````I6@!``\```"R:`$`%0```,)H`0`I````V&@!`"H````":0$`)@```"UI
M`0`G````5&D!`"D```!\:0$`*@```*9I`0`9````T6D!`$(```#K:0$`$0``
M`"YJ`0`2````0&H!`!,```!3:@$`%````&=J`0`/````?&H!`!8```",:@$`
M%P```*-J`0`0````NVH!`!$```#,:@$`-````-YJ`0`3````$VL!`!(````G
M:P$`-0```#IK`0`4````<&L!``<```"%:P$`#````(UK`0`K````FFL!``\`
M``#&:P$`%@```-9K`0`@````[6L!`!`````.;`$`%````!]L`0`1````-&P!
M`"@```!&;`$`%P```&]L`0`<````AVP!`!,```"D;`$`"P```+AL`0`4````
MQ&P!`!H```#9;`$`$0```/1L`0`:````!FT!`!X````A;0$`&@```$!M`0`3
M````6VT!`"$```!O;0$`(````)%M`0`5````LFT!`!$```#(;0$`%P```-IM
M`0`4````\FT!`!<````';@$`%0```!]N`0`)````-6X!``8````_;@$`$```
M`$9N`0`9````5VX!``0```!Q;@$`!P```'9N`0`+````?FX!`!$```"*;@$`
M!@```)QN`0`&````HVX!``8```"J;@$`!0```+%N`0`'````MVX!``<```"_
M;@$`!0```,=N`0`6````S6X!``8```#D;@$`!@```.MN`0`$````\FX!``0`
M``#W;@$`!P```/QN`0`.````!&\!``P````3;P$`#````"!O`0`-````+6\!
M``(````[;P$`"@```#YO`0`.````26\!``4```!8;P$`*````%YO`0`.````
MAV\!``P```"6;P$`#P```*-O`0`*````LV\!``@```"^;P$`"0```,=O`0`K
M````T6\!`$\```#];P$`1P```$UP`0!3````E7`!`"X```#I<`$`!````!AQ
M`0`(````'7$!`"8````F<0$`$@```$UQ`0`/````8'$!``8```!P<0$`"@``
M`'=Q`0`'````@G$!``@```"*<0$`(````)-Q`0`)````M'$!`!$```"^<0$`
M"0```-!Q`0`4````VG$!``P```#O<0$`#0```/QQ`0`.````"G(!`!8````9
M<@$`$0```#!R`0`&````0G(!``,```!)<@$`!@```$UR`0`9````5'(!``<`
M``!N<@$`!````'9R`0`+````>W(!``L```"'<@$`!P```)-R`0`%````FW(!
M``<```"A<@$`%@```*ER`0`-````P'(!``T```#.<@$`"@```-QR`0`0````
MYW(!``\```#X<@$`$0````AS`0`7````&G,!``H````R<P$`$0```#US`0`(
M````3W,!``0```!8<P$`$0```%US`0`/````;W,!`#H```!_<P$`(0```+IS
M`0`%````W',!`!<```#B<P$`#````/IS`0`>````!W0!``X````F=`$`$```
M`#5T`0`+````1G0!`'P```!2=`$`#````,]T`0`)````W'0!``<```#F=`$`
M"@```.YT`0`)````^70!``X````#=0$`$````!)U`0`5````(W4!`!L````Y
M=0$`&````%5U`0`:````;G4!``H```")=0$`"0```)1U`0`*````GG4!``X`
M``"I=0$`#````+AU`0`/````Q74!``@```#5=0$`!@```-YU`0`,````Y74!
M`!P```#R=0$`!P````]V`0`%````%W8!``L````==@$`1P```"EV`0`-````
M<78!``D```!_=@$`!````(EV`0`#````CG8!``P```"2=@$`$P```)]V`0`3
M````LW8!`!,```#'=@$`!@```-MV`0`*````XG8!``(```#M=@$`!````/!V
M`0`E````]78!``,````;=P$`!0```!]W`0`J````)7<!``X```!0=P$`"@``
M`%]W`0`%````:G<!``0```!P=P$`"@```'5W`0`-````@'<!`!\```".=P$`
M!P```*YW`0`B````MG<!``T```#9=P$`!@```.=W`0`(````[G<!``@```#W
M=P$`!`````!X`0`%````!7@!`&@````+>`$`"0```'1X`0`,````?G@!`!``
M``"+>`$`!0```)QX`0`&````HG@!`",```"I>`$`)0```,UX`0`(````\W@!
M`#<```#\>`$`(@```#1Y`0`3````5WD!`!L```!K>0$`+P```(=Y`0`0````
MMWD!``H```#(>0$`$0```--Y`0`/````Y7D!``\```#U>0$`"@````5Z`0`)
M````$'H!`!,````:>@$`&P```"YZ`0`8````2GH!`!<```!C>@$`%P```'MZ
M`0`9````DWH!`!\```"M>@$`#@```,UZ`0`F````W'H!`"8````#>P$``P``
M`"I[`0`'````+GL!``@````V>P$`!P```#][`0`0````1WL!``H```!8>P$`
M"P```&-[`0`'````;WL!`!,```!W>P$`#````(M[`0`/````F'L!``X```"H
M>P$`#````+=[`0`.````Q'L!`%$```#3>P$`#P```"5\`0`0````-7P!``T`
M``!&?`$`#P```%1\`0`/````9'P!`!<```!T?`$`%````(Q\`0`1````H7P!
M``\```"S?`$`(````,-\`0`N````Y'P!`!H````3?0$`#````"Y]`0`F````
M.WT!``L```!B?0$`#0```&Y]`0`:````?'T!`$H```"7?0$`&0```.)]`0`&
M````_'T!`!H````#?@$`)0```!Y^`0`&````1'X!``8```!+?@$`'P```%)^
M`0`&````<GX!``D```!Y?@$`&````(-^`0`7````G'X!`"@```"T?@$`!@``
M`-U^`0`-````Y'X!`"(```#R?@$`5P```!5_`0`3````;7\!`",```"!?P$`
M$P```*5_`0`"````N7\!``L```"\?P$`"````,A_`0`-````T7\!``8```#?
M?P$`"@```.9_`0`'````\7\!`!0```#Y?P$`!@````Z``0`(````%8`!``X`
M```>@`$`!P```"V``0`*````-8`!``L```!`@`$`,@```$R``0`K````?X`!
M``<```"K@`$`#````+.``0`-````P(`!``P```#.@`$`!````-N``0`)````
MX(`!``D```#J@`$`"@```/2``0`'````_X`!``D````'@0$`0````!&!`0`.
M````4H$!``<```!A@0$`"@```&F!`0`;````=($!``\```"0@0$`%0```*"!
M`0`5````MH$!`!(```#,@0$`"@```-^!`0`6````ZH$!``D````!@@$`$```
M``N"`0`'````'((!`!(````D@@$`!````#>"`0`$````/((!``0```!!@@$`
M(0```$:"`0`'````:((!``4```!P@@$`#````':"`0`%````@X(!``L```")
M@@$`%````)6"`0`1````JH(!`!H```"\@@$`%@```->"`0`4````[H(!`!<`
M```#@P$`&````!N#`0`<````-(,!`!D```!1@P$`!P```&N#`0`%````<X,!
M`!8```!Y@P$``P```)"#`0`-````E(,!``P```"B@P$`"@```*^#`0`(````
MNH,!``L```##@P$`$0```,^#`0`(````X8,!`!<```#J@P$`"P````*$`0`,
M````#H0!``P````;A`$`'P```"B$`0`:````2(0!`!,```!CA`$`!````'>$
M`0`*````?(0!``0```"'A`$`#0```(R$`0`,````FH0!``D```"GA`$`#```
M`+&$`0`%````OH0!``D```#$A`$`!0```,Z$`0`'````U(0!``4```#<A`$`
M!````.*$`0`"````YX0!`!0```#JA`$`#0```/^$`0`2````#84!``L````@
MA0$`&P```"R%`0`?````2(4!``\```!HA0$`%````'B%`0`>````C84!`!4`
M``"LA0$`.````,*%`0`L````^X4!`!(````HA@$`*0```#N&`0`R````988!
M``H```"8A@$`+````*.&`0`N````T(8!`#,```#_A@$`,P```#.'`0`X````
M9X<!``\```"@AP$`&````+"'`0`O````R8<!`!````#YAP$`$P````J(`0`J
M````'H@!`!D```!)B`$`'````&.(`0`?````@(@!``\```"@B`$`$P```+"(
M`0`5````Q(@!`!0```#:B`$`%````.^(`0`4````!(D!`"`````9B0$`$@``
M`#J)`0`4````38D!`!4```!BB0$`+0```'B)`0`M````IHD!`#$```#4B0$`
M+@````:*`0`O````-8H!`"P```!EB@$`8@```)**`0`3````]8H!`"4````)
MBP$`)````"^+`0`I````5(L!`$@```!^BP$`#0```,>+`0`(````U8L!`!<`
M``#>BP$`"````/:+`0`D````_XL!`!(````DC`$`#````#>,`0`.````1(P!
M`#<```!3C`$`*P```(N,`0`2````MXP!`"$```#*C`$`&@```.R,`0`)````
M!XT!`$4````1C0$`00```%>-`0`/````F8T!``0```"IC0$`$P```*Z-`0`4
M````PHT!``X```#7C0$`!@```.:-`0`3````[8T!`!@````!C@$`!@```!J.
M`0`)````(8X!``H````KC@$`"P```#:.`0`)````0HX!``T```!,C@$`#```
M`%J.`0`/````9XX!`!<```!WC@$`%````(^.`0`0````I(X!`!8```"UC@$`
M!P```,R.`0`.````U(X!`"$```#CC@$`!0````6/`0`'````"X\!`!L````3
MCP$`*@```"^/`0`(````6H\!``8```!CCP$`%````&J/`0`1````?X\!`$0`
M``"1CP$`/````-:/`0`.````$Y`!`#@````BD`$``@```%N0`0`"````7I`!
M``8```!AD`$`#@```&B0`0`%````=Y`!``<```!]D`$`#@```(60`0`&````
ME)`!`"@```";D`$`#````,20`0`,````T9`!`!P```#>D`$`(P```/N0`0`$
M````'Y$!`"D````DD0$`,@```$Z1`0`7````@9$!`!\```"9D0$`,P```+F1
M`0!<````[9$!``P```!*D@$`%````%>2`0`^````;)(!``T```"KD@$`'P``
M`+F2`0`0````V9(!`!0```#JD@$`!P```/^2`0`.````!Y,!``P````6DP$`
M#````".3`0`3````,),!``H```!$DP$`'0```$^3`0`9````;9,!``4```"'
MDP$`$0```(V3`0`3````GY,!``T```"SDP$`#P```,&3`0`1````T9,!`"0`
M``#CDP$`$@````B4`0`#````&Y0!`!4````?E`$`$P```#64`0`2````290!
M``L```!<E`$`-````&B4`0`+````G90!`!0```"IE`$`/@```+Z4`0`.````
M_90!`!,````,E0$`-````""5`0`Q````594!`!(```"'E0$`$````)J5`0`8
M````JY4!`!D```#$E0$`(P```-Z5`0`B`````I8!`"<````EE@$`5@```$V6
M`0!-````I)8!`+D```#RE@$`"````*R7`0`)````M9<!``T```"_EP$`!P``
M`,V7`0`*````U9<!``<```#@EP$`#P```.B7`0`&````^)<!``L```#_EP$`
M!`````N8`0`<````$)@!``T````MF`$`)P```#N8`0`;````8Y@!``P```!_
MF`$`&@```(R8`0`*````IY@!``<```"RF`$`#0```+J8`0`B````R)@!`"$`
M``#KF`$`"`````V9`0`%````%ID!`!\````<F0$`!@```#R9`0`0````0YD!
M``@```!4F0$`!P```%V9`0`-````99D!``H```!SF0$`$@```'Z9`0`A````
MD9D!``L```"SF0$`&P```+^9`0`8````VYD!``@```#TF0$`'@```/V9`0`2
M````')H!`"P````OF@$`&@```%R:`0`)````=YH!``H```"!F@$`%0```(R:
M`0`%````HIH!`!0```"HF@$`!````+V:`0`0````PIH!``8```#3F@$`!P``
M`-J:`0`>````XIH!`"@````!FP$`"@```"J;`0`<````-9L!`!$```!2FP$`
M"P```&2;`0`:````<)L!`"P```"+FP$`"````+B;`0`4````P9L!`"P```#6
MFP$`)P````.<`0`K````*YP!`"H```!7G`$`!````(*<`0`$````AYP!``L`
M``",G`$`!0```)B<`0`&````GIP!``@```"EG`$`!@```*Z<`0`Q````M9P!
M`!P```#GG`$`"@````2=`0"B````#YT!`!L```"RG0$`-````,Z=`0`T````
M`YX!`"`````XG@$`*0```%F>`0`G````@YX!`"````"KG@$`00```,R>`0`:
M````#I\!`"@````IGP$`&@```%*?`0!V````;9\!`'D```#DGP$`'`$``%Z@
M`0`H````>Z$!`!T```"DH0$`*0```,*A`0`=````[*$!`%`````*H@$`+@``
M`%NB`0`V````BJ(!`"P```#!H@$`,0```.ZB`0`N````(*,!`"(```!/HP$`
M!@```'*C`0`(````>:,!``4```""HP$`"````(BC`0`9````D:,!`!D```"K
MHP$`*@```,6C`0`0````\*,!`"L````!I`$`(P```"VD`0`9````4:0!`"$`
M``!KI`$`+@```(VD`0`T````O*0!``@```#QI`$`%P```/JD`0`*````$J4!
M``<````=I0$`(0```"6E`0`0````1Z4!``T```!8I0$`$````&:E`0`%````
M=Z4!``X```!]I0$`"````(RE`0`+````E:4!`!0```"AI0$`!P```+:E`0`3
M````OJ4!``@```#2I0$`-@```-NE`0`W````$J8!``L```!*I@$`"0```%:F
M`0`*````8*8!`!0```!KI@$`#P```("F`0`O````D*8!`#(```#`I@$`"P``
M`/.F`0`.````_Z8!``T````.IP$`#P```!RG`0`6````+*<!``X```!#IP$`
M/@```%*G`0`G````D:<!`"8```"YIP$`)````."G`0`%````!:@!``4````+
MJ`$`!0```!&H`0`G````%Z@!`!\````_J`$`%@```%^H`0`+````=J@!`!<`
M``""J`$`#P```)JH`0`$````JJ@!``H```"OJ`$`"0```+JH`0`+````Q*@!
M``T```#0J`$`#````-ZH`0`.````ZZ@!``4```#ZJ`$`!`````"I`0`-````
M!:D!`#(````3J0$`10```$:I`0`3````C*D!``L```"@J0$`#@```*RI`0`.
M````NZD!``D```#*J0$`"````-2I`0`0````W:D!`!4```#NJ0$`$P````2J
M`0`7````&*H!``<````PJ@$`'@```#BJ`0`5````5ZH!`!0```!MJ@$`!0``
M`(*J`0`4````B*H!``8```"=J@$`"P```*2J`0`'````L*H!`",```"XJ@$`
M%@```-RJ`0`/````\ZH!``X````#JP$`*@```!*K`0`&````/:L!``P```!$
MJP$`&````%&K`0`-````:JL!`!$```!XJP$`"P```(JK`0`V````EJL!``T`
M``#-JP$`"@```-NK`0`B````YJL!``L````)K`$`#P```!6L`0`0````):P!
M`"X````VK`$`.@```&6L`0`.````H*P!``T```"OK`$`!0```+VL`0`+````
MPZP!``P```#/K`$`#0```-RL`0`-````ZJP!``X```#XK`$`#0````>M`0`@
M````%:T!`"<````VK0$`*P```%ZM`0`(````BJT!``H```"3K0$`!@```)ZM
M`0`2````I:T!``X```"XK0$`%P```,>M`0`R````WZT!`!8````2K@$`'```
M`"FN`0`E````1JX!`#````!LK@$`,0```)VN`0`M````SZX!``X```#]K@$`
M%`````RO`0`%````(:\!``X````GKP$`$P```#:O`0`:````2J\!`!(```!E
MKP$`!P```'BO`0`&````@*\!`!,```"'KP$`'P```)NO`0`4````NZ\!`!$`
M``#0KP$`2P```.*O`0`3````+K`!``<```!"L`$`%````$JP`0`8````7[`!
M``<```!XL`$`!0```("P`0`,````AK`!``P```"3L`$`$@```*"P`0`$````
ML[`!``<```"XL`$`"@```,"P`0`+````R[`!``P```#7L`$`#@```.2P`0`.
M````\[`!``4````"L0$`!0````BQ`0`N````#K$!`"8````]L0$`(P```&2Q
M`0`#````B+$!`!(```",L0$`!@```)^Q`0`&````IK$!`!X```"ML0$`%@``
M`,RQ`0`8````X[$!``X```#\L0$`-P````NR`0`.````0[(!`!<```!2L@$`
M00```&JR`0`T````K+(!`"4```#AL@$`%0````>S`0`Q````';,!`!,```!/
MLP$`&P```&.S`0`J````?[,!`%$```"JLP$`60```/RS`0!0````5K0!`+\`
M``"GM`$`)0```&>U`0`-````C;4!``0```";M0$`"0```*"U`0`?````JK4!
M``,```#*M0$`!P```,ZU`0`*````UK4!``@```#AM0$``@```.JU`0`0````
M[;4!``@```#^M0$`#`````>V`0`5````%+8!``L````JM@$`&0```#:V`0`@
M````4+8!`!(```!QM@$`!0```(2V`0`*````BK8!`!4```"5M@$`$@```*NV
M`0`,````OK8!``0```#+M@$`"0```-"V`0`'````VK8!`#(```#BM@$`"@``
M`!6W`0`*````(+<!`!4````KMP$`#````$&W`0`/````3K<!``L```!>MP$`
M!P```&JW`0`6````<K<!`%(```")MP$`.@```-RW`0`@````%[@!``\````X
MN`$`%P```$BX`0`D````8+@!`#D```"%N`$`$@```+^X`0`'````TK@!``8`
M``#:N`$`"0```.&X`0`.````Z[@!``X```#ZN`$`#@````FY`0`$````&+D!
M``8````=N0$`%@```"2Y`0`,````.[D!``T```!(N0$`#@```%:Y`0`5````
M9;D!`!(```![N0$`#P```(ZY`0`4````GKD!`!0```"SN0$`0P```,BY`0`*
M````#+H!`!L````7N@$`-0```#.Z`0`1````:;H!`!````![N@$`"P```(RZ
M`0!I````F+H!`!H````"NP$`%P```!V[`0`H````-;L!`"<```!>NP$`&P``
M`(:[`0`:````HKL!`!<```"]NP$`&P```-6[`0`9````\;L!`!\````+O`$`
M%P```"N\`0`<````0[P!`!<```!@O`$`#````'B\`0`3````A;P!``@```"9
MO`$`'P```**\`0`O````PKP!``<```#RO`$`"````/J\`0`0`````[T!`!$`
M```4O0$`"0```":]`0`5````,+T!``T```!&O0$`!@```%2]`0`=````6[T!
M`",```!YO0$`!P```)V]`0`-````I;T!`!,```"SO0$`"````,>]`0`#````
MT+T!`$8```#4O0$`0P```!N^`0`R````7[X!`#\```"2O@$`-P```-*^`0!7
M````"K\!``4```!BOP$`'P```&B_`0`O````B+\!``H```"XOP$`#0```,._
M`0`2````T;\!`"D```#DOP$`"`````[``0`-````%\`!`"T````EP`$`<```
M`%/``0`_````Q,`!`#D````$P0$`1@```#[!`0`$````A<$!`!````"*P0$`
M$````)O!`0`,````K,$!`!0```"YP0$`'0```,[!`0`<````[,$!`!$````)
MP@$`/0```!O"`0!/````6<(!`"4```"IP@$`(````,_"`0`<````\,(!``L`
M```-PP$`)P```!G#`0`:````0<,!`!\```!<PP$`'0```'S#`0`H````FL,!
M``\```##PP$`)0```-/#`0`@````^<,!`"0````:Q`$`)````#_$`0`@````
M9,0!`"4```"%Q`$`"P```*O$`0`'````M\0!``T```"_Q`$`#````,W$`0`7
M````VL0!``4```#RQ`$`!@```/C$`0`Y````_\0!``4````YQ0$`#````#_%
M`0`'````3,4!``D```!4Q0$`$P```%[%`0`&````<L4!``D```!YQ0$`!```
M`(/%`0`0````B,4!``@```"9Q0$`"````*+%`0`$````J\4!``L```"PQ0$`
M#````+S%`0`2````R<4!`!$```#<Q0$`#````.[%`0`:````^\4!``\````6
MQ@$`!P```";&`0`-````+L8!``\````\Q@$`#````$S&`0`4````6<8!`!0`
M``!NQ@$`#P```(/&`0`.````D\8!`!(```"BQ@$`%````+7&`0`.````RL8!
M``P```#9Q@$`&P```.;&`0`L`````L<!`!,````OQP$`'````$/'`0`H````
M8,<!``8```")QP$`!P```)#'`0`3````F,<!``4```"LQP$`!````++'`0`,
M````M\<!`!<```#$QP$`$@```-S'`0`I````[\<!``L````9R`$`#0```"7(
M`0`4````,\@!`"\```!(R`$`"@```'C(`0`,````@\@!``D```"0R`$`!@``
M`)K(`0`)````H<@!``@```"KR`$`"0```+3(`0`%````OL@!``H```#$R`$`
M$0```,_(`0`*````X<@!`!````#LR`$`$````/W(`0`+````#LD!``8````:
MR0$`#@```"')`0`.````,,D!``T````_R0$`"P```$W)`0`0````6<D!`!T`
M``!JR0$`$0```(C)`0`+````FLD!``(```"FR0$`"````*G)`0`<````LLD!
M``<```#/R0$`#0```-?)`0`&````Y<D!`&0```#LR0$`%@```%'*`0`)````
M:,H!``<```!RR@$`)@```'K*`0`X````H<H!`!H```#:R@$`*@```/7*`0`[
M````(,L!`"@```!<RP$`-````(7+`0`9````NLL!`!4```#4RP$`!0```.K+
M`0`+````\,L!``<```#\RP$`"`````3,`0`'````#<P!``4````5S`$`!P``
M`!O,`0`.````(\P!``D````RS`$`!@```#S,`0`(````0\P!``L```!,S`$`
M!P```%C,`0`(````8,P!``<```!IS`$`%@```'',`0`)````B,P!``8```"2
MS`$`&0```)G,`0`:````L\P!`"````#.S`$`"P```._,`0`0````^\P!``8`
M```,S0$`'````!/-`0`4````,,T!``<```!%S0$`$0```$W-`0`(````7\T!
M``X```!HS0$`"````'?-`0`%````@,T!`!````"&S0$`"0```)?-`0`0````
MH<T!``8```"RS0$`&0```+G-`0`*````T\T!`!P```#>S0$`!P```/O-`0`%
M`````\X!``4````)S@$`$`````_.`0`4````(,X!``L````US@$`#0```$'.
M`0`H````3\X!`!@```!XS@$`%P```)'.`0`+````J<X!`!H```"US@$`%```
M`-#.`0`O````Y<X!``0````5SP$`"0```!K/`0`*````),\!``<````OSP$`
M`@```#?/`0`.````.L\!``@```!)SP$`(P```%+/`0`Q````=L\!`!\```"H
MSP$`.````,C/`0!X`````=`!`"8```!ZT`$`&P```*'0`0`Q````O=`!`#$`
M``#OT`$`)P```"'1`0`B````2=$!`"````!LT0$`9````(W1`0`=````\M$!
M`!0````0T@$`'````"72`0!5````0M(!`#@```"8T@$`+0```-'2`0`S````
M_](!`$L````STP$`2@```'_3`0!;````RM,!`"@````FU`$`+````$_4`0`X
M````?-0!`"4```"UU`$`(0```-O4`0`H````_=0!`"P````FU0$`)@```%/5
M`0`;````>M4!`!X```"6U0$`=0```+75`0`^````*]8!`$(```!JU@$`/0``
M`*W6`0`]````Z]8!`"D````IUP$`*0```%/7`0`Q````?=<!`#X```"OUP$`
M+P```.[7`0"I`0``'M@!`",```#(V0$`8@```.S9`0!/````3]H!`!<```"?
MV@$`2````+?:`0`V`````-L!`#X````WVP$`,````';;`0`@````I]L!`#\`
M``#(VP$`-`````C<`0`L````/=P!`!T```!JW`$`'@```(C<`0`J````I]P!
M`(4```#2W`$`,````%C=`0`E````B=T!`$$```"OW0$`6P```/'=`0!)````
M3=X!`#$```"7W@$`-````,G>`0`\````_MX!`#@````[WP$`'0```'3?`0`8
M````DM\!`*<```"KWP$`*P```%/@`0`A````?^`!`!\```"AX`$`/````,'@
M`0`D````_N`!`"@````CX0$`*P```$SA`0`B````>.$!`"8```";X0$`(P``
M`,+A`0`E````YN$!`"4````,X@$`*0```#+B`0`G````7.(!`!<```"$X@$`
M*0```)SB`0`@````QN(!`#(```#GX@$`'````!KC`0`N````-^,!`#H```!F
MXP$`'0```*'C`0`1````O^,!`#,```#1XP$`)0````7D`0`X````*^0!`"<`
M``!DY`$`(````(SD`0`\````K>0!`"8```#JY`$`'P```!'E`0`P````,>4!
M`&D```!BY0$`+@```,SE`0`Q````^^4!`$$````MY@$`/@```&_F`0`S````
MKN8!`"4```#BY@$`/0````CG`0!E````1N<!`$T```"LYP$`4P```/KG`0!7
M````3N@!`%4```"FZ`$`1@```/SH`0`J````0^D!`"\```!NZ0$`50```)[I
M`0`@````].D!`"X````5Z@$`*P```$3J`0`P````<.H!`"H```"AZ@$`/@``
M`,SJ`0!4````"^L!`%(```!@ZP$`6@```+/K`0`R````#NP!`"L```!![`$`
M2````&WL`0!*````MNP!`"H````![0$`)@```"SM`0`L````4^T!`$X```"`
M[0$`,@```,_M`0`P`````NX!`!T````S[@$`(P```%'N`0`O````=>X!`"P`
M``"E[@$`+0```-+N`0!Q`````.\!`&8```!R[P$`;P```-GO`0"S````2?`!
M`!<```#]\`$`)0```!7Q`0`R````._$!`"D```!N\0$`/@```)CQ`0`B````
MU_$!`%(```#Z\0$`)0```$WR`0`+````<_(!`+$```!_\@$`.P```#'S`0`G
M````;?,!`$X```"5\P$`1P```.3S`0!B````+/0!`$D```"/]`$`50```-GT
M`0!`````+_4!`"\```!P]0$`,@```*#U`0`K````T_4!`"D```#_]0$`#P``
M`"GV`0!%````.?8!`"$```!_]@$`,````*'V`0`M````TO8!`"4`````]P$`
M'````";W`0`Q````0_<!`#$```!U]P$`#@```*?W`0`+````MO<!``<```#"
M]P$`!P```,KW`0`$````TO<!``T```#7]P$`"P```.7W`0`.````\?<!``L`
M````^`$`!0````SX`0`0````$O@!``(````C^`$`"@```";X`0!6````,?@!
M`%D```"(^`$`3@```.+X`0`%````,?D!`!(````W^0$`!````$KY`0`'````
M3_D!``@```!7^0$`!0```&#Y`0`#````9OD!`!````!J^0$`%P```'OY`0`,
M````D_D!``P```"@^0$`#0```*WY`0`3````N_D!``T```#/^0$``@```-WY
M`0`'````X/D!``8```#H^0$`%````._Y`0`,````!/H!`!@````1^@$`!@``
M`"KZ`0`2````,?H!``P```!$^@$``P```%'Z`0`J````5?H!``0```"`^@$`
M!@```(7Z`0`'````C/H!`!\```"4^@$`-0```+3Z`0`N````ZOH!`"\````9
M^P$`%P```$G[`0`B````8?L!`"4```"$^P$`(````*K[`0`;````R_L!`!@`
M``#G^P$`)`````#\`0`?````)?P!`!H```!%_`$`(0```&#\`0`@````@OP!
M`!H```"C_`$`,@```+[\`0`:````\?P!`"\````,_0$`*P```#S]`0`?````
M:/T!`",```"(_0$`'P```*S]`0`:````S/T!`"$```#G_0$`)0````G^`0`F
M````+_X!`"4```!6_@$`)````'S^`0`8````H?X!`!T```"Z_@$`)````-C^
M`0`8````_?X!`"(````6_P$`+````#G_`0`O````9O\!`!4```"6_P$`)0``
M`*S_`0`\````TO\!`!\````/``(`(P```"\``@`?````4P`"`"````!S``(`
M&@```)0``@`8````KP`"`!@```#(``(`)@```.$``@`>````"`$"`"D````G
M`0(`'@```%$!`@`Q````<`$"``H```"B`0(`$P```*T!`@`(````P0$"``D`
M``#*`0(`%@```-0!`@`,````ZP$"`!<```#X`0(`+P```!`"`@`X````0`("
M`#<```!Y`@(`,0```+$"`@`D````XP("``<````(`P(`'P```!`#`@`/````
M,`,"`!0```!``P(`#@```%4#`@`-````9`,"`"0```!R`P(`!0```)<#`@`'
M````G0,"``P```"E`P(`.P```+(#`@`/````[@,"`!$```#^`P(`(@```!`$
M`@`E````,P0"`!H```!9!`(`'0```'0$`@`:````D@0"`!$```"M!`(`!P``
M`+\$`@#'````QP0"``8```"/!0(`"P```)8%`@`:````H@4"`!4```"]!0(`
M!@```-,%`@`)````V@4"`!@```#D!0(`"P```/T%`@`-````"08"`!<````7
M!@(`!@```"\&`@`S````-@8"`!,```!J!@(`$P```'X&`@`'````D@8"``\`
M``":!@(`$0```*H&`@`>````O`8"``<```#;!@(`&0```.,&`@`R````_08"
M``0````P!P(`1@```#4'`@`A````?`<"`!,```">!P(`#````+('`@`1````
MOP<"`#(```#1!P(`%@````0(`@`(````&P@"`!T````D"`(`"0```$((`@`*
M````3`@"`!0```!7"`(`"@```&P(`@`=````=P@"``@```"5"`(`'P```)X(
M`@`(````O@@"`!H```#'"`(`)P```.((`@`&````"@D"`!4````1"0(`!P``
M`"<)`@`(````+PD"``D````X"0(`/P```$()`@`'````@@D"``\```"*"0(`
M#@```)H)`@`0````J0D"``D```"Z"0(`"0```,0)`@`(````S@D"`!,```#7
M"0(`!````.L)`@`'````\`D"`!(```#X"0(`)@````L*`@`-````,@H"`!D`
M``!`"@(`&````%H*`@`+````<PH"``X```!_"@(`&0```(X*`@`*````J`H"
M`"0```"S"@(`(0```-@*`@`*````^@H"`!,````%"P(`)P```!D+`@`)````
M00L"``\```!+"P(`%P```%L+`@`4````<PL"`"@```"("P(`#P```+$+`@`@
M````P0L"``T```#B"P(`%````/`+`@`-````!0P"`!0````3#`(`%````"@,
M`@`*````/0P"``P```!(#`(`%P```%4,`@`$````;0P"`"H```!R#`(`#```
M`)T,`@`1````J@P"``<```"\#`(``@```,0,`@`0````QPP"`!@```#8#`(`
M"P```/$,`@`#````_0P"``@````!#0(`!@````H-`@`'````$0T"``T````9
M#0(`"P```"<-`@`4````,PT"`!4```!(#0(`#@```%X-`@`O````;0T"`"``
M``"=#0(`'````+X-`@!7````VPT"`%H````S#@(`/P```(X.`@`V````S@X"
M`'X````%#P(`%0```(0/`@`,````F@\"`#$```"G#P(`"0```-D/`@`%````
MXP\"`!(```#I#P(`/P```/P/`@`2````/!`"``H```!/$`(`!@```%H0`@`$
M````81`"``0```!F$`(`"@```&L0`@`3````=A`"``4```"*$`(`!@```)`0
M`@`&````EQ`"``@```">$`(`!````*<0`@`,````K!`"``H```"Y$`(`.0``
M`,00`@`N````_A`"`"D````M$0(`!0```%<1`@`8````71$"`!D```!V$0(`
M'P```)`1`@`=````L!$"`!$```#.$0(``@```.`1`@`$````XQ$"``H```#H
M$0(`!@```/,1`@`%````^A$"``,`````$@(`#`````02`@`[````$1("`$\`
M``!-$@(`-0```)T2`@`G````TQ("`"$```#[$@(`)````!T3`@!%````0A,"
M`"8```"($P(`,@```*\3`@`S````XA,"`!H````6%`(`'0```#$4`@!X````
M3Q0"`#0```#(%`(`(0```/T4`@!6````'Q4"`"@```!V%0(`4P```)\5`@`Z
M````\Q4"`$(````N%@(`&0```'$6`@`7````BQ8"`"4```"C%@(`&0```,D6
M`@`J````XQ8"`"L````.%P(`<@```#H7`@`@````K1<"`#4```#.%P(`(0``
M``08`@!%````)A@"`"8```!L&`(`,````),8`@!+````Q!@"`$X````0&0(`
M)P```%\9`@`I````AQD"`"$```"Q&0(`*````-,9`@`K````_!D"`!T````H
M&@(`*0```$8:`@`F````<!H"`"4```"7&@(`*````+T:`@`H````YAH"`"(`
M```/&P(`.@```#(;`@`K````;1L"`"D```"9&P(`(@```,,;`@`]````YAL"
M`$$````D'`(`*````&8<`@`L````CQP"`#````"\'`(`$@```.T<`@`3````
M`!T"`!`````4'0(`>0```"4=`@`)````GQT"`!P```"I'0(`$````,8=`@`/
M````UQT"`"L```#G'0(`)P```!,>`@`.````.QX"`$L```!*'@(`H0```)8>
M`@!S````.!\"`'P```"L'P(`0````"D@`@`K````:B`"`%0```"6(`(`%P``
M`.L@`@`J`````R$"`#0````N(0(`)P```&,A`@`6````BR$"``\```"B(0(`
MKP```+(A`@`7````8B("`"@```!Z(@(`'P```*,B`@!`````PR("`!\````$
M(P(`'````"0C`@!1````02,"`!H```"3(P(`%````*XC`@`/````PR,"``H`
M``#3(P(`!0```-XC`@`&````Y","``@```#K(P(`!0```/0C`@`0````^B,"
M`!(````+)`(`#````!XD`@`0````*R0"`!$````\)`(`$P```$XD`@`=````
M8B0"`"````"`)`(`#P```*$D`@`/````L20"``0```#!)`(`"@```,8D`@`$
M````T20"``,```#6)`(`"0```-HD`@`'````Y"0"``L```#L)`(`"````/@D
M`@`'`````24"``4````))0(`"0````\E`@`4````&24"``8````N)0(`!P``
M`#4E`@`(````/24"``\```!&)0(`#P```%8E`@`,````9B4"``@```!S)0(`
M#````'PE`@`&````B24"``D```"0)0(`"P```)HE`@`/````IB4"``8```"V
M)0(`!P```+TE`@`-````Q24"``8```#3)0(`%````-HE`@`'````[R4"``,`
M``#W)0(`"0```/LE`@`&````!28"``P````,)@(`"@```!DF`@`,````)"8"
M`!$````Q)@(`"@```$,F`@`/````3B8"``4```!>)@(`"````&0F`@`$````
M;28"`!D```!R)@(`$0```(PF`@`*````GB8"`!@```"I)@(`$P```,(F`@`<
M````UB8"`!$```#S)@(`!`````4G`@`/````"B<"``<````:)P(`!````"(G
M`@`$````)R<"`!D````L)P(`!P```$8G`@`"````3B<"``(```!1)P(`$0``
M`%0G`@`)````9B<"``8```!P)P(`$@```'<G`@`7````BB<"``,```"B)P(`
M!@```*8G`@`,````K2<"`"<```"Z)P(``@```.(G`@`$````Y2<"``0```#J
M)P(`#P```.\G`@`3````_R<"``<````3*`(``@```!LH`@`'````'B@"`!$`
M```F*`(`!@```#@H`@`+````/R@"`!@```!+*`(`!@```&0H`@`3````:R@"
M`!````!_*`(`$@```)`H`@`.````HR@"``\```"R*`(``@```,(H`@`&````
MQ2@"``P```#,*`(`"0```-DH`@`1````XR@"`"(```#U*`(`!P```!@I`@`'
M````("D"``L````H*0(`!0```#0I`@`"````.BD"``L````]*0(`#@```$DI
M`@`.````6"D"`'L!``!G*0(`"@```.,J`@`*````[BH"``H```#Y*@(`"@``
M``0K`@`/````#RL"``L````?*P(`#0```"LK`@`&````.2L"``D```!`*P(`
M!P```$HK`@`)````4BL"``,```!<*P(`!````&`K`@`9````92L"`!\```!_
M*P(`,@```)\K`@`O````TBL"`"@````"+`(`+0```"LL`@`9````62P"``$`
M``!S+`(`&0```'4L`@`K````CRP"``H```"[+`(`"P```,8L`@`N````TBP"
M`"$````!+0(`1````",M`@`G````:"T"`$````"0+0(`(P```-$M`@`9````
M]2T"`!8````/+@(`"@```"8N`@`4````,2X"``4```!&+@(`+@```$PN`@`3
M````>RX"``L```"/+@(`&@```)LN`@`-````MBX"`#````#$+@(`#@```/4N
M`@`=````!"\"`"X````B+P(`#P```%$O`@`5````82\"`!````!W+P(`-0``
M`(@O`@`K````OB\"`"X```#J+P(`(````!DP`@"9````.C`"``T```#4,`(`
M"@```.(P`@`7````[3`"`"8````%,0(`(0```"PQ`@`.````3C$"`"8```!=
M,0(`%0```(0Q`@`E````FC$"`#0```#`,0(`$0```/4Q`@`,````!S("`!8`
M```4,@(`#````"LR`@`&````.#("`!L````_,@(`G0```%LR`@`V````^3("
M`#T````P,P(`!@```&XS`@`,````=3,"`)````"",P(`>````!,T`@`I````
MC#0"`"T```"V-`(`"@```.0T`@`/````[S0"`!4```#_-`(`$0```!4U`@`:
M````)S4"`#\```!"-0(`(@```((U`@`]````I34"`"````#C-0(`#@````0V
M`@`/````$S8"`!,````C-@(`$P```#<V`@`(````2S8"``X```!4-@(`#@``
M`&,V`@`)````<C8"`#8```!\-@(`)````+,V`@`\````V#8"`%<````5-P(`
M.````&TW`@!#````IC<"`&4```#J-P(`8@```%`X`@!K````LS@"`&@````?
M.0(`.@```(@Y`@`/````PSD"`!4```#3.0(`#@```.DY`@`3````^#D"`!D`
M```,.@(`!0```"8Z`@`!````+#H"``D````N.@(`$0```#@Z`@`,````2CH"
M``T```!7.@(`#0```&4Z`@`<````<SH"`!````"0.@(`"````*$Z`@`*````
MJCH"`#0```"U.@(`,0```.HZ`@`)````'#L"`!0````F.P(`%````#L[`@`4
M````4#L"``P```!E.P(`"````'([`@`&````>SL"`"4```"".P(`&0```*@[
M`@`>````PCL"``P```#A.P(`#````.X[`@`1````^SL"`",````-/`(`*```
M`#$\`@`2````6CP"``X```!M/`(`#P```'P\`@`*````C#P"``T```"7/`(`
M+P```*4\`@`2````U3P"`!D```#H/`(`&0````(]`@`2````'#T"``X````O
M/0(`(````#X]`@!<````7ST"`#H```"\/0(`*@```/<]`@!M````(CX"`#``
M``"0/@(`(0```,$^`@`@````XSX"`#T````$/P(`*````$(_`@!%````:S\"
M``D```"Q/P(`"P```+L_`@`7````QS\"`&\```#?/P(`>````$]``@`T````
MR$`"``X```#]0`(`"`````Q!`@`*````%4$"``<````@00(`!P```"A!`@`%
M````,$$"``<````V00(`"P```#Y!`@`%````2D$"`"$```!000(`$````')!
M`@`5````@T$"``\```"900(`7P```*E!`@!F````"4("`$X```!P0@(`3@``
M`+]"`@!6````#D,"`"(```!E0P(`+@```(A#`@`;````MT,"`#0```#30P(`
M"0````A$`@`7````$D0"`!8````J1`(`&````$%$`@`A````6D0"`!<```!\
M1`(`$0```)1$`@`D````ID0"``<```#+1`(`'````--$`@`/````\$0"`&``
M````10(`'P```&%%`@`E````@44"`#8```"G10(`-P```-Y%`@`'````%D8"
M``8````>1@(`!P```"5&`@`-````+48"``D````[1@(`"@```$5&`@`4````
M4$8"``D```!E1@(`$@```&]&`@`*````@D8"`!4```"-1@(`&0```*-&`@`/
M````O48"`!4```#-1@(`+@```.-&`@!`````$D<"`"P```!31P(`!P```(!'
M`@`1````B$<"``4```":1P(`%@```*!'`@`2````MT<"`!(```#*1P(`1@``
M`-U'`@`V````)$@"`$@```!;2`(`)0```*1(`@`^````RD@"`$(````)20(`
M0````$Q)`@`^````C4D"`"X```#,20(`-````/M)`@`M````,$H"`$(```!>
M2@(`0@```*%*`@`\````Y$H"``D````A2P(`!P```"M+`@`3````,TL"`!,`
M``!'2P(`!````%M+`@`%````8$L"``H```!F2P(`#@```'%+`@`.````@$L"
M`!<```"/2P(`"0```*=+`@!'````L4L"`!8```#Y2P(`$0```!!,`@`W````
M(DP"`!````!:3`(`7@```&M,`@!!````RDP"``<````,30(`'````!1-`@`6
M````,4T"`"L```!(30(`"````'1-`@`F````?4T"`"L```"D30(`+````-!-
M`@`T````_4T"``H````R3@(`"````#U.`@`)````1DX"``8```!03@(`"0``
M`%=.`@`'````84X"`#@```!I3@(`.@```*).`@`W````W4X"`%P````53P(`
M-@```')/`@`G````J4\"`#8```#13P(`1P````A0`@!+````4%`"`#8```"<
M4`(`3@```--0`@`L````(E$"`"X```!/40(`30```'Y1`@`V````S%$"`#P`
M```#4@(`+@```$!2`@`8````;U("`!P```"(4@(`,P```*52`@`M````V5("
M`"T````'4P(`;0```#53`@`D````HU,"`!,```#(4P(`$P```-Q3`@`*````
M\%,"``P```#[4P(`$@````A4`@`-````&U0"`!X````I5`(`(@```$A4`@`%
M````:U0"``X```!Q5`(`'P```(!4`@`F````H%0"`"$```#'5`(`/P```.E4
M`@`6````*54"``<```!`50(`!P```$A5`@`5````4%4"``H```!F50(`"```
M`'%5`@`S````>E4"``H```"N50(``P```+E5`@`'````O54"``<```#%50(`
M!@```,U5`@`^````U%4"``4````35@(`"````!E6`@`&````(E8"``H````I
M5@(`"P```#16`@`T````0%8"`!(```!U5@(`#@```(A6`@!5````EU8"``8`
M``#M5@(`!P```/16`@`'````_%8"``H````$5P(`!0````]7`@`1````%5<"
M``8````G5P(`$@```"Y7`@`%````05<"`#0```!'5P(`"````'Q7`@`(````
MA5<"``X```".5P(`!@```)U7`@`I````I%<"`!$```#.5P(`"````.!7`@`1
M````Z5<"``P```#[5P(`!P````A8`@`#````$%@"`$T````46`(``P```&)8
M`@`:````9E@"`!@```"!6`(`%````)I8`@`J````KU@"``8```#:6`(`!0``
M`.%8`@`'````YU@"``<```#O6`(`,@```/=8`@`S````*ED"`%\```!>60(`
M90```+Y9`@`G````)%H"`#@```!,6@(`*0```(5:`@`B````KUH"``8```#2
M6@(`"````-E:`@`0````XEH"`!T```#S6@(`/0```!%;`@`E````3UL"`"<`
M``!U6P(`-````)U;`@`H````TEL"`"T```#[6P(`8@```"E<`@`V````C%P"
M``H```##7`(`"0```,Y<`@`)````V%P"`!8```#B7`(`#````/E<`@`"````
M!ET"``X````)70(`%````!A=`@`0````+5T"`!0````^70(`$P```%-=`@`.
M````9UT"`!4```!V70(`!P```(Q=`@`8````E%T"`!L```"M70(`&````,E=
M`@`;````XET"`!D```#^70(`8P```!A>`@`$````?%X"``@```"!7@(`!P``
M`(I>`@`-````DEX"``\```"@7@(`%````+!>`@!A````Q5X"`#@````G7P(`
M6````&!?`@!<````N5\"`'(````68`(`!P```(E@`@`8````D6`"`!4```"J
M8`(`%@```,!@`@`8````UV`"`#X```#P8`(`,0```"]A`@`%````86$"``4`
M``!G80(`&P```&UA`@`8````B6$"``X```"B80(`"P```+%A`@`<````O6$"
M`$,```#:80(`%````!YB`@`:````,V("`!X```!.8@(`.P```&UB`@`\````
MJ6("`$,```#F8@(`#@```"IC`@`L````.6,"``<```!F8P(`&P```&YC`@`/
M````BF,"`!(```":8P(`#@```*UC`@`8````O&,"`!````#58P(`50```.9C
M`@`B````/&0"`"X```!?9`(`/````(YD`@`M````RV0"`#4```#Y9`(`3```
M`"]E`@`D````?&4"`&8```"A90(`%@````AF`@!$````'V8"`$L```!D9@(`
M$P```+!F`@!#````Q&8"`"X````(9P(`!@```#=G`@`.````/F<"`!,```!-
M9P(`#P```&%G`@`%````<6<"``\```!W9P(`!@```(=G`@`8````CF<"``@`
M``"G9P(`#@```+!G`@`;````OV<"`!````#;9P(`%0```.QG`@`/`````F@"
M``@````2:`(`!0```!MH`@`4````(6@"`!$````V:`(`$@```$AH`@`)````
M6V@"`!<```!E:`(`!@```'UH`@`'````A&@"`!$```",:`(`"@```)YH`@`,
M````J6@"``<```"V:`(`"````+YH`@`)````QV@"`!4```#1:`(`*P```.=H
M`@!6````$VD"``L```!J:0(`"0```'9I`@`+````@&D"`!\```",:0(`20``
M`*QI`@`E````]FD"``T````<:@(`*````"IJ`@`S````4VH"`!0```"':@(`
M!0```)QJ`@`@````HFH"`"H```##:@(`$@```.YJ`@`3`````6L"`#H````5
M:P(`2@```%!K`@`G````FVL"`!T```##:P(`"0```.%K`@`\````ZVL"`"H`
M```H;`(`$0```%-L`@`)````96P"`"````!O;`(`(P```)!L`@`]````M&P"
M`%$```#R;`(`*P```$1M`@`*````<&T"``8```![;0(`!@```()M`@`2````
MB6T"`!````"<;0(`$P```*UM`@`(````P6T"``\```#*;0(`"P```-IM`@`*
M````YFT"``\```#Q;0(`+`````%N`@`L````+FX"`"T```!;;@(`+@```(EN
M`@`B````N&X"`"4```#;;@(`(@````%O`@`T````)&\"`"8```!9;P(`-@``
M`(!O`@`N````MV\"`"(```#F;P(`)@````EP`@`H````,'`"`"0```!9<`(`
M,0```'YP`@!-````L'`"`$4```#^<`(`0````$1Q`@`W````A7$"`#X```"]
M<0(`.@```/QQ`@`U````-W("`#0```!M<@(`/@```*)R`@`F````X7("`"4`
M```(<P(`/````"YS`@`E````:W,"`!4```"1<P(`.0```*=S`@`E````X7,"
M`$0````'=`(`)P```$QT`@`4````='0"`,H```")=`(`&P```%1U`@`Q````
M<'4"`#````"B=0(`,P```--U`@!"````!W8"`#$```!*=@(`)P```'QV`@`H
M````I'8"`"L```#-=@(`,@```/EV`@`U````+'<"`$L```!B=P(`-````*YW
M`@"D````XW<"`"<```"(>`(`'0```+!X`@`F````SG@"`#,```#U>`(`,0``
M`"EY`@!.````6WD"`%4```"J>0(`#0````!Z`@`$````#GH"``8````3>@(`
M!0```!IZ`@`-````('H"``P````N>@(`$````#MZ`@`/````3'H"`!D```!<
M>@(`&P```'9Z`@`%````DGH"`!\```"8>@(`#@```+AZ`@!D````QWH"``\`
M```L>P(`+0```#Q[`@`1````:GL"`!8```!\>P(`'````)-[`@`'````L'L"
M``0```"X>P(`$````+U[`@`1````SGL"``L```#@>P(`"@```.Q[`@`1````
M]WL"``T````)?`(`$@```!=\`@`2````*GP"``T````]?`(`.P```$M\`@`@
M````AWP"`#H```"H?`(`!@```.-\`@`0````ZGP"``8```#[?`(`$0````)]
M`@`7````%'T"`!L````L?0(`#P```$A]`@`"````6'T"`$D```!;?0(`"P``
M`*5]`@`&````L7T"``P```"X?0(`'````,5]`@`%````XGT"`!<```#H?0(`
M$@````!^`@`#````$WX"`!$````7?@(`"0```"E^`@`1````,WX"``D```!%
M?@(`"P```$]^`@`0````6WX"``L```!L?@(`$0```'A^`@`5````BGX"`!T`
M``"@?@(`$0```+Y^`@`F````T'X"`"4```#W?@(`#````!U_`@`(````*G\"
M``@````S?P(`'P```#Q_`@`.````7'\"`!P```!K?P(`$P```(A_`@`.````
MG'\"`!$```"K?P(`$P```+U_`@`?````T7\"`!(```#Q?P(`&`````2``@`O
M````'8`"`!H```!-@`(`#@```&B``@`0````=X`"`"L```"(@`(`,0```+2`
M`@`3````YH`"`!$```#Z@`(`.0````R!`@`Y````1H$"`!P```"`@0(`1```
M`)V!`@`-````XH$"`!\```#P@0(`%@```!""`@`4````)X("`!D````\@@(`
M%@```%:"`@`)````;8("`!,```!W@@(`0P```(N"`@`@````SX("`"$```#P
M@@(`$````!*#`@`)````(X,"`!,````M@P(`-P```$&#`@`+````>8,"`!0`
M``"%@P(`"P```)J#`@`(````IH,"`#8```"O@P(`-0```.:#`@`*````'(0"
M`!4````GA`(`*0```#V$`@`7````9X0"`#4```!_A`(`$````+6$`@`6````
MQH0"`!8```#=A`(`"@```/2$`@`'````_X0"`"`````'A0(`&0```"B%`@`Q
M````0H4"`!P```!TA0(`&````)&%`@`9````JH4"`"````#$A0(`*0```.6%
M`@`W````#X8"`#L```!'A@(`"P```(.&`@`8````CX8"``@```"HA@(`%```
M`+&&`@`9````QH8"``L```#@A@(`*0```.R&`@`D````%H<"`!D````[AP(`
M6````%6'`@`(````KH<"`!0```"WAP(`(@```,R'`@`%````[X<"``D```#U
MAP(`#````/^'`@`<````#(@"`#$````IB`(`%````%N(`@`C````<(@"`#8`
M``"4B`(`&0```,N(`@`(````Y8@"`!8```#NB`(`%@````6)`@`1````'(D"
M``8````NB0(`!@```#6)`@`2````/(D"`%4```!/B0(`!0```*6)`@`#````
MJXD"`"4```"OB0(`!P```-6)`@`)````W8D"`!4```#GB0(`$````/V)`@`1
M````#HH"``\````@B@(`%````#"*`@`5````18H"`!L```!;B@(`'@```'>*
M`@`9````EHH"`#````"PB@(`%@```.&*`@`6````^(H"`!T````/BP(`&P``
M`"V+`@`8````28L"`"````!BBP(`/@```(.+`@`9````PHL"``D```#<BP(`
M!@```.:+`@`+````[8L"``L```#YBP(``@````6,`@`&````"(P"`!,````/
MC`(`+P```".,`@`7````4XP"`!4```!KC`(`"@```(&,`@`J````C(P"`#L`
M``"WC`(`$0```/.,`@`=````!8T"``8````CC0(`"0```"J-`@`+````-(T"
M`!$```!`C0(`%````%*-`@`<````9XT"`!<```"$C0(`&@```)R-`@`Y````
MMXT"`"0```#QC0(`-P```!:.`@`4````3HX"``<```!CC@(`!0```&N.`@`:
M````<8X"`!````",C@(`%@```)V.`@`2````M(X"``\```#'C@(`&0```->.
M`@"&````\8X"`",```!XCP(`(````)R/`@`J````O8\"`#8```#HCP(`.@``
M`!^0`@`I````6I`"``\```"$D`(`10```)20`@`1````VI`"``<```#LD`(`
M!0```/20`@`L````^I`"`!P````GD0(`+0```$21`@`S````<I$"`!\```"F
MD0(`(0```,:1`@`E````Z)$"`!\````.D@(`%P```"Z2`@`'````1I("``<`
M``!.D@(`!@```%:2`@`&````79("`#````!DD@(`#P```)62`@`.````I9("
M`!````"TD@(`#@```,62`@`5````U)("``\```#JD@(`"P```/J2`@`3````
M!I,"``@````:DP(`"````".3`@`.````+),"`!L````[DP(`$````%>3`@`0
M````:),"`!4```!YDP(`50```(^3`@`_````Y9,"``L````EE`(`#P```#&4
M`@!%````090"`!0```"'E`(`"0```)R4`@`.````II0"`!\```"UE`(`!@``
M`-64`@`@````W)0"`"<```#]E`(`)@```"65`@`8````3)4"`!<```!EE0(`
M(````'V5`@`8````GI4"`!8```"WE0(`"0```,Z5`@`9````V)4"``L```#R
ME0(`%````/Z5`@`#````$Y8"``4````7E@(`!P```!V6`@`.````)98"`!``
M```TE@(`#````$66`@`F````4I8"`"(```!YE@(`'P```)R6`@`<````O)8"
M``X```#9E@(`(@```.B6`@`-````"Y<"`!@````9EP(`"````#*7`@`0````
M.Y<"`!$```!,EP(`#P```%Z7`@`$````;I<"``<```!SEP(`&@```'N7`@`;
M````EI<"``@```"REP(`$0```+N7`@`4````S9<"``X```#BEP(`)P```/&7
M`@`4````&9@"`!D````NF`(`*0```$B8`@`[````<I@"``<```"NF`(`'```
M`+:8`@`@````TY@"``D```#TF`(`"0```/Z8`@`0````")D"`!@````9F0(`
M#@```#*9`@`0````09D"``H```!2F0(`!P```%V9`@`+````99D"``D```!Q
MF0(`!@```'N9`@`8````@ID"`"(```";F0(`%0```+Z9`@`5````U)D"`"X`
M``#JF0(`)0```!F:`@`.````/YH"``8```!.F@(`*````%6:`@`0````?IH"
M`)L```"/F@(`&P```"N;`@!$````1YL"``L```",FP(`!P```)B;`@`/````
MH)L"``@```"PFP(`"@```+F;`@`%````Q)L"``@```#*FP(`"0```-.;`@`1
M````W9L"`!<```#OFP(`"`````><`@`#````$)P"``8````4G`(`!P```!N<
M`@`6````(YP"`"D````ZG`(`$````&2<`@`2````=9P"`!T```"(G`(``P``
M`*:<`@`"````JIP"``T```"MG`(`!````+N<`@`4````P)P"``H```#5G`(`
M#P```."<`@`$````\)P"``4```#UG`(`&P```/N<`@`%````%YT"`",````=
MG0(`"````$&=`@`&````2IT"`!(```!1G0(`&P```&2=`@`/````@)T"``<`
M``"0G0(`"````)B=`@`H````H9T"``4```#*G0(`"0```-"=`@`/````VIT"
M`!$```#JG0(``@```/R=`@`-````_YT"`#,````-G@(`!@```$&>`@`/````
M2)X"`!(```!8G@(`#P```&N>`@`0````>YX"``8```",G@(`$P```).>`@`+
M````IYX"``<```"SG@(`&````+N>`@`P````U)X"`$T````%GP(`*P```%.?
M`@`M````?Y\"``8```"MGP(`"0```+2?`@`$````OI\"``D```##GP(`"0``
M`,V?`@`7````UY\"``P```#OGP(`!@```/R?`@`-`````Z`"``<````1H`(`
M!````!F@`@`$````'J`"`!@````CH`(`00```#R@`@!(````?J`"`$$```#'
MH`(`)P````FA`@`%````,:$"``T````WH0(`!P```$6A`@`(````3:$"``D`
M``!6H0(`&P```&"A`@`9````?*$"`!4```"6H0(`!@```*RA`@`%````LZ$"
M`!````"YH0(`"````,JA`@`*````TZ$"`",```#>H0(`+`````*B`@`&````
M+Z("`"`````VH@(`$@```%>B`@`4````:J("``0```!_H@(`#@```(2B`@`'
M````DZ("``<```";H@(`)P```*.B`@`&````RZ("``D```#2H@(`$P```-RB
M`@`3````\*("``@````$HP(`"0````VC`@`%````%Z,"`$<````=HP(`-```
M`&6C`@!!````FJ,"`#(```#<HP(`20````^D`@`[````6:0"`"P```"5I`(`
M/@```,*D`@`O`````:4"`#T````QI0(`,0```&^E`@`0````H:4"`!$```"R
MI0(`"P```,2E`@`R````T*4"`"$````#I@(`(0```"6F`@`?````1Z8"`!X`
M``!GI@(`,0```(:F`@`'````N*8"``D```#`I@(`"@```,JF`@`'````U:8"
M``0```#=I@(`(@```.*F`@`]````!:<"`"D```!#IP(`+````&VG`@`]````
MFJ<"``X```#8IP(`*0```.>G`@`=````$:@"`"@````OJ`(`#0```%BH`@`>
M````9J@"``P```"%J`(`(P```)*H`@`V````MJ@"`!8```#MJ`(`%0````2I
M`@`(````&JD"``L````CJ0(`#````"^I`@`0````/*D"`!<```!-J0(`10``
M`&6I`@!!````JZD"`#X```#MJ0(`?````"RJ`@!G````J:H"``<````1JP(`
M#0```!FK`@`&````)ZL"``T````NJP(`$````#RK`@`1````3:L"`!0```!?
MJP(`%0```'2K`@`7````BJL"``@```"BJP(`"````*NK`@`.````M*L"``\`
M``##JP(`$0```-.K`@`2````Y:L"`!T```#XJP(`(P```!:L`@`C````.JP"
M`"<```!>K`(`%@```(:L`@`:````G:P"`!T```"XK`(`%0```-:L`@`5````
M[*P"`"P````"K0(`$0```"^M`@`*````0:T"`!0```!,K0(`'0```&&M`@`3
M````?ZT"`!(```"3K0(`"@```*:M`@`5````L:T"``<```#'K0(`,P```,^M
M`@`J`````ZX"`"X````NK@(`+0```%VN`@"7````BZX"`!$````CKP(`!0``
M`#6O`@`5````.Z\"``D```!1KP(`"P```%NO`@`+````9Z\"`"4```!SKP(`
M)0```)FO`@`H````OZ\"`"@```#HKP(`"````!&P`@`8````&K`"`!P````S
ML`(`#P```%"P`@`K````8+`"`"L```",L`(`(@```+BP`@`.````V[`"`!0`
M``#JL`(`&0```/^P`@`M````&;$"`"X```!'L0(`*@```':Q`@`J````H;$"
M`"8```#,L0(`*````/.Q`@`>````'+("`$$````[L@(`%0```'VR`@`4````
MD[("`!<```"HL@(`%@```,"R`@`1````U[("`!<```#IL@(`%@````&S`@`4
M````&+,"`!0````MLP(`.P```$*S`@`9````?K,"`!H```"8LP(`.@```+.S
M`@`3````[K,"``8````"M`(`$`````FT`@`]````&K0"`!D```!8M`(`'```
M`'*T`@`M````C[0"`!0```"]M`(`%0```-*T`@`5````Z+0"`#0```#^M`(`
M(````#.U`@`>````5+4"`!P```!SM0(`#P```)"U`@`<````H+4"`"<```"]
MM0(`$P```.6U`@`@````^;4"`"8````:M@(`(````$&V`@`9````8K8"`"0`
M``!\M@(`)````*&V`@`=````QK8"`!0```#DM@(`'````/FV`@`<````%K<"
M`"$````SMP(`&0```%6W`@`*````;[<"``@```!ZMP(`$@```(.W`@`;````
MEK<"``0```"RMP(`!P```+>W`@`+````O[<"`!(```#+MP(`!@```-ZW`@`&
M````Y;<"``<```#LMP(`!@```/2W`@`'````^[<"``4````#N`(`!0````FX
M`@`5````#[@"``8````EN`(`!@```"RX`@`%````,[@"``4````YN`(`"@``
M`#^X`@`1````2K@"``H```!<N`(`%@```&>X`@`4````?K@"``(```"3N`(`
M"@```):X`@`7````H;@"``4```"YN`(`-0```+^X`@`2````];@"`!$````(
MN0(`&@```!JY`@`/````-;D"``T```!%N0(`$````%.Y`@`T````9+D"`&4`
M``"9N0(`70```/^Y`@!P````7;H"`#H```#.N@(`!0````F[`@`(````#[L"
M`"<````8NP(`$P```$"[`@`0````5+L"``8```!ENP(`"@```&R[`@`-````
M=[L"``8```"%NP(`(@```(R[`@`0````K[L"`!<```#`NP(`#0```-B[`@`;
M````YKL"`!`````"O`(`%0```!.\`@`1````*;P"`!H````[O`(`%````%:\
M`@`&````:[P"``4```!RO`(`#````'B\`@`F````A;P"``<```"LO`(`"0``
M`+2\`@`2````OKP"`!<```#1O`(`!P```.F\`@`%````\;P"``<```#WO`(`
M%@```/^\`@`-````%KT"``\````DO0(`#0```#2]`@`6````0KT"`!@```!9
MO0(`#P```'*]`@`1````@KT"``P```"4O0(`&````*&]`@`,````NKT"``<`
M``#'O0(`$P```,^]`@`4````X[T"`$(```#XO0(`(P```#N^`@`(````7[X"
M`!P```!HO@(`#````(6^`@`M````DKX"`!4```#`O@(`%0```-:^`@`-````
M[+X"`(X```#ZO@(`#````(F_`@`)````EK\"``<```"@OP(`"@```*B_`@`)
M````L[\"``X```"]OP(`$````,R_`@`5````W;\"`"D```#SOP(`)0```!W`
M`@`J````0\`"``H```!NP`(`"````'G``@`*````@L`"``P```"-P`(`#```
M`)K``@`-````I\`"``D```"UP`(`#@```+_``@`4````SL`"`#4```#CP`(`
M!0```!G!`@`.````'\$"`!H````NP0(`70```$G!`@`:````I\$"``X```#"
MP0(`!````-'!`@`$````UL$"``X```#;P0(`&@```.K!`@`:````!<("`!H`
M```@P@(`"````#O"`@`*````1,("``(```!/P@(`!````%+"`@`E````5\("
M``,```!]P@(`!0```('"`@`I````A\("`!$```"QP@(`"@```,/"`@`%````
MSL("``8```#4P@(`"P```-O"`@`8````Y\("`"T`````PP(`!0```"[#`@`O
M````-,,"`!$```!DPP(`!@```';#`@`'````?<,"``@```"%PP(`!````([#
M`@`%````D\,"`&L```"9PP(`"@````7$`@`-````$,0"`!T````>Q`(`!0``
M`#S$`@`&````0L0"`"T```!)Q`(`+P```'?$`@`,````I\0"`#$```"TQ`(`
M*0```.;$`@`:````$,4"`"D````KQ0(`-@```%7%`@`.````C,4"``D```";
MQ0(`$@```*7%`@`7````N,4"`!,```#0Q0(`"@```.3%`@`(````[\4"`!<`
M``#XQ0(`.````!#&`@`?````2<8"`!X```!IQ@(`&````(C&`@`9````H<8"
M`",```"[Q@(`#P```-_&`@`M````[\8"`"T````=QP(`!````$O'`@`'````
M4,<"``@```!8QP(`"````&''`@`<````:L<"`!$```"'QP(`#P```)G'`@`'
M````J<<"`!4```"QQP(`"0```,?'`@`4````T<<"`!0```#FQP(`"@```/O'
M`@`2````!L@"`&$````9R`(`&0```'O(`@`1````E<@"`!0```"GR`(`%```
M`+S(`@`-````T<@"`!D```#?R`(`%P```/G(`@`7````$<D"`!4````IR0(`
M*@```#_)`@`Z````:LD"`"(```"ER0(`#P```,C)`@`L````V,D"``H````%
MR@(`#P```!#*`@`;````(,H"`%$````\R@(`'````([*`@`&````J\H"`!\`
M``"RR@(`)@```-+*`@`'````^<H"``8````!RP(`(`````C+`@`(````*<L"
M``D````RRP(`(0```#S+`@`@````7LL"`#P```!_RP(`"````+S+`@`*````
MQ<L"`"<```#0RP(`5````/C+`@`;````3<P"`!\```!IS`(`&@```(G,`@`#
M````I,P"``P```"HS`(`"````+7,`@`9````OLP"``D```#8S`(`#0```.+,
M`@`&````\,P"`!8```#WS`(`!@````[-`@`(````%<T"``D````>S0(`#```
M`"C-`@`*````-<T"`!````!`S0(`00```%'-`@`Y````D\T"``D```#-S0(`
M&@```-?-`@`7````\LT"`!@````*S@(`"0```"/.`@`5````+<X"`!@```!#
MS@(`%@```%S.`@`6````<\X"`!4```"*S@(`90```*#.`@`6````!L\"`!8`
M```=SP(`"@```#3/`@`?````/\\"`!````!?SP(`%0```'#/`@`9````AL\"
M`!(```"@SP(`"0```+//`@`,````O<\"``D```#*SP(`&0```-3/`@`'````
M[L\"`!<```#VSP(`!P````[0`@`+````%M`"``8````BT`(`-@```"G0`@`'
M````8-`"``4```!HT`(`%@```&[0`@`%````A=`"``<```"+T`(`$P```)/0
M`@`4````I]`"`"(```"\T`(`(@```-_0`@`=`````M$"`!P````@T0(`(@``
M`#W1`@`F````8-$"`!\```"'T0(``P```*?1`@`%````J]$"`!8```"QT0(`
M!@```,C1`@`/````S]$"``\```#?T0(`#0```._1`@`,````_=$"``@````*
MT@(`%0```!/2`@`*````*=("`"(````TT@(`#0```%?2`@`/````9=("`!``
M``!UT@(`(P```(;2`@`=````JM("`!8```#(T@(`"````-_2`@`.````Z-("
M``D```#WT@(`$`````'3`@`/````$M,"``X````BTP(`$P```#'3`@`*````
M1=,"``D```!0TP(`!0```%K3`@`'````8-,"``4```!HTP(`!````&[3`@`"
M````<],"`"(```!VTP(`"@```)G3`@`;````I-,"``P```#`TP(`*0```,W3
M`@`>````]],"`!8````6U`(`)````"W4`@`K````4M0"`!X```!^U`(`-P``
M`)W4`@`[````U=0"`!D````1U0(`)@```"O5`@!&````4M4"``P```"9U0(`
M-````*;5`@`[````V]4"`$0````7U@(`1````%S6`@!,````H=8"``\```#N
MU@(`(````/[6`@`]````']<"`!\```!=UP(`'@```'W7`@`S````G-<"`!P`
M``#0UP(`(P```.W7`@`E````$=@"`!P````WV`(`'P```%38`@`?````=-@"
M`"4```"4V`(`(0```+K8`@`@````W-@"`"X```#]V`(`(````"S9`@`@````
M3=D"``P```!NV0(`00```'O9`@!!````O=D"`$4```#_V0(`1@```$7:`@!#
M````C-H"`$````#0V@(`>0```!';`@`5````B]L"`#$```"AVP(`,0```-/;
M`@`S````!=P"`$H````YW`(`$````(3<`@`)````E=P"`",```"?W`(`!P``
M`,/<`@`Z````R]P"`!P````&W0(`%````"/=`@`2````.-T"`$(```!+W0(`
M.@```([=`@`A````R=T"`#@```#KW0(`)````"3>`@`+````2=X"`%,```!5
MW@(`2@```*G>`@`1````]-X"``<````&WP(`%P````[?`@`5````)M\"``\`
M```\WP(`!@```$S?`@`0````4]\"`!@```!DWP(`!P```'W?`@`*````A=\"
M``@```"0WP(`#````)G?`@`+````IM\"``T```"RWP(`"P```,#?`@`3````
MS-\"`!\```#@WP(`%@````#@`@`0````%^`"`!<````HX`(`#@```$#@`@`2
M````3^`"`"T```!BX`(`!0```)#@`@`$````EN`"`"0```";X`(`*@```,#@
M`@`)````Z^`"``8```#UX`(`%````/S@`@`2````$>$"`%X````DX0(`1P``
M`(/A`@`/````R^$"`$@```#;X0(`!P```"3B`@`!````+.("``8````NX@(`
M$@```#7B`@`%````2.("``<```!.X@(`#P```%;B`@`'````9N("`#4```!N
MX@(`$0```*3B`@`2````MN("`"4```#)X@(`)@```._B`@`$````%N,"`#L`
M```;XP(`.P```%?C`@`.````D^,"`"@```"BXP(`-@```,OC`@"'`````N0"
M``X```"*Y`(`&@```)GD`@!%````M.0"``\```#ZY`(`)P````KE`@`1````
M,N4"`!4```!$Y0(`"````%KE`@`.````8^4"``X```!RY0(`#````('E`@`3
M````CN4"``P```"BY0(`(````*_E`@`<````T.4"``0```#MY0(`$````/+E
M`@`7`````^8"``X````;Y@(`$@```"KF`@`;````/>8"`"H```!9Y@(`%0``
M`(3F`@`#````FN8"`!$```">Y@(`%@```+#F`@`6````Q^8"``X```#>Y@(`
M2````.WF`@`/````-N<"`!H```!&YP(`5````&'G`@`1````MN<"`!T```#(
MYP(`/@```.;G`@`[````)>@"`!,```!AZ`(`%0```'7H`@`?````B^@"`!\`
M``"KZ`(`,0```,OH`@`Q````_>@"`#$````OZ0(`7@```&'I`@!8````P.D"
M`*P````9Z@(`"@```,;J`@`,````T>H"`!,```#>Z@(`$0```/+J`@`7````
M!.L"`!`````<ZP(`'````"WK`@`.````2NL"`!4```!9ZP(`!````&_K`@`B
M````=.L"``X```"7ZP(`*0```*;K`@`=````T.L"``T```#NZP(`(@```/SK
M`@`-````'^P"``8````M[`(`#P```#3L`@`B````1.P"`"(```!G[`(`"```
M`(KL`@`%````D^P"`"````"9[`(`!@```+KL`@`2````P>P"``@```#4[`(`
M"````-WL`@`3````YNP"``L```#Z[`(`&`````;M`@`E````'^T"``P```!%
M[0(`+````%+M`@`=````?^T"``H```"=[0(`*````*CM`@`5````T>T"`$$`
M``#G[0(`&P```"GN`@`+````1>X"``P```!1[@(`)0```%[N`@`%````A.X"
M`!8```"*[@(``P```*'N`@`1````I>X"``4```"W[@(`"@```+WN`@`E````
MR.X"`#H```#N[@(`"@```"GO`@`F````-.\"`!,```!;[P(`"P```&_O`@`=
M````>^\"`#4```"9[P(`"````,_O`@`4````V.\"`#@```#M[P(`.0```";P
M`@`S````8/`"`#P```"4\`(`!````-'P`@`(````UO`"``D```#?\`(`"```
M`.GP`@`+````\O`"``@```#^\`(`!P````?Q`@`W````#_$"`!P```!'\0(`
M!P```&3Q`@#2````;/$"`!(````_\@(`*@```%+R`@`W````??("`!L```"U
M\@(`*P```-'R`@`I````_?("`",````G\P(`00```$OS`@`;````C?,"`"D`
M``"I\P(`&P```-/S`@!K````[_,"`&X```!;]`(`)@$``,KT`@`D````\?4"
M`!D````6]@(`+0```##V`@`@````7O8"`$P```!_]@(`-P```,SV`@`U````
M!/<"`#$````Z]P(`,0```&SW`@`T````GO<"`"@```#3]P(`!P```/SW`@`(
M````!/@"``D````-^`(`"````!?X`@`5````(/@"`!0````V^`(`+````$OX
M`@`4````>/@"`"@```"-^`(`+P```+;X`@`B````YO@"`#(````)^0(`-P``
M`#SY`@`_````=/D"``<```"T^0(`&@```+SY`@`)````U_D"``P```#A^0(`
M+@```.[Y`@`0````'?H"``\````N^@(`$P```#[Z`@`(````4OH"`!(```!;
M^@(`"0```&[Z`@`-````>/H"`!L```"&^@(`"P```*+Z`@`8````KOH"``D`
M``#'^@(`.@```-'Z`@`Z````#/L"`!(```!'^P(`"@```%K[`@`1````9?L"
M`!H```!W^P(`'````)+[`@!"````K_L"`#D```#R^P(`"P```"S\`@`+````
M./P"``8```!$_`(`$0```$O\`@`A````7?P"`!````!__`(`2@```)#\`@`O
M````V_P"`"8````+_0(`)````#+]`@`%````5_T"``@```!=_0(`!0```&;]
M`@`V````;/T"`#````"C_0(`)P```-3]`@`.````_/T"`!H````+_@(`#P``
M`";^`@`&````-OX"``\````]_@(`$0```$W^`@`(````7_X"``X```!H_@(`
M#@```'?^`@`3````AOX"``4```":_@(`$````*#^`@`-````L?X"`#P```"_
M_@(`4@```/S^`@`=````3_\"``P```!M_P(`#P```'K_`@`/````BO\"``X`
M``":_P(`"0```*G_`@`2````L_\"`!0```#&_P(`'````-O_`@`B````^/\"
M``H````;``,`)P```"8``P`=````3@`#`!L```!L``,`!0```(@``P`7````
MC@`#``H```"F``,`$````+$``P`-````P@`#`"T```#0``,`&````/X``P`-
M````%P$#`!(````E`0,`*@```#@!`P`&````8P$#``T```!J`0,`'````'@!
M`P`.````E0$#`!````"D`0,`"@```+4!`P`]````P`$#``\```#^`0,`"0``
M``X"`P`@````&`(#`!`````Y`@,`%````$H"`P`4````7P(#`#,```!T`@,`
M0@```*@"`P`4````ZP(#``X``````P,`"0````\#`P`2````&0,#`!$````L
M`P,`$@```#X#`P`4````40,#`!4```!F`P,`%@```'P#`P`E````DP,#`$``
M``"Y`P,`.0```/H#`P`+````-`0#``T```!`!`,`"@```$X$`P`9````600#
M`!,```!S!`,`'0```(<$`P!`````I00#`!P```#F!`,`)0````,%`P`F````
M*04#`$(```!0!0,`0P```),%`P`\````UP4#``\````4!@,`%@```"0&`P`'
M````.P8#`!(```!#!@,`$@```%8&`P`C````:08#`!D```"-!@,`"@```*<&
M`P`(````L@8#``\```"[!@,`(````,L&`P`7````[`8#`!,````$!P,`3```
M`!@'`P`;````90<#``<```"!!P,`%P```(D'`P`H````H0<#``8```#*!P,`
M!P```-$'`P`0````V0<#`!4```#J!P,`%P`````(`P`'````&`@#``<````@
M"`,`"0```"@(`P`4````,@@#`!(```!'"`,`$P```%H(`P`3````;@@#``8`
M``"""`,`!0```(D(`P`Q````CP@#`"@```#!"`,`)0```.H(`P`(````$`D#
M``\````9"0,`!@```"D)`P`&````,`D#`!H````W"0,`&0```%()`P`9````
M;`D#``X```"&"0,`2````)4)`P`/````W@D#`!T```#N"0,`5P````P*`P`^
M````9`H#`#,```"C"@,`%@```-<*`P`^````[@H#`!@````M"P,`(0```$8+
M`P`T````:`L#`%L```"="P,`9@```/D+`P!A````8`P#`+(```#"#`,`*P``
M`'4-`P`)````H0T#``0```"K#0,`#````+`-`P`G````O0T#``,```#E#0,`
M!0```.D-`P`-````[PT#``<```#]#0,``P````4.`P`6````"0X#`!$````@
M#@,`#````#(.`P`3````/PX#``L```!3#@,`%P```%\.`P`8````=PX#`!,`
M``"0#@,`!0```*0.`P`*````J@X#`!8```"U#@,`%0```,P.`P`.````X@X#
M``<```#Q#@,`#````/D.`P`*````!@\#`$,````1#P,`$````%4/`P`.````
M9@\#`!P```!U#P,`$````)(/`P`1````HP\#`!$```"U#P,`#````,</`P`C
M````U`\#`%T```#X#P,`4@```%80`P`K````J1`#`!@```#5$`,`)@```.X0
M`P`\````%1$#`$$```!2$0,`$@```)01`P`'````IQ$#``8```"O$0,`#```
M`+81`P`+````PQ$#`!0```#/$0,`&0```.01`P`%````_A$#``L````$$@,`
M%@```!`2`P`4````)Q(#`!0````\$@,`$P```%$2`P`<````91(#`!\```""
M$@,`%@```*(2`P`:````N1(#`!X```#4$@,`4P```/,2`P`1````1Q,#`"T`
M``!9$P,`.P```(<3`P`5````PQ,#`!4```#9$P,`$````.\3`P!N`````!0#
M`"0```!O%`,`(````)04`P`R````M10#`"L```#H%`,`*````!05`P`C````
M/14#`!\```!A%0,`(P```($5`P`E````I14#`!\```#+%0,`)@```.L5`P`J
M````$A8#`!X````]%@,`#@```%P6`P`;````:Q8#``H```"'%@,`'@```)(6
M`P`\````L18#``<```#N%@,`"````/86`P`;````_Q8#`!P````;%P,`"@``
M`#@7`P`3````0Q<#``\```!7%P,`"````&<7`P`D````<!<#`"T```"5%P,`
M"0```,,7`P`8````S1<#`!P```#F%P,`"`````,8`P`*````#!@#`%(````7
M&`,`2P```&H8`P`X````MA@#`$4```#O&`,`0````#49`P!X````=AD#``T`
M``#O&0,`,````/T9`P`Q````+AH#``H```!@&@,`$@```&L:`P`<````?AH#
M`#0```";&@,`!P```-`:`P`-````V!H#`#H```#F&@,`=P```"$;`P`^````
MF1L#`#D```#8&P,`.@```!(<`P`3````31P#`!H```!A'`,`&P```'P<`P`2
M````F!P#`!L```"K'`,`)P```,<<`P`?````[QP#`!0````/'0,`3P```"0=
M`P!$````=!T#`"T```"Y'0,`*P```.<=`P`G````$QX#`!`````['@,`-```
M`$P>`P`F````@1X#`#(```"H'@,`(P```-L>`P`S````_QX#`!`````S'P,`
M,P```$0?`P`J````>!\#`#(```"C'P,`,@```-8?`P`K````"2`#`#$````U
M(`,`#0```&<@`P`)````=2`#`!$```!_(`,`$P```)$@`P`8````I2`#``@`
M``"^(`,`!P```,<@`P`W````SR`#``<````'(0,`#`````\A`P`$````'"$#
M``4````A(0,`$@```"<A`P`'````.B$#``@```!"(0,`!@```$LA`P`4````
M4B$#``H```!G(0,`"0```'(A`P`%````?"$#`!$```""(0,`$0```)0A`P`:
M````IB$#`!P```#!(0,`%0```-XA`P`A````]"$#``T````6(@,`!P```"0B
M`P`2````+"(#`!,````_(@,`$0```%,B`P`5````92(#`!X```![(@,`$@``
M`)HB`P`5````K2(#`!@```##(@,`*0```-PB`P`)````!B,#``D````0(P,`
M&P```!HC`P`H````-B,#``X```!?(P,`(0```&XC`P`T````D",#``D```#%
M(P,`"0```,\C`P`2````V2,#``8```#L(P,`!````/,C`P`0````^",#`"(`
M```))`,`%0```"PD`P`Y````0B0#`!8```!\)`,`%0```),D`P`?````J20#
M`$X```#))`,`#0```!@E`P`/````)B4#``P````V)0,`"````$,E`P`)````
M3"4#``@```!6)0,`"0```%\E`P`'````:24#``T```!Q)0,`$@```'\E`P`)
M````DB4#`!<```"<)0,`$@```+0E`P`*````QR4#``8```#2)0,`&0```-DE
M`P`5````\R4#``<````))@,`$````!$F`P`0````(B8#`"`````S)@,`&0``
M`%0F`P`,````;B8#``,```![)@,`!P```'\F`P`E````AR8#``8```"M)@,`
M"@```+0F`P`&````OR8#`'L```#&)@,`'@```$(G`P`)````82<#``4```!K
M)P,`+````'$G`P!&````GB<#`",```#E)P,`+P````DH`P!0````.2@#`#H`
M``"**`,`/0```,4H`P`D`````RD#`"`````H*0,`!0```$DI`P`+````3RD#
M``<```!;*0,`"````&,I`P`)````;"D#``<```!V*0,`"````'XI`P`2````
MARD#``H```":*0,`"0```*4I`P`+````KRD#``L```"[*0,`!P```,<I`P`'
M````SRD#``@```#7*0,`%````.`I`P`+````]2D#``8````!*@,`'`````@J
M`P`9````)2H#`!T````_*@,`!0```%TJ`P`D````8RH#``8```"(*@,`+0``
M`(\J`P`8````O2H#``@```#6*@,`%````-\J`P`)````]"H#`!,```#^*@,`
M"P```!(K`P`%````'BL#`!0````D*P,`!0```#DK`P`4````/RL#``8```!4
M*P,`&@```%LK`P`*````=BL#`!P```"!*P,`"````)XK`P`&````IRL#``8`
M``"N*P,`$@```+4K`P`D````R"L#``L```#M*P,`#0```/DK`P`J````!RP#
M`"$````R+`,`'````%0L`P`-````<2P#`"$```!_+`,`&0```*$L`P!#````
MNRP#``4```#_+`,`"@````4M`P`3````$"T#`!@````D+0,``P```#TM`P`3
M````02T#``D```!5+0,`)````%\M`P`I````A"T#`"@```"N+0,`,P```-<M
M`P"(````"RX#`"@```"4+@,`'0```+TN`P`W````VRX#`#4````3+P,`+P``
M`$DO`P`?````>2\#`!X```"9+P,`9````+@O`P`:````'3`#`!8````X,`,`
M)0```$\P`P!<````=3`#`#H```#2,`,`-P````TQ`P`Q````13$#`%````!W
M,0,`20```,@Q`P!K````$C(#`"H```!^,@,`+@```*DR`P!!````V#(#`"P`
M```:,P,`(P```$<S`P`Q````:S,#`#<```"=,P,`+0```-4S`P`=`````S0#
M`!D````A-`,`?0```#LT`P`[````N30#`$$```#U-`,`0````#<U`P!#````
M>#4#`"L```"\-0,`+@```.@U`P`Y````%S8#`$(```!1-@,`-P```)0V`P#3
M`0``S#8#`"(```"@.`,`?````,,X`P!0````0#D#`!<```"1.0,`3````*DY
M`P!`````]CD#`$8````W.@,`-P```'XZ`P`:````MCH#`$@```#1.@,`.0``
M`!H[`P`<````5#L#`!L```!Q.P,`'````(T[`P`K````JCL#`(````#6.P,`
M-P```%<\`P`L````CSP#`#\```"\/`,`7@```/P\`P!*````6ST#`"H```"F
M/0,`,0```-$]`P`V`````SX#`#(````Z/@,`(@```&T^`P`4````D#X#`(``
M``"E/@,`'P```"8_`P`A````1C\#`"````!H/P,`.0```(D_`P`>````PS\#
M`"0```#B/P,`*P````=``P`B````,T`#`"0```!60`,`(````'M``P`B````
MG$`#`"0```"_0`,`+````.1``P`C````$4$#`!0````U00,`)0```$I!`P`=
M````<$$#`"X```".00,`'````+U!`P`M````VD$#`#X````(0@,`(@```$="
M`P`5````:D(#`#<```"`0@,`)@```+A"`P!*````WT(#`"P````J0P,`*P``
M`%=#`P`Z````@T,#`!X```"^0P,`&@```-U#`P`M````^$,#`&D````F1`,`
M*P```)!$`P`V````O$0#`$D```#S1`,`3@```#U%`P`W````C$4#`"T```#$
M10,`0````/)%`P!P````,T8#`%(```"D1@,`5@```/=&`P!<````3D<#`%P`
M``"K1P,`30````A(`P`V````5D@#`#4```"-2`,`6@```,-(`P`C````'DD#
M`#<```!"20,`-@```'I)`P`T````L4D#`"T```#F20,`5````!1*`P!K````
M:4H#`%D```#52@,`<P```"]+`P`Z````HTL#`"P```#>2P,`6@````M,`P!9
M````9DP#`#@```#`3`,`*````/E,`P`N````(DT#`%4```!130,`-P```*=-
M`P`M````WTT#`!X````-3@,`*0```"Q.`P`I````5DX#`"D```"`3@,`+P``
M`*I.`P!Y````VDX#`&X```!43P,`=P```,-/`P#$````.U`#`!8`````40,`
M)P```!=1`P`X````/U$#`"\```!X40,`30```*A1`P`J````]E$#`&,````A
M4@,`(P```(52`P`+````J5(#`*@```"U4@,`/P```%Y3`P`K````GE,#`%``
M``#*4P,`0P```!M4`P!I````7U0#`$(```#)5`,`40````Q5`P`[````7E4#
M`#4```":50,`.````-!5`P`K````"58#`"@````U5@,`#@```%Y6`P!*````
M;58#`"D```"X5@,`.````.)6`P`U````&U<#`"H```!15P,`(P```'Q7`P`W
M````H%<#`#T```#85P,`%0```!98`P`.````+%@#``8````[6`,`"P```$)8
M`P`$````3E@#``H```!36`,`#P```%Y8`P`1````;E@#``L```"`6`,`!@``
M`(Q8`P`1````DU@#``0```"E6`,`$````*I8`P!N````NU@#`&8````J60,`
M3P```)%9`P`#````X5D#`!0```#E60,`!````/I9`P`'````_UD#``8````'
M6@,`!0````Y:`P`(````%%H#`!4````=6@,`&0```#-:`P`,````35H#``@`
M``!:6@,`"0```&-:`P`1````;5H#`!$```!_6@,``P```)%:`P`%````E5H#
M``<```";6@,`$@```*-:`P`,````MEH#`!0```##6@,`!@```-A:`P`5````
MWUH#``T```#U6@,``P````-;`P`N````!UL#``0````V6P,`!@```#M;`P`'
M````0EL#`"4```!*6P,`1P```'!;`P`X````N%L#`#D```#Q6P,`&````"M<
M`P`G````1%P#`"H```!L7`,`)@```)=<`P`<````OEP#`"$```#;7`,`*```
M`/U<`P`C````)ET#`"````!*70,`)````&M=`P`F````D%T#`"(```"W70,`
M-@```-I=`P`=````$5X#`#,````O7@,`.0```&->`P`F````G5X#`"H```#$
M7@,`*````.]>`P`C````&%\#`"@````\7P,`,@```&5?`P`K````F%\#`#``
M``#$7P,`)@```/5?`P`D````'&`#`"4```!!8`,`+@```&=@`P`@````EF`#
M`"<```"W8`,`-P```-]@`P`Z````%V$#`!P```!280,`)@```&]A`P`]````
MEF$#`"<```#480,`*P```/QA`P`H````*&(#`"H```!18@,`)````'QB`P`H
M````H6(#`!X```#*8@,`*P```.EB`P`H````%6,#`#<````^8P,`+@```'9C
M`P`Y````I6,#``T```#?8P,`%@```.UC`P`)````!&0#``D````.9`,`%0``
M`!AD`P`0````+F0#`!@````_9`,`,@```%AD`P`Z````BV0#`#P```#&9`,`
M,P````-E`P`E````-V4#``T```!=90,`(P```&ME`P`/````CV4#`!8```"?
M90,`"@```+9E`P`.````P64#`"H```#090,`"````/ME`P`+````!&8#`!$`
M```09@,`0@```")F`P`3````968#`!@```!Y9@,`+P```))F`P`Q````PF8#
M`"D```#T9@,`(@```!YG`P`D````06<#`!,```!F9P,`"@```'IG`P#L````
MA6<#``@```!R:`,`#````'MH`P`A````B&@#`!8```"J:`,`"@```,%H`P`-
M````S&@#`!X```#::`,`$@```/EH`P`7````#&D#`"H````D:0,`!@```$]I
M`P!2````5FD#`!H```"I:0,`&@```,1I`P`'````WVD#``\```#G:0,`%@``
M`/=I`P`D````#FH#``@````S:@,`%P```#QJ`P!"````5&H#``<```"7:@,`
M7P```)]J`P`M````_VH#`!H````M:P,`$P```$AK`P`4````7&L#`#0```!Q
M:P,`(````*9K`P`'````QVL#`"0```#/:P,`"````/1K`P`)````_6L#`!<`
M```';`,`"@```!]L`P`<````*FP#``@```!';`,`+@```%!L`P`'````?VP#
M`",```"';`,`)P```*ML`P`'````TVP#`!4```#;;`,`!P```/%L`P`(````
M^6P#``D````";0,`0`````QM`P`'````36T#``P```!5;0,`$P```&)M`P`/
M````=FT#``D```"&;0,`"````)!M`P`'````F6T#`!,```"A;0,``P```+5M
M`P`&````N6T#`!<```#`;0,`*@```-AM`P`,`````VX#`!H````0;@,`&@``
M`"MN`P`-````1FX#``T```!4;@,`&@```&)N`P`+````?6X#`",```");@,`
M)0```*UN`P`2````TVX#`!(```#F;@,`+0```/EN`P`)````)V\#`!`````Q
M;P,`&@```$)O`P`4````76\#`#,```!R;P,`"0```*9O`P`N````L&\#``<`
M``#?;P,`&@```.=O`P`(`````G`#`!@````+<`,`&P```"1P`P`+````0'`#
M``T```!,<`,`(````%IP`P`%````>W`#`#4```"!<`,`#````+=P`P`/````
MQ'`#``4```#4<`,``P```-IP`P`4````WG`#`"(```#S<`,`"P```!9Q`P`#
M````(G$#``@````F<0,`#````"]Q`P`*````/'$#`!````!'<0,`#@```%AQ
M`P`2````9W$#`!,```!Z<0,`$0```(YQ`P`X````H'$#`"$```#9<0,`'P``
M`/MQ`P!=````&W(#`%8```!Y<@,`,````-!R`P`U`````7,#`(D````W<P,`
M(0```,%S`P`)````XW,#`#0```#M<P,`#````")T`P`'````+W0#`!<````W
M=`,`0````$]T`P`3````D'0#`!,```"D=`,`"````+AT`P`$````P70#``8`
M``#&=`,`#P```,UT`P`=````W70#``<```#[=`,`"`````-U`P`)````#'4#
M``8````6=0,`!@```!UU`P`5````)'4#`!0````Z=0,`0@```$]U`P`S````
MDG4#`"D```#&=0,`!0```/!U`P`;````]G4#`!T````2=@,`(P```#!V`P`G
M````5'8#`!(```!\=@,``@```(]V`P`$````DG8#``\```"7=@,`"@```*=V
M`P`%````LG8#``(```"X=@,`#0```+MV`P`]````R78#`#\````'=P,`+P``
M`$=W`P`N````=W<#`"````"F=P,`+````,=W`P!(````]'<#`"X````]>`,`
M-P```&QX`P`X````I'@#`!8```#=>`,`'0```/1X`P!_````$GD#`#<```"2
M>0,`)@```,IY`P!@````\7D#`"P```!2>@,`6@```']Z`P`_````VGH#`$0`
M```:>P,`&0```%][`P`6````>7L#`!H```"0>P,`%P```*M[`P`K````PWL#
M`"X```#O>P,`@P```!Y\`P`E````HGP#`#H```#(?`,`(@````-]`P`V````
M)GT#`"L```!=?0,`.````(E]`P!1````PGT#`%0````4?@,`,@```&E^`P`L
M````G'X#`"P```#)?@,`+0```/9^`P`R````)'\#`"(```!7?P,`+````'I_
M`P`L````IW\#`"H```#4?P,`+@```/]_`P`N````+H`#`#(```!=@`,`.```
M`)"``P`S````R8`#`"<```#]@`,`(P```"6!`P`Y````28$#`#P```"#@0,`
M(P```,"!`P`F````Y($#`#(````+@@,`%@```#Z"`P`-````58(#``X```!C
M@@,`A@```'*"`P`)````^8(#`!H````#@P,`$````!Z#`P`0````+X,#`"T`
M``!`@P,`)P```&Z#`P`,````EH,#`%@```"C@P,`K0```/R#`P!Q````JH0#
M`(4````<A0,`2````**%`P`K````ZX4#`%P````7A@,`%````'2&`P`Z````
MB88#`#@```#$A@,`*````/V&`P`6````)H<#`!`````]AP,`PP```$Z'`P`D
M````$H@#`"(````WB`,`(@```%J(`P!"````?8@#`"````#`B`,`'@```.&(
M`P!<`````(D#`!H```!=B0,`$P```'B)`P`&````C(D#``H```"3B0,`!0``
M`)Z)`P`&````I(D#``@```"KB0,`!0```+2)`P`5````NHD#`!8```#0B0,`
M#````.>)`P`5````](D#`!8````*B@,`%P```"&*`P`B````.8H#`"@```!<
MB@,`$````(6*`P`/````EHH#``0```"FB@,`#````*N*`P`$````N(H#``,`
M``"]B@,`#````,&*`P`)````SHH#``X```#8B@,`"0```.>*`P`'````\8H#
M``8```#YB@,`"@````"+`P`9````"XL#``@````EBP,`#P```"Z+`P`&````
M/HL#`!,```!%BP,`%0```%F+`P`)````;XL#``D```!YBP,`#````(.+`P`)
M````D(L#``X```":BP,`#@```*F+`P`4````N(L#``H```#-BP,`!P```-B+
M`P`/````X(L#``P```#PBP,`&````/V+`P`*````%HP#``4````AC`,`#@``
M`">,`P`)````-HP#``X```!`C`,`#0```$^,`P`+````78P#`!@```!IC`,`
M!P```(*,`P`,````BHP#``4```"7C`,`!@```)V,`P`%````I(P#`"<```"J
MC`,`&P```-*,`P`*````[HP#`!D```#YC`,`%@```!.-`P`D````*HT#`!D`
M``!/C0,`"0```&F-`P`5````<XT#``@```")C0,`!P```)*-`P`"````FHT#
M`!<```"=C0,`!P```+6-`P`"````O8T#``(```#`C0,`'P```,.-`P`.````
MXXT#``@```#RC0,`%P```/N-`P`9````$XX#``4````MC@,`!P```#..`P`0
M````.XX#`"L```!,C@,``@```'B.`P`&````>XX#``<```""C@,`#P```(J.
M`P`9````FHX#``4```"TC@,``0```+J.`P`*````O(X#`!,```#'C@,`!P``
M`-N.`P`.````XXX#`!D```#RC@,`"@````R/`P`6````%X\#`!,````NCP,`
M$@```$*/`P`3````58\#`!4```!ICP,``@```'^/`P`'````@H\#`!$```"*
MCP,`!@```)R/`P`.````HX\#`#````"RCP,`"0```../`P`*````[8\#`!0`
M``#XCP,`!0````V0`P`"````$Y`#``L````6D`,`#@```"*0`P`/````,9`#
M``$```"=!0````````````!@"0``(`<``#,(``#<!P``L0$````````K!P``
MG`<``-X'``````````````````#0"@```````,8*````````BP,```````#U
M"```*`H```````!D`0``*@$``"D)````````XP<``#0$```O"0``E````.\#
M``"R`0``%@```+8)```9`@``+0@`````````````S`(``&X!``"Z"```8@$`
M`,T`````````6`(````````Q`P```````-0$``"3"`````````````"$!@``
M&P4``"L(``!I!0``K00`````````````````````````````M04``"H&``#Q
M"@``KP4````````.`0````````T```#[!0````````````#Z"@``,@H`````
M``!U!0``#PD``&P+``#&!0``;`,``)4#```K"0````````````#^"0``'PH`
M`-@'```'"```PP4```````#3"```Y@(``&4)``!,`0````````````!="@``
M`````'@*``#@`@``F`(``$(&``!9!@``````````````````D08``,\%````
M````H@```/X"``!5"0```````&8(``"(`0``?`L``/T*````````9@L``/8%
M``")`P```````,0(``!-`P``*P,`````````````80@```,(``"4!0``:@L`
M`)<(``","0``7P8``.D!```X!@``Q@$``-H&``#``@```````"(%````````
M(00``#L(``#.!0``5`(``%0```#F"@``8`0``#\(``!<`0``"P(``%\)``"E
M`0``!`L``,0)````````-0D``-T%``!_"0````````````"?"@``&04``*('
M```!`@````````````!?`@``*0(``+D$``#-"0```````"$*``#1`P``L@<`
M``D)````````%@,```$&``#9`P``BP0``'@"```W"@``)`L``#T(``#(````
M.0``````````````%00``#L+````````&````!D!``"H"```'PD``$4"``":
M!```&`$```````">`@``Q`(``"X&``!I"P``@0(``"4!``!U`@``!0$`````
M```Q!@``Q@@``)0'```.!@```P0``(<#```X!0```````&@`````````Z@H`
M`+@(``#[`0``@0,``*L*`````````````!0#``"C`@``;04``$<#``!#!```
M0@0``(,#``"A"@``(P0`````````````'`L```````!!`P``,@```&T*```>
M"P``W@$``````````````````!H(``"8"0``%0H``&X(``#B!P``R@```&`%
M``!@"@``H````)D%````````4`,``/$#````````O@$````````3"@``````
M``````">"0``2P$`````````````50<``$`"`````````````+$$````````
M```````````Z"P``N@```*D*``!("P``V@(``$`$``!7!P``&PD``.`*```S
M"P``(0@``+T(``#L!0``WPD``&P"``#G!@``2@L```````!&!0``U@D`````
M``"Z`P```````",(``"$`@``````````````````WP```"@"``#W````````
M`,4$```=`@``I`0``+8```#=!````````-<```"*"@``408`````````````
MPPH``'X$```:!@``X`<``.<`````````U`H``/@)``#\`@``<04``-,!``!P
M"0``SP8``/X*````````>@H``#<$````````(0```#P`````````.`@``!T`
M``!;!0``*04``)D$``#$!P````````````#F`0````````P'```&`P``````
M`!T%``#G"0``8`@``+$'``!0`0```````.(%```M"@``-0<``.L)````````
MY0,``'8)``!D!P```````,$```!$!P``[`@```````"T````9PD``"T&``#_
M!```D`4``!D)``"]`0``W@@``,T%````````8@@``(`!````````]0<`````
M``!F`0``!P(``.D%``#A!0``M0<``-L'````````=@```#4+``!7!```````
M`"<*````````.0D``'D+``!V!```O@@```8```#*`@``1@@``"T+``#2!@``
M`````&P*````````@`D```````#!"@``KP0``&4%``!H!P``Q@,``$4(````
M````&@<``&<$````````EP<``#T%``"J"@``+@0`````````````6@,```\%
M``!U````<`L``'(&``#)````APH``#@```!2"@``8````*0#``"H"0``Z`H`
M`````````````````.\"````````VPH``,X"```G!```C`H``&L%````````
M`````(,```#!"```B@@`````````````+@```&@$``#`!```NP(``#H%``#+
M"```PP8``#P(``!\!P``/`(```P+```="@```````)`$`````````````)H'
M````````900``````````````````%@'```5"```MP4```H$````````B0H`
M`*D'```Z`P```````$T*```^!P``.04``"4+``"=````4`8`````````````
M[@``````````````W`@``"H"```D!P``NP0```````"R"@```````"X"```L
M"P``B00``````````````````&\&````````=@,```````!X"0``APL````!
M``#4!P``^`,````````M!````````.D)``"6`P```````*`*``#V`@``4@4`
M`*L)```H"```:0```)`&``!;`P````````````"7"0``````````````````
M`````,P$``"O"@``A0,```````"2!0``9`````(+``##`````````$H"````
M````-0,``'T)``#S!@```````)$%``#C`P````````````!R!```3````!`+
M```O`0```````+`!``#J!P``>00``-@$``"?`@``Z@4``-L%````````X```
M`!H)```!"0``S`4``)T*``"6"@``?P8``&$$``"Q`@````````8+```/"```
M`````(8&``"0`P```````(H&````````A0D``$0)``#=!@``Q@0``-8&```B
M!```$@4``,(!```+"P```````/<*```]`0``H00``````````````````*<(
M``!Z`@````````<&``#+"@``4P4``$,'````````@`H``,(%``"2!```P04`
M`*<$````````0P(``',*````````QPH``)4&``!F!```6`$``,@'``#9!```
M!@4```````#K````"0L``"\%````````5@@``&,(``!"`P``"@H``&\$````
M``````````````!L!0``P0,``*0'````````50```*@$``#.!```QP```/("
M```?`````````'$!````````S0<``(8*```A!P``90L`````````````-P,`
M``````!!"P```````'@#```F!@``L`4````````6`0``4`(`````````````
M``````````````````````@#``"V!`````````````!#!0``;P<`````````
M````000``````````````````)0#```X`@``O04``$8&````````QP$``*L%
M``!\"0```````(4```!A"0```````-@(````````3P,```````#8`0``Y`@`
M`)(#```C"0``(`4``*,'````````EP8``),$````````Y`0``/,(````````
M`````*X%``!C`0``!0L``+`(``"G!@````````L%``"`"P``UPD`````````
M````H0```,P!````````10,```0&``!`"0``X`0`````````````?P,`````
M``"O`0``S`<``(T"``","```Z`<```````!Q!@``Y@<```T'````````````
M`-$$``![!```Z0```&\#``!T!@`````````````O!P```````*0%``#]````
MO`(``*X)``"P"0``7P<```8)`````````````#\&```Q!P``,`,````````@
M`@``Z0H``&<+``"O"0``_`H``)H#``!C"@``-@<``"\(``#U!```]`8``&@!
M``"0"@``=@(``(`$```\"@```````)@#``!1`0``^`@````````2!@``<`<`
M`%@$````````$P``````````````B0(``.P*````````O`8```````"`````
MW@D``,,'``"M`P``%`0```(```#W!0````````4```#:`P``DP,```````#-
M`@```````$D!``#K`0``:`8``%X#``#;!@``GP```*P)``!E!@``?@(`````
M``````````````````#5`P``R`@``/\#``"O`@``\@<``,\$````````\P``
M`)4%``#'!P``&@0``,4'``"0`@``AP@``)8(````````@@$``"0*``!'"P``
M'@```+L#``#W`@``5P$``,<%``#P`P``5`8``.T%``!G!0``=@@```````"7
M`@``,@D``.$'````````J`4````````H!P``N0<``$8*``"_!@``3P$`````
M``"V"```C@@``$(%``"Z!0``$0D``!D```"B"0``WP8```<+``!E````3P0`
M`!0'`````````````#D*```.!0``7PH````````:`@````````@'``"%`@``
M!`(``&\```#/"0``+@4``($+````````C@<```````!``0``10L``.4*``!0
M"P``%P$``!L"``",````^@```!(*``!2"0```````$<(````````!PH``$H*
M``"+"```YP4``+H&```_`0``APD``.(#``"R"```S0,``!<*``">!```/@H`
M`&T#``"""P``+0<``(`#``"H`0````````````"A"```<0L``"4&````````
M`````.0%```!`0``*`$``````````````````$`'```"!```!`,``'$*```=
M"```$PD```````!N!P``]`$``+`"```M`P``P@8``.X*```]!P```````#D(
M````````W0@`````````````X@(``-<!``!+!```O`H```@+````````````
M`````````````````'(*`````````````,\!``#3`@``-P$``'X+``!"`0``
M`04``,0!``!.`@``;0(```P%``#<!0``=`<``%\$``"*`````````+(&```^
M"P````````````#Z!@``N`<``(@(``````````````````!T"P``H04``/<!
M``"("@``IP4``!8&``!-````2PH``!T!``#(!0``^P@``-D"``!<````"`(`
M`(,+```-!@```````.0'``#""```G@4``","``".!@``3`H``%D!```B"```
M_````$0"``#R`P```````/(*`````````````(()```G`P``>P(``"D&````
M````Y`D``$\&``!I"0``,0````,#``#V`P``?P4``*D(```'````-0(```D"
M``!D"@``,P8``#X````B`P``_0$``)8!```<`P``L`<```````!2!P``!0(`
M``````!4!0``6@H``````````````````'L(``"F"0```````#P!``!;"```
MD0H``&\!``#_`@``_`8``-(!````````DP$``*P"```\!0``6@(``.H!``!C
M!@``70,```````````````````````!`"````````'H#``!B````E`D``+4&
M``#["@```````(L!```9`P``&`4``-,$````````K`@``!L+```9"P``````
M`&L*``#[!@```````)\'````````OP$```````!R!P``J0(``/`*```U````
MZ0,``%X"``":`````````/`)``````````````````#H!```30(``.,%``#E
M!@``9P,````````/`@``V`H``"4)````````1`0``"D'``!Y`@``````````
M```;`0```````&$!``"("0````````````!C"P``8`L```$#``#O"@``/@D`
M``````")`0```````,,"``"#!0``P`@`````````````VP@``/<)``!P"@``
M)@L```````#O``````````L'````````E0(````````4`````````!$"``"&
M!```H@0``#T+`````````````+4*``"X!@``*@D`````````````)04``$$&
M``#2!0``"0@``,()``#'`P``7P4``,D)```-"@``:0<````````+`P``!```
M`.@%``#,!@``>P4`````````````T@(``-@```#^`0``%@D```````#3"@``
M4P@```````!S!@``5@,``$0%``"W`0``'P0``,`'``"N`P``CP```&\(````
M`````````$P+``"J!P``;P4``!<+``"@!P```````/8(``!W!```7@```&(#
M``#>!0``CP4``-\"``#*`0``GPD``+D!``"(!0``N`````T$``#_!P``````
M````````````U`8``#8"```A`P``O@H``,D$``"A!P``EP0``.X&``!U`P``
MC0H``%T)``"F`P`````````````;`P```````+\)``!Y!@``-`(``#8)````
M`````````%D(````````E`$```````!G`````````&@%````````H0$`````
M``"L!```4@8``-4"``#C"@```````#`%```1"````````(T%``!4"P``````
M`/D)``"^!0``G@8``)4'``#>````````````````````?0L``(,&``#Z!0``
M`````!4````P`@``00(```````!)!@```````!0&``!G`@```````+\$``!@
M`0``D0(``.L(```_`@``NPD``````````````````````````````````-D*
M``!_!```\@D``'T```"W!@``F@4````````M`@``708``(@'``"1"```B```
M`'8+````````!@$```````#=`0```````+@#``#S!0``R`D``/0%````````
ME@<``"D!``!?"P```````(H%```"`@``E0`````````+"0```````.L$``#1
M!0```````%$$``#4````[@(```````#4`@`````````````="P``IPD``#0)
M``#V"0```````(`&````````B`8``"H$``#N`0``N@<``'D%``#/"```[P<`
M`.@!``"5`0```````+L%````````A`D``"(&``#%"@```````'L&```F"0``
M=PD``/@&``!>!P``&0H``$<*``"H````[00```````!(!0````8```````!>
M!```^P```+P$```1!0``````````````````(PL``"0"``#5!@``4`<``"8!
M````````M0(``',!```H"P``;0$``&,)``#Z"```*@4``*L'````````````
M`+8!``#(!```U@H``"0#``#*"@``3`,``(H)````````\`@``'``````````
M``````````!L!```%P(``"<&``!_!P``A@L``/,'``#T"@````````L````^
M`0``-`L``$D````[!@``S`H``%@%```T`````````-P#``"I!```$PL``'D(
M``#M`0```````.H(``"-!P```````)H(```]!```1P$``)@%````````'00`
M``X"```9!```>`0```````"S`````````*,$``#&````3`@``,(*````````
M$@````````#<`0``=00``"4"``"C"```V`(``'4'``!("@``ZP4``$D$``"B
M`0```````"P#```-"```4@(``%(```!6`@``;@4``%L```!)"```3@,``&8"
M``#H`P``K@<``!<(``````````````````!3`@``R`$``%@&``#;!```````
M`$$)````````%0,``&D$``"T"0``CP(```````#*!@```````'$'````````
MT`,``+($``"J!```<PL``-()````````(04``"H+``!#`P``<@D```````"D
M!@```````,0*``#6````N@0``((#``#?`0``G0<``$T'``!_"```.00``!,$
M````````"P8``.,!````````<P(``#P$``#Y"@``9@```)T#``!D!0``````
M`'@&``"^!```'@(```````!F!P``?@4``-`&```I"P```````.@"``#-`0``
M0PD``&T&```3!P````````````!W`0``````````````````BP````````"O
M`P``70(``#,$````````````````````````B@<``$D%``"C"@``)P4`````
M````````>`4``.,```"8````$@$`````````````;`$``*<"``"5"@``?```
M`"@$```[!`````````,'```$"```$P8``"X'``!5!0``'`0``/T%````````
MK@(``/0#``#+`@``+`$``(D%```K!0``L@4``"H*```H!@``+@L``!@#``!M
M!```DPD``$$%``!9"P``&`@```````"!`````````#8%``!C`P``````````
M```6!0``<@L```````"<`0``R0,``%8&````````$P$``%D"``#1"@``K`8`
M`%4#```Z`0```````.8````$!0``9@4````````6!P``N0(```````!;!```
M:`(``/`&````````'P<``'X```#S!```T`<`````````````EP,````````'
M!0``!0<``(L&````````2@4``-X$`````````````.`)``#^`````````/L)
M``#E"```M`H``/0'``"2`@``MP```",*``#-!@``?P(``/,)````````30D`
M`&,$``"B"```````````````````@0H``#L)``#2!````````%<(``"E`@``
MA`$``/$`````````Q@(``$L`````````Y@0``,\'````````K0D``/($```-
M"P``[@,`````````````C`8``$<````?"```<`,```````"I`P``<`$``*@'
M``".`0``#`@``(('```U!@``W0(``#D!``````````````````"F`@``````
M`'<#```E!```+P8``-\#```@"0``10```(L%``#W"```X`4```````!("```
M`````!,#``!8`P```````!`&``!Q"0````````````"W!```=PL`````````
M````L04``$T$``!K`0```````%\#``"!`0``A@```&4(````````:@,``#H(
M``",`@``7@4``%`$``!""@``[0```#T)``#P!P``.@8``*0)````````?@H`
M``````#T!```````````````````FP0```````"P`P``#`0``/$'``"&"```
M$`(``!L*```\"0``CPH``/D!```2"P``I@8``'T&``!$````1P0```````!7
M````J@@``$(```"M````?`0``+0&``"$!P```````%H'```6`@``\P(``)$)
M````````F@$```````"Q"```'@8``$T!```1`P``&`0``$()``"\!0``````
M`+4#```:`0``"`0```````!E`P``/P4```````#(`@``?0<``*X$``#5"@``
M/@@``)L&````````4P8``#`&``!*!@```````'8&``#?!P`````````````4
M"@``#```````````````.`D``+<'```>!0``1P(``*D!``!Y"@``P````.\&
M````````"P$`````````````)`8``+(`````````A00``'X!``!("0``?PH`
M`$D*``"F`0``%P8```````#>`@``JP(``!`)``#_`0``10H``.()````````
M>@8```@&```B"0``>@D``#,!``!+"```3@$``!0"`````````````,8&``!V
M!P``>0<``&$```````````````````#0`0``!P$``)()``!5!@``YP@``$,`
M``"&"0``!@@````````7!0``3P<``%,'``"/`P``,P,`````````````5@$`
M`$@!``#U!0```````.@&``!`````D0$``(H"``",!0```P```%4(```X"P``
M'P$``$H#``"'!````````/(!````````Z08`````````!P``6P<``/@'``"<
M"```1@```(8#````````F@D``.`&``!B"0``````````````````-@H``/<&
M``"/!@```````$$'`````````````%(#``#7"@``CP@``%(!``"K````T`@`
M``D```"'!@``M@,``#@$``#Q!@`````````````(!0``>0````\+````````
M'@0``#0&```%!@``C0@``-$(``#,"0``M`(``+L'```S!P``C@````````#K
M!@``*P$```````"&`@``1@<``,D(``!#"@``^`4``-4'```@`P``VP(```\$
M````````"0$``'P*````````0PL``#((``"O!P```@<```X*``!M!P``#@``
M`.<$``!3"@``>@````````"E!0```````"@)``""````70<``'0)```Y!@``
MR@D``#\$``#E!P```````.<"```;!P``LP4``-@%``";"0``!PD``,D&```$
M"0``P0(```P!``"V`@``50H``+D```"U!```MPD``.$```!<`P```````#L%
M````````V@$``#4!```A`@``]0$``&L#``!>"@``]@<`````````````C0$`
M`````````````````*`"``#O!```-P@``%<&``"-!```K@H``$0#```[````
MZP<``.(*```<"@``"@````````#7!@``7@$``/4`````````UP0```````#L
M!@``"`H```````##"```8@8``&P(````````E@0``-\$```!"@``$@@``&H$
M``"+"@``(0$``)4(``"%!0```````.$*```V`0``6@L``"`(```."```````
M`&L$``#E!```I0H``&,'```E"@``F0D`````````````6@D``&H(```8`@``
M3P4``$X$``#A!```OP4```````!T"```:0H``%8$``"Z"@``^P0``/T#``#2
M`````````/8&```K!```9@D``+T&```@"P```````-@#``!9`P``^08``,@*
M``!L"0``'@@``,X'``!5`@``)`$``','``!%`0``^@,``"H#``##`P``G0$`
M``````!#!@``+P0``)L``````````````$X+``"A`P``CP<``'0*``"`!P``
M````````````````<P@``#\)```M"0``P`H```````"]"@``(@L```D'````
M````L0,``'(`````````XP8``$H$``"V!@``(`````4)```G"P``X@``````
M```@!```````````````````K0H``*8'````````6`@``)D&```V"```````
M``````!)"P``$08``)P)``!J!@``````````````````*PH``+8%``#F!0``
M@@@```````!<"0``EPH``*T(``#H"````````&D&````````FP(``"4'``#3
M"0```````-$'``````````````````!,"0``J0````````"D"@``FP4`````
M``"F"```/`L``/4*````````-0@``-0#````````!@8``+T$``#-!```!00`
M`&D"``"L!0``5@H``'H!``!Z!P``Y@,``!H```!S````HP4```````#Z!```
M:0@``'<*````````"@L``*8%``!D"P``,`<```0!``"H`@```@,`````````
M````8@0```````!O`@``+`D````````Q"P```````.X$``#!"0``E`@``-(#
M``#J`P``TP4``/T"```````````````````#"0``<0(``*<!``"C!@``````
M``````!F`P``$@,``,\#````````P@```$8#`````````````+8'``"#"0``
MKP8``"D#```8"@```````'$(```#"P```````',)````````ZP(``%H!``!8
M"@``E@D``&P&```F!P``NP```#$"```?!@``5P4``*H"``"(!```)P(`````
M```L`@``.P(```````"<`@`````````````*`0``$0``````````````"@8`
M`,('``!3"0``2P(``$X)``"0!P```````#```````P``&P```+<#````````
MN04``#`*``#U`P``C`<``/D(``#T````]`@```````"S"```,@L``'L)````
M`````````&$&````````F`8```T#``#M`P``1P4```````#3````@PH``.X(
M````````!P,``*4'```.!P``(P8``!P'``"."0``H`@``-H'``![!P``;0@`
M`&X```!/"P``O````$L%````````=0$``/H)``#!`0``4P```'$$```V"P``
MM0D```````!(!```U00```````!K`@``^P<```````!R"```V04``!<$``"P
M!```H0D```````#Z`0``R`,``/@"````````K`$``#(#``"'!P``9`(``(\$
M``#+`0```````$L+``"F"@``3`4````````G!P``)0,``+8*``#`"0``5P(`
M``````"@`0```````-<"``#]"0``S@D``%X(````````90(``.4%``"F````
M,0@``#\```!P!````````$("```F!0``2@```%8'``#E"0``GP$```````#+
M`P```````/T(``#N!0````````````")"0``&0<``'T#```X`P``'`@``.P'
M``"1!P``]P,``/0"``!9`````````&H'``#P!0``B`,```````#\`P``.@0`
M`-0(``"#"```'@D``-X*`````````````&H!``#/`@``!@<``,0%```7!P``
MDP<```````!A"P``.@(``)`!````````3@<``$T%```\!@``S@,``!$+````
M````;`<````````R!````````#D#``!A"@``S@@``-$)````````W0D`````
M``#'"0``H0(```````!3"P``7`H``,@&````````9@8```````#7"```````
M`/(%``"C`P``*P8``!,"``"6````T`````````"/`0``:P<``.$!````````
M7P```+,*```^!```K04``",!```""```;PD``%,$```&!```.@``````````
M````6`L```````"$"P``%08```````!1"````````*`&```8"0``````````
M```0!0````````````!N!@``N`D``)L'```V`P``#@D``+0(``"`"```,@(`
M`%,#``!R!0``=````(0````T`P``C0,``-4)````````+`8``(<"```]!@``
MF0(``'(!``!)"0``+@$``/D%``!J"0```````*H```!V`0``(@<``,$$````
M````M`0``/\&``"!!````P8``)T&`````````````*`#````````GP8``$('
M``"M`@``-@0`````````````9`0``'`%``#0`@````````````!1"0``4@L`
M`````````````````$,(``!J````704``*D)``"3"@``H08``-8"```N"@``
MH@H```````"0"```8P4``````````````````!,%``"4"@``E0D``#`+````
M````/@(```````!(`@``A`4``*4````\!P``F@8```````#!!P``8`<``"$&
M``"7````8P(``"$)``#E`````````%$'```O`@```````,4!``!6!0``X`$`
M`/4"`````````````%L&``!9!```?P$```D*``"Q"0``2@$``(T`````````
M[0<``+D*``!:"```500``.T&```]"@```````,D!``!\!@```````#`$````
M`````````%P&``"9!P``8@<``-D```"%`0`````````````:"P``700``+\(
M```>!P```````)P%```#`@````````````!E`0``:PD``&X+````````[`(`
M``````#``P````````````"Q````F`H``$`%`````````````+X'``#@`P``
M`````/4)``";"@```````%0*``"H"@``O`@``%0(```Z"0````````````#\
M!0```````#8`````````2PD``%P"```_"P``_`@``+P'```4!0```0L`````
M``````````````````"=!```"````,X`````````G0@``%X&``!$"@``````
M``````!."```Q0(``````````````````$0+``!%!P``%`@``,0```!/`@``
M,P```/@*``">"@``9P$``/8!``#$!@``B0<``*P#``"E"```/`,```````"G
M!P``^P(``+0'``!T!```90H``($)``!:!@``@@4``.H&```C!P``U`D``/@$
M``!Z!```'`$``+@$```>"@``;0```-((`````````@D```````#0!```S0@`
M`&X#````````4`H``!4"````````(@(``(`%```W"0``@0@``!P"``#J"0``
M[`0````````U!0``_P```,4#``!4!```0P$``/@```"B`P``1@0```````#D
M````+`0```````#H`````````&D!``!1`@``VPD````$``#J`@``7`0``&T+
M````````.@<`````````````EP$``'\````]````2`<``&(%``!*"0``%PD`
M`$P&``!>"0``4P$``!`#````````'`D``*P*``"-"0``=`,``,`%```R`0``
M+PL``*T'`````````````$8)``#*!P``#0(``.D"```=!@``RP4``(D(```4
M"0```````/T&``#)!0``@04```````#Q"0``R@@``!('``#P`0```````-L#
M```*`P``,PD``.(&``"/"0```````)P*``#-"@````````````!:!0``````
M``````"Y"````````*("``"S!@``X0@```````#``0```````+P!````````
MI`@``&<(``"<`P``?00``-8$````````@08``+L&```%!0```````.$"``"\
M"0```````(4&``"N"```'0D``!8+``!?`0``*0H``#D"``"J`P``<0``````
M```>`0``)@H``$\(``#'"```G0D``.0"```0````>`<```````"*`P``U@@`
M``````"4!```5PD```````"%"@``'0,``%T(````````Q@<``+T```!4!P``
MQ`0``'<&``#9!P``@P0````````I````>@4``/P)````````0`,`````````
M````7@L``*0"``#P!````````-,#``"'!0``G@@`````````````(@$``.D'
M``!%!0```````#('``"S!```I0D``(@"``"8!```````````````````Z00`
M`"0```"9`````````)$```"#`0``R0(``$((``"9"@``O@```"0%``!]"```
MV@```/\*``!8````JP@``-('``"$"```@@H```````!G!P``N`$``!X#``!B
M`@``$@D``(D&````````"08````````_!P``M`4``$@&````````@P<``#T"
M``#J!```)@````````#1````_@8```````!N`@```````"(```"4`@``````
M``D$```9"````````!,(``!'!@```````)H"````````>`$``"D$``"J!0``
MN@$```<$``!U"P``K`<``"P%````````_P4``*L$```O`P``````````````
M````60H```````"8`0``&@H``-P)````````2`````````#A`P``LP$``+\`
M``"J"0``3`(```````"8"```L````*,!````````=`$`````````````A`H`
M`,,)```0!```YP<``-,&``#+!```_@,```T!`````````````*0````W!@``
M!@H``"<)``#>`P``I`$``#X%``"?!0``4````)8"````````:@4``%$%``#]
M!````````.,(``!W`@``IP,````+````````<@,``#0(``#>!@``(0L``+`&
M``#2"@``C@,``'`"````````K@```#4*```?"P``````````````````/0,`
M```````````````````````%"@``#P<``$H'``!1"P``F`<```````!=`0``
M!P<``,H%``!7"P``C@H``%T```#L"0``LPD```````#%!0```````&X)````
M````7`4``*(%``#@"```W`8```````!<!P```````/<$``":"@````````\`
M``!B"P``@0<``.D(````````^0```+L(````````U`4``'H(```0`0``A0@`
M`-`%````````%P,``$H(``#%!@``I08``!\"``#M"@````H``(X$``!;`@``
M?0$``.\(``#8!@``QP0``"8"``#O!0``O0D```````"X"@``!0@``)('````
M````D@```(8!````````>0,``-D)``"<!``````````````"!0``80(``-T*
M````````.P$``````````````````*\```!D!@```````,4```#A"0``-`<`
M`'8*```1"@``8`,``-4!``#C"0``ZP,``%L*``#U!@``"@4``,P(``"^`P``
M=P4``),%``#P`@``+0````````!U"0```````),&`````````````$<'``#1
M`@``^0<``!\#`````````@$````````+"```)@0``/D#``#R!@``$0$``)(!
M````````#`,``+\#``"3`@``&`<``.,$``!J`@```````%<#``!W!P``H`D`
M`%H````&`@``#P,``/L#```,!@```````'@```!0!0``#PH``+P#``!`!@``
M?@8``"@#```)`P``.P,``)`)``!N!``````````````Q`0``%0D`````````
M````*0@````````E"```N0,``)L#``"E`P``_0<``#@!```P"0``[`,`````
M````````*@<``!`(``#7!P``C`0```4#````````/@8``"4```#,`P``:P@`
M`,0#``#Q`@```````%\(``#M"```"P0``,$&``!^`P````````D%````````
M``````````!K!@```````/X%``"0````6PL```````"+"0``VP```!8$```;
M!```MP(``(("```,"0``FP@``&$#````````3PH``&`&```.!````````!$$
M``")````RP<``,<&``!H"```[@D``+T"``#<!```B`L``#H*``!Y"0``"@@`
M`,8)``#?"`````````\&`````````PH``-,'``"4!@```````&@)``"1!```
M`````/$%``!,!P``V`D```X#``!&`0``1`@``)\(``!H`P`````````````(
M"```%0$``/P!````````LP<``,\*```6"```AP$``"`!``">!P``5@```)4$
M```;"```P@,``,4)``"^!@``<@(``/\(````````D0,```````"-!@``0`L`
M`(0$`````````````/,#````````,`@``!P%``````````````````"M!@``
M=`4``,4(``!7"@```````.\!```K`@``,P(`````````````3PD``)(&````
M````YP,``$X%``!["@``V@@``+T#``!M"0``J08``'@+``![````BP(``.((
M``!%!@````````````"T`0```````&0(``#Z!P``3`0``$$!``"6!0``1`$`
M`"H(``#^!P``Y`,``%H$````````30@``!H#`````````````/8$``"C````
MO0<``,H$```H````4@@````````,`@```````'4&``#D`0```````*T!```$
M!P``(`H``.L*```1!P``\PH``!4%```2`@``DP```%P+``#\!P``L08``"T!
M``!B"@``[@<``````````````````.$&``"9`0``S@$``'`&``!S`P``KP@`
M````````````(P```.(!````````W0```'L!```:!0``[`````````",`P``
M+04```````"C"0``0`H``$\`````````P`8``%4!```Q"@````````````#*
M`P````````````!)`P``"`$``'<(``"<````N08```````!O"@``&P8``/,!
M```D"0``O@(``/8*``#L`0``LP(```````"R`@``YP$`````````````J04`
M`!@&``!.!@``"@(``*(&```5"P```````%D'```F"```S`````````#5!0``
M>@L``/P$`````@````4``)D#```R!@``L0H``.\)``"?`P``"`D``-H*````
M`````````"P*``#C`@```````!0!```=!P``#P$``"P`````````````````
M````````RP8``%`(```B"@``A0<```````#+````)`@``&,`````````````
M```````$"@``#04``!P``````````````/$(``!Y`0````````````!-!@``
MUP4```````"&!0``!`0```````"["@``5@D````````4"P```````+0#````
M"0```````$8"``".`@``)P@```````!8"0``A@<``(X%``">`0```````!\%
M```!!P`````````````0"@``OP(``$T+``!N"@```````+D)``!D"0``````
M``````"J`0``5`,```````#5"````````/((``!1``````````````#_"0``
M6P$``)8&```#`0``+P```)\$``!F"@```````%$*``"_"@``YPH`````````
M``````````(&``"G````?@@``,X&``#M`@``JP$``$<)``#:!0``W0,``/<'
M``#E`@``-P(``,,$``!S!```-@8``,("````````:`H``/D$``!\`@``````
M`,\`````````K@$``/8```!\"`````````````#."@```````-8%```!!```
M9P8``'4*```*"0``BP<``%D)````````-`$``$$(````````VP$```T)``!1
M`P``100``-`)```W!0``D@@```$(``##`0```````&$'````````"@<``#\*
M``#^!```,0D``#L'``""!@``2P<````````N`P````````````">````-00`
M```````K"P``4`D``,($``#9`0``10D``-8'``!@`@``U`$``#<+``#J````
M`P4``"P'````````U@$``.4!````````^0(``$$```"=`@``3@H`````````
M````?@D``!D&``"@!0``50L``/0)``#Q!```<0,``)L!``"L````````````
M```_`P``$@0``'T*```P`0``&`L``+\'````````M0@``)D(``!$!@``N@D`
M````````````B@$```````#X`0``N`(```````!L``````````````#R````
MLP,``*X&``!P"```90<``.($````````(P,```````"@!```.`<``"0$````
M````9`,``/H"````````L@D``-$&``"J!@```````#$%``">`P``M0$``*@#
M``"W"@``@@0``.T)```G`0``%P```.0&`````````````'X'````````````
M`'P!``!O"P``Y@@``',%``#:"0```````$(+```["@``:@H``%8+``!)`@``
MO@D``(0#````````UP,``%($``#6`P``W`H``%0!````````70L``#0%``#<
M`@``I@0```````#Q`0``:PL`````````````M0```,<"``!U"```+`@``+@%
M``"2"@```````"\*```C!0``9PH``!4'``!I`P```````*<*````````=`(`
M`#0*``#:!```J`8```````!&"P``.`H````````Q!```G`8``%P(````````
M?`4``.0*````````W0<``-4````@!@```````-D&````````L@,``-P```!]
M`@``NP$``-\%```^`P``Z`D``*L#```H!0``#`H```(*````````A0L`````
M```."P```````/```````````````'<`````````B@0```````#?"@``R0H`
M``````!.````MP@````````F`P``R0<`````````````RPD``!P&``!["P``
M-P<``&$%````````-P```.8)``"'````I00``'T%``!!"@``2P8``-$!```+
M"@``2P,```````#9"````````)<%``"Z`@```````'8%```Y"P``)P``````
M``![`P```````"X)``!K````JP8``(P!````````$`<``"X(``!;"0``20<`
M`"H```#^"```,P4``$@#````````?PL``'@(``"#`@`````````````K````
M%@H`````````````,@4``#,*````````?`,``(`"````"````````%D%``"P
M"@``5`D``&@+``#F!@``.0<`````````("`@("`@0V,Z(``@("`@("!4;SH@
M`"`@("!$871E.B``("`@($9R;VTZ(``@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@
M*'EE<W1E<F1A>2D`(%-U8FIE8W0Z(``@870@`"!I;B``(B5S(B!I<R!N;W0@
M82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S
M(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`(P`E
M+C)F34(@+R`E+C)F34(@("@E+C)F)24I`"4N,F9-0B!U<V5D(&]F("4N,F9-
M0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!-97-S86=E<P`E
M9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60@;65S<V%G
M97,@:&%V92!B965N(&1E;&5T960N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P
M86TN`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`"5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M+@`E9"!T;R`E9"!O9B`E9"!-97-S86=E
M<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`
M)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E
M<R!A;')E861Y(&5X:7-T<RX`)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@
M9F]L9&5R('=A<R!N;W0@<F5N86UE9"X`)7,@870@)7,@)7,`)7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R(&)E
M:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"X`)7,@:&%S
M(&%C8V5P=&5D+@`E<R!H87,@8V%N8V5L;&5D("(E<R(N`"5S(&AA<R!D96-L
M:6YE9"X`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="X`
M)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@(B5S(BX`)7,@
M:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S('1E
M;G1A=&EV96QY(&%C8V5P=&5D+@`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K
M('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`
M)7,@;F]T(&9O=6YD+@`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`B)7,B+@`E
M<R!T;R`E<R!O9B`E<P`E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O("(E
M<R(N`"5S('=I<VAE<R!T;R!A;6UE;F0@(B5S(BX`)7,@=VES:&5S('1O(&UA
M:V4@>6]U(&%W87)E(&]F("(E<R(N`"5S('=I<VAE<R!T;R!R96-E:79E('1H
M92!L871E<W0@:6YF;W)M871I;VX@86)O=70@(B5S(BX`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P
M<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA
M=&EO;BX`*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S
M8W)E96XN*0`H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H
M92!C;VUP;W-E('-C<F5E;BXI`"A(5$U,*0`H4&QA:6X@5&5X="D`*%)E='5R
M;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H
M86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@
M<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*0`H4V5N9"!M97-S86=E(&%F
M=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N
M9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D
M+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S96QE
M8W0@861D<F5S<RAE<RD@*@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@;65S<V%G
M92!H87,@8F5E;B!D96QE=&5D+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`
M,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`Q(&UE
M<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@
M87,@<W!A;2X`,3`P(&-H87)A8W1E<G,`,3`P,"!C:&%R86-T97)S`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#(U,"!C:&%R86-T
M97)S`#4P,"!C:&%R86-T97)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D`$$@;&%R9V4@:6UA9V4@;F%M960@)7,@:7,@871T86-H
M960@=&\@=&AI<R!M97-S86=E+@!!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H
M87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE
M(')E8VEP:65N="X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A
M:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!
M3D0`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O
M;0!!8G-M:61D;&4`06-C97!T(&%N9"!A9&0@=&\@;7D@8V%L96YD87(`06-C
M97!T(')E<75E<W0`06-C97!T960`06-C97!T960Z(`!!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S
M=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N="=S(&YA;64Z`$%C8V]U;G1I
M;F<`06-T:6]N<P!!9&0`061D("5S('1O(&UY($%D9')E<W,@0F]O:P!!9&0@
M0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D
M9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R
M;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D
M9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@
M<&%I<@!!9&0@<V]U<F-E`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&AI<R!T;R!M>2!C86QE;F1A<@!!9&0@=&\@861D<F5S
M<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!T;R!M>2!C86QE
M;F1A<@!!9&0@=7-E<@!!9&1E9"`B)7,B(&%S(&%N(&%T=&%C:&UE;G0N`$%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES<&QA>2!W
M:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@:&5A9&5R
M(&]N(&$@;F5W(&QI;F4I/"]E;3X`061D:71I;VYA;"!I;F9O<FUA=&EO;B!C
M86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I
M;',`061D:71I;VYA;"!M97-S86=E(&1E=&%I;',`061D:71I;VYA;"!M97-S
M86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`061D:71I;VYA;"!M97-S
M86=E(&5R<F]R(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E
M=&%I;',@8V%N(&)E('9I97=E9"`E<RX`061D<F5S<P!!9&1R97-S($)O;VL`
M061D<F5S<R!";V]K<P!!9&1R97-S97,@=&\@0D-#(&%L;"!M97-S86=E<SH@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI
M;F4I/"]E;3X`061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H:7,@
M:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O
M;B!A(&YE=R!L:6YE*3PO96T^`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO
M;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI
M<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!
M;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R
M;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL(&UE<W-A9V5S(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N
M92!-0D]8(&9I;&4Z`$%L;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R
M(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T
M960N`$%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M
M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T
M960N`$%L;"!R:6=H=',@;VX@9F]L9&5R("(E<R(@<W5C8V5S<V9U;&QY(')E
M;6]V960@9F]R('5S97(@(B5S(BX`06QL;W<@1F]L9&5R($-R96%T:6]N/P!!
M;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O
M>#\`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)
M35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)
M35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T
M92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%L=&5R;F%T:79E('!A<G1S
M(&9O<B!T:&ES('-E8W1I;VXZ`$%L=V%Y<P!!;'=A>7,@<V%V92!A='1A8VAM
M96YT<P!!;65R:6-A;B!386UO80!!;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T
M=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0('-E
M<G9E<B!S86ED.B``06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;B!U;FMN;W=N(&5R<F]R
M(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N;W1E+@!!;B!U;FMN
M;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K
M+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS
M=V5R`$%N<W=E<F5D`$%N<W=E<F5D(&UE<W-A9V5S`$%N=&%R8W1I8V$`06YT
M:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T
M`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!&:6QT97)S`$%P<&QY($9I
M;'1E<G,@=&\@)7,`07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O
M;C\`07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L
M87EE9#\`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA
M=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&
M:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!D96QE=&4@=&AI<R!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N/P!!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\`
M07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_
M("A4:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!D;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S
M/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E
M('1H:7,@871T86-H;65N=#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE
M<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@
M;65S<V%G92!A<R!I;FYO8V5N=#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\`07)G96YT:6YA`$%R;65N
M:6$`07)M96YI86X@*$%235-#24DM."D`07)R:79A;"!4:6UE`$%R=`!!<G5B
M80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]0
M86-I9FEC(%)E9VEO;@!!<VL`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L
M=6UN<P!!='1A8V@@1FEL97,`071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'4"!P
M=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\`071T86-H960@1FEL93H`071T
M86-H960@9FEL92`B)7,B(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L
M:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+@!!='1A8VAE9"!I<R!A(')E<&QY
M('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N="X`071T86-H;65N=`!!
M='1A8VAM96YT("5S(&1E;&5T960N`$%T=&%C:&UE;G0@26YF;W)M871I;VX`
M071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N="!T>7!E
M`$%T=&%C:&UE;G1S`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!
M='1E;F1E97,`071T96YT:6]N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI
M80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V
M92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@
M1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE
M("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VEM<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P
M.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S
M;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T
M:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N
M=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N
M('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`075T;VUA=&EC86QL>2!S:&]W
M(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I
M;B!M>2!A9&1R97-S8F]O:S\`079A:6QA8FQE($%D9')E<W,@8F]O:W,Z`$%V
M86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`
M0D]&2"!%>&-U<V5S`$)A8U]K('1O("5S`$)A8VL@=&\@)7,`0F%C:R!T;R!-
M=6QT:7!L92!-97-S86=E(%9I97<@26YD97@`0F%C:R!T;R!4:')E860@1&ES
M<&QA>0!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A9"!L;V=I;B!N
M86UE(&]R('!A<W-W;W)D+@!"860@;W(@;6%L9F]R;65D(')E<75E<W0N(%-E
M<G9E<B!297-P;VYD960Z("5S`$)A9"!R97%U97-T.B`E<RX`0F%H86UA<P!"
M86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D
M;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A
M<V5L:6YE`$)C8P!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;&]W(&ES('1H
M92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L86-K;&ES=`!";&]C
M:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3
M971T:6YG<P!";&]C:R!4>7!E`$)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A
M9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/P!"
M;V1Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC
M:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O
M=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G90!";W1S=V%N
M80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U
M;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-204TM340U
M(&]R($1)1T535"U-1#4@<F5Q=6ER97,@=&AE($%U=&A?4T%33"!P86-K86=E
M('1O(&)E(&EN<W1A;&QE9"X`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M`$-?96QL(%!R;W!E<G1I97,N+BX`0U]H87)S970`0V%C:&4@:6YI="!W87,@
M;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O
M;@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<BX`
M0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z(`!#
M86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F
M('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="!M86EL8F]X+@!#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B
M)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!-97-S86=E`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA
M;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+@!#86YN;W0@9&5L971E(&9I
M;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#
M86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N
M`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L
M("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F
M(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@
M;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O
M<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-C`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#97)T:69I8V%T92!I
M;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N
M86)L960@;VX@=&AI<R!S97)V97(N`$-H860`0VAA:7(@4&5R<V]N`$-H86YG
M90!#:&%N9V4@06QL`$-H86YG92!&;VQD97(`0VAA;F=E(%EO=7(@4&%S<W=O
M<F0`0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE
M<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@
M87)E('-O<G1E9"X`0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T
M=&EN9W,N`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS
M+@!#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M(&5M86EL+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T
M960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAA<F%C=&5R<R!T;R!D:7-P;&%Y
M.@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL
M`$-H96-K(%]!;&PO3F]N90!#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W
M86YT('1O(&9E=&-H(&UA:6P@9G)O;3H`0VAE8VL@<W!E;&QI;F<@8F5F;W)E
M('-E;F1I;F<@82!M97-S86=E/P!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO
M;W-E($%C=&EO;CH`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!M86EL
M('-E<G9E<CH`0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T
M;R!T:&4@<FEG:'0Z`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N
M86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D
M<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N`$-H;V]S
M92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E
M>'!A;F1I;F<@861D<F5S<V5S+@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC
M92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U
M<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K("5S('1O
M(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R
M;W=S97(@8V%N('9I97<N`$-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G
M92X`0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+@!#;&EC
M:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O
M=RX`0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E
M+@!#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E
M;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@:&5R92!T
M;R!32$]7('1H92!);6%G97,`0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T
M960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T
M;R!S96%R8V@N`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K('1O(%-A=F4@4$=0
M(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VL`0VQI8VL@=&\@4V%V
M92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O
M;VL`0VQI8VMA=&5L;"!V:6$@2%144`!#;&EC:VEN9R!O;B!T:&4@861D<F5S
M<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R`$-L
M:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T
M;R!B92!R96%D`$-L;W-E`$-L;W-E(%=I;F1O=P!#;&]S92!T:&ES('=I;F1O
M=P!#;&]S960@1F]L9&5R`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E`$-O;&QA<'-E($%L;`!#
M;VQL87!S92!!;&P@1F]L9&5R<P!#;VQL87!S92!&;VQD97(`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO
M<B!);F1I8V%T;W(Z(`!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE
M;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&QE
M=&5D`$-O;7!O<V4@86YO=&AE<B!M97-S86=E`$-O;7!O<V4@;65S<V%G97,@
M:6X@82!S97!A<F%T92!W:6YD;W<_`$-O;7!O<V4@;65S<V%G97,@=VET:"!A
M;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H
M92!F96%T=7)E*3\`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN
M8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FEG
M=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+@!#;VYF:6=U<F4@;6%I
M;"!P<F5V:65W(&]P=&EO;G,N`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N
M9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N
M(&1R;W!P960@8GD@24U!4"!S97)V97(N`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I
M;&5D`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E
M<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;VYT<F]L
M(%!'4"!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!3+TU)344@<W5P<&]R="!F
M;W(@)7,N`$-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S
M96%R8VAI;F<N`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K
M960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N
M(&ET(&%R<FEV97,N`$-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G
M<F%P:&EC86P@;VYE<S\`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@
M9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W!Y('1O(&9O;&1E<@!#;W)R
M96-T`$-O<G)E8W1E9"!497AT`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G
M279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N
M;W0@8V]M<&QE=&4@<F5Q=65S="X@4F5A<V]N($=I=F5N.B`E<P!#;W5L9"!N
M;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@8W)E871E('1H92!6
M1E,@8F%C:V5N9#H@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#
M;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H
M92!S97)V97(@<V%I9#H@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I
M<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&5X96-U=&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<RX`0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E
M<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="X`0V]U
M;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II
M<"!A<F-H:79E+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B
M;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T
M<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N
M`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B
M(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@
M9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!O<&5N('-E8W5R92!C;VYN96-T
M:6]N('1O('1H92!)34%0('-E<G9E<BX@)7,@.B`E<RX`0V]U;&0@;F]T(')E
M86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I
M979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E
M<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S
M92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N
M("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O
M=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL
M:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R
M:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@
M<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#
M;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!&;VQD97(`0W)E871E($ME
M>7,`0W)E871E(&$@3F5W($%C8V]U;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@
M82!N97<@4W!A;2!F;VQD97(`0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`
M0W)E871E(&$@;F5W(&]N90!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E
M<@!#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@
M<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET
M(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@;F5W('-T
M871I;VYE<GD`0W)E871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S
M+@!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D
M:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`
M0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`
M0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!A8V-E<W,@
M=&\@)7,`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O
M;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C
M8V]U;G1S+@!#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN`$-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE
M8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!2
M97!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY
M`$1A=%]E`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`
M1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU
M;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8VQI;F5D
M.B``1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A
M=6QT($ED96YT:71Y`$1E9F%U;'0@4V5A<F-H($9I96QD`$1E9F%U;'0@4VAE
M;&P`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@
M9&ER96-T:6]N.@!$969I;FET:6]N<P!$96QE9V%T960`1&5L971E`$1E;&5T
M92`E<R!0=6)L:6,@2V5Y`$1E;&5T92!#96QL`$1E;&5T92!#=7)R96YT($ME
M>7,`1&5L971E($9O;&1E<BAS*0!$96QE=&4@1W)O=7``1&5L971E($QO9P!$
M96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@4V5L96-T960@1F]L9&5R<P!$96QE
M=&4@4W1A=&EO;F5R>0!$96QE=&4@5FER='5A;"!&;VQD97(`1&5L971E(%9I
M<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$1E;&5T92!A;F0@<'5R
M9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!F971C:&5D(&UE
M<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\`1&5L971E(&9R;VT@;7D@8V%L
M96YD87(`1&5L971E(&UE<W-A9V5S`$1E;&5T92!O;&0@;&EN:V5D(&%T=&%C
M:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(&]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E
M<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S<&%M(&UE<W-A9V5S`$1E;&5T
M92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T
M92!T:&4@8W5R<F5N="!R;W<`1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E
M;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L971E9"!T:&4@
M871T86-H;65N="`B)7,B+@!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S
M`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$96YY(')E<75E<W0`1&5N>2!R97%U
M97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VX`1&5S8V5N9&EN9P!$97-C
M<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS`$1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W
M(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``
M1&ED(&YO="!A='1A8V@@(B5S(B!A<R!T:&4@9FEL92!W87,@96UP='DN`$1I
M;2!S:6=N871U<F5S/P!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&-O;F9I<FUA
M=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\`1&ES<&QA>2!D971A:6QE
M9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R
M;6%T`$1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E`$1I<W!L87D@<&]P+75P
M(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\`1&ES<&QA>2!T:&4@(D5M<'1Y
M(%-P86TB(&QI;FL@:6X@=&AE(&UE;G5B87(_`$1I<W!L87D@=&AE(")%;7!T
M>2!4<F%S:"(@;&EN:R!I;B!T:&4@;65N=6)A<C\`1&ES<&]S:71I;VX`1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O($Y/5"!M871C:`!$
M;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;@!$;R!Y
M;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/P!$;V5S('1H92!F:7)S="!R
M;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI
M<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E
M(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O;F4`1&]W;FQO860`1&]W;FQO860@
M)7,`1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870`1&]W;FQO860@06QL($%T
M=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I`$1O=VYL;V%D($9O;&1E<BAS*0!$
M;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T70!$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$;W=N;&]A9"!I
M;B`N>FEP($9O<FUA=`!$<F%F=`!$<F%F="!F;VQD97(`1')A9G1S(&9O;&1E
M<CH`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$4M;6%I;"!!9&1R97-S
M`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H
M:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%3D0`15)2`$524D]2.B!9;W5R
M(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`16-U861O<@!%9&ET
M`$5D:70@0FQA8VML:7-T`$5D:70@0FQO8VL`161I="!&:6QT97)S`$5D:70@
M1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!396%R8V@@475E<GD`161I="!6:7)T
M=6%L($9O;&1E<@!%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R
M("5S`$5D:70@5VAI=&5L:7-T`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I
M="!Y;W5R(&)L86-K;&ES=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D:70@
M>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C
M;W5N=',N`$5D:70@>6]U<B!W:&ET96QI<W0`161U8V%T:6]N`$5G>7!T`$5L
M(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M
M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1I960@
M86QL(&UE<W-A9V5S(&9R;VT@)7,N`$5M<'1I960@86QL(&UE<W-A9V5S(&9R
M;VT@5FER='5A;"!4<F%S:"!&;VQD97(N`$5M<'1Y($9O;&1E<BAS*0!%;7!T
M>2!396QE8W1E9"!&;VQD97)S`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T>2!?
M4W!A;0!%;7!T>2!?5')A<V@`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT
M+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y
M/P!%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_`$5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N
M86)L92!M97-S86=E('!R979I97=S/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N
M=&5X="!M96YU/P!%;F-R7WEP=&EO;B!/<'1I;VYS`$5N8W)Y<'1E9`!%;F0`
M16YD(&9O<G=A<F1E9"!M97-S86=E`$5N9"!M97-S86=E`$5N9"!M97-S86=E
M(&9R;VT@)7,`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@4&%S<W!H
M<F%S90!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@
M=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%
M;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(`16YT97(@
M=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(`16YT97(@=&AE
M(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(`16YT97(@=&AE
M(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<@!%;G1I<F4@365S<V%G
M90!%;G1R>2`B)7,B('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D
M9')E<W,@8F]O:P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R
M<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S(#H@)7,N`$5R<F]R
M(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO
M<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I
M;F<@8V]N=&5N=#H@)7,`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R
M('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN
M:6,`175R;W!E`$5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+@!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A
M;F0@06QL`$5X<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N
M9"!.86UE<P!%>'!A;F0@4VED96)A<@!%>'!A;F0@;F%M97,@:6X@=&AE(&-O
M;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_
M`$5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@
M=&AE(&9O;&1E<G,@=FEE=S\`17AP86YD:6YG`$5X<&5C=&5D("<I)P!%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I
M;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P
M`$9?971C:"!-86EL`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B
M+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE
M=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A
M:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-
M86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S
M`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=&-H($UA:6P`
M1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\`1F5T8V@@;65S<V%G
M97,@=7!O;B!L;V=G:6YG(&]N/P!&971C:&5D("5D(&UE<W-A9V5S(&9R;VT@
M)7,`1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<P!&971C:&UA:6PZ(`!&971C
M:&UA:6PZ(&YO(&YE=R!M97-S86=E<RX`1F5W(%-H;W=E<G,`1F5W(%-N;W<@
M4VAO=V5R<P!&:5]L=&5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`
M1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%-E='1I;F=S`$9I;'1E<B!M
M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\`1FEL=&5R('-U<'!O<G0@
M:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`$9I;'1E<G,`1FEL=&5R<R!.
M3U0@06-T:79E`$9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G90!&:6YD`$9I
M;FQA;F0`1FER<W0@2&%L9@!&:7)S="!-86EL8F]X(%!A9V4`1FER<W0@4&%G
M90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O7W)W87)D
M`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]L9&5R($%C=&EO;G,@
M+2!#;VYF:7)M871I;VX`1F]L9&5R($YA=FEG871O<@!&;VQD97(@4W5M;6%R
M>0!&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"X`1F]L9&5R('5S92!I
M<R!N;W0@96YA8FQE9"X`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X
M('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y`$9O<FUS`$9O<G1U;F4`
M1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A
M<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A
M9V4@9G)O;2`E<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@
M365T<F]P;VQI=&%N`$9R964O0G5S>2!297%U97-T(%)E<W!O;G-E`$9R96YC
M:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,`1G)O7VT`1G)O;0!&<F]M($%D9')E<W,`1G)O;2!T:&4@`$9U
M;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=V0Z`$9W9#H@
M`$9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S`$=A8F]N`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%L($]P=&EO
M;G,`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'
M96]R9VEA`$=E<FUA;GD`1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O
M;FQY*0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N
M<P!';P!';R!T;R!-97-S86=E`$=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O
M9B`B)7,B`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R86YT
M(&%C8V5S<P!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'
M<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2$5210!(
M5$U,`$A434P@5F5R<VEO;B!O9B!-97-S86=E`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO
M;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R
M`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE
M879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP
M`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&5R92!I<R!T:&4@;65S<V%G
M92!Y;W4@=V5R92!C;VUP;W-I;F<Z`$AI9&1E;@!(:61D96X@:6X@5&AR96%D
M(%9I97<`2&ED92!$96QE=&5D`$AI9&4@56YS=6)S8W)I8F5D`$AI9V@`2&EG
M:"!0<FEO<FET>0!(:6=H97-T`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I
M='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO
M;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M
M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG
M:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W
M;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I
M;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@
M<F5P;W)T(2D`2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N
M=',_`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@=&\@871T<FEB
M=71E('%U;W1E9"!L:6YE<R!I;B!A(')E<&QY`$AU;6ED:71Y`$AU;6ED:71Y
M.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4`!)34%0("A!=71O($1E=&5C="!0
M<F]T;V-O;',I`$E-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX@
M4V5R=F5R(%)E<W!O;F1E9#H@)7,`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!
M4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!O=F5R
M(%-33`!)34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92D`
M24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960I`$E-05`@<V5R=F5R(&-L;W-E
M9"!T:&4@8V]N;F5C=&EO;BX`24U!4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL
M(%-E<G9E<G,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0
M(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA
M;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED
M96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!U<VEN9R!3
M4TP@;W(@5$Q3+"!Y;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E
M;G-I;VX@;&]A9&5D+@!)9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I
M;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S="$`268@>6]U(&1O;B=T('-E
M92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@
M;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P
M87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L
M('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BX`26=N;W)E`$EG;F]R92!!;&P`26UA9V4`
M26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O
M;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM
M86=E<P!);7!O<G0`26UP;W)T($ME>0!);7!O<G0@2V5Y<&%I<@!);7!O<G0@
M365S<V%G97,`26UP;W)T(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L($-E<G1I
M9FEC871E`$EM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D`26UP;W)T
M(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!3+TU)
M344@0V5R=&EF:6-A=&5S`$EM<&]R="!0=6)L:6,@2V5Y`$EM<&]R="!0=6)L
M:6,@4$=0($ME>0!);7!O<G0@4'5B;&EC(%,O34E-12!+97D`26UP;W)T(%,O
M34E-12!+97D`26UP;W)T(&UB;W@@1FEL90!);7!O<G0@;6)O>"!F:6QE("5S
M(&EN=&\@9F]L9&5R("5S+@!);7!O<G0L(%-T97`@)60`26UP;W)T86YT`$EM
M<&]R=&%N="!M97-S86=E<P!);7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S
M+@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);B!0<F]C
M97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8F]X`$EN8VQU9&4@82!B<FEE9B!S
M=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\`26YC;'5D92!O<FEG
M:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_`$EN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I
M9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA
M=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);F9O<FUA=&EO;B!O;B`E<R!0
M=6)L:6,@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y
M`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97D`26YL:6YE`$EN
M<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!#97)T:69I8V%T92!(97)E`$EN
M<V5R="!);6%G90!);G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE
M<F4`26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS97)T
M(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS97)T(%1A8FQE`$EN<V5R="!796(@
M3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA
M:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P
M87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E
M`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS
M97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A
M<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E
M9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF
M>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`
M26YT96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES
M(&-O;7!O;F5N="X`26YV86QI9"!!9&1R97-S`$EN=F%L:60@4F5M;W1E($UA
M:6QB;W@`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI
M9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H
M($E$+@!);G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N
M`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&ME>0!);G9A
M;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!)
M;G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@
M<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!E<G-O
M;F%L(%!'4"!P<FEV871E(&ME>2X`26YV86QI9"!P97)S;VYA;"!01U`@<'5B
M;&EC(&ME>2X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C
M;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J
M96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D
M871A+@!);G9E;G1O<GD`26YV97)T`$EN=F5R="!S96QE8W1I;VX`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`
M27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`
M2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E
M<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2T(`
M2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V
M97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME
M>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP
M90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+@!+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM
M92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y(&=E;F5R871I;VX_
M`$ME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@
M;F]T(&5N86)L960@;VX@=&AI<R!S97)V97(N`$ME>2!I;7!O<G0@:7,@;F]T
M(&%V86EL86)L92X@66]U(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@
M=&\@861D('EO=7(@8V]N=&%C=',N`$ME>2!S=6-C97-S9G5L;'D@<V5N="!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L
M:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO
M=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`
M3&%S="!(86QF`$QA<W0@36%I;&)O>"!086=E`$QA<W0@4&%G90!,87-T(%!A
M<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T
M(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ
M($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE
M<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI
M96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A
M:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3
M:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK($%T=&%C:&UE;G1S/P!,:6YK('!O
M:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S
M92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK960@871T86-H;65N=',@87)E
M(&9O<F)I9&1E;BX`3&EN:W,`3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,`3&EN
M=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T
M($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0@
M86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N
M/R`H:68@9&ES86)L960L('EO=2!W:6QL(&]N;'D@<V5E(&-O;G1A8W1S('1H
M870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2D`3&ES="U!<F-H:79E`$QI
M<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B
M<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!I;B!T:&4@2&5A9&5R
M`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A
M:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R
M90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!-86EL8F]X.@!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@:6X@
M=&\@)7,`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO
M9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=R!0<FEO<FET>0!,
M;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@
M<F]M86X@;G5M8F5R<P!,;W=E<W0`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-86-I
M;G1O<V@@1FEL90!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-
M86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SH`
M36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS`$UA
M:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L
M=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@
M;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@
M=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P
M:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K($%L;"!-97-S86=E<R!I
M;B!&;VQD97(@87,@4V5E;@!-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@
M87,@56YS965N`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q
M=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`36%R:R!M97-S86=E<R!A
M<R!S965N/R`H24U!4"!O;FQY*0!-87)K('-I;7!L92!M87)K=7`_`$UA<FL@
M=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA
M<G1I;FEQ=64`36%T8V@@06QL(%%U97)I97,`36%T8V@@06YY(%%U97)Y`$UA
M=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E
M9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X
M:6UU;2!!='1A8VAM96YT(%-I>F4`36%X:6UU;2!.=6UB97(@;V8@1F]L9&5R
M<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N
M9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N`$UA
M>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE(')E86-H960N`$UA>0!-87EO
M='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!&;VQD97(@3&ES=`!-96YU(&UO
M9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!#;VUP;W-I=&EO;@!-
M97-S86=E($1A=&4`365S<V%G92!/<'1I;VYS`$UE<W-A9V4@4V5A<F-H`$UE
M<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!6:65W:6YG`$UE<W-A9V4@97AP
M:7)E9"X`365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G92!F
M<F]M("5S`$UE<W-A9V4@:&%S(&%T=&%C:&UE;G1S`$UE<W-A9V4@:7,@96YC
M<GEP=&5D`$UE<W-A9V4@:7,@<VEG;F5D`$UE<W-A9V4@;6%T8VAE<P!-97-S
M86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY+@!-97-S86=E('-E;G0@<W5C
M8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S`$UE<W-A9V4@<V5N="!S
M=6-C97-S9G5L;'DN`$UE<W-A9V4@='EP90!-97-S86=E<R!P97(@<&%G92!I
M;B!T:&4@;6%I;&)O>"!V:65W+@!-97-S86=E<R!T;P!-971A<B!796%T:&5R
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D
M`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI
M;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R
M`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R
M871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO
M;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-
M86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y`$UO9&EF>2!54DP`
M36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`
M36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S
M`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N`$UO<F4@=&AA;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@
M(B5S(BX`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T
M;'D@4W5N;GD`36]V90!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`
M36]V92!5<`!-;W9E(&1O=VX`36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@
M9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6`!-;W9E('1O
M(&9O;&1E<@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!A<G0O86QT97)N871I
M=F4`375L=&EP;&4@365S<V%G92!6:65W`$UU;'1I<&QE('-E;&5C=&EO;@!-
M>2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY
M(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3D].
M10!.3U1%`$YA;64`3F%M92!A;F0O;W(@96UA:6P@8V%N;F]T(&)E(&5M<'1Y
M`$YA;6EB:6$`3F%U<G4`3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S
M`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C
M87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`
M3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE
M=F5R`$YE=F5R('-A=F4@871T86-H;65N=',`3F5W`$YE=R!#86QE9&]N:6$`
M3F5W($-A=&5G;W)Y`$YE=R!&;VQD97(`3F5W($UA:6P`3F5W($UE<W-A9V4`
M3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I
M;VYA;"D`3F5W(%IE86QA;F0`3F5W(&UE<W-A9V5S`$YE=R!P87-S=V]R9`!.
M97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@
M9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O
M=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT($UE<W-A9V4`3F5X="!086=E
M`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.
M:6=H=`!.:75E`$YO`$YO($-E<G1I9FEC871E(&9O=6YD`$YO($5N8W)Y<'1I
M;VX`3F\@2V5Y<R!I;B!+97ER:6YG`$YO($UE<W-A9V5S`$YO(%!'4"!P=6)L
M:6,@:V5Y(&EM<&]R=&5D+@!.;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S
M96YT`$YO(%!R979I97<@5&5X=`!.;R!0=6)L:6,@2V5Y<R!&;W5N9`!.;R!3
M+TU)344@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@871T86-H;65N=',@9F]U
M;F0N`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N
M9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F
M="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&5M86EL(&EN9F]R;6%T
M:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K97DN`$YO(&9I;&4@=7!L;V%D
M960`3F\@9F]L9&5R('-E;&5C=&5D+@!.;R!F;VQD97)S(&%R92!B96EN9R!C
M:&5C:V5D(&9O<B!N97<@;6%I;"X`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE
M9`!.;R!F;VQD97)S('=I=&@@;F5W(&UE<W-A9V5S`$YO(&9O;&1E<G,@=VET
M:"!U;G-E96X@;65S<V%G97,`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N
M(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@8F]D
M>2!T97AT`$YO(&UE<W-A9V4@<F5T=7)N960N`$YO(&UE<W-A9V4@<W5P<&QI
M960N`$YO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N`$YO(&YA;64@
M<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@
M9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!
M4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N
M=7!S+@!.;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N`$YO
M('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA
M;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!P
M<FEV871E(&ME>2!E>&ES=',@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O
M(&)E(&1E8W)Y<'1E9"X`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A
M<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S<&5L;&-H96-K:6YG('!R
M;V=R86T@8V]N9FEG=7)E9"X`3F\@<W!E;&QI;F<@97)R;W)S`$YO('-U8V@@
M9FEL90!.;R!S=6=G97-T:6]N<P!.;R!S=7!P;W)T960@24U!4"!A=71H96YT
M:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N`$YO('1E;7!O<F%R>2!D
M:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<B!S<&5C:69I
M960N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!087)T:6-I<&%N
M=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:R!)<VQA;F0`3F]R;6%L`$YO<G1H97)N($AE;6ES<&AE<F4`
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T
M($)E9F]R90!.;W0@1&5L971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.
M;W0@4&5R<V]N86P`3F]T(&$@9&ER96-T;W)Y`$YO="!A('9A;&ED('!U8FQI
M8R!K97DN`$YO="!D96QE=&5D(&UE<W-A9V5S`$YO="!I;7!L96UE;G1E9"X`
M3F]T(&EM<&]R=&%N="!M97-S86=E<P!.;W0@<V5T`$YO="!S=7!P;W)T960N
M`$YO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM90!.;W1E<P!.;W1H
M:6YG`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I9FEC871I;VXZ
M($QI;FME9"!A='1A8VAM96YT(&1O=VYL;V%D960`3F]V96UB97(`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF
M(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O
M;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+@!.=6UB97(@;V8@
M<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+@!/2P!/4@!/8FIE8W0`3V)J96-T($-R96%T;W(`
M3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N
M97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@;65S<V%G97,`
M3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VQD
M('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"X`3VUA;@!/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&1I<W!L
M87D@9F]L9&5R<R!W:71H('5N<F5A9"!M97-S86=E<R!I;B!T:&5M/P!/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N`$]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R
M('1H:7,@86-T:6]N+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S
M:6]N<R!F;W(@82!S:&%R90!/<&5N($9O7VQD97(`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;F5D($9O;&1E<@!/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T
M:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E
M<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G
M86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T
M:&5R($UA:6P@06-C;W5N=',`3W1H97(@3W!T:6]N<P!/=71B;W5N9"!397)V
M97(`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U``4$=0($1I9VET
M86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T($UE<W-A9V4`4$=0($5N8W)Y<'1E
M9"!$871A`%!'4"!%<G)O<CH@`%!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E
M(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4$=0($]P=&EO;G,`4$=0(%!A
M<W-P:')A<V4@26YP=70`4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R
M97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`4$=0(%!U8FQI8R!+
M97D`4$=0(%!U8FQI8R!+97D@5&5X=`!01U`@4'5B;&EC($ME>2!F;W(@(B5S
M("@E<RDB('=A<R!S=6-C97-S9G5L;'D@861D960N`%!'4"!0=6)L:6,@2V5Y
M(&9O<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"X`4$=0(%!U8FQI
M8R!+97ER:6YG`%!'4"!3:6=N($UE<W-A9V4`4$=0(%-I9VXO16YC<GEP="!-
M97-S86=E`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$=0('!R:79A=&4@
M:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0('!U8FQI8R!K97D@<W5C8V5S
M<V9U;&QY(&%D9&5D+@!01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES
M('-Y<W1E;2X`4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@
M<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I
M9FEE9"X`4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@
M=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`4$=0('-U
M<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@
M>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U
M<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L
M<V4@=&AE(%!'4"!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`
M4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3
M:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T
M;W)M<P!03U`S`%!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RD`4$]0,R!O
M=F5R(%-33`!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T
M92D`4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I`%!/4#,L(&YO(%1,4P!0
M3U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`
M4&%G92`E9"!O9B`E9`!086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S
M86=E`%!A9V4@=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G90!086MI<W1A
M;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M
M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G0H<RD`4&%R=&QY($-L
M;W5D>0!087-S<&AR87-E`%!A<W-P:')A<V4@*$%G86EN*0!087-S<&AR87-E
M('-U8V-E<W-F=6QL>2!U;FQO861E9"X`4&%S<W!H<F%S93H`4&%S<W!H<F%S
M97,@8V%N;F]T(&)E(&5M<'1Y`%!A<W-P:')A<V5S(&1O(&YO="!M871C:`!0
M87-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O
M<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W
M;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!0
M87-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O
M<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@
M1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N;F]T(&)E(&-H86YG960N
M`%!E<G-O;F%L`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G-O;F%L(%!'4"!K
M97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!E<G-O;F%L(%!'4"!K
M97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)S;VYA;"!3+TU)344@8V5R
M=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@`%!E<G-O;F%L(%,O34E-12!K97ES
M(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)U`%!E=',`4&AI;&EP<&EN97,`
M4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%C92!Y;W5R('-I9VYA
M='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_`%!L86EN=&5X="!6
M97)S:6]N(&]F($UE<W-A9V4`4&QA=&ET=61E<P!0;&%Y('-O=6YD(&]N(&YE
M=R!M86EL/R`@5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R
M="!E;6)E9&1E9"!S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN
M9&]W<R!A;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@<F5Q=6ER
M92!A('!L=6=I;BX`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N
M=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI
M<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0
M;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N
M=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@
M9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`
M4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&5N=&5R('1H92!N
M86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N
M86UE.@!0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0
M('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI
M<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN`%!L96%S92!E;G1E
M<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN
M(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@
M;VYC92!P97(@)7,@<V5S<VEO;BX`4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R
M97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@
M=7-I;F<@8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@
M:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R!L;V<@:6X@86=A
M:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME
M97`@871T86-K97)S(&9R;VT@:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@
M5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92X`4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED
M92!Y;W5R('!A<W-W;W)D+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE+@!0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5S
M;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N`%!L96%S92!S
M96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M('1H:7,@86-T:6]N
M+@!0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H
M+@!0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R
M871I;VXN`%!L96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H
M92!R:6=H=#H`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0
M;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@
M=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@
M=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0;W=E<F5D(&)Y
M($AO<F1E`%!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M
M+2`G*3\`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E
M8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F97)E;F-E<R!S=6-C97-S9G5L
M;'D@=7!D871E9"X`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E
M82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@365S<V%G90!0<F5V:6]U<R!0
M86=E`%!R979I;W5S(&]P=&EO;G,`4')I;G0`4')I;G0@9&]C=6UE;G0`4')I
M;W)I='D`4')I=F%T92!+97D`4')I=F%T92!+97D@4&%S<W=O<F0`4')O8FQE
M;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!E=F5R>2!T
M:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3P!0<F]M
M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@
M=&\@6453`%!R;VUP="!T97AT`%!R;W1O8V]L.@!0=6)L:6,@2V5Y`%!U8FQI
M8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,@4$=0(&ME
M>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+@!0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R
M=&\@4FEC;P!0=7)?9V4@1&5L971E9`!0=7)G92!$96QE=&5D`%!U<F=E($9O
M;&1E<BAS*0!0=7)G92!4<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S
M`%!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H
M:7,@86UO=6YT(&]F(&1A>7,N`%!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@
M5')A<V@@9F]L9&5R/P!0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@
M9F]L9&5R+@!0=7)G:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BX`
M46%T87(`475E<GD`475O=&$`475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F
M34(@("@E+C)F)24I`%%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250`
M475O=&$@<W1A='5S.B!.3R!,24U)5`!1=6]T:6YG("5F.@!24T$@4'5B;&EC
M($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY
M`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@
M4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8G5I;&0@1F]L9&5R
M(%1R964`4F5C96EV960@3VX`4F5C96EV960@4VEN8V4`4F5C96EV960@56YT
M:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T($UE<W-A9V4`4F5D:7)E
M8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE9"X`4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SH`4F5F<F5S:"!&;VQD97(@5FEE=W,Z`%)E9G)E<V@@4&]R=&%L
M(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296QO
M860@5FEE=P!296UA<FMS`%)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E($UA:6QB;W@Z
M`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!&:65L
M9"!&<F]M(%-E87)C:`!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG
M`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@<V]U<F-E`%)E;6]V92!T
M:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@
M=7-E<@!296UO=F4@=7-E<CH@)7,`4F5N86UE($9O;&1E<BAS*0!296YA;64@
M<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_`%)E;F%M
M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60`4F5P;%]Y('1O($QI<W0`4F5P;&%C92!W:71H.@!297!L>0!2
M97!L>2!396YT+@!297!L>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2!T
M;R!,:7-T`%)E<&QY('1O($QI<W0Z`%)E<&QY('1O(%]!;&P`4F5P;'D@=VET
M:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@
M9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O
M8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DM5&\`4F5P;'DM5&\Z(`!297!L>3H`
M4F5P;W)T(&%S($EN;F]C96YT`%)E<&]R="!A<R!3<&%M`%)E<75E<W0@82!?
M4F5A9"!296-E:7!T`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`4F5Q
M=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+@!297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!2
M97%U:7)E9"!087)T:6-I<&%N=`!297-E=`!297-E="!087-S=V]R9`!297-E
M="!9;W5R(%!A<W-W;W)D`%)E<W!O;F1E;G0@4W1A='5S(%5P9&%T960N`%)E
M<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E<W5M90!297-U;64@>6]U<B!S
M97-S:6]N`%)E='5R;B!T;R`B365S<V%G92!#;VUP;W-I=&EO;B(`4F5T=7)N
M('1O($9E=&-H($UA:6P`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O('1H
M92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@
M8V]P>6EN9R!A(&UE<W-A9V4_`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO
M;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O
M7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A
M=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E
M<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344`4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T($UE
M<W-A9V4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%,O34E-12!%<G)O<CH@
M`%,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P
M<FEV871E(&ME>2X`4R]-24U%($]P=&EO;G,`4R]-24U%(%!A<W-P:')A<V4@
M26YP=70`4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E
M<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`4R]-24U%(%!U8FQI8R!+97D@
M9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!3+TU)344@4'5B
M;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N`%,O34E-12!0=6)L:6,@2V5Y
M<FEN9P!3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L
M;'D@861D960N`%,O34E-12!3:6=N($UE<W-A9V4`4R]-24U%(%-I9VXO16YC
M<GEP="!-97-S86=E`%,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H
M:7,@<WES=&5M+@!3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N
M86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E
M9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E
M;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N;F]T(&)E(&1I<W!L87EE
M9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET
M86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4R]-24U%
M('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@
M268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P
M;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R
M(&5L<V4@=&AE(%,O34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E
M8W1L>2X`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!3
M35,@365S<V%G:6YG`%--5%``4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R
M('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!37W5B:F5C
M=`!380!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S`%-A:6YT($AE;&5N80!3
M86EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M
M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I
M80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@071T86-H;65N=',@=VET
M:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`4V%V
M92!);6%G90!3879E($EM86=E(&EN($=A;&QE<GD`4V%V92!/<'1I;VYS`%-A
M=F4@4W1A=&EO;F5R>0!3879E(%]$<F%F=`!3879E(&%S`%-A=F4@9')A9G1S
M(&%S('5N<V5E;C\`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A
M(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!3879E(')E8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F
M875L="!A9&1R97-S(&)O;VL_`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F
M;VQD97(_`%-A=F4@<V5N="!M86EL/P!3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V%V:6YG
M('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("5S`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R
M8V@@)7,`4V5A<F-H($5N9VEN97,`4V5A<F-H($]P=&EO;G,`4V5A<F-H(%)E
M<W5L=',`4V5E;@!396QE8W0`4V5L96-T($%N;W1H97(@06-C;W5N=`!396QE
M8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!F:65L9`!396QE8W0@
M82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E
M<G9E<@!396QE8W0@82!S=&%T:6]N97)Y.@!396QE8W0@82!U<V5R('1O(&%D
M9`!396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@
M<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N`%-E;&5C="!A;&P`4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C
M:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT
M`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R
M86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N
M('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I
M;BX`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E
M;&5C="!T:&4@;6%I;"!S97)V97(@='EP90!396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&5C=&5D($%D9')E<W,@
M8F]O:W,Z`%-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(`4V5N9"!,871E
M<W0@26YF;W)M871I;VX`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N9"!335,`4V5N9"!M97-S86=E('=I=&AO=70@82!3=6)J96-T/P!3
M96YD(')E860@<F5C96EP="!W:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R
M/P!396YE9V%L`%-E;G-O<CH@`%-E;G0@;6%I;"!F;VQD97(`4V5N="!M86EL
M(&9O;&1E<CH`4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I
M86P@3G5M8F5R`%-E<G9E<@!397)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO
M;@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397)V97(Z
M`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3
M970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@<')E9F5R96YC97,@
M9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S
M<V%G97,N`%-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I
M;F<@;65S<V%G97,_`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W
M86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E
M="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U
M<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C
M871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL
M97,`4VAA<F4@1F]L9&5R<P!3:&%R92!M86EL(&9O;&1E<G,`4VAA<F4@>6]U
M<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RX`4VAO<'!I;F<`4VAO
M<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\`4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X
M="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E('1O
M9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+@!3:&]U;&0@=&AE
M(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!0
M1U`@9&%T83\`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@
M869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@
M:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L
M=#\`4VAO=P!3:&]W($%L;"!&;VQD97)S`%-H;W<@06QL($AE861E<G,`4VAO
M=R!$96QE=&5D`%-H;W<@3&EM:71E9"!(96%D97)S`%-H;W<@36%I;&EN9R!,
M:7-T($EN9F]R;6%T:6]N`%-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,`
M4VAO=R!5;G-U8G-C<FEB960`4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP
M<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/P!3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@
M=FEE=S\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME
M<@!3:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\`4VAO
M=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\`4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W
M('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE
M($EM86=E<P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!F:6QT97(@:6-O
M;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/P!3
M:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E
M`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H;W=N`%-H<FEN:P!3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0`4VE?>F4`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I
M9VYA='5R92!!;&=O<FET:&T`4VEG;F5D`%-I;F=A<&]R90!3:7IE`%-K:7`@
M36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E
M<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R
M<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@
M8GD@07)R:79A;`!3;W)T(&)Y($1A=&4`4V]R="!B>2!&<F]M($%D9')E<W,`
M4V]R="!B>2!-97-S86=E(%-I>F4`4V]R="!B>2!3=6)J96-T`%-O<G0@8GD@
M5&AR96%D`%-O<G0@8GD@5&\@061D<F5S<P!3;W)T(&]R9&5R('-E;&5C=&EO
M;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I
M;F<`4W!A:6X`4W!A;0!3<&%M(&9O;&1E<CH`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W!E8VEA;"!#:&%R86-T97)S`%-P96-I86P@5FER='5A;"!&;VQD
M97)S(&-A;FYO="!B92!E9&ET960N`%-P96QL($-H96-K`%-P96QL($-H96-K
M97(`4W!E;&P@8VAE8VL@8V]M<&QE=&4`4W!E;&QI;F<@97)R;W)S('!E<B!S
M8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RX`4W!L:70@8V5L;`!3<&QI="!C
M;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A
M<B!4<F5K`%-T87)T`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A
M=&EO;F5R>0!3=&%T:6]N97)Y(&YA;64Z`%-T871I;VYE<GD@='EP93H`4W1A
M=&EO;F5R>3H`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S
M`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@071T86-H;65N=`!3
M=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3=')I<"!L:6YE8G)E86MS
M/P!3='EL92!;0U-370!3=0!3=6)?:F5C=`!3=6)D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`%-U8FIE8W0`4W5B:F5C="!&:65L9`!3=6)M:70`4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O
M=F5D+@!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U8G-C<FEP=`!3=6-C97-S
M`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL
M>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U
M8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@
M=W)O=&4@)7,`4W5D86X`4W5G9V5S=&EO;G,`4W5M;6%R>0!3=6X@4FES90!3
M=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@
M`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE
M`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E
M9&5N`%-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0`4W=I=&-H('1O($A434P@
M8V]M<&]S:71I;VX`4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I;VX`
M4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T
M;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY
M`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<F=E=#H`5&%S:W,`5&5?>'0`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L
M87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S
M(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E;G1A=&EV
M93H@`%1E;G1A=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A=&EV96QY($%C
M8V5P=&5D`%1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN
M(&-O;F8N<&AP`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4
M:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I
M<R!N;W0@879A:6QA8FQE+@!4:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M97-S
M86=E('-H;W5L9"!B92!L:6YK960Z`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D
M:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-05`@<V5R=F5R(&1O97,@;F]T
M(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A=&EO;B!M971H;V0@
M<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N
M`%1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:P!4:&4@36%C:6YT;W-H(')E
M<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N`%1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A8V-O=6YT
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&%C8V]U;G0@(B5S(B!H87,@
M8F5E;B!S879E9"X`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG
M=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@871T86-H;65N="!W87,@;F]T
M(&9O=6YD+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V%L96YD87(@9&%T
M82!I<R!I;G9A;&ED`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D
M871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&-O;G1E;G1S(&]F('1H92!-86-I
M;G1O<V@@9FEL92!A<F4@8F5L;W<N`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B
M)7,B('=I;&P@8F4@<F5N86UE9"!T;R`B)7,B+@!4:&4@8W5R<F5N="!L:7-T
M(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO
M="!B92!R971R:65V960`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H
M92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@(B5S(B!F;VQD97(N`%1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN`%1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A
M<BX`5&AE(&9I96QD("(E<R(@8V%N)W0@8F4@97AP86YD960N`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N
M;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D
M(&YO(&1A=&$N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@
M9F]L9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET
M<R!N86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U
M<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C
M<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE
M(&9O;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS
M=6)S8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R
M96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E
M<B`B)7,B('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A
M=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D
M+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O
M("(E<R(N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F;VQL;W=I;F<@9FEL97,@
M=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z`%1H92!F=6QL('-C<F5E;B!M
M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@
M17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T
M(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A
M<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O
M<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!I
M;6%G92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y
M;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O
M=W,_`%1H92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@
M<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U<B!A9&1R97-S8F]O:RX`5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O
M<B!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL
M;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@
M9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93H`5&AE(&UA:6QB;W@@
M)7,@:7,@86QR96%D>2!E;7!T>2X`5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E
M<R(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@;&EM:70N`%1H92!M
M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN
M9RX`5&AE(&UE<W-A9V4@9&]E<R!N;W0@:&%V92!A(%-U8FIE8W0@96YT97)E
M9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"X`5&AE(&UE<W-A9V4@
M:&%S(&)E96X@=F5R:69I960N`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF
M:65D+B!396YD97(Z("5S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T
M(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F
M;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E
M;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@
M97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R
M86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F
M;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R87<@=&5X="!O9B!T:&4@
M4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E<RX`5&AE(')E<75E<W1E
M9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE
M;G0N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@
M6FEP(&%T=&%C:&UE;G0N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY
M`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5N9&5R(&]F('1H:7,@
M;65S<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VX@9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@
M;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE(&YO=&EF:6-A
M=&EO;B!M97-S86=E+@!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D
M+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S97)V97(@
M=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM
M86=E+@!4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"X`5&AE
M('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+@!4:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C
M:69I960@9FEL92!D;V5S(&YO="!E>&ES="X`5&AE('-P96-I9FEE9"!R;W<@
M*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('-T871I;VYE<GD@(B5S(B!H87,@
M8F5E;B!A9&1E9"X`5&AE('-T871I;VYE<GD@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B965N('5P9&%T960N`%1H
M92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H92!T
M96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!O
M9B!T:&4@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@
M=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G90!4
M:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D
M("5S+@!4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E`%1H92!T97AT(&]F
M('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RX`5&AE('1E>'0@
M>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R
M965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I
M9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@
M<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@
M;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T
M:&ES(&UA:6QB;W@N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!I<R!N;R!T97AT('1H870@8V%N
M(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M
M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N
M(%1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET
M97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W
M87,@86X@97)R;W(@8V]P>6EN9R!M97-S86=E<R!F<F]M("(E<R(@=&\@(B5S
M(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E<R(N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z
M("5S+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@
M:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O
M<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG
M=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D
M(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R
M;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A
M(&1R869T+@!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A
M9V4Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C
M="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M
M97-S86=E('!A<G0`5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E
M9&1E9"!I;B!I="X`5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E
M9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@=&AI<SH@
M`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N`%1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O('1H
M92!M97-S86=E+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES
M(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@
M;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UA>2!T86ME('-O
M;64@=&EM92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O;G1I;G5E/P!4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92X`5&AI<R!M
M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D
M:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N`%1H:7,@;65S<V%G92!C;VYT
M86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I
M82!3+TU)344N`%1H:7,@;65S<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y
M('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M870@;V8@=&AI<R!M
M97-S86=E(&ES('5N:VYO=VXN`%1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R<F]R
M.B``5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@
M8V]R<F5C="!01U`@9F]R;6%T("AA8V-O<F1I;F<@=&\@4D9#(#(P,34I+@!4
M:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R
M96-T(%,O34E-12!F;W)M870N`%1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I
M=&%L;'D@<VEG;F5D('9I82!01U`N`%1H:7,@;65S<V%G92!H87,@8F5E;B!D
M:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N`%1H:7,@;65S<V%G92!H87,@
M8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B
M965N(&5N8W)Y<'1E9"!W:71H(%!'4"X`5&AI<R!M97-S86=E('1O`%1H:7,@
M;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O
M=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N`%1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD
M;W<@;75S="!B92!C86QL960@9G)O;2!A(&-O;7!O<V4@=VEN9&]W+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M`%1H<F5A9"!$:7-P;&%Y`%1H<F5A9"!6:65W`%1H=6YD97(`5&EC:V5T<P!4
M:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`
M5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!!9&1R
M97-S`%1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@8VQI8VMI;F<N
M`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N
M`%1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG
M(&$@=F5R<VEO;B!O9B!02%`@-2XQ+C`@;W(@:&EG:&5R+@!4;V1A>0!4;V=G
M;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O
M<`!4;W`@9G)A;64@*%]T;W`I`%1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z`%1R
M86YS;&%T:6]N<P!4<F%S:"!F;VQD97(`5')A<V@@9F]L9&5R.@!4<FEN:61A
M9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`
M5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@
M:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W
M:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5
M;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE
M9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A
M:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@
M)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')E=')I979E('%U;W1A`%5N
M86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YA;G-W97)E
M9`!5;F%N<W=E<F5D(&UE<W-A9V5S`%5N9&5L971E`%5N9&5R;&EN90!5;F1I
M<V-L;W-E9"!296-I<&EE;G1S`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O($%55$A%3E1)0T%412!C;VUM86YD+@!5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O($1I9V5S="U-1#4@<F5S<&]N<V4N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\@3$]'24X@8V]M;6%N9"X`56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YH
M86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<P!5;FEC;V1E("A55$8M."D`
M56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T
M871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI
M=',`56YK;F]W;@!5;FMN;W=N($1A=&4`56YK;F]W;B!)34%0(')E<W!O;G-E
M(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,`56YK;F]W
M;B!-965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N=`!5;FQO860@4&%S<W!H<F%S90!5;FYA;65D`%5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E
M(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"X`56YS965N`%5N<V5T(&-O;&]R`%5N<W5B<V-R:6)E(&9R;VT@1F]L
M9&5R*',I`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S
M`%5P9&%T92!R97-P;VYD96YT('-T871U<P!5<&1A=&4@=7-E<@!5<&1A=&5D
M("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`
M57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U
M87D`57-E($-U<G)E;G0Z("5S`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0
M(&9O;&1E<B!S=6)S8W)I<'1I;VYS/P!5<V4@4U-,`%5S92!6:7)T=6%L(%1R
M87-H($9O;&1E<C\`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("(E<R(@<W5C8V5S<V9U;&QY
M(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E
M<R(N`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D
M;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE
M("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S
M97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD
M(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L
M=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E
M;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O
M;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A
M;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE
M=P!6:65W("5S`%9I97<@)7,@4'5B;&EC($ME>0!6:65W($A434P@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W($UE<W-A9V5S`%9I97<@4&5R
M<V]N86P@4')I=F%T92!+97D`5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y`%9I
M97<@5&AR96%D`%9I97<@5&AU;6)N86EL`%9I97<@86X@97AT97)N86P@=V5B
M('!A9V4`5FEE=R!A<R`E<P!6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<`5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I
M97<@979E;G0`5FEE=R!M97-S86=E<R!I;B`E<P!6:65W(&]R(&UA:6QB;W@@
M=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CH`5FEE=R!T87-K`%9I97<@=&AE($EM
M86=E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@
M52Y3+@!6:7)T=6%L($9O;&1E<B`B)7,B(&-R96%T960@<W5C8V5S9G5L;'DN
M`%9I<G1U86P@1F]L9&5R<P!6:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA
M8F5L+@!6:7)T=6%L($E.0D]8`%9I<G1U86P@24Y"3U@@1F]L9&5R`%9I<G1U
M86P@5')A<V@`5FER='5A;"!4<F%S:"!&;VQD97(`5FER='5A;"!F;VQD97(@
M;&%B96P`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@
M=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A
M<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED
M960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE
M`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM
M,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@
M87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\`5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE
M<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@
M;W(@:6YN;V-E;G0_`%=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE
M;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@=&AE
M;2!A<R!D96QE=&5D/P!7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI
M8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\`5VAE;B!S879I;F<@
M<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_`%=H
M96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N9&EN9R!A9&1R97-S97,L('=H870@
M9&]M86EN('-H;W5L9"!W92!A<'!E;F0@=&\@=6YQ=6%L:69I960@861D<F5S
M<V5S("AE;6%I;"!A9&1R97-S97,@=VET:&]U="`B0"(I/P!7:&5R96ES($%U
M<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA
M8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VAI=&5L:7-T`%=I9'1H
M`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@
M;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD
M($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O
M;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O
M=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X
M=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`
M665S+"!)($%G<F5E`%EO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O
M;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ`%EO=2!A<F4@871T96UP=&EN
M9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@9F]L
M;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T
M92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!C;W!Y:6YG+VUO
M=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E871I;F<@82!S=6(M
M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E
M<BX`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&9O;&1E<G,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z
M(`!9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T
M:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE(&-U<G)E;G0@;65S<V%G
M92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92X`66]U(&-A;FYO="!H
M879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@
M8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@(B5S(BX`66]U(&1I9"!N;W0@86=R
M964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@
M=V5R92!N;W0@86QL;W=E9"!T;R!L;V=I;BX`66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE
M;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I
M;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T
M;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R`%EO=2!F;W)W87)D960@
M=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N
M=',Z("5S+@!9;W4@:&%V92`E<R!N97<@;65S<V%G97,N`%EO=2!H879E(#$@
M;F5W(&UE<W-A9V4N`%EO=2!H879E(&%L<F5A9'D@<W5B;6ET=&5D('1H:7,@
M<&%G92X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!N97<@
M;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CH`66]U(&AA=F4@;F5W(&UA
M:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.@!9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@
M86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG
M('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U
M(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG
M;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!A="!L96%S="!O
M;F4@<F5C:7!I96YT+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A
M<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S
M86=E`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O
M34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9;W4@;75S
M="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="X`66]U(&UU<W0@<V5L
M96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T
M(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@
M=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M
M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N`%EO=2!N965D('1O(&AA=F4@(B5S(B!E;F%B;&5D(&EN('EO
M=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RX`66]U(&YE960@=&\@<')O=FED92!A
M;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@<F5D:7)E8W1E9"!T:&ES(&UE
M<W-A9V4@=&\@)7,@;VX@)25S+@!9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A
M9V4@;VX@)7,N`%EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N($AE
M<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N<W5B
M<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60`66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S(@!9
M;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@3F%M90!9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES`%EO=7(@
M4')I=F%T92!+97D`66]U<B!0=6)L:6,@2V5Y`%EO=7(@4F5P;'DM=&\Z(&%D
M9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3X`66]U<B!3+TU)344@4'5B;&EC
M+U!R:79A=&4@0V5R=&EF:6-A=&5S`%EO=7(@86-C;W5N=',Z`%EO=7(@86QI
M87,@861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E
M<W,@;VX@82!N97<@;&EN92D\+V5M/@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W
M:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L
M('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K
M96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A
M<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G92!T>7!E+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0
M<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN
M9R!M97-S86=E<SH`66]U<B!D969A=6QT(&5N8W)Y<'1I;VX@;65T:&]D(&9O
M<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S
M(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U
M;&P@;F%M93H`66]U<B!L:6YK960@871T86-H;65N="!H87,@8F5E;B!D;W=N
M;&]A9&5D(&)Y(&%T(&QE87-T(&]N92!U<V5R+@H*071T86-H;65N="!N86UE
M.B`E<PI!='1A8VAM96YT(&1A=&4Z("5S"@I#;&EC:R!O;B!T:&4@9F]L;&]W
M:6YG(&QI;FL@=&\@<&5R;6%N96YT;'D@9&5L971E('1H92!A='1A8VAM96YT
M.@HE<P!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&UE<W-A9V4@=V%S
M('-U8V-E<W-F=6QL>2!D96QI=F5R960N`%EO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E
M;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@
M<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EO
M=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W
M90!::7!P>0!;2&ED92!!9&1R97-S97-=`%M(:61E(%%U;W1E9"!497AT70!;
M3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!!9&1R97-S97,@
M+0!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=`%M3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP:65N='-=`%ML:6YE
M("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T)C8P!?0FQA8VML:7-T`%]#
M3$D`7T-C`%]$871A5')E90!?1&5L971E`%]$96QE=&4@4F]W`%]&;VQD97)S
M`%]'<F]U<',`7TAE;'``7TED96YT:71Y`%]);6%G92!0<F]P97)T:65S+BXN
M`%]);F)O>`!?3&]G(&EN`%],;V<@;W5T`%]-97-S86=E(%-O=7)C90!?36]D
M:69Y($QI;FLN+BX`7TYE=R!-97-S86=E`%]/<'1I;VYS`%]097)M:7-S:6]N
M<P!?4')I;G0`7U!R:6]R:71Y`%]2969R97-H("5S`%]296UO=F4@3&EN:RXN
M+@!?4F5P;'D`7U-E87)C:`!?4V5N9"!-97-S86=E`%]3971U<`!?5&%B;&4@
M4')O<&5R=&EE<RXN+@!?5&AR96%D`%]4;P!?56YD96QE=&4`7U5S97)S`%]6
M:65W(%1H<F5A9`!?5VAI=&5L:7-T`&%D9')E<W,@8F]O:P!A9&1R97-S964@
M=6YK;F]W;@!A='1A8VAM96YT`&%T=&%C:&UE;G1S+GII<`!B>71E<P!C86QE
M;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P
M96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`
M8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S
M:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A
M;&QI;F<`9FEL90!F<F]M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S
M=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE
M`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!K
M97D`;&EN97-=`&UA:6QB;W@@9FEL90!M:VES;V9S(&5R<F]R(&-O9&4@)60@
M=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;VYE`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;W(`<&5R8V5N=`!P97)M
M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5C:7!I96YT<UT`<F5M;W1E(&5R<F]R
M(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@
M9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-P96QL:6YG(&5R<F]R
M`'-P96QL:6YG(&5R<F]R<P!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@
M;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R
M9`!W.@!W96%T:&5R+F-O;0!Y;W5R(&)L86-K;&ES=`!Y;W5R('=H:71E;&ES
M=`!0<F]J96-T+4ED+59E<G-I;VXZ($E-4"`T+C`M8W9S"E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`R+3$U(#$W.C,R*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-BTP,BTQ-2`Q-SHS,BLP,3`P"DQA<W0M5')A;G-L871O<CH@36%N=65L
M(%`N($%Y86QA(#QM87EA;&%`=6YE>"YE<SX*3&%N9W5A9V4M5&5A;3H@:3$X
M;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS
M/3([('!L=7)A;#TH;B`A/2`Q*3L*`"`@("`@($-C.B``("`@(%!A<F$Z(``@
M("!&96-H83H@`"`@("`@($1E.B``("AH86-E("5S(&3M87,I`"`H06QT("L@
M)7,I`"`H96X@)7,@9.UA<RD`("AH;WDI`"`H;6'Q86YA*0`@*&%Y97(I`"!!
M<W5N=&\Z(`!E;B``(&5N(``B)7,B(&YO(&5S('5N(&1I<F5C=&]R:6\N`"(E
M<R(@;F\@97,@=6YA(&5L96-C:?-N(';A;&ED82X`3F\@<V4@:&$@8V]N9FEG
M=7)A9&\@(B5S(B!E;B!E;"!R96=I<W1R;R!D92!(;W)D92X`3F\@<V4@96YC
M;VYT<O,@96P@9V5N97)A9&]R(&1E(.%R8F]L97,@9&4@(B5S(BX`4V4@:&$@
M8?%A9&ED;R`B)7,B(&%L('-I<W1E;6$@9&4@9W)U<&]S+@!392!H82!A\6%D
M:61O("(E<R(@86P@<VES=&5M82!D92!P<FEV:6QE9VEO<RX`3F\@<V4@:&$@
M8W)E861O("(E<R(Z("5S+@`C`"4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`
M57-A9&]S("4N,F9-0B!D92`E+C)F34(@<&5R;6ET:61O<R`H)2XR9B4E*0`E
M9"`E<R!Y("5S`"5D(&UE;G-A:F5S`%%U961A;B`E9"!D[6%S(&AA<W1A('%U
M92!E>'!I<F4@;&$@8V]N=')A<V7Q82X`4V4@:&$H;BD@96QI;6EN861O("5D
M(&UE;G-A:F4H<RDN`%-E(&AA;B!N;W1I9FEC861O("5D(&UE;G-A:F5S(&YO
M<FUA;&5S(&%L(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,N`%-E(&AA;B!N
M;W1I9FEC861O("5D(&UE;G-A:F5S(&YO<FUA;&5S+@!392!H86X@;F]T:69I
M8V%D;R`E9"!M96YS86IE<R!S<&%M(&%L(&%D;6EN:7-T<F%D;W(@9&4@<VES
M=&5M87,N`%-E(&AA;B!N;W1I9FEC861O("5D(&UE;G-A:F5S('-P86TN`"5D
M(&%L("5D(&1E("5D(&UE;G-A:F4H<RD`)60@<')O;O-S=&EC;W,@9&EA<FEO
M<P`E<R`M($%V:7-O`$AU96QL82!D:6=I=&%L(&1E("5S`"5S($M"`"5S(&]P
M97)A8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\@+2!#;VYF:7)M86-I\VX`0V]N
M9FEG=7)A8VGS;B!D92`E<P!&:7)M82!D92`E<P!!8W5E<F1O<R!D92!L:6-E
M;F-I82!D92`E<P!982!E>&ES=&4@)7,N`"5S('EA(&5X:7-T92X@3&$@8V%R
M<&5T82`E<R!N;R!S92!H82!R96YO;6)R861O+@`E<R!A(&QA<R`E<R`E<P`E
M<R!N;R!P87)E8V4@=6X@8G5Z\VX@=N%L:61O+@!,82!C87)P971A("5S('-E
M(')E;F]M8G)A<N$@86P@:6YI8VEO(&1E;"!M97,N`"5S(&AA(&%C97!T861O
M+@`E<R!H82!C86YC96QA9&\@(B5S(BX`)7,@:&$@<F5C:&%Z861O+@`E<R!H
M82!R97-P;VYD:61O(&$@=6YA(&-O;G-U;'1A(&1E('1I96UP;R!D:7-P;VYI
M8FQE+@`E<R!H82!R97-P;VYD:61O(&$@;&$@:6YV:71A8VGS;B!P87)A("(E
M<R(N`"5S(&QE(&AA(&EN9F]R;6%D;R!S;V)R92!S=2!T:65M<&\@9&ES<&]N
M:6)L92X`)7,@:&$@86-E<'1A9&\@<')O=FES:6]N86QM96YT92X`)7,@97-T
MX2!P<F5P87)A9&\@<&%R82!R96%L:7IA<B!L87,@;W!E<F%C:6]N97,@9&4@
M;6%N=&5N:6UI96YT;R!S96QE8V-I;VYA9&%S+D%C=&EV92!L87,@8V%S:6QL
M87,@9&4@;&%S(&]P97)A8VEO;F5S('%U92!D97-E82!E:F5C=71A<B!E;B!E
M<W1A(&]C87-I\VXN`$AA8V4@9F%L=&$@)7,`)7,@;6EN=71O<P!.;R!S92!H
M82!E;F-O;G1R861O("5S+@`E<R!D97-E82!C;VYO8V5R('-U('1I96UP;R!D
M:7-P;VYI8FQE+@`E<R!S;VQI8VET82!S=2!A<VES=&5N8VEA(&$@(B5S(BX`
M)7,@86P@)7,@9&4@)7,`)7,@<V4@:&$@8?%A9&ED;R!C;W)R96-T86UE;G1E
M(&$@(B5S(BX`)7,@9&5S96$@8V]R<F5G:7(@)7,N`"5S(&1E<V5A('!O;F5R
M;&4@86P@=&%N=&\@<V]B<F4@(B5S(BX`)7,@9&5S96$@<F5C:6)I<B!I;F9O
M<FUA8VGS;B!A8W1U86QI>F%D82!S;V)R92`B)7,B+@!$:7)E8V-I;VYE<R!D
M92`E<P!!9V5N9&$@9&4@)7,`3&EB<F5T82!D92!N;W1A<R!D92`E<P!487)E
M87,@9&4@)7,`)7,Z("5S`"5S.B`E<R`H)60F;F)S<#MD929N8G-P.R5D*0`E
M<SH@17-T92!M96YS86IE('!U961E('%U92!N;R!P<F]C961A(&1E('%U:65N
M('!A<F5C92!S97(N($5V:71E('-E9W5I<B!C=6%L<75I97(@=NUN8W5L;R!I
M;F-L=>UD;R!O('-U;6EN:7-T<F%R(&-U86QQ=6EE<B!I;F9O<FUA8VGS;B!P
M97)S;VYA;"!A;"!R96UI=&5N=&4N`"A!<&QI8V%R(&QO<R!C86UB:6]S('D@
M<&%S87(@82!L82!S:6=U:65N=&4@<&%N=&%L;&$N*0`H1&5S96-H87(@;&]S
M(&-A;6)I;W,@>2!R96=R97-A<B!A(&QA('!A;G1A;&QA(&1E(')E9&%C8VGS
M;BXI`"A(5$U,*0`H4_-L;R!T97AT;RD`*%)E9W)E<V%R(&$@;&$@<&%N=&%L
M;&$@9&4@<F5D86-C:?-N(&1E<W!UZ7,@9&4@87!L:6-A<B!L;W,@8V%M8FEO
M<R!H96-H;W,@:&%S=&$@96P@;6]M96YT;RX@3&]S(&-A;6)I;W,@9&4@;&$@
M<&%N=&%L;&$@86-T=6%L($Y/('-E(&%P;&EC87+A;BXI`"A%;G9I87(@96P@
M;65N<V%J92!T<F%S(&%P;&EC87(@=&]D;W,@;&]S(&-A;6)I;W,@:&5C:&]S
M(&AA<W1A(&%Q=>TN($QO<R!C86UB:6]S(&1E(&QA('!A;G1A;&QA(&%C='5A
M;"!.3R!S92!A<&QI8V%RX6XN*0`J($'Q861I<B#I<W1O<R!H86-I96YD;R!C
M;&EC(&5N($%C97!T87(@*@`J(%!O<B!F879O<BP@<V5L96-C:6]N92!L82AS
M*2!D:7)E8V-I\VXH97,I("H`+"!V96YT;W-O(``L('9E;G1O<V\@)7,@)7,`
M+"!V87)I86)L92!D92`E<R!A("5S`"TM('-E;&5C8VEO;F%R("TM`%-E(&AA
M(&5L:6UI;F%D;R`Q(&UE;G-A:F4N`%-E(&AA(&YO=&EF:6-A9&\@,2!M96YS
M86IE(&YO<FUA;"!A;"!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S+@!392!H
M82!N;W1I9FEC861O(#$@;65N<V%J92!N;W)M86PN`%-E(&AA(&YO=&EF:6-A
M9&\@,2!M96YS86IE('-P86T@86P@861M:6YI<W1R861O<B!D92!S:7-T96UA
M<RX`4V4@:&$@;F]T:69I8V%D;R`Q(&UE;G-A:F4@<W!A;2X`,3`P(&-A<F%C
M=&5R97,`,3`P,"!C87)A8W1E<F5S`$9O<FUA=&\@9&4@,3(@:&]R87,`1F]R
M;6%T;R!D92`R-"!H;W)A<P`R-"!H;W)A<P`R-3`@8V%R86-T97)E<P`U,#`@
M8V%R86-T97)E<P`\06YT97)I;W(`4&%R82!E<W1E(&)L;W%U92!H86-E(&9A
M;'1A('5N(&UO=&]R(&1E(&)A<V4@9&4@9&%T;W,N`%-E(&AA('!R;V1U8VED
M;R!U;B!E<G)O<B!I<G)E<&%R86)L90!392!H82!A9&IU;G1A9&\@82!E<W1E
M(&UE;G-A:F4@=6YA(&EM86=E;B!G<F%N9&4@;&QA;6%D82`E<RX`4V4@:&$@
M<F5C:6)I9&\@=6X@879I<V\@9&4@9&5V;VQU8VGS;B!D96P@9&5S=&EN871A
M<FEO(&1E('5N(&UE;G-A:F4@<75E(&AA8NUA(&5N=FEA9&\N`$AA8V4@9F%L
M=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A('!A<F$@8VEF<F%R('5N(&UE;G-A
M:F4N`$AA8V4@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A('!A<F$@8V]M
M<')O8F%R('5N(&UE;G-A:F4@9FER;6%D;RX`2&%C96X@9F%L=&$@=6YA(&-L
M879E(%!'4"!P^F)L:6-A+"!U;F$@8VQA=F4@4$=0('!R:79A9&$@>2!U;F$@
M9G)A<V4@8VQA=F4@<&%R82!D97-C:69R87(@=6X@;65N<V%J92X`2&%C96X@
M9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A+"!U;F$@8VQA=F4@4$=0('!R
M:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@<&%R82!F:7)M87(@=6X@;65N<V%J
M92X`2&%C96X@9F%L=&$@=6YA(&-L879E(%,O34E-12!P^F)L:6-A+"!U;F$@
M8VQA=F4@4R]-24U%('!R:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@<&%R82!D
M97-C:69R87(@=6X@;65N<V%J92X`2&%C96X@9F%L=&$@=6YA(&-L879E(%,O
M34E-12!P^F)L:6-A+"!U;F$@8VQA=F4@4R]-24U%('!R:79A9&$@>2!U;F$@
M9G)A<V4@8VQA=F4@<&%R82!F:7)M87(@=6X@;65N<V%J92X`2&%C92!F86QT
M82!U;F$@8VQA=F4@4TU)344@</IB;&EC82!P87)A(&-I9G)A<B!U;B!M96YS
M86IE+@!.=6)E<R!M871I;F%L97,`3&EG97)A(&QL=79I82!M871I;F%L`$QL
M=79I82!M871I;F%L`$%G=6%C97)O<R!M871I;F%L97,`06=U86-E<F\@;6%T
M:6YA;"!D92!N:65V90!!32]030!9`$E$(&1E($%020!!8V5R8V$@9&5L(&5D
M:71O<@!!8V5R8V$@9&4N+BX`26YF97)I;W(@06)S+@!%;B!M961I;R!!8G,N
M`$%C97!T87(@>2!A\6%D:7(@82!L82!A9V5N9&$`06-E<'1A<B!P971I8VGS
M;@!!8V5P=&%D80!!8V5P=&%D83H@`%-E(&AA(&1E;F5G861O(&5L(&%C8V5S
M;R!A;"!C<F5A<B!E;"!D:7)E8W1O<FEO(%9&4RX`4V4@:&$@9&5N96=A9&\@
M96P@86-C97-O(&%L(&-R96%R(&5L(&%R8VAI=F\@5D93+@!)9&5N=&ED860`
M0V]N=')A<V7Q82!D92!A8V-E<V\`261E;G1I9&%D(&)L;W%U96%D82X`3F]M
M8G)E(&1E(&QA(&-U96YT83H`0V]N=&%B:6QI9&%D`$%C8VEO;F5S`$'Q861I
M<@!!\6%D:7(@)7,@82!L82!,:6)R971A(&1E(&1I<F5C8VEO;F5S`$'Q861I
M<B!G<G5P;R!D97-C96YD:65N=&4`0?%A9&ER('!R:79I;&5G:6\@9&5S8V5N
M9&EE;G1E`$'Q861I<B!A<77M.@!!\6%D:7(@9W)U<&\`0?%A9&ER('!R:79I
M;&5G:6\`0?%A9&ER(&$@(B5S(B!U;B!G<G5P;R!D97-C96YD:65N=&4`0?%A
M9&ER(&$@(B5S(B!U;B!P<FEV:6QE9VEO(&1E<V-E;F1I96YT90!!\6%D:7(@
M=6X@=7-U87)I;SH`0?%A9&ER(&-O;'5M;F$`0?%A9&ER(&UI96UB<F]S`$'Q
M861I<B!P87(`0?%A9&ER(&9U96YT90!!\6%D:7(@96P@;65N^B`E<R!C;VUO
M('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL80!!\6%D:7(@82!L82!A9V5N9&$`
M0?%A9&ER(&$@;&%S(&1I<F5C8VEO;F5S.@!!\6%D:7(@82!L87,@9&ER96-C
M:6]N97,Z`$'Q861I<B!A(&QA(&%G96YD80!!\6%D:7(@=7-U87)I;P!392!H
M82!A\6%D:61O("(E<R(@8V]M;R!A9&IU;G1O+@!392!H82!A\6%D:61O("(E
M<R(@86P@<VES=&5M82P@<&5R;R!N;R!S92!P=65D92!A\6%D:7(@;&$@:6YF
M;W)M86-I\VX@861I8VEO;F%L(&1E(&%L=&$Z("5S+@!392!H82!A\6%D:61O
M("(E<R(@86P@<VES=&5M82X@66$@<'5E9&4@:6YI8VEA<B!L82!S97-I\VXN
M`$QA(&%D:6-I\VX@9&4@=7-U87)I;W,@97-TX2!D97-H86)I;&ET861A+@!#
M86)E8V5R87,@861I8VEO;F%L97,@;6]S=')A9&%S(&%L('9I<W5A;&EZ87(Z
M(#QE;3XH;W!C:6]N86PL(&EN9&EQ=64@8V%D82!C86)E8V5R82!E;B!L[6YE
M87,@9&ES=&EN=&%S*3PO96T^`%-E('!U961E('9I<W5A;&EZ87(@)7,@;&$@
M:6YF;W)M86-I\VX@861I8VEO;F%L+@!$971A;&QE<R!D92!I;F9O<FUA8VGS
M;B!A9&EC:6]N86P`1&5T86QL97,@861I8VEO;F%L97,@9&5L(&UE;G-A:F4`
M4V4@<'5E9&5N('9I<W5A;&EZ87(@)7,@;&]S(&1E=&%L;&5S(&%D:6-I;VYA
M;&5S(&1E;"!M96YS86IE+@!$971A;&QE<R!A9&EC:6]N86QE<R!D92!M96YS
M86IE(&1E(&5R<F]R`%-E('!U961E;B!V:7-U86QI>F%R("5S(&QO<R!D971A
M;&QE<R!A9&EC:6]N86QE<R!D92!M96YS86IE(&1E(&5R<F]R+@!$:7)E8V-I
M\VX`1&ER96-C:6]N97,`3&EB<F5T87,@9&4@9&ER96-C:6]N97,`1&ER96-C
M:6]N97,@82!L87,@<75E($)#0R!T;V1O<R!L;W,@;65N<V%J97,Z(#QE;3XH
M;W!C:6]N86PL(&EN9&EQ=64@8V%D82!D:7)E8V-I\VX@96X@=6YA(&SM;F5A
M(&1I<W1I;G1A*3PO96T^`$1I<F5C8VEO;F5S(&5N;&%Z861A<R!E>'!L[6-I
M=&%M96YT92!A(&5S=&$@:61E;G1I9&%D.B`\96T^*&]P8VEO;F%L+"!I;F1I
M<75E(&-A9&$@9&ER96-C:?-N(&5N('5N82!L[6YE82!D:7-T:6YT82D\+V5M
M/@!!9&UI;FES=')A9&]R("T@9&5F:6YE('!R:79I;&5G:6]S(&1E(&]T<F]S
M('5S=6%R:6]S`$%D;6EN:7-T<F%C:?-N`$%N=6YC:6]S`$%F9V%N:7-TX6X`
M06QB86YI80!!<F=E;&EA`$%L:6%S`$%L:6YE87(`06QI;F5A8VGS;CH`5&]D
M;W,`5&]D;W,@;&]S('5S=6%R:6]S(&%U=&5N=&EF:6-A9&]S`%1O9&]S(&QO
M<R!G<G5P;W,`5&]D;W,@;&]S('!R:79I;&5G:6]S`%1O9&]S(&QO<R!L861O
M<P!4;V1O<R!L;W,@;65N<V%J97,@9&4@;&$H<RD@<VEG=6EE;G1E*',I(&-A
M<G!E=&$H<RD@<V4@9&5S8V%R9V%RX6X@8V]M;R!U;B#Z;FEC;R!A<F-H:79O
M($U"3U@Z(`!392!E;&EM:6YA<N%N('!E<FUA;F5N=&5M96YT92!T;V1O<R!L
M;W,@;65N<V%J97,@9&4@<W4@8V%R<&5T82`B)7,B(&-O;B!A;G1I9_QE9&%D
M('-U<&5R:6]R(&$@)7,@9.UA<RX`4V4@96QI;6EN87+A;B!T;V1O<R!L;W,@
M861J=6YT;W,@=FEN8W5L861O<R!C;VX@;>%S(&1E("5S(&UE<V5S(&1E(&%N
M=&EG_&5D860N`%-E(&5L:6UI;F%RX6X@=&]D87,@;&%S(&-A<G!E=&%S(")%
M;G9I861O<R(@8V]N(&WA<R!D92`E<R!M97-E<R!D92!A;G1I9_QE9&%D+@!3
M92!H86X@96QI;6EN861O(&-O<G)E8W1A;65N=&4@9&4@;&$@8V%R<&5T82`B
M)7,B('1O9&]S(&QO<R!D97)E8VAO<R!D96P@=7-U87)I;R`B)7,B+@"_4&5R
M;6ET:7(@;&$@8W)E86-I\VX@9&4@8V%R<&5T87,_`+]!<&QI8V%R(')E9VQA
M<R!D92!F:6QT<F%D;R!A(&-U86QQ=6EE<B!B=7KS;C\`4&5R;6ET:7(@=F%R
M:6%S(&1I<F5C8VEO;F5S`+]097)M:71I<B!C;VYF:6=U<F%C:?-N(&1E('1I
M<&\@9&4@;&ES=&%S(&]R9&5N861A<S\`66$@97AI<W1E`$%C8V5S;R!)35-0
M(&%L=&5R;F%T:79O`$-L879E($E-4U`@86QT97)N871I=F$`57-U87)I;R!)
M35!3(&%L=&5R;F%T:79O`$1I<F5C8VGS;B!E;&5C='+S;FEC82!A;'1E<FYA
M=&EV80!0;&%N=&EL;&%S(&%L=&5R;F%T:79A<P!497AT;R!A;'1E<FYA=&EV
M;P!087)T97,@86QT97)N871I=F%S(&1E(&5S=&$@<V5C8VGS;CH`4VEE;7!R
M90!'=6%R9&%R('-I96UP<F4@;&]S(&%D:G5N=&]S`%-A;6]A($%M97)I8V%N
M80!392!H82!P<F]D=6-I9&\@=6X@97)R;W(@86P@:6YT96YT87(@96QI;6EN
M87(@96P@861J=6YT;RX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O
M<B!)34%0.B``4V4@:&$@:6YD:6-A9&\@=6X@=F%L;W(@:6QE9V%L+@!392!H
M82!P<F]D=6-I9&\@=6X@97)R;W(@9&5S8V]N;V-I9&\N`%-E(&AA('!R;V1U
M8VED;R!U;B!E<G)O<B!D97-C;VYO8VED;R!A;"!C<F5A<B!L82!N;W1A+@!3
M92!H82!P<F]D=6-I9&\@=6X@97)R;W(@9&5S8V]N;V-I9&\@86P@8W)E87(@
M;&$@=&%R96$N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&$`4')O>'D@86[S;FEM
M;P!297-P=65S=&$`4F5S<&]N9&ED;P!-96YS86IE<R!R97-P;VYD:61O<P!!
M;G3A<G1I9&$`06YT:6=U82!Y($)A<F)A9&]S`$%P;&EC86-I\VX`3&ES=&$@
M9&4@87!L:6-A8VEO;F5S`$QA(&%P;&EC86-I\VX@97-TX2!L:7-T82X`07!L
M:6-A<B!F:6QT<F]S`$%P;&EC87(@9FEL=')O<R!E;B`E<P"_07!L:6-A<B!R
M96=L87,@9&4@9FEL=')A9&\@86P@:6YI8VEA<B!S97-I\VX_`+]!<&QI8V%R
M(')E9VQA<R!D92!F:6QT<F%D;R!A;"!V:7-U86QI>F%R(&QA(&-A<G!E=&$@
M9&4@14Y44D%$03\`07!L:6-A<B!A(')E8W5R<V]S(&-O;7!A<G1I9&]S(&1E
M<V-E;F1I96YT97,`07!R;V)A<@!486UA\6\@87!R;WAI;6%D;P!!8G)I;`!!
M<N%B:6=O("A7:6YD;W=S+3$R-38I`%1A;6'Q;R!D96P@87)C:&EV;P!.;VUB
M<F4@9&5L(&%R8VAI=F\`OT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM
M:6YA<B!E<W1A(&1E9FEN:6-I\VX@9&4@0V%R<&5T82!6:7)T=6%L/P"_17-T
MX2!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&5S=&$@8VQA=F4@</IB
M;&EC83\`OT5S=&$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!S=2!C
M;&%V93\@**%.;R!E<R!.041!(')E8V]M96YD86)L92$I`+]%<W3A('-E9W5R
M;R!D92!Q=64@9&5S96$@:&%C97(@Z7-T;S\`OT5S=&$@<V5G=7)O(&1E('%U
M92!D97-E82!E;&EM:6YA<B!L82!S;VQI8VET=60@9&4@86QT82!D92`E<S\`
MOT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!015)-04Y%3E1%
M345.5$4@97-T;W,@;65N<V%J97,_`+]%<W3A('-E9W5R;R!D92!Q=64@9&5S
M96$@96QI;6EN87(@4$5234%.14Y414U%3E1%(&5S=&4@861J=6YT;S\`OT5S
M=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B`B)7,B('D@=&]D;W,@
M<W5S('-U8F=R=7!O<S\`OT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!V86-I
M87(@97-T82!C87)P971A/P"_17-TX2!S96=U<F\@9&4@<75E(&1E<V5A('9A
M8VEA<B!L82!C87)P971A(&1E('-P86T_`+]%<W3A('-E9W5R;R!D92!Q=64@
M9&5S96$@=F%C:6%R(&QA('!A<&5L97)A/P"_17-TX2!S96=U<F\@9&4@<75E
M(&1E<V5A(&5L:6UI;F%R(%!%4DU!3D5.5$5-14Y412!E<W1O<R!M96YS86IE
M<S\`OT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!C;VYS:61E<F%R(&5S=&4@
M;65N<V%J92!C;VUO(&EN;V9E;G-I=F\_`+]%<W3A('-E9W5R;R!D92!Q=64@
M9&5S96$@8V]N<VED97)A<B!E<W1E(&UE;G-A:F4@8V]M;R!S<&%M/P!!<F=E
M;G1I;F$`07)M96YI80!!<FUE;FEO("A!4DU30TE)+3@I`%!O<B!H;W)A(&1E
M(&QL96=A9&$`07)T90!!<G5B80!!<V-E;F1E;G1E`$ES;&$@07-C96YS:?-N
M`$=RX69I8V]S($%S8VEI`%)E9VGS;B!D92!!<VEA+U!A8^UF:6-O`$-O;G-U
M;'1A<@"_4V]L:6-I=&%R(&-O;F9I<FUA8VGS;B!A;G1E<R!D92!R96%L:7IA
M<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O/P!#;VQU;6YA<R!D92!A
M<VEG;F%C:?-N`$%D:G5N=&%R(&%R8VAI=F]S`+]!9&IU;G1A<B!U;F$@8V]P
M:6$@9&4@;&$@8VQA=F4@4$=0('#Z8FQI8V$@86P@;65N<V%J93\`07)C:&EV
M;R!A9&IU;G1O.@!%;"!A<F-H:79O(&%D:G5N=&\@(B5S(B!S=7!E<F$@96P@
M;.UM:71E(&1E('1A;6'Q;R!D92!A9&IU;G1O<RX@3D\@<V4@:&$@861J=6YT
M861O(&5L(&%R8VAI=F\N`%-E(&%D:G5N=&$@;&$@<F5S<'5E<W1A(&$@;&$@
M<V]L:6-I='5D(&1E(&%G96YD82!Q=64@:&%B[6$@:&5C:&\N`$%D:G5N=&\`
M4V4@:&$@8F]R<F%D;R!E;"!A9&IU;G1O("5S+@!);F9O<FUA8VGS;B!D92!A
M9&IU;G1O`$%D:G5N=&\@96QI;6EN861O.B!4:7!O(&1E(&%D:G5N=&\@;W)I
M9VEN86P`061J=6YT;W,`26YT96YT82!E;&EM:6YA<B!U;B!G<G5P;R!I;F5X
M:7-T96YT92X`26YT96YT82!E;&EM:6YA<B!U;B!P<FEV:6QE9VEO(&EN97AI
M<W1E;G1E+@!);G1E;G1A(&UO9&EF:6-A<B!U;B!P<FEV:6QE9VEO(&EN97AI
M<W1E;G1E+@!);G1E;G1A(&UO9&EF:6-A<B!U;B!R96-U<G-O(&-O;7!A<G1I
M9&\@:6YE>&ES=&5N=&4N`$%S:7-T96YT97,`071E;F-I\VX`071R:6)U=&]S
M`$%G;W-T;P!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@3F\@<V4@
M96YC;VYT<O,@;&$@97AT96YS:?-N(&EM87`@;F5C97-A<FEA+@!!=71H7V-Y
M<G5S.B!%;"!M;W1O<B!C87)E8V4@9&4@;&%S(&-A<&%C:61A9&5S(&YE8V5S
M87)I87,N`$%U=&A?8WER=7,Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS
M;B!I;6%P(&YE8V5S87)I82X`075T:%]F='`Z($YO('-E(&5N8V]N='+S(&QA
M(&5X=&5N<VGS;B!&5%`@;F5C97-A<FEA+B!#;VUP:6QE(%!(4"!C;VX@;&$@
M;W!C:?-N("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!.;R!S92!E;F-O;G1R
M\R!L82!E>'1E;G-I\VX@24U!4"!N96-E<V%R:6$N`$%U=&A?:6UP.B!H86-E
M(&9A;'1A(&QA(&5X=&5N<VGS;B!)34%0+@!!=71H7VMR8C4Z($YO('-E(&5N
M8V]N='+S(&QA(&5X=&5N<VGS;B!K<F(U(&YE8V5S87)I82X`075T:%]L9&%P
M.B!.;R!E<W3A('-O<&]R=&%D82!L82!A9&EC:?-N(&1E('5S=6%R:6]S(&1E
M($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!.;R!E<W3A('-O<&]R=&%D
M82!L82!E;&EM:6YA8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N($Q$
M05`@;F5C97-A<FEA+@!!=71H7VQD87`Z($YO('-E('!U961E(&'Q861I<B!E
M;"!U<W5A<FEO("5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L('-E<G9I9&]R
M.B``075T:%]L9&%P.B!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L('5S=6%R:6\@
M)7,`075T:%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A;&EZ87(@96P@=7-U87)I
M;R`E<P!!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&%C='5A;&EZ
M86-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>0!!=71H7VUC
M86PZ($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!-0T%,(&YE8V5S87)I
M82X`075T:%]S;6)A=71H.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@
M<VUB875T:"!N96-E<V%R:6$N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C
M;VX@96P@<V5R=FED;W(@24U!4"X`1F%L;/,@;&$@875T96YT:69I8V%C:?-N
M`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;BX@)7,`16P@<V5R=FED;W(@4D%$
M2553(&AA(')E8VAA>F%D;R!L82!A=71E;G1I9FEC86-I\VXN`$9A;&SS(&QA
M(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@<V5R=FED;W(@1E10+@!&86QL\R!L
M82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R(%--0BX`OTUO<W1R
M87(@875T;VWA=&EC86UE;G1E(&QA<R!I;>%G96YE<R!D92!L;W,@;65N<V%J
M97,@2%1-3"!S:2!E;"!R96UI=&5N=&4@97-TX2!E;B!M:2!L:6)R971A(&1E
M(&1I<F5C8VEO;F5S/P!,:6)R971A<R!D92!D:7)E8V-I;VYE<R!D:7-P;VYI
M8FQE<SH`0V%M<&]S(&1I<W!O;FEB;&5S.@!%<W!E<F%N9&\@<F5S<'5E<W1A
M`$%Z97)B86EJ86X`17AC=7-A<R!"3T9(`%)E9W)E<V%R(&$@)7,@*%]K*0!2
M96=R97-A<B!A("5S`%)E9W)E<V%R(&%L(.UN9&EC92!D92!M96YS86IE<P!2
M96=R97-A<B!A(&QA('9I<W1A('!O<B!S96-U96YC:6%S`$9O;F1O`$-O;&]R
M(&1E(&9O;F1O`$-O;G1R87-E\6$@:V5R8F5R;W,@:6YC;W)R96-T82X`3F]M
M8G)E(&1E('5S=6%R:6\@:V5R8F5R;W,@:6YC;W)R96-T;RX`57-U87)I;R!O
M(&-O;G1R87-E\6$@:6YC;W)R96-T;W,N`%!E=&EC:?-N(&EN8V]R<F5C=&$@
M;R!M86QF;W)M861A+B!%;"!S97)V:61O<B!H82!R97-P;VYD:61O.B`E<P!0
M971I8VGS;B!I;G;A;&ED83H@)7,N`$)A:&%M87,`0F%H<F%I;@!"X6QT:6-O
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!.;R!S92!E;F-O
M;G1R\R!E;"!D:7)E8W1O<FEO(&)A<V4@9&4@:6WA9V5N97,@(B5S(BX`3.UN
M96$@8F%S90!"8V,`0F5L87)U<P!"Z6QG:6-A`$)E;&EZ90!!(&-O;G1I;G5A
M8VGS;B!S92!M=65S=')A(&5L(&UE;G-A:F4@9&4@:6YF;W)M86-I\VX@9&4@
M97-T861O+@!"96YI;@!"97)M=61A<P!":'5T86X`0W5M<&QE8?%O<P!,:7-T
M82!N96=R80!.;R!S92!E;F-O;G1R\R!E;"!B;&]Q=64@(B5S(B!D92!L82!A
M<&QI8V%C:?-N("(E<R(N`$]P8VEO;F5S(&1E(&)L;W%U90!4:7!O(&1E(&)L
M;W%U90"_0FQO<75E87(@;&%S(&EMX6=E;F5S(&1E(&QO<R!M96YS86IE<R!(
M5$U,(&$@;65N;W,@<75E('-E('-O;&EC:71E;B!E<W!E8^UF:6-A;65N=&4_
M`$-U97)P;P!.96=R:71A`$)O;&EV:6$`36%R8V%D;W)E<P!";W)D90!'<F]S
M;W(@9&5L(&)O<F1E.@!";W)D97,`0F]S;FEA($AE<GIE9V]V:6YA`$%M8F]S
M`%1A;G1O(&5N(&QA<R!C86)E8V5R87,@8V]M;R!E;B!E;"!C=65R<&\@9&5L
M(&UE;G-A:F4`0F]T<W=A;F$`26YF97)I;W(`27-L82!D92!";W5V970`0G)A
M<VEL`%1E<G)I=&]R:6\@;V-EX6YI8V\@9&4@;&$@26YD:6$@8G)I=.%N:6-A
M`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$QI<W1A(&1E<V]R9&5N861A
M`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!087)A('5S87(@0U)!32U-1#4@
M;R!$24=%4U0M340U(&AA>2!Q=64@=&5N97(@:6YS=&%L861O(&5L('!A<75E
M=&4@075T:%]305-,+@!#4D,`4'5N=&]S(&1E(&1I<W1R:6)U8VGS;B!#4D,`
M4')O<&EE9&%D97,@9&4@7V-E;&1A+BXN`%]*=65G;R!D92!C87)A8W1E<F5S
M`$YO('-E(&AA(&9I;F%L:7IA9&\@96P@:6YI8VEO(&1E(&QA(&-A8VCI+@!!
M9V5N9&$`0V%L;6$`0V%M8F]Y80!#86UE<OIN`$YO('-E('!U961E(&-O;F5C
M=&%R(&%L('-E<G9I9&]R(&1E(&-O<G)E;R!R96UO=&\N`$YO('-E('!U961E
M(&-O;F5C=&%R(&%L('-E<G9I9&]R(&1E(&-O<G)E;R!R96UO=&\Z(`!.;R!S
M92!P=65D92!M;W-T<F%R("T@96X@96P@8G5Z\VX@86-T=6%L('/S;&\@<V4@
M:&$@96YC;VYT<F%D;R`E<R!P87)T97,@9&4@)7,@9&4@97-T92!M96YS86IE
M+@!.;R!S92!P=65D92!R96%J=7-T87(@;&$@8VQA=F4@875T;VWA=&EC86UE
M;G1E+"!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"!A9&UI;FES=')A9&]R
M(&1E;"!S:7-T96UA+@!.;R!S92!P=65D92!E<V-R:6)I<B!E;B!E;"!A<F-H
M:79O("(E<R(`3F\@<V4@<'5E9&5N(&%D;6EN:7-T<F%R(&UA;F5J861O<F5S
M(&1E('-E<VGS;B!E>'1E<FYO<RX`3F\@<V4@<'5E9&4@8V]N96-T87(@86P@
M<V5R=FED;W(@24U!4#H@)7,`3F\@<V4@<'5E9&4@86)R:7(@96P@87)C:&EV
M;R`B)7,B+@!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@;65N<V%J90!#86YC
M96QA<B!I;F9O<FUE(&1E('!R;V)L96UA<P!#86YC96QA<B!E<W1E(&UE;G-A
M:F4@9&5S96-H87+A('!E<FUA;F5N=&5M96YT92!S=2!C;VYT96YI9&\N`$YO
M('-E('!U961E(&5L:6UI;F%R(&5L(&%R8VAI=F\@(B5S(BX`3F\@<V4@96YC
M=65N=')A('5N(&1I<F5C=&]R:6\@=&5M<&]R86PN`$YO('-E('!U961E(&-O
M;G1I;G5A<B!S:6X@96P@<&%RX6UE=')O("=T87)G971&:6QE)RX`3F\@<V4@
M<'5E9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R`B)7,B+@!.;R!S92!P=65D
M92!E;&EM:6YA<BP@=&EE;F4@)60@9&5S8V5N9&EE;G1E<RX`3F\@<V4@<'5E
M9&4@<F5O<F1E;F%R+"!E;"!N^FUE<F\@9&4@96YT<F%D87,@<75E('-E(&1E
M<V5A(&]R9&5N87(@;F\@8V]I;F-I9&4@8V]N(&QA<R!A;&UA8V5N861A<RX`
M3F\@<V4@<'5E9&4@9&ER:6=I<B!E;"!M96YS86IE(&%L(&[Z;65R;R!E<W!E
M8VEF:6-A9&\N`$-A8F\@5F5R9&4`4W5B=.UT=6QO`%!R;W9E961O<@!#871E
M9V]R[6%S('D@971I<75E=&%S`$ES;&%S($-A:6WA;@!#8P!496SI9F]N;R!M
M\W9I;`!0<F]P:65D861E<R!D92!C96QD80!-87)G96X@9&4@8V5L9&$Z`%!R
M;W!I961A9&5S(&1E(&-E;&1A`$5S<&%C:6%D;R!D92!C96QD83H`5&5LZ69O
M;F\@;?-V:6P`0^EL=&EC;R`H25-/+3@X-3DM,30I`$-E;G1R87(`4F5P^F)L
M:6-A($-E;G1R;V%F<FEC86YA`$5U<F]P82!#96YT<F%L("A)4T\M.#@U.2TR
M*0!$971A;&QE<R!D96P@8V5R=&EF:6-A9&\`4')O<&EE=&%R:6\@9&5L(&-E
M<G1I9FEC861O`%!O;.UT:6-A<R!D96P@8V5R=&EF:6-A9&\`3F\@<V4@9&ES
M<&]N92!D92!I;7!O<G1A8VGS;B!D92!C97)T:69I8V%D;W,N($5S=&4@<V5R
M=FED;W(@;F\@=&EE;F4@86-T:79A9&$@;&$@8V%R9V$@9&4@87)C:&EV;W,N
M`$-H860`3V-U<&%N=&4`0V%M8FEA<@!#86UB:6%R('1O9&]S`$-A;6)I87(@
M8V%R<&5T80!#86UB:64@;&$@8V]N=')A<V7Q80!#86UB:6$@;W!C:6]N97,@
M9&4@=FES=6%L:7IA8VGS;B!T86QE<R!C;VUO(&QA(&-A;G1I9&%D(&1E(&UE
M;G-A:F5S('!O<B!PX6=I;F$@>2!C\VUO(&]R9&5N87)L;W,N`$-A;6)I82!L
M82!C;VYF:6=U<F%C:?-N(&1E('-E<G9I9&]R('D@8V%R<&5T82!D92!C;W)R
M96\N`$-A;6)I82!E;"!N;VUB<F4@>2!L82!D:7)E8V-I\VX@96QE8W1R\VYI
M8V$@=FES:6)L97,@86P@;&5E<B!O(')E<W!O;F1E<B!A('-U<R!M96YS86IE
M<RX`0V%M8FEA(&5L(&YO;6)R92P@9&ER96-C:?-N(&5L96-T<O-N:6-A('D@
M9FER;6$@=FES:6)L97,@86P@;&5E<B!O(')E<W!O;F1E<B!A('-U<R!M96YS
M86IE<RX`3&$@8V]N9FEG=7)A8VGS;B!A8W1U86P@;F\@<V]P;W)T82!E;"!C
M86UB:6\@9&4@8V]N=')A<V7Q87,N(%#S;F=A<V4@96X@8V]N=&%C=&\@8V]N
M(&5L(&%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N`$=RX69I8V\`0V%R86-T
M97)E<R!V:7-U86QI>F%D;W,Z`%9E<FEF:6-A<B!?=NUN8W5L;RXN+@!#;VUP
M<F]B87(@8V]R<F5O(&YU979O`$-O;7!R;V)A<B!?5&]D87,O3FEN9W5N80!#
M;VUP<F]B87(@=&]D;W,@;&]S('-E<G9I9&]R97,@9&4@;&]S('%U92!Q=6EE
M<F4@=')A97(@8V]R<F5O.@"_0V]M<')O8F%R(&]R=&]G<F%F[6$@86YT97,@
M9&4@96YV:6%R('5N(&UE;G-A:F4_`$-H:6QE`$-H:6YA`$-H:6YO('-I;7!L
M:69I8V%D;R`H1T(R,S$R*0!#:&EN;R!T<F%D:6-I;VYA;"`H0FEG-2D`16QE
M9VER(&%C8VGS;CH`07!L:6-A8VGS;CH`16QI:F$@=6X@<V5R=FED;W(@9&4@
M8V]R<F5O.@!396QE8V-I;VYE('5N82!C;VEN8VED96YC:6$@;R!M;V1I9FEQ
M=64@;&$@9&ER96-C:?-N(&1E(&QA(&1E<F5C:&$Z`$5L:6IA('5N82!C;VYT
M<F%S9?%A`$5L:6IA('5N(&YO;6)R92!D92!U<W5A<FEO`$5L:6IA(&/S;6\@
M;6]S=')A<B!L87,@9F5C:&%S.@!396QE8V-I;VYA<B!T:7!O(&1E(&5S=&EL
M;R!D92!L:7-T82`H<&%R82!L:7-T87,@;W)D96YA9&%S*0!%;&EJ82!L82!L
M:6)R971A(&1E(&1I<F5C8VEO;F5S('5S861A(&%L(&'Q861I<B!D:7)E8V-I
M;VYE<RX`16QI:F$@96P@;W)D96X@9&4@8OIS<75E9&$@96X@;&%S(&QI8G)E
M=&%S(&%L(&5X<&%N9&ER(&1I<F5C8VEO;F5S+@!)<VQA(&1E(%!A<V-U80!.
M;R!S92!E;F-O;G1R\R!L82!D969I;FEC:?-N(&1E(&-L87-E(&1E("5S+@!,
M:6UP:6%R`$5L:6UI;F%R(&5T:7%U971A<R!-4T]F9FEC90!";W)R87(@8V]N
M<W5L=&$`0F]R<F%R('5S=6%R:6\Z("5S`$)O<G)A<B!U<W5A<FEO`$)O<G)A
M<B!D871O<R!D96P@=7-U87)I;P!$97-P96IA9&\@=&%R9.UO`%!U;'-E("5S
M('!A<F$@8V]N=F5R=&ER(&5L(&%R8VAI=F\@9&4@:6UA9V5N(&$@=6X@9F]R
M;6%T;R!S;W!O<G1A9&\@<&]R('-U(&YA=F5G861O<BX`4'5L<V4@)7,@<&%R
M82!D97-C87)G87(@;&$@:6UA9V5N+@!0=6QS92`E<R!P87)A(&ER(&$@;&$@
M<.%G:6YA(&1E(&=E<W1I\VX@9&4@)7,N`%!U;'-E("5S('!A<F$@=F5R(&5L
M(&-O;G1E;FED;R!(5$U,(&5N('5N82!V96YT86YA('-E<&%R861A+@!0=6QS
M92`E<R!P87)A('9E<B!U;F$@;6EN:6%T=7)A(&1E(&QA(&EM86=E;BX`4'5L
M<V4@)7,@<&%R82!V97(@96P@861J=6YT;R!E;B!U;F$@=F5N=&%N82!S97!A
M<F%D82X`4'5L<V4@)7,@<&%R82!V97(@97-T82!P87)T92!M=6QT:7!A<G1E
M+W)E;&%C:6]N861A(&5N('5N82!V96YT86YA('-E<&%R861A+@!0=6QS92!A
M<77M('!A<F$@34]35%)!4B!L87,@:6WA9V5N97,`4'5L<V4@<V]B<F4@=6YA
M(&1E(&QA<R!L:6)R971A<R!D92!D:7)E8V-I;VYE<R!Y(&QU96=O('-E;&5C
M8VEO;F4@;&]S(&-A;7!O<R!P;W(@;&]S('%U92!D97-E82!B=7-C87(N`$AA
M9V$@8VQI8VL@<&%R82!S96=U:7(`4'5L<V4@<&%R82!G=6%R9&%R(&QA(&-L
M879E(%!'4"!P^F)L:6-A(&5N(&QA($QI8G)E=&$@9&4@9&ER96-C:6]N97,`
M4'5L<V4@<&%R82!G=6%R9&%R(&5L(&-E<G1I9FEC861O(%,O34E-12!D92`E
M<R!E;B!L82!,:6)R971A(&1E(&1I<F5C8VEO;F5S`$-L:6-K871E;&P@<&]R
M($A45%``06P@<'5L<V%R(&5N(&QA(&1I<F5C8VGS;B!S92!R961A8W1A<N$@
M=6X@;65N<V%J92!P87)A(&5L(')E;6ET96YT90!!;"!P=6QS87(@96X@;&$@
M9&ER96-C:?-N('-E(&%B<FERX2!E;"!M96YS86IE`$-E<G)A<@!#97)R87(@
M=F5N=&%N80!#97)R87(@97-T82!V96YT86YA`$-A<G!E=&$@8V5R<F%D80!.
M=6)E<P!.=6)E<R!T96UP<F%N87,`;G5B;W-O`$ES;&%S(&1E(&-O8V]S("A+
M965L:6YG*0!#;VQA<'-A<@!#;VQA<'-A<B!T;V1A<P!#;VQA<'-A<B!T;V1A
M<R!L87,@8V%R<&5T87,`0V]L87!S87(@8V%R<&5T80!/8W5L=&%R(&)A<G)A
M(&QA=&5R86P`0V]L87!S87(@8F]R9&5S`$-O;&]M8FEA`$-O;&]R`$EN9&EC
M861O<B!D92!C;VQO<CH@`%-E;&5C=&]R(&1E(&-O;&]R`%-E;&5C8VGS;B!D
M92!C;VQO<@!#;VQU;6YA<SH`5.UT=6QO<R!D92!L87,@8V]L=6UN87,`0_-M
M:6-S`$-O;6%N9&\`26YTZ7)P<BX@8V]M86YD;W,`0V]M96YT87)I;P!.;VUB
M<F4@8V]M^FX`0V]M;W)O<P!#;VUP8?'M80!497)M:6YA9&\`4F5D86-T87(@
M;W1R;R!M96YS86IE`+]2961A8W1A<B!M96YS86IE<R!E;B!U;F$@=F5N=&%N
M82!S97!A<F%D83\`OU)E9&%C=&%R(&UE;G-A:F5S('!O<B!O;6ES:?-N(&5N
M('5N(&5N=&]R;F\@1U5)(&1E($A434P@*'-I(&5L(&YA=F5G861O<B!L;R!S
M;W!O<G1A*3\`3W)D96YA9&]R97,`0V]N9&EC:?-N`$-O;F1I8VEO;F5S`$1I
M9F5R96YC:6%S(&1E(&QA(&-O;F9I9W5R86-I\VX`0V]N9FEG=7)A8VGS;B!P
M87)A('-I;F-R;VYI>F%C:?-N(&-O;B!01$%S+"!-\W9I;&5S(&-O;B!A9V5N
M9&$@>2!/=71L;V]K+@!,82!C;VYF:6=U<F%C:?-N(&5S=.$@9&5S86-T=6%L
M:7IA9&$N`$-O;F9I9W5R87(@)7,`0V]N9FEG=7)A(&/S;6\@<V4@;75E<W1R
M86X@;&]S(&UE;G-A:F5S+@!#;VYF:6=U<F%R(&QA<R!O<&-I;VYE<R!D92!V
M:7-T82!P<F5V:6$@9&5L(&-O<G)E;RX`0V]N9FER;6%R(&-O;G1R87-E\6$`
M0V]N9V\`0V]N9V\L(%)E</IB;&EC82!$96UO8W+A=&EC82!D96P`0V]N97AI
M\VX@9&5S86-T:79A9&$@<&]R(&5L('-E<G9I9&]R($E-05`N`$9A;&SS(&QA
M(&-O;F5X:?-N+@!&86QL\R!L82!C;VYE>&GS;CH@`%-E(&AA(')E8VAA>F%D
M;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RX`
M4V4@:&$@<F5C:&%Z861O(&QA(&-O;F5X:?-N(&%L('-E<G9I9&]R(&1E(&-L
M879E<R!P^F)L:6-O+B!-;W1I=F\Z("5S("@E<RD`2&$@9F%L;&%D;R!L82!C
M;VYE>&GS;B!A;"!S97)V:61O<B!&5%`N`$5R<F]R(&%L(&-O;F5C=&%R(&%L
M('-E<G9I9&]R`$-O;G1A8W1O<P!392!H86X@8?%A9&ED;R!C;W)R96-T86UE
M;G1E(&QO<R!C;VYT86-T;W,@82!S=7,@9&ER96-C:6]N97,`5&EP;R!D92!C
M;VYT96YI9&\@9&5L(&%R8VAI=F\@8V]M<')I;6ED;SH@`$-O;G1E;FED;R!D
M92`B)7,B`$-O;G1I;G5A<@!#;VYT<F]L82!E;"!S;W!O<G1E(%!'4"!P87)A
M("5S+@!#;VYT<F]L82!E;"!S;W!O<G1E(%,O34E-12!P87)A("5S+@!/<&-I
M;VYE<R!D92!C;VYT<F]L(')E;&%C:6]N861A<R!C;VX@;&$@8OIS<75E9&$@
M9&4@;65N<V%J97,N`$-O;G1R;VQA(&QA(&-O;7!R;V)A8VGS;B!D92!C;W)R
M96\@;G5E=F\@>2!S:2!S92!L92!N;W1I9FEC87+A(&\@;F\@86P@<F5C:6)I
M<FQO+@"_0V]N=F5R=&ER(&5M;W1I8V]N97,@9&4@=&5X=&\@96X@9W+A9FEC
M;W,_`$ES;&%S($-O;VL`0V]O:VEE`$-O<&EA<@!&86QL\R!L82!C;W!I83H@
M)7,`0V]P:6%R('-E;&5C8VGS;@!#;W!I87(@82!L82!C87)P971A`$-O<G)E
M9VER`%1E>'1O(&-O<G)E9VED;P!)1"!D92!C;W-T90!#;W-T82!2:6-A`$-O
M<W1A(&1E($UA<F9I;`!.;R!S92!P=65D92!C:69R87(@96P@;65N<V%J92!M
M961I86YT92!01U`Z(`!.;R!S92!P=65D92!F:7)M87(@96P@;65N<V%J92!M
M961I86YT92!01U`Z(`!.;R!S92!P=65D92!C:69R87(@96P@;65N<V%J92!M
M961I86YT92!3+TU)344`3F\@<V4@<'5E9&4@9FER;6%R(&5L(&UE;G-A:F4@
M;65D:6%N=&4@(%,O34E-10!.;R!S92!P=65D92!A\6%D:7(@96P@8V]N=&%C
M=&\N("5S`$YO('-E('!U961E(&5N;&%Z87(@86P@<V5R=FED;W(@3$1!4"X`
M3F\@<V4@<'5E9&4@8V]M<')O8F%R(&5L('-A;&1O+B`E<P!.;R!S92!P=65D
M92!C;VUP;&5T87(@;&$@<&5T:6-I\VXN(%)A>O-N(&%L96=A9&$Z("5S`$YO
M('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($Q$05`N`$YO('-E('!U
M961E(&-O;F5C=&%R(&%L('-E<G9I9&]R("(E<R(@;65D:6%N=&4@1E10.B`E
M<P!.;R!S92!P=65D92!C<F5A<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN
M("5S`$YO('-E('!U961E(&-R96%R(&5L(&UO=&]R(%9&4SH@)7,`3F\@<V4@
M<'5E9&5N(&1E<V-I9G)A<B!L;W,@9&%T;W,@4$=0.B``3F\@<V4@<'5E9&5N
M(&1E<V-I9G)A<B!L;W,@9&%T;W,@4R]-24U%+@!.;R!S92!P=65D92!E;&EM
M:6YA<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@96QI;6EN87(@;&$@
M;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P=65D96X@96QI;6EN
M87(@;&]S(&UE;G-A:F5S(&1E("5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L
M('-E<G9I9&]R.B`E<P!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!G=6GS;B!D
M92!A8W1U86QI>F%C:?-N(&1E(&-O;F9I9W5R86-I\VX@(B5S(BX`3F\@<V4@
M<'5E9&4@9&5T97)M:6YA<F$@;&$@9&ER96-C:?-N(&1E(&-O<G)E;R!D96P@
M9&5S=&EN871A<FEO+@!.;R!S92!P=65D96X@<F5A;&EZ87(@;&%S(&]P97)A
M8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\N`$YO('-E('!U961E(&5X=')A97(@
M96P@87)C:&EV;R!S;VQI8VET861O(&1E;"!A9&IU;G1O($U3+51.148N`$YO
M('-E('!U961E(&5X=')A97(@96P@87)C:&EV;R!S;VQI8VET861O(&1E;"!A
M<F-H:79O(%II<"X`3F\@<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T82!D92!D
M:7)E8V-I;VYE<R!C;VUP;&5T82X`3F\@<V4@<'5E9&4@=')A97(@;&$@;&ES
M=&$@9&4@9&ES=')I8G5C:?-N(&-O;7!L971A+@!.;R!S92!P=65D92!T<F%E
M<B!L82!L:7-T82!C;VUP;&5T82!D92!L:7-T87,@9&4@9&ES=')I8G5C:?-N
M+@!.;R!S92!P=65D92!C87)G87(@;&$@97-T<F%T96=I82`B)7,B+@!.;R!S
M92!P=65D92!C<F5A<B!E;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E
M(&]B=&5N97(@;&$@8VQA=F4@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA
M=F5S+@!.;R!S92!P=65D92!A8G)I<B`B)7,B('!A<F$@97-C<FEB:7(N`$YO
M('-E('!U961E(&%B<FER("5S+@!.;R!S92!P=65D92!A8G)I<B!E;"!M\V1U
M;&\@9&4@=&%R96%S(&1E(&UA;G1E;FEM:65N=&\@)7,`3F\@<V4@<'5E9&4@
M86)R:7(@96P@9&ER96-T;W)I;R`B)7,B+@!.;R!S92!P=65D92!A8G)I<B!U
M;F$@8V]N97AI\VX@<V5G=7)A(&-O;B!E;"!S97)V:61O<B!)34%0+B`E<R`Z
M("5S+@!.;R!S92!P=65D92!L;V-A;&EZ87(@96P@<V5R=FED;W(@3$1!4"X`
M3F\@<V4@<'5E9&4@;&5E<B`E<RX`3F\@<V4@<'5E9&4@<F5S=&%B;&5C97(@
M;&$@8V]N=')A<V7Q82!D96P@=7-U87)I;R!S;VQI8VET861O+B!087)T92!D
M92!L;W,@9&5T86QL97,@;R!T;V1O<RP@<V]N(&EN8V]R<F5C=&]S+B!0<G5E
M8F4@;W1R82!V97H@;R!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"!A9&UI
M;FES=')A9&]R(&1E;"!S:7-T96UA('!A<F$@;>%S(&EN9F]R;6%C:?-N+@!.
M;R!S92!P=65D92!O8G1E;F5R(&QA($%#3"X`3F\@<V4@<'5E9&4@;V)T96YE
M<B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B`E<P!.;R!S92!P=65D92!O
M8G1E;F5R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@<V4@<'5E
M9&5N(&]B=&5N97(@;&%S(&QI<W1A<R!D92!D:7-T<FEB=6-I\VXN("5S`$YO
M('-E('!U961E(')E8W5P97)A<B!L82!I;F9O<FUA8VGS;B!D92!N;VUB<F5S
M(&1E;"!S97)V:61O<B!)34%0+@!.;R!S92!P=65D96X@;V)T96YE<B!L87,@
M8V%P86-I9&%D97,@9&5L('-E<G9I9&]R`$YO('-E('!U961E(')E<W1A=7)A
M<B!L82!C;VYF:6=U<F%C:?-N+@!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!D
M:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&=U87)D87(@;&$@8V]N9FEG
M=7)A8VGS;B!D92`E<RX`3F\@<V4@<'5E9&4@9W5A<F1A<B!U;F$@8V]P:6$@
M9&4@;&$@8V]N9FEG=7)A8VGS;BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!U;F$@
M8V]P:6$@9&4@;&$@8V]N9FEG=7)A8VGS;CH@)7,`3F\@<V4@<'5E9&4@9W5A
M<F1A<B!E;"!G=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I9W5R
M86-I\VX@96XZ("(E<R(N`$YO('-E('!U961E(&=U87)D87(@;&$@8V]P:6$@
M)7,@9&4@;&$@8V]N9FEG=7)A8VGS;BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!E
M;"!A<F-H:79O("5S(&1E(&-O;F9I9W5R86-I\VXN(%!U961E('5T:6QI>F%R
M('5N82!D92!L87,@;W!C:6]N97,@<&%R82!R97-T875R87(@96P@8_-D:6=O
M(&1E("5S(&\@8V]P:6%R(&UA;G5A;&UE;G1E(&$@)7,@96P@8_-D:6=O('-I
M9W5I96YT92X`3F\@<V4@<'5E9&4@8G5S8V%R(&5N(&5L('-E<G9I9&]R($Q$
M05`N`$YO('-E('!U961E(&1E<W9I;F-U;&%R("(E<R(N`$YO('-E('!U961E
M(&%C='5A;&EZ87(@96P@8V]N=&%C=&\N("5S`$YO('-E('!U961E(&%C='5A
M;&EZ87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P=65D
M92!E<V-R:6)I<B!L82!C;VYF:6=U<F%C:?-N(&1E("(E<R(Z("5S`$YO('-E
M('!U961E(&QO8V%L:7IA<B!E;"!P86YE;"!L871E<F%L(&1E($UO>FEL;&$N
M($-O;7!R=65B92!Q=64@97-TZ2!A8FEE<G1O+@!.;R!S92!P=65D96X@;W1O
M<F=A<B!A;"!U<W5A<FEO("(E<R(@;&]S('-I9W5I96YT97,@9&5R96-H;W,@
M<&%R82!L82!C87)P971A("(E<R(Z("5S`%1E>'1O(&-O;G1A9&\`4&'M<P!#
M=7)S;W,`0W)E87(`0W)E87(@8V%R<&5T80!#<F5A<B!C;&%V97,`0W)E87(@
M=6YA(&-U96YT80!#<F5A('5N(';M;F-U;&\`0W)E87(@=6YA(&-A<G!E=&$@
M9&4@<W!A;0!#<F5A<B!C87)P971A(&1E(&)O<G)A9&]R97,`0W)E87(`0W)E
M87(@8V%R<&5T82!D92!C;W)R96\@96YV:6%D;P!#<F5A<B!P87!E;&5R80!#
M<F5A(')E9VQA<R!D92!F:6QT<F%D;R!P87)A(&]R9V%N:7IA<B!E;"!C;W)R
M96\@96YT<F%N=&4L(&-L87-I9FEC87)L;R!E;B!C87)P971A<R!Y(&5L:6UI
M;F%R('-P86TN`$-R96%R('!L86YT:6QL80!#<F5A<B!P;&%N=&EL;&%S('D@
M<F5S<'5E<W1A<R!D92!F;W)M=6QA<FEO<RX`0W)E87(@<W5B8V%R<&5T87,`
M4')I=FEL96=I;W,@9&4@8W)E861O<@!.^FUE<F\@9&4@=&%R:F5T82!D92!C
M<NED:71O`$-R;V%C:6$`0W5B80`T($9A<V5S(&%C='5A;&5S`%-E<VEO;F5S
M(&%C='5A;&5S`$AO<F$@86-T=6%L`%523"!A8W1U86P`57-U87)I;W,@86-T
M=6%L97,`5&EE;7!O(&%C='5A;`!!8V-E<V\@86-T=6%L(&$@)7,`0V]N9&EC
M:?-N(&%C='5A;#H@`$5S=&EL;R!A8W1U86P`4&5R<V]N86QI>F$@8W5E;G1A
M<R!P87)A('1R865R(&-O<G)E;R!D92!O=')A<R!I9&5N=&ED861E<RX`4&5R
M<V]N86QI>F%R(&5L(&5N=NUO(&1E(&-O<G)E;RX`4&5R<V]N86QI>F$@;&%S
M('1A<F5A<R!A(&5J96-U=&%R(&%L(&EN:6-I87(@<V5S:?-N(&5N("5S+@!#
M;W)T87(`0V]R=&%R('-E;&5C8VGS;@!#:&EP<F4`0VER[6QI8V\@*$M/23@M
M4BD`0VER[6QI8V\@*%=I;F1O=W,M,3(U,2D`0VER[6QI8V\O56-R86YI86YO
M("A+3TDX+54I`%)E</IB;&EC82!#:&5C80!$1`!$4TX@*'9E82!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E<R]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I`$1I87)I86UE;G1E`%]&96-H80#!<E]B;VP@9&%T;W,`
M0V]N<W5L=&$@9&4@;&$@8F%S92!D92!D871O<P!&96-H80!392!H82!R96-I
M8FED;R!L82!F96-H80!396QE8V-I\VX@9&4@9F5C:&$`1.UA`$5?;&EM:6YA
M<B!C;VQU;6YA`$1I8VEE;6)R90!.^FUE<F]S(&1E8VEM86QE<P!296-H87IA
M9&$`4F5C:&%Z861A.B``4F5D=6-I<B!S86YG<F%D;P!0;W(@;VUI<VGS;@!#
M;VQO<B!P;W(@;VUI<VGS;@!)9&5N=&ED860@<&]R(&]M:7-I\VX`0V%M<&\@
M9&4@8OIS<75E9&$@<&]R(&]M:7-I\VX`4VAE;&P@<&]R(&]M:7-I\VX`0W)I
M=&5R:6\@9&4@8VQA<VEF:6-A8VGS;B!P;W(@;VUI<VGS;CH`4V5N=&ED;R!D
M92!C;&%S:69I8V%C:?-N('!O<B!O;6ES:?-N.@!$969I;FEC:6]N97,`1&5L
M96=A9&\`16QI;6EN87(`16QI;6EN87(@;&$@8VQA=F4@</IB;&EC82!D92`E
M<P!%;&EM:6YA<B!C96QD80!%;&EM:6YA<B!L87,@8VQA=F5S(&%C='5A;&5S
M`$5L:6UI;F%R(&-A<G!E=&$H<RD`16QI;6EN87(@9W)U<&\`16QI;6EN87(@
M<F5G:7-T<F\`16QI;6EN87(@<')I=FEL96=I;P!%;&EM:6YA<B!C87)P971A
M<R!S96QE8V-I;VYA9&%S`$5L:6UI;F%R('!L86YT:6QL80!%;&EM:6YA<B!C
M87)P971A('9I<G1U86P`16QI;6EN87(@;&$@9&5F:6YI8VGS;B!D92!C87)P
M971A('9I<G1U86P@9&4@)7,`16QI;6EN87(@>2!V86-I87(@;65N<V%J97,`
M16QI;6EN87(@8V5L9&$`16QI;6EN87(@8V]L=6UN80!%;&EM:6YA<B!P;&%N
M=&EL;&%S(&%L=&5R;F%T:79A<R!E>&ES=&5N=&5S`+]";W)R87(@9&5L('-E
M<G9I9&]R(')E;6]T;R!L;W,@;65N<V%J97,@=')A[61O<S\`475I=&%R(&1E
M(&UI(&%G96YD80!%;&EM:6YA<B!M96YS86IE<P"_16QI;6EN87(@861J=6YT
M;W,@=FEN8W5L861O<R!A;G1I9W5O<R!A;"!I;FEC:6\@9&5L(&UE<S\`OT5L
M:6UI;F%R(&-A<G!E=&%S(")%;G9I861O<R(@86YT:6=U87,@86P@:6YI8VEO
M(&1E;"!M97,_`$5L:6UI;F%R('!R:79I;&5G:6]S(&1E("(E<R(`OT5L:6UI
M;F%R('!R:79I;&5G:6]S('!A<F$@(B5S(B!Y(&-U86QQ=6EE<B!P<FEV:6QE
M9VEO(&1E<V-E;F1I96YT93\`16QI;6EN87(@9FEL80!%;&EM:6YA<B!I9&5N
M=&ED860@<V5L96-C:6]N861A`$5L:6UI;F%R(&UE;G-A:F5S('-P86T`16QI
M;6EN87(@<W5B8V%R<&5T87,`16QI;6EN82!L82!C;VQU;6YA(&%C='5A;`!%
M;&EM:6YA(&QA(&9I;&$@86-T=6%L`$5L:6UI;F%D;P!-96YS86IE<R!E;&EM
M:6YA9&]S`%-E(&AA(&5L:6UI;F%D;R!E;"!G=6GS;B!D92!A8W1U86QI>F%C
M:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX@(B5S(BX`4V4@:&$@96QI;6EN861O
M(&5L(&%D:G5N=&\@(B5S(BX`16QI;6EN86YD;R!Y('1R87-L861A;F1O(&UE
M;G-A:F5S`$AO<F$@9&4@96YT<F5G83H`1&EN86UA<F-A`$1E;F5G87(@;&$@
M<&5T:6-I\VX`1&5N96=A<B!L82!P971I8VGS;B!D92!I;F9O<FUA8VGS;B!D
M92!T:65M<&\@9&ES<&]N:6)L90!$97-C96YD96YT90!$97-C<FEB82!E;"!P
M<F]B;&5M80!$97-C<FEP8VGS;@!$971A;&QE<P!$971A;&QE<R`H=&%M8FGI
M;B!E;B!E;"!A<F-H:79O(&1E(')E9VES=')O(&1E($AO<F1E*3H`4V4@:&%N
M(')E9VES=')A9&\@;&]S(&1E=&%L;&5S('!A<F$@96P@861M:6YI<W1R861O
M<BX`1&5S87)R;VQL;P!0=6YT;R!D92!C;VYD96YS86-I\VX`4'5N=&\@9&4@
M8V]N9&5N<V%C:?-N(&1E(&QA(/IL=&EM82!H;W)A.B``4'5N=&\@9&4@8V]N
M9&5N<V%C:?-N.B``3F\@<V4@:&$@861J=6YT861O("(E<R(@>6$@<75E(&5L
M(&%R8VAI=F\@97-TX2!V86/M;RX`OT%T96YU87(@9FER;6%S/P!$92!I>G%U
M:65R9&$@82!D97)E8VAA`$1E(&1E<F5C:&$@82!I>G%U:65R9&$`1&ER96-T
M;W)I;P!-;W-T<F%R`+]-;W-T<F%R(&5N(&9O<FUA=&\@9&4@,C0M:&]R87,_
M`$]P8VEO;F5S(&1E(%9I<W5A;&EZ86-I\VX`OTUO<W1R87(@=6YA(&-O;F9I
M<FUA8VGS;B!T<F%S(&5N=FEA<B!U;B!M96YS86IE/P!-;W-T<F%R('!R;V[S
M<W1I8V\@9&5T86QL861O`$UO<W1R87(@<')O;O-S=&EC;R`H5$%&*0!&;W)M
M871O(&1E('9I<W5Z86QI>F%C:?-N`$UO<W1R87(@96X@96P@8W5E<G!O(&1E
M;"!M96YS86IE`+]-;W-T<F%R(&%V:7-O(&5M97)G96YT92!D92!C;W)R96\@
M;G5E=F\_`+]-;W-T<F%R(&5L(';M;F-U;&\@<'5R9V%R(")3<&%M(B!E;B!L
M82!B87)R82!D92!M96[Z<S\`OTUO<W1R87(@96P@=NUN8W5L;R`B5F%C:6%R
M(B!P87!E;&5R82!E;B!L82!B87)R82!D92!M96[Z<S\`1&ES<&]S:6-I\VX`
M3F]T:69I8V%C:?-N(&1E(&-O;G-U;'1A`$1J:6)O=71I`$Y/(&AA>2!C;VEN
M8VED96YC:6%S`$YO(&-O;7!R;V)A<B!C;W)R96\@;G5E=F\`3F\@96QI;6EN
M87(`3F\@86-C961E<B!D:7)E8W1A;65N=&4@82!M86EN=&5N86YC92YP:'``
M3F\@9V5N97)A<B!V[6YC=6QO(&5N(&QA(&-O;'5M;F$@1&4Z`+]$97-E82!A
M8G)I<B!E<V$@8V%R<&5T83\`OT-O;G1I96YE(&QA('!R:6UE<F$@9FEL82!L
M;W,@;F]M8G)E<R!D92!L;W,@8V%M<&]S/R!3:2!E<R!A<^TL('-E;&5C8VEO
M;F4@97-T82!C87-I;&QA.@!$;VUI;FEC80!297#Z8FQI8V$@1&]M:6YI8V%N
M80"_3F\@9&ES<&]N92!D92!C=65N=&$_(%-O;&EC[71E;&$N`$AE8VAO`$1E
M<V-A<F=A<@!$97-C87)G87(@)7,`1&5S8V%R9V%R("5S(&5N(&9O<FUA=&\@
M+GII<`!$97-C87)G87(@=&]D;W,@;&]S(&%D:G5N=&]S("AE;B!U;B!A<F-H
M:79O("YZ:7`I`$1E<V-A<F=A<B!C87)P971A*',I`$1E<V-A<F=A<B!C87)P
M971A*',I(%MF;W)M871O("YZ:7!=`$1E<V-A<F=A<B!L82!C;VYF:6=U<F%C
M:?-N(&=E;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0+@!$97-C87)G87(@96X@
M9F]R;6%T;R`N>FEP`$)O<G)A9&]R`$-A<G!E=&$@9&4@8F]R<F%D;W)E<SH`
M0V%R<&5T82!D92!B;W)R861O<F5S.@!,:7-T82!D97-P;&5G86)L90!$<F]G
M87,`0V]R<F5O`$-O<G)E;R!E;&5C='+S;FEC;P!#;VYT<F]L861O<B!D92!P
M87-A<F5L82!#;W)R96\M82U335,@<&%R82!P<F]V965D;W)E<R!Q=64@<')O
M<&]R8VEO;F5N(&5S=&4@<V5R=FEC:6\N`$9)3D%,`$524@!%4E)/4CH@3F\@
M<V4@<'5E9&4@96YV:6%R(&5L(&UE;G-A:F4N`$5C=6%D;W(`36]D:69I8V%R
M`$UO9&EF:6-A<B!L:7-T82!N96=R80!-;V1I9FEC87(@8FQO<75E`$UO9&EF
M:6-A<B!F:6QT<F]S`$UO9&EF:6-A<B!G<G5P;P!-;V1I9FEC87(@<')I=FEL
M96=I;P!-;V1I9FEC87(@<')I=FEL96=I;W,`36]D:69I8V%R('!R:79I;&5G
M:6]S(&1E("5S`$UO9&EF:6-A<B!C;VYS=6QT82!D92!B^G-Q=65D80!-;V1I
M9FEC87(@8V%R<&5T82!V:7)T=6%L`$UO9&EF:6-A<B!L82!D969I;FEC:?-N
M(&1E(&-A<G!E=&$@=FER='5A;"!D92`E<P!-;V1I9FEC87(@;&ES=&$@8FQA
M;F-A`$UO9&EF:6-A<B!O<&-I;VYE<R!D93H`36]D:69I8V%R('!R:79I;&5G
M:6]S(&1E("(E<R(`36]D:69I8V%R('!R:79I;&5G:6]S(&1E("5S`$UO9&EF
M:6-A<B!L82!L:7-T82!N96=R80!-;V1I9FEC87(@;&%S(')E9VQA<R!D92!F
M:6QT<F%D;P!-;V1I9FEC87(@;&%S(&]P8VEO;F5S('!A<F$@86-C961E<B!A
M(&]T<F%S(&-U96YT87,@9&4@8V]R<F5O+@!-;V1I9FEC87(@;&$@;&ES=&$@
M8FQA;F-A`$5D=6-A8VGS;@!%9VEP=&\`16P@4V%L=F%D;W(`16QE;65N=&\N
M+BX`16T`0V]R<F5O`$1I<F5C8VGS;B!D92!C;W)R96\`3&%S(&1I<F5C8VEO
M;F5S(&1E(&-O<G)E;R!T:65N96X@<75E(&-O:6YC:61I<BX`0V]R<F5O(&-O
M;B!C;VYF:7)M86-I\VX`4&%S87)E;&$@0V]R<F5O+6$M4TU3`$5M;W1I8V]N
M97,`4V4@:&%N(&5L:6UI;F%D;R!T;V1O<R!L;W,@;65N<V%J97,@9&4@)7,N
M`%-E(&AA;B!E;&EM:6YA9&\@=&]D;W,@;&]S(&UE;G-A:F5S(&1E(&QA(%!A
M<&5L97)A('9I<G1U86PN`%9A8VEA<B!C87)P971A*',I`%9A8VEA<B!C87)P
M971A<R!S96QE8V-I;VYA9&%S`%9A8VEA<@!3<&%M("A?;BD`5F%C:6%R("A?
M>"D`365N<V%J92!E;B!B;&%N8V\`4F5S=6QT861O(&5N(&)L86YC;RX`3&EM
M<&EA<B!TZ7)M:6YO<R!D92!B^G-Q=65D80"_06-T:79A<B!C87!A8VED860@
M4$=0/P"_06-T:79A<B!C87!A8VED860@4R]-24U%/P"_4&5R;6ET:7(@:6YS
M97)C:?-N(&1E(&EMX6=E;F5S(&1E(&QA<R!'86QE<NUA<R!D92!F;W1O<S\`
MOT%C=&EV87(@=FES=&%S('!R979I87,@9&4@;65N<V%J97,_`+]097)M:71I
M<B!M96[Z(&1E(&-O;G1E>'1O(&1E;"!B;W3S;B!D97)E8VAO(&1E;"!R873S
M;C\`7T]P8VEO;F5S(&1E(&-I9G)A9&\`0VEF<F%D;P!&:6YA;`!497)M:6YA
M<B!M96YS86IE(')E96YV:6%D;P!497)M:6YA<B!M96YS86IE`%1E<FUI;F%R
M(&UE;G-A:F4@9&4@)7,`0?%O(&1E('1E<FUI;F%C:?-N`$%G<F%N9&%R(&5D
M:71O<@!);G1R;V1U>F-A(&QA(&9R87-E(&-L879E`$EN=')O9'5Z8V$@=6YA
M('!R96=U;G1A(&1E('-E9W5R:61A9"!Q=64@<V4@;&4@9F]R;75L87+A('-I
M('!R96-I<V$@<F5A:G5S=&%R(&QA(&-O;G1R87-E\6$L('`N92X@)[]#=>%L
M(&5S(&5L(&YO;6)R92!D92!S=2!M87-C;W1A/R<Z`$EN=')O9'5Z8V$@87%U
M[2!L82!54DP@9&4@;&$@:6UA9V5N`$EN=')O9'5Z8V$@;&%S(&QE=')A<R!D
M92!D96)A:F\Z`$EN=')O9'5Z8V$@96P@;F]M8G)E(&1E(&QA(&-A<G!E=&$@
M9&4@<W!A;0!);G1R;V1U>F-A(&5L(&YO;6)R92!D92!L82!N=65V82!C87)P
M971A(&1E(&)O<G)A9&]R97,`26YT<F]D=7IC82!E;"!N;VUB<F4@9&4@;&$@
M;G5E=F$@8V%R<&5T82!D92!C;W)R96\@96YV:6%D;P!);G1R;V1U>F-A(&5L
M(&YO;6)R92!D92!L82!N=65V82!P87!E;&5R80!4;V1O(&5L(&UE;G-A:F4`
M4V4@:&$@8?%A9&ED;R!C;W)R96-T86UE;G1E(&5L(')E9VES=')O("(E<R(@
M82!L82!L:6)R971A(&1I<F5C8VEO;F5S`$=U:6YE82!%8W5A=&]R:6%L`$5R
M:71R96$`17)R;W(`17)R;W(@86P@8V]N96-T87(@86P@<V5R=FED;W(@24U!
M4"X@)7,@.B`E<RX`17)R;W(@86P@8W)E87(@96P@8FQO<75E.B`E<P!%<G)O
M<B!A;"!E;&EM:6YA<B!A;F-L82!D92!S:6YC<F]N:7IA8VGS;CH@)7,`17)R
M;W(@86P@96QI;6EN87(@96P@<F5G:7-T<F\@9&4@<VEN8W)O;FEZ86-I\VXZ
M("5S`$5R<F]R(&%L(&]B=&5N97(@8V]N=&5N:61O<SH@)7,`17)R;W(@86P@
M96YV:6%R(&QA(')E<W!U97-T83H@)7,N`$5R<F]R(&%L(&%C='5A;&EZ87(@
M;&$@8V]N=')A<V7Q83H@)7,`17)R;W(@8V]N(&5L(&UE;G-A:F4@9&4@8V]R
M<F5O+@!%<G)O<B!A;"!E<V-R:6)I<B`B)7,B+@!%<W1O;FEA`$5T:6]P[6$`
MR71N:6-O`$5U<F]P80!392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92!E
M;"!A8V]N=&5C:6UI96YT;RX`0V%D82`Q-2!M:6YU=&]S`$-A9&$@,B!M:6YU
M=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI;G5T;W,`0V%D82!I;FEC
M:6\@9&4@<V5S:?-N`$-A9&$@;65D:6$@:&]R80!#861A(&UI;G5T;P!686QO
M<F5S(&1E(&5J96UP;&\Z`$5J96-U=&%R`$5X<&%N9&ER`$5X<&%N9&ER('1O
M9&%S`$5X<&%N9&ER('1O9&%S(&QA<R!C87)P971A<P!%>'!A;F1I<B!C87)P
M971A`$5X<&%N9&ER(&YO;6)R97,`36]S=')A<B!B87)R82!L871E<F%L`+]%
M>'!A;F1I<B!A=71O;>%T:6-A;65N=&4@8V]M;R!T87)E82!D92!F;VYD;R!L
M;W,@;F]M8G)E<R!E;B!L82!V96YT86YA(&1E(')E9&%C8VGS;C\`4&]R(&]M
M:7-I\VXL(+]E>'!A;F1I<B!E;"#A<F)O;"!E;G1E<F\@96X@;&$@=FES=&$@
M9&4@8V%R<&5T87,_`$5X<&%N9&EE;F1O`'-E(&5S<&5R86)A("<I)P!392!E
M<W!E<F%B82!U;F$@^FYI8V$@<&%L86)R82!O('5N('3I<FUI;F\@9&4@8OIS
M<75E9&$@96YT<F5C;VUI;&QA9&\`1F5C:&$@9&4@=F5N8VEM:65N=&\`17AP
M;VYE;G1E`$-O;&]R(&1E(&QE=')A`$-A<F=A<B!L82!C;VYF:6=U<F%C:?-N
M('!O<B!&5%``7U1R865R`$9A;&QO(&%L('1R865R(&QA<R!P<F5F97)E;F-I
M87,N`$EN8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!,1$%0+@!)
M;F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@<V5R=FED;W(@4TU"+@!&86QL;R!A
M;"!C;W!I87(@9&4@(B5S(BX`1F%L;&\@86P@8V]P:6%R(&$@(B5S(BX`1F%L
M;&\@86P@8W)E87(@=6YA(&-O;F5X:?-N(%-!4TP`1F%L;&\@86P@=')A<VQA
M9&%R("(E<R(N`$9A;&QO(&%L(')E8W5P97)A<CH@)7,`1&5S<&5J861O`$ES
M;&%S($UA;'9I;F%S("A&86QK;&%N9"D`27-L87,@1F%R;V4`17)R;W(@:7)R
M96-U<&5R86)L93H`1F%X`$9A>&5S`$9E8G)E<F\`4V4@<VEE;G1E(&-O;6\`
M4V4@<VEE;G1E(&-O;6\Z(`!4<F%E<B!C;W)R96\`OU1R865R(&-O<G)E;R!E
M;B!U;F$@=F5N=&%N82!S97!A<F%D83\`OU1R865R(&UE;G-A:F5S(&%L(&EN
M:6-I87(@<V5S:?-N/P!392!H86X@=')A[61O("5D(&UE;G-A:F5S(&1E("5S
M`%-E(&AA('1R8>UD;R`Q(&UE;G-A:F4@9&4@)7,`5')A97(@8V]R<F5O.B``
M1F5T8VAM86EL.B!N;R!H87D@;65N<V%J97,@;G5E=F]S+@!0;V-A<R!L;'5V
M:6%S`$5S8V%S;R!A9W5A8V5R;R!D92!N:65V90!?1FEL=')O<P!-871R:7H@
M9&4@8V%M<&]S`$-!4%1#2$$@9&4@1FEG;&5T`$QE=')A(&1E($9I9VQE=`!&
M:6II`$%R8VAI=F\`3KH@9&4@87)C:&EV;W,Z("5S(&%R8VAI=F\`3KH@9&4@
M87)C:&EV;W,Z("5S(&%R8VAI=F]S`$%R8VAI=F]S`$YO;6)R92!D92!A<F-H
M:79O`%-E;&5C8VGS;B!D92!A<F-H:79O`$-A<F=A<B!A<F-H:79O`$QA(&-A
M<F=A(&1E(&%R8VAI=F]S(&YO(&5S=.$@<V]P;W)T861A+@!/<&-I;VYE<R!D
M92!F:6QT<F%D;P!#;VYF:6=U<F%C:?-N(&1E(&9I;'1R861O`+]&:6QT<F%R
M(&-O;G1E;FED;R!O8G-C96YO(&5N(&5L(&UE;G-A:F4_`$5N(&5S=&4@<VES
M=&5M82!S92!H82!D97-H86)I;&ET861O(&5L('-O<&]R=&4@9&4@9FEL=')A
M9&\N`$9I;'1R;W,`3&]S(&9I;'1R;W,@3D\@97-TX6X@86-T:79O<P!&:6QT
M<F]S.B!PX6=I;F$@9&4@9V5S=&GS;B!D92`E<P!%;F-O;G1R87(`1FEN;&%N
M9&EA`$-U87)T;R!C<F5C:65N=&4`4')I;65R82!PX6=I;F$@9&5L(&)U>O-N
M`%!R:6UE<F$@<.%G:6YA`$-U87)T;R!C<F5C:65N=&4`4F%Z\VX@9FEJ80!6
M;VQT96%R`$1I<W!O<VEC:?-N`%)E96Y?=FEA<@!.:65B;&$`3&$@8V%R<&5T
M82`E<R!N;R!E>&ES=&4N`$%C8VEO;F5S(&1E(&-A<G!E=&$@+2!#;VYF:7)M
M86-I\VX`3F%V96=A9&]R(&1E(&-A<G!E=&%S`%)E<W5M96X@9&4@;&$@8V%R
M<&5T80!.;R!S92!H82!A8W1I=F%D;R!L82!C;VUP87)T:6-I\VX@9&4@8V%R
M<&5T87,N`$YO('-E(&AA(&%C=&EV861O(&5L('5S;R!D92!C87)P971A<RX`
M0V]L;W(@9&4@;&5T<F$`0V]M:61A`%!A<F$@;F%V96=A9&]R97,@<75E(&YO
M(&%D;6ET86X@:6WA9V5N97,`4')O;O-S=&EC;R`H5$%&*0!$[6%S(&1E;"!P
M<F]N\W-T:6-O("AT96YG82!E;B!C=65N=&$@<75E(&5L('!R;V[S<W1I8V\@
M9F%C:6QI=&%D;R!I;F-L=7EE('1A;G1O(&5L(&3M82!C;VUO(&QA(&YO8VAE
M.R!U;B!N^FUE<F\@9W)A;F1E('-E('1R861U8VERX2!E;B!U;B!B;&]Q=64@
M;75Y(&%N8VAO*0"_2&$@;VQV:61A9&\@;&$@8V]N=')A<V7Q83\`1F]R;6%T
M;R!D92!F96-H82!D92!L;W,@;65N<V%J97,@9F5C:&%D;W,@:&]Y(&5N(&QA
M('9I<W1A(&1E(&)U>F]N97,`1F]R;75L87)I;W,`1F]R='5N80!4:7!O(&1E
M(&9O<G1U;F$`1F]R='5N87,`1F]R='5N87,@,@!&;W)O<P!2965N=FEA<@!2
M965N=FEA<CH`365N<V%J92!R965N=FEA9&\`365N<V%J92!R965N=FEA9&\@
M9&4@)7,`4F5E;G;M;W,`5FEE`$9R86UE<P!&<F%N8VEA`$9R86YC:6$L($UE
M=')O<&]L:71A;F$`4F5S<'5E<W1A(&$@<&5T:6-I\VX@9&4@=&EE;7!O(&1I
M<W!O;FEB;&4`1W5A>6%N82!F<F%N8V5S80!0;VQI;F5S:6$@9G)A;F-E<V$`
M5&5R<FET;W)I;W,@9G)A;F-E<V5S(&1E;"!S=7(`7T1E`$1E`%!O<B!R96UI
M=&5N=&4`1&5L(`!$97-C<FEP8VGS;B!C;VUP;&5T80!,=6YA(&QL96YA`$YO
M;6)R92!C;VUP;&5T;P!&=V0Z`$9W9#H@`$9W9#H@)74@;65N<V%J97,@<F5E
M;G9I861O<P!'86+S;@!'86QE<NUA(&1E(&QA('%U92!O8G1E;F5R(&QA(&EM
M86=E;@!'86QE<NUA.@!'86UB:6$`3W!C:6]N97,@9V5N97)A;&5S`$=E;F5R
M87(@8V]N9FEG=7)A8VGS;B!D92`E<P!#\V1I9V\@9V5N97)A9&\`1V5O<F=I
M80!!;&5M86YI80"_5')A97(@<_-L;R!M96YS86IE<R!N=65V;W,_("AS\VQO
M($E-05`I`$=H86YA`$=I8G)A;'1A<@!.;VUB<F4@:6YD:6-A9&\`3W!C:6]N
M97,@9VQO8F%L97,`27(`27(@86P@;65N<V%J90!)<B!A;"!R96=I<W1R;R!D
M92`B)7,B(&5N(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,`1V]E9&5L`$UA
M<&%S(&1E($=O;V=L90!"^G-Q=65D82!E;B!';V]G;&4`0V]N8V5D97(@86-C
M97-O`$5S8V%L82!D92!G<FES97,`1W)E8VEA`$=R:65G;R`H25-/+3@X-3DM
M-RD`1W)O96YL86YD:6$`1W)A;F%D80!!9&UI;FES=')A8VGS;B!D92!G<G5P
M;W,`3&]S(&YO;6)R97,@9&4@9W)U<&\@;F\@<'5E9&5N(&1E:F%R<V4@96X@
M8FQA;F-O`$=R;W5P7VQD87`Z($YO('-E('!U961E(&'Q861I<B!E;"!G<G5P
M;R`E<RX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<CH@`$=R;W5P
M7VQD87`Z($EN8V%P87H@9&4@96QI;6EN87(@96P@9W)U<&\@)7,`1W)O=7!?
M;&1A<#H@26YC87!A>B!D92!A8W1U86QI>F%R(&5L(&=R=7!O("5S`$=R=7!O
M<P!'=6%D86QU<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYE<V5Y`%!R:79I;&5G
M:6]S(&1E(&EN=FET861O`$PN(&EN=FET861O<P!'=6EN96$`1W5I;F5A+4)I
M<W-A=0!'=6%Y86YA`$%15<T`2%1-3`!697)S:?-N($A434P@9&5L(&UE;G-A
M:F4`2%1-3"!S92!N:65G82!C;V)A<F1E;65N=&4@82!E;&EM:6YA<B!L82#Z
M;'1I;6$@8V5L9&$@9&4@;&$@9FEL82X`2%1-3$%R96$@<V4@;FEE9V$@8V]B
M87)D96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA(&-O;'5M;F$@9&4@;&$@
M=&%B;&$N`$A434P@<V4@;FEE9V$@8V]B87)D96UE;G1E(&$@96QI;6EN87(@
M;&$@^FQT:6UA(&9I;&$@9&4@;&$@=&%B;&$N`$YO('-E(&5N8V]N='+S(&QA
M(&%U=&5N=&EF:6-A8VGS;B!(5%10+@!(86ET[0!!;&=O<FEM;R!(87-H`$YE
M8FQI;F$`0V%B96-E<F$`0V%B96-E<F%S`$ES;&$@2&5A<F0@92!)<VQA<R!-
M8T1O;F%L9`!4;W)M96YT82!T<F]P:6-A;"!I;G1E;G-A`$AE8G)E;R`H25-/
M+3@X-3DM."U)*0!!;'1U<F$`07EU9&$`07EU9&$@9&5L(&5D:71O<@!!>75D
M86YT90!(96UI<V9E<FEO`$%Q=>T@=&EE;F4@96P@8V]M:65N>F\@9&5L(&%R
M8VAI=F\Z`$%Q=>T@=&EE;F4@96P@;65N<V%J92!Q=64@97-T86)A(')E9&%C
M=&%N9&\Z`$]C=6QT;P!/8W5L=&\@96X@;&$@=FES=&$@9&4@<V5C=65N8VEA
M<P!/8W5L=&%R(&5L:6UI;F%D;W,`3V-U;'1A<B!N;R!S=7-C<FET;W,`06QT
M80!0<FEO<FED860@86QT80!%;&5V861A`%]);FEC:6\`4V%N=&$@4V5D92`H
M0VEU9&%D+45S=&%D;R!D96P@5F%T:6-A;F\I`$EN:6-I;P!$;VUI8VEL:6\`
M1&ER96-T;W)I;R!P97)S;VYA;`!496SI9F]N;R!P87)T:6-U;&%R`$AO;F1U
M<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@4V4@:&%N(&5N8V]N
M=')A9&\@9&%T;W,@6$U,("5S(&YO(';A;&ED;W,@96X@96P@;65N<V%J92`E
M<P!(;W)D92]+;VQA8CH@3FEN9_IN(&UE;G-A:F4@8V]R<F5S<&]N9&4@86P@
M;V)J971O("5S`$AO<F1E+TMO;&%B.B!.;R!S92!E;F-O;G1R\R!U;B!O8FIE
M=&\@9&4@=&EP;R`E<R!E;B!E;"!M96YS86IE("5S`$AO<F1E+TMO;&%B.B!3
M92!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`E<R`B)7,B`$AO<F1E+TMO
M;&%B.B!%;"!M;W1O<B!D92!I;G1E9W)A8VGS;B!P<F5C:7-A(&1E(&QA(&5X
M=&5N<VGS;B!02%`@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@
M8W)E87(@;G5E=F\@X7)B;VP@6$U,(&1E;"!O8FIE=&\@)7,`2&]R9&4O2V]L
M86(Z($EN8V%P87H@9&4@96QI;6EN87(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z($EN8V%P87H@9&4@;V)T96YE<B!)1"!-24U%(&1E(&QA('!A<G1E(&1E
M('1I<&\@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN8W)O;FEZ87(@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN8W)O;FEZ
M87(@96QE;65N=&]S(&-O;7!A<G1I9&]S.B`E<P!(;W)D92]+;VQA8CH@16QE
M;65N=&\@8V]M<&%R=&ED;R!D97-C;VYO8VED;R`B)7,B`$SM;F5A(&AO<FEZ
M;VYT86P`36%R9V5N(&AO<FEZ;VYT86P`2&]R:7IO;G1A;#H`OT/S;6\@;&QE
M9_,@:&%S=&$@87%U[3\@**%#;VUU;NUQ=65L;RP@<&]R(&9A=F]R(2D`OT/S
M;6\@9&5S96$@;6]S=')A<B!L;W,@861J=6YT;W,_`+]#=6%N=&%S(&-O;'5M
M;F%S(&1E<V5A(&-O;6)I;F%R/P"_0W7A;G1O<R!C86UP;W,@*&-O;'5M;F%S
M*2!H87D_`+]#=6%N=&%S(&9I;&%S(&1E<V5A(&-O;6)I;F%R/P!#\VUO(')E
M<V%L=&%R(&QA<R!L[6YE87,@8VET861A<R!E;B!U;F$@<F5S<'5E<W1A`$AU
M;65D860`2'5M961A9#H@`$AU;6]R:7-T87,`2'5N9W+M80!)34%0`$E-05`@
M*$%U=&]D971E8V-I\VX@9&4@<')O=&]C;VQO<RD`16P@<V5R=FED;W(@24U!
M4"!H82!C97)R861O(&QA(&-O;F5X:?-N+B!%;"!S97)V:61O<B!D:6IO.B`E
M<P!(82!F86QL861O(&QA(&-R96%C:?-N(&1E;"!B=7KS;B!)34%0.B`E<P!(
M82!F86QL861O(&QA(&5L:6UI;F%C:?-N(&1E;"!B=7KS;B!)34%0.B`E<P!(
M82!F86QL861O(&QA(&-R96%C:?-N(&1E(&5S<&%C:6\@87-I9VYA9&\@9&5L
M(&)U>O-N($E-05`Z("5S`$E-05`@<V]B<F4@4U-,`$E-05`@<V]B<F4@4U-,
M("AC97)T:69I8V%D;R!A=71O+69I<FUA9&\I`$E-05`@<V]B<F4@4U-,("AA
M=71O+69I<FUA9&\I`$5L('-E<G9I9&]R($E-05`@:&$@8V]R=&%D;R!L82!C
M;VYE>&GS;BX`24U!4"P@<VEN(%1,4P!397)V:61O<F5S(&1E(&-O<G)E;R!)
M34%0+U!/4#,`1&ER96-C:?-N($E0`$QA(&1I<F5C8VGS;B!)4"!N;R!E<W3A
M(&1I<W!O;FEB;&4N`$QA(&1I<F5C8VGS;B!)4"!N;R!E<W3A(&5N=')E(&)L
M;W%U97,@0TE$4B!P97)M:71I9&]S+@!6:6]L86-I\VX@;&]C:V1O=VX@25`N
M`$E?;G-E<G1A<B!F:6QA(&5N8VEM80!)<VQA;F1I80!3\VQO(&EC;VYO<P!)
M8V]N;W,@9&4@)7,`26-O;F]S(&-O;B!T97AT;P!.;VUB<F4@9&4@;&$@:61E
M;G1I9&%D.@!3:2!N;R!S92!M=65S=')A(&-O<G)E8W1A;65N=&4L("5S('!A
M<F$@86)R:7)L;R!E;B!U;F$@=F5N=&%N82!N=65V82X`4VD@<V4@=71I;&EZ
M82!34TP@;R!43%,@;F5C97-I=&$@8V%R9V%R(&QA(&5X=&5N<VGS;B!02%`@
M;W!E;G-S;"X`4VD@<VEG=64L(*%T;V1O<R!L;W,@;65N<V%J97,@9&4@;&$H
M<RD@8V%R<&5T82AS*2!S92!P97)D97+A;B$`4VD@;F\@=F4@;FEN9_IN(&EC
M;VYO(&UE9&EA;G1E($EN=&5R;F5T($5X<&QO<F5R+"!P=65D92!T96YE<B!Q
M=64@86-T:79A<B!E<W1A(&-A<VEL;&$@<&%R82!D97-A8W1I=F%R(&QA('1R
M86YS<&%R96YC:6$@4$Y'+@!3:2!V92!E<W1E(&UE;G-A:F4@<VEN(&YI;F=U
M;F$@:6UA9V5N+"!L82!I;6%G96X@<75E('%U:65R92!C87)G87(@;F\@<V4@
M<'5E9&4@;6]S=')A<B!E;B!S=2!N879E9V%D;W(N`$EG;F]R87(`26=N;W)A
M<B!T;V1A<P!);6%G96X`5FES=&$@<')E=FEA.@!54DP@9&4@;&$@:6UA9V5N
M`%523"!D92!L82!I;6%G96XZ`$EM86=E;B!D92!L82!G86QE<NUA`$EM86=E
M;B!D92!L82!G86QE<NUA.@!392!H82!C87)G861O(&QA(&EM86=E;@!);>%G
M96YE<P!);7!O<G1A<@!);7!O<G1A<B!C;&%V90!);7!O<G1A<B!C;&%V97,`
M26UP;W)T87(@;65N<V%J97,`26UP;W)T87(@8VQA=F4@4$=0`$EM<&]R=&%R
M(&-E<G1I9FEC861O('!E<G-O;F%L`$EM<&]R=&%R(&-L879E('!E<G-O;F%L
M(%!'4"!P<FEV861A`$EM<&]R=&%R(&-L879E('!E<G-O;F%L(%!'4"!P^F)L
M:6-A`$EM<&]R=&%R(&-E<G1I9FEC861O<R!P97)S;VYA;&5S(%,O34E-10!)
M;7!O<G1A<B!C;&%V92!P^F)L:6-A`$EM<&]R=&%R(&-L879E(%!'4"!P^F)L
M:6-A`$EM<&]R=&%R(&-L879E(%,O34E-12!P^F)L:6-A`$EM<&]R=&%R(&-L
M879E(%,O34E-10!);7!O<G1A<B!A<F-H:79O(&UB;W@`26UP;W)T87(@96P@
M87)C:&EV;R!M8F]X("5S(&$@;&$@8V%R<&5T82`E<RX`26UP;W)T87(L('!A
M<V\@)60`26UP;W)T86YT90!-96YS86IE<R!I;7!O<G1A;G1E<P!);7!O<G1A
M9&]S("5D(&UE;G-A:F5S(&1E("5S+@!#86UP;R!I;7!O<G1A9&\Z("5S`$-A
M;7!O<R!I;7!O<G1A9&]S.@!0<F]C97-A;F1O`$EN7W-E<G1A<B!F:6QA(&1E
M8F%J;P!%;G1R861A`+]);F-L=6ER('5N(')E<W5M96X@9&4@;&$@8V%B96-E
M<F$@96X@;&$@<F5S<'5E<W1A/P"_26YC;'5I<B!M96YS86IE(&]R:6=I;F%L
M(&5N(&QA(')E<W!U97-T83\`4V4@:&$@:6YD:6-A9&\@=6X@8_-D:6=O(&1E
M(&%C8VGS;B!I;F-O<G)E8W1O+@!.;VUB<F4@9&4@=7-U87)I;R!Y+V\@8V]N
M=')A<V7Q82!I;F-O<G)E8W1O<RX`3F]M8G)E(&1E('5S=6%R:6\@;R!D:7)E
M8V-I\VX@86QT97)N871I=F$@:6YC;W)R96-T;W,N(%9U96QV82!A(&EN=&5N
M=&%R;&\@;R!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"!A9&UI;FES=')A
M9&]R(&1E('-I<W1E;6%S('!A<F$@;>%S(&EN9F]R;6%C:?-N+@!!=6UE;G1A
M<B!S86YG<F%D;P!);F1I80!5<W5A<FEO<R!I;F1I=FED=6%L97,`26YD;VYE
M<VEA`$EN9F]R;6%C:?-N`$EN9F]R;6%C:?-N`$QA(&EN9F]R;6%C:?-N('EA
M(&YO(&5S=.$@9&ES<&]N:6)L92X`26YF;W)M86-I\VX@9&4@;&$@8VQA=F4@
M</IB;&EC82!D92`E<P!);F9O<FUA8VGS;B!D92!L82!C;&%V92!P97)S;VYA
M;"!P<FEV861A`$EN9F]R;6%C:?-N(&1E(&QA(&-L879E('!E<G-O;F%L('#Z
M8FQI8V$`16X@;.UN96$`26YS97)T87(@8U]O;'5M;F$@9&5T<N%S`$EN<V5R
M=&%R(&%Q=>T@96P@8V5R=&EF:6-A9&\`26YS97)T87(@:6UA9V5N`$EN<V5R
M=&%R(&%Q=>T@;&$@8VQA=F4@<&5R<V]N86P@4$=0('!R:79A9&$`26YS97)T
M87(@87%U[2!L82!C;&%V92!P97)S;VYA;"!01U`@</IB;&EC80!);G-E<G1A
M<B!A<77M(&QA(&-L879E(%!'4"!P^F)L:6-A`$EN<V5R=&%R('1A8FQA`$EN
M<V5R=&%R(';M;F-U;&\@5V5B`$EN<V5R=&%R(%]C;VQU;6YA(&1E;&%N=&4`
M26YS97)T82!U;F$@;G5E=F$@8V]L=6UN82!D971RX7,@9&4@;&$@86-T=6%L
M`$EN<V5R=&$@=6YA(&YU979A(&-O;'5M;F$@9&5L86YT92!D92!L82!A8W1U
M86P`26YS97)T82!U;F$@9FEL82!N=65V82!D96)A:F\@9&4@;&$@86-T=6%L
M`$EN<V5R=&$@=6YA(&9I;&$@;G5E=F$@96YC:6UA(&1E(&QA(&%C='5A;`!)
M;G-E<G1A('5N('#A<G)A9F\@=')A<R!E;"!N;V1O(&%C='5A;`!);G-E<G1A
M('5N('#A<G)A9F\@86YT97,@9&5L(&YO9&\@86-T=6%L`$EN<V5R=&%R('!L
M86YT:6QL82!A;'1E<FYA=&EV80!);G-E<G1A<B!U;F$@9&ER96-C:?-N(&1E
M(&-O<G)E;R!E;B!L82!Q=64@<F5C:6)I<B!L82!C;VYT<F%S9?%A.@!);G-E
M<G1A<B!C96QD82!D971RX7,`26YS97)T87(@8V5L9&$@86YT97,`26YS97)T
M87(@8V]L=6UN82!D971RX7,`26YS97)T87(@8V]L=6UN82!A;G1E<P!);G-E
M<G1A<B!M96YS86IE<P!);G-E<G1A<B!PX7)R869O(&1E='+A<P!);G-E<G1A
M<B!PX7)R869O(&%N=&5S`$EN<V5R=&%R(&9I;&$@9&5B86IO`$EN<V5R=&%R
M(&9I;&$@96YC:6UA`$EN<V5R=&%R(&QA(')E<W!U97-T82!N96-E<V%R:6$@
M82!L82!P<F5G=6YT82!D92!S96=U<FED860Z`$EN<V5R=&%R+TUO9&EF:6-A
M<B!I;6%G96X`26YS97)T87(O36]D:69I8V%R(';M;F-U;&\`4V%L9&\@:6YS
M=69I8VEE;G1E('!A<F$@96YV:6%R(&$@;&$@;&ES=&$@9&4@9&ES=')I8G5C
M:?-N+@!386QD;R!I;G-U9FEC:65N=&4N`$5N=&5R;P!,:7-T82!D92!E;G1E
M<F]S`%-E(&AA('-E;&5C8VEO;F%D;R!U;F$@86-C:?-N(&YO(';A;&ED82!P
M87)A(&5S=&4@8V]M<&]N96YT92X`3&$@9&ER96-C:?-N(&YO(&5S(';A;&ED
M80!%;"!B=7KS;B!R96UO=&\@;F\@97,@=N%L:61O`%5$2"`H0V%B96-E<F$@
M9&4@1&%T;W,@9&4@57-U87)I;RD@;F\@=N%L:61A+@!$871O<R!:25`@;F\@
M=N%L:61O<P!!<&QI8V%C:?-N(&YO(';A;&ED82X`240@9&4@;&]T92!N;R!V
MX6QI9&\N`$-A<F%C=&5R97,@;F\@=N%L:61O<R!E;B!L82!D:7)E8V-I\VX@
M9&4@8V]R<F5O.B`E<RX`4V4@:&%N(&5N=FEA9&\@9&%T;W,@;F\@=N%L:61O
M<RX`1&ER96-C:?-N(&1E(&-O<G)E;R!N;R!VX6QI9&$N`$9O<FUA=&\@9&4@
M87)C:&EV;R!N;R!VX6QI9&\`0VQA=F4@;F\@=N%L:61A`$-L879E(&1E(&QI
M8V5N8VEA(&YO(';A;&ED82X`4V4@:&$@:6YD:6-A9&\@=6YA('5B:6-A8VGS
M;B!N;R!VX6QI9&$N`&US9U]T>7!E(&YO(';A;&ED;RX`87!I7VED(&YO(';A
M;&ED;R!O(&1E<V%P87)E8VED;RX`4&%RX6UE=')O<R!N;R!VX6QI9&]S(&\@
M9&5S87!A<F5C:61O<RX`4')I=FEL96=I;R!D96P@<&%D<F4@;F\@=N%L:61O
M<RX`240@9&4@87-O8VEA9&\@;F\@=N%L:61O+@!#;&%V92!P97)S;VYA;"!0
M1U`@<')I=F%D82!N;R!VX6QI9&$`0VQA=F4@<&5R<V]N86P@4$=0('#Z8FQI
M8V$@;F\@=N%L:61A`$/S9&EG;R!D92!P<F]D=6-T;R!N;R!VX6QI9&\N`%!R
M;W1O8V]L;R!N;R!VX6QI9&\N`$1E<W1I;F%T87)I;R!N;R!VX6QI9&\Z("(E
M<R(`3V)J971O(&-O;7!A<G1I9&\@;F\@=N%L:61O+@!$:7)E8V-I\VX@9&5L
M(')E;6ET96YT92!N;R!VX6QI9&$`1&%T;W,@=6YI8V]D92!N;R!VX6QI9&]S
M+@!);G9E;G1A<FEO`$EN=F5R=&ER`$EN=F5R=&ER('-E;&5C8VGS;@!)<N%N
M+"!297#Z8FQI8V$@27-LX6UI8V$@9&4`27)A<0!)<FQA;F1A`$ES;&$@9&4@
M36%N`$)O<G)A<V-A<R!A:7-L861A<P!)<W)A96P`16UI<V]R`$-U<G-I=F$`
M271A;&EA`$IA;6%I8V$`16YE<F\`2F%P\VX`2F%P;V[I<R`H25-/+3(P,C(M
M2E`I`$IE<G-E>0!*;W)DX6X`2G5L:6\`2G5N:6\`2G5S=&EF:6-A<@!!;&EN
M96%R(&%L(&-E;G1R;P!*=7-T:69I8V%R`$%L:6YE87(@82!L82!I>G%U:65R
M9&$`06QI;F5A<B!A(&QA(&1E<F5C:&$`2T(`2V%Z86MH<W1A;@"_0V]N<V5R
M=F%R(&5L(&]R:6=I;F%L/P!+96YY80!%;"!S97)V:61O<B!+97)B97)O<R!H
M82!R96-H87IA9&\@;&$@875T96YT:69I8V%C:?-N+@!.;W9A=&]S(&1E;"!+
M97)N96P`0W)E86-I\VX@9&4@8VQA=F4`2'5E;&QA(&1I9VET86P@9&4@;&$@
M8VQA=F4`5&%M8?%O(&1E(&-L879E`%1I<&\@9&4@8VQA=F4`57-O(&1E(&QA
M(&-L879E.@!,82!C;&%V92!Y82!E>&ES=&4@96X@96P@<V5R=FED;W(@9&4@
M8VQA=F5S('#Z8FQI8V\N`$QA(&=E;F5R86-I\VX@9&4@;&%S(&-L879E<R!P
M=65D92!T87)D87(@8F%S=&%N=&4@=&EE;7!O+B"_0V]N=&EN=6%R(&-O;B!L
M82!G96YE<F%C:?-N(&1E(&QA<R!C;&%V97,_`$YO('-E(&1I<W!O;F4@9&4@
M:6UP;W)T86-I\VX@9&4@8VQA=F5S+B!%<W1E('-E<G9I9&]R(&YO('1I96YE
M(&%C=&EV861A(&QA(&-A<F=A(&1E(&%R8VAI=F]S+@!.;R!S92!D:7-P;VYE
M(&1E(&EM<&]R=&%C:?-N(&1E(&-L879E<RX@3F\@:&$@9&5F:6YI9&\@=6YA
M(&QI8G)E=&$@9&4@9&ER96-C:6]N97,@82!L82!Q=64@8?%A9&ER(&QO<R!C
M;VYT86-T;W,N`$-L879E(&5N=FEA9&$@8V]R<F5C=&%M96YT92!A;"!S97)V
M:61O<B!D92!C;&%V97,@</IB;&EC;RX`3FGQ;W,`2VER:6)A=&D`0V]R96$L
M(%)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A(&1E`$-O<F5A+"!297#Z
M8FQI8V$@9&4`0V]R96%N;R`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!?
M1&ES=')I8G5C:?-N`$ED:6]M80!,86\L(%)E</IB;&EC82!$96UO8W+A=&EC
M82!0;W!U;&%R`$-U87)T;R!M96YG=6%N=&4`VFQT:6UA('#A9VEN82!D96P@
M8G5Z\VX`VFQT:6UA('#A9VEN80#:;'1I;6\@8V%M8FEO(&1E(&-O;G1R87-E
M\6$`0W5A<G1O(&UE;F=U86YT90#:;'1I;6$@86-T=6%L:7IA8VGS;CH`VFQT
M:6UA('-E<VGS;CH@)7,`VFQT:6UA('-E<VGS;CH@)7,@9&5S9&4@)7,`VFQT
M:6UA('-E<VGS;CH@3G5N8V$`3&%T=FEA`$QE>65S`$1I<W1R:6)U8VGS;@!$
M96IA<B!E;B!B;&%N8V\@<&%R82!E;&EM:6YA<B!E;"!B;W)D90!,96)A;F]N
M`$EZ<75I97)D80!#86)E8V5R82!I>G%U:65R9&$`5F%L;W)E<R!D92!L82!I
M>G%U:65R9&$`3&5S;W1H;P!.:79E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA
M;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=E<F$@;&QO=FEZ;F$`3&QU=FEA
M(&QI9V5R80!,;'5V:6$@;&EG97)A(&UA='5T:6YA`$QL=79I82!L:6=E<F$@
M=F5S<&5R=&EN80!!9W5A8V5R;R!L:6=E<F\`3&QU=FEA<R!Y('1R=65N;W,`
M3F5V861A('-U879E`$QI9V5R;R!A9W5A8V5R;R!D92!N:65V90!#:&%S8V%R
M<FEL;&\`5NUN8W5L;P"_5FEN8W5L87(@861J=6YT;W,_`$5L(';M;F-U;&\@
M87!U;G1A(&$Z`%9I;F-U;&%R(&1I<F5C8VGS;B!D92!C;W)R96\@82!L82!P
MX6=I;F$@9&4@8V]M<&]S:6-I\VX@86P@;6]S=')A<@!.;R!S92!P97)M:71E
M;B!A9&IU;G1O<R!V:6YC=6QA9&]S+@!6[6YC=6QO<P!,;W,@=NUN8W5L;W,@
M97AP:7)A<N%N(&5L("5S`$-O;VMI92!,:6YU>`!,:7-T87(@+2!E;"!U<W5A
M<FEO('!U961E(&5X86UI;F%R(&QA(&-A<G!E=&$`3&ES=&%R(&)A<V5S(&1E
M(&1A=&]S`$QI<W1A<B!T96UA<R!D92!A>75D80!,:7-T87(@=&%B;&%S`+],
M:7-T87(@=&]D;W,@;&]S(&-O;G1A8W1O<R!A;"!C87)G87(@;&$@<&%N=&%L
M;&$@9&4@8V]N=&%C=&]S/R`H4VD@97-TX2!D97-H86)I;&ET861O+"!S\VQO
M('9E<N$@;&]S(&-O;G1A8W1O<R!Q=64@8G5S<75E(&1E(&9O<FUA(&5X<&SM
M8VET82D`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N
M97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`
M3&ES=&%R(&5N(&QA(&-A8F5C97)A`$AA(&9A;&QA9&\@96P@;&ES=&%D;R!D
M92!L87,@<V5S:6]N97,Z("5S`$AA(&9A;&QA9&\@96P@;&ES=&%D;R!D92!U
M<W5A<FEO<SH@)7,`16P@;&ES=&%D;R!D92!U<W5A<FEO<R!E<W3A(&1E<VAA
M8FEL:71A9&\N`$QI=&5R871U<F$`3&ET=6%N:6$`3&5Y96YD;RXN+@!"=7KS
M;B!L;V-A;#H`2&]R82!L;V-A;#H@`$ED:6]M82!Y(&AO<F$`56)I8V%C:?-N
M`$EN:6-I87(@<V5S:?-N`$EN:6-I87(@<V5S:?-N(&5N("5S`%)E9VES=')O
M(&1E(&QA<R!S97-I;VYE<R!D92!S:6YC<F]N:7IA8VGS;B!A;G1E<FEO<F5S
M`%-A;&ER`$EN:6-I87(@<V5S:?-N`%1A<F5A<R!D92!I;FEC:6\@9&4@<V5S
M:?-N`$9A;&SS(&5L(&EN:6-I;R!D92!S97-I\VX@<&]R<75E(&EN=')O9'5J
M;R!I;F-O<G)E8W1A;65N=&4@<W4@;F]M8G)E(&1E('5S=6%R:6\@;R!C;VYT
M<F%S9?%A+@!&86QL\R!E;"!I;FEC:6\@9&4@<V5S:?-N+@!497AT;R!C;VUP
M;&5T;P!!;6]R`$)A:F$`4')I;W)I9&%D(&)A:F$`06QF86)E=&\@9W)I96=O
M(&5N(&UI;OIS8RX`06QF86)E=&\@;&%T:6YO(&5N(&UI;OIS8RX`3OIM97)O
M<R!R;VUA;F]S(&5N(&UI;OIS8RX`4F5D=6-I9&$`3'5X96UB=7)G;P!-30!-
M3U1$`$5L(&%D:G5N=&\@35,M5$Y%1B!N;R!C;VYT96[M82!D871O<RX`35-'
M`$UA8V%O`$UA8V5D;VYI82P@06YT:6=U82!297#Z8FQI8V$@675G;W-L879A
M(&1E`$%R8VAI=F\@36%C:6YT;W-H`$UA9&%G87-C87(`36%G:6$`0V]R<F5O
M`$%D;2X@8V]R<F5O`%9I<W1A<R!P<F5V:6%S(&1E(&-O<G)E;P!4:7!O(&1E
M('-E<G9I9&]R(&1E(&-O<G)E;R!A;"!Q=64@8V]N96-T87)S93H`0G5Z\VX`
M3W!C:6]N97,@9&4@=FES=6%L:7IA8VGS;B!D92!B=7IO;F5S('D@8V%R<&5T
M87,`0W)E87(@7W;M;F-U;&\N+BX`36%L87=I`$UA;&%S:6$`36%L9&EV87,`
M36%L:0!-86QT80!'97-T:6]N82!L82!L:7-T82!D92!C871E9V]R[6%S(&-O
M;B!L82!Q=64@971I<75E=&%R(&5L96UE;G1O<R!Y(&QO<R!C;VQO<F5S(&%S
M;V-I861O<R!A(&1I8VAA<R!C871E9V]R[6%S+@!-87!A(&UA<#(T`$UA<&$@
M;6%P<75E<W0`0V]R<F5S<&]N9&5N8VEA<R!A;&UA8V5N861A<RX`36%R>F\`
M36%R9V5N`$UA<F-A<B!L;W,@;65N<V%J97,@9&4@;&$@8V%R<&5T82!C;VUO
M(&QE[61O<P!-87)C87(@;&]S(&UE;G-A:F5S(&1E(&QA(&-A<G!E=&$@8V]M
M;R!S:6X@;&5E<@!-87)C87(@8V]M;SH`OU)E<V%L=&%R(&YI=F5L97,@9&4@
M8VET87,@8V]N(&-O;&]R97,@9&ES=&EN=&]S/P"_36%R8V%R(&UE;G-A:F5S
M(&-O;6\@;&5I9&]S/R`H4_-L;R!)34%0*0"_4F5S86QT87(@;6%R8V%D;W(@
M<VEM<&QE/P!-87)C87(@8V]N(&QA<R!B86YD97)A<R!D92!,9>UD;R]3:6X@
M;&5E<@!-87)C87(@8V]N(&]T<F%R(&)A;F1E<F%S("AP+F4N($EM<&]R=&%N
M=&4O4F5S<&]N9&ED;RD`27-L87,@36%R<VAA;&P`36%R=&EN:6-A`$-O:6YC
M:61I<B!E;B!T;V1A<P!#;VEN8VED:7(@96X@8W5A;'%U:65R80!#86UP;W,@
M8V]I;F-I9&5N=&5S`$UA=7)I=&%N:6$`36%U<FEC:6\`4V%L9&\@;>%X:6UO
M('!E<FUI=&ED;RX`4V4@:&$@<V]B<F5P87-A9&\@96P@;OIM97)O(&WA>&EM
M;R!D92!P87)T97,@9&4@;65N<V%J92X`5&5M<"X@;>%X:6UA(/IL=&EM87,@
M,C0@:&]R87,Z(`!496UP+B!MX7AI;6$@^FQT:6UA<R`V(&AO<F%S.B``5&%M
M8?%O(&WA>&EM;R!D92!A9&IU;G1O`$[Z;65R;R!MX7AI;6\@9&4@8V%R<&5T
M87,`3OIM97)O(&WA>&EM;R!D92!B;&]Q=65S(&1E;"!P;W)T86P`3&]N9VET
M=60@;>%X:6UA`%-E(&AA(&%L8V%N>F%D;R!E;"!N^FUE<F\@;>%X:6UO(&1E
M(&%D:G5N=&]S+@!392!H82!A;&-A;GIA9&\@96P@=&%M8?%O(&WA>&EM;R!D
M92!A9&IU;G1O<RX`36%Y;P!-87EO='1E`$UE9&EC:6YA`$UI96UB<F]S`$QI
M<W1A9&\@9&5L(&UE;OH@9&4@8V%R<&5T87,`1F]R;6%T;R!D96P@;65N^CH`
M0V]M8FEN87(@8V5L9&%S`$UE;G-A:F4`4F5D86-C:?-N(&1E;"!M96YS86IE
M`%!O<B!F96-H80!/<&-I;VYE<R!D92!M96YS86IE<P!"^G-Q=65D82!D92!M
M96YS86IE<P!0;W(@=&%M8?%O`$]R:6=E;B!D96P@;65N<V%J90!392!H82!C
M;VUP<F]B861O(&-O<G)E8W1A;65N=&4@96P@;65N<V%J92!P97)O(&YO('-E
M('!U961E('9E<FEF:6-A<B!E;"!C97)T:69I8V%D;R!D96P@9FER;6%N=&4N
M`%9I<W5A;&EZ86-I\VX@9&4@;65N<V%J97,`365N<V%J92!C861U8V%D;RX`
M0F%N9&5R87,@9&5L(&UE;G-A:F4`0V%R<&5T87,@9&4@;65N<V%J97,`365N
M<V%J92!D92`E<P!%;"!M96YS86IE('1I96YE(&%D:G5N=&]S`$5L(&UE;G-A
M:F4@97-TX2!C:69R861O`$5L(&UE;G-A:F4@97-TX2!F:7)M861O`$UE;G-A
M:F5S(&-O:6YC:61E;G1E<P!392!H82!R961I<FEG:61O(&-O<G)E8W1A;65N
M=&4@96P@;65N<V%J92X`4V4@96YV:?,@8V]R<F5C=&%M96YT92!E;"!M96YS
M86IE+"!P97)O(&YO('-E(&=U87)D\R!E;B`E<P!392!E;G9I\R!C;W)R96-T
M86UE;G1E(&5L(&UE;G-A:F4N`%1I<&\@9&4@;65N<V%J90!-96YS86IE<R!P
M;W(@<.%G:6YA(&5N(&5L(&QI<W1A9&\@9&5L(&)U>O-N+@!-96YS86IE<R!A
M`%1I96UP;R!D92!-971A<@!";&]Q=64@365T87(@;F\@9&ES<&]N:6)L92X`
M0FQO<75E($UE=&%R(&YO(&1I<W!O;FEB;&4N(%-E(&AA;B!R96=I<W1R861O
M(&QO<R!D971A;&QE<R!P87)A(&5L(&%D;6EN:7-T<F%D;W(N`$YO(&5S=.$@
M8V]N96-T861A(&QA($UE=&%R1$(`3>ET;V1O`$5L(&WI=&]D;R`B)7,B(&YO
M(&5S=.$@9&5F:6YI9&\`3>ET;V1O(&YO(&1E9FEN:61O+B!-Z71O9&\@;&QA
M;6%D;SH@)7,`3>ET<FEC;P!-Z6II8V\`36EC<F]N97-I82P@17-T861O<R!&
M961E<F%D;W,@9&4`16X@;65D:6\`5&EP;R!-:6UE`%1E;7`N(&WM;BX@;&%S
M(/IL=&EM87,@,C0@:&]R87,Z(`!496UP+B!M[6XN(&QA<R#Z;'1I;6%S(#8@
M:&]R87,Z(`!4;V1A=NUA(&YO(&AA(&5X<&ER861O(&QA(&%N=&EG_&5D860@
M;>UN:6UA(&1E(&QA(&-O;G1R87-E\6$`4F5F;&5J87(`36ES8V5LX6YE80!0
M87%U971E(%!%05(@2%144%]297%U97-T(&1E<V%P87)E8VED;RX`1F%L=&$@
M;&$@8V]N9FEG=7)A8VGS;BX@5&EE;F4@<75E(&=E;F5R87)L82!A:&]R82!S
M:2!D97-E82!U=&EL:7IA<B!E<W1A(&%P;&EC86-I\VXN`$E$(&1E(&UE;G-A
M:F4@9&5S87!A<F5C:61O+@!087%U971E(%!%05(@36%I;"!D97-A<&%R96-I
M9&\N`$E$(&1E('-E<VGS;B!D97-A<&%R96-I9&\N`$QU;@!#;W)R96\@;?-V
M:6P`36]D97)A9&\`4V4@:&$@;6]D:69I8V%D;R!L82!F96-H80!-;V1I9FEC
M87(`36]D:69I8V%R(%523`!-\V1U;&\`36]L9&%V:6$L(%)E</IB;&EC82!D
M90!-\VYA8V\`36]N9V]L:6$`365S('D@8?%O`$UE;G-U86QM96YT90!-;VYT
M<V5R<F%T`$9A<V5S(&1E(&QA(&QU;F$`4V4@:&%N(&5N8V]N=')A9&\@;>%S
M(&-A;7!O<R!E;B!L82!L[6YE82`E9"!Q=64@;&]S("5D(&5S<&5R861O<RX`
M4V4@:&$@96YC;VYT<F%D;R!MX7,@9&4@=6YA(&1I<F5C8VGS;B!P87)A(&5L
M(&-A;7!O("(E<R(N`$UA<G)U96-O<P!&=6YD86UE;G1A;&UE;G1E(&1E<W!E
M:F%D;P!&=6YD86UE;G1A;&UE;G1E(&YU8F]S;P!&=6YD86UE;G1A;&UE;G1E
M('-O;&5A9&\`5')A<VQA9&%R`$1E<W!L87IA<B!H86-I82!A8F%J;P!$97-P
M;&%Z87(@82!L82!I>G%U:65R9&$`1&5S<&QA>F%R(&$@;&$@9&5R96-H80!$
M97-P;&%Z87(@:&%C:6$@87)R:6)A`$1E<W!L87IA<B!H86-I82!A8F%J;P!4
M<F%S;&%D87(@;&]S(&UE;G-A:F5S(&1E('-P86T@82!L82!C87)P971A(&1E
M('-P86T@>2!L;W,@;65N<V%J97,@:6YO9F5N<VEV;W-A(&QA(&-A<G!E=&$@
M9&4@16YT<F%D80!4<F%S;&%D87(@82!L82!C87)P971A`$1E<W!L87IA<B!H
M86-I82!A<G)I8F$`36]Z86UB:7%U90!,:7-T87,@9&5S<&QE9V%B;&5S(&UU
M;'1I+6YI=F5L`$UA<&$@54L@;?IL=&EP;&4`375L=&EP87)T+V%L=&5R;F%T
M:79E`%9I<W5A;&EZ86-I\VX@9&4@;65N<V%J97,`4V5L96-C:?-N(&WZ;'1I
M<&QE`$ED96YT:61A9`!-:2!I9&5N=&ED860`36D@<&]R=&%L`$1I<W1R:6)U
M8VGS;B!D92!M:2!P;W)T86P`37EA;FUA<@!.3RP@3D\@97-T;WD@9&4@86-U
M97)D;P!.24Y'54Y/`$]"4T525D%#2=-.`$YO;6)R90!%;"!N;VUB<F4@>2]O
M(&QA(&1I<F5C8VGS;B!N;R!P=65D96X@9&5J87)S92!E;B!B;&%N8V\`3F%M
M:6)I80!.875R=0!392!N96-E<VET82!U;F$@86-C:?-N`$YE<&%L`$AO;&%N
M9&$`06YT:6QL87,@2&]L86YD97-A<P!54DP@8F%S92!D92!.971S8V%P90!5
M4DP@9&4@86YU;&%C:?-N(&1E($-!(&1E($YE='-C87!E`%523"!D92!P;VSM
M=&EC87,@9&4@0T$@9&4@3F5T<V-A<&4`55),(&1E(')E;F]V86-I\VX@9&4@
M3F5T<V-A<&4`55),(&1E(&%N=6QA8VGS;B!D92!.971S8V%P90!.;VUB<F4@
M9&4@<V5R=FED;W(@4U-,(&1E($YE='-C87!E`$-O;65N=&%R:6\@9&5L(&-E
M<G1I9FEC861O(&1E($YE='-C87!E`%1I<&\@9&4@8V5R=&EF:6-A9&\@9&4@
M3F5T<V-A<&4`4F5D`$YU;F-A`$YU;F-A(&=U87)D87(@861J=6YT;W,`3G5E
M=F]S`$YU979A($-A;&5D;VYI80!.=65V82!C871E9V]R[6$`0V%R<&5T82!N
M=65V80!#;W)R96\@;G5E=F\`4F5D86-T87(`365N<V%J92!N=65V;R!P87)A
M("5S`$QU;F$@;G5E=F$`3G5E=F\@;F]M8G)E(&1E('5S=6%R:6\@*&]P8VEO
M;F%L*0!.=65V82!:96QA;F1A`$UE;G-A:F5S(&YU979O<P!#;VYT<F%S9?%A
M(&YU979A`$QA(&YU979A(&-O;G1R87-E\6$@97AP:7)A<N$@96P@)7@N`$QA
M<R!C;VYT<F%S9?%A<R!N;R!C;VEN8VED96XN`$YU979A('9E;G1A;F$@*%]B
M;&%N:RD`3F]T:6-I87,`1RX@9&4@;F]T:6-I87,`4VEG=6EE;G1E`%!R\WAI
M;6%S(#0@9F%S97,`4'+S>&EM;R!M96YS86IE`%!R\WAI;6$@<.%G:6YA`$]P
M8VEO;F5S('-I9W5I96YT97,`4VEG=6EE;G1E/@!.:6-A<F%G=6$`3FEG97(`
M3FEG97)I80!.;V-H90!.:75E`$YO`$YO('-E(&AA(&5N8V]N=')A9&\@=6X@
M8V5R=&EF:6-A9&\`4VEN(&-I9G)A<@!.;R!H87D@8VQA=F5S(&5N(&5L(&QL
M879E<F\`4VEN(&UE;G-A:F5S`$YO('-E(&AA(&EM<&]R=&%D;R!U;F$@8VQA
M=F4@4$=0('#Z8FQI8V$N`$YO(&AA>2!U;B!C97)T:69I8V%D;R!P97)S;VYA
M;`!6:7-T82!P<F5V:6$@<VEN('1E>'1O`$YO('-E(&AA;B!E;F-O;G1R861O
M(&-L879E<R!P^F)L:6-A<P!.;R!S92!H82!I;7!O<G1A9&\@;&$@8VQA=F4@
M4R]-24U%('#Z8FQI8V$N`$YO('-E(&AA;B!E;F-O;G1R861O(&%D:G5N=&]S
M+@!.;R!H87D@9&%T;W,@9&4@8V]N9FEG=7)A8VGS;B!P87)A(&UO<W1R87(@
M9&EF97)E;F-I87,N`$YO('-E(&1I<W!O;F4@9&4@97-T<F%T96=I82!D92!E
M;&%B;W)A8VGS;B!D92!I;>%G96YE<R!)4T\N`$YO(&AA>2!P;&%N=&EL;&$@
M9&4@;&]T97,`3F\@:&%Y(&)L;W%U97,@96X@;&$@<&]S:6-I\VX@:6YD:6-A
M9&$`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@;F]M8G)E(&1E(&%G96YD82!P
M87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!-0T%,+@!3:6X@8V%M8FEO<RX`3F\@
M<V4@<'5E9&5N(&'Q861I<B!D97-C96YD:65N=&5S(&$@97-T92!P<FEV:6QE
M9VEO+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N
M9FEG=7)A8VGS;B!P87)A("5S+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF
M;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@1E10+@!.
M;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A
M8VGS;B!P87)A(%9&4R!P;W(@4U%,+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@
M:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@87)C
M:&EV;R!344PN`$YO('%U961A('-A;&1O+@!.;R!S92!H82!I;G1R;V1U8VED
M;R!E;"!D97-T:6YO+@!.;R!S92!E;F-U96YT<F$@:6YF;W)M86-I\VX@9&4@
M9&ER96-C:?-N(&5N(&QA(&-L879E('#Z8FQI8V$N`$YO('-E(&AA(&-A<F=A
M9&\@;FEN9_IN(&%R8VAI=F\`;F\@:&%Y(&-A<G!E=&%S('-E;&5C8VEO;F%D
M87,N`$YO('-E(&-O;7!R=65B82!E;"!C;W)R96\@;G5E=F\@96X@;FEN9W5N
M82!C87)P971A+@!.;R!S92!E<W!E8VEF:6-A<F]N(&-A<G!E=&%S`$YO(&AA
M>2!C87)P971A<R!C;VX@;65N<V%J97,@;G5E=F]S`$YO(&AA>2!C87)P971A
M<R!C;VX@;65N<V%J97,@<VEN(&QE97(`3F\@<V4@:&%N(&5N8V]N=')A9&\@
M:6-O;F]S+@!.;R!S92!H82!D969I;FED;R!L82!U8FEC86-I\VXN`$YO('-E
M(&AA(&1E9FEN:61O(&QA('5B:6-A8VGS;BX`3F\@:&%Y('1E>'1O(&5N(&5L
M(&-U97)P;R!D96P@;65N<V%J90!.;R!S92!H82!D979U96QT;R!N:6YG^FX@
M;65N<V%J92X`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@;65N<V%J92X`3F\@
M:&%Y(&UE;G-A:F5S('%U92!C;VEN8VED86X@8V]N('-U(&+Z<W%U961A+@!.
M;R!S92!H82!E<W!E8VEF:6-A9&\@=6X@;F]M8G)E+@!.;R!S92!H82!E<W!E
M8VEF:6-A9&\@=6X@;OIM97)O+@!.;R!O9F5N<VEV87,`3F\@<V4@:&$@:6YT
M<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I
M\VX@2%144"X`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@
M<&%R82!L82!A=71E;G1I9FEC86-I\VX@24U!4"X`3F\@<V4@:&$@:6YT<F]D
M=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@
M2V5R8F5R;W,N`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A
M('!A<F$@;&$@875T96YT:69I8V%C:?-N(&1E(&EN:6-I;RX`3F\@<V4@:&$@
M:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC
M86-I\VX@4$%34U=$+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A
M<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!334(N`$YO('-E(&AA(&EN
M9&EC861O(';M82!D92!A8V-E<V\@82!L;W,@8FEN87)I;W,@3W!E;E-33"X@
M4&%R82!T<F%B86IA<B!C;VX@9&%T;W,@4$M#4R`Q,B!H86-E;B!F86QT82!L
M;W,@8FEN87)I;W,@3W!E;E-33"X`4VEN(&%L=&%S('!E;F1I96YT97,N`$YO
M('-E(&AA(&EM<&]R=&%D;R!L82!C;&%V92!P97)S;VYA;"!01U`@<')I=F%D
M82X`3F\@<V4@:&$@:6UP;W)T861O(&QA(&-L879E('!E<G-O;F%L(%!'4"!P
M^F)L:6-A+@!.;R!S92!H86X@:6UP;W)T861O(&-E<G1I9FEC861O<R!P97)S
M;VYA;&5S(%,O34E-12X`3F\@:&%Y(&-L879E('!R:79A9&$@<&5R<V]N86P@
M<&]R(&QO('%U92!N;R!S92!P=65D92!D97-C:69R87(@96P@;65N<V%J92X`
M0V%R96-E(&1E('%U;W1A+@!3:6X@<F%Y87,`3F\@<V4@:&$@97-P96-I9FEC
M861O('5N('-E<&%R861O<BX`3FEN9W5N;P!.;R!S92!H82!C;VYF:6=U<F%D
M;R!U;B!P<F]G<F%M82!D92!C;W)R96-I\VX@;W)T;V=RX69I8V$N`$YO(&AA
M>2!E<G)O<F5S(&1E(&]R=&]G<F%F[6$`3F\@97AI<W1E(&5L(&%R8VAI=F\`
M3F\@:&%Y('-U9V5R96YC:6%S`$YO('-E('!U961E(&QO8V%L:7IA<B!U;B!M
MZ71O9&\@9&4@875T96YT:69I8V%C:?-N($E-05`@<V]P;W)T861O+@!.;R!S
M92!D:7-P;VYE(&1E('5N(&1I<F5C=&]R:6\@9&4@86QM86-E;F%M:65N=&\@
M=&5M<&]R86PN`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!U<W5A<FEO+@!.
M;R!S92!H82!E;G9I861O(&5L(&YO;6)R92!D92!U<W5A<FEO('DO;R!L82!C
M;VYT<F%S9?%A+@!.;R!S92!H86X@9&5V=65L=&\@9&%T;W,@6$U,(';A;&ED
M;W,`4VEN('9A;&]R97,`3F\@<V4@96YC;VYT<O,@;&$@=F5R<VGS;B!E;B!L
M82!C;VYF:6=U<F%C:?-N(&]R:6=I;F%L+B!296=E;F5R87(@;&$@8V]N9FEG
M=7)A8VGS;BX`3F\@<V4@96YC;VYT<O,@;&$@=F5R<VGS;B!E;B!L82!C;VYF
M:6=U<F%C:?-N+B!296=E;F5R87(@;&$@8V]N9FEG=7)A8VGS;BX`4VEN('!A
M<G1I8VEP86YT97,`3FEN9W5N80!.:6YG=6YO("AU<V\@:6UP;.UC:71O*0!.
M\W)D:6-O("A)4T\M.#@U.2TQ,"D`27-L82!D92!.;W)F;VQK`$YO<FUA;`!(
M96UI<V9E<FEO(&YO<G1E`$ES;&%S($UA<FEA;F%S(&1E;"!.;W)T90!.;W)U
M96=A`$YO(&1E<W!UZ7,`3F\@86YT97,`3F\@96QI;6EN861O`$YO(&)O<G)A
M9&]R`$YO(&EM<&]R=&%N=&4`3F\@<&5R<V]N86P`3F\@97,@=6X@9&ER96-T
M;W)I;P!.;R!E<R!U;F$@8VQA=F4@</IB;&EC82!VX6QI9&$N`$UE;G-A:F5S
M(&YO(&5L:6UI;F%D;W,`4VEN(&1E<V%R<F]L;&%R+@!-96YS86IE<R!N;R!I
M;7!O<G1A;G1E<P!3:6X@97-T86)L96-E<@!.;R!E<W3A('-O<&]R=&%D;RX`
M5&5N9V$@96X@8W5E;G1A('%U92#I<W1O('!U961E(&QL979A<B!U;B!R871O
M`$YO=&%S`$YA9&$`3F\@:&%Y(&YA9&$@=FES=6%L:7IA8FQE+"!R971R;V-E
M9&$N`$YO=&EF:6-A8VGS;CH@061J=6YT;R!V:6YC=6QA9&\@9&5S8V%R9V%D
M;P!.;W9I96UB<F4`3OIM97)O`$[Z;65R;R!D92!C87)A8W1E<F5S`$[Z;65R
M;R!D92!C;VQU;6YA<P!.^FUE<F\@9&4@;65S97,@<75E('-E(&-O;G-E<G9A
M;B!L;W,@861J=6YT;W,@=FEN8W5L861O<R!A;G1I9W5O<R!A;"!E;&EM:6YA
M<FQO<R!M96YS=6%L;65N=&4N`$-A<G!E=&%S(")%;G9I861O<R(@86YT:6=U
M87,@<75E('-E(&-O;G-E<G9A;B!A;"!E;&EM:6YA<B!M96YS=6%L;65N=&4N
M`$[Z;65R;R!D92!F:6QA<P!.;R!S92!H86X@97-P96-I9FEC861O(&[Z;65R
M;W,@82!A8W1U86QI>F%R(&5N(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX`
M06-E<'1A<@!/`$]B:F5T;P!#<F5A9&]R(&1E(&]B:F5T;W,`3V-T86P`3V-T
M=6)R90!&:6QT<F%R(&]F96YS87,`3V9I8VEN80!,82!C;VYT<F%S9?%A(&%N
M=&EG=6$@>2!L82!N=65V82!D96)E;B!S97(@9&ES=&EN=&%S+@!-96YS86IE
M<R!A;G1I9W5O<P!#;VYT<F%S9?%A(&%N=&EG=6$`3&$@8V]N=')A<V7Q82!A
M;G1I9W5A(&YO(&5S(&-O<G)E8W1A+@!0=7)G86YD;R!C87)P971A<R`B16YV
M:6%D;W,B(&%N=&EG=6%S+@!/;>%N`%/S;&\@;&]S('-E<G9I9&]R97,@24U!
M4"!S;W!O<G1A;B!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N`+]-;W-T<F%R
M('/S;&\@;&%S(&-A<G!E=&%S('%U92!C;VYT96YG86X@;65N<V%J97,@<VEN
M(&QE97(_`%/S;&\@;V9E;G-I=F%S`%/S;&\@<V4@<&5R;6ET92!U;F$@9&ER
M96-C:?-N(&1E(&-O<G)E;RX`4&%R82!E<W1A(&%C8VGS;B!H87D@<75E('-E
M;&5C8VEO;F%R('/S;&\@=6YA(&-A<G!E=&$N`%/S;&\@96P@<')O<&EE=&%R
M:6\@;R!U;B!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('!U961E(&-A;6)I
M87(@;&$@<')O<&EE9&%D(&\@;&]S('!R:79I;&5G:6]S(&1E('!R;W!I971A
M<FEO(&1E('5N(')E8W5R<V\@8V]M<&%R=&ED;P!!8G)?:7(@8V%R<&5T80!!
M8G)I<B!E;B!U;F$@;G5E=F$@=F5N=&%N80!%<G)O<B!/<&5N4U-,.B!.;R!S
M92!P=65D96X@97AT<F%E<B!D871O<R!D92!L82!P87)T92!3+TU)344@9FER
M;6%D82X`0V%R<&5T82!A8FEE<G1A`$%B<FER(&5S=&4@=NUN8W5L;R!E;B!U
M;F$@=F5N=&%N82!N=65V80!3:7-T96UA(&]P97)A=&EV;P!087)T:6-I<&%N
M=&4@;W!C:6]N86P`3W!C:6]N97,`3W!C:6]N97,@9&4@)7,`3&ES=&$@;W)D
M96YA9&$`3W)G86YI>F%C:?-N`%5N:61A9"!O<F=A;FEZ871I=F$`3W)G86YI
M>F%C:?-N`%!L86YT:6QL82!D92!A<&QI8V%C:?-N(&]R:6=I;F%L`%!L86YT
M:6QL87,@;W)I9VEN86QE<R!E;B`E<SH`3W1R;P!/=')A(&EN9F]R;6%C:?-N
M`$]T<F%S(&-U96YT87,@9&4@8V]R<F5O`$]T<F%S(&]P8VEO;F5S`%-E<G9I
M9&]R(&1E('-A;&ED80!0<FEV:6QE9VEO<R!D96P@<')O<&EE=&%R:6\`3&$@
M875T96YT:69I8V%C:?-N(%!!32!N;R!E<W3A(&1I<W!O;FEB;&4N`%!%05(Z
M.DUO=&]R(&1E(&-O<G)E;P!01U``1FER;6$@9&EG:71A;"!01U``0VEF<F%R
M(&UE;G-A:F4@8V]N(%!'4`!$871O<R!C:69R861O<R!C;VX@4$=0`$5R<F]R
M(&1E(%!'4#H@`$5R<F]R(&1E(%!'4#H@2&%C92!F86QT82!U;F$@9G)A<V4@
M8VQA=F4@<&%R82!L82!C;&%V92!P97)S;VYA;"!P<FEV861A+@!/<&-I;VYE
M<R!D92!01U``16YT<F%D82!D92!F<F%S92!C;&%V92!01U``2&%C92!F86QT
M82!U;F$@8V]N97AI\VX@=V5B('-E9W5R82!P87)A('5T:6QI>F%R(&5L('-O
M<&]R=&4@9&4@8VQA=F5S('!E<G-O;F%L97,@4$=0`$-L879E(%!'4"!P^F)L
M:6-A`%1E>'1O(&1E(&QA(&-L879E(%!'4"!P^F)L:6-A`%-E(&AA(&'Q861I
M9&\@8V]R<F5C=&%M96YT92!L82!C;&%V92!01U`@</IB;&EC82!D92`B)7,@
M*"5S*2(N`%-E(&AA(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E(&QA(&-L879E
M(%!'4"!P^F)L:6-A(&1E("(E<R(N`$QL879E<F\@4$=0('#Z8FQI8V\`365N
M<V%J92!C;VX@9FER;6$@4$=0`$UE;G-A:F4@9FER;6%D;R]C:69R861O(&-O
M;B!01U``1&%T;W,@9FER;6%D;W,O8VEF<F%D;W,@8V]N(%!'4`!392!H82!A
M\6%D:61O(&-O<G)E8W1A;65N=&4@;&$@8VQA=F4@4$=0('!R:79A9&$N`%-E
M(&AA(&'Q861I9&\@8V]R<F5C=&%M96YT92!L82!C;&%V92!01U`@</IB;&EC
M82X`16X@97-T92!S:7-T96UA('-E(&AA(&1E<V%C=&EV861O(&5L('-O<&]R
M=&4@4$=0+@!%;"!S;W!O<G1E(%!'4"!N;R!E<W3A(&%C=&EV861O(&%C='5A
M;&UE;G1E('!O<B!L;R!Q=64@;F\@<V4@<'5E9&4@8V]M<')O8F%R(&QA(&9I
M<FUA(&1I9VET86PN`$5L('-O<&]R=&4@4$=0(&YO(&5S=.$@86-T:79A9&\@
M86-T=6%L;65N=&4@<&]R(&QO('%U92!N;R!S92!P=65D92!D97-C:69R87(@
M96P@;65N<V%J92X`16P@<V]P;W)T92!01U`@;F5C97-I=&$@=71I;&EZ87(@
M=F5N=&%N87,@96UE<F=E;G1E<RX@4VD@;&%S(&AA(&1E<V%C=&EV861O(&5N
M('-U(&YA=F5G861O<BP@=&5N9'+A('%U92!R96%C=&EV87)L87,@;R!L87,@
M8V%R86-T97+M<W1I8V%S(%!'4"!N;R!F=6YC:6]N87+A;B!C;W)R96-T86UE
M;G1E+@!#\V1I9V\@4$A0`$EN=.ER<'(N(%!(4`!,;&]V:7IN82!V97-P97)T
M:6YA`$QL=79I82!V97-P97)T:6YA`$-H87!A<G)O;F5S('9E<W!E<G1I;F]S
M`$YI979E('9E<W!E<G1I;F$`06=U86-E<F\@9&4@;FEE=F4@=F5S<&5R=&EN
M;P!3;VP@=F5S<&5R=&EN;P!";W)R87-C87,@=F5S<&5R=&EN87,`4$]0,P!0
M3U`S("A!=71O9&5T96-C:?-N(&1E('!R;W1O8V]L;W,I`%!/4#,@<V]B<F4@
M4U-,`%!/4#,@<V]B<F4@4U-,("AC97)T:69I8V%D;R!A=71O+69I<FUA9&\I
M`%!/4#,@<V]B<F4@4U-,("AA=71O+69I<FUA9&\I`%!/4#,L('-I;B!43%,`
M3F\@<V4@96YC=65N=')A(&QA(&5X=&5N<VGS;B!03U-)6`!);G3I<G!R+B!0
M7TA0`$UA<F=E;@!0X6=I;F$@)60@9&4@)60`4.%G:6YA(&1E;"!P<FEM97(@
M;65N<V%J92!S:6X@;&5E<@!0X6=I;F$@9&5L(/IL=&EM;R!M96YS86IE('-I
M;B!L965R`%!A:VES=.%N`%!A;&%U`%!A;&5S=&EN;W,L(%1E<G)I=&]R:6]S
M($]C=7!A9&]S`%!A;F%MX0!087#Z82!.=65V82!'=6EN96$`4&%R86=U87D`
M4&%R=&4H<RD`4&%R8VEA;&UE;G1E(&YU8F]S;P!&<F%S92!C;&%V90!&<F%S
M92!C;&%V92`H<F5P971I8VGS;BD`1G)A<V4@8VQA=F4@9&5S8V%R9V%D82!C
M;W)R96-T86UE;G1E+@!&<F%S92!C;&%V93H`3&%S(&9R87-E<R!C;&%V92!N
M;R!P=65D96X@9&5J87)S92!E;B!B;&%N8V\`3&%S(&9R87-E<R!C;&%V92!N
M;R!C;VEN8VED96X`0V]N=')A<V7Q80!,82!C;VYT<F%S9?%A('-E(&-A;6)I
M861O(&-O<G)E8W1A;65N=&4N`$-O;G1R87-E\6$@:6YC;W)R96-T80!(87D@
M<75E(&EN=')O9'5C:7(@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I
M9FEC86-I\VX@4D%$2553+@!#;VYT<F%S9?%A(&-O;B!C;VYF:7)M86-I\VX`
M0V]N=')A<V7Q83H`0V]N=')A<V7Q83H@`$QA<R!C;VYT<F%S9?%A<R!T:65N
M96X@<75E(&-O:6YC:61I<BX`4&5G87(`4&5G87(@9&5L('!O<G1A<&%P96QE
M<P!6[6$`06QT87,@<&5N9&EE;G1E<SH`1V5N=&4`4&]R8V5N=&%J90!296%L
M:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O`+]296%L:7IA<B!O
M<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O(&%L(&EN:6-I87(@<V5S:?-N
M/S\`4')I=FEL96=I;P!.;R!S92!H82!E;&EM:6YA9&\@96P@<')I=FEL96=I
M;R`B)7,B+@!0<FEV:6QE9VEO(&1E;F5G861O`%!R:79I;&5G:6]S`$%D;6EN
M:7-T<F%C:?-N(&1E('!R:79I;&5G:6]S`$YO('-E('!U961E;B!C86UB:6%R
M(&QO<R!P<FEV:6QE9VEO<R!D92!E<W1E('5S=6%R:6\N`%!E<G-O;F%L`$EN
M9F]R;6%C:?-N('!E<G-O;F%L`%-E(&AA;B!G96YE<F%D;R!C;W)R96-T86UE
M;G1E(&QA<R!C;&%V97,@<&5R<V]N86QE<R!01U`N`%-E(&AA;B!E;&EM:6YA
M9&\@8V]R<F5C=&%M96YT92!L87,@8VQA=F5S('!E<G-O;F%L97,@4$=0+@!.
M;R!S92!H86X@:6UP;W)T861O(&-E<G1I9FEC861O<R!P97)S;VYA;&5S(%,O
M34E-12X`4V4@:&%N(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E(&QA<R!C;&%V
M97,@<&5R<V]N86QE<R!3+TU)344N`%!E<OH`36%S8V]T87,`1FEL:7!I;F%S
M`%1E;.EF;VYO`$9O=&]G<F%F[6%S`%!I=&-A:7)N`%#M>&5L97,`OT'Q861I
M<B!S=2!F:7)M82!A;G1E<R!D92!L82!C;VYT97-T86-I\VX@;R!E;"!R965N
M=NUO/P!697)S:?-N(&5N('1E>'1O(&1E;"!M96YS86IE`%3S<&EC;W,`OU)E
M<')O9'5C:7(@<V]N:61O(&-O;B!L82!R96-E<&-I\VX@9&4@8V]R<F5O/R!(
M86-E(&9A;'1A('%U92!E;"!N879E9V%D;W(@<&5R;6ET82!A<F-H:79O<R!D
M92!S;VYI9&\@:6YC;'5I9&]S+B!,82!M87EO<NUA(&1E(&QO<R!D92!7:6YD
M;W=S('D@36%C(&QO('!E<FUI=&5N+"!P97)O(&]T<F%S('!L871A9F]R;6%S
M('!U961E;B!P<F5C:7-A<B!U;B!P;'5G:6XN`%!U;'-E(&5N('5N82!C96QD
M80!#;VYF:7)M92!Q=64@9&5S96$@96QI;6EN87(@97-T92!E;&5M96YT;SH`
M0V]N9FER;64@<75E(&1E<V5A(&5L:6UI;F%R(&5L(';M;F-U;&\@82!E<W1E
M(&5L96UE;G1O+@!);G1R;V1U>F-A('5N(&UE<R!Y('5N(&'Q;RX`26YT<F]D
M=7IC82!E;"!N;VUB<F4@9&4@;&$@;G5E=F$@8V%T96=O<NUA.@!);G1R;V1U
M>F-A(&5L(&YO;6)R92!D92!L82!N=65V82!C87)P971A.@!);G1R;V1U>F-A
M('5N82!D:7)E8V-I\VX@25`@=N%L:61A+@!);G1R;V1U>F-A('5N82!F96-H
M82!VX6QI9&$L(&-O;7!R=65B92!E;"!N^FUE<F\@9&4@9.UA<R!D96P@;65S
M+@!);G1R;V1U>F-A('5N82!H;W)A(';A;&ED82X`26YT<F]D=7IC82!E;"!N
M;VUB<F4@9&4@;&$@;G5E=F$@8V%R<&5T83H`26YT<F]D=7IC82!E;"!N=65V
M;R!N;VUB<F4Z`$EN=')O9'5Z8V$@;&$@9G)A<V4@8VQA=F4@<&%R82!L82!C
M;&%V92!01U`@<')I=F%D82X@4_-L;R!T96YD<N$@<75E(&EN=')O9'5C:7)L
M82!U;F$@=F5Z('!O<B!S97-I\VX@9&4@)7,N`$EN=')O9'5Z8V$@;&$@9G)A
M<V4@8VQA=F4@<&%R82!L82!C;&%V92!3+TU)344@<')I=F%D82X@4_-L;R!T
M96YD<N$@<75E(&EN=')O9'5C:7)L82!U;F$@=F5Z('!O<B!S97-I\VX@9&4@
M)7,N`%9U96QV82!A(&EN:6-I87(@;&$@<V5S:?-N('!A<F$@<F5A;G5D87(@
M;&$@<F5D86-C:?-N(&1E;"!M96YS86IE+B!3:2!.3R!U=&EL:7IA(&-O;VMI
M97,@62!E<W3A(')E9&%C=&%N9&\@;&]S(&UE;G-A:F5S(&5N('9E;G1A;F%S
M(&5M97)G96YT97,L('1E;F1RX2!Q=64@:6YI8VEA<B!S97-I\VX@=&%M8FGI
M;B!E;B!L82!V96YT86YA('!R:6YC:7!A;"X@17,@;F5C97-A<FEO('!A<F$@
M979I=&%R('%U92!U;B!A<V%L=&%N=&4@<W5P;&%N=&4@<W4@240@9&4@<V5S
M:?-N+B!$:7-C=6QP92!L87,@;6]L97-T:6%S+@!0<F]P;W)C:6]N92!U;B!R
M97-U;65N(&1E;"!P<F]B;&5M82X`26YT<F]D=7IC82!S=2!C;VYT<F%S9?%A
M+@!);G1R;V1U>F-A('-U(&YO;6)R92!D92!U<W5A<FEO('D@8V]N=')A<V7Q
M82X`26YT<F]D=7IC82!S=2!N;VUB<F4@9&4@=7-U87)I;RX`3&5A(&5L('1E
M>'1O('-I9W5I96YT92X@1$5"12!A8V5P=&%R(&QO<R!TZ7)M:6YO<R!S:2!Q
M=6EE<F4@=7-A<B!E;"!S:7-T96UA+@!297-U96QV82!D:7)E8V-I;VYE<R!E
M;&5C='+S;FEC87,@86UB:6=U87,@;R!I;G;A;&ED87,N`%-E;&5C8VEO;F4@
M=6YA(&-A<G!E=&$@86YT97,@9&4@<F5A;&EZ87(@97-T82!A8V-I\VXN`%-E
M;&5C8VEO;F4@86P@;65N;W,@=6YA(&-A<G!E=&$@<&%R82!L82!B^G-Q=65D
M82X`4V5L96-C:6]N92!U;F$@^FYI8V$@8V%R<&5T82!P87)A(&5S=&$@;W!E
M<F%C:?-N+@!396QE8V-I;VYE(&\@;6]D:69I<75E(&5N(&5L(')E8W5A9')O
M(&1E(&QA(&1E<F5C:&$Z`$EN=')O9'5Z8V$@96P@;G5E=F\@;F]M8G)E(&1E
M(&-A=&5G;W+M83H`4&]L;VYI80!0;VSM=&EC80!%;F-U97-T87,`4&]R='5G
M86P`4&]S:6-I\VX@9&4@;&$@:6UA9V5N`%!O<VEC:?-N(&1E(&QA('1A8FQA
M`$5N=FEA<B!A(&5S=&$@8V%R<&5T82`H;F\@;V)L:6=A9&\@<&]R($E-05`I
M`%!O=&5N8VEA9&\@<&]R($AO<F1E`+]%;F-A8F5Z87(@;&$@9FER;6$@8V]N
M(&=U:6]N97,@*"<M+2`G*3\`4')E8VEP:71A8VEO;F5S(&1E(&QA*',I(/IL
M=&EM82AS*2`E<R!H;W)A*',I.B``4')O8F%B:6QI9&%D/&)R("\^9&4@<')E
M8VEP:71A8VGS;@!392!H86X@86-T=6%L:7IA9&\@8V]R<F5C=&%M96YT92!L
M87,@<')E9F5R96YC:6%S+@!0<F5F<U]L9&%P.B!N;R!S92!E;F-O;G1R\R!L
M82!E>'1E;G-I\VX@3$1!4"!R97%U97)I9&$N`%!R969S7W-E<W-I;VXZ(&YO
M('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!D92!S97-I\VX@<F5Q=65R:61A
M+@!0<F5S:?-N`%!R97-I\VX@86P@;FEV96P@9&5L(&UA<CH@`%!R97-I\VXZ
M(`!6:7-T82!P<F5V:6$`5FES=&$@<')E=FEA(&1E(&QA(&EM86=E;B!E;B!U
M;F$@;G5E=F$@=F5N=&%N80!-96YS86IE(&%N=&5R:6]R`%#A9VEN82!A;G1E
M<FEO<@!/<&-I;VYE<R!A;G1E<FEO<F5S`$EM<')I;6ER`$EM<')I;6ER(&1O
M8W5M96YT;P!0<FEO<FED860`0VQA=F4@<')I=F%D80!#;VYT<F%S9?%A(&1E
M(&-L879E('!R:79A9&$`OU!R;V)L96UA<S\`1&5S8W)I<&-I\VX@9&5L('!R
M;V)L96UA`%!R;WEE8W1O<P!#;VYS=6QT87(@8V%D82!V97H@<75E('-E(&5N
M=NUE('5N(&%D:G5N=&\[($Y/('!O<B!O;6ES:?-N`$-O;G-U;'1A<B!C861A
M('9E>B!Q=64@<V4@96YV[64@=6X@861J=6YT;SL@4\T@<&]R(&]M:7-I\VX`
M5&5X=&\@9&5L(&EN9'5C=&]R`%!R;W1O8V]L;SH`0VQA=F4@4$=0('#Z8FQI
M8V$`06QG;W)I=&UO(&1E(&-L879E('#Z8FQI8V$`26YF;W)M86-I\VX@9&4@
M8VQA=F4@</IB;&EC80!392!H82!D97-A8W1I=F%D;R!E;"!S;W!O<G1E(&1E
M('-E<G9I9&]R97,@9&4@8VQA=F5S(%!'4"!P^F)L:6-O<RX`3F\@<V4@9V5N
M97)A<F]N(&-O<G)E8W1A;65N=&4@;&%S(&-L879E<R!0^F)L:6-A+U!R:79A
M9&$N`%!U97)T;R!2:6-O`%9A8VEA<B`H7W@I`%9A8VEA<@!686-I87(@8V%R
M<&5T82AS*0!#=>%N(&$@;65N=61O('9A8VEA<B!L82!P87!E;&5R83H`3&EM
M<&EA<B!M96YS86IE<P!%;&EM:6YA<B!D92!L82!P87!E;&5R82!L;W,@;65N
M<V%J97,@;>%S(&%N=&EG=6]S('%U92!E<W1E(&[Z;65R;R!D92!D[6%S+@"_
M16QI;6EN87(@9&4@;&$@<&%P96QE<F$@;&]S(&UE;G-A:F5S(&%N=&EG=6]S
M/P!%;&EM:6YA;F1O("5D(&UE;G-A:F5S(&1E(&QA('!A<&5L97)A+@!%;&EM
M:6YA;F1O(#$@;65N<V%J92!D92!L82!P87!E;&5R82X`46%T87(`0V]N<W5L
M=&$`475O=&$`17-T861O(&1E;"!E<W!A8VEO(&%S:6=N861O.B`E+C)F34(@
M+R`E+C)F34(@("@E+C)F)24I`$5S=&%D;R!D96P@97-P86-I;R!A<VEG;F%D
M;SH@)2XR9DU"("\@4TE.($S-34E410!%<W1A9&\@9&5L(&5S<&%C:6\@87-I
M9VYA9&\Z(%-)3B!,S4U)5$4`)68@:&$@97-C<FET;SH`0VQA=F4@4E-!('#Z
M8FQI8V$@*"5D(&)I="D`0F]T\VX@9&4@;W!C:?-N`$QL=79I80!,;'5V:6$@
M;6%T=71I;F$`3&QU=FEA('9E<W!E<G1I;F$`06=U86-E<F\`3&QU=FEA('D@
M3FEE=F4`3&QU=FEA(&$@3FEE=F4`4G5E9&$@9&4@;&$@9F]R='5N80!287KS
M;@`F;F)S<#M,965R)FYB<W`[`$QE97(@;65N<V%J97,`OT5L:6UI;F%R(')E
M86QM96YT92`E<S\@17-T82!O<&5R86-I\VX@;F\@<V4@<'5E9&4@9&5S:&%C
M97(N`+]%;&EM:6YA<B!R96%L;65N=&4@;&]S(&1A=&]S(&1E;"!U<W5A<FEO
M("5S/R!%<W1A(&]P97)A8VGS;B!N;R!S92!P=65D92!D97-H86-E<BX`4F5C
M;VYS=')U:7(@X7)B;VP@9&4@8V%R<&5T87,`4F5C:6)I9&]S(&5L`%)E8VEB
M:61O<R!D97-D90!296-I8FED;W,@:&%S=&$`4F5D:7)I9VER("A?<2D`4F5D
M:7)I9VER`%]2961I<FEG:7(@;65N<V%J90!2961I9VER(&5S=&4@;65N<V%J
M90!&86QL\R!E;"!R961I<F5C8VEO;F%M:65N=&\N`%9U96QV92!A(')E86QI
M>F%R(&QA(/IL=&EM82!A8V-I\VX`06-T=6%L:7IA<@!!8W1U86QI>F%R(&5L
M96UE;G1O<R!D92!M96[Z(&1I;N%M:6-O<SH`06-T=6%L:7IA<B!V:7-T87,@
M9&4@8V%R<&5T83H`06-T=6%L:7IA<B!V:7-T82!D96P@<&]R=&%L`%)E9V5X
M`$YA=F5G861O<B!D92!R96QA8VEO;F5S`$%C='5A;&EZ87(`06-T=6%L:7IA
M<B!V:7-T80!/8G-E<G9A8VEO;F5S`%)E8V]R9&%R(&QA(&EN9F]R;6%C:?-N
M(&1E('1I96UP;R!D:7-P;VYI8FQE+@!296-O<F1A<B!L82#Z;'1I;6$@=FES
M=&$`0G5Z\VX@<F5M;W1O.@!397)V:61O<F5S(')E;6]T;W,`55),(')E;6]T
M82`H:'1T<#HO+W=W=RYE:F5M<&QO+F-O;2]H;W)D92DZ`%%U:71A<@!1=6ET
M87(@8FQO<75E`%%U:71A<B!C86UP;W,@9&4@;&$@8OIS<75E9&$`475I=&%R
M(&-O;'5M;F$`16QI;6EN87(@9F]R;6%T;P!1=6ET87(@<&%R`$5L:6UI;F%R
M(&=U:?-N(&=U87)D861O(&1E;"!D:7)E8W1O<FEO('1E;7!O<F%L(&1E;"!S
M97)V:61O<BX`16QI;6EN87(@;W)I9V5N`$5L:6UI;F%R(`!%;&EM:6YA<B!E
M<W1E(&YO9&\@9&5L(&1O8W5M96YT;P!%;&EM:6YA<B!U<W5A<FEO`$5L:6UI
M;F%R('5S=6%R:6\Z("5S`%)E;F]M8G)A<B!C87)P971A*',I`+]296YO;6)R
M87(@;&$@8V%R<&5T82`B16YV:6%D;W,B(&%L(&EN:6-I;R!D96P@;65S/P!%
M<G)O<B!A;"!R96YO;6)R87(@(B5S(B!C;VUO("(E<R(N(,ES=&\@97,@;&\@
M<75E(&1I:F\@96P@<V5R=FED;W(`4F5S<&]N9&5R(&$@;&$@;&ES=&$`4W5S
M=&ET=6ER('!O<CH`4F5S<&]N9&5R`%)E<W!U97-T82!E;G9I861A+@!297-P
M;VYD97(@82!T;V1O<P!297-P;VYD97(@82!T;V1O<SH`4F5S<&]N9&5R(&$@
M;&$@;&ES=&$`4F5S<&]N9&5R(&$@;&$@;&ES=&$Z`%)E<W!O;F1E<B!A('1O
M9&]S("A?>BD`4F5S<&]N9&5R(&-O;B!U;B!M96YS86IE(&YO('-O<&]R=&%D
M;P!297-P;VYD97(@8V]N(&5L('1I96UP;R!D:7-P;VYI8FQE(&1U<F%N=&4@
M;&]S('!R\WAI;6]S(#(@;65S97,N`%)E<W!O;F1E<B!C;VX@;&$@:6YF;W)M
M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4@<&5D:61A+@!297-P;VYD97(M
M00!297-P;VYD97(M03H@`%)E<W!O;F1E<CH`3F]T:69I8V%R(&-O;6\@:6YO
M9F5N<VEV;P!.;W1I9FEC87(@8V]M;R!S<&%M`%-O;&EC:71A<B!U;B!A8W5S
M92!D92!?<F5C:6)O`$YO('-E('!U961E(')E<W!O;F1E<B!A(&QA('-O;&EC
M:71U9"X@0_-D:6=O(&1E(&5R<F]R(&1E=G5E;'1O.B``OU-O;&EC:71A<B!A
M8W5S97,@9&4@<F5C:6)O/P!.;R!S92!E;F-O;G1R\R!E;"!M96YS86IE('-O
M;&EC:71A9&\N`$YO('-E(&5N8V]N='+S(&5L('-E<G9I8VEO('-O;&EC:71A
M9&\N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!E;"`B)7,B(')E<75E<FED;R!E
M;B!L82!C;VYF:6=U<F%C:?-N(&1E("5S+@!.;R!S92!H82!E<W!E8VEF:6-A
M9&\@96P@(B5S(B!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A8VGS;B!D92!6
M1E,N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!E;"`B)7,B(')E<75E<FED;R!E
M;B!L82!C;VYF:6=U<F%C:?-N+@!#86UP;R!N96-E<V%R:6\`4&%R=&EC:7!A
M;G1E(')E<75E<FED;P!,:6UP:6%R`$QI;7!I87(@8V]N=')A<V7Q80!,:6UP
M:6%R(&-O;G1R87-E\6$`06-T=6%L:7IA9&\@96P@97-T861O(&1E(')E<W!U
M97-T82X`4F5S=&%U<F%R(/IL=&EM82!C;VYS=6QT80!297-U;'1A9&]S`%)E
M86YU9&%R`%)E86YU9&%R('-E<VGS;@!6;VQV97(@82`B4F5D86-C:?-N(&1E
M;"!M96YS86IE(@!296=R97-A<B!A(%1R865R(&-O<G)E;P!296=R97-A<B!A
M(&]P8VEO;F5S`+]296=R97-A<B!A;"!L:7-T861O(&1E;"!B=7KS;B!T<F%S
M(&5L:6UI;F%R+"!T<F%S;&%D87(@;R!C;W!I87(@=6X@;65N<V%J93\`4F5E
M<V-R:6)I<B!C;VYT<F%S9?%A(&YU979A`%)E=6YI\VX`4F5S=&%U<F%R(&-O
M;F9I9W5R86-I\VX`3W!C:6]N97,@9&4@961I8VGS;B!D92!T97AT;R!E;G)I
M<75E8VED;P!#<FEB87,`1&5R96-H80!#86)E8V5R82!D97)E8VAA`%9A;&]R
M97,@9&4@;&$@9&5R96-H80!0<F]P:65D861E<R!D92!?9FEL82XN+@!&=6YC
M:?-N`%)U;6%N[6$`1VER87(@,3@P`$=I<F%R(&$@;&$@:7IQ=6EE<F1A`$=I
M<F%R(&$@;&$@9&5R96-H80!0<F]P:65D861E<R!D92!F:6QA`%!R;W!I961A
M9&5S(&1E(&9I;&$`1FEL87,Z`%)A>6%S`$%P87)E8V5RX6X@<F%Y87,@96YT
M<F4@=&]D87,@;&%S(&9I;&%S('D@8V]L=6UN87,`07!A<F5C97+A;B!R87EA
M<R!S\VQO(&5N=')E(&QA<R!C;VQU;6YA<P!!<&%R96-E<N%N(')A>6%S('/S
M;&\@96YT<F4@;&%S(&9I;&%S`$5J96-U=&%R`$9E9&5R86-I\VX@4G5S80!2
M=6%N9&$`4R]-24U%`$9I<FUA(&-R:7!T;V=RX69I8V$@4R]-24U%`$UE;G-A
M:F4@8VEF<F%D;R!E;B!3+TU)344`365N<V%J92!C:69R861O(&5N(%,O34E-
M10!%<G)O<B!3+TU)344Z(`!%<G)O<B!3+TU)344Z($AA8V4@9F%L=&$@=6YA
M(&9R87-E(&-L879E('!A<F$@;&$@8VQA=F4@<&5R<V]N86P@<')I=F%D82X`
M3W!C:6]N97,@4R]-24U%`$5N=')A9&$@9&4@9G)A<V4@8VQA=F4@4R]-24U%
M`$AA8V4@9F%L=&$@=6YA(&-O;F5X:?-N('=E8B!S96=U<F$@<&%R82!U=&EL
M:7IA<B!E;"!S;W!O<G1E(&1E(&-L879E<R!P97)S;VYA;&5S(%,O34E-10!3
M92!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92!L82!C;&%V92!3+TU)344@
M</IB;&EC82!D92`B)7,B+@!392!H82!A\6%D:61O(&-O<G)E8W1A;65N=&4@
M;&$@8VQA=F4@</IB;&EC82!3+TU)344`3&QA=F5R;R!3+TU)344@</IB;&EC
M;P!392!H86X@8?%A9&ED;R!C;W)R96-T86UE;G1E(&QA<R!C;&%V97,@</IB
M;&EC82]P<FEV861A(%,O34E-10!-96YS86IE(&-O;B!F:7)M82!3+TU)344`
M365N<V%J92!F:7)M861O+V-I9G)A9&\@96X@4R]-24U%`$5N(&5S=&4@<VES
M=&5M82!S92!H82!D97-A8W1I=F%D;R!E;"!S;W!O<G1E(%,O34E-12X`16P@
M<V]P;W)T92!3+TU)344@;F\@97-TX2!A8W1I=F%D;R!A8W1U86QM96YT92!P
M;W(@;&\@<75E(&YO('-E('!U961E(&1E<V-I9G)A<B!E;"!M96YS86IE+@!%
M;"!S;W!O<G1E(%,O34E-12!N;R!E<W3A(&%C=&EV861O('!O<B!L;R!Q=64@
M;F\@<V4@<'5E9&4@;6]S=')A<B!E;"!C;VYT96YI9&]D92!E<W1E(&UE;G-A
M:F4@9FER;6%D;RX`16P@<V]P;W)T92!3+TU)344@;F\@97-TX2!A8W1I=F%D
M;R!A8W1U86QM96YT92!P;W(@;&\@<75E(&YO('-E('!U961E(&-O;7!R;V)A
M<B!L82!F:7)M82!D:6=I=&%L+@!%;"!S;W!O<G1E(%,O34E-12!N96-E<VET
M82!U=&EL:7IA<B!V96YT86YA<R!E;65R9V5N=&5S+B!3:2!L87,@:&$@9&5S
M86-T:79A9&\@96X@<W4@;F%V96=A9&]R+"!T96YD<N$@<75E(')E86-T:79A
M<FQA<R!O(&QA<R!C87)A8W1E<NUS=&EC87,@4R]-24U%(&YO(&9U;F-I;VYA
M<N%N(&-O<G)E8W1A;65N=&4N`$YO(&5S=.$@9&ES<&]N:6)L92!L82!A=71E
M;G1I9FEC86-I\VX@4T%33"X`365N<RX@4TU3`%--5%``26YTZ7)P<BX@4U%,
M`%-E;G1E;F-I82!344P@<&%R82!C;VYS=6QT87,@9&4@=F%L;W)E<P!34T@`
MR5A)5$\`26YTZ7)P<BX@4U]13`!!<U]U;G1O`%-A8@!'=6%R7V1A<B!U;F$@
M8V]P:6$@96X@`$=U87)D87(@8V]M;R`H7W<I`%-A;G1A($AE;&5N80!386EN
M="!+:71T<R!Y($YE=FES`%-A;G1A($QU8^UA`%-A:6YT(%!I97)R92!Y($UI
M<75E;&]N`%-A;B!6:6-E;G1E('D@1W)A;F%D:6YA<P!-:7-M;R!F<F%M92`H
M7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%N=&\@5&]MX7,@>2!0<NUN8VEP
M90!0<F]V965D;W(@9&4@<V%TZ6QI=&4`07)A8FEA(%-A=61I=&$`1W5A<F1A
M<@!'=6%R9&%R("(E<R(`1W5A<F1A<B`E<P"_1W5A<F1A<B!A9&IU;G1O<R!C
M;VX@;&]S(&UE;G-A:F5S(&5N(&QA(&-A<G!E=&$@9&4@8V]R<F5O(&5N=FEA
M9&\_`$=U87)D87(@8F]R<F%D;W(`1W5A<F1A<B!I;6%G96X`1W5A<F1A<B!I
M;6%G96X@96X@;&$@9V%L97+M80!'=6%R9&%R(&]P8VEO;F5S`$=U87)D87(@
M<&QA;G1I;&QA`%]'=6%R9&%R(&)O<G)A9&]R`$=U87)D87(@8V]M;P"_1W5A
M<F1A<B!B;W)R861O<F5S(&-O;6\@;F\@;&7M9&]S/P!'=6%R9&%R(&QA(&-O
M;F9I9W5R86-I\VX@9V5N97)A9&$@8V]M;R!U;B!G=6GS;B!02%`@96X@96P@
M9&ER96-T;W)I;R!T96UP;W)A;"!D92!S=2!S97)V:61O<BX`OT'Q861I<B!A
M=71O;>%T:6-A;65N=&4@;&]S(&1E<W1I;F%T87)I;W,@82!L82!,:6)R971A
M(&1E(&1I<F5C8VEO;F5S('!O<B!O;6ES:?-N/P"_1W5A<F1A<B!B^G-Q=65D
M82!C;VUO('5N82!C87)P971A('9I<G1U86P_`+]'=6%R9&%R(&-O<G)E;R!E
M;G9I861O/P!392!H82!G=6%R9&%D;R!L82!C;VYF:6=U<F%C:?-N(&1E("5S
M+@!'=6%R9&%R(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG
M=7)A8VGS;B!E;CH@(B5S(BX`1F%L;&\@86P@9W5A<F1A<B!E;"!B;W)R861O
M<BX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<CH@)7,`0F]R<F%S
M8V%S(&%I<VQA9&%S`$-I96YC:6$`0G5S8V%R`$)U<V-A<B!E;B`E<P!-+B!B
M^G-Q=65D80!/<&-I;VYE<R!D92!B^G-Q=65D80!297-U;'1A9&]S(&1E(&QA
M(&+Z<W%U961A`$QE[61O`%-E;&5C8VEO;F%R`%-E;&5C8VEO;F4@;W1R82!C
M=65N=&$`4V5L96-C:6]N87(@87)C:&EV;W,`4V5L96-C:6]N92!U;F$@9F5C
M:&$`4V5L96-C:6]N92!U;B!C86UP;P!396QE8V-I;VYE(&5L(&=R=7!O(&$@
M8?%A9&ER`%-E;&5C8VEO;F4@=6X@;G5E=F\@<')O<&EE=&%R:6\`4V5L96-C
M:6]N92!U;B!S97)V:61O<@!396QE8V-I;VYA<B!U;F$@<&QA;G1I;&QA.@!3
M96QE8V-I;VYE(&5L('5S=6%R:6\@82!A\6%D:7(`4V5L96-C:6]N82!L82!L
M:6)R971A(&1E(&1I<F5C8VEO;F5S(&]R:6=E;B!P87)A(&%D:6-I\VX@>2!B
M^G-Q=65D82!D92!D:7)E8V-I;VYE<RX`4V5L96-C:6]N87(@=&]D87,`4V5L
M96-C:6]N92!T;V1O<R!L;W,@8V]M<&]N96YT97,@9&4@;&$@9F5C:&$N`$5L
M:6IA(&QO<R!C86UP;W,@96X@;&]S('%U92!B=7-C87(@86P@97AP86YD:7(@
M9&ER96-C:6]N97,N`%-E;&5C8VEO;F4@=6YA(&-U96YT80!396QE8V-I;VYA
M<B!U;B!O8FIE=&\`06YU;&%R('-E;&5C8VGS;@!396QE8V-I;VYE(&QO<R!C
M87+A8W1E<F5S('%U92!N96-E<VET92!D92!L87,@8V%S:6QL87,@9&4@86)A
M:F\N(%!U961E(&-O<&EA<FQO<R!Y('!E9V%R;&]S(&1E;"#A<F5A(&1E('1E
M>'1O+@!396QE8V-I;VYE(&5L(&1E;&EM:71A9&]R(&1E(&9E8VAA<SH`4V5L
M96-C:6]N92!E;"!F;W)M871O(&1E(&9E8VAA<SH`4V5L96-C:6]N92!L82!G
M86QE<NUA(&5N(&QA('%U92!G=6%R9&%R(&QA(&EM86=E;BX`4V5L96-C:6]N
M92!L82!I9&5N=&ED860@<75E('%U:65R82!C86UB:6%R.@!396QE8V-I;VYE
M(&5L('1I<&\@9&4@<V5R=FED;W(@9&4@8V]R<F5O`%-E;&5C8VEO;F4@96P@
M9&5L:6UI=&%D;W(@9&4@:&]R87,Z`%-E;&5C8VEO;F4@96P@9F]R;6%T;R!D
M92!H;W)A<SH`4V5L96-C:6]N92!D;W,@8V%M<&]S(&-O:6YC:61E;G1E<RX`
M4V5L96-C:6]N92!S=2!C;VUB:6YA8VGS;B!D92!C;VQO<F5S+@!396QE8V-I
M;VYE('-U(&ED:6]M82!P<F5F97)I9&\Z`$QI8G)E=&%S(&1E(&1I<F5C8VEO
M;F5S('-E;&5C8VEO;F%D87,Z`$5N=FEA<B!C;&%V92!A;"!S97)V:61O<B!D
M92!C;&%V97,@</IB;&EC;P!%;G9I87(@:6YF;W)M86-I\VX@86-T=6%L:7IA
M9&$`16YV:6%R(&UE;G-A:F4`16YV:6%R(&EN9F]R;64@9&4@<')O8FQE;6%S
M`$5N=FEA<B!335,`OT5N=FEA<B!E;"!M96YS86IE(%-)3B!!<W5N=&\_`+]%
M;G9I87(@8V]N9FER;6%C:?-N(&1E(&QE8W1U<F$@<VD@;&\@<V]L:6-I=&$@
M96P@<F5M:71E;G1E/P!396YE9V%L`%-E;G-O<CH@`$-A<G!E=&$@9&4@8V]R
M<F5O<R!E;G9I861O<P!#87)P971A(&1E(&-O<G)E;W,@96YV:6%D;W,Z`%-E
M<'1I96UB<F4`4V5R8FEA('D@36]N=&5N96=R;P!.^FUE<F\@9&4@<V5R:64`
M4V5R=FED;W(`26YF;W)M86-I\VX@9&4@<V5R=FED;W(@>2!D92!C87)P971A
M`$1A=&]S(&1E;"!S97)V:61O<B!E<G+S;F5O<R!O(&YO(&1I<W!O;FEB;&5S
M+@!397)V:61O<CH`061M:6YI<W1R86-I\VX@9&4@<V5S:?-N`$AA(&-A9'5C
M861O(&5L($E$(&1E('-E<VGS;BX`4V5S:6]N97,`17-T86)L96-E<@!%<W1A
M8FQE8V4@;W!C:6]N97,@<75E(&QE('!E<FUI=&5N(')E86IU<W1A<B!S=2!C
M;VYT<F%S9?%A('-I(&QL96=A<F$@82!O;'9I9&%R;&$N`$5S=&%B;&5C92!P
M<F5F97)E;F-I87,@9&4@;&\@<75E(&]C=7)R:7+A(&%L('1R87-L861A<B!O
M(&5L:6UI;F%R(&UE;G-A:F5S+@"_17-T86)L96-E<B!L82!C86)E8V5R82!8
M+5!R:6]R:71Y(&%L(')E9&%C=&%R(&UE;G-A:F5S/P!#;VYF:6=U<F$@<V5R
M=FED;W)E<R!R96UO=&]S(&$@;&]S('%U92!D97-E92!A8V-E9&5R(&1E<V1E
M(&5L('!O<G1A;"X`1&5F:6YE(&QA<R!O<&-I;VYE<R!P<F5F97)I9&%S(&1E
M(&ED:6]M82P@>F]N82!H;W)A<FEA('D@9F5C:&%S+@!$969I;F4@;&$@87!L
M:6-A8VGS;B!D92!I;FEC:6\L(&QA(&-O;6)I;F%C:?-N(&1E(&-O;&]R97,L
M(&QA(&%C='5A;&EZ86-I\VX@9&4@<.%G:6YA('D@;W1R87,@;W!C:6]N97,@
M9&4@=FES=6%L:7IA8VGS;BX`0V]N9FEG=7)A8VGS;@!(87D@9W5I;VYE<R!D
M92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX`5F%R:6%S('5B
M:6-A8VEO;F5S(&1I<W!O;FEB;&5S(&-O;B!E;"!P87+A;65T<F\Z(`!397EC
M:&5L;&5S`$-O;7!A<G1I<B!C87)P971A<P!#;VUP87)T:7(@8V%R<&5T87,@
M9&4@8V]R<F5O`$-O;7!A<G1I<B!S=7,@8V%R<&5T87,@9&4@8V]R<F5O(&-O
M;B!O=')O<R!U<W5A<FEO<RX`0V]M<')A<P!297-U;65N(&-O<G1O`+]$969I
M;FER(&-L879E<R!D92!A8V-E<V\@<&%R82!L82!M87EO<NUA(&1E(&QO<R!V
M[6YC=6QO<S\`OTUO<W1R87(@=2!O8W5L=&%R('!O<B!O;6ES:?-N(&QO<R!B
M;&]Q=65S(&=R86YD97,@9&4@=&5X=&\@8VET861O/R!392!P=65D92!C;VYM
M=71A<B!C;VX@9F%C:6QI9&%D(&5L:6IA(&QO('%U92!E;&EJ82X`OT)U<V-A
M<B!D871O<R!01U`@96X@96P@8W5E<G!O(&1E(&QO<R!M96YS86IE<R!D92!T
M97AT;R]P;&%N;S\`OT-E<G)A<B!L82!V96YT86YA(&1E(')E9&%C8VGS;B!T
M<F%S(&=U87)D87(@=6X@8F]R<F%D;W(_`+]!9&IU;G1A<B!P;W(@;VUI<VGS
M;B!L82!C;&%V92!01U`@</IB;&EC82!A(&QO<R!M96YS86IE<S\`)FYB<W`[
M36]S=')A<B9N8G-P.P!-;W-T<F%R('1O9&%S(&QA<R!C87)P971A<P!-;W-T
M<F%R('1O9&%S(&QA<R!C86)E8V5R87,`36]S=')A<B!E;&EM:6YA9&]S`$UO
M<W1R87(@8V%B96-E<F%S(')E9'5C:61A<P!-;W-T<F%R(&EN9F]R;6%C:?-N
M(&1E(&QI<W1A<R!D92!C;W)R96\`36]S=')A<B!S\VQO(&-A<G!E=&%S('-U
M<V-R:71A<P!-;W-T<F%R(&YO('-U<V-R:71O<P"_36]S=')A<B!U;B!I8V]N
M;R!P87)A('!E<FUI=&ER(&QA(&5L:6UI;F%C:?-N(&1E(&QO<R!A9&IU;G1O
M<R!D92!L;W,@;65N<V%J97,_`$UU97-T<F$@;&%S(&1I9F5R96YC:6%S(&5N
M=')E(&QA(&YU979A(&-O;F9I9W5R86-I\VX@>2!L82!A;&UA8V5N861A`+]-
M;W-T<F%R(&AO<F$@9&4@;&$@^FQT:6UA('-E<VGS;B!A;"!I;FEC:6%R/P"_
M36]S=')A<B!C;VUE;G1A<FEO<R!E;B!L82!V:7-T82!D96P@8G5Z\VX_`$UO
M<W1R87(@;W!C:?-N(&1E(&-O;G-E<G9A<B!E;"!O<FEG:6YA;`!-;W-T<F%R
M('-E;&5C=&]R`+]-;W-T<F%R('9I<W1A('!R979I82!S\VQO(&1E(&QO<R!M
M96YS86IE<R!S:6X@;&5E<C\`OTUO<W1R87(@=FES=&$@<')E=FEA(&5N(&QO
M<R!C;VYS96IO<S\`OTUO<W1R87(@;&$@8F%R<F$@9&4@;65N^B!D92!O<&5R
M86-I;VYE<R!D92!T86)L83\`OTUO<W1R87(@96P@;65N^B`E<R!A(&QA(&EZ
M<75I97)D83\`OTUO<W1R87(@96P@:6-O;F\@5')A97(@8V]R<F5O(&5N(&QA
M(&)A<G)A(&1E(&UE;OH_`$UO<W1R87(@:6WA9V5N97,`375E<W1R82!E;"!D
M:>%L;V=O(&1E('!R;W!I961A9&5S(&1E(&-E;&1A(&1E('1A8FQA`$UU97-T
M<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!T86)L80!-=65S=')A
M(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@9FEL82!D92!T86)L80"_
M36]S=')A<B!E;"!I8V]N;R!D92!F:6QT<F%D;R!E;B!L82!B87)R82!D92!M
M96[Z/P!-=65S=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@:6UA
M9V5N`+]-;W-T<F%R(&5L(&[Z;65R;R!T;W1A;"!D92!M96YS86IE<R!P;W(@
M8V%R<&5T83\`36]S=')A<B!C87)G80!!9W5A8V5R;W,`3&QU=FEA<R!M871U
M=&EN87,`3&QU=FEA<R!V97-P97)T:6YA<P!!9W5A8V5R;W,@96X@;&$@=F5C
M:6YD860`36]S=')A9&\`4F5D=6-I<@!0<FEM97)O(')E9'5Z8V$@;R!Q=6ET
M92!D92!E;FUE9&EO(&QO<R!B;&]Q=65S(&-E<F-A;F]S`%1A7VUA\6\`4VEE
M<G)A($QE;VYA`$%L=&$`1FER;6$`06QG;W)I=&UO(&1E(&9I<FUA`$9I<FUA
M9&\`4VEN9V%P=7(`5&%M8?%O`$]M:71I<B!M86YT96YI;6EE;G1O`$5S;&]V
M87%U:6$`17-L;W9E;FEA`$YI979E`$%G=6%C97)O(&1E(&YI979E`$%G=6%C
M97)O(&1E(&YI979E`$%G=6%C97)O(&1E(&YI979E(&UA='5T:6YO`$%G=6%C
M97)O(&1E(&YI979E('9E<W!E<G1I;F\`17-P97-O<B!D92!L82!N:65V93H@
M`$5Q=6EV86QE;G1E(&1E(&QA(&YI979E(&5N(&%G=6$Z(`!)<VQA<R!386QO
M;?-N`%-O;6%L:6$`0V%N8VEO;F5S("8@4&]E;6%S`$]R9&5N87(@<&]R(&QL
M96=A9&$`3W)D96YA<B!P;W(@9F5C:&$`3W)D96YA<B!P;W(@<F5M:71E;G1E
M`$]R9&5N87(@<&]R('1A;6'Q;R!D96P@;65N<V%J90!/<F1E;F%R('!O<B!A
M<W5N=&\`3W)D96YA<B!P;W(@<V5C=65N8VEA`$]R9&5N87(@<&]R(&1E<W1I
M;F%T87)I;P!396QE8V-I\VX@9&5L('-E;G1I9&\@9&4@;&$@8VQA<VEF:6-A
M8VGS;@!296UI=&5N=&4`4W5DX69R:6-A`$5U<F]P82!D96P@<W5R("A)4T\M
M.#@U.2TS*0!'96]R9VEA(&1E;"!3=7(@92!)<VQA<R!386YD=VEC:"!D96P@
M4W5R`$AE;6ES9F5R:6\@<W5R`$5S<&%C:6%D;R!E;G1R92!C96QD87,@861Y
M86-E;G1E<P!%<W!A8VEA9&\@96YT<F4@96P@8V]N=&5N:61O('D@96P@8F]R
M9&4@9&4@=6YA(&-E;&1A`%-E<&%R861O<@!%<W!A8VEA9&\`17-P86-I861O
M('D@;6%R9V5N`$5S<&'Q80!3<&%M`$-A<G!E=&$@9&4@<W!A;3H`17-C<FET
M=7)A(&1E(&-A<F%C=&5R97,@97-P96-I86QE<P!#87)A8W1E<F5S(&5S<&5C
M:6%L97,`3&%S(&-A<G!E=&%S('9I<G1U86QE<R!E<W!E8VEA;&5S(&YO('-E
M('!U961E;B!M;V1I9FEC87(N`$-O<G)E8V-I\VX@;W)T;V=RX69I8V$`0V]R
M<F5C=&]R(&]R=&]G<N%F:6-O`$-O<G)E8V-I\VX@;W)T;V=RX69I8V$@8V]M
M<&QE=&$`3OIM97)O(&1E(&5R<F]R97,@;W)T;V=RX69I8V]S('!O<B!P86YT
M86QL82!D=7)A;G1E(&QA(&-O<G)E8V-I\VX@;W)T;V=RX69I8V$N`$1I=FED
M:7(@8V5L9&$`1&EV:61I<B!C;VQU;6YA`$1I=FED:7(@9FEL80!$97!O<G1E
M<P!3<FD@3&%N:V$`17-TX6YD87(`4W1A<B!4<F5K`$5M<&EE>F$`0?%O(&1E
M(&EN:6-I;P!%<W1A9&\@;R!P<F]V:6YC:6$`4&QA;G1I;&QA`$YO;6)R92!D
M92!L82!P;&%N=&EL;&$Z`%1I<&\@9&4@<&QA;G1I;&QA.@!0;&%N=&EL;&$Z
M`$5S=&%D;P!&;W)M871O(&1E(&%L;6%C96YA;6EE;G1O`$1I<F5C8VGS;B!D
M92!L82!C86QL90!486-H861A`$QI<W1A(&1E(&-A9&5N87,`16QI;6EN87(@
M861J=6YT;P!%;&EM:6YA<B!D;VUI;FEO(&1E(&QA(&1I<F5C8VGS;@"_17AT
M<F%E<B!S86QT;W,@9&4@;.UN96$_`$5S=&EL;R!;0U-370!$;VT`07-?=6YT
M;P!.;R!S92!E;F-O;G1R\R!E;"!S=6)D:7)E8W1O<FEO("(E<R(N`$%S=6YT
M;P!0;W(@87-U;G1O`$5N=FEA<@!392!H82!E;G9I861O('5N82!S;VQI8VET
M=60@9&4@86QT82!D92`B)7,B(&5N(&5L('-I<W1E;6$N($YO('!O9'+A(&EN
M:6-I87(@<V5S:?-N(&AA<W1A('%U92!S92!H87EA(&%P<F]B861O(&QA('-O
M;&EC:71U9"X`4W5S8W)I8FER<V4@82!L82AS*2!C87)P971A*',I`%-U8NUN
M9&EC90#)>&ET;P!392!H82!A\6%D:61O(&-O<G)E8W1A;65N=&4@(B5S(B!A
M;"!S:7-T96UA+@!392!H86X@96QI;6EN861O(&-O<G)E8W1A;65N=&4@;&]S
M(&1A=&]S(&1E;"!U<W5A<FEO("(E<R(@9&5L('-I<W1E;6$N`%-E(&AA(&5L
M:6UI;F%D;R!C;W)R96-T86UE;G1E("(E<R(N`%-E(&AA(&5L:6UI;F%D;R!C
M;W)R96-T86UE;G1E("(E<R(@9&5L('-I<W1E;6$N`%-E(&AA(')E<W1A=7)A
M9&\@8V]R<F5C=&%M96YT92!L82!C;VYF:6=U<F%C:?-N+B!2969R97-Q=64@
M<&%R82!V97(@;&]S(&-A;6)I;W,N`%-E(&AA(&=U87)D861O(&-O<G)E8W1A
M;65N=&$@;&$@8V]P:6$@9&4@;&$@8V]N9FEG=7)A8VGS;BX`4V4@:&$@9W5A
M<F1A9&\@8V]R<F5C=&%M96YT92!L82!C;W!I82`E<R!D92!L82!C;VYF:6=U
M<F%C:?-N+@!392!H82!A8W1U86QI>F%D;R!C;W)R96-T86UE;G1E("(E<R(`
M4V4@:&$@97-C<FET;R!C;W)R96-T86UE;G1E("<E<R<`4W5DX6X`4W5G97)E
M;F-I87,`4F5S=6UE;@!!;6%N96-E<@!!=&%R9&5C97(`4V]L96%D;P!!;6%N
M96-E<@!!;6%N96-E<B]!=&%R9&5C97(`06UA;F5C97(Z(`!!=&%R9&5C97(`
M071A<F1E8V5R.B``4W5P97+M;F1I8V4`4V]P;W)T90!3=7)I;F%M`$%P96QL
M:61O`%-V86QB87)D('D@2F%N($UA>65N`%-W87II;&%N9&EA`%-U96-I80!#
M;VYM=71A<B!MZ71O9&\@9&4@<F5D86-C:?-N`$-O;FUU=&%R(&$@<F5D86-C
M:?-N($A434P`0V]N;75T87(@82!R961A8V-I\VX@9&4@=&5X=&\`4W5I>F$`
M4F5G:7-T<F\@9&4@<VEN8W)O;FEZ86-I\VX@96QI;6EN861O`%-Y;F--3`!%
M<G)O<B!D92!S:6YT87AI<R!E;B!L;W,@=.ER;6EN;W,@9&4@8OIS<75E9&$`
M4F5P^F)L:6-A(,%R86)E(&1E(%-I<FEA`$-H=6)A<V-O`$)O<G)A<V-O<V\@
M>2!V96YT;W-O`$)O<G)A<V-A<P!";W)R87-C87,@;6%T=71I;F%S`$%R8VAI
M=F\@5%-6`%1A8FQA`%!R;W!I961A9&5S(&1E('1A8FQA`%1A8FQA`%!R;W!I
M961A9&5S(&1E('1A8FQA`%1A:7?A;@!486EWX6XL(%!R;W9I;F-I82!D92!#
M:&EN80!487EI:VES=.%N`%1A;GIA;FEA+"!297#Z8FQI8V$@56YI9&$@9&4`
M1&5S=&EN;SH`5&%R96%S`%]497AT;P!.^FUE<F\@9&4@=&5LZ69O;F\`5&5M
M<&5R871U<F$@9'5R86YT92!L82#Z;'1I;6$@:&]R83H@`%1E;7!E<F%T=7)A
M`%1E;7!E<F%T=7)A.B``5&5M<&5R871U<F$\8G(@+SXH)7--X7@E<R\E<TWM
M;B5S*2`F9&5G.R5S`$YO('-E(&5N8V]N='+S(&QA('!L86YT:6QL82`B)7,B
M+@!!9&UI;FES=')A8VGS;B!D92!P;&%N=&EL;&%S`%!R;W9I<VEO;F%L.B``
M06-E<'1A<B!P971I8VGS;B!P<F]V:7-I;VYA;&UE;G1E`$%C97!T861A('!R
M;W9I<VEO;F%L;65N=&4`3F\@<V4@:&%N(&EN9&EC861O(&QO<R!TZ7)M:6YO
M<R!D96P@87)C:&EV;R!D92!S97)V:6-I;R!E;B!C;VYF+G!H<`!497AT;P!3
M\VQO('1E>'1O`$%L:6YE86-I\VX@9&4@=&5X=&\`0F]R9&4@<W5P97)I;W(@
M9&5L('1E>'1O`$IU90!486EL86YDZ7,@*%1)4RTV,C`I`%1A:6QA;F1I80!.
M;R!E<W3A(&1I<W!O;FEB;&4@;&$@97AT96YS:?-N($944"X`0_-M;R!V:6YC
M=6QA<B!L82!C;VQU;6YA($1E.B!D96P@;65N<V%J93H`16P@<VES=&5M82!H
M:7-T\W)I8V\@97-TX2!D97-H86)I;&ET861O+@!%;"!M;W1O<B!D92!I;G1E
M9W)A8VGS;B!(;W)D92]+;VQA8B!N;R!S;W!O<G1A("(E<R(`3F\@<&%R96-E
M('%U92!E;"!S97)V:61O<B!)34%0('-O<&]R=&4@96P@<VES=&5M82!D92!A
M=71E;G1I9FEC86-I\VX@<V5L96-C:6]N861O+B!0\VYG87-E(&5N(&-O;G1A
M8W1O(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA+@!.;R!S92!P
M=65D92!I;FEC:6%R(&5L(')E9VES=')O(&1E($E-4U`N`$9O<FL@9&4@<F5C
M=7)S;W,@9&4@36%C:6YT;W-H`%-E('!U961E(&1E<V-A<F=A<B`E<R!E;"!F
M;W)K(&1E(')E8W5R<V]S(&1E($UA8VEN=&]S:"X`3F\@<V4@:&$@8V%R9V%D
M;R!C;W)R96-T86UE;G1E(&QA(&-L87-E($UA:6YT96YA;F-E.CH`4V4@:&$@
M8V5R<F%D;R!L82!V96YT86YA(&1E(&]P8VEO;F5S+B!386QI96YD;RX`4V4@
M:&$@96QI;6EN861O(&QA(&-U96YT82`B)7,B+@!392!H82!G=6%R9&%D;R!L
M82!C=65N=&$@(B5S(BX`4VD@9&5S96$@=71I;&EZ87(@<&5R;6ES;W,L(&5L
M(&%D;6EN:7-T<F%D;W(@=&EE;F4@<75E(&-O;F9I9W5R87(@=6X@<V]P;W)T
M92!D92!P97)M:7-O<R!P97)M86YE;G1E+@!.;R!S92!E;F-O;G1R\R!E;"!A
M9&IU;G1O+@!3\VQO(&5L(&)O<F1E(&EN9F5R:6]R`$QO<R!D871O<R!D92!L
M82!A9V5N9&$@;F\@<V]N(';A;&ED;W,`16P@240@9&5L(&-O;G1A8W1O(&YO
M('-E(&5S<&5C:69I8_,L('-E(&1E:O,@96X@8FQA;F-O(&\@;F\@<V4@96YC
M;VYT<O,@96X@;&$@8F%S92!D92!D871O<RX`4V4@:&$@8?%A9&ED;R!C;W)R
M96-T86UE;G1E(&5L(&-O;G1A8W1O(&$@<W5S(&1I<F5C8VEO;F5S+@!!(&-O
M;G1I;G5A8VGS;B!E<W3A(&5L(&-O;G1E;FED;R!D96P@87)C:&EV;R!-86-I
M;G1O<V@N`$QA*',I(&-A<G!E=&$H<RD@(B5S(B!S92!R96YO;6)R87+A*&XI
M(&-O;6\@(B5S(BX`3F\@<V4@<'5E9&4@;V)T96YE<B!L82!L:7-T82!D92!U
M<W5A<FEO<R!A8W1U86P@<75E('1I96YE;B!A8V-E<V\@82!E<W1A(&-A<G!E
M=&$`4&%R82!C;VUP<F]B87(@96P@;65N<V%J92!F:7)M861O(&AA8V4@9F%L
M=&$@96P@8FQO<75E(&1E(&9I<FUA('-E<&%R861O+@!%;"!)1"!D92!L82!L
M:7-T82!D92!D:7-T<FEB=6-I\VX@;F\@<V4@97-P96-I9FEC\RP@<V4@9&5J
M\R!E;B!B;&%N8V\@;R!N;R!S92!E;F-O;G1R\R!E;B!L82!B87-E(&1E(&1A
M=&]S+@!.;R!S92!E<W!E8VEF:6/S(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS
M;BX`4V4@:&$@9W5A<F1A9&\@96P@8F]R<F%D;W(@96X@;&$@8V%R<&5T82`B
M)7,B+@!,87,@8V%R86-T97+M<W1I8V%S(&1E(&-I9G)A9&\@;F5C97-I=&%N
M('5N82!C;VYE>&GS;B!W96(@<V5G=7)A+@!392!H82!A\6%D:61O(&5L(&%C
M;VYT96-I;6EE;G1O(&$@;&$@86=E;F1A+@!.;R!S92!P=65D92!E>'!A;F1I
M<B!E;"!C86UP;R`B)7,B+@!%;"!A<F-H:79O("5S('1E;F1R[6$@<75E(&-O
M;G1E;F5R('5N82!O<&-I\VX@)7,N`$5L(&%R8VAI=F\@)7,@=&5N9'+M82!Q
M=64@8V]N=&5N97(@86QG=6YA<R!O<&-I;VYE<R`E<RX`3F\@<V4@<'5E9&4@
M8V]P:6%R(&5L(&%R8VAI=F\@<V]B<F4@<^T@;6ES;6\N`$5L(&%R8VAI=F\@
M;F\@8V]N=&EE;F4@9&%T;W,N`%EA(&5X:7-T92!L82!C87)P971A("(E<R(`
M3&$@8V%R<&5T82`B)7,B('1I96YE(&-A<F%C=&5R97,@:6QE9V%L97,@96X@
M96P@;F]M8G)E+B#)<W1O('!U961E(&]R:6=I;F%R('!R;V)L96UA<RX@0V]N
M<W5L=&4@86P@861M:6YI<W1R861O<B!D92!S:7-T96UA<RX`4V4@:&$@8W)E
M861O(&QA(&-A<G!E=&$@(B5S(B!P97)O(&YO('-E(&AA('-U<V-R:71O(&$@
M96QL82X`4V4@:&$@96QI;6EN861O(&QA(&-A<G!E=&$@(B5S(B!P97)O(&YO
M('-E(&AA(&1E<W5S8W)I=&\@9&4@96QL82X`3F\@<V4@:&$@8W)E861O(&QA
M(&-A<G!E=&$@(B5S(BX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O
M<@!.;R!S92!H82!E;&EM:6YA9&\@;&$@8V%R<&5T82`B)7,B+B#)<W1O(&5S
M(&QO('%U92!D:6IO(&5L('-E<G9I9&]R`%-E(&AA(&-R96%D;R!C;W)R96-T
M86UE;G1E(&QA(&-A<G!E=&$@(B5S(BX`4V4@:&$@96QI;6EN861O(&-O<G)E
M8W1A;65N=&4@;&$@8V%R<&5T82`B)7,B+@!392!H82!R96YO;6)R861O(&-O
M<G)E8W1A;65N=&4@;&$@8V%R<&5T82`B)7,B(&-O;6\@(B5S(BX`02!C;VYT
M:6YU86-I\VX@=&EE;F4@;&%S(&-A8F5C97)A<R!D92!E<W1E(&UE;G-A:F4@
M;65S<V%G92]R9F,X,C(N`%-E(&AA8NUA;B!A\6%D:61O(&QO<R!A<F-H:79O
M<R!S:6=U:65N=&5S(&$@97-T82!P87)T93H`4V4@<V%B92!Q=64@96P@;6]D
M;R!D92!P86YT86QL82!C;VUP;&5T82!D82!P<F]B;&5M87,@8V]N($EN=&5R
M;F5T($5X<&QO<F5R(&1E8FED;R!A(&9A;&QO<R!D96P@;F%V96=A9&]R('%U
M92!N;R!H96UO<R!P;V1I9&\@<V]S;&%Y87(N(%!U961E('-U9G)I<B!V:7-U
M86QI>F%C:?-N(&1E(&)A<W5R82P@<.ER9&ED82!D92!F=6YC:6]N97,@9&5L
M(&5D:71O<B!Y+V\@8W5E;&=U97,@86QE871O<FEO<R!D96P@;F%V96=A9&]R
M+B!3:2!S=2!S:7-T96UA(&]P97)A=&EV;R!E<R!7:6YD;W=S(#EX+"!E<R!M
M=7D@<')O8F%B;&4@<75E('-U9G)A('5N(&9A;&QO(&1E('!R;W1E8V-I\VX@
M9V5N97)A;"!Y('1E;F=A('%U92!R96EN:6-I87(@96P@97%U:7!O+EQN7&Y9
M82!E<W3A(&%V:7-A9&\N(%!U;'-E($%C97!T87(@<VD@8?IN(&1E<V5A('!R
M;V)A<B!E;"!E9&ET;W(@96X@;6]D;R!D92!P86YT86QL82!C;VUP;&5T82X`
M4V4@:&$@96QI;6EN861O(&QA(&ED96YT:61A9"`B)7,B+@!.;R!S92!P=65D
M92!A8G)I<B!L82!V96YT86YA(&1E(&=U87)D861O(&1E(&EMX6=E;F5S+B"_
M2&$@8V]N9FEG=7)A9&\@<W4@;F%V96=A9&]R('!A<F$@<75E(&)L;W%U964@
M;&%S('9E;G1A;F%S(&5M97)G96YT97,_`%-E(&UO<W1R87+A;B!L87,@:6WA
M9V5N97,@>6$@<75E(&5L(')E;6ET96YT92!E<W3A(&5N('-U($QI8G)E=&$@
M9&4@9&ER96-C:6]N97,N`%/S;&\@96P@8F]R9&4@:7IQ=6EE<F1O`$AA>2!Q
M=64@:6YD:6-A<FQE(&$@;&$@8VQA<V4@0W)Y<'1?<&=P.CH@;&$@=6)I8V%C
M:?-N(&1E(&QO<R!B:6YA<FEO<R!';G501RX`16P@<V5R=FED;W(@9&4@8V]R
M<F5O(&AA(&=E;F5R861O(&5L('-I9W5I96YT92!M96YS86IE(&1E(&5R<F]R
M.@!%;"!S97)V:61O<B!D92!C;W)R96\@:&$@9V5N97)A9&\@96P@<VEG=6EE
M;G1E(&UE;G-A:F4@9&4@:6YF;W)M86-I\VXZ`$5L('-E<G9I9&]R(&1E(&-O
M<G)E;R!H82!G96YE<F%D;R!E;"!S:6=U:65N=&4@;65N<V%J93H`16P@8G5Z
M\VX@)7,@>6$@97-TX2!V86/M;RX`16P@;65N<V%J92`B)7,B(&1E("(E<R(@
M*"5D(&)Y=&5S*2!S=7!E<F$@96P@=&%M8?%O(&SM;6ET92!D92!O8G1E;F-I
M\VXN`%-E(&AA(&-E<G)A9&\@96P@;65N<V%J92!Q=64@97-T86)A(')E9&%C
M=&%N9&\N(%-A;&EE;F1O+@!%;"!M96YS86IE(&-A<F5C92!D92!!<W5N=&\N
M`%-E(&AA(&5L:6UI;F%D;R!E;"!M96YS86IE+@!392!H82!C;VUP<F]B861O
M(&5L(&UE;G-A:F4N`%-E(&AA(&-O;7!R;V)A9&\@96P@;65N<V%J92X@4F5M
M:71E;G1E.B`E<RX`4V4@:&$@;6]S=')A9&\@96P@;65N<V%J92!E;G9I861O
M(&5L("5S(&$@)7,@8V]N(&5L(&%S=6YT;R`B)7,B+@K)<W1O(&YO(&=A<F%N
M=&EZ82!Q=64@96P@;65N<V%J92!H87EA('-I9&\@;&5I9&\@;R!C;VUP<F5N
M9&ED;RX`3F]M8G)E('5T:6QI>F%D;R!A;"!V:6YC=6QA<B!A(&QA('#A9VEN
M82!D92!C;VUP;W-I8VGS;@!%;"!N^FUE<F\@9&4@8V%M<&]S('1I96YE('%U
M92!S97(@=6X@;OIM97)O+@!(86-E(&9A;'1A(&5L(&WS9'5L;R!O<&5N<W-L
M('!A<F$@;&$@8VQA<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BX`3F\@<V4@<'5E
M9&4@9W5A<F1A<B!L82!P<F5F97)E;F-I82`B)7,B('!O<G%U92!S=7,@9&%T
M;W,@<V]B<F5P87-A;B!E;"!T86UA\6\@;>%X:6UO('!E<FUI=&ED;P!.;R!S
M92!E;F-O;G1R\R!E;B!E;"!S:7-T96UA(&5L('!R;V=R86UA('!A<F$@=F5R
M(&5S=&4@=&EP;R!D92!D871O<R`H)7,I+@!%;"!C87+A8W1E<B!D92!C:71A
M(&1E8F4@<V5R('-E<B!S\VQO('5N;RX`4V4@<'5E9&4@=F5R("5S(&5L('1E
M>'1O(&1E(&QA(&-L879E(%!'4"!P^F)L:6-A+@!.;R!E>&ES=&4@96P@87)C
M:&EV;R!S;VQI8VET861O(&5N(&5L(&%D:G5N=&\@35,M5$Y%1BX`3F\@97AI
M<W1E(&5L(&%R8VAI=F\@<V]L:6-I=&%D;R!E;B!E;"!A9&IU;G1O(%II<"X`
M4_-L;R!L;W,@;&%D;W,@:7IQ=6EE<F1O('D@9&5R96-H;P!3\VQO(&5L(&QA
M9&\@9&5R96-H;P!%;"!R96UI=&5N=&4@9&4@97-T92!M96YS86IE(&QE('-O
M;&EC:71A('5N82!.;W1I9FEC86-I\VX@9&4@0V]N<W5L=&$@9&4@365N<V%J
M92!C=6%N9&\@;&\@:&%Y82!L9>UD;RX@4'5L<V4@)7,@<&%R82!E;G9IX7)S
M96QA+@!%;"!S97!A<F%D;W(@9&5B92!S97(@<_-L;R!U;F\N`%-E(&AA(&5L
M:6UI;F%D;R!E;"!S97)V:61O<B`B)7,B+@!392!H82!G=6%R9&%D;R!E;"!S
M97)V:61O<B`B)7,B+@!%;"!S97)V:61O<B!N;R!P=61O(&=E;F5R87(@=6YA
M(&UI;FEA='5R82!D92!E<W1A(&EM86=E;BX`3F\@<V4@<'5D;R!S=7-T:71U
M:7(@;&$@9FER;6$N`%-E('-U<W1I='5Y\R!C;W)R96-T86UE;G1E(&QA(&9I
M<FUA+@!392!H82!E;&EM:6YA9&\@;&$@<V]L:6-I='5D(&1E(&%L=&$@9&4@
M)7,N`$5L(&%R8VAI=F\@97-P96-I9FEC861O(&YO(&5X:7-T92X`3&$@9FEL
M82!E<W!E8VEF:6-A9&$@*"5D*2!N;R!E>&ES=&4N`%-E(&AA(&'Q861I9&\@
M;&$@<&QA;G1I;&QA("(E<R(N`%-E(&AA(&5L:6UI;F%D;R!L82!P;&%N=&EL
M;&$@(B5S(BX`4V4@:&$@86-T=6%L:7IA9&\@;&$@<&QA;G1I;&QA("(E<R(N
M`%-E(&AA(&'Q861I9&\@;&$@=&%R96$@82!S=2!L:7-T82!D92!T87)E87,N
M`$5L(&%R8VAI=F\@=&5M<&]R86P@(B5S(B!N;R!E>&ES=&4N`$5L('1E>'1O
M(&1E;"!M96YS86IE`%-E('!U961E('9E<B`E<R!E;"!T97AT;R!D96P@;65N
M<V%J92X`16P@=&5X=&\@9&5L(&UE;G-A:F4@9&5V=65L=&\`4V4@<'5E9&4@
M=F5R("5S(&5L('1E>'1O(&1E;"!M96YS86IE(&1E=G5E;'1O+@!%;"!T97AT
M;R!D96P@;65N<V%J92!E;G9I861O`%-E('!U961E('9E<B`E<R!E;"!T97AT
M;R!D96P@;65N<V%J92!E;G9I861O+@!%;"!T97AT;R!Q=64@:&$@:6YT<F]D
M=6-I9&\@;F\@8V]I;F-I9&4@8V]N(&5L(&1E(&QA('!A;G1A;&QA+@!3\VQO
M(&QO<R!L861O<R!S=7!E<FEO<B!E(&EN9F5R:6]R`%/S;&\@96P@;&%D;R!S
M=7!E<FEO<@!392!P97)D:65R;VX@;&]S(&1A=&]S(&-A<F=A9&]S(&1E<V1E
M(&5L('!A<V\@86YT97)I;W(N`$YO('-E('!U9&\@9W5A<F1A<B!E;"!A<F-H
M:79O(&-A<F=A9&\N`%-E(&%L;6%C96[S(&-O<G)E8W1A;65N=&4@;&$@:6YF
M;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4@9&5L('5S=6%R:6\N`$YO
M(&5S=.$@9&ES<&]N:6)L92!E;"!B;&]Q=64@9&4@=V5A=&AE<BYC;VTN`$YO
M('-E(&5N8V]N='+S(&5L(&1I<F5C=&]R:6\@9&4@5&5M87,@(B5S(BX`3F\@
M:&%Y('!A<G1E<R!A;'1E<FYA=&EV87,@<75E('-E('!U961A;B!M;W-T<F%R
M(&5N(&SM;F5A+@!.;R!H87D@;65N<V%J97,@96X@97-T92!B=7KS;BX`3F\@
M<V4@9&ES<&]N92!D92!O<&-I;VYE<RX`3F\@:&%Y('!A<G1E<R!Q=64@<V4@
M<'5E9&%N(&UO<W1R87(@96X@;.UN96$N`$5N(&5S=&4@8V%M<&\@:&%Y(&1E
M;6%S:6%D;W,@8V%R86-T97)E<RX@2&$@:6YT<F]D=6-I9&\@)7,@8V%R86-T
M97)E<R!Y('1I96YE('%U92!I;G1R;V1U8VER(&UE;F]S(&1E("5S+@!.;R!H
M87D@=&5X=&\@<75E('-E('!U961A(&UO<W1R87(@96X@;.UN96$N`%-E('!R
M;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A9&ER(&$@(B5S(B!A;"!S:7-T96UA
M.B`E<P!392!P<F]D=6IO('5N('!R;V)L96UA(&%L(&)O<G)A<B!L;W,@9&%T
M;W,@9&5L('5S=6%R:6\@(B5S(B!D96P@<VES=&5M83H@`%-E('!R;V1U:F\@
M=6X@<')O8FQE;6$@86P@=F%C:6%R(&5L(&)U>O-N+B#)<W1O(&5S(&QO('%U
M92!D:6IO(&5L('-E<G9I9&]R.B`E<P!392!P<F]D=6IO('5N('!R;V)L96UA
M(&%L(&5L:6UI;F%R(&$@(B5S(B!D96P@<VES=&5M83H@`%-E('!R;V1U:F\@
M=6X@<')O8FQE;6$@86P@86-T=6%L:7IA<B`B)7,B.B`E<P!392!P<F]D=6IO
M('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D96P@87)C:&EV;SH@3F\@<V4@
M8V%R9_,@)7,N`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@8V]N(&QA(&-A<F=A
M(&1E;"!A<F-H:79O+B!%;"`E<R!E<F$@;>%S(&=R86YD92!Q=64@96P@=&%M
M8?%O(&WA>&EM;R!P97)M:71I9&\@*"5D(&)Y=&5S*2X`4V4@<')O9'5J;R!U
M;B!P<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N(%/S;&\@<V4@
M8V%R9_,@<&%R8VEA;&UE;G1E(&5L("5S+@!392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&-O<&EA<B!M96YS86IE<R!D92`B)7,B(&$@(B5S(BX@R7-T;R!E<R!L
M;R!Q=64@9&EJ;R!E;"!S97)V:61O<@!392!P<F]D=6IO('5N(&5R<F]R(&%L
M(&5L:6UI;F%R(&UE;G-A:F5S(&1E(&QA(&-A<G!E=&$@(B5S(BX@R7-T;R!E
M<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<@!392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&5L:6UI;F%R(&UE;G-A:F5S(&1E(&QA(&-A<G!E=&$@(B5S(BX@R7-T
M;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<@!392!P<F]D=6IO('5N(&5R
M<F]R(&%L(&5L:6UI;F%R(&UE;G-A:F5S+B#)<W1O(&5S(&QO('%U92!D:6IO
M(&5L('-E<G9I9&]R.B`E<P!392!P<F]D=6IO('5N(&5R<F]R(&%L(&5L:6UI
M;F%R(&5L(&%C;VYT96-I;6EE;G1O.B`E<RX`4V4@<')O9'5J;R!U;B!E<G)O
M<B!A;"!M;W-T<F%R(&5S=&$@<&%R=&4@9&5L(&UE;G-A:F4`4V4@<')O9'5J
M;R!U;B!E<G)O<B!A;"!M87)C87(@;65N<V%J97,@9&4@;&$@8V%R<&5T82`B
M)7,B+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L('-E<G9I9&]R`%-E('!R;V1U
M:F\@=6X@97)R;W(@86P@:6UP;W)T87(@)7,N`%-E('!R;V1U:F\@=6X@97)R
M;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S(&1E;"!C;VYT86-T;RX`4V4@<')O
M9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A<B!E;"!A8V]N=&5C:6UI96YT;SH@
M)7,N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S
M(&E#86QE;F1A<BX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L
M82!T87)E83H@)7,N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@
M;&$@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4@9&5L('5S=6%R
M:6\Z("5S+@!392!P<F]D=6IO('5N(&5R<F]R(&5N(&5L(&9O<FUU;&%R:6\@
M9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@<75E(&AA>6$@;VQV:61A9&\@<F5L
M;&5N87(@=6X@8V%M<&\@;F5C97-A<FEO+@!392!P<F]D=6IO('5N(&5R<F]R
M(&%L('1R87-L861A<B!M96YS86IE<R!D92`B)7,B(&$@(B5S(BX@R7-T;R!E
M<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<@!392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&5J96-U=&%R(&QA(&9U;F-I\VX@97-P96-I9FEC861A(&1E(&QA(&QI
M8G)E=&$@9&4@9&ER96-C:6]N97,N(%9U96QV82!A('!R;V)A<B!MX7,@861E
M;&%N=&4N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@9W5A<F1A<B!E<W1E(&UE
M;G-A:F4@8V]M;R!B;W)R861O<BX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!E
M;G9I87(@96P@;65N<V%J93H@)7,`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A
M8W1U86QI>F%R(&QO<R!D971A;&QE<R!D96P@8V]N=&%C=&\N(%9U96QV82!A
M('!R;V)A<B!MX7,@861E;&%N=&4N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@
M86-T=6%L:7IA<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN(%9U96QV82!A
M('!R;V)A<B!MX7,@861E;&%N=&4N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@
M86-T=6%L:7IA<B!E;"!A8V]N=&5C:6UI96YT;SH@)7,N`$YO(&AA8NUA('1E
M>'1O(&5N(&5S=&$@<&%R=&4@9&5L(&UE;G-A:F4`17-T92!M96YS86IE($A4
M34P@=&EE;F4@:6WA9V5N97,@:6YC;W)P;W)A9&%S+@!%<W1E(&UE;G-A:F4@
M2%1-3"!T:65N92!I;>%G96YE<R!I;F-O<G!O<F%D87,N($QA<R!I;>%G96YE
M<R!B;&]Q=65A9&%S(&%P87)E8V5N(&%S[3H@`$5S=&4@<V5R=FED;W(@24U!
M4"!N;R!S;W!O<G1A(&QA<R!C87)P971A<R!C;VUP87)T:61A<RX`4V4@861J
M=6YT\R!E<W1A(&-L879E(%!'4"!P^F)L:6-A(&%L(&UE;G-A:F4N`$5S=&$@
M86-C:?-N(&YO(&5S=.$@<V]P;W)T861A+@!%<W1A(&%C8VGS;B!T;V1A=NUA
M(&YO(&5S=.$@9&5S87)R;VQL861A+@#)<W1E(&YO('!A<F5C92!S97(@=6X@
M87)C:&EV;R!R87(@=N%L:61O+@#)<W1E(&YO('!A<F5C92!S97(@=6X@87)C
M:&EV;R!Z:7`@=N%L:61O+@#)<W1E(&YO('!A<F5C92!S97(@=6X@;OIM97)O
M(&1E('1A<FIE=&$@=N%L:61O+@!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@
M96YV:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA($-L:6-K
M871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2DL(&UE9&EA;G1E(&QA($%0
M22!(5%10`$5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I87(@;65N<V%J
M97,@82!T<F%VZ7,@9&4@;&$@<&%S87)E;&$@5TE.("AH='1P.B\O=VEN<&QC
M+F-O;2DL(&UE9&EA;G1E(&QA($%022!(5%10`$5S=&4@8V]N=')O;&%D;W(@
M<&5R;6ET92!E;G9I87(@;65N<V%J97,@82!T<F%VZ7,@9&4@;&$@<&%S87)E
M;&$@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2DL(&UE9&EA;G1E
M(&QA($%022!(5%10`$5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I87(@
M;65N<V%J97,@=FEA(%--5%`@82!T<F%VZ7,@9&4@;&$@<&%S87)E;&$@9&4@
M5F]D869O;F4@9&4@271A;&EA+"!S\VQO(&$@;OIM97)O<R!6;V1A9F]N92X@
M2&%C92!F86QT82!U;F$@8W5E;G1A(&1E(&-O<G)E;R!D92!6;V1A9F]N92!D
M92!)=&%L:6$@*&AT='`Z+R]W=W<N,3DP+FET*2X`2&%C92!F86QT82!E<W1E
M(&-A;7!O+@!%<W1E(&-A;7!O('/S;&\@<'5E9&4@8V]N=&5N97(@96YT97)O
M<RX`17-T92!C86UP;R!S\VQO('!U961E(&-O;G1E;F5R(&[Z;65R;W,@>2!L
M;W,@9&]S('!U;G1O<RX`17-T92!C86UP;R!S\VQO('!U961E(&-O;G1E;F5R
M('9A;&]R97,@;V-T86QE<RX`17-T92!C86UP;R!T:65N92!Q=64@<V5R('5N
M82!L:7-T82!D92!E;G1E<F]S('-E<&%R861O<R!P;W(@8V]M87,@;R!E<W!A
M8VEO<RX`17-T92!C86UP;R!T:65N92!Q=64@<V5R('5N(&[Z;65R;R!VX6QI
M9&\N`$5S=&4@8V%M<&\@=&EE;F4@<75E(&-O;G1E;F5R('5N(&/S9&EF;R!D
M92!C;VQO<B!E;B!F;W)M871O(%)'0B!(97AA9&5C:6UA;"P@<&]R(&5J96UP
M;&\@)R,Q,C,T868G+@!982!S92!H82!P<F]C97-A9&\@97-T92!F;W)M=6QA
M<FEO+@!%<W1O(&5S("5S+@#)<W1O(&5S('5N(&]B:F5T;R!D92!+;VQA8B!'
M<F]U<'=A<F4N(%!A<F$@=F5R;&\@;F5C97-I=&$@=6X@8VQI96YT92!D92!C
M;W)R96\@('%U92!E;G1I96YD82!E;"!F;W)M871O($MO;&%B($=R;W5P=V%R
M92X@4&%R82!V97(@=6YA(&QI<W1A(&1E(&1I8VAO<R!C;&EE;G1E<R!V:7-I
M=&4@)7,`17-T;R!P=65D92!T87)D87(@=6X@<F%T;RX@OT5S=&$@<V5G=7)O
M(&1E('%U92!D97-E82!C;VYT:6YU87(_`$5S=&4@;65N<V%J92!C;VYT:65N
M92!U;B!A<F-H:79O($UA8VEN=&]S:"X`17-T92!M96YS86IE(&-O;G1I96YE
M('5N(&%D:G5N=&\@<75E('-E(&AA(&9I<FUA9&\@9&EG:71A;&UE;G1E(&UE
M9&EA;G1E(%,O34E-12X`17-T92!M96YS86IE(&-O;G1I96YE('5N(&%D:G5N
M=&\@<75E('-E(&AA(&-I9G)A9&\@;65D:6%N=&4@4R]-24U%+@!%<W1E(&UE
M;G-A:F4@=&EE;F4@:6YF;W)M86-I\VX@9&4@97-T861O(&1E(&5N=NUO(&1E
M;"!C;W)R96\L('!E<F\@96P@9F]R;6%T;R!D96P@;65N<V%J92!E<R!D97-C
M;VYO8VED;RX`17-T92!M96YS86IE("!N;R!P87)E8V4@<V5R('5N(&UE;G-A
M:F4@8VEF<F%D;R!01U`@=N%L:61O+B!%<G)O<CH@`$5S=&4@;65N<V%J92!N
M;R!P87)E8V4@<V5R(&1E;"!F;W)M871O(%!'4"!C;W)R96-T;R`H9&4@86-U
M97)D;R!C;VX@;&$@4D9#(#(P,34I+@!%<W1E(&UE;G-A:F4@;F\@<&%R96-E
M(&5S=&%R(&5N(&5L(&9O<FUA=&\@4R]-24U%(&-O<G)E8W1O+@!%<W1E(&UE
M;G-A:F4@<V4@:&$@9FER;6%D;R!D:6=I=&%L;65N=&4@;65D:6%N=&4@4$=0
M+@!%<W1E(&UE;G-A:F4@<V4@:&$@9FER;6%D;R!D:6=I=&%L;65N=&4@;65D
M:6%N=&4@4R]-24U%+@!%<W1E(&UE;G-A:F4@<V4@:&$@8VEF<F%D;R!M961I
M86YT92!3+TU)344N`$5S=&4@;65N<V%J92!S92!H82!C:69R861O(&UE9&EA
M;G1E(%!'4"X`17-T92!M96YS86IE(&$`17-T92!M96YS86IE('-E(&5S8W)I
M8FGS(&-O;B!U;B!J=65G;R!D92!C87)A8W1E<F5S("@E<RD@9&ES=&EN=&\@
M86P@<W5Y;RX`17-T92!N^FUE<F\@9&5B92!S97(@<&]R(&QO(&UE;F]S('5N
M('5N;RX`17-T92!S97)V:61O<B!N;R!P=65D92!D97-C;VUP<FEM:7(@87)C
M:&EV;W,@>FEP('D@9WII<"X`17-T92!S97)V:61O<B!N;R!S;W!O<G1A(&QA
M(&-O;7!A<G1I8VGS;B!D92!C87)P971A<RX`17-T92!S:7-T96UA(&%C='5A
M;&UE;G1E(&5S=.$@9&5S86-T:79A9&\N`$5S=&4@=F%L;W(@=&EE;F4@<75E
M('-E<B!U;B!N^FUE<F\N`$5S=&$@=F5N=&%N82!S\VQO('!U961E(&%B<FER
M<V4@9&5S9&4@=6YA(&1E(')E9&%C8VGS;BX`17-T82!V96YT86YA('/S;&\@
M<'5E9&4@86)R:7)S92!D97-D92!U;F$@=F5N=&%N82!D92!O<&-I;VYE<P!6
M:7-U86QI>F%R('-E8W5E;F-I87,`4&]R('-E8W5E;F-I87,`5')U96YO`$EN
M8VED96YC:6%S`$AO<F$`0RX@=&EE;7!O<P!&;W)M871O(&AO<F%R:6\`4V5L
M96-C:?-N(&1E(&AO<F$`5&EM;W(M3&5S=&4`5.UT=6QO`%3M='5L;R`H8V]N
M<V5J;RDZ`%!A<F$`4&]R(&1E<W1I;F%T87)I;P!087)A('-E;&5C8VEO;F%R
M('9A<FEO<R!C86UP;W,L(&UA;G1E;F=A('!U;'-A9&$@;&$@=&5C;&$@0V]N
M=')O;"`H4$,I(&\@0V]M86YD;R`H36%C*2!A;"!P=6QS87(@8V]N(&5L(')A
M=/-N+@!087)A('-E;&5C8VEO;F%R('9A<FEO<R!C86UP;W,L(&UA;G1E;F=A
M('!U;'-A9&$@;&$@=&5C;&$@0V]N=')O;"`H4$,I(&\@0V]M86YD;R`H36%C
M*2!A;"!H86-E<B!C;&EC:RX`4&%R82!U=&EL:7IA<B!U;F$@8V]N97AI\VX@
M5$Q3('1I96YE('%U92!U=&EL:7IA<B!02%`@=F5R<VGS;B`U+C$N,"!O('-U
M<&5R:6]R+@!(;WD`0V]N;75T87(@;W)I9V5N($A434P`5&]G;P!4;VME;&%U
M`$UA\6%N80!4;VYG80!3=7!E<FEO<@!&<F%M92!S=7!E<FEO<B`H7W1O<"D`
M5&%M8?%O('1O=&%L(&1E(&%D:G5N=&]S.@!4<F%D=6-C:6]N97,`4&%P96QE
M<F$`4&%P96QE<F$Z`%1R:6YI9&%D('D@5&]B86=O`%9E<F1A9&5R;R!O(&9A
M;'-O`$UA<@!4^FYE>@!4=7)Q=>UA`%1U<F-O("A)4T\M.#@U.2TY*0!4=7)K
M;65N:7-TX6X`27-L87,@5'5R:W,@>2!#86EC;W,`5'5V86QU`$5S8W)I8F$@
M<W4@96QE8V-I\VXZ(`#-;F1I8V4@52Y6+CH@`%523`!54DP@9&4@<W4@:6YF
M;W)M92!D92!E<W1A9&\@9&4@96YV[6\@9&5L(&=U:?-N`%523#H`56=A;F1A
M`%5C<F%N:6$`26YC87!A>B!D92!A8V-E9&5R(&%L(&1I<F5C=&]R:6\@5D93
M+@!);F-A<&%Z(&1E(&'Q861I<B!I;F9O<FUA8VGS;B!D92!U<W5A<FEO(&%D
M:6-I;VYA;"!A;"!R96%L:7IA<B!E;"!A;'1A+@!);F-A<&%Z(&1E(&-A;6)I
M87(@;&]S('!R:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A
M<&%Z(&1E(&-A;6)I87(@;&]S('!R:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&
M4R`E<R\E<RX`26YC87!A>B!D92!C86UB:6%R(&$@)7,N`$EN8V%P87H@9&4@
M8V]M<')O8F%R(&5L('1A;6'Q;R!D92`B)7,B+@!);F-A<&%Z(&1E(&-O;7!R
M;V)A<B!E;"!T86UA\6\@9&4@(B5S+R5S(BX`26YC87!A>B!D92!C;VYE8W1A
M<G-E(&%L('-E<G9I9&]R(%-13"X`26YC87!A>B!D92!C;VYE8W1A<B!C;VX@
M4U-,+@!);F-A<&%Z(&1E(&-O<&EA<B!E;"!A<F-H:79O(%9&4RX`26YC87!A
M>B!D92!C<F5A<B!E;"!D:7)E8W1O<FEO(%9&4R`B)7,B+@!);F-A<&%Z(&1E
M(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(&-R96%R(&5L
M(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&-R96%R(&QA(&-A<G!E=&$@5D93
M("(E<R(`26YC87!A>B!D92!C<F5A<B!U;B!A<F-H:79O(%9&4R!V86/M;RX`
M26YC87!A>B!D92!D97-C;VUP<FEM:7(@;&]S(&1A=&]S+@!);F-A<&%Z(&1E
M(&5L:6UI;F%R("(E<R(L(&5L(&1I<F5C=&]R:6\@;F\@97-TX2!V86/M;RX`
M26YC87!A>B!D92!E;&EM:6YA<B`B)7,B.B`E<RX`26YC87!A>B!D92!E;&EM
M:6YA<B`E<RP@96P@9&ER96-T;W)I;R!N;R!E<W3A('9A8^UO`$EN8V%P87H@
M9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,@9&4@9F]R;6$@<F5C=7)S
M:79A+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93+@!)
M;F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93.B`E<RX`26YC
M87!A>B!D92!E;&EM:6YA<B!E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z
M(&1E(&5L:6UI;F%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&5L:6UI
M;F%R(&QA(&-A<G!E=&$@5D93("(E<R(N`$EN8V%P87H@9&4@96QI;6EN87(@
M96P@5D93(&1E(&9O<FUA(')E8W5R<VEV83H@)7,N`$EN8V%P87H@9&4@9&5T
M97)M:6YA<B!E;"!D:7)E8W1O<FEO(&%C='5A;"X`26YC87!A>B!D92!E>'1R
M865R(&QO<R!D971A;&QE<R!D96P@8V5R=&EF:6-A9&\N`$EN8V%P87H@9&4@
M8V%R9V%R(&QA(&1E9FEN:6-I\VX@9&4@)7,N`$EN8V%P87H@9&4@=')A<VQA
M9&%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI
M=F\@5D93("(E<R(N`$EN8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!61E,@
M<&%R82!E<V-R:6)I<BX`26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(%9&
M4RX`26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(&-O;7!R:6UI9&\N`$EN
M8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O(%9&4R`H:&$@9F%L;&%D;R!F:6QE
M<VEZ92@I*2X`26YC87!A>B!D92!L965R('5N(&%R8VAI=F\@5D93("AH82!F
M86QL861O(&=E=$9I;&53:7IE*"DI+@!);F-A<&%Z(&1E(&QE97(@=6X@87)C
M:&EV;SH@`$EN8V%P87H@9&4@;&5E<B!E;"!D:7)E8W1O<FEO('9F<W)O;W0N
M`$EN8V%P87H@9&4@<F5N;VUB<F%R("5S(&-O;6\@)7,Z(&QA(&-A<G!E=&$@
M9&5S=&EN;R!Y82!E>&ES=&4`26YC87!A>B!D92!R96YO;6)R87(@96P@9&ER
M96-T;W)I;R!61E,N`$EN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&1I<F5C=&]R
M:6\@5D93.B`E<RX`26YC87!A>B!D92!R96YO;6)R87(@96P@87)C:&EV;R!6
M1E,@(B5S(@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4R`E
M<R\E<RX`26YC87!A>B!D92!R96YO;6)R87(@96P@87)C:&EV;R!61E,N`$EN
M8V%P87H@9&4@;V)T96YE<B!E;"!E<W!A8VEO(&1I<W!O;FEB;&4`26YC87!A
M>B!D92!E:F5C=71A<B`G;6MI<V]F<R<N`$YO('-E('!U961E('1R861U8VER
M(&5S=&4@9&]C=6UE;G1O(&1E(%=O<F0`26YC87!A>B!D92!E<V-R:6)I<B!E
M;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&5S8W)I8FER('5N(&%R
M8VAI=F\@5D93("AH82!F86QL861O(&-O<'DH*2DN`$EN8V%P87H@9&4@97-C
M<FEB:7(@;&]S(&1A=&]S(&1E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!E
M<V-R:6)I<B!U;B!A<F-H:79O(%9&4RP@<V4@<W5P97)A<N$@;&$@<75O=&$N
M`%-I;B!R97-P;VYD97(`365N<V%J97,@<VEN(')E<W!O;F1E<@!296-U<&5R
M87(`4W5B<F%Y861A`$1E<W1I;F%T87)I;W,@;V-U;'1O<P!$97-H86-E<B!C
M86UB:6]S`$1E<VAA8V4@;&$@^FQT:6UA(&%C8VGS;@!297-P=65S=&$@:6YE
M<W!E<F%D82!D96P@<V5R=FED;W(@96X@;&$@8V]N97AI\VXZ(`!297-P=65S
M=&$@:6YE<W!E<F%D82!D96P@<V5R=FED;W(@86P@;6%N9&%T;R!!551(14Y4
M24-!5$4N`%)E<W!U97-T82!I;F5S<&5R861A(&1E;"!S97)V:61O<B!A(&QA
M(')E<W!U97-T82!$:6=E<W0M340U+@!297-P=65S=&$@:6YE<W!E<F%D82!D
M96P@<V5R=FED;W(@86P@;6%N9&%T;R!,3T=)3BX`4F5S<'5E<W1A(&EN97-P
M97)A9&$@9&5L('-E<G9I9&]R(&$Z(`!3:6X@8V%T96=O<NUA`$-O;7!O;F5N
M=&4@;F\@<V]P;W)T861O(&1E('1I<&\Z("5S`%5N:6-O9&4@*%541BTX*0!%
M;6ER871O<R#!<F%B97,@56YI9&]S`$EN9VQA=&5R<F$`17-T861O<R!5;FED
M;W,`17-T861O<R!5;FED;W,@;65N;W,@;&%S(&ES;&%S('!E<FEFZ7)I8V%S
M`%5N:61A9&5S`$1E<V-O;F]C:61O`$9E8VAA(&1E<V-O;F]C:61A`%)E<W!U
M97-T82!)34%0(&1E<V-O;F]C:61A(&1E;"!S97)V:61O<BX@16P@<V5R=FED
M;W(@<F5S<&]N9&GS.B`E<P!2975N:?-N(&1E<V-O;F]C:61A`$1E<W1I;F%T
M87)I;R!D97-C;VYO8VED;P!!<&EM<V=I9"!D97-C;VYO8VED;R`H240@9&4@
M;65N<V%J92!D92!L82!!4$DI+@!#;&EM<V=I9"!D97-C;VYO8VED;R`H240@
M9&4@;65N<V%J92!D96P@8VQI96YT92DN`%-E(&AA(&1E9FEN:61O('5N82!U
M8FEC86-I\VX@9&5S8V]N;V-I9&$N`%5S=6%R:6\@;R!C;VYT<F%S9?%A(&1E
M<V-O;F]C:61O<RX`16QI;6EN87(@=NUN8W5L;R!D96P@96QE;65N=&\@86-T
M=6%L`$]L=FED87(@9G)A<V4@8VQA=F4`4VEN(&YO;6)R90!,;W,@9W5I;VYE
M<R!S:6X@<')I=FEL96=I;W,@;F\@<'5E9&5N(&%C8V5D97(@9&4@9F]R;6$@
M<')O9W)A;>%T:6-A(&$@0V]R=&%R+T-O<&EA<B]096=A<B!P;W(@<F%Z;VYE
M<R!D92!S96=U<FED860N(%!U;'-E($%C97!T87(@<&%R82!V97(@96X@;6]Z
M:6QL82YO<F<@=6YA(&YO=&$@=.EC;FEC82!Q=64@;&4@;75E<W1R92!C\VUO
M('!E<FUI=&ER('%U92!U;B!G=6GS;B!A8V-E9&$@86P@<&]R=&%P87!E;&5S
M+@!3:6X@;&5E<@!!;G5L87(@8V]L;W(`1&5S=7-C<FEB:7)S92!D92!L82AS
M*2!C87)P971A*',I`$5X=&5N<VGS;B!N;R!S;W!O<G1A9&$`06-T=6%L:7IA
M<@!!8W1U86QI>F%R("5S`$%C='5A;&EZ87(@97-T861O(&1E(')E<W!U97-T
M80!!8W1U86QI>F%R('5S=6%R:6\`4V4@:&$@86-T=6%L:7IA9&\@(B5S(BX`
M4V4@:&$@96QI;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VXN`$-A
M<F=A<@!392!H86X@8V%R9V%D;R!E;B!E;"!S97)V:61O<B!T;V1O<R!L;W,@
M87)C:&EV;W,@9&4@8V]N9FEG=7)A8VGS;B!D92!A<&QI8V%C:6]N97,N`$%L
M9F%B971O(&QA=&EN;R!E;B!M87GZ<V,N`$[Z;65R;W,@<F]M86YO<R!E;B!M
M87GZ<V,N`%5R=6=U87D`57-A<B!A8W1U86PZ("5S`%5S87(@=F%L;W(@<&]R
M(&]M:7-I\VX`OU5S87(@<W5S8W)I<&-I;VYE<R!A(&-A<G!E=&%S($E-05`_
M`%5S87(@4U-,`+]5<V%R('!A<&5L97)A('9I<G1U86P_`%-E('5S82!S:2!E
M;"!U<W5A<FEO+V-O;G1R87-E\6$@<V]N(&1I<W1I;G1O<R!E;B!E;"!S97)V
M:61O<B!)35-0+@!5<W5A<FEO`%-E(&AA;B!C;VYC961I9&\@8V]R<F5C=&%M
M96YT92!A;"!U<W5A<FEO("(E<R(@;&]S(&1E<F5C:&]S(&5S<&5C:69I8V%D
M;W,@<&%R82!L82!C87)P971A("(E<R(N`$5L('5S=6%R:6\@)7,@8V%R96-E
M(&1E(&%U=&]R:7IA8VGS;B!P87)A("5S+@!!9&UI;FES=')A8VGS;B!D92!U
M<W5A<FEO<P!/<&-I;VYE<R!D92!U<W5A<FEO`%)E9VES=')O(&1E('5S=6%R
M:6]S`$5S=&$@<V5D92!T:65N92!D97-A8W1I=F%D;R!E;"!R96=I<W1R;R!D
M92!U<W5A<FEO<RX`3F\@<V4@:&$@96YC;VYT<F%D;R!L82!I9&5N=&ED860`
M57-U87)I;P!982!E>&ES=&4@96P@;F]M8G)E(&1E('5S=6%R:6\@(B5S(BX`
M57-U87)I;SH`57-U87)I;SH@`%5S=6%R:6]S(&5N(&5L('-I<W1E;6$Z`%5Z
M8F5K:7-TX6X`3F\@97AI<W1E(&5L(&1I<F5C=&]R:6\@5D93+@!!=7-E;F-I
M80!,87,@=6)I8V%C:6]N97,@=N%L:61A<R!E;F-O;G1R861A<R!I;F-L=7EE
M;CH@`%9A;&ED97H`5F%L;W(@96X@;6EN=71O<R!A('!A<G1I<B!D92!A:&]R
M82X`16P@=F%L;W(@97AC961E(&5L('1A;6'Q;R!MX7AI;6\@9&4@)7,N`%9A
M;&]R97,`5F%L;W)E<R!A('-E;&5C8VEO;F%R`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`$AA(&9A;&QA9&\@;&$@8V]M<')O8F%C:?-N("T@97-T92!M
M96YS86IE('!U961E(&AA8F5R<V4@9F]R>F%D;RX`5F5R<VGS;@!#+B!V97)S
M:6]N97,`06QI;F5A8VGS;B!V97)T:6-A;`!-87)G96X@=F5R=&EC86P`5F5R
M=&EC86PZ`$UU>2!A;'1A`%9I971N86T`5FEE=&YA;6ET82`H5DE30TE)*0!6
M97(`5F5R("5S`%9E<B!C;&%V92!P^F)L:6-A(&1E("5S`%9E<B!C;VYT96YI
M9&\@2%1-3"!E;B!U;F$@=F5N=&%N82!S97!A<F%D80!697(@;65N<V%J97,`
M5F5R(&-L879E('!E<G-O;F%L('!R:79A9&$`5F5R(&-L879E('!E<G-O;F%L
M('#Z8FQI8V$`5F5R('-E8W5E;F-I80!697(@;6EN:6%T=7)A`%9E<B!U;F$@
M<.%G:6YA('=E8B!E>'1E<FYA`%9E<B!C;VUO("5S`%9E<B!A9&IU;G1O(&5N
M('5N82!V96YT86YA('-E<&%R861A`%9E<B!C;VYT96YI9&\@96X@=6YA('9E
M;G1A;F$@<V5P87)A9&$`5F5R(&%C;VYT96-I;6EE;G1O`%9E<B!M96YS86IE
M<R!D92`E<P!6:7-T82!O(&)U>O-N(&UO<W1R861O<R!A;"!I;FEC:6%R(&QA
M('-E<VGS;CH`5F5R('1A<F5A`%9E<B!L87,@:6WA9V5N97,`27-L87,@5NUR
M9V5N97,L($)R:73A;FEC87,`27-L87,@5NUR9V5N97,L(%4N4RX`4V4@:&$@
M8W)E861O(&-O<G)E8W1A;65N=&4@;&$@8V%R<&5T82!V:7)T=6%L("(E<R(N
M`%9I<G1U86QE<P!,87,@8V%R<&5T87,@=FER='5A;&5S(&YE8V5S:71A;B!U
M;F$@971I<75E=&$N`$5N=')A9&$`0V%R<&5T82!D92!%;G1R861A('9I<G1U
M86P`4&%P96QE<F$`0V%R<&5T82!087!E;&5R82!V:7)T=6%L`$5T:7%U971A
M(&1E(&-A<G!E=&$@=FER='5A;`!6:7-I8FEL:61A9`!6:7-I8FEL:61A9#H@
M`%9O9&%F;VYE(&1E($ET86QI82!M961I86YT92!33510`$%625-/`*&AH4%$
M5D525$5.0TE!(2$A($5,24U)3D4@34%.54%,345.5$4@14P@1U5)TTX@1$4@
M)7,N`%=)3B!P;W(@2%144`!786QL:7,@>2!&=71U;F$`079I<V\`36EE`%!R
M979I<VGS;B!D96P@=&EE;7!O`$1A=&]S(&1E;"!T:65M<&\@<W5M:6YI<W1R
M861O<R!P;W(`5V5A=&AE<BYC;VT`5V5B`%-E9&4@5V5B`%-E;6%N86QM96YT
M90!":65N=F5N:61O`$)I96YV96YI9&]S(&$@)7,`0FEE;G9E;FED;RP@)7,`
M3V5S=&4@*$E33RTX.#4Y+3$I`$]E<W1E("A)4T\M.#@U.2TQ-2D`4^%H87)A
M($]C8VED96YT86P`OU%UZ2!A<&QI8V%C:?-N(&1E8F5R[6$@;6]S=')A<B`E
M<R!A;"!I;FEC:6%R(&QA('-E<VGS;C\`OT-UX6P@97,@96P@8V%RX6-T97(@
M9&5L:6UI=&%D;W(_`+]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E(&-I=&%D;S\`
MOU%UZ2!D96)E<NUA;6]S(&AA8V5R(&-O;B!L;W,@;65N<V%J97,@<W!A;2!T
M<F%S(&AA8F5R;&]S(&YO=&EF:6-A9&\@8V]M;R!S<&%M(&\@:6YO9F5N<VEV
M;W,_`$%L(&5L:6UI;F%R(&UE;G-A:F5S+""_=')A<VQA9&%R;&]S(&$@;&$@
M<&%P96QE<F$@96X@=F5Z(&1E(&UA<F-A<FQO<R!C;VUO(&5L:6UI;F%D;W,_
M`$%L(&%B<FER('5N(&)U>O-N+""_96X@<77I('#A9VEN82!D97-E82!E;7!E
M>F%R/P"_1W5A<F1A<B!D871O<R!A9&IU;G1O<R!A;"!G=6%R9&%R(&5L(&-O
M<G)E;R!E;G9I861O/P!!;"!E;G9I87(@8V]R<F5O(&\@97AP86YD:7(@9&ER
M96-C:6]N97,L(+]1=>D@9&]M:6YI;R!S92!D96)E<NUA(&'Q861I<B!A(&QA
M<R!D:7)E8V-I;VYE<R!N;R!C86QI9FEC861A<R`H9&ER96-C:6]N97,@9&4@
M8V]R<F5O('-I;B`B0"(I/P!-87!A(&1E(&QO8V%L:7IA8VGS;B!D92!!=7-T
M<F%L:6$`477I(&9A<V5S`%!L=6=I;G,@:&%B:6QI=&%D;W,@9&5L(&5D:71O
M<B!D92!T97AT;R!E;G)I<75E8VED;RX`3&ES=&$@8FQA;F-A`$%N8VAU<F$`
M06YC:'5R82!E;B!U;FED861E<R!#4U,`06YC:'5R82!D96P@;65N^B`E<R!I
M>G%U:65R9&\@*&1I<W!O;FEB;&4@96X@;&$@<'+S>&EM82!S97-I\VXI.@!!
M;F-H=7)A(&1E(&QA('1A8FQA`%5N:61A9&5S(&1E(&%N8VAU<F$`06YC:'5R
M83H`5VEK:0!6:65N=&\`5FEE;G1O(&UA='5T:6YA`%9E;&]C:61A9"!D96P@
M=FEE;G1O(&5N(&YU9&]S`%9I96YT;SH`5FEE;G1O.B``4V%B:61U<NUA`$1E
M<V5O<P!%;7!L96\`1&ER96-C:?-N(&1E;"!T<F%B86IO`%1E;.EF;VYO(&1E
M;"!T<F%B86IO`$[Z;65R;R!E<G+S;F5O(&1E(&-A;7!O<R!E;B!L82!L[6YE
M82`E9"X@4V4@97-P97)A8F%N("5D('D@:&%Y("5D+@!.^FUE<F\@97)R\VYE
M;R!D92!C86UP;W,N(%-E(&5S<&5R86)A;B`E9"!Y(&AA>2`E9"X`3V9F<V5T
M("5D(&5R<O-N96\@86P@;&5E<B!U;B!A<F-H:79O(%9&4RX`6"U2968`3&EM
M:71A8VEO;F5S(&+A<VEC87,@6#4P.78S`%5S;R!D92!C;&%V92!E>'1E;F1I
M9&$@6#4P.78S`$YO;6)R92!A;'1E<FYA=&EV;R!D92!A<W5N=&\@6#4P.78S
M`$ED96YT:69I8V%D;W(@9&4@8VQA=F4@9&4@87-U;G1O(%@U,#EV,P!%>'1E
M;G-I;VYE<R!8-3`Y=C,`04$`04%!00"A36%P82!D92!986AO;R$`06YU86QM
M96YT90!996UE;@!3[0!3[2P@;&\@86-E<'1O`$5S=.$@82!P=6YT;R!D92!T
M<F%E<B!C;W)R96\@9&4@;&$H<RD@<VEG=6EE;G1E*',I(&-U96YT82AS*3H`
M26YT96YT82!E;&EM:6YA<B!T;V1O<R!L;W,@;65N<V%J97,@9&4@;&%S('-I
M9W5I96YT97,@8V%R<&5T87,N`$EN=&5N=&$@96QI;6EN87(@;&$H<RD@<VEG
M=6EE;G1E*',I(&-A<G!E=&$H<RDN`$5S=.$@8V]P:6%N9&\O=')A<VQA9&%N
M9&\@82!U;F$@;G5E=F$@8V%R<&5T82X`17-TX2!C<F5A;F1O('5N82!S=6(M
M8V%R<&5T82!D92``17-TX2!C<F5A;F1O('5N82!C87)P971A(&1E;"!N:79E
M;"!S=7!E<FEO<BX`17-TX2!E;B!-3T1/(%1%6%1/+B!5=&EL:6-E(&5L(&)O
M=/-N(%L\/ET@<&%R82!R96=R97-A<B!A;"!M;V1O(%=94TE764<N`$YO(&1I
M<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!C<F5A<B!C87)P971A<RX`3F\@
M9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A(&-R96%R(&WA<R!D92`E9"!B
M;&]Q=65S+@!.;R!D:7-P;VYE(&1E('!R:79I;&5G:6]S('!A<F$@8W)E87(@
M;>%S(&1E("5D(&-A<G!E=&%S+@!.;R!E<W3A(&%U=&5N=&EF:6-A9&\N`$5S
M=.$@<F5N;VUB<F%N9&\@;&$@8V%R<&5T83H@`%!U961E('5T:6QI>F%R(&QO
M<R!S:6=U:65N=&5S(&-O;6]D:6YE<R!E;B!E;"!T97AT;R!D92!L82!P;&%N
M=&EL;&$Z("5C('!A<F$@96P@8V]N=&5N:61O(&%C='5A;"!D96P@;65N<V%J
M93L@)7,@<&%R82!L82!F:7)M82X`3F\@<'5E9&4@:6YC;'5I<B!E;"!C87+A
M8W1E<B`B7"(@96X@96P@;F]M8G)E(&-O;7!L971O+@!392!H82!D97-U<V-R
M:71O(&-O<G)E8W1A;65N=&4@9&4@(B5S(@!.;R!E<W3A(&1E(&%C=65R9&\@
M8V]N(&QA<R!C;VYD:6-I;VYE<R!D96P@4V5R=FEC:6\L('!O<B!L;R!Q=64@
M;F\@<V4@;&4@<&5R;6ET92!I;FEC:6%R('-E<VGS;BX`3F\@:6YT<F]D=6IO
M('5N82!D:7)E8V-I\VX@9&4@8V]R<F5O(';A;&ED82X`3F\@87-O8VGS(&YI
M;F=U;F\@9&4@;&]S(&-A;7!O<R!D96P@87)C:&EV;R!I;7!O<G1A9&\@82!L
M;W,@8V%M<&]S(&-O<G)E<W!O;F1I96YT97,@9&4@)7,N`$YO(&1I<W!O;F4@
M9&4@<')I=FEL96=I;W,@<&%R82!C86UB:6%R(&5L(&%C8V5S;R!A(&5S=&$@
M8V%R<&5T80!(82!R965N=FEA9&\@97-T92!M96YS86IE(&1E("4E<R!A(&QO
M<R!S:6=U:65N=&5S(&1E<W1I;F%T87)I;W,Z("5S+@!4:65N92`E<R!M96YS
M86IE<R!N=65V;W,N`%1I96YE(#$@;65N<V%J92!N=65V;RX`66$@:&$@96YV
M:6%D;R!E<W1A('#A9VEN82X`2&$@<V%L:61O(&1E(&QA('-E<VGS;BX`5&EE
M;F4@8V]R<F5O(&YU979O(&5N(&QA('-I9W5I96YT92!C87)P971A.@!4:65N
M92!C;W)R96\@;G5E=F\@96X@;&%S('-I9W5I96YT97,@8V%R<&5T87,Z`%1I
M96YE('%U92!I;G1R;V1U8VER('5N(&[Z;65R;R!D92!T96SI9F]N;R!M\W9I
M;"!VX6QI9&\L('/S;&\@9.UG:71O<R!C;VX@=6X@)RLG(&]P8VEO;F%L('!A
M<F$@96P@<')E9FEJ;R!D92!L;&%M861A(&EN=&5R;F%C:6]N86PN`%1I96YE
M('%U92!I;G1R;V1U8VER('5N('9A;&]R(';A;&ED;RX`4&%R82!U<V%R($%L
M=&%S('1I96YE('%U92!C;VYF:6=U<F%R('5N(&UO=&]R(&1E($1A=&%4<F5E
M+@!4:65N92!Q=64@8V]N9FEG=7)A<B!U;B!M;W1O<B!61E,N`$1E8F4@9&5S
M8W)I8FER(&5L('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!E;"!I;F9O<FUE
M+@!4:65N92!Q=64@:6YD:6-A<B!A;"!M96YO<R!U;B!D97-T:6YA=&%R:6\N
M`%1I96YE('%U92!I;G1R;V1U8VER(&QA(%523"!A(&QA('%U92!A<'5N=&$@
M97-T92!V[6YC=6QO`%!A<F$@=F5R(&5S=&4@;65N<V%J92!T:65N92!Q=64@
M:6YT<F]D=6-I<B!L82!F<F%S92!C;&%V92!D92!S=2!C;&%V92!01U`@<')I
M=F%D80!087)A('9E<B!E<W1E(&UE;G-A:F4@=&EE;F4@<75E(&EN=')O9'5C
M:7(@;&$@9G)A<V4@8VQA=F4@9&4@<W4@8VQA=F4@4R]-24U%('!R:79A9&$`
M4')I;65R;R!T:65N92!Q=64@<V5L96-C:6]N87(@=6X@8G5Z\VX@9&4@9&5S
M=&EN;RX`5&EE;F4@<75E('-E;&5C8VEO;F%R('5N82!C=65N=&$@82!E;&EM
M:6YA<BX`4')I;65R;R!T:65N92!Q=64@<V5L96-C:6]N87(@=6YA(&1I<F5C
M8VGS;BX`5&EE;F4@<75E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R(&$@96QI
M;6EN87(N`%!R:6UE<F\@=&EE;F4@<75E('-E;&5C8VEO;F%R(&%L(&UE;F]S
M('5N(&UE;G-A:F4N`%1I96YE('%U92!I;F1I8V%R('5N(&1E<W1I;F%T87)I
M;RX`5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S=6%R:6\@82!E;&EM:6YA
M<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S=6%R:6\@82!E;&EM:6YA
M<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S=6%R:6\@82!A\6%D:7(N
M`%1I96YE('%U92!E<W!E8VEF:6-A<B!E;"!U<W5A<FEO(&$@86-T=6%L:7IA
M<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('%UZ2!A8V-I\VX@<V4@96IE8W5T
M87+A+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N=65V;R!N;VUB<F4@9&4@
M8V%T96=O<NUA+@!4:65N92!Q=64@86-T:79A<B`B)7,B(&5N('-U<R!O<&-I
M;VYE<R!D92!M86YT96YI;6EE;G1O+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U
M;B!N^FUE<F\@9&4@=&5LZ69O;F\@:71A;&EA;F\`2&$@<F5D:7)I9VED;R!E
M<W1E(&UE;G-A:F4@82`E<R!E;B`E)7,N`$AA(&-O;G1E<W1A9&\@82!E<W1E
M(&UE;G-A:F4@96X@)7,N`$YO('-E(&AA('-U<V-R:71O(&$@(B5S(BX@R7-T
M;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<@!.;R!S92!H82!D97-U<V-R
M:71O(&1E("(E<R(N(,ES=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(`
M4V4@:&$@<W5S8W)I=&\@8V]R<F5C=&%M96YT92!A("(E<R(`4V4@:&$@9&5S
M=7-C<FET;R!C;W)R96-T86UE;G1E(&1E("(E<R(`2&$@97AP:7)A9&\@<W4@
M<V5S:?-N("5S+B!6=65L=F$@82!I;FEC:6%R('-E<VGS;BX`4W4@9&ER96-C
M:?-N(&1E(&-O<G)E;P!$:7)E8V-I\VX@1&4Z`%-U(&EN9F]R;6%C:?-N`$AA
M(&-A;6)I861O('-U(&1I<F5C8VGS;B!D92!);G1E<FYE="!D97-D92!E;"!C
M;VUI96YZ;R!D92!S=2!S97-I\VX@)7,N(%!O<B!R87IO;F5S(&1E('-E9W5R
M:61A9"!T:65N92!Q=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S97-I\VXN`%-U
M(&YO;6)R90!#;&%V97,@4$=0(%#Z8FQI8V$O4')I=F%D80!3=2!C;&%V92!P
M<FEV861A`%-U(&-L879E('#Z8FQI8V$`4W4@9&ER96-C:?-N(%)E<W!O;F1E
M<BUA.B`\96T^*&]P8VEO;F%L*3PO96T^`%-U<R!C97)T:69I8V%D;W,@4R]-
M24U%(%#Z8FQI8V\O4')I=F%D;P!3=7,@8W5E;G1A<SH`4W5S(&1I<F5C8VEO
M;F5S(&%P;V1O.B`\96T^*&]P8VEO;F%L+"!I;F1I<75E(&-A9&$@9&ER96-C
M:?-N(&5N('5N82!L[6YE82!D:7-T:6YT82D\+V5M/@!3=2!M;W1O<B!D92!A
M=71E;G1I9FEC86-I\VX@;F\@<&5R;6ET92!A\6%D:7(@=7-U87)I;W,N(%-I
M('%U:7-I97)A('5S87(@2&]R9&4@<&%R82!A9&UI;FES=')A<B!C=65N=&%S
M(&1E('5S=6%R:6\L('1E;F1RX2!Q=64@=71I;&EZ87(@=6X@;6]T;W(@9&4@
M875T96YT:69I8V%C:?-N(&1I<W1I;G1O+@!3=2!M;W1O<B!D92!A=71E;G1I
M9FEC86-I\VX@;F\@<&5R;6ET92!L:7-T87(@=7-U87)I;W,L(&\@<V4@:&$@
M9&5S:&%B:6QI=&%D;R!L82!C87)A8W1E<NUS=&EC82!P;W(@86QG^FX@;6]T
M:79O+@!087)E8V4@<75E(&AA(&-A;6)I861O('-U(&YA=F5G861O<B!D97-D
M92!E;"!C;VUI96YZ;R!D92!S=2!S97-I\VX@)7,N(%!O<B!R87IO;F5S(&1E
M('-E9W5R:61A9"!T:65N92!Q=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S97-I
M\VXN`$5L(&YA=F5G861O<B!N;R!A9&UI=&4@;&$@=FES=6%L:7IA8VGS;B!E
M;B!L[6YE82!D92!E<W1E('1I<&\@9&4@:6UA9V5N+@!3=2!N879E9V%D;W(@
M;F\@861M:71E(&5S=&$@8V%R86-T97+M<W1I8V$N`$5L(&YA=F5G861O<B!N
M;R!A9&UI=&4@97-T82!O<&-I\VX@9&4@:6UP<F5S:?-N+B!0<F5S:6]N92!#
M;VYT<F]L+T-O;6%N9&\@*R!0('!A<F$@:6UP<FEM:7(N`%IO;F$@:&]R87)I
M82!A8W1U86PZ`$IU96=O(&1E(&-A<F%C=&5R97,@<&]R(&]M:7-I\VX@<&%R
M82!E;"!E;G;M;R!D92!M96YS86IE<SH`3>ET;V1O(&1E(&-I9G)A9&\@<&]R
M(&]M:7-I\VX@<&%R82!E;"!E;G;M;R!D92!M96YS86IE<SH`4V4@:&$@8V%M
M8FEA9&\@<W4@:61E;G1I9&%D('!O<B!O;6ES:?-N+@!)9&5N=&ED860@<&]R
M(&]M:7-I\VXZ`$YO;6)R92!C;VUP;&5T;SH`16P@87)C:&EV;R!A9&IU;G1O
M('9I;F-U;&%D;R!H82!S:61O(&1E<V-A<F=A9&\@86P@;65N;W,@<&]R('5N
M('5S=6%R:6\Z"@I.;VUB<F4@9&5L(&%D:G5N=&\Z("5S"D9E8VAA(&1E;"!A
M9&IU;G1O.B`E<PH*4'5L<V4@96P@=NUN8W5L;R!S:6=U:65N=&4@<&%R82!E
M;&EM:6YA<B!D92!F;W)M82!P97)M86YE;G1E(&5L(&%D:G5N=&\Z"B5S`%-E
M(&AA(&%G;W1A9&\@<W4@=&EE;7!O(&1E(&-O;F5X:?-N+@!392!E;G9I\R!C
M;W)R96-T86UE;G1E('-U(&UE;G-A:F4N`$QA(&YU979A(&-O;G1R87-E\6$@
M<&%R82`E<R!E<SH@)7,`4V4@:&%N(&%C='5A;&EZ861O('-U<R!O<&-I;VYE
M<R!S\VQO('!O<B!L82!D=7)A8VGS;B!D92!L82!S97-I\VXN`%-E(&AA;B!A
M8W1U86QI>F%D;R!S=7,@;W!C:6]N97,N`%-E(&AA(')E86IU<W1A9&\@<W4@
M8V]N=')A<V7Q80!392!H82!R96%J=7-T861O('-U(&-O;G1R87-E\6$L(&-O
M;7!R=65B92!E;"!C;W)R96\@92!I;FEC:64@<V5S:?-N(&-O;B!S=2!N=65V
M82!C;VYT<F%S9?%A+@!,82!C;VYT<F%S9?%A(&AA(&5X<&ER861O+@!397)V
M:61O<F5S(')E;6]T;W,Z`$9I<FUA.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;3V-U;'1A<B!D:7)E8V-I;VYE<UT`6T]C=6QT
M87(@=&5X=&\@8VET861O70!;4VEN(&%S=6YT;UT`6TEN9F]R;64@9&4@<')O
M8FQE;6%=`%M-;W-T<F%R(&1I<F5C8VEO;F5S("T`6TUO<W1R87(@=&5X=&\@
M8VET861O("T`6TUO<W1R87(@=&5X=&\@8VET861O("T@)7,@;.UN96%S70!;
M36]S=')A<B!D:7)E8V-I;VYE<R`M("5S(&1E<W1I;F%T87)I;W-=`%ML[6YE
M82`E<R!D92`E<UT`7T%D;6EN:7-T<F%C:?-N`%]"8V,`3&ES=&$@;F5?9W)A
M`%]#3$D`7T-C`,%R7V)O;"!D871O<P!%7VQI;6EN87(`15]L:6UI;F%R(&9I
M;&$`7T-A<G!E=&%S`%]'<G5P;W,`05]Y=61A`%])9&5N=&ED860`4')O<&EE
M9&%D97,@9&4@7VEM86=E;BXN+@!?16YT<F%D80!?26YI8VEA<B!S97-I\VX`
M7U-A;&ER`$]R:6=E;B!D96P@;65N<V%?:F4`36]D:69I8V%R(%]V[6YC=6QO
M+BXN`%]2961A8W1A<@!?3W!C:6]N97,`7U!R:79I;&5G:6]S`$E?;7!R:6UI
M<@!0<FEO<FED860@*%]Y*0!!8W1U86QI7WIA<B`E<P!?16QI;6EN87(@=NUN
M8W5L;RXN+@!297-P;VY?9&5R`%]"=7-C87(`7T5N=FEA<B!M96YS86IE`$-O
M;E]F:6=U<F%C+@!0<F]P:65D861E<R!D92!?=&%B;&$N+BX`4V5C7W5E;F-I
M80!?4&%R80!296-U<&5R87(@*%]W*0!?57-U87)I;W,`7U9E<B!S96-U96YC
M:6$`3&ES=&$@8FQ?86YC80!D:7)E8V-I;VYE<P!D97-T:6YA=&%R:6\@9&5S
M8V]N;V-I9&\`861J=6YT;P!A9&IU;G1O<RYZ:7``8GET97,`86=E;F1A`&-A
M;&UA`&YO('-E('!U961E(&-R96%R(&5L(&%R8VAI=F\@9&4@9&5S=&EN;P!N
M;R!S92!P=65D92!A8G)I<B!E;"!O<FEG96X`<'5L<V4@87%U[0!E<G)O<B!D
M92!L[6YE82!D92!C;VUA;F1O`&5R<F]R(&1E(&-O;F9I9W5R86-I\VX`9F%L
M=&$@=6X@87)C:&EV;R!C<NUT:6-O(&1E;"!S:7-T96UA`&5R<F]R(&1E(&9O
M<FUA=&\@9&4@9&%T;W,`;6]D:69I8V%R`&5N=')A9&$@;F\@96YC;VYT<F%D
M80!D97-C96YS;P!A<F-H:79O`&1E`&1E;"`E<R`H)7,I(&$@;&%S("5S("5S
M`'9E;G1O<V\`:#H`:&@`;F]M8G)E(&1E(&%N9FET<FGS;B!D97-C;VYO8VED
M;P!I;FUE9&EA=&%M96YT90!E;B!L[6YE80!E<G)O<B!D92!E;G1R861A+W-A
M;&ED80!E<G)O<B!D92!S;V9T=V%R92!I;G1E<FYO`&-L879E`&SM;F5A<UT`
M87)C:&EV;R!D92!B=7KS;@!C\V1I9V\@9&4@97)R;W(@;6MI<V]F<R`E9"!A
M;"!R96%L:7IA<B!)4T\N`&UM`&YO;6)R90!N:6YG=6YO`'-I;B!D97-A<G)O
M;&QA<@!A^FX@;F\@<V4@:&$@9&5S87)R;VQL861O`&YO=&%S`&\`<&]R8V5N
M=&%J90!P<FEV:6QE9VEO(&1E;F5G861O`'#M>&5L97,`9&5S=&EN871A<FEO
M<UT`97)R;W(@<F5M;W1O(&1E('!R;W1O8V]L;P!E;B!A=6UE;G1O`'-E<G9I
M8VEO(&YO(&1I<W!O;FEB;&4`;6]S=')A<B!D:69E<F5N8VEA<P!S;7,R96UA
M:6P@<&]R($A45%``97)R;W(@9&4@;W)T;V=R86;M80!E<G)O<F5S(&1E(&]R
M=&]G<F%F[6$`<W,`97-T86)L90!E<G)O<B!D96P@<VES=&5M80!T87)E87,`
M9F%L;&\@=&5M<&]R86P`97-C<FEB82!D;W,@=F5C97,@;&$@8V]N=')A<V7Q
M82!P87)A(&-O;F9I<FUA<FQA`'5N:69I8V%D;P!S:6X@;F]M8G)E`'5S=6%R
M:6\@<V5L96-C:6]N861O`'9#87)D`'<Z`'=E871H97(N8V]M`'-U(&QI<W1A
M(&YE9W)A`'-U(&QI<W1A(&)L86YC80``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]L;V-A;&4O97-?15,O:&5L<"YX;6P`````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`Q,S$T,3(`,3`T,3<S-C(W-C``,#(Q,3$U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_>&UL('9E
M<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:6UP+VQO8V%L92]E<U]%4R]H
M96QP+GAM;"QV(#$N,C0N-"XU(#(P,#8O,#$O,S$@,3@Z,#0Z-30@:F%N($5X
M<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(@
M;60U/2(S,C4Y8F$P,&$Q.3@U-3EC-V9A83<V93<X-C<V,#!D.2(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93Y2961A8V-I)B-X1C,[;B!D96P@;65N
M<V%J93H@06-C:6]N97,\+W1I=&QE/@H@("`@/&AE861I;F<^06-C:6]N97,\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(")%;G9I87(@;65N<V%J92(@;6%N
M9&$@96P@;65N<V%J92!A;"]L;W,@9&5S=&EN871A<FEO*',I('!R979I<W1O
M*',I+B!!<V5G)B-X1D$[<F5S92!D92!Q=64@9&5S96$@96YV:6%R;&\@>6$@
M<75E(&5S=&$@86-C:28C>$8S.VX@97,@:7)R979E<G-I8FQE+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("`B1W5A<F1A<B!B;W)R861O<B(@8V]L;V-A
M('5N(&UE;G-A:F4@:6YA8V%B861O(&5N('5N82!C87)P971A(&QL86UA9&$@
M(D)O<G)A9&]R97,B(&%C8V5S:6)L92!M961I86YT92!E;"!M96XF(WA&03L@
M9&5S<&QE9V%B;&4@9&4@8V%R<&5T87,@9&4@;&$@97-Q=6EN82!S=7!E<FEO
M<B!D97)E8VAA(&1E(&QA('!A;G1A;&QA+B!0=65D92!T97)M:6YA<B!E;"!M
M96YS86IE(&-O;B!P;W-T97)I;W)I9&%D(&-A;6)I86YD;R!A(&QA(&-A<G!E
M=&$@(D)O<G)A9&]R97,B+"!P=6QS86YD;R!E;"!M96YS86IE(&=U87)D861O
M('!A<F$@86)R:7)L;R!Y(&AA8VEE;F1O(&-L:6-K(&5N(")296%N=61A<B(N
M($%S96<F(WA&03MR97-E(&1E(&$F(WA&,3MA9&ER('5N(&%S=6YT;R!A;"!M
M96YS86IE(&%N=&5S(&1E(&=U87)D87)L;R!C;VUO(&)O<G)A9&]R(&1E(&9O
M<FUA('%U92!P=65D82!I9&5N=&EF:6-A<FQO(&8F(WA%,3MC:6QM96YT92!D
M96YT<F\@9&4@;&$@8V%R<&5T82!D92!";W)R861O<F5S+@H@("`@/"]P87)A
M/@H@("`@/'1I<#X*("`@($1E<&5N9&EE;F1O(&1E(&QA(&EN<W1A;&%C:28C
M>$8S.VXL('!U961E(&-A;6)I87(@96X@;&%S('!R969E<F5N8VEA<R!S:2P@
M=')A<R!G=6%R9&%R('5N(&UE;G-A:F4@8V]M;R!B;W)R861O<BP@=F]L=F5R
M)B-X13$[(&$@;&$@)B-X1D$[;'1I;6$@8V%R<&5T82!Q=64@97-T86)A('9I
M<W5A;&EZ86YD;R!O('-I('-E9W5I<B8C>$4Q.R!E;B!L82!V96YT86YA(&1E
M(')E9&%C8VDF(WA&,SMN(&1E(&UE;G-A:F5S+@H@("`@/"]T:7`^"B`@("`\
M<&%R83X*("`@(")#86YC96QA<B!M96YS86IE(B!I;G1E<G)U;7!E(&QA(')E
M9&%C8VDF(WA&,SMN(&1E;"!M96YS86IE('D@;&4@9&5V=65L=F4@82!L82`F
M(WA&03ML=&EM82!C87)P971A('%U92!E<W1A8F$@=FES=6%L:7IA;F1O"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB
M(&UD-3TB.#)C9C(T9#,Q838V-V$U8CDT930X,6-D-3$W.6,U,CDB('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4F5D86-C:28C>$8S.VX@9&5L(&UE
M;G-A:F4Z($ED96YT:61A9#PO=&ET;&4^"B`@("`\:&5A9&EN9SY)9&5N=&ED
M860\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-I(&5S="8C>$4Q.R!H86)I
M;&ET861O+"!P;V1R)B-X13$[(&5L96=I<B!M961I86YT92!U;F$@;&ES=&$@
M9&5S<&QE9V%B;&4@=6YA(&1E(&QA<R!I9&5N=&ED861E<R!I;G1R;V1U8VED
M87,@96X@/'%T/D]P8VEO;F5S+29G=#M);F9O<FUA8VDF(WA&,SMN('!E<G-O
M;F%L/"]Q=#XL(&\@<&]D<B8C>$4Q.R!I;G1R;V1U8VER(&5N('5N(&-A;7!O
M(&1E('1E>'1O(&QA(&1I<F5C8VDF(WA&,SMN(&1E(&-O<G)E;R!Q=64@9&5S
M964@=7-A<B!C;VUO(')E;6ET96YT92!D96P@;65N<V%J92X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M=&\B(&UD-3TB,S%C
M8F$Q-V8Q-CDU-S)C,S8W86$X,#$T.#,Q96(X9C@B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^4F5D86-C:28C>$8S.VX@9&5L(&UE;G-A:F4Z(%!A
M<F$\+W1I=&QE/@H@("`@/&AE861I;F<^4&%R83PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@26YT<F]D=7IC82!L82!D:7)E8V-I)B-X1C,[;B!D92!C;W)R
M96\@=B8C>$4Q.VQI9&$@9&5L(&1E<W1I;F%T87)I;R!D96P@;65N<V%J92X@
M4&%R82!I;G1R;V1U8VER('9A<FEO<R!D97-T:6YA=&%R:6]S+"!S97!A<F4@
M;&%S(&1I<F5C8VEO;F5S(&UE9&EA;G1E(&-O;6%S+B!%;"!U<V\@9&4@8W5A
M;'%U:65R(&]T<F\@<VEG;F\@9&4@<'5N='5A8VDF(WA&,SMN('!A<F$@<V5P
M87)A<B!V87)I87,@9&ER96-C:6]N97,@9&4@8V]R<F5O('!R;W9O8V%R)B-X
M13$[('5N(&5R<F]R+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UC8R(@;60U/2(Y-S4W,30S,V%B,#,W968Y8S1D,3`Q834V
M8F8W-&4R-2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y2961A8V-I
M)B-X1C,[;B!D96P@;65N<V%J93H@0V,\+W1I=&QE/@H@("`@/&AE861I;F<^
M0V,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EN=')O9'5Z8V$@;&$@9&ER
M96-C:28C>$8S.VX@9&4@8V]R<F5O('8F(WA%,3ML:61A(&1E;"!D97-T:6YA
M=&%R:6\@861I8VEO;F%L(&1E;"!M96YS86IE+B!087)A(&EN=')O9'5C:7(@
M=F%R:6]S(&1E<W1I;F%T87)I;W,L('-E<&%R92!L87,@9&ER96-C:6]N97,@
M;65D:6%N=&4@8V]M87,N($5L('5S;R!D92!C=6%L<75I97(@;W1R;R!S:6=N
M;R!D92!P=6YT=6%C:28C>$8S.VX@<&%R82!S97!A<F%R('9A<FEA<R!D:7)E
M8V-I;VYE<R!D92!C;W)R96\@<')O=F]C87(F(WA%,3L@=6X@97)R;W(N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@($QA<R!C;W!I87,@<V4@<W5E;&5N
M(&5N=FEA<B!A(&1E<W1I;F%T87)I;W,@<75E(&YO('1I96YE;B!P;W(@<74F
M(WA%.3L@<V5R(&QO<R!D97-T:6YA=&%R:6]S(&1I<F5C=&]S(&1E;"!M96YS
M86IE+"!P97)O('%U92!P<F5C:7-E;B!R96-I8FER;&\@8V]M;R!I;F9O<FUA
M8VDF(WA&,SMN+"!G96YE<F%L;65N=&4@<&]R('%U92!E<W0F(WA%.3MN(&EN
M9&ER96-T86UE;G1E(&EN=&5R97-A9&]S(&5N(&5L(&%S=6YT;R!D96P@8V]R
M<F5O+B!4;V1O<R!L;W,@9&5S=&EN871A<FEO<R`B4&%R83HB('D@(D-C.B(@
M<'5E9&5N('9E<B!L82!L:7-T82!C;VUP;&5T82!D92!A;6)O<R!T:7!O<R!D
M92!D97-T:6YA=&%R:6]S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UB8V,B(&UD-3TB86$X9CEE,F0T-&9D8C<T9&5F,&9A
M,34R-#!F9C8X-V(B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4F5D
M86-C:28C>$8S.VX@9&5L(&UE;G-A:F4Z($)C8SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY"8V,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EN=')O9'5Z8V$@
M;&$@9&ER96-C:28C>$8S.VX@9&4@8V]R<F5O('8F(WA%,3ML:61A(&1E;"!D
M97-T:6YA=&%R:6\@861I8VEO;F%L(&]C=6QT;R!D96P@;65N<V%J92X@4&%R
M82!I;G1R;V1U8VER('9A<FEO<R!D97-T:6YA=&%R:6]S+"!S97!A<F4@;&%S
M(&1I<F5C8VEO;F5S(&UE9&EA;G1E(&-O;6%S+B!%;"!U<V\@9&4@8W5A;'%U
M:65R(&]T<F\@<VEG;F\@9&4@<'5N='5A8VDF(WA&,SMN('!A<F$@<V5P87)A
M<B!V87)I87,@9&ER96-C:6]N97,@9&4@8V]R<F5O('!R;W9O8V%R)B-X13$[
M('5N(&5R<F]R+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!,87,@8V]P
M:6%S(&]C=6QT87,@<V4@<W5E;&5N(&5N=FEA<B!A(&1E<W1I;F%T87)I;W,@
M<75E('!U961A;B!N96-E<VET87(@;&5E<B!L;R!Q=64@<V4@:&%Y82!E<V-R
M:71O(%-)3B!Q=64@96P@<F5S=&\@9&4@;&]S(&1E<W1I;F%T87)I;W,@<V5P
M86X@<75E('1A;6)I)B-X13D[;B!H86X@<F5C:6)I9&\@96P@;65N<V%J92X@
M07,F(WA%1#L@(F]C=6QT82(@<VEG;FEF:6-A('%U92!L82!I9&5N=&ED860@
M9&4@97-T;W,@9&5S=&EN871A<FEO<R!S92!L97,@;V-U;'1A(&%L(')E<W1O
M(&1E(&QO<R!D97-T:6YA=&%R:6]S(&1E;"!C;W)R96\N(%,F(WA&,SML;R!E
M;"!R96UI=&5N=&4@>2!L;W,@9&5S=&EN871A<FEO<R`B0F-C(B!S86)R)B-X
M13$[;B!Q=64@:&%N(')E8VEB:61O('5N82!C;W!I82X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<W5B:F5C="(@;60U/2(P
M-C,Y83@W.3!E,S`V86-C.64Q.6(T9#%C93,T,F0U,R(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y2961A8V-I)B-X1C,[;B!D96P@;65N<V%J93H@
M07-U;G1O/"]T:71L93X*("`@(#QH96%D:6YG/D%S=6YT;SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@26YT<F]D=7IC82!E;"!A<W5N=&\@9&5L(&UE;G-A
M:F4N($5S(&-O;G9E;FEE;G1E('%U92!S96$@8V]R=&\L('-I;7!L92!Y(&1E
M<V-R:7!T:79O+B!,82!L)B-X140[;F5A(&1E(&%S=6YT;R!E<R!L82!M86YE
M<F$@;28C>$4Q.W,@<V5N8VEL;&$@9&4@<F5C;W)D87(@96P@8V]N=&5N:61O
M(&1E('5N(&UE;G-A:F4@<&]R(&QO('%U92!E<R!M=7D@:6UP;W)T86YT92!E
M;B!L82!O<F=A;FEZ86-I)B-X1C,[;B!D96P@8V]R<F5O('D@96X@;&$@<&]S
M=&5R:6]R(&QO8V%L:7IA8VDF(WA&,SMN(&1E(&QO<R!M96YS86IE<R!I;7!O
M<G1A;G1E<RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@061E;28C>$4Q
M.W,L('-I(")297-P;VYD92(@;R`B4F5E;G8F(WA%1#MA(B!U;B!M96YS86IE
M+"!L82!L)B-X140[;F5A(&1E(&%S=6YT;R!S92!C;W!I82!E;B!E;"!N=65V
M;R!M96YS86IE(&1E(&9O<FUA('%U92!S92!C;VYV:65R=&4@96X@=6YA('9A
M;&EO<V$@;6%N97)A(&1E(&ED96YT:69I8V%R('%U)B-X13D[(&UE;G-A:F5S
M('-E(&%G<G5P86X@<&%R82!F;W)M87(@=6YA(")S96-U96YC:6$B(&1E('5N
M82!C;VYV97)S86-I)B-X1C,[;B!P;W(@8V]R<F5O+B!#;VUO('-U9V5R96YC
M:6$L('-I('5N82!R97-P=65S=&$@;R!M96YS86IE(')E96YV:6%D;R!C;VYT
M:65N92!I9&5A<R!N=65V87,L('!U961E('-E<B!C;VYV96YI96YT92!A;'1E
M<F%R(&QI9V5R86UE;G1E(&QA(&PF(WA%1#MN96$@9&4@(D%S=6YT;R(@9&4@
M9F]R;6$@<75E(&QO<R!D97-T:6YA=&%R:6]S('!U961A;B!S96=U:7(@;&$@
M<')O9W)E<VDF(WA&,SMN(&1E(&QA(")S96-U96YC:6$B+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO<'1I;VYS(B!M9#4]
M(C5F,60U,&$W,S-C.&(W930V865C96-E,C@X,C)F9C<P(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/E)E9&%C8VDF(WA&,SMN(&1E;"!M96YS86IE
M.B!/<&-I;VYE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/<&-I;VYE<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@17-T87,@;W!C:6]N97,@;&4@87EU9&%N
M(&$@<')E<&%R87(@96P@;65N<V%J92X*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@4'5L<V4@(D-O<G)E8V-I)B-X1C,[;B!O<G1O9W(F(WA%,3MF:6-A
M(B!P87)A(&-O;7!R;V)A<B!L82!O<G1O9W)A9B8C>$5$.V$N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@(%!U;'-E(")!9&IU;G1O<R(@<&%R82!I<B!A
M(&QA('!A<G1E(&EN9F5R:6]R(&1E(&QA('`F(WA%,3MG:6YA(&1O;F1E('!U
M961E(&%D:G5N=&%R(&%R8VAI=F]S(&%L(&UE;G-A:F4N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@(%-I(&5L(&%D;6EN:7-T<F%D;W(@:&$@:&%B:6QI
M=&%D;R!L82!C;VYS97)V86-I)B-X1C,[;B!D96P@8V]R<F5O(&5N=FEA9&\L
M('!O9'(F(WA%,3L@86-T:79A<B!L82!C87-I;&QA(&IU;G1O(&$@(D=U87)D
M87(@=6YA(&-O<&EA(B!P87)A(&-O;G-E<G9A<B!U;F$@8V]P:6$@9&5L(&UE
M;G-A:F4@<75E('9A(&$@96YV:6%R+B!,82!C87)P971A(&1E(&1E<W1I;F\@
M<V5R)B-X13$[(&QA(&-A<G!E=&$@<&]R(&]M:7-I)B-X1C,[;B!O(&%Q=65L
M;&$@<75E(&AA>6$@<V5L96-C:6]N861O('!A<F$@97-T92!P<F]P)B-X1C,[
M<VET;R!E;B`B3W!C:6]N97,M)F=T.TEN9F]R;6%C:28C>$8S.VX@<&5R<V]N
M86PM)F=T.TED96YT:61A9&5S(BX@4VD@96P@861M:6YI<W1R861O<B!H82!H
M86)I;&ET861O(&QA('-E;&5C8VDF(WA&,SMN(&1E(&1E<W1I;F\@9&5L(&-O
M<G)E;R!E;G9I861O+"!P;V1R)B-X13$[(&5L96=I<B!U;F$@8V%R<&5T82!D
M92!U;F$@;&ES=&$@9&5S<&QE9V%B;&4@:G5N=&\@82!E<W1A(&]P8VDF(WA&
M,SMN+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!;&UA8V5N87(@8V]P
M:6%S(&1E(&QO<R!C;W)R96]S(&EM<&]R=&%N=&5S('%U92!E;G8F(WA%1#ME
M('!U961E(')E<W5L=&%R("8C>$9!.W1I;"!P87)A(&UA;G1E;F5R<V4@86P@
M=&%N=&\@9&4@;&\@<75E('-E(&AA(&1I8VAO+B!0=65D92P@;F\@;V)S=&%N
M=&4L(")A8W1I=F%R(B!E<W1A(&]P8VDF(WA&,SMN('!O<B!O;6ES:28C>$8S
M.VX@<&%R82!S=2!I9&5N=&ED860@96X@(D]P8VEO;F5S+29G=#M);F9O<FUA
M8VDF(WA&,SMN('!E<G-O;F%L+29G=#M-;V1I9FEC87(@:61E;G1I9&%D(BX@
M16X@;&%S(&]P8VEO;F5S('1A;6)I)B-X13D[;B!S92!P=65D96X@97-T86)L
M96-E<B!T87)E87,@9&4@;6%N=&5N:6UI96YT;R!Q=64@=F%C)B-X140[96X@
M;R!R96YO;6)R96X@97-T87,@8V%R<&5T87,@9&4@9F]R;6$@<&5R:28C>$8S
M.V1I8V$N"B`@("`\+W!A<F$^"B`@("`\=V%R;CX*("`@(%!U961E('%U92!N
M;R!D97-E92!A;&UA8V5N87(@=&]D;W,@>2!C861A('5N;R!D92!L;W,@8V]R
M<F5O<R!Q=64@96YV)B-X140[92!P=65S=&\@<75E('!O9'(F(WA%1#MA('1E
M;F5R('!R;V)L96UA<R!C;VX@96P@<B8C>$4Q.W!I9&\@86=O=&%M:65N=&\@
M9&5L(&5S<&%C:6\@87-I9VYA9&\@96X@9&ES8V\L('-O8G)E('1O9&\@86P@
M96YV:6%R(&%D:G5N=&]S(&1E(&=R86X@=&%M828C>$8Q.V\N(%5N(&)U>B8C
M>$8S.VX@<75E(&AA>6$@86=O=&%D;R!E;"!E<W!A8VEO(&%S:6=N861O(&5N
M(&1I<V-O(&YO('!O9'(F(WA%,3L@<F5C:6)I<B!C;W)R96\@;G5E=F\N"B`@
M("`\+W=A<FX^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C
M:"(@;60U/2)E.#`V935E,38T,69B,C4S,6-C.35D,F1F,C<W.#4Q9B(@<W1A
M=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y2961A8V-I)B-X1C,[;B!D96P@
M;65N<V%J93H@061J=6YT;W,\+W1I=&QE/@H@("`@/&AE861I;F<^061J=6YT
M;W,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%!U961E(&%D:G5N=&%R(&%R
M8VAI=F]S(&$@;&]S(&UE;G-A:F5S('-I(&5L(&YA=F5G861O<B!S;W!O<G1A
M(&QA(&-A<F=A(&1E(&%R8VAI=F]S+B!392!P=65D92!C87)G87(@;28C>$4Q
M.W,@9&4@=6X@87)C:&EV;R!C861A('9E>BX*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@4&%S;R`Q.B!":65N(&5S8W)I8F$@;&$@=B8C>$5$.V$@9&4@
M86-C97-O('D@;F]M8G)E(&1E;"!A<F-H:79O('%U92!Q=6EE<F$@861J=6YT
M87(@86P@;65N<V%J92!O('!U;'-E(&5L(&)O="8C>$8S.VX@(D5X86UI;F%R
M(B!Y('-E;&5C8VEO;F4@96P@87)C:&EV;R!Q=64@9&5S964@861J=6YT87(N
M($QA('8F(WA%1#MA(&1E(&%C8V5S;R!Y(&YO;6)R92!D96P@87)C:&EV;R!A
M<&%R96-E<B8C>$4Q.VX@96X@96P@<F5C=6%D<F\@9&4@861J=6YT;W,N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%!A<V\@,CH@16QI:F$@<VD@9&5S
M96$@<75E(&5L(&%R8VAI=F\@<V4@=F5A(&-O;6\@=6X@861J=6YT;R!O(&1I
M<F5C=&%M96YT92!E;B!L)B-X140[;F5A(&5N(&5L(&-U97)P;R!D96P@;65N
M<V%J92X@16P@8VQI96YT92!D92!C;W)R96\@9&5L(&1E<W1I;F%T87)I;R!T
M96YD<B8C>$4Q.R!Q=64@<&]D97(@;6%N96IA<B!L82!V:7-U86QI>F%C:28C
M>$8S.VX@96X@;"8C>$5$.VYE82!D96P@=&EP;R!D92!A<F-H:79O(&%D:G5N
M=&%D;R!O(&1E(&QO(&-O;G1R87)I;R!L;R!V97(F(WA%,3L@8V]M;R!U;B!A
M9&IU;G1O+@H@("`@/"]P87)A/@H@("`@/'1I<#X*("`@(%1E;F=A(&5N(&-U
M96YT82!Q=64@96X@96P@8V%S;R!D92!A<F-H:79O<R!G<F%N9&5S(&\@8V]N
M97AI;VYE<R!A($EN=&5R;F5T(&QE;G1A<RP@96P@<')O8V5S;R!D92!C87)G
M82!Y(&%D:G5N=&%D;R!D96P@87)C:&EV;R!A;"!M96YS86IE('!U961E(&QL
M979A<B!B87-T86YT92!T:65M<&\N(%1E;F=A('!A8VEE;F-I82!Y(&YO('!U
M;'-E(&]T<F]S('8F(WA%1#MN8W5L;W,@;R!B;W1O;F5S(&UI96YT<F%S(&5S
M="8C>$4Y.R!E<W!E<F%N9&\@;&$@8V%R9V$@9&4@=6X@87)C:&EV;RX*("`@
M(#PO=&EP/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM
M96YT<R(@;60U/2(X86,P,S)C-&%C,3@R9C-F,&0V-#0V8S(P9C`P.#ED9"(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y2961A8V-I)B-X1C,[;B!D
M96P@;65N<V%J93H@061J=6YT;W,\+W1I=&QE/@H@("`@/&AE861I;F<^061J
M=6YT;W,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5S=&$@<V5C8VDF(WA&
M,SMN(&UU97-T<F$@=6X@;&ES=&%D;R!D92!A<F-H:79O<R!Y82!A9&IU;G1A
M9&]S(&%L(&UE;G-A:F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;&EM
M:6YA<B!A<F-H:79O<R!A9&IU;G1O<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@4&%R82!B;W)R87(@87)C:&EV;W,@861J=6YT;W,Z"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@(%!A<V\@,3H@06-T:79E(&QA(&-A<VEL;&$@(D5L
M:6UI;F%R(B!D96P@87)C:&EV;R!A9&IU;G1O('%U92!D97-E82!E;&EM:6YA
M<BX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4&%S;R`R.B!0=6QS92`B
M06-T=6%L:7IA<B!I;F9O<FUA8VDF(WA&,SMN(&1E(&%D:G5N=&]S(BX*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D-A;6)I87(@;&$@9&ES<&]S:6-I)B-X
M1C,[;B!D92!L;W,@861J=6YT;W,\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%!A<F$@8V%M8FEA<B!L82!D:7-P;W-I8VDF(WA&,SMN(&1E(&QO<R!A9&IU
M;G1O<SH*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4&%S;R`Q.B!#86UB
M:64@;&$@9&ES<&]S:6-I)B-X1C,[;B!D92!C861A(&%D:G5N=&\@86P@=F%L
M;W(@9&5S96%D;SH@(D5N(&PF(WA%1#MN96$B(&\@(D%D:G5N=&\B+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("!087-O(#(Z(%!U;'-E(")!8W1U86QI
M>F%R(&EN9F]R;6%C:28C>$8S.VX@9&4@861J=6YT;W,B+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^0V%M8FEA<B!L82!D97-C<FEP8VDF(WA&,SMN(&1E
M(&QO<R!A9&IU;G1O<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4&%R82!C
M86UB:6%R(&QA(&1E<V-R:7!C:28C>$8S.VX@9&4@;&]S(&%D:G5N=&]S("AE
M;"!T97AT;R!Q=64@=F5R)B-X13$[(&5L(&1E<W1I;F%T87)I;R!D97-C<FEB
M:65N9&\@96P@861J=6YT;RDZ"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M(%!A<V\@,3H@26YT<F]D=7IC82!U;F$@9&5S8W)I<&-I)B-X1C,[;B!E;B!E
M;"!C86UP;R!D92!$97-C<FEP8VDF(WA&,SMN+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!087-O(#(Z(%!U;'-E(")!8W1U86QI>F%R(&EN9F]R;6%C
M:28C>$8S.VX@9&4@861J=6YT;W,B+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB8V]M<&]S92UP<FEO<FET>2(@;60U/2)B,#(S,S8W8S,V
M9&4S8V4Q-38W9#(W8V-A830U-C0P8R(@<W1A=&4](G5P=&]D871E(CX*("`@
M(#QT:71L93Y2961A8V-I)B-X1C,[;B!D96P@;65N<V%J93H@4')I;W)I9&%D
M/"]T:71L93X*("`@(#QH96%D:6YG/E!R:6]R:61A9#PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@)B-X0SD[<W1O(&5S=&%B;&5C92!L82!C86)E8V5R82`B
M6"U0<FEO<FET>2(@9&5L(&UE;G-A:F4@82!E;G9I87(N($QA(&5T:7%U971A
M(")8+5!R:6]R:71Y(B!E<R!U;B!T:7!O(&1E(")P<V5U9&\@97-T)B-X13$[
M;F1A<B(@<75E(&QA(&UA>6]R)B-X140[82!D92!L;W,@8VQI96YT97,@9&4@
M8V]R<F5O(&%C97!T86X@*$YE='-C87!E+"!-;WII;&QA+"!/<&5R82P@3W5T
M;&]O:RDN($-U86QQ=6EE<B!C;&EE;G1E(&1E(&-O<G)E;R!Q=64@;F\@;&$@
M9V5S=&EO;F4@<VEM<&QE;65N=&4@;&$@:6=N;W)A<B8C>$4Q.RX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<V%V92UA='1A
M8VAM96YT<R(@;60U/2)D8C@Y.3<R8S1E8F(P8C0Q86(V.3%B-F$W-S0T83@Q
M9"(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y2961A8V-I)B-X1C,[
M;B!D96P@;65N<V%J93H@1W5A<F1A<B!A9&IU;G1O<SPO=&ET;&4^"B`@("`\
M<&%R83X*("`@($1E=&5R;6EN82!S:2!L;W,@861J=6YT;W,@9&5L(&UE;G-A
M:F4@<V4@9W5A<F1A<B8C>$4Q.VX@8V]N(&5L(&UI<VUO(&5N(&QA(&-A<G!E
M=&$@9&4@8V]R<F5O(&5N=FEA9&\N(%-I('-E('-E;&5C8VEO;F$@(E,F(WA%
M1#LB+"!S92!G=6%R9&%R)B-X13$[;B!L;W,@9&%T;W,@9&4@;&]S(&%D:G5N
M=&]S+B!3:2!S92!S96QE8V-I;VYA(").;R(L(&QO<R!D871O<R!D92!L;W,@
M861J=6YT;W,@<V4@96QI;6EN87(F(WA%,3MN(&1E;"!M96YS86IE('1R87,@
M96YV:6%R;&\@82!L;W,@9&5S=&EN871A<FEO<RX@4V5L96-C:6]N87(@(DYO
M(B!L92!A>75D87(F(WA%,3L@82!C;VYS97)V87(@96P@97-P86-I;R!D92!D
M:7-C;R!A;"!E;&EM:6YA<B!L82!I;F9O<FUA8VDF(WA&,SMN(&1E(&QO<R!A
M9&IU;G1O<R`H<&]T96YC:6%L;65N=&4@9W)A;F1E*2!D92!L;W,@;65N<V%J
M97,@86QM86-E;F%D;W,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)C;VUP;W-E+6QI;FLM871T86-H;65N=',B('-T871E/2)U<'1O9&%T
M92(@;60U/2)A-V)B,#0Q,F(P,S-A8F1B8F$R9C4U8CAB.#1D-F,W-B(^"B`@
M("`\=&ET;&4^4F5D86-C:28C>$8S.VX@9&5L(&UE;G-A:F4Z($%D:G5N=&]S
M('9I;F-U;&%D;W,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F$@
M<VD@;&]S(&%D:G5N=&]S(&1E(&QA(')E9&%C8VDF(WA&,SMN('-E(&5N=FEA
M<B8C>$4Q.VX@8V]M;R!P87)T92!D96P@;65N<V%J92!O('-I('-E(&1E:F%R
M)B-X13$[;B!E;B!U;B!S97)V:61O<B!L;V-A;"X@4VD@;&]S(&%D:G5N=&]S
M('-E('9I;F-U;&%N+"!E;"]L;W,@9&5S=&EN871A<FEO*',I(&1E;"!M96YS
M86IE(&1I<W!O;F1R)B-X13$[;B!D92!U;B!V)B-X140[;F-U;&\@=V5B(&UE
M9&EA;G1E(&5L('%U92!P;V1R)B-X13$[;B!D97-C87)G87(@96PO;&]S(&%D
M:G5N=&\H<RDN($QO<R!A9&IU;G1O<R!V:6YC=6QA9&]S('1I96YE;B!L82!V
M96YT86IA(&1E(')E9'5C:7(@8V]N<VED97)A8FQE;65N=&4@96P@=&%M828C
M>$8Q.V\@9&4@;&]S(&UE;G-A:F5S(&5N=FEA9&]S+B!4:65N96X@;&$@9&5S
M=F5N=&%J82!D92!Q=64@;F\@<V4@<'5E9&4@9V%R86YT:7IA<B!Q=64@96P@
M8V]N=&5N:61O(&1E;"!A9&IU;G1O('-E(&UA;G1E;F=A(&1I<W!O;FEB;&4@
M96X@96P@9G5T=7)O('EA('%U92!L;W,@9&%T;W,@9&5L(&%D:G5N=&\@;F\@
M97-T)B-X13$[;B!I;F-L=6ED;W,@96X@96P@:6YT97)I;W(@9&5L(&UE;G-A
M:F4@9&4@8V]R<F5O+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<V5A<F-H(B!M9#4](C@V8C)E9C4W8C$Q.30X.3`X,S-D.61D-#EE8F,Y
M8C,R(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D(F(WA&03MS<75E
M9&$@9&4@;65N<V%J97,\+W1I=&QE/@H@("`@/&AE861I;F<^0W)I=&5R:6\@
M9&4@8B8C>$9!.W-Q=65D83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4'5E
M9&4@8G5S8V%R(&UE;G-A:F5S(&5N(&QA<R!C87)P971A<R!M961I86YT92!D
M:7-T:6YT;W,@8W)I=&5R:6]S(&1E(&(F(WA&03MS<75E9&$N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@("`@("!087-O(#$Z($EN=')O9'5Z8V$@=&5X
M=&\@96X@;&]S(&-A;7!O<R!Q=64@9&5S964@828C>$8Q.V%D:7(@86P@8W)I
M=&5R:6\@9&4@8B8C>$9!.W-Q=65D82X*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@("`@(%!A<V\@,CH@16QI:F$@;&$H<RD@8F%N9&5R82AS*2!D92!M
M96YS86IE<R!Q=64@9&5S964@828C>$8Q.V%D:7(@86P@8W)I=&5R:6\N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@("!087-O(#,Z($5L:6IA(&QA
M*',I(&-A<G!E=&$H<RD@96X@;&$H<RD@<75E(&1E<V5E(&)U<V-A<BX*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@("`@(%!A<V\@-#H@4'5L<V4@(D)U
M<V-A<B(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-I(&%L9R8C>$9!
M.VX@;65N<V%J92!C=6UP;&4@96P@8W)I=&5R:6\@9&4@8B8C>$9!.W-Q=65D
M82P@;&]S(&%S=6YT;W,@9&4@97-O<R!M96YS86IE<R!S92!M;W-T<F%R)B-X
M13$[;B!E;B!L82!V:7-T82!D92`B4F5S=6QT861O<R!D92!L82!B)B-X1D$[
M<W%U961A(@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]L
M9&5R+6]P=&EO;G,B(&UD-3TB,S`V.#=E8S0W-3<V-6)A-#0V-V0R968V9&-E
M8S0P8S,B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^1V5S=&DF(WA&
M,SMN(&1E(&-A<G!E=&%S.B!/<&-I;VYE<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY/<&-I;VYE<R!D92!C87)P971A<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@("!0=65D92!S96QE8V-I;VYA<B!U;F$@8V%R<&5T82!M961I86YT92!E
M;"!B;W0F(WA&,SMN(&1E('-E;&5C8VDF(WA&,SMN(&1E(&QA(&EZ<75I97)D
M82X@56YA('9E>B!L;R!H87EA(&AE8VAO+"!E;&EJ82!L82!O<&-I)B-X1C,[
M;B!Q=64@9&5S964@<F5A;&EZ87(@96X@;&$@8V%R<&5T82!M961I86YT92!L
M82!L:7-T82!D97-P;&5G86)L92!D92!O<&-I;VYE<RX*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@("!392!L92!P961I<B8C>$4Q.VX@;W1R;W,@9&%T
M;W,N("8C>$$Q.U1E;F=A(&-U:61A9&\@8V]N(&QA(&]P8VDF(WA&,SMN($5L
M:6UI;F%R('EA('%U92!P=65D92!P97)D97(@=&]D;W,@;&]S(&UE;G-A:F5S
M(&1E('5N82!C87)P971A('-I(&QA(&)O<G)A('!O<B!E<G)O<B$*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/DEM<&]R=&%R(&%R8VAI=F\@;6)O>#PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("!%<W1A(&]P8VDF(WA&,SMN(&EM<&]R
M=&%R)B-X13$[(&$@;&$@8V%R<&5T82!D92!S=2!E;&5C8VDF(WA&,SMN('5N
M(&%R8VAI=F\@9&4@9F]R;6%T;R!M8F]X+B!396QE8V-I;VYE(#$@*'5N82D@
M8V%R<&5T82!A(&QA('%U92!I;7!O<G1A<B!L;W,@;65N<V%J97,@>2!E;&EJ
M82!E<W1A(&]P8VDF(WA&,SMN+B!392!L92!M;W-T<F%R)B-X13$[('5N82!P
M)B-X13$[9VEN82!Q=64@;&4@<&5D:7(F(WA%,3L@<75E(&EN9&EQ=64@96P@
M87)C:&EV;R!M8F]X('%U92!D97-E92!I;7!O<G1A<BX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUW:61G971S(B!M9#4](F(Y
M8F,V.#DT,#)F-S4W-3<W,60W-#4W,&4W9C9F.#!A(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/D=E<W1I)B-X1C,[;B!D92!C87)P971A<SH@36]S
M=')A<CPO=&ET;&4^"B`@("`\:&5A9&EN9SY-;W-T<F%R+T]C=6QT87(@;F\@
M<W5S8W)I=&]S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3:2!S92!U=&EL
M:7IA(&QA('-U<V-R:7!C:28C>$8S.VX@82!C87)P971A<R!M961I86YT92!)
M34%0+"!M=65S=')A+V]C=6QT82!L87,@8V%R<&5T87,@;F\@<W5S8W)I=&%S
M+B!087)A('-U<V-R:6)I<G-E+V1E<W5S8W)I8FER<V4@82!U;F$@8V%R<&5T
M82P@<V5L96-C:6]N92!L82!C87-I;&QA(&1E('9E<FEF:6-A8VDF(WA&,SMN
M(&IU;G1O(&%L(&YO;6)R92!D92!L82!C87)P971A('D@=71I;&EC92!L82!O
M<&-I)B-X1C,[;B!3=7-C<FEB:7(O1&5S=7-C<FEB:7(@9&5L(&UE;B8C>$9!
M.R!D97-P;&5G86)L92!D92!!8V-I;VYE<R!D92!C87)P971A<RX*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9&ER('1O9&%S/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!%>'!A;F1E('1O9&%S(&QA<R!C87)P971A<RX*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D-O;&%P<V%R('1O9&%S/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#;VQA<'-A('1O9&%S(&QA<R!C87)P971A<RX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<G,B(&UD
M-3TB-65F-C`W.#8W-C=E-C,X9F)F-6)A.&9C-6)D-60Y9#(B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^1FEL=')O<SH@07!L:6-A<CPO=&ET;&4^
M"B`@("`\:&5A9&EN9SY!<&QI8V%R(')E9VQA<R!D92!F:6QT<F%D;SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@4'5L<V4@96P@:6-O;F\@(D%P;&EC87(@
M9FEL=')O<R(@:G5N=&\@86P@;F]M8G)E(&1E;"!B=7HF(WA&,SMN(&1E($5.
M5%)!1$$@96X@;&$@=FES=&$@9&4@8G5Z;VYE<R!P87)A(&9I;'1R87(@=&]D
M;W,@;&]S(&UE;G-A:F5S(&-O;F9O<FUE(&$@;&%S(')E9VQA<R!E<W!E8VEF
M:6-A9&%S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL
M=&5R+65D:70M<G5L97,B(&UD-3TB-6)A834W,#AA8SDT-#EE-SDW9CDV-S,Q
M,V$Y93%A,C<B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^1FEL=')O
M<SH@36]D:69I8V%R(&QA<R!R96=L87,@9&4@9FEL=')A9&\\+W1I=&QE/@H@
M("`@/&AE861I;F<^36]D:69I8V%R(&QA<R!R96=L87,@9&4@9FEL=')A9&\\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%!U;'-E(")-;V1I9FEC87(@;&%S
M(')E9VQA<R!D92!F:6QT<F%D;R(@<&%R82!P87-A<B!A(&QA('`F(WA%,3MG
M:6YA(&5N(&QA('%U92!P=65D92!A)B-X1C$[861I<BP@96QI;6EN87(@>2!M
M;V1I9FEC87(@96P@8V]N:G5N=&\@86-T:79O(&1E(')E9VQA<R!D92!F:6QT
M<F%D;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E
M<BUE9&ET+6)L86-K;&ES="(@;60U/2(X,&9F-S@P,V,V-C4Y.6,W,#,U9C=F
M.#@Q,60R,3AC8R(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y&:6QT
M<F]S.B!-;V1I9FEC87(@;&$@;&ES=&$@;F5G<F$\+W1I=&QE/@H@("`@/&AE
M861I;F<^36]D:69I8V%R(&QA(&QI<W1A(&YE9W)A/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!0=6QS92`B36]D:69I8V%R(&QA(&QI<W1A(&YE9W)A(B!P
M87)A('!A<V%R(&$@;&$@<"8C>$4Q.V=I;F$@96X@;&$@<75E('!U961E(&$F
M(WA&,3MA9&ER+"!E;&EM:6YA<B!Y(&UO9&EF:6-A<B!L82!L:7-T82!D92!D
M:7)E8V-I;VYE<R!D92!C;W)R96\@9&4@;&%S('%U92!3245-4%)%('9A(&$@
M<F5C:&%Z87(@;&]S(&5N=B8C>$5$.V]S+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M=VAI=&5L:7-T(B!M9#4](C,S
M,&,S83AF860Q.3AC-V%F93@U-6,Q,#%C-C-C9#!F(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/D9I;'1R;W,Z($UO9&EF:6-A<B!L82!L:7-T82!B
M;&%N8V$\+W1I=&QE/@H@("`@/&AE861I;F<^36]D:69I8V%R(&QA(&QI<W1A
M(&)L86YC83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4'5L<V4@(DUO9&EF
M:6-A<B!L82!L:7-T82!B;&%N8V$B('!A<F$@<&%S87(@82!L82!P)B-X13$[
M9VEN82!E;B!L82!Q=64@<'5E9&4@828C>$8Q.V%D:7(L(&5L:6UI;F%R('D@
M;6]D:69I8V%R(&QA(&QI<W1A(&1E(&1I<F5C8VEO;F5S(&1E(&-O<G)E;R!D
M92!L87,@<75E(%-)14U04D4@=F$@82!A8V5P=&%R(&5N=B8C>$5$.V]S+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+6QO
M9VEN(B!M9#4](C,W9#DR.3=D,6-C830V-#,U93,V8C9E,SAE-#5D8V1B(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D9I;'1R;W,Z($9I;'1R87(@
M86P@:6YI8VEA<CPO=&ET;&4^"B`@("`\:&5A9&EN9SXF(WA"1CM!<&QI8V%R
M(')E9VQA<R!D92!F:6QT<F%D;R!A;"!I;FEC:6%R('-E<VDF(WA&,SMN/SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@06-T:79E(&5S=&$@;W!C:28C>$8S
M.VX@<&%R82!A<&QI8V%R('-I96UP<F4@;&]S(&9I;'1R;W,@86P@:6YI8VEA
M<B!S97-I)B-X1C,[;B!E;B!)35`N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)F:6QT97(M;VXM9&ES<&QA>2(@;60U/2)F-6%F8S,P-30P
M,F5F-3)B860Q,#@Y,S-F,V8S,S(Y,2(@<W1A=&4](G5P=&]D871E(CX*("`@
M(#QT:71L93Y&:6QT<F]S.B!&:6QT<F%R(&%L(')E9G)E<V-A<CPO=&ET;&4^
M"B`@("`\:&5A9&EN9SXF(WA"1CM!<&QI8V%R(')E9VQA<R!D92!F:6QT<F%D
M;R!A;"!V:7-U86QI>F%R(&QA(&-A<G!E=&$@9&4@14Y44D%$03\\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($%C=&EV92!E<W1A(&]P8VDF(WA&,SMN('!A
M<F$@87!L:6-A<B!L;W,@9FEL=')O<R!S:65M<')E('%U92!V96$@;&$@8V%R
M<&5T82!D92!%;G1R861A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB9FEL=&5R+6%N>2UM86EL8F]X(B!M9#4](C<Q8S4Q93@S.3`Y9CED
M,&)D-#0P9#(R,#<W,F5E,V,V(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/D9I;'1R;W,Z($9I;'1R87(@8W5A;'%U:65R(&)U>B8C>$8S.VX\+W1I
M=&QE/@H@("`@/&AE861I;F<^)B-X0D8[07!L:6-A<B!R96=L87,@9&4@9FEL
M=')A9&\@82!C=6%L<75I97(@8G5Z)B-X1C,[;C\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($%C=&EV92!E<W1A(&]P8VDF(WA&,SMN('-I(&1E<V5A(&%P
M;&EC87(@;&%S(')E9VQA<R!D92!F:6QT<F%D;R!A(&-U86QQ=6EE<B!B=7HF
M(WA&,SMN+B!.;W)M86QM96YT92!L87,@<F5G;&%S(&1E(&9I;'1R861O('-E
M(&%P;&EC86X@<R8C>$8S.VQO(&%L(&-O<G)E;R!N=65V;R!Q=64@;&QE9V$@
M82!L82!C87)P971A(&1E($5.5%)!1$$N(%-I('-E(&%C=&EV82!E<W1A(&]P
M8VDF(WA&,SMN+"!A<&%R96-E<B8C>$4Q.R!U;B!I8V]N;R!E;B!T;V1A<R!L
M87,@<"8C>$4Q.V=I;F%S(&1E(&)U>F]N97,@<75E(&QE('!E<FUI=&ER)B-X
M13$[(&%P;&EC87(@;&%S(')E9VQA<R!D92!F:6QT<F%D;R!A(&QO<R!M96YS
M86IE<R!D96P@8G5Z)B-X1C,[;B!A8W1U86PN($]"4T525D%#228C>$0S.TXZ
M($9I;'1R87(@;W1R;W,@8G5Z;VYE<R!D:7-T:6YT;W,@9&5L(&1E($5.5%)!
M1$$@<'5E9&4@<')O9'5C:7(@<F5S=6QT861O<R!E>'1R828C>$8Q.V]S("AP
M+F4N(&5L(&9I;'1R;R!P=65D92!H86-E<B!Q=64@<V4@96YV)B-X140[92!U
M;F$@8V]P:6$@86P@;6ES;6\@8G5Z)B-X1C,[;B!D92!L;W,@;65N<V%J97,@
M82!E;G9I87(I('DO;R!N;R!D97-E861O<R`H<"YE+B!P=65D92!O8V%S:6]N
M87(@<75E('-E('1R87-L861E;B!O(&5L:6UI;F5N(&UE;G-A:F5S('-I('-E
M(&AA;B!A)B-X1C$[861I9&\@;G5E=F%S(')E9VQA<R!D92!F:6QT<F%D;R!D
M97-P=28C>$4Y.W,@9&4@<75E('5N(&UE;G-A:F4@>6$@<V4@:&%B)B-X140[
M82!E;G9I861O(&%L(&)U>B8C>$8S.VX@86-T=6%L*2X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C:"UP=6)K
M97DB(&UD-3TB.3<T-#9D8F)B,C<V,39B-&9A,SEB93@P,64Q,&1F,F0B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0.B!!9&IU;G1A<B!C;&%V
M92!P)B-X1D$[8FQI8V$\+W1I=&QE/@H@("`@/&AE861I;F<^061J=6YT87(@
M8VQA=F4@<"8C>$9!.V)L:6-A/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3
M:2!S92!S96QE8V-I;VYA+"!S92!A9&IU;G1A<B8C>$4Q.R!A;"!M96YS86IE
M('5N82!C;W!I82!D92!L82!C;&%V92!01U`@<"8C>$9!.V)L:6-A+"!S:2!E
M>&ES=&4N(%-E('!U961E(&-O;F9I9W5R87(@96P@8V]M<&]R=&%M:65N=&\@
M<&]R(&]M:7-I)B-X1C,[;B!M961I86YT92!L82!P86YT86QL82!D92!O<&-I
M;VYE<R!01U`N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M;W!T:6]N+7-C86XM8F]D>2(@;60U/2(V8F%A861A,&0T-F1C,6%B,#DT
M,3`X-V8R,S5F,S4Y8B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y0
M1U`Z($%N86QI>F%R('1E>'1O(&1E;"!C=65R<&\\+W1I=&QE/@H@("`@/&AE
M861I;F<^06YA;&EZ87(@=&5X=&\@9&5L(&-U97)P;V\\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%-I('-E('-E;&5C8VEO;F$L($E-4"!B=7-C87(F(WA%
M,3L@9&%T;W,@4$=0(&5N(&5L(&-U97)P;R!D92!L;W,@;65N<V%J97,@9&4@
M=&5X=&\@>2!M;W-T<F%R)B-X13$[(&QO<R!R97-U;'1A9&]S('-I(&QO<R!E
M;F-U96YT<F$N($]B<V5R=F4@<75E("8C>$4Y.W-T;R!P=65D92!R86QE;G1I
M>F%R(&5L('-I<W1E;6$@>6$@<75E(&-A9&$@;65N<V%J92!T:65N92!Q=64@
M8V]M<')O8F%R<V4@96X@<W4@=&]T86QI9&%D+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO<'1I;VYS+65N8W)Y<'0B(&UD
M-3TB,3`Q,C$T-&8W-#EF,3EF-6$R-&-E9C,X-C`Q9&%A-S$B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^4F5D86-C:28C>$8S.VXZ($]P8VEO;F5S
M(&1E(&-I9G)A9&\\+W1I=&QE/@H@("`@/&AE861I;F<^4VEN(&-I9G)A<CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YV)B-X140[82!E;"!M96YS86IE
M('-I;B!C:69R861O("AT97AT;R!P;&%N;RDN"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY#:69R87(@;65N<V%J92!C;VX@4$=0/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!%<W1A(&]P8VDF(WA&,SMN(&-I9G)A<B8C>$4Q.R!E;"!M
M96YS86IE(&UE9&EA;G1E(%!'4"!Y(&QA(&-L879E('!E<G-O;F%L('`F(WA&
M03MB;&EC82!D96P@9&5S=&EN871A<FEO('D@;&\@96YV:6%R)B-X13$[+B!-
M961I86YT92!E<W1A(&]P8VDF(WA&,SMN(',F(WA&,SML;R!S92!P=65D92!E
M;G9I87(@96P@;65N<V%J92!A('5N("8C>$9!.VYI8V\@9&5S=&EN871A<FEO
M+B!4:65N92!Q=64@1$E34$].15(@9&4@;&$@8VQA=F4@<"8C>$9!.V)L:6-A
M(&1E;"!D97-T:6YA=&%R:6\@86QM86-E;F%D82!E;B!L82!L:6)R971A(&1E
M(&1I<F5C8VEO;F5S(&\@;&$@;W!C:28C>$8S.VX@9F%L;&%R)B-X13$[+B!3
M:2!D:7-P;VYE(&1E(&QA(&-L879E('`F(WA&03MB;&EC82!D96P@9&5S=&EN
M871A<FEO(&5N(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,@>2!S:6=U92!T
M96YI96YD;R!E<G)O<F5S+"!C;VUP<G5E8F4@<75E(&QA(&1I<F5C8VDF(WA&
M,SMN(&1E(&-O<G)E;R!E;&5C='(F(WA&,SMN:6-O(&1E;"!D97-T:6YA=&%R
M:6\@8V]I;F-I9&4@8V]N(&QA(&1I<F5C8VDF(WA&,SMN(&5N(&QA('%U92!E
M<W0F(WA%,3L@86QM86-E;F%D82!L82!C;&%V92!P)B-X1D$[8FQI8V$L($QO
M<R!D871O<R!C:69R861O<R!S92!A9&IU;G1A<B8C>$4Q.VX@86P@;65N<V%J
M92!D92!S86QI9&$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY-96YS86IE
M(&-O;B!F:7)M82!01U`\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5S=&$@
M;W!C:28C>$8S.VX@9FER;6%R)B-X13$[(&1I9VET86QM96YT92!E;"!M96YS
M86IE(&%C='5A;"!M961I86YT92!01U`@>2!S=2!C;&%V92!P97)S;VYA;"!P
M<FEV861A+B!3:2!A)B-X1D$[;B!N;R!H86(F(WA%1#MA(&EN=')O9'5C:61O
M(&QA(&9R87-E(&-L879E(&1E('-U(&-L879E('!E<G-O;F%L('!R:79A9&$@
M9'5R86YT92!L82!S97-I)B-X1C,[;B!A8W1U86PL('-E(&QE('!E9&ER)B-X
M13$[+B!%;"!D97-T:6YA=&%R:6\@=&EE;F4@<75E('1E;F5R('5N82!C;W!I
M82!D92!S=2!C;&%V92!P)B-X1D$[8FQI8V$@<&%R82!V97)I9FEC87(@9&EG
M:71A;&UE;G1E(&QA(&9I<FUA+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M365N<V%J92!F:7)M861O+V-I9G)A9&\@8V]N(%!'4#PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@17-T82!O<&-I)B-X1C,[;B!F:7)M87(F(WA%,3L@9&EG
M:71A;&UE;G1E(&5L(&UE;G-A:F4@96X@<')I;65R(&QU9V%R('D@;'5E9V\@
M8VEF<F%R)B-X13$[(&5L(')E<W5L=&%D;RX@0V]N<W5L=&4@;&]S(&%P87)T
M861O<R`B0VEF<F%R(&UE;G-A:F4@8V]N(%!'4"(@>2`B365N<V%J92!C;VX@
M9FER;6$@4$=0(B!P87)A(&TF(WA%,3MS(&EN9F]R;6%C:28C>$8S.VXN"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY-96YS86IE(&-I9G)A9&\@96X@4R]-
M24U%/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!03U(@2$%#15(*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/DUE;G-A:F4@8V]N(&9I<FUA(%,O34E-13PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4$]2($A!0T52"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY-96YS86IE(&9I<FUA9&\O8VEF<F%D;R!E;B!3+TU)
M344\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%!/4B!(04-%4@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]V97)V:65W(B!M9#4]
M(C(T8C4Q,SAB-&(U,V8W,V(U9C)F,C<S.64T8S$X-3AD(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@26YT<F]D=6-C:28C>$8S.VX\+W1I
M=&QE/@H@("`@/&AE861I;F<^)B-X0D8[474F(WA%.3L@97,@4$=0/SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@4$=0(&5S('5N82!H97)R86UI96YT82!P
M87)A(&-O;75N:6-A8VEO;F5S('D@86QM86-E;F%M:65N=&\@9&4@9&%T;W,@
M<V5G=7)O<RP@97-P96-I86QM96YT92!P87)A('-U('5S;R!C;VX@96P@8V]R
M<F5O(&5L96-T<B8C>$8S.VYI8V\N(%-E('!U961E('5T:6QI>F%R('!A<F$@
M8VEF<F%R(&1A=&]S('D@<&%R82!C<F5A<B!F:7)M87,@9&EG:71A;&5S+B!)
M35`@=71I;&EZ82!';G501R`H1TY5(%!R:79A8WD@1W5A<F0O1W5A<F1I)B-X
M13$[;B!D92!0<FEV86-I9&%D($=.52D@<&%R82!P<F]P;W)C:6]N87(@97-T
M82!F=6YC:6]N86QI9&%D+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^)B-X
M0D8[06-T:79A<B!L82!F=6YC:6]N86QI9&%D(%!'4#\\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%-I('-E('-E;&5C8VEO;F$@97-T82!O<&-I)B-X1C,[
M;BP@<&]D<B8C>$4Q.R!C<F5A<B]V97(@<W4@8VQA=F4@4$=0('!E<G-O;F%L
M+"!A)B-X1C$[861I<B]E;&EM:6YA<B!C;&%V97,@<"8C>$9!.V)L:6-A<R!D
M92!O=')A<R!P97)S;VYA<RP@;&5E<B!C;W)R96\@8VEF<F%D;RP@8V]M<')O
M8F%R(&-O<G)E;R!F:7)M861O(&1I9VET86QM96YT92!Y(&-I9G)A<B]F:7)M
M87(@96P@8V]R<F5O('%U92!E;G8F(WA%1#ME+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO;BUA='1A8V@M<'5B:V5Y(B!M
M9#4](C4V,6-E-#,S-S!A8S1A9F)C8S-F.3@Q.&,X9F)C,F8V(B!S=&%T93TB
M=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@3W!C:6]N97,@+2!!9&IU;G1A
M<B!C;&%V92!P)B-X1D$[8FQI8V$\+W1I=&QE/@H@("`@/&AE861I;F<^3W!C
M:6]N97,@+2!!9&IU;G1A<B!C;&%V92!P)B-X1D$[8FQI8V$\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%-I('-E('-E;&5C8VEO;F$L('!O<B!O;6ES:28C
M>$8S.VX@<V4@861J=6YT87(F(WA%,3L@82!L;W,@;65N<V%J97,@=6YA(&-O
M<&EA(&1E('-U(&-L879E(%!'4"!P)B-X1D$[8FQI8V$@<VD@;&$@=&EE;F4N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;6%N86=E
M+7!U8FME>2(@;60U/2)B,C@Y96$U.#(T8C=F-CEF,S5C,#<U,30Y-V8T93%C
M,R(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z($=E<W1I;VYA
M<B!C;&%V97,@<"8C>$9!.V)L:6-A<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY)
M;G1R;V1U8V-I)B-X1C,[;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17-T
M82!P86YT86QL82!E;G5M97)A('1O9&]S(&QO<R!U<W5A<FEO<R!A8W1U86QE
M<R!D92!S=2!L:6)R971A(&1E(&1I<F5C8VEO;F5S('%U92!T:65N96X@8VQA
M=F5S(%!'4"!P)B-X1D$[8FQI8V%S+B!%<V]S('5S=6%R:6]S('-O;B!L;W,@
M)B-X1$$[3DE#3U,@82!L;W,@<75E('!U961E(&5N=FEA<B!U;B!M96YS86IE
M(&-I9G)A9&\@;R!D92!L;W,@<75E('!U961E(&-O;7!R;V)A<B!L82!F:7)M
M82!D:6=I=&%L+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^5F5R/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!!8G)E('5N82!V96YT86YA('!A<F$@=FES
M=6%L:7IA<B!L82!C;&%V92!01U`@<"8C>$9!.V)L:6-A+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^1&5T86QL97,\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($UU97-T<F$@=F%R:6]S(&1E=&%L;&5S('-O8G)E(&QA(&-L879E(%!'
M4"!P)B-X1D$[8FQI8V$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;&EM
M:6YA<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16QI;6EN82!L82!C;&%V
M92!P)B-X1D$[8FQI8V$@9&4@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UI;7!O<G0M
M<'5B:V5Y(B!M9#4](C9E93$Q,S!B-#9E.69F,6-A.6%D,V$S830W93=B,S@R
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@1V5S=&EO;F%R
M(&-L879E<R!P)B-X1D$[8FQI8V%S("T@26UP;W)T87(\+W1I=&QE/@H@("`@
M/&AE861I;F<^26UP;W)T87(@8VQA=F5S('`F(WA&03MB;&EC87,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5S=&4@8F]T)B-X1C,[;B!A8G)I<B8C>$4Q
M.R!U;F$@=F5N=&%N82!E;B!L82!Q=64@<'5E9&4@:6UP;W)T87(@9&4@9F]R
M;6$@;6%N=6%L('5N82!C;&%V92!01U`@<"8C>$9!.V)L:6-A+B!,82!C;&%V
M92!S92!P=65D92!P96=A<B!E;B!U;B!C86UP;R!D92!T97AT;R!O+"!S:2!S
M92!E;F-U96YT<F$@96X@=6X@87)C:&EV;R!E;B!E;"!O<F1E;F%D;W(@;&]C
M86PL('!U961E(&EM<&]R=&%R;&$N(%-I(&QA(&-L879E(&5S('8F(WA%,3ML
M:61A('-E(&EN<V5R=&%R)B-X13$[(&5N(&QA(&QI8G)E=&$@9&4@9&ER96-C
M:6]N97,@>2!L82!V96YT86YA('-E(&-E<G)A<B8C>$4Q.SL@<VD@;F\@97,@
M=B8C>$4Q.VQI9&$@<V4@;6]S=')A<B8C>$4Q.R!U;B!M96YS86IE(&1E(&5R
M<F]R(&5X<&QI8V%N9&\@;&$@<F%Z)B-X1C,[;BX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R=FEE=RUP97)S;VYA;&ME>2(@
M;60U/2(R,C!A9C)B-S1A-3AF-#,P969D-S)D-F0V8C%F.3DS9B(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z($=E<W1I;VYA<B!C;&%V97,@
M<&5R<V]N86QE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY);G1R;V1U8V-I)B-X
M1C,[;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4VD@9&5S96$@9FER;6%R
M(&1I9VET86QM96YT92!M96YS86IE<R!O('!E<FUI=&ER('%U92!O=')O<R!L
M92!E;G8F(WA%1#ME;B!M96YS86IE<R!C:69R861O<RP@=&EE;F4@<75E(&1I
M<W!O;F5R(&1E('-U<R!P<F]P:6%S(&-L879E<R!01U`@<"8C>$9!.V)L:6-A
M+W!R:79A9&$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY,82!C;&%V92!P
M)B-X1D$[8FQI8V$\+VAE861I;F<^"B`@("`\<&%R83X*("`@($QA(&-L879E
M('`F(WA&03MB;&EC82!T:65N92!Q=64@<&]N97)L82!A(&1I<W!O<VEC:28C
M>$8S.VX@9&4@8W5A;'%U:65R('!E<G-O;F$@<75E(&1E<V5E('%U92!P=65D
M82!E;G9I87)L92!M96YS86IE<R!C:69R861O<R!Q=64@<R8C>$8S.VQO(%53
M5$5$('!O9'(F(WA%,3L@9&5S8VEF<F%R("AM961I86YT92!S=2!C;&%V92!P
M<FEV861A*2X@061E;28C>$4Q.W,L(&QA(&-L879E('`F(WA&03MB;&EC82!T
M:65N92!Q=64@97-T87(@9&ES<&]N:6)L92!P87)A('1O9&\@87%U96P@86P@
M<75E('%U:65R82!E;G9I87(@=6X@;65N<V%J92!F:7)M861O(&1I9VET86QM
M96YT92`M(&QA(&-L879E('`F(WA&03MB;&EC82!H86-E(&9A;'1A('!A<F$@
M8V]M<')O8F%R(&QA(&9I<FUA(&1I9VET86PN"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY,82!C;&%V92!P<FEV861A/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!,82!C;&%V92!P<FEV861A(&AA8V4@9F%L=&$@<&%R82!D97-C:69R
M87(@8W5A;'%U:65R(&UE;G-A:F4@8VEF<F%D;R!M961I86YT92!S=2!C;&%V
M92!P)B-X1D$[8FQI8V$N($%D96TF(WA%,3MS(&QA(&-L879E('!R:79A9&$@
M:&%C92!F86QT82!S:2!Q=6EE<F4@9FER;6%R(&1I9VET86QM96YT92!U;B!M
M96YS86IE+B!,82!C;&%V92!P<FEV861A('-E('!R;W1E9V5R)B-X13$[(&UE
M9&EA;G1E('5N82!F<F%S92!C;&%V92!C<F5A9&$@86P@9V5N97)A<B!L87,@
M8VQA=F5S('!O<B!L;R!Q=64L('!A<F$@<F5A;&EZ87(@8W5A;'%U:65R(&%C
M=&EV:61A9"!Q=64@<')E8VES92!L82!C;&%V92!P<FEV861A+"!)35`@;&4@
M<&5D:7(F(WA%,3L@;&$@9G)A<V4@8VQA=F4N(%,F(WA&,SML;R!T96YD<B8C
M>$4Q.R!Q=64@:6YT<F]D=6-I<FQA('5N82!V97H@<&]R('-E<VDF(WA&,SMN
M("T@24U0(&QA(&%L;6%C96YA<B8C>$4Q.R!H87-T82!Q=64@<V%L9V$@9&4@
M;&$@<V5S:28C>$8S.VX@*%!O<B!L;R!Q=64@)B-X03$[87-E9R8C>$9!.W)E
M<V4@9&4@<V%L:7(@9&4@;&$@<V5S:28C>$8S.VXA*2X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP=6)L:6,B
M(&UD-3TB,V,X-#1D-&9F.&9D9&$S93!D-#0V8C0W838S,3$W93`B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0.B!'97-T:6]N87(@8VQA=F5S
M('!E<G-O;F%L97,@+2!#;&%V92!P)B-X1D$[8FQI8V$\+W1I=&QE/@H@("`@
M/&AE861I;F<^5F5R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!8G)E('5N
M82!V96YT86YA('!A<F$@=FES=6%L:7IA<B!L82!C;&%V92!01U`@<"8C>$9!
M.V)L:6-A+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86QL97,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($UU97-T<F$@=F%R:6]S(&1E=&%L;&5S
M('-O8G)E(&QA(&-L879E(%!'4"!P)B-X1D$[8FQI8V$N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T
M92(@;60U/2(Q.#4Q8C8W83%A965F,3(T,F9C,V$R8CDT868W-6,P,R(@<W1A
M=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z($=E<W1I;VYA<B!C;&%V
M97,@<&5R<V]N86QE<R`M($-L879E('!R:79A9&$\+W1I=&QE/@H@("`@/&AE
M861I;F<^26YT<F]D=7IC82!L82!F<F%S92!C;&%V93PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@06)R92!E;"!C=6%D<F\@9&4@9&DF(WA%,3ML;V=O(&1E
M(&9R87-E(&-L879E+B!3:2!L82!F<F%S92!C;&%V92!I;G1R;V1U8VED82!E
M<R!C;W)R96-T82!S92!A;&UA8V5N87(F(WA%,3L@:&%S=&$@<75E('-E('1E
M<FUI;F4@;&$@<V5S:28C>$8S.VXN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY/;'9I9&%R(&9R87-E(&-L879E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!%;&EM:6YA(&QA(&9R87-E(&-L879E(&%L;6%C96YA9&$@+2!C=6%L<75I
M97(@=7-O(&%D:6-I;VYA;"!D92!L82!C;&%V92!P<FEV861A('!R96-I<V%R
M)B-X13$[(&QA(')E:6YT<F]D=6-C:28C>$8S.VX@9&4@;&$@9G)A<V4@8VQA
M=F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY697(\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($%B<F4@=6YA('9E;G1A;F$@<&%R82!V:7-U86QI>F%R
M(&QA(&-L879E(%!'4"!P<FEV861A+B!.3R!%3E8F(WA#1#M%($535$$@0TQ!
M5D4@02!.041)12`M(&5S=&$@;W!C:28C>$8S.VX@97,@97-T<FEC=&%M96YT
M92!S)B-X1C,[;&\@<&%R82!E>'!O<G1A<B!S=2!C;&%V92!P97)S;VYA;"!P
M<FEV861A(&1E($E-4"!P87)A('5S87)L82!E;B!O=')O('!R;V=R86UA+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86QL97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($UU97-T<F$@=F%R:6]S(&1E=&%L;&5S('-O8G)E(&QA
M(&-L879E(%!'4"!P<FEV861A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(@;60U/2)D8F0X8V)E
M-F)C93<Q8S1F8C4Y,F1D,6(S8C(W8C=C92(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93Y01U`Z($=E<W1I;VYA<B!C;&%V97,@<&5R<V]N86QE<R`M
M($5L:6UI;F%R/"]T:71L93X*("`@(#QH96%D:6YG/D5L:6UI;F%R(&-L879E
M<R!P97)S;VYA;&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%<W1E(&)O
M="8C>$8S.VX@96QI;6EN87(F(WA%,3L@;&%S(&-L879E<R!P97)S;VYA;&5S
M('`F(WA&03MB;&EC82]P<FEV861A(&1E(&QA<R!P<F5F97)E;F-I87,@9&4@
M24U0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E
M<G-O;F%L:V5Y+6-R96%T92UN86UE(B!M9#4](C<T.&-B,3(T8C=F9C4R.#(P
M-SDR93(W.#`S-V$X8S(W(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/E!'4#H@0W)E87(@8VQA=F5S('!E<G-O;F%L97,@+2!.;VUB<F4\+W1I=&QE
M/@H@("`@/&AE861I;F<^4W4@;F]M8G)E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%<R!E;"!N;VUB<F4@<75E(&1E<V5A('%U92!S92!I;F-L=7EA(&5N
M('-U<R!C;&%V97,@<&5R<V]N86QE<RX@17,@=6X@8V%M<&\@;F5C97-A<FEO
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O
M;F%L:V5Y+6-R96%T92UC;VUM96YT(B!M9#4](F4V-C9E8CEF,&5E-&(T.69E
M,#1F-S1F8S$X9&(X-C0P(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/E!'4#H@0W)E87(@8VQA=F5S('!E<G-O;F%L97,@+2!#;VUE;G1A<FEO/"]T
M:71L93X*("`@(#QH96%D:6YG/D-O;65N=&%R:6\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%5N(&-O;65N=&%R:6\@<75E(&1E<V5E('%U92!S92!I;F-L
M=7EA(&5N('-U<R!C;&%V97,@<&5R<V]N86QE<RX@17,@=6X@8V%M<&\@;W!C
M:6]N86PN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M
M<&5R<V]N86QK97DM8W)E871E+65M86EL(B!M9#4](F,W,CEF-S!F9&(S83<S
M8V)B-V)A-65F-3@X.&4S,#DR(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/E!'4#H@0W)E87(@8VQA=F5S('!E<G-O;F%L97,@+2!#;W)R96\@96QE
M8W1R)B-X1C,[;FEC;SPO=&ET;&4^"B`@("`\:&5A9&EN9SY#;W)R96\@96QE
M8W1R)B-X1C,[;FEC;SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3&$@9&ER
M96-C:28C>$8S.VX@9&4@8V]R<F5O('%U92!Q=6EE<F4@87-O8VEA<B!C;VX@
M<W5S(&-L879E<R!P97)S;VYA;&5S+B!%<R!U;B!C86UP;R!N96-E<V%R:6\N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N
M86QK97DM8W)E871E+6ME>6QE;F=T:"(@;60U/2(R-&-A-C0Q8S8S9F(U9F8S
M,3!A,SEE93!D,V(Q964U-2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L
M93Y01U`Z($-R96%R(&-L879E<R!P97)S;VYA;&5S("T@5&%M828C>$8Q.V\@
M9&4@8VQA=F4\+W1I=&QE/@H@("`@/&AE861I;F<^5&%M828C>$8Q.V\@9&4@
M8VQA=F4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5L('1A;6$F(WA&,3MO
M+"!E;B!B>71E<RP@9&4@;&$@8VQA=F4@9V5N97)A9&$N($-U86YT;R!M87EO
M<B!S96$@96P@=F%L;W(L(&UA>6]R('-E<B8C>$4Q.R!L82!P<F]T96-C:28C
M>$8S.VX@*'D@=&%M8FDF(WA%.3MN(&UA>6]R('-E<B8C>$4Q.R!E;"!T:65M
M<&\@9&4@9V5N97)A8VDF(WA&,SMN('D@9&4@8VEF<F%D;RDN(#$P,C0@8GET
M97,@97,@;&$@;W!C:28C>$8S.VX@<&]R(&]M:7-I)B-X1C,[;B`M(&5S=&4@
M=F%L;W(@;V9R96-E('5N82!P<F]T96-C:28C>$8S.VX@97AC96QE;G1E+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L
M:V5Y+6-R96%T92UP87-S<&AR87-E(B!M9#4](C)F8CDS-S(Y-S!B9C,S9C4Q
M93DX.&)A,SED8F0W,3DS(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/E!'4#H@0W)E87(@8VQA=F5S('!E<G-O;F%L97,@+2!&<F%S92!C;&%V93PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY&<F%S92!C;&%V93PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@3&$@9G)A<V4@8VQA=F4@=71I;&EZ861A('!A<F$@<')O
M=&5G97(O8VEF<F%R('-U(&-L879E('!E<G-O;F%L('!R:79A9&$N($1E8F5R
M)B-X140[82!T96YE<B!!3"!-14Y/4R`V(&-A<F%C=&5R97,L($Y/(&1E8F5R
M)B-X140[82!S97(@:6=U86P@82!S=2!C;VYT<F%S928C>$8Q.V$@9&4@86-C
M97-O+"!.3R!D96)E(&)A<V%R<V4@96X@=6YA('!A;&%B<F$@:6YC;'5I9&$@
M96X@96P@9&EC8VEO;F%R:6\@>2!D96)E<B8C>$5$.V$@8V]N=&5N97(@=&%N
M=&\@;B8C>$9!.VUE<F]S(&-O;6\@;&5T<F%S+B!496YD<B8C>$4Q.R!Q=64@
M:6YT<F]D=6-I<B!L82!F<F%S92!C;&%V92!D;W,@=F5C97,@8V]N(&]B:F5T
M;R!D92!V97)I9FEC87)L82X@17,@=6X@8V%M<&\@;F5C97-A<FEO+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y
M+6-R96%T92UA8W1I;VYS(B!M9#4](C!F.#(S-#DS-6(Y-C1C.#,U,S-B-&5C
M-&,Q-65B-S$R(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@
M0W)E87(@8VQA=F5S('!E<G-O;F%L97,@+2!!8V-I;VYE<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY#<F5A<B!C;&%V97,\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($-R96$@>2!A;&UA8V5N82!S=7,@8VQA=F5S('!E<G-O;F%L97,@<"8C
M>$9!.V)L:6-A+W!R:79A9&$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY)
M;7!O<G1A<B!C;&%V97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EM<&]R
M=&$@=6YA<R!C;&%V97,@<&5R<V]N86QE<R!P)B-X1D$[8FQI8V$O<')I=F%D
M82X@17-T92!B;W0F(WA&,SMN(&%B<F4@=6YA('9E;G1A;F$@96X@;&$@<75E
M('!U961E(&EM<&]R=&%R(&1E(&9O<FUA(&UA;G5A;"!S=7,@8VQA=F5S('!E
M<G-O;F%L97,@<"8C>$9!.V)L:6-A+W!R:79A9&$@97AI<W1E;G1E<RX@3&%S
M(&-L879E<R!S92!P=65D96X@<&5G87(@96X@=6X@8V%M<&\@9&4@=&5X=&\@
M;RP@<VD@97-T)B-X13$[;B!D:7-P;VYI8FQE<R!E;B!U;B!A<F-H:79O(&5N
M(&5L(&]R9&5N861O<B!L;V-A;"P@<'5E9&4@:6UP;W)T87)L87,@9&5S9&4@
M96P@;6ES;6\N(%-I(&QA<R!C;&%V97,@<V]N('8F(WA%,3ML:61A<R!S92!I
M;G-E<G1A<B8C>$4Q.VX@96X@;&%S('!R969E<F5N8VEA<R!Y(&QA('9E;G1A
M;F$@<V4@8V5R<F%R)B-X13$[.R!S:2!N;R!S;VX@=B8C>$4Q.VQI9&%S('-E
M(&UO<W1R87(F(WA%,3L@=6X@;65N<V%J92!D92!E<G)O<B!I;F1I8V%N9&\@
M;&$@<F%Z)B-X1C,[;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G-M:6UE+6]V97)V:65W(B!M9#4](F0S8S<U,F(Q,S0U9F(R96-C9F4U
M-S5C,#<T-C$Y-C-F(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E,O
M34E-13H@26YT<F]D=6-C:28C>$8S.VX\+W1I=&QE/@H@("`@/&AE861I;F<^
M)B-X0D8[474F(WA%.3L@97,@4R]-24U%/SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@4R]-24U%(&5S('5N('-I<W1E;6$@9&4@8VQA=F5S('!R:79A9&$O
M<"8C>$9!.V)L:6-A('%U92!P<F]P;W)C:6]N82!F:7)M87,@9&EG:71A;&5S
M+"!P<FEV86-I9&%D(&1E(&UE;G-A:F5S('D@9&5T96-C:28C>$8S.VX@9&4@
M9F%L<VEF:6-A8VDF(WA&,SMN(&1E('5N82!F;W)M82!A8FEE<G1A(&4@:6YT
M97)O<&5R86)L92X@4R]-24U%('!U961E('!R;W!O<F-I;VYA<B!P<FEV86-I
M9&%D(&$@;&]S(&UE;G-A:F5S(&-I9G(F(WA%,3MN9&]L;W,@9&4@9F]R;6$@
M<75E(',F(WA&,SML;R!E;"!R96UI=&5N=&4@>2!L;W,@9&5S=&EN871A<FEO
M<R!P<F5V:7-T;W,@<'5E9&%N(&1E<V-I9G)A<FQO<RX@3&4@<&5R;6ET92!I
M9&5N=&EF:6-A<B!A;"!R96UI=&5N=&4@9&4@=6X@;65N<V%J92!M961I86YT
M92!U;F$@9FER;6$@9&EG:71A;"X@16X@8V]N:G5N=&\L(&5S=&$@87EU9&$@
M9&4@8VEF<F%D;R!Y(&9I<FUA(&1I9VET86P@<')O<&]R8VEO;F$@9&5T96-C
M:28C>$8S.VX@9&4@9F%L<VEF:6-A8VDF(WA&,SMN+"!P97)M:71I96YD;R!A
M(&QO<R!D97-T:6YA=&%R:6]S(&1E=&5R;6EN87(@<VD@=6X@;65N<V%J92!S
M92!H82!M;V1I9FEC861O(&1E<W!U)B-X13D[<R!D92!H86)E<B!S:61O(&5N
M=FEA9&\N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SXF(WA"1CM!8W1I=F%R
M(&-A<&%C:61A9"!3+TU)344_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3
M:2!S92!S96QE8V-I;VYA(&5S=&$@;W!C:28C>$8S.VXL('!O9'(F(WA%,3L@
M:6UP;W)T87(@<W5S(&-L879E<R!P97)S;VYA;&5S(%,O34E-12P@;&5E<B!C
M;W)R96\@8VEF<F%D;RP@8V]M<')O8F%R(&-O<G)E;R!F:7)M861O(&1I9VET
M86QM96YT92!Y(&-I9G)A<B]F:7)M87(@96P@8V]R<F5O('%U92!E;G8F(WA%
M1#ME+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M
M;W9E<G9I97<M<&5R<V]N86QK97DB(&UD-3TB.68T9C,V864W,F-B-&%B8S<S
M,3`V-V0S,SAB93-B.3@B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^
M4R]-24U%.B!#;&%V97,@<&5R<V]N86QE<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY);G1R;V1U8V-I)B-X1C,[;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M4VD@9&5S96$@9FER;6%R(&1I9VET86QM96YT92!O(&-I9G)A<B!L;W,@;65N
M<V%J97,L('1I96YE('%U92!D:7-P;VYE<B!D92!S=7,@<')O<&EA<R!C;&%V
M97,@4R]-24U%('`F(WA&03MB;&EC82]P<FEV861A+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M:6UP;W)T+7!E<G-O;F%L+6-E
M<G1S(B!M9#4](F-F,&5D,F4S93(T9#,P9&5D9CAC9F5F,F,R-C0U-S4Y(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E,O34E-13H@26UP;W)T87(@
M8V5R=&EF:6-A9&]S('!E<G-O;F%L97,\+W1I=&QE/@H@("`@/&AE861I;F<^
M26UP;W)T87(@8V5R=&EF:6-A9&]S('!E<G-O;F%L97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($EM<&]R=&$@;&]S(&-E<G1I9FEC861O<R!P97)S;VYA
M;&5S(&1E<V1E('5N(&%R8VAI=F\@9&4@9F]R;6%T;R!02T-3(",Q,BX@06P@
M97AP;W)T87(@=6YA(&-L879E(&1E<V1E('5N(&YA=F5G861O<B`H<"YE+B!)
M;G1E<FYE="!%>'!L;W)E<BP@1FER969O>"D@;R!A;"!E>'!O<G1A<B!U;B!C
M97)T:69I8V%D;R!A;&UA8V5N861O('!O<B!E;"!3:7-T96UA($]P97)A=&EV
M;R`H<"YE+B!7:6YD;W=S(%A0*2!S92!S=65L92!G96YE<F%R('5N(&%R8VAI
M=F\@9&4@=&EP;R!02T-3(",Q,BX@4VD@;&%S(&-L879E<R!S;VX@=B8C>$4Q
M.VQI9&%S+"!S92!I;G-E<G1A<B8C>$4Q.VX@96X@;&%S('!R969E<F5N8VEA
M<R!Y('-E(&-E<G)A<B8C>$4Q.R!L82!V96YT86YA.R!S:2!N;R!S;VX@=B8C
M>$4Q.VQI9&%S('-E(&UO<W1R87(F(WA%,3L@=6X@;65N<V%J92!D92!E<G)O
M<B!E>'!L:6-A;F1O(&QA(')A>B8C>$8S.VXN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UD96QE=&4M<&5R<V]N86PM8V5R=',B
M(&UD-3TB,#$X8F(V8C8Q83=E-#$V.#DR9&4R.#AA9#%C.#@P9C0B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4R]-24U%.B!%;&EM:6YA<B!C97)T
M:69I8V%D;W,@<&5R<V]N86QE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%;&EM
M:6YA<B!C97)T:69I8V%D;W,@<&5R<V]N86QE<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@16QI;6EN82!S=7,@8V5R=&EF:6-A9&]S('!E<G-O;F%L97,@
M9&4@;&%S('!R969E<F5N8VEA<RX@3F\@<&]D<B8C>$4Q.R!V;VQV97(@82!F
M:7)M87(@;65N<V%J97,@96X@4R]-24U%(&YI('9E<B!N:6YG)B-X1D$[;B!M
M96YS86IE(&-I9G)A9&\@96X@4R]-24U%('%U92!S92!L92!E;G8F(WA%1#ME
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;6%N
M86=E+7!U8FME>2(@;60U/2(X8C9C-C,V.#1D,V0W,V(S9#`X-#`R-6$W.&9E
M-V4X."(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y3+TU)344Z($=E
M<W1I;VYA<B!C;&%V97,@<"8C>$9!.V)L:6-A<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY3+TU)344Z($=E<W1I;VYA<B!C;&%V97,@<"8C>$9!.V)L:6-A<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1V5S=&EO;F$@<W4@;&ES=&%D;R!D
M92!C;&%V97,@4R]-24U%('`F(WA&03MB;&EC87,N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY697(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9E<B!E
M;"!T97AT;R!E;B!B<G5T;R!D92!U;F$@8VQA=F4@<"8C>$9!.V)L:6-A+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86QL97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%9E<B!D871O<R!T)B-X13D[8VYI8V]S(&1E('5N82!C
M;&%V92!P)B-X1D$[8FQI8V$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%
M;&EM:6YA<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16QI;6EN82!D96P@
M86QM86-E;F%M:65N=&\@;&$@8VQA=F4@<"8C>$9!.V)L:6-A('-E;&5C8VEO
M;F%D82X@16QI;6EN87(@;&$@8VQA=F4@<"8C>$9!.V)L:6-A(&1E('5N('5S
M=6%R:6\@;&4@:6UP961I<B8C>$4Q.R!E;G9I87)L92!M96YS86IE<R!C:69R
M861O<R!A(&1I8VAO('5S=6%R:6\N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<FEN=&EN9R(@;60U/2)F,C,S8S$Q8C9B-&$V8F5D96(V
M.&8Q9#5A,F$Y-S9D8B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y)
M;7!R97-I)B-X1C,[;CPO=&ET;&4^"B`@("`\:&5A9&EN9SY);7!R:6UI<B!U
M;B!M96YS86IE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!087)A(&EM<')I
M;6ER('5N(&UE;G-A:F4@<75E(&5S="8C>$4Y.R!V:7-U86QI>F%N9&\L('!U
M;'-E(&-U86QQ=6EE<F$@9&4@;&]S('8F(WA%1#MN8W5L;W,@(DEM<')I;6ER
M(B!D92!L82!P87)T92!S=7!E<FEO<B!O(&EN9F5R:6]R(&1E;"!M96YS86IE
M+B!%;"!M96YS86IE('-E(&%B<FER)B-X13$[(&5N('5N82!N=65V82!V96YT
M86YA(&-O;B!U;B!F;W)M871O('!R97!A<F%D;R!P87)A(&QA(&EM<')E<VDF
M(WA&,SMN+B!$97!E;F1I96YD;R!D96P@;F%V96=A9&]R('D@<VES=&5M82!O
M<&5R871I=F\@<75E(&5S="8C>$4Y.R!U=&EL:7IA;F1O+"!P=65D92!A8G)I
M<G-E(&5L(&-U861R;R!D92!D:28C>$4Q.VQO9V\@9&4@:6UP<F5S:28C>$8S
M.VXN(%-I(&YO('-E(&%B<F4L(&1E<W!L:65G=64@96P@;65N)B-X1D$[(")!
M<F-H:79O(B!D96P@;F%V96=A9&]R('D@<V5L96-C:6]N92`B26UP<FEM:7(B
M('!A<F$@86)R:7(@96P@8W5A9')O(&1E(&1I)B-X13$[;&]G;R!D92!I;7!R
M97-I)B-X1C,[;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G-O<G1I;F<B(&UD-3TB,3AC9&5A8S,X,#(W9F4U8S0R8F%B-CDS9C)A-#(V
M,&$B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^3W)D96YA8VDF(WA&
M,SMN('D@<V5C=65N8VEA8VDF(WA&,SMN/"]T:71L93X*("`@(#QH96%D:6YG
M/D]R9&5N86-I)B-X1C,[;B!D92!E;G1R861A<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@06P@=FES=6%L:7IA<B!U;B!L:7-T861O(&1E(&UE;G-A:F5S
M+"!P=65D92!O<F1E;F%R;&\@<&]R(&-U86QQ=6EE<F$@9&4@;&%S(&-O;'5M
M;F%S('!U;'-A;F1O('-O8G)E(&QA(&-A8F5C97)A(&1E(&QA(&-O;'5M;F$@
M8V]R<F5S<&]N9&EE;G1E+B!087)A(&-O;FUU=&%R(&5L('-E;G1I9&\@9&4@
M;&$@8VQA<VEF:6-A8VDF(WA&,SMN(&1E(&QA<R!C;VQU;6YA<R!E;G1R92!A
M<V-E;F1E;G1E('D@9&5S8V5N9&5N=&4L('!U;'-E(&5L(&EC;VYO(&1E(&9L
M96-H82!D92!L82!C86)E8V5R82!D92!L82!C;VQU;6YA+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^4V5C=65N8VEA8VDF(WA&,SMN/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!087)A(&%G<G5P87(@;&]S(&UE;G-A:F5S('!O<B!S
M96-U96YC:6%S("AA<W5N=&]S*2P@9&4@9F]R;6$@<75E(&-A9&$@;65N<V%J
M92!S92!A9W)U<&4@8V]N('1O9&%S('-U<R!R97-P=65S=&%S+"!P=6QS92!E
M;"!V)B-X140[;F-U;&\@6U-E8W5E;F-I85T@9&4@;&$@8V%B96-E<F$@9&4@
M;&$@8V]L=6UN82!A<W5N=&\N(%!A<F$@=F]L=F5R(&$@;&$@;W)D96YA8VDF
M(WA&,SMN(&YO<FUA;"!P;W(@87-U;G1O<RP@<'5L<V4@96P@=B8C>$5$.VYC
M=6QO(%M!<W5N=&]=(&1E(&QA(&-A8F5C97)A(&1E(&QA(&-O;'5M;F$@87-U
M;G1O+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB86QT97)N
M871I=F4M;7-G(B!M9#4](C0Y-S@P-S-F-S8Y-S=B-F%F-F(V.3@Q,&4T9#(R
M838U(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE;G-A:F5S($UU
M;'1I<&%R="]!;'1E<FYA=&EV93PO=&ET;&4^"B`@("`\<&%R83X*("`@($QO
M<R!R96UI=&5N=&5S(&5N=B8C>$5$.V%N(&5N(&]C87-I;VYE<R!M96YS86IE
M<R!D92!T:7!O(")M=6QT:7!A<G0O86QT97)N871I=F4B+B!%<W1O<R!M96YS
M86IE<R!T:65N96X@=F%R:6%S('!A<G1E<RP@=&]D87,@;6]S=')A;F1O($5,
M($U)4TU/($-/3E1%3DE$3R!P97)O(&5N($9/4DU!5$]3($1)4U1)3E1/4RX@
M16P@86=E;G1E(&1E(&-O<G)E;R!M;W-T<F%R)B-X13$[(&QA("8C>$9!.VQT
M:6UA('!A<G1E(&1E(&QA(&QI<W1A('%U92!P=65D82!V:7-U86QI>F%R<V4@
M8V]R<F5C=&%M96YT92!E;B!L)B-X140[;F5A(&5N(&5L(&YA=F5G861O<BP@
M<VD@;&$@:&%Y+B!%;"!R97-T;R!D92!L;W,@9F]R;6%T;W,@87!A<F5C97(F
M(WA%,3MN(&)A:F\@96P@97`F(WA%1#MG<F%F92`B4&%R=&5S(&%L=&5R;F%T
M:79A<R!D92!E<W1A('-E8V-I)B-X1C,[;B(@>2!S92!P;V1R)B-X13$[;B!V
M:7-U86QI>F%R(&\@9&5S8V%R9V%R(&1E(&9O<FUA('-E<&%R861A+B!%<R!I
M;7!O<G1A;G1E('1E;F5R(&5N(&-U96YT82!Q=64@=&]D87,@;&%S('!A<G1E
M<R!A;'1E<FYA=&EV87,@=&EE;F5N($5,($U)4TU/($-/3E1%3DE$3R!Q=64@
M;&$@<&%R=&4@;6]S=')A9&$@+2!S:6UP;&5M96YT92!E<W0F(WA%,3MN(&5N
M(&9O<FUA=&]S(&1I<W1I;G1O<R`H<"YE+B!T97AT;R!F<F5N=&4@82!(5$U,
M*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7)E
M;F%M95]S96YT;6%I;%]M;VYT:&QY(B!M9#4](C4S,&9A,C!E,&%F8F,R-69F
M9#0P.#<W.30X.#,R.#DY(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/E!R969E<F5N8VEA<SH@36%N=&5N:6UI96YT;SH@4F5N;VUB<F%R(&QA(&-A
M<G!E=&$@<V5N="UM86EL(&UE;G-U86QM96YT93PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($%C=&EV92!E<W1A(&]P8VDF(WA&,SMN('-I('%U:65R92!R96YO
M;6)R87(@;&$@8V%R<&5T82!S96YT+6UA:6P@86P@8V]M:65N>F\@9&4@8V%D
M82!M97,N($QA(&-A<G!E=&$@<V4@<F5N;VUB<F%R)B-X13$[("AC;VX@=6X@
M;F]M8G)E('%U92!C;VYT96YG82!E;"!M97,@>2!E;"!A)B-X1C$[;RD@>2!S
M92!C<F5A<B8C>$4Q.R!U;F$@;G5E=F$@8V%R<&5T82!S96YT+6UA:6PN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?
M<V5N=&UA:6Q?;6]N=&AL>2(@;60U/2(P8F5E9#$V9&9D-CAE,F8R-64P8S8V
M.#<Q9F0U-#9D9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y0<F5F
M97)E;F-I87,Z($UA;G1E;FEM:65N=&\Z($5L:6UI;F%R(&-A<G!E=&%S('-E
M;G0M;6%I;"!M96YS=6%L;65N=&4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!!
M8W1I=F4@97-T82!O<&-I)B-X1C,[;B!S:2!Q=6EE<F4@96QI;6EN87(@;&%S
M(&-A<G!E=&%S('-E;G0M;6%I;"!A;G1I9W5A<R!A;"!C;VUI96YZ;R!D92!C
M861A(&UE<RX@4'5E9&4@<V5R(&1E('5T:6QI9&%D+"!P;W(@96IE;7!L;RP@
M<VD@=&EE;F4@=6X@;"8C>$5$.VUI=&4@9&4@97-P86-I;R!D92!D:7-C;R!A
M<VEG;F%D;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY7VME97`B(&UD-3TB-S%E9#%C
M,F5A8C0X8CDQ83(U8C5B8V0T8C$T8V-E83DB('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^4')E9F5R96YC:6%S.B!-86YT96YI;6EE;G1O.B!%;&EM
M:6YA<B!C87)P971A<R!S96YT+6UA:6P@;65N<W5A;&UE;G1E("T@(R!C87)P
M971A<R!C;VYS97)V861A<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-I(&5S
M="8C>$4Q.R!B;W)R86YD;R!M96YS=6%L;65N=&4@;&%S(&-A<G!E=&%S('-E
M;G0M;6%I;"!A;G1I9W5A<RP@)B-X0D8[8W4F(WA%,3MN=&]S(&UE<V5S(&1E
M(&-O<G)E;R!A;G1I9W5O('%U:65R92!C;VYS97)V87(_($-U86QQ=6EE<B!C
M87)P971A(&TF(WA%,3MS(&%N=&EG=6$@<75E(&5S=&4@;B8C>$9!.VUE<F\@
M9&4@;65S97,@<V4@96QI;6EN87(F(WA%,3LN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N
M=&AL>2(@;60U/2(S-S-E83`R961E-F1F-69C,S0U8V%F-C,R93$Y83<U9B(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y0<F5F97)E;F-I87,Z($UA
M;G1E;FEM:65N=&\Z($5L:6UI;F%R(&%D:G5N=&]S('9I;F-U;&%D;W,@;65N
M<W5A;&UE;G1E/"]T:71L93X*("`@(#QP87)A/@H@("`@06-T:79E(&5S=&$@
M;W!C:28C>$8S.VX@<VD@9&5S96$@96QI;6EN87(@861J=6YT;W,@=FEN8W5L
M861O<R!A;G1I9W5O<R!A;"!C;VUI96YZ;R!D92!C861A(&UE<RX@4'5E9&4@
M<V5R(&1E('5T:6QI9&%D+"!P;W(@96IE;7!L;RP@<VD@=&EE;F4@=6X@;"8C
M>$5$.VUI=&4@9&4@97-P86-I;R!D92!D:7-C;R!A<VEG;F%D;RX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]A='1A
M8VAM96YT<U]M;VYT:&QY7VME97`B(&UD-3TB,6(S-#!A-C`R,31D9F9D,#1A
M96,P,F-C,3$R-V1F-60B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^
M4')E9F5R96YC:6%S.B!-86YT96YI;6EE;G1O.B!%;&EM:6YA<B!A9&IU;G1O
M<R!V:6YC=6QA9&]S(&UE;G-U86QM96YT92`M(",@;65S97,@8V]N<V5R=F%D
M;W,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3:2!E<W0F(WA%,3L@96QI;6EN
M86YD;R!M96YS=6%L;65N=&4@;&]S(&%D:G5N=&]S('9I;F-U;&%D;W,@86YT
M:6=U;W,L("8C>$)&.V-U)B-X13$[;G1O<R!M97-E<R!D92!A9&IU;G1O<R!A
M;G1I9W5O<R!D97-E82!C;VYS97)V87(_($-U86QQ=6EE<B!A9&IU;G1O(&TF
M(WA%,3MS(&%N=&EG=6\@<75E(&5S=&4@;B8C>$9!.VUE<F\@9&4@;65S97,@
M<V4@96QI;6EN87(F(WA%,3LN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@;60U/2)D8S<Q.#<Q,30V8F4S
M930V861E,#`X-V$X8V8Q.#(W,R(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-I87,Z($UA;G1E;FEM:65N=&\Z(%9A8VEA<B!P87!E
M;&5R83PO=&ET;&4^"B`@("`\<&%R83X*("`@($1E<V5A('9A8VEA<B!L82!P
M87!E;&5R82!A(&UE;G5D;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+7!U<F=E7W1R87-H7VEN=&5R=F%L(B!M9#4](C=B93DQ
M9F)E8C`U8C)D.#<R.#ED-&,U-C`R9#5A,S)F(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/E!R969E<F5N8VEA<SH@36%N=&5N:6UI96YT;SH@26YT
M97)V86QO(&1E('9A8VEA9&\@9&4@;&$@<&%P96QE<F$\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!3:2!E<W0F(WA%,3L@=F%C:6%N9&\@;&$@<&%P96QE<F$L
M("8C>$)&.V-O;B!Q=28C>$4Y.R!F<F5C=65N8VEA(&AA8V5R;&\_"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S
M:%]K965P(B!M9#4](C-C8C5A,F(U8C@P8C=A8S$Q-SEA93`P-68Y.#,Y-S!E
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!R969E<F5N8VEA<SH@
M36%N=&5N:6UI96YT;SH@0V]N<V5R=F%C:28C>$8S.VX@9&4@=F%C:6%D;R!D
M92!L82!P87!E;&5R83PO=&ET;&4^"B`@("`\<&%R83X*("`@(%-I(&5S="8C
M>$4Q.R!V86-I86YD;R!L82!P87!E;&5R82P@)B-X0D8[86YT:6<F(WA&0SME
M9&%D(&TF(WA%1#MN:6UA(&1E(&QO<R!M96YS86IE<R!A(&5L:6UI;F%R/PH@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB
M7W1E>'0B(&UD-3TB-S(Q83`Y9#=C83`R.&,Y-V4S8F0R8C,X8S4Y-V9F9C<B
M('-T871E/2)U<'1O9&%T92(^"B`@("`@/'1I=&QE/E!R969E<F5N8VEA<SH@
M4F5D86-C:28C>$8S.VX@9&5L(&UE;G-A:F4Z(%1E>'1O(&1E(&%S:6=N86-I
M)B-X1C,[;CPO=&ET;&4^"B`@("`@/'!A<F$^"B`@("`@07%U)B-X140[('-E
M('!U961E(&EN=')O9'5C:7(@;&$@9G)A<V4@<75E('%U:65R92!Q=64@87!A
M<F5Z8V$@86YT97,@9&4@8W5A;'%U:65R('1E>'1O(&-I=&%D;R!E;B!L82!R
M97-P=65S=&$@<75E(&5N=B8C>$5$.V4N"B`@("`@/"]P87)A/@H@("`@(#QP
M87)A/@H@("`@(%!U961E(&EN8VQU:7(@=6YO(&\@;28C>$4Q.W,@8V]M;V1I
M;F5S('!A<F$@:6YS97)T87(@:6YF;W)M86-I)B-X1C,[;B!S;V)R92!E;"!M
M96YS86IE(&%L('%U92!E<W0F(WA%,3L@<F5S<&]N9&EE;F1O+B!,;W,@8V]M
M;V1I;F5S('-E(&-O;7!O;F5N(&1E('5N("<E)R!S96=U:61O(&1E('5N82`F
M(WA&03MN:6-A(&QE=')A+B!392!D:7-P;VYE(&1E(&QO<R!S:6=U:65N=&5S
M.@H@("`@(#PO<&%R83X*"B`@("`@/'!A<F$^("5F(#H@3F]M8G)E('D@9&ER
M96-C:28C>$8S.VX@9&4@8V]R<F5O(&1E;"!R96UI=&5N=&4\+W!A<F$^"B`@
M("`@/'!A<F$^("5A(#H@1&ER96-C:28C>$8S.VX@9&4@8V]R<F5O(&1E;"!R
M96UI=&5N=&4\+W!A<F$^"B`@("`@/'!A<F$^("5P(#H@3F]M8G)E(&1E;"!R
M96UI=&5N=&4\+W!A<F$^"B`@("`@/'!A<F$^("5R(#H@1F5C:&$@>2!Z;VYA
M(&AO<F%R:6$@96X@97-T:6QO(%)&0R`R.#(R(&-O;7!L971O/"]P87)A/@H@
M("`@(#QP87)A/B`E9"`Z($9E8VAA(&-O;6\@=W=W+"!D9"!M;6T@04%!03PO
M<&%R83X*("`@("`\<&%R83X@)7@@.B!&96-H82!E;B!F;W)M871O(&QO8V%L
M('!O<B!O;6ES:28C>$8S.VX\+W!A<F$^"B`@("`@/'!A<F$^("5C(#H@1F5C
M:&$@>2!H;W)A(&5N(&9O<FUA=&\@;&]C86P@<&]R(&]M:7-I)B-X1C,[;CPO
M<&%R83X*("`@("`\<&%R83X@)6T@.B!)1"!D96P@;65N<V%J93PO<&%R83X*
M("`@("`\<&%R83X@)7,@.B!!<W5N=&\@9&5L(&UE;G-A:F4\+W!A<F$^"B`@
M("`@/'!A<F$^("5N(#H@56YA(&YU979A(&PF(WA%1#MN96$\+W!A<F$^"B`@
M("`@/'!A<F$^("4E(#H@16P@8V%R)B-X13$[8W1E<B`G)2<\+W!A<F$^"@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q=65S
M=%]R96%D(B!M9#4](C@Y93DR8S1D-C@R,C1B,C,T-6(U.3DU.3@W.&$W,3<T
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!R969E<F5N8VEA<SH@
M4V]L:6-I=&%R(&%C=7-E<R!D92!R96-I8F\\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("`B4V]L:6-I=&%R(&%C=7-E<R!D92!R96-I8F\B(&5N=B8C>$5$.V$@
M82!L;W,@9&5S=&EN871A<FEO<R!D96P@;65N<V%J92!L82!P971I8VDF(WA&
M,SMN(&1E('%U92!L92!I;F9O<FUE;B!C=6%N9&\@86)R86X@96P@;65N<V%J
M92X@3F\@=&]D;W,@;&]S(&-L:65N=&5S('-O<&]R=&%N("\@=&EE;F5N(&5N
M(&-U96YT82`F(WA%.3MS=&\N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S96YD7VUD;B(@;60U/2(Q9F4P
M-&4U9&,S9&4V.&0Q-S)D83(X-#@Y-3DW,V5A.2(@<W1A=&4](G5P=&]D871E
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-I87,Z($5N=FEA<B!.0TT\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("`B16YV:6%R($Y#32!S:2!L;R!S;VQI8VET82!E
M;"!R96UI=&5N=&4B(&5N=B8C>$5$.V$@=6YA($YO=&EF:6-A8VDF(WA&,SMN
M(&1E($-O;G-U;'1A(&1E;"!-96YS86IE("AT86UB:28C>$4Y.VX@8V]N;V-I
M9&$@8V]M;R!U;F$@8V]N9FER;6%C:28C>$8S.VX@9&4@;&5C='5R82D@8W5A
M;F1O(&QE82!U;B!M96YS86IE(&5N(&5L('%U92!E;"!U<W5A<FEO(&AA('-O
M;&EC:71A9&\@<F5C:6)I<B!U;F$@;F]T:69I8V%C:28C>$8S.VX@9&4@<75E
M(&QO(&AA(&QE)B-X140[9&\N($5N(&QA(&UA>6]R)B-X140[82!D92!L;W,@
M8V%S;W,@)B-X13D[<W1O('-E(')E86QI>F%R)B-X13$[(&1E(&9O<FUA(&%U
M=&]M)B-X13$[=&EC82!S:6X@<')E9W5N=&%R;&4N($5N(&%L9W5N;W,@8V%S
M;W,@86ES;&%D;W,@<'5E9&4@=&5N97(@<75E(&1E8VED:7(@96YV:6%R(&QA
M(&YO=&EF:6-A8VDF(WA&,SMN('!U;'-A;F1O('5N('8F(WA%1#MN8W5L;RX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O
M<VET:6]N7W)E<75E<W1?9&5L:79E<GDB(&UD-3TB,C8U.3AE,CEA9C`U83`W
M9&4U93$S-C0T-C8Y8F4W,3(B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET
M;&4^4')E9F5R96YC:6%S.B!3;VQI8VET87(@8V]N9FER;6%C:28C>$8S.VX@
M9&5L(&5N=B8C>$5$.V\\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`B4V]L:6-I
M=&%R(&-O;F9I<FUA8VDF(WA&,SMN(&1E;"!E;G8F(WA%1#MO(B!E;G8F(WA%
M1#MA('5N82!S;VQI8VET=60@86P@<V5R=FED;W(@9&5L(&1E<W1I;F%T87)I
M;R!D92!Q=64@;&4@:6YF;W)M92!C=6%N9&\@:&%Y82!D:7-T<FEB=6ED;R!E
M;"!M96YS86IE(&%L(&)U>B8C>$8S.VX@9&4@9&5S=&EN;RX@3F\@<VEG;FEF
M:6-A('%U92!E;"!M96YS86IE(&AA>6$@<VED;R!L928C>$5$.V1O+"!S:6UP
M;&5M96YT92!Q=64@:&$@;&QE9V%D;R!A('5N(&)U>B8C>$8S.VX@96X@86QG
M=6YA('!A<G1E+B!.;R!T;V1O<R!L;W,@<V5R=FED;W)E<R!D92!C;W)R96\@
M<V]P;W)T86X@)B-X13D[<W1O+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&5L971E7W-P86U?869T97)?<F5P;W)T(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB8V5F83AB-3)E,#EB,&%D83DP93`X.#EA,SDU
M.65F96$B/@H@("`@/'1I=&QE/E!R969E<F5N8VEA<SH@16QI;6EN87(@<W!A
M;2!T<F%S(&-O;75N:6-A<FQO/"]T:71L93X*("`@(#QP87)A/@H@("`@5')A
M<R!C;VUU;FEC87(@=6X@;65N<V%J92!C;VUO('-P86T@;R!I;F]F96YS:79O
M+"!P=65D92!O<'1A<B!P;W(@=6YA(&1E(&5N=')E('1R97,@;W!C:6]N97,N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($QA('!R:6UE<F$L('!U961E
M(&1E8VED:7(@;F\@:&%C97(@;F%D82!E;B!A8G-O;'5T;R`M(&5L(&UE;G-A
M:F4@<V4@8V]M=6YI8V%R)B-X13$[(&)I96X@8V]M;R!S<&%M(&\@8V]M;R!I
M;F]F96YS:79O('!E<F\@<V4@;6%N=&5N9'(F(WA%,3L@<VEN(&-A;6)I;W,@
M96X@<W4@8G5Z)B-X1C,[;BX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M3&$@<V5G=6YD82P@<VD@<V4@8V]M=6YI8V$@96P@;65N<V%J92!C;VUO('-P
M86TL('!U961E(&AA8V5R('%U92!S92!B;W)R92!I;FUE9&EA=&%M96YT92X@
M17-T82!O<&-I)B-X1C,[;B!C87)E8V4@9&4@969E8W1O('-I('-E(&-O;75N
M:6-A(&5L(&UE;G-A:F4@8V]M;R!I;F]F96YS:79O+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!,82!T97)C97)A+"!T<F%S(&-O;75N:6-A<B!U;B!M
M96YS86IE(&-O;6\@<W!A;2P@96P@;65N<V%J92!S92!B;W)R87(F(WA%,3L@
M9&5L(&)U>B8C>$8S.VX@86-T=6%L('D@<V4@=')A<VQA9&%R)B-X13$[(&$@
M;&$@8V%R<&5T82!D92!S<&%M+B!$92!F;W)M82!A;'1E<FYA=&EV82P@<VD@
M<V4@8V]M=6YI8V$@8V]M;R!I;F]F96YS:79O+"!S92!E;&EM:6YA<B8C>$4Q
M.R!D96P@8G5Z)B-X1C,[;B!A8W1U86P@>2!S92!T<F%S;&%D87(F(WA%,3L@
M86P@8G5Z)B-X1C,[;B!D92!%;G1R861A+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]R97!L86-E;65N="(@
M;60U/2(R.&4Q8V8P.&4S,C@S-#5A.&4W,C<T8S@U,S0Y,F0T9B(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93Y0<F5F97)E;F-I87,Z(%-U<W1I='5C
M:28C>$8S.VX@9&4@:6TF(WA%,3MG96YE<R!(5$U,/"]T:71L93X*("`@(#QP
M87)A/@H@("`@16X@96P@8V%S;R!D92!M96YS86IE<R!(5$U,(&UO<W1R861O
M<R!E;B!L)B-X140[;F5A+"`F(WA"1CMH86)R)B-X140[82!Q=64@8FQO<75E
M87(@=&]D87,@;&%S(&5T:7%U971A<R!D92!I;28C>$4Q.V=E;F5S(&AA<W1A
M('%U92!D96-I9&$@97AP;"8C>$5$.V-I=&%M96YT92!V97)L87,_(%1E;F=A
M(&5N(&-U96YT82!Q=64@<VD@97-T)B-X13$[('9I<W5A;&EZ86YD;R!U;B!A
M9&IU;G1O($A434P@;&%S(&EM)B-X13$[9V5N97,@<V4@=F5R)B-X13$[;B!S
M:65M<')E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M:'1M;%]I;6%G95]A9&1R8F]O:R(@;60U/2(W-3EF83-D9C(T93!A,V-D
M.#EF,S(P,3`R,C4R9CDQ82(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-I87,Z(%-U<W1I='5C:28C>$8S.VX@9&4@:6TF(WA%,3MG
M96YE<R!(5$U,+TUO<W1R87(@<VD@96X@1&ER96-C:6]N97,\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!3:2!S92!E<W0F(WA%,3MN(&)L;W%U96%N9&\@;&%S
M(&EM)B-X13$[9V5N97,@9&4@;&]S(&UE;G-A:F5S($A434P@96X@;"8C>$5$
M.VYE82P@)B-X0D8[:&%B<B8C>$5$.V$@<75E(&UO<W1R87)L87,@875T;VTF
M(WA%,3MT:6-A;65N=&4@<VD@96P@<F5M:71E;G1E(&%P87)E8V4@96X@;&$@
M;&EB<F5T82!D92!D:7)E8V-I;VYE<S\*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A<G0B(&UD-3TB,V0Q,3DV
M9C(V-60X8C=C8S0V-65B9C(Q-3$R86-C,#4B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^4')E9F5R96YC:6%S.B!0)B-X13$[9VEN82!D92!I;FEC
M:6\@9&5L(&)U>B8C>$8S.VX\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$96-I
M9&4@<74F(WA%.3L@<"8C>$4Q.V=I;F$@9&5L(&QI<W1A9&\@9&5L(&)U>B8C
M>$8S.VX@<V4@;6]S=')A<B8C>$4Q.R!C=6%N9&\@86-C961A(&%L(&)U>B8C
M>$8S.VX@<&]R('!R:6UE<F$@=F5Z+B!496YG82!E;B!C=65N=&$@<75E(&QA
M<R!O<&-I;VYE<R!D92!M96YS86IE<R`B<VEN(&QE97(B(&YO(&9U;F-I;VYA
M;B!C;VX@;&$@;W!C:28C>$8S.VX@9&4@;W)D96YA8VDF(WA&,SMN('!O<B`B
M4V5C=65N8VEA(B`M(&5N(&5S92!C87-O('-E(&QE(&5N=FEA<B8C>$4Q.R!A
M(&QA("8C>$9!.VQT:6UA('`F(WA%,3MG:6YA+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<V%V95]A='1A8VAM96YT<R(@;60U
M/2(S-6(T-C,S-&-D8V,W9F$T,39B.68Y9F-A-3@W-&4X,"(@<W1A=&4](G5P
M=&]D871E(CX*("`@(#QT:71L93Y0<F5F97)E;F-I87,Z($=U87)D87(@861J
M=6YT;W,@9&4@;65N<V%J97,@96YV:6%D;W,\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!3:2!S92!E<W0F(WA%,3L@9W5A<F1A;F1O('5N(&UE;G-A:F4@96X@
M=6YA(&-A<G!E=&$@<V5N="UM86EL+"!D96-I9&4@<VD@<V4@9W5A<F1A;B!T
M;V1O<R!L;W,@9&%T;W,@9&4@861J=6YT;W,N(%-E(&1I<W!O;F4@9&4@;&%S
M(&]P8VEO;F5S('-I9W5I96YT97,Z"B`@("`\+W!A<F$^"@H@("`@/'!A<F$^
M*B`B1W5A<F1A<B!S:65M<')E(&QO<R!A9&IU;G1O<R(@+2!.54Y#02!C;VYS
M=6QT87(@96P@86QM86-E;F%M:65N=&\@9&4@;&]S(&%D:G5N=&]S(&5N(&QA
M('9E;G1A;F$@9&4@<F5D86-C:28C>$8S.VX[(&QO<R!A9&IU;G1O<R!S92!G
M=6%R9&%R)B-X13$[;B!3245-4%)%(&-O;B!E;"!M96YS86IE+CPO<&%R83X*
M("`@("`\<&%R83XJ(")#;VYS=6QT87(@8V%D82!V97H@<75E('-E(&5N=B8C
M>$5$.V4@=6X@861J=6YT;SL@4R8C>$-$.R!P;W(@;VUI<VDF(WA&,SMN(B`M
M($-O;G-U;'1A<B!3245-4%)%(&5L(&%L;6%C96YA;6EE;G1O(&1E(&QO<R!A
M9&IU;G1O<R!E;B!L82!V96YT86YA(&1E(')E9&%C8VDF(WA&,SMN.R!P;W(@
M;VUI<VDF(WA&,SMN('-E(&=U87)D87(F(WA%,3MN(&QO<R!A9&IU;G1O<RX\
M+W!A<F$^"B`@("`@/'!A<F$^*B`B0V]N<W5L=&%R(&-A9&$@=F5Z('%U92!S
M92!E;G8F(WA%1#ME('5N(&%D:G5N=&\[($Y/('!O<B!O;6ES:28C>$8S.VXB
M("T@0V]N<W5L=&%R(%-)14U04D4@96P@86QM86-E;F%M:65N=&\@9&4@;&]S
M(&%D:G5N=&]S(&5N(&QA('9E;G1A;F$@9&4@<F5D86-C:28C>$8S.VX[('!O
M<B!O;6ES:28C>$8S.VX@;&]S(&%D:G5N=&]S(&YO('-E(&=U87)D87(F(WA%
M,3MN+CPO<&%R83X*("`@("`\<&%R83XJ(").=6YC82!G=6%R9&%R(&%D:G5N
M=&]S(B`M($Y53D-!(&-O;G-U;'1A<B!E;"!A;&UA8V5N86UI96YT;R!D92!L
M;W,@861J=6YT;W,@96X@;&$@=F5N=&%N82!D92!R961A8V-I)B-X1C,[;CL@
M;&]S(&%D:G5N=&]S(&YO('-E(&=U87)D87(F(WA%,3MN($Y53D-!(&-O;B!E
M;"!M96YS86IE+CPO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U
M86Q?:6YB;W@B('-T871E/2)U<'1O9&%T92(@;60U/2(T9#$Y-CEE-C0P9C9E
M,&)E9#1F.#DU.&8P,3AC,F0P-R(^"B`@("`\=&ET;&4^0V%R<&5T87,@5FER
M='5A;&5S.B!%;G1R861A('9I<G1U86P\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!,82!%;G1R861A('9I<G1U86P@97,@=6YA(&(F(WA&03MS<75E9&$@86QM
M86-E;F%D82!Q=64@979I=&$@;&$@;F5C97-I9&%D(&1E(&)U<V-A<B!M86YU
M86QM96YT92!E;B!C861A(&)U>B8C>$8S.VX@;&]S(&UE;G-A:F5S(&UA<F-A
M9&]S(&-O;6\@;G5E=F]S+B!%;B!S=2!L=6=A<BP@<V4@8G5S8V%N(&%U=&]M
M)B-X13$[=&EC86UE;G1E(&QO<R!N=65V;W,@;65N<V%J97,@96X@=&]D;W,@
M;&]S(&)U>F]N97,@<W5S8W)I=&]S(&%C='5A;&UE;G1E('D@;&]S(')E<W5L
M=&%D;W,@<V4@;75E<W1R86X@96X@=6X@)B-X1D$[;FEC;R!B=7HF(WA&,SMN
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T
M<F%S:"(@<W1A=&4](G5P=&]D871E(B!M9#4](C$Q9CDQ.#$Q8CEB,F%F.3!F
M938X-S0P9C9A.#9C968V(CX*("`@(#QT:71L93Y#87)P971A<R!6:7)T=6%L
M97,Z(%!A<&5L97)A('9I<G1U86P\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!,
M82!087!E;&5R82!V:7)T=6%L(&5S('5N82!B)B-X1D$[<W%U961A(&%L;6%C
M96YA9&$@<75E(&5V:71A(&QA(&YE8V5S:61A9"!D92!D:7-P;VYE<B!D92!U
M;F$@8V%R<&5T82!087!E;&5R82!I;F1E<&5N9&EE;G1E+B!%;B!L=6=A<B!D
M92!T<F%S;&%D87(@;&]S(&UE;G-A:F5S(&$@=6YA(&-A<G!E=&$@<&%P96QE
M<F$@8V5N=')A;&EZ861A+"!S:6UP;&5M96YT92!S92!M87)C86X@8V]M;R!B
M;W)R861O<R!E;B!L82!C87)P971A(&5N(&QA('%U92!S92!E;F-U96YT<F5N
M+B!3:2`G36]S=')A<B!L;W,@;65N<V%J97,@96QI;6EN861O<R<@97-T)B-X
M13$[(&1E<V%C=&EV861O+"`F(WA%.3MS=&\@<V4@=')A9'5C92!E;B!Q=64@
M97-T;W,@;65N<V%J97,@;F\@87!A<F5C96X@96X@;&$@=FES=&$@9&5L(&)U
M>B8C>$8S.VXN($-U86YD;R!U;B!U<W5A<FEO('!U;'-A(&QA(%!A<&5L97)A
M('9I<G1U86PL('-E(&)U<V-A;B!L;W,@;65N<V%J97,@;6%R8V%D;W,@8V]M
M;R!B;W)R861O<R!E;B`J=&]D;W,J(&QO<R!B=7IO;F5S('D@<V4@;75E<W1R
M86X@96X@=6X@)B-X1D$[;FEC;R!B=7HF(WA&,SMN+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]F:5]&22\`````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<V,``P,3<T,C(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE
M+V9I7T9)+TQ#7TU%4U-!1T53+P``````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S8P`#`R,3(P-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]L;V-A;&4O9FE?1DDO3$-?34534T%'15,O:6UP+FUO````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`V-S4W-3$`,3`T,3<S-C(W-C``,#(R,S4S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````-X2
M!)4`````B0L``!P```!D7```9P\``*RX````````2/8```H```!)]@``"@``
M`%3V```*````7_8```H```!J]@``#@```'7V```/````A/8```T```"4]@``
M"````*+V```+````J_8```P```"W]@``"@```,3V```$````S_8```0```#4
M]@``&````-GV```;````\O8``"T````.]P``'0```#SW```D````6O<``"D`
M``!_]P``&0```*GW```!````P_<``!D```#%]P``)@```-_W```,````!O@`
M``L````3^```)````!_X```>````1/@``$@```!C^```*P```*SX``!$````
MV/@``"<````=^0``%P```$7Y```/````7?D```L```!M^0``#@```'GY```%
M````B/D``"@```".^0``"````+?Y```*````P/D``!4```#+^0``$@```.'Y
M```R````]/D```L````G^@``*0```#/Z```R````7?H``!````"0^@``%@``
M`*'Z```0````N/H``"8```#)^@``*0```/#Z```F````&OL``!P```!!^P``
MA0```%[[```.````Y/L```H```#S^P``#0```/[[```G````#/P``"(````T
M_```#@```%?\```B````9OP``!D```")_```)````*/\```W````R/P``!$`
M````_0``#0```!+]```,````(/T```T````M_0``!@```#O]```;````0OT`
M`)0```!>_0``+@```//]```W````(OX```8```!:_@``#````&'^``!\````
M;OX``&P```#K_@``'````%C_```=````=?\```H```"3_P``#P```)[_```8
M````KO\```P```#'_P``&P```-3_``!%````\/\``"@````V``$`00```%\`
M`0`D````H0`!``X```#&``$`#P```-4``0`.````Y0`!``X```#T``$`"```
M``,!`0`.````#`$!``X````;`0$`"0```"H!`0`N````-`$!`!H```!C`0$`
M,P```'X!`0!1````L@$!`#(````$`@$`.````#<"`0!4````<`(!`%$```#%
M`@$`6@```!<#`0!7````<@,!`#0```#*`P$`"0```/\#`0`-````"00!``<`
M```7!`$`"@```!\$`0`/````*@0!``4````Z!`$``P```$`$`0`&````1`0!
M`!$```!+!`$`"````%T$`0`)````9@0!``D```!P!`$`'0```'H$`0`.````
MF`0!``@```"G!`$`"@```+`$`0`E````NP0!`"````#A!`$`$P````(%`0`0
M````%@4!``\````G!0$`#P```#<%`0`*````1P4!``<```!2!0$``P```%H%
M`0`9````7@4!``\```!X!0$`%````(@%`0`)````G04!``T```"G!0$`$@``
M`+4%`0`9````R`4!`!X```#B!0$`#P````$&`0`*````$08!``\````<!@$`
M"````"P&`0`*````-08!`"0```!`!@$`%P```&4&`0`4````?08!`!8```"2
M!@$`$@```*D&`0`(````O`8!`!P```#%!@$`3@```.(&`0`M````,0<!`!D`
M``!?!P$`8````'D'`0`H````V@<!`!X````#"`$`&@```"((`0`L````/0@!
M`"````!J"`$`,@```(L(`0`'````O@@!``P```#&"`$`#0```-,(`0!4````
MX0@!`&,````V"0$`+````)H)`0`.````QPD!``,```#6"0$`"P```-H)`0`'
M````Y@D!``<```#N"0$`!0```/8)`0`%````_`D!``H````""@$``P````T*
M`0`7````$0H!``H````I"@$`#P```#0*`0`.````1`H!`$X```!3"@$`4```
M`*(*`0!#````\PH!`$(````W"P$`/0```'H+`0`6````N`L!`#````#/"P$`
M&``````,`0`C````&0P!``X````]#`$`%````$P,`0`7````80P!`!<```!Y
M#`$`%P```)$,`0`3````J0P!``\```"]#`$`(P```,T,`0`&````\0P!`!<`
M``#X#`$`#@```!`-`0!1````'PT!`!\```!Q#0$`'0```)$-`0`U````KPT!
M`#4```#E#0$`!P```!L.`0`&````(PX!``@````J#@$`#P```#,.`0`&````
M0PX!``@```!*#@$`$0```%,.`0`*````90X!`!,```!P#@$`"P```(0.`0`0
M````D`X!`!4```"A#@$`#0```+<.`0`3````Q0X!`",```#9#@$`+P```/T.
M`0`5````+0\!``<```!##P$`$````$L/`0`%````7`\!`!4```!B#P$`$0``
M`'@/`0`,````B@\!`#\```"7#P$`,````-</`0!(````"!`!`"$```!1$`$`
M.P```',0`0`[````KQ`!`#P```#K$`$`.````"@1`0`K````81$!`#````"-
M$0$`,0```+X1`0`[````\!$!`#D````L$@$`-0```&82`0`)````G!(!``<`
M``"F$@$`%````*X2`0`,````PQ(!``,```#0$@$`!0```-02`0`)````VA(!
M`!````#D$@$`"0```/42`0`3````_Q(!``,````3$P$`.0```!<3`0`2````
M41,!``P```!D$P$`-0```'$3`0`.````IQ,!`$D```"V$P$`,P`````4`0`*
M````-!0!`!8````_%`$`%@```%84`0`M````;10!``L```";%`$`)P```*<4
M`0`L````SQ0!`"H```#\%`$`)0```"<5`0`)````314!``D```!7%0$`"@``
M`&$5`0`&````;!4!``D```!S%0$`!P```'T5`0`O````A14!`#<```"U%0$`
M+@```.T5`0!5````'!8!`"T```!R%@$`+````*`6`0`M````S18!`#T```#[
M%@$`/P```#D7`0`M````>1<!`$````"G%P$`(P```.@7`0`C````#!@!`$``
M```P&`$`+0```'$8`0`S````GQ@!`"4```#3&`$`%0```/D8`0`9````#QD!
M`"D````I&0$`)````%,9`0`H````>!D!`%````"A&0$`&````/(9`0`1````
M"QH!`!$````=&@$`"@```"\:`0`,````.AH!``L```!'&@$`"@```%,:`0`C
M````7AH!`!8```""&@$`"@```)D:`0`0````I!H!`!8```"U&@$`%@```,P:
M`0`;````XQH!`"X```#_&@$`$````"X;`0`'````/QL!``<```!'&P$`%```
M`$\;`0`*````9!L!``@```!O&P$`)P```'@;`0`(````H!L!``,```"I&P$`
M!P```*T;`0`'````M1L!``8```"]&P$`.````,0;`0`%````_1L!``<````#
M'`$`!@````L<`0`(````$AP!``D````;'`$`*0```"4<`0`.````3QP!``H`
M``!>'`$`10```&D<`0`$````KQP!``0```"T'`$`!P```+D<`0`)````P1P!
M``8```#+'`$`$0```-(<`0`'````Y!P!`!8```#L'`$`!`````,=`0`G````
M"!T!``@````P'0$`!@```#D=`0`-````0!T!``8```!.'0$`'@```%4=`0`1
M````=!T!``@```"&'0$`#0```(\=`0`,````G1T!``<```"J'0$``P```+(=
M`0!&````MAT!``,```#]'0$`%P````$>`0`3````&1X!``@````M'@$`'0``
M`#8>`0`(````5!X!``0```!='@$`"````&(>`0`(````:QX!`"H```!T'@$`
M*P```)\>`0!3````RQX!`$$````?'P$`&@```&$?`0`K````?!\!`"````"H
M'P$`%0```,D?`0`&````WQ\!``8```#F'P$`#@```.T?`0`5````_!\!`#X`
M```2(`$`&````%$@`0`B````:B`!`"X```"-(`$`'0```+P@`0`A````VB`!
M`%0```#\(`$`*0```%$A`0`*````>R$!``<```"&(0$`!P```(XA`0`5````
MEB$!``X```"L(0$``@```+LA`0`*````OB$!``\```#)(0$`#0```-DA`0`/
M````YR$!``T```#W(0$`"0````4B`0`4````#R(!``8````D(@$`&````"LB
M`0`=````1"(!`!,```!B(@$`$0```'8B`0`4````B"(!`$\```"=(@$`!```
M`.TB`0`,````\B(!``8```#_(@$`"@````8C`0`-````$2,!`!0````?(P$`
M8@```#0C`0`G````ER,!`%0```"_(P$`7P```!0D`0!D````="0!``0```#9
M)`$`%@```-XD`0`.````]20!`!P````$)0$`#P```"$E`0`S````,24!`"@`
M``!E)0$`!0```(XE`0`%````E"4!`!L```":)0$`&@```+8E`0`.````T24!
M`!,```#@)0$`%0```/0E`0`P````"B8!`!$````[)@$`$0```$TF`0`<````
M7R8!`"H```!\)@$`-0```*<F`0!%````W28!`!`````C)P$`(0```#0G`0`%
M````5B<!`!,```!<)P$`"P```'`G`0`2````?"<!``H```"/)P$`#P```)HG
M`0`-````JB<!`$<```"X)P$`'P`````H`0`E````("@!`#,```!&*`$`*P``
M`'HH`0`U````IB@!`$(```#<*`$`'0```!\I`0!1````/2D!`!$```"/*0$`
M,0```*$I`0`[````TRD!`!,````/*@$`0````",J`0`X````9"H!``4```"=
M*@$`#````*,J`0`1````L"H!``T```#"*@$`!@```-`J`0`,````URH!``8`
M``#D*@$`%P```.LJ`0`(`````RL!``P````,*P$`%````!DK`0`/````+BL!
M`!`````^*P$`$0```$\K`0`(````82L!``4```!J*P$`$0```'`K`0`,````
M@BL!`!````"/*P$`!0```*`K`0`-````IBL!``8```"T*P$`!P```+LK`0`-
M````PRL!``<```#1*P$`"P```-DK`0`'````Y2L!``<```#M*P$`"0```/4K
M`0`7````_RL!`"8````7+`$`3P```#XL`0`)````CBP!``D```"8+`$`"@``
M`*(L`0`9````K2P!`#T```#'+`$`'0````4M`0`,````(RT!`"4````P+0$`
M'P```%8M`0`0````=BT!``4```"'+0$`)0```(TM`0`B````LRT!`!(```#6
M+0$`$P```.DM`0`K````_2T!`#L````I+@$`(````&4N`0`;````ABX!``@`
M``"B+@$`-@```*LN`0`A````XBX!`!`````$+P$`"````!4O`0`;````'B\!
M`!X````Z+P$`+P```%DO`0!<````B2\!`"X```#F+P$`#````!4P`0`&````
M(C`!``0````I,`$`#P```"XP`0`.````/C`!``X```!-,`$`!P```%PP`0`.
M````9#`!``<```!S,`$`"@```'LP`0`-````AC`!`!\```"4,`$`'````+0P
M`0`A````T3`!`!X```#S,`$`&0```!(Q`0`>````+#$!`!L```!+,0$`+```
M`&<Q`0`A````E#$!`"X```"V,0$`)@```.4Q`0`D````##(!`!P````Q,@$`
M'@```$XR`0`<````;3(!`"8```"*,@$`-@```+$R`0`K````Z#(!`#,````4
M,P$`*0```$@S`0!!````<C,!`#H```"T,P$`)@```.\S`0`K````%C0!`#@`
M``!"-`$`'0```'LT`0`5````F30!`"\```"O-`$`(````-\T`0`2`````#4!
M`"D````3-0$`'@```#TU`0`]````7#4!`"````":-0$`$@```+LU`0"B````
MSC4!`!8```!Q-@$`(P```(@V`0`H````K#8!`"D```#5-@$`.@```/\V`0`H
M````.C<!`!\```!C-P$`%0```(,W`0`@````F3<!`"4```"Z-P$`*````.`W
M`0`M````"3@!`#`````W.`$`D@```&@X`0`A````^S@!`!8````=.0$`'```
M`#0Y`0`F````43D!`"H```!X.0$`00```*,Y`0!$````Y3D!``P````J.@$`
M!P```#<Z`0`'````/SH!``8```!'.@$`#0```$XZ`0`+````7#H!`!0```!H
M.@$`#0```'TZ`0`8````BSH!`!H```"D.@$`$````+\Z`0`=````T#H!`!D`
M``#N.@$`70````@[`0`5````9CL!`"4```!\.P$`$@```*([`0`3````M3L!
M`!(```#).P$`!P```-P[`0`$````Y#L!`!````#I.P$`$````/H[`0`,````
M"SP!``X````8/`$`#0```"<\`0`/````-3P!`!0```!%/`$`$P```%H\`0`-
M````;CP!`#D```!\/`$`'````+8\`0`H````TSP!``,```#\/`$`#0`````]
M`0`&````#CT!`!$````5/0$`%P```"<]`0`;````/ST!``X```!;/0$``@``
M`&H]`0!)````;3T!``4```"W/0$`!0```+T]`0`0````PST!``\```#4/0$`
M!````.0]`0`-````Z3T!``X```#W/0$``P````8^`0`.````"CX!``@````9
M/@$`#P```"(^`0`(````,CX!``H````[/@$`#P```$8^`0`'````5CX!``T`
M``!>/@$`$````&P^`0`4````?3X!``T```"2/@$`&0```*`^`0`:````NCX!
M``L```#5/@$`"0```.$^`0`&````ZSX!`!0```#R/@$`"P````<_`0`3````
M$S\!`!`````G/P$`#````#@_`0`*````13\!`!$```!0/P$`%P```&(_`0`1
M````>C\!`!4```",/P$`)P```*(_`0`9````RC\!``L```#D/P$`#0```/`_
M`0`B````_C\!`"L````A0`$`%P```$U``0`/````94`!`#0```!U0`$`,P``
M`*I``0`;````WD`!`#0```#Z0`$`"@```"]!`0`8````.D$!`!0```!300$`
M$@```&A!`0`9````>T$!`!8```"500$`!P```*Q!`0`0````M$$!`"(```#%
M00$`'````.A!`0`<````!4(!``T````B0@$`!P```#!"`0`,````.$(!`"8`
M``!%0@$`"@```&Q"`0`4````=T(!``L```",0@$`!P```)A"`0`B````H$(!
M`"\```##0@$`"P```/-"`0`)````_T(!`!D````)0P$`"P```"-#`0`J````
M+T,!``\```!:0P$`%P```&I#`0`7````@D,!``D```":0P$`!P```*1#`0`6
M````K$,!``\```##0P$`+0```--#`0`9`````40!`!8````;1`$`#@```#)$
M`0`:````040!`"@```!<1`$`+0```(5$`0`N````LT0!``L```#B1`$`&```
M`.Y$`0`(````!T4!``P````010$`(P```!U%`0`-````044!`"8```!/10$`
M*@```'9%`0`@````H44!`$,```#"10$`"`````9&`0`2````#T8!`!\````B
M1@$`!````$)&`0`(````1T8!``L```!01@$`&@```%Q&`0`G````=T8!`!(`
M``"?1@$`(````+)&`0`O````TT8!`!<````#1P$`!0```!M'`0`,````(4<!
M``X````N1P$`#@```#U'`0`%````3$<!``8```!21P$`#@```%E'`0!%````
M:$<!``,```"N1P$``P```+)'`0`K````MD<!``<```#B1P$`!````.I'`0`.
M````[T<!``H```#^1P$`#`````E(`0`*````%D@!``\````A2`$`$````#%(
M`0`7````0D@!`!$```!:2`$`$P```&Q(`0`E````@$@!``X```"F2`$`$0``
M`+5(`0`9````QT@!`!<```#A2`$`$P```/E(`0`6````#4D!`#@````D20$`
M$P```%U)`0`)````<4D!``4```![20$`"P```(%)`0`*````C4D!``(```"8
M20$`!0```)M)`0`-````H4D!`!L```"O20$`%P```,M)`0`4````XTD!``D`
M``#X20$`'0````)*`0`O````($H!``\```!02@$`%@```&!*`0`2````=TH!
M``L```"*2@$`#````)9*`0`.````HTH!``T```"R2@$`$@```,!*`0`9````
MTTH!`!P```#M2@$`.`````I+`0`8````0TL!`"````!<2P$`$P```'U+`0`)
M````D4L!``,```";2P$`%0```)]+`0`+````M4L!`!,```#!2P$`"````-5+
M`0`.````WDL!`!````#M2P$`>P```/Y+`0`8````>DP!`!@```"33`$`)P``
M`*Q,`0`I````U$P!`"P```#^3`$`*````"M-`0`.````5$T!`#4```!C30$`
M$0```)E-`0`'````JTT!``4```"S30$`*0```+E-`0`8````XTT!`!X```#\
M30$`&P```!M.`0`9````-TX!`!@```!13@$`&P```&I.`0`9````ADX!`!,`
M``"@3@$`!P```+1.`0`(````O$X!``8```#%3@$`!@```,Q.`0`;````TTX!
M`!````#O3@$`#P````!/`0`0````$$\!``\````A3P$`"P```#%/`0`/````
M/4\!``P```!-3P$`#P```%I/`0`'````:D\!``8```!R3P$`"@```'E/`0`2
M````A$\!``T```"73P$`#````*5/`0`.````LD\!`$,```#!3P$`/0````50
M`0`)````0U`!``P```!-4`$`*````%I0`0`/````@U`!``@```"34`$`"```
M`)Q0`0`3````I5`!``L```"Y4`$`'@```,50`0`A````Y%`!`"`````&40$`
M&0```"=1`0`7````05$!`"4```!940$`%P```']1`0`6````EU$!``0```"N
M40$`&P```+-1`0`-````SU$!``P```#=40$``P```.I1`0`%````[E$!``@`
M``#T40$`"@```/U1`0`,````"%(!``H````54@$`(````"!2`0`?````05(!
M`!L```!A4@$`&0```'U2`0`+````EU(!`!L```"C4@$`"P```+]2`0`0````
MRU(!``@```#<4@$`#````.52`0`.````\E(!``L````!4P$`!`````U3`0`$
M````$E,!`!,````74P$`%````"M3`0`,````0%,!``D```!-4P$`#@```%=3
M`0`+````9E,!`!L```!R4P$`#@```(Y3`0`/````G5,!`"4```"M4P$`*@``
M`--3`0`'````_E,!`!(````&5`$`&P```!E4`0`$````-50!``<````Z5`$`
M"@```$)4`0`2````350!``H```!@5`$`#0```&M4`0`)````>50!``0```"#
M5`$`!0```(A4`0`(````CE0!``,```"75`$`&````)M4`0`=````M%0!`!``
M``#25`$`#@```.-4`0`>````\E0!`!H````150$`"@```"Q5`0`$````-U4!
M`"8````\50$`#@```&-5`0!\````<E4!`!4```#O50$`1`````56`0`%````
M2E8!``<```!05@$`#````%A6`0`(````958!``H```!N5@$`!@```'E6`0`'
M````@%8!``@```"(5@$`$0```)%6`0`9````HU8!``@```"]5@$``@```,96
M`0`&````R58!``8```#05@$`%````-=6`0`:````[%8!``T````'5P$`$```
M`!57`0`;````)E<!``4```!"5P$`!````$A7`0`,````35<!``D```!:5P$`
M$````&17`0`)````=5<!``D```!_5P$`!````(E7`0`%````CE<!`!H```"4
M5P$`!0```*]7`0`:````M5<!``@```#05P$`!@```-E7`0`/````X%<!`!D`
M``#P5P$`#@````I8`0`'````&5@!``<````A6`$`(@```"E8`0`%````3%@!
M``D```!26`$`"@```%Q8`0`.````9U@!``(```!V6`$`#0```'E8`0`@````
MAU@!``8```"H6`$`"P```*]8`0`-````NU@!``P```#)6`$`"0```-98`0`&
M````X%@!`!(```#G6`$`"0```/I8`0`'````!%D!`!0````,60$`'0```"%9
M`0!"````/UD!`"4```""60$`)0```*A9`0`&````SED!``H```#560$`!```
M`.!9`0`)````Y5D!``@```#O60$`$0```/A9`0`)````"EH!``8````46@$`
M#0```!M:`0`&````*5H!``0````P6@$`!````#5:`0`7````.EH!`#D```!2
M6@$`/0```(Q:`0`Z````REH!`!X````%6P$`!0```"1;`0`.````*EL!``0`
M```Y6P$`!@```#Y;`0`'````15L!`"$```!-6P$`#0```&];`0`5````?5L!
M``8```"36P$`!````)I;`0`1````GUL!``8```"Q6P$`"@```+A;`0`B````
MPUL!`"<```#F6P$`!@````Y<`0`5````%5P!``P````K7`$`$0```#A<`0`$
M````2EP!``T```!/7`$`!P```%U<`0`%````95P!`!T```!K7`$`!````(E<
M`0`,````CEP!``X```";7`$`"@```*I<`0`(````M5P!``D```"^7`$`!0``
M`,A<`0`Z````SEP!`#`````)70$`-0```#I=`0`I````<%T!`$<```":70$`
M.````.)=`0`I````&UX!`#\```!%7@$`+@```(5>`0`M````M%X!`!\```#B
M7@$`#P````)?`0`2````$E\!``L````E7P$`)@```#%?`0`G````6%\!`"D`
M``"`7P$`)````*I?`0`F````SU\!`"@```#V7P$`"````!]@`0`*````*&`!
M``D````S8`$`!P```#U@`0`$````16`!`!P```!*8`$`-P```&=@`0`@````
MGV`!`"````#`8`$`)@```.%@`0`-````"&$!`"<````680$`&P```#YA`0`B
M````6F$!``P```!]80$`%@```(IA`0`*````H6$!`!D```"L80$`*0```,9A
M`0`6````\&$!`!(````'8@$`!P```!IB`0`*````(F(!``P````M8@$`#P``
M`#IB`0`0````2F(!`$````!;8@$`1````)QB`0`\````X6(!`'`````>8P$`
M9@```(]C`0`&````]F,!``H```#]8P$`!0````AD`0`.````#F0!``D````=
M9`$`"@```"=D`0`2````,F0!`!,```!%9`$`#````%ED`0`&````9F0!``8`
M``!M9`$`"@```'1D`0`.````?V0!``\```".9`$`#@```)YD`0`;````K60!
M`!\```#)9`$`'@```.ED`0`C````"&4!`!$````L90$`%0```#YE`0`8````
M5&4!`!$```!M90$`$````']E`0`C````D&4!``\```"T90$`"0```,1E`0`2
M````SF4!`!T```#A90$`$@```/]E`0`0````$F8!``H````C9@$`$0```"YF
M`0`%````0&8!`#$```!&9@$`)````'AF`0`<````G68!`",```"Z9@$`:@``
M`-YF`0`/````26<!``4```!99P$`$````%]G`0`)````<&<!``0```!Z9P$`
M"P```']G`0`@````BV<!`!P```"L9P$`(P```,EG`0`B````[6<!``8````0
M:`$`%````!=H`0`7````+&@!``P```!$:`$`)````%%H`0`C````=F@!`!H`
M``"::`$`#````+5H`0`/````PF@!`!4```#2:`$`*0```.AH`0`J````$FD!
M`"8````]:0$`)P```&1I`0`I````C&D!`"H```"V:0$`&0```.%I`0!"````
M^VD!`!$````^:@$`$@```%!J`0`3````8VH!`!0```!W:@$`#P```(QJ`0`6
M````G&H!`!<```"S:@$`$````,MJ`0`1````W&H!`#0```#N:@$`$P```"-K
M`0`2````-VL!`#4```!*:P$`%````(!K`0`'````E6L!``P```"=:P$`*P``
M`*IK`0`/````UFL!`!8```#F:P$`(````/UK`0`0````'FP!`!0````O;`$`
M$0```$1L`0`H````5FP!`!<```!_;`$`'````)=L`0`3````M&P!``L```#(
M;`$`%````-1L`0`:````Z6P!`!$````$;0$`&@```!9M`0`>````,6T!`!H`
M``!0;0$`$P```&MM`0`A````?VT!`"````"A;0$`%0```,)M`0`1````V&T!
M`!<```#J;0$`%`````)N`0`7````%VX!`!4````O;@$`"0```$5N`0`&````
M3VX!`!````!6;@$`&0```&=N`0`$````@6X!``<```"&;@$`"P```(YN`0`1
M````FFX!``8```"L;@$`!@```+-N`0`&````NFX!``4```#!;@$`!P```,=N
M`0`'````SVX!``4```#7;@$`%@```-UN`0`&````]&X!``8```#[;@$`!```
M``)O`0`$````!V\!``<````,;P$`#@```!1O`0`,````(V\!``P````P;P$`
M#0```#UO`0`"````2V\!``H```!.;P$`#@```%EO`0`%````:&\!`"@```!N
M;P$`#@```)=O`0`,````IF\!``\```"S;P$`"@```,-O`0`(````SF\!``D`
M``#7;P$`*P```.%O`0!/````#7`!`$<```!=<`$`4P```*5P`0`N````^7`!
M``0````H<0$`"````"UQ`0`F````-G$!`!(```!=<0$`#P```'!Q`0`&````
M@'$!``H```"'<0$`!P```))Q`0`(````FG$!`"````"C<0$`"0```,1Q`0`1
M````SG$!``D```#@<0$`%````.IQ`0`,````_W$!``T````,<@$`#@```!IR
M`0`6````*7(!`!$```!`<@$`!@```%)R`0`#````67(!``8```!=<@$`&0``
M`&1R`0`'````?G(!``0```"&<@$`"P```(MR`0`+````EW(!``<```"C<@$`
M!0```*MR`0`'````L7(!`!8```"Y<@$`#0```-!R`0`-````WG(!``H```#L
M<@$`$````/=R`0`/````"',!`!$````8<P$`%P```"IS`0`*````0G,!`!$`
M``!-<P$`"````%]S`0`$````:',!`!$```!M<P$`#P```']S`0`Z````CW,!
M`"$```#*<P$`!0```.QS`0`7````\G,!``P````*=`$`'@```!=T`0`.````
M-G0!`!````!%=`$`"P```%9T`0!\````8G0!``P```#?=`$`"0```.QT`0`'
M````]G0!``H```#^=`$`"0````EU`0`.````$W4!`!`````B=0$`%0```#-U
M`0`;````274!`!@```!E=0$`&@```'YU`0`*````F74!``D```"D=0$`"@``
M`*YU`0`.````N74!``P```#(=0$`#P```-5U`0`(````Y74!``8```#N=0$`
M#````/5U`0`<`````G8!``<````?=@$`!0```"=V`0`+````+78!`$<````Y
M=@$`#0```(%V`0`)````CW8!``0```"9=@$``P```)YV`0`,````HG8!`!,`
M``"O=@$`$P```,-V`0`3````UW8!``8```#K=@$`"@```/)V`0`"````_78!
M``0`````=P$`)0````5W`0`#````*W<!``4````O=P$`*@```#5W`0`.````
M8'<!``H```!O=P$`!0```'IW`0`$````@'<!``H```"%=P$`#0```)!W`0`?
M````GG<!``<```"^=P$`(@```,9W`0`-````Z7<!``8```#W=P$`"````/YW
M`0`(````!W@!``0````0>`$`!0```!5X`0!H````&W@!``D```"$>`$`#```
M`(YX`0`0````FW@!``4```"L>`$`!@```+)X`0`C````N7@!`"4```#=>`$`
M"`````-Y`0`W````#'D!`"(```!$>0$`$P```&=Y`0`;````>WD!`"\```"7
M>0$`$````,=Y`0`*````V'D!`!$```#C>0$`#P```/5Y`0`/````!7H!``H`
M```5>@$`"0```"!Z`0`3````*GH!`!L````^>@$`&````%IZ`0`7````<WH!
M`!<```"+>@$`&0```*-Z`0`?````O7H!``X```#=>@$`)@```.QZ`0`F````
M$WL!``,````Z>P$`!P```#Y[`0`(````1GL!``<```!/>P$`$````%=[`0`*
M````:'L!``L```!S>P$`!P```'][`0`3````AWL!``P```";>P$`#P```*A[
M`0`.````N'L!``P```#'>P$`#@```-1[`0!1````XWL!``\````U?`$`$```
M`$5\`0`-````5GP!``\```!D?`$`#P```'1\`0`7````A'P!`!0```"<?`$`
M$0```+%\`0`/````PWP!`"````#3?`$`+@```/1\`0`:````(WT!``P````^
M?0$`)@```$M]`0`+````<GT!``T```!^?0$`&@```(Q]`0!*````IWT!`!D`
M``#R?0$`!@````Q^`0`:````$WX!`"4````N?@$`!@```%1^`0`&````6WX!
M`!\```!B?@$`!@```()^`0`)````B7X!`!@```"3?@$`%P```*Q^`0`H````
MQ'X!``8```#M?@$`#0```/1^`0`B`````G\!`%<````E?P$`$P```'U_`0`C
M````D7\!`!,```"U?P$``@```,E_`0`+````S'\!``@```#8?P$`#0```.%_
M`0`&````[W\!``H```#V?P$`!P````&``0`4````"8`!``8````>@`$`"```
M`"6``0`.````+H`!``<````]@`$`"@```$6``0`+````4(`!`#(```!<@`$`
M*P```(^``0`'````NX`!``P```##@`$`#0```-"``0`7````WH`!``P```#V
M@`$`!`````.!`0`)````"($!``D````2@0$`"@```!R!`0`'````)X$!``D`
M```O@0$`0````#F!`0`.````>H$!``<```")@0$`"@```)&!`0`;````G($!
M``\```"X@0$`%0```,B!`0`5````WH$!`!(```#T@0$`"@````>"`0`6````
M$H(!``D````I@@$`$````#."`0`'````1((!`!(```!,@@$`!````%^"`0`$
M````9((!``0```!I@@$`(0```&Z"`0`'````D((!``4```"8@@$`#````)Z"
M`0`%````JX(!``L```"Q@@$`%````+V"`0`1````TH(!`!H```#D@@$`%@``
M`/^"`0`4````%H,!`!<````K@P$`&````$.#`0`<````7(,!`!D```!Y@P$`
M!P```).#`0`%````FX,!`!8```"A@P$``P```+B#`0`-````O(,!``P```#*
M@P$`"@```->#`0`(````XH,!``L```#K@P$`$0```/>#`0`(````"80!`!<`
M```2A`$`"P```"J$`0`,````-H0!``P```!#A`$`'P```%"$`0`:````<(0!
M`!,```"+A`$`!````)^$`0`*````I(0!``0```"OA`$`#0```+2$`0`,````
MPH0!``D```#/A`$`#````-F$`0`%````YH0!``D```#LA`$`!0```/:$`0`'
M````_(0!``4````$A0$`!`````J%`0`"````#X4!`!0````2A0$`#0```">%
M`0`2````-84!``L```!(A0$`&P```%2%`0`?````<(4!``\```"0A0$`%```
M`*"%`0`>````M84!`!4```#4A0$`.````.J%`0`L````(X8!`!(```!0A@$`
M*0```&.&`0`R````C88!``H```#`A@$`+````,N&`0`N````^(8!`#,````G
MAP$`,P```%N'`0`X````CX<!``\```#(AP$`&````-B'`0`O````\8<!`!``
M```AB`$`$P```#*(`0`J````1H@!`!D```!QB`$`'````(N(`0`?````J(@!
M``\```#(B`$`$P```-B(`0`5````[(@!`!0````"B0$`%````!>)`0`4````
M+(D!`"````!!B0$`$@```&*)`0`4````=8D!`!4```"*B0$`+0```*")`0`M
M````SHD!`#$```#\B0$`+@```"Z*`0`O````78H!`"P```"-B@$`8@```+J*
M`0`3````'8L!`"4````QBP$`)````%>+`0`I````?(L!`$@```"FBP$`#0``
M`.^+`0`(````_8L!`!<````&C`$`"````!Z,`0`D````)XP!`!(```!,C`$`
M#````%^,`0`.````;(P!`#<```![C`$`*P```+.,`0`2````WXP!`"$```#R
MC`$`&@```!2-`0`)````+XT!`$4````YC0$`00```'^-`0`/````P8T!``0`
M``#1C0$`$P```-:-`0`4````ZHT!``X```#_C0$`!@````Z.`0`3````%8X!
M`!@````IC@$`!@```$*.`0`)````28X!``H```!3C@$`"P```%Z.`0`)````
M:HX!``T```!TC@$`#````(*.`0`/````CXX!`!<```"?C@$`%````+>.`0`0
M````S(X!`!8```#=C@$`!P```/2.`0`.````_(X!`"$````+CP$`!0```"V/
M`0`'````,X\!`!L````[CP$`*@```%>/`0`(````@H\!``8```"+CP$`%```
M`)*/`0`1````IX\!`$0```"YCP$`/````/Z/`0`.````.Y`!`#@```!*D`$`
M`@```(.0`0`"````AI`!``8```")D`$`#@```)"0`0`%````GY`!``<```"E
MD`$`#@```*V0`0`&````O)`!`"@```##D`$`#````.R0`0`,````^9`!`!P`
M```&D0$`(P```".1`0`$````1Y$!`"D```!,D0$`,@```':1`0`7````J9$!
M`!\```#!D0$`,P```.&1`0!<````%9(!``P```!RD@$`%````'^2`0`^````
ME)(!``T```#3D@$`'P```.&2`0`0`````9,!`!0````2DP$`!P```">3`0`.
M````+Y,!``P````^DP$`#````$N3`0`3````6),!``H```!LDP$`'0```'>3
M`0`9````E9,!``4```"ODP$`$0```+63`0`3````QY,!``T```#;DP$`#P``
M`.F3`0`1````^9,!`"0````+E`$`$@```#"4`0`#````0Y0!`!4```!'E`$`
M$P```%V4`0`2````<90!``L```"$E`$`-````)"4`0`+````Q90!`!0```#1
ME`$`/@```.:4`0`.````)94!`!,````TE0$`-````$B5`0`Q````?94!`!(`
M``"OE0$`$````,*5`0`8````TY4!`!D```#LE0$`(P````:6`0`B````*I8!
M`"<```!-E@$`5@```'66`0!-````S)8!`+D````:EP$`"````-27`0`)````
MW9<!``T```#GEP$`!P```/67`0`*````_9<!``<````(F`$`#P```!"8`0`&
M````()@!``L````GF`$`!````#.8`0`<````.)@!``T```!5F`$`)P```&.8
M`0`;````BY@!``P```"GF`$`&@```+28`0`*````SY@!``<```#:F`$`#0``
M`.*8`0`B````\)@!`"$````3F0$`"````#69`0`%````/ID!`!\```!$F0$`
M!@```&29`0`0````:YD!``@```!\F0$`!P```(69`0`-````C9D!``H```";
MF0$`$@```*:9`0`A````N9D!``L```#;F0$`&P```.>9`0`8`````YH!``@`
M```<F@$`'@```"6:`0`2````1)H!`"P```!7F@$`&@```(2:`0`)````GYH!
M``H```"IF@$`%0```+2:`0`%````RIH!`!0```#0F@$`!````.6:`0`0````
MZIH!``8```#[F@$`!P````*;`0`>````"IL!`"@````IFP$`"@```%*;`0`<
M````79L!`!$```!ZFP$`"P```(R;`0`:````F)L!`"P```"SFP$`"````.";
M`0`4````Z9L!`"P```#^FP$`)P```"N<`0`K````4YP!`"H```!_G`$`!```
M`*J<`0`$````KYP!``L```"TG`$`!0```,"<`0`&````QIP!``@```#-G`$`
M!@```-:<`0`Q````W9P!`!P````/G0$`"@```"R=`0"B````-YT!`!L```#:
MG0$`-````/:=`0`T````*YX!`"````!@G@$`*0```(&>`0`G````JYX!`"``
M``#3G@$`00```/2>`0`:````-I\!`"@```!1GP$`&@```'J?`0!V````E9\!
M`'D````,H`$`'`$``(:@`0`H````HZ$!`!T```#,H0$`*0```.JA`0`=````
M%*(!`%`````RH@$`+@```(.B`0`V````LJ(!`"P```#IH@$`,0```!:C`0`N
M````2*,!`"(```!WHP$`!@```)JC`0`(````H:,!``4```"JHP$`"````+"C
M`0`9````N:,!`!D```#3HP$`*@```.VC`0`0````&*0!`"L````II`$`(P``
M`%6D`0`9````>:0!`"$```"3I`$`+@```+6D`0`T````Y*0!``@````9I0$`
M%P```"*E`0`*````.J4!``<```!%I0$`(0```$VE`0`0````;Z4!``T```"`
MI0$`$````(ZE`0`%````GZ4!``X```"EI0$`"````+2E`0`+````O:4!`!0`
M``#)I0$`!P```-ZE`0`3````YJ4!``@```#ZI0$`-@````.F`0`W````.J8!
M``L```!RI@$`"0```'ZF`0`*````B*8!`!0```"3I@$`#P```*BF`0`O````
MN*8!`#(```#HI@$`"P```!NG`0`.````)Z<!``T````VIP$`#P```$2G`0`6
M````5*<!``X```!KIP$`/@```'JG`0`G````N:<!`"8```#AIP$`)`````BH
M`0`%````+:@!``4````SJ`$`!0```#FH`0`G````/Z@!`!\```!GJ`$`%@``
M`(>H`0`+````GJ@!`!<```"JJ`$`#P```,*H`0`$````TJ@!``H```#7J`$`
M"0```.*H`0`+````[*@!``T```#XJ`$`#`````:I`0`.````$ZD!``4````B
MJ0$`!````"BI`0`-````+:D!`#(````[J0$`10```&ZI`0`3````M*D!``L`
M``#(J0$`#@```-2I`0`.````XZD!``D```#RJ0$`"````/RI`0`0````!:H!
M`!4````6J@$`$P```"RJ`0`7````0*H!``<```!8J@$`'@```&"J`0`5````
M?ZH!`!0```"5J@$`!0```*JJ`0`4````L*H!``8```#%J@$`"P```,RJ`0`'
M````V*H!`",```#@J@$`%@````2K`0`/````&ZL!``X````KJP$`*@```#JK
M`0`&````9:L!``P```!LJP$`&````'FK`0`-````DJL!`!$```"@JP$`"P``
M`+*K`0`V````OJL!``T```#UJP$`"@````.L`0`B````#JP!``L````QK`$`
M#P```#VL`0`0````3:P!`"X```!>K`$`.@```(VL`0`.````R*P!``T```#7
MK`$`!0```.6L`0`+````ZZP!``P```#WK`$`#0````2M`0`-````$JT!``X`
M```@K0$`#0```"^M`0`@````/:T!`"<```!>K0$`*P```(:M`0`(````LJT!
M``H```"[K0$`!@```,:M`0`2````S:T!``X```#@K0$`%P```.^M`0`R````
M!ZX!`!8````ZK@$`'````%&N`0`E````;JX!`#````"4K@$`,0```,6N`0`M
M````]ZX!``X````EKP$`%````#2O`0`%````2:\!``X```!/KP$`$P```%ZO
M`0`:````<J\!`!(```"-KP$`!P```*"O`0`&````J*\!`!,```"OKP$`'P``
M`,.O`0`4````XZ\!`!$```#XKP$`2P````JP`0`3````5K`!``<```!JL`$`
M%````'*P`0`8````A[`!``<```"@L`$`!0```*BP`0`,````KK`!``P```"[
ML`$`$@```,BP`0`$````V[`!``<```#@L`$`"@```.BP`0`+````\[`!``P`
M``#_L`$`#@````RQ`0`.````&[$!``4````JL0$`!0```#"Q`0`N````-K$!
M`"8```!EL0$`(P```(RQ`0`#````L+$!`!(```"TL0$`!@```,>Q`0`&````
MSK$!`!X```#5L0$`%@```/2Q`0`8````"[(!``X````DL@$`-P```#.R`0`.
M````:[(!`!<```!ZL@$`00```)*R`0`T````U+(!`"4````)LP$`%0```"^S
M`0`Q````1;,!`!,```!WLP$`&P```(NS`0`J````I[,!`%$```#2LP$`60``
M`"2T`0!0````?K0!`+\```#/M`$`)0```(^U`0`-````M;4!``0```##M0$`
M"0```,BU`0`?````TK4!``,```#RM0$`!P```/:U`0`*````_K4!``@````)
MM@$``@```!*V`0`0````%;8!``@````FM@$`#````"^V`0`5````/+8!``L`
M``!2M@$`&0```%ZV`0`@````>+8!`!(```"9M@$`!0```*RV`0`*````LK8!
M`!4```"]M@$`$@```-.V`0`,````YK8!``0```#SM@$`"0```/BV`0`'````
M`K<!`#(````*MP$`"@```#VW`0`*````2+<!`!4```!3MP$`#````&FW`0`/
M````=K<!``L```"&MP$`!P```)*W`0`6````FK<!`%(```"QMP$`.@````2X
M`0`@````/[@!``\```!@N`$`%P```'"X`0`D````B+@!`#D```"MN`$`$@``
M`.>X`0`'````^K@!``8````"N0$`"0````FY`0`.````$[D!``X````BN0$`
M#@```#&Y`0`$````0+D!``8```!%N0$`%@```$RY`0`,````8[D!``T```!P
MN0$`#@```'ZY`0`5````C;D!`!(```"CN0$`#P```+:Y`0`4````QKD!`!0`
M``#;N0$`0P```/"Y`0`*````-+H!`!L````_N@$`-0```%NZ`0`1````D;H!
M`!````"CN@$`"P```+2Z`0!I````P+H!`!H````JNP$`%P```$6[`0`H````
M7;L!`"<```"&NP$`&P```*Z[`0`:````RKL!`!<```#ENP$`&P```/V[`0`9
M````&;P!`!\````SO`$`%P```%.\`0`<````:[P!`!<```"(O`$`#````*"\
M`0`3````K;P!``@```#!O`$`'P```,J\`0`O````ZKP!``<````:O0$`"```
M`"*]`0`0````*[T!`!$````\O0$`"0```$Z]`0`5````6+T!``T```!NO0$`
M!@```'R]`0`=````@[T!`",```"AO0$`!P```,6]`0`-````S;T!`!,```#;
MO0$`"````.^]`0`#````^+T!`$8```#\O0$`0P```$.^`0`R````A[X!`#\`
M``"ZO@$`-P```/J^`0!7````,K\!``4```"*OP$`'P```)"_`0`O````L+\!
M``H```#@OP$`#0```.N_`0`2````^;\!`"D````,P`$`"````#;``0`-````
M/\`!`"T```!-P`$`<````'O``0`_````[,`!`#D````LP0$`1@```&;!`0`$
M````K<$!`!````"RP0$`$````,/!`0`,````U,$!`!0```#AP0$`'0```/;!
M`0`<````%,(!`!$````QP@$`/0```$/"`0!/````@<(!`"4```#1P@$`(```
M`/?"`0`<````&,,!``L````UPP$`)P```$'#`0`:````:<,!`!\```"$PP$`
M'0```*3#`0`H````PL,!``\```#KPP$`)0```/O#`0`@````(<0!`"0```!"
MQ`$`)````&?$`0`@````C,0!`"4```"MQ`$`"P```-/$`0`'````W\0!``T`
M``#GQ`$`#````/7$`0`7`````L4!``4````:Q0$`!@```"#%`0`Y````)\4!
M``4```!AQ0$`#````&?%`0`'````=,4!``D```!\Q0$`$P```(;%`0`&````
MFL4!``D```"AQ0$`!````*O%`0`0````L,4!``@```#!Q0$`"````,K%`0`$
M````T\4!``L```#8Q0$`#````.3%`0`2````\<4!`!$````$Q@$`#````!;&
M`0`:````(\8!``\````^Q@$`!P```$[&`0`-````5L8!``\```!DQ@$`#```
M`'3&`0`4````@<8!`!0```"6Q@$`#P```*O&`0`.````N\8!`!(```#*Q@$`
M%````-W&`0`.````\L8!``P````!QP$`&P````['`0`L````*L<!`!,```!7
MQP$`'````&O'`0`H````B,<!``8```"QQP$`!P```+C'`0`3````P,<!``4`
M``#4QP$`!````-K'`0`,````W\<!`!<```#LQP$`$@````3(`0`I````%\@!
M``L```!!R`$`#0```$W(`0`4````6\@!`"\```!PR`$`"@```*#(`0`,````
MJ\@!``D```"XR`$`!@```,+(`0`)````R<@!``@```#3R`$`"0```-S(`0`%
M````YL@!``H```#LR`$`$0```/?(`0`*````"<D!`!`````4R0$`$````"7)
M`0`+````-LD!``8```!"R0$`#@```$G)`0`.````6,D!``T```!GR0$`"P``
M`'7)`0`0````@<D!`!T```"2R0$`$0```+#)`0`+````PLD!``(```#.R0$`
M"````-')`0`<````VLD!``<```#WR0$`#0```/_)`0`&````#<H!`&0````4
MR@$`%@```'G*`0`)````D,H!``<```":R@$`)@```*+*`0`X````R<H!`!H`
M```"RP$`*@```!W+`0`[````2,L!`"@```"$RP$`-````*W+`0`9````XLL!
M`!4```#\RP$`!0```!+,`0`+````&,P!``<````DS`$`"````"S,`0`'````
M-<P!``4````]S`$`!P```$/,`0`.````2\P!``D```!:S`$`!@```&3,`0`(
M````:\P!``L```!TS`$`!P```(#,`0`(````B,P!``<```"1S`$`%@```)G,
M`0`)````L,P!``8```"ZS`$`&0```,',`0`:````V\P!`"````#VS`$`"P``
M`!?-`0`0````(\T!``8````TS0$`'````#O-`0`4````6,T!``<```!MS0$`
M$0```'7-`0`(````A\T!``X```"0S0$`"````)_-`0`%````J,T!`!````"N
MS0$`"0```+_-`0`0````R<T!``8```#:S0$`&0```.'-`0`*````^\T!`!P`
M```&S@$`!P```"/.`0`%````*\X!``4````QS@$`$````#?.`0`4````2,X!
M``L```!=S@$`#0```&G.`0`H````=\X!`!@```"@S@$`%P```+G.`0`+````
MT<X!`!H```#=S@$`%````/C.`0`O````#<\!``0````]SP$`"0```$+/`0`*
M````3,\!``<```!7SP$``@```%_/`0`.````8L\!``@```!QSP$`(P```'K/
M`0`Q````GL\!`!\```#0SP$`.````/#/`0!X````*=`!`"8```"BT`$`&P``
M`,G0`0`Q````Y=`!`#$````7T0$`)P```$G1`0`B````<=$!`"````"4T0$`
M9````+71`0`=````&M(!`!0````XT@$`'````$W2`0!5````:M(!`#@```#`
MT@$`+0```/G2`0`S````)],!`$L```!;TP$`2@```*?3`0!;````\M,!`"@`
M``!.U`$`+````'?4`0`X````I-0!`"4```#=U`$`(0````/5`0`H````)=4!
M`"P```!.U0$`)@```'O5`0`;````HM4!`!X```"^U0$`=0```-W5`0`^````
M4]8!`$(```"2U@$`/0```-76`0`]````$]<!`"D```!1UP$`*0```'O7`0`Q
M````I=<!`#X```#7UP$`+P```!;8`0"I`0``1M@!`",```#PV0$`8@```!3:
M`0!/````=]H!`!<```#'V@$`2````-_:`0`V````*-L!`#X```!?VP$`,```
M`)[;`0`@````S]L!`#\```#PVP$`-````##<`0`L````9=P!`!T```"2W`$`
M'@```+#<`0`J````S]P!`(4```#ZW`$`,````(#=`0`E````L=T!`$$```#7
MW0$`6P```!G>`0!)````==X!`#$```"_W@$`-````/'>`0`\````)M\!`#@`
M``!CWP$`'0```)S?`0`8````NM\!`*<```#3WP$`*P```'O@`0`A````I^`!
M`!\```#)X`$`/````.G@`0`D````)N$!`"@```!+X0$`*P```'3A`0`B````
MH.$!`"8```##X0$`(P```.KA`0`E````#N(!`"4````TX@$`*0```%KB`0`G
M````A.(!`!<```"LX@$`*0```,3B`0`@````[N(!`#(````/XP$`'````$+C
M`0`N````7^,!`#H```".XP$`'0```,GC`0`1````Y^,!`#,```#YXP$`)0``
M`"WD`0`X````4^0!`"<```",Y`$`(````+3D`0`\````U>0!`"8````2Y0$`
M'P```#GE`0`P````6>4!`&D```"*Y0$`+@```/3E`0`Q````(^8!`$$```!5
MY@$`/@```)?F`0`S````UN8!`"4````*YP$`/0```##G`0!E````;N<!`$T`
M``#4YP$`4P```"+H`0!7````=N@!`%4```#.Z`$`1@```"3I`0`J````:^D!
M`"\```"6Z0$`50```,;I`0`@````'.H!`"X````]Z@$`*P```&SJ`0`P````
MF.H!`"H```#)Z@$`/@```/3J`0!4````,^L!`%(```"(ZP$`6@```-OK`0`R
M````-NP!`"L```!I[`$`2````)7L`0!*````WNP!`"H````I[0$`+````%3M
M`0!.````@>T!`#(```#0[0$`,`````/N`0`=````-.X!`",```!2[@$`+P``
M`';N`0`L````INX!`"T```#3[@$`<0````'O`0!F````<^\!`&\```#:[P$`
MLP```$KP`0`7````_O`!`"4````6\0$`,@```#SQ`0`I````;_$!`#X```"9
M\0$`(@```-CQ`0!2````^_$!`"4```!.\@$`"P```'3R`0"Q````@/(!`#L`
M```R\P$`)P```&[S`0!.````EO,!`$<```#E\P$`8@```"WT`0!)````D/0!
M`%4```#:]`$`0````##U`0`O````<?4!`#(```"A]0$`*P```-3U`0`I````
M`/8!``\````J]@$`10```#KV`0`A````@/8!`#````"B]@$`+0```-/V`0`E
M`````?<!`!P````G]P$`,0```$3W`0`Q````=O<!``X```"H]P$`"P```+?W
M`0`'````P_<!``<```#+]P$`!````-/W`0`-````V/<!``L```#F]P$`#@``
M`/+W`0`+`````?@!``4````-^`$`$````!/X`0`"````)/@!``H````G^`$`
M5@```#+X`0!9````B?@!`$X```#C^`$`!0```#+Y`0`2````./D!``0```!+
M^0$`!P```%#Y`0`(````6/D!``4```!A^0$`,````&?Y`0`#````F/D!`!``
M``"<^0$`%P```*WY`0`,````Q?D!``P```#2^0$`#0```-_Y`0`3````[?D!
M``T````!^@$``@````_Z`0`'````$OH!``8````:^@$`%````"'Z`0`,````
M-OH!`!@```!#^@$`!@```%SZ`0`2````8_H!``P```!V^@$``P```(/Z`0`J
M````A_H!``0```"R^@$`!@```+?Z`0`'````OOH!`!\```#&^@$`-0```.;Z
M`0`N````'/L!`"\```!+^P$`%P```'O[`0`B````D_L!`"4```"V^P$`(```
M`-S[`0`;````_?L!`!@````9_`$`)````#+\`0`?````5_P!`!H```!W_`$`
M(0```)+\`0`@````M/P!`!H```#5_`$`,@```/#\`0`:````(_T!`"\````^
M_0$`*P```&[]`0`?````FOT!`",```"Z_0$`'P```-[]`0`:````_OT!`"$`
M```9_@$`)0```#O^`0`F````8?X!`"4```"(_@$`)````*[^`0`8````T_X!
M`!T```#L_@$`)`````K_`0`8````+_\!`"(```!(_P$`+````&O_`0`O````
MF/\!`!4```#(_P$`)0```-[_`0`\````!``"`!\```!!``(`(P```&$``@`?
M````A0`"`"````"E``(`&@```,8``@`8````X0`"`!@```#Z``(`)@```!,!
M`@`>````.@$"`"D```!9`0(`'@```(,!`@`Q````H@$"``H```#4`0(`$P``
M`-\!`@`(````\P$"``D```#\`0(`%@````8"`@`,````'0("`!<````J`@(`
M+P```$("`@`X````<@("`#<```"K`@(`,0```.,"`@`D````%0,"``<````Z
M`P(`'P```$(#`@`/````8@,"`!0```!R`P(`#@```(<#`@`-````E@,"`"0`
M``"D`P(`!0```,D#`@`'````SP,"``P```#7`P(`.P```.0#`@`/````(`0"
M`!$````P!`(`(@```$($`@`E````900"`!H```"+!`(`'0```*8$`@`:````
MQ`0"`!$```#?!`(`!P```/$$`@#'````^00"``8```#!!0(`"P```,@%`@`:
M````U`4"`!4```#O!0(`!@````4&`@`)````#`8"`!@````6!@(`"P```"\&
M`@`-````.P8"`!<```!)!@(`!@```&$&`@`S````:`8"`!,```"<!@(`$P``
M`+`&`@`'````Q`8"``\```#,!@(`$0```-P&`@`>````[@8"``<````-!P(`
M&0```!4'`@`R````+P<"``0```!B!P(`1@```&<'`@`A````K@<"`!,```#0
M!P(`#````.0'`@`1````\0<"`#(````#"`(`%@```#8(`@`(````30@"`!T`
M``!6"`(`"0```'0(`@`*````?@@"`!0```")"`(`"@```)X(`@`=````J0@"
M``@```#'"`(`'P```-`(`@`(````\`@"`!H```#Y"`(`)P```!0)`@`&````
M/`D"`!4```!#"0(`!P```%D)`@`(````80D"``D```!J"0(`/P```'0)`@`'
M````M`D"``\```"\"0(`#@```,P)`@`0````VPD"``D```#L"0(`"0```/8)
M`@`(``````H"`!,````)"@(`!````!T*`@`'````(@H"`!(````J"@(`)@``
M`#T*`@`-````9`H"`!D```!R"@(`&````(P*`@`+````I0H"``X```"Q"@(`
M&0```,`*`@`*````V@H"`"0```#E"@(`(0````H+`@`*````+`L"`!,````W
M"P(`)P```$L+`@`)````<PL"``\```!]"P(`%P```(T+`@`4````I0L"`"@`
M``"Z"P(`#P```.,+`@`@````\PL"``T````4#`(`%````"(,`@`-````-PP"
M`!0```!%#`(`%````%H,`@`*````;PP"``P```!Z#`(`%P```(<,`@`$````
MGPP"`"H```"D#`(`#````,\,`@`1````W`P"``<```#N#`(``@```/8,`@`0
M````^0P"`!@````*#0(`"P```",-`@`#````+PT"``@````S#0(`!@```#P-
M`@`'````0PT"``T```!+#0(`"P```%D-`@`4````90T"`!4```!Z#0(`#@``
M`)`-`@`O````GPT"`"````#/#0(`'````/`-`@!7````#0X"`%H```!E#@(`
M/P```,`.`@`V``````\"`'X````W#P(`%0```+8/`@`,````S`\"`#$```#9
M#P(`"0````L0`@`%````%1`"`!(````;$`(`/P```"X0`@`2````;A`"``H`
M``"!$`(`!@```(P0`@`$````DQ`"``0```"8$`(`"@```)T0`@`3````J!`"
M``4```"\$`(`!@```,(0`@`&````R1`"``@```#0$`(`!````-D0`@`,````
MWA`"``H```#K$`(`.0```/80`@`N````,!$"`"D```!?$0(`!0```(D1`@`8
M````CQ$"`!D```"H$0(`'P```,(1`@`=````XA$"`!$`````$@(``@```!(2
M`@`$````%1("``H````:$@(`!@```"42`@`%````+!("``,````R$@(`#```
M`#82`@`[````0Q("`$\```!_$@(`-0```,\2`@`G````!1,"`"$````M$P(`
M)````$\3`@!%````=!,"`"8```"Z$P(`,@```.$3`@`S````%!0"`!H```!(
M%`(`'0```&,4`@!X````@10"`#0```#Z%`(`(0```"\5`@!6````414"`"@`
M``"H%0(`4P```-$5`@`Z````)18"`$(```!@%@(`&0```*,6`@`7````O18"
M`"4```#5%@(`&0```/L6`@`J````%1<"`"L```!`%P(`<@```&P7`@`@````
MWQ<"`#4`````&`(`(0```#88`@!%````6!@"`"8```">&`(`,````,48`@!+
M````]A@"`$X```!"&0(`)P```)$9`@`I````N1D"`"$```#C&0(`*`````4:
M`@`K````+AH"`!T```!:&@(`*0```'@:`@`F````HAH"`"4```#)&@(`*```
M`.\:`@`H````&!L"`"(```!!&P(`.@```&0;`@`K````GQL"`"D```#+&P(`
M(@```/4;`@`]````&!P"`$$```!6'`(`*````)@<`@`L````P1P"`#````#N
M'`(`$@```!\=`@`3````,AT"`!````!&'0(`>0```%<=`@`)````T1T"`!P`
M``#;'0(`$````/@=`@`/````"1X"`"L````9'@(`)P```$4>`@`.````;1X"
M`$L```!\'@(`H0```,@>`@!S````:A\"`'P```#>'P(`0````%L@`@`K````
MG"`"`%0```#((`(`%P```!TA`@`J````-2$"`#0```!@(0(`)P```)4A`@`6
M````O2$"``\```#4(0(`KP```.0A`@`7````E"("`"@```"L(@(`'P```-4B
M`@!`````]2("`!\````V(P(`'````%8C`@!1````<R,"`!H```#%(P(`%```
M`.`C`@`/````]2,"``H````%)`(`!0```!`D`@`&````%B0"``@````=)`(`
M!0```"8D`@`0````+"0"`!(````])`(`#````%`D`@`0````720"`!$```!N
M)`(`$P```(`D`@`=````E"0"`"````"R)`(`#P```-,D`@`/````XR0"``0`
M``#S)`(`"@```/@D`@`$`````R4"``,````()0(`"0````PE`@`'````%B4"
M``L````>)0(`"````"HE`@`'````,R4"``4````[)0(`"0```$$E`@`4````
M2R4"``8```!@)0(`!P```&<E`@`(````;R4"``\```!X)0(`#P```(@E`@`,
M````F"4"``@```"E)0(`#````*XE`@`&````NR4"``D```#")0(`"P```,PE
M`@`/````V"4"``8```#H)0(`!P```.\E`@`-````]R4"``8````%)@(`%```
M``PF`@`'````(28"``,````I)@(`"0```"TF`@`&````-R8"``P````^)@(`
M"@```$LF`@`,````5B8"`!$```!C)@(`"@```'4F`@`/````@"8"``4```"0
M)@(`"````)8F`@`$````GR8"`!D```"D)@(`$0```+XF`@`*````T"8"`!@`
M``#;)@(`$P```/0F`@`<````""<"`!$````E)P(`!````#<G`@`/````/"<"
M``<```!,)P(`!````%0G`@`$````62<"`!D```!>)P(`!P```'@G`@`"````
M@"<"``(```"#)P(`$0```(8G`@`)````F"<"``8```"B)P(`$@```*DG`@`7
M````O"<"``,```#4)P(`!@```-@G`@`,````WR<"`"<```#L)P(``@```!0H
M`@`$````%R@"``0````<*`(`#P```"$H`@`3````,2@"``<```!%*`(``@``
M`$TH`@`'````4"@"`!$```!8*`(`!@```&HH`@`+````<2@"`!@```!]*`(`
M!@```)8H`@`3````G2@"`!````"Q*`(`$@```,(H`@`.````U2@"``\```#D
M*`(``@```/0H`@`&````]R@"``P```#^*`(`"0````LI`@`1````%2D"`"(`
M```G*0(`!P```$HI`@`'````4BD"``L```!:*0(`!0```&8I`@`"````;"D"
M``L```!O*0(`#@```'LI`@`.````BBD"`%4!``"9*0(`#P```.\J`@`0````
M_RH"`!`````0*P(`$````"$K`@`3````,BL"`!$```!&*P(`#@```%@K`@`)
M````9RL"``L```!Q*P(`"````'TK`@`0````ABL"``$```"7*P(``0```)DK
M`@`5````FRL"`!H```"Q*P(`*@```,PK`@`A````]RL"`"(````9+`(`&@``
M`#PL`@`2````5RP"``,```!J+`(`&0```&XL`@`J````B"P"``L```"S+`(`
M"@```+\L`@`F````RBP"`!<```#Q+`(`0@````DM`@`I````3"T"`#\```!V
M+0(`)@```+8M`@`>````W2T"`!(```#\+0(`#0````\N`@`.````'2X"``4`
M```L+@(`(P```#(N`@`*````5BX"`!````!A+@(`#@```'(N`@`2````@2X"
M`#8```"4+@(`#P```,LN`@`A````VRX"`"X```#]+@(`$0```"PO`@`9````
M/B\"`!,```!8+P(`)P```&PO`@`A````E"\"`"\```"V+P(`'````.8O`@!E
M`````S`"`!````!I,`(`#````'HP`@`/````AS`"`"@```"7,`(`*@```,`P
M`@`,````ZS`"`!8```#X,`(`&@````\Q`@`E````*C$"`"D```!0,0(`$```
M`'HQ`@`.````BS$"`!````":,0(`$0```*LQ`@`&````O3$"`!H```#$,0(`
MP@```-\Q`@`X````HC("`#P```#;,@(`!@```!@S`@`/````'S,"`)8````O
M,P(`80```,8S`@`K````*#0"`!4```!4-`(`#P```&HT`@`5````>C0"`!4`
M``"0-`(`#0```*8T`@`6````M#0"`$````#+-`(`)P````PU`@`]````-#4"
M`"0```!R-0(`"P```)<U`@`,````HS4"`!4```"P-0(`%0```,8U`@`)````
MW#4"``L```#F-0(`"P```/(U`@`*````_C4"`#P````)-@(`%0```$8V`@`Q
M````7#8"`$$```".-@(`,````-`V`@!#`````3<"`%X```!%-P(`8````*0W
M`@!<````!3@"`&8```!B.`(`,@```,DX`@`)````_#@"`!(````&.0(`!P``
M`!DY`@`*````(3D"``X````L.0(`!0```#LY`@`"````03D"``8```!$.0(`
M$@```$LY`@`*````7CD"``D```!I.0(`#0```',Y`@`H````@3D"``X```"J
M.0(`"@```+DY`@`,````Q#D"`"X```#1.0(`+0`````Z`@`8````+CH"`!H`
M``!'.@(`%@```&(Z`@`5````>3H"``H```"/.@(`"0```)HZ`@`%````I#H"
M`!<```"J.@(`#@```,(Z`@`/````T3H"``P```#A.@(`$````.XZ`@`1````
M_SH"`!L````1.P(`%@```"T[`@`4````1#L"``P```!9.P(`$P```&8[`@`*
M````>CL"``L```"%.P(`*````)$[`@`7````NCL"`!0```#2.P(`%0```.<[
M`@`2````_3L"``X````0/`(`(0```!\\`@!;````03P"`#@```"=/`(`(0``
M`-8\`@!;````^#P"`!L```!4/0(`&P```'`]`@`2````C#T"`",```"?/0(`
M)P```,,]`@`H````ZST"``8````4/@(`"P```!L^`@`,````)SX"`(,````T
M/@(`;````+@^`@`Y````)3\"``@```!?/P(`"0```&@_`@`*````<C\"``<`
M``!]/P(`!P```(4_`@`%````C3\"``4```"3/P(`!P```)D_`@`&````H3\"
M`!X```"H/P(`#0```,<_`@`/````U3\"`!D```#E/P(`3````/\_`@!1````
M3$`"`$,```">0`(`1P```.)``@`\````*D$"`!X```!G00(`,0```(9!`@`5
M````N$$"`"<```#.00(`#@```/9!`@`G````!4("`!P````M0@(`(@```$I"
M`@`B````;4("`!4```"00@(`%@```*9"`@`B````O4("``0```#@0@(`&P``
M`.5"`@`2`````4,"`%`````40P(`%P```&5#`@`:````?4,"`#@```"80P(`
M,P```-%#`@`'````!40"``8````-1`(`"````!1$`@`.````'40"``<````L
M1`(`"````#1$`@`0````/40"``D```!.1`(`$@```%A$`@`'````:T0"``P`
M``!S1`(`$@```(!$`@`/````DT0"`!X```"C1`(`+P```,)$`@`T````\D0"
M`"$````G10(`!P```$E%`@`-````444"``@```!?10(`%0```&A%`@`,````
M?D4"``P```"+10(`0P```)A%`@`Y````W$4"`$0````61@(`,P```%M&`@`_
M````CT8"`$(```#/1@(`1````!)'`@`_````5T<"`#(```"71P(`-@```,I'
M`@`U`````4@"`$(````W2`(`/@```'I(`@`_````N4@"``D```#Y2`(`!P``
M``-)`@`3````"TD"``P````?20(`!0```"Q)`@`%````,DD"``<````X20(`
M$````$!)`@`+````44D"`!8```!=20(`!````'1)`@`W````>4D"`!````"Q
M20(`#P```,))`@`P````TDD"`!(````#2@(`5@```!9*`@`Y````;4H"``4`
M``"G2@(`%@```*U*`@`/````Q$H"`#,```#42@(`"`````A+`@`E````$4L"
M`"<````W2P(`)P```%]+`@`D````ATL"``P```"L2P(`!@```+E+`@`/````
MP$L"``8```#02P(`"0```-=+`@`(````X4L"`#8```#J2P(`/P```"%,`@`U
M````84P"`%T```"73`(`-````/5,`@`S````*DT"`#0```!>30(`00```)--
M`@!#````U4T"`#0````93@(`1P```$Y.`@`H````EDX"`"H```"_3@(`10``
M`.I.`@`T````,$\"`#H```!E3P(`+````*!/`@`9````S4\"`!T```#G3P(`
M+@````50`@`K````-%`"`"L```!@4`(`5@```(Q0`@`B````XU`"`!L````&
M40(`$P```")1`@`+````-E$"``\```!"40(`$@```%)1`@`1````95$"`"@`
M``!W40(`'P```*!1`@`&````P%$"``H```#'40(`&````-)1`@`>````ZU$"
M`"(````*4@(`.@```"U2`@`4````:%("``8```!]4@(`!P```(12`@`4````
MC%("``H```"A4@(`"````*Q2`@`N````M5("``H```#D4@(`"@```.]2`@`,
M````^E("``8````'4P(`!@````Y3`@`F````%5,"``4````\4P(`!P```$)3
M`@`&````2E,"``P```!14P(`"P```%Y3`@`H````:E,"``\```"34P(`#```
M`*-3`@`Z````L%,"``<```#K4P(`"0```/-3`@`'````_5,"``P````%5`(`
M!0```!)4`@`/````&%0"``8````H5`(`$@```"]4`@`(````0E0"`"(```!+
M5`(`"````&Y4`@`$````=U0"``T```!\5`(`"````(I4`@`G````DU0"`!``
M``"[5`(`"````,Q4`@`-````U50"``P```#C5`(`!P```/!4`@`#````^%0"
M`$<```#\5`(``P```$15`@`3````2%4"`!````!<50(`"0```&U5`@`C````
M=U4"``D```";50(`!0```*55`@`)````JU4"``<```"U50(`)@```+U5`@`G
M````Y%4"`%`````,5@(`1@```%U6`@`A````I%8"`#H```#&5@(`)@````%7
M`@`<````*%<"``8```!%5P(`!````$Q7`@`+````45<"`!(```!=5P(`,0``
M`'!7`@`@````HE<"`"$```##5P(`+P```.57`@`A````%5@"`"@````W6`(`
M80```&!8`@`I````PE@"``D```#L6`(`"@```/98`@`0`````5D"`!4````2
M60(`#0```"A9`@`%````-ED"``P````\60(`#````$E9`@`,````5ED"``P`
M``!C60(`#````'!9`@`,````?5D"`!0```"*60(`"@```)]9`@`7````JED"
M`!L```#"60(`$0```-Y9`@`3````\%D"`!4````$6@(`6````!I:`@`$````
M<UH"``T```!X6@(`!0```(9:`@`,````C%H"``X```"96@(`$0```*A:`@!7
M````NEH"`$@````26P(`2P```%M;`@!J````IUL"`%,````27`(`!@```&9<
M`@`<````;5P"`!,```"*7`(`)0```)Y<`@`9````Q%P"`#T```#>7`(`-```
M`!Q=`@`%````45T"``4```!770(`(````%U=`@`8````?ET"`!$```"770(`
M#P```*E=`@`6````N5T"`#T```#070(`$`````Y>`@`6````'UX"`!\````V
M7@(`,````%9>`@`N````AUX"`%8```"V7@(`"P````U?`@`@````&5\"``8`
M```Z7P(`%0```$%?`@`-````5U\"`!,```!E7P(`#P```'E?`@`7````B5\"
M`!(```"A7P(`50```+1?`@`A````"F`"`"H````L8`(`1@```%=@`@`O````
MGF`"`#<```#.8`(`3`````9A`@`A````4V$"`%,```!U80(`%````,EA`@!!
M````WF$"`$,````@8@(`%P```&1B`@!$````?&("`#L```#!8@(`!0```/UB
M`@`,`````V,"`!$````08P(`#P```")C`@`&````,F,"`!$````Y8P(`"```
M`$MC`@`7````5&,"``@```!L8P(`#P```'5C`@`7````A6,"``\```"=8P(`
M%````*UC`@`2````PF,"``@```#58P(`!````-YC`@`.````XV,"``P```#R
M8P(`"P```/]C`@`&````"V0"`!,````29`(`"@```"9D`@`'````,60"``T`
M```Y9`(`"0```$=D`@`,````460"``<```!>9`(`!@```&9D`@`*````;60"
M`!8```!X9`(`)P```(]D`@!8````MV0"``L````090(`"````!QE`@`*````
M)64"``\````P90(`0P```$!E`@`:````A&4"`!(```"?90(`*0```+)E`@`W
M````W&4"`"H````49@(`!0```#]F`@`?````168"`"````!E9@(`$P```(9F
M`@`4````FF8"`#,```"O9@(`0@```.-F`@`D````)F<"`!\```!+9P(`#```
M`&MG`@`F````>&<"`!T```"?9P(`#@```+UG`@`%````S&<"`"````#29P(`
M(P```/-G`@`H````%V@"`&\```!`:`(`*0```+!H`@`+````VF@"``8```#F
M:`(`!@```.UH`@`9````]&@"``X````.:0(`#P```!UI`@`&````+6D"``\`
M```T:0(`!P```$1I`@`*````3&D"`!$```!7:0(`)0```&EI`@`Q````CVD"
M`"<```#!:0(`,P```.EI`@`;````'6H"`#`````Y:@(`'0```&IJ`@`P````
MB&H"`",```"Y:@(`.0```-UJ`@`?````%VL"`"D````W:P(`)P```&%K`@`I
M````B6L"`"$```"S:P(`(0```-5K`@!(````]VL"`"<```!`;`(`0@```&AL
M`@`I````JVP"`#P```#5;`(`,P```!)M`@`A````1FT"`"$```!H;0(`*P``
M`(IM`@`?````MFT"`!\```#6;0(`.@```/9M`@`B````,6X"`!4```!4;@(`
M)P```&IN`@`@````DFX"`#\```"S;@(`*P```/-N`@`5````'V\"`)(````U
M;P(`&@```,AO`@`?````XV\"`!\````#<`(`(````"-P`@`Y````1'`"`"X`
M``!^<`(`'0```*UP`@`?````RW`"`"````#K<`(`+`````QQ`@`N````.7$"
M`#````!H<0(`+P```)EQ`@"A````R7$"`"L```!K<@(`(````)=R`@`D````
MN'("`",```#=<@(`+`````%S`@!`````+G,"`$0```!O<P(`#P```+1S`@`#
M````Q',"``<```#(<P(``P```-!S`@`*````U',"``L```#?<P(`%P```.MS
M`@`/`````W0"`!D````3=`(`%@```"UT`@`(````1'0"`"4```!-=`(`&```
M`'-T`@!F````C'0"`!,```#S=`(`)`````=U`@`9````+'4"`!(```!&=0(`
M$@```%EU`@`'````;'4"``4```!T=0(`&````'IU`@`6````DW4"`!D```"J
M=0(`%````,1U`@`7````V74"`!$```#Q=0(`'0````-V`@`4````(78"`!,`
M```V=@(`0````$IV`@`X````BW8"`$X```#$=@(`!P```!-W`@`/````&W<"
M``8````K=P(`$P```#)W`@`9````1G<"`!L```!@=P(`$````'QW`@`"````
MC7<"`%````"0=P(`"@```.%W`@`(````['<"``\```#U=P(`#@````5X`@`'
M````%'@"`!@````<>`(`$P```#5X`@`%````27@"``X```!/>`(`"````%YX
M`@`0````9W@"``H```!X>`(`#````(-X`@`3````D'@"``8```"D>`(`"@``
M`*MX`@`.````MG@"`!````#%>`(`%````-9X`@`0````ZW@"`!H```#\>`(`
M"P```!=Y`@`+````(WD"``8````O>0(`&````#9Y`@`+````3WD"`!<```!;
M>0(`#@```'-Y`@`,````@GD"``L```"/>0(`#0```)MY`@`6````J7D"`!$`
M``#`>0(`%@```-)Y`@`K````Z7D"`"H````5>@(`"P```$!Z`@`-````3'H"
M`"L```!:>@(`*P```(9Z`@`5````LGH"`!0```#(>@(`.0```-UZ`@`]````
M%WL"`!<```!5>P(`00```&U[`@`+````KWL"`!<```"[>P(`&P```--[`@`9
M````[WL"`!4````)?`(`$P```!]\`@`)````,WP"`!$````]?`(`'P```$]\
M`@`?````;WP"`",```"/?`(`#````+-\`@`&````P'P"``T```#'?`(`)```
M`-5\`@`'````^GP"``\````"?0(`!@```!)]`@`0````&7T"`#D````J?0(`
M.````&1]`@`'````G7T"``P```"E?0(`'P```+)]`@`.````TGT"`"\```#A
M?0(`&@```!%^`@`:````+'X"`!H```!'?@(`"0```&)^`@`%````;'X"`!T`
M``!R?@(`$0```)!^`@`H````HGX"`"0```#+?@(`'````/!^`@`*````#7\"
M`!4````8?P(`,0```"Y_`@`]````8'\"`#H```">?P(`!@```-E_`@`3````
MX'\"``@```#T?P(`"0```/U_`@`Z````!X`"``X```!"@`(`)````%&``@`L
M````=H`"`!<```"C@`(`0````+N``@`.````_(`"`!@````+@0(`+@```"2!
M`@`&````4X$"``@```!:@0(`"P```&.!`@`9````;X$"`#$```")@0(`$```
M`+N!`@`@````S($"`"0```#M@0(`%@```!*"`@`'````*8("``X````Q@@(`
M#@```$""`@`/````3X("``<```!?@@(`$````&>"`@`0````>(("`%8```")
M@@(`!0```.""`@`%````YH("`"P```#L@@(`!P```!F#`@`'````(8,"`!4`
M```I@P(`#@```#^#`@`3````3H,"``X```!B@P(`$````'&#`@`1````@H,"
M`!@```"4@P(`$P```*V#`@`=````P8,"`"L```#?@P(`&`````N$`@`2````
M)(0"`!@````WA`(`%@```%"$`@`7````9X0"`!H```!_A`(`,````)J$`@`:
M````RX0"``@```#FA`(`!@```.^$`@`+````]H0"``P````"A0(``@````^%
M`@`*````$H4"`!`````=A0(`)P```"Z%`@`9````5H4"`!0```!PA0(`!@``
M`(6%`@`J````C(4"`#\```"WA0(`$````/>%`@`8````"(8"`!@````AA@(`
M%````#J&`@`3````3X8"``T```!CA@(`#@```'&&`@`/````@(8"`!0```"0
MA@(`%P```*6&`@`Z````O88"`!L```#XA@(`+0```!2'`@`4````0H<"``<`
M``!7AP(`!P```%^'`@`8````9X<"``T```"`AP(`'````(Z'`@`.````JX<"
M`!$```"ZAP(`$P```,R'`@!G````X(<"`!0```!(B`(`%````%V(`@`G````
M<H@"`"0```":B`(`,P```+^(`@`F````\X@"``L````:B0(`*@```":)`@`6
M````48D"``<```!HB0(`!0```'")`@`P````=HD"`!\```"GB0(`+````,>)
M`@`B````](D"`!X````7B@(`(@```#:*`@`B````68H"`!H```!\B@(`&P``
M`)>*`@`%````LXH"``<```"YB@(`!P```,&*`@`(````R8H"`!L```#2B@(`
M$@```.Z*`@`1`````8L"`!(````3BP(`$0```":+`@`@````.(L"`!0```!9
MBP(`#P```&Z+`@`/````?HL"``<```".BP(`"````):+`@`/````GXL"`!<`
M``"OBP(`#P```,>+`@`.````UXL"`!0```#FBP(`0P```/N+`@`Z````/XP"
M``P```!ZC`(`%@```(>,`@`P````GHP"``\```#/C`(`"P```-^,`@`'````
MZXP"`"````#SC`(`#````!2-`@`;````(8T"`"0````]C0(`(P```&*-`@`?
M````AHT"`!\```"FC0(`*0```,:-`@`<````\(T"`!8````-C@(`!@```"2.
M`@`<````*XX"``H```!(C@(`#0```%..`@`%````88X"``8```!GC@(`"```
M`&Z.`@`+````=XX"``T```"#C@(`"P```)&.`@`B````G8X"`"H```#`C@(`
M(P```.N.`@`A````#X\"``T````QCP(`'0```#^/`@`0````78\"`!0```!N
MCP(`#````(./`@`.````D(\"``X```"?CP(`#P```*Z/`@`%````OH\"``@`
M``#$CP(`(@```,V/`@`C````\(\"`!4````4D`(`#@```"J0`@`1````.9`"
M`!````!+D`(`*````%R0`@`2````A9`"`!(```"8D`(`)0```*N0`@`P````
MT9`"``L````"D0(`'`````Z1`@`9````*Y$"``0```!%D0(`!0```$J1`@`4
M````4)$"`!X```!ED0(`$````(21`@`5````E9$"``P```"KD0(`#0```+B1
M`@`'````QI$"``<```#.D0(`!````-:1`@`<````VY$"`"8```#XD0(`$P``
M`!^2`@`5````,Y("`"4```!)D@(`&0```&^2`@`/````B9("``4```"9D@(`
M(0```)^2`@`-````P9("`),```#/D@(`%0```&.3`@!'````>9,"``D```#!
MDP(`"@```,N3`@`3````UI,"``P```#JDP(`#@```/>3`@`(````!I0"``\`
M```/E`(`$````!^4`@`8````,)0"`"@```!)E`(`$@```'*4`@`"````A90"
M``@```"(E`(`!@```)&4`@`1````F)0"`!X```"JE`(`#@```,F4`@`1````
MV)0"`!T```#JE`(`"@````B5`@`)````$Y4"`!$````=E0(`"@```"^5`@`/
M````.I4"``@```!*E0(`"0```%.5`@`$````794"``4```!BE0(`(@```&B5
M`@`%````BY4"`!P```"1E0(`"0```*Z5`@`&````N)4"`!$```"_E0(`$```
M`-&5`@`/````XI4"``<```#RE0(`!0```/J5`@`B`````)8"``4````CE@(`
M"0```"F6`@`'````,Y8"`!$````[E@(`!````$V6`@`-````4I8"`"````!@
ME@(`!0```(&6`@`-````AY8"``L```"5E@(`#0```*&6`@`*````KY8"``<`
M``"ZE@(`%````,*6`@`)````UY8"``<```#AE@(`#P```.F6`@`C````^98"
M`$@````=EP(`*P```&:7`@`K````DI<"``8```"^EP(`"@```,67`@`$````
MT)<"``D```#5EP(`"````-^7`@`4````Z)<"``L```#]EP(`!@````F8`@`-
M````$)@"``8````>F`(`!0```"68`@`$````*Y@"`!0````PF`(`1@```$68
M`@!/````C)@"`$L```#<F`(`(````"B9`@`%````29D"``X```!/F0(`!```
M`%Z9`@`&````8YD"``<```!JF0(`&````'*9`@`4````BYD"`!4```"@F0(`
M!P```+:9`@`$````OID"`!8```##F0(`!````-J9`@`/````WYD"`!L```#O
MF0(`*@````N:`@`*````-IH"`"(```!!F@(`$0```&2:`@`5````=IH"``8`
M``",F@(`$P```).:`@`'````IYH"``4```"OF@(`)P```+6:`@`$````W9H"
M``H```#BF@(`#0```.V:`@`.````^YH"``@````*FP(`"0```!.;`@`%````
M'9L"`#`````CFP(`,@```%2;`@`Z````AYL"`"````#"FP(`20```..;`@`Y
M````+9P"`"D```!GG`(`.````)&<`@`J````RIP"`"P```#UG`(`(0```"*=
M`@`1````1)T"`!````!6G0(`"P```&>=`@`E````<YT"`!\```"9G0(`)P``
M`+F=`@`A````X9T"`",````#G@(`.P```">>`@`'````8YX"``D```!KG@(`
M"@```'6>`@`&````@)X"``0```"'G@(`*@```(R>`@`U````MYX"`"D```#M
MG@(`*0```!>?`@`R````09\"`!(```!TGP(`,@```(>?`@`R````NI\"`!T`
M``#MGP(`%`````N@`@`>````(*`"``D````_H`(`'P```$F@`@`M````::`"
M`!8```"7H`(`$0```*Z@`@`'````P*`"``L```#(H`(`#0```-2@`@`0````
MXJ`"``\```#SH`(`0`````.A`@!?````1*$"`#8```"DH0(`C0```-NA`@!D
M````::("``L```#.H@(`&````-JB`@`$````\Z("`!$```#XH@(`"`````JC
M`@`)````$Z,"`!`````=HP(`$0```"ZC`@`,````0*,"``4```!-HP(``P``
M`%.C`@`)````5Z,"``T```!AHP(`"P```&^C`@`-````>Z,"`"(```")HP(`
M)P```*RC`@`G````U*,"`"D```#\HP(`$@```":D`@`6````.:0"`!D```!0
MI`(`$````&JD`@`1````>Z0"`"$```"-I`(`$````*^D`@`&````P*0"``\`
M``#'I`(`(````->D`@`0````^*0"``X````)I0(`"````!BE`@`3````(:4"
M``4````UI0(`,P```#NE`@`F````;Z4"`!P```"6I0(`)@```+.E`@!T````
MVJ4"`!````!/I@(`!0```&"F`@`5````9J8"``D```!\I@(`!````(:F`@`+
M````BZ8"`!X```"7I@(`(0```+:F`@`C````V*8"`"4```#\I@(`$@```"*G
M`@`5````-:<"`!D```!+IP(`"@```&6G`@`O````<*<"`"\```"@IP(`'@``
M`-"G`@`.````[Z<"`!````#^IP(`$P````^H`@`B````(Z@"`"````!&J`(`
M(````&>H`@`>````B*@"`"0```"GJ`(`(@```,RH`@`:````[Z@"`#4````*
MJ0(`$@```$"I`@`0````4ZD"`!(```!DJ0(`$@```'>I`@`4````BJD"`!4`
M``"?J0(`$P```+6I`@`0````R:D"`!(```#:J0(`*0```.VI`@`3````%ZH"
M`!4````KJ@(`2@```$&J`@`<````C*H"``P```"IJ@(`$0```+:J`@`N````
MR*H"``\```#WJ@(`'0````>K`@`A````):L"`!4```!'JP(`$0```%VK`@`2
M````;ZL"`"H```""JP(`'0```*VK`@`?````RZL"`!8```#KJP(`$@````*L
M`@`7````%:P"`!4````MK`(`$P```$.L`@`=````5ZP"`"````!UK`(`)0``
M`):L`@`3````O*P"`#$```#0K`(`,0````*M`@`4````-*T"`!0```!)K0(`
M'````%ZM`@`5````>ZT"`!4```"1K0(`&0```*>M`@`+````P:T"``H```#-
MK0(`&P```-BM`@`<````]*T"``0````1K@(`!P```!:N`@`)````'JX"`!<`
M```HK@(`!@```$"N`@`1````1ZX"``H```!9K@(`!@```&2N`@`'````:ZX"
M``@```!SK@(`!@```'RN`@`4````@ZX"``8```"8K@(`"````)^N`@`(````
MJ*X"``<```"QK@(`!P```+FN`@`0````P:X"``X```#2K@(`$@```.&N`@`0
M````]*X"``(````%KP(`"0````BO`@`5````$J\"``4````HKP(`,````"ZO
M`@`3````7Z\"``X```!SKP(`$````(*O`@`.````DZ\"``X```"BKP(`#@``
M`+&O`@`K````P*\"`$(```#LKP(`40```"^P`@!?````@;`"`#8```#AL`(`
M!@```!BQ`@`(````'[$"`#4````HL0(`'@```%ZQ`@`.````?;$"``8```",
ML0(`"0```).Q`@`)````G;$"``4```"GL0(`)````*VQ`@`5````TK$"`!P`
M``#HL0(`#@````6R`@`9````%+("`!8````NL@(`%````$6R`@`A````6K("
M`"4```!\L@(`+0```**R`@`&````T+("``0```#7L@(`"````-RR`@`<````
MY;("``<````"LP(`!0````JS`@`,````$+,"``L````=LP(`!@```"FS`@`$
M````,+,"``<````ULP(`%0```#VS`@`,````4[,"``X```!@LP(`#P```&^S
M`@`8````?[,"`!D```"8LP(`$P```+*S`@`=````QK,"`!,```#DLP(`$P``
M`/BS`@`)````#+0"``8````6M`(`%P```!VT`@`0````-;0"`#\```!&M`(`
M)P```(:T`@`&````KK0"`!4```"UM`(`#P```,NT`@`>````V[0"`!$```#Z
MM`(`%0````RU`@`,````(K4"`'H````OM0(`#@```*JU`@`+````N;4"``D`
M``#%M0(`#P```,^U`@`,````W[4"``T```#LM0(`'0```/JU`@`8````&+8"
M`"(````QM@(`(@```%2V`@`H````=[8"``P```"@M@(`!P```*VV`@`+````
MM;8"`!@```#!M@(`$P```-JV`@`4````[K8"``8````#MP(`#P````JW`@`<
M````&K<"`"(````WMP(`#0```%JW`@`/````:+<"`!X```!XMP(`90```)>W
M`@`@````_;<"``P````>N`(`!P```"NX`@`&````,[@"`!4````ZN`(`'@``
M`%"X`@`=````;[@"`!H```"-N`(`"````*BX`@`)````L;@"``(```"[N`(`
M!````+ZX`@`@````P[@"``8```#DN`(`!0```.NX`@`J````\;@"`!(````<
MN0(`"@```"^Y`@`'````.KD"``H```!"N0(`#P```$VY`@`3````7;D"`"\`
M``!QN0(`!@```*&Y`@`G````J+D"``X```#0N0(`!@```-^Y`@`'````YKD"
M``H```#NN0(`!0```/FY`@`%````_[D"`(,````%N@(`#````(FZ`@`/````
MEKH"`!@```"FN@(`"0```+^Z`@`*````R;H"`"L```#4N@(`*0````"[`@`)
M````*KL"`"4````TNP(`)P```%J[`@`F````@KL"`!X```"INP(`+````,B[
M`@`/````];L"``H````%O`(`&@```!"\`@`>````*[P"`!````!*O`(`"@``
M`%N\`@`)````9KP"`!H```!PO`(`*0```(N\`@`G````M;P"`"8```#=O`(`
M(P````2]`@`8````*+T"`!X```!!O0(`%@```&"]`@`I````=[T"`#@```"A
MO0(`"````-J]`@`)````X[T"``H```#MO0(`!P```/B]`@`3`````+X"``P`
M```4O@(`#0```"&^`@`&````+[X"`!$````VO@(`#P```$B^`@`/````6+X"
M``X```!HO@(`#````'>^`@`4````A+X"`%(```"9O@(`#````.R^`@`/````
M^;X"`!(````)OP(`#0```!R_`@`6````*K\"`!8```!!OP(`$0```%B_`@`:
M````:K\"``T```"%OP(`&````)._`@`^````K+\"`!D```#KOP(`#@````7`
M`@`H````%,`"`!`````]P`(`"0```$[``@`@````6,`"`%D```!YP`(`&@``
M`-/``@`&````[L`"`!X```#UP`(`+0```!3!`@`(````0L$"``<```!+P0(`
M'P```%/!`@`(````<\$"``L```!\P0(`)P```(C!`@`F````L,$"`"4```#7
MP0(`"0```/W!`@`*````!\("`"(````2P@(`7````#7"`@`4````DL("`"8`
M``"GP@(`%````,["`@`"````X\("`!$```#FP@(`"P```/C"`@`6````!,,"
M``4````;PP(`#@```"'#`@`'````,,,"`!(````XPP(`!@```$O#`@`(````
M4L,"`!$```!;PP(`#0```&W#`@`*````>\,"``P```"&PP(`,P```)/#`@!#
M````Q\,"``<````+Q`(`$0```!/$`@`2````)<0"`"`````XQ`(`%P```%G$
M`@`&````<<0"``\```!XQ`(`$0```(C$`@`/````FL0"``\```"JQ`(`#P``
M`+K$`@!2````RL0"``\````=Q0(`#P```"W%`@`(````/<4"`!P```!&Q0(`
M'@```&/%`@`5````@L4"`!````"8Q0(`"P```*G%`@`2````M<4"`!T```#(
MQ0(`#````.;%`@`7````\\4"``\````+Q@(`#0```!O&`@`)````*<8"``8`
M```SQ@(`!````#K&`@`K````/\8"``<```!KQ@(`!0```'/&`@`4````><8"
M``4```".Q@(`"@```)3&`@`5````G\8"`!$```"UQ@(`&@```,?&`@`6````
MXL8"`!0```#YQ@(`%P````['`@`>````)L<"`!T```!%QP(`&@```&/'`@`&
M````?L<"``H```"%QP(`&P```)#'`@`$````K,<"``X```"QQP(`#0```,#'
M`@`+````SL<"``\```#:QP(`"P```.K'`@`2````]L<"``<````)R`(`(P``
M`!'(`@`-````-<@"``T```!#R`(`#0```%'(`@`:````7\@"`"8```!ZR`(`
M%````*'(`@`'````ML@"`!````"^R`(`"````,_(`@`4````V,@"``\```#M
MR`(`#0```/W(`@`3````"\D"``D````?R0(`"0```"G)`@`%````,\D"``<`
M```YR0(``@```$')`@`$````1,D"``(```!)R0(`%P```$S)`@`+````9,D"
M`"4```!PR0(`"P```);)`@`J````HLD"`"X```#-R0(`#@```/S)`@`<````
M"\H"`"T````HR@(`'````%;*`@!$````<\H"`$,```"XR@(`#0```/S*`@`B
M````"LL"`#8````MRP(`#````&3+`@`I````<<L"`!T```";RP(`(@```+G+
M`@`B````W,L"`"<```#_RP(`$````"?,`@`4````.,P"`#````!-S`(`'@``
M`'[,`@`7````G<P"`#0```"US`(`&0```.K,`@`K````!,T"`#(````PS0(`
M%0```&/-`@`8````><T"`!<```"2S0(`(````*K-`@`=````R\T"`!,```#I
MS0(`*@```/W-`@`7````*,X"`!P```!`S@(`&@```%W.`@`O````>,X"`"\`
M``"HS@(`,P```-C.`@`P````#,\"`#$````]SP(`+@```&_/`@!K````GL\"
M`"4````*T`(`*0```##0`@`I````6M`"`#P```"$T`(`20```,'0`@`9````
M"]$"``L````ET0(`&P```#'1`@`*````3=$"`#<```!8T0(`%````)#1`@`5
M````I=$"``T```"[T0(`+````,G1`@`J````]M$"`!H````AT@(`+````#S2
M`@`H````:=("``D```"2T@(`6P```)S2`@!-````^-("``X```!&TP(`"0``
M`%73`@`@````7],"`"8```"`TP(`#@```*?3`@`(````MM,"`!@```"_TP(`
M&P```-C3`@`%````]-,"``H```#ZTP(`"`````74`@`,````#M0"``H````;
MU`(`"0```";4`@`3````,-0"`!````!$U`(`&````%74`@`6````;M0"`!(`
M``"%U`(`$@```)C4`@`+````J]0"``H```"WU`(`+0```,+4`@`-````\-0"
M``D```#^U`(`)0````C5`@`O````+M4"``D```!>U0(`"0```&C5`@`2````
M<M4"`!4```"%U0(`<P```)O5`@!J````#]8"`!````!ZU@(`.0```(O6`@`"
M````Q=8"``,```#(U@(`!P```,S6`@`.````U-8"``<```#CU@(`!P```.O6
M`@`3````\]8"``@````'UP(`.````!#7`@`.````2=<"``X```!8UP(`&0``
M`&?7`@`_````@=<"``0```#!UP(`,````,;7`@`W````]]<"`!P````OV`(`
M+````$S8`@`J````>=@"`%4```"DV`(`#````/K8`@`6````!]D"`$<````>
MV0(`"P```&;9`@`C````<MD"`!$```"6V0(`%P```*C9`@`)````P-D"`!``
M``#*V0(`$0```-O9`@`,````[=D"`!,```#ZV0(`#`````[:`@`;````&]H"
M`!L````WV@(``P```%/:`@`+````5]H"`!0```!CV@(`#@```'C:`@`0````
MA]H"`!(```"8V@(`*````*O:`@`<````U-H"``,```#QV@(`'@```/7:`@`2
M````%-L"`!,````GVP(`"P```#O;`@`P````1]L"``T```!XVP(`&````(;;
M`@`\````G]L"`!(```#<VP(`&P```._;`@`Y````"]P"`#````!%W`(`&```
M`';<`@`7````C]P"`"````"GW`(`)P```,C<`@`E````\-P"`"4````6W0(`
M*P```#S=`@!*````:-T"`#X```"SW0(`N````/+=`@`)````J]X"`!$```"U
MW@(`$@```,?>`@`'````VMX"``H```#BW@(`!P```.W>`@`.````]=X"``<`
M```$WP(`$`````S?`@`$````'=\"`"H````BWP(`$@```$W?`@`R````8-\"
M`#(```"3WP(`%0```,;?`@`<````W-\"`!(```#YWP(`!0````S@`@`,````
M$N`"`",````?X`(`)````$/@`@`(````:.`"``4```!QX`(`'````'?@`@`&
M````E.`"`!$```";X`(`"````*W@`@`&````MN`"`!$```"]X`(`#@```,_@
M`@`:````WN`"`"````#YX`(`#P```!KA`@`@````*N$"`!T```!+X0(`"```
M`&GA`@`:````<N$"``X```"-X0(`*P```)SA`@`7````R.$"``D```#@X0(`
M"@```.KA`@`=````]>$"``4````3X@(`$P```!GB`@`%````+>("`"@````S
MX@(`!P```%SB`@`)````9.("`!P```!NX@(`/````(OB`@`&````R.("`!L`
M``#/X@(`$````.OB`@`(````_.("`!,````%XP(`*0```!GC`@`0````0^,"
M``L```!4XP(`,````&#C`@`O````D>,"`"X```#!XP(`,@```/#C`@`$````
M(^0"``@````HY`(`"P```#'D`@`'````/>0"``D```!%Y`(`"````$_D`@`'
M````6.0"`$4```!@Y`(`%@```*;D`@`'````O>0"`-H```#%Y`(`%0```*#E
M`@`M````MN4"`#L```#DY0(`%P```"#F`@`@````..8"`!@```!9Y@(`%0``
M`'+F`@`^````B.8"`!P```#'Y@(`&````.3F`@`/````_>8"`&<````-YP(`
M:@```'7G`@!)`0``X.<"`!T````JZ0(`$````$CI`@`E````6>D"`!@```!_
MZ0(`6````)CI`@`L````\>D"`#,````>Z@(`*P```%+J`@`L````?NH"`#(`
M``"KZ@(`(````-[J`@`%````_^H"``H````%ZP(`!P```!#K`@`)````&.L"
M`!(````BZP(`%0```#7K`@`X````2^L"``X```"$ZP(`+@```)/K`@`C````
MPNL"`!\```#FZP(`'0````;L`@`U````).P"`#H```!:[`(`"@```)7L`@`:
M````H.P"``P```"[[`(`"@```,CL`@`A````T^P"`!````#U[`(`#@````;M
M`@`3````%>T"``<````I[0(`$@```#'M`@`,````1.T"``X```!1[0(`&@``
M`&#M`@`'````>^T"``\```"#[0(`"0```)/M`@`[````G>T"`#X```#9[0(`
M$````!CN`@`+````*>X"``X````U[@(`&@```$3N`@`7````7^X"`"\```!W
M[@(`,````*?N`@`+````V.X"`!````#D[@(`#P```/7N`@`:````!>\"`"H`
M```@[P(`'P```$OO`@`\````:^\"`"D```"H[P(`*@```-+O`@`H````_>\"
M``4````F\`(`!@```"SP`@`'````,_`"`"<````[\`(`)````&/P`@`;````
MB/`"``L```"D\`(`'@```+#P`@`,````S_`"``0```#<\`(`$````.'P`@`/
M````\O`"``D````"\0(`#`````SQ`@`.````&?$"`!8````H\0(`!0```#_Q
M`@`$````1?$"`!(```!*\0(`,0```%WQ`@!$````C_$"`!P```#4\0(`#@``
M`/'Q`@`6`````/("`!0````7\@(`#P```"SR`@`.````//("`!4```!+\@(`
M&@```&'R`@`<````?/("`!<```"9\@(`!P```+'R`@`C````N?("`!L```#=
M\@(`&````/GR`@`4````$O,"``X````G\P(`#P```#;S`@`6````1O,"``T`
M``!=\P(`'````&OS`@`7````B/,"`!$```"@\P(`#0```++S`@`O````P/,"
M``8```#P\P(`"P```/?S`@`:`````_0"``T````>]`(`#P```"ST`@`+````
M//0"`#P```!(]`(`#````(7T`@`&````DO0"`!X```"9]`(`#P```+CT`@`3
M````R/0"`!<```#<]`(`/@```/3T`@!&````,_4"`!````!Z]0(`%0```(OU
M`@`&````H?4"`!(```"H]0(`#P```+OU`@`0````R_4"``\```#<]0(`$```
M`.SU`@`0````_?4"`"H````.]@(`20```#GV`@`Q````@_8"``T```"U]@(`
M#P```,/V`@`(````T_8"`!0```#<]@(`%````/'V`@`C````!O<"`"<````J
M]P(`(P```%+W`@`>````=O<"`!\```"5]P(`.P```+7W`@`\````\?<"`#@`
M```N^`(`$0```&?X`@`6````>?@"``@```"0^`(`$0```)GX`@`3````J_@"
M`"(```"_^`(`&````.+X`@`(````^_@"``4````$^0(`$`````KY`@`=````
M&_D"`!T````Y^0(`$````%?Y`@!)````:/D"`!8```"R^0(`!P```,GY`@`1
M````T?D"`!P```#C^0(`"P````#Z`@`%````#/H"``P````2^@(`"P```!_Z
M`@`0````*_H"``4````\^@(`!P```$+Z`@`*````2OH"`!,```!5^@(`$P``
M`&GZ`@`,````??H"``P```"*^@(`!@```)?Z`@`)````GOH"`#8```"H^@(`
M*````-_Z`@`C````"/L"``<````L^P(`(````#3[`@`&````5?L"``8```!<
M^P(`)````&/[`@`5````B/L"`!4```">^P(`#@```+3[`@`S````P_L"`!``
M``#W^P(`&P````C\`@`_````)/P"`#(```!D_`(`*````)?\`@`;````P/P"
M`#0```#<_`(`&@```!']`@`C````+/T"`"X```!0_0(`0P```'_]`@!E````
MP_T"`$\````I_@(`O0```'G^`@`H````-_\"`!$```!@_P(`!````'+_`@`1
M````=_\"`!P```")_P(``P```*;_`@`(````JO\"`!(```"S_P(`"````,;_
M`@`"````S_\"`!@```#2_P(`$````.O_`@`,````_/\"`!0````)``,`"P``
M`!X``P`8````*@`#`!P```!#``,`&````&```P`%````>0`#``H```!_``,`
M%````(H``P`<````GP`#``T```"\``,`!P```,H``P`,````T@`#``H```#?
M``,`1@```.H``P`/````,0$#``P```!!`0,`%P```$X!`P`1````9@$#`!(`
M``!X`0,`$````(L!`P`/````G`$#`"0```"L`0,`2@```-$!`P`[````'`(#
M`"H```!8`@,`%P```(,"`P`<````FP(#`#<```"X`@,`10```/`"`P`8````
M-@,#``4```!/`P,`!````%4#`P`'````6@,#``H```!B`P,`#@```&T#`P`-
M````?`,#``4```"*`P,`!P```)`#`P`6````F`,#`!$```"O`P,`$@```,$#
M`P`.````U`,#`!<```#C`P,`%0```/L#`P`0````$00#`!,````B!`,`&@``
M`#8$`P!'````400#``X```"9!`,`)````*@$`P`V````S00#`!8````$!0,`
M#P```!L%`P`/````*P4#`&L````[!0,`(````*<%`P`>````R`4#`"D```#G
M!0,`'````!$&`P`>````+@8#`"````!-!@,`&````&X&`P`D````AP8#`!(`
M``"L!@,`&0```+\&`P`5````V08#`"D```#O!@,`&@```!D'`P`-````-`<#
M`!0```!"!P,`"@```%<'`P`=````8@<#`#,```"`!P,`!P```+0'`P`+````
MO`<#`!P```#(!P,`'0```.4'`P`'`````P@#`!0````+"`,`"P```"`(`P`(
M````+`@#`"(````U"`,`.@```%@(`P`)````DP@#`!,```"="`,`&@```+$(
M`P`(````S`@#``4```#5"`,`2@```-L(`P!'````)@D#`"\```!N"0,`3P``
M`)X)`P!-````[@D#`&0````\"@,`!P```*$*`P`H````J0H#`"P```#2"@,`
M"@```/\*`P`4````"@L#`!<````?"P,`-@```#<+`P`(````;@L#``T```!W
M"P,`,@```(4+`P!O````N`L#`#,````H#`,`1@```%P,`P`\````HPP#``4`
M``#@#`,`%````.8,`P`:````^PP#``\````6#0,`&@```"8-`P`6````00T#
M`!H```!8#0,`$P```',-`P`P````APT#`%(```"X#0,`+`````L.`P`R````
M.`X#`"0```!K#@,`#@```)`.`P`P````GPX#`"````#0#@,`(````/$.`P`<
M````$@\#`#(````O#P,`"P```&(/`P`C````;@\#`!T```"2#P,`(P```+`/
M`P`O````U`\#`!H````$$`,`(P```!\0`P`,````0Q`#``<```!0$`,`$```
M`%@0`P`1````:1`#`!0```![$`,`"````)`0`P`(````F1`#`$````"B$`,`
M!0```.,0`P`,````Z1`#``@```#V$`,`#0```/\0`P`:````#1$#``\````H
M$0,`"0```#@1`P`$````0A$#`!8```!'$0,`"````%X1`P`(````9Q$#``0`
M``!P$0,`"P```'41`P`+````@1$#`!0```"-$0,`$P```*(1`P`.````MA$#
M`!0```#%$0,`#@```-H1`P`'````Z1$#`!````#Q$0,`&`````(2`P`;````
M&Q(#`!H````W$@,`'````%(2`P`7````;Q(#`"$```"'$@,`'@```*D2`P`<
M````R!(#``L```#E$@,`#0```/$2`P`;````_Q(#`"H````;$P,`&````$83
M`P`>````7Q,#`"H```!^$P,`!````*D3`P`$````KA,#``T```"S$P,`!P``
M`,$3`P`*````R1,#`!$```#4$P,`%@```.83`P`-````_1,#`"P````+%`,`
M&````#@4`P`/````410#`!X```!A%`,`-````(`4`P`(````M10#``H```"^
M%`,`"````,D4`P`'````TA0#``D```#:%`,`"0```.04`P`)````[A0#``4`
M``#X%`,`#````/X4`P`.````"Q4#``H````:%0,`$0```"45`P`2````-Q4#
M``L```!*%0,`!````%85`P`.````6Q4#``H```!J%0,`"@```'45`P`/````
M@!4#`!0```"0%0,`'````*45`P`4````PA4#``L```#7%0,``@```.,5`P`(
M````YA4#`!\```#O%0,`!P````\6`P`-````%Q8#``8````E%@,`:````"P6
M`P`-````E18#``P```"C%@,`"````+`6`P`H````N18#`$0```#B%@,`'P``
M`"<7`P`M````1Q<#`%@```!U%P,`)@```,X7`P`I````]1<#`!@````?&`,`
M'0```#@8`P`%````5A@#``H```!<&`,`"@```&<8`P`-````<A@#``T```"`
M&`,`"P```(X8`P`-````FA@#`!4```"H&`,`#P```+X8`P`-````SA@#``\`
M``#<&`,`#P```.P8`P`$````_!@#``<````!&0,`"`````D9`P`9````$AD#
M``@````L&0,`!@```#49`P`5````/!D#`!(```!2&0,`$P```&49`P`'````
M>1D#`!,```"!&0,`!@```)49`P`;````G!D#`!8```"X&0,`"P```,\9`P`9
M````VQD#``P```#U&0,`%@````(:`P`,````&1H#``@````F&@,`#P```"\:
M`P`2````/QH#``\```!2&@,`!@```&(:`P`7````:1H#``L```"!&@,`'@``
M`(T:`P`&````K!H#``@```"S&@,`!P```+P:`P`-````Q!H#`"````#2&@,`
M"0```/,:`P`+````_1H#`"8````)&P,`&````#`;`P`0````21L#``T```!:
M&P,`&@```&@;`P`6````@QL#`$(```":&P,`!@```-T;`P`+````Y!L#``X`
M``#P&P,`"0```/\;`P`"````"1P#``X````,'`,`!P```!L<`P`F````(QP#
M`",```!*'`,`*0```&X<`P`K````F!P#`&````#$'`,`'````"4=`P`@````
M0AT#`#````!C'0,`+````)0=`P`I````P1T#`"$```#K'0,`(@````T>`P!:
M````,!X#`!H```"+'@,`#0```*8>`P`7````M!X#`$T```#,'@,`-````!H?
M`P`D````3Q\#`#(```!T'P,`2@```*<?`P!3````\A\#`$P```!&(`,`(0``
M`),@`P`D````M2`#`#,```#:(`,`(0````XA`P`>````,"$#`"8```!/(0,`
M,@```'8A`P`K````J2$#`!,```#5(0,`&@```.DA`P"`````!"(#`#<```"%
M(@,`.0```+TB`P`Z````]R(#`#@````R(P,`%0```&LC`P`9````@2,#`"``
M``";(P,`/0```+PC`P`H````^B,#`)@"```C)`,`&@```+PF`P!R````UR8#
M`$0```!*)P,`$````(\G`P`_````H"<#`",```#@)P,`)0````0H`P`>````
M*B@#`!L```!)*`,`6@```&4H`P`N````P"@#`!H```#O*`,`%`````HI`P`6
M````'RD#`"4````V*0,`A0```%PI`P`N````XBD#`"4````1*@,`1````#<J
M`P!/````?"H#`$H```#,*@,`+````!<K`P`Y````1"L#`#4```!^*P,`+```
M`+0K`P`9````X2L#`!````#[*P,`I@````PL`P`E````LRP#`!L```#9+`,`
M'````/4L`P`R````$BT#`"$```!%+0,`(@```&<M`P`H````BBT#`",```"S
M+0,`)P```-<M`P`;````_RT#`!T````;+@,`'@```#DN`P`C````6"X#`"H`
M``!\+@,`#@```*<N`P`?````MBX#`!H```#6+@,`*@```/$N`P`8````'"\#
M`"D````U+P,`,````%\O`P`9````D"\#``T```"J+P,`*P```+@O`P`D````
MY"\#`#,````),`,`*````#TP`P`A````9C`#`$8```"(,`,`(````,\P`P`<
M````\#`#`#H````-,0,`90```$@Q`P`Y````KC$#`#4```#H,0,`2P```!XR
M`P!&````:C(#`#4```"Q,@,`*````.<R`P`V````$#,#`%P```!',P,`.@``
M`*0S`P!>````WS,#`%(````^-`,`4@```)$T`P!'````Y#0#`"L````L-0,`
M+P```%@U`P!E````B#4#`"P```#N-0,`*````!LV`P`H````1#8#`"P```!M
M-@,`*P```)HV`P`^````QC8#`%<````%-P,`90```%TW`P!6````PS<#`#$`
M```:.`,`*@```$PX`P!'````=S@#`$4```"_.`,`+`````4Y`P`J````,CD#
M`%,```!=.0,`+P```+$Y`P`N````X3D#`!P````0.@,`)@```"TZ`P`I````
M5#H#`"D```!^.@,`*0```*@Z`P!H````TCH#`&(````[.P,`:P```)X[`P"[
M````"CP#`!H```#&/`,`+@```.$\`P`W````$#T#`"@```!(/0,`9````'$]
M`P`8````UCT#`%@```#O/0,`'````$@^`P`+````93X#`,P```!Q/@,`,0``
M`#X_`P`I````<#\#`%4```":/P,`1````/`_`P!?````-4`#`#\```"50`,`
M7@```-5``P`U````-$$#`#8```!J00,`.0```*%!`P`?````VT$#`!P```#[
M00,`%````!A"`P!/````+4(#`"(```!]0@,`/````*!"`P`J````W4(#`"``
M```(0P,`&````"E#`P`Y````0D,#`#,```!\0P,`%````+!#`P`5````Q4,#
M``8```#;0P,`!P```.)#`P`$````ZD,#``P```#O0P,`$````/Q#`P`,````
M#40#``L````:1`,`!P```"9$`P`2````+D0#``T```!!1`,`%0```$]$`P!Q
M````940#`((```#71`,`6````%I%`P`&````LT4#`!4```"Z10,`!````-!%
M`P`'````U44#``@```#=10,`!0```.9%`P!2````[$4#``0````_1@,`&0``
M`$1&`P`?````7D8#``H```!^1@,`#P```(E&`P`0````F48#`!(```"J1@,`
M$````+U&`P`"````SD8#``<```#11@,`!@```-E&`P`3````X$8#``P```#T
M1@,`%@````%'`P`&````&$<#`!0````?1P,`#P```#1'`P`#````1$<#`"X`
M``!(1P,`!````'='`P`&````?$<#``<```"#1P,`'@```(M'`P`\````JD<#
M`"X```#G1P,`+P```!9(`P`6````1D@#`"@```!=2`,`,````(9(`P`B````
MMT@#`"H```#:2`,`(`````5)`P`C````)DD#`!X```!*20,`'````&E)`P`L
M````ADD#`"0```"S20,`&@```-A)`P`N````\TD#`!H````B2@,`+````#U*
M`P`P````:DH#`"````";2@,`)````+Q*`P`D````X4H#`!\````&2P,`(P``
M`"9+`P`L````2DL#`"<```!W2P,`)P```)]+`P`E````QTL#`!\```#M2P,`
M)`````U,`P`P````,DP#`!T```!C3`,`*@```(%,`P`V````K$P#`#D```#C
M3`,`&@```!U-`P`G````.$T#`$T```!@30,`*0```*Y-`P`M````V$T#`"T`
M```&3@,`+@```#1.`P`H````8TX#`",```",3@,`)@```+!.`P`A````UTX#
M`"<```#Y3@,`.````"%/`P`J````6D\#`#4```"%3P,`"P```+M/`P`6````
MQT\#``<```#>3P,`#````.9/`P`;````\T\#``X````/4`,`(````!Y0`P`J
M````/U`#`$(```!J4`,`-@```*U0`P`[````Y%`#`"$````@40,`#P```$)1
M`P`K````4E$#``\```!^40,`&@```(Y1`P`:````J5$#``L```#$40,`)P``
M`-!1`P`,````^%$#``H````%4@,`%0```!!2`P!!````)E(#`!4```!H4@,`
M&````'Y2`P`E````EU(#`"@```"]4@,`(@```.92`P`G````"5,#`"(````Q
M4P,`%0```%13`P`'````:E,#`-P```!R4P,`!````$]4`P`+````5%0#`!@`
M``!@5`,`$P```'E4`P`'````C50#``H```"55`,`'````*!4`P`0````O50#
M`!(```#.5`,`'````.%4`P`#````_E0#`#,````"50,`&P```#95`P`8````
M4E4#``<```!K50,`$@```'-5`P`1````AE4#`"L```"850,`$@```,15`P`E
M````UU4#`#,```#]50,`"````#%6`P`^````.E8#`"D```!Y5@,`$P```*-6
M`P`3````MU8#`!D```#+5@,`,P```.56`P`=````&5<#``X````W5P,`(P``
M`$97`P`/````:E<#`!````!Z5P,`%P```(M7`P`*````HU<#`!\```"N5P,`
M#P```,Y7`P`=````WE<#``\```#\5P,`'@````Q8`P`F````*U@#``4```!2
M6`,`$````%A8`P`'````:5@#``L```!Q6`,`"0```'U8`P`X````AU@#``8`
M``#`6`,`#P```,=8`P`1````UU@#`!````#I6`,`"P```/I8`P`/````!ED#
M``<````660,`$````!Y9`P`%````+UD#``@````U60,`%P```#Y9`P`[````
M5ED#``T```"260,`)0```*!9`P`E````QED#`!0```#L60,`#P````%:`P`;
M````$5H#``@````M6@,`(0```#9:`P`K````6%H#``\```"$6@,`&@```)1:
M`P!#````KUH#``T```#S6@,`"P````%;`P`;````#5L#`!L````I6P,`'@``
M`$5;`P`0````9%L#`"4```!U6P,`$@```)M;`P`9````KEL#`!8```#(6P,`
M'````-];`P`5````_%L#``L````27`,`#0```!Y<`P`<````+%P#``@```!)
M7`,`,0```%)<`P`1````A%P#`!````"67`,`"````*=<`P`"````L%P#``H`
M``"S7`,`&````+Y<`P`+````UUP#``,```#C7`,`"P```.=<`P`+````\UP#
M``H```#_7`,`%P````I=`P`.````(ET#`!@````Q70,`'@```$I=`P`,````
M:5T#`#D```!V70,`(@```+!=`P`C````TUT#`%T```#W70,`8P```%5>`P!$
M````N5X#`$<```#^7@,`F@```$9?`P`9````X5\#``T```#[7P,`10````E@
M`P`/````3V`#``8```!?8`,`&@```&9@`P!6````@6`#``\```#88`,`$```
M`.A@`P`'````^6`#``0````!80,`!0````9A`P`1````#&$#`!8````>80,`
M!@```#5A`P`'````/&$#``<```!$80,`"P```$QA`P`#````6&$#``P```!<
M80,`#0```&EA`P`Y````=V$#`"X```"Q80,`+````.!A`P`%````#6(#`!8`
M```38@,`)0```"IB`P`B````4&(#`!\```!S8@,`$P```)-B`P`"````IV(#
M``0```"J8@,`#0```*]B`P`*````O6(#``4```#(8@,`!0```,YB`P`/````
MU&(#`#H```#D8@,`.0```!]C`P`E````66,#`#8```!_8P,`)0```+9C`P`F
M````W&,#`$T````#9`,`*P```%%D`P`D````?60#`"8```"B9`,`%P```,ED
M`P`D````X60#`(@````&90,`(@```(]E`P`G````LF4#`$<```#:90,`,```
M`")F`P!.````4V8#`#@```"B9@,`-P```-MF`P`<````$V<#`!D````P9P,`
M'P```$IG`P`6````:F<#`"0```"!9P,`)0```*9G`P!^````S&<#`!X```!+
M:`,`60```&IH`P`J````Q&@#`$\```#O:`,`,@```#]I`P`P````<FD#`&(`
M``"C:0,`90````9J`P`?````;&H#`"X```",:@,`(````+MJ`P`H````W&H#
M`"<````%:P,`)0```"UK`P`M````4VL#`"T```"!:P,`*P```*]K`P`N````
MVVL#`"D````*;`,`*````#1L`P`Y````76P#`"P```"7;`,`-@```,1L`P`C
M````^VP#`$$````?;0,`3@```&%M`P`<````L&T#`"T```#-;0,`-P```/MM
M`P`4````,VX#`!H```!(;@,`#````&-N`P"H````<&X#``8````9;P,`(0``
M`"!O`P`1````0F\#`!$```!4;P,`*P```&9O`P`G````DF\#`!$```"Z;P,`
M50```,QO`P"Y````(G`#`(4```#<<`,`H````&)Q`P!(`````W(#`"````!,
M<@,`5P```&UR`P`0````Q7(#`#0```#6<@,`*@````MS`P`=````-G,#`!$`
M``!4<P,`!P```&9S`P"U````;G,#`!D````D=`,`&P```#YT`P`>````6G0#
M`$$```!Y=`,`&0```+MT`P`6````U70#`%<```#L=`,`&@```$1U`P`/````
M7W4#`!(```!O=0,`"@```()U`P`%````C74#``8```"3=0,`"````)IU`P`%
M````HW4#`!,```"I=0,`&0```+UU`P`-````UW4#``D```#E=0,`$@```.]U
M`P`8`````G8#`"(````;=@,`)@```#YV`P`/````978#``D```!U=@,`"P``
M`']V`P`,````BW8#``X```"8=@,`!@```*=V`P`)````KG8#``<```"X=@,`
M#````,!V`P`(````S78#``<```#6=@,`!0```-YV`P`)````Y'8#`!````#N
M=@,`!@```/]V`P`0````!G<#``X````7=P,`%0```"9W`P`0````/'<#``P`
M``!-=P,`"@```%IW`P`)````97<#``@```!O=P,`#0```'AW`P`+````AG<#
M`!````"2=P,`!P```*-W`P`%````JW<#``X```"Q=P,`"````,!W`P`3````
MR7<#``\```#==P,`#@```.UW`P`(````_'<#``H````%>`,`%0```!!X`P`0
M````)G@#``L````W>`,`$0```$-X`P`-````57@#``\```!C>`,`!0```'-X
M`P`)````>7@#``8```"#>`,`&P```(IX`P`8````IG@#``X```"_>`,`%```
M`,YX`P`+````XW@#`"8```#O>`,`%````!9Y`P`'````*WD#`!4````S>0,`
M!P```$EY`P`(````47D#``4```!:>0,`(@```&!Y`P`+````@WD#``(```"/
M>0,``@```))Y`P`:````E7D#``P```"P>0,`!@```+UY`P`(````Q'D#`!H`
M``#->0,`!0```.AY`P`&````[GD#`!````#U>0,`)0````9Z`P`"````+'H#
M``0````O>@,`"0```#1Z`P`1````/GH#`!<```!0>@,`"P```&AZ`P`#````
M='H#``D```!X>@,`$````()Z`P`*````DWH#``\```">>@,`%@```*YZ`P`'
M````Q7H#`!P```#->@,`"@```.IZ`P`7````]7H#``X````->P,`$0```!Q[
M`P`"````+GL#``4````Q>P,`$````#=[`P`,````2'L#`!(```!5>P,`*0``
M`&A[`P`'````DGL#``<```":>P,`$0```*)[`P`%````M'L#``(```"Z>P,`
M"P```+U[`P`-````R7L#`!$```#7>P,``0```)T%`````````````&$)```A
M!P``-`@``-T'``"Q`0```````"P'``"=!P``WP<``````````````````-$*
M````````QPH```````"+`P```````/8(```I"@```````&0!```J`0``*@D`
M``````#D!P``-`0``#`)``"4````[P,``+(!```6````M@D``!D"```N"```
M``````````#,`@``;@$``+L(``!B`0``S0````````!8`@```````#$#````
M````U`0``)0(`````````````(4&```;!0``+`@``&D%``"M!```````````
M``````````````````"V!0``*P8``/(*``"P!0````````X!````````#0``
M`/P%`````````````/L*```S"@```````'4%```0"0``;0L``,<%``!L`P``
ME0,``"P)`````````````/\)```@"@``V0<```@(``#$!0```````-0(``#F
M`@``9@D``$P!`````````````%X*````````>0H``.`"``"8`@``0P8``%H&
M``````````````````"2!@``T`4```````"B````_@(``%8)````````9P@`
M`(@!``!]"P``_@H```````!G"P``]P4``(D#````````Q0@``$T#```K`P``
M``````````!B"```!`@``)0%``!K"P``F`@``(P)``!@!@``Z0$``#D&``#&
M`0``VP8``,`"````````(@4````````A!```/`@``,\%``!4`@``5````.<*
M``!@!```0`@``%P!```+`@``8`D``*4!```%"P``Q0D````````V"0``W@4`
M`'\)`````````````*`*```9!0``HP<```$"`````````````%\"```I`@``
MN00``,X)````````(@H``-$#``"S!P``"@D````````6`P```@8``-D#``"+
M!```>`(``#@*```E"P``/@@``,@````Y```````````````5!```/`L`````
M```8````&0$``*D(```@"0``10(``)H$```8`0```````)X"``#$`@``+P8`
M`&H+``"!`@``)0$``'4"```%`0```````#(&``#'"```E0<```\&```#!```
MAP,``#@%````````:`````````#K"@``N0@``/L!``"!`P``K`H`````````
M````%`,``*,"``!M!0``1P,``$,$``!"!```@P,``*(*```C!```````````
M```="P```````$$#```R````;@H``!\+``#>`0``````````````````&P@`
M`)@)```6"@``;P@``.,'``#*````8`4``&$*``"@````F04```````!0`P``
M\0,```````"^`0```````!0*`````````````)X)``!+`0````````````!6
M!P``0`(`````````````L00``````````````````#L+``"Z````J@H``$D+
M``#:`@``0`0``%@'```<"0``X0H``#0+```B"```O@@``.T%``#@"0``;`(`
M`.@&``!+"P```````$8%``#7"0```````+H#````````)`@``(0"````````
M``````````#?````*`(``/<`````````Q00``!T"``"D!```M@```-T$````
M````UP```(L*``!2!@````````````#$"@``?@0``!L&``#A!P``YP``````
M``#5"@``^0D``/P"``!Q!0``TP$``'$)``#0!@``_PH```````!["@``-P0`
M```````A````/``````````Y"```'0```%L%```I!0``F00``,4'````````
M`````.8!````````#0<```8#````````'04``.@)``!A"```L@<``%`!````
M````XP4``"X*```V!P``[`D```````#E`P``=PD``&4'````````P0```$4'
M``#M"````````+0```!H"0``+@8``/\$``"0!0``&@D``+T!``#?"```S@4`
M``````!C"```@`$```````#V!P```````&8!```'`@``Z@4``.(%``"V!P``
MW`<```````!V````-@L``%<$````````*`H````````Z"0``>@L``'8$``"_
M"```!@```,H"``!'"```+@L``-,&````````;0H```````"`"0```````,(*
M``"O!```904``&D'``#&`P``1@@````````;!P``9P0```````"8!P``/04`
M`*L*```N!`````````````!:`P``#P4``'4```!Q"P``<P8``,D```"("@``
M.````%,*``!@````I`,``*@)``#I"@``````````````````[P(```````#<
M"@``S@(``"<$``"-"@``:P4`````````````@P```,((``"+"```````````
M```N````:`0``,`$``"[`@``.@4``,P(``#$!@``/0@``'T'```\`@``#0L`
M`!X*````````D`0`````````````FP<```````!E!```````````````````
M60<``!8(``"X!0``"@0```````"*"@``J@<``#H#````````3@H``#\'```Y
M!0``)@L``)T```!1!@````````````#N``````````````#="```*@(``"4'
M``"[!````````+,*````````+@(``"T+``")!```````````````````<`8`
M``````!V`P```````'D)``"("P````$``-4'``#X`P```````"T$````````
MZ@D``)8#````````H0H``/8"``!2!0``JPD``"D(``!I````D08``%L#````
M`````````)<)````````````````````````S`0``+`*``"%`P```````)(%
M``!D`````PL``,,`````````2@(````````U`P``?0D``/0&````````D04`
M`.,#`````````````'($``!,````$0L``"\!````````L`$``.L'``!Y!```
MV`0``)\"``#K!0``W`4```````#@````&PD```()``#-!0``G@H``)<*``"`
M!@``800``+$"````````!PL``!`(````````AP8``)`#````````BP8`````
M``"%"0``10D``-X&``#&!```UP8``"($```2!0``P@$```P+````````^`H`
M`#T!``"A!```````````````````J`@``'H"````````"`8``,P*``!3!0``
M1`<```````"!"@``PP4``)($``#"!0``IP0```````!#`@``=`H```````#(
M"@``E@8``&8$``!8`0``R0<``-D$```&!0```````.L````*"P``+P4`````
M``!7"```9`@``$(#```+"@``;P0``````````````````&P%``#!`P``I0<`
M``````!5````J`0``,X$``#'````\@(``!\`````````<0$```````#.!P``
MAPH``"('``!F"P`````````````W`P```````$(+````````>`,``"<&``"Q
M!0```````!8!``!0`@``````````````````````````````````"`,``+8$
M`````````````$,%``!P!P````````````!!!```````````````````E`,`
M`#@"``"^!0``1P8```````#'`0``JP4``'P)````````A0```&()````````
MV0@```````!/`P```````-@!``#E"```D@,``"0)```@!0``I`<```````"8
M!@``DP0```````#D!```]`@`````````````KP4``&,!```&"P``L0@``*@&
M````````"P4``($+``#8"0````````````"A````S`$```````!%`P``!08`
M`$$)``#@!`````````````!_`P```````*\!``#-!P``C0(``(T(``#I!P``
M`````'(&``#G!P``#@<`````````````T00``'L$``#I````;P,``'4&````
M`````````#`'````````I`4``/T```"\`@``K@D``+`)``!@!P``!PD`````
M````````0`8``#('```P`P```````"`"``#J"@``:`L``*\)``#]"@``F@,`
M`&0*```W!P``,`@``/4$``#U!@``:`$``)$*``!V`@``@`0``#T*````````
MF`,``%$!``#Y"````````!,&``!Q!P``6`0````````3``````````````")
M`@``[0H```````"]!@```````(````#?"0``Q`<``*T#```4!````@```/@%
M````````!0```-H#``"3`P```````,T"````````20$``.L!``!I!@``7@,`
M`-P&``"?````K`D``&8&``!^`@```````````````````````-4#``#)"```
M_P,``*\"``#S!P``SP0```````#S````E04``,@'```:!```Q@<``)`"``"(
M"```EP@```````""`0``)0H``$@+```>````NP,``/<"``!7`0``R`4``/`#
M``!5!@``[@4``&<%``!W"````````)<"```S"0``X@<```````"H!0``````
M`"D'``"Z!P``1PH``,`&``!/`0```````+<(``"/"```0@4``+L%```2"0``
M&0```*()``#@!@``"`L``&4```!/!```%0<`````````````.@H```X%``!@
M"@```````!H"````````"0<``(4"```$`@``;P```-`)```N!0``@@L`````
M``"/!P```````$`!``!&"P``Y@H``%$+```7`0``&P(``(P```#Z````$PH`
M`%,)````````2`@````````("@``2PH``(P(``#H!0``NP8``#\!``"'"0``
MX@,``+,(``#-`P``&`H``)X$```_"@``;0,``(,+```N!P``@`,``*@!````
M`````````*((``!R"P``)@8`````````````Y04```$!```H`0``````````
M````````00<```($```$`P``<@H``!X(```4"0```````&\'``#T`0``L`(`
M`"T#``##!@``[PH``#X'````````.@@```````#>"`````````````#B`@``
MUP$``$L$``"]"@``"0L`````````````````````````````<PH`````````
M````SP$``-,"```W`0``?PL``$(!```!!0``Q`$``$X"``!M`@``#`4``-T%
M``!U!P``7P0``(H`````````LP8``#\+`````````````/L&``"Y!P``B0@`
M`````````````````'4+``"A!0``]P$``(D*``"G!0``%P8``$T```!,"@``
M'0$``,D%``#\"```V0(``%P````(`@``A`L```X&````````Y0<``,,(``">
M!0``(P(``(\&``!-"@``60$``",(``#\````1`(``/(#````````\PH`````
M````````@@D``"<#``![`@``*@8```````#E"0``4`8``&H)```Q`````P,`
M`/8#``!_!0``J@@```<````U`@``"0(``&4*```T!@``/@```"(#``#]`0``
ME@$``!P#``"Q!P```````%,'```%`@```````%0%``!;"@``````````````
M````?`@``*8)````````/`$``%P(``"2"@``;P$``/\"``#]!@``T@$`````
M``"3`0``K`(``#P%``!:`@``Z@$``&0&``!=`P``````````````````````
M`$$(````````>@,``&(```"4"0``M@8``/P*````````BP$``!D#```8!0``
MTP0```````"M"```'`L``!H+````````;`H``/P&````````H`<```````"_
M`0```````','``"I`@``\0H``#4```#I`P``7@(``)H`````````\0D`````
M`````````````.@$``!-`@``Y`4``.8&``!G`P````````\"``#9"@``)@D`
M``````!$!```*@<``'D"`````````````!L!````````80$``(@)````````
M`````&0+``!A"P```0,``/`*```_"0```````(D!````````PP(``(,%``#!
M"`````````````#<"```^`D``'$*```G"P```````.\`````````#`<`````
M``"5`@```````!0`````````$0(``(8$``"B!```/@L`````````````M@H`
M`+D&```K"0`````````````E!0``0@8``-,%```*"```PPD``,<#``!?!0``
MR@D```X*``!J!P````````L#```$````Z04``,T&``![!0````````````#2
M`@``V````/X!```7"0```````-0*``!4"````````'0&``!6`P``1`4``+<!
M```?!```P0<``*X#``"/````<`@`````````````30L``*L'``!O!0``&`L`
M`*$'````````]P@``'<$``!>````8@,``-\%``"/!0``WP(``,H!``"?"0``
MN0$``(@%``"X````#00````(``````````````````#5!@``-@(``"$#``"_
M"@``R00``*('``"7!```[P8``'4#``"."@``7@D``*8#`````````````!L#
M````````P`D``'H&```T`@``-PD`````````````6@@```````"4`0``````
M`&<`````````:`4```````"A`0```````*P$``!3!@``U0(``.0*````````
M,`4``!((````````C04``%4+````````^@D``+\%``"?!@``E@<``-X`````
M``````````````!^"P``A`8``/L%````````%0```#`"``!!`@```````$H&
M````````%08``&<"````````OP0``&`!``"1`@``[`@``#\"``"["0``````
M````````````````````````````V@H``'\$``#S"0``?0```+@&``":!0``
M`````"T"``!>!@``B0<``)((``"(````=PL````````&`0```````-T!````
M````N`,``/0%``#)"0``]04```````"7!P``*0$``&`+````````B@4```("
M``"5``````````P)````````ZP0``-(%````````400``-0```#N`@``````
M`-0"`````````````!X+``"G"0``-0D``/<)````````@08```````")!@``
M*@0``.X!``"[!P``>04``-`(``#P!P``Z`$``)4!````````O`4```````"$
M"0``(P8``,8*````````?`8``"<)``!X"0``^08``%\'```:"@``2`H``*@`
M``#M!````````$@%```!!@```````%X$``#[````O`0``!$%````````````
M```````D"P``)`(``-8&``!1!P``)@$```````"U`@``<P$``"D+``!M`0``
M9`D``/L(```J!0``K`<`````````````M@$``,@$``#7"@``)`,``,L*``!,
M`P``B@D```````#Q"```<````````````````````&P$```7`@``*`8``(`'
M``"'"P``]`<``/4*````````"P```#X!```U"P``20```#P&``#-"@``6`4`
M`#0`````````W`,``*D$```4"P``>@@``.T!````````ZP@``(X'````````
MFP@``#T$``!'`0``F`4````````=!```#@(``!D$``!X!````````+,`````
M````HP0``,8```!-"```PPH````````2`````````-P!``!U!```)0(``*0(
M``#8`@``=@<``$D*``#L!0``200``*(!````````+`,```X(``!2`@``4@``
M`%8"``!N!0``6P```$H(``!.`P``9@(``.@#``"O!P``&`@`````````````
M`````%,"``#(`0``608``-L$````````0@D````````5`P``:00``+0)``"/
M`@```````,L&````````<@<```````#0`P``L@0``*H$``!T"P``TPD`````
M```A!0``*PL``$,#``!S"0```````*4&````````Q0H``-8```"Z!```@@,`
M`-\!``">!P``3@<``(`(```Y!```$P0````````,!@``XP$```````!S`@``
M/`0``/H*``!F````G0,``&0%````````>08``+X$```>`@```````&<'``!^
M!0``T08``"H+````````Z`(``,T!``!$"0``;@8``!0'`````````````'<!
M``````````````````"+`````````*\#``!=`@``,P0`````````````````
M``````"+!P``204``*0*```G!0````````````!X!0``XP```)@````2`0``
M``````````!L`0``IP(``)8*``!\````*`0``#L$````````!`<```4(```4
M!@``+P<``%4%```<!```_@4```````"N`@``]`,``,L"```L`0``B04``"L%
M``"S!0``*PH``"D&```O"P``&`,``&T$``"3"0``004``%H+```9"```````
M`($`````````-@4``&,#`````````````!8%``!S"P```````)P!``#)`P``
M5P8````````3`0``60(``-(*``"M!@``50,``#H!````````Y@````0%``!F
M!0```````!<'``"Y`@```````%L$``!H`@``\08````````@!P``?@```/,$
M``#1!P````````````"7`P````````<%```&!P``C`8```````!*!0``W@0`
M````````````X0D``/X`````````_`D``.8(``"U"@``]0<``)("``"W````
M)`H``,X&``!_`@``]`D```````!."0``8P0``*,(``````````````````""
M"@``/`D``-($````````6`@``*4"``"$`0``\0````````#&`@``2P``````
M``#F!```T`<```````"M"0``\@0```X+``#N`P````````````"-!@``1P``
M`"`(``!P`P```````*D#``!P`0``J0<``(X!```-"```@P<``#8&``#=`@``
M.0$``*T%`````````````*8"````````=P,``"4$```P!@``WP,``"$)``!%
M````BP4``/@(``#A!0```````$D(````````$P,``%@#````````$08``'()
M`````````````+<$``!X"P````````````"R!0``300``&L!````````7P,`
M`($!``"&````9@@```````!J`P``.P@``(P"``!>!0``4`0``$,*``#M````
M/@D``/$'```[!@``I`D```````!_"@```````/0$``````````````````";
M!````````+`#```,!```\@<``(<(```0`@``'`H``#T)``"0"@``^0$``!,+
M``"G!@``?@8``$0```!'!````````%<```"K"```0@```*T```!\!```M08`
M`(4'````````6P<``!8"``#S`@``D0D```````":`0```````+((```?!@``
M30$``!$#```8!```0PD``+T%````````M0,``!H!```(!````````&4#```_
M!0```````,@"``!^!P``K@0``-8*```_"```G`8```````!4!@``,08``$L&
M````````=P8``.`'`````````````!4*```,```````````````Y"0``N`<`
M`!X%``!'`@``J0$``'H*``#`````\`8````````+`0`````````````E!@``
ML@````````"%!```?@$``$D)``"`"@``2@H``*8!```8!@```````-X"``"K
M`@``$0D``/\!``!&"@``XPD```````![!@``"08``",)``#&"0``,P$``$P(
M``!.`0``%`(`````````````QP8``'<'``!Z!P``80``````````````````
M`-`!```'`0``D@D``%8&``#H"```0P```(8)```'"````````!<%``!0!P``
M5`<``(\#```S`P````````````!6`0``2`$``/8%````````Z08``$````"1
M`0``B@(``(P%```#````5@@``#D+```?`0``2@,``(<$````````\@$`````
M``#J!@````````$'``!<!P``^0<``)T(``!&````A@,```````":"0``X08`
M`&,)```````````````````W"@``^`8``)`&````````0@<`````````````
M4@,``-@*``"0"```4@$``*L```#1"```"0```(@&``"V`P``.`0``/(&````
M``````````@%``!Y````$`L````````>!```-08```8&``"."```T@@``,T)
M``"T`@``O`<``#0'``".`````````.P&```K`0```````(8"``!'!P``R@@`
M`$0*``#Y!0``U@<``"`#``#;`@``#P0````````)`0``?0H```````!$"P``
M,P@``+`'```#!P``#PH``&X'```.````YP0``%0*``!Z`````````*4%````
M````*0D``((```!>!P``=0D``#H&``#+"0``/P0``.8'````````YP(``!P'
M``"T!0``V04``)L)```("0``R@8```4)``#!`@``#`$``+8"``!6"@``N0``
M`+4$``"W"0``X0```%P#````````.P4```````#:`0``-0$``"$"``#U`0``
M:P,``%\*``#W!P````````````"-`0``````````````````H`(``.\$```X
M"```6`8``(T$``"O"@``1`,``#L```#L!P``XPH``!T*```*`````````-@&
M``!>`0``]0````````#7!````````.T&```)"@```````,0(``!C!@``;0@`
M``````"6!```WP0```(*```3"```:@0``(P*```A`0``E@@``(4%````````
MX@H``#8!``!;"P``(0@```\(````````:P0``.4$``"F"@``9`<``"8*``"9
M"0````````````!;"0``:P@``!@"``!/!0``3@0``.$$``#`!0```````'4(
M``!J"@``5@0``+L*``#[!```_0,``-(`````````]P8``"L$``!G"0``O@8`
M`"$+````````V`,``%D#``#Z!@``R0H``&T)```?"```SP<``%4"```D`0``
M=`<``$4!``#Z`P``*@,``,,#``"=`0```````$0&```O!```FP``````````
M````3PL``*$#``"0!P``=0H``($'``````````````````!T"```0`D``"X)
M``#!"@```````+X*```C"P``"@<```````"Q`P``<@````````#D!@``2@0`
M`+<&```@````!@D``"@+``#B`````````"`$``````````````````"N"@``
MIP<```````!9"```F@8``#<(`````````````$H+```2!@``G`D``&L&````
M```````````````L"@``MP4``.<%``"#"````````%T)``"8"@``K@@``.D(
M````````:@8```````";`@``)@<``-0)````````T@<`````````````````
M`$T)``"I`````````*4*``";!0```````*<(```]"P``]@H````````V"```
MU`,````````'!@``O00``,T$```%!```:0(``*P%``!7"@``>@$``'L'``#F
M`P``&@```',```"C!0```````/H$``!J"```>`H````````+"P``I@4``&4+
M```Q!P``!`$``*@"```"`P````````````!B!````````&\"```M"0``````
M`#(+````````[@0``,()``"5"```T@,``.H#``#4!0``_0(`````````````
M``````0)``!Q`@``IP$``*0&`````````````&8#```2`P``SP,```````#"
M````1@,`````````````MP<``(,)``"P!@``*0,``!D*````````<@@```0+
M````````=`D```````#K`@``6@$``%D*``"6"0``;08``"<'``"[````,0(`
M`"`&``!7!0``J@(``(@$```G`@```````"P"```[`@```````)P"````````
M``````H!```1```````````````+!@``PP<``%0)``!+`@``3PD``)$'````
M````,``````#```;````MP,```````"Z!0``,0H``/4#``"-!P``^@@``/0`
M``#U"````````+0(```S"P``>PD`````````````8@8```````"9!@``#0,`
M`.T#``!'!0```````-,```"$"@``[P@````````'`P``I@<```\'```D!@``
M'0<``(X)``"A"```VP<``'P'``!N"```;@```%`+``"\````2P4```````!U
M`0``^PD``,$!``!3````<00``#<+``"U"0```````$@$``#5!````````&L"
M``#\!P```````',(``#:!0``%P0``+`$``"A"0```````/H!``#(`P``^`(`
M``````"L`0``,@,``(@'``!D`@``CP0``,L!````````3`L``*<*``!,!0``
M`````"@'```E`P``MPH``,$)``!7`@```````*`!````````UP(``/X)``#/
M"0``7P@```````!E`@``Y@4``*8````R"```/P```'`$````````0@(``"8%
M``!*````5P<``.8)``"?`0```````,L#````````_@@``.\%````````````
M`(D)```:!P``?0,``#@#```="```[0<``)('``#W`P``]`(``%D`````````
M:P<``/$%``"(`P```````/P#```Z!```U0@``(0(```?"0``WPH`````````
M````:@$``,\"```'!P``Q04``!@'``"4!P```````&(+```Z`@``D`$`````
M``!/!P``304``#T&``#.`P``$@L```````!M!P```````#($````````.0,`
M`&(*``#/"```T@D```````#>"0```````,@)``"A`@```````%0+``!="@``
MR08```````!G!@```````-@(````````\P4``*,#```L!@``$P(``)8```#0
M`````````(\!``!L!P``X0$```````!?````M`H``#X$``"N!0``(P$```,(
M``!P"0``4P0```8$```Z``````````````!9"P```````(4+```6!@``````
M`%((````````H08``!D)`````````````!`%`````````````&\&``"X"0``
MG`<``#8#```/"0``M0@``($(```R`@``4P,``'(%``!T````A````#0#``"-
M`P``U@D````````M!@``AP(``#X&``"9`@``<@$``$H)```N`0``^@4``&L)
M````````J@```'8!```C!P``P00```````"T!`````<``($$```$!@``G@8`
M````````````H`,```````"@!@``0P<``*T"```V!`````````````!D!```
M<`4``-`"`````````````%()``!3"P``````````````````1`@``&H```!=
M!0``J0D``)0*``"B!@``U@(``"\*``"C"@```````)$(``!C!0``````````
M````````$P4``)4*``"5"0``,0L````````^`@```````$@"``"$!0``I0``
M`#T'``";!@```````,('``!A!P``(@8``)<```!C`@``(@D``.4`````````
M4@<``"\"````````Q0$``%8%``#@`0``]0(`````````````7`8``%D$``!_
M`0``"@H``+$)``!*`0``C0````````#N!P``N@H``%L(``!5!```[@8``#X*
M````````R0$``'T&````````,`0`````````````708``)H'``!C!P``V0``
M`(4!`````````````!L+``!=!```P`@``!\'````````G`4```,"````````
M`````&4!``!L"0``;PL```````#L`@```````,`#`````````````+$```"9
M"@``0`4`````````````OP<``.`#````````]@D``)P*````````50H``*D*
M``"]"```50@``#L)`````````````/T%````````-@````````!,"0``7`(`
M`$`+``#]"```O0<``!0%```""P```````````````````````)T$```(````
MS@````````">"```7P8``$4*`````````````$\(``#%`@``````````````
M````10L``$8'```5"```Q````$\"```S````^0H``)\*``!G`0``]@$``,4&
M``"*!P``K`,``*8(```\`P```````*@'``#[`@``M0<``'0$``!F"@``@0D`
M`%L&``""!0``ZP8``"0'``#5"0``^`0``'H$```<`0``N`0``!\*``!M````
MTP@````````#"0```````-`$``#."```;@,```````!1"@``%0(````````B
M`@``@`4``#@)``"""```'`(``.L)``#L!````````#4%``#_````Q0,``%0$
M``!#`0``^````*(#``!&!````````.0````L!````````.@`````````:0$`
M`%$"``#<"0````0``.H"``!<!```;@L````````[!P````````````"7`0``
M?P```#T```!)!P``8@4``$L)```8"0``308``%\)``!3`0``$`,````````=
M"0``K0H``(T)``!T`P``P04``#(!```P"P``K@<`````````````1PD``,L'
M```-`@``Z0(``!X&``#,!0``B@@``!4)````````_@8``,H%``"!!0``````
M`/()``#+"```$P<``/`!````````VP,```H#```T"0``XP8``(\)````````
MG0H``,X*`````````````%H%`````````````+H(````````H@(``+0&``#B
M"````````,`!````````O`$```````"E"```:`@``)P#``!]!```U@0`````
M``""!@``O`8```4%````````X0(``+P)````````A@8``*\(```>"0``%PL`
M`%\!```J"@``.0(``*H#``!Q`````````!X!```G"@``4`@``,@(``"="0``
MY`(``!````!Y!P```````(H#``#7"````````)0$``!8"0```````(8*```=
M`P``7@@```````#'!P``O0```%4'``#$!```>`8``-H'``"#!````````"D`
M``!Z!0``_0D```````!``P````````````!?"P``I`(``/`$````````TP,`
M`(<%``"?"``````````````B`0``Z@<``$4%````````,P<``+,$``"E"0``
MB`(``)@$``````````````````#I!```)````)D`````````D0```(,!``#)
M`@``0P@``)H*``"^````)`4``'X(``#:``````L``%@```"L"```TP<``(4(
M``"#"@```````&@'``"X`0``'@,``&("```3"0``B@8````````*!@``````
M`$`'``"U!0``208```````"$!P``/0(``.H$```F`````````-$```#_!@``
M`````&X"````````(@```)0"````````"00``!H(````````%`@``$@&````
M````F@(```````!X`0``*00``*H%``"Z`0``!P0``'8+``"M!P``+`4`````
M````!@``JP0``"\#``````````````````!:"@```````)@!```;"@``W0D`
M``````!(`````````.$#``"S`0``OP```*H)``!,`@```````)D(``"P````
MHP$```````!T`0````````````"%"@``Q`D``!`$``#H!P``U`8``,L$``#^
M`P``#0$`````````````I````#@&```'"@``*`D``-X#``"D`0``/@4``)\%
M``!0````E@(```````!J!0``404``/T$````````Y`@``'<"``"G`P```0L`
M``````!R`P``-0@``-\&```B"P``L08``-,*``".`P``<`(```````"N````
M-@H``"`+```````````````````]`P````````````````````````8*```0
M!P``2P<``%(+``"9!P```````%T!```(!P``RP4``%@+``"/"@``70```.T)
M``"S"0```````,8%````````;PD```````!<!0``H@4``.$(``#=!@``````
M`%T'````````]P0``)L*````````#P```&,+``""!P``Z@@```````#Y````
MO`@```````#5!0``>P@``!`!``"&"```T04````````7`P``2P@``,8&``"F
M!@``'P(``.X*```!"@``C@0``%L"``!]`0``\`@``-D&``#'!```)@(``/`%
M``"^"0```````+D*```&"```DP<```````"2````A@$```````!Y`P``V@D`
M`)P$``````````````(%``!A`@``W@H````````[`0``````````````````
MKP```&4&````````Q0```.()```U!P``=PH``!(*``!@`P``U0$``.0)``#K
M`P``7`H``/8&```*!0``S0@``+X#``!W!0``DP4``/`"```M`````````'8)
M````````E`8`````````````2`<``-$"``#Z!P``'P,````````"`0``````
M``P(```F!```^0,``/,&```1`0``D@$````````,`P``OP,``),"```9!P``
MXP0``&H"````````5P,``'@'``"@"0``6@````8"```/`P``^P,```T&````
M````>````%`%```0"@``O`,``$$&``!_!@``*`,```D#```[`P``D`D``&X$
M`````````````#$!```6"0`````````````J"````````"8(``"Y`P``FP,`
M`*4#``#^!P``.`$``#$)``#L`P`````````````K!P``$0@``-@'``",!```
M!0,````````_!@``)0```,P#``!L"```Q`,``/$"````````8`@``.X(```+
M!```P@8``'X#````````"04``````````````````&P&````````_P4``)``
M``!<"P```````(L)``#;````%@0``!L$``"W`@``@@(```T)``"<"```80,`
M``````!0"@``808```X$````````$00``(D```#,!P``R`8``&D(``#O"0``
MO0(``-P$``")"P``.PH``'H)```+"```QPD``.`(````````$`8````````$
M"@``U`<``)4&````````:0D``)$$````````\@4``$T'``#9"0``#@,``$8!
M``!%"```H`@``&@#``````````````D(```5`0``_`$```````"T!P``T`H`
M`!<(``"'`0``(`$``)\'``!6````E00``!P(``#"`P```````+\&``!R`@``
M``D```````"1`P```````(X&``!!"P``A`0`````````````\P,````````Q
M"```'`4``````````````````*X&``!T!0``Q@@``%@*````````[P$``"L"
M```S`@````````````!0"0``DP8```````#G`P``3@4``'P*``#;"```O0,`
M`&X)``"J!@``>0L``'L```"+`@``XP@``$8&`````````````+0!````````
M90@``/L'``!,!```00$``)8%``!$`0``*P@``/\'``#D`P``6@0```````!.
M"```&@,`````````````]@0``*,```"^!P``R@0``"@```!3"`````````P"
M````````=@8``.0!````````K0$```4'```A"@``[`H``!('``#T"@``%04`
M`!("``"3````70L``/T'``"R!@``+0$``&,*``#O!P``````````````````
MX@8``)D!``#.`0``<08``',#``"P"``````````````C````X@$```````#=
M````>P$``!H%``#L`````````(P#```M!0```````*,)``!!"@``3P``````
M``#!!@``50$``#(*`````````````,H#`````````````$D#```(`0``>`@`
M`)P```"Z!@```````'`*```<!@``\P$``"4)``"^`@``]PH``.P!``"S`@``
M`````+("``#G`0````````````"I!0``&08``$\&```*`@``HP8``!8+````
M````6@<``"<(``#,`````````-8%``!["P``_`0````"````!0``F0,``#,&
M``"R"@``\`D``)\#```)"0``VPH`````````````+0H``.,"````````%`$`
M`!X'```/`0``+`````````````````````````#,!@``40@``",*``"&!P``
M`````,L````E"```8P````````````````````4*```-!0``'```````````
M````\@@``'D!`````````````$X&``#8!0``O0D``(8%```$!````````+P*
M``!7"0```````!4+````````M`,```$)````````1@(``(X"```H"```````
M`%D)``"'!P``C@4``)X!````````'P4```('`````````````!$*``"_`@``
M3@L``&\*````````N0D``&4)`````````````*H!``!4`P```````-8(````
M````\P@``%$````````````````*``!;`0``EP8```,!```O````GP0``&<*
M````````4@H``,`*``#H"@```````````````````P8``*<```!_"```SP8`
M`.T"``"K`0``2`D``-L%``#=`P``^`<``.4"```W`@``PP0``',$```W!@``
MP@(```````!I"@``^00``'P"````````SP````````"N`0``]@```'T(````
M`````````,\*````````UP4```$$``!H!@``=@H```L)``",!P``6@D`````
M```T`0``0@@```````#;`0``#@D``%$#``!%!```T0D``#<%``"3"````@@`
M`,,!````````8@<````````+!P``0`H``/X$```R"0``/`<``(,&``!,!P``
M`````"X#`````````````)X````U!````````"P+``!1"0``P@0``-D!``!&
M"0``UP<``&`"``#4`0``.`L``.H````#!0``+0<```````#6`0``Y0$`````
M``#Y`@``00```)T"``!/"@````````````!^"0``&@8``*`%``!6"P``]0D`
M`/$$``!Q`P``FP$``*P``````````````#\#```2!```?@H``#`!```9"P``
MP`<```````"V"```F@@``$4&``"Z"0````````````"*`0```````/@!``"X
M`@```````&P``````````````/(```"S`P``KP8``'$(``!F!P``X@0`````
M```C`P```````*`$```Y!P``)`0```````!D`P``^@(```````"R"0``T@8`
M`*L&````````,04``)X#``"U`0``J`,``+@*``""!```[@D``"<!```7````
MY08`````````````?P<`````````````?`$``'`+``#G"```<P4``-L)````
M````0PL``#P*``!K"@``5PL``$D"``"_"0``A`,```````#7`P``4@0``-8#
M``#="@``5`$```````!>"P``-`4``-P"``"F!````````/$!``!L"P``````
M``````"U````QP(``'8(```M"```N04``),*````````,`H``",%``!H"@``
M%@<``&D#````````J`H```````!T`@``-0H``-H$``"I!@```````$<+```Y
M"@```````#$$``"=!@``70@```````!\!0``Y0H```````#>!P``U0```"$&
M````````V@8```````"R`P``W````'T"``"[`0``X`4``#X#``#I"0``JP,`
M`"@%```-"@```PH```````"&"P````````\+````````\```````````````
M=P````````"*!````````.`*``#*"@```````$X```"X"````````"8#``#*
M!P````````````#,"0``'08``'P+```X!P``804````````W````YPD``(<`
M``"E!```?04``$(*``!,!@``T0$```P*``!+`P```````-H(````````EP4`
M`+H"````````=@4``#H+```G`````````'L#````````+PD``&L```"L!@``
MC`$````````1!P``+P@``%P)``!*!P``*@```/\(```S!0``2`,```````"`
M"P``>0@``(,"`````````````"L````7"@`````````````R!0``-`H`````
M``!\`P``@`(```$(````````604``+$*``!5"0``:0L``.<&```Z!P``````
M```@("`@("!#8SH@`"`@("`@(%1O.B``("`@($1A=&4Z(``@("`@1G)O;3H@
M`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I
M`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@4W5B:F5C=#H@
M`"!A="``(&EN(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N
M;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@
M=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O
M=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W
M87,@;F]T(&-R96%T960Z("5S+@`C`"4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2D`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@
M)7,@86YD("5S`"5D($UE<W-A9V5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S
M=V]R9"!E>'!I<F5S+@`E9"!M97-S86=E<R!H879E(&)E96X@9&5L971E9"X`
M)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`"5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2X`)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BX`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN
M`"5D('1O("5D(&]F("5D($UE<W-A9V5S`"5D+61A>2!F;W)E8V%S=``E<R`M
M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``
M)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A
M;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA;65D
M+@`E<R!A="`E<R`E<P`E<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!M86EL8F]X+@`E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A
M<G0@;V8@=&AE(&UO;G1H+@`E<R!H87,@86-C97!T960N`"5S(&AA<R!C86YC
M96QL960@(B5S(BX`)7,@:&%S(&1E8VQI;F5D+@`E<R!H87,@<F5P;&EE9"!T
M;R!A(&9R964O8G5S>2!R97%U97-T+@`E<R!H87,@<F5P;&EE9"!T;R!T:&4@
M:6YV:71A=&EO;B!T;R`B)7,B+@`E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+@`E<R!H87,@=&5N=&%T:79E;'D@86-C97!T960N`"5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A
M=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@
M:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(')E<75E
M<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y
M;W5R('!R97-E;F-E(&%T("(E<R(N`"5S('1O("5S(&]F("5S`"5S('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@(B5S(BX`)7,@=VES:&5S('1O(&%M;65N
M9"`B)7,B+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@(B5S(BX`
M)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A
M8F]U="`B)7,B+@`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S
M)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@)7,@*"5D)FYB
M<W`[;V8F;F)S<#LE9"D`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R
M;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@
M86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I
M=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`H07!P;'D@=&AE<V4@8VAA
M;F=E<R!A;F0@;6]V92!T;R!N97AT('-C<F5E;BXI`"A$:7-C87)D(&%L;"!C
M:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BD`*$A4
M34PI`"A0;&%I;B!497AT*0`H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E
M;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@
M0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P
M;&EE9"XI`"A396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG
M97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R
M965N('=I;&P@3D]4(&)E(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC
M:VEN9R!/2R`J`"H@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S
M=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`M+2!S96QE8W0@+2T`,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N`#$@
M;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P
M;W)T960@87,@;F]T('-P86TN`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+@`Q,#`@8VAA<F%C=&5R
M<P`Q,#`P(&-H87)A8W1E<G,`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M
M870`,C0@:&]U<G,`,C4P(&-H87)A8W1E<G,`-3`P(&-H87)A8W1E<G,`/%!R
M979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!L87)G92!I
M;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N`$$@
M;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R
M;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@<F5C:7!I96YT+@!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`
M04T@4VYO=R!3:&]W97)S`$%-+U!-`$%.1`!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'0@86YD
M(&%D9"!T;R!M>2!C86QE;F1A<@!!8V-E<'0@<F5Q=65S=`!!8V-E<'1E9`!!
M8V-E<'1E9#H@`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!)
M;F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!
M8V-O=6YT)W,@;F%M93H`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@)7,@
M=&\@;7D@061D<F5S<R!";V]K`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@
M4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E
M<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU
M;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!S;W5R8V4`061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY
M(&-A;&5N9&%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R
M97-S(&)O;VL`061D('1O(&UY(&-A;&5N9&%R`$%D9"!U<V5R`$%D9&5D("(E
M<R(@87,@86X@871T86-H;65N="X`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N
M86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I
M;VYA;"P@96YT97(@96%C:"!H96%D97(@;VX@82!N97<@;&EN92D\+V5M/@!!
M9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N`$%D9&ET
M:6]N86P@:6YF;W)M871I;VX@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@
M9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE
M=V5D("5S+@!!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<P!!9&1I
M=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S
M+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&1R97-S($)O;VMS`$%D9')E<W-E
M<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E
M86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/@!!9&1R97-S97,@=&\@
M97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA
M;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3X`061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M
M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!
M;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5
M<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E
M<P!!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL
M;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@9FEL93H`06QL(&UE<W-A
M9V5S(&EN('EO=7(@(B5S(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I
M;&P@8F4@<&5R;6%N96YT;'D@9&5L971E9"X`06QL(&]L9"!L:6YK960@871T
M86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE
M=&5D+@!!;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M
M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL(')I9VAT<R!O;B!F;VQD
M97(@(B5S(B!S=6-C97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B`B)7,B+@!!
M;&QO=R!&;VQD97(@0W)E871I;VX_`$%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B
M92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/P!!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR
M96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-
M4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E
M(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@
M=&5X=#H`06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CH`06QW
M87ES`$%L=V%Y<R!S879E(&%T=&%C:&UE;G1S`$%M97)I8V%N(%-A;6]A`$%N
M(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@
M871T86-H;65N="X@5&AE($E-05`@<V5R=F5R('-A:60Z(`!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C
M8W5R960N`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN
M9R!T:&4@;F5W(&YO=&4N`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL
M92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN`$%N9&]R<F$`06YG;VQA`$%N9W5I
M;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`06YS=V5R960@
M;65S<V%G97,`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI
M8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN
M`$%P<&QY($9I;'1E<G,`07!P;'D@1FEL=&5R<R!T;R`E<P!!<'!L>2!F:6QT
M97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/P!!<'!L>2!F:6QT97(@<G5L97,@
M=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/P!!<'!L>2!T;R!#:&EL9"!3
M:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H
M5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`
M07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES(%9I<G1U86P@
M1F]L9&5R($1E9FEN:71I;VX_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D
M96QE=&4@=&AI<R!P=6)L:6,@:V5Y/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M;65N
M9&5D(2D`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,
M62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT/P!!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M
M9W)O=7!S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F
M;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P
M86T@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U
M<B!T<F%S:"!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M
M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A
M<R!S<&%M/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX
M*0!!<G)I=F%L(%1I;64`07)T`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I;VX@
M27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:P!!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&%C:"!&:6QE<P!!='1A
M8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S
M86=E/P!!='1A8VAE9"!&:6QE.@!!='1A8VAE9"!F:6QE("(E<R(@97AC965D
M<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H
M960N`$%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T
M('EO=2!S96YT+@!!='1A8VAM96YT`$%T=&%C:&UE;G0@)7,@9&5L971E9"X`
M071T86-H;65N="!);F9O<FUA=&EO;@!!='1A8VAM96YT('-T<FEP<&5D.B!/
M<FEG:6YA;"!A='1A8VAM96YT('1Y<&4`071T86-H;65N=',`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1E;G1I;VX`071T
M<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N
M9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`
M075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E
M<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H
M7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!
M4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I
M;&5D+@!!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A434P@;65S<V%G
M97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY(&%D9')E<W-B;V]K/P!!=F%I
M;&%B;&4@061D<F5S<R!B;V]K<SH`079A:6QA8FQE(&9I96QD<SH`07=A:71I
M;F<@4F5S<&]N<V4`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C7VL@=&\@
M)7,`0F%C:R!T;R`E<P!"86-K('1O($UU;'1I<&QE($UE<W-A9V4@5FEE=R!)
M;F1E>`!"86-K('1O(%1H<F5A9"!$:7-P;&%Y`$)A8VMG<F]U;F0`0F%C:V=R
M;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O
M<R!U<V5R;F%M92X`0F%D(&QO9VEN(&YA;64@;W(@<&%S<W=O<F0N`$)A9"!O
M<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,`0F%D
M(')E<75E<W0Z("5S+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U
M.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C
M=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F-C`$)E;&%R=7,`0F5L
M9VEU;0!"96QI>F4`0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T
M=7,@:6YF;W)M871I;VX@;65S<V%G92X`0F5N:6X`0F5R;75D80!":'5T86X`
M0FER=&AD87D`0FQA8VML:7-T`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@
M(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQO
M8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@87)E('-P
M96-I9FEC86QL>2!R97%U97-T960_`$)O9'D`0F]L9`!";VQI=FEA`$)O;VMM
M87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@
M86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@
M0F]D>2!O9B!-97-S86=E`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD
M`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I
M($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A
M<V\`0G5R=6YD:0!#35,`0U)!32U-1#4@;W(@1$E'15-4+4U$-2!R97%U:7)E
M<R!T:&4@075T:%]305-,('!A8VMA9V4@=&\@8F4@:6YS=&%L;&5D+@!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#
M7VAA<G-E=`!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A
M<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@8V]N;F5C="!T;R!T
M:&4@<F5M;W1E(&UA:6P@<V5R=F5R+@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE
M(')E;6]T92!M86EL('-E<G9E<CH@`$-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD
M(&]N;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C
M=7)R96YT(&UA:6QB;W@N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@
M=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N
M8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;F-E;&QI;F<@
M=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N
M=&5N=',N`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E
M`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N
M($ES;&%N9',`0V,`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P
M861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO
M;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A
M;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T
M:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E
M(%!O;&EC:65S`$-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE
M+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BX`
M0VAA9`!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG92!!;&P`0VAA;F=E($9O
M;&1E<@!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@9&ES<&QA>2!O<'1I
M;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H
M('!A9V4@86YD(&AO=R!M97-S86=E<R!A<F4@<V]R=&5D+@!#:&%N9V4@;6%I
M;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RX`0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG92!T:&4@;F%M92P@861D
M<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6PN`$-H86YG:6YG('EO=7(@
M<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O
M;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA
M<@!#:&%R86-T97)S('1O(&1I<W!L87DZ`$-H96-?:R!,:6YK+BXN`$-H96-K
M($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAE8VL@7T%L;"].;VYE`$-H96-K
M(&%L;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M
M.@!#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_`$-H
M:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@06-T:6]N.@!#:&]O<V4@07!P
M;&EC871I;VXZ`$-H;V]S92!A(&UA:6P@<V5R=F5R.@!#:&]O<V4@82!M871C
M:"!O<B!E9&ET('1H92!A9&1R97-S('1O('1H92!R:6=H=#H`0VAO;W-E(&$@
M<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E
M9"!L:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@
M861D:6YG(&%D9')E<W-E<RX`0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S
M(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`$-H
M<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE
M87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L
M96%R:6YG($QA=&4`0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL
M92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RX`0VQI8VL@
M)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+@!#;&EC:R`E<R!T;R!G;R!T;R`E
M<R!M86YA9V5M96YT('!A9V4N`$-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT
M96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W(&$@
M=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N`$-L:6-K("5S('1O('9I97<@=&AE
M(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N`$-L:6-K("5S('1O
M('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A
M=&4@=VEN9&]W+@!#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM86=E<P!#;&EC
M:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T
M:&5N('-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"X`0VQI8VL@=&\@0V]N
M=&EN=64`0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D
M9')E<W,@8F]O:P!#;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O
M9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O:P!#;&EC:V%T96QL('9I82!(5%10
M`$-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M
M97-S86=E('1O('1H92!S96YD97(`0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@
M=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860`0VQO<V4`0VQO<V4@
M5VEN9&]W`$-L;W-E('1H:7,@=VEN9&]W`$-L;W-E9"!&;VQD97(`0VQO=61S
M`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`
M0V]L;&%P<V4`0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&;VQD97)S`$-O
M;&QA<'-E($9O;&1E<@!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D
M97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R($EN9&EC871O<CH@`$-O;&]R(%!I
M8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M
M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE
M`$-O;6]R;W,`0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!A;F]T:&5R(&UE
M<W-A9V4`0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\`
M0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@
M*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE(&9E871U<F4I/P!#;VUP=71E<G,`
M0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N`$-O;F9I9W5R92`E<P!#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D
M:7-P;&%Y960N`$-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RX`0V]N
M9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P
M=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0('-E<G9E
M<BX`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYN96-T:6]N('1O('-E<G9E<B!F86EL960`0V]N=&%C=',`0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O
M9B`B)7,B`$-O;G1I;G5E`$-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+@!#
M;VYT<F]L(%,O34E-12!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!O<'1I;VYS
M(')E;&%T:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RX`0V]N=')O;"!W:&5N
M(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R
M(&YO="!T;R!N;W1I9GD@>6]U('=H96X@:70@87)R:79E<RX`0V]N=F5R="!T
M97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/P!#;V]K($ES
M;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T
M:6]N`$-O<'D@=&\@9F]L9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]S
M="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@
M`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H
M96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!2
M96%S;VX@1VEV96XZ("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&
M5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<P!#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<P!#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+@!#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+@!#
M;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@
M35,M5$Y%1B!A='1A8VAM96YT+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q
M=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@
M;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N
M`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V
M97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO
M="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@
M;F]T(&]P96X@<V5C=7)E(&-O;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R
M+B`E<R`Z("5S+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R
M9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@
M9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D
M9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T
M:6]N(&9R;VT@24U!4"!S97)V97(N`$-O=6QD(&YO="!R971R:65V92!S97)V
M97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P
M9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U
M<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`
M0W)E871E($9O;&1E<@!#<F5A=&4@2V5Y<P!#<F5A=&4@82!.97<@06-C;W5N
M=`!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!3<&%M(&9O;&1E<@!#<F5A
M=&4@82!N97<@9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@;VYE`$-R96%T
M92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE=R!T<F%S:"!F
M;VQD97(`0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R
M(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"!A;F0@9&5L
M971E('-P86TN`$-R96%T92!N97<@<W1A=&EO;F5R>0!#<F5A=&4@<W1A=&EO
M;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N`$-R96%T92!S=6(@9F]L9&5R<P!#
M<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA
M`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E
M;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@
M5V5A=&AE<@!#=7)R96YT(&%C8V5S<R!T;R`E<P!#=7)R96YT(&-O;F1I=&EO
M;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C
M:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N`$-U<W1O;6EZ92!H;W<@
M>6]U('-E;F0@;6%I;"X`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@
M*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR
M86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N
M9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T7V4`1&%T851R964@0G)O=W-E
M<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L
M96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU
M;6)E<G,`1&5C;&EN960`1&5C;&EN960Z(`!$96-R96%S92!);F1E;G0`1&5F
M875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3
M96%R8V@@1FEE;&0`1&5F875L="!3:&5L;`!$969A=6QT('-O<G1I;F<@8W)I
M=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS
M`$1E;&5G871E9`!$96QE=&4`1&5L971E("5S(%!U8FQI8R!+97D`1&5L971E
M($-E;&P`1&5L971E($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E
M;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T
M92!396QE8W1E9"!&;VQD97)S`$1E;&5T92!3=&%T:6]N97)Y`$1E;&5T92!6
M:7)T=6%L($9O;&1E<@!$96QE=&4@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO
M;B!F;W(@)7,`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L
M;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4`1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R
M=F5R/P!$96QE=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;65S<V%G97,`
M1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG(&]F
M(&UO;G1H/P!$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN
M;FEN9R!O9B!M;VYT:#\`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L
M971E('-P86T@;65S<V%G97,`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T
M:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE
M=&5D`$1E;&5T960@;65S<V%G97,`1&5L971E9"!S971U<"!U<&=R861E('-C
M<FEP="`B)7,B+@!$96QE=&5D('1H92!A='1A8VAM96YT("(E<R(N`$1E;&5T
M:6YG(&%N9"!-;W9I;F<@365S<V%G97,`1&5L:79E<GD@=&EM90!$96YM87)K
M`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O
M<FUA=&EO;@!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R
M:7!T:6]N`$1E=&%I;',`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I
M;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:60@;F]T(&%T=&%C:"`B)7,B(&%S
M('1H92!F:6QE('=A<R!E;7!T>2X`1&EM('-I9VYA='5R97,_`$1I<F5C=&EO
M;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C
M=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/
M<'1I;VYS`$1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M
M97-S86=E/P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R
M96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&QA>2!I;B!";V1Y(&]F
M($UE<W-A9V4`1&ES<&QA>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M
M86EL/P!$:7-P;&%Y('1H92`B16UP='D@4W!A;2(@;&EN:R!I;B!T:&4@;65N
M=6)A<C\`1&ES<&QA>2!T:&4@(D5M<'1Y(%1R87-H(B!L:6YK(&EN('1H92!M
M96YU8F%R/P!$:7-P;W-I=&EO;@!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`
M1&II8F]U=&D`1&\@3D]4(&UA=&-H`$1O($YO="!#:&5C:R!&;VQD97(H<RD@
M9F]R($YE=R!-86EL`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'``1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I
M;B!T:&4@1G)O;3H@8V]L=6UN`$1O('EO=2!W86YT('1O(&]P96X@=&AA="!F
M;VQD97(_`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI
M8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`
M1&]N90!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"`E<R!I;B`N>FEP
M($9O<FUA=`!$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL
M92D`1&]W;FQO860@1F]L9&5R*',I`$1O=VYL;V%D($9O;&1E<BAS*2!;+GII
M<"!F;W)M871=`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(%!(4"!S8W)I<'0N`$1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T`$1R869T`$1R
M869T(&9O;&1E<@!$<F%F=',@9F]L9&5R.@!$<F]P(&1O=VX@;&ES=`!$<G5G
M<P!%+4UA:6P`12UM86EL($%D9')E<W,`14UA:6PM=&\M4TU3(&=A=&5W87D@
M9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I
M8V4N`$5.1`!%4E(`15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@
M9&5L:79E<F5D+@!%8W5A9&]R`$5D:70`161I="!";&%C:VQI<W0`161I="!"
M;&]C:P!%9&ET($9I;'1E<G,`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`
M161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET
M(%-E87)C:"!1=65R>0!%9&ET(%9I<G1U86P@1F]L9&5R`$5D:70@5FER='5A
M;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,`161I="!7:&ET96QI<W0`161I
M="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET('EO=7(@8FQA8VML:7-T`$5D:70@
M>6]U<B!F:6QT97(@<G5L97,`161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A
M8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RX`161I="!Y;W5R('=H:71E
M;&ES=`!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%
M;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T
M97=A>0!%;6]T:6-O;G,`16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RX`
M16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2!6:7)T=6%L(%1R87-H($9O;&1E
M<BX`16UP='D@1F]L9&5R*',I`$5M<'1Y(%-E;&5C=&5D($9O;&1E<G,`16UP
M='D@5')A<V@@9F]L9&5R`$5M<'1Y(%]3<&%M`$5M<'1Y(%]4<F%S:`!%;7!T
M>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%
M;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_`$5N86)L92!3+TU)344@9G5N8W1I
M;VYA;&ET>3\`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T
M;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N8W)?>7!T:6]N
M($]P=&EO;G,`16YC<GEP=&5D`$5N9`!%;F0@9F]R=V%R9&5D(&UE<W-A9V4`
M16YD(&UE<W-A9V4`16YD(&UE<W-A9V4@9G)O;2`E<P!%;F0@>65A<@!%;FQA
M<F=E($5D:71O<@!%;G1E<B!087-S<&AR87-E`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT
M97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!3<&%M(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N
M="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A
M<V@@9F]L9&5R`$5N=&ER92!-97-S86=E`$5N=')Y("(E<R(@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K`$5Q=6%T;W)I86P@
M1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8V]N;F5C=&EN9R!T;R!)34%0
M('-E<G9E<BX@)7,@.B`E<RX`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R
M<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!S
M96YD:6YG(')E<&QY.B`E<RX`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B
M+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E;G0@<W5C8V5S
M<V9U;&QY(&1E;&5T960N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD
M97)S`$5X<&%N9"!&;VQD97(`17AP86YD($YA;65S`$5X<&%N9"!3:61E8F%R
M`$5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC
M86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\`17AP86YD('1H92!E;G1I<F4@9F]L
M9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/P!%>'!A
M;F1I;F<`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T
M960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O
M;&]R`$944"!U<&QO860@;V8@<V5T=7``1E]E=&-H($UA:6P`1F%I;&5D(')E
M=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&
M86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E
M<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I
M;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&
M86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S
M`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&
M965L<R!L:6ME.B``1F5T8V@@36%I;`!&971C:"!-86EL(&EN(&$@<V5P87)A
M=&4@=VEN9&]W/P!&971C:"!M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_`$9E
M=&-H960@)60@;65S<V%G97,@9G)O;2`E<P!&971C:&5D(#$@;65S<V%G92!F
M<F]M("5S`$9E=&-H;6%I;#H@`$9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S
M+@!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I7VQT97)S`$9I96QD
M(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`
M1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE
M($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D
M`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97(@3W!T:6]N<P!&
M:6QT97(@4V5T=&EN9W,`1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O
M9F%N:71Y/P!&:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y
M<W1E;2X`1FEL=&5R<P!&:6QT97)S($Y/5"!!8W1I=F4`1FEL=&5R<SH@)7,@
M;6%N86=E;65N="!P86=E`$9I;F0`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T
M($UA:6QB;W@@4&%G90!&:7)S="!086=E`$9I<G-T(%%U87)T97(`1FEX(')A
M=&EO`$9L:7``1FQO870`1F]?<G=A<F0`1F]G`$9O;&1E<B`E<R!D;V5S(&YO
M="!E>&ES=`!&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;@!&;VQD97(@
M3F%V:6=A=&]R`$9O;&1E<B!3=6UM87)Y`$9O;&1E<B!S:&%R:6YG(&ES(&YO
M="!E;F%B;&5D+@!&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D+@!&;VYT($-O
M;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H
M92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H
M=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;6%T(&]F(&UE<W-A
M9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T
M960@=&]D87D`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`
M1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9`!&;W)W87)D.@!&;W)W87)D960@
M;65S<V%G90!&;W)W87)D960@;65S<V%G92!F<F]M("5S`$9O<G=A<F1S`$9R
M`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E92]"=7-Y
M(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE
M<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]?;0!&<F]M`$9R
M;VT@061D<F5S<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO
M;VX`1G5L;"!.86UE`$9W9#H`1G=D.B``1G=D.B`E=2!&;W)W87)D960@365S
M<V%G97,`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V%M8FEA`$=E;F5R86P@3W!T:6]N<P!'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!'970@;VYL
M>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI`$=H86YA`$=I8G)A;'1A<@!'
M:79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O('1O($UE<W-A9V4`1V\@
M=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F("(E<R(`1V]E9&5L`$=O;V=L92!-
M87!S`$=O;V=L92!396%R8V@`1W)A;G0@86-C97-S`$=R87ES8V%L90!'<F5E
M8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P
M($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E
M<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN
M96$M0FES<V%U`$=U>6%N80!(15)%`$A434P`2%1-3"!697)S:6]N(&]F($UE
M<W-A9V4`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A
M8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S
M:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@
M86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E3
M3RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L
M<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.@!(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SH`
M2&ED9&5N`$AI9&1E;B!I;B!4:')E860@5FEE=P!(:61E($1E;&5T960`2&ED
M92!5;G-U8G-C<FEB960`2&EG:`!(:6=H(%!R:6]R:71Y`$AI9VAE<W0`2&]?
M;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D
M9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@
M96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO
M(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L
M86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX
M;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A
M=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z
M("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A
M;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@9&\@>6]U('=A
M;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\`2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$AO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@
M<F5P;'D`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)
M34%0`$E-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RD`24U!4"!397)V97(@
M8VQO<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S<&]N9&5D.B`E<P!)
M34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<P!)34%0(&]V97(@4U-,`$E-05`@;W9E<B!34TP@*'-E
M;&8M<VEG;F5D(&-E<G1I9FEC871E*0!)34%0(&]V97(@4U-,("AS96QF+7-I
M9VYE9"D`24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+@!)34%0
M+"!N;R!43%,`24U!4"]03U`S($UA:6P@4V5R=F5R<P!)4"!!9&1R97-S`$E0
M($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)
M7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O
M<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N`$EF('5S:6YG(%-33"!O<B!43%,L('EO=2!M=7-T(&AA
M=F4@=&AE(%!(4"!O<&5N<W-L(&5X=&5N<VEO;B!L;V%D960N`$EF('EO=2!C
M;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B
M92!L;W-T(0!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X
M('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!)
M9VYO<F4`26=N;W)E($%L;`!);6%G90!);6%G92!0<F5V:65W.@!);6%G92!5
M4DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G
M86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R=`!);7!O<G0@2V5Y
M`$EM<&]R="!+97EP86ER`$EM<&]R="!-97-S86=E<P!);7!O<G0@4$=0($ME
M>0!);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&4`26UP;W)T(%!E<G-O;F%L
M(%!R:79A=&4@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+
M97D`26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,`26UP;W)T
M(%!U8FQI8R!+97D`26UP;W)T(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!0=6)L
M:6,@4R]-24U%($ME>0!);7!O<G0@4R]-24U%($ME>0!);7!O<G0@;6)O>"!&
M:6QE`$EM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N`$EM<&]R
M="P@4W1E<"`E9`!);7!O<G1A;G0`26UP;W)T86YT(&UE<W-A9V5S`$EM<&]R
M=&5D("5D(&UE<W-A9V5S(&9R;VT@)7,N`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T97(`
M26YB;W@`26YC;'5D92!A(&)R:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I
M;B!A(')E<&QY/P!);F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L
M>3\`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@
M86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E
M87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!)
M;F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N`$EN9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97D`26YF;W)M871I;VX@
M;VX@4&5R<V]N86P@4')I=F%T92!+97D`26YF;W)M871I;VX@;VX@4&5R<V]N
M86P@4'5B;&EC($ME>0!);FQI;F4`26YS97)T($-?;VQU;6X@069T97(`26YS
M97)T($-E<G1I9FEC871E($AE<F4`26YS97)T($EM86=E`$EN<V5R="!097)S
M;VYA;"!0<FEV871E(%!'4"!+97D@2&5R90!);G-E<G0@4&5R<V]N86P@4'5B
M;&EC(%!'4"!+97D@2&5R90!);G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R90!)
M;G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E
M9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E
M('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A
M9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!)
M;G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A
M<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@
M<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO
M9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F
M:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!!
M8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+@!);G9A;&ED($%D
M9')E<W,`26YV86QI9"!296UO=&4@36%I;&)O>`!);G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P
M;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@8VAA<F%C=&5R
M(&EN(&4M;6%I;"!A9&1R97-S.B`E<RX`26YV86QI9"!D871A('-U8FUI='1E
M9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@
M9F]R;6%T`$EN=F%L:60@:V5Y`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L
M:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A
M<G1N97(@:60N`$EN=F%L:60@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y+@!)
M;G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y+@!);G9A;&ED('!R;V1U
M8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z
M("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D
M<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0`
M26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER
M87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A
M96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`
M2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N
M90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y
M($QE9G0`2G5S=&EF>2!2:6=H=`!+0@!+87IA:VAS=&%N`$ME97`@;W)I9VEN
M86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A
M=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P
M<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$ME>2!G96YE<F%T
M:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE('1O(&-O;7!L971E+B`@0V]N=&EN
M=64@=VET:"!K97D@9V5N97)A=&EO;C\`2V5Y(&EM<&]R="!I<R!N;W0@879A
M:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E
M<G9E<BX`2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N
M;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B!C;VYT86-T<RX`
M2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`
M2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!-86EL8F]X
M(%!A9V4`3&%S="!086=E`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A
M<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO
M=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F
M="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI
M8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ
M>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA
M=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`
M3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI
M;FL@071T86-H;65N=',_`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M`$QI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+@!,:6YK<P!,:6YK
M<R!W:6QL(&5X<&ER92!O;B`E<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4
M;W!I8W,`3&ES="!486)L97,`3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D
M:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I
M;&P@;VYL>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L
M:6-I=&QY*0!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/
M=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB
M90!,:7-T:6YG(&EN('1H92!(96%D97(`3&ES=&EN9R!S97-S:6]N<R!F86EL
M960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN
M`$QO8V%L($UA:6QB;W@Z`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`
M3&]C871I;VX`3&]G(&EN`$QO9R!I;B!T;R`E<P!,;V<@;V8@<')E=FEO=7,@
M<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`
M3&]V90!,;W<`3&]W(%!R:6]R:71Y`$QO=V5R(&=R965K(&QE='1E<G,`3&]W
M97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QO=V5S=`!,
M=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F`$UA8VEN=&]S:"!&:6QE`$UA9&%G87-C87(`
M36%G:6,`36%I;`!-86EL($%D;6EN`$UA:6P@4')E=FEE=W,`36%I;"!S97)V
M97(@='EP92!T;R!C;VYN96-T('1O.@!-86EL8F]X`$UA:6QB;W@@86YD($9O
M;&1E<B!$:7-P;&%Y($]P=&EO;G,`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L
M87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R
M-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R
M9VEN`$UA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N`$UA<FL@
M06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96X`36%R:R!A<SH`36%R
M:R!D:69F97)E;G0@;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@
M8V]L;W)S/P!-87)K(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI`$UA
M<FL@<VEM<&QE(&UA<FMU<#\`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:"!!;&P@475E
M<FEE<P!-871C:"!!;GD@475E<GD`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N
M:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($%T=&%C:&UE;G0@4VEZ90!-
M87AI;75M($YU;6)E<B!O9B!&;VQD97)S`$UA>&EM=6T@3G5M8F5R(&]F(%!O
M<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%X:6UU;2!N=6UB97(@;V8@
M871T86-H;65N=',@<F5A8VAE9"X`36%X:6UU;2!T;W1A;"!A='1A8VAM96YT
M('-I>F4@<F5A8VAE9"X`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-
M96YU($9O;&1E<B!,:7-T`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G
M90!-97-S86=E($-O;7!O<VET:6]N`$UE<W-A9V4@1&%T90!-97-S86=E($]P
M=&EO;G,`365S<V%G92!396%R8V@`365S<V%G92!3:7IE`$UE<W-A9V4@4V]U
M<F-E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG
M;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S
M86=E(%9I97=I;F<`365S<V%G92!E>'!I<F5D+@!-97-S86=E(&9L86=S`$UE
M<W-A9V4@9F]L9&5R<P!-97-S86=E(&9R;VT@)7,`365S<V%G92!H87,@871T
M86-H;65N=',`365S<V%G92!I<R!E;F-R>7!T960`365S<V%G92!I<R!S:6=N
M960`365S<V%G92!M871C:&5S`$UE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S
M9G5L;'DN`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V
M960@=&\@)7,`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2X`365S<V%G92!T
M>7!E`$UE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N`$UE
M<W-A9V5S('1O`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I
M<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E
M9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-
M971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`
M36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN
M('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A
M=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT
M('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N
M`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@
M<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@
M1&%T90!-;V1I9GD`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B
M;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY
M`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@
M;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R92!T:&%N(&]N92!A
M9&1R97-S(&9O=6YD(&9O<B!F:65L9"`B)7,B+@!-;W)O8V-O`$UO<W1L>2!#
M;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO
M<W1L>2!3=6YN>0!-;W9E`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H
M=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('-P86T@;65S<V%G97,@=&\@<W!A
M;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8`$UO=F4@
M=&\@9F]L9&5R`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&%R="]A;'1E<FYA
M=&EV90!-=6QT:7!L92!-97-S86=E(%9I97<`375L=&EP;&4@<V5L96-T:6]N
M`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`
M37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.
M3TY%`$Y/5$4`3F%M90!.86UE(&%N9"]O<B!E;6%I;"!C86YN;W0@8F4@96UP
M='D`3F%M:6)I80!.875R=0!.965D<R!!8W1I;VX`3F5P86P`3F5T:&5R;&%N
M9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%52
M3`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%52
M3`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`
M3F5V97(`3F5V97(@<V%V92!A='1A8VAM96YT<P!.97<`3F5W($-A;&5D;VYI
M80!.97<@0V%T96=O<GD`3F5W($9O;&1E<@!.97<@36%I;`!.97<@365S<V%G
M90!.97<@365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P
M=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@;65S<V%G97,`3F5W('!A<W-W;W)D
M`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D
M<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G
M<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@365S<V%G90!.97AT(%!A
M9V4`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA
M`$YI9VAT`$YI=64`3F\`3F\@0V5R=&EF:6-A=&4@9F]U;F0`3F\@16YC<GEP
M=&EO;@!.;R!+97ES(&EN($ME>7)I;F<`3F\@365S<V%G97,`3F\@4$=0('!U
M8FQI8R!K97D@:6UP;W)T960N`$YO(%!E<G-O;F%L($-E<G1I9FEC871E(%!R
M97-E;G0`3F\@4')E=FEE=R!497AT`$YO(%!U8FQI8R!+97ES($9O=6YD`$YO
M(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!A='1A8VAM96YT<R!F
M;W5N9"X`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H
M86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L
M969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@96UA:6P@:6YF;W)M
M871I;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2X`3F\@9FEL92!U<&QO
M861E9`!.;R!F;VQD97(@<V5L96-T960N`$YO(&9O;&1E<G,@87)E(&)E:6YG
M(&-H96-K960@9F]R(&YE=R!M86EL+@!.;R!F;VQD97)S('=E<F4@<W!E8VEF
M:65D`$YO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,`3F\@9F]L9&5R<R!W
M:71H('5N<V5E;B!M97-S86=E<P!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I
M;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!B
M;V1Y('1E>'0`3F\@;65S<V%G92!R971U<FYE9"X`3F\@;65S<V%G92!S=7!P
M;&EE9"X`3F\@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"X`3F\@;F%M
M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV
M92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO
M9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,
M(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S
M<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I
M9VYU<',N`$YO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"X`
M3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N`$YO('!E<G-O
M;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP;W)T960N`$YO('!E<G-O;F%L
M('!R:79A=&4@:V5Y(&5X:7-T<R!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@
M=&\@8F4@9&5C<GEP=&5D+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E
M<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-P96QL8VAE8VMI;F<@
M<')O9W)A;2!C;VYF:6=U<F5D+@!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5C
M:"!F:6QE`$YO('-U9V=E<W1I;VYS`$YO('-U<'!O<G1E9"!)34%0(&%U=&AE
M;G1I8V%T:6]N(&UE=&AO9"!C;W5L9"!B92!F;W5N9"X`3F\@=&5M<&]R87)Y
M(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R('-P96-I
M9FEE9"X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A
M;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N(%!A<G1I8VEP
M86YT`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y
M+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)M86P`3F]R=&AE<FX@2&5M:7-P:&5R
M90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.
M;W0@0F5F;W)E`$YO="!$96QE=&5D`$YO="!$<F%F=`!.;W0@26UP;W)T86YT
M`$YO="!097)S;VYA;`!.;W0@82!D:7)E8W1O<GD`3F]T(&$@=F%L:60@<'5B
M;&EC(&ME>2X`3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&QE;65N=&5D
M+@!.;W0@:6UP;W)T86YT(&UE<W-A9V5S`$YO="!S970`3F]T('-U<'!O<G1E
M9"X`3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE`$YO=&5S`$YO
M=&AI;F<`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EF:6-A=&EO
M;CH@3&EN:V5D(&%T=&%C:&UE;G0@9&]W;FQO861E9`!.;W9E;6)E<@!.=6UB
M97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M
M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@
M:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E<B!O
M9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]2`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!M97-S86=E
M<P!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/
M;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D+@!/;6%N`$]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@9&ES
M<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_`$]N
M;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@
M86QL;W=E9"X`3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F
M;W(@=&AI<R!A8W1I;VXN`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI
M<W-I;VYS(&9O<B!A('-H87)E`$]P96X@1F]?;&1E<@!/<&5N(&EN(&$@;F5W
M('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A
M(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N960@1F]L9&5R`$]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/
M<'1I;VYA;"!087)T:6-I<&%N=`!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R
M9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/
M<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I
M;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`
M3W1H97(@36%I;"!!8V-O=6YT<P!/=&AE<B!/<'1I;VYS`$]U=&)O=6YD(%-E
M<G9E<@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4`!01U`@1&EG
M:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'0@365S<V%G90!01U`@16YC<GEP
M=&5D($1A=&$`4$=0($5R<F]R.B``4$=0($5R<F]R.B!.965D('!A<W-P:')A
M<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!01U`@3W!T:6]N<P!01U`@
M4&%S<W!H<F%S92!);G!U=`!01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T
M(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!01U`@4'5B;&EC
M($ME>0!01U`@4'5B;&EC($ME>2!497AT`%!'4"!0=6)L:6,@2V5Y(&9O<B`B
M)7,@*"5S*2(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0(%!U8FQI8R!+
M97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!01U`@4'5B
M;&EC($ME>7)I;F<`4$=0(%-I9VX@365S<V%G90!01U`@4VEG;B]%;F-R>7!T
M($UE<W-A9V4`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!01U`@<')I=F%T
M92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@<'5B;&EC(&ME>2!S=6-C
M97-S9G5L;'D@861D960N`%!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H
M:7,@<WES=&5M+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV
M92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E('9E
M<FEF:65D+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S
M;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+@!01U`@
M<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)
M9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O
M<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@
M96QS92!T:&4@4$=0(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY
M+@!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-
M(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M
M4W1O<FUS`%!/4#,`4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*0!03U`S
M(&]V97(@4U-,`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC
M871E*0!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"D`4$]0,RP@;F\@5$Q3
M`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN
M9P!086=E("5D(&]F("5D`%!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE
M<W-A9V4`4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E`%!A:VES
M=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N
M86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R="AS*0!087)T;'D@
M0VQO=61Y`%!A<W-P:')A<V4`4&%S<W!H<F%S92`H06=A:6XI`%!A<W-P:')A
M<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+@!087-S<&AR87-E.@!087-S<&AR
M87-E<R!C86YN;W0@8F4@96UP='D`4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H
M`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S
M=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S
M<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E
M`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!0
M96]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M
M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO
M;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VX`4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C86YN;W0@8F4@8VAA;F=E
M9"X`4&5R<V]N86P`4&5R<V]N86P@26YF;W)M871I;VX`4&5R<V]N86P@4$=0
M(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4&5R<V]N86P@4$=0
M(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN`%!E<G-O;F%L(%,O34E-12!C
M97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B``4&5R<V]N86P@4R]-24U%(&ME
M>7,@9&5L971E9"!S=6-C97-S9G5L;'DN`%!E<G4`4&5T<P!0:&EL:7!P:6YE
M<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L86-E('EO=7(@<VEG
M;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\`4&QA:6YT97AT
M(%9E<G-I;VX@;V8@365S<V%G90!0;&%T:71U9&5S`%!L87D@<V]U;F0@;VX@
M;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P
M;W)T(&5M8F5D9&5D('-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7
M:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"!R97%U
M:7)E(&$@<&QU9VEN+@!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.@!0;&5A<V4@
M96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@96YT97(@=&AE
M(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@;F5W
M(&YA;64Z`%!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!0
M1U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T
M:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BX`4&QE87-E(&5N
M=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME
M>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N=&5R('1H:7,@<&%S<W!H<F%S
M92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A<V4@;&]G(&EN(&%G86EN('1O
M(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/
M5"!U<VEN9R!C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E
M<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O(&QO9R!I;B!A
M9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@
M:V5E<"!A='1A8VME<G,@9G)O;2!H:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$
M+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E+@!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@<&%S<W=O<F0N`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64N
M`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R
M97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E
M('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@=&AI<R!A8W1I
M;VXN`%!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R
M8V@N`%!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P
M97)A=&EO;BX`4&QE87-E('-E;&5C="!O<B!E9&ET(&EN('1H92!B;W@@=&\@
M=&AE(')I9VAT.@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z
M`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O
M9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T
M;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!O=V5R960@
M8GD@2&]R9&4`4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H
M)RTM("<I/P!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0
M<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969E<F5N8V5S('-U8V-E<W-F
M=6QL>2!U<&1A=&5D+@!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@
M<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!-97-S86=E`%!R979I;W5S
M(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0<FEN=`!0<FEN="!D;V-U;65N=`!0
M<FEO<FET>0!0<FEV871E($ME>0!0<FEV871E($ME>2!087-S=V]R9`!0<F]B
M;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T(&5V97)Y
M('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/`%!R
M;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L
M="!T;R!915,`4')O;7!T('1E>'0`4')O=&]C;VPZ`%!U8FQI8R!+97D`4'5B
M;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R!01U`@
M:V5Y<V5R=F5R('-U<'!O<G0@:&%S(&)E96X@9&ES86)L960N`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U
M97)T;R!2:6-O`%!U<E]G92!$96QE=&5D`%!U<F=E($1E;&5T960`4'5R9V4@
M1F]L9&5R*',I`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S<V%G
M97,`4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@
M=&AI<R!A;6]U;G0@;V8@9&%Y<RX`4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H
M92!4<F%S:"!F;VQD97(_`%!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S
M:"!F;VQD97(N`%!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R
M+@!1871A<@!1=65R>0!1=6]T80!1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N
M,F9-0B`@*"4N,F8E)2D`475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)
M5`!1=6]T82!S=&%T=7,Z($Y/($Q)34E4`%%U;W1I;F<@)68Z`%)302!0=6)L
M:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R
M;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T
M;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5B=6EL9"!&;VQD
M97(@5')E90!296-E:79E9"!/;@!296-E:79E9"!3:6YC90!296-E:79E9"!5
M;G1I;`!2961I<F5C7W0`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I
M<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2961O97,@
M>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.@!2969R97-H($9O;&1E<B!6:65W<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E
M;&]A9"!6:65W`%)E;6%R:W,`4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BX`4F5M96UB97(@=&AE(&QA<W0@=FEE=P!296UO=&4@36%I;&)O
M>#H`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E($9I
M96QD($9R;VT@4V5A<F-H`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I
M;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!S;W5R8V4`4F5M;W9E
M('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V
M92!U<V5R`%)E;6]V92!U<V5R.B`E<P!296YA;64@1F]L9&5R*',I`%)E;F%M
M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`4F5N
M86UI;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!297!L7WD@=&\@3&ES=`!297!L86-E('=I=&@Z`%)E<&QY
M`%)E<&QY(%-E;G0N`%)E<&QY('1O($%L;`!297!L>2!T;R!!;&PZ`%)E<&QY
M('1O($QI<W0`4F5P;'D@=&\@3&ES=#H`4F5P;'D@=&\@7T%L;`!297!L>2!W
M:71H($YO="!3=7!P;W)T960@365S<V%G90!297!L>2!W:71H(&9R964O8G5S
M>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P;'D@=VET:"!R97%U97-T960@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L>2U4;P!297!L>2U4;SH@`%)E<&QY
M.@!297!O<G0@87,@26YN;V-E;G0`4F5P;W)T(&%S(%-P86T`4F5Q=65S="!A
M(%]296%D(%)E8V5I<'0`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S="!R96%D(')E8V5I<'1S/P!2
M97%U97-T960@;65S<V%G92!N;W0@9F]U;F0N`%)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P
M96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N
M;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD
M`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E
M<V5T(%EO=7(@4&%S<W=O<F0`4F5S<&]N9&5N="!3=&%T=7,@57!D871E9"X`
M4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5S=6UE`%)E<W5M92!Y;W5R
M('-E<W-I;VX`4F5T=7)N('1O(")-97-S86=E($-O;7!O<VET:6]N(@!2971U
M<FX@=&\@1F5T8V@@36%I;`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@
M=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O
M<B!C;W!Y:6YG(&$@;65S<V%G93\`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N
M:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`
M4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-10!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'0@
M365S<V%G90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4R]-24U%($5R<F]R
M.B``4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L
M('!R:79A=&4@:V5Y+@!3+TU)344@3W!T:6]N<P!3+TU)344@4&%S<W!H<F%S
M92!);G!U=`!3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I
M<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!3+TU)344@4'5B;&EC($ME
M>2!F;W(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%,O34E-12!0
M=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`4R]-24U%(%!U8FQI8R!+
M97ER:6YG`%,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F
M=6QL>2!A9&1E9"X`4R]-24U%(%-I9VX@365S<V%G90!3+TU)344@4VEG;B]%
M;F-R>7!T($UE<W-A9V4`4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@
M=&AI<R!S>7-T96TN`%,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@
M96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP
M=&5D+@!3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@8V]N
M=&5N=',@;V8@=&AI<R!S:6=N960@;65S<V%G92!C86YN;W0@8F4@9&ES<&QA
M>65D+@!3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG
M:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E('9E<FEF:65D+@!3+TU)
M344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N
M("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE
M('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@
M;W(@96QS92!T:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R
M<F5C=&QY+@!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%--4R!-97-S86=I;F<`4TU44`!344P@4VAE;&P`4U%,('-T871E;65N="!F
M;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-?=6)J
M96-T`%-A`%-A7W9E(&$@8V]P>2!I;B``4V%?=F4@87,`4V%I;G0@2&5L96YA
M`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R
M<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4
M;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A
M8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!!='1A8VAM96YT<R!W
M:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\`4V%V92!$<F%F=`!3
M879E($EM86=E`%-A=F4@26UA9V4@:6X@1V%L;&5R>0!3879E($]P=&EO;G,`
M4V%V92!3=&%T:6]N97)Y`%-A=F4@7T1R869T`%-A=F4@87,`4V%V92!D<F%F
M=',@87,@=6YS965N/P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D
M969A=6QT(&%D9')E<W,@8F]O:S\`4V%V92!S96%R8V@@87,@82!V:7)T=6%L
M(&9O;&1E<C\`4V%V92!S96YT(&UA:6P_`%-A=F5D("5S(&-O;F9I9W5R871I
M;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!3879I
M;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@)7,`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E
M87)C:"`E<P!396%R8V@@16YG:6YE<P!396%R8V@@3W!T:6]N<P!396%R8V@@
M4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@06YO=&AE<B!!8V-O=6YT`%-E
M;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C
M="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@
M<V5R=F5R`%-E;&5C="!A('-T871I;VYE<GDZ`%-E;&5C="!A('5S97(@=&\@
M861D`%-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N
M9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RX`4V5L96-T(&%L;`!396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%L;"!F:65L9',@=&\@<V5A
M<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RX`4V5L96-T(&%N(&%C8V]U
M;G0`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E
M(&EN+@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`
M4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E`%-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@061D<F5S
M<R!B;V]K<SH`4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<@!396YD($QA
M=&5S="!);F9O<FUA=&EO;@!396YD($UE<W-A9V4`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YD(&UE<W-A9V4@=VET:&]U="!A(%-U8FIE8W0_
M`%-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD
M97(_`%-E;F5G86P`4V5N<V]R.B``4V5N="!M86EL(&9O;&1E<@!396YT(&UA
M:6P@9F]L9&5R.@!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E
M<FEA;"!.=6UB97(`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T
M:6]N`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<G9E
M<CH`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS
M`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!P<F5F97)E;F-E
M<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M
M97-S86=E<RX`4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O
M<VEN9R!M97-S86=E<S\`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE
M;&QE<P!3:&%R92!&;VQD97)S`%-H87)E(&UA:6P@9F]L9&5R<P!3:&%R92!Y
M;W5R(&UA:6P@9F]L9&5R<R!W:71H(&]T:&5R('5S97)S+@!3:&]P<&EN9P!3
M:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/P!3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T
M97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@
M=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N`%-H;W5L9"!T
M:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R
M(%!'4"!D871A/P!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E
M9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=6QD('EO=7(@4$=0('!U8FQI
M8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A
M=6QT/P!3:&]W`%-H;W<@06QL($9O;&1E<G,`4VAO=R!!;&P@2&5A9&5R<P!3
M:&]W($1E;&5T960`4VAO=R!,:6UI=&5D($AE861E<G,`4VAO=R!-86EL:6YG
M($QI<W0@26YF;W)M871I;VX`4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R
M<P!3:&]W(%5N<W5B<V-R:6)E9`!3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R
M:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_`%-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&QE9V5N9"!I;B!T:&4@;6%I;&)O
M>"!V:65W/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC
M:V5R`%-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/P!3
M:&]W('!R979I97=S(&EN('1O;VQT:7!S/P!3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H
M;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T
M:&4@26UA9V5S`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&9I;'1E<B!I
M8V]N(&]N('1H92!M96YU8F%R/P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9P!3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_
M`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA
M=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAO=VX`4VAR:6YK`%-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S=`!3:5]Z90!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`
M4VEG;F%T=7)E($%L9V]R:71H;0!3:6=N960`4VEN9V%P;W)E`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO
M=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W
M97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R
M="!B>2!!<G)I=F%L`%-O<G0@8GD@1&%T90!3;W)T(&)Y($9R;VT@061D<F5S
M<P!3;W)T(&)Y($UE<W-A9V4@4VEZ90!3;W)T(&)Y(%-U8FIE8W0`4V]R="!B
M>2!4:')E860`4V]R="!B>2!4;R!!9&1R97-S`%-O<G0@;W)D97(@<V5L96-T
M:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A
M;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@
M8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D
M9&EN9P!3<&%I;@!3<&%M`%-P86T@9F]L9&5R.@!3<&5C:6%L($-H87)A8W1E
M<B!);G!U=`!3<&5C:6%L($-H87)A8W1E<G,`4W!E8VEA;"!6:7)T=6%L($9O
M;&1E<G,@8V%N;F]T(&)E(&5D:71E9"X`4W!E;&P@0VAE8VL`4W!E;&P@0VAE
M8VME<@!3<&5L;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R
M('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+@!3<&QI="!C96QL`%-P;&ET
M(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3
M=&%R(%1R96L`4W1A<G0`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T:6]N97)Y`%-T871I;VYE<GD@;F%M93H`4W1A=&EO;F5R>2!T>7!E.@!3
M=&%T:6]N97)Y.@!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E
M<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!!='1A8VAM96YT
M`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T<FEP(&QI;F5B<F5A
M:W,_`%-T>6QE(%M#4U-=`%-U`%-U8E]J96-T`%-U8F1I<F5C=&]R>2`B)7,B
M(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)J96-T($9I96QD`%-U8FUI=`!3=6)M
M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P
M<F]V960N`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5B<V-R:7!T`%-U8V-E
M<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE
M('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U
M;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL
M>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG
M97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`
M4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL
M>2!W<F]T92`E<P!3=61A;@!3=6=G97-T:6]N<P!3=6UM87)Y`%-U;B!2:7-E
M`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E
M.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA
M;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3
M=V5D96X`4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9`!3=VET8V@@=&\@2%1-
M3"!C;VUP;W-I=&EO;@!3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO
M;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M
M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R
M;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`
M5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#
M:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`
M5&%R9V5T.@!487-K<P!495]X=`!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R
M(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R
M871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B
M)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5N=&%T
M:79E.B``5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0`5&5N=&%T:79E;'D@
M06-C97!T960`5&5R;7,@;V8@4V5R=FEC92!F:6QE(&YO="!S<&5C:69I960@
M:6X@8V]N9BYP:'``5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P
M`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%1H92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE
M<W-A9V4@<VAO=6QD(&)E(&QI;FME9#H`5&AE($AI<W1O<GD@<WES=&5M(&ES
M(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U!4"!S97)V97(@9&]E<R!N
M;W0@87!P96%R('1O('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO
M9"!S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BX`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"X`5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K`%1H92!-86-I;G1O<V@@
M<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RX`5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%C8V]U
M;G0@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@86-C;W5N="`B)7,B(&AA
M<R!B965N('-A=F5D+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!A='1A8VAM96YT('=A<R!N
M;W0@9F]U;F0N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C86QE;F1A<B!D
M871A(&ES(&EN=F%L:60`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@8V]N=&5N=',@;V8@=&AE($UA
M8VEN=&]S:"!F:6QE(&%R92!B96QO=RX`5&AE(&-U<G)E;G0@9F]L9&5R*',I
M("(E<R(@=VEL;"!B92!R96YA;65D('1O("(E<R(N`%1H92!C=7)R96YT(&QI
M<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@
M;F]T(&)E(')E=')I979E9`!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A
M<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`
M5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92`B)7,B(&9O;&1E<BX`
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BX`5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N
M9&%R+@!4:&4@9FEE;&0@(B5S(B!C86XG="!B92!E>'!A;F1E9"X`5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C
M86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82X`5&AE(&9O;&1E<B`B)7,B(&%L<F5A9'D@97AI<W1S`%1H
M92!F;VQD97(@(B5S(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@
M:71S(&YA;64N($ET(&UA>2!C875S92!P<F]B;&5M<RX@4&QE87-E('-E92!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4:&4@9F]L9&5R("(E<R(@=V%S
M(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+@!4
M:&4@9F]L9&5R("(E<R(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U
M;G-U8G-C<FEB960@9G)O;2!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@
M8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L
M9&5R("(E<R(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&-R
M96%T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T
M960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@
M=&\@(B5S(BX`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9O;&QO=VEN9R!F:6QE
M<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R=#H`5&AE(&9U;&P@<V-R965N
M(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE
M="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD
M+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I
M<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T
M(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/
M2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D
M:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S
M('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@<&]P=7`@=VEN
M9&]W<S\`5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H
M92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R(&%D9')E<W-B;V]K+@!4:&4@
M;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RX`5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R
M<F]R(&UE<W-A9V4Z`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O
M;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z`%1H92!M86EL('-E<G9E
M<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.@!4:&4@;6%I;&)O
M>"`E<R!I<R!A;')E861Y(&5M<'1Y+@!4:&4@;65S<V%G92`B)7,B(&9R;VT@
M(B5S(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="X`5&AE
M(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET
M:6YG+@!4:&4@;65S<V%G92!D;V5S(&YO="!H879E(&$@4W5B:F5C="!E;G1E
M<F5D+@!4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+@!4:&4@;65S<V%G
M92!H87,@8F5E;B!V97)I9FEE9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R
M:69I960N(%-E;F1E<CH@)7,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES
M(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E
M860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN
M9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E
M<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')A=R!T97AT(&]F('1H
M92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+@!4:&4@<F5Q=65S
M=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE($U3+51.148@871T86-H
M;65N="X`5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H
M92!::7`@871T86-H;65N="X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S96YD97(@;V8@=&AI
M<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;B!F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI
M<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@;F]T:69I
M8V%T:6]N(&UE<W-A9V4N`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-E<G9E
M<B!W87,@;F]T(&%B;&4@=&\@8W)E871E(&$@=&AU;6)N86EL(&]F('1H:7,@
M:6UA9V4N`%1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+@!4
M:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N`%1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P
M96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X:7-T+@!4:&4@<W!E8VEF:65D(')O
M=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@<W1A=&EO;F5R>2`B)7,B(&AA
M<R!B965N(&%D9&5D+@!4:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!S=&%T:6]N97)Y("(E<R(@:&%S(&)E96X@=7!D871E9"X`
M5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="X`5&AE
M('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT
M(&]F('1H92!M97-S86=E`%1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B
M92!V:65W960@)7,N`%1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E
M`%1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W
M960@)7,N`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4`5&AE('1E>'0@
M;V8@=&AE('-E;G0@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X
M="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S
M8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@
M<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N`%1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A
M<R!S=6-E<W-F=6QL>2!S=&]R960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!4:&5R92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN
M('1H:7,@;6%I;&)O>"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E(&ES(&YO('1E>'0@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B
M;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T
M96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O
M>"X@5&AE('-E<G9E<B!S86ED.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O
M8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E
M('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B
M)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@(B5S
M(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O
M<B!D96QE=&EN9R!M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N
M=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E
M<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RX`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER
M960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@
M9G)O;2`B)7,B('1O("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S
M(&$@9')A9G0N`%1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S
M<V%G93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@979E;G0Z("5S+@!4:&ES($A434P@;65S<V%G92!H87,@:6UA
M9V5S(&5M8F5D9&5D(&EN(&ET+@!4:&ES($A434P@;65S<V%G92!H87,@:6UA
M9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK
M92!T:&ES.B``5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H
M87)I;F<@9F]L9&5R<RX`5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H
M960@=&\@=&AE(&UE<W-A9V4N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T
M960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H
M:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS
M,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I
M<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE
M8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T
M86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O
M9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;6%Y
M('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N
M=&EN=64_`%1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE
M+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA
M<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S
M86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R
M>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@
M9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O
M9B!T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BX`5&AI<R!M97-S86=E(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G
M92X@17)R;W(Z(`!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R!21D,@
M,C`Q-2DN`%1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@
M=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="X`5&AI<R!M97-S86=E(&AA<R!B
M965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"X`5&AI<R!M97-S86=E(&AA
M<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S
M86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A
M9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+@!4:&ES(&UE<W-A9V4@
M=&\`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD
M;W<N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N
M<R!W:6YD;W<`5&AR96%D($1I<W!L87D`5&AR96%D(%9I97<`5&AU;F1E<@!4
M:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E
M;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O
M`%1O($%D9')E<W,`5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92!C
M;&EC:VEN9RX`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C
M;&EC:VEN9RX`5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO=2!M=7-T(&)E
M(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C$N,"!O<B!H:6=H97(N`%1O
M9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`
M5&]N9V$`5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T
M(&UI;G5T97,N`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1O=&%L($%T=&%C:&UE
M;G1S(%-I>F4Z`%1R86YS;&%T:6]N<P!4<F%S:"!F;VQD97(`5')A<V@@9F]L
M9&5R.@!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N
M:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N
M`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H
M;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D
M96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA
M8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X
M=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I
M>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O
M)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP
M<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E
M;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE
M<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&
M:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')E=')I
M979E('%U;W1A`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E
M9"X`56YA;G-W97)E9`!5;F%N<W=E<F5D(&UE<W-A9V5S`%5N9&5L971E`%5N
M9&5R;&EN90!5;F1I<V-L;W-E9"!296-I<&EE;G1S`%5N9&\@0VAA;F=E<P!5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O($%55$A%3E1)0T%412!C;VUM86YD+@!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($1I9V5S="U-1#4@<F5S<&]N
M<V4N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\@3$]'24X@
M8V]M;6%N9"X`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@
M`%5N9FEL960`56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<P!5;FEC
M;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D
M;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG
M($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N($1A=&4`56YK;F]W;B!)
M34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E
M9#H@)7,`56YK;F]W;B!-965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FQO860@4&%S<W!H<F%S90!5;FYA;65D`%5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"X`56YS965N`%5N<V5T(&-O;&]R`%5N<W5B<V-R
M:6)E(&9R;VT@1F]L9&5R*',I`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A
M=&4`57!D871E("5S`%5P9&%T92!R97-P;VYD96YT('-T871U<P!5<&1A=&4@
M=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P
M;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!$969A=6QT(%9A
M;'5E`%5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/P!5<V4@4U-,`%5S
M92!6:7)T=6%L(%1R87-H($9O;&1E<C\`57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("(E<R(@
M<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R("(E<R(N`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E
M9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N
M86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5
M<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U
M`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@
M*%9)4T-)22D`5FEE=P!6:65W("5S`%9I97<@)7,@4'5B;&EC($ME>0!6:65W
M($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W($UE<W-A
M9V5S`%9I97<@4&5R<V]N86P@4')I=F%T92!+97D`5FEE=R!097)S;VYA;"!0
M=6)L:6,@2V5Y`%9I97<@5&AR96%D`%9I97<@5&AU;6)N86EL`%9I97<@86X@
M97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W(&%T=&%C:&UE;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W`%9I97<@979E;G0`5FEE=R!M97-S86=E<R!I;B`E<P!6:65W
M(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CH`5FEE=R!T87-K
M`%9I97<@=&AE($EM86=E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G
M:6X@27-L86YD<RP@52Y3+@!6:7)T=6%L($9O;&1E<B`B)7,B(&-R96%T960@
M<W5C8V5S9G5L;'DN`%9I<G1U86P@1F]L9&5R<P!6:7)T=6%L($9O;&1E<G,@
M<F5Q=6ER92!A(&QA8F5L+@!6:7)T=6%L($E.0D]8`%9I<G1U86P@24Y"3U@@
M1F]L9&5R`%9I<G1U86P@5')A<V@`5FER='5A;"!4<F%S:"!&;VQD97(`5FER
M='5A;"!F;VQD97(@;&%B96P`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D
M869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!3
M0U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A
M;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R
M(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E
M96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R
M;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@
M4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T
M97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H
M870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAA="!S:&]U;&0@=V4@9&\@
M=VET:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R
M=&5D(&%S('-P86T@;W(@:6YN;V-E;G0_`%=H96X@9&5L971I;F<@;65S<V%G
M97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F
M(&UA<FMI;F<@=&AE;2!A<R!D96QE=&5D/P!7:&5N(&]P96YI;F<@82!N97<@
M;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\`
M5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM
M96YT(&1A=&$_`%=H96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N9&EN9R!A9&1R
M97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E;F0@=&\@=6YQ=6%L
M:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S97,@=VET:&]U="`B0"(I
M/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VAI
M=&5L:7-T`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I
M:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`
M5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K
M(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP
M96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R
M96%D:6YG(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A
M:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T
M($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I
M97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L
M>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@86)O=70@=&\@9F5T
M8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ`%EO=2!A
M<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE
M9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!A='1E;7!T
M:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R
M92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E
M871I;F<@82!S=6(M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P
M+6QE=F5L(&9O;&1E<BX`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE
M(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S
M+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@87)E(')E;F%M:6YG
M('1H92!F;VQD97(Z(`!9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E
M:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE(&-U
M<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92X`
M66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+@!9;W4@8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@(B5S(BX`66]U
M(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M
M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"!T;R!L;V=I;BX`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R`%EO
M=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W
M:6YG(')E8VEP:65N=',Z("5S+@!9;W4@:&%V92`E<R!N97<@;65S<V%G97,N
M`%EO=2!H879E(#$@;F5W(&UE<W-A9V4N`%EO=2!H879E(&%L<F5A9'D@<W5B
M;6ET=&5D('1H:7,@<&%G92X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9
M;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CH`66]U
M(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET
M<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E
M<B!A="!L96%S="!O;F4@<F5C:7!I96YT+@!9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@96YT97(@
M=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I
M97<@=&AI<R!M97-S86=E`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E
M(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S
M<V%G90!9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="X`
M66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"X`66]U
M(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%T
M(&QE87-T(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y(&$@
M<F5C:7!I96YT+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O(&AA=F4@(B5S(B!E
M;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RX`66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@<F5D:7)E
M8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+@!9;W4@<F5P;&EE9"!T
M;R!T:&ES(&UE<W-A9V4@;VX@)7,N`%EO=2!W97)E(&YO="!S=6)S8W)I8F5D
M('1O("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E
M<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB
M960@=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D
M(&9R;VT@(B5S(@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S
M92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@
M861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E
M<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(%!'4"!0=6)L:6,O4')I=F%T
M92!+97ES`%EO=7(@4')I=F%T92!+97D`66]U<B!0=6)L:6,@2V5Y`%EO=7(@
M4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3X`66]U<B!3
M+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S`%EO=7(@86-C;W5N
M=',Z`%EO=7(@86QI87,@861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E
M<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/@!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT
M:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G
M92!T>7!E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT
M+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8VAA<G-E
M="!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&5N8W)Y<'1I
M;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U;'0@
M:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT
M:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L:6YK960@871T86-H;65N="!H
M87,@8F5E;B!D;W=N;&]A9&5D(&)Y(&%T(&QE87-T(&]N92!U<V5R+@H*071T
M86-H;65N="!N86UE.B`E<PI!='1A8VAM96YT(&1A=&4Z("5S"@I#;&EC:R!O
M;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@<&5R;6%N96YT;'D@9&5L971E('1H
M92!A='1A8VAM96YT.@HE<P!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R
M(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N`%EO=7(@;F5W
M('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@
M8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S
M<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E
M('-E<G9E<G,Z`%EO=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!::7!P>0!;2&ED92!!9&1R97-S97-=`%M(:61E(%%U
M;W1E9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO
M=R!!9&1R97-S97,@+0!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=`%M3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP
M:65N='-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T)C8P!?
M0FQA8VML:7-T`%]#3$D`7T-C`%]$871A5')E90!?1&5L971E`%]$96QE=&4@
M4F]W`%]&;VQD97)S`%]'<F]U<',`7TAE;'``7TED96YT:71Y`%]);6%G92!0
M<F]P97)T:65S+BXN`%]);F)O>`!?3&]G(&EN`%],;V<@;W5T`%]-97-S86=E
M(%-O=7)C90!?36]D:69Y($QI;FLN+BX`7TYE=R!-97-S86=E`%]/<'1I;VYS
M`%]097)M:7-S:6]N<P!?4')I;G0`7U!R:6]R:71Y`%]2969R97-H("5S`%]2
M96UO=F4@3&EN:RXN+@!?4F5P;'D`7U-E87)C:`!?4V5N9"!-97-S86=E`%]3
M971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?5&AR96%D`%]4;P!?56YD96QE
M=&4`7U5S97)S`%]6:65W(%1H<F5A9`!?5VAI=&5L:7-T`&%D9')E<W,@8F]O
M:P!A9&1R97-S964@=6YK;F]W;@!A='1A8VAM96YT`&%T=&%C:&UE;G1S+GII
M<`!B>71E<P!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T
M96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@
M;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M`&9R;VT@=&AE("5S("@E<RD@
M870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE
M9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T
M=V%R92!E<G)O<@!K97D`;&EN97-=`&UA:6QB;W@@9FEL90!M:VES;V9S(&5R
M<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;VYE`&YO
M="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;W(`
M<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5C:7!I96YT<UT`
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A
M:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-P
M96QL:6YG(&5R<F]R`'-P96QL:6YG(&5R<F]R<P!S<P!S=&5A9'D`<WES=&5M
M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R
M('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!Y;W5R(&)L86-K;&ES=`!Y
M;W5R('=H:71E;&ES=`!0<F]J96-T+4ED+59E<G-I;VXZ($EM<"`T+C$M8W9S
M"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3(W(#$Y.C4Q*S`R,#`*4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-BTP,BTR-B`Q,CHU.2LP,C`P"DQA<W0M5')A;G-L
M871O<CH@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3X*3&%N9W5A9V4M5&5A
M;3H@1FEN;FES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO
M;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M
M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`@("`@
M("`@($MO<&EO.B``(%9A<W1A86YO='1A:F$Z(``@("`@("`@4.1I=N1Y<SH@
M`"`@("`@3.1H971TY&KD.B``("@E<R!PY&EVY.0@<VET=&5N*0`@*%!I:V%N
MY'!PY&EN("5S*0`@*"5S('#D:7;D<W/D*0`@*'3D;N3D;BD`("AH=6]M96YN
M82D`("AE:6QE;BD`("`@("`@($]T<VEK:V\Z(``@`"``(B5S(B!E:2!O;&4@
M:&%K96UI<W1O`"(E<R(@96D@:V5L<&%A('9A;&EN;F%K<VDN`"(E<R(@96D@
M;VQE(&%S96YN971T=2!(;W)D96X@<F5K:7-T97)I<W/D+@`B)7,B('!U:61E
M;B!K=79A86IA82!E:2!L]GET>6YY="X`(B5S(B!L:7/D='1I:6X@<GEH;>1J
MY')J97-T96QMY.1N+@`B)7,B(&QI<^1T=&EI;B!O:6ME=6MS:6EN+@`B)7,B
M(&5I(&QU;W1U.B`E<RX`3G)O`"4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`
M)2XR9DU"(&OD>71E='1Y("4N,F9-0B!S86QL:71U<W1A("@E+C)F)24I`"5D
M("5S(&IA("5S`"5D('9I97-T:>0`4V%L87-A;F%S:2!V86YH96YT=74@)60@
M<.1I=N1N('#DY'-TY"X`<&]I<W1E='1I:6X@)60@=FEE<W1IY"X`)60@=FEE
M<W1IY"!O;B!R87!O<G1O:71U(&5I+7)O<VMA<&]S=&EN82!JY')J97-T96QM
MY&X@>6QLY'!I9&]L;&4N`"5D('9I97-T:>0@;VX@<F%P;W)T;VET=2!E:2UR
M;W-K87!O<W1I;F$N`"5D('9I97-T:>0@;VX@<F%P;W)T;VET=2!R;W-K87!O
M<W1I;F$@:N1R:F5S=&5L;>1N('EL;.1P:61O;&QE+@`E9"!V:65S=&GD(&]N
M(')A<&]R=&]I='4@<F]S:V%P;W-T:6YA+@!6:65S=&ET("5D("T@)60@*'EH
M=&5E;G/D.B`E9"D`)60@<.1I=N1N(&5N;G5S='5S`"5S("T@26QM;VET=7,`
M)7,@4V]R;65N:N1L:VD`)7,@2T(`)7,@66QLY'!I=&]T;VEM96YP:71E970@
M+2!687)M:7-T=7,`)7,@87-E;FYU<P`E<R!K:7)J875T=6UI;F5N`"5S(&OD
M>71T]F5H9&]T`"5S(&]N(&IO(&]L96UA<W-A+@`E<R!O;B!J;R!O;&5M87-S
M82X@2V%N<VEO=&%S:2`E<R!E:2!N:6UE='1Y('5U9&5L;&5E;BX`)7,@<W5U
M;G1A("5S("5S`"5S(&5I('9A:6MU=&$@;VQE=F%N('!O<W1I:V%N<VEO+@`E
M<R!K86YS:6\@;FEM973DY&X@=75D96QL965N(&MU=6MA=61E;B!A;'5S<V$N
M`"5S(&]N(&AY=N1K<WEN>70N`"5S(&]N('!E<G5U='1A;G5T("(E<R(Z;BX`
M)7,@;VX@:VEE;'3D>71Y;GET+@`E<R!O;B!V87-T86YN=70@=F%P86$O=F%R
M871T=2!P>7EN=/;V;BX`)7,@;VX@=F%S=&%N;G5T(&MU='-U=6X@(B5S(CIS
M=.0N`"5S(&]N(&SD:&5T=.1N>70@<VEN=6QL92!V87!A82]V87)A='1U('1I
M971O:F$N`"5S(&]N(&%L=7-T879A<W1I(&AY=N1K<WET='D`)7,@;VX@=F%L
M;6ES('-U;W)I='1A;6%A;B!Y;&SD<&ET;W1O:6UE;G!I=&5I=.0N(%9A;&ET
M<V4@=F%L:6YT87)U=61U:7-T82!S=6]R:71E='1A=F%T('1O:6UE;G!I=&5E
M="X`)7,@;VX@<&%K;VQL:6YE;@`E<R!M:6YU=71T:6$`)7,@96D@;/9Y='EN
M>70N`"5S('!Y>73DY"!S:6YU;'1A('9A<&%A+W9A<F%T='4@=&EE=&]J82X`
M)7,@<'EY=.3D('-I;G5A(&]L96UA86X@<&%I:V%L;&$@(B5S(CIS<^0N`"5S
M("T@)7,@+R`E<P`E<R!L:7/D='1I:6X@(B5S(CKDY&XN`"5S(&AA;'5A82!M
M=75T=&%A("(E<R(ZY.0N`"5S(&AA;'5A82!I;&UO:71T86$@<VEN=6QL92`B
M)7,B.G-TY"X`)7,@:&%L=6%A('-A861A('5U<VEM;6%T('1I961O="`B)7,B
M.G-TY"X`)7,Z;B!O<V]I=&5K:7)J80`E<SIN(&MA;&5N=&5R:0`E<SIN(&UU
M:7-T:6QI<W1A`"5S.FX@=&5H=.1VY&QI<W1A`"5S.B`E<P`E<SH@)7,@*"5D
M)FYB<W`[+R9N8G-P.R5D*0`E<R`Z(%3D;>0@=FEE<W1I(&5I(&]L92!VY&QT
M=.1MY'1TY"!S:6QTY"!LY&AE='3D:N1L=.0L(&IO:V$@;VX@;65R:VET='D@
M;.1H971TY&KD:W-I+B!3=6AT875D=2!V87)A=6MS96QL82!V:65S=&ES<^0@
M;VQE=FEI;B!L:6YK:V5I:&EN(&IA('9A<F\@86YT86UA<W1A(&SD:&5T=.1J
MY&QL92!M:73DY&X@>6MS:6SV:79IY"!T:65T;VIA+@`H07-E=&$@;75U=&]K
M<V5T('9O:6UA86X@:F$@<VEI<G)Y('-E=7)A879A;&QE('-I=G5L;&4N*0`H
M2'EL:^3D(&MA:6MK:2!M=75T;VMS970@:F$@<VEI<G)Y('9I97-T:6YK:7)J
M;VET=7-S:79U;&QE+BD`*$A434PI`"A096QK:^0@=&5K<W1I*0`H4&%L86$@
M=&%K86ES:6X@=FEE<W1I;FMI<FIO:71U<W-I=G5L;&4@:F$@87-E=&$@=F]I
M;6%A;B!K86EK:VD@=.1HY&X@87-T:2!T96AD>70@;75U=&]K<V5T+B!.>6MY
M:7-E;&QE('-I=G5L;&4@=&5H='EJY"!M=75T;VMS:6$@96D@87-E=&5T82!V
M;VEM86%N+BD`*$SD:&5TY"!V:65S=&D@:W5N(&MA:6MK:2!M=75T;VMS970@
M;VX@87-E=&5T='4@=F]I;6%A;BX@375U=&]K<V5T(&5I=N1T(&[D>2!N>6MY
M:7-E;&SD('-I=G5L;&$N*0`J($QI<^3D(&[D;>0@;F%P<V%U='1A;6%L;&$@
M3TLM<&%I;FEK971T82`J`"H@5F%L:71S92!O<V]I='1E970@*@`L('!U=7-K
M:71T86ES=&$`+"!P=75S:VET=&%I<W1A("5S("5S`"P@=F%I:'1E;&5V86$@
M)7,@+2`E<P`M+2!V86QI='-E("TM`#$@=FEE<W1I(&]N('!O:7-T971T=2X`
M,2!V:65S=&D@;VX@<F%P;W)T;VET=2!E:2UR;W-K87!O<W1I;F$@:N1R:F5S
M=&5L;>1N('EL;.1P:61O;&QE+@`Q('9I97-T:2!O;B!R87!O<G1O:71U(&5I
M+7)O<VMA<&]S=&EN82X`,2!V:65S=&D@;VX@<F%P;W)T;VET=2!R;W-K87!O
M<W1I;F$@:N1R:F5S=&5L;>1N('EL;.1P:61O;&QE+@`Q('9I97-T:2!O;B!R
M87!O<G1O:71U(')O<VMA<&]S=&EN82X`,3`P(&UE<FMK:>0`,3`P,"!M97)K
M:VGD`#$R+71U;FYI;B!JY')J97-T96QMY``R-"UT=6YN:6X@:N1R:F5S=&5L
M;>0`,C0@='5N=&EA`#(U,"!M97)K:VGD`#4P,"!M97)K:VGD`#Q%9&5L;&EN
M96X`5&EE=&]K86YT871A=7-T86KD<FIE<W1E;&WDY"!E:2!O;&4@;>3D<FET
M96QT>2!TY&QL92!O<VEO;&QE`%1A<&%H='5I('9A:V%V82!V:7)H90!4Y&WD
M;B!V:65S=&EI;B!O;B!L:6ET971T>2!S=75R:2!K=79A=&EE9&]S=&\@)7,N
M`$SD:&5T=.1MY'-I('9I97-T:2!A:6AE=71T:2!P86QA=71U<VEL;6]I='5K
M<V5N('9A<W1A86YO='1A:F%L=&$N`%9I97-T:6X@<V%L875K<V5E;B!T87)V
M:71A86X@:G5L:VEN96X@4$=0+6%V86EN+@!!;&QE:VER:F]I=&5T=6X@=FEE
M<W1I;B!T87)K:7-T=6MS965N('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A
M:6XN`%-A;&%T=6X@=FEE<W1I;B!A=F%A;6ES965N('1A<G9I=&%A;B!J=6QK
M:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'4"UA=F%I;B!J82!S86QA<V%N
M871E:W-T:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A;6ES96MS:2!T87)V:71A
M86X@:G5L:VEN96X@4$=0+6%V86EN+"!S86QA:6YE;B!01U`M879A:6X@:F$@
M<V%L87-A;F%T96MS=&DN`%9I97-T:6X@879A86UI<V5E;B!T87)V:71A86X@
M:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA:6YE;B!3+TU)344M879A:6X@
M:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@86QL96MI<FIO:71T86UI<V5K
M<VD@=&%R=FET86%N(&IU;&MI;F5N(%,O34E-12UA=F%I;BP@<V%L86EN96X@
M4R]-24U%+6%V86EN(&IA('-A;&%S86YA=&5K<W1I+@!6:65S=&EN('-A;&%U
M:W-E96X@=&%R=FET86%N(&IU;&MI;F5N(%--24U%+6%V86EN+@!!32!0:6QV
M:>0`04T@:V5V>71TY"!S861E='1A`$%-('-A9&4`04T@<V%T96ET80!!32!L
M=6UI<V%T96ET80!!32]030!*00!!4$D@240`5&EE=&]J82!E9&ET;W)I<W1A
M`%1I971O:F$N+BX`06)S+B!A;&EN`$%B<RX@:V5S:V5L;.0`2'EVY&MS>2!J
M82!L:7/DY"!T87!A:'1U;6$@:V%L96YT97)I:7-I+@!(>7;D:W-Y('!Y>6YT
M]@!(>7;D:W-Y='1Y`$AY=N1K<WET='DZ(`!3:6YU;&QA(&5I(&]L92!O:6ME
M=6MS:6$@;'5O9&$@5D93+6AA:V5M:7-T;V$N`%-I;G5L;&$@96D@;VQE(&]I
M:V5U:W-I82!L=6]D82!61E,M=&EE9&]S=&]A+@!+Y'ET=.1JY'1U;FYU:W-E
M;B!T:65D;W0`2^1Y='3D:N1T=6YN=6MS96X@<V%L87-A;F$`2^1Y='3D:N1T
M:6QI('-U;&IE='1U+@!3Y&AK]G!O<W1I=&EL:6X@;FEM:3H`2VER:F%N<&ET
M;P!4;VEM:6YN;W0`3&ESY.0`3&ESY.0@)7,@;W-O:71E:VER:F%A;FD`3&ES
MY.0@86QI<GEH;>0`3&ESY.0@86QI;VEK975S`$QI<^3D('3D:.1N.@!,:7/D
MY"!U=7-I(')Y:&WD`$QI<^3D('5U<VD@;VEK975S`$QI<^3D(&%L:7)Y:&WD
M(')Y:&WDY&X@(B5S(@!,:7/DY"!A;&EO:6ME=61E="`B)7,B`$QI<^3D('5U
M<VD@:^1Y='3D:N0Z`$QI<^3D('-A<F%K90!,:7/DY"!U=7-I82!JY'-E;FGD
M`$QI<^3D('!A<FD`;&ESY.0@;.1H9&4`3&ESY.0@)7,@=F%L:6MK;R!-;WII
M;&QA;B!3:61E8F%R(&]S:6]O;@!,:7/DY"!TY&WD(&MA;&5N=&5R:6EN:0!,
M:7/DY"!O<V]I=&5K:7)J86%N.@!,:7/DY"!O<V]I=&5K:7)J86%N:3H`3&ES
MY.0@:V%L96YT97)I:6YI`$QI<^3D(&OD>71TY&KD`$QI:71E='1I:6X@(B5S
M(B!L:6ET971I961O<W1O:W-I+@!,:7/D='1I:6X@(B5S(B!JY')J97-T96QM
MY.1N+"!M=71T82!E:2!V;VD@;&ESY'3D('-I<^3D;FMI<FIA=71U;6ES<'EY
M;F[V;B!L:7/D=&EE=&]J83H@)7,N`$QI<^1T=&EI;B`B)7,B(&KD<FIE<W1E
M;&WDY&XN(%9O:70@;GET(&MI<FIA=71U82!S:7/DY&XN`$OD>71TY&II96X@
M;&ESY.1M:6YE;B!O;B!E<W1E='1Y+@!.Y'ET971TY';D="!L:7/D;W1S86MK
M965T.B`\96T^*'9A<&%A96AT;VEN96XL(&QA:71A(&IO:V%I;F5N(&]T<V%K
M92!O;6%L;&4@<FEV:6QL965N*3PO96T^`$QI<^1T:65T;VIA('9O:70@:V%T
M<V]A("5S+@!,:7/D=&EE=&]J96X@>6MS:71Y:7-K;VAD870`5FEE<W1I;B!L
M:7/D=&EE9&]T`%9I97-T:6X@;&ESY'1I971O:F$@=F]I="!K871S;V$@)7,N
M`'9I97-T:6X@=FER:&5I;&UO:71U:W-E;B!Y:W-I='EI<VMO:&1A=`!6:65S
M=&EN('9I<FAE:6QM;VET=6MS96X@=F]I="!K871S;V$@)7,N`$]S;VET90!/
M<V]I=&5K:7)J80!/<V]I=&5K:7)J870`3W-O:71T965T+"!J;W1K82!L:6ET
M973DY&X@<&EI;&]K;W!I;VEN82`H0D-#*2!J;VMA:7-E96X@=FEE<W1I:6XZ
M(#QE;3XH=F%P86%E:'1O:6YE;BP@;&%I=&$@:F]K86EN96X@;W-O:71E(&]M
M86QL92!R:79I;&QE96XI/"]E;3X`3W-O:71T965T(&IO=&MA(&QI:71T>7;D
M="!TY&CD;B!P<F]F:6EL:6EN.B`\96T^*'9A<&%A96AT;VEN96XL(&QA:71A
M(&IO:V%I;F5N(&]S;VET92!O;6%L;&4@<FEV:6QL965N*3PO96T^`%9O:2!A
M<V5T=&%A('1A:2!MY.1R:71E;&SD(&]I:V5U:W-I82!T;VES:6QL92!KY'ET
M=.1J:6QL90!9;&SD<&ET;P!-86EN;VMS970`069G86YI<W1A;@!!;&)A;FEA
M`$%L9V5R:6$`06QI87,`5&%S86$`5&%S875S.@!+86EK:VD`2V%I:VMI(&%U
M=&5N=&EK;VED=70@:^1Y='3D:N1T`$MA:6MK:2!R>6AMY'0`2V%I:VMI(&]I
M:V5U9&5T`$MA:6MI;'1A(&YE;&KD;'3D('-I=G5L=&$`2V%I:VMI('9I97-T
M:70@<V5U<F%A=FES=&$@:V%N<VEO:7-T82!T86QL96YN971A86X@>6AD96MS
M:2!-0D]8+71I961O<W1O:W-I.@!+86EK:VD@:V%N<VEO<W-A("(E<R(@;VQE
M=F%T("5S('#D:7;DY"!V86YH96UM870@=FEE<W1I="!P;VES=&5T86%N(&QO
M<'5L;&ES97-T:2X`2V%I:VMI("5S(&MU=6MA=71T82!V86YH96UM870@;&EN
M:VET971Y="!L:6ET971I961O<W1O="!P;VES=&5T86%N+@!+86EK:VD@)7,@
M:W5U:V%U='1A('9A;FAE;6UA="!LY&AE=&5T='EJ96X@=FEE<W1I96X@:V%N
M<VEO="!P;VES=&5T86%N+@!+86YS:6]S=&$@(B5S(B!P;VES=&5T=&EI;B!K
M86EK:VD@;VEK975D970@:^1Y='3D:N1L=.0@(B5S(BX`4V%L;&ET86%N:V\@
M:V%N<VEO:61E;B!L=6]N=&D_`%-U;V1A='5S<^3D;F[V="!K;W-K979A="!K
M86EK:VEA('!O<W1I;&%A=&EK;VET82X`4V%L;&D@;6]N970@;W-O:71T965T
M`%-A;&QI(&KD<FIE<W1E='EN(&QI<W1A;B!T>7EP:6X@87-E='5S+@!/;B!J
M;R!O;&5M87-S80!686EH=&]E:'1O:6YE;B!)35-0+7-I<^3D;FMI<FIA=71U
M;6EN96X`5F%I:'1O96AT;VEN96X@24U34"US86QA<V%N80!686EH=&]E:'1O
M:6YE;B!)35-0+6OD>71TY&KD='5N;G5S`%9A:6AT;V5H=&]I<V5T('/D:&OV
M<&]S=&EO<V]I='1E970`5F%I:'1O96AT;VES970@;6%L;&ET`%9A:6AT;V5H
M=&]I;F5N('1E:W-T:3H`5F%I:'1O96AT;VES970@;W-A="!TY&QL92!O<VEO
M;&QE.@!!:6YA`%1A;&QE=&$@86EN82!L:6ET971I961O<W1O=`!9:&1Y<W9A
M;'1A:6X@4V%M;V$`5&%P86AT=6D@=FER:&4@<&]I<W1E='1A97-S82!L:6ET
M971I961O<W1O82X@24U!4"UP86QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI
M.B``06YN971T=2!A<G9O(&5I(&ME;'!A82X`=&%P86AT=6D@='5N=&5M871O
M;B!V:7)H92X`575D96X@;75I<W1I:6YP86YO;B!L=6]N;FES<V$@=&%P86AT
M=6D@='5N=&5M871O;B!V:7)H92X`575D96X@=&5H=.1VY&X@;'5O;FYI<W-A
M('1A<&%H='5I('1U;G1E;6%T;VX@=FER:&4N`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYY>6UI('!R;WAY`%9A<W1A=7,`5F%S=&%T='4`5F%S=&%T
M=70@=FEE<W1I=`!!;G1A<FMT:7,`06YT:6=U82!J82!"87)B=61A`$]H:F5L
M;6$`3VAJ96QM86QI<W1A`$]H:F5L;6$@;VX@=F%L;6ES+@!3=6]D871A('9I
M97-T:70`2^1Y=.0@<W5O9&%T=&EM:6$@:V%N<VEO<W-A("5S`%-U;V1A=&$@
M=FEE<W1I="!S:7/DY&YK:7)J875T=6UI<V5N('EH=&5Y9&5S<^0N`%-U;V1A
M=&$@=FEE<W1I="!K=6X@24Y"3U@@<&]S=&EK86YS:6]T82!PY&EV:71E=.3D
M;BX`3&%I=&$@:^1Y='3V]FX@:V%I:VMI(&%L:6IA:V]I:&EN`$AY=N1K<WD`
M07)V:6]I='4@:V]K;P!H=6AT:6MU=0!!<F%B:6$@*%=I;F1O=W,M,3(U-BD`
M4&%K971I;B!K;VMO`%!A:V5T:6X@;FEM:0!/;&5T:V\@=F%R;6$L(&5T=.0@
M:&%L=6%T('!O:7-T86$@=.1MY&X@5FER='5A86QI:V%N<VEO;>3D<FET96QM
MY&X_`$]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82!TY&WD;B!J
M=6QK:7-E;B!A=F%I;65N/P!/;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O
M:7-T86$@;VUA;B!A=F%I;G!A<FES:3\@*$5)('-U;W-I=&5L;&$A*0!/;&5T
M:V\@=F%R;6$L(&5T=.0@:&%L=6%T('1E:&3D('3D;>1N('1O:6UE;G!I=&5E
M;C\`3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!P;VES=&%A('-I<^3D;FMI
M<FIA=71U;6ES<'EY;F[V;B`E<R`_`$]L971K;R!A:79A;B!V87)M82P@971T
MY"!H86QU870@3$]054Q,25-%4U1)('!O:7-T86$@;N1MY"!V:65S=&ET/P!/
M;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T($Q/4%5,3$E315-422!P;VES=&%A
M('3D;>1N(&QI:71E=&EE9&]S=&]N/P!/;&5T:V\@=F%R;6$L(&5T=.0@:&%L
M=6%T('!O:7-T86$@(B5S(B!J82!K86EK:VD@<V5N(&%L:7)Y:&WD=#\`3VQE
M=&MO('9A<FUA+"!E='3D(&AA;'5A="!T>6AJ96YTY.0@=.1MY&X@:V%N<VEO
M;C\`3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!T>6AJ96YTY.0@<F]S:V%P
M;W-T:6MA;G-I;VX_`$]L971K;R!V87)M82P@971TY"!H86QU870@='EH:F5N
M=.3D(')O<VMA:V]R:6MA;G-I;VX_`$]L971K;R!A:79A;B!V87)M82P@971T
MY"!H86QU870@;&]P=6QL:7-E<W1I('!O:7-T86$@;N1MY"!V:65S=&ET/P!/
M;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T(')A<&]R=&]I9&$@=.1MY&X@=FEE
M<W1I;B!V:6%T=&]M86YA/P!/;&5T:V\@=F%R;6$@971TY"!H86QU870@<F%P
M;W)T;VED82!TY&WD;B!V:65S=&EN(')O<VMA<&]S=&EN83\`06=E;G1I:6YA
M`$%R;65N:6$`07)M96YI82`H05)-4T-)22TX*0!386%P=6UI<V%I:V$`5&%I
M9&4`07)U8F$`3F]U<V5V80!!<V-E;G-I;VX@<V%A<F5T`$%S8VEI+71A:61E
M`$%S:6%N+U1Y>6YE;FUE<F5N(&%L=64`2WES>0!+>7-Y('9A<FUI<W1U<R!E
M;FYE;B!K=6EN('1E:&3DY&X@>6QLY'!I=&]T;VEM96YP:71E970N`%1E:'3D
M=N1S87)A:VME970`3&EI=.0@=&EE9&]S=&]T`$QI:73D('9I97-T:6EN(&MO
M<&EO(&IU;&MI<V5S=&$@4$=0+6%V86EM97-T87-I+@!,:6ET971T>2!T:65D
M;W-T;SH`5&EE9&]S=&\@(B5S(B!Y;&ET=.3D(&QI:71E=&EE9&]S=&]J96X@
M<W5U<FEM;6%N('-A;&QI='5N(&MO;VXN(%1I961O<W1O82!%22!L:6ET971T
M>2X`3&EI='1E96[D(&]N('9A<W1A=7,@;.1H971TY&WDY'-I(&MA;&5N=&5R
M:71I971O<'EY;G3V]FXN`$QI:71E`$QI:71E("5S(&]N('!O:7-T971T=2X`
M3&EI='1E96X@=&EE9&]T`$QI:71E('!O:7-T971T=3H@06QK=7!E<N1I<V5N
M(&QI:71E=&EE9&]S=&]N('1Y>7!P:0!,:6ET=&5E=`!9<FET971T:6EN('!O
M:7-T86$@;VQE;6%T;VYT82!R>6AMY.0N`%ER:71E='1I:6X@<&]I<W1A82!O
M;&5M871O;G1A(&]I:V5U='1A+@!9<FET971T:6EN(&UU;VMA=&$@;VQE;6%T
M;VYT82!O:6ME=71T82X`67)I=&5T=&EI;B!M=6]K871A(&]L96UA=&]N=&$@
M:F%K;V$N`$]S86QL:7-T=6IA=`!(=6]M:6\`3&ESY&WDY')I='EK<V5T`&5L
M;VMU=0!!=7-T<F%L:6$`273D=F%L=&$`075T:%]C>7)S<6PZ(%1A<G9I='1A
M=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?8WER=7,Z
M(%1A=7-T86KD<FIE<W1E;&WD(&5I('1U92!T87)V:71T879I82!O;6EN86ES
M=75K<VEA+@!!=71H7V-Y<G5S.B!487)V:71T879A82!)34%0+6QA86IE;FYU
M<W1A(&5I(&SV>71Y;GET+@!!=71H7V9T<#H@=&%R=FET=&%V86$@1E10+6QA
M86IE;FYU<W1A(&5I(&SV>71Y;GET+B!+Y.1N;N0@4$A0(&OD>71TY&5N("TM
M96YA8FQE+69T<"!A<V5T=7-T82X`075T:%]I;6%P.B!487)V:71T879A82!)
M34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7VEM<#H@5&%R=FET
M=&%V86$@24U!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T:%]K<F(U
M.B!487)V:71T879A82!K<F(U+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!
M=71H7VQD87`Z(&OD>71TY&II96X@;&ESY.1M:6YE;B!!8W1I=F4@1&ER96-T
M;W)Y>6X@96D@;VQE('1U971T=0!!=71H7VQD87`Z($OD>71TY&II96X@<&]I
M<W1A;6EE;FX@06-T:79E($1I<F5C=&]R>7-TY"!E:2!O;&4@='5E='1U`$%U
M=&A?;&1A<#H@5&%R=FET=&%V86$@3$1!4"UL86%J96YN=7-T82!E:2!L]GET
M>6YY="X`075T:%]L9&%P.B!%:2!V;VED82!L:7/D=.0@:^1Y='3D:N3D("5S
M+B!086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI.B``075T:%]L9&%P.B!%
M:2!V;VED82!P;VES=&%A(&OD>71TY&KDY"`E<P!!=71H7VQD87`Z($5I('9O
M:61A('#D:7;D='3DY"!KY'ET=.1JY.0@)7,`075T:%]L9&%P.B!+Y'ET=.1J
M:65N('#D:79I='3D;6EN96X@06-T:79E($1I<F5C=&]R>7EN(&5I(&]L92!T
M=65T='4N`$%U=&A?;6-A;#H@5&%R=FET=&%V86$@34-!3"UL86%J96YN=7-T
M82!E:2!L]GET>6YY="X`075T:%]S;6)A=71H.B!487)V:71T879A82!S;6)A
M=71H+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71E;G1I:V]I;G1I($E-
M05`M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!!=71E;G1I:V]I;G1I(&5P
MY&]N;FES='5I`$%U=&5N=&EK;VEN=&D@97#D;VYN:7-T=6DN("5S`$%U=&5N
M=&EK;VEN=&D@4D%$2553+7!A;'9E;&EM96QT82!E<.1O;FYI<W1U:2X`075T
M96YT:6MO:6YT:2!&5%`M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!!=71E
M;G1I:V]I;G1I(%--0BUP86QV96QI;65L;&4@97#D;VYN:7-T=6DN`$[D>73D
M($A434PM=FEE<W1I96X@:W5V870@875T;VUA871T:7-E<W1I+"!J;W,@;.1H
M971TY&KD(&]N(&UA:6YI='1U(&]S;VET96MI<FIA<W-A;FDN`$OD>71E='3D
M=FES<^0@;VQE=F%T(&]S;VET96MI<FIA=#H`2^1Y=&5T=.1V:7-SY&]L979A
M="!K96YTY'0Z`$]D;W1E=&%A;B!V87-T875S=&$`07IE<F)A:7ID86X`0D]&
M2"!S96QI='EK<V5T`%!A;&%A(%]T86MA:7-I;B`E<P!086QA82!T86MA:7-I
M;B`E<P!486MA:7-I;B!U<V5A;B!V:65S=&EN(&AA:V5M:7-T;V[D:WEMY.1N
M`%1A:V%I<VEN(&ME<VMU<W1E;'5SY&EE;N1K>6WDY&X`5&%U<W1A`%1A=7-T
M87;D<FD`5N3D<N0@:V5R8F5R;W,@<V%L87-A;F$N`%;DY'+D(&ME<F)E<F]S
M(&OD>71TY&KD='5N;G5S+@!6Y.1RY"!KY'ET=.1JY'1U;FYU<R!T86D@<V%L
M87-A;F$N`%;DY'+D('1A:2!V:7)H965L;&EN96X@<'EY;G3V+B!086QV96QI
M;65N(&EL;6]I='5S(&]L:3H@)7,`17#D:V5L<&\@<'EY;G3V.B`E<RX`0F%H
M86UA`$)A:')A:6X`0F%L=&EA("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"
M87)B861O<P!'<F%F:6EK;VED96X@<&5R=7-H86ME;6ES=&]A("(E<R(@96D@
M;/9Y='EN>70N`%!E<G5S=FEI=F$`4&EI;&]K;W!I;P!686QK;RU696[D:N0`
M0F5L9VEA`$)E;&EZ90!!;&QA(&]N('1I;&%T:65T;W9I97-T:2!R86%K86UU
M;V1O<W-A+@!"96YI;@!"97)M=61A`$)H=71A;@!3>6YT>6WD<.1I=N0`375S
M=&$@;&ES=&$`3W-I;W1A("(E<R(@;VAJ96QM86QL92`B)7,B(&5I(&SV>71Y
M;GET+@!/<VEO;B!A<V5T=6MS970`3W-I;VX@='EY<'!I`,1LY"!NY'ETY"!(
M5$U,+79I97-T:65N(&MU=FEA+"!E;&QE="!N:6ETY"!E<FEK<V5E;B!P>7ED
MY"X`4VESY&QT]@!,:6AA=F]I='4`0F]L:79I80!+:7)J86YM97)K:70`4F5U
M;F$`4F5U;F%N('9A:'9U=7,Z`%)E=6YA=`!";W-N:6$@2&5R>F5G;W9I;F$`
M36]L96UM870`5FEE<W1I;B!O='-I:VMO(&IA('9I97-T:6X@<VESY&QT]@!"
M;W1S=V%N80!!;&EN`$)O=79E="!S86%R970`0G)A<VEL:6$`0G)I=&%N;FEA
M;B!);G1I86X@=F%L=&%M97)E;B!T97)R:71O<FEO`$)R=6YE:2!$87)U<V%L
M86T`0G5L9V%R:6$`4&%L;'5K:V%L:7-T80!"=7)K:6YA($9A<V\`0G5R=6YD
M:0!#35,`0U)!32U-1#4@=&%I($1)1T535"U-1#4@=F%A=&EV870@971TY"!!
M=71H7U-!4TP@;&%A:F5N;G5S(&]N(&%S96YN971T=2X`0U)#`$-23"UJ86ME
M;'5O<V]I='1E970`4U]O;'5N('1I961O="XN+@!-95]R:VES=/8`5N1L:6UU
M:7-T:6X@86QU<W1U<R!E:2!V86QM:7-T=6YU="X`2V%L96YT97)I`%1Y>6YI
M`$MA;7!U='-E80!+86UE<G5N`$5TY'!O<W1I<&%L=F5L:6UE96X@96D@<V%A
M='4@>6AT97ET=.0N`$5TY'!O<W1I<&%L=F5L:6UE96X@96D@<V%A9&$@>6AT
M97ET=.0Z(`!%:2!V;VD@;N1Y='3DY"`M(%!O<W1I;&%A=&EK;W-S82!O;&D@
M=FEE<W1I<W3D('9A:6X@)7,@;W-I;W1A(&IA('!I=.1I<VD@;VQL82`E<P!3
M86QA<V%N86$@96D@=F]I('1Y:&IE;G3DY"!A=71O;6%A='1I<V5S=&DL(&]T
M82!Y:'1E>71TY"!Y;&SD<&ETY&KDY&XN`$5I('9O:2!K:7)J;VET=&%A('1I
M961O<W1O;VX@(B5S(@!5;&MO:7-I82!I<W1U;G1O:^1S:71T96QI:O9I=.0@
M96D@;VQE(&UA:&1O;&QI<W1A(&AA;&QI=&$N`$E-05`M<&%L=F5L:6UE96X@
M96D@<V%A='4@>6AT97ET=.0Z("5S`$5I('9O:2!A=F%T82!T:65D;W-T;V$@
M(B5S(BX`2V%N861A`%!E<G4`4&5R=2!V:65S=&D`4&5R=2!O;F=E;&UA=FEE
M<W1I`$IO<R!P97)U="!V:65S=&EN+"!N:6EN('9I97-T:6X@<VESY&QT]B!T
M=6AO=71U=2X`16D@=F]I9&$@<&]I<W1A82!T:65D;W-T;V$@(B5S(BX`5N1L
M:6%I:V%I<VAA:V5M:7-T;V$@96D@;/9Y='EN>70N`$5I('9O:61A(&IA=&MA
M82!I;&UA;B`G=&%R9V5T1FEL92<@+7!A<F%M971R:6$N`$5I('9O:61A('!O
M:7-T86$@:&%K96UI<W1O82`B)7,B+@!%:2!V;VED82!P;VES=&%A+"`E9"!A
M;&ET87-O:F$@;VQE;6%S<V$N`$5I('9O:2!U=61E;&QE96YJY')J97-TY.0L
M(&%N;F5T='5J96X@=&EE='5E:61E;B!MY.1RY"!E:2!V87-T86$@=&%L;&5T
M971T=6IE;B!T:65T=65I9&5N(&WDY'+DY"X`16D@=F]I(&]H:F%T82!V:65S
M=&GD(&%N;F5T='5U;B!N=6UE<F]O;BX`2V%P(%9E<F1E`$MU=F%T96MS=&D`
M4&%L=F5L=6YT87)J;V%J80!+871E9V]R:6%T(&IA(&]T<VEK;W0`0V%Y;6%N
M('-A87)E=`!+;W!I;P!0=6AE;&EN*$=332D`4V]L=6X@=&EE9&]T`%-O;'5N
M('3D>71E.@!3;VQU;B!T:65D;W0`4V]L=6X@=N1L>7,Z`$UA=&MA<'5H96QI
M;@!+96QT=&D@*$E33RTX.#4Y+3$T*0!+97-K:71E='1Y`$ME<VMI+4%F<FEK
M86X@=&%S879A;'1A`$ME<VMI+45U<F]O<'!A("A)4T\M.#@U.2TR*0!687)M
M96YT965N('1I961O=`!687)M96YT965N(&]M:7-T86IA`%9A<FUE;G1E96X@
M<&]L:71I:6MA=`!397)T:69I:V%A='1I96X@='5O;G1I(&5I(&]L92!KY'ET
M971TY'9I<W/D+B!4:65D;W-T;VIA(&5I('9O:2!T=6]T82!TY&QL92!P86QV
M96QI;65L;&4N`%1S860`4'5H965N:F]H=&%J80!-=75T80!-=75T82!K86EK
M:VD`375U=&$@:V%N<VEO=&$`5F%I:&1A('-A;&%S86YA<VD`5F]I="!M=75T
M=&%A(&[D:WEMY.1N(&QI:71T>79IY"!A<V5T=6MS:6$@:W5T96X@=FEE<W1I
M96X@;>3D<N3D(&IA(&KD<FIE<W1Y<W3D('-I=G5L;&$N`%9O:70@;75U='1A
M82!P;W-T:7!A;'9E;&EM96X@:^1Y='3V]FX@:F$@:V%N<VEO:6AI;B!L:6ET
M='EV:>0@87-E='5K<VEA+@!6;VET(&UU=71T86$@;.1H971TY&UI<W/D<VD@
M<^1H:_9P;W-T96ES<V$@;N1K>79IY"!N:6UI+2!T86D@;W-O:71E=&EE=&]J
M82X`5F]I="!M=75T=&%A(&SD:&5T=.1M:7-SY'-I('/D:&OV<&]S=&5I<W-A
M(&[D:WEV:>0@;FEM:2T@=&%I(&]S;VET971I971O:F$@:F$@:^1Y='3D;>3D
M<VD@86QL96MI<FIO:71U<W1A+@!386QA<V%N86X@=F%I:'1O(&5I(&]L92!K
MY'ET]G-SY"!N>6MY:7-I;&SD(&%S971U:W-I;&QA+B!/=&$@>6AT97ET=.0@
M>6QLY'!I=.1J:6EN+@!-97)K:VD`3N1Y=&5T=.1V:65N(&UE<FMK:65N(&WD
MY'+D.@!487)K:7-T7V$@;&EN:VMI+BXN`%1A<FMI<W1A(&MA;G-I;VED96X@
M=75D970@<^1H:_9P;W-T:70`5F%L:71S92!?:V%I:VMI+V5I(&UI=.3D;@!6
M86QI='-E(&MA:6MK:2!P;W-T:7!A;'9E;&EM970L(&IO:6QT82!H86QU870@
M:&%K96$@=FEE<W1E:N0Z`%1A<FMI<W1A('9I97-T:6X@;VEK96EN:VER:F]I
M='5S(&5N;F5N(&SD:&5T=.1M:7-TY"X`0VAI;&4`2VEI;F$`2VEI;F$@>6MS
M:6YK97)T86ES=&5T='4@*$=",C,Q,BD`2VEI;F$@<&5R:6YT96EN96X@*$)I
M9S4I`%9A;&ET<V4@=&]I;6EN=&\Z`%9A;&ET<V4@;VAJ96QM80!686QI='-E
M('!O<W1I<&%L=F5L:6XZ`%9A;&ET<V4@=&%I(&UU;VMK86$@;W-O:71T96ET
M82!O:6ME86X@<'5O;&5I<V5S<V$@;&%A=&EK;W-S83H`5F%L:71S92!S86QA
M<V%N80!686QI='-E(&OD>71TY&KD='5N;G5S`%9A;&ET<V4@<.1I=N1MY.1R
M:65N(&5S:71Y<V%S=3H`5F%L:71S92!L:7-T86X@='EY<'!I("AJY')J97-T
M971Y:6QL92!L:7-T;VEL;&4I`%9A;&ET<V4@;W-O:71E:VER:F$L(&IO:&]N
M(&]S;VET=&5E="!L:7/D=.3D;BX`5F%L:71S92!O<V]I='1E:61E;B!L86%J
M96YN=6MS96X@>6AT97ED97-SY"!KY'ET971TY'9I96X@;W-O:71E:VER:F]J
M96X@:&%K=6KD<FIE<W1Y<SH`2F]U;'5S86%R970`3'5O:VMA;>3D<FET>7-T
MY"`E<R!E:2!L]GET>6YY="X`4V5L:V7D`%!O:7-T82!-4T]F9FEC92!T86=I
M=`!0;VES=&$@:WES96QY`%!O:7-T82!KY'ET=.1JY#H@)7,`4&]I<W1A(&OD
M>71TY&KD`%!O:7-T82!KY'ET=.1JY&X@=&EE9&]T`%-E;&ME;F5VY.0@;7GV
M:.3D;@!.87!S875T82`E<R!M=75T=&%A:W-E<VD@:W5V86X@<V5L;&%I<V5E
M;B!M=6]T;V]N+"!J;VYK82!S96QA:6UE<VD@<'ES='EY(&[D>71TY&WDY&XN
M`$YA<'-A=71A("5S('1A;&QE;G1A86MS97-I(&MU=F%N+@!.87!S875T82`E
M<R!M96YNY&MS97-I("5S(&AA;&QI;G1A<VEV=6QL92X`3F%P<V%U=&$@)7,@
M:V%T<V]A:W-E<VD@2%1-3"UM=6]T;VES96X@<VESY&QL]FX@97)I;&QI<V5S
M<^0@:6MK=6YA<W-A+@!.87!S875T82`E<R!K871S;V%K<V5S:2!TY&WD;B!K
M=79A;B!P:6MK=6MU=F%N80!.87!S875T82`E<R!K871S;V%K<V5S:2!L:6ET
M=&5E;B!E<FEL;&ES97-SY"!I:VMU;F%S<V$N`$YA<'-A=71A("5S(&MA='-O
M86MS97-I('3D;>1N(&UU;'1I<&%R="]R96QA=&5D(&]S:6]N(&5R:6QL:7-E
M<W/D(&EK:W5N87-S82X`3F%P<V%U=&$@=.1S=.0@3L195%3$Q$M315-)(&MU
M=F%T`%9A;&ET<V4@96YS:6X@;W-O:71E:VER:F$@:F$@=F%L:71S92!S96X@
M:N1L:V5E;B!N92!K96YTY'0L(&IO:7-T82!T:65T;VIA(&AA971A86XN`$YA
M<'-A=71A(&IA=&MA86MS97-I`$YA<'-A=71A('3D<W3D('1A;&QE='1A86MS
M97-I(&IU;&MI<V5N(%!'4"UA=F%I;65N(&]S;VET96MI<FIA87-I`$YA<'-A
M=71A('3D<W3D('1A;&QE='1A86MS97-I("5S.FX@4R]-24U%+79A<FUE;G1E
M96X@;W-O:71E:VER:F%A<VD`0VQI:V%T96QL($A45%`Z;B!K875T=&$`3F%P
M<V%U='1A;6%L;&$@;W-O:71E='1A('9O:70@:VER:F]I='1A82!U=61E;B!V
M:65S=&EN(&SD:&5T=.1JY&QL92X`3F%P<V%U='1A;6%L;&$@;W-O:71E='1A
M('9O:70@875K86ES=&$@=FEE<W1I;B!L=65T=&%V86MS:2X`4W5L:F4`4W5L
M:F4@:6MK=6YA`%-U;&IE('3D;>0@:6MK=6YA`%-U;&IE='1U(&MA;G-I;P!0
M:6QV:>0`4&EL=FEN96X@86EK86ES:6X`4&EL=FEN96X`2V]O:V]S("A+965L
M:6YG*2!S86%R970`4&EE;F5N;N0`4&EE;F5N;N0@:V%I:VMI`%!I96YE;F[D
M(&MA:6MK:2!K86YS:6]T`%!I96YE;F[D(&MA;G-I;P!0:65N96YNY"!S:79U
M=F%L:6MK;P!0:65N96YN971Y="!R975N870`2V]L=6UB:6$`5N1R:0!6Y')I
M;65R:VEN=.0Z(`!6Y')I=F%L:71S:6X`5N1R:79A;&EN=&$`4V%R86LZ`%-A
M<F%K:V5I9&5N(&]T<VEK;W0`4V%R:F%K=79A=`!+;VUE;G1O`$MO;65N=&]T
M=6QK:VD`2V]M;65N='1I`%EL96EN96X@;FEM:0!+;VUO<FET`%ER:71Y<P!3
M=6]R:71E='1U`$MI<FIO:71A('1O:6YE;B!V:65S=&D`2VER:F]I=&$@=FEE
M<W1I="!E<FEL;&ES97-SY"!I:VMU;F%S<V$N`$]L971U:W-E;F$@:VER:F]I
M=&$@=FEE<W1I="!(5$U,(&OD>71T]FQI:71T>6WD;&SD("A*;W,@<V5L86EM
M97-I('1U:V5E('3D=.0@=&]I;6EN=&]A*2X`5&EE=&]K;VYE970`3VQO<W5H
M9&4`3VQO<W5H=&5E=`!!<V5T=6MS:65N(&5R;W0`07-E='5K<V5T(%!$02UL
M86ET=&5I9&5N+"#D;'EP=6AE;&EM:65N(&IA($]U=&QO;VMI;B!S>6YK<F]N
M;VET:6EN+@!!<V5T=6MS:6$@<&ETY.0@<.1I=FET=.3D+@!!<V5T82!A<V5T
M=6MS970@)7,`5F]I="!MY.1R:71E;&SD(&MU:6YK82!V:65S=&ET(&[D>71E
M=.3D;BX`5F]I="!M=75T=&%A('9I97-T:65N(&5S:6MA='-E;'5U;B!L:6ET
M='EV:>0@87-E='5K<VEA+@!686AV:7-T82!K:7)J;VET=&%M86QL82!S86QA
M<V%N82!U=61E<W1A86X`2V]N9V\`2V]N9V]N(&1E;6]K<F%A='1I;F5N('1A
M<V%V86QT80!9:'1E>7,@24U!4"UP86QV96QI;65E;B!K871K97-I+@!9:'1E
M>7,@97#D;VYN:7-T=6DN`%EH=&5Y<R!E<.1O;FYI<W1U:3H@`%EH=&5Y<R!J
M=6QK:7-T96X@879A:6YT96X@<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!9
M:'1E>7,@:G5L:VES=&5N(&%V86EN=&5N('!A;'9E;&EM96QL92!E<.1O;FYI
M<W1U:2X@5FER:&4Z("5S("@E<RD`66AT97ES(&9T<"UP86QV96QI;65L;&4@
M97#D;VYN:7-T=6DN`%EH=&5Y<R!P86QV96QI;65E;B!E<.1O;FYI<W1U:2X`
M66AT97ES=&EE9&]T`%EH=&5Y<W1I961O="!L:7/D='1I:6X@;W-O:71E:VER
M:F%A<VDN`%1I:79I<W1E='EN('1I961O<W1O;B!T>7EP<&DZ`"(E<R(Z;B!S
M:7/D;'3V`$IA=&MA`%9O:70@;75U='1A82`E<SIN(%!'4"UA<V5T=6MS:6$N
M`%9O:70@;75U='1A82`E<SIN(%,O34E-12UA<V5T=6MS:6$N`%9O:70@87-E
M='1A82!H86MU=6X@;&EI='1Y=FGD(&%S971U:W-I82X`5F]I="!MY.1R:71T
MY.0@;6ET96X@=7-E:6X@=&%R:VES=&5T86%N('5U<VEE;B!V:65S=&EE;B!S
M86%P=6UI;F5N(&IA(&EL;6]I=&5T86%N:V\@<VEN=6QL92!U=7-I<W1A('9I
M97-T96ES=.0N`$UU=71A('1E:W-T:6UU;W1O:7-E="!H>6UI]G0@9W)A869I
M<VEK<VDN`$-O;VL@<V%A<F5T`$5VY'-T90!+;W!I;VD`2V]P:6]I;G1I(&5P
MY&]N;FES='5I.B`E<P!+;W!I;VD@=F%L:6YT80!+;W!I;VD@:V%N<VEO;VX`
M2V]R:F%A`$MO<FIA='1U('1E:W-T:0!#;W-T($E$`$-O<W1A(%)I8V$`3F]R
M<W5N;'5U<F%N;FEK:V\`5FEE<W1I;B!01U`M<V%L875S=&$@96D@=F]I='4@
M=&5H9.0Z(`!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@4$=0+6%L;&5K
M:7)J;VET=7-T83H@`%9I97-T:6X@4R]-24U%+7-A;&%U<W1A(&5I('9O:71U
M('1E:&3D+@!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@4R]-24U%+6%L
M;&5K:7)J;VET=7-T82X`16D@=F]I='4@;W1T86$@>6AT97ET=.0N("5S`$QD
M87`M<&%L=F5L:6UE96X@96D@<V%A='4@875T;W)I<V]I='5A('EH=&5Y='3D
M+@!%:2!V;VET=2!T87)K:7-T86$@<V%L9&]A+B`E<P!0>7EN=/;D(&5I('9O
M:2!S=6]R:71T86$Z(%!A;'9E;&EM96X@:6UO:71U<SH@)7,`3$1!4"UP86QV
M96QI;65E;B!E:2!S86%T=2!Y:'1E>71TY"X`16D@=F]I='4@;W1T86$@>6AT
M97ET=.0@<&%L=F5L:6UE96X@(B5S(B!KY'ET=.1E;B!&5%`Z("5S`$5I('9O
M:71U(&QU;V1A(&IA:V5L=6QI<W1A82X@)7,`16D@=F]I9&$@;'5O9&$@5D93
M+71A=7-T86KD<FIE<W1E;&WDY#H@)7,`4$=0+7-A;&%T='5A('1I971O82!E
M:2!V;VET=2!A=6MA:7-T83H@`%,O34E-12US86QA='1U82!T:65T;V$@96D@
M=F]I='4@875K86ES=&$N`$5I('9O:71U('!O:7-T86$@>6AT97ES=&EE=&]A
M+B`E<P!%:2!V;VET=2!P;VES=&%A(&IA:V5L=6QI<W1A82X@)7,`5FEE<W1E
M:N0@96D@=F]I='4@<&]I<W1A82!K86YS:6]S=&$@)7,N(%!A;'9E;&EM96X@
M=FER:&5I;&UO:71U<R!O;&DZ("5S`$5I('9O:71U('!O:7-T86$@<.1I=FET
M>7-S:W)I<'1IY"`B)7,B+@!6:65S=&EN(&SD:&5T=.1JY&X@<^1H:_9P;W-T
M:6]S;VET971T82!E:2!P>7-T>71T>2!MY.1R:71T96QE;>3D;BX`66QLY'!I
M=&]T;VEM96YP:71E:73D(&5I('9O:71U('-U;W)I='1A82X`5F%L:71T=6$@
M=&EE9&]S=&]A(&5I('9O:71U('!U<FMA82!-4RU43D5&(&QI:71E=&EE9&]S
M=&]S=&$N`%9A;&ET='5A('1I961O<W1O82!E:2!V;VET=2!P=7)K86$@6FEP
M+71I961O<W1O<W1A+@!%:2!V;VET=2!H86ME82!K;VMO(&]S;VET96MI<FIA
M82X`16D@=F]I='4@:&%K96$@:V]K;R!J86ME;'5L:7-T86$N`$5I('9O:71U
M(&AA:V5A(&MO:V\@;&ES=&%A(&IA:V5L=6QI<W1O:7-T82X`16D@=F]I='4@
M;'5K96$@<W1R871E9VEA82`B)7,B+@!+;VUE;G1O(&UK9&ER("(E<R(@97#D
M;VYN:7-T=6DN`$IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L=&$@96D@
M<V%A='4@:G5L:VES=&$@879A:6YT82X`5&EE9&]S=&]O;B`B)7,B(&5I('9O
M:2!K:7)J;VET=&%A+@!%:2!V;VET=2!A=6MA:7-T82`E<RX`66QLY'!I=&]M
M;V1U=6QI;B`E<R!A=6MA:7-U(&5PY&]N;FES='5I`$5I('9O:2!A=6MA:7-T
M82!H86ME;6ES=&]A("(E<R(N`$5I('9O:71U(&UU;V1O<W1A82!S86QA='1U
M82!Y:'1E>71TY"!)34%0+7!A;'9E;&EM96QL92X@)7,Z("5S+@!,1$%0+7!A
M;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L;&ES=&$@971S:>0N`"5S.N3D(&5I
M('9O:71U(&QU:V5A+@!+Y'ET=.1JY&X@<V%L87-A;F%A(&5I('9O:71U(&YO
M;&QA=&$N($IO=&MU="!T87)V:71T879A="!T:65D;W0@;W9A="!VY.1R:6XN
M(%ER:73D('5U9&5S=&%A;B!T86D@;W1A('EH=&5Y='3D('EL;.1P:71O;VX@
M:F]S('1A<G9I='-E="!L:7/DY"!A<'5A+@!%:2!V;VET=2!H86ME82!!0TPM
M=&EE=&]J80!%:2!V;VET=2!H86ME82!O<V]I=&5K:7)J86$N("5S`$5I('9O
M:71U(&AA:V5A(&IA:V5L=6QI<W1A82X@)7,`16D@=F]I='4@:&%K96$@:F%K
M96QU;&ES=&]J82X@)7,`24U!4"UP86QV96QI;65L=&$@96D@=F]I='4@:&%K
M96$@=&EE=&]J82!N:6UI879A<G5U9&5S=&$N`$5I('9O:71U(&AA:V5A('1I
M971O:F$@<&%L=F5L:6UE;B!T;VEM:6YN;VES=&$`16D@=F]I='4@<&%L875T
M=&%A(&%S971U:W-I82X`2V]M96YT;R!R;61I<B`B)7,B(&5PY&]N;FES='5I
M+@!%:2!V;VET=2!T86QL971T86$@)7,@87-E='5K<VEA+@!%:2!V;VET=2!T
M86QL971T86$@87-E='5S=&5N('9A<FUU=7-K;W!I;W1A+@!%:2!V;VET=2!T
M86QL971T86$@87-E='5S=&5N('9A<FUU=7-K;W!I;W1A("5S`$5I('9O:71U
M('1A;&QE='1A82!A<V5T=7-PY&EV:71Y<W-K<FEP=&GD.B`B)7,B+@!%:2!V
M;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU=7-K;W!I;W1A("5S+@!!
M<V5T=7-T:65D;W-T;VX@)7,@=&%L;&5T=7,@97#D;VYN:7-T=6DN(%9O:70@
M:^1Y='3DY"!J;W1A:VEN(&%S971U<W1A('1A;&QE='1A86MS97-I(&MO;V1I
M;B!T86MA:7-I;B`E<R!T86D@=&%I(&MO<&EO:61A(&OD<VEN(&%L;&$@;VQE
M=F%N(&MO;V1I;B!T:65D;W-T;V]N("5S+@!,1$%0+7!A;'9E;&EM96QT82!E
M:2!O;&4@;6%H9&]L;&ES=&$@971S:>0N`$MO;65N=&\@=6YL:6YK("(E<R(@
M97#D;VYN:7-T=6DN`$5I('9O:71U('#D:79I='3DY"!Y:'1E>7-T:65T;VIA
M+B`E<P!%:2!V;VET=2!PY&EV:71TY.0@:F%K96QU;&ES=&%A+B`E<P!6:65S
M=&5JY"!E:2!V;VET=2!P;VES=&%A(&MA;G-I;W-T82`B)7,B.B`E<P!-;WII
M;&QA(%-I9&5B87(@96D@;/9Y='EN>70N(%9A<FUI<W1A(&5T=.0@4VED96)A
M<B!O<VEO(&]N(&%U:VDN`$OD>71TY&KD;&QE("(E<R(@96D@=F]I='4@86YT
M86$@<V5U<F%A=FEA(&]I:V5U<VEA(&MA;G-I;V]N("(E<R(Z("5S`$QA<VME
M='1U('1E:W-T:0!-86$`2W5R<W-I=`!,=6\`3'5O(&MA;G-I;P!,=6\@879A
M:6UE=`!,=6\@=75S:2!SY&AK]G!O<W1I=&EL:0!,=6\@=75S:2!L:6YK:VD`
M3'5O('5U<VD@<F]S:V%P;W-T:6MA;G-I;P!,=6\@=75S:2!L=6]N;F]S:V%N
M<VEO`$QU;R!U=7-I`$QU;R!U=7-I(&SD:&5T971T>6IE;B!V:65S=&EE;B!K
M86YS:6\`3'5O('5U<VD@<F]S:V%K;W)I:V%N<VEO`%9O:70@;'5O9&$@<W5O
M9&%T:6YSY.1N=/9JY"P@:F]I;&QA('9O:70@<VEI<G3DY"!S86%P=79A;B!V
M:65S=&EN(&MA;G-I;VEH:6X@=&%I('!O:7-T86$@<F]S:V%P;W-T96IA+@!,
M=6\@=75S:2!K:7)J97!O:&IA`$QU;R!K:7)J97!O:&II82!J82!V86QM:7-V
M87-T875K<VEA+@!6;VD@;'5O9&$@=75S:6$@:V%N<VEO:71A`$]I:V5U9&5T
M('1E:VEJY&QLY`!,=6]T=&]K;W)T:6YN=6UE<F\`2W)O871I80!+=75B80!4
MY&WD;FAE=&MI;F5N(#0@=F%I:&5T=&$`5.1MY&YH971K:7-E="!I<W1U;FYO
M=`!+96QL;VYA:6MA('3D;&SD(&AE=&ME;&SD`%3D;>1N:&5T:VEN96X@55),
M(&]N`%3D;>1N:&5T:VES970@:^1Y='3D:N1T`%3D;>1N:&5T:VEN96X@<^3D
M`$YY:WEI<V5T(&]I:V5U9&5T(&MA;G-I;V]N("5S`%3D;>1N:&5T:VEN96X@
M=&EL83H@`%3D;>1N:&5T:VEN96X@='EY;&D`5F]I="!M=75T=&%A(&UI=&5N
M('9I97-T96KD(&AA971A86X@=&]I<VEL=&$@<^1H:_9P;W-T:71I;&5I;'3D
M+@!6;VET(&UU;VMA=&$@=FEE<W1I96X@;.1H971TY&UI<V5E;B!L:6ET='EV
M:>0@87-E='5K<VEA+@!6;VET(&UU;VMA=&$@=&5H=.1V:>0L(&IO=&MA('-U
M;W)I=&5T86%N(&MU;B!K:7)J875D=71A86X@<VESY.1N(&]H:F5L;6%A;B`E
M<RX`3&5I:VMA80!,96EK:V%A('9A;&ET='4`2WEP<F]S`$MY<FEL;&EN96X@
M*$M/23@M4BD`2WER:6QL:6YE;B`H5VEN9&]W<RTQ,C4Q*0!+>7)I;&QI;F5N
M+U5K<F%I;F$@*$M/23@M52D`5'-E:VEN('1A<V%V86QT80!04`!$4TX@*&QI
M<^1T:65T;V$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!0Y&EV:71TY&EN`%#D:7;D
M7WES`$1A=&%4<F5E+7-E;&%I;@!4:65T;VMA;G1A:&%K=0!0Y&EVY'ES`%#D
M:7;D;>3D<N0@=F%S=&%A;F]T971T=0!0Y&EVY&WDY'+D;B!V86QI;G1A`%#D
M:7;D`%!O7VES=&$@<V%R86ME`&IO=6QU:W5U`$1E<VEM86%L:6YU;65R;W0`
M2VEE;'3D>71Y:0!+:65L=.1Y='EI.B``4&EE;F5N;N0@<VES96YN>7-TY`!/
M;&5T=7,`3VQE='5S=N1R:0!/;&5T=7-P<F]F:6EL:0!/;&5T=7-H86MU:V5N
M='3D`$]L971U<R!K;VUE;G1O='5L:VMI`$]L971U<VKD<FIE<W1Y<SH`3VQE
M='5S:N1R:F5S='EK<V5N('-U=6YT83H`3>3D<FET96QMY'0`5F%L='5U=&5T
M='4`4&]I<W1A`%!O:7-T82`E<R!J=6QK:6YE;B!A=F%I;@!0;VES=&$@<V]L
M=0!0;VES=&$@;GEK>6ES970@879A:6UE=`!0;VES=&$@:V%N<VEO=`!0;VES
M=&$@<GEH;>0`4&]I<W1A(&QO:VD`4&]I<W1A(&]I:V5U<P!0;VES=&$@=F%L
M:71U="!K86YS:6]T`%!O:7-T82!K:7)J97!O:&IA`%!O:7-T82!V:7)T=6%A
M;&EK86YS:6\`375O:VMA82!V:7)T=6%A;&ES96X@:V%N<VEO;B!MY.1R:71T
M96QYY"`E<P!6;VD@<&]I<W1A82!J82!T=6AO=&$@<&]I<W1E='1U:F$@=FEE
M<W1E:N0`4&]I<W1A('-O;'4`4&]I<W1A('-A<F%K90!0;VES=&$@;VQE;6%S
M<V$@;VQE=F%T('9A:6AT;V5H=&]I;F5N(&UA;&QI`%!O:7-T82!H865T=70@
M=FEE<W1I="!E=.1P;W-T:7!A;'9E;&EM96QT82X`4&]I<W1A(&MA;&5N=&5R
M:7-T86YI`%9O:2!P;VES=&%A('9I97-T96KD`%!O:7-T82!V86YH870@;&EN
M:VET971Y="!L:6ET971I961O<W1O="!K=75K875D96X@86QU<W-A+@!0;VES
M=&$@:W5U:V%U9&5N(&%L=7-S82!V86YH870@;.1H971E='1Y:F5N('9I97-T
M:65N(&MA;G-I;W0N`%!O:7-T82`B)7,B.FX@;VEK975K<VEA`$]L971K;R!V
M87)M82P@971TY"!H86QU870@<&]I<W1A82`B)7,B(&IA(&MA:6MK:2!S96X@
M86QI;VEK975D970_`%!O:7-T82!R:79I`%!O:7-T82!V86QI='1U('!R;V9I
M:6QI`%!O:7-T971U="!R;W-K87!O<W1I=FEE<W1I=`!6;VD@;'5O9&$@=75S
M:6$@:V%N<VEO:71A`%!O:7-T82!V86QI='1U('-A<F%K90!0;VES=&$@=F%L
M:71T=2!R:79I`%!O:7-T971T=0!0;VES=&5T=70@=FEE<W1I=`!0;VES=&5T
M='4@<.1I=FET>7-S:W)I<'1I("(E<R(N`%!O:7-T971T:6EN(&QI:71E=&EE
M9&]S=&\@(B5S(BX`5FEE<W1I96X@<&]I<W1A;6EN96X@:F$@<VEI<G3D;6EN
M96X`5&]I;6ET=7-A:6MA`%1A;G-K80!+:65L;.0@<'EY;G3V`$MI96QLY"!V
M87!A82]V87)A='1U('1I971O:F5N('!Y>6YT]@!,87-K979A`$]N9V5L;6%N
M(&MU=F%U<P!+=79A=7,`5&%R:V5M;6%T('1I961O=`!487)K96UM870@=&EE
M9&]T("AL]GET>7;D="!M>?9S($AO<F1E.FX@;&]K:71I961O<W1O<W1A*3H`
M5&%R:V5M;6%T('1I961O="!O;B!T86QL971E='1U('EL;.1P:61O;B!KY'-I
M=&5L=.1VY&MS:2X`2V5H:71Y<P!+;W-T975S<&ES=&4`161E;&QI<V5N('1U
M;FYI;B!K;W-T975S<&ES=&4Z(`!+;W-T975S<&ES=&4Z(`!4:65D;W-T;V$@
M(B5S(B!E:2!L:6ET971T>2P@:V]S:V$@<V4@;VQI('1Y:&KD+@!(:6UM96YN
MY"!A;&QE:VER:F]I='5K<V5T+@!3=75N=&$@=F%S96UM86QT82!O:6ME86QL
M90!3=75N=&$@;VEK96%L=&$@=F%S96UM86QL90!(86ME;6ES=&\`3N1Y=.0`
M2^1Y=.0@,C0M='5N;FEN(&%I:V%E<VET>7-TY"X`3N1K>6WD;B!A<V5T=6MS
M970`3N1Y=.0@=F%R;6ES='5S(&MU;B!V:65S=&D@;VX@;.1H971E='1Y+@!%
M<VET>7-T87!A('EK<VET>6ES:V]H=&%I;F5N(&5N;G5S=&4`17-I='ES=&%P
M82!E;FYU<W1E96QL92`H5$%&*0!%<VET>7-T87!A`$[D>73D('9I97-T:6X@
M<VESY&QT]@!);&UO:71A('5U<VES=&$@=FEE<W1E:7-TY"!E<FEL;&ES97-S
MY"!I:VMU;F%S<V$N`$[D>73D("<B='EH:F5N;N0@<F]S:V%P;W-T:70B+6QI
M;FMK:2!M=6ED96X@:6MO;FEE;B!J;W5K;W-S82X`3N1Y=.0@(G1Y:&IE;F[D
M(')O<VMA:V]R:2(M;&EN:VMI(&UU:61E;B!I:V]N:65N(&IO=6MO<W-A+@!4
M>7EP<&D`4&5R:6QL96UE;F]I;&UO:71U<P!$:FEB;W5T:0!%22!TY'-MY.0`
MQ&SD('1A<FMI<W1A(&]N:V\@:V%N<VEO;VX@='5L;'5T('5U<VEA('/D:&OV
M<&]S=&EV:65S=&5JY`!%:2!S86$@<&]I<W1A80#$;.0@:^1Y=.0@<W5O<F%A
M;B!M86EN=&5N86YC92YP:'`Z=.0`Q&SD(&UU;V1O<W1A(&QI;FMK96KD($SD
M:&5T=.1JY#H@<V%R86MK965S<V$`2&%L=6%T:V\@879A=&$@:V%N<VEO;C\`
M2F]S(&5N<VEM;>1I;F5N(')I=FD@<VESY&QTY.0@<V%R86MK96ED96X@;W1S
M:6MO="P@;FEI;B!V86QI='-E.@!$;VUI;FEK86%N:6YE;@!$;VUI;FEK86%N
M:6YE;B!T87-A=F%L=&$`4VEN=6QL82!E:2!O;&4@='5N;G5S=&$N($MI<FIA
M=61U(&OD>71TY&KD:W-I+@!686QM:7,`5&%L;&5N;F$`5&%L;&5N;F$@)7,`
M5&%L;&5N;F$@)7,@+GII<"!M=6]D;W-S80!486QL96YN82!K86EK:VD@;&EI
M=&5T:65D;W-T;W0@*"YZ:7`@=&EE9&]S=&]K<VDI`%1A;&QE;FYA(&MA;G-I
M;W0`5&%L;&5N;F$@:V%N<VEO="!;+GII<"!M=6]D;W-S85T`5&%L;&5N;F$@
M;'5O='4@87-E='5S(%!(4"US:W)I<'1I;N0N`%1A;&QE;FYA("YZ:7`@;75O
M9&]S<V$`3'5O;FYO<P!,=6]N;F]S:V%N<VEO.@!,=6]N;F]S:V%N<VEO.@!!
M;&%S=F5T;W9A;&EK:V\`2'5U;65E=`!3Y&AK]G!O<W1I;W-O:71E`%/D:&OV
M<&]S=&EO<V]I=&4`14UA:6PM=&\M4TU3(&=A=&5W87D@86IU<FDL(&YI:6QL
M92!P86QV96QU;G1A<FIO86II;&QE+"!J;W1K82!T87)J;V%V870@=.1TY"!P
M86QV96QU82X`3$]04%4`5DE22$4`5DE22$4Z(%9I97-T:>1S:2!E:2!V;VET
M=2!T;VEM:71T86$@<&5R:6QL92X`16-U861O<@!-=6]K:V%A`$UU;VMK86$@
M;75S=&%A(&QI<W1A80!-=6]K:V%A(&]S:6]T80!-=6]K:V%A('-U;V1A='1I
M;6EA`$UU;VMK86$@<GEH;>3D`$UU;VMK86$@;VEK975T=&$`375O:VMA82!O
M:6ME=6MS:6$`375O:VMA82`G)7,G.FX@;VEK975K<VEA`$UU;VMK86$@:&%K
M=6MY<V5L>>0`375O:VMA82!V:7)T=6%A;&ES=&$@:V%N<VEO=&$`375O:VMA
M82!V:7)T=6%A;&ES96X@:V%N<VEO;B!MY.1R:71T96QYY"`E<P!-=6]K:V%A
M('9A;&MO:7-T82!L:7-T86$`375O:VMA82!A<V5T=6MS:6$Z`$UU;VMK86$@
M(B5S(CIN(&]I:V5U:W-I80!-=6]K:V%A("5S.FX@;VEK975K<VEA`$UU;VMK
M86$@;75S=&%A(&QI<W1A87-I`$UU;VMK86$@<W5O9&%T:6YSY.1N=/9JY'-I
M`$UU;VMK86$@973D<&]S=&EL86%T:6MO:6AI;B!L:6ET='EV:>0@87-E='5K
M<VEA+@!-=6]K:V%A('9A;&MO:7-T82!L:7-T86%S:0!+;W5L=71U<P!%9WEP
M=&D`16P@4V%L=F%D;W(`16QE;65N='1I+BXN`$5M`%/D:&OV<&]S=&D`4^1H
M:_9P;W-T:6]S;VET90!3Y&AK]G!O<W1I;W-O:71T96ED96X@<&ETY.0@;VQL
M82!S86UA="X`4^1H:_9P;W-T:2!V87)M:7-T=6MS96QL80!%;6%I;"UT;RU3
M35,@1V%T97=A>0!(>6UI]G0`5'EH:F5N;F5T=&EI;B!K86EK:VD@=FEE<W1I
M="!K;VAT965S=&$@)7,N`%1Y:&IE;FYE='1I:6X@:V%I:VMI('9I97-T:70@
M=FER='5A86QI<V5S=&$@<F]S:V%K;W)I:V%N<VEO<W1A+@!4>6AJ96YNY"!K
M86YS:6]T`%1Y:&IE;F[D('9A;&ET=70@:V%N<VEO=`!4>6AJ96YNY"!R;W-K
M86MO<FEK86YS:6\`5'EH:F5N;N0@<F]?<VMA<&]S=&D`7U1Y:&IE;F[D(')O
M<VMA:V]R:0!4>6AJY"!V:65S=&DN`%1Y:&KD('9A<W1A=7,N`%1Y:&KD(&AA
M:W5T97)M:0!+Y'ETY"!01U`M=&]I;6EN=&]A+@!+Y'ETY"!3+TU)344M=&]I
M;6EN=&]A+@!386QL:2!K=79I96X@;&%I='1A;6EN96X@:W5V86=A;&QE<FEA
M<W1A('1E:W-T:6X@:F]U:VMO;VXN`$OD>73D('9I97-T:65N(&5S:6MA='-E
M;'5A+@!,86ET82!PY.1L;&4@;VEK96%N('!A:6YI:VME96X@:V]N=&5K<W1I
M;65N=2X`4V%L875?:W-E;B!A<V5T=6MS970`4V%L871T=0!0Y.1T='EY`%;D
M;&ET971T>2!V:65S=&D@<.3D='1Y>0!6:65S=&EN(&QO<'!U`"5S(&SD:&5T
M=.1MY&X@=FEE<W1I;B!L;W!P=2X`4.3D='1Y;6ES=G5O<VD`4W5U<F5N;F$@
M961I=&]R:6$`06YN82!S86QA<V%N871E:W-T:0!!;FYA(&MY<WEM>7,@:F]K
M82!K>7-Y=.3D;BP@:F]S('-A;&%S86YA<VD@:F]U9'5T86%N(&YO;&QA86UA
M86X@97-I;65R:VEK<VD@)VUI:^0@;VX@;&5M;6EK:VES:2!N:6UI/R<Z`$QA
M:71A(&MU=F$@55),('3D:.1N`$%N;F$@:VER:F%I;65T(&%L;&4Z`$%N;F$@
M;FEM:2!U=61E;&QE(')O<VMA<&]S=&EK86YS:6]L;&5S:0!!;FYA(&YI;6D@
M=75D96QL92!L=6]N;F]S:V%N<VEO;&QE<VD`06YN82!N:6UI('5U9&5L;&4@
M;.1H971E='1Y:F5N('9I97-T:65N(&MA;G-I;VQL97-I`$%N;F$@;FEM:2!U
M=61E;&QE(')O<VMA:V]R:6MA;G-I;VQL97-I`$MO:V\@=FEE<W1I`"(E<R(@
M;&ESY'1T:6EN(&]N;FES='5N965S=&D@;W-O:71E:VER:F%A;@!%:W9A=&]R
M:6%A;&EN96X@1W5I;F5A`$5R:71R96$`5FER:&4`5FER:&4@>6AD:7-T971T
MY&5S<^0@24U!4"UP86QV96QI;65L;&4N("5S(#H@)7,N`%9I<FAE('#D:79I
M=&5T=.1E<W/D(&]S:6]T83H@)7,`5FER:&4@<.1I=FET971TY&5S<^0@<WEN
M8R!A;F-H;W(@+71I971O83H@)7,`5FER:&4@<&]I<W1E='1A97-S82!S>6YC
M(&QO:VEA.B`E<P!6:7)H92!H865T=&%E<W-A('-I<^1L=/;D.B`E<RX`5FER
M:&4@;.1H971E='3D97-SY"!V87-T875S=&$Z("5S+@!6:7)H92!PY&EV:71E
M='3D97-SY"!S86QA<V%N86$Z("5S`%9I<FAE('/D:&OV<&]S=&EV:65S=&ES
M<^0N`%9I<FAE(&MI<FIO:71E='1A97-S82`B)7,B+@!%97-T:0!%=&EO<&EA
M`$5T;FEN96X`175R;V]P<&$`5&%P86AT=6UA;B!P;VES=&\@;VYN:7-T=6DN
M`#$U(&UI;G5U=&EN(';D;&5I;@`R(&UI;G5U=&EN(';D;&5I;@`S,"!S96MU
M;FYI;B!VY&QE:6X`-2!M:6YU=71I;B!VY&QE:6X`2F]K86ES96QL82!S:7/D
MY&YK:7)J875T=6UI<V5L;&$`4'5O;&5N('1U;FYI;B!VY&QE:6X`36EN=75T
M:6X@=N1L96EN`$5S:6UE<FMK:6%R=F]T.@!3=6]R:71A`$QA86IE;FYA`$QA
M86IE;FYA(&MA:6MK:0!,86%J96YN82!K86EK:VD@:V%N<VEO=`!,86%J96YN
M82!K86YS:6\`3&%A:F5N;F$@;FEM970`3&%A:F5N;F$@<VEV=79A;&EK:V\`
M3&%A:F5N;F$@;FEM970@875T;VUA871T:7-E<W1I('1A=7-T86QL82!V:65S
M=&EN:VER:F]I='5S:6MK=6YA<W-A+@!,86%J96YN82!O;&5T=6MS96YA(&MO
M:V\@:V%N<VEO<'5U(&MA;G-I;VED96X@:&%L;&EN;F%S<V$N`$QA86IE;FYE
M=&%A;@!/9&]T971T:6EN(&UE<FMK:>0@)RDG`%-A;F$@<V5L;&%I<V5N86%N
M('1A:2!H86MU=&5R;6D@;&%I;F%U<VUE<FME:7-SY`!,;W!P=7#D:7;D;>3D
M<N0`16MS<&]N96YT=&D`1D<@=N1R:0!!<V5T=7-T:65D;W-T;VIE;B!T=6]N
M=&D@1E10.FQLY`!(85]E('9I97-T:70`07-E='5S=&5N(&AA:W4@97#D;VYN
M:7-T=6DN`%EH=&5Y<R!,1$%0+7!A;'9E;&EM965N(&5PY&]N;FES='5I+@!9
M:'1E>7,@4TU"+7!A;'9E;&EM965N(&5PY&]N;FES='5I+@!+;W!I;VEN=&D@
M(B5S(CIL=.0@97#D;VYN:7-T=6DN`$MO<&EO:6YT:2`B)7,B.FQL92!E<.1O
M;FYI<W1U:2X`575D96X@4T%33"UY:'1E>61E;B!L=6]M:6YE;B!E<.1O;FYI
M<W1U:2X`4VEI<G1O("(E<R(ZY.1N(&5PY&]N;FES='5I+@!3:6ER=&\@97#D
M;VYN:7-T=6DZ("5S`$MA=6YI<P!&86QK;&%N9&EN('-A87)E="`H36%L=FEN
M87,I`$;D<B!S86%R970`5F%K879A('9I<FAE.@!&86MS:0!&86MS:70`:&5L
M;6EK=74`5'5N='5U(&MU:6X`5'5N='5U(&MU:6XZ(`!(864@=FEE<W1I=`!(
M864@=FEE<W1I="!E<FEL;&ES97-SY"!I:VMU;F%S<V$N`$AA92!V:65S=&ET
M('-I<^3D;FMI<FIA=71U;6ES96X@>6AT97ED97-SY`!(865T=&EI;B`E9"!V
M:65S=&GD('!A;'9E;&EM96QT82`E<P!(865T=&EI;B`Q('9I97-T:2!P86QV
M96QI;65L=&$@)7,`2&%E('9I97-T:70Z(`!&971C:&UA:6PZ(&5I('5U<VEA
M('9I97-T96KD+@!-=75T86UI82!S871E:71A`$UU=71A;6EA(&QU;6ES871E
M:71A`%-U;U]D871T:6UE=`!+96YT=.1M871R:6ES:0!&:6=L970@0T%05$-(
M00!&:6=L970@:VER:F%S:6X`1FED>FD`5&EE9&]S=&\`5&EE9&]S=&]J96X@
M;'5K=6WDY'+D.B`E<R!T:65D;W-T;P!4:65D;W-T;VIE;B!L=6MU;>3D<N0Z
M("5S('1I961O<W1O80!4:65D;W-T;VIE;B!KY'-I='1E;'D`5&EE9&]S=&]N
M(&YI;6D`5&EE9&]S=&]N('9A;&EN=&$`5&EE9&]S=&]N('1U;VYT:0!4:65D
M;W-T;VIE;B!T=6]N=&D@96D@;VQE(&OD>71E='3D=FES<^0N`%-U;V1A=&EN
M(&%S971U:W-E=`!3=6]D871I;B!A<V5T=6MS970`4W5O9&%T82!V:65S=&D@
M;&]U:VMA879I<W1A('-A;F]I<W1A+@!4Y'-SY"!JY')J97-T96QMY'-SY"!E
M:2!V;VD@:^1Y='3DY"!S=6]D871T:6UI82X`4W5O9&%T=&EM970`4W5O9&%T
M=&EM970@;W9A="!03TE3(%#$Q$Q4Q`!3=6]D871U<SH@)7,@:&%L;&EN=&%S
M:79U`$AA:W4`4W5O;6D`16YS:6UMY&EN96X@<'5O;&ES:V\`4&]S=&EL86%T
M:6MO;B!E;G-I;6WD:6YE;B!S:79U`$5N<VEM;>1I;F5N('-I=G4`16YS:6UM
MY&EN96X@;F5L:N1N;F5S`$MO<FIA82!S=6AD90!+Y.1N;N0@>6UPY')I`$ME
M;&QU=F$`5N1L7VETY`!3=6UU`$MA;G-I;W1A("5S(&5I(&]L92!O;&5M87-S
M82X`2V%N<VEO;VX@;&EI='1Y=N0@=&]I;6EN=&\@+2!687)M:7-T=7,`2V%N
M<VEO:61E;B!H86QL:6YT80!+86YS:6]I9&5N('EH=&5E;G9E=&\`2V%N<VEO
M:61E;B!J86MA;6EN96X@96D@;VQE(&OD>73V<W/D+@!+86YS:6]I=&$@96D@
M=F]I(&OD>71TY.0N`$MI<FIA<VEM96X@=N1R:0!2=6]K80!396QA:6UI;&QE
M+"!J;W1K82!E:7;D="!T=64@:W5V:6$`16YN=7-T92`H5$%&*0!%;FYU<W1E
M='1A=F%T('9U;W)O:V%U9&5T("A(=6]M86%T:&%N(&5T=.0@96YN=7-T=6MS
M97-S82!O;B!T:65D;W0@<V5KY"!PY&EV:7-TY"!E='3D(/9I<W3D+"!J;W1E
M;B!S=75R:2!MY.1RY"!PY&EV:>0@86EH975T=&%A(&QI:6%N(&QE=F7D;B!O
M<VEO;BD`56YO:&1I=&MO('-A;&%S86YA<VD_`$%J86X@97-I='ES=&%P82!N
M:6EL;&4@=FEE<W1E:6QL92P@:F]I<W-A(&]N(&MU;'5V86X@<.1I=N1N('#D
M:7;D;>3D<N0N`$QO;6%K:V5E=`!-:65T96QA=7-E`$UI971E;&%U<V5E;B!T
M>7EP<&D`36EE=&5L875S965T`$UI971E;&%U<V5E="`R`$9O;W)U;6ET`%;D
M;&ETY"!E9&5L;&5E;@!6Y&QI=.0@961E;&QE96XZ`$5D96QL965N=N1L:71E
M='1Y('9I97-T:0!%9&5L;&5E;G;D;&ET971T>2!V:65S=&D@;.1H971TY&KD
M;'3D("5S`%5U9&5L;&5E;F]H:F%U:W-E=`!P90!+96AY:W-E=`!286YS:V$`
M4F%N<VMA+"!-971R;W!O;&D`5F%S=&%U<R!V87!A82]V87)A='1U('!Y>6YT
M]O9N`%)A;G-K86X@1W5Y86YA`%)A;G-K86X@4&]L>6YE<VEA`%)A;G-K86X@
M971E;.1I<V5T('1E<G)I=&]R:6]T`$SD:&5T=.1?:N0`3.1H971TY&KD`$SD
M:&5T=.1JY&X@;W-O:71E`%-U=6YN87-T82``4&ED96UP:2!K=79A=7,Z`%3D
M>7-I:W5U`$MO:V\@;FEM:0!&=V0Z`$9W9#H@`$9W9#H@)74@961E;&QE96YV
MY&QI=&5T='GD('9I97-T:>0`1V%B;VX`1V%L;&5R:6$L(&IO<W1A(&MU=F$@
M;W1E=&%A;@!'86QL97)I83H`1V%M8FEA`%EL96ES970@87-E='5K<V5T`%1E
M92`E<R!A<V5T=6MS970`1V5N97)O:71U(&MO;V1I`$=E;W)G:6$`4V%K<V$`
M2&%E('9A:6X@=75D970@=FEE<W1I="`H=F%I;B!)34%0*0!':&%N80!':6)R
M86QT87(`171U;FEM:0!9;&5I<V5T(&%S971U:W-E=`!-96YE`$UE;F4@=FEE
M<W1I:6X`365N92!O<V]I=&5K:7)J82!M97)K:6YTY.1N("(E<R(`1_9D96P`
M1V]O9VQE($MA<G1A=`!';V]G;&4@:&%K=0!!;FYA(&]I:V5U9&5T`$AA<FUA
M87/D=GD`2W)E:6MK80!+<F5I:VMA("A)4T\M.#@U.2TW*0!'<O9N;&%N=&D`
M1W)E;F%D80!2>6AMY&X@>6QLY'!I=&\`4GEH;6EE;B!N:6UE="!E:7;D="!S
M86$@;VQL82!T>6AJ:>0`1W)O=7!?;&1A<#H@16D@=F]I9&$@;&ESY'3D(&OD
M>71TY&KDY"`E<RX@4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L:3H@`$=R
M;W5P7VQD87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET=.1JY.0@)7,`1W)O
M=7!?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D(&OD>71TY&KDY"`E<P!2>6AM
MY'0`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!6:65R86EL
M:6IA;B!O:6ME=61E=`!6:65R87-K:7)J80!'=6EN96$`1W5I;F5A+4)I<W-A
M=0!'=7EA;F$`5,135,0`2%1-3`!6:65S=&D@2%1-3"UM=6]D;W-S80!(5$U,
M07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!R
M:79I;B!V:6EM96ES=.0@<V]L=6$N`$A434Q!<F5A('!E;&MU<FEM86ES97-T
M:2!K:65L=.1Y='EY('!O:7-T86UA<W1A('9I:6UE:7-TY"!S87)A:V5T=&$@
M=&%U;'5K;W-T82X`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET
M>7D@<&]I<W1A;6%S=&$@=FEI;65I<W3D(')I=FGD('1A=6QU:V]S=&$N`$A4
M5%`M875T96YT:6MO:6YT:6$@96D@;/9Y='EN>70N`$AA:71I`$AA<V@M86QG
M;W)I=&UI`%5S=F$`3W1S86ME`$]T<VEK;W0`2&5A<F0@:F$@36-$;VYA;&0@
M<V%A<F5T`%9O:6UA:V%S('5K:V]S;7ER<VMY`$AE<')E82`H25-/+3@X-3DM
M."U)*0!+;W)K975S`$]H:F4`07!U82!E9&ET;W)I;B!KY'ET=/;V;@!/:&IE
M`%!A;&QO;G!U;VQI<VMO.@!4Y'-SY"!O;B!T:65D;W-T;VX@86QK=6]S83H`
M5.1S<^0@;VX@=FEE<W1I+"!J;W1A(&]L:70@:VER:F]I='1A;6%S<V$Z`%!I
M:6QO=&5T='4`4&EI;&]T971T=2!K97-K=7-T96QU<^1I96[D:WEMY'-SY`!0
M:6EL;W1A('!O:7-T971U=`!0:6EL;W1A('1I;&%A;6%T=&]M870`2V]R:V5A
M`$MO<FME82!P<FEO<FET965T=&D`2V]R:V5I;@!+;U]T:0!0>6CD(&ES='5I
M;B`H5F%T:6MA86YI;B!K875P=6YK:79A;'1I;RD`2V]T:0!+;W1I;W-O:71E
M`$MO=&EH86ME;6ES=&\`4'5H96QI;B`H:V]T:2D`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!%<.1K96QP;V$@)7,@6$U,+61A=&%A
M('9I97-T:7-SY"`E<P!(;W)D92]+;VQA8CH@66MS:6ODY&X@=FEE<W1I(&5I
M('9A<W1A82!O8FIE:W1I82`E<P!(;W)D92]+;VQA8CH@66ATY&ODY&X@;V)J
M96MT:6$@)7,@96D@;/9Y='EN>70@=FEE<W1I<W3D("5S`$AO<F1E+TMO;&%B
M.B!0;VES=&5T=&EI;B`E<R`B)7,B`$AO<F1E+TMO;&%B.B!);G1E9W)A871I
M;VMO;F4@=F%A=&EI('1O:6UI86MS965N("=D;VUX;6PG(%!(4"UL86%J96YN
M=6MS96X`2&]R9&4O2V]L86(Z($5I('9O:61A(&QU;V1A('5U='1A(%A-3"UP
M=75T82!O8FIE:W1I;&QE("5S`$AO<F1E+TMO;&%B.B!%:2!V;VET=2!P;VES
M=&%A("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2!V;VED82!H86ME82!-
M24U%($E$.N0@;W-I;VQL92!T>7EP<&GD("5S`$AO<F1E+TMO;&%B.B!%:2!V
M;VD@<WEK<F]N;VED82`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@16D@=F]I
M9&$@<WEN:W)O;F]I9&$@:F%K;VIA.B`E<P!(;W)D92]+;VQA8CH@5'5N=&5M
M871O;B!J86MO("(E<R(`5F%A:V%S=6]R82!SY.1N=/8`5F%A:V%S=6]R82!T
MY'ET90!686%K87-U;W)A.@!-:71E;B!T=6QI="!TY&YN93\@*%)A<&]R=&]I
M(&MI:71O<R$I`$UI=&5N(&QI:71E=&EE9&]S=&]T(&[D>71E=.3D;C\`2W5I
M;FMA(&UO;G1A('-A<F%K971T82!H86QU870@>6AD:7-TY.0_`$ME;G1T:65N
M("AS87)A:VME:61E;BD@;'5K=6WDY'+D+@!+=6EN:V$@;6]N=&$@<FEV:>0@
M:&%L=6%T('EH9&ES=.3D/P!-:71E;B!V87-T875K<V5E;B!M97)K:73DY&X@
M:V5N96QL92!L86EN871U="!R:79I="!K=75L=79A=`!+;W-T975S`$MO<W1E
M=7,Z(`!(=6UO<FES=&ET`%5N:V%R:0!)34%0`$E-05`@*%1U;FYI<W1A('!R
M;W1O:V]L;&$@875T;VUA871T:7-E<W1I*0!)34%0+7!A;'9E;&EN('-U;&MI
M('EH=&5Y9&5N+B!086QV96QI;65N(&EL;6]I='5S.B`E<P!)34%0+7!O<W1I
M;&%A=&EK;VX@;'5O;G1I(&5PY&]N;FES='5I.B`E<P!)34%0+7!O<W1I;&%A
M=&EK;VX@<&]I<W1O(&5PY&]N;FES='5I.B`E<P!)34%0+7!O<W1I;&%A=&EK
M;VX@:VEI;G1I]FX@;'5O;G1I(&5PY&]N;FES='5I.B`E<P!)34%0(&IA(%-3
M3"US86QA=7,`24U!4"!J82!34TPM<V%L875S("AI='-E(&%L;&5K:7)J;VET
M971T=2!V87)M96YN92D`24U!4"!J82!34TPM<V%L875S("AI='-E(&%L;&5K
M:7)J;VET971T=2!V87)M96YN92D`24U!4"UP86QV96QI;B!S=6QK:2!Y:'1E
M>61E;BX`24U!4"!E:2!43%,M<V%L875S=&$`24U!4"]03U`S('/D:&OV<&]S
M=&EP86QV96QI;65T`$E0+6]S;VET90!)4"UO<V]I=&4@96D@;VQE(&OD>71E
M='3D=FES<^0N`$E0+6]S;VET92!E:2!O;&4@<V%L;&ET=6X@0TE$4BUB;&]K
M:6X@<VESY&QLY`!)4"USY.1N;O9S=/9N(')I:VMO;75S`$Q?86ET82!R:79I
M(&5N;F5N`$ES;&%N=&D`5F%I;B!I:V]N:70`26MO;FET("5S.FQL90!):V]N
M:70@:F$@=&5K<W1I`%!R;V9I:6QI;B!N:6UI.@!*;W,@<VEV=2!E:2!NY'D@
M:W5N;F]L;&$L(&YI:6X@875K86ES92`E<R!E<FEL;&ES97-SY"!I:VMU;F%S
M<V$N`$IO<R!KY'ETY'0@4U-,('1A:2!43%,@<V%L875S=&$L(&YI:6X@<VEN
M=6QL82!P:73DY"!O;&QA(&OD>71E='3D=FES<^0@4$A0.FX@;W!E;G-S;"UL
M86%J96YN=7,N`$IO<R!J871K870L(&YI:6X@:V%I:VMI('9I97-T:70@:V%N
M<VEO:7-S82!T=6AO=71U=F%T(0!*;W,@970@;N1E(&EK;VYE:71A(&OD>71T
MY&5S<^1S:2!);G1E<FYE="!%>'!L;W)E<B!S96QA:6YT82P@;FEI;B!S:6YU
M;B!P:73DY"!O='1A82!P;VES('#DY&QTY"!03D<@;.1P:6[D:WEV>7ES(')A
M<W1I='1A;6%L;&$@=.1MY"!L86%T:6MK;RX`2F]S(&[D970@=.1MY&X@=FEE
M<W1I;BP@;75T=&$@970@:W5V86$L(&YI:6X@='5O;6%A<VD@:W5V86$@96D@
M=F]I(&[D>71TY.0@:^1Y='3D;>1S<^1S:2!S96QA:6UE<W-A+@#$;.0@:'5O
M;6EO:0!*Y'3D(&MA:6MK:2!H=6]M:6]I;6%T=&$`2W5V80!+=79I96X@97-I
M:V%T<V5L=0!+=79A(%523`!+=79A(%523#H`2W5V82!G86QL97)I87-T80!+
M=79A(&=A;&QE<FEA<W1A.@!+=79A;B!V:65N=&D`2W5V870`5'5O`%1U;R!A
M=F%I;@!4=6\@879A:6YP87)I`%1U;R!V:65S=&ET`%1U;R!01U`M879A:6X`
M5'5O(&AE;FMI;/9K;VAT86EN96X@<V5R=&EF:6MA871T:0!4=6\@:&5N:VEL
M]FMO:'1A:6YE;B!S86QA:6YE;B!01U`M879A:6X`5'5O(&AE;FMI;/9K;VAT
M86EN96X@:G5L:VEN96X@4$=0+6%V86EN`%1U;R!H96YK:6SV:V]H=&%I<V5T
M(%,O34E-12US97)T:69I:V%A=&ET`%1U;R!J=6QK:6YE;B!A=F%I;@!4=6\@
M:G5L:VEN96X@4$=0+6%V86EN`%1U;R!J=6QK:6YE;B!3+TU)344M879A:6X`
M5'5O(%,O34E-12UA=F%I;@!4=6\@;6)O>"UT:65D;W-T;P!4=6\@;6)O>"UT
M:65D;W-T;R`E<R!K86YS:6]O;B`E<RX`5'5O;G1I+"!A<VME;"`E9`!4Y')K
M9>0`5.1R:V7D="!V:65S=&ET`%1U;W1I:6X@)60@=FEE<W1IY"!LY&AT965S
M=.0@)7,N`%1U;W1U(&ME;G1TY#H@)7,`5'5O9'5T(&ME;G3D=#H`5&5K96EL
M;.0`3&%?:71A(')I=FD@:N1L:V5E;@!);F)O>`!,:6ETY"!V87-T875K<V5E
M;B!L>6AY="!Y:'1E96YV971O(&]T<V%K971I961O:7-T82X`3&EI=.0@86QK
M=7!E<N1I;F5N('9I97-T:2!V87-T875K<V5E;BX`5N3D<N0@=&]I;6EN=&]K
M;V]D:2!A;FYE='1U+@!+Y'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$@;VX@
M=N3D<FEN+@!6Y.1RY"!KY'ET=.1JY'1U;FYU<R!T86D@=F%I:'1O96AT;VEN
M96X@;W-O:71E+B!9<FETY"!U=61E<W1A86X@:F$@;W1A('EH=&5Y='3D('EL
M;.1P:71O;VX@:F]S('1A<G9I='-E="!L:7/DY"!A<'5A+@!,:7/DY"!S:7-E
M;FYY<W3D`$EN=&EA`%EK<VET=.1I<V5T(&OD>71TY&KD=`!);F1O;F5S:6$`
M26YF;P!);F9O<FUA871I;P!4:65T;V$@96D@;VQE(&5NY.0@<V%A=&%V:6QL
M82X`5&EE=&]J82`E<SIN(&IU;&MI<V5S=&$@879A:6UE<W1A`%1I971O:F$@
M;VUA<W1A('-A;&%I<V5S=&$@879A:6UE<W1A`%1I971O:F$@;VUA<W1A(&IU
M;&MI<V5S=&$@879A:6UE<W1A<VD`5FEE<W1I;B!Y:'1E>61E<W/D`$QA:71A
M('-?87)A:V4@:N1L:V5E;@!,86ET82!S97)T:69I:V%A='1I('3D:.1N`$QA
M:71A(&MU=F$`3&%I=&$@:&5N:VEL]FMO:'1A:6YE;B!S86QA:6YE;B!01U`M
M879A:6X@=.1HY&X`3&%I=&$@:&5N:VEL]FMO:'1A:6YE;B!J=6QK:6YE;B!0
M1U`M879A:6X@=.1HY&X`3&%I=&$@:G5L:VEN96X@4$=0+6%V86EN('3D:.1N
M`$QA:71A('1A=6QU:VMO`$QA:71A('=W=RUL:6YK:VD`3&%I=&$@7W-A<F%K
M92!E;FYE;@!,86ET82!U=7-I('-A<F%K92!N>6MY:7-E;B!JY&QK965N`$QA
M:71A('5U<VD@<V%R86ME(&5N;F5N(&YY:WEI<W3D`$QA:71A('5U<VD@<FEV
M:2!N>6MY:7-E;B!JY&QK965N`$QA:71A('5U<VD@<FEV:2!E;FYE;B!N>6MY
M:7-TY`!,86ET82!K87!P86QE(&YY:WEI<V5N(&YO9&5N(&KD;&ME96X`3&%I
M=&$@:V%P<&%L92!E;FYE;B!N>6MY:7-TY"!N;V1E80!,86ET82!V86EH=&]E
M:'1O:6YE;B!M86QL:0!!;FYA('/D:&OV<&]S=&EO<V]I=&4@:F]H;VX@=75S
M:2!S86QA<V%N82!LY&AE=&5TY.1N.@!,86ET82!S;VQU(&KD;&ME96X`3&%I
M=&$@<V]L=2!E;FYE;@!,86ET82!S;VQU(&KD;&ME96X`3&%I=&$@<V%R86ME
M(&5N;F5N`%9O:2!L86ET=&%A('9I97-T96KD`$QA:71A(&MA<'!A;&4@:N1L
M:V5E;@!,86ET82!K87!P86QE(&5N;F5N`$QA:71A(')I=FD@96YN96X`3&%I
M=&$@<FEV:2!JY&QK965N`$%N;F$@=F%A9&ET=&%V82!V87-T875S('1U<G9A
M:WES>6UY:W-E96XZ`$QI:73D+TUU;VMK86$@:W5V:6$`3&EI=.0O375O:VMA
M82!L:6YK:VGD`%-I;G5L;&$@96D@;VQE('1A<G!E96MS:2!K<F5D:6ET=&5J
MY"!LY&AE='3DY&MS97-I('9I97-T:6X@:F%K96QU;&ES=&%L;&4N`%)I:71T
MY&WD='3V;>1S=&D@:W)E9&EI='1E:N0`2V]K;VYA:7-L=6MU`$MO:V]N86ES
M;'5K=6QI<W1A`%3D;&QE(&MO;7!O;F5N=&EL;&4@;VX@=F%L:71T=2!VY.1R
MY"!T;VEM:6YT;RX`17#D:V5L<&\@;W-O:71E`%9I<FAE96QL:6YE;B!E=.1P
M;W-T:6QA871I:VMO`$5PY&ME;'!O("!51$@@*%5S97(@1&%T82!(96%D97(I
M+@!%<.1K96QP;V$@6DE0+71I971O82X`17#D:V5L<&\@;VAJ96QM82X`17#D
M:V5L<&\@8F%T8V@@240N`$5PY&ME;'!O(&UE<FMK:2!SY&AK]G!O<W1I;W-O
M:71T965S<V$Z("5S+@!,Y&AE=&5T=&EI;B!E<.1K96QP;V$@=&EE=&]A+@!%
M<.1K96QP;R!V87-T86%N;W1T86IA;B!O<V]I=&4N`$5PY&ME;'!O('1I961O
M<W1O;75O=&\`5FER:&5E;&QI;F5N(&%V86EN`$5PY&ME;'!O(&QI<V5N<W-I
M879A:6XN`$5PY&ME;'!O('!A:6MK871I971O+@!%<.1K96QP;R!M<V=?='EP
M92`N`$5PY&ME;'!O('1A:2!P=75T='5V82!A<&E?:60N`$5PY&ME;'!O('1A
M:2!P=75T='5V82!P87)A;65T<FDN`$5PY&ME;'9O="!O:6ME=61E="!Y;&5M
M;>1L;.0@=&%S;VQL82X`17#D:V5L<&\@<&%R;F5R(&ED+@!6:7)H965L;&EN
M96X@:&5N:VEL]FMO:'1A:6YE;B!S86QA:6YE;B!01U`M879A:6XN`%9I<FAE
M96QL:6YE;B!H96YK:6SV:V]H=&%I;F5N(&IU;&MI;F5N(%!'4"UA=F%I;BX`
M17#D:V5L<&\@='5O=&5K;V]D:2X`17#D:V5L<&\@<')O=&]K;VQL82X`17#D
M:V5L<&\@=F%S=&%A;F]T=&%J83H@(B5S(@!%<.1K96QP;R!J86MO+6]B:F5K
M=&D`17#D:V5L<&\@;.1H9&5O<V]I=&4N`$5PY&ME;'!O82!U;FEC;V1E+71I
M971O82X`26YV96YT86%R:6\`2^3D;G1E:6YE;@!+Y.1N;N0@=F%L:6YT82!K
MY.1N=&5I<V5K<VD`27)A;BP@27-L86UI;&%I;F5N('1A<V%V86QT80!)<F%K
M`$ER;&%N=&D`36%N+7-A87)I`$5R:6QL:7-IY"!5:VMO<VUY<G-K>6KD`$ES
M<F%E;`!,:6EK:V5E;&QE;&%S:VEJ80!+=7)S:79O:71U`$ET86QI80!*86UA
M:6MA`'1A;6UI:W5U`$IA<&%N:0!*87!A;FD@*$E33RTR,#(R+4I0*0!*97)S
M97D`2F]R9&%N:6$`:&5I;N1K=74`:V5SY&MU=0!+97-K:73D`$ME<VMI=.0@
M:V5S:V5L;&4`2V5S:VETY"!TY'ES:6X`2V5S:VETY"!V87-E;6UA;&QE`$ME
M<VMI=.0@;VEK96%L;&4`2T(`2V%Z86MS=&%N`%/D:6QY=.0@86QK=7!E<N1I
M;F5N/P!+96YI80!!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I($ME<F)E<F]S
M+7!A;'9E;&EM96QL92X`2V5R;F5L(&%L;VET=&5L:6IA=`!!=F%I;65N(&QU
M;VYT:0!!=F%I;65N('1U;FYI<W1E`$%V86EM96X@<&ET=75S`$%V86EM96X@
M='EY<'!I`$%V86EM96X@:^1Y='3V`$%V86EN(&]N(&IO(&IU;&MI<W1E;B!A
M=F%I;G1E;B!P86QV96QI;65L;&$`079A:6UE;B!L=6]N=&D@=F]I('9I963D
M('!I=&OD;B!A:F%N+B!*871K971A86YK;R!A=F%I;65N(&QU;VYT:6$_`$%V
M86EM:65N('1U;VYT:2!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X@5.1L;&4@<&%L
M=F5L:6UE;&QE(&5I('9O:2!T=6]D82!T:65D;W-T;VIA+@!!=F%I;6EE;B!T
M=6]N=&D@96D@;VQE(&OD>71E='3D=FES<^0N(%-I;G5L;&$@96D@;VQE(&]S
M;VET96MI<FIA82!MY.1R:71E;'1Y;N0@>6AT97ES=&EE9&]I<W-A+@!!=F%I
M;65N(&SD:&5T>7,@;VYN:7-T=6D@:G5L:VES96QL92!A=F%I;G!A;'9E;&EM
M96QL92X`3&%P<V5T`$MI<FEB871I`$MO<F5A+"!D96UO:W)A871T:6YE;B!K
M86YS86YT87-A=F%L=&$@*%!O:&IO:7,M2V]R96$I`$MO<F5A+"!T87-A=F%L
M=&$@*$5T96SD+4MO<F5A*0!+;W)E82`H155#+4M2*0!+=7=A:70`2VER9VES
M=&%N`$%S7V5T=&5L=0!+:65L:0!,86]S+"!D96UO:W)A871T:6YE;B!K86YS
M86YT87-A=F%L=&$`2N1L:VEM;>1I;F5N('!U;VQI<VMO`%!O<W1I;&%A=&EK
M;VX@=FEI;65I;F5N('-I=G4`5FEI;65I;F5N('-I=G4`161E;&QI;F5N('-A
M;&%S86YA;G9A:6AT;P!*Y&QK:6UMY&EN96X@;F5L:N1N;F5S`%#D:79I=&5T
M='D@=FEI;65K<VDZ`$5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI;F5N.B`E
M<P!%9&5L;&EN96X@<VESY.1N:VER:F%U='5M:6YE;CH@)7,L("5S`$5D96QL
M:6YE;B!S:7/DY&YK:7)J875T=6UI;F5N.B!%:2!M:6QL;VEN:V%A;@!,871V
M:6$`3&%K:0!!<V5T=&5L=0!*Y'3D('1Y:&KD:W-I(&IO<R!E:2!R975N;VIA
M`$QI8F%N;VX`5F%S96X`5F%S96X@;W1S86ME`%9A<V5N(&%R=F]T`$QE<V]T
M;P!487-O`$QI8F5R:6$`3&EB>6$@07)A8B!*86UA:&ER:7EA`$QI8VAT96YS
M=&%I;@!+979Y='3D('+D;G3DY`!+:7)J875D=2!S:7/DY&X`2V5V>71TY"!S
M861E='1A(&%I:V%I<VEN`$ME=GET=.0@<V%D971T82!M>?9H96UM:6X`2V5V
M>6ETY"!S861E:W5U<F]J80!+979Y='3D('-A9&5T=&$@:F$@;7ER<VMY:7-T
MY`!+979Y='3D(&QU;6ES861E='1A`$ME=GEI=.0@;'5M:6MU=7)O:F$`3&EM
M97)I:VET`$QI;FMK:0!,:6YK:73D(&QI:71E=&EE9&]S=&]T+@!,:6YK:VD@
M;W-O:71T86$Z`$QI;FMI=.0@<^1H:_9P;W-T:6]S;VET92!K:7)J;VET82!U
M=7-I('9I97-T:2!S:79U;&QE(&[D:WEMY'-SY`!,:6YK:71E='ET(&QI:71E
M=&EE9&]S=&]T(&]N(&MI96QL971T>2X`3&EN:VET`$QI;FMI="!V86YH96YT
M=79A="`E<P!,:6YU>"!P:7!A<F5I=&$`5F]I(&QI<W1A=6MS97-S82!NY&AD
MY"!K86YS:6]N`$[D>73D('1I971O:V%N;F%T`$[D>73D(&]H:F5I9&5N(&%I
M:&5E=`!.Y'ETY"!T875L=70`3N1Y=.0@:V%I:VMI('EH=&5Y<W1I961O="!Y
M:'1E>7-T:65D;W0M;N1K>6WD<W/D("A*;W,@=.1MY"!A<V5T=7,@;VX@<&]I
M<R!PY.1L=.0L(&YI:6X@;N1Y=&5TY.1N('9A:6X@:&%E='5T('EH=&5Y<W1I
M961O="D`3&ES=&%N+4%R:VES=&\`3&ES=&%N+4]H:F4`3&ES=&%N+4ED`$QI
M<W1A;BU/;6ES=&%J80!,:7-T82UV:65S=&D`3&ES=&%N+51I;&%U<P!,:7-T
M86XM5&EL875K<V5N+6QO<&5T=&%M:6YE;@!/='-I:VMO=&EE=&]J96X@='5L
M;W-T=7,`27-T=6YT;VIE;B!L:7-T875S(&5PY&]N;FES='5I.B`E<P!+Y'ET
M=.1J:65N(&QI<W1A=7,@97#D;VYN:7-T=6DZ("5S`$OD>71TY&KD=&EE=&]J
M96X@;N1Y='3D;6EN96X@;VX@97-T971T>2X`2VER:F%L;&ES=75S`$QI971T
M=6$`3&%D871A86XN+BX`4&%I:V%L;&EN96X@<&]S=&EK86YS:6\Z`%!A:6MA
M;&QI<W1A(&%I:V%A.B``3&]K86QI<V%A=&EO(&IA(&%I:V$`4&%I:VMA`$MI
M<FIA=61U('-I<^3D;@!+:7)J875D=2!S:7/DY&X@;VAJ96QM86%N("5S`$5D
M96QL:7-E;B!S>6YK<F]N;VEN=&ES97-S:6]N(&QO:VD`2VER:F%U9'4@=6QO
M<P!+:7)J875D=2!S:7/DY&X`5&5H=.1VY'0@<VESY.1N:VER:F%U='5M:7-E
M<W-A`%-I<^3D;FMI<FIA=71U;6ES97-I(&5PY&]N;FES='5I+B!4;V1E;F[D
M:_9I<V5S=&D@:VER:F]I=&ET(';DY')I;B!KY'ET=.1JY'1U;FYU:W-E<VD@
M=&%I('-A;&%S86YA<VDN`%-I<^3D;FMI<FIA=71U;6EN96X@97#D;VYN:7-T
M=6DN`%!I=&OD('1E:W-T:0!286MK875S`$UA=&%L80!!;&AA:6YE;B!P<FEO
M<FET965T=&D`4&EE;F5T(&MR96EK:V%L86ES970@:VER:F%I;65T`%!I96YE
M="!L871I;F%L86ES970@:VER:F%I;65T`%!I96YE="!R;V]M86QA:7-E="!N
M=6UE<F]T`$%L:&%I<VEN`$QU>&5M8G5R9P!+2P!-3U1$`$U3+51.148@;&EI
M=&5T:65D;W-T;R!O;&D@='EH:N0N`%9)15-420!-86-A;P!-86ME9&]N:6$L
M($5N=&EN96X@2G5G;W-L879I86X@=&%S879A;&QA;BX`36%C:6YT;W-H('1I
M961O<W1O`$UA9&%G87-K87(`5&%I:W5U<P!3Y&AK]G!O<W1I`%!O<W1I;B!Y
M;&SD<&ET;P!6:65S=&EE;B!E<VEK871S96QU`%!O<W1I<&%L=F5L:6UE;B!T
M>7EP<&DL(&IO:&]N(&]T971A86X@>6AT97ET=.0Z`$MA;G-I;P!0;W-T:6MA
M;G-I;RT@:F$@:V%N<VEO;N1K>6WD;B!A<V5T=6MS970`5&5E(&QI;FM?:VDN
M+BX`36%L87=I`$UA;&5S:6$`36%L961I:79I=`!0;W-T:0!-86QT80!6;VET
M(&AA;&QI;FYO:61A(&QI<W1A82!K871E9V]R:6]I<W1A+"!J;VED96X@879U
M;&QA('9O:70@;&EI='3DY"!A<VEO:71A('EH=&5E;B!S86UO:F5N(&]T<V%K
M:V5I9&5N(&%L;&4@:F$@;&EI='3DY"!N:6EH:6X@=N1R96KD+@!-87`R-"!K
M87)T=&$`36%P475E<W0@:V%R='1A`%9A<W1A879U=61E="!T86QL971E='1U
M+@!M86%L:7-K=74`36%R9VEN86%L:0!-97)K:71S92!K86EK:VD@=FEE<W1I
M="!K86YS:6]S<V$@=F%N:&]I:W-I`$UE<FMI='-E(&MA:6MK:2!V:65S=&ET
M(&MA;G-I;W-S82!U=7-I:W-I`$UE<FMI='-E.@!-97)K:71S92!E<FD@;&%I
M;F%U:W-E="!E<FD@=N1R96EL;.0N`$UE<FMI='-E('9I97-T:70@=F%N:&]I
M:W-I/R`H=F%I;B!)34%0*0!-97)K:71S92!Y:W-I;FME<G1A:7-E;&QA(&UE
M<FMI;F[D;&SD+@!6;VD@;65R:VETY"!686YH82]5=7-I('1I971O:F$`5F]I
M(&UE<FMI=.0@=FEE<W1E:N0@*&5S:6TN(%3D<FMEY"]687-T871T=2D`36%R
M<VAA;&P@<V%A<F5T`$UA<G1I;FEQ=64`5.1S;>3D=N1T(&MA:6MK:2!H86MU
M96AD;W0`4V]P:79A="!J;VEH:6YK:6X@:&%K=65H=&]I:&EN`%3D<VWDY';D
M="!K96YTY'0`36%U<FET86YI80!-875R:71I=7,`4W5U<FEN('-A;&QI='1Y
M(&MR961I:71T:2X`4W5U<FEN('-A;&QI='1U('9I97-T:6]S:6]MY.1RY"!Y
M;&ET971T>2X`161E;&QI<V5N(#(T('1U;FYI;B!K;W)K96EN(&SD;7#V=&EL
M83H@`$5D96QL:7-E;B`V('1U;FYI;B!K;W)K96EN(&SD;7#V=&EL83H@`$QI
M:71E=&EE9&]S=&]N('-U=7)I;B!S86QL:71T=2!K;VMO`$MA;G-I;VED96X@
M96YI;6WD:7-MY.1RY`!0;W)T86%L:6]S:6]I9&5N(&5N:6UMY&ES;>3D<N0`
M4W5U<FEN('-A;&QI='1U('!I='5U<P!,:6ET971I961O<W1O:F$@;VX@<W5U
M<FEN('-A;&QI='1U(&WDY'+D+@!,:6ET971I961O<W1O:F5N('EH=&5E;FQA
M<VME='1U(&MO:V\@;VX@<W5U<FEN('-A;&QI='1U+@!T;W5K;VMU=0!-87EO
M;F5T=&4`3.3D:V5T:65D90!*Y'-E;F5T`%9A;&EK:V\@:V%N<VEO;&ES=&$`
M365N=6X@;75O=&\Z`%EH9&ES=.0@<V]L=70`5FEE<W1I`%9I97-T:6X@:VER
M:F]I='5S`%9I97-T:6X@<.1I=N1Y<P!6:65S=&EA<V5T=6MS970`2&%K=2!V
M:65S=&ES=.0`5FEE<W1I;B!K;VMO`%9I97-T:2!R86%K86UU;V1O<W-A`%9I
M97-T:6X@=&%R:VES='5S(&]N;FES='5I+"!M=71T82!A;&QE:VER:F]I='1A
M:F%N('9A<FUE;FYE='1A(&5I('9O:71U('1A<FMI<W1A82X`5FEE<W1I;B!L
M=6MU`%9I97-T:2!V86YH96YI+@!6:65S=&EN('1I;&%T:65D;W0`5FEE<W1I
M:V%N<VEO=`!6:65S=&D@;.1H971TY&KD;'3D("5S`%9I97-T:7-SY"!O;B!L
M:6ET=&5I=.0`5FEE<W1I(&]N('-A;&%T='4`5FEE<W1I;B!O;B!A;&QE:VER
M:F]I=&5T='4`5FEE<W1I('3D<VWDY`!6:65S=&EN(&]H:F%U<R!O;FYI<W1U
M:2X`5FEE<W1I;B!LY&AE='ES(&]N;FES='5I+"!M=71T82!S:73D(&5I('1A
M;&QE=&5T='4@:V%N<VEO;VX@)7,`5FEE<W1I;B!LY&AE='ES(&]N;FES='5I
M+@!6:65S=&EN('1Y>7!P:0!6:65S=&EE;B!L=6MU;>3D<N0@<&]S=&EK86YS
M:6]NY&MY;>1S<^0N`%9I97-T:70@:V%N<VEO;VX`365T87(@<^3D`$UE=&%R
M+6]S:6\@96D@;VQE(&OD>71E='3D=FES<^0N`$UE=&%R+6]S:6\@96D@;VQE
M(&OD>71E='3D=FES<^0N(%1A<FME;6UA="!T:65D;W0@;VX@=&%L;&5T971T
M=2!Y;&SD<&ED;VX@:^1S:71E;'3D=N1K<VDN`$UE=&%R1$(@96D@;VQE('EH
M9&ES=&5T='DN`$UE=&]D:0!-971O9&EA("(E<R(@96D@;VQE(&WDY')I=&5L
M='D`365T;V1I82!E:2!O;&4@;>3D<FET96QT>2X@2W5T<W5V82!M971O9&DZ
M("5S`$UE=')I;F5N`$UE:W-I:V\`36EK<F]N97-I82P@66AD:7-T>6YE970@
M=F%L=&EO=`!+97-K96QLY`!-:6UE+71Y>7!P:0!%9&5L;&ES96X@,C0@='5N
M;FEN(&UA=&%L:6X@;.1M</9T:6QA.B``161E;&QI<V5N(#8@='5N;FEN(&UA
M=&%L:6X@;.1M</9T:6QA.B``4V%L87-A;F$@96D@;VQE('9I96SD('1A<G!E
M96MS:2!V86YH80!096EL:6MU=F$`4V5K86QA:7-E=`!014%2+7!A:V5T=&D@
M2%144%]297%U97-T('!U=71T=74N`%!U=71T=79A="!A<V5T=7-T:65D;W-T
M;RX@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5S=&EE9&]S=&\@:F]S(&AA;'5A
M="!KY'ET=.3D('3D=.0@;VAJ96QM86$N`%!U=71T=79A(&UE<W-A9V4@240N
M`%;D;'1TY&WD=/9N(%!%05(M<&%K971T:2!-86EL('!U=71T=74N`%!U=71T
M=79A('-E<W-I;VX@240N`&UA`$UO8FEI;&ESY&AK]G!O<W1I`$MO:'1A;&%I
M;F5N`$UU;VMK875K<V5N('#D:7;D;>3D<N0`375U=&$`375O:VMA82!54DPZ
M:6$`2V5R<F]I;@!-;VQD;W9A+"!T87-A=F%L=&$`36]N86-O`$UO;F=O;&EA
M`&MU=6MA=7-I(&IA('9U;W-I`$MU=6MA=7-I='1A:6X`36]N='-E<G)A=`!+
M=75N('9A:6AE970`4FEV:6QTY"`E9"!L]GET>6D@96YE;6WD;B!K96YT=&GD
M(&MU:6X@;V1O=&5T='4@)60N`$QA86IE;FYE='1A=F%L;&4@:V5N=.1L;&4@
M(B5S(B!L]GET>6D@=7-E86UP:2!K=6EN('EK<VD@=F%I:'1O96AT;RX`36%R
M;VMK;P!%;FEM;>1K<VD@<V5L:V7DY`!%;FEM;>1K<VD@<&EL=FES=.0`16YI
M;6WD:W-E96X@<&EL=FES=.0@:F$@='5U;&ES=&$`16YI;6WD:W-E96X@875R
M:6YK;VES=&$`4VEI<G+D`%-I:7)RY"!A;&%S<.1I;@!3:6ER<N0@=F%S96UM
M86QL90!3:6ER<N0@;VEK96%L;&4`4VEI<G+D('EL]G-PY&EN`%-I:7)RY"!A
M;&%S<.1I;@!3:6ER<N0@<F]S:V%P;W-T:79I97-T:70@<F]S:V%P;W-T:6MA
M;G-I;V]N(&IA(&5I(')O<VMA<&]S=&EV:65S=&ET($E.0D]8(&MA;G-I;V]N
M`%-I:7)RY"!K86YS:6]O;@!3:6ER<N0@>6SV<W#D:6X`36]S86UB:6L`36]N
M:71A<V]I;F5N(&%L87-V971O=F%L:6MK;P!-=6QT:6UA<"!)<V\M0G)I=&%N
M;FEA;B!K87)T=&$`375L=&EP87)T+V%L=&5R;F%T:79E`$UO;FEV:65S=&EN
MY&MY;>0`36]N:79A;&EN=&$`2^1Y='3D:N1T=6YN=6MS96YI`$]M86X@:^1Y
M='3D:N1T=6YN=6MS96X@=&EE9&]T`$]M82!P;W)T86%L:0!/;6%N('!O<G1A
M86QI;B!A<V5T=&5L=0!->6%N;6%R("A"=7)M82D`14DL($5.('-U;W-T=0!%
M22!-253$Q$X`2%5/34%!`$YI;6D`3FEM:2!T86D@<^1H:_9P;W-T:6]S;VET
M92!E:2!S86$@;VQL82!T>6AJY`!.86UI8FEA`$YA=7)U`%9A871I:2!T;VEM
M96YP:61E='3D`$YE<&%L`$%L86YK;VUA870`06QA;FMO;6%I9&5N($%N=&EL
M;&ET`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,+7!A;'9E
M;&EM96X@;W-O:71E`$YE='-C87!E('9A<FUE;G1E96X@:V]M;65N='1I`$YE
M='-C87!E('9A<FUE;G1E96X@='EY<'!I`%9E<FMK;P!%:2!K;W-K86%N`,1L
MY"!T86QL971A(&QI:71E=&EE9&]S=&]J80!5=7-I`%5U<VDM2V%L961O;FEA
M`%5U<VD@;'5O:VET=7,`575S:2!K86YS:6\`5'5L979A="!V:65S=&ET`%5U
M<VD@=FEE<W1I`%5U<VD@=FEE<W1I("5S.FQL90!5=7-I:W5U`%5U<VD@:^1Y
M='3D:N1T=6YN=7,@*'9A<&%A96AT;VEN96XI`%5U<VDM4V5E;&%N=&D`575D
M970@=FEE<W1I=`!5=7-I('-A;&%S86YA`%5U<VD@<V%L87-A;F$@=F%N:&5N
M964@)7@N`$%N=&%M87-I('5U9&5T('-A;&%S86YA="!E:7;D="!TY'-MY.0N
M`%5U<VD@:6MK=6YA("A?8FQA;FLI`%5U=&ES970`2V5S:W5S=&5L=7)Y:&WD
M=`!3975R86%V80!3975R86%V870@-"!V86EH971T80!3975R86%V82!V:65S
M=&D`4V5U<F%A=F$@<VEV=0!3975R86%V870@87-E='5K<V5T`%-E=7)A879A
M/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!9]@!.:75E`$5I`%9A<FUE;FYE
M='1A(&5I(&SV>71Y;GET`$5I('-A;&%U<W1A`$5I(&%I;G5T=&%K86%N(&%V
M86EN=&$@879A:6YR96YK86%S<V$`16D@=FEE<W1E:N0`16D@='5O='4@86EN
M=71T86MA86X@:G5L:VES=&$@4$=0+6%V86EN=&$N`$AE;FMI;/9K;VAT86ES
M=&$@=F%R;65N;F5T=&$@96D@;VQE('-A871A=FEL;&$`16D@97-I:V%T<V5L
M=6$`2G5L:VES:6$@879A:6UI82!E:2!L]GET>6YY=`!%:2!T=6]T=2!A:6YU
M='1A:V%A;B!J=6QK:7-T82!3+TU)344M879A:6YT82X`3&EI=&5T:65D;W-T
M;VIA(&5I(&SV>71Y;GET+@!!<V5T=7-T:65T;VIA(&5I(&]L92!S86%T879I
M;&QA+"!J;W-T82!V;VES:2!NY'ET=.3D(&5R;V%V86ES=75K<VEA+@!%:2!O
M;&4@<V%A=&%V:6QL82!S=75N;FET96QM86$@25-/(&QE=GEK=79A=&EE9&]S
M=&]J96X@=&5K96UI<V5K<VDN`$5I(&5RY&UA;&QI82X`3W-I;W1A(&5I(&]L
M92!P>7ED971Y<W/D('!A:6MA<W-A+@!+86QE;G1E<FEN(&YI;67D(&5I(&]L
M92!A;FYE='1U($U#04PM875T96YT:6MO:6YN:6QL92X`16D@;75U=&]S=&$N
M`$%L:71A<V]J82!E:2!V;VD@;&ESY'3D('3D;&QE(&]I:V5U9&5L;&4N`$%S
M971U:W-I82!E:2!L]GET>6YY="`E<SIL;&4N`$%S971U:W-I82!E:2!L]GET
M>6YY="!&5%`@5D93.FQL92X`07-E='5K<VEA(&5I(&SV>71Y;GET(%-13"!6
M1E,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@4U%,+49I;&4@5D93.FQL
M92X`2W)E9&EI=&ET(&QO<'!U+@!+;VAD971T82!E:2!A;FYE='1U+@!3Y&AK
M]G!O<W1I=&EE=&]J82!E:2!O;&QU="!J=6QK:7-E<W-A(&%V86EM97-S82X`
M16D@='5O='4@86EN=71T86MA86X@=&EE9&]S=&]A`$5I(&MA;G-I;VET82!V
M86QI='1U;F$N`%EH9&5S=.1KY.1N(&MA;G-I;VES=&$@96D@=&%R:V%S=&5T
M82!U=7-I82!V:65S=&5JY"X`16D@:V%N<VEO:71A(&WDY')I=&5T='ENY`!9
M:&1E<W/D:^3D;B!K86YS:6]S<V$@96D@;VQE('5U<VEA('9I97-T96KD`%EH
M9&5S<^1KY.1N(&MA;G-I;W-S82!E:2!O;&4@;'5K96UA='1O;6EA('9I97-T
M96KD`$EK;VYE:71A(&5I(&SV>71Y;GET+@!086EK:V%A(&5I(&]L92!A<V5T
M971T=2X`4&%I:VMA82!E:2!O;&4@86YN971T=2X`16D@=&5K<W1IY"!V:65S
M=&EN('9I97-T:6]S:6]S<V$`5FEE<W1I<W3D(&5I('1U;&QU="!S:7/D;'3V
MY"X`16D@86YN971T=2!V:65S=&GD+@!(86MU96AD;VEL;&$@96D@;/9Y='EN
M>70@>6ATY&ODY&X@=FEE<W1IY"X`3FEM9>0@96D@;VQL=70@86YN971T=2X`
M3'5K=6WDY'+DY"!E:2!O;&QU="!A;FYE='1U+@!%:2!L;W5K:V%A=F%T(&UI
M971E;&%U<V5E=`!386QA<V%N86$@96D@;VQE(&%N;F5T='4@2%144"UA=71E
M;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE(&%N;F5T='4@24U!4"UA
M=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE(&%N;F5T='4@2V5R
M8F5R;W,M875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L92!A;FYE
M='1U($QO9VEN(&%U=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@
M86YN971T=2!005-35T0M875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I
M(&]L92!A;FYE='1U(%--0BUA=71E;G1I:V]I;FYI<W-A+@!0;VQK=6$@3W!E
M;E-33"!K;VUE;G1O;VX@96D@;VQE(&WDY')I=&5L='DN($]P96Y34TP@<&ET
MY.0@;VQL82!KY'ET971TY'9I<W/D(&IO<R!KY'-I=&5L;.3D;B!02T-3(#$R
M(&1A=&%A+@!%:2!S:7/DY&YK:7)J875T=6UI<W!Y>6YT]FKD(&IO;F]S<V$N
M`$5I('1U;W1U(&%I;G5T=&%K86%N('-A;&%I<W1A(%!'4"UA=F%I;G1A`$5I
M('1U;W1U(&%I;G5T=&%K86%N(&IU;&MI<W1A(%!'4"UA=F%I;G1A`$5I('1U
M;W1U(&%I;G5T=&%K86%N(&AE;FMI;/9K;VAT86ES=&$@4R]-24U%+7-E<G1I
M9FEK86%T=&EA+@!386QA:7-T82!A=F%I;G1A(&5I(&]L92!O;&5M87-S82P@
M:F]T96X@<V%L871T=6$@=FEE<W1IY"!E:2!V;VD@875K86ES=&$N`$MI:6YT
M:?9TY"!E:2!O;&4@87-E=&5T='4`16D@<^3D;G3V:N0`17)O=&EN=&$@96D@
M;VQE(&WDY')I=&5L='DN`$5I(')E=6YO:F$`2VER:F]I='5S=FER:&5I9&5N
M('1A<FMI<W1U<V]H:F5L;6%A(&5I(&]L92!MY.1R:71E;'1Y+@!%:2!K:7)J
M;VET=7-V:7)H96ETY`!%:2!L]GET>6YY="!T:65D;W-T;V$`16D@96AD;W1U
M:W-I80!4=65T='5A($E-05`M875T96YT:6MA871I;W1A<&%A(&5I(&SV>71Y
M;GET+@!6Y&QI;75I<W1I;&QE(&5I(&]L92!VY&QI86EK86ES:&%K96UI<W1O
M82X`16D@:^1Y='3D:N3D(&WDY')I=&5L='ENY"X`2^1Y='3D:N1T=6YN=7-T
M82!T86D@<V%L87-A;F%A(&5I(&SD:&5T971T>2X`2V%I:VMI('!A;&%U='5N
M=70@6$U,+61A=&$@;VQI(&5PY&ME;'!O80!%:2!A<G9O:F$`5F5R<VEO=&EE
M=&]J82!E:2!L]GET>6YY="!A;&MU<&5RY&ES:73D(&%S971U:W-I<W1A+B!3
M:6YU;B!P:73DY"!T96ADY"!A<V5T=6MS970@=75D97-T86%N+@!697)S:6]T
M:65T;VIA(&5I(&SV>71Y;GET(&%S971U:W-I<W1A+B!3:6YU;B!P:73DY"!T
M96ADY"!A<V5T=6MS970@=75D97-T86%N+@!%:2!O<V%L;&ES='5J80!%:2!M
M:73DY&X`16D@;6ETY.1N("A+Y'ETY"!I;7!L:7-I:71T:7-TY"D`3&%P<&DO
M4&]H:F]I<VUA870O17-K:6UO("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!S86%R
M970`3F]R;6%A;&D`4&]H:F]I;F5N('!A;&QO;G!U;VQI<VMO`%!O:&IO:7-E
M="!-87)I86%N:65N('-A87)E=`!.;W)J80!%:2!JY&QK965N`$5I(&5N;F5N
M`$5I('!O:7-T971T=0!%:2!L=6]N;F]S`$5I('3D<FMEY`!%:2!H96YK:6SV
M:V]H=&%I;F5N`$5I(&]L92!H86ME;6ES=&\`17#D:V5L<&\@:G5L:VEN96X@
M879A:6XN`%!O:7-T86UA='1O;6%T('9I97-T:70`16D@;VQE('1O=&5U=&5T
M='4N`$5I('3D<FMEY'0@=FEE<W1I=`!%:2!A<V5T971T=0!%:2!T=65T='4N
M`$AU;VUA871H86XL(&5T=.0@=.1MY"!V;VD@:V5S=.3D(&IO;FMI;B!A:6MA
M80!-=6ES=&EI;G!A;F]T`$5I(&UI=.3D;@!%:2!M:73DY&X@<V5L871T879A
M82P@<&%L86$@=&%K86ES:6XN`$EL;6]I='5S.B!486QL971E='1I:6X@;&EN
M:VET971T>2!L:6ET971I961O<W1O`&UA<G)A<VMU=0!,=6MU;>3D<N0`365R
M:VMI96X@;'5K=6WDY'+D`%-A<F%K:V5I9&5N(&QU:W5MY.1RY`!*;W,@=FEE
M<W1I="!P;VES=&5T86%N(&MU=6MA=7-I='1A:6XL(&YI:6X@:W5I;FMA(&UO
M;G1A(&MU=6MA=71T82!SY&EL>71E=.3D;B!V86YH;VIA(&QI;FMI=&5T='EJ
MY"!L:6ET971I961O<W1O:F$N`$IO<R!V:65S=&ET('!O:7-T971A86X@:W5U
M:V%U<VET=&%I;BP@;FEI;B!K=6EN:V$@;6]N=&$@=F%N:&%A(&SD:&5T971T
M>6IE;B!V:65S=&EE;B!K86YS:6]T82!SY&EL>71E=.3D;BX`4FEV:65N(&QU
M:W5MY.1RY`!*86ME;'5L:7-T86X@;G5M97)O:71A(&5I(&]L92!MY.1R:71E
M;'1Y('#D:79I=&5T=.1VY&MS:2X`3TL`5$%)`$]B:F5K=&D`3V)J96MT:6X@
M;'5O:F$`3VMT86%L:0!L;VMA:W5U`$QO=6MK86%V=75S<W5O9&%T:6X`5&]I
M;6ES=&\`575S:2!S86QA<V%N82!E:2!S86$@;VQL82!S86UA(&MU:6X@;GEK
M>6EN96X@<V%L87-A;F%S:2X`5F%N:&%T('9I97-T:70`5F%N:&$@<V%L87-A
M;F$`5F%N:&$@<V%L87-A;F$@;VX@=N3D<FEN+@!0;VES=&5T86%N('9I97-T
M96KD('9A;FAO:7-T82!LY&AE=&5T='EJ96X@=FEE<W1I96X@:V%N<VEO:7-T
M82X`3VUA;@!686EN($E-05`M<&%L=F5L:6UE="!T=6ME=F%T(&IA971T=6IA
M(&MA;G-I;VET82X`3N1Y=.0@=F%I;B!N92!K86YS:6]T+"!J;VES<V$@;VX@
M;'5K96UA='1O;6EA('9I97-T96KD+@!686EN(&QO=6MK86%V870@;6EE=&5L
M875S965T`%9O:70@;&%I='1A82!V86EN('EH9&5N('/D:&OV<&]S=&EO<V]I
M='1E96XN`%9A;&ET<V4@=F%I;B!Y:W-I(&MA;G-I;R!TY&CD;B!T;VEM:6YT
M;V]N+@!686EN(&]M:7-T86IA('1A:2!JY')J97-T96QMY&X@>6QLY'!I=.1J
MY"!V;VD@;75U='1A82!J86MO:F5N(&]M:7-T86II82!T86D@;VEK975K<VEA
M`$%V86$@:V%?;G-I;P!!=F%A('5U9&5S<V$@:6MK=6YA<W-A`$]P96Y34TP@
M=FER:&4Z(%1I971O:F$@96D@<V%A='4@97-I;&QE(&%L;&5K:7)J;VET971U
M<W1A(%,O34E-12UO<V%S=&$N`$%V86$@:V%N<VEO`$%V86$@=.1MY&X@;&EN
M:VEN('5U9&5S<V$@:6MK=6YA<W-A`$OD>71T]FKD<FIE<W1E;&WD`$UA:&1O
M;&QI;F5N(&]S86QL:7-T=6IA`$%S971U:W-E=`!!<V5T=6MS970@)7,Z;&QE
M`$KD<FIE<W1E='1Y(&QI<W1A`$]R9V%N:7-A871I;P!/<F=A;FES86%T:6]Y
M:W-I:VOV`$]R9V%N:7-O:6YT:0!!;&MU<&5RY&EN96X@;VAJ96QM86X@;6%L
M;&D`06QK=7!E<N1I<V5T(&UA;&QI="`E<SIS<^0Z`$UU=0!-=75T('1I961O
M=`!-=75T('/D:&OV<&]S=&ET:6QI=`!-=75T(&%S971U:W-E=`!,Y&AT97;D
M('!A;'9E;&EN`$]M:7-T86IA;B!O:6ME=61E=`!004TM875T96YT:6MO:6YT
M:6$@96D@;VQE(&OD>71E='3D=FES<^0N`%!%05(Z.DUA:6P@=&%U<W1A:N1R
M:F5S=&5L;>0`4$=0`$1I9VET86%L:6YE;B!01U`M86QL96MI<FIO:71U<P!0
M1U`M<V%L871T=2!V:65S=&D`4$=0+7-A;&%T='5A('1I971O80!01U`@=FER
M:&4Z(`!01U`@=FER:&4Z(%-A;&%I;F5N(&%V86EN('9A871I:2!S86QA<V%N
M871E:W-T:6X`4$=0($%S971U:W-E=`!01U`@<WEO=.0@<V%L87-A;F%T96MS
M=&D`2&5N:VEL]FMO:'1A:6YE;B!01U`M879A:6YP87)I('9A871I:2!S86QA
M='1U82!75U<M>6AT97ET=.0N`$IU;&MI;F5N(%!'4"UA=F%I;@!*=6QK:7-E
M;B!01U`M879A:6UE;B!T96MS=&D`2G5L:VEN96X@4$=0+6%V86EN(&QI<^1Y
M<R!O;FYI<W1U:2!O<V]I='1E96QL93H@(B5S("@E<RDB`$IU;&MI;F5N(%!'
M4"UA=F%I;B!P;VES=&5T=&EI;B!O<V]I='1E96QT83H@(B5S(@!*=6QK:6YE
M;B!01U`M879A:6YR96YG87,`4$=0+6%L;&5K:7)J;VET82!V:65S=&D`4$=0
M+7-A;&%A(&IA(&%L;&5K:7)J;VET82!V:65S=&D`4$=0+6%L;&5K:7)J;VET
M971T=6$@:F$@<V%L871T=6$@=&EE=&]A`%-A;&%I<V5N(%!'4"UA=F%I;65N
M(&QI<^1Y<R!O;FYI<W1U:2X`2G5L:VES96X@4$=0+6%V86EM96X@;&ESY'ES
M(&]N;FES='5I+@!01U`@:^1Y='3V(&]N(&5S=&5T='D@=.1S<^0@:N1R:F5S
M=&5L;>1S<^0N`%!'4"!E:2!O;&4@:^1Y=/9S<^0L(&IO=&5N(&1I9VET86%L
M:7-I82!A;&QE:VER:F]I='5K<VEA(&5I('9O:2!T87)K:7-T86$N`%!'4"!E
M:2!O;&4@:^1Y=/9S<^0L(&IO=&5N('-A;&%T='5J82!V:65S=&5JY"!E:2!V
M;VD@875K86ES=&$N`%!'4#IN(&OD>71T]B!E9&5L;'ET=.3D('!O;FYA:&1U
M<VEK:W5N;VET82X@2F]S('-E;&%I;65S:2!A<V5T=6MS970@97-TY';D="!E
M<FEL;&ES=&5N(&EK:W5N;VED96X@879A86UI<V5N+"!N:6EN('-I;G5N('!I
M=.3D(&UU=71T86$@;N1I=.0@87-E='5K<VEA('1A:2!E="!V;VD@:^1Y='3D
MY"!01U`M=&]I;6EN=&]J82X`4$A0+6MO;V1I`%!(4"UK;VUE;G1O='5L:VMI
M`%!-(&ME=GET=.0@<V%D971T80!032!S861E`%!-(&MU=7)O:F$`4$T@;'5M
M:0!032!L=6UI<V%T96ET80!032!L=6UI`%!-('5K:V]S;7ER<VMY:N0`4$]0
M,P!03U`S("A4=6YN:7-T82!P<F]T;VMO;&QA(&%U=&]M86%T=&ES97-T:2D`
M4$]0,R!J82!34TPM<V%L875S`%!/4#,@:F$@4U-,+7-A;&%U<R`H:71S92!A
M;&QE:VER:F]I=&5T='4@=F%R;65N;F4I`%!/4#,@:F$@4U-,+7-A;&%U<R`H
M:71S92!A;&QE:VER:F]I=&5T='4@=F%R;65N;F4I`%!/4#,L(&5I(%1,4RUS
M86QA=7-T80!03U-)6"UL86%J96YN=6MS970@<'5U='1U=F%T`%!?2%`M:V]M
M96YT;W1U;&MK:0!4Y'ET90!3:79U("5D("\@)60`4VEV=2P@:F]S<V$@96YS
M:6UMY&EN96X@=75S:2!V:65S=&D`4VEV=2P@:F]S<V$@;VX@=FEI;65I;F5N
M('5U<VD@=FEE<W1I`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EI;F$@*&UI96AI
M=&5T='D@86QU92D`4&%N86UA`%!A<'5A(%5U<VDM1W5I;F5A`%!A<F%G=6%Y
M`$]S82AT*0!/<VET=&%I;B!P:6QV:7-TY`!386QA<V%N871E:W-T:0!386QA
M<V%N871E:W-T:2`H575D97-T86%N*0!386QA<V%N871E:W-T:6X@<&]I<W1O
M(&]N;FES='5I+@!386QA<V%N871E:W-T:3H`4V%L87-A;F%T96MS=&D@96D@
M<V%A(&]L;&$@='EH:N0`4V%L87-A;F%T96MS=&ET(&5I=N1T('3D<VWDY"``
M4V%L87-A;F$`4V%L87-A;F%N('9A:6AT;R!O;FYI<W1U:2X`5N3D<N0@<V%L
M87-A;F$`4V%L87-A;F%A('1A<G9I=&%A;B!2041)55,M875T96YT:6MO:6YT
M:6EN+@!386QA<V%N82!V87)M:7-T=6MS96QL80!386QA<V%N83H`4V%L87-A
M;F$Z(`!386QA<V%N;VIE;B!P:73DY"!O;&QA('-A;6%T+@!,:6ETY`!,:6ET
MY"!L96EK97#V>63D;'3D`%!O;&MU`$IO;F]S<V$@;VQE=F%T('-I<^3D;FMI
M<FIA=71U;6ES<'EY;F[V=#H`26AM:7-E=`!0<F]S96YT=&D`4W5O<FET82!Y
M;&SD<&ET;W1O:6UE;G!I=&5E=`!3=6]R:71A('EL;.1P:71O=&]I;65N<&ET
M965T('-I<^3D;FMI<FIA=71U;6ES96X@>6AT97ED97-SY"X`3VEK975S`$]I
M:V5U='1A("(E<R(@96D@<&]I<W1E='1U+@!+Y'ET=/8@:VEE;&QE='1Y`$]I
M:V5U9&5T`$]I:V5U:W-I96X@>6QLY'!I=&\`5.1MY&X@:^1Y='3D:N1N(&]I
M:V5U:W-I82!E:2!V;VD@;75U='1A82X`2&5N:VEL]FMO:'1A:6YE;@!/;6%T
M('1I961O=`!(96YK:6SV:V]H=&%I<V5N(%!'4"UA=F%I;G!A<FEN(&QU;VYT
M:2!O;FYI<W1U:2X`2&5N:VEL]FMO:'1A:7-T96X@4$=0+6%V86EM:65N('!O
M:7-T;R!O;FYI<W1U:2X`2&5N:VEL]FMO:'1A:7-I82!3+TU)344M=F%R;65N
M=&5I=&$@14D@='5O='4Z(`!(96YK:6SV:V]H=&%I<W1E;B!3+TU)344M879A
M:6UI96X@<&]I<W1O(&]N;FES='5I+@!097)U`$QE;6UI:VET`$9I;&EP<&EI
M;FET`%!U:&5L:6X`5F%L;VMU=F%T`%!I=&-A:7)N`%!I:W-E;&D`3&%I=&$@
M86QL96MI<FIO:71U<R!V87-T875S=FEE<W1I96X@:F$@=N1L:71E='3D=FEE
M;B!V:65S=&EE;B!A;&MU=6XN`%9I97-T:2!T96MS=&EM=6]D;W-S82X`2VQI
M<V5E=`!3;VET82#DY&YI('5U<VES=&$@=FEE<W1E:7-TY#\@5.1MY"!T;VEM
M:6YT;R!V86%T:6D@<V5L86EM965N(&QI:71E='1Y:N0@Y.1N:71I961O<W1O
M:F$N($SD:&5S(&MA:6MK:2!S96QA:6UE="!7:6YD;W=S(&IA($UA8R!A;'5S
M=&%L;&$@<VESY&QTY';D="#DY&YI=&EE9&]S=&]J82P@;75T=&$@;75I;&QA
M(&%L=7-T;VEL;&$@<V%A=&5T86%N('1A<G9I=&$@;&%A:F5N;G5K<VEA+@!.
M87!S875T82!J;W1A:6X@<V]L=6$`5F%R;6ES=&$@971TY"!H86QU870@<&]I
M<W1A82!TY&WD;B!E;&5M96YT:6XZ`%9A<FUI<W1A(&5T=.0@:&%L=6%T('!O
M:7-T86$@;&EN:VET>6MS96X@=.1HY&X@96QE;65N='1I:6XN`$%N;F$@:W5U
M:V%U<VD@:F$@=G5O<VDN`$%N;F$@;FEM:2!U=61E;&QE(&QU;VMI='5K<V5L
M;&4Z`$%N;F$@=75D96X@:V%N<VEO;B!N:6UI.@!!;FYA(&]I:V5A($E0+6]S
M;VET92X`06YN82!O:6ME82!PY&EVY&WDY'+D.R!487)K:7-T82!PY&EV:65N
M(&QU:W5MY.1RY"!K=75K875D97-S82X`06YN82!A:6MA(&]I:V5A<W-A(&UU
M;V1O<W-A+@!!;FYA('5U9&5N(&MA;G-I;VX@;FEM:3H`06YN82!U=7-I(&YI
M;6DZ`$%N;F$@<V%L86ES96X@4$=0+6%V86EM96X@<V%L87-A;F%T96MS=&DN
M(%-I;G5N('!I=.3D(&%N=&%A('3D;>0@=&5K<W1I('9A:6X@:V5R<F%N("5S
M+6ES='5N;F]N(&%I:V%N82X`06YN82!S86QA:7-E;B!3+TU)344M879A:6UE
M;B!S86QA<V%N871E:W-T:2X@4VEN=6X@<&ETY.0@86YT86$@=.1MY"!T96MS
M=&D@=F%I;B!K97)R86X@)7,M:7-T=6YN;VX@86EK86YA+@!+:7)J875D=2!U
M=61E<W1A86X@<VESY.1N(&IA=&MA86MS97-I('9I97-T:6X@:VER:F]I='1A
M;6ES=&$N($IO<R!%5"!KY'ETY"!E=N1S=&5I=.0@2D$@:VER:F]I=&%T('9I
M97-T96KD('!O;FYA:&1U<VEK:W5N87-S82P@;FEI;B!S:6YU;B!P:73DY"!K
M:7)J875T=6$@<VESY.1N(&UY]G,@<.3D:6MK=6YA<W-A+B!4Y&WD(&]N('!A
M:VMO('1E:&3D('-I:W-I+"!E='3D(&UA:&1O;&QI<V5T(&AY]FMKY.1JY'0@
M96EVY'0@<V%A('1I973DY"!S97-S:6]N($E$('1I971O:F%S:2X@4'EY9.1M
M;64@:F\@971U:^1T965N(&%N=&5E:W-I(&%I:&5U='1A;6%A;6UE(&CD:7)I
M]G3D+@!!;FYA(&QY:'ET(&MU=F%U<R!O;F=E;&UA<W1A+@!!;FYA('-A;&%S
M86YA<VDN`$%N;F$@:^1Y='3D:N1T=6YN=6MS97-I(&IA('-A;&%S86YA<VD`
M06YN82!KY'ET=.1JY'1U;FYU:W-E<VDN`$QU92!S975R86%V82!T96MS=&DN
M(%-I;G5N(%!)5,3$('-U;W-T=6$@:^1Y='3V96AT;VEH:6X@=F]I9&%K<V5S
M:2!KY'ET=.3D(&KD<FIE<W1E;&WDY"X`2V]R:F%A(&5PY&WDY'+D:6YE;B!T
M86D@=FER:&5E;&QI;F5N(&]S;VET92X`5F%L:71S92!K86YS:6\@96YN96X@
M=.1MY&X@=&]I;6EN;F]N('-U;W)I='1A;6ES=&$N`%9A;&ET<V4@86EN86MI
M;B!Y:W-I(&MA;G-I;RP@:F]S=&$@:&%E=&%A;BX`5F%L:71S92!TY&QL92!O
M<&5R86%T:6]L;&4@=F%I;B!Y:W-I(&MA;G-I;RX`5F%L:71S92!T86D@;75O
M:VMA82!O:6ME86X@<'5O;&5I<V5S<V$@;&%A=&EK;W-S83H`06YN82!N:6UI
M('5U9&5L;&4@;'5O:VET=6MS96QL93H`4'5O;&$`4&]L:71I:6MK80!+>7-E
M;'ET`%!O<G1U9V%L:0!4Y&WD;B!K=79A;B!P86EK:V$`5.1MY&X@=&%U;'5K
M;VX@<&%I:VMA`%9O:2!LY&AE='3DY"!V:65S=&5JY"!K86YS:6]O;B`H96D@
M:V]S:V4@24U!4"!Y:'1E>6MS:>0I`$OD>71TY.0@2&]R9&5A`$QA:71A(&%L
M;&5K:7)J;VET=6MS96X@971E96X@97)O='1I;65T("@G+2T@)RD`4V%D96WD
MY'+D(&5D96QL:7-I;&QE("5S('1U;FYI;&QE.B``2&%I:'1U=G5U<R`\8G(@
M+SYT;V1E;F[D:_9I<WEY<P!!<V5T=6MS:65N('#D:79I='ES(&]N;FES='5I
M+@!0<F5F<U]L9&%P.B!487)V:71T879A82!,1$%0+6QA86IE;FYU<W1A(&5I
M(&SV>71Y;GET+@!0<F5F<U]S97-S:6]N.B!487)V:71T879A82!S97-S:6]N
M+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET`$EL;6%N<&%I;F4`26QM86YP86EN
M92!M97)E;G!I;FYA<W-A.B``26QM86YP86EN93H@`$5S:6MA='-E;'4`17-I
M:V%T<V5L92!K=79A('5U9&5S<V$@:6MK=6YA<W-A`$5D96QL:6YE;B!V:65S
M=&D`161E;&QI;F5N('-I=G4`161E;&QI<V5T(&%S971U:W-E=`!4=6QO<W1A
M`%1U;&]S=&$@9&]K=6UE;G1T:0!0<FEO<FET965T=&D`4V%L86EN96X@879A
M:6X`4V%L86ES96X@879A:6UE<VD@<V%L87-A;F$`3VYG96QM80!/;F=E;&UA
M;B!K=79A=7,`4')O:F5K=&ET`$MY<WD@:F]K82!K97)T82!K=6X@;.1H971E
M=.3D;B!L:6ET971I961O<W1O.R!/;&5T=6MS96YA($5)`$MY<WD@:F]K82!K
M97)T82!K=6X@;.1H971E=.3D;B!L:6ET971I961O<W1O.R!/;&5T=6MS96YA
M($M93$S$`$ME:&]T=&5E;B!T96MS=&D`4')O=&]K;VQL83H`2G5L:VEN96X@
M879A:6X`2G5L:VES96X@879A:6UE;B!A;&=O<FET;6D`2G5L:VES96X@879A
M:6UE;B!T:65D;W0`2G5L:VES96X@4$=0+6%V86EN<&%L=F5L:6UE;B!KY'ET
M=/8@;VX@97-T971T>2X`2G5L:VES96XO<V%L86ES96X@879A:6YP87)I;B!L
M=6]N=&D@97#D;VYN:7-T=6DN`%!U97)T;R!2:6-O`%1U7VAO82!P;VES=&5T
M=70`5'5H;V$@<&]I<W1E='5T`%1U:&]A('!O:7-T971U="!K86YS:6]I<W1A
M`$UI=&5N('5S96EN(')O<VMA:V]R:2!K86YS:6\@='EH:F5N;F5TY.1N.@!6
M;VD@='5H;W1A('!O:7-T971T=6IA('9I97-T96KD`%!O:7-T82!NY&EN(&UO
M;F5N('#D:7;D;B!I:^1I<V5T('9I97-T:70@<F]S:V%K;W)I:V%N<VEO<W1A
M+@!0;VES=&$@=F%N:&%T('9I97-T:70@<F]S:V%K;W)I:V%N<VEO<W1A+@!0
M;VES=&5T=&EI;B`E9"!V:65S=&GD(')O<VMA:V]R:6MA;G-I;W-T82X`4&]I
M<W1E='1I:6X@,2!V:65S=&D@<F]S:V%K;W)I:V%N<VEO<W1A+@!1871A<@!+
M>7-E;&4`2VEI;G1I]@!0;W-T:6MI:6YT:?8Z("4N,F9-0B`O("4N,F9-0B`@
M*"4N,F8E)2D`4&]S=&EK:6EN=&GV.B`E+C)F34(@+R!%22!204I/25154U1!
M`%!O<W1I:VEI;G1I]CH@14D@4D%*3TE455-400!,86EN875S("5F.@!24T$@
M2G5L:VEN96X@879A:6X@*"5D(&)I='1IY"D`4F%D:6]P86EN:6ME`%-A9&4`
M4V%D971T82!A:6MA:7-I;@!3861E='1A(&UY]FCDY&X`4V%D96MU=7)O`%9E
M<VD@:F$@;'5M:0!6961E<W3D(&QU;65E;@!3871U;FYA:6YE;B!M:65T96QA
M=7-E`%-U:&1E`$QU:W4`5F]I(&QU:V5A('9I97-T96KD`%!O:7-T971A86YK
M;R`E<S\@5.1TY"!T;VEM:6YT;V$@96D@=F]I('!E<G5U='1A82X`4&]I<W1E
M=&%A;FMO('1I961O="!KY'ET=.1JY'-TY"`E<S\@5.1TY"!T;VEM:6YT;V$@
M96D@=F]I('!E<G5U='1A82X`4F%K:V5N;F$@:V%N<VEO<'5U('5U9&5L;&5E
M;@!386%P=6D@<&5R:6QL90!386%P=6D@<&5R:6QL92!JY&QK965N`%-A87!U
M:2!P97)I;&QE(&5N;F5N`%5U9&5L;&5E;F]H:F%?80!5=61E;&QE96YO:&IA
M80!5=61E;&QE96YO:&IA82!V:65S=&D`575D96QL965N;VAJ86$@=.1MY"!V
M:65S=&D`575D96QL965N;VAJ875S(&5PY&]N;FES='5I+@!4964@;75U=&]K
M<V5T('5U9&5S=&%A;@!0Y&EV:73D`%#D:7;D="!D>6YA86UI<V5T('9A;&EK
M:V]E;&5M96YT:70Z`%#D:79I=.0@<&]S=&EK86YS:6]NY&MY;>3D.@!0Y&EV
M:73D('!O<G1A86QI;N1K>6WDY#H`4^3D;F[V;&QI;F5N(&QA=7-E:V4`4F5L
M86%T:6]S96QA:6X`3&%T86$@=75D97-T86%N`$QA=&%A(&[D:WEMY"!U=61E
M<W1A86X`375I<W1I:6YP86YO=`!-=6ES=&$@=F%P86$O=F%R871T=2!T:65D
M;W0N`$UU:7-T82!E9&5L;&EN96X@;N1K>6WD`$5TY'!O<W1I;&%A=&EK:V\Z
M`$5TY'!A;'9E;&EM970`173D<&%L=F5L=6X@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`4&]I<W1A`%!O:7-T82!O<VEO`%!O:7-T82!K
M96YT=.0@:&%K=65H9&]I<W1A`%!O:7-T82!S87)A:V4`4&]I<W1A(&UU;W1O
M:6QU`%!O:7-T82!P87)I`%!O:7-T82!T86QL971E='1U('-K<FEP=&D@<&%L
M=F5L:6UE;B!VY&QI86EK86ES:&%K96UI<W1O<W1A+@!P;VES=&$@;.1H9&4`
M4&]I<W1A`%!O:7-T82!TY&WD(&YO;V1I(&1O:W5M96YT:7-T80!0;VES=&$@
M:^1Y='3D:N0`4&]I<W1A(&OD>71TY&KD.B`E<P!.:6UEY"!K86YS:6]T('5U
M9&5L;&5E;@!.:6UEY"!LY&AE=&5T='EJ96X@=FEE<W1I96X@:V%N<VEO('5U
M9&5L;&5E;B!K=75K875D96X@86QU<W-A+@!+86YS:6]N("(E<R(@;FEM9>1M
M:6YE;B`B)7,B(&5PY&]N;FES='5I+B!086QV96QI;65N('9I<FAE:6QM;VET
M=7,@;VQI`%9A<W1A7V$@;&ES=&%L;&4`2V]R=F%A('9A:6AT;V5H9&]L;&$Z
M`%9A<W1A80!687-T875S(&SD:&5T971T>2X`5F%S=&%A(&MA:6MI;&QE`%9A
M<W1A82!K86EK:6QL93H`5F%S=&%A(&QI<W1A;&QE`%9A<W1A82!L:7-T86QL
M93H`7U9A<W1A82!K86EK:6QL90!,Y&AE=.0@=F%S=&%U<W9I97-T:2!E:2UT
M=65T=7-S82!M=6]D;W-S82X`3.1H973D('9A<W1A=6MS96YA('9A<&%A+W9A
M<F%T='4@=&EE9&]T('-E=7)A879A;&QE(&MA:&1E;&QE(&MU=6MA=61E;&QE
M+@!,Y&AE=.0@=F%S=&%U:W-E;F$@<'EY9&5T>70@=F%P86$O=F%R871T=2!T
M:65D;W0N`%9A<W1A=7-O<V]I=&4`5F%S=&%U<V]S;VET93H@`%9A<W1A=7,Z
M`$EL;6]I=&$@:&%R;6ET=&]M86YA`$EL;6]I=&$@<F]S:V%P;W-T:6YA`%]0
M>7EDY"!I;&UO:71U<R!V:65S=&EN(&QU:V5M:7-E<W1A`%!Y>6YT]O9N(&5I
M('9O:71U('9A<W1A=&$N(%9I<FAE:V]O9&DZ(`!0>7EDY"!I;&UO:71U<R!V
M:65S=&EN(&QU:V5M:7-E<W1A+@!0>7ED971T>>0@=FEE<W1IY"!E:2!L]GET
M>6YY="X`4'EY9&5T='GD('!A;'9E;'5A(&5I(&SV>71Y;GET+@!487)V:71T
M879A82`B)7,B+71I971O82!E:2!O;&QU="!MY.1R:71E;'1Y("5S(&%S971U
M:W-I<W-A+@!487)V:71T879A82`B)7,B+71I971O82!E:2!O;&QU="!MY.1R
M:71E;'1Y(%9&4R!A<V5T=6MS:7-S82X`5&%R=FET=&%V86$@(B5S(BUT:65T
M;V$@96D@;VQL=70@;>3D<FET96QT>2!A<V5T=6MS:7-S82X`4&%K;VQL:6YE
M;B!K96YT=.0`4&%K;VQL:6YE;B!O<V%L;&ES='5J80!4>6AJ96YNY`!4>6AJ
M96YNY"!S86QA<V%N80!4>6AJ96YNY"!S86QA<V%N87-I`%9A<W1A86IA;B!T
M:6QA=&EE9&]T(&]N('#D:79I=&5T='D`4&%L875T82!E9&5L;&EN96X@:WES
M96QY`%1U;&]K<V5T`$IA=&MA`$IA=&MA(&ES='5N=&]A<VD`4&%L86$@(E9I
M97-T:6X@:VER:F]I='5K<V5E;B(`4&%L86$@=&%K86ES:6X@2&%E('9I97-T
M96EH:6X`4&%L86$@87-E='5K<VEI;@!086QA82!P;W-T:6MA;G-I;W-I=G5L
M;&4@:W5N('9I97-T:2!O;B!P;VES=&5T='4L('-I:7)R971T>2!T86D@:V]P
M:6]I='4N`%9A:'9I<W1A('5U<VD@<V%L87-A;F$`4F5U;FEO;@!086QA=71A
M(&%S971U:W-E=`!2:6-H(%1E>'0@161I=&]R:6X@87-E='5K<V5T`$%R=F]I
M='5K<V5T`$]I:V5A`$]I:V5A(&]T<V%K90!/:6ME82!A<G9O=`!2:79I7VX@
M=&EE9&]T+BXN`%)O;VQI`%)O;6%N:6$`2^3D;F[D(#$X,`!+Y.1N;N0@=F%S
M=&%PY&EVY.1N`$ODY&YNY"!M>?9TY'#D:7;DY&X`4FEV:6X@=&EE9&]T`%)I
M=FEN('1I961O=`!2:79I=#H`5FEI=F]I=&EN`%9I:79O:71I;B!NY&MY>2!K
M86EK:VEE;B!R:79I96X@:F$@<V%R86MK96ED96X@=N1L:6QLY`!6:6EV;VET
M:6X@;N1K>7D@=F%I;B!S87)A:VME:61E;B!VY&QI;&SD`%9I:79O:71I;B!N
MY&MY>2!V86EN(')I=FEE;B!VY&QI;&SD`%-U;W)I=&$`5F5NY&KD;B!&961E
M<F%T:6EV:6YE;B!T87-A=F%L=&$`4G5A;F1A`%,O34E-10!3+TU)344@:W)Y
M<'1O9W)A869I;F5N(&%L;&5K:7)J;VET=7,`4R]-24U%('-A;&%T='4@=FEE
M<W1I`%,O34E-12!S86QA='1U('9I97-T:0!3+TU)344@=FER:&4Z(`!3+TU)
M344@5FER:&4Z(%-A;&%I;F5N(&%V86EN('9A871I:2!S86QA<V%N871E:W-T
M:6X`4R]-24U%+6%S971U:W-E=`!3+TU)344@<WGV=.0@<V%L87-A;F%T96MS
M=&D`2&5N:VEL]FMO:'1A:6YE;B!3+TU)344M879A:6YP87)I('9A871I:2!S
M86QA='1U82!75U<M>6AT97ET=.0N`$IU;&MI;F5N(%,O34E-12UA=F%I;B!P
M;VES=&5T=&EI;B!O<V]I='1E96QT82`B)7,B`$IU;&MI<V5N(%,O34E-12UA
M=F%I;65N(&QI<^1Y<R!O;FYI<W1U:2X`2G5L:VEN96X@4R]-24U%+6%V86EN
M<F5N9V%S`$IU;&MI;F5N+U-A;&%I;F5N(%,O34E-12UA=F%I;G!A<FEN(&QI
M<^1Y<R!O;FYI<W1U:2X`4R]-24U%+6%L;&5K:7)J;VET82!V:65S=&D`4R]-
M24U%+7-A;&%A(&IA(&%L;&5K:7)J;VET82!V:65S=&D`4R]-24U%(&OD>71T
M]B!O;B!E<W1E='1Y('3D<W/D(&KD<FIE<W1E;&WD<W/D+@!3+TU)344@96D@
M;VQE(&OD>73V<W/D+"!J;W1E;B!S86QA='1U:F$@=FEE<W1E:N0@96D@=F]I
M9&$@875K86ES=&$N`%,O34E-12!E:2!O;&4@:^1Y=/9S<^0L(&IO=&5N('3D
M;>1N(&1I9VET86%L:7-E<W1I(&%L;&5K:7)J;VET971U;B!V:65S=&EN('-I
M<^1L=/;D(&5I('9O:61A(&[D>71TY.0N`%,O34E-12!E:2!O;&4@:^1Y=/9S
M<^0L(&IO=&5N(&1I9VET86%L:7-I82!A;&QE:VER:F]I='5K<VEA(&5I('9O
M:61A('1A<FMI<W1A82X`4R]-24U%.FX@:^1Y='3V(&5D96QL>71TY.0@<&]N
M;F%H9'5S:6MK=6YO:71A+B!*;W,@<V5L86EM97-I(&%S971U:W-E="!E<W3D
M=N1T(&5R:6QL:7-T96X@:6MK=6YO:61E;B!A=F%A;6ES96XL(&YI:6X@<VEN
M=6X@<&ETY.0@;75U='1A82!NY&ETY"!A<V5T=7-T82!T86D@970@=F]I(&OD
M>71TY.0@4R]-24U%+71O:6UI;G1O:F$N`%-!4TPM875T96YT:6MO:6YT:2!E
M:2!O;&4@:^1Y=&5T=.1V:7-SY"X`4TU3(%1E:W-T:79I97-T:70`4TU44`!3
M44PM:V]M96YT;W1U;&MK:0!344PM;&%U<V4@87)V;VIE;B!H86ME;6ES965N
M`%-32`!/3DY)4U1520!37U%,+6MO;65N=&]T=6QK:VD`3W1?<VEK:V\`;&$`
M5&%?;&QE=&$@:V]P:6\@:V%N<VEO;VX@`%1A7VQL971A(&YI;65L;.0`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&IA($YE=FES`%-A:6YT($QU8VEA`%-A
M:6YT(%!I97)R92!J82!-:7%U96QO;@!386EN="!6:6YC96YT(&IA($=R96YA
M9&EI;FET`%-A;6%A;B!K96AY:W-E96X@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&IA(%!R:6YC:7!E`%-A=&5L;&EI='1I('!A;'9E;'5N
M=&%R:F]A:F$`4V%U9&EA($%R86)I80!486QL971A`%1A;&QE=&$@(B5S(@!4
M86QL971A("5S`%1A;&QE=&$@;&EI=&5T:65D;W-T;W0@=FEE<W1I96X@;75K
M86YA(&SD:&5T971T>6IE;B!V:65S=&EE;B!K86YS:6]O;BX`5&%L;&5T82!L
M=6]N;F]S`%1A;&QE=&$@:W5V80!T86QL971A(&MU=F$@9V%L;&5R:6%A;@!4
M86QL971A(&%S971U:W-E=`!486QL971A(&MI<FIE<&]H:F$`5&%L;&5T82!?
M;'5O;FYO<P!486QL971A(&YI;65L;.0`5&%L;&5T82!L=6]N;F]K<V5T('1I
M;&%T:65D;VQL82!U=7-I`%1A;&QE=&$@;'5O9'5T(&%S971U:W-E="!02%`M
M<VMR:7!T:6[D('!A;'9E;&EM97-I(';D;&EA:6MA:7-H86ME;6ES=&]O;BX@
M`%1A;&QE=&$@=F%S=&%A;F]T=&%J870@875T;VUA871T:7-E<W1I(&]L971U
M<V]S;VET96MI<FIA86XN`%1A;&QE=&5T86%N:V\@:&%K=2!V:7)T=6%A;&ES
M965N(&MA;G-I;V]N/P!486QL971A(&SD:'1E=N0@=FEE<W1I+@!486QL971E
M='1I:6X@)7,Z;B!A<V5T=6MS970N`$%S971U<W1E;B!PY&EV:71Y<W-K<FEP
M=&D@;VX@=&%L;&5T971T=2!P86EK:V%A;CH@(B5S(BX`3'5O;FYO<W9I97-T
M:6X@=&%L;&5T=7,@97#D;VYN:7-T=6DN(%!A;'9E;&EM96X@=FER:&5I;&UO
M:71U<R!O;&DZ("5S`$AA:F%N86ES:6$@=6MK;W-M>7)S:WEJY`!4:65D90!(
M86MU`$AA:W4@)7,`2&%K=6MO;F5E=`!(875N(&%S971U:W-E=`!(875N('1U
M;&]K<V5T`%9A;FAA`%9A;&ET<V4`5F%L:71S92!SY&AK]G!O<W1I=&EL:0!6
M86QI='-E('1I961O<W1O=`!686QI='-E('#D:7;D;>3D<N0`5F%L:71S92!K
M96YT=.0`5F%L:71S92!L:7/D='3D=N0@<GEH;>0`5F%L:71S92!U=7-I(&]M
M:7-T86IA`%9A;&ET<V4@<&%L=F5L:6X`5F%L:71S92!K:7)J97!O:&IA.@!6
M86QI='-E(&QI<^1T=.1VY"!KY'ET=.1JY`!6;VET('9A;&ET82!O<V]I=&5K
M:7)J870L(&IO:6AI;B!L:7/D=.3D;B!J82!J;VES=&$@:&%E=&%A;B!O<V]I
M='1E:71A+@!686QI='-E(&MA:6MK:0!686QI='-E(&MA:6MK:2!PY&EVY&WD
MY'+D:V]M<&]N96YT:70`5F%L:71S92!O<V]I='1E:61E;B!L86%J96YN=6MS
M97-S82!KY'ET971TY';D="!K96YTY'0N`%9A;&ET<V4@<^1H:_9P;W-T:71I
M;&D`5F%L:71S92!O8FIE:W1I`%!O:7-T82!V86QI;FYA=`!686QI='-E('1A
M<G9I='1A=F%T(&UE<FMI="!A;&QA(&]L979I<W1A('9A;&EK;VES=&$N(%9O
M:70@<V5N(&KD;&ME96X@:V]P:6]I9&$@:F$@;&EI='3DY"!M97)K:70@=&5K
M<W1I:7-I+@!686QI='-E('#D:7;D>6MS96X@97)O=&EN;65R:VMI.@!686QI
M='-E('#D:7;D>6MS96X@97-I='ES=&%P83H`5F%L:71S92!G86QL97)I82P@
M:F]H;VX@:W5V82!T86QL971E=&%A;BX`5F%L:71S92!M=75T971T879A('!R
M;V9I:6QI.@!686QI='-E('!O<W1I<&%L=F5L:6UE;B!T>7EP<&D`5F%L:71S
M92!K96QL;VYA:F%N(&5R;W1I;FUE<FMK:3H`5F%L:71S92!A:F%N(&5S:71Y
M<W1A<&$Z`%9A;&ET<V4@:V%K<VD@>6AT965N<V]P:79A82!K96YT=.3D+@!6
M86QI='-E(';D<FET965M82X`5F%L:71S92!KY'ET971TY';D(&MI96QI.@!6
M86QI='-E(&]S;VET96MI<FIA=#H`3.1H973D(&%V86EN(&IU;&MI<V5L;&4@
M879A:6YP86QV96QI;65L;&4`3.1H973D('9I:6UE:7-I;6WD="!T:65D;W0`
M3.1H973D('9I97-T:0!,Y&AE=.0@;VYG96QM879I97-T:0!,Y&AE=.0@4TU3
M`$SD:&5TY"!V:65S=&D@:6QM86X@;W1S:6MK;V$_`$SD:&5TY"!L=6MU:W5I
M='1A=7,@:W5N(&SD:&5T=.1JY"!O;B!S:73D('!Y>73D;GET+@!396YE9V%L
M`%1U;FYI<W1I;CH@`$SD:&5T971T>6IE;B!V:65S=&EE;B!K86YS:6\`3.1H
M971E='1Y:F5N('9I97-T:65N(&MA;G-I;SH`<WEY<VMU=0!397)B:6$@:F$@
M36]N=&5N96=R;P!387)J86YU;65R;P!086QV96QI;@!086QV96QI;65N(&IA
M(&MA;G-I;VED96X@87-E='5K<V5T`%!A;'9E;&EM96X@=&EE9&]T(&]V870@
M=N3D<FGD('1A:2!E:7;D="!O;&4@:^1Y=&5T=.1V:7-SY"X`4&%L=F5L:6XZ
M`$ES='5N=&]J96X@:&%L;&EN=&$`4V5S<VEO;B!)1"!O;B!V86YH96YT=6YU
M="X`27-T=6YN;W0`07-E=&$`4V%L87-A;F%N(')E<V5T;VEN=&EI;B!L:6ET
M='EV:>0@87-E='5K<VEA+"!J;W,@:F]S:W5S('5N;VAD870@<V%L87-A;F%S
M:2X`5F]I="!M=75T=&%A('9I97-T:6X@:V]P:6]I;6ES965N('1A:2!S:6ER
M=.1M:7-E96X@;&EI='1Y=FGD(&%S971U:W-I82X`07-E=&$@6"U0<FEO<FET
M>2!K96YT=.0@=FEE<W1I;B!K:7)J;VET=6MS97-S82X`5F]I="!A<V5T=&%A
M('5L:V]I<W1E;B!P86QV96QI;6EE;B!A<V5T=6MS970L(&IO:71A(&AA;'5A
M="!KY'ET=.3D('!O<G1A86QI<W-A+@!6;VET(&%S971T86$@:^1Y=&5T=.1V
MY&X@:VEE;&5N+"!A:6MA=GGV:'EK:V5E;B!J82!M=6ET82!PY&EVY&WDY'+D
M87-E='5K<VEA+@!6;VET(&%S971T86$@86QO:71U<V]H:F5L;6%N+"!VY')I
M=&5E;6%N+"!NY&MY;>1N('#D:79I='EK<V5N(&IA(&UU:71A(&[D:WEMY.1N
M(&QI:71T>79IY"!A<V5T=6MS:6$N`$%S96YN=7,`07-E;FYU:W-E;B!PY&EV
M:71Y<W-K<FEP=&D@;VX@<V%A=&%V:6QL80!5<V5A="!P86EK870@<V]P:79A
M="!A;FYE='1U=6X@<&%R86UE=')I:6XZ(`!397EC:&5L;&ET`$MA;G-I;VED
M96X@:F%K86UI;F5N`$UU=71A(&MA;G-I;VED96X@:F%K;VIA`%9O:70@86YT
M86$@=&]I<VEL;&4@:^1Y='3D:FEL;&4@;VEK975K<VEA(&MA;G-I;VEH:7-I
M+@!/<W1O:W-E=`!,>6AY="!K=79A=7,Z`$%S971E=&$@<&EK879A;&EN=&%N
MY'!PY&EM970@=7-E:6UM:6QL92!L:6YK96EL;&4N`$[D>73D('1A:2!P:6EL
M;W1A(&]L971U:W-E;F$@=FEE<W1I<W3D('-U=7)E="!T96MS=&EL86EN875K
M<V5T+B!!<V5T=6MS96X@=F]I(&UU=71T86$@:&5L<&]S=&D@;6EL;&]I;B!T
M86AA;G-A+@!%='-I('1E>'0O<&QA:6X@='EY<'!I<VES=.0@=FEE<W1E:7-T
MY"!01U`M=&EE=&]J82X`4W5L:F4@=FEE<W1I;FMI<FIO:71U<VEK:W5N82!K
M=6X@=FEE<W1I(&]N('1A;&QE=&5T='4@;'5O;FYO<VMA;G-I;V]N+@!,:6ET
MY"!O;&5T=6MS96YA(&IU;&MI;F5N(%!'4"UA=F%I;65S:2!LY&AT979I:6X@
M=FEE<W1E:6AI;BX`3N1Y=.0`3N1Y=.0@:V%I:VMI(&MA;G-I;W0`3N1Y=.0@
M:V%I:VMI(&]T<VEK:V]T:65D;W0`3N1Y=.0@<&]I<W1E='5T`$[D>73D(&]S
M82!O='-I:VMO=&EE9&]I<W1A`$[D>73D('!O<W1I;&ES=&%T:65D;W0`3N1Y
M=.0@=F%I;B!T:6QA='5T(&MA;G-I;W0`3N1Y=.0@=&EL86%M871T;VUA=`!.
MY'ETY"!I:V]N:2P@:F]S(&QI:71T965N('9O:2!P;VES=&%A('9I97-T:7-T
MY"X`3N1Y=.0@97)O879A:7-U=61E="!A<V5T=6MS:65N('1A;&QE=&5T=7-S
M82!J82!U=61E<W-A(&IU=7)I(&UU;VMA='5S<V$@=F5R<VEO<W-A+@!.Y'ET
MY"!E9&5L;&ES96X@<VESY.1N:VER:F%U='5M:7-E;B!PY&EVY'ES+@!.Y'ET
MY"!V:65S=&EN('1I;&]J96X@<V5L:71E('!O<W1I:V%N<VEO;N1K>6WD<W/D
M+@!.Y'ETY"!A<V5T=7,@<&ETY.1K<V5S:2!A;&MU<&5RY&ES96X`3N1Y=.0@
M=F%L:71S:6X`2^1Y=.0@97-I:V%T<V5L=6$@=F%I;B!L=6ME;6%T=&]M:6EN
M('9I97-T96EH:6XN`$[D>73D(&5S:6MA='-E;'4@=&]O;'1I<',Z96ES<^0N
M`$[D>73D('1A=6QU:VMO=&]I;6EN;F]T('9A;&EK:V\N`$[D>73D('9A<V5M
M;6%L;&$@)7,@=F%L:6MK;RX`3N1Y=.0@(DAA92!V:65S=&ET(BUI:V]N:2!M
M=6ED96X@:6MO;FEE;B!J;W5K;W-S82X`3N1Y=.0@:W5V870`3N1Y=.0@=&%U
M;'5K;VX@<V]L=6X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@=&%U;'5K;VX@=&EE
M9&]T(&1I86QO9VD`3N1Y=.0@=&%U;'5K;VX@<FEV:6X@=&EE9&]T(&1I86QO
M9VD`3N1Y=.0@(E-U;V1A=&EN(BUI:V]N:2!M=6ED96X@:6MO;FEE;B!J;W5K
M;W-S82X`3N1Y=.0@:W5V86X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@=FEE<W1I
M96X@;'5K=6WDY'+D(&MA;G-I;W-S82X`3N1Y=.0@='5O;G1I`%-A=&5I=&$`
M4V%T96ET82!A:6MA:7-I;@!3871E:71A(&UY]FAE;6UI;@!3871E:71A(&SD
M:&5T='EV:6QL80!.Y'ET971T>0!0:65N96YNY`!0:65N96YNY"!T86D@<VEI
M<G+D('9I97)E:7-IY"!O<VEO:71A+"!J;W1T82!N92!E:7;D="!O;&4@=&EE
M;&SD`$MO7VMO`%-I97)R82!,96]N90!+:7)J875D=0!!;&QE:VER:F]I='5S
M`$%L;&5K:7)J;VET=6MS96X@86QG;W)I=&UI`$%L;&5K:7)J;VET971T=0!3
M:6YG87!O<F4`2V]K;P!/:&ET82!Y;&SD<&ET;W1E:'3D=N1T`%-L;W9A:VEA
M`%-L;W9E;FEA`$QU;6D`3'5M:7-A9&5T=&$`3'5M:7-A=&5I=&$`3'5M:7-A
M=&5I=&$@86EK86ES:6X`3'5M:7-A=&5I=&$@;7GV:.3D;@!,=6UE;B!S>79Y
M>7,Z(`!,=6UE;B!MY.1RY"!V971E;N0Z(`!386QO;6]N('-A87)E=`!3;VUA
M;&EA`$QA=6QU="!J82!2=6YO=7,`2N1R:F5S=.0@='5L;V%J86X@;75K86%N
M`$KD<FIE<W3D('#D:7;D;>3D<N1N(&UU:V%A;@!*Y')J97-TY"!LY&AE='3D
M:N1N(&UU:V%A;@!*Y')J97-TY"!V:65S=&EN(&MO;VX@;75K86%N`$KD<FIE
M<W3D(&]T<VEK;VX@;75K86%N`$KD<FIE<W3D(&ME<VMU<W1E;'5SY&EK965N
M(&UU:V%A;@!*Y')J97-TY"!V87-T86%N;W1T86IA;B!M=6MA86X`2N1R:F5S
M='EK<V5N('-U=6YN86X@=F%L:6YT80!,Y&AD96]S;VET90!%=&5LY"U!9G)I
M:VMA`$5T96SD+45U<F]O<'!A("A)4T\M.#@U.2TS*0!%=&5LY"U'96]R9VEA
M(&IA(&5T96SD:7-E="!386YD=VEC:"!S86%R970`171E;.1I;F5N('!A;&QO
M;G!U;VQI<VMO`%;D;&D@=FEE<F5I<V5T('-O;'5J96X@=N1L:7-SY`!6Y&QI
M('-O;'5N(&QE:7#D=&5K<W1I;B!J82!R975N86X@=N1L:7-SY"``5N1L:0!6
MY&QI`%;D;&D@:F$@=.1Y=&4`17-P86YJ80!2;W-K87!O<W1I`%)O<VMA<&]S
M=&EK86YS:6\Z`$5R:6MO:7-M97)K:VEE;B!S>?9T=/8`17)I:V]I<VUE<FMI
M=`!%<FET>6ES:>0@=FER='5A86QI:V%N<VEO:71A(&5I('9O:2!M=6]K871A
M+@!487)K:7-T82!O:6ME:6YK:7)J;VET=7,`3VEK96EN:VER:F]I='5S`$]I
M:V5I;FMI<FIO:71U<R!O;B!T87)K:7-T971T=0!-;VYT86MO(&MI<FIO:71U
M<W9I<FAE='3D(&[D>71E=.3D;B!Y:&1E;'3D('-I=G5L=&$_`$IA82!S;VQU
M`$IA82!S87)A:V4`2F%A(')I=FD`57)H96EL=0!3<FD@3&%N:V$`4W1A;F1A
M<F1I`%-T87(@5')E:P!!;&MA80!!;&MA;6ES=G5O<VD`3.3D;FD@=&%I(&%L
M=64`2VER:F5P;VAJ80!+:7)J97!O:&IA;B!N:6UI.@!+:7)J97!O:&IA;B!T
M>7EP<&D`2VER:F5P;VAJ83H`5&EL80!486QL96YN=7-M=6]T;P!+871U;W-O
M:71E`$SD<&EL>?9N=&D`365R:VMI:F]N;VQI<W1A`%!O:7-T82!L:6ET971I
M961O<W1O`%!O:7-T82!T;VEM:6%L=64@;W-O:71T965S=&$`4&]I<W1A(')I
M=FEN=F%I:&1O="X`5'EY;&D@6T-34UT`<W4`3W1S7VEK:V\`06QI:&%K96UI
M<W1O82`B)7,B(&5I(&SV>71Y;GET+@!/='-I:VMO`$]T<VEK:V]K96YT=.0`
M3.1H973D`$SD:&5T971T:6EN("(E<R(Z;B!L:7/D>7-P>7EN=/8N($5T('9O
M:2!K:7)J875T=6$@<VESY.1N(&5N;F5N(&MU:6X@<'EY;G3V<VD@;VX@:^1S
M:71E;'1Y(&IA(&AY=N1K<WET='DN`%1I;&%A(&MA;G-I;W0`06QI:VER:F]I
M='5S`$]N;FES='5I`"(E<R(Z(&QI<^3D;6EN96X@:N1R:F5S=&5L;>3D;B!O
M;FYI<W1U:2X`2^1Y='3D:N1N("(E<R(@:^1Y='3D:N1T:65T;VIE;B!P;VES
M=&%M:6YE;B!JY')J97-T96QMY'-TY"!O;FYI<W1U:2X`(B5S(B!P;VES=&5T
M=&EI;B!O;FYI<W1U;F5E<W1I+@`B)7,B.B!O;FYI<W1U='1I:6X@<&]I<W1A
M;6%A;B!JY')J97-T96QMY'-TY"X`4&%L871T:6EN(&]N;FES='5N965S=&D@
M=F%N:&]I:&EN(&%S971U:W-I:6XN($QA=&%A('-I=G4@=75D97-T86%N(&[D
M:&3D:W-E<VD@;75U=&]K<V5T+@!486QL96YN971T:6EN(&%S971U:W-I96X@
M=F%R;75U<VMO<&EO+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U
M<VMO<&EO("5S+@`G)7,G.B!PY&EV:71Y<R!O;FYI<W1U:2X`)7,Z;B!K:7)J
M;VET=&%M:6YE;B!O;FYI<W1U:2X`4W5D86X`16AD;W1U:W-E=`!9:'1E96YV
M971O`$%U<FEN9V]N;F]U<W4`075R:6YG;VYL87-K=0!!=7)I;FMO:6YE;@!!
M=7)I;F=O;FYO=7-U`$%U<FEN:V\@;F]U<V5E+VQA<VME90!!=7)I;F=O;FYO
M=7-U.B``075R:6YG;VYL87-K=0!!=7)I;F=O;FQA<VMU.B``4.3D;&QE:VER
M:F]I='5S`%1U:VD`4W5R:6YA;0!3=6MU;FEM:0!(=6EP<'5V=6]R970@:F$@
M2F%N($UA>65N`%-W87II;6%A`%)U;W1S:0!686EH9&$@:VER:F]I='5S=&EL
M86$`5F%I:&1A($A434PM=&EL86%N`%9A:6AD82!T96MS=&ET:6QA86X`4W9E
M:71S:0!3>6YC(&QO:VD@<&]I<W1E='1U`%-Y;F--3`!3>6YT86MS:79I<FAE
M(&AA:W5T97)M96ES<^0`4WEY<FEA+"!A<F%B:71A<V%V86QT80!5:VMO<VUY
M<G-K>0!5:VMO<VUY<G-K>6KD(&IA('1U=6QI<W1A`%5K:V]S;7ER<VMY=`!5
M:VMO<VUY<G-K>6KD(&%I:V%I<VEN`%135BUT:65D;W-T;P!4875L=6MK;P!4
M875L=6MO;B!T:65D;W0`5&%U;'5K;VX@87-E='5K<V5T`%1A=6QU:V]N('1I
M961O=`!486EW86X`5&%I=V%N+"!+:6EN86X@;6%A:W5N=&$`5&%D>FEK:7-T
M86X`5&%N>F%N:6$L(%EH9&ES='EN>70@=&%S879A;'1A`$MO:&1E.@!496AT
MY';D=`!495]K<W1I`%!U:&5L:6YN=6UE<F\`3.1M</9T:6QA(&5D96QL:7-E
M;&QE('1U;FYI;&QE.B``3.1M</9T:6QA`$SD;7#V=&EL83H@`$SD;7#V=&EL
M83QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`$UA;&QI82`B)7,B(&5I
M(&SV>71Y;GET+@!-86QL:65N(&AA;&QI;G1A`$%L=7-T879A<W1I.B``2'EV
MY&MS>2!P>7EN=/8@86QU<W1A=F%S=&D`06QU<W1A=F%S=&D@:'EVY&MS>71T
M>0!497)M<R!O9B!397)V:6-E("UT:65D;W-T;V$@96D@;VQE(&WDY')I=&5L
M='D@8V]N9BYP:'`@=&EE9&]S=&]S<V$`5&5K<W1I`%9A:6X@=&5K<W1I`%1E
M:W-T:6X@=&%S875S`%1E:W-T:71O<`!T;P!4:&%I("A425,M-C(P*0!4:&%I
M;6%A`$944"UL:7/D=&]I;6EN=&\@96D@;VQE(&OD>71E='3D=FES<^0N`%9I
M97-T:6X@3.1H971TY&KD.B!R:79I(&]N(&QI;FMK:3H@`$AI<W1O<GD@:N1R
M:F5S=&5L;>0@96D@;VQE(&OD>71E='3D=FES<^0N`$AO<F1E+TMO;&%B(&EN
M=&5G<F]I;G1I;6]O='1O<FD@96D@='5E("(E<R(`24U!4"UP86QV96QI;B!E
M:2!NY'ETY"!T=6ME=F%N('9A;&ET='5A(&%U=&5N=&EK;VEN=&ET87!A82X@
M3W1A('EH=&5Y='3D(&KD<FIE<W1E;&WD('EL;.1P:71O;VXN`$E-4U`@;&]K
M:6$@96D@=F]I='4@86QU<W1A82X`36%C:6YT;W-H('1I961O<W1O;B!R97-U
M<G-S:6]S:6\`36%C:6YT;W-H('1I961O<W1O;B!R97-U<G-S:6]S:6\@=F]I
M(&QA9&%T82`E<RX@`$UA:6YT96YA;F-E.CH@+6QU;VMA;B!L871A86UI;F5N
M(&5PY&]N;FES='5I`$%S971U:W-E="!I:VMU;F$@;VX@<W5L:F5T='4N(%!O
M:7-T=71A86XN`%/D:&OV<&]S=&ET:6QI("(E<R(@;VX@<&]I<W1E='1U+@!3
MY&AK]G!O<W1I=&EL:2`B)7,B(&]N('1A;&QE=&5T='4N`%EL;.1P:61O;B!P
M:73DY"!O='1A82!KY'ET=/;V;B!P>7-Y=N0@=&%L;&5T=7-T>7EP<&D@4&5R
M;6ES<VEO;BP@:F]S(&AA;'5A="!KY'ET=.3D(&YI:73D+@!,:6ET971I961O
M<W1O82!E:2!L]GET>6YY=`!686EN(&%L87!U;VQI`$5PY&ME;'!O(&MA;&5N
M=&5R:71I971O`$-O;G1A8W0@:60@;G5M97)O82!E:2!O;&4@;>3D<FET96QT
M>2P@;VX@='EH:N0@=&%I(&5I(&SV>71Y;GET('1I971O:V%N;F%S=&$N`%EH
M=&5Y<W1I961O="!L:7/D='1I:6X@;VYN:7-T=6YE97-T:2!O<V]I=&5K:7)J
M86%S:2X`36%C:6YT;W-H('1I961O<W1O;B!S:7/D;'3V(&]N(&%L;&$N`$YY
M:WEI<V5T(&MA;G-I;W0@(B5S(B!N:6UE=.3D;B!U=61E;&QE96X@(B5S(CIK
M<VDN`$5I('9O:71U(&AA:V5A(&QI<W1A82!N:6ES=.0@:^1Y='3D:FES=.0L
M(&IO:6QL82!O;B!O:6ME=7,@=.1HY&X@:V%N<VEO;VXN`%9I97-T:6X@86QL
M96MI<FIO:71U:W-E;B!T87)K:7-T86UI<V5E;B!T87)V:71A86X@97)I;&QI
M;F5N(%!'4"UA;&QE:VER:F]I='5S;&]H:V\N`$IA:V5L=6QI<W1A;B!)1"!E
M:2!O;&QU="!MY.1R:71E;'1Y+"!O;B!T>6AJY"!T86D@96D@;/9Y='EN>70@
M=&EE=&]K86YN87-T82X`2F%K96QU;&ES=&%A(&5I(&]L;'5T(&WDY')I=&5L
M='DN`$QU;VYN;W,@;VX@=&%L;&5T971T=2!K86YS:6]O;B`B)7,B+@!386QA
M=7-T;VEM:6YN;VX@:^1Y='3V('9A871I('-A;&%T='5A(%=75RUY:'1E>71T
MY"X`5&%P86AT=6UA(&QI<^1T=&EI;B!K86QE;G1E<FEI<VDN`$ME;G1TY.0@
M(B5S(B!E:2!V;VD@;&%A:F5N=&%A+@!4:65D;W-T;W-S82`E<R!P:73D:7-I
M(&]L;&$@)7,@87-E='5S+@!4:65D;W-T;W-S82`E<R!P:73D:7-I(&]L;&$@
M:F]I=&%K:6X@)7,@87-E='5K<VEA+@!4:65D;W-T;V$@96D@=F]I9&$@:V]P
M:6]I9&$@:71S96YSY"!PY.1L;&4N`%1I961O<W1O(&]L:2!T>6AJY"X`2V%N
M<VEO("(E<R(@;VX@:F\@;VQE;6%S<V$`2V%N<VEO;B!N:6UE<W/D("(E<R(@
M;VX@:VEE;&QE='1Y:N0@:VER:F%I;6EA+B!.Y&WD(&MI<FIA:6UE="!V;VEV
M870@86EH975T=&%A(&]N9V5L;6EA+B!/=&$@>6AT97ET=.0@:N1R:F5S=&5L
M;>1N('EL;.1P:73D:N3D;BX`2V%N<VEO("(E<R(@;VX@;'5O='4L(&UU='1A
M(&5T(&]L92!V:65LY"!T:6QA;FYU="!S:73D+@!+86YS:6\@(B5S(B!O;B!P
M;VES=&5T='4@;75T=&$@<V5N('1I;&%U<W1A(&5I(&QO<&5T971T=2X`2V%N
M<VEO=&$@(B5S(B!E:2!V;VET=2!L=6]D82X@4&%L=F5L:6UE;B!V:7)H96EL
M;6]I='5S(&]L:0!+86YS:6]T82`B)7,B(&5I('!O:7-T971T=2X@4&%L=F5L
M:6UE;B!V:7)H96EL;6]I='5S(&]L:0!+86YS:6\@(B5S(B!O;B!L=6]T=2X`
M2V%N<VEO("(E<R(@;VX@<&]I<W1E='1U+@!+86YS:6\@(B5S(B!O;B!N:6UE
M='1Y("(E<R(Z:W-I+@!3975R86%V87-S82!O;B!O='-I:VMO=&EE9&]T('3D
M<W3D(&UE<W-A9V4O<F9C.#(R("UV:65S=&ES=.0N`%3D:.1N(&]S:6]O;B!O
M;B!L:6ET971T>2!L:6ET971I961O<W1O=#H`2V]K;W)U=61U;B!NY'ET=/9T
M:6QA(&%I:&5U='1A82!O;F=E;&UI82!J;VEL;&%K:6X@26YT97)N970@17AP
M;&]R97(@<V5L86EM96X@:^1Y='3D:FEL;.0N(%9A;&ET971T879A<W1I(&MY
M<V5I;F5N('-E;&%I;B!S:7/D;'3DY"!P:6ER=&5I=.0@:F$@=FER:&5I=.0@
M:F]I:&EN(&5I(&]L92!L]GET>6YY="!K;W)J875S=&$@=&%I(&ME:6YO82!K
M:65R=.3D(&]N9V5L;6$N($AU;VUA871H86X@971TY"!J;W,@:^1Y=.1T('3D
M=.0@;N1Y='3V=&EL86$@:F$@26YT97)N970@17AP;&]R97(@<V5L86EN=&$L
M(&YI:6X@;N1Y='3V('-A871T86$@;65N;N0@<V5K86ES:6XL(&IO=&MU="!T
M;VEM:6YN;W0@96EVY'0@=&]I;6D@=&%I('-E;&%I;B!S86%T=&%A(&MA871U
M82X@2F]S(&OD>73D="!7:6YD;W=S(#EX('1A:2!-12!V97)S:6]T82P@;FEI
M;B!O;B!M86AD;VQL:7-T82!E='3D(&OD>71T]FKD<FIE<W1E;&WD(&MA871U
M=2!N<RX@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@+79I<FAE97-E96X@
M:F$@<VEN=6X@<&ETY.0@:^1Y;FYI<W3DY"!K;VYE('5U9&5S=&%A;BY<;EQN
M($UU:7-T82!E='3D('-I;G5A(&]N('9A<F]I=&5T='4N($YA<'-A=71A($]+
M+6YA<'!U;&%A(&IO<R!H86QU870@:V]K96EL;&4@961I=&]R:6X@:V]K;W)U
M=71U(&[D>71T]G1I;&%A+@!0;VES=&5T=&EI;B!P<F]F:6EL:2`B)7,B+@!6
M:65S=&EN:VER:F]I='5S:6MK=6YA82!E:2!V;VET=2!A=F%T82X@3VQE=&MO
M(&UA:&1O;&QI<V5S=&D@:VEE;'3D;GET('-E;&%I;G1A<VD@875K86ES96UA
M<W1A('!O;FYA:&1U<VEK:W5N;VET83\`2W5V870@;N1Y=&5TY.1N(&MO<VMA
M('9I97-T:6X@;.1H971TY&KD;B!O<V]I=&4@;VX@;W-O:71E:VER:F%S<V%S
M:2X`5F%I;B!V87-E;B!P=6]L:0!';G501R!O:&IE;&UA;B!S:6IA:6YT:2!P
M:73DY"!MY.1R:71E;&SD($-R>7!T7W!G<#HZ("UL=6]K87-S82X`4&]S=&EP
M86QV96QI;65L=&$@='5L:2!V:7)H979I97-T:3H`4&]S=&EP86QV96QI;65L
M=&$@='5L:2!T:65D;W1E=FEE<W1I.@!0;W-T:7!A;'9E;&EM96QT82!T=6QI
M('9I97-T:3H`4&]S=&EK86YS:6\@)7,@;VX@:F\@='EH:N0N`%9I97-T:2`B
M)7,B(&SD:&5T=.1JY&[D("(E<R(@*"5D('1A=G5A*2!Y;&ET=.3D(&AA971T
M879A;B!V:65S=&EN('-U=7)I;6UA;B!S86QL:71U;B!K;V]N+@!+:7)J;VET
M=&%M87-I('9I97-T:2!O;B!S=6QJ971T=2X@(%!O:7-T=71A86XN`%9I97-T
M:7-SY"!E:2!O;&4@;W1S:6MK;V$N`%9I97-T:2!O;B!P;VES=&5T='4N`%9I
M97-T:2!O;B!T87)K87-T971T=2X`5FEE<W1I(&]N('1A<FMA<W1E='1U+B!,
MY&AE='3D:N0Z("5S+@!6:65S=&D@;.1H971E='1Y("5S('9A<W1A86YO='1A
M:F%L;&4@)7,@;W1S:6MK;VYA("(E<R(@;VX@;N1Y=&5T='DN"D5I(&]L92!M
M:73DY&X@=&%K96ET82!S:6ETY"!E='3D('9I97-T:2!O;B!L=65T='4@=&%I
M('EM;>1R<F5T='DN`$YI;6D@:F]T82!KY'ET973DY&X@;&EN:VET971TY&5S
M<V$@;'5O('-I=G5L;&4`2V5N='1I96X@;>3D<N0@<&ETY.0@86YT86$@;G5M
M97)O:6YA+@!-;V1U=6QI(&]P96YS<VP@=&%R=FET86%N($AO<F1E7T-R>7!T
M7W-M:6UE.CH@+6QU;VMA;B!KY'ET=.1M:7-E:W-I+@!!<V5T=7-T82`B)7,B
M(&MO<VMA('-E;B!T:65D;W0@>6QI='1I=N1T('1A;&QE='5S=&%V86X@<W5U
M<FEM;6%N('-A;&QI='5N(')A:F%N`$]H:F5L;6%A+"!J;VQL82!V;VD@:V%T
M<V]A('9I97-T:71Y>7!P:>0@*"5S*2P@96D@;/9Y='EN>70@:N1R:F5S=&5L
M;>1S=.0N`$QA:6YA=7-M97)K:VD@<&ETY.0@;VQL82!Y:W-I='3D:6YE;B!M
M97)K:VDN`$QU:V5A:W-E<VD@:G5L:VES96X@4$=0+6%V86EM96X@=&5K<W1I
M;B!R86%K86UU;V1O<W-A("5S+@!686QI='1U82!T:65D;W-T;V$@96D@;VQL
M=70@35,M5$Y%1B!L:6ET971I961O<W1O<W-A+@!686QI='1U82!T:65D;W-T
M;V$@96D@;VQL=70@6FEP+71I961O<W1O<W-A+@!686EN(&]I:V5A(&IA('9A
M<V5N('!U;VQI`%9A:6X@;VEK96$@<'5O;&D`5.1MY&X@=FEE<W1I;B!LY&AE
M='3D:N0@<'EY=.3D($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M("A-1$XI(&EL;6]I='5S=FEE<W1IY"!K=6X@;VQE="!L=6ME;G5T('3D;>1N
M('9I97-T:6XN($YA<'-A=71A("5S(&SD:&5T=.3D:W-E<VD@=.1MY&X@:6QM
M;VET=7-V:65S=&EN+@!%<F]T:6X@<&ETY.0@;VQL82!Y:W-I='3D:6YE;B!M
M97)K:VDN`%!A;'9E;&EN("(E<R(@;VX@<&]I<W1E='1U+@!086QV96QI;B`B
M)7,B(&]N('1A;&QE=&5T='4N`%!A;'9E;&EN(&5I('9O:6YU="!L=6]D82!P
M:6MK=6MU=F%A('3D<W3D(&MU=F%S=&$N`$%L;&5K:7)J;VET=7-T82!E:2!V
M;VET=2!K;W)V871A+@!!;&QE:VER:F]I='5S(&]N(&MO<G9A='1U('5U9&5L
M;&$N`%-I<^3D;FMI<FIA=71U;6ES<'EY;G3V("5S(&]N('!O:7-T971T=2X`
M5F%L:71T=6$@=&EE9&]S=&]A(&5I(&]L92!O;&5M87-S82X`3>3D<FET96QT
M>>0@<FEV:>0@*"5D*2!E:2!O;&4@;VQE;6%S<V$N`$MI<FIE<&]H:F$@(B5S
M(B!O;B!L:7/D='1Y+@!+:7)J97!O:&IA("(E<R(@;VX@<&]I<W1E='1U+@!+
M:7)J97!O:&IA("(E<R(@;VX@<.1I=FET971T>2X`5&5H=.1VY"!O;B!L:7/D
M='1Y('1E:'3D=N1L:7-T86%S:2X`5F%L:>1A:6MA:7-T:65D;W-T;V$@(B5S
M(B!E:2!O;&4@;VQE;6%S<V$N`%9I97-T:6X@=&5K<W1I`%9O:70@:V%T<V]A
M('9I97-T:6X@=&5K<W1I;B`E<RX`4&%L875T971U;B!V:65S=&EN('1E:W-T
M:2X`5F]I="!K871S;V$@<&%L875T971U;B!V:65S=&EN('1E:W-T:6X@)7,N
M`$SD:&5T971Y;B!V:65S=&ET('1E:W-T:0!6;VET(&MA='-O82!LY&AE=&5T
M>6X@=FEE<W1I;B!T96MS=&EN("5S+@!+:7)J;VET=&%M87-I('1E:W-T:2!E
M:2!V87-T86$@=&5K<W1IY"!R=75D=6QL82X`5F%I;B!Y;.1P=6]L:2!J82!A
M;&%P=6]L:0!686EN('ELY'!U;VQI`%1U;W1U('1I971O(&CD=FES:2!E9&5L
M;&ES96X@:V]H9&%N(&%I:V%N82X`5'5O='5A('1I961O<W1O82!E:2!V;VET
M=2!T86QL971T86$N`$OD>71TY&KD;B!V87!A82]V87)A='1U('1I971O:F5N
M('1A;&QE='5S(&]N;FES='5I+@!/<VEO=&$@=V5A=&AE<BYC;VT@96D@;VQE
M(&OD>71E='3D=FES<^0N`%1E96UA:&%K96UI<W1O82`B)7,B(&5I(&SV>71Y
M;GET+@!%:2!O;&4@=F%I:'1O96AT;VES:6$@;W-I82P@:F]T:V$@=F]I9&%A
M;B!NY'ET=.3D('9I97-T:65N('EH=&5Y9&5S<^0N`%3D<W/D(&MA;G-I;W-S
M82!E:2!O;&4@=FEE<W1E:N0N`$%S971U:W-I82!E:2!O;&4@<V%A=&%V:6QL
M82X`16D@;VQE(&]S:6]I=&$L(&IO=&MA('9O:61A86X@;N1Y='3DY"!V:65S
M=&EE;B!Y:'1E>61E<W/D+@!4Y'-SY"!K96YTY'-SY"!O;B!L:6EA;B!M;VYT
M82!M97)K:VGD+B!!;FYO:70@)7,@;65R:VMIY#L@<VEN=6X@<&ETY.0@86YT
M86$@=N1H96UMY&X@:W5I;B`E<R!M97)K:VGD+@!%:2!O;&4@=&5K<W1IY"P@
M:F]K82!V;VED86%N(&[D>71TY.0@=FEE<W1I96X@>6AT97ED97-SY"X`2F]I
M=&%K:6X@;VYG96QM:6$@(B5S(B!L:7/DY&UI<V5S<^0@:N1R:F5S=&5L;>3D
M;CH@)7,`2^1Y='3D:N1N("(E<R(@:^1Y='3D:N1T:65T;VIE;B!P;VES=&%M
M:7-E<W-A(&KD<FIE<W1E;&WD<W/D(&]L:2!O;F=E;&UI83H@`$MA;G-I;VX@
M='EH:F5N=.1M:7-E<W/D(&]L:2!O;F=E;&UI82X@4&%L=F5L:6UE;B!V:7)H
M96EL;6]I='5S(&]L:3H@)7,`2F]I=&%K:6X@;VYG96QM:6$@(B5S(B!P;VES
M=&%M:7-E<W-A(&KD<FIE<W1E;&WD<W3D.B``2F]I=&%K:6X@;VYG96QM:6$@
M(B5S(B!PY&EV:71Y:W-E<W/D.B`E<P!4:65D;W-T;VX@='5O;FYI<W-A(&]L
M:2!O;F=E;&UI82X@66ATY.1N("5S.F$@96D@='5O='4`5&EE9&]S=&]N('1U
M;VYN:7-S82!O;&D@;VYG96QM:6$N("5S(&MO:V\@;VQI('-U=7)E;7!I(&MU
M:6X@<W5U<FEN('-A;&QI='1U(&MO:V\@*"5D('1A=G5A*2X`5&EE9&]S=&]N
M('1U;VYN:7-S82!O;&D@;VYG96QM:6$N("5S(&QA=&%U='5I('9A:6X@;W-A
M:W-I+@!487!A:'1U:2!V:7)H92!K;W!I;VED97-S82!V:65S=&5JY"!K86YS
M:6]S=&$@(B5S(B!K86YS:6]O;B`B)7,B+B!086QV96QI;65N('9I<FAE:6QM
M;VET=7,@;VQI`%1A<&%H='5I('9I<FAE('!O:7-T971T865S<V$@=FEE<W1E
M:N0@:V%N<VEO<W1A("(E<R(N(%!A;'9E;&EM96X@=FER:&5I;&UO:71U<R!O
M;&D`5&%P86AT=6D@=FER:&4@<&]I<W1E='1A97-S82!V:65S=&5JY"!K86YS
M:6]S<V$@(B5S(BX@4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L:0!487!A
M:'1U:2!V:7)H92!P;VES=&5T=&%E<W-A('9I97-T96KD+B!086QV96QI;65N
M('9I<FAE:6QM;VET=7,@;VQI.B`E<P!487!A:'1U:2!V:7)H92!P;VES=&5T
M=&%E<W-A('1A<&%H='5M86$Z("5S`%1A<&%H='5I('9I<FAE(&[D>71E='3D
M97-SY"!V:65S=&EN('3D=.0@;W-I;W1A`%1A<&%H='5I(&IO:VEN('9I<FAE
M(&%S971E='1A97-S82!M97)K:VEL:7!P=6IA(&MA;G-I;VX@(B5S(B!V:65S
M=&5I:&EN+B!086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI`%1A<&%H='5I
M(&IO:VEN('9I<FAE('1U;W1A97-S82!LY&AT965S=.0@)7,N`%EH=&5Y<W1I
M971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`5&%P86AT=6D@=FER
M:&4@='5O=&%E<W-A('1A<&%H='5M86$Z("5S+@!I0V%L96YD87(M=&EE=&]J
M96X@='5O;FYI<W-A('1A<&%H='5I('9I<FAE+@!487!A:'1U:2!V:7)H92!T
M=6]T865S<V$@=.1TY"!T96ATY';DY#H@)7,N`$OD>71TY&KD;B!V87!A82]V
M87)A='1U('1I971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H93H@)7,N
M`$%S971U<W1I971O;&]M86MK965S<V$@;VX@:F]K:6X@=FER:&4N($5H:^0@
M:N1T:70@:F]N:W5N('!A:V]L;&ES96X@:V]H9&%N('3D>71TY&WD='3D+@!4
M87!A:'1U:2!J;VMI;B!V:7)H92!S:6ER971TY&5S<^0@=FEE<W1E:N0@:V%N
M<VEO<W1A("(E<R(@:V%N<VEO;VX@(B5S(BX@4&%L=F5L:6UE;B!V:7)H96EL
M;6]I='5S(&]L:0!487!A:'1U:2!V:7)H92!Y<FET971TY&5S<^0@<W5O<FET
M=&%A(&]S;VET96MI<FIA=&]I;6EN=&]A+B!9<FETY"!M>?9H96UM:6X@=75D
M97-T86%N+@!487!A:'1U:2!J;VMI;B!V:7)H92!L=6]N;F]S=FEE<W1IY"!T
M86QL971T865S<V$N`%1A<&%H='5I('9I<FAE(&SD:&5T971TY&5S<^0@=FEE
M<W1IY'-I.B`E<P!9:'1E>7-T:65T;VIE;B!PY&EV:71Y:W-E<W/D('1A<&%H
M='5I('9I<FAE+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N+@!*86ME;'5L
M:7-T86X@<.1I=FET>6MS97-SY"!T87!A:'1U:2!V:7)H92X@67)I=.0@;7GV
M:&5M;6EN('5U9&5S=&%A;BX`5&%P86AT=6D@=FER:&4@<.1I=FET971TY&5S
M<^0@=&%P86AT=6UA83H@)7,`5.1S<^0@2%1-3"UV:65S=&ES<^0@;VX@:W5V
M:6$@=7!O=&5T='5I;F$N`%3D<W/D($A434PM=FEE<W1I<W/D(&]N(&MU=FEA
M('5P;W1E='1U:6YA+B!%<W1E=&5T>70@:W5V870@;N1Y='3D=N1T('3D;>1N
M;&%I<VEN83H@`%3D;>0@24U!4"!P86QV96QI;B!E:2!T=64@:V%N<VEO:61E
M;B!J86MA;6ES=&$N`%3D;>0@:G5L:VEN96X@4$=0+6%V86EN(&]L:2!L:6ET
M971T>2!V:65S=&EI;BX`5.1MY"!T;VEM:6YT;R!E:2!O;&4@='5E='1U+@!4
MY&WD('1O:6UI;G1O(&5I(&]L92!V:65LY"!T;W1E=71E='1U+@!4Y&WD('1I
M961O<W1O(&5I('9A:6MU=&$@<F%R+71I961O<W1O;'1A+@!4Y&WD('1I961O
M<W1O(&5I('9A:6MU=&$@>FEP+71I961O<W1O;'1A+@!4Y&WD(&5I('9A:6MU
M=&$@;VEK96%L=&$@:V]R='1I;G5M97)O;'1A+@!4Y&QLY"!A:G5R:6QL82!V
M;VD@;.1H971TY.0@=FEE<W1E:N0@0VQI8VMA=&5L;&EN("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87D@<&%L=F5L=6$@2%144"!!4$DZ;&QA+@!4
MY&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@9V%T97=A>2!P86QV96QU;B!K875T=&$@2%144"!!
M4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@
M<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2!P86QV
M96QU;B!K875T=&$@2%144"!!4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@
M;.1H971TY.0@=FEE<W1E:N0@5F]D869O;F5N(&YU;65R;VEH:6X@4TU44#IL
M;.0@:^1Y='3D96X@5F]D869O;F4@271A;'D@9V%T97=A>2!P86QV96QU82X@
M5.1TY"!P86QV96QU82!V;VD@:^1Y='3DY"!V86EN(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="D@='5N;G5K<VEL;&$N`%3D;>0@:V5N='3D
M(&]N('!A:V]L;&EN96XN`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@=F%I
M;B!K;VMO;F%I<VQU:W5J82X`5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!N
M=6UE<F]I=&$@:F$@<&EL:VMU+6UE<FMK96KD+@!4Y'-SY"!K96YTY'-SY"!P
M:73DY"!O;&QA(&]K=&%A;&EL=6MU:F$N`%3D<W/D(&ME;G3D<W/D('!I=.3D
M(&]L;&$@;&ES=&$@:V]K;VYA:7-L=6MU:F$L(&IO=&MA('!I=.3D(&]L;&$@
M97)O=&5T='4@<&EL:W5L;&$@=&%I(';D;&EL>?9N;FEL;.0`07)V;VX@<&ET
MY.0@;VQL82!N=6UE<F\N`%3D<W/D(&ME;G3D<W/D(&]N(';D<FEMY.1R:71Y
M<RP@:F]N:V$@<&ETY.0@;VQL82!21T(@2&5X(&UU;V1O<W,L(&5S:6UE<FMI
M:W-I("<C,3(S-&%F)RX`5.1MY"!L;VUA:V4@;VX@:F\@:^1S:71E;'1Y+@!4
MY&WD(&]N("5S+@!4Y&WD(&]N($MO;&%B($=R;W5P=V%R92!O8FIE:W1I+B!+
M871S;V%K<V5S:2!TY&WD;B!O8FIE:W1I;B!S:6YU;&QA('!I=.3D(&]L;&$@
M<^1H:_9P;W-T:6]H:F5L;6$L(&IO:V$@>6UMY')TY.0@2V]L86(@1W)O=7!W
M87)E(&9O<FUA871T:6$N($QI<W1A('EH=&5E;G-O<&EV:7-T82!SY&AK]G!O
M<W1I;VAJ96QM:7-T82!L]GET>7D@;W-O:71T965S=&$@)7,`5.1MY"!V;VD@
M:V5S=.3D(&IO;FMI;B!A:6MA82X@3VQE=&MO(&%I=F%N('9A<FUA/P!4Y&WD
M('9I97-T:2!S:7/D;'3DY"!-86-I;G1O<V@@=&EE9&]S=&]N+@!4Y'-SY"!V
M:65S=&ES<^0@;VX@;&EI=&5T:65D;W-T;RP@:F]K82!O;B!D:6=I=&%A;&ES
M97-T:2!A;&QE<FMI<FIO:71E='1U(%,O34E-13IL;.0N`%3D<W/D('9I97-T
M:7-SY"!O;B!L:6ET971I961O<W1O+"!J;VMA(&]N('-A;&%T='4@:^1Y='3D
M96X@4R]-24U%.N0N`%3D;>0@=FEE<W1I('-I<^1L=.3D('9I97-T:6X@<&5R
M:6QL96UE;F]O;B!L:6ET='EVY.0@=&EE=&]A+"!M=71T82!V:65S=&EN(&UU
M;W1O(&]N('1U;G1E;6%T;VXN`%3D;>0@=FEE<W1I(&5I('9A:6MU=&$@4$=0
M+7-A;&%T=6QT82!V:65S=&EL=.0N(%9I<FAE:6QM;VET=7,Z(`!4Y&WD('9I
M97-T:2!E:2!NY'ETY"!O;&5V86X@;VEK96%S<V$@4$=0+6UU;V1O<W-A("AM
M=6]T;R!O;B!MY.1R:71E;'1Y(%)&0R`R,#$U(&1O:W5M96YT:7-S82DN`%3D
M;>0@=FEE<W1I(&5I(&[D>73D(&]L979A;B!O:6ME87-S82!3+TU)344M;75O
M9&]S<V$N`%3D;>0@;VX@4$=0.FQLY"!D:6=I=&%A;&ES97-T:2!A;&QE:VER
M:F]I=&5T='4@=FEE<W1I+@!4Y&WD(&]N(%,O34E-13IL;.0@9&EG:71A86QI
M<V5S=&D@86QL96MI<FIO:71E='1U('9I97-T:2X`5.1MY"!3+TU)344Z;&SD
M('-A;&%T='4@=FEE<W1I+@!4Y&WD(%!'4#IL;.0@<V%L871T=2!V:65S=&DN
M`%3D;>0@=FEE<W1I(&MA;G-I;V]N`%3D;>0@=FEE<W1I(&]N(&MI<FIO:71E
M='1U(&5R:2!M97)K:7-T]FQLY"`H)7,I(&MU:6X@;6EKY"!S:6YU;&QA(&]N
M(&OD>73V<W/D+B``3G5M97)O;B!P:73DY"!O;&QA(';D:&EN=.3D;B!Y:W-I
M+@!4Y&QLY"!P86QV96QI;65L;&$@96D@=F]I(&%U:V%I<W1A('II<"T@=&%I
M(&=Z:7`M=&EE9&]S=&]J82X`5.1MY"!P86QV96QI;B!E:2!T=64@:V%N<VEO
M:61E;B!J86MA;6ES=&$N`%3D;>0@:N1R:F5S=&5L;>0@;VX@<&]I<R!PY.1L
M=.0N`$%R=F]N('!I=.3D(&]L;&$@;G5M97)O+@!4Y&WD;B!I:VMU;F%N('9O
M:2!A=6MA:7-T82!V86EN('9I97-T:6YK:7)J;VET=7-I:VMU;F%S=&$`5.1M
MY&X@:6MK=6YA;B!V;VD@875K86ES=&$@=F%I;B!!<V5T=6MS970@:6MK=6YA
M<W1A`$ME<VMU<W1E;'5SY&EE;N1K>6WD`$ME<VMU<W1E;'5SY&EK96ET=.1I
M;@!->7)S:WD`5&EK971I=`!!:6MA`$%J86YS975R86YT80!!:F%N(&5S:71Y
M<VUU;W1O`$%J86X@=F%L:6YT80!4:6UO<BU,97-T90!4:71T96QI`$]T<VEK
M:V\@*'1O;VQT:7`I.@!687-T86%N;W1T86IA`%9A<W1A86YO='1A:F%N(&]S
M;VET90!6;VED86MS97-I('9A;&ET82!U<V5A;7!I82!V86EH=&]E:'1O:F$L
M('!I9.0@<&]H:F%S<V$@0V]N=')O;"]/<'1I;VX@+6[D<'#D:6YTY"!K=6X@
M;F%P<V%U=&%T(&AI:7)E;B!P86EN:6ME='1A+@!6;VED86MS97-I('9A;&ET
M82!U<V5A;7!I82!V86EH=&]E:'1O:F$L('!I9.0@0V]N=')O;"T@*%!#*2!T
M86D@0V]M;6%N9"T@*$UA8RD@;N1P<.1I;G3D('!O:&IA<W-A(&MU;B!N87!S
M875T870@:&EI<F5N('!A:6YI:V5T=&$N`$OD>71TY.1K<V5S:2!43%,M>6AT
M97ET=.0@<VEN=6QL82!P:73DY"!O;&QA(&OD>73V<W/D(%!(4"!V97)S:6\@
M-2XQ+C`@=&%I('-I=.0@=75D96UP:2X`5.1NY.1N`$[D>73D($A434PM;.1H
M9&5K;V]D:0!4;V=O`%1O:V5L874`2'5O;65N;F$`5&]N9V$`3&EI86X@;6]N
M=&$@97#D;VYN:7-T=6YU='1A(&MI<FIA=71U;6ES>7)I='ES=.0@=FEI;65I
M<VEM<&EE;B!M:6YU=71T:65N(&MU;'5E<W-A+@!9;/9S`%EL:6UPY.1N(&ME
M:'EK<V5E;B`H7W1O<"D`3&EI=&5T:65D;W-T;VIE;B!K;VMO('EH=&5E;G/D
M.@!+Y.1N;O9K<V5T`%)O<VMA:V]R:6MA;G-I;P!2;W-K86MO<FEK86YS:6\Z
M`%1R:6YI9&%D(&IA(%1O8F%G;P!4;W-I('9A:2!E<.1T;W-I`'1I`%1U;FES
M:6$`5'5R:VMI`%1U<FMK:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U
M<FMS(&IA($-A:6-O<R!S86%R970`5'5V86QU`$MI<FIO:71A('9A;&EN=&%S
M:3H@`%4N5BX@+6EN9&5K<VDZ(`!54DP`55),(&IO:&]N('!A;&%U=&5T86%N
M('-K<FEP=&EN('-T871U<R!R87!O<G1T:0!54DPZ`%5G86YD80!5:W)A:6YA
M`%9&4RUH86ME;6ES=&]A(&5I('9O:71U(&QU:V5A+@!+Y'ET=.1JY&X@;&ES
MY'1I971O:F5N(&QI<^1Y<R!E:2!O;FYI<W1U;G5T(&MI<FIA=71U;6ES97-S
M82X`16D@=F]I('9A:6AT86$@;VEK975K<VEA(%9&4RUT:65D;W-T;VQL92`B
M)7,B+@!%:2!V;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE
M("5S+R5S+@!%:2!V;VED82!V86EH=&%A("5S.FXN`%1I961O<W1O;B`B)7,B
M(&MO:V]A(&5I('9O:71U('1A<FMI<W1A82X`16D@=F]I9&$@;FEM973D('5U
M9&5L;&5E;B!61E,M=&EE9&]S=&]A("(E<R\E<R(N`%-13"UP86QV96QI;65E
M;B!E:2!S86%D82!Y:'1E>71TY"X`66AT97ET=.0@96D@=F]I9&$@;75O9&]S
M=&%A(%-33"US86QA='1U;F$N`%9&4RUT:65D;W-T;V$@96D@=F]I9&$@:V]P
M:6]I9&$N`$5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A("(E<R(N`$5I
M('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A+@!%:2!V;VET=2!L=6]D82!6
M1E,M=&EE9&]S=&]A`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+6MA
M;G-I;W1A("(E<R(N`$5I('9O:71U(&QU;V1A('1Y:&KDY"!61E,M=&EE9&]S
M=&]A+@!4:65T;V$@96D@=F]I9&$@;&%A:F5N=&%A+@!%:2!V;VED82!P;VES
M=&%A("(E<R(L(&AA:V5M:7-T;R!E:2!O;&4@='EH:N0N`$5I('9O:61A('!O
M:7-T86$@(B5S(CH@)7,N`$5I('9O:61A('!O:7-T86$@)7,L(&AA:V5M:7-T
M;R!E:2!O;&4@='EH:N0N`$5I('9O:61A('!O:7-T86$@5D93+6AA:V5M:7-T
M;V$@<F5K=7)S:6EV:7-E<W1I+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME
M;6ES=&]A+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A.B`E<RX`
M16D@=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A
M('!O:7-T86$@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M
M:V%N<VEO=&$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82!61E,ZY.0@<F5K=7)S
M:6EV:7-E<W1I.B`E<RX`3GEK>6ES=.0@:&%K96UI<W1O82!E:2!V;VET=2!S
M96QV:71TY.0N`%9A<FUE;G1E96X@=&EE=&]J82!E:2!V;VED82!E>'1R86MT
M;VED80!-Y.1R:71Y:W-E;B`E<R!L=6ME;6EN96X@97#D;VYN:7-T=6DN`$5I
M('9O:61A('-I:7)TY.0@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A
M82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&%V871A(%9&4RUT:65D
M;W-T;V$@:VER:F]I='5S=&$@=F%R=&5N+@!%:2!V;VED82!A=F%T82!61E,M
M=&EE9&]S=&]A+@!4:6EV:7-T971Y;B!T:65D;W-T;VX@875K86ES=2!E<.1O
M;FYI<W1U:2X`16D@=F]I='4@;'5K96$@5D93+71I961O<W1O82`H9FEL97-I
M>F4H*2!E<.1O;FYI<W1U:2DN`$5I('9O:61A(&QU:V5A(%9&4RUT:65D;W-T
M;V$@*&=E=$9I;&53:7IE*"D@97#D;VYN:7-T=6DI+@!%:2!V;VET=2!L=6ME
M82!T:65D;W-T;V$Z(`!V9G-R;V]T(&IU=7)I:&%K96UI<W1O82!E:2!V;VET
M=2!L=6ME82X`575D96QL965N;FEM9>1M:6YE;B`E<R`E<SIK<VD@97#D;VYN
M:7-T=6D@:V]S:V$@:V]H9&5H86ME;6ES=&\@;VX@:F\@;VQE;6%S<V$`16D@
M=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O82X`16D@=F]I
M9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O83H@)7,N`$5I('9O
M:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82`B)7,B+@!%:2!V
M;VED82!N:6UE=.0@=75D96QL965N(%9&4RUT:65D;W-T;V$@)7,O)7,N`$5I
M('9O:71U(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82X`4&]S=&EK
M:6EN=&GV=&EE=&]J82!E:2!V;VET=2!H86ME82X`16D@=F]I9&$@<W5O<FET
M=&%A(&MO;65N=&]A("=M:VES;V9S)RX`5V]R9"UD;VMU;65N='1I82!E:2!V
M;VET=2!KY.1N=.3D`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O<W1O
M82`B)7,B+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T;V]N("AC
M;W!Y*"D@97#D;VYN:7-T=6DI+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT
M:65D;W-T;VX@=&EE=&]J82X`16D@=F]I9&$@:VER:F]I='1A82!61E,M=&EE
M9&]S=&]A+"!K:6EN=&GV(&]N('3D>6YNY"X`5F%S=&%A;6%T;VX`5F%S=&%A
M;6%T=&]M870@=FEE<W1I=`!086QA=71A`$%L;&5V:6EV871T=0!386QA='5I
M;&QE('9A<W1A86YO='1A:FEL;&4`4&5R=2!M=75T;VMS970`4&5R=75T=&%A
M(&5D96QL:7-E;B!T;VEM96YP:71E96X`5'5N=&5M871O;B!V87-T875S('!A
M;'9E;&EM96QT82!Y:'1E>71E96XZ`%!A;'9E;&EN(&SD:&5T=&D@;V1O='1A
M;6%T=&]M86X@=F%S=&%U:W-E;B!!551(14Y424-!5$4@:V]M96YT;V]N+@!0
M86QV96QI;B!LY&AE='1I(&]D;W1T86UA='1O;6%N($1I9V5S="U-1#4@=F%S
M=&%U:W-E;BX`4&%L=F5L:6X@;.1H971T:2!O9&]T=&%M871T;VUA;B!V87-T
M875K<V5N($Q/1TE.(&MO;65N=&]O;BX`5'5N=&5M871O;B!V87-T875S('!A
M;'9E;&EM96QT83H@`$QU;VMI='1E;&5M871O;@!+;VUP;VYE;G1T:71Y>7!I
M;&QE(&5I(&]L92!KY'-I='1E;&EJY.0Z("5S`%5N:6-O9&4@*%541BTX*0!9
M:&1I<W1Y;F5E="!A<F%B:65M:7)A871I=`!9:&1I<W1Y;F5E="!K=6YI;F=A
M<VMU;FYA=`!9:&1Y<W9A;&QA=`!9:&1Y<W9A;'1O:F5N(%1Y>6YE;FUE<F5N
M(&5R:6QL:7-S86%R970`36ET=&%Y:W-I:_9T`%1U;G1E;6%T;VX`5'5N=&5M
M871O;B!PY&EVY&WDY'+D`%1U;G1E;6%T;VX@=F%S=&%U<R!)34%0+7!A;'9E
M;&EM96QT82X@4&%L=F5L:6UE;B!I;&UO:71U<R!O;&DZ("5S`%1U;G1E;6%T
M;VX@=&%P86%M:6YE;@!4=6YT96UA=&]N('9A<W1A86YO='1A:F$`5'5N=&5M
M871O;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!4=6YT96UA=&]N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$%N;F5T='4@<&%I:VMA=&EE
M=&\@;VX@='5N=&5M871O;BX`5'5N=&5M871O;B!KY'ET=.1JY'1U;FYU<R!T
M86D@<V%L87-A;F$N`%!O:7-T82!N>6MY:7-E;B!E;&5M96YT:6X@;&EN:VET
M>7,`4&]I<W1A('-A;&%S86YA=&5K<W1I`$YI;65T]FX`5&EE=&]T=7)V87-Y
M:7-TY"!E:2UP<FEV:6QE96=I<V5T('-K<FEP=&ET(&5I=N1T('9O:2!K=71S
M=6$@3&5I:VMA82]+;W!I;VDO3&EI=.0@=&]I;6EN=&]J82X@3F%P<V%U=&$@
M3TLM;F%P<'5L86$@;N1H9.1K<V5S:2!M;WII;&QA+F]R9R!S:79U:6QL82!O
M;&5V86X@;VAJ965N+"!J;W-S82!N975V;W1A86X@;6ET96X@<VMR:7!T:7-I
M('9O:79A="!KY'ET=.3D(&QE:6ME</9Y=.3D+@!5=7-I`%!O:7-T82!VY')I
M`$QO<&5T82!K86YS:6]I9&5N('1I;&%U<P!%:2UT=65T='4@;&%A:F5N;G5S
M`%#D:79I=.0`4.1I=FETY"`E<P!0Y&EV:73D('9A<W1A86IA;B!T:6QA=&EE
M9&]T`%#D:79I=.0@:^1Y='3D:N0`4.1I=FET971T:6EN("(E<R(N`%#D:79I
M='ES<VMR:7!T:2!P;VES=&5T=&EI;BX`5'5O`'1U;R!K86EK:VD@;VAJ96QM
M:65N(&%S96YN=7-T:65D;W-T;W0@<&%L=F5L:6UE;&QE+@!)<V]T(&QA=&EN
M86QA:7-E="!K:7)J86EM970`27-O="!R;V]M86QA:7-E="!N=6UE<F]T`%5R
M=6=U87D`2^1Y=.0@;GEK>6ES=.0Z("5S`$OD>73D(&]L971U<V%R=F]A`$OD
M>73D($E-05`M<')O=&]K;VQL86X@:V%N<VEO:61E;B!T:6QA=7-T82X`2^1Y
M=.0@4U-,+7-A;&%U<W1A`$OD>73D('9I<G1U86%L:7-T82!R;W-K86MO<FEK
M86YS:6]T82X`2^1Y=.0@:F]S('1U;FYU<R]S86QA<V%N82!O;B!E<FD@24U3
M4"UP86QV96QI;65L;&4N`$OD>71TY&KD`$OD>71TY&KD;&QE("(E<R(@;VYN
M:7-T=71T:6EN(&%N=&%M86%N(&]I:V5U9&5T(&MA;G-I;V]N("(E<R(N`$OD
M>71TY&KD;&SD("5S(&5I(&]L92!O:6ME=6MS:6$@=&5H9.0@)7,N`$OD>71T
MY&II96X@>6QLY'!I=&\`2^1Y='3D:N1N(&%S971U:W-E=`!+Y'ET=.1JY&X@
M<F5K:7-T97+V:6UI;F5N`%3D<W/D(&KD<FIE<W1E;&WD<W/D(&5I('9O:2!R
M96MI<W1E<O9I9.0@:^1Y='3D:FGD+@!+Y'ET=.1JY'1U;FYU<W1A(&5I(&SV
M>71Y;GET+@!+Y'ET=.1JY'1U;FYU<P!+Y'ET=.1JY'1U;FYU<R`B)7,B(&]N
M(&IO(&]L96UA<W-A+@!+Y'ET=.1JY'1U;FYU<SH`2^1Y='3D:N1T=6YN=7,Z
M(`!*Y')J97-T96QMY&X@:^1Y='3D:N1T.@!5>F)E:VES=&%N`%9&4RUH86ME
M;6ES=&]A(&5I(&]L92!O;&5M87-S82X`4&]I<W-A;VQO=FEE<W1I`%!A:6MK
M;VIA(&SV>71Y:2!E<VEM97)K:6MS:3H@`%9O:6UA<W-A;VQO86EK80!!<G9O
M(&UI;G5U=&5I<W-A(&YY:WEH971K97-TY"X`07)V;R!O;B!Y;&D@<&ET=75D
M96X@;6%K<VEM:6%R=F]N("5S+CP`07)V;W0`5F%L:71T879A="!A<G9O=`!6
M86YU871U`%9A:6AT96QE=F%A`%9E;F5Z=65L80!487)K:7-T=7,@97#D;VYN
M:7-T=6D@+2!4Y'3D('9I97-T:>0@;VX@=F]I='4@:^1S:71E;&SD+@!697)S
M:6\`5F5R<VEO;FAA;&QI;G1A`%!Y<W1Y<W5O<F$@=&%S875S`%!Y<W1Y<W5O
M<F$@=.1Y=&4`4'ES='ES=6]R83H`17)I='3D:6X@:V]R:V5A`%9I971N86T`
M5FEE=&YA;2`H5DE30TE)*0!.Y'ETY`!.Y'ETY"`E<P!.Y'ETY"!J=6QK:6YE
M;B!A=F%I;B`E<P!.Y'ETY"!V:65S=&EE;B!(5$U,+6UU;W1O:6YE;B!S:7/D
M;'3V(&5R:6QL:7-E<W/D(&EK:W5N87-S80!.Y'ETY"!V:65S=&ET`$[D>73D
M(&AE;FMI;/9K;VAT86EN96X@<V%L86EN96X@879A:6X`3N1Y=.0@:&5N:VEL
M]FMO:'1A:6YE;B!J=6QK:6YE;B!A=F%I;@!.Y'ETY"!+97-K=7-T96QU<^1I
M90!.Y'ETY"!P:6MK=6MU=F$`3N1Y=.0@97)I;&QI<V5NY"!W=W<M<VEV=6YA
M`$[D>73D("5S`$[D>73D(&QI:71E(&5R:6QL:7-E<W/D(&EK:W5N87-S80!.
MY'ETY"!V:65S=&EN('-I<^1L=/8@97)I;&QI<V5S<^0@:6MK=6YA<W-A`$[D
M>73D('1A<&%H='5M80!.Y'ETY"!V:65S=&ET(&MA;G-I;W-S82`E<P!.Y&MY
M;>0@=&%I('!O<W1I:V%N<VEO+"!J;VMA(&[D>71E=.3D;B!S:7/DY&YK:7)J
M875T=6UI<V5N(&KD;&ME96XZ`$[D>73D('1E:'3D=N0`3N1Y=.0@:W5V870`
M3F5I='-Y='-A87)E="P@0G)I='1I;.1I;F5N`$YE:71S>71S86%R970L(%EH
M9'ES=F%L=&%I;@!6:7)T=6%A;&EK86YS:6\@(B5S(B!O;B!L=6]T=2X`5FER
M='5A86QI:V%N<VEO=`!6:7)T=6%A;&EK86YS:6]I;&QE('!I=.3D(&%N=&%A
M(&YI;6DN`%9I<G1U86%L:6YE;B!)3D)/6`!6:7)T=6%A;&EN96X@24Y"3U@M
M:V%N<VEO`%9I<G1U86%L:6YE;B!R;W-K86MO<FD`5FER='5A86QI;F5N(')O
M<VMA:V]R:6MA;G-I;P!6:7)T=6%A;&EK86YS:6]N(&YI;6D`3N1K>7;D:7-Y
M>7,`3N1K>7;D:7-Y>7,Z(`!6;V1A9F]N92!)=&%L>2!33510.FX@879U;&QA
M`%9!4D])5%53`%9!4D])5%53(2$A(%!/25-402!32U))4%1)($OD4TE.(%!!
M3%9%3$E-14Q402`E<RX`5TE.($A45%`Z;B!A=G5L;&$`5V%L;&ES(&IA($9U
M='5N80!687)O:71U<P!K90!3Y.1E;FYU<W1E`%/DY'1I961O="!O;B!T;VEM
M:71T86YU=`!796%T:&5R+F-O;0!75U<`5U=7+7-I=G5S=&\`5FEI:V]I='1A
M:6X`5&5R=F5T=6QO80!497)V971U;&]A(&]H:F5L;6%A;B`E<P!497)V971U
M;&]A+"`E<P!,Y&YS:6UA:6YE;B`H25-/+3@X-3DM,2D`3.1N<VEM86EN96XO
M175R;R`H25-/+3@X-3DM,34I`$SD;G-I+5-A:&%R80!-:6YKY"!O:&IE;&UA
M;B`E<R!KY'EN;FES=.3D('-I<^3D;FMI<FIA=71U;6ES96X@:N1L:V5E;BX`
M36ETY"!M97)K:VGD(&OD>71E=.3D;B!E<F]T=&EM96YA/P!-:73D(&UE<FMK
M:>0@:^1Y=&5TY.1N(&QA:6YA=6MS965N/P!-:73D('1E:&3DY&X@<F]S:V%P
M;W-T:79I97-T96EL;&4@:W5N(&YE(&]N(')A<&]R=&]I='4@:F]K;R!R;W-K
M87!O<W1I;F$@=&%I(&5I(')O<VMA<&]S=&EN82X`2W5N('9I97-T96KD('!O
M:7-T971A86XL('-I:7)RY"!N92!R;W-K86MO<FEK86YS:6]O;B!S96X@<VEJ
M86%N+"!E='3D(&YE(&UE<FMI='3D:7-I:6X@<&]I<W1E='5K<VDN`$MU;B!U
M=7-I('!O<W1I:V%N<VEO(&%U:V%I<W1A86XL(&YI:6X@;6EL=.0@<VEV=6QT
M82!H86QU870@86QO:71T86$_`%1A;&QE=&5T=&%E<W-A(&SD:'1E=FGD('9I
M97-T96KD+"!T86QL971A(&UY]G,@;.1H971E='1Y(&QI:71E=&EE9&]S=&\N
M`$MU;B!LY&AE=&5TY.1N('9I97-T:>0@;&%A:F5N=&%M871T;VUI:6X@;W-O
M:71T96ES:6EN+"!N:6EN(&UI:^0@9&]M86EN+71I971O(&QI<^1TY.1N(&5P
MY&WDY'+D:7-I:6X@;W-O:71T96ES:6EN("ASY&AK]G!O<W1I;W-O:71T965T
M(&EL;6%N(")`(BUM97)K:VGD*3\`5VAE<F5I<R!!=7-T<F%L:6%N(&MA<G1T
M80!-:71KY"!V86EH965T`%9O:70@;>3D<FET96QLY"!L:7/D=&]I;6EN=&]J
M82!L86ET971A86X@<.3D;&QE(%)I8V@@5&5X="!E9&ET;W)I<W-A+@!686QK
M;VEN96X@;&ES=&$`3&5V97ES`$QE=F5Y<R!#4U,@;6ET=&%Y:W-I:VOV:6[D
M`%9A<V5M;6%L;&$@;VQE=F%N("5S('9A;&EK;VX@;&5V97ES("AT=6QE92!V
M;VEM86%N('-E=7)A879A;&QA('-I<^3D;FMI<FIA=71U;6ES96QL82DZ`%1A
M=6QU:V]N(&QE=F5Y<P!,979E>61E;B!Y:W-I:VOV`$QE=F5Y<SH`5VEK:0!4
M=75L:0!4=75L:7-T82!A:6MA:7-I;@!4=75L96YN;W!E=7,@<V]L;75I<W-A
M`%1U=6QI.@!4=75L:3H@`%9I:7-A=7,`5&]I=F5L:7-T870`5'GV`$]S;VET
M92`H='GV*0!0=6AE;&EN("AT>?8I`%;DY'+D(&WDY'+D(&ME;G1T:>0@<FEV
M:6QLY"`E9"X@3V1O=&5T=&EI;B`E9"P@;/9Y='EI("5D+@!6Y.1RY"!MY.1R
MY"!K96YT=&GD+B!/9&]T971T:6EN("5D+"!L]GET>6D@)60N`%;DY'+D('!O
M:6MK96%M82`E9"!L=65T=&%E<W-A(%9&4RUT:65D;W-T;V$N`%@M4F5F`%@U
M,#EV,R!P97)U<W)A:F]I='1E970`6#4P.78S(&QI<^1T;VEM:6YN;W0@879A
M:6UE;B!KY'ET]FQL90!8-3`Y=C,@2V]H=&5E;B!V86EH=&]E:'1O:6YE;B!N
M:6UI`%@U,#EV,R!+;VAT965N(&%V86EM96X@='5N;FES=&4`6#4P.78S+6QA
M86IE;FYU:W-E=`!65@!65E96`%EA:&]O(2!K87)T=&$`5G5O<VET=&%I;@!*
M96UE;@!+>6QLY`!+>6QLY"P@<W5O<W1U;BX`3VQE="!H86ME;6%S<V$@<^1H
M:_9P;W-T:6$@<V5U<F%A=FEL=&$@<^1H:_9P;W-T:71I;&5I;'3D.@!/;&5T
M('!O:7-T86UA<W-A(&MA:6MK:6$@=FEE<W1E:N0@<V5U<F%A=FES=&$@:V%N
M<VEO:7-T82X`3VQE="!P;VES=&%M87-S82!S975R86%V:6$@:V%N<VEO:71A
M+@!/;&5T(&MO<&EO:6UA<W-A+W-I:7)TY&WD<W/D('9I97-T96KD('5U=&5E
M;B!K86YS:6]O;BX`3VQE="!T96ME;>1S<^0@86QI:V%N<VEO=&$@:V%N<VEO
M;&QE(`!/;&5T('1E:V5MY'-SY"!Y;&EM;>1N('1A<V]N(&MA;G-I;W1A+@!+
MY'ETY'0@5$5+4U1)5$E,04$N($OD>73D(%L\/ET@;F%P<'5L86$@=F%I:'1A
M86MS97-I('1A:V%I<VEN(%=94TE764<M=&EL86%N+@!9;&EM;>1N('1A<V]N
M(&MA;G-I;VED96X@;'5O;G1I(&]N(&5S=&5T='DN`$5T('9O:2!T96ADY"!E
M;F5M<.3D(&MU:6X@)60@;W-I;W1A+@!%="!V;VD@;'5O9&$@96YE;7#DY"!K
M=6EN("5D(&MA;G-I;W1A+@!%="!O;&4@875T96YT:6MO:71U;G5T+@!/;&5T
M(&YI;67D;>1S<^0@=75D96QL965N(&MA;G-I;W1A.B``5F]I="!KY'ET=.3D
M('-E=7)A879I82!M97)K:VEJ;VYO:F$@97)I:V]I<VUE<FMI='EK<V5S<^0@
M:VER:F5P;VAJ87-S83H@)6,@=&%R:V]I='1A82!V:65S=&EN('-E;B!H971K
M:7-TY"!S:7/D;'3VY#L@)7,@86QL96MI<FIO:71U<W1A+@!.:6UE<W/D<VD@
M96D@<V%A(&]L;&$@)UPG+6UE<FMK:>0N`$5T('9O:2!L;W!E='1A82!T:6QA
M=7-T82!K86YS:6]O;B`B)7,B+@!%="!H>7;D:W-Y;GET(&KD<FIE<W1E;&WD
M;B!KY'ET=/9E:'1O:F$L(&IO=&5N(&5T('9O:2!K:7)J875T=6$@<VESY.1N
M+@!%="!A;G1A;G5T(&]I:V5A;B!M=6]T;VES=&$@<^1H:_9P;W-T:6]S;VET
M971T82X`170@;>3D<FET96QL>70@;6ET:^0@='5O9'5N('1I961O<W1O;B!K
M96YTY'0@=F%S=&%A=F%T(&UI=.1K:6X@:V5N='1IY"`E<SIS<^0N`%-I;G5L
M;&$@96D@;VQE(&]I:V5U:W-I82!M=75T=&%A('3D;>1N(&MA;G-I;VX@;VEK
M975K<VEA`%;D;&ET:70@=.1MY&X@=FEE<W1I;B`E)7,@<.1I=N1NY"!V87-T
M86%N;W1T86II;&QE.B`E<RX`4VEN=6QL92!O;B`E<R!U=71T82!V:65S=&GD
M+@!3:6YU;&QE(&]N(#$@=75S:2!V:65S=&DN`$]L970@:F\@;.1H971TY&YY
M="!TY&WD;B!S:79U;BX`3VQE="!K:7)J875T=6YU="!U;&]S+@!3:6YU;&QE
M(&]N('5U<VEA('9I97-T96KD(&MA;G-I;W-S83H`4VEN=6QL92!O;B!U=7-I
M82!V:65S=&5JY"!K86YS:6]I<W-A.@!3:6YU;B!P:73DY"!A;G1A82!O:6ME
M82!M871K87!U:&5L:6YN=6UE<F\L('9A:6X@;G5M97)O:71A(&IA(&UA:&1O
M;&QI<V5S=&D@)RLG(&IO<R!KY'ETY'0@:V%N<V%I;G;D;&ES=.0@<'5H96QI
M;FYU;65R;VUU;W1O82X`4VEN=6X@=.1Y='EY(&%N=&%A(&]I:V5A(&%R=F\N
M`%-I;G5N('!I=.3D(&%S96YT86$@1&%T851R964M=&%U<W1A:N1R:F5S=&5L
M;>0@96YN96X@:W5I;B!V;VET(&OD>71TY.0@4VEG;G5P+71O:6UI;G1O:F$N
M`%-I;G5N('!I=.3D(&%S96YT86$@5D93+71A=7-T86KD<FIE<W1E;&WD+@!3
M:6YU;B!T=6QE92!K=79A:6QL82!O;F=E;&UA=&EL86YN971T82!E;FYE;B!K
M=6EN('9O:70@;.1H971TY.0@;VYG96QM879I97-T:6XN`%-I;G5N('!I=.3D
M(&WDY')I=&5L;.0@86EN86MI;B!Y:W-I('9A<W1A86YO='1A:F$N`%-I;G5N
M('!I=.3D(&%N=&%A(%523"!M:6AI;B!TY&WD(&QI;FMK:2!O<V]I='1A80!3
M:6YU;B!P:73DY"!A;G1A82!S86QA<V%N871E:W-T:2!V;VED86MS97-I(&OD
M>71TY.0@<V%L86ES=&$@4$=0+6%V86EN=&$@=.1MY&X@=FEE<W1I;B!A=F%A
M;6ES96MS:0!3:6YU;B!P:73DY"!A;G1A82!S86QA<V%N871E:W-T:2!V;VED
M86MS97-I(&OD>71TY.0@<V%L86ES=&$@4R]-24U%+6%V86EN=&$@=.1MY&X@
M=FEE<W1I;B!A=F%A;6ES96MS:0!3:6YU;B!P:73DY"!V86QI=&$@:V]H9&5K
M86YS:6\N`%-I;G5N('!I=.3D('9A;&ET82!P;VES=&5T=&%V82!SY&AK]G!O
M<W1I=&EL:2X`4VEN=6X@<&ETY.0@96YS:6X@=F%L:71A(&]S;VET92X`4VEN
M=6X@<&ETY.0@=F%L:71A('!O:7-T971T879A('!A;'9E;&EN+@!3:6YU;B!P
M:73DY"!V86QI=&$@86EN86MI;B!Y:W-I('9I97-T:2X`4VEN=6X@<&ETY.0@
M;>3D<FET96QLY"!V87-T86%N;W1T86IA+@!3:6YU;B!P:73DY"!A;G1A82!P
M;VES=&5T=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@
M<&]I<W1E='1A=F$@:^1Y='3D:N1T=6YN=7,N`%-I;G5N('!I=.3D(&%N=&%A
M(&QI<^1T=.1VY"!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@
M<.1I=FET971TY';D(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!V86QI
M=&$@<W5O<FET971T879A('1O:6UI;G1O+@!3:6YU;B!P:73DY"!A;G1A82!U
M=61E;B!K871E9V]R:6%N(&YI;6DN`$AU;VTZ(%-I;G5L;&$@<&ETY.0@;VQL
M82!Y;&SD<&ET;W1O:6UI<W-A('9A;&ET='5N82`B)7,B+@!3:6YU;B!P:73D
MY"!A;G1A82!I=&%L:6%L86EN96X@<'5H96QI;FYU;65R;P!/:&IA<VET('3D
M;>1N('9I97-T:6X@=F%S=&%A;F]T=&%J86QL92`E<R`E)7,@<.1I=N1NY"X`
M5F%S=&%S:70@=.1HY&X@=FEE<W1I:6X@)7,@<.1I=N1NY"X`2V%N<VEO;B`B
M)7,B('1I;&%A;6EN96X@97#D;VYN:7-T=6DN(%!A;'9E;&EM96X@=FER:&5I
M;&UO:71U<R!O;&D`5&EL875K<V5N(&QO<&5T=&%M:6YE;B!K86YS:6]O;B`B
M)7,B(&5PY&]N;FES='5I+B!086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI
M`$MA;G-I;VX@(B5S(B!T:6QA=7,@;VYN:7-T=6D`5&EL875K<V5N(&QO<&5T
M=&%M:6YE;B!K86YS:6]O;B`B)7,B(&]N;FES='5I`$ES='5N=&]S:2`E<R!O
M;B!V86YH96YT=6YU="X@2VER:F%U9'4@=75D96QL965N('-I<^3D;BX`4^1H
M:_9P;W-T:6]S;VET=&5E<VD`4VEN=6X@;.1H971TY&KD;W-O:71T965S:3H`
M3VUA="!T:65T;W-I`%-I;G5N('1I971O:V]N965S:2!KY'ET=.1MY"!T:65T
M;W9E<FMK;RUO<V]I=&4@;VX@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O
M;&5T(&%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@
M<VEN=6X@<&ETY.0@:VER:F%U='5A('5U9&5S=&%A;B!JY')J97-T96QMY.1N
M+@!.:6UE<VD`2G5L:VEN96X@:F$@<V%L86EN96X@4$=0+6%V86EM97-I`%-A
M;&%I;F5N(&%V86EM97-I`$IU;&MI;F5N(&%V86EM97-I`%9A<W1A=7-O<V]I
M='1E97-I.B`\96T^*'9A<&%A96AT;VEN96XI/"]E;3X`2G5L:VEN96X@:F$@
M<V%L86EN96X@4R]-24U%+79A<FUE;G1E97-I`%/D:&OV<&]S=&ET:6QI<VDZ
M`%/D:&OV<&]S=&EA;&EA:W-E<VDZ(#QE;3XH=F%P86%E:'1O:6YE;BP@;&%I
M=&$@:F]K86EN96X@;W-O:71E(&]M86QL92!R:79I;&QE96XI/"]E;3X`2^1Y
M='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J97-T96QMY"!E:2!T
M=64@:^1Y='3D:FEE;B!L:7/DY&UI<W3D+B!*;W,@:&%L=6%T(&AA;&QI;FYO
M:61A(&OD>71TY&KD='5N;G5K<VEA+"!S:6YU;B!P:73DY"!KY'ET=.3D(&IO
M=&%K:6X@=&]I<W1A(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WD
MY"X`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J97-T96QM
MY"!E:2!T=64@:^1Y='3D:N1T:65T;VIE;B!NY'ET=.1M:7-TY"!T86D@=.1M
MY"!P:6ER<F4@96D@;VQE(&IO<W1A:VEN('-Y>7-TY"!KY'ET971TY'9I<W/D
M+@!3:6YU;B!KY'ET=.1MY'-I('=W=RUS96QA:6X@;N1Y='3DY"!O;&5V86X@
M;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T(&%L;VET=&%N=70@)7,@
M:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN=6X@<&ETY.0@:VER:F%U
M='5A('5U9&5S=&%A;FKD<FIE<W1E;&WDY&XN`%-E;&%I;65S:2!E:2!T=64@
M=.1MY&X@='EY<'!I<W1E;B!K=79I96X@;N1Y='3D;6ES=.0@=FEE<W1I96X@
M>6AT97ED97-SY`!396QA:6UE<VD@96D@='5E('3D=.0@=&]I;6EN=&]A+@!3
M96QA:6UE<VD@96D@='5E('1A<G9I='1A=F%A('1U;&]S='5S=&]I;6EN=&]A
M+B!086EN82!#;VYT<F]L+T]P=&EO;B`K(%`@='5L;W-T86%K<V5S:2X`06EK
M879Y]FAY:VME97-I.@!/;&5T=6MS96YA('9I97-T:6X@;.1H971Y:W-E<W/D
M(&OD>71E='3D=N0@;65R:VES=/8Z`$]L971U:W-E;F$@:^1Y=&5T=.1VY"!V
M:65S=&EE;B!S86QA=7-T87!A.@!/;&5T=7-P<F]F:6EL:7-I(&]N(&UU=71E
M='1U+@!/;&5T=7-P<F]F:6EL:7-I.@!.:6UE<VDZ`$QI;FMI='3D;>1S:2!L
M:6ET=&5E;B!O;B!T86QL96YT86YU="!A:6YA:VEN('EK<VD@:^1Y='3D:N0N
M"@I,:6ET971I961O<W1O;B!N:6UI.B`E<PI,:6ET971I961O<W1O;B!PY&EV
MY&WDY'+D.B`E<PH*3F%P<V%U=&$@<V5U<F%A=F%S=&$@;&EN:VES=.0@<&]I
M<W1A86MS97-I(&QI:71T965N('!Y<WEVY'-T:3H*)7,`27-T=6YT;W-I(&]N
M('9A;FAE;G1U;G5T+@!6:65S=&ES:2!O;B!M96YN>70@<&5R:6QL92X`4VEN
M=6X@<V%L87-A;F%S:2`E<SIL;&4@;VXZ("5S`$%S971U:W-E<VD@;VX@<.1I
M=FET971T>2!J82!N92!O=F%T('9O:6UA<W-A('3D;>1N(&ES='5N;F]N(&%J
M86XN`$%S971U:W-E<VD@;VX@<.1I=FET971T>2X`4V%L87-A;F%S:2!O;B!N
M;VQL871T=0!386QA<V%N87-I(&]N(&YO;&QA='1U+"!T87)K:7-T82!SY&AK
M]G!O<W1I<VD@:F$@:VER:F%U9'4@<VESY.1N('5U9&5L;&$@<V%L87-A;F%L
M;&%S:2X`4V%L87-A;F%S:2!O;B!V86YH96YT=6YU="X`173D<&%L=F5L:6UE
M<VDZ`$%L;&5K:7)J;VET=6MS97-I.@!*=6=O<VQA=FEA`%IA:7)E`%-A;6)I
M80!::6UB86)W90!::7!P>0!;4&EI;&]T82!O<V]I='1E971=`%M0:6EL;W1A
M(&QA:6YA='1U('1E:W-T:5T`6T5I(&]T<VEK:V]A70!;3VYG96QM85T`6T[D
M>73D(&]S;VET=&5E="`M`%M.Y'ETY"!L86EN871T=2!T96MS=&D@+0!;3N1Y
M=.0@;&%I;F%T='4@=&5K<W1I("T@)7,@<FEV:>1=`%M.Y'ETY"!O<V]I='1E
M970@+2`E<R!V87-T86%N;W1T86II;F%=`%MR:79I;&SD("5S+R5S70!?66QL
MY'!I=&\`7U!I:6QO:V]P:6\`7TUU<W1A(&QI<W1A`%]+;VUE;G1O='5L:VMI
M`%]+;W!I;P!?1&%T851R964`7U!O:7-T80!?4&]I<W1A(')I=FD`7TMA;G-I
M;W0`7U)Y:&WD=`!?3VAJ90!?4')O9FEI;&D`7TMU=F%N('1I961O="XN+@!?
M26YB;W@`7TMI<FIA=61U('-I<^3D;@!?2VER:F%U9'4@=6QO<P!?5FEE<W1I
M(')A86MA;75O9&]S<V$`7TUU;VMK86$@;&EN:VMIY`!?575S:2!V:65S=&D`
M7T%S971U:W-E=`!?3VEK975D970`7U1U;&]S=&$`7U!R:6]R:71E971T:0!?
M4.1I=FETY"`E<P!0;VES=&$@;&EN:VMI+BXN`%]687-T86$`7TAA:W4`7TSD
M:&5TY"!V:65S=&D`7T%S96YN=7,`7U1A=6QU:V]N('1I961O="XN+@!?2V5S
M:W5S=&5L=7/D:64`7U9A<W1A86YO='1A:F$`7U!A;&%U=&$`7TOD>71TY&KD
M=`!?3N1Y=.0@2V5S:W5S=&5L=7/D:64`7U9A;&MO:6YE;B!L:7-T80!O<V]I
M=&5K:7)J80!T=6YT96UA=&]N(&]S;VET90!L:6ET971I961O<W1O`&%T=&%C
M:&UE;G1S+GII<`!T879U80!K86QE;G1E<FD`='EY;G3D`&5I('9O:2!L=6]D
M82!T=6QO<W1I961O<W1O80!E:2!V;VD@875K86ES=&$@;.1H9&5T=.0`;F%P
M<V%U=&$@=.1S=.0`=FER:&4@:V]M96YT;W)I=FEL;.0`87-E='5S=FER:&4`
M:W)I:71T:6YE;B!JY')J97-T96QMY'1I961O<W1O('!U=71T=74`;75O=&]V
M:7)H92!T:65D;VES<V$`;75O:VMA80!T:65T=65T=&$@96D@;/9Y='EN>70`
M;&%S:V5V80!T:65D;W-T;P!LY&AD90!S=75N;F%S=&$@)7,@*"5S*2!N;W!E
M=61E;&QA("5S("5S`'!U=7-K:71T86EN`&@Z`&AH`'1U;G1E;6%T;VX@<&%L
M=F5L:6UE;B!N:6UI`';D;&ET=/9MY'-T:0!I;FQI;F4`:6\M=FER:&4`;VAJ
M96QM:7-T;VX@<VESY&EN96X@=FER:&4`879A:6X`<FEV:71=`&UA:6QB;W@M
M=&EE9&]S=&\`;6MI<V]F<R!V:7)H96MO;V1I("5D($E33SIA('1E:&1E<W/D
M+@!M;0!N:6UI`&5I(&UI=.3D;@!E:2!O;&4@=&]T975T971T=0!E:2!O;&4@
M=FEE;.0@=&]T975T971T=0!M=6ES=&EL:7-T80!T86D`<')O<V5N='1I`&OD
M>71T]B!K:65L;&5T='D`<&EK<V5L96ETY`!V87-T86%N;W1T86IA=%T`973D
M=FER:&4@<')O=&]K;VQL87-S80!N;W5S979A`'!A;'9E;'4@96D@;VQE(&OD
M>71E='3D=FES<^0`;N1Y=.0@97)O=`!S;7,R96UA:6P@2%144#IN(&%V=6QL
M80!K:7)J;VET=7-V:7)H90!K:7)J;VET=7-V:7)H96ETY`!S<P!V86MA80!J
MY')J97-T96QMY'9I<FAE`'1E:'3D=N1L:7-T80!VY&QI86EK86EN96X@=FER
M:&4`=F%R;6ES=&%A:W-E<VD@:VER:F]I=&$@<V%L87-A;F$@:V%H9&5S=&D`
M=6YI9FEE9`!N:6UE=/9N`&OD>71TY&KD;B!V86QI;G1A`'9#87)D`'<Z`'=E
M871H97(N8V]M`&UU<W1A(&QI<W1A<VD`=F%L:V]I;F5N(&QI<W1A<VD`````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]L;V-A;&4O9FE?1DDO:&5L<"YX;6P`````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`Q-#$S,C$`,3`T,3<S-C(W-C``,#(Q,#<S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_>&UL('9E
M<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:6UP+VQO8V%L92]F:5]&22]H
M96QP+GAM;"QV(#$N,3DN-BXX(#(P,#8O,#(O,C@@,3,Z-#0Z,C4@:F%N($5X
M<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(@
M<W1A=&4](G5P=&]D871E(B!M9#4](C,R-3EB83`P83$Y.#4U.6,W9F%A-S9E
M-S@V-S8P,&0Y(CX*("`@(#QT:71L93Y6:65S=&EN(&MI<FIO:71U<SH@5&]I
M;6EN;F]T/"]T:71L93X*("`@(#QH96%D:6YG/E1O:6UI;FYO=#PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@(DPF(WA%-#MH970F(WA%-#L@=FEE<W1I(B!L
M)B-X130[:&5T="8C>$4T.R8C>$4T.R!V:65S=&EN('9A<W1A86YO='1A:FEL
M;&4N($UU:7-T871H86X@971T)B-X130["B`@("!V:65S=&DF(WA%-#L@96D@
M=F]I(&5N)B-X130[)B-X130[('!E<G5A(&MU;B!S92!O;B!L)B-X130[:&5T
M971T>2!M871K86%N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`B5&%L
M;&5N;F$@;'5O;FYO<R(@=&%L;&5T=&%A(&ME<VME;F5R)B-X130[:7-E;B!V
M:65S=&EN(&MA;G-I;V]N"B`@("`B3'5O;FYO<R(N($MA;G-I;W1A('9O:2!K
M)B-X130[<VET96QL)B-X130[(&%L87-V971O=F%L:6MO<W1A(')U=61U;@H@
M("`@;VEK96%S=&$@>6PF(WA%-#MK=6QM87-T82X@5F]I="!V:6EM96ES=&5L
M;"8C>$4T.R!V:65S=&ES:2!S:6ER='EM)B-X130[;&PF(WA%-#L*("`@("),
M=6]N;F]S(B!K86YS:6]O;BP@=F%L:71S96UA;&QA('-I96QT)B-X130[('9I
M97-T:6X@:F$@<&%I;F%M86QL80H@("`@<&%I;FEK971T82`B2F%T:V$B+B!-
M=6ES=&%T:&%N(&%I;F$@;&%I='1A82!V:65S=&5I:&EN(&MU=F%A=F%N"B`@
M("!O='-I:V]N(&5N;F5N:W5I;B!T86QL971A="!N92!L=6]N;F]S:V%N<VEO
M;VXN($AY=B8C>$4T.R!O='-I:VMO"B`@("!H96QP;W1T86$@;7DF(WA&-CMH
M96UM:6X@=&EL86YN971T82!K=6X@<&ET)B-X130[)B-X130[(&PF(WA&-CMY
M="8C>$4T.R8C>$4T.R!O:6ME82!V:65S=&DN"B`@("`\+W!A<F$^"B`@("`\
M=&EP/@H@("`@07-E;FYU:W-E<W1A(')I:7!P=65N('9O:70@=F%L:71A(&%S
M971U:W-I<W1A<VD@<&%L86%T:V\@=FEI;65K<VD*("`@('-E;&%I;&5M86%S
M:2!K86YS:6]O;B!T86D@=FEI;65K<VD@;'5K96UA87-I('9I97-T:6EN(&MU
M;B!V:65S=&D*("`@(&]N('1A;&QE=&5T='4@;'5O;FYO:W-E:W-I+@H@("`@
M/"]T:7`^"B`@("`\<&%R83X*("`@(")097)U('9I97-T:2(@:'EL:R8C>$4T
M.R8C>$4T.R!K:7)J;VET=&%M87-I('9I97-T:6X@:F$@<&%L875T=&%A('-I
M;G5T"B`@("!S:6EH96X@:V%N<VEO;VX@;6ET)B-X130[(&]L:70@=FEI;65K
M<VD@<V5L86EL;'5T+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UF<F]M(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB.#)C9C(T
M9#,Q838V-V$U8CDT930X,6-D-3$W.6,U,CDB/@H@("`@/'1I=&QE/E9I97-T
M:6X@:VER:F]I='5S.B!,)B-X130[:&5T="8C>$4T.VHF(WA%-#L\+W1I=&QE
M/@H@("`@/&AE861I;F<^3"8C>$4T.VAE='0F(WA%-#MJ)B-X130[/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!686EN(&IO<R!Y;&PF(WA%-#MP:70F(WA%
M-#MJ)B-X130[(&]N('-A;&QI;G5T('0F(WA%-#MM)B-X130[;B!T;VEM:6YN
M;VX@:R8C>$4T.WET="8C>$4T.VUI<V5N+B!3:6YU;@H@("`@;VX@;6%H9&]L
M;&ES=&$@=F%L:71A(&%L87-V971O=F%L:6MO<W1A(&LF(WA%-#MY=&5T="8C
M>$4T.W8F(WA%-#L@<')O9FEI;&D@=&%I"B`@("!V;VET(&MI<FIO:71T86$@
M:V5N='0F(WA%-#LF(WA%-#MN(&PF(WA%-#MH971T)B-X130[:B8C>$4T.VXF
M(WA%-#L@;B8C>$4T.VMY=B8C>$4T.VX*("`@(',F(WA%-#MH:R8C>$8V.W!O
M<W1I;W-O:71T965N+B!0<F]F:6EL96IA('9O:70@;28C>$4T.R8C>$4T.W)I
M=&5L;"8C>$4T.PH@("`@/'%T/D%S971U:W-E="TF9W0[3VUA="!T:65D;W0\
M+W%T/BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O
M<V4M=&\B('-T871E/2)U<'1O9&%T92(@;60U/2(S,6-B83$W9C$V.34W,F,S
M-C=A83@P,30X,S%E8CAF."(^"B`@("`\=&ET;&4^5FEE<W1I;B!K:7)J;VET
M=7,Z(%9A<W1A86YO='1A:F$\+W1I=&QE/@H@("`@/&AE861I;F<^5F%S=&%A
M;F]T=&%J83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@2VER:F]I=&$@="8C
M>$4T.V@F(WA%-#MN('9I97-T:6X@=F%S=&%A;F]T=&%J86X@<R8C>$4T.VAK
M)B-X1C8[<&]S=&EO<V]I=&4N($IO<PH@("`@=FEE<W1I;&PF(WA%-#L@;VX@
M=7-E:71A('9A<W1A86YO='1A:FEA+"!N:6EN(&5R;W1A(&]S;VET=&5E=`H@
M("`@=&]I<VES=&%A;B!P:6QK=6QL82X@36EN:R8C>$4T.R!T86AA;G-A(&UU
M=6X@;65R:VEN(&LF(WA%-#MY='0F(WA%-#MM:6YE;@H@("`@97)O='1I;65N
M82!A:6AE=71T86$@=FEK871I;&%N=&5E;B!J82!V:7)H96EL;6]I='5K<V5N
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UC
M8R(@<W1A=&4](G5P=&]D871E(B!M9#4](CDW-3<Q-#,S86(P,S=E9CEC-&0Q
M,#%A-39B9C<T93(U(CX*("`@(#QT:71L93Y6:65S=&EN(&MI<FIO:71U<SH@
M2V]P:6\\+W1I=&QE/@H@("`@/&AE861I;F<^2V]P:6\\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($MI<FIO:71A('0F(WA%-#MH)B-X130[;B!S)B-X130[
M:&LF(WA&-CMP;W-T:6]S;VET92P@:F]H;VX@;"8C>$4T.VAE=&5T)B-X130[
M)B-X130[;B!K;W!I;PH@("`@=FEE<W1I<W0F(WA%-#LN($IO<R!V:65S=&ES
M="8C>$4T.R!L)B-X130[:&5T970F(WA%-#LF(WA%-#MN(&MO<&EO('5S96%L
M;&4*("`@('9A<W1A86YO='1A:F%L;&4L(&YI:6X@97)O=&$@;W-O:71T965T
M('1O:7-I<W1A86X@<&EL:W5L;&$N($UI;FLF(WA%-#L*("`@('1A:&%N<V$@
M;75U;B!M97)K:6X@:R8C>$4T.WET="8C>$4T.VUI;F5N(&5R;W1T:6UE;F$@
M86EH975T=&%A('9I:V%T:6QA;G1E96X*("`@(&IA('9I<FAE:6QM;VET=6MS
M96XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($MO<&EO(&PF(WA%-#MH
M971E="8C>$4T.R8C>$4T.VX@>6QE96YS)B-X130[(&YI:6QL92!V87-T86%N
M;W1T86II;&QE+"!J;W1K82!E:78F(WA%-#MT(&]L90H@("`@=FEE<W1I;B!S
M=6]R86YA:7-I82!V87-T86%N;W1T86II82P@;75T=&$@=F]I=F%T('1A<G9I
M=&$@=&%I(&]L;&$*("`@(&MI:6YN;W-T=6YE:71A('9I97-T:7-S)B-X130[
M(&]L979I<W1A('1I961O:7-T82X@375I<W1A=&AA;B!E='0F(WA%-#L*("`@
M('9A<W1A86YO='1A:F$@;B8C>$4T.VME92!K86EK:VD@;F4@;W-O:71T965T
M+"!J;W1K82!O=F%T('9I97-T:6X*("`@('9A<W1A86YO='1A:FEN82!T86D@
M:F]I;&QE('9I97-T:7-T)B-X130[(&]N(&PF(WA%-#MH971E='1Y(&MO<&EO
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UB
M8V,B('-T871E/2)U<'1O9&%T92(@;60U/2)A83AF.64R9#0T9F1B-S1D968P
M9F$Q-3(T,&9F-C@W8B(^"B`@("`\=&ET;&4^5FEE<W1I;B!K:7)J;VET=7,Z
M(%!I:6QO:V]P:6\\+W1I=&QE/@H@("`@/&AE861I;F<^4&EI;&\\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($MI<FIO:71A('0F(WA%-#MH)B-X130[;B!S
M)B-X130[:&LF(WA&-CMP;W-T:6]S;VET92P@:F]H;VX@;"8C>$4T.VAE=&5T
M)B-X130[)B-X130[;B!P:6EL;VMO<&EO"B`@("!V:65S=&ES="8C>$4T.RX@
M2F]S('9I97-T:7-T)B-X130[(&PF(WA%-#MH971E="8C>$4T.R8C>$4T.VX@
M<&EI;&]K;W!I;R!U<V5A;&QE"B`@("!V87-T86%N;W1T86IA;&QE+"!N:6EN
M(&5R;W1A(&]S;VET=&5E="!T;VES:7-T86%N('!I;&MU;&QA+B!-:6YK)B-X
M130["B`@("!T86AA;G-A(&UU=6X@;65R:VEN(&LF(WA%-#MY='0F(WA%-#MM
M:6YE;B!E<F]T=&EM96YA(&%I:&5U='1A82!V:6MA=&EL86YT965N"B`@("!J
M82!V:7)H96EL;6]I='5K<V5N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!0:6EL;VMO<&EO(&PF(WA%-#MH971E="8C>$4T.R8C>$4T.VX@>6QE96YS
M)B-X130[(&YI:6QL92!V87-T86%N;W1T86II;&QE+"!J;W1K82!E:78F(WA%
M-#MT"B`@("!O;&4@=FEE<W1I;B!S=6]R86YA:7-I82!V87-T86%N;W1T86II
M82P@;75T=&$@=F]I=F%T('1A<G9I=&$@=&%I"B`@("!O;&QA(&MI:6YN;W-T
M=6YE:71A('9I97-T:7-S)B-X130[(&]L979I<W1A('1I961O:7-T82X@5FEE
M<W1I;@H@("`@=F%R<VEN86ES970@=F%S=&%A;F]T=&%J870@96EV)B-X130[
M="!N)B-X130[92!K96YE;&QE('9I97-T:2!O;B!M96YN>70*("`@('!I:6QO
M:V]P:6]I;F$N(%9A:6X@=FEE<W1I;B!L)B-X130[:&5T="8C>$4T.VHF(WA%
M-#L@=&EE="8C>$4T.R8C>$4T.R!K96YE;&QE(&MA:6MI;&QE"B`@("!V:65S
M=&D@;VX@;"8C>$4T.VAE=&5T='DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+7-U8FIE8W0B('-T871E/2)U<'1O9&%T92(@
M;60U/2(P-C,Y83@W.3!E,S`V86-C.64Q.6(T9#%C93,T,F0U,R(^"B`@("`\
M=&ET;&4^5FEE<W1I;B!K:7)J;W1U<SH@3W1S:6MK;SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY/='-I:VMO/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!+:7)J
M;VET82!T)B-X130[:"8C>$4T.VX@=FEE<W1I;B!O='-I:VMO+B!6:65S=&EN
M(&]T<VEK:V\@;VX@<&%R87-T82!P:70F(WA%-#LF(WA%-#L*("`@(&QY:'EE
M;B8C>$4T.R!J82!Y:W-I;FME<G1A:7-E;F$@;75T=&$@:W5I=&5N:VEN(&MU
M=F%A=F%N82X@3W1S:6MK;R!V;VD*("`@(&%U='1A82!O:6ME86X@=FEE<W1I
M;B!L)B-X1C8[>70F(WA%-#MM:7-E<W,F(WA%-#L@:F$@;7DF(WA&-CMS(&UU
M:7-T=71T86$@<VEN=6$@;6ES="8C>$4T.PH@("`@=FEE<W1I<W,F(WA%-#L@
M;VQI(&MY<V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($UU:7-T82!M
M>28C>$8V.W,@971T)B-X130[('9I97-T:6X@(E9A<W1A82(@=&%I(")6)B-X
M130[;&ET)B-X130[(&5T965N<"8C>$4T.VEN(@H@("`@=&]I;6EN;F]I<W-A
M('9I97-T:6X@;W1S:6MK;R!K;W!I;VED86%N('5U=&5E;B!V:65S=&EI;B!S
M:71E;B!E='0F(WA%-#L*("`@('9I97-T96ES="8C>$4T.R!N)B-X130[:V5E
M(&UI=&LF(WA%-#L@:W5U;'5V870@<V%M86%N(")S)B-X130[:6ME97-E96XB
M+B!*;W,@=FEE<W1I;@H@("`@86EH92!M=75T='5U(&%L:W5P97(F(WA%-#MI
M<V5S=&D@;W1S:6MO<W1A+"!N:6EN(&MA;FYA='1A;F5E('9A:6AT86$*("`@
M(&UY)B-X1C8[<R!V:65S=&EN(&]T<VEK:V]A+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO<'1I;VYS(B!M9#4](C5F,60U
M,&$W,S-C.&(W930V865C96-E,C@X,C)F9C<P(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/E9I97-T:6X@:VER:F]I='5S.B!,:7,F(WA%-#MT;VEM
M:6YN;W0\+W1I=&QE/@H@("`@/&AE861I;F<^3&ES)B-X130[=&]I;6EN;F]T
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!.)B-X130[;28C>$4T.R!L:7,F
M(WA%-#MT;VEM:6YN;W0@;W9A="!A<'5N82!V:65S=&EE;B!K:7)J;VET=&%M
M:7-E96XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($YA<'-A=71A(")/
M:6ME:6YK:7)J;VET=7,B('1A<FMI<W1A86MS97-I('9I97-T:6X@;VEK96EN
M:VER:F]I='5K<V5N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!.87!S
M875T82`B3&EI='1E970B(&UE;FXF(WA%-#MK<V5S:2!V:65S=&ES:79U;B!L
M;W!P=75N+"!J;W-S82!V;VET(&QI:71T)B-X130[)B-X130[('9I97-T:6EN
M(&QI:71E=&EE9&]S=&]J82X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M5F%I;B!J;W,@>6QL)B-X130[<&ET)B-X130[:B8C>$4T.R!O;B!S86QL:6YU
M="!T)B-X130[;28C>$4T.VX@=&]I;6EN;F]N(&LF(WA%-#MY='0F(WA%-#MM
M:7-E;BX@5F]I=`H@("`@=&%L;&5T=&%A('9I97-T:7-T)B-X130[(&MO<&EO
M;B!L)B-X130[:'1E=FEE;B!V:65S=&EE;B!K86YS:6]O;B!T86D*("`@('9A
M;&ET<V5M86%S:2!K86YS:6]O;BX@3"8C>$4T.VAT979I96X@=FEE<W1I;B!K
M86YS:6]N('9O:2!M)B-X130[)B-X130[<FET96QL)B-X130["B`@("`B07-E
M='5K<V5T+29G=#M/;6%T('1I961O="TF9W0[4')O9FEI;&ET(BX@2F]S('EL
M;"8C>$4T.W!I="8C>$4T.VHF(WA%-#L@;VX*("`@('-A;&QI;G5T('1O:6UI
M;FYO;BP@;FEI;B!V;VET('9A;&ET82!T86QL971U<VMA;G-I;VX*("`@(&%L
M87-V971O=F%L:6MO<W1A+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!6
M;VD@;VQL82!I:&%N(&AY=B8C>$4T.R!T87!A('1A;&QE='1A82!K;W!I;R!T
M)B-X130[<FME)B-X130[:W-I(&MA='-O;6ES=&%S:0H@("`@=FEE<W1E:70F
M(WA%-#LN($]N(&UY)B-X1C8[<R!M86AD;VQL:7-T82!L86ET=&%A('`F(WA%
M-#LF(WA%-#ML;&4@87-E='5S+"!J;VQL80H@("`@=&%L;&5T870@:V]P:6]I
M;B!K86EK:7-T82!L)B-X130[:'1E=FES="8C>$4T.R!V:65S=&5I<W0F(WA%
M-#L*("`@(")!<V5T=6MS970M)F=T.T]M870@=&EE9&]T+29G=#M0<F]F:6EL
M:70M)F=T.TUU;VMK86$*("`@('!R;V9I;&EA(BX@07-E='5K<VES=&$@=F]I
M="!M>28C>$8V.W,@;28C>$4T.R8C>$4T.W)I=&5L;"8C>$4T.R!Y;&PF(WA%
M-#MP:71O=&]I;65N<&ET96ET)B-X130[+`H@("`@:F]I;&QA('9O:70@;FEM
M970F(WA%-#L@;B8C>$4T.VTF(WA%-#L@:V%N<VEO="!U=61E<W1A86X@=&EE
M='EI;B!V)B-X130[;&EA:F]I;BX*("`@(#PO<&%R83X*("`@(#QW87)N/@H@
M("`@4VEN=6X@96D@:V%N;F%T82!T86QL971T86$@:V%I:VMI82!V:65S=&5J
M)B-X130[+"!K;W-K82!T86QL971E='5T"B`@("!V:65S=&ET('9I978F(WA%
M-#MT('1I;&%A(&IA('!O<W1I:VEI;G1I)B-X1C8[="8C>$4T.RX@2F]S('-I
M;G5L;&$@;VX@<&%L:F]N('1A;&QE=&5T='5J82!V:65S=&5J)B-X130[(&IA
M(&YI:7-S)B-X130[(&]N(&ES;VIA(&QI:71E=&EE9&]S=&]J82P@;FEI;B!P
M;W-T:6MI:6YT:28C>$8V.W-I('9O:2!T)B-X130[>71T>28C>$4T.R!H>79I
M;FMI;B!N;W!E87-T:2X@2F]S('!O<W1I:VEI;G1I)B-X1C8[<VD@;VX*("`@
M('0F(WA%-#MY;FXF(WA%-#LL(&YI:6X@970@=F]I('9A<W1A86YO='1A82!U
M=7-I82!V:65S=&5J)B-X130[+@H@("`@/"]W87)N/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B('-T871E/2)U<'1O9&%T92(@;60U
M/2)E.#`V935E,38T,69B,C4S,6-C.35D,F1F,C<W.#4Q9B(^"B`@("`\=&ET
M;&4^5FEE<W1I;B!K:7)J;VET=7,Z($QI:70F(WA%-#L\+W1I=&QE/@H@("`@
M/&AE861I;F<^3&EI="8C>$4T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5F]I="!L:6ET="8C>$4T.R8C>$4T.R!V:65S=&EI<VD@;&EI=&5T:65D;W-T
M;VIA+"!J;W,@<V5L86EM97-I('1U:V5E"B`@("!T:65D;W-T;VIE;B!T=6]M
M:7-T82X@5F]I="!T=6]D82!V86EN('EH9&5N('1I961O<W1O;B!K97)R86QL
M86%N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!<VME;"`Q.B!+:7)J
M;VET82!T:65D;W-T;VX@;FEM:2!J82!P;VQK=2P@=&%I(&YA<'-A=71A(")3
M96QA82(*("`@('!A:6YI:V5T=&$@:F$@=F]I="!V86QI=&$@='5O=&%V86X@
M=&EE9&]S=&]N+B!686QI;FYA;B!J)B-X130[;&ME96X*("`@('1I961O<W1O
M;B!N:6UI(&IA('!O;&MU(&XF(WA%-#MK>7D@:V5N="8C>$4T.W-S)B-X130[
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!<VME;"`R.B!686QI='-E
M(&UI=&5N(&AA;'5A="!T:65D;W-T;VX@;B8C>$4T.VMY=B8C>$4T.VX@;&EI
M='1E96XF(WA%-#L@=F%I(&UU=6X*("`@('9I97-T:6X@>6AT97ED97-S)B-X
M130[+B!*;W,@=F%S=&%A;F]T=&%J86X@<R8C>$4T.VAK)B-X1C8[<&]S=&EO
M:&IE;&UA(&5I('!Y<W1Y"B`@("!N)B-X130[>71T)B-X130[;28C>$4T.R8C
M>$4T.VX@;&EI=&5T="8C>$4T.R!V:65S=&EN('EH=&5Y9&5S<R8C>$4T.RP@
M;FEI;B!L:6ET92!N)B-X130[:WEY"B`@("!T879A;&QI<V5N82!L:6ET971I
M961O<W1O;F$N"B`@("`\+W!A<F$^"B`@("`\=&EP/@H@("`@2'5O;6%A=&AA
M;B!E='0F(WA%-#L@<W5U<G1E;B!T:65D;W-T;VIE;B!T=6]N=&D@<V%A='1A
M82!K97-T)B-X130[)B-X130[(&IA"B`@("!V:65D)B-X130[(&MA=6%N(&%I
M:V%A+B!%=&5N:VEN(&IO<R!T:65D;W-T;R!O;B!S=75R:2!T86D@:R8C>$4T
M.WET)B-X130[=`H@("`@:&ED87-T82!Y:'1E>71T)B-X130[(&EN=&5R;F5T
M=&EI;BX@2V%N;F%T=&%A('9A:6X@;V1O='1A80H@("`@<F%U:&%L;&ES97-T
M:2!J82!M=6ES=&$@;7DF(WA&-CMS(&5T="8C>$4T.R!S86UA86X@86EK86%N
M(&5I('-A82!N87!S875T=&%A(&UU:71A"B`@("!P86EN:6MK96ET82!T86D@
M;75I=&$@;&EN:VME:B8C>$4T.RX*("`@(#PO=&EP/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(@<W1A=&4](G5P=&]D871E
M(B!M9#4](CAA8S`S,F,T86,Q.#)F,V8P9#8T-#9C,C!F,#`X.61D(CX*("`@
M(#QT:71L93Y6:65S=&EN(&MI<FIO:71U<SH@3&EI='1E970\+W1I=&QE/@H@
M("`@/&AE861I;F<^3&EI='1E970\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%0F(WA%-#MS<R8C>$4T.R!O<VEO<W-A(&]N(&QI<W1A(&QI:71E='EI<W0F
M(WA%-#L@;&EI=&5T:65D;W-T;VES=&$N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY0;VES=&$@;&EI=&5T='D@;&EI=&5T:65D;W-T;SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@4&]I<W1A86MS97-I(&QI:71E='EN(&QI:71E=&EE
M9&]S=&]N.@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!<VME;"`Q.B!6
M86QI='-E('!O:7-T971T879A(&QI:71E=&EE9&]S=&\@:R8C>$4T.WET="8C
M>$4T.V5N('9A;&EN=&%L86%T:6MK;V$N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@($%S:V5L(#(Z($YA<'-A=71A(")0)B-X130[:79I="8C>$4T.R!L
M:6ET971I961O<W1O;B!T:65D;W0B+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^3&EI=&5T879A;B!M=75T;W,\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($UU=71T86%K<V5S:2!L:6ET=&5E;B!L:6ET971A<&%A.@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("!!<VME;"`Q.B!-=75T82!L:6ET=&5E;B!T>7EP
M<&DF(WA%-#L@:&%L=71T=75N(&UU;W1O;VX@:F]K;R`B=FEE<W1I;@H@("`@
M>6AT97ED97-S)B-X130[(B!T86D@(FQI:71E(BX*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@07-K96P@,CH@3F%P<V%U=&$@(E`F(WA%-#MI=FET)B-X
M130[(&QI:71E=&EE9&]S=&]N('1I961O="(N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY-=75T82!L:6ET=&5E;B!K=79A=7-T83PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@375U='1A86MS97-I(&QI:71T965N(&MU=F%U<W1A("AK
M=79A879A('1E:W-T:2P@:F]K82!N)B-X130[:WEY('9I97-T:6X@=F%S=&%A
M;F]T=&%J86QL92DZ"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%S:V5L
M(#$Z($MI<FIO:71A(&MU=F%U<R!K=79A=7-K96YT="8C>$4T.R8C>$4T.VXN
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%S:V5L(#(Z($YA<'-A=71A
M(")0)B-X130[:79I="8C>$4T.R!L:6ET971I961O<W1O;B!T:65D;W0B+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UP<FEO
M<FET>2(@<W1A=&4](G5P=&]D871E(B!M9#4](F(P,C,S-C=C,S9D93-C93$U
M-C=D,C=C8V%A-#4V-#!C(CX*("`@(#QT:71L93Y6:65S=&EN(&MI<FIO:71U
M<SH@4')I;W)I=&5E='1I/"]T:71L93X*("`@(#QH96%D:6YG/E!R:6]R:71E
M971T:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5"8C>$4T.VTF(WA%-#L@
M87-E='1A82!L)B-X130[:'1E=B8C>$4T.VX@=FEE<W1I;B`B6"U0<FEO<FET
M>2(*("`@("UO='-A:VME96XN(")8+5!R:6]R:71Y(B`M;W1S86MK965N(&LF
M(WA%-#MY="8C>$8V.W-T)B-X130[(&5I(&]L92!V87)S:6YA:7-T80H@("`@
M<W1A;F1A<F1I82P@;75T=&$@86EN86MI;B!.971S8V%P92P@36]Z:6QL82P@
M3W!E<F$@:F$@3W5T;&]O:PH@("`@:R8C>$4T.WET="8C>$4T.W8F(WA%-#MT
M('0F(WA%-#MT)B-X130[(&ME;G1T)B-X130[)B-X130[+B!*;W,@;VAJ96QM
M82!E:2!T=64@;W1S86ME='1A+"!N:6EN(&YE('9A:6X*("`@(&HF(WA%-#MT
M="8C>$4T.W8F(WA%-#MT('-E;B!H=6]M:6]T=&$N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7-A=F4M871T86-H;65N=',B
M('-T871E/2)U<'1O9&%T92(@;60U/2)D8C@Y.3<R8S1E8F(P8C0Q86(V.3%B
M-F$W-S0T83@Q9"(^"B`@("`\=&ET;&4^5FEE<W1I;B!K:7)J;VET=7,Z($QI
M:71T96ED96X@=&%L;&5T=7,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6;VET
M('9A;&ET82!T86QL971E=&%A;FMO(&QI:71E('9I97-T:6X@;75K86YA(&MU
M;B!V:65S=&D*("`@('1A;&QE=&5T86%N(&PF(WA%-#MH=&5V:65N('9I97-T
M:65N(&MA;G-I;V]N+B!*;W,@=F%L:71S970@(DMY;&PF(WA%-#LB+`H@("`@
M;FEI;B!L:6ET965T('1A;&QE=&5T86%N+B!*;W,@=F%L:71S970@(D5I(BP@
M;FEI;B!L:6ET971I961O<W1O"B`@("!P;VES=&5T86%N('9I97-T:7-T)B-X
M130[(&5N;F5N:W5I;B!S92!T86QL971A86X@;"8C>$4T.VAT979I96X@=FEE
M<W1I96X*("`@(&MA;G-I;V]N+B!686QI='-E;6%L;&$@(D5I(B!S)B-X130[
M)B-X130[<W0F(WA%-#MT(&QE=GET:6QA82!J82!V;VET('1A;&QE='1A80H@
M("`@=7-E86UP:6$@=FEE<W1E:B8C>$4T.RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](F-O;7!O<V4M;&EN:RUA='1A8VAM96YT<R(@<W1A
M=&4](G5P=&]D871E(B!M9#4](F$W8F(P-#$R8C`S,V%B9&)B83)F-35B.&(X
M-&0V8S<V(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!,:6YK
M($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE
M<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N
M(&%R92!S96YT(&%S(&$@<&%R="!O9B!T:&4@;6%I;"!M97-S86=E(&]R('=H
M971H97(@=&AO<V4@871T86-H;65N=',@87)E(&ME<'0@;VX@82!L;V-A;"!S
M97)V97(N("!)9B!A='1A8VAM96YT<R!A<F4@;&EN:V5D+"!T:&4@<F5C:7!I
M96YT*',I(&]F('EO=7(@;65S<V%G92!W:6QL(&)E('!R;W9I9&5D(&$@=V5B
M;&EN:R!W:&5R92!T:&5Y(&-A;B!D;W=N;&]A9"!T:&4@871T86-H;65N="AS
M*2X@($QI;FMI;F<@871T86-H;65N=',@:&%S('1H92!A9'9A;G1A9V4@;V8@
M=')E;65N9&]U<VQY(')E9'5C:6YG('1H92!S:7IE(&]F(&]U=&=O:6YG(&UE
M<W-A9V5S+B`@3&EN:VEN9R!A='1A8VAM96YT<R!H87,@=&AE(&1I<V%D=F%N
M=&%G92!T:&%T('1H92!C;VYT96YT(&]F('1H92!A='1A8VAM96YT<R!C86X@
M;F]T(&)E(&=U87)A;G1E960@=&\@8F4@879A:6QA8FQE(&EN('1H92!F=71U
M<F4@<VEN8V4@=&AE(&%T=&%C:&UE;G0@9&%T82!I<R!N;W0@;&]C871E9"!W
M:71H:6X@=&AE(&4M;6%I;"!M97-S86=E+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<V5A<F-H(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M.#9B,F5F-3=B,3$Y-#@Y,#@S,V0Y9&0T.65B8SEB,S(B/@H@("`@/'1I=&QE
M/E9I97-T:6AA:W4\+W1I=&QE/@H@("`@/&AE861I;F<^2&%U;B!K<FET965R
M:70\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9O:70@971S:28C>$4T.R!V
M:65S=&5J)B-X130[(&MA;G-I;VES=&%S:2!A;G1A;6EE<VD@:W)I=&5E<FEE
M;B!P97)U<W1E96QL82X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("`@
M($%S:V5L(#$Z($MI<FIO:71A(&5T<VET="8C>$4T.W8F(WA%-#L@=&5K<W1I
M+"!J;VYK82!H86QU870@;&ES)B-X130[='0F(WA%-#MV)B-X130[;@H@("`@
M("`@(&AA:W5K<FET965R96EH:7-I+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("`@("`@07-K96P@,CH@5F%L:71S92!V:65S=&EN('9I97-T:6X@=&EL
M871I961O="P@:F]T:V$@:&%L=6%T"B`@("`@("`@;&ES)B-X130[='0F(WA%
M-#MV)B-X130[;B!H86MU:W)I=&5E<F5I:&ES:2X*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@("`@($%S:V5L(#,Z(%9A;&ET<V4@:V%N<VEO="P@:F]I
M<W1A('9I97-T96HF(WA%-#L@971S:70F(WA%-#LF(WA%-#MN+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("`@("`@07-K96P@-#H@3F%P<V%U=&$@(DAA
M92(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($IO<R!J;VMI;B!V:65S
M=&D@=F%S=&%S:2!H86MU:W)I=&5E<F5I="8C>$4T.W-I+"!N:6EN(&XF(WA%
M-#MI9&5N('9I97-T:6X*("`@(&]T<VEK;W0@;B8C>$4T.VMY=B8C>$4T.W0@
M(DAA=6X@='5L;VMS970B(&XF(WA%-#MK>6TF(WA%-#MS<R8C>$4T.RX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUO<'1I;VYS
M(B!M9#4](C,P-C@W96,T-S4W-C5B830T-C=D,F5F-F1C96,T,&,S(B!S=&%T
M93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DMA;G-I;VED96X@:&%L;&EN=&$Z
M(%1O:6UI;FYO=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY+86YS:6]T;VEM:6YN
M;W0\+VAE861I;F<^"B`@("`\<&%R83X*("`@("!6;VET('9A;&ET82!K86YS
M:6]N(&LF(WA%-#MY='0F(WA%-#MM)B-X130[;&PF(WA%-#L@<F%D:6]P86EN
M:6MK96ET82!V87-E;6UA<W-A"B`@("`@<V%R86MK965S<V$N($MU;B!O;&5T
M('9A;&EN;G5T(&MA;G-I;W0L(&YI:6X@=F%L:71S92!K86YS:6]L;&4*("`@
M("!T96AT)B-X130[=B8C>$4T.R!T;VEM:6YT;R!A;&%S=F5T;W9A;&EK;W-T
M82X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("!2:6EP<'5E;B!T;VEM
M:6YN;W-T82P@<VEN=6QT82!V;VED86%N(&MY<WDF(WA%-#L@=FEE;"8C>$4T
M.PH@("`@("!L:7,F(WA%-#MT:65T;VIA+B!/;&4@97)I='0F(WA%-#MI;B!V
M87)O=F%I;F5N(%!O:7-T82!T;VEM:6YN;VX*("`@("`@:V%N<W-A+B!*;W,@
M<&]I<W1A="!K86YS:6]N+"!N:6EN('!O:7-T870@;7DF(WA&-CMS(&MA:6MK
M:2!K86YS:6]S<V$*("`@("`@;VQE=F%T('9I97-T:70N"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY4=6\@=FEE<W1E:B8C>$4T.SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@("!4)B-X130[;&PF(WA%-#L@=&]I;6EN;F]L;&$@=F]I
M="!T=6]D82!V:65S=&5J)B-X130[(&UB;W@@=&%I("YE;6P@=&EE9&]S=&]I
M<W1A"B`@("`@('9A;&ET<V5M86%S:2!K86YS:6]O;BX@5F%L:71S92!E;G-I
M;B!Y:W-I(&MA;G-I;RP@:F]H;VX@=FEE<W1I=`H@("`@("!T=6]D86%N(&IA
M('9A;&ET<V4@<VET=&5N('0F(WA%-#MM)B-X130[('1O:6UI;G1O+B!396X@
M:B8C>$4T.VQK965N('1U;&5T"B`@("`@('-I=G5L;&4L(&IO<W-A(&MY<WET
M)B-X130[)B-X130[;B!T=6]T:V\@=FEE<W1E:B8C>$4T.R!M8F]X('9A:2`N
M96QM"B`@("`@('1I961O<W1O<W1A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9F]L9&5R+7=I9&=E=',B(&UD-3TB8CEB8S8X.30P,F8W
M-3<U-S<Q9#<T-3<P93=F-F8X,&$B('-T871E/2)U<'1O9&%T92(^"B`@("`\
M=&ET;&4^2V%N<VEO:61E;B!H86QL:6YT83H@3B8C>$4T.VMY;28C>$4T.SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY.)B-X130[>70F(WA%-#LO4&EI;&]T82!T
M:6QA86UA='1O;6%T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!*;W,@:R8C
M>$4T.WET)B-X130[="!)34%0+7!R;W1O:V]L;&%A;B!S:7,F(WA%-#ML='EV
M)B-X130[)B-X130[(&MA;G-I;VED96X@=&EL875S=&$L(&YI:6X*("`@('9O
M:70@;B8C>$4T.WET="8C>$4T.R8C>$4T.R]P:6EL;W1T86$@=&EL86%M871T
M;VUA="!K86YS:6]T+B!-=75T=&%A:W-E<VD@:V%N<VEO;@H@("`@=&EL875S
M=&EE=&]J82P@=F%L:71S92!E;G-I;B!K86YS:6\@:R8C>$4T.WET="8C>$4T
M.V5N('9A<V5M;6%N('-A<F%K:V5E;@H@("`@=F%L:6YT86QA871I:V]I=&$@
M:F$@=F%L:71S92!S:71T96X@86QA<W9E=&]V86QI:V]S=&$@=&]I;6EN=&\*
M("`@(")4:6QA82(@=&%I("),;W!E=&$@=&EL875S(BX*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/DQA86IE;FYA(&MA:6MK:3PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@3B8C>$4T.WET="8C>$4T.R8C>$4T.R!K86EK:VD@:V%N<VEO
M="!J82!N:6ED96X@86QI:V%N<VEO="X*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/E!I96YE;FXF(WA%-#L@:V%I:VMI/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!0:6EL;W1T86$@;B8C>$4T.VMY=FES="8C>$4T.R!K86EK:VD@;75U
M="!P86ET<VD@<"8C>$4T.R8C>$4T.VMA;G-I;VXN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97)S(B!M9#4](C5E9C8P-S@V-S8W
M938S.&9B9C5B83AF8S5B9#5D.60R(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@
M/'1I=&QE/E-U;V1A='1I;65T.B!+)B-X130[>71T)B-X1C8[/"]T:71L93X*
M("`@(#QH96%D:6YG/E-U;V1A=&EN<R8C>$4T.R8C>$4T.VYT)B-X1C8[:F5N
M(&LF(WA%-#MY='0F(WA&-CL\+VAE861I;F<^"B`@("`\<&%R83X*("`@($YA
M<'-A=71A(")3=6]D871A('9I97-T:70B("UI:V]N:6$@24Y"3U@@;FEM96X@
M=FEE<F5S<R8C>$4T.PH@("`@<&]S=&EK86YS:6]N)B-X130[:WEM)B-X130[
M<W,F(WA%-#L@<W5O9&%T=&%A:W-E<VD@=FEE<W1I="!M)B-X130[)B-X130[
M<FET=&5L96UI97-I"B`@("!S=6]D871U<W,F(WA%-#LF(WA%-#MN="8C>$8V
M.VIE;B!M=6MA86XN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)F:6QT97(M961I="UR=6QE<R(@;60U/2(U8F%A-3<P.&%C.30T.64W.3=F
M.38W,S$S83EE,6$R-R(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y3
M=6]D871T:6UE=#H@375O:VMA82!S=6]D871I;G,F(WA%-#LF(WA%-#MN="8C
M>$8V.VHF(WA%-#L\+W1I=&QE/@H@("`@/&AE861I;F<^375O:VMA82!S=6]D
M871I;G,F(WA%-#LF(WA%-#MN="8C>$8V.VHF(WA%-#MS:3PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@3F%P<V%U=&$@(DUU;VMK86$@<W5O9&%T=&EM:6$B
M('`F(WA%-#LF(WA%-#MS="8C>$4T.VMS97-I('-I=G5L;&4L(&IO<W-A('9O
M:70*("`@(&QI<R8C>$4T.W0F(WA%-#LL('!O:7-T86$@:F$@;75O:V%T82!K
M)B-X130[>70F(WA&-CMS<R8C>$4T.R!O;&5V:6$@<W5O9&%T:6YS)B-X130[
M)B-X130[;G0F(WA&-CMJ)B-X130[+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M8FQA8VML:7-T(B!M9#4](C@P9F8W
M.#`S8S8V-3DY8S<P,S5F-V8X.#$Q9#(Q.&-C(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/E-U;V1A='1I;65T.B!-=6]K:V%A(&UU<W1A82!L:7-T
M86$\+W1I=&QE/@H@("`@/&AE861I;F<^375O:VMA82!M=7-T86$@;&ES=&%A
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!.87!S875T82`B375O:VMA82!M
M=7-T86$@;&ES=&%A(B!P)B-X130[)B-X130[<W0F(WA%-#MK<V5S:2!S:79U
M;&QA+"!J;W-S82!V;VET"B`@("!L:7,F(WA%-#MT)B-X130[+"!P;VES=&%A
M(&IA(&UU;VMA=&$@;&ES=&%A(&YI:7-T)B-X130[(',F(WA%-#MH:R8C>$8V
M.W!O<W1I;W-O:71T96ES=&$L"B`@("!J;VES=&$@970@;W1A('9A<W1A86X@
M<R8C>$4T.VAK)B-X1C8[<&]S=&EA+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M=VAI=&5L:7-T(B!M9#4](C,S,&,S
M83AF860Q.3AC-V%F93@U-6,Q,#%C-C-C9#!F(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/E-U;V1A='1I;65T.B!-=6]K:V%A('9A;&MO:7-T82!L
M:7-T86$\+W1I=&QE/@H@("`@/&AE861I;F<^375O:VMA82!V86QK;VES=&$@
M;&ES=&%A/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!.87!S875T82`B375O
M:VMA82!V86QK;VES=&$@;&ES=&%A(B!P)B-X130[)B-X130[<W0F(WA%-#MK
M<V5S:2!S:79U;&QA+"!J;W-S80H@("`@=F]I="!L:7,F(WA%-#MT)B-X130[
M+"!P;VES=&%A(&IA(&UU;VMA=&$@;&ES=&%A(&YI:7-T)B-X130["B`@("!S
M)B-X130[:&LF(WA&-CMP;W-T:6]S;VET=&5I<W1A+"!J;VES=&$@;W1A="!!
M24Y!('9A<W1A86X@<R8C>$4T.VAK)B-X1C8[<&]S=&EA+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!M9#4]
M(C,W9#DR.3=D,6-C830V-#,U93,V8C9E,SAE-#5D8V1B(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/E-U;V1A='1I;65T.B!3=6]D871U<R!S:7,F
M(WA%-#LF(WA%-#MN:VER:F%U='5E<W-A/"]T:71L93X*("`@(#QH96%D:6YG
M/E-U;V1A=&$@=FEE<W1I="!S:7,F(WA%-#LF(WA%-#MN:VER:F%U='5M:7-E
M;B!Y:'1E>61E<W,F(WA%-#LN/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!+
M=6X@=F%L:71S970@="8C>$4T.VTF(WA%-#MN(&%S971U:W-E;BP@;FEI;B!S
M=6]D871T:6UE="!A:F5T86%N(&%I;F$@:W5N"B`@("!K:7)J875D=70@<VES
M)B-X130[)B-X130[;B!)35`M;VAJ96QM86%N+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+61I<W!L87DB(&UD-3TB9C5A
M9F,S,#4T,#)E9C4R8F%D,3`X.3,S9C-F,S,R.3$B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^4W5O9&%T=&EM970Z(%-U;V1A=&$@<"8C>$4T.VEV
M:71Y:W-E;B!Y:'1E>61E<W,F(WA%-#L\+W1I=&QE/@H@("`@/&AE861I;F<^
M4W5O9&%T82!V:65S=&ET(&MU;B!)3D)/6"!P;W-T:6MA;G-I;V$@<"8C>$4T
M.VEV:71E="8C>$4T.R8C>$4T.VXN/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!+=6X@=F%L:71S970@="8C>$4T.VTF(WA%-#MN(&%S971U:W-E;BP@;FEI
M;B!S=6]D871T:6UE="!A:F5T86%N(&%I;F$@:W5N"B`@("!)3D)/6#IA('`F
M(WA%-#MI=FET970F(WA%-#LF(WA%-#MN+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6%N>2UM86EL8F]X(B!M9#4](C<Q8S4Q
M93@S.3`Y9CED,&)D-#0P9#(R,#<W,F5E,V,V(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/E-U;V1A='1I;65T.B!3=6]D871A(&UI="8C>$4T.R!T
M86AA;G-A('!O<W1I:V%N<VEO83PO=&ET;&4^"B`@("`\:&5A9&EN9SY+)B-X
M130[>70F(WA%-#L@<W5O9&%T=&EM:6$@;6EH:6X@:V%N<VEO;VX@=&%H86YS
M82X\+VAE861I;F<^"B`@("`\<&%R83X*("`@($LF(WA%-#MY="8C>$4T.R!T
M)B-X130[="8C>$4T.R!A<V5T=7-T82!J;W,@:&%L=6%T(&LF(WA%-#MY='0F
M(WA%-#LF(WA%-#L@<W5O9&%T=&EM:6$@;6EH:6X@:V%N<VEO;VX*("`@('1A
M:&%N<V$N(%EL965N<R8C>$4T.R!S=6]D871T:6UI82!K)B-X130[>71E="8C
M>$4T.R8C>$4T.VX@=F%I;B!N:6EH:6X@:V%N<VEO:6AI;BP*("`@(&IO:6AI
M;B!T=6QE92!U=7-I82!V:65S=&5J)B-X130[(&MU=&5N($E.0D]8+B!*;W,@
M="8C>$4T.VTF(WA%-#L@87-E='5S(&]N"B`@("!V86QI='1U;F$L(&YI:6X@
M(E-U;V1A=&$@=FEE<W1I="(@+6EK;VYI('1U;&5E(&MA:6MK:65N(&MA;G-I
M;VED96X*("`@(&MA;G-I;VXF(WA%-#MK>6UI:6X@:F$@=F]I="!K)B-X130[
M>71T)B-X130[)B-X130[(&XF(WA%-#MI<W,F(WA%-#MK:6X@:V%N<VEO:7-S
M80H@("`@;28C>$4T.R8C>$4T.W)I='1E;&5M:28C>$4T.W-I('-U;V1A='1I
M;6EA+B!(54]-24\Z(%-U;V1A='1I;6EE;B!K)B-X130[>71T)B-X1C8[(&UU
M:7-S80H@("`@:W5I;B!)3D)/6"!K86YS:6]S<V$@=F]I(&%I:&5U='1A82!O
M;6ET=6ES:6$@;&]P<'5T=6QO:W-I80H@("`@*&5S:6UE<FMI:W-I.B!S=6]D
M871I;B!V;VD@86EH975T=&%A('-E;B!E='0F(WA%-#L@=FEE<W1E:B8C>$4T
M.R!K;W!I;VED86%N"B`@("!S86UA<W1A(&MA;G-I;W-T82!S86UA86X@:V%N
M<VEO;VXI('1A:2!E:2UT;VEV;W1T=6IA(&QO<'!U='5L;VMS:6$*("`@("AE
M<VEM97)K:6MS:3H@=FEE<W1E:B8C>$4T.R!V;VD@<VEI<G1Y)B-X130[('1A
M:2!K861O=&$L(&IO<R!U=7-I80H@("`@<W5O9&%T=&EM:6$@;VX@='5L;'5T
M(&LF(WA%-#MY="8C>$8V.R8C>$8V.VX@<V5N(&HF(WA%-#ML:V5E;B!K=6X@
M=FEE<W1I="!O;@H@("`@=&%L;&5T971T=2!K86YS:6]O;BDN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M
M<'5B:V5Y(B!M9#4](CDW-#0V9&)B8C(W-C$V8C1F83,Y8F4X,#%E,3!D9C)D
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@3&EI="8C>$4T
M.R!J=6QK:6YE;B!A=F%I;CPO=&ET;&4^"B`@("`\:&5A9&EN9SY,:6ET)B-X
M130[(&IU;&MI;F5N(&%V86EN/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!*
M;W,@="8C>$4T.VTF(WA%-#L@=&]I;6EN=&\@;VX@=F%L:71T=6YA(&IA(&IO
M<R!S:6YU;&QA(&]N(&IU;&MI;F5N"B`@("!01U`M879A:6XL(&YI:6X@<V4@
M;&EI=&5T)B-X130[)B-X130[;B!L)B-X130[:'1E=FEI;B!V:65S=&5I:&EN
M+B!6;VET(&%S971T86$*("`@(&]L971U<W1O:6UI;FYO;B!01U`@07-E='5K
M<V5T(&XF(WA%-#MK>6TF(WA%-#MS="8C>$4T.RX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I;VXM<V-A;BUB;V1Y(B!M9#4]
M(C9B86%A9&$P9#0V9&,Q86(P.30Q,#@W9C(S-68S-3EB(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@171S:2!V:65S=&EE;B!V:65S=&EO
M<V%S=&$\+W1I=&QE/@H@("`@/&AE861I;F<^171S:2!V:65S=&EE;B!V:65S
M=&EO<V%S=&$\+VAE861I;F<^"B`@("`\<&%R83X*("`@($IO<R!T)B-X130[
M;28C>$4T.R!O;B!V86QI='1U;F$L(&YI:6X@24U0(&5T<VEI('9I97-T:6X@
M=FEE<W1I;W-A<W1A"B`@("!01U`M=&EE=&]J82!J82!N)B-X130[>71T)B-X
M130[)B-X130[('1U;&]K<V5T(&IO<R!J;W1A:6X@=&EE=&]J80H@("`@;"8C
M>$8V.WET>6DN($AU;VUI;VET:&%N(&5T="8C>$4T.R!T)B-X130[;28C>$4T
M.R!T;VEM:6YT;R!V;VD@:'5O;6%T=&%V87-T:2!H:61A<W1A80H@("`@:V]K
M;R!J)B-X130[<FIE<W1E;&TF(WA%-#MN('1O:6UI;G1A82P@:V]S:V$@:F]K
M86EN96X@=FEE<W1I(&IO=61U=&%A;@H@("`@:R8C>$4T.WEM)B-X130[)B-X
M130[;B!K;VMO;F%A;B!L)B-X130[=FET<V4N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,M96YC<GEP="(@;60U
M/2(Q,#$R,30T9C<T.68Q.68U83(T8V5F,S@V,#%D86$W,2(@<W1A=&4](G5P
M=&]D871E(CX*("`@(#QT:71L93Y+:7)J;VET=7,Z(%-A;&%U<V%S971U:W-E
M=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY%:2!S86QA=7-T83PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@3"8C>$4T.VAE="8C>$4T.R!V:65S=&D@:6QM86X@
M<V%L875S=&$@*'-E;'8F(WA%-#MK:65L:7-E;B8C>$4T.RDN"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY01U`M<V%L871T=2!V:65S=&D\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($LF(WA%-#MY='0F(WA%-#MM)B-X130[;&PF(WA%
M-#L@="8C>$4T.W0F(WA%-#L@87-E='5S=&$@=F]I="!S86QA=&$@;"8C>$4T
M.VAT978F(WA%-#MN('9I97-T:6X@:R8C>$4T.WET="8C>$4T.V5N"B`@("!0
M1U`M;VAJ96QM86$@:F$@=F%S=&%A;F]T=&%J86X@:G5L:VES=&$@879A:6YT
M82X@4$=0+7-A;&%T=6X*("`@('9I97-T:6X@=F]I(&PF(WA%-#MH971T)B-X
M130[)B-X130[('9A:6X@:F$@86EN;V%S=&%A;B!Y:&1E;&QE"B`@("!V87-T
M86%N;W1T86IA;&QE+B!3:6YU;&QA('!I="8C>$4T.R8C>$4T.R!O;&QA('9A
M<W1A86YO='1A:F%N(&IU;&MI;F5N(&%V86EN"B`@("!T86QL971E='1U;F$@
M;W-O:71E:VER:F%A;B!T86D@970@=F]I(&PF(WA%-#MH971T)B-X130[)B-X
M130[('-A;&%T='5A"B`@("!V:65S=&DF(WA%-#LN($IO<R!V:65S=&EN(&PF
M(WA%-#MH971Y<R!E:2!O;FYI<W1U('-I='1E;FLF(WA%-#LF(WA%-#MN(&IA
M('-A870*("`@('9I<FAE:6QM;VET=6MS96XL(&YI:6X@=&%R:VES=&$@971T
M)B-X130[(&IU;&MI<V5S<V$@879A:6UE<W-A(&]L979A"B`@("!S)B-X130[
M:&LF(WA&-CMP;W-T:6]S;VET92!O;B!S86UA(&MU:6X@=F%S=&%A;F]T=&%J
M86X@<R8C>$4T.VAK)B-X1C8[<&]S=&EO<V]I=&4N($MU;@H@("`@<V%L875S
M(&]N(&]N;FES='5N=70L(&YI:6X@<V%L871T=2!T:65T;R!L:6ET970F(WA%
M-#LF(WA%-#MN(&PF(WA%-#MH=&5V)B-X130[)B-X130[;@H@("`@=FEE<W1I
M:6XN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`M86QL96MI<FIO:71A
M('9I97-T:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@2R8C>$4T.WET="8C
M>$4T.VTF(WA%-#ML;"8C>$4T.R!T)B-X130[="8C>$4T.R!A<V5T=7-T82!V
M;VET(',F(WA%-#MH:R8C>$8V.VES97-T:2!A;&QE:VER:F]I='1A82!L)B-X
M130[:'1E=B8C>$4T.VX*("`@('9I97-T:6X@:R8C>$4T.WET="8C>$4T.V5N
M(%!'4"UO:&IE;&UA82!J82!V87-T86%N;W1T86IA;B!J=6QK:7-T80H@("`@
M879A:6YT82X@2F]S(&5T(&]L92!J;R!A;G1A;G5T('-A;&%S86YA=&5K<W1I
M)B-X130[<VDL(&YI:6X@875K96%A"B`@("!E<FEL;&EN96X@:6MK=6YA(&IO
M<W-A('-I;G5A('!Y>61E="8C>$4T.R8C>$4T.VX@86YT86UA86X*("`@('-A
M;&%S86YA=&5K<W1I<VDN(%9A<W1A86YO='1A:F%L;&$@<&ET)B-X130[)B-X
M130[(&]L;&$@=&%L;&5T971T=6YA('-I;G5N"B`@("!J=6QK:6YE;B!A=F%I
M;65S:2P@:F]T=&$@:"8C>$4T.VX@=F]I('1A<FMI<W1A82!V:65S=&ES:2!E
M:&5Y9&5N+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0+7-A;&%A(&IA
M(&%L;&5K:7)J;VET82!V:65S=&D\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($LF(WA%-#MY='0F(WA%-#MM)B-X130[;&PF(WA%-#L@="8C>$4T.W0F(WA%
M-#L@87-E='5S=&$@=F]I="!S)B-X130[:&LF(WA&-CMI<V5S=&D@86QL96MI
M<FIO:71T86$@<V%L871A(&PF(WA%-#MH=&5V)B-X130[;B!V:65S=&EN(&LF
M(WA%-#MY='0F(WA%-#ME;B!01U`M;VAJ96QM86$N($MA='-O('1A<FME;6UA
M="!T:65D;W0@:V]H9&ES=&$@(E!'4"US86QA='1U('9I97-T:2(@:F$@(E!'
M4"UA;&QE:VER:F]I=&$@=FEE<W1I(BX*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/E,O34E-12US86QA82!V:65S=&D\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($](2D4@5$5+14E,3"8C>$,T.RX*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/E,O34E-12UA;&QE:VER:F]I=&$@=FEE<W1I/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!/2$I%(%1%2T5)3$PF(WA#-#LN"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY3+TU)344M<V%L86$@:F$@86QL96MI<FIO:71A('9I97-T
M:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3TA*12!414M%24Q,)B-X0S0[
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]V97)V
M:65W(B!M9#4](C(T8C4Q,SAB-&(U,V8W,V(U9C)F,C<S.64T8S$X-3AD(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@66QE:7-K=79A/"]T
M:71L93X*("`@(#QH96%D:6YG/DUI:R8C>$4T.R!O;B!01U`_/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!01U`@;VX@;VAJ96QM82P@:F]K82!O;B!K96AI
M=&5T='D@='5R=F%A;6%A;B!T:65D;VYS:6ER=&]A"B`@("!E<VEM97)K:6MS
M:2!S)B-X130[:&LF(WA&-CMP;W-T:7-S82!J82!T:65D;VX@='5R=F%L;&ES
M=&$*("`@('1A;&QE='5S=&$N($]H:F5L;6%A('9O:61A86X@:R8C>$4T.WET
M="8C>$4T.R8C>$4T.R!S86QA86UA86X@=&EE=&]A(&IA('-I;&PF(WA%-#L@
M=F]I"B`@("!T96AD)B-X130[(',F(WA%-#MH:R8C>$8V.VES:28C>$4T.R!A
M;&QE:VER:F]I='5K<VEA+B!)35`@:R8C>$4T.WET="8C>$4T.R8C>$4T.R!'
M;G501R`H1VYU(%!R:79A8WD*("`@($=U87)D*2!O:&IE;&UA82!T)B-X130[
M:"8C>$4T.VX@=&%R:V]I='5K<V5E;BX*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/DLF(WA%-#MY="8C>$4T.R!01U`M=&]I;6ET;V$N/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!*;W,@="8C>$4T.VTF(WA%-#L@87-E='5S(&]N('9A
M;&ET='5N82P@;FEI;B!V;VET(&QU;V1A('1A:2!K871S;V$*("`@(&AE;FMI
M;"8C>$8V.VMO:'1A:7-I82!01U`M879A:6UI82P@<&]I<W1A82!T86D@;&ES
M)B-X130[="8C>$4T.R!O<V]I=&5K:7)J86%N"B`@("!T;VES=&5N(&LF(WA%
M-#MY='0F(WA%-#MJ:65N(&IU;&MI<VEA(&%V86EM:6$L(&QU:V5A('-A;&%T
M='5A(',F(WA%-#MH:R8C>$8V.W!O<W1I82P*("`@('1A<FMI<W1A82!S)B-X
M130[:&LF(WA&-CMP;W-T:6X@<R8C>$4T.VAK)B-X1C8[:7-E;B!A;&QE:VER
M:F]I='5K<V5N+"!L)B-X130[:&5T="8C>$4T.R8C>$4T.PH@("`@<V%L871T
M=6$@<R8C>$4T.VAK)B-X1C8[<&]S=&EA('1A:2!S)B-X130[:&LF(WA&-CMI
M<V5S=&D@86QL96MI<FIO:71T86$@;"8C>$4T.VAT978F(WA%-#MN"B`@("!S
M)B-X130[:&LF(WA&-CMP;W-T:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C:"UP=6)K97DB(&UD-3TB-38Q
M8V4T,S,W,&%C-&%F8F-C,V8Y.#$X8SAF8F,R9C8B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^4$=0.B!!<V5T=6MS970@+2!,:6ET)B-X130[(&IU
M;&MI;F5N(&%V86EN/"]T:71L93X*("`@(#QH96%D:6YG/D%S971U:W-E="`M
M($QI:70F(WA%-#L@:G5L:VEN96X@879A:6X\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($IO<R!T)B-X130[;28C>$4T.R!A<V5T=7,@;VX@=F%L:71T=6YA
M(&IA(&IO<R!S:6YU;&QA(&]N(&]L96UA<W-A(&IU;&MI;F5N"B`@("!01U`M
M879A:6XL(&YI:6X@<V4@;&EI=&5T)B-X130[)B-X130[;B!O;&5T=6MS96YA
M(&MA:6MK:6EN(&PF(WA%-#MH=&5V:6EN"B`@("!V:65S=&5I:&EN+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6UA;F%G92UP=6)K
M97DB(&UD-3TB8C(X.65A-3@R-&(W9C8Y9C,U8S`W-3$T.3=F-&4Q8S,B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0.B!*=6QK:7-E;B!A=F%I
M;65N(&AA;&QI;G1A/"]T:71L93X*("`@(#QH96%D:6YG/EEL96ES:W5V83PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3&ES=&%A(&]S;VET96MI<FIA<W1A
M<VD@:V%I:VMI(&YE(&LF(WA%-#MY='0F(WA%-#MJ)B-X130[="P@:F]I9&5N
M(&IU;&MI;F5N"B`@("!01U`M879A:6X@;VX@=&%L;&5T971T=6YA(&]S;VET
M96MI<FIA87-I+B!.)B-X130[;28C>$4T.R!K)B-X130[>71T)B-X130[:B8C
M>$4T.W0*("`@(&UU;V1O<W1A=F%T(&IO=6MO;BP@:F]L;&4@=F]I="!L)B-X
M130[:&5T="8C>$4T.R8C>$4T.R!S86QA='1U82!S)B-X130[:&LF(WA&-CMP
M;W-T:6$@=&%I"B`@("!T87)K:7-T86$@:&5I9"8C>$4T.VX@;"8C>$4T.VAE
M='0F(WA%-#MM)B-X130[;G,F(WA%-#L@<R8C>$4T.VAK)B-X1C8[:7-E<W1I
M(&%L;&5K:7)J;VET971U;@H@("`@<R8C>$4T.VAK)B-X1C8[<&]S=&EN(&%L
M;&5K:7)J;VET=6MS96XN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY.)B-X
M130[>70F(WA%-#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($XF(WA%-#MY
M='0F(WA%-#LF(WA%-#L@:G5L:VES96X@4$=0+6%V86EM96X@97)I;&QI<V5S
M<R8C>$4T.R!I:VMU;F%S<V$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY4
M87)K96UM870@=&EE9&]T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!.)B-X
M130[>71T)B-X130[)B-X130[('1A<FME;7!I82!T:65T;VIA(&IU;&MI<V5S
M=&$@4$=0+6%V86EM97-T82X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!O
M:7-T83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4&]I<W1A82!J=6QK:7-E
M;B!A=F%I;65N(&]S;VET96MI<FIA<W1A<VDN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M:6UP;W)T+7!U8FME>2(@;60U/2(V964Q
M,3,P8C0V93EF9C%C83EA9#-A,V$T-V4W8C,X,B(@<W1A=&4](G5P=&]D871E
M(CX*("`@(#QT:71L93Y01U`Z($IU;&MI<V5N(&%V86EM96X@:&%L;&EN=&$@
M+2!4=6]N=&D\+W1I=&QE/@H@("`@/&AE861I;F<^5'5O(&IU;&MI<VEA(&%V
M86EM:6$\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%0F(WA%-#MS="8C>$4T
M.R`@<&%I;FEK:V5E<W1A("!A=6ME86$@("!I:VMU;F$L("!J;VAO;B`@=F]I
M("!T=6]D82`@:G5L:VES96X*("`@(%!'4"UA=F%I;65N+B!6;VET("!K;W!I
M;VED82!J82!L:6ET="8C>$4T.R8C>$4T.R`@879A:6UE;B!T96MS=&EK96YT
M="8C>$4T.R8C>$4T.VX@=&%I"B`@("!J;W,@<VEN=6QL82!O;B`@879A:6YT
M:65D;W-T;VIA('!A:6MA;&QI<V5L;&$@=&EE=&]K;VYE96QL82P@;FEI;@H@
M("`@=F]I="!T=6]D82!S96X@<W5O<F%A;BX@2F]S(&%V86EN(&]N(&ME;'9O
M;&QI;F5N+"!N:6EN('-E(&QI<R8C>$4T.W0F(WA%-#LF(WA%-#MN"B`@("!O
M<V]I=&5K:7)J86%S:2`@(&IA("`@:6MK=6YA("!S=6QK975T=74N("`@2F]S
M("`@879A:6X@(&5I("`@;VQL=70*("`@(&ME;'9O;&QI;F5N+"!N:6EN(&XF
M(WA%-#MK>79I:6X@('1U;&5E('9I<FAE:6QM;VET=7,L(&IO<W-A('-E;'9I
M=&5T)B-X130[)B-X130[;@H@("`@;6EK)B-X130[(&%V86EM97-S82!O;&D@
M=FEK86YA+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P
M+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!M9#4](C(R,&%F,F(W-&$U.&8T,S!E
M9F0W,F0V9#9B,68Y.3-F(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/E!'4#H@2&5N:VEL)B-X1C8[:V]H=&%I<W1E;B!A=F%I;G1E;B!H86QL:6YT
M83PO=&ET;&4^"B`@("`\:&5A9&EN9SY9;&5I<VMU=F$\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($IO<R!H86QU870@(',F(WA%-#MH:R8C>$8V.VES97-T
M:2!A;&QE:VER:F]I='1A82!T86D@('9A<W1A86YO='1A82!S86QA='1U:F$*
M("`@(',F(WA%-#MH:R8C>$8V.W!O<W1I=FEE<W1E:B8C>$4T.RP@;FEI;B`@
M<VEN=6QL82!P:70F(WA%-#LF(WA%-#L@;VQL82`@;VUA(&AE;FMI;"8C>$8V
M.VMO:'1A:6YE;@H@("`@:G5L:VEN96XO<V%L86EN96X@4$=0+6%V86EN<&%R
M:2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DIU;&MI;F5N(&%V86EM97-I
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!*=6QK:6YE;B`@(&%V86EM97-I
M("`@='5L964@("!O;&QA("!S86%T879I;&QA("`@:V%I:VEL;&4@("!N:6EL
M;&4*("`@(&AE;FMI;"8C>$8V.VEL;&4L("!J;VED96X@:V%N<W-A("!H86QU
M870@(&MO;6UU;FEK;VED82!S86QA='5S=&D@('-I=&5N"B`@("!E='0F(WA%
M-#L@=F%I;B`@4TE.)B-X0S0[('9O:70@879A=&$@<VEN=6QL92!T=6QL965T
M("!V:65S=&ET+B!,:7,F(WA%-#MK<VD@<VEN=6X*("`@('1U;&5E("!L86ET
M=&%A("!A=F%I;B!S86%T879I;&QE("!S:71E;B`@971T)B-X130[("!N92P@
M:F]I;&QE("!L)B-X130[:&5T)B-X130[=`H@("`@<R8C>$4T.VAK)B-X1C8[
M:7-E<W1I("`@(&%L;&5K:7)J;VET971T=6IA("`@('9I97-T96HF(WA%-#L@
M("!V;VEV870@("`@=&%R:VES=&%A"B`@("!A;&QE:VER:F]I='5K<V5S:2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E-A;&%I;F5N(&%V86EM97-I/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!386QA:6YE;B!A=F%I;B!T87)V:71A
M86X@<VEI:&5N(&5T="8C>$4T.R!V;VES:70@<'5R:V%A('-E;&QA:7-E;@H@
M("`@=FEE<W1I;BP@:F]K82!O;B!S86QA='1U(&LF(WA%-#MY='0F(WA%-#ME
M;B!J=6QK:7-T82!A=F%I;G1A+B!,:7,F(WA%-#MK<VD*("`@('-A;&%I<W1A
M(&%V86EN=&$@=&%R=FET86%N+"!J;W,@:&%L=6%T(',F(WA%-#MH:R8C>$8V
M.VES97-T:2!A;&QE:VER:F]I='1A80H@("`@<R8C>$4T.VAK)B-X1C8[<&]S
M=&EV:65S=&5J)B-X130[+B!386QA:6YE;B!A=F%I;65S:2!O;B!S=6]J871T
M=2!N:6EH:6X@;'5O;FYI;@H@("`@>6AT97ED97-S)B-X130[(&QI:71E='EL
M;"8C>$4T.R!S86QA<V%N871E:W-T:6QL)B-X130[+B!*;W,@:&%L=6%T(&LF
M(WA%-#MY='0F(WA%-#LF(WA%-#L*("`@('-E;&QA:7-I82!T;VEM:6YT;VIA
M+"!J;W1K82!K)B-X130[>71T)B-X130[=B8C>$4T.W0@<V%L86ES=&$@879A
M:6YT87-I+"!N:6EN"B`@("!S:6QL;VEN($E-4"!K>7-Y>2!S:6YU;'1A('0F
M(WA%-#MT)B-X130[('-A;&%S86YA=&5K<W1I+B!3:6YU;B!E:2!T87)V:71S
M90H@("`@:VER:F]I='1A82!S86QA<V%N871E:W-T:2!K=6EN(&ME<G)A;B!Y
M:&1E;B!I<W1U;FYO;B!A:6MA;F$@+2!)35`*("`@(&UU:7-T86$@86YN971U
M;B!S86QA<V%N871E:W-T:6X@<VEI:&5N('-A86MK82!K=6YN97,@:VER:F%U
M9'5T"B`@("!U;&]S("A-=6ES=&$@<VEI<R!A:6YA(&MI<FIA=71U82!U;&]S
M(2DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R
M<V]N86QK97DM<'5B;&EC(B!M9#4](C-C.#0T9#1F9CAF9&1A,V4P9#0T-F(T
M-V$V,S$Q-V4P(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@
M2&5N:VEL)B-X1C8[:V]H=&%I<W1E;B!A=F%I;G1E;B!H86QL:6YT82`M($IU
M;&MI;F5N(&%V86EN/"]T:71L93X*("`@(#QH96%D:6YG/DXF(WA%-#MY="8C
M>$4T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@079A82!U=61E;B!I:VMU
M;F%N(&IO<W-A(&XF(WA%-#MK>7D@<VEN=6X@:G5L:VEN96X@4$=0+6%V86EN
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^5&%R:V5M;6%T('1I961O=#PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3B8C>$4T.WET="8C>$4T.R8C>$4T
M.R!T87)K96UP:6$@=&EE=&]J82!J=6QK:7-E<W1A(%!'4"UA=F%I;65S=&%S
M:2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S
M;VYA;&ME>2UP<FEV871E(B!M9#4](C$X-3%B-C=A,6%E968Q,C0R9F,S83)B
M.31A9C<U8S`S(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@
M2&5N:VEL)B-X1C8[:V]H=&%I<W1E;B!A=F%I;G1E;B!H86QL:6YT82`M(%-A
M;&%I;F5N(&%V86EN/"]T:71L93X*("`@(#QH96%D:6YG/D%N;F$@<V%L87-A
M;F%T96MS=&D\+VAE861I;F<^"B`@("`\<&%R83X*("`@($%V86$@97)I;&QI
M<V5N(&EK:W5N86XL(&IO<W-A(&MY<WET)B-X130[)B-X130[;B!S86QA<V%N
M871E:W-T:28C>$4T.RX@2F]S(&%N;F%T(&]I:V5A;B!S86QA<V%N871E:W-T
M:6XL(&YI:6X@24U0('1A;&QE='1A82!T)B-X130[;28C>$4T.VX@=&EE9&]N
M(&IA('-E(&]N('9O:6UA<W-A(&ES='5N;F]N('`F(WA%-#LF(WA%-#MT='EM
M:7-E96X@<V%A:VMA+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4&]I<W1A
M('-A;&%S86YA=&5K<W1I/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!0;VES
M=&%A($E-4"UO:&IE;&UA;B!M=6ES=&ES=&$@=&%L;&5T971U;B!S86QA<V%N
M871E:W-T:2`M('0F(WA%-#MM)B-X130[;@H@("`@:B8C>$4T.VQK965N(&IO
M<R!S86QA:7-T82!A=F%I;G1A('1A<G9I=&%A;B!J;VAO;FMI;B!T;VEM:6YT
M;V]N+"!N:6EN"B`@("!S92!K>7-Y="8C>$4T.R8C>$4T.VX@<VEN=6QT82!U
M=61E<W1A86XN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY.)B-X130[>70F
M(WA%-#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($%V86$@=75D96X@:6MK
M=6YA;B!J;W-S82!N)B-X130[:WEY('-A;&%I;F5N(%!'4"UA=F%I;65S:2X@
M)B-X0S0[3"8C>$,T.R!+3U-+04%."B`@("!,)B-X0S0[2$54)B-X0S0[(%0F
M(WA#-#M4)B-X0S0[($%604E.5$$@2T5.14Q,14M+)B-X0S0[)B-X0S0[3B`M
M('0F(WA%-#MM)B-X130[('1O:6UI;G1O(&]N('9A:6X@<VET)B-X130["B`@
M("!V87)T96X@971T)B-X130[('9O:70@=FEE9"8C>$4T.R!J82!K)B-X130[
M>71T)B-X130[)B-X130[(&%V86EN=&$@:F]S<V%K:6X@=&]I<V5S<V$*("`@
M(&]H:F5L;6%S<V$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY487)K96UM
M870@=&EE9&]T/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!.)B-X130[>71T
M)B-X130[)B-X130[('1A<FME;7!I82!T:65T;VIA('-A;&%I<V5S=&$@4$=0
M+6%V86EM97-T87-I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(@;60U/2)D8F0X8V)E-F)C93<Q
M8S1F8C4Y,F1D,6(S8C(W8C=C92(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT
M:71L93Y01U`Z($AE;FMI;"8C>$8V.VMO:'1A:7-T96X@879A:6YT96X@:&%L
M;&EN=&$@+2!0;VES=&$\+W1I=&QE/@H@("`@/&AE861I;F<^4&]I<W1A(&AE
M;FMI;"8C>$8V.VMO:'1A:7-E="!A=F%I;65T/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!.87!A=71T86UA;&QA('0F(WA%-#MT)B-X130[('!A:6YI:V5T
M=&$@=F]I="!P;VES=&%A(&IU;&MI;F5N+W-A;&%I;F5N"B`@("!01U`M879A
M:6YP87)I<VD@24U0+6]H:F5L;6%N(&%S971U:W-I<W1A+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T
M92UN86UE(B!M9#4](C<T.&-B,3(T8C=F9C4R.#(P-SDR93(W.#`S-V$X8S(W
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@3'5O(&AE;FMI
M;"8C>$8V.VMO:'1A:6YE;B!A=F%I;B`M($YI;6D\+W1I=&QE/@H@("`@/&AE
M861I;F<^3FEM:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3FEM:2P@:F]N
M:V$@:&%L=6%T('-I<R8C>$4T.VQL>71T)B-X130[)B-X130[(&AE;FMI;"8C
M>$8V.VMO:'1A:7-I:6X*("`@(&%V86EM:6ES:2X@4&%K;VQL:6YE;B!K96YT
M="8C>$4T.RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UP97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N="(@;60U/2)E-C8V96(Y9C!E
M931B-#EF93`T9C<T9F,Q.&1B.#8T,"(@<W1A=&4](G5P=&]D871E(CX*("`@
M(#QT:71L93Y01U`Z($QU;R!H96YK:6PF(WA&-CMK;VAT86EN96X@879A:6X@
M+2!+;VUM96YT=&D\+W1I=&QE/@H@("`@/&AE861I;F<^2V]M;65N='1I/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!+;VUM96YT=&DL(&IO:V$@:&%L=6%T
M('-I<R8C>$4T.VQL>71T)B-X130[)B-X130[(&AE;FMI;"8C>$8V.VMO:'1A
M:7-I:6X*("`@(&%V86EM:6ES:2X@5F%P86%E:'1O:6YE;B!K96YT="8C>$4T
M.RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S
M;VYA;&ME>2UC<F5A=&4M96UA:6PB(&UD-3TB8S<R.68W,&9D8C-A-S-C8F(W
M8F$U968U.#@X93,P.3(B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^
M4$=0.B!,=6\@:&5N:VEL)B-X1C8[:V]H=&%I;F5N(&%V86EN("T@4R8C>$4T
M.VAK)B-X1C8[<&]S=&EO<V]I=&4\+W1I=&QE/@H@("`@/&AE861I;F<^4R8C
M>$4T.VAK)B-X1C8[<&]S=&EO<V]I=&4\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%,F(WA%-#MH:R8C>$8V.W!O<W1I;W-O:71E+"!J;VYK82!H86QU870@
M;&EI='0F(WA%-#LF(WA%-#L@:&5N:VEL)B-X1C8[:V]H=&%I<VEI;@H@("`@
M879A:6UI:7-I+B!086MO;&QI;F5N(&ME;G1T)B-X130[+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T
M92UK97EL96YG=&@B(&UD-3TB,C1C838T,6,V,V9B-69F,S$P83,Y964P9#-B
M,65E-34B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0.B!,=6\@
M:&5N:VEL)B-X1C8[:V]H=&%I;F5N(&%V86EN("T@079A:6UE;B!P:71U=7,\
M+W1I=&QE/@H@("`@/&AE861I;F<^079A:6UE;B!P:71U=7,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%-I;G5L;&4@;'5O=&%V86X@879A:6UE;B!P:71U
M=7,@=&%V=6EN82X@36ET)B-X130[('-U=7)E;7!I(&%R=F\L(&YI:6X*("`@
M('-E;B!S=75R96UP:2!S=6]J82P@;75T=&$@;7DF(WA&-CMS('-U=7)E;7!I
M(&QU;VYT:6%I:V$@:F$@<V%L875K<V5E;@H@("`@:R8C>$4T.WET971T>2!A
M:6MA*2X@,3`R-"!O;B!O;&5T=7-A<G9O("T@="8C>$4T.VTF(WA%-#L@;VX@
M96YE;6TF(WA%-#MN(&MU:6X@<FEI='0F(WA%-#MV)B-X130["B`@("!A=F%I
M;G!I='5U<R!J82!T87)J;V%A(&AY=B8C>$4T.VX@<W5O:F%N+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R
M96%T92UP87-S<&AR87-E(B!M9#4](C)F8CDS-S(Y-S!B9C,S9C4Q93DX.&)A
M,SED8F0W,3DS(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@
M3'5O(&AE;FMI;"8C>$8V.VMO:'1A:6YE;B!A=F%I;B`M(%-A;&%S86YA=&5K
M<W1I/"]T:71L93X*("`@(#QH96%D:6YG/E-A;&%S86YA=&5K<W1I/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!386QA<V%N871E:W-T:2!K)B-X130[>71E
M="8C>$4T.R8C>$4T.VX@<W5O:F%A;6%A;B!J82!S86QA86UA86X@:&5N:VEL
M)B-X1C8[:V]H=&%I<V5T"B`@("!A=F%I;65S:2X@5"8C>$4T.VTF(WA%-#L@
M<&ET)B-X130[)B-X130[(&]L;&$@5B8C>$,T.TA)3E0F(WA#-#LF(WA#-#M.
M(#8@;65R:VMI)B-X130[('!I=&LF(WA%-#LL($5)(%-!02!O;&QA"B`@("!S
M86UA(&MU:6X@;6EH:6YK)B-X130[)B-X130[;B!P86QV96QU=6X@:R8C>$4T
M.WET="8C>$4T.VTF(WA%-#MS:2!S86QA<V%N82P@96D@='5L:7-I(&]L;&$*
M("`@('-A;F%K:7)J87-T82!L)B-X1C8[>71Y=B8C>$4T.R!S86YA(&IA('1U
M;&ES:2!S:7,F(WA%-#ML="8C>$4T.R8C>$4T.R!S96LF(WA%-#L@;G5M97)O
M:71A(&5T="8C>$4T.PH@("`@:VER:F%I;6EA+B!687)M=75D96X@=G5O:W-I
M('-I;G5N('!I="8C>$4T.R8C>$4T.R!K:7)J;VET=&%A('-A;&%S86YA=&5K
M<W1I"B`@("!K86AT965N(&ME<G1A86XN(%!A:V]L;&EN96X@:V5N='0F(WA%
M-#LN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R
M<V]N86QK97DM8W)E871E+6%C=&EO;G,B(&UD-3TB,&8X,C,T.3,U8CDV-&,X
M,S4S,V(T96,T8S$U96(W,3(B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET
M;&4^4$=0.B!,=6\@:&5N:VEL)B-X1C8[:V]H=&%I;F5N(&%V86EN("T@5&]I
M;6EN;F]T/"]T:71L93X*("`@(#QH96%D:6YG/DQU;R!A=F%I;65T/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!,=6\@:F$@=&%L;&5T=&%A(&AE;FMI;"8C
M>$8V.VMO:'1A:7-E;B!J=6QK:6YE;B]S86QA:6YE;B!A=F%I;G!A<FEN+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^5'5O(&%V86EN<&%R:3PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5"8C>$4T.W-T)B-X130[('!A:6YI:VME97-T
M82!A=6ME86$@:6MK=6YA+"!J;VAO;B!V;VD@='5O9&$*("`@(&IU;&MI<V5N
M+W-A;&%I<V5N(&%V86EN<&%R:6XN(%9O:70@:V]P:6]I9&$@:F$@;&EI='0F
M(WA%-#LF(WA%-#L*("`@(%!'4"UA=F%I;G!A<FEN('1E:W-T:6ME;G1T)B-X
M130[)B-X130[;B!T86D@:F]S('-I;G5L;&$@;VX@879A:6UE=`H@("`@=&EE
M9&]S=&]I;F$@<&%I:V%L;&ES96QL82!T:65T;VMO;F5E;&QA+"!N:6EN('9O
M:70@='5O9&$@;F4*("`@('-U;W)A86XN($IO<R!A=F%I;65T(&]V870@:V5L
M=F]L;&ES970L(&YI:6X@;F4@;&ES)B-X130[="8C>$4T.R8C>$4T.VX*("`@
M(&%S971U:W-I:7-I(&IA(&EK:W5N82!S=6QK975T=74N($IO<R!A=F%I;65T
M(&5I=B8C>$4T.W0@;VQL965T"B`@("!K96QV;VQL:7-I82P@;FEI;B!N)B-X
M130[:WEV:6EN('1U;&5E('9I<FAE:6QM;VET=7,L(&IO<W-A('-E;'9I=&5T
M)B-X130[)B-X130[;@H@("`@;6EK)B-X130[(&%V86EM:7-S82!O;&D@=FEK
M86YA+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M
M;W9E<G9I97<B(&UD-3TB9#-C-S4R8C$S-#5F8C)E8V-F934W-6,P-S0V,3DV
M,V8B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4R]-24U%.B!9;&5I
M<VMU=F$\+W1I=&QE/@H@("`@/&AE861I;F<^36EK)B-X130[(&]N(%,O34E-
M13\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%,O34E-12!O;B!J=6QK:7-E
M96X@:F$@<V%L86ES965N(&%V86EM965N('!E<G5S='5V82!A=F]I;B!J80H@
M("`@>6AT965N<V]P:79A(&HF(WA%-#MR:F5S=&5L;28C>$4T.RP@:F]N:V$@
M879U;&QA('9O:2!M=6]D;W-T86$@<R8C>$4T.VAK)B-X1C8[:7-I)B-X130[
M"B`@("!A;&QE:VER:F]I='5K<VEA+"!S86QA=&$@=FEE<W1I(&IA('-U;VIA
M=&$@=FEE<W1I;B!E:&5Y<RX@4R]-24U%"B`@("!A=G5L;&$@=F]I="!S86QA
M=&$@=FEE<W1I="!S:71E;B!E='0F(WA%-#L@=F%I;B!V:65S=&EN(&PF(WA%
M-#MH971T)B-X130[:B8C>$4T.R!J80H@("`@=F%S=&%A;F]T=&%J82!V;VD@
M<V5N(&QU:V5A+B!6;VET(&UY)B-X1C8[<R!S)B-X130[:&LF(WA&-CMI<V5S
M=&D@86QL96MI<FIO:71T86$*("`@('9I97-T:6XL(&IO;&QO:6X@=F%S=&%A
M;F]T=&%J82!V;VD@=&%R:VES=&%A(&5T="8C>$4T.R!V:65S=&D@;VX@='5L
M;'5T"B`@("!J=75R:2!S:6YU;'1A(&IA('-I="8C>$4T.R!E:2!O;&4@;75U
M=&5T='4@;6%T:V%L;&$N(%EH9&ES="8C>$4T.VTF(WA%-#ML;"8C>$4T.PH@
M("`@<V%L875S(&IA(',F(WA%-#MH:R8C>$8V.VEN96X@86QL96MI<FIO:71U
M<R!V;VED86%N('1A871A('9I97-T:6X@96AE>7,@:F$*("`@('-E(&5T="8C
M>$4T.R!K=6MA86X@;75U(&MU:6X@=F%S=&%A;F]T=&%J82!E:2!P)B-X130[
M)B-X130[<V4@;'5K96UA86X@=FEE<W1I)B-X130[+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^2R8C>$4T.WET)B-X130[(%,O34E-12UT;VEM:6YT;V$\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($IO<R!T)B-X130[;28C>$4T.R!A
M<V5T=7,@;VX@=F%L:71T=6YA+"!N:6EN('9O:70@='5O9&$@;VAJ96QM86%N
M"B`@("!H96YK:6PF(WA&-CMK;VAT86ES970@4R]-24U%+6%V86EM970L(&QU
M:V5A('-A;&%T='5J82!V:65S=&5J)B-X130[+`H@("`@=&%R:VES=&%A(',F
M(WA%-#MH:R8C>$8V.VES:28C>$4T.R!A;&QE:VER:F]I='5K<VEA(&IA('9O
M:70@:VER:F]I='1A82!J80H@("`@;"8C>$4T.VAE='0F(WA%-#LF(WA%-#L@
M<R8C>$4T.VAK)B-X1C8[:7-E<W1I(&%L;&5K:7)J;VET971T=6IA('-A;&%T
M='5J82!V:65S=&5J)B-X130[+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<VUI;64M;W9E<G9I97<M<&5R<V]N86QK97DB(&UD-3TB.68T
M9C,V864W,F-B-&%B8S<S,3`V-V0S,SAB93-B.3@B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^4R]-24U%.B!(96YK:6PF(WA&-CMK;VAT86ES970@
M879A:6UE=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY9;&5I<VMU=F$\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($IO<R!H86QU870@;&ES)B-X130[="8C>$4T
M.R!V:65S=&5I:&EN(',F(WA%-#MH:R8C>$8V.VES96X@86QL96MI<FIO:71U
M:W-E;B!T86D@<V%L871A"B`@("!V:65S=&5J)B-X130[+"!N:6EN('-I;G5L
M;&$@<&ET)B-X130[)B-X130[(&]L;&$@:G5L:VEN96XO<V%L86EN96X*("`@
M(%,O34E-12UA=F%I;G!A<FDN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)S;6EM92UI;7!O<G0M<&5R<V]N86PM8V5R=',B(&UD-3TB8V8P
M960R93-E,C1D,S!D961F.&-F968R8S(V-#4W-3DB('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^4R]-24U%.B!4=6\@:&5N:VEL)B-X1C8[:V]H=&%I
M<V5T('9A<FUE;G1E970\+W1I=&QE/@H@("`@/&AE861I;F<^5'5O(&AE;FMI
M;"8C>$8V.VMO:'1A:7-E="!V87)M96YT965T/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!6;VET(&AE;FMI;"8C>$8V.VMO:'1A:7-E="!V87)M96YT965S
M=&DL(&IO<R!N92!O=F%T(%!+0U,@(S$R"B`@("!M=6]D;W-S82X@4$M#4R`C
M,3(@;75O=&]A(&LF(WA%-#MY=&5T)B-X130[)B-X130[;B!Y;&5I<V5S=&D@
M879A:6YT96X@=FEE;FYI<W,F(WA%-#L*("`@(&5S:6UE<FMI:W-I('-E;&%I
M;6ES=&$@*&5S:6TN($EN=&5R;F5T($5X<&QO<F5R+"!&:7)E9F]X*2!T86D@
M:F]S"B`@("!A=F%I;65T(&AA;'5T86%N('9I960F(WA%-#L@:R8C>$4T.WET
M="8C>$8V.VHF(WA%-#MR:F5S=&5L;28C>$4T.W-T)B-X130[("AE<VEM+B!7
M:6YD;W=S"B`@("!84"DN($IO<R!A=F%I;FUE="!O=F%T(&ME;'9O;&QI<V5T
M+"!N:6EN(&YE(&QI<R8C>$4T.W0F(WA%-#LF(WA%-#MN(&%S971U:W-I:7-I
M"B`@("!J82!I:VMU;F$@<W5L:V5U='5U+B!*;W,@879A:6UE="!E:78F(WA%
M-#MT(&]L;&5E="!K96QV;VQL:7-I82P@;FEI;@H@("`@;B8C>$4T.VMY=FEI
M;B!T=6QE92!V:7)H96EL;6]I='5S+"!J;W-S82!S96QV:71E="8C>$4T.R8C
M>$4T.VX@;6EK)B-X130[(&%V86EM:7-S82!O;&D*("`@('9I:V%N82X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+61E;&5T92UP
M97)S;VYA;"UC97)T<R(@;60U/2(P,3AB8C9B-C%A-V4T,38X.3)D93(X.&%D
M,6,X.#!F-"(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y3+TU)344Z
M(%!O:7-T82!H96YK:6PF(WA&-CMK;VAT86EN96X@=F%R;6%N;F4\+W1I=&QE
M/@H@("`@/&AE861I;F<^4&]I<W1A(&AE;FMI;"8C>$8V.VMO:'1A:6YE;B!V
M87)M96YN93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4&]I<W1A82!H96YK
M:6PF(WA&-CMK;VAT86ES96X@=F%R;65N=&5E;B!A<V5T=6MS:7-T87-I+B!4
M)B-X130[;28C>$4T.VX@:B8C>$4T.VQK965N(&5T('9O:2!E;B8C>$4T.R8C
M>$4T.R!3+TU)344M86QL96MI<FIO:71T86$@=FEE<W1E:B8C>$4T.R!T86D@
M;'5K96$@<VEN=6QL92!O<V]I=&5T='5J82!3+TU)344M<V%L871T=6IA('9I
M97-T96HF(WA%-#LN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)S;6EM92UM86YA9V4M<'5B:V5Y(B!M9#4](CAB-F,V,S8X-&0S9#<S8C-D
M,#@T,#(U83<X9F4W93@X(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/E,O34E-13H@2G5L:VES=&5N(&%V86EM:65N(&AA;&QI;G1A/"]T:71L93X*
M("`@(#QH96%D:6YG/E,O34E-13H@2G5L:VES=&5N(&%V86EM:65N(&AA;&QI
M;G1A/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6;VET(&AA;&QI;FYO:61A
M(&IU;&MI<W1E;B!3+TU)344M879A:6YT96X@;&ES=&%A+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^3B8C>$4T.WET)B-X130[/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!.)B-X130[>71T)B-X130[)B-X130[(&IU;&MI<V5N(&%V
M86EM96X@<F%A:V%T96MS=&EV97)S:6]N82X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E1A<FME;6UA="!T:65D;W0\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($XF(WA%-#MY='0F(WA%-#LF(WA%-#L@:G5L:VES96X@879A:6UE;B!T
M87)K96UM870@=&5K;FES970@=&EE9&]T+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^4&]I<W1A/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!0;VES=&%A
M('9A;&ET=6X@:G5L:VES96X@879A:6UE;BX@2W5N('!O:7-T870@:F]N:W5N
M(&LF(WA%-#MY='0F(WA%-#MJ)B-X130[;@H@("`@:G5L:VES96X@879A:6UE
M;BP@;FEI;B!E="!V;VD@96XF(WA%-#LF(WA%-#L@;"8C>$4T.VAE='0F(WA%
M-#LF(WA%-#L@:"8C>$4T.VYE;&QE('-A;&%T='5J80H@("`@=FEE<W1E:B8C
M>$4T.RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R:6YT
M:6YG(B!M9#4](F8R,S-C,3%B-F(T839B961E8C8X9C%D-6$R83DW-F1B(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E1U;&]S='5S/"]T:71L93X*
M("`@(#QH96%D:6YG/E1U;&]S=&$@=FEE<W1I/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4=6QO<W1A86MS97-I(&MA='-E;&5M87-I('9I97-T:6XL(&YA
M<'-A=71A('9I97-T:6X@86QU<W-A('1A:0H@("`@;&]P=7-S82!O;&5V86$@
M(E1U;&]S=&$B("UL:6YK:VDF(WA%-#LN(%9I97-T:2!A=6ME86$@=75T965N
M(&EK:W5N86%N"B`@("!T=6QO<W1E='1A=F%S<V$@;75O9&]S<V$N(%)I:7!P
M=65N(&LF(WA%-#MY=&5T>7-T)B-X130[('-E;&%I;65S=&$@:F$*("`@(&LF
M(WA%-#MY='0F(WA&-CMJ)B-X130[<FIE<W1E;&TF(WA%-#MS="8C>$4T.RP@
M;FEI;B!S:6YU;&QE('!I="8C>$4T.VES:2!A=65T80H@("`@='5L;W-T=7-D
M:6%L;V=I+B!*;W,@9&EA;&]G:6$@96D@='5L92P@;FEI;B!V86QI='-E('-E
M;&%I;65N"B`@("`B5&EE9&]S=&\B("UA;&%S=F5T;W9A;&EK;W-T82!T;VEM
M:6YT;R`B5'5L;W-T82(N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)S;W)T:6YG(B!M9#4](C$X8V1E86,S.#`R-V9E-6,T,F)A8C8Y,V8R
M830R-C!A(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DQA:FET=&5L
M=2!J82!S)B-X130[:6ME970\+W1I=&QE/@H@("`@/&AE861I;F<^3&%J:71T
M96QU/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6;VET(&HF(WA%-#MR:F5S
M="8C>$4T.R8C>$4T.R!V:65S=&ET(&5R:2!S87)A:VME:61E;B!M=6MA86X@
M;F%P875T=&%M86QL80H@("`@<V%R86MK965N(&]T<VEK:V]A+B!6;VET(&QA
M:FET96QL82!N92!N;W5S979A86X@=&%I(&QA<VME=F%A;@H@("`@:B8C>$4T
M.W)J97-T>6MS965N(&YA<&%U='1A;6%L;&$@<V%R86MK965N(&]T<VEK;VX@
M=FEE<F5S<R8C>$4T.R!O;&5V86$*("`@(&YU;VQE;G`F(WA%-#LF(WA%-#MN
M(&MU=F%A+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4R8C>$4T.VEK965T
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!*;W,@:&%L=6%T(&HF(WA%-#MR
M:F5S="8C>$4T.R8C>$4T.R!V:65S=&ET(&ME<VMU<W1E;'5S)B-X130[:6ME
M96X@;75K86%N+"!N:6EN"B`@("!N87!S875T82!;2V5S:W5S=&5L=7,F(WA%
M-#MI95T@+6QI;FMK:28C>$4T.R!/='-I:VMO<V%R86MK965S<V$N($MU;B!H
M86QU870*("`@('!A;&%U='1A82!J)B-X130[<FIE<W1Y:W-E;B!O='-I:V]N
M(&UU:V%I<V5K<VDL(&YI:6X@;F%P<V%U=&$@6T]T<VEK:V]="B`@("!L:6YK
M:VDF(WA%-#L@;W1S:6MK;W-A<F%K:V5E<W-A+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB86QT97)N871I=F4M;7-G(B!M9#4](C0Y-S@P
M-S-F-S8Y-S=B-F%F-F(V.3@Q,&4T9#(R838U(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/DUU;'1I<&%R="]!;'1E<FYA=&EV92!V:65S=&ET/"]T
M:71L93X*("`@(#QP87)A/@H@("`@3"8C>$4T.VAE='0F(WA%-#MJ)B-X130[
M(&]N('9O:6YU="!L)B-X130[:&5T="8C>$4T.R8C>$4T.R!J;W1K=70@=FEE
M<W1I="!T>7EP:6QL)B-X130["B`@("`B;75L=&EP87)T+V%L=&5R;F%T:79E
M(BX@3B8C>$4T.VES<R8C>$4T.R!V:65S=&5I<W,F(WA%-#L@;VX@;6]N=&$@
M;W-I;W1A+"!M=71T80H@("`@;FEI<W,F(WA%-#L@:V%I:VES<V$@;VX@4T%-
M02!325,F(WA#-#M,5"8C>$0V.RP@;75T=&$@15))"B`@("!-54]43RX@4R8C
M>$4T.VAK)B-X1C8[<&]S=&EO:&IE;&UA('!Y<FMI:2!N)B-X130[>71T)B-X
M130[;28C>$4T.R8C>$4T.VX@;B8C>$4T.VES="8C>$4T.R!O<VEO:7-T82!S
M96XL"B`@("!M:6YK)B-X130[('-E('!Y<W1Y>2!P87)H86ET96X@;B8C>$4T
M.WET="8C>$4T.VTF(WA%-#LF(WA%-#MN+"!V:65S=&EN(&UU=70@;W-I;W0@
M;B8C>$4T.VMY=B8C>$4T.W0*("`@(&]T<VEK;VX@(E9A:6AT;V5H=&]I<V5T
M(&]S870@="8C>$4T.VQL92!O<VEO;&QE.B(@86QA<'5O;&5L;&$@:F$@;F4@
M=F]I"B`@("!K871S;V$@=&%I('1A;&QE='1A82!E<FEK<V5E;BX@2V%N;F%T
M=&%A(&MU:71E;FMI;B!P:70F(WA%-#LF(WA%-#L@;6EE;&5S<R8C>$4T.PH@
M("`@971T)B-X130[(&XF(WA%-#MM)B-X130[('9A:6AT;V5H=&]I<V5T(&]S
M:6]T('!I="8C>$4T.W8F(WA%-#MT('-I<R8C>$4T.VQL)B-X130[)B-X130[
M;B!S86UA;B!S:7,F(WA%-#ML;"8C>$8V.VX*("`@(&MU:6X@<V4@;W-I;R!M
M:6YK)B-X130[(',F(WA%-#MH:R8C>$8V.W!O<W1I;VAJ96QM82!N)B-X130[
M>71T:2`M(&]S:6]T(&]V870@=F%I;B!E<FD*("`@(&UU;V1O<W-A("AE<VEM
M97)K:6MS:2!T96MS=&D@:F$@2%1-3"UO<VEO="DN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUR96YA;65?<V5N=&UA:6Q?;6]N
M=&AL>2(@;60U/2(U,S!F83(P93!A9F)C,C5F9F0T,#@W-SDT.#@S,C@Y.2(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y!<V5T=6MS970Z(%EL;"8C
M>$4T.W!I=&]T;VEM96YP:71E970Z($YI;64F(WA%-#L@:W5U:V%U<VET=&%I
M;B!U=61E<W1A86X@;"8C>$4T.VAE=&5T='EJ96X@=FEE<W1I96X@:V%N<VEO
M=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($QA:71A('0F(WA%-#MM)B-X130[
M(&%S971U<R!P)B-X130[)B-X130[;&QE+"!J;W,@:&%L=6%T(&MU=6MA=7-I
M='1A:6X@;FEM970F(WA%-#L*("`@('5U9&5L;&5E;B!L)B-X130[:&5T971T
M>6IE;B!V:65S=&EE;B!K86YS:6]T+"!N:6EN(&MA;G-I;W0@;FEM970F(WA%
M-#LF(WA%-#MN"B`@("!U=61E<W1A86X@:W5U:V%U9&5N(&%L=7-S82X@2V%N
M<VEO:61E;B!U=71E96X@;FEM965N(&QI<R8C>$4T.W0F(WA%-#LF(WA%-#MN
M"B`@("!K=75K875S:2!J82!V=6]S:2!J82!S86UA;&QA(&QU;V1A86X@;7DF
M(WA&-CMS('5U<VD@;"8C>$4T.VAE=&5T='EJ96X*("`@('9I97-T:65N(&MA
M;G-I;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+61E;&5T95]S96YT;6%I;%]M;VYT:&QY(B!M9#4](C!B965D,39D9F0V.&4R
M9C(U93!C-C8X-S%F9#4T-F1F(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/D%S971U:W-E=#H@66QL)B-X130[<&ET;W1O:6UE;G!I=&5E=#H@4&]I
M<W1A(&MU=6MA=7-I='1A:6X@;"8C>$4T.VAE=&5T='EJ96X@=FEE<W1I96X@
M:V%N<VEO/"]T:71L93X*("`@(#QP87)A/@H@("`@3&%I=&$@="8C>$4T.VTF
M(WA%-#L@87-E='5S('`F(WA%-#LF(WA%-#ML;&4@:F]S(&AA;'5A="!J;VMA
M(&MU=6MA=61E;B!A;'5S<V$@<&]I<W1A80H@("`@=F%N:&%N(&PF(WA%-#MH
M971E='1Y:F5N('9I97-T:65N(&MA;G-I;VXN($IO<R!P;W-T:6QA871I:V]L
M;&5S:2!O;@H@("`@87-E=&5T='4@:VEI;G1I)B-X1C8[+"!N:6EN('0F(WA%
M-#MM)B-X130[(&%S971U<R!V;VD@;VQL82!H>28C>$8V.V1Y;&QI;F5N+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E
M7W-E;G1M86EL7VUO;G1H;'E?:V5E<"(@;60U/2(W,65D,6,R96%B-#AB.3%A
M,C5B-6)C9#1B,31C8V5A.2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L
M93Y!<V5T=6MS970Z(%EL;"8C>$4T.W!I=&]T;VEM96YP:71E970Z(%!O:7-T
M82!K=75K875S:71T86EN(&PF(WA%-#MH971E='1Y:F5N('9I97-T:65N(&MA
M;G-I;R`M(",@:V%N<VEO=&$@<&ED970F(WA%-#LF(WA%-#MN('1A;&QE<W-A
M/"]T:71L93X*("`@(#QP87)A/@H@("`@2F]S('!O:7-T870@;"8C>$4T.VAE
M=&5T='EJ96X@=FEE<W1I96X@:V%N<VEO:71A(&MU=6MA=7-I='1A:6XL(&YI
M:6X*("`@(&MU:6YK82!M;VYT82!V86YH86$@:V%N<VEO=&$@:&%L=6%T('!I
M="8C>$4T.R8C>$4T.R!T86QL97-S82X@2V%I:VMI(&YE"B`@("!L)B-X130[
M:&5T971T>6IE;B!V:65S=&EE;B!K86YS:6]T('!O:7-T971A86XL(&IO=&MA
M(&]V870@=F%N:&5M<&EA"B`@("!K=6EN('9A;&ET='4@;28C>$4T.R8C>$4T
M.W(F(WA%-#L@:W5U:V%U<VEA+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DB(&UD
M-3TB,S<S96$P,F5D939D9C5F8S,T-6-A9C8S,F4Q.6$W-68B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^07-E='5K<V5T.B!9;&PF(WA%-#MP:71O
M=&]I;65N<&ET965T.B!0;VES=&$@:W5U:V%U<VET=&%I;B!L:6ET971Y="!L
M:6ET971I961O<W1O=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($QA:71A('0F
M(WA%-#MM)B-X130[(&%S971U<R!P)B-X130[)B-X130[;&QE+"!J;W,@:&%L
M=6%T('!O:7-T86$@;&EI=&5T:65D;W-T;W0@:F]K80H@("`@:W5U:V%U9&5N
M(&%L=7-S82X@2F]S('!O<W1I;&%A=&EK;VQL97-I(&]N(&%S971E='1U(&MI
M:6YT:28C>$8V.RP@;FEI;@H@("`@="8C>$4T.VTF(WA%-#L@87-E='5S('9O
M:2!O;&QA(&AY)B-X1C8[9'EL;&EN96XN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL
M>5]K965P(B!M9#4](C%B,S0P838P,C$T9&9F9#`T865C,#)C8S$Q,C=D9C5D
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%S971U:W-E=#H@66QL
M)B-X130[<&ET;W1O:6UE;G!I=&5E=#H@4&]I<W1A(&MU=6MA=7-I='1A:6X@
M;&EI=&5T>70@;&EI=&5T:65D;W-T;W0@+2`C(&MU=6MA=71A('9A;FAE;6UA
M=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($IO<R!P;VES=&%T(&QI:71E=&EE
M9&]S=&]J82!K=75K875S:71T86EN+"!N:6EN(&MU:6YK82!M;VYT80H@("`@
M:W5U:V%U='1A('9A;FAE;6UA="!L:6ET971I961O<W1O="!P;VES=&5T86%N
M/R!*;W,@:F]K:6X@;&EI=&4@;VX*("`@('0F(WA%-#MT)B-X130[('9A;FAE
M;7!I+"!N:6EN('-E('!O:7-T971A86XN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@;60U/2)D8S<Q.#<Q
M,30V8F4S930V861E,#`X-V$X8V8Q.#(W,R(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93Y!<V5T=6MS970Z(%EL;"8C>$4T.W!I=&]T;VEM96YP:71E
M970Z(%1Y:&IE;FXF(WA%-#L@<F]S:V%K;W)I/"]T:71L93X*("`@(#QP87)A
M/@H@("`@2W5N(&AA;'5A="!A=71O;6%A='1I<V5S=&D@='EH:F5N="8C>$4T
M.R8C>$4T.R!R;W-K86MO<FEN('1I971Y:6X@=B8C>$4T.VQI86IO:6XN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T
M<F%S:%]I;G1E<G9A;"(@;60U/2(W8F4Y,69B96(P-6(R9#@W,C@Y9#1C-38P
M,F0U83,R9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y!<V5T=6MS
M970Z(%EL;"8C>$4T.W!I=&]T;VEM96YP:71E970Z(%1Y:&IE;FXF(WA%-#L@
M<F]S:V%K;W)I('8F(WA%-#ML:6%J;VEN/"]T:71L93X*("`@(#QP87)A/@H@
M("`@2F]S('1Y:&IE;FXF(WA%-#MT(')O<VMA:V]R:6MA;G-I;W1A(&%U=&]M
M86%T=&ES97-T:2P@;FEI;B!M:71E;B!U<V5I;@H@("`@<V4@<&ET)B-X130[
M:7-I('1Y:&IE;G0F(WA%-#LF(WA%-#LN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]K965P(B!M9#4](C-C
M8C5A,F(U8C@P8C=A8S$Q-SEA93`P-68Y.#,Y-S!E(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/B9G=#M!<V5T=6MS970Z(%EL;"8C>$4T.W!I=&]T
M;VEM96YP:71E970Z(%1Y:&IE;FXF(WA%-#L@<F]S:V%K;W)I(&EK)B-X130[
M/"]T:71L93X*("`@(#QP87)A/@H@("`@2F]S('1Y:&IE;FXF(WA%-#MT(')O
M<VMA:V]R:6MA;G-I;W1A(&%U=&]M86%T=&ES97-T:2P@;FEI;B!M;VYT86MO
M"B`@("!P)B-X130[:78F(WA%-#LF(WA%-#L@=F%N:&5M;6%T('9I97-T:70@
M='5H;W1A86X@875T;VUA871T:7-E<W1I+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB7W1E>'0B(&UD-3TB-S(Q83`Y
M9#=C83`R.&,Y-V4S8F0R8C,X8S4Y-V9F9C<B('-T871E/2)U<'1O9&%T92(^
M"B`@("`@/'1I=&QE/D%S971U:W-E=#H@5FEE<W1I;B!K:7)J;VET=7,Z($QA
M:6YA=7-T96MS=&D\+W1I=&QE/@H@("`@(#QP87)A/@H@("`@(%0F(WA%-#ML
M;"8C>$4T.R!A<V5T=6MS96QL82!V;VET(&TF(WA%-#LF(WA%-#MR:71E;&PF
M(WA%-#L@;6EK)B-X130[('1E:W-T:2!L86ET971A86X*("`@("!V87-T875S
M=FEE<W1E:6AI;B!E;FYE;B!L86EN871T=6$@=&5K<W1I)B-X130[+@H@("`@
M(#PO<&%R83X*("`@("`\<&%R83X*("`@("!6;VET(&5R:6MO:7-K;V]D:65N
M(&%V=6QL82!L86ET=&%A(&QA:71T86$@;28C>$4T.R8C>$4T.W)I='1E;'ET
M96MS=&EI;@H@("`@(&QI<R8C>$4T.W1I971O:F$@=FEE<W1I<W0F(WA%-#LL
M(&IO:&]N(&]L970@=F%S=&%A;6%S<V$N($5R:6MO:7-K;V]D:0H@("`@(&MO
M;W-T=74@)R4G+6UE<FMI<W0F(WA%-#L@:F$@<VET)B-X130[('-E=7)A82!A
M:6YA('EK<VD@:VER:F%I;B!T86D*("`@("!M97)K:VDN($%L;&$@;VX@;&ES
M=&$L(&IO<W-A(&]N(&TF(WA%-#LF(WA%-#MR:71E;'1Y(&LF(WA%-#MY=&5T
M="8C>$4T.W9I<R8C>$4T.R!O;&5V870*("`@("!E<FEK;VES:V]O9&ET+@H@
M("`@(#PO<&%R83X*"B`@("`@/'!A<F$^("5F(#H@3"8C>$4T.VAE='0F(WA%
M-#MJ)B-X130[;B!N:6UI(&IA(',F(WA%-#MH:R8C>$8V.W!O<W1I;W-O:71E
M/"]P87)A/@H@("`@(#QP87)A/B`E82`Z($PF(WA%-#MH971T)B-X130[:B8C
M>$4T.VX@<R8C>$4T.VAK)B-X1C8[<&]S=&EO<V]I=&4\+W!A<F$^"B`@("`@
M/'!A<F$^("5P(#H@3"8C>$4T.VAE='0F(WA%-#MJ)B-X130[;B!N:6UI/"]P
M87)A/@H@("`@(#QP87)A/B`E<B`Z(%)&0R`R.#(R(&UU:V%I;F5N('`F(WA%
M-#MI=B8C>$4T.VTF(WA%-#LF(WA%-#MR)B-X130[(&IA(&%I:V%V>28C>$8V
M.VAY:V4\+W!A<F$^"B`@("`@/'!A<F$^("5D(#H@4"8C>$4T.VEV)B-X130[
M;28C>$4T.R8C>$4T.W(F(WA%-#L@;75O9&]S<V$@=W=W+"!P<"!K:VL@5E96
M5CPO<&%R83X*("`@("`\<&%R83X@)7@@.B!0)B-X130[:78F(WA%-#MM)B-X
M130[)B-X130[<B8C>$4T.R!E<VET971T>6XF(WA%-#L@;&]K86QI<V%A=&EO
M;B!O;&5T=7-T879A;&QA/"]P87)A/@H@("`@(#QP87)A/B`E8R`Z(%`F(WA%
M-#MI=B8C>$4T.VTF(WA%-#LF(WA%-#MR)B-X130[(&IA(&%I:V$@97-I=&5T
M='EN)B-X130[(&QO:V%L:7-A871I;VX@;VQE='5S=&%V86QL83PO<&%R83X*
M("`@("`\<&%R83X@)6T@.B!-97-S86=E+4E$/"]P87)A/@H@("`@(#QP87)A
M/B`E<R`Z($]T<VEK:V\\+W!A<F$^"B`@("`@/'!A<F$^("5N(#H@4FEV:6YV
M86EH=&\\+W!A<F$^"B`@("`@/'!A<F$^("4E(#H@)R4G("UM97)K:VD\+W!A
M<F$^"@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?
M<F5Q=65S=%]R96%D(B!M9#4](C@Y93DR8S1D-C@R,C1B,C,T-6(U.3DU.3@W
M.&$W,3<T(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%S971U:W-E
M=#H@4'EY9"8C>$4T.R!I;&UO:71U<R!V:65S=&EN(&QU:V5M:7-E<W1A/"]T
M:71L93X*("`@(#QP87)A/@H@("`@(E!Y>60F(WA%-#L@:6QM;VET=7,@=FEE
M<W1I;B!L=6ME;6ES97-T82(@=F]I(&QI:71T)B-X130[)B-X130[('9I97-T
M:6EN('!Y>6YN)B-X1C8[;@H@("`@971T)B-X130[('-I;G5L;&4@;"8C>$4T
M.VAT:7-I('9I97-T:2!K=6X@=F%S=&%A;F]T=&%J82!A=6MA:7-E90H@("`@
M=FEE<W1I;BX@2V%I:VMI(',F(WA%-#MH:R8C>$8V.W!O<W1I;VAJ96QM870@
M96EV)B-X130[="!T=64@="8C>$4T.W0F(WA%-#L@=&]I;6EN=&]A+`H@("`@
M;&ES)B-X130[:W-I(&LF(WA%-#MY='0F(WA%-#MJ)B-X130[('9O:2!K:65L
M="8C>$4T.R8C>$4T.R!K=6ET=&%U<W9I97-T:6X@;"8C>$4T.VAE='0F(WA%
M-#MM:7-E;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+61I<W!O<VET:6]N7W-E;F1?;61N(B!M9#4](C%F93`T935D8S-D938X
M9#$W,F1A,C@T.#DU.3<S96$Y(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/D%S971U:W-E=#H@3"8C>$4T.VAE="8C>$4T.R!-1$X\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("`B3"8C>$4T.VAE="8C>$4T.R!-1$XB(&PF(WA%-#MH
M971T)B-X130[)B-X130[($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N("AV:65S=&EN"B`@("!A=6MA:7-U;B!K=6ET=&%U<W9I97-T:2D@+6EL
M;6]I='5S=FEE<W1I;B!K=6X@875K86ES970@=FEE<W1I;B!J80H@("`@:F]S
M(&PF(WA%-#MH971T)B-X130[:B8C>$4T.R!O;B!P>7ET)B-X130[;GET(&5T
M="8C>$4T.R!V:65S=&ES="8C>$4T.R!L)B-X130[:&5T970F(WA%-#LF(WA%
M-#MN"B`@("!K=6ET=&%U<W9I97-T:2X@57-E:6UM:7-S82!T87!A=6MS:7-S
M82!T)B-X130[;28C>$4T.R!T87!A:'1U=0H@("`@875T;VUA871T:7-E<W1I
M(&EL;6%N(&5T="8C>$4T.R!S:6YU;'1A(&MY<WET)B-X130[)B-X130[;B!L
M=7!A82X@2F]I9&5N:VEN"B`@("!V:65S=&EE;B!K;VAD86QL82!V;VET(&IO
M=71U82!P)B-X130[)B-X130[='0F(WA%-#MM)B-X130[)B-X130[;B!L)B-X
M130[:&5T970F(WA%-#LF(WA%-#MN:R8C>$8V.PH@("`@:W5I='1A=7-V:65S
M=&DF(WA%-#L@:F$@;F%P<V%U='1A;6%A;B!L:6YK:VDF(WA%-#LN"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO
M;E]R97%U97-T7V1E;&EV97)Y(B!M9#4](C(V-3DX93(Y868P-6$P-V1E-64Q
M,S8T-#8V.6)E-S$R(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%S
M971U:W-E=#H@4'EY9"8C>$4T.R!I;&UO:71U<R!V:65S=&EN('!E<FEL;&5M
M96YO<W1A/"]T:71L93X*("`@(#QP87)A/@H@("`@(E!Y>60F(WA%-#L@:6QM
M;VET=7,@=FEE<W1I;B!P97)I;&QE;65N;W-T82(@;"8C>$4T.VAE='0F(WA%
M-#LF(WA%-#L@:6QM;VET=7-V:65S=&EN"B`@("!K=6X@=F%S=&%A;F]T=&%J
M86X@<R8C>$4T.VAK)B-X1C8[<&]S=&EP86QV96QI;B!O;B!T;VEM:71T86YU
M="!V:65S=&EN"B`@("!V87-T86%N;W1T86IA;B!S)B-X130[:&LF(WA&-CMP
M;W-T:6MA;G-I;V]N+B!4)B-X130[;28C>$4T.R!E:2!T87)K;VET82!S:70F
M(WA%-#LL(&5T="8C>$4T.PH@("`@=F%S=&%A;F]T=&%J82!O;&ES:2!L=6ME
M;G5T('9I97-T:6X@=F%A;B!E='0F(WA%-#L@=FEE<W1I(&]N('1O:6UI=&5T
M='4*("`@('9A<W1A86YO='1A:F%L;&4N($MA:6MK:2!P;W-T:7!A;'9E;&EM
M970@96EV)B-X130[="!T=64@="8C>$4T.W0F(WA%-#L@=&]I;6EN=&]A+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E
M7W-P86U?869T97)?<F5P;W)T(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB8V5F
M83AB-3)E,#EB,&%D83DP93`X.#EA,SDU.65F96$B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!$96QE=&4@4W!A;2!!9G1E<B!297!O<G1I;F<\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y(&5L96-T('1O(&1O(&]N92!O9B!T
M:')E92!I=&5M<R!A9G1E<B!R97!O<G1I;F<@82!M97-S86=E(&%S(&5I=&AE
M<B!S<&%M(&]R(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!&:7)S="P@>6]U(&-A;B!D96-I9&4@=&\@9&\@;F]T:&EN9R`M('1H92!M
M97-S86=E('=I;&P@8F4@<F5P;W)T960@87,@96ET:&5R('-P86T@;W(@:6YN
M;V-E;G0@8G5T('=I;&P@;W1H97)W:7-E(')E;6%I;B!U;F-H86YG960@:6X@
M>6]U<B!M86EL8F]X+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!396-O
M;F0L(&EF(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@<W!A;2P@>6]U(&-A;B!I
M;G-T96%D(&AA=F4@=&AE(&UE<W-A9V4@8F4@:6UM961I871E;'D@9&5L971E
M9"X@(%1H:7,@<V5T=&EN9R!H87,@;F\@969F96-T(&]N(')E<&]R=&EN9R!A
M(&UE<W-A9V4@87,@:6YN;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@(%1H:7)D+"!A9G1E<B!R97!O<G1I;F<@82!M97-S86=E(&%S('-P86T@
M=&AE(&UE<W-A9V4@=VEL;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E;G0@
M;6%I;&)O>"!A;F0@;6]V960@=&\@>6]U<B!S<&%M(&9O;&1E<BX@($%L=&5R
M;F%T:79E;'DL(&EF(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN;V-E;G0@
M=&AE(&UE<W-A9V4@=VEL;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E;G0@
M;6%I;&)O>"!A;F0@;6]V960@=&\@>6]U<B!)3D)/6"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6AT;6Q?:6UA9V5?<F5P;&%C
M96UE;G0B(&UD-3TB,CAE,6-F,#AE,S(X,S0U83AE-S(W-&,X-3,T.3)D-&8B
M('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^07-E='5K<V5T.B!(5$U,
M+"!K=79A;B!K;W)V875S/"]T:71L93X*("`@(#QP87)A/@H@("`@2F]S($A4
M34PM=FEE<W1I="!N)B-X130[>71E="8C>$4T.R8C>$4T.VX@<W5O<F%A;BP@
M;FEI;B!E<W1E="8C>$4T.R8C>$4T.VLF(WA&-CL@:W5V:65N"B`@("!N)B-X
M130[>71T)B-X130[;6EN96X@=FEE<W1I;B!Y:'1E>61E<W,F(WA%-#L@96QL
M970@;VQE="!A;G1A;G5T('-I:6AE;@H@("`@;'5P86$N($AU;VUA871H86X@
M971T)B-X130[(&IO<R!K871S;W0@2%1-3"UL:6ET971T)B-X130[+"!N:6EN
M(&MU=F%T"B`@("!N)B-X130[>71E="8C>$4T.R8C>$4T.VX@875T;VUA871T
M:7-E<W1I('9I97-T:6X@;75K86YA+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]A9&1R8F]O:R(@;60U/2(W
M-3EF83-D9C(T93!A,V-D.#EF,S(P,3`R,C4R9CDQ82(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y!<V5T=6MS970Z($A434PL(&MU=F%N(&MO<G9A
M=7,@+R!.)B-X130[>70F(WA%-#L@:F]S(&]S;VET96MI<FIA<W-A/"]T:71L
M93X*("`@(#QP87)A/@H@("`@2F]S($A434PM=FEE<W1E:7-T)B-X130[(&5I
M(&]L971U:W-E;F$@;B8C>$4T.WET970F(WA%-#L@:W5V:6$@=FEE<W1I;@H@
M("`@>6AT97ED97-S)B-X130[+"!N:6EN(&XF(WA%-#MY=&5T)B-X130[)B-X
M130[;FLF(WA&-CL@:W5V870@:F]S(&PF(WA%-#MH971T)B-X130[:B8C>$4T
M.VX@<R8C>$4T.VAK)B-X1C8[<&]S=&EO<V]I=&4*("`@(&PF(WA&-CMY='EY
M(&]S;VET96MI<FIA<W1A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M;6%I;&)O>%]S=&%R="(@;60U/2(S9#$Q.39F,C8U9#AB
M-V-C-#8U96)F,C$U,3)A8V,P-2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT
M:71L93Y!<V5T=6MS970Z(%!O<W1I;&%A=&EK;VX@86QO:71U<W-I=G4\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!4)B-X130[;&PF(WA%-#L@87-E='5K<V5L
M;&$@=F]I9&%A;B!M)B-X130[)B-X130[<FET96QL)B-X130[(&UI;&QE('-I
M=G5L;&4@<&]S=&EK86YS:6\*("`@(&%U:V5A82P@:W5N('-E(&%V871A86X@
M96YS:6UM)B-X130[:7-T)B-X130[(&ME<G1A82X@2'5O;6%A(&5T="8C>$4T
M.R`B=75S:2(*("`@('9I97-T:6%S971U<R!E:2!T;VEM:2P@:F]S('-I;G5L
M;&$@;VX@=F%L:71T=6YA(")+97-K=7-T96QU<R8C>$4T.VEE(@H@("`@:B8C
M>$4T.W)J97-T>7-A<V5T=7,@+2!T)B-X130[<W,F(WA%-#L@=&%P875K<V5S
M<V$@875K96%A(&%I;F$@=FEI;65I<VEN"B`@("!V:65S=&ES:79U+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<V%V95]A='1A
M8VAM96YT<R(@;60U/2(S-6(T-C,S-&-D8V,W9F$T,39B.68Y9F-A-3@W-&4X
M,"(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y!<V5T=6MS970Z(%1A
M;&QE=&$@;&EI=&5T:65D;W-T;W0@;"8C>$4T.VAE=&5T>6ES="8C>$4T.R!V
M:65S=&5I<W0F(WA%-#L\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!*;W,@=&%L
M;&5T870@;"8C>$4T.VAE=&5T>70@=FEE<W1I(&PF(WA%-#MH971E='1Y:F5N
M('9I97-T:65N(&MA;G-I;V]N+"!N:6EN('1A;&QE=&5T86%N:V\@=FEE<W1I
M96X@;75K86YA(&UY)B-X1C8[<R!L:6ET971I961O<W1O+B!686EH=&]E:'1O
M:F$@;W9A=#H*("`@(#PO<&%R83X*"B`@("`\<&%R83XJ(")486QL971A(&%I
M;F$@;&EI='1E970B("T@)B-X0S0[3"8C>$,T.R!+3U-+04%.(&MY<WD@=&%L
M;&5T971A86YK;R!L:6ET=&5I="8C>$4T.RX@3&EI='1E970@=&%L;&5T86%N
M($%)3D$@=FEE<W1I;B!M=6MA;F$N/"]P87)A/@H@("`@(#QP87)A/BH@(DMY
M<WD@86EN82!K=6X@;"8C>$4T.VAE=&5T)B-X130[)B-X130[;B!L:6ET971I
M961O<W1O.R!/;&5T=7,@2UE,3"8C>$,T.R(@+2!+>7-Y($%)3D$@=&%L;&5T
M86%N:V\@;&EI='1E970@=FEE<W1I;B!M=6MA;F$N($]L971U<R!O;B!E='0F
M(WA%-#L@;&EI='1E970@=&%L;&5T86%N('9I97-T:6X@;75K86YA+CPO<&%R
M83X*("`@("`\<&%R83XJ(")+>7-Y(&%I;F$@:W5N(&PF(WA%-#MH971E="8C
M>$4T.R8C>$4T.VX@;&EI=&5T:65D;W-T;SL@3VQE='5S($5)(B`M($MY<WD@
M04E.02!T86QL971A86YK;R!L:6ET=&5E="!V:65S=&EN(&UU:V%N82X@3VQE
M='5S(&]N(&5T="8C>$4T.R!L:6ET=&5I="8C>$4T.R!E:2!T86QL971E=&$@
M=FEE<W1I;B!M=6MA;F$N/"]P87)A/@H@("`@(#QP87)A/BH@(B8C>$,T.VPF
M(WA%-#L@=&%L;&5T82!L:6ET=&5I="8C>$4T.R(@)B-X0S0[3"8C>$,T.R!+
M3U-+04%.(&MY<WD@=&%L;&5T971A86YK;R!L:6ET=&5I="8C>$4T.RX@3&EI
M='1E:70F(WA%-#L@14D@24M)3B8C>$,T.R!T86QL971E=&$@=FEE<W1I;B!M
M=6MA;F$N/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]I
M;F)O>"(@<W1A=&4](G5P=&]D871E(B!M9#4](C1D,3DV.64V-#!F-F4P8F5D
M-&8X.34X9C`Q.&,R9#`W(CX*("`@(#QT:71L93Y6:7)T=6%A;&ES970@:V%N
M<VEO=#H@5FER='5A86QI;F5N($EN8F]X/"]T:71L93X*("`@(#QP87)A/@H@
M("`@5FER='5A86QI;F5N(&EN8F]X(&]N('1A;&QE='1E='1U(&AA:W5E:'1O
M+"!J;VYK82!A=G5L;&$@<VEN=6X@96D@96XF(WA%-#LF(WA%-#L@=&%R=FET
M<V4@971S:28C>$4T.R!U=7-I82!V:65S=&5J)B-X130[('EH9&5S="8C>$4T
M.R!K86YS:6]S=&$@:V5R<F%L;&%A;BX@5"8C>$4T.VTF(WA%-#L@=FER='5A
M86QI;F5N(&EN8F]X(&5T<VEI('5U9&5T('9I97-T:70@:V%I:VES=&$@=&EL
M86%M:7-T87-I(&MA;G-I;VES=&$@:F$@;B8C>$4T.WET="8C>$4T.R8C>$4T
M.R!N92!Y:'1E;B8C>$4T.R!V:7)T=6%A;&ES96YA(&EN8F]X(&MA;G-I;VYA
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T
M<F%S:"(@<W1A=&4](G5P=&]D871E(B!M9#4](C$Q9CDQ.#$Q8CEB,F%F.3!F
M938X-S0P9C9A.#9C968V(CX*("`@(#QT:71L93Y6:7)T=6%A;&ES970@:V%N
M<VEO=#H@5FER='5A86QI;F5N(')O<VMA:V]R:6MA;G-I;SPO=&ET;&4^"B`@
M("`\<&%R83X*("`@(%9I<G1U86%L:6YE;B!R;W-K86MO<FEK86YS:6\@;VX@
M=&%L;&5T971T=2!H86MU96AT;RP@:F]N:V$@879U;&QA('-I;G5N(&5I('8F
M(WA%-#ML='0F(WA%-#MM)B-X130[='0F(WA%-#L@=&%R=FET<V4@=&5H9"8C
M>$4T.R!E<FEL;&ES=&$@<F]S:V%K;W)I:V%N<VEO=&$N(%-E;B!E='0F(WA%
M-#L@<VEI<G0F(WA%-#MI<VET('9I97-T96HF(WA%-#L@97)I;&QI<V5E;B!R
M;W-K86MO<FEK86YS:6]O;BP@;FEI;B!V;VET(&UE<FMI="8C>$4T.R!N92!P
M;VES=&5T=6EK<VD@<&%I:V%L;&ES97-S82!K86YS:6]S<V$N($MU;B`G3B8C
M>$4T.WET)B-X130[('!O:7-T971U="<@;VX@<&]I<R!P)B-X130[)B-X130[
M;'0F(WA%-#LL(&YI:6X@<&]I<W1E='5T('9I97-T:70@96EV)B-X130[="!N
M)B-X130[>2!P;W-T:6MA;G-I;VXF(WA%-#MK>6TF(WA%-#MS<R8C>$4T.RX@
M2W5N(&LF(WA%-#MY='0F(WA%-#MJ)B-X130[('9A;&ET<V5E(%9I<G1U86%L
M:6YE;B!R;W-K86MO<FEK86YS:6\@=&]I;6EN;F]N+"!N:6EN('!O:7-T971T
M=6MS:2!M97)K:71T>6HF(WA%-#L@=FEE<W1E:B8C>$4T.R!E='-I="8C>$4T
M.R8C>$4T.VX@:V%I:VES=&$@:V%N<VEO:7-T82!J82!P;VES=&5T=&%V86MS
M:2!M97)K:71Y="!V:65S=&ET(&XF(WA%-#MY=&5T)B-X130[)B-X130[;B!Y
M:'1E;B8C>$4T.R!K86YS:6]N82X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H
M96QP/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O971?144O````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-C,`,#$W-#,R`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L
M92]E=%]%12],0U]-15-304=%4R\`````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,C$R,3<`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O;&]C86QE+V5T7T5%+TQ#7TU%4U-!1T53+VEM<"YM;P``
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8Q,#,U`#$P-#$W,S8R-S8S`#`R,C,T
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````'4!```<````Q`L``/,!``!L%P```````#@?```*````.1\```H`
M``!$'P``"@```$\?```*````6A\``!<```!E'P``*````'T?```R````IA\`
M`#(```#9'P``&P````P@```N````*"```#<```!7(```?````(\@```<````
M#"$``!T````I(0``"````$<A```%````4"$```,```!6(0``#P```%HA```(
M````:B$```@```!S(0``&0```'PA```'````EB$```P```">(0``#@```*LA
M```%````NB$```,```#`(0``3@```,0A``!0````$R(``$(```!D(@``'P``
M`*<B```(````QR(``!$```#0(@``(0```.(B```[````!",``"L```!`(P``
M#````&PC```)````>2,```8```"#(P``"@```(HC```+````E2,``"<```"A
M(P``+````,DC```J````]B,``!$````A)```"@```#,D```#````/B0```@`
M``!")```"0```$LD```$````520```0```!:)```!@```%\D```.````9B0`
M`!4```!U)```/@```(LD```"````RB0```H```#-)```!@```-@D```*````
MWR0```T```#J)```7P```/@D```<````6"4```X```!U)0``#````(0E```-
M````D24```P```"?)0``%````*PE```/````P24```<```#1)0``$````-DE
M``!<````ZB4```0```!')@``!P```$PF```.````5"8``"D```!C)@``!@``
M`(TF```-````E"8``!H```"B)@``'0```+TF```9````VR8``%T```#U)@``
M*````%,G```"````?"<```4```!_)P``!````(4G```0````BB<``!D```";
M)P``&@```+4G```&````T"<``!````#7)P``!P```.@G```0````\"<``!P`
M```!*```"@```!XH```4````*2@``"\````^*```#P```&XH```'````?B@`
M``\```"&*```(P```)8H```F````NB@``"````#A*```!`````(I```2````
M!RD```4````:*0``#@```"`I```$````+RD``!8````T*0``!0```$LI```/
M````42D``!(```!A*0``#0```'0I```5````@BD``"D```"8*0``+````,(I
M```H````[RD``!`````8*@``$````"DJ```/````.BH```L```!**@``#P``
M`%8J```,````9BH```\```!S*@``"@```(,J```2````CBH```T```"A*@``
M#````*\J```A````O"H```,```#>*@``#````.(J```'````[RH```0```#W
M*@``"@```/PJ```0````!RL```<````8*P``"````"`K```9````*2L```0`
M``!#*P``#````$@K```4````52L```8```!J*P``!````'$K```,````=BL`
M`!$```"#*P``#````)4K```*````HBL```4```"M*P``!@```+,K```*````
MNBL```D```#%*P``$@```,\K```2````XBL``!````#U*P``)`````8L```(
M````*RP```D````T+```$````#XL```:````3RP```8```!J+```#````'$L
M```'````?BP```L```"&+````@```)(L```'````E2P```@```"=+```-P``
M`*8L```/````WBP```<```#N+```$P```/8L```,````"BT```X````7+0``
M#````"8M```.````,RT```\```!"+0``#0```%(M```/````8"T``"8```!P
M+0``"P```)<M```&````HRT```<```"J+0``!````+(M```$````MRT```<`
M``"\+0``!0```,0M```#````RBT```@```#.+0``#````-<M```$````Y"T`
M``P```#I+0``"0```/8M```"`````"X``!D````#+@``$@```!TN```.````
M,"X``!H````_+@``!````%HN```+````7RX```D```!K+@``#0```'4N```,
M````@RX``!0```"0+@``%@```*4N```%````O"X```P```#"+@``(P```,\N
M```'````\RX``!$```#[+@``#0````TO```-````&R\```<````I+P``"```
M`#$O```5````.B\``!X```!0+P``"P```&\O```:````>R\```@```"6+P``
M%````)\O```%````M"\``#$```"Z+P``*````.PO```:````%3```"@````P
M,```*0```%DP```N````@S```#8```"R,```+````.DP```Q````%C$``!``
M``!(,0``#0```%DQ```%````9S$``!,```!M,0``#0```($Q```6````CS$`
M``0```"F,0``"````*LQ```0````M#$``!4```#%,0``$P```-LQ```'````
M[S$``!4```#W,0``"P````TR```6````&3(```8````P,@``"P```#<R```Z
M````0S(```T```!^,@``!0```(PR```,````DC(```T```"?,@``"@```*TR
M```&````N#(```X```"_,@``!@```,XR``!+````U3(```H````A,P``!P``
M`"PS```Y````-#,```8```!N,P``#@```'4S```$````A#,```8```"),P``
M"@```)`S```+````FS,``!H```"G,P``%P```,(S```7````VC,``!L```#R
M,P``&0````XT```?````*#0```P```!(-```$P```%4T```1````:30``$,`
M``![-```.0```+\T```$````^30```P```#^-```$0````LU```$````'34`
M`!`````B-0``%P```#,U```2````2S4```L```!>-0``#0```&HU```4````
M>#4``"\```"--0``!P```+TU```-````Q34``!8```#3-0``"P```.HU```%
M````]C4```0```#\-0``,P````$V```>````-38``'4```!4-@``/@```,HV
M``!"````"3<``#T```!,-P``*0```(HW```I````M#<``#$```#>-P``*```
M`!`X```F````.3@``#X```!@.```1P```)\X``!7````YS@``%4````_.0``
M+P```)4Y``!5````Q3D``"L````;.@``.P```$<Z```/````@SH``"$```"3
M.@``'````+4Z```+````TCH```4```#>.@```@```.0Z```-````YSH``"``
M``#U.@``)@```!8[```*````/3L``!,```!(.P``"````%P[```6````93L`
M``P```!\.P``!P```(D[```&````D3L``!H```"8.P``$0```+,[```3````
MQ3L```P```#9.P``"````.8[```4````[SL```<````$/```)P````P\```&
M````-#P```T````[/```"P```$D\```,````53P```H```!B/````@```&T\
M```&````<#P```,```!W/```(0```'L\```D````G3P``!T```#"/```&0``
M`.`\```7````^CP``"H````2/0``*P```#T]``!%````:3T``"<```"O/0``
M(0```-<]```K````^3T``!T````E/@``)@```$,^```E````:CX``#T```"0
M/@``00```,X^```H````$#\``"P````Y/P``,````&8_```0````ES\``',`
M``"H/P``'P```!Q````/````/$````P```!,0```$````%E````/````:D``
M``0```!Z0```!````']````"````A$````X```"'0```#P```)9```!;`0``
MID````H````"0@``"@````U"```*````&$(```H````C0@``&P```"Y"```9
M````2D(``#4```!D0@``)P```)I"```:````PD(``#8```#=0@``,P```!1#
M``!W````2$,``!H```#`0P``&@```-M#```(````]D,```4```#_0P``!```
M``5$```2````"D0```D````=1```#0```"=$```A````-40```<```!71```
M#@```%]$```&````;D0```4```!U1```!````'M$```_````@$0``%$```#`
M1```30```!)%```;````8$4```@```!\10``#P```(5%```?````E44``#H`
M``"U10``,@```/!%```-````(T8```8````Q1@``!````#A&```&````/48`
M``@```!$1@``(````$U&```>````;D8``!H```"-1@``$@```*A&```+````
MNT8```,```#'1@``"0```,M&```-````U48```0```#C1@``!P```.A&```%
M````\$8```T```#V1@``!0````1'```]````"D<```8```!(1P``#0```$]'
M```%````74<```H```!C1P``#````&Y'``!D````>T<``"<```#@1P``#0``
M``A(```)````%D@```T````@2```"0```"Y(```1````.$@```H```!*2```
M!0```%5(```0````6T@``%D```!L2```!P```,9(```$````SD@``!````#3
M2```*0```.1(```#````#DD```D````220``&````!Q)```>````-4D``!(`
M``!420``;````&=)```\````U$D```(````12@``"````!1*```'````'4H`
M``\````E2@``%P```#5*```=````34H```<```!K2@``$0```'-*```*````
MA4H``!$```"02@``)````*)*```'````QTH``!(```#/2@``*````.)*```6
M````"TL```X````B2P``#@```#%+```P````0$L``"X```!Q2P``'0```*!+
M```&````ODL``!$```#%2P``!P```-=+```1````WTL```<```#Q2P``'```
M`/E+```&````%DP``!$````=3```$P```"],```0````0TP``!0```!43```
M(@```&E,```H````C$P``!P```"U3```%````-),```5````YTP``!,```#]
M3```$P```!%-```6````)4T```P````\30``#P```$E-```(````64T``!``
M``!B30``"0```'--```-````?4T``"(```"+30``!````*Y-```+````LTT`
M``<```"_30``!````,=-```0````S$T```D```#=30``!@```.=-```'````
M[DT``!0```#V30``!P````M.```.````$TX```\````B3@``!@```#).```#
M````.4X``!`````]3@``#P```$Y.```.````7DX```X```!M3@``!0```'Q.
M```)````@DX```\```",3@``!@```)Q.```.````HTX``!,```"R3@``$@``
M`,9.```:````V4X```0```#T3@``$````/E.```8````"D\``"<````C3P``
M"@```$M/```/````5D\```H```!F3P``$P```'%/```"````A4\```D```"(
M3P``"P```))/```S````GD\```X```#23P``!P```.%/```0````Z4\```T`
M``#Z3P``"@````A0```,````$U````X````@4```#P```"]0```0````/U``
M``<```!04```*0```%A0```7````@E````4```":4```"0```*!0```%````
MJE````0```"P4```!````+50```,````NE````,```#'4```"P```,M0```+
M````UU````@```#C4```#0```.Q0```1````^E````(````,40``&`````]1
M```0````*%$``!`````Y40``)0```$I1```,````<%$``!````!]40``#0``
M`(Y1```,````G%$```T```"I40``%P```+=1```4````SU$```<```#D40``
M#````.Q1```M````^5$```D````G4@``"````#%2```+````.E(``!$```!&
M4@``!@```%A2```(````7U(``!H```!H4@``$P```(-2```$````EU(```T`
M``"<4@``!P```*I2```,````LE(```<```"_4@``'````,=2```>````Y%(`
M`!<````#4P``$P```!M3```D````+U,``#<```!44P``(````(Q3```I````
MK5,``#,```#74P``#`````M4```0````&%0```8````I5```$P```#!4```1
M````1%0``"$```!65````P```'A4```+````?%0``!````"(5```%````)E4
M```:````KE0```D```#)5```&````--4```/````[%0``!@```#\5```!P``
M`!55```,````'54``#8````J50``!@```&%5```%````:%4```T```!N50``
M#@```'Q5```&````BU4```8```"250``%````)E5```%````KE4``%D```"T
M50``$`````Y6```(````'U8``#,````H5@``!@```%Q6```/````8U8```8`
M``!S5@``!````'I6```*````?U8``!````"*5@``%P```)M6```6````LU8`
M`!8```#*5@``&````.%6```0````^E8``!0````+5P``"@```"!7```9````
M*U<``!<```!%5P``-P```%U7```L````E5<```4```#"5P``$````,A7```/
M````V5<```8```#I5P``$P```/!7```3````!%@```D````86```$@```")8
M```5````-5@``!P```!+6```&0```&A8```%````@E@```H```"(6```#P``
M`)-8```*````HU@```0```"N6```!0```+-8```M````N5@``!D```#G6```
M9P````%9```M````:5D``#<```"760``(P```,]9```=````\UD``",````1
M6@``(0```#5:```5````5UH``"````!M6@``*@```(Y:```R````N5H``#P`
M``#L6@``.P```"E;```@````95L``#D```"&6P``'P```,!;```^````X%L`
M``L````?7```(````"M<```?````3%P```\```!L7```"````'Q<```'````
MA5P```L```"-7```'@```)E<```J````N%P```D```#C7```$````.U<```&
M````_EP``!8````%70``$````!Q=```&````+5T```@````T70``'````#U=
M```4````6ET```X```!O70``$@```'Y=```,````D5T``!0```">70``"```
M`+-=```V````O%T```P```#S70``$@````!>```1````$UX```\````E7@``
M"@```#5>```"````0%X```L```!#7@```P```$]>```<````4UX``!X```!P
M7@``&0```(]>```6````J5X``!0```#`7@``'````-5>```I````\EX``"X`
M```<7P``'@```$M?```@````:E\``"H```"+7P``(````+9?```I````UU\`
M`"8````!8```,P```"A@```_````7&```!@```"<8```)````+5@```U````
MVF````D````080``=P```!IA```?````DF$```T```"R80``#@```,!A```0
M````SV$```\```#@80``!P```/!A```,````^&$```,````%8@``"0````EB
M```)````$V(```$```!+`````````(P```":````?P```%<!```D`0``````
M`)<``````````````$`````;``````````\```"L````7`$``"````#"````
M(@```/,```#V`````````!(!``!2`````````&D!````````2`$``$,!``#R
M``````````````"-````B0```(<```"W`````````%0!``!R`0``KP```&X!
M````````QP`````````'````E````,H```!!``````````````"\````````
M```````%````;P$```````!M`0``"0$``'T```#N````DP```"8````1`0``
M/P```+@`````````!````)8```!%`0``40$``!P!``#%````+0$``#(````?
M````.`$``&T````-````N0```#L`````````]````%D```#/````.P$``$H`
M```8````#````!`!````````A````&<``````````````%@```!G`0``````
M`"P!```G````0`$```````!&`0```````-,```!3`0```````.H```#+````
M[P```'0!````````G@````\!``"=````+P```!<```"M````A0```+X```!2
M`0``#@```*@```#&`````````!P````A`0``"0```"`!```&````@0```!<!
M``#H````^````'0```#?````V0````,!````````%@$``&L````Q````5@``
M`&4!``#@````F0````````#:`````````,X`````````-0$``$(````I`0``
MU@```*<`````````4P`````````=````#@$``#T```#=````.@$```````!N
M````=P`````````:`0```````(\```!D````.`````(!````````&`$`````
M``!=`0``"````%D!`````````````%T````4`0``JP``````````````````
M`"$`````````F````%X!```H`0``;````'`````+````Y0`````````T````
M$P```",!``!!`0```````.0```#>````*P```````````````````"8!````
M````I@```"\!````````8````((````V`````````*H````E`0``````````
M``!^````P0```!,!``!'`0``5@$``-P```#L`````````#4````^`0``````
M`&@!```:````+@$``'4!``#F````2P$`````````````T``````````L````
M=@```+0````E````>@```%<````9````-P```+(`````````C@```&H!````
M````I0```*X`````````<0$``$0!```&`0``'P$``$H!``!:`0``````````
M```0````E0```)$``````````0$``%0````>`0``D````',```#C````````
M``````#A````/@```&\``````````````'`!```$`0```````)\````*`0``
M``````````#5`````````',!```J````3@```*``````````(P```/$```#U
M````\````#`!``#4````80$```````!J````PP```$<`````````HP```$4`
M````````,P```#T!```1````L````$T!``````````````<!``"A````````
M`*0`````````3````#<!``#7`````````$D```!B````R0```+T````V`0``
M20$``.(`````````VP````````#1````LP```%\!``"`````,`````H```!.
M`0``'0$``#,!``!C````1@````````"[``````````````#,`````````.<`
M``"#````9`$``#0!``"_````.@````(```!1`````````-@```!H````^0``
M````````````2````#\!``"U````*@$``!4````2````%````%L!``"(````
M````````````````/`$```````"V````=0```,@```!5`0```````&$```!I
M````^@```/X````9`0```````'@```!R````90```%L```!/````7@```'$`
M````````4`$``/<```!C`0```````$T```!:`````````!L!``!#````Z0``
M```````,`0```````#(!``````````````,`````````:P$``!8````Q`0``
MB@```%P````\````50`````````5`0```````-(```!"`0````````````"2
M````J0`````````>````BP````````!,`0``8@$``"X``````0```````"@`
M```Y````#0$``%\`````````A@`````````+`0``P````)L```"<````*P$`
M`/P`````````L0```'D```!\````_P```,0```!0````>P```"<!````````
M`````.L```!F````6`$``,T````D`````````"D``````````````&P!``#M
M````+0````````````````````4!````````8`$``$0```!F`0``.0$``$\!
M```B`0``^P````@!``#]````H@```+H`````("`@("`@5&\Z(``@("`@1&%T
M93H@`"`@("!&<F]M.B``(%-U8FIE8W0Z(``E9"!T;R`E9"!O9B`E9"!-97-S
M86=E<P`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E
M;F%M960N`"5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O
M9B!T:&4@;6]N=&@N`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*0`H07!P
M;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C<F5E;BXI`"A$
M:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@
M<V-R965N+BD`*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@
M87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@
M;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*0`J
M($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J`"H@4&QE87-E('-E;&5C="!A
M9&1R97-S*&5S*2`J`#(T(&AO=7)S`$%-+U!-`$%D9`!!9&0@82!N97<@=7-E
M<CH`061D('!A:7(`061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=')A=&EO;@!!;&EA<P!!
M;&P`06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I
M;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z`$%L;"!M97-S
M86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W
M:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@<V5N="UM86EL
M(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE
M=&5D+@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N<W=E<F5D
M`$%N<W=E<F5D(&UE<W-A9V5S`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D
M;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@
M9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@96UP='D@=&AI<R!F;VQD97(_`$%R<FEV86P@5&EM90!!<V-E;F1I;F<`
M071T86-H`$%T=&%C:&UE;G0`071T86-H;65N=',`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!=F%I;&%B;&4@9FEE;&1S.@!"86-K
M('1O("5S`$)C8P!":7)T:&1A>0!";&%C:VQI<W0`0F]D>0!";W1H`$-A;F-E
M;`!#86YC96P@365S<V%G90!#86YC96P@4')O8FQE;2!297!O<G0`0V%N8V5L
M;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET
M<R!C;VYT96YT<RX`0V,`0V5L;"!0:&]N90!#:&%N9V4`0VAA;F=E($%L;`!#
M:&%N9V4@1F]L9&5R`$-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I
M9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E
M<&QY('1O('EO=7(@96UA:6PN`$-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA
M:6P`0VAO;W-E($%C=&EO;CH`0VQO<V4@5VEN9&]W`$-L;W-E9"!&;VQD97(`
M0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&;VQD97)S`$-O;&QA<'-E($9O
M;&1E<@!#;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]N=')O;"!W:&5N(&YE
M=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO
M="!T;R!N;W1I9GD@>6]U('=H96X@:70@87)R:79E<RX`0V]P>0!#;W)R96-T
M`$-O<G)E8W1E9"!497AT`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-R96%T90!#<F5A=&4@1F]L9&5R`$-R96%T92!A(&YE
M=R!D<F%F=',@9F]L9&5R`$-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R
M`$-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(`0W)E871E(&9I;'1E<FEN9R!R
M=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@
M:6YT;R!F;VQD97)S+"!A;F0@9&5L971E('-P86TN`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`1$0`1&%I;'D`1&%T90!$969A
M=6QT($ED96YT:71Y`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5L971E`$1E;&5T92!&;VQD97(H<RD`
M1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T:6YG(&%N9"!-;W9I;F<@
M365S<V%G97,`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M:6T@<VEG;F%T=7)E<S\`1&ES<&QA>0!$:7-P;&%Y($]P=&EO;G,`1&\@3F]T
M($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@=&\@;W!E;B!T
M:&%T(&9O;&1E<C\`1&]N90!$;W=N;&]A9"!&;VQD97(H<RD`1')A9G0`1')A
M9G1S(&9O;&1E<CH`161I=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5M86EL
M`$5M<'1Y($9O;&1E<BAS*0!%;7!T>2!4<F%S:"!F;VQD97(`16UP='D@<F5S
M=6QT+@!%;F0@9F]R=V%R9&5D(&UE<W-A9V4`16YT97(@=&AE(&YA;64@9F]R
M('EO=7(@;F5W(&1R869T<R!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO
M=7(@;F5W('-E;G0@;6%I;"!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO
M=7(@;F5W('1R87-H(&9O;&1E<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P
M('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA
M;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X<&%N9"!!
M;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N9"!&;VQD97(`17AP86YD($YA
M;65S`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`1FEL
M92!-86YA9V5R`$9I;'1E<G,`1FEN9`!&:7)S="!086=E`$9O;&1E<B!.879I
M9V%T;W(`1F]R=V%R9`!&;W)W87)D.@!&;W)W87)D960@;65S<V%G92!F<F]M
M("5S`$9R;VT`1G)O;2!!9&1R97-S`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R
M;W5P<P!(96QP`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E9`!(;VUE
M($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)9VYO<F4`26=N;W)E($%L;`!)
M;7!O<G1A;G0`26UP;W)T86YT(&UE<W-A9V5S`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I
M;B!A(')E<&QY/P!,86YG=6%G90!,87-T(%!A9V4`3&ES="!(96QP(%1O<&EC
M<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G(&EN('1O
M("5S`$QO9R!O=70`3&]G:6X@5&%S:W,`34T`36%I;&)O>`!-87)K(&%S.@!-
M87)K(&1I9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N
M="!C;VQO<G,_`$UA=&-H:6YG(&9I96QD<P!-96UB97)S`$UE<W-A9V4@0V]M
M<&]S:71I;VX`365S<V%G92!$871E`$UE<W-A9V4@4V5A<F-H`$UE<W-A9V4@
M4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9I97=I;F<`365S<V%G92!F
M;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G97,@<&5R('!A9V4@:6X@=&AE
M(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`36]D:69Y`$UO;G1H;'D`36]V
M90!.86UE`$YE='=O<FL`3F5V97(`3F5W`$YE=R!-86EL`$YE=R!M97-S86=E
M<P!.97AT`$YE>'0@365S<V%G90!.97AT(%!A9V4`3F\`3F\@9F]L9&5R<R!W
M97)E('-P96-I9FEE9`!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S=&EO
M;G,`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F]N90!.;W0@1&5L971E
M9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&1E
M;&5T960@;65S<V%G97,`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.;W1E<P!/
M;&0@;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E
M9"X`3W!T:6]N<P!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`%!A
M9V4@)60@;V8@)60`4&%R="AS*0!087-S=V]R9`!087-S=V]R9',@;75S="!M
M871C:"X`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<FUI<W-I
M;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L`%!E<G-O
M;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!L86-E('EO=7(@<VEG;F%T=7)E(&)E
M9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\`4&QE87-E(&5N=&5R('1H92!N
M86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N
M86UE.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L
M96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`
M4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY
M(&%C=&EO;G,N`%!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T
M;R!S96%R8V@N`%!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T
M:&ES(&]P97)A=&EO;BX`4')E=FEO=7,@365S<V%G90!0<F5V:6]U<R!086=E
M`%!R:6YT`%!R;V)L96T@1&5S8W)I<'1I;VX`4'5R9V4@1&5L971E9`!0=7)G
M92!4<F%S:"!H;W<@;V9T96XZ`%)E860`4F5D:7)E8W0`4F5D:7)E8W0@365S
M<V%G90!2961I<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D
M+@!2969R97-H`%)E9G)E<V@@1F]L9&5R(%9I97=S.@!296QO860@5FEE=P!2
M96UE;6)E<B!T:&4@;&%S="!V:65W`%)E;6]V90!296UO=F4@<&%I<@!296YA
M;6EN9R`B)7,B('1O("(E<R(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%)E<&QA8V4@=VET:#H`4F5P;'D`4F5P;'D@=&\@06QL`%)E
M<&QY('1O($%L;#H`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S(%-P86T`
M4F5S=6UE`%)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E
M;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/P!3879E($1R
M869T`%-A=F4@87,`4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%-E87)C:`!396%R8V@@4F5S=6QT
M<P!3965N`%-E;&5C=`!396QE8W0@86QL`%-E;&5C="!N;VYE`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE;2!2
M97!O<G0`4V5N="!M86EL(&9O;&1E<CH`4V5T('!R969E<F5N8V5S(&9O<B!W
M:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S
M+@!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S
M879I;F<@82!D<F%F=#\`4VAO=P!3:&]W($1E;&5T960`4VAO=R!5;G-U8G-C
M<FEB960`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R
M($EN<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5L;"!#:&5C:P!3<&5L;"!#
M:&5C:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R<F]R<R!P
M97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-U8FIE8W0`4W5B:F5C
M="!&:65L9`!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U9V=E<W1I;VYS`%1A
M<VMS`%1E>'0`5&AE(&-U<G)E;G0@9F]L9&5R*',I("(E<R(@=VEL;"!B92!R
M96YA;65D('1O("(E<R(N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T
M<P!4:&4@9F]L9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S
M(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S
M964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B
M('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I
M="X`5&AE(&9O;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N
M;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@
M;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE
M(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"X`5&AE(&9O
M;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"X`5&AE(&9O;&1E
M<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R`B)7,B+@!4:&4@
M<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N`%1H97)E(&%R
M92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N`%1H97)E('=A<R!A('!R
M;V)L96T@97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E
M<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R('-E
M;F1I;F<@>6]U<B!M97-S86=E.B`E<P!4:&ES(&UA>2!T86ME('-O;64@=&EM
M92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O;G1I;G5E/P!4:&ES(&UE
M<W-A9V4@=&\`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AR96%D(%9I97<`5&ET;&4`
M5&\`5')A<V@@9F]L9&5R.@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%N<W=E<F5D`%5N86YS=V5R960@;65S<V%G97,`56YD96QE=&4`56YD:7-C
M;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`56YN86UE9`!5;G-E96X`
M56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RD`57-E($1E9F%U;'0@5F%L=64`
M57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<FYA;64`57-E
M<G,@:6X@=&AE('-Y<W1E;3H`5FEE=R`E<P!6:65W(&]R(&UA:6QB;W@@=&\@
M9&ES<&QA>2!A9G1E<B!L;V=I;CH`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EE
M<P!9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R``66]U(&%R92!C
M<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N`%EO=2!A<F4@<F5N86UI;F<@
M=&AE(&9O;&1E<CH@`%EO=2!H879E("5S(&YE=R!M97-S86=E<RX`66]U(&AA
M=F4@,2!N97<@;65S<V%G92X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R<SH`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M
M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+@!9;W4@;75S="!S
M96QE8W0@86X@861D<F5S<R!F:7)S="X`66]U(&UU<W0@<V5L96-T(&%T(&QE
M87-T(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y(&$@<F5C
M:7!I96YT+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!W
M97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N($AE<F4@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E
M<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@<W5C
M8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S
M9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(@!9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA
M=&EO;@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"X`66]U<B!S:6=N871U<F4Z`%M.;R!3=6)J96-T
M70!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!F<F]M`&YO;F4`
M;W(`<W!E;&QI;F<@97)R;W(`<W!E;&QI;F<@97)R;W)S`%!R;VIE8W0M260M
M5F5R<VEO;CH@24U0(#0N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`T+3`V+3`R(#$P
M.C0Y*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!4;V]M87,@06%S(#QT;V]M87,N
M86%S0&UA:6PN964^"DQA;F=U86=E+51E86TZ($5S=&]N:6%N(#QD979`;&ES
M=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,3,*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@."UB:70*`"!+96QL96QE.B``($MU=7#D978Z(``@
M2V5L;&5L=#H@`"`@(%1E96UA.B``2VER:F%D("5D(&MU;FD@)60L(&MO:VMU
M("5D`"5S($AO;VQD=7-T]O9D("T@:VEN;FET=7,`)7,@;VX@:G5B82!O;&5M
M87,N(%-I;G4@)7,@:V%U<W1A(&5I(&YI;65T871U9"#\;6)E<BX`)7,@:V%U
M<W0@;FEM971A=&%K<V4@_&UB97(@:W5U(&%L9W5S97,N`"5S.B`E<R`H)60F
M;F)S<#LO)FYB<W`[)60I`"A386QV97-T82!N965D(&UU=71U<V5D(&IA(&UI
M;F4@:N1R9VUI<V5L92!E:W)A86YI;&4N*0`HY')A('-A;'9E<W1A(&UU=71U
M<VD@:F$@;6EN92!T86=A<VD@:VER:F$@:G5U<F1E+BD`*$UI;F4@=&%G87-I
M(&MI<FIA(&IU=7)D92!SY&EL:71A9&5S(&OU:6L@<V5N:2!S86QV97-T871U
M9"!M=75D871U<V5D+B!396QL96P@96MR86%N:6P@=&5H='5D(&UU=61A='5S
M:2!%22!304Q615-4051!+BD`*B!,:7-A(&YE960@=F%J=71A9&5S($]+("H`
M*B!086QU;B!V86QI(&%A9')E<W,H:60I("H`,C0@='5N9&D`14PO4$P`3&ES
M80!,:7-A('5U<R!K87-U=&%J83H`3&ES82!P86%R`$QI<V$@:V%S=71A:F$`
M2V%S=71A:F%T92!L:7-A;6EN92!P;VQE(&QU8F%T=60N`$%A9')E<W,`06%D
M<F5S<VER86%M870`2&%L9'5S`$%L:6%S`$OU:6L`2_5I:R!K:7)J860@:N1R
M9VUI<W1E<R!K875S=&%D97,@<V%L=F5S=&%T86MS92#\:'1E($U"3U@@9F%I
M;&DZ`$OU:6L@:VER:F%D('-I;G4@(B5S(B!K875S=&%S(&UI<R!O;B!V86YE
M;6%D(&MU:2`E<R!PY&5V82!K=7-T=71A=&%K<V4@:N3D9&%V86QT+@!+]6EK
M('-A861E='5D(&MI<FIA9&4@:V%U<W1A9"P@;6ES(&]N(')O:&ME;2!K=6D@
M)7,@:W5U9"!V86YA9"P@:W5S='5T871A:W-E+@!3:7-E<W1A=&D@;'5B86UA
M='4@=N3D<G1U<RX`5F%S=&%T=60`5F%S=&%T=60@:VER:F%D`$MA<R!O;&5D
M(&MI;F1E;"!E="!S;V]V:60@<V5D83\`2V%S(&]L960@:VEN9&5L(&5T('-O
M;W9I9"!N965D(&MI<FIA9"!*Q,1$059!3%0@:W5S='5T861A/P!+87,@;VQE
M9"!K:6YD96P@970@<V]O=FED('-E;&QE(&MA=7-T82!T_&AJ96YD861A/P!3
M86%B=6UI<V4@865G`$MA<W9A=@!,:7-A`$QI<V%N9`!,:7-A;F1I9`!+871S
M92!K=7-T=71A9&$@;VQE;6%T=70@9W)U<'!I+@!+871S92!K=7-T=71A9&$@
M;VQE;6%T=70@;'5B82X`2V%T<V4@;75U=&$@;VQE;6%T=70@;'5B82X`2V%S
M=71A=&%V860@=N1L:F%D`%1A9V%S:2`E<R=I`$)C8P!3_&YN:7#D978`375S
M="!N:6UE:VER:0!+96AA`$WU;&5M860`3&]O8G4`3&]O8G4@:VER:F%S=`!,
M;V]B=0!396QL97-T(&MI<FIA<W0@;&]O8G5M:7-E9V$@;.1H96(@=&5M82!S
M:7-U(&EG879E<V5K<R!K86]T<VDN`$MO;W!I80!-;V)I:6QT96QE9F]N`$UU
M=61A`$UU=61A(&OU:6L`375U9&$@:V%U<W1A`$UU=61A(&YI;64L(&%A9')E
M<W-I(&IA(&%L;&MI<FIA(&UI9&$@:6YI;65S960@;N1E=F%D(&MU:2!N860@
M<VEN=2!K:7)J82!L;V5V860@:F$@<V5L;&5L92!V87-T879A9"X`2V]N=')O
M;&QI(&MA<R!K875S=&$H9&4I<R!O;B!U=7-I(&MI<FIU`%9A;&D@=&5G979U
M<SH`4W5L92!A:V5N`$MA=7-T('-U;&5T=60`4W5L92!K]6EK`%-U;&4@:_5I
M:R!K875S=&%D`%-U;&4@:V%U<W0`1FER;6$`2VEN;FET82!S86QA<_5N80!-
MY.1R82!M:6QL86P@:V]N=')O;&QI9&$@=75T92!K:7)J861E('-A86)U;6ES
M="!J82!K87,@86YD82!S=6QL92!MY')K=2!K=6D@;F%D('-A86)U=F%D+@!+
M;W!E97)I`-5I9V4`4&%R86YD871U9"!T96MS=`!%:2!S=75D82!KY&EV:71A
M9&$@:&]O;&1U<W3V]B!M;V]D=6QI="`E<P!5=7,`3&]O(&MA=7-T`$QO;R!U
M=7,@;75S=&%N9&ET92!K875S=`!,;V\@=75S('-A861E='5D(&MI<FIA9&4@
M:V%U<W0`3&]O('5U<R!P<OQG:6MA=7-T`$QO;R!F:6QT<F5E<FEM:7-R965G
M;&ED(&5T(&MO<G)A<W1A9&$@;VUA('-A86)U=F%T('!O<W1I+"!S;W)T965R
M:61A('-E92!K875S=&%D97-S92!J82!K=7-T=71A9&$@<N1M<'-P;W-T+@!+
M;W)R86QD82!T]FED(&UI9&$@=&5H86MS92`E<RUI('-I<W-E;&]G:6UI<V5L
M(&%U=&]M86%T<V5L="X`4%``26=A('#D978`2W5U<.1E=@!686EK96ED96YT
M:71E970`5F%I:VEM:7-I('-O<G1E97)I;6EN93H`5F%I:VEM:7-I('-O<G1E
M97)I;6ES92!S=75N9#H`2W5S='5T80!+=7-T=71A(&MA=7-T*&%D*0!+=7-T
M=71A='5D`$MU<W1U=&%T=60@:VER:F%D`$MI<FIA9&4@:W5S='5T86UI;F4@
M:F$@_&UB97)T]7-T;6EN90!+86AA;F5V`$MI<FIE;&1A('!R;V)L965M:0#<
M:W-I:V%S:F%D(&QO9VET:2!A9&UI;FES=')A871O<FD@:F%O:W,N`$[D:71A
M(&%L;&MI<FIA('1U:&UI;'0`16MR86%N:2!S96%D960`16MR86%N:2!S96%D
M960`Q')A(&MO;G1R;VQL:2!K875S=&$H9&4I<R!U=71E(&MI<FIA9&4@;VQE
M;6%S;VQU`,1R82#\<FET82!M86EN=&5N86YC92YP:'`@9F%I;&D@;W1S92!K
MY&EV:71A9&$`2V%S('1A:&%D(&%V861A('-E;&QE(&MA=7-T83\`5F%L;6ES
M`$MO<&5E<FD@:V%U<W0H860I`$UU<W1A;F0`375S=&%N9&ET92!K875S=#H`
M4&%R86YD80!087)A;F1A(&9I;'1R965R:6UI<W)E96=L96ED`$4M;6%I;`!+
M=7-T=71A(&MA=7-T*&%D*0!4_&AJ96YD82!P<OQG:6MA=7-T`%1U;&5M=7,@
M;VX@=/QH:2X`161A<W1A='5D(&MI<FIA(&SU<'``4VES97-T82!U=64@;75S
M=&%N9&ET92!K875S=&$@;FEM:0!3:7-E<W1A('5U92!S86%D971U9"!K:7)J
M861E(&MA=7-T82!N:6UI`%-I<V5S=&$@=75E('!R_&=I:V%U<W1A(&YI;6D`
M26=A(#$U(&UI;G5T:2!T86=A;G0`26=A(#,P('-E:W5N9&D@=&%G86YT`$EG
M82`U(&UI;G5T:2!T86=A;G0`26=A;"!S:7-S96QO9VEM:7-E;`!)9V$@<&]O
M;&4@='5N;FD@=&%G86YT`$MO<F0@;6EN=71I<P!.Y&ED:7-VY.1R='5S960`
M079A(&OU:6L`079A(&OU:6L@:V%U<W1A9`!!=F$@:V%U<W0`3&%H96YD82!N
M:6UE9`!%:2!S86%N=60@_&AE;F1U<W0@3$1!4"!S97)V97)I9V$N`$9A:W,`
M1F%I;&EH86QD=7(`1FEL=')I9`!,96EA`$5S:6UE;F4@;&5H96O\;&<`2V%U
M<W1A<'5U`$5D87-T80!%9&%S=&$Z`$5D87-T871U9"!K:7)I("5S)VQT`$ME
M;&QE;'0`4V%A=&IA(&%A9')E<W,`1W)U<'!I9&4@:&%L9'5S`$=R=7!I9`!!
M8FD`4&5I9&$@:W5S='5T871U9`!096ED82!T96QL:6UA=&$`2V]D=6YE(&%A
M9')E<W,`2V]D=6YE('1E;&5F;VX`2&]R9&4`26=N;W)E97)I`$EG;F]R965R
M:2!K]6EK:0!4Y&AT:7,`5.1H='-A9"!K:7)J860`26UP;W)D:71U9"!VY&QI
M.B`E<P!);7!O<F1I='5D(';D;&IA9#H`5O5T82!V87-T=7-E<W-E(&%L9VYE
M(&MI<FD`2V5E;`!6:6EM86YE(&QE:&5K_&QG`$%B:6EN9F\@=&5E;6%D92!N
M:6UE:VER:0!+87-U=&%J871E(&YI;65K:7)J82!P;VQE(&QU8F%T=60@;N1H
M82X`3&]G:2!S:7-S90!,;V=I('-I<W-E("5S)VD`3&]G:2!VY&QJ80!4]O9D
M('-I<W-E;&]G:6UI<V5L`$M+`$MI<FIA:V%S=`!!=')I8G5U9&ED.@!4Y&AI
M<W1A(&5R:6YE=F%D('1S:71E97)I;6ES=&%S96UE9"!E<FEN979A(';D<G9I
M9V$`4V]B:79A9"!VY&QJ860`3&EI:VUE9`!+:7)J82!K;V]S=&%M:6YE`$MI
M<FIA(&MU=7#D978`3W1S:2!K:7)J80!+:7)J82!S=75R=7,`2VER:F$@86QG
M=&5K<W0`2VER:F$@=F%A=&%M:6YE`$MI<FIA(&%T<FEB=75D:60`2V%U<W1A
M9`!+;W)R86=A(&[D:'1A=F%T92!K:7)J861E(&%R=B!L96AE:_QL:F5L+@!M
MY')G:71U9"!K:7)J860@:V%U<W1A.@!-=75D80!+;W)D(&MU=7,`5/5S=&$`
M3FEM:0!6]7)K`$UI='1E(&MU;F%G:0!5=7,`5N1R<VME('!O<W0`575E9"!K
M:7)J860`2N1R9VUI;F4`2N1R9VUI;F4@:VER:0!*Y')G;6EN92!L96AE:_QL
M9P!%:0#<:'1K:2!K875S=&$@96D@;>3D<F%T=60`2VER:F%V:6=U(&5I(&]L
M90!3;V]V:71U<VD@96D@;VQE`$5I('1A9V%S=&%T=60@:V]R<F5K='-E:60@
M6$U,(&%N9&UE:60`36ET=&4@;6ED86=I`$UI='1E(&MU<W1U=&%T=60`36ET
M=&4@;75S=&%N9`!-:71T92!TY&AT:7,`36ET=&4@:7-I:VQI:P!-:71T92!K
M=7-T=71A='5D(&MI<FIA9`!-:71T92!TY&AT<V%D(&MI<FIA9`!-Y')K;65D
M`%9A;F%D(&MI<FIA9`!686YA9"!S86%D971U9"!K:7)J861E(&MA=7-T860@
M=/QH:F5N9&%T86MS92X`2.3D;&5S='5S`$UU=2!I;F9O`$UU=60@<V5A9&5D
M`$QE:&5K_&QG("5D("5D+7-T`$]S82AD*0!386QA<_5N80!386QA<_5N860@
M<&5A=F%D(&ML87!P:6UA+@!+Y&EV:71A(&AO;VQD=7-T]O9D`$QO860`3'5B
M861E(&AA;&1U<P!)<VEK;&EK`$ES:6ML:6L@:6YF;P!496QE9F]N`%!A:6=U
M=&$@86QL:VER:2!E;FYE('9A<W1U<W0`4&%L=6X@<VES97-T82!U=64@:V%U
M<W1A(&YI;6DZ`%!A;'5N('-I<V5S=&$@=75S(&YI;6DZ`$MI<FIE;&1A('!R
M;V)L965M:2X`4VES97-T82!O;6$@:V%S=71A:F%N:6UI(&IA('-A;&%S]6YA
M`%!A;'5N('!A<F%N9&$@=FEG87-E9"!V]6D@;6ET;65TY&AE;F1U<VQI:W5D
M(&%A9')E<W-I9"X`16YN92!K=6D@;6ED86=I('1E960@=F%L:2!K875S="X`
M4&%L=6X@=F%L:2!O='-I;6ES96MS(';D:&5M86QT(/QK<R!K875S="X`4&%L
M=6X@=F%L:2!S96QL96MS(&]P97)A='-I;V]N:6MS(&%I;G5L="#\:W,@:V%U
M<W0N`$5E;&UI;F4@:VER:0!%96QM:6YE(&QE:&5K_&QG`%!R:6YD:0!0<F]B
M;&5E;6D@:VER:F5L9'5S`$MU<W1U=&$@;/5P;&EK=6QT`$MU:2!T:6AT:2!T
M_&AJ96YD861A('!R_&=I:V%U<W1A.@!,;V4`4W5U;F$@961A<VD`4W5U;F$@
M:VER:2!E9&%S:0!3=75N82!S964@:VER:2!E9&%S:0!%9&%S:7-U=6YA;6EN
M92!E8F'U;FYE<W1U<P!6Y')S:V5N9&$`5N1R<VME;F1A(&MA=7-T861E('-I
M<W4Z`%;D<G-K96YD82!V86%D90!096$@=FEI;6%N92!V86%D92!M965L97,`
M165M86QD80!%96UA;&1A('!A87(`(B5S(B#\;6)E<FYI;65T86UI;F4@(B5S
M(BUK<R!E8F'U;FYE<W1U<RX@4V5R=F5R(/QT;&5S`$%S96YD80!687-T80!6
M87-T82!K]6EG:6QE`%9A<W1A(&OU:6=I;&4Z`%9A<W1A.@!687-T83H`2W5R
M9&$@<N1M<'-P;W-T:2#\;&4`2N1T:V$`4.1R87-T(&MI<FIA(&MU<W1U=&%M
M:7-T+"#\;6)E<G3U<W1M:7-T(';U:2!K;W!E97)I;6ES="!P]O9R9'4@=&%G
M87-I('!O<W1K87-T:2!N:6UE:VER:F$`4V%L=F5S=&$@;75S=&%N9`!386QV
M97-T80!-=7-T86YD:2!S86QV97-T86UI;F4@96)A]6YN97-T=7,N(%-E<G9E
M<B#\=&QE<SH@)7,`3W1S:6YG`$]T<VEN9W4@='5L96UU<P!,;V5T=60`5F%L
M:0!-Y')G:2!K]6EK`,1R82!MY')G:2!M:61A9VD`5F%L:2!K=75PY&5V82!E
M<F%L9&%J83H`5F%L:2!K=75PY&5V82!F;W)M86%T.@!686QI(&ME;&QA86IA
M(&9O<FUA870Z`%9A;&D@:V%K<R!S;V)I=F%T(';D;&IA+@!686QI(';D<G9I
M<VME96TN`%9A;&D@;VUA(&QE;6UI:VME96PZ`%-A861A(&MI<FD`4V%A9&$@
M<')O8FQE96UI(&MI<FIE;&1U<P!386%D971U9"!K:7)J861E(&MA=7-T.@!-
MY.1R82!M:7,@:G5H='5B(&MU:2!S82!K:7)J=2!K=7-T=71A9"!J82#\;6)E
M<B!T]7-T860N`%-U;&4@:VER:F$@86ME;B!PY')A<W0@;75S=&%N9&D@<V%L
M=F5S=&%M:7-T`$[D:71A`$[D:71A(&MU<W1U=&%T=60`3N1I=&$@=&5L;&EM
M871A`%-U=7)U<P!*Y'1A(&AO;VQD=7,@=F%H96QE`$5R:6WD<FMI9&4@<VES
M97-T=7,`17)I;>1R9VED`-5I9V5K:7)J82!K;VYT<F]L;`#5:6=E:VER:F$@
M:V]N=')O;&QI:F$`U6EG96MI<FIA(&MO;G1R;VQL(&SU<&5T871U9`!+:7)J
M879I9V%D92!A<G8@96MR86%N:6PN`%1E96UA`%1E96UA(';D;&D`5&5L;&D@
M:V%U<W0H860I`%-O;W9I='5S960`5/;V9`!496MS=`!+Y&5S;VQE=B!K875S
M="`B)7,B(&YI;65T871A:W-E(/QM8F5R("(E<R(M:W,`2V%U<W0@(B5S(B!O
M;B!J=6)A(&]L96UA<P!+875S=&$@(B5S(B!N:6UE<R!O;B!L=6)A;6%T=6ED
M(&WD<FME+B!3964@=O5I8B!T96MI=&%D82!P<F]B;&5E;64N(%!E82!N]74@
M<_QS=&5E;6D@861M:6YI<W1R86%T;W)I9V$N`$MA=7-T("(E<R(@;&]O9&D@
M86=A('-A(&5I(&]L92!S961A('1E;&QI;G5D+@!+875S="`B)7,B(&MU<W1U
M=&%T:2!A9V$@<W5L(&]N('-E92!JY'1K=79A;'0@=&5L;&ET=60N`$MA=7-T
M82`B)7,B(&5I(&QO;V1U9"X@4V5R=F5R(/QT;&5S`$MA=7-T("(E<R(@;VX@
M961U:V%L="!L;V]D=60N`$MA=7-T("(E<R(@;VX@:N3D9&%V86QT(&MU<W1U
M=&%T=60N`$MA=7-T("(E<R(@;FEM971A=&D@_&UB97(@(B5S(BUK<P!!;&QK
M:7)I(&]N(&%S96YD871U9"X`4V5L;&5S(&MI<FIA:V%S=&ES(&5I(&]L92!K
M:7)J=2X`)7,@=/QH:F5N9&%M:7-E;"!T96MK:7,@=FEG82X@4V5R=F5R(/QT
M;&5S`$MI<FIA:V%S=&D@=/QH:F5N9&%M:7-E;"!T96MK:7,@=FEG82X@4V5R
M=F5R(/QT;&5S`$MI<FIA9&4@:W5S='5T86UI<V5L(&MA=7-T87-T("(E<R(@
M=&5K:VES('9I9V$N(%-E<G9E<B#\=&QE<P!+:7)J861E(&MU<W1U=&%M:7-E
M;"!K875S=&%S("(E<R(@=&5K:VES('9I9V$N(%-E<G9E<B#\=&QE<P!+:7)J
M82!O<V$@97-I=&%M:7-E;"!T96MK:7,@=FEG80!+:7)J861E(&WD<FMI;6ES
M96P@:V%U<W1A<R`B)7,B('1E:VMI<R!V:6=A+B!397)V97(@_'1L97,`2VER
M:F$@<V%A=&UI<V5L('1E:VMI<R!V:6=A.B`E<P!3964@=O5I8B!V]71T82!N
M871U:V4@865G82X@2V%S(&]L960@:VEN9&5L(&5T('-O;W9I9"!JY'1K871A
M/P!K:7)I(&MA=7-T80!3964@87)V('!E86(@;VQE;6$@=N1H96UA;'0@_&MS
M+@!396QL92!K;VAA('!E86P@<&5A8B!O;&5M82!A<G8N`$IU='5L]6YG82!V
M86%D90!096%L:VER:0!+96QL96QE`%!R_&=I:V%U<W0Z`$5I('-A82#\:&5N
M9'5S="!344P@<V5R=F5R:6=A+@!3961A(%=O<F1I(&1O:W5M96YT:2!O;B!V
M]6EM871U('3U;&=E;F1A9&$`5F%S=&%M871A`%9A<W1A;6%T82!K:7)J860`
M5&%A<W1A`$[D:'1A;6%T=60@861R97-S86%D:60`5/QH:7-T82!M=75T=7-E
M9`!.:6UE='4`3'5G96UA=&$`3&]O8G4@:V%U<W1A*&1E*2!T96QL:6UI<V5S
M=`!+87-U=&$@=F%I:V5VY.1R='5S=`!+87-U=&%J86AA;&1U<P!+87-U=&%J
M82!HY.1L97-T=7,`2V%S=71A:F%N:6UI`$MA<W5T86IA9"!S_'-T965M:7,Z
M`%9A871A("5S`%9A861E(';U:2!K:7)J86MA<W0@;6ED82!NY&ED871A('#D
M<F%S="!S:7-S96QO9VEM:7-T.@!+;W)D(&[D9&%L87,`5&5R92!T=6QE;6%S
M="`E<RUI`%1E<F4@='5L96UA<W0L("5S`%3V]FMO:&$@86%D<F5S<P!4]O9T
M96QE9F]N`$%!`$MO<F0@86%S=&%S`$IA:`!382!L;V]D(&%L86UK875S=&$@
M:V%U<W1A;&4@`%-A(&QO;V0@_&QE;6ES92!T87-E;64@:V%U<W1A(`!382!N
M:6UE=&%D(/QM8F5R(&MA=7-T83H@`%-U;&QE(&]N("5S('5U="!K:7)J82X`
M4W5L;&4@;VX@,2!U=7,@:VER:2X`4W5L;&4@;VX@=75S:2!K:7)J=2!K875S
M=&%S.@!3=6QL92!O;B!U=7-I(&MI<FIU(&KD<F=M:7-T97,@:V%U<W1A9&5S
M.@!%;FYE('-A871M:7-T(&]L96MS('1A<FL@<')O8FQE96UI(&MI<FIE;&1A
M9&$N`$OU:6=E<&5A;'0@<&5A9"!V86QI;6$@:V%U<W1A+@!+]6EG97!E86QT
M('!E860@=F%L:6UA(&%A9')E<W-I+@!+]6EG97!E86QT('!E860@=F%L:6UA
M(';D:&5M86QT(/QH92!K:7)J82X`2VER:F$@<V%A:F$@<&5A8B!O;&5M82!M
MY.1R871U9"X`4&5A9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&5E;6%L
M9&%D82X`4&5A9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&QI<V%D82X`
M4W5L(&5I(/5N;F5S='5N=60@=&5L;&ED82!K875S=&$@(B5S(BX@4V5R=F5R
M(/QT;&5S`%-U;"!E:2#U;FYE<W1U;G5D('3\:&ES=&%D82!K875S=&$@(B5S
M(B!T96QL:6UU<W0N(%-E<G9E<B#\=&QE<P!382!T96QL:7-I9"!K875S=&$@
M(B5S(BX`4V$@;&]O8G5S:60@:V%U<W1A("(E<R(@=&5L;&EM=7-E<W0N`%-I
M;G4@)7,@<V5S<VEO;VX@;VX@865G=6YU9"X@4&%L=6X@;&]G:2!U=65S=&D@
M<VES<V4N`%-I;G4@:6YF;P!3:6YU(&%U=&5N=&EM:7-S_'-T965M(&5I(';U
M:6UA;&1A(&MA<W5T86IA=&4@;FEM96MI<FIA(&[D:&$L(';U:2!O;B!S964@
M=O5I;6%L=7,@;6EN9VEL(&UU=6P@</5H:G5S96P@=N1L:F$@;/QL:71A='5D
M+@!3:6YU(&UU=61A='5S960@;VX@<V%L=F5S=&%T=60N`%-I;G4@86QL:VER
M:3H`6U1E96UA('!U=61U8ET`6TAO<F1E('!R;V)L965M70!;<FED82`E<R`E
M<RUS=%T`:V5L;&5L=`!%:2!M:61A9VDN+BX`=O5I`&MI<FIA=FEG80!K:7)J
M879E860`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+V5T7T5%+VAE;'`N>&UL
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3(V-3$V`#$P-#$W
M,S8R-S8S`#`R,3$Q-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z
M(&EM<"]L;V-A;&4O971?144O:&5L<"YX;6PL=B`Q+C$V+C8N-"`R,#`V+S`Q
M+S,P(#$U.C4X.C`Q(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED
M/2)C;VUP;W-E+6)U='1O;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!!8W1I;VYS/"]T:71L93X*("`@(#QH
M96%D:6YG/D%C=&EO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@
M365S<V%G92!L875N8VAE<R!Y;W5R(&5M86EL('1O('1H92!I;G1E;F1E9"!R
M96-I<&EE;G0H<RDN($)E('-U<F4@>6]U('=A;G0@=&\@<V5N9"!B969O<F4@
M8VQI8VMI;F<@:&5R92!A<R!O;F-E('-E;G0@:70@8V%N;F]T(&)E('1A:V5N
M(&)A8VLN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-A=F4@1')A9G0@
M<&QA8V5S(&%N('5N9FEN:7-H960@;65S<V%G92!I;B!A(&9O;&1E<B!C86QL
M960@)T1R869T<R<*86-C97-S:6)L92!B>2!T:&4@<&]P+61O=VX@8F]X(&]N
M('1H92!R:6=H="!S:61E(&]F('1H92!B;'5E(&YA=FEG871I;VX@8F%R(&%T
M('1O<"X@66]U(&-A;B!T:&5N(&9I;FES:"!T:&4@;65S<V%G92!L871E<B!B
M>2!S=VET8VAI;F<@=&\@=&AE("=$<F%F=',G(&9O;&1E<BP@8VQI8VMI;F<@
M;VX@=&AE('-A=F5D(&UE<W-A9V4@=&\@;W!E;B!I="P@86YD('1H96X@8VQI
M8VMI;F<@;VX@)U)E<W5M92<N($)E('-U<F4@=&\@<'5T(&$@<W5B:F5C="!O
M;B!T:&4@96UA:6P@8F5F;W)E('EO=2!S879E('1H92!D<F%F="!S;R!T:&%T
M('EO=2!C86X@96%S:6QY(&ED96YT:69Y('=H:6-H(&UE<W-A9V4@>6]U('=A
M;G0@=VET:&EN('1H92!$<F%F=',@9F]L9&5R+B!!9G1E<B!S879I;F<@87,@
M82!$<F%F="P@>6]U(&%R92!R971U<FYE9"!T;R!Y;W5R($E.0D]8(&]R('=H
M871E=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@($-A;F-E;"!-97-S86=E(&1R;W!S('1H92!M
M97-S86=E(&EN('!R;V=R97-S(&%N9"!S:6UP;'D@<F5T=7)N<R!Y;W4@=&\@
M=&AE($E.0D]8(&]R('=H871E=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG
M(&QA<W0N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+6)U='1O;G,B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^06-T:6]N
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5N9"!-97-S86=E(&QA=6YC
M:&5S('EO=7(@96UA:6P@=&\@=&AE(&EN=&5N9&5D(')E8VEP:65N="AS*2X@
M0F4@<W5R92!Y;W4@=V%N="!T;R!S96YD(&)E9F]R92!C;&EC:VEN9R!H97)E
M(&%S(&]N8V4@<V5N="!I="!C86YN;W0@8F4@=&%K96X@8F%C:RX*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@4V%V92!$<F%F="!P;&%C97,@86X@=6YF
M:6YI<VAE9"!M97-S86=E(&EN(&$@9F]L9&5R(&-A;&QE9"`G1')A9G1S)PIA
M8V-E<W-I8FQE(&)Y('1H92!P;W`M9&]W;B!B;W@@;VX@=&AE(')I9VAT('-I
M9&4@;V8@=&AE(&)L=64@;F%V:6=A=&EO;B!B87(@870@=&]P+B!9;W4@8V%N
M('1H96X@9FEN:7-H('1H92!M97-S86=E(&QA=&5R(&)Y('-W:71C:&EN9R!T
M;R!T:&4@)T1R869T<R<@9F]L9&5R+"!C;&EC:VEN9R!O;B!T:&4@<V%V960@
M;65S<V%G92!T;R!O<&5N(&ET+"!A;F0@=&AE;B!C;&EC:VEN9R!O;B`G4F5S
M=6UE)RX@0F4@<W5R92!T;R!P=70@82!S=6)J96-T(&]N('1H92!E;6%I;"!B
M969O<F4@>6]U('-A=F4@=&AE(&1R869T('-O('1H870@>6]U(&-A;B!E87-I
M;'D@:61E;G1I9GD@=VAI8V@@;65S<V%G92!Y;W4@=V%N="!W:71H:6X@=&AE
M($1R869T<R!F;VQD97(N($%F=&5R('-A=FEN9R!A<R!A($1R869T+"!Y;W4@
M87)E(')E='5R;F5D('1O('EO=7(@24Y"3U@@;W(@=VAA=&5V97(@9F]L9&5R
M('EO=2!W97)E('9I97=I;F<@;&%S="X*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@0V%N8V5L($UE<W-A9V4@9')O<',@=&AE(&UE<W-A9V4@:6X@<')O
M9W)E<W,@86YD('-I;7!L>2!R971U<FYS('EO=2!T;R!T:&4@24Y"3U@@;W(@
M=VAA=&5V97(@9F]L9&5R('EO=2!W97)E('9I97=I;F<@;&%S="X*("`@(#PO
M<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UF<F]M(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!#
M;VUP;W-I=&EO;CH@1G)O;3PO=&ET;&4^"B`@("`\:&5A9&EN9SXB1G)O;2(\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('EO=7(@8V]R<F5C="!E
M;6%I;"!A9&1R97-S+B!9;W5R(&5M86EL(&%D9')E<W,@:7,@875T;VUA=&EC
M86QL>2!E;G1E<F5D(&9O<B!Y;W4@9F]L;&]W:6YG(")&<F]M.B(@:6X@;W5T
M9V]I;F<@96UA:6PN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*
M/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($9R;VT\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[
M1G)O;29Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@>6]U
M<B!C;W)R96-T(&5M86EL(&%D9')E<W,N(%EO=7(@96UA:6P@861D<F5S<R!I
M<R!A=71O;6%T:6-A;&QY(&5N=&5R960@9F]R('EO=2!F;VQL;W=I;F<@)G%U
M;W0[1G)O;3HF<75O=#L@:6X@;W5T9V]I;F<@96UA:6PN"B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M=&\B
M('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET
M:6]N.B!4;SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB5&\B/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S
M*&5S*2!O9B!T:&]S92!T;R!R96-E:79E('EO=7(@;65S<V%G92X@66]U(&UU
M<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@
M<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT
M<GD@9F]L;&]W<R`B5&\Z(B!I;B!O=71G;VEN9R!M86EL+B`@"B`@("`\+W!A
M<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+71O
M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!4;SPO=&ET;&4^
M"B`@("`\:&5A9&EN9SXF<75O=#M4;R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@
M;V8@=&AO<V4@=&\@<F5C96EV92!Y;W5R(&UE<W-A9V4N(%EO=2!M=7-T('-E
M<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R('!U;F-T
M=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N=')Y(&9O
M;&QO=W,@)G%U;W0[5&\Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN("`*("`@
M(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M
M<&]S92UC8R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($-C/"]T:71L93X*("`@(#QH96%D:6YG/B)#8R(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL
M(&%D9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@82!C87)B;VX@8V]P
M>2!O9B!Y;W5R(&UE<W-A9V4N(%-E<&%R871E(&5A8V@@861D<F5S<R!W:71H
M(&$@8V]M;6$N(%EO=7(@96YT<GD@9F]L;&]W<R`B0V,Z(B!I;B!O=71G;VEN
M9R!M86EL+B!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O
M<&QE(&]T:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET=&5N('1O(&1I
M<F5C=&QY(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@;V8@=&AE(&5M
M86EL(&%S('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C=&QY(&-O;F-E
M<FYE9"!A8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN("!!;&P@)U1O
M.B<@<F5C:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C86X@<V5E('1H
M92!E;G1I<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP:65N=',N"B`@
M("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP
M;W-E+6-C(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!#8SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M#8R9Q=6]T.SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S
M<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&-A<F)O;B!C;W!Y(&]F('EO
M=7(@;65S<V%G92X@4V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM
M82X@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T-C.B9Q=6]T.R!I;B!O=71G
M;VEN9R!M86EL+B!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@=&\@
M<&5O<&QE(&]T:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET=&5N('1O
M(&1I<F5C=&QY(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@;V8@=&AE
M(&5M86EL(&%S('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C=&QY(&-O
M;F-E<FYE9"!A8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN("!!;&P@
M)U1O.B<@<F5C:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C86X@<V5E
M('1H92!E;G1I<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP:65N=',N
M"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60]
M(F-O;7!O<V4M8F-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S
M<V%G92!#;VUP;W-I=&EO;CH@0F-C/"]T:71L93X*("`@(#QH96%D:6YG/B)"
M8V,B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C
M="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@8FQI
M;F0@8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E+B!9;W4@;75S="!S97!A
M<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A
M=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL
M;W=S(")"8V,Z(B!I;B!O=71G;VEN9R!M86EL+B!";&EN9"!C87)B;VX@8V]P
M:65S(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O<&QE(&]T:&5R('1H86X@9&ER
M96-T(&%N9"!I;F1I<F5C="!R96-I<&EE;G1S("@B5&\Z(B!A;F0@(D-C.B(@
M<F5C:7!I96YT<RD@=VAO(&YE960@=&\@<F5A9"!W:&%T(&ES(&)E:6YG('=R
M:71T96X@87,@=V5L;"!7251(3U54('1H92!O=&AE<B!R96-I<&EE;G1S(&MN
M;W=I;F<@=&AA="!T:&5Y(&%R92!R96-E:79I;F<@=&AE(&5M86EL+B!4:'5S
M("=B;&EN9"<@;65A;G,@=&AA="!T:&4@:61E;G1I='D@;V8@=&AE<V4@<F5C
M:7!I96YT<R!I<R!H:61D96X@9G)O;2!A;&P@;W1H97(@<F5C:7!I96YT<R!O
M9B!T:&4@96UA:6PL(&%N9"!O;FQY('EO=2!A;F0@=&AE>2!K;F]W('1H97D@
M9V]T(&$@8V]P>2X@66]U('1Y<&EC86QL>2!U<V4@=&AI<R!T;R!T96QL(&%N
M(&%U=&AO<FET>2!F:6=U<F4@=&AA="!Y;W4@87)E('1E;&QI;F<@<V]M96]N
M92!S;VUE=&AI;F<@=VET:&]U="!A;&%R;6EN9R!T:&4@<&5R<V]N('EO=2!A
M<F4@<V5N9&EN9R!T:&4@86-T=6%L(&5M86EL('1O+@H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UB8V,B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($)C8SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SXF<75O=#M"8V,F<75O=#L\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F
M('1H;W-E('1O(')E8V5I=F4@82!B;&EN9"!C87)B;VX@8V]P>2!O9B!Y;W5R
M(&UE<W-A9V4N(%EO=2!M=7-T('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H
M(&$@8V]M;6$[(&]T:&5R('!U;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N
M(&5R<F]R+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[0F-C.B9Q=6]T.R!I
M;B!O=71G;VEN9R!M86EL+B!";&EN9"!C87)B;VX@8V]P:65S(&%R92!U<W5A
M;&QY('-E;G0@=&\@<&5O<&QE(&]T:&5R('1H86X@9&ER96-T(&%N9"!I;F1I
M<F5C="!R96-I<&EE;G1S("@F<75O=#M4;SHF<75O=#L@86YD("9Q=6]T.T-C
M.B9Q=6]T.R!R96-I<&EE;G1S*2!W:&\@;F5E9"!T;R!R96%D('=H870@:7,@
M8F5I;F<@=W)I='1E;B!A<R!W96QL(%=)5$A/550@=&AE(&]T:&5R(')E8VEP
M:65N=',@:VYO=VEN9R!T:&%T('1H97D@87)E(')E8V5I=FEN9R!T:&4@96UA
M:6PN(%1H=7,@)V)L:6YD)R!M96%N<R!T:&%T('1H92!I9&5N=&ET>2!O9B!T
M:&5S92!R96-I<&EE;G1S(&ES(&AI9&1E;B!F<F]M(&%L;"!O=&AE<B!R96-I
M<&EE;G1S(&]F('1H92!E;6%I;"P@86YD(&]N;'D@>6]U(&%N9"!T:&5Y(&MN
M;W<@=&AE>2!G;W0@82!C;W!Y+B!9;W4@='EP:6-A;&QY('5S92!T:&ES('1O
M('1E;&P@86X@875T:&]R:71Y(&9I9W5R92!T:&%T('EO=2!A<F4@=&5L;&EN
M9R!S;VUE;VYE('-O;65T:&EN9R!W:71H;W5T(&%L87)M:6YG('1H92!P97)S
M;VX@>6]U(&%R92!S96YD:6YG('1H92!A8W1U86P@96UA:6P@=&\N"B`@("`\
M+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O
M<V4M<W5B:F5C="(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A
M9V4@0V]M<&]S:71I;VXZ(%-U8FIE8W0\+W1I=&QE/@H@("`@/&AE861I;F<^
M(E-U8FIE8W0B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@
M<W5B:F5C="!O9B!Y;W5R(&UE<W-A9V4N(%EO=7(@96YT<GD@9F]L;&]W<R`B
M4W5B:F5C=#HB(&EN(&]U=&=O:6YG(&UA:6PN($ME97`@:70@<VAO<G0L('-I
M;7!L92!A;F0@9&5S8W)I<'1I=F4N("!4:&4@<W5B:F5C="!L:6YE(&ES('1H
M92!E87-I97-T('=A>2!F;W(@>6]U(&%N9"!Y;W5R(&-O<G)E<W!O;F1E;G1S
M('1O(')E;65M8F5R('=H870@=V%S(&EN('1H92!E;6%I;"!A;F0@=&AU<R!I
M<R!V97)Y(&EM<&]R=&%N="!I;B!O<F=A;FEZ:6YG('EO=7(@96UA:6P@86YD
M(&9I;F1I;F<@:6UP;W)T86YT(&]N97,@;&%T97(N("!!;'-O+"!W:&5N('EO
M=2`G4F5P;'DG(&]R("=&;W)W87)D)R!A;F0@96UA:6P@=&AI<R!S=6)J96-T
M(&QI;F4@:7,@8V]P:65D(&]V97(@:6YT;R!T:&4@;F5W(&UE<W-A9V4@86YD
M('-O(&ES(&$@=F%L=6%B;&4@=V%Y(&]F('1E;&QI;F<@=VAA="!M97-S86=E
M<R!G;R!T;V=E=&AE<B!T;R!F;W)M(&$@(G1H<F5A9"(@;V8@82!C;VYV97)S
M871I;VXN("!(;W=E=F5R+"!I9B!T:&4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@
M8V]N=&%I;G,@;F5W(&ED96%S+"!Y;W4@;6%Y('=A;G0@=&\@861D('-I;7!L
M92!M;V1I9FEC871I;VYS('1O('1H92`G4W5B:F5C="<@;&EN92!S;R!T:&4@
M<F5C:7!I96YT*',I(&-A;B!F;VQL;W<@=&AE('!R;V=R97-S:6]N(&]F('1H
M92`B=&AR96%D+B(*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\
M96YT<GD@:60](F-O;7!O<V4M<W5B:F5C="(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@4W5B:F5C=#PO=&ET;&4^"B`@("`\:&5A9&EN9SXF
M<75O=#M3=6)J96-T)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%
M;G1E<B!T:&4@<W5B:F5C="!O9B!Y;W5R(&UE<W-A9V4N(%EO=7(@96YT<GD@
M9F]L;&]W<R`F<75O=#M3=6)J96-T.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL
M+B!+965P(&ET('-H;W)T+"!S:6UP;&4@86YD(&1E<V-R:7!T:79E+B`@5&AE
M('-U8FIE8W0@;&EN92!I<R!T:&4@96%S:65S="!W87D@9F]R('EO=2!A;F0@
M>6]U<B!C;W)R97-P;VYD96YT<R!T;R!R96UE;6)E<B!W:&%T('=A<R!I;B!T
M:&4@96UA:6P@86YD('1H=7,@:7,@=F5R>2!I;7!O<G1A;G0@:6X@;W)G86YI
M>FEN9R!Y;W5R(&5M86EL(&%N9"!F:6YD:6YG(&EM<&]R=&%N="!O;F5S(&QA
M=&5R+B`@06QS;RP@=VAE;B!Y;W4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@86YD
M(&5M86EL('1H:7,@<W5B:F5C="!L:6YE(&ES(&-O<&EE9"!O=F5R(&EN=&\@
M=&AE(&YE=R!M97-S86=E(&%N9"!S;R!I<R!A('9A;'5A8FQE('=A>2!O9B!T
M96QL:6YG('=H870@;65S<V%G97,@9V\@=&]G971H97(@=&\@9F]R;2!A("9Q
M=6]T.W1H<F5A9"9Q=6]T.R!O9B!A(&-O;G9E<G-A=&EO;BX@($AO=V5V97(L
M(&EF('1H92`G4F5P;'DG(&]R("=&;W)W87)D)R!C;VYT86EN<R!N97<@:61E
M87,L('EO=2!M87D@=V%N="!T;R!A9&0@<VEM<&QE(&UO9&EF:6-A=&EO;G,@
M=&\@=&AE("=3=6)J96-T)R!L:6YE('-O('1H92!R96-I<&EE;G0H<RD@8V%N
M(&9O;&QO=R!T:&4@<')O9W)E<W-I;VX@;V8@=&AE("9Q=6]T.W1H<F5A9"XF
M<75O=#L*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UO<'1I;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\
M=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@3W!T:6]N<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SXB3W!T:6]N<R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1H97-E($]P=&EO;G,@:&5L<"!Y;W4@<')E<&%R92!Y;W5R(&UE<W-A9V4N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-L:6-K(")3<&5L;"!#:&5C
M:R(@=&\@8VAE8VL@>6]U<B!S<&5L;&EN9RX*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@0VQI8VL@(D%T=&%C:&UE;G1S(B!T;R!V:65W(&%T('1H92!B
M;W1T;VT@;V8@=&AE('!A9V4@82!L:7-T(&]F(&9I;&5S(&%T=&%C:&5D('1O
M('1H:7,@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@06-T
M:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O(")3879E(&-O<'DB('1O
M('-A=F4@82!C;W!Y(&]F('1H:7,@;65S<V%G92!I;B!Y;W5R(")396YT($UA
M:6PB(&9O;&1E<BX@4V%V92!C;W!I97,@;V8@:6UP;W)T86YT(&5M86EL<R!Y
M;W4@<V5N9"!S;R!T:&%T('EO=2!H879E('-O;65T:&EN9R!T;R!R969E<B!B
M86-K('1O(&QA=&5R(&%N9"!T;R!K965P(&%N(&%C8W5R871E(')E8V]R9"!O
M9B!W:&%T('=A<R!S86ED+B!792!D;R!N;W0@<F5C;VUM96YD('EO=2!S879E
M(&5V97)Y(&5M86EL('-I;F-E('1H96X@>6]U<B!D:7-K('-T;W)A9V4@<75O
M=&$@=VEL;"!B92!U<V5D('5P('%U:6-K;'D@*&5S<&5C:6%L;'D@=VAE;B!Y
M;W4@<V5N9"!A='1A8VAM96YT<RD@86YD('EO=7(@;6%I;&)O>"!W:6QL(&)E
M(&9U;&P@86YD('5N86)L92!T;R!R96-E:79E(&YE=R!I;F-O;6EN9R!E;6%I
M;"X@66]U(&-A;BP@:&]W979E<BP@='5R;B!T:&ES(&9E871U<F4@)V]N)R!A
M<R!Y;W5R(&1E9F%U;'0@=VET:&EN('EO=7(@261E;G1I='DL(&)Y(&=O:6YG
M('1O($]P=&EO;G,M)F=T.U!E<G-O;F%L($EN9F]R;6%T:6]N+29G=#M%9&ET
M('EO=7(@:61E;G1I=&EE<RX@0F4@8V%R969U;"!W:&5N('5S:6YG('1H:7,@
M;6]D:69I960@9&5F875L="!A<R!Y;W4@=VEL;"!N965D('1O('!E<FEO9&EC
M86QL>2!P=7)G92!Y;W5R(")396YT($UA:6PB(&9O;&1E<B!O<B!I="!W:6QL
M(&5V96YT=6%L;'D@;6%K92!Y;W5R(&UA:6QB;W@@9G5L;"!A;F0@=6YU<V5A
M8FQE+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I
M9#TB8V]M<&]S92UO<'1I;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T]P
M=&EO;G,F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H97-E($]P
M=&EO;G,@:&5L<"!Y;W4@<')E<&%R92!Y;W5R(&UE<W-A9V4N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@($-L:6-K("9Q=6]T.U-P96QL($-H96-K)G%U
M;W0[('1O(&-H96-K('EO=7(@<W!E;&QI;F<N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@($-L:6-K("9Q=6]T.T%T=&%C:&UE;G1S)G%U;W0[('1O('9I
M97<@870@=&AE(&)O='1O;2!O9B!T:&4@<&%G92!A(&QI<W0@;V8@9FEL97,@
M871T86-H960@=&\@=&AI<R!M97-S86=E+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@)G%U
M;W0[4V%V92!C;W!Y)G%U;W0[('1O('-A=F4@82!C;W!Y(&]F('1H:7,@;65S
M<V%G92!I;B!Y;W5R("9Q=6]T.U-E;G0@36%I;"9Q=6]T.R!F;VQD97(N(%-A
M=F4@8V]P:65S(&]F(&EM<&]R=&%N="!E;6%I;',@>6]U('-E;F0@<V\@=&AA
M="!Y;W4@:&%V92!S;VUE=&AI;F<@=&\@<F5F97(@8F%C:R!T;R!L871E<B!A
M;F0@=&\@:V5E<"!A;B!A8V-U<F%T92!R96-O<F0@;V8@=VAA="!W87,@<V%I
M9"X@5V4@9&\@;F]T(')E8V]M;65N9"!Y;W4@<V%V92!E=F5R>2!E;6%I;"!S
M:6YC92!T:&5N('EO=7(@9&ES:R!S=&]R86=E('%U;W1A('=I;&P@8F4@=7-E
M9"!U<"!Q=6EC:VQY("AE<W!E8VEA;&QY('=H96X@>6]U('-E;F0@871T86-H
M;65N=',I(&%N9"!Y;W5R(&UA:6QB;W@@=VEL;"!B92!F=6QL(&%N9"!U;F%B
M;&4@=&\@<F5C96EV92!N97<@:6YC;VUI;F<@96UA:6PN(%EO=2!C86XL(&AO
M=V5V97(L('1U<FX@=&AI<R!F96%T=7)E("=O;B<@87,@>6]U<B!D969A=6QT
M('=I=&AI;B!Y;W5R($ED96YT:71Y+"!B>2!G;VEN9R!T;R!/<'1I;VYS+29G
M=#M097)S;VYA;"!);F9O<FUA=&EO;BTF9W0[161I="!Y;W5R(&ED96YT:71I
M97,N($)E(&-A<F5F=6P@=VAE;B!U<VEN9R!T:&ES(&UO9&EF:65D(&1E9F%U
M;'0@87,@>6]U('=I;&P@;F5E9"!T;R!P97)I;V1I8V%L;'D@<'5R9V4@>6]U
M<B`F<75O=#M396YT($UA:6PF<75O=#L@9F]L9&5R(&]R(&ET('=I;&P@979E
M;G1U86QL>2!M86ME('EO=7(@;6%I;&)O>"!F=6QL(&%N9"!U;G5S96%B;&4N
M"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60]
M(F-O;7!O<V4M871T86-H(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H/"]T:71L93X*("`@(#QH96%D
M:6YG/B)!='1A8V@B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@("`@66]U
M(&UA>2!A='1A8V@@9FEL97,@=&\@>6]U<B!M97-S86=E+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^4W1E<"`Q.B!%:71H97(L('1Y<&4@=&AE('!A=&@@86YD
M(&YA;64@;V8@82!F:6QE('1H870@>6]U('=A;G0@871T86-H960@=&\@=&AI
M<R!M97-S86=E(&]R(&-L:6-K(")"<F]W<V4B(&)U='1O;B!A;F0@<V5L96-T
M('1H92!F:6QE('1O(&)E(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD(&YA;64@
M;V8@=&AA="!F:6QE(&YO=R!A<'!E87)S(&EN('1H92!!='1A8VAM96YT(&)O
M>"X@3F]W('!R;V-E960@=&\*4W1E<"`R+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^4W1E<"`R.B!#;&EC:R`B071T86-H(B!B=71T;VXN(%1H92!F:6QE(&YA
M;64@86YD('-I>F4@=VEL;"!B92!A9&1E9"!T;R!Y;W5R(&QI<W0@;V8@071T
M86-H;65N=',N(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S(&%N
M9"]O<B!S;&]W97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C97-S
M(&]F('5P;&]A9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T:&4@
M96UA:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@86YD
M(&1O(&YO="!C;&EC:R!O;B!O=&AE<B!T:&EN9W,@=VAI;&4@>6]U(&%R92!W
M86ET:6YG+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB8V]M<&]S92UA='1A8V@B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M!
M='1A8V@F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=2!M87D@
M871T86-H(&9I;&5S('1O('EO=7(@;65S<V%G93L@;VYL>2!O;F4@9FEL92!M
M87D@8F4@871T86-H960@870@82!T:6UE+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^4W1E<"`Q.B!%:71H97(L('1Y<&4@=&AE('!A=&@@86YD(&YA;64@;V8@
M82!F:6QE('1H870@>6]U('=A;G0@871T86-H960@=&\@=&AI<R!M97-S86=E
M(&]R(&-L:6-K("9Q=6]T.T)R;W=S929Q=6]T.R!B=71T;VX@86YD('-E;&5C
M="!T:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N86UE
M(&]F('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N="!B
M;W@N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($1E8VED92!W:&5T
M:&5R('EO=2!W86YT('1H92!F:6QE('1O(&)E('9I97=E9"!A<R!A;B!A='1A
M8VAM96YT(&]R(&EN;&EN960@=VET:"!T:&4@<F5S="!O9B!T:&4@;65S<V%G
M92X@5&AE(')E8V5I=FEN9R!P97)S;VXH<RD@;6%I;"!R96%D:6YG('-O9G1W
M87)E(&UU<W0@8F4@86)L92!T;R!H86YD;&4@=&AE(&9I;&4@='EP92!I;FQI
M;F4[(&EF(&YO="P@=&AI<R!P87)T('=I;&P@8F4@=FEE=V5D(&%S(&%N(&%T
M=&%C:&UE;G0@:6YS=&5A9"X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@
M,SH@0VQI8VL@)G%U;W0[071T86-H)G%U;W0[(&)U='1O;BX@5&AE(&9I;&4@
M;F%M92!A;F0@<VEZ92!W:6QL(&)E(&%D9&5D('1O('EO=7(@;&ES="!O9B!!
M='1A8VAM96YT<RX@4&QE87-E(&YO=&4@=&AA="!F;W(@;&%R9V4@9FEL97,@
M86YD+V]R('-L;W=E<B!);G1E<FYE="!C;VYN96-T:6]N<RP@=&AE('!R;V-E
M<W,@;V8@=7!L;V%D:6YG(&%N9"!A='1A8VAI;F<@>6]U<B!F:6QE('1O('1H
M92!E;6%I;"!M87D@=&%K92!A('=H:6QE+B!0;&5A<V4@8F4@<&%T:65N="!A
M;F0@9&\@;F]T(&-L:6-K(&]T:&5R('1H:6YG<R!W:&EL92!Y;W4@87)E('=A
M:71I;F<N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT
M<GD@:60](F-O;7!O<V4M871T86-H;65N=',B('-T871E/2)U;FMN;W=N(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8VAM96YT<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SXB071T86-H;65N=',B/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!4:&ES('-E8W1I;VX@9&ES<&QA>7,@82!L:7-T(&]F
M(&9I;&5S(&%L<F5A9'D@871T86-H960@=&\@>6]U<B!M97-S86=E+B!4;R!$
M96QE=&4@86X@871T86-H960@9FEL93H*("`@(#PO<&%R83X*("`@(#QP87)A
M/E-T97`@,3H@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O('1H
M92!A='1A8VAE9"!F:6QE;F%M92!Y;W4@=V%N="!T;R!$96QE=&4N"B`@("`\
M+W!A<F$^(`H@("`@/'!A<F$^4W1E<"`R.B!#;&EC:R`B1&5L971E($%T=&%C
M:&UE;G0H<RDB+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(^"B`@("`\=&ET;&4^365S
M<V%G92!#;VUP;W-I=&EO;CH@071T86-H;65N=',\+W1I=&QE/@H@("`@/&AE
M861I;F<^)G%U;W0[071T86-H;65N=',F<75O=#L\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H:7,@<V5C=&EO;B!D:7-P;&%Y<R!A(&QI<W0@;V8@9FEL
M97,@86QR96%D>2!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V4N(%1O($1E;&5T
M92!A;B!A='1A8VAE9"!F:6QE.@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E
M<"`Q.B!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@=&AE(&%T
M=&%C:&5D(&9I;&5N86UE('EO=2!W86YT('1O($1E;&5T92X*("`@(#PO<&%R
M83X@"B`@("`\<&%R83Y3=&5P(#(Z($-L:6-K("9Q=6]T.T1E;&5T92!!='1A
M8VAM96YT*',I)G%U;W0[+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7!R:6]R:71Y(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!0<FEO<FET>3PO
M=&ET;&4^"B`@("`\:&5A9&EN9SXB4')I;W)I='DB/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!4:&ES('-E=',@=&AE(")8+5!R:6]R:71Y(B!H96%D97(@
M;VX@>6]U<B!O=71G;VEN9R!M97-S86=E+B!4:&4@(E@M4')I;W)I='DB('1A
M9R!I<R!A('-O<G0@;V8@(G!S975D;R!S=&%N9&%R9"(@=&AA="!.971S8V%P
M92P@36]Z:6QL82P@3W!E<F$L(&%N9"!/=71L;V]K(&UA:6P@8VQI96YT<R!A
M<'!E87(@=&\@86=R964@;VXN($%N>2!M86EL(&-L:65N=',@=&AA="!D;R!N
M;W0@:&%N9&QE('1H:7,@:&5A9&5R('=I;&P@<VEM<&QY(&EG;F]R92!I="X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<V%V
M92UA='1A8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@4V%V92!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\
M<&%R83X*("`@($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@
M:6X@>6]U<B!C;VUP;W-I=&EO;B!A<F4@<V%V960@=VET:"!T:&4@;65S<V%G
M92!W:&5N('-T;W)E9"!I;B!T:&4@<V5N="UM86EL(&9O;&1E<BX@($EF(")9
M97,B+"!T:&4@871T86-H;65N="!D871A('=I;&P@8F4@<V%V960N("!)9B`B
M3F\B+"!T:&4@871T86-H;65N="!D871A('=I;&P@8F4@<W1R:7!P960@9G)O
M;2!T:&4@;65S<V%G92!A9G1E<B!I="!I<R!S96YT('1O(&%L;"!R96-I<&EE
M;G1S+B`@0VAO;W-I;F<@(DYO(B!W:6QL(&AE;'`@8V]N<V5R=F4@9&ES:R!S
M<&%C92!B>2!R96UO=FEN9R`H<&]T96YT:6%L;'D@;&%R9V4I(&%T=&%C:&UE
M;G0@:6YF;W)M871I;VX@9G)O;2!T:&4@<V%V960@;65S<V%G97,N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6QI;FLM871T
M86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ($QI;FL@071T86-H;65N=',\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!$971E<FUI;F5S('=H971H97(@=&AE(&%T=&%C:&UE;G1S(&EN('EO
M=7(@8V]M<&]S:71I;VX@87)E('-E;G0@87,@82!P87)T(&]F('1H92!M86EL
M(&UE<W-A9V4@;W(@=VAE=&AE<B!T:&]S92!A='1A8VAM96YT<R!A<F4@:V5P
M="!O;B!A(&QO8V%L('-E<G9E<BX@($EF(&%T=&%C:&UE;G1S(&%R92!L:6YK
M960L('1H92!R96-I<&EE;G0H<RD@;V8@>6]U<B!M97-S86=E('=I;&P@8F4@
M<')O=FED960@82!W96)L:6YK('=H97)E('1H97D@8V%N(&1O=VYL;V%D('1H
M92!A='1A8VAM96YT*',I+B`@3&EN:VEN9R!A='1A8VAM96YT<R!H87,@=&AE
M(&%D=F%N=&%G92!O9B!T<F5M96YD;W5S;'D@<F5D=6-I;F<@=&AE('-I>F4@
M;V8@;W5T9V]I;F<@;65S<V%G97,N("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA
M<R!T:&4@9&ES861V86YT86=E('1H870@=&AE(&-O;G1E;G0@;V8@=&AE(&%T
M=&%C:&UE;G1S(&-A;B!N;W0@8F4@9W5A<F%N=&5E9"!T;R!B92!A=F%I;&%B
M;&4@:6X@=&AE(&9U='5R92!S:6YC92!T:&4@871T86-H;65N="!D871A(&ES
M(&YO="!L;V-A=&5D('=I=&AI;B!T:&4@92UM86EL(&UE<W-A9V4N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S96%R8V@B('-T871E/2)U
M;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E(%-E87)C:#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY396%R8V@@0W)I=&5R:6$\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@("`@("!(96QP('1E>'0@=&\@8F4@=W)I='1E;BX*("`@(#PO<&%R
M83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G-E87)C:"(^"B`@
M("`\=&ET;&4^365S<V%G92!396%R8V@\+W1I=&QE/@H@("`@/&AE861I;F<^
M4V5A<F-H($-R:71E<FEA/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W4@
M;6%Y('-E87)C:"!F;W(@;65S<V%G97,@9G)O;2!Y;W5R(&9O;&1E<G,@=7-I
M;F<@9&EF9F5R96YT('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*("`@
M(#QP87)A/E-T97`@,3H@16YT97(@=&5X="!T;R!T:&4@9FEE;&1S('EO=2!W
M86YT('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@,CH@0VAO;W-E('1H92!M97-S86=E(&9L86<H
M<RD@=&\@861D('1O('EO=7(@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^4W1E<"`S.B!#:&]O<V4@=&AE(&9O;&1E<BAS*2!F<F]M
M('=H:6-H('1O('-E87)C:"!F;W(@=&AE(&UE<W-A9V5S+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^4W1E<"`T.B!#;&EC:R`F<75O=#M396%R8V@F<75O=#LN
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($EF(&%N>2!M97-S86=E<R!M
M871C:&5D('EO=7(@<V5A<F-H(&-R:71E<FEA+"!T:&5N('1H92!S=6)J96-T
M<R!O9B!T:&5S92!M97-S86=E<R!W:6QL(&)E('-H;W=N(&EN('1H92`F<75O
M=#M396%R8V@@4F5S=6QT<R9Q=6]T.R!V:65W+@H@("`@/"]P87)A/@H\+V5N
M=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(@
M<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M96YT
M/"]T:71L93X*("`@(#QH96%D:6YG/D9O;&1E<B!/<'1I;VYS/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("`@(%EO=2!C86X@<V5L96-T(&$@9F]L9&5R(&)Y
M('5S:6YG('1H92!R861I;R!B=71T;VYS(&%L;VYG('1H92!L969T(&-O;'5M
M;BX@($]N8V4@>6]U(&AA=F4@9&]N92!T:&ES+"!S96QE8W0@=&AE(&]P=&EO
M;B!Y;W4@=VES:"!T;R!P97)F;W)M(&]N('1H92!F;VQD97(@=FEA('1H92!S
M96QE8W0@8F]X('1O('1H92!L969T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("`@(%EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!F=7)T:&5R(&]P=&EO
M;G,N("!"92!C87)E9G5L('=I=&@@=&AE(&1E;&5T92!O<'1I;VXL(&%S('EO
M=2!C86X@;&]S92!A;&P@=&AE(&UE<W-A9V5S(&EN(&$@9F]L9&5R(&EF('EO
M=2!D96QE=&4@:70@8GD@;6ES=&%K92$*("`@(#PO<&%R83X*/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](F9O;&1E<BUO<'1I;VYS(CX*("`@(#QT
M:71L93Y&;VQD97(@36%N86=E;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY&
M;VQD97(@3W!T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!9;W4@
M8V%N('-E;&5C="!A(&9O;&1E<B!B>2!U<VEN9R!T:&4@<F%D:6\@8G5T=&]N
M<R!A;&]N9R!T:&4@;&5F="!C;VQU;6XN("!/;F-E('EO=2!H879E(&1O;F4@
M=&AI<RP@<V5L96-T('1H92!O<'1I;VX@>6]U('=I<V@@=&\@<&5R9F]R;2!O
M;B!T:&4@9F]L9&5R('9I82!T:&4@<V5L96-T(&)O>"!T;R!T:&4@;&5F="X*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("!9;W4@=VEL;"!B92!P<F]M
M<'1E9"!F;W(@9G5R=&AE<B!O<'1I;VYS+B`@0F4@8V%R969U;"!W:71H('1H
M92!D96QE=&4@;W!T:6]N+"!A<R!Y;W4@8V%N(&QO<V4@86QL('1H92!M97-S
M86=E<R!I;B!A(&9O;&1E<B!I9B!Y;W4@9&5L971E(&ET(&)Y(&UI<W1A:V4A
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY);7!O<G0@;6)O>"!&:6QE/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%1H:7,@;W!T:6]N('=I;&P@:6UP
M;W)T(&$@;6)O>"!F;W)M870@9FEL92!I;G1O('1H92!F;VQD97(@;V8@>6]U
M<B!C:&]I8V4N($-H;V]S92`Q("AO;F4I(&9O;&1E<B!T;R!I;7!O<G0@=&AE
M(&UE<W-A9V5S(&EN=&\@86YD('1H96X@<V5L96-T('1H:7,@;W!T:6]N+B!9
M;W4@=VEL;"!T:&5N(&)E('1A:V5N('1O(&$@<&%G92!T:&%T('=I;&P@<')O
M;7!T(&9O<B!T:&4@;6)O>"!F:6QE('1O(&EM<&]R="X*("`@(#PO<&%R83X*
M/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]L9&5R+7=I9&=E
M=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M96YT
M.B!$:7-P;&%Y/"]T:71L93X*("`@(#QH96%D:6YG/E-H;W<O2&ED92!5;G-U
M8G-C<FEB960\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('5S:6YG($E-
M05`@9F]L9&5R('-U8G-C<FEP=&EO;G,L('-H;W<O:&ED92!T:&4@=6YS=6)S
M8W)I8F5D(&9O;&1E<G,N("!4;R!S=6)S8W)I8F4O=6YS=6)S8W)I8F4@=&\@
M82!F;VQD97(L('-E;&5C="!T:&4@8VAE8VMB;W@@;F5X="!T;R!T:&4@9F]L
M9&5R;F%M92!A;F0@=7-E('1H92!3=6)S8W)I8F4O56YS=6)S8W)I8F4@;W!T
M:6]N(&EN('1H92!&;VQD97(@06-T:6]N(&1R;W`M9&]W;B!M96YU+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^17AP86YD($%L;#PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@17AP86YD(&%L;"!F;VQD97(@96YT<FEE<RX*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D-O;&QA<'-E($%L;#PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@0V]L;&%P<V4@86QL(&9O;&1E<B!E;G1R:65S+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R<R(@<W1A=&4]
M(G5N:VYO=VXB/@H@("`@/'1I=&QE/D9I;'1E<G,Z($%P<&QY/"]T:71L93X*
M("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@0VQI8VL@;VX@=&AE(")!<'!L>2!&:6QT97(B(&EC;VX@
M;F5X="!T;R!T:&4@24Y"3U@@;F%M92!I;B!T:&4@;6%I;&)O>"!V:65W('1O
M(&9I;'1E<B!A;&P@=6YD96QE=&5D(&UE<W-A9V5S(&%C8V]R9&EN9R!T;R!T
M:&4@<W!E8VEF:65D(')U;&5S+B`@3W(L(&%L=&5R;F%T979L>2P@8VQI8VL@
M;VX@(D%P<&QY($%L;"!2=6QE<R(@:6X@=&AE(&9I;'1E<B!M96YU+B`@3F]T
M92!T:&%T(&9I;'1E<FEN9R!I<R!N;W0@9&]N92!A=71O;6%T:6-A;&QY+@H@
M("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB9FEL
M=&5R<R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@07!P;'D\+W1I=&QE/@H@("`@
M/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!#;&EC:R!O;B!T:&4@)G%U;W0[07!P;'D@1FEL=&5R)G%U;W0[
M(&EC;VX@;F5X="!T;R!T:&4@24Y"3U@@;F%M92!I;B!T:&4@;6%I;&)O>"!V
M:65W('1O(&9I;'1E<B!A;&P@=6YD96QE=&5D(&UE<W-A9V5S(&%C8V]R9&EN
M9R!T;R!T:&4@<W!E8VEF:65D(')U;&5S+B`@3W(L(&%L=&5R;F%T979L>2P@
M8VQI8VL@;VX@)G%U;W0[07!P;'D@06QL(%)U;&5S)G%U;W0[(&EN('1H92!F
M:6QT97(@;65N=2X@($YO=&4@=&AA="!F:6QT97)I;F<@:7,@;F]T(&1O;F4@
M875T;VUA=&EC86QL>2X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M<G5L97,B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@1FEL=&5R(%)U;&5S/"]T:71L
M93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!&:6QT97(@4G5L97,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@9FEL=&5R
M(')U;&5S(B!T;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@
M861D+"!D96QE=&4L(&%N9"!E9&ET('1H92!C=7)R96YT;'D@86-T:79E('-E
M="!O9B!F:6QT97(@<G5L97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)F:6QT97(M961I="UB;&%C:VQI<W0B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@0FQA8VML:7-T/"]T:71L93X*("`@
M(#QH96%D:6YG/D5D:70@66]U<B!";&%C:VQI<W0\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@8FQA8VML:7-T(B!T;R!P
M<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L
M(&%N9"!E9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U($%,
M5T%94R!R969U<V4@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M=VAI=&5L:7-T(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET(%=H:71E;&ES=#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@5VAI=&5L:7-T/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R('=H:71E;&ES="(@
M=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L
M971E+"!A;F0@961I="!T:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S('EO
M=2!!3%=!65,@86-C97!T(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](F9I;'1E<BUO;BUL;V=I;B(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&]N($QO9VEN/"]T:71L93X*
M("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<R!5<&]N($QO9V]N/SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@=&\@
M86QW87ES(&%P<&QY(&9I;'1E<G,@=VAE;B!F:7)S="!L;V=G:6YG(&]N=&\@
M24U0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R
M+6]N+61I<W!L87DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z
M($9I;'1E<B!O;B!2969R97-H/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY
M(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T;R!A
M;'=A>7,@87!P;'D@9FEL=&5R<R!W:&5N979E<B!Y;W5R('9I97<@=&AE($E.
M0D]8/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R
M+6%N>2UM86EL8F]X(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S
M.B!&:6QT97(@86YY($UA:6QB;W@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P
M;'D@9FEL=&5R(')U;&5S('1O(&%N>2!M86EL8F]X/SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@:68@>6]U('=A;G0@=&\@
M8F4@86QL;W=E9"!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA:6QB
M;W@N($YO<FUA;&QY+"!F:6QT97)I;F<@<G5L97,@87)E(&]N;'D@87!P;&EE
M9"!T;R!N97<@;6%I;"!T:&%T(&ES(&1E;&EV97)E9"!T;R!Y;W5R($E.0D]8
M+B`@268@=&AI<R!O<'1I;VX@:7,@8VAE8VME9"P@86X@:6-O;B!W:6QL(&%P
M<&5A<B!O;B!A;&P@;6%I;&)O>"!P86=G97,@=&AA="!W:6QL(&%L;&]W('EO
M=2!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@=&AE(&UE<W-A9V5S(&EN('1H
M92!C=7)R96YT(&UA:6QB;W@N("!.3U1%.B!&:6QT97)I;F<@:6X@;6%I;&)O
M>&5S(&]T:&5R('1H86X@24Y"3U@@;6%Y('!R;V1U8V4@<W1R86YG92`H92YG
M+B!T:&4@9FEL=&5R(&UA>2!C875S92!A(&-O<'D@;V8@;65S<V%G97,@=&\@
M8F4@9&5L:79E<F5D('1O('1H92!S86UE(&UA:6QB;W@I(&%N9"]O<B!U;F1E
M<VER960@<F5S=6QT<R`H92YG+B!I="!M87D@8V%U<V4@;65S<V%G97,@=&\@
M8F4@;6]V960O9&5L971E9"!I9B!N97<@9FEL=&5R:6YG(')U;&5S(&AA=F4@
M8F5E;B!I;7!L96UE;G1E9"!S:6YC92!T:&4@;65S<V%G92!H87,@8F5E;B!D
M96QI=F5R960@=&\@=&AE(&-U<G)E;G0@;6%I;&)O>"DN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M<'5B
M:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($%T=&%C:"!0=6)L
M:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D%T=&%C:"!0=6)L:6,@2V5Y
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N(&$@
M8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L('=I
M;&P@8F4@871T86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N("!9;W4@
M8V%N('-E="!T:&4@9&5F875L="!B96AA=FEO<B!V:6$@=&AE(%!'4"!/<'1I
M;VYS('-C<F5E;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UO<'1I;VXM<V-A;BUB;V1Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y01U`Z(%-C86X@5&5X="!";V1I97,\+W1I=&QE/@H@("`@/&AE861I;F<^
M4V-A;B!497AT($)O9&EE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M<V5L96-T960@=&AE;B!)35`@=VEL;"!S8V%N('1H92!B;V1Y(&]F(&%L;"!T
M97AT(&UE<W-A9V5S(&9O<B!01U`@9&%T82P@86YD(&1I<W!L87D@=&AE(')E
M<W5L=',@:68@86YY(&1A=&$@:7,@9F]U;F0N("!.;W1E('1H870@=&AI<R!M
M87D@<VQO=R!D;W=N('1H92!S>7-T96T@87,@979E<GD@=&5X="!M97-S86=E
M(&UU<W0@8F4@<V-A;FYE9"!I;B!I=',@96YT:7)E='D@9F]R(%!'4"!D871A
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO
M<'1I;VYS+65N8W)Y<'0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D-O;7!O
M<V4Z($5N8W)Y<'1I;VX@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY.
M;R!%;F-R>7!T:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD('1H
M92!M97-S86=E('=I=&@@;F\@96YC<GEP=&EO;B`H8VQE87)T97AT*2X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!%;F-R>7!T($UE<W-A9V4\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@96YC<GEP
M="!T:&4@8W5R<F5N="!M97-S86=E+"!U<VEN9R!01U`@86YD('1H92!R96-I
M<&EE;G1S('!E<G-O;F%L('!U8FQI8R!K97DL(&%N9"!T:&5N('-E;F0@:70N
M(%EO=2!C86X@;VYL>2!S96YD(&$@;65S<V%G92!T;R!A('-I;F=L92!P97)S
M;VX@=7-I;F<@=&AI<R!O<'1I;VXN(%EO=2!-55-4(&AA=F4@=&AE('!U8FQI
M8R!K97D@;V8@=&AE(')E8VEP:65N="!S=&]R960@:6X@>6]U<B!A9&1R97-S
M8F]O:R!O<B!E;'-E('1H:7,@;W!T:6]N('=I;&P@9F%I;"X@268@>6]U(&AA
M=F4@=&AE('!U8FQI8R!K97D@9F]R('1H92!R96-I<&EE;G0@:6X@>6]U<B!A
M9&1R97-S8F]O:R!A;F0@87)E('-T:6QL(')E8V5I=FEN9R!E<G)O<G,L('9E
M<FEF>2!T:&%T('1H92!E+6UA:6P@861D<F5S<R!I;B!T:&4@<F5C:7!I96YT
M(&9I96QD(&UA=&-H97,@=&AE(&4M;6%I;"!A9&1R97-S('=H97)E('1H92!P
M=6)L:6,@:V5Y(&ES('-T;W)E9"X@5&AE(&5N8W)Y<'1E9"!D871A('=I;&P@
M8F4@871T86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL(&1I9VET86QL>2!S:6=N
M('1H92!C=7)R96YT(&UE<W-A9V4@=7-I;F<@4$=0(&%N9"!Y;W5R('!E<G-O
M;F%L('!R:79A=&4@:V5Y+B!)9B!Y;W4@:&%V92!N;W0@86QR96%D>2!E;G1E
M<F5D('1H92!P87-S<&AR87-E(&9O<B!Y;W5R('!R:79A=&4@:V5Y(&1U<FEN
M9R!T:&ES('-E<W-I;VX@>6]U('=I;&P@8F4@<')O;7!T960@9F]R(&ET+B`@
M5&AE(')E8V5I<&EE;G0@;75S="!H879E(&$@8V]P>2!O9B!Y;W5R('!U8FQI
M8R!K97D@=&\@9&EG:71A;&QY('9E<FEF>2!Y;W5R"B`@("!S:6=N871U<F4N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B]%;F-R>7!T($UE
M<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I
M;&P@9FER<W0@9&EG:71A;&QY('-I9VX@>6]U<B!M97-S86=E(&%N9"!T:&5N
M('=I;&P@96YC<GEP="!T:&4@<F5S=6QT:6YG(&]U='!U="X@4V5E('1H92`G
M4$=0($5N8W)Y<'0@365S<V%G92<@86YD("=01U`@4VEG;B!-97-S86=E)R!E
M;G1R:65S(&9O<B!F=7)T:&5R(&EN9F]R;6%T:6]N+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^4R]-24U%($5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M4R]-24U%(%-I9VX@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^4R]-24U%(%-I9VXO16YC
M<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@3W9E<G9I97<\+W1I=&QE
M/@H@("`@/&AE861I;F<^5VAA="!I<R!01U`_/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!01U`@:7,@82!T;V]L(&9O<B!S96-U<F4@8V]M;75N:6-A=&EO
M;B!A;F0@9&%T82!S=&]R86=E+"!E<W!E8VEA;&QY(&9O<B!U<V4@=VET:"!E
M+6UA:6PN($ET(&-A;B!B92!U<V5D('1O(&5N8W)Y<'0@9&%T82!A;F0@=&\@
M8W)E871E(&1I9VET86P@<VEG;F%T=7)E<RX@24U0('5S97,@1VYU4$<@*$=.
M52!0<FEV86-Y($=U87)D*2!T;R!P<F]V:61E('1H:7,@9G5N8W1I;VYA;&ET
M>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!01U`@9G5N8W1I
M;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@;W!T
M:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&-R96%T92]V
M:65W('EO=7(@<&5R<V]N86P@4$=0(&ME>7,L(&%D9"]D96QE=&4@<'5B;&EC
M(&ME>7,@9G)O;2!O=&AE<B!I;F1I=FED=6%L<RP@<F5A9"!E;F-R>7!T960@
M;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N8W)Y
M<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C:"UP=6)K97DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@3W!T:6]N<R`M($%T=&%C:"!0
M=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D]P=&EO;G,@+2!!='1A
M8V@@4'5B;&EC($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@<V5L
M96-T960@=&AE;B!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@:68@
M:70@97AI<W1S+"!W:6QL(&)Y(&1E9F%U;'0@8F4@871T86-H960@=&\@86QL
M(&]U=&=O:6YG(&UE<W-A9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*("`@(#QH
M96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES
M('-C<F5E;B!L:7-T<R!A;&P@;V8@=&AE(&-U<G)E;G0@=7-E<G,@:6X@>6]U
M<B!A9&1R97-S8F]O:R!T:&%T(&AA=F4@4$=0('!U8FQI8R!K97ES+B!4:&5S
M92!U<V5R<R!A<F4@=&AE($].3%D@=7-E<G,@=&AA="!Y;W4@8V%N(&5I=&AE
M<B`Q*2!S96YD(&%N(&5N8W)Y<'1E9"!M97-S86=E('1O("U/4BT@,BD@=F5R
M:69Y(&$@9&EG:71A;"!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A('=I
M;F1O=R!T;R!V:65W('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!U8FQI8R!K
M97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($1E;&5T97,@=&AE('!U8FQI8R!K97D@9G)O;2!Y
M;W5R(&%D9')E<W-B;V]K+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+6EM<&]R="UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES("T@26UP;W)T/"]T:71L93X*
M("`@(#QH96%D:6YG/DEM<&]R="!0=6)L:6,@2V5Y<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!O<&5N(&$@=VEN9&]W('=H
M97)E('EO=2!C86X@;6%N=6%L;'D@:6UP;W)T(&$@4$=0('!U8FQI8R!K97DN
M("!4:&4@:V5Y(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT9FEE
M;&0@;W(L(&EF('1H92!K97D@<F5S:61E<R!I;B!A(&9I;&4@;VX@>6]U<B!L
M;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@:70N("!)9B!T:&4@:V5Y
M(&ES('9A;&ED(&ET('=I;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R(&%D9')E
M<W-B;V]K(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V86QI
M9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI
M;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P
M+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES/"]T:71L93X*("`@(#QH96%D
M:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!M97-S86=E<R!O<B!E;F%B;&4@;W1H
M97)S('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M97-S86=E<RP@>6]U(&UU<W0@
M:&%V92!Y;W5R(&]W;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!01U`@:V5Y
M<&%I<BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4'5B;&EC($ME
M>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U<B!P=6)L:6,@:V5Y('-H
M;W5L9"!B92!M861E(&%V86EL86)L92!T;R!A;GD@<&5R<V]N('1H870@>6]U
M('=A;G0@=&\@8F4@86)L92!T;R!S96YD('EO=2!E;F-R>7!T960@;65S<V%G
M97,@=&AA="!O;FQY(%E/52!C86X@9&5C<GEP="`H=7-I;F<@>6]U<B!P<FEV
M871E(&ME>2DN($%D9&ET:6]N86QL>2P@>6]U<B!P=6)L:6,@:V5Y(&YE961S
M('1O(&)E(&UA9&4@879A:6QA8FQE('1O(&%N>6)O9'D@>6]U('-E;F0@82!D
M9&EG:71A;&QY('-I9VYE9"!M97-S86=E('1O("T@=&AE('!U8FQI8R!K97D@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!D:6=I=&%L('-I9VYA='5R92X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4')I=F%T92!+97D\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%EO=7(@<')I=F%T92!K97D@:7,@;F5C
M97-S87)Y('1O(&1E8W)Y<'0@86YY(&UE<W-A9V4@96YC<GEP=&5D('5S:6YG
M('EO=7(@<'5B;&EC(&ME>2X@061D:71I;VYA;&QY+"!Y;W5R('!R:79A=&4@
M:V5Y(&ES(&YE961E9"!I9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!A
M(&UE<W-A9V4N(%EO=7(@<')I=F%T92!K97D@=VEL;"!B92!P<F]T96-T960@
M=FEA(&$@<&%S<W!H<F%S92!C<F5A=&5D('=H96X@=&AE(&ME>7,@87)E(&=E
M;F5R871E9"X@5&AU<RP@=&\@<&5R9F]R;2!A;GD@86-T:79I='D@=&AA="!R
M97%U:7)E<R!Y;W5R('!R:79A=&4@:V5Y+"!)35`@=VEL;"!P<F]M<'0@>6]U
M(&9O<B!Y;W5R('!A<W-P:')A<V4N(%EO=2!O;FQY(&YE960@=&\@:6YS97)T
M('EO=7(@<&%S<W!H<F%S92!O;F-E('!E<B!S97-S:6]N("T@24U0('=I;&P@
M<W1O<F4@>6]U<B!P87-S<&AR87-E('5N=&EL('EO=2!L;V=O=70@*%-O(&)E
M('-U<F4@=&\@;&]G;W5T(2DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<'5B;&EC(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@4'5B;&EC
M($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@<'5B
M;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A
M8F]U="!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T92(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M
M(%!R:79A=&4@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D5N=&5R(%!A<W-P
M:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS('1H92!P87-S
M<&AR87-E(&1I86QO9R!W:6YD;W<N(%1H92!P87-S<&AR87-E(&5N=&5R960L
M(&EF(&-O<G)E8W0L('=I;&P@8F4@<W1O<F5D(&)Y($E-4"!U;G1I;"!Y;W5R
M('-E<W-I;VX@96YD<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5N;&]A
M9"!087-S<&AR87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!296UO=F5S
M('1H92!S=&]R960@<&%S<W!H<F%S92!F<F]M($E-4"`M(&%N>2!A9&1I=&EO
M;F%L('5S86=E(&]F('1H92!P<FEV871E(&ME>2!W:6QL(')E<75I<F4@>6]U
M('1O(')E96YT97(@=&AE('!A<W-P:&5A<V4N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A
M('=I;F1O=R!T;R!V:65W('1H92!01U`@<')I=F%T92!K97DN($1/($Y/5"!3
M14Y$(%1(25,@2T59(%1/($%.64].12`M('1H:7,@;W!T:6]N(&ES('-T<FEC
M=&QY('-O('1H870@>6]U(&-A;B!E>'!O<G0@>6]U<B!)35`@<&5R<V]N86P@
M<')I=F%T92!K97D@9F]R('5S92!I;B!A;F]T:&5R('!R;V=R86TN"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P
M<FEV871E(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UP97)S;VYA;&ME>2UD96QE=&4B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!$96QE=&4\+W1I=&QE
M/@H@("`@/&AE861I;F<^1&5L971E(%!E<G-O;F%L($ME>7,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1H:7,@8G5T=&]N('=I;&P@9&5L971E('EO=7(@
M<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<B!F<F]M($E-4"=S('!R
M969E<F5N8V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UN86UE(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!.86UE/"]T:71L
M93X*("`@(#QH96%D:6YG/DYA;64\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1H92!N86UE('EO=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@
M:V5Y<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N="(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@
M2V5Y("T@0V]M;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY#;VUM96YT/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!!(&-O;6UE;G0@<W1R:6YG('EO=2!W
M86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@:V5Y<RX@06X@;W!T:6]N
M86P@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M<&5R<V]N86QK97DM8W)E871E+65M86EL(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!%+6UA:6P@061D
M<F5S<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%+6UA:6P@061D<F5S<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&4M;6%I;"!A9&1R97-S('EO=2!W
M86YT(&%S<V]C:6%T960@=VET:"!Y;W5R('!E<G-O;F%L(&ME>7,N($$@<F5Q
M=6ER960@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@2V5Y
M;&5N9W1H/"]T:71L93X*("`@(#QH96%D:6YG/DME>6QE;F=T:#PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5&AE(&ME>6QE;F=T:"P@:6X@8GET97,L(&]F
M('EO=7(@9V5N97)A=&5D(&ME>2X@5&AE(&=R96%T97(@=&AE('9A;'5E+"!T
M:&4@9W)E871E<B!T:&4@<')O=&5C=&EO;B`H86YD(&%L<V\@9W)E871E<B!G
M96YE<F%T:6]N('1I;64@86YD(&5N8W)Y<'1I;VX@=&EM92DN(#$P,C0@8GET
M97,@:7,@=&AE(&1E9F%U;'0@+2!T:&ES('9A;'5E('!R;W9I9&5S(&5X8V5L
M;&5N="!P<F]T96-T:6]N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UP87-S<&AR87-E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@
M+2!087-S<&AR87-E/"]T:71L93X*("`@(#QH96%D:6YG/DYA;64\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H92!P87-S<&AR87-E('5S960@=&\@<')O
M=&5C="]E;F-R>7!T('EO=7(@<&5R<V]N86P@<')I=F%T92!K97DN(%1H:7,@
M<VAO=6QD(&)E($%4($Q%05-4(#8@8VAA<F%C=&5R<RP@<VAO=6QD($Y/5"!B
M92!T:&4@<V%M92!A<R!Y;W5R(&QO9VEN('!A<W-W;W)D+"!S:&]U;&0@3D]4
M(&)E(&)A<V5D(&]N(&$@9&EC=&EO;F%R>2!W;W)D+"!A;F0@<VAO=6QD(&EN
M8VQU9&4@8F]T:"!N=6UB97)S(&%N9"!L971T97)S+B!9;W4@;75S="!E;G1E
M<B!T:&ES('!A<W-P:')A<V4@='=I8V4@9F]R('9E<FEF:6-A=&EO;B!P=7)P
M;W-E<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M86-T:6]N<R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@
M2V5Y("T@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY#<F5A=&4@2V5Y
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0W)E871E(&%N9"!S=&]R92!Y
M;W5R('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/DEM<&]R="!+97EP86ER/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!);7!O<G0@82!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N(%1H:7,@
M8G5T=&]N(&]P96YS(&$@=VEN9&]W('=H97)E('EO=2!C86X@;6%N=6%L;'D@
M:6UP;W)T('EO=7(@97AI<W1I;F<@4$=0('!E<G-O;F%L('!U8FQI8R]P<FEV
M871E(&ME>7!A:7(N("!4:&4@:V5Y<R!C86X@96ET:&5R(&)E('!A<W1E9"!I
M;G1O(&$@=&5X=&9I96QD(&]R+"!I9B!T:&4@:V5Y<R!R97-I9&4@:6X@82!F
M:6QE(&]N('EO=7(@;&]C86P@8V]M<'5T97(L('EO=2!C86X@:6UP;W)T('1H
M96TN("!)9B!T:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E(&EN<V5R
M=&5D(&EN=&\@>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O=R!W:6QL
M(&-L;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B
M92!R971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y3+TU)344Z($]V97)V:65W/"]T:71L93X*("`@(#QH96%D
M:6YG/E=H870@:7,@4R]-24U%/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M4R]-24U%(&ES(&$@<')I=F%T92]P=6)L:6,@:V5Y('!A:7(@<WES=&5M('=H
M:6-H('!R;W9I9&5S(&1I9VET86P@<VEG;F%T=7)E<RP@;65S<V%G92!P<FEV
M86-Y+"!A;F0@=&%M<&5R(&1E=&5C=&EO;B!I;B!A(&]P96XL(&EN=&5R;W!E
M<F%B;&4@=V%Y+B`@4R]-24U%(&-A;B!P<F]V:61E(&UE<W-A9V4@<')I=F%C
M>2!B>2!E;F-R>7!T:6YG(&UE<W-A9V5S('1H870@;VYL>2!T:&4@<V5N9&5R
M(&%N9"!T:&4@:6YT96YD960@<F5C:7!I96YT<R!C86X@9&5C;V1E+B`@270@
M86QL;W=S('EO=2!T;R!I9&5N=&EF>2!T:&4@<V5N9&5R(&]F(&$@;65S<V%G
M92!V:6$@82!D:6=I=&%L('-I9VYA='5R92X@(%1O9V5T:&5R+"!T:&ES(&5N
M8W)Y<'1I;VX@86YD(&1I9VET86P@<VEG;FEN9R!H96QP('!R;W9I9&4@=&%M
M<&5R(&1E=&5C=&EO;BP@86QL;W=I;F<@<F5C:7!I96YT<R!T;R!D971E<FUI
M;F4@=VAE=&AE<B!A(&UE<W-A9V4@=V%S(&%L=&5R960@869T97(@:70@=V%S
M('-E;G0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;F%B;&4@4R]-24U%
M(&9U;F-T:6]N86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!T
M:&ES(&]P=&EO;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@86)L92!T;R!I
M;7!O<G0@>6]U<B!P97)S;VYA;"!3+TU)344@:V5Y<RP@<F5A9"!E;F-R>7!T
M960@;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N
M8W)Y<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=RUP97)S;VYA;&ME
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!097)S;VYA;"!+
M97ES/"]T:71L93X*("`@(#QH96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!)9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!O
M<B!E;F-R>7!T(&UE<W-A9V5S('EO=2!M=7-T(&AA=F4@>6]U<B!O=VX@<&5R
M<V]N86P@<'5B;&EC+W!R:79A=&4@4R]-24U%(&ME>7!A:7(N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UI;7!O<G0M<&5R<V]N
M86PM8V5R=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@26UP
M;W)T(%!E<G-O;F%L($-E<G1I9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!);7!O<G0@<&5R<V]N86P@8V5R=&EF:6-A=&5S(&9R;VT@
M82!02T-3(",Q,B!F;W)M870@9FEL92X@4$M#4R`C,3(@9FEL97,@:7,@=&AE
M(&9I;&4@=7-U86QL>2!G96YE<F%T960@=VAE;B!E>'!O<G1I;F<@82!K97D@
M9G)O;2!A(&)R;W=S97(@*&4N9RX@26YT97)N970@17AP;&]R97(L($9I<F5F
M;W@I(&]R(&9R;VT@82!C97)T:69I8V%T92!S=&]R92!M86EN=&%I;F5D(&)Y
M(&%N($]P97)A=&EN9R!3>7-T96T@*&4N9RX@5VEN9&]W<R!84"DN($EF('1H
M92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS97)T960@:6YT;R!Y
M;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF
M(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D
M(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<VUI;64M9&5L971E+7!E<G-O;F%L+6-E<G1S(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y3+TU)344Z($1E;&5T92!097)S;VYA;"!#97)T:69I
M8V%T97,\+W1I=&QE/@H@("`@/&AE861I;F<^1&5L971E(%!E<G-O;F%L($-E
M<G1I9FEC871E<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E('EO
M=7(@<&5R<V]N86P@8V5R=&EF:6-A=&5S(&9R;VT@>6]U<B!P<F5F97)E;F-E
M<RX@(%EO=2!W:6QL(&YO(&QO;F=E<B!B92!A8FQE('1O('-I9VX@4R]-24U%
M(&UE<W-A9V5S(&]R('9I97<@86YY(%,O34E-12!E;F-R>7!T960@;65S<V%G
M97,@861D<F5S<V5D('1O('EO=2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G-M:6UE+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*
M("`@(#QH96%D:6YG/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!-86YA9V4@>6]U<B!3+TU)344@<'5B;&EC
M(&ME>2!L:7-T+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5FEE=R!T:&4@<F%W('1E>'0@;V8@=&AE
M('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W('1E8VAN:6-A;"!D971A
M:6QS(&]F('1H92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^1&5L971E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&5S('1H
M92!S96QE8W1E9"!P=6)L:6,@:V5Y(&9R;VT@<W1O<F%G92X@($1E;&5T:6YG
M(&$@<'5B;&EC(&ME>2!F;W(@82!U<V5R('=I;&P@<')E=F5N="!Y;W5R(&9R
M;VT@96YC<GEP=&EN9R!A(&UE<W-A9V4@=&\@=&AA="!U<V5R+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')I;G1I;F<B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R:6YT:6YG/"]T:71L93X*("`@(#QH96%D:6YG
M/E!R:6YT(&$@;65S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&\@
M<')I;G0@82!M97-S86=E('EO=2!A<F4@=FEE=VEN9RP@8VQI8VL@;VX@=&AE
M(")0<FEN="(@;&EN:R!A="!E:71H97(@=&AE('1O<"!O<B!B;W1T;VT@;V8@
M=&AE(&UE<W-A9V4N(%1H92!M97-S86=E('=I;&P@;W!E;B!I;B!A(&YE=R!W
M:6YD;W<@9F]R;6%T960@9F]R('!R:6YT:6YG+B`@1&5P96YD:6YG(&]N('EO
M=7(@=V5B(&)R;W=S97(@86YD(&]P97)A=&EN9R!S>7-T96TL('1H92!P<FEN
M="!D:6%L;V<@8F]X(&UA>2!O<&5N(&9O<B!Y;W4N("!)9B!I="!D;V5S(&YO
M="!O<&5N+"!T:&5N('!U;&P@9&]W;B!T:&4@=V5B(&)R;W=S97(G<R`B1FEL
M92(@;65N=2!A;F0@8VAO;W-E(")0<FEN="(@=&\@;W!E;B!T:&4@<')I;G0@
M9&EA;&]G(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G-O<G1I;F<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E-O<G1I;F<@86YD
M(%1H<F5A9&EN9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3;W)T:6YG($5N=')I
M97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%=H96X@=FEE=VEN9R!A(&QI
M<W0@;V8@;65S<V%G97,L('EO=2!C86X@<V]R="!T:&4@;65S<V%G97,@8GD@
M86YY(&-O;'5M;B!B>2!C;&EC:VEN9R!O;B!T:&4@87!P<F]P<FEA=&4@8V]L
M=6UN(&AE861I;F<N("!4;R!S=VET8V@@8V]L=6UN<R!B971W965N(&%S8V5N
M9&EN9R!A;F0@9&5S8V5N9&EN9R!O<F1E<BP@8VQI8VL@;VX@=&AE(&%R<F]W
M(&EC;VX@:6X@=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^5&AR96%D:6YG/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M;R!G<F]U<"!M97-S86=E<R!B>2!T:')E861S("AS=6)J96-T*2P@<V\@96%C
M:"!M97-S86=E(&ES(&=R;W5P960@=VET:"!A;&P@:71S(')E<&QI97,L(&-L
M:6-K('1H92!;5&AR96%D72!L:6YK(&EN('1H92!S=6)J96-T(&-O;'5M;B!H
M96%D:6YG+B`@5&\@<F5T=7)N('1O(&YO<FUA;"!S=6)J96-T('-O<G1I;F<L
M(&-L:6-K(&]N('1H92!;4W5B:F5C=%T@;&EN:R!I;B!T:&4@<W5B:F5C="!C
M;VQU;6X@:&5A9&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](F%L=&5R;F%T:79E+6US9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M375L=&EP87)T+T%L=&5R;F%T:79E($UE<W-A9V5S/"]T:71L93X*("`@(#QP
M87)A/@H@("`@4V]M92!M97-S86=E(&AA=F4@8F5E;B!S96YT(&%S(&$@(FUU
M;'1I<&%R="]A;'1E<FYA=&EV92(@='EP92!B>2!T:&4@<V5N9&5R+B!4:&5S
M92!M97-S86=E<R!H879E('-E=F5R86P@<&%R=',L(&%L;"!D:7-P;&%Y:6YG
M('1H92!304U%($-/3E1%3E0@8G5T(&EN($1)1D9%4D5.5"!&3U)-0513+B!4
M:&4@;6%I;"!A9V5N="!W:6QL(&1I<W!L87D@=&AE(&QA<W0@<&%R="!I;B!T
M:&4@;&ES="!T:&%T(&-A;B!B92!S=6-C97-S9G5L;'D@9&ES<&QA>65D(&EN
M;&EN92!I;B!T:&4@8G)O=W-E<BP@:68@86YY+B!!;&P@;W1H97(@9F]R;6%T
M<R!W:6QL(&%P<&5A<B!U;F1E<B!T:&4@:&5A9&EN9R`B06QT97)N871I=F4@
M<&%R=',@9F]R('1H:7,@<V5C=&EO;B(@86YD(&-A;B!B92!V:65W960@;W(@
M9&]W;FQO861E9"!S97!A<F%T96QY+B!)="!I<R!I;7!O<G1A;G0@=&\@;F]T
M92!T:&%T('1H97-E(&%L=&5R;F%T:79E('!A<G1S(&-O;G1A:6X@=&AE(%-!
M344@0T].5$5.5%,@87,@=&AE('!A<G0@=&AA="!I<R!S:&]W;B`M('1H97D@
M87)E('-I;7!L>2!I;B!A(&1I9F9E<F5N="!M961I82!F;W)M870@*&4N9RX@
M=&5X="!V<RX@2%1-3"!O=71P=70I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@4F5N86UE(%-E;G0M;6%I;"!&;VQD97(@36]N=&AL>3PO=&ET;&4^"B`@
M("`\<&%R83X*("`@(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U('=O=6QD
M(&QI:V4@=&\@<F5N86UE('EO=7(@<V5N="UM86EL(&9O;&1E<B!A="!T:&4@
M8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AE(&9O;&1E<B!W:6QL(&)E
M(')E;F%M960@*'1O(&$@;F%M92!T:&%T(&-O;G1A:6YS('1H92!M;VYT:"!A
M;F0@>65A<BD@86YD(&$@;F5W('-E;G0M;6%I;"!F;VQD97(@=VEL;"!B92!C
M<F5A=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&5L971E7W-E;G1M86EL7VUO;G1H;'DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E(%-E;G0M
M;6%I;"!&;VQD97(@36]N=&AL>3PO=&ET;&4^"B`@("`\<&%R83X*("`@(%1U
M<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U('=O=6QD(&QI:V4@=&\@9&5L971E
M(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!T:&4@8F5G:6YN:6YG(&]F(&5V
M97)Y(&UO;G1H+B`@5&AI<R!M87D@8F4@=7-E9G5L(&EF('EO=2!H879E(&$@
M<75O=&$L(&9O<B!E>&%M<&QE+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&5L971E7W-E;G1M86EL7VUO;G1H;'E?:V5E<"(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!$96QE=&4@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY("T@(R!O9B!&
M;VQD97)S('1O($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M87)E(&1E;&5T:6YG(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!E=F5R>2!M;VYT
M:"P@:&]W(&UA;GD@;6]N=&AS(&]F(&]L9"!F;VQD97)S(&1O('EO=2`@=V%N
M="!T;R!K965P/R`@06YY(&9O;&1E<G,@;VQD97(@=&AA;B!T:&ES(&UA;GD@
M;6]N=&AS('=I;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E
M;F%N8V4Z($1E;&5T92!,:6YK960@071T86-H;65N=',@36]N=&AL>3PO=&ET
M;&4^"B`@("`\<&%R83X*("`@(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U
M('=O=6QD(&QI:V4@=&\@9&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@
M870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H:7,@;6%Y(&)E
M('5S969U;"!I9B!Y;W4@:&%V92!A('%U;W1A+"!F;W(@97AA;7!L92X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]A
M='1A8VAM96YT<U]M;VYT:&QY7VME97`B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E($QI;FME9"!!
M='1A8VAM96YT<R!-;VYT:&QY("T@(R!O9B!-;VYT:',@=&\@2V5E<#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@9&5L971I;F<@;VQD(&QI
M;FME9"!A='1A8VAM96YT<R!E=F5R>2!M;VYT:"P@:&]W(&UA;GD@;6]N=&AS
M(&]F(&]L9"!A='1A8VAM96YT<R!D;R!Y;W4@('=A;G0@=&\@:V5E<#\@($%N
M>2!A='1A8VAM96YT<R!O;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT:',@=VEL
M;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M<'5R9V5?=')A<V@B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@4'5R9V4@5')A<V@\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!$;R!Y;W4@=V%N="!T;R!P=7)G92!Y;W5R('1R
M87-H(&9O;&1E<B!E=F5R>2!S;R!O9G1E;BX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H7VEN=&5R=F%L(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z(%!U<F=E(%1R87-H($EN=&5R=F%L/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@>6]U(&%R92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R+"!H;W<@
M;V9T96X@<VAO=6QD(&ET(&)E('!U<F=E9#\*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H7VME97`B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@
M4'5R9V4@5')A<V@@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO
M=2!A<F4@<'5R9VEN9R!Y;W5R('1R87-H(&9O;&1E<BP@;65S<V%G92!O;&1E
M<B!T:&%N(&AO=R!M86YY(&1A>7,@<VAO=6QD(&)E('!U<F=E9#\*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6%T=')I8E]T97AT
M(B!S=&%T93TB;F5W(CX*("`@("`\=&ET;&4^4')E9F5R96YC97,Z($UE<W-A
M9V4@0V]M<&]S:71I;VXZ($%T=')I8G5T:6]N(%1E>'0\+W1I=&QE/@H@("`@
M(#QP87)A/@H@("`@($AE<F4@>6]U(&-A;B!E;G1E<B!T:&4@<&AR87-E('1H
M870@>6]U('=I<V@@=&\@87!P96%R(&)E9F]R92!A;GD@<75O=&5D('1E>'0@
M:6X@82!R97!L>2!T:&%T('EO=2!S96YD+@H@("`@(#PO<&%R83X*("`@("`\
M<&%R83X*("`@("!9;W4@8V%N(&EN8VQU9&4@;VYE(&]R(&UO<F4@<W!E8VEA
M;"!P;&%C96AO;&1E<G,@=&\@:6YS97)T(&EN9F]R;6%T:6]N(&%B;W5T('1H
M92!M97-S86=E('1O('=H:6-H('EO=2!A<F4@<F5P;'EI;F<N(%!L86-E:&]L
M9&5R<R!C;VYS:7-T(&]F(&$@)R4G(&9O;&QO=V5D(&)Y(&$@<VEN9VQE(&QE
M='1E<BX@5&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@87)E(&%V86EL86)L
M93H*("`@("`\+W!A<F$^"@H@("`@(#QP87)A/B`E9B`Z(%1H92!S96YD97(G
M<R!N86UE(&%N9"!E;6%I;"!A9&1R97-S/"]P87)A/@H@("`@(#QP87)A/B`E
M82`Z(%1H92!S96YD97(G<R!E;6%I;"!A9&1R97-S/"]P87)A/@H@("`@(#QP
M87)A/B`E<"`Z(%1H92!S96YD97(G<R!N86UE/"]P87)A/@H@("`@(#QP87)A
M/B`E<B`Z(%1H92!F=6QL(%)&0R`R.#(R('-T>6QE(&1A=&4@86YD('1I;64@
M>F]N93PO<&%R83X*("`@("`\<&%R83X@)60@.B!4:&4@9&%T92!A<R!W=W<L
M(&1D(&UM;2!965E9/"]P87)A/@H@("`@(#QP87)A/B`E>"`Z(%1H92!D871E
M(&EN('1H92!L;V-A;&4G<R!D969A=6QT/"]P87)A/@H@("`@(#QP87)A/B`E
M8R`Z(%1H92!D871E(&%N9"!T:6UE(&EN('1H92!L;V-A;&4G<R!D969A=6QT
M/"]P87)A/@H@("`@(#QP87)A/B`E;2`Z(%1H92!-97-S86=E+4E$/"]P87)A
M/@H@("`@(#QP87)A/B`E<R`Z(%1H92!S=6)J96-T/"]P87)A/@H@("`@(#QP
M87)A/B`E;B`Z($$@;F5W(&QI;F4\+W!A<F$^"B`@("`@/'!A<F$^("4E(#H@
M5&AE("<E)R!C:&%R86-T97(\+W!A<F$^"@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]R96%D(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4F5Q=65S="!296%D(%)E8V5I
M<'1S/"]T:71L93X*("`@(#QP87)A/@H@("`@(E)E<75E<W0@82!296%D(%)E
M8V5I<'0B('-E;F1S(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT<R!O9B!T
M:&ES(&UE<W-A9V4@=&\@;F]T:69Y('EO=2!W:&5N('1H:7,@;65S<V%G92!I
M<R!O<&5N960@8GD@=&AE(')E8VEP:65N=',N($YO="!A;&P@8VQI96YT<R!S
M=7!P;W)T("\@:&]N;W(@=&AI<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W-E;F1?;61N(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4V5N9"!-1$X\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("`B4V5N9"!A($U$3B(@<V5N9',@82!-97-S86=E
M($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`H86QS;R!K;F]W;B!A<R!A(')E
M860@<F5C96EP="D@=VAE;B!Y;W4@=FEE=R!A(&UE<W-A9V4@:6X@=VAI8V@@
M=&AE('5S97(@:&%S(')E<75E<W1E9"!T:&%T('1H97D@<F5C96EV92!N;W1I
M9FEC871I;VX@=&AA="!Y;W4@:&%V92!R96%D('1H92!M97-S86=E+B!);B!M
M;W-T(&-A<V5S+"!T:&ES('=I;&P@:&%P<&5N(&%U=&]M871I8V%L;'D@=VET
M:&]U="!P<F]M<'1I;F<@>6]U+B!);B!C97)T86EN(&ES;VQA=&5D(&-A<V5S
M+"!Y;W4@;6%Y(&AA=F4@=&\@;6%N=6%L;'D@9&5C:61E('1O('-E;F0@=&AE
M(&YO=&EF:6-A=&EO;B!B>2!C;&EC:VEN9R!O;B!A(&QI;FLN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R
M97%U97-T7V1E;&EV97)Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F
M97)E;F-E<SH@4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VX\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I
M;VXB('-E;F1S(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT)W,@92UM86EL
M('-E<G9E<B!T;R!N;W1I9GD@>6]U('=H96X@:70@:&%S(&1E;&EV97)E9"!T
M:&4@;65S<V%G92!T;R!T:&4@<F5C:7!I96YT)W,@;6%I;&)O>"X@270@9&]E
M<VXG="!M96%N('1H92!M97-S86=E(&AA<R!B965N('-E96XL(&IU<W0@=&AA
M="!I="=S('-I='1I;F<@:6X@82!M86EL8F]X('-O;65W:&5R92X@3F]T(&%L
M;"!M86EL('-E<G9E<G,@<W5P<&]R="!T:&ES+B`*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]S<&%M7V%F=&5R7W)E
M<&]R="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($1E
M;&5T92!3<&%M($%F=&5R(%)E<&]R=&EN9SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@(%EO=2!M87D@96QE8W0@=&\@9&\@;VYE(&]F('1H<F5E(&ET96US(&%F
M=&5R(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@96ET:&5R('-P86T@;W(@:6YN
M;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($9I<G-T+"!Y;W4@
M8V%N(&1E8VED92!T;R!D;R!N;W1H:6YG("T@=&AE(&UE<W-A9V4@=VEL;"!B
M92!R97!O<G1E9"!A<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="!B=70@=VEL
M;"!O=&AE<G=I<V4@<F5M86EN('5N8VAA;F=E9"!I;B!Y;W5R(&UA:6QB;W@N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-E8V]N9"P@:68@<F5P;W)T
M:6YG(&$@;65S<V%G92!A<R!S<&%M+"!Y;W4@8V%N(&EN<W1E860@:&%V92!T
M:&4@;65S<V%G92!B92!I;6UE9&EA=&5L>2!D96QE=&5D+B`@5&AI<R!S971T
M:6YG(&AA<R!N;R!E9F9E8W0@;VX@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I
M;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@5&AI<F0L(&%F
M=&5R(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@<W!A;2!T:&4@;65S<V%G92!W
M:6QL(&)E(&1E;&5T960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M
M;W9E9"!T;R!Y;W5R('-P86T@9F]L9&5R+B`@06QT97)N871I=F5L>2P@:68@
M<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I;FYO8V5N="!T:&4@;65S<V%G92!W
M:6QL(&)E(&1E;&5T960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M
M;W9E9"!T;R!Y;W5R($E.0D]8+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]R97!L86-E;65N="(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P
M;&%C96UE;G0\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!&;W(@2%1-3"!M97-S
M86=E<R!D:7-P;&%Y960@:6YL:6YE+"!S:&]U;&0@86QL(&EM86=E('1A9W,@
M8F4@8FQO8VME9"!U;G1I;"!Y;W4@<W!E8VEF:6-A;&QY(&1E8VED92!T;R!V
M:65W('1H;W-E(&EM86=E<S\@3F]T92!T:&%T+"!I9B!V:65W:6YG(&%N($A4
M34P@871T86-H;65N="P@=&AE(&EM86=E<R!W:6QL(&%L=V%Y<R!B92!D:7-P
M;&%Y960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUH=&UL7VEM86=E7V%D9')B;V]K(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G92!297!L86-E;65N="]!9&1R97-S
M8F]O:R!3:&]W/"]T:71L93X*("`@(#QP87)A/@H@("`@268@8FQO8VMI;F<@
M:6UA9V5S(&9O<B!I;FQI;F4@2%1-3"!M97-S86=E<RP@<VAO=6QD('=E(&%U
M=&]M871I8V%L;'D@9&ES<&QA>2!T:&5M(&EN<W1E860@:68@=&AE('-E;F1E
M<B!A<'!E87)S(&EN('EO=7(@861D<F5S<V)O;VL_"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUM86EL8F]X7W-T87)T(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;&)O>"!3=&%R
M="!086=E/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&EC
M:"!P86=E(&EN('1H92!M86EL8F]X('9I97<@=VEL;"!B92!D:7-P;&%Y960@
M=VAE;B!Y;W4@86-C97-S(&$@;6%I;&)O>"!F;W(@=&AE(&9I<G-T('1I;64N
M($YO=&4@=&AA="!T:&4@)W5N<V5E;B<@;65S<V%G92!O<'1I;VYS(&1O(&YO
M="!W;W)K('=I=&@@=&AE("=4:')E860G('-O<G1I;F<@;W!T:6]N("T@:6YS
M=&5A9"P@>6]U('=I;&P@8F4@<V5N="!T;R!T:&4@;&%S="!P86=E+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<V%V95]A='1A
M8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M(%-A=F4@071T86-H;65N=',@;VX@4V5N="!-97-S86=E<SPO=&ET;&4^"B`@
M("`\<&%R83X*("`@($EF('-A=FEN9R!A(&-O;7!O<V5D(&UE<W-A9V4@:6X@
M82!S96YT+6UA:6P@9F]L9&5R+"!D971E<FUI;F4@:68@86QL(&%T=&%C:&UE
M;G0@9&%T82!I<R!S879E9"X@5&AE(&9O;&QO=VEN9R!O<'1I;VYS(&%R92!A
M=F%I;&%B;&4Z"B`@("`\+W!A<F$^"@H@("`@/'!A<F$^*B`B06QW87ES('-A
M=F4@871T86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A=F4@871T86-H
M;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT<R!A<F4@
M04Q705E3('-A=F5D('=I=&@@=&AE(&UE<W-A9V4N/"]P87)A/@H@("`@(#QP
M87)A/BH@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N
M=#L@9&5F875L="!T;R!915,B("T@04Q705E3('!R;VUP="!T;R!S879E(&%T
M=&%C:&UE;G1S(&EN('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@
M:7,@=&\@<V%V92!A='1A8VAM96YT<RX\+W!A<F$^"B`@("`@/'!A<F$^*B`B
M4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A
M=6QT('1O($Y/(B`M($%,5T%94R!P<F]M<'0@=&\@<V%V92!A='1A8VAM96YT
M<R!I;B!T:&4@8V]M<&]S92!S8W)E96X[('1H92!D969A=6QT(&ES('1O(&YO
M="!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R83XJ(").979E
M<B!S879E(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP="!T;R!S879E(&%T
M=&%C:&UE;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@871T86-H;65N=',@
M87)E($Y%5D52('-A=F5D('=I=&@@=&AE(&UE<W-A9V4N/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]I;F)O>"(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L($EN8F]X/"]T
M:71L93X*("`@(#QP87)A/@H@("`@5FER=71A;"!);F)O>"!I<R!A('-A=F5D
M('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D('1O('-E87)C
M:"!E=F5R>2!M86EL8F]X(&9O<B!M97-S86=E<R!M87)K960@87,@;F5W+B`@
M26YS=&5A9"P@86QL(&-U<G)E;G1L>2!S=6)S8W)I8F5D(&UA:6QB;WAE<R!A
M<F4@<V5A<F-H960@9F]R(&YE=R!M97-S86=E<R!A;F0@=&AE(')E<W5L=',@
M87)E(&1I<W!L87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T<F%S:"(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L(%1R
M87-H/"]T:71L93X*("`@(#QP87)A/@H@("`@5FER='5A;"!4<F%S:"!I<R!A
M('-A=F5D('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D(&9O
M<B!A('-E<&%R871E(%1R87-H(&9O;&1E<BX@($EN<W1E860@;V8@;6]V:6YG
M(&UE<W-A9V5S('1O(&$@8V5N=')A;&EZ960@=')A<V@@9F]L9&5R+"!M97-S
M86=E<R!A<F4@<VEM<&QY(&UA<FME9"!A<R!D96QE=&5D(&EN('1H92!C=7)R
M96YT(&9O;&1E<B!T:&5Y(&QI=F4@:6XN("!7:&5N("=S:&]W(&1E;&5T960@
M;65S<V%G97,G(&ES('1U<FYE9"!O9F8L('1H:7,@<F5S=6QT<R!I;B!T:&5S
M92!M97-S86=E<R!N;W0@87!P96%R:6YG(&EN(&$@;6%I;&)O>"!V:65W+B`@
M5VAE;B!A('5S97(@8VQI8VMS(&]N(%9I<G1U86P@5')A<V@L("IA;&PJ(&UA
M:6QB;WAE<R!A;&P@<V5A<F-H960@9F]R(&UE<W-A9V5S('1H870@87)E(&9L
M86=G960@9&5L971E9"!A;F0@=&AE<V4@;65S<V%G97,@87)E(&1I<W!L87EE
M9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\
M+VAE;'`^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O9G)?
M1E(O````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-C,`,#$W-#0W`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+VQO8V%L92]F<E]&4B],0U]-15-304=%4R\`````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,C$R,S0`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+V9R7T92+TQ#7TU%4U-!
M1T53+VEM<"YM;P``````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S$W-34U`#$P-#$W
M,S8R-S8S`#`R,C,W-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#>$@25`````'L+```<````]%L``$\/``#,MP````````CU
M```*````"?4```H````4]0``"@```!_U```*````*O4```X````U]0``#P``
M`$3U```-````5/4```@```!B]0``"P```&OU```,````=_4```H```"$]0``
M!````(_U```$````E/4``!@```"9]0``&P```++U```M````SO4``!T```#\
M]0``)````!KV```I````/_8``!D```!I]@```0```(/V```9````A?8``"8`
M``"?]@``#````,;V```+````T_8``"0```#?]@``'@````3W``!(````(_<`
M`"L```!L]P``1````)CW```G````W?<``!<````%^```#P```!WX```+````
M+?@```X````Y^```!0```$CX```H````3O@```@```!W^```"@```(#X```5
M````B_@``!(```"A^```,@```+3X```+````Y_@``"D```#S^```,@```!WY
M```0````4/D``!8```!A^0``$````'CY```F````B?D``"D```"P^0``)@``
M`-KY```<`````?H``(4````>^@``#@```*3Z```*````L_H```T```"^^@``
M)P```,SZ```B````]/H```X````7^P``(@```";[```9````2?L``"0```!C
M^P``-P```(C[```1````P/L```T```#2^P``#````.#[```-````[?L```8`
M``#[^P``&P````+\``"4````'OP``"X```"S_```-P```.+\```&````&OT`
M``P````A_0``?````"[]``!L````J_T``!P````8_@``'0```#7^```*````
M4_X```\```!>_@``&````&[^```,````A_X``!L```"4_@``10```+#^```H
M````]OX``$$````?_P``)````&'_```.````AO\```\```"5_P``#@```*7_
M```.````M/\```@```##_P``#@```,S_```.````V_\```D```#J_P``+@``
M`/3_```:````(P`!`#,````^``$`40```'(``0`R````Q``!`#@```#W``$`
M5````#`!`0!1````A0$!`%H```#7`0$`5P```#("`0`T````B@(!``D```"_
M`@$`#0```,D"`0`'````UP(!``H```#?`@$`#P```.H"`0`%````^@(!``,`
M`````P$`!@````0#`0`1````"P,!``@````=`P$`"0```"8#`0`)````,`,!
M`!T````Z`P$`#@```%@#`0`(````9P,!``H```!P`P$`)0```'L#`0`@````
MH0,!`!,```#"`P$`$````-8#`0`/````YP,!``\```#W`P$`"@````<$`0`'
M````$@0!``,````:!`$`&0```!X$`0`/````.`0!`!0```!(!`$`"0```%T$
M`0`-````9P0!`!(```!U!`$`&0```(@$`0`>````H@0!``\```#!!`$`"@``
M`-$$`0`/````W`0!``@```#L!`$`"@```/4$`0`D``````4!`!<````E!0$`
M%````#T%`0`6````4@4!`!(```!I!0$`"````'P%`0`<````A04!`$X```"B
M!0$`+0```/$%`0`9````'P8!`&`````Y!@$`*````)H&`0`>````PP8!`!H`
M``#B!@$`+````/T&`0`@````*@<!`#(```!+!P$`!P```'X'`0`,````A@<!
M``T```"3!P$`5````*$'`0!C````]@<!`"P```!:"`$`#@```(<(`0`#````
ME@@!``L```":"`$`!P```*8(`0`'````K@@!``4```"V"`$`!0```+P(`0`*
M````P@@!``,```#-"`$`%P```-$(`0`*````Z0@!``\```#T"`$`#@````0)
M`0!.````$PD!`%````!B"0$`0P```+,)`0!"````]PD!`#T````Z"@$`%@``
M`'@*`0`P````CPH!`!@```#`"@$`(P```-D*`0`.````_0H!`!0````,"P$`
M%P```"$+`0`7````.0L!`!<```!1"P$`$P```&D+`0`/````?0L!`",```"-
M"P$`!@```+$+`0`7````N`L!``X```#0"P$`40```-\+`0`?````,0P!`!T`
M``!1#`$`-0```&\,`0`U````I0P!``<```#;#`$`!@```.,,`0`(````Z@P!
M``\```#S#`$`!@````,-`0`(````"@T!`!$````3#0$`"@```"4-`0`3````
M,`T!``L```!$#0$`$````%`-`0`5````80T!``T```!W#0$`$P```(4-`0`C
M````F0T!`"\```"]#0$`%0```.T-`0`'`````PX!`!`````+#@$`!0```!P.
M`0`5````(@X!`!$````X#@$`#````$H.`0`_````5PX!`#````"7#@$`2```
M`,@.`0`A````$0\!`#L````S#P$`.P```&\/`0`\````JP\!`#@```#H#P$`
M*P```"$0`0`P````31`!`#$```!^$`$`.P```+`0`0`Y````[!`!`#4````F
M$0$`"0```%P1`0`'````9A$!`!0```!N$0$`#````(,1`0`#````D!$!``4`
M``"4$0$`"0```)H1`0`0````I!$!``D```"U$0$`$P```+\1`0`#````TQ$!
M`#D```#7$0$`$@```!$2`0`,````)!(!`#4````Q$@$`#@```&<2`0!)````
M=A(!`#,```#`$@$`"@```/02`0`6````_Q(!`"T````6$P$`"P```$03`0`G
M````4!,!`"P```!X$P$`*@```*43`0`E````T!,!``D```#V$P$`"0`````4
M`0`*````"A0!``8````5%`$`"0```!P4`0`'````)A0!`"\````N%`$`-P``
M`%X4`0`N````EA0!`%4```#%%`$`+0```!L5`0`L````214!`"T```!V%0$`
M/0```*05`0`_````XA4!`"T````B%@$`0````%`6`0`C````D18!`",```"U
M%@$`0````-D6`0`M````&A<!`#,```!(%P$`)0```'P7`0`5````HA<!`!D`
M``"X%P$`*0```-(7`0`D````_!<!`"@````A&`$`4````$H8`0`8````FQ@!
M`!$```"T&`$`$0```,88`0`*````V!@!``P```#C&`$`"P```/`8`0`*````
M_!@!`",````'&0$`%@```"L9`0`*````0AD!`!````!-&0$`%@```%X9`0`6
M````=1D!`"X```",&0$`!P```+L9`0`'````PQD!`!0```#+&0$`"@```.`9
M`0`(````ZQD!`"<```#T&0$`"````!P:`0`#````)1H!``<````I&@$`!P``
M`#$:`0`&````.1H!`#@```!`&@$`!0```'D:`0`'````?QH!``8```"'&@$`
M"````(X:`0`)````EQH!`"D```"A&@$`#@```,L:`0`*````VAH!`$4```#E
M&@$`!````"L;`0`$````,!L!``<````U&P$`"0```#T;`0`&````1QL!`!$`
M``!.&P$`!P```&`;`0`6````:!L!``0```!_&P$`)P```(0;`0`(````K!L!
M``8```"U&P$`#0```+P;`0`&````RAL!`!X```#1&P$`$0```/`;`0`(````
M`AP!``T````+'`$`#````!D<`0`'````)AP!``,````N'`$``P```#(<`0`7
M````-AP!`!,```!.'`$`"````&(<`0`=````:QP!``@```")'`$`!````)(<
M`0`(````EQP!``@```"@'`$`*@```*D<`0`K````U!P!`%,`````'0$`00``
M`%0=`0`:````EAT!`"L```"Q'0$`(````-T=`0`5````_AT!``8````4'@$`
M!@```!L>`0`.````(AX!`!4````Q'@$`/@```$<>`0`8````AAX!`"(```"?
M'@$`+@```,(>`0`=````\1X!`"$````/'P$`5````#$?`0`I````AA\!``H`
M``"P'P$`!P```+L?`0`'````PQ\!`!4```#+'P$`#@```.$?`0`"````\!\!
M``H```#S'P$`#P```/X?`0`-````#B`!``\````<(`$`#0```"P@`0`)````
M.B`!`!0```!$(`$`!@```%D@`0`8````8"`!`!T```!Y(`$`$P```)<@`0`1
M````JR`!`!0```"](`$`3P```-(@`0`$````(B$!``P````G(0$`!@```#0A
M`0`*````.R$!``T```!&(0$`%````%0A`0!B````:2$!`"<```#,(0$`5```
M`/0A`0!?````22(!`&0```"I(@$`!`````XC`0`6````$R,!``X````J(P$`
M'````#DC`0`/````5B,!`#,```!F(P$`*````)HC`0`%````PR,!``4```#)
M(P$`&P```,\C`0`:````ZR,!``X````&)`$`$P```!4D`0`5````*20!`#``
M```_)`$`$0```'`D`0`1````@B0!`!P```"4)`$`*@```+$D`0`U````W"0!
M`$4````2)0$`$````%@E`0`A````:24!``4```"+)0$`$P```)$E`0`+````
MI24!`!(```"Q)0$`"@```,0E`0`/````SR4!``T```#?)0$`1P```.TE`0`?
M````-28!`"4```!5)@$`,P```'LF`0`K````KR8!`#4```#;)@$`0@```!$G
M`0`=````5"<!`%$```!R)P$`$0```,0G`0`Q````UB<!`#L````(*`$`$P``
M`$0H`0!`````6"@!`#@```"9*`$`!0```-(H`0`,````V"@!`!$```#E*`$`
M#0```/<H`0`&````!2D!``P````,*0$`!@```!DI`0`7````("D!``@````X
M*0$`#````$$I`0`4````3BD!``\```!C*0$`$````',I`0`1````A"D!``@`
M``"6*0$`!0```)\I`0`1````I2D!``P```"W*0$`$````,0I`0`%````U2D!
M``T```#;*0$`!@```.DI`0`'````\"D!``T```#X*0$`!P````8J`0`+````
M#BH!``<````:*@$`!P```"(J`0`)````*BH!`!<````T*@$`)@```$PJ`0!/
M````<RH!``D```##*@$`"0```,TJ`0`*````URH!`!D```#B*@$`/0```/PJ
M`0`=````.BL!``P```!8*P$`)0```&4K`0`?````BRL!`!````"K*P$`!0``
M`+PK`0`E````PBL!`"(```#H*P$`$@````LL`0`3````'BP!`"L````R+`$`
M.P```%XL`0`@````FBP!`!L```"[+`$`"````-<L`0`V````X"P!`"$````7
M+0$`$````#DM`0`(````2BT!`!L```!3+0$`'@```&\M`0`O````CBT!`%P`
M``"^+0$`+@```!LN`0`,````2BX!``8```!7+@$`!````%XN`0`/````8RX!
M``X```!S+@$`#@```((N`0`'````D2X!``X```"9+@$`!P```*@N`0`*````
ML"X!``T```"[+@$`'P```,DN`0`<````Z2X!`"$````&+P$`'@```"@O`0`9
M````1R\!`!X```!A+P$`'0```(`O`0`;````GB\!`"P```"Z+P$`(````.<O
M`0`N````"#`!`"8````W,`$`)````%XP`0`<````@S`!`!X```"@,`$`'```
M`+\P`0`F````W#`!`#8````#,0$`*P```#HQ`0`S````9C$!`"D```":,0$`
M00```,0Q`0`Z````!C(!`"8```!!,@$`*P```&@R`0`X````E#(!`!T```#-
M,@$`%0```.LR`0`O`````3,!`"`````Q,P$`$@```%(S`0`I````93,!`!X`
M``"/,P$`/0```*XS`0`@````[#,!`!(````--`$`H@```"`T`0`6````PS0!
M`",```#:-`$`*````/XT`0`I````)S4!`#H```!1-0$`*````(PU`0`?````
MM34!`!4```#5-0$`(````.LU`0`E````##8!`"@````R-@$`+0```%LV`0`P
M````B38!`)(```"Z-@$`(0```$TW`0`6````;S<!`!P```"&-P$`)@```*,W
M`0`J````RC<!`$$```#U-P$`1````#<X`0`,````?#@!``<```").`$`!P``
M`)$X`0`&````F3@!``T```"@.`$`"P```*XX`0`5````NC@!`!0```#0.`$`
M#0```.4X`0`8````\S@!`!H````,.0$`$````"<Y`0`=````.#D!`!D```!6
M.0$`70```'`Y`0`5````SCD!`"4```#D.0$`$@````HZ`0`3````'3H!`!(`
M```Q.@$`!P```$0Z`0`$````3#H!`!````!1.@$`$````&(Z`0`,````<SH!
M``X```"`.@$`#0```(\Z`0`/````G3H!`!0```"M.@$`$P```,(Z`0`-````
MUCH!`#D```#D.@$`'````!X[`0`H````.SL!``,```!D.P$`#0```&@[`0`&
M````=CL!`!$```!].P$`%P```(\[`0`;````ISL!``X```##.P$``@```-([
M`0!)````U3L!``4````?/`$`!0```"4\`0`0````*SP!``\````\/`$`!```
M`$P\`0`-````43P!``X```!?/`$``P```&X\`0`.````<CP!``@```"!/`$`
M#P```(H\`0`(````FCP!``H```"C/`$`#P```*X\`0`'````OCP!``T```#&
M/`$`$````-0\`0`4````Y3P!``T```#Z/`$`&0````@]`0`:````(CT!``L`
M```]/0$`"0```$D]`0`&````4ST!`!0```!:/0$`"P```&\]`0`3````>ST!
M`!````"//0$`#````*`]`0`*````K3T!`!$```"X/0$`%P```,H]`0`1````
MXCT!`!4```#T/0$`)P````H^`0`9````,CX!``L```!,/@$`#0```%@^`0`B
M````9CX!`"L```")/@$`%P```+4^`0`T````S3X!`#,````"/P$`&P```#8_
M`0`T````4C\!``H```"'/P$`&````)(_`0`4````JS\!`!D```#`/P$`%@``
M`-H_`0`'````\3\!`!````#Y/P$`(@````I``0`<````+4`!`!P```!*0`$`
M#0```&=``0`'````=4`!``P```!]0`$`)@```(I``0`*````L4`!`!0```"\
M0`$`"P```-%``0`'````W4`!`"(```#E0`$`+P````A!`0`+````.$$!``D`
M``!$00$`&0```$Y!`0`+````:$$!`"H```!T00$`#P```)]!`0`7````KT$!
M`!<```#'00$`"0```-]!`0`'````Z4$!`!8```#Q00$`#P````A"`0`M````
M&$(!`!D```!&0@$`%@```&!"`0`.````=T(!`!H```"&0@$`*````*%"`0`M
M````RD(!`"X```#X0@$`"P```"=#`0`8````,T,!``@```!,0P$`#````%5#
M`0`C````8D,!``T```"&0P$`)@```)1#`0`J````NT,!`"````#F0P$`0P``
M``=$`0`(````2T0!`!(```!41`$`'P```&=$`0`$````AT0!``@```",1`$`
M"P```)5$`0`:````H40!`"<```"\1`$`$@```.1$`0`@````]T0!`"\````8
M10$`%P```$A%`0`%````8$4!``P```!F10$`#@```'-%`0`.````@D4!``4`
M``"110$`!@```)=%`0`.````GD4!`$4```"M10$``P```/-%`0`#````]T4!
M`"L```#[10$`!P```"=&`0`$````+T8!``X````T1@$`"@```$-&`0`,````
M3D8!``H```!;1@$`#P```&9&`0`0````=D8!`!<```"'1@$`$P```)]&`0`E
M````LT8!``X```#91@$`$0```.A&`0`9````^D8!`!<````41P$`$P```"Q'
M`0`6````0$<!`#@```!71P$`$P```)!'`0`)````I$<!``4```"N1P$`"P``
M`+1'`0`*````P$<!``(```#+1P$`!0```,Y'`0`-````U$<!`!L```#B1P$`
M%P```/Y'`0`4````%D@!``D````K2`$`'0```#5(`0`/````4T@!`!8```!C
M2`$`$@```'I(`0`+````C4@!``P```"92`$`#@```*9(`0`-````M4@!`!(`
M``##2`$`&0```-9(`0`<````\$@!`#@````-20$`&````$9)`0`@````7TD!
M`!,```"`20$`"0```)1)`0`#````GDD!`!4```"B20$`"P```+A)`0`3````
MQ$D!``@```#820$`#@```.%)`0`0````\$D!`'L````!2@$`&````'U*`0`8
M````EDH!`"<```"O2@$`*0```-=*`0`L`````4L!`"@````N2P$`#@```%=+
M`0`U````9DL!`!$```"<2P$`!P```*Y+`0`%````MDL!`"D```"\2P$`&```
M`.9+`0`>````_TL!`!L````>3`$`&0```#I,`0`8````5$P!`!L```!M3`$`
M&0```(E,`0`3````HTP!``<```"W3`$`"````+],`0`&````R$P!``8```#/
M3`$`&P```-9,`0`0````\DP!``\````#30$`$````!--`0`/````)$T!``L`
M```T30$`#P```$!-`0`,````4$T!``\```!=30$`!P```&U-`0`&````=4T!
M``H```!\30$`$@```(=-`0`-````FDT!``P```"H30$`#@```+5-`0!#````
MQ$T!`#T````(3@$`"0```$9.`0`,````4$X!`"@```!=3@$`#P```(9.`0`(
M````EDX!``@```"?3@$`$P```*A.`0`+````O$X!`!X```#(3@$`(0```.=.
M`0`@````"4\!`!D````J3P$`%P```$1/`0`E````7$\!`!<```""3P$`%@``
M`)I/`0`$````L4\!`!L```"V3P$`#0```-)/`0`,````X$\!``,```#M3P$`
M!0```/%/`0`(````]T\!``H`````4`$`#`````M0`0`*````&%`!`"`````C
M4`$`'P```$10`0`;````9%`!`!D```"`4`$`"P```)I0`0`;````IE`!``L`
M``#"4`$`$````,Y0`0`(````WU`!``P```#H4`$`#@```/50`0`+````!%$!
M``0````040$`!````!51`0`3````&E$!`!0````N40$`#````$-1`0`)````
M4%$!``X```!:40$`"P```&E1`0`;````=5$!``X```"140$`#P```*!1`0`E
M````L%$!`"H```#640$`!P````%2`0`2````"5(!`!L````<4@$`!````#A2
M`0`'````/5(!``H```!%4@$`$@```%!2`0`*````8U(!``T```!N4@$`"0``
M`'Q2`0`$````AE(!``4```"+4@$`"````)%2`0`#````FE(!`!@```">4@$`
M'0```+=2`0`0````U5(!``X```#F4@$`'@```/52`0`:````%%,!``H````O
M4P$`!````#I3`0`F````/U,!``X```!F4P$`?````'53`0`5````\E,!`$0`
M```(5`$`!0```$U4`0`'````4U0!``P```!;5`$`"````&A4`0`*````<50!
M``8```!\5`$`!P```(-4`0`(````BU0!`!$```"45`$`&0```*94`0`(````
MP%0!``(```#)5`$`!@```,Q4`0`&````TU0!`!0```#:5`$`&@```.]4`0`-
M````"E4!`!`````850$`&P```"E5`0`%````154!``0```!+50$`#````%!5
M`0`)````754!`!````!G50$`"0```'A5`0`)````@E4!``0```",50$`!0``
M`)%5`0`:````EU4!``4```"R50$`&@```+A5`0`(````TU4!``8```#<50$`
M#P```.-5`0`9````\U4!``X````-5@$`!P```!Q6`0`'````)%8!`"(````L
M5@$`!0```$]6`0`)````558!``H```!?5@$``@```&I6`0`-````;58!`"``
M``![5@$`!@```)Q6`0`+````HU8!``T```"O5@$`#````+U6`0`)````RE8!
M``8```#45@$`$@```-M6`0`)````[E8!``<```#X5@$`%`````!7`0`=````
M%5<!`$(````S5P$`)0```'97`0`E````G%<!``8```#"5P$`"@```,E7`0`$
M````U%<!``D```#95P$`"````.-7`0`1````[%<!``D```#^5P$`!@````A8
M`0`-````#U@!``8````=6`$`!````"18`0`$````*5@!`!<````N6`$`.0``
M`$98`0`]````@%@!`#H```"^6`$`'@```/E8`0`%````&%D!``X````>60$`
M!````"U9`0`&````,ED!``<````Y60$`(0```$%9`0`-````8UD!`!4```!Q
M60$`!@```(=9`0`$````CED!`!$```"360$`!@```*59`0`*````K%D!`"(`
M``"W60$`)P```-I9`0`&`````EH!`!4````)6@$`#````!]:`0`1````+%H!
M``0````^6@$`#0```$-:`0`'````45H!``4```!96@$`'0```%]:`0`$````
M?5H!``P```""6@$`#@```(]:`0`*````GEH!``@```"I6@$`"0```+):`0`%
M````O%H!`#H```#"6@$`,````/U:`0`U````+EL!`"D```!D6P$`1P```(Y;
M`0`X````UEL!`"D````/7`$`/P```#E<`0`N````>5P!`"T```"H7`$`'P``
M`-9<`0`/````]EP!`!(````&70$`"P```!E=`0`F````)5T!`"<```!,70$`
M*0```'1=`0`D````GET!`"8```##70$`*````.I=`0`(````$UX!``H````<
M7@$`"0```"=>`0`'````,5X!``0````Y7@$`'````#Y>`0`W````6UX!`"``
M``"37@$`(````+1>`0`F````U5X!``T```#\7@$`)P````I?`0`;````,E\!
M`"(```!.7P$`#````'%?`0`6````?E\!``4```"57P$`"@```)M?`0`9````
MIE\!`"D```#`7P$`%@```.I?`0`2`````6`!``<````48`$`"@```!Q@`0`,
M````)V`!``\````T8`$`$````$1@`0!`````56`!`$0```"68`$`/````-M@
M`0!P````&&$!`&8```")80$`!@```/!A`0`*````]V$!``4````"8@$`#@``
M``AB`0`)````%V(!``H````A8@$`$@```"QB`0`3````/V(!``P```!38@$`
M!@```&!B`0`&````9V(!``H```!N8@$`#@```'EB`0`/````B&(!``X```"8
M8@$`&P```*=B`0`?````PV(!`!X```#C8@$`(P````)C`0`1````)F,!`!4`
M```X8P$`&````$YC`0`1````9V,!`!````!Y8P$`(P```(IC`0`/````KF,!
M``D```"^8P$`$@```,AC`0`=````VV,!`!(```#Y8P$`$`````QD`0`*````
M'60!`!$````H9`$`!0```#ID`0`Q````0&0!`"0```!R9`$`'````)=D`0`C
M````M&0!`&H```#89`$`#P```$-E`0`%````4V4!`!````!990$`"0```&IE
M`0`$````=&4!``L```!Y90$`(````(5E`0`<````IF4!`",```##90$`(@``
M`.=E`0`&````"F8!`!0````19@$`%P```"9F`0`,````/F8!`"0```!+9@$`
M(P```'!F`0`:````E&8!``P```"O9@$`#P```+QF`0`5````S&8!`"D```#B
M9@$`*@````QG`0`F````-V<!`"<```!>9P$`*0```(9G`0`J````L&<!`!D`
M``#;9P$`0@```/5G`0`1````.&@!`!(```!*:`$`$P```%UH`0`4````<6@!
M``\```"&:`$`%@```)9H`0`7````K6@!`!````#%:`$`$0```-9H`0`T````
MZ&@!`!,````=:0$`$@```#%I`0`U````1&D!`!0```!Z:0$`!P```(]I`0`,
M````EVD!`"L```"D:0$`#P```-!I`0`6````X&D!`"````#W:0$`$````!AJ
M`0`4````*6H!`!$````^:@$`*````%!J`0`7````>6H!`!P```"1:@$`$P``
M`*YJ`0`+````PFH!`!0```#.:@$`&@```.-J`0`1````_FH!`!H````0:P$`
M'@```"MK`0`:````2FL!`!,```!E:P$`(0```'EK`0`@````FVL!`!4```"\
M:P$`$0```-)K`0`7````Y&L!`!0```#\:P$`%P```!%L`0`5````*6P!``D`
M```_;`$`!@```$EL`0`0````4&P!`!D```!A;`$`!````'ML`0`'````@&P!
M``L```"(;`$`$0```)1L`0`&````IFP!``8```"M;`$`!@```+1L`0`%````
MNVP!``<```#!;`$`!P```,EL`0`%````T6P!`!8```#7;`$`!@```.YL`0`&
M````]6P!``0```#\;`$`!`````%M`0`'````!FT!``X````.;0$`#````!UM
M`0`,````*FT!``T````W;0$``@```$5M`0`*````2&T!``X```!3;0$`!0``
M`&)M`0`H````:&T!``X```"1;0$`#````*!M`0`/````K6T!``H```"];0$`
M"````,AM`0`)````T6T!`"L```#;;0$`3P````=N`0!'````5VX!`%,```"?
M;@$`+@```/-N`0`$````(F\!``@````G;P$`)@```#!O`0`2````5V\!``\`
M``!J;P$`!@```'IO`0`*````@6\!``<```",;P$`"````)1O`0`@````G6\!
M``D```"^;P$`$0```,AO`0`)````VF\!`!0```#D;P$`#````/EO`0`-````
M!G`!``X````4<`$`%@```"-P`0`1````.G`!``8```!,<`$``P```%-P`0`&
M````5W`!`!D```!><`$`!P```'AP`0`$````@'`!``L```"%<`$`"P```)%P
M`0`'````G7`!``4```"E<`$`!P```*MP`0`6````LW`!``T```#*<`$`#0``
M`-AP`0`*````YG`!`!````#Q<`$`#P````)Q`0`1````$G$!`!<````D<0$`
M"@```#QQ`0`1````1W$!``@```!9<0$`!````&)Q`0`1````9W$!``\```!Y
M<0$`.@```(EQ`0`A````Q'$!``4```#F<0$`%P```.QQ`0`,````!'(!`!X`
M```1<@$`#@```#!R`0`0````/W(!``L```!0<@$`?````%QR`0`,````V7(!
M``D```#F<@$`!P```/!R`0`*````^'(!``D````#<P$`#@````US`0`0````
M'',!`!4````M<P$`&P```$-S`0`8````7W,!`!H```!X<P$`"@```)-S`0`)
M````GG,!``H```"H<P$`#@```+-S`0`,````PG,!``\```#/<P$`"````-]S
M`0`&````Z',!``P```#O<P$`'````/QS`0`'````&70!``4````A=`$`"P``
M`"=T`0!'````,W0!``T```![=`$`"0```(ET`0`$````DW0!``,```"8=`$`
M#````)QT`0`3````J70!`!,```"]=`$`$P```-%T`0`&````Y70!``H```#L
M=`$``@```/=T`0`$````^G0!`"4```#_=`$``P```"5U`0`%````*74!`"H`
M```O=0$`#@```%IU`0`*````:74!``4```!T=0$`!````'IU`0`*````?W4!
M``T```"*=0$`'P```)AU`0`'````N'4!`"(```#`=0$`#0```.-U`0`&````
M\74!``@```#X=0$`"`````%V`0`$````"G8!``4````/=@$`:````!5V`0`)
M````?G8!``P```"(=@$`$````)5V`0`%````IG8!``8```"L=@$`(P```+-V
M`0`E````UW8!``@```#]=@$`-P````9W`0`B````/G<!`!,```!A=P$`&P``
M`'5W`0`O````D7<!`!````#!=P$`"@```-)W`0`1````W7<!``\```#O=P$`
M#P```/]W`0`*````#W@!``D````:>`$`$P```"1X`0`;````.'@!`!@```!4
M>`$`%P```&UX`0`7````A7@!`!D```"=>`$`'P```+=X`0`.````UW@!`"8`
M``#F>`$`)@````UY`0`#````-'D!``<````X>0$`"````$!Y`0`'````27D!
M`!````!1>0$`"@```&)Y`0`+````;7D!``<```!Y>0$`$P```(%Y`0`,````
ME7D!``\```"B>0$`#@```+)Y`0`,````P7D!``X```#.>0$`40```-UY`0`/
M````+WH!`!`````_>@$`#0```%!Z`0`/````7GH!``\```!N>@$`%P```'YZ
M`0`4````EGH!`!$```"K>@$`#P```+UZ`0`@````S7H!`"X```#N>@$`&@``
M`!U[`0`,````.'L!`"8```!%>P$`"P```&Q[`0`-````>'L!`!H```"&>P$`
M2@```*%[`0`9````['L!``8````&?`$`&@````U\`0`E````*'P!``8```!.
M?`$`!@```%5\`0`?````7'P!``8```!\?`$`"0```(-\`0`8````C7P!`!<`
M``"F?`$`*````+Y\`0`&````YWP!``T```#N?`$`(@```/Q\`0!7````'WT!
M`!,```!W?0$`(P```(M]`0`3````KWT!``(```##?0$`"P```,9]`0`(````
MTGT!``T```#;?0$`!@```.E]`0`*````\'T!``<```#[?0$`%`````-^`0`&
M````&'X!``@````??@$`#@```"A^`0`'````-WX!``H````_?@$`"P```$I^
M`0`R````5GX!`"L```")?@$`!P```+5^`0`,````O7X!``T```#*?@$`#```
M`-A^`0`$````Y7X!``D```#J?@$`"0```/1^`0`*````_GX!``<````)?P$`
M"0```!%_`0!`````&W\!``X```!<?P$`!P```&M_`0`*````<W\!`!L```!^
M?P$`#P```)I_`0`5````JG\!`!4```#`?P$`$@```-9_`0`*````Z7\!`!8`
M``#T?P$`"0````N``0`0````%8`!``<````F@`$`$@```"Z``0`$````08`!
M``0```!&@`$`!````$N``0`A````4(`!``<```!R@`$`!0```'J``0`,````
M@(`!``4```"-@`$`"P```).``0`4````GX`!`!$```"T@`$`&@```,:``0`6
M````X8`!`!0```#X@`$`%P````V!`0`8````)8$!`!P````^@0$`&0```%N!
M`0`'````=8$!``4```!]@0$`%@```(.!`0`#````FH$!``T```">@0$`#```
M`*R!`0`*````N8$!``@```#$@0$`"P```,V!`0`1````V8$!``@```#K@0$`
M%P```/2!`0`+````#((!``P````8@@$`#````"6"`0`?````,H(!`!H```!2
M@@$`$P```&V"`0`$````@8(!``H```"&@@$`!````)&"`0`-````EH(!``P`
M``"D@@$`"0```+&"`0`,````NX(!``4```#(@@$`"0```,Z"`0`%````V((!
M``<```#>@@$`!0```.:"`0`$````[((!``(```#Q@@$`%````/2"`0`-````
M"8,!`!(````7@P$`"P```"J#`0`;````-H,!`!\```!2@P$`#P```'*#`0`4
M````@H,!`!X```"7@P$`%0```+:#`0`X````S(,!`"P````%A`$`$@```#*$
M`0`I````180!`#(```!OA`$`"@```**$`0`L````K80!`"X```#:A`$`,P``
M``F%`0`S````/84!`#@```!QA0$`#P```*J%`0`8````NH4!`"\```#3A0$`
M$`````.&`0`3````%(8!`"H````HA@$`&0```%.&`0`<````;88!`!\```"*
MA@$`#P```*J&`0`3````NH8!`!4```#.A@$`%````.2&`0`4````^88!`"``
M```.AP$`$@```"^'`0`4````0H<!`!4```!7AP$`+0```&V'`0`M````FX<!
M`#$```#)AP$`+@```/N'`0`O````*H@!`"P```!:B`$`8@```(>(`0`3````
MZH@!`"4```#^B`$`)````"2)`0`I````28D!`$@```!SB0$`#0```+R)`0`(
M````RHD!`!<```#3B0$`"````.N)`0`D````](D!`!(````9B@$`#````"R*
M`0`.````.8H!`#<```!(B@$`*P```("*`0`2````K(H!`"$```"_B@$`&@``
M`.&*`0`)````_(H!`$4````&BP$`00```$R+`0`/````CHL!``0```">BP$`
M$P```*.+`0`4````MXL!``X```#,BP$`!@```-N+`0`3````XHL!`!@```#V
MBP$`!@````^,`0`)````%HP!``H````@C`$`"P```"N,`0`)````-XP!``T`
M``!!C`$`#````$^,`0`/````7(P!`!<```!LC`$`%````(2,`0`0````F8P!
M`!8```"JC`$`!P```,&,`0`.````R8P!`"$```#8C`$`!0```/J,`0`'````
M`(T!`!L````(C0$`*@```"2-`0`(````3XT!``8```!8C0$`%````%^-`0`1
M````=(T!`$0```"&C0$`/````,N-`0`.````"(X!`#@````7C@$``@```%".
M`0`"````4XX!``8```!6C@$`#@```%V.`0`%````;(X!``<```!RC@$`#@``
M`'J.`0`&````B8X!`"@```"0C@$`#````+F.`0`,````QHX!`!P```#3C@$`
M(P```/".`0`$````%(\!`"D````9CP$`,@```$./`0`7````=H\!`!\```".
MCP$`,P```*Z/`0!<````XH\!``P````_D`$`%````$R0`0`^````89`!``T`
M``"@D`$`'P```*Z0`0`0````SI`!`!0```#?D`$`!P```/20`0`.````_)`!
M``P````+D0$`#````!B1`0`3````)9$!``H````YD0$`'0```$21`0`9````
M8I$!``4```!\D0$`$0```(*1`0`3````E)$!``T```"HD0$`#P```+:1`0`1
M````QI$!`"0```#8D0$`$@```/V1`0`#````$)(!`!4````4D@$`$P```"J2
M`0`2````/I(!``L```!1D@$`-````%V2`0`+````DI(!`!0```">D@$`/@``
M`+.2`0`.````\I(!`!,````!DP$`-````!63`0`Q````2I,!`!(```!\DP$`
M$````(^3`0`8````H),!`!D```"YDP$`(P```-.3`0`B````]Y,!`"<````:
ME`$`5@```$*4`0!-````F90!`+D```#GE`$`"````*&5`0`)````JI4!``T`
M``"TE0$`"@```,*5`0`'````S94!``\```#5E0$`!@```.65`0`+````[)4!
M``0```#XE0$`'````/V5`0`-````&I8!`"<````HE@$`&P```%"6`0`,````
M;)8!`!H```!YE@$`"@```)26`0`'````GY8!``T```"GE@$`(@```+66`0`A
M````V)8!``@```#ZE@$`!0````.7`0`?````"9<!``8````IEP$`$````#"7
M`0`(````09<!``<```!*EP$`#0```%*7`0`*````8)<!`!(```!KEP$`(0``
M`'Z7`0`+````H)<!`!L```"LEP$`&````,B7`0`(````X9<!`!X```#JEP$`
M$@````F8`0`L````')@!`!H```!)F`$`"0```&28`0`*````;I@!`!4```!Y
MF`$`!0```(^8`0`4````E9@!``0```"JF`$`$````*^8`0`&````P)@!``<`
M``#'F`$`'@```,^8`0`H````[I@!``H````7F0$`'````"*9`0`1````/YD!
M``L```!1F0$`&@```%V9`0`L````>)D!``@```"EF0$`%````*Z9`0`L````
MPYD!`"<```#PF0$`*P```!B:`0`J````1)H!``0```!OF@$`!````'2:`0`+
M````>9H!``4```"%F@$`!@```(N:`0`(````DIH!``8```";F@$`,0```**:
M`0`<````U)H!``H```#QF@$`H@```/R:`0`;````GYL!`#0```"[FP$`-```
M`/";`0`@````)9P!`"D```!&G`$`)P```'"<`0`@````F)P!`$$```"YG`$`
M&@```/N<`0`H````%IT!`!H````_G0$`=@```%J=`0!Y````T9T!`!P!``!+
MG@$`*````&B?`0`=````D9\!`"D```"OGP$`'0```-F?`0!0````]Y\!`"X`
M``!(H`$`-@```'>@`0`L````KJ`!`#$```#;H`$`+@````VA`0`B````/*$!
M``8```!?H0$`"````&:A`0`%````;Z$!``@```!UH0$`&0```'ZA`0`9````
MF*$!`"H```"RH0$`$````-VA`0`K````[J$!`",````:H@$`&0```#ZB`0`A
M````6*(!`"X```!ZH@$`-````*FB`0`(````WJ(!`!<```#GH@$`"@```/^B
M`0`'````"J,!`"$````2HP$`$````#2C`0`-````1:,!`!````!3HP$`!0``
M`&2C`0`.````:J,!``@```!YHP$`"P```(*C`0`4````CJ,!``<```"CHP$`
M$P```*NC`0`(````OZ,!`#8```#(HP$`-P```/^C`0`+````-Z0!``D```!#
MI`$`"@```$VD`0`4````6*0!``\```!MI`$`+P```'VD`0`R````K:0!``L`
M``#@I`$`#@```.RD`0`-````^Z0!``\````)I0$`%@```!FE`0`^````,*4!
M`"<```!OI0$`)@```)>E`0`D````OJ4!``4```#CI0$`!0```.FE`0`%````
M[Z4!`"<```#UI0$`'P```!VF`0`6````/:8!``L```!4I@$`%P```&"F`0`/
M````>*8!``0```"(I@$`"@```(VF`0`)````F*8!``L```"BI@$`#0```*ZF
M`0`,````O*8!``X```#)I@$`!0```-BF`0`$````WJ8!``T```#CI@$`,@``
M`/&F`0!%````)*<!``L```!JIP$`#@```':G`0`.````A:<!``D```"4IP$`
M"````)ZG`0`0````IZ<!`!4```"XIP$`$P```,ZG`0`7````XJ<!``<```#Z
MIP$`'@````*H`0`5````(:@!`!0````WJ`$`!0```$RH`0`4````4J@!``8`
M``!GJ`$`"P```&ZH`0`'````>J@!`",```""J`$`%@```*:H`0`/````O:@!
M``X```#-J`$`*@```-RH`0`&````!ZD!``P````.J0$`&````!NI`0`-````
M-*D!`!$```!"J0$`"P```%2I`0`V````8*D!``T```"7J0$`"@```*6I`0`B
M````L*D!``L```#3J0$`#P```-^I`0`0````[ZD!`"X`````J@$`.@```"^J
M`0`.````:JH!``T```!YJ@$`!0```(>J`0`+````C:H!``P```"9J@$`#0``
M`*:J`0`-````M*H!``X```#"J@$`#0```-&J`0`@````WZH!`"<`````JP$`
M*P```"BK`0`(````5*L!``H```!=JP$`!@```&BK`0`2````;ZL!``X```""
MJP$`%P```)&K`0`R````J:L!`!8```#<JP$`'````/.K`0`E````$*P!`#``
M```VK`$`,0```&>L`0`M````F:P!``X```#'K`$`%````-:L`0`%````ZZP!
M``X```#QK`$`$P````"M`0`:````%*T!`!(````OK0$`!P```$*M`0`&````
M2JT!`!,```!1K0$`'P```&6M`0`4````A:T!`!$```":K0$`2P```*RM`0`3
M````^*T!``<````,K@$`%````!2N`0`8````*:X!``<```!"K@$`!0```$JN
M`0`,````4*X!``P```!=K@$`$@```&JN`0`$````?:X!``<```""K@$`"@``
M`(JN`0`+````E:X!``P```"AK@$`#@```*ZN`0`.````O:X!``4```#,K@$`
M!0```-*N`0`N````V*X!`"8````'KP$`(P```"ZO`0`#````4J\!`!(```!6
MKP$`!@```&FO`0`&````<*\!`!X```!WKP$`%@```):O`0`8````K:\!``X`
M``#&KP$`-P```-6O`0`.````#;`!`!<````<L`$`00```#2P`0`T````=K`!
M`"4```"KL`$`%0```-&P`0`Q````Y[`!`!,````9L0$`&P```"VQ`0`J````
M2;$!`%$```!TL0$`60```,:Q`0!0````(+(!`+\```!QL@$`)0```#&S`0`-
M````5[,!``0```!ELP$`"0```&JS`0`?````=+,!``,```"4LP$`!P```)BS
M`0`*````H+,!``@```"KLP$``@```+2S`0`0````M[,!``@```#(LP$`#```
M`-&S`0`5````WK,!``L```#TLP$`&0````"T`0`@````&K0!`!(````[M`$`
M!0```$ZT`0`*````5+0!`!4```!?M`$`$@```'6T`0`,````B+0!``0```"5
MM`$`"0```)JT`0`'````I+0!`#(```"LM`$`"@```-^T`0`*````ZK0!`!4`
M``#UM`$`#`````NU`0`/````&+4!``L````HM0$`!P```#2U`0`6````/+4!
M`%(```!3M0$`.@```*:U`0`@````X;4!``\````"M@$`%P```!*V`0`D````
M*K8!`#D```!/M@$`$@```(FV`0`'````G+8!``8```"DM@$`"0```*NV`0`.
M````M;8!``X```#$M@$`#@```-.V`0`$````XK8!``8```#GM@$`%@```.ZV
M`0`,````!;<!``T````2MP$`#@```""W`0`5````+[<!`!(```!%MP$`#P``
M`%BW`0`4````:+<!`!0```!]MP$`0P```)*W`0`*````UK<!`!L```#AMP$`
M-0```/VW`0`1````,[@!`!````!%N`$`"P```%:X`0!I````8K@!`!H```#,
MN`$`%P```.>X`0`H````_[@!`"<````HN0$`&P```%"Y`0`:````;+D!`!<`
M``"'N0$`&P```)^Y`0`9````N[D!`!\```#5N0$`%P```/6Y`0`<````#;H!
M`!<````JN@$`#````$*Z`0`3````3[H!``@```!CN@$`+P```&RZ`0`'````
MG+H!``@```"DN@$`$````*VZ`0`1````OKH!``D```#0N@$`%0```-JZ`0`-
M````\+H!``8```#^N@$`'0````6[`0`C````([L!``<```!'NP$`#0```$^[
M`0`3````7;L!``@```!QNP$``P```'J[`0!&````?KL!`$,```#%NP$`,@``
M``F\`0`_````/+P!`#<```!\O`$`5P```+2\`0`%````#+T!`!\````2O0$`
M+P```#*]`0`*````8KT!``T```!MO0$`$@```'N]`0`I````CKT!``@```"X
MO0$`#0```,&]`0`M````S[T!`'````#]O0$`/P```&Z^`0`Y````KKX!`$8`
M``#HO@$`!````"^_`0`0````-+\!`!````!%OP$`#````%:_`0`4````8[\!
M`!T```!XOP$`'````):_`0`1````L[\!`#T```#%OP$`3P````/``0`E````
M4\`!`"````!YP`$`'````)K``0`+````M\`!`"<```##P`$`&@```.O``0`?
M````!L$!`!T````FP0$`*````$3!`0`/````;<$!`"4```!]P0$`(````*/!
M`0`D````Q,$!`"0```#IP0$`(`````["`0`E````+\(!``L```!5P@$`!P``
M`&'"`0`-````:<(!``P```!WP@$`%P```(3"`0`%````G,(!``8```"BP@$`
M.0```*G"`0`%````X\(!``P```#IP@$`!P```/;"`0`)````_L(!`!,````(
MPP$`!@```!S#`0`)````(\,!``0````MPP$`$````#+#`0`(````0\,!``@`
M``!,PP$`!````%7#`0`+````6L,!``P```!FPP$`$@```'/#`0`1````AL,!
M``P```"8PP$`&@```*7#`0`/````P,,!``<```#0PP$`#0```-C#`0`/````
MYL,!``P```#VPP$`%`````/$`0`4````&,0!``\````MQ`$`#@```#W$`0`2
M````3,0!`!0```!?Q`$`#@```'3$`0`,````@\0!`!L```"0Q`$`+````*S$
M`0`3````V<0!`!P```#MQ`$`*`````K%`0`&````,\4!``<````ZQ0$`$P``
M`$+%`0`%````5L4!``0```!<Q0$`#````&'%`0`7````;L4!`!(```"&Q0$`
M*0```)G%`0`+````P\4!``T```#/Q0$`%````-W%`0`O````\L4!``H````B
MQ@$`#````"W&`0`)````.L8!``8```!$Q@$`"0```$O&`0`(````5<8!``D`
M``!>Q@$`!0```&C&`0`*````;L8!`!$```!YQ@$`"@```(O&`0`0````EL8!
M`!````"GQ@$`"P```+C&`0`&````Q,8!``X```#+Q@$`#@```-K&`0`-````
MZ<8!``L```#WQ@$`$`````/'`0`=````%,<!`!$````RQP$`"P```$3'`0`"
M````4,<!``@```!3QP$`'````%S'`0`'````><<!``T```"!QP$`!@```(_'
M`0!D````EL<!`!8```#[QP$`"0```!+(`0`'````',@!`"8````DR`$`.```
M`$O(`0`:````A,@!`"H```"?R`$`.P```,K(`0`H````!LD!`#0````OR0$`
M&0```&3)`0`5````?LD!``4```"4R0$`"P```)K)`0`'````ILD!``@```"N
MR0$`!P```+?)`0`%````O\D!``<```#%R0$`#@```,W)`0`)````W,D!``8`
M``#FR0$`"````.W)`0`+````]LD!``<````"R@$`"`````K*`0`'````$\H!
M`!8````;R@$`"0```#+*`0`&````/,H!`!D```!#R@$`&@```%W*`0`@````
M>,H!``L```"9R@$`$````*7*`0`&````MLH!`!P```"]R@$`%````-K*`0`'
M````[\H!`!$```#WR@$`"`````G+`0`.````$LL!``@````ARP$`!0```"K+
M`0`0````,,L!``D```!!RP$`$````$O+`0`&````7,L!`!D```!CRP$`"@``
M`'W+`0`<````B,L!``<```"ERP$`!0```*W+`0`%````L\L!`!````"YRP$`
M%````,K+`0`+````W\L!``T```#KRP$`*````/G+`0`8````(LP!`!<````[
MS`$`"P```%/,`0`:````7\P!`!0```!ZS`$`+P```(_,`0`$````O\P!``D`
M``#$S`$`"@```,[,`0`'````V<P!``(```#AS`$`#@```.3,`0`(````\\P!
M`",```#\S`$`,0```"#-`0`X````4LT!`'@```"+S0$`)@````3.`0`;````
M*\X!`#$```!'S@$`,0```'G.`0`G````J\X!`"(```#3S@$`(````/;.`0!D
M````%\\!`!T```!\SP$`%````)K/`0`<````K\\!`%T```#,SP$`50```"K0
M`0`X````@-`!`"T```"YT`$`,P```.?0`0!+````&]$!`$H```!GT0$`6P``
M`++1`0`H````#M(!`"P````WT@$`.````&32`0`E````G=(!`"$```##T@$`
M*````.72`0`L````#M,!`"8````[TP$`&P```&+3`0`>````?M,!`'4```"=
MTP$`/@```!/4`0!"````4M0!`#T```"5U`$`/0```-/4`0`I````$=4!`"D`
M```[U0$`,0```&75`0`^````E]4!`"\```#6U0$`J0$```;6`0`C````L-<!
M`&(```#4UP$`3P```#?8`0`7````A]@!`$@```"?V`$`-@```.C8`0`^````
M']D!`#````!>V0$`(````(_9`0`_````L-D!`#0```#PV0$`'0```"7:`0`>
M````0]H!`"H```!BV@$`A0```(W:`0`P````$]L!`"4```!$VP$`00```&K;
M`0!@````K-L!`%L````-W`$`20```&G<`0`Q````L]P!`#0```#EW`$`/```
M`!K=`0`X````5]T!`!T```"0W0$`&````*[=`0"G````Q]T!`"L```!OW@$`
M(0```)O>`0`?````O=X!`#P```#=W@$`)````!K?`0`H````/]\!`"L```!H
MWP$`(@```)3?`0`A````M]\!`",```#9WP$`)0```/W?`0`E````(^`!`"D`
M``!)X`$`)P```'/@`0`7````F^`!`"D```"SX`$`(````-W@`0`R````_N`!
M`!P````QX0$`+@```$[A`0`Z````?>$!`!T```"XX0$`$0```-;A`0`S````
MZ.$!`"4````<X@$`.````$+B`0`G````>^(!`"````"CX@$`/````,3B`0`F
M`````>,!`!\````HXP$`,````$CC`0!I````>>,!`"X```#CXP$`,0```!+D
M`0!!````1.0!`#X```"&Y`$`,P```,7D`0`E````^>0!`#T````?Y0$`90``
M`%WE`0!-````P^4!`%,````1Y@$`5P```&7F`0!5````O>8!`$8````3YP$`
M*@```%KG`0`O````A><!`%4```"UYP$`(`````OH`0`N````+.@!`"L```!;
MZ`$`,````(?H`0`J````N.@!`#X```#CZ`$`5````"+I`0!2````=^D!`%H`
M``#*Z0$`,@```"7J`0`K````6.H!`$@```"$Z@$`2@```,WJ`0`J````&.L!
M`"8```!#ZP$`+````&KK`0!.````E^L!`#(```#FZP$`,````!GL`0`=````
M2NP!`",```!H[`$`+P```(SL`0`L````O.P!`"T```#I[`$`<0```!?M`0!F
M````B>T!`&\```#P[0$`LP```&#N`0`7````%.\!`"4````L[P$`,@```%+O
M`0`I````A>\!`#X```"O[P$`(@```.[O`0!2````$?`!`"4```!D\`$`"P``
M`(KP`0"Q````EO`!`#L```!(\0$`)P```(3Q`0!.````K/$!`$<```#[\0$`
M8@```$/R`0!)````IO(!`%4```#P\@$`0````$;S`0`O````A_,!`#(```"W
M\P$`*P```.KS`0`I````%O0!``\```!`]`$`10```%#T`0`A````EO0!`#``
M``"X]`$`+0```.GT`0`E````%_4!`!P````]]0$`,0```%KU`0`Q````C/4!
M``X```"^]0$`"P```,WU`0`'````V?4!``<```#A]0$`!````.GU`0`-````
M[O4!``L```#\]0$`#@````CV`0`+````%_8!``4````C]@$`$````"GV`0`"
M````.O8!``H````]]@$`5@```$CV`0!9````G_8!`$X```#Y]@$`!0```$CW
M`0`2````3O<!``0```!A]P$`!P```&;W`0`(````;O<!``4```!W]P$``P``
M`'WW`0`0````@?<!`!<```"2]P$`#````*KW`0`,````M_<!``T```#$]P$`
M$P```-+W`0`-````YO<!``(```#T]P$`!P```/?W`0`&````__<!`!0````&
M^`$`#````!OX`0`8````*/@!``8```!!^`$`$@```$CX`0`,````6_@!``,`
M``!H^`$`*@```&SX`0`$````E_@!``8```"<^`$`!P```*/X`0`?````J_@!
M`#4```#+^`$`+@````'Y`0`O````,/D!`!<```!@^0$`(@```'CY`0`E````
MF_D!`"````#!^0$`&P```.+Y`0`8````_OD!`"0````7^@$`'P```#SZ`0`:
M````7/H!`"$```!W^@$`(````)GZ`0`:````NOH!`#(```#5^@$`&@````C[
M`0`O````(_L!`"L```!3^P$`'P```'_[`0`C````G_L!`!\```##^P$`&@``
M`./[`0`A````_OL!`"4````@_`$`)@```$;\`0`E````;?P!`"0```"3_`$`
M&````+C\`0`=````T?P!`"0```#O_`$`&````!3]`0`B````+?T!`"P```!0
M_0$`+P```'W]`0`5````K?T!`"4```##_0$`/````.G]`0`?````)OX!`",`
M``!&_@$`'P```&K^`0`@````BOX!`!H```"K_@$`&````,;^`0`8````W_X!
M`"8```#X_@$`'@```!__`0`I````/O\!`!X```!H_P$`,0```(?_`0`*````
MN?\!`!,```#$_P$`"````-C_`0`)````X?\!`!8```#K_P$`#`````(``@`7
M````#P`"`"\````G``(`)````%<``@`'````?``"`!\```"$``(`#P```*0`
M`@`4````M``"``X```#)``(`#0```-@``@`D````Y@`"``4````+`0(`!P``
M`!$!`@`,````&0$"`#L````F`0(`#P```&(!`@`1````<@$"`"(```"$`0(`
M)0```*<!`@`:````S0$"`!T```#H`0(`&@````8"`@`1````(0("``<````S
M`@(`QP```#L"`@`&`````P,"``L````*`P(`&@```!8#`@`5````,0,"``8`
M``!'`P(`"0```$X#`@`8````6`,"``L```!Q`P(`#0```'T#`@`7````BP,"
M``8```"C`P(`,P```*H#`@`3````W@,"`!,```#R`P(`!P````8$`@`/````
M#@0"`!$````>!`(`'@```#`$`@`'````3P0"`!D```!7!`(`,@```'$$`@`$
M````I`0"`$8```"I!`(`(0```/`$`@`3````$@4"``P````F!0(`$0```#,%
M`@`R````104"`!8```!X!0(`"````(\%`@`=````F`4"``D```"V!0(`"@``
M`,`%`@`4````RP4"``H```#@!0(`'0```.L%`@`(````"08"`!\````2!@(`
M"````#(&`@`:````.P8"`"<```!6!@(`!@```'X&`@`5````A08"``<```";
M!@(`"````*,&`@`)````K`8"`#\```"V!@(`!P```/8&`@`/````_@8"``X`
M```.!P(`$````!T'`@`)````+@<"``D````X!P(`"````$('`@`3````2P<"
M``0```!?!P(`!P```&0'`@`2````;`<"`"8```!_!P(`#0```*8'`@`9````
MM`<"`!@```#.!P(`"P```.<'`@`.````\P<"`!D````""`(`"@```!P(`@`D
M````)P@"`"$```!,"`(`"@```&X(`@`3````>0@"`"<```"-"`(`"0```+4(
M`@`/````OP@"`!<```#/"`(`%````.<(`@`H````_`@"`!X````E"0(`#P``
M`$0)`@`@````5`D"``T```!U"0(`%````(,)`@`-````F`D"`!0```"F"0(`
M)````+L)`@`4````X`D"``H```#U"0(`#``````*`@`7````#0H"``0````E
M"@(`*@```"H*`@`,````50H"`!$```!B"@(`!P```'0*`@`"````?`H"`!``
M``!_"@(`&````)`*`@`+````J0H"``,```"U"@(`"````+D*`@`&````P@H"
M``<```#)"@(`#0```-$*`@`+````WPH"`!0```#K"@(`%0`````+`@`.````
M%@L"`"\````E"P(`(````%4+`@`<````=@L"`%<```"3"P(`6@```.L+`@`_
M````1@P"`#8```"&#`(`?@```+T,`@`5````/`T"``P```!2#0(`,0```%\-
M`@`)````D0T"``4```";#0(`$@```*$-`@`_````M`T"`!(```#T#0(`"@``
M``<.`@`&````$@X"``0````9#@(`!````!X.`@`*````(PX"`!,````N#@(`
M!0```$(.`@`&````2`X"``8```!/#@(`"````%8.`@`$````7PX"``P```!D
M#@(`"@```'$.`@`Y````?`X"`"X```"V#@(`*0```.4.`@`%````#P\"`!@`
M```5#P(`&0```"X/`@`?````2`\"`!T```!H#P(`$0```(8/`@`"````F`\"
M``0```";#P(`"@```*`/`@`&````JP\"``4```"R#P(``P```+@/`@`,````
MO`\"`#L```#)#P(`3P````40`@`U````51`"`"<```"+$`(`(0```+,0`@`D
M````U1`"`$4```#Z$`(`)@```$`1`@`R````9Q$"`#,```":$0(`&@```,X1
M`@`=````Z1$"`'@````'$@(`-````(`2`@`A````M1("`%8```#7$@(`*```
M`"X3`@!3````5Q,"`#H```"K$P(`0@```.83`@`9````*10"`!<```!#%`(`
M)0```%L4`@`9````@10"`"H```";%`(`*P```,84`@!R````\A0"`"````!E
M%0(`-0```(85`@`A````O!4"`$4```#>%0(`)@```"06`@`P````2Q8"`$L`
M``!\%@(`3@```,@6`@`G````%Q<"`"D````_%P(`(0```&D7`@`H````BQ<"
M`"L```"T%P(`'0```.`7`@`I````_A<"`"8````H&`(`)0```$\8`@`H````
M=1@"`"@```">&`(`(@```,<8`@`Z````ZA@"`"L````E&0(`*0```%$9`@`B
M````>QD"`#T```">&0(`00```-P9`@`H````'AH"`"P```!'&@(`,````'0:
M`@`2````I1H"`!,```"X&@(`$````,P:`@!Y````W1H"``D```!7&P(`'```
M`&$;`@`0````?AL"``\```"/&P(`*P```)\;`@`G````RQL"``X```#S&P(`
M2P````(<`@"A````3AP"`',```#P'`(`?````&0=`@!`````X1T"`"L````B
M'@(`5````$X>`@`7````HQX"`"H```"['@(`-````.8>`@`G````&Q\"`!8`
M``!#'P(`#P```%H?`@"O````:A\"`!<````:(`(`*````#(@`@`?````6R`"
M`$````![(`(`'P```+P@`@`<````W"`"`%$```#Y(`(`&@```$LA`@`4````
M9B$"``\```![(0(`"@```(LA`@`%````EB$"``8```"<(0(`"````*,A`@`%
M````K"$"`!````"R(0(`$@```,,A`@`,````UB$"`!````#C(0(`$0```/0A
M`@`3````!B("`!T````:(@(`(````#@B`@`/````62("``\```!I(@(`!```
M`'DB`@`*````?B("``0```")(@(``P```(XB`@`)````DB("``<```"<(@(`
M"P```*0B`@`(````L"("``<```"Y(@(`!0```,$B`@`)````QR("`!0```#1
M(@(`!@```.8B`@`'````[2("``@```#U(@(`#P```/XB`@`/````#B,"``P`
M```>(P(`"````"LC`@`,````-","``8```!!(P(`"0```$@C`@`+````4B,"
M``\```!>(P(`!@```&XC`@`'````=2,"``T```!](P(`!@```(LC`@`4````
MDB,"``<```"G(P(``P```*\C`@`)````LR,"``8```"](P(`#````,0C`@`*
M````T2,"``P```#<(P(`$0```.DC`@`*````^R,"``\````&)`(`!0```!8D
M`@`(````'"0"``0````E)`(`&0```"HD`@`1````1"0"``H```!6)`(`&```
M`&$D`@`3````>B0"`!P```".)`(`$0```*LD`@`/````O20"``<```#-)`(`
M!````-4D`@`$````VB0"`!D```#?)`(`!P```/DD`@`"`````24"``(````$
M)0(`$0````<E`@`)````&24"``8````C)0(`$@```"HE`@`7````/24"``,`
M``!5)0(`!@```%DE`@`,````8"4"`"<```!M)0(``@```)4E`@`$````F"4"
M``0```"=)0(`#P```*(E`@`3````LB4"``<```#&)0(``@```,XE`@`'````
MT24"`!$```#9)0(`!@```.LE`@`+````\B4"`!@```#^)0(`!@```!<F`@`3
M````'B8"`!`````R)@(`$@```$,F`@`.````5B8"``\```!E)@(``@```'4F
M`@`&````>"8"``P```!_)@(`"0```(PF`@`1````EB8"`"(```"H)@(`!P``
M`,LF`@`'````TR8"``L```#;)@(`!0```.<F`@`"````[28"``L```#P)@(`
M#@```/PF`@`.````"R<"`'\!```:)P(`"@```)HH`@`*````I2@"``L```"P
M*`(`"@```+PH`@`2````QR@"`!H```#:*`(`$````/4H`@`.````!BD"``D`
M```5*0(`!P```!\I`@`)````)RD"``,````Q*0(`!@```#4I`@`;````/"D"
M`"$```!8*0(`-0```'HI`@`Q````L"D"`"L```#B*0(`+P````XJ`@`=````
M/BH"``<```!<*@(`&P```&0J`@`M````@"H"``L```"N*@(`"P```+HJ`@`R
M````QBH"`"````#Y*@(`;````!HK`@`_````ARL"`%P```#'*P(`+P```"0L
M`@`7````5"P"`!0```!L+`(`"P```($L`@`3````C2P"``4```"A+`(`,0``
M`*<L`@`0````V2P"`!$```#J+`(`'@```/PL`@`/````&RT"`#4````K+0(`
M"P```&$M`@`G````;2T"`"T```"5+0(`#0```,,M`@`3````T2T"``P```#E
M+0(`,@```/(M`@`F````)2X"`"0```!,+@(`'P```'$N`@"6````D2X"`!(`
M```H+P(`"@```#LO`@`-````1B\"`!X```!4+P(`(P```',O`@`-````ER\"
M`"(```"E+P(`'0```,@O`@`D````YB\"`#L````+,`(`%P```$<P`@`,````
M7S`"`!````!L,`(`%0```'TP`@`'````DS`"`!P```";,`(`G0```+@P`@`\
M````5C$"`#L```"3,0(`!0```,\Q`@`,````U3$"`($```#B,0(`@0```&0R
M`@`B````YC("`"T````),P(`#````#<S`@`,````1#,"`!0```!1,P(`$@``
M`&8S`@`9````>3,"`%<```"3,P(`.````.LS`@!1````)#0"`"D```!V-`(`
M#@```*`T`@`/````KS0"`!````"_-`(`$````-`T`@`)````X30"``X```#K
M-`(`#@```/HT`@`*````"34"`$0````4-0(`(````%DU`@`]````>C4"`%8`
M``"X-0(`/@````\V`@!-````3C8"`&X```"<-@(`:@````LW`@!T````=C<"
M`'````#K-P(`00```%PX`@`/````GC@"`!4```"N.`(`#@```,0X`@`0````
MTS@"`!@```#D.`(`!0```/TX`@`"`````SD"``8````&.0(`%P````TY`@`+
M````)3D"``H````Q.0(`#0```#PY`@`A````2CD"`!,```!L.0(`!P```(`Y
M`@`*````B#D"`#0```"3.0(`,````,@Y`@`4````^3D"`!8````..@(`#@``
M`"4Z`@`/````-#H"``<```!$.@(`!P```$PZ`@`'````5#H"`"(```!<.@(`
M%@```'\Z`@`D````ECH"``T```"[.@(`&0```,DZ`@`?````XSH"`!\````#
M.P(`)0```",[`@`?````23L"`!,```!I.P(`&P```'T[`@`1````F3L"`!(`
M``"K.P(`*````+X[`@`6````YSL"`!X```#^.P(`'P```!T\`@`4````/3P"
M`!8```!2/`(`'@```&D\`@!A````B#P"`#````#J/`(`,@```!L]`@!F````
M3CT"`#8```"U/0(`(P```.P]`@`F````$#X"`#8````W/@(`*P```&X^`@!*
M````FCX"``<```#E/@(`$0```.T^`@`2````_SX"`&@````2/P(`=P```'L_
M`@!#````\S\"``X````W0`(`!````$9``@`+````2T`"``<```!70`(`!P``
M`%]``@`%````9T`"``<```!M0`(`#````'5``@`$````@D`"`"(```"'0`(`
M$````*I``@`6````NT`"`!````#20`(`3P```.-``@!6````,T$"`%,```"*
M00(`4P```-Y!`@!5````,D("`",```"(0@(`50```*Q"`@`L`````D,"`#$`
M```O0P(`"P```&%#`@`A````;4,"`!P```"/0P(`(0```*Q#`@`?````SD,"
M``X```#N0P(`$@```/U#`@`I````$$0"``@````Z1`(`)P```$-$`@`/````
M:T0"`%H```![1`(`)````-9$`@`C````^T0"`$D````?10(`2@```&E%`@`'
M````M$4"``8```"\10(`"````,-%`@`-````S$4"``<```#:10(`!P```.)%
M`@`1````ZD4"``L```#\10(`$@````A&`@`+````&T8"`!0````G1@(`%P``
M`#Q&`@`5````5$8"`!P```!J1@(`+````(=&`@!`````M$8"`!L```#U1@(`
M"````!%'`@`4````&D<"``4````O1P(`%````#5'`@`9````2D<"`!````!D
M1P(`3P```'5'`@`\````Q4<"`%@````"2`(`)P```%M(`@!-````@T@"`$0`
M``#12`(`2@```!9)`@!!````84D"`"\```"C20(`/P```--)`@`T````$TH"
M`$(```!(2@(`00```(M*`@!%````S4H"``D````32P(`!P```!U+`@`4````
M)4L"`!(````Z2P(``P```$U+`@`%````44L"``D```!72P(`#P```&%+`@`)
M````<4L"`!4```![2P(`"````)%+`@!)````FDL"`!,```#D2P(`%````/A+
M`@`^````#4P"``X```!,3`(`2@```%M,`@`R````IDP"``P```#93`(`&@``
M`.9,`@`X`````4T"``X````Z30(`+@```$E-`@`U````>$T"`#<```"N30(`
M,@```.9-`@`(````&4X"``D````B3@(`"@```"Q.`@`$````-TX"``D````\
M3@(`"````$9.`@`P````3TX"`#<```"`3@(`+P```+A.`@!>````Z$X"`"\`
M``!'3P(`+@```'=/`@`O````ID\"`$L```#63P(`3@```")0`@`O````<5`"
M`%0```"A4`(`-````/90`@`W````*U$"`%<```!C40(`+P```+M1`@`U````
MZU$"`"P````A4@(`&P```$Y2`@`>````:E("`"X```")4@(`*P```+A2`@`K
M````Y%("`&X````04P(`(````']3`@`4````H%,"`!@```"U4P(`"P```,Y3
M`@`,````VE,"``T```#G4P(`#````/53`@`W`````E0"`!T````Z5`(`#P``
M`%A4`@`/````:%0"`!T```!X5`(`(0```)94`@`Y````N%0"``<```#R5`(`
M!P```/I4`@`3`````E4"``H````650(`!P```"%5`@`L````*54"``T```!6
M50(``P```&15`@`'````:%4"``@```!P50(`!@```'E5`@`^````@%4"``4`
M``"_50(`"````,55`@`'````SE4"``P```#650(`"P```.-5`@`J````[U4"
M`!,````:5@(`#````"Y6`@!`````.U8"``4```!\5@(`!````()6`@`'````
MAU8"``<```"/5@(`!P```)=6`@`9````GU8"``4```"Y5@(`$@```+]6`@`(
M````TE8"`$0```#;5@(`"````"!7`@`#````*5<"``8````M5P(`!@```#17
M`@`J````.U<"`!(```!F5P(`"````'E7`@`-````@E<"``P```"05P(`!P``
M`)U7`@`2````I5<"``,```"X5P(`00```+Q7`@`9````_E<"`!(````86`(`
M,````"M8`@`&````7%@"``4```!C6`(`"````&E8`@`(````<E@"`#0```![
M6`(`-@```+!8`@!G````YU@"`&0```!/60(`*@```+19`@`_````WUD"`"H`
M```?6@(`)@```$I:`@`&````<5H"``<```!X6@(`$@```(!:`@`>````DUH"
M`$8```"R6@(`*@```/E:`@`N````)%L"`#<```!36P(`+0```(M;`@`W````
MN5L"`&\```#Q6P(`,P```&%<`@`(````E5P"``<```">7`(`#````*9<`@`8
M````LUP"``L```#,7`(``@```-A<`@`4````VUP"`!@```#P7`(`(@````E=
M`@`8````+%T"`!H```!%70(`%0```&!=`@`3````=ET"``<```"*70(`&0``
M`))=`@`=````K%T"`!4```#*70(`&@```.!=`@`:````^UT"`&0````67@(`
M!0```'M>`@`)````@5X"``@```"+7@(`#````)1>`@`2````H5X"`!L```"T
M7@(`>P```-!>`@!!````3%\"`'(```".7P(`<@````%@`@!Y````=&`"``0`
M``#N8`(`%P```/-@`@`1````"V$"`#$````=80(`$P```$]A`@!#````8V$"
M`#,```"G80(`!0```-MA`@`%````X6$"`!H```#G80(`&P````)B`@`2````
M'F("`!<````Q8@(`(````$EB`@`^````:F("`!<```"I8@(`&P```,%B`@`G
M````W6("`#8````%8P(`30```#QC`@!6````BF,"``X```#A8P(`*@```/!C
M`@`'````&V0"`!X````C9`(`$@```$)D`@`9````560"`!4```!O9`(`)```
M`(5D`@`?````JF0"`%0```#*9`(`)````!]E`@`W````1&4"`$8```!\90(`
M,@```,-E`@!&````]F4"`$,````]9@(`(P```(%F`@!=````I68"`!<````#
M9P(`2@```!MG`@!0````9F<"`!,```"W9P(`00```,MG`@`X````#6@"``8`
M``!&:`(`$0```$UH`@`4````7V@"``T```!T:`(`!@```()H`@`/````B6@"
M``<```"9:`(`"@```*%H`@`'````K&@"``P```"T:`(`&0```,%H`@`2````
MVV@"`!@```#N:`(`$0````=I`@`(````&6D"``<````B:0(`&````"II`@`3
M````0VD"`!<```!7:0(`!@```&]I`@`1````=FD"``0```"(:0(`"````(UI
M`@`.````EFD"``L```"E:0(`"0```+%I`@`'````NVD"``<```##:0(`!P``
M`,MI`@`8````TVD"`"\```#L:0(`9@```!QJ`@`+````@VH"``D```"/:@(`
M"@```)EJ`@`<````I&H"`$D```#!:@(`(@````MK`@`-````+FL"`"0````\
M:P(`.````&%K`@`9````FFL"``4```"T:P(`(````+IK`@`E````VVL"`!4`
M```!;`(`&````!=L`@`M````,&P"`#\```!>;`(`)````)YL`@`@````PVP"
M``@```#D;`(`/````.UL`@`G````*FT"`!$```!2;0(`"@```&1M`@`B````
M;VT"`"4```"2;0(`+P```+AM`@!>````Z&T"`#````!';@(`"0```'AN`@`/
M````@FX"``8```"2;@(`%@```)EN`@`5````L&X"`!8```#&;@(`"````-UN
M`@`-````YFX"``@```#T;@(`"@```/UN`@`-````"&\"`"0````6;P(`)@``
M`#MO`@`N````8F\"`"<```"1;P(`(````+EO`@`E````VF\"`"0`````<`(`
M*@```"5P`@`V````4'`"`"4```"'<`(`-````*UP`@`P````XG`"`"8````3
M<0(`*P```#IQ`@`L````9G$"`",```"3<0(`,0```+=Q`@!%````Z7$"`#8`
M```O<@(`-@```&9R`@`T````G7("`$X```#2<@(`00```"%S`@`K````8W,"
M`#$```"/<P(`00```,%S`@`J`````W0"`"D````N=`(`0P```%AT`@`K````
MG'0"`!L```#(=`(`,0```.1T`@`G````%G4"`$D````^=0(`)P```(AU`@`:
M````L'4"`+,```#+=0(`'P```']V`@`J````GW8"`"X```#*=@(`,````/EV
M`@!-````*G<"`"T```!X=P(`,@```*9W`@`I````V7<"`"L````#>`(`.P``
M`"]X`@`[````:W@"`$````"G>`(`0@```.AX`@"R````*WD"`"<```#>>0(`
M(0````9Z`@`E````*'H"`#(```!.>@(`.0```(%Z`@!&````NWH"`$\````"
M>P(`#````%)[`@`$````7WL"``4```!D>P(`!0```&I[`@`0````<'L"``\`
M``"!>P(`&````)%[`@`7````JGL"``T```#">P(`*P```-![`@`F````_'L"
M`!`````C?`(`+````#1\`@`<````87P"`'T```!^?`(`'````/Q\`@`R````
M&7T"`!4```!,?0(`%P```&)]`@`9````>GT"``<```"4?0(`!````)Q]`@`2
M````H7T"`!$```"T?0(`#@```,9]`@`:````U7T"`!0```#P?0(`%@````5^
M`@`2````''X"`!4````O?@(`#0```$5^`@!3````4WX"`"L```"G?@(`.0``
M`--^`@`&````#7\"`!,````4?P(`!@```"A_`@`3````+W\"`!D```!#?P(`
M'0```%U_`@`2````>W\"``(```".?P(`20```)%_`@`+````VW\"``4```#G
M?P(`%@```.U_`@`0````!(`"``0````5@`(`$0```!J``@`4````+(`"``0`
M``!!@`(`%0```$:``@`(````7(`"`!````!E@`(`!P```':``@`*````?H`"
M`!8```")@`(`!@```*"``@`2````IX`"`!,```"Z@`(`'0```,Z``@`C````
M[(`"`!L````0@0(`&0```"R!`@`+````1H$"``<```!2@0(`"0```%J!`@`=
M````9($"`!(```""@0(`'0```)6!`@`9````LX$"`!,```#-@0(`$````.&!
M`@`8````\H$"`",````+@@(`%@```"^"`@`;````1H("`#(```!B@@(`(```
M`)6"`@`2````MH("`!(```#)@@(`(@```-R"`@`S````_X("`!<````S@P(`
M/0```$N#`@!$````B8,"`"4```#.@P(`10```/2#`@`1````.H0"`"$```!,
MA`(`%P```&Z$`@`;````AH0"`!H```"BA`(`"````+V$`@`2````QH0"`#<`
M``#9A`(`(````!&%`@`F````,H4"`!(```!9A0(`"````&R%`@`2````=84"
M`"D```"(A0(`"P```+*%`@`3````OH4"``L```#2A0(`!P```-Z%`@`T````
MYH4"`#0````;A@(`#0```%"&`@`.````7H8"`"@```!MA@(`$0```):&`@`[
M````J(8"`!D```#DA@(`$@```/Z&`@`2````$8<"``H````DAP(`"0```"^'
M`@`8````.8<"`!,```!2AP(`-@```&:'`@`?````G8<"`!L```"]AP(`$@``
M`-F'`@`A````[(<"`$H````.B`(`0````%F(`@`_````FH@"``L```#:B`(`
M$0```.:(`@`(````^(@"`!0````!B0(`,@```!:)`@`0````28D"`"P```!:
MB0(`+0```(>)`@`?````M8D"`&(```#5B0(`"0```#B*`@`6````0HH"`"T`
M``!9B@(`!P```(>*`@`+````CXH"``X```";B@(`'0```*J*`@`V````R(H"
M`!X```#_B@(`+````!Z+`@`X````2XL"`!H```"$BP(`"0```)^+`@`5````
MJ8L"`!<```"_BP(`$````->+`@`'````Z(L"`!4```#PBP(`%`````:,`@!)
M````&XP"``,```!EC`(``P```&F,`@`O````;8P"``@```"=C`(`"````*:,
M`@`5````KXP"``X```#%C`(`$@```-2,`@`0````YXP"`!4```#XC`(`%@``
M``Z-`@`B````)8T"`!@```!(C0(`,0```&&-`@`7````DXT"`!D```"KC0(`
M(@```,6-`@`>````Z(T"`!@````'C@(`&P```"".`@!#````/(X"`!H```"`
MC@(`"0```)N.`@`&````I8X"``@```"LC@(`"@```+6.`@`"````P(X"`!0`
M``##C@(`%````-B.`@`P````[8X"`!H````>CP(`&0```#F/`@`*````4X\"
M`"8```!>CP(`%@```(6/`@`?````G(\"`!(```"\CP(`#@```,^/`@`3````
MWH\"``T```#RCP(`#@````"0`@`8````#Y`"`"0````HD`(`)P```$V0`@!%
M````=9`"`"L```"[D`(`+P```.>0`@`7````%Y$"``<````OD0(``P```#>1
M`@`8````.Y$"``X```!4D0(`%````&.1`@`.````>)$"`!(```"'D0(`&```
M`)J1`@"@````LY$"`"8```!4D@(`'P```'N2`@`S````FY("`"X```#/D@(`
M-````/Z2`@`I````,Y,"``\```!=DP(`,````&V3`@`2````GI,"``@```"Q
MDP(`!@```+J3`@`M````P9,"`"<```#ODP(`0````!>4`@!`````6)0"`"X`
M``"9E`(`*@```,B4`@`R````\Y0"`!<````FE0(`*@```#Z5`@`'````:94"
M``@```!QE0(`"````'J5`@`&````@Y4"`"4```"*E0(`%0```+"5`@`4````
MQI4"`!8```#;E0(`%````/*5`@`2````!Y8"`!8````:E@(`$@```#&6`@`4
M````1)8"``@```!9E@(`"@```&*6`@`/````;98"`!P```!]E@(`%0```)J6
M`@`3````L)8"`!@```#$E@(`4@```-V6`@`M````,)<"`!$```!>EP(`#@``
M`'"7`@`S````?Y<"`!$```"SEP(`#````,67`@`4````TI<"`#H```#GEP(`
M&0```"*8`@`C````/)@"`"8```!@F`(`)0```(>8`@`@````K9@"`!\```#.
MF`(`+P```.Z8`@`A````'ID"`"(```!`F0(`!````&.9`@`9````:)D"``H`
M``""F0(`#P```(V9`@`#````G9D"``H```"AF0(`!P```*R9`@`5````M)D"
M`!@```#*F0(`&````..9`@`S````_)D"`"T````PF@(`)````%Z:`@`A````
M@YH"`!L```"EF@(`)0```,&:`@`0````YYH"`!@```#XF@(`"````!&;`@`2
M````&IL"``X````MFP(`&@```#R;`@`%````5YL"``<```!=FP(`%P```&6;
M`@`7````?9L"`!@```"5FP(`#@```*Z;`@`0````O9L"`!D```#.FP(`+0``
M`.B;`@`3````%IP"`!$````JG`(`(0```#R<`@`T````7IP"``<```"3G`(`
M$@```)N<`@`<````KIP"``@```#+G`(`"````-2<`@`.````W9P"`!D```#L
MG`(`#0````:=`@`0````%)T"``X````EG0(`"0```#2=`@`(````/IT"``H`
M``!'G0(`"@```%*=`@`6````79T"`"8```!TG0(`&````)N=`@`3````M)T"
M`"D```#(G0(`+````/*=`@`1````'YX"``H````QG@(`,0```#R>`@`/````
M;IX"`(0```!^G@(`)0````.?`@!;````*9\"``L```"%GP(`"````)&?`@`0
M````FI\"``D```"KGP(`"P```+6?`@`&````P9\"``D```#(GP(`"P```-*?
M`@`1````WI\"`!<```#PGP(`"P````B@`@`"````%*`"``8````7H`(`!@``
M`!Z@`@`5````):`"`"L````[H`(`$````&>@`@`3````>*`"`"L```",H`(`
M`P```+B@`@`"````O*`"``P```"_H`(``P```,R@`@`4````T*`"``L```#E
MH`(`"P```/&@`@`'````_:`"``@````%H0(`'@````ZA`@`%````+:$"`!H`
M```SH0(`!P```$ZA`@`&````5J$"`!$```!=H0(`'@```&^A`@`+````CJ$"
M``<```":H0(`"0```**A`@`X````K*$"``4```#EH0(`"0```.NA`@`&````
M]:$"``4```#\H0(`$`````*B`@`O````$Z("``8```!#H@(`#0```$JB`@`0
M````6*("`!````!IH@(`#@```'JB`@`%````B:("`!$```"/H@(`"0```*&B
M`@`'````JZ("`!H```"SH@(`+````,ZB`@!0````^Z("`#````!,HP(`,0``
M`'VC`@`'````KZ,"``H```"WHP(`!````,*C`@`)````QZ,"``D```#1HP(`
M%P```-NC`@`*````\Z,"``8```#^HP(`#0````6D`@`&````$Z0"``,````:
MI`(`!````!ZD`@`7````(Z0"`$8````[I`(`1````(*D`@!#````QZ0"`"(`
M```+I0(`!0```"ZE`@`5````-*4"``L```!*I0(`!P```%:E`@`(````7J4"
M`!8```!GI0(`#P```'ZE`@`5````CJ4"``<```"DI0(`!````*RE`@`3````
ML:4"``0```#%I0(`"@```,JE`@`;````U:4"`#4```#QI0(`!0```">F`@`D
M````+:8"`!L```!2I@(`$P```&ZF`@`%````@J8"``\```"(I@(`#@```)BF
M`@`(````IZ8"``\```"PI@(`!P```,"F`@`3````R*8"`!0```#<I@(`$P``
M`/&F`@`(````!:<"``D````.IP(`!0```!BG`@!$````'J<"`#4```!CIP(`
M/@```)FG`@`L````V*<"`$L````%J`(`10```%&H`@`Q````EZ@"`%(```#)
MJ`(`-P```!RI`@`Z````5*D"`"0```"/J0(`$0```+2I`@`6````QJD"``P`
M``#=J0(`,P```.JI`@`Q````'JH"`"L```!0J@(`)P```'RJ`@`J````I*H"
M`#````#/J@(`"`````"K`@`+````":L"``H````5JP(`!P```""K`@`$````
M**L"`"X````MJP(`/P```%RK`@`O````G*L"`#(```#,JP(`.0```/^K`@`,
M````.:P"`"$```!&K`(`(````&BL`@`E````B:P"``X```"OK`(`'@```+ZL
M`@`2````W:P"``H```#PK`(`&@```/NL`@`D````%JT"`!@````[K0(`%0``
M`%2M`@`'````:JT"`!````!RK0(`#@```(.M`@`1````DJT"``\```"DK0(`
M30```+2M`@!-`````JX"`$@```!0K@(`BP```)FN`@!W````):\"``<```"=
MKP(`#````*6O`@`%````LJ\"`!,```"XKP(`%@```,RO`@`8````XZ\"`!``
M``#\KP(`$@````VP`@`7````(+`"``8````XL`(`"````#^P`@`0````2+`"
M`!H```!9L`(`%0```'2P`@`4````BK`"`"````"?L`(`*0```,"P`@`K````
MZK`"`"H````6L0(`&0```$&Q`@`=````6[$"`"````!YL0(`%P```)JQ`@`8
M````LK$"`#(```#+L0(`%0```/ZQ`@`0````%+("`!,````EL@(`)````#FR
M`@`2````7K("`!$```!QL@(`"````(.R`@`5````C+("`!(```"BL@(`-P``
M`+6R`@`P````[;("`!@````>LP(`-0```#>S`@!X````;;,"`!<```#FLP(`
M!````/ZS`@`8`````[0"``D````<M`(`!````":T`@`,````*[0"`"0````X
MM`(`(P```%VT`@`J````@;0"`"P```"LM`(`"@```-FT`@`6````Y+0"`!D`
M``#[M`(`#0```!6U`@`L````([4"`"X```!0M0(`(````'^U`@`2````H+4"
M`!,```"SM0(`%@```,>U`@`V````WK4"`#8````5M@(`-````$RV`@`T````
M@;8"`#````"VM@(`,````.>V`@`7````&+<"`%0````PMP(`%0```(6W`@`5
M````F[<"`!4```"QMP(`%0```,>W`@`4````W;<"`!@```#RMP(`&`````NX
M`@`4````)+@"`!0````YN`(`,````$ZX`@`:````?[@"`!P```":N`(`.P``
M`+>X`@`3````\[@"``8````'N0(`#@````ZY`@`R````';D"`!````!0N0(`
M%P```&&Y`@`?````>;D"`!0```"9N0(`%0```*ZY`@`3````Q+D"`#,```#8
MN0(`&P````RZ`@`@````*+H"`!L```!)N@(`#0```&6Z`@`9````<[H"`!T`
M``"-N@(`%````*NZ`@`>````P+H"`"(```#?N@(`%`````*[`@`;````%[L"
M`"4````SNP(`)P```%F[`@`9````@;L"`!,```";NP(`'@```*^[`@`9````
MSKL"`!@```#HNP(`&`````&\`@`*````&KP"``@````EO`(`%0```"Z\`@`$
M````1+P"``0```!)O`(`!P```$Z\`@`*````5KP"`!````!AO`(`!@```'*\
M`@`(````>;P"``@```""O`(`!@```(N\`@`(````DKP"``<```";O`(`!0``
M`*.\`@`6````J;P"``8```#`O`(`"````,>\`@`'````T+P"``0```#8O`(`
M"0```-V\`@`'````Y[P"``D```#OO`(`$````/F\`@`0````"KT"``(````;
MO0(`"@```!Z]`@`3````*;T"``4````]O0(`,````$.]`@`2````=+T"`!``
M``"'O0(`%````)B]`@`3````K;T"``P```#!O0(`%@```,Z]`@`V````Y;T"
M`$H````<O@(`6````&>^`@!K````P+X"`#8````LOP(`!P```&._`@`(````
M:[\"``T```!TOP(`#````(*_`@`/````C[\"``8```"?OP(`#````*:_`@`-
M````L[\"``8```#!OP(`!````,B_`@`.````S;\"`!D```#<OP(`#0```/:_
M`@`E````!,`"`!`````JP`(`%@```#O``@`7````4L`"`"8```!JP`(`&P``
M`)'``@`(````K<`"``,```"VP`(`#````+K``@`I````Q\`"``4```#QP`(`
M!@```/?``@`-````_L`"`!$````,P0(`!P```![!`@`&````)L$"``<````M
MP0(`!0```#7!`@`-````.\$"``T```!)P0(`#````%?!`@`@````9,$"`!$`
M``"%P0(`#P```)?!`@`:````I\$"`!,```#"P0(`%@```-;!`@`%````[<$"
M``0```#SP0(`&0```/C!`@`5````$L("`$P````HP@(`+@```'7"`@`%````
MI,("`!H```"JP@(`#0```,7"`@`H````T\("`!H```#\P@(`#P```!?#`@`3
M````)\,"`(<````[PP(`%````,/#`@`0````V,,"``\```#IPP(`&````/G#
M`@`0````$L0"`!4````CQ`(`&0```#G$`@`7````4\0"`",```!KQ`(`)P``
M`(_$`@`W````M\0"``L```#OQ`(`"````/O$`@`-````!,4"``X````2Q0(`
M#P```"'%`@`/````,<4"``0```!!Q0(`"0```$;%`@`.````4,4"`"\```!?
MQ0(`"P```(_%`@`1````F\4"`!,```"MQ0(`:P```,'%`@`3````+<8"``H`
M``!!Q@(`!0```$S&`@`&````4L8"``\```!9Q@(`&@```&G&`@`9````A,8"
M`!D```">Q@(`#0```+C&`@`*````QL8"``(```#1Q@(`%@```-3&`@`S````
MZ\8"``,````?QP(`!0```"/'`@`7````*<<"`!$```!!QP(`"@```%/'`@`%
M````7L<"``@```!DQP(`&@```&W'`@`>````B,<"`"4```"GQP(`$0```,W'
M`@`_````W\<"``X````?R`(`!@```"[(`@`(````-<@"``@````^R`(`!```
M`$?(`@`%````3,@"`$H```!2R`(`#P```)W(`@`2````K<@"`!T```#`R`(`
M!````-[(`@`%````X\@"`"X```#IR`(`,@```!C)`@`/````2\D"`$(```!;
MR0(`,0```)[)`@`C````T,D"`"4```#TR0(`.0```!K*`@`-````5,H"``H`
M``!BR@(`(````&W*`@`J````CLH"`!$```"YR@(`"@```,O*`@`+````ULH"
M`!8```#BR@(`&P```/G*`@`O````%<L"`"X```!%RP(`(@```'3+`@`:````
ME\L"`"(```"RRP(`$````-7+`@`I````YLL"`#,````0S`(``P```$3,`@`'
M````2,P"``H```!0S`(`!P```%O,`@`6````8\P"``X```!ZS`(`%@```(G,
M`@`'````H,P"`!0```"HS`(`#P```+W,`@`2````S<P"`!4```#@S`(`$0``
M`/;,`@`1````",T"`%H````:S0(`%P```'7-`@`/````C<T"`!4```"=S0(`
M$P```+/-`@`-````Q\T"`!\```#5S0(`%@```/7-`@`4````#,X"`!4````A
MS@(`'P```#?.`@`P````5\X"`!T```"(S@(`#P```*;.`@`R````MLX"``H`
M``#IS@(`"P```/3.`@`G`````,\"`%T````HSP(`&P```(;/`@`'````HL\"
M`",```"JSP(`*0```,[/`@`(````^,\"``<````!T`(`&P````G0`@`&````
M)=`"``D````LT`(`+@```#;0`@`M````9=`"`#<```"3T`(`!@```,O0`@`&
M````TM`"`"P```#9T`(`9@````;1`@`7````;=$"`"0```"%T0(`%P```*K1
M`@`"````PM$"`!$```#%T0(`!@```-?1`@`4````WM$"``@```#ST0(`#@``
M`/S1`@`&````"]("``@````2T@(`!@```!O2`@`(````(M("``T````KT@(`
M#0```#G2`@`*````1]("`!$```!2T@(`.P```&32`@`Q````H-("``4```#2
MT@(`%P```-C2`@`4````\-("`!<````%TP(`"````!W3`@`+````)M,"`!$`
M```RTP(`$0```$33`@`,````5M,"``L```!CTP(`8P```&_3`@`/````T],"
M``P```#CTP(`"@```/#3`@`@````^],"`!4````<U`(`%0```#+4`@`@````
M2-0"`!(```!IU`(`%0```'S4`@`8````DM0"``L```"KU`(`&P```+?4`@`(
M````T]0"`!4```#<U`(`!0```/+4`@`$````^-0"``,```#]U`(`,`````'5
M`@`'````,M4"``4````ZU0(`$````$#5`@`%````4=4"``@```!7U0(`%@``
M`&#5`@`7````=]4"`"0```"/U0(`(P```+35`@`>````V-4"`!H```#WU0(`
M&P```!+6`@`B````+M8"`!L```!1U@(`!@```&W6`@`&````=-8"`"@```![
MU@(`!P```*36`@`2````K-8"`!(```"_U@(`#P```-+6`@`0````XM8"``\`
M``#SU@(`%P````/7`@`-````&]<"`"4````IUP(`$````$_7`@`1````8-<"
M`!0```!RUP(`)P```(?7`@`E````K]<"`!D```#5UP(`"0```._7`@`&````
M^=<"``<`````V`(`$@````C8`@`/````&]@"``T````KV`(`$0```#G8`@`(
M````2]@"``D```!4V`(`!0```%[8`@`'````9-@"``0```!LV`(`!````''8
M`@`#````=M@"`!<```!ZV`(`$0```)+8`@`9````I-@"``\```"^V`(`*@``
M`,[8`@`C````^=@"`!@````=V0(`'````#;9`@`E````4]D"`!P```!YV0(`
M2````);9`@`V````W]D"`"4````6V@(`*@```#S:`@!!````9]H"``P```"I
MV@(`0````+;:`@`V````]]H"`#D````NVP(`.0```&C;`@`^````HML"`!@`
M``#AVP(`&P```/K;`@`W````%MP"`!0```!.W`(`(@```&/<`@`W````AMP"
M`!8```"^W`(`)P```-7<`@`G````_=P"`!,````EW0(`'````#G=`@`@````
M5MT"`"4```!WW0(`%````)W=`@`N````LMT"`!,```#AW0(`%@```/7=`@`:
M````#-X"`#L````GW@(`.P```&/>`@`_````G]X"`#0```#?W@(`.P```!3?
M`@`X````4-\"`'L```")WP(`'@````7@`@`H````).`"`"H```!-X`(`*@``
M`'C@`@!.````H^`"`!@```#RX`(`#0````OA`@`:````&>$"``P````TX0(`
M*P```$'A`@`;````;>$"`!(```")X0(`$0```)SA`@!!````KN$"`#@```#P
MX0(`&P```"GB`@`S````1>("`"H```!YX@(`#0```*3B`@!3````LN("`$P`
M```&XP(`#P```%/C`@`%````8^,"`!X```!IXP(`%@```(CC`@`+````G^,"
M``8```"KXP(`#P```++C`@`6````PN,"``<```#9XP(`"0```.'C`@`)````
MZ^,"``P```#UXP(`%@````+D`@`-````&>0"``T````GY`(`#@```#7D`@`7
M````1.0"`!8```!<Y`(`#P```'/D`@`7````@^0"``<```";Y`(`$P```*/D
M`@`L````M^0"``4```#DY`(`!````.KD`@`F````[^0"`#P````6Y0(`"```
M`%/E`@`&````7.4"`!0```!CY0(`$@```'CE`@!1````B^4"`%$```#=Y0(`
M$0```"_F`@!$````0>8"``(```"&Y@(``@```(GF`@`%````C.8"`!````"2
MY@(`!0```*/F`@`'````J>8"`!4```"QY@(`!@```,?F`@`]````SN8"`!``
M```,YP(`$P```!WG`@`C````,><"`$,```!5YP(`!````)GG`@`X````GN<"
M`#L```#7YP(`)@```!/H`@`F````.N@"`$$```!AZ`(`70```*/H`@`2````
M`>D"`"`````4Z0(`30```#7I`@`.````@^D"`"H```"2Z0(`%@```+WI`@`6
M````U.D"``<```#KZ0(`#P```//I`@`/`````^H"``P````3Z@(`%P```"#J
M`@`,````..H"`!T```!%Z@(`&P```&/J`@`%````?^H"`!,```"%Z@(`&@``
M`)GJ`@`.````M.H"``\```##Z@(`&P```-/J`@`L````[^H"`!$````<ZP(`
M`P```"[K`@`7````,NL"`!P```!*ZP(`%0```&?K`@`-````?>L"`$X```"+
MZP(`#@```-KK`@`?````Z>L"`%4````)[`(`$0```%_L`@`<````<>P"`#<`
M``".[`(`-````,;L`@`=````^^P"`!H````9[0(`(P```#3M`@`=````6.T"
M`"8```!V[0(`*````)WM`@`O````QNT"`&0```#V[0(`7@```%ON`@"A````
MNNX"``@```!<[P(`$````&7O`@`9````=N\"`!0```"0[P(`$@```*7O`@`<
M````N.\"`!,```#5[P(`$P```.GO`@`$````_>\"`"X````"\`(`#````#'P
M`@`A````/O`"`"````!@\`(`#@```('P`@`7````D/`"`!$```"H\`(`"P``
M`+KP`@`-````QO`"`",```#4\`(`(P```/CP`@`(````'/$"``4````E\0(`
M'0```"OQ`@`&````2?$"`!D```!0\0(`"````&KQ`@`)````<_$"`!4```!]
M\0(`#@```)/Q`@`:````HO$"`"<```"]\0(`$````.7Q`@`G````]O$"`!X`
M```>\@(`#````#WR`@`D````2O("`!8```!O\@(`,P```(;R`@`>````NO("
M``X```#9\@(`#P```.CR`@`J````^/("``8````C\P(`'P```"KS`@`&````
M2O,"`!H```!1\P(`"0```&SS`@`+````=O,"`"<```""\P(`.````*KS`@`*
M````X_,"`"D```#N\P(`$@```!CT`@`+````*_0"`!X````W]`(`.P```%;T
M`@`)````DO0"`!0```"<]`(`.````+'T`@`Q````ZO0"`"T````<]0(`-```
M`$KU`@`%````?_4"``<```"%]0(`"P```(WU`@`)````F?4"``8```"C]0(`
M"````*KU`@`&````L_4"`$````"Z]0(`'0```/OU`@`*````&?8"`.(````D
M]@(`'`````?W`@`M````)/<"`#$```!2]P(`)0```(3W`@`S````JO<"`#``
M``#>]P(`)@````_X`@!'````-O@"`"$```!^^`(`*P```*#X`@`@````S/@"
M`(@```#M^`(`BP```';Y`@"(`0```OH"`"<```"+^P(`(P```+/[`@`^````
MU_L"`"@````6_`(`7````#_\`@`U````G/P"`#X```#2_`(`-P```!']`@`]
M````2?T"`#@```"'_0(`,````,#]`@`'````\?T"``D```#Y_0(`"`````/^
M`@`(````#/X"`!<````5_@(`%@```"W^`@`L````1/X"`!(```!Q_@(`,@``
M`(3^`@`N````M_X"`!D```#F_@(`*@````#_`@`P````*_\"`#H```!<_P(`
M"````)?_`@`?````H/\"``L```#`_P(`$0```,S_`@`K````WO\"`!$````*
M``,`#P```!P``P`3````+``#``@```!```,`%````$D``P`(````7@`#``L`
M``!G``,`'@```',``P`(````D@`#`!<```";``,`!P```+,``P!%````NP`#
M`$4````!`0,`"P```$<!`P`+````4P$#``T```!?`0,`&P```&T!`P`A````
MB0$#`#8```"K`0,`/````.(!`P`*````'P(#`!`````J`@,`&P```#L"`P`6
M````5P(#`#,```!N`@,`/@```*("`P`N````X0(#`"D````0`P,`*````#H#
M`P`%````8P,#``<```!I`P,`!0```'$#`P`K````=P,#`"8```"C`P,`'0``
M`,H#`P`,````Z`,#`!L```#U`P,`#P```!$$`P`%````(00#`!(````G!`,`
M&@```#H$`P`'````500#``X```!=!`,`$````&P$`P`3````?00#``0```"1
M!`,`!````)8$`P`,````FP0#`!X```"H!`,`6@```,<$`P`(````(@4#``L`
M```K!0,`"P```#<%`P`*````0P4#``D```!.!0,`%````%@%`P`4````;04#
M`!@```""!0,`'P```)L%`P`*````NP4#`"L```#&!0,`)0```/(%`P`@````
M&`8#`!8````Y!@,`%@```%`&`P`*````9P8#``D```!R!@,`"0```'P&`P`?
M````A@8#`"````"F!@,`$````,<&`P`1````V`8#`"X```#J!@,`!P```!D'
M`P`/````(0<#`!H````Q!P,`$@```$P'`P`4````7P<#`!````!T!P,`00``
M`(4'`P`1````QP<#``H```#9!P,`'````.0'`P`5`````0@#`!H````7"`,`
M&0```#((`P`[````3`@#`$<```"("`,`%````-`(`P`/````Y0@#``@```#U
M"`,`$````/X(`P`/````#PD#`!$````?"0,`$P```#$)`P`5````10D#`!``
M``!;"0,`)````&P)`P`V````D0D#`"L```#("0,`"@```/0)`P`-````_PD#
M``H````-"@,`$0```!@*`P`7````*@H#`!X```!""@,`.0```&$*`P`A````
MFPH#`!L```"]"@,`(P```-D*`P!,````_0H#`%````!*"P,`20```)L+`P`1
M````Y0L#`!D```#W"P,``P```!$,`P`=````%0P#`"(````S#`,`*0```%8,
M`P`=````@`P#``D```">#`,`"0```*@,`P`7````L@P#`"<```#*#`,`)P``
M`/(,`P`2````&@T#`&,````M#0,`(0```)$-`P`'````LPT#`"4```"[#0,`
M'@```.$-`P`*``````X#``8````+#@,`$````!(.`P`1````(PX#`!P````U
M#@,`!````%(.`P`(````5PX#``L```!@#@,`$````&P.`P`0````?0X#`!<`
M``".#@,`%P```*8.`P`)````O@X#``8```#(#@,`0````,\.`P`T````$`\#
M`#,```!%#P,`!@```'D/`P`&````@`\#``8```"'#P,`!@```(X/`P`=````
ME0\#`!T```"S#P,`%@```-$/`P`0````Z`\#`%$```#Y#P,`#@```$L0`P`B
M````6A`#`%P```!]$`,`-P```-H0`P`J````$A$#`"`````]$0,`/````%X1
M`P`;````FQ$#`"0```"W$0,`,@```-P1`P!A````#Q(#`&<```!Q$@,`:0``
M`-D2`P"R````0Q,#`"P```#V$P,`#@```",4`P`$````,A0#`!`````W%`,`
M)````$@4`P`#````;10#``8```!Q%`,`$0```'@4`P`&````BA0#``(```"1
M%`,`'````)04`P`1````L10#``T```##%`,`&@```-$4`P`,````[!0#`!@`
M``#Y%`,`'P```!(5`P`2````,A4#`!(```!%%0,`"P```%@5`P`4````9!4#
M`!4```!Y%0,`#P```(\5`P`+````GQ4#`!(```"K%0,`#@```+X5`P!0````
MS14#`!@````>%@,`$P```#<6`P`C````2Q8#`!<```!O%@,`&````(<6`P`9
M````H!8#`!````"Z%@,`,````,L6`P!H````_!8#`$\```!E%P,`,````+47
M`P`@````YA<#`"(````'&`,`/P```"H8`P!"````:A@#``T```"M&`,`!P``
M`+L8`P`)````PQ@#``P```#-&`,`%````-H8`P`4````[Q@#`!D````$&0,`
M!@```!X9`P`,````)1D#`!P````R&0,`%P```$\9`P`5````9QD#`!,```!]
M&0,`(````)$9`P`D````LAD#`!<```#7&0,`'````.\9`P`E````#!H#`%<`
M```R&@,`$0```(H:`P`O````G!H#`$X```#,&@,`%@```!L;`P`3````,AL#
M``4```!&&P,`D````$P;`P`D````W1L#`"`````"'`,`-0```",<`P`Q````
M61P#`"L```"+'`,`)````+<<`P`C````W!P#`"0`````'0,`)0```"4=`P`D
M````2QT#`"$```!P'0,`(0```)(=`P`E````M!T#`!(```#:'0,`'0```.T=
M`P`+````"QX#`$`````7'@,`!P```%@>`P`(````8!X#`!H```!I'@,`'```
M`(0>`P`)````H1X#`!0```"K'@,`#P```,`>`P`'````T!X#`"0```#8'@,`
M-P```/T>`P`)````-1\#`!L````_'P,`%@```%L?`P`(````<A\#``P```![
M'P,`:@```(@?`P!-````\Q\#`$````!!(`,`0@```((@`P!*````Q2`#`(``
M```0(0,`#0```)$A`P`Q````GR$#`#$```#1(0,`"@````,B`P`5````#B(#
M`"$````D(@,`/0```$8B`P`%````A"(#``8```"*(@,`10```)$B`P"-````
MUR(#`$P```!E(P,`3@```+(C`P!'`````20#``@```!))`,`&0```%(D`P`;
M````;"0#`!P```"()`,`)P```*4D`P`R````S20#`#D`````)0,`&0```#HE
M`P!*````5"4#`&8```"?)0,`-0````8F`P`L````/"8#`"@```!I)@,`%```
M`)(F`P`P````IR8#`#<```#8)@,`)P```!`G`P`>````."<#`$,```!7)P,`
M$@```)LG`P`M````KB<#`#<```#<)P,`1````!0H`P`T````62@#`#<```".
M*`,`-@```,8H`P`;````_2@#``<````9*0,`&P```"$I`P`7````/2D#`!4`
M``!5*0,`!P```&LI`P`)````<RD#`#0```!]*0,`!P```+(I`P`,````NBD#
M``H```#'*0,`"0```-(I`P`7````W"D#``4```#T*0,`"0```/HI`P`&````
M!"H#`!8````+*@,`"0```"(J`P`(````+"H#``4````U*@,`#P```#LJ`P`0
M````2RH#`"0```!<*@,`(````($J`P`3````HBH#`#0```"V*@,`#````.LJ
M`P`'````^"H#`!(`````*P,`$P```!,K`P`1````)RL#`",````Y*P,`'@``
M`%TK`P`2````?"L#`!D```"/*P,`(P```*DK`P`;````S2L#``X```#I*P,`
M#@```/@K`P`9````!RP#`"8````A+`,`#@```$@L`P`@````5RP#`#8```!X
M+`,`"````*\L`P`*````N"P#`!D```##+`,`!P```-TL`P`(````Y2P#`!8`
M``#N+`,`$P````4M`P`3````&2T#`#H````M+0,`'0```&@M`P`:````ABT#
M`"8```"A+0,`-@```,@M`P`2````_RT#`!(````2+@,`$0```"4N`P`&````
M-RX#``D````^+@,`"````$@N`P`)````42X#``4```!;+@,`#@```&$N`P`0
M````<"X#``D```"!+@,`%0```(LN`P`3````H2X#``L```"U+@,`!@```,$N
M`P`4````R"X#``,```#=+@,`!0```.$N`P`0````YRX#`!<```#X+@,`'P``
M`!`O`P`>````,"\#``L```!/+P,``@```%LO`P`&````7B\#`"$```!E+P,`
M!0```(<O`P`+````C2\#``<```"9+P,`<@```*$O`P`:````%#`#``8````O
M,`,`!@```#8P`P`<````/3`#`$8```!:,`,`'@```*$P`P`<````P#`#`%L`
M``#=,`,`.P```#DQ`P!/````=3$#`"````#%,0,`%0```.8Q`P`&````_#$#
M``L````#,@,`"`````\R`P`/````&#(#`!$````H,@,`"@```#HR`P`/````
M13(#`!<```!5,@,`$0```&TR`P`1````?S(#`!0```"1,@,`"````*8R`P`*
M````KS(#`!T```"Z,@,`#@```-@R`P`:````YS(#``D````",P,`!0````PS
M`P`B````$C,#`"(````U,P,`*````%@S`P`&````@3,#`",```"(,P,`!@``
M`*PS`P`N````LS,#``4```#B,P,`!@```.@S`P`-````[S,#``8```#],P,`
M#P````0T`P`+````%#0#``<````@-`,`%0```"@T`P`2````/C0#`!4```!1
M-`,`!@```&<T`P`9````;C0#``H```"(-`,`"````),T`P`'````G#0#``8`
M``"D-`,`!@```*LT`P`3````LC0#`"4```#&-`,`"P```.PT`P`.````^#0#
M`"@````'-0,`&````#`U`P`:````234#``P```!D-0,`(0```'$U`P`8````
MDS4#`$````"L-0,`!0```.TU`P`*````\S4#`!,```#^-0,`#0```!(V`P`"
M````(#8#``X````C-@,`"0```#(V`P`E````/#8#`#4```!B-@,`.@```)@V
M`P"$````TS8#`"L```!8-P,`(@```(0W`P`V````IS<#`#@```#>-P,`+```
M`!<X`P`@````1#@#`"(```!E.`,`9P```(@X`P`D````\#@#`!L````5.0,`
M*````#$Y`P"%````6CD#`&````#@.0,`.````$$Z`P`O````>CH#`#$```"J
M.@,`2@```-PZ`P!*````)SL#`%D```!R.P,`+P```,P[`P`U````_#L#`#$`
M```R/`,`+P```&0\`P`K````E#P#`"L```#`/`,`,0```.P\`P`O````'CT#
M`"8```!./0,`'0```'4]`P">````DST#`#X````R/@,`2@```'$^`P`Y````
MO#X#`#P```#V/@,`(@```#,_`P`E````5C\#`"\```!\/P,`/0```*P_`P`T
M````ZC\#`"("```?0`,`(P```$)"`P"%````9D(#`%0```#L0@,`&````$%#
M`P!*````6D,#`#4```"E0P,`-P```-M#`P`L````$T0#`!H```!`1`,`/@``
M`%M$`P`U````FD0#`!H```#01`,`&0```.M$`P`J````!44#`($````P10,`
M,P```+)%`P`O````YD4#`$`````61@,`B````%=&`P!:````X$8#`%`````[
M1P,`.0```(Q'`P`S````QD<#`$$```#Z1P,`1````#Q(`P`C````@4@#`!<`
M``"E2`,`E0```+U(`P`L````4TD#`"$```"`20,`(P```*))`P!!````QDD#
M`",````(2@,`(@```"Q*`P`S````3TH#`"````"#2@,`'P```*1*`P`F````
MQ$H#`"0```#K2@,`)@```!!+`P`M````-TL#`"H```!E2P,`$````)!+`P`J
M````H4L#`!D```#,2P,`,P```.9+`P`:````&DP#`#$````U3`,`-@```&=,
M`P`;````GDP#`!$```"Z3`,`5````,Q,`P`K````(4T#`#X```!-30,`+0``
M`(Q-`P`G````NDT#`#D```#B30,`*````!Q.`P`B````14X#`"T```!H3@,`
M60```)9.`P`J````\$X#`#4````;3P,`5````%%/`P!%````ID\#`#H```#L
M3P,`/````"=0`P!.````9%`#`&\```"S4`,`6````"-1`P!>````?%$#`&``
M``#;40,`90```#Q2`P!6````HE(#`$(```#Y4@,`.P```#Q3`P!K````>%,#
M`#0```#D4P,`2@```!E4`P!!````9%0#`$D```"F5`,`00```/!4`P!)````
M,E4#`&L```!\50,`9````.A5`P!U````358#`#X```##5@,`-P````)7`P!I
M````.E<#`&8```"D5P,`0@````M8`P`E````3E@#`"\```!T6`,`7@```*18
M`P`_`````UD#`#````!#60,`)P```'19`P`J````G%D#`"T```#'60,`+```
M`/59`P`P````(EH#`'<```!36@,`9@```,M:`P!U````,EL#`,````"H6P,`
M&0```&E<`P`J````@UP#`#T```"N7`,`,@```.Q<`P!2````'UT#`"0```!R
M70,`6P```)==`P`@````\UT#``D````47@,`O0```!Y>`P!6````W%X#`"D`
M```S7P,`3P```%U?`P!"````K5\#`'8```#P7P,`1@```&=@`P!(````KF`#
M`#P```#W8`,`,P```#1A`P`V````:&$#`"H```"?80,`(@```,IA`P`,````
M[6$#`$H```#Z80,`(P```$5B`P`]````:6(#`#,```"G8@,`)@```-MB`P`A
M`````F,#`#\````D8P,`/@```&1C`P`7````HV,#`!8```"[8P,`"````-)C
M`P`'````VV,#``4```#C8P,`#0```.EC`P`.````]V,#`!0````&9`,`#@``
M`!MD`P`%````*F0#`!,````P9`,``0```$1D`P`7````1F0#`',```!>9`,`
M>0```-)D`P!9````3&4#``L```"F90,`$P```+)E`P`$````QF4#``<```#+
M90,`!@```--E`P`%````VF4#``0```#@90,`%````.5E`P`B````^F4#``L`
M```=9@,`"0```"EF`P`+````,V8#`!$````_9@,`#````%%F`P`"````7F8#
M``<```!A9@,`!P```&EF`P`1````<68#``P```"#9@,`%P```)!F`P`&````
MJ&8#`!4```"O9@,`#````,5F`P`#````TF8#`"T```#69@,`!`````1G`P`'
M````"6<#``<````19P,`*0```!EG`P!&````0V<#`$(```"*9P,`00```,UG
M`P`>````#V@#`#8````N:`,`.0```&5H`P`D````GV@#`!L```#$:`,`)```
M`.!H`P`M````!6D#`"8````S:0,`(P```%II`P`M````?FD#`"D```"L:0,`
M+@```-9I`P`\````!6H#`"8```!":@,`-P```&EJ`P`P````H6H#`"D```#2
M:@,`+P```/QJ`P`M````+&L#`"8```!::P,`,````(%K`P`J````LFL#`"P`
M``#=:P,`+P````IL`P`J````.FP#`"8```!E;`,`*@```(QL`P`O````MVP#
M`",```#G;`,`+0````MM`P`X````.6T#`#L```!R;0,`(````*YM`P`L````
MSVT#`#X```#\;0,`*0```#MN`P`N````96X#`"T```"4;@,`+````,)N`P`F
M````[VX#`"`````6;P,`(````#=O`P`H````6&\#`"H```"!;P,`0P```*QO
M`P`O````\&\#`#P````@<`,`#````%UP`P`6````:G`#``D```"!<`,`"0``
M`(MP`P`4````E7`#`!<```"J<`,`'````,)P`P`U````WW`#`"(````5<0,`
M#@```#AQ`P`P````1W$#``\```!X<0,`$P```(AQ`P`+````G'$#``H```"H
M<0,`'P```+-Q`P`&````TW$#``<```#:<0,`#0```.)Q`P`[````\'$#`!``
M```L<@,`%````#UR`P`B````4G(#`"4```!U<@,`(````)MR`P`J````O'(#
M`!@```#G<@,`&0````!S`P`(````&G,#`/@````C<P,`!@```!QT`P`:````
M(W0#`!X````^=`,`'0```%UT`P`(````>W0#``L```"$=`,`(P```)!T`P`6
M````M'0#`!8```#+=`,`)0```.)T`P`'````"'4#`%,````0=0,`&@```&1U
M`P`:````?W4#``<```":=0,`&0```*)U`P`=````O'4#`"P```#:=0,`#```
M``=V`P`J````%'8#`$P````_=@,`"P```(QV`P!:````F'8#`#````#S=@,`
M'P```"1W`P`8````1'<#`!\```!==P,`/````'UW`P`=````NG<#`!$```#8
M=P,`)P```.IW`P`3````$G@#`!0````F>`,`%@```#MX`P`+````4G@#`!H`
M``!>>`,`"````'EX`P`L````@G@#``@```"O>`,`*0```+AX`P`O````XG@#
M``<````2>0,`&0```!IY`P`'````-'D#``@````\>0,`"0```$5Y`P!%````
M3WD#``<```"5>0,`$P```)UY`P`3````L7D#`!0```#%>0,`"@```-IY`P`*
M````Y7D#``<```#P>0,`%````/AY`P`$````#7H#``<````2>@,`&````!IZ
M`P`M````,WH#`!$```!A>@,`'P```'-Z`P`A````DWH#`!(```"U>@,`#@``
M`,AZ`P`9````UWH#``T```#Q>@,`+0```/]Z`P`H````+7L#`!,```!6>P,`
M&0```&I[`P`L````A'L#``T```"Q>P,`#P```+][`P`9````SWL#`!L```#I
M>P,`,`````5\`P`;````-GP#`!$```!2?`,`.0```&1\`P`<````GGP#`!P`
M``"[?`,`$P```-A\`P`<````['P#`"@````)?0,`%@```#)]`P`*````27T#
M``T```!4?0,`%P```&)]`P`&````>GT#`#0```"!?0,`#````+9]`P`0````
MPWT#``D```#4?0,``@```-Y]`P`0````X7T#`!H```#R?0,`"P````U^`P`#
M````&7X#``@````=?@,`#@```"9^`P`)````-7X#``X````_?@,`#0```$Y^
M`P`7````7'X#`!@```!T?@,`$0```(U^`P`\````GWX#`"4```#<?@,`(P``
M``)_`P!.````)G\#`&P```!U?P,`/0```.)_`P!4````((`#`(0```!U@`,`
M%P```/J``P`.````$H$#`#0````A@0,`#0```%:!`P`'````9($#`!4```!L
M@0,`60```(*!`P`2````W($#`!````#O@0,`"0````""`P`$````"H(#``0`
M```/@@,`$0```!2"`P`>````)H(#``8```!%@@,`!P```$R"`P`'````5((#
M`!,```!<@@,`!P```'""`P`7````>((#`!<```"0@@,`0@```*B"`P`T````
MZX(#`#@````@@P,`!0```%F#`P`;````7X,#`"$```![@P,`&0```)V#`P`B
M````MX,#`!$```#:@P,``@```.R#`P`$````[X,#`!$```#T@P,`#`````:$
M`P`%````$X0#``,````9A`,`#@```!V$`P`W````+(0#`$4```!DA`,`,0``
M`*J$`P`S````W(0#`"0````0A0,`,````#6%`P!6````9H4#`"X```"]A0,`
M,@```.R%`P`U````'X8#`!P```!5A@,`(0```'*&`P"*````E(8#`$$````?
MAP,`+0```&&'`P!V````CX<#`#8````&B`,`6````#V(`P`_````EH@#`#<`
M``#6B`,`'P````Z)`P`<````+HD#`"$```!+B0,`&0```&V)`P`W````AXD#
M`#H```"_B0,`>0```/J)`P`H````=(H#`$@```"=B@,`)````.:*`P!'````
M"XL#`"H```!3BP,`+````'Z+`P!6````JXL#`%D````"C`,`*@```%R,`P`N
M````AXP#`"P```"VC`,`+````..,`P`L````$(T#`",````]C0,`+P```&&-
M`P`N````D8T#`"X```#`C0,`.````.^-`P`L````*(X#`#0```!5C@,`/P``
M`(J.`P`M````RHX#`"\```#XC@,`)0```"B/`P!.````3H\#`#T```"=CP,`
M(@```-N/`P`F````_H\#`#4````ED`,`&0```%N0`P`C````=9`#`!@```"9
MD`,`>@```+*0`P`)````+9$#`!T````WD0,`$0```%61`P`3````9Y$#`#$`
M``![D0,`(P```*V1`P`-````T9$#`&````#?D0,`RP```$"2`P"0````#),#
M`'P```"=DP,`3````!J4`P`M````9Y0#`&X```"5E`,`'0````25`P`U````
M(I4#`$,```!8E0,`)@```)R5`P`3````PY4#`!,```#7E0,`T0```.N5`P`6
M````O98#`",```#4E@,`*@```/B6`P!`````(Y<#`"$```!DEP,`)0```(:7
M`P!Q````K)<#`!P````>F`,`%P```#N8`P`1````4Y@#``L```!EF`,`!0``
M`'&8`P`&````=Y@#``@```!^F`,`!0```(>8`P`5````C9@#`!8```"CF`,`
M#@```+J8`P`5````R9@#`!<```#?F`,`&0```/>8`P`D````$9D#`"D````V
MF0,`$````&"9`P`/````<9D#``0```"!F0,`#````(:9`P`2````DYD#``,`
M``"FF0,`"0```*J9`P`*````M)D#`!0```"_F0,`"0```-29`P`(````WID#
M``4```#GF0,`"0```.V9`P`9````]YD#`!,````1F@,`"@```"6:`P`,````
M,)H#`!(````]F@,`&````%":`P`0````:9H#``@```!ZF@,`#````(.:`P`)
M````D)H#``D```":F@,`#@```*2:`P`0````LYH#``D```#$F@,`"@```,Z:
M`P`3````V9H#``X```#MF@,`%@```/R:`P`)````$YL#``(````=FP,`"@``
M`"";`P`-````*YL#`!,````YFP,`#@```$V;`P`1````7)L#`!0```!NFP,`
M#````(.;`P`0````D)L#``8```"AFP,`!@```*B;`P`%````KYL#`"@```"U
MFP,`'````-Z;`P`+````^YL#`"P````'G`,`%P```#2<`P`E````3)P#`!H`
M``!RG`,`$0```(V<`P`'````GYP#``<```"GG`,``@```*^<`P`9````LIP#
M``D```#,G`,``P```-:<`P`"````VIP#`!(```#=G`,`#0```/"<`P`*````
M_IP#`!8````)G0,`&0```""=`P`$````.IT#``<````_G0,`'````$>=`P`F
M````9)T#``(```"+G0,``P```(Z=`P`%````DIT#`!(```"8G0,`&0```*N=
M`P`*````Q9T#``(```#0G0,`"P```-.=`P`2````WYT#``8```#RG0,`#@``
M`/F=`P`A````")X#``D````JG@,`%@```#2>`P`7````2YX#`!(```!CG@,`
M%````':>`P`5````BYX#``(```"AG@,`!````*2>`P`.````J9X#``\```"X
MG@,`$````,B>`P`O````V9X#``8````)GP,`"````!"?`P`7````&9\#``4`
M```QGP,``P```#>?`P`+````.Y\#`!$```!'GP,`$P```%F?`P`!````````
M`$0'``"C"```F08``&,#``!<!0``*0(``%@"``!7"0```````&T`````````
M,P0```````!("0````````````!S`0```````%D+````````70,```L'```,
M````5`(`````````````@0$``&L$```9"P``I@<``(X(```+`P``30@``!8`
M```:!0``9@4``$$"``"Q`@``M@0``#<&``""!0``A`8```````#W"```3`L`
M``````",`0```````%P&````````\@(``%`"````````;PH``,P*```%"P``
M`````&4'````````/P(``#@"````````'@```.X(```$!0````````````#[
M`0``P@$```````!S!P``AP,``(8$``#E!@``O04``"0#``#K"@``,0``````
M```8"@```````)<(``#A!@``<0<``+H'````````M0H``&0'``#C````:@<`
M`)0)``"V"@``2@(``*D`````````FP@```````"?````V@D``"\(````````
M`````#4+````````Q`(```````!Z"P``Q0,`````````````]0```/0!````
M````B0D`````````````J@H``"8!``!9"```K00````````:"P``7P<``"<)
M````````<P,``%8%``!?"0``20@``#\&````````APH``!(%````````0P4`
M`(0!```A"P```````#,%``!H!P``Z0```(T'``!A!````````&<(```3````
M`````/`!``"E`P``!P```"@&``#S"````````-H`````````[PH``,P!```;
M````1@D``!("`````````````#$(```L"```1@,``!X%``!M"@``V`@``)$!
M``"R!0``O@4``*H#```````````````````=````5P8``!P+````````?0H`
M`(\(```E`0```````'D!``!9`@``?0$`````````````S@H``%`(``")"```
M^`D``$\+`````````````%P```!Q!``````````````P"```Z0H``$H(``!S
M````\P4``````````````````(<!``"U!0``20,``(X"``"(!@``$`$``#8+
M````````1P(`````````````:P,``$4)````````B@@``*`&``!,"0``)`$`
M`%L`````````[P8``,\````X!0``80$``)4(````````@0@``'<````X````
M(````````````````````.(%````````X@0``",(```Q"@```````&D)``"R
M!```5P@``/8!``"``P``E0H``%$"```%"@``20(``"D*``"0"0``/0@``"D!
M``!."```C0D````````1!P``$@H``-X```!:`0``'0H```````">`0``````
M`"H)``"O`0``?@D``.0"``"K`0````````````"$`P```````%P$````````
M`````.8!``#C`P``O@8``!L+``!.````4`D``,4*``"H`@``XP@``+<`````
M````T`,```````"S"0``E@,``)$"``!'````-`D``$@$```Y`P```````+$'
M`````````````*,)```(!@``<P0``/`*``"!"0``-@(``,X`````````Q00`
M```````[`0``8`$````````A`P``G@,``),"``#N`P``]P8``&L*``"+````
M\@@``),```````````````````"5!0````````````!.`P``L0H``'D*``#L
M!```[0<``,H$````````E@<``)D'````````^@(``"D%`````````````+$#
M`````````````!T!``!I"P``X0$``-$$``!^!0``&0,``,\$````````````
M``````#*"````````&,*``!F"P``8P(``+T'``#P````^@0``/@&``#K`0``
M(@$``"T)```P`@``LPH``/0(````````H0H``,H)```J!@``H@$``&0$````
M````^0H`````````````J08````````N"`````````````"L"@``IP(`````
M``"0!````P0``*X*``"F"0``?`0``&D%``#="@``````````````````G04`
M`#P)``!N"0````````````!6`@``.0```"(&``!&!P``R0```#8!``"!!```
MA00``/`"````````<@D``(,)``"="0```````-$(``#>!P``OP$``#<+``#X
M"```*PD``'$&```7!P``$0(``+0!````````P`4``.(#````````ZP,``&(&
M````````Z````+T)``"?!@``HP<``'("``!3`0``1@(``%@```"P!@``````
M`.D&```I"0``7P8``'0*`````````````/4#````````W@D``$0*```F"0``
MF@(``!\%````````[PD``,L(``#2"@``,`L``"('``"N"0``8@0``#````#8
M`@``Q@(`````````````M0(``,$`````````4@@``'\%``!+"```H`D```(%
M``#O````)0<``!0*````````00H``&L```"A````<PL``"0(````````00$`
M````````````K@(``"4&``#-!@```````!L"````````P`D``.0!````````
M?@$`````````````X@H``'T#````````4@D``%@(```<"0``#@H```````#3
M!@``R0(```````"N````&P4``-,'``!_!```D@H``&,&`````````````-4%
M```0"@``W00````````K"@```````&$*``"X`P``M@<``(\"````````)00`
M``D#``"-`P```````+4!``"X`@``2@H```````!D!0``%P@```````"\`0``
M````````````````N0<``(H#``"P"@``$@```-P$``#U!```U0$`````````
M````^04`````````````$@0```````#$"0``=04````````O`@``A`D``#$)
M``!V!```IP```#$#```H!```)@H``!,&````````[00```````"4`P``````
M`'<+``````````````````"&`P``A@(``"L(``"5!P`````````````<`P``
M```````````G`@``500``(0*``"3"@````````D!``#*`0``&0$`````````
M`````````"()``!U"@``KP```)L"``"1`P``.`L``````````````````,@#
M``#$`0``50H``$8!``!Z!P``#`D``(\&``!9"0``W`D``$X&````````````
M`!<%````````CP,``,,%````````"@$``",)``#R!0``_0H`````````````
M)@@`````````````4@0```````")!@``;@H``(L$````````ZP(```X"``";
M"0````````````"H"```Y04``"X%``"`````K@0``!4+````````````````
M``#""0``XPD```````!I`P``6@,``#@)```6!@```````#D%````````]@@`
M`$(``````````````%,'``"J"0``9P<`````````````=PD``/0&````````
M;@@``-L$``!(!0``#`<```````!,!P``/`0``#(!```N!````````.4*``!Q
M!0``7`H``)0"```1"0``+`H```````"*!0```````.@#``"0!P``MP0``,D&
M``!E`@```````)`#``#R!@```````'P'````````0`````H&``"U"```````
M`*L'```H"@``O0@``-@&``"R"@```````)`"````````LP8```````"L!P``
M``````X&``#Y`````````#<```#+!P``@P$``)8$``!Z!```%PD```````#X
M!P``A@```(4)``#""```)`4```````#<!0``%@<``.<"`````````````!$(
M````````\`<``.D$``!Y````;`@```````#7`0``_`<``'(+``"J`0``4@H`
M```````%`P``D@0``!H(````````90$``"D(``"K"0``V08``#4&````````
M`````!,#``!V!P``F@8```````!4`P``[0$``%$#```"`0``````````````
M````5`D``&D"``!""0``9`D``((&````````P08``+0'``"R`P``````````
M``!="```6PD```````"B"```]P,````````T!0``_P@``#`$``"`!```````
M`*0"`````````````*\*``#>`P``/@```.8$````````@@,```````!\"```
M'@H``'D)``#:!```=P0``+`)```."0``^0D````````,!@````````````!H
M!0``;`L``/8*``!T"0```````(8!``#W!```-00```P%``#!`0``H@4``$,&
M````````W@(```````#J!P```````#<*``!="@``'`$``#P#```H`0``_@,`
M`+$&``"#!```K`@``$<(``!@!@``ZP8``#(+``!=`@````````<*```>"P``
M$`,``!\```"@`0```````-H*``"]`@``NPD`````````````10,``%8+````
M````-@0``'<'`````````````/L"````````S@D``!L$``!3"0```````!@$
M```0!P``[P$``!T$`````````````"`*```4!P```````-,(``"+`@``1@@`
M`#D)````````W0$``*(#``"_````D@@````````V"0``'`0``*X%``#F````
M`````$0)``"<!0``#`@`````````````EPH``.8%`````````PL````!````
M````J`4``#`#``![`P``O`D``%\!``#_`0````````````"@!```9@0``)T"
M``!N!P````````````".`P``HP,``.4"``!>"@``$0H```\#``"4`0``<`8`
M`'L&``"<````J0@```````#\"0``9`8``"P`````````2`<``/4(``"A`@``
M`````)\!``!S!@``*0<``,T'``!D`P```````!<*``!_!@``<0L`````````
M````<@@``*X!````````7@4``#,&``#=!P```````.8'``!L"0``AP8``!<&
M```@"````````#P'``"[!0``X0H````````J`@``6`8``+8#````````````
M`$H&````````&`8`````````````SP@``,8(``"A`0``Z`4``%`'``#5`@``
M]08````````N`@``,@0``$4(````````U@H``(L)``#-````6PH``.H#````
M````]@0```T!```9!0````````T"````````-`(``,$#``!$!@``YPD``(D"
M``!S!0``1P4``&\&````````E@H````````-`````@````<%````````````
M`&(```#^!P``1`@```````"E!P``F0H````````C"@``T0,``+8!``#&!0``
M/0(``(4%``".`0```````'H#``"Y"```U00``(<(````````:`@``/<```#<
M`P``6P0````"``"L!```2`````<'```L!@``?08`````````````*P,``(H*
M``!W`P````````````#I"0``=`,``,(```!["````````!<$``"`"0``#`0`
M``````!8`0```````-8#````````Z@4```````"D"```=@D``*P"``#F!@``
MU`(```````",`@``_`(``$`$``"?`@``GP@```````!^````]0(````````_
M!0``U@$``!P&``#."````````*4)``"#"@```````(8)``#%`@``!@4`````
M````````T@0``%(&````````CPD``!8(```)"```>`0``*X(``!6!```F@$`
M`%L!``!"`@``Z`D``$H+```T`P```````-@#``"O"```8P<``.@'```3!0``
MI@,``"8$``!6````NP(``$D*``#!!P``808``/X(``"""```3P,```````!(
M"```,`8``*0`````````'P@``*P#````````=P(```````!F"@``"PH``(P*
M````````2@0``)X'``#+!```"`H`````````````.PD`````````````A0$`
M`%<```!K"P``A0H``&T!``````````````8'```6!```0@L``!L(````````
MV0<``$$+``!S"0``*@$``.0*``"*"0``T`D```````"W`@``'PD```````#!
M"@``Z`8``"\+```*"0``-0<```````"C!```:P@``*("``#P!```6`D``/L)
M`````````````&H!```^"@````````````"5`P``!@,````````M"P``;`<`
M`)0`````````P@H```````"!!0``WP4``/\%````````B@```/$!``!)!P``
M`````#4```"G!0``B`(``,P"````````Y`````<)``"4"@```````.0$```A
M`0``X04``!@)``!0`0```````!8+``!E"@```````,<#``````````H``/(#
M``"8!0``0@8``)P!``#G!0``N08`````````````Z@D``.("``!D````T@``
M`%T!``""`0``3`$```````#6````W0D````````B"```QP@``/X&``!>!```
M`````,<'``#4````@`H``!<+``"!"@```````#P"``"U!P``C0(``&D'``#J
M"@``G`H``-8$``#O`P```````,<"``#\````R00``'0(``"_!0``M`(`````
M``#9`@``N0````T)```Z`@``L`4````````F!P``"@(``-<%``"B"@``>@@`
M`+D$``!6`P``+`4``!H)``!2!0``VP8``#(%````````(00```````!U`@``
MU`,``+("````````.`<```$%``!D"@````````````":````X`@```````"G
M!P``-`8````````\"P``/PD``!()``!,````A@H`````````````508```\'
M``"K`````````)0%``"`"```[0H``%8&``"&"```>00`````````"```)0``
M`+\#```4`@``O@D``'\#`````````````+,#``#N!0```````$,!```X`0``
M(@L``(D````)!0``/`8``(0%``#[!@```````(H!```E!0``'@(```$*``#+
M`@``RP,``&\%``````````````````!O`0```````*\"``!&"P``)@L`````
M``!%!```Z@@```$)``#L!0``MP8``$P%```````````````````V!P``````
M`&T"```>"```S00```````"-"@``108``#,!``"V"0``!@(``/4)``!@"P``
M`````$('````````#`L```````!I````Z`0``!4'``!>!P``70<``/\*``#-
M"@``:0H``.H&````````G@````````"]!@``9@8```````"=!P``P0D`````
M```$!P``^@<``'('``#/"@``R@4``"4+``".````)`0```````"\"@``<`0`
M`'H*``"1!```^0(``)D(``"\"````````.4(```5"```````````````````
M*@0````````V`P```````,T(``#G!@``R`D``$<#``"Z"0```````-\(````
M`````````$L#``#L"```(@(```L```#?"@``V0D``!@"``!A`P```````*\&
M``#L"0````````````#)!0``5`8```````!C`````````'4+``#S!@``Y`<`
M`,8```"_"0``<`H```````#H`@```````-@!`````````````-L%````````
M`````.P#``"0!0``M@(``"`"``!R"@```````)T(``#_`@``BP$`````````
M`````````&\"``":`P``J0H```````"1!@``#00``)@*``#+`0``\0<``-P(
M``"Z`0``C`,``#8&``````````````````"K`@````````````!4`0``````
M`.<$``!'!P``-`L```````!\`0``;08``!H$``"^`@```````(@!````````
M`````.<``````````````'($``"8`@``+`L``,P`````````G0H``,`&``!0
M"P``T````$0%`````````````$D&``#'!@``````````````````0`L``"4(
M``"P`P``/`@```````!T!P``)`L``*0$``![`0`````````````""0``7@8`
M````````````H`@``"X+``!V"```+`,``$T&``#_!@``X`8``-T#````````
M_`@``#(````J!0```````"<%``"6`@````````H+``!Y!P``WP,``#H&````
M``````````````#,!0``8P4``)P(````````&0(``#$!`````````````&,$
M``#I`0``TP0``#T#```N"0````````````#<````;`H``&<"``!_"0``F04`
M```````]!0```````-0%```G````8`````````"M!@```````/L$````````
MLP0````````*"```@P<``'4$``!S"@``+`$``!((````````HPH```4%````
M````*`L``*<&``"-!```VP<``)\%``"4!P``4`H````````>!```#0<``,\!
M``"9!```^0$``````````````````+D"``"Z!@```````)@'``!P`P``%@(`
M`%@'```I!@``C08``.8"```G!@```````-@`````````N@(``&\(``#1"@``
M?@H``,H"```A!@``^`(``*L*```#!0``4P(``$D$``#M"```C`<``"<+``"C
M`@``8@D``&\```#M````>`@```````"^!```6`L``(H'```A`@```````$`(
M````````;`$```````#X!```#@$```````!2`0``*00``!@%````````K0H`
M``````#3````"P$``+$$``","````````&0!``"8`P```````*8!``#0!@``
M````````````````$`````````#(!P``V`4``+8&````````6@@```````"+
M"@``Y@D```4)````````N04``#H````/!@``I@0``+@%``!D"P``$@,``&`"
M````````U`8```````"G`0``Z@(``/($```X!```````````````````"@``
M`.P'``"7!@``<`@``.T#```E"@``PP8``)<'``!+`@``40@``*T%``#5`P``
M<@$``,P#```("````````&4&```<`````````,T#````````5P(``,,)````
M````J@0````````)"@``-@@``&@&``#X!0``60H``#L*````````S`D``)L#
M```Q!P`````````````R`P```````'L```#>!``````````````U"0``%`,`
M``0#``"P````604```($``"U`P``.`H```````!U"0```````"\&``#?!P``
MW@H`````````````Q@0``-\```"H"@```````-L#`````P``>P(``)@)```-
M"P``+@8``(,%````````Q`0``+T$``"S`0``^@D```````!M"0``)@,``$$'
M``"%"```R`(```````#%"```(P8``$L!```G"```80D``$0+``#:!P``L0D`
M`%4#````````V@(``)4"```P"0``/@,``-0*``#Y`P``DPD```````"P!P``
M$0L```````!C"0``"`L``+L!````````*@@``!\&``#K!````````(H"```Z
M!0``;0@``.8(``!=`````@<``&4(``#5"@``W04`````````````+0,`````
M``!U`P```````$8````.!0``<`4```````"2````0@H```````#Y"```O`,`
M`(<%````````UPH```````!=!@``I@8```````"/````E`8````````F!0``
M*P0``*<)``#;"```L`0``/0```#@`P``=@,````````?!P``;P<```````"L
M"0``>0@```````"B````VPD``)4$````!0``Q@D``"`)``#"!0``B0<``#H)
M````````EPD``%0'``#?`@``.@<``-<&```+"P``'04``#0$``#.!```\@$`
M`*4```"L!@```````(4#``"!!P``H@D``'0!`````````````#<!```S"```
MY@,``'\```"\!0``FPH``"L"``"1"@``B0$``.X`````````90L``,$(````
M`````````*$%``!J"@``````````````````&@```*$&````````>`,```(*
M```9"@```````.`!`````````````'@+```="P``TP(``"@(````````-0H`
M`'(%````````&@<``````````````````&\+`````````````$`&``"\!@``
M/@@```````"E!```,`H``+,(``"U````N@```-`(``"7`@``6`,``'H"``"H
M!@``F@4``,\)`````````````(X*``!!!@``)`````\*```W"0``1`(``'X(
M````````UP0``&<&``!5`@````````\!``!*`P``EP0``*L&``#1"0``F`$`
M``@$```%!```P`````T(``!A"```]`(``)T#```<!0````````````"@`P``
M*````,('``#%"0``M`0``"@#```&"@```````+L&````````]P(```8)``"<
M!```#@0``+@`````!@``PP$```````!."0``=@H``$\&``"\````.00``%`%
M````````K````/,!``#A!```FP<``/$#``":"@``W@4``%\"```D!@``````
M``````!F`P``SP(``$<&````````<0H````````M"@``@@H``!P(````````
M,PH``-H%``!V"P``6@L``)8%``"S!0``0P0```````#1`@```````'(#``#$
M````_0D```````!Q`P``:`H``.L'``!H"P``@`8``((```#I"````````(0'
M``!$`0``G@H``-(%````````:`````("``!_`@``XPH``*$$````````````
M`%4'``!'`0``W0(```````!?!0``B`<``+T`````````!PL``"(*````````
MI08``-<'``!$````@@<``(<'``!)"0```````(<$``#S`@``.P(``'<&``!/
M``````````````!-!```TP$``.,&``#Y!P``D0<``````````````````"<'
M````````[P(``-,)``"9`````````/`(``!T````(0H```````!B!0``K0<`
M`$T!```G!```Z0<``%L&``````````````````!V`0``#@L``.P```!@"@``
M``````````")!0``00,``!P"``!9`P``P@8```````":"```>04`````````
M````W@@``/P#``#.!@``"@H``,\&```#!P``R@```-("``!``@````````<(
M``!9!@``+0@``+P'``"*!@````````````#W"@``>`8``,T"``!Q`@``\@<`
M````````````<`$``#<'``````````````````#7"```2P4``(,#````````
M*PL``(H$```F````20```+`"``!;`P``^P4```````#P!@``H0@```8(``!P
M!P``;`4``!H!```+`@```````+0(```_"```.0@``+H#`````````````.X)
M``#>`0``#@<``.`%``!3"P``'P$``+<%````````T0$``/L*```8"```````
M`'P&````````10L`````````````Z0(``+X(``!C"````````$`%```'`P``
ME0$```\%``!U"````````!,+``![!P``%@4``-\&``#D"0``OP<``&`'```0
M"P``;@$```````!2`@``K0```%````!R````U`0``+8%`````````````'L*
M``"6````.P<``!@!```R!P```````(@(```["```/0$``($#``!J````0P@`
M`.$'``!M!0```````+H*``#M"0``W`H``"`+``!Y!@``!@L``'@%```$`@``
MK0D```````#N`0```````/H%````````-P,``!$#````````90D```8!``!T
M"P``E`@``*`'```1`````````)H'``#+!@```````)X&``#J`````````",!
M`````````````/L``````````````+@$```$!````````,`#```N!P``````
M`.,$```/`````````$H'``!P````$@<``)L!``""`@``&P$``'L)``#0!P``
M`````#X$``#A`@``?0``````````!P``V0@```````!X````40D``%`&````
M````HP8``+<)````````%@,``%D'`````````````"X#``!F!P``700``!H"
M``!T!0``\0D``*0#``!&!````````/0%``!1"@``"0L``#\!```]````=PH`
M`/(*``#9`````P8`````````````A`@``%D!````"0``/@L``#L%````````
M.0$``)\$```B!```(`0``,4%``"#````30D```````!I!```(`$``#X&```9
M"```(@````````!(`P``OP8``"L!```A`````````#P!``",````R````+`(
M``!6"@``7@$```(+``#["```G`8``%('````````[`8`````````````900`
M`#\#````````1@8``%\*```\!0```````'$)```@!0``KP,```````"G"```
M`````-<"```A"```X@@```````#,!```YP<```````!,`@``G@@````````%
M`@```````-P'``#W`0``.@@``-@'```R"0``M`8````````Q!0```P$``.()
M```5`P``\PD``.\$``"H`P``I@4```````#\"@``30<``'<%``"Q"```U0D`
M``L%````````9@````````#1!0``=0$``&T#``#H"@``N`@````````#````
M3P4``*D)``#%!P``P0(``(T!```!`@``DP@``'4'``#F"@```````+8```!T
M!```IP,``(`%```4`````````,X"``"[!P```````%D```#C!0``````````
M```T````4P```"@"````````````````````````<0@``)P'````````````
M`)\*``"/"@```````.H$``".!0```````#\$````````R`8``#(*````````
MPP0``/`#``"8"```RP4````````````````````````&!```!@```%P)``!_
M`0```PD``"H+``!X`@``'0@``!\"``"F`@``+PD``+0%``!]"```'@8`````
M``````````````0)``!7!0```````$\)``"9`P```````#L&``!P"0``*0``
M`!\+````````D@4``&L'``!?````0PH``)()``"I!0``Y0<``/D$``#*`P``
M:P8``,<!````````````````````````2@```.4!``##`@``FP```+,'``"/
M!0``(P,``$@&````````X@8``&4%````````Y0D``#8*```M!P``+00``+0)
M``"9`@``%0(``"@'``!5"```K0(``!L#```!`P``0P<```````!X"@``````
M`'4```#$!0``%`D``-0!````````:@L````````S!P``5PL`````````````
M[`$`````````````&@8``.<(````````3@$``*<*```Y!P``C@8```````!!
M!```J0,``.P*``"W`0``&@,``&("``!0`P```````,`*``"W"@``OPH``-4'
M`````````````)('````````/@4``#4"````````T@<``(T%``#0!0``````
M`*D"``#2"0``]04```````#?!````````'\*``"$`````````.`$``!H`@``
MS0$````````G"@``#0H```````"(``````````D)``#&!@``)@(``$P*``"J
M````D@(``!`)```C`````````'8&````````NP```!4$````````<`L`````
M``"!!@``W`8``(@#````````30```+H$``"J"```%`@``/X%``#&`P``````
M``@#````````#08``/$"````````4P,``&,+``!L`@```````),$``"_!```
M`````!X#````````````````````````7@L```````#9"@``)`H``%,&````
M````J`0````````*!0``N0D``*H"````````80<``````````````````,<$
M``!/`0``=P@``-P"``#&"@``MP@``.('```N````K0@``%X````-`P``````
M`-D#``!I`0``50$`````````````,0(``#((```M````D@8```````"C`0``
M```````````J"@``)`D``.`*````````G`D```````#(!```;@(``(,"````
M`````````.<#``````````````0*``!?!```(@4``*L(```;"@```````/,$
M``")`P``5P<``$L&````````:`,``,($``"^`P``&````-D!```!"```8@$`
M`!8)````````.0(``!\$``"N`P``U@8``/$%``#("@``L0````````"6"0``
M0P```)$```#R"0``#`,``````````````````)X$```.`P```````%X"```(
M!P```````%L+``!T`@``I`D``/\#``"D!0``R0D``$T*```H"0``'0<``'L$
M``"(!0``?`,``(L#````````X`D```@!``#D!@```````$,#``#D`P``````
M`.L```",!```"`D```````#G`0```08``!<!````````RP````D&``#Q"```
M#P0``$T%``"7!0``P`<```````!<!P``L`$``&,!`````````````"L&```]
M!@``A`(```````!K!0```````#@&``!!!0```````/$&``!6`0``/0D``*,`
M``!$`P```````#X"``#.`P``%@H``-<#`````````````.$#````````SP<`
M`&H%``#0`@``C0@``),!``"7`0```````&T$```\"@```````'H%``#_!```
M9`@``&4```!A`@```````'D#``"["@``J`D``-,*``".!````````$`!``#X
M````U@D``'(&````````]P<````````X"```_@````````#>!@``K@<```D'
M`````````````-L*```````````````````$"```#@@`````````````````
M`,,*````````_0<``(L'```Y!@``'`<```````!]"0``Z`@`````````````
MD@$``!4!``#O"```U0@``$<*``#6`@``SP4``'T$``"4!````````!(!``"S
M`@``Q08``/`%````````M@@``&D(``#D"```5P,``#("```S`P``(P<`````
M````````8`,``/T&```)!```?04``+((``#("```]0$``+<#``"O"0``````
M`%$+``#V!P``5@D``$L+``"R````Y0,``(T````+!``````````````1!@``
M400```X````D`@``R0H``/L#```%!P````````````!W`0``6@(`````````
M````6@8``,P&``!+"@``.@$``)8&``"E"```@0`````````@!@``7PL``-\)
M``#G"@```````"T"``#\!```H@0``#D+````````&08``%L"``#^"0``D0D`
M`.D#``"I!```!P(``*8````%`0``/PH``+\"``!_!P``Q@<``.@!````````
M80```,,```"2`P``5````%,$``!."@`````````````_````N`<``/X"``#.
M`0``)0D```,*```(`@``+P4``(<)```O!P``TP,```````!V!0``7`$`````
M``!O`P``X````-,%```````````````+``";!0``$@L``+X*``!Z"0``F0D`
M`%X(```7`@``T@,``-H(```%`````````!$%```5!@``"PD``#<"``"^`0``
MD`H```````#-!0``O0,`````````````T0<``#,```#2!@```````*\$````
M````;`,``#H#``!L````,0L``%H%```6`0``U0```%0+```C!0``-`H`````
M```#"```:PD``/L'``!="0```````-$```!'!```G00``$4```#7````+@H`
M``````#Z````\@```,X'``#``0``,PD``/P!``````````````,"```"`P``
MA@<``/,```!L!@``)`<``,`"``#;`@```````!T"``!9!```*P````````!=
M"P``'@<``"$%````````M00``)`&``#<`0```````%P"````````T`$``/8&
M````````N0$``!,)````````T@$``&\$``"D`0``;@4`````````````````
M``````!,`P``6P<``#`!````````S0D``$@*``#I!0``%P,```````#K"0``
M_@H``)P"``"/`0``9P,``#T'``"5!@``+P0``%0%``"7````&00``%$```#Z
M!@``[08``*P%````````:@8``'H!```]!```]PD``*('```'!@``5PH``,8!
M````````2P0``#0!```U`0``FP8``,0#````````L@<``/T$``!*`0``7`@`
M`),'```+"```:@,``$T"``"["````````,<``````````````,4!``!1!@``
M6@```-0)``!2````;PD``*H%``#*!P``OP@```````"M`0``````````````
M````)0(``)@$``!5"0``B`D``/0'````````7@D```````!'"0```````+<'
M``"]`0``/@D``+,`````````(`,``'T'``!J!`````````````"``0``````
M`#8%``#;````_`4``#P```".!P``+08```@````O`0``G0```)8!```U"```
MB00``$`*``";!```]@4``(4````<"@``2`(``"4#```!"P``BP@````````^
M!P```````*`*````````PP,``'L%``#$!@```````(<`````````\0H``"\`
M``"%`@``]@D``/\)``!."P``0@,``,P(``#"`P```````,0'``!7!```D`$`
M`$@!``!^!@``^`,```P*``#Q!```4`0``*X&```T"```0@$`````````````
MG`,``#8`````````A`0``!L)``!-`P``[`(``#<$````````RPH`````````
M````G@D``&H"``!/!P``0@@``/,*``!T!@``]@,``,<%````````BP4`````
M````````F@D``'X#``#N!P```````&@!````````0P(``$$(``!N`P``Q`@`
M`*D!``!A"P``>0(``.\'``#]!0``%0D``#L+```Z!```/0H```D```#="```
M6`0``.L(````````7@,``+@!``#+"0``I0$``.X"``!J"```9@D``-D%````
M````C`D``&`$``#%````GP,``#X!```:"@``$PH``"P"``#.!0``P`0`````
M``!^!```[@8````````!!P```````#T+``!["P``$00``',"````````CP0`
M`'H&``!.!P``&0```,P'``#(`0``[0(```````#A````X@$```````!$!```
MPP@``-8(``#C`@``<0`````````9!P``^`$```````!5"P``G@4``*4"``#Z
M`P``L0$``-0'``!("P```````/\```"``@``E0```!T)``!%"@``XP$``)D!
M``"O!P``#04``/T"`````````````/D&``!X`0``KP4```````"."0``_@0`
M`"$'``!G"@``*@```#(&```9"0``X`<```````""!```)@8```````!7`0``
M%`0``%,%``!+"0``00D``*@!``#8!````````-H&`````````````%$'``"@
M!0``#`(```H'````````3`@```````"#"```$0$``,\#``"E"@``8@<``$\(
M````````6`4``%8'``#!!0``;@```.$)````````Y00``'`"``#6!P``DP4`
M````````````[04``$<+``!2`P```````*L%````````I04``'P`````````
MZ@$``/8"````````D0@```````"Z!0```````````````````````/8```!"
M!````````+4)``"7`P``_0$``"L'``!V`@``9PD``-T&``#_!P``B`H`````
M`````````````-0(```3!P```````*H'```(!0``G@(```````"G!```!```
M`*T#```_!P````````D"````````(@,``$4!``#)`0``J0<``*$)``!F`0``
M:P(``.X*````````6@<``#4%``!N!````````&L!````````104``.,'``#'
M"@``(PL```````!2"P``.0H````````2!@```````$X$``#:`P``!`$```,#
M```M`0```````/0*```_"P```````$\$``"X!@``M````'T"``"!`@``(P0`
M``((```C`@``!`L``.L%```/"0``F`8``!0+```W"```O`(``(8&``"X"0``
M``````````#A"```\P<``"H'``"]"@```````+()``!6"```B0H``$(%``"D
M"@``Q`H``````````````````'P*``#]"```,`4``+L$``!J"0```````-8%
M``!@!0``L@8``/X!````````,`<```````!=!0```````#4#``"X"@``&`,`
M`"P'````````N@@``-@*``"""0``C`4``,D(```=!@``D04``!0!``#T!```
M``````````!``P``30L``%$%```+!@````````<$```'`0``0`<``%4%``"[
M`P``GP<``````````````````'H````3!````````-@)``#:`0``9P0``)T!
M`````````````'P%``#"`@``GPD```4&```5"@```````/H!````````H`(`
M`+4&``!\`@``7`,``"P$``!U!@``6`H```````"R`0``X@```&8(``#N!```
M.`,```(&``"0````H0<`````````````*0L``'X"```S"P``N0,``$H)``!4
M"```R@H```````!;"``````````$````````]0<``&<```#1!@``-`<`````
M```O"@``+P,``.0%`````````````!`&``!@"0``3`8``!,(```S`@``0PL`
M`-D$``"H!P``3@4`````````````:`D``'\(``#U"@``20L```````"Q!0``
ME@@``&@$``!*!0```````%P+``#S`P``]`D``%$!```>"0``'P,``*L$``!:
M"0``D`@``-`$```J`P`````````````[`P```````#$&``#T`P``$`@``-T`
M````````3`0``'X'``#]````[P4``&(*``!3"@```````%H$``!@"```;`0`
M``8&```;!@``5`0``*H&`````````````#H*``!M!P``7P,```\"````````
MI@@``/H(````````O`0``*8*``#)!P``%P```(`'``"(!```%0`````````?
M"@``9PL``+D*``"^````3@(``&T+``!E`P``0PD``)4)``"D!@``3PH``,$$
M``#Q````.P```-4&```Q!```20$``*$#``"+!@``9@(```H$```@!P``8@L`
M`$8%``!\"0```````,H&```=`P```````/<%``#;`0``T@@``!@'```4!@``
MY0```$4'````````8@@``-\!```[!```F````#<%````````9`(``),&``!:
M"@``8@,``(<"``!?"`````````````#(!0``)P,```````#]`P``H`````$$
M````````1@H``%0*``##!P``*`4``(P&````````%`4``&<!````````!`8`
M`!4%````````&P<``/@*```/"```804``+X'````````I`<```P!``#'"0``
MM`H``*P!``"%!@`````````````0!0```````'@)``"&!0```````*@```"%
M!P```````"X!````````M`,``%4```"3`P``JP,``(,&``!I!@``H@8``"L%
M```I`P``3P(```$!``#P"0``G08``'8`````````CP<```````!)!0``6P4`
M`!`"````````<P@``$L'```3`@``+`D``!,!```A"0``4P@```````#`"```
M^@H`````````````9P4``,D#````````00```!X!``!N!@```````"<!```%
M"```F@0```````!N"P``.@L```````#0"@``_`8```\+``!+````X`(```H#
M``!`"0``HP4``-<)``!Y"P``&`L``'@'``!%`@``+04``!`$````````<0$`
M`````````````"`@("`@($-C.B``("`@("`@5&\Z(``@("`@1&%T93H@`"`@
M("!&<F]M.B``("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@
M)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!3
M=6)J96-T.B``(&%T(``@:6X@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B
M)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG
M=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E
M<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES
M=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`",`)2XR9DU"("\@)2XR9DU"
M("`H)2XR9B4E*0`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*0`E9"`E<R!A;F0@)7,`)60@365S<V%G97,`)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D
M96QE=&5D+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T
M('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@;65S<V%G
M97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`E9"!M97-S86=E
M<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@<W!A;2X`)60@=&\@)60@;V8@)60@365S<V%G97,`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@
M4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES
M=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T
M(')E;F%M960N`"5S(&%T("5S("5S`"5S(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T
M('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S(&AA<R!A8V-E<'1E9"X`)7,@
M:&%S(&-A;F-E;&QE9"`B)7,B+@`E<R!H87,@9&5C;&EN960N`"5S(&AA<R!R
M97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L:65D
M('1O('1H92!I;G9I=&%T:6]N('1O("(E<R(N`"5S(&AA<R!S96YT('EO=2!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(&AA<R!T96YT871I=F5L>2!A8V-E
M<'1E9"X`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A
M;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T
M:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`
M)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(')E
M<75E<W1S('EO=7(@<')E<V5N8V4@870@(B5S(BX`)7,@=&\@)7,@;V8@)7,`
M)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R`B)7,B+@`E<R!W:7-H97,@
M=&\@86UM96YD("(E<R(N`"5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O
M9B`B)7,B+@`E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R
M;6%T:6]N(&%B;W5T("(E<R(N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L
M96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B`E
M<R`H)60F;F)S<#MO9B9N8G-P.R5D*0`E<SH@5&AI<R!M97-S86=E(&UA>2!N
M;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O
M;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S
M96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"A!<'!L>2!T
M:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A
M<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E
M96XN*0`H2%1-3"D`*%!L86EN(%1E>'0I`"A2971U<FX@=&\@=&AE(&-O;7!O
M<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU
M<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/
M5"!B92!A<'!L:65D+BD`*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A
M;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R
M<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"H@061D('1H97-E
M(&)Y(&-L:6-K:6YG($]+("H`*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I
M("H`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M
M("5S('1O("5S`"TM('-E;&5C="`M+0`Q(&UE<W-A9V4@:&%S(&)E96X@9&5L
M971E9"X`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M
M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2X`,2!M97-S86=E(&AA<R!B965N
M(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BX`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN`#$P,"!C
M:&%R86-T97)S`#$P,#`@8VAA<F%C=&5R<P`Q,B!(;W5R($9O<FUA=``R-"!(
M;W5R($9O<FUA=``R-"!H;W5R<P`R-3`@8VAA<F%C=&5R<P`U,#`@8VAA<F%C
M=&5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D
M(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!
M(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S
M<V%G92X`02!M97-S86=E('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D(&EN
M(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H92!R96-I<&EE;G0N`$$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@
M<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G
M92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E
M+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@
M4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`04Y$`$%022!)1`!!8F]U
M="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C
M8V5P="!A;F0@861D('1O(&UY(&-A;&5N9&%R`$%C8V5P="!R97%U97-T`$%C
M8V5P=&5D`$%C8V5P=&5D.B``06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!
M8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F
M<F]Z96XN`$%C8V]U;G0G<R!N86UE.@!!8V-O=6YT:6YG`$%C=&EO;G,`061D
M`$%D9"`E<R!T;R!M>2!!9&1R97-S($)O;VL`061D($-H:6QD($=R;W5P`$%D
M9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D
M9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D
M9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`
M061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('-O=7)C
M90!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1H
M:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O
M(&UY(&%D9')E<W,@8F]O:P!!9&0@=&\@;7D@8V%L96YD87(`061D('5S97(`
M061D960@(B5S(B!A<R!A;B!A='1A8VAM96YT+@!!9&1E9"`B)7,B('1O('1H
M92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P
M(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\
M96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B!O;B!A(&YE=R!L:6YE
M*3PO96T^`$%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E
M<RX`061D:71I;VYA;"!I;F9O<FUA=&EO;B!D971A:6QS`$%D9&ET:6]N86P@
M;65S<V%G92!D971A:6QS`$%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(&-A
M;B!B92!V:65W960@)7,N`$%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A
M:6QS`$%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(&-A;B!B92!V
M:65W960@)7,N`$%D9')E<W,`061D<F5S<R!";V]K`$%D9')E<W,@0F]O:W,`
M061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL
M(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^`$%D9')E
M<W-E<R!T;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES(&ED96YT:71Y.B`\96T^
M*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\
M+V5M/@!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!
M;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT
M:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F
M;W5R('-I9&5S`$%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E
M<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE.@!!
M;&P@;65S<V%G97,@:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N("5S
M(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD(&QI
M;FME9"!A='1A8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL
M(&)E(&1E;&5T960N`$%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T
M:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&P@<FEG:'1S
M(&]N(&9O;&1E<B`B)7,B('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U<V5R
M("(E<R(N`$%L;&]W($9O;&1E<B!#<F5A=&EO;C\`06QL;W<@9FEL=&5R(')U
M;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_`$%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T
M>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E
M<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!
M;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L
M=&5R;F%T92!T97AT.@!!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T
M:6]N.@!!;'=A>7,`06QW87ES('-A=F4@871T86-H;65N=',`06UE<FEC86X@
M4V%M;V$`06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-T
M<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@<V%I9#H@`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"X`06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE
M(&-R96%T:6YG('1H92!N97<@;F]T92X`06X@=6YK;F]W;B!E<G)O<B!O8V-U
M<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RX`06YD;W)R80!!;F=O
M;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G-W97)E9`!!
M;G-W97)E9"!M97-S86=E<P!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U
M9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I
M<R!R96%D>2X`07!P;'D@1FEL=&5R<P!!<'!L>2!&:6QT97)S('1O("5S`$%P
M<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_`$%P<&QY(&9I;'1E
M<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`
M07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI
M=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@
M5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;C\`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_`$%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@
M<F5C;VUM96YD960A*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI
M<S\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%
M4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE
M;G0_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@
M86YY('-U8BUG<F]U<',_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T
M>2!T:&ES(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y
M('EO=7(@<W!A;2!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E
M;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN
M;V-E;G0_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M
M97-S86=E(&%S('-P86T_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!
M4DU30TE)+3@I`$%R<FEV86P@5&EM90!!<G0`07)U8F$`07-C96YD:6YG`$%S
M8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`
M07-K`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T86-H($9I
M;&5S`$%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y
M;W5R(&UE<W-A9V4_`$%T=&%C:&5D($9I;&4Z`$%T=&%C:&5D(&9I;&4@(B5S
M(B!E>&-E961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/
M5"!A='1A8VAE9"X`071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R
M(')E<75E<W0@>6]U('-E;G0N`$%T=&%C:&UE;G0`071T86-H;65N="`E<R!D
M96QE=&5D+@!!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM
M96YT('1Y<&4`071T86-H;65N=',`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<VAA<F4N`$%T=&5N9&5E<P!!='1E;G1I;VX`071T<FEB=71E<P!!=6=U<W0`
M075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:6UP.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN
M`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=71O;6%T:6-A
M;&QY('-H;W<@:6UA9V5S(&EN($A434P@;65S<V%G97,@=VAE;B!T:&4@<V5N
M9&5R(&ES(&EN(&UY(&%D9')E<W-B;V]K/P!!=F%I;&%B;&4@061D<F5S<R!B
M;V]K<SH`079A:6QA8FQE(&9I96QD<SH`07=A:71I;F<@4F5S<&]N<V4`07IE
M<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C7VL@=&\@)7,`0F%C:R!T;R`E<P!"
M86-K('1O($UU;'1I<&QE($UE<W-A9V4@5FEE=R!);F1E>`!"86-K('1O(%1H
M<F5A9"!$:7-P;&%Y`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@
M:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%D
M(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N9&5D.B`E<P!"
M86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F
M;W5N9"X`0F%S96QI;F4`0F-C`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5L
M;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@
M;65S<V%G92X`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQA8VML
M:7-T`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N
M`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQO8VL@:6UA9V5S(&EN($A4
M34P@;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I9FEC86QL>2!R97%U
M97-T960_`$)O9'D`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R
M9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA
M`$)O=&@`0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E
M`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L
M9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`
M0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N
M+BX`0U]H87)S970`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L
M96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(&-O;FYE8W0@
M=&\@=&AE(')E;6]T92!M86EL('-E<G9E<BX`0V%N(&YO="!C;VYN96-T('1O
M('1H92!R96UO=&4@;6%I;"!S97)V97(Z(`!#86X@;F]T(&1I<W!L87D@+2!F
M;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S<V%G92!I;B!T
M:&4@8W5R<F5N="!M86EL8F]X+@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@
M;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L
M`$-A;F-E;"!-97-S86=E`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YC96QL
M:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S
M(&-O;G1E;G1S+@!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T
M+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N
M;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!6
M97)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A
M>6UA;B!)<VQA;F1S`$-C`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E
M;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L
M;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`
M0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I
M8V%T92!0;VQI8VEE<P!#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V86EL
M86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R!S97)V
M97(N`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@06QL`$-H86YG
M92!&;VQD97(`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E(&1I<W!L87D@
M;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@
M96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@87)E('-O<G1E9"X`0VAA;F=E
M(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N`$-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V4@=&AE(&YA;64L
M(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-H87(`0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.@!#:&5C7VL@3&EN:RXN+@!#
M:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$-H96-K(%]!;&PO3F]N90!#
M:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@
M9G)O;3H`0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M97-S86=E
M/P!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%C=&EO;CH`0VAO;W-E
M($%P<&QI8V%T:6]N.@!#:&]O<V4@82!M86EL('-E<G9E<CH`0VAO;W-E(&$@
M;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z`$-H;V]S
M92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R
M9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W
M:&5N(&%D9&EN9R!A9&1R97-S97,N`$-H;V]S92!T:&4@;W)D97(@;V8@861D
M<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S
M+@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y
M`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T
M80!#;&5A<FEN9R!,871E`$-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E
M(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N`$-L
M:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92X`0VQI8VL@)7,@=&\@9V\@
M=&\@)7,@;6%N86=E;65N="!P86=E+@!#;&EC:R`E<R!T;R!V:65W($A434P@
M8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@)7,@=&\@=FEE
M=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!#;&EC:R`E<R!T;R!V:65W
M('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R`E
M<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E
M<&%R871E('=I;F1O=RX`0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,`
M0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A
M;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T;R!S96%R8V@N`$-L:6-K('1O
M($-O;G1I;G5E`$-L:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U
M<B!!9&1R97-S(&)O;VL`0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A
M=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O;VL`0VQI8VMA=&5L;"!V:6$@
M2%144`!#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N
M97<@;65S<V%G92!T;R!T:&4@<V5N9&5R`$-L:6-K:6YG(&]N('1H92!A9&1R
M97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D`$-L;W-E`$-L
M;W-E(%=I;F1O=P!#;&]S92!T:&ES('=I;F1O=P!#;&]S960@1F]L9&5R`$-L
M;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA
M;F1S`$-O;&QA<'-E`$-O;&QA<'-E($%L;`!#;VQL87!S92!!;&P@1F]L9&5R
M<P!#;VQL87!S92!&;VQD97(`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@
M8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!);F1I8V%T;W(Z(`!#;VQO
M<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S
M`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@
M3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&QE=&5D`$-O;7!O<V4@86YO=&AE
M<B!M97-S86=E`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD
M;W<_`$-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A
M=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92!F96%T=7)E*3\`0V]M<'5T
M97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M
M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A
M<F4@9&ES<&QA>65D+@!#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N
M`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC
M(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&1R;W!P960@8GD@24U!4"!S
M97)V97(N`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@
M`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!2
M96%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D`$-O;G1A8W1S`$-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N
M=',@;V8@(B5S(@!#;VYT:6YU90!#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E
M<RX`0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@;W!T
M:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N`$-O;G1R;VP@
M=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE
M<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O;G9E
M<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\`0V]O
M:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E
M;&5C=&EO;@!#;W!Y('1O(&9O;&1E<@!#;W)R96-T`$-O<G)E8W1E9"!497AT
M`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!0
M1U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E
M+B`E<P!#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S="X@4F5A<V]N($=I=F5N
M.B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<@!#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!C
M<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<P!#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@
M9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<P!#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@
M97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+@!#;W5L9"!N;W0@97AT
M<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A
M8VAM96YT+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@
M9G)O;2!T:&4@6FEP(&%R8VAI=F4N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO
M="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(&]P96X@<V5C
M=7)E(&-O;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R+B`E<R`Z("5S+@!#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R;VT@24U!
M4"!S97)V97(N`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO
M="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U
M;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E($9O;&1E
M<@!#<F5A=&4@2V5Y<P!#<F5A=&4@5FER='5A;"!&;VQD97(`0W)E871E(&$@
M3F5W($%C8V]U;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@4W!A;2!F
M;VQD97(`0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E871E(&$@;F5W
M(&]N90!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@82!N
M97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G
M86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R
M<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@;F5W('-T871I;VYE<GD`0W)E
M871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+@!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S
M:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R
M<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!A8V-E<W,@=&\@)7,`0W5R<F5N
M="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!A8V-O=6YT
M<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+@!#=7-T
M;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN`$-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S
M`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y
M<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$
M4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E
M+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=%]E`$1A=&%4
M<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E
M9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`
M1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8VQI;F5D.B``1&5C<F5A<V4@
M26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y
M`$1E9F%U;'0@4V5A<F-H($9I96QD`$1E9F%U;'0@4VAE;&P`1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$
M969I;FET:6]N<P!$96QE9V%T960`1&5L971E`$1E;&5T92`E<R!0=6)L:6,@
M2V5Y`$1E;&5T92!#96QL`$1E;&5T92!#=7)R96YT($ME>7,`1&5L971E($9O
M;&1E<BAS*0!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES
M<VEO;@!$96QE=&4@4V5L96-T960@1F]L9&5R<P!$96QE=&4@4W1A=&EO;F5R
M>0!$96QE=&4@5FER='5A;"!&;VQD97(`1&5L971E(%9I<G1U86P@1F]L9&5R
M($1E9FEN:71I;VX@9F]R("5S`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E`$1E;&5T92!F971C:&5D(&UE<W-A9V5S(&9R;VT@
M<F5M;W1E('-E<G9E<C\`1&5L971E(&9R;VT@;7D@8V%L96YD87(`1&5L971E
M(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H
M/P!$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O
M9B!M;VYT:#\`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`
M1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-P
M86T@;65S<V%G97,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W`$1E;&5T960`1&5L971E9"!M97-S86=E<P!$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&5T960@=&AE(&%T
M=&%C:&UE;G0@(B5S(BX`1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$
M96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5N>2!R97%U97-T`$1E;GD@<F5Q=65S
M="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N`$1E<V-E;F1I;F<`1&5S8W)I
M8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<P!$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0
M;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I
M9"!N;W0@871T86-H("(E<R(@87,@=&AE(&9I;&4@=V%S(&5M<'1Y+@!$:6T@
M<VEG;F%T=7)E<S\`1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N
M(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!C;VYF:7)M871I
M;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_`$1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA
M=`!$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G90!$:7-P;&%Y('!O<"UU<"!N
M;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_`$1I<W!L87D@=&AE(")%;7!T>2!3
M<&%M(B!L:6YK(&EN('1H92!M96YU8F%R/P!$:7-P;&%Y('1H92`B16UP='D@
M5')A<V@B(&QI;FL@:6X@=&AE(&UE;G5B87(_`$1I<W!O<VET:6]N`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!.3U0@;6%T8V@`1&\@
M3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1E;&5T
M90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!N
M;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6X`1&\@>6]U
M('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\`1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A
M;B!A8V-O=6YT/R!3:6=N('5P+@!$;VYE`$1O=VYL;V%D`$1O=VYL;V%D("5S
M`$1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T`$1O=VYL;V%D($%L;"!!='1A
M8VAM96YT<R`H:6X@+GII<"!F:6QE*0!$;W=N;&]A9"!&;VQD97(H<RD`1&]W
M;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%T`1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1&]W;FQO860@:6X@
M+GII<"!&;W)M870`1')A9G0`1')A9G0@9F]L9&5R`$1R869T<R!F;VQD97(Z
M`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%+6UA:6P@061D<F5S<P!%
M36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC
M:"!P<F]V:61E('1H:7,@<V5R=FEC92X`14Y$`$524@!%4E)/4CH@66]U<B!M
M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N`$5C=6%D;W(`161I=`!%
M9&ET($)L86-K;&ES=`!%9&ET($)L;V-K`$5D:70@1FEL=&5R<P!%9&ET($=R
M;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@5FER='5A;"!&;VQD97(`161I="!6:7)T
M=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E<P!%9&ET(%=H:71E;&ES=`!%
M9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@>6]U<B!B;&%C:VQI<W0`161I
M="!Y;W5R(&9I;'1E<B!R=6QE<P!%9&ET('EO=7(@<')E9F5R96YC97,@9F]R
M(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+@!%9&ET('EO=7(@=VAI
M=&5L:7-T`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'
M871E=V%Y`$5M;W1I8V]N<P!%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S
M+@!%;7!T>2!&;VQD97(H<RD`16UP='D@4V5L96-T960@1F]L9&5R<P!%;7!T
M>2!4<F%S:"!F;VQD97(`16UP='D@7U-P86T`16UP='D@7U1R87-H`$5M<'1Y
M(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N
M86)L92!01U`@9G5N8W1I;VYA;&ET>3\`16YA8FQE(%,O34E-12!F=6YC=&EO
M;F%L:71Y/P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O
M($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@;65S<V%G92!P<F5V:65W<S\`
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YC<E]Y<'1I;VX@
M3W!T:6]N<P!%;F-R>7!T960`16YD`$5N9"!F;W)W87)D960@;65S<V%G90!%
M;F0@;65S<V%G90!%;F0@;65S<V%G92!F<F]M("5S`$5N9"!Y96%R`$5N;&%R
M9V4@161I=&]R`$5N=&5R(%!A<W-P:')A<V4`16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SH`16YT97(@=&AE(&YA;64@9F]R('EO=7(@
M;F5W(%-P86T@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D
M<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT
M(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S
M:"!F;VQD97(`16YT:7)E($UE<W-A9V4`16YT<GD@(B5S(B!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O;VL`17%U871O<FEA;"!'
M=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C;VYN96-T:6YG('1O($E-05`@
M<V5R=F5R+B`E<R`Z("5S+@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('-E
M;F1I;F<@<F5P;'DZ("5S+@!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`
M17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N
M`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5N="!S=6-C97-S
M9G5L;'D@9&5L971E9"X`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>'!A;F0`17AP86YD($%L;`!%>'!A;F0@06QL($9O;&1E
M<G,`17AP86YD($9O;&1E<@!%>'!A;F0@3F%M97,`17AP86YD(%-I9&5B87(`
M17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A
M;&QY(&EN('1H92!B86-K9W)O=6YD/P!%>'!A;F0@=&AE(&5N=&ER92!F;VQD
M97(@=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_`$5X<&%N
M9&EN9P!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L
M;W(`1E10('5P;&]A9"!O9B!S971U<`!&7V5T8V@@36%I;`!&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A
M:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S
M(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL
M960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A
M:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`
M1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E
M96QS(&QI:V4Z(`!&971C:"!-86EL`$9E=&-H($UA:6P@:6X@82!S97!A<F%T
M92!W:6YD;W<_`$9E=&-H(&UE<W-A9V5S('5P;VX@;&]G9VEN9R!O;C\`1F5T
M8VAE9"`E9"!M97-S86=E<R!F<F]M("5S`$9E=&-H960@,2!M97-S86=E(&9R
M;VT@)7,`1F5T8VAM86EL.B``1F5T8VAM86EL.B!N;R!N97<@;65S<V%G97,N
M`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FE?;'1E<G,`1FEE;&0@
M;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@
M36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<B!/<'1I;VYS`$9I
M;'1E<B!3971T:6YG<P!&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F
M86YI='D_`$9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES
M=&5M+@!&:6QT97)S`$9I;'1E<G,@3D]4($%C=&EV90!&:6QT97)S.B`E<R!M
M86YA9V5M96YT('!A9V4`1FEN9`!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@
M36%I;&)O>"!086=E`$9I<G-T(%!A9V4`1FER<W0@475A<G1E<@!&:7@@<F%T
M:6\`1FQI<`!&;&]A=`!&;U]R=V%R9`!&;V<`1F]L9&5R("5S(&1O97,@;F]T
M(&5X:7-T`$9O;&1E<B!!8W1I;VYS("T@0V]N9FER;6%T:6]N`$9O;&1E<B!.
M879I9V%T;W(`1F]L9&5R(%-U;6UA<GD`1F]L9&5R('-H87)I;F<@:7,@;F]T
M(&5N86)L960N`$9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N`$9O;G0@0V]L
M;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E
M<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE
M(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT
M.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@
M8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M870@;V8@;65S<V%G
M92!D871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E
M9"!T;V1A>0!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&
M;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D`$9O<G=A<F0Z`$9O<G=A<F1E9"!M
M97-S86=E`$9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,`1F]R=V%R9',`1G(`
M1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E+T)U<WD@
M4F5Q=65S="!297-P;VYS90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S
M:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;U]M`$9R;VT`1G)O
M;2!!9&1R97-S`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O
M;@!&=6QL($YA;64`1G=D.@!&=V0Z(`!&=V0Z("5U($9O<G=A<F1E9"!-97-S
M86=E<P!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y
M.@!'86UB:6$`1V5N97)A;"!/<'1I;VYS`$=E;F5R871E("5S($-O;F9I9W5R
M871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=E="!O;FQY
M(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2D`1VAA;F$`1VEB<F%L=&%R`$=I
M=F5N($YA;64`1V\`1V\@=&\@365S<V%G90!';R!T;R!A9&1R97-S(&)O;VL@
M96YT<GD@;V8@(B5S(@!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C
M:`!'<F%N="!A8V-E<W,`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X
M-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`
M1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`
M1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M
M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA
M`$A%4D4`2%1-3`!(5$U,(%9E<G-I;VX@;V8@365S<V%G90!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N
M=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE
M`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG
M:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AE<F4@:7,@=&AE
M(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.@!(:61D96X`2&ED9&5N(&EN
M(%1H<F5A9"!6:65W`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E9`!(
M:6=H`$AI9V@@4')I;W)I='D`2&EG:&5S=`!(;U]M90!(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C
M=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T
M:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO
M;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A
M;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I`$AO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T
M=&%C:&UE;G1S/P!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W('1O
M(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R97!L>0!(=6UI9&ET>0!(
M=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05``24U!4"`H075T;R!$
M971E8W0@4')O=&]C;VQS*0!)34%0(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE
M8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S`$E-05`@;6%I;&)O>"!C<F5A
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E-
M05`@;W9E<B!34TP`24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF
M:6-A=&4I`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*0!)34%0('-E<G9E
M<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN`$E-05`L(&YO(%1,4P!)34%0+U!/
M4#,@36%I;"!397)V97)S`$E.0D]8`$E0($%D9')E<W,`25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W
M($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS
M('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RX`268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0
M(&]P96YS<VP@97AT96YS:6]N(&QO861E9"X`268@>6]U(&-O;G1I;G5E+"!A
M;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E(&QO<W0A`$EF
M('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO
M<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O
M9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@
M8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A
M;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EG;F]R90!)9VYO
M<F4@06QL`$EM86=E`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!5
M4DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM
M86=E('5P;&]A9`!);6%G97,`26UP;W)T`$EM<&]R="!+97D`26UP;W)T($ME
M>7!A:7(`26UP;W)T($UE<W-A9V5S`$EM<&]R="!01U`@2V5Y`$EM<&]R="!0
M97)S;VYA;"!#97)T:69I8V%T90!);7!O<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y`$EM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>0!);7!O<G0@
M4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<P!);7!O<G0@4'5B;&EC($ME
M>0!);7!O<G0@4'5B;&EC(%!'4"!+97D`26UP;W)T(%!U8FQI8R!3+TU)344@
M2V5Y`$EM<&]R="!3+TU)344@2V5Y`$EM<&]R="!M8F]X($9I;&4`26UP;W)T
M(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RX`26UP;W)T+"!3=&5P("5D
M`$EM<&]R=&%N=`!);7!O<G1A;G0@;65S<V%G97,`26UP;W)T960@)60@;65S
M<V%G97,@9G)O;2`E<RX`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I
M96QD<SH`26X@4')O8V5S<P!);E]S97)T(%)O=R!!9G1E<@!);F)O>`!);F-L
M=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_
M`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/P!);F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT
M`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M
M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YF;W)M
M871I;VX@;VX@)7,@4'5B;&EC($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA
M;"!0<FEV871E($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@
M2V5Y`$EN;&EN90!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@0V5R=&EF
M:6-A=&4@2&5R90!);G-E<G0@26UA9V4`26YS97)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>2!(97)E`$EN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME
M>2!(97)E`$EN<V5R="!0=6)L:6,@4$=0($ME>2!(97)E`$EN<V5R="!486)L
M90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`
M26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E
M:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R
M="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU
M;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F
M=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`
M26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E
M`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E
M9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED($%C=&EO;B!S96QE
M8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN=F%L:60@061D<F5S<P!);G9A
M;&ED(%)E;6]T92!-86EL8F]X`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`
M26YV86QI9"!B871C:"!)1"X`26YV86QI9"!C:&%R86-T97(@:6X@92UM86EL
M(&%D9')E<W,Z("5S+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV
M86QI9"!K97D`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO
M;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN
M=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`
M26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN`$EN=F%L:60@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97DN`$EN=F%L:60@<')O9'5C="!C;V1E+@!)
M;G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A
M;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A
M;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R=`!);G9E<G0@<V5L
M96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD
M`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`
M271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H
M25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`
M2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T
M:69Y(%)I9VAT`$M"`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N
M96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,
M96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2V5Y(&=E;F5R871I;VX@;6%Y('1A
M:V4@82!L;VYG('1I;64@=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME
M>2!G96YE<F%T:6]N/P!+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I
M;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+@!+97D@
M:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H879E(&YO(&%D9')E<W,@
M8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R(&-O;G1A8W1S+@!+97D@<W5C8V5S
M<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER
M:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`
M2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER
M9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A
M=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T($UA:6QB;W@@4&%G90!,87-T
M(%!A9V4`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,
M969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@
M4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!2
M86EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W
M`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!!='1A8VAM
M96YT<S\`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:V5D(&%T
M=&%C:&UE;G1S(&%R92!F;W)B:61D96XN`$QI;FMS`$QI;FMS('=I;&P@97AP
M:7)E(&]N("5S`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T
M(%1A8FQE<P!,:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O
M;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"!O;FQY('-E
M92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@
M:6X@=&AE($AE861E<@!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES
M=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@36%I
M;&)O>#H`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I
M;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C
M875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN
M8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,
M;W<@4')I;W)I='D`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L
M971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3&]W97-T`$QU>&5M8F]U<F<`
M34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N
M`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8`36%C:6YT;W-H($9I;&4`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%I;"!0<F5V:65W<P!-86EL('-E<G9E<B!T>7!E('1O
M(&-O;FYE8W0@=&\Z`$UA:6QB;W@`36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L
M87D@3W!T:6]N<P!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD
M:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S
M;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1
M=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!!
M;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%-E96X`36%R:R!!;&P@365S<V%G
M97,@:6X@1F]L9&5R(&%S(%5N<V5E;@!-87)K(&%S.@!-87)K(&1I9F9E<F5N
M="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA
M<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2D`36%R:R!S:6UP;&4@
M;6%R:W5P/P!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA
M;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H($%L;"!1=65R:65S`$UA=&-H
M($%N>2!1=65R>0!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I
M=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UA>&EM=6T@071T86-H;65N="!3:7IE`$UA>&EM=6T@3G5M
M8F5R(&]F($9O;&1E<G,`36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<P!-87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT
M<R!R96%C:&5D+@!-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C
M:&5D+@!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@1F]L9&5R
M($QI<W0`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@
M0V]M<&]S:71I;VX`365S<V%G92!$871E`$UE<W-A9V4@3W!T:6]N<P!-97-S
M86=E(%-E87)C:`!-97-S86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G
M92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T
M:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@5FEE=VEN
M9P!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@9FQA9W,`365S<V%G92!F;VQD
M97)S`$UE<W-A9V4@9G)O;2`E<P!-97-S86=E(&AA<R!A='1A8VAM96YT<P!-
M97-S86=E(&ES(&5N8W)Y<'1E9`!-97-S86=E(&ES('-I9VYE9`!-97-S86=E
M(&UA=&-H97,`365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2X`365S
M<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<P!-
M97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+@!-97-S86=E('1Y<&4`365S<V%G
M97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`
M365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN
M96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H
M;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI
M8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM
M92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E
M>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K
M86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@
M:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H
M:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R
M97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$
M+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF
M>0!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N
M86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A
M=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+@!-;W)E('1H86X@;VYE(&%D9')E<W,@9F]U
M;F0@9F]R(&9I96QD("(E<R(N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L
M>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F
M=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@<W!A;2!M97-S
M86=E<R!T;R!S<&%M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@
M24Y"3U@`36]V92!T;R!F;VQD97(`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I
M+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP
M87)T+V%L=&5R;F%T:79E`$UU;'1I<&QE($UE<W-A9V4@5FEE=P!-=6QT:7!L
M92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N
M`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@
M3D]4($%G<F5E`$Y/3D4`3D]410!.86UE`$YA;64@86YD+V]R(&5M86EL(&-A
M;FYO="!B92!E;7!T>0!.86UI8FEA`$YA=7)U`$YE961S($%C=&EO;@!.97!A
M;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"
M87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#
M02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E
M=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4`3F5T=V]R:P!.979E<@!.979E<B!S879E(&%T=&%C:&UE;G1S`$YE=P!.
M97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@1F]L9&5R`$YE=R!-86EL
M`$YE=R!-97-S86=E`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5
M<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!M97-S86=E<P!.
M97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.
M97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI
M`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!-97-S
M86=E`$YE>'0@4&%G90!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI
M9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!#97)T:69I8V%T92!F;W5N
M9`!.;R!%;F-R>7!T:6]N`$YO($ME>7,@:6X@2V5Y<FEN9P!.;R!-97-S86=E
M<P!.;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@4&5R<V]N86P@0V5R
M=&EF:6-A=&4@4')E<V5N=`!.;R!0<F5V:65W(%1E>'0`3F\@4'5B;&EC($ME
M>7,@1F]U;F0`3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N`$YO(&%T
M=&%C:&UE;G1S(&9O=6YD+@!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T
M92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@
M=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`
M3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!E
M;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+@!.
M;R!F:6QE('5P;&]A9&5D`$YO(&9O;&1E<B!S96QE8W1E9"X`3F\@9F]L9&5R
M<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN`$YO(&9O;&1E<G,@
M=V5R92!S<&5C:69I960`3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<P!.
M;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S`$YO(&EC;VYS(&9O=6YD
M+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.
M;R!M97-S86=E(&)O9'D@=&5X=`!.;R!M97-S86=E('-U<'!L:65D+@!.;R!M
M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H+@!.;R!N86UE('-P96-I9FEE
M9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@
M<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA
M;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@<&5R<V]N86P@4R]-24U%
M(&-E<G1I9FEC871E<R!I;7!O<G1E9"X`3F\@<&5R<V]N86P@<')I=F%T92!K
M97D@97AI<W1S('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R
M>7!T960N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P
M96-I9FEE9"X`3F\@<VED97,`3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O
M;F9I9W5R960N`$YO('-P96QL:6YG(&5R<F]R<P!.;R!S=6-H(&9I;&4`3F\@
M<W5G9V5S=&EO;G,`3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@
M;65T:&]D(&-O=6QD(&)E(&9O=6YD+@!.;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97(@<W!E8VEF:65D+@!.;R!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A
M=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I
M9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`3F]N90!.
M;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O
M;&L@27-L86YD`$YO<FUA;`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N
M($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`
M3F]T($1E;&5T960`3F]T($1R869T`$YO="!);7!O<G1A;G0`3F]T(%!E<G-O
M;F%L`$YO="!A(&1I<F5C=&]R>0!.;W0@82!V86QI9"!P=6)L:6,@:V5Y+@!.
M;W0@9&5L971E9"!M97-S86=E<P!.;W0@:6UP;&5M96YT960N`$YO="!I;7!O
M<G1A;G0@;65S<V%G97,`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E('1H
M870@=&AI<R!C86X@=&%K92!S;VUE('1I;64`3F]T97,`3F]T:&EN9P!.;W1H
M:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:69I8V%T:6]N.B!,:6YK960@
M871T86-H;65N="!D;W=N;&]A9&5D`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@
M;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@;6]N
M=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE=&EN
M9R!M;VYT:&QY+@!.=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O
M(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F(')O=W,`3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="X`3TL`3U(`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C
M=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD(&UE<W-A9V5S`$]L9"!P87-S
M=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]L9"!S96YT+6UA
M:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]M86X`3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!D:7-P;&%Y(&9O;&1E
M<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\`3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/
M;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C
M=&EO;BX`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4`3W!E;B!&;U]L9&5R`$]P96X@:6X@82!N97<@=VEN9&]W`$]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N`$]P96YE9"!&;VQD97(`3W!E;G,@=&AI<R!L:6YK
M(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;F%L(%!A
M<G1I8VEP86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T
M`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`
M3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA
M=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!-86EL
M($%C8V]U;G1S`$]T:&5R($]P=&EO;G,`3W5T8F]U;F0@4V5R=F5R`$]W;F5R
M(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0`%!'4"!$:6=I=&%L(%-I9VYA
M='5R90!01U`@16YC<GEP="!-97-S86=E`%!'4"!%;F-R>7!T960@1&%T80!0
M1U`@17)R;W(Z(`!01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R
M<V]N86P@<')I=F%T92!K97DN`%!'4"!/<'1I;VYS`%!'4"!087-S<&AR87-E
M($EN<'5T`%!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@
M82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%!'4"!0=6)L:6,@2V5Y`%!'4"!0
M=6)L:6,@2V5Y(%1E>'0`4$=0(%!U8FQI8R!+97D@9F]R("(E<R`H)7,I(B!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@4'5B;&EC($ME>2!F;W(@(B5S
M(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%!'4"!0=6)L:6,@2V5Y<FEN
M9P!01U`@4VEG;B!-97-S86=E`%!'4"!3:6=N+T5N8W)Y<'0@365S<V%G90!0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!'4"!P<FEV871E(&ME>2!S=6-C
M97-S9G5L;'D@861D960N`%!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F=6QL>2!A
M9&1E9"X`4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN
M`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!D
M:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@=F5R:69I960N`%!'
M4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!M97-S
M86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N`%!'4"!S=7!P;W)T(')E
M<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O
M=W-E<B!I<R!C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W
M<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H92!0
M1U`@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN`%!(4"!#;V1E
M`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!0
M32!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4#,`4$]0,R`H
M075T;R!$971E8W0@4')O=&]C;VQS*0!03U`S(&]V97(@4U-,`%!/4#,@;W9E
M<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*0!03U`S(&]V97(@4U-,
M("AS96QF+7-I9VYE9"D`4$]0,RP@;F\@5$Q3`%!/4TE8(&5X=&5N<VEO;B!I
M<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086=E("5D(&]F("5D`%!A
M9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4`4&%G92!W:71H('1H
M92!,87-T(%5N<V5E;B!-97-S86=E`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN
M96$`4&%R86=U87D`4&%R="AS*0!087)T;'D@0VQO=61Y`%!A<W-P:')A<V4`
M4&%S<W!H<F%S92`H06=A:6XI`%!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N
M;&]A9&5D+@!087-S<&AR87-E.@!087-S<&AR87-E<R!C86YN;W0@8F4@96UP
M='D`4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H`%!A<W-W;W)D`%!A<W-W;W)D
M(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O
M87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@
M(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO
M;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R;6ES<VEO;G,@9F]R
M('1H:7,@=7-E<B!C86YN;W0@8F4@8VAA;F=E9"X`4&5R<V]N86P`4&5R<V]N
M86P@26YF;W)M871I;VX`4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2X`4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C
M97-S9G5L;'DN`%!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM
M<&]R=&5D.B``4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S
M9G5L;'DN`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET
M8V%I<FX`4&EX96QS`%!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L
M:65S(&%N9"!F;W)W87)D<S\`4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G
M90!0;&%T:71U9&5S`%!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E
M<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D('-O=6YD
M(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U
M="!O=&AE<B!P;&%T9F]R;7,@=VEL;"!R97%U:7)E(&$@<&QU9VEN+@!0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A
M9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@
M;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V
M86QI9"!T:6UE+@!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F
M;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!E;G1E
M<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO
M=2!W:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC
M92!P97(@)7,@<V5S<VEO;BX`4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E
M(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N
M965D('1O(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S
M:6]N+@!0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@
M>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R!C;V]K:65S($%.
M1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S
M+"!Y;W4@=VEL;"!H879E('1O(&QO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@
M=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O
M;2!H:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R
M(&%N>2!I;F-O;G9E;FEE;F-E+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64N`%!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O
M<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E('-E;&5C="!A(&9O;&1E<B!B
M969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N`%!L96%S92!S96QE8W0@
M870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N`%!L96%S92!S96QE8W0@
M;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BX`4&QE87-E('-E
M;&5C="!O<B!E9&ET(&EN('1H92!B;W@@=&\@=&AE(')I9VAT.@!0;&5A<V4@
M='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0
M;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I`%!O=V5R960@8GD@2&]R9&4`4')E8V5D92!Y
M;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/P!0<F5C:7!I=&%T
M:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^
M8VAA;F-E`%!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!0<F5F
M<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U
M<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=P!0<F5V:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')E=FEO=7,@;W!T
M:6]N<P!0<FEN=`!0<FEN="!D;V-U;65N=`!0<FEO<FET>0!0<FEV871E($ME
M>0!0<FEV871E($ME>2!087-S=V]R9`!0<F]B;&5M`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4')O:F5C=',`4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N
M="!I<R!S96YT.R!D969A=6QT('1O($Y/`%!R;VUP="!E=F5R>2!T:6UE(&%N
M(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,`4')O;7!T('1E
M>'0`4')O=&]C;VPZ`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`
M4'5B;&EC($ME>2!);F9O`%!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O<G0@
M:&%S(&)E96X@9&ES86)L960N`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<E]G92!$
M96QE=&5D`%!U<F=E($1E;&5T960`4'5R9V4@1F]L9&5R*',I`%!U<F=E(%1R
M87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L9&5R
M(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RX`4'5R9V4@;VQD(&UE
M<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_`%!U<F=I;F<@)60@;65S<V%G
M97,@9G)O;2!4<F%S:"!F;VQD97(N`%!U<F=I;F<@,2!M97-S86=E(&9R;VT@
M5')A<V@@9F]L9&5R+@!1871A<@!1=65R>0!1=6]T80!1=6]T82!S=&%T=7,Z
M("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`475O=&$@<W1A='5S.B`E+C)F
M34(@+R!.3R!,24U)5`!1=6]T82!S=&%T=7,Z($Y/($Q)34E4`%%U;W1I;F<@
M)68Z`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD
M(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5C96EV960@3VX`4F5C96EV960@4VEN8V4`4F5C96EV960@56YT:6P`4F5D
M:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T($UE<W-A9V4`4F5D:7)E8W0@=&AI
M<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE9"X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!&;VQD97(@5FEE=W,Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z
M`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296QO860@5FEE
M=P!296UA<FMS`%)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E($UA:6QB;W@Z`%)E;6]T
M92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!&:65L9"!&<F]M
M(%-E87)C:`!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V
M92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@<V]U<F-E`%)E;6]V92!T:&4`4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!2
M96UO=F4@=7-E<CH@)7,`4F5N86UE($9O;&1E<BAS*0!296YA;64@<V5N="UM
M86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_`%)E;F%M:6YG("(E
M<R(@=&\@(B5S(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60`4F5P;%]Y('1O($QI<W0`4F5P;&%C92!W:71H.@!297!L>0!297!L>2!3
M96YT+@!297!L>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2!T;R!,:7-T
M`%)E<&QY('1O($QI<W0Z`%)E<&QY('1O(%]!;&P`4F5P;'D@=VET:"!.;W0@
M4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE
M>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I
M;F9O<FUA=&EO;BX`4F5P;'DM5&\`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T
M(&%S($EN;F]C96YT`%)E<&]R="!A<R!3<&%M`%)E<75E<W0@82!?4F5A9"!2
M96-E:7!T`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`4F5Q=65S=&5D
M(&UE<W-A9V4@;F]T(&9O=6YD+@!297%U97-T960@<V5R=FEC92!C;W5L9"!N
M;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I
M9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297%U:7)E
M9"!087)T:6-I<&%N=`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R
M(%!A<W-W;W)D`%)E<W!O;F1E;G0@4W1A='5S(%5P9&%T960N`%)E<W1O<F4@
M3&%S="!1=65R>0!297-U;'1S`%)E<W5M90!297-U;64@>6]U<B!S97-S:6]N
M`%)E='5R;B!T;R`B365S<V%G92!#;VUP;W-I=&EO;B(`4F5T=7)N('1O($9E
M=&-H($UA:6P`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O('1H92!M86EL
M8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN
M9R!A(&UE<W-A9V4_`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E
M<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED
M9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O
M<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F
M=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`
M4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M
M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2
M=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344`4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T($UE<W-A9V4`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%,O34E-12!%<G)O<CH@`%,O34E-
M12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E
M(&ME>2X`4R]-24U%($]P=&EO;G,`4R]-24U%(%!A<W-P:')A<V4@26YP=70`
M4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BX`4R]-24U%(%!U8FQI8R!+97D@9F]R("(E
M<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!3+TU)344@4'5B;&EC($ME
M>2!S=6-C97-S9G5L;'D@861D960N`%,O34E-12!0=6)L:6,@2V5Y<FEN9P!3
M+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D
M960N`%,O34E-12!3:6=N($UE<W-A9V4`4R]-24U%(%-I9VXO16YC<GEP="!-
M97-S86=E`%,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES
M=&5M+@!3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@
M<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`4R]-
M24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F
M('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N;F]T(&)E(&1I<W!L87EE9"X`4R]-
M24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG
M;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4R]-24U%('-U<'!O
M<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U
M<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W
M:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@
M=&AE(%,O34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S
M<V%G:6YG`%--5%``4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E
M(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!37W5B:F5C=`!380!3
M85]V92!A(&-O<'D@:6X@`%-A7W9E(&%S`%-A:6YT($AE;&5N80!386EN="!+
M:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE
M(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@
M4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E
M`%-A=F4@(B5S(@!3879E("5S`%-A=F4@071T86-H;65N=',@=VET:"!M97-S
M86=E(&EN('-E;G0M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`4V%V92!);6%G
M90!3879E($EM86=E(&EN($=A;&QE<GD`4V%V92!/<'1I;VYS`%-A=F4@4W1A
M=&EO;F5R>0!3879E(%]$<F%F=`!3879E(&%S`%-A=F4@9')A9G1S(&%S('5N
M<V5E;C\`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E(')E8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A
M9&1R97-S(&)O;VL_`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_
M`%-A=F4@<V5N="!M86EL/P!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V%V:6YG('1H92!D
M<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S
M`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@)7,`
M4V5A<F-H($5N9VEN97,`4V5A<F-H($]P=&EO;G,`4V5A<F-H(%)E<W5L=',`
M4V5E;@!396QE8W0`4V5L96-T($%N;W1H97(@06-C;W5N=`!396QE8W0@1FEL
M97,`4V5L96-T(&$@9&%T90!396QE8W0@82!F:65L9`!396QE8W0@82!G<F]U
M<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!3
M96QE8W0@82!S=&%T:6]N97)Y.@!396QE8W0@82!U<V5R('1O(&%D9`!396QE
M8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H
M:6YG(&9O<B!A9&1R97-S97,N`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N
M(&5X<&%N9&EN9R!A9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C
M="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S
M('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@
M8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C
M="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z
M`%-E;&5C="!T:&4@9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BX`4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T
M:&4@;6%I;"!S97)V97(@='EP90!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&5C=&5D($%D9')E<W,@8F]O:W,Z
M`%-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(`4V5N9"!,871E<W0@26YF
M;W)M871I;VX`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE;2!297!O<G0`4V5N
M9"!335,`4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE
M('-E;F1E<C\`4V5N96=A;`!396YS;W(Z(`!396YT(&UA:6P@9F]L9&5R`%-E
M;G0@;6%I;"!F;VQD97(Z`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G
M<F\`4V5R:6%L($YU;6)E<@!397)V97(`4V5R=F5R(&%N9"!&;VQD97(@26YF
M;W)M871I;VX`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`
M4V5R=F5R.@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S
M<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('!R969E
M<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L
M971E(&UE<W-A9V5S+@!3970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@
M8V]M<&]S:6YG(&UE<W-A9V5S/P!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA
M="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE
M;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N
M<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!3
M97EC:&5L;&5S`%-H87)E($9O;&1E<G,`4VAA<F4@;6%I;"!F;VQD97)S`%-H
M87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E<G,N`%-H;W!P
M:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_`%-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O
M=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A
M;B!B92!T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92X`4VAO
M=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE
M9"!F;W(@4$=0(&1A=&$_`%-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@
M8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/P!3:&]U;&0@>6]U<B!01U`@
M<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y
M(&1E9F%U;'0_`%-H;W<`4VAO=R!!;&P@1F]L9&5R<P!3:&]W($%L;"!(96%D
M97)S`%-H;W<@1&5L971E9`!3:&]W($QI;6ET960@2&5A9&5R<P!3:&]W($UA
M:6QI;F<@3&ES="!);F9O<FUA=&EO;@!3:&]W($]N;'D@4W5B<V-R:6)E9"!&
M;VQD97)S`%-H;W<@56YS=6)S8W)I8F5D`%-H;W<@86X@:6-O;B!T;R!A;&QO
M=R!S=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\`4VAO
M=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE
M(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G
M:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;&5G96YD(&EN('1H92!M
M86EL8F]X('9I97<_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO
M=R!P:6-K97(`4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE<W-A9V5S(&]N
M;'D_`%-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_`%-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\`4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H92!M96YU8F%R/P!3
M:&]W('1H92!);6%G97,`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@9FEL
M=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O
M;&1E<C\`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E
M<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:&]W;@!3:')I;FL`
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T`%-I7WIE`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA
M='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I9VYE9`!3:6YG87!O<F4`4VEZ
M90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO
M=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W
M(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN
M('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M
M<P!3;W)T(&)Y($%R<FEV86P`4V]R="!B>2!$871E`%-O<G0@8GD@1G)O;2!!
M9&1R97-S`%-O<G0@8GD@365S<V%G92!3:7IE`%-O<G0@8GD@4W5B:F5C=`!3
M;W)T(&)Y(%1H<F5A9`!3;W)T(&)Y(%1O($%D9')E<W,`4V]R="!O<F1E<B!S
M96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E
M(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT
M(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N
M9"!P861D:6YG`%-P86EN`%-P86T`4W!A;2!F;VQD97(Z`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5C:6%L(%9I<G1U
M86P@1F]L9&5R<R!C86YN;W0@8F4@961I=&5D+@!3<&5L;"!#:&5C:P!3<&5L
M;"!#:&5C:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R<F]R
M<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-P;&ET(&-E;&P`
M4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD
M87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I
M;F-E`%-T871I;VYE<GD`4W1A=&EO;F5R>2!N86UE.@!3=&%T:6]N97)Y('1Y
M<&4Z`%-T871I;VYE<GDZ`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP($%T=&%C
M:&UE;G0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1R:7`@;&EN
M96)R96%K<S\`4W1Y;&4@6T-34UT`4W4`4W5B7VIE8W0`4W5B9&ER96-T;W)Y
M("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FIE8W0@1FEE;&0`4W5B;6ET
M`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN
M(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E
M;B!A<'!R;W9E9"X`4W5B<V-R:6)E('1O($9O;&1E<BAS*0!3=6)S8W)I<'0`
M4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M
M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O
M;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@
M8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S
M<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U9V=E<W1I;VYS`%-U;6UA<GD`4W5N
M(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U
M;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3
M=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL
M86YD`%-W961E;@!3=VET8V@@0V]M<&]S:71I;VX@365T:&]D`%-W:71C:"!T
M;R!(5$U,(&-O;7!O<VET:6]N`%-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O
M<VET:6]N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y
M;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L
M:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M
M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE
M(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9@!487)G970Z`%1A<VMS`%1E7WAT`%1E;&5P:&]N92!.=6UB97(`5&5M
M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!4
M96UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L
M871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!4
M96YT871I=F4Z(`!496YT871I=F5L>2!!8V-E<'0@<F5Q=65S=`!496YT871I
M=F5L>2!!8V-E<'1E9`!497)M<R!O9B!397)V:6-E(&9I;&4@;F]T('-P96-I
M9FEE9"!I;B!C;VYF+G!H<`!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E
M>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E>'1E
M;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($9R;VTZ(&-O;'5M;B!O9B!T
M:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.@!4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@
M24U!4"!S97)V97(@9&]E<R!N;W0@87!P96%R('1O('-U<'!O<G0@=&AE(&%U
M=&AE;G1I8V%T:6]N(&UE=&AO9"!S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@
M>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA8VEN=&]S:"!R97-O=7)C92!F
M;W)K`%1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO
M861E9"`E<RX`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D
M('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@
M17AI=&EN9RX`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4
M:&4@86-C;W5N="`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@861M:6YI<W1R
M871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO
M;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H
M92!A='1A8VAM96YT('=A<R!N;W0@9F]U;F0N`%1H92!B;W1T;VT@<VED92!O
M;FQY`%1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;7!O<V4@
M=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@
M>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N
M`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N86UE9"!T
M;R`B)7,B+@!4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S
M('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960`5&AE(&1E
M=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N
M;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!D<F%F="!H87,@8F5E;B!S879E
M9"!T;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S
M(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E=F5N="!W
M87,@861D960@=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9I96QD("(E<R(@8V%N
M)W0@8F4@97AP86YD960N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQD97(@
M(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L9&5R("(E<R(@8V]N=&%I;G,@
M:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@
M<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N
M;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!D96QE
M=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N`%1H
M92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@9&5L971E
M9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E
M<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@
M=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S
M('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N`%1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES
M('!A<G0Z`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!I;6%G92!S879E('=I;F1O=R!C86X@
M;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W
M<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!I;6%G97,@=VEL;"!B
M92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@
M>6]U<B!A9&1R97-S8F]O:RX`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M86EL('-E<G9E<B!G96YE
M<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@;6%I;"!S
M97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M
M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I
M;F<@;65S<V%G93H`5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2X`
M5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@*"5D(&)Y=&5S*2!E>&-E961S
M(&9E=&-H('-I>F4@;&EM:70N`%1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D
M(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A9V4@:&%S(&)E
M96X@9&5L971E9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N`%1H
M92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+@!4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA
M<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N
M86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N`%1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O
M<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B
M;&]C:R!P;W!U<"!W:6YD;W=S/P!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD
M(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M
M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE
M=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y
M<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+@!4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y
M(&-A;B!B92!V:65W960@)7,N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO
M="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!4:&4@<F5Q=65S
M=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM96YT
M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'D`5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q
M=65S=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(&9R
M;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S
M92!C;&EC:R`E<R!T;R!S96YD('1H92!N;W1I9FEC871I;VX@;65S<V%G92X`
M5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4
M:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T
M;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92X`5&AE('-I9VYA
M='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N`%1H92!S:6=N871U<F4@=V%S
M('-U8V-E<W-F=6QL>2!R97!L86-E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(&9I;&4@9&]E
M<R!N;W0@97AI<W0N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T
M+@!4:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B965N(&%D9&5D+@!4:&4@<W1A
M=&EO;F5R>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S=&%T:6]N97)Y
M("(E<R(@:&%S(&)E96X@=7!D871E9"X`5&AE('1A<VL@:&%S(&)E96X@861D
M960@=&\@>6]U<B!T87-K;&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@
M9&]E<R!N;W0@97AI<W0N`%1H92!T97AT(&]F('1H92!M97-S86=E`%1H92!T
M97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT
M(&]F('1H92!R971U<FYE9"!M97-S86=E`%1H92!T97AT(&]F('1H92!R971U
M<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT(&]F('1H
M92!S96YT(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92!C
M86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T
M(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O
M='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!U<V5R)W,@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N
M`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M
M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@86QT
M97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`
M5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M`%1H97)E(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92X`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES
M=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B
M;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@
M<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA
M>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P
M87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG
M(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S
M86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G
M97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A
M;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O;2`B)7,B('1O("(E<R(N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N`%1H97)E('=A<R!A
M;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S+@!4
M:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES($A4
M34P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+@!4:&ES($A4
M34P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D
M(&EM86=E<R!A<'!E87(@;&EK92!T:&ES.B``5&AI<R!)34%0('-E<G9E<B!D
M;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!01U`@4'5B
M;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N`%1H:7,@86-T
M:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@
M:6UP;&5M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A
M;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R
M,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`
M5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E
M('9I<VET("5S`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G92!C;VYT86EN
M<R!A($UA8VEN=&]S:"!F:6QE+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@
M871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA
M(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@
M=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S
M86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N
M+"!B=70@=&AE(&9O<FUA="!O9B!T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BX`
M5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'
M4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z(`!4:&ES(&UE<W-A9V4@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@
M*&%C8V]R9&EN9R!T;R!21D,@,C`Q-2DN`%1H:7,@;65S<V%G92!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="X`
M5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'
M4"X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA
M(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@
M4R]-24U%+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@
M4$=0+@!4:&ES(&UE<W-A9V4@=&\`5&AI<R!M97-S86=E('=A<R!W<FET=&5N
M(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&$@8V]M<&]S92!W:6YD;W<N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AR96%D($1I<W!L87D`5&AR
M96%D(%9I97<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4
M:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4
M:71L92`H=&]O;'1I<"DZ`%1O`%1O($%D9')E<W,`5&\@<V5L96-T(&UU;'1I
M<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!W:&EL92!C;&EC:VEN9RX`5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&\@=7-E(&$@5$Q3(&-O;FYE
M8W1I;VXL('EO=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U
M+C`N-B!O<B!H:6=H97(N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`
M5&]T86P@071T86-H;65N=',@4VEZ93H`5')A;G-L871I;VYS`%1R87-H(&9O
M;&1E<@!4<F%S:"!F;VQD97(Z`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O
M<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY
M*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L
M=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N
M9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L
M9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E
M860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L
M9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$`56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W
M:6QL(&)E(&5X8V5E9&5D+@!5;F%N<W=E<F5D`%5N86YS=V5R960@;65S<V%G
M97,`56YD96QE=&4`56YD97)L:6YE`%5N9&ES8VQO<V5D(%)E8VEP:65N=',`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!$871E`%5N:VYO=VX@24U!4"!R97-P;VYS92!F
M<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S`%5N:VYO=VX@
M365E=&EN9P!5;FMN;W=N(%)E8VEP:65N=`!5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U
M<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0`56YL;V%D(%!A<W-P:')A<V4`56YN86UE9`!5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N`%5N<V5E;@!5;G-E="!C;VQO<@!5;G-U8G-C<FEB92!F<F]M($9O;&1E
M<BAS*0!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5
M<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`B
M)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y
M`%5S92!#=7)R96YT.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@24U!4"!F
M;VQD97(@<W5B<V-R:7!T:6]N<S\`57-E(%-33`!5<V4@5FER='5A;"!4<F%S
M:"!&;VQD97(_`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N`%5S97(`57-E<B`B)7,B('-U8V-E<W-F=6QL>2!G
M:79E;B!T:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B
M+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI
M;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B
M)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R
M<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E
M<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE
M>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@
M:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT
M<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ
M`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<`
M5FEE=R`E<P!6:65W("5S(%!U8FQI8R!+97D`5FEE=R!(5$U,(&-O;G1E;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!-97-S86=E<P!6:65W(%!E<G-O
M;F%L(%!R:79A=&4@2V5Y`%9I97<@4&5R<V]N86P@4'5B;&EC($ME>0!6:65W
M(%1H<F5A9`!6:65W(%1H=6UB;F%I;`!6:65W(&%N(&5X=&5R;F%L('=E8B!P
M86=E`%9I97<@87,@)7,`5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@
M=VEN9&]W`%9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W
M(&5V96YT`%9I97<@;65S<V%G97,@:6X@)7,`5FEE=R!O<B!M86EL8F]X('1O
M(&1I<W!L87D@869T97(@;&]G:6XZ`%9I97<@=&%S:P!6:65W('1H92!);6%G
M97,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N
M4RX`5FER='5A;"!&;VQD97(@(B5S(B!C<F5A=&5D('-U8V-E<V9U;&QY+@!6
M:7)T=6%L($9O;&1E<B!D;V5S(&YO="!E>&ES="X`5FER='5A;"!&;VQD97)S
M`%9I<G1U86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN`%9I<G1U86P@24Y"
M3U@`5FER='5A;"!)3D)/6"!&;VQD97(`5FER='5A;"!4<F%S:`!6:7)T=6%L
M(%1R87-H($9O;&1E<@!6:7)T=6%L(%1R87-H($9O;&1E<B!D;V5S(&YO="!E
M>&ES="X`5FER='5A;"!F;VQD97(@;&%B96P`5FES:6)I;&ET>0!6:7-I8FEL
M:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10
M`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S
M=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E
M8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I
M`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAA="!S:&]U
M;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B
M965N(')E<&]R=&5D(&%S('-P86T@;W(@:6YN;V-E;G0_`%=H96X@9&5L971I
M;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I
M;G-T96%D(&]F(&UA<FMI;F<@=&AE;2!A<R!D96QE=&5D/P!7:&5N(&]P96YI
M;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S
M=&%R="!O;C\`5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V
M92!A='1A8VAM96YT(&1A=&$_`%=H96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N
M9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E;F0@
M=&\@=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S97,@=VET
M:&]U="`B0"(I/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VAI=&5L:7-T`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T
M:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N
M(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`
M5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO
M=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D
M<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN
M92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E
M9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@
M;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@86)O
M=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H
M<RDZ`%EO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S
M(&-O;G1A:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R
M92!A='1E;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS
M*2X`66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO
M=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T
M:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BX`66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N`%EO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C
M:W,N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!F;VQD97)S+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@87)E
M(')E;F%M:6YG('1H92!F;VQD97(Z(`!9;W4@8V%N('5S92!T:&4@9F]L;&]W
M:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F
M;W(@=&AE(&-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I
M9VYA='5R92X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+@!9;W4@8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@
M(B5S(BX`66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I
M8V4@86=R965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"!T;R!L;V=I
M;BX`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@
M9F]L9&5R`%EO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T
M:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+@!9;W4@:&%V92`E<R!N97<@
M;65S<V%G97,N`%EO=2!H879E(#$@;F5W(&UE<W-A9V4N`%EO=2!H879E(&%L
M<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92X`66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<CH`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD
M97)S.@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@
M;75S="!E;G1E<B!A="!L96%S="!O;F4@<F5C:7!I96YT+@!9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU
M<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@
M:V5Y('1O('9I97<@=&AI<R!M97-S86=E`%EO=2!M=7-T(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W
M('1H:7,@;65S<V%G90!9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O
M>"!F:7)S="X`66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L
M971E9"X`66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S
M<&5C:69Y(&$@<F5C:7!I96YT+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@
M;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O(&AA
M=F4@(B5S(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RX`
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9
M;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+@!9;W4@
M<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N`%EO=2!W97)E(&YO="!S
M=6)S8W)I8F5D('1O("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60`66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@<W5C8V5S<V9U;&QY
M('-U8G-C<FEB960@=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS
M=6)S8W)I8F5D(&9R;VT@(B5S(@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO
M=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(%!'4"!0=6)L
M:6,O4')I=F%T92!+97ES`%EO=7(@4')I=F%T92!+97D`66]U<B!0=6)L:6,@
M2V5Y`%EO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E
M;3X`66]U<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S`%EO
M=7(@86-C;W5N=',Z`%EO=7(@86QI87,@861D<F5S<V5S.B`\96T^*&]P=&EO
M;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/@!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@
M=&AI<R!I;6%G92!T>7!E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0
M('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U
M;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT
M(&5N8W)Y<'1I;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L:6YK960@871T
M86-H;65N="!H87,@8F5E;B!D;W=N;&]A9&5D(&)Y(&%T(&QE87-T(&]N92!U
M<V5R+@H*071T86-H;65N="!N86UE.B`E<PI!='1A8VAM96YT(&1A=&4Z("5S
M"@I#;&EC:R!O;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@<&5R;6%N96YT;'D@
M9&5L971E('1H92!A='1A8VAM96YT.@HE<P!9;W5R(&QO9VEN(&AA<R!E>'!I
M<F5D+@!9;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N
M`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EO=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA
M`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!!9&1R97-S97-=
M`%M(:61E(%%U;W1E9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!!9&1R97-S97,@+0!;4VAO=R!1=6]T960@5&5X="`M`%M3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%M3:&]W(&%D9')E<W-E<R`M
M("5S(')E8VEP:65N='-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T)C8P!?0FQA8VML:7-T`%]#3$D`7T-C`%]$871A5')E90!?1&5L971E
M`%]$96QE=&4@4F]W`%]&;VQD97)S`%]'<F]U<',`7TAE;'``7TED96YT:71Y
M`%]);6%G92!0<F]P97)T:65S+BXN`%]);F)O>`!?3&]G(&EN`%],;V<@;W5T
M`%]-97-S86=E(%-O=7)C90!?36]D:69Y($QI;FLN+BX`7TYE=R!-97-S86=E
M`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U!R:6]R:71Y`%]2969R
M97-H("5S`%]296UO=F4@3&EN:RXN+@!?4F5P;'D`7U-E87)C:`!?4V5N9"!-
M97-S86=E`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?5&AR96%D`%]4
M;P!?56YD96QE=&4`7U5S97)S`%]6:65W(%1H<F5A9`!?5VAI=&5L:7-T`&%D
M9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!A='1A8VAM96YT`&%T=&%C
M:&UE;G1S+GII<`!B>71E<P!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@
M;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM
M86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET
M:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5N
M=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O;0!F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`
M:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@
M<V]F='=A<F4@97)R;W(`:V5Y`&QI;F5S70!M86EL8F]X(&9I;&4`;6MI<V]F
M<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]N
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`&]R`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E8VEP:65N
M='-=`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U
M;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%14
M4`!S<&5L;&EN9R!E<G)O<@!S<&5L;&EN9R!E<G)O<G,`<W,`<W1E861Y`'-Y
M<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`
M=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`>6]U<B!B;&%C:VQI
M<W0`>6]U<B!W:&ET96QI<W0`4')O:F5C="U)9"U697)S:6]N.B!F<E]&4@I2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-BTP,2TP-R`Q-3HU-RLP,3`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#8M,#,M,#$@,#DZ-3@K,#$P,`I,87-T+51R86YS;&%T
M;W(Z(%1H:65R<GD@5&AO;6%S(#QT:&EE<G)Y0'!O;7!O+FYE=#X*3&%N9W5A
M9V4M5&5A;3H@1G)E;F-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U6
M97)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0
M;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`^(#$I.PH`("`@
M("!#8Z`Z(``@("`@("#`H#H@`"`@("!$871EH#H@`"`@("`@1&6@.B``("AI
M;"!Y(&$@)7,@:F]U<G,I`"A4;W5C:&4@9"=A8V/H<R!R87!I9&4@)7,I`"`H
M9&%N<R`E<R!J;W5R<RD`("AA=6IO=7)D)VAU:2D`("AD96UA:6XI`"`H:&EE
M<BD`($]B:F5TH#H@`"#@(``@9&%N<R``JZ`E<Z"[(&XG97-T('!A<R!U;B!D
M;W-S:65R`*N@)7.@NR!N)V5S="!P87,@=6X@8VAO:7@@=F%L:61E+@"KH"5S
MH+L@;B=E<W0@<&%S(&-O;F9I9W5RZ2!D86YS(&QE(')E9VES=')E(&1E($AO
M<F1E+@!,)VEN=&5R<'+I=&5U<B!D)V%R8G)E(*N@)7.@NR!N)V$@<&%S(.ET
MZ2!T<F]U=NDN`*N@)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM92!D97,@
M9W)O=7!E<RX`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S>7-TZ&UE(&1E<R!P
M97)M:7-S:6]N<RX`JZ`E<Z"[(&XG82!P87,@Z73I(&-RZ>F@.B`E<RX`3B9O
M<F1M.P`E+C)FH$UO("\@)2XR9J!-;R`@*"4N,F8E)2D`)2XR9J!-;R!U=&EL
M:7/I<R!S=7(@)2XR9J!-;R!P97)M:7,@*"4N,F:@)24I`"5D("5S(&5T("5S
M`"5D(&UE<W-A9V5S`"5D(&IO=7)S(&%V86YT(&PG97AP:7)A=&EO;B!D92!V
M;W1R92!M;W0@9&4@<&%S<V4N`"5D(&UE<W-A9V5S(&]N="#I=.D@<W5P<')I
M;>DH<RDN`"5D(&UE<W-A9V5S(&XG87EA;G0@<&%S(.ETZ2!C;VYS:63I<NES
M(&-O;6UE(&1E<R!P;W5R<FEE;',@;VYT(.ETZ2!R87!P;W)TZ7,@X"!V;W1R
M92!A9&UI;FES=')A=&5U<B!S>7-TZ&UE+@`E9"!M97-S86=E<R!O;G0@Z73I
M(&ED96YT:69IZ7,@8V]M;64@;B?I=&%N="!P87,@9&5S('!O=7)R:65L<RX`
M)60@;65S<V%G97,@8V]N<VEDZ7+I<R!C;VUM92!D97,@<&]U<G)I96QS(&]N
M="#I=.D@<F%P<&]R=.ES(.`@=F]T<F4@861M:6YI<W1R871E=7(@<WES=.AM
M92X`)60@;65S<V%G97,@;VYT(.ETZ2!I9&5N=&EF:>ES(&-O;6UE('!O=7)R
M:65L<RX`365S<V%G97,@)60@X"`E9"!S=7(@)60`)60M<'+I=FES:6]N(&1U
M(&IO=7(`)7,@+2!.;W1I8V4`16UP<F5I;G1E(%!'4"!D92`E<P`E<Z!+;P`E
M<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E("9N9&%S:#L@0V]N9FER;6%T
M:6]N`$-O;F9I9W5R871I;VX@)7,`26YS8W)I<'1I;VX@9&4@)7,`0V]N9&ET
M:6]N<R!D)W5T:6QI<V%T:6]N(&1E("5S`"5S(&5X:7-T92!DZ6K@+@`E<R!E
M>&ES=&4@9.EJX"X@5F]T<F4@9&]S<VEE<B`E<R!N)V$@<&%S(.ETZ2!R96YO
M;6WI+@`@)7.@X"`E<R`E<P`E<R!N92!S96UB;&4@<&%S(.IT<F4@=6YE(&)O
M[G1E('9A;&ED92X`3&4@9&]S<VEE<B`E<R!A(.ETZ2!R96YO;6WI(&%U(&3I
M8G5T(&1U(&UO:7,N`"5S(&$@86-C97!TZ2X`)7,@82!A;FYU;.D@JZ`E<Z"[
M+@`E<R!A(')E9G5SZ2X`)7,@82!RZ7!O;F1U(.`@=6YE(')E<77J=&4@<W5R
M('-E<R!D:7-P;VYI8FEL:73I<RX`)7,@82!RZ7!O;F1U(.`@;"=I;G9I=&%T
M:6]N(&1E(*N@)7.@NRX`)7,@=F]U<R!A(&5N=F]YZ2!S97,@9&ES<&]N:6)I
M;&ETZ7,N`"5S(&$@Z73I(&%C8V5P=.D@<V]U<R!RZ7-E<G9E<RX`)7,@97-T
M('!RZG0@X"!E9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N
M8V4@8V]C:.EE<R!C:2UD97-S;W5S+B!3Z6QE8W1I;VYN97H@;&$@;W4@;&5S
M(&]PZ7)A=&EO;BAS*2!Q=64@=F]U<R!V;W5L97H@969F96-T=65R(&-E='1E
M(&9O:7,M8VDN`"5S(&5S="!O8FQI9V%T;VER90`E<R!M:6YU=&5S`"5S(&YO
M;B!T<F]U=ND`)7,@9&5M86YD92!V;W,@9&ES<&]N:6)I;&ETZ7,N`"5S('+I
M8VQA;64@=F]T<F4@<'+I<V5N8V4@X""KH"5SH+LN`"5SH.`@)7,@9&4@)7,`
MJZ`E<Z"[(&$@8FEE;B#I=.D@86IO=73I(.`@JZ`E<Z"[+@`E<R!S;W5H86ET
M92!C;VUP;.ET97(@JZ`E<Z"[+@`E<R!S;W5H86ET92!V;W5S(&EN9F]R;65R
M(&1E(*N@)7.@NRX`)7,@<V]U:&%I=&4@<F5C979O:7(@;&5S(&1E<FYIZ')E
M<R!I;F9O<FUA=&EO;G,@<W5R(*N@)7.@NRX`0V%R;F5T(&0G861R97-S97,@
M9&4@)7,`06=E;F1A(&1E("5S`$)L;V,M;F]T97,@9&4@)7,`3&ES=&4@9&4@
M=.)C:&5S(&1E("5S`"5SH#H@)7,`)7.@.B`E<R`H)60F;F)S<#MD929N8G-P
M.R5D*0`E<Z`Z(&PGZ6UE='1E=7(@9&4@8V4@;65S<V%G92!A('!U(.IT<F4@
M9F%L<VEF:>DN($%T=&5N=&EO;B!E;B!S=6EV86YT(&QE<R!L:65N<R!Q=2=I
M;"!C;VYT:65N="!O=2!E;B!F;W5R;FES<V%N="!D97,@:6YF;W)M871I;VYS
M('!E<G-O;FYE;&QE<R#@(&PGZ6UE='1E=7(N`"A!<'!L:7%U97(@8V5S(&-H
M86YG96UE;G1S(&5T('!O=7)S=6EV<F4@X"!L)^EC<F%N('-U:79A;G0N*0`H
M06YN=6QE<B!L97,@8VAA;F=E;65N=',@970@<F5V96YI<B#@(&PGZ6-R86X@
M9&4@<NED86-T:6]N*0`H2%1-3``H5&5X=&4@8G)U="D`*%)E=F5N:7(@X"!L
M)^EC<F%N(&1E('+I9&%C=&EO;B!A<'+H<R!A=F]I<B!A<'!L:7%UZ2!T;W5T
M97,@;&5S(&UO9&EF:6-A=&EO;G,N($QE<R!C:&%N9V5M96YT<R!E;B!C;W5R
M<R!N92!S97)O;G0@4$%3(&%P<&QI<77I<RXI`"A2979E;FER(.`@;"?I8W)A
M;B!D92!RZ61A8W1I;VX@87!RZ',@879O:7(@87!P;&EQ=>D@=&]U=&5S(&QE
M<R!M;V1I9FEC871I;VYS+B!,97,@8VAA;F=E;65N=',@96X@8V]U<G,@;F4@
M<V5R;VYT(%!!4R!A<'!L:7%UZ7,N*0`J($QE<R!A:F]U=&5R(&5N(&-L:7%U
M86YT('-U<B!/2R`J`"H@5F5U:6QL97H@<^EL96-T:6]N;F5R('5N92AD97,I
M(&%D<F5S<V4H<RD@*@`L(&5N(')A9F%L92``<F%F86QE("5S("5S`'9A<FEA
M8FQE(&1U("5S(&%U("5S`"TM(%/I;&5C=&EO;FYE<B`M+0`Q(&UE<W-A9V4@
M82#I=.D@<W5P<')I;>DN`%5N(&UE<W-A9V4@82#I=.D@<F%P<&]R=.D@X"!V
M;W1R92!A9&UI;FES=')A=&5U<B!S>7-TZ&UE(&-O;6UE(&XGZ71A;G0@<&%S
M('5N('!O=7)R:65L+@`Q(&UE<W-A9V4@82#I=.D@:61E;G1I9FGI(&-O;6UE
M(&XGZ71A;G0@<&%S('5N('!O=7)R:65L+@!5;B!M97-S86=E(&$@Z73I(')A
M<'!O<G3I(.`@=F]T<F4@861M:6YI<W1R871E=7(@<WES=.AM92!C;VUM92#I
M=&%N="!U;B!P;W5R<FEE;"X`,2!M97-S86=E(&$@Z73I(&ED96YT:69IZ2!C
M;VUM92!P;W5R<FEE;"X`,3`P(&-A<F%C=.AR97,`,3`P,"!C87)A8W3H<F5S
M`$9O<FUA="`Q,B!H975R97,`1F]R;6%T(#(T(&AE=7)E<P`R-"!H975R97,`
M,C4P(&-A<F%C=.AR97,`-3`P(&-A<F%C=.AR97,`/%!RZ6/I9&5N=`!5;F4@
M8F%S92!D92!D;VYNZ65S('!R:6YC:7!A;&4@*&)A8VME;F0I(&5S="!NZ6-E
M<W-A:7)E('!O=7(@8V4@8FQO8P!5;F4@97)R975R(&9A=&%L92!S)V5S="!P
M<F]D=6ET90!5;F4@:6UA9V4@9&4@9W)A;F1E('1A:6QL92!N;VUMZ64@)7,@
M97-T(&IO:6YT92#@(&-E(&UE<W-A9V4N`%5N(&UE<W-A9V4@<75E('9O=7,@
M879E>B!E;G9O>>D@82!P<F]V;W%UZ2!U;F4@;F]T:69I8V%T:6]N(&5N(')E
M=&]U<B!D=2!D97-T:6YA=&%I<F4N`%5N92!C;&5F('!U8FQI<75E(%!'4"!E
M<W0@;NEC97-S86ER92!P;W5R(&-H:69F<F5R('5N(&UE<W-A9V4N`%5N92!C
M;&5F('!U8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P;W5R(';I<FEF:65R
M(&QA('-I9VYA='5R92!D)W5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E
M(%!'4"P@=6YE(&-L968@<')I=NEE(%!'4"P@970@=6YE('!H<F%S92!S96-R
MZ'1E('-O;G0@;NEC97-S86ER97,@<&]U<B!DZ6-H:69F<F5R('5N(&UE<W-A
M9V4N`%5N92!C;&5F('!U8FQI<75E(%!'4"P@=6YE(&-L968@<')I=NEE(%!'
M4"P@970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U
M<B!S:6=N97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%
M+"!U;F4@8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@<&AR87-E('-E8W+H
M=&4@<V]N="!NZ6-E<W-A:7)E<R!P;W5R(&3I8VAI9F9R97(@=6X@;65S<V%G
M92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@
M4R]-24U%+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E
M<R!P;W5R('-I9VYE<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!3
M+TU)344@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF9G)E<B!U;B!M97-S86=E
M+@!.=6%G97,@;&4@;6%T:6X`4&QU:64@;.EGZ')E(&QE(&UA=&EN`%!L=6EE
M(&QE(&UA=&EN`$%V97)S97,@;&4@;6%T:6X`0VAU=&5S(&1E(&YE:6=E(&QE
M(&UA=&EN`$%-+U!-`$54`$%022!)1`#`('!R;W!O<R!D92!C970@Z61I=&5U
M<@#`('!R;W!O<RXN+@!"87,@86)S;VQU`$UI;&EE=2!A8G-O;'4`06-C97!T
M97(@970@86IO=71E<B#@(&UO;B!A9V5N9&$N`$%C8V5P=&5R(&QA(')E<77J
M=&4`06-C97!TZ0!!8V-E<'3IH#H@`$%C8^AS(')E9G5SZ2!L;W)S(&1E(&QA
M(&-RZ6%T:6]N(&1E('+I<&5R=&]I<F4@5D93("X`06-CZ',@<F5F=7/I(&QO
M<G,@9&4@;&$@8W+I871I;VX@9&4@9FEC:&EE<B!61E,N`$1O;F[I97,@<&5R
M<V]N;F5L;&5S`$UO="!D92!P87-S92!D=2!C;VUP=&4`0V]M<'1E(&EN86-T
M:68`3F]M(&1U(&-O;7!T9:`Z`$-O;7!T97,`06-T:6]N<P!!:F]U=&5R`$%J
M;W5T97(@)7,@X"!M;VX@8V%R;F5T(&0G861R97-S97,`06IO=71E<B!U;B!S
M;W5S+6=R;W5P90!!:F]U=&5R('5N92!N;W5V96QL92!S;W5S+7!E<FUI<W-I
M;VX`06IO=71E<B!I8VF@.@!!:F]U=&5R('5N(&YO=79E874@9W)O=7!E`$%J
M;W5T97(@=6YE(&YO=79E;&QE('!E<FUI<W-I;VX`06IO=71E<B!U;B!G<F]U
M<&4@9FEL<R#@(*N@)7.@NP!!:F]U=&5R('5N92!P97)M:7-S:6]N(&9I;&QE
M(.`@JZ`E<Z"[`$%J;W5T97(@=6X@;F]U=F5L('5T:6QI<V%T975RH#H`06IO
M=71E<B!U;F4@8V]L;VYN90!!:F]U=&5R(&1E(&YO=79E875X(&UE;6)R97,`
M06IO=71E<B!U;F4@<&%I<F4`06IO=71E<B!U;F4@<V]U<F-E`$%J;W5T97(@
M;&4@;65N=2`E<R#@(&QA(&)A<G)E(&1E($UO>FEL;&$`P"!A:F]U=&5R(.`@
M;6]N(&%G96YD80!!:F]U=&5R(&%U(&-A<FYE="!D)V%D<F5S<V5SH#H`06IO
M=71E<B#@(&UO;B!C87)N970@9"=A9')E<W-E<P!!:F]U=&5R(.`@;6]N(&%G
M96YD80!!:F]U=&5R('5N('5T:6QI<V%T975R`*N@)7.@NR!A:F]U=.D@96X@
M<&GH8V4@:F]I;G1E+@"KH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64L
M(&UA:7,@;"=A:F]U="!D)VEN9F]R;6%T:6]N('-U<'!LZ6UE;G1A:7)E<R`E
M<R!N)V5S="!P87,@<&]S<VEB;&4N`*N@)7.@NR!A(.ETZ2!A:F]U=.DN(%9O
M=7,@<&]U=F5Z('9O=7,@8V]N;F5C=&5R+@!,82!F;VYC=&EO;B!D)V%J;W5T
M(&0G=71I;&ES871E=7)S(&5S="!DZ7-A8W1I=NEE+@!%;BUTZG1E<R!A9&1I
M=&EO;FYE;',@X"!A9F9I8VAE<CH@/&5M/BAO<'1I;VYN96PL(&5N=')E>B!C
M:&%Q=64@96XM=.IT92!S=7(@('5N92!N;W5V96QL92!L:6=N92D\+V5M/BX`
M56YE(&EN9F]R;6%T:6]N(&-O;7!LZ6UE;G1A:7)E('!E=70@ZG1R92!C;VYS
M=6QTZ64@)7,N`$3I=&%I;',@:6YF;W)M871I9G,@8V]M<&SI;65N=&%I<F5S
M`$3I=&%I;',@8V]M<&SI;65N=&%I<F5S('-U<B!L92!M97-S86=E`$1E<R!D
MZ71A:6QS(&-O;7!LZ6UE;G1A:7)E<R!P975V96YT(.IT<F4@8V]N<W5L=.ES
M("5S+@!$Z71A:6QS(&-O;7!LZ6UE;G1A:7)E<R!D=2!M97-S86=E(&0G97)R
M975R`$1E<R!DZ71A:6QS(&-O;7!LZ6UE;G1A:7)E<R!A=2!M97-S86=E(&0G
M97)R975R('!E=79E;G0@ZG1R92!C;VYS=6QTZ7,@)7,N`$%D<F5S<V4`0V%R
M;F5T(&0G861R97-S97,`0V%R;F5T<R!D)V%D<F5S<V5S`$%D<F5S<V5R(&5N
M($-C:2!T;W5S(&QE<R!M97-S86=E<Z`Z(#QE;3XH;W!T:6]N;F5L+"!E;G1R
M97H@8VAA<75E(&%D<F5S<V4@<W5R("!U;F4@;F]U=F5L;&4@;&EG;F4I/"]E
M;3XN`$%D<F5S<V5S(.`@871T86-H97(@97AP;&EC:71E;65N="#@(&-E='1E
M(&ED96YT:73IH#H@/&5M/BAO<'1I;VYN96PZ(&5N=')E<B!C:&%Q=64@861R
M97-S92!S=7(@=6YE(&YO=79E;&QE(&QI9VYE*3PO96T^`$%D;6EN:7-T<F%T
M975R("T@86IU<W1E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!D)V%U=')E<R!U
M=&EL:7-A=&5U<G,`061M:6YI<W1R871I;VX`4'5B<P!!9F=H86YI<W1A;@!!
M;&)A;FEE`$%L9^ER:64`06QI87,`06QI9VYE<@!!;&EG;F5M96YTH#H`5&]U
M=`!4;W5S(&QE<R!P87)T:6-I<&%N=',@875T:&5N=&EF:>ES`%1O=7,@;&5S
M(&=R;W5P97,`5&]U=&5S(&QE<R!P97)M:7-S:6]N<P!,97,@<75A=')E(&/T
M=.ES`%1O=7,@;&5S(&UE<W-A9V5S(&1E(&-E*',I(&1O<W-I97(H<RD@<V5R
M;VYT('3I;.EC:&%R9^ES(&1A;G,@=6X@9FEC:&EE<B!-0D]8H#H`5&]U<R!L
M97,@;65S<V%G97,@9&4@=F]T<F4@9&]S<VEE<B"KH"5SH+L@<75I(&]N="!P
M;'5S(&1E(*N@)7.@NR!J;W5R<R!S97)O;G0@969F86/I<RX`5&]U<R!V;W,@
M9&]S<VEE<G,@9"=A;F-I96YS(&UE<W-A9V5S(&5N=F]YZ7,@9&5P=6ES('!L
M=7,@9&4@)7,@;6]I<R!S97)O;G0@969F86/I<RX`5&]U<R!V;W,@9&]S<VEE
M<G,@9"=A;F-I96YS(&UE<W-A9V5S(&5N=F]YZ7,@9&5P=6ES('!L=7,@9&4@
M)7,@;6]I<R!S97)O;G0@969F86/I<RX`5&]U<R!L97,@9')O:71S('-U<B!L
M92!D;W-S:65R(*N@)7.@NR!O;G0@8FEE;B#I=.D@<F5T:7+I<R!P;W5R(&PG
M=71I;&ES871E=7(@JZ`E<Z"[+@!!=71O<FES97(@;&$@8W+I871I;VX@9&4@
M9&]S<VEE<G.@/P!!=71O<FES97(@;&5S('+H9VQE<R!D92!F:6QT<F%G92#@
M(',G87!P;&EQ=65R(.`@;B=I;7!O<G1E('%U96QL92!B;^YT92!D92!C;W5R
M<FEE;*`_`%!E<FUE='1R92!D97,@861R97-S97,@9&4@8V]U<G)I96P@;75L
M=&EP;&5S`$%U=&]R:7-E<B!L82!M:7-E(&5N('!L86-E(&1E(&QI<W1E<R!N
M=6WI<F]TZ65SH#\`17AI<W1E(&3I:N``3F]M(&0G=71I;&ES871E=7(@24U3
M4"!A;'1E<FYA=&EF`$UO="!D92!P87-S92!)35-0(&%L=&5R;F%T:68`3F]M
M(&0G=71I;&ES871E=7(@24U34"!A;'1E<FYA=&EF`$%D<F5S<V4@9&4@8V]U
M<G)I96P@86QT97)N871I=F4`075T<F5S(&UO9.AL97,`5&5X=&4@86QT97)N
M871I9J`Z`%!A<G1I97,@86QT97)N871I=F5S('!O=7(@8V5T=&4@<V5C=&EO
M;J`Z`%1O=6IO=7)S`%1O=6IO=7)S(&5N<F5G:7-T<F5R(&QE<R!P:>AC97,@
M:F]I;G1E<P!386UO82!!;>ER:6-A:6X`56YE(&5R<F5U<B!S)V5S="!P<F]D
M=6ET92!L;W)S(&1U(')E=')A:70@9&4@;&$@<&GH8V4@:F]I;G1E+B!,92!S
M97)V975R($E-05`@82!RZ7!O;F1UH#H@`%5N92!V86QE=7(@:6QLZ6=A;&4@
M82#I=.D@<W#I8VEF:>EE+@!5;F4@97)R975R(&EN8V]N;G5E(',G97-T('!R
M;V1U:71E+@!5;F4@97)R975R(&EN8V]N;G5E(&5S="!S=7)V96YU92!P96YD
M86YT(&QA(&-RZ6%T:6]N(&1E(&QA(&YO=79E;&QE(&YO=&4N`%5N92!E<G)E
M=7(@:6YC;VYN=64@97-T('-U<G9E;G5E('!E;F1A;G0@;&$@8W+I871I;VX@
M9&4@;&$@;F]U=F5L;&4@=.)C:&4N`$%N9&]R<F4`06YG;VQA`$%N9W5I;&QA
M`%!R;WAY(&%N;VYY;64`4NEP;VYS90!2Z7!O;F1U`$UE<W-A9V5S('+I<&]N
M9'5S`$%N=&%R8W1I<75E`$%N=&EG=6$M970M0F%R8G5D80!!<'!L:6-A=&EO
M;@!,:7-T92!D)V%P<&QI8V%T:6]N<P!,)V%P<&QI8V%T:6]N(&5S="!P<NIT
M90!!<'!L:7%U97(@;&5S(&9I;'1R97,`07!P;&EQ=65R(&QE<R!F:6QT<F5S
M('-U<B`E<P!!<'!L:7%U97(@8V5S(&9I;'1R97,@;&]R<R!D92!L82!C;VYN
M97AI;VZ@/P!!<'!L:7%U97(@;&5S(&9I;'1R97,@X"!C:&%Q=64@869F:6-H
M86=E(&1E($)O[G1E(&1E('+I8V5P=&EO;J`_`$%P<&QI<75E<B!A=7@@<&%R
M=&%G97,@9FEL<P!!<'!R;W5VZ0!486EL;&4@87!P<F]X:6UA=&EV90!!=G)I
M;`!!<F%B92`H5VEN9&]W<RTQ,C4V*0!486EL;&4@9'4@9FEC:&EE<B!A<F-H
M:79E`$YO;2!D92!L)V%R8VAI=F4`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U
M;&]I<B!S=7!P<FEM97(@8V5T=&4@9.EF:6YI=&EO;B!D92!RZ7!E<G1O:7)E
M('9I<G1U96R@/P#*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER('-U<'!R
M:6UE<B!C971T92!C;&5F('!U8FQI<75EH#\`RG1E<RUV;W5S(&-E<G1A:6X@
M9&4@=F]U;&]I<B!DZ71R=6ER92!C971T92!P86ER92!D92!C;&5F<Z`_("AC
M92!N)V5S="!P87,@<F5C;VUM86YDZ:`A*0#*=&5S+79O=7,@8V5R=&%I;B!D
M92!V;W5L;VER(&9A:7)E(.=AH#\`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U
M;&]I<B!S=7!P<FEM97(@8V5T=&4@<F5Q=>IT92!D)VEN<V-R:7!T:6]N("!P
M;W5R("5SH#\`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!S=7!P<FEM
M97(@9.EF:6YI=&EV96UE;G0@8V5S(&UE<W-A9V5SH#\`RG1E<RUV;W5S(&-E
M<G1A:6X@9&4@=F]U;&]I<B!S=7!P<FEM97(@9.EF:6YI=&EV96UE;G0@8V5T
M=&4@<&GH8V4@:F]I;G1EH#\`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I
M<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U<RUG<F]U<&5SH#\`RG1E<RUV
M;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!V:61E<B!C92!D;W-S:65RH#\`RG1E
M<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!V:61E<B!V;W1R92!D;W-S:65R
M(&1E('!O=7)R:65L<Z`_`,IT97,M=F]U<R!C97)T86EN(&1E('9O=6QO:7(@
M=FED97(@=F]T<F4@8V]R8F5I;&QEH#\`RG1E<RUV;W5S(&-E<G1A:6X@9&4@
M=F]U;&]I<B!E9F9A8V5R(&-E<R!M97-S86=E<R!DZ69I;FET:79E;65N=*`_
M`,IT97,M=F]U<R!C97)T86EN(&1E('9O=6QO:7(@9.EC;&%R97(@8V4@;65S
M<V%G92!C;VUM92!LZ6=I=&EM9:`_`,IT97,M=F]U<R!C97)T86EN(&1E('9O
M=6QO:7(@<F%P<&]R=&5R(&-E(&UE<W-A9V4@8V]M;64@9'4@<&]U<G)I96R@
M/P!!<F=E;G1I;F4`07)MZ6YI90!!<FWI;FEE;B`H05)-4T-)22TX*0!(975R
M92!D92!RZ6-E<'1I;VX`07)T`$%R=6)A`$-R;VES<V%N=`!!<V-E;G-I;VX@
M*,YL92D`07)T($%30TE)`%+I9VEO;B!!<VEE+U!A8VEF:7%U90!$96UA;F1E
M<@!$96UA;F1E<B!U;F4@8V]N9FER;6%T:6]N(&%V86YT(&1E(&QA;F-E<B!L
M97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC9:`_`$-O;&]N;F5S(&1E<R!T
MXF-H97,`2F]I;F1R92!L97,@9FEC:&EE<G,`2F]I;F1R92!U;F4@8V]P:64@
M9&4@=F]T<F4@8VQE9B!01U`@<'5B;&EQ=64@X"!V;W1R92!M97-S86=EH#\`
M4&GH8V4@:F]I;G1EH#H`3&$@<&GH8V4@:F]I;G1E(*N@)7.@NR!DZ7!A<W-E
M(&QE<R!L:6UI=&5S(&1E('1A:6QL92X@1FEC:&EE<B!.3TX@871T86-HZ2X`
M0VDM:F]I;G0@=6YE('+I<&]N<V4@X"!U;F4@<F5Q=>IT92!V97)S('5N(&%G
M96YD82X`4&GH8V4@:F]I;G1E`%!IZ&-E(&IO:6YT92`E<R!S=7!P<FEMZ64N
M`%!IZ&-E(&IO:6YT92!R971I<NEEH#H@='EP92!D)V]R:6=I;F4@9&4@;&$@
M<&GH8V4@:F]I;G1E`%!IZ&-E<R!J;VEN=&5S`%1E;G1A=&EV92!D)V5F9F%C
M96UE;G0@9"=U;B!G<F]U<&4@:6YE>&ES=&%N="X`5&5N=&%T:79E("!D)V5F
M9F%C96UE;G0@9"=U;F4@<&5R;6ES<VEO;B!I;F5X:7-T86YT92X`5&5N=&%T
M:79E(&1E(&UO9&EF:6-A=&EO;B!D)W5N92!P97)M:7-S:6]N(&EN97AI<W1A
M;G1E+@!496YT871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6X@<&%R=&%G92!I
M;F5X:7-T86YT+@!0<NES96YT<P!!='1E;G1I;VX`4')O<')IZ73I<P!!;_MT
M`$%U<W1R86QI90!!=71R:6-H90!!=71H7V-Y<G5SH#H@17AT96YS:6]N(')E
M<75I<V4@24U!4"!N;VX@=')O=7;I92X`075T:%]C>7)U<Z`Z(&QE(&)A8VME
M;F0@;B=A('!A<R!L97,@8V%P86-I=.ES(')E<75I<V5S+@!!=71H7V-Y<G5S
MH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I90!!=71H7V9T
M<*`Z(&5X=&5N<VEO;B!R97%U:7-E($944"!N;VX@=')O=7;I92X@26P@9F%U
M="!C;VUP:6QE<B!02%`@879E8R!L)V]P=&EO;B`M+65N86)L92UF='`N`$%U
M=&A?:6UA<*`Z(&5X=&5N<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64N
M`$%U=&A?:6UPH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I
M92X`075T:%]K<F(UH#H@97AT96YS:6]N(')E<75I<V4@:W)B-2!N;VX@=')O
M=7;I92X`075T:%]L9&%PH#H@;"=A:F]U="!D)W5T:6QI<V%T975R<R!N)V5S
M="!P87,@<W5P<&]R=.D@879E8R!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<*`Z(&QE(')E=')A:70@9"=U=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U<'!O
M<G3I(&%V96,@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87"@.B!E>'1E;G-I
M;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE+@!!=71H7VQD87"@.B!I;7!O
M<W-I8FQE(&0G86IO=71E<B!L)W5T:6QI<V%T975R("5S+B!#96-I(&5S="!L
M82!RZ7!O;G-E(&1U('-E<G9E=7*@.B``075T:%]L9&%PH#H@:6UP;W-S:6)L
M92!D92!S=7!P<FEM97(@;"=U=&EL:7-A=&5U<B`E<P!!=71H7VQD87"@.B!M
M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D92!L)W5T:6QI<V%T975R("5S`$%U
M=&A?;&1A<*`Z(&QA(&UO9&EF:6-A=&EO;B!D97,@=71I;&ES871E=7)S(&XG
M97-T('!A<R!S=7!P;W)TZ64@879E8R!!8W1I=F4@1&ER96-T;W)Y+@!!=71H
M7VUC86R@.B!E>'1E;G-I;VX@<F5Q=6ES92!-0T%,(&YO;B!T<F]U=NEE+@!!
M=71H7W-M8F%U=&B@.B!E>'1E;G-I;VX@<F5Q=6ES92!S;6)A=71H(&YO;B!T
M<F]U=NEE+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX@874@<V5R=F5U
M<B!)34%0+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX`R6-H96,@9&4@
M;"=A=71H96YT:69I8V%T:6]N("5S`$QE('-E<G9E=7(@4D%$2553(&$@<F5J
M973I(&PG875T:&5N=&EF:6-A=&EO;BX`R6-H96,@9&4@;"=A=71H96YT:69I
M8V%T:6]N(&%U('-E<G9E=7(@1E10+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC
M871I;VX@874@<V5R=F5U<B!334(N`$%F9FEC:&5R(&%U=&]M871I<75E;65N
M="!L97,@:6UA9V5S(&1E<R!M97-S86=E<R!E;B!(5$U,(&QO<G-Q=64@;"=E
M>'#I9&ET975R(&5S="!D86YS(&UO;B!C87)N970@9"=A9')E<W-E<Z`_`$-A
M<FYE=',@9"=A9')E<W-E<R!D:7-P;VYI8FQE<Z`Z`$-H86UP<R!D:7-P;VYI
M8FQE<Z`Z`$5N(&%T=&5N=&4@9"=U;F4@<NEP;VYS90!!>F5R8F'O9&IA;@!%
M>&-U<V5S($)/1D@`4F5?=F5N:7(@X"`E<P!2979E;FER(.`@)7,`4F5T;W5R
M(.`@;"=I;F1E>"!D92!P<NES96YT871I;VX@9&5S(&UE<W-A9V5S(&UU;'1I
M<&QE<P!2971O=7(@X"!L)V%F9FEC:&%G92!P87(@9FEL<P!#;W5L975R(&1E
M(&9O;F0`0V]U;&5U<B!D92!F;VYD`$UO="!D92!P87-S92!+97)B97)O<R!E
M<G)O;NDN`$YO;2!D92!C;VYN97AI;VX@2V5R8F5R;W,@97)R;V[I+@!297%U
MZG1E(&UA=79A:7-E(&]U(&UA;"!F;W)MZ64N($QE('-E<G9E=7(@82!RZ7!O
M;F1UH#H@)7,`0F%H86UA<P!"86AR9>]N`$)A;'1E("A)4T\M.#@U.2TQ,RD`
M0F%N9VQA9&5S:`!"87)B861E`%+I<&5R=&]I<F4@9&5S(&=R87!H:7%U97,@
MJZ`E<Z"[(&YO;B!T<F]U=NDN`$QI9VYE(&1E(&)A<V4`0V-I`$+I;&%R=7,`
M0F5L9VEQ=64`0F5L:7IE`$-I+61E<W-O=7,@;&4@=&5X=&4@8G)U="#@('!R
M;W!O<R!D97,@:6YF;W)M871I;VYS(&1U(&UE<W-A9V4N`$+I;FEN`$)E<FUU
M9&5S`$)H;W5T86X`06YN:79E<G-A:7)E`$QI<W1E(&YO:7)E`$)L;V,@JR5S
M(+L@9&4@;"=A<'!L:6-A=&EO;B"KH"5SH+L@:6YC;VYN=0!0<NEFZ7)E;F-E
M<R!D92!B;&]C`%1Y<&4@9&4@8FQO8P!";&]Q=65R(&QE<R!I;6%G97,@9&5S
M(&UE<W-A9V5S(&5N($A434P@<V%U9B!D96UA;F1E(&5X<&QI8VET9:`_`$-O
M<G!S`$=R87,`0F]L:79I90!3:6=N971S`$)O<F1U<F4`R7!A:7-S975R(&1E
M(&QA(&)O<F1U<F6@.@!";W)D<P!";W-N:64M2&5R>NEG;W9I;F4`3&5S(&1E
M=7@`4VEM=6QT86[I;65N="!D86YS(&QA(&QI<W1E(&1E<R!E;BUTZG1E<R!E
M="!D86YS(&QE(&-O<G!S(&1U(&UE<W-A9V4`0F]T<W=A;F$`0F%S`$)O=79E
M=`!"<NES:6P`5&5R<FET;VER97,@8G)I=&%N;FEQ=65S(&1E(&PG3V/I86X@
M26YD:65N`%-U;'1A;F%T(&1U($)R=6[I:0!"=6QG87)I90!,:7-T92#@('!U
M8V5S`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$=E<W1I;VX@9&4@8V]N=&5N=0!#
M4D,`1&ES=')I8G5T:6]N(&1E<R!P;VEN=',@3%)#("A,:7-T92!D92!RZ79O
M8V%T:6]N(&1E<R!C97)T:69I8V%T<RD`4')O<')IZ73I<R!D92!L82!#7V5L
M;'5L90!?2F5U(&1E(&-A<F%C=.AR97,`3"=I;FET:6%L:7-A=&EO;B!D=2!C
M86-H92!N92!S)V5S="!P87,@=&5R;6ENZ64N`$%G96YD80!#86QM90!#86UB
M;V1G90!#86UE<F]U;@!#;VYN97AI;VX@874@<V5R=F5U<B!D92!C;W5R<FEE
M;"!D:7-T86YT(&EM<&]S<VEB;&4N`$-O;FYE>&EO;B!A=2!S97)V975R(&1E
M(&-O=7)R:65L(&1I<W1A;G0@:6UP;W-S:6)L9:`Z(`!.92!P975T(&%F9FEC
M:&5R("T@=')O=7;I('-E=6QE;65N="`E<R!P87)T:65S(&1E("5S(&1E(&-E
M(&UE<W-A9V4@9&%N<R!L82!P<NES96YT92!B;^YT92!D92!C;W5R<FEE;',N
M`$EM<&]S<VEB;&4@9&4@<NEI;FET:6%L:7-E<B!L92!M;W0@9&4@<&%S<V4@
M875T;VUA=&EQ=65M96YT+"!C;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E
M=7(@<WES=.AM92X`26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@9FEC:&EE
M<B"KH"5SH+LN`$EM<&]S<VEB;&4@9"=A9&UI;FES=')E<B!D97,@9V5S=&EO
M;FYA:7)E<R!D92!S97-S:6]N(&5X=&5R;F5S+@#)8VAE8R!D92!L82!C;VYN
M97AI;VX@874@<V5R=F5U<B!)34%0H#H@)7,`26UP;W-S:6)L92!D)V]U=G)I
M<B!L92!F:6-H:65R(*N@)7.@NRX`0V%N861A`$%N;G5L97(`06YN=6QE<B!L
M92!M97-S86=E`$%N;G5L97(@;&4@<F%P<&]R="!D=2!P<F]B;.AM90!,)V%N
M;G5L871I;VX@9'4@;65S<V%G92!E;G1R8>YN97)A(&QA('!E<G1E(&3I9FEN
M:71I=F4@9&4@<V]N(&-O;G1E;G4N`$EM<&]S<VEB;&4@9&4@<W5P<')I;65R
M(&QE(&9I8VAI97(@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E('1R;W5V97(@=6X@
M<NEP97)T;VER92!T96UP;W)A:7)E`$EM<&]S<VEB;&4@9&4@<')O8^ED97(@
M<V%N<R!L92!P87)A;>AT<F4@JR!T87)G971&:6QE(+L`26UP;W-S:6)L92!D
M92!S=7!P<FEM97(@;&4@<NEP97)T;VER92"KH"5SH+LN`%-U<'!R97-S:6]N
M(&EM<&]S<VEB;&4L(&EL('D@82`E9"!E;G)E9VES=')E;65N=',@9FEL<RX`
M26UP;W-S:6)L92!D92!RZ6]R9&]N;F5R+"!L92!N;VUB<F4@9"?I;.EM96YT
M<R#@('+I;W)D;VYN97(@;F4@8V]R<F5S<&]N9"!P87,@874@;F]M8G)E(&0G
MZ6SI;65N=',@96YR96=I<W1RZ7,N`$YE('!E=70@9&ER:6=E<B!L92!M97-S
M86=E('9E<G,@;&4@;F]M8G)E('-PZ6-I9FGI+@!#87`M5F5R=`!,Z6=E;F1E
M`%1R86YS<&]R=&5U<@!#873I9V]R:65S(&5T(,ET:7%U971T97,`SFQE<R!#
M8>]M86X`0V,`5.ELZ7!H;VYE(&-E;&QU;&%I<F4`4')O<')IZ73I<R!D92!L
M82!C96QL=6QE`%)E;7!L:7-S86=E(&%U=&]U<B!D92!L82!C96QL=6QEH#H`
M4')O<')IZ73I<R!D92!L82!C96QL=6QE`$5S<&%C96UE;G0@9&4@;&$@8V5L
M;'5L9:`Z`%3I;.EP:&]N92!C96QL=6QA:7)E(`!#96QT92`H25-/+3@X-3DM
M,30I`$-E;G1R97(`4NEP=6)L:7%U92!C96YT<F%F<FEC86EN90!%=7)O<.EE
M;B!C96YT<F%L("A)4T\M.#@U.2TR*0!$Z71A:6QS(&1U(&-E<G1I9FEC870`
M4')O<')IZ71A:7)E(&1U(&-E<G1I9FEC870`4&]L:71I<75E(&1E(&-E<G1I
M9FEC871I;VX`3"=I;7!O<G1A=&EO;B!D92!C97)T:69I8V%T<R!N)V5S="!P
M87,@9&ES<&]N:6)L92X@3VX@;F4@<&5U="!P87,@96YV;WEE<B!D92!F:6-H
M:65R('-U<B!C92!S97)V975R+@!48VAA9`!!;FEM871E=7(`36]D:69I97(`
M0VAA;F=E<B!T;W5T`$-H86YG97(@9&4@9&]S<VEE<@!-;V1I9FEE<B!V;W1R
M92!M;W0@9&4@<&%S<V4`0VAA;F=E<B!L97,@<'+I9NER96YC97,@9"=A9F9I
M8VAA9V4@=&5L;&5S('%U92!L92!T:.AM92P@;&4@;F]M8G)E(&1E(&UE<W-A
M9V5S(&%F9FEC:.ES('!A<B!P86=E(&5T(&-O;6UE;G0@:6QS('-O;G0@=')I
MZ7,N`$UO9&EF:65R(&QA(&-O;F9I9W5R871I;VX@9'4@<V5R=F5U<B!D92!C
M;W5R<FEE;"!E="!D97,@9&]S<VEE<G,N`$-H86YG97(@;&4@;F]M+"!L)V%D
M<F5S<V4@970@;&$@<VEG;F%T=7)E('%U92!L97,@<&5R<V]N;F5S('9O:65N
M="!Q=6%N9"!E;&QE<R!L:7-E;G0@970@<NEP;VYD96YT(.`@=F]S(&UE<W-A
M9V5S+@!#:&%N9V5R(&QE(&YO;2P@;"=A9')E<W-E(&5T(&QA('-I9VYA='5R
M92!Q=64@;&5S('!E<G-O;FYE<R!V;VEE;G0@<75A;F0@96QL97,@;&ES96YT
M(&5T('+I<&]N9&5N="#@('9O<R!M97-S86=E<RX`3&$@;6]D:69I8V%T:6]N
M(&1E('9O=')E(&UO="!D92!P87-S92!N)V5S="!P87,@<W5P<&]R=.EE(&%V
M96,@;&$@8V]N9FEG=7)A=&EO;B!A8W1U96QL92X@0V]N=&%C=&5Z('9O=')E
M(&%D;6EN:7-T<F%T975R+@!#:&%R`$-A<F%C=.AR97,@X"!A9F9I8VAE<J`Z
M`%;I7W)I9FEE<B!L92!L:65N`%;I<FEF:65R(&QE<R!N;W5V96%U>"!M97-S
M86=E<R!D=2AD97,I(&1O<W-I97(H<RD`5NER:69I97(@7U1O=70O4FEE;@!6
MZ7)I9FEE>B!T;W5S(&QE<R!S97)V975R<R!D;VYT('9O=7,@=F]U;&5Z('+I
M8W5PZ7)E<B!L92!C;W5R<FEE<J`Z`%;I<FEF:65R(&PG;W)T:&]G<F%P:&4@
M879A;G0@;"=E;G9O:2!D)W5N(&UE<W-A9V6@/P!#:&EL:0!#:&EN90!#:&EN
M;VES('-I;7!L:69IZ2`H1T(R,S$R*0!#:&EN;VES('1R861I=&EO;FYE;"`H
M0FEG-2D`0VAO:7-I<B!L)V%C=&EO;J`Z`$-H;VES:7(@;"=A<'!L:6-A=&EO
M;J`Z`$-H;VES:7(@=6X@<V5R=F5U<B!D92!C;W5R<FEE;*`Z`%/I;&5C=&EO
M;FYE<B!U;F4@8V]R<F5S<&]N9&%N8V4@;W4@Z61I=&5R(&PG861R97-S92#@
M(&1R;VET9:`Z`$-H;VES:7(@=6X@;6]T(&1E('!A<W-E`$-H;VES:7(@=6X@
M;F]M(&1E(&-O;FYE>&EO;@!#:&]I<VER(&QE(&UO9&4@9"=A9F9I8VAA9V4@
M9&5S(&1A=&5SH#H`0VAO:7-I<B!L92!S='EL92!D92!L:7-T92`H<&]U<B!L
M97,@;&ES=&5S(&YU;>ER:7%U97,I`$-H;VES:7-S97H@;&4@8V%R;F5T(&0G
M861R97-S97,@X"!U=&EL:7-E<B!L;W)S<75E('9O=7,@86IO=71E>B!D97,@
M861R97-S97,N`$-H;VES:7-S97H@;"=O<F1R92!D92!R96-H97)C:&4@9&5S
M(&-A<FYE=',@9"=A9')E<W-E<R!L;W)S(&1U(&3I=F5L;W!P96UE;G0@9&5S
M(&YO;7,N`,YL97,@0VAR:7-T;6%S`$3I9FEN:71I;VX@9&4@;&$@8VQA<W-E
M(&1E("5S(&YO;B!T<F]U=NEE+@!%9F9A8V5R`$YE='1O>65R(&QE<R!B86QI
M<V5S($U3+4]F9FEC90!%9F9A8V5R(&QA(')E<77J=&4`4F5T:7)E<B!L)W5T
M:6QI<V%T975R.B`E<P!%9F9A8V5R(&PG=71I;&ES871E=7(`169F86-E<B!L
M97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R`,EC;&%I<F-I97,@=&%R9"!D
M86YS(&QA(&IO=7)NZ64`0VQI<75E<B!S=7(@)7,@<&]U<B!C;VYV97)T:7(@
M;"=I;6%G92!D86YS('5N(&9O<FUA="!Q=64@=F]T<F4@;F%V:6=A=&5U<B!P
M975T(&QI<F4N`$-L:7%U97(@)7,@<&]U<B!TZ6SI8VAA<F=E<B!L)VEM86=E
M+@!#;&EQ=65R("5S('!O=7(@=F]U<R!R96YD<F4@X"!L82!P86=E(&1E(&=E
M<W1I;VX@9&4@)7,N`$-L:7%U97(@<W5R("5S('!O=7(@=FES=6%L:7-E<B!L
M92!C;VYT96YU($A434P@9&%N<R!U;F4@875T<F4@9F5NZG1R92X`0VQI<75E
M<B`E<R!P;W5R('9O:7(@=6YE(.ET:7%U971T92!D92!C971T92!I;6%G92X`
M0VQI<75E<B!S=7(@)7,@<&]U<B!V:7-U86QI<V5R(&QA('!IZ&-E(&IO:6YT
M92!D86YS('5N92!A=71R92!F96[J=')E+@!#;&EQ=65R('-U<B`E<R!P;W5R
M('9I<W5A;&ES97(@8V5T=&4@<&%R=&EE(&1A;G,@=6YE(&%U=')E(&9E;NIT
M<F4N`$-L:7%U97(@:6-I('!O=7(@34].5%)%4B!L97,@:6UA9V5S`$-H;VES
M:7-S97H@=6X@9&4@=F]S(&-A<FYE=',@9"=A9')E<W-E<R!E="!E;G-U:71E
M('/I;&5C=&EO;FYE>B!T;W5S(&QE<R!C:&%M<',@X"!R96-H97)C:&5R+@!#
M;&EQ=65R('!O=7(@<&]U<G-U:79R90!#;&EQ=65R('!O=7(@96YR96=I<W1R
M97(@;&$@8VQE9B!01U`@<'5B;&EQ=64@9&%N<R!V;W1R92!C87)N970@9"=A
M9')E<W-E<P!#;&EQ=65R('!O=7(@96YR96=I<W1R97(@;&4@8V5R=&EF:6-A
M="!3+TU)344@9&4@)7,@9&%N<R!V;W1R92!C87)N970@9"=A9')E<W-E<P!#
M;&EC:V%T96QL('9I82!(5%10`$-L:7%U97(@<W5R(&PG861R97-S92!C;VUP
M;W-E<F$@=6X@;F]U=F5A=2!M97-S86=E(.`@;"=E>'#I9&ET975R`$-L:7%U
M97(@<W5R(&PG861R97-S92!O=79R:7)A(&QE(&UE<W-A9V4@<&]U<B!L82!L
M96-T=7)E`$9E<FUE<@!&97)M97(@;&$@9F5NZG1R90!&97)M97(@8V5T=&4@
M9F5NZG1R90!$;W-S:65R(&9E<FWI`$YU86=E<P!.=6%G97,@;6%T:6YA=7@`
M3G5A9V5U>`#.;&5S($-O8V]S`%+I9'5I<F4`4NED=6ER92!T;W5T`%+I9'5I
M<F4@=&]U<R!L97,@9&]S<VEE<G,`4NED=6ER92!L92!D;W-S:65R`%)E<&QI
M97(@;&$@8F%R<F4@9&4@8_1TZ0!2Z61U:7)E(&QE<R!B;W)D<P!#;VQO;6)I
M90!#;W5L975R`$EN9&EC871E=7(@9&4@8V]U;&5U<J`Z(`!086QE='1E(&1E
M(&-O=6QE=7)S`%/I;&5C=&EO;B!D)W5N92!C;W5L975R`$-O;'.@.@!4:71R
M97,@9&4@8V]L;VYN90!"+D0N`$-O;6UA;F1E`$-O;6UA;F1E('-H96QL`$-O
M;6UE;G1A:7)E`$YO;2!U<W5E;`!#;VUO<F5S`%-O8VGI=.D`5&5R;6ENZ0!2
MZ61I9V5R('5N(&%U=')E(&UE<W-A9V4`4NED:6=E<B!L97,@;65S<V%G97,@
M9&%N<R!U;F4@9F5NZG1R92!SZ7!A<NEEH#\`0V]M<&]S97(@;&5S(&UE<W-A
M9V5S(&%V96,@=6YE(&EN=&5R9F%C92!E;B!(5$U,('!A<B!DZ69A=70@*'-I
M(&QE(&YA=FEG871E=7(@<W5P<&]R=&4@8V5T=&4@;W!T:6]N*:`_`$]R9&EN
M871E=7)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$1I9F;I<F5N8V5S(&1E(&-O
M;F9I9W5R871I;VX`4WEN8VAR;VYI<V%T:6]N(&1E<R!A<W-I<W1A;G1S('!E
M<G-O;FYE;',L(#Q)/G-M87)T<&AO;F5S/"])/B!E="!/=71L;V]K+@!,82!C
M;VYF:6=U<F%T:6]N(&XG97-T('!A<R#@(&IO=7(N`$-O;F9I9W5R97(@)7,`
M0V]N9FEG=7)E<B!L)V%F9FEC:&%G92!D97,@;65S<V%G97,N`$-O;F9I9W5R
M97(@;&5S(&]P=&EO;G,@9&4@<'+I+79I<W5A;&ES871I;VX@9'4@8V]U<G)I
M97(N`$-O;F9I<FUE<B!L92!M;W0@9&4@<&%S<V4`0V]N9V\`4NEP=6)L:7%U
M92!DZ6UO8W)A=&EQ=64@9'4@0V]N9V\`0V]N;F5X:6]N(')O;7!U92!P87(@
M;&4@<V5R=F5U<B!)34%0+@#)8VAE8R!D92!L82!C;VYN97AI;VX`R6-H96,@
M9&4@;&$@8V]N;F5X:6]NH#H@`$-O;FYE>&EO;B!A=2!S97)V975R(&1E(&-L
M969S('!U8FQI8R!R969U<^EE+@!#;VYN97AI;VX@874@<V5R=F5U<B!D92!C
M;&5F<R!P=6)L:6,@<F5F=7/I92X@4F%I<V]NH#H@("5S("@E<RD`R6-H96,@
M9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@1E10`,EC:&5C(&1E(&QA(&-O
M;FYE>&EO;B!A=2!S97)V975R`$-O;G1A8W1S`$-E<R!C;VYT86-T<R!O;G0@
M8FEE;B#I=.D@86IO=73I<R#@('9O=')E(&-A<FYE="!D)V%D<F5S<V5S+@!4
M>7!E(&1E(&-O;G1E;G4@9'4@9FEC:&EE<B!C;VUP<F5S<^F@.B``0V]N=&5N
M=2!D92"KH"5SH+L`4&]U<G-U:79R90!'97-T:6]N(&1U('-U<'!O<G0@9&4@
M4$=0(&1A;G,@)7,N`$=E<W1I;VX@9'4@<W5P<&]R="!D92!3+TU)344@9&%N
M<R`E<RX`0V]N='+T;&4@9&5S(&]P=&EO;G,@9&4@<F5C:&5R8VAE(&1E<R!M
M97-S86=E<RX`4NEG;&5R(&QA(';I<FEF:6-A=&EO;B!D92!L)V%R<FEVZ64@
M9&4@;F]U=F5A=7@@;65S<V%G97,L(&5T(',G:6P@9F%U="!O=2!N;VX@=F]U
M<R!E;B!A=F5R=&ER+@!#;VYV97)T:7(@;&5S(.EM;W1I8_1N97,@=&5X='5E
M;',@96X@9W)A<&AI<75EH#\`SFQE<R!#;V]K`%3I;6]I;B`H8V]O:VEE*0!#
M;W!I97(`R6-H96,@9&4@;&$@8V]P:66@.B`E<P!3Z6QE8W1I;VX@9"=U;F4@
M8V]P:64`0V]P:65R('9E<G,@;&4@9&]S<VEE<@!#;W)R:6=E<@!497AT92!C
M;W)R:6?I`$ED+B!C;_MT`$-O<W1A(%)I8V$`0_1T92!D)TEV;VER90!);7!O
M<W-I8FQE(&1E(&-H:69F<F5R(&QE(&UE<W-A9V6@.B``4VEG;F%T=7)E(%!'
M4"!D=2!M97-S86=E(&EM<&]S<VEB;&6@.B``26UP;W-S:6)L92!D92!C:&EF
M9G)E<B!L92!M97-S86=E(&%V96,@4R]-24U%+@!3:6=N871U<F4@4R]-24U%
M(&1U(&UE<W-A9V4@:6UP;W-S:6)L92X`06IO=70@9'4@8V]N=&%C="`E<R!I
M;7!O<W-I8FQE+B``3F4@<&5U="!S92!C;VYN96-T97(@874@<V5R=F5U<B!,
M1$%0+@!.92!P975T('-E(&-O;FYE8W1E<B!A=2!S97)V975R($Q$05``5NER
M:69I8V%T:6]N(&1E(&QA(&)A;&%N8V4@)7,@:6UP;W-S:6)L92X@`$EM<&]S
M<VEB;&4@9&4@=&5R;6EN97(@;&$@<F5Q=>IT92X@4F%I<V]N(.EV;W%UZ66@
M.B`E<P#)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!,1$%0`,EC
M:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R(*N@)7.@NR!V:6$@1E10
MH#H@)7,`0W+I871I;VX@9&4@;&ES=&4@9&4@9&ES=')I8G5T:6]N(&EM<&]S
M<VEB;&4N("5S`$EM<&]S<VEB;&4@9&4@8W+I97(@=6X@9&]R<V%L(%9&4Z`Z
M("5S`$EM<&]S<VEB;&4@9&4@9.EC:&EF9G)E<B!L97,@9&]N;NEE<R!01U"@
M.B``26UP;W-S:6)L92!D92!DZ6-H:69F<F5R(&QE<R!D;VYNZ65S(%,O34E-
M12X`3F4@<&5U="!P87,@<W5P<')I;65R(&QE(&-O;G1A8W0@)7,`3F4@<&5U
M="!P87,@<W5P<')I;65R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B`E<P!)
M;7!O<W-I8FQE(&1E('-U<'!R:6UE<B!D97,@;65S<V%G97,@9&4@)7,N($QE
M('-E<G9E=7(@82!RZ7!O;F1UH#H@)7,`3F4@<&5U="!P87,@<W5P<')I;65R
M(&QE('-C<FEP="!D92!M:7-E(.`@:F]U<B"KH"5SH+LN`$3I=&5R;6EN871I
M;VX@9&4@;"=A9')E<W-E(&1U(&1E<W1I;F%T86ER92!I;7!O<W-I8FQE+@!)
M;7!O<W-I8FQE(&0G97CI8W5T97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E
M;F%N8V4N`$EM<&]S<VEB;&4@9"=E>'1R86ER92!L92!F:6-H:65R(&1E;6%N
M9.D@9&4@;&$@<&GH8V4@:F]I;G1E(&%U(&9O<FUA="!-4RU43D5&+@!);7!O
M<W-I8FQE(&0G97AT<F%I<F4@;&4@9FEC:&EE<B!D96UA;F3I(&1E(&PG87)C
M:&EV92!C;VUP<F5S<^EE+@!.92!P975T('+I8W5PZ7)E<B!T;W5T(&QE(&-A
M<FYE="!D)V%D<F5S<V4N`$YE('!E=70@<NEC=7#I<F5R('1O=71E(&QA(&QI
M<W1E(&1E(&1I<W1R:6)U=&EO;BX`3B=A('!A<R!P=2!RZ6-U<.ER97(@;&$@
M;&ES=&4@8V]M<&SH=&4@9&4@;&ES=&5S(&1E(&1I<W1R:6)U=&EO;BX`26UP
M;W-S:6)L92!D92!C:&%R9V5R(&QA('-T<F%TZ6=I92"KH"5SH+LN`$EM<&]S
M<VEB;&4@9&4@8W+I97(@;&4@<NEP97)T;VER92"KH"5SH+LN`$EM<&]S<VEB
M;&4@9"=O8G1E;FER(&QA(&-L968@<'5B;&EQ=64@X"!P87)T:7(@9'4@<V5R
M=F5U<B!D92!C;&5F<RX`3W5V97)T=7)E(&1E(*N@)7.@NR!I;7!O<W-I8FQE
M(&5N(.EC<FET=7)E+@!/=79E<G1U<F4@9&4@)7,@:6UP;W-S:6)L92X`26UP
M;W-S:6)L92!D)V]U=G)I<B!L92!M;V1U;&4@36%I;G1E;F%N8V5?5&%S:R`E
M<P!/=79E<G1U<F4@9'4@9&]S<VEE<B"KH"5SH+L@:6UP;W-S:6)L92X`26UP
M;W-S:6)L92!D)V]U=G)I<B!U;F4@8V]N;F5X:6]N('/I8W5R:7/I92!S=7(@
M;&4@<V5R=F5U<B!)34%0+B`E<Z`Z("5S+@!);7!O<W-I8FQE(&0G871T96EN
M9')E(&QE('-E<G9E=7(@3$1!4"X`3&5C='5R92!D92`E<R!I;7!O<W-I8FQE
M+B``3B=A('!U(')E;65T=')E(.`@>NER;R!L92!M;W0@9&4@<&%S<V4@<&]U
M<B!L)W5T:6QI<V%T975R(&1E;6%N9.DN($-E<G1A:6YS("AO=2!T;W5S*2!L
M97,@9.ET86EL<R!N92!S;VYT('!A<R!C;W)R96-T<RX@4NEE<W-A>65Z(&]U
M(&-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U<B!P;W5R(&1E(&PG86ED
M92X`4NEC=7#I<F%T:6]N(&1E<R!!0TP@:6UP;W-S:6)L90!.92!P975T('+I
M8W5PZ7)E<B!L92!C87)N970@9"=A9')E<W-E<RX@)7,`3F4@<&5U="!RZ6-U
M<.ER97(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<P!.92!P975T('+I
M8W5PZ7)E<B!L97,@;&ES=&5S(&1E(&1I<W1R:6)U=&EO;BX@)7,`26UP;W-S
M:6)L92!D92!RZ6-U<.ER97(@;&5S(&EN9F]R;6%T:6]N<R!D92!N;VUM86=E
M(.`@<&%R=&ER(&1U('-E<G9E=7(@24U!4"X`3F4@<&5U="!RZ6-U<.ER97(@
M;&5S('!O<W-I8FEL:73I<R!D=2!S97)V975R`$YE('!E=70@<&%S(')E=F5N
M:7(@X"!L82!C;VYF:6=U<F%T:6]N('!RZ6/I9&5N=&4N`$5F9F%C96UE;G0@
M9'4@9&]S<VEE<B"KH"5SH+L@:6UP;W-S:6)L92X@`$YE('!E=70@<&%S(&5N
M<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I;VX@)7,`3F4@<&5U="!P87,@96YR
M96=I<W1R97(@=6YE('-A=79E9V%R9&4@9&4@;&$@8V]N9FEG=7)A=&EO;BX`
M26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R('5N92!C;W!I92!D92!L82!C;VYF
M:6=U<F%T:6]NH#H@)7,`26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R(&QE('-C
M<FEP="!D92!M:7-E(.`@:F]U<B!D86YSH#H@JZ`E<Z"[+@!);7!O<W-I8FQE
M(&0G96YR96=I<W1R97(@=6YE(&-O<&EE(&1U(&9I8VAI97(@9&4@8V]N9FEG
M=7)A=&EO;B`E<RX`26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R(&QE(&9I8VAI
M97(@9&4@8V]N9FEG=7)A=&EO;B`E<RX@5F]U<R!P;W5V97H@<V]I="!U=&EL
M:7-E<B!U;F4@9&5S(&]P=&EO;G,@<&]U<B!S875V97(@;&4@8V]D92!S=7(@
M)7,@<V]I="!C;W!I97(@;6%N=65L;&5M96YT(&QE(&-O9&4@8VDM9&5S<V]U
M<R!D86YS("5S+@!.92!P975T('!A<R!R96-H97)C:&5R(&QE('-E<G9E=7(@
M3$1!4"X`4W5P<')E<W-I;VX@9&4@JZ`E<Z"[(&EM<&]S<VEB;&4N`$UI<V4@
MX"!J;W5R(&1U(&-O;G1A8W0@:6UP;W-S:6)L92X@)7,`3F4@<&5U="!M971T
M<F4@X"!J;W5R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@)7,`3F4@<&5U
M="!P87,@96YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!P;W5R(*N@)7.@
MNZ`Z("5S`$YE('!E=70@=')O=79E<B!L82!B87)R92!D92!-;WII;&QA+B`@
M07-S=7)E>BUV;W5S('%U)V5L;&4@97-T(&%C=&EV92X`3F4@<&5U="!A='1R
M:6)U97(@8V5S(&1R;VET<R#@(&PG=71I;&ES871E=7(@JZ`E<Z"[("!S=7(@
M;&4@9&]S<VEE<B"KH"5SH+N@.B`E<P!497AT92!C;VUP=.D`4&%Y<P!#;W5R
M<P!#<NEE<@!#<NEE<B!U;B!D;W-S:65R`$-RZ65R(&1E<R!C;&5F<P!#<NEE
M<B!U;B!D;W-S:65R('9I<G1U96P`0W+I97(@=6X@;F]U=F5A=2!C;VUP=&4`
M0W+I97(@=6X@;&EE;@!#<NEE<B!U;B!N;W5V96%U(&1O<W-I97(@<&]U<B!L
M97,@<&]U<G)I96QS`$-RZ65R('5N(&YO=79E874@9&]S<VEE<B!D92!B<F]U
M:6QL;VYS`$-RZ65R('5N(&YO=79E874`0W+I97(@=6X@;F]U=F5A=2!D;W-S
M:65R(&1E(&UE<W-A9V5S(&5N=F]YZ7,`0W+I97(@=6YE(&YO=79E;&QE(&-O
M<F)E:6QL90!#<NEE<B!D97,@<NAG;&5S(&1E(&9I;'1R86=E('!O=7(@;W)G
M86YI<V5R('9O<R!A<G)I=NEE<R!D92!M97-S86=E<RP@;&5S('1R:65R(&1A
M;G,@9&5S(&1O<W-I97)S+"!E="#I;&EM:6YE<B!L97,@<&]U<G)I96QS+@!#
M<NEE<B!U;F4@;F]U=F5L;&4@<&%P971E<FEE`$-RZ65R('5N92!P87!E=&5R
M:64@970@9&5S(&9O<FUU;&%I<F5S(&1E('+I<&]N<V4N`$-RZ65R('5N('-O
M=7,M9&]S<VEE<@!097)M:7-S:6]N<R!$92!#<NEA=&5U<@!.=6WI<F\@9&4@
M8V%R=&4@9&4@8W+I9&ET`$-R;V%T:64`0W5B80`T('!H87-E<R!C;W5R86YT
M97,`4V5S<VEO;G,@96X@8V]U<G,`2&5U<F4@86-T=65L;&4`3"=A9')E<W-E
M(%523"!A8W1U96QL92!E<W0`571I;&ES871E=7)S(&%C='5E;',`3V)S97)V
M871I;VYS(&%C='5E;&QE<P!!8V/H<R!C;W5R86YT(.`@)7,`0V]N9&ET:6]N
M(&%C='5E;&QEH#H@`%-T>6QE(&-O=7)A;G0`4&5R<V]N;F%L:7-E<B!L97,@
M8V]M<'1E<R!P;W5R(&QA('+I8W5PZ7)A=&EO;B!D92!C;W5R<FEE<B!D97!U
M:7,@9"=A=71R97,@8V]M<'1E<RX`1.EF:6YI<B!C;VUM96YT('9O=7,@96YV
M;WEE>B!D97,@;65S<V%G97,@+@!$Z69I;FER(&QE<R!TXF-H97,@X"!E9F9E
M8W1U97(@;&]R<R!D92!L82!C;VYN97AI;VX@X"`E<RX`0V]U<&5R`$-O=7!E
M<B!L82!SZ6QE8W1I;VX`0VAY<')E`$-Y<FEL;&EQ=64@*$M/23@M4BD`0WER
M:6QL:7%U92`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI<75E+U5K<F%I;FEE;B`H
M2T])."U5*0!2Z7!U8FQI<75E(%1C:.AQ=64`2DH`1%-.("A#9BX@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*0!#:&%Q=64@:F]U<@!?1&%T90!.879I9V%T975R(&1E
M($1A=&%4<F5E`$%L:6%S(&1E(&QA(&)A<V4`1&%T90!$871E(&1E('+I8V5P
M=&EO;@!3Z6QE8W1I;VX@9"=U;F4@9&%T90!*;W5R`%-U<'!R:6UE<B!?;&$@
M8V]L;VYN90!$Z6-E;6)R90!.;VUB<F5S(&3I8VEM875X`$3I8VQI;ND`1.EC
M;&ENZ:`Z(`!$:6UI;G5E<B!L)VEN9&5N=&%T:6]N`$3I9F%U=`!#;W5L975R
M('!A<B!DZ69A=70`261E;G1I=.D@<&%R(&3I9F%U=`!#:&%M<"!D92!R96-H
M97)C:&4@<&%R(&3I9F%U=`!);G1E<G!RZ71E=7(@9&4@8V]M;6%N9&4@<&%R
M(&3I9F%U=`!#<FETZ')E(&1E('1R:2!P87(@9.EF875TH#H`3W)D<F4@9&4@
M=')I('!A<B!DZ69A=72@.@!$Z69I;FET:6]N<P!$Z6SI9W7I`%-U<'!R:6UE
M<@!3=7!P<FEM97(@;&$@8VQE9B!P=6)L:7%U92`E<P!%9F9A8V5R(&QA(&-E
M;&QU;&4`4W5P<')I;65R(&QE<R!C;&5F<R!C;W5R86YT97,`1.ET<G5I<F4@
M;&4H<RD@9&]S<VEE<BAS*0!3=7!P<FEM97(@=6X@9W)O=7!E`$5F9F%C97(@
M;&$@=')A8V4`4W5P<')I;65R('5N92!P97)M:7-S:6]N`%-U<'!R:6UE<B!L
M97,@9&]S<VEE<G,@<^EL96-T:6]N;NES`%-U<'!R:6UE<B!L82!P87!E=&5R
M:64`1.ET<G5I<F4@;&4@9&]S<VEE<B!V:7)T=65L`%-U<'!R:6UE<B!L82!D
MZ69I;FET:6]N(&1U(&1O<W-I97(@=FER='5E;"!P;W5R("5S`%-U<'!R:6UE
M<B!E="!P=7)G97(@;&5S(&UE<W-A9V5S`$5F9F%C97(@;&$@8V5L;'5L90!%
M9F9A8V5R(&QA(&-O;&]N;F4`4W5P<')I;65R('5N(&%U=')E(&UO9.AL92!E
M>&ES=&%N=`!3=7!P<FEM97(@;&5S(&UE<W-A9V5S(')A;65NZ7,@9'4@<V5R
M=F5U<B!D:7-T86YTH#\`4W5P<')I;65R(&1E(&UO;B!A9V5N9&$`169F86-E
M<B!L97,@86YC:65N;F5S('!IZ&-E<R!J;VEN=&5S(&QIZ65S(&%U(&3I8G5T
M(&1U(&UO:7.@/P!%9F9A8V5R(&QE<R!D;W-S:65R<R!D97,@86YC:65N<R!M
M97-S86=E<R!E;G9O>>ES(&%U(&3I8G5T(&1U(&UO:7.@/P!3=7!P<FEM97(@
M;&5S('!E<FUI<W-I;VYS('!O=7(@JZ`E<Z"[`,IT97,M=F]U<R!C97)T86EN
M(&1E('9O=6QO:7(@969F86-E<B"KH"5SH+L@970@<V5S('-O=7,M<&5R;6ES
M<VEO;G.@/P!%9F9A8V5R(&QA(')A;F?I90!3=7!P<FEM97(@;"=I9&5N=&ET
MZ2!SZ6QE8W1I;VYNZ64`4W5P<')I;65R(&QE<R!P;W5R<FEE;',`169F86-E
M<B!L82!C;VQO;FYE(&%C='5E;&QE`$5F9F%C97(@;&$@<F%N9^EE(&%C='5E
M;&QE`%-U<'!R:6WI`$UE<W-A9V5S('-U<'!R:6WI<P!38W)I<'0@9&4@8V]N
M9FEG=7)A=&EO;B!D92!M:7-E(.`@:F]U<B!S=7!P<FEMZ2"KH"5SH+LN`$3I
M=')U:7)E(&QA('!IZ&-E(&IO:6YT92"KH"5SH+LN`$3I<&QA8V5M96YT(&5T
M(&1E<W1R=6-T:6]N(&1E(&UE<W-A9V5S`$AE=7)E(&1E(&QI=G)A:7-O;@!$
M86YE;6%R:P!2969U<V5R(&QA(')E<77J=&4`4F5F=7-E<B!L82!R97%UZG1E
M('-U<B!L97,@9&ES<&]N:6)I;&ETZ7,`1.EC<F]I<W-A;G0`1.EC<FER92!L
M92!P<F]B;.AM90!$97-C<FEP=&EO;@!$Z71A:6QS`$3I=&%I;',@*&%U<W-I
M(&1A;G,@;&4@9FEC:&EE<B!D92!T<F%C97,@9&4@2&]R9&4IH#H`3&5S(&3I
M=&%I;',@;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L)V%D;6EN:7-T<F%T975R
M+@!$Z79E;&]P<&5M96YT`%!O:6YT(&1E(')O<^EE`%!O:6YT(&1E(')O<^EE
M('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``4&]I;G0@9&4@<F]SZ66@.B``
M4&GH8V4@:F]I;G1E(*N@)7.@NR!N;VX@871T86-HZ64@8V%R(&QE(&9I8VAI
M97(@Z71A:70@=FED92X`17-T;VUP97(@;&5S('-I9VYA='5R97.@/P!$92!G
M875C:&4@X"!D<F]I=&4`1&4@9')O:71E(.`@9V%U8VAE`%+I<&5R=&]I<F4`
M069F:6-H86=E`$%F9FEC:&5R('-U<B`R-"!H975R97.@/P!/<'1I;VYS(&0G
M869F:6-H86=E`$%F9FEC:&5R('5N92!C;VYF:7)M871I;VX@87!RZ',@;"=E
M;G9O:2!D)W5N(&UE<W-A9V6@/P!!9F9I8VAE<B!L82!P<NEV:7-I;VX@9.ET
M86EL;.EE`$%F9FEC:&5R(&QA('!RZ79I<VEO;B`H5$%&*0!&;W)M870@9"=A
M9F9I8VAA9V4`069F:6-H97(@9&%N<R!L92!C;W)P<R!D=2!M97-S86=E`$%F
M9FEC:&5R('5N92!N;W1I9FEC871I;VX@9&4@;F]U=F5A=2!C;W5R<FEE<B!D
M86YS('5N92!B;^YT92!S=7)G:7-S86YT9:`_`$%F9FEC:&5R(&QE(&QI96X@
MJZ!6:61E<B!L97,@<&]U<G)I96QSH+L@9&%N<R!L82!B87)R92!D92!M96YU
MH#\`069F:6-H97(@;&4@;&EE;B"KH%9I9&5R(&QA(&-O<F)E:6QL9:"[(&1A
M;G,@;&$@8F%R<F4@9&4@;65N=:`_`$1I<W!O<VET:6]N`$%V:7,@9&4@;&EV
M<F%I<V]N`$1J:6)O=71I`$YE(&-O<G)E<W!O;F1E;G0@<&%S`$YE('!A<R!V
MZ7)I9FEE<B!L97,@;F]U=F5A=7@@;65S<V%G97,@9&5S(&1O<W-I97)S`$YE
M('!A<R!S=7!P<FEM97(`3F4@<&%S(&%C8^ED97(@9&ER96-T96UE;G0@X"!M
M86EN=&5N86YC92YP:'``3F4@<&%S(&?I;NER97(@=6X@;&EE;B!D86YS(&QA
M(&-O;&]N;F4@JZ!$9:"[`%9O=6QE>BUV;W5S(&]U=G)I<B!C92!D;W-S:65R
MH#\`3&4@<')E;6EE<B!E;G)E9VES=')E;65N="!C;VYT:65N="UI;"!L92!N
M;VT@9&5S(&-H86UP<Z`_($1A;G,@;"=A9F9I<FUA=&EV92P@8V]C:&5Z(&-E
M='1E(&)O[G1EH#H`1&]M:6YI<75E`%+I<'5B;&EQ=64@9&]M:6YI8V%I;F4`
M5F]U<R!N)V%V97H@<&%S(&1E(&-O;7!T9:`_($5N<F5G:7-T<F5Z+79O=7,N
M`%1E<FUI;ND`5.ELZ6-H87)G97(`5.ELZ6-H87)G97(@)7,`5.ELZ6-H87)G
M97(@)7,@874@9F]R;6%T("YZ:7``5.ELZ6-H87)G97(@=&]U=&5S(&QE<R!P
M:>AC97,@:F]I;G1E<R`H96X@9F]R;6%T("YZ:7`I`%3I;.EC:&%R9V5R('5N
M*&1E<RD@9&]S<VEE<BAS*0!4Z6SI8VAA<F=E<B!U;BAD97,I(&1O<W-I97(H
M<RD@6V9O<FUA="`N>FEP70!4Z6SI8VAA<F=E<B!L82!C;VYF:6=U<F%T:6]N
M(&?I;NERZ64@8V]M;64@=6X@<V-R:7!T(%!(4`!4Z6SI8VAA<F=E<B!A=2!F
M;W)M870@+GII<`!"<F]U:6QL;VX`1&]S<VEE<B!D92!B<F]U:6QL;VYS`$1O
M<W-I97(@9&4@8G)O=6EL;&]N<Z`Z`$QI<W1E(&3I<F]U;&%N=&4`1')O9W5E
M<P!#;W5R<FEE<B#I;&5C=')O;FEQ=64`061R97-S92#I;&5C=')O;FEQ=64`
M4&EL;W1E(&1E('!A<W-E<F5L;&4@8V]U<G)I97(@+R!335,L('!O=7(@;&5S
M(&9O=7)N:7-S975R<R!D92!C92!S97)V:6-E+@!&24X`15)2`$524D554J`Z
M('9O=')E(&UE<W-A9V4@;B=A('!A<R!P=2#J=')E(&3I;&EV<NDN`,EQ=6%T
M975R`$UO9&EF:65R`,ED:71E<B!L82!L:7-T92!N;VER90#)9&ET97(@;&4@
M8FQO8P#)9&ET97(@;&5S(&9I;'1R97,`R61I=&5R('5N(&=R;W5P90#)9&ET
M97(@=6YE('!E<FUI<W-I;VX`R61I=&5R(&QE<R!P97)M:7-S:6]N<P#)9&ET
M97(@;&5S('!E<FUI<W-I;VYS('!O=7(@JZ`E<Z"[`$UO9&EF:65R(&1O<W-I
M97(@=FER='5E;`!-;V1I9FEE<B!L82!DZ69I;FET:6]N(&1U(&1O<W-I97(@
M=FER='5E;"!P;W5R("5S`,ED:71E<B!L82!L:7-T92!B;&%N8VAE`,ED:71E
M<B!L97,@;W!T:6]N<R!P;W5RH#H`R61I=&5R(&QE<R!P97)M:7-S:6]N<R!P
M;W5R(*N@)7.@NP#)9&ET97(@;&5S('!E<FUI<W-I;VYS('!O=7(@)7,`R61I
M=&5R('9O=')E(&QI<W1E(&YO:7)E`,ED:71E<B!V;W,@<NAG;&5S(&1E(&9I
M;'1R90#)9&ET97(@=F]S('!RZ6;I<F5N8V5S('!O=7(@86-CZ61E<B#@(&0G
M875T<F5S(&-O;7!T97,@9&4@8V]U<G)I97(N`,ED:71E<B!V;W1R92!L:7-T
M92!B;&%N8VAE`,ED=6-A=&EO;@#)9WEP=&4`4V%L=F%D;W(`R6SI;65N="XN
M+@!%;0!!9')E<W-E(.EL96-T<F]N:7%U90!!9')E<W-E(.EL96-T<F]N:7%U
M90!,97,@861R97-S97,@Z6QE8W1R;VYI<75E<R!D;VEV96YT(&-O<G)E<W!O
M;F1R92X`0V]U<G)I97(@879E8R!C;VYF:7)M871I;VX`4&%S<V5R96QL92!C
M;W5R<FEE<B`O(%--4P#);6]T:6/T;F5S`$5F9F%C96UE;G0@9&4@=&]U<R!L
M97,@;65S<V%G97,@9&4@)7,N`%9I9&5R(&QE*',I(&1O<W-I97(H<RD`5FED
M97(@;&5S(&1O<W-I97)S('/I;&5C=&EO;F[I<P!6:61E<B!L82!C;W)B96EL
M;&4`5FED97(@;&4@7W-P86T`5FED97(@;&$@7V-O<F)E:6QL90!-97-S86=E
M('9I9&4N`%+I<W5L=&%T('9I9&4N`%1E<FUE<R!D92!R96-H97)C:&4@=FED
M90!!8W1I=F5R(&QE<R!F;VYC=&EO;FYA;&ETZ7,@9&4@4$=0H#\`06-T:79E
M<B!L97,@9F]N8W1I;VYN86QI=.ES(&1E(%,O34E-1:`_`$%C=&EV97(@;"=I
M;G-E<G1I;VX@9"=I;6%G97,@=F5N86YT(&1E<R!A;&)U;7,@<&AO=&]S(&1A
M;G,@;&4@=&5X=&6@/P!!8W1I=F5R(&QA('!RZ2UV:7-U86QI<V%T:6]N(&1E
M<R!M97-S86=E<Z`_`$%C=&EV97(@;&4@;65N=2!C;VYT97AT=65L(&%V96,@
M=6X@8VQI8R!D<F]I=*`_`$]?<'1I;VYS(&1E(&-H:69F<F5M96YT`$-H:69F
M<ND`1FEN`$9I;B!D=2!M97-S86=E('1R86YS9NERZ0!&:6X@9'4@;65S<V%G
M90!&:6X@9'4@;65S<V%G92!D92`E<P!&:6X@9&4@;"=A;F[I90!!9W)A;F1I
M<B!L)^ED:71E=7(`16YT<F5Z(&QA('!H<F%S92!S96-RZ'1E`,EC<FEV97H@
M=6YE('%U97-T:6]N(&1E('/I8W5R:73I('%U)V]N('9O=7,@<&]S97)A('-I
M('9O=7,@9&5V97H@<F5M971T<F4@X"!ZZ7)O('9O=')E(&UO="!D92!P87-S
M92P@<&%R(&5X96UP;&4@JR!1=65L(&5S="!L92!N;VT@9&4@=F]T<F4@86YI
M;6%L('!RZ6;I<NF@/Z"[H#H`26YS8W)I=F5Z(&PG861R97-S92!54DP@9&4@
M;"=I;6%G92!I8VD`16YT<F5Z(&QE<R!L971T<F5S(&-I+61E<W-O=7.@.@!%
M;G1R97H@;&4@;F]M(&1E('9O=')E(&YO=79E874@9&]S<VEE<B!D92!P;W5R
M<FEE;',`16YT<F5Z(&QE(&YO;2!D=2!N;W5V96%U(&1O<W-I97(@9&4@8G)O
M=6EL;&]N<P!%;G1R97H@;&4@;F]M(&1U(&YO=79E874@9&]S<VEE<B!D92!M
M97-S86=E<R!E;G9O>>ES`$5N=')E>B!L92!N;VT@9&4@=F]T<F4@;F]U=F5L
M;&4@8V]R8F5I;&QE`$UE<W-A9V4@8V]M<&QE=`!!:F]U="!RZ75S<VD@9&4@
MJZ`E<Z"[(&1A;G,@;&4@8V%R;F5T(&0G861R97-S97,`1W5I;NEE(.EQ=6%T
M;W)I86QE`,ER>71H<NEE`$5R<F5U<@!%<G)E=7(@9&4@8V]N;F5X:6]N(&%U
M('-E<G9E=7(@24U!4"X@)7.@.B`E<RX`17)R975R(&QO<G,@9&4@;&$@8W+I
M871I;VX@9'4@8FQO8Z`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S
M:6]N(&1E(&PG86YC<F4@9&4@<WEN8VAR;VYI<V%T:6]NH#H@)7,`17)R975R
M(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9'4@:F]U<FYA;"!D92!S>6YC:')O
M;FES871I;VZ@.B`E<P!%<G)E=7(@;&]R<R!D92!L82!RZ6-U<.ER871I;VX@
M9'4@8V]N=&5N=:`Z("5S`$5R<F5U<B!L;W)S(&1E(&PG96YV;VD@9&4@;&$@
M<NEP;VYS9:`Z("5S+@!%<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D
M=2!M;W0@9&4@<&%S<V6@.B`E<P!%<G)E=7(@879E8R!L92!M97-S86=E+@!%
M<G)E=7(@;&]R<R!D92!L)V5N<F5G:7-T<F5M96YT(&1E(*N@)7.@NRX`17-T
M;VYI90#)=&AI;W!I90!%=&AN:7%U90!%=7)O<&4`3"?I=NEN96UE;G0@82#I
M=.D@969F86/I(&%V96,@<W5C8^AS+@!4;W5T97,@;&5S(#$U(&UI;G5T97,`
M5&]U=&5S(&QE<R`R(&UI;G5T97,`5&]U=&5S(&QE<R`S,"!S96-O;F1E<P!4
M;W5T97,@;&5S(#4@;6EN=71E<P#`(&-H87%U92!C;VYN97AI;VX`5&]U=&5S
M(&QE<R!D96UI+6AE=7)E<P!4;W5T97,@;&5S(&UI;G5T97,`17AE;7!L92!D
M92!V86QE=7)SH#H`17CI8W5T97(`1.EV96QO<'!E<@!$Z79E;&]P<&5R('1O
M=70`1.EV96QO<'!E<B!T;W5S(&QE<R!D;W-S:65R<P!$Z79E;&]P<&5R(&QE
M(&1O<W-I97(`1.EV96QO<'!E<B!L97,@;F]M<P!$Z7!L:65R(&QA(&)A<G)E
M(&1E(&/T=.D`1.EV96QO<'!E<B!L97,@;F]M<R!D86YS(&QA(&9E;NIT<F4@
M9&4@<NED86-T:6]N(&%U=&]M871I<75E;65N="!E;B!A<G)IZ')E+7!L86Z@
M/P!$Z79E;&]P<&5R(&QA(&QI<W1E(&1E<R!D;W-S:65R<R!P87(@9.EF875T
MH#\`1.EV96QO<'!E;65N="XN+B``JR`I(+L@871T96YD=64`56X@<V5U;"!M
M;W0@;W4@97AP<F5S<VEO;B!E;G1R92!G=6EL;&5M971S(&%T=&5N9'5S`$1A
M=&4@9"=E>'!I<F%T:6]N`%)E<'+I<V5N=&%N=`!#;W5L975R(&0G879A;G0M
M<&QA;@!4Z6SI8VAA<F=E;65N="!V97)S(&QE('-E<G9E=7(@9&4@;&$@8V]N
M9FEG=7)A=&EO;B!P87(@1E10`%+I8W5PZ7)A=&EO;B!D=2!C;W5R<FE?97(`
M3&5C='5R92!D97,@<'+I9NER96YC97,@:6UP;W-S:6)L92X`R6-H96,@9&4@
M;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@3$1!4"X`R6-H96,@9&4@;&$@8V]N
M;F5X:6]N(&%U('-E<G9E=7(@4TU"+@#)8VAE8R!D92!L82!C;W!I92!D97!U
M:7,@JZ`E<Z"[+@#)8VAE8R!D92!L82!C;W!I92!V97)S(""KH"5SH+LN`$EM
M<&]S<VEB;&4@9&4@8W+I97(@=6YE(&YO=79E;&QE(&-O;FYE>&EO;B!305-,
M`,EC:&5C(&1U(&3I<&QA8V5M96YT('9E<G,@JZ`E<Z"[+@#)8VAE8R!L;W)S
M(&1E(&QA('+I8W5PZ7)A=&EO;J`Z("5S`$)E874`SFQE<R!&86QK;&%N9"`H
M36%L;W5I;F5S*0#.;&5S($;I<F_I`$5R<F5U<B!F871A;&6@.@!&87@`5.EL
MZ6-O<&EE<P!&Z79R:65R`%1E;7#I<F%T=7)E(')E<W-E;G1I90!496UPZ7)A
M='5R92!R97-S96YT:66@.B``4NEC=7#I<F%T:6]N(&1U(&-O=7)R:65R`%+I
M8W5PZ7)A=&EO;B!D=2!C;W5R<FEE<B!D86YS('5N92!F96[J=')E('/I<&%R
MZ66@/P!287!A=')I97(@;&5S(&UE<W-A9V5S(&QO<G,@9&4@;&$@8V]N;F5X
M:6]NH#\`)60@;65S<V%G97,@<F%P871R:>ES(.`@<&%R=&ER(&1E("5S`#$@
M;65S<V%G92!R87!A=')IZ2#@('!A<G1I<B!D92`E<P!2Z6-U<.ER871I;VX@
M9'4@8V]U<G)I97*@.B``1F5T8VAM86ELH#H@<&%S(&1E(&YO=79E875X(&UE
M<W-A9V5S+@!1=65L<75E<R!A=F5R<V5S`%%U96QQ=65S(&-H=71E<R!D92!N
M96EG90!&:5]L=')E<P!-871R:6-E(&1E<R!C:&%M<',`1FEG;&5T($-!4%1#
M2$$`4&]L:6-E(&1E(&QA(#Q)/F9I9VQE=#PO23X`1FED:FD`1FEC:&EE<@!.
M;VUB<F4@9&4@9FEC:&EE<G.@.B`E<P!.;VUB<F4@9&4@9FEC:&EE<G.@.B`E
M<P!'97-T:6]N;F%I<F4@9&4@9FEC:&EE<G,`3F]M(&1U(&9I8VAI97(`0VAO
M:7@@9&4@9FEC:&EE<@!4Z6SI8VAA<F=E;65N="!D92!F:6-H:65R`$PG96YV
M;VD@9&4@9FEC:&EE<G,@;B=E<W0@<&%S('!R:7,@96X@8V]M<'1E+@!/<'1I
M;VYS(&1E(&9I;'1R86=E`%+H9VQE<R!D92!F:6QT<F5S`$9I;'1R97(@;&4@
M8V]N=&5N=2!D97,@;65S<V%G97.@/P!,92!S=7!P;W)T(&1U(&9I;'1R86=E
M(&5S="!DZ7-A8W1I=ND@<W5R(&-E('-Y<W3H;64N`$9I;'1R97,`1FEL=')E
M<R!.3TX@86-T:69S`$9I;'1R97.@.B!P86=E(&1E(&=E<W1I;VX@)7,`0VAE
M<F-H97(`1FEN;&%N9&4`4')E;6GH<F4@9&5M:64`4')E;6GH<F4@<&%G92!D
M92!L82!B;^YT90!0<F5M:>AR92!P86=E`%!R96UI97(@<75A<G1I97(`1FEX
M97(@;&4@<F%T:6\`4F5T;W5R;F5R`$9L;W1T86YT`%1?<F%N<V9E<G0`0G)O
M=6EL;&%R9`!$;W-S:65R("5S(&EN97AI<W1A;G0N`$%C=&EO;B!S=7(@;&5S
M(&1O<W-I97)S("T@0V]N9FER;6%T:6]N`$5X<&QO<F%T975R(&1E<R!D;W-S
M:65R<P!3;VUM86ER92!D=2!D;W-S:65R`$QE('!A<G1A9V4@9&5S(&1O<W-I
M97)S(&XG97-T('!A<R!A8W1I=NDN`$PG=71I;&ES871I;VX@9&5S(&1O<W-I
M97)S(&XG97-T('!A<R!A8W1I=NDN`$-O=6QE=7(@9&4@<&]L:6-E`$YO=7)R
M:71U<F4`4&]U<B!L97,@;F%V:6=A=&5U<G,@;F4@<W5P<&]R=&%N="!P87,@
M;&5S(&EM86=E<P!0<NEV:7-I;VX@*%1!1BD`2F]U<G,@9&4@<'+I=FES:6]N
M("AN;W1E>B!Q=64@;&5S('!RZ79I<VEO;G,@9F]U<FYI97,@9&]N;F5N="!L
M92!J;W5R(&5T(&QA(&YU:72@.R!U;B!G<F%N9"!N;VUB<F4@:6-I('!E=70@
M9F%I<F4@=6X@8FQO8R!T<NAS(&QA<F=E`%9O=7,@879E>B!O=6)L:>D@=F]T
M<F4@;6]T(&1E('!A<W-EH#\`3&4@9F]R;6%T(&1E(&QA(&1A=&4@9&%N<R!L
M82!V=64@9&4@8F_N=&4@875X(&QE='1R97,@<&]U<B!D97,@;65S<V%G97,@
M9&%TZ7,@9"=A=6IO=7)D)VAU:0!&;W)M=6QA:7)E<P!#:71A=&EO;@!4>7!E
M(&1E(&-I=&%T:6]N`$-I=&%T:6]N<P!#:71A=&EO;G,@,@!&;W)U;7,`5')A
M;G-F97)T`%1R86YS9F5R=*`Z`$UE<W-A9V4@=')A;G-FZ7+I`$UE<W-A9V4@
M=')A;G-FZ7+I(&1E("5S`%)E9&ER96-T:6]N`%9E`$-A9')E<P!&<F%N8V4`
M1G)A;F-E(&WI=')O<&]L:71A:6YE`%+I<&]N<V4@X"!L82!R97%UZG1E('-U
M<B!L97,@9&ES<&]N:6)I;&ETZ7,`1W5Y86YE(&9R86[G86ES90!0;VQY;NES
M:64@9G)A;N=A:7-E`%1E<G)E<R!A=7-T<F%L97,@970@86YT87)C=&EQ=65S
M(&9R86[G86ES97,`1%]E`$1E`$1E(&PG861R97-S90!$=2``1&5S8W)I<'1I
M;VX@8V]M<&SH=&4`4&QE:6YE(&QU;F4`3F]M(&-O;7!L970`5')A;G,N.@!4
M<F%N<RXZ(`!4<F%N<RXZ("5U(&UE<W-A9V5S('1R86YS9NERZ7,`1V%B;VX`
M06QB=6T@9"=O<FEG:6YE(&1E(&PG:6UA9V4`06QB=6V@.@!'86UB:64`3W!T
M:6]N<R!GZ6[I<F%L97,`1^ENZ7)E<B!L82!C;VYF:6=U<F%T:6]N(&1E("5S
M`$-O9&4@9^ENZ7+I`$?I;W)G:64`06QL96UA9VYE`$YE(')E8V5V;VER('%U
M92!L97,@;F]U=F5A=7@@;65S<V%G97.@/R`H24U!4"!S975L96UE;G0I`$=H
M86YA`$=I8G)A;'1A<@!0<NEN;VT`06QL97(`06QL97(@874@;65S<V%G90!!
M;&QE<B#@(&QA(&9I8VAE(&1U(&-A<FYE="!D)V%D<F5S<V5S(&1E(*N@)7.@
MNP!';V5D96P`0V%R=&5S($=O;V=L90!296-H97)C:&4@1V]O9VQE`$%C8V]R
M9&5R(&PG86-CZ',`3FEV96%U(&1E(&=R:7,`1W+H8V4`1W)E8R`H25-/+3@X
M-3DM-RD`1W)OZVYL86YD`$=R96YA9&4`061M:6YI<W1R871I;VX@9&5S(&=R
M;W5P97,`3&5S(&YO;7,@9&4@9W)O=7!E(&YE('!E=79E;G0@<&%S(.IT<F4@
M=FED97,`1W)O=7!?;&1A<*`Z(&EM<&]S<VEB;&4@9"=A:F]U=&5R(&QE(&=R
M;W5P92`E<RX@0V5C:2!E<W0@;&$@<NEP;VYS92!D=2!S97)V975RH#H`1W)O
M=7!?;&1A<*`Z('-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@9W)O=7!E("5S
M`$=R;W5P7VQD87"@.B!M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D=2!G<F]U
M<&4@)7,`1W)O=7!E<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M97-E>0!097)M:7-S:6]N<R!D97,@:6YV:73I<P!,:79R92!D)V]R`$=U:6[I
M90!'=6ENZ64M0FES<V%U`$=U>6%N80!)0TD`2%1-3`!697)S:6]N($A434P@
M9'4@;65S<V%G90!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I
M;65R(&QA(&1E<FYIZ')E(&-E;&QU;&4@9&4@;&$@<F%N9^EE`$A434Q!<F5A
M(')E9G5S92!BZG1E;65N="!D92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@8V]L
M;VYN92!D=2!T86)L96%U`$A434Q!<F5A(')E9G5S92!BZG1E;65N="!D92!S
M=7!P<FEM97(@;&$@9&5R;FGH<F4@<F%N9^EE(&1U('1A8FQE874`075T:&5N
M=&EF:6-A=&EO;B!(5%10(&YO;B!T<F]U=NEE+@!(8>]T:0!!;&=O<FET:&UE
M(&1E(&AA8VAA9V4`0G)U;64@<^AC:&4`16XM=.IT90!%;BUTZG1E<P#.;&5S
M($AE87)D(&5T($UC1&]N86QD`$]R86=E<R!V:6]L96YT<P!(Z6)R974@*$E3
M3RTX.#4Y+3@M22D`2&%U=&5U<@!!:61E`$%I9&4@<&]U<B!L)^ED:71E=7(`
M06ED90!(Z6UI<W!HZ')E`%9O:6-I(&QE(&3I8G5T(&1U(&9I8VAI97*@.@!6
M;VEC:2!L92!M97-S86=E('%U92!V;W5S(.ET:65Z(&5N('1R86EN(&1E('+I
M9&EG97*@.@!#86-HZ0!#86-HZ2!D86YS(&QA('9U92!A=F5C(&QE<R!E;F9I
M;&%D97,`0V%C:&5R(&QE<R!M97-S86=E<R!E9F9A8^ES`%-O=7-C<FET<R!S
M975L96UE;G0`2&%U=&4`4')I;W)I=.D@Z6QE=NEE`$QA('!L=7,@Z6QE=NEE
M`$%?8V-U96EL`$-I=.D@9'4@5F%T:6-A;@!!8V-U96EL`$%D<F5S<V4@<&5R
M<V]N;F5L;&4`4NEP97)T;VER92!P97)S;VYN96P`5.ELZ7!H;VYE('!E<G-O
M;FYE;`!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86*@.B!D
M;VYNZ65S(%A-3"`E<R!I;G9A;&ED97,@<F5T<F]U=NEE<R!D86YS(&QE(&UE
M<W-A9V4@)7,`2&]R9&4O2V]L86*@.B!A=6-U;B!M97-S86=E(&YE(&-O<G)E
M<W!O;F0@874@<W5J970@)7,`2&]R9&4O2V]L86*@.B!P87,@9"=O8FIE="!D
M92!T>7!E("5S('1R;W5VZ2!D86YS(&QE(&UE<W-A9V4@)7,`2&]R9&4O2V]L
M86*@.B`E<R!S=7!P<FEMZ2"KH"5SH+L@879E8R!S=6-CZ',`2&]R9&4O2V]L
M86*@.B!L92!M;W1E=7(@9"=I;G3I9W)A=&EO;B!NZ6-E<W-I=&4@;"=E>'1E
M;G-I;VX@)V1O;7AM;"<@9&4@4$A0`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L
M92!D92!C<NEE<B!U;B!N;W5V96P@87)B<F4@6$U,('!O=7(@;"=O8FIE="`E
M<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9"=E;FQE=F5R("5S(*N@)7.@
MNZ`Z("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D92!RZ6-U<.ER97(@
M;"=I9&5N=&EF:6%N="!-24U%('!O=7(@;&$@<&%R=&EE(&1E('1Y<&4@)7,`
M2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E('-Y;F-H<F]N:7-E<B`E<R"K
MH"5SH+N@.B`E<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<WEN8VAR
M;VYI<V5R(&QE<R!P87)T86=E<Z`Z("5S`$AO<F1E+TMO;&%BH#H@<&%R=&%G
M92!I;F-O;FYU(*N@)7.@NP!,:6=N92!H;W)I>F]N=&%L90!296UP;&ES<V%G
M92!H;W)I>F]N=&%L`$AO<FEZ;VYT86R@.@!#;VUM96YT(.IT97,M=F]U<R!A
M<G)I=ND@:6-IH#\@*%-64"!R87!P;W)T97HM;&6@(2D`0V]M;65N="!V;W5L
M97HM=F]U<R!A9F9I8VAE<B!L97,@<&GH8V5S(&IO:6YT97.@/P!#;VUB:65N
M(&1E(&-O;&]N;F5S('9O=6QE>BUV;W5S(&9U<VEO;FYE<J`_`$-O;6)I96X@
M9&4@8VAA;7!S("AC;VQO;FYE<RD@>2!A+70M:6R@/P!#;VUB:65N(&1E(')A
M;F?I97,@=F]U;&5Z+79O=7,@9G5S:6]N;F5RH#\`0V]M;65N="!A='1R:6)U
M97(@;&5S(&-I=&%T:6]N<R!D86YS('5N92!RZ7!O;G-E`$AU;6ED:73I`$AU
M;6ED:73IH#H@`$AU;6]R:7-T97,`2&]N9W)I90!)34%0`$E-05`@*&3I=&5C
M=&5R(&%U=&]M871I<75E;65N="!L97,@<')O=&]C;VQE<RD`3&4@<V5R=F5U
M<B!)34%0(&$@9F5R;>D@;&$@8V]N;F5X:6]N+B!,92!S97)V975R(&$@<NEP
M;VYD=:`Z("5S`,EC:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@;&$@8F_N
M=&4@24U!4*`Z("5S`,EC:&5C(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@
M;&$@8F_N=&4@24U!4*`Z("5S`,EC:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@
M9'4@<75O=&$@<W5R(&QA(&)O[G1E($E-05"@.B`E<P!)34%0('-U<B!34TP`
M24U!4"!S=7(@4U-,("AC97)T:69I8V%T(&UA:7-O;BD@`$E-05`@<W5R(%-3
M3"`H8V5R=&EF:6-A="!M86ES;VXI`$QE('-E<G9E=7(@24U!4"!A(&9E<FWI
M(&QA(&-O;FYE>&EO;BX`24U!4"P@<V%N<R!43%,`4V5R=F5U<G,@9&4@8V]U
M<G)I97(@24U!4"]03U`S`$)O[G1E(&1E('+I8V5P=&EO;@!!9')E<W-E($E0
M`$%D<F5S<V4@25`@;F]N(&1I<W!O;FEB;&4N`$%D<F5S<V4@25`@:&]R<R!D
M=2!B;&]C($-)1%(@86QL;W7I+@!6:6]L871I;VX@9&4@8FQO8V%G92!)4"X`
M25]N<^ER97(@<F%N9^EE(&%V86YT`$ES;&%N9&4`26/T;F5S('-E=6QE;65N
M=`!)8_1N97,@<&]U<B`E<P!)8_1N97,@<&QU<R!T97AT90!.;VT@9'4@8V]M
M<'1EH#H`4VD@;"=A9F9I8VAA9V4@;B=E<W0@<&%S(&-O<G)E8W0L("5S('!O
M=7(@;"=O=79R:7(@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R92X`4&]U<B!U
M=&EL:7-E<B!34TP@;W4@5$Q3+"!V;W5S(&1E=F5Z(&%V;VER(&-H87)GZ2!L
M)V5X=&5N<VEO;B!/<&5N4U-,(&1E(%!(4"X`4VD@=F]U<R!C;VYT:6YU97HL
M('1O=7,@;&5S(&UE<W-A9V5S(&1E(&-E*',I(&1O<W-I97(H<RD@<V5R;VYT
M('!E<F1U<Z`A`%-I('9O=7,@;F4@=F]Y97H@875C=6X@:6/T;F4@96X@=71I
M;&ES86YT($EN=&5R;F5T($5X<&QO<F5R+"!V;W5S('!O=79E>B!A=F]I<B#@
M(&-O8VAE<B!C971T92!C87-E('!O=7(@9.ES86-T:79E<B!L82!T<F%N<W!A
M<F5N8V4@9&5S(%!.1RX`4VD@=F]U<R!V;WEE>B!C92!M97-S86=E(&UA:7,@
M875C=6YE(&EM86=E+"!L)VEM86=E('%U92!V;W5S('9O=6QE>B!E;G9O>65R
M(&YE('!E=70@ZG1R92!A9F9I8VCI92!P87(@=F]T<F4@;F%V:6=A=&5U<BX`
M26=N;W)E<@!)9VYO<F5R('1O=70`26UA9V4`07!E<N=U(&1E(&PG:6UA9V6@
M.@!!9')E<W-E(%523"!D92!L)VEM86=E`$%D<F5S<V4@55),(&1E(&PG:6UA
M9V6@.@!);6%G92!D92!L)V%L8G5M`$EM86=E(&1E(&PG86QB=6V@.@!4Z6SI
M8VAA<F=E;65N="!D)VEM86=E<P!);6%G97,`26UP;W)T97(`26UP;W)T97(@
M;&$@8VQE9@!);7!O<G1E<B!L82!P86ER92!D92!C;&5F<P!);7!O<G1E<B!L
M97,@;65S<V%G97,`26UP;W)T97(@;&$@8VQE9B!01U``26UP;W)T97(@;&4@
M8V5R=&EF:6-A="!P97)S;VYN96P`26UP;W)T97(@;&$@8VQE9B!P<FEVZ64@
M<&5R<V]N;F5L;&4@*%!'4"D`26UP;W)T97(@;&$@8VQE9B!P=6)L:7%U92!P
M97)S;VYN96QL92`H4$=0*0!);7!O<G1E<B!L97,@8V5R=&EF:6-A=',@4R]-
M24U%('!E<G-O;FYE;',`26UP;W)T97(@;&$@8VQE9B!P=6)L:7%U90!);7!O
M<G1E<B!L82!C;&5F('!U8FQI<75E(%!'4`!);7!O<G1E<B!L82!C;&5F('!U
M8FQI<75E(%,O34E-10!);7!O<G1E<B!L82!C;&5F(%,O34E-10!);7!O<G1E
M<B!U;B!F:6-H:65R(&UB;W@`26UP;W)T97(@=6X@9FEC:&EE<B!M8F]X("5S
M(&1A;G,@;&4@<NEP97)T;VER92`E<RX`26UP;W)T871I;VXL(.ET87!E("5D
M`$AA=71E(&EM<&]R=&%N8V4`365S<V%G97,@:6UP;W)T86YT<P`E9"!M97-S
M86=E<R!I;7!O<G3I<R#@('!A<G1I<B!D92`E<RX`0VAA;7`@:6UP;W)TZ:`Z
M("5S`$-H86UP<R!I;7!O<G3I<Z`Z`$5N(&-O=7)S`$EN7W/I<F5R(')A;F?I
M92!A<'+H<P!";^YT92!D92!RZ6-E<'1I;VX`26YC;'5R92!U;B!B<F5F(')A
M<'!E;"!D97,@96XM=.IT97,@9&%N<R!L97,@<NEP;VYS97.@/P!);F-L=7)E
M(&QE(&UE<W-A9V4@9"=O<FEG:6YE(&1A;G,@;&5S('+I<&]N<V5SH#\`0V]D
M92!D)V%C=&EO;B!I;F-O<G)E8W0N`$YO;2!D)W5T:6QI<V%T975R(&5T+V]U
M('9O=')E(&UO="!D92!P87-S92!I;F-O<G)E8W0N`$YO;2!D)W5T:6QI<V%T
M975R(&]U(&%D<F5S<V4@86QT97)N871I=F4@:6YC;W)R96-T+B`@4NEE<W-A
M>65Z(&]U(&-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U<B!S>7-TZ&UE
M('!O=7(@9&4@;"=A:61E+@!!=6=M96YT97(@;"=I;F1E;G1A=&EO;@!);F1E
M`%5T:6QI<V%T975R<R!I;F1I=FED=65L<P!);F1O;NES:64`26YF;P!);F9O
M<FUA=&EO;G,`3"=I;F9O<FUA=&EO;B!N)V5S="!P;'5S(&1I<W!O;FEB;&4N
M`$EN9F]R;6%T:6]N('-U<B!L82!C;&5F('!U8FQI<75E("5S`$EN9F]R;6%T
M:6]N('-U<B!L82!C;&5F('!R:7;I92!P97)S;VYN96QL90!);F9O<FUA=&EO
M;B!S=7(@;&$@8VQE9B!P=6)L:7%U92!P97)S;VYN96QL90!);F-O<G!O<NEE
M`$EN<^ER97(@8U]O;&]N;F4@87!RZ',`26YSZ7)E<B!L92!C97)T:69I8V%T
M(&EC:0!);G/I<F5R(&EM86=E`$EN<^ER97(@;&$@8VQE9B!P<FEVZ64@<&5R
M<V]N;F5L;&4@*%!'4"D@:6-I`$EN<^ER97(@;&$@8VQE9B!P=6)L:7%U92!P
M97)S;VYN96QL92`H4$=0*2!I8VD`26YSZ7)E<B!L82!C;&5F('!U8FQI<75E
M(%!'4"!I8VD`26YSZ7)E<B!U;B!T86)L96%U`$EN<^ER97(@=6X@;&EE;B!W
M96(`26YSZ7)E<B!?8V]L;VYN92!A=F%N=`!);G/I<F5R('5N92!N;W5V96QL
M92!C;VQO;FYE(&%P<NAS(&QA(&-O;&]N;F4@86-T=65L;&4`26YSZ7)E<B!U
M;F4@;F]U=F5L;&4@8V]L;VYN92!A=F%N="!L82!C;VQO;FYE(&%C='5E;&QE
M`$EN<^ER97(@=6YE(&YO=79E;&QE(')A;F?I92!A<'+H<R!L82!R86YGZ64@
M86-T=65L;&4`26YSZ7)E<B!U;F4@;F]U=F5L;&4@<F%N9^EE(&%V86YT(&QA
M(')A;F?I92!A8W1U96QL90!);G/I<F5R('5N('!A<F%G<F%P:&4@87!RZ',@
M;&4@;B9O96QI9SMU9"!A8W1U96P`26YSZ7)E<B!U;B!P87)A9W)A<&AE(&%V
M86YT(&QE(&XF;V5L:6<[=60@86-T=65L`$EN<^ER97(@=6X@875T<F4@;6]D
MZ&QE`$EN<V-R:79E>B!U;F4@861R97-S92!D92!C;W5R<FEE<B#@(&QA<75E
M;&QE('9O=7,@<F5C979R97H@;&4@;F]U=F5A=2!M;W0@9&4@<&%S<V6@.@!)
M;G/I<F5R(&-E;&QU;&4@87!RZ',`26YSZ7)E<B!C96QL=6QE(&%V86YT`$EN
M<^ER97(@8V]L;VYN92!A<'+H<P!);G/I<F5R(&-O;&]N;F4@879A;G0`26YS
MZ7)E<B!L97,@;65S<V%G97,`26YSZ7)E<B!P87)A9W)A<&AE(&%P<NAS`$EN
M<^ER97(@<&%R86=R87!H92!A=F%N=`!);G/I<F5R(')A;F?I92!A<'+H<P!)
M;G/I<F5R(')A;F?I92!A=F%N=`!);G-C<FEV97H@;&$@<NEP;VYS92#@(&QA
M('%U97-T:6]N(&1E('/I8W5R:73IH#H`26YSZ7)E<B]-;V1I9FEE<B!U;F4@
M:6UA9V4`26YSZ7)E<B]-;V1I9FEE<B!U;B!L:65N('=E8@!#<NED:70@:6YS
M=69F:7-A;G0@<&]U<B!E;G9O>65R(.`@;&$@;&ES=&4@9&4@9&ES=')I8G5T
M:6]N+@!#<NED:70@:6YS=69F:7-A;G0N`$5N=&EE<@!,:7-T92!C;VUP;.AT
M90!3Z6QE8W1I;VX@9"=U;F4@86-T:6]N(&EN=F%L:61E('!O=7(@8V4@8V]M
M<&]S86YT+@!!9')E<W-E(&EN=F%L:61E`$)O[G1E(&1I<W1A;G1E(&EN=F%L
M:61E`%5$2"`H57-E<B!$871A($AE861E<BD@:6YV86QI9&4`1&]N;NEE(%I)
M4"!I;G9A;&ED92X`07!P;&EC871I;VX@:6YV86QI9&4N`$=R;W5P92!)1"!I
M;G9A;&ED92X`0V%R86-TZ')E(&EN=F%L:61E(&1A;G,@;"=A9')E<W-E(&1E
M(&-O=7)R:65LH#H@)7,N`$5N=F]I(&1E(&1O;F[I97,@:6YV86QI9&5S+@!!
M9')E<W-E(&1E(&1E<W1I;F%T:6]N(&EN=F%L:61E+@!&;W)M870@9&4@9FEC
M:&EE<B!I;G9A;&ED92X`0VQE9B!I;G9A;&ED90!#;&5F(&1E(&QI8V5N8V4@
M:6YV86QI9&4N`$5M<&QA8V5M96YT(&EN9&EQ=>D@:6YV86QI9&4N`*MM<V=?
M='EP9;L@:6YV86QI9&4N`*MA<&E?:62[(&EN=F%L:61E(&]U(&UA;G%U86YT
M+@!087)A;>AT<F5S(&EN=F%L:61E<R!O=2!M86YQ=6%N=',N`%!E<FUI<W-I
M;VX@:6YV86QI9&4N`$ED+B!D92!P87)T96YA:7)E(&EN=F%L:61E+@!#;&5F
M('!R:7;I92!01U`@<&5R<V]N;F5L;&4@:6YV86QI9&4N`$-L968@<'5B;&EQ
M=64@4$=0('!E<G-O;FYE;&QE(&EN=F%L:61E+@!#;V1E(&1E('!R;V1U:70@
M:6YV86QI9&4N`%!R;W1O8V]L92!I;G9A;&ED92X`1&5S=&EN871A:7)E(&EN
M=F%L:61EH#H@JZ`E<Z"[`$]B:F5T(&1E('!A<G1A9V4@:6YV86QI9&4`061R
M97-S92!S;W5R8V4@:6YV86QI9&4N`$1O;F[I92!5;FEC;V1E(&EN=F%L:61E
M+@!);G9E;G1A:7)E`$EN=F5R<V5R`$EN=F5R<V5R(&QA('/I;&5C=&EO;@!)
M<F%N`$ER86L`27)L86YD90#.;&4@9&4@36%N`%1E;7#J=&5S(&ES;VSI97,`
M27-R8>ML`,EM971T975R`$ET86QI<75E`$ET86QI90!*86UA[W%U90!*86YV
M:65R`$IA<&]N`$IA<&]N86ES("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A
M;FEE`$IU:6QL970`2G5I;@!*=7-T:69I97(`0V5N=')E<@!*=7-T:69I97(`
M06QI9VYE<B#@(&=A=6-H90!!;&EG;F5R(.`@9')O:71E`$MO`$MA>F%K:'-T
M86X`1V%R9&5R(&PG;W)I9VEN86R@/P!+96YY80!,92!S97)V975R($ME<F)E
M<F]S(&$@<F5J973I(&PG875T:&5N=&EF:6-A=&EO;BX`1.EB=71A;G1S(&1U
M(&YO>6%U`$-RZ6%T:6]N(&1E(&-L968`16UP<F5I;G1E(&1E(&QA(&-L968`
M3&]N9W5E=7(@9&4@;&$@8VQE9@!4>7!E(&1E(&-L968`571I;&ES871I;VX@
M9&4@;&$@8VQE9@!,82!C;&5F('-E('1R;W5V92!DZ6K@('-U<B!L92!S97)V
M975R(&1E(&-L969S('!U8FQI8RX`1^ENZ7)E<B!L82!C;&5F('!E=70@ZG1R
M92!A<W-E>B!L;VYG+B!#;VYT:6YU97(@;&$@9^ENZ7)A=&EO;B!D92!L82!C
M;&5FH#\`26UP;W)T871I;VX@9&4@;&$@8VQE9B!N;VX@9&ES<&]N:6)L92X@
M3VX@;F4@<&5U="!P87,@9.EP;W-E<B!D92!F:6-H:65R('-U<B!C92!S97)V
M975R+@!);7!O<G1A=&EO;B!D92!L82!C;&5F(&YO;B!D:7-P;VYI8FQE+B!6
M;W5S(&XG879E>B!P87,@9.EF:6YI(&1E(&-A<FYE="!D)V%D<F5S<V5S(&_Y
M(&%J;W5T97(@=F]S(&-O;G1A8W1S+@!,82!C;&5F(&$@8FEE;B#I=.D@96YV
M;WGI92!A=2!S97)V975R(&1E(&-L969S('!U8FQI8RX`16YF86YT<P!+:7)I
M8F%T:0!#;W+I92!D=2!.;W)D`$-O<NEE(&1U(%-U9`!#;W+I96X@*$550RU+
M4BD`2V]W9>]T`$MI<F=H:7II<W1A;@!0<NE?<V5N=&%T:6]N`$QA;F=U90!,
M86]S`$1E<FYIZ')E(&1E;6EE`$1E<FYIZ')E('!A9V4@9&4@;&$@8F_N=&4`
M1&5R;FGH<F4@<&%G90!$97)N:>AR92!M;V1I9FEC871I;VX@9'4@;6]T(&1E
M('!A<W-E`$1E<FYI97(@<75A<G1I97(`1&5R;FGH<F4@;6ES92#@(&IO=7*@
M.@!$97)N:>AR92!C;VYN97AI;VZ@.B`E<P!$97)N:>AR92!C;VYN97AI;VZ@
M.B`E<R#@('!A<G1I<B!D92`E<P!$97)N:>AR92!C;VYN97AI;VZ@.B!J86UA
M:7,`3&5T=&]N:64`3&]I`%!RZ7-E;G1A=&EO;@!,86ES<V5R('9I9&4@<&]U
M<B!N92!P87,@879O:7(@9&4@8F]R9'5R90!,:6)A;@!'875C:&4`16YTZG1E
M(&=A=6-H90!686QE=7)S(&1E(&=A=6-H90!,97-O=&AO`$YI=F5A=0!,:6+I
M<FEA`$QI8GEE`$QI96-H=&5N<W1E:6X`0G)U:6YE(&SI9^AR90!0;'5I92!L
MZ6?H<F4`4&QU:64@;.EGZ')E('3T="!D86YS(&QA(&IO=7)NZ64`4&QU:64@
M;.EGZ')E('1A<F0`079E<G-E<R!LZ6?H<F5S`%!L=6EE(&SI9^AR92!A=F5C
M('1O;FYE<G)E`$YE:6=E(&EN=&5R;6ET=&5N=&4`079E<G-E(&1E(&YE:6=E
M(&SI9^AR90!2:6UE<P!,:65N`$QI97(@;&5S('!IZ&-E<R!J;VEN=&5SH#\`
M3&4@;&EE;B!P;VEN=&4@=F5R<Z`Z`$QI92!L)V%D<F5S<V4@9&4@8V]U<G)I
M96P@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N(&1U(&UE<W-A9V4@96X@;"=A
M9F9I8VAA;G0`3&5S('!IZ&-E<R!J;VEN=&5S(&QIZ65S(&YE('-O;G0@<&%S
M('!E<FUI<V5S+@!,:65N<P!,97,@;&EE;G,@97AP:7)E<F]N="!L92`E<P!"
M:7-C=6ET($QI;G5X`$QI<W1E("T@=71I;&ES871E=7(@<&5U="!V;VER(&QE
M(&1O<W-I97(`3&ES=&4@9&5S(&)A<V5S(&1E(&1O;F[I97,`26YD97@@9&4@
M;"=A:61E`$%F9FEC:&5R(&QE<R!T86)L97,`3&ES=&5R('1O=7,@;&5S(&-O
M;G1A8W1S(&%U(&-H87)G96UE;G0@9&4@;"?I8W)A;B!D97,@8V]N=&%C='.@
M/R`H<VD@9.ES86-T:7;I+"!V;W5S(&YE('9E<G)E>B!Q=64@;&5S(&-O;G1A
M8W1S(&5X<&QI8VET96UE;G0@9&5M86YDZ7,I`$%R8VAI=F5S(&1E(&QA(&QI
M<W1E`$%I9&4@9&4@;&$@;&ES=&4`260N(&1E(&QA(&QI<W1E`%!R;W!R:>ET
M86ER92!D92!L82!L:7-T90!%;G9O:2#@(&QA(&QI<W1E`$%B;VYN96UE;G0@
MX"!L82!L:7-T90!$Z7-A8F]N;F5M96YT(&1E(&QA(&QI<W1E`$QI<W1E(&1A
M;G,@;&5S(&5N+73J=&5S`,EC:&5C(&1E(&QA(&QI<W1E(&1E<R!S97-S:6]N
M<Z`Z("5S`,EC:&5C(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G.@.B`E
M<P!,)V%F9FEC:&%G92!D92!L82!L:7-T92!D97,@=71I;&ES871E=7)S(&5S
M="!DZ7-A8W1I=NDN`$QI='3I<F%T=7)E`$QI='5A;FEE`$-H87)G96UE;G0N
M+BX`0F_N=&4@;&]C86QEH#H`2&5U<F4@;&]C86QEH#H@`$AE=7)E(&5T(&QO
M8V%L90!,:65U`$-O;FYE>&EO;@!#;VYN97AI;VX@X"`E<P!4<F%C92!D92!L
M82!D97)N:>AR92!S97-S:6]N(&1E('-Y;F-H<F]N:7-A=&EO;@!$Z6-O;FYE
M>&EO;@!.;VT@9"=U=&EL:7-A=&5U<@!4XF-H97,@9&4@8V]N;F5X:6]N`$QA
M(&-O;FYE>&EO;B!E<W0@<F5F=7/I92X@26P@97-T('!R;V)A8FQE('%U92!V
M;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!O=2!V;W1R92!M;W0@9&4@<&%S<V4@
M82#I=.D@;6%L('-A:7-I`,EC:&5C(&1E(&-O;FYE>&EO;BX`5&5X=&4@;&]N
M9P!!;6]U<@!&86EB;&4`4')I;W)I=.D@9F%I8FQE`$QE='1R92!G<F5C<75E
M<R!M:6YU<V-U;&5S`$QE='1R92!L871I;F5S(&UI;G5S8W5L97,`3F]M8G)E
M(')O;6%I;G,@;6EN=7-C=6QE<P!,82!P;'5S(&)A<W-E`$QU>&5M8F]U<F<`
M34T`365S<V%G92!D=2!J;W5R("A-3U1$*0!,82!P:>AC92!J;VEN=&4@35,M
M5$Y%1B!N92!C;VYT96YA:70@875C=6YE(&1O;F[I92X`35-'`$UA8V%O`%+I
M<'5B;&EQ=64@9&4@36%CZ61O:6YE`$9I8VAI97(@36%C:6YT;W-H`$UA9&%G
M87-C87(`36%G:64`0V]U<G)I97(`061M:6YI<W1R871I;VX@9'4@8V]U<G)I
M96P`4'+I+79I<W5A;&ES871I;VYS(&1U(&-O=7)R:65R`%1Y<&4@9&4@<V5R
M=F5U<B!A=7%U96P@<V4@8V]N;F5C=&5RH#H`0F_N=&4@9&4@8V]U<G)I97(`
M3W!T:6]N<R!D)V%F9FEC:&%G92!P;W5R(&QE<R!B;^YT97,@9&4@8V]U<G)I
M97(@970@;&5S(&1O<W-I97)S`$9A:7)E('5N(&QI95]N`$UA;&%W:0!-86QA
M:7-I90!-86QD:79E<P!-86QI`$UA;'1E`$%D;6EN:7-T<F5Z(&QA(&QI<W1E
M(&1E(&-A=.EG;W)I97,@970@;&5S(&-O=6QE=7)S(&QIZ65S(.`@8V5S(&-A
M=.EG;W)I97,N`$-A<G1E(*L@36%P,C0@NP!#87)T92"K($UA<'%U97-T(+L`
M0V]R<F5S<&]N9&%N8V5S(&5N<F5G:7-T<NEE<RX`36%R<P!-87)G90!-87)Q
M=65R('1O=7,@;&5S(&UE<W-A9V5S(&1U(&1O<W-I97(@8V]M;64@;'5S`$UA
M<G%U97(@=&]U<R!L97,@;65S<V%G97,@9'4@9&]S<VEE<B!C;VUM92!N;VXM
M;'5S`$UA<G%U97(@8V]M;66@.@!$:7-T:6YG=65R(&QE<R!N:79E875X(&1E
M(&-I=&%T:6]N<R!P87(@9&5S(&-O=6QE=7)S(&1I9F;I<F5N=&5SH#\`36%R
M<75E<B!L97,@;65S<V%G97,@8V]M;64@;'5SH#\@*$E-05`@<V5U;&5M96YT
M*0!-87)Q=65R(&%V96,@=6YE(.ET:7%U971T92!S:6UP;&6@/P!-87)Q=65R
M(&%V96,@9&5S(.ET:7%U971T97,@5G4O3F]N('9U`$UA<G%U97(@879E8R!D
M)V%U=')E<R#I=&EQ=65T=&5S("AE>"XZ($EM<&]R=&%N="]2Z7!O;F1U*0#.
M;&5S($UA<G-H86QL`$UA<G1I;FEQ=64`0V]R<F5S<&]N9"#@('1O=71E<R!L
M97,@<F5Q=>IT97,`0V]R<F5S<&]N9"#@(&XG:6UP;W)T92!Q=65L;&4@9&5S
M(')E<77J=&5S`$-H86UP<R!A<'!A<F5N=.ES`$UA=7)I=&%N:64`SFQE($UA
M=7)I8V4`0W+I9&ET(&UA>&EM=6T@86QL;W7I+@!,:6UI=&4@9'4@;65S<V%G
M92!DZ7!A<W/I92X`5&5M<.ER871U<F4@;6%X:6UA;&4@9&5S(#(T(&1E<FYI
MZ')E<R!H975R97.@.B``5&5M<.ER871U<F4@;6%X:6UA;&4@9&5S(#8@9&5R
M;FGH<F5S(&AE=7)E<Z`Z(`!486EL;&4@;6%X:6UA;&4@9&4@;&$@<&GH8V4@
M:F]I;G1E`$YO;6)R92!M87AI;6%L(&1E(&1O<W-I97)S`$YO;6)R92!M87AI
M;75M(&1E(&)L;V-S(&1U('!O<G1A:6P`3&]N9W5E=7(@;6%X:6UU;0!.;VUB
M<F4@;6%X:6UA;"!D92!P:>AC97,@:F]I;G1E<R!A='1E:6YT+@!486EL;&4@
M;6%X:6UA;&4@=&]T86QE(&1E<R!P:>AC97,@:F]I;G1E<R!A='1E:6YT92X`
M36%I`$UA>6]T=&4`3>ED:6-A;65N=`!-96UB<F5S`$UE;G4@;&ES=&4@9&4@
M9&]S<VEE<G,`5'EP92!D92!M96YUH#H`1G5S:6]N;F5R(&QE<R!C96QL=6QE
M<P!-97-S86=E`%+I9&%C=&EO;B!D92!M97-S86=E`$1A=&4@9'4@;65S<V%G
M90!/<'1I;VYS(&1U(&UE<W-A9V4`4F5C:&5R8VAE<B!U;B!M97-S86=E`%1A
M:6QL92!D=2!M97-S86=E`%-O=7)C92!D=2!M97-S86=E`%;I<FEF:6-A=&EO
M;B!D=2!M97-S86=E('+I=7-S:64L(&UA:7,@;&4@8V5R=&EF:6-A="!D=2!S
M:6=N871A:7)E(&XG82!P87,@<'4@ZG1R92!VZ7)I9FGI+@!#;VYS=6QT871I
M;VX@9'4@;65S<V%G90!-97-S86=E(&5X<&ERZ2X`R71I<75E='1E<R!D=2!M
M97-S86=E`$1O<W-I97)S(&1U(&UE<W-A9V4`365S<V%G92!D92`E<P!,92!M
M97-S86=E(&$@9&5S('!IZ&-E<R!J;VEN=&5S`$QE(&UE<W-A9V4@97-T(&-H
M:69F<ND`3&4@;65S<V%G92!E<W0@<VEG;ND`3&4@;65S<V%G92!C;W)R97-P
M;VYD`$QE(&UE<W-A9V4@82!B:65N(.ETZ2!R961I<FEGZ2X`365S<V%G92!B
M:65N(&5N=F]YZ2P@;6%I<R!N;VX@96YR96=I<W1RZ2!D86YS("5S`$QE(&UE
M<W-A9V4@82!B:65N(.ETZ2!E;G9O>>DN`%1Y<&4@9&4@;65S<V%G90!-97-S
M86=E<R!P87(@<&%G92!L;W)S(&1E(&PG869F:6-H86=E(&1E(&QA(&)O[G1E
M+@!-97-S86=E<R#@`$WI=.EO($UE=&%R`$QE(&)L;V,@JR!-971A<B"[(&XG
M97-T('!A<R!D:7-P;VYI8FQE+@!,92!B;&]C(*L@365T87(@NR!N)V5S="!P
M87,@9&ES<&]N:6)L92X@($QE<R!DZ71A:6QS(&]N="#I=.D@8V]N<VEG;NES
M('!O=7(@;"=A9&UI;FES=')A=&5U<BX`365T87)$0B!N)V5S="!P87,@8V]N
M;F5C=.DN`$WI=&AO9&4`3&$@;>ET:&]D92"KH"5SH+L@;B=E<W0@<&%S(&3I
M9FEN:64`3>ET:&]D92!N;VX@9.EF:6YI92X@3>ET:&]D92!A<'!E;.EEH#H@
M)7,`3>ET<FEQ=64`365X:7%U90#)=&%T<R!FZ63I<NES(&1E($UI8W)O;NES
M:64`36EL:65U`%1Y<&4@34E-10!496UPZ7)A='5R92!M:6YI;75M(&1E<R`R
M-"!D97)N:>AR97,@:&5U<F5SH#H@`%1E;7#I<F%T=7)E(&UI;FEM=6T@9&5S
M(#8@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!,82!D=7+I92!M:6YI;6%L92!D=2!M
M;W0@9&4@<&%S<V4@;B=A('!A<R!E;F-O<F4@97AP:7+I`$UI<F]I<@!687)I
MZ7,`3&4@<&%Q=65T86=E($A45%!?<F5Q=65S="!014%2(&5S="!M86YQ=6%N
M="X`0V]N9FEG=7)A=&EO;B!I;F5X:7-T86YT92X@5F]U<R!D979E>B!L82!G
MZ6[I<F5R(&UA:6YT96YA;G0@<VD@=F]U<R!V;W5L97H@=71I;&ES97(@8V5T
M=&4@87!P;&EC871I;VXN`$E$(&1U(&UE<W-A9V4@;6%N<75A;G0N`$QE('!A
M<75E=&%G92!014%2($UA:6P@97-T(&UA;G%U86YT+@!)1"!D92!S97-S:6]N
M(&UA;G%U86YT+@!,=0!#;W5R<FEE;"!S86YS(&9I;`!-;V3I<ND`1&%T92!D
M92!M;V1I9FEC871I;VX`36]D:69I97(`36]D:69I97(@;"=54DP`36]D=6QO
M`$UO;&1A=FEE`$UO;F%C;P!-;VYG;VQI90!-;VES(&5T(&%N;NEE`$UE;G-U
M96QL96UE;G0`36]N='-E<G)A=`!0:&%S97,@9&4@;&$@;'5N90!#:&%M<',@
M<W5P<&SI;65N=&%I<F5S('1R;W5VZ7,@X"!L82!L:6=N92`E9"`H871T96YD
M=7,@)60I+@!0;'5S:65U<G,@861R97-S97,@8V]R<F5S<&]N9&5N="!A=2!C
M:&%M<""KH"5SH+LN`$UA<F]C`$?I;NER86QE;65N="!E;G-O;&5I;&SI`$?I
M;NER86QE;65N="!N=6%G975X`$?I;NER86QE;65N="!E;G-O;&5I;&SI`$3I
M<&QA8V5R`%9E<G,@;&4@8F%S`$3I<&QA8V5R(.`@9V%U8VAE`$3I<&QA8V5R
M(.`@9')O:71E`%9E<G,@;&4@:&%U=`!697)S(&QE(&)A<P!$Z7!L86-E<B!L
M97,@<&]U<G)I96QS('9E<G,@;&4@9&]S<VEE<B!D92!S<&%M(&5T(&QE<R!M
M97-S86=E<R!LZ6=I=&EM97,@=F5R<R!L82!B;^YT92!D92!RZ6-E<'1I;VX`
M5F5R<R!L92!D;W-S:65R`%9E<G,@;&4@:&%U=`!-;WIA;6)I<75E`$QI<W1E
M<R!DZ7)O=6QA;G1E<R!M=6QT:2UN:79E875X`$-A<G1E(*N@375L=&EM87`@
M54N@NP!-=6QT:7!A<G0O06QT97)N871I=F4`069F:6-H86=E(&1E<R!M97-S
M86=E<R!M=6QT:7!L97,`4^EL96-T:6]N(&UU;'1I<&QE`%!A<F%MZ71R86=E
M(&1U(&-O;7!T90!-97,@9&]N;NEE<R!P97)S;VYN96QL97,`36]N('!O<G1A
M:6P`4'+I<V5N=&%T:6]N(&1E(&UO;B!P;W)T86EL`$)I<FUA;FEE`$Y/3BP@
M:F4@;B=A8V-E<'1E('!A<P!!54-53@!.3U1%`$YO;0!,92!N;VT@970O;W4@
M;"=A9')E<W-E(&YE('!E=79E;G0@<&%S(.IT<F4@=FED97,`3F%M:6)I90!.
M875R=0!!='1E;G1E(&0G86-T:6]N`$[I<&%L`%!A>7,M0F%S`$%N=&EL;&5S
M(&[I97)L86YD86ES97,`55),(&1E(&)A<V4@9&4@3F5T<V-A<&4`55),(&1E
M('+I=F]C871I;VX@9&4@;"=!+D,N($YE='-C87!E`%523"!D92!L82!P;VQI
M=&EQ=64@9"=!+D,N($YE='-C87!E`%523"!D92!R96YO=79E;&QE;65N="!.
M971S8V%P90!54DP@9&4@<NEV;V-A=&EO;B!.971S8V%P90!.;VT@9'4@<V5R
M=F5U<B!34TP@3F5T<V-A<&4`0V]M;65N=&%I<F4@9'4@8V5R=&EF:6-A="!.
M971S8V%P90!4>7!E(&1U(&-E<G1I9FEC870@3F5T<V-A<&4`4NES96%U`$IA
M;6%I<P!.92!J86UA:7,@96YR96=I<W1R97(@;&5S('!IZ&-E<R!J;VEN=&5S
M`$YO=79E874`3F]U=F5L;&4M0V%LZ61O;FEE`$YO=79E;&QE(&-A=.EG;W)I
M90!.;W5V96%U(&1O<W-I97(`3F]U=F5A=2!C;W5R<FEE<@!.;W5V96%U(&UE
M<W-A9V4`3F]U=F5A=2!M97-S86=E('!O=7(@)7,`3F]U=F5L;&4@;'5N90!.
M;W5V96%U(&YO;2!D92!C;VYN97AI;VX@*&9A8W5L=&%T:68I`$YO=79E;&QE
M+5KI;&%N9&4`3F]U=F5A=7@@;65S<V%G97,`3F]U=F5A=2!M;W0@9&4@<&%S
M<V4`3&4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@97AP:7)E<F$@;&4@)7@N`$QE
M<R!N;W5V96%U>"!M;W1S(&1E('!A<W-E(&1I9F;H<F5N="X`3F]U=F5L;&4@
M9F5NZG1R92`H7V)L86YK*0!.;W5V96QL97,`1F]R=6US`%-U:79A;G0`-"!P
M:&%S97,@<W5I=F%N=&5S`$UE<W-A9V4@<W5I=F%N=`!086=E('-U:79A;G1E
M`$]P=&EO;G,@<W5I=F%N=&5S`%-U:79A;G0^`$YI8V%R86=U80!.:6=E<@!.
M:6=E<FEA`$YU:70`3FEU90!.;VX`075C=6X@8V5R=&EF:6-A="!T<F]U=ND`
M075C=6X@8VAI9F9R96UE;G0`075C=6YE(&-L968@9&%N<R!L)V%N;F5A=0!0
M87,@9&4@;65S<V%G97,`075C=6YE(&-L968@<'5B;&EQ=64@4$=0(&XG82#I
M=.D@:6UP;W)TZ64N`%!A<R!D92!C97)T:69I8V%T('!E<G-O;FYE;"!P<NES
M96YT`%!A<R!D92!P<NDM=FES=6%L:7-A=&EO;@!!=6-U;F4@8VQE9B!P=6)L
M:7%U92!T<F]U=NEE`$%U8W5N92!C;&5F('!U8FQI<75E(%,O34E-12!I;7!O
M<G3I92X`075C=6YE('!IZ&-E(&IO:6YT92!T<F]U=NEE+@!087,@9&4@9&]N
M;NEE<R!D92!C;VYF:6=U<F%T:6]N('!O=7(@;&5S<75E;&QE<R!M;VYT<F5R
M(&QE<R!D:69FZ7)E;F-E<RX`4&%S(&1E('-T<F%TZ6=I92!D:7-P;VYI8FQE
M('!O=7(@9F%I<F4@9&5S(&EM86=E<R!)4T\N`%!A<R!D92!G86)A<FET(&5N
M('1R86ET96UE;G0@<&%R(&QO="X`075C=6X@8FQO8R!N)V5X:7-T92#@(&QA
M('!O<VET:6]N(&1E;6%N9.EE`%!A<R!D92!N;VT@9&4@8V%L96YD<FEE<B!F
M;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($U#04PN`$YO;B!M
M;V1I9FGI+@!!=6-U;F4@<V]U<RUP97)M:7-S:6]N(&XG82!B97-O:6X@9"?J
M=')E(&%J;W5TZ64@<V]U<R!C92!N:79E874N`$%U8W5N92!I;F9O<FUA=&EO
M;B!D92!C;VYF:6=U<F%T:6]N('-PZ6-I9FGI92!P;W5R("5S+@!!=6-U;F4@
M:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE('!O=7(@1E10
M(%9&4RX`075C=6YE(&EN9F]R;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@9F]U
M<FYI92!P;W5R(%-13"!61E,N`$%U8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF
M:6=U<F%T:6]N(&9O=7)N:64@<&]U<B!344PM1FEL92!61E,N`$%U8W5N(&-R
MZ61I="!D:7-P;VYI8FQE+@!!=6-U;F4@9&5S=&EN871I;VX@=')O=7;I92X`
M075C=6YE(&EN9F]R;6%T:6]N('-U<B!L)V%D<F5S<V4@9&%N<R!L82!C;&5F
M('!U8FQI<75E+@!!=6-U;B!F:6-H:65R(&5N=F]YZ0!!=6-U;B!D;W-S:65R
M(&XG82#I=.D@<^EL96-T:6]N;NDN`$%U8W5N(&1O<W-I97(@;B=E<W0@=NER
M:69IZ2!P;W5R(&QE<R!N;W5V96%U>"!M97-S86=E<RX`075C=6X@9&]S<VEE
M<B!S<.EC:69IZ0!!=6-U;B!D;W-S:65R(&%V96,@9&4@;F]U=F5A=7@@;65S
M<V%G97,`075C=6X@9&]S<VEE<B!A=F5C(&1E<R!M97-S86=E<R!N;VXM;'5S
M`$%U8W5N(&EC]&YE('1R;W5VZ2X`075C=6X@;&EE=2!N)V5S="!SZ6QE8W1I
M;VYNZ0!!=6-U;B!E;7!L86-E;65N="!N)V5S="!I;F1I<77I+@!087,@9&4@
M=&5X=&4@9&%N<R!L92!C;W)P<R!D=2!M97-S86=E`$%U8W5N(&UE<W-A9V4@
M9F]U<FYI`$%U8W5N(&UE<W-A9V4@;F4@8V]R<F5S<&]N9"#@('9O=')E(')E
M8VAE<F-H92X`075C=6X@;F]M('-PZ6-I9FGI+@!!=6-U;B!N;VUB<F4@<W#I
M8VEF:>DN`%!A<R!D)V%P:&]R:7-M97,@8VAO<75A;G1S`$%U8W5N(&UO="!D
M92!P87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($A4
M5%`N`$%U8W5N(&UO="!D92!P87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I
M9FEC871I;VX@<&%R($E-05`N`$%U8W5N(&UO="!D92!P87-S92!F;W5R;FD@
M<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($ME<F)E<F]S+@!!=6-U;B!M
M;W0@9&4@<&%S<V4@<W#I8VEF:>D@<&]U<B!L)V%U=&AE;G1I9FEC871I;VXN
M`$%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF
M:6-A=&EO;B!005-35T0N`$%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P
M;W5R(&PG875T:&5N=&EF:6-A=&EO;B!334(N`$%U8W5N(&-H96UI;B!V97)S
M(&QE(&)I;F%I<F4@3W!E;E-33"!F;W5R;FDN($QE(&)I;F%I<F4@9"=/<&5N
M4U-,(&5S="!NZ6-E<W-A:7)E('!O=7(@9F]N8W1I;VYN97(@879E8R!D97,@
M9&]N;NEE<R!02T-3(#$R+@!!=6-U;F4@8V]N9FER;6%T:6]N(&5N(&%T=&5N
M=&4`075C=6YE(&-L968@<')I=NEE(%!'4"!N)V$@Z73I(&EM<&]R=.EE+@!!
M=6-U;F4@8VQE9B!P=6)L:7%U92!01U`@;B=A(.ETZ2!I;7!O<G3I92X`075C
M=6X@8V5R=&EF:6-A="!P97)S;VYN96P@4R]-24U%(&EM<&]R=.DN`$EL(&XG
M97AI<W1E(&%U8W5N92!C;&5F('!R:7;I92P@970@;&4@;65S<V%G92!N92!P
M975T(&1O;F,@<&%S(.IT<F4@9.EC:&EF9G+I+@!087,@9&4@<75O=&$@<&]S
M:71I;VYNZ2X`4&%S(&1E('+H9VQE<P!!=6-U;B!SZ7!A<F%T975R('-PZ6-I
M9FGI+@!087,@9&4@8_1TZ7,`075C=6X@=NER:69I8V%T975R(&0G;W)T:&]G
M<F%P:&4@8V]N9FEG=7+I+@!!=6-U;F4@97)R975R(&0G;W)T:&]G<F%P:&4`
M1FEC:&EE<B!I;F5X:7-T86YT`$%U8W5N92!S=6=G97-T:6]N`$%U8W5N92!M
MZ71H;V1E(&0G875T:&5N=&EF:6-A=&EO;B!)34%0('-U<'!O<G3I92!N)V$@
MZ73I('1R;W5VZ64N`$%U8W5N('+I<&5R=&]I<F4@=&5M<&]R86ER92!E<W0@
M9&ES<&]N:6)L92!P;W5R(&QA(&-A8VAE`$%U8W5N('5T:6QI<V%T975R('-P
MZ6-I9FGI+@!!=6-U;B!N;VT@9"=U=&EL:7-A=&5U<B!E="`O;W4@;6]T(&1E
M('!A<W-E(&5N=F]YZ2X`075C=6YE(&1O;F[I92!834P@=F%L:61E(&XG82#I
M=.D@<F5T;W5R;NEE`%!A<R!D92!V86QE=7(`4&%S(&1E('9E<G-I;VX@=')O
M=7;I92!D86YS(&QA(&-O;F9I9W5R871I;VX@;W)I9VEN86QE+B!2Z6?I;NER
M97H@;&$@8V]N9FEG=7)A=&EO;BX`4&%S(&1E('9E<G-I;VX@=')O=7;I92!D
M86YS('9O=')E(&-O;F9I9W5R871I;VXN(%+I9^ENZ7)E>B!L82!C;VYF:6=U
M<F%T:6]N+@!.;VXM<&%R=&EC:7!A;G0`075C=6X`075C=6X@*'5T:6QI<V5R
M(&EM<&QI8VET96UE;G0I`$YO<F1I<75E("A)4T\M.#@U.2TQ,"D`SFQE($YO
M<F9O;&L`3F]R;6%L`$CI;6ES<&CH<F4@3F]R9`#.;&5S($UA<FEA;FYE<R!D
M=2!N;W)D`$YO<G;H9V4`4&%S(&%P<NAS`%!A<R!A=F%N=`!.;VX@<W5P<')I
M;>D`3B=E<W0@<&%S('5N(&)R;W5I;&QO;@!0974@:6UP;W)T86YT`$YO;B!P
M97)S;VYN96P`4&%S('5N(&1O<W-I97(`0VQE9B!P=6)L:7%U92!I;G9A;&ED
M92X`365S<V%G97,@;F]N+7-U<'!R:6WI<P!.;VX@:6UP;.EM96YTZ2X`365S
M<V%G97,@<&5U(&EM<&]R=&%N=',`26YA8W1I9@!.;VX@<')I<R!E;B!C;VUP
M=&4N`$YO=&5Z('%U92!C96QA('!E=70@<')E;F1R92!U;B!C97)T86EN('1E
M;7!S`$YO=&5S`%)I96X`4FEE;B#@(&YA=FEG=65R+"!R971O=7)N97H@96X@
M87)R:>AR92X`3F]T:69I8V%T:6]NH#H@;&5S('!IZ&-E<R!J;VEN=&5S(&QI
MZ65S(&]N="#I=.D@=.ELZ6-H87)GZ65S`$YO=F5M8G)E`$YO;6)R90!.;VUB
M<F4@9&4@8V%R86-TZ')E<P!.;VUB<F4@9&4@8V]L;VYN97,`3F]M8G)E(&1E
M(&UO:7,@<&]U<B!G87)D97(@9&4@=FEE=7@@871T86-H96UE;G1S(&QIZ7,@
M<VD@<W5P<')I;>ES(&UE;G-U96QL96UE;G0N`$YO;6)R92!D92!D;W-S:65R
M<R!D92!M97-S86=E<R!E;G9O>>ES(.`@9V%R9&5R(',G:6QS('-O;G0@969F
M86/I<R!M96YS=65L;&5M96YT+@!.;VUB<F4@9&4@<F%N9^EE<P!.;VUB<F4@
M;F]N('-PZ6-I9FGI('!O=7(@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES=&4@
M9&4@9&ES=')I8G5T:6]N+@!/2P!/50!/8FIE=`!#<NEA=&5U<B!D)V]B:F5T
M`$]C=&%L`$]C=&]B<F4`1FEL=')E(&%N=&DM;V9F96YS86YT`$)U<F5A=0!,
M)V%N8VEE;B!E="!L92!N;W5V96%U(&UO=',@9&4@<&%S<V4@9&]I=F5N="#J
M=')E(&1I9F;I<F5N=',N`$%N8VEE;G,@;65S<V%G97,`06YC:65N(&UO="!D
M92!P87-S90!,)V%N8VEE;B!M;W0@9&4@<&%S<V4@97-T(&EN8V]R<F5C=`!,
M97,@9&]S<VEE<G,@9"=A;F-I96YS(&UE<W-A9V5S(&5N=F]YZ7,@<V]N="!E
M;B!C;W5R<R!D)V5F9F%C96UE;G0N`$]M86X`4V5U;"!L97,@<V5R=F5U<G,@
M24U!4"!S=7!P;W)T96YT(&QE<R!D;W-S:65R<R!P87)T86?I<RX`069F:6-H
M97(@;&5S(&1O<W-I97)S(&%V96,@9&5S(&UE<W-A9V5S(&YO;BUL=7,@<V5U
M;&5M96YTH#\`4V5U;&5M96YT(&QE<R"KH&9O<G1U;F5SH+L@;V9F96YS86YT
M97,`56YE('-E=6QE(&%D<F5S<V4@9&4@8V]U<G)I96P@<&5R;6ES92X`5F]U
M<R!N92!P;W5V97H@<^EL96-T:6]N;F5R('%U)W5N('-E=6P@9&]S<VEE<B!P
M;W5R(&-E='1E(&%C=&EO;BX`4V5U;',@;&4@<')O<')IZ71A:7)E(&]U(&PG
M861M:6YI<W1R871E=7(@<WES=.AM92!P975T(&UO9&EF:65R(&QE<R!P97)M
M:7-S:6]N<R!D)W5N('!A<G1A9V4N`$]U=G)I<B!?;&4@9&]S<VEE<@!/=79R
M:7(@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R90!%<G)E=7(@3W!E;E-33*`Z
M(&EM<&]S<VEB;&4@9"=E>'1R86ER92!L97,@9&]N;NEE<R!D92!L82!P87)T
M:64@<VEG;NEE(%,O34E-10!$;W-S:65R(&]U=F5R=`!/=79R:7(@;&5S(&QI
M96YS(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`4WES=.AM92!D)V5X<&QO
M:71A=&EO;@!087)T:6-I<&%N="!F86-U;'1A=&EF`$]P=&EO;G,`3W!T:6]N
M<R!P;W5R("5S`$QI<W1E(&YU;>ER;W3I90!/<F=A;FES871I;VX`56YI=.D@
M;W)G86YI<V%T:6]N;F5L;&4`3W)G86YI<V%T:6]N`$UO9.AL92!O<FEG:6YA
M;"!D)V%P<&QI8V%T:6]N`$UO9.AL97,@;W)I9VEN875X(&1A;G,@)7.@.@!!
M=71R90!!=71R97,@:6YF;W)M871I;VYS`$%U=')E<R!C;VUP=&5S(&1E(&-O
M=7)R:65R`$%U=')E<R!O<'1I;VYS`%-E<G9E=7(@9&ES=&%N=`!097)M:7-S
M:6]N<R!D=2!P<F]P<FGI=&%I<F4`3"=A=71H96YT:69I8V%T:6]N(%!!32!N
M)V5S="!P87,@9&ES<&]N:6)L92X`36]D=6QE(%!%05(Z.DUA:6P`4$=0`%-I
M9VYA='5R92!N=6WI<FEQ=64@4$=0`$-H:69F<F5R(&QE(&UE<W-A9V4@879E
M8R!01U``1&]N;NEE<R!01U`@8VAI9F9RZ65S`$5R<F5U<B!01U"@.B``17)R
M975R(%!'4*`Z(&QA('!H<F%S92!S96-RZ'1E(&5S="!NZ6-E<W-A:7)E('!O
M=7(@;&$@8VQE9B!P<FEVZ64@<&5R<V]N;F5L;&4N`$]P=&EO;G,@9&4@4$=0
M`$5N='+I92!D92!L82!P:')A<V4@<V5C<NAT92!01U``3&4@<W5P<&]R="!D
M92!L82!P86ER92!D92!C;&5F<R!P97)S;VYN96QL97,@<F5Q=6EE<G0@=6YE
M(&-O;FYE>&EO;B!A=2!W96(@<^EC=7)I<^EE+@!#;&5F('!U8FQI<75E(%!'
M4`!497AT92!D92!L82!C;.D@<'5B;&EQ=64@4$=0`$QA(&-L968@<'5B;&EQ
M=64@4$=0(&1E(*N@)7,@*"5S*:"[(&$@8FEE;B#I=.D@86IO=73I92X`3&$@
M8VQE9B!P=6)L:7%U92!01U`@9&4@JZ`E<Z"[(&$@8FEE;B#I=.D@<W5P<')I
M;>EE+@!!;FYE874@9&4@8VQE9G,@<'5B;&EQ=65S(%!'4`!3:6=N97(@;&4@
M;65S<V%G92!A=F5C(%!'4`!3:6=N97(O8VAI9F9R97(@;&4@;65S<V%G92!A
M=F5C(%!'4`!$;VYNZ65S(%!'4"!S:6=NZ65S+V-H:69F<NEE<P!,82!C;&5F
M(%!'4"!P<FEVZ64@82!B:65N(.ETZ2!A:F]U=.EE+@!,82!C;&5F(%!'4"!P
M=6)L:7%U92!A(&)I96X@Z73I(&%J;W5TZ64N`$QE('-U<'!O<G0@9&4@4$=0
M(&5S="!DZ7-A8W1I=ND@<W5R(&-E('-Y<W3H;64N`$QE('-U<'!O<G0@9&4@
M4$=0(&XG97-T('!A<R!A8W1I9B!A8W1U96QL96UE;G0L(&5T(&QA('-I9VYA
M='5R92!N=6WI<FEQ=64@;B=A(&1O;F,@<&%S(.ETZ2!VZ7)I9FGI92X`3&4@
M<W5P<&]R="!D92!01U`@;B=E<W0@<&%S(&%C=&EF(&%C='5E;&QE;65N="P@
M970@;&4@;65S<V%G92!N92!P975T(&1O;F,@<&%S(.IT<F4@9.EC:&EF9G+I
M+@!01U`@=71I;&ES92!D97,@9F5NZG1R97,@<W5R9VES<V%N=&5S+B!3:2!C
M971T92!F;VYC=&EO;B!E<W0@9.ES86-T:7;I92!D86YS('9O=')E(&YA=FEG
M871E=7(L(&EL(&9A=70@;"=A8W1I=F5R+"!S86YS('%U;VD@4$=0(&YE(&9O
M;F-T:6]N;F5R82!P87,@8V]R<F5C=&5M96YT+@!#;V1E(%!(4`!);G1E<G!R
MZ71E=7(@4$A0`%!L=6EE(&SI9^AR92!L)V%P<NAS+6UI9&D`079E<G-E<R!L
M)V%P<NAS+6UI9&D`3F5I9V4@;"=A<'+H<RUM:61I`$-H=71E<R!D92!N96EG
M92!L)V%P<NAS+6UI9&D`4V]L96EL(&PG87!RZ',M;6ED:0!/<F%G97,@;"=A
M<'+H<RUM:61I`%!/4#,`4$]0,R`H9.ET96-T97(@875T;VUA=&EQ=65M96YT
M(&QE<R!P<F]T;V-O;&5S*0!03U`S('-U<B!34TP`4$]0,R!S=7(@4U-,("AC
M97)T:69I8V%T(&UA:7-O;BD@`%!/4#,@<W5R(%-33"`H8V5R=&EF:6-A="!M
M86ES;VXI`%!/4#,L('-A;G,@5$Q3`$5X=&5N<VEO;B!03U-)6"!A8G-E;G1E
M`$EN=&5R<'+I=&5U<B!07TA0`%)E;7!L:7-S86=E`%!A9V4@)60@9&4@)60`
M4&%G92!A=F5C(&QE('!R96UI97(@;65S<V%G92!N;VX@;'4`4&%G92!A=F5C
M(&QE(&1E<FYI97(@;65S<V%G92!N;VX@;'4`4&%K:7-T86X`0F5L874`4&%L
M97-T:6YE("AT97)R:71O:7)E(&]C8W5PZ2D`4&%N86UA`%!A<&]U87-I92U.
M;W5V96QL92U'=6ENZ64`4&%R86=U87D`4&%R=&EE*',I`%!A<G1I96QL96UE
M;G0@;G5A9V5U>`!0:')A<V4@<V5C<NAT90!0:')A<V4@<V5C<NAT92`HX"!N
M;W5V96%U*0!,82!P:')A<V4@<V5C<NAT92!A(&)I96X@Z73I(&3I8VAA<F?I
M92X`4&AR87-E('-E8W+H=&6@.@!,82!P:')A<V4@<V5C<NAT92!N92!D;VET
M('!A<R#J=')E('9I9&4`3&5S('!H<F%S97,@<V5C<NAT97,@9&EF9NAR96YT
M`$UO="!D92!P87-S90!#:&%N9V5M96YT(&1U(&UO="!D92!P87-S92!E9F9E
M8W1UZ2X`36]T(&1E('!A<W-E(&EN8V]R<F5C=`!-;W0@9&4@<&%S<V4@<F5Q
M=6ES('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%)!1$E54RX`36]T(&1E('!A
M<W-E(&%V96,@8V]N9FER;6%T:6]N`$UO="!D92!P87-S9:`Z`$UO="!D92!P
M87-S9:`Z(`!,97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@:61E;G1I
M<75E<RX`0V]L;&5R`$-O;&QE<B!D97!U:7,@;&4@<')E<W-E+7!A<&EE<G,`
M0VAE;6EN`$-O;F9I<FUA=&EO;G,@96X@871T96YT9:`Z`%!E<G-O;FYE<P!0
M;W5R8V5N=&%G90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E
M;F%N8V4`17CI8W5T:6]N(&1E<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E
M(.`@;&$@8V]N;F5X:6]NH#\`4&5R;6ES<VEO;@!,82!P97)M:7-S:6]N(*N@
M)7.@NR!N)V5S="!P87,@<W5P<')I;>EE+@!097)M:7-S:6]N(')E9G5SZ64`
M4&5R;6ES<VEO;G,`061M:6YI<W1R871I;VX@9&5S('!E<FUI<W-I;VYS`$UO
M9&EF:6-A=&EO;B!I;7!O<W-I8FQE(&1E<R!P97)M:7-S:6]N<R!D92!C970@
M=71I;&ES871E=7(N`%!E<G-O;FYE;`!$;VYNZ65S('!E<G-O;FYE;&QE<P!6
M;W1R92!P86ER92!D92!C;&5F<R!01U`@<&5R<V]N;F5L;&4@82!B:65N(.ET
MZ2!GZ6[I<NEE+@!6;W,@8VQE9G,@4$=0('!E<G-O;FYE;&QE<R!O;G0@8FEE
M;B#I=.D@969F86/I97,N`$-E<G1I9FEC871S('!E<G-O;FYE;',@4R]-24U%
M($Y/3B!I;7!O<G3I<Z`Z(`!6;W,@8VQE9G,@4R]-24U%('!E<G-O;FYE;&QE
M<R!O;G0@8FEE;B#I=.D@969F86/I97,N`%#I<F]U`$%N:6UA=7@`4&AI;&EP
M<&EN97,`5.ELZ7!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA8V5R
M('9O=')E('-I9VYA='5R92!A=2!DZ6)U="!D97,@<NEP;VYS97,@970@9&5S
M('1R86YS9F5R='.@/P!697)S:6]N('1E>'1E(&)R=70@9'4@;65S<V%G90!0
M;&%T:71U9&5S`$YO=&EF:6-A=&EO;B!S;VYO<F4@9&4@8V]U<G)I97*@/R!#
M96QA('-U<'!O<V4@<75E('9O=')E(&YA=FEG871E=7(@<W5P<&]R=&4@;"=I
M;F-O<G!O<F%T:6]N(&1E(&9I8VAI97)S('-O;G,N($,G97-T(&QE(&-A<R!D
M92!L82!P;'5P87)T('-O=7,@5VEN9&]W<R!O=2!-86,L(&UA:7,@<W5R(&0G
M875T<F5S('!L871E<RUF;W)M97,@=6YE(&5X=&5N<VEO;B!P975T(.IT<F4@
M;NEC97-S86ER92X`4U90(&-L:7%U97H@9&%N<R!U;F4@8V5L;'5L90!35E`@
M8V]N9FER;65Z(&QA('-U<'!R97-S:6]N(&1E(&-E="#I;.EM96YTH#H`4U90
M(&-O;F9I<FUE>B!Q=64@=F]U<R!V;W5L97H@9.EL:65R(&-E="#I;.EM96YT
M+@!6975I;&QE>B!S86ES:7(@=6X@;6]I<R!E="!U;F4@86YNZ64N`%9E=6EL
M;&5Z('-A:7-I<B!U;B!N;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R:66@
M.@!6975I;&QE>B!E;G1R97(@=6X@;F]M('!O=7(@;&4@;F]U=F5A=2!D;W-S
M:65RH#H`5F5U:6QL97H@96YT<F5R('5N92!A9')E<W-E($E0('9A;&ED92X`
M5F5U:6QL97H@96YT<F5R('5N92!D871E('9A;&ED9:`[(';I<FEF:65Z(&QE
M(&YO;6)R92!D92!J;W5R<R!D=2!M;VES+B``5F5U:6QL97H@96YT<F5R('5N
M92!H975R92!V86QI9&4N`%9E=6EL;&5Z(&5N=')E<B!L92!N;VT@9'4@;F]U
M=F5A=2!D;W-S:65RH#H`5F5U:6QL97H@96YT<F5R(&QE(&YO=79E874@;F]M
MH#H`5F5U:6QL97H@96YT<F5R(&QA('!H<F%S92!S96-RZ'1E('!O=7(@=F]T
M<F4@8VQE9B!01U`@<')I=NEE+B!);"!N92!F875D<F$@96YT<F5R(&-E='1E
M('!H<F%S92!S96-RZ'1E('%U)W5N92!S975L92!F;VES('!A<B!S97-S:6]N
M("5S+@!6975I;&QE>B!E;G1R97(@;&$@<&AR87-E('-E8W+H=&4@<&]U<B!V
M;W1R92!C;&5F(%,O34E-12!P<FEVZ64N($EL(&YE(&9A=61R82!E;G1R97(@
M8V5T=&4@<&AR87-E('-E8W+H=&4@<74G=6YE('-E=6QE(&9O:7,@<&%R('-E
M<W-I;VX@)7,N`%9E=6EL;&5Z('9O=7,@<F5C;VYN96-T97(@<&]U<B!P;W5R
M<W5I=G)E(&QA('+I9&%C=&EO;B!D92!V;W1R92!M97-S86=E+B!3:2!V;W5S
M(&XG=71I;&ES97H@4$%3(&QE<R!C;V]K:65S($54('-I('9O=7,@<NED:6=E
M>B!L97,@;65S<V%G97,@9&%N<R!U;F4@9F5NZG1R92#@('!A<G0L('9O=7,@
M9&5V<F5Z(&%U<W-I('9O=7,@<F5C;VYN96-T97(@9&%N<R!V;W1R92!F96[J
M=')E('!R:6YC:7!A;&4N($-E8VD@<&5R;65T(&0G96UPZF-H97(@;"=U=&EL
M:7-A=&EO;B!D92!V;W1R92!I9&5N=&EF:6%N="!D92!S97-S:6]N('!A<B!D
M)^EV96YT=65L<R!I;G1R=7,L(&5T(&YE('!E=70@<&%S(.IT<F4@Z79I=.DN
M(%9E=6EL;&5Z(&YO=7,@97AC=7-E<B!D92!C92!DZ7-A9W+I;65N="X@`%9E
M=6EL;&5Z(&9O=7)N:7(@=6X@<NES=6WI(&1U('!R;V)LZ&UE+@!6975I;&QE
M>B!S86ES:7(@=F]T<F4@;6]T(&1E('!A<W-E+@!6975I;&QE>B!F;W5R;FER
M('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&5T('9O=')E(&UO="!D92!P87-S
M90!6975I;&QE>B!S86ES:7(@=F]T<F4@;F]M(&0G=71I;&ES871E=7(N`%9E
M=6EL;&5Z(&QI<F4@;&4@=&5X=&4@<W5I=F%N="X@5F]U<R!D979E>B!A8V-E
M<'1E<B!L97,@8V]N9&ET:6]N<R!P;W5R('5T:6QI<V5R(&QE('-Y<W3H;64N
M`%9E=6EL;&5Z(&-O<G)I9V5R(&QE<R!A9')E<W-E<R!A;6)I9W7K<R!O=2!I
M;G9A;&ED97,N`%9E=6EL;&5Z('/I;&5C=&EO;FYE<B!U;B!D;W-S:65R(&%V
M86YT(&0G86-C;VUP;&ER('5N92!A8W1I;VXN`%9E=6EL;&5Z('/I;&5C=&EO
M;FYE<B!A=2!M;VEN<R!U;B!D;W-S:65R(&1E(')E8VAE<F-H92X`5F5U:6QL
M97H@<^EL96-T:6]N;F5R('5N(&1O<W-I97(@=6YI<75E('!O=7(@8V5T=&4@
M;W#I<F%T:6]N+@!6975I;&QE>B!SZ6QE8W1I;VYN97(@;W4@Z61I=&5R(&1A
M;G,@;&$@8F_N=&4@X"!D<F]I=&6@.@!6975I;&QE>B!E;G1R97(@;&4@;F]U
M=F5A=2!N;VV@9&4@;&$@8V%TZ6=O<FEEH#H`4&]L;V=N90!0;VQI=&EQ=64`
M4V-R=71I;G,`4&]R='5G86P`4&]S:71I;VX@9&4@8V5T=&4@:6UA9V4`4&]S
M:71I;VX@9&4@8V4@=&%B;&5A=0!%;G9O>65R(.`@8V4@9&]S<VEE<B`H;F]N
M(&%P<&QI<77I('!A<B!)34%0*0!0<F]P=6QSZ2!P87(@2&]R9&4`1F%I<F4@
M<'+I8^ED97(@=F]T<F4@<VEG;F%T=7)E(&1E('1I<F5T<R`H)RTM("<IH#\`
M4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@9&5R;FGH<F5S(&AE=7)E<Z`Z
M(`!0<F]B86)I;&ETZ3QB<B`O/F1E('!L=6EE`$QE<R!P<NEFZ7)E;F-E<R!O
M;G0@8FEE;B#I=.D@;6ES97,@X"!J;W5R+@!0<F5F<U]L9&%PH#H@97AT96YS
M:6]N(')E<75I<V4@3$1!4"!N;VX@=')O=7;I92X`4')E9G-?<V5S<VEO;J`Z
M(&5X=&5N<VEO;B!R97%U:7-E(*N@<V5S<VEO;J"[(&YO;B!T<F]U=NEE+@!0
M<F5S<VEO;@!0<F5S<VEO;B!A=2!N:79E874@9&4@;&$@;65RH#H@`%!R97-S
M:6]NH#H@`%!RZ2UV:7-U86QI<V%T:6]N`$%P97+G=2!D92!L)VEM86=E(&1A
M;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`365S<V%G92!P<NECZ61E;G0`4&%G
M92!P<NECZ61E;G1E`$]P=&EO;G,@<'+I8^ED96YT97,`26UP<FEM97(`26UP
M<FEM97(@;&4@9&]C=6UE;G0`4')I;W)I=.D`0VQE9B!P<FEVZ64`36]T(&1E
M('!A<W-E(&1E(&QA(&-L968@<')I=NEE`%!R;V)LZ&UE`$1E<V-R:7!T:6]N
M(&1U('!R;V)LZ&UE`%!R;VIE=',`1&5M86YD97(@8VAA<75E(&9O:7,@<74G
M=6YE('!IZ&-E(&IO:6YT92!E<W0@96YV;WGI9:`[($Y/3B!P87(@9.EF875T
M`$1E;6%N9&5R(&-H87%U92!F;VES('%U)W5N92!P:>AC92!J;VEN=&4@97-T
M(&5N=F]YZ66@.R!/54D@<&%R(&3I9F%U=`!497AT92!C;W5R=`!0<F]T;V-O
M;&6@.@!#;&5F('!U8FQI<75E`$%L9V]R:71H;64@9&4@8VQE9B!P=6)L:7%U
M90!);F9O<FUA=&EO;G,@<W5R(&QA(&-L968@<'5B;&EQ=64`3&4@<W5P<&]R
M="!D=2!S97)V975R(&1E(&-L969S('!U8FQI8R!A(.ETZ2!DZ7-A8W1I=NDN
M`,EC:&5C(&1E(&QA(&?I;NER871I;VX@9&4@;&$@<&%I<F4@9&4@8VQE9G,@
M<'5B;&EQ=64O<')I=NEE+@!0;W)T;R!2:6-O`%!U<E]G92!E9F9E8W1UZ64`
M4'5R9V5R(&QE<R#I;.EM96YT<R!E9F9A8^ES`%9I9&5R(&QE*',I(&1O<W-I
M97(H<RD`1G+I<75E;F-E(&0G969F86-E;65N="!D=2!C;VYT96YU(&1E(&QA
M(&-O<F)E:6QL9:`Z`$5F9F%C97(@;&5S(&UE<W-A9V5S(&1E(&QA(&-O<F)E
M:6QL92!A=2!D96S@(&1E('1A;G0@9&4@:F]U<G,N`$5F9F%C97(@;&5S(&%N
M8VEE;G,@;65S<V%G97,@9&4@;&$@8V]R8F5I;&QEH#\`169F86-E;65N="!D
M92`E9"!M97-S86=E(&1E(&QA(&-O<F)E:6QL92X`169F86-E;65N="!D92`Q
M(&UE<W-A9V4@9&4@;&$@8V]R8F5I;&QE+@!1871A<@!297%UZG1E`%%U;W1A
M`,ET870@9'4@<75O=&&@.B`E+C)FH$UO("\@)2XR9J!-;R`@*"4N,F8E)2D`
MR71A="!D=2!Q=6]T8:`Z("4N,F:@36\@+V%U8W5N92!L:6UI=&4`R71A="!D
M=2!Q=6]T8:`Z(&%U8W5N92!L:6UI=&4`)68@82#I8W)I=*`Z`$-L968@<'5B
M;&EQ=64@4E-!("@E9"!B:71S*0!3Z6QE8W1I;VX@<F%D:6\`4&QU:64`4&QU
M:64@=/1T(&QE(&UA=&EN`%!L=6EE('1A<F0@9&%N<R!L82!J;W5R;NEE`$%V
M97)S97,`4&QU:64@970@;F5I9V4`4&QU:64@<'5I<R!N96EG90!!<&AO<FES
M;64@874@:&%S87)D`%1A=7@`3&ER90!-97-S86=E<R!L=7,`4W5P<')E<W-I
M;VX@9.EF:6YI=&EV92!D92`E<Z`_`%-U<'!R97-S:6]N(&3I9FEN:71I=F4@
M9&5S(&1O;F[I97,@<&]U<B!L)W5T:6QI<V%T975R("5SH#\@0V5T=&4@;W#I
M<F%T:6]N(&5S="!DZ69I;FET:79E+@!29>=U(&QE(`!29>=U(&1E<'5I<P!2
M9>=U(&1E<'5I<P!2961I<FE?9V5R`%)E9&ER:6=E<@!2961I<FEG97(@;&4@
M;65S<V%G90!2961I<FEG97(@8V4@;65S<V%G90!,82!R961I<F5C=&EO;B!A
M(.EC:&]UZ2X`4F5P<F5N9')E('9O=')E(&1E<FYIZ')E(&%C=&EO;@!2869R
M8>YC:&ER`%)A9G)A[F-H:7(@;&5S(.ELZ6UE;G1S(&1U(&UE;G4@9'EN86UI
M<75EH#H`4F%F<F'N8VAI<B!L)V%F9FEC:&%G92!D97,@9&]S<VEE<G.@.@!2
M869R8>YC:&ER(&PGZ6-R86X@9'4@<V]M;6%I<F6@.@!%>'!R97-S:6]N(')A
M=&EO;FYE;&QE`$YA=FEG871E=7(@<F5L871I;VYN96P`4F%F<F'N8VAI<@!2
M96-H87)G97(`4F5M87)Q=65S`%-E('-O=79E;FER(&1E<R!D:7-P;VYI8FEL
M:73I<RX`4V4@<V]U=F5N:7(@9'4@9&5R;FEE<B!A9F9I8VAA9V4`0F_N=&4@
M9&ES=&%N=&6@.@!397)V975R<R!D:7-T86YT<P!54DP@9&ES=&%N=&4@*&AT
M='`Z+R]W=W<N97AE;7!L92YC;VTO:&]R9&4O*:`Z`%)E=&ER97(`4F5T:7)E
M<B!L92!B;&]C`$5N;&5V97(@;&4@8VAA;7`@4F5C:&5R8VAE`%)E=&ER97(@
M;&$@8V]L;VYN90!2971I<F5R(&QE(&9O<FUA=&%G90!2971I<F5R(&QA('!A
M:7)E`$5N;&5V97(@;&4@<V-R:7!T(&5N<F5G:7-T<ND@9'4@<NEP97)T;VER
M92!T96UP;W)A:7)E(&1U('-E<G9E=7(N`%)E=&ER97(@;&$@<V]U<F-E`%)E
M=&ER97(@;&4`4F5T:7)E<B!C92!N;V5U9"!D=2!D;V-U;65N=`!2971I<F5R
M(&PG=71I;&ES871E=7(`4F5T:7)E<B!L)W5T:6QI<V%T975RH#H@)7,`4F5N
M;VUM97(@;&4H<RD@9&]S<VEE<BAS*0!296YO;6UE<B!L92!D;W-S:65R(&1E
M<R!M97-S86=E<R!E;G9O>>ES(&%U(&3I8G5T(&1U(&UO:7.@/P!,92!C:&%N
M9V5M96YT(&1E(&YO;2!D92"KH"5SH+L@96X@JZ`E<Z"[(&$@Z6-H;W7I+B!,
M92!S97)V975R(&$@<NEP;VYD=0!2Z7!?;VYD<F4@X"!L82!L:7-T90!296UP
M;&%C97(@<&%RH#H`4NEP;VYD<F4`4NEP;VYS92!E;G9O>>EE+@!2Z7!O;F1R
M92#@('1O=7,`4NEP;VYD<F4@X"!T;W5SH#H`4NEP;VYD<F4@X"!L82!L:7-T
M90!2Z7!O;F1R92#@(&QA(&QI<W1EH#H`4NEP;VYD<F4@X"!?=&]U<P!296YV
M;WEE<B!U;B!M97-S86=E(*N@3F]N('-U<'!O<G3IH+L`4NEP;VYD<F4@879E
M8R!L97,@9&ES<&]N:6)I;&ETZ7,@9&5S(#(@<')O8VAA:6YS(&UO:7,N`%+I
M<&]N9')E(&%V96,@;&5S(&1I<W!O;FEB:6QI=.ES(&1E;6%N9.EE<RX`4NEP
M;VYD<F4@X`!2Z7!O;F1R92#@H#H@`%+I<&]N9')EH#H`1.EC;&%R97(@;.EG
M:71I;64`1.EC;&%R97(@8V]M;64@<&]U<G)I96P`1&5M86YD97(@=6X@86-C
M=7/I(&1E(%]L96-T=7)E`$%U8W5N92!RZ7!O;G-E(.`@=F]T<F4@<F5Q=>IT
M92X@0V]D92!D)V5R<F5U<B!R971O=7)NZ:`Z(`!$96UA;F1E<B!D97,@86-C
M=7/I<R!D92!L96-T=7)EH#\`365S<V%G92!D96UA;F3I(&YO;B!T<F]U=NDN
M`$QE('-E<G9I8V4@9&5M86YDZ2!E<W0@:6YT<F]U=F%B;&4N`$QE('!A<F%M
MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@;B=E<W0@<&%S('-PZ6-I9FGI(&1A
M;G,@;&$@8V]N9FEG=7)A=&EO;B`E<RX`3&4@<&%R86WH=')E(&]B;&EG871O
M:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U
M<F%T:6]N(&1U(%9&4RX`3&4@<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@
MNR!N)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N+@!#
M:&%M<"!O8FQI9V%T;VER90!087)T:6-I<&%N="!I;F1I<W!E;G-A8FQE`%+`
M6@!296UI<V4@X"!ZZ7)O(&1U(&UO="!D92!P87-S90!296UE='1R92#@('KI
M<F\@=F]T<F4@;6]T(&1E('!A<W-E`$QE('-T871U="!D=2!C;W)R97-P;VYD
M86YT(&$@Z73I(&UO9&EF:>DN`%)E=F5N:7(@X"!L82!D97)N:>AR92!R97%U
MZG1E`%+I<W5L=&%T<P!297!R96YD<F4`4F5P<F5N9')E('9O=')E('-E<W-I
M;VX`4F5T;W5R('9E<G,@;&$@JZ!2Z61A8W1I;VX@9&4@;65S<V%G9:"[`%)E
M=&]U<B!V97)S(&QA('+I8W5PZ7)A=&EO;B!D=2!C;W5R<FEE<@!2971O=7(@
M875X(&]P=&EO;G,`4F5T;W5R;F5R(&%U(&-O;G1E;G4@9&4@=F]T<F4@8F_N
M=&4@9&4@<NEC97!T:6]N(&%P<NAS(&%V;VER(&5F9F%CZ2P@9.EP;&%CZ2P@
M;W4@8V]P:>D@=6X@;65S<V%G9:`_`%+I+65N=')E<B!L92!N;W5V96%U(&UO
M="!D92!P87-S90!2Z75N:6]N`%)E=F5N:7(@X"!L82!C;VYF:6=U<F%T:6]N
M('!RZ6/I9&5N=&4`3W!T:6]N<R!D92!L)^ED:71E=7(@4FEC:"!497AT`$1E
M=FEN971T97,`1')O:71E`$5N=.IT92!D92!D<F]I=&4`5F%L975R<R!C;W)R
M96-T97,`4')O<')IZ73I<R!D92!L82!R86Y?9^EE("XN+@!2]&QE`%)O=6UA
M;FEE`%!I=F]T97(@,3@P`%!I=F]T97(@X"!G875C:&4`4&EV;W1E<B#@(&1R
M;VET90!0<F]P<FGI=.ES(&1E(&QA(')A;F?I90!0<F]P<FGI=.ES(&1E(&QA
M(')A;F?I90!286YGZ65SH#H`4NAG;&5S`$1E<R!F:6QE=',@87!P87)A[G1R
M;VYT(&5N=')E('1O=71E<R!L97,@<F%N9^EE<R!E="!L97,@8V]L;VYN97,`
M1&5S(&9I;&5T<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(&-O;&]N;F5S('-E
M=6QE;65N=`!$97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!L97,@<F%N
M9^EE<R!S975L96UE;G0`3&%N8V5R`%)U<W-I90!2=V%N9&$`4R]-24U%`%-I
M9VYA='5R92#I;&5C=')O;FEQ=64@4R]-24U%`$-H:69F<F5R(&QE(&UE<W-A
M9V4@96X@4R]-24U%`$UE<W-A9V4@8VAI9F9RZ2!3+TU)344`17)R975R(%,O
M34E-1:`Z(`!%<G)E=7(@4R]-24U%H#H@;&$@<&AR87-E('-E8W+H=&4@97-T
M(&[I8V5S<V%I<F4@<&]U<B!L82!C;&5F('!R:7;I92!P97)S;VYN96QL92X`
M3W!T:6]N<R!3+TU)344`16YT<NEE(&1E(&QA('!H<F%S92!S96-RZ'1E(%,O
M34E-10!,92!S=7!P;W)T(&1E(&QA('!A:7)E(&1E(&-L969S(%,O34E-12!P
M97)S;VYN96QL97,@<F5Q=6EE<G0@=6YE(&-O;FYE>&EO;B!A=2!W96(@<^EC
M=7)I<^EE+@!,82!C;&5F('!U8FQI<75E(%,O34E-12!D92"KH"5SH+L@82!B
M:65N(.ETZ2!S=7!P<FEMZ64N`$QA(&-LZ2!P=6)L:7%U92!3+TU)344@82!B
M:65N(.ETZ2!A:F]U=.EE+@!!;FYE874@9&4@8VQE9G,@<'5B;&EQ=65S(%,O
M34E-10!,82!P86ER92!D92!C;&5F<R!3+TU)344@<'5B;&EQ=64O<')I=NEE
M(&$@8FEE;B#I=.D@86IO=73I92X`4VEG;F5R(&QE(&UE<W-A9V4@96X@4R]-
M24U%`%-I9VYE<B]C:&EF9G)E<B!L92!M97-S86=E(&5N(%,O34E-10!,92!S
M=7!P;W)T(&1E(%,O34E-12!E<W0@9.ES86-T:7;I('-U<B!C92!S>7-TZ&UE
M+@!,92!S=7!P;W)T(&1E(%,O34E-12!N)V5S="!P87,@86-T:68@86-T=65L
M;&5M96YT+"!E="!L92!M97-S86=E(&YE('!E=70@9&]N8R!P87,@ZG1R92!D
MZ6-H:69F<NDN`$QE('-U<'!O<G0@9&4@4R]-24U%(&XG97-T('!A<R!A8W1I
M=NDL(&5T(&QE(&-O;G1E;G4@9&4@8V4@;65S<V%G92!S:6=NZ2!N92!P975T
M(&1O;F,@<&%S(.IT<F4@869F:6-HZ2X`3&4@<W5P<&]R="!D92!01U`@;B=E
M<W0@<&%S(&%C=&EF(&%C='5E;&QE;65N="P@970@;&$@<VEG;F%T=7)E(&YU
M;>ER:7%U92!N92!P975T(&1O;F,@<&%S(.IT<F4@=NER:69IZ64N`$QE('-U
M<'!O<G0@4R]-24U%('5T:6QI<V4@9&5S(&9E;NIT<F5S('-U<F=I<W-A;G1E
M<RX@4VD@8V5T=&4@9F]N8W1I;VX@97-T(&3I<V%C=&EVZ64@9&%N<R!V;W1R
M92!N879I9V%T975R+"!I;"!F875T(&PG86-T:79E<BP@<V%N<R!Q=6]I(%,O
M34E-12!N92!F;VYC=&EO;FYE<F$@<&%S(&-O<G)E8W1E;65N="X`3"=A=71H
M96YT:69I8V%T:6]N(%-!4TP@;B=E<W0@<&%S(&1I<W!O;FEB;&4`365S<V%G
M97)I92!335,`4TU44`!);G1E<G!RZ71E=7(@4U%,`$]R9')E(%-13"!P;W5R
M(')E=&]U<FYE<B!L97,@=F%L975R<P!34T@`4U5#0\A3`$EN=&5R<'+I=&5U
M<B!37U%,`%-?=6IE=`!380!%;G)E7V=I<W1R97(@=6YE(&-O<&EE(&1A;G,@
M`$5N7W)E9VES=')E<B!S;W5S`%-A:6YT92U(Z6SH;F4`4V%I;G0M0VAR:7-T
M;W!H92UE="U.:>EVZ',`4V%I;G1E+4QU8VEE`%-A:6YT+5!I97)R92!E="!-
M:7%U96QO;@!386EN="U6:6YC96YT+65T+6QE<R!'<F5N861I;F5S`$WJ;64@
M8V%D<F4@*%]S96QF*0!386UO82!O8V-I9&5N=&%L97,`4V%I;G0M36%R:6X`
M4V%O+51O;>DM970M4')I;F-I<&4`1F]U<FYI<W-E=7(@<V%T96QL:71E`$%R
M86)I92!386]U9&ET90!%;G)E9VES=')E<@!%;G)E9VES=')E<B"KH"5SH+L`
M16YR96=I<W1R97(@)7,`4V%U=F5G87)D97(@;&5S('!IZ&-E<R!J;VEN=&5S
M(&%V96,@;&4@;65S<V%G92!D86YS(&QE(&1O<W-I97(@8V]U<G)I97(@96YV
M;WGIH#\`16YR96=I<W1R97(@;&4@8G)O=6EL;&]N`$5N<F5G:7-T<F5R(&PG
M:6UA9V4`16YR96=I<W1R97(@;"=I;6%G92!D86YS(&QA(&=A;&5R:64`16YR
M96=I<W1R97(@;&5S(&]P=&EO;G,`16YR96=I<W1R97(@;&$@<&%P971E<FEE
M`$5N<F5G:7-T<F5R(&QE(%]B<F]U:6QL;VX`16YR96=I<W1R97(@<V]U<P!%
M;G)E9VES=')E<B!L97,@8G)O=6EL;&]N<R!E;B!T86YT('%U92!N;VXM;'5S
MH#\`16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE(&-O;6UE
M('5N('-C<FEP="!02%`@9&%N<R!L92!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@
M9&4@=F]T<F4@<V5R=F5U<BX`16YR96=I<W1R97(@;&5S(&%D<F5S<V5S(&%U
M=&]M871I<75E;65N="!D86YS(&QE(&-A<FYE="!D)V%D<F5S<V5S('!A<B!D
MZ69A=72@/P!%;G)E9VES=')E<B!L82!R96-H97)C:&4@8V]M;64@9&]S<VEE
M<B!V:7)T=65LH#\`16YR96=I<W1R97(@;&4@8V]U<G)I97(@96YV;WGIH#\`
M16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!38W)I<'0@9&4@
M;6ES92#@(&IO=7(@9&4@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I('-O=7.@
M.B"K("5SH+L`3"=E;G)E9VES=')E;65N="!D=2!B<F]U:6QL;VX@82#I8VAO
M=>DN($QE('-E<G9E=7(@82!RZ7!O;F1UH#H@)7,@`$]R86=E<R!I<V]LZ7,`
M4V-I96YC90!296-H97)C:&4`4F5C:&5R8VAE("5S`$UO=&5U<G,@9&4@<F5C
M:&5R8VAE`$]P=&EO;G,@9&4@<F5C:&5R8VAE`%+I<W5L=&%T<R!D92!L82!R
M96-H97)C:&4`3W5V97)T`%/I;&5C=&EO;FYE<@!3Z6QE8W1I;VYN97H@=6X@
M875T<F4@8V]M<'1E`$-H;VES:7-S97H@;&5S(&9I8VAI97)S`%/I;&5C=&EO
M;FYE>B!U;F4@9&%T90!#:&]I<VES<V5Z('5N(&-H86UP`%/I;&5C=&EO;FYE
M>B!U;B!G<F]U<&4@X"!A:F]U=&5R`%/I;&5C=&EO;FYE>B!U;B!N;W5V96%U
M('!R;W!R:>ET86ER90!3Z6QE8W1I;VYN97H@=6X@<V5R=F5U<@!3Z6QE8W1I
M;VYN97H@=6YE('!A<&5T97)I9:`Z`%/I;&5C=&EO;FYE>B!U;B!U=&EL:7-A
M=&5U<B#@(&%J;W5T97(`4^EL96-T:6]N;F5Z(&QE<R!C87)N971S(&0G861R
M97-S97,@X"!U=&EL:7-E<B!P;W5R(&PG86IO=70@;W4@;&$@<F5C:&5R8VAE
M(&0G861R97-S97,N`%1O=70@<^EL96-T:6]N;F5R`%/I;&5C=&EO;FYE>B!T
M;W5T97,@;&5S(&-O;7!O<V%N=&5S(&1E(&QA(&1A=&4N`%/I;&5C=&EO;FYE
M<B!T;W5S(&QE<R!C:&%M<',@;&]R<R!D)W5N92!R96-H97)C:&4@<&]U<B!D
MZ79E;&]P<&5R('5N92!A9')E<W-E+@!3Z6QE8W1I;VYN97H@=6X@8V]M<'1E
M`$-H;VES:7-S97H@=6X@;V)J970`075C=6X`4^EL96-T:6]N;F5Z(&QE<R!C
M87)A8W3H<F5S(&1O;G0@=F]U<R!A=F5Z(&)E<V]I;B#@(&PG86ED92!D92!L
M)V]U=&EL(&-I+61E<W-O=7,N(%9O=7,@<&]U=F5Z(&5N<W5I=&4@;&5S(&-O
M<&EE<B!E="!L97,@8V]L;&5R(&1A;G,@=F]T<F4@=&5X=&4N`%/I;&5C=&EO
M;FYE>B!L92!DZ6QI;6ET975R(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97H@;&4@
M9F]R;6%T(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97H@;&$@9V%L97)I92!D86YS
M(&QA<75E;&QE('-A=79E>B!L)VEM86=E+@!3Z6QE8W1I;VYN97(@;&4@<')O
M9FEL('%U92!V;W5S(&3I<VER97H@;6]D:69I97(Z`%/I;&5C=&EO;FYE<B!L
M92!T>7!E(&1E('-E<G9E=7(@9&4@8V]U<G)I97(`4^EL96-T:6]N;F5Z(&QE
M(&3I;&EM:71E=7(@9"=H975R9:`Z`%/I;&5C=&EO;FYE>B!L92!F;W)M870@
M9&4@;"=H975R9:`Z`%/I;&5C=&EO;FYE>B!D975X(&-H86UP<R!A<'!A<F5N
M=.ES+@!3Z6QE8W1I;VYN97H@=F]T<F4@=&CH;64@9&4@8V]U;&5U<G,N`%/I
M;&5C=&EO;FYE>B!V;W1R92!L86YG=64@<'+I9NERZ66@.@!#87)N971S(&0G
M861R97-S97,@<^EL96-T:6]N;NESH#H`16YV;WEE<B!L82!C;&5F(&%U('-E
M<G9E=7(@<'5B;&EC`$5N=F]Y97(@;"=I;F9O<FUA=&EO;B!L82!P;'5S('+I
M8V5N=&4`16YV;WEE<B!L92!M97-S86=E`$5N=F]Y97(@;&4@<F%P<&]R="!D
M)V%N;VUA;&EE`$5N=F]Y97(@4TU3`$5N=F]Y97(@=6X@879I<R!D92!RZ6-E
M<'1I;VX@<R=I;"!E<W0@9&5M86YDZ2!P87(@;"=E>'#I9&ET975RH#\`4^EN
MZ6=A;`!3;VYD9:`Z(`!$;W-S:65R(&1U(&-O=7)R:65R(&5N=F]YZ0!$;W-S
M:65R(&1U(&-O=7)R:65R(&5N=F]YZ:`Z`%-E<'1E;6)R90!397)B:64@970@
M36]N=&5N96=R;P!.=6WI<F\@9&4@<^ER:64`4V5R=F5U<@!);F9O<FUA=&EO
M;B!D=2!S97)V975R(&5T(&1U(&1O<W-I97(`3&5S(&1O;F[I97,@9'4@<V5R
M=F5U<B!S;VYT(&9A=7-S97,@;W4@;F]N(&1I<W!O;FEB;&5S+@!397)V975R
MH#H`061M:6YI<W1R871I;VX@9&5S('-E<W-I;VYS`$ED+B!D92!S97-S:6]N
M(&5X<&ERZ2X`4V5S<VEO;G,`4^EL96-T:6]N;F5R`$-O;F9I9W5R97(@;&5S
M(&]P=&EO;G,@<&]U<B!V;W5S('!E<FUE='1R92!D92!R96UE='1R92#@('KI
M<F\@=F]T<F4@;6]T(&1E('!A<W-E('-I(&IA;6%I<R!V;W5S(&PG;W5B;&EE
M>BX`0VAO:7-I<B!L97,@<'+I9NER96YC97,@<&]U<B!L97,@9.EP;&%C96UE
M;G1S(&5T(&QA(&1E<W1R=6-T:6]N(&1E<R!M97-S86=E<RX`1.EF:6YI<B!L
M)V5N+73J=&4@6"U0<FEO<FET>2!L;W)S(&1E(&QA('+I9&%C=&EO;B!D97,@
M;65S<V%G97.@/P!#;VYF:6=U<F5R(&QE<R!S97)V975R<R!D:7-T86YT<R!A
M8V-E<W-I8FQE<R!D97!U:7,@=F]T<F4@<&]R=&%I;"X`4^EL96-T:6]N;F5Z
M('9O=')E(&QA;F=U92!P<NEFZ7+I92P@9G5S96%U(&AO<F%I<F4@970@;&5S
M(&]P=&EO;G,@9&4@9&%T92X`1.EF:6YI<W-E>B!L82!P<F5M:>AR92!A<'!L
M:6-A=&EO;B!L86YCZ64L(&QE('1HZ&UE(&1E(&-O=6QE=7)S+"!L92!R869R
M8>YC:&ES<V5M96YT(&1E<R!P86=E<RP@970@9"=A=71R97,@;W!T:6]N<R!D
M)V%F9FEC:&%G92X`0V]N9FEG=7)A=&EO;@!38W)I<'0@9&4@8V]N9FEG=7)A
M=&EO;B!D92!M:7-E(.`@:F]U<B!D:7-P;VYI8FQE`%!L=7-I975R<R!E;F1R
M;VET<R!P;W-S:6)L97,@879E8R!L92!P87)A;>AT<F6@.B``4V5Y8VAE;&QE
M<P!087)T86=E<B!L97,@9&]S<VEE<G,`4&%R=&%G97(@;&5S(&1O<W-I97)S
M(&1E(&-O=7)R:65R`%!A<G1A9V5R('9O<R!D;W-S:65R<R!D92!C;W5R<FEE
M<B!A=F5C(&0G875T<F5S('5T:6QI<V%T975R<RX`06-H870`4NES=6WI`$1O
M:70M;VX@9.EF:6YI<B!D97,@=&]U8VAE<R!D92!R86-C;W5R8VES('!O=7(@
M;&$@<&QU<&%R="!D97,@;&EE;G.@/P!,97,@9W)A;F1S(&)L;V-S(&1E('1E
M>'1E(&-I=.D@9&5V<F%I96YT+6EL<R#J=')E(&UO;G1RZ7,@;W4@8V%C:.ES
M('!A<B!DZ69A=72@/R!6;W5S('!O=79E>B!B87-C=6QE<B!F86-I;&5M96YT
M('9E<G,@8V5L=6D@<75E('9O=7,@9.ES:7)E>BX`5F]U;&5Z+79O=7,@<F5C
M:&5R8VAE<B!D97,@9&]N;NEE<R!01U`@9&%N<R!L92!C;W)P<R!D97,@;65S
M<V%G97,@=&5X='5E;'.@/P!&875T+6EL(&9E<FUE<B!L82!F96[J=')E(&1E
M('+I9&%C=&EO;B!A<'+H<R!L)V5N<F5G:7-T<F5M96YT(&0G=6X@8G)O=6EL
M;&]NH#\`5F]U;&5Z+79O=7,@:F]I;F1R92!V;W1R92!C;&5F('!U8FQI<75E
M(%!'4"#@('9O<R!M97-S86=E<R!P87(@9.EF875TH#\`069F:6-H97(`36]N
M=')E<B!T;W5S(&QE<R!D;W-S:65R<P!-;VYT<F5R('1O=71E<R!L97,@96XM
M=.IT97,`36]N=')E<B!L97,@;65S<V%G97,@969F86/I<P!.92!M;VYT<F5R
M('%U92!L97,@96XM=.IT97,@<')I;F-I<&%L97,`36]N=')E<B!L97,@:6YF
M;W)M871I;VYS('-U<B!L82!L:7-T92!D92!D:69F=7-I;VX`36]N=')E<B!S
M975L96UE;G0@;&5S(&1O<W-I97)S(&%U>'%U96QS('9O=7,@ZG1E<R!A8F]N
M;NES`$UO;G1R97(@=&]U<R!L97,@9&]S<VEE<G,`36]N=')E<B!U;F4@:6/T
M;F4@<&5R;65T=&%N="!D92!DZ71A8VAE<B!L97,@<&GH8V5S(&IO:6YT97,@
M9&5S(&UE<W-A9V5SH#\`36]N=')E<B!L97,@9&EF9NER96YC97,@96YT<F4@
M;&$@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I92!A8W1U96QL96UE;G0@970@
M8V5L;&4@;F]U=F5L;&5M96YT(&?I;NERZ64N`$UO;G1R97(@;"=H975R92!D
M92!L82!D97)N:>AR92!C;VYN97AI;VX@X"!L)V5N='+I9:`_`$UO;G1R97(@
M;&$@;.EG96YD92!D86YS(&QA('9U92!D92!L82!B;^YT9:`_`$UO;G1R97(@
M;"=O<'1I;VX@9&4@8V]N<V5R=F5R(&PG;W)I9VEN86P`36]N=')E<B!L92!S
MZ6QE8W1E=7(`3F4@<'+I+79I<W5A;&ES97(@<75E(&QE<R!M97-S86=E<R!N
M;VX@;W5V97)T<Z`_`$UO;G1R97(@;&5S('!RZ2UV:7-U86QI<V%T:6]N<R!D
M86YS(&QE<R!B=6QL97,@9"=A:61EH#\`069F:6-H97(@;&$@8F%R<F4@9&4@
M;65N=2!D92!T86)L96%U>*`_`$%F9FEC:&5R(&QE(&UE;G4@)7,@X"!G875C
M:&6@/P!-;VYT<F5R(&PG:6/T;F4@9&4@<NEC=7#I<F%T:6]N(&1U(&-O=7)R
M:65R(&1A;G,@;&$@8F%R<F4@9&4@;65N=:`_`$UO;G1R97(@;&5S(&EM86=E
M<P!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!T86)L96%U(&-E;&QU
M;&4`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ET
MZ7,@9'4@=&%B;&5A=0!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!D
M97,@<')O<')IZ73I<R!D92!L82!R86YGZ64@9'4@=&%B;&5A=0!!9F9I8VAE
M<B!L)VEC]&YE(&1U(&9I;'1R86=E(&1A;G,@;&$@8F%R<F4@9&4@;65N=:`_
M`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P<F]P<FGI=.ES
M(&1E(&PG:6UA9V4`069F:6-H97(@;&4@;F]M8G)E('1O=&%L(&1E(&UE<W-A
M9V5S(&1A;G,@;&4@9&]S<VEE<J`_`$%F9FEC:&5R(&PG96YV;VD@9&4@9FEC
M:&EE<@!!=F5R<V5S`$%V97)S97,@=/1T(&1A;G,@;&$@:F]U<F[I90!!=F5R
M<V5S('1A<F0@96X@:F]U<F[I90!!=F5R<V5S(&%U>"!A;&5N=&]U<G,`069F
M:6-HZ0!297-S97)R97(`4F5S<V5R<F5R(&]U(&3I9V%G97(@9"=A8F]R9"!L
M92AS*2!B;&]C*',I('9O:7-I;BAS*0!?5&%I;&QE`%-I97)R82!,96]N90!3
M)VEN<V-R:7)E`%-I9VYA='5R90!!;&=O<FET:&UE(&1E('-I9VYA='5R90!3
M:6=NZ0!3:6YG87!O=7(`5&%I;&QE`$%N;G5L97(@;&$@;6%I;G1E;F%N8V4`
M4VQO=F%Q=6EE`%-L;W;I;FEE`$YE:6=E`$%V97)S92!D92!N96EG90!!=F5R
M<V5S(&1E(&YE:6=E`$%V97)S97,@9&4@;F5I9V4@=/1T(&1A;G,@;&$@:F]U
M<F[I90!!=F5R<V5S(&1E(&YE:6=E('1A<F0@96X@:F]U<F[I90!(875T975R
M(&1E(&YE:6=EH#H@`%%U86YT:73I(&0G96%U(.EQ=6EV86QE;G1E(.`@;&$@
M<75A;G1I=.D@9&4@;F5I9V6@.B``SFQE<R!386QO;6]N`%-O;6%L:64`0VAA
M;G-O;G,@970@<&_H;65S`%1R:2!S96QO;B!L)V%R<FEVZ64`5')I('-E;&]N
M(&QA(&1A=&4`5')I('-E;&]N(&PG861R97-S92!D92!L)V5X<.ED:71E=7(`
M5')I('-E;&]N(&QA('1A:6QL92!D=2!M97-S86=E`%1R:2!S96QO;B!L92!S
M=6IE=`!4<FD@<&%R(&9I;"!D92!D:7-C=7-S:6]N`%1R:2!S96QO;B!L)V%D
M<F5S<V4@9'4@9&5S=&EN871A:7)E`%/I;&5C=&EO;B!D92!L)V]R9')E(&1E
M('1R:0!!9')E<W-E('-O=7)C90!!9G)I<75E(&1U('-U9`!3=60M975R;W#I
M96X@*$E33RTX.#4Y+3,I`$?I;W)G:64M9'4M<W5D(&5T(.YL97,@4V%N9'=I
M8V@M9'4M<W5D`$CI;6ES<&CH<F4@4W5D`$5S<&%C92!E;G1R92!C96QL=6QE
M<R!A9&IA8V5N=&5S`$5S<&%C92!E;G1R92!L92!C;VYT96YU(&5T(&QA(&)O
M<F1U<F4@9&%N<R!U;F4@8V5L;'5L90!%<W!A8V5U<@!%<W!A8V5M96YT`$5S
M<&%C96UE;G0@970@<F5M<&QI<W-A9V4`17-P86=N90!0;W5R<FEE;`!$;W-S
M:65R(&1E('!O=7)R:65L<Z`Z`$-A<F%C=.AR97,@<W#I8VEA=7@`0V%R86-T
MZ')E<R!S<.EC:6%U>`!,97,@9&]S<VEE<G,@=FER='5E;',@<W#I8VEA=7@@
M;F4@<&5U=F5N="!P87,@ZG1R92#I9&ETZ7,N`%;I<FEF:6-A=&EO;B!D92!L
M)V]R=&AO9W)A<&AE`%;I<FEF:6-A=&5U<B!D)V]R=&AO9W)A<&AE`%;I<FEF
M:6-A=&EO;B!D92!L)V]R=&AO9W)A<&AE('1E<FUI;NEE`$5R<F5U<G,@9"=O
M<G1H;V=R87!H92!P87(@Z6-R86X@;&]R<R!D92!L82!C;W)R96-T:6]N+@!3
M8VEN9&5R(&QA(&-E;&QU;&4`4V-I;F1E<B!L82!C;VQO;FYE`%-C:6YD97(@
M;&$@<F%N9^EE`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K
M`$3I8G5T`$%N;NEE(&1E(&3I8G5T`,ET870@;W4@<')O=FEN8V4`4&%P971E
M<FEE`$YO;2!D92!L82!P87!E=&5R:66@.@!4>7!E(&1E('!A<&5T97)I9:`Z
M`%!A<&5T97)I9:`Z`%-T871U=`!&;W)M870@9&4@<V%U=F5G87)D90!2=64`
M0F%R<ND`3&ES=&4@9&4@8VAA[FYE<P!2971I<F5R(&QA('!IZ&-E(&IO:6YT
M90!2971I<F5R(&QE(&1O;6%I;F4@9&4@;"=A9')E<W-E`%-U<'!R:6UE<B!L
M97,@<V%U=',@9&4@;&EG;F6@/P!3='EL92!;0U-370!$:0!3=5]J970`4V]U
M<RURZ7!E<G1O:7)E(*N@)7.@NR!N;VX@=')O=7;I`%-U:F5T`$-H86UP('-U
M:F5T`$5N=F]Y97(`3&$@9&5M86YD92!D)V%J;W5T(&1E(*N@)7.@NR!A=2!S
M>7-TZ&UE(&$@Z73I('-O=6UI<V4N(%9O=7,@;F4@<&]U<G)E>B!P87,@=F]U
M<R!C;VYN96-T97(@:G5S<74GX"!S;VX@87!P<F]B871I;VXN`%,G86)O;FYE
M<B!A=2AX*2!D;W-S:65R*',I`$EN9&EC90!2Z75S<VD`JZ`E<Z"[(&$@8FEE
M;B#I=.D@86IO=73I*&4I+@!,97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R
M(*N@)7.@NR!O;G0@8FEE;B#I=.D@<F5T:7+I97,@9'4@<WES=.AM92XN`*N@
M)7.@NR!A(&)I96X@Z73I('-U<'!R:6WI*&4I+@"KH"5SH+L@82!B:65N(.ET
MZ2!R971I<NDH92DN`%)E=&]U<B#@(&QA(&-O;F9I9W5R871I;VX@:6YI=&EA
M;&4@<NEU<W-I+B`@4F%F<F'N8VAI<B!L82!P86=E('!O=7(@=F]I<B!L97,@
M;6]D:69I8V%T:6]N<RX`16YR96=I<W1R96UE;G0@9&4@;&$@8V]N9FEG=7)A
M=&EO;B!D92!L82!S875V96=A<F1E('+I=7-S:2X`16YR96=I<W1R96UE;G0@
M<NEU<W-I(&1E(&QA(&-O<&EE(&1E('-A=79E9V%R9&4@9'4@9FEC:&EE<B!D
M92!C;VYF:6=U<F%T:6]N("5S+@"KH"5SH+L@82!B:65N(.ETZ2!M:7,H92D@
MX"!J;W5R+@#)8W)I='5R92!D92`E<R!RZ75S<VD`4V]U9&%N`%-U9V=E<W1I
M;VYS`%-O;6UA:7)E`$QE=F5R(&1U(%-O;&5I;`!#;W5C:&5R(&1U(%-O;&5I
M;`!%;G-O;&5I;&SI`$QE=F5R(&1U(%-O;&5I;`!,979E<B]#;W5C:&5R(&1U
M(%-O;&5I;`!,979E<B!D=2!3;VQE:6PZ(`!#;W5C:&5R(&1U(%-O;&5I;`!#
M;W5C:&5R(&1U(%-O;&5I;*`Z(`!%>'!O<V%N=`!!<W-I<W1A;F-E`%-U<FEN
M86T@;W4@1W5Y86YE(&AO;&QA;F1A:7-E`$YO;2!D92!F86UI;&QE`,YL97,@
M4W9A;&)A<F0@970@2F%N($UA>65N`%-W87II;&%N9`!3=>AD90!"87-C=6QE
M<B!L97,@;>ET:&]D97,@9&4@<NED86-T:6]N`$)A<V-U;&5R('9E<G,@;&$@
M<NED86-T:6]N(&5N($A434P`0F%S8W5L97(@=F5R<R!L82!RZ61A8W1I;VX@
M96X@=&5X=&4@8G)U=`!3=6ES<V4`2F]U<FYA;"!D92!S>6YC:')O;FES871I
M;VX@<W5P<')I;>D`4WEN8TU,`$5R<F5U<B!D92!S>6YT87AE(&1A;G,@;&5S
M('1E<FUE<R!D92!R96-H97)C:&4`4WER:64`3W)A9V5S`$]R86=E(&5T('9E
M;G0`3W)A9V5S`$]R86=E<R!M871I;F%U>`!&:6-H:65R(%135@!486)L96%U
M`%!R;W!R:>ETZ7,@9'4@=&%B;&5A=0!486)L96%U(&1E('9A;&5U<G,`4')O
M<')IZ73I<R!D=2!T86)L96%U`%1A[W=A;@!48>]W86XL('!R;W9I;F-E(&1E
M($-H:6YE`%1A:FEK:7-T86X`5&%N>F%N:64`0VEB;&6@.@!4XF-H97,`5&5?
M>'1E`$YU;>ER;R!D92!TZ6SI<&AO;F4`5&5M<.ER871U<F4@<&]U<B!L82!D
M97)N:>AR92!H975R9:`Z(`!496UPZ7)A='5R90!496UPZ7)A='5R9:`Z(`!4
M96UPZ7)A='5R93QB<B`O/B@E<TAA)7,O)7-"825S*2`F9&5G.R5S`%!R;V9I
M;""KH"5SH+L@;F]N('1R;W5VZ0!!9&UI;FES=')A=&EO;B!D97,@;6]DZ&QE
M<P!496YT871I=F6@.B``1&5M86YD92!A8V-E<'3I92!M86ES(.`@8V]N9FER
M;65R`$%C8V5P=.D@;6%I<R#@(&-O;F9I<FUE<@!,97,@8V]N9&ET:6]N<R!D
M)W5T:6QI<V%T:6]N(&YE('-O;G0@<&%S(&EN9&EQ=>EE<R!D86YS(&-O;F8N
M<&AP`%1E>'1E`%1E>'1E('-E=6P`06QI9VYE;65N="!D=2!T97AT90!497AT
M92!E;B!H875T`$IE`%1H8>\@*%1)4RTV,C`I`%1H8>]L86YD90!,)V5X=&5N
M<VEO;B!&5%`@;B=E<W0@<&%S(&1I<W!O;FEB;&4N`$QA(&-O;&]N;F4@JZ!$
M92`ZH+L@9&4@8V4@;65S<V%G92!D979R86ET(.IT<F4@;&GI9:`Z`$QE(&UO
M=&5U<B!D)VEN=.EG<F%T:6]N($AO<F1E+TMO;&%B(&YE('-U<'!O<G1E('!A
M<R"KH"5SH+L`3&4@<V5R=F5U<B!)34%0(&YE('-E;6)L92!P87,@<W5P<&]R
M=&5R(&QA(&WI=&AO9&4@9"=A=71H96YT:69I8V%T:6]N(&-H;VES:64N(%9E
M=6EL;&5Z(&-O;G1A8W1E<B!L)V%D;6EN:7-T<F%T975R(&1E('9O=')E('-Y
M<W3H;64N`$QE(&IO=7)N86P@24U34"!N)V$@<&%S('!U(.IT<F4@:6YI=&EA
M;&ESZ2X`3&$@<&%L971T92!D92!R97-S;W5R8V5S($UA8VEN=&]S:`!,97,@
M<F5S<V]U<F-E<R!-86-I;G1O<V@@<&5U=F5N="#J=')E('3I;.EC:&%R9^EE
M<R`E<RX`3&$@8VQA<W-E($UA:6YT96YA;F-E.CH@;B=A('!A<R#I=.D@8VAA
M<F?I92!C;W)R96-T96UE;G0`3&$@9F5NZG1R92!D97,@;W!T:6]N<R!S)V5S
M="!F97)MZ64N(%-O<G1I92X`3&4@8V]M<'1E(*N@)7.@NR!A(.ETZ2!S=7!P
M<FEMZ2X`3&4@8V]M<'1E(*N@)7.@NR!A(.ETZ2!E;G)E9VES='+I+@!,)V%D
M;6EN:7-T<F%T975R(&1O:70@8V]N9FEG=7)E<B!U;B!B86-K96YD('!E<FUA
M;F5N="!P;W5R(&QE<R!P97)M:7-S:6]N<R!S:2!V;W5S('9O=6QE>B!L97,@
M96UP;&]Y97(N`$QA('!IZ&-E(&IO:6YT92!N)V$@<&%S(.ETZ2!T<F]U=NEE
M+@!,82!B;W)D=7)E(&1U(&)A<R!S975L96UE;G0`3&5S(&1O;F[I97,@9'4@
M8V%L96YD<FEE<B!S;VYT(&EN=F%L:61E<P!,82!F96[J=')E(&1E(&-O;7!O
M<VET:6]N(&1E(&UE<W-A9V4@;F4@<&5U="#J=')E(&]U=F5R=&4N($5S="UI
M;"!P;W-S:6)L92!Q=64@=F]U<R!A>65Z(&%C=&EVZ2!L92!B;&]C86=E(&1E
M(&9E;NIT<F5S('-U<F=I<W-A;G1E<Z`_`$PG240@9'4@8V]N=&%C="!N)V$@
M<&%S(.ETZ2!S<.EC:69IZ2P@;&%I<W/I('9I9&4@;W4@;B=A('!A<R#I=.D@
M=')O=7;I(&1A;G,@;&$@8F%S92!D92!D;VYNZ65S+@!#92!C;VYT86-T(&$@
M8FEE;B#I=.D@86IO=73I(.`@=F]T<F4@8V%R;F5T(&0G861R97-S97,N(`!,
M92!C;VYT96YU(&1U(&9I8VAI97(@36%C:6YT;W-H(&5S="!C:2UD97-S;W5S
M+@!,92!D;W-S:65R(&-O=7)A;G0@JZ`E<Z"[('-E<F$@<F5N;VUMZ2!E;B"K
MH"5SH+LN`$QE8W1U<F4@:6UP;W-S:6)L92!D92!L82!L:7-T92!D97,@=71I
M;&ES871E=7)S('%U:2!O;G0@86-CZ',@X"!C92!D;W-S:65R`$QE(&)L;V,@
M9&4@<VEG;F%T=7)E(%!'4"!SZ7!A<ND@97-T(&[I8V5S<V%I<F4@<&]U<B!V
MZ7)I9FEE<B!L82!S:6=N871U<F4N`$PG240@9&4@;&$@;&ES=&4@;B=A('!A
M<R#I=.D@<W#I8VEF:>DL(&QA:7-SZ2!V:61E(&]U(&YO;B!T<F]U=ND@9&%N
M<R!L82!B87-E(&1E(&1O;F[I97,N`$QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO
M;B!N)V$@<&%S(.ETZ2!S<.EC:69IZ64N`$QE(&)R;W5I;&QO;B!A(.ETZ2!E
M;G)E9VES='+I(&1A;G,@;&4@9&]S<VEE<B"KH"5SH+LN`$QE(&-H:69F<F5M
M96YT(&[I8V5S<VET92!U;F4@8V]N;F5X:6]N('/I8W5R:7/I92X`0V5T(.EV
MZ6YE;65N="!A(&)I96X@Z73I(&%J;W5TZ2#@('9O=')E(&%G96YD82X`3&4@
M8VAA;7`@JZ`E<Z"[(&YE('!E=70@<&%S(.IT<F4@9.EV96QO<'#I+@!,92!F
M:6-H:65R("5S(&1O:70@8V]N=&5N:7(@;&5S(&]P=&EO;G,@)7,N`$QE(&9I
M8VAI97(@)7,@9&]I="!C;VYT96YI<B!C97)T86EN97,@;W!T:6]N<R`E<RX`
M3&4@9FEC:&EE<B!N92!P975T('!A<R#J=')E(&-O<&GI('-U<B!L=6DM;>IM
M92X`3&4@9FEC:&EE<B!N92!C;VYT96YA:70@875C=6YE(&1O;F[I92X`3&4@
M9&]S<VEE<B"KH"5SH+L@97AI<W1E(&3I:N``3&4@;F]M(&1U(&1O<W-I97(@
MJZ`E<Z"[(&-O;G1I96YT(&1E<R!C87)A8W3H<F5S(&EL;.EG875X+B!#96QA
M('!O=7)R86ET(.EV96YT=65L;&5M96YT(&-A=7-E<B!D97,@<')O8FSH;65S
M+B!6975I;&QE>B!C;VYT86-T97(@=F]T<F4@861M:6YI<W1R871E=7(@<WES
M=.AM92X`3&4@9&]S<VEE<B"KH"5SH+L@82#I=.D@8W+IZ2P@;6%I<R!V;W5S
M(&XG>2!A=F5Z('!A<R!S;W5S8W)I="X`3&4@9&]S<VEE<B"KH"5SH+L@82#I
M=.D@<W5P<')I;>DL(&UA:7,@=F]U<R!N)V5N(&XG879E>B!P87,@Z73I(&3I
M<V%B;VYNZ2X`($QE(&1O<W-I97(@JZ`E<Z"[(&XG82!P87,@Z73I(&-RZ>DN
M($QE('-E<G9E=7(@82!RZ7!O;F1U`$QE(&1O<W-I97(@JZ`E<Z"[(&XG82!P
M87,@Z73I('-U<'!R:6WI+B!,92!S97)V975R(&$@<NEP;VYD=0!,92!D;W-S
M:65R(*N@)7.@NR!A(&)I96X@Z73I(&-RZ>DN`$QE(&1O<W-I97(@JZ`E<Z"[
M(&$@8FEE;B#I=.D@9.ET<G5I="X`3&4@9&]S<VEE<B"KH"5SH+L@82!B:65N
M(.ETZ2!R96YO;6WI(&5N(*N@)7.@NRX`0V4@<75I('-U:70@<V]N="!L97,@
M96XM=.IT97,@<&]U<B!C92!M97-S86=E(&UE<W-A9V4O4D9#.#(R+@!,97,@
M9FEC:&EE<G,@<W5I=F%N=',@<V]N="!A='1A8VCI<R#@(&-E='1E('!A<G1I
M9:`Z`$QE(&UO9&4@<&QE:6X@Z6-R86X@8V%U<V4@9&5S('!R;V)LZ&UE<R!A
M=F5C($EN=&5R;F5T($5X<&QO<F5R(&3[(.`@9&5S(&)O9W5E<R!D=2!N879I
M9V%T975R('%U:2!N)V]N="!P=2#J=')E(&-O;G1O=7)NZ7,N(%9O=7,@<&]U
M=F5Z(.IT<F4@8V]N9G)O;G3I<R#@(&1E(&PG869F:6-H86=E(&1E(&-A<F%C
M=.AR97,@Z71R86YG97,L(&%U(&YO;BUF;VYC=&EO;FYE;65N="!D97,@8V5R
M=&%I;F5S(&9O;F-T:6]N<R!E="]O=2!A=2!P;&%N=&%G92!A;.EA=&]I<F4@
M9'4@;F%V:6=A=&5U<BX@4VD@=F]T<F4@<WES=.AM92!E<W0@=6X@5VEN9&]W
M<R`Y>"P@:6P@97-T('1RZ',@<&]S<VEB;&4@<75E('9O=7,@875R97H@=6YE
M("=&875T92!GZ6[I<F%L92!D92!P<F]T96-T:6]N)R!E="!Q=64@=F]U<R!D
M979R97H@<F5DZ6UA<G)E<B!V;W1R92!O<F1I;F%T975R+EQN7&Y6;W5S(&%V
M97H@Z73I('!RZ79E;G5S+B!35E`@87!P=7EE>B!S=7(@3TL@<VD@=F]U<R!V
M;W5L97H@=&]U:F]U<G,@97-S87EE<B!L92!M;V1E('!L96EN(.EC<F%N(&1E
M(&PGZ61I=&5U<@!,)VED96YT:73I(*N@)7.@NR`@82#I=.D@<W5P<')I;>EE
M+@!,82!F96[J=')E(&1E('-A=79E9V%R9&4@9&5S(&EM86=E<R!N92!P975T
M(.IT<F4@;W5V97)T92X@17-T+6EL('!O<W-I8FQE('%U92!V;W5S(&%Y97H@
M86-T:7;I(&QE(&)L;V-A9V4@9&5S(&9E;NIT<F5S('-U<F=I<W-A;G1E<Z`_
M`$QE<R!I;6%G97,@<V5R;VYT(&%F9FEC:.EE<R!P87)C92!Q=64@;"=E>'#I
M9&ET975R(&5S="!D86YS('9O=')E(&-A<FYE="!D)V%D<F5S<V5S+@!,92!C
M]'3I(&=A=6-H92!S975L96UE;G0`3"=E;7!L86-E;65N="!D=2!P<F]G<F%M
M;64@1VYU4$<@9&]I="#J=')E(&9O=7)N:2#@(&QA(&-L87-S92!#<GEP=%]P
M9W`Z.BX`3&4@<V5R=F5U<B!D92!C;W5R<FEE;"!A(&?I;NERZ2!C92!M97-S
M86=E(&0G97)R975RH#H`3&4@<V5R=F5U<B!D92!C;W5R<FEE;"!A(&?I;NER
MZ2!C92!M97-S86=E(&EN9F]R;6%T:6:@.@!,92!S97)V975R(&1E(&-O=7)R
M:65L(&$@9^ENZ7+I(&-E(&UE<W-A9V6@.@!,82!B;^YT92`E<R!E<W0@9.EJ
MX"!V:61E+@!,92!M97-S86=E(*LE<R"[9&4@JR5SNR`H)60@;V-T971S*2!D
MZ7!A<W-E(&QA(&QI;6ET92!P97)M:7-E+@!,92!M97-S86=E(&5N(&-O=7)S
M(&1E('+I9&%C=&EO;B!A(.ETZ2!F97)MZ2X@4V]R=&EE+@!,92!M97-S86=E
M(&$@Z73I('-U<'!R:6WI+@!,92!M97-S86=E(&$@Z73I(';I<FEF:>DN`$QE
M(&UE<W-A9V4@82#I=.D@=NER:69IZ2X@17APZ61I=&5U<J`Z("5S+@!,92!M
M97-S86=E(&5N=F]YZ2!L92`E<R#@("5S(&%V96,@8V]M;64@<W5J970@JZ`E
M<Z"[(&$@Z73I(&%F9FEC:.DN(`I);"!N)WD@82!A=6-U;F4@9V%R86YT:64@
M<75E(&-E(&UE<W-A9V4@82#I=.D@;'4@;W4@8V]M<')I<RX`3&4@;F]M(.`@
M=71I;&ES97(@96X@;&EA;G0@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N`$QE
M(&YO;6)R92!D92!C:&%M<',@9&]I="#J=')E('5N(&YO;6)R92!V86QI9&4N
M`$QE(&UO9'5L92!/<&5N4U-,(&5S="!R97%U:7,@<&]U<B!L82!C;&%S<V4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.BX`3&$@9F5NZG1R92!D=2!M;W0@9&4@<&%S
M<V4@;F4@<&5U="!P87,@<R=O=79R:7(N($5S="UI;"!P;W-S:6)L92!Q=64@
M=F]U<R!A>65Z(&%C=&EVZ2!L82!F;VYC=&EO;B!D92!B;&]C86=E(&1E<R!F
M96[J=')E<R!S=7)G:7-S86YT97.@/P!,82!P<NEFZ7)E;F-E(*N@)7.@NR!N
M)V$@<&%S('!U(.IT<F4@96YR96=I<W1RZ64@8V%R('-A('1A:6QL92!DZ7!A
M<W-E(&QE(&UA>&EM=6T@875T;W)I<^D`3&4@<')O9W)A;6UE('5T:6QI<^D@
M<&]U<B!V:7-U86QI<V5R(&-E('1Y<&4@9&4@9&]N;NEE<R`H)7,I(&XG82!P
M87,@Z73I('1R;W5VZ2X`3&4@8V%R86-TZ')E(&1E('!R;W1E8W1I;VX@9&]I
M="#J=')E('5N(&-A<F%C=.AR92!U;FEQ=64N`$QE('1E>'1E(&)R=70@9&4@
M;&$@8VQE9B!01U`@<&5U="#J=')E(&-O;G-U;'3I("5S+@!,92!F:6-H:65R
M(&1E;6%N9.D@;F4@<V4@=')O=79E('!A<R!D86YS(&QA('!IZ&-E(&IO:6YT
M92!-4RU43D5&+@!,92!F:6-H:65R(&1E;6%N9.D@;F4@<V4@=')O=79E('!A
M<R!D86YS(&QA('!IZ&-E(&IO:6YT92!C;VUP<F5S<^EE+@!,97,@8_1TZ7,@
M9V%U8VAE(&5T(&1R;VET('-E=6QE;65N=`!,92!C]'3I(&1R;VET('-E=6QE
M;65N=`!,)V5X<.ED:71E=7(@9&4@8V4@;65S<V%G92!V;W5S(&1E;6%N9&4@
M=6X@879I<R!D92!L:79R86ES;VX@*$U$3BD@;&]R<W%U92!V;W5S(&%U<F5Z
M(&QU(&-E(&UE<W-A9V4N(%-64"!C;&EQ=65Z("5S('!O=7(@96YV;WEE<B!L
M)V%V:7,@9&4@;&EV<F%I<V]N+@!,92!SZ7!A<F%T975R(&1O:70@ZG1R92!U
M;B!C87)A8W3H<F4@=6YI<75E+@!,92!S97)V975R(*N@)7.@NR!A(.ETZ2!S
M=7!P<FEMZ2X`3&4@<V5R=F5U<B"KH"5SH+L@82#I=.D@96YR96=I<W1RZ2X`
M3&4@<V5R=F5U<B!N)V$@<&%S('!U(&-RZ65R('5N92!V:6=N971T92#@('!A
M<G1I<B!D92!C971T92!I;6%G92X`3&$@<VEG;F%T=7)E(&XG82!P=2#J=')E
M(')E;7!L86/I92X`3&$@<VEG;F%T=7)E(&$@8FEE;B#I=.D@<F5M<&QA8^EE
M+@!,82!R97%UZG1E(&0G96YR96=I<W1R96UE;G0@<&]U<B`E<R!A(.ETZ2!D
MZ7!L86/I92X`3&4@9FEC:&EE<B!D96UA;F3I(&XG97AI<W1E('!A<RX`3&$@
M;&EG;F4@9&5M86YDZ64@;B=E>&ES=&4@<&%S+@!,82!P87!E=&5R:64@JZ`E
M<Z"[(&$@Z73I(&5N<F5G:7-T<NEE+@!,82!P87!E=&5R:64@JZ`E<Z"[(&$@
MZ73I('-U<'!R:6WI92X`3&$@<&%P971E<FEE(*N@)7.@NR!A(.ETZ2!M:7-E
M(.`@:F]U<BX`0V5T=&4@=.)C:&4@82!B:65N(.ETZ2!A:F]U=.EE(.`@=F]T
M<F4@;&ES=&4N`$QE(&9I8VAI97(@=&5M<&]R86ER92"K("5SH+L@;B=E>&ES
M=&4@<&%S+@!497AT92!D=2!M97-S86=E`$QE('1E>'1E(&1U(&UE<W-A9V4@
M<&5U="#J=')E(&-O;G-U;'3I("5S+@!497AT92!D=2!M97-S86=E(')E=&]U
M<F[I`$QE('1E>'1E(&1U(&UE<W-A9V4@<F5T;W5R;ND@<&5U="#J=')E(&-O
M;G-U;'3I("5S+@!,92!T97AT92!D=2!M97-S86=E(&5N=F]YZ0!,92!T97AT
M92!D=2!M97-S86=E(&5N=F]YZ2!P975T(.IT<F4@8V]N<W5L=.D@)7,N`$QE
M('1E>'1E(&5N='+I(&YE(&-O<G)E<W!O;F0@<&%S(&%U('1E>'1E('-U<B!L
M)^EC<F%N+@!,92!H875T(&5T(&QE(&)A<R!S975L96UE;G0`3&4@:&%U="!S
M975L96UE;G0`3&5S(&1O;F[I97,@=.ELZ6-H87)GZ65S('9E<G,@;&4@<V5R
M=F5U<B!O;G0@Z73I('!E<F1U97,@9&5P=6ES(&PGZ71A<&4@<'+I8^ED96YT
M92X@`$QE(&9I8VAI97(@Z6UI<R!N)V$@<&%S('!U(.IT<F4@96YR96=I<W1R
MZ2X`3&5S(&1I<W!O;FEB:6QI=.ES(&1E(&PG=71I;&ES871E=7(@;VYT(&)I
M96X@Z73I(&5N<F5G:7-T<NEE<RX`3&4@8FQO8R"KH'=E871H97(N8V]MH+L@
M;B=E<W0@<&%S(&1I<W!O;FEB;&4N`%+I<&5R=&]I<F4@9&5S('1HZ&UE<R"K
MH"5SH+L@;F]N('1R;W5VZ0!!=6-U;F4@<&%R=&EE(&%L=&5R;F%T:79E(&YE
M('!E=70@ZG1R92!A9F9I8VCI92!E;B!L:6=N92X`26P@;B=Y(&$@875C=6X@
M;65S<V%G92!D86YS(&-E='1E(&)O[G1E+@!);"!N)WD@82!P87,@9"=O<'1I
M;VYS(&1I<W!O;FEB;&5S`$%U8W5N92!P87)T:64@;F4@<&5U="#J=')E(&%F
M9FEC:.EE(&5N(&QI9VYE+@!);"!Y("!A('1R;W`@9&4@8V%R86-TZ')E<R!D
M86YS(&-E(&-H86UP+B!6;W5S(&5N(&%V97H@96YT<ND@)7.@.R!I;"!E;B!F
M875T(&UO:6YS(&1E("5S+@!!=6-U;B!T97AT92!N92!P975T(.IT<F4@869F
M:6-HZ2!E;B!L:6=N92X`56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E
M(&PG86IO=70@9&4@JZ`E<Z"[H#H@)7,`56X@<')O8FSH;64@97-T(&%P<&%R
M=2!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E<R!D;VYNZ65S(&1E(&PG=71I
M;&ES871E=7(@JZ`E<Z"[H#H@`%5N92!E<G)E=7(@97-T('-U<G9E;G5E(&5N
M('9I9&%N="!L82!B;^YT92X@3&4@<V5R=F5U<B!A('+I<&]N9'6@.B`E<P!5
M;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@
M9&4@JZ`E<Z"[H#H@`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L
M82!M:7-E(.`@:F]U<B!D92"KH"5SH+N@.B`E<P!5;B!P<F]B;.AM92!E<W0@
M87!P87)U(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65RH#H@875C=6X@)7,@
M;B=A(.ETZ2!T<F%N<VUI<RX`56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R
M<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!L92`E<R#I=&%I="!P;'5S(&=R
M;W,@<75E(&QE(&UA>&EM=6T@875T;W)I<^D@*"5D(&]C=&5T<RDN`%5N92!E
M<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65R
MH#H@;&4@)7,@82#I=.D@=')A;G-M:7,@<&%R=&EE;&QE;65N="X`26P@>2!A
M(&5U('5N92!E<G)E=7(@;&]R<R!D92!L82!C;W!I92!D97,@;65S<V%G97,@
M9&4@JZ`E<Z"[('9E<G,@JZ`E<Z"[+B!,92!S97)V975R(&$@<NEP;VYD=0!)
M;"!Y(&$@974@=6YE(&5R<F5U<B!L;W)S(&1E(&QA(&1E<W1R=6-T:6]N(&1E
M<R!M97-S86=E<R!D=2!D;W-S:65R(*N@)7.@NRX@3&4@<V5R=F5U<B!A('+I
M<&]N9'4`26P@>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D92!L82!D97-T<G5C
M=&EO;B!D97,@;65S<V%G97,@9&%N<R!L92!D;W-S:65R(*N@)7.@NRX@3&4@
M<V5R=F5U<B!A('+I<&]N9'4`56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R
M<R!D92!L82!D97-T<G5C=&EO;B!D97,@;65S<V%G97,N($QE('-E<G9E=7(@
M82!RZ7!O;F1UH#H@)7,`56YE(&5R<F5U<B!E<W0@87!P87)U92!L;W)S(&1E
M(&QA('-U<'!R97-S:6]N(&1E(&PGZ7;I;F5M96YTH#H@)7,N`%5N92!E<G)E
M=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=A9F9I8VAA9V4@9&4@8V5T=&4@
M<&%R=&EE`%5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9'4@8VAA;F=E
M;65N="!D)^ET870@9&5S(&UE<W-A9V5S(&1A;G,@;&4@9&]S<VEE<B"KH"5S
MH+LN($QE('-E<G9E=7(@82!RZ7!O;F1U`%5N92!E<G)E=7(@97-T('-U<G9E
M;G5E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D92`E<RX`56YE(&5R<F5U<B!S
M)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I
M97,@9&4@8V4@8V]N=&%C="X`56YE(&5R<F5U<B!E<W0@87!P87)U92!L;W)S
M(&1E(&PG:6UP;W)T871I;VX@9&4@;"?I=NEN96UE;G2@.B`E<RX`56YE(&5R
M<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&4@
M8V5T=&4@8V%R=&4@:4-A;&5N9&%R+@!5;F4@97)R975R(&5S="!A<'!A<G5E
M(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D92!C971T92!TXF-H9:`Z("5S+@!5
M;F4@97)R975R(&5S="!S=7)V96YU92!L;W)S(&1E(&PG:6UP;W)T871I;VX@
M9&5S(&1O;F[I97,@:4-A;&5N9&%RH#H@)7,N`$EL('D@879A:70@=6YE(&5R
M<F5U<B!D86YS(&QE(&9O<FUU;&%I<F4@9&4@8V]N9FEG=7)A=&EO;BX@4&5U
M="WJ=')E(&%V97HM=F]U<R!L86ES<^D@=6X@8VAA;7`@<F5Q=6ES('9I9&4N
M`%5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9'4@9.EP;&%C96UE;G0@
M9&5S(&UE<W-A9V5S(&1E(*N@)7.@NR!V97)S(*N@)7.@NRX@3&4@<V5R=F5U
M<B!A('+I<&]N9'4`56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E
M(&PG97CI8W5T:6]N(&1E(&-E='1E(&9O;F-T:6]N(&1U(&-A<FYE="!D)V%D
M<F5S<V4N(%-64"!E<W-A>65R(.`@;F]U=F5A=2!P;'5S('1A<F0N`%5N92!E
M<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G)E9VES=')E;65N="!D
M=2!B<F]U:6QL;VXN`%5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@
M;"=E;G9O:2!D=2!M97-S86=EH#H@)7,`26P@>2!A(&5U('5N92!E<G)E=7(@
M;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D97,@:6YF;W)M871I;VYS('-U<B!L
M92!C;VYT86-T+B`@5F5U:6QL97H@97-S87EE<B#@(&YO=79E874N`$EL('D@
M82!E=2!U;F4@97)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@9&4@;&$@
M;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`@5F5U:6QL97H@97-S87EE<B!D92!N
M;W5V96%U+@!5;F4@97)R975R(&5S="!A<'!A<G5E(&QO<G,@9&4@;&$@;6ES
M92#@(&IO=7(@9&4@;"?I=NEN96UE;G2@.B`E<RX`0V5T=&4@<&%R=&EE(&YE
M(&-O;G1E;F%I="!A=6-U;B!T97AT90!#92!M97-S86=E($A434P@8V]M<&]R
M=&4@9&5S(&EM86=E<R!I;6)R:7%UZ65S+@!#92!M97-S86=E($A434P@8V]M
M<&]R=&4@9&5S(&EM86=E<R!I;6)R:7%UZ65S+B!,97,@:6UA9V5S(&)L;W%U
MZ65S(&%P<&%R86ES<V5N="!C;VUM92!S=6ETH#H@`$QE('!RZ7-E;G0@<V5R
M=F5U<B!)34%0(&YE('-U<'!O<G1E('!A<R!L92!P87)T86=E(&1E(&1O<W-I
M97)S+@!#971T92!C;&5F(%!'4"!P=6)L:7%U92!A(.ETZ2!J;VEN=&4@874@
M;65S<V%G92X`0V5T=&4@86-T:6]N(&XG97-T('!A<R!P<FES92!E;B!C;VUP
M=&4N`$-E='1E(&%C=&EO;B!N)V5S="!P87,@96YC;W)E(&EM<&SI;65N=.EE
M+@#'82!N92!S96UB;&4@<&%S(.IT<F4@=6YE(&%R8VAI=F4@4D%2('9A;&ED
M92X`QV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&9I8VAI97(@6DE0('9A;&ED
M92X`QV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&YU;>ER;R!D92!C87)T92!V
M86QI9&4N`$-E('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R#@
M('1R879E<G,@;&$@<&%S<V5R96QL92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&5N('5T:6QI<V%N="!L)T%022!(5%10`$-E('!I;&]T
M92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R!V:6$@;&$@<&%S<V5R96QL
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@
M2%144`!#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G97,@X"!T
M<F%V97)S(&QA('!A<W-E<F5L;&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M
M86EL+F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%``0V4@<&EL;W1E('!E
M<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('!A<B!33510(.`@=')A=F5R<R!L
M82!P87-S97)E;&QE(%9O9&%F;VYE($ET86QI92P@<V5U;&5M96YT(&%U>"!N
M=6WI<F]S(%9O9&%F;VYE+B!#96QA(&[I8V5S<VET92!U;B!C;VUP=&4@9&4@
M8V]U<G)I96P@5F]D869O;F4@271A;&EE("AH='1P.B\O=W=W+C$Y,"YI="DN
M`$-E(&-H86UP(&5S="!O8FQI9V%T;VER92X`0V4@8VAA;7`@;F4@9&]I="!C
M;VYT96YI<B!Q=64@9&5S(&5N=&EE<G,N`$-E(&-H86UP(&YE(&1O:70@8V]N
M=&5N:7(@<75E(&1E<R!N;VUB<F5S(&5T(&QE<R!D975X+7!O:6YT<RX`0V4@
M8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S('9A;&5U<G,@;V-T86QE
M<RX`0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U;F4@;&ES=&4@9"=E;G1I97)S
M('/I<&%RZ7,@<&%R(&1E<R!V:7)G=6QE<R!O=2!D97,@97-P86-E<P!#92!C
M:&%M<"!D;VET(.IT<F4@=6X@;F]M8G)E('9A;&ED92X`0V4@8VAA;7`@9&]I
M="!C;VYT96YI<B!U;B!C;V1E(&1E(&-O=6QE=7(@874@9F]R;6%T(%)'0B!H
M97AA9.EC:6UA;"P@<&%R(&5X96UP;&4@)R,Q,C,T868G+@!#92!F;W)M=6QA
M:7)E(&$@9.EJX"#I=.D@=')A:73I+@!#)V5S="`E<RX`0V5C:2!E<W0@=6X@
M;V)J970@2V]L86(@1W)O=7!W87)E+B!0;W5R('9O:7(@8V5T(&]B:F5T+"!V
M;W5S(&1E=G)E>B!A=F]I<B!U;B!C;&EE;G0@9&4@8V]U<G)I96P@<75I(&-O
M;7!R96YD(&QE(&9O<FUA="!+;VQA8B!'<F]U<'=A<F4N(%!O=7(@=6YE(&QI
M<W1E(&1E(&-E<R!C;&EE;G1S(&1E(&-O=7)R:65L+"!V:7-I=&5Z("5S`$-E
M='1E(&]PZ7)A=&EO;B!P975T('!R96YD<F4@=6X@<&5U(&1E('1E;7!S+B#*
M=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER(&-O;G1I;G5E<J`_`$-E(&UE
M<W-A9V4@8V]N=&EE;G0@=6X@9FEC:&EE<B!-86-I;G1O<V@N`$-E(&UE<W-A
M9V4@8V]N=&EE;G0@=6YE('!IZ&-E(&IO:6YT92!Q=6D@82#I=.D@<VEG;NEE
M(&YU;>ER:7%U96UE;G0@=FEA(%,O34E-12X`0V4@;65S<V%G92!C;VYT:65N
M="!U;F4@<&GH8V4@:F]I;G1E('%U:2!A(.ETZ2!C:&EF9G+I('9I82!3+TU)
M344N`$-E(&UE<W-A9V4@8V]N=&EE;G0@;&5S(&EN9F]R;6%T:6]N<R#@('!R
M;W!O<R!D92!L)^ET870@9"=E;G9O:2!D=2!C;W5R<FEE;"P@;6%I<R!L92!F
M;W)M870@9&4@8V4@;65S<V%G92!E<W0@:6YC;VYN=2X`0V4@;65S<V%G92!N
M92!S96UB;&4@<&%S(.IT<F4@=6X@;65S<V%G92!C:&EF9G+I(%!'4"!V86QI
M9&4N($5R<F5U<J`Z(`!#92!M97-S86=E(&YE('-E;6)L92!P87,@ZG1R92!A
M=2!F;W)M870@4$=0(&-O<G)E8W0@*'-E;&]N(&QA(%)&0R`R,#$U*2X`0V4@
M;65S<V%G92!N92!S96UB;&4@<&%S(.IT<F4@9&%N<R!U;B!F;W)M870@4R]-
M24U%(&-O<G)E8W0N`$-E(&UE<W-A9V4@82#I=.D@<VEG;ND@;G5MZ7)I<75E
M;65N="!A=2!F;W)M870@4$=0+@!#92!M97-S86=E(&$@Z73I('-I9V[I(&YU
M;>ER:7%U96UE;G0@874@9F]R;6%T(%,O34E-12X`0V4@;65S<V%G92!A(.ET
MZ2!C:&EF9G+I(&%U(&9O<FUA="!3+TU)344N`$-E(&UE<W-A9V4@82#I=.D@
M8VAI9F9RZ2!A=F5C(%!'4"X`0V4@;65S<V%G92#@`$-E(&UE<W-A9V4@82#I
M=.D@Z6-R:70@9&%N<R!U;B!C;V1E(&1E(&-A<F%C=.AR97,@*"5S*2!A=71R
M92!Q=64@;&4@=O1T<F4N`$-E(&YO;6)R92!D;VET(.IT<F4@<W5PZ7)I975R
M(.`@=6XN`$-E('-E<G9E=7(@;F4@<&5U="!P87,@9.EC;VUP<F5S<V5R(&QE
M<R!F:6-H:65R<R!:25`@970@9WII<"X`0V4@<V5R=F5U<B!N92!S=7!P;W)T
M92!P87,@;&4@<&%R=&%G92!D97,@9&]S<VEE<G,N`$-E('-Y<W3H;64@97-T
M('!RZ7-E;G1E;65N="!DZ7-A8W1I=NDN`$-E='1E('9A;&5U<B!D;VET(.IT
M<F4@=6X@;F]M8G)E+@!#971T92!F96[J=')E(&1O:70@ZG1R92!A<'!E;.EE
M(&1E<'5I<R!L82!F96[J=')E(&1E('+I9&%C=&EO;BX`0V5T=&4@9F5NZG1R
M92!D;VET(.IT<F4@87!P96SI92!D97!U:7,@=6YE(&9E;NIT<F4@9&5S(&]P
M=&EO;G,`069F:6-H86=E(&1E<R!E;F9I;&%D97,`5G5E(&%V96,@;&5S(&5N
M9FEL861E<P!4;VYN97)R90!4:6-K971S`$AE=7)E`%-U:79I(&AO<F%I<F4`
M1F]R;6%T(&0G:&5U<F4`4^EL96-T:6]N(&1E(&PG:&5U<F4`5&EM;W(@;W)I
M96YT86P`5&ET<F4`5&ET<F4@*&EN9F]B=6QL92F@.@#``$%D<F5S<V4@9'4@
M9&5S=&EN871A:7)E`%!O=7(@<^EL96-T:6]N;F5R('!L=7-I975R<R!I=&5M
M<R#@(&QA(&9O:7,L(&UA:6YT96YE>B!E;F9O;F/I(&QE(&)O=71O;B"KH$-T
M<FR@NR`H4$,I(&]U($-O;6UA;F0@*$UA8RD@970@8VQI<75E>BX`4&]U<B!S
MZ6QE8W1I;VYN97(@<&QU<VEE=7)S(&ET96US(.`@;&$@9F]I<RP@;6%I;G1E
M;F5Z(&5N9F]N8^D@;&4@8F]U=&]N(*N@0W1R;*"[("A00RD@;W4@JZ!#;VUM
M86YD9:"[("A-86,I(&5N(&-L:7%U86YT+@!0;W5R('5T:6QI<V5R('5N92!C
M;VYN97AI;VX@5$Q3+"!V;W5S(&1E=F5Z(&%V;VER('5N92!V97)S:6]N(#4N
M,"XV(&]U('-U<.ER:65U<F4@9&4@4$A0+@!!=6IO=7)D)VAU:0!6;VER(&QA
M('-O=7)C92!(5$U,`%1O9V\`5&]K96QA=0!$96UA:6X`5&]N9V$`2&%U=`!#
M861R92!D=2!H875T("A?=&]P*0!486EL;&4@=&]T86QE(&1E<R!P:>AC97,@
M:F]I;G1E<Z`Z`%1R861U8W1I;VYS`$-O<F)E:6QL90!#;W)B96EL;&6@.@!4
M<FEN:73I+65T+51O8F%G;P!6<F%I(&]U(&9A=7@`36$`5'5N:7-I90!4=7)Q
M=6EE`%1U<F,@*$E33RTX.#4Y+3DI`%1U<FMMZ6YI<W1A;@#.;&5S(%1U<G%U
M97,@970@0V'O<75E<P!4=79A;'4`16YT<F5Z('9O=')E(&-H;VEXH#H@`$EN
M9&EC92!55J`Z(`!54DP`55),('!O=7(@=F]T<F4@<F%P<&]R="!D92!L:79R
M86ES;VX@9'4@<V-R:7!T`%523#H`3W5G86YD80!5:W)A:6YE`$EM<&]S<VEB
M;&4@9"=A='1E:6YD<F4@;&4@<NEP97)T;VER92!61E,N`$EM<&]S<VEB;&4@
M9"=A:F]U=&5R(&1E<R!I;F9O<FUA=&EO;G,@8V]M<&SI;65N=&%I<F5S(.`@
M;"=I;G-C<FEP=&EO;BX`26UP;W-S:6)L92!D92!M;V1I9FEE<B!L97,@<&5R
M;6ES<VEO;G,@<&]U<B!L92!F:6-H:65R(%9&4R"KH"5SH+LN`$EM<&]S<VEB
M;&4@9&4@;6]D:69I97(@;&5S('!E<FUI<W-I;VYS('!O=7(@;&4@9FEC:&EE
M<B!61E,@)7,O)7,N`$EM<&]S<VEB;&4@9&4@8VAA;F=E<B!P;W5R("5S+@!)
M;7!O<W-I8FQE(&1E(';I<FEF:65R(&QA('1A:6QL92!D=2!F:6-H:65R(&1E
M(*N@)7.@NRX`26UP;W-S:6)L92!D92!VZ7)I9FEE<B!L82!T86EL;&4@9'4@
M9FEC:&EE<B!D92"K("5S+R5S(+LN`$-O;FYE>&EO;B!I;7!O<W-I8FQE(&%U
M('-E<G9E=7(@4U%,+@!#;VYN97AI;VX@:6UP;W-S:6)L92!E;B!34TP`26UP
M;W-S:6)L92!D92!C;W!I97(@=6X@9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@
M9&4@8W+I97(@=6X@<NEP97)T;VER92!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE
M(&1E(&-RZ65R('5N('+I<&5R=&]I<F4@5D93+@!);7!O<W-I8FQE(&1E(&-R
MZ65R(&QE(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&1E(&-RZ65R(&QE('+I
M<&5R=&]I<F4@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D92!C<NEE<B!U;B!F
M:6-H:65R(%9&4R!V:61E+B``3W5V97)T=7)E(&EM<&]S<VEB;&4@9&4@;"=A
M<F-H:79E(&-O;7!R97-SZ64N(`!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E
M(*N@)7.@NRP@;&4@9&]S<VEE<B!N)V5S="!P87,@=FED92X`4W5P<')E<W-I
M;VX@:6UP;W-S:6)L92!D92"KH"5SH+N@.B`E<RX`4W5P<')E<W-I;VX@:6UP
M;W-S:6)L92!D92`E<RP@;&4@9&]S<VEE<B!N)V5S="!P87,@=FED90!3=7!P
M<F5S<VEO;B!RZ6-U<G-I=F4@9'4@9&]S<VEE<B!61E,@:6UP;W-S:6)L92X`
M4W5P<')E<W-I;VX@9'4@<NEP97)T;VER92!61E,@:6UP;W-S:6)L92X`26UP
M;W-S:6)L92!D92!S=7!P<FEM97(@;&4@<NEP97)T;VER92!61E.@.B`E<RX`
M4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!F:6-H:65R(%9&4R"KH"5SH+LN
M`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@9FEC:&EE<B!61E,N`%-U<'!R
M97-S:6]N(&EM<&]S<VEB;&4@9'4@<NEP97)T;VER92!61E,@JZ`E<Z"[+@!3
M=7!P<F5S<VEO;B!61E,@<NEC=7)S:79E(&EM<&]S<VEB;&6@.B`E<RX`26UP
M;W-S:6)L92!D92!DZ71E<FUI;F5R(&QE(&1O<W-I97(@8V]U<F%N="X`26UP
M;W-S:6)L92!D)V5X=')A:7)E(&QE<R!DZ71A:6QS(&1U(&-E<G1I9FEC870`
M26UP;W-S:6)L92!D92!C:&%R9V5R(&QA(&3I9FEN:71I;VX@9&4@)7,N`$EM
M<&]S<VEB;&4@9&4@9.EP;&%C97(@;&4@9FEC:&EE<B!61E,N`$EM<&]S<VEB
M;&4@9"=O=79R:7(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE
M(&0G;W5V<FER('5N(&9I8VAI97(@5D93(&5N(.EC<FET=7)E+@!);7!O<W-I
M8FQE(&0G;W5V<FER('5N(&9I8VAI97(@5D93+@!/=79E<G1U<F4@:6UP;W-S
M:6)L92!D92!L)V%R8VAI=F4@8V]M<')E<W/I92X`26UP;W-S:6)L92!D92!L
M:7)E(&QE(&9I8VAI97(@5D93("CI8VAE8R!D92!F:6QE<VEZ92@I*2X`26UP
M;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97(@5D93("CI8VAE8R!D92!G971&
M:6QE4VEZ92@I*2X`26UP;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97*@.B``
M3&5C='5R92!D=2!RZ7!E<G1O:7)E(')A8VEN92!61E,@:6UP;W-S:6)L92X`
M26UP;W-S:6)L92!D92!R96YO;6UE<B`E<R!E;B`E<Z`Z(&QE(&1O<W-I97(@
M8VEB;&4@97AI<W1E(&3I:N``26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!R
MZ7!E<G1O:7)E(%9&4RX`26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!RZ7!E
M<G1O:7)E(%9&4Z`Z("5S+@!);7!O<W-I8FQE(&1E(')E;F]M;65R(&QE(&9I
M8VAI97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!F
M:6-H:65R(%9&4R`E<R\E<RX`26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!F
M:6-H:65R(%9&4RX`4NEC=7#I<F%T:6]N(&1U('%U;W1A(&EM<&]S<VEB;&4`
M26UP;W-S:6)L92!D)V5XZ6-U=&5R("=M:VES;V9S)RX`26UP;W-S:6)L92!D
M92!T<F%D=6ER92!C92!D;V-U;65N="!7;W)D+@!);7!O<W-I8FQE(&0GZ6-R
M:7)E(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D)^EC<FER
M92!L97,@9&]N;NEE<R!D=2!F:6-H:65R(%9&4R`H8V]P>2@I(&EM<&]S<VEB
M;&4I+@!);7!O<W-I8FQE(&0GZ6-R:7)E(&QE<R!D;VYNZ65S(&1U(&9I8VAI
M97(@5D93+@!);7!O<W-I8FQE(&0GZ6-R:7)E(&QE(&9I8VAI97(@5D93+"!L
M92!Q=6]T82!S97)A:70@9.EP87-SZ2X`4V%N<R!RZ7!O;G-E`$UE<W-A9V5S
M('-A;G,@<NEP;VYS97,`4F5S=&%U<F5R`%-O=6QI9VYE<@!$97-T:6YA=&%I
M<F5S(&-A8VCI<P!!;FYU;&5R(&QE<R!C:&%N9V5M96YT<P!!;FYU;&4@=F]T
M<F4@9&5R;FGH<F4@86-T:6]N`%+I<&]N<V4@:6YA='1E;F1U92!D=2!S97)V
M975R(&QO<G,@9&4@;&$@8V]N;F5X:6]NH#H@`%+I<&]N<V4@:6YA='1E;F1U
M92!D=2!S97)V975R(."@.B``2&]R<R!C873I9V]R:64`4&%S(&1E('!R:7-E
M(&5N(&-O;7!T92!D=2!C;VUP;W-A;G0@9&4@='EP9:`Z("5S`%5N:6-O9&4@
M*%541BTX*0#);6ER871S($%R86)E<R!5;FES`%)O>6%U;64M56YI`,ET871S
M+55N:7,`SFQE<R!E>'3I<FEE=7)E<R!D97,@R71A=',M56YI<P!5;FETZ7,`
M26YC;VYN=0!$871E(&EN8V]N;G5E`%+I<&]N<V4@24U!4"!I;F-O;FYU92!D
M=2!S97)V975R+B!,92!S97)V975R(&$@<NEP;VYD=:`Z("5S`%+I=6YI;VX@
M:6YC;VYN=64`1&5S=&EN871A:7)E(&EN8V]N;G4`87!I;7-G:60@:6YC;VYN
M=2`H05!)($UE<W-A9V4@240I+@!C;&EM<V=I9"!I;F-O;FYU("A#;&EE;G0@
M365S<V%G92!)1"DN`$5M<&QA8V5M96YT('/I;&5C=&EO;F[I(&EN8V]N;G4N
M`$YO;2!D)W5T:6QI<V%T975R(&]U(&UO="!D92!P87-S92!I;F-O;FYU+@!$
MZ6QI97(@;"?I;.EM96YT(&-O=7)A;G0`169F86-E<B!L82!P:')A<V4@<V5C
M<NAT90!386YS(&YO;0!,97,@<V-R:7!T<R!N;VXM<')I=FELZ6=IZ7,@;F4@
M<&5U=F5N="!A8V/I9&5R(&%U>"!F;VYC=&EO;G,@8V]U<&5R+V-O<&EE<B]C
M;VQL97(@<&]U<B!D97,@<F%I<V]N<R!D92!SZ6-U<FETZ2X@07!P=7EE>B!S
M=7(@3TL@<&]U<B!V;VER('5N92!N;W1E('1E8VAN:7%U92!S=7(@;6]Z:6QL
M82YO<F<@<75I('9O=7,@97AP;&EQ=65R82!C;VUM96YT(&%U=&]R:7-E<B!U
M;B!S8W)I<'0@X"!U=&EL:7-E<B!L92!P<F5S<V4M<&%P:65R<P!.;VX@=G4`
M4F5M971T<F4@;&$@8V]U;&5U<B#@('KI<F\`4V4@9.ES86)O;FYE<B!D92AS
M*2!D;W-S:65R*',I`$5X=&5N<VEO;B!N;VX@<')I<V4@96X@8V]M<'1E`$UO
M9&EF:65R`$UO9&EF:65R("5S`$UO9&EF:65R(&QE('-T871U="!D=2!C;W)R
M97-P;VYD86YT`$UO9&EF:65R(&PG=71I;&ES871E=7(`36ES92#@(&IO=7(@
M9&4@JZ`E<Z"[+@!,92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@97-T('-U<'!R
M:6WI`$-H87)G97(`5&]U<R!L97,@9FEC:&EE<G,@9&4@8V]N9FEG=7)A=&EO
M;B!D97,@87!P;&EC871I;VYS(&]N="#I=.D@96YV;WGI<R!S=7(@;&4@<V5R
M=F5U<BX`3&5T=')E<R!L871I;F5S(&UA:G5S8W5L97,`3F]M8G)E<R!R;VUA
M:6YS(&UA:G5S8W5L97,`57)U9W5A>0!%;7!L;WGI(&%C='5E;&QE;65N=*`Z
M("5S`%5T:6QI<V5R(&QA('9A;&5U<B!P87(@9.EF875T`%5T:6QI<V5R(&QE
M<R!A8F]N;F5M96YT<R!A=7@@9&]S<VEE<G,@24U!4*`_`%5T:6QI<V5R(%-3
M3`!5=&EL:7-E<B!L92!D;W-S:65R('9I<G1U96P@9&4@8V]R8F5I;&QEH#\`
M571I;&ES97(@<VD@;&4@;F]M(&0G=71I;&ES871E=7(O;6]T(&1E('!A<W-E
M(&5S="!D:69FZ7)E;G0@9'4@<V5R=F5U<B!)35-0+@!5=&EL:7-A=&5U<@!,
M97,@9')O:71S('-PZ6-I9FGI<R!O;G0@8FEE;B#I=.D@871T<FEB=>ES(.`@
M;"=U=&EL:7-A=&5U<B"KH"5SH+L@<&]U<B!L92!D;W-S:65R(*N@)7.@NRX`
M3"=U=&EL:7-A=&5U<B`E<R!N)V$@<&%S(&PG875T;W)I<V%T:6]N('!O=7(@
M)7,N`$%D;6EN:7-T<F%T:6]N(&1E<R!U=&EL:7-A=&5U<G,`4'+I9NER96YC
M97,@<&5R<V]N;F5L;&5S`$5N<F5G:7-T<F5M96YT(&1E<R!U=&EL:7-A=&5U
M<G,`3"=E;G)E9VES=')E;65N="!D)W5T:6QI<V%T975R(&5S="!DZ7-A8W1I
M=ND@<W5R(&-E('-Y<W3H;64N`$-O;7!T92!U=&EL:7-A=&5U<B!N;VX@=')O
M=7;I`$YO;2!D)W5T:6QI<V%T975R`$QE(&YO;2!D92!C;VYN97AI;VX@JZ`E
M<Z"[(&5X:7-T92!DZ6K@+@!.;VT@9"=U=&EL:7-A=&5U<J`Z`$YO;2!D)W5T
M:6QI<V%T975RH#H@`%5T:6QI<V%T975R<R!DZ69I;FESH#H`3W5Z8NEK:7-T
M86X`4NEP97)T;VER92!61E,@:6YE>&ES=&%N="X`06)S96YC97,`3&5S(&5M
M<&QA8V5M96YT<R!V86QI9&5S('1R;W5VZ7,@:6YC;'5E;G2@.B``5F%L:61I
M=.D`5F%L975R(&5N(&UI;G5T97,@X"!P87)T:7(@9&4@;6%I;G1E;F%N="X`
M5F%L975R('-U<.ER:65U<F4@X"!L82!L;VYG=65U<B!M87AI;6%L92!D92`E
M<RX`5F%L975R<P!686QE=7)S(.`@<^EL96-T:6]N;F5R(&1E`%9A;G5A='4`
M5F%R:6%B;&4`5NENZ7IU96QA`,EC:&5C(&1E(&QA(';I<FEF:6-A=&EO;B`F
M;61A<V@[(&-E(&UE<W-A9V4@82!P975T+>IT<F4@Z73I(&9A;'-I9FGI+@!6
M97)S:6]N`$-O;G1R]&QE(&1E('9E<G-I;VX`06QI9VYE;65N="!V97)T:6-A
M;`!296UP;&ES<V%G92!V97)T:6-A;`!697)T:6-A;*`Z`%1RZ',@:&%U=&4`
M5FEE=&YA;0!6:>IT+6YA;6EE;B`H5DE30TE)*0!6;VER`%9O:7(@)7,`5F]I
M<B!L82!C;&5F('!U8FQI<75E("5S`%9O:7(@;&4@8V]N=&5N=2!(5$U,(&1A
M;G,@=6YE(&9E;NIT<F4@<^EP87+I90!6;VER(&QE<R!M97-S86=E<P!6;VER
M(&QA(&-L968@<')I=NEE('!E<G-O;FYE;&QE`%9O:7(@;&$@8VQE9B!P=6)L
M:7%U92!P97)S;VYN96QL90!6;VER(&QE<R!%;F9I;&%D97,`5F]I<B#I=&EQ
M=65T=&4`5F]I<B!U;F4@<&%G92!W96(@97AT97)N90!6;VER(&-O;6UE("5S
M`%9O:7(@;&$@<&GH8V4@:F]I;G1E(&1A;G,@=6YE(&9E;NIT<F4@<^EP87+I
M90!6;VER(&QE(&-O;G1E;G4@9&%N<R!U;F4@9F5NZG1R92!SZ7!A<NEE`%9O
M:7(@;&5S(.EVZ6YE;65N=',`5F]I<B!L97,@;65S<V%G97,@9&%N<R`E<P!6
M=64@;W4@8F_N=&4@X"!A9F9I8VAE<B!A<'+H<R!L82!C;VYN97AI;VZ@.@!6
M;VER(&QA('3B8VAE`%9O:7(@;&5S(&EM86=E<P#.;&5S(%9I97)G97,@8G)I
M=&%N;FEQ=65S`,YL97,@5FEE<F=E<R!D97,@R71A=',M56YI<P!,92!D;W-S
M:65R('9I<G1U96RKH"5SH+L@82#I=.D@8W+IZ2!A=F5C('-U8V/H<RX`1&]S
M<VEE<B!V:7)T=65L(&EN97AI<W1A;G0N`$1O<W-I97)S('9I<G1U96QS`%5N
M92#I=&EQ=65T=&4@97-T(&]B;&EG871O:7)E('!O=7(@;&5S(&1O<W-I97)S
M('9I<G1U96QS+@!";^YT92!D92!RZ6-E<'1I;VX@=FER='5E;&QE`$1O<W-I
M97(@9&4@<NEC97!T:6]N('9I<G1U96P`0V]R8F5I;&QE('9I<G1U96QL90!$
M;W-S:65R(&1E(&-O<F)E:6QL92!V:7)T=65L`$1O<W-I97(@9&4@8V]R8F5I
M;&QE('9I<G1U96P@:6YE>&ES=&%N="X`3F]M(&1U(&1O<W-I97(@=FER='5E
M;`!6:7-I8FEL:73I`%9I<VEB:6QI=.F@.B``5F]D869O;F4@271A;'D@=FEA
M(%--5%``3D]424-%`$%45$5.5$E/3B$A(2`@4U504%))3452($Q%(%-#4DE0
M5"!-04Y514Q,14U%3E0@1$4@)7,`5TE.('9I82!(5%10`%=A;&QI<R!E="!&
M=71U;F$`071T96YT:6]N`$UE`%!RZ79I<VEO;G,@;>ETZ6\`1&]N;NEE<R!M
MZ73I;R!F;W5R;FEE<R!P87(`5V5A=&AE<BYC;VT`5V5B`%-I=&4@=V5B`$-H
M87%U92!S96UA:6YE`$)I96YV96YU90!":65N=F5N=64@X"`E<P!":65N=F5N
M=64L("5S`$]C8VED96YT86P@*$E33RTX.#4Y+3$I`$]C8VED96YT86P@*$E3
M3RTX.#4Y+3$U*0!386AA<F$@3V-C:61E;G1A;`!1=65L;&4@87!P;&EC871I
M;VX@)7,@9&]I="UI;"!P<NES96YT97(@87!RZ',@;&$@8V]N;F5X:6]NH#\`
M475E;"!E<W0@;&4@8V%R86-TZ')E(&1E('/I<&%R871I;VZ@/P!1=65L(&5S
M="!L92!C87)A8W3H<F4@9&4@8VET871I;VZ@/P!1=64@9F%I<F4@9&5S('!O
M=7)R:65L<R!A<'+H<R!Q=2=I;',@86EE;G0@Z73I(&3I8VQA<NES('!O=7)R
M:65L(&]U(&SI9VET:6UEH#\`475A;F0@=F]U<R!DZ71R=6ES97H@9&5S(&UE
M<W-A9V5S+"!L97,@9.EP;&%C97(@9&%N<R!V;W1R92!C;W)B96EL;&4@874@
M;&EE=2!D92!L97,@;6%R<75E<B!C;VUM92!DZ71R=6ET<Z`_`%%U96QL92!P
M86=E(&1E(&3I;6%R<F%G92#@(&PG;W5V97)T=7)E(&0G=6YE(&YO=79E;&QE
M(&)O[G1EH#\`3&]R<W%U92!L)V]N(&5N<F5G:7-T<F4@;&4@8V]U<G)I97(@
M96YV;WGI+"!D;VET+6]N(&5N<F5G:7-T<F5R(&QE<R!P:>AC97,@:F]I;G1E
M<R`_`$QO<G,@9&4@;"=E;G9O:2!D=2!C;W5R<FEE<B!O=2!D92!L)V5X<&%N
M<VEO;B!D97,@861R97-S97,L('%U96P@9&]M86EN92!A:F]U=&5R(&%U>"!A
M9')E<W-E<R!N;VXM<75A;&EF:>EE<R`H861R97-S97,@<V%N<R"KH$"@NRF@
M/P!#87)T92!7:&5R96ES($%U<W1R86QI90!1=65L;&5S('!H87-E<P!1=65L
M;&5S(&5X=&5N<VEO;G,@86-T:79E<B!P;W5R(&PGZ61I=&5U<B!2:6-H(%1E
M>'0N`$QI<W1E(&)L86YC:&4`3&%R9V5U<@!,87)G975R(&5N('5N:73I<R!#
M4U,`3&%R9V5U<B!D=2!M96YU(&1E(&=A=6-H92`E<R`@*&QA(&-O;F9I9W5R
M871I;VX@<')E;F1R82!E9F9E="#@(&QA('!R;V-H86EN92!C;VYN97AI;VXI
MH#H`3&%R9V5U<B!D=2!T86)L96%U`%5N:73I(&1E(&QA<F=E=7(`3&%R9V5U
M<J`Z`%=I:VD`5F5N=`!696YT('3T="!L92!M871I;@!6:71E<W-E(&1U('9E
M;G0@96X@;B9O96QI9SMU9',`5F5N=*`Z`%9E;G2@.B``4V%G97-S90!,:7-T
M92!D92!V)F]E;&EG.W5X`%1R879A:6P`061R97-S92!P<F]F97-S:6]N;F5L
M;&4`5.ELZ7!H;VYE('!R;V9E<W-I;VYN96P`3F]M8G)E(&1E(&-H86UP<R!I
M;F-O<G)E8W0@X"!L82!L:6=N92`E9"X@)60@871T96YD=7,L("5D('1R;W5V
MZ7,N`$YO;6)R92!D92!C:&%M<',@:6YC;W)R96-T+B`E9"!A='1E;F1U<RP@
M)60@=')O=7;I<RX`1.EC86QA9V4@)60@:6YC;W)R96-T(&QO<G,@9&4@;&$@
M;&5C='5R92!D92!F:6-H:65R(%9&4RX`6"U2968`0V]N=')A:6YT97,@8F%S
M:7%U97,@6#4P.78S`%5T:6QI<V%T:6]N(&1E(&-LZ2#I=&5N9'5E(%@U,#EV
M,P!!=71R92!N;VT@9'4@<W5J970@6#4P.78S`$ED96YT:69I86YT(&1E(&-L
MZ2!D=2!S=6IE="!8-3`Y=C,`17AT96YS:6]N<R!8-3`Y=C,`04$`04%!00!#
M87)T92"KH%EA:&]OH"&@NP!!;FYU96QL96UE;G0`6>EM96X`3W5I`$]U:2P@
M:B=A8V-E<'1E`%9O=7,@86QL97H@<F%P871R:65R(&QE(&-O=7)R:65R(&1E
M<R!C;VUP=&5S('-U:79A;G1SH#H`5F]U<R!A;&QE>B!DZ71R=6ER92!T;W5S
M(&QE<R!M97-S86=E<R!D=2AD97,I(&1O<W-I97(H<RD@<W5I=F%N="AS*:`Z
M`%9O=7,@86QL97H@9.ET<G5I<F4@;&4H<RD@9&]S<VEE<BAS*2!S=6EV86YT
M*',IH#H`5F]U<R!A;&QE<B!C;W!I97(O9.EP;&%C97(@=F5R<R!U;B!N;W5V
M96%U(&1O<W-I97(N`%9O=7,@86QL97H@8W+I97(@=6X@<V]U<RUD;W-S:65R
M(&1E(`!6;W5S(&%L;&5Z(&-RZ65R('5N(&1O<W-I97(@874@;FEV96%U('-U
M<.ER:65U<BX`5F]U<R#J=&5S(&5N(&UO9&4@JZ!497AT9:"[+B!5=&EL:7-E
M>B!L92!B;W5T;VX@6SP^72!P;W5R(')E=F5N:7(@874@;6]D92"KH%=94TE7
M64>@NRX`5F]U<R!N)^IT97,@<&%S(&%U=&]R:7/I(.`@8W+I97(@9&5S(&1O
M<W-I97)S+@!6;W5S(&XGZG1E<R!P87,@875T;W)I<^D@X"!C<NEE<B!P;'5S
M(&1E("5D(&)L;V-S+@!6;W5S(&XGZG1E<R!P87,@875T;W)I<^D@X"!C<NEE
M<B!P;'5S(&1E("5D(&1O<W-I97)S+@!6;W5S(&XGZG1E<R!P87,@875T:&5N
M=&EF:>DN`%9O=7,@86QL97H@<F5N;VUM97(@;&4@9&]S<VEE<J`Z(`!6;W5S
M('!O=79E>B!U=&EL:7-E<B!L97,@8V]N=&5N975R<R!S=6EV86YT<R!D86YS
M(&QE('1E>'1E(&1E(&QA('!A<&5T97)I9:`Z("5C('!O=7(@;&4@8V]N=&5N
M=2!D=2!M97-S86=E(&-O=7)A;G2@.R`E<R!P;W5R(&QA('-I9VYA='5R92X`
M5F]U<R!N92!P;W5V97H@<&%S(&%V;VER(&QE(&-A<F%C=.AR92"K7+L@9&%N
M<R!V;W1R92!N;VT@8V]M<&QE="X`5F]U<R!N92!P;W5V97H@<&%S('9O=7,@
M9.ES86)O;FYE<B!D92"KH"5SH+LN`%9O=7,@;B?I=&EE>B!P87,@9"=A8V-O
M<F0@<W5R(&QE<R!T97)M97,@9&4@;"=A8V-O<F0@9&4@<V5R=FEC92P@=F]U
M<R!N)V%V97H@9&]N8R!P87,@;&$@<&5R;6ES<VEO;B!D92!V;W5S(&-O;FYE
M8W1E>BX`5F]U<R!N)V%V97H@<&%S('-A:7-I('5N92!A9')E<W-E(.EL96-T
M<F]N:7%U92!V86QI9&4N`%9O=7,@;B=A=F5Z('!A<R!A<W-O8VGI(&QE<R!C
M:&%M<',@9'4@9FEC:&EE<B!I;7!O<G3I(&%U>"!C:&%M<',@8V]R<F5S<&]N
M9&%N=',@9&%N<R`E<RX`5F]U<R!N)V%V97H@<&%S(&PG875T;W)I<V%T:6]N
M(&1E(&UO9&EF:65R(&PG86-CZ',@X"!C92!D;W-S:65R`%9O=7,@=')A;G-F
MZ7)E>B!C92!M97-S86=E(.`@)25S(&1A;G,@;&4@<NEP97)T;VER92`E<RX`
M5F]U<R!A=F5Z("5S(&YO=79E875X(&UE<W-A9V5S+@!6;W5S(&%V97H@,2!N
M;W5V96%U(&UE<W-A9V4N`%9O=7,@879E>B!DZ6K@(&5N=F]YZ2!C971T92!P
M86=E+@!6;W5S(&%V97H@Z73I(&3I8V]N;F5C=.DN`%9O=7,@879E>B!D=2!N
M;W5V96%U(&-O=7)R:65R(&1A;G,@;&4@9&]S<VEE<B!S=6EV86YTH#H`5F]U
M<R!A=F5Z(&1U(&YO=79E874@8V]U<G)I97(@9&%N<R!L97,@9&]S<VEE<G,@
M<W5I=F%N='.@.@!6;W5S(&1E=F5Z(&EN<V-R:7)E('5N(&YU;>ER;R!D92!C
M96QL=6QA:7)E('9A;&ED92P@<V5U;',@9&5S(&YO;6)R97,@970@=6X@JRN[
M(&]P=&EO;FYE;"!P;W5R(&QE<R!A<'!E;',@:6YT97)N871I;VYA=7@N`%9O
M=7,@;B=A=F5Z('!A<R!S86ES:2!U;F4@96YT<NEE('9A;&ED92X`5F]U<R!D
M979E>B!C;VYF:6=U<F5R('5N(&)A8VME;F0@1&%T851R964@<&]U<B!U=&EL
M:7-E<B!L97,@:6YS8W)I<'1I;VYS`%9O=7,@9&5V97H@8V]N9FEG=7)E<B!U
M;B!M;V1U;&4@5D93+@!6;W5S(&1E=F5Z(&3I8W)I<F4@;&4@<')O8FSH;64@
M879A;G0@9&4@;F]U<R!F86ER92!P87)V96YI<B!L92!R87!P;W)T+@!6;W5S
M(&1E=F5Z(&%V;VER(&%U(&UO:6YS('5N(&1E<W1I;F%T86ER92X`5F]U<R!D
M979E>B!E;G1R97(@=6YE(%523"!O^2!P;VEN=&4@9&4@;&EE;BX`5F]U<R!D
M979E>B!E;G1R97(@;&$@<&AR87-E('-E8W+H=&4@<&]U<B!V;W1R92!C;&5F
M(%!'4"!P<FEVZ64@869I;B!D92!V;VER(&-E(&UE<W-A9V4`5F]U<R!D979E
M>B!E;G1R97(@;&$@<&AR87-E('-E8W+H=&4@<&]U<B!V;W1R92!C;&5F(%,O
M34E-12!P<FEVZ64@869I;B!D92!V;VER(&-E(&UE<W-A9V4`5F]U<R!D979E
M>B!D)V%B;W)D('/I;&5C=&EO;FYE<B!U;F4@8F_N=&4N`%9O=7,@9&5V97H@
M<^EL96-T:6]N;F5R('5N(&-O;7!T92#@('-U<'!R:6UE<BX`5F]U<R!D979E
M>B!D)V%B;W)D('/I;&5C=&EO;FYE<B!U;F4@861R97-S92X`26P@9F%U="!S
MZ6QE8W1I;VYN97(@=6X@<V5R=F5U<B#@('-U<'!R:6UE<BX`5F]U<R!D979E
M>B!SZ6QE8W1I;VYN97(@874@;6]I;G,@=6X@;65S<V%G92X`5F]U<R!D979E
M>B!C:&]I<VER('5N(&1E<W1I;F%T86ER92X`5F]U<R!D979E>B!S<.EC:69I
M97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+B``5F]U<R!D979E>B!S<.EC
M:69I97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+@!6;W5S(&1E=F5Z('-P
MZ6-I9FEE<B!U;B!U=&EL:7-A=&5U<B#@(&%J;W5T97(N`%9O=7,@9&5V97H@
M<W#I8VEF:65R(&QE(&YO;2!D92!L)W5T:6QI<V%T975R(.`@;6]D:69I97(N
M`%9O=7,@9&5V97H@:6YD:7%U97(@<75E;&QE(&%C=&EO;B!A8V-O;7!L:7(N
M`%9O=7,@9&5V97H@Z6-R:7)E('5N(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A
M=.EG;W)I92X`3F]T9:`Z(*N@)7.@NR!D;VET(.IT<F4@86-T:7;I(&1A;G,@
M=F]S(&]P=&EO;G,@9&4@;6%I;G1E;F%N8V4N`%9O=7,@9&5V97H@9F]U<FYI
M<B!U;B!NL"!D92!TZ6SI<&AO;F4@:71A;&EE;@!6;W5S(&%V97H@<F5D:7)I
M9^D@8V4@;65S<V%G92!V97)S("5S(&1A;G,@)25S+@!6;W5S(&%V97H@<NEP
M;VYD=2#@(&-E(&UE<W-A9V4@;&4@)7,N`%5N92!E<G)E=7(@97-T('-U<G9E
M;G5E(&QO<G,@9&4@;&$@<V]U<V-R:7!T:6]N(.`@JZ`E<Z"[+B!,92!S97)V
M975R(&$@<NEP;VYD=0!6;W5S(&XG879E>B!P87,@Z73I(&3I<V%B;VYNZ2!D
M92"KH"5SH+LN($QE('-E<G9E=7(@82!RZ7!O;F1U`%9O=7,@879E>B!B:65N
M(.ETZ2!A8F]N;ND@X""KH"5SH+L`5F]U<R!A=F5Z(&)I96X@Z73I(&3I<V%B
M;VYNZ2!D92"KH"5SH+L`5F]T<F4@<V5S<VEO;B`E<R!A(&5X<&ERZ2X@5F5U
M:6QL97H@=F]U<R!R96-O;FYE8W1E<BX`5F]T<F4@861R97-S92!D92!C;W5R
M<FEE;`!6;W1R92!A9')E<W-E(&1E(&-O=7)R:65L(*L@1&4Z(+N@.@!6;W,@
M9&]N;NEE<R!P97)S;VYN96QL97,`5F]T<F4@861R97-S92!);G1E<FYE="!A
M(&-H86YGZ2!D97!U:7,@;"=O=79E<G1U<F4@9&4@=F]T<F4@<V5S<VEO;B`E
M<RX@(%!O=7(@=F]T<F4@<^EC=7)I=.DL('9O=7,@9&5V97H@=F]U<R!R96-O
M;FYE8W1E<BX`5F]T<F4@;F]M`%9O<R!C;&5F<R!01U`@<'5B;&EQ=64O<')I
M=NEE`%9O=')E(&-L968@<')I=NEE`%9O=')E(&-L968@<'5B;&EQ=64`5F]T
M<F4@861R97-S92!D92!RZ7!O;G-EH#H@/&5M/BAO<'1I;VYN96QL92D\+V5M
M/@!6;W,@8V5R=&EF:6-A=',@4R]-24U%('!U8FQI8R]P<FEVZ0!6;W,@8V]M
M<'1E<Z`Z`%9O<R!A9')E<W-E<R!A;'1E<FYA=&EV97.@.B`\96T^*&]P=&EO
M;FYE;"P@96YT<F5Z(&-H87%U92!A9')E<W-E('-U<B!U;F4@;F]U=F5L;&4@
M;&EG;F4I/"]E;3XN(`!6;W1R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N
M(&YE('-U<'!O<G1E('!A<R!L)V%J;W5T(&0G=71I;&ES871E=7)S+"!3:2!V
M;W5S('-O=6AA:71E>B!U=&EL:7-E>B!(;W)D92!P;W5R(&%D;6EN:7-T<F5R
M(&QE<R!C;VUP=&5S('5T:6QI<V%T975R<RP@=F]U<R!D979E>B!U=&EL:7-E
M<B!U;B!A=71R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N+@!6;W1R92!M
M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N(&XG97-T('!A<R!E;B!M97-U<F4@
M9"?I=&%B;&ER('5N92!L:7-T92!D97,@=71I;&ES871E=7)S+"!O=2!C971T
M92!F;VYC=&EO;B!A(.ETZ2!R971I<NEE('!O=7(@=6YE(&%U=')E(')A:7-O
M;BX`5F]T<F4@;F%V:6=A=&5U<B!S96UB;&4@879O:7(@8VAA;F?I(&1E<'5I
M<R!L92!DZ6)U="!D92!V;W1R92!S97-S:6]N("5S+B`@4&]U<B!V;W1R92!S
MZ6-U<FETZ2P@=F]U<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+@!6;W1R92!N
M879I9V%T975R(&YE('-U<'!O<G1E('!A<R!L)V%F9FEC:&%G92!E;B!L:6=N
M92!D97,@:6UA9V5S(&1E(&-E('1Y<&4N`%9O=')E(&YA=FEG871E=7(@;F4@
M<W5P<&]R=&4@<&%S(&-E='1E(&]P=&EO;@!6;W1R92!N879I9V%T975R(&YE
M('!R96YD('!A<R!E;B!C;VUP=&4@8V5T=&4@;W!T:6]N(&0G:6UP<F5S<VEO
M;BX@4')E<W-E>B!#;VYT<O1L92]#;VUM86YD92`K(%`@<&]U<B!I;7!R:6UE
M<@!6;W1R92!F=7-E874@:&]R86ER92!A8W1U96R@.@!6;W1R92!E;F-O9&%G
M92!P87(@9.EF875T('!O=7(@;"=E;G9O:2!D97,@;65S<V%G97.@.@!6;W1R
M92!MZ71H;V1E(&1E(&-H:69F<F5M96YT('!A<B!DZ69A=70@<&]U<B!L)V5N
M=F]I(&1E<R!M97-S86=E<Z`Z`%9O=')E('!R;V9I;"!P87(@9.EF875T(&$@
MZ73I(&UO9&EF:>DN`%!R;V9I;"!P87(@9.EF875TH#H`5F]T<F4@;F]M(&-O
M;7!L972@.@!6;W1R92!P:>AC92!J;VEN=&4@;&GI92!A(.ETZ2!TZ6SI8VAA
M<F?I92!P87(@874@;6]I;G,@=6YE('!E<G-O;FYE+@H*3F]M(&1E(&QA('!I
MZ&-E(&IO:6YT9:`Z("5S"D1A=&4@9&4@;&$@<&GH8V4@:F]I;G1EH#H@)7,*
M"D-L:7%U97H@<W5R(&QE(&QI96X@<W5I=F%N="!P;W5R('-U<'!R:6UE<B!D
MZ69I;FET:79E;65N="!C971T92!P:>AC92!J;VEN=&6@.@HE<P!6;W1R92!C
M;VUP=&4@82!E>'!I<NDN`%9O=')E(&UE<W-A9V4@82!B:65N(.ETZ2!D:7-T
M<FEB=>DN`%9O=')E(&YO=79E874@;6]T(&1E('!A<W-E('!O=7(@)7,@97-T
MH#HE<P!6;W,@;W!T:6]N<R!O;G0@Z73I(&UI<V5S(.`@:F]U<B!P;W5R(&QA
M(&1U<NEE(&1E(&-E='1E('-E<W-I;VXN`%9O<R!O<'1I;VYS(&]N="#I=.D@
M;6ES97,@X"!J;W5R+@!6;W1R92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@
MX"!ZZ7)O`%9O=')E(&UO="!D92!P87-S92!A(.ETZ2!R96UI<R#@('KI<F\L
M(';I<FEF:65R('9O=')E(&-O=7)R:65R(&5T(&-O;FYE8W1E>BUV;W5S(&%V
M97H@=F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4N`%9O=')E(&UO="!D92!P
M87-S92!A(&5X<&ERZ2X`5F]S('-E<G9E=7)S(&1I<W1A;G1SH#H`5F]T<F4@
M<VEG;F%T=7)EH#H`66]U9V]S;&%V:64`6F'O<F4`6F%M8FEE`%II;6)A8G=E
M`%II<'!Y`%M#86-H97(@;&5S(&%D<F5S<V5S70!;0V%C:&5R(&QE<R!C:71A
M=&EO;G-=`%M087,@9&4@<W5J971=`%M287!P;W)T(&1E('!R;V)LZ&UE70!;
M36]N=')E<B!L97,@861R97-S97,@+0!;069F:6-H97(@;&4@=&5X=&4@8VET
MZ2`M`%M!9F9I8VAE<B!L92!T97AT92!C:73I("T@)7,@;&EG;F5S70!;36]N
M=')E<B!L97,@861R97-S97,@+2`E<R!D97-T:6YA=&%I<F5S70!;;&EG;F4@
M)7,@9&4@)7-=`%]!9&UI;FES=')A=&EO;@!#8U]I`$QI<W1E(%]N;VER90!,
M:6=N92!D92!?8V]M;6%N9&4`7T-C`%]$871A5')E90!?4W5P<')I;65R`%-U
M<'!R:6UE<B!L82!?<F%N9^EE`$1?;W-S:65R<P!?1W)O=7!E<P!?06ED90!)
M9&5?;G1I=.D`4')O<')?:>ETZ7,@9&4@;"=I;6%G92XN+@!";^YT92!D92!R
MZ6-E<'1?:6]N`%]#;VYN97AI;VX`1.EC;VYN95]X:6]N`%-O=7)C92!D=2!?
M;65S<V%G90!?36]D:69I97(@=6X@;&EE;B!W96(N+BX`7TYO=79E874@;65S
M<V%G90!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`26U?<')I;65R`%]0<FEO<FET
MZ0!?4F%F<F'N8VAI<B`E<P!?4F5T:7)E<B!U;B!L:65N`%]2Z7!O;F1R90!2
M96-?:&5R8VAE`$5N=F]?>65R(&QE(&UE<W-A9V4`7T-O;F9I9W5R871I;VX`
M4')O<')IZ73I<R!D=2!?=&%B;&5A=0!%;F9I7VQA9&4`7T$`4F5S=&%?=7)E
M<@!?571I;&ES871E=7)S`%]6;VER(&QE<R!%;F9I;&%D97,`3&E?<W1E(&)L
M86YC:&4`8V%R;F5T(&0G861R97-S97,`9&5S=&EN871A:7)E(&EN8V]N;G4`
M<&GH8V4@:F]I;G1E`'!IZ&-E(&IO:6YT92YZ:7``;V-T971S`&%G96YD80!C
M86QM90!I;7!O<W-I8FQE(&1E(&-RZ65R(&QE(&9I8VAI97(@9&4@<V]R=&EE
M`&EM<&]S<VEB;&4@9"=O=79R:7(@;"=E;G1RZ64`8VQI<75E>B!I8VD`97)R
M975R(&0G=71I;&ES871I;VX@9&4@;&$@;&EG;F4@9&4@8V]M;6%N9&4`97)R
M975R(&1E(&-O;F9I9W5R871I;VX`86)S96YC92!C<FET:7%U92!D)W5N(&9I
M8VAI97(@<WES=.AM90!E<G)E=7(@9&4@9F]R;6%T(&1E(&1O;F[I90!E;G1R
MZ64@;F]N('1R;W5VZ0!T;VUB86YT`&9I8VAI97(`9&4`9&5P=6ES(&QE("5S
M("@E<RD@X"`E<R`E<P!E;B!R869A;&4`:*`Z`&AH`&YO;2!D)VCT=&4@:6YC
M;VYN=0!I;6WI9&EA=&5M96YT`&EN8V]R<&]RZ64`97)R975R(&0G96YT<NEE
M+W-O<G1I90!E<G)E=7(@;&]G:6-I96QL92!I;G1E<FYE`&-L968`;&EG;F5S
M70!F:6-H:65R(&1E(&)O[G1E(&1E(&-O=7)R:65R`&5R<F5U<B!M:VES;V9S
M(&-O9&4@)60@96X@8W+I86YT(&PG25-/`&UM`&YO;0!A=6-U;@!N;VX@<')I
M<R!E;B!C;VUP=&4`<&%S(&5N8V]R92!P<FES(&5N(&-O;7!T90!B;&]C+6YO
M=&5S`&]U`'!O=7)C96YT86=E`'!E<FUI<W-I;VX@<F5F=7/I90!P:7AE;',`
M9&5S=&EN871A:7)E<UT`97)R975R(&1I<W1A;G1E(&1A;G,@;&4@<')O=&]C
M;VQE`',GZ6QE=F%N=`!S97)V:6-E(&YO;B!D:7-P;VYI8FQE`&UO;G1R97(@
M;&5S(&1I9F;I<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!E<G)E=7(@9"=O
M<G1H;V=R87!H90!E<G)E=7)S(&0G;W)T:&]G<F%P:&4`<W,`9FEX90!E<G)E
M=7(@<WES=.AM90!L:7-T92!D92!TXF-H97,`Z6-H96,@=&5M<&]R86ER90!E
M;G1R97H@;&4@;6]T(&1E('!A<W-E(&1E=7@@9F]I<R!P;W5R(&-O;F9I<FUE
M<@!U;FEF:>D`<V%N<R!N;VT`4^EL96-T:6]N(&0G=71I;&ES871E=7(`=D-A
M<F0`;*`Z`'=E871H97(N8V]M`'9O=')E(&QI<W1E(&YO:7)E`'9O=')E(&QI
M<W1E(&)L86YC:&4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O;&]C86QE+V9R7T92+VAE;'`N>&UL````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,3(W-C$Q`#$P-#$W,S8R-S8S`#`R,3$R-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/WAM
M;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA+2T@
M)$AO<F1E.B!I;7`O;&]C86QE+V9R7T92+VAE;'`N>&UL+'8@,2XQ-RXV+C0@
M,C`P-B\P,2\S,"`Q-3HU.#HP,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE
M;G1R>2!I9#TB8V]M<&]S92UB=71T;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@
M("`\=&ET;&4^4NED86-T:6]N(&1E(&UE<W-A9V4Z($%C=&EO;G,\+W1I=&QE
M/@H@("`@/&AE861I;F<^06-T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A/@I,
M92!B;W5T;VX@)T5N=F]Y97(@;65S<V%G92<@9F5R82!P87)V96YI<B!V;W1R
M92!M97-S86=E(&%U*'@I(&1E<W1I;F%T86ER92AS*2!D92!C92!D97)N:65R
M+B!!<W-U<F5Z+79O=7,@9&4@8FEE;B!VZ7)I9FEE<B!L92!C;VYT96YU+"!A
M:6YS:2!Q=64@;&5S('+I8VEP:65N9&%I<F5S(&1E('9O=')E(&UE<W-A9V4@
M879A;G0@9&4@8VQI<75E<B!S=7(@8V4@8F]U=&]N+"!P=6ES<74G=6YE(&9O
M:7,@;&4@;65S<V%G92!E;G9O>>DL('9O=7,@;F4@<&]U=F5Z('!A<R!C86YC
M96QL97(@;"=O<.ER871I;VXN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*3&4@
M8F]U=&]N("=3875V96=A<F1E<B!B<F]U:6QL;VXG('!E<FUE="!D92!P;&%C
M97(@=6X@;65S<V%G92!N;VXM=&5R;6ENZ2!E;B!A='1E;G1E(&1A;G,@=6X@
M9&]S<VEE<B!B<F]U:6QL;VX@*$]P=&EO;G,@+29G=#L@4NED86-T:6]N(&1E
M(&UE<W-A9V4I+"!A8V-E<W-I8FQE(&1I<F5C=&5M96YT('9I82!L)V]P=&EO
M;B`G1&]S<VEE<G,G(&1U(&UE;G4@<')I;F-I<&%L+B!6;W5S('!O=79E>B!T
M97)M:6YE<B!C97,@;65S<V%G97,@96X@=&]U="!T96UP<R!A(&%C8^ED86YT
M(.`@8V4@9&]S<VEE<BX@07-S=7)E>BUV;W5S(&1E('-PZ6-I9FEE<B!U;B!S
M=6IE="#@('9O<R!M97-S86=E<R!B<F]U:6QL;VYS('!O=7(@<&]U=F]I<B!L
M97,@:61E;G1I9FEE<B!P;'5S(&9A8VEL96UE;G0@<&%R(&QA('-U:71E+B!!
M<'+H<R!A=F]I<B!S875V97)G87)D97(@=6X@;65S<V%G92!C;VUM92!B<F]U
M:6QL;VXL('9O=7,@ZG1E<R!A=71O;6%T:7%U96UE;G0@<F5D:7)I9^D@=F5R
M<R!L92!D97)N:65R(&1O<W-I97(@;W5V97)T+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"DQE(&)O=71O;B`G06YN=6QE<B!M97-S86=E)R!A8F%N9&]N;F4@
M;&$@<NED86-T:6]N(&1E('9O=')E(&UE<W-A9V4L(&5T('9O=7,@<F5D:7)I
M9V4@=F5R<R!L92!D97)N:65R(&1O<W-I97(@;W5V97)T+@H@("`@/"]P87)A
M/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UB=71T
M;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!8W1I;VYS
M/"]T:71L93X*("`@(#QH96%D:6YG/D%C=&EO;G,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%-E;F0@365S<V%G92!L875N8VAE<R!Y;W5R(&5M86EL('1O
M('1H92!I;G1E;F1E9"!R96-I<&EE;G0H<RDN($)E('-U<F4@>6]U('=A;G0@
M=&\@<V5N9"!B969O<F4@8VQI8VMI;F<@:&5R92!A<R!O;F-E('-E;G0@:70@
M8V%N;F]T(&)E('1A:V5N(&)A8VLN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@(%-A=F4@1')A9G0@<&QA8V5S(&%N('5N9FEN:7-H960@;65S<V%G92!I
M;B!A(&9O;&1E<B!C86QL960@)T1R869T<R<*86-C97-S:6)L92!B>2!T:&4@
M<&]P+61O=VX@8F]X(&]N('1H92!R:6=H="!S:61E(&]F('1H92!B;'5E(&YA
M=FEG871I;VX@8F%R(&%T('1O<"X@66]U(&-A;B!T:&5N(&9I;FES:"!T:&4@
M;65S<V%G92!L871E<B!B>2!S=VET8VAI;F<@=&\@=&AE("=$<F%F=',G(&9O
M;&1E<BP@8VQI8VMI;F<@;VX@=&AE('-A=F5D(&UE<W-A9V4@=&\@;W!E;B!I
M="P@86YD('1H96X@8VQI8VMI;F<@;VX@)U)E<W5M92<N($)E('-U<F4@=&\@
M<'5T(&$@<W5B:F5C="!O;B!T:&4@96UA:6P@8F5F;W)E('EO=2!S879E('1H
M92!D<F%F="!S;R!T:&%T('EO=2!C86X@96%S:6QY(&ED96YT:69Y('=H:6-H
M(&UE<W-A9V4@>6]U('=A;G0@=VET:&EN('1H92!$<F%F=',@9F]L9&5R+B!!
M9G1E<B!S879I;F<@87,@82!$<F%F="P@>6]U(&%R92!R971U<FYE9"!T;R!Y
M;W5R($E.0D]8(&]R('=H871E=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG
M(&QA<W0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-A;F-E;"!-97-S
M86=E(&1R;W!S('1H92!M97-S86=E(&EN('!R;V=R97-S(&%N9"!S:6UP;'D@
M<F5T=7)N<R!Y;W4@=&\@=&AE($E.0D]8(&]R('=H871E=F5R(&9O;&1E<B!Y
M;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^
M/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M9G)O;2(@<W1A=&4](G5N
M:VYO=VXB/@H@("`@/'1I=&QE/E+I9&%C=&EO;B!D92!M97-S86=E.B!$93PO
M=&ET;&4^"B`@("`\:&5A9&EN9SXB1&4B/"]H96%D:6YG/@H@("`@/'!A<F$^
M"DEN<^ER97H@:6-I('9O=')E(&%D<F5S<V4@8V]U<G)I96P@97AA8W0N(%!A
M<B!DZ69A=70L('9O=')E(&%D<F5S<V4@97-T(&?I;NERZ64@875T;VUA=&EQ
M=65M96YT('!A<B!L92!P<F]G<F%M;64L(&UA:7,@=F]U<R!P;W5V97H@<W#I
M8VEF:65R(&%U=')E;65N="X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N
M=')Y.@H\96YT<GD@:60](F-O;7!O<V4M9G)O;2(^"B`@("`\=&ET;&4^365S
M<V%G92!#;VUP;W-I=&EO;CH@1G)O;3PO=&ET;&4^"B`@("`\:&5A9&EN9SXF
M<75O=#M&<F]M)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E
M<B!Y;W5R(&-O<G)E8W0@96UA:6P@861D<F5S<RX@66]U<B!E;6%I;"!A9&1R
M97-S(&ES(&%U=&]M871I8V%L;'D@96YT97)E9"!F;W(@>6]U(&9O;&QO=VEN
M9R`F<75O=#M&<F]M.B9Q=6]T.R!I;B!O=71G;VEN9R!E;6%I;"X*("`@(#PO
M<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UT;R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E+I9&%C=&EO;B!D
M92!M97-S86=E.B!!/"]T:71L93X*("`@(#QH96%D:6YG/B)!(CPO:&5A9&EN
M9SX*("`@(#QP87)A/@I%;G1R97H@;&5S(&%D<F5S<V5S(&-O=7)R:65L<R!D
M92!C975X(&5T(&-E;&QE<R!Q=6D@9&]I=F5N="!R96-E=F]I<B!V;W1R92!M
M97-S86=E+B!6;W5S(&1E=F5Z('/I<&%R97(@8VAA<75E(&%D<F5S<V4@<&%R
M('5N92!V:7)G=6QE+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ
M"CQE;G1R>2!I9#TB8V]M<&]S92UT;R(^"B`@("`\=&ET;&4^365S<V%G92!#
M;VUP;W-I=&EO;CH@5&\\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[5&\F
M<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R
M96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@>6]U
M<B!M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET
M:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A
M;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.U1O.B9Q=6]T.R!I
M;B!O=71G;VEN9R!M86EL+B`@"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E
M;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M8V,B('-T871E/2)U;FMN;W=N
M(CX*("`@(#QT:71L93Y2Z61A8W1I;VX@9&4@;65S<V%G93H@0V,\+W1I=&QE
M/@H@("`@/&AE861I;F<^(D-C(CPO:&5A9&EN9SX*("`@(#QP87)A/@I%;G1R
M97H@:6-I(&QE(&]U(&QE<R!A9')E<W-E*',I(&1E(&-E=7@@<75I(&1O:79E
M;G0@<F5C979O:7(@=6YE(&-O<&EE(&-O;F9O<FUE(&1E('9O=')E(&UE<W-A
M9V4N($%S<W5R97HM=F]U<R!D92!SZ7!A<F5R(&-H87%U92!A9')E<W-E<R!P
M87(@=6YE('9I<F=U;&4N($QE<R!C;W!I97,@8V]N9F]R;65S('-O;G0@9^EN
MZ7)A;&QE;65N="!E;G9O>>EE<R#@(&1E<R!G96YS(&%U=')E<R!Q=64@8V5U
M>"!D:7)E8W1E;65N="!I;G-C<FET(&1A;G,@;&4@8VAA;7!S("=!)RP@;6%I
M<R!Q=6D@<V]N="!P975T+>IT<F4@:6YD:7)E8W1E;65N="!C;VYC97)NZ7,@
M<&%R(&QA('-U:F5T(&1E('9O=')E(&UE<W-A9V4N(%1O=70@;&5S(&=E;G,@
M<75I(')E8V5V<F]N="!V;W1R92!M97-S86=E+"!Q=2=I;',@<V]I96YT(&EN
M<V-R:70@9&%N<R!L92!C:&%M<"`G03HG(&]U("=#8SHG+"!P975V96YT(&-O
M;G-U;'1E<B!L82!L:7-T92!E;G1IZ')E(&1A;G,@9&5U>"!T>7!E<R!D92!R
MZ6-I<&EE;F1A:7)E<RX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y
M.@H\96YT<GD@:60](F-O;7!O<V4M8V,B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($-C/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T-C
M)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R
M<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@
M8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E+B!397!A<F%T92!E86-H(&%D
M9')E<W,@=VET:"!A(&-O;6UA+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[
M0V,Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN($-A<F)O;B!C;W!I97,@87)E
M('5S=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!T:&4@;VYE*',I
M(&)E:6YG('=R:71T96X@=&\@9&ER96-T;'D@8G5T(&%R92!I;7!O<G1A;G0@
M<F5C:7!I96YT<R!O9B!T:&4@96UA:6P@87,@=V5L;"P@=7-U86QL>2!S;VUE
M;VYE(&EN9&ER96-T;'D@8V]N8V5R;F5D(&%B;W5T('1H92!S=6)J96-T(&]F
M('1H92!E;6%I;"X@($%L;"`G5&\Z)R!R96-I<&EE;G1S(&%N9"`G0V,Z)R!R
M96-I<&EE;G1S(&-A;B!S964@=&AE(&5N=&ER92!L:7-T(&]F(&)O=&@@:VEN
M9',@;V8@<F5C:7!I96YT<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UB8V,B('-T871E/2)U;FMN;W=N
M(CX*("`@(#QT:71L93Y2Z61A8W1I;VX@9&4@;65S<V%G93H@0F-C/"]T:71L
M93X*("`@(#QH96%D:6YG/B)"8V,B/"]H96%D:6YG/@H@("`@/'!A<F$^"D5N
M=')E>B!I8VD@;&4@;W4@;&5S(&%D<F5S<V4H<RD@9&4@8V5U>"!Q=6D@9&]I
M=F5N="!R96-E=F]I<B!U;F4@8V]P:64@8V]N9F]R;64@:6YV:7-I8FQE+B`@
M07-S=7)E>BUV;W5S(&1E('/I<&%R97(@8VAA<75E(&%D<@IE<W-E<R!P87(@
M=6YE('9I<F=U;&4N($QE<R!C;W!I97,@8V]N9F]R;65S(&EN=FES:6)L97,@
M<V]N="!GZ6[I<F%L;&5M96YT(&5N=F]YZ65S(.`@9&5S(&=E;G,@875T<F5S
M('%U92!C975X('%U:2!S;VYT(&1I<F5C=&5M96YT(&-O;F-E<F[I<R!P87(@
M;&4@<W5J970@9'4@;65S<V%G92P@<75I(&1O:79E;G0@<')E;F1R92!C;VYN
M86ES<V%N8V4@9'5D:70@;65S<V%G92P@4T%.4R!Q=64@;&5S(&%U=')E<R!S
M86-H96YT('%U92!C92!M97-S86=E(&QE=7(@82#I=.D@96YV;WGI+B!!:6YS
M:2P@<V5U;"!V;W5S(&5T(&QA('!E<G-O;FYE('%U:2!A(.ETZ2!D97-T:6[I
M92#@(')E8V5V;VER(&-E='1E(&-O<&EE(&5N(&UO9&4@:6YV:7-I8FQE('-A
M=F5N="!Q=2=I;"!A(')EYW4@9&4@;65S<V%G92X*("`@(#PO<&%R83X*/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8F-C(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@
M/&AE861I;F<^)G%U;W0[0F-C)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T
M:&]S92!T;R!R96-E:79E(&$@8FQI;F0@8V%R8F]N(&-O<'D@;V8@>6]U<B!M
M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A
M(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E
M<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T)C8SHF<75O=#L@:6X@
M;W5T9V]I;F<@;6%I;"X@0FQI;F0@8V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL
M>2!S96YT('1O('!E;W!L92!O=&AE<B!T:&%N(&1I<F5C="!A;F0@:6YD:7)E
M8W0@<F5C:7!I96YT<R`H)G%U;W0[5&\Z)G%U;W0[(&%N9"`F<75O=#M#8SHF
M<75O=#L@<F5C:7!I96YT<RD@=VAO(&YE960@=&\@<F5A9"!W:&%T(&ES(&)E
M:6YG('=R:71T96X@87,@=V5L;"!7251(3U54('1H92!O=&AE<B!R96-I<&EE
M;G1S(&MN;W=I;F<@=&AA="!T:&5Y(&%R92!R96-E:79I;F<@=&AE(&5M86EL
M+B!4:'5S("=B;&EN9"<@;65A;G,@=&AA="!T:&4@:61E;G1I='D@;V8@=&AE
M<V4@<F5C:7!I96YT<R!I<R!H:61D96X@9G)O;2!A;&P@;W1H97(@<F5C:7!I
M96YT<R!O9B!T:&4@96UA:6PL(&%N9"!O;FQY('EO=2!A;F0@=&AE>2!K;F]W
M('1H97D@9V]T(&$@8V]P>2X@66]U('1Y<&EC86QL>2!U<V4@=&AI<R!T;R!T
M96QL(&%N(&%U=&AO<FET>2!F:6=U<F4@=&AA="!Y;W4@87)E('1E;&QI;F<@
M<V]M96]N92!S;VUE=&AI;F<@=VET:&]U="!A;&%R;6EN9R!T:&4@<&5R<V]N
M('EO=2!A<F4@<V5N9&EN9R!T:&4@86-T=6%L(&5M86EL('1O+@H@("`@/"]P
M87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E
M+7-U8FIE8W0B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y2Z61A8W1I
M;VX@9&4@;65S<V%G93H@4W5J970\+W1I=&QE/@H@("`@/&AE861I;F<^(E-U
M:F5T(CPO:&5A9&EN9SX*("`@(#QP87)A/@I%;G1R97H@;&4@<W5J970@9&4@
M=F]T<F4@;65S<V%G92X@1V%R9&5Z+6QE(&-O=7)T+"!S:6UP;&4@970@9&5S
M8W)I<'1I9BX@3&4@<W5J970@97-T(&QE('-E=6P@;6]Y96X@<VEM<&QE+"!P
M;W5R('9O=7,@970@=F]S(&-O<G)E<W!O;F1A;G1S+"#@('9O=7,@<V]U=F5N
M:7(@<75E;"#I=&%I="!L92!C;VYT96YU(&1E(&-E(&UE<W-A9V4N($%U<W-I
M+"!L;W)S<75E('9O=7,@<NEP;VYD97HL(&]U('%U92!V;W5S(&9A:71E<R!S
M=6EV<F4@=6X@;65S<V%G92P@;&$@;&EG;F4@8%-U:F5T8"!E<W0@8V]P:>EE
M+B!#96-I('!E<FUE="!D92!F86ER92!U;B!S=6EV:70@;W)G86YI<^D@9"=U
M;F4@8V]N=F5R<V%T:6]N+B!087(@8V]N=')E+"!S:2!U;F4@<NEP;VYS92!C
M;VUP<F5N9"!D92!N;W5V96QL97,@:63I97,L('9O=7,@<&]U=F5Z(&%J;W5T
M97(@9&4@<VEM<&QE<R!M;V1I9FEC871I;VYS(.`@8V4@;>IM92!S=6IE="!P
M;W5R('%U92!L97,@<NEC:7!I96YD86ER97,@9&4@=F]T<F4@;65S<V%G92!P
M=6ES<V5N="!S=6EV<F4@;&$@<')O9W)E<W-I;VX@9'4@;65S<V%G92X*("`@
M(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O
M<V4M<W5B:F5C="(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@
M4W5B:F5C=#PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M3=6)J96-T)G%U
M;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@<W5B:F5C
M="!O9B!Y;W5R(&UE<W-A9V4N(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O=#M3
M=6)J96-T.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL+B!+965P(&ET('-H;W)T
M+"!S:6UP;&4@86YD(&1E<V-R:7!T:79E+B`@5&AE('-U8FIE8W0@;&EN92!I
M<R!T:&4@96%S:65S="!W87D@9F]R('EO=2!A;F0@>6]U<B!C;W)R97-P;VYD
M96YT<R!T;R!R96UE;6)E<B!W:&%T('=A<R!I;B!T:&4@96UA:6P@86YD('1H
M=7,@:7,@=F5R>2!I;7!O<G1A;G0@:6X@;W)G86YI>FEN9R!Y;W5R(&5M86EL
M(&%N9"!F:6YD:6YG(&EM<&]R=&%N="!O;F5S(&QA=&5R+B`@06QS;RP@=VAE
M;B!Y;W4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@86YD(&5M86EL('1H:7,@<W5B
M:F5C="!L:6YE(&ES(&-O<&EE9"!O=F5R(&EN=&\@=&AE(&YE=R!M97-S86=E
M(&%N9"!S;R!I<R!A('9A;'5A8FQE('=A>2!O9B!T96QL:6YG('=H870@;65S
M<V%G97,@9V\@=&]G971H97(@=&\@9F]R;2!A("9Q=6]T.W1H<F5A9"9Q=6]T
M.R!O9B!A(&-O;G9E<G-A=&EO;BX@($AO=V5V97(L(&EF('1H92`G4F5P;'DG
M(&]R("=&;W)W87)D)R!C;VYT86EN<R!N97<@:61E87,L('EO=2!M87D@=V%N
M="!T;R!A9&0@<VEM<&QE(&UO9&EF:6-A=&EO;G,@=&\@=&AE("=3=6)J96-T
M)R!L:6YE('-O('1H92!R96-I<&EE;G0H<RD@8V%N(&9O;&QO=R!T:&4@<')O
M9W)E<W-I;VX@;V8@=&AE("9Q=6]T.W1H<F5A9"XF<75O=#L*("`@(#PO<&%R
M83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO
M<'1I;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4NED86-T:6]N
M(&1E(&UE<W-A9V4Z($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^(D]P
M=&EO;G,B/"]H96%D:6YG/@H@("`@/'!A<F$^"D-E<R!O<'1I;VYS('!E=79E
M;G0@=F]U<R!A:61E<B#@('!RZ7!A<F5R('9O=')E(&UE<W-A9V4N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*0VQI<75E>B!S=7(@(D1E=F5L;W!P97(@;&5S
M(&YO;7,B('!O=7(@87-S;V-I97(@875T;VUA=&EQ=65M96YT(&QE<R!N;VUS
M('!A<G1I96QS(&1E('9O<R!RZ6-I<&EE;G1S("AQ=64@=F]U<R!D979E>B!E
M;G1R97(@874@<'+I86QA8FQE+"!S;VET(&1A;G,@;&4@8VAA;7!S($$Z+"!#
M0SH@;W4@0F-C.BDL(.`@;&5U<B!A9')E<W-E(&1E(&-O=7)R:65R('!E<G-O
M;FYE;&QE+B!0;W5R('5T:6QI<V5R(&-E='1E(&]P=&EO;BP@=F]U<R!D979E
M>B!A=F]I<B!A=2!M;VEN<R!U;F4@96YT<ND@9&%N<R!V;W1R92!C87)N970@
M9"=A9')E<W-E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"D-L:7%U97H@<W5R
M(")6Z7)I9FEC871I;VX@9&4@;"=O<G1H;V=R87!H92(@<&]U<B!E;B!F86ER
M92!L82!V97)I9FEC871I;VXN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*0VQI
M<75E>B!S=7(@(E!IZ&-E<R!*;VEN=&5S(B!P;W5R('9I<W5L86QI<V5R+"!A
M=2!B87,@9&4@;&$@<&%G92P@;&$@;&ES=&4@9&4@9FEC:&EE<G,@871T86-H
MZ7,@X"!V;W1R92!M97-S86=E+"!O=2!E;F-O<F4@<&]U<B!Y(&IO:6YD<F4@
M=6YE('!IZ&-E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"D%C=&EV97H@;&$@
M8V%S92`B0V]P:64@9&%N<RXN+B(@<&]U<B!S875V96=A<F1E<B!C92!M97-S
M86=E(&1A;G,@=F]T<F4@9&]S<VEE<B!D92!M97-S86=E<R!E;G9O>>ES+B!)
M;"!E<W0@=&]U:F]U<G,@:6YTZ7)E<W-A;G0@9&4@<')O8^ED97(@9&4@;&$@
M<V]R=&4L(&%I;G-I+"!V;W5S('!O=79E>B!V;W5S('+I9NER97(@X"!C92!D
M;W-S:65R('!L=7,@=&%R9"!P;W5R(&%V;VER('5N92!M96EL;&5U<F4@:63I
M92!D92!C92!Q=6D@82#I=.D@9F%I="P@970@8V4@<75I(&$@Z>ET(&1I="X@
M3F]U<R!N92!S=6=GZ7)O;G,@=&]U=&5F;VES('!A<R!D92!S875V97)G87)D
M97(@=&]U="!V;W,@8V]U<G)I96QS(&1E(&-E='1E(&9AYV]N+"!P=6ES<74G
M:6P@97-T(&9O<G0@<')O8F%B;&4@<75E('9O=')E('%U;W1A('!E<G-O;FYE
M;"!D86YS('!E=70@9&4@=&5M<',L(&5T('9O=7,@<V5R97H@86QO<G,@:6YC
M87!A8FQE(&1E(')E8V5V;VER(&1E(&YO=7,@;65S<V%G97,N(%9O=7,@<&]U
M=F5Z+"!T;W5T969O:7,L(&5C=&EV97(@8V5T=&4@;W!T:6]N('!A<B!DZ69A
M=70@9&%N<R!L97,@3W!T:6]N<R`H3W!T:6]N<R`M)F=T.R!2Z61A8W1I;VX@
M9&4@;65S<V%G92DN($5N8V]R92!U;F4@9F]I<RP@<')E;F5Z(&=A<F1E(.`@
M8V5T=&4@;W!T:6]N+"!E="!N;W5S('9O=7,@8V]N<V5I;&QO;G,@<&%R(&QE
M(&9A:70@;>IM92#@(&9A:7)E(&QE(&WI;F%G92!D92!V;W1R92!D;W-S:65R
M(&1E(&UE<W-A9V5S(&5N=F]YZ7,@<W5R('5N92!B87-E('+I9W5L:>AR92X*
M("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O
M;7!O<V4M;W!T:6]N<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO
M;CH@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M/<'1I;VYS
M)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&5S92!/<'1I;VYS
M(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M97-S86=E+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!#;&EC:R`F<75O=#M3<&5L;"!#:&5C:R9Q=6]T.R!T
M;R!C:&5C:R!Y;W5R('-P96QL:6YG+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("!#;&EC:R`F<75O=#M!='1A8VAM96YT<R9Q=6]T.R!T;R!V:65W(&%T
M('1H92!B;W1T;VT@;V8@=&AE('!A9V4@82!L:7-T(&]F(&9I;&5S(&%T=&%C
M:&5D('1O('1H:7,@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O("9Q=6]T.U-A
M=F4@8V]P>29Q=6]T.R!T;R!S879E(&$@8V]P>2!O9B!T:&ES(&UE<W-A9V4@
M:6X@>6]U<B`F<75O=#M396YT($UA:6PF<75O=#L@9F]L9&5R+B!3879E(&-O
M<&EE<R!O9B!I;7!O<G1A;G0@96UA:6QS('EO=2!S96YD('-O('1H870@>6]U
M(&AA=F4@<V]M971H:6YG('1O(')E9F5R(&)A8VL@=&\@;&%T97(@86YD('1O
M(&ME97`@86X@86-C=7)A=&4@<F5C;W)D(&]F('=H870@=V%S('-A:60N(%=E
M(&1O(&YO="!R96-O;6UE;F0@>6]U('-A=F4@979E<GD@96UA:6P@<VEN8V4@
M=&AE;B!Y;W5R(&1I<VL@<W1O<F%G92!Q=6]T82!W:6QL(&)E('5S960@=7`@
M<75I8VML>2`H97-P96-I86QL>2!W:&5N('EO=2!S96YD(&%T=&%C:&UE;G1S
M*2!A;F0@>6]U<B!M86EL8F]X('=I;&P@8F4@9G5L;"!A;F0@=6YA8FQE('1O
M(')E8V5I=F4@;F5W(&EN8V]M:6YG(&5M86EL+B!9;W4@8V%N+"!H;W=E=F5R
M+"!T=7)N('1H:7,@9F5A='5R92`G;VXG(&%S('EO=7(@9&5F875L="!W:71H
M:6X@>6]U<B!)9&5N=&ET>2P@8GD@9V]I;F<@=&\@3W!T:6]N<RTF9W0[4&5R
M<V]N86P@26YF;W)M871I;VXM)F=T.T5D:70@>6]U<B!I9&5N=&ET:65S+B!"
M92!C87)E9G5L('=H96X@=7-I;F<@=&AI<R!M;V1I9FEE9"!D969A=6QT(&%S
M('EO=2!W:6QL(&YE960@=&\@<&5R:6]D:6-A;&QY('!U<F=E('EO=7(@)G%U
M;W0[4V5N="!-86EL)G%U;W0[(&9O;&1E<B!O<B!I="!W:6QL(&5V96YT=6%L
M;'D@;6%K92!Y;W5R(&UA:6QB;W@@9G5L;"!A;F0@=6YU<V5A8FQE+@H@("`@
M/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6%T=&%C:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E+I9&%C
M=&EO;B!D92!M97-S86=E.B!0:>AC97,@2F]I;G1E<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SXB4&GH8V5S($IO:6YT97,B/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("`@("!6;W5S('!O=79E>B!J;VEN9')E(&1E<R!P:>AC97,@X"!V;W,@
M;65S<V%G97,N"B`@("`\+W!A<F$^"B`@("`\<&%R83[)=&%P92`Q.B!6;W5S
M('!O=79E>B!S;VET('1A<'!E<B!L92!C:&5M:6X@9'4@9FEC:&EE<B`H;_D@
M<V4@=')O=79E(&-E(&9I8VAI97(@<W5R('9O=')E(&]R9&EN871E=7(I+"!O
M=2!C;&EQ=65R('-U<B!L92!B;W5T;VX@(D)R;W=S92(L('!O=7(@96YS=6ET
M92!SZ6QE8W1I;VYN97(@;&4@9FEC:&EE<B#@(&%T=&%C:&5R+B!,92!C:&5M
M:6X@9'4@9FEC:&EE<B!A<'!A<F'N=&5R82!A;&]R<R!D86YS(&QA(&)O[G1E
M(")0:>AC97,@2F]I;G1E<R(N(%!R;V/I9&5Z(&UA:6YT96YA;G0@X"!L)^ET
M87!E(#(N"B`@("`\+W!A<F$^"B`@("`\<&%R83[)=&%P92`R.B!#;&EQ=65Z
M('-U<B!L92!B;W5T;VX@(DIO:6YD<F4B+B!,92!N;VT@9'4@9FEC:&EE<B!A
M:6YS:2!Q=64@;&$@=&%I;&QE(&1U(&9I8VAI97(@<V5R82!A:F]U=.D@X"!L
M82!L:7-T92!D97,@<&GH8V5S(&IO:6YT97,N(%9E=6EL;&5Z(&YO=&5R('%U
M92!P;W5R('5N(&9I8VAI97(@9&4@9W)O<W-E('1A:6QL92P@;W4@96YC;W)E
M('!O=7(@=6X@8V]N;F5X:6]N($EN=&5R;F5T(&UO:6YS(')A<&ED92P@;&4@
M<')O8^EDZ2!D)V%T=&%C:&5M96YT(.`@=F]T<F4@;65S<V%G92!P975T('!R
M96YD<F4@=6X@8V5R=&%I;B!T96UP<RX@4V]Y97H@<&%T:65N="!A='1E;F1E
M>B!Q=64@;&4@<')O8V5S<W5S('-O:70@=&5R;6ENZ2!A=F%N="!D92!C;VYT
M:6YU97(N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+6%T=&%C:"(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@071T86-H/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T%T
M=&%C:"9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA>2!A
M='1A8V@@9FEL97,@=&\@>6]U<B!M97-S86=E.R!O;FQY(&]N92!F:6QE(&UA
M>2!B92!A='1A8VAE9"!A="!A('1I;64N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83Y3=&5P(#$Z($5I=&AE<BP@='EP92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A
M(&9I;&4@=&AA="!Y;W4@=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@
M;W(@8VQI8VL@)G%U;W0[0G)O=W-E)G%U;W0[(&)U='1O;B!A;F0@<V5L96-T
M('1H92!F:6QE('1O(&)E(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD(&YA;64@
M;V8@=&AA="!F:6QE(&YO=R!A<'!E87)S(&EN('1H92!!='1A8VAM96YT(&)O
M>"X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,CH@1&5C:61E('=H971H
M97(@>6]U('=A;G0@=&AE(&9I;&4@=&\@8F4@=FEE=V5D(&%S(&%N(&%T=&%C
M:&UE;G0@;W(@:6YL:6YE9"!W:71H('1H92!R97-T(&]F('1H92!M97-S86=E
M+B!4:&4@<F5C96EV:6YG('!E<G-O;BAS*2!M86EL(')E861I;F<@<V]F='=A
M<F4@;75S="!B92!A8FQE('1O(&AA;F1L92!T:&4@9FEL92!T>7!E(&EN;&EN
M93L@:68@;F]T+"!T:&ES('!A<G0@=VEL;"!B92!V:65W960@87,@86X@871T
M86-H;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`S
M.B!#;&EC:R`F<75O=#M!='1A8V@F<75O=#L@8G5T=&]N+B!4:&4@9FEL92!N
M86UE(&%N9"!S:7IE('=I;&P@8F4@861D960@=&\@>6]U<B!L:7-T(&]F($%T
M=&%C:&UE;G1S+B!0;&5A<V4@;F]T92!T:&%T(&9O<B!L87)G92!F:6QE<R!A
M;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O;FYE8W1I;VYS+"!T:&4@<')O8V5S
M<R!O9B!U<&QO861I;F<@86YD(&%T=&%C:&EN9R!Y;W5R(&9I;&4@=&\@=&AE
M(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N(%!L96%S92!B92!P871I96YT(&%N
M9"!D;R!N;W0@8VQI8VL@;W1H97(@=&AI;F=S('=H:6QE('EO=2!A<F4@=V%I
M=&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/E+I9&%C=&EO;B!D92!M97-S86=E.B!0:>AC97,@2F]I;G1E
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB4&GH8V5S($IO:6YT97,B/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!#971T92!S96-T:6]N(&UO;G1R92!L82!L
M:7-T92!D97,@9FEC:&EE<G,@871T86-HZ7,@X"!V;W1R92!M97-S86=E+B!0
M;W5R(&5F9F%C97(@=6X@9FEC:&EE<B!A='1A8VCI.@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^R71A<&4@,3H@06-T:79E>B!L82!C87-E(.`@8_1TZ2!D=2!N
M;VT@9'4@9FEC:&EE<B!Q=64@=F]U<R!V;W5L97H@969F86-E<BX*("`@(#PO
M<&%R83X*("`@(#QP87)A/LET87!E(#(Z($-L:7%U97H@<W5R(")3=7!P<FEM
M97(@<&GH8V4H<RD@:F]I;G1E*',I(BX*("`@(#PO<&%R83X*/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M871T86-H;65N=',B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:&UE;G1S/"]T
M:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T%T=&%C:&UE;G1S)G%U;W0[/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES('-E8W1I;VX@9&ES<&QA>7,@
M82!L:7-T(&]F(&9I;&5S(&%L<F5A9'D@871T86-H960@=&\@>6]U<B!M97-S
M86=E+B!4;R!$96QE=&4@86X@871T86-H960@9FEL93H*("`@(#PO<&%R83X*
M("`@(#QP87)A/E-T97`@,3H@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N
M97AT('1O('1H92!A='1A8VAE9"!F:6QE;F%M92!Y;W4@=V%N="!T;R!$96QE
M=&4N"B`@("`\+W!A<F$^(`H@("`@/'!A<F$^4W1E<"`R.B!#;&EC:R`F<75O
M=#M$96QE=&4@071T86-H;65N="AS*29Q=6]T.RX*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UP<FEO<FET
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO
M;CH@4')I;W)I='D\+W1I=&QE/@H@("`@/&AE861I;F<^(E!R:6]R:71Y(CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S971S('1H92`B6"U0<FEO
M<FET>2(@:&5A9&5R(&]N('EO=7(@;W5T9V]I;F<@;65S<V%G92X@5&AE(")8
M+5!R:6]R:71Y(B!T86<@:7,@82!S;W)T(&]F(")P<V5U9&\@<W1A;F1A<F0B
M('1H870@3F5T<V-A<&4L($UO>FEL;&$L($]P97)A+"!A;F0@3W5T;&]O:R!M
M86EL(&-L:65N=',@87!P96%R('1O(&%G<F5E(&]N+B!!;GD@;6%I;"!C;&EE
M;G1S('1H870@9&\@;F]T(&AA;F1L92!T:&ES(&AE861E<B!W:6QL('-I;7!L
M>2!I9VYO<F4@:70N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)C;VUP;W-E+7-A=F4M871T86-H;65N=',B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%-A=F4@071T86-H;65N=',\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H971H97(@=&AE
M(&%T=&%C:&UE;G1S(&EN('EO=7(@8V]M<&]S:71I;VX@87)E('-A=F5D('=I
M=&@@=&AE(&UE<W-A9V4@=VAE;B!S=&]R960@:6X@=&AE('-E;G0M;6%I;"!F
M;VQD97(N("!)9B`B665S(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W:6QL(&)E
M('-A=F5D+B`@268@(DYO(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W:6QL(&)E
M('-T<FEP<&5D(&9R;VT@=&AE(&UE<W-A9V4@869T97(@:70@:7,@<V5N="!T
M;R!A;&P@<F5C:7!I96YT<RX@($-H;V]S:6YG(").;R(@=VEL;"!H96QP(&-O
M;G-E<G9E(&1I<VL@<W!A8V4@8GD@<F5M;W9I;F<@*'!O=&5N=&EA;&QY(&QA
M<F=E*2!A='1A8VAM96YT(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-A=F5D(&UE
M<W-A9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M
M<&]S92UL:6YK+6%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!,:6YK($%T=&%C:&UE;G1S/"]T:71L
M93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A
M8VAM96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N(&%R92!S96YT(&%S(&$@<&%R
M="!O9B!T:&4@;6%I;"!M97-S86=E(&]R('=H971H97(@=&AO<V4@871T86-H
M;65N=',@87)E(&ME<'0@;VX@82!L;V-A;"!S97)V97(N("!)9B!A='1A8VAM
M96YT<R!A<F4@;&EN:V5D+"!T:&4@<F5C:7!I96YT*',I(&]F('EO=7(@;65S
M<V%G92!W:6QL(&)E('!R;W9I9&5D(&$@=V5B;&EN:R!W:&5R92!T:&5Y(&-A
M;B!D;W=N;&]A9"!T:&4@871T86-H;65N="AS*2X@($QI;FMI;F<@871T86-H
M;65N=',@:&%S('1H92!A9'9A;G1A9V4@;V8@=')E;65N9&]U<VQY(')E9'5C
M:6YG('1H92!S:7IE(&]F(&]U=&=O:6YG(&UE<W-A9V5S+B`@3&EN:VEN9R!A
M='1A8VAM96YT<R!H87,@=&AE(&1I<V%D=F%N=&%G92!T:&%T('1H92!C;VYT
M96YT(&]F('1H92!A='1A8VAM96YT<R!C86X@;F]T(&)E(&=U87)A;G1E960@
M=&\@8F4@879A:6QA8FQE(&EN('1H92!F=71U<F4@<VEN8V4@=&AE(&%T=&%C
M:&UE;G0@9&%T82!I<R!N;W0@;&]C871E9"!W:71H:6X@=&AE(&4M;6%I;"!M
M97-S86=E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V5A
M<F-H(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4F5C:&5R8VAE/"]T
M:71L93X*("`@(#QH96%D:6YG/D-R:73H<F5S(&1E(')E8VAE<F-H93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("`@(%1E>'1E(.`@Z6-R:7)E("XN+@H@
M("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<V5A
M<F-H(CX*("`@(#QT:71L93Y-97-S86=E(%-E87)C:#PO=&ET;&4^"B`@("`\
M:&5A9&EN9SY396%R8V@@0W)I=&5R:6$\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%EO=2!M87D@<V5A<F-H(&9O<B!M97-S86=E<R!F<F]M('EO=7(@9F]L
M9&5R<R!U<VEN9R!D:69F97)E;G0@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^4W1E<"`Q.B!%;G1E<B!T97AT('1O('1H92!F:65L
M9',@>6]U('=A;G0@=&\@861D('1O('EO=7(@<V5A<F-H(&-R:71E<FEA+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`R.B!#:&]O<V4@=&AE(&UE<W-A
M9V4@9FQA9RAS*2!T;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#,Z($-H;V]S92!T:&4@9F]L9&5R
M*',I(&9R;VT@=VAI8V@@=&\@<V5A<F-H(&9O<B!T:&4@;65S<V%G97,N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#0Z($-L:6-K("9Q=6]T.U-E87)C
M:"9Q=6]T.RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@268@86YY(&UE
M<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@@8W)I=&5R:6$L('1H96X@=&AE
M('-U8FIE8W1S(&]F('1H97-E(&UE<W-A9V5S('=I;&P@8F4@<VAO=VX@:6X@
M=&AE("9Q=6]T.U-E87)C:"!297-U;'1S)G%U;W0[('9I97<N"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUO
M<'1I;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^1V5S=&EO;B!D
M97,@9&]S<VEE<G,\+W1I=&QE/@H@("`@/&AE861I;F<^3W!T:6]N<R!D97,@
M9&]S<VEE<G,\+VAE861I;F<^"B`@("`\<&%R83X*"59O=7,@<&]U=F5Z('/I
M;&5C=&EO;FYE<B!U;B!D;W-S:65R(&5N('5T:6QI<V%N="!L97,@8F]U=&]N
M<R!D86YS(&QA(&-O;&]N92!D92!G875C:&4N(%5N92!F;VES(&-E8VD@8V]M
M<&SI=.DL('/I;&5C=&EO;FYE>B!L)V]P=&EO;B!Q=64@=F]U<R!V;W5L97H@
M871T<FEB=65R(&%U*'@I(&1O<W-I97(H<RD@<^EL96-T:6]N;NDH<RD@96X@
M=71I;&ES86YT(&QE(&UE;G4@9.ER;W5L86YT(&%U(&AA=70@;W4@874@8F%S
M(&1E(&PGZ6-R86XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*"59O=7,@=F]U
M<R!V97)E>B!A;&]R<R!D96UA;F1E<B!D97,@;W!T:6]N<R!S=7!P;.EM96YT
M86ER97,N(%-O>65Z('1RZ',@<')U9&5N="!A=F5C(&PG;W!T:6]N(&1E(&1E
M<W1R=6-T:6]N(&1E(&1O<W-I97(H<RDL('!U:7-Q=2=U;F4@9F]I<R!U;B!D
M;W-S:65R(&5F9F5CZ2P@<V]N(&-O;G1E;G4@97-T(&ER<NEC=7#I<F%B;&4N
M"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F
M;VQD97(M;W!T:6]N<R(^"B`@("`\=&ET;&4^1F]L9&5R($UA;F%G96UE;G0\
M+W1I=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($]P=&EO;G,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@82!F;VQD97(@8GD@
M=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE(&QE9G0@8V]L=6UN
M+B`@3VYC92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C="!T:&4@;W!T:6]N
M('EO=2!W:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E<B!V:6$@=&AE('-E
M;&5C="!B;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@("`@66]U('=I;&P@8F4@<')O;7!T960@9F]R(&9U<G1H97(@;W!T:6]N
M<RX@($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO;BP@87,@>6]U
M(&-A;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD97(@:68@>6]U
M(&1E;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^26UP;W)T(&UB;W@@1FEL93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M("!4:&ES(&]P=&EO;B!W:6QL(&EM<&]R="!A(&UB;W@@9F]R;6%T(&9I;&4@
M:6YT;R!T:&4@9F]L9&5R(&]F('EO=7(@8VAO:6-E+B!#:&]O<V4@,2`H;VYE
M*2!F;VQD97(@=&\@:6UP;W)T('1H92!M97-S86=E<R!I;G1O(&%N9"!T:&5N
M('-E;&5C="!T:&ES(&]P=&EO;BX@66]U('=I;&P@=&AE;B!B92!T86ME;B!T
M;R!A('!A9V4@=&AA="!W:6QL('!R;VUP="!F;W(@=&AE(&UB;W@@9FEL92!T
M;R!I;7!O<G0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](F9O;&1E<BUW:61G971S(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y&;VQD97(@36%N86=E;65N=#H@1&ES<&QA>3PO=&ET;&4^"B`@("`\
M:&5A9&EN9SY3:&]W+TAI9&4@56YS=6)S8W)I8F5D/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!)9B!U<VEN9R!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS
M+"!S:&]W+VAI9&4@=&AE('5N<W5B<V-R:6)E9"!F;VQD97)S+B`@5&\@<W5B
M<V-R:6)E+W5N<W5B<V-R:6)E('1O(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H
M96-K8F]X(&YE>'0@=&\@=&AE(&9O;&1E<FYA;64@86YD('5S92!T:&4@4W5B
M<V-R:6)E+U5N<W5B<V-R:6)E(&]P=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO
M;B!D<F]P+61O=VX@;65N=2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X
M<&%N9"!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5X<&%N9"!A;&P@
M9F]L9&5R(&5N=')I97,N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL
M87!S92!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-O;&QA<'-E(&%L
M;"!F;VQD97(@96YT<FEE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F9I;'1E<G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y&
M:6QT<F5S.B!!<'!L:7%U97(\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;&EQ
M=65R(&1E<R!RZ&=L97,@9&4@9FEL=')E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"@E#;&EQ=65Z('-U<B!L)VEC]&YE(")!<'!L:7%U97(@;&5S($9I;'1R97,@
M<W5R(%LN+BY=(B#@(&1R;VET92!D=2!N;VT@9'4@9&]S<VEE<B!P<NES96YT
M(&%F:6X@9"=A<'!L:7%U97(@;&5S('+H9VQE<R!D92!F:6QT<F4@<75E('9O
M=7,@879E>B!S<.EC:69I97H@*$]P=&EO;G,@+29G=#L@161I=&5R(&UE<R!R
MZ&=L97,@9&4@9FEL=')E("TF9W0[(%+H9VQE<R!D92!F:6QT<F5S*2X@06QT
M97)N871I=F5M96YT+"!V;W5S('!O=79E>B!C;&EQ=65R('-U<B!L92!B;W5T
M;VX@(D%P<&QI<75E<B!T;W5T97,@;&4@<NEG;&5S(BP@<V4@<F5T<F]U=F%N
M="!D86YS(&QE(&UE;G4@<')I;F-I<&%L(&1E<R!F:6QT<F4@*$]P=&EO;G,@
M+29G=#L@161I=&5R(&UE<R!RZ&=L97,@9&4@9FEL=')E("TF9W0[(%+H9VQE
M<R!D92!F:6QT<F5S*2X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y
M.@H\96YT<GD@:60](F9I;'1E<G,B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($%P
M<&QY/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@;VX@=&AE("9Q=6]T.T%P
M<&QY($9I;'1E<B9Q=6]T.R!I8V]N(&YE>'0@=&\@=&AE($E.0D]8(&YA;64@
M:6X@=&AE(&UA:6QB;W@@=FEE=R!T;R!F:6QT97(@86QL('5N9&5L971E9"!M
M97-S86=E<R!A8V-O<F1I;F<@=&\@=&AE('-P96-I9FEE9"!R=6QE<RX@($]R
M+"!A;'1E<FYA=&5V;'DL(&-L:6-K(&]N("9Q=6]T.T%P<&QY($%L;"!2=6QE
M<R9Q=6]T.R!I;B!T:&4@9FEL=&5R(&UE;G4N("!.;W1E('1H870@9FEL=&5R
M:6YG(&ES(&YO="!D;VYE(&%U=&]M871I8V%L;'DN"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUE9&ET+7)U
M;&5S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET($9I
M;'1E<B!2=6QE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@1FEL
M=&5R(%)U;&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B
M161I="!Y;W5R(&9I;'1E<B!R=6QE<R(@=&\@<')O8V5E9"!T;R!T:&4@<&%G
M92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E+"!A;F0@961I="!T:&4@8W5R
M<F5N=&QY(&%C=&EV92!S970@;V8@9FEL=&5R(')U;&5S+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M8FQA8VML:7-T
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET($)L86-K
M;&ES=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@0FQA8VML:7-T
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R
M(&)L86-K;&ES="(@=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@
M8V%N(&%D9"P@9&5L971E+"!A;F0@961I="!T:&4@;&ES="!O9B!E+6UA:6P@
M861D<F5S<V5S('EO=2!!3%=!65,@<F5F=7-E(&UA:6P@9G)O;2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUE9&ET+7=H:71E
M;&ES="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!7
M:&ET96QI<W0\+W1I=&QE/@H@("`@/&AE861I;F<^161I="!9;W5R(%=H:71E
M;&ES=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@
M>6]U<B!W:&ET96QI<W0B('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@
M>6]U(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@=&AE(&QI<W0@;V8@92UM
M86EL(&%D9')E<W-E<R!Y;W4@04Q705E3(&%C8V5P="!M86EL(&9R;VTN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM;&]G
M:6XB('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!O
M;B!,;V=I;CPO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L
M97,@57!O;B!,;V=O;C\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K
M('1H:7,@;W!T:6]N('1O(&%L=V%Y<R!A<'!L>2!F:6QT97)S('=H96X@9FER
M<W0@;&]G9VEN9R!O;G1O($E-4"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F9I;'1E<BUO;BUD:7-P;&%Y(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y&:6QT97)S.B!&:6QT97(@;VX@4F5F<F5S:#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@
M:7,@9&ES<&QA>65D/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@
M=&AI<R!O<'1I;VX@=&\@86QW87ES(&%P<&QY(&9I;'1E<G,@=VAE;F5V97(@
M>6]U<B!V:65W('1H92!)3D)/6#\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F9I;'1E<BUA;GDM;6%I;&)O>"(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&%N>2!-86EL8F]X/"]T:71L93X*
M("`@(#QH96%D:6YG/D%P<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@;6%I;&)O
M>#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N
M(&EF('EO=2!W86YT('1O(&)E(&%L;&]W960@=&\@87!P;'D@9FEL=&5R(')U
M;&5S('1O(&%N>2!M86EL8F]X+B!.;W)M86QL>2P@9FEL=&5R:6YG(')U;&5S
M(&%R92!O;FQY(&%P<&QI960@=&\@;F5W(&UA:6P@=&AA="!I<R!D96QI=F5R
M960@=&\@>6]U<B!)3D)/6"X@($EF('1H:7,@;W!T:6]N(&ES(&-H96-K960L
M(&%N(&EC;VX@=VEL;"!A<'!E87(@;VX@86QL(&UA:6QB;W@@<&%G9V5S('1H
M870@=VEL;"!A;&QO=R!Y;W4@=&\@87!P;'D@9FEL=&5R(')U;&5S('1O('1H
M92!M97-S86=E<R!I;B!T:&4@8W5R<F5N="!M86EL8F]X+B`@3D]413H@1FEL
M=&5R:6YG(&EN(&UA:6QB;WAE<R!O=&AE<B!T:&%N($E.0D]8(&UA>2!P<F]D
M=6-E('-T<F%N9V4@*&4N9RX@=&AE(&9I;'1E<B!M87D@8V%U<V4@82!C;W!Y
M(&]F(&UE<W-A9V5S('1O(&)E(&1E;&EV97)E9"!T;R!T:&4@<V%M92!M86EL
M8F]X*2!A;F0O;W(@=6YD97-I<F5D(')E<W5L=',@*&4N9RX@:70@;6%Y(&-A
M=7-E(&UE<W-A9V5S('1O(&)E(&UO=F5D+V1E;&5T960@:68@;F5W(&9I;'1E
M<FEN9R!R=6QE<R!H879E(&)E96X@:6UP;&5M96YT960@<VEN8V4@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@9&5L:79E<F5D('1O('1H92!C=7)R96YT(&UA:6QB
M;W@I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6-O
M;7!O<V4M871T86-H+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4$=0.B!!='1A8V@@4'5B;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M='1A8V@@4'5B;&EC($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M<V5L96-T960@=&AE;B!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@
M:68@:70@97AI<W1S+"!W:6QL(&)E(&%T=&%C:&5D('1O('1H92!O=71G;VEN
M9R!M97-S86=E+B`@66]U(&-A;B!S970@=&AE(&1E9F%U;'0@8F5H879I;W(@
M=FEA('1H92!01U`@3W!T:6]N<R!S8W)E96XN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+7-C86XM8F]D>2(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!38V%N(%1E>'0@0F]D:65S/"]T:71L
M93X*("`@(#QH96%D:6YG/E-C86X@5&5X="!";V1I97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@24U0('=I;&P@<V-A;B!T
M:&4@8F]D>2!O9B!A;&P@=&5X="!M97-S86=E<R!F;W(@4$=0(&1A=&$L(&%N
M9"!D:7-P;&%Y('1H92!R97-U;'1S(&EF(&%N>2!D871A(&ES(&9O=6YD+B`@
M3F]T92!T:&%T('1H:7,@;6%Y('-L;W<@9&]W;B!T:&4@<WES=&5M(&%S(&5V
M97)Y('1E>'0@;65S<V%G92!M=7-T(&)E('-C86YN960@:6X@:71S(&5N=&ER
M971Y(&9O<B!01U`@9&%T82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F-O;7!O<V4M;W!T:6]N<RUE;F-R>7!T(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y#;VUP;W-E.B!%;F-R>7!T:6]N($]P=&EO;G,\+W1I=&QE
M/@H@("`@/&AE861I;F<^3F\@16YC<GEP=&EO;CPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@4V5N9"!T:&4@;65S<V%G92!W:71H(&YO(&5N8W)Y<'1I;VX@
M*&-L96%R=&5X="DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@16YC
M<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P
M=&EO;B!W:6QL(&5N8W)Y<'0@=&AE(&-U<G)E;G0@;65S<V%G92P@=7-I;F<@
M4$=0(&%N9"!T:&4@<F5C:7!I96YT<R!P97)S;VYA;"!P=6)L:6,@:V5Y+"!A
M;F0@=&AE;B!S96YD(&ET+B!9;W4@8V%N(&]N;'D@<V5N9"!A(&UE<W-A9V4@
M=&\@82!S:6YG;&4@<&5R<V]N('5S:6YG('1H:7,@;W!T:6]N+B!9;W4@3553
M5"!H879E('1H92!P=6)L:6,@:V5Y(&]F('1H92!R96-I<&EE;G0@<W1O<F5D
M(&EN('EO=7(@861D<F5S<V)O;VL@;W(@96QS92!T:&ES(&]P=&EO;B!W:6QL
M(&9A:6PN($EF('EO=2!H879E('1H92!P=6)L:6,@:V5Y(&9O<B!T:&4@<F5C
M:7!I96YT(&EN('EO=7(@861D<F5S<V)O;VL@86YD(&%R92!S=&EL;"!R96-E
M:79I;F<@97)R;W)S+"!V97)I9GD@=&AA="!T:&4@92UM86EL(&%D9')E<W,@
M:6X@=&AE(')E8VEP:65N="!F:65L9"!M871C:&5S('1H92!E+6UA:6P@861D
M<F5S<R!W:&5R92!T:&4@<'5B;&EC(&ME>2!I<R!S=&]R960N(%1H92!E;F-R
M>7!T960@9&%T82!W:6QL(&)E(&%T=&%C:&5D('1O('1H92!O=71G;VEN9R!M
M97-S86=E+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0(%-I9VX@365S
M<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL
M;"!D:6=I=&%L;'D@<VEG;B!T:&4@8W5R<F5N="!M97-S86=E('5S:6YG(%!'
M4"!A;F0@>6]U<B!P97)S;VYA;"!P<FEV871E(&ME>2X@268@>6]U(&AA=F4@
M;F]T(&%L<F5A9'D@96YT97)E9"!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!P
M<FEV871E(&ME>2!D=7)I;F<@=&AI<R!S97-S:6]N('EO=2!W:6QL(&)E('!R
M;VUP=&5D(&9O<B!I="X@(%1H92!R96-E:7!I96YT(&UU<W0@:&%V92!A(&-O
M<'D@;V8@>6]U<B!P=6)L:6,@:V5Y('1O(&1I9VET86QL>2!V97)I9GD@>6]U
M<@H@("`@<VEG;F%T=7)E+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0
M(%-I9VXO16YC<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4:&ES(&]P=&EO;B!W:6QL(&9I<G-T(&1I9VET86QL>2!S:6=N('EO=7(@
M;65S<V%G92!A;F0@=&AE;B!W:6QL(&5N8W)Y<'0@=&AE(')E<W5L=&EN9R!O
M=71P=70N(%-E92!T:&4@)U!'4"!%;F-R>7!T($UE<W-A9V4G(&%N9"`G4$=0
M(%-I9VX@365S<V%G92<@96YT<FEE<R!F;W(@9G5R=&AE<B!I;F9O<FUA=&EO
M;BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-12!%;F-R>7!T($UE
M<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/E,O34E-12!3:6=N($UE<W-A9V4\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5$]$3PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+6]V97)V:65W(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z
M($]V97)V:65W/"]T:71L93X*("`@(#QH96%D:6YG/E=H870@:7,@4$=0/SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4$=0(&ES(&$@=&]O;"!F;W(@<V5C
M=7)E(&-O;6UU;FEC871I;VX@86YD(&1A=&$@<W1O<F%G92P@97-P96-I86QL
M>2!F;W(@=7-E('=I=&@@92UM86EL+B!)="!C86X@8F4@=7-E9"!T;R!E;F-R
M>7!T(&1A=&$@86YD('1O(&-R96%T92!D:6=I=&%L('-I9VYA='5R97,N($E-
M4"!U<V5S($=N=5!'("A'3E4@4')I=F%C>2!'=6%R9"D@=&\@<')O=FED92!T
M:&ES(&9U;F-T:6]N86QI='DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%
M;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!)9B!T:&ES(&]P=&EO;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@
M86)L92!T;R!C<F5A=&4O=FEE=R!Y;W5R('!E<G-O;F%L(%!'4"!K97ES+"!A
M9&0O9&5L971E('!U8FQI8R!K97ES(&9R;VT@;W1H97(@:6YD:79I9'5A;',L
M(')E860@96YC<GEP=&5D(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG;F5D
M(&UA:6PL(&%N9"!E;F-R>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO;BUA
M='1A8V@M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($]P
M=&EO;G,@+2!!='1A8V@@4'5B;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY/<'1I;VYS("T@071T86-H(%!U8FQI8R!+97D\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@82!C;W!Y(&]F('EO=7(@4$=0
M('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T<RP@=VEL;"!B>2!D969A=6QT(&)E
M(&%T=&%C:&5D('1O(&%L;"!O=71G;VEN9R!M97-S86=E<RX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UM86YA9V4M<'5B:V5Y(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!S8W)E96X@;&ES=',@86QL(&]F('1H92!C=7)R
M96YT('5S97)S(&EN('EO=7(@861D<F5S<V)O;VL@=&AA="!H879E(%!'4"!P
M=6)L:6,@:V5Y<RX@5&AE<V4@=7-E<G,@87)E('1H92!/3DQ9('5S97)S('1H
M870@>6]U(&-A;B!E:71H97(@,2D@<V5N9"!A;B!E;F-R>7!T960@;65S<V%G
M92!T;R`M3U(M(#(I('9E<FEF>2!A(&1I9VET86P@<VEG;F%T=7)E+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!U8FQI8R!K
M97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@
M=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M1&5L971E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&5S('1H92!P
M=6)L:6,@:V5Y(&9R;VT@>6]U<B!A9&1R97-S8F]O:RX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UI;7!O<G0M<'5B:V5Y(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y<R`M
M($EM<&]R=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY);7!O<G0@4'5B;&EC($ME
M>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@8G5T=&]N('=I;&P@
M;W!E;B!A('=I;F1O=R!W:&5R92!Y;W4@8V%N(&UA;G5A;&QY(&EM<&]R="!A
M(%!'4"!P=6)L:6,@:V5Y+B`@5&AE(&ME>2!C86X@96ET:&5R(&)E('!A<W1E
M9"!I;G1O(&$@=&5X=&9I96QD(&]R+"!I9B!T:&4@:V5Y(')E<VED97,@:6X@
M82!F:6QE(&]N('EO=7(@;&]C86P@8V]M<'5T97(L('EO=2!C86X@:6UP;W)T
M(&ET+B`@268@=&AE(&ME>2!I<R!V86QI9"!I="!W:6QL(&)E(&EN<V5R=&5D
M(&EN=&\@>6]U<B!A9&1R97-S8F]O:R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L
M;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R
M971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UO=F5R=FEE=RUP97)S;VYA;&ME>2(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@268@>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@;65S<V%G
M97,@;W(@96YA8FQE(&]T:&5R<R!T;R!S96YD('EO=2!E;F-R>7!T960@;65S
M<V%G97,L('EO=2!M=7-T(&AA=F4@>6]U<B!O=VX@<&5R<V]N86P@<'5B;&EC
M+W!R:79A=&4@4$=0(&ME>7!A:7(N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY9;W5R(%!U8FQI8R!+97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO
M=7(@<'5B;&EC(&ME>2!S:&]U;&0@8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY
M('!E<G-O;B!T:&%T('EO=2!W86YT('1O(&)E(&%B;&4@=&\@<V5N9"!Y;W4@
M96YC<GEP=&5D(&UE<W-A9V5S('1H870@;VYL>2!93U4@8V%N(&1E8W)Y<'0@
M*'5S:6YG('EO=7(@<')I=F%T92!K97DI+B!!9&1I=&EO;F%L;'DL('EO=7(@
M<'5B;&EC(&ME>2!N965D<R!T;R!B92!M861E(&%V86EL86)L92!T;R!A;GEB
M;V1Y('EO=2!S96YD(&$@9&1I9VET86QL>2!S:6=N960@;65S<V%G92!T;R`M
M('1H92!P=6)L:6,@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@9&EG
M:71A;"!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY9;W5R
M(%!R:79A=&4@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!R
M:79A=&4@:V5Y(&ES(&YE8V5S<V%R>2!T;R!D96-R>7!T(&%N>2!M97-S86=E
M(&5N8W)Y<'1E9"!U<VEN9R!Y;W5R('!U8FQI8R!K97DN($%D9&ET:6]N86QL
M>2P@>6]U<B!P<FEV871E(&ME>2!I<R!N965D960@:68@>6]U('=A;G0@=&\@
M9&EG:71A;&QY('-I9VX@82!M97-S86=E+B!9;W5R('!R:79A=&4@:V5Y('=I
M;&P@8F4@<')O=&5C=&5D('9I82!A('!A<W-P:')A<V4@8W)E871E9"!W:&5N
M('1H92!K97ES(&%R92!G96YE<F%T960N(%1H=7,L('1O('!E<F9O<FT@86YY
M(&%C=&EV:71Y('1H870@<F5Q=6ER97,@>6]U<B!P<FEV871E(&ME>2P@24U0
M('=I;&P@<')O;7!T('EO=2!F;W(@>6]U<B!P87-S<&AR87-E+B!9;W4@;VYL
M>2!N965D('1O(&EN<V5R="!Y;W5R('!A<W-P:')A<V4@;VYC92!P97(@<V5S
M<VEO;B`M($E-4"!W:6QL('-T;W)E('EO=7(@<&%S<W!H<F%S92!U;G1I;"!Y
M;W4@;&]G;W5T("A3;R!B92!S=7)E('1O(&QO9V]U="$I+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!U8FQI
M8R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N
M86P@2V5Y<R`M(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^5FEE
M=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@
M=FEE=R!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y
M<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y
M+7!R:79A=&4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E
M(%!E<G-O;F%L($ME>7,@+2!0<FEV871E($ME>3PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY%;G1E<B!087-S<&AR87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!/<&5N<R!T:&4@<&%S<W!H<F%S92!D:6%L;V<@=VEN9&]W+B!4:&4@<&%S
M<W!H<F%S92!E;G1E<F5D+"!I9B!C;W)R96-T+"!W:6QL(&)E('-T;W)E9"!B
M>2!)35`@=6YT:6P@>6]U<B!S97-S:6]N(&5N9',N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY5;FQO860@4&%S<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@4F5M;W9E<R!T:&4@<W1O<F5D('!A<W-P:')A<V4@9G)O;2!)
M35`@+2!A;GD@861D:71I;VYA;"!U<V%G92!O9B!T:&4@<')I=F%T92!K97D@
M=VEL;"!R97%U:7)E('EO=2!T;R!R965N=&5R('1H92!P87-S<&AE87-E+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!R:79A
M=&4@:V5Y+B!$3R!.3U0@4T5.1"!42$E3($M%62!43R!!3EE/3D4@+2!T:&ES
M(&]P=&EO;B!I<R!S=')I8W1L>2!S;R!T:&%T('EO=2!C86X@97AP;W)T('EO
M=7(@24U0('!E<G-O;F%L('!R:79A=&4@:V5Y(&9O<B!U<V4@:6X@86YO=&AE
M<B!P<F]G<F%M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS
M(&%B;W5T('1H92!01U`@<')I=F%T92!K97DN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM9&5L971E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES
M("T@1&5L971E/"]T:71L93X*("`@(#QH96%D:6YG/D1E;&5T92!097)S;VYA
M;"!+97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&)U='1O;B!W
M:6QL(&1E;&5T92!Y;W5R('!E<G-O;F%L('!U8FQI8R]P<FEV871E(&ME>7!A
M:7(@9G)O;2!)35`G<R!P<F5F97)E;F-E<RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M;F%M92(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@
M2V5Y("T@3F%M93PO=&ET;&4^"B`@("`\:&5A9&EN9SY.86UE/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&4@;F%M92!Y;W4@=V%N="!E;6)E9&1E9"!I
M;B!Y;W5R('!E<G-O;F%L(&ME>7,N($$@<F5Q=6ER960@9FEE;&0N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM
M8W)E871E+6-O;6UE;G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@
M0W)E871E(%!E<G-O;F%L($ME>2`M($-O;6UE;G0\+W1I=&QE/@H@("`@/&AE
M861I;F<^0V]M;65N=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@02!C;VUM
M96YT('-T<FEN9R!Y;W4@=V%N="!E;6)E9&1E9"!I;B!Y;W5R('!E<G-O;F%L
M(&ME>7,N($%N(&]P=&EO;F%L(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UE;6%I;"(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@
M2V5Y("T@12UM86EL($%D9')E<W,\+W1I=&QE/@H@("`@/&AE861I;F<^12UM
M86EL($%D9')E<W,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!E+6UA
M:6P@861D<F5S<R!Y;W4@=V%N="!A<W-O8VEA=&5D('=I=&@@>6]U<B!P97)S
M;VYA;"!K97ES+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UK97EL
M96YG=&@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E
M<G-O;F%L($ME>2`M($ME>6QE;F=T:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY+
M97EL96YG=&@\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!K97EL96YG
M=&@L(&EN(&)Y=&5S+"!O9B!Y;W5R(&=E;F5R871E9"!K97DN(%1H92!G<F5A
M=&5R('1H92!V86QU92P@=&AE(&=R96%T97(@=&AE('!R;W1E8W1I;VX@*&%N
M9"!A;'-O(&=R96%T97(@9V5N97)A=&EO;B!T:6UE(&%N9"!E;F-R>7!T:6]N
M('1I;64I+B`Q,#(T(&)Y=&5S(&ES('1H92!D969A=6QT("T@=&AI<R!V86QU
M92!P<F]V:61E<R!E>&-E;&QE;G0@<')O=&5C=&EO;BX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M
M<&%S<W!H<F%S92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A
M=&4@4&5R<V]N86P@2V5Y("T@4&%S<W!H<F%S93PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY.86UE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@<&%S<W!H
M<F%S92!U<V5D('1O('!R;W1E8W0O96YC<GEP="!Y;W5R('!E<G-O;F%L('!R
M:79A=&4@:V5Y+B!4:&ES('-H;W5L9"!B92!!5"!,14%35"`V(&-H87)A8W1E
M<G,L('-H;W5L9"!.3U0@8F4@=&AE('-A;64@87,@>6]U<B!L;V=I;B!P87-S
M=V]R9"P@<VAO=6QD($Y/5"!B92!B87-E9"!O;B!A(&1I8W1I;VYA<GD@=V]R
M9"P@86YD('-H;W5L9"!I;F-L=61E(&)O=&@@;G5M8F5R<R!A;F0@;&5T=&5R
M<RX@66]U(&UU<W0@96YT97(@=&AI<R!P87-S<&AR87-E('1W:6-E(&9O<B!V
M97)I9FEC871I;VX@<'5R<&]S97,N($$@<F5Q=6ER960@9FEE;&0N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM
M8W)E871E+6%C=&EO;G,B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@
M0W)E871E(%!E<G-O;F%L($ME>2`M($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE
M861I;F<^0W)E871E($ME>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-R
M96%T92!A;F0@<W1O<F4@>6]U<B!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY);7!O<G0@2V5Y<&%I<CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@26UP;W)T(&$@<&5R<V]N86PO<')I=F%T
M92!K97EP86ER+B!4:&ES(&)U='1O;B!O<&5N<R!A('=I;F1O=R!W:&5R92!Y
M;W4@8V%N(&UA;G5A;&QY(&EM<&]R="!Y;W5R(&5X:7-T:6YG(%!'4"!P97)S
M;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER+B`@5&AE(&ME>7,@8V%N(&5I
M=&AE<B!B92!P87-T960@:6YT;R!A('1E>'1F:65L9"!O<BP@:68@=&AE(&ME
M>7,@<F5S:61E(&EN(&$@9FEL92!O;B!Y;W5R(&QO8V%L(&-O;7!U=&5R+"!Y
M;W4@8V%N(&EM<&]R="!T:&5M+B`@268@=&AE(&ME>7,@87)E('9A;&ED('1H
M97D@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD
M('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O
M<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE
M=R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!/=F5R=FEE=SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY7:&%T(&ES(%,O34E-13\\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%,O34E-12!I<R!A('!R:79A=&4O<'5B;&EC(&ME
M>2!P86ER('-Y<W1E;2!W:&EC:"!P<F]V:61E<R!D:6=I=&%L('-I9VYA='5R
M97,L(&UE<W-A9V4@<')I=F%C>2P@86YD('1A;7!E<B!D971E8W1I;VX@:6X@
M82!O<&5N+"!I;G1E<F]P97)A8FQE('=A>2X@(%,O34E-12!C86X@<')O=FED
M92!M97-S86=E('!R:79A8WD@8GD@96YC<GEP=&EN9R!M97-S86=E<R!T:&%T
M(&]N;'D@=&AE('-E;F1E<B!A;F0@=&AE(&EN=&5N9&5D(')E8VEP:65N=',@
M8V%N(&1E8V]D92X@($ET(&%L;&]W<R!Y;W4@=&\@:61E;G1I9GD@=&AE('-E
M;F1E<B!O9B!A(&UE<W-A9V4@=FEA(&$@9&EG:71A;"!S:6=N871U<F4N("!4
M;V=E=&AE<BP@=&AI<R!E;F-R>7!T:6]N(&%N9"!D:6=I=&%L('-I9VYI;F<@
M:&5L<"!P<F]V:61E('1A;7!E<B!D971E8W1I;VXL(&%L;&]W:6YG(')E8VEP
M:65N=',@=&\@9&5T97)M:6YE('=H971H97(@82!M97-S86=E('=A<R!A;'1E
M<F5D(&%F=&5R(&ET('=A<R!S96YT+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@268@=&AI<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W
M:6QL(&)E(&%B;&4@=&\@:6UP;W)T('EO=7(@<&5R<V]N86P@4R]-24U%(&ME
M>7,L(')E860@96YC<GEP=&5D(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG
M;F5D(&UA:6PL(&%N9"!E;F-R>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E
M<G9I97<M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O
M34E-13H@4&5R<V]N86P@2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R
M=FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@>6]U('=A;G0@=&\@
M9&EG:71A;&QY('-I9VX@;W(@96YC<GEP="!M97-S86=E<R!Y;W4@;75S="!H
M879E('EO=7(@;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%,O34E-12!K
M97EP86ER+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI
M;64M:6UP;W)T+7!E<G-O;F%L+6-E<G1S(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y3+TU)344Z($EM<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+W1I
M=&QE/@H@("`@/&AE861I;F<^26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@26UP;W)T('!E<G-O;F%L(&-E
M<G1I9FEC871E<R!F<F]M(&$@4$M#4R`C,3(@9F]R;6%T(&9I;&4N(%!+0U,@
M(S$R(&9I;&5S(&ES('1H92!F:6QE('5S=6%L;'D@9V5N97)A=&5D('=H96X@
M97AP;W)T:6YG(&$@:V5Y(&9R;VT@82!B<F]W<V5R("AE+F<N($EN=&5R;F5T
M($5X<&QO<F5R+"!&:7)E9F]X*2!O<B!F<F]M(&$@8V5R=&EF:6-A=&4@<W1O
M<F4@;6%I;G1A:6YE9"!B>2!A;B!/<&5R871I;F<@4WES=&5M("AE+F<N(%=I
M;F1O=W,@6%`I+B!)9B!T:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E
M(&EN<V5R=&5D(&EN=&\@>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O
M=R!W:6QL(&-L;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@
M=VEL;"!B92!R971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+61E;&5T92UP97)S;VYA;"UC
M97)T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!$96QE=&4@
M4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH96%D:6YG/D1E
M;&5T92!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($1E;&5T92!Y;W5R('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M
M('EO=7(@<')E9F5R96YC97,N("!9;W4@=VEL;"!N;R!L;VYG97(@8F4@86)L
M92!T;R!S:6=N(%,O34E-12!M97-S86=E<R!O<B!V:65W(&%N>2!3+TU)344@
M96YC<GEP=&5D(&UE<W-A9V5S(&%D9')E<W-E9"!T;R!Y;W4N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z($UA;F%G92!0=6)L
M:6,@2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3+TU)344Z($UA;F%G92!0
M=6)L:6,@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@36%N86=E('EO
M=7(@4R]-24U%('!U8FQI8R!K97D@;&ES="X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&AE
M(')A=R!T97AT(&]F('1H92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5FEE
M=R!T96-H;FEC86P@9&5T86EL<R!O9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@1&5L971E<R!T:&4@<V5L96-T960@<'5B;&EC(&ME>2!F<F]M('-T
M;W)A9V4N("!$96QE=&EN9R!A('!U8FQI8R!K97D@9F]R(&$@=7-E<B!W:6QL
M('!R979E;G0@>6]U<B!F<F]M(&5N8W)Y<'1I;F<@82!M97-S86=E('1O('1H
M870@=7-E<BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M:6YT:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<FEN=&EN9SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY0<FEN="!A(&UE<W-A9V4\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1O('!R:6YT(&$@;65S<V%G92!Y;W4@87)E('9I97=I
M;F<L(&-L:6-K(&]N('1H92`B4')I;G0B(&QI;FL@870@96ET:&5R('1H92!T
M;W`@;W(@8F]T=&]M(&]F('1H92!M97-S86=E+B!4:&4@;65S<V%G92!W:6QL
M(&]P96X@:6X@82!N97<@=VEN9&]W(&9O<FUA=&5D(&9O<B!P<FEN=&EN9RX@
M($1E<&5N9&EN9R!O;B!Y;W5R('=E8B!B<F]W<V5R(&%N9"!O<&5R871I;F<@
M<WES=&5M+"!T:&4@<')I;G0@9&EA;&]G(&)O>"!M87D@;W!E;B!F;W(@>6]U
M+B`@268@:70@9&]E<R!N;W0@;W!E;BP@=&AE;B!P=6QL(&1O=VX@=&AE('=E
M8B!B<F]W<V5R)W,@(D9I;&4B(&UE;G4@86YD(&-H;V]S92`B4')I;G0B('1O
M(&]P96X@=&AE('!R:6YT(&1I86QO9R!B;W@N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)S;W)T:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y3;W)T:6YG(&%N9"!4:')E861I;F<\+W1I=&QE/@H@("`@/&AE861I
M;F<^4V]R=&EN9R!%;G1R:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!7
M:&5N('9I97=I;F<@82!L:7-T(&]F(&UE<W-A9V5S+"!Y;W4@8V%N('-O<G0@
M=&AE(&UE<W-A9V5S(&)Y(&%N>2!C;VQU;6X@8GD@8VQI8VMI;F<@;VX@=&AE
M(&%P<')O<')I871E(&-O;'5M;B!H96%D:6YG+B`@5&\@<W=I=&-H(&-O;'5M
M;G,@8F5T=V5E;B!A<V-E;F1I;F<@86YD(&1E<V-E;F1I;F<@;W)D97(L(&-L
M:6-K(&]N('1H92!A<G)O=R!I8V]N(&EN('1H92!C;VQU;6X@:&5A9&EN9RX*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E1H<F5A9&EN9SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&\@9W)O=7`@;65S<V%G97,@8GD@=&AR96%D<R`H
M<W5B:F5C="DL('-O(&5A8V@@;65S<V%G92!I<R!G<F]U<&5D('=I=&@@86QL
M(&ET<R!R97!L:65S+"!C;&EC:R!T:&4@6U1H<F5A9%T@;&EN:R!I;B!T:&4@
M<W5B:F5C="!C;VQU;6X@:&5A9&EN9RX@(%1O(')E='5R;B!T;R!N;W)M86P@
M<W5B:F5C="!S;W)T:6YG+"!C;&EC:R!O;B!T:&4@6U-U8FIE8W1=(&QI;FL@
M:6X@=&AE('-U8FIE8W0@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)A;'1E<FYA=&EV92UM<V<B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/DUU;'1I<&%R="]!;'1E<FYA=&EV92!-97-S86=E
M<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-O;64@;65S<V%G92!H879E(&)E
M96X@<V5N="!A<R!A(")M=6QT:7!A<G0O86QT97)N871I=F4B('1Y<&4@8GD@
M=&AE('-E;F1E<BX@5&AE<V4@;65S<V%G97,@:&%V92!S979E<F%L('!A<G1S
M+"!A;&P@9&ES<&QA>6EN9R!T:&4@4T%-12!#3TY414Y4(&)U="!I;B!$249&
M15)%3E0@1D]234%44RX@5&AE(&UA:6P@86=E;G0@=VEL;"!D:7-P;&%Y('1H
M92!L87-T('!A<G0@:6X@=&AE(&QI<W0@=&AA="!C86X@8F4@<W5C8V5S<V9U
M;&QY(&1I<W!L87EE9"!I;FQI;F4@:6X@=&AE(&)R;W=S97(L(&EF(&%N>2X@
M06QL(&]T:&5R(&9O<FUA=',@=VEL;"!A<'!E87(@=6YD97(@=&AE(&AE861I
M;F<@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXB(&%N9"!C
M86X@8F4@=FEE=V5D(&]R(&1O=VYL;V%D960@<V5P87)A=&5L>2X@270@:7,@
M:6UP;W)T86YT('1O(&YO=&4@=&AA="!T:&5S92!A;'1E<FYA=&EV92!P87)T
M<R!C;VYT86EN('1H92!304U%($-/3E1%3E13(&%S('1H92!P87)T('1H870@
M:7,@<VAO=VX@+2!T:&5Y(&%R92!S:6UP;'D@:6X@82!D:69F97)E;G0@;65D
M:6$@9F]R;6%T("AE+F<N('1E>'0@=G,N($A434P@;W5T<'5T*2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7)E;F%M95]S96YT
M;6%I;%]M;VYT:&QY(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z(%)E;F%M92!396YT+6UA:6P@1F]L9&5R($UO
M;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N
M(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(')E;F%M92!Y;W5R('-E;G0M;6%I
M;"!F;VQD97(@870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H
M92!F;VQD97(@=VEL;"!B92!R96YA;65D("AT;R!A(&YA;64@=&AA="!C;VYT
M86EN<R!T:&4@;6]N=&@@86YD('EE87(I(&%N9"!A(&YE=R!S96YT+6UA:6P@
M9F]L9&5R('=I;&P@8F4@8W)E871E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z($1E;&5T92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L
M9"!L:6ME('1O(&1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@=&AE
M(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H:7,@;6%Y(&)E('5S969U
M;"!I9B!Y;W4@:&%V92!A('%U;W1A+"!F;W(@97AA;7!L92X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]S96YT;6%I
M;%]M;VYT:&QY7VME97`B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E(%-E;G0M;6%I;"!&;VQD97(@
M36]N=&AL>2`M(",@;V8@1F]L9&5R<R!T;R!+965P/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O;&0@<V5N="UM86EL(&9O
M;&1E<G,@979E<GD@;6]N=&@L(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@9F]L
M9&5R<R!D;R!Y;W4@('=A;G0@=&\@:V5E<#\@($%N>2!F;VQD97)S(&]L9&5R
M('1H86X@=&AI<R!M86YY(&UO;G1H<R!W:6QL(&)E(&1E;&5T960N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T
M86-H;65N='-?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE
M;G1S($UO;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@
M;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(&1E;&5T92!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N
M=&@N("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@
M9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL>5]K965P(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($1E;&5T92!,:6YK960@071T86-H;65N=',@36]N=&AL>2`M(",@;V8@36]N
M=&AS('1O($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E
M(&1E;&5T:6YG(&]L9"!L:6YK960@871T86-H;65N=',@979E<GD@;6]N=&@L
M(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@871T86-H;65N=',@9&\@>6]U("!W
M86YT('1O(&ME97`_("!!;GD@871T86-H;65N=',@;VQD97(@=&AA;B!T:&ES
M(&UA;GD@;6]N=&AS('=I;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U
M<F=E(%1R87-H/"]T:71L93X*("`@(#QP87)A/@H@("`@1&\@>6]U('=A;G0@
M=&\@<'5R9V4@>6]U<B!T<F%S:"!F;VQD97(@979E<GD@<V\@;V9T96XN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T
M<F%S:%]I;G1E<G9A;"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:"!);G1E<G9A;#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@<'5R9VEN9R!Y;W5R('1R
M87-H(&9O;&1E<BP@:&]W(&]F=&5N('-H;W5L9"!I="!B92!P=7)G960_"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T
M<F%S:%]K965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@36%I;G1E;F%N8V4Z(%!U<F=E(%1R87-H($ME97`\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD
M97(L(&UE<W-A9V4@;VQD97(@=&AA;B!H;W<@;6%N>2!D87ES('-H;W5L9"!B
M92!P=7)G960_"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUA='1R:6)?=&5X="(@<W1A=&4](FYE=R(^"B`@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-97-S86=E($-O;7!O<VET:6]N.B!!='1R:6)U=&EO;B!4
M97AT/"]T:71L93X*("`@("`\<&%R83X*("`@("!(97)E('EO=2!C86X@96YT
M97(@=&AE('!H<F%S92!T:&%T('EO=2!W:7-H('1O(&%P<&5A<B!B969O<F4@
M86YY('%U;W1E9"!T97AT(&EN(&$@<F5P;'D@=&AA="!Y;W4@<V5N9"X*("`@
M("`\+W!A<F$^"B`@("`@/'!A<F$^"B`@("`@66]U(&-A;B!I;F-L=61E(&]N
M92!O<B!M;W)E('-P96-I86P@<&QA8V5H;VQD97)S('1O(&EN<V5R="!I;F9O
M<FUA=&EO;B!A8F]U="!T:&4@;65S<V%G92!T;R!W:&EC:"!Y;W4@87)E(')E
M<&QY:6YG+B!0;&%C96AO;&1E<G,@8V]N<VES="!O9B!A("<E)R!F;VQL;W=E
M9"!B>2!A('-I;F=L92!L971T97(N(%1H92!F;VQL;W=I;F<@<&QA8V5H;VQD
M97)S(&%R92!A=F%I;&%B;&4Z"B`@("`@/"]P87)A/@H*("`@("`\<&%R83X@
M)68@.B!4:&4@<V5N9&5R)W,@;F%M92!A;F0@96UA:6P@861D<F5S<SPO<&%R
M83X*("`@("`\<&%R83X@)6$@.B!4:&4@<V5N9&5R)W,@96UA:6P@861D<F5S
M<SPO<&%R83X*("`@("`\<&%R83X@)7`@.B!4:&4@<V5N9&5R)W,@;F%M93PO
M<&%R83X*("`@("`\<&%R83X@)7(@.B!4:&4@9G5L;"!21D,@,C@R,B!S='EL
M92!D871E(&%N9"!T:6UE('IO;F4\+W!A<F$^"B`@("`@/'!A<F$^("5D(#H@
M5&AE(&1A=&4@87,@=W=W+"!D9"!M;6T@65E963PO<&%R83X*("`@("`\<&%R
M83X@)7@@.B!4:&4@9&%T92!I;B!T:&4@;&]C86QE)W,@9&5F875L=#PO<&%R
M83X*("`@("`\<&%R83X@)6,@.B!4:&4@9&%T92!A;F0@=&EM92!I;B!T:&4@
M;&]C86QE)W,@9&5F875L=#PO<&%R83X*("`@("`\<&%R83X@)6T@.B!4:&4@
M365S<V%G92U)1#PO<&%R83X*("`@("`\<&%R83X@)7,@.B!4:&4@<W5B:F5C
M=#PO<&%R83X*("`@("`\<&%R83X@)6X@.B!!(&YE=R!L:6YE/"]P87)A/@H@
M("`@(#QP87)A/B`E)2`Z(%1H92`G)2<@8VAA<F%C=&5R/"]P87)A/@H*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?
M<F5A9"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E
M<75E<W0@4F5A9"!296-E:7!T<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(")2
M97%U97-T(&$@4F5A9"!296-E:7!T(B!S96YD<R!A(')E<75E<W0@=&\@=&AE
M(')E8VEP:65N=',@;V8@=&AI<R!M97-S86=E('1O(&YO=&EF>2!Y;W4@=VAE
M;B!T:&ES(&UE<W-A9V4@:7,@;W!E;F5D(&)Y('1H92!R96-I<&EE;G1S+B!.
M;W0@86QL(&-L:65N=',@<W5P<&]R="`O(&AO;F]R('1H:7,N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S
M96YD7VUD;B(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M(%-E;F0@341./"]T:71L93X*("`@(#QP87)A/@H@("`@(E-E;F0@82!-1$XB
M('-E;F1S(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@*&%L
M<V\@:VYO=VX@87,@82!R96%D(')E8V5I<'0I('=H96X@>6]U('9I97<@82!M
M97-S86=E(&EN('=H:6-H('1H92!U<V5R(&AA<R!R97%U97-T960@=&AA="!T
M:&5Y(')E8V5I=F4@;F]T:69I8V%T:6]N('1H870@>6]U(&AA=F4@<F5A9"!T
M:&4@;65S<V%G92X@26X@;6]S="!C87-E<RP@=&AI<R!W:6QL(&AA<'!E;B!A
M=71O;6%T:6-A;&QY('=I=&AO=70@<')O;7!T:6YG('EO=2X@26X@8V5R=&%I
M;B!I<V]L871E9"!C87-E<RP@>6]U(&UA>2!H879E('1O(&UA;G5A;&QY(&1E
M8VED92!T;R!S96YD('1H92!N;W1I9FEC871I;VX@8GD@8VQI8VMI;F<@;VX@
M82!L:6YK+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]D96QI=F5R>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E<75E<W0@1&5L:79E<GD@0V]N
M9FER;6%T:6]N/"]T:71L93X*("`@(#QP87)A/@H@("`@(E)E<75E<W0@1&5L
M:79E<GD@0V]N9FER;6%T:6]N(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!S97)V97(@=&\@;F]T:69Y('EO=2!W:&5N(&ET
M(&AA<R!D96QI=F5R960@=&AE(&UE<W-A9V4@=&\@=&AE(')E8VEP:65N="=S
M(&UA:6QB;W@N($ET(&1O97-N)W0@;65A;B!T:&4@;65S<V%G92!H87,@8F5E
M;B!S965N+"!J=7-T('1H870@:70G<R!S:71T:6YG(&EN(&$@;6%I;&)O>"!S
M;VUE=VAE<F4N($YO="!A;&P@;6%I;"!S97)V97)S('-U<'!O<G0@=&AI<RX@
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE
M=&5?<W!A;5]A9G1E<E]R97!O<G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!$96QE=&4@4W!A;2!!9G1E<B!297!O<G1I;F<\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y(&5L96-T('1O(&1O(&]N92!O
M9B!T:')E92!I=&5M<R!A9G1E<B!R97!O<G1I;F<@82!M97-S86=E(&%S(&5I
M=&AE<B!S<&%M(&]R(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("!&:7)S="P@>6]U(&-A;B!D96-I9&4@=&\@9&\@;F]T:&EN9R`M('1H
M92!M97-S86=E('=I;&P@8F4@<F5P;W)T960@87,@96ET:&5R('-P86T@;W(@
M:6YN;V-E;G0@8G5T('=I;&P@;W1H97)W:7-E(')E;6%I;B!U;F-H86YG960@
M:6X@>6]U<B!M86EL8F]X+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3
M96-O;F0L(&EF(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@<W!A;2P@>6]U(&-A
M;B!I;G-T96%D(&AA=F4@=&AE(&UE<W-A9V4@8F4@:6UM961I871E;'D@9&5L
M971E9"X@(%1H:7,@<V5T=&EN9R!H87,@;F\@969F96-T(&]N(')E<&]R=&EN
M9R!A(&UE<W-A9V4@87,@:6YN;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@(%1H:7)D+"!A9G1E<B!R97!O<G1I;F<@82!M97-S86=E(&%S('-P
M86T@=&AE(&UE<W-A9V4@=VEL;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E
M;G0@;6%I;&)O>"!A;F0@;6]V960@=&\@>6]U<B!S<&%M(&9O;&1E<BX@($%L
M=&5R;F%T:79E;'DL(&EF(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN;V-E
M;G0@=&AE(&UE<W-A9V4@=VEL;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E
M;G0@;6%I;&)O>"!A;F0@;6]V960@=&\@>6]U<B!)3D)/6"X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6AT;6Q?:6UA9V5?<F5P
M;&%C96UE;G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!(5$U,($EM86=E(%)E<&QA8V5M96YT/"]T:71L93X*("`@(#QP87)A/@H@
M("`@1F]R($A434P@;65S<V%G97,@9&ES<&QA>65D(&EN;&EN92P@<VAO=6QD
M(&%L;"!I;6%G92!T86=S(&)E(&)L;V-K960@=6YT:6P@>6]U('-P96-I9FEC
M86QL>2!D96-I9&4@=&\@=FEE=R!T:&]S92!I;6%G97,_($YO=&4@=&AA="P@
M:68@=FEE=VEN9R!A;B!(5$U,(&%T=&%C:&UE;G0L('1H92!I;6%G97,@=VEL
M;"!A;'=A>7,@8F4@9&ES<&QA>65D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]A9&1R8F]O:R(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P
M;&%C96UE;G0O061D<F5S<V)O;VL@4VAO=SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF(&)L;V-K:6YG(&EM86=E<R!F;W(@:6YL:6YE($A434P@;65S<V%G
M97,L('-H;W5L9"!W92!A=71O;6%T:6-A;&QY(&1I<W!L87D@=&AE;2!I;G-T
M96%D(&EF('1H92!S96YD97(@87!P96%R<R!I;B!Y;W5R(&%D9')E<W-B;V]K
M/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M;6%I
M;&)O>%]S=&%R="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6QB;W@@4W1A<G0@4&%G93PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($1E=&5R;6EN97,@=VAI8V@@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W('=I
M;&P@8F4@9&ES<&QA>65D('=H96X@>6]U(&%C8V5S<R!A(&UA:6QB;W@@9F]R
M('1H92!F:7)S="!T:6UE+B!.;W1E('1H870@=&AE("=U;G-E96XG(&UE<W-A
M9V4@;W!T:6]N<R!D;R!N;W0@=V]R:R!W:71H('1H92`G5&AR96%D)R!S;W)T
M:6YG(&]P=&EO;B`M(&EN<W1E860L('EO=2!W:6QL(&)E('-E;G0@=&\@=&AE
M(&QA<W0@<&%G92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+7-A=F5?871T86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!3879E($%T=&%C:&UE;G1S(&]N(%-E;G0@365S
M<V%G97,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!S879I;F<@82!C;VUP
M;W-E9"!M97-S86=E(&EN(&$@<V5N="UM86EL(&9O;&1E<BP@9&5T97)M:6YE
M(&EF(&%L;"!A='1A8VAM96YT(&1A=&$@:7,@<V%V960N(%1H92!F;VQL;W=I
M;F<@;W!T:6]N<R!A<F4@879A:6QA8FQE.@H@("`@/"]P87)A/@H*("`@(#QP
M87)A/BH@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP
M="!T;R!S879E(&%T=&%C:&UE;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@
M871T86-H;65N=',@87)E($%,5T%94R!S879E9"!W:71H('1H92!M97-S86=E
M+CPO<&%R83X*("`@("`\<&%R83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453(B`M($%,5T%94R!P
M<F]M<'0@=&\@<V%V92!A='1A8VAM96YT<R!I;B!T:&4@8V]M<&]S92!S8W)E
M96X[('1H92!D969A=6QT(&ES('1O('-A=F4@871T86-H;65N=',N/"]P87)A
M/@H@("`@(#QP87)A/BH@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE
M;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(@+2!!3%=!65,@<')O;7!T('1O
M('-A=F4@871T86-H;65N=',@:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@
M9&5F875L="!I<R!T;R!N;W0@<V%V92!A='1A8VAM96YT<RX\+W!A<F$^"B`@
M("`@/'!A<F$^*B`B3F5V97(@<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P
M<F]M<'0@=&\@<V%V92!A='1A8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@
M=&AE(&%T=&%C:&UE;G1S(&%R92!.159%4B!S879E9"!W:71H('1H92!M97-S
M86=E+CPO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U86Q?:6YB
M;W@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E9I<G1U86P@1F]L9&5R<SH@
M5FER='5A;"!);F)O>#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%9I<G5T86P@
M26YB;W@@:7,@82!S879E9"!S96%R8V@@=&AA="!D;V5S(&%W87D@=VET:"!T
M:&4@;F5E9"!T;R!S96%R8V@@979E<GD@;6%I;&)O>"!F;W(@;65S<V%G97,@
M;6%R:V5D(&%S(&YE=RX@($EN<W1E860L(&%L;"!C=7)R96YT;'D@<W5B<V-R
M:6)E9"!M86EL8F]X97,@87)E('-E87)C:&5D(&9O<B!N97<@;65S<V%G97,@
M86YD('1H92!R97-U;'1S(&%R92!D:7-P;&%Y960@:6X@82!S:6YG;&4@;6%I
M;&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U
M86Q?=')A<V@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E9I<G1U86P@1F]L
M9&5R<SH@5FER='5A;"!4<F%S:#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%9I
M<G1U86P@5')A<V@@:7,@82!S879E9"!S96%R8V@@=&AA="!D;V5S(&%W87D@
M=VET:"!T:&4@;F5E9"!F;W(@82!S97!A<F%T92!4<F%S:"!F;VQD97(N("!)
M;G-T96%D(&]F(&UO=FEN9R!M97-S86=E<R!T;R!A(&-E;G1R86QI>F5D('1R
M87-H(&9O;&1E<BP@;65S<V%G97,@87)E('-I;7!L>2!M87)K960@87,@9&5L
M971E9"!I;B!T:&4@8W5R<F5N="!F;VQD97(@=&AE>2!L:79E(&EN+B`@5VAE
M;B`G<VAO=R!D96QE=&5D(&UE<W-A9V5S)R!I<R!T=7)N960@;V9F+"!T:&ES
M(')E<W5L=',@:6X@=&AE<V4@;65S<V%G97,@;F]T(&%P<&5A<FEN9R!I;B!A
M(&UA:6QB;W@@=FEE=RX@(%=H96X@82!U<V5R(&-L:6-K<R!O;B!6:7)T=6%L
M(%1R87-H+"`J86QL*B!M86EL8F]X97,@86QL('-E87)C:&5D(&9O<B!M97-S
M86=E<R!T:&%T(&%R92!F;&%G9V5D(&1E;&5T960@86YD('1H97-E(&UE<W-A
M9V5S(&%R92!D:7-P;&%Y960@:6X@82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]G
M;%]%4R\`````````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,3<T-#(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O;&]C86QE+V=L7T53+TQ#7TU%4U-!1T53+P``````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S`#`R,3(R-P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O9VQ?15,O3$-?3453
M4T%'15,O:6UP+FUO````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C0W,S$`,3`T
M,3<S-C(W-C,`,#(R,S8Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-X2!)4`````<P$``!P```"T"P``\P$``$P7````````
M&!\```H````9'P``"@```"0?```*````+Q\```H````Z'P``!````$4?```!
M````2A\``!<```!,'P``*````&0?```R````C1\``#(```#`'P``&P```/,?
M```N````#R```#<````^(```?````'8@```<````\R```!T````0(0``"```
M`"XA```%````-R$```@````](0``!P```$8A```,````3B$```4```!;(0``
M`P```&$A``!.````92$``%````"T(0``0@````4B```?````2"(```@```!H
M(@``$0```'$B```A````@R(``#L```"E(@``*P```.$B```,````#2,```D`
M```:(P``!@```"0C```*````*R,```L````V(P``$0```$(C```*````5",`
M``,```!?(P``"````&,C```)````;",```0```!V(P``!````'LC```&````
M@",```X```"'(P``%0```)8C```^````K",```(```#K(P``"@```.XC```&
M````^2,```H`````)```8@````LD``!?````;B0``!P```#.)```#@```.LD
M```,````^B0```T````')0``#````!4E```4````(B4```\````W)0``!P``
M`$<E```F````3R4``%P```!V)0``!````-,E```'````V"4```X```#@)0``
M*0```.\E```&````&28```T````@)@``&@```"XF```=````228``!D```!G
M)@``70```($F```H````WR8```(````()P``!0````LG```$````$2<``!``
M```6)P``&0```"<G```:````02<```8```!<)P``$````&,G```S````="<`
M``<```"H)P``$````+`G```<````P2<```H```#>)P``%````.DG```O````
M_B<```\````N*```!P```#XH```/````1B@``"@```!6*```(P```'\H```F
M````HR@``"````#**```!````.LH```2````\"@```4````#*0``#@````DI
M```$````&"D``!8````=*0``!0```#0I```-````.BD```\```!(*0``$@``
M`%@I```-````:RD``!4```!Y*0``*0```(\I```L````N2D``"@```#F*0``
M!0````\J```0````%2H``!`````F*@``#P```#<J```+````1RH```\```!3
M*@``#````&,J```/````<"H```H```"`*@``$@```(LJ```-````GBH```P`
M``"L*@``/0```+DJ```>````]RH``"$````6*P```P```#@K```'````/"L`
M``0```!$*P``"@```$DK```0````5"L```<```!E*P``"````&TK```9````
M=BL```0```"0*P``#````)4K```$````HBL```0```"G*P``#````*PK```1
M````N2L```P```#+*P``"@```-@K```%````XRL```4```#I*P``!@```.\K
M```*````]BL```D````!+```$@````LL```2````'BP``!`````Q+```)```
M`$(L```(````9RP```D```!P+```$````'HL```&````BRP```P```"2+```
M!P```)\L```+````IRP```(```"S+```!P```+8L```(````OBP``#<```#'
M+```#P```/\L```'````#RT``!,````7+0``#````"LM```.````."T```P`
M``!'+0``#@```%0M```/````8RT```T```!S+0``#P```($M```F````D2T`
M``L```"X+0``!@```,0M```'````RRT```0```#3+0``!````-@M```%````
MW2T```,```#C+0``"````.<M```,````\"T```0```#]+0``#`````(N```)
M````#RX```(````9+@``&0```!PN```2````-BX```X```!)+@``!````%@N
M```+````72X```D```!I+@``#0```',N```,````@2X``!0```".+@``%@``
M`*,N```%````NBX``#P```#`+@```@```/TN```,`````"\``",````-+P``
M!P```#$O```1````.2\```T```!++P``#0```%DO```'````9R\```@```!O
M+P``'@```'@O```H````ER\```@```#`+P``%````,DO```%````WB\``#$`
M``#D+P``*````!8P```:````/S```"@```!:,```*0```(,P```N````K3``
M`#8```#<,```+````!,Q```Q````0#$``!````!R,0``#0```(,Q```%````
MD3$``!,```"7,0``#0```*LQ```6````N3$``#X```#0,0``"`````\R```0
M````&#(``!4````I,@``$P```#\R```'````4S(``!4```!;,@``"P```'$R
M```6````?3(```L```"4,@``+@```*`R```Z````SS(```T````*,P``!0``
M`!@S```,````'C,```T````K,P``"@```#DS```&````1#,```X```!+,P``
M!0```%HS```&````8#,``$L```!G,P``"@```+,S```'````OC,``#D```#&
M,P``!@`````T```.````!S0```0````6-```!@```!LT```*````(C0```L`
M```M-```&@```#DT```7````5#0``!<```!L-```&P```(0T```?````H#0`
M``P```#`-```$P```,TT```1````X30```8```#S-```0P```/HT```Y````
M/C4```P```!X-0``$0```(4U```@````ES4```0```"X-0``$````+TU```7
M````SC4``!(```#F-0``"P```/DU```-````!38``!0````3-@``+P```"@V
M```'````6#8```T```!@-@``%@```&XV```'````A38```L```"--@``!0``
M`)DV```$````GS8``#,```"D-@``'@```-@V``!U````]S8``#X```!M-P``
M0@```*PW```]````[S<``#T````M.```*0```&LX```I````E3@``#$```"_
M.```*````/$X```F````&CD``#X```!!.0``1P```(`Y``!7````R#D``%4`
M```@.@``+P```'8Z``!5````ICH``"L```#\.@``.P```"@[```/````9#L`
M`"$```!T.P``'````)8[```+````LSL```4```"_.P```@```,4[```-````
MR#L```,```#6.P``(````-H[```F````^SL```H````B/```$P```"T\```(
M````03P``!8```!*/```#````&$\```'````;CP```8```!V/```&@```'T\
M```1````F#P```P```"J/```"````+<\```'````P#P``"<```#(/```!P``
M`/`\```&````^#P```T```#_/```"P````T]``!:````&3T```P```!T/0``
M"@```($]```"````C#T```8```"//0```P```)8]```A````FCT``"0```"\
M/0``'0```.$]```9````_ST``!<````9/@``*@```#$^```K````7#X``$4`
M``"(/@``)P```,X^```A````]CX``"L````8/P``'0```$0_```]````8C\`
M`$$```"@/P``*````.(_```L````"T```#`````X0```$````&E````?````
M>D````\```":0```#````*I````0````MT````\```#(0```!````-A````$
M````W4````(```#B0```#@```.5````/````]$````4````$00``3@$```I!
M```*````64(```D```!D0@``"@```&Y"```)````>4(```0```"#0@```0``
M`(A"```6````BD(``"H```"A0@``,P```,Q"```Q`````$,``!L````R0P``
M+P```$Y#```^````?D,``(<```"]0P``(````$5$```?````9D0```@```"&
M1```!0```(]$```.````E40```@```"D1```$P```*U$```&````P40```4`
M``#(1```6````,Y$``!F````)T4``$D```".10``)````-A%```*````_44`
M`!0````(1@``)@```!U&```Z````1$8``"\```!_1@``$P```*]&```*````
MPT8```D```#.1@``%````-A&```&````[48``!,```#T1@``#0````A'```#
M````%D<```L````:1P``"P```"9'```%````,D<```4````X1P``"````#Y'
M```2````1T<``!\```!:1P``*@```'I'```"````I4<```X```"H1P``!P``
M`+='```/````OT<``%X```#/1P``90```"Y(```A````E$@``!,```"V2```
M#P```,I(```0````VD@``!$```#K2```'````/U(```4````&DD```@````O
M20``)P```#A)``!)````8$D```8```"J20``"````+%)```/````NDD``#(`
M``#*20``!0```/U)```1`````TH``!8````52@``*````"Q*```B````54H`
M`'<```!X2@``00```/!*```"````,DL```L````U2P``!````$%+```9````
M1DL``"D```!@2P``)0```(I+```(````L$L``!4```"Y2P``/P```,]+```)
M````#TP``!,````93```'0```"U,```+````2TP``!8```!73```+P```&Y,
M```4````GDP```H```"S3```&````+Y,```P````UTP``#$````(30``*P``
M`#I-```;````9DT```4```""30``%@```(A-```(````GTT``!@```"H30``
M!@```,%-```<````R$T``!(```#E30``'@```/A-```8````%TX``!P````P
M3@``#@```$U.```8````7$X``#````!U3@``,P```*9.```I````VDX```0`
M```$3P``#P````E/```0````&4\```X````J3P``%0```#E/```/````3T\`
M``L```!?3P``$P```&M/```)````?T\``!P```")3P``$P```*9/```1````
MND\``$H```#,3P``(P```!=0```C````.U````,```!?4```!P```&-0```&
M````:U````\```!R4```&````()0```(````FU````D```"D4```&@```*Y0
M```"````R5```!4```#,4```!@```.)0```%````Z5```!4```#O4```&0``
M``51```3````'U$``!,````S40``!0```$=1```%````35$```<```!340``
M#P```%M1```*````:U$``!0```!V40``$P```(M1```2````GU$``"@```"R
M40``!@```-M1```-````XE$``!@```#P40``!@````E2```+````$%(```\`
M```<4@``&P```"Q2```"````2%(```\```!+4@``#````%M2```Y````:%(`
M`!8```"B4@``!P```+E2```5````P5(```\```#74@``$0```.=2```5````
M^5(``!<````/4P``&0```"=3```1````05,``!8```!34P``,````&I3```*
M````FU,```D```"F4P``#````+!3```%````O5,```0```##4P``!0```,A3
M```$````SE,```L```#34P``#@```-]3```(````[E,``!````#W4P``#P``
M``A4```#````&%0``!\````<5```&P```#Q4```2````6%0```@```!K5```
M#0```'14```1````@E0``!````"45```#0```*54```7````LU0``!@```#+
M5```!0```.14``!2````ZE0```@````]50``#P```$95```Q````5E4```<`
M``"(50``$0```)!5```.````HE4```\```"Q50``"````,%5```/````RE4`
M`"$```#:50``-P```/Q5```'````-%8``!,````\5@``"````%!6``!$````
M658``"(```">5@``%@```,%6```>````V%8``"\```#W5@``+0```"=7```Y
M````55<``#H```"/5P``+0```,I7```0````^%<```\````)6```"````!E8
M```6````(E@```\````Y6```)````$E8```W````;E@```P```"F6```%P``
M`+-8```:````RU@``!L```#F6```"@````)9```A````#5D``!`````O60``
M%@```$!9```+````5UD``#X```!C60``1P```*)9```/````ZED```D```#Z
M60``%0````1:```6````&EH```X````Q6@``"@```$!:```N````2UH```D`
M``!Z6@``"````(1:``!7````C5H``!$```#E6@``"P```/=:```_`````UL`
M``8```!#6P``$P```$I;```%````7EL```L```!D6P``$P```'!;```2````
MA%L``"$```"76P``'0```+E;```=````UUL``"4```#U6P``%````!M<```0
M````,%P``!T```!!7```'P```%]<```(````?UP``%4```"(7```0P```-Y<
M```5````(ET``"(````X70``+P```%M=```&````BUT``!,```"270``'P``
M`*9=```4````QET``!8```#;70``%0```/)=```?````"%X``#,````H7@``
M!@```%Q>```/````8UX``!P```!S7@``#0```)!>```*````GEX```<```"I
M7@``!0```+%>```R````MUX``!D```#J7@``>`````1?```]````?5\``$(`
M``"[7P``/0```/Y?``!!````/&```"D```!^8```+````*A@```Y````U6``
M`"8````/80``)P```#9A``!2````7F$``$\```"Q80``5@````%B``!6````
M6&(``#````"O8@``5````.!B```H````-6,``$(```!>8P``#@```*%C```B
M````L&,``!L```#38P``#````.]C```&````_&,```0````#9```!0````AD
M```#````#F0``"H````29```+P```#UD```-````;60``!8```![9```"0``
M`))D```F````G&0``!,```##9```"````-=D```)````X&0``"D```#J9```
M(````!1E```2````-64```<```!(90``!@```%!E```_````5V4```4```"7
M90``#````)UE```0````JF4```T```"[90``5````,EE```4````'F8``!0`
M```S9@```@```$AF```*````2V8```(```!69@``'P```%EF```N````>68`
M`"0```"H9@``%@```,UF```3````Y&8``"4```#X9@``*0```!YG```N````
M2&<``"D```!W9P``(````*%G```M````PF<``"H```#P9P``.0```!MH```^
M````56@``"(```"4:```)P```+=H```\````WV@``!$````<:0``'P```"YI
M```)````3FD```P```!8:0``%0```&5I```/````>VD```(```"+:0``!@``
M`(YI```"````E6D``!(```"8:0``$P```*MI```9````OVD```$```!%````
M``````T!``"9````H@```%<!```@`0```````)8``````````````#8````8
M`````````!$```"J````7`$``!T```"_````'P```%\```#R``````````\!
M``!,`````````&<!````````2`$``$,!``#N````````````````````!P``
M`(8````I`0```````%0!``!O`0``K0```&L!````````PP`````````)````
MDP```,8```!Y``````````````"Y```````````````%````;`$``/````!J
M`0``!@$``'L```#J````<@```",````&````.0```+4`````````!````)4`
M``!%`0``4`$``!D!``#!````+`$``"P````<````-P$``&D````/````M@``
M`!P!````````[P```%,```#-````.@$``$0````6````#@````P!````````
M@P`````!`````````````%(```!E`0```````"L!```D``````````````!&
M`0```````-$````H`0```````%,!``"1````ZP```$\!````````M`````L!
M``"<````*0```!4```"K````A````+L```!`````$````-X```#"````````
M`!D````?`0``"P```!T!```(````@0```#T!``#D````]````'$```#;````
MU0```/D`````````$P$``&<````K````4````&,!``#<````F`````````#6
M`````````,P`````````-`$``#P````G`0``3@$``*4`````````30``````
M```:````"@$``#<```#9````.0$```````!K````=0`````````7`0``````
M`(T```!@````,@```/\`````````%0$```````!=`0``"@```%D!``"F````
M`````%@````0`0``J0``````````````R0```!X`````````EP```%X!```F
M`0``:````&T````-````X0`````````N`````````"$!``!!`0```````.``
M``#:````.P```````````````````"0!````````I````"X!````````6P``
M`(@````P`````````*@````2`0```````'$!``!\````:@````````!'`0``
M5@$``-@```#H`````````"\```!,`0```````&8!```7````+0$``'(!``#B
M````2@$`````````````.@`````````%`0``=````+(````B````>````%$`
M```U````,0```+``````````C````&@!``#(````HP```*P````U`0``;@$`
M`$0!```#`0```````$D!``!:`0`````````````2````E````(\`````````
M_@```$X````;`0``C@```'````#?``````````````#=````O@```&P```!5
M`````````&T!```!`0``#@$``)T````'`0``QP````````#2````Y@```'`!
M````````2````)X`````````(````.T```#Q````[````"\!```P`0``80$`
M``````!F`````````$$`````````H0```#\```!2`0``+0```#P!```3````
MK@```$L!``````````````0!``"?``````````````!_````1@```#8!``#S
M`````````$,```!=````Q0```+H````B`0``<P$`````````````UP``````
M``#/````L0```%\!``"`````*@````P```!1`0``&@$``#(!``!>````?0``
M``````"X````S@````````#*`````````.,```""`````````#,!``"\````
M-`````(```!+`````````-0```!D````]0``````````````0@```#\!``"S
M`````````#@`````````%````%L!``"'````````````````````.P$`````
M```1`0``<P```,0```!5`0```````%P```!E````]@```/L````6`0``````
M`'8```!O````80```%8```!)````60```&X`````````'@$`````````````
M`````$<```!4`````````!@!```]````Y0``````````````6`$``#$!````
M``````````,``````````````&,````^`0``B0```%<````4`0``3P``````
M``!``0```````-````!"`0````````````"0````IP```&D!```;````B@``
M````````````30$``"@```#]`````````"4````S````"0$``%H`````````
MA0`````````(`0``O0```)H```";````*@$``/@````C`0``KP```'<```!Z
M````_````,````!*`````````"4!``"2`````````.<```!B````?@```,L`
M```A`````````"8``````````````(L```#I````)P``````````````````
M``(!````````8`$``#X```!D`0``.`$```````#3````]P```&(!``#Z````
MH````+<`````("`@("`@5&\Z(``@("`@1&%T93H@`"`@("!&<F]M.B``(%-U
M8FIE8W0Z(``@:6X@`",`)60@=&\@)60@;V8@)60@365S<V%G97,`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!A;')E861Y
M(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA;65D+@`E<R!F
M;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H
M+@`E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"D`*$%P<&QY('1H97-E(&-H
M86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*0`H1&ES8V%R9"!A;&P@
M8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI`"A2
M971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L
M;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R
M96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@
M8GD@8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@
M*@`R-"!H;W5R<P!!32]030!!9&0@<&%I<@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!;&EA<P!!;&P`06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L
M9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z
M`$%L;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@
M)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@
M<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL
M;"!B92!D96QE=&5D+@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M`$%N<W=E<F5D`$%N<W=E<F5D(&UE<W-A9V5S`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!D;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$52
M34%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@96UP='D@=&AI<R!F;VQD97(_`$%R<FEV86P@5&EM90!!
M<V-E;F1I;F<`071T86-H`$%T=&%C:&UE;G0`071T86-H;65N=',`079A:6QA
M8FQE(&9I96QD<SH`0F%C:R!T;R`E<P!"8V,`0FER=&AD87D`0FQA8VML:7-T
M`$)O9'D`0F]T:`!#86YC96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N
M96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N`$-C`$-E;&P@4&AO;F4`0VAA
M;F=E`$-H86YG92!!;&P`0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S
M(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"!H
M;W<@;65S<V%G97,@87)E('-O<G1E9"X`0VAA;F=E('1H92!N86UE+"!A9&1R
M97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;"X`0VAE8VL@1F]L9&5R*',I
M(&9O<B!.97<@36%I;`!#:&]O<V4@06-T:6]N.@!#;&]S92!7:6YD;W<`0VQO
M<V5D($9O;&1E<@!#;VQL87!S92!!;&P`0V]L;&%P<V4@06QL($9O;&1E<G,`
M0V]L;&%P<V4@1F]L9&5R`$-O;7!A;GD`0V]M<&]S92!M97-S86=E<R!I;B!A
M('-E<&%R871E('=I;F1O=S\`0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@
M8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@
M>6]U('=H96X@:70@87)R:79E<RX`0V]P>0!#;W)R96-T`$-O<G)E8W1E9"!4
M97AT`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M`$-R96%T90!#<F5A=&4@1F]L9&5R`$-R96%T92!A(&YE=R!D<F%F=',@9F]L
M9&5R`$-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE
M=R!T<F%S:"!F;VQD97(`0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A
M;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S
M+"!A;F0@9&5L971E('-P86TN`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O
M;B!L;V=O;B!T;R`E<RX`1$0`1&%I;'D`1&%T90!$969A=6QT($ED96YT:71Y
M`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I
M<F5C=&EO;CH`1&5L971E`$1E;&5T92!&;VQD97(H<RD`1&5L971E(&]L9"!S
M96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T
M960`1&5L971E9"!M97-S86=E<P!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A
M9V5S`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&EM('-I
M9VYA='5R97,_`$1I<W!L87D`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@<&]P
M+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\`1&\@3F]T($-H96-K($9O
M;&1E<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E
M<C\`1&]N90!$;W=N;&]A9"!&;VQD97(H<RD`1')A9G0`1')A9G1S(&9O;&1E
M<CH`161I=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5M86EL`$5M86EL($%D
M9')E<W,`16UP='D@1F]L9&5R*',I`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T
M>2!R97-U;'0N`$5N9"!F;W)W87)D960@;65S<V%G90!%;G1E<B!T:&4@;F%M
M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R`$5R<F]R`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AP86YD($%L;`!%>'!A;F0@06QL($9O;&1E<G,`17AP86YD($9O;&1E
M<@!%>'!A;F0@3F%M97,`17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@
M8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/P!&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A>`!&:6QT97)S`$9I;F0`1FER<W0@4&%G90!&;VQD97(@3F%V
M:6=A=&]R`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4@9G)O
M;2`E<P!&<F]M`$9R;VT@061D<F5S<P!&=V0Z`$AE;'``2&ED92!$96QE=&5D
M`$AI9&4@56YS=6)S8W)I8F5D`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO
M<F1E`$E.0D]8`$EG;F]R90!)9VYO<F4@06QL`$EM<&]R=&%N=`!);7!O<G1A
M;G0@;65S<V%G97,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD
M<SH`26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_`$QA;F=U
M86=E`$QA<W0@4&%G90!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@:6X@
M=&\@)7,`3&]G(&]U=`!,;V=I;B!487-K<P!-30!-86EL8F]X`$UA<FL@87,Z
M`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R
M96YT(&-O;&]R<S\`36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`365S<V%G92!#
M;VUP;W-I=&EO;@!-97-S86=E($1A=&4`365S<V%G92!396%R8V@`365S<V%G
M92!3:7IE`$UE<W-A9V4@4V]U<F-E`$UE<W-A9V4@5FEE=VEN9P!-97-S86=E
M(&9L86=S`$UE<W-A9V4@9F]L9&5R<P!-97-S86=E<R!P97(@<&%G92!I;B!T
M:&4@;6%I;&)O>"!V:65W+@!-97-S86=E<R!T;P!-;V1I9GD`36]N=&AL>0!-
M;W9E`$YA;64`3F5V97(`3F5W`$YE=R!-86EL`$YE=R!M97-S86=E<P!.97AT
M`$YE>'0@365S<V%G90!.97AT(%!A9V4`3F\`3F\@9F]L9&5R<R!W97)E('-P
M96-I9FEE9`!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S=&EO;G,`3F]N
M90!.;W0@1&5L971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R
M<V]N86P`3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&]R=&%N="!M97-S
M86=E<P!.;W1E<P!.=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O
M(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2X`3TL`3VQD(&UE<W-A9V5S`$]L
M9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]P=&EO;G,`3W1H
M97(@26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!086=E("5D(&]F("5D`%!A
M<G0H<RD`4&%S<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS
M`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R
M<V]N86P`4&5R<V]N86P@26YF;W)M871I;VX`4&AO;F4`4&QA8V4@>6]U<B!S
M:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/P!0;&5A<V4@
M96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E
M<B!T:&4@;F5W(&YA;64Z`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0`4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@
M861D<F5S<V5S+@!0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@
M<&5R9F]R;2!A;GD@86-T:6]N<RX`4&QE87-E('-E;&5C="!A="!L96%S="!O
M;F4@9F]L9&5R('1O('-E87)C:"X`4&QE87-E('-E;&5C="!O;FQY(&]N92!F
M;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+@!0<F5V:6]U<R!-97-S86=E`%!R
M979I;W5S(%!A9V4`4')I;G0`4')O8FQE;2!$97-C<FEP=&EO;@!0=7)G92!$
M96QE=&5D`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S<V%G97,@
M:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y
M<RX`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I<F5C="!T:&ES(&UE
M<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2969R97-H`%)E9G)E<V@@1F]L
M9&5R(%9I97=S.@!296QO860@5FEE=P!296UE;6)E<B!T:&4@;&%S="!V:65W
M`%)E;6]V92!P86ER`%)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN
M;FEN9R!O9B!M;VYT:#\`4F5N86UI;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!297!L86-E('=I=&@Z`%)E
M<&QY`%)E<&QY('1O($%L;`!297!L>2!T;R!!;&PZ`%)E<&QY+51O.B``4F5P
M;'DZ`%)E<&]R="!A<R!3<&%M`%)E<V5T`%)E<W5M90!2971U<FX@=&\@=&AE
M(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C
M;W!Y:6YG(&$@;65S<V%G93\`4V%V92!$<F%F=`!3879E(&%S`%-A=FEN9R!T
M:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`E<P!396%R8V@`4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`4V5L96-T
M(&%L;`!396QE8W0@;F]N90!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD($UE<W-A9V4`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YT(&UA:6P@9F]L9&5R.@!397)V97(`4V5T('!R969E<F5N8V5S
M(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE
M<W-A9V5S+@!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A
M9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=R!$96QE=&5D`%-H;W<@56YS=6)S
M8W)I8F5D`%-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_`%-I>F4`
M4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&5C
M:6%L($-H87)A8W1E<G,`4W!E;&P@0VAE8VL`4W!E;&P@0VAE8VME<@!3<&5L
M;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W
M:&5N('-P96QL(&-H96-K:6YG+@!3=6)J96-T`%-U8FIE8W0@1FEE;&0`4W5B
M<V-R:6)E('1O($9O;&1E<BAS*0!3=6-C97-S`%-U9V=E<W1I;VYS`%1A<VMS
M`%1E>'0`5&AE(&-U<G)E;G0@9F]L9&5R*',I("(E<R(@=VEL;"!B92!R96YA
M;65D('1O("(E<R(N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4
M:&4@9F]L9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN
M(&ET<R!N86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@
M>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A
M<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`
M5&AE(&9O;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@
M=6YS=6)S8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T
M(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O
M;&1E<B`B)7,B('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C
M<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE
M=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D
M('1O("(E<R(N`%1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L
M86-E9"X`5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I
M;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE
M(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H
M97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L
M9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE
M<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD
M97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W
M87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H:7,@;6%Y
M('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N
M=&EN=64_`%1H:7,@;65S<V%G92!T;P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:')E
M860@5FEE=P!4:71L90!4;P!4<F%S:"!F;VQD97(Z`%523`!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F%N<W=E<F5D`%5N86YS=V5R960@;65S<V%G
M97,`56YD96QE=&4`56YD:7-C;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG
M97,`56YN86UE9`!5;G-E96X`56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RD`
M57-E($1E9F%U;'0@5F%L=64`57-E<B!/<'1I;VYS`%5S97)N86UE`%9I97<@
M)7,`5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ`%=A
M<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5VAE;B!D
M96QE=&EN9R!M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L
M9&5R(&EN<W1E860@;V8@;6%R:VEN9R!T:&5M(&%S(&1E;&5T960_`%=O<FL@
M061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U(&%R92!C<F5A
M=&EN9R!A('-U8BUF;VQD97(@=&\@`%EO=2!A<F4@8W)E871I;F<@82!T;W`M
M;&5V96P@9F]L9&5R+@!9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z(`!9
M;W4@:&%V92`E<R!N97<@;65S<V%G97,N`%EO=2!H879E(#$@;F5W(&UE<W-A
M9V4N`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R
M.@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!S96QE8W0@82!T
M87)G970@;6%I;&)O>"!F:7)S="X`66]U(&UU<W0@<V5L96-T(&%N(&%D9')E
M<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G
M92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="X`66]U('=E
M<F4@;F]T('-U8G-C<FEB960@=&\@(B5S(BX@2&5R92!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@(B5S
M(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!S=6-C
M97-S9G5L;'D@<W5B<V-R:6)E9"!T;R`B)7,B`%EO=2!W97)E('-U8V-E<W-F
M=6QL>2!U;G-U8G-C<FEB960@9G)O;2`B)7,B`%EO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T
M:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!S:6=N
M871U<F4Z`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S
M(&]F("5S70!F<F]M`&YO;F4`;W(`<W!E;&QI;F<@97)R;W(`<W!E;&QI;F<@
M97)R;W)S`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@24U0(#,N,0I297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E
M871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#,M,3$M,#,@,3,Z,S-'350K,0I,87-T+51R86YS;&%T;W(Z
M(&=U:6QL92`\9W5I;&QE0'5S8RYE<SX*3&%N9W5A9V4M5&5A;3H@1V%L96=O
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*6"U'96YE<F%T;W(Z($M"86)E;"`P+CDN-0H`("`@(%!A<F$Z(``@
M("!$871A.B``("`@("`@1&4Z(``@07-U;G1O.B``(&5N(``C`"5D(&\@)60@
M9&4@)60@;65N<V%X97,`3W!E<F%C:?-N<R!D92!M86YT96UE;G1O("5S("T@
M0V]N9FER;6%C:?-N`"5S('AA(&5X:7-T92X@3F]N(&QL92!C86UB:6]U(&\@
M;F]M92!O(&-A<G1A9F]L("5S+@!/(&YO;64@9&\@8V%R=&%F;VP@)7,@=F%I
M(&UU9&%R(&$@8V]M97IO<R!D92!M97,N`"5S.B`E<R`H)60F;F)S<#MD929N
M8G-P.R5D*0`H07!L:6-A(&]S(&-A;6)I;W,@92!P87-A(.$@<V5G=6EN=&4@
M<&%N=&%L;&$N*0`H1&5S9F%C97(@=/-D;VQO<R!C86UB:6]S(&4@<F5G<F5S
M87(@X2!P86YT86QL82!D92!R961A8V-I\VXN*0`H4F5G<F5S87(@X2!P86YT
M86QL82!D92!R961A8V-I\VX@9&5S<&]I<R!D92!A<&QI8V%R('3S9&]L;W,@
M8V%M8FEO<R!F96ET;W,@871A(&%G;W)A+B!/<R!C86UB:6]S(&YA('!A;G1A
M;&QA(&%C='5A;"!.3TX@<V4@87!L:6-A<N%N+BD`*B!%;F=A9&ER(&5S=&5S
M('!R96UE;F1O(&5N($]+("H`*B!396QE8V-I;VYE(&\H<RD@96YD97)E>F\H
M<RD@*@`R-"!H;W)A<P!!32]030!%;F=A9&ER('5N('!A<@!%;F1E<F5Z;P!!
M>&5N9&$@9&4@96YD97)E>F]S`$%L8W5M90!4;V1O<P!4\V1A;&%S(&UE;G-A
M>&5S(&1O*',I('-E9W5I;G1E*',I(&-A<G1A9F]L*&5S*2!D97-C87)G87)A
M;G-E(&YU;B!A<G%U:79O(&1E('1I<&\@34)/6#H@`%9A;G-E(&)O<G)A<B!D
M92!V97H@87,@;65N<V%X97,@9&\@8V%R=&%F;VP@(B5S(B!C;VX@;>%I<R!D
M92`E<R!D[6%S('-E<N%N(&5L:6UI;F%D87,@<&5R;6%N96YT96UE;G1E+@!6
M86YS92!E;&EM:6YA<B!O<R!C87)T869O;&5S(&1E(&UE;G-A>&5S(&5N=FEA
M9&%S(&AA:2!MX6ES(&1E("`E<R!M97-E<R`N`$\@=F%L;W(@<75E(&5S<&5C
M:69I8V]U(&YO;B#I(';A;&ED;P!297-P;VYD:61A`$UE;G-A>&5S(')E<W!O
M;F1I9&%S`+]%<W3A('-E9W5R;R!D92!Q=64@9&5S97AA(&9A8V5R(&ES=&\_
M`+]%<W3A('-E9W5R;R!D92!Q=64@9&5S97AA(&5L:6UI;F%R($1%(%9%6B!E
M<W1A<R!M96YS87AE<S\`OT5S=.$@<V5G=7)O('%U92!D97-E>&$@8F%L96ER
M87(@97-T92!C87)T869O;#\`4&]R(&AO<F$@9&4@8VAE9V%D80!!<V-E;F1E
M;G1E`$%C;VUP8?%A<@!!8V]M<&'Q87(@=6X@87)Q=6EV;P!!;F5X;W,`0V%M
M<&]S(&1I<W!O\6EB;&5S.@!296=R97-A<B!A("5S`$-#3P!!;FEV97)S87)I
M;P!,:7-T82!N96=R80!497AT;P!!;6)O<P!#86YC96QA<@!#86YC96QA<B!A
M(&UE;G-A>&4`0V%N8V5L87(@;R!I;F9O<FUE(&1E('!R;V)L96UA<P!392!C
M86YC96QA(&5S=&$@;65N<V%X92!P97)D97+A(&\@8V]N=&ED;RX`0V,`5&5L
MZ69O;F\@;?-B:6P`0V%M8FEA<@!#86UB:6%L87,@=&]D87,`0V%M8FEA<B!O
M<&-I\VYS(&1E('9I<W5A;&EZ86-I\VX@=&%L97,@8V]M;R!CX6YT87,@;65N
M<V%X97,@=F5RX2!P;W(@<.%X:6YA(&4@8V]M;R!S92!O<F1E;F%N+@!#86UB
M:6%R(&\@;F]M92P@;R!E;F1E<F5Z;R!E;&5C='+S;FEC;R!E(&$@<VEN871U
M<F$@<75E('-E('9E(&-A;F1O(&QE;B!E(')E<W!O;F1E;B#A<R!S^F%S(&UE
M;G-A>&5S+@!"=7-C87(@8V]R<F5O(&YO=F\@8FES(&-A<G1A9F]L97,`16QI
M>&ER('5N:&$@86-C:?-N.@!096-H87(@82!X86YE;&$`0V%R=&%F;VP@<&5C
M:&%D;P!#;VUP<FEM:6QO<R!T;V1O<P!#;VUP<FEM:7(@=/-D;VQO<R!C87)T
M869O;&5S`$-O;7!R:6UI<B!O(&-A<G1A9F]L`$-O;7!A\>UA`%)E9&%C=&%R
M(&UE;G-A>&5S(&YU;FAA('AA;F5L82#A('!A<G1E+@!#;VYT<F]L82!A(&-O
M;7!R;V)A8VGS;B!D;R!C;W)R96\@;F]V;R!E(&$@<_IA(&YO=&EF:6-A8VGS
M;B!P;VQO('-I<W1E;6$N`$-O<&EA<@!#;W)R:7AI<@!497AT;R!C;W)R:7AI
M9&\`1F%L;&\@\R!A8G)I<B!O(&WS9'5L;R!D92!T87)E9F%S(&1E(&UA;G1E
M;65N=&\@)7,`0W)E87(`0W)E87(@=6X@8V%R=&%F;VP`0W)E87(@=6X@;F]V
M;R!C87)T869O;`!#<F5A<B!U;B!N;W9O(&-A<G1A9F]L(&1O(&-O<G)E;R!E
M;G9I861O`$-R96%R('5N(&YO=F\@8V%R=&%F;VP@<&%R82!O(&QI>&\`0W)E
M87(@<F5G<F%S(&1E(&9I;'1R87AE('!A<F$@;W)G86YI>F%R(&\@8V]R<F5O
M('%U92!E;G1R82P@8VQA<VEF:6-A;&\@96X@8V%R=&%F;VQE<R!E(&5L:6UI
M;F%R(&\@8V]R<F5O(&YO;B!D97-E>&%D;RX`4&5R<V]N86QI>F%R(&%S('1A
M<F5F87,@<75E('-E(&5X96-U=&5N(/,@:6YI8VEA<B!A('-E<VGS;B!E;B`E
M<RX`1$0`1&EA<FEA;65N=&4`1&%T80!)9&5N=&ED861E('!R961E=&5R;6EN
M861A`$-R:71E<FEO(&1E(&-L87-I9FEC86-I\VX@<')E9&5T97)M:6YA9&\Z
M`$]R9&4@9&4@8VQA<VEF:6-A8VGS;B!P<F5D971E<FUI;F%D;SH`16QI;6EN
M87(`16QI;6EN87(@8V%R=&%F;VPH97,I`$5L:6UI;F%R(&]S(&-A<G1A9F]L
M97,@9&4@;65N<V%X97,@96YV:6%D87,@82!P<FEN8VEP:6]S(&1O(&UE<P!%
M;&EM:6YA9&$`365N<V%X97,@96QI;6EN861A<P!%;&EM:6YA;F1O(&4@;6]V
M96YD;R!M96YS87AE<P!$97-C96YD96YT90!$97-C<FEC:?-N(&1O('!R;V)L
M96UA`%)E>&ES='+A<F]N<V4@;W,@9&5T86QL97,@<&%R82!O(&%D;6EN:7-T
M<F%D;W(N`+]!=&5N=6%R(&$@<VEN871U<F$_`%9I<W5A;&EZ87(`3W!C:?-N
M<R!D92!V:7-U86QI>F%C:?-N`$UO<W1R87(@82!X86YE;&$@9&4@;F]T:69I
M8V%C:?-N(&1E(&-O<G)E;R!N;W9O+@!.;VX@97AA;6EN87(@8V%R=&%F;VQE
M<R!P87)A(&)U<V-A<B!O(&-O<G)E;R!N;W9O`$YO;B!A8V-E9&$@9&ER96-T
M86UE;G1E(&$@(FUA:6YT96YA;F-E+G!H<"(`OT1E<V5X82!A8G)I<B!E<V4@
M8V%R=&%F;VP_`$9E:71O`$1E<V-A<F=A<B!C87)T869O;"AE<RD`0F]R<F%D
M;W(`0V%R=&%F;VP@9&]S(&)O<G)A9&]R97,Z`$5D:71A<@!%9&ET87(@87,@
M<F5G<F%S(&1E(&9I;'1R87AE`$-O<G)E;R!E;&5C='+S;FEC;P!%;F1E<F5Z
M;R!D92!C;W)R96\@96QE8W1R\VYI8V\`0F%L96ER87(@;W,@8V%R=&%F;VPH
M97,I`$)A;&5I<F%R(&$@<&%P96QE:7)A(&1O(&QI>&\`4V5N(')E<W5L=&%D
M;RX`1FEN(&1A(&UE;G-A>&4@<F5E;G9I861A`$EN=')O9'5Z82!O(&YO;64@
M9&\@;F]V;R!C87)T869O;"!D;W,@8F]R<F%D;W)E<P!);G1R;V1U>F$@;R!N
M;VUE(&1O(&YO=F\@8V%R=&%F;VP@9&\@8V]R<F5O(&5N=FEA9&\`26YT<F]D
M=7IA(&\@;F]M92!D;R!N;W9O(&-A<G1A9F]L(&1O(&QI>&\`17)R;P!#861A
M(#$U(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@;6EN=71O<P!#
M861A(&EN:6-I;R!D92!S97-I\VX`0V%D82!M961I82!H;W)A`$-A9&$@;6EN
M=71O`$5X96UP;&\@9&4@=F%L;W)E<SH`17AP86YD:7(@`$5X<&%N9&ER('1O
M9&]S(&]S(&-A<G1A9F]L97,`17AP86YD:7(@;R!C87)T869O;`!%>'!A;F1I
M<B!O<R!N;VUE<P"_17AP86YD:7(@<&]R(&1E9F5C=&\@=&]D82!A(.%R8F]R
M92!D;W,@8V%R=&%F;VQE<R!N82!V:7-T82!D92!C87)T869O;&5S/P!&86QL
M;W4@\R!R96-U<&5R87(@87,@<')E9F5R96YC:6%S+@!&86QL;W4@\R!C;VYE
M8W1A<B!C;R!S97)V:61O<B!,1$%0+@!&87@`1FEL=')O<P!!=&]P87(`4')I
M;65I<F$@<.%X:6YA`$YA=F5G861O<B!D;W,@8V%R=&%F;VQE<P!2965N=FEA
M<@!2965N=FEA<CH`365N<V%X92!R965N=FEA9&$@9&5N9&4@)7,`1&4`16YD
M97)E>F\@9&\@<F5M:71E;G1E`%)E96YV.@!!>'5D80!/8W5L=&%R(&%S(&5L
M:6UI;F%D87,`3V-U;'1A<B!A<R!N;VX@<W5B<V-R:71A<P!%;F1E<F5Z;R!P
M87)T:6-U;&%R`%1E;.EF;VYO('!A<G1I8W5L87(`2&]R9&4`24Y"3U@`26=N
M;W)A<@!)9VYO<F%L87,@=&]D87,`26UP;W)T86YT90!-96YS87AE<R!I;7!O
M<G1A;G1E<P!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O<R!I;7!O<G1A9&]S
M.@"_26YC;'7M<B!A(&UE;G-A>&4@;W)I>&EN86P@;F$@<F5S<&]S=&$_`$QI
M;F=U80#:;'1I;6$@<.%X:6YA`$QI<W1A<B!O<R!T96UA<R!D92!A>'5D80!%
M;G1R87(`16YT<F%R(&$@)7,`4&5C:&%R(&$@<V5S:?-N`%1A<F5F87,@9&4@
M:6YI8VEO(&1E('-E<VGS;@!-30!#86EX82!D92!C;W)R96\`36%R8V%R(&-O
M;6\Z`+]-87)C87(@;W,@;FEV96ES(&1I9F5R96YT97,@9&$@8VET82!C;VX@
M8V]R97,@9&ES=&EN=&%S/P!#86UP;W,@8V]R<F5S<&]N9&5N=&5S`$UE;G-A
M>&4`4F5D86-T87(@=6YH82!M96YS87AE`$1A=&$@9&$@;65N<V%X90!"=7-C
M82!D92!M96YS87AE<P!0;W(@=&%M8?%O(&1A(&UE;G-A>&4`0_-D:6=O(&9O
M;G1E(&1A(&UE;G-A>&4`5FES=6%L:7IA8VGS;B!D92!M96YS87AE<P!-87)C
M87,@9&$@;65N<V%X90!#87)T869O;&5S(&1E(&UE;G-A>&5S`$UE;G-A>&5S
M('!O<B!PX7AI;F$@;F$@;&ES=&$@9&$@8V%I>&$@9&\@8V]R<F5O+@!-96YS
M87AE<R!A`$UO9&EF:6-A<@!-96YS=6%L;65N=&4`36]V97(`3F]M90!.=6YC
M80!.;W9A`$-O<G)E;R!N;W9O`$UE;G-A>&5S(&YO=F%S`%-E9W5I;G1E`%-E
M9W5I;G1E(&UE;G-A>&4`4V5G=6EN=&4@<.%X:6YA`$YO;@!.;VX@97-P96-I
M9FEC;W4@;FEN9_IN(&-A<G1A9F]L`$YO;B!H86D@97)R;W,@9&4@;W)T;V=R
M86;M80!.;VX@:&%I('-U>&5S=&GS;G,`3FEN9W5N:&$`3F]N(&5L:6UI;F%D
M80!.;VX@Z2!U;B!B;W)R861O<@!.;VX@Z2!I;7!O<G1A;G1E`$YO;B#I('!E
M<G-O86P`365N<V%X97,@;F]N(&5L:6UI;F%D87,`365N<V%X97,@;F]N(&EM
M<&]R=&%N=&5S`$YO=&%S`$[Z;65R;R!D92!C87)T869O;&5S(&1E(&-O<G)E
M;R!E;G9I861O('%U92!S92!V86X@;6%N=&5R(/,@96QI;6EN86QO<R!M96YS
M=6%L;65N=&4`0V]R<F5C=&\`365N<V%X97,@=F5L;&%S`$5L:6UI;F%N9&\@
M;W,@8V%R=&%F;VQE<R!D92!C;W)R96\@96YV:6%D;R!V96QL;W,`3W!C:?-N
M<P!/=71R82!I;F9O<FUA8VGS;@!/=71R87,@;W!C:?-N<P!0X7AI;F$@)60@
M9&4@)60`4&%R=&4H<RD`0VAA=F4@9&4@86-C97-O`%)E86QI>F%R(&]P97)A
M8VGS;G,@9&4@;6%N=&5M96YT;P!296%L:7IA<B!A<R!O<&5R86-I\VYS(&1E
M(&UA;G1E;65N=&\@\R!I;FEC:6\@9&4@<V5S:?-N`%!E<G-O86P`26YF;W)M
M86-I\VX@<&5R<V]A;`!496SI9F]N;P"_475E<F4@8V]L;V-A<B!A('/Z82!S
M:6YA='5R82!N82!M96YS87AE(&1E(')E<W!O<W1A(&4@;F]S(')E96YV[6]S
M/P!);G1R;V1U>F$@;R!N;VUE(&1O(&YO=F\@8V%R=&%F;VPZ`$EN=')O9'5Z
M82!O(&YO=F\@;F]M93H`06-H96=U92!U;B!R97-U;6\@9&\@<')O8FQE;6$N
M`$%C:&5G=64@;R!S974@;F]M92!D92!U<W5A<FEO(&4@8VAA=F4@9&4@86-C
M97-O`$-O<G)I>&$@;W,@96YD97)E>F]S(&%M8FEG=6]S(&]U(&EN8V]R<F5C
M=&]S+@!396QE8V-I;VYE('5N(&-A<G1A9F]L(&%N=&5S(&1E(')E86QI>F%R
M(&-A;'%U97)A(&%C8VGS;BX`4V5L96-C:6]N92!P;VQO(&UE;F]S('5N(&-A
M<G1A9F]L(&YO('%U92!R96%L:7IA<B!A(&)U<V-A+@!396QE8V-I;VYE('5N
M('/S(&-A<G1A9F]L('!A<F$@97-T82!O<&5R86-I\VX`365N<V%X92!A;G1E
M<FEO<@!0X7AI;F$@86YT97)I;W(`26UP<FEM:7(`1&5S8W)I8VGS;B!D;R!P
M<F]B;&5M80!296-I8VQA<B!O(&QI>&\`4F5C:6-L87(@;R!L:7AO(&-O;B!E
M<W1A(&9R96-U96YC:6$Z`%)E8VEC;&%R(&1O(&QI>&\@87,@;65N<V%X97,@
M<75E('1E\6%N(&WA:7,@9&5S=&5S(&3M87,`4F5D:7)E8V-I;VYA`%)E9&ER
M96-C:6]N87(@82!M96YS87AE`%)E9&ER96-C:6]N87(@97-T82!M96YS87AE
M`$9A;&QO=2!O(')E9&ER96-C:6]N86UE;G1O+@!!8W1U86QI>F%R`$%C='5A
M;&EZ87(@82!V:7-T82!D;W,@8V%R=&%F;VQE<P!296-A<F=A<B!A('9I<W1A
M`$QE;6)R87(@82#Z;'1I;6$@=FES=&$`4V%C87(@;R!P87(`0V%M8FEA<FQL
M92!O(&YO;64@\R!C87)T869O;"!D;R!C;W)R96\@96YV:6%D;R#S(&EN:6-I
M;R!D;R!M97,`1F%L;&]U(/,@8V%M8FEA<FQL92!O(&YO;64@(B5S(B!A("(E
M<R(N($5S=&$@9F]I(&$@<F5S<&]S=&$@9&\@<V5R=FED;W(`4W5B<W1I='7M
M<B!C;VXZ`%)E<W!O;F1E<@!297-P;VYD97)L;&5S(&$@=&]D;W,`4F5S<&]N
M9&5R;&QE<R!A('1O9&]S.@!297-P;VYD97)L;&4Z(`!297-P;VYD97(Z`$1E
M;G5N8VEA<B!E<W1A(&UE;G-A>&4@8V]M;R!C;W)R96\M;&EX;R`H<W!A;2D`
M4F5I;FEC:6%R`%)E86YU9&%R`+]296=R97-A<B#A(&QI<W1A(&1A(&-A:7AA
M(&1E(&-O<G)E;R!D97-P;VES(&1E(&5L:6UI;F%R+"!M;W9E<B!O=2!C;W!I
M87(@=6YH82!M96YS87AE/P!'87)D87(@;R!B;W)R861O<@!'87)D87(@8V]M
M;P!&86QL;W4@\R!G87)D87(@;R!B;W)R861O<BX@17-T82!F;VD@82!R97-P
M;W-T82!D;R!S97)V:61O<CH@)7,`0G5S8V%R`%)E<W5L=&%D;W,@9&$@8G5S
M8V$`5FES=&\`4V5L96-C:6]N87(`4V5L96-C:6]N86QA<R!T;V1A<P!1=6ET
M87(@82!S96QE8V-I\VX`4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A(&1A
M=&$Z`%-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&1A=&$Z`%-E;&5C8VEO;F4@
M;R!F;W)M871O(&1A(&AO<F$Z`%-E;&5C8VEO;F4@9&]U<R!C86UP;W,@<75E
M(&-O:6YC:61A;BX`4V5L96-C:6]N92!A(&QI;F=U83H`16YV:6%R(&$@;65N
M<V%X90!%;G9I87(@;R!I;F9O<FUE(&1E('!R;V)L96UA<P!#87)T869O;"!D
M87,@;65N<V%X97,@96YV:6%D87,Z`%-E<G9I9&]R`$5S=&%B;&5C92!A<R!P
M<F5F97)E;F-I87,@<&%R82!A<R!A8V-I\VYS('%U92!O8V]R<F5N(&-A;F1O
M(&UO=F$@;W4@96QI;6EN92!M96YS87AE<RX`OT1E8F4@<&5C:&%R<V4@82!X
M86YE;&$@9&4@<F5D86-C:?-N(&1E<W!O:7,@9&4@9V%R9&%R('5N(&)O<G)A
M9&]R/P!-;W-T<F%R(&%S(&5L:6UI;F%D87,`36]S=')A<B!A<R!S=6)S8W)I
M8VGS;G,@8V%N8V5L861A<P!-;W-T<F%R('5N:&$@;&5N9&$@;F$@;&ES=&$@
M9&$@8V%I>&$@9&4@8V]R<F5O+@!486UA\6\`3VUI=&ER(&\@;6%N=&5M96YT
M;P!%;G1R861A(&1E(&-A<F%C=&5R97,@97-P96-I86ES`$-A<F%C=&5R97,@
M97-P96-I86ES`$-O;7!R;V)A<B!A(&]R=&]G<F%F[6$`0V]R<F5C=&]R(&]R
M=&]G<N%F:6-O`%)E=FES:?-N(&1E(&]R=&]G<F%F[6$@8V]M<&QE=&$`17)R
M;W,@;W)T;V=RX69I8V]S('!O<B!P86YT86QL82!D=7)A;G1E(&$@<F5V:7-I
M\VXN`$%S=6YT;P!#86UP;R!D;R!A<W5N=&\`4W5B<V-R:6)I<G-E(/-S(&-A
M<G1A9F]L*&5S*0!#;W)R96-T86UE;G1E`%-U>&5S=&GS;G,`5&%R969A<P!4
M97AT;P!/<R!C87)T869O;"AE<RD@(B5S(B!C86UB:6%RX7-E;&QE<R!O(&YO
M;64@82`B)7,B+@!/(&-A<G1A9F]L("(E<R(@>&$@97AI<W1E`$\@;F]M92!D
M;R!C87)T869O;"`B)7,B(&-O;G3I;B!C87)A8W1E<F5S(&YO;B!VX6QI9&]S
M+B!)<W1O('!O9&4@8V%U<V%R('!R;V)L96UA<RX@0V]N=&%C=&4@8V\@861M
M:6YI<W1R861O<B!D;R!S:7-T96UA+@!#<F5O=7-E(&\@8V%R=&%F;VP@(B5S
M(B!P97)O('9O<W1E9&4@;F]N(&5S=.$@<W5B<V-R:71O(&$@96PN`$5L:6UI
M;F]U<V4@;R!C87)T869O;"`B)7,B('!E<F\@;F]N('-E(&-A;F-E;&]U(&$@
M<_IA('-U8G-C<FEC:?-N+@!.;VX@<V4@8W)E;W4@;R!C87)T869O;"`B)7,B
M+B!%<W1A(&9O:2!A(')E<W!O<W1A(&1O('-E<G9I9&]R`$$@8V%R<&5T82`B
M)7,B(&YO;B!F;VD@96QI;6EN861A+B!)<W1A(&9O:2!A(')E<W!O<W1A(&1O
M('-E<G9I9&]R`$\@8V%R=&%F;VP@(B5S(B!F;VD@8W)E861O(&-O<G)E8W1A
M;65N=&4N`$\@8V%R=&%F;VP@(B5S(B!F;VD@96QI;6EN861O(&-O<G)E8W1A
M;65N=&4N`$\@8V%R=&%F;VP@(B5S(B!C86UB:?-U<V5L;&4@;R!N;VUE(&-O
M<G)E8W1A;65N=&4@82`B)7,B+@!!('-I;F%T=7)A('-U8G-T:71U[75S92!C
M;W)R96-T86UE;G1E+@!.;VX@:&%I(&UE;G-A>&5S(&YE<W1A(&-A:7AA(&1E
M(&-O<G)E;RX`2&]U8F\@=6X@<')O8FQE;6$@\R!B86QE:7)A<B!A(&-A:7AA
M(&1O(&-O<G)E;R`E<RX@17-T82!F;VD@82!R97-P;W-T82!D;R!S97)V:61O
M<@!(;W5B;R!U;B!P<F]B;&5M82#S(&)A;&5I<F%R(&$@8V%I>&$@9&\@8V]R
M<F5O+B!%<W1A(&9O:2!A(')E<W!O<W1A(&1O('-E<G9I9&]R`$AO=6)O('5N
M(&5R<F\@\R!E;&EM:6YA<B!A<R!M96YS87AE<R!D;R!C87)T869O;"`B)7,B
M+B!%<W1A(&9O:2!A(')E<W!O<W1A(&1O('-E<G9I9&]R`$AO=6)O('5N(&5R
M<F\@\R!E;&EM:6YA<B!A<R!M96YS87AE<R!D;R!C87)T869O;"`B)7,B+B!%
M<W1A(&9O:2!A(')E<W!O<W1A(&1O('-E<G9I9&]R`$AO=6)O('5N(&5R<F\@
M\R!V:7-U86QI>F%R(&5S=&$@<&%R=&4@9&$@;65N<V%X90!(;W5B;R!U;B!E
M<G)O(/,@;6%R8V%R(&%S(&UE;G-A>&5S(&YO(&-A<G1A9F]L("(E<R(N($5S
M=&$@9F]I(&$@<F5S<&]S=&$@9&\@<V5R=FED;W(`2&]U8F\@=6X@97)R;R#S
M(&5N=FEA<B!A('/Z82!M96YS87AE.B`E<P!)<W1O('!O9&4@;&5V87(@86QG
M^FX@=&5M<&\N(+]%<W1A('-E9W5R;R!D92!Q=64@9&5S97AA(&-O;G1I;G5A
M<C\`02!M96YS87AE('!A<F$`3R!N^FUE<F\@9&5B92!S97(@<&]L;R!M96YO
M<R!U;B`Q+@!/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R;RX`5F5I('!O;&\@
M9NUO`%3M='5L;P!087)A`$QI>&\Z`%523`!.;VX@9F]I('!O<VEB;&4@8V]N
M96-T87)S92#S('-E<G9I9&]R(%-13"X`3F]N(&9O:2!P;W-I8FQE('1R861U
M8VER(&5S=&4@9&]C=6UE;G1O(&1E(%=O<F0`4V5N(')E<W!O;F1E<@!-96YS
M87AE<R!S96X@<F5S<&]N9&5R`%)E8W5P97)A<@!.;VX@<V4@97-P96-I9FEC
M;W4@;FEN9_IN(&1E<W1I;F%T87)I;P!$97-F86-E<B!O<R!C86UB:6]S`%-E
M;B!N;VUE`$YO;B!V:7-T80!#86YC96QA<B!A('-U8G-C<FEC:?-N(&1O*',I
M(&-A<G1A9F]L*&5S*0!%;7!R96=A<B!U;B!V86QO<B!P<F5D971E<FUI;F%D
M;P!/<&-I\VYS(&1O('5S=6%R:6\`57-U87)I;P!697(@)7,`5FES=&$@;W4@
M8V%I>&$@9&\@8V]R<F5O(&$@;6]S=')A<B!D97-P;VES(&1E(&EN:6-I87(@
M82!S97-I\VXZ`$%V:7-O`%-E;6%N86QM96YT90!"96YV:61O<R]A<R!A("5S
M`$)E;G9I9&\O82P@)7,`0V%N9&\@<V4@96QI;6EN96X@;65N<V%X97,L(+]B
M;W1A;&%S(/,@;&EX;R!E;B!T<F]Q=65S(&1E(&UA<F-A;&%S(&-O;6\@96QI
M;6EN861A<S\N`$5N9&5R97IO(&1O('1R86)A;&QO`%1E;.EF;VYO(&1O('1R
M86)A;&QO`$%!`$%N=6%L;65N=&4`4VD`17-TX2!C<F5A;F1O('5N('-U8F-A
M<G1A9F]L(&5N(`!%<W3A(&-R96%N9&\@=6X@<W5B8V%R=&%F;VP@9&4@;NUV
M96P@<W5P97)I;W(N`$5S=&%L;&4@8V%M8FEA;F1O(&\@;F]M92#S(&-A<G1A
M9F]L.@!496X@)7,@;65N<V%X97,@;F]V87,N`%1E;B`Q(&UE;G-A>&4@;F]V
M82X`5&5N(&-O<G)E;R!N;W9O(&YO('-E9W5I;G1E(&-A<G1A9F]L.@!496X@
M8V]R<F5O(&YO=F\@;F]S('-E9W5I;G1E<R!C87)T869O;&5S.@!$97-C<FEB
M82!O('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!O(&EN9F]R;64N`%!R:6UE
M:7)O('-E;&5C8VEO;F4@=6X@8V]R<F5O(&1E(&1E<W1I;F\N`%!R:6UE:7)O
M('-E;&5C8VEO;F4@=6X@96YD97)E>F\N`%!R:6UE:7)O('-E;&5C8VEO;F4@
M=6YH82!M96YS87AE+"!P;VQO(&UE;F]S+@!%<W!E8VEF:7%U92!U;B!D97-T
M:6YA=&%R:6\@;F\@8V%M<&\@4&%R83H`3F]N(&9O:2!S=6)S8W)I=&\@82`B
M)7,B+B!%<W1A(&9O:2!A(')E<W!O<W1A(&1O('-E<G9I9&]R`$YO;B!F;VD@
M9&%D;R!D92!B86EX82!D92`B)7,B+B!%<W1A(&9O:2!A(')E<W!O<W1A(&1O
M('-E<G9I9&]R`$9O:2!S=6)S8W)I=&\@8V]R<F5C=&%M96YT92!A("(E<R(`
M1F]I(&1A9&\@9&4@8F%I>&$@8V]R<F5C=&%M96YT92!D92`B)7,B`$-A9'5C
M;W4@82!S^F$@<V5S:?-N(&5N("5S(&5X<&ER;W4N($EN:6-I92!U;FAA(&YO
M=F$@<V5S:?-N+@!!('/Z82!I;F9O<FUA8VGS;@!!8W1U86QI>N%R;VYS92!A
M<R!S^F%S(&]P8VGS;G,N`%-I;F%T=7)A.@!;4V5N(&%S=6YT;UT`6TEN9F]R
M;64@9&\@4')O8FQE;6%=`%ML:?%A("5S(&1E("5S70!D90!N:6YG^FX`;W4`
M97)R;R!D92!O<G1O9W)A9NUA`&5R<F]S(&1E(&]R=&]G<F%F[6$`5&%R>&5T
M82!D92!V:7-I=&$@*'9#87)D*0``````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M;V-A;&4O:&5?24PO````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#$W-#,Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]H95])3"],0U]-15-304=%4R\`````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P
M,C$R,38`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VAE7TE,
M+TQ#7TU%4U-!1T53+VEM<"YM;P``````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(S
M,S,P`#$P-#$W,S8R-S8S`#`R,C,S-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````-H````<````[`8``"4!``"\
M#0```````%`2```*````41(```H```!<$@``"@```&<2```*````<A(```H`
M``!]$@``"P```(@2```'````E!(```<```"<$@```P```*02```*````J!(`
M``D```"S$@``!P```+T2```)````Q1(```<```#/$@``!P```-<2```'````
MWQ(```H```#G$@```P```/(2```'````]A(```8```#^$@``"0````43```'
M````#Q,```@````7$P``!@```"`3```1````)Q,```<````Y$P``"````$$3
M```(````2A,```8```!3$P``!@```%H3```*````81,```(```!L$P``&```
M`&\3```$````B!,```4```"-$P``!0```),3```%````F1,```4```"?$P``
M$0```*43```&````MQ,```@```"^$P``!P```,<3```%````SQ,```H```#5
M$P``!````.`3```&````Y1,```X```#L$P``!0```/L3```$`````10```8`
M```&%```!P````T4```2````%10```X````H%```!P```#<4```%````/Q0`
M``L```!%%```"````%$4```$````6A0```<```!?%````P```&<4```'````
M:Q0```@```!S%```!@```'P4```%````@Q0```0```")%```!0```(X4```&
M````E!0```\```";%```!P```*L4```'````LQ0```4```"[%````@```,$4
M```&````Q!0```<```#+%```"0```-,4```&````W10```8```#D%```!0``
M`.L4```'````\10```T```#Y%```!`````<5```=````#!4```@````J%0``
M"````#,5```*````/!4```<```!'%0``!0```$\5```'````514```8```!=
M%0``!0```&05```)````:A4``!D```!T%0``!````(X5```'````DQ4```8`
M``";%0``!0```*(5```'````J!4```4```"P%0``!@```+85```%````O14`
M``8```##%0``!P```,H5```'````TA4``!8```#:%0``"@```/$5```*````
M_!4```8````'%@``"`````X6```(````%Q8```0````@%@``!0```"46```*
M````*Q8```D````V%@``!@```$`6```&````1Q8```@```!.%@``!P```%<6
M```$````7Q8```H```!D%@``!````&\6```%````=!8```L```!Z%@``"P``
M`(86```+````DA8```D```">%@``!0```*@6```'````KA8```8```"V%@``
M`@```+T6```"````P!8```0```##%@``!P```,@6```%````T!8```@```#6
M%@``!@```-\6```(````YA8```@```#O%@``"0```/@6```*`````A<```0`
M```-%P``"P```!(7```&````'A<```@````E%P``!0```"X7```%````-!<`
M``4````Z%P``#````$`7```'````31<``!(```!5%P``!@```&@7```,````
M;Q<```8```!\%P``!P```(,7```*````BQ<```P```"6%P``"0```*,7```%
M````K1<```<```"S%P``#````+L7```%````R!<```D```#.%P``"````-@7
M```'````X1<```4```#I%P``"````.\7```)````^!<```8````"&```"P``
M``D8```4````%1@``!P````J&```"````$<8```"````4!@```4```!3&```
M$P```%D8```'````;1@```8```!U&````P```'P8```$````@!@```8```"%
M&```!P```(P8```4````E!@```X```"I&```#0```+@8```&````QA@```<`
M``#-&```!P```-48```(````W1@```<```#F&```"0```.X8```'````^!@`
M``@`````&0``!`````D9```%````#AD```8````4&0``!0```!L9```7````
M(1D```H````Y&0``!@```$09```(````2QD```0```!4&0``"@```%D9```#
M````9!D```<```!H&0``"````'`9```%````>1D```8```!_&0``"````(89
M```,````CQD```@```"<&0``!@```*49```&````K!D```<```"S&0```P``
M`+L9```,````OQD```0```#,&0``!````-$9```"````UAD``%$!``#9&0``
M%````"L;```,````0!L``!````!-&P``#````%X;```+````:QL``!````!W
M&P``#````(@;```,````E1L```8```"B&P``'P```*D;```0````R1L```P`
M``#:&P``$````.<;```.````^!L``!$````''```#````!D<```,````)AP`
M`!L````S'```"@```$\<```(````6AP``!4```!C'```#@```'D<```.````
MB!P```H```"7'```#````*(<```.````KQP```X```"^'```"@```,T<```(
M````V!P```8```#A'```#P```.@<```,````^!P``"X````%'0``!````#0=
M```(````.1T```8```!"'0``$P```$D=```(````71T``!@```!F'0``%P``
M`'\=```0````EQT```H```"H'0``"@```+,=```3````OAT```@```#2'0``
M#@```-L=```(````ZAT```H```#S'0``"@```/X=```&````"1X```@````0
M'@``*0```!D>```9````0QX```X```!='@``"@```&P>```5````=QX```X`
M``"-'@``"````)P>```,````I1X```@```"R'@``!@```+L>```'````PAX`
M``@```#*'@``!@```-,>```&````VAX```@```#A'@``"@```.H>```=````
M]1X```P````3'P``#````"`?```&````+1\```0````T'P``"````#D?```*
M````0A\```X```!-'P``"@```%P?```*````9Q\```H```!R'P``#````'T?
M```<````BA\```@```"G'P``"@```+`?```.````NQ\```@```#*'P``"0``
M`-,?```.````W1\``!$```#L'P``#````/X?```&````"R````@````2(```
M$@```!L@```(````+B````@````W(```#````$`@```,````32````P```!:
M(```#````&<@```&````="````@```![(```"````(0@```,````C2````H`
M``":(```#````*4@```&````LB```!(```"Y(```#````,P@```*````V2``
M``X```#D(```'P```/,@```&````$R$```@````:(0``$@```",A```2````
M-B$```P```!)(0``"@```%8A```0````82$```H```!R(0``"````'TA```.
M````AB$```0```"5(0``!@```)HA```*````H2$``!,```"L(0``$P```,`A
M```0````U"$```@```#E(0``#````.XA```0````^R$```H````,(@``!```
M`!<B```*````'"(``!`````G(@``!@```#@B```,````/R(```@```!,(@``
M#@```%4B```*````9"(```L```!O(@``#````'LB```&````B"(``!0```"/
M(@``"@```*0B```.````KR(```@```"^(@``!@```,<B```&````SB(```T`
M``#5(@``#````.,B```*````\"(```P```#[(@``%0````@C```&````'B,`
M``@````E(P``$P```"XC```5````0B,```X```!8(P``"0```&<C```,````
M<2,``!<```!^(P``"````)8C```/````GR,```@```"O(P``"````+@C```(
M````P2,```P```#*(P``$````-<C```,````Z",```H```#U(P``"@`````D
M```,````"R0```P````8)```!````"4D```@````*B0``!L```!+)```#@``
M`&<D```.````=B0```8```"%)```!P```(PD```,````E"0``!````"A)```
M(P```+(D```;````UB0``!<```#R)```"@````HE```+````%24``!`````A
M)0``'````#(E```,````3R4```X```!<)0``"@```&LE```/````=B4```8`
M``"&)0``!P```(TE```(````E24```@```">)0``'````*<E```2````Q"4`
M``P```#7)0``$````.0E```;````]24``!4````1)@``#````"<F```&````
M-"8```P````[)@``"````$@F```1````428```X```!C)@``$P```'(F```0
M````AB8```@```"7)@``!@```*`F```&````IR8```0```"N)@``$P```+,F
M```&````QR8```0```#.)@``!````-,F```!````L@````````!P````Q```
M`-4```!Y````(0````````"I`````````#(```!R``````````,```!2````
MEP````H`````````>P```!H```!.````H0```($```#7````!0```"@```"H
M````:@```)0```!G```````````````?````50```)H```````````````0`
M```C````,````)`````S````7P``````````````40```+P````M````#P``
M`&0```"9````KP```+0```!\`````````'\```!W````/P`````````I````
M`````"\```!6````@P``````````````I0```(T```#3````?0```(L`````
M````=````+,```!)`````````*````!-````K@```!X```"U`````````&@`
M``#(````A````!L```!C`````````#0```#!````>`````````!S````"P``
M````````````G```````````````I@```-(```"P````00``````````````
M`````!D`````````2@```,8```!:````MP```#H```#+````L0```(H```#0
M`````````&4````3````#````+H``````````````)L```!O````O0``````
M``!%````$@```,4````5````.P```*<```"_````?@````````!$````````
M````````````O@````````")````R0```"(````G`````````)@```"&````
M.````*P```!&````80```*L`````````+@````````!9````U````)4````F
M````=@```$```````````````((````]````G0```+D```"X````"0````8`
M``!K````(````)(```!"````CP`````````Y````,0`````````=````G@``
M``````"6``````````````"'`````````$L````E`````````&X`````````
M6`````T`````````P@```+L```!7````4P```#8```!(````8@``````````
M``````````````!,````0P```#4```#9```````````````8````:0```"H`
M``#``````````$<````7````4`````X````<````70````````!U````S@``
M````````````7@```%0```"%`````````)$`````````"````&T```".````
M$``````````"````HP```*(```````````````````#1````R@```$\`````
M````B````,<```!<````SP```````````````````"P```"``````````'H`
M```D````J@```#<```##````/@`````````\````GP```+8```!@````9@``
M`),```!L````V@```-@````6````*P```'$```!;````K0```-8````1````
MS0````<```"D`````````,P```",````%``````@("`@("!#8SH@`"`@("`@
M(%1O.B``("`@($1A=&4Z(``@("`@1G)O;3H@`"!3=6)J96-T.B``069G:&%N
M:7-T86X`06QB86YI80!!;&=E<FEA`$%L;`!!;G1A<F-T:6-A`$%R9V5N=&EN
M80!!<FUE;FEA`$%U<W1R86QI80!!=7-T<FEA`$)A:&%M87,`0F%H<F%I;@!"
M86YG;&%D97-H`$)C8P!"96QG:75M`$)E;&EZ90!";&%C:VQI<W0`0F]L:79I
M80!";W1S=V%N80!"<F%Z:6P`0G)U;F5I($1A<G5S<V%L86T`0G5R=6YD:0!#
M86UB;V1I80!#86UE<F]O;@!#86YA9&$`0V%N8V5L`$-A<&4@5F5R9&4`0V,`
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-H860`0VAI;&4`0VAI;F$`0VQE
M87(`0VQO<V4`0VQO<V4@=&AI<R!W:6YD;W<`0VQO=61Y`$-O;&]M8FEA`$-O
M;6UE;G0`0V]N9V\`0V]S=&$@4FEC80!#=6)A`$-Y<')U<P!#>F5C:"!297!U
M8FQI8P!$871?90!$871E`$1E;&5T90!$96YM87)K`$1O;6EN:6-A;B!297!U
M8FQI8P!%+6UA:6P@061D<F5S<P!%8W5A9&]R`$5G>7!T`$5L(%-A;'9A9&]R
M`$5T:&EO<&EA`$9I:FD`1FEN;&%N9`!&;V<`1F]R=V%R9`!&;W)W87)D.@!&
M<F%N8V4`1G)O7VT`1G)O;0!'86)O;@!'86UB:6$`1V5N97)A;"!/<'1I;VYS
M`$=E;W)G:6$`1V5R;6%N>0!':&%N80!';P!'<F5E8V4`1W)E;F%D80!'=6%T
M96UA;&$`1W5I;F5A`$=U>6%N80!(86ET:0!(96%D97)S`$AE879Y(%0M4W1O
M<FT`2&5L<`!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VYD=7)A
M<P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;F=A<GD`24Y"3U@`26-E;&%N9`!)
M;7!O<G0`26YD:6$`26YD;VYE<VEA`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8`27)A<0!)<F5L86YD`$ES<F%E;`!)=&%L>0!*86UA:6-A`$IA<&%N`$IO
M<F1A;@!+96YY80!+=7=A:70`3&5B86YO;@!,:6)E<FEA`$QI8GEA;B!!<F%B
M($IA;6%H:7)I>6$`3'5X96UB;W5R9P!-861A9V%S8V%R`$UA;&%W:0!-86QA
M>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA=7)I=&%N:6$`36%U<FET:75S
M`$UE>&EC;P!-;VYA8V\`36]N9V]L:6$`36]R;V-C;P!-;W9E`$UO>F%M8FEQ
M=64`3F%M90!.97!A;`!.971H97)L86YD<P!.97<@365S<V%G90!.97<@6F5A
M;&%N9`!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.;W)W87D`3TL`3U(`3VUA
M;@!/<'1I;VYS`$]T:&5R`%!A:VES=&%N`%!A;F%M80!087)A9W5A>0!087-S
M=V]R9`!087-S=V]R9#H`4&%S<W=O<F0Z(`!097)U`%!H:6QI<'!I;F5S`%!O
M;&%N9`!0;W)T=6=A;`!0<FEN=`!1871A<@!297!L>0!297!L>2!T;R!!;&P`
M4F]M86YI80!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%-A=61I($%R86)I
M80!396%R8V@`4V5N96=A;`!397EC:&5L;&5S`%-I97)R82!,96]N90!3:6YG
M87!O<F4`4VEZ93H`4V]M86QI80!3;W5T:"!!9G)I8V$`4W!A:6X`4W)I($QA
M;FMA`%-U8E]J96-T`%-U8FIE8W0`4W5D86X`4W5R:6YA;64`4W=A>FEL86YD
M`%-W961E;@!3=VET>F5R;&%N9`!3>7)I86X@07)A8B!297!U8FQI8P!486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1H86EL86YD`%1O`%1O;F=A`%1R
M:6YI9&%D(&%N9"!4;V)A9V\`5'5N:7-I80!4=7)K97D`55),`%523#H`56=A
M;F1A`%5K<F%I;F4`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D
M;VT`56YI=&5D(%-T871E<P!5<&QO860`57!L;V%D.@!5<G5G=6%Y`%5S97)N
M86UE`%9A;G5A='4`5F5N97IU96QA`%9E<G-I;VX`5FEE="!.86T`5VEN9`!7
M:6YD.@!7:6YD.B``665M96X`66]U(&AA=F4@,2!N97<@;65S<V%G92X`675G
M;W-L879I80!:86UB:6$`6FEM8F%B=V4`7T)C8P!?0FQA8VML:7-T`%]#8P!?
M1&5L971E`%]&;VQD97)S`%](96QP`%]);F)O>`!?3&]G(&]U=`!?3F5W($UE
M<W-A9V4`7T]P=&EO;G,`7U!R:6YT`%]297!L>0!?4V5A<F-H`%]4;P!A9&1R
M97-S(&)O;VL`9G)O;0!N86UE`&]R`%!R;VIE8W0M260M5F5R<VEO;CH@26UP
M($@S("@T+C(M8W9S*0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,2TR-"`Q-CHU
M-RLP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#$M,C0@,38Z-3<K,#$P
M,`I,87-T+51R86YS;&%T;W(Z($UA='0@4V5L<VMY(#QS96QS:WE`8V]L=6UB
M:6$N961U/@I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-
M24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]551&+3@*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`
M("`@("`@UY37HM>JUZ?7F=>=.B``("`@("`@UY#7G#H@`"`@("#7JM>0UZC7
MF=>:.B``("`@(->>UY#7JCH@`"#7H->5UZG7D#H@`->0UZ37DM>@UYG7H=>J
MUY\`UY#7G->1UZ#7F=>4`->0UYS7DM>HUYG7E`#7E->;UYP`UYG7D=>IUZKB
M@)/7D->@UYC7D->HUZ?7F->9UZ?7E`#7D->HUY+7H->8UYG7H->4`->0UZC7
MGM>@UYG7E`#7D->5UZ'7F->HUYS7F=>4`->0UY77H=>8UZC7F=>4`->0UYG7
MF>*`D]>1UY37GM>4`->1UY?7J->9UYG7GP#7D=>@UY+7G->3UZD`UY37HM>J
MUZ?7F=>=(->BUYG7E=>5UZC7F=>=`->1UYS7DM>9UY0`UY'7G->9UY8`UZC7
MJ=>9UY[7E"#7J=>7UY77J->4`->1UY77G->9UY'7F=>4`->1UY77IM>5UY77
MH->4`->1UZC7EM>9UYP`UY'7J->5UZ#7F=>9`->1UY77J->5UZ#7D]>9`->G
MUY[7D=>5UY/7F=>4`->GUY[7J->5UY\`UZ?7H->3UY0`UZG7H->4`->GUZ37
ME"#7E=>HUY/7E`#7E->BUZK7I]>9UYT`UY37I]>4UYG7G->9UYG7E"#7E->>
MUZC7F]>6XH"3UY#7I->HUYG7I]>@UYG7J@#7IM>3`->FUYG7G->9`->AUYG7
MGP#7J=>>UYG7G2#7D=>4UYG7J->=`->AUY+7E=>H`->AUY+7F=>HUZH@UY?7
MG->5UY\@UY;7E`#7J=>>UYG7G2#7GM>BUY77H->@UYG7G0#7I]>5UYS7E=>>
MUY'7F=>4`->JUY+7E=>1UY0`UZ?7E=>@UY+7E0#7I]>5UZ'7F->4(->HUYG7
MI]>4`->GUY77D=>4`->GUZ37J->9UZ'7F=>?`->FUYO7F=>4`->JUY#7J->9
MUYH`UZK7D->HUYG7F@#7GM>7UZ<`UY/7H->9UY0`UY37J->DUY77D=><UYG7
MI]>4(->4UY/7E=>>UYG7H->9UZ?7H->9UZH`UY/7E=>0UZ@MUY#7G->GUYC7
MJ->5UZ#7F0#7D->GUY77E=>3UY77J`#7GM>FUZC7F=>=`->0UYSB@)/7H=><
MUY77E=>3UY77J`#7D->JUYG7E=>DUYG7E`#7I->9UY+7F0#7I->9UZ#7G->@
MUY,`UZ+7J->DUYP`UY37I->E`->4UZ37I3H`UZ;7J->DUZH`UY[7D->J`->>
MUY#7J@#7DM>1UY77GP#7DM>>UY'7F=>4`->0UZ37J=>HUY77F=>5UZH@UYO7
MG-><UYG7E=>J`->2UY77J->2UYG7E`#7DM>HUY[7H->9UY0`UY+7H->4`-><
MUYH`UYG7E=>5UY\`UY+7J->@UY/7E`#7DM>5UY#7F->>UYS7E`#7DM>9UZ#7
MD->4`->2UYG7D->@UY0`UY37D->9UYC7F0#7F]>5UZK7J->5UZH`UZ'7E=>D
MUZKB@)/7J->BUY[7F=>=(->BUY;7E`#7HM>6UZC7E`#7E=>8UYG7I]>?`->4
MUY77H->3UY77J->A`-><UY?7E=>J`#K7G->7UYG7J@#7E->5UZ#7DM>HUYG7
ME`#7D]>5UY#7J"#7H->;UZ#7H0#7D->9UZ'7G->@UY,`UYG7D=>0`->4UY77
MD]>5`->0UYG7H->3UY77H->6UYG7E`#7D->9UZC7GP#7HM>9UZC7IP#7D->9
MUZC7G->@UY,`UYG7J=>!UZC7D-><`->0UYG7F-><UYG7E`#7DM>>UYG7F=>G
MUY0`UYG7I->?`->9UZC7D]>?`->GUZ#7F=>4`->;UY77E=>9UYG7J@#7G->1
MUZ#7E=>?`-><UYG7D=>HUYG7E`#7G->5UY$`UYS7E=>;UZ'7GM>1UY77J->2
M`->>UY/7DM>AUZ?7J`#7GM><UY77E=>9`->>UYS7F=>9UY;7F=>4`->4UY#7
MF=>9UYT@UY37GM><UY/7F=>5UY77F=>9UYT`UY[7G->9`->>UYS7F->4`->>
MUY#7E=>HUYG7F->@UYG7E`#7GM>0UY77J->9UZ;7F=>5UZ$`UY[7F]>AUYG7
MI]>5`->>UY77H->GUY4`UY[7E=>@UY+7E=><UYG7E`#7GM>HUY77I]>5`->4
MUZ+7D=>H`->>UY77EM>>UY'7F=>G`->IUYT`UZ#7I-><`->4UY77G->@UY,`
MUY37E=>3UZ+7E"#7E]>3UZG7E`#7H->9UY7B@)/7EM>9UYS7H->3`->@UYG7
MI]>HUY+7E=>0UY0`UZ#7F=>6UZ@`UZ#7F=>2UZC7F=>4`->@UY77J->5UY77
MDM>9UY0`UY#7F=>IUY77J`#7D->5`->BUY77GM>0UY\`UY#7I->IUZC7E=>9
MUY77J@#7D->7UZ@`UZ37I]>9UZ'7JM>?`->DUZ#7GM>4`->DUZC7DM>5UY#7
MF=>9`->AUYG7H=>>UY``UZ'7F=>AUY[7D#H`UZ'7F=>AUY[7D#H@`->DUZC7
ME0#7I->9UYS7F=>DUYG7H->9UYG7G0#7I->5UYS7F=>?`->DUY77J->8UY77
MDM><`->4UY/7I->A`->GUYC7J`#7E->IUY$`UY37J=>1(-><UYO7G`#7J->5
MUY[7H->9UY0`UZC7E=>AUYG7E`#7J->5UY#7H->3UY0`UZ+7J->1(->4UZ'7
MHM>5UY/7F=>J`->7UZ37J0#7H=>@UY+7G`#7D->9UYGB@)/7H=>9UYG7J=><
M`->GUYG7F=>HUY0@UYS7F=>0UY77GP#7H=>9UZ#7DM>DUY77J`#7DM>5UY/7
MG#H`UZ'7E=>>UYS7F=>4`->3UZC7E=>=XH"3UY#7I->HUYG7I]>4`->AUZ37
MJ->3`->AUZC7F2#7G->@UZ?7E`#7H->5UZG7D`#7H->5UZG7D`#7H=>5UY/7
MGP#7H=>5UZC7F=>@UYT`UZ'7E=>5UY;7F=><UZ#7DP#7J=>5UY77D]>9UY0`
MUZG7E=>5UYG7I0#7H=>5UZC7F=>4`->8UZ#7EM>@UYG7E`#7JM>0UYG7G->@
MUY,`UY#7G`#7I]>1UY77IM>JXH"3UY#7F=>9XH"3UYC7E=>@UY+7E`#7F->H
MUYG7H->9UY/7DR#7E=>8UY77D=>2UY4`UYC7E=>@UYG7H=>9UY0`UYC7E=>H
MUZ?7F=>9UY0`UY#7JM>H`->0UZK7J#H`UY#7E=>2UZ#7D]>4`->0UY77I]>H
MUYG7F=>@UY0`UY37D->>UYG7J->5UYG7E=>J(->4UY[7D->5UY?7D]>5UZH`
MUY37GM>>UYS7F]>4(->4UY[7D->5UY?7D]>J`->0UZC7IM>5UZKB@)/7E->1
MUZC7F=>J`->4UZ+7G->0UY0`UY37HM><UY#7E#H`UY#7E=>HUY77DM>5UY77
MF0#7I]>5UY,@UY;7F=>4UY77F2#7GM>IUZK7GM>I`->5UZ#7E=>0UYC7E0#7
ME=>@UY;7E=>0UYS7E`#7DM>9UZC7H=>4`->5UYG7F=>8XH"3UZ#7G0#7J->5
MUY<`UZC7E=>7.@#7J->5UY<Z(`#7JM>9UY[7GP#7F=>IUX$@UYS7FB#7D]>5
MUY#7J"#7E]>3UZDN`->9UY77DM>5UZ'7G->1UYG7E`#7EM>>UY'7F=>9UY0`
MUY;7F=>>UY'7D=>5UY77E`#7E->BUZK7I]>9UYT@UZ+7F=>5UY77J->9UYT`
MUZC7J=>9UY[7E"#7J=>7UY77J->4`->4UZ+7JM>GUYG7G0#7GM>7UZ<`UZK7
MF=>GUYG7E=>J`->BUY;7J->4`->3UY77D->H(->@UYO7H->A`->4UZK7H->J
MUZ?7E=>J`->4UY77D]>BUY0@UY?7D]>IUY0`UY#7I->IUZC7E=>9UY77J@#7
ME->3UZ37H0#7E->IUY$`UY?7I->I`->0UYP`UZ'7I->H(->;UZK7E=>1UY77
MJ@#7GM>0UZH`UZG7G0#7D->5````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VED7TE$+P``
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S8S`#`Q-S0R,0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM
M<"]L;V-A;&4O:61?240O3$-?34534T%'15,O````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#(Q,C`V`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]I9%])1"],0U]-15-304=%4R]I
M;7`N;6\````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(S,3,V-@`Q,#0Q-S,V,C<V
M,P`P,C(S-#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````!L!```'````'PC``#G!0``W$8```````!X7@``"@``
M`'E>```*````A%X```H```"/7@``"@```)I>```$````I5X```0```"J7@``
M)````*]>```I````U%X``!D```#^7@```0```!A?```F````&E\```P```!!
M7P``)````$Y?```7````<U\```\```"+7P``"P```)M?```H````IU\```@`
M``#07P``%0```-E?```R````[U\```L````B8```*0```"Y@```R````6&``
M`(4```"+8```"@```!%A```.````'&$``!L````K80``+@```$=A```W````
M=F$``'P```"N80``'````"MB```=````2&(```\```!F8@``&````'9B```.
M````CV(```X```">8@``"````*UB```N````MF(```D```#E8@``#0```.]B
M```'````_6(```H````%8P``#P```!!C```%````(&,``!$````F8P``"```
M`#AC```)````06,```D```!+8P``$P```%5C```0````:6,```H```!Z8P``
M`P```(5C```/````B6,```D```"98P``#0```*-C```/````L6,```\```#!
M8P``"````-%C```D````VF,```@```#_8P``&0````AD```,````(F0```X`
M```O9````P```#YD```%````0F0```H```!(9````P```%-D```7````5V0`
M``H```!O9```#@```'ID``!.````B60``%````#89```0@```"EE```C````
M;&4``!0```"090``%P```*5E```7````O64``!<```#590``$P```.UE```/
M`````68```8````19@``"````!AF```1````(68```L````S9@``$````#]F
M```5````4&8``",```!F9@``%0```(IF```'````H&8```4```"H9@``%0``
M`*YF```A````Q&8``#L```#F9@``.P```")G```K````7F<``#$```"*9P``
M%````+QG```,````T6<```,```#>9P``"0```.)G```)````[&<``#D```#V
M9P``!@```#!H```*````-V@```L```!":```)P```$YH```L````=F@``"H`
M``"C:```)0```,YH```&````]&@``!$```#[:```#`````UI```*````&FD`
M``H````E:0``$````#!I```4````06D```@```!6:0```P```%]I```)````
M8VD```X```!M:0``"@```'QI```$````AVD```0```",:0``"0```)%I```&
M````FVD``!$```"B:0``!P```+1I```$````O&D```8```#!:0``#0```,AI
M```#````UFD``!,```#::0``!````.YI``!!````\VD```8````U:@``#@``
M`#QJ```5````2VH``#X```!A:@``!P```*!J```5````J&H```(```"^:@``
M#P```,%J```-````T6H```\```#?:@``#0```.]J```4````_6H```8````2
M:P``'0```!EK```&````-VL```H````^:P``%````$EK``!B````7FL``%0`
M``#!:P``7P```!9L``!D````=FP```0```#;;```#@```.!L```<````[VP`
M`!L````,;0``&@```"AM```.````0VT``!4```!2;0``'````&AM```J````
MA6T```4```"P;0``$P```+9M```2````RFT```H```#=;0``#P```.AM```-
M````^&T``!$````&;@``#````!AN```-````)6X```8````S;@``#````#IN
M```&````1VX```P```!.;@``%````%MN```/````<&X``!````"`;@``$0``
M`)%N```%````HVX```P```"I;@``!0```+9N```&````O&X```<```##;@``
M#0```,MN```F````V6X```D`````;P``"0````IO```*````%&\``!D````?
M;P``'0```#EO```,````5V\``!````!D;P``"````'5O```(````?F\``%P`
M``"';P``!@```.1O```$````ZV\```X```#P;P``!P```/]O```.````!W``
M`!T````6<```(````#1P``"B````57```!\```#X<```(````!AQ```P````
M.7$``)(```!J<0``00```/UQ```'````/W(```8```!'<@``#0```$YR```-
M````7'(``!H```!J<@``$````(5R```=````EG(``!D```"T<@``70```,YR
M```,````+',```X````Y<P``#P```$AS```3````6',```T```!L<P``*```
M`'IS```#````HW,```T```"G<P``$0```+5S```7````QW,``!L```#?<P``
M`@```/MS```0````_G,```0````/=```#0```!1T```#````(G0```X````F
M=```"````#5T```/````/G0```\```!.=```#0```%YT```-````;'0``!D`
M``!Z=```&@```)1T```+````KW0```8```"[=```"P```,)T```0````SG0`
M``P```#?=```"P```.QT```-````^'0``"(````&=0``,P```"EU```*````
M774``!@```!H=0``&0```(%U```6````FW4```<```"R=0``$````+IU```<
M````RW4```H```#H=0``%````/-U```+````"'8```D````4=@``&0```!YV
M```+````.'8```\```!$=@``%P```%1V```7````;'8```D```"$=@``!P``
M`(YV```6````EG8```\```"M=@``&0```+UV```6````UW8``"@```#N=@``
M(P```!=W```F````.W<``"````!B=P``0P```(-W```$````QW<``!(```#,
M=P``+P```-]W```%````#W@```X````5>```!0```"1X```$````*G@```H`
M```O>```"@```#IX```0````17@``!<```!6>```$0```&YX```7````@'@`
M`!8```"8>```"0```*]X```*````N7@```(```#$>```#0```,=X```/````
MU7@``!(```#E>```.````/AX```@````,7D``!4```!2>0``#@```&AY``![
M````=WD``!@```#S>0``*0````QZ```L````-GH``"@```!C>@``!0```(QZ
M```;````DGH```8```"N>@``$````+5Z```/````QGH``!````#6>@``#P``
M`.=Z```/````]WH```P````'>P``#P```!1[```'````)'L```H````L>P``
M$@```#=[```-````2GL```P```!8>P``#@```&5[```]````='L```@```"R
M>P``$P```+M[```$````SWL```4```#4>P``"````-I[```*````XWL```P`
M``#N>P``"P```/M[```0````!WP```P````8?```)0```"5\```'````2WP`
M``0```!3?```"@```%A\```*````8WP```T```!N?```!0```'Q\```#````
M@GP``!````"&?```"@```)=\```$````HGP``"8```"G?```#@```,Y\``!\
M````W7P``!4```!:?0``!0```'!]```'````=GT```P```!^?0``"````(M]
M```*````E'T```8```"??0``!P```*9]```(````KGT``!D```"W?0``"```
M`-%]```"````VGT```8```#=?0``!````.1]```,````Z7T```D```#V?0``
M$`````!^```)````$7X```D````;?@``!````"5^```:````*GX```@```!%
M?@``&0```$Y^```.````:'X```8```!W?@``#0```'Y^```2````C'X``!0`
M``"??@``!@```+1^```1````NWX```D```#-?@``.0```-=^```]````$7\`
M`#H```!/?P``!````(I_```5````CW\```8```"E?P``!````*Q_```1````
ML7\```H```##?P``(@```,Y_```,````\7\``!$```#^?P``!0```!"````.
M````%H````4````E@```#P```"N````2````.X````L```!.@```)@```%J`
M```I````@8```"0```"K@```)@```-"````(````]X````H`````@0``"0``
M``N!```%````%8$``!(````;@0``"@```"Z!```,````.8$```\```!&@0``
M$````%:!``!P````9X$```8```#8@0``"@```-^!```.````ZH$```D```#Y
M@0``"@````."```2````#H(``!,````A@@``!@```#6"```/````/((```D`
M``!,@@``$@```%:"```2````:8(``!````!\@@``$0```(V"```D````GX(`
M`&H```#$@@``#P```"^#```0````/X,```L```!0@P``(````%R#```4````
M?8,```P```"2@P``#````)^#```/````K(,``!4```"\@P``*0```-*#```J
M````_(,``"8````GA```)P```$Z$```I````=H0``"H```"@A```&0```,N$
M``!"````Y80``!$````HA0``$@```#J%```3````384``!0```!AA0``%@``
M`':%```7````C84``!````"EA0``$0```+:%```T````R(4``!,```#]A0``
M$@```!&&```4````)(8``!H````YA@``"0```%2&```1````7H8```8```!P
MA@``!P```'>&```6````?X8```0```"6A@``!````)N&```'````H(8```X`
M``"HA@``#````+>&```,````Q(8```T```#1A@``#@```-^&```$````[H8`
M``\```#SA@``!P````.'```(````"X<```D````4AP``"0```!Z'```4````
M*(<```P````]AP``#0```$J'```#````6(<```8```!<AP``&0```&.'```$
M````?8<```T```""AP``"@```)"'```0````FX<```\```"LAP``$0```+R'
M```7````SH<```H```#FAP``$0```/&'```(`````X@```\````,B```#```
M`!R(```.````*8@``!`````XB```"P```$F(```:````58@```H```!PB```
M#````'N(```/````B(@```8```"8B```#````)^(```'````K(@```L```"T
MB```!````,"(```3````Q8@``!,```#9B```$P```.V(```"`````8D```0`
M```$B0``!0````F)```*````#XD```<````:B0``#0```"*)``!H````,(D`
M``4```"9B0``!@```)^)```(````IHD``#<```"OB0``#P```.>)```8````
M]XD``!<````0B@``'P```"B*```#````2(H```@```!,B@``!P```%6*```*
M````78H```L```!HB@``!P```'2*```3````?(H```P```"0B@``#@```)V*
M```,````K(H```X```"YB@``#P```,B*```-````V(H```\```#FB@``)@``
M`/:*```+````'8L```T````IBP``&@```#>+``!*````4HL```8```"=BP``
M!@```*2+```8````JXL``!<```#$BP``#0```-R+``!7````ZHL```(```!"
MC```"P```$6,```(````48P```8```!:C```"@```&&,```+````;(P```P`
M``!XC```#0```(6,```,````DXP```0```"@C```"@```*6,```6````L(P`
M``D```#'C```$````-&,```2````XHP```0```#UC```!P```/J,```%````
M`HT```,````(C0``#`````R-```*````&8T```@````DC0``"````"V-```7
M````-HT```P```!.C0``#````%N-```:````:(T``!,```"#C0``!````)>-
M```*````G(T```0```"GC0``#````*R-```)````N8T```4```##C0```@``
M`,F-```X````S(T```H````%C@``&0```!".```/````*HX``!,````ZC@``
M%0```$Z.```3````9(X```@```!XC@``"````(&.```2````BHX```X```"=
MC@``*P```*R.``!%````V(X``$$````>CP``!````&"/```3````98\``!0`
M``!YCP``$P```(Z/```+````HH\```D```"NCP``#0```+B/```,````QH\`
M`!0```#3CP``%@```.B/```'````_X\```4````'D```&P````V0```(````
M*9```!$````RD```/````$20```.````@9````(```"0D```#@```).0```'
M````HI````X```"JD```!@```+F0```H````P)````P```#ID```#````/:0
M```<`````Y$``",````@D0``%P```$21``!<````7)$``!0```"YD0``'P``
M`,Z1```0````[I$```<```#_D0``#@````>2```,````%I(```H````CD@``
M'0```"Z2```9````3)(```4```!FD@``$0```&R2```-````?I(``!$```",
MD@``"````)Z2```)````IY(```T```"QD@``"@```+^2```'````RI(```\`
M``#2D@``!@```.*2```+````Z9(``!H```#UD@``"@```!"3```'````&Y,`
M``T````CDP``!P```#&3```-````.9,```@```!'DP``'@```%"3```)````
M;Y,```H```!YDP``%0```(23```%````FI,``!0```"@DP``!````+63```0
M````NI,```8```#+DP``!P```-*3```>````VI,``"@```#YDP``'````"*4
M```:````/Y0```@```!:E```%````&.4```$````>)0```8```!]E```!@``
M`(24```Q````BY0```H```"]E```&P```,B4```T````Y)0``#0````9E0``
M*0```$Z5```G````>)4``"@```"@E0``&@```,F5```H````Y)4``"D````-
ME@``4````#>6```N````B)8``#8```"WE@``+````.Z6```Q````&Y<```@`
M``!-EP``!0```%:7```9````7)<``!D```!VEP``(P```)"7```9````M)<`
M``@```#.EP``%P```->7```*````[Y<``"$```#ZEP``$````!R8```-````
M+9@```4````[F```#@```$&8```3````4)@```@```!DF```#0```&V8```6
M````>Y@``#X```"2F```!0```-&8```%````UY@```0```#=F```"@```.*8
M```)````[9@```L```#WF```#0````.9```,````$9D```X````>F0``!```
M`"V9```R````,ID``$4```!EF0``"````*N9```0````M)D``!4```#%F0``
M$P```-N9```7````[YD```<````'F@``'@````^:```5````+IH``!0```!$
MF@``"P```%F:```'````99H``!8```!MF@``#@```(2:```J````DYH```8`
M``"^F@``#````,6:```1````TIH```L```#DF@``-@```/":```*````)YL`
M`"(````RFP``"P```%6;```/````89L``"X```!QFP``#0```*";```%````
MKIL```P```"TFP``#0```,&;```*````SYL```8```#:FP``#@```.&;```%
M````\)L```X```#VFP``$P````6<```'````&9P```8````AG```2P```"B<
M```3````=)P``!0```"(G```&````)V<```'````MIP```4```"^G```$@``
M`,2<```.````UYP```X```#FG```!0```/6<```%````^YP``"X````!G0``
M)@```#"=```C````5YT```,```![G0``#0```'^=```)````C9T```,```"7
MG0``"@```)N=```"````IIT``!(```"IG0``!P```+R=```*````Q)T```<`
M``#/G0``4@```->=```7````*IX``#D```!"G@``$@```'R>```'````CYX`
M``8```"7G@``#@```)Z>```.````K9X```0```"\G@``!@```,&>```5````
MR)X``!(```#>G@``#P```/&>```4`````9\```H````6GP``"P```"&?``!I
M````+9\``!H```"7GP``%P```+*?```G````RI\``!H```#RGP``%P````V@
M```;````):```!D```!!H```'P```%N@```,````>Z```!,```"(H```"```
M`)R@```1````I:````D```"WH```!@```,&@``!&````R*```$,````/H0``
M/P```%.A```W````DZ$``%<```#+H0``!0```".B```?````*:(``"\```!)
MH@``"````'FB```-````@J(``"T```"0H@``.0```+ZB```$````^*(```P`
M``#]H@``$0````JC``!/````'*,``"4```!LHP``(````)*C```?````LZ,`
M`!T```#3HP``)0```/&C```@````%Z0``"0````XI```(````%VD```'````
M?J0```T```"&I```#````)2D```7````H:0```0```"YI```$````+ZD```$
M````SZ0```L```#4I```#````."D```2````[:0``!$`````I0``#````!*E
M```:````'Z4```T````ZI0``&P```$BE```3````9*4``!P```!XI0``*```
M`)6E```'````OJ4``!,```#&I0``!````-JE```7````WZ4``!(```#WI0``
M"P````JF```-````%J8``!0````DI@``+P```#FF```*````::8```P```!T
MI@``"0```(&F```&````BZ8```@```"2I@``"0```)NF```-````I:8```L`
M``"SI@```@```+^F```'````PJ8```T```#*I@``%@```-BF```)````[Z8`
M``<```#YI@``&@````&G```[````'*<``"@```!8IP``-````(&G```5````
MMJ<```L```#,IP``"````-BG```'````X:<```4```#IIP``!P```.^G```.
M````]Z<```D````&J```!@```!"H```(````%Z@```L````@J```!P```"RH
M```'````-*@``!$````\J```"````$ZH```0````5Z@``!````!HJ```!P``
M`'FH```%````@:@``!0```"'J```"P```)RH```-````J*@``"@```"VJ```
M%P```-^H```$````]Z@```D```#\J```"@````:I```'````$:D```(````9
MJ0``#@```!RI```Q````*ZD``"<```!=J0``%````(6I```S````FJD``!X`
M``#.J0``=0```.VI```^````8ZH``$(```"BJ@``/0```.6J```]````(ZL`
M`"D```!AJP``*0```(NK```Q````M:L``*D!``#GJP``(P```)&M```7````
MM:T``!T```#-K0``&````.NM```A````!*X``!\````FK@``*````$:N```K
M````;ZX``!T```";K@``$0```+FN```G````RZX``"8```#SK@``/@```!JO
M``!'````6:\``%<```"AKP``50```/FO```O````3[```%4```!_L```5```
M`-6P```K````*K$```L```!6L0``.P```&*Q```/````GK$``#$```"NL0``
M"P```."Q```'````[+$```<```#TL0``#0```/RQ```+````"K(```4````6
ML@``$````!RR```"````+;(```4````PL@``$@```#:R```(````2;(```,`
M``!2L@``$````%:R```,````9[(```T```!TL@```@```(*R```4````A;(`
M``P```":L@```P```*>R```$````J[(``!H```"PL@``"@```,NR```3````
MUK(```@```#JL@``"0```/.R```6````_;(```P````4LP``%P```"&S```'
M````.;,```\```!!LP``!0```%&S```:````5[,```<```!RLP``QP```'JS
M```&````0K0```L```!)M```&@```%6T```&````<+0```D```!WM```"P``
M`(&T```-````C;0``!<```";M```,P```+.T```3````Y[0``!,```#[M```
M$0````^U```>````(;4``#(```!`M0``$P```'.U```1````A[4``#(```"9
MM0``%@```,RU```(````X[4```H```#LM0``%````/>U```(````#+8```@`
M```5M@``#P```!ZV```.````+K8``!`````]M@``"0```$ZV```)````6+8`
M`!,```!BM@``!P```':V```9````?K8``"<```"8M@``"@```,"V```,````
MR[8``"H```#8M@``!P````.W```"````"[<``!`````.MP``&````!^W```#
M````.+<```@````\MP``!P```$6W```-````3;<```L```!;MP``%````&>W
M```5````?+<``"\```"2MP``(````,*W```<````X[<``%H`````N```#```
M`%NX```Q````:+@```D```":N```!0```*2X```_````JK@``!(```#JN```
M"@```/VX```&````"+D```0````/N0``!````!2Y```*````&;D``!,````D
MN0``!0```#BY```&````/KD```8```!%N0``"````$RY```$````5;D```4`
M``!:N0```@```&"Y```#````8[D```P```!GN0``)P```'2Y```A````G+D`
M`"0```"^N0``10```..Y```R````*;H``!T```!<N@``&0```'JZ```7````
ME+H``"H```"LN@``*P```->Z``!%`````[L``#````!)NP``)P```'J[```A
M````HKL``"@```#$NP``*P```.V[```=````&;P``"D````WO```)@```&&\
M```E````B+P``"@```"NO```/0```->\``!!````%;T``"@```!7O0``+```
M`("]```2````K;T``!,```#`O0``$````-2]``!S````Y;T``"L```!9O@``
M%P```(6^```G````G;X``!8```#%O@``#P```-R^```?````[+X``!P````,
MOP``40```"F_```4````>[\```\```"0OP``!0```*"_```2````IK\```P`
M``"YOP``$````,:_```3````U[\```\```#KOP``!````/N_```)`````,``
M``L````*P```!P```!;````4````'L````\````SP```#````$/````/````
M4,````8```!@P```%````&?````&````?,````0```"#P```!P```(C````$
M````D,```!D```"5P```!P```*_````&````M\````8```"^P```!````,7`
M```"````RL````<```#-P```!@```-7````&````W,```!````#CP```#@``
M`/3````/`````\$```8````3P0``(@```!K!```'````/<$```L```!%P0``
M4P$``%'!```.````I<(```T```"TP@``"@```,+"```*````S<(```8```#8
MP@``!@```-_"```L````YL(``"P````3PP``%@```$##```!````5\,``$``
M``!9PP``#````)K#```P````I\,``!8```#8PP``%0```._#```2````!<0`
M`"0````8Q```"````#W$```;````1L0``#````!BQ```#0```)/$```K````
MH<0``"T```#-Q```OP```/O$```(````N\4```X```#$Q0``&P```-/%```S
M````[\4``#H````CQ@``;P```%[&```9````SL8``!@```#HQ@``%0````''
M```8````%\<```T````PQP``#0```#['```&````3,<``"L```!3QP``"@``
M`'_'```*````BL<```@```"5QP``"@```)['```0````J<<```4```"ZQP``
M$@```,#'```+````T\<``#H```#?QP``/````!K(```1````5\@```T```!I
MR```"0```'?(```&````@<@``!````"(R```#@```)G(```0````J,@``!4`
M``"YR```$P```,_(```/````X\@``"T```#SR```#P```"')```E````,<D`
M``L```!7R0``#````&/)```%````<,D```0```!VR0``"````'O)```%````
MA,D``!,```"*R0``"@```)[)```0````J<D``$8```"ZR0``4P````'*``!"
M````5<H``#(```"8R@``%````,O*```4````X,H``!P```#UR@``%@```!++
M```2````*<L```\````\RP``!P```$S+```%````5,L```L```!:RP``"```
M`&;+```/````;\L``!0```!_RP``)@```)3+```;````N\L```D```#7RP``
M!0```.'+```3````Y\L``!\```#[RP``20```!O,```[````9<P``"D```"A
MS```+P```,O,```3````^\P``!`````/S0``!````"#-```-````)<T```H`
M```SS0``/0```#[-```)````?,T```@```"&S0``$0```(_-```L````H<T`
M`"P```#.S0``*P```/O-```M````)\X```<```!5S@``%````%W.```+````
M<LX```T```!^S@``#@```(S.```4````F\X``!0```"PS@``.0```,7.```#
M````_\X```D````#SP``#P````W/```)````'<\```0````GSP``"P```"S/
M```4````.,\```8```!-SP``$````%3/```&````9<\```@```!LSP``!0``
M`'7/```-````>\\```,```")SP``#0```(W/```&````F\\``%4```"BSP``
M"````/C/```.`````=```!@````0T```/@```"G0```+````:-```!(```!T
MT````@```(?0```,````BM```#$```"7T```#````,G0```6````UM```!0`
M``#MT```!@````+1```9````"=$```0````CT0``"@```"C1```/````,]$`
M`'T```!#T0``9@```,'1``!=````*-(``&@```"&T@``"````._2```/````
M^-(``!H````(TP``%P```"/3```7````.],```L```!3TP``$@```%_3```E
M````<M,``#,```"8TP``"0```,S3```6````UM,``!8```#MTP``$@````34
M```7````%]0``!@````OU```$0```$C4```-````6M0```\```!HU```!P``
M`'C4```4````@-0```<```"5U```"P```)W4```2````J=0```P```"\U```
M&````,G4```/````XM0```4```#RU```#0```/C4```%````!M4```8````,
MU0``!P```!/5```-````&]4``"$````IU0``"````$O5```'````5-4```<`
M``!<U0``%0```&35```H````>M4```L```"CU0``$````*_5```&````P-4`
M``8```#'U0``7````,[5```&````*]8```0````RU@``#0```#?6```%````
M1=8```H```!+U@``)@```%;6```D````?=8``+L```"BU@``(P```%[7```E
M````@M<``#$```"HUP``O0```-K7``!4````F-@```8```#MV```!````/38
M```+````^=@```D````%V0``%P````_9```)````)]D``!H````QV0``%@``
M`$S9``!6````8]D```X```"ZV0``$P```,G9```.````W=D``!$```#LV0``
M#0```/[9```N````#-H```4````[V@``#0```$':```1````3]H``!<```!A
MV@``&P```'G:```"````E=H``!````"8V@``!P```*G:```0````L=H```0`
M``#"V@``"P```,?:```(````T]H```T```#<V@``$````.K:```-````^]H`
M``T````)VP``'````!?;```8````--L```@```!-VP``!0```%;;```)````
M7-L```P```!FVP``"@```'/;```)````?ML```L```"(VP``)P```)3;```L
M````O-L```L```#IVP``'0```/7;```9````$]P``!D````MW```!P```$?<
M```.````3]P``!P```!>W```#````'O<```0````B-P```P```"9W```"P``
M`*;<```?````LMP```L```#2W```$````-[<```2````[]P``!(````"W0``
M"0```!7=```)````']T``!<````IW0``$0```$'=```=````4]T``!T```!Q
MW0``+@```(_=```D````OMT``"D```#CW0``)0````W>``!6````,]X```4`
M``"*W@``#P```)#>```X````H-X```4```#9W@``#0```-_>```+````[=X`
M``0```#YW@``"P```/[>```)````"M\```D````4WP``$@```![?```3````
M,=\``!(```!%WP``$@```%C?```*````:]\```D```!VWP```@```(#?```,
M````@]\``!````"0WP``%@```*'?``!!````N-\``"$```#ZWP``&P```!S@
M```/````..```)T```!(X```&@```.;@```F`````>$``"D````HX0``)0``
M`%+A```%````>.$``"8```!^X0``!````*7A```/````JN$```X```"ZX0``
M#P```,GA```.````V>$``!,```#HX0``#````/SA```3````">(```@````=
MX@``$````";B```7````-^(``!$```!/X@``#P```&'B```7````<>(``$8`
M``")X@``"````-#B```6````V>(```4```#PX@```P```/;B```(````^N(`
M``<````#XP``"`````OC```0````%.,``!8````EXP``#````#SC```A````
M2>,```8```!KXP``!````'+C```?````=^,```\```"7XP``'P```*?C```%
M````Q^,```@```#-XP``$````-;C```-````Y^,```<```#UXP``+P```/WC
M```3````+>0``)\```!!Y```%P```.'D```(````^>0```<````"Y0``#```
M``KE```'````%^4```D````?Y0``!0```"GE```(````+^4```D````XY0``
M%@```$+E```*````6>4```,```!DY0``!0```&CE```$````;N4```L```!S
MY0``!````'_E```1````A.4```T```"6Y0``#````*3E```$````L>4``"(`
M``"VY0``!@```-GE```<````X.4``!0```#]Y0``!@```!+F```0````&>8`
M`!,````JY@``$0```#[F```$````4.8```D```!5Y@``"0```%_F``!.````
M:>8``%````"XY@``4`````GG```(````6N<``!4```!CYP``!@```'GG```'
M````@.<``!H```"(YP``#````*/G```?````L.<``!@```#0YP``&P```.GG
M```%````!>@```X````+Z```!0```!KH```>````(.@``#L````_Z```"P``
M`'OH```Z````A^@``"X```#"Z```)````/'H```N````%ND```H```!%Z0``
M"P```%#I```'````7.D```4```!DZ0``&0```&KI```*````A.D```T```"/
MZ0``$````)WI```/````KND``)H```"^Z0``!P```%GJ```-````8>H```T`
M``!OZ@``"@```'WJ```+````B.H``!(```"4Z@``$P```*?J```-````N^H`
M`!$```#)Z@``!P```-OJ```-````X^H``!8```#QZ@``$P````CK```9````
M'.L``"$````VZP``DP```%CK```.````[.L``!````#[ZP``"0````SL```A
M````%NP``!D````X[```#P```%+L```.````8NP``!$```!Q[```&0```(/L
M```T````G>P``#0```#2[```-`````?M```T````/.T``#````!Q[0``,```
M`*+M```;````T^T``$$```#O[0``%P```#'N```7````2>X``!D```!A[@``
M&0```'ON```<````E>X``!P```"R[@``&0```,_N```9````Z>X``#P````#
M[P``%````$#O```2````5>\``!4```!H[P``%P```'[O```*````EN\``#D`
M``"A[P``#````-OO```'````Z.\``!0```#P[P``!`````7P```$````"O``
M``0````/\```"P```!3P```3````(/````D````T\```"@```#[P```.````
M2?````D```!8\```#@```&+P```(````<?````8```!Z\```(````('P```0
M````HO```!@```"S\```(````,SP```2````[?````4`````\0``"`````;Q
M```>````#_$```0````N\0``!P```#/Q```'````._$``!0```!#\0``&@``
M`%CQ```'````<_$``!8```![\0``"````)+Q```-````F_$```T```"I\0``
M$0```+?Q```,````R?$```\```#6\0``%````.;Q```,````^_$``!\````(
M\@``#0```"CR```,````-O(``!H```!#\@``!0```%[R```-````9/(```<`
M``!R\@``"P```'KR```%````AO(``!D```",\@``&````*;R```9````O_(`
M``(```#9\@``!````-SR```%````X?(```L```#G\@``!P```//R```,````
M^_(``&P````(\P``!0```'7S```&````>_,```\```""\P``,P```)+S```1
M````QO,``"X```#8\P``+`````?T```I````-/0```,```!>]```"P```&+T
M```'````;O0```H```!V]```#0```('T```%````C_0``!````"5]```#0``
M`*;T```*````M/0```P```"_]```#````,ST```+````V?0```H```#E]```
M#````/#T```H````_?0```@````F]0``#````"_U```<````//4``$4```!9
M]0``!@```)_U```&````IO4``"P```"M]0``*P```-KU```)````!O8``'(`
M```0]@```P```(/V```+````A_8```8```"3]@``!````)KV```(````G_8`
M``H```"H]@``%````+/V```6````R/8``!0```#?]@``!@```/3V```*````
M^_8``!0````&]P``"````!OW```1````)/<``!@````V]P``!````$_W```'
M````5/<```P```!<]P``!````&GW```-````;O<```L```!\]P``"0```(CW
M```*````DO<``!P```"=]P``"@```+KW```*````Q?<``!<```#0]P``%```
M`.CW```&````_?<```L````$^```"@```!#X```0````&_@``!`````L^```
M!0```#WX```%````0_@``$L```!)^```%````)7X```D````JO@``!X```#/
M^```'0```.[X```B````#/D``",````O^0``$````%/Y```.````9/D``!T`
M``!S^0``#P```)'Y```W````H?D``&````#9^0``6P```#KZ```)````EOH`
M`"(```"@^@``&0```,/Z```2````W?H```T```#P^@``"P```/[Z```-````
M"OL```T````8^P``%````";[```3````._L```P```!/^P``!P```%S[```O
M````9/L```@```"4^P``#````)W[``!!````JOL```P```#L^P```@```/G[
M```.````_/L```<````+_```$@```!/\```&````)OP``"(````M_```"@``
M`%#\```*````6_P``!<```!F_```)0```'[\```>````I/P``&L```##_```
M&0```"_]```B````2?T```X```!L_0``!P```'O]```0````@_T``!0```"4
M_0``"````*G]```6````LOT``!H```#)_0``"0```.3]```.````[OT```P`
M``#]_0``#`````K^```(````%_X```D````@_@``"@```"K^```*````-?X`
M``L```!`_@``$````$S^```(````7?X``"H```!F_@``'@```)'^```)````
ML/X``!<```"Z_@``$@```-+^```&````Y?X``!````#L_@``"````/W^```6
M````!O\```8````=_P``!@```"3_```2````*_\```4````^_P``%P```$3_
M```$````7/\``!D```!A_P``!0```'O_```&````@?\``"$```"(_P``)0``
M`*K_```D````T/\``!$```#U_P``!P````<``0`1````#P`!`!,````A``$`
M!````#4``0`%````.@`!`#H```!```$`#P```'L``0`B````BP`!`#L```"N
M``$`1````.H``0`O````+P$!`"````!?`0$`'P```(`!`0`3````H`$!`"D`
M``"T`0$`+0```-X!`0!B````#`(!`"L```!O`@$`*P```)L"`0`M````QP(!
M`"H```#U`@$`!P```"`#`0`'````*`,!`!<````P`P$`%@```$@#`0`B````
M7P,!`!P```""`P$`!P```)\#`0`<````IP,!``@```#$`P$`)P```,T#`0`0
M````]0,!`!(````&!`$`!0```!D$`0`-````'P0!`!$````M!`$`!@```#\$
M`0`2````1@0!`!,```!9!`$`1@```&T$`0`%````M`0!``4```"Z!`$`!0``
M`,`$`0`2````Q@0!`!@```#9!`$`!P```/($`0`2````^@0!`!P````-!0$`
M#````"H%`0`$````-P4!`#T````\!0$`7````'H%`0`'````UP4!``T```#?
M!0$`$0```.T%`0`0````_P4!`!D````0!@$`#````"H&`0`<````-P8!`!0`
M``!4!@$`%0```&D&`0`+````?P8!``@```"+!@$`%P```)0&`0`-````K`8!
M`"D```"Z!@$`"0```.0&`0`0````[@8!`!4```#_!@$`$@```!4'`0!%````
M*`<!``D```!N!P$`'P```'@'`0`2````F`<!`!8```"K!P$`*P```,('`0`-
M````[@<!``4```#\!P$`#@````((`0`/````$0@!``T````A"`$`!@```"\(
M`0`5````-@@!``4```!,"`$`$@```%((`0`7````90@!``4```!]"`$`!@``
M`(,(`0!(````B@@!`!8```#3"`$`%@```.H(`0`8`````0D!``D````:"0$`
M!0```"0)`0`1````*@D!``X````\"0$`#@```$L)`0`&````6@D!``8```!A
M"0$`-@```&@)`0`L````GPD!`"P```#,"0$`"````/D)`0`)`````@H!``D`
M```,"@$``P```!8*`0`*````&@H!``,````E"@$`%P```"D*`0`)````00H!
M``P```!+"@$`#@```%@*`0!?````9PH!`!X```#'"@$`-@```.8*`0`I````
M'0L!`!````!'"P$`!````%@+`0`/````70L!``\```!M"P$`!P```'T+`0`%
M````A0L!`!D```"+"P$`$@```*4+`0`,````N`L!`!T```#%"P$`"P```.,+
M`0`/````[PL!`'D```#_"P$`%````'D,`0`5````C@P!`"P```"D#`$`$@``
M`-$,`0`3````Y`P!`!L```#X#`$`&````!0-`0`@````+0T!``L```!.#0$`
M%0```%H-`0`'````<`T!`!$```!X#0$`"0```(H-`0`&````E`T!`%X```";
M#0$`1P```/H-`0`Z````0@X!`$````!]#@$`5````+X.`0`%````$P\!`!T`
M```9#P$`+@```#</`0`'````9@\!`!````!N#P$`.0```'\/`0`[````N0\!
M``D```#U#P$`%@```/\/`0`9````%A`!`%4````P$`$`,0```(80`0`H````
MN!`!`",```#A$`$`(@````41`0`C````*!$!`!\```!,$0$`)0```&P1`0`@
M````DA$!``<```"S$0$`%````+L1`0`:````T!$!`!D```#K$0$`!@````42
M`0`3````#!(!``4````@$@$`#0```"82`0`-````-!(!`!H```!"$@$`(```
M`%T2`0`0````?A(!`"(```"/$@$`#````+(2`0`:````OQ(!`!0```#:$@$`
M(````.\2`0`H````$!,!``L````Y$P$`)P```$43`0`$````;1,!`!D```!R
M$P$`$````(P3`0`)````G1,!``X```"G$P$`$0```+83`0`K````R!,!``P`
M``#T$P$`#@````$4`0`.````$!0!``@````?%`$`!P```"@4`0`2````,!0!
M`"H```!#%`$`"@```&X4`0`#````>10!``<```!]%`$`#0```(44`0`3````
MDQ0!`#@```"G%`$`!@```.`4`0`;````YQ0!`$D````#%0$`*P```$T5`0`S
M````>14!`!L```"M%0$`!0```,D5`0`/````SQ4!`!$```#?%0$`!0```/$5
M`0`/````]Q4!`"$````'%@$`$````"D6`0`1````.A8!`!(```!,%@$`,0``
M`%\6`0`(````D18!`"<```":%@$`+0```,(6`0`G````\!8!``X````8%P$`
M#@```"<7`0`'````-A<!``4````^%P$`&````$07`0`$````71<!``4```!B
M%P$`(0```&@7`0`5````BA<!``0```"@%P$`"@```*47`0`-````L!<!`!``
M``"^%P$``P```,\7`0`.````TQ<!`"T```#B%P$`+````!`8`0`7````/1@!
M`#(```!5&`$`%0```(@8`0![````GA@!`#T````:&0$`1````%@9`0`S````
MG1D!`#0```#1&0$`)P````8:`0`H````+AH!`#0```!7&@$`'0(``(P:`0`=
M````JAP!`!8```#('`$`(````-\<`0`7`````!T!`",````8'0$`)````#P=
M`0`H````81T!`#L```"*'0$`(````,8=`0`6````YQT!`"4```#^'0$`(@``
M`"0>`0`S````1QX!`#@```!['@$`3@```+0>`0`_`````Q\!`"\```!#'P$`
M3````',?`0!>````P!\!`"H````?(`$`#@```$H@`0`V````62`!`!````"0
M(`$`+@```*$@`0`,````T"`!``4```#=(`$`!0```.,@`0`/````Z2`!``P`
M``#Y(`$`!0````8A`0`8````#"$!``8````E(0$`"````"PA`0`1````-2$!
M``4```!'(0$`!````$TA`0`1````4B$!``D```!D(0$`#0```&XA`0`#````
M?"$!`!(```"`(0$`"P```),A`0`#````GR$!``0```"C(0$`)0```*@A`0`-
M````SB$!`!,```#<(0$`#0```/`A`0`+````_B$!`!`````*(@$`$@```!LB
M`0`;````+B(!`!````!*(@$`#P```%LB`0`$````:R(!`"<```!P(@$`#0``
M`)@B`0`9`0``IB(!``T```#`(P$`$@```,XC`0`;````X2,!``H```#](P$`
M#0````@D`0`3````%B0!`!@````J)`$`'0```$,D`0`S````820!`!@```"5
M)`$`&0```*XD`0`5````R"0!`!X```#>)`$`.@```/TD`0`5````."4!`!0`
M``!.)0$`.0```&,E`0`@````G24!``@```"^)0$`#@```,<E`0`9````UB4!
M``<```#P)0$`"````/@E`0`-`````28!`#8````/)@$`,0```$8F`0`)````
M>"8!``T```"")@$`$````)`F`0`(````H28!`!@```"J)@$`*P```,,F`0`-
M````[R8!``X```#])@$`.0````PG`0`*````1B<!``0```!1)P$`#0```%8G
M`0`:````9"<!``,```!_)P$`"````(,G`0`.````C"<!`!0```";)P$`$@``
M`+`G`0`4````PR<!`!4```#8)P$`,P```.XG`0`E````(B@!`"D```!(*`$`
M8P```'(H`0`.````UB@!`#P```#E*`$`"0```"(I`0`%````+"D!`$<````R
M*0$`"P```'HI`0`*````ABD!``8```"1*0$`!````)@I`0`%````G2D!`!(`
M``"C*0$`'0```+8I`0`&````U"D!``8```#;*0$`#@```.(I`0`0````\2D!
M``D````"*@$`!0````PJ`0`"````$BH!``(````5*@$`#P```!@J`0`M````
M*"H!`"(```!6*@$`*````'DJ`0!B````HBH!`#8````%*P$`(@```#PK`0`9
M````7RL!`!@```!Y*P$`*0```)(K`0`P````O"L!`$X```#M*P$`-0```#PL
M`0`G````<BP!`!\```":+`$`+@```+HL`0`T````Z2P!`",````>+0$`.P``
M`$(M`0`[````?BT!`#,```"Z+0$`-P```.XM`0`W````)BX!`#\```!>+@$`
M*@```)XN`0`R````R2X!`!$```#\+@$`$@````XO`0`.````(2\!`'P````P
M+P$`+0```*TO`0`9````VR\!`"0```#U+P$`%P```!HP`0`2````,C`!`",`
M``!%,`$`'0```&DP`0!A````AS`!`!,```#I,`$`$````/TP`0`%````#C$!
M`!P````4,0$`$P```#$Q`0`1````13$!`!H```!7,0$`#0```'(Q`0`$````
M@#$!``D```"%,0$`"P```(\Q`0`%````FS$!`!(```"A,0$`#````+0Q`0`$
M````P3$!`!$```#&,0$`!@```-@Q`0`1````WS$!``@```#Q,0$`!@```/HQ
M`0`%`````3(!``0````',@$`%P````PR`0`-````)#(!`!8````R,@$`!@``
M`$DR`0`)````4#(!``0```!:,@$`!@```%\R`0`%````9C(!``0```!L,@$`
M$P```'$R`0`/````A3(!`!D```"5,@$`!0```*\R`0`I````M3(!``H```#?
M,@$`"P```.HR`0`!`````````)D```!Y`@``I0$``/H#``#*`P``&P``````
M`````````````,P!``![`0``;`$``"\#``"@`P``D@,``!\$```4`@``````
M`%\$``#/````:0,``($`````````90,``!,!``#@`P``60,```````"P`P``
M``````````!Z``````````L```#,`@`````````````Y``````````````"8
M````V`$```\#`````@``+@0``*0!```/!````````,,"``#/`P```````)X!
M``!_````#@```!8`````````XP,``)("```(`0```````",```!L`@``````
M`-\"``!W`@```````,X!``"4````X0(``%P!``"J`P``U`(``"D````"`@``
M]`$``%8!````````)00``$0!```5`P``SP(`````````````VP```"L"``#6
M`@``'P$`````````````(@$``.H```#V`@``K````.L```#>`0``30,``+\"
M```D`0```````-<```#B`P``"`(````````P`@``*`,``)L```"L`@``'@,`
M`$H````*`0```````$D"``"M````9P````````!B`````````$\$``"!`@``
M!@0``````````````````$8!``!=````40,`````````````/0```'@"````
M``````````4$```Z`P``,`0``+$"``!#`0``-`$```````!!!```8P$``*P#
M```7````>@,``+,```!.`P```````*$```"T`P````````````#T````#0``
M`*(#``!9`0``7P,````````M`@``;`````````"Y````2P```*@#``#U`P``
M90$``-0#````````4P0```````"0`P``40$``"`#```H````JP``````````
M````C`(``%H!````````?`````````!.`@``F@```"`"``!R`0``F@(``/T"
M``#U````%0```#X!````````[@````8#``"<`0``OP```.````!C`P``D0$`
M``````"D````Q````%($``!-`@``)`0```````!5````-0```!<!```K`P``
MP`$``#($``"[````M@(``/T!``!H`@``U@$``+`!```3````,0,```D$````
M`0``00```%P"``!$`P``!0$``*H!``#W````-P0``(("``"<````````````
M````````8`````````"#`P``@P`````````#`P```````%D$```*`@``[@$`
M`&$$``!,`0``>@(```````"-`0``W0(``-D!``!)`0``+P(``%4#``#Q`0``
M`````&D$``#B````8`(`````````````D```````````````(`$``+@#``"Z
M````.````"T#```1`P``8@,``#\"``#"````9@0``$(#````````O`$``%<!
M``!E!````````*L"````````F0,``````````````````%`$``"G`P``0`(`
M`+,"``#3````7@(``/@#``"E````IP```!P#``!R`P``$P0``/(!````````
M`````(P#```<`0``?@,``*$!``#%`0``Q0,```````#[`@```````/@"``"W
M`P``FP,```````#%`@``Q0```(H!``"7`````````"8#``!4!```F0$``',"
M```J````S0(``",$````````9`,``.4#````````80```/H"````````Y`(`
M`(0`````````#P(``!L!```7`@``!@(``-P!``"\`P``3P```$0```#5`0``
M\`$``'$#````````````````````````D@$``*\!`````````````'L"``!5
M`0```````!8!``````````````````#7`@``[0$````````S`0``%`0```$!
M`````````````,$#``"@`@``F@,``-P`````````W`(``#,`````````_0``
M`"P```!>`0``PP$``'`````[````J0``````````````````````````````
M^0$``,8#``!U`@````````````!B!````````!(```#J`P``YP$```````!J
M`P````````````#B`0``?0```+@"``!&````IP$```````!;!```A@```.$`
M``#9`P``T`(```(!```U`@``'````$T!`````````````!D!``!H!```````
M`%T!``"N`P``8`0``%,"``"M`P``M0,``#@$``!3`0``@`(``,H```#[`P``
MY@$``)X"```!!```````````````````=@$````````Y`@``2@0``(4!``!W
M````9````-````#2`@``U@,`````````````%P0```````"+`@``=0,```,!
M``"'````-P$```````"\``````````````!S`0``PP,``$``````````````
M`*`!``!K````1`0``*T!``#U`0```````-(```!+`0``!````&T!```1````
MCP$``.8"``#+`P``T0$``-(#```+!```6P,`````````````-@```%L`````
M````````````````````K0(``$<$```#`@``/P$``-H"``"!`P```````,T`
M``#;`0```0(`````````````'P````````#(`0``Q@```"8$````````-`,`
M``````"_`P```````!L#````````C@$```````"=````L`(``,L"```B`@``
MD0```$4`````````-@$``%`#``#V`P``Y`$`````````````I@$````````-
M!```#P$``#T#``"I`@``)P```,X"``"3`0``D`$``)0"```0!```5`````@`
M```[`@``^`````````!]`P``G`(``,<```!;`@``[`,``%T$``"X````````
M`"X#```:`0````````````"C`0``00,``&T#``">`P``9P,``$H!````````
M;P(``*$#`````````````'`#````````3P,``,,````\!```<P,``)@#````
M````-`(``-@"``#H`@``N@,``'4`````````M@$``/P```"?````5@,``*(`
M````````!P$``#,#``"A`@``:0(``,0"````````2@,``)L!```D`@``^@$`
M``````!^`0``Z`$```````!C`@``8P```*P!``!<````G0$``.D!````````
M'@$``$D$``#[`0```````+<```!2`P``#@(``/`#``!Q`0``BP````,```!:
M!```K@```%8$````````$`$``````````````````(8#```D`P``&````$<`
M``!8!```U@```%X#``"I`0```````,$```!A`@``;P```,X#```&````!P,`
M`!,#````````+`(``#`!``"7`0```````,X``````````````#@#````````
MQP(``*8#````````HP,``$,#````````R@(```````"2`````````%`````[
M`P``A@(````````````````````````:`P``"P,``&0$```6!```80,``.H"
M````````,@,```````!,`@``T`,``,`"``#&`@```````%D"```]!```````
M`"8!```8!```HP(`````````````3P$```````")`P``7`,``'4!````````
MX0$```$#````````W0$``+<"``"Y`@``80$```P!```2`0```````(`!```$
M!``````````````,`@``M0(````````6`@``6@(``-\`````````=@,``*0"
M````````6````$$!``#J`0``````````````````:@(``)\#````````,P0`
M`+X"``!]`0``TP(``(<!``!)`````````*L!``!T`@``S````#8"``!%!```
M$`(``'D```#_````GP$``-H#```Z`0``2P0````````2`P``_0,``(``````
M````#0$``&@#``!9````_@````````"G`@``+`$````````N`0``1@,``+T!
M``#M`@``[`$```````````````````````#G````'P(````````6`P``````
M````````````L@```%$```!@`0``=P,``&8"``"O`````````'0#````````
MWP$``&,$``"Q````F@$``,0!``!J````G@`````````P````*0$``)<"````
M````2@(``````````````````,````!2````@P$``.,"``#W`@``N@(`````
M``#N`@``*@0``&0"````````N@$``#\#``"'`@``JP,``,@"```:!```L```
M`*8"``"]`P``C@```%0#``!G`@``*`0``$@"````````S0$``-,#``#+`0``
M9P0``,<#``#G`@``=````/$#````````$0$``)L"``".`@``W@(``"(#````
M`````````*(!``#C````V`,```````!$`@```````&\!````````#0,``/$`
M``"Y`P``)0````````!_`@``>`,``,("``#D`P``/@0``/````",`0``Y0(`
M```````%`P``?`,``$P$````````5@(``.\"``!,````/P0```````!O`P``
M(P$``!X````A`0``.`$```````!2`0``!P(```````#A`P```````*\#```W
M`@``F0(``-H```"/`@``"@0``!<#``"<`P``:@$``)8#````````[P``````
M``!0`0``N`$``(\```!I````00(`````````````5@```+4!````````Y0``
M`"8````A!```9`$``$P#````````C`````````!^`@``^0```%$$``!7````
MJ`(``*X"``!)`P```````/L````O````(P(``-4````5`0````````````!R
M`@``2`$```````!N````````````````````[0```-4#``"%`@``V````!@!
M``#^`P``F`(``%$"```W`````````,<!``!R`````````/,`````````A0,`
M``````!M````^`$``(T#``"W`0```````(L!````````B0$``-(!``!H`0``
M`````,H!````````B@,``)4!````````>``````````4`P``'`(``-,!``!"
M!`````````````!;`0``&@(``,D```!L`P``/`$``````````````````'@!
M```Q`0``9@,``,8!```2`@```@0``$,$````````A0```&("``#D````\P(`
M`&`#```F`@``[````$8"``"(````'0````````"T`@``O`(````````+`@``
M-`0``'$"```^````(0,``*4"```R`0```````%`"```?`P``-0,``,L`````
M````````````````````+@(``#D$``!7`@```````%\```"$`@``M0``````
M```U!```A`$``'<!````````VP,```````!(````.0,`````````````````
M``````"4`P``?`(````````M`0``?P,``%X$`````````````,(!````````
M3@0```````"C````YP,``)0!``"[`@``T0,``(D"``#R`@```````/,!``"3
M`@``(P,``(D```!K!```"`0``+0````@!````````)@!``!%`P```````#$"
M```'````>0,````````N````L0$``#$$````````X`(```````!&!```3@$`
M`$("``#\`@``:````'`!````````;0(```````#;`@``?`$``!X"````````
M\@,``'`"``"7`P``@P(``+0!``"*`@``+P0```````!-!```+`0``,D"````
M````/@(``.8#`````````````+8#``"5`````````-\#``"(`0``:@0`````
M``!7`P``1P$```X#```]`@``%`$``"P#``!F`0`````````````V`P``6`$`
M`-P#``!7!```90(````````.!```_P(``-H!````````^0,``(\#```%````
MZ0```*H```!``0```````-$````0`P``^0(```D#````````5`(``)4#``#W
M`0``[0,```````"@````,0```-D```#=````)P$````````I!````````&X"
M```````````````#```W`P``Z0,```L!```Z````#P``````````````````
M`!$"```$`@``=`$``"(````D````V0(``(T"```K`0``Y@````X!``#R````
MO@,``#(````[!````````'8``````````````#T!```V!```6`,``(T`````
M````*@$``#,"```>!```N0$````````T````!`$``/P#````````J@(``!,"
M``"(`P``+0```!H```"R`P``````````````````_@(``&X!```=`P``:P$`
M`.\#``!8`@``;@,````````@````D0(``!D#``"(`@``)P,``,T#``#@`0``
MO0(``)T#````````L@(```````""`P``5`$``.L!```8`P``%00``"4"```&
M`0``W@,``"$````%`@``*P0``-0````2!```+P$``(X#``!:`P``"@``````
M````````-0$``"@!````````:0$``(H```#L`@``3P(```````#I`@``7P$`
M``````"^`0```@```*D#``#O`0``?0(``"@"```)`@``0`0``#("```#!```
MJ`$``.4!``#U`@``*@,``'L```"6`0``NP$``#\`````````500``!D````G
M`@``(0(``-`!``#S`P``9P$``,D#``#T`P``DP````T"``!-````SP$``*\"
M```\`P``%0(``"H"````````!`,``.("``!L!```O@```#`#```=`@``````
M`%T"````````Z````$@#``````````````D!```````````````````0````
M@@````<$````````:P(```````!5`@```@,``"D"``!%`@``P0$``!P$````
M````#````(0#````````````````````````#`0``$4!```X`@``"0```"T$
M``!+`@```````$<"```9`@```````+L#``#!`@``U0(``%T#````````````
M`(`#```8`@``U`$``'L#``#V````=@(``/8!``!#`@``I0,``!L"````````
M`````*@```!.````D`(``/<#``"1`P``*0,```````"6````I`,````````;
M!```K@$``!T$`````````````"4!````````\0(``,`#````````6@```-X`
M```^`P``2`0```````#,`P``R0$``+8```"S`0``%````,@#``!_`0``UP$`
M```$``!"````AP,``$,`````````0@$```````"Q`P``^@```'X````,`P``
MI@``````````````````````````````"`,```````"]````LP,``#H$``!E
M````UP,```````"+`P```````'$```!Y`0```````&L#````````'0$``%\"
M```G!```(@0``.L#```E`P```````-T#``#K`@``0`,`````````````*P``
M`/\!``"_`0```````%X````[`0``@@$``'H!```9!````````/P!``#T`@``
M4P,``%P$````````T0(`````````````Z`,``$<#``"B`@``GP(``($!``"&
M`0```````.,!``#$`P``4@(``/X!``#N`P``/`(``%,```!+`P``G0(``/\#
M```*`P``.@(``#D!``"6`@``R``````````\````L@$``&(!``"5`@``DP,`
M``````!S````$00``&8```#"`P``\`(````@("`@("!4;SH@`"`@("!$871E
M.B``("`@($9R;VTZ(``@4W5B:F5C=#H@`"!A="``(&EN(``B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z
M("5S+@`C`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I
M`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP
M:7)E<RX`)60@=&\@)60@;V8@)60@365S<V%G97,`)60M9&%Y(&9O<F5C87-T
M`"5S("T@3F]T:6-E`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VX`)7,@4V5T=7``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L
M<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N
M`"5S(&%T("5S("5S`"5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R
M="!O9B!T:&4@;6]N=&@N`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92X`)7,@;6EN=71E<P`E<R!T;R`E<R!O9B`E<P`E<SH@
M)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"D`*$%P<&QY('1H97-E(&-H86YG97,@
M86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*0`H1&ES8V%R9"!A;&P@8VAA;F=E
M<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI`"A2971U<FX@
M=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N
M9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C
M<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI
M8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`L(&=U
M<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`#$R($AO=7(@
M1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C
M:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`04T@0VQO=61S`$%-
M($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R
M<P!!32]030!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`
M06)S;6ED9&QE`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R
M9`!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($AE<F4Z`$%D
M9"!.97<@1W)O=7``061D(&$@;F5W('5S97(Z`$%D9"!N97<@;65M8F5R<P!!
M9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`
M061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S($)O
M;VL`061M:6YI<W1R871I;VX`061S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L
M;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(&9O=7(@<VED
M97,`06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I
M;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z`$%L;"!M97-S
M86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W
M:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@<V5N="UM86EL
M(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE
M=&5D+@!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;'1E
M<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E
M<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!
M;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;G-W97(`06YS
M=V5R960`06YS=V5R960@;65S<V%G97,`07!P;&EC871I;VX`07!P;&EC871I
M;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@9FEL=&5R(')U
M;&5S('5P;VX@;&]G9VEN9R!O;C\`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P
M<')O=F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H97-E(&UE
M<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F
M;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R
M87-H(&9O;&1E<C\`07)M96YI86X@*$%235-#24DM."D`07)R:79A;"!4:6UE
M`$%R=`!!<V-E;F1I;F<`07-C:6D@07)T`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1A8V@`
M071T86-H;65N=`!!='1A8VAM96YT<P!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`075G=7-T`$%V86EL86)L92!F:65L9',Z`$)/1D@@17AC=7-E
M<P!"86-K('1O("5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"86QT
M:6,@*$E33RTX.#4Y+3$S*0!"87-E;&EN90!"8V,`0FQA8VML:7-T`$)L;V-K
M(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]D>0!";VQD`$)O;VMM87)K<P!";W)D
M97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W1H`$)O='1O;0!"=6QL
M971E9"!,:7-T`$--4P!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&T`0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0V%N8V5L`$-A;F-E;"!-97-S86=E`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E
M<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+@!#87!T:6]N`$-A=&5G
M;W)I97,@86YD($QA8F5L<P!#8P!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D
M:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QT:6,@*$E3
M3RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BD`0VAA;F=E`$-H86YG92!!;&P`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA
M;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S
M('EO=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@87)E('-O
M<G1E9"X`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N
M`$-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M96UA:6PN`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E
M9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!&
M;VQD97(H<RD@9F]R($YE=R!-86EL`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@06-T:6]N
M.@!#:&]O<V4@82!M86EL('-E<G9E<CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L
M:7-T<RD`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E
M<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T
M90!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7:6YD;W<`0VQO<V5D($9O;&1E
M<@!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;VQL87!S92!!;&P`0V]L
M;&%P<V4@06QL($9O;&1E<G,`0V]L;&%P<V4@1F]L9&5R`$-O;&QA<'-E(%-I
M9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L;W(@4&EC:V5R`$-O
M;',Z`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M<&]S92!M97-S
M86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\`0V]M<'5T97)S`$-O;F1I=&EO
M;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG
M=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@
M4&%S<W=O<F0`0V]N=&%C=',`0V]N=&EN=64`0V]N=')O;"!W:&5N(&YE=R!M
M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T
M;R!N;W1I9GD@>6]U('=H96X@:70@87)R:79E<RX`0V]O:VEE`$-O<'D`0V]P
M>2!S96QE8W1I;VX`0V]R<F5C=`!#;W)R96-T960@5&5X=`!#;W5L9"!N;W0@
M8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P
M('-E<G9E<@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@
M<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T
M:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU
M86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U<G-E<P!#<F5A=&4`0W)E871E($9O;&1E<@!#<F5A=&4@82!L:6YK
M`$-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R`$-R96%T92!A(&YE=R!O;F4`
M0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(`0W)E871E(&$@;F5W('1R
M87-H(&9O;&1E<@!#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE
M('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L(&%N
M9"!D96QE=&4@<W!A;2X`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U
M<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y
M;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#
M=70`0W5T('-E;&5C=&EO;@!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`1$0`
M1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%Y`$1E7VQE
M=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!)
M;F1E;G0`1&5F875L="!#;VQO<@!$969A=6QT(%-H96QL`$1E9F%U;'0@<V]R
M=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5F
M:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!&;VQD97(H<RD`
M1&5L971E($=R;W5P`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;VQD('-E;G0M
M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(')O
M=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960`1&5L971E
M9"!M97-S86=E<P!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E<V-E
M;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5V96QO<&UE;G0`1&5W(%!O
M:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&EM
M('-I9VYA='5R97,_`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO
M;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M
M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y('!O<"UU
M<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_`$1O($YO="!#:&5C:R!&;VQD
M97(H<RD@9F]R($YE=R!-86EL`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD97(_
M`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]N90!$;W=N;&]A9"!&;VQD97(H
M<RD`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="X`1')A9G0`1')A9G1S(&9O;&1E<CH`1')U9W,`161I=`!%9&ET($)L
M;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS
M(&9O<B`E<P!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D=6-A=&EO;@!%;&5M
M96YT+BXN`$5M`$5M86EL($%D9')E<W,`16UP='D@1F]L9&5R*',I`$5M<'1Y
M(%1R87-H(&9O;&1E<@!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M
M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/P!%;F0@9F]R=V%R9&5D(&UE<W-A9V4`16YL87)G92!%
M9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL
M;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D
M+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R
M('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M<V5N="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M=')A<V@@9F]L9&5R`$5R<F]R`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E
M<P!%=&AN:6,`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E
M<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@:&%L9B!H;W5R
M`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0@
M06QL`$5X<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.
M86UE<P!%>'!A;F0@4VED96)A<@!%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@
M=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1F%I<@!&87AE<P!&96)R=6%R>0!&965L
M<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W
M97)S`$9I;&4@36%N86=E<@!&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P
M<F]F86YI='D_`$9I;'1E<G,`1FEN9`!&:7)S="!(86QF`$9I<G-T(%!A9V4`
M1FER<W0@475A<G1E<@!&;&]A=`!&;V<`1F]L9&5R($YA=FEG871O<@!&;VYT
M($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9`!&;W)W87)D.@!&;W)W87)D960@;65S<V%G92!F<F]M("5S`$9O<G=A
M<F1S`$9R`$9R86UE<P!&<F]M`$9R;VT@061D<F5S<P!&<F]M('1H92``1G5L
M;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9W9#H`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!';V5D96P`1V]O9VQE(%-E87)C
M:`!'<F5E:R`H25-/+3@X-3DM-RD`1W)O=7`@061M:6YI<W1R871I;VX`1W)O
M=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$AA>F4`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(
M:61E($1E;&5T960`2&ED92!5;G-U8G-C<FEB960`2&]?;64`2&]M92!$:7)E
M8W1O<GD`2&]R9&4`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`
M2'5M:61I='DZ(`!(=6UO<FES=',`24Y"3U@`25]N<V5R="!2;W<@0F5F;W)E
M`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N
M=&ET>2=S(&YA;64Z`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`26=N;W)E`$EG
M;F]R92!!;&P`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`
M26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V5S
M`$EM<&]R="P@4W1E<"`E9`!);7!O<G1A;G0`26UP;W)T86YT(&UE<W-A9V5S
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@
M4F]W($%F=&5R`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY
M/P!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I=FED=6%L
M(%5S97)S`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I
M;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E
M<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R
M90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E
M;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E
M<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E
M<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R
M="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O
M=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-
M;V1I9GD@3&EN:P!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+@!);G9E;G1O<GD`27-O;&%T960@5"U3=&]R;7,`271A
M;&EC`$IA;G5A<GD`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*=6QY`$IU;F4`
M2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,
M969T`$IU<W1I9GD@4FEG:'0`2V5R;F5L($YE=V)I97,`2VED<P!+;W)E86X@
M*$550RU+4BD`3&%?>6]U=`!,86YG=6%G90!,87-T($AA;&8`3&%S="!086=E
M`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T
M960Z`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,969T
M`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI
M9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I
M=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R
M:6-K`$QI;FL@<&]I;G1S('1O.@!,:6YU>"!#;V]K:64`3&ES="!$871A8F%S
M97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QO8V%L('1I;64Z(`!,;V-A;&4@
M86YD(%1I;64`3&]G(&EN`$QO9R!I;B!T;R`E<P!,;V<@;W5T`$QO9VEN(%1A
M<VMS`$QO=F4`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T
M97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`34T`34]41`!-86=I8P!-86EL($%D
M;6EN`$UA:6QB;W@`36%K92!L:6Y?:RXN+@!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87)C
M:`!-87)G:6X`36%R:R!A<SH`36%R:R!D:69F97)E;G0@;&5V96QS(&]F('%U
M;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/P!-871C:&EN9R!F:65L9',`
M36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R
M<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%Y`$UE9&EC
M:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE
M<W-A9V4@0V]M<&]S:71I;VX`365S<V%G92!$871E`$UE<W-A9V4@4V5A<F-H
M`$UE<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9I97=I;F<`
M365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G97,@<&5R('!A
M9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`365T87(@5V5A
M=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-971R:6,`36ED9&QE`$UI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7-C96QL86YE
M;W5S`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N
M+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9GD`36]D:69Y(%523`!-
M;V]N(%!H87-E<P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@
M4W5N;GD`36]V90!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`
M37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`3D\L($D@1&\@3D]4($%G<F5E
M`$YA;64`3F5T=V]R:P!.979E<@!.97<`3F5W($-A=&5G;W)Y`$YE=R!&;VQD
M97(`3F5W($UA:6P`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`
M3F5W(&UE<W-A9V5S`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F1S(&1O;B=T
M(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.
M97AT`$YE>'0@365S<V%G90!.97AT(%!A9V4`3FEG:'0`3F\`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@8VAA;F=E+@!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&EC
M;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&]F9F5N<VEV92!F
M;W)T=6YE<P!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S
M`$YO('-P96QL:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N<P!.;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('9E<G-I;VX@
M9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@
M*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R=&AE<FX@
M2&5M:7-P:&5R90!.;W0@1&5L971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N
M=`!.;W0@4&5R<V]N86P`3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&]R
M=&%N="!M97-S86=E<P!.;W0@<V5T`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@
M;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@
M;6]N=&AL>2X`3G5M8F5R(&]F(')O=W,`3TL`3V)J96-T($-R96%T;W(`3V-T
M;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O
M<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@;65S<V%G97,`3VQD('!A<W-W
M;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VQD('-E;G0M;6%I
M;"!F;VQD97)S(&)E:6YG('!U<F=E9"X`3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N
M<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7II;F<`3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/
M=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E
M<FUI<W-I;VYS`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-
M(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M
M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`
M4&%D9&EN9P!086=E("5D(&]F("5D`%!A<G0H<RD`4&%R=&QY($-L;W5D>0!0
M87-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O
M<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A
M<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P
M;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S
M:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N`%!E<G-O;F%L`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E=',`4&AO=&]S
M`%!I>&5L<P!0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A
M;F0@9F]R=V%R9',_`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N
M97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.@!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H
M92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R
M;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R97-O;'9E(&%M8FEG=6]U
M<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E('-E;&5C="!A(&9O;&1E
M<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N`%!L96%S92!S96QE
M8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N`%!L96%S92!S96QE
M8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BX`4&]L:71I
M8W,`4&]L;',`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E<W-U<F4`4')E
M<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@365S<V%G90!0<F5V:6]U
M<R!086=E`%!R:6YT`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4')O:F5C=',`4'5R9V4@1&5L971E9`!0=7)G92!4<F%S:"!H;W<@;V9T
M96XZ`%!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N
M('1H:7,@86UO=6YT(&]F(&1A>7,N`%%U97)Y`%%U;W1A`%)A:6X`4F%I;B!%
M87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN
M('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F5A9`!296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I
M<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2961O97,@
M>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.@!2969R97-H($9O;&1E<B!6:65W<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5L;V%D(%9I97<`4F5M87)K<P!296UE;6)E<B!T:&4@;&%S
M="!V:65W`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE
M`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S
M97(`4F5M;W9E('5S97(Z("5S`%)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T
M(&)E9VEN;FEN9R!O9B!M;VYT:#\`4F5P;&%C92!W:71H.@!297!L>0!297!L
M>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2U4;SH@`%)E<&QY.@!297!O
M<G0@87,@4W!A;0!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<W5L=',`4F5S=6UE`%)E='5R;B!T;R!T:&4@;6%I;&)O>"!L
M:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M
M97-S86=E/P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=F5R="!#;VYF:6=U<F%T
M:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)O
M7W<@4')O<&5R=&EE<RXN+@!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE
M<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R
M;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L
M=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY
M`%)U;@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U]13"!3:&5L;`!3
M80!386UE(&9R86UE("A?<V5L9BD`4V%V92`E<P!3879E($1R869T`%-A=F4@
M87,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E
M9"`E<R!C;VYF:6=U<F%T:6]N+@!3879I;F<@=&AE(&1R869T(&9A:6QE9"X@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`4V-A='1E<F5D(%0M
M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!2
M97-U;'1S`%-E96X`4V5L96-T`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE
M8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@
M=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R
M86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N
M('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z`%-E;F0@365S<V%G90!396YD(%!R;V)L96T@4F5P;W)T`%-E;G-O<CH@
M`%-E;G0@;6%I;"!F;VQD97(Z`%-E<'1E;6)E<@!397)V97(`4V5T(&]P=&EO
M;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U
M(&5V97(@9F]R9V5T(&ET+@!3970@<')E9F5R96YC97,@9F]R('=H870@:&%P
M<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H
M;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN
M9R!A(&1R869T/P!3:&]W`%-H;W<@1&5L971E9`!3:&]W(%5N<W5B<V-R:6)E
M9`!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N
M9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E;F0@:6X@
M=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@
M8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W
M97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;F]W`%-N;W<@4VAO
M=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W
M97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@`%-O;F=S("8@4&]E;7,`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%M`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5L;"!#:&5C:P!3
M<&5L;"!#:&5C:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R
M<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-P;&ET(&-E
M;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W1A;F1A<F0`4W1A
M<B!4<F5K`%-T<FEK971H<F]U9V@`4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3
M=6)J96-T($9I96QD`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U
M;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA
M;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6=G97-T:6]N<P!3
M=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`
M4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T
M`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5&%B;&4@4')O
M<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A<F=E=#H`5&%S:W,`5&5M<"!F
M;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E
M($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X
M='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4
M:&4@8W5R<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M960@=&\@
M(B5S(BX`5&AE(&9O;&1E<B`B)7,B(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD
M97(@(B5S(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA
M;64N($ET(&UA>2!C875S92!P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+@!4:&4@9F]L9&5R("(E<R(@=V%S(&-R96%T
M960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+@!4:&4@9F]L
M9&5R("(E<R(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C
M<FEB960@9G)O;2!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@8W)E871E
M9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E
M<R(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N
M`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%1H
M92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@(B5S
M(BX`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O
M8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D
M:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N
M("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O
M;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R
M=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N871U<F4@=V%S('-U
M8V-E<W-F=6QL>2!R97!L86-E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H
M:7,@;6%I;&)O>"X`5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O
M8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A
M9V5S(&9R;VT@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S
M(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9`!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<P!4
M:&ES(&ES("5S+@!4:&ES(&UA>2!T86ME('-O;64@=&EM92X@07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&-O;G1I;G5E/P!4:&ES(&UE<W-A9V4@=&\`5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=P!4:')E860@5FEE=P!4:'5N9&5R`%1I8VME=',`5&EM92!4<F%C:VEN9P!4
M:6UE(&9O<FUA=`!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O9&%Y`%1O
M9V=L92!(5$U,(%-O=7)C90!4;VUO<G)O=P!4;W``5&]P(&9R86UE("A?=&]P
M*0!4<F%N<VQA=&EO;G,`5')A<V@@9F]L9&5R.@!4=0!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!5+E8N(&EN9&5X.B``55),`%523#H`56YA8FQE('1O(&1E;&5T
M92`B)7,B.B`E<RX`56YA;G-W97)E9`!5;F%N<W=E<F5D(&UE<W-A9V5S`%5N
M9&5L971E`%5N9&5R;&EN90!5;F1I<V-L;W-E9"!296-I<&EE;G1S`%5N9&\@
M0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F9I;&5D`%5N:6-O
M9&4@*%541BTX*0!5;FET<P!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5
M;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T
M+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S
M;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z
M:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP
M="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS965N`%5N<V5T(&-O;&]R
M`%5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0(&9O;&1E<B!S=6)S
M8W)I<'1I;VYS/P!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@
M9F]R($E-4U`@<V5R=F5R+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA
M;64`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!686-A=&EO;@!6
M87)I86)L90!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC
M86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I971N86UE<V4@*%9)
M4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@
M;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.@!6:7-I8FEL:71Y
M`%9I<VEB:6QI='DZ(`!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RX`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H
M97(@9&%T82!P<F]V:61E9"!B>0!796(`5V5B(%-I=&4`5V5L8V]M90!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E
M<W1E<FX@*$E33RTX.#4Y+3$U*0!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H96X@
M9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O
M;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@=&AE;2!A<R!D96QE=&5D/P!7:&EC
M:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+@!7:&ET96QI<W0`5VED=&@`5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI
M`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!8+5)E9@!960!997,`665S+"!)
M($%G<F5E`%EO=2!A<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R
M+@!9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R``66]U(&%R92!C
M<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N`%EO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@8FQO8VMS+@!9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z(`!9
M;W4@:&%V92`E<R!N97<@;65S<V%G97,N`%EO=2!H879E(#$@;F5W(&UE<W-A
M9V4N`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R
M.@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T
M(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!A
M9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G
M92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O
M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@
M;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@
M=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R
M;VT@(B5S(@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S
M.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9
M;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@
M:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R
M(&9U;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!9;W5R
M('-I9VYA='5R93H`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M.;R!3=6)J
M96-T70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`7T%D
M;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U
M<',`7TEM86=E(%!R;W!E<G1I97,N+BX`7TUO9&EF>2!,:6YK+BXN`%]097)M
M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T
M:65S+BXN`%]5<V5R<P!C86QM`&9A;&QI;F<`9G)O;0!F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S`&=U<W1I;F<`:6YL:6YE`&QI;F5S70!N;VYE`&]R`'!E
M<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-P96QL:6YG
M(&5R<F]R`'-P96QL:6YG(&5R<F]R<P!S=&5A9'D`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@24U0('8S+C(N,@I297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#$M
M,#D@,3,Z-38K,#<P,`I,87-T+51R86YS;&%T;W(Z(%-L86UI;B`\<VQA;6EN
M0'5N96HN86,N:60^"DQA;F=U86=E+51E86TZ(%505"!422!53D5*(#QU<'1T
M:4!U;F5J+F%C+FED/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@`@("`@("!+97!A9&$Z(``@("`@5&%N9V=A
M;#H@`"`@("!$87)I.B``(%!E<FEH86PZ(``@<&%D82``('!A9&$@`"(E<R(@
M<W5D86@@9&ET86UB86AK86X@:V4@9&%L86T@<VES=&5M(&=R=7`N`"(E<R(@
M<W5D86@@9&ET86UB86AK86X@:V4@9&%L86T@:7II;B!S:7-T96TN`"(E<R(@
M8F5L=6T@9&EB=6%T.B`E<RX`(P`E+C)F34(@<W5D86@@9&EG=6YA:V%N(&1A
M<FD@)2XR9DU"('EA;F<@<W5D86@@9&EI:FEN:V%N("@E+C)F)24I`"5D("5S
M(&1A;B`E<P`E9"!H87)I('-A;7!A:2!S86YD:2!A;F1A(&AA8FES(&UA<V$@
M8F5R;&%K=6YY82X`)60@:V4@)60@9&%R:2`E9"!097-A;@`E9"UH87)I(')A
M;6%L86X@8W5A8V$`)7,@+2!096UB97)I=&%H=6%N`$MO;F9I<FUA<VD@+2!/
M<&5R87-I(%!E;65L:6AA<F%A;B`E<P`E<R!3971U<``E<R!3>6%R870M<WEA
M<F%T(%!E<FIA;FII86X`)7,@<W5D86@@861A+B!.86UA(&9O;&1E<B`E<R!A
M;F1A('1I9&%K(&)E<G5B86@N`"5S('!A9&$@)7,@)7,`)7,@=&ED86L@;75N
M8W5L('-E8F%G86D@;6%I;&)O>"!Y86YG(&)E;F%R+@!.86UA(&9O;&1E<B`E
M<R!S961A;F<@9&EU8F%H('!A9&$@87=A;"!B=6QA;BX`)7,@<VEA<"!U;G1U
M:R!M96QA:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X@>6%N9R!S=61A
M:"!D:71A;F1A:2!D:2!B87=A:"!I;FDN($)E<FEL86@@=&%N9&$@<&%D82!K
M;W1A:R!T97)S96)U="!U;G1U:R!O<&5R87-I(&UA;F%P=6X@>6%N9R!A;F1A
M(&EN9VEN:V%N('5N='5K(&1I;&%K<V%N86MA;B!P861A('=A:W1U(&EN:2X`
M)7,@;65N:70`)7,@=6YT=6L@)7,@)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB
M<W`[)60I`"A,86MU:V%N('!E<G5B86AA;B!D86X@<&EN9&%H(&ME(&QA>6%R
M(&)E<FEK=71N>6$N*0`H06)A:6MA;B!S96UU82!P97)U8F%H86X@9&%N(&ME
M;6)A;&D@:V4@;&%Y87(@<&5N9VER:6UA;BXI`"A+96UB86QI(&ME(&QA>6%R
M('!E;F=I<FEM86X@<V5T96QA:"!M96QA:W5K86X@<V5M=6$@<&5R=6)A:&%N
M+B!097)U8F%H86X@<&%D82!L87EA<B!I;FD@=&ED86L@86MA;B!D:6QA:W5K
M86XN*0`J(%1A;6)A:"!D96YG86X@:VQI:R!/2R`J`"H@4VEL86MA;B!P:6QI
M:"!A;&%M870@*@`L(&%N9VEN(&ME;F-A;F<@)7,@)7,`+"!V87)I86)L92!D
M87)I("5S(&ME("5S`$9O<FUA="`Q,B!*86T`1F]R;6%T(#(T($IA;0`R-"!J
M86T`1&%T86)A<V4@8F%C:V5N9"!D:7!E<FQU:V%N('5N='5K(&%R96$@:6YI
M+@!!32!-96YD=6YG`$%-($=E<FEM:7,`04T@2'5J86X`04T@1V5R:6UI<P!!
M32!'97)I;6ES(%-A;&IU`$%-+U!-`%1E;G1A;F<@961I=&]R(&EN:0!496YT
M86YG+BXN(`!*87)A:R!A;G1A<F$@8F%G:6%N(&)A=V%H(&)A<FES(&1E;F=A
M;B!B86=I86X@8F%W86@@9V%M8F%R`$IA<F%K(&%N=&%R82!B86=I86X@=&5N
M9V%H(&)A<FES(&1E;F=A;B!B86=I86X@=&5N9V%H(&=A;6)A<@!);F9O<FUA
M<VD@06-C;W5N=`!386YD:2!!8V-O=6YT`$%K=6YT86YS:0!486UB86@`5&%M
M8F%H($=R=7`@06YA:P!486UB86@@1&ES:6YI.@!486UB86@@1W)U<"!"87)U
M`%1A;6)A:"!P96YG9W5N82!B87)U.@!486UB86@@86YG9V]T82!B87)U`%1A
M;6)A:"!P87-A;F=A;@!486UB86@@365N=2`E<R!S96)A9V%I(%!A;F5L(&YA
M=FEG87-I($UO>FEL;&$`5&%M8F%H('!E;F=G=6YA`%!E;F%M8F%H86X@<&5N
M9V=U;F$@=&ED86L@9&EA:W1I9FMA;BX`0G5K=2!!;&%M870`061M:6YI<W1R
M87-I`$EK;&%N`%)A=&$`4&5R871A86X`4V5M=6$`4V5M=6$@4&5N9V=U;F$@
M07-L:0!396UU82!'<G5P`%-E;75A(&5M<&%T('-I<VD`4V5M=6$@<&5S86X@
M9&%L86T@9F]L9&5R(&)E<FEK=70@86MA;B!D:61O=VYL;V%D('!A9&$@<V%T
M=2!F:6QE($U"3U@Z(`!396UU82!P97-A;B!D86QA;2!F;VQD97(@(B5S(B!Y
M86YG(&QE8FEH(&1A<FD@)7,@:&%R:2!A:V%N(&1I:&%P=7,@<V5C87)A('!E
M<FUA;F5N+@!396UU82!F;VQD97(@<V5N="UM86EL(&QA;6$@>6%N9R!L96)I
M:"!D87)I("5S(&)U;&%N(&%K86X@9&EH87!U<RX`27II;FMA;B!P96YG871U
M<F%N(&1A<FD@=&EP92!D869T87(@;F]M;W(@8F5R=7)U=#\`4&5N9V=A;G1I
M($QO9VEN($E-4U``4&5N9V=A;G1I(%-A;F1I($E-4U``4&5N9V=A;G1I($YA
M;6$@4&5N9V=U;F$@24U34`!096YG9V%N=&D@86QA;6%T(&5M86EL`%!E;F=G
M86YT:2!T96UP;&%T90!096YG9V%N=&D@=&5K<SH`2F%W86)A;@!*87=A8@!*
M87=A8B!P97-A;@!!<&QI:V%S:0!$869T87(@07!L:6MA<VD`07!L:6MA<VD@
M<W5D86@@<VEA<"X`3&%K=6MA;B!A='5R86X@9FEL=&5R('!A9&$@<V%A="!L
M;V=I;C\`1&EG=6YA:V%N('5N='5K($)A9VEA;B!!;F%K`$1I<V5T=6IU:0!!
M<')I;`!!<F%B("A7:6YD;W=S+3$R-38I`$%N9&$@>6%K:6X@:6YG:6X@;65L
M86MU:V%N(&EN:3\`07!A:V%H(&%N9&$@>6%K:6X@86YD82!I;F=I;B!M96UI
M;F1A:&MA;B!P97)M;VAO;F%N('!E;F1A9G1A<F%N('5N='5K("5S/P!!;F1A
M('EA:VEN(&EN9VEN(&UE;F=H87!U<R!P97-A;BUP97-A;B!I;FD@<V5C87)A
M(%!%4DU!3D5./P!!;F1A('EA:VEN(&EN9VEN(&UE;F=O<V]N9VMA;B!F;VQD
M97(@:6YI/P!!;F1A('EA:VEN(&EN9VEN(&UE;F=O<V]N9VMA;B!F;VQD97(@
M=')A<V@@:6YI/P!!<FUE;FEA("A!4DU30TE)+3@I`%=A:W1U($ME9&%T86YG
M86X`4V5N:0!5<G5T86X@;65N86EK`$MO9&4@07-C:6D`365M:6YT82!K;VYF
M:7)M87-I('-E8F5L=6T@;65L86MS86YA:V%N(&]P97)A<VD@<&5M96QI:&%R
M86%N/P!,86UP:7)K86X`3&%M<&ER86X`3&%M<&ER86XM;&%M<&ER86X`365N
M8V]B82!U;G1U:R!M96YG:&%P=7,@9W)U<"!Y86YG('1I9&%K(&%D82X`365N
M8V]B82!U;G1U:R!M96YG:&%P=7,@:7II;B!Y86YG('1I9&%K(&%D82X`365N
M8V]B82!U;G1U:R!M96YG=6)A:"!I>FEN('EA;F<@=&ED86L@861A+@!-96YC
M;V)A('5N='5K(&UE;F=U8F%H(&)A9VEA;B!Y86YG('1I9&%K(&%D82X`06=U
M<W1U<P!+;VQO;2!Y86YG('1E<G-E9&EA.@!!;&%S86X@0D]&2`!+96UB86QI
M(&ME("5S`$QA=&%R($)E;&%K86YG`%=A<FYA($QA=&%R($)E;&%K86YG`$)A
M;'1I8R`H25-/+3@X-3DM,3,I`$IA<F%K(&%N=&%R82!B86=I86X@8F%W86@@
M9V%M8F%R(&1E;F=A;B!G87)I<R!D87-A<B!B87)I<P!"8V,`0FQA8VML:7-T
M`%!E;F=A='5R86X@07)E80!4:7!E($%R96$`0F]D>0!(=7)U9B!496)A;`!0
M971U;FIU:R!H86QA;6%N('=E8@!";W)D97(`2V5T96)A;&%N($)O<F1E<@!"
M;W)D97(`2V5D=6%N>6$`0F%W86@`1&%F=&%R($)U;&QE=`!#35,`4')O<&5R
M=&D@4U]E;`!496YA;F<`5&ED86L@9&%P870@;65N9V%T=7(@=6QA;F<@<V%N
M9&D@<V5C87)A(&]T;VUA=&ES+"!S:6QA:V%N(&AU8G5N9VD@861M:6YI<W1R
M871O<B!A;F1A+@!"871A;&MA;@!"871A;&MA;B!097-A;@!"871A;&MA;B!,
M87!O<F%N($UA<V%L86@`365M8F%T86QK86X@<&5S86X@:6YI(&%K86X@;65N
M9V%B86EK86X@:7-I;GEA('-E8V%R82!P97)M86YE;BX`2G5D=6P@5&%B96P`
M2V%T96=O<FD@9&%N($QA8F5L`$-C`%!R;W!E<G1I(%-E;`!*87)A:R!S<&%S
M:2!D87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D86QA;2!S96PZ`'!R;W!E
M<G1I('-E;`!*87)A:R!S<&%S:2!A;G1A<B!S96PN`$-E;'1I8R`H25-/+3@X
M-3DM,30I`%1E;F=A:`!%<F]P82!496YG86@@*$E33RTX.#4Y+3(I`%5B86@`
M56)A:"!396UU80!58F%H(%-A;F1I($%N9&$`56)A:"!P:6QI:&%N('1A;7!I
M;&%N('-E<&5R=&D@8F%N>6%K;GEA('!E<V%N('EA;F<@86YD82!L:6AA="!P
M861A(&UA<VEN9RUM87-I;F<@:&%L86UA;B!D86X@8F%G86EM86YA('!E<V%N
M+7!E<V%N(&1I=7)U=&MA;BX`56)A:"!N86UA(&1A;B!A;&%M870@<V5H:6YG
M9V$@;W)A;F<@9&%P870@;65L:6AA=&YY82!K971I:V$@;65R96MA(&UE;6)A
M8V$@9&%N(&UE;6)A;&%S(&ME(&5M86EL(&%N9&$N`%5B86@@;F%M82P@86QA
M;6%T+"!D86X@=&%N9&%T86YG86X@>6%N9R!D:6QI:&%T(&]R86YG(&ME=&EK
M82!M96UB86-A(&1A;B!M96UB86QA<R!E;6%I;"!A;F1A+@!-96YG=6)A:"!S
M86YD:2!A;F1A('1I9&%K(&1I9'5K=6YG(&1E;F=A;B!K;VYF:6=U<F%S:2!Y
M86YG('-E:V%R86YG+B!3:6QA:V%N(&AU8G5N9VD@861M:6YI<W1R871O<B!A
M;F1A+@!+87)A:W1E<@!097)I:W-A($QI;FLN+BX`0V5K($9O;&1E<B!U;G1U
M:R!-86EL($)A<G4`0VEN82!3961E<FAA;F$@*$=",C,Q,BD`0VEN82!4<F%D
M:7-I;VYI;"`H0FEG-2D`4&EL:6@@06MS:3H`4&EL:6@@;6%I;"!S97)V97(Z
M`%!I;&EH(&-A<F$@=6YT=6L@;65N86UP:6QK86X@=&%N9V=A;#H`4&EL:6@@
M9&%F=&%R('1I<&4@9V%Y82`H=6YT=6L@9&%F=&%R(&YO;6]R(&)E<G5R=70I
M`$)E<G-I:&MA;@!"97)S:6AK86X@=&%G($U33V9F:6-E`$)E<G-I:&MA;B!P
M96YG9W5N83H@)7,`0F5R<VEH:V%N('!E;F=G=6YA`$)E<G-I:&MA;B!D871A
M('!E;F=G=6YA`$-E<F%H(&)E8F5R87!A('-A870@;&%G:0!+;&EK('5N='5K
M($QA;FIU=`!4=71U<"!*96YD96QA`$9O;&1E<B!497)T=71U<`!-96YD=6YG
M`$UE;F1U;F<@9&D@<&%G:2!H87)I`$)E<F%W86X`2&%P=7,@4V5M=6$`2&%P
M=7,@4V5M=6$@1F]L9&5R`$AA<'5S($9O;&1E<@!097)B97-A<B!086YE;"!.
M879I9V%S:2``4&5R8F5S87(@8F]R9&5R`%=A<FYA`%!E;6EL:6@@5V%R;F$`
M2V]L;VT`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!+:7)I;2!P97-A
M;B!P861A('=I;F1O=R!T97)P:7-A:#\`2V]M<'5T97(`2V]N9&ES:0!+;VYD
M:7-I`%!E<F)E9&%A;B!+;VYF:6=U<F%S:0!+;VYF:6=U<F%S:2!S=61A:"!H
M86)I<R!M87-A(&)E<FQA:W5N>6$N`$UE;F=A='5R("5S`$MO;F9I<FUA<VD@
M4V%N9&D`2V]N=&%K`$QA;FIU=`!+;VYT<F]L(&II:V$@;6%I;"!B87)U(&%K
M86X@9&EC96LL(&1A;B!A<&%K86@@;65M8F5R:2!T86AU(&%N9&$@871A=2!T
M:61A:R!J:6MA(&UA:6P@9&%T86YG+@!#;V]K:64`0V]P>0!386QI;B!0:6QI
M:&%N`$)E;F%R`%1E:W,@0F5N87(`5&ED86L@9&%P870@=&5R:6MA="!D96YG
M86X@<V5R=F5R(&QD87``5&ED86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E
M<B!L9&%P`%1I9&%K(&1A<&%T(&UE;F=A='5R('5L86YG('5N='5K('!E;F=G
M=6YA('EA;F<@9&EM:6YT82X@0F5B97)A<&$@871A=2!S96UU82!D971I;"!T
M:61A:R!B96YA<BX@0V]B82!L86=I(&%T874@<VEL86MA;B!H=6)U;F=I(&%D
M;6EN:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@;65M97)L=6MA;B!B86YT=6%N
M(&QE8FEH(&QA;FIU="X`5&ED86L@9&%P870@:V5M8F%L:2!K92!K;VYF:6=U
M<F%S:2X`5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I("5S+@!4
M:61A:R!D87!A="!M96YY:6UP86X@9FEL92!K;VYF:6=U<F%S:2!B86-K=7`@
M)7,N`%1I9&%K(&1A<&%T(&UE;GEI;7!A;B!F:6QE(&MO;F9I9W5R87-I("5S
M+B!!;F1A(&1A<&%T(&UE;F=G=6YA:V%N('-A;&%H('-A='4@9&%R:2!P:6QI
M:&%N('5N='5K(&UE;GEI;7!A;B!K;V1E('1E<G-E8G5T(&ME;6)A;&D@:V4@
M)7,@871A=7!U;B!M96YY86QI;B!K;V1E(&1I(&)A=V%H(&EN:2!S96-A<F$@
M;6%N=6%L(&ME("5S+@!4:61A:R!D87!A="!M96YE;75K86X@4&%N96P@3F%V
M:6=A<VD@36]Z:6QL82X@4&%S=&EK86X@<&%N96P@;F%V:6=A<VD@<W5D86@@
M=&5R8G5K82X`2W5R<W5S`$)U870`0G5A="!&;VQD97(`0G5A="!L:6YK`$)U
M870@9F]L9&5R(&1R869T<R!B87)U`$)U870@8F%R=0!"=6%T(&9O;&1E<B!S
M96YT(&UA:6P@8F%R=0!"=6%T(&9O;&1E<B!T<F%S:"!B87)U`$)U870@871U
M<F%N(&9I;'1E<B!U;G1U:R!M96YG871U<B!P97-A;B!M87-U:R!A;F1A+"!U
M<G5T:V%N(&ME(&9O;&1E<BP@9&%N(&AA<'5S('-P86TN`%=A:W1U(%-E:V%R
M86YG`%523"!396MA<F%N9R!A9&%L86@`0W5A8V$@4V5K87)A;F<`2V]N9&ES
M:2!396MA<F%N9SH`1V%Y82!396MA<F%N9P!!='5R('1U9V%S('EA;F<@9&EJ
M86QA;FMA;B!S86%T(&QO9V]N('!A9&$@)7,N`$AA<'5S`$AA<'5S('!I;&EH
M86X`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A=&%4<F5E($)R;W=S
M97(`5&%N9V=A;`!486YG9V%L($1I=&5R:6UA`$AA<FD`2&%P=7,@2V]L;VT`
M1&5S96UB97(`06YG:V$@1&5S:6UA;`!-96YG=7)A;F=I($EN9&5N`$1E9F%U
M;'0@5V%R;F$`1&5F875L="!3:&5L;`!+<FET97)I82!U<G5T86X@>6%N9R!D
M969A=6QT`$%R86@@=7)U=&%N('EA;F<@9&5F875L=`!$969I;FES:0!(87!U
M<P!(87!U<R!396P`2&%P=7,@1F]L9&5R`$AA<'5S($=R=7``2&%P=7,@<V5L
M`$AA<'5S(&MO;&]M`$AA<'5S('!E;F=G86YT:2!T96UP;&%T92!Y86YG('-U
M9&%H(&%D80!(87!U<R!F;VQD97(@<V5N="UM86EL(&QA;6$@<&%D82!A=V%L
M(&)U;&%N/P!(87!U<R!B87)I<P!(87!U<R!I9&5N=&ET87,@>6%N9R!T97)P
M:6QI:`!(87!U<R!K;VQO;2!Y86YG('-E:V%R86YG`$AA<'5S(&)A<FES('EA
M;F<@<V5K87)A;F<`1&EH87!U<P!097-A;B!T97)H87!U<P!-96YG:&%P=7,@
M9&%N($UE;6EN9&%H(%!E<V%N`%5R=70@;65N=7)U;@!*96QA<VMA;B!-87-A
M;&%H`%!E<FME;6)A;F=A;@!4:71I:R!%;6)U;@!4:71I:R!%;6)U;B!U;G1U
M:R!J86T@=&5R86MH:7(Z`%1I=&EK($5M8G5N`$1I;2!T86YD871A;F=A;C\`
M07)A:"!K:7)I(&ME(&MA;F%N`$%R86@@:V%N86X@:V4@:VER:0!$:7)E:W1O
M<FD`5&%M<&EL:V%N`%1A;7!I;&MA;B!W86MT=2`R-"!J86T_`%1A;7!I;&MA
M;B!0:6QI:&%N`%1A;7!I;&MA;B!D971I;"!R86UA;&%N(&-U86-A`%1A;7!I
M;&MA;B!R86UA;&%N(&-U86-A("A4048I`%1A;7!I;&MA;B!P96UB97)I=&%H
M=6%N('!O<"UU<"!D87)I(&UA:6P@8F%R=3\`2F%N9V%N(%1A;F1A:2!&;VQD
M97(@=6YT=6L@36%I;"!"87)U`$IA;F=A;B!L86YG<W5N9R!M96YG86MS97,@
M;6%I;G1E;F%N8V4N<&AP`$%P86MA:"!A;F1A(&EN9VEN(&UE;6)U:V$@9F]L
M9&5R(&ET=3\`07!A:V%H(&)A<FES('EA;F<@<&5R=&%M82!T97)D:7)I(&1A
M<FD@:V]L;VT@;F%M83\@:FEK82!Y82P@8F5R:2!T86YD82!P861A(&MO=&%K
M(&EN:3H`4W5D86@`1&]W;FQO860@1F]L9&5R`$1O=VYL;V%D(&MO;F9I9W5R
M87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!02%`N`$1R869T
M`$9O;&1E<B!D<F%F=',`3V)A="UO8F%T86X`161I=`!58F%H($)L;VMI<@!5
M8F%H($=R=7``56)A:"!)>FEN`%5B86@@27II;B!U;G1U:R`E<P!58F%H('!I
M;&EH86X@=6YT=6LZ`%5B86@@:7II;B!U;G1U:R`E<P!%9&ET(&%T=7)A;B!F
M:6QT97(`4&5N9&ED:6MA;@!%;&5M96XN+BX`16T`06QA;6%T($5M86EL`$MO
M<V]N9VMA;B!&;VQD97(`2V]S;VYG:V%N(&9O;&1E<B!4<F%S:`!!:W1I9FMA
M;B!P96YY:7-I<&%N(&=A;6)A<BUG86UB87(@9&%R:2!'86QE<FD@1F]T;R!D
M:2!D86QA;2!T96MS/P!!:W1I9FMA;B!K;&EK(&MA;F%N(&UE;G4@:V]N=&5K
M<S\`06MH:7(@<&5S86X@>6%N9R!D:71E<G5S:V%N`%!E<F)E<V%R($5D:71O
M<@!-87-U:VMA;B!P97)T86YY86%N(&ME86UA;F%N(&1I;6%N82!A;F1A(&%K
M86X@9&ET86YY86MA;B!A<&%B:6QA(&%N9&$@<&5R;'4@=6YT=6L@;65N9V%T
M=7(@=6QA;F<@<V%N9&D@86YD82P@(&-O;G1O:"`G87!A:V%H(&YA;6$@8FEN
M871A;F<@:V5S87EA;F=A;B!A;F1A/R<Z`$UA<W5K:V%N(%523"!G86UB87(@
M9&ES:6YI`$UA<W5K:V%N(&YA;6$@=6YT=6L@9F]L9&5R(&1R869T<R!B87)U
M`$UA<W5K:V%N(&YA;6$@=6YT=6L@9F]L9&5R('-E;G0@;6%I;"!B87)U`$UA
M<W5K:V%N(&YA;6$@=6YT=6L@9F]L9&5R('1R87-H(&)A<G4`4V%L86@`2V5S
M86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,`4W5K=0!3971I
M87`@,34@;65N:70`4V5T:6%P(#(@;65N:70`4V5T:6%P(#,P(&1E=&EK`%-E
M=&EA<"`U(&UE;FET`%-E=&EA<"!S971E;F=A:"!J86T`4V5T:6%P(&UE;FET
M`$-O;G1O:"!N:6QA:2UN:6QA:3H`2F%L86YK86X`2V5M8F%N9VMA;B!396UU
M80!+96UB86YG:V%N(%-E;75A($9O;&1E<@!+96UB86YG:V%N($9O;&1E<@!+
M96UB86YG:V%N($YA;6$`4&5R8F5S87(@4&%N96P@3F%V:6=A<VD`2V5M8F%N
M9VMA;B!S96QU<G5H(&AI<F%R:VD@9F]L9&5R('-E8V%R82!D969A=6QT('!A
M9&$@=&%M<&EL86X@9F]L9&5R/P!787)N82!&1P!&5%`@=7!L;V%D('5N='5K
M('-E='5P`$-E<F%H`$9A>`!&96)R=6%R:0!397!E<G1I`%-E<&5R=&DZ`$=E
M<FEM:7,@4V5B86=I86X`1V5R:6UI<R!386QJ=2!396)A9VEA;@!&:6QE($UA
M;F%G97(`1FEL=&5R(&ES:2!P97-A;B!U;G1U:R!P<F]F86YI='D_`$9I;'1E
M<@!#87)I`$9A<V4@<&5R=&%M82!D87)I(%-E<&%R=6@@0G5L86X`2&%L86UA
M;B!097)T86UA`$9A<V4@<&5R=&%M82!D87)I(%-E<&%R=6@@0G5L86X`1FQO
M870`0F5R:V%B=70`3F%V:6=A=&]R($9O;&1E<@!787)N82!4=6QI<V%N`$UA
M:V%N86X`56YT=6L@8G)O=W-E<B!Y86YG('1I9&%K(&1A<&%T(&UE;F1U:W5N
M9R!G86UB87(`4F%M86QA;B!C=6%C82`H5$%&*0!(87)I(%)A;6%L86X@0W5A
M8V$@*&-A=&%T86X@8F%H=V$@<F%M86QA;B!C=6%C82!Y86YG(&1I:V5M8F%L
M:6MA;B!A:V%N(&UE;F=E;6)A;&EK86X@8F%I:R!S:6%N9R!A=&%U(&UA;&%M
M(&AA<FDL('-E:G5M;&%H(&%N9VMA(&1A<&%T(&1I:&%S:6QK86X@<&%D82!A
M<F5A(&EN:2D`3'5P82!D96YG86X@<V%N9&D@86YD83\`1F]R;75L:7(`4F%M
M86QA;@!4:7!E(%)A;6%L86X`4F%M86QA;@!286UA;&%N(#(`1F]R=6T`5&5R
M=7-K86X`5&5R=7-K86XZ`%1E<G5S:V%N('!E<V%N(&1A<FD@)7,`1&ET97)U
M<VMA;@!*;70`1G)A;64`1&%R:0!$87)I($%L86UA=`!$87)I`$1E<VMR:7!S
M:2!,96YG:V%P`$)U;&%N(%!U<FYA;6$`3F%M82!,96YG:V%P`$9W9#H`1V%L
M97)I('5N='5K(&UE;F=A;6)I;"!G86UB87(@9&%R:0!'86QE<FD`365N9VAA
M<VEL:V%N("5S($MO;F9I9W5R87-I(`!+;V1E('EA;F<@9&EH87-I;&MA;@!'
M;V5D96P`4&5N8V%R:6%N($=O;V=L90!9=6YA;FD@*$E33RTX.#4Y+3<I`$%D
M;6EN:7-T<F%S:2!'<G5P`$=R=7``27II;B!T86UU`$)U:W4@=&%M=0!(5$U,
M07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H87!U<R!S96P@
M>6%N9R!T97)A:VAI<B!D:2!D86QA;2!B87)I<RX`2%1-3$%R96$@9&5N9V%N
M(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@:V]L;VT@>6%N9R!T97)A
M:VAI<B!D:2!D86QA;2!T86)E;"X`2%1-3$%R96$@9&5N9V%N(')A9W4@;65N
M;VQA:R!U;G1U:R!M96YG:&%P=7,@8F%R:7,@>6%N9R!T97)A:VAI<B!D:2!D
M86QA;2!T86)E;"X`0F5R:V%B=70`66%H=61I("A)4T\M.#@U.2TX+4DI`%1I
M;F=G:0!"86YT=6%N`$)A;G1U86X@;65N9V=U;F%K86X@961I=&]R`$)E;&%H
M86X@0G5M:0!);FD@861A;&%H('!E<FUU;&%A;B!D87)I(&9I;&4Z`%-E;6)U
M;GEI:V%N('EA;F<@1&EH87!U<P!396UB=6YY:6MA;B!T:61A:R!L86YG9V%N
M86X`2&]?;64`1&ER96MT;W)I($AO;64`2&]R9&4`1V%R:7,@2&]R:7-O;G1A
M;"!D:2!D86QA;2!(5$U,`$IA<F%K(&=A<FES(&AO<FEZ;VYT86P@9&%R:2!B
M;W)D97(@9&5N9V%N('1E:W,@9&D@9&%L86T@<V5L`$AO<FEZ;VYT86PZ`$)A
M9V%I;6%N82!C87)A(&%N9&$@8FES82!S86UP86D@9&ES:6YI/R`H4VEL86MA
M;B!M96QA<&]R(2D`0F5R87!A(&)A;GEA:R!K;VQO;2!Y86YG(&EN9VEN(&%N
M9&$@9V%B=6YG:V%N/P!"97)A<&$@8F%N>6%K(&MO;&]M('EA;F<@861A(&1I
M<V%N83\`0F5R87!A(&)A;GEA:R!B87)I<R!Y86YG(&EN9VEN(&%N9&$@9V%B
M=6YG:V%N/P!+96QE;6)A8F%N`$ME;&5M8F%B86XZ`%!E;&%W86L`24Y"3U@`
M36%S=6MK86X@0F%R:7,@4V5B96QU;6YY80!(86YY82!I:V]N`$EK;VX@=6YT
M=6L@)7,`26MO;B!D96YG86X@=&5K<P!.86UA($ED96YT:71A<SH`2FEK82!A
M;F1A('1I9&%K(&UE;&EH870@:6MO;B!M86YA<'5N(&1E;F=A;B!M96YG9W5N
M86MA;B!);G1E<FYE="!%>'!L;W)E<BP@86YD82!M=6YG:VEN('!E<FQU('5N
M='5K(&UE;F%N9&%I(&MO=&%K(&EN:2!U;G1U:R!M96YO;BUA:W1I9FMA;B!K
M96QE;6%H86X@4$Y'+@!!8F%I:V%N`$%B86EK86X@4V5M=6$`3&EH870@1V%M
M8F%R.@!54DP@1V%M8F%R`%523"!'86UB87(Z`$=A;6)A<B!D87)I(&=A;&5R
M:0!'86UB87(@9&%R:2!G86QE<FDZ`$=A;6)A<BUG86UB87(`26UP;W(L($QA
M;F=K86@@)60`4&5N=&EN9P!097-A;B!P96YT:6YG`$MO;&]M('EA;F<@9&EI
M;7!O<CH@)7,`2V]L;VT@>6%N9R!D:6EM<&]R.@!-87-U:VMA;B!"87)I<R!"
M97)I:W5T;GEA`$UA<W5K:V%N('!E<V%N(&%S;&D@<&%D82!B86QA<V%N/P!.
M86UA('!E;F=G=6YA(&%T874@86QA;6%T(&5M86EL('!E;F=G86YT:2!T:61A
M:R!B96YA<BX@0V]B82!L86=I(&%T874@<VEL86MA;B!H=6)U;F=I(&%D;6EN
M:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@;65M97)L=6MA;B!B86YT=6%N(&QE
M8FEH(&QA;FIU="X`365N86UB86@@26YD96X`4&5N9V=U;F$@4')I8F%D:0!)
M;F9O<FUA<VD`26YF;W)M87-I('-U9&%H('1I9&%K(&1I<V5D:6%K86XN`$UA
M<W5K:V%N($MO;&]M($)E<FEK=71N>6$`36%S=6MK86X@1V%M8F%R`$UA<W5K
M:V%N(%1A8F5L`$UA<W5K:V%N(%=E8B!,:6YK`$UA<W5K:V%N($MO;&]M(%-E
M8F5L=6UN>6$`36%S=6MK86X@:V]L;VT@>6%N9R!B87)U('-E=&5L86@@:V]L
M;VT@>6%N9R!S96MA<F%N9P!-87-U:VMA;B!K;VQO;2!Y86YG(&)A<G4@<V5B
M96QU;2!K;VQO;2!Y86YG('-E:V%R86YG`$UA<W5K:V%N(&)A<FES('EA;F<@
M8F%R=2!S971E;&%H(&)A<FES('EA;F<@<V5K87)A;F<`36%S=6MK86X@8F%R
M:7,@>6%N9R!B87)U('-E8F5L=6T@:V]L;VT@>6%N9R!S96MA<F%N9P!-87-U
M:VMA;B!P87)A9W)A9B!S971E;&%H('!A<F%G<F%F('EA;F<@<V5K87)A;F<`
M36%S=6MK86X@<&%R86=R868@<V5B96QU;2!P87)A9W)A9B!Y86YG('-E:V%R
M86YG`$UA<W5K:V%N('1E;7!L871E('!E;F=G86YT:0!-87-U:VMA;B!A;&%M
M870@96UA:6P@9&EM86YA(&%N9&$@9&%P870@;65N97)I;6$@<V%N9&D@>6%N
M9R!B87)U.@!-87-U:VMA;B!S96P@8F5R:6MU=&YY80!-87-U:VMA;B!S96P@
M<V5B96QU;6YY80!-87-U:VMA;B!K;VQO;2!B97)I:W5T;GEA`$UA<W5K:V%N
M(&MO;&]M('-E8F5L=6UN>6$`36%S=6MK86X@<&%R86=R868@8F5R:6MU=&YY
M80!-87-U:VMA;B!P87)A9W)A9B!S96)E;'5M;GEA`$UA<W5K:V%N(&)A<FES
M(&)E<FEK=71N>6$`36%S=6MK86X@8F%R:7,@<V5B96QU;6YY80!-87-U:VMA
M;B!J87=A8F%N('EA;F<@9&EP97)L=6MA;B!U;G1U:R!P97)T86YY86%A;B!K
M96%M86YA;CH`36%S=6MK86XO56)A:"!'86UB87(`36%S=6MK86XO56)A:"!,
M:6YK`$%P;&EK87-I('1I9&%K('9A;&ED+@!)>FEN(&EN9'5K('1I9&%K('9A
M;&ED+@!);G9E;G1O<FES`$AU:F%N('!E=&ER(&1I<V5R=&%I(&%N9VEN(')I
M8G5T(&1I(&1A97)A:"!Y86YG('1E<G!E;F-I;`!(=7)U9B!-:7)I;F<`2F%N
M=6%R:0!*97!A;F<@*$E33RTR,#(R+4I0*0!*=6QI`$IU;FD`4F%T80!2871A
M(%1E;F=A:`!2871A($MI<FD@9&%N($MA;F%N`%)A=&$@2VER:0!2871A($MA
M;F%N`$ME<FYE;"!.97=B:65S`$%N86LM86YA:P!+;W)E82`H155#+4M2*0!4
M86UP:6QA;@!"86AA<V$`1F%S92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L
M86X`2&%L86UA;B!497)A:VAI<@!097)U8F%H86X@4V%N9&D@5&5R86MH:7(`
M1F%S92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86X`4&5R=6)A:&%N(%1E
M<F%K:7(Z`$AU:W5M`%1A;7!I;&%N`%1I;F=G86QK86X@:V]S;VYG('1A;G!A
M(&)O<F1E<@!+:7)I`$=E<FEM:7,`1V5R:6UI<P!'97)I;6ES(&1I('!A9VD@
M:&%R:0!'97)I;6ES(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$=E<FEM
M:7,@9&ES97)T86D@<&5T:7(`0F5R<V%L:G4`1V5R:6UI<R!386QJ=0!086YT
M=6X@2F5N86MA`$QI;FL@;65N=6YJ=6L@:V4Z`$QI;G5X($-O;VMI90!$869T
M87(@1&%T86)A<V4`1&%F=&%R(%1O<&EK($)A;G1U86X`1&%F=&%R(%1A8F5L
M`$1A9G1A<B!P96YG9W5N82!D:6YO;BUA:W1I9FMA;BX`1&%F=&%R($)A8V%A
M;@!786MT=2!L;V-A;#H`5&5M<&%T(%!E<FES=&EW82!D86X@5V%K='4`36%S
M=6L`36%S=6L@<&%D82`E<P!,;V<@;W5T`$QO9VEN(%1U9V%S`$-I;G1A`%-I
M;6)O;"!(=7)U9B!K96-I;"!Y=6YA;FD`4VEM8F]L($AU<G5F(&ME8VEL(&QA
M=&EN`%-I;6)O;"!(=7)U9B!K96-I;"!R;VUA=VD`34T`34]41`!3=6QA<`!3
M=7)A="!!9&UI;@!-86EL8F]X`$)U870@;&EN:RXN+@!-96YG871U<B!D869T
M87(@:V%T96=O<FD@>6%N9R!H87)U<R!D:6)E<FD@;&%B96P@:71E;2P@9&%N
M('=A<FYA('EA;F<@8F5R:'5B=6YG86X@(&1E;F=A;B!K871E9V]R:2!T97)S
M96)U="X`36%R970`36%R9VEN`%1A;F1A:2!S96)A9V%I.@!486YD86D@<&5R
M8F5D86%N('1I;F=K870@9&5N9V%N('=A<FYA('EA;F<@8F5R8F5D83\`365N
M8V]C;VMK86X@:V]L;VT`(%-U:'4@;6%K<VEM=6T@>6%N9R!B97)L86YG<W5N
M9R!S96QA;6$@,C0@:F%M.@!3=6AU(&UA:W-I;75M('EA;F<@8F5R;&%N9W-U
M;F<@<V5L86UA(#8@:F%M.@!*=6UL86@@;6%K<VEM=6T@9&%R:2!P;W)T86P@
M>6%N9R!D:6)L;VMI<@!-96D`3V)A="UO8F%T86X`06YG9V]T80!-96YU(&UO
M9&4Z`$=A8G5N9VMA;B!S96P`4&5S86X`4&5N9VER:6UA;B!097-A;@!486YG
M9V%L(%!E<V%N`$-A<FD@4&5S86X`56MU<F%N(%!E<V%N`%-U;6)E<B!097-A
M;@!,:6AA="!097-A;@!&;&%G('!E<V%N`$9O;&1E<B!097-A;@!097-A;B!P
M97(@:&%L86UA;B!P861A('1A;7!I;&%N(&UA:6QB;W@N`%!E<V%N(&ME`"!#
M=6%C82!-971A<@!!<F5A($UE=&%R('1I9&%K(&1I<V5D:6%K86XN`$%R96$@
M365T87(@=&ED86L@9&ES961I86MA;BX@1&5T:6P@=&5L86@@9&EC871A="!U
M;G1U:R!A9&UI;FES=')A=&]R+@!-971R:6L`5&5N9V%H`%-U:'4@;6EN:6UU
M;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ`%-U:'4@;6EN:6UU
M;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`V(&IA;3H`3&%I;BUL86EN`$MO
M;F9I9W5R87-I('1I9&%K(&1I=&5M=6MA;BX@06YD82!H87)U<R!M96YG:&%S
M:6MA;B!K;VYF:6=U<F%S:2!S96MA<F%N9R!J:6MA(&%N9&$@:6YG:6X@;65N
M9V=U;F%K86X@87!L:6MA<VD@:6YI+@!396X`36]B:6QE($UA:6P`4V5D86YG
M`%5B86@`56)A:"!54DP`1F%S92!"=6QA;@!396)A9VEA;B!B97-A<B!#97)A
M:`!396)A9VEA;B!B97-A<B!"97)A=V%N`%-E8F%G:6%N(&)E<V%R($-E<F%H
M`%!I;F1A:`!!8V-O=6YT+6MU`$EN9F]R;6%S:2!!8V-O=6YT+6MU`%!O<G1A
M;&MU`%1A;7!I;&%N(%!O<G1A;&MU`%1)1$%++"!387EA(%1)1$%+(%-E='5J
M=0!.86UA`$YE='=O<FL`5&ED86L@<&5R;F%H`$)A<G4`2V%T96=O<FD@0F%R
M=0!&;VQD97(@0F%R=0!-86EL($)A<G4`0G5L86X@0F%R=0!.86UA(%!E;F=G
M=6YA($)A<G4@*'!I;&EH86XI`%!E<V%N(&)A<G4`4V%N9&D@0F%R=0!386YD
M:2!B87)U('1I9&%K(&-O8V]K+@!7:6YD;W<@0F%R=2`H7V)L86YK*0!"97)I
M=&$`1W)U<"!"97)I=&$`0F5R:6MU=&YY80!097-A;B!"97)I:W5T;GEA`$AA
M;&%M($)E<FEK=71N>6$`36%L86T`5&ED86L`5&ED86L@861A(&1A=&$@:V]N
M9FEG=7)A<VD@>6%N9R!T97)S961I82!U;G1U:R!M96YU;FIU:VMA;B!P97)B
M961A86X@=6YT=6LN`%1I9&%K(&%D82!P97)U8F%H86XN`%1I9&%K(&%D82!F
M;VQD97(@>6%N9R!T97)S<&5S:69I:V%S:0!4:61A:R!A9&$@:6MO;B!Y86YG
M(&1I=&5M=6MA;BX`5&ED86L@861A(&QO:V%S:2!Y86YG(&1I871U<BX`5&ED
M86L@861A(')A;6%L86X@>6%N9R!T:61A:R!S;W!A;@!4:61A:R!A9&$@<&5N
M9&%F=&%R86X@>6%N9R!D:71U;F1A+@!4:61A:R!A9&$@871U<F%N`%1I9&%K
M(&%D82!S:7-I`%1I9&%K(&%D82!K97-A;&%H86X@<&5N9V5J86%N`%1I9&%K
M(&%D82!S87)A;@!4:61A:R!A9&$@9&ER96MT;W)I('-E;65N=&%R82!Y86YG
M('1E<G-E9&EA('5N='5K(&-A8VAE`%1I9&%K(&%D82!V97)S:2!Y86YG(&1I
M=&5M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!Y86YG(&%S;&DN($UE;F=H
M87-I;&MA;B!K;VYF:6=U<F%S:2!K96UB86QI+@!4:61A:R!A9&$@=F5R<VD@
M>6%N9R!D:71E;75K86X@9&D@9&%L86T@:V]N9FEG=7)A<VD@86YD82X@365N
M9VAA<VEL:V%N(&MO;F9I9W5R87-I(&ME;6)A;&DN`%1I9&%K(&%D80!4:61A
M:R!A9&$@*&1I9W5N86MA;B!S96QE;F=K87!N>6$I`%-C86YD:6YA=FEA("A)
M4T\M.#@U.2TQ,"D`0F5L86AA;B!"=6UI(%5T87)A`%1I9&%K($1I:&%P=7,`
M0G5K86X@1')A9G0`5&ED86L@4&5N=&EN9P!4:61A:R!0<FEB861I`%!E<V%N
M('1I9&%K('1E<FAA<'5S`%!E<V%N('1I9&%K('!E;G1I;F<`0F5L=6T@9&EA
M='5R`$-A=&%T86X`5&ED86L@861A('EA;F<@9&%P870@9&EB<F]W<V4L('-I
M;&%K86X@:V5M8F%L:2X`3F]V96UB97(`2G5M;&%H(&MO;&]M`$IU;6QA:"!F
M;VQD97(@<V5N="UM86EL(&QA;6$@>6%N9R!T971A<"!A9&$@:FEK82!D:6AA
M<'5S(&)U;&%N86XN`$IU;6QA:"!B87)I<P!/2P!096YC:7!T82!/8FIE:P!/
M:W1O8F5R`$9I;'1E<B!096QA;F=G87)A;@!+86YT;W(`4V%N9&D@;&%M82!D
M86X@8F%R=2!H87)U<R!B97)B961A+@!097-A;B!,86UA`%-A;F1I(&QA;6$`
M4V%N9&D@;&%M82!T:61A:R!B96YA<BX`1F]L9&5R('-E;G0M;6%I;"!L86UA
M('-E9&%N9R!D:6)U86YG+@!(86YY82!R86UA;&%N('EA;F<@=&ED86L@<V]P
M86X`2&%N>6$@<&5M:6QI:R!A=&%U('-I<W1E;2!A9&UI;FES=')A=&]R('-A
M:F$@>6%N9R!D87!A="!M96YG=6)A:"!K97!E;6EL:6MA;B!A=&%U('!E;6EL
M:6L@:7II;B!U;G1U:R!B86=I86X`0G5K82!D:2!J96YD96QA('EA;F<@8F%R
M=0!"=6MA(&QI;FL@:6YI(&1I(&IE;F1E;&$@>6%N9R!B87)U`%-I<W1E;2!/
M<&5R87-I`%!I;&EH86X`4&EL:6AA;B!U;G1U:R`E<P!$869T87(@3F]M;W(@
M0F5R=7)U=`!-96YG871U<@!!<&QI:V%S:2!T96UP;&%T92!A<VQI`%1E;7!L
M871E(&%S;&D@9&D@9&%L86T@)7,Z`$QA:6XM;&%I;@!);F9O<FUA<VD@3&%I
M;@!0:6QI:&%N($QA:6X`27II;B!096UI;&EK`$MO9&4@4$A0`%!(4"!3:&5L
M;`!032!'97)I;6ES`%!-($=E<FEM:7,`4$T@0F5R<V%L:G4`4$T@1V5R:6UI
M<R!386QJ=0!032!#97)A:`!032!(=6IA;B!P971I<B!D:7-E<G1A:2!D96YG
M86X@86YG:6X@<FEB=70`16MS=&5N<VD@4$]325@@=&ED86L@9&ET96UU:V%N
M`%!(4"!3:&5L;`!*87)A:R!S<&%S:2!D87)I(&)O<F1E<@!(86QA;6%N("5D
M(&1A<FD@)60`0F%G:6%N`%-E8F%G:6%N($)E<F%W86X`4&%S<W=O<F0`4V%N
M9&D@8F5R:&%S:6P@9&EU8F%H+@!386YD:3H`4V%N9&DZ`%-A;F1I(&AA<G5S
M(&-O8V]K+@!386QI;@!,96MA=&MA;B!D87)I(&-L:7!B;V%R9`!0871H`%!E
M;F1A9G1A<F%N('EA;F<@9&ET=6YD83H`3W)A;F<`4&5R<V5N`$UE;&%K<V%N
M86MA;B!/<&5R87-I(%!E;65L:6AA<F%A;@!,86MU:V%N(&]P97)A<VD@<&5R
M87=A=&%N('!A9&$@;&]G:6X_`$EZ:6X@=6YT=6L@(B5S(B!T:61A:R!D87!A
M="!D:6AA<'5S+@!)>FEN($%D;6EN:7-T<F%S:0!0<FEB861I`$EN9F]R;6%S
M:2!0<FEB861I`$)I;F%T86YG($ME<V%Y86YG86X`1F]T;P!0:7AE;`!,971A
M:VMA;B!T86YD871A;F=A;B!A;F1A('-E8F5L=6T@;65M8F%L87,@9&%N(&UE
M;F5R=7-K86X_`$MA=&$M:V%T82!K;&ES90!3:6QA:V%N(&ML:6L@:V4@9&%L
M86T@8F5B97)A<&$@<V5L`%-I;&%K86X@:V]N9FER;6%S:2!B86AW82!A;F1A
M(&EN9VEN(&UE;6EN9&%H:V%N(&5L96UE;B!I;FDZ`%-I;&%K86X@:V]N9FER
M;6%S:2!B86AW82!A;F1A(&EN9VEN(&UE;F=H87!U<R!L:6YK('5N='5K(&5L
M96UE;B!I;FDN`%-I;&%K86X@;6%S=6MK86X@;F%M82!U;G1U:R!K871E9V]R
M:2!Y86YG(&)A<G4Z`$UA<W5K:V%N(&YA;6$@=6YT=6L@9F]L9&5R(&)A<G4Z
M`$UA<W5K:V%N(&YA;6$@9&%R:2!F;VQD97(@8F%R=3H`36%S=6MK86X@;F%M
M82!B87)U.@!3:6QA:V%N(&UA<W5K:V%N(')I;F=K87-A;B!U;G1U:R!M87-A
M;&%H+@!3:6QA:V%N(&UA<W5K:V%N(&YA;6$@<&5N9V=U;F$@9&%N('-A;F1I
M(&%N9&$`4VEL86MA;B!M96UB86-A('1E:W,@8F5R:6MU="!I;FDN($%N9&$@
M2$%255,@<V5T=6IU(&1E;F=A;B!S>6%R870M<WEA<F%T('5N='5K(&UE;F=G
M=6YA:V%N('-I<W1E;2X`0F5T=6QK86X@86QA;6%T('EA;F<@<F%N8W4@9&%N
M('1I9&%K(&)E;F%R+@!0:6QI:"!S96)U86@@9F]L9&5R('-E8F5L=6T@;65L
M86MU:V%N(&%K<VDN`%!I;&EH('-E9&EK:71N>6$@<V%T=2!F;VQD97(@=6YT
M=6L@<&5N8V%R:6%N+@!0:6QI:"!H86YY82!S871U(&9O;&1E<B!U;G1U:R!O
M<&5R87-I(&EN:2X`4&]L:71I:P!0;VQL:6YG`%!O<VES:2!U;G1U:R!G86UB
M87(@:6YI`%!O<VES:2!U;G1U:R!T86)E;"!I;FD`2'5J86X@<V%L:G4@=6YT
M=6L@)7,@:F%M('1E<F%K:&ER.@!+96UU;F=K:6YA;B`\8G(O/DAU:F%N('-A
M;&IU`%1E:V%N86X`5&5K86YA;B!P861A('!E<FUU:V%A;B!L875T.@!496MA
M;F%N.@!,:6AA="!G86UB87(@9&D@9&%L86T@:F5N9&5L82!Y86YG(&)A<G4`
M4&5S86X@4V5B96QU;6YY80!(86QA;6%N(%-E8F5L=6UN>6$`0V5T86L`0V5T
M86L@9&]K=6UE;@!$97-K<FEP<VD@36%S86QA:`!0<F]J96L`0G5A;F<@>6%N
M9R!$:6AA<'5S`$)U86YG(%1R87-H('-E;&%M83H`0G5A;F<@<&5S86X@;&%M
M82!D86QA;2!F;VQD97(@5')A<V@@>6%N9R!L96)I:"!D87)I(&IU;6QA:"!J
M871A:"!H87)I+@!1=65R>0!+=6]T80!(=6IA;@!(=6IA;B!D:2!P86=I(&AA
M<FD`2'5J86X@8F5B97)A<&$@<V%A="!L86=I`$=E<FEM:7,`2'5J86X@9&%N
M($)E<G-A;&IU`$AU:F%N(&)E<F-A;7!U<B!D96YG86X@<V%L:G4`4F%M86QA
M;B!!8V%K`$)A8V$`66%K:6X@=6YT=6L@;65N9VAA<'5S("5S/R!/<&5R87-I
M(&EN:2!T:61A:R!D87!A="!D:6)A=&%L:V%N+@!986MI;B!U;G1U:R!M96UI
M;F1A:&MA;B!D871A('!E;F=G=6YA('5N='5K('!E;F=G=6YA("5S/R!/<&5R
M87-I(&EN:2!T:61A:R!D87!A="!D:6)A=&%L:V%N+@!!<F%H:V%N`$%R86AK
M86X@4&5S86X`07)A:&MA;B!P97-A;B!I;FD`4&5N9V%R86AA;B!G86=A;`!5
M;&%N9VD@86MS:2!T97)A:VAI<B!A;F1A`%1A;7!I;"!5;&%N9P!2969R97-H
M($5L96UE;B!-96YU($1I;F%M:7,Z`%1A;7!I;"!5;&%N9R!&;VQD97(Z`%)E
M9G)E<V@@3&EH870@4&]R=&%L.@!486UP:6P@3&%G:0!$:71A;F1A:0!);F=A
M="!T86UP:6QA;B!T97)A:VAI<@!296UO=&4@4V5R=F5R`%)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I`%!I;F1A:&MA;@!0:6YD
M86AK86X@0FQO:VER`%!I;F1A:&MA;B!#87)A($9O<FUA=`!0:6YD86AK86X@
M<&%S86YG86X`4&EN9&%H:V%N('-C<FEP="!Y86YG('-U9&%H(&1I<VEM<&%N
M(&1A<FD@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A<F$N`%!I;F1A:&MA;@!0
M:6YD86AK86X@;F]D92!I;FD@9&%R:2!D;VMU;65N`%!I;F1A:&MA;B!P96YG
M9W5N80!0:6YD86AK86X@<&5N9V=U;F$Z("5S`%5B86@@;F%M82!F;VQD97(@
M<V5N="UM86EL('!A9&$@87=A;"!B=6QA;C\`1V%N=&D@9&5N9V%N.@!"86QA
M<P!"86QA<R!K92!396UU80!"86QA<R!K92!396UU83H`0F%L87,M2V5P861A
M.@!"86QA<SH`3&%P;W)K86X@<V5B86=A:2!3<&%M`%)E<V5T`$%T=7(@:V5M
M8F%L:2!386YD:0!!='5R(&ME;6)A;&D@4V%N9&D@06YD80!(87-I;`!5;&%N
M9VD`2V5M8F%L:2!K92!M86EL8F]X('-E=&5L86@@<&5N9VAA<'5S86XL('!E
M;6EN9&%H86X@9&%N('!E;F=C;W!Y86X@<&5S86X_`$ME=&EK('5L86YG('-A
M;F1I(&)A<G4`2V5M8F%L:2!K92!+;VYF:6=U<F%S:0!0:6QI:&%N($5D:71O
M<B!2:6-H(%1E>'0`5&5K82UT96MI`$MA;F%N`%!R;W!E<G1I($)A<FES+BXN
M`%!R;W!E<G1I($)A<FES`%!R;W!E<G1I(&)A<FES`$)A<FES.@!!='5R86X`
M071U<F%N(&%K86X@9&ET86UP:6QK86X@9&EA;G1A<F$@<V5M=6$@8F%R:7,@
M9&%N(&MO;&]M`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&AA;GEA(&1I86YT
M87)A(&MO;&]M`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&AA;GEA(&1I86YT
M87)A(&)A<FES`$IA;&%N:V%N`%!E<V%N(%--4P!344P@4VAE;&P`4U-(`%-?
M44P@4VAE;&P`4V)T`$9R86UE('EA;F<@<V%M82`H7W-E;&8I`%-I;7!A;B`E
M<P!3:6UP86X@1')A9G0`4VEM<&%N('-E8F%G86D`4VEM<&%N(&MO;F9I9W5R
M87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!02%`@:V4@9&%L
M86T@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A<F$@86YD82X`2V]N9FEG=7)A
M<VD@)7,@<W5D86@@9&ES:6UP86XN`%!E;GEI;7!A;F%N(&1R869T(&=A9V%L
M+B!);FD@>6%N9R!D:6MA=&%K86X@<V5R=F5R.B`E<P!396)A9VEA;B!(=6IA
M;B!P971I<B!D:7-E<G1A:2!A;F=I;B!R:6)U=`!);&UU(%!E;F=E=&%H=6%N
M`$-A<FD`365S:6X@4&5N8V%R:6%N`$AA<VEL(%!E;F-A<FEA;@!$:6QI:&%T
M`%!I;&EH`%!I;&EH(&=R=7`@=6YT=6L@9&ET86UB86@`4&EL:6@@<&5M:6QI
M:R!B87)U`%!I;&EH('-E<G9E<@!0:6QI:"!P96YG9W5N82!U;G1U:R!D:71A
M;6)A:`!0:6QI:"!S96UU80!0:6QI:"!T:61A:R!A9&$`4&EL:6@@:V%R86MT
M97(@>6%N9R!A;F1A('!E<FQU:V%N(&1A<FD@:V]T86LM:V]T86L@9&EB87=A
M:"!I;FDN($%N9&$@9&%P870@;65N>6%L:6X@9&%N(&UE;&5K871K86YN>6$@
M:V4@9&%L86T@87)E82!T96MS+@!0:6QI:"!B871A<R!T86YG9V%L.@!0:6QI
M:"!F;W)M870@=&%N9V=A;#H`4&EL:6@@:61E;G1I=&%S('EA;F<@:6YG:6X@
M9&EU8F%H(&]L96@@86YD83H`4&EL:6@@8F%T87,@=V%K='4Z`%!I;&EH(&9O
M<FUA="!W86MT=3H`4&EL:6@@9'5A(&MO;&]M('EA;F<@8V]C;VLN`%!I;&EH
M('=A<FYA('-C:&5M92!A;F1A+@!0:6QI:"!B86AA<V$@>6%N9R!A;F1A(&EN
M9VEN:V%N.@!+:7)I;2!097-A;@!+:7)I;2!,87!O<F%N($UA<V%L86@`4V5N
M<V]R.@!&;VQD97(@<V5N="!M86EL.@!397!T96UB97(`4V5R=F5R`$%T=7(@
M<&EL:6AA;B!U;G1U:R!M96YG:7II;FMA;B!A;F1A(&1A<&%T(&UE;F=A='5R
M('5L86YG(&ME;6)A;&D@<V%N9&D@86YD82!A<&%B:6QA(&%N9&$@;'5P82X`
M4V5T('!R969E<F5N8V4@87!A('EA;F<@=&5R:F%D:2!J:6MA(&%N9&$@;65M
M:6YD86@@9&%N(&UE;F=H87!U<R!P97-A;BX`071U<B!R96UO=&4@<V5R=F5R
M('EA;F<@:6YG:6X@86YD82!A:W-E<R!D87)I('!O<G1A;"!A;F1A+@!!='5R
M(&)A:&%S82P@>F]N82!W86MT=2!D86X@<&EL:6AA;B!T86YG9V%L+"!Y86YG
M(&%N9&$@:6YG:6YK86XN`$%T=7(@87!L:6MA<VD@87=A;"!A;F1A+"!W87)N
M82!S8VAE;64L(&AA;&%M86X@<F5F<F5S:"!D86X@<&EL:6AA;B!T86UP:6QA
M;B!L86EN;GEA+@!3971U<`!38W)I<'0@<V5T=7`@=7!G<F%D92!T97)S961I
M80!"96)E<F%P82!L;VMA<VD@>6%N9R!M=6YG:VEN(&1E;F=A;B!P87)A;65T
M97(Z`$)E;&%N:F$`4FEN9VMA<V%N(%!E;F1E:P!097)L=6MA:"!K=6YC:2!A
M:W-E<R!D:61E9FEN:7-I:V%N('5N='5K(&ME8F%N>6%K86X@;&EN:S\`2&%R
M=7-K86@@=VEN9&]W('!E;F=I<FEM86X@9&ET=71U<"!S971E;&%H(&UE;GEI
M;7!A;B!D<F%F=#\`5&%M<&EL:V%N`%1U;FIU:VMA;B!Y86YG($1I:&%P=7,`
M5'5N:G5K:V%N('1I9&%K(&QA;F=G86YA;@!486UP:6QK86X@<&5R8F5D86%N
M(&1I86YT87)A(&MO;F9I9W5R87-I('EA;F<@8F%R=2!D:7-I;7!A;B!D86X@
M>6%N9R!B87)U(&1I:&%S:6QK86XN`%1A;7!I;&MA;B!W86MT=2!L;V=I;B!T
M97)A:VAI<B!K971I:V$@86YD82!L;V=I;C\`5'5N:G5K:V%N(&QE9V5N9&$@
M<&%D82!T86UP:6QA;B!M86EL8F]X/P!486UP:6QK86X@<&%N96P@;65N=2!T
M86)E;"!O<&5R87-I/P!486UP:6QK86X@365N=2`E<R!D:2!S96)E;&%H(&MI
M<FD_`%1A;7!I;&MA;B!D:6%L;V<@4')O<&5R=&D@4V5L(%1A8F5L`%1A;7!I
M;&MA;B!D:6%L;V<@4')O<&5R=&D@5&%B96P`5&%M<&EL:V%N(&1I86QO9R!0
M<F]P97)T:2!"87)I<R!486)E;`!486UP:6QK86X@9&EA;&]G('!R;W!E<G1I
M(&=A;6)A<@!'97)I;6ES`$=E<FEM:7,@9&D@<&%G:2!H87)I`$=E<FEM:7,@
M8F5B97)A<&$@<V%A="!L86=I`$=E<FEM:7,@9&D@<V5K:71A<B!D865R86@`
M56MU<F%N`$QE=V%T:2!096UE;&EH87)A86X`4V%L:G4`1V5R:6UI<R!386QJ
M=0!'97)I;6ES(%-A;&IU`$=E<FEM:7,@4V%L:G4@9&D@<&%G:2!H87)I`$=E
M<FEM:7,@4V%L:G4@8F5B97)A<&$@<V%A="!L86=I`$ME9&%L86UA;B!386QJ
M=3H`4&5R8F%N9&EN9V%N('-A;&IU(&1I("AD86QA;2D@86ER.@!,86=U("8@
M4V%J86L`17)O<&$@4V5L871A;B`H25-/+3@X-3DM,RD`0F5L86AA;B!"=6UI
M(%-E;&%T86X`2F%R86L@86YT87)A('-E;"!Y86YG(&)E<F1E:V%T86X`2F%R
M86L@86YT87)A(&ES:2!D86X@8F]R9&5R(&1I(&1A;&%M('-E;`!*87)A:R!S
M<&%S:0!*87)A:R!S<&%S:2!D86X@:F%R86L@<W!A<VD@9&%R:2!B;W)D97(`
M4W!A;0!-87-U:VMA;B!+87)A:W1E<B!3<&5S:6%L`$MA<F%K=&5R(%-P97-I
M86P`0V5K($5J86%N`%!E;F=E8V5K($5J86%N`$-E:R!E:F%A;B!S96QE<V%I
M`$5J82!K97-A;&%H86X@<&5R(&QA>6%R(&II:V$@;65N9V5C96L@96IA86X`
M4&ES86AK86X@4V5L`%!I<V%H:V%N(&MO;&]M`%!I<V%H:V%N(&)A<FES`$]L
M86AR86=A`%-T86YD87(`4&5R:F%L86YA;B!":6YT86YG`$%N9VMA+VAU<G5F
M+W-I;6)O;"!Y86YG(&1I8F5R:2!T86YD82!G87)I<P!'87EA(%M#4U-=`$UI
M;@!097)I:&%L`$9I96QD(%!E<FEH86P`4W5B<V-R:6)E(&ME($9O;&1E<@!!
M;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:71U;&ES(&1I8F%W86@@9V%R:7,@
M8F%R:7,@=&5K<P!3=6MS97,`(B5S(G-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N
M`$MO;F9I9W5R87-I('-U9&%H(&)E<FAA<VEL(&1I:V5M8F%L:6MA;BX@56QA
M;F=I('5N='5K(&UE;&EH870@<&5R=6)A:&%N+B``0F%C:W5P(&MO;F9I9W5R
M87-I('-U9&%H(&)E<FAA<VEL(&1I<VEM<&%N+@!&:6QE($)A8VMU<"!+;VYF
M:6=U<F%S:2`E<R!S=61A:"!B97)H87-I;"!D:7-I;7!A;BX`)R5S)R!S=61A
M:"!B97)H87-I;"!D:71U;&ES`%-A<F%N`$UA=&%H87)I(%1E<F)I=`!-871A
M:&%R:2!497)B96YA;0!#97)A:`!-871A:&%R:2!497)B:70`36%T86AA<FD@
M5&5R8FET+TUA=&%H87)I(%1E<F)E;F%M`$UA=&%H87)I(%1E<F)I=#H`36%T
M86AA<FD@5&5R8F5N86T`36%T86AA<FD@5&5R8F5N86TZ`$%N9VMA+VAU<G5F
M+W-I;6)O;"!Y86YG(&1I='5L:7,@9&EA=&%S(&)A<FES('1E:W,`1'5K=6YG
M86X`2'5J86X@<&5T:7(@9&ES97)T86D@9&5N9V%N(&%N9VEN(')I8G5T`$AU
M:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!B861A:2!A;F=I;B!R:6)U=`!(
M=6IA;B!P971I<B!D:7-E<G1A:2!D96YG86X@86YG:6X@<FEB=70`4')O<&5R
M=&D@5&%B96P`4')O<&5R=&D@=&%B96P`5&%R9V5T.@!4=6=A<P!3=6AU('5N
M='5K(&IA;2!T97)A:VAI<CH`4W5H=0!3=6AU.@!3=6AU/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@061M:6YI<W1R87-I`%1E:W,`
M2&%N>6$@5&5K<P!097)A=&%A;B!496MS`%1E:W,@0F%G:6%N($%T87,`2VUS
M`%1H86D@*%1)4RTV,C`I`%!E;65L:6AA<F%A;CHZ(&-L87-S('1I9&%K(&)E
M<FAA<VEL(&1I<&%N9V=I;`!7:6YD;W<@4&EL:6AA;B!S=61A:"!D:71U='5P
M+B!3:6QA:V%N($ME;'5A<@!(86YY82!S:7-I(&)A9VEA;B!B87=A:`!&;VQD
M97(@(B5S(B!Y86YG(&)E<FQA:W4@86MA;B!D:75B86@@;F%M82!K92`B)7,B
M+@!&;VQD97(@(B5S(B!S=61A:"!A9&$`1F]L9&5R("(E<R(@8F5R:7-I(&MA
M<F%K=&5R(&EL96=A;"!P861A(&YA;6%N>6$N($EN:2!M=6YG:VEN(&UE;FIA
M9&D@;6%S86QA:"X@4VEL86MA;B!T86YY82!P861A(&%D;6EN:7-T<F%T;W(@
M<VES=&5M(&%N9&$N`$9O;&1E<B`B)7,B('-U9&%H(&1I8G5A="!T971A<&D@
M86YD82!T:61A:R!M96QA;F=G86X@<&%D86YY82X`1F]L9&5R("(E<R(@<W5D
M86@@9&EH87!U<R!T971A<&D@86YD82!T:61A:R!T:61A:R!M96QA;F=G86X@
M9&%R:6YY82X`1F]L9&5R("(E<R(@<W5D86@@9&EB=6%T+B!);FD@>6%N9R!D
M:6MA=&%K86X@<V5R=F5R`$9O;&1E<B`B)7,B('1I9&%K(&1I:&%P=7,N($EN
M:2!Y86YG(&1I:V%T86MA;B!S97)V97(`1F]L9&5R("(E<R(@<W5D86@@9&EB
M=6%T(&1E;F=A;B!S=6MS97,N`$9O;&1E<B`B)7,B('-U9&%H(&1I:&%P=7,@
M9&5N9V%N('-U:W-E<RX`1F]L9&5R("(E<R(@<W5D86@@9&EU8F%H(&YA;6$@
M:V4@(B5S(B!D96YG86X@<W5K<V5S+@!-;V1E($QA>6%R(%!E;G5H(&1I:V5N
M86P@9&%P870@;65N>65B86)K86X@;6%S86QA:"!D96YG86X@26YT97)N970@
M17AP;&]R97(L(&IU9V$@=6YT=6L@;65N8V%R:2!K97-A;&%H86X@>6%N9R!M
M96YY96)A8FMA;B!A;F1A('1I9&%K(&UA;7!U(&)E:V5R:F$@9&5N9V%N(&)A
M:6LN($%N9&$@;75N9VMI;B!P97)N86@@;65N9V%L86UI('1A;7!I;&%N('EA
M;F<@8G5R=6LL(&ME:W5R86YG86X@9&%R:2!F=6YG<VD@961I=&]R(&1A;B]A
M=&%U(&)R;W=S97(@>6%N9R!S97)I;F<@:V%L:2!R=7-A:R!D86X@:&%R=7,@
M9&EU;&%N9R!K96UB86QI+B!*:6MA('-I<W1E;2!A;F1A(&%D86QA:"!7:6YD
M;W=S(#EX(&%D82!K96UU;F=K:6YA;B!A;F1A(&%K86X@;65N9&%P871K86X@
M)TME<V%L86AA;B!097)L:6YD=6YG86X@56UU;2<@9&%N('!E<FQU('5N='5K
M(&UE+7)E<W1A<G0@:V]M<'5T97(@86YD82Y<;EQN($%N9&$@<W5D86@@9&EP
M97)I;F=A=&DN(%-I;&%K86X@:VQI:R!/2R!J:6MA(&%N9&$@:6YG:6X@;65N
M8V]B82!E9&ET;W(@;&%Y87(@<&5N=6@N`$ED96YT:71A<R`B)7,B('-U9&%H
M(&1I:&%P=7,N`$AA;GEA('-I<VD@8F%G:6%N(&MI<FD`2&%N>6$@<VES:2!B
M86=I86X@:V%N86X@9&%N(&MI<FD`2&%N>6$@<VES:2!B86=I86X@:V%N86X`
M4V5R=F5R("(E<R(@<W5D86@@8F5R:&%S:6P@9&EH87!U<RX`4V5R=F5R("(E
M<R(@<W5D86@@8F5R:&%S:6P@9&ES:6UP86XN`%1A;F1A=&%N9V%N('-U9&%H
M(&1I9V%N=&D@9&5N9V%N('-U:W-E<RX`4&5R;6EN=&%A;B!P96YD869T87)A
M;B!U;G1U:R`E<R!S=61A:"!B97)H87-I;"!D:7!I;F1A:&MA;BX`2&%N>6$@
M<VES:2!B86=I86X@871A<R!D86X@8F%W86@`2&%N>6$@<VES:2!B86=I86X@
M871A<P!!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D:6%K86XN`%1I
M9&%K(&%D82!P97-A;B!D86QA;2!M86EL8F]X(&EN:2X`061A(&UA<V%L86@@
M97AP=6YG:6YG("5S+B!);FD@>6%N9R!D:6MA=&%K86X@<V5R=F5R`$%D82!M
M87-A;&%H(&5X<'5N9VEN9R!M86EL8F]X+B!);FD@>6%N9R!D:6MA=&%K86X@
M<V5R=F5R`$%D82!K97-A;&%H86X@<V%A="!M96YG:&%P=7,@<&5S86X@9&%R
M:2!F;VQD97(@(B5S(BX@26YI('EA;F<@9&EK871A:V%N('-E<G9E<@!!9&$@
M:V5S86QA:&%N(&UE;F=C;W!Y('!E<V%N(&ME("(E<R(N($EN:2!Y86YG(&1I
M:V%T86MA;B!S97)V97(`061A(&ME<V%L86AA;B!S86%T(&UE;F%M<&EL:V%N
M(&)A9VEA;B!P97-A;B!I;FD`061A(&ME<V%L86AA;B!S86%T(&UE;69L86<@
M<&5S86X@9&%R:2!F;VQD97(@(B5S(BX@26YI('EA;F<@9&EK871A:V%N('-E
M<G9E<@!!9&$@:V5S86QA:&%N(&1I(&1A;&%M(&9O<FUU;&ER(&MO;F9I9W5R
M87-I+B!-=6YG:VEN(&%N9&$@=&ED86L@;65N9VES:2!K;VQO;2!Y86YG(&1I
M<&5R;'5K86XN`$%D82!K97-A;&%H86X@<V%A="!M96YG:7)I;2!P97-A;B!A
M;F1A.B`E<P!);FD@861A;&%H("5S+@!);FD@;75N9VMI;B!B=71U:"!W86MT
M=2X@06YD82!Y86MI;B!I;F=I;B!M96QA;FIU=&MA;C\`4&5S86X@:6YI(&ME
M<&%D80!7:6YD;W<@:6YI(&AA<G5S(&1I<&%N9V=I;"!D87)I(%!I;&EH86X@
M5VEN9&]W`$QI:&%T(%1H<F5A9`!0971I<@!4:6ME=`!-96YG:6MU=&D@5V%K
M='4`1F]R;6%T(%=A:W1U`$IU9'5L`$IU9'5L("A#871A=&%N('!E='5N:G5K
M*0!+97!A9&$`2&%R:2!);FD`1V%N=&D@4V]U<F-E($A434P`0F5S;VL`071A
M<P!&<F%M92!!=&%S("A?=&]P*0!4<F%N<VQA<VD`1F]L9&5R(%1R87-H.@!3
M96P`5'5R:VD@*$E33RTX.#4Y+3DI`$EN9&5K<R!5+E8Z`%523`!54DPZ`%1I
M9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R`B)7,B.B`E<RX`5&ED86L@9&EJ
M87=A8@!097-A;B!T:61A:R!D:6IA=V%B`%1I9&%K(&1I:&%P=7,`1V%R:7,@
M8F%W86@`4&5N97)I;6$@<F%H87-I80!"871A;&MA;B!097)U8F%H86X`0F%T
M86QK86X@86MS:2!T97)A:VAI<B!A;F1A`%1I9&%K(&1I87)S:7!K86X`56YI
M8V]D92`H551&+3@I`%5N:70`0F%T86QK86X@;&EN:R!P861A(&5L96UE;B!Y
M86YG('-E:V%R86YG`%1I9&%K(&1I;F%M86D`4V-R:7!T('EA;F<@=&ED86L@
M;65M<'5N>6%I(&AA:R!I<W1I;65W82!T:61A:R!D87!A="!M96YG86MS97,@
M2&%P=7,O4V%L:6XO3&5K871K86X@<V5S=6%I(')E;F-A;F$@=6YT=6L@86QA
M<V%N(&ME86UA;F%N+DML:6L@3TL@=6YT=6L@;65L:6AA="!C871A=&%N('1E
M:VYI<R!P861A(&UO>FEL;&$N;W)G(&1I;6%N82!A;F1A(&%K86X@9&EP97)L
M:6AA=&MA;B!C87)A(&)A9V%I;6%N82!U;G1U:R!M96YG:7II;FMA;B!S8W)I
M<'0@=6YT=6L@9&%P870@;65N9V%K<V5S(&ME(&-L:7!B;V%R9"X`5&ED86L@
M9&EL:6AA=`!787)N82!B96QU;2!D:6%T=7(`5&ED86L@;&%N9V=A;F%N(&1A
M<FD@1F]L9&5R`%!E<F)A:&%R=6D`4&5R8F%H87)U:2`E<P!097)B86AA<G5I
M('!E;F=G=6YA`"(E<R(@<W5D86@@9&EP97)B86AA<G5I+@!38W)I<'0@=7!G
M<F%D92!S=61A:"!D:6AA<'5S+@!396UU82!F:6QE('-E='5P(&%P;&EK87-I
M('-U9&%H(&1I=7!L;V%D(&ME('-E<G9E<BX`4VEM8F]L(&AU<G5F(&)E<V%R
M(&QA=&EN`%-I;6)O;"!H=7)U9B!B97-A<B!R;VUA=VD`1W5N86MA;B!.:6QA
M:2!$969A=6QT`$=U;F%K86X@9F]L9&5R($E-05`@;&%N9V=A;F%N/P!'=6YA
M:V%N;&%H(&II:V$@;F%M82]S86YD:2!A;F1A(&)E<F)E9&$@=6YT=6L@<V5R
M=F5R($E-4U`N`$%D;6EN:7-T<F%S:2!096YG9W5N80!096YD869T87)A;B!0
M96YG9W5N80!096YD869T87)A;B!096YG9W5N82!S=61A:"!D:6YO;BUA:W1I
M9FMA;B!U;G1U:R!S:71E(&EN:2X`06-C;W5N="!096YG9W5N82!T:61A:R!D
M:71E;75K86X`57-E<FYA;64`3F%M82!096YG9W5N83H`4&5N9V=U;F$@9&D@
M9&%L86T@<VES=&5M.@!,:6)U<F%N`%9A<FEA8FQE`%9E<G-I($MO;G1R;VP`
M2F%R86L@<&]S:7-I('9E<G1I:V%L(&%N=&%R82!G87)I<R!D87-A<B!D96YG
M86X@9V%M8F%R`$IA<F%K('!O<VES:2!V97)T:6MA;"!A;G1A<F$@8F]R9&5R
M(&1E;F=A;B!G86UB87(`5F5R=&EK86PZ`%-A;F=A="!4:6YG9VD`5FEE=&YA
M;2`H5DE30TE)*0!,:6AA="`E<P!,:6AA="!W96(@<&%G92!E:W-T97)N86P`
M3&EH870@871A=2!T86UP:6QK86X@;6%I;&)O>"!S971E;&%H(&QO9VEN.@!*
M87)A:R!086YD86YG`$IA<F%K(%!A;F1A;F<Z`%!%4DE.1T%404XA(2$@4$E.
M1$%(2T%.(%-#4DE05"!)3DD@4T5#05)!($U!3E5!3"!$05))("5S+@!097)I
M;F=A=&%N`%)A8G4`4F%M86QA;B!#=6%C80!$871A($-U86-A(&1I<V5D:6%K
M86X@;VQE:`!796(`5V5B(%-I=&4`4V5L86UA="!$871A;F<`4V5L86UA="!$
M871A;F<@9&D@)7,`4V5L86UA="!D871A;F<L("5S`%=E<W1E<FX@*$E33RTX
M.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!!<&%K86@@87!L:6MA<VD@
M)7,@<&5R;'4@9&ET86UP:6QK86X@<V5T96QA:"!L;V=I;C\`07!A:V%H('EA
M;F<@;65R=7!A:V%N(&)A=&%S(&MA<F%K=&5R/P!!<&%K86@@>6%N9R!M97)U
M<&%K86X@:V%R86MT97(@:6YD96YT87-I/P!*:6MA('!E<V%N(&1I:&%P=7,L
M('!I;F1A:&MA;B!M97)E:V$@:V4@9F]L9&5R(%1R87-H(&%N9&$@9&%R:7!A
M9&$@;65N86YD86D@;65R96MA(&1E;F=A;B!T97)H87!U<S\`1F%S92!Y86YG
M(&UA;F$`4&QU9VEN(&UA;F%K86@@>6%N9R!D87!A="!D:6%K=&EF:V%N('5N
M='5K(&5D:71O<B!2:6-H(%1E>'0N`%=H:71E;&ES=`!,96)A<@!,96)A<B!M
M96YU("5S('!A9&$@8F%G:6%N(&MI<FD@*&%K86X@8F5R<&5N9V%R=6@@<&%D
M82!L;V=I;B!B97)I:W5T;GEA*0!,96)A<B!T86)E;`!,96)A<B!U;FET`$QE
M8F%R.@!7:6MI`$%N9VEN`$%N9VEN(&1I('!A9VD@:&%R:0!+96-E<&%T86X@
M86YG:6X@9&D@9&%L86T@:VYO=`!!;F=I;CH`06YG:6XZ`$MA=&$@0FEJ86MS
M86YA`$1A9G1A<B!+96EN9VEN86X`4&5K97)J86%N`%@M4F5F`%E9`%EA`%EA
M+"!305E!(%-%5%5*50!!;F1A('-E9&%N9R!M96YG8V]P>2]M96UI;F1A:"!K
M92!F;VQD97(@8F%R=2X`06YD82!S961A;F<@;65M8G5A="!S=6(M9F]L9&5R
M(&ME(`!!;F1A('-E9&%N9R!M96UB=6%T(&9O;&1E<B!T:6YG:V%T+6%T87,N
M`$%N9&$@8F5R861A(&1I(&1A;&%M($U/1$4@5$5+4RX@1W5N86MA;B!T;VUB
M;VP@6SP^72!U;G1U:R!M96YG9V%N=&D@:V5M8F%L:2!K92!D86QA;2!M;V1E
M(%=94TE764<N`$%N9&$@=&ED86L@9&EI>FEN:V%N('5N='5K(&UE;6)U870@
M;&5B:6@@9&%R:2`E9"!A<F5A+@!!;F1A('-E9&%N9R!M96YG=6)A:"!N86UA
M(&9O;&1E<CH@`$%N9&$@<'5N>6$@)7,@<&5S86X@8F%R=2X`06YD82!P=6YY
M82`Q('!E<V%N(&)A<G4N`$%N9&$@<'5N>6$@;6%I;"!D86QA;2!F;VQD97(@
M8F5R:6MU="!I;FDZ`$%N9&$@<'5N>6$@;6%I;"!D86QA;2!F;VQD97(M9F]L
M9&5R(&)E<FEK=70@:6YI.@!!;F1A(&AA<G5S(&UE;FIE;&%S:V%N(&UA<V%L
M86@@<V5B96QU;2!A;F1A(&1A<&%T(&UE;F=I<FEM:V%N(&QA<&]R86X@;6%S
M86QA:"X`06YD82!H87)U<R!M96UA<W5K:V%N(%523"!D:6UA;F$@;&EN:R!I
M;FD@;65N=6YJ=6L@:V4`06YD82!H87)U<R!M96UI;&EH(&UA:6QB;W@@=&%R
M9V5T(&1U;'4N`$%N9&$@:&%R=7,@;65M:6QI:"!A;&%M870@9'5L=2X`06YD
M82!H87)U<R!M96UI;&EH('-E<G9E<B!U;G1U:R!D87!A="!D:6AA<'5S+@!!
M;F1A(&AA<G5S(&UE;6EL:6@@9'5L=2!P86QI;F<@<V5D:6MI=&YY82!S871U
M('!E<V%N`$%N9&$@:&%R=7,@;65N<W!E<VEF:6MA<VD@<&5N97)I;6$N`$%N
M9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('EA;F<@:6YG:6X@
M9&EB97)S:6AK86XN`$%N9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G
M=6YA('EA;F<@:6YG:6X@9&EP:6YD86AK86XN`$%N9&$@:&%R=7,@;65N971A
M<&MA;B!N86UA('!E;F=G=6YA('5N='5K(&1I=&%M8F%H+@!!;F1A(&AA<G5S
M(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!U;G1U:R!D:7!E<F)A:&%R=6DN
M`$%N9&$@=&ED86L@;&%N9V=A;F%N(&ME("(E<R(N($EN:2!Y86YG(&1I:V%T
M86MA;B!S97)V97(`06YD82!T:61A:R!T:61A:RUL86YG9V%N86X@9&%R:2`B
M)7,B+B!);FD@>6%N9R!D:6MA=&%K86X@<V5R=F5R`$%N9&$@<W5D86@@;&%N
M9V=A;F%N(&ME("(E<R(@9&5N9V%N('-U:W-E<P!!;F1A('-U9&%H('1I9&%K
M+6QA;F=G86YA;B!D87)I("(E<R(@9&5N9V%N('-U:W-E<P!!;&%M870@16UA
M:6P@06YD80!!;F1A($1A<FDZ(&%L86UA=#H`26YF;W)M87-I($%N9&$`0F%C
M:V5N9"!A<VQI(&%N9&$@=&ED86L@9&%P870@;65N9'5K=6YG('!E;F1A9G1A
M<F%N('!E;F=G=6YA+"!A=&%U(&9I='5R(&EN:2!S=61A:"!D:6YO;BUA:W1I
M9FMA;B!U;G1U:R!B96)E<F%P82!A;&%S86X@;&%I;@!"<F]W<V5R(&%N9&$@
M=&ED86L@;65N9'5K=6YG('5N='5K(&9I='5R(&EN:2X`6F]N82!786MT=2!!
M;F1A(%-E:V%R86YG.@!$969A=6QT(&ED96YT:71A<R!A;F1A('-U9&%H(&1I
M=6)A:"X`1&5F875L="!I9&5N=&ET87,@86YD83H`3F%M82!L96YG:V%P(&%N
M9&$Z`%-A;F1I(&)A<G4@86YD82!U;G1U:R`E<R!A9&%L86@Z("5S`%-A;F1I
M(&%N9&$@<W5D86@@9&EA='5R('5L86YG`%-A;F1I(&%N9&$@<W5D86@@9&EA
M='5R('5L86YG+"!P97)I:W-A;&%H(&5M86EL(&%N9&$@9&%N(&QO9VEN(&1E
M;F=A;B!M96YG9W5N86MA;B!S86YD:2!B87)U(&%N9&$`4F5M;W1E('-E<G9E
M<B!A;F1A.@!486YD871A;F=A;B!!;F1A`$-E<FEA`%M396UB=6YY:6MA;B!)
M;F1E;G1A<VD@5&5K<UT`6U1I9&%K(&%D82!097)I:&%L70!;3&%P;W)A;B!-
M87-A;&%H70!;5&%M<&EL86X@26YD96YT87-I(%1E:W,@+0!?061M:6YI<W1R
M87-I`%]#3$D`7T1A=&%4<F5E`$AA<'5S($)A<FES`%]'<G5P`%!R;W!E<G1I
M($=A;6)A<BXN+@!58F%H($QI;FLN+BX`27II;@!0:6YD86AK86X@3&EN:RXN
M+@!?4V5T=7``4')O<&5R=&D@5&%B96PN+BX`4&5N9V=U;F$`5&5N86YG`&IA
M='5H`&1A<FD`1&%R:2`E<R`H)7,I('!A9&$@)7,@)7,`86YG:6X@:V5N8V%N
M9P!M87-I:"!D:2!D86QA;2!A;G1R:6%N`&)A<FES70!T:61A:R!A9&$`871A
M=0!P97)S96X`<&EX96P`;F%I:P!T86UP:6QK86X@<&5R8F5D86%N`&ME<V%L
M86AA;B!E:F%A;@!K97-A;&%H86XM:V5S86QA:&%N(&5J86%N`'1E=&%P`$ME
M=&EK('-A;F1I(&1U82!K86QI('5N='5K(&UE;F=K;VYF:7)M87-I`&UE;GEA
M='5K86X`=V5A=&AE<BYC;VT`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M;V-A;&4O:'5?2%4O````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#$W-#8Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]H=5](52],0U]-15-304=%4R\`````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P
M,C$R-#8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VAU7TA5
M+TQ#7TU%4U-!1T53+VEM<"YM;P``````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S$V
M,S`P`#$P-#$W,S8R-S8S`#`R,C,W-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````&D+```<````9%L``$,/``"L
MM@```````+CS```*````N?,```H```#$\P``"@```,_S```*````VO,```X`
M``#E\P``#P```/3S```-````!/0```@````2]```"P```!OT```,````)_0`
M``H````T]```!````#_T```8````1/0``!L```!=]```+0```'GT```=````
MI_0``"0```#%]```*0```.KT```9````%/4```$````N]0``)@```##U```,
M````5_4```L```!D]0``)````'#U```>````E?4``$@```"T]0``*P```/WU
M``!$````*?8``"<```!N]@``%P```);V```/````KO8```L```"^]@``#@``
M`,KV```H````V?8```@````"]P``"@````OW```5````%O<``!(````L]P``
M,@```#_W```+````<O<``"D```!^]P``,@```*CW```0````V_<``!8```#L
M]P``$`````/X```F````%/@``"D````[^```)@```&7X```<````C/@``(4`
M``"I^```#@```"_Y```*````/OD```T```!)^0``)P```%?Y```B````?_D`
M``X```"B^0``(@```+'Y```9````U/D``"0```#N^0``-P```!/Z```1````
M2_H```T```!=^@``#````&OZ```-````>/H``!L```"&^@``E````*+Z```N
M````-_L``#<```!F^P``!@```)[[```,````I?L``'P```"R^P``;````"_\
M```<````G/P``!T```"Y_```"@```-?\```/````XOP``!@```#R_```#```
M``O]```;````&/T``$4````T_0``*````'K]``!!````H_T``"0```#E_0``
M#@````K^```/````&?X```X````I_@``#@```#C^```(````1_X```X```!0
M_@``#@```%_^```)````;OX``"X```!X_@``&@```*?^```S````POX``%$`
M``#V_@``,@```$C_```X````>_\``%0```"T_P``40````D``0!:````6P`!
M`%<```"V``$`-`````X!`0`)````0P$!``T```!-`0$`!P```%L!`0`*````
M8P$!``\```!N`0$`!0```'X!`0`#````A`$!``8```"(`0$`$0```(\!`0`(
M````H0$!``D```"J`0$`"0```+0!`0`=````O@$!``X```#<`0$`"````.L!
M`0`*````]`$!`"4```#_`0$`(````"4"`0`3````1@(!`!````!:`@$`#P``
M`&L"`0`/````>P(!``H```"+`@$`!P```)8"`0`#````G@(!`!D```"B`@$`
M#P```+P"`0`4````S`(!``D```#A`@$`#0```.L"`0`2````^0(!`!D````,
M`P$`'@```"8#`0`/````10,!``H```!5`P$`#P```&`#`0`(````<`,!``H`
M``!Y`P$`)````(0#`0`7````J0,!`!0```#!`P$`%@```-8#`0`2````[0,!
M``@`````!`$`'`````D$`0!.````)@0!`"T```!U!`$`&0```*,$`0!@````
MO00!`"@````>!0$`'@```$<%`0`:````9@4!`"P```"!!0$`(````*X%`0`R
M````SP4!``<````"!@$`#`````H&`0`-````%P8!`%0````E!@$`8P```'H&
M`0`L````W@8!``X````+!P$``P```!H'`0`+````'@<!``<````J!P$`!P``
M`#('`0`%````.@<!``4```!`!P$`"@```$8'`0`#````40<!`!<```!5!P$`
M"@```&T'`0`/````>`<!``X```"(!P$`3@```)<'`0!0````Y@<!`$,````W
M"`$`0@```'L(`0`]````O@@!`!8```#\"`$`,````!,)`0`8````1`D!`",`
M``!="0$`#@```($)`0`4````D`D!`!<```"E"0$`%P```+T)`0`7````U0D!
M`!,```#M"0$`#P````$*`0`C````$0H!``8````U"@$`%P```#P*`0`.````
M5`H!`%$```!C"@$`'P```+4*`0`=````U0H!`#4```#S"@$`-0```"D+`0`'
M````7PL!``8```!G"P$`"````&X+`0`/````=PL!``8```"'"P$`"````(X+
M`0`1````EPL!``H```"I"P$`$P```+0+`0`+````R`L!`!````#4"P$`%0``
M`.4+`0`-````^PL!`!,````)#`$`(P```!T,`0`O````00P!`!4```!Q#`$`
M!P```(<,`0`0````CPP!``4```"@#`$`%0```*8,`0`1````O`P!``P```#.
M#`$`/P```-L,`0`P````&PT!`$@```!,#0$`(0```)4-`0`[````MPT!`#L`
M``#S#0$`/````"\.`0`X````;`X!`"L```"E#@$`,````-$.`0`Q`````@\!
M`#L````T#P$`.0```'`/`0`U````J@\!``D```#@#P$`!P```.H/`0`4````
M\@\!``P````'$`$``P```!00`0`%````&!`!``D````>$`$`$````"@0`0`)
M````.1`!`!,```!#$`$``P```%<0`0`Y````6Q`!`!(```"5$`$`#````*@0
M`0`U````M1`!``X```#K$`$`20```/H0`0`S````1!$!``H```!X$0$`%@``
M`(,1`0`6````FA$!`"T```"Q$0$`"P```-\1`0`G````ZQ$!`"P````3$@$`
M*@```$`2`0`E````:Q(!``D```"1$@$`"0```)L2`0`*````I1(!``8```"P
M$@$`"0```+<2`0`'````P1(!`"\```#)$@$`-P```/D2`0`N````,1,!`%4`
M``!@$P$`+0```+83`0`L````Y!,!`"T````1%`$`/0```#\4`0`_````?10!
M`"T```"]%`$`0````.L4`0`C````+!4!`",```!0%0$`0````'05`0`M````
MM14!`#,```#C%0$`)0```!<6`0`5````/18!`!D```!3%@$`*0```&T6`0`D
M````EQ8!`"@```"\%@$`4````.46`0`8````-A<!`!$```!/%P$`$0```&$7
M`0`*````<Q<!``P```!^%P$`"P```(L7`0`*````EQ<!`",```"B%P$`%@``
M`,87`0`*````W1<!`!````#H%P$`%@```/D7`0`6````$!@!`!L````G&`$`
M+@```$,8`0`0````<A@!``<```"#&`$`!P```(L8`0`4````DQ@!``H```"H
M&`$`"````+,8`0`G````O!@!``@```#D&`$``P```.T8`0`'````\1@!``<`
M``#Y&`$`!@````$9`0`X````"!D!``4```!!&0$`!P```$<9`0`&````3QD!
M``@```!6&0$`"0```%\9`0`I````:1D!``X```"3&0$`"@```*(9`0!%````
MK1D!``0```#S&0$`!````/@9`0`'````_1D!``D````%&@$`!@````\:`0`1
M````%AH!``<````H&@$`%@```#`:`0`$````1QH!`"<```!,&@$`"````'0:
M`0`&````?1H!``T```"$&@$`!@```)(:`0`>````F1H!`!$```"X&@$`"```
M`,H:`0`-````TQH!``P```#A&@$`!P```.X:`0`#````]AH!`$8```#Z&@$`
M`P```$$;`0`7````11L!`!,```!=&P$`"````'$;`0`=````>AL!``@```"8
M&P$`!````*$;`0`(````IAL!``@```"O&P$`*@```+@;`0`K````XQL!`%,`
M```/'`$`00```&,<`0`:````I1P!`"L```#`'`$`(````.P<`0`5````#1T!
M``8````C'0$`!@```"H=`0`.````,1T!`!4```!`'0$`/@```%8=`0`8````
ME1T!`"(```"N'0$`+@```-$=`0`=`````!X!`"$````>'@$`5````$`>`0`I
M````E1X!``H```"_'@$`!P```,H>`0`'````TAX!`!4```#:'@$`#@```/`>
M`0`"````_QX!``H````"'P$`#P````T?`0`-````'1\!``\````K'P$`#0``
M`#L?`0`)````21\!`!0```!3'P$`!@```&@?`0`8````;Q\!`!T```"('P$`
M$P```*8?`0`1````NA\!`!0```#,'P$`3P```.$?`0`$````,2`!``P````V
M(`$`!@```$,@`0`*````2B`!``T```!5(`$`%````&,@`0!B````>"`!`"<`
M``#;(`$`5`````,A`0!?````6"$!`&0```"X(0$`!````!TB`0`6````(B(!
M``X````Y(@$`'````$@B`0`/````92(!`#,```!U(@$`*````*DB`0`%````
MTB(!``4```#8(@$`&P```-XB`0`:````^B(!``X````5(P$`$P```"0C`0`5
M````.",!`#````!.(P$`$0```'\C`0`1````D2,!`!P```"C(P$`*@```,`C
M`0`U````ZR,!`$4````A)`$`$````&<D`0`A````>"0!``4```":)`$`$P``
M`*`D`0`+````M"0!`!(```#`)`$`"@```-,D`0`/````WB0!``T```#N)`$`
M1P```/PD`0`?````1"4!`"4```!D)0$`,P```(HE`0`K````OB4!`#4```#J
M)0$`0@```"`F`0`=````8R8!`%$```"!)@$`$0```-,F`0`Q````Y28!`#L`
M```7)P$`$P```%,G`0!`````9R<!`#@```"H)P$`!0```.$G`0`,````YR<!
M`!$```#T)P$`#0````8H`0`&````%"@!``P````;*`$`!@```"@H`0`7````
M+R@!``@```!'*`$`#````%`H`0`4````72@!``\```!R*`$`$````((H`0`1
M````DR@!``@```"E*`$`!0```*XH`0`1````M"@!``P```#&*`$`$````-,H
M`0`%````Y"@!``T```#J*`$`!@```/@H`0`'````_R@!``T````'*0$`!P``
M`!4I`0`+````'2D!``<````I*0$`!P```#$I`0`)````.2D!`!<```!#*0$`
M)@```%LI`0!/````@BD!``D```#2*0$`"0```-PI`0`*````YBD!`!D```#Q
M*0$`/0````LJ`0`=````22H!``P```!G*@$`)0```'0J`0`?````FBH!`!``
M``"Z*@$`!0```,LJ`0`E````T2H!`"(```#W*@$`$@```!HK`0`3````+2L!
M`"L```!!*P$`.P```&TK`0`@````J2L!`!L```#**P$`"````.8K`0`V````
M[RL!`"$````F+`$`$````$@L`0`(````62P!`!L```!B+`$`'@```'XL`0`O
M````G2P!`%P```#-+`$`+@```"HM`0`,````62T!``8```!F+0$`!````&TM
M`0`/````<BT!``X```""+0$`#@```)$M`0`'````H"T!``X```"H+0$`!P``
M`+<M`0`*````ORT!``T```#*+0$`'P```-@M`0`<````^"T!`"$````5+@$`
M'@```#<N`0`9````5BX!`!X```!P+@$`&P```(\N`0`L````JRX!`"$```#8
M+@$`+@```/HN`0`F````*2\!`"0```!0+P$`'````'4O`0`>````DB\!`!P`
M``"Q+P$`)@```,XO`0`V````]2\!`"L````L,`$`,P```%@P`0`I````C#`!
M`$$```"V,`$`.@```/@P`0`F````,S$!`"L```!:,0$`.````(8Q`0`=````
MOS$!`!4```#=,0$`+P```/,Q`0`@````(S(!`!(```!$,@$`*0```%<R`0`>
M````@3(!`#T```"@,@$`(````-XR`0`2````_S(!`*(````2,P$`%@```+4S
M`0`C````S#,!`"@```#P,P$`*0```!DT`0`Z````0S0!`"@```!^-`$`'P``
M`*<T`0`5````QS0!`"````#=-`$`)0```/XT`0`H````)#4!`"T```!--0$`
M,````'LU`0"2````K#4!`"$````_-@$`%@```&$V`0`<````>#8!`"8```"5
M-@$`*@```+PV`0!!````YS8!`$0````I-P$`#````&XW`0`'````>S<!``<`
M``"#-P$`!@```(LW`0`-````DC<!``L```"@-P$`%````*PW`0`-````P3<!
M`!@```#/-P$`&@```.@W`0`0`````S@!`!T````4.`$`&0```#(X`0!=````
M3#@!`!4```"J.`$`)0```,`X`0`2````YC@!`!,```#Y.`$`$@````TY`0`'
M````(#D!``0````H.0$`$````"TY`0`0````/CD!``P```!/.0$`#@```%PY
M`0`-````:SD!``\```!Y.0$`%````(DY`0`3````GCD!``T```"R.0$`.0``
M`,`Y`0`<````^CD!`"@````7.@$``P```$`Z`0`-````1#H!``8```!2.@$`
M$0```%DZ`0`7````:SH!`!L```"#.@$`#@```)\Z`0`"````KCH!`$D```"Q
M.@$`!0```/LZ`0`%`````3L!`!`````'.P$`#P```!@[`0`$````*#L!``T`
M```M.P$`#@```#L[`0`#````2CL!``X```!..P$`"````%T[`0`/````9CL!
M``@```!V.P$`"@```'\[`0`/````BCL!``<```":.P$`#0```*([`0`0````
ML#L!`!0```#!.P$`#0```-8[`0`9````Y#L!`!H```#^.P$`"P```!D\`0`)
M````)3P!``8````O/`$`%````#8\`0`+````2SP!`!,```!7/`$`$````&L\
M`0`,````?#P!``H```")/`$`$0```)0\`0`7````ICP!`!$```"^/`$`%0``
M`-`\`0`G````YCP!`!D````./0$`"P```"@]`0`-````-#T!`"(```!"/0$`
M*P```&4]`0`7````D3T!``\```"I/0$`-````+D]`0`S````[CT!`!L````B
M/@$`-````#X^`0`*````<SX!`!@```!^/@$`%````)<^`0`2````K#X!`!D`
M``"_/@$`%@```-D^`0`'````\#X!`!````#X/@$`(@````D_`0`<````+#\!
M`!P```!)/P$`#0```&8_`0`'````=#\!``P```!\/P$`)@```(D_`0`*````
ML#\!`!0```"[/P$`"P```-`_`0`'````W#\!`"(```#D/P$`+P````=``0`+
M````-T`!``D```!#0`$`&0```$U``0`+````9T`!`"H```!S0`$`#P```)Y`
M`0`7````KD`!`!<```#&0`$`"0```-Y``0`'````Z$`!`!8```#P0`$`#P``
M``=!`0`M````%T$!`!D```!%00$`%@```%]!`0`.````=D$!`!H```"%00$`
M*````*!!`0`M````R4$!`"X```#W00$`"P```"9"`0`8````,D(!``@```!+
M0@$`#````%1"`0`C````84(!``T```"%0@$`)@```)-"`0`J````ND(!`"``
M``#E0@$`0P````9#`0`(````2D,!`!(```!30P$`'P```&9#`0`$````AD,!
M``@```"+0P$`"P```)1#`0`:````H$,!`"<```"[0P$`$@```.-#`0`@````
M]D,!`"\````71`$`%P```$=$`0`%````7T0!``P```!E1`$`#@```')$`0`.
M````@40!``4```"01`$`!@```)9$`0`.````G40!`$4```"L1`$``P```/)$
M`0`#````]D0!`"L```#Z1`$`!P```"9%`0`$````+D4!``X````S10$`"@``
M`$)%`0`,````344!``H```!:10$`#P```&5%`0`0````=44!`!<```"&10$`
M$0```)Y%`0`3````L$4!`"4```#$10$`#@```.I%`0`1````^44!`!D````+
M1@$`%P```"5&`0`3````/48!`!8```!11@$`.````&A&`0`3````H48!``D`
M``"U1@$`!0```+]&`0`+````Q48!``H```#11@$``@```-Q&`0`%````WT8!
M``T```#E1@$`&P```/-&`0`7````#T<!`!0````G1P$`"0```#Q'`0`=````
M1D<!`"\```!D1P$`#P```)1'`0`6````I$<!`!(```"[1P$`"P```,Y'`0`,
M````VD<!``X```#G1P$`#0```/9'`0`2````!$@!`!D````72`$`'````#%(
M`0`X````3D@!`!@```"'2`$`(````*!(`0`3````P4@!``D```#52`$``P``
M`-](`0`5````XT@!``L```#Y2`$`$P````5)`0`(````&4D!``X````B20$`
M$````#%)`0![````0DD!`!@```"^20$`&````-=)`0`G````\$D!`"D````8
M2@$`+````$)*`0`H````;TH!``X```"82@$`-0```*=*`0`1````W4H!``<`
M``#O2@$`!0```/=*`0`I````_4H!`!@````G2P$`'@```$!+`0`;````7TL!
M`!D```![2P$`&````)5+`0`;````KDL!`!D```#*2P$`$P```.1+`0`'````
M^$L!``@`````3`$`!@````E,`0`&````$$P!`!L````73`$`$````#-,`0`/
M````1$P!`!````!43`$`#P```&5,`0`+````=4P!``\```"!3`$`#````)%,
M`0`/````GDP!``<```"N3`$`!@```+9,`0`*````O4P!`!(```#(3`$`#0``
M`-M,`0`,````Z4P!``X```#V3`$`0P````5-`0`]````24T!``D```"'30$`
M#````)%-`0`H````GDT!``\```#'30$`"````-=-`0`(````X$T!`!,```#I
M30$`"P```/U-`0`>````"4X!`"$````H3@$`(````$I.`0`9````:TX!`!<`
M``"%3@$`)0```)U.`0`7````PTX!`!8```#;3@$`!````/).`0`;````]TX!
M``T````33P$`#````"%/`0`#````+D\!``4````R3P$`"````#A/`0`*````
M04\!``P```!,3P$`"@```%E/`0`@````9$\!`!\```"%3P$`&P```*5/`0`9
M````P4\!``L```#;3P$`&P```.=/`0`+`````U`!`!`````/4`$`"````"!0
M`0`,````*5`!``X````V4`$`!````$50`0`$````2E`!`!,```!/4`$`%```
M`&-0`0`,````>%`!``D```"%4`$`#@```(]0`0`+````GE`!`!L```"J4`$`
M#@```,90`0`/````U5`!`"4```#E4`$`*@````M1`0`'````-E$!`!(````^
M40$`&P```%%1`0`$````;5$!``<```!R40$`"@```'I1`0`2````A5$!``H`
M``"840$`#0```*-1`0`)````L5$!``0```"[40$`"````,!1`0`#````R5$!
M`!@```#-40$`'0```.91`0`0````!%(!``X````54@$`'@```"12`0`:````
M0U(!``H```!>4@$`!````&E2`0`F````;E(!``X```"54@$`?````*12`0`5
M````(5,!`$0````W4P$`!0```'Q3`0`'````@E,!``P```"*4P$`"````)=3
M`0`*````H%,!``8```"K4P$`!P```+)3`0`(````NE,!`!$```##4P$`&0``
M`-53`0`(````[U,!``(```#X4P$`!@```/M3`0`&`````E0!`!0````)5`$`
M&@```!Y4`0`-````.50!`!````!'5`$`&P```%A4`0`%````=%0!``0```!Z
M5`$`#````']4`0`)````C%0!`!````"65`$`"0```*=4`0`)````L50!``0`
M``"[5`$`&@```,!4`0`%````VU0!`!H```#A5`$`"````/Q4`0`&````!54!
M``\````,50$`&0```!Q5`0`.````-E4!``<```!%50$`!P```$U5`0`B````
M554!``4```!X50$`"0```'Y5`0`*````B%4!``X```"350$``@```*)5`0`-
M````I54!`"````"S50$`!@```-15`0`+````VU4!``T```#G50$`#````/55
M`0`)`````E8!``8````,5@$`$@```!-6`0`)````)E8!``<````P5@$`%```
M`#A6`0`=````358!`$(```!K5@$`)0```*Y6`0`E````U%8!``8```#Z5@$`
M"@````%7`0`$````#%<!``D````15P$`"````!M7`0`1````)%<!``D````V
M5P$`!@```$!7`0`-````1U<!``8```!55P$`!````%Q7`0`7````85<!`#D`
M``!Y5P$`/0```+-7`0`Z````\5<!`!X````L6`$`!0```$M8`0`.````45@!
M``0```!@6`$`!@```&58`0`'````;%@!`"$```!T6`$`#0```)98`0`5````
MI%@!``8```"Z6`$`!````,%8`0`1````QE@!``8```#86`$`"@```-]8`0`B
M````ZE@!`"<````-60$`!@```#59`0`5````/%D!``P```!260$`$0```%]9
M`0`$````<5D!``T```!V60$`!P```(19`0`%````C%D!`!T```"260$`!```
M`+!9`0`,````M5D!``X```#"60$`"@```-%9`0`(````W%D!``D```#E60$`
M!0```.]9`0`Z````]5D!`#`````P6@$`-0```&%:`0`I````EUH!`$<```#!
M6@$`.`````E;`0`I````0EL!`#\```!L6P$`+@```*Q;`0`M````VUL!`!\`
M```)7`$`#P```"E<`0`2````.5P!``L```!,7`$`)@```%A<`0`G````?UP!
M`"D```"G7`$`)````-%<`0`F````]EP!`"@````=70$`"````$9=`0`*````
M3UT!``D```!:70$`!P```&1=`0`$````;%T!`!P```!Q70$`-P```(Y=`0`@
M````QET!`"````#G70$`)@````A>`0`-````+UX!`"<````]7@$`&P```&5>
M`0`B````@5X!``P```"D7@$`%@```+%>`0`*````R%X!`!D```#37@$`*0``
M`.U>`0`6````%U\!`!(````N7P$`!P```$%?`0`*````25\!``P```!47P$`
M#P```&%?`0`0````<5\!`$````""7P$`1````,-?`0`\````"&`!`'````!%
M8`$`9@```+9@`0`&````'6$!``H````D80$`!0```"]A`0`.````-6$!``D`
M``!$80$`"@```$YA`0`2````66$!`!,```!L80$`#````(!A`0`&````C6$!
M``8```"480$`"@```)MA`0`.````IF$!``\```"U80$`#@```,5A`0`;````
MU&$!`!\```#P80$`'@```!!B`0`C````+V(!`!$```!38@$`%0```&5B`0`8
M````>V(!`!$```"48@$`$````*9B`0`C````MV(!``\```#;8@$`"0```.MB
M`0`2````]6(!`!T````(8P$`$@```"9C`0`0````.6,!``H```!*8P$`$0``
M`%5C`0`Q````9V,!`"0```"98P$`'````+YC`0`C````VV,!`&H```#_8P$`
M#P```&ID`0`%````>F0!`!````"`9`$`"0```)%D`0`$````FV0!``L```"@
M9`$`(````*QD`0`<````S60!`",```#J9`$`(@````YE`0`&````,64!`!0`
M```X90$`%P```$UE`0`,````964!`"0```!R90$`(P```)=E`0`:````NV4!
M``P```#690$`#P```.-E`0`5````\V4!`"D````)9@$`*@```#-F`0`F````
M7F8!`"<```"%9@$`*0```*UF`0`J````UV8!`!D````"9P$`0@```!QG`0`1
M````7V<!`!(```!Q9P$`$P```(1G`0`4````F&<!``\```"M9P$`%@```+UG
M`0`7````U&<!`!````#L9P$`$0```/UG`0`T````#V@!`!,```!$:`$`$@``
M`%AH`0`U````:V@!`!0```"A:`$`!P```+9H`0`,````OF@!`"L```#+:`$`
M#P```/=H`0`6````!VD!`"`````>:0$`$````#]I`0`4````4&D!`!$```!E
M:0$`*````'=I`0`7````H&D!`!P```"X:0$`$P```-5I`0`+````Z6D!`!0`
M``#U:0$`&@````IJ`0`1````)6H!`!H````W:@$`'@```%)J`0`:````<6H!
M`!,```",:@$`(0```*!J`0`@````PFH!`!4```#C:@$`$0```/EJ`0`7````
M"VL!`!0````C:P$`%P```#AK`0`5````4&L!``D```!F:P$`!@```'!K`0`0
M````=VL!`!D```"(:P$`!````*)K`0`'````IVL!``L```"O:P$`$0```+MK
M`0`&````S6L!``8```#4:P$`!@```-MK`0`%````XFL!``<```#H:P$`!P``
M`/!K`0`%````^&L!`!8```#^:P$`!@```!5L`0`&````'&P!``0````C;`$`
M!````"AL`0`'````+6P!``X````U;`$`#````$1L`0`,````46P!``T```!>
M;`$`"@```&QL`0`.````=VP!``4```"&;`$`*````(QL`0`.````M6P!``P`
M``#$;`$`#P```-%L`0`*````X6P!``@```#L;`$`"0```/5L`0`K````_VP!
M`$\````K;0$`1P```'MM`0!3````PVT!`"X````7;@$`!````$9N`0`(````
M2VX!`"8```!4;@$`$@```'MN`0`/````CFX!``8```">;@$`"@```*5N`0`'
M````L&X!``@```"X;@$`(````,%N`0`)````XFX!`!$```#L;@$`"0```/YN
M`0`4````"&\!``P````=;P$`#0```"IO`0`.````.&\!`!8```!';P$`$0``
M`%YO`0`&````<&\!``,```!W;P$`!@```'MO`0`9````@F\!``<```"<;P$`
M!````*1O`0`+````J6\!``L```"U;P$`!P```,%O`0`%````R6\!``<```#/
M;P$`%@```-=O`0`-````[F\!``T```#\;P$`"@````IP`0`0````%7`!``\`
M```F<`$`$0```#9P`0`7````2'`!``H```!@<`$`$0```&MP`0`$````?7`!
M`!$```""<`$`#P```)1P`0`Z````I'`!`"$```#?<`$`!0````%Q`0`7````
M!W$!``P````?<0$`'@```"QQ`0`.````2W$!`!````!:<0$`"P```&MQ`0!\
M````=W$!``P```#T<0$`"0````%R`0`'````"W(!``H````3<@$`"0```!YR
M`0`.````*'(!`!`````W<@$`%0```$AR`0`;````7G(!`!@```!Z<@$`&@``
M`)-R`0`*````KG(!``D```"Y<@$`"@```,-R`0`.````SG(!``P```#=<@$`
M#P```.IR`0`(````^G(!``8````#<P$`#`````IS`0`<````%W,!``<````T
M<P$`!0```#QS`0`+````0G,!`$<```!.<P$`#0```)9S`0`)````I',!``0`
M``"N<P$``P```+-S`0`,````MW,!`!,```#$<P$`$P```-AS`0`3````[',!
M``8`````=`$`"@````=T`0`"````$G0!``0````5=`$`)0```!IT`0`#````
M0'0!``4```!$=`$`*@```$IT`0`.````=70!``H```"$=`$`!0```(]T`0`$
M````E70!``H```":=`$`#0```*5T`0`?````LW0!``<```#3=`$`(@```-MT
M`0`-````_G0!``8````,=0$`"````!-U`0`(````''4!``0````E=0$`!0``
M`"IU`0!H````,'4!``D```"9=0$`#````*-U`0`0````L'4!``4```#!=0$`
M!@```,=U`0`C````SG4!`"4```#R=0$`"````!AV`0`W````(78!`"(```!9
M=@$`$P```'QV`0`;````D'8!`"\```"L=@$`$````-QV`0`*````[78!`!$`
M``#X=@$`#P````IW`0`/````&G<!``H````J=P$`"0```#5W`0`3````/W<!
M`!L```!3=P$`&````&]W`0`7````B'<!`!<```"@=P$`&0```+AW`0`?````
MTG<!``X```#R=P$`)@````%X`0`F````*'@!``,```!/>`$`!P```%-X`0`(
M````6W@!``<```!D>`$`$````&QX`0`*````?7@!``L```"(>`$`!P```)1X
M`0`3````G'@!``P```"P>`$`#P```+UX`0`.````S7@!``P```#<>`$`#@``
M`.EX`0!1````^'@!``\```!*>0$`$````%IY`0`-````:WD!``\```!Y>0$`
M#P```(EY`0`7````F7D!`!0```"Q>0$`$0```,9Y`0`/````V'D!`"````#H
M>0$`+@````EZ`0`:````.'H!``P```!3>@$`)@```&!Z`0`+````AWH!``T`
M``"3>@$`&@```*%Z`0!*````O'H!`!D````'>P$`!@```"%[`0`:````*'L!
M`"4```!#>P$`!@```&E[`0`&````<'L!`!\```!W>P$`!@```)=[`0`)````
MGGL!`!@```"H>P$`%P```,%[`0`H````V7L!``8````"?`$`#0````E\`0`B
M````%WP!`%<````Z?`$`$P```))\`0`C````IGP!`!,```#*?`$``@```-Y\
M`0`+````X7P!``@```#M?`$`#0```/9\`0`&````!'T!``H````+?0$`!P``
M`!9]`0`4````'GT!``8````S?0$`"````#I]`0`.````0WT!``<```!2?0$`
M"@```%I]`0`+````97T!`#(```!Q?0$`*P```*1]`0`'````T'T!``P```#8
M?0$`#0```.5]`0`,````\WT!``0`````?@$`"0````5^`0`)````#WX!``H`
M```9?@$`!P```"1^`0`)````+'X!`$`````V?@$`#@```'=^`0`'````AGX!
M``H```".?@$`&P```)E^`0`/````M7X!`!4```#%?@$`%0```-M^`0`2````
M\7X!``H````$?P$`%@````]_`0`)````)G\!`!`````P?P$`!P```$%_`0`2
M````27\!``0```!<?P$`!````&%_`0`$````9G\!`"$```!K?P$`!P```(U_
M`0`%````E7\!``P```";?P$`!0```*A_`0`+````KG\!`!0```"Z?P$`$0``
M`,]_`0`:````X7\!`!8```#\?P$`%````!.``0`7````*(`!`!@```!`@`$`
M'````%F``0`9````=H`!``<```"0@`$`!0```)B``0`6````GH`!``,```"U
M@`$`#0```+F``0`,````QX`!``H```#4@`$`"````-^``0`+````Z(`!`!$`
M``#T@`$`"`````:!`0`7````#X$!``L````G@0$`#````#.!`0`,````0($!
M`!\```!-@0$`&@```&V!`0`3````B($!``0```"<@0$`"@```*&!`0`$````
MK($!``T```"Q@0$`#````+^!`0`)````S($!``P```#6@0$`!0```..!`0`)
M````Z8$!``4```#S@0$`!P```/F!`0`%`````8(!``0````'@@$``@````R"
M`0`4````#X(!``T````D@@$`$@```#*"`0`+````18(!`!L```!1@@$`'P``
M`&V"`0`/````C8(!`!0```"=@@$`'@```+*"`0`5````T8(!`#@```#G@@$`
M+````""#`0`2````38,!`"D```!@@P$`,@```(J#`0`*````O8,!`"P```#(
M@P$`+@```/6#`0`S````)(0!`#,```!8A`$`.````(R$`0`/````Q80!`!@`
M``#5A`$`+P```.Z$`0`0````'H4!`!,````OA0$`*@```$.%`0`9````;H4!
M`!P```"(A0$`'P```*6%`0`/````Q84!`!,```#5A0$`%0```.F%`0`4````
M_X4!`!0````4A@$`%````"F&`0`@````/H8!`!(```!?A@$`%````'*&`0`5
M````AX8!`"T```"=A@$`+0```,N&`0`Q````^88!`"X````KAP$`+P```%J'
M`0`L````BH<!`&(```"WAP$`$P```!J(`0`E````+H@!`"0```!4B`$`*0``
M`'F(`0!(````HX@!``T```#LB`$`"````/J(`0`7`````XD!``@````;B0$`
M)````"2)`0`2````28D!``P```!<B0$`#@```&F)`0`W````>(D!`"L```"P
MB0$`$@```-R)`0`A````[XD!`!H````1B@$`"0```"R*`0!%````-HH!`$$`
M``!\B@$`#P```+Z*`0`$````SHH!`!,```#3B@$`%````.>*`0`.````_(H!
M``8````+BP$`$P```!*+`0`8````)HL!``8````_BP$`"0```$:+`0`*````
M4(L!``L```!;BP$`"0```&>+`0`-````<8L!``P```!_BP$`#P```(R+`0`7
M````G(L!`!0```"TBP$`$````,F+`0`6````VHL!``<```#QBP$`#@```/F+
M`0`A````"(P!``4````JC`$`!P```#",`0`;````.(P!`"H```!4C`$`"```
M`'^,`0`&````B(P!`!0```"/C`$`$0```*2,`0!$````MHP!`#P```#[C`$`
M#@```#B-`0`X````1XT!``(```"`C0$``@```(.-`0`&````AHT!``X```"-
MC0$`!0```)R-`0`'````HHT!``X```"JC0$`!@```+F-`0`H````P(T!``P`
M``#IC0$`#````/:-`0`<`````XX!`",````@C@$`!````$2.`0`I````28X!
M`#(```!SC@$`%P```*:.`0`?````OHX!`#,```#>C@$`7````!*/`0`,````
M;X\!`!0```!\CP$`/@```)&/`0`-````T(\!`!\```#>CP$`$````/Z/`0`4
M````#Y`!``<````DD`$`#@```"R0`0`,````.Y`!``P```!(D`$`$P```%60
M`0`*````:9`!`!T```!TD`$`&0```)*0`0`%````K)`!`!$```"RD`$`$P``
M`,20`0`-````V)`!``\```#FD`$`$0```/:0`0`D````")$!`!(````MD0$`
M%0```$"1`0`3````5I$!`!(```!JD0$`"P```'V1`0`T````B9$!``L```"^
MD0$`%````,J1`0`^````WY$!``X````>D@$`$P```"V2`0`T````09(!`#$`
M``!VD@$`$@```*B2`0`0````NY(!`!@```#,D@$`&0```.62`0`C````_Y(!
M`"(````CDP$`)P```$:3`0!6````;I,!`$T```#%DP$`N0```!.4`0`(````
MS90!``T```#6E`$`!P```.24`0`*````[)0!``<```#WE`$`#P```/^4`0`&
M````#Y4!``L````6E0$`!````"*5`0`<````)Y4!``T```!$E0$`)P```%*5
M`0`;````>I4!``P```"6E0$`&@```*.5`0`'````OI4!``T```#&E0$`(@``
M`-25`0`A````]Y4!``@````9E@$`!0```"*6`0`?````*)8!``8```!(E@$`
M$````$^6`0`(````8)8!``<```!IE@$`#0```'&6`0`*````?Y8!`!(```"*
ME@$`(0```)V6`0`+````OY8!`!L```#+E@$`&````.>6`0`(`````)<!`!X`
M```)EP$`$@```"B7`0`L````.Y<!`!H```!HEP$`"0```(.7`0`*````C9<!
M`!4```"8EP$`!0```*Z7`0`4````M)<!``0```#)EP$`$````,Z7`0`&````
MWY<!``<```#FEP$`'@```.Z7`0`H````#9@!``H````VF`$`'````$&8`0`1
M````7I@!``L```!PF`$`&@```'R8`0`L````EY@!``@```#$F`$`%````,V8
M`0`L````XI@!`"<````/F0$`*P```#>9`0`J````8YD!``0```".F0$`!```
M`).9`0`+````F)D!``4```"DF0$`!@```*J9`0`(````L9D!``8```"ZF0$`
M,0```,&9`0`<````\YD!``H````0F@$`H@```!N:`0`;````OIH!`#0```#:
MF@$`-`````^;`0`@````1)L!`"D```!EFP$`)P```(^;`0`@````MYL!`$$`
M``#8FP$`&@```!J<`0`H````-9P!`!H```!>G`$`=@```'F<`0!Y````\)P!
M`!P!``!JG0$`*````(>>`0`=````L)X!`"D```#.G@$`'0```/B>`0!0````
M%I\!`"X```!GGP$`-@```):?`0`L````S9\!`#$```#ZGP$`+@```"R@`0`B
M````6Z`!``8```!^H`$`"````(6@`0`%````CJ`!``@```"4H`$`&0```)V@
M`0`9````MZ`!`"H```#1H`$`$````/R@`0`K````#:$!`",````YH0$`&0``
M`%VA`0`A````=Z$!`"X```"9H0$`-````,BA`0`(````_:$!`!<````&H@$`
M"@```!ZB`0`'````*:(!`"$````QH@$`$````%.B`0`-````9*(!`!````!R
MH@$`!0```(.B`0`.````B:(!``@```"8H@$`"P```*&B`0`4````K:(!``<`
M``#"H@$`$P```,JB`0`(````WJ(!`#8```#GH@$`-P```!ZC`0`+````5J,!
M``D```!BHP$`"@```&RC`0`4````=Z,!``\```",HP$`+P```)RC`0`R````
MS*,!``L```#_HP$`#@````ND`0`-````&J0!``\````HI`$`%@```#BD`0`.
M````3Z0!`#X```!>I`$`)P```)VD`0`F````Q:0!`"0```#LI`$`!0```!&E
M`0`%````%Z4!``4````=I0$`)P```".E`0`?````2Z4!`!8```!KI0$`"P``
M`(*E`0`7````CJ4!``\```"FI0$`!````+:E`0`*````NZ4!``D```#&I0$`
M"P```-"E`0`-````W*4!``P```#JI0$`#@```/>E`0`%````!J8!``0````,
MI@$`#0```!&F`0`R````'Z8!`$4```!2I@$`$P```)BF`0`+````K*8!``X`
M``"XI@$`#@```,>F`0`)````UJ8!``@```#@I@$`$````.FF`0`5````^J8!
M`!,````0IP$`%P```"2G`0`'````/*<!`!X```!$IP$`%0```&.G`0`4````
M>:<!`!0```".IP$`!@```*.G`0`+````JJ<!``<```"VIP$`(P```+ZG`0`6
M````XJ<!``\```#YIP$`#@````FH`0`J````&*@!``8```!#J`$`#````$JH
M`0`8````5Z@!``T```!PJ`$`$0```'ZH`0`+````D*@!`#8```"<J`$`#0``
M`-.H`0`*````X:@!`"(```#LJ`$`"P````^I`0`/````&ZD!`!`````KJ0$`
M+@```#RI`0`Z````:ZD!``X```"FJ0$`#0```+6I`0`%````PZD!``L```#)
MJ0$`#````-6I`0`-````XJD!``T```#PJ0$`#@```/ZI`0`-````#:H!`"``
M```;J@$`)P```#RJ`0`K````9*H!``@```"0J@$`"@```)FJ`0`&````I*H!
M`!(```"KJ@$`#@```+ZJ`0`7````S:H!`#(```#EJ@$`%@```!BK`0`<````
M+ZL!`"4```!,JP$`,````'*K`0`Q````HZL!`"T```#5JP$`#@````.L`0`4
M````$JP!``4````GK`$`#@```"VL`0`3````/*P!`!H```!0K`$`$@```&NL
M`0`'````?JP!``8```"&K`$`$P```(VL`0`?````H:P!`!0```#!K`$`$0``
M`-:L`0!+````Z*P!`!,````TK0$`!P```$BM`0`4````4*T!`!@```!EK0$`
M!P```'ZM`0`%````AJT!``P```",K0$`#````)FM`0`2````IJT!``0```"Y
MK0$`!P```+ZM`0`*````QJT!``L```#1K0$`#````-VM`0`.````ZJT!``X`
M``#YK0$`!0````BN`0`%````#JX!`"X````4K@$`)@```$.N`0`C````:JX!
M``,```".K@$`$@```)*N`0`&````I:X!`!X```"LK@$`%@```,NN`0`8````
MXJX!``X```#[K@$`-P````JO`0`.````0J\!`!<```!1KP$`00```&FO`0`T
M````JZ\!`"4```#@KP$`%0````:P`0`Q````'+`!`!,```!.L`$`&P```&*P
M`0`J````?K`!`%$```"IL`$`60```/NP`0!0````5;$!`+\```"FL0$`)0``
M`&:R`0`-````C+(!`!\```":L@$``P```+JR`0`'````OK(!``@```#&L@$`
M`@```,^R`0`0````TK(!``@```#CL@$`#````.RR`0`5````^;(!``L````/
MLP$`&0```!NS`0`@````-;,!`!(```!6LP$`!0```&FS`0`*````;[,!`!4`
M``!ZLP$`$@```)"S`0`,````H[,!``0```"PLP$`"0```+6S`0`'````O[,!
M`#(```#'LP$`"@```/JS`0`*````!;0!`!4````0M`$`#````":T`0`/````
M,[0!``L```!#M`$`!P```$^T`0`6````5[0!`%(```!NM`$`.@```,&T`0`@
M````_+0!``\````=M0$`%P```"VU`0`D````1;4!`#D```!JM0$`$@```*2U
M`0`'````M[4!``8```"_M0$`"0```,:U`0`.````T+4!``X```#?M0$`#@``
M`.ZU`0`$````_;4!``8````"M@$`%@````FV`0`,````(+8!``T````MM@$`
M#@```#NV`0`5````2K8!`!(```!@M@$`#P```'.V`0`4````@[8!`!0```"8
MM@$`0P```*VV`0`*````\;8!`!L```#\M@$`-0```!BW`0`1````3K<!`!``
M``!@MP$`"P```'&W`0!I````?;<!`!H```#GMP$`%P````*X`0`H````&K@!
M`"<```!#N`$`&P```&NX`0`:````A[@!`!<```"BN`$`&P```+JX`0`9````
MUK@!`!\```#PN`$`%P```!"Y`0`<````*+D!`!<```!%N0$`#````%VY`0`3
M````:KD!``@```!^N0$`'P```(>Y`0`O````I[D!``<```#7N0$`"````-^Y
M`0`0````Z+D!`!$```#YN0$`"0````NZ`0`5````%;H!``T````KN@$`!@``
M`#FZ`0`=````0+H!`",```!>N@$`!P```(*Z`0`-````BKH!`!,```"8N@$`
M"````*RZ`0`#````M;H!`$8```"YN@$`0P````"[`0`R````1+L!`#\```!W
MNP$`-P```+>[`0!7````[[L!``4```!'O`$`'P```$V\`0`O````;;P!``H`
M``"=O`$`#0```*B\`0`2````MKP!`"D```#)O`$`"````/.\`0`-````_+P!
M`"T````*O0$`<````#B]`0`_````J;T!`#D```#IO0$`1@```".^`0`$````
M:KX!`!````!OO@$`$````("^`0`,````D;X!`!0```">O@$`'0```+.^`0`<
M````T;X!`!$```#NO@$`/0````"_`0!/````/K\!`"4```".OP$`(````+2_
M`0`<````U;\!``L```#ROP$`)P```/Z_`0`:````)L`!`!\```!!P`$`'0``
M`&'``0`H````?\`!``\```"HP`$`)0```+C``0`@````WL`!`"0```#_P`$`
M)````"3!`0`@````2<$!`"4```!JP0$`"P```)#!`0`'````G,$!``T```"D
MP0$`#````++!`0`7````O\$!``4```#7P0$`!@```-W!`0`Y````Y,$!``4`
M```>P@$`#````"3"`0`'````,<(!``D````YP@$`$P```$/"`0`&````5\(!
M``D```!>P@$`!````&C"`0`0````;<(!``@```!^P@$`"````(?"`0`$````
MD,(!``L```"5P@$`#````*'"`0`2````KL(!`!$```#!P@$`#````-/"`0`:
M````X,(!``\```#[P@$`!P````O#`0`-````$\,!``\````APP$`#````#'#
M`0`4````/L,!`!0```!3PP$`#P```&C#`0`.````>,,!`!(```"'PP$`%```
M`)K#`0`.````K\,!``P```"^PP$`&P```,O#`0`L````Y\,!`!,````4Q`$`
M'````"C$`0`H````1<0!``8```!NQ`$`!P```'7$`0`3````?<0!``4```"1
MQ`$`!````)?$`0`,````G,0!`!<```"IQ`$`$@```,'$`0`I````U,0!``L`
M``#^Q`$`#0````K%`0`4````&,4!`"\````MQ0$`"@```%W%`0`,````:,4!
M``D```!UQ0$`!@```'_%`0`)````AL4!``@```"0Q0$`"0```)G%`0`%````
MH\4!``H```"IQ0$`$0```+3%`0`*````QL4!`!````#1Q0$`$````.+%`0`+
M````\\4!``8```#_Q0$`#@````;&`0`.````%<8!``T````DQ@$`"P```#+&
M`0`0````/L8!`!T```!/Q@$`$0```&W&`0`+````?\8!``(```"+Q@$`"```
M`([&`0`<````E\8!``<```"TQ@$`#0```+S&`0`&````RL8!`&0```#1Q@$`
M%@```#;'`0`)````3<<!``<```!7QP$`)@```%_'`0`X````AL<!`!H```"_
MQP$`*@```-K'`0`[````!<@!`"@```!!R`$`-````&K(`0`9````G\@!`!4`
M``"YR`$`!0```,_(`0`+````U<@!``<```#AR`$`"````.G(`0`'````\L@!
M``4```#ZR`$`!P````#)`0`.````",D!``D````7R0$`!@```"')`0`(````
M*,D!``L````QR0$`!P```#W)`0`(````1<D!``<```!.R0$`%@```%;)`0`)
M````;<D!``8```!WR0$`&0```'[)`0`:````F,D!`"````"SR0$`"P```-3)
M`0`0````X,D!`!P```#QR0$`%`````[*`0`'````(\H!`!$````KR@$`"```
M`#W*`0`.````1LH!``@```!5R@$`!0```%[*`0`0````9,H!`!````!UR@$`
M!@```(;*`0`9````C<H!``H```"GR@$`'````++*`0`'````S\H!``4```#7
MR@$`!0```-W*`0`0````X\H!`!0```#TR@$`"P````G+`0`-````%<L!`"@`
M```CRP$`&````$S+`0`7````9<L!``L```!]RP$`&@```(G+`0`4````I,L!
M`"\```"YRP$`!````.G+`0`)````[LL!``H```#XRP$`!P````/,`0`"````
M"\P!``X````.S`$`"````!W,`0`C````)LP!`#$```!*S`$`'P```'S,`0`X
M````G,P!`'@```#5S`$`)@```$[-`0`;````=<T!`#$```"1S0$`,0```,/-
M`0`G````]<T!`"(````=S@$`(````$#.`0!D````8<X!`!T```#&S@$`%```
M`.3.`0`<````^<X!`%4````6SP$`.````&S/`0`M````I<\!`#,```#3SP$`
M2P````?0`0!*````4]`!`%L```">T`$`*````/K0`0`L````(]$!`#@```!0
MT0$`)0```(G1`0`A````K]$!`"@```#1T0$`+````/K1`0`F````)](!`!L`
M``!.T@$`'@```&K2`0!U````B=(!`#X```#_T@$`0@```#[3`0`]````@=,!
M`#T```"_TP$`*0```/W3`0`I````)]0!`#$```!1U`$`/@```(/4`0`O````
MPM0!`*D!``#RU`$`(P```)S6`0!B````P-8!`$\````CUP$`%P```'/7`0!(
M````B]<!`#8```#4UP$`/@````O8`0`P````2M@!`"````![V`$`/P```)S8
M`0`T````W-@!`"P````1V0$`'0```#[9`0`>````7-D!`"H```![V0$`A0``
M`*;9`0`P````+-H!`"4```!=V@$`00```(/:`0!;````Q=H!`$D````AVP$`
M,0```&O;`0`T````G=L!`#P```#2VP$`.`````_<`0`=````2-P!`!@```!F
MW`$`IP```'_<`0`K````)]T!`"$```!3W0$`'P```'7=`0`\````E=T!`"0`
M``#2W0$`*````/?=`0`K````(-X!`"(```!,W@$`)@```&_>`0`C````EMX!
M`"4```"ZW@$`)0```.#>`0`I````!M\!`"<````PWP$`%P```%C?`0`I````
M<-\!`"````":WP$`,@```+O?`0`<````[M\!`"X````+X`$`.@```#K@`0`=
M````=>`!`!$```"3X`$`,P```*7@`0`E````V>`!`#@```#_X`$`)P```#CA
M`0`@````8.$!`#P```"!X0$`)@```+[A`0`?````Y>$!`#`````%X@$`:0``
M`#;B`0`N````H.(!`#$```#/X@$`00````'C`0`^````0^,!`#,```""XP$`
M)0```+;C`0`]````W.,!`&4````:Y`$`30```(#D`0!3````SN0!`%<````B
MY0$`50```'KE`0!&````T.4!`"H````7Y@$`+P```$+F`0!5````<N8!`"``
M``#(Y@$`+@```.GF`0`K````&.<!`#````!$YP$`*@```'7G`0`^````H.<!
M`%0```#?YP$`4@```#3H`0!:````A^@!`#(```#BZ`$`*P```!7I`0!(````
M0>D!`$H```"*Z0$`*@```-7I`0`F`````.H!`"P````GZ@$`3@```%3J`0`R
M````H^H!`#````#6Z@$`'0````?K`0`C````)>L!`"\```!)ZP$`+````'GK
M`0`M````INL!`'$```#4ZP$`9@```$;L`0!O````K>P!`+,````=[0$`%P``
M`-'M`0`E````Z>T!`#(````/[@$`*0```$+N`0`^````;.X!`"(```"K[@$`
M4@```,[N`0`E````(>\!``L```!'[P$`L0```%/O`0`[````!?`!`"<```!!
M\`$`3@```&GP`0!'````N/`!`&(`````\0$`20```&/Q`0!5````K?$!`$``
M```#\@$`+P```$3R`0`R````=/(!`"L```"G\@$`*0```-/R`0`/````_?(!
M`$4````-\P$`(0```%/S`0`P````=?,!`"T```"F\P$`)0```-3S`0`<````
M^O,!`#$````7]`$`,0```$GT`0`.````>_0!``L```"*]`$`!P```);T`0`'
M````GO0!``0```"F]`$`#0```*OT`0`+````N?0!``X```#%]`$`"P```-3T
M`0`%````X/0!`!````#F]`$``@```/?T`0`*````^O0!`%8````%]0$`60``
M`%SU`0!.````MO4!``4````%]@$`$@````OV`0`$````'O8!``<````C]@$`
M"````"OV`0`%````-/8!``,````Z]@$`$````#[V`0`7````3_8!``P```!G
M]@$`#````'3V`0`-````@?8!`!,```"/]@$`#0```*/V`0`"````L?8!``<`
M``"T]@$`!@```+SV`0`4````P_8!``P```#8]@$`&````.7V`0`&````_O8!
M`!(````%]P$`#````!CW`0`#````)?<!`"H````I]P$`!````%3W`0`&````
M6?<!``<```!@]P$`'P```&CW`0`U````B/<!`"X```"^]P$`+P```.WW`0`7
M````'?@!`"(````U^`$`)0```%CX`0`@````?O@!`!L```"?^`$`&````+OX
M`0`D````U/@!`!\```#Y^`$`&@```!GY`0`A````-/D!`"````!6^0$`&@``
M`'?Y`0`R````DOD!`!H```#%^0$`+P```.#Y`0`K````$/H!`!\````\^@$`
M(P```%SZ`0`?````@/H!`!H```"@^@$`(0```+OZ`0`E````W?H!`"8````#
M^P$`)0```"K[`0`D````4/L!`!@```!U^P$`'0```([[`0`D````K/L!`!@`
M``#1^P$`(@```.K[`0`L````#?P!`"\````Z_`$`%0```&K\`0`E````@/P!
M`#P```"F_`$`'P```./\`0`C`````_T!`!\````G_0$`(````$?]`0`:````
M:/T!`!@```"#_0$`&````)S]`0`F````M?T!`!X```#<_0$`*0```/O]`0`>
M````)?X!`#$```!$_@$`"@```';^`0`3````@?X!``@```"5_@$`"0```)[^
M`0`6````J/X!``P```"__@$`%P```,S^`0`O````Y/X!`#@````4_P$`-P``
M`$W_`0`Q````A?\!`"0```"W_P$`!P```-S_`0`?````Y/\!``\````$``(`
M%````!0``@`.````*0`"``T````X``(`)````$8``@`%````:P`"``<```!Q
M``(`#````'D``@`[````A@`"``\```#"``(`$0```-(``@`B````Y``"`"4`
M```'`0(`&@```"T!`@`=````2`$"`!H```!F`0(`$0```($!`@`'````DP$"
M`,<```";`0(`!@```&,"`@`+````:@("`!H```!V`@(`%0```)$"`@`&````
MIP("``D```"N`@(`&````+@"`@`+````T0("``T```#=`@(`%P```.L"`@`&
M`````P,"`#,````*`P(`$P```#X#`@`3````4@,"``<```!F`P(`#P```&X#
M`@`1````?@,"`!X```"0`P(`!P```*\#`@`9````MP,"`#(```#1`P(`!```
M``0$`@!&````"00"`"$```!0!`(`$P```'($`@`,````A@0"`!$```"3!`(`
M,@```*4$`@`6````V`0"``@```#O!`(`'0```/@$`@`)````%@4"``H````@
M!0(`%````"L%`@`*````0`4"`!T```!+!0(`"````&D%`@`?````<@4"``@`
M``"2!0(`&@```)L%`@`G````M@4"``8```#>!0(`%0```.4%`@`'````^P4"
M``@````#!@(`"0````P&`@`_````%@8"``<```!6!@(`#P```%X&`@`.````
M;@8"`!````!]!@(`"0```(X&`@`)````F`8"``@```"B!@(`$P```*L&`@`$
M````OP8"``<```#$!@(`$@```,P&`@`F````WP8"``T````&!P(`&0```!0'
M`@`8````+@<"``L```!'!P(`#@```%,'`@`9````8@<"``H```!\!P(`)```
M`(<'`@`A````K`<"``H```#.!P(`$P```-D'`@`G````[0<"``D````5"`(`
M#P```!\(`@`7````+P@"`!0```!'"`(`*````%P(`@`/````A0@"`"````"5
M"`(`#0```+8(`@`4````Q`@"``T```#9"`(`%````.<(`@`4````_`@"``H`
M```1"0(`#````!P)`@`7````*0D"``0```!!"0(`*@```$8)`@`,````<0D"
M`!$```!^"0(`!P```)`)`@`"````F`D"`!````";"0(`&````*P)`@`#````
MQ0D"``@```#)"0(`!@```-()`@`'````V0D"``T```#A"0(`"P```.\)`@`4
M````^PD"`!4````0"@(`#@```"8*`@`O````-0H"`"````!E"@(`'````(8*
M`@!7````HPH"`%H```#["@(`/P```%8+`@`V````E@L"`'X```#-"P(`%0``
M`$P,`@`,````8@P"`#$```!O#`(`"0```*$,`@`%````JPP"`!(```"Q#`(`
M/P```,0,`@`2````!`T"``H````7#0(`!@```"(-`@`$````*0T"``0````N
M#0(`"@```#,-`@`3````/@T"``4```!2#0(`!@```%@-`@`&````7PT"``@`
M``!F#0(`!````&\-`@`,````=`T"``H```"!#0(`.0```(P-`@`N````Q@T"
M`"D```#U#0(`!0```!\.`@`8````)0X"`!D````^#@(`'P```%@.`@`=````
M>`X"`!$```"6#@(``@```*@.`@`$````JPX"``H```"P#@(`!@```+L.`@`%
M````P@X"``,```#(#@(`#````,P.`@`[````V0X"`$\````5#P(`-0```&4/
M`@`G````FP\"`"$```###P(`)````.4/`@!%````"A`"`"8```!0$`(`,@``
M`'<0`@`S````JA`"`!H```#>$`(`'0```/D0`@!X````%Q$"`#0```"0$0(`
M(0```,41`@!6````YQ$"`"@````^$@(`4P```&<2`@`Z````NQ("`$(```#V
M$@(`&0```#D3`@`7````4Q,"`"4```!K$P(`&0```)$3`@`J````JQ,"`"L`
M``#6$P(`<@````(4`@`@````=10"`#4```"6%`(`(0```,P4`@!%````[A0"
M`"8````T%0(`,````%L5`@!+````C!4"`$X```#8%0(`)P```"<6`@`I````
M3Q8"`"$```!Y%@(`*````)L6`@`K````Q!8"`!T```#P%@(`*0````X7`@`F
M````.!<"`"4```!?%P(`*````(47`@`H````KA<"`"(```#7%P(`.@```/H7
M`@`K````-1@"`"D```!A&`(`(@```(L8`@`]````KA@"`$$```#L&`(`*```
M`"X9`@`L````5QD"`#````"$&0(`$@```+49`@`3````R!D"`!````#<&0(`
M>0```.T9`@`)````9QH"`!P```!Q&@(`$````(X:`@`/````GQH"`"L```"O
M&@(`)P```-L:`@`.`````QL"`$L````2&P(`H0```%X;`@!S`````!P"`'P`
M``!T'`(`0````/$<`@`K````,AT"`%0```!>'0(`%P```+,=`@`J````RQT"
M`#0```#V'0(`)P```"L>`@`6````4QX"``\```!J'@(`KP```'H>`@`7````
M*A\"`"@```!"'P(`'P```&L?`@!`````BQ\"`!\```#,'P(`'````.P?`@!1
M````"2`"`!H```!;(`(`%````'8@`@`/````BR`"``H```";(`(`!0```*8@
M`@`&````K"`"``@```"S(`(`$````+P@`@`2````S2`"``P```#@(`(`$```
M`.T@`@`1````_B`"`!,````0(0(`'0```"0A`@`@````0B$"``\```!C(0(`
M#P```',A`@`$````@R$"``H```"((0(`!````),A`@`#````F"$"``<```"<
M(0(`"P```*0A`@`(````L"$"``<```"Y(0(`!0```,$A`@`)````QR$"`!0`
M``#1(0(`!@```.8A`@`'````[2$"``@```#U(0(`#P```/XA`@`/````#B("
M``P````>(@(`"````"LB`@`,````-"("``8```!!(@(`"0```$@B`@`+````
M4B("``\```!>(@(`!@```&XB`@`'````=2("``T```!](@(`!@```(LB`@`4
M````DB("``<```"G(@(``P```*\B`@`)````LR("``8```"](@(`#````,0B
M`@`*````T2("``P```#<(@(`$0```.DB`@`*````^R("``4````&(P(`"```
M``PC`@`$````%2,"`!D````:(P(`$0```#0C`@`*````1B,"`!@```!1(P(`
M$P```&HC`@`<````?B,"`!$```";(P(`!````*TC`@`/````LB,"``<```#"
M(P(`!````,HC`@`$````SR,"`!D```#4(P(`!P```.XC`@`"````]B,"`!$`
M``#Y(P(`"0````LD`@`2````%20"`!<````H)`(``P```$`D`@`&````1"0"
M``P```!+)`(`)P```%@D`@`$````@"0"``0```"%)`(`#P```(HD`@`3````
MFB0"``<```"N)`(``@```+8D`@`'````N20"`!$```#!)`(`!@```-,D`@`+
M````VB0"`!@```#F)`(`!@```/\D`@`3````!B4"`!`````:)0(`$@```"LE
M`@`.````/B4"``\```!-)0(`!@```%TE`@`,````9"4"``D```!Q)0(`$0``
M`'LE`@`B````C24"``<```"P)0(`"P```+@E`@`%````Q"4"``(```#*)0(`
M#@```,TE`@`.````W"4"`&$!``#K)0(`"@```$TG`@`*````6"<"``H```!C
M)P(`"@```&XG`@`4````>2<"`!,```".)P(`#P```*(G`@`%````LB<"``D`
M``"X)P(`"0```,(G`@`*````S"<"``,```#7)P(`%````-LG`@`<````\"<"
M`"P````-*`(`*P```#HH`@`A````9B@"`"T```"(*`(`'````+8H`@`!````
MTR@"`#,```#5*`(`"P````DI`@`(````%2D"`"P````>*0(`%0```$LI`@!)
M````82D"`"(```"K*0(`10```,XI`@`>````%"H"`!L````S*@(`%````$\J
M`@`3````9"H"``L```!X*@(`*````(0J`@`,````K2H"`!4```"Z*@(`&P``
M`-`J`@`A````["H"`#,````.*P(`"@```$(K`@`>````32L"`"<```!L*P(`
M&0```)0K`@`>````KBL"`!P```#-*P(`*0```.HK`@`K````%"P"`"H```!`
M+`(`)@```&LL`@"#````DBP"`!8````6+0(`!P```"TM`@`1````-2T"`",`
M``!'+0(`/@```&LM`@`5````JBT"`"0```#`+0(`/````.4M`@`Y````(BX"
M`$0```!<+@(`#@```*$N`@`*````L"X"``\```"[+@(`$0```,LN`@`>````
MW2X"`)H```#\+@(`0P```)<O`@!(````VR\"``8````D,`(`#0```"LP`@"-
M````.3`"`(0```#',`(`+0```$PQ`@`>````>C$"``T```"9,0(`%0```*<Q
M`@`9````O3$"``\```#7,0(`%````.<Q`@!(````_#$"`"$```!%,@(`1```
M`&<R`@`=````K#("``P```#*,@(`#0```-<R`@`0````Y3("`!````#V,@(`
M!@````<S`@`,````#C,"``P````;,P(`!@```"@S`@`\````+S,"`!X```!L
M,P(`.0```(LS`@`W````Q3,"`#D```#],P(`3````#<T`@!K````A#0"`&<`
M``#P-`(`<0```%@U`@!M````RC4"`#P````X-@(`$@```'4V`@`3````B#8"
M``P```"<-@(`$0```*DV`@`2````NS8"``4```#.-@(``@```-0V`@`K````
MUS8"`!(````#-P(`"@```!8W`@`)````(3<"``H````K-P(`/0```#8W`@`5
M````=#<"``D```"*-P(`"P```)0W`@`S````H#<"`"T```#4-P(`&0````(X
M`@`&````'#@"`"$````C.`(`)````$4X`@`)````:C@"``L```!T.`(`!P``
M`(`X`@`B````B#@"`!4```"K.`(`(@```,$X`@`1````Y#@"`!8```#V.`(`
M&@````TY`@`=````*#D"`"H```!&.0(`&P```'$Y`@`4````C3D"`!(```"B
M.0(`$0```+4Y`@`+````QSD"`"X```#3.0(`&0````(Z`@`<````'#H"`!T`
M```Y.@(`&0```%<Z`@`9````<3H"`!\```"+.@(`90```*LZ`@!"````$3L"
M`#````!4.P(`B@```(4[`@`>````$#P"`!P````O/`(`$0```$P\`@`H````
M7CP"`!P```"'/`(`*````*0\`@`#````S3P"``H```#1/`(`#````-P\`@!^
M````Z3P"`((```!H/0(`/````.L]`@`.````*#X"``H````W/@(`"P```$(^
M`@`'````3CX"``<```!6/@(`!0```%X^`@`*````9#X"``D```!O/@(`"P``
M`'D^`@`=````A3X"``X```"C/@(`$@```+(^`@`@````Q3X"`%$```#F/@(`
M4P```#@_`@!C````C#\"`%T```#P/P(`4@```$Y``@`A````H4`"`#P```##
M0`(`&P````!!`@`S````'$$"``L```!000(`'P```%Q!`@`2````?$$"`!X`
M``"/00(`#P```*Y!`@`3````OD$"`!(```#200(`*0```.5!`@`&````#T("
M`"(````60@(`#P```#E"`@!<````24("`"(```"F0@(`&````,E"`@`W````
MXD("`#0````:0P(`!P```$]#`@`&````5T,"``@```!>0P(`*````&=#`@`&
M````D$,"``P```"70P(`%````*1#`@`*````N4,"`!(```#$0P(`"@```-=#
M`@`4````XD,"`!,```#W0P(`&`````M$`@`<````)$0"`#4```!!1`(`30``
M`'=$`@`M````Q40"``H```#S1`(`$0```/Y$`@`'````$$4"`!,````810(`
M'````"Q%`@`:````244"`#$```!D10(`-0```)9%`@!`````S$4"`!\````-
M1@(`/0```"U&`@`^````:T8"`#T```"J1@(`.@```.A&`@`N````(T<"`#$`
M``!21P(`/0```(1'`@`]````PD<"`%0`````2`(`40```%5(`@`)````IT@"
M``P```"Q2`(`$@```+Y(`@`,````T4@"``@```#>2`(`!0```.=(`@`'````
M[4@"``<```#U2`(`#````/U(`@`:````"DD"``T````E20(`20```#-)`@`7
M````?4D"`!````"520(`,P```*9)`@`-````VDD"`'(```#H20(`/````%M*
M`@`)````F$H"`!T```"B2@(`%````,!*`@`Y````U4H"``L````/2P(`*0``
M`!M+`@`M````14L"`#0```!S2P(`.0```*A+`@`*````XDL"``X```#M2P(`
M#0```/Q+`@`)````"DP"``H````43`(`"````!],`@`T````*$P"`$@```!=
M3`(`,P```*9,`@!>````VDP"`#(````Y30(`-@```&Q-`@`R````HTT"`$4`
M``#630(`/@```!Q.`@`R````6TX"`$8```".3@(`+@```-5.`@`[````!$\"
M`$(```!`3P(`,@```(-/`@`X````MD\"`#H```#O3P(`)0```"I0`@`H````
M4%`"`#D```!Y4`(`.@```+-0`@`Y````[E`"`',````H40(`(@```)Q1`@`;
M````OU$"``P```#;40(`#````.A1`@`@````]5$"``X````64@(`#0```"52
M`@`6````,U("`!D```!*4@(`!@```&12`@`+````:U("`!X```!W4@(`)@``
M`)92`@`H````O5("`"D```#F4@(`$@```!!3`@`'````(U,"``<````K4P(`
M$P```#-3`@`)````1U,"``@```!14P(`-0```%I3`@`+````D%,"``,```"<
M4P(`$````*!3`@`'````L5,"``8```"Y4P(`/0```,!3`@`%````_E,"``<`
M```$5`(`!@````Q4`@`+````$U0"``H````?5`(`+0```"I4`@`6````6%0"
M`!(```!O5`(`7@```()4`@`*````X50"``@```#L5`(`!P```/54`@`0````
M_50"``4````.50(`#P```!15`@`'````)%4"`!,````L50(`"0```$!5`@!#
M````2E4"``@```".50(`!````)=5`@`-````G%4"``@```"J50(`&@```+-5
M`@`1````SE4"``@```#@50(`"@```.E5`@`,````]%4"``<````!5@(`%0``
M``E6`@!1````'U8"``,```!Q5@(`+````'56`@`3````HE8"`!````"V5@(`
M*0```,=6`@`&````\58"``<```#X5@(`"0````!7`@`'````"E<"`"<````2
M5P(`*````#I7`@!;````8U<"`$````"_5P(`'@````!8`@`[````'U@"`"H`
M``!;6`(`)````(98`@`&````JU@"``4```"R6`(`%@```+A8`@`:````SU@"
M`#L```#J6`(`(0```"99`@`_````2%D"`#L```"(60(`(P```,19`@`B````
MZ%D"`%<````+6@(`+````&-:`@`2````D%H"``H```"C6@(`"P```*Y:`@`7
M````NEH"``\```#26@(``@```.):`@`-````Y5H"`!(```#S6@(`$@````9;
M`@`2````&5L"`!,````L6P(`#0```$!;`@`3````3EL"``4```!B6P(`&0``
M`&A;`@`:````@EL"`!<```"=6P(`&0```+5;`@`D````SUL"`%@```#T6P(`
M!````$U<`@`%````4EP"``L```!87`(`'````&1<`@`8````@5P"`!,```":
M7`(`80```*Y<`@`Y````$%T"`$0```!*70(`8````(]=`@!<````\%T"``@`
M``!-7@(`*@```%9>`@`2````@5X"`"(```"47@(`'````+=>`@!`````U%X"
M`#,````57P(`!0```$E?`@`$````3U\"`!X```!47P(`&0```'-?`@`-````
MC5\"`!T```";7P(`&P```+E?`@`\````U5\"`!$````28`(`'@```"1@`@`M
M````0V`"`#8```!Q8`(`.P```*A@`@!:````Y&`"`!(````_80(`*````%)A
M`@`&````>V$"`!D```""80(`%````)QA`@`6````L6$"`!4```#(80(`'P``
M`-YA`@`0````_F$"`&H````/8@(`+@```'IB`@`Y````J6("`$0```#C8@(`
M,0```"AC`@!`````6F,"`$L```";8P(`)P```.=C`@!H````#V0"`"0```!X
M9`(`4````)UD`@!;````[F0"`"@```!*90(`,P```'-E`@`C````IV4"``<`
M``#+90(`$0```--E`@`1````Y64"``H```#W90(`"0````)F`@`1````#&8"
M``H````>9@(`#P```"EF`@`*````.68"`!8```!$9@(`'@```%MF`@`6````
M>F8"`!T```"19@(`$0```*]F`@`(````P68"``0```#*9@(`#0```,]F`@`,
M````W68"``T```#J9@(`"0```/AF`@`1`````F<"``8````49P(`!P```!MG
M`@`0````(V<"``H````T9P(`#@```#]G`@`/````3F<"``,```!>9P(`"0``
M`&)G`@`1````;&<"`"8```!^9P(`>````*5G`@`,````'F@"`!$````K:`(`
M$0```#UH`@`=````3V@"`%@```!M:`(`(````,9H`@`1````YV@"`"<```#Y
M:`(`)0```"%I`@`5````1VD"``4```!=:0(`'P```&-I`@`L````@VD"`!<`
M``"P:0(`&````,AI`@`V````X6D"`$,````8:@(`+````%QJ`@`G````B6H"
M``D```"Q:@(`-````+MJ`@`>````\&H"``T````/:P(`"0```!UK`@`A````
M)VL"`"0```!):P(`-0```&YK`@!:````I&L"`&(```#_:P(`#0```&)L`@`$
M````<&P"``L```!U;`(`&@```(%L`@`8````G&P"``P```"U;`(`"````,)L
M`@`/````RVP"`!0```#;;`(`"@```/!L`@`0````^VP"`"P````,;0(`+P``
M`#EM`@`^````:6T"`#$```"H;0(`+````-IM`@`>````!VX"`$0````F;@(`
M.0```&MN`@`L````I6X"`#X```#2;@(`+````!%O`@`I````/F\"`#T```!H
M;P(`/P```*9O`@`B````YF\"`"@````)<`(`/@```#)P`@`W````<7`"`#$`
M``"I<`(`,P```-MP`@!!````#W$"`#@```!1<0(`+0```(IQ`@`O````N'$"
M`#P```#H<0(`(@```"5R`@`G````2'("`#\```!P<@(`*P```+!R`@`<````
MW'("`"D```#Y<@(`)@```"-S`@!+````2G,"`!X```"6<P(`$0```+5S`@#$
M````QW,"`#H```",=`(`*0```,=T`@`K````\70"`"T````==0(`0````$MU
M`@`O````C'4"`#4```"\=0(`(P```/)U`@`H````%G8"`"X````_=@(`,0``
M`&YV`@`Y````H'8"`#0```#:=@(`D`````]W`@`T````H'<"`!@```#5=P(`
M+0```.YW`@`K````''@"`"\```!(>`(`1````'AX`@!*````O7@"``\````(
M>0(`!@```!AY`@`*````'WD"``H````J>0(`%````#5Y`@`4````2GD"`!@`
M``!?>0(`$````'AY`@`<````B7D"`#D```"F>0(`#@```.!Y`@!`````[WD"
M`"H````P>@(`70```%MZ`@`9````N7H"`"T```#3>@(`%`````%[`@`H````
M%GL"``\````_>P(`#````$][`@`$````7'L"`!$```!A>P(`(@```'-[`@`*
M````EGL"``\```"A>P(`%@```+%[`@`2````R'L"`#H```#;>P(`'@```!9\
M`@`0````-7P"`$<```!&?`(`*0```(Y\`@!+````N'P"``<````$?0(`&```
M``Q]`@`&````)7T"``\````L?0(`%0```#Q]`@`5````4GT"`!````!H?0(`
M`@```'E]`@!=````?'T"``<```#:?0(`!0```.)]`@`1````Z'T"`!D```#Z
M?0(`!0```!1^`@`1````&GX"`!(````L?@(`!@```#]^`@`.````1GX"``@`
M``!5?@(`!@```%Y^`@`*````97X"``P```!P?@(`$````'U^`@`/````CGX"
M`!\```">?@(`(0```+Y^`@`H````X'X"`!4````)?P(`,P```!]_`@`O````
M4W\"``H```"#?P(`#0```(Y_`@`&````G'\"`!T```"C?P(`#P```,%_`@`;
M````T7\"`!````#M?P(`$0```/Y_`@`7````$(`"`!4````H@`(`'0```#Z`
M`@`:````7(`"`!<```!W@`(`(````(^``@`/````L(`"``\```#`@`(`$0``
M`-"``@`H````XH`"`#,````+@0(`%@```#^!`@`1````5H$"`%\```!H@0(`
M4P```,B!`@`=````'(("`#X````Z@@(`#0```'F"`@`@````AX("`!D```"H
M@@(`$P```,*"`@`:````UH("`!<```#Q@@(`!@````F#`@`.````$(,"`"L`
M```?@P(`'````$N#`@`@````:(,"`!(```")@P(`!0```)R#`@`6````HH,"
M`"4```"Y@P(`"````-^#`@`;````Z(,"``8````$A`(`"P````N$`@`O````
M%X0"`$$```!'A`(`"@```(F$`@`*````E(0"`!4```"?A`(`#````+6$`@`R
M````PH0"`#P```#UA`(`$@```#*%`@`2````184"``8```!8A0(`#````%^%
M`@`R````;(4"`!D```"?A0(`/@```+F%`@`E````^(4"`"8````>A@(`%@``
M`$6&`@`A````7(8"`#X```!^A@(`,P```+V&`@`W````\88"``H````IAP(`
M)@```#2'`@`(````6X<"``\```!DAP(`)0```'2'`@`+````FH<"`"P```"F
MAP(`+@```-.'`@`<`````H@"`$`````?B`(`"````&"(`@`5````:8@"`"<`
M``!_B`(`!````*>(`@`(````K(@"``\```"UB`(`(0```,6(`@`O````YX@"
M`!<````7B0(`*0```"^)`@`]````68D"`!P```"7B0(`#````+2)`@`2````
MP8D"`!,```#4B0(`#P```.B)`@`,````^(D"``4````%B@(`"0````N*`@!1
M````%8H"``0```!GB@(`!````&R*`@`G````<8H"``<```"9B@(`"0```*&*
M`@`7````JXH"``\```##B@(`'````-.*`@`1````\(H"`!4````"BP(`&```
M`!B+`@`>````,8L"`!0```!0BP(`'0```&6+`@`F````@XL"`"$```"JBP(`
M'0```,R+`@`@````ZHL"`!X````+C`(`(````"J,`@`<````2XP"`#<```!H
MC`(`(0```*",`@`'````PHP"``@```#*C`(`"````-.,`@`'````W(P"`!8`
M``#DC`(`!0```/N,`@`)`````8T"`"$````+C0(`%P```"V-`@`0````18T"
M``X```!6C0(`(@```&6-`@`G````B(T"`!<```"PC0(`(@```,B-`@`F````
MZXT"`!0````2C@(`&````">.`@`,````0(X"``P```!-C@(`&0```%J.`@`B
M````=(X"`"8```"7C@(`0P```+Z.`@`^`````H\"`#8```!!CP(`&````'B/
M`@`0````D8\"``,```"BCP(`'````*:/`@`,````PX\"`!$```#0CP(`#```
M`.*/`@`6````[X\"`!0````&D`(`>@```!N0`@`:````EI`"`!H```"QD`(`
M'P```,R0`@!#````[)`"`$H````PD0(`+0```'N1`@`.````J9$"`"P```"X
MD0(`$0```.61`@`'````]Y$"``0```#_D0(`)P````22`@`G````+)("`#8`
M``!4D@(`/0```(N2`@`B````R9("`"0```#LD@(`+````!&3`@`8````/I,"
M`"<```!7DP(`"@```'^3`@`'````BI,"``P```"2DP(`!@```)^3`@`?````
MII,"``T```#&DP(`#````-23`@`2````X9,"``P```#TDP(`%P````&4`@`+
M````&90"``H````EE`(`#@```#"4`@`+````/Y0"``P```!+E`(`&````%B4
M`@`=````<90"`!4```"/E`(`(````*64`@`?````QI0"`#D```#FE`(`0```
M`""5`@`:````894"`!L```!\E0(`30```)B5`@`7````YI4"``8```#^E0(`
M!`````66`@`G````"I8"`!$````RE@(`,0```$26`@`>````=I8"`!T```"5
ME@(`*P```+.6`@`J````WY8"`"P````*EP(`+0```#>7`@`<````99<"``8`
M``""EP(`'````(F7`@`.````II<"`!<```"UEP(``P```,V7`@`#````T9<"
M``<```#5EP(`$````-V7`@`2````[I<"`!$````!F`(`+0```!.8`@!`````
M09@"`!T```""F`(`'````*"8`@`/````O9@"`!\```#-F`(`#0```.V8`@`6
M````^Y@"``8````2F0(`"P```!F9`@`F````)9D"``8```!,F0(`!````%.9
M`@`2````6)D"`!(```!KF0(`#@```'Z9`@`'````C9D"``X```"5F0(`#P``
M`*29`@`A````M)D"`!,```#6F0(`#P```.J9`@!%````^ID"`"L```!`F@(`
M!@```&R:`@`<````<YH"`!L```"0F@(`!P```*R:`@`*````M)H"``@```"_
MF@(`$P```,B:`@`*````W)H"``L```#GF@(`%@```/.:`@`1````"IL"``L`
M```<FP(``P```"B;`@`4````+)L"`"<```!!FP(`#P```&F;`@`3````>9L"
M`%````"-FP(`)0```-Z;`@`(````!)P"``8````-G`(`.0```!2<`@`8````
M3IP"`(P```!GG`(`&0```/2<`@`W````#IT"``P```!&G0(`!@```%.=`@`.
M````6IT"``@```!IG0(`"@```'*=`@`'````?9T"``H```"%G0(`"P```)"=
M`@`1````G)T"`!L```"NG0(`#````,J=`@`"````UYT"``@```#:G0(`#0``
M`..=`@`-````\9T"`!T```#_G0(`#@```!V>`@`1````+)X"`!8````^G@(`
M!@```%6>`@`&````7)X"``T```!CG@(`!P```'&>`@`0````>9X"``@```"*
MG@(`"@```).>`@`$````GIX"`!H```"CG@(`!0```+Z>`@`@````Q)X"``L`
M``#EG@(`!@```/&>`@`5````^)X"`"0````.GP(`$0```#.?`@`&````19\"
M``L```!,GP(`*P```%B?`@`%````A)\"``D```"*GP(`"@```)2?`@`4````
MGY\"``4```"TGP(`"@```+J?`@`L````Q9\"``4```#RGP(`#0```/B?`@`.
M````!J`"`!$````5H`(`#````">@`@`+````-*`"`!(```!`H`(`"````%.@
M`@`'````7*`"`!8```!DH`(`'````'N@`@!#````F*`"`"L```#<H`(`.```
M``BA`@`)````0:$"``H```!+H0(`!````%:A`@`)````6Z$"``@```!EH0(`
M%````&ZA`@`+````@Z$"``8```"/H0(`#0```):A`@`&````I*$"``,```"K
MH0(`%@```*^A`@!`````QJ$"`$4````'H@(`0@```$VB`@`K````D*("``4`
M``"\H@(`#P```,*B`@`#````TJ("``8```#6H@(`!@```-VB`@`;````Y*("
M``P`````HP(`%`````VC`@`(````(J,"``@````KHP(`(P```#2C`@`(````
M6*,"``<```!AHP(`$````&FC`@`B````>J,"``P```"=HP(`)0```*JC`@`8
M````T*,"`$$```#IHP(`!````"ND`@`&````,*0"``H````WI`(`"````$*D
M`@`,````2Z0"``@```!8I`(`"P```&&D`@`4````;:0"``\```""I`(`"```
M`)*D`@`(````FZ0"``4```"DI`(`-````*JD`@`W````WZ0"`#<````7I0(`
M+````$^E`@!%````?*4"`$,```#"I0(`+P````:F`@!8````-J8"`#0```"/
MI@(`2@```,2F`@`M````#Z<"`!`````]IP(`$````$ZG`@`+````7Z<"`",`
M``!KIP(`+P```(^G`@`D````OZ<"`!<```#DIP(`(````/RG`@`R````':@"
M``P```!0J`(`#@```%VH`@`*````;*@"``P```!WJ`(`!````(2H`@`L````
MB:@"`$(```"VJ`(`+@```/FH`@`J````**D"`#\```!3J0(`#P```).I`@`B
M````HZD"`!T```#&J0(`+````.2I`@`0````$:H"`!L````BJ@(`!@```#ZJ
M`@`>````1:H"`#````!DJ@(`'````)6J`@`6````LJH"``8```#)J@(`"P``
M`-"J`@`*````W*H"`!````#GJ@(`)0```/BJ`@!&````'JL"`$H```!EJP(`
M-P```+"K`@"1````Z*L"`'0```!ZK`(`%````.^L`@`<````!*T"``,````A
MK0(`#P```"6M`@`,````-:T"``T```!"K0(`&P```%"M`@`7````;*T"``X`
M``"$K0(`!0```).M`@`*````F:T"`!$```"DK0(`%````+:M`@`3````RZT"
M`!4```#?K0(`(0```/6M`@`G````%ZX"`"H````_K@(`*@```&JN`@`;````
ME:X"`!\```"QK@(`(@```-&N`@`8````]*X"`!X````-KP(`/P```"RO`@`5
M````;*\"``8```""KP(`#@```(FO`@`?````F*\"`!4```"XKP(`$P```,ZO
M`@`+````XJ\"`!8```#NKP(`/P````6P`@`S````1;`"`!<```!YL`(`-```
M`)&P`@"-````QK`"`!````!4L0(`!0```&6Q`@`2````:[$"``D```!^L0(`
M"@```(BQ`@`*````D[$"`"@```">L0(`(````,>Q`@`G````Z+$"`"H````0
ML@(`"0```#NR`@`7````1;("`!T```!=L@(`$````'NR`@`N````C+("`#$`
M``"[L@(`)@```.VR`@`5````%+,"`!`````JLP(`%@```#NS`@`7````4K,"
M`!8```!JLP(`$P```(&S`@`3````E;,"`!P```"ILP(`&P```,:S`@`@````
MXK,"`#\````#M`(`&0```$.T`@`8````7;0"`!<```!VM`(`%@```(ZT`@`2
M````I;0"`!P```"XM`(`&P```-6T`@`3````\;0"`!,````%M0(`,````!FU
M`@`;````2K4"`!P```!FM0(`0@```(.U`@`?````QK4"``4```#FM0(`%```
M`.RU`@`P`````;8"`!H````RM@(`)P```$VV`@`M````=;8"`",```"CM@(`
M(0```,>V`@`F````Z;8"`#(````0MP(`)0```$.W`@`=````:;<"`",```"'
MMP(`"P```*NW`@`C````M[<"`!P```#;MP(`(@```/BW`@!!````&[@"`"(`
M``!=N`(`)P```("X`@`G````J+@"`"(```#0N`(`)0```/.X`@`@````&;D"
M`"`````ZN0(`(P```%NY`@`I````?[D"`"(```"IN0(`(P```,RY`@`-````
M\+D"``\```#^N0(`%P````ZZ`@`8````)KH"``0````_N@(`"````$2Z`@`*
M````3;H"`!0```!8N@(`!@```&VZ`@`5````=+H"``0```"*N@(`"P```(^Z
M`@`'````F[H"``8```"CN@(`!0```*JZ`@`3````L+H"``8```#$N@(`"```
M`,NZ`@`&````U+H"``8```#;N@(`"@```.*Z`@`0````[;H"`!H```#^N@(`
M$````!F[`@`1````*KL"``H````\NP(`&````$>[`@`%````8+L"`#D```!F
MNP(`%@```*"[`@`1````M[L"`!$```#)NP(`#@```-N[`@`+````ZKL"`!(`
M``#VNP(`+P````F\`@!1````.;P"`%(```"+O`(`6P```-Z\`@!&````.KT"
M``@```"!O0(`"````(J]`@`D````D[T"`!(```"XO0(`#P```,N]`@`&````
MV[T"``P```#BO0(`"0```.^]`@`%````^;T"`"0```#_O0(`"@```"2^`@`5
M````+[X"``P```!%O@(`%@```%*^`@`-````:;X"`!,```!WO@(`&````(N^
M`@`C````I+X"`"<```#(O@(`"@```/"^`@`#````^[X"``H```#_O@(`(@``
M``J_`@`'````+;\"``,````UOP(`$0```#F_`@`2````2[\"``<```!>OP(`
M!0```&:_`@`'````;+\"`"H```!TOP(`#0```)^_`@`2````K;\"``H```#`
MOP(`$P```,N_`@`7````W[\"``P```#WOP(`#@````3``@`.````$\`"``X`
M```BP`(`!````#'``@`N````-L`"`!$```!EP`(`0P```'?``@!!````N\`"
M``8```#]P`(`,P````3!`@`%````.,$"`"<````^P0(`%@```&;!`@`T````
M?<$"`!4```"RP0(`?@```,C!`@`.````1\("`!,```!6P@(`#P```&K"`@`0
M````>L("``\```"+P@(`'@```)O"`@`?````NL("`!L```#:P@(`-0```/;"
M`@`K````+,,"`"8```!8PP(`"````'_#`@`(````B,,"``L```"1PP(`#```
M`)W#`@`+````JL,"`!$```"VPP(`!````,C#`@`-````S<,"`!,```#;PP(`
M*@```._#`@`-````&L0"``T````HQ`(`)@```#;$`@!1````7<0"`!T```"O
MQ`(`#0```,W$`@`(````V\0"``@```#DQ`(`"@```.W$`@`.````^,0"``X`
M```'Q0(`%0```!;%`@`.````+,4"``D````[Q0(``@```$7%`@`-````2,4"
M`",```!6Q0(`!@```'K%`@`%````@<4"``D```"'Q0(`#@```)'%`@`+````
MH,4"``D```"LQ0(`"0```+;%`@`4````P,4"`!,```#5Q0(`(0```.G%`@`)
M````"\8"`#,````5Q@(`#@```$G&`@`&````6,8"``@```!?Q@(`#P```&C&
M`@`$````>,8"``4```!]Q@(`:P```(/&`@`,````[\8"``\```#\Q@(`(```
M``S'`@`'````+<<"``4````UQP(`,````#O'`@`R````;,<"`!,```"?QP(`
M.````+/'`@`R````[,<"`"0````?R`(`*@```$3(`@`Q````;\@"`!$```"A
MR`(`"@```+/(`@`D````OL@"`"0```#CR`(`&0````C)`@`*````(LD"``D`
M```MR0(`*@```#?)`@`>````8LD"`"D```"!R0(`*````*O)`@`9````U,D"
M`!@```#NR0(`*P````?*`@`/````,\H"`#$```!#R@(`2````'7*`@`%````
MOLH"``<```#$R@(`#0```,S*`@`%````VLH"`!(```#@R@(`$P```//*`@`6
M````!\L"``4````>RP(`"0```"3+`@`.````+LL"`!\````]RP(`$@```%W+
M`@`.````<,L"``\```!_RP(`60```(_+`@`4````Z<L"`!X```#^RP(`#P``
M`!W,`@`,````+<P"``P````ZS`(`(````$?,`@`3````:,P"`"@```!\S`(`
M$@```*7,`@`C````N,P"`#$```#<S`(`%`````[-`@`0````(\T"`$,````T
MS0(`$@```'C-`@`6````B\T"`"0```"BS0(`9@```,?-`@`8````+LX"``<`
M``!'S@(`'P```$_.`@`P````;\X"``@```"@S@(`!@```*G.`@`>````L,X"
M``4```#/S@(`"@```-7.`@`N````X,X"`"T````/SP(`.P```#W/`@`3````
M><\"``8```"-SP(`)````)3/`@!6````N<\"`!\````0T`(`'````##0`@`Y
M````3=`"``(```"'T`(`&0```(K0`@`'````I-`"`!(```"LT`(`"0```+_0
M`@`1````R=`"``<```#;T`(`%````./0`@`&````^-`"``@```#_T`(`"P``
M``C1`@`'````%-$"``H````<T0(`"P```"?1`@`L````,]$"`"T```!@T0(`
M!P```([1`@`0````EM$"`!````"GT0(`#P```+C1`@`)````R-$"``D```#2
MT0(`#````-S1`@`-````Z=$"``H```#WT0(`#@````+2`@!)````$=("`!@`
M``!;T@(`#@```'32`@`(````@]("`!L```",T@(`'@```*C2`@`@````Q]("
M`!````#HT@(`%````/G2`@`:````#M,"`!8````ITP(`%@```$#3`@`@````
M5],"``<```!XTP(`%@```(#3`@`%````E],"``H```"=TP(``P```*C3`@`H
M````K-,"``<```#5TP(`!0```-W3`@`,````X],"``4```#PTP(`"0```/;3
M`@`0`````-0"`!(````1U`(`,P```"34`@`N````6-0"`"(```"'U`(`)```
M`*K4`@`7````S]0"`!\```#GU`(`&0````?5`@`'````(=4"``0````IU0(`
M(````"[5`@`"````3]4"``P```!2U0(`#````%_5`@`(````;-4"``@```!U
MU0(`"````'[5`@`1````A]4"``8```"9U0(`'@```*#5`@`)````O]4"``H`
M``#)U0(`"0```-35`@`K````WM4"`"4````*U@(`#P```##6`@`%````0-8"
M``P```!&U@(`"0```%/6`@`1````7=8"``\```!OU@(`#P```'_6`@`0````
MC]8"``H```"@U@(`"0```*O6`@`%````M=8"``<```"[U@(`!P```,/6`@`$
M````R]8"``,```#0U@(`&0```-36`@`C````[M8"`!<````2UP(`"P```"K7
M`@`O````-M<"`",```!FUP(`&P```(K7`@`=````IM<"`"D```#$UP(`$```
M`.[7`@!9````_]<"`"T```!9V`(`1````(?8`@`;````S-@"`#T```#HV`(`
M#P```";9`@!`````-MD"`"D```!WV0(`'@```*'9`@`>````P-D"`",```#?
MV0(`-@````/:`@`-````.MH"`#X```!(V@(`,````(?:`@`5````N-H"`#,`
M``#.V@(`'`````+;`@`A````']L"`"D```!!VP(`&0```&O;`@`5````A=L"
M`!4```";VP(`$0```+';`@`,````P]L"``\```#0VP(`'````.#;`@`4````
M_=L"`!4````2W`(`(0```"C<`@`]````2MP"`#X```"(W`(`00```,?<`@`^
M````"=T"`#\```!(W0(`/0```(C=`@!M````QMT"`!X````TW@(`,````%/>
M`@`S````A-X"`"\```"XW@(`5@```.C>`@`6````/]\"`!H```!6WP(`)0``
M`''?`@`/````E]\"`#$```"GWP(`%@```-G?`@`0````\-\"``X````!X`(`
M20```!#@`@`[````6N`"`!P```"6X`(`*P```+/@`@`M````W^`"``H````-
MX0(`*0```!CA`@`K````0N$"``T```!NX0(`#0```'SA`@`F````BN$"`!8`
M``"QX0(`#@```,CA`@`'````U^$"``X```#?X0(`%P```.[A`@`(````!N("
M``H````/X@(`#````!KB`@`*````)^("`!`````RX@(`"@```$/B`@`-````
M3N("``X```!<X@(`'0```&OB`@`2````B>("`"\```"<X@(`$@```,SB`@`/
M````W^("``\```#OX@(`%@```/_B`@`,````%N,"``4````CXP(`)@```"GC
M`@`S````4.,"``@```"$XP(`!````(WC`@`0````DN,"``X```"CXP(`:0``
M`++C`@!:````'.0"``L```!WY`(`-0```(/D`@`"````N>0"``0```"\Y`(`
M"````,'D`@`7````RN0"``P```#BY`(`!P```._D`@`&````]^0"`!$```#^
MY`(`*P```!#E`@`,````/.4"``T```!)Y0(`'````%?E`@!#````=.4"``0`
M``"XY0(`-P```+WE`@!`````]>4"`",````VY@(`'@```%KF`@`[````>>8"
M`'<```"UY@(`#````"WG`@`7````.N<"`$@```!2YP(`#P```)OG`@`G````
MJ^<"`!(```#3YP(`%0```.;G`@`&````_.<"``X````#Z`(`%````!+H`@`)
M````)^@"`!$````QZ`(`#@```$/H`@`>````4N@"`!4```!QZ`(`!0```(?H
M`@`0````C>@"`"H```">Z`(`$0```,GH`@`5````V^@"`!H```#QZ`(`,@``
M``SI`@`5````/^D"`!4```!5Z0(`'0```&OI`@`8````B>D"``H```"BZ0(`
M10```*WI`@`/````\^D"`!D````#Z@(`1P```!WJ`@`3````9>H"`!L```!Y
MZ@(`,P```)7J`@`M````R>H"`!4```#WZ@(`+`````WK`@`V````.NL"`!\`
M``!QZP(`*0```)'K`@`L````N^L"`"X```#HZP(`;````!?L`@!<````A.P"
M`.P```#A[`(`!P```,[M`@`7````UNT"``L```#N[0(`%````/KM`@`4````
M#^X"`!8````D[@(`$````#ON`@`6````3.X"``0```!C[@(`+````&CN`@`/
M````E>X"`"(```"E[@(`(@```,CN`@`0````Z^X"`!@```#\[@(`"P```!7O
M`@`2````(>\"`"L````T[P(`+0```&#O`@`)````CN\"``4```"8[P(`'0``
M`)[O`@`&````O.\"``\```##[P(`"````-/O`@`(````W.\"`!(```#E[P(`
M"0```/CO`@`7`````O`"`"<````:\`(`"@```$+P`@`:````3?`"`!H```!H
M\`(`!@```(/P`@`D````BO`"`!0```"O\`(`,P```,3P`@`5````^/`"``<`
M```.\0(`"````!;Q`@`>````'_$"``L````^\0(`&P```$KQ`@`'````9O$"
M`",```!N\0(`!P```)+Q`@`(````FO$"`"0```"C\0(`.P```,CQ`@`+````
M!/("`"4````0\@(`)P```#;R`@`-````7O("`!H```!L\@(`,P```(?R`@`)
M````N_("`!````#%\@(`,````-;R`@`M````!_,"`#(````U\P(`,````&CS
M`@`$````F?,"``X```">\P(`#@```*WS`@`'````O/,"``X```#$\P(`"```
M`-/S`@`%````W/,"`'````#B\P(`&P```%/T`@`)````;_0"`.(```!Y]`(`
M'0```%SU`@`F````>O4"`#\```"A]0(`*````.'U`@`E````"O8"`"$````P
M]@(`'P```%+V`@`[````<O8"`!X```"N]@(`(0```,WV`@`;````[_8"`(,`
M```+]P(`A@```(_W`@!7`0``%O@"`"H```!N^0(`&P```)GY`@`R````M?D"
M`"8```#H^0(`70````_Z`@`U````;?H"`#H```"C^@(`/@```-[Z`@`[````
M'?L"`#P```!9^P(`)0```);[`@`-````O/L"``@```#*^P(`"@```-/[`@`*
M````WOL"`!$```#I^P(`%@```/O[`@!'````$OP"`!4```!:_`(`2@```'#\
M`@`E````N_P"`!H```#A_`(`)@```/S\`@`X````(_T"`$````!<_0(`"0``
M`)W]`@`F````I_T"``L```#._0(`"@```-K]`@`G````Y?T"``L````-_@(`
M"P```!G^`@`,````)?X"``D````R_@(`&0```#S^`@`5````5OX"``P```!L
M_@(`%P```'G^`@`.````D?X"``X```"@_@(`#P```*_^`@!"````O_X"`$,`
M```"_P(`$````$;_`@`*````5_\"``\```!B_P(`&P```'+_`@`:````CO\"
M`#D```"I_P(`-0```./_`@`+````&0`#`!`````E``,`#P```#8``P`0````
M1@`#`#,```!7``,`&@```(L``P!!````I@`#`#L```#H``,`,````"0!`P`O
M````50$#``4```"%`0,`%0```(L!`P`%````H0$#`"````"G`0,`&P```,@!
M`P`2````Y`$#``P```#W`0,`'@````0"`P`7````(P(#``,````[`@,`#```
M`#\"`P`0````3`(#``4```!=`@,`#@```&,"`P`(````<@(#``\```![`@,`
M!0```(L"`P`'````D0(#`!````"9`@,`20```*H"`P!0````]`(#`!X```!%
M`P,`%0```&0#`P`/````>@,#`!````"*`P,`"P```)L#`P`+````IP,#`!0`
M``"S`P,`&P```,@#`P`<````Y`,#`"<````!!`,`"0```"D$`P`R````,P0#
M`!T```!F!`,`*P```(0$`P`1````L`0#``D```#"!`,`'````,P$`P`,````
MZ00#`"4```#V!`,`'0```!P%`P`1````.@4#`!````!,!0,`,@```%T%`P`&
M````D`4#``T```"7!0,`'P```*4%`P`.````Q04#`!4```#4!0,`#0```.H%
M`P!<````^`4#``T```!5!@,`"@```&,&`P`E````;@8#`!4```"4!@,`%@``
M`*H&`P`3````P08#`%````#5!@,`10```"8'`P`0````;`<#`!,```!]!P,`
M!@```)$'`P`4````F`<#`!8```"M!P,`%P```,0'`P`0````W`<#`!$```#M
M!P,`%@```/\'`P`H````%@@#`#`````_"`,`)@```'`(`P`1````EP@#`!,`
M``"I"`,`!P```+T(`P`3````Q0@#``\```#9"`,`*P```.D(`P`L````%0D#
M`$````!""0,`'0```(,)`P`F````H0D#`#X```#("0,`00````<*`P`[````
M20H#``X```"%"@,`$P```)0*`P`%````J`H#`!,```"N"@,`'````,(*`P`C
M````WPH#`"`````#"P,`"````"0+`P`)````+0L#`!<````W"P,`&````$\+
M`P`9````:`L#`!,```"""P,`1````)8+`P`;````VPL#``<```#W"P,`'P``
M`/\+`P`7````'PP#`!`````W#`,`!````$@,`P`2````30P#`!,```!@#`,`
M%````'0,`P`&````B0P#``<```"0#`,`$P```)@,`P`.````K`P#``\```"[
M#`,`$0```,L,`P`1````W0P#``8```#O#`,`!P```/8,`P`H````_@P#`"0`
M```G#0,`(````$P-`P`(````;0T#``\```!V#0,`!@```(8-`P`8````C0T#
M`!X```"F#0,`*0```,4-`P`-````[PT#`$@```#]#0,`$@```$8.`P`=````
M60X#`$L```!W#@,`,````,,.`P`N````]`X#`!@````C#P,`.0```#P/`P`O
M````=@\#`#D```"F#P,`*P```.`/`P!@````#!`#`&P```!M$`,`<````-H0
M`P#T````2Q$#`"D```!`$@,`"@```&H2`P`8````=1(#``,```".$@,`"```
M`)(2`P`&````FQ(#``,```"B$@,`*P```*82`P`&````TA(#`!(```#9$@,`
M%````.P2`P`+`````1,#`!@````-$P,`(P```"83`P`7````2A,#``8```!B
M$P,`"@```&D3`P`4````=!,#`!<```")$P,`#````*$3`P`&````KA,#``P`
M``"U$P,`"@```,(3`P!-````S1,#`!L````;%`,`#P```#<4`P`B````1Q0#
M``8```!J%`,`%@```'$4`P`<````B!0#``8```"E%`,`0P```*P4`P!Y````
M\!0#`$X```!J%0,`*@```+D5`P`B````Y!4#`!\````'%@,`+P```"<6`P!"
M````5Q8#`!0```":%@,`"````*\6`P`'````N!8#`!@```#`%@,`%P```-D6
M`P`D````\18#`!,````6%P,`#````"H7`P`3````-Q<#`"$```!+%P,`%P``
M`&T7`P`8````A1<#`!8```">%P,`(@```+47`P`=````V!<#`!(```#V%P,`
M'0````D8`P`E````)Q@#`%H```!-&`,`$0```*@8`P`F````NA@#`%D```#A
M&`,`&````#L9`P`8````5!D#`!<```!M&0,`@P```(49`P`H````"1H#`!\`
M```R&@,`.@```%(:`P`X````C1H#`"4```#&&@,`)P```.P:`P`>````%!L#
M`"L````S&P,`(P```%\;`P`G````@QL#`!P```"K&P,`,0```,@;`P`A````
M^AL#``H````<'`,`%````"<<`P`+````/!P#`"T```!('`,`4````'8<`P`(
M````QQP#``D```#0'`,`'````-H<`P`=````]QP#``H````5'0,`%0```"`=
M`P`+````-AT#``<```!"'0,`'````$H=`P`[````9QT#``@```"C'0,`*0``
M`*P=`P`W````UAT#`!8````.'@,`!@```"4>`P!%````+!X#`#\```!R'@,`
M,P```+(>`P!5````YAX#`#0````\'P,`G````'$?`P`+````#B`#`#<````:
M(`,`+P```%(@`P`2````@B`#`"\```"5(`,`*@```,4@`P`V````\"`#``@`
M```G(0,`$P```#`A`P!$````1"$#`'(```")(0,`0P```/PA`P!8````0"(#
M`$4```"9(@,`#````-\B`P`9````["(#`"`````&(P,`&````"<C`P`G````
M0",#`"H```!H(P,`/0```),C`P!!````T2,#`$4````3)`,`6````%DD`P!(
M````LB0#`#0```#[)`,`*````#`E`P`4````624#`"\```!N)0,`1P```)XE
M`P`B````YB4#`"(````))@,`*````"PF`P`2````528#`"P```!H)@,`(@``
M`)4F`P`K````N"8#`"X```#D)@,`'P```!,G`P`J````,R<#`!4```!>)P,`
M!P```'0G`P`0````?"<#`!0```"-)P,`#0```*(G`P`(````L"<#``L```"Y
M)P,`40```,4G`P`%````%R@#``P````=*`,`'@```"HH`P`1````22@#`!\`
M``!;*`,`$@```'LH`P`)````CB@#``4```"8*`,`&````)XH`P`)````MR@#
M``D```#!*`,`!P```,LH`P`'````TR@#``D```#;*`,`$@```.4H`P`<````
M^"@#``\````5*0,`'P```"4I`P`0````12D#``@```!6*0,`#0```%\I`P`:
M````;2D#`!@```"(*0,`%P```*$I`P`;````N2D#`!8```#5*0,`&````.PI
M`P`8````!2H#`"8````>*@,`"P```$4J`P`*````42H#`!@```!<*@,`)@``
M`'4J`P`,````G"H#`"(```"I*@,`*P```,PJ`P`+````^"H#``@````$*P,`
M(0````TK`P`-````+RL#`!D````]*P,`"P```%<K`P`;````8RL#`!0```!_
M*P,`+@```)0K`P`4````PRL#`!,```#8*P,`(P```.PK`P!#````$"P#`!0`
M``!4+`,`%@```&DL`P`2````@"P#``4```"3+`,`"0```)DL`P`(````HRP#
M``D```"L+`,`!@```+8L`P`*````O2P#`!0```#(+`,`"@```-TL`P`2````
MZ"P#`!4```#[+`,`"P```!$M`P`'````'2T#`!`````E+0,`"@```#8M`P`(
M````02T#``P```!*+0,`&````%<M`P`A````<"T#`"<```"2+0,`#````+HM
M`P`"````QRT#``4```#*+0,`(P```-`M`P`%````]"T#``H```#Z+0,`"@``
M``4N`P!Z````$"X#`"X```"++@,`"@```+HN`P`(````Q2X#`"H```#.+@,`
M.@```/DN`P`:````-"\#`"X```!/+P,`70```'XO`P`C````W"\#`#,`````
M,`,`+P```#0P`P`E````9#`#``8```"*,`,`"@```)$P`P`-````G#`#``@`
M``"J,`,`"0```+,P`P`%````O3`#``@```##,`,`$@```,PP`P`*````WS`#
M``D```#J,`,`"P```/0P`P`+`````#$#`!H````,,0,`"````"<Q`P`)````
M,#$#`!4````Z,0,`"@```%`Q`P`*````6S$#`!D```!F,0,`(P```(`Q`P`H
M````I#$#``4```#-,0,`+@```-,Q`P`F`````C(#`!@````I,@,`!P```$(R
M`P`2````2C(#``D```!=,@,`#P```&<R`P`S````=S(#``@```"K,@,`&```
M`+0R`P`8````S3(#``8```#F,@,`!@```.TR`P`-````]#(#`!P````",P,`
M!@```!\S`P`)````)C,#``<````P,P,`"P```#@S`P`<````1#,#``L```!A
M,P,`#0```&TS`P`J````>S,#`!\```"F,P,`&````,8S`P`,````WS,#`"(`
M``#L,P,`%@````\T`P!(````)C0#``8```!O-`,`"P```'8T`P`0````@C0#
M``T```"3-`,``P```*$T`P`.````I30#``@```"T-`,`'0```+TT`P`P````
MVS0#`"\````,-0,`,````#PU`P!V````;34#`"H```#D-0,`&0````\V`P`J
M````*38#`"X```!4-@,`+@```(,V`P`@````LC8#`"$```#3-@,`C@```/4V
M`P`:````A#<#`!8```"?-P,`*0```+8W`P!C````X#<#`#@```!$.`,`+P``
M`'TX`P`E````K3@#`&$```#3.`,`80```#4Y`P!I````ESD#`"$````!.@,`
M,````",Z`P!-````5#H#`"````"B.@,`*P```,,Z`P`\````[SH#`$<````L
M.P,`'@```'0[`P`8````DSL#`!T```"L.P,`;P```,H[`P!0````.CP#`%8`
M``"+/`,`.````.(\`P`X````&ST#`"0```!4/0,`(0```'D]`P`K````FST#
M`",```#'/0,`+P```.L]`P#]`0``&SX#`!T````90`,`C@```#=``P!)````
MQD`#`!T````000,`20```"Y!`P`R````>$$#`#,```"K00,`+@```-]!`P`;
M````#D(#`&(````J0@,`.@```(U"`P`F````R$(#`!4```#O0@,`,0````5#
M`P`^````-T,#`*````!V0P,`-````!=$`P`I````3$0#`$<```!V1`,`6@``
M`+Y$`P!D````&44#`#(```!^10,`0@```+%%`P`V````]$4#`#$````K1@,`
M(````%U&`P`>````?D8#`'X```"=1@,`-````!Q'`P`<````44<#`!\```!N
M1P,`-P```(Y'`P`]````QD<#`$`````$2`,`)````$5(`P`<````:D@#`"``
M``"'2`,`(@```*A(`P`?````RT@#`",```#K2`,`(@````])`P`F````,DD#
M``\```!920,`(0```&E)`P`0````BTD#`"(```"<20,`&@```+])`P`L````
MVDD#`"\````'2@,`&@```#=*`P`6````4DH#`#$```!I2@,`*@```)M*`P`Z
M````QDH#`"0````!2P,`/````"9+`P!:````8TL#`!T```"^2P,`&@```-Q+
M`P`R````]TL#`'$````J3`,`+P```)Q,`P`[````S$P#`#H````(30,`8```
M`$--`P`R````I$T#`"D```#730,`1P````%.`P!M````24X#`%\```"W3@,`
M4P```!=/`P!$````:T\#`$0```"P3P,`.````/5/`P`G````+E`#`#````!6
M4`,`3@```(=0`P`B````UE`#`#````#Y4`,`+0```"I1`P`S````6%$#`"P`
M``",40,`1P```+E1`P!.`````5(#`%8```!04@,`9@```*=2`P`X````#E,#
M`",```!'4P,`30```&M3`P!3````N5,#`#,````-5`,`(@```$%4`P`B````
M9%0#`%````"'5`,`20```-A4`P`Q````(E4#`#8```!450,`/P```(M5`P`G
M````RU4#`"<```#S50,`)````!M6`P!X````0%8#`&T```"Y5@,`=P```"=7
M`P#.````GU<#`!P```!N6`,`+````(M8`P`V````N%@#`"X```#O6`,`4```
M`!Y9`P`<````;UD#`$````",60,`/P```,U9`P`%````#5H#`,@````36@,`
M.P```-Q:`P`M````&%L#`$P```!&6P,`10```)-;`P!,````V5L#`$8````F
M7`,`2````&U<`P`U````MEP#`#8```#L7`,`.0```"-=`P`T````75T#`#$`
M``"270,`%````,1=`P!&````V5T#`"(````@7@,`/@```$->`P!?````@EX#
M`"<```#B7@,`'`````I?`P`U````)U\#`"P```!=7P,`%@```(I?`P`6````
MH5\#``D```"X7P,`%@```,)?`P`#````V5\#`!8```#=7P,`#````/1?`P`-
M`````6`#``L````/8`,`!P```!M@`P`-````(V`#``<````Q8`,`"0```#E@
M`P"5````0V`#`'4```#98`,`30```$]A`P`"````G6$#`!8```"@80,`!```
M`+=A`P`'````O&$#``8```#$80,`!0```,MA`P`%````T6$#`!4```#780,`
M%P```.UA`P`*````!6(#`!H````08@,`&P```"MB`P`2````1V(#``\```!:
M8@,``@```&IB`P`'````;6(#``L```!U8@,`$@```(%B`P`-````E&(#`!D`
M``"B8@,`!@```+QB`P`9````PV(#``H```#=8@,``P```.AB`P!;````[&(#
M``0```!(8P,`!@```$UC`P`'````5&,#`"<```!<8P,`3````(1C`P!&````
MT6,#`$<````89`,`*@```&!D`P`N````BV0#`#$```"Z9`,`'0```.QD`P`B
M````"F4#`!P````M90,`,@```$IE`P`J````?64#`"0```"H90,`)@```,UE
M`P`G````]&4#`"X````<9@,`*P```$MF`P`>````=V8#`"D```"69@,`*@``
M`,!F`P`?````ZV8#`",````+9P,`(0```"]G`P`9````46<#`"(```!K9P,`
M+````(YG`P`R````NV<#`#,```#N9P,`)P```")H`P`=````2F@#`"0```!H
M:`,`*0```(UH`P`=````MV@#`"<```#5:`,`.````/UH`P`[````-FD#`!D`
M``!R:0,`(P```(QI`P`Z````L&D#`"(```#K:0,`)@````YJ`P`D````-6H#
M`"4```!::@,`'````(!J`P`@````G6H#`"0```"^:@,`,````.-J`P`>````
M%&L#`#$````S:P,`(0```&5K`P`V````AVL#`!````"^:P,`&````,]K`P`-
M````Z&L#``D```#V:P,`'@````!L`P`0````'VP#`"(````P;`,`1P```%-L
M`P!`````FVP#`#H```#<;`,`.````!=M`P`L````4&T#``P```!];0,`%```
M`(IM`P`/````GVT#`!<```"O;0,`$@```,=M`P`0````VFT#`"<```#K;0,`
M!@```!-N`P`*````&FX#`!`````E;@,`1````#9N`P`6````>VX#`!(```"2
M;@,`)0```*5N`P`H````RVX#`!L```#T;@,`*````!!O`P`<````.6\#`"$`
M``!6;P,`#P```'AO`P#T````B&\#``P```!]<`,`%0```(IP`P!`````H'`#
M`!<```#A<`,`"0```/EP`P`7`````W$#`"`````;<0,`(@```#QQ`P`=````
M7W$#`!X```!]<0,`"0```)QQ`P`^````IG$#``\```#E<0,`%@```/5Q`P`'
M````#'(#`!L````4<@,`&````#!R`P!$````27(#`!$```".<@,`)0```*!R
M`P!.````QG(#`!`````5<P,`9````"9S`P`B````BW,#`!P```"N<P,`&```
M`,MS`P`C````Y',#`&$````(=`,`)P```&IT`P`0````DG0#`"<```"C=`,`
M$0```,MT`P`2````W70#`!@```#P=`,`"P````EU`P`=````%74#`"D````S
M=0,`'P```%UU`P`+````?74#`#,```")=0,`/0```+UU`P`'````^W4#`!,`
M```#=@,`!P```!=V`P`'````'W8#``D````G=@,`20```#%V`P`&````>W8#
M``T```""=@,`$````)!V`P`6````H78#``L```"X=@,`#````,1V`P`'````
MT78#`!$```#9=@,`"P```.MV`P`/````]W8#`!\````'=P,`+P```"=W`P`4
M````5W<#`"4```!L=P,`*````))W`P`9````NW<#`!<```#5=P,`'````.UW
M`P`7````"G@#`"P````B>`,`*@```$]X`P`<````>G@#`!H```"7>`,`-```
M`+)X`P`6````YW@#`!4```#^>`,`%````!1Y`P`8````*7D#`#$```!">0,`
M$````'1Y`P`M````A7D#``\```"S>0,`%0```,-Y`P`7````V7D#`!<```#Q
M>0,`'`````EZ`P`,````)GH#``X````S>@,`+````$)Z`P`.````;WH#`#8`
M``!^>@,`&@```+5Z`P`0````T'H#``X```#A>@,``P```/!Z`P`4````]'H#
M`!L````)>P,``P```"5[`P`)````*7L#``<````S>P,`"@```#M[`P`E````
M1GL#``X```!L>P,`&P```'M[`P`<````EWL#``X```"T>P,`-````,-[`P`:
M````^'L#`!4````3?`,`20```"E\`P!?````<WP#`#L```#3?`,`5@````]]
M`P!M````9GT#`!D```#4?0,`#0```.Y]`P`R````_'T#`!,````O?@,`"0``
M`$-^`P`7````37X#`%8```!E?@,`%0```+Q^`P`9````TGX#``H```#L?@,`
M!````/=^`P`$````_'X#`!8````!?P,`%0```!A_`P`%````+G\#``8````T
M?P,`"@```#M_`P`-````1G\#``4```!4?P,`#@```%I_`P`2````:7\#`#\`
M``!\?P,`,@```+Q_`P`I````[W\#`"`````9@`,`'````#J``P`C````5X`#
M`"@```![@`,`(````*2``P`5````Q8`#``(```#;@`,`!````-Z``P`-````
MXX`#``8```#Q@`,`!0```/B``P`$````_H`#`!$````#@0,`-@```!6!`P`M
M````3($#`"4```!Z@0,`)````*"!`P`K````Q8$#`"8```#Q@0,`>````!B"
M`P`M````D8(#`"0```"_@@,`.0```.2"`P`M````'H,#`"8```!,@P,`A```
M`'.#`P`O````^(,#`$<````HA`,`3````'"$`P`C````O80#`$@```#AA`,`
M0P```"J%`P!(````;H4#`!8```"WA0,`%P```,Z%`P`C````YH4#`!D````*
MA@,`(P```"2&`P`D````2(8#`(X```!MA@,`(@```/R&`P!4````'X<#`"$`
M``!TAP,`5P```):'`P`F````[H<#`"X````5B`,`80```$2(`P!D````IH@#
M`"\````+B0,`,@```#N)`P`F````;HD#`"D```"5B0,`+P```+^)`P`;````
M[XD#`$`````+B@,`,P```$R*`P`O````@(H#`#\```"PB@,`'0```/"*`P`E
M````#HL#`$,````TBP,`*````'B+`P`M````H8L#`",```#/BP,`4@```/.+
M`P!1````1HP#`#P```"8C`,`1````-6,`P!-````&HT#`!````!HC0,`&P``
M`'F-`P`4````E8T#`'4```"JC0,`"@```"".`P`B````*XX#`!X```!.C@,`
M%@```&V.`P`[````A(X#`"L```#`C@,`$0```.R.`P!*````_HX#`-8```!)
MCP,`A0```""0`P!^````II`#`%4````ED0,`.````'N1`P!Z````M)$#`!P`
M```OD@,`-@```$R2`P`W````@Y(#`#<```"[D@,`*@```/.2`P`2````'I,#
M`,T````QDP,`)0```/^3`P`K````)90#`"0```!1E`,`1@```':4`P`B````
MO90#`!P```#@E`,`60```/V4`P`O````5Y4#`"8```"'E0,`*0```*Z5`P`+
M````V)4#``4```#DE0,`!@```.J5`P`(````\94#`!<```#ZE0,`(@```!*6
M`P`.````-98#``X```!$E@,`%0```%.6`P`@````:98#`"@```"*E@,`(0``
M`+.6`P`+````U98#``\```#AE@,`!````/&6`P`*````]I8#``L````!EP,`
M`P````V7`P`'````$9<#``D````9EP,`!P```".7`P`*````*Y<#``D````V
MEP,`"@```$"7`P`6````2Y<#``8```!BEP,`#0```&F7`P`.````=Y<#``\`
M``"&EP,`%````):7`P`*````JY<#``<```"VEP,`#@```+Z7`P`*````S9<#
M`!4```#8EP,`#0```.Z7`P`1````_)<#``<````.F`,`"````!:8`P`+````
M'Y@#``P````KF`,`%@```#B8`P`/````3Y@#``@```!?F`,`#0```&B8`P`-
M````=I@#`!H```"$F`,`$P```)^8`P`*````LY@#`!0```"^F`,`"0```-.8
M`P`$````W9@#``8```#BF`,`!P```.F8`P`E````\9@#`"(````7F0,`#@``
M`#J9`P`0````29D#`!(```!:F0,`)````&V9`P`1````DID#``D```"DF0,`
M%0```*Z9`P`'````Q)D#``0```#,F0,``P```-&9`P`C````U9D#``L```#Y
MF0,``@````6:`P`5````")H#``@````>F@,`$0```">:`P`1````.9H#``4`
M``!+F@,`!````%&:`P`,````5IH#`$D```!CF@,``P```*V:`P`'````L9H#
M`"\```"YF@,`+P```.F:`P`+````&9L#``0````EFP,`"````"J;`P`<````
M,YL#``4```!0FP,`"````%:;`P`=````7YL#``D```!]FP,`)````(>;`P`:
M````K)L#`"````#'FP,`$````.B;`P`0````^9L#``L````*G`,`#````!:<
M`P`,````(YP#``T````PG`,`*0```#Z<`P`*````:)P#`!\```!SG`,`!0``
M`).<`P`#````F9P#``P```"=G`,`%0```*J<`P`!````&@<``',&````````
M<@,``.H```!,````.P<``-`*``#U`0``FP$``*X'````````'P(``+4$```+
M`@``L`(``)8#`````````````&4)``"H"```7@H``#4%````````````````
M``"4"@``&`$``#4'``#V"@``.0D```````!Z!0``E@<``!4```!Q!```@00`
M`'@*`````````````%4```#*"@````````````!?"P``)@0``$@&```+"```
M804```,+```]"@``@P$``"T*``!_"```<@0``)@#``!E`P``/0(``!@$``"1
M!@``Y04``&0)``#/!@``!`(``/`!````````]`@```4%``!H!0``-0```",#
M```;`0``R0$````````N!```^P<``*$"``"=!0``M````%T%``!Z````OP4`
M``````#K!@``?0<``*`(```F"```=0H``$L$````````OP<```H#```_````
M:@@``-$$``"L````B04``,$`````````E@8````````A!0``9P,```````!;
M`````````,`$``"<!P``GPD``!4$``!8"0``8PD``"D%`````````````.H(
M```/!0```````*((````````Y`@``,4```#*`0```````%<'``!D`P``J@(`
M`'P"````````B````"H"`````````````+$$```+`0``G@```+<%``#@`@``
M`````.0)``!E!```P@```'D%``#P!```8PL```````!I!0``3@(``(@&``!)
M!P``_0$``-L"```G!```1@0``$$!``!"`P``\0H``+H!``#0!0``8P0``*P)
M``!8`@``908``!\```"0!@``'0@``(<"```P"````````)L(``#1`P``$```
M`*P#``"<"```"P4``",$``!-"0``)0``````````````G@$``#\)```I"0``
MOP8``"\+``#5````)0H``)4&`````````````(\*``"T!```IP8```````!U
M`0````````````!P`0``S0,```````"/`0``1@,``-P(````````=@8``)0%
M```2`@``E@0``.8%```*`0``'@0``-<`````````(`<``'P&```H!```A`,`
M``````!#"@``@0H``*\&``!9!0``]P(``*X!````````.0<````'``#,!```
M`````),$`````````````,````!I`P```````"L&```4`0``)08``$8(````
M````2@D``!$"``#^!0``````````````````W@@``/H!``"U!P``+@,``,,'
M```G`P``(@$```````"7!P``U@0``%\(``"2`@```````),&``#["0``[P``
M``````"/`P``GP(``'$!````````T@,``!H$````````B`D``)P"````````
M*0(```````##`0``F0(``$D(``#U"@````````@+``!="```8@<``&X%````
M````V`<``"('````````8@$``$@)``!%"0``40(``#P*``#H"@``,P,`````
M```B````.04```````#+!```G`H````````E`0``2@<``%4(``!/`@``MP0`
M```````*"P``O@,```````#J"@``<@``````````````B@0``)X$``#E!@``
M^`(``/((``!6"0```````,L#````````CPD``),*```9!0```````"P!````
M````5PL````````Y`P``[08``$4%```T!@```````&X*``"S!@``E`8``/P*
M```^!````````,H'``!,"0``_@D``*\"``#&"@```````%X```#W"0``J08`
M`-P$```T"```RP8``"P%``"V````8@L`````````````U0D````````/!```
M4`L``%D`````````1`,``-T*```````````````````<`@```````'4#```5
M"0``VP0``'L(``#'`@``L0<````````4!0``204``````````````````"H(
M``!+"P``H`H``)`%````````\`,````````R`@``0`4``/@'``#5!@``40D`
M`!8&``#Z"0``NP(``(P"``"+!```>@$````````&`0``T`@`````````````
M`````%,!``#W`0``P0,``((%``!-`P``@0,``/T&``!\````````````````
M````/@<``-D````X`@``.`8``+H*``!4!P````````````!@!0``H0@`````
M```G````````````````````50H``'H(``#%`0``L`````````"-````%@<`
M`/<$````````L@4```@'``#V!```C`@``'@&``!2!P``\P@``(D"``"W`@``
MO`$``(\$``#("0``[PH```````#)"```G0D``+@'```"`P``>P```&@+````
M`````````.<&``#R"0``3@H``.\!``#@"```\@H``&8"```_`P``RP```*8*
M````````J0```%P`````````?`<``````````````````(D#```7`@``````
M``````#6`@```````#0"``!@"0``8`8``+8!``#3`P``````````````````
M$`@``!L%``#2!P``B@4``"X"```,!0````````````!#!@``U0$``%$`````
M````4@H```````"Y!P```````!T'``!I!@``U0<``$(&```W````BP8``&,"
M```N!@```````'@$``#V`P``ZPH``&@)``#\"```:0D``)P`````````*0``
M```````@"@``*0,``,X!```G"0```````)(!``#]!P``/@H``)$%``"A````
M5PD``)<#```>!P```````-8%``#\`0``O`<``/P)`````````````"0(``#G
M`@``A0(``$(!``!*"@``X00``!T&````````5`H```L+````````4@D``%,'
M```M!```W@D``+\```!["@``>P(``#P'``"@!```B0<``)H%``"`"@``Z`<`
M`)H)``!M!@``"@H``&T"``#0!@``VPD``"\(``#B!0`````````````4`@``
MWP4``,L)`````````````,D%```'`@``O@8````````:"P``<P4``%D#``"W
M`0``U`$``-,*``#,`P``\`8`````````````#0D````````1!```Z`D``$<)
M``"#!0``4`4``"````#J`0````$``(T*``#H!0```````+,%``!&`@``W@H`
M`"\)``#$````/@4```,)`````````````)4!```(`@````````````#@"@``
M`````*T&``#,!P``'````,$(``#]!0``FPD``&\"````````;P$`````````
M````80<``"P```!2`0````````````!(!```RP$``#$!``"D!```#`$`````
M````````1P8``"0)``!>`0``80D```````#3`@```````)(*``!'"P``K@0`
M``````!U!0```````&()````````6@8``"<&``!J!P``6`<``(0&``"9"@``
M:0$``!`&``#."```)@$```\*``"L!```;0@````````3"0``20L``+@#````
M````L`@`````````````IP(``&8#```T!P```````+<```!'!0``@08``.X)
M``","@``50(``+T%``!<"P``5@```(T"``#I"@``:`,```<```!2!0``Z0@`
M`"4+``#E"@``-0(``!\*``!%````:0L``,,```!``P``-@@``.$%``"9`P``
MI@D``#T%``#Q`P```````-()````````HP<``*D%````````(`D``'0(``#S
M!0```````.P)````````^P8```````"!"````````-P*``!/`````````-,$
M```1"0``#@,``(H!``#L"@``G@<``%T'``#_`@``P`@`````````````F`(`
M`'@!``"]`P````````````!5!0```````.$```"^"````````+@`````````
MNP<``&L*````````Q@@``-\'``"U"0```````!L&``!A`````````,H(````
M````SP@``#X`````````-`4````````/````:P$``/0&```("````````"L%
M```&!P``Y````&H&````````?@@`````````````P`<``'X&````````!PL`
M`(,```#G"@``;0H``"L#``#9"````````"L```!Y!````````&P)````````
M%`0``&\%````````,08``#8)``"T`@``8`@``%8&``!3!```^0H``!0)``#]
M!```;@$```````#6`P``<@@``(X!``#F`````````'H)``!@"@```````"@#
M``"^!P``)0D``(P!```?`0```````(8)```5`P``B`<````````5"P``>```
M`)P$``!V!P``!P<``(,&```O!P`````````````1````!@4`````````````
M70,``#D`````````]00```````!?!```0@@``,,&```W!@``2@@``$H#````
M````JP<`````````````,@D``-P&``#A`0``2`4``'@'```""````````"X)
M``!K````T`,``#D$``#B"0``P00``/0"``#?"`````````X(``!O!`````0`
M``````#L`0``M@H```("``#,!@``N`8``````````````````&,*```*!@``
M`````-H```":`@``\`4`````````````&@(``#D"`````````````$<(``!7
M!```VPH``/@*``!W!@``8P8``*0&````````&0@````````_!P``I@$`````
M``!J````6@4`````````````J`$``#H#``"6"```G`8``(D*``!@````_P<`
M`+@"``!6!````````%L'``#."0``V`4``&`$`````````````",*````````
M``````P(````````V0<``*<!````````[@$``(,(``#V````!08```````!.
M`P``T0````````````````````````#K!P``I@4``&\)``#H`0``W`,`````
M`````````````.D'``#8"@``Y0D```0`````````^PH```````!%!```````
M``````!]````KPH``)L*``":!@```````#L(``!Z`P````````````#O`P``
MN@0```````#$!P``Q`H```````#B!```F`D``/$%````````6````,T!``"$
M"@``MP,``"0%``#V!0````4````````7````V`$`````````````'@@``-0*
M````````=`(````````I!@``C0$``)8`````````YP<``$`+``#\`P``D@8`
M``````"%!@``(`(``.@"``#<!P``[P<``'<*```8`P``QPD``%<&````````
M6@,``#L$``#."@``2P<````````S"P``BP<``$0'``#*"0```````/$!``#=
M!P``D0H```````!K"0``?08``)(`````````4`8``(`"``"("@``BP``````
M``#(`P``R08``(`%``#&"0``N@@``/L"```P"P``2P4``)8)```-`0``O@D`
M`.`%``#[`````````*4$``"&!P``B`@``/,```!#!```F0D``'8)````````
M````````````````>P8`````````````````````````````?`H``%8+````
M````00D``&L$``!4!@``NP,```````!P"@```````.X$``"0!```L04``(<'
M``"^"@``'P<```,%```#`P``6PL``*$%``#O!@```````#T!``#2"@``````
M`*H&``#7`0``N`4``&0+```P`P``3`<``(,"``"X"0```````!L$````````
MPP@``!(%```'"0``^00```````!,`0``#@4```0!```J"0````8``"H+``!0
M`P``V0(``&X&``#$!0``0P,``&@(``````````````````#O"0```````-4%
M````````K0(``!<*````````=0(```````!P!0```````,\*```H!@``F`0`
M``````"N"0```````)L$``"D`0``D0(``/T*```X`0``A0$``(@%``#Z!```
M[`0``"H!``#E!P``<````),'``"D!P```````/H&```1!0``!`0``&((``#`
M"@``L@(``/@$``#D"@``V0,``,<'``#"`P``M@D`````````````U`4``%\#
M````````/P8``)H````"!P``O`(``#H)``!``0``R0H`````````````````
M````````````80@``&P$```7"```!P,````````\!0``N04```````#*!@``
M`````)P)``"2!P```````(,'``">!@```````&@!``"V`P```````($!``!^
M"@``F04``"L"```1"P``J`,``)0(```H"P```08``.`'````````Y`4``$X'
M```P!P```````/8(``"I"0```````,<#````````'@$```````!G!```````
M`#X#``!D"```40<``)X(`````````````/X&``!;"@```````/H"````````
M=`0```````"8!P``M`8```````!_!P``\@,```P*``"J"@```````!,#``!-
M!@``?@4``'D(````````HP8``(,$``!!"P``K`H``'`$````````G0H``%$+
M``"C`P``UP<``",!````````+0D``%D(````````,P$``,\)````````2P``
M```````."0```````*,`````````80(``/<````]"P``.0$```````!V````
M)P4``+8(``"N"`````````````#7`P``\@<``$4#````````+`(````````+
M!P```````+$#````````"00``+,)``!O!@``>`(``#T)```_!```AP```#4+
M````````_`8``````````````````/T#```["P``408``)T$``!Y````CP``
M`(\%````````R`8``%(&```H"```?`4```````#7"@``(@L``$$$``#Z"@``
M````````````````I0````````"O!```[@@``*L```"'`P```````$@!````
M````V`D``/`"``#[`0``^@@``(<&``!Q!@``&PD``!8`````````@0D``)T!
M`````````````*P%``"'"0```````.,(`````````````$<#````````````
M`*,*```*"```=0@``*4#`````````````+D*``"`!P``Q@(``.(#```N"@``
M?P8``$$#``!1`P``````````````````5@,``$$'``!;!@``IP@`````````
M````1P(```,"``!!!0``^`D``$@"``!4````W`(``$0*``!Y!P``T04`````
M``#.!```U@```"0*``"W!P``(@4``,D)```P"0``S08```````![!P``$`4`
M`&4'``!Q`@```````'\"``!1"@``!@H```````!J`P```````"T&```G"@``
M`````)$(``!*`0``D0```-0"``#6`0``,@$``+$)``"`!```$0$````````O
M`P```````/X````:"```D`(```4'```U`0```````$H+``"?"```:0<``,0#
M``!F!P``2P@```````"`"0``O`H``.D!``#@"0``\P<````````!"```````
M`*4'````````.`,``+(`````````9@@``(('``#T!```J@0``$0)``#9"@``
M.P(````````@`0``0PD```H)``"B`@``Y`$``*8(````````70D```0(``!G
M````U````+`#``!^```````````````""P``'`<``&P%```R````I`H```\'
M```-````GPH``/<(``"I`P``Q@0```4(```B"0``8@```%X&```;````T`<`
M`$T+``!-!0``#04``(````">`P``A0```.4!```9"0``P`,``%0"```<`0``
ML08``$8+``":`P``EPD``!H*```.!```?`@```````"N!0``.PD``%L!```>
M"P``DPD``+0'```^"0```````#,$``#N`@``9`4``-\```#"!@``U0H``!<%
M``#Z`P```````*X```"A"0```````)((``#1"@``&@4``#8#```J!P``]P<`
M`$P"``!*!```)04```````!?"@``H`8``"D+````````*@4``(`!``"I!P``
MVP```)0)````````J`<````````C`@``2P$``+L%``"8"```0@D``/P'```'
M`0``X`8``.,$``#)!P``OPD``.(````7`0```````/D&``!X"0``?P,`````
M``!?!0```````$D)```C"```.`H``.8"``"@`P``EP```(P#``"C`0``-`0`
M```````D!P``8@0```D```#^`0``(00``*<$```=`0``3PD`````````````
MV@4``-`)````````'PD``$$(```;!P``W0,`````````````WPD``(T&````
M````.0L``.8$`````````````,@*````````C@,``%`(``!F"P```````!0`
M````````A`@`````````````W0@``%P)````````1`0``)`)````````````
M``````#_`P``30(```````"]`@`````````````Z"@``"08``'$*``!Z!P``
MJP0``.`#````````2PD``&0*```(!0``+`<````"``#/`P```````)$'````
M````'0```,\'``!`!@``Y@<``(P)``!-!```]0@``,L%```A"```6P,``(H'
M````````E0D```````!O"```=P@``$4(`````````````%T+``!:````````
M``````!9`0```````"T'````````&`<``,8%``#T`P``P0$``+H'```F"0``
M)0,``/,*``!>!0````````````!F"@``@@,``!(&``!%"P``1`4``.T)``"J
M`P```````"$)````````O`4``-@"``!G`0``_0@``&$#````````F@H``&H!
M``!)`@``W@0``*(#```S````7P(```L````J```````````````"!@``\P(`
M``````"(`P``9`(``+8$```[!@``M@8```P)``#'"@``+`@```````#7`@``
M``````````#C`P``I`4``"P)```G`@``+@<``/`*```(!``````````````:
M````=`H```````#7"```]04``$P*``"(`@``"P8``,4%````````W@$``'H$
M````````````````````````-P@``+@(``"T`0```````)L#```E"```<@$`
M``````#4"0``_P8```````"9````IP<``!,"``"G!0````````````!M````
M`````#<*````````+@4``&(*``"5!P``^0<```````"K"@```````'(%``"A
M`P``(`4``$\#```=!0``=````)X*``":`0``:P4``+T!````````C0@``,T(
M``"O`P``.@```/\(``"L!P``PPD``!D#```E!P``(@0```````!+!@``````
M`*T*``#S`P``QP0``,X'``"."@``\PD``.P```!/"P```````$$"```*`@``
MX````"H$````````BPD``#@)````````0PL```($```3!```#0L``"8&```F
M"P``700``!T+````````Q`0``(X(````````^@<```````"4`0```````)\&
M```;"````````(X'``#4`P``Q@8``%H$```8`@``]@<``&,%``#G"0``````
M`)\!``"\!```T0(`````````````I`````````"'!```:P8``,T$```=!```
M``````$!``"\`P```````!<'``!V`@``$@H``#0#``!"`@``X@8``*,)``")
M`0```````#\%```T````T@8```````#.`@``O0@``!`'```4"@``500``-\*
M```V"@````````````#E`@``K0$```@#```8"```A`0``',$````````Q0(`
M``````!""@``-@$``"\%```;"@``Q`(```````!W"0```````!D+``""!@``
M`````+`)```-!```/@L```````#-"0``P04``.(!``"P!P``70H``!L"``"+
M`@```````/$)````````R`@```````#A`P``_0D``+T&````````X@H`````
M``!G"P``W0D``(,#``#=!```9P(``#L!``#K`P``<PD```````#)!```6P@`
M````````````]`H`````````````#@L``$(```!S"```HP4``(4'```P!```
M3@8``/P%``"3`0```````/,!`````````````-,)``"Z!@``%0@``$T'``!C
M"```'`8``````````````````+L!``!E"@``E`0```````!X`P```````/0`
M`````````````(H#````````K@,``,0&``!&````:0(``&0!```C````T@@`
M`#X"``#;!@```````*P&```[`````````-8(``#1"```C@4``.D```#%!P``
M>0D``#,%````````3`L```````!&`0```````&,#``"?`P````````````!T
M`P``L0H``"\&``!G!0``6`8```````"=`@``7@(``%0$```2"P``&0<`````
M``````````````````#:`P``JP,``#\(```>"@``0P<````````9````YP0`
M``````!'!P```````-@&``!?````$P`````````'!```#`L``#$*`````P``
M```````````B"@```````"8#```>`````````.L(```X!```````````````
M`````````/$&``#G`P``:@0``%P(``"&`0``Z`8``'`)```#`0``1`8``.,`
M``````````````````"P!0``I`@``.T````P!0```````)($``!X"```,P@`
M``````!H`@``E````,,%``"\`````````!4*````````WP,``%8'```H`0``
M(08``#P&````````H@<``$`)```P````#@H``*H'``!]"0``'`4```$#```W
M"P``>0(``-`"``"Z`@``>0$``"4$``!8"P````````````"Y````M0,```$*
M````````Y@D````````"````DP,``'T*```Z!0``N0,````````2!P``_PD`
M``P$````````60L``+,$````````T0<``$D*``#K"0`````````````2`P``
M``````````#%!@```````,T%```="@``7`8`````````````(0<```````#1
M!@``?PD``!\(``"T"@```````&<)``!"!0``Q0,``-D!````````^```````
M````````/0<``'X$``#C"0``Z@4``&P'````````````````````````@@``
M``````#!!P``K0,``),"``!U"0``5P4``#@`````````!PH```````"S"```
MV@<````````X!P``E@$````````Z"P````````````!Z!@``[@,``.("``"U
M!@``/PL``````````````````/D#``"1!```6@(```(%````````MPD`````
M`````````````,8#``!L`P````````````"G`P``3@L``)4(``"O"```+P``
M`!@)``!T"0``/@$``#L*````````<0````````!(!P``$@0``!@&``"Q````
M``````````![`P``S@,``#P$``#\!```D0D``(`&``#_!``````````````I
M!``````````````1"@``H`$``,T*``"I`@``G@(``$<```!:"@``````````
M```("0``#0<```````"X"@``#P8``#P(``"?````\````-0&``#"!0``W`D`
M`$P$````````^@4```````"7!0``O@4``%X'````````)@```*,"````````
M`````/$$````````;0$```````!F`0```````&P"``"I"```B@8```8#```0
M`0```````*\)``!U!`````````````"*````;0,``-,```"[````"`H``!4%
M``"1`P``-@0``/D`````````/PH``+0%``!N`````````&<'````````````
M`,\"``#S!```S@````````"'"@``V@@``(0"``!V"```9@```!4&```M"P``
M-@8``````````````````($'``"Z!0``D`<`````````````60H``"L(``#X
M!@``R`(``'$%`````````````*@&````````\@```-H!````````1@<`````
M``"K"0```````'D*``!7"@``AP@```````!0````%@H``)4#``"0`0``JP$`
M`,@!```7!@``A`````````#A!@``]`4``(0%````````4P8``(D)``!9`@``
M`````%0!```6`P``(PL``"T#``#,!0``4P```+((````````,@<``)0"``#U
M`@``(@,```````"6`@```````,$)``!E"P```````````````````````!0(
M``#K`0``B0```+T*````````I@0```````#]`@`````````(``"_"@``````
M`$D#```U"0``;@0``#P#``!;"0``$PL``$H%````````_@@``-0'``"5!```
M)`,``*P"``!R!P``C@(``&@$```*!0``/@8``"$"``````````````4#```!
M!P``L@8```````"Q`@```````.H$```/`@``DP```,\%````````````````
M```W`@```@$``!8%```(!@``PP0`````````````W04```````#&!P``M0$`
M`)`(````````0P@``+`*```(`0``+`8``&H%```G!P``Z0(``)H'````````
M,0(``&$*``"9!@``1`$``%$$``!G"@``J@@```````""!```-P0```````#M
M!0``!@L``"T"````````S@4``.$)``"E!0``T@(``&X(```'!@``:P,``'P#
M``"O````2@8``!L#```Q"0``S`D``&0$``!]!0``BP$````````O`@``````
M`/(!```-`P``U0@```````!;!```Q`D``/4#```&`@`````````````#"```
M6@D```````#;!0``\0@``#T```#+"```J0$``.<(``"[!@``-@4``.<!``#,
M"```80L``,<````6"`````````````#N"@``+P0``$P#``````````````4`
M```I"@``200``#H$`````````````,`)``"8"@```````'D#``#I!@``2P,`
M`)T#``#>````F`$``.<%``#;!P``_P`````````7"P``.@@``&T)``!P!@``
M+04``!`#``!8!````````"8"``#M"````````#0*``!`"`````````````!M
M!P``3PH``%@#````````$P4``/(%````````#@$```4"````````.@(`````
M``#"!```_0```-,&``"+!0``Q0D``#L#````````=`<```````"+"```````
M`.0#``!H!@``O@````````"B"0``````````````````A04``.8(``#?!```
M`````)P#```&"0````L``$$```!2"P``RP(``#`&````````-`D``-($``"*
M`@``00H```````#R!@```````.L````?!````PH```````!&"0``<0,``$X`
M``#E"```B@@``%`!````````.0H```````!1!0``G`$``+T)```O`0``)P@`
M`-L#``!0!```&@D``'\$``"=!@``,@8```D!``"R`P``^`$``%(`````````
M`````(P'``"I!```FP```.,*`````````````'<%````````XP8```````#3
M"```ZP4``/,&``#1`0``7`0``(D&```P"@``CP@``*\'`````````````.4$
M```<"P``!@0``)8*``#?`@``10$`````````````IPD```````#7"0``Z0,`
M`*8#``"\"0``#`(````````&````,0```#P+````````Q@$``,4$````````
M````````````````R````!X)``#A!P```````(0!``!L`````````%P!``!<
M!P``@@@``%X)``!H"@``Z04``%@(``"+`P```````+8"````````608``*(!
M``"F````=0``````````````'@(``'<!````````O00``)L%``!M!```OP,`
M``````!0`@``$P@``"L'``!F"0```````#($``!/!P``````````````````
M8@4``.<```"6!0````````\!````````V@0``*,$``!-`````````!`+````
M````[@8``*(&``"&!@```````%0(``"/!P``L`0``,('````````U@H``*$*
M``"-"0````````````!&"@``4`<``&<(``"M!0``EP8````````3!@``.`4`
M``````#'`0``@`@`````````````!0$`````````````9`<``"L$````````
M*@,``-X"```$"P``JP8``!0&```<!```Y@$``+D"``#+!P``Z@<``',!````
M`````````%H!``!E!0``H@4``+D$````````C`4```````!*`@``I0@`````
M```!!```EP(```````!O!P``U00``,("````````LP(``*T(```]"```````
M`'`(````````F@0```\(````````$@$``)\%````````@@$`````````````
M80$``&`+``!V`P``(P4```8&`````````````'(&``#(!P``K0````````"/
M!@``E0(``,0(```)"```````````````````C````*0#``!]`@``:00``"@"
M````````'0(```````#+"@``+@L``*<```#-````=P,```````#D!P``)`L`
M`#$(```P`@``*PH``'$'```0!```"0D``'`#```4!P``@@(``.T#````````
M````````````````600```````"P!@``0`(``-T!``#'!0```````#@(``"N
M"@```````-L(``!=`0```````(8#``!/`0``)0(``&,!````````K0<``/<#
M``#N!0`````````````A````R`0````````L"@``_@,```````"F!P``\@0`
M`#,"````````1````/D(````````E0```/`(```T"P```````$<*``"%"@``
M%@0``#4*````````E0H``-<$``!_````C00``$``````"@````````````!?
M!@``W@<``%($``"W!@``50,``*``````````6@L``)0#````````(0L``#\!
M``!W`````````````````````````!8"````````^@```+T```!3!0``;`@`
M```````9!```V@8````````6`0``TP$``(`#``!%"@``B0@``&`!``!$"```
MMP@```````"+"@``3`@```P&``!1`0``^P4``)D!``";!P``-00``&@````+
M`P``N`$``%<!``!."```WP8````````K"P``QP8``&8%````````,0L``-$)
M``!&!0``2PH````````I!P``3P@``-X#```$!0```@D``,4(````````$0,`
M`"0````!!0``PPH``.H#````````G@4```T*``".!```5`4``'P$```P`0``
M<`(``'<$``!T!@``P`$```````"/`@``LP<``&L'``!R"@``&@8```````!8
M!0````````````"I"@``@PH```````#*`@``_P$``+()```Z`0``&@,`````
M``!9!P``<0@``!X%````````$@```!P#`````````````,$"````````'`@`
M`(8"````````'0D```````"_"```T@$``*X&```#!P``,PD```0*```9!@``
M```````````3`0``0`0````````\`0``PP,``#P"``!)!@``A@4``*0)``#6
M!P```````-L!```-!@```````%$(``!4"0``=08```````#0`0``WP$``%X(
M``"^!```4@@````````M`0``_PH``-4#``#B"```,0<``&X)```1!@``.0@`
M`%T&``!U!P```````/D!``!N!P``L@$```D'````````#@8```````#9!```
MD@4```````!'`0```````*@```!S`P``/00``+L(```9`0``!0D```````!3
M`P```````','```/"P``Z@(``.0&````````+`L``"D(``#M!````````/X"
M````````Z`,``*L(`````````````&D(``#O!```$@D``.@`````````,@4`
M`$X$````````!`,``!,'``"8!@``-P<``!H!``!J"@``^0(``+,`````````
M:P(``$($``#Q`````````!@*``#_!0``"`````````"'!0```````+D&```-
M`@````````,&``"["0``M`,``/L#```````````````````G"P``````````
M``#3!0```````&0```!-"```F0@``-(```",!@```````'()``#""@``#@(`
M`*`%``#O!0``N`0```````#6"0``XP<``,P```#V`@``N@D``+T'``"&"@``
MR@4``*8"``!O````E04``,D#``#3!P``^0D``#P````N"`````````````!_
M`0```````+,#``"A!@``108``*T)````````X0(``(@!``!?"0``P@$`````
M``#Y!0```````$X%``";`@``"0,``+$(````````_@<``$,````\"0``A0@`
M``T(``````````````````#W"@``<`<```````")!````````.,!``!A!```
M`````*4!``!S````C`0```````"@`@``N@,``,,"```+!```,04``)<$``"F
M!@``O`8``,<(````````OP0```````"O`0``8@8``($"`````````````&P!
M``".!@``)`(```````!O`P```````/4&```F"@``G0````````#\`@``V`,`
M`+X"``#M"@``+`0``)X)``"B!```*@8```````"J````8`(```````!>"P``
M)P$```````#L!@``*`<``-P```!5"P``>@(`````````````"0L``&X#````
M````P@D``%8%```C!@``G0@```````!%!P``(@8``&\*``"A`0``K@(`````
M``"P`0```````&4`````````.`L``'H*```?"P``X0H``*4"````````A00`
M`%8!```6"P``+0```+,!```<"0``0`<``,P!``"E"@````````4*``#T!P``
MV04``'\*````````)`8```````"!!0``M0H``,H`````````4P(``$,!```#
M!```$PH``/0!```A"@``0P4```P`````````[`(``.L"``"."0``Q0H``%8"
M``!@!P``N0$```````"J"0```````!`*``!/!@```````'D&``"E"0``````
M`&P&````````50<``)(#````````20$``-@````.````@0````````!("@``
M@PD``%8(``#$`0```````*0"```H"@``.P4``%`*```V!P``R0(``&`#````
M````?00``!X#``"?!P``O@$``!<)``"Z````A@0``,T"``"$"0``R`4``$$&
M```A`0``J`H``*$$``"7`0``>P0``#,*```S!P``M0@``((*```?!@``-P$`
M```````Q`P``R@,``%@*````````20```'X)```W"0``8P```&$&````````
M*`4``#4#``#F"@````````````#W!@``[0(``,`%``!+`@``P`8``$@+``"3
M!0``50D````````7`P``0@<``"$#``#M`0``K`@```````"K`@``$@@`````
M``"J!0``ZP0``.T'``#L!P``-@(``+(*``!^`@``=@4```````!C!P``FP8`
M`/8!````````]@8````````!"0``0@L``*H!``!4"P``F00``+\!``!E"```
M-0@``#X(````````1`L``/4)``"&``````````````#Q!P```````%D)````
M````!`D``.0$``"2"0``V`0``%P#````````MPH```````#,`@``B@H``$8&
M``#/`0``H`<``$@(`````````````#0!``#R`@```````"`&````````W08`
M`-D&```U!@``?0@``'X'``!3"0``SP```(()````````#P,``&X"```5`0``
M%`,`````````````A@@``)D'```@!```&PL``)H(```R"```:@(``%\'``!F
M!```!@@`````````````(`L``-4"```M"```$`D``"8'````````I08`````
M``!2`@``8@(``%,(``#-!P``30$```$+```J"@``````````````````W`4`
M`%X$``!Q"0``!P4``'\%``!,!0``W0```,8````V````?`D``!T#``#O"```
MEP@``'X#``!D!@``]`D``'0!``#>!0```````"@)``#2!0``````````````
M`````````&@'``!S"@``F`4``)0'`````````````+D(```5!P``!0L``,$&
M``#U````V@H``+('```%!````````.8&````````)`0`````````````$`(`
M`&D`````````7`(``%8*```4"P``Z00``.('``"-`P``G0<``%T```#!"@``
M`````!4"``#N!P``*P$```H`````````U`0``-T"``#[!```N0D``-<%``!>
M`P````````````#E````8@,``'8!``````````````L*``"L`0``````````
M``!I"@``KP4``&4!`````````````+,*```@"```$0@``.H&````````Z0D`
M`)`*``!(`P```````/X$````````#`,``&H)``"3"```A0D``-<&``!.`0``
M`````#(*````````D`,``.`!`````````````"X```!/!0```````!$'``!M
M!0`````````````@`P``5P(````````N`0```````%,*```R"P``H@```(<!
M```$!@```````(0'```]!@``1`(``+\"```S!@``1P0``%H(``"R!```Y0,`
M`"((````````S`H```````#>!@``90(```D*``!T!0``(@(```````#W!0``
M,00```````#P"0``D0$`````````````SP0``%@!``#A"```-P4``'L)``#@
M!````````/$"```W`P``V`@``.0"``!;!0````````````#L"```S@8``.,%
M``#["```.@8``,`"```.!P``)`$``.,"``"<!0``````````````````5P,`
M``````!\`0```````'8*``#0!```]@D``!8)``#F`P``70(``/@%````````
M#`<``!D*``!<!0`````````````V"P``<P(```<(``"V!0``9P8``!@+```"
M"@``(PD``%4&````````:P@```0'```````````````````?!0```````*<*
M``#)````M`@``.@$````````?0,```,`````````[`,```````#J"0``````
M`"D!``!7"```;`H```````"U`@``5P````````!5`0``4PL``!@````]`P``
M#PD``$T*``!?`0```````/@(```F!0``*PD``%0#````````0P(`````````
M````+`,```````#""```&`4```````#4"```M`D``,H$``!0"0``]0<``!<$
M``"(!```M0```(T'``!,!@````D``*@"```+"0``?@$``*$'``"V!P``,@,`
M`*@)``````````````````"B"@``HP@``(T%```O"@``"@<``'L!``!F!@``
M_````'L%``#^"@``"@0``.P%``#:`@```````/@#````````3P0``!X&``#9
M"0``NPH``%(#````````Z`@```D%``!X!0``M04``%H'``!(````A0,``(H)
M``#N````\`<``*T$``!;`@``V@D``+P(``!V!```10(``%P*```<"@``````
M`*@$`````````0(`````````````U@8``-P!``!`"@``&0(``(X```"Q`0``
MNP0```````"?!```[P(```````````````````````"7"@````````````!.
M"0``=P(``'("````````T``````````)`@``.08``'<'```?`P``JP4``)@`
M```H````(P<``#\"```Z!P```````*`)``"H!0``?0$``$H```"0`````"`@
M("`@($-C.B``("`@("`@5&\Z(``@("`@1&%T93H@`"`@("!&<F]M.B``("@E
M<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT
M;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!3=6)J96-T.B``(&%T
M(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B
M('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R
M96%T960Z("5S+@`C`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E
M+C)F)24I`"5D("5S(&%N9"`E<P`E9"!-97-S86=E<P`E9"!D87ES('5N=&EL
M('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60@;65S<V%G97,@:&%V92!B965N
M(&1E;&5T960N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S
M86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN`"5D(&UE<W-A
M9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M+@`E9"!T;R`E9"!O9B`E9"!-97-S86=E<P`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N
M(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`
M)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N
M86UE9"X`)7,@870@)7,@)7,`)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@=&AE
M('-T87)T(&]F('1H92!M;VYT:"X`)7,@:&%S(&%C8V5P=&5D+@`E<R!H87,@
M8V%N8V5L;&5D("(E<R(N`"5S(&AA<R!D96-L:6YE9"X`)7,@:&%S(')E<&QI
M960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="X`)7,@:&%S(')E<&QI960@=&\@
M=&AE(&EN=FET871I;VX@=&\@(B5S(BX`)7,@:&%S('-E;G0@>6]U(&9R964O
M8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S('1E;G1A=&EV96QY(&%C8V5P=&5D
M+@`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R
M871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O
M<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N
M`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!R
M97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@<F5Q=65S
M=',@>6]U<B!P<F5S96YC92!A="`B)7,B+@`E<R!T;R`E<R!O9B`E<P`E<R!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O("(E<R(N`"5S('=I<VAE<R!T;R!A
M;6UE;F0@(B5S(BX`)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("(E
M<R(N`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I
M;VX@86)O=70@(B5S(BX`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A
M<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,@*"5D)FYB<W`[
M;V8F;F)S<#LE9"D`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@
M=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY
M(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@
M86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`H07!P;'D@=&AE<V4@8VAA;F=E
M<R!A;F0@;6]V92!T;R!N97AT('-C<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N
M9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BD`*$A434PI
M`"A0;&%I;B!497AT*0`H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A
M9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA
M;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE
M9"XI`"A396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@
M;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N
M('=I;&P@3D]4(&)E(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN
M9R!/2R`J`"H@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN
M9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M
M+2!S96QE8W0@+2T`,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N`#$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86TN`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G
M92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+@`Q,#`@8VAA<F%C=&5R<P`Q
M,#`P(&-H87)A8W1E<G,`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`
M,C0@:&]U<G,`,C4P(&-H87)A8W1E<G,`-3`P(&-H87)A8W1E<G,`/%!R979I
M;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!L87)G92!I;6%G
M92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N`$$@;65S
M<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N
M;W1I9FEC871I;VX@9G)O;2!T:&4@<F5C:7!I96YT+@!!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!
M32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@
M4VYO=R!3:&]W97)S`$%-+U!-`$%.1`!!4$D@240`06)O=70@=&AI<R!E9&ET
M;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'0@86YD(&%D
M9"!T;R!M>2!C86QE;F1A<@!!8V-E<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E
M<'1E9#H@`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O
M<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O
M=6YT)W,@;F%M93H`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@)7,@=&\@
M;7D@061D<F5S<R!";V]K`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R
M;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI
M<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`
M061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!S;W5R8V4`061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A
M;&5N9&%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S
M(&)O;VL`061D('1O(&UY(&-A;&5N9&%R`$%D9"!U<V5R`$%D9&5D("(E<R(@
M87,@86X@871T86-H;65N="X`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B
M=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO
M;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@
M:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA
M;"P@96YT97(@96%C:"!H96%D97(@;VX@82!N97<@;&EN92D\+V5M/@!!9&1I
M=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N`$%D9&ET:6]N
M86P@:6YF;W)M871I;VX@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T
M86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D
M("5S+@!!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<P!!9&1I=&EO
M;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!
M9&1R97-S`$%D9')E<W,@0F]O:P!!9&1R97-S($)O;VMS`$%D9')E<W-E<R!T
M;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H
M(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/@!!9&1R97-S97,@=&\@97AP
M;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@
M96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3X`061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI
M<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA
M<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R
M<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!
M;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B
M92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@9FEL93H`06QL(&UE<W-A9V5S
M(&EN('EO=7(@(B5S(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@
M8F4@<&5R;6%N96YT;'D@9&5L971E9"X`06QL(&]L9"!L:6YK960@871T86-H
M;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D
M+@!!;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT
M:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL(')I9VAT<R!O;B!F;VQD97(@
M(B5S(B!S=6-C97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B`B)7,B+@!!;&QO
M=R!&;VQD97(@0W)E871I;VX_`$%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A
M<'!L:65D(&EN(&%N>2!M86EL8F]X/P!!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D
M>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@
M4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M
M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X
M=#H`06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CH`06QW87ES
M`$%L=V%Y<R!S879E(&%T=&%C:&UE;G1S`$%M97)I8V%N(%-A;6]A`$%N(&5R
M<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T
M86-H;65N="X@5&AE($E-05`@<V5R=F5R('-A:60Z(`!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R
M960N`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T
M:&4@;F5W(&YO=&4N`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C
M<F5A=&EN9R!T:&4@;F5W('1A<VLN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA
M`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`06YS=V5R960@;65S
M<V%G97,`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T
M:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P
M<&QY($9I;'1E<G,`07!P;'D@1FEL=&5R<R!T;R`E<P!!<'!L>2!F:6QT97(@
M<G5L97,@=7!O;B!L;V=G:6YG(&]N/P!!<'!L>2!F:6QT97(@<G5L97,@=VAE
M;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/P!!<'!L>2!T;R!#:&EL9"!3:&%R
M97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN
M9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES(%9I<G1U86P@1F]L
M9&5R($1E9FEN:71I;VX_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE
M=&4@=&AI<R!P=6)L:6,@:V5Y/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D
M(2D`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D
M96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT/P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O
M=7!S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F;VQD
M97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@
M9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T
M<F%S:"!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE
M;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/P!!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S
M<&%M/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!
M<G)I=F%L(%1I;64`07)T`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I;VX@27-L
M86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:P!!<VL@9F]R
M(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&%C:"!&:6QE<P!!='1A8V@@
M82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E
M/P!!='1A8VAE9"!&:6QE.@!!='1A8VAE9"!F:6QE("(E<R(@97AC965D<R!T
M:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N
M`$%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO
M=2!S96YT+@!!='1A8VAM96YT`$%T=&%C:&UE;G0@)7,@9&5L971E9"X`071T
M86-H;65N="!);F9O<FUA=&EO;@!!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG
M:6YA;"!A='1A8VAM96YT('1Y<&4`071T86-H;65N=',`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1E;G1I;VX`071T<FEB
M=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@
M0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!
M=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD
M87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S
M97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2
M041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D
M+@!!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A434P@;65S<V%G97,@
M=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY(&%D9')E<W-B;V]K/P!!=F%I;&%B
M;&4@061D<F5S<R!B;V]K<SH`079A:6QA8FQE(&9I96QD<SH`07=A:71I;F<@
M4F5S<&]N<V4`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C7VL@=&\@)7,`
M0F%C:R!T;R`E<P!"86-K('1O($UU;'1I<&QE($UE<W-A9V4@5FEE=R!);F1E
M>`!"86-K('1O(%1H<F5A9"!$:7-P;&%Y`$)A8VMG<F]U;F0`0F%C:V=R;W5N
M9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U
M<V5R;F%M92X`0F%D(&QO9VEN(&YA;64@;W(@<&%S<W=O<F0N`$)A9"!O<B!M
M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,`0F%D(')E
M<75E<W0Z("5S+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F-C`$)E;&%R=7,`0F5L9VEU
M;0!"96QI>F4`0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@
M:6YF;W)M871I;VX@;65S<V%G92X`0F5N:6X`0F5R;75D80!":'5T86X`0FER
M=&AD87D`0FQA8VML:7-T`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S
M(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQO8VL@
M:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I
M9FEC86QL>2!R97%U97-T960_`$)O9'D`0F]L9`!";VQI=FEA`$)O;VMM87)K
M<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD
M($AE<GIE9V]V:6YA`$)O=&@`0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D
M>2!O9B!-97-S86=E`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R
M87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A
M<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`
M0G5R=6YD:0!#35,`0U)!32U-1#4@;W(@1$E'15-4+4U$-2!R97%U:7)E<R!T
M:&4@075T:%]305-,('!A8VMA9V4@=&\@8F4@:6YS=&%L;&5D+@!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#7VAA
M<G-E=`!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#
M86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@
M<F5M;W1E(&UA:6P@<V5R=F5R+@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E
M;6]T92!M86EL('-E<G9E<CH@`$-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N
M;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R
M96YT(&UA:6QB;W@N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I
M=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L
M($UE<W-A9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;F-E;&QI;F<@=&AI
M<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N
M=',N`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A
M<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES
M;&%N9',`0V,`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D
M:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`
M0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!2
M97!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I
M8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&
M:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BX`0VAA
M9`!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG92!!;&P`0VAA;F=E($9O;&1E
M<@!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@9&ES<&QA>2!O<'1I;VYS
M('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A
M9V4@86YD(&AO=R!M97-S86=E<R!A<F4@<V]R=&5D+@!#:&%N9V4@;6%I;"!S
M97)V97(@86YD(&9O;&1E<B!S971T:6YG<RX`0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG92!T:&4@;F%M92P@861D<F5S
M<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6PN`$-H86YG:6YG('EO=7(@<&%S
M<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I
M9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#
M:&%R86-T97)S('1O(&1I<W!L87DZ`$-H96-?:R!,:6YK+BXN`$-H96-K($9O
M;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAE8VL@7T%L;"].;VYE`$-H96-K(&%L
M;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.@!#
M:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_`$-H:6QE
M`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*0!#:&]O<V4@06-T:6]N.@!#:&]O<V4@07!P;&EC
M871I;VXZ`$-H;V]S92!A(&UA:6P@<V5R=F5R.@!#:&]O<V4@82!M871C:"!O
M<B!E9&ET('1H92!A9&1R97-S('1O('1H92!R:6=H=#H`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L
M:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D
M:6YG(&%D9')E<W-E<RX`0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O
M;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`$-H<FES
M=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@
M;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R
M:6YG($QA=&4`0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I
M;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RX`0VQI8VL@)7,@
M=&\@9&]W;FQO860@=&AE(&EM86=E+@!#;&EC:R`E<R!T;R!G;R!T;R`E<R!M
M86YA9V5M96YT('!A9V4N`$-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT
M(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W(&$@=&AU
M;6)N86EL(&]F('1H:7,@:6UA9V4N`$-L:6-K("5S('1O('9I97<@=&AE(&%T
M=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N`$-L:6-K("5S('1O('9I
M97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@
M=VEN9&]W+@!#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM86=E<P!#;&EC:R!O
M;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N
M('-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"X`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E
M<W,@8F]O:P!#;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O9B`E
M<R!I;B!Y;W5R($%D9')E<W,@0F]O:P!#;&EC:V%T96QL('9I82!(5%10`$-L
M:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S
M86=E('1O('1H92!S96YD97(`0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL
M;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860`0VQO<V4`0VQO<V4@5VEN
M9&]W`$-L;W-E('1H:7,@=VEN9&]W`$-L;W-E9"!&;VQD97(`0VQO=61S`$-L
M;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L
M;&%P<V4`0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&;VQD97)S`$-O;&QA
M<'-E($9O;&1E<@!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]M8FEA`$-O;&]R`$-O;&]R($EN9&EC871O<CH@`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O
M;6]R;W,`0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!A;F]T:&5R(&UE<W-A
M9V4`0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\`0V]M
M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF
M(&)R;W=S97(@<W5P<&]R=',@=&AE(&9E871U<F4I/P!#;VUP=71E<G,`0V]N
M9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#
M;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N
M97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M`$-O;F9I9W5R92`E<P!#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P
M;&%Y960N`$-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RX`0V]N9FER
M;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE`$-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0('-E<G9E<BX`
M0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYN
M96-T:6]N('1O('-E<G9E<B!F86EL960`0V]N=&%C=',`0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O
M;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B
M)7,B`$-O;G1I;G5E`$-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+@!#;VYT
M<F]L(%,O34E-12!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!O<'1I;VYS(')E
M;&%T:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RX`0V]N=')O;"!W:&5N(&YE
M=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO
M="!T;R!N;W1I9GD@>6]U('=H96X@:70@87)R:79E<RX`0V]N=F5R="!T97AT
M=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/P!#;V]K($ES;&%N
M9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N
M`$-O<'D@=&\@9F]L9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]S="!)
M1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R
M>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K
M(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S
M;VX@1VEV96XZ("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z
M("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<P!#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D
M871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D
M96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@
M;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<P!#;W5L9"!N
M;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#
M;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+@!#;W5L
M9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M
M5$Y%1B!A='1A8VAM96YT+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S
M=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C
M;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O
M<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T
M(&]P96X@<V5C=7)E(&-O;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R+B`E
M<R`Z("5S+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O
M=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N
M(&9R;VT@24U!4"!S97)V97(N`$-O=6QD(&YO="!R971R:65V92!S97)V97(G
M<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N
M+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S
M879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@
M8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T
M92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S
M(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R
M("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S
M(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E
M871E($9O;&1E<@!#<F5A=&4@2V5Y<P!#<F5A=&4@82!.97<@06-C;W5N=`!#
M<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!3<&%M(&9O;&1E<@!#<F5A=&4@
M82!N97<@9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@;VYE`$-R96%T92!A
M(&YE=R!S96YT(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE=R!T<F%S:"!F;VQD
M97(`0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN
M8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"!A;F0@9&5L971E
M('-P86TN`$-R96%T92!N97<@<W1A=&EO;F5R>0!#<F5A=&4@<W1A=&EO;F5R
M>2!A;F0@9F]R;2!R97-P;VYS97,N`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A
M=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U
M8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@
M5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A
M=&AE<@!#=7)R96YT(&%C8V5S<R!T;R`E<P!#=7)R96YT(&-O;F1I=&EO;CH@
M`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN
M9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N`$-U<W1O;6EZ92!H;W<@>6]U
M('-E;F0@;6%I;"X`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/
M23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN
M:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N
M:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T7V4`1&%T851R964@0G)O=W-E<@!$
M871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T
M:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E
M<G,`1&5C;&EN960`1&5C;&EN960Z(`!$96-R96%S92!);F1E;G0`1&5F875L
M=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!396%R
M8V@@1FEE;&0`1&5F875L="!3:&5L;`!$969A=6QT('-O<G1I;F<@8W)I=&5R
M:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E
M;&5G871E9`!$96QE=&4`1&5L971E("5S(%!U8FQI8R!+97D`1&5L971E($-E
M;&P`1&5L971E($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E;&5T
M92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!3
M96QE8W1E9"!&;VQD97)S`$1E;&5T92!3=&%T:6]N97)Y`$1E;&5T92!6:7)T
M=6%L($9O;&1E<@!$96QE=&4@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F
M;W(@)7,`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$
M96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4`1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R
M/P!$96QE=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;65S<V%G97,`1&5L
M971E(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/P!$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN
M9R!O9B!M;VYT:#\`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E
M('-P86T@;65S<V%G97,`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D
M`$1E;&5T960@;65S<V%G97,`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="`B)7,B+@!$96QE=&5D('1H92!A='1A8VAM96YT("(E<R(N`$1E;&5T:6YG
M(&%N9"!-;W9I;F<@365S<V%G97,`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;@!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T
M:6]N`$1E=&%I;',`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:60@;F]T(&%T=&%C:"`B)7,B(&%S('1H
M92!F:6QE('=A<R!E;7!T>2X`1&EM('-I9VYA='5R97,_`$1I<F5C=&EO;B!L
M969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R
M>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I
M;VYS`$1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S
M86=E/P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A
M<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&QA>2!I;B!";V1Y(&]F($UE
M<W-A9V4`1&ES<&QA>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL
M/P!$:7-P;&%Y('1H92`B16UP='D@4W!A;2(@;&EN:R!I;B!T:&4@;65N=6)A
M<C\`1&ES<&QA>2!T:&4@(D5M<'1Y(%1R87-H(B!L:6YK(&EN('1H92!M96YU
M8F%R/P!$:7-P;W-I=&EO;@!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II
M8F]U=&D`1&\@3D]4(&UA=&-H`$1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R
M($YE=R!-86EL`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'``1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T
M:&4@1G)O;3H@8V]L=6UN`$1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD
M97(_`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N
M(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]N
M90!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"`E<R!I;B`N>FEP($9O
M<FUA=`!$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92D`
M1&]W;FQO860@1F]L9&5R*',I`$1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F
M;W)M871=`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N`$1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T`$1R869T`$1R869T
M(&9O;&1E<@!$<F%F=',@9F]L9&5R.@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%
M+4UA:6P`12UM86EL($%D9')E<W,`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I
M=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N
M`$5.1`!%4E(`15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L
M:79E<F5D+@!%8W5A9&]R`$5D:70`161I="!";&%C:VQI<W0`161I="!";&]C
M:P!%9&ET($9I;'1E<G,`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I
M="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(%-E
M87)C:"!1=65R>0!%9&ET(%9I<G1U86P@1F]L9&5R`$5D:70@5FER='5A;"!&
M;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,`161I="!7:&ET96QI<W0`161I="!O
M<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E
M<FUI<W-I;VYS(&9O<B`E<P!%9&ET('EO=7(@8FQA8VML:7-T`$5D:70@>6]U
M<B!F:6QT97(@<G5L97,`161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E
M<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RX`161I="!Y;W5R('=H:71E;&ES
M=`!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%
M;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A
M>0!%;6]T:6-O;G,`16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RX`16UP
M=&EE9"!A;&P@;65S<V%G97,@9G)O;2!6:7)T=6%L(%1R87-H($9O;&1E<BX`
M16UP='D@1F]L9&5R*',I`$5M<'1Y(%-E;&5C=&5D($9O;&1E<G,`16UP='D@
M5')A<V@@9F]L9&5R`$5M<'1Y(%]3<&%M`$5M<'1Y(%]4<F%S:`!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B
M;&4@4$=0(&9U;F-T:6]N86QI='D_`$5N86)L92!3+TU)344@9G5N8W1I;VYA
M;&ET>3\`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'
M86QL97)I97,@:6X@=&5X=#\`16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_`$5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N8W)?>7!T:6]N($]P
M=&EO;G,`16YC<GEP=&5D`$5N9`!%;F0@9F]R=V%R9&5D(&UE<W-A9V4`16YD
M(&UE<W-A9V4`16YD(&UE<W-A9V4@9G)O;2`E<P!%;F0@>65A<@!%;FQA<F=E
M($5D:71O<@!%;G1E<B!087-S<&AR87-E`$5N=&5R(&$@<V5C=7)I='D@<75E
M<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@
M=&AE(&QE='1E<G,@8F5L;W<Z`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE
M=R!3<&%M(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A
M9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N="!M
M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@
M9F]L9&5R`$5N=&ER92!-97-S86=E`$5N=')Y("(E<R(@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K`$5Q=6%T;W)I86P@1W5I
M;F5A`$5R:71R96$`17)R;W(`17)R;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E
M<G9E<BX@)7,@.B`E<RX`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!S96YD
M:6YG(')E<&QY.B`E<RX`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R
M<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%
M<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E;G0@<W5C8V5S<V9U
M;&QY(&1E;&5T960N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S
M`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN
M`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z
M`$5X96-U=&4`17AP86YD`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S
M`$5X<&%N9"!&;VQD97(`17AP86YD($YA;65S`$5X<&%N9"!3:61E8F%R`$5X
M<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL
M>2!I;B!T:&4@8F%C:V=R;W5N9#\`17AP86YD('1H92!E;G1I<F4@9F]L9&5R
M('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/P!%>'!A;F1I
M;F<`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1E]E=&-H($UA:6P`1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL
M960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N
M`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D
M('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER
M`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A
M=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L
M<R!L:6ME.B``1F5T8V@@36%I;`!&971C:"!-86EL(&EN(&$@<V5P87)A=&4@
M=VEN9&]W/P!&971C:"!M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_`$9E=&-H
M960@)60@;65S<V%G97,@9G)O;2`E<P!&971C:&5D(#$@;65S<V%G92!F<F]M
M("5S`$9E=&-H;6%I;#H@`$9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+@!&
M97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I7VQT97)S`$9I96QD(&UA
M=')I>`!&:6=L970@0T%05$-(00!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.
M86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+@!&:6QT97(@3W!T:6]N<P!&:6QT97(@4V5T=&EN9W,`
M1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/P!&:6QT97(@
M<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`1FEL=&5R<P!&
M:6QT97)S($Y/5"!!8W1I=F4`1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E
M`$9I;F0`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T($UA:6QB;W@@4&%G90!&
M:7)S="!086=E`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1F]?<G=A
M<F0`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VQD97(@06-T:6]N
M<R`M($-O;F9I<FUA=&EO;@!&;VQD97(@3F%V:6=A=&]R`$9O;&1E<B!3=6UM
M87)Y`$9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+@!&;VQD97(@=7-E
M(&ES(&YO="!E;F%B;&5D+@!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P
M87-S=V]R9#\`1F]R;6%T(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB
M;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T960@=&]D87D`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9`!&;W)W87)D.@!&;W)W87)D960@;65S<V%G90!&;W)W87)D960@;65S
M<V%G92!F<F]M("5S`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E
M+"!-971R;W!O;&ET86X`1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E
M;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<P!&<F]?;0!&<F]M`$9R;VT@061D<F5S<P!&<F]M('1H92``
M1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9W9#H`1G=D
M.B`E=2!&;W)W87)D960@365S<V%G97,`1V%B;VX`1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@3W!T:6]N<P!'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G
M:6$`1V5R;6%N>0!'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI
M`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O
M`$=O('1O($UE<W-A9V4`1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F("(E
M<R(`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A;G0@86-C
M97-S`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N
M;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`
M1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(15)%`$A434P@
M5F5R<VEO;B!O9B!-97-S86=E`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O
M<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I
M;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93H`2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R
M92!C;VUP;W-I;F<Z`$AI9&1E;@!(:61D96X@:6X@5&AR96%D(%9I97<`2&ED
M92!$96QE=&5D`$AI9&4@56YS=6)S8W)I8F5D`$AI9V@`2&EG:"!0<FEO<FET
M>0!(:6=H97-T`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I
M`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`
M2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B
M)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO
M;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`
M2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@=&\@871T<FEB=71E('%U;W1E
M9"!L:6YE<R!I;B!A(')E<&QY`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I
M<W1S`$AU;F=A<GD`24U!4`!)34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I
M`$E-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E
M<W!O;F1E9#H@)7,`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!O=F5R(%-33`!)34%0
M(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92D`24U!4"!O=F5R
M(%-33"`H<V5L9BUS:6=N960I`$E-05`@<V5R=F5R(&-L;W-E9"!T:&4@8V]N
M;F5C=&EO;BX`24U!4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL(%-E<G9E<G,`
M25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N
M('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@
M3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@
M;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!U<VEN9R!34TP@;W(@5$Q3
M+"!Y;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A
M9&5D+@!)9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L
M9&5R*',I('=I;&P@8F4@;&]S="$`268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)
M9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G
M92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO
M=7(@8G)O=W-E<BX`26=N;W)E`$EG;F]R92!!;&P`26UA9V4`26UA9V4@4')E
M=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y
M`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O
M<G0`26UP;W)T($ME>0!);7!O<G0@2V5Y<&%I<@!);7!O<G0@365S<V%G97,`
M26UP;W)T(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E`$EM
M<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L
M(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF
M:6-A=&5S`$EM<&]R="!0=6)L:6,@2V5Y`$EM<&]R="!0=6)L:6,@4$=0($ME
M>0!);7!O<G0@4'5B;&EC(%,O34E-12!+97D`26UP;W)T(%,O34E-12!+97D`
M26UP;W)T(&UB;W@@1FEL90!);7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L
M9&5R("5S+@!);7!O<G0L(%-T97`@)60`26UP;W)T86YT`$EM<&]R=&%N="!M
M97-S86=E<P!);7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+@!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);B!0<F]C97-S`$EN7W-E
M<G0@4F]W($%F=&5R`$EN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H
M96%D97(@:6X@82!R97!L>3\`26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN
M(&$@<F5P;'D_`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O
M;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@
M879A:6QA8FQE+@!);F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y`$EN9F]R
M;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y`$EN9F]R;6%T:6]N(&]N
M(%!E<G-O;F%L(%!U8FQI8R!+97D`26YL:6YE`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!#97)T:69I8V%T92!(97)E`$EN<V5R="!);6%G90!);G-E
M<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4`26YS97)T(%!E<G-O
M;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS97)T(%!U8FQI8R!01U`@2V5Y
M($AE<F4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV
M86QI9"!!9&1R97-S`$EN=F%L:60@4F5M;W1E($UA:6QB;W@`26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A
M;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&-H
M87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N`$EN=F%L:60@9&%T82!S
M=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI
M9"!F:6QE(&9O<FUA=`!);G9A;&ED(&ME>0!);G9A;&ED(&QI8V5N<V4@:V5Y
M+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E
M+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV
M86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E
M(&ME>2X`26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`26YV86QI
M9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C
M:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U
M<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`
M26YV97)T`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R
M;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y
M`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*
M=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`
M2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R
M:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN
M9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97D@9V5N
M97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O
M;G1I;G5E('=I=&@@:V5Y(&=E;F5R871I;VX_`$ME>2!I;7!O<G0@:7,@;F]T
M(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI
M<R!S97)V97(N`$ME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA
M=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@8V]N=&%C
M=',N`$ME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M
M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@36%I
M;&)O>"!086=E`$QA<W0@4&%G90!,87-T(%!A<W-W;W)D($-H86YG90!,87-T
M(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO
M9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`
M3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T
M`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I
M80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@
M1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I
M;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EN:P!,:6YK($%T
M=&%C:&UE;G1S/P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK
M960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BX`3&EN:W,`3&EN:W,@=VEL
M;"!E>'!I<F4@;VX@)7,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S
M964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S
M`$QI<W0@5&%B;&5S`$QI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T
M:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL(&]N
M;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L
M>2D`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`
M3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES
M=&EN9R!I;B!T:&4@2&5A9&5R`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E
M<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A
M;"!-86EL8F]X.@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T
M:6]N`$QO9R!I;@!,;V<@:6X@=&\@)7,`3&]G(&]F('!R979I;W5S('-Y;F,@
M<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`
M3&]W`$QO=R!0<FEO<FET>0!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA
M=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,;W=E<W0`3'5X96UB
M;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@
M9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9@!-86-I;G1O<V@@1FEL90!-861A9V%S8V%R`$UA9VEC
M`$UA:6P`36%I;"!!9&UI;@!-86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y
M<&4@=&\@8V]N;F5C="!T;SH`36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@
M1&ES<&QA>2!/<'1I;VYS`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA
M`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P
M`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-
M87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;@!-87)K($%L;"!-
M97-S86=E<R!I;B!&;VQD97(@87,@56YS965N`$UA<FL@87,Z`$UA<FL@9&EF
M9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R
M<S\`36%R:R!M97-S86=E<R!A<R!S965N/R`H24U!4"!O;FQY*0!-87)K('-I
M;7!L92!M87)K=7`_`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-
M87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8V@@06QL(%%U97)I97,`
M36%T8V@@06YY(%%U97)Y`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA
M=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@
M;&%S="`V(&AO=7)S.B``36%X:6UU;2!!='1A8VAM96YT(%-I>F4`36%X:6UU
M;2!.=6UB97(@;V8@1F]L9&5R<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@
M0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&%T=&%C
M:&UE;G1S(')E86-H960N`$UA>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE
M(')E86-H960N`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!&
M;VQD97(@3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S
M<V%G92!#;VUP;W-I=&EO;@!-97-S86=E($1A=&4`365S<V%G92!/<'1I;VYS
M`$UE<W-A9V4@4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!6
M:65W:6YG`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!F;&%G<P!-97-S86=E
M(&9O;&1E<G,`365S<V%G92!F<F]M("5S`$UE<W-A9V4@:&%S(&%T=&%C:&UE
M;G1S`$UE<W-A9V4@:7,@96YC<GEP=&5D`$UE<W-A9V4@:7,@<VEG;F5D`$UE
M<W-A9V4@;6%T8VAE<P!-97-S86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY
M+@!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O
M("5S`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN`$UE<W-A9V4@='EP90!-
M97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W+@!-97-S86=E
M<R!T;P!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T
M(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D
M`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC
M`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L
M90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@
M>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I
M;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`
M36]D:69Y`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O
M9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT
M<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@
M)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F4@=&AA;B!O;F4@861D<F5S
M<R!F;W5N9"!F;W(@9FEE;&0@(B5S(BX`36]R;V-C;P!-;W-T;'D@0VQE87(`
M36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V90!-;W9E($1O=VX`36]V
M92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!S<&%M
M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E
M<R!T;R!)3D)/6`!-;W9E('1O(&9O;&1E<@!-;W9E('5P`$UO>F%M8FEQ=64`
M375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-
M=6QT:7!A<G0O86QT97)N871I=F4`375L=&EP;&4@365S<V%G92!6:65W`$UU
M;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M
M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@
M22!$;R!.3U0@06=R964`3D].10!.3U1%`$YA;64`3F%M92!A;F0O;W(@96UA
M:6P@8V%N;F]T(&)E(&5M<'1Y`$YA;6EB:6$`3F%U<G4`3F5E9',@06-T:6]N
M`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C
M87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C
M87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A
M<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE
M='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@='EP90!.971W;W)K`$YE=F5R`$YE=F5R('-A=F4@871T86-H;65N=',`
M3F5W`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!&;VQD97(`3F5W
M($UA:6P`3F5W($UE<W-A9V4`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`
M3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W(&UE<W-A
M9V5S`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B
M;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT
M($UE<W-A9V4`3F5X="!086=E`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G
M=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO($-E<G1I9FEC871E
M(&9O=6YD`$YO($5N8W)Y<'1I;VX`3F\@2V5Y<R!I;B!+97ER:6YG`$YO($UE
M<W-A9V5S`$YO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!097)S;VYA
M;"!#97)T:69I8V%T92!0<F5S96YT`$YO(%!R979I97<@5&5X=`!.;R!0=6)L
M:6,@2V5Y<R!&;W5N9`!.;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O<G1E9"X`
M3F\@871T86-H;65N=',@9F]U;F0N`$YO(&%V86EL86)L92!C;VYF:6=U<F%T
M:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E
M;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E
M9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M`$YO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K
M97DN`$YO(&9I;&4@=7!L;V%D960`3F\@9F]L9&5R('-E;&5C=&5D+@!.;R!F
M;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"X`3F\@9F]L
M9&5R<R!W97)E('-P96-I9FEE9`!.;R!F;VQD97)S('=I=&@@;F5W(&UE<W-A
M9V5S`$YO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,`3F\@:6-O;G,@
M9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED
M960N`$YO(&UE<W-A9V4@8F]D>2!T97AT`$YO(&UE<W-A9V4@<F5T=7)N960N
M`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&UE<W-A9V5S(&UA=&-H960@>6]U
M<B!S96%R8V@N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF
M:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T
M82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!P97)S;VYA;"!01U`@<')I=F%T
M92!K97D@:6UP;W)T960N`$YO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM
M<&]R=&5D+@!.;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R
M=&5D+@!.;R!P97)S;VYA;"!P<FEV871E(&ME>2!E>&ES=',@<V\@=&AE(&UE
M<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`3F\@<75O=&$@<V5T
M+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.
M;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"X`3F\@<W!E;&QI
M;F<@97)R;W)S`$YO('-U8V@@9FEL90!.;R!S=6=G97-T:6]N<P!.;R!S=7!P
M;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U
M;F0N`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92X`3F\@=7-E<B!S<&5C:69I960N`$YO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU
M97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO;B!087)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`
M3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R;6%L`$YO
M<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO
M<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@1&5L971E9`!.;W0@1')A
M9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&$@9&ER96-T;W)Y
M`$YO="!A('9A;&ED('!U8FQI8R!K97DN`$YO="!D96QE=&5D(&UE<W-A9V5S
M`$YO="!I;7!L96UE;G1E9"X`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.;W0@
M<V5T`$YO="!S=7!P;W)T960N`$YO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O
M;64@=&EM90!.;W1E<P!.;W1H:6YG`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B
M86-K+@!.;W1I9FEC871I;VXZ($QI;FME9"!A='1A8VAM96YT(&1O=VYL;V%D
M960`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E
M<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E<B!O
M9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M
M;VYT:&QY+@!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@
M9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/4@!/8FIE
M8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E
M<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+@!/;&0@;65S<V%G97,`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I
M<R!N;W0@8V]R<F5C="X`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U
M<F=E9"X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+@!/;FQY(&1I<W!L87D@9F]L9&5R<R!W:71H('5N<F5A9"!M97-S
M86=E<R!I;B!T:&5M/P!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE(&9O;&1E<B!S:&]U
M;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+@!/;FQY('1H92!O=VYE
M<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI
M<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N($9O7VQD
M97(`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@
M;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E
M;F5D($9O;&1E<@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P
M97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/
M<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N
M:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C;W5N=',`3W1H97(@3W!T
M:6]N<P!/=71B;W5N9"!397)V97(`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C
M:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'0@365S<V%G
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0($5R<F]R.B``4$=0($5R<F]R.B!.
M965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!01U`@
M3W!T:6]N<P!01U`@4&%S<W!H<F%S92!);G!U=`!01U`@4&5R<V]N86P@2V5Y
M<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+@!01U`@4'5B;&EC($ME>0!01U`@4'5B;&EC($ME>2!497AT`%!'4"!0=6)L
M:6,@2V5Y(&9O<B`B)7,@*"5S*2(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"X`
M4$=0(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE
M=&5D+@!01U`@4'5B;&EC($ME>7)I;F<`4$=0(%-I9VX@365S<V%G90!01U`@
M4VEG;B]%;F-R>7!T($UE<W-A9V4`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M80!01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@<'5B
M;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N`%!'4"!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R
M<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA
M8FQE('1O(&)E('9E<FEF:65D+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C
M<GEP=&5D+@!01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O
M(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T
M;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES
M('-E='1I;F<@;W(@96QS92!T:&4@4$=0(&9E871U<F5S('=I;&P@;F]T('=O
M<FL@8V]R<F5C=&QY+@!02%`@0V]D90!032!,:6=H="!286EN`%!-(%)A:6X`
M4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@
M5"U3=&]R;7,`4$]0,P!03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I`%!/
M4#,@;W9E<B!34TP`4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF
M:6-A=&4I`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D*0!03U`S+"!N;R!4
M3%,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4&%D9&EN9P!086=E("5D
M(&]F("5D`%!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4`4&%G
M92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E`%!A:VES=&%N`%!A;&%U
M`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A
M($YE=R!'=6EN96$`4&%R86=U87D`4&%R="AS*0!087)T;'D@0VQO=61Y`%!A
M<W-P:')A<V4`4&%S<W!H<F%S92`H06=A:6XI`%!A<W-P:')A<V4@<W5C8V5S
M<V9U;&QY('5N;&]A9&5D+@!087-S<&AR87-E.@!087-S<&AR87-E<R!C86YN
M;W0@8F4@96UP='D`4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H`%!A<W-W;W)D
M`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O
M<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A
M=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A
M<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R
M;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R
M8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E
M<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`
M4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R;6ES
M<VEO;G,@9F]R('1H:7,@=7-E<B!C86YN;W0@8F4@8VAA;F=E9"X`4&5R<V]N
M86P`4&5R<V]N86P@26YF;W)M871I;VX`4&5R<V]N86P@4$=0(&ME>7!A:7(@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4&5R<V]N86P@4$=0(&ME>7,@9&5L
M971E9"!S=6-C97-S9G5L;'DN`%!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T
M97,@3D]4(&EM<&]R=&5D.B``4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E
M9"!S=6-C97-S9G5L;'DN`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0
M:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L86-E('EO=7(@<VEG;F%T=7)E(&)E
M9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\`4&QA:6YT97AT(%9E<G-I;VX@
M;V8@365S<V%G90!0;&%T:71U9&5S`%!L87D@<V]U;F0@;VX@;F5W(&UA:6P_
M("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D
M9&5D('-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N
M9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"!R97%U:7)E(&$@<&QU
M9VEN+@!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@
M=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L
M96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T
M92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P
M:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BX`4&QE87-E(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I
M;&P@;VYL>2!N965D('1O(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E
M<B`E<R!S97-S:6]N+@!0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C
M;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R!C
M;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U
M<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O(&QO9R!I;B!A9V%I;B!I;B!Y
M;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A
M8VME<G,@9G)O;2!H:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L
M;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E+@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M<&%S<W=O<F0N`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64N`%!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R97-O;'9E(&%M
M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E('-E;&5C="!A
M(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@=&AI<R!A8W1I;VXN`%!L96%S
M92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N`%!L96%S
M92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BX`
M4&QE87-E('-E;&5C="!O<B!E9&ET(&EN('1H92!B;W@@=&\@=&AE(')I9VAT
M.@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0
M;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!O=V5R960@8GD@2&]R9&4`
M4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/P!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A
M=&5D+@!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')E
M=FEO=7,@;W!T:6]N<P!0<FEN=`!0<FEN="!D;V-U;65N=`!0<FEO<FET>0!0
M<FEV871E($ME>0!0<FEV871E($ME>2!087-S=V]R9`!0<F]B;&5M`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T(&5V97)Y('1I;64@86X@
M871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/`%!R;VUP="!E=F5R
M>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,`
M4')O;7!T('1E>'0`4')O=&]C;VPZ`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!
M;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R!01U`@:V5Y<V5R=F5R
M('-U<'!O<G0@:&%S(&)E96X@9&ES86)L960N`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%!U<E]G92!$96QE=&5D`%!U<F=E($1E;&5T960`4'5R9V4@1F]L9&5R*',I
M`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S<V%G97,`4'5R9V4@
M;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U
M;G0@;V8@9&%Y<RX`4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F
M;VQD97(_`%!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N
M`%!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+@!1871A<@!1
M=65R>0!1=6]T80!1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N
M,F8E)2D`475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5`!1=6]T82!S
M=&%T=7,Z($Y/($Q)34E4`%%U;W1I;F<@)68Z`%)302!0=6)L:6,@2V5Y("@E
M9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,
M871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A
M;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5B=6EL9"!&;VQD97(@5')E90!2
M96-E:79E9"!/;@!296-E:79E9"!3:6YC90!296-E:79E9"!5;G1I;`!2961I
M<F5C7W0`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I<F5C="!T:&ES
M(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2961O97,@>6]U<B!L87-T
M(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H($9O;&1E<B!6:65W<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`
M4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;&]A9"!6:65W`%)E;6%R
M:W,`4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M96UB
M97(@=&AE(&QA<W0@=FEE=P!296UO=&4@36%I;&)O>#H`4F5M;W1E(%-E<G9E
M<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E($9I96QD($9R;VT@4V5A<F-H
M`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`%)E;6]V92!S;W5R8V4`4F5M;W9E('1H90!296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U
M<V5R.B`E<P!296YA;64@1F]L9&5R*',I`%)E;F%M92!S96YT+6UA:6P@9F]L
M9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`4F5N86UI;F<@(B5S(B!T;R`B
M)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!297!L
M7WD@=&\@3&ES=`!297!L86-E('=I=&@Z`%)E<&QY`%)E<&QY(%-E;G0N`%)E
M<&QY('1O($%L;`!297!L>2!T;R!!;&PZ`%)E<&QY('1O($QI<W0`4F5P;'D@
M=&\@3&ES=#H`4F5P;'D@=&\@7T%L;`!297!L>2!W:71H($YO="!3=7!P;W)T
M960@365S<V%G90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO
M;G1H<RX`4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+@!297!L>2U4;P!297!L>2U4;SH@`%)E<&QY.@!297!O<G0@87,@26YN
M;V-E;G0`4F5P;W)T(&%S(%-P86T`4F5Q=65S="!A(%]296%D(%)E8V5I<'0`
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B``4F5Q=65S="!R96%D(')E8V5I<'1S/P!297%U97-T960@;65S<V%G
M92!N;W0@9F]U;F0N`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F
M;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<75I<F5D(%!A<G1I
M8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O
M<F0`4F5S<&]N9&5N="!3=&%T=7,@57!D871E9"X`4F5S=&]R92!,87-T(%%U
M97)Y`%)E<W5L=',`4F5S=6UE`%)E<W5M92!Y;W5R('-E<W-I;VX`4F5T=7)N
M('1O(")-97-S86=E($-O;7!O<VET:6]N(@!2971U<FX@=&\@1F5T8V@@36%I
M;`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES
M=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S
M<V%G93\`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF
M:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I
M9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S
M+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T
M92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2
M=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C
M;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S
M:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R90!3+TU)344@16YC<GEP="!-97-S86=E`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!3+TU)344@17)R;W(Z(`!3+TU)344@17)R;W(Z($YE960@
M<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN`%,O34E-12!/
M<'1I;VYS`%,O34E-12!087-S<&AR87-E($EN<'5T`%,O34E-12!097)S;VYA
M;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN`%,O34E-12!0=6)L:6,@2V5Y(&9O<B`B)7,B('=A<R!S=6-C97-S
M9G5L;'D@9&5L971E9"X`4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY
M(&%D9&5D+@!3+TU)344@4'5B;&EC($ME>7)I;F<`4R]-24U%(%!U8FQI8R]0
M<FEV871E($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D+@!3+TU)344@4VEG
M;B!-97-S86=E`%,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G90!3+TU)344@
M<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`4R]-24U%('-U
M<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E
M(&ES('5N86)L92!T;R!B92!D96-R>7!T960N`%,O34E-12!S=7!P;W)T(&ES
M(&YO="!E;F%B;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I9VYE9"!M
M97-S86=E(&-A;FYO="!B92!D:7-P;&%Y960N`%,O34E-12!S=7!P;W)T(&ES
M(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B
M;&4@=&\@8F4@=F5R:69I960N`%,O34E-12!S=7!P;W)T(')E<75I<F5S('!O
M<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C
M=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU
M<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H92!3+TU)344@9F5A
M='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN`%-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?=6)J96-T
M`%-A`%-A7W9E(&$@8V]P>2!I;B``4V%?=F4@87,`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA
M`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!!='1A8VAM96YT<R!W:71H
M(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\`4V%V92!$<F%F=`!3879E
M($EM86=E`%-A=F4@26UA9V4@:6X@1V%L;&5R>0!3879E($]P=&EO;G,`4V%V
M92!3=&%T:6]N97)Y`%-A=F4@7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@
M87,@=6YS965N/P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A
M=6QT(&%D9')E<W,@8F]O:S\`4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O
M;&1E<C\`4V%V92!S96YT(&UA:6P_`%-A=F5D("5S(&-O;F9I9W5R871I;VXN
M`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!3879I;F<@
M=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@)7,`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C
M:"`E<P!396%R8V@@16YG:6YE<P!396%R8V@@3W!T:6]N<P!396%R8V@@4F5S
M=6QT<P!3965N`%-E;&5C=`!396QE8W0@06YO=&AE<B!!8V-O=6YT`%-E;&5C
M="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A
M(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R
M=F5R`%-E;&5C="!A('-T871I;VYE<GDZ`%-E;&5C="!A('5S97(@=&\@861D
M`%-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S
M96%R8VAI;F<@9F]R(&%D9')E<W-E<RX`4V5L96-T(&%L;`!396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H
M('=H96X@97AP86YD:6YG(&%D9')E<W-E<RX`4V5L96-T(&%N(&%C8V]U;G0`
M4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A
M8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@
M=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O
M<FUA=#H`4V5L96-T('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN
M+@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L
M96-T('1H92!M86EL('-E<G9E<B!T>7!E`%-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@061D<F5S<R!B
M;V]K<SH`4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<@!396YD($QA=&5S
M="!);F9O<FUA=&EO;@!396YD($UE<W-A9V4`4V5N9"!0<F]B;&5M(%)E<&]R
M=`!396YD(%--4P!396YD(&UE<W-A9V4@=VET:&]U="!A(%-U8FIE8W0_`%-E
M;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD97(_
M`%-E;F5G86P`4V5N<V]R.B``4V5N="!M86EL(&9O;&1E<@!396YT(&UA:6P@
M9F]L9&5R.@!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA
M;"!.=6UB97(`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N
M`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<G9E<CH`
M4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E
M=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!P<F5F97)E;F-E<R!F
M;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S
M86=E<RX`4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN
M9R!M97-S86=E<S\`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A
M;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P
M`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A
M=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE
M<P!3:&%R92!&;VQD97)S`%-H87)E(&UA:6P@9F]L9&5R<P!3:&%R92!Y;W5R
M(&UA:6P@9F]L9&5R<R!W:71H(&]T:&5R('5S97)S+@!3:&]P<&EN9P!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT
M(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@=&]G
M9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N`%-H;W5L9"!T:&4@
M8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'
M4"!D871A/P!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A
M9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K
M97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT
M/P!3:&]W`%-H;W<@06QL($9O;&1E<G,`4VAO=R!!;&P@2&5A9&5R<P!3:&]W
M($1E;&5T960`4VAO=R!,:6UI=&5D($AE861E<G,`4VAO=R!-86EL:6YG($QI
M<W0@26YF;W)M871I;VX`4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<P!3
M:&]W(%5N<W5B<V-R:6)E9`!3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P
M:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_`%-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&QE9V5N9"!I;B!T:&4@;6%I;&)O>"!V
M:65W/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R
M`%-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/P!3:&]W
M('!R979I97=S(&EN('1O;VQT:7!S/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@
M=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@
M26UA9V5S`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&9I;'1E<B!I8V]N
M(&]N('1H92!M96YU8F%R/P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9P!3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_`%-H
M;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`
M4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAO=VX`4VAR:6YK`%-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S=`!3:5]Z90!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6=N960`4VEN9V%P;W)E`%-I>F4`4VMI<"!-
M86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R
M`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S
M($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!B
M>2!!<G)I=F%L`%-O<G0@8GD@1&%T90!3;W)T(&)Y($9R;VT@061D<F5S<P!3
M;W)T(&)Y($UE<W-A9V4@4VEZ90!3;W)T(&)Y(%-U8FIE8W0`4V]R="!B>2!4
M:')E860`4V]R="!B>2!4;R!!9&1R97-S`%-O<G0@;W)D97(@<V5L96-T:6]N
M`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN
M9P!3<&%I;@!3<&%M`%-P86T@9F]L9&5R.@!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&5C:6%L($-H87)A8W1E<G,`4W!E8VEA;"!6:7)T=6%L($9O;&1E
M<G,@8V%N;F]T(&)E(&5D:71E9"X`4W!E;&P@0VAE8VL`4W!E;&P@0VAE8VME
M<@!3<&5L;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C
M<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+@!3<&QI="!C96QL`%-P;&ET(&-O
M;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R
M(%1R96L`4W1A<G0`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T
M:6]N97)Y`%-T871I;VYE<GD@;F%M93H`4W1A=&EO;F5R>2!T>7!E.@!3=&%T
M:6]N97)Y.@!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`
M4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!!='1A8VAM96YT`%-T
M<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T<FEP(&QI;F5B<F5A:W,_
M`%-T>6QE(%M#4U-=`%-U`%-U8E]J96-T`%-U8F1I<F5C=&]R>2`B)7,B(&YO
M="!F;W5N9"X`4W5B:F5C=`!3=6)J96-T($9I96QD`%-U8FUI=`!3=6)M:71T
M960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V
M960N`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6=G97-T:6]N<P!3=6UM87)Y`%-U;B!2:7-E`%-U
M;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``
M4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`
M4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D
M96X`4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9`!3=VET8V@@=&\@2%1-3"!C
M;VUP;W-I=&EO;@!3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;@!3
M=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;G1A>"!E<G)O<B!I;B!S
M96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T
M;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL
M90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I
M=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5?>'0`
M5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A
M='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L
M871E($%D;6EN:7-T<F%T:6]N`%1E;G1A=&EV93H@`%1E;G1A=&EV96QY($%C
M8V5P="!R97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E<FUS(&]F(%-E
M<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP`%1E>'0`5&5X
M="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4
M:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4
M:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK
M960Z`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E
M+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E
M<R(`5&AE($E-05`@<V5R=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T
M('1H92!A=71H96YT:6-A=&EO;B!M971H;V0@<V5L96-T960N(%!L96%S92!C
M;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!)35-0(&QO
M9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86-I;G1O<V@@<F5S
M;W5R8V4@9F]R:P!4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E
M(&1O=VYL;V%D960@)7,N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!A8V-O=6YT("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I
M;VYS+@!4:&4@871T86-H;65N="!W87,@;F]T(&9O=6YD+@!4:&4@8F]T=&]M
M('-I9&4@;VYL>0!4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED`%1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L
M;W<N`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N86UE
M9"!T;R`B)7,B+@!4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C
M97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960`5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!D<F%F="!H87,@8F5E;B!S
M879E9"!T;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E=F5N
M="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9I96QD("(E<R(@
M8V%N)W0@8F4@97AP86YD960N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O
M(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQD
M97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L9&5R("(E<R(@8V]N=&%I
M;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U
M<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R
M92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!D
M96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N
M`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@9&5L
M971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R
M("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E
M<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@
M=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N`%1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T
M:&ES('!A<G0Z`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C
M:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C
M<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E
M<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I
M;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E
M;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@
M=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!I;6%G92!S879E('=I;F1O=R!C
M86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B
M<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!I;6%G97,@=VEL
M;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES('!R97-E;G0@
M:6X@>6]U<B!A9&1R97-S8F]O:RX`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`
M5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E
M;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M86EL('-E<G9E<B!G
M96YE<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@;6%I
M;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA
M;"!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL
M;W=I;F<@;65S<V%G93H`5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T
M>2X`5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@*"5D(&)Y=&5S*2!E>&-E
M961S(&9E=&-H('-I>F4@;&EM:70N`%1H92!M97-S86=E(&)E:6YG(&-O;7!O
M<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A9V4@9&]E
M<R!N;W0@:&%V92!A(%-U8FIE8W0@96YT97)E9"X`5&AE(&UE<W-A9V4@:&%S
M(&)E96X@9&5L971E9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N
M`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+@!4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B
M(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM
M=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N`%1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N
M(&)E('9I97=E9"`E<RX`5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X
M:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N`%1H92!R97%U97-T960@
M9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N`%1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I
M9&4@;VYL>0!4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T
M:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@9G)O;2!Y
M;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L
M:6-K("5S('1O('-E;F0@=&AE(&YO=&EF:6-A=&EO;B!M97-S86=E+@!4:&4@
M<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@<V%V960N`%1H92!S97)V97(@=V%S(&YO="!A8FQE('1O(&-R
M96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!4:&4@<VEG;F%T=7)E
M(&-O=6QD(&YO="!B92!R97!L86-E9"X`5&AE('-I9VYA='5R92!W87,@<W5C
M8V5S<V9U;&QY(')E<&QA8V5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@9FEL92!D;V5S(&YO
M="!E>&ES="X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES
M="X`5&AE('-T871I;VYE<GD@(B5S(B!H87,@8F5E;B!A9&1E9"X`5&AE('-T
M871I;VYE<GD@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<W1A=&EO;F5R
M>2`B)7,B(&AA<R!B965N('5P9&%T960N`%1H92!T87-K(&AA<R!B965N(&%D
M9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B
M(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G90!4:&4@
M=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X
M="!O9B!T:&4@<F5T=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@<F5T
M=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T
M:&4@<V5N="!M97-S86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@
M8V%N(&)E('9I97=E9"`E<RX`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO
M="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D
M+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE
M;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&%L
M=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N`%1H97)E
M(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+@!4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y
M<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O
M8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@
M)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@
M)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@8V]P>6EN
M9R!M97-S86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S
M<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A
M9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@
M86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@
M86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T+@!4:&5R92!W87,@
M86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RX`
M5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0`5&AI<R!(
M5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X`5&AI<R!(
M5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO8VME
M9"!I;6%G97,@87!P96%R(&QI:V4@=&AI<SH@`%1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@4$=0(%!U
M8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O('1H92!M97-S86=E+@!4:&ES(&%C
M=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@>65T
M(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H
M92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU
M;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES
M(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E
M<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T
M:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V
M86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E
M<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A
M('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO
M<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q
M,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T
M+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@
M8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F
M;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S
M92!V:7-I="`E<P!4:&ES(&UA>2!T86ME('-O;64@=&EM92X@07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&-O;G1I;G5E/P!4:&ES(&UE<W-A9V4@8V]N=&%I
M;G,@82!-86-I;G1O<V@@9FEL92X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N
M(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I
M82!3+TU)344N`%1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT
M('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N`%1H:7,@;65S
M<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO
M;BP@8G5T('1H92!F;W)M870@;V8@=&AI<R!M97-S86=E(&ES('5N:VYO=VXN
M`%1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!0
M1U`@96YC<GEP=&5D(&UE<W-A9V4N($5R<F]R.B``5&AI<R!M97-S86=E(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T
M("AA8V-O<F1I;F<@=&\@4D9#(#(P,34I+@!4:&ES(&UE<W-A9V4@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F;W)M870N
M`%1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!0
M1U`N`%1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I
M82!3+TU)344N`%1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA
M(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H
M(%!'4"X`5&AI<R!M97-S86=E('1O`%1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V
M97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A(&-O;7!O<V4@=VEN9&]W+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H<F5A9"!$:7-P;&%Y`%1H
M<F5A9"!6:65W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`
M5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`
M5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!!9&1R97-S`%1O('-E;&5C="!M=6QT
M:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@=VAI;&4@8VQI8VMI;F<N`%1O('-E;&5C="!M=6QT:7!L
M92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N
M9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O('5S92!A(%1,4R!C;VYN
M96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@
M-2XQ+C`@;W(@:&EG:&5R+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I
M`%1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z`%1R86YS;&%T:6]N<P!4<F%S:"!F
M;VQD97(`5')A<V@@9F]L9&5R.@!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@
M;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM
M.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A
M;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A
M;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T
M;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O
M(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O
M;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E
M<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L
M971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@
M9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C
M="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D
M(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D
M(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R
M96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O
M;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`
M56YA8FQE('1O(')E=')I979E('%U;W1A`%5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"X`56YA;G-W97)E9`!5;F%N<W=E<F5D(&UE<W-A
M9V5S`%5N9&5L971E`%5N9&5R;&EN90!5;F1I<V-L;W-E9"!296-I<&EE;G1S
M`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($%55$A%3E1)0T%412!C
M;VUM86YD+@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($1I
M9V5S="U-1#4@<F5S<&]N<V4N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@=&\@3$]'24X@8V]M;6%N9"X`56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YH86YD;&5D(&-O;7!O;F5N="!O
M9B!T>7!E.B`E<P!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T
M97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N
M($1A=&4`56YK;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@
M4V5R=F5R(%)E<W!O;F1E9#H@)7,`56YK;F]W;B!-965T:6YG`%5N:VYO=VX@
M4F5C:7!I96YT`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`
M56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N
M(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W
M;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FQO860@4&%S<W!H
M<F%S90!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E
M<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS965N`%5N<V5T
M(&-O;&]R`%5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I`%5N<W5P<&]R=&5D
M($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!R97-P;VYD96YT
M('-T871U<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@
M<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R
M<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S
M`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I
M;VYS/P!5<V4@4U-,`%5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\`57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`
M57-E<@!5<V5R("(E<R(@<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I
M960@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(N`%5S97(@)7,@:7,@;F]T
M(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@
M3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@
M;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES
M=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ
M`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C
M871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET
M>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H
M92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE
M8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I
M;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R
M960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI
M9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@
M3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=P!6:65W("5S`%9I97<@)7,@
M4'5B;&EC($ME>0!6:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I
M;F1O=P!6:65W($UE<W-A9V5S`%9I97<@4&5R<V]N86P@4')I=F%T92!+97D`
M5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y`%9I97<@5&AR96%D`%9I97<@5&AU
M;6)N86EL`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6
M:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!C;VYT
M96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I97<@979E;G0`5FEE=R!M97-S
M86=E<R!I;B`E<P!6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L
M;V=I;CH`5FEE=R!T87-K`%9I97<@=&AE($EM86=E<P!6:7)G:6X@27-L86YD
M<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7)T=6%L($9O;&1E
M<B`B)7,B(&-R96%T960@<W5C8V5S9G5L;'DN`%9I<G1U86P@1F]L9&5R<P!6
M:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA8F5L+@!6:7)T=6%L($E.0D]8
M`%9I<G1U86P@24Y"3U@@1F]L9&5R`%9I<G1U86P@5')A<V@`5FER='5A;"!4
M<F%S:"!&;VQD97(`5FER='5A;"!F;VQD97(@;&%B96P`5FES:6)I;&ET>0!6
M:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I
M82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&
M;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5B`%=E8B!3:71E
M`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S
M=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E
M<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAA="!S:&]U;&0@=V4@
M9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E
M<&]R=&5D(&%S('-P86T@;W(@:6YN;V-E;G0_`%=H96X@9&5L971I;F<@;65S
M<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D
M(&]F(&UA<FMI;F<@=&AE;2!A<R!D96QE=&5D/P!7:&5N(&]P96YI;F<@82!N
M97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O
M;C\`5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A
M8VAM96YT(&1A=&$_`%=H96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N9&EN9R!A
M9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E;F0@=&\@=6YQ
M=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S97,@=VET:&]U="`B
M0"(I/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H
M('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`
M5VAI=&5L:7-T`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z
M`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7
M;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@
M17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL
M92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS
M=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE
M87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@86)O=70@=&\@
M9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ`%EO
M=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A
M:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!A='1E
M;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U
M(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@
M8W)E871I;F<@82!S=6(M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@
M=&]P+6QE=F5L(&9O;&1E<BX`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@
M=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N`%EO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD
M97)S+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@87)E(')E;F%M
M:6YG('1H92!F;VQD97(Z(`!9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L
M86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE
M(&-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R
M92X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+@!9;W4@8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@(B5S(BX`
M66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R
M965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"!T;R!L;V=I;BX`66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED
M;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@
M=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R
M`%EO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L
M;&]W:6YG(')E8VEP:65N=',Z("5S+@!9;W4@:&%V92`E<R!N97<@;65S<V%G
M97,N`%EO=2!H879E(#$@;F5W(&UE<W-A9V4N`%EO=2!H879E(&%L<F5A9'D@
M<W5B;6ET=&5D('1H:7,@<&%G92X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CH`
M66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E
M;G1E<B!A="!L96%S="!O;F4@<F5C:7!I96YT+@!9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O
M('9I97<@=&AI<R!M97-S86=E`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@
M;65S<V%G90!9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S
M="X`66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"X`
M66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E
M;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T
M(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y
M(&$@<F5C:7!I96YT+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O(&AA=F4@(B5S
M(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RX`66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@<F5D
M:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+@!9;W4@<F5P;&EE
M9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N`%EO=2!W97)E(&YO="!S=6)S8W)I
M8F5D('1O("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C
M<FEB960@=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I
M8F5D(&9R;VT@(B5S(@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O
M;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(%!'4"!0=6)L:6,O4')I
M=F%T92!+97ES`%EO=7(@4')I=F%T92!+97D`66]U<B!0=6)L:6,@2V5Y`%EO
M=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3X`66]U
M<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S`%EO=7(@86-C
M;W5N=',Z`%EO=7(@86QI87,@861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E
M;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H
M96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I
M;6%G92!T>7!E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R
M:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8VAA
M<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&5N8W)Y
M<'1I;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U
M;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED
M96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L:6YK960@871T86-H;65N
M="!H87,@8F5E;B!D;W=N;&]A9&5D(&)Y(&%T(&QE87-T(&]N92!U<V5R+@H*
M071T86-H;65N="!N86UE.B`E<PI!='1A8VAM96YT(&1A=&4Z("5S"@I#;&EC
M:R!O;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@<&5R;6%N96YT;'D@9&5L971E
M('1H92!A='1A8VAM96YT.@HE<P!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9
M;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N`%EO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M
M;W1E('-E<G9E<G,Z`%EO=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!;2&ED92!!9&1R97-S97-=`%M(:61E(%%U;W1E
M9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!!
M9&1R97-S97,@+0!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%M3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP:65N
M='-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T)C8P!?0FQA
M8VML:7-T`%]#3$D`7T-C`%]$96QE=&4`7T1E;&5T92!2;W<`7T9O;&1E<G,`
M7T=R;W5P<P!?2&5L<`!?261E;G1I='D`7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TEN8F]X`%],;V<@:6X`7TQO9R!O=70`7TUE<W-A9V4@4V]U<F-E`%]-;V1I
M9GD@3&EN:RXN+@!?3F5W($UE<W-A9V4`7T]P=&EO;G,`7U!E<FUI<W-I;VYS
M`%]0<FEN=`!?4')I;W)I='D`7U)E9G)E<V@@)7,`7U)E;6]V92!,:6YK+BXN
M`%]297!L>0!?4V5A<F-H`%]396YD($UE<W-A9V4`7U-E='5P`%]486)L92!0
M<F]P97)T:65S+BXN`%]4:')E860`7U1O`%]5;F1E;&5T90!?57-E<G,`7U9I
M97<@5&AR96%D`%]7:&ET96QI<W0`861D<F5S<R!B;V]K`&%D9')E<W-E92!U
M;FMN;W=N`&%T=&%C:&UE;G0`8GET97,`8V%L96YD87(`8V%L;0!C86YN;W0@
M8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE
M<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R
M;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E
M<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O;0!F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&]S="!N86UE
M('5N:VYO=VX`:6UM961I871E`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA
M;"!S;V9T=V%R92!E<G)O<@!K97D`;&EN97-=`&UA:6QB;W@@9FEL90!M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M90!N;VYE
M`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`
M;W(`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5C:7!I96YT
M<UT`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N
M879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10
M`'-P96QL:6YG(&5R<F]R`'-P96QL:6YG(&5R<F]R<P!S=&5A9'D`<WES=&5M
M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N;F%M960`=7-E<B!S96QE8W0`
M=D-A<F0`=SH`>6]U<B!B;&%C:VQI<W0`>6]U<B!W:&ET96QI<W0`4')O:F5C
M="U)9"U697)S:6]N.B!)35`@-"XQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R
M+3$W(#$P.C`P*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ."`P
M.3HT-BLP,3`P"DQA<W0M5')A;G-L871O<CH@3&%S>FQO($PN(%1O<FYO8VD@
M/'1O<FQA<WI`>&5N:6$N<V]T92YH=3X*3&%N9W5A9V4M5&5A;3H@2'5N9V%R
M:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3(*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("`@("`@0V,Z(``@
M0^UM>F5T=#H@`"`@($3A='5M.B``("!&96QA9/,Z(``@*"5S(&YA<'!A;"!E
M>F5L]71T*0`@*$%L="UB:6QL96YT>?L@)7,I`"`H)7,@;F%P(&WZ;'9A*0`@
M*&UA*0`@*&AO;&YA<"D`("AT96=N87`I`%1A<G1A;&]M.B``(#H@`"(E<R(@
M;F5M(&%L:_9N>79TX7(N`"(E<R(@;F5M(.ER=NEN>65S(';A;&%S>G3A<RX`
M(B5S(B!N:6YC<R!K;VYF:6=U<N%L=F$@82!(;W)D92!296=I<W1R>6)E;BX`
M(B5S(B!F87-T<G5K=/IR82UM96=J96QE;NUT]2!N96T@=&%LX6QH873S+@`B
M)7,B+70@:&]Z>N%A9'1U:R!A(&-S;W!O<G1O:VAO>BX`(B5S(BUT(&AO>GKA
M861T=6L@82!J;V=O<W5L='/A9VD@<F5N9'-Z97)H97HN`"(E<R(M="!N96T@
M:&]Z='5K(&SI=')E.B`E<RX`(P`E+C)F34(@9F5L:&%S>F[A;'0@82`E+C)F
M34(@;65G96YG961E='1B]6P@*"4N,F8E)2D`)60@)7,@Z7,@)7,`)60@;&5V
MZ6P`)60@;F%P(&WZ;'9A(&QE:N%R(&IE;'-Z87;A;F%K(.ER=NEN>65S<^EG
M92X`)60@;&5V96QE="!T]G+V;'3\;FLN`"5D(&QE=F5L970@;6EN]7/M=&5T
M="!N96T@<W!A;6YE:R!A(')E;F1S>F5R9V%Z9.%N86L@:_QL9/9T="!J96QE
M;G3I<V)E;BX`)60@;&5V96QE="!M:6[U<^UT971T(&YE;2!S<&%M;F5K+@`E
M9"!L979E;&5T(&UI;O5S[71E='0@<W!A;6YE:R!A(')E;F1S>F5R9V%Z9.%N
M86L@:_QL9/9T="!J96QE;G3I<V)E;BX`)60@;&5V96QE="!M:6[U<^UT971T
M('-P86UN96LN`"5D("T@)60@*/9S<WIE<V5N("5D(&QE=NEL*0`E9"!N87!O
M<R!E;/5R96IE;'KI<P`E<R`M($9I9WEE;&UE>G1E=.ES`"5S(&QE;GEO;6%T
M`"5S(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K("T@;65G97+U<^UTZ7,`)7,@
M8F7A;&SM=.%S`"5S(&QO9VEN(&[I=B!I9^EN>6SI<P`E<R!S>F]L9^%L=&%T
MX7-I(&9E;'3I=&5L96L`02`B)7,B(&YE=OL@X6QL;VWA;GD@;>%R(&SI=&5Z
M:6LN`"5S(&WA<B!LZ71E>FEK+B!!("5S(&UA<'#A="!N96T@<VEK97+\;'0@
MX71N979E>FYI+@`E<R`Z("5S("5S`"5S(&YE;2!E9WD@Z7)VZ6YY97,@;&5V
MZ6QLX61A+@!!("5S(&UA<'!A(&$@:/-N87`@96QE:NEN(&YE=F5Z]61I:R#A
M="X`)7,@96QF;V=A9'1A(&$@;65G:.UVX7-T+@`E<R!T]G+V;'1E(&$H>BD@
M(B5S(B!E<V5MZ6YY="X`)7,@96QU=&%S[71O='1A(&$@;65G:.UVX7-T+@`E
M<R!VX6QA<WIO;'0@87H@:63U8F5O<WITX7-I(&%D871KZ7+I<W)E+@`E<R!V
MX6QA<WIO;'0@82AZ*2`B)7,B+7)E('-Z\VSS(&UE9VCM=N%S<F$N`"5S(&ED
M]6)E;W-Z=.%S:2!I;F9O<FWA8VGS="!K_&QD]G1T(-9N;F5K+@`E<R!F96QT
MZ71E;&5S96X@96QF;V=A9'1A(&$@;65G:.UVX7-T+@!!*'HI("5S(&OI<WIE
M;B#A;&P@87H@86SA8F)I(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K(&5L=NEG
M>NESZ7)E+DIE;/9L:F4@:VD@87IO:V%T(&$@9F5L861A=&\H:V$I="P@86UI
M*&ME*70@;6]S="!E;"!K[7;A;B!VZ6=E>FYI+@`E<R!K:73V;'3I<V4@<WK\
M:W/I9V5S`"5S('!E<F,`)7,@;F5M('1A;.%L:&%T\RX`)7,@:63U8F5O<WIT
MX7-I(&%D871O:V%T(&OI<B#6;G3U;"X`)7,@<WIE<F5T;NDL(&AA('+I<WIT
M('1U9&YA('9E;FYI(&$@:_9V971K97KU(&5S96WI;GEE;CH@(B5S(BX`)7,@
M+2`E<R`H]G-S>F5S96X@)7,I`"5S+70@<VEK97)E<V5N(&AO>GKA=&5T=/QK
M("(E<R(M:&5Z+@`E<R!VX6QT;WIT873A<W0@<WIE<F5T;F4@82AZ*2`B)7,B
M(&5S96WI;FYY96P@:V%P8W-O;&%T;W-A;BX`)7,@=.%JZ6MO>G1A=&YI(&OM
M=N%N:F$@UFYT(&$@:_9V971K97KU(&5S96WI;GER]6PZ("(E<R(N`"5S(&$@
M;&5G9G)I<W-E8F(@:6YF;W)MX6-I\W0@<WIE<F5T;ND@;65G:V%P;FD@82AZ
M*2`B)7,B(&5S96WI;GER]6PN`"5S(&/M;6IE9WEZZ6ME`"5S(&YA<'3A<F$`
M)7,@9F5L:F5G>7KI<V5I`"5S(&9E;&%D871L:7-TX6IA`"5S.B`E<R`H)60F
M;F)S<#MA)FYB<W`[)60M8O5L*0`E<SH@3&5H971SZ6=E<RP@:&]G>2!E>B!A
M(&QE=NEL('9A;/-JX6)A;B!N96T@82!M96=A9&]T="!F96QA9/-T\VP@<WKA
M<FUA>FEK+B!';VYD;VQJ82!M96<L(&UI96SU='0@<N%K871T:6YT('9A;&%M
M:7)E+"!V86=Y('-Z96WI;'EE<R!I;F9O<FWA8VGS="!A9"!M96<N`"A!(';A
M;'1O>G1A=.%S;VL@;65G=.ET96QE('5TX6X@=.ER:OQN:R#A="!A(&OV=F5T
M:V5Z]2!KZ7!E<FYY]7)E+BD`*%9O;FIU:R!V:7-S>F$@87H@]G-S>F5S(';A
M;'1O>G1A=.%S="#I<R!TZ7)J_&YK('9I<W-Z82!A(&QE=NEL[7+A<VAO>BXI
M`"A(5$U,*0`H<VEM82!S>O9V96<I`"A4Z7)J_&YK('9I<W-Z82!A(&QE=NEL
M[7+A<VAO>B!A>B!E9&1I9VD@=N%L=&]Z=&%TX7-O:R!M96=TZ71E;&4@=73A
M;BX@02!J96QE;FQE9VD@:^EP97)N>?5N(&SA=&AA=/,@=N%L=&]Z=&%TX7-O
M:R!A>F]N8F%N($Y%32!T]G)TZ6YN96L@;65G+@`H2_QL9&K\:R!E;"!A(&QE
M=F5L970@87H@961D:6=I(';A;'1O>G1A=.%S;VL@;65G=.ET96QE('5TX6XN
M($$@:F5L96YL96=I(&OI<&5R;GGU;B!LX71H873S(';A;'1O>G1A=.%S;VL@
M87IO;F)A;B!.14T@=/9R=.EN;F5K(&UE9RX`*B!!>B!/2R!G;VUB<F$@:V%T
M=&EN='9A(&%D:G5K(&AO>GKA(&5Z96ME="`J`"H@2^ER:OQK(';A;&%S<WIO
M;B!C[6TH96LI970@*@`L('-ZZ6QL]FOI<V5K`"P@)7,@)7,M<R!S>NEL;/9K
MZ7-E:P`L(';A;'1O>O,@)7,@Z7,@)7,@:_9Z]G1T`"TM(';A;&%S<WIO;B`M
M+0`Q(&QE=F5L970@=/9R]FQT_&YK+@`Q(&QE=F5L970@;6EN]7/M=&5T="!N
M96T@<W!A;6YE:R!A(')E;F1S>F5R9V%Z9.%N86L@:_QL9/9T="!J96QE;G3I
M<V)E;BX`,2!L979E;&5T(&UI;O5S[71E='0@;F5M('-P86UN96LN`#$@;&5V
M96QE="!M:6[U<^UT971T('-P86UN96L@82!R96YD<WIE<F=A>F3A;F%K(&O\
M;&3V='0@:F5L96YTZ7-B96XN`#$@;&5V96QE="!M:6[U<^UT971T('-P86UN
M96LN`#$P,"!K87)A:W1E<@`Q,#`P(&MA<F%K=&5R`#$R(/-RX7,@9F]R;>%T
M=6T`,C0@\W+A<R!F;W)MX71U;0`R-"#S<F$`,C4P(&MA<F%K=&5R`#4P,"!K
M87)A:W1E<@`\16SU>O4`17IE;B!B;&]K:R!H87-Z;N%L873A:&]Z(&5G>2!A
M9&%T8N%Z:7,@86QR96YD<WIE<B!S>OQK<^EG97,N`$AE;'ER96AO>FAA=&%T
M;&%N(&AI8F$@=/9R=.EN=`!%9WD@)7,@;F5V^R!N86=Y;>ER973[(&OI<"!V
M86X@8W-A=&]L=F$@96AH97H@82!L97;I;&AE>BX`07H@96QK_&QD]G1T(&QE
M=NEL<F4@=FES<WIA:F5L>NES(.ER:V5Z971T(&$@8^UM>F5T=/5L+@!!(&QE
M=NEL('1I=&MO<^UTX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S('-Z
M_&MSZ6=E<RX`02!D:6=I=.%L:7-A;B!A;.'M<G0@;&5VZ6P@96QL96[U<GKI
M<^EH97H@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,@<WK\:W/I9V5S+@!!('1I
M=&MO<^UT;W1T(&QE=NEL(&1E:_-D;VSA<^%H;WH@96=Y(&YY:6QVX6YO<R!0
M1U`@:W5L8W,L(&5G>2!T:71K;W,@4$=0(&MU;&-S(.ES(&5G>2!J96QM;VYD
M870@<WK\:W/I9V5S+@!!(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%SX6AO>B!E
M9WD@;GEI;';A;F]S(%!'4"!K=6QC<RP@96=Y('1I=&MO<R!01U`@:W5L8W,@
MZ7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG97,N`$$@=&ET:V]S[71O='0@;&5V
MZ6P@9&5K\V1O;.%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<RP@
M96=Y('1I=&MO<R!3+TU)344@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK
M<^EG97,N`$$@;&5VZ6P@9&EG:73A;&ES(&%LX>URX7/A:&]Z(&5G>2!N>6EL
M=N%N;W,@4R]-24U%(&MU;&-S+"!E9WD@=&ET:V]S(%,O34E-12!K=6QC<R#I
M<R!E9WD@:F5L;6]N9&%T('-Z_&MSZ6=E<RX`02!L97;I;"!T:71K;W/M=.%S
MX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<R!S>OQK<^EG97,N`$3I
M;&5L]71T(&)O<G5L="#I9P!$Z6QE;/5T="!G>65N9V4@97/U`$3I;&5L]71T
M(&5S]0!$Z6QE;/5T=&D@>N%P;W)O:P!$Z6QE;/5T="!H\WKA<&]R;VL`9&4O
M9'4`R5,`05!)($E$("AA('!R;V=R86UO>N%S:2!F96S\;&5T(&%Z;VYO<^UT
M\VIA*0!%<G+U;"!A>B!E9&ET;W)R\VP`3NEV:F5G>2XN+@!A8G-Z(&%L=6P`
M86)S>B!K]GKI<`!&;V=A9&IU:R!E;"!A(&UE9VCM=N%S="#I<R#M<FIU:R!B
M92!A>B!E<V5MZ6YY="!A(&YA<'3A<G5N:V)A`&5L9F]G861O;2!A(&UE9VCM
M=N%S=`!E;&9O9V%D=F$`16QF;V=A9'9A.B``3FEN8W,@:F]G;W-U;'1SX6=A
M(&$@5D93(&%L:_9N>79TX7(@;.ET<F5H;WKA<^%H;WHN`$YI;F-S(&IO9V]S
M=6QT<^%G82!A(%9&4R!FX6IL(&SI=')E:&]ZX7/A:&]Z+@!"96IE;&5N=&ME
M>NES:2!I;F9O<FWA8VGS`$IE;'-Z\P!!(&IO9V]S=6QT<^%G(&9E;"!V86X@
M9OQG9V5S>G1V92X`07H@X71T]FQTZ7-H97H@=N%L87-Z=&]T="!E;&YE=F5Z
MZ7,Z`%#I;GK\9WEE:P!,96AE=/5SZ6=E:P!"979I=&5L`&%D:G5K(&AO>GKA
M("5S+70@82!C[6UJ96=Y>NEK96UH97H`06QC<V]P;W)T(&SI=')E:&]ZX7-A
M`$IO9V]S=6QT<^%G:2!A;&-S;W!O<G0@;.ET<F5H;WKA<V$`061D:G5K(&AO
M>GKA(&ET=#H`VFH@8W-O<&]R="!LZ71R96AO>N%S80#::B!J;V=O<W5L='/A
M9R!LZ71R96AO>N%S80!!;&-S;W!O<G0@:&]Z>N%A9.%S82`B)7,B+6AE>@!*
M;V=O<W5L='/A9VD@86QC<V]P;W)T(&AO>GKA863A<V$@(B5S(BUH97H`VFH@
M9F5L:&%S>F[A;/,@;.ET<F5H;WKA<V$Z`-IJ(&]S>FQO<"!H;WIZX6%DX7-A
M`-IJ('1A9V]K(&9E;';I=&5L90#::B!PX7(@:&]Z>N%A9.%S80!A9&IU:R!H
M;WIZX0!!*'HI("5S(&UE;OQT(&%D:G5K(&AO>GKA(&$@36]Z:6QL82!M96[\
M<V]R:&]Z`&%D:G5K(&AO>GKA(&$@;F%P=.%R86UH;WH`061J=6L@:&]Z>N$@
M82!C[6UJ96=Y>NEK:&5Z.@!!9&IU:R!H;WIZX2!A(&/M;6IE9WEZZ6ME;6AE
M>@!A9&IU:R!H;WIZX2!A(&YA<'3A<F%M:&]Z`-IJ(&9E;&AA<WINX6SS(&AO
M>GKA863A<V$`(B5S(BUT(&UE;&SI:VQE=&OI;G0@8W-A=&]L='5K+@`B)7,B
M(&9E;&AA<WINX6SS="!H;WIZX6%D='5K(&$@<F5N9'-Z97)H97HL(&1E(&YE
M;2!S:6ME<OQL="!A('3V8F)I(&)E:F5L96YT:V5ZZ7-I(&%D870@=.%R;VSA
M<V$Z("5S+@`B)7,B(&9E;&AA<WINX6SS="!F96QV971TZ6L@82!R96YD<WIE
M<F)E+B!-;W-T(&WA<B!B96IE;&5N=&ME>FAE="X`02!R96YD<WIE<FAE>B!N
M96T@861H873S:R!H;WIZX2#Z:B!F96QH87-Z;N%L\VLN`$$@<WIO:^%S;W-A
M:V]N(&OM=OQL(&UE;'D@9F5J;.EC<V]R;VMA="`H;6%I;"!H96%D97(I(&OM
M=N%N(&UE9VIE;&5N[71T971N:2`\96T^*&YE;2!K]G1E;&5Z]2P@;6EN9&5N
M(&9E:FSI8W-O<B!K_&SV;B!S;W)B82!K97+\;&KV;BD\+V5M/@!4;W;A8F)I
M(&EN9F]R;>%C:?,@;.%T:&%T\R`E<RX`5&]VX6)B:2!RZ7-Z;&5T97,@:6YF
M;W)MX6-I\P!4;W;A8F)I('+I<WIL971E:P!!>B#\>F5N970@=&]VX6)B:2!R
MZ7-Z;&5T96D@;.%T:&%T\VL@)7,N`%1O=N%B8FD@<NES>FQE=&5S(&AI8F'\
M>F5N970`5&]VX6)B:2!RZ7-Z;&5T97,@:&EB8?QZ96YE="!LX71H873S("5S
M+@!#[6T`0^UM:F5G>7KI:P!#[6UJ96=Y>NEK96L`365L>2!C[6UE:W)E(&OM
M=N%N(&UI;F1E;B!E;&O\;&3V='0@;&5VZ6QR]6P@(D)#0R(@;>%S;VQA=&]T
M(&O\;&1E;FDZ(#QE;3XH;F5M(&OV=&5L97KU+"!M:6YD96X@8^UM(&O\;/9N
M('-O<F)A(&ME<OQL:O9N*3PO96T^`$%Z;VL@82!C[6UE:RP@;65L>65K<F4@
MZ7)K97KU(&QE=F5L96ME="!E:&AE>B!A>B!A>F]N;W/M=/-H;WH@:^UVX6X@
M:_9T;FD@/&5M/BAN96T@:_9T96QE>O4L(&UI;F1E;B!C[6T@:_QL]FX@<V]R
M8F$@:V5R_&QJ]FXI/"]E;3X`061M:6YI<WIT<N%C:?,@+2!J;V=O<W5L='/A
M9V]K(&%DX7-A('1O=N%B8FD@9F5L:&%S>F[A;/-K;F%K`$%D;6EN:7-Z='+A
M8VGS`$AI<F1E=.ES96L`069G86YI<WITX6X`06QBX6YI80!!;&?I<FEA`$%L
M:6%S`$5L:&5L>65ZZ7,`4F5N9&5ZZ7,Z`&%Z(/9S<WIE<V5T`$UI;F1E;B!N
M96T@=F5N9.EG(&9E;&AA<WINX6SS`$UI;F1E;B!C<V]P;W)T`$UI;F1E;B!J
M;V=O<W5L='/A9P!-:6YD(&$@;NEG>2!O;&1A;&]N(&QE9WEE;B!K97)E=`!!
M(&OV=F5T:V5Z]2!M87!P82AK*2!T87)T86QM82!L973V;.ES<F4@:V5R_&P@
M96=Y('-T86YD87)D(&UB;W@@9F]R;>%T=6WZ(&;A:FQB83H`07H@UFX@(B5S
M(B!M87!PX6KA8F%N(&%Z(/9S<WIE<R`E<R!N87!NX6P@<NEG96)B:2!L97;I
M;"!VZ6?I<G;I;GEE<V5N('3V<FSU9&YI(&9O9RX`07H@]G-S>F5S+"`E<R!H
M\VYA<&[A;"!RZ6=E8F)I+"!H:79A=&MO>N%S(&9O<FWA:N%B86X@:_QL9/9T
M="!M96QLZ6ML970@97)E9&5T:2!PZ6QDX6YYX70@=/9R]FQJ_&LN`$$@)7,@
M:/-N87!O<V[A;"!RZ6=E8F)I+"!E;&O\;&3V='0@;&5V96QE:V5T('1A<G1A
M;&UA>O,@*'-E;G0M;6%I;"D@;6%P<.%K('3V<FSI<W)E(&ME<OQL;F5K+@`B
M)7,B(&UA<'#A:&]Z('3V<G3I;O4@:&]Z>N%FZ7+I<VD@:F]G;VMA="!S:6ME
M<F5S96X@;65G=F]N='5K("(E<R(@9F5L:&%S>F[A;/-T\VPN`$5N9V5D:OQK
M(&UE9R!M87!PX6L@;.ET<F5H;WKA<^%T/P!!('-Z^W+I<VD@<WIA8N%L>6]K
M870@8N%R;65L>6EK(&UA<'#A<F$@96YG961J_&L@86QK86QM87IN:3\`16YG
M961J_&YK(&UE9R!T]F)B(&/M;65T(&ES`$$@<V]R<WKA;6]S(&9E;'-O<F]L
MX7,@=.UP=7-A(';A;'1O>G1A=&AA=/,@;&5G>65N/P!-X7(@;.ET97II:P!)
M35-0(&)E:F5L96YT:V5ZZ7-I('!A<F%MZ71E<F5K`$WA<VEK+"!)35-0(&IE
M;'-Z\P!-X7-I:RP@24U34"!B96IE;&5N=&ME>NES:2!NZ78`3>%S:6L@96UA
M:6P@8^UM`$%L=&5R;F%T[78@<V%B;&]N;VL`06QT97)N873M=B!S>O9V96<Z
M`$5N;F5K(&$@<NES>FYE:R!A>B!A;'1E<FYA=.UV(';A;'1O>F%T86DZ`&UI
M;F1I9P!-:6YD:6<@;65N='/\:R!E;"!A(&UE;&SI:VQE=&5K970N`$%M97)I
M:V%I(%-Z86UO80!(:6)A('3V<G3I;G0@82!M96QLZ6ML971N96L@82!L97;I
M;'+U;"!T]G)TZ6[U(&QE=N%L87-Z=.%S82!S;W+A;BX@07H@24U!4"!S>F5R
M=F5R(/QZ96YE=&4Z(`!!(&UE9V%D;W1T(.ER=.EK(&YE;2!F;V=A9&AA=/,@
M96PN`$ES;65R971L96X@:&EB82!T]G)TZ6YT+@!!>B#Z:B!F96QJ96=Y>NES
M(&SI=')E:&]ZX7-A('-O<N%N('9A;&%M:2!H:6)A('3V<G3I;G0N`$%Z(/IJ
M(&9E;&%D870@;.ET<F5H;WKA<V$@<V]RX6X@=F%L86UI(&AI8F$@=/9R=.EN
M="X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;FEM('!R;WAY;B!K97)E
M<WIT_&QI(&EN=&5R;F5T(&5LZ7+I<P!6X6QA<WH`;65G=N%L87-Z;VQT`$UE
M9W;A;&%S>F]L="!L979E;&5K`$%N=&%R:W1I<WH`06YT:6=U82#I<R!"87)B
M=61A`$%L:V%L;6%ZX7,`06QK86QM87KA<V]K(&QI<W3A:F$`07H@86QK86QM
M87KA<R!KZ7-Z+@!+87!C<V]L:G5K(&)E(&$@<WK[<O5K970`06QK86QM87IZ
M=6L@82!S>OMR]6ME="`E<RUR90!!('-Z^W+I<VD@<WIA8N%L>6]K870@82!B
M96IE;&5N=&ME>NES:V]R(&%L:V%L;6%Z>G5K/P!!;&MA;&UA>GIU:R!A('-Z
M^W+I<VD@<WIA8N%L>6]K870@87H@24Y"3U@@;6%P<&$@;6EN9&5N(&UE9VIE
M;&5N[73I<V4@97-E=.EN/P!!(&OV>O9S('3A<G1E<OQL970@86QC<V]P;W)T
M:F%I<F$@:7,@Z7)VZ6YY97,`2O-VX6AA9WGA<P!+]G+\;&)E;/QL:2!MZ7)E
M=`#A<')I;&ES`&%R86(@*%=I;F1O=W,M,3(U-BD`02!T]FWV<NUT971T(.%L
M;&]MX6YY(&WI<F5T90!!('3V;?9R[71E='0@X6QL;VWA;GD@;F5V90!":7IT
M;W,L(&AO9WD@=/9R]FQN:2!A:V%R:F$@97IT('9I<G1UX6QI<R!M87!PX70_
M`$)I>G1O<RP@:&]G>2!T]G+V;&YI(&OM=N%N:F$@97IT(&$@;GEI;';A;F]S
M(&MU;&-S;W0_`$)I>G1O<V%N('3V<O9L;FD@86MA<FIA(&$@<V%JX70@:W5L
M8W-PX7)JX70_("A%>B!.14T@86KA;FQA=&]S(2D`0FEZ=&]S+"!H;V=Y(&5Z
M="!K[7;A;FIA('1E;FYI/P!":7IT;W,@8F5N;F4L(&AO9WD@=/9R]FQN:2!K
M[7;A;FIA("5S(&)E:F5L96YT:V5ZZ7-I(&EGZ6YYZ70_`$)I>G1O<RP@:&]G
M>2!6R4?)4E;)3EE%4T5.('3V<O9L;FD@:^UVX6YJ82!E>F5K970@82!L979E
M;&5K970_`$)I>G1O<RP@:&]G>2!6R4?)4E;)3EE%4T5.('3V<O9L;FD@:^UV
MX6YJ82!E>G0@82!M96QLZ6ML971E=#\`0FEZ=&]S+"!H;V=Y('3V<O9L;FD@
M86MA<FIA("(E<R(M="!A;&-S;W!O<G1J86EV86P@96=Y_'1T/P!":7IT;W,L
M(&AO9WD@:VD@<WIE<F5T;ND@_'+M=&5N:2!E>G0@82!M87!PX70_`$)I>G1O
M<RP@:&]G>2!K:2!S>F5R971NZ2#\<NUT96YI(&$@<W!A;2!A(&UA<'#A=#\`
M0FEZ=&]S+"!H;V=Y(&MI('-Z97)E=&[I(/QR[71E;FD@82!S>F5M971E<R`H
M5')A<V@I(&$@;6%P<.%T/P!":7IT;W,@86)B86XL(&AO9WD@=NEG;&5G('3V
M<O9L;FD@:^UVX6YJ82!E>F5K970@82!L979E;&5K970_`$)I>G1O<RP@:&]G
M>2!N96US<&%M;F5K(&OM=N%N:F$@;6EN]7/M=&5N:2!E>G0@82!L979E;&5T
M(&$@;&5V96QE>O5R96YD<WIE<B!S>N%MX7)A/P!":7IT;W,L(&AO9WD@<W!A
M;6YE:R!K[7;A;FIA(&UI;O5S[71E;FD@97IT(&$@;&5V96QE="!A(&QE=F5L
M97KU<F5N9'-Z97(@<WKA;>%R83\`07)G96YT[6YA`-9R;>EN>6]R<WKA9P#V
M<FWI;GD@*$%235-#24DM."D`R7)K97KI<VD@:63U`$W[=NES>F5T`$%R=6)A
M`&[V=F5K=O4`4&]H;G!E:0!!<V-I:2!R86IZ;VL`P7IS:6$O0W-E;F1E<RWS
M8V7A;FD@<NEG:?,`=N%L87-Z=&AA<W-A:P!+Z7)J96X@82!R96YD<WIE<B!M
M96=E<O5S[73I<W0@82!K87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI
M<V4@96SU='0_`$AO>GKA<F5N9&5LZ7-I(&]S>FQO<&]K`$;A:FQO:R!C<V%T
M;VSA<V$`365L;.EK96QJ_&L@87H@UFX@4$=0(&YY:6QVX6YO<R!K=6QC<^%T
M(&$@;&5VZ6QH97H_`$-S871O;'0@9N%J;#H`02!M96QLZ6ME;&YI(&OM=N%N
M="`B)7,B(.%L;&]MX6YN>6%L('3Z;&SI<&[I(&$@;65L;.EK;&5T96L@;>ER
M973I<F4@=F]N871K;WKS(&MO<FSA=&]K870N($%Z(&;A:FQT($Y%32!C<V%T
M;VQT=6LN`$$@;65L;.EK;&5T8F5N(&%Z(-9N(&ED]6)E;W-Z=.%S:2!KZ7+I
M<^ER92!A9&]T="!VX6QA<WH@=F%N+@!-96QLZ6ML970`02AZ*2`E<R!M96QL
MZ6ML971E="!T]G+V;'3\:RX`02!M96QLZ6ML971E:R!A9&%T86D`02!M96QL
MZ6ML971E="!L97;A;&%S>G1O='1U:SH@87H@97)E9&5T:2!M96QLZ6ML970@
M=.UP=7-A`$UE;&SI:VQE=&5K`$YE;6SI=&5Z]2!C<V]P;W)T;W0@:^USZ7)E
M;'0@;65G('3V<O9L;FDN`$YE;6SI=&5Z]2!J;V=O<W5L='/A9V]T(&OM<^ER
M96QT(&UE9R!T]G+V;&YI+@!.96ULZ71E>O4@:F]G;W-U;'1SX6=O="!K[7/I
M<F5L="!M96<@;65G=N%L=&]Z=&%T;FDN`$YE;6SI=&5Z]2!K]GKV<R!TX7)T
M97+\;&5T970@:^USZ7)E;'0@;65G(&UE9W;A;'1O>G1A=&YI+@!2Z7-Z='9E
M=O5K`$9I9WEE;&UE>G1E=.ES`%1U;&%J9&]N<^%G;VL`875G=7-Z='5S`$%U
M<WIT<N%L:6$`075S>G1R:6$`075T:%]C>7)S<6PZ(&$@<WK\:W/I9V5S(&EM
M87`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H7V-Y<G5S.B!A(&CA='3I
M<G-Z;VQGX6QT873A<R!N96T@<F5N9&5L:V5Z:6L@82!K[7;A;G0@:^EP97-S
MZ6=E:VME;"X`075T:%]C>7)U<SH@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES
M(&YE;2!T86SA;&AA=/,N`$%U=&A?9G1P.B!A('-Z_&MSZ6=E<R!F='`@8O5V
M[73I<R!N96T@=&%LX6QH873S+B!&;W)D[71S82!L92!A(%!(4"UT(&%Z("TM
M96YA8FQE+69T<"!O<&-I\W9A;"X`075T:%]I;6%P.B!A('-Z_&MSZ6=E<R!I
M;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]I;7`Z(&$@<WK\:^EG
M97,@24U!4"!B]7;M=/5F=6YK8VGS(&YE;2!T86SA;&AA=/,N`$%U=&A?:W)B
M-3H@82!S>OQK<^EG97,@:W)B-2!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U
M=&A?;&1A<#H@;F5M(&AO>FAA=/-K(&SI=')E(/IJ(&9E;&AA<WINX6SS:R!!
M8W1I=F4@1&ER96-T;W)Y(&5S973I;@!!=71H7VQD87`Z(&9E;&AA<WINX6SS
M:R!N96T@=/9R]FQH973U:R!!8W1I=F4@1&ER96-T;W)Y(&5S973I;@!!=71H
M7VQD87`Z(&$@<WK\:W/I9V5S($Q$05`@8O5V[73I<R!N96T@=&%LX6QH873S
M+@!!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS(&AO>GKA863A<V$@;F5M('-I
M:V5R_&QT+B!!('-Z97)V97(@=N%L87-Z83H@`$%U=&A?;&1A<#H@)7,@9F5L
M:&%S>F[A;/,@=/9R;.ES92!N96T@<VEK97+\;'0`075T:%]L9&%P.B`E<R!F
M96QH87-Z;N%L\R!A9&%T86EN86L@;65G^FKM=.%S82!N96T@<VEK97+\;'0`
M075T:%]L9&%P.B!A(&9E;&AA<WINX6SS:R!N96T@;?-D;W/M=&AA=/-K($%C
M=&EV92!$:7)E8W1O<GD@97-E=.EN`$%U=&A?;6-A;#H@82!S>OQK<^EG97,@
M34-!3"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?<VUB875T:#H@82!S
M>OQK<^EG97,@<VUB875T:"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$YE;2!S
M:6ME<OQL="!A>B!)34%0('-Z97)V97)E;B!V86SS(&9E;&AA<WINX6SS87IO
M;F]S[73A<RX`02!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('-I:V5R_&QT
M+@!!(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@<VEK97+\;'0N("5S`$$@
M9F5L:&%S>F[A;/,@87IO;F]S[73A<^%T(&$@4D%$2553('-Z97)V97(@96QU
M=&%S[71O='1A+@!.96T@<VEK97+\;'0@87H@1E10('-Z97)V97)H97H@=F%L
M\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N`$YE;2!S:6ME<OQL="!A>B!334(@
M<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S+@!*96QE;NUT
M<_QK+64@;65G(&%U=&]M871I:W5S86X@82!(5$U,(&9O<FWA='5M^B!L979E
M;&5K8F5N(&QE=O4@:^EP96ME="P@:&$@82!F96QA9/,@;65G=&%LX6QH873S
M(&%Z(-9N(&/M;73A<N%B86X_`$$@<F5N9&5L:V5ZZ7-R92#A;&SS(&/M;6IE
M9WEZZ6ME:SH`02!R96YD96QK97KI<W)E(.%L;/,@;65Z]6LZ`';A;&%S>G)A
M(';A<@!!>F5R8F%J9'ISX6X`02!G;VYO<WH@<F5N9'-Z97)G87ID82!M96YT
M<^EG96D`5FES<WI?82`E<RUH97H`5FES<WIA("5S+6AE>@!6:7-S>F$@82!L
M97;I;&QI<W3A:&]Z`%9I<W-Z82!A(&QO9VEK86D@;NEZ971H97H`2.%T=.ER
M`$CA='3I<B!S>NUN`$YE;2!M96=F96QE;/4@:V5R8F5R;W,@:F5L<WKS+@!.
M96T@;65G9F5L96SU(&ME<F)E<F]S(&9E;&AA<WINX6SS;NEV+@!)<VUE<F5T
M;&5N(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!J96QS>O,N`$AI8N%S($E-05`@
M<&%R86YC<RX@02!S>F5R=F5R(';A;&%S>F$Z("5S`$AI8N%S(&QE:^ERZ7,Z
M("5S+@!"86AA;>%K`$)A:')E:6X`8F%L=&D@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97,`0F%R8F%D;W,`02!G<F%F:6MU<R#A;&QO;>%N>6]K("(E<R(@86QK
M]FYY=G3A<F$@;F5M('1A;.%L:&%T\RX`86QA<'9O;F%L;VX`0F-C`$9E:.ER
M;W)O<WIO<G-ZX6<`0F5L9VEU;0!"96QI>F4`06SA8F(@;.%T:&%T\R!A('-T
MX71U<WH@:6YF;W)MX6-I\R!N>65R<RP@<WKV=F5G97,@=N%L=&]Z871A+@!"
M96YI;@!"97)M=61A`$)H=73A;@!3>OQL973I<VYA<`!4:6QT\VQI<W1A`$$@
M(B5S(B!B;&]K:R!A("(E<R(@<')O9W)A;6UA;"!N96T@=&%LX6QH873S+@!+
MZ7!E<FYY]7+I<WH@8F7A;&SM=.%S`$OI<&5R;GGU<NES>B!T[7!U<P!4:6QT
M<W5K+64@;&4@82!(5$U,(&9O<FWA='5M^B!L979E;&5K8F5N(&QE=O4@:^EP
M96L@:^ERZ7,@;NEL:_QL:2P@875T;VUA=&EK=7,@;65G:F5L96[M=.ESZ70_
M`$QE=NEL=/9R>G,`9NEL:_9VZ7(`0F]L[79I80!+961V96YC('=E8F/M;65K
M`$ME<F5T`$ME<F5T=F%S=&%G<^%G.@!+97)E=&5K`$)O<WIN:6$M2&5R8V5G
M;W9I;F$`36EN9&ME='3U`&$@9F5J;.EC8F5N('9A;/,@9F5L<V]R;VSA<R#I
M<R!A(&QE=NEL=/9R>G-B96X@=F%L\R!M96=J96QE;NUTZ7,@:7,`0F]T<W=A
M;F$`86QU;`!";W5V970M<WII9V5T`$)R87KM;&EA`$)R:70@26YD:6%I+?-C
M9>%N:2!497+\;&5T`$)R=6YE:2!$87)U<W-A;&%M`$)U;&?A<FEA`$9E;'-O
M<F]LX7,`0G5R:VEN82!&87-O`$)U<G5N9&D`5V5B;VQD86P@:V%R8F%N=&%R
M=.%S`$$@0U)!32U-1#4@:6QL+B!A($1)1T535"U-1#4@:&%S>F[A;&%TX6AO
M>B!T96QE<.UT96YI(&ME;&P@87H@075T:%]305-,(&-S;VUA9V]T+@!#4D,`
M02!T86[Z<^UT=N%N>79I<W-Z879O;N%S:2!L:7-TX6L@*$-23"D@8^UM96D`
M0V5L;&$@='5L86ID;VYSX6=O:P!?2V%R86MT97)KZ7-Z;&5T`$$@8V%C:&4@
M:6YI8VEA;&EZX6SA<V$@;F5M(&9E:F5Z]63V='0@8F4N`$YA<'3A<@!.>75G
M;V1T`$MA;6)O9'IS80!+86UE<G5N`$$@=.%V;VQI(&QE=F5L97KU<WIE<G9E
M<B!N96T@Z7)H973U(&5L+@!!('3A=F]L:2!L979E;&5Z]7-Z97)V97(@;F5M
M(.ER:&5T]2!E;#H@`$YE;2!J96QE;NUT:&5T]2!M96<@+2!A(&QE=NEL;F5K
M(&-S86L@)7,@9&%R86)JX70@=&%LX6QN:2!M96<@82AZ*2`E<RUB]6P@96)B
M96X@82!M87!PX6)A;BX`3F5M('-I:V5R_&QT(&$@:F5L<WKS="#A=.%L;.UT
M86YI+"!F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+@!!*'HI("(E<R(@
MX6QL;VWA;GD@;F5M(.UR:&%T\RX`02!K_&QS]2!F96QH87-Z;N%L\VMA<&-S
M;VQA="UK97IE;/5K(&YE;2!A9&UI;FES>G1RX6QH873S:RX`02!K]G9E=&ME
M>O4@24U!4"!S>F5R=F5R(&YE;2#I<FAE=/4@96PZ("5S`$$H>BD@(B5S(B#A
M;&QO;>%N>2!N96T@;GEI=&AA=/,@;65G+@!+86YA9&$`3>EG<V4`3>EG<V5M
M(&ME;&P@97H@82!L97;I;`!-Z6=S92!K_&QD]FL@:&EB86IE;&5N=.ES=`!!
M(&MI;.EPZ7,@:_9V971K97ITZ6)E;B!E(&QE=NEL('1A<G1A;&UA(';I9VQE
M9V5S96X@96QVZ7-Z+@!!*'HI("(E<R(@X6QL;VWA;GD@;F5M('3V<O9L:&5T
M]2X`3F5M('1A;.%L:&%T\R!A>B!I9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T
M87)T86QM87KS(&%L:_9N>79TX7(N`$$@)W1A<F=E=$9I;&4G('!A<F%MZ71E
M<B!M96=A9.%S82!NZ6QK_&P@;F5M(&9O;'ET871H871J=6LN`$$H>BD@(B5S
M(B!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N`$YE;2!T]G+V;&AE=/4L("5D
M(&%L8W-O<&]R=&IA('9A;BX`07H@^FH@<V]R8F%R96YD97KI<R!N96T@;&5H
M971SZ6=E<RP@82!M96=A9&]T="!A9&%T;VL@<WKA;6$@;F5M(&5G>65Z:6L@
M82!TX7)O;'1A:^EV86PN`$$@;65G861O='0@<WKA;7)A(&YE;2!K_&QD:&5T
M]2!E;"!A>B#\>F5N970N`%KV;&0M9F]K:2US>FEG971E:P#!8G)A<WKV=F5G
M`%-Z;VQGX6QT873S`$MA=&5G\W)IX6L@Z7,@:F5L]FSI<_QK`$MA:FWA;BUS
M>FEG971E:P!#8P!-;V)I;"!T96QE9F]N`$-E;&QA='5L86ID;VYSX6=O:P!#
M96QL82!B96QS]2!M87)G\SH`0V5L;&%T=6QA:F1O;G/A9V]K`$-E;&SA:R!K
M]GKV='1I('+I<SH`36]B:6P@=&5L969O;@!K96QT82`H25-/+3@X-3DM,30I
M`&OV>NEP`$OV>NEP+6%F<FEK86D@2_9Z=.%R<V%SX6<`:V5L970M975R\W!A
M:2`H25-/+3@X-3DM,BD`02!T86[Z<^UT=N%N>2!RZ7-Z;&5T96D`02!T86[Z
M<^UT=N%N>2!T=6QA:F1O;F]S80!486[Z<^UT=N%N>2!F96QH87-Z;N%LX7-I
M(&ERX6YY96QV96L`02!T86[Z<^UT=N%N>2!N96T@:6UP;W)TX6QH873S+B!!
M('-Z97)V97)E;B!N:6YC<R!E;F=E9.EL>65Z=F4@87H@X6QL;VWA;GEO:R!F
M96QT]FQTZ7-E+@!#<^%D`$5L;O9K`%;A;'1O>G1A=.%S`%;A;'1O>G1A<W-U
M:R!M96<@87H@]G-S>F5S970`3>%S:6L@;6%P<&$@:VEVX6QA<WITX7-A`$$@
M:F5L<WKS(.%TX6QL[73A<V$`365G:F5L96[M=.ES:2!B9>%L;.UTX7-O:RP@
M<&PN(&QI<W3A>N%S:V]R(&CA;GD@;&5VZ6P@:V5R_&P@96=Y(&]L9&%L<F$L
M(&$@;&5V96QE:R!S;W)R96YD:F4@<W1B+@!!(&QE=F5L97KU<WIE<G9E<BT@
M:6QL+B!M87!P86)EX6QL[73A<V]K(&UE9W;A;'1O>G1A=.%S82X`07H@UFX@
MX6QT86P@96QK_&QD]G1T(&QE=F5L96ME;B!S>F5R97!L]2!NZ78@Z7,@8^UM
M(&UE9W;A;'1O>G1A=.%S82X`07H@UFX@X6QT86P@96QK_&QD]G1T(&QE=F5L
M96ME;B!S>F5R97!L]2!NZ78L(&/M;2P@X6QL86YD\R!L97;I;';I9WKU9.ES
M("AS:6=N871U<F4I(&)EX6QL[73A<V$N`$$@:F5L96X@:V]N9FEG=7+A8VGS
M8F%N(&YE;2!L96AE='/I9V5S(&$@:F5L<WIA=F%K(&WS9&]S[73A<V$N($9O
M<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN`$MA<F%K=&5R`$CA;GD@:V%R
M86MT97)T(&UU=&%S<W5N:R!A(&QE=NEL(&5L96KI<O5L.@!,:6Y?:V5L;&5N
M]7)ZZ7,N+BX`16QL96[U<FEZ>OQK+"!H;V=Y(&KV='0M92#Z:B!L97;I;`!*
M96SV;&K\:R!K:2!M:6YD+V5G>6EK970@<V5M`$IE;/9L:F4@:VDL(&UE;'D@
M;&5V96QE>O5S>F5R=F5R96MR]6P@:^UVX6X@;&5V96QE:V5T(.%T=/9L=&5N
M:3H`16QL96[U<FEZ>OQK(&$@:&5L>65S[7+A<W0@82!L97;I;"!E;&O\;&3I
M<V4@96SU='0_`$-H:6QE`$OM;F$`:^UN86DL(&5G>7-Z97+[<^UT971T("A'
M0C(S,3(I`&OM;F%I+"!H86=Y;VWA;GEO<R`H0FEG-2D`36D@=/9R=.EN:F5N
M.@!6X6QA<W-Z;VX@:VD@96=Y(&%L:V%L;6%ZX7-T.@!6X6QA<W-Z;VX@;&5V
M96QE>O5S>F5R=F5R=#H`2^ER96TL(&AO9WD@:F]B8B!O;&1A;&D@;65Z]6)E
M;B!VX6QA<W-Z82!K:2P@=F%G>2!M\V1O<^UT<V$Z`%;A;&%S<WIO;B!J96QS
M>O-T`%;A;&%S<WIO;B!E9WD@9F5L:&%S>F[A;/-N979E=`!6X6QA<W-Z82!K
M:2!A(&3A='5M;VL@;65G:F5L96[M=.ES:2!F;W)MX6KA=#H`5N%L87-S>F$@
M:VD@82!F96QS;W)O;.%S('3M<'5SX70@*'-ZX6UO>F]T="!L:7-TX6MNX6PI
M`$UE;'EI:R!C[6UJ96=Y>NEK970@:^UVX6YJ82!H87-Z;N%L;FD@^FH@8^UM
M96L@<O9G>NUTZ7/I<F4N`$$@8^UM<NES>FQE="!T96QJ97,@8^UM;>D@86QA
M:^UTX7-A:V]R(&UI;'EE;B!S;W)R96YD8F5N(&ME<F5S<V5N(&$@9^EP(&$@
M8^UM:F5G>7KI:V5K8F5N+@!+87+A8W-O;GDM<WII9V5T96L`02AZ*2`E<R!C
M;&%S<R!D969I;NUC:?-J82!N96T@=&%LX6QH873S+@!$97+\;'0`5/9R;&D@
M87H@35-/9F9I8V4@=&%G96ME=`!!(&QE:^ER9&5ZZ7,@=/9R;.ES90`E<R!F
M96QH87-Z;N%L\R!T]G)LZ7-E`$$@9F5L:&%S>F[A;/,@=/9R;.ES90!!(&9E
M;&AA<WINX6SS(&%D871A:6YA:R!T]G)LZ7-E`$5S=.ER92!D97+\;'0@Z6<`
M)7,@:V%T=&EN='-O;BP@:&$@82!KZ7!E="!O;'EA;B!F;W)MX71U;7)A(&OM
M=N%N:F$@86QA:^UT86YI+"!A;6ET(&$@8O9N9^ES>O5P<F]G<F%M:F$@;65G
M('1U9"!J96QE;NUT96YI+@!(82!L92!S>F5R971NZ2!T]FQT96YI(&$@:^EP
M970L(&MA='1I;G1S;VX@)7,N`"5S(&MA='1I;G1S;VXL(&AA("5S(&UE;F5D
M>G-M96YT(&]L9&%LX7)A('-Z97)E=&YE(&UE;FYI+@`E<R!K871T:6YT<V]N
M+"!A($A434P@=&%R=&%L;VT@:_QL]FX@86)L86MB86X@=F%L\R!M96=J96QE
M;NUTZ7/I:&5Z+@`E<R!K871T:6YT<V]N+"!H82!A(&OI<&5T('!I8VEB96X@
M<WIE<F5T;ND@;.%T;FDN`"5S(&MA='1I;G1S;VXL(&$@;65L;.EK;&5T(&O\
M;/9N(&%B;&%K8F%N('9A;/,@;65G:F5L96[M=.ESZ6AE>BX`)7,@:V%T=&EN
M='-O;BP@82!M96QLZ6ML970@92!RZ7-ZZ6YE:R!K_&SV;B!A8FQA:V)A;B!V
M86SS(&UE9VIE;&5N[73I<^EH97HN`$MA='1I;G1S;VX@:61E(&$@:^EP96L@
M;65G:F5L96[M=.ESZ6AE>@!+871T:6YT<V]N(&%Z(&5G>6EK(&MI=N%L87-Z
M=&]T="!C[6UJ96=Y>NEK<F4L(&UA:F0@=N%L87-S>F$@:VDL(&AO9WD@;65L
M>6EK(&UE>O5K8F5N('3V<G3I;FIE;B!K97)E<^ES+@!!(&9O;'ET873A<VAO
M>B!K871T:6YT<V]N(&%Z(&5GZ7)R96P`2V%T=&EN='-O;B!I9&4L(&AA(&/M
M;6IE9WEZZ6OI8F5N(&5L(&OM=N%N:F$@=.%R;VQN:2!E>G0@82!01U`@;GEI
M;';A;F]S(&MU;&-S;W0`2V%T=&EN='-O;B!A($UE;G3I<R!F96QI<F%T<F$L
M(&AA(&/M;6IE9WEZZ6OI8F5N(&5L(&OM=N%N:F$@=.%R;VQN:2`E<R!3+TU)
M344@=&%N^G/M=';A;GGA=`!#;&EC:V%T96QL('-Z;VQGX6QT873A<R!(5%10
M+6X@:V5R97-Z=/QL`$$@8^UM<F4@:V%T=&EN='9A(&$@^FH@;&5V96QE="#M
M<FAA='5N:R!A(&9E;&%D\VYA:P!!(&/M;7)E(&MA='1I;G1V82!M96=N>>UL
M:6L@82!L97;I;`!"97KA<N%S`$%Z(&%B;&%K(&)E>N%RX7-A`$%Z(&%B;&%K
M(&)E>N%RX7-A`%KA<G0@;6%P<&$`0F]R=6QT(.EG`%)E9V=E;"!F96QH]7,@
M:63U`$9E;&CU<R!I9/4`2_-K=7-Z+7-Z:6=E=&5K`$-S=6MJ=6L@8F4`0W-U
M:VIU:R!B92!A>B#V<W-Z97-E=`!#<W5K:G5K(/9S<WIE(&%Z(/9S<WIE<R!M
M87!PX70`0W-U:VIU:R#V<W-Z92!A(&UA<'#A=`!4_&YT97-S_&L@96P@87H@
M;VQD86QS\R!M96[\=`#6<W-Z97KA<G0@:V5R971E:P!+;VQU;6)I80!3>NUN
M`%-Z[6YJ96SV;.ES.B``4WKM;G;A;&%S>G3S`%-Z[6YVX6QA<WITX7,`3W-Z
M;&]P;VLZ`$%Z(&]S>FQO<&]K(&/M;65I`%9I8V-E:P!087)A;F-S`%!A<F%N
M8W/I<G1E;&UE>O4`365G:F5G>7KI<P!.Z78L(&5L;F5V97KI<P!#;VUO<F4M
M<WII9V5T96L`0^EG`&)E9F5J97IV90#::F%B8B!L97;I;"#M<N%S80!!(&QE
M=NEL[7+A<R!K_&SV;B!A8FQA:V)A;B!T]G)TZ6YJZ6L_+@!,979E;&5I="!(
M5$U,+6)E;B!K[7;A;FIA(.UR;FD@86QA<.ER=&5L;65Z971T(&AE;'EZ971B
M96X@*&9E;'3I=F4L(&AO9WD@8O9N9^ES>O5P<F]G<F%M:F$@=.%M;V=A=&IA
M(&5Z="!A(&QE:&5T]7/I9V5T*3\`4WKA;>UT\V?I<&5K`$ED]6KA<N%S:2!H
M96QY>F5T`$ED]6KA<N%S:2!H96QY>F5T`$O\;/9N8G/I9V5K(&$@:V]N9FEG
M=7+A8VGS8F%N`$OI>FES>N%M[73S9^EP96MK96PL(&]K;W-T96QE9F]N;VMK
M86PL($]U=&QO;VMK86P@=F%L\R!A9&%T<WII;FMR;VYI>N%LX7,@:V]N9FEG
M=7+A8VGS:F$`02!K;VYF:6=U<N%C:?,@;>%R(&YE;2#I<G;I;GEE<RX`)7,@
M:V]N9FEG=7+A8VGS:F$`02!L979E;&5K(&UE9VIE;&5N[73I<^EN96L@8F7A
M;&SM=.%S86DN`$5L]6[I>F5T:2`H;6%I;"!P<F5V:65W*2!B9>%L;.UTX7-O
M:RX`02!J96QS>O,@;65G97+U<^UTZ7-E`$MO;F?S`$MO;F?S:2!$96UO:W)A
M=&EK=7,@2_9Z=.%R<V%SX6<`07H@24U!4"!S>F5R=F5R(&UE9W-Z86OM=&]T
M=&$@82!K87!C<V]L871O="X`4VEK97)T96QE;B!A(&MA<&-S;VQA="X`4VEK
M97)T96QE;B!A(&MA<&-S;VQA=#H@`$$@;GEI;';A;F]S(&MU;&-S;VL@<WIE
M<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA=&]T+@!!(&YY:6QVX6YO<R!K
M=6QC<V]K('-Z97)V97)E(&5L=71A<^UT:F$@82!K87!C<V]L871O="X@3VMA
M.B`E<R`H)7,I`%-I:V5R=&5L96X@87H@1E10('-Z97)V97)R96P@=F%L\R!K
M87!C<V]L870N`$$@<WIE<G9E<G)E;"!N96T@=F5H973U(&9E;"!A(&MA<&-S
M;VQA=`!087)T;F5R96L`02!P87)T;F5R96ME="!S:6ME<F5S96X@:&]Z>N%A
M9'1U:R!A(&/M;6IE9WEZZ6OI:&5Z+@!!('3V;?9R[71E='0@X6QL;VWA;GD@
M=.UP=7-A.B``(B5S(B!T87)T86QM80!&;VQY=&%TX7,`)7,@4$=0('3A;6]G
M873A<^%N86L@8F7A;&SM=.%S86DN`"5S(%,O34E-12!TX6UO9V%TX7/A;F%K
M(&)EX6QL[73A<V%I+@!!(&QE=F5L96L@:_9Z]G1T:2!K97)E<^ES<V5L(&MA
M<&-S;VQA=&]S(&)EX6QL[73A<V]K+@!-:6MO<B!E;&QE;O5R:7IZ_&L@^FH@
M;&5V96QE:R#I<FME>NESZ70L(.ES(&MA<&IO;BUE(.ER=&5S[73I<W0@87H@
M^FH@;&5V96QE:R#I<FME>NES96MO<BX`07H@Z7)Z96QE;73\:W+V>O4@<WKV
M=F5G97,@:V%R86MT97)C<V]P;W)T;VMA="`H96UO=&EC;VYS+"`B<VUI;&5Y
M<R(I(&-S97+I;&K\:R!G<F%F:6MU<R!I:V]N;VMR83\`0V]O:RUS>FEG971E
M:P!3_'1I`$WA<V]L:G5K(.%T`$$@;>%S;VSA<R!N96T@<VEK97+\;'0Z("5S
M`$$@:VEJ96SV;'0@<NES>B!MX7-O;.%S80!-X7-O;&IU:R!I9&4`2&EBX71L
M86X`2F%V[71O='0@<WKV=F5G`%-ZX6ULX7KA<VD@87IO;F]S[73S`$-O<W1A
M(%)I8V$`16QE9N%N=&-S;VYT<&%R=`!.96T@<VEK97+\;'0@4$=0+79E;"!T
M:71K;W/M=&%N:2!A(&QE=F5L970Z(`!!(&QE=F5L970@;F5M('-I:V5R_&QT
M(%!'4"!A;.'M<N%S<V%L(&5L;.%T;FDZ(`!!(&QE=F5L970@;F5M('-I:V5R
M_&QT(&%Z(%,O34E-12!S>F%B=N%N>2!S>F5R:6YT('1I=&MO<^UT86YI+@!!
M(&QE=F5L970@;F5M('-I:V5R_&QT(%,O34E-12!A;.'M<N%S<V%L(&5L;.%T
M;FDN`$$@<&%R=&YE<B!A9&%T86ET(&YE;2!S:6ME<OQL="!E;'3A<F]L;FDN
M("5S`$%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+@!.96T@<VEK97+\
M;'0@96QL96[U<FEZ;FD@82!S>N%M;.%JX6X@<F5N9&5L:V5ZZ7-R92#A;&SS
M(/9S<WIE9V5T+B`E<P!!(&OI<NES="!N96T@<VEK97+\;'0@=NEG<F5H86IT
M86YI+B!!>B!O:R!A(&OV=F5T:V5Z]3H@)7,`3F5M('-I:V5R_&QT(&%Z($Q$
M05`@<WIE<G9E<FAE>B!K87!C<V]L\V1N:2X`3F5M('-I:V5R_&QT(&$H>BD@
M(B5S(B!S>F5R=F5R<F5L($944"!K87!C<V]L871O="!F96QV96YN:3H@)7,`
M3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@82!K]G)L97;I;&QI<W3A="X@)7,`
M02!61E,@:.%T=.ER<')O9W)A;2!N96T@:&]Z:&%T\R!LZ71R93H@)7,`07H@
M861A=&]K(%!'4"!T:71K;W/M=.%S8O-L('3V<G3I;O4@9&5K\V1O;.%S82!N
M96T@<VEK97+\;'0Z(`!!>B!A9&%T;VL@4R]-24U%('1I=&MO<^UTX7-B\VP@
M=/9R=.EN]2!D96OS9&]LX7-A(&YE;2!S:6ME<OQL="X`02!P87)T;F5R('3V
M<FSI<V4@;F5M('-I:V5R_&QT+B`E<P!!(&OV<FQE=NEL;&ES=&$@=/9R;.ES
M92!N96T@<VEK97+\;'0N("5S`$YE;2!S:6ME<OQL="`E<RUB]6P@=/9R]FQN
M:2!A(&QE=F5L96ME="X@02!S>F5R=F5R(/QZ96YE=&4Z("5S`$YE;2!S:6ME
M<OQL="!T]G+V;&YI(&$H>BD@(B5S(B!S971U<"!U<&=R861E('!R;V=R86UO
M="X`3F5M('-I:V5R_&QT(&UE9^%L;&%P[71A;FD@82!C[6UZ971T(&5M86EL
M(&/M;>ET+@!.96T@<VEK97+\;'0@96QVZ6=E>FYI(&$@:V%R8F%N=&%R=.%S
M:2!F96QA9&%T;VMA="X`02!K[7;A;G0@X6QL;VWA;GET(&YE;2!S:6ME<OQL
M="!K:6YY97)N:2!A>B!-4RU43D5&(&UE;&SI:VQE=&+U;"X`02!K[7;A;G0@
MX6QL;VWA;GET(&YE;2!S:6ME<OQL="!K:6)O;G1A;FD@82!::7`@9N%J;&+S
M;"X`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A('1E;&IE<R!C[6UJ96=Y>NEK
M970N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@:_9R;&5VZ6QL
M:7-TX70N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A
M:R!T96QJ97,@9F5L<V]R;VSA<^%T+@!!*'HI("(E<R(@<W1R873I9VEA(&YE
M;2!T86SA;&AA=/,N`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!H;WIH873S
M(&SI=')E+@!!(&YY:6QVX6YO<R!K=6QC<V]T(&YE;2!S:6ME<OQL="!M96=S
M>F5R97IN:2!A(&MU;&-S<WIE<G9E<G+U;"X`3F5M('-I:V5R_&QT("(E<R(M
M="#M<N%S:2!CZ6QL86P@;65G;GEI=&YI+@!.96T@<VEK97+\;'0@)7,M="!M
M96=N>6ET;FDN`$$@)7,@:V%R8F%N=&%R=.%S:2!M;V1U;"!N96T@;GEI=&AA
M=/,@;65G`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!N>6ET:&%T\R!M96<N
M`$YE;2!S:6ME<OQL="!A('1I=&MO<^UT;W1T(&MA<&-S;VQA="!F96QVZ71E
M;&4@87H@24U!4"!S>F5R=F5R<F5L+B`E<R`Z("5S+@!!>B!,1$%0('-Z97)V
M97(@;F5M(.ER:&5T]2!E;"X`)7,@;F5M(&]L=F%S:&%T\RX`3F5M('-I:V5R
M_&QT(&$@:^UVX6YT(&9E;&AA<WINX6SS(&IE;'-Z87;A="#A=.%L;.UT86YI
M+B!!>B!M96=A9&]T="!A9&%T;VL@;F5M('9A9WD@;F5M('1E;&IE<V5N(&9E
M;&5L;F5K(&UE9RX@4'+S8N%L:F$@^FIR82P@=F%G>2!H82!T;W;A8F)I('-E
M9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+"!F;W)D=6QJ;VX@82!R96YD<WIE<F=A
M>F3A:&]Z+@!.96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&%Z(&5LZ7+I<VD@
M:F]G;W-U;'1SX6=O:V%T("A!0TPI`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@
M82!C[6UJ96=Y>NEK970N("5S`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K
M]G)L97;I;&QI<W3A="X@)7,`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV
M<FQE=NEL;&ES=.%K870N("5S`$%Z($E-05`@<WIE<G9E<G3U;"!N96T@<VEK
M97+\;'0@;65G:V%P;FD@82`B;F%M97-P86-E(B!A9&%T;VMA="X`3F5M('-I
M:V5R_&QT(&UE9VAA=.%R;WIN:2!A('-Z97)V97(@:^EP97-SZ6=E:70`3F5M
M('-I:V5R_&QT('9I<W-Z8>%L;.UT86YI(&5Z(&5R961E=&D@:V]N9FEG=7+A
M8VGS="X`02AZ*2`B)7,B(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2X`3F5M
M('-I:V5R_&QT(&5L;65N=&5N:2`E<R!K;VYF:6=U<N%C:?-T+@!.96T@<VEK
M97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I\W0N`$YE;2!S
M:6ME<OQL="!E;&UE;G1E;FD@82!B86-K=7`@:V]N9FEG=7+A8VGS=#H@)7,`
M3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A*'HI("(E<R(@<V5T=7`@=7!G<F%D
M92!P<F]G<F%M;W0N`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82AZ*2`E<R!B
M86-K=7`@:V]N9FEG=7+A8VGS="X`02AZ*2`E<R!K;VYF:6=U<N%C:?-S(.%L
M;&]MX6YY="!N96T@<VEK97+\;'0@96QM96YT96YI+B!686=Y(&AA<WINX6QJ
M82!A("5S(&]L9&%L;VX@;&5V]2!L96AE=/5SZ6=E:V5T+"!V86=Y(&WA<V]L
M:F$@X70@87H@86SA8F)I(&OS9&]T(&ED93H@)7,N`$%Z($Q$05`@<WIE<G9E
M<F5N(&YE;2!S:6ME<OQL="!E;';I9V5Z;FD@82!K97)E<^ES="X`(B5S(B!N
M96T@=F]L="!T]G+V;&AE=/4N`$$@<&%R=&YE<B!A9&%T86ET(&YE;2!S:6ME
M<OQL="!M\V1O<^UT86YI+B`E<P!.96T@<VEK97+\;'0@82!K]G)L97;I;&QI
M<W1A(&WS9&]S[73A<V$N("5S`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@(B5S
M(B!K;VYF:6=U<N%C:?-JX70Z("5S`$$@36]Z:6QL82!M96[\<V]R(&YE;2!T
M86SA;&AA=/,N($5L;&5N]7)I>GIE+"!H;V=Y(&UE9R!V86XM92!N>6ET=F$N
M`$YE;2!S:6ME<OQL="`B)7,B(&9E;&AA<WINX6SS;F%K(&IO9V]S=6QT<^%G
M;W0@861N:2!A*'HI("(E<R(@;6%P<.%H;WHZ("5S`$MO<FSA=&]S('-Z]G9E
M9P!/<G-ZX6<`5.%V;VMT873A<P!,Z71R96AO>N%S`-IJ(&UA<'!A(&SI=')E
M:&]ZX7-A`$MU;&-S<.%R(&SI=')E:&]ZX7-A`-IJ(&%Z;VYO<^UT\R!LZ71R
M96AO>N%S80!,:6YK(&SI=')E:&]ZX7-A`$AO>GIU;FL@;.ET<F4@^FH@4W!A
M;2!M87!PX70`2&]Z>G5N:R!LZ71R92#Z:B!M87!PX70@82!M=6YK87#I;&3A
M;GEO:R`H9')A9G1S*2!S>N%MX7)A`-IJ(&SI=')E:&]ZX7-A`$AO>GIU;FL@
M;.ET<F4@^FH@;6%P<.%T(&%Z(&5L:_QL9/9T="!L979E;&5K("AS96YT+6UA
M:6PI('-ZX6WA<F$`2&]Z>G5N:R!LZ71R92#Z:B`G4WIE;65T97,G("A4<F%S
M:"D@;6%P<.%T`%-Z^W+U9F5L=.ET96QE:R!A9&AA=/-K(&UE9RP@;65L>65K
M:V5L(&$@8F7I<FME>O4@;&5V96QE:R!A=71O;6%T:6MU<V%N(&UA<'#A:V)A
M(')E;F1E>FAE=/5K+@#::B!L97;I;'!A<.UR(&SI=')E:&]ZX7-A`$QE=NEL
M<&%P[7(@=F%G>2!F;W)M86YY;VUT871VX6YY(&SI=')E:&]ZX7-A+@!!;&UA
M<'#A:R!LZ71R96AO>N%S80!!>B!O8FIE:W1U;2!LZ71R96AO>O-JX6YA:R!J
M;V=O<W5L='/A9V%I`$AI=&5L:^%R='EA<WKA;0!(;W)VX71O<G-ZX6<`2W5B
M80!*96QE;FQE9VD@-"!FX7II<P!!(&IE;&5N;&5G:2!F96QH87-Z;N%L\VMA
M<&-S;VQA=&]K`%!O;G1O<R!I9/4`02!J96QE;FQE9VD@55),`$IE;&5N;&5G
M:2!F96QH87-Z;N%L\VL`2F5L96YL96=I(&ED]6KA<N%S`$$H>BD@)7,@;6%P
M<.%H;WH@=F%L\R!J96QE;FQE9VD@:&]Z>N%FZ7+I<VD@:F]G;W-U;'1SX6=O
M:SH`02!J96QE;FQE9VD@:63U:N%RX7-I(&AE;'EZ970Z`$IE;&5N;&5G:2!S
M=.UL=7,`02!L979E;&5K(&ED96=E;B!L979E;&5Z]7-Z97)V97)E:W+U;"!T
M]G)TZ6[U(.%T=/9L=.ESZ6YE:R!B9>%L;.UTX7-A:2X`02!L97;I;&O\;&3I
M<W-E;"!K87!C<V]L871O<R!B9>%L;.UTX7-O:RX`36EL>65N('!A<F%N8W-O
M:R!F=7-S86YA:R!L92!A=71O;6%T:6MU<V%N(&$@)7-B92!T]G)TZ6[U(&)E
M:F5L96YT:V5ZZ7-K;W(N`$MI=N%GX7,`02!K:6IE;/9L="!RZ7-Z(&MI=N%G
MX7-A`$-I<')U<P!C:7)I;&P@*$M/23@M4BD`8VER:6QL("A7:6YD;W=S+3$R
M-3$I`&-I<FEL;"UU:W+A;B`H2T])."U5*0!#<V5H($OV>G3A<G-A<^%G`$1$
M`$133B`H861A=&9O<G+A<VQE[7+S("T@;.%S9#H@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!N87!O;G1A`$3A='5M`$1A=&%4<F5E(&+V;F?I<WKU`$%D871BX7II
M<V)A;B!V86SS(&ME<F5SZ7,`1.%T=6T`02!B9>ER:V5ZZ7,@;F%P:F$`1.%T
M=6T@:VEVX6QA<WITX7-A`&YA<'!A;`!/<WIL;W`@=/9R;.ES90!D96-E;6)E
M<@!S>N%M;VL`96QU=&%S[71V80!%;'5T87/M='9A.B``0F5K97IDZ7,@:VEJ
M:F5B8@!!;&%PZ7)T96QM97IE='0`07H@86QA<.ER=&5L;65ZZ7,@<WIE<FEN
M=&D@<WKM;@!!;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/,`07H@
M86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@:V5R97/I<VD@;65Z]0!!;&%PZ7)T
M96QM97IE='0@<VAE;&P`02!S;W)B87)E;F1E>NES(&%L87#I<G1E;&UE>NES
M('-Z97)I;G1I('-Z96UP;VYT:F$Z`$$@<V]R8F%R96YD97KI<R!A;&%PZ7)T
M96QM97KI<R!S>F5R:6YT:2!I<N%N>6$Z`$1E9FEN[6-I\VL`;>%S;F%K(.%T
M861V80!4]G)LZ7,`5/9R]FQJ_&L@)7,@;GEI;';A;F]S(&MU;&-S;W0`02!C
M96QL82!T]G)LZ7-E`$$@:F5L96YL96=I(&MU;&-S;VL@=/9R;.ES90!-87!P
M82AK*2!T]G)LZ7-E`$$@8W-O<&]R="!T]G)LZ7-E`$$@;F%P;//A;&QO;>%N
M>2!T]G)LZ7-E`$$@:F]G;W-U;'1SX6<@=/9R;.ES90!!(&MI=N%L87-Z=&]T
M="!M87!PX6L@=/9R;.ES90!4]G+V;&K\:R!E>G0@82!L97;I;'!A<.UR=`!6
M:7)T=>%L:7,@;6%P<&$@=/9R;.ES90!!*'HI("5S('9I<G1UX6QI<R!M87!P
M82!T]G)LZ7-E+@!,979E;&5K('3V<FSI<V4`02!C96QL82!T]G)LZ7-E`$%Z
M(&]S>FQO<"!T]G)LZ7-E`%3V<O9L:OQK(&MI(&$@;65G;.EV]2!A;'1E<FYA
M=.UV('-A8FQO;G0`5/9R]FQJ_&L@82!TX79O;&D@<WIE<G9E<G+U;"!A>B#A
M=&AO>F]T="!L979E;&5K970_`%3V<O9L:OQK(&$@;F%P=.%R86UB\VP`02!L
M979E;&5K('3V<FSI<V4`5/9R]FQJ_&L@82!H\VYA<"!E;&5JZ6X@82!RZ6=I
M+"!H:79A=&MO>N%S(&9O<FWA:N%B86X@:_QL9/9T="!M96QLZ6ML971E:R!T
MZ6YY;&5G97,@<.EL9.%N>6%I=#\`5/9R]FQJ_&L@82!RZ6=I(&5L:_QL9/9T
M="!L979E;&5K970@*'-E;G0M;6%I;"D@=&%R=&%L;6%Z\R!M87!PX6MA="!A
M(&CS;F%P(&5L96KI;C\`(B5S(B!J;V=O<W5L='/A9V%I;F%K('3V<FSI<V4`
M5/9R]FQJ_&L@(B5S(B!J;V=O<W5L='/A9V%I="#I<R!E;FYE:R!E<V5T;&5G
M97,@86QC<V]P;W)T:F%I=#\`02!S;W(@=/9R;.ES90!!(&MI=N%L87-Z=&]T
M="!A>F]N;W/M=/,@=/9R;.ES90!4]G+V;&K\:R!A('-P86T@;&5V96QE:V5T
M`$%Z(&%L;6%P<.%K('3V<FSI<V4`02!J96QE;FQE9VD@;W-Z;&]P('3V<FSI
M<V4`02!J96QE;FQE9VD@<V]R('3V<FSI<V4`=/9R]FQT`%3V<O9L="!L979E
M;&5K`%3V<O9L=/QK(&$H>BD@(B5S(B!S971U<"!U<&=R861E('!R;V=R86UO
M="X`02`B)7,B(&UE;&SI:VQE=&5T('3V<O9L=/QK+@!!(&QE=F5L96L@=/9R
M;.ES92#I<R#A=&AE;'EE>NES90!!(&OI>F)E<^UTZ7,@:61E:F4`1.%N:6$`
M96QU=&%S[71O;2!A(&UE9VCM=N%S=`!!>B!I9/5B96]S>G3A<VD@861A=&OI
M<NES(&5L=71A<^UTX7-A`&-S]FMK96[U`$%D:F]N(&QE[7+A<W0@82!P<F]B
M;.EMX7+S;`!,9>URX7,`4NES>FQE=&5S96X`4NES>FQE=&5K("AA($AO<F1E
M(&QO9V;A:FQB86X@:7,@;65G=&%LX6QH873S*3H`02!RZ7-Z;&5T96L@82!R
M96YD<WIE<F=A>F1A('-ZX6WA<F$@:^ES>OQL]2!N87!L\V;A:FQB82!K97+\
M;'1E:RX`1F5J;&5S>G3I<P!(87)M871P;VYT`$AA<FUA='!O;G0@:F5L96YL
M96<Z(`!(87)M871P;VYT.B``(B5S(B!N96T@:V5R_&QT(&-S871O;.%S<F$L
M(&UE<G0@87H@X6QL;VWA;GD@_')E<RX`07H@X6QL86YD\R!L97;I;';I9WKU
M9.ES("AS:6=N871U<F4I(&AA;';A;GEA;B!J96QE;FIE;B!M96<_`&)A;'+S
M;"!J;V)B<F$@[7+A<P!J;V)B<O-L(&)A;')A(.URX7,`0^UM=.%R`$UE9VIE
M;&5N[73I<P!!>B!I9/5P;VYT;VMA="`R-"#S<N%S(&9O<FWA='5M8F%N(&IE
M;&5N[71S_&L@;65G/P!-96=J96QE;NUTZ7-I(&)EX6QL[73A<V]K`$$@;&5V
MZ6P@96QK_&QDZ7-E('5TX6X@:F5L96YJ96X@;65G(&5G>2!E>G0@;65G97+U
M<^UT]2#\>F5N970_`$$@<NES>FQE=&5S(&5L]7)E:F5L>NES(&UE9VIE;&5N
M[73I<V4`16SU<F5J96QZZ7,@;65G:F5L96[M=.ES92`H<F5P_&SU=.ER:2D`
M365G:F5L96[M=.ES:2!F;W)MX71U;0!A(&QE=NEL=/9R>G-B96X@=F%L\R!M
M96=J96QE;NUTZ7,`VFH@;&5VZ6P@Z7)K97KI<^ER]6P@:_QL]FX@9F5L8G5K
M:V%N\R!A8FQA:V)A;B!KZ7(@Z7)T97/M=.ES=#\`3&5G>65N(&5G>2`B4W!A
M;2!M87!P82#\<NUTZ7,B('!O;G1J82!A(&UE;OQS;W)N86L_`$QE9WEE;B!E
M9WD@(E-Z96UE=&5S(&UA<'!A(/QR[73I<R(@<&]N=&IA(&$@;65N_'-O<FYA
M:S\`16QH96QY97KI<P#)<G1E<^UTZ7,@82!KZ7IB97/M=&5T="!L97;I;"!S
M;W)SX7+S;`!$>G-I8G5T:0!.12!L96=Y96X@8F5N;F4`3F4@96QL96[U<FEZ
M>OQK+"!H;V=Y(&KV='0M92#Z:B!L97;I;`!.92!T]G+V;&K\:P!!(&UA:6YT
M96YA;F-E+G!H<"!N96T@Z7)H973U(&5L(&OV>G9E=&QE;OQL+@!!($9E;&%D
M\R!O<WIL;W!R82!K871T:6YT=F$@;F4@=/9R=.EN:F5N('-E;6UI`$UE9R!K
M[7;A;FIA(&YY:71N:2!A(&UA<'#A=#\`07H@96QS]2!S;W(@82!M97KU:R!N
M979E:70@=&%R=&%L;6%Z>F$_($AA(&EG96XL(&IE;/9L:F4@:VD@97IT.@!$
M;VUI;FEK80!$;VUI;FEK86D@2_9Z=.%R<V%SX6<`3FEN8W,@;>EG(&QO9VEN
M(&YE=F4_($EGZ6YY96QJ96X@96=Y970N`$OI<WH`3&5T]FQTZ7,`5/9L='/\
M:R!L92`E<RUT`%3V;'1S_&L@;&4@)7,M="`N>FEP(&9O<FWA='5M8F%N+@!!
M>B#V<W-Z97,@;65L;.EK;&5T(&QE=/9L=.ES92`H96=Y("YZ:7`@9N%J;&)A
M*0!4]FQT<_QK(&QE(&$@;6%P<.$H:V$I=`!4]FQT<_QK(&QE(&$@;6%P<.$H
M:V$I="`H96=Y("YZ:7`@9N%J;&)A*0!4]FQT<_QK(&QE(%!(4"!P<F]G<F%M
M(&9O<FWA:N%B86X@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0N`%3V;'1S
M_&L@;&4@+GII<"!F;W)MX71U;6)A;BX`;75N:V%PZ6QDX6YY`$UU;FMA<.EL
M9.%N>2!M87!P80!-=6YK87#I;&3A;GD@;6%P<&$Z`$QE9_9R9/QL]2!L:7-T
M80!+X6+M=/-S>F5R96L`96UA:6P`16UA:6P@8^UM`$5M86EL8O5L(%--4RUK
M_&QD]2!M96=H86IT\RP@:&$@82!T96QE9F]N=.%R<V%SX6<@8FEZ=&]S[71J
M82!E>G0@82!S>F]L9^%L=&%TX7-T+@!6R4=%`$A)0D$`2$E"03H@;&5V96SI
M="!N96T@<VEK97+\;'0@:^EZ8F5S[71E;FDN`$5C=6%D;W(`3?-D;W/M=.%S
M`$$@=&EL=/-L:7-T82!M\V1O<^UTX7-A`$)L;VMK(&WS9&]S[73A<P!!('-Z
M^W+U9F5L=.ET96QE:R!M\V1O<^UTX7-A`$-S;W!O<G0@;?-D;W/M=.%S`$IO
M9V]S=6QT<^%G(&WS9&]S[73A<P!*;V=O<W5L='/A9V]K(&WS9&]S[73A<V$`
M)7,@:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A`$$@:V5R97/I<R!M\V1O
M<^UTX7-A`%9I<G1UX6QI<R!M87!P82#A=&1E9FEN:>%LX7-A`$$H>BD@)7,@
M=FER='7A;&ES(&UA<'!A(.%T9&5F:6YIX6SA<V$N`$%Z(&5N9V5DZ6QY97KI
M<VD@;&ES=&$@;?-D;W/M=.%S80!-96QY:6L@;W!C:?-K870@=N%L=&]Z=&%S
M<W5K.@`B)7,B(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S80`E<R!J;V=O
M<W5L='/A9V%I;F%K(&WS9&]S[73A<V$`07H@UFX@=&EL=/-L:7-TX6KA;F%K
M(&WS9&]S[73A<V$`02!S>OMR]69E;'3I=&5L96L@;?-D;W/M=.%S80!!(&O\
M;'/U('-Z97)V97)E:W+U;"!T]G)TZ6[U(&QE=NELX71T]FQTZ7,@8F7A;&SM
M=.%S86DN`$%Z(&5N9V5DZ6QY97KI<VD@;&ES=&$@;?-D;W/M=.%S80!/:W1A
M=.%S`$5G>6EP=&]M`%-A;'9A9&]R`$5L96TN+BX`87H@)VTG(&)E=/L@<WKI
M;&5S<^EG90!%;6%I;`!%;6%I;"!C[6T`07H@96UA:6P@8^UM96MN96L@96=Y
M97IN:?QK(&ME;&PN`$5M86EL('9I<W-Z86EG87IO;.%S<V%L`$5M86EL+5--
M4R#A=&KA<O,`2&%N9W5L871I:V]N;VL`07H@]G-S>F5S(&QE=F5L970@=/9R
M]FQT_&L@)7,M8O5L+@!!('9I<G1UX6QI<R!S>F5M971E<VUA<'#A="!K:?QR
M[71E='3\:RX`W'+M='/\:R!K:2!A(&UA<'#A*&MA*70`W'+M='/\:R!K:2!A
M(&MI=N%L87-Z=&]T="!M87!PX6MA=`#<<NUT<_QK(&MI(&$@)U-Z96UE=&5S
M)R`H5')A<V@I(&UA<'#A=`!!(%-P86T@;6%P<&$@_'+M=.ES90!!('-Z96UE
M=&5S(&UA<'!A(/QR[73I<V4`W')E<R#\>F5N970N`$YI;F-S(&EL>65N+@!4
M]G+V;&K\:R!K:2!A(&ME<F5SZ7-E:V5T`$%K=&EVX6QJ=6L@82!01U`@<WIO
M;&?A;'1A=.%S;VMA=#\`06MT:7;A;&IU:R!A>B!3+TU)344@<WIO;&?A;'1A
M=.%S;VMA=#\`16YG961J_&L@;65G+"!H;V=Y(&OI<&5K970@:6QL97-S>OQN
M:R!A('-Z]G9E9V)E(&$@1F]T\V=A;.ER:>%K8O-L/P!3>F5R971N92!B96QE
M;NEZ;FD@82!L979E;&5K8F4@86[I;&O\;"P@:&]G>2!RX6IU:R!K871T:6YT
M86YA/P!,96=Y96X@:F]B8B!E9^ER9V]M8F)A;"!E;.ER:&5T]2P@:V]N=&5X
M='5S9OQG9_4@;65N_#\`5%]I=&MO<^UTX7-I(&)EX6QL[73A<V]K`%1I=&MO
M<^UT;W1T(&%D870`5NEG`%;I9V4@82!T;W;A8F+M=&]T="#\>F5N971N96L`
M02!L97;I;"!VZ6=E`"5S(&QE=F5LZ6YE:R!VZ6=E`$%Z('5T;VQS\R#I=@#!
M=';A;'3A<R!K_&SV;B!A8FQA:W)A`$$@:F5L;6]N9&%T(&UE9V%DX7-A`$%D
M:F$@;65G(&%Z="!A(&)I>G1O;G/A9VD@:^ER9.ES="P@86UE;'ER92!M86ID
M(';A;&%S>F]L;FEA(&ME;&P@:F5L<WIA=N%N86L@X73A;&SM=.%SX6AO>BP@
M<&PN("=H;V=Y(&CM=FKA:R!A(&MU='GA:N%T/R<Z`$%D:F$@;65G(&$@:^EP
M(%523"UJZ70@:71T`,UR:F$@8F4@87H@86SA8F)I(&)E=/MK970Z`$%D:F$@
M;65G(&%Z(/IJ(%-P86T@;6%P<&$@;F5VZ70`061J82!M96<@82!M=6YK87#I
M;&3A;GEO:R`H9')A9G1S*2!LZ71R96AO>F%N9/,@^FH@;6%P<.%JX6YA:R!N
M97;I=`!!9&IA(&UE9R!A>B!E;&O\;&3V='0@;&5V96QE:R`H<V5N="UM86EL
M*2!LZ71R96AO>F%N9/,@^FH@;6%P<.%JX6YA:R!N97;I=`!!9&IA(&UE9R!A
M>B#Z:B`G4WIE;65T97,G("A4<F%S:"D@;6%P<&$@;F5VZ70`02!T96QJ97,@
M;&5VZ6P`02!C[6UJ96=Y>NEK:&5Z('-I:V5R97-E;B!H;WIZX6%D='5K("(E
M<R(M="X`16=Y96YL[73U:2U'=6EN96$`17)I=')E80!(:6)A`$%Z($E-05`@
M<WIE<G9E<B!N96T@Z7)H973U(&5L+B`E<R`Z("5S+@!(:6)A('3V<G3I;G0@
M82!B;&]K:R!LZ71R96AO>N%S86MO<CH@)7,`2&EB82!T]G)TZ6YT(&%Z(&%D
M871S>FEN:W)O;FEZX6-I\W,@:F5L('3V<FSI<V5K;W(Z("5S`$%Z(&%D871S
M>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>2!T]G)LZ7-E(&YE;2!S:6ME
M<OQL=#H@)7,`2&EB82!T]G)TZ6YT(&%Z(&%D871L96OI<NES8F5N.B`E<P!(
M:6)A('3V<G3I;G0@82!VX6QA<WH@:_QL9.ES96MO<CH@)7,`2&EB82!T]G)T
MZ6YT(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%S86MO<CH@)7,`2&EB82!A>B!E
M;6%I;"#\>F5N971B96XN`$$H>BD@(B5S(B#A;&QO;>%N>7)A(&YE;2!S:6ME
M<OQL="#M<FYI+@#)<WIT;W)S>N%G`$5T:?-P:6$`3F5M>F5T:7/I9V5K`$5U
M<O-P80!!>B!E<V5MZ6YY="!S:6ME<F5S96X@=/9R]FQT_&LN`#$U('!E<F-E
M;FOI;G0`,B!P97)C96YKZ6YT`#,P(&WA<V]D<&5R8V5N:^EN=``U('!E<F-E
M;FOI;G0`;6EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(`9NEL\W+A;FOI;G0`<&5R
M8V5N:^EN=`!0Z6QD82#I<G3I:V5K.@!6Z6=R96AA:G3A<P!.>6ES<W5K('-Z
MZ70`3GEI<W-U:R!S>NET(&%Z(/9S<WIE<V5T`$YY:7-S=6L@<WKI="!A>B#V
M<W-Z97,@;6%P<.%T`$YY:7-S=6L@<WKI="!A(&UA<'#A=`!!(&/M;7+I<WIL
M970@=&5L:F5S<^D@96?I<WKM=.ES90!*96QE;NUT<_QK(&UE9R!A>B!O;&1A
M;'/S(&UE;OQT`$5GZ7-Z[71S_&LM92!K:2!A(&YE=F5K970@875T;VUA=&EK
M=7-A;B!L97;I;.URX7,@:_9Z8F5N/P!!(&UA<'#A:R!NZ7IE=.EB96X@<O9G
M=/9N(&MI;GEI='9A(&IE;&5N:F5N(&UE9R!A>B#V<W-Z97,@;6%P<&$_`$/M
M;7+I<WIL970@:VEE9^ES>NUTZ7-E+BXN`$ET="`G*2<@:V5L;&5N92!K]G9E
M=&ME>GIE;@!)='0@8W-U<&%S>B!S>O-N86L@=F%G>2!I9.EZ]6IE;&)E;B!L
M97;U(&ME<F5SZ7-I(&MI9F5J97KI<VYE:R!K96QL96YE(&QE;FYI90!!>B#I
M<G;I;GEE<W/I9R!L96KA<F%T80!+:71E=O4`4WKM;@!!(&MO;F9I9W5RX6-I
M\R!&5%`M;B#A="!V86SS(&9E;'3V;'3I<V4`3&5V96QE:R#A='3V;'3I<V4`
M02!S>F5MZ6QY97,@8F7A;&SM=.%S;VMA="!N96T@<VEK97+\;'0@8F5O;'9A
M<VYI+@!!>B!,1$%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`07H@4TU"('-Z
M97)V97(@;F5M(.ER:&5T]2!E;"X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(BUB
M]6P@=/9R=.EN]2!MX7-O;.%S+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B+6)E
M('3V<G3I;O4@;>%S;VSA<RX`3F5M('-I:V5R_&QT(/IJ(%-!4TP@:V%P8W-O
M;&%T;W0@;.ET<F5H;WIN:2X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(BUB92!T
M]G)TZ6[U(.%T:&5L>65ZZ7,N`,%L;&]MX6YY:&]Z>N%FZ7+I<VD@:&EB83H@
M)7,`5&ES>G1A`$9A;&ML86YD+7-Z:6=E=&5K("A-86QV:6YA<RD`1F%R;V4M
M<WII9V5T96L`2&5L>7)E:&]Z:&%T871L86X@:&EB83H`1F%X`$9A>`!F96)R
M=>%R`$CU;>ER<^EK;&5TZ7)Z970`2/5MZ7)SZ6ML973I<GIE=#H@`$QE=F5L
M96L@X71T]FQTZ7-E`$$@;&5V96QE:R#A='3V;'3I<V4@:_QL]FX@86)L86MB
M86X@=/9R=.EN:NEK/P!"96IE;&5N=&ME>NES:V]R(&%U=&]M871I:W5S86X@
M:6YD=6QJ;VX@;65G(&$@;&5V96QE:R#A='3V;'3I<V4_`"5D(&QE=NEL('3V
M;'3U9/9T="#A="`E<RUR]6PN`#$@;&5VZ6P@=/9L=/5D]G1T(.%T("5S+7+U
M;"X`3&5VZ6SA='3V;'3I<SH@`$QE=NELX71T]FQTZ7,Z(&YI;F-S(/IJ(&QE
M=F5L92X`16=Y+65G>2!ZX7!O<@!3>O-R=N%N>6]S86X@:/-ZX7!O<F]K`%-Z
M^W+U:P!-97KU(&WA=')I>`!&:6=L970@0T%05$-(02`H8F5T^VMI<F%K\R!H
M=6WA;G1E<WIT*0!&:61Z<VD`1N%J;`!!(&;A:FQO:R!S>N%M83H@)7,`02!F
MX6IL;VL@<WKA;6$Z("5S`$;A:FP@;65N961Z<V5R`$;A:FQNZ78`1N%J;"!K
M:6IE;/9LZ7,`1N%J;"!F96QT]FQTZ7-E`$;A:FQO:R!F96QT]FQTZ7-E(&YE
M;2!L96AE='/I9V5S+@!3>OMRZ7-I(&)EX6QL[73A<V]K`%-Z^W+U9F5L=.ET
M96QE:P!3>OMR:OQK(&MI(&$@:_9Z]FYSZ6=E<R`H<')O9N%N*2!K:69E:F5Z
MZ7-E:V5T(&$@;&5V96QE:R!T87)T86QMX6+S;#\`17H@82!R96YD<WIE<B!N
M96T@=.%M;V=A=&IA(&$@;&5VZ6QS>OMRZ7-T+@!3>OMR]6L`02!S>OMR]6L@
M:VD@=F%N;F%K(&MA<&-S;VQV80!3>OMR]6LZ("5S(&WS9&]S[73A<VD@;VQD
M86P`2V5R97/I<P!&:6YN;W)S>N%G`&5L<_4@9NEL`$$@;6%P<&$@96QS]2!O
M;&1A;&$`16QS]2!O;&1A;`!E;'/U(&YE9WEE9`!6X6QT;WIA=&QA;B!MZ7)E
M=&%RX6YY`%3\:W+V>NES("AF]FPO;&4I`%1O=N%?8F+M=.%S`$OV9``E<R!M
M87!P82!N96T@;.ET97II:P!!(&UA<'#A:V]N(';I9WIE='0@;?MV96QE="!M
M96=E<O5S[73I<V4`36%P<.%K(&ME>F5LZ7-E`$UA<'!A(/9S<WIE9F]G;&%L
MX7,`3FEN8W,@;65G96YG961V92P@:&]G>2!MX7,@9F5L:&%S>F[A;/-K;F%K
M(&AO>GKA9NERZ7-I(&IO9V]T(&%D:G5N:R!M87!PX6EN:VAO>BX`02!M87!P
MX6L@:&%S>F[A;&%T82!N:6YC<R!M96=E;F=E9'9E+@!"973[<WKM;@#)=&5L
M96L`3VQY86X@8O9N9^ES>O5K('-ZX6WA<F$L(&%M:6L@;F5M(&IE;&5N[71I
M:R!M96<@82!KZ7!E:V5T`$5L]7)E:F5L>NES("AR97#\;/5TZ7)I*0!!>B!E
M;/5R96IE;'KI<R!I9/5T87)T86UA(&YA<&]K8F%N("AA>B!E;/5R96IE;'KI
M<R!N87!P86QI(.ES(.EJ<WIA:V%I(&%D871O:V%T('1A<G1A;&UA>BP@97KI
M<G0@82!N86=Y('-ZX6UO:R!S>NEL97,@8FQO:VMO="!E<F5D;>EN>65Z;F5K
M*0!%;&9E;&5J=&5T=&4@82!J96QS>F%VX70_`$%Z(&%Z;F%P(&MA<&]T="!L
M979E;&5K(.ER:V5ZZ7-I(&ED]7!O;G1JX6YA:R!F;W)MX71U;6$`VW)L87!K
M97IE;.ES`$EDZ7IE=`!)9.EZ970@9F%J=.%J80!)9.EZ971E:P!)9.EZ971E
M:R`R`$;S<G5M;VL`5&]VX6)B[73A<P!4;W;A8F+M=.%S.@!4;W;A8F+M=&]T
M="!L97;I;`!4;W;A8F+M=&]T="!L97;I;"`E<R!C[6UR]6P`5&]VX6)B[73A
M<V]K`%#I`$9R86UE+65K`$9R86YC:6%O<G-ZX6<`1G)A;F-I86]R<WKA9P!6
MX6QA<WH@96QF;V=L86QT<^%G:2!KZ7)DZ7-R90!&<F%N8VEA($=U>6%N80!&
M<F%N8VEA(%!O;&ENZ7II80!&<F%N8VEA($3I;&D@5&5R_&QE=&5K`$9E;&%D
M\P!&96QA9/,`02!F96QA9/,@8^UM90!)<N%N>3H@`%+I<WIL971E<R!L9>UR
MX7,`=&5L:6AO;&0`5&5L:F5S(&[I=@!&=V0Z`$9W9#H@)74@=&]VX6)B[71O
M='0@_'IE;F5T`$=A8F]N`$UE;'EI:R!G86SI<FGA8O-L('9E9WG\:R!A(&OI
M<&5T`$OI<&=A;.ER:6$Z`$=A;6)I80#!;'1A;.%N;W,@8F7A;&SM=.%S;VL`
M2&]Z>G5K(&SI=')E(&$H>BD@)7,@:V]N9FEG=7+A8VGS:N%T`$$@:V5L971K
M97IE='0@:_-D`$=R^GII80!.Z6UE=&]R<WKA9P!#<V%K(&%Z(/IJ(&QE=F5L
M96ME="!H;WIZ=6L@X70_("AC<V%K($E-05`I`$=HX6YA`$=I8G)A;'3A<@!+
M97)E<WIT;NEV`$=L;V+A;&ES(&)EX6QL[73A<V]K`$UE:&5T`$$@;&5VZ6QH
M97H`365N:OQN:R!A(&OV=F5T:V5Z]2!C[6UJ96=Y>NEK(&%D871H;WHZ("(E
M<R(`1_9D96P`1V]O9VQE('3I<FOI<`!';V]G;&4@:V5R97/I<P!*;V=O<W5L
M='/A9R!A9.%S80!&96ME=&4O9F5HZ7(`1_9R]F=O<G-ZX6<`9_9R]F<@*$E3
M3RTX.#4Y+3<I`$=R]FYL86YD`$=R96YA9&$`0W-O<&]R="!A9&UI;FES>G1R
MX6-I\P!!(&-S;W!O<G1NZ78@;6%R861H870@_')E<V5N`$=R;W5P7VQD87`Z
M("5S(&-S;W!O<G0@:&]Z>N%A9.%S82!N96T@<VEK97+\;'0N($$@<WIE<G9E
M<B!VX6QA<WIA.B``1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!T]G)LZ7-E(&YE
M;2!S:6ME<OQL=`!'<F]U<%]L9&%P.B`E<R!C<V]P;W)T(&%D871A:6YA:R!M
M96?Z:NUTX7-A(&YE;2!S:6ME<OQL=`!#<V]P;W)T;VL`1W5A9&5L;W5P90!'
M=6%M`$=U871E;6%L80!'=65R;G-E>0!696YDZ6<@:F]G;W-U;'1SX6=O:P!6
M96YDZ6=K]FYY=@!'=6EN96$`0FES<V%U+4=U:6YE80!'=7EA;F$`2514`$$@
M;&5VZ6P@2%1-3"!VX6QT;WIA=&$`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M
M(&AA:FQA;F3S(&$@<V]R('5T;VQS\R!C96QLX6KA="!T]G+V;&YI+@!(5$U,
M07)E82!G>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA="!U=&]L
M<_,@;W-Z;&]PX70@=/9R]FQN:2X`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M
M(&AA:FQA;F3S(&$@=.%B;.%Z870@=71O;'/S('-O<N%T('3V<O9L;FDN`$$@
M2%144"!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('1A;.%L:&%T\RX`2&%I
M=&D`2&%S:"!A;&=O<FET;75S`$OV9`!&96ILZ6,`1F5J;.EC`$AE87)D+2#I
M<R!-8T1O;F%L9"US>FEG971E:P!%<O5S('II=F%T87(`:.EB97(@*$E33RTX
M.#4Y+3@M22D`36%G87-SX6<`4V5G[71SZ6<`4V5G[71SZ6<@82!S>F5R:V5S
M>G3U(&AA<WINX6QA=.%H;WH`4V5G[71SZ6<`1NEL=&5K90!%>B!A(&;A:FP@
M96QE:F4Z`$ET="!A>B#6;B#A;'1A;"!F;V=A;&UA>F]T="!L97;I;#H`;F4@
M;75T87-S<W5K`&QO9VEK86D@*'1H<F5A9"D@;NEZ971B96X@;F4@;75T87-S
M=6L`02!T]G+V;'1E:V5T(&YE(&UU=&%S<W5K`$$@:&%S>F[A;&%T;VX@:^UV
M_&P@:&5L>65Z971T("AU;G-U8G-C<FEB960I(&UA<'#A:V%T(&YE(&UU=&%S
M<W5K`&YA9WD`4_QR9_5S`&QE9VYA9WEO8F(`2V5Z9/5L87``5F%T:6OA;G;A
M<F]S`$ME>F3U;&%P`$]T=&AO;FD@8^UM`%-Z96WI;'EE<R!A;&OV;GEV=.%R
M`$]T=&AO;FD@=&5L969O;@!(;VYD=7)A<P!(;VYG:V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@:&EBX7,@)7,@6$U,(&%D870@=F%N(&$H>BD@)7,@_'IE;F5T
M8F5N`$AO<F1E+TMO;&%B.B!N:6YC<R!A*'HI("5S(&]B:F5K='5M;F%K(&UE
M9V9E;&5L]2#\>F5N970`2&]R9&4O2V]L86(Z(&YI;F-S("5S('3M<'5S^B!O
M8FIE:W1U;2!A*'HI("5S(/QZ96YE=&)E;@!(;W)D92]+;VQA8CH@4VEK97)E
M<V5N('3V<O9L=/QK(&5Z=#H@)7,@(B5S(@!(;W)D92]+;VQA8CH@87H@:6YT
M96=RX6SS('!R;V=R86UH;WH@<WK\:W/I9V5S(&$@)V1O;7AM;"<@4$A0(&+U
M=NUTZ7,`2&]R9&4O2V]L86(Z(&YE;2!S:6ME<OQL="#Z:B!834P@9N%T(&SI
M=')E:&]Z;FD@82AZ*2`E<R!O8FIE:W1U;6AO>@!(;W)D92]+;VQA8CH@3F5M
M('-I:V5R_&QT('3V<O9L;FD@)7,M="`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M;F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A($U)344@240M:N%T(&$@:_9V
M971K97KU('3M<'5S^B!M96QLZ6ML971N96LZ("5S`$AO<F1E+TMO;&%B.B!.
M96T@<VEK97+\;'0@<WII;FMR;VYI>N%L;FD@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z($YE;2!S:6ME<OQL="!A(&OV=F5T:V5Z]2!K]GKV<R!TX7)T97+\
M;&5T('-Z:6YK<F]N:7KA;.%S83H@)7,`2&]R9&4O2V]L86(Z(&ES;65R971L
M96X@:_9Z]G,@=.%R=&5R_&QE="`B)7,B`%;M>G-Z:6YT97,@=F]N86P`5NUZ
M<WII;G1E<R!M87)G\P!6[7IS>FEN=&5S.@!(;V=Y(&IU=&]T="!I9&4_("A+
MZ7)J_&L@[7)J82!M96<A*0!(;V=Y86X@:^UVX6YJ82!M96=J96QE;NUT=&5T
M;FD@82!M96QLZ6ML971E:V5T/P!(X6YY(&]S>FQO<&]T(&OM=N%N(/9S<WIE
M;VQV87-Z=&%N:3\`2.%N>2!M97KU("AO<WIL;W`I('9A;C\`2.%N>2!S;W)T
M(&OM=N%N(/9S<WIE;VQV87-Z=&%N:3\`5N%L87-Z;VSA<VMO<B!H;V=Y86X@
M:F5L97IZ_&LL(&AO9WD@:VET]6P@:63I>G3\;FL`4.%R871A<G1A;&]M`%#A
M<F%T87)T86QO;3H@`$AU;6]R:7-TX6L`36%G>6%R;W)S>N%G`$E-05``24U!
M4"`H875T;VUA=&EK=7,@<')O=&]K;VQL(&UE9VAA=.%R;WKA<W-A;"D`07H@
M24U!4"!S>F5R=F5R(&UE9W-Z86OM=&]T=&$@82!K87!C<V]L871O="X@02!S
M>F5R=F5R(';A;&%S>F$Z("5S`$%Z($E-05`@;&5VZ6QLX61A(&SI=')E:&]Z
MX7-A(&YE;2!S:6ME<OQL=#H@)7,`07H@24U!4"!L97;I;&SA9&$@=/9R;.ES
M92!N96T@<VEK97+\;'0Z("5S`$%Z($E-05`@;&5VZ6QLX63A:&]Z('1A<G1O
M>O,@:W;S=&$@;.ET<F5H;WKA<V$@;F5M('-I:V5R_&QT.B`E<P!)34%0(%-3
M3"!F]FSV='0`24U!4"!34TP@9O9L]G1T("CV;G1A;OIS[71VX6YN>6%L*0!3
M4TP@9O9L]G1T("CV;G1A;OIS[71VX6YN>6%L*0!!>B!)34%0('-Z97)V97(@
M;65G<WIA:^UT;W1T82!A(&MA<&-S;VQA=&]T+@!)34%0+"!43%,@;NEL:_QL
M`$E-05`O4$]0,R!L979E;&5Z]7-Z97)V97)E:P!)4"!C[6T`07H@25`@8^UM
M(&YE;2!H873A<F]Z:&%T\R!M96<N`$%Z($E0(&/M;2!N:6YC<R!A(&UE9V5N
M9V5D971T($-)1%(@=&%R=&]MX6YY8F%N+@!4:6QT;W1T+VUE9W;A;'1O>F]T
M="!)4"!C[6TN`%-O<B!B96EL;&5S>G3I<V4@96;V;.D`27IL86YD`&-S86L@
M:6MO;F]K`"5S(&EK;VYJ86D`:6MO;F]K(.ES('-Z]G9E9P!!>B!A>F]N;W/M
M=/-H;WH@=N%L87-Z=&]T="!E;&YE=F5ZZ7,Z`$AA(&$@;65G:F5L96[M=.ES
M(&YE;2!M96=F96QE;/4L("5S(&5G>2#Z:B!A8FQA:V)A;B!V86SS(&UE9VYY
M:73A<VAO>BX`07H@4U-,('9A9WD@5%-,(&AA<WINX6QA=.%H;WH@82!02%`@
M;W!E;G-S;"!B]7;M=.ESZ6YE:R!B92!K96QL('3V;'3U9&YI92X`2&$@9F]L
M>71A=&IA+"!A(&UA<'#A*&LI8F%N(&QE=O4@]G-S>F5S(&QE=NEL('3V<FSU
M9&EK(0!(82#6;B!);G1E<FYE="!%>'!L;W)E<G0@:&%S>F[A;"P@Z7,@;F5M
M(&IE;&5N;F5K(&UE9R!A>B!I:V]N;VLL(&%K:V]R(';A;&%S<WIA(&5Z="!A
M>B!O<&-I\W0L(&UE;&QY96P@:VEK87!C<V]L:F$@82!03D<@:^EP96L@=')A
M;G-Z<&%R96YC:>%JX70N`$AA(&SA=&IA(&5Z="!A('-Z]G9E9V5T+"!D92!A
M(&OI<&5T(&YE;2P@86MK;W(@8O9N9^ES>O5P<F]G<F%M:F$@;F5M(&OI<&5S
M(&UE9VIE;&5N[71E;FD@82!S>F5R=F5R<F4@:_QL9&5N9/4@:^EP970N`$YE
M('9E9WG\:R!F:6=Y96QE;6)E`$5G>6EK970@<V4@=F5G>?QK(&9I9WEE;&5M
M8F4`2^EP`$5L]7IE=&5S(&[I>F5T.@!!(&OI<"!54DPM:F4`02!KZ7`@55),
M+6IE.@!-96QY:6L@9V%LZ7)IX6+S;"!V86X@82!KZ7``2^EP(&5B8O5L(&$@
M9V%LZ7)IX6+S;#H`2^EP(&9E;'3V;'3I<V4`2^EP96L`26UP;W)TX6SA<P!+
M=6QC<R!I;7!O<G3A;.%S80!+=6QC<W#A<B!I;7!O<G3A;.%S80!,979E;&5K
M(&EM<&]R=.%LX7-A`%!'4"!K=6QC<R!I;7!O<G3A;.%S80!3>F5MZ6QY97,@
M=&%N^G/M=';A;GD@:6UP;W)TX6SA<V$`4WIE;>EL>65S+"!T:71K;W,@4$=0
M(&MU;&-S(&EM<&]R=.%LX7-A`%-Z96WI;'EE<RP@;GEI;';A;F]S(%!'4"!K
M=6QC<R!I;7!O<G3A;.%S80!3>F5MZ6QY97,@4R]-24U%('1A;OIS[71VX6YY
M;VL@:6UP;W)TX6SA<V$`3GEI;';A;F]S(&MU;&-S(&EM<&]R=.%LX7-A`$YY
M:6QVX6YO<R!01U`@:W5L8W,@:6UP;W)TX6SA<V$`3GEI;';A;F]S(%,O34E-
M12!K=6QC<R!I;7!O<G3A;.%S80!3+TU)344@:W5L8W,@:6UP;W)TX6SA<V$`
M4W1A;F1A<F0@;6)O>"!FX6IL(&EM<&]R=.%LX7-A`"5S('-T86YD87)D(&UB
M;W@@9N%J;"!I;7!O<G3A;.%S82`H9F5L=/9L=.ES92D@82AZ*2`E<R!M87!P
MX6)A+@!);7!O<G3A;.%S+"`E9"X@;.EPZ7,`9F]N=&]S`$9O;G1O<R!L979E
M;&5K`"5D(&QE=F5L970@:6UP;W)TX6QT=6YK("5S+6+U;"X`07H@:6UP;W)T
MX6QT(&UE>O4Z("5S`$%Z(&EM<&]R=.%L="!M97KU:SH`9F]L>6%M871B86X`
M4V]R(&)E:6QL97-Z=.ES92!E>F%LX0!6X6QA<WIO;.%S:V]R(&EDZ7IZ_&LM
M92!B92!A(&QE=NEL(&9E:FSI8^EN96L@9F]N=&]S86)B('-O<F%I=#\`5N%L
M87-Z;VSA<VMO<B!I9.EZ>OQK(&)E(&$@;65G=N%L87-Z;VQA;F3S(&QE=F5L
M970_`$AI8N%S('!A<F%N8W-P87)A;>ET97(N`$YE;2!M96=F96QE;/4@82!B
M96IE;&5N=&ME>NES:2!NZ78@Z7,O=F%G>2!A(&IE;'-Z\RX`3F5M(&UE9V9E
M;&5L]2!A(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!A>B!A;'1E<FYA=.UV(&/M
M;2X@4'+S8N%L:F$@^FIR82!V86=Y(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z
M9.%H;WHL(&AA('1O=N%B8FD@<V5G[71SZ6=R92!V86X@<WK\:W/I9V4N`$)E
M:V5Z9.ES(&)E;&IE8F(`26YD:6$`16=Y97,@9F5L:&%S>F[A;/-K`$EN9&]N
MZ7II80!);F9O<FWA8VGS`$EN9F]R;>%C:?,`07H@:6YF;W)MX6-I\R!MX7(@
M;F5M(.%L;"!R96YD96QK97KI<W)E+@!);F9O<FWA8VGS("5S(&YY:6QVX6YO
M<R!K=6QC<W+S;`!);F9O<FWA8VGS(&$@<WIE;>EL>65S+"!T:71K;W,@:W5L
M8W-R\VP`26YF;W)MX6-I\R!A('-Z96WI;'EE<RP@;GEI;';A;F]S(&MU;&-S
M<O-L`$QE=NEL8F5N:0!/<WIL;W`@8F5S>OIRX7-A(&5Z=73A;@!)9&4@;>%S
M;VQJ82!B92!A('1A;OIS[71VX6YY=`!+Z7`@8F5I;&QE<WITZ7-E`$ED92!M
MX7-O;&IA(&)E(&$@<WIE;>EL>65S+"!T:71K;W,@4$=0(&MU;&-SX70`261E
M(&WA<V]L:F$@8F4@82!S>F5MZ6QY97,L(&YY:6QVX6YO<R!01U`@:W5L8W/A
M=`!)9&4@;>%S;VQJ82!B92!A(&YY:6QVX6YO<R!01U`@:W5L8W-O=`!4X6)L
MX7IA="!B96EL;&5S>G3I<V4`3&EN:R!LZ71R96AO>N%S80!/<WIL;W`@8F5S
M>OIRX7-A(&5Z96SI`$]S>FQO<"!B97-Z^G+A<V$@97IU=.%N`$]S>FQO<"!B
M97-Z^G+A<V$@97IE;.D`4V]R(&)E<WKZ<N%S82!E>F%LX0!3;W(@8F5S>OIR
MX7-A(&5F]FSI`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>G5TX6X`0F5K97ID
MZ7,@8F5I;&QE<WITZ7-E(&5Z96SI`$AO>GIU;FL@;.ET<F4@86QT97)N873M
M=B!S86)L;VYT`$%D:F]N(&UE9R!E9WD@96UA:6P@8^UM970L(&UE;'ER92!E
M;&O\;&1H973U(&%Z(-9N(/IJ(&IE;'-Z879A.@!#96QL82!B96EL;&5S>G3I
M<V4@97IU=.%N`$-E;&QA(&)E:6QL97-Z=.ES92!E>F5LZ0!/<WIL;W`@8F5S
M>OIRX7-A(&5Z=73A;@!/<WIL;W`@8F5S>OIRX7-A(&5Z96SI`$QE=F5L96L@
M8F5MX7-O;.%S80!"96ME>F3I<R!B96EL;&5S>G3I<V4@97IU=.%N`$)E:V5Z
M9.ES(&)E:6QL97-Z=.ES92!E>F5LZ0!3;W(@8F5S>OIRX7-A(&5Z86SA`%-O
M<B!B97-Z^G+A<V$@96;V;.D`061J82!M96<@82!K[7;A;G0@=N%L87-Z="!A
M(&)I>G1O;G/A9VD@:^ER9.ES<F4Z`$OI<"!B96EL;&5S>G3I<V4O;?-D;W/M
M=.%S80!,:6YK(&)E:6QL97-Z=.ES92]M\V1O<^UTX7-A`$$@<WKA;6SA:N%N
M(&YI;F-S(&5LZ6<@9F5D97IE="#\>F5N971E="!K_&QD96YI(&$@:_9R;&5V
MZ6QL:7-TX7)A+@!!('-ZX6ULX6KA;B!N:6YC<R!E;.EG(&9E9&5Z970N`$5G
MZ7-Z`$5GZ7-Z('-ZX6UO:R!L:7-TX6IA`$5Z(&$@;&5H973U<^EG(&YE;2!V
MX6QA<WIT:&%T\R!E8F)E;B!A>B!E<V5T8F5N+@!(:6+A<R]E;&9O9V%D:&%T
M871L86X@8^UM+@!(:6+A<R]E;&9O9V%D:&%T871L86X@=.%V;VQI(&QE=NEL
M;.%D82X`2&EBX7,O96QF;V=A9&AA=&%T;&%N(%5$2"`H57-E<B!$871A($AE
M861E<BDN`$AI8N%S+V5L9F]G861H871A=&QA;B!:25`@=/9M]G+M=.ES`$AI
M8N%S+V5L9F]G861H871A=&QA;B!A;&MA;&UA>N%S+@!(:6+A<R]E;&9O9V%D
M:&%T871L86X@8F%T8V@@87IO;F]S[73S+@!(:6+A<R]E;&9O9V%D:&%T86QA
M;B!K87)A:W1E<B!A>B!E;6%I;"!C[6UB96XZ("5S+@!!(&O\;&3V='0@861A
M="!H:6+A<R]E;&9O9V%D:&%T871L86XN`$AI8N%S+V5L9F]G861H871A=&QA
M;B!C[6UZZ7,N`$AI8N%S+V5L9F]G861H871A=&QA;B!FX6IL(&9O<FWA='5M
M`$AI8N%S(&MU;&-S`$AI8N%S+V5L9F]G861H871A=&QA;B!L:6-E;G-Z:W5L
M8W,N`$AI8N%S+V5L9F]G861H871A=&QA;B!VX7)O<RX`2&EBX7,O96QF;V=A
M9&AA=&%T;&%N(/QZ96YE='3M<'5S+@!(:6+A<R]E;&9O9V%D:&%T871L86X@
M=F%G>2!H:>%N>7KS('!R;V=R86UO>N%S:69E;/QL970M87IO;F]S[73S+@!(
M:6+A<R]E;&9O9V%D:&%T871L86X@<&%R86WI=&5R96LN`$AI8N%S(&%Z(&]B
M:F5K='5M(&5LZ7+I<VD@:F]G;W-U;'1SX6=A+@!(:6+A<R]E;&9O9V%D:&%T
M871L86X@<&%R=&YE<F%Z;VYO<^UT\RX`2&EBX7,@4$=0('-Z96WI;'EE<RP@
M=&ET:V]S(&MU;&-S+@!(:6+A<R!01U`@<WIE;>EL>65S+"!N>6EL=N%N;W,@
M:W5L8W,N`$AI8N%S+V5L9F]G861H871A=&QA;B!T97)MZ6MK\V0N`$AI8N%S
M+V5L9F]G861H871A=&QA;B!P<F]T;VMO;&PN`$AI8N%S+V5L9F]G861H871A
M=&QA;B!C[6UZ971T.B`B)7,B`$AI8N%S+V5L9F]G861H871A=&QA;B!M96=O
M<WIT;W1T(&]B:F5K='5M`$AI8N%S+V5L9F]G861H871A=&QA;B!F96QA9/-I
M(&/M;2X`2&EBX7,O96QF;V=A9&AA=&%T;&%N('5N:6-O9&4@861A="X`3GEI
M;';A;G1A<G3A<P!A>B!E;&QE;FME>O5JZ70`02!K:6IE;/9LZ7,@:6YV97)T
MX6SA<V$`27+A;FD@27-Z;.%M($OV>G3A<G-A<^%G`$ER86L`S7)O<G-ZX6<`
M36%N+7-Z:6=E=`!3>O-R=N%N>6]S('II=F%T87)O:P!)>G)A96P`02!T86[Z
M<^UT=N%N>2!K:6%D\VIA`&3U;'0`3VQA<WIO<G-ZX6<`2F%M86EC80!J86YU
MX7(`2F%PX6X`:F%PX6X@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9.%N:6$`
M:OIL:75S`&KZ;FEU<P!3;W)K:7KA<N%S`&OV>NEP<F4@<F5N9&5ZZ7,`<V]R
M:VEZX7+A<R!M:6YD:^ET(&]L9&%L<F$`<V]R:VEZX7+A<R!B86QR80!S;W)K
M:7KA<N%S(&IO8F)R80!+87IA:'-Z=.%N`%1A<G1S=6L@;65G(&%Z(&5R961E
M=&ET/P!+96YY80!!(&ME<F)E<F]S('-Z97)V97(@96QU=&%S[71O='1A(&$@
M9F5L:&%S>F[A;/-A>F]N;W/M=.%S="X`2V5Z9/4@:V5R;F5L9F5J;&5S>G3U
M:P!+=6QC<R!LZ71R96AO>N%S80!!(&MU;&-S(&QE;GEO;6%T80!+=6QC<VAO
M<W-Z^G/A9P!+=6QC<R!T[7!U<P!!(&MU;&-S(&AA<WINX6QA=&$`02!K=6QC
M<R!MX7(@;.ET97II:R!A(&YY:6QVX6YO<R!K=6QC<W-Z97)V97)E;BX`02!K
M=6QC<R!LZ71R96AO>N%S82!H;W-S>F%B8B!I9/5T('9E:&5T(&EGZ6YY8F4N
M($9O;'ET87-S=6L@82!K=6QC<R!LZ71R96AO>N%SX70_`$$@:W5L8W,@;F5M
M(&EM<&]R=.%L:&%T\RX@02!S>F5R=F5R96X@;FEN8W,@96YG963I;'EE>G9E
M(&%Z(.%L;&]MX6YY;VL@9F5L=/9L=.ES92X`02!K=6QC<R!N96T@:6UP;W)T
MX6QH873S+B!.:6YC<R!M96=A9'9A(&$@8^UM:F5G>7KI:RP@86AO=F$@96P@
M;&5H971N92!M96YT96YI(&%Z(&%D871O:V%T+@!!(&MU;&-S;W0@<VEK97)E
M<V5N(&5L:_QL9'3\:R!A(&YY:6QVX6YO<R!K=6QC<V]K870@=.%R;VSS('-Z
M97)V97)N96LN`$=Y97)E:V5K`$MI<FEB871I`$MO<F5A:2!.Z7!I($1E;6]K
M<F%T:6MU<R!+]GITX7)S87/A9P!+;W)E86D@2_9Z=.%R<V%SX6<`:V]R96%I
M("A%54,M2U(I`$MU=F%I=`!+:7)G:7II<WITX6X`7U1E<G9E>NES`$YY96QV
M`$QA;W-Z:2!.Z7!I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9P!U=&]L<_,@
M9NEL`$$@;6%P<&$@=71O;'/S(&]L9&%L80!5=&]L<_,@;VQD86P`07H@=71O
M;'/S(&IE;'-Z\W;A;'3A<P!U=&]L<_,@;F5G>65D`%5T;VQS\R!VX6QT;WIT
M873A<SH`571O;'/S(&)E:F5L96YT:V5ZZ7,Z("5S`%5T;VQS\R!B96IE;&5N
M=&ME>NES.B`E<RP@)7,@8^UM<O5L`%5T;VQS\R!B96IE;&5N=&ME>NES.B!M
MZ6<@<V]H82!N96T@=F]L=`!,971T;W)S>N%G`$IO9P!%;&AE;'EE>NES`$AA
M9WEJ82#\<F5S96XL(&AA(&YE;2!A:V%R(&ME<F5T970`3&EB86YO;@!B86P`
M0F%L(&]L9&%L:2!F96ILZ6,`0F%L(&]L9&%L:2#I<G3I:V5K`$QE<V]T:&\`
M4WII;G0`3&EBZ7)I80!,[6)I86D@07)A8B!3>F]C:6%L:7-T82!.86=Y($[I
M<&D@2_9Z]G-SZ6<`3&EE8VAT96YS=&5I;@!'>65N9V4@<WII=.%L\R!E<_4`
M1WEE;F=E(&5S]0!$Z6QE;/5T="!G>65N9V4@97/U`$3I;'5TX6XO97-T92!G
M>65N9V4@97/U`$=Y96YG92!ZX7!O<@!'>65N9V4@>FEV871A<@!'>65N9V4@
M:&%V87KA<P!'>65N9V4@:/-ZX7!O<@!,:6YK`$$@;65L;.EK;&5T96ME="!H
M:79A=&MO>N%S(&9O<FWA:N%B86X@:_QL9&K\:S\`02!L:6YK(&ED92!M=71A
M=#H`365G:F5L96[M=.ES:V]R(&UU=&%S<V]N(&5G>2!L:6YK(&$@;&5VZ6QC
M[6UR]6P@82!L97;I;.UR\R!A8FQA:VAO>@!!(&UE;&SI:VQE=&5K(&AI=F%T
M:V]ZX7,@9F]R;>%JX6)A;B!V86SS(&O\;&3I<V4@;F5M(&UE9V5N9V5D971T
M+@!,:6YK96L`02!H:79A=&MO>F]T="!M96QLZ6ML971E:R!E:VMO<B!T]G)L
M]61N:2!F;V=N86LZ("5S`$QI;G5X`$QI<W3A>N%S("T@82!F96QH87-Z;N%L
M\R!LX71J82!A(&UA<'#A=`!!>B!A9&%T8N%Z:7-O:R!L:7-TX6IA`$%Z;VMN
M86L@82!TZ6WA:VYA:R!A(&QI<W3A:F$@86UI<O5L('-E9^UT<^EG(&MA<&AA
M=/,`07H@861A='3A8FSA:R!L:7-TX6IA`$QI<W3A>GIU:R!K:2!A>B#V<W-Z
M97,@<&%R=&YE<G0@82!C[6UJ96=Y>NEK(&)E:.UVX7-A:V]R/R`H:&$@;F5M
M+"!A:VMO<B!C<V%K(&%Z;VL@82!P87)T;F5R96L@:F5L96YN96L@;65G+"!M
M96QY96MR92!RX6ME<F5S*0!,:7-T82!A<F-H[79U;0!,:7-T82!S96?M='/I
M9VOI<NES`$QI<W1A(&%Z;VYO<^UT\P!,:7-T82!T=6QA:F1O;F]S`$QI<W1A
M(&QE=NEL[7+A<P!,:7-T82!F96QI<F%T:V]ZX7,@*'-U8G-C<FEB92D`3&ES
M=&$@;&5I<F%T:V]ZX7,@*'5N<W5B<V-R:6)E*0!A(&9E:FSI8V)E;B!V86SS
M(&9E;'-O<F]LX7,`02!F96QH87-Z;N%L\VMA<&-S;VQA=&]K(&MI;&ES=.%Z
MX7-A(&YE;2!S:6ME<OQL=#H@)7,`02!F96QH87-Z;N%L\VL@:VEL:7-TX7KA
M<V$@;F5M('-I:V5R_&QT.B`E<P!!(&9E;&AA<WINX6SS:R!K:6QI<W3A>N%S
M82!T:6QT=F$@=F%N+@!)<F]D86QO;0!,:71VX6YI80!,973V;'3I<RXN+@!(
M96QY:2!M87!P83H`2&5L>6D@:63U.B``3GEE;'8L(&3A='5M+"!I9/4`2&5L
M>0!"96IE;&5N=&ME>NES`$)E:F5L96YT:V5ZZ7,@)7,M8F4`07H@96SU>O4@
M861A='-Z:6YK<F]N:7KA8VGS(&YA<&SSX6QL;VWA;GEA`$MI:F5L96YT:V5Z
MZ7,`0F5J96QE;G1K97KI<P!"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA=&]S
M(&9E;&%D871O:P!!(&)E:F5L96YT:V5ZZ7,@;F5M('-I:V5R_&QT+"!M97)T
M(')O<W-Z(&9E;&AA<WINX6SS;F5V970@=F%G>2!J96QS>O-T(&%D;W1T(&UE
M9RX`02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="X`2&]S<WKZ('-Z]G9E
M9P!3>F5R96QE;0!A;&%C<V]N>0!.96T@<_QR9_5S`&?V<O9G(&MI<V)E=/MK
M`&QA=&EN(&MI<V)E=/MK`&MI<V)E=/MS('+S;6%I('-ZX6UO:P!L96=A;&%C
M<V]N>6%B8@!,=7AE;6)U<F<`34T`3F%P:2#\>F5N971E:P!!>B!-4RU43D5&
M(&UE;&SI:VQE=&)E;B!N:6YC<R!A9&%T+@#<6D5.150`36%K8?,`36%K963S
M;FEA`$UA8VEN=&]S:"!FX6IL`$UA9&%G87-Z:^%R`%9A<N%Z<VQA=`!,979E
M;&5ZZ7,`16UA:6P@9&]M86EN(&ME>F5LZ7,`02!L979E;&5K(&5L]6[I>F5T
M90!!>B!I9&5G96X@;&5V96QE>O5S>F5R=F5R('3M<'5S83H`3&5VZ6QLX61A
M`$$@;&5VZ6QLX61A(&EL;"X@82!M87!PX6L@;65G:F5L96[M=.ES:2!B9>%L
M;.UTX7-A:0!,:6YK(&OI<WKM=.ES90!-86QA=VD`36%L86IZ:6$`36%L9.UV
M+7-Z:6=E=&5K`$UA;&D`3>%L=&$`061A=&%I="!K871E9_-R:>%K8F$@<V]R
M;VQH871J82X@17IE:R!I='0@9&5F:6YIX6QH873S:RP@;?-D;W/M=&AA=/-K
M+"!T;W;A8F+A('-Z[6YE:R!R96YD96QH973U:R!H;WIZX6IU:RX`36%P,C0@
M=.ER:^EP`$UA<%%U97-T('3I<FOI<`!!(&AO>GKA<F5N9&5LZ7-E:V5T(&5L
M;65N=&5T=/QK+@!MX7)C:75S`$UA<F?S`$$@;6%P<&$@]G-S>F5S(&QE=F5L
MZ70@;VQV87-O='1KZ6YT(&IE;/9L:OQK(&UE9P!!(&UA<'!A(/9S<WIE<R!L
M979E;.ET(&]L=F%S871L86YKZ6YT(&IE;/9L:OQK(&UE9P!*96SV;&K\:R!M
M96<L(&UI;G0Z`$%Z(&EDZ7IE=&5K(&O\;/9N8O9Z]2!S>FEN=&IE:70@96QT
MZ7+U('-Z[6YN96P@:F5L97IZ_&L_`$]L=F%S;W1T:^EN="!J96SV;&K\:R!M
M96<@82!L979E;&5K970_("AC<V%K($E-05`I`$IE;&5Z>OQK(&%Z(&5G>7-Z
M97+[8F(@2%1-3"!K\V1O:V%T/P!!>B!/;'9A<V]T="]/;'9A<V%T;&%N(&IE
M;'IE=&5K(&AA<WINX6QA=&$`3>%S(&IE;'IE=&5K("AP;"X@1F]N=&]S+TUE
M9W;A;&%S>F]L="D@:&%S>F[A;&%T80!-87)S:&%L;"US>FEG971E:P!-87)T
M:6YI<75E`$%Z(/9S<WIE<R!K97)E<_5F96QTZ71E;'0@:VEE;.EG[71I:P!"
MX7)M96QY:6L@:V5R97/U9F5L=.ET96QT(&MI96SI9^UT:6L`16=Y;>%S;F%K
M(&UE9V9E;&5L]2!M97KU:P!-875R:73A;FEA`$UA=7)I=&EU<P!-87AI;>%L
M:7,@<F5N9&5L:V5ZZ7-R92#A;&SS('-ZX6UL8?9S<WIE9RX`07H@_'IE;F5T
M('3Z;"!S;VL@<NES>F+U;"#A;&PN`$%Z(&5L;?IL="`R-"#S<F$@;6%X:6WA
M;&ES(&CU;>ER<^EK;&5T93H@`$%Z(&5L;?IL="`V(/-R82!M87AI;>%L:7,@
M:/5MZ7)SZ6ML971E.B``36%X:6WA;&ES(&UE;&SI:VQE="!MZ7)E=`!!(&UA
M<'#A:R!M87AI;>%L:7,@<WKA;6$`07H@]G-S>F5G]6]L9&%L(&)L;VMK:F%I
M;F%K(&UA>&EMX6QI<R!S>N%M80!-87AI;>%L:7,@:&]S<WH`02!C<V%T;VQT
M(&UE;&SI:VQE=&5K('-ZX6UA(&YE;2!N]G9E;&AE=/4@=&]VX6)B+@!!(&-S
M871O;'0@;65L;.EK;&5T96L@]G-S>FWI<F5T92!E;.ER=&4@82!M87AI;>%L
M:7,@;65G96YG961E='0@Z7)TZ6ME="X`;>%J=7,`36%Y;W1T90!/<G9O<W1U
M9&]MX6YY`%1A9V]K`$UA<'!A(&QI<W3A>O,@;65N_`!!(&UE;OP@;65G:F5L
M96[I<V4Z`$-E;&SA:R!E9WEB96]L=F%S>G3A<V$`3&5VZ6P`3&5VZ6SM<N%S
M`$$@;&5VZ6P@9.%T=6UA`$QE=F5L96MR92!V;VYA=&MO>O,@8F7A;&SM=.%S
M;VL`2V5R97/I<R!A(&QE=NEL8F5N`$$@;&5VZ6P@;>ER971E`$$@;&5VZ6P@
M9F]R<N%S80!!(&1I9VETX6QI<V%N(&%LX>UR="#\>F5N970@:&ET96QE<RP@
M9&4@87H@86SA[7+S('1A;OIS[71VX6YYX70@;F5M('-I:V5R_&QT(&5L;&5N
M]7)I>FYI+@!!(&QE=NEL(&UE9W1E:VEN=.ES90!,96KA<G0@87H@_'IE;F5T
M(.ER=NEN>65S<^EG92X`02!L97;I;"!F86ITX6IA`$UE;'EI:R!M87!P80!,
M97;I;"`E<RUT]6P`02!L97;I;&AE>B!M96QLZ6ML971E:R!I<R!V86YN86L`
M02!L97;I;"!K\V1O;'9A('9A;@!!(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%S
M<V%L('9A;B!E;&SA='9A`$$@:V5R97-E='0@;&5V96QE:P!!(&QE=F5L970@
M<VEK97)E<V5N(.%T:7+A;GGM=&]T='5K+@!!(&QE=NEL(&5L;65N="P@9&4@
M;F5M('-I:V5R_&QT(&5L;65N=&5N:2!I='0Z("5S`$$@;&5V96QE="!E;&O\
M;&1T_&LN`$%Z(/QZ96YE="!T[7!U<V$`07H@96=Y(&]L9&%L;VX@;65G:F5L
M96[U(&QE=F5L96L@<WKA;6$@82!L97;I;&SA9&$@;65G=&5K:6YTZ7-E:V]R
M+@!A(&QE=F5L96ME="!I9&4N+BX`365T87(@:63U:N%RX7-J96QE;G3I<P!!
M($UE=&%R(&)L;VMK(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X`02!-971A<B!B
M;&]K:R!N96T@X6QL(')E;F1E;&ME>NES<F4N($$@<NES>FQE=&5K(&$@<F5N
M9'-Z97)G87ID82!S>N%MX7)A(&OI<WK\;/4@;F%P;/-FX6IL8F$@:V5R_&QT
M96LN`$$@365T87)$0B!N96T@Z7)H973U(&5L+@!-\V1S>F5R`$$H>BD@(B5S
M(B!M\V1S>F5R(&1E9FEN:>%L871L86X`02!M\V1S>F5R(&1E9FEN:>%L871L
M86XN($$@;65G:.UV;W1T(&WS9'-Z97(Z("5S`$UE=')I:W5S`$UE>&EK\P!-
M:6MR;V[I>FEA:2!3>O9V971SZ6=I(,%L;&%M;VL`:_9ZZ7``34E-12!T[7!U
M<P!!>B!E;&WZ;'0@,C0@\W)A(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T
M93H@`$%Z(&5L;?IL="`V(/-R82!L96=A;&%C<V]N>6%B8B!H]6WI<G/I:VQE
M=&4Z(`!-Z6<@;F5M('1E;'0@96P@82!M:6YI;>%L:7,@:63U(&$@:F5L<WKS
M(&UE9W;A;'1O>G1A=.%SX6AO>@!4_&MR]GKI<R`H:F]B8B]B86PI`%9E9WEE
M<P!(:>%N>7II:R!A($A45%!?4F5Q=65S="!014%2(&-S;VUA9RX`2V]N9FEG
M=7+A8VGS('-Z_&MSZ6=E<RX@17IT(&UO<W0@:V5L;"!LZ71R96AO>FYI82P@
M:&$@:&%S>F[A;&YI(&%K87)J82!A>B!A;&MA;&UA>N%S="X`2&GA;GEZ:6L@
M87H@_'IE;F5T(&%Z;VYO<^UT\VIA+@!(:>%N>7II:R!A($UA:6P@4$5!4B!C
M<V]M86<N`$AIX6YY>FEK(&$@9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S
M[73S:F$@*'-E<W-I;VX@240I+@!(Z0!,979E;&5ZZ7,@;6]B:6QT96QE9F]N
M<O-L`$OV>F5P97,`02!M\V1O<^UTX7,@9.%T=6UA`$WS9&]S[73A<P!!>B!5
M4DP@;?-D;W/M=.%S80!-;V1U;'5S`$UO;&1O=F%I($OV>G3A<G-A<^%G`$UO
M;F%C;P!-;VYG\VQI80!(\VYA<"#I<R#I=@!H879O;G1A`$UO;G1S97)R870`
M2&]L9&;A>FES;VL`02`E9"X@<V]R8F%N('3V8F(@;65Z]2!V;VQT+"!M:6YT
M(&$@=N%R="`E9"X`5/9B8BP@;6EN="!E9WD@8^UM970@=&%LX6QT=6YK(&$@
M(B5S(B!M97KU<F4N`$UA<F]K:_,`5/9B8FYY:7)E(&1E<OQL=`!4]F)B;GEI
M<F4@8F]R=6QT`%3V8F)N>6ER92!N87!O<P!496=Y_&L@X70`=FEG>?QK(&QE
M`'9I9WG\:R!B86QR80!V:6=Y_&L@:F]B8G)A`'9I9WG\:R!F]FP`=FEG>?QK
M(&QE:FIE8F(`02!S<&%M(&O\;&1E;>EN>65K970@=&5G>?QK(.%T(&$@<W!A
M;2!M87!PX6)A+"!A('3V8F)I="!P961I9R!A>B!)3D)/6"UB80!T96=Y_&L@
MX70@96)B92!A(&UA<'#A8F$`=FEG>?QK(&;V;&IE8F(`36]Z86UB:6L`5/9B
M8G-Z:6YT^R!L96?V<F3\;/4@;&ES=.%K`$UU;'1I;6%P($YA9WDM0G)I=&%N
M;FEA('3I<FOI<`!4]F)B+"!A;'1E<FYA=.UV('+I<WIT('1A<G1A;&UA>@!,
M97;I;&QI<W1A(&[I>F5T`%3V8F)S>O9R]G,@=N%L87-Z=.%S`$)E:F5L96YT
M:V5ZZ7-I(&)EX6QL[73A<V]K`$)E:F5L96YT:V5ZZ7-I(&%D871A:6T`4V%J
MX70@]G-S>F5G>O4@;VQD86QA;0!386KA="#V<W-Z96=Z]2!O;&1A;&%M('1E
M<G9E>NES90!-:6%N;6%R`$Y%32P@;F5M(&5G>65Z96T@8F5L92X`4T5-34D`
M345'2D5'65K)4P!.Z78`02!NZ78@:6QL+B!E;6%I;"!C[6T@;F5M(&UA<F%D
M:&%T(/QR97-E;@!.86WM8FEA`$YA=7)U`&YI;F-S(';A;&%S>@!.97#A;`!(
M;VQL86YD:6$`2&]L;&%N9"!!;G1I;&SA:P!.971S8V%P92!BX7II<RU54DP`
M3F5T<V-A<&4@=&%N^G/M=';A;GEK:6%DX7-I:F]G*$-!*2UV:7-S>F%V;V[A
M<VD@55),`$YE='-C87!E('1A;OIS[71VX6YY9F5L:&%S>F[A;.%S:2!I<N%N
M>65L=B!54DP`3F5T<V-A<&4@=&%N^G/M=';A;GEM96?Z:NUTX7-I(%523`!.
M971S8V%P92!T86[Z<^UT=N%N>79I<W-Z879O;N%S:2!54DP`3F5T<V-A<&4@
M4U-,('-Z97)V97)NZ78`3F5T<V-A<&4@=&%N^G/M=';A;GD@;65G:F5G>7KI
M<P!.971S8V%P92!T86[Z<^UT=N%N>73M<'5S`$CA;/-Z870`<V]H80!!(&UE
M;&SI:VQE=&5K970@<V]S92!M96YT<_QK(&5L+@#Z:@#::BU+86QE9/-N:6$`
MVFH@:V%T96?S<FEA`-IJ(&UA<'!A`-IJ(&QE=NEL`-IJ(&QE=NEL`-IJ(&QE
M=NEL("5S(&/M;7)E`/IJ:&]L9`#::B!F96QH87-Z;N%L\V[I=B`H;W!C:6]N
MX6QI<RD`VFHM6NEL86YD`-IJ(&QE=F5L96L`VFH@:F5L<WKS`$%Z(/IJ(&IE
M;'-Z\R#I<G;I;GEE<W/I9V4@96MK;W(@:N%R(&QE.B`E>"X`02!M96=A9&]T
M="#Z:B!J96QS>F%V86L@;F5M(&5G>65Z;F5K+@#::B!A8FQA:R`H_')E<RD`
M2.UR96L`2.UR8W-O<&]R=&]K`$OV=F5T:V5Z]0!+]G9E=&ME>O4@-"!FX7II
M<P!+]G9E=&ME>O4@;&5VZ6P`2_9V971K97KU(&]L9&%L`$OV=F5T:V5Z]2!O
M<&-I\VL`2_9V971K97KU/@!.:6-A<F%G=6$`3FEG97(`3FEGZ7)I80#I:G-Z
M86MA`$YI=64`3F5M`$YE;2!T86SA;&AA=/,@=&%N^G/M=';A;GD`5&ET:V]S
M[73A<R]D:6=I=.%L:7,@86SA[7+A<R!NZ6QK_&P`16=Y(&MU;&-S('-I;F-S
M('3A<F]L=F$`3FEN8W,@;&5VZ6P`3F5M(&EM<&]R=.%L='5N:R!E9WD@;GEI
M;';A;F]S(%!'4"!K=6QC<V]T('-E;2X`3F5M('1A;.%L:&%T\R!S>F5MZ6QY
M97,@=&%N^G/M=';A;GD`3FEN8W,@;65G:F5L96[M=&AE=/4@<WKV=F5G`$YE
M;2!T86SA;&AA=/,@;GEI;';A;F]S(&MU;&-S`$YE;2!I;7!O<G3A;/-D;W1T
M(%,O34E-12!N>6EL=N%N;W,@:W5L8W,N`$YI;F-S(&UE;&SI:VQE="X`3FEN
M8W,@<F5N9&5L:V5ZZ7-R92#A;&SS(&MO;F9I9W5RX6-I\RP@86UI:&5Z(&OI
M<&5S="!A(&O\;/9N8G/I9V5K970@;65G(&QE:&5T;F4@;75T871N:2X`3FEN
M8W,@;&5H973U<^EG($E33R#A;&QO;>%N>6]K(&SI=')E:&]ZX7/A<F$N`$AI
MX6YY>FEK(&$@:_9T96=E;'0@9F5L9&]L9V]ZX7-H;WH@<WK\:W/I9V5S(&UI
M;G1A("AB871C:"!T96UP;&%T92DN`$$@:^UVX6YT(&AE;'EE;B!N:6YC<R!B
M;&]K:P!!>B!-0T%,(&9E;&AA<WINX6SS87IO;F]S[73A<VAO>B!N:6YC<R!M
M96=A9'9A(&$@;F%P=.%R(&YE=F4N`$YI;F-S(';A;'1O>N%S+@!%:&AE>B!A
M(&IO9V]S=6QT<^%G:&]Z(&YE;2!H;WIH873S(&SI=')E(&IO9V]S=6QT<^%G
M:2!A;&-S;W!O<G0N`$AIX6YY;WIN86L@82!K;VYF:6=U<N%C:?-S(&%D871O
M:R`E<RUH97HN`$%Z($944"!61E,@;FEN8W,@:V]N9FEG=7+A;'9A+@!!>B!3
M44P@5D93(&YI;F-S(&MO;F9I9W5RX6QV82X`07H@4U%,+49I;&4@5D93(&YI
M;F-S(&MO;F9I9W5RX6QV82X`07H@UFX@<WKA;6SA:N%N(&5L9F]G>6]T="!A
M(')E;F1E;&ME>NES<F4@X6QL\R#V<W-Z96<N`$YI;F-S(&/M;7KI<RX`02!N
M>6EL=N%N;W,@:W5L8W,@;F5M('1A<G1A;&UA>B!E;6%I;')E('9O;F%T:V]Z
M\R!I;F9O<FWA8VGS="X`02!S>F5R=F5R<F4@;F5M('3V;'3U9/9T="!F96P@
M<V5M;6EL>65N(.%L;&]MX6YY`$YI;F-S(&MI:F5L]FQT(&UA<'!A+@!%9WD@
M;6%P<.%B86X@<V5M(&5L;&5N]7)I>GK\:RP@Z7)K97IE='0M92#Z:B!L97;I
M;"X`16=Y(&UA<'!A('-E;2!V;VQT(&MI:F5L]FQV90!.:6YC<R#Z:B!L979E
M;&5T('1A<G1A;&UA>O,@;6%P<&$`3FEN8W,@;VQV87-A=&QA;B!L979E;&5T
M('1A<G1A;&UA>O,@;6%P<&$`07H@:6MO;F]K(&YE;2!T86SA;&AA=/-K+@!.
M:6YC<R!M96=A9'9A(&$@:&5L>2X`3FEN8W,@;65G861V82!A(&AE;'DN`$$@
M;&5VZ6QT]G)Z<R#\<F5S`$YI;F-S(&QE=NEL+@!!>B#\>F5N970@_')E<RX`
M02!K97)E<^ES(&YE;2!T86SA;'0@<V5M;6ET+@!.:6YC<R!M96=A9'9A(&$@
M;NEV+@!.:6YC<R!M96=A9'9A(&$@<WKA;2X`3F4@;&5G>65N(&UE9V)O='+A
M;FMO>G1A=/,@:63I>F5T`$YI;F-S(&IE;'-Z\R!M96=A9'9A(&$@2%144"!A
M;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS
M(&UE9V%D=F$@87H@24U!4"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A
M<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!+97)B97)O<R!A;&%P^B!F
M96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D
M=F$@82!,;V=I;B!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`
M3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!005-35T0@86QA</H@9F5L:&%S>F[A
M;/-I(&%Z;VYO<^UTX7-H;WHN`$YI;F-S(&IE;'-Z\R!M96=A9'9A(&%Z(%--
M0B!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@;65G
M861V82!A>B!/<&5N4U-,('!R;V=R86T@96SI<NES:2#Z='9O;F%L82X@07H@
M3W!E;E-33"!P<F]G<F%M('-Z_&MSZ6=E<R!A(%!+0U,@,3(@861A=&]K(&ME
M>F5LZ7/I:&5Z+@!.:6YC<R#Z:B!B96IE;&5N=&ME>NES:2!I9^EN>2X`3F5M
M(&EM<&]R=.%L\V1O='0@82!01U`@<WIE;>EL>65S+"!T:71K;W,@:W5L8W,N
M`$YE;2!I;7!O<G3A;/-D;W1T(&$@4$=0('-Z96WI;'EE<RP@;GEI;';A;F]S
M(&MU;&-S+@!.96T@:6UP;W)TX6SS9&]T="!3+TU)344@<WIE;>EL>65S('1A
M;OIS[71VX6YY+@!.:6YC<R!M96<@82!T:71K;W,@<WIE;>EL>65S(&MU;&-S
M+"!E>NER="!A(&OS9&]L="!L97;I;"!T87)T86QM82!N96T@9F5J=&AE=/4@
M=FES<WIA+@!.:6YC<R!K=O-T82!B9>%L;.UT=F$N`$YE(&QE9WEE;F5K('9O
M;F%L86L@<V5H;VPN`$YI;F-S(&1E9FEN:>%L=F$@96QVX6QA<WIT\R!K87)A
M:W1E<BX`3F4@;&5G>65N(&ME<F5T`$$@:&5L>65S[7+A<V5L;&5N]7)Z]2!P
M<F]G<F%M(&YI;F-S(&MO;F9I9W5RX6QV82X`3FEN8W,@:&5L>65S[7+A<VD@
M:&EB80!.:6YC<R!I;'EE;B!FX6IL`$YI;F-S(&IA=F%S;&%T`$YI;F-S(&]L
M>6%N(&9E;&AA<WINX6SS87IO;F]S[73A<VD@;?-D<WIE<BP@86UI="!A>B!)
M34%0('-Z97)V97(@=.%M;V=A="X`3FEN8W,@:61E:6=L96YE<R#A;&QO;>%N
M>6]K('3A<F]LX7/A<F$@<WIO;&?A;/,@86QK]FYY=G3A<BX`3F5M(&IE;/9L
M="!M96<@9F5L:&%S>F[A;/-T+@!(:>%N>7II:R!A(&9E;&AA<WINX6SS;NEV
M(.ES+W9A9WD@82!J96QS>O,N`$$@=FES<WIA:V%P;W1T(&%D871O:R!N96T@
MZ7)VZ6YY97,@6$U,(&%D871O:P!.:6YC<R!A9&%T`$YI;F-S(&WI9R!K;VYF
M:6=U<N%C:?,L(&=E;F5RX6QJ;VX@96=Y970N`$YI;F-S(&WI9R!K;VYF:6=U
M<N%C:?-J82P@9V5N97+A;&IO;B!E9WEE="X`3F5M('+I<WIT=F5V]0!E9WEI
M:RAE="D@<V5M`&YI;F-S(&UE9V%D=F$@*&QE9WEE;B!A;&%PZ7)T96QM97IE
M='0I`&YO<F1I:W5S("A)4T\M.#@U.2TQ,"D`3F]R9F]L:RUS>FEG970`:_9Z
M97!E<P#)<WIA:VD@9NEL=&5K90#)<WIA:VDM36%R:6%N82US>FEG971E:P!.
M;W)VZ6=I80!.96T@:^ES]6)B`$YE;2!K;W+A8F)A;@!N96T@=/9R]FQT`&YE
M;2!M=6YK87#I;&3A;GD`;F5M(&9O;G1O<P!N96T@<WIE;>EL>65S`$YE;2!A
M;&OV;GEV=.%R`$YE;2#I<G;I;GEE<R!N>6EL=N%N;W,@:W5L8W,N`$YE;2!T
M]G+V;'0@;&5V96QE:P!!('!R;V=R86UN86L@97H@82!RZ7-Z92!MZ6<@;FEN
M8W,@;65G=F%L\W/M='9A+@!.96T@9F]N=&]S(&QE=F5L96L`3FEN8W,@8F7A
M;&SM='9A`$YE;2!TX6UO9V%T;W1T+@!%>B!E;'1A<G1H870@96=Y(&ED96EG
M`$9E;&IE9WEZZ7-E:P!396UM:0!.:6YC<R!B]FYGZ7-Z:&5T]2!A9&%T+"!T
MZ7)J96X@=FES<WIA+@!4X6KI:V]Z=&%TX7,Z(&$@:&EV871K;WIO='0@;65L
M;.EK;&5T970@;&5T]FQT]G1T_&L`;F]V96UB97(`4WKA;0!+87)A:W1E<F5K
M('-ZX6UA`$]S>FQO<&]K('-ZX6UA`"!H\VYA<&EG('1A<G1S=6L@;65G(&$@
M:&EV871K;WKA<R!F;W)MX6KA8F%N(&O\;&3V='0@;65L;.EK;&5T96L@=.EN
M>6QE9V5S('#I;&3A;GGA="P@:&%V:2!T]G)LZ7,@97-E=.EN+@!D8B!RZ6=I
M(&5L:_QL9/9T="!L979E;&5K970@=&%R=&%L;6%Z\R`H<V5N="UM86EL*2!M
M87!PX70@=&%R='-U;FL@;65G+"!H879I('3V<FSI<R!E<V5TZ6X`4V]R;VL@
M<WKA;6$`02!K]G)L97;I;&QI<W1A(&WS9&]S[73A<^%H;WH@;F5M(&%D;W1T
M(&UE9R!S>N%M;VMA="X`3TL`5D%'60!/8FIE:W1U;0!!>B!O8FIE:W1U;2!L
MZ71R96AO>O-J80!/:W3A;&ES('-ZX6T`;VMT\V)E<@!3>OMRZ7,`2&EV871A
M;"]M=6YK86AE;'D`02!RZ6=I(.ES(&%Z(/IJ(&IE;'-Z\VYA:R!K_&SV;F+V
M>FYI92!K96QL+@!2Z6=I(&QE=F5L96L`02!RZ6=I(&IE;'-Z\P!!('+I9VD@
M:F5L<WKS(&YE;2!M96=F96QE;/4N`%3V<FSU9&YE:R!A('+I9VD@96QK_&QD
M]G1T(&QE=F5L96ME="!T87)T86QM87KS("AS96YT+6UA:6PI(&UA<'#A:RX`
M3VWA;@!#<V%K(&%Z($E-05`@<WIE<G9E<F5K('3A;6]G871JX6L@82!M87!P
MX6L@;65G;W-Z=.%SX70N`$-S86L@87IO:V%T(&$@;6%P<.%K870@;75T87-S
M=6LL(&UE;'EE:V)E;B!V86X@;VQV87-A=&QA;B!L97;I;#\`0W-A:R!M96=B
M;W1RX6YK;WIT873S(&EDZ7IE="!L96=Y96X`0W-A:R!E9WD@96UA:6P@8^UM
M(&%D:&%T\R!M96<N`$OI<F5M+"!H;V=Y(&5H:&5Z(&$@9F5L861A=&AO>B!C
M<V%K(&5G>2!M87!PX70@:F5L]FQJ]FX@:VDN`$-S86L@82!T=6QA:F1O;F]S
M('9A9WD@82!R96YD<WIE<F=A>F1A(';A;'1O>G1A=&AA=&IA(&UE9R!E9WD@
M:_9Z]G,@=.%R=&5R_&QE="!T=6QA:F1O;F]SX70@=F%G>2!E;.ERZ7-I(&IO
M9V]S=6QT<^%G86ET`$UA<'!A(&YY:73A<P!.>6ES<W5K(&UE9R#Z:B!A8FQA
M:V)A;@!/<&5N4U-,(&AI8F$Z($YE;2!S:6ME<OQL="!K:6YY97)N:2!A>B!A
M9&%T;VMA="!A>B!A;.'M<G0@4R]-24U%('+I<WIB]6P`2VEN>6ET;W1T(&UA
M<'!A`$YY:7-S=6L@;65G(&5Z="!A(&/M;65T(&5G>2#Z:B!A8FQA:V)A;@!/
M<&5RX6-I\W,@<F5N9'-Z97(`5N%L87-Z=&AA=/,@<NES>G1V97;U`$]P8VGS
M:P`E<R!B9>%L;.UTX7-A:0!3;W)S>N%M;W,@9F5L<V]R;VSA<P!3>F5R=F5Z
M970`4WIE<G9E>F5T:2!E9WESZ6<`375N:V%S>F5R=F5ZZ7,`07H@86QK86QM
M87KA<R!E<F5D971I('-A8FQO;FIA`"5S(&5R961E=&D@<V%B;&]N:F%I.@!%
M9WGI8@!%9WGI8B!I;F9O<FWA8VGS`$ED96=E;B!L979E;&5Z]7-Z97)V97)E
M:V5N(&QE=O4@;&5VZ6QLX63A:P!%9WGI8B!B9>%L;.UTX7-O:P!+:6UE;O4@
M*%--5%`I('-Z97)V97(`02!T=6QA:F1O;F]S(&IO9V]S=6QT<^%G86D`02!0
M04T@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R
M92X`4$5!4CHZ36%I;"!A;')E;F1S>F5R`%!'4"!D:6=I=.%L:7,@86SA[7+A
M<P!4:71K;W/M='-U:R!A(&QE=F5L970@4$=0+79E;`!01U`M=F5L('1I=&MO
M<^UT;W1T(&%D870`4$=0(&AI8F$Z(`!01U`@:&EB83H@82!S>F5MZ6QY97,@
M=&ET:V]S(&MU;&-S(&AA<WINX6QA=.%H;WH@:F5L;6]N9&%T('-Z_&MSZ6=E
M<RX`4$=0(&)EX6QL[73A<V]K`,UR:F$@8F4@82!01U`@:F5L;6]N9&%TX70`
M02!01U`@<WIE;>EL>65S(&MU;&-S<.%R('3A;6]G873A<R!T:71K;W/M=&]T
M="!W96(@:V%P8W-O;&%T;W0@:6?I;GEE;"X`4$=0(&YY:6QVX6YO<R!K=6QC
M<P!01U`@;GEI;';A;F]S(&MU;&-S('-Z]G9E9V4`(B5S("@E<RDB(&YY:7;A
M;F]S(%!'4"!K=6QC<^%T('-I:V5R97-E;B!F96QV971T_&LN`"(E<R(@;GEI
M=N%N;W,@4$=0(&MU;&-SX70@<VEK97)E<V5N('3V<O9L=/QK+@!01U`@;GEI
M;';A;F]S(&MU;&-S;VL`3.%S<W5K(&5L(&$@;&5V96QE="!01U`@9&EG:73A
M;&ES(&%LX>URX7-S86P`5&ET:V]S[71S=6L@Z7,@9&EG:73A;&ES86X@[7)J
M=6L@86SA(&$@;&5V96QE="!01U`M=F5L`%!'4"UV96P@86SA[7)T+W1I=&MO
M<^UT;W1T(&%D870`02!01U`@=&ET:V]S(&MU;&-S;W0@<VEK97)E<V5N(&9E
M;'9E='3\:RX`02!01U`@;GEI;';A;F]S(&MU;&-S;W0@<VEK97)E<V5N(&9E
M;'9E='3\:RX`02!01U`@=.%M;V=A=.%S(&EN86MT:7;A;'9A('9A;B!A(')E
M;F1S>F5R8F5N+@!!(%!'4"!TX6UO9V%TX7,@:F5L96YL96<@;FEN8W,@86MT
M:7;A;'9A+"!E>NER="!A(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%SX6YA:R!H
M:71E;&5S<^EG92!N96T@96QL96[U<FEZ:&5T]2X`02!01U`@=.%M;V=A=.%S
M(&IE;&5N;&5G(&YI;F-S(&%K=&EVX6QV82P@97KI<G0@82!K\V1O;'0@;&5V
MZ6P@=&%R=&%L;6$@;F5M(&9E:G1H973U('9I<W-Z82X`02!01U`@=.%M;V=A
M=.%S(&9E;&)U:VMA;O,@*'!O<'5P*2!A8FQA:V]K870@:6?I;GEE;"X@2&$@
M87H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@^F=Y('9A;B!B9>%L;.UT=F$L(&AO
M9WD@;&5T:6QT:F$@82!F96QB=6MK86[S(&%B;&%K;VMA="P@86MK;W(@=F%G
M>2!VX6QT;WIT87-S;VX@82!B9>%L;.UTX7-O:V]N+"!V86=Y(&$@4$=0('-Z
M;VQGX6QT873A<V]K(&YE;2!F;V=N86L@;65G9F5L96SU96X@;?MK]F1N:2X`
M4$A0(&OS9`!$Z6QU=.%N+V5S=&4@9WEE;F=E(&5S]0!$Z6QU=.%N(&5S]0!$
MZ6QU=.%N+V5S=&4@>N%P;W)O:P!$Z6QU=.%N+V5S=&4@:&%V87KA<P!$Z6QU
M=.%N+V5S=&4@:/-ZX7!O<F]K`$3I;'5TX6X@;F%P<_QTZ7,`1.EL=73A;B]E
M<W1E('II=F%T87)O:P!03U`S`%!/4#,@*&%U=&]M871I:W5S('!R;W1O:V]L
M;"!M96=H873A<F]ZX7-S86PI`%!/4#,@4U-,(&;V;/9T=`!03U`S(%-33"!F
M]FSV='0@*/9N=&%N^G/M=';A;FYY86PI`%!/4#,@4U-,(&;V;/9T="`H]FYT
M86[Z<^UT=N%N;GEA;"D`4$]0,BP@5$Q3(&[I;&O\;`!(:>%N>7II:R!A(%!/
M4TE8(&+U=NUTZ7,`8F5L<_4@;6%R9_,`)60N(&]L9&%L(&$@)60M8O5L`$%Z
M(&5L<_4@;VQV87-A=&QA;B!L979E;&5T('1A<G1A;&UA>O,@;VQD86P`07H@
M=71O;'/S(&]L=F%S871L86X@;&5V96QE="!T87)T86QM87KS(&]L9&%L`%!A
M:VES>G3A;@!086QA=0!086QE<WIT:6X@5&5R_&QE="`H;65G<WKA;&QT*0!0
M86YA;6$`4.%P=6$@VFHM1W5I;F5A`%!A<F%G=6%Y`%+I<WHH96LI`$WI<G/I
M:V5L=&5N(&)O<G5L=`!*96QM;VYD870`2F5L;6]N9&%T("AMZ6<@96=Y<WIE
M<BD`02!J96QM;VYD871O="!S:6ME<F5S96X@96QTX79O;.UT;W1T=6LN`$IE
M;&UO;F1A=#H`02!J96QM;VYD870@;F5M(&QE:&5T(/QR97,`02!J96QM;VYD
M871O:R!N96T@96=Y97IN96L`2F5L<WKS`$$@:F5L<WKS="!S:6ME<F5S96X@
M;65G=N%L=&]Z=&%T='5K+@!.96T@;65G9F5L96SU(&IE;'-Z\P!!(%)!1$E5
M4R!F96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@:F5L<WKS('-Z_&MSZ6=E<RX`
M2F5L<WKS(&UE9V5R]7/M=.ES<V5L`$IE;'-Z\SH`2F5L<WKS.B``02!J96QS
M>F%V86MN86L@96=Y97IN:?QK(&ME;&PN`$)E:6QL97-Z=.ES`$)E:6QL97-Z
M=.%S(&$@=N%G\V%S>G1A;'+S;`#:='9O;F%L`-IJ(&9E;&AA<WINX6SS;F%K
M(&)E:F5L96YT:V5Z971T96LZ`$5M8F5R96L`<WKA>F%LZ6L`2V%R8F%N=&%R
M=.%S:2!F96QA9&%T;VL@=NEG<F5H86ITX7-A`$)E:F5L96YT:V5ZZ7-K;W(@
M:&%J='-U:R!VZ6=R92!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K870_`$IO
M9V]S=6QT<^%G`$$H>BD@(B5S(B!J;V=O<W5L='/A9V]T(&YE;2!T]G+V;'3\
M:RX`UFYN96L@;FEN8W,@96AH97H@96QE9V5N9/4@:F]G;W-U;'1SX6=A`$IO
M9V]S=6QT<^%G;VL`2F]G;W-U;'1SX6<@861M:6YI<WIT<N%C:?,`02!F96QH
M87-Z;N%L\R!J;V=O<W5L='/A9V%I(&YE;2!VX6QT;WIT871H873S:R!M96<N
M`'-Z96WI;'EE<P!3>F5MZ6QY97,@861A=&]K`$$@<WIE;>EL>65S(%!'4"!K
M=6QC<W#A<G0@<VEK97)E<V5N(&SI=')E:&]Z='5K+@!!('-Z96WI;'EE<R!0
M1U`@:W5L8W-O:V%T('-I:V5R97-E;B!T]G+V;'3\:RX`3D5-(&EM<&]R=.%L
M\V1O='0@4R]-24U%('-Z96WI;'EE<R!T86[Z<^UT=N%N>6]K.B``02!S>F5M
MZ6QY97,@4R]-24U%(&MU;&-S;VMA="!S:6ME<F5S96X@=/9R]FQT_&LN`%!E
M<G4`P6QL871K961V96YC96L`1OQL]G`M<WII9V5T96L`5&5L969O;@!&Z6YY
M:^EP9V%LZ7)I80!0:71C86ER;@!P:7AE;`!!>B#6;B#A;&QA;F3S(&QE=NEL
M=NEG>O5DZ7/I="`H<VEG;F%T=7)E*2!VX6QA<WIO;.%S:V]R(&EL;"X@;&5V
MZ6QT;W;A8F+M=.%S:V]R(&$@8F5I9.EZ971T(&QE=NEL(&5LZ2!H96QY97IZ
M_&L_`$$@;&5VZ6P@<VEM82!T97AT(';A;'1O>F%T80!+]GIH96QY96L`2^ER
M(&AA;F=J96QZZ7-T(/IJ(&QE=NEL(.ER:V5ZZ7-E:V]R/R!%:&AE>B!B]FYG
MZ7-Z]7!R;V=R86UJX6YA:R!TX6UO9V%T;FEA(&ME;&P@82!H86YG;&5JX71S
M>N%S="X@17)R92!A(%=I;F1O=W,@Z7,@36%C('!R;V=R86UO:R!C<V%K;F5M
M(&UI;F1E9WEI:V4@:^EP97,L(&1E(&WA<R!P;&%T9F]R;6]K;VX@:VEE9^ES
M>NUT]2`H<&QU9VEN*2!P<F]G<F%M('1E;&5P[73I<V4@<WK\:W/I9V5S+@!+
M871T:6YT<V]N('9A;&%M96QY:6L@8V5L;.%R80!":7IT;W-A;B!T]G+V;&YI
M(&%K87)J82!E>G0@87H@96QE;65T.@!+Z7)E;2!E<O5S[71S92!M96<L(&AO
M9WD@=F%L\V)A;B!T]G+V;&YI(&OM=N%N:F$@97IT(&%Z(&5L96UE="X`2^ER
M96T@861J;VX@;65G(&5G>2!H\VYA<&]T(.ES(&5G>2#I=F5T+@!+Z7)E;2!A
M9&IA(&UE9R!A>B#Z:B!K871E9_-R:6$@;F5VZ70Z`$OI<F5M(&%D:F$@;65G
M(&%Z(/IJ(&UA<'!A(&YE=NET.@!+Z7)E;2!V86SS<R!)4"!C[6UE="!A9&IO
M;B!M96<N`$OI<F5M('9A;/-S(&3A='5M;W0@861J;VX@;65G+"!E;&QE;O5R
M:7IZ92!A(&CS;F%P(&YA<&IA:70N`$OI<F5M('9A;/-S(&3A='5M;W0@861J
M;VX@;65G+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!M87!P82!N97;I=#H`2^ER
M96T@861J82!M96<@87H@^FH@;F5V970Z`$OI<F5M(&%D:F$@;65G(&$@<WIE
M;>EL>65S+"!T:71K;W,@4$=0(&MU;&-SX6AO>B!T87)T;WKS(&IE;&UO;F1A
M=&]T+B!%>B!C<V%K(&5G>7-Z97(@:V5L;"!B9>UR;FEA(&%L:V%L;6%N:^EN
M="!A("5S(&AA<WINX6QA=&%K;W(N`$OI<F5M(&%D:F$@;65G(&$@<WIE;>EL
M>65S+"!T:71K;W,@4R]-24U%(&MU;&-SX6AO>B!T87)T;WKS(&IE;&UO;F1A
M=&]T+B!%>B!C<V%K(&5G>7-Z97(@:V5L;"!B9>UR;FEA(&%L:V%L;6%N:^EN
M="!A("5S(&AA<WINX6QA=&%K;W(N`$OI<FK\:R!J96QE;G1K97IZ96X@8F4@
M:7-MZ70@82!L97;I;.URX7,@9F]L>71A=.%SX6AO>BX@2&$@8O9N9^ES>O5P
M<F]G<F%M:F$@3D5-(&5N9V5DZ6QY97II(&$@8V]O:VEE+6L@:&%S>F[A;&%T
MX70@R5,@9F5L8G5K:V%N\R!A8FQA:V)A;B#M<FIA(&QE=F5L96ET(&%K:V]R
M(&$@9O4@86)L86MB86X@:7,@8F4@:V5L;"!J96QE;G1K97IN:64N($5Z(&%Z
M(-9N(&)I>G1O;G/A9V$@Z7)D96OI8F5N('9A;B#M9WDL(&AO9WD@;F4@=.ER
M[71H97-SZ6L@96P@82!S>F5R=F5R<F5L(&MO<N%B8F%N(&9E;.EP[71E='0@
M:V%P8W-O;&%TX70N($5L;NEZZ7/I="!KZ7)J_&L@82!K96QL96UE=&QE;G/I
M9^ER="X`2^ER96T@<O9V:61E;B#M<FIA(&QE(&$@<')O8FSI;6$@;.EN>65G
MZ70N`$OI<F5M(&%D:F$@;65G(&$@:F5L<WIA=N%T+@!+Z7)E;2!A9&IA(&UE
M9R!A(&)E:F5L96YT:V5ZZ7-I(&YE=NET(.ES(&IE;'-Z87;A=`!+Z7)E;2!A
M9&IA(&UE9R!A(&)E:F5L96YT:V5ZZ7-I(&YE=NET+@!+Z7)E;2!O;'9A<W-A
M(&5L(&$@:_9V971K97KU('-Z]G9E9V5T+B!!(')E;F1S>F5R(&AA<WINX6QA
M=.%N86L@9F5L=.ET96QE:70@96P@2T5,3"!F;V=A9&YI82X`2^ER96T@:F%V
M[71S82!K:2!A(&AI8N%S('9A9WD@;F5M(&5G>>ER=&5L;?L@8^UM96ME="X`
M2^ER96T@:F5L]FQJ]FX@:VD@96=Y(&UA<'#A="!A(&9E;&%D870@=NEG<F5H
M86ITX7-A(&5L]71T+@!+Z7)E;2!J96SV;&KV;B!K:2!L96=A;.%B8B!E9WD@
M;6%P<.%T+"!A;6EB96X@82!K97)E<VYI(/-H86IT+@!+Z7)E;2P@:&]G>2!E
M:&AE>B!A(&9E;&%D871H;WH@8W-A:R!E9WD@;6%P<.%T(&IE;/9L:O9N(&MI
M+@!+Z7)E;2P@:&]G>2!J;V)B(&]L9&%L:2!M97KU8F5N(';A;&%S<WIA(&MI
M+"!V86=Y(&WS9&]S[71S83H`2^ER96T@861J82!M96<@87H@^FH@:V%T96?S
M<FEA(&YE=NET.@!,96YG>65L;W)S>N%G`%!O;&ET:6MA`%-Z879A>N%S;VL`
M4&]R='5GX6QI80!!(&OI<"!E;&AE;'EE>NES90!!('3A8FSA>F%T(&5L:&5L
M>65ZZ7-E`$OV>G9E=&QE;B!L97;I;&O\;&3I<R!E8F)E(&$@;6%P<.%B82`H
M24U!4"!N96T@;6EN9&EG('9E<WII(&9I9WEE;&5M8F4I`$5Z(&5G>2!(;W)D
M92!R96YD<WIE<@!,96=Y96X@87H@UFX@X6QL86YD\R!L97;I;';I9WKU9.ES
M92`H<VEG;F%T=7)E*2!E;/5T="!KZ70@:_9T]6IE;"`H)RTM("<I/P!!>B!E
M;&WZ;'0@)7,@\W)A(&-S87!A9.EK;65N;GEI<^EG93H@`$-S87!A9.EK/&)R
M("\^=F%L\W-Z[6[[<^EG`$$@8F7A;&SM=.%S;VMA="!S:6ME<F5S96X@96QM
M96YT971T_&LN`%!R969S7VQD87`Z(&YE;2!T86SA;&AA=/,@82!S>OQK<^EG
M97,@3$1!4"!K:71E<FIE<WITZ7,N`%!R969S7W-E<W-I;VXZ(&YE;2!T86SA
M;&AA=/,@82!S>OQK<^EG97,@*'-E<W-I;VXI(&MI=&5R:F5S>G3I<RX`3.EG
M;GEO;>%S`$$@=&5N9V5R<WII;G1N96L@;65G9F5L96SU(&SI9VYY;VWA<SH@
M`$SI9VYY;VWA<SH@`$)E=&5K:6YTZ7,`02!KZ7`@96SU>F5T97,@;65G=&5K
M:6YTZ7-E(/IJ(&%B;&%K8F%N`$5L]7KU(&QE=NEL`$5L]7KU(&]L9&%L`$5L
M]7KU(&]P8VGS:P!.>6]M=&%TX7,`02!D;VMU;65N='5M(&MI;GEO;71A=.%S
M80!0<FEO<FETX7,@*'/\<F?U<W/I9RD`5&ET:V]S(&MU;&-S`$$@=&ET:V]S
M(&MU;&-S(&IE;'-Z879A`$AI8F%B96IE;&5N=.ES`$$@:&EB82!L9>URX7-A
M`%!R;VIE:W0@:V5Z96SI<P!6X6QA<WIT:&%S<V%K+"!H82!M96QLZ6ML970@
M=F%N(&$@;&5VZ6QB96X[($Y%32!A>B!A;&%PZ7)T96QM97IE='0`5N%L87-Z
M=&AA<W-A:RP@:&$@;65L;.EK;&5T('9A;B!A(&QE=NEL8F5N.R!)1T5.(&%Z
M(&%L87#I<G1E;&UE>F5T=`!!('!R;VUP="!S>O9V96=E`%!R;W1O:V]L;#H`
M3GEI;';A;F]S(&MU;&-S`$YY:6QVX6YO<R!K=6QC<_H@86QG;W)I=&UU<P!.
M>6EL=N%N;W,@:W5L8W,@:6YF;W)MX6-I\P!!(&YY:6QVX6YO<R!01U`@:W5L
M8W-S>F5R=F5R('3A;6]G873A<R!N:6YC<R!E;F=E9.EL>7IV92X`02!N>6EL
M=N%N;W,O=&ET:V]S(&MU;&-S<.%R="!N96T@<VEK97+\;'0@;.ET<F5H;WIN
M:2X`4'5E<G1O(%)I8V\`7U;I9VQE9V5S('3V<FSI<P!6Z6=L96=E<R!T]G)L
MZ7,`36%P<&$H:RD@=/9R;.ES90!-:6QY96X@9WEA:W)A;B#\<NUT<_QK(&$@
M)U-Z96UE=&5S)R`H5')A<V@I(&UA<'#A=#\`02!L979E;&5K(';I9VQE9V5S
M('3V<FSI<V4`;F%P;N%L('+I9V5B8FD@;&5V96QE:V5T(/QR[71S_&L@:VD@
M82`G4WIE;65T97,G("A4<F%S:"D@;6%P<.%B\VP`02`G4WIE;65T97,G("A4
M<F%S:"D@;6%P<.%B\VP@=/9R]FQJ_&L@:VD@82!RZ6=I(&QE=F5L96ME=#\`
M)60@;&5VZ6P@=/9R;/5D:6L@82`G4WIE;65T97,G("A4<F%S:"D@;6%P<.%B
M\VPN`#$@;&5VZ6P@=/9R;/5D:6L@82`G4WIE;65T97,G("A4<F%S:"D@;6%P
M<.%B\VPN`$MA=&%R`$ME<F5S]2]P87)A;F-S('-T<FEN9P!+=O-T80!+=O-T
M83H@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0!+=O-T83H@)2XR9DU"("\@
M;FEN8W,@;&EM:70`2W;S=&$Z(&YI;F-S(&QI;6ET`$EDZ7IE="`H)68I.@!2
M4T$@;GEI;';A;F]S(&MU;&-S("@E9"!B:71E<RD`4N%D:?-G;VUB;W,@:VEV
MX6QA<WITX7,`17/U`$5S]2!DZ6QE;/5T=`!%<_4@9.EL=73A;B]E<W1E`%KA
M<&]R`$5S]2#I<R!H879A>N%S`$AA=F%S97/U`%;I;&5T;&5N(&EDZ7IE=`!!
M<N%N>0!/;'9A<^%S`$QE=F5L96L@;VQV87/A<V$`5.EN>6QE9R!T]G+V;&K\
M:R`E<R!F96QH87-Z;N%L\W0_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M(&9O<F3M
M=&AA=/,@=FES<WIA+@!4Z6YY;&5G('3V<O9L:OQK("5S(&9E;&AA<WINX6SS
M(&%D871A:70_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M(&9O<F3M=&AA=/,@=FES
M<WIA+@#)<.UT<_QK(/IJ<F$@82!M87!P87-T<G5K=/IRX70`17IE;B!A(&YA
M<&]N(.ER:V5Z971T`$5Z=73A;B#I<FME>F5T=`!%>F5L]71T(.ER:V5Z971T
M`,%T:7+A;GGM=.%S`,%T:7+A;GGM=.%S`$$@;&5VZ6P@X71I<N%N>>UTX7-A
M`$ERX6YY[71S=6L@X70@97IT(&$@;&5V96QE=`!!>B#A=&ERX6YY[73A<R!N
M96T@<VEK97+\;'0N`-IJ<F$@=NEG<F5H86IT:F$@87H@=71O;'/S(';A;'1O
M>G1A=.%S=`!&<FES<^UTZ7,`02!M96[\(&1I;F%M:6MU<R!E;&5M96EN96L@
M9G)I<W/M=.ES:2!G>6%K;W)I<^%G83H`1G)I<W/M='/\:R!A(&UA<'#A:R!L
M:7-TX6KA=#H`07H@]G-S>F5G>O5O;&1A;"!F<FES<^UTZ7/I;F5K(&=Y86MO
M<FESX6=A.@!/8FIE:W1U;2!B]FYGZ7-Z]0!&<FES<^UTZ7,`2^ER:OQK(&QE
M(/IJ<F$@97IT(&%Z(&]L9&%L=`!-96=J96=Y>NES96L`5.%R;VQJ=6L@96P@
M87H@:63U8F5O<WITX7-I(&%D871O:V%T+@!4X7)O;&IU:R!E;"!A>B!U=&]L
M<_,@;NEZ971E=`!4X79O;&D@;&5VZ6QLX61A.@!4X79O;&D@<WIE<G9E<F5K
M`$$@=.%V;VQI(%523"`H<&PN(&AT='`Z+R]W=W<N=F%L86UI+FAU+VUE9W9A
M;&%M:2DZ`%3V<FSI<P!";&]K:R!T]G)LZ7-E`$AA9WEJ=6L@:VD@82!M97KU
M="!A(&ME<F5SZ7-B]6P`3W-Z;&]P('3V<FSI<V4`02!F;W)M871TX6SA<R!T
M]G)LZ7-E`$$@<.%R('3V<FSI<V4`5/9R]FQJ_&L@87H@96QM96YT971T('!R
M;V=R86UO="!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N>6]K870@=&%R
M=&%L;6%Z\R!A;&OV;GEV=.%RX6+S;"X`=.%V;VSM='-U:R!E;`!696=Y_&L@
M:VD@`%9E9WG\:R!K:2!E>G0@82!RZ7-Z="!A(&1O:W5M96YT=6UB\VP`02!F
M96QH87-Z;N%L\R!T]G)LZ7-E`"5S(&9E;&AA<WINX6SS('3V<FSI<V4`36%P
M<&$H:RD@X71N979E>NES90!.979E>GK\:R#A="!A>B!E;&O\;&3V='0@;&5V
M96QE:V5T('1A<G1A;&UA>O,@*'-E;G0M;6%I;"D@;6%P<.%T(&$@:/-N87`@
M96QE:NEN/P!!("`B)7,B+7+U;"`B)7,B+7)E('3V<G3I;O4@X71N979E>NES
M(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R(/QZ96YE=&4`5N%L87-Z(&$@;&ES
M=.%R80!#<V5RZ6QJ_&L@:VD@97IZ96PZ`%;A;&%S>@!!(';A;&%S>G0@96QK
M_&QD=/QK+@!6X6QA<WH@87H@]G-S>F5S(&/M;7)E`%;A;&%S>B!A>B#V<W-Z
M97,@8^UM<F4Z`%;A;&%S>B!A(&QI<W3A<F$`5N%L87-Z(&$@;&ES=.%R83H`
M5N%L87-Z(&%Z(/9S<WIE<R!C[6UR90!!>B!A9&]T="!KZ7+I<W0@82!R96YD
M<WIE<B!N96T@=.%M;V=A=&IA`$%Z(&ED]6)E;W-Z=.%S:2!A9&%T:^ERZ7-T
M(#(@:/-N87!R82!T96QJ97/M=&5M+@!!>B!I9/5B96]S>G3A<VD@861A=&OI
M<NES('1E;&IE<^UTZ7-E+@!6:7-Z;VYT=N%L87-Z(&/M;0!6:7-Z;VYT=N%L
M87-Z(&/M;3H@`%;A;&%S>CH`3F5M+7-P86T@8F5J96QE;G3I<P!3<&%M(&)E
M:F5L96YTZ7,`5FES<WIA:6=A>F]LX7-T(&OI<F5K(&$@;&5VZ6P@96QO;'9A
M<^%SX7+S;`!!(&OI<NES(&YE;2!T96QJ97/M=&AE=/4N($$@:V%P;W1T(&AI
M8F%K\V0Z(`!+Z7(@=FES<WIA:6=A>F]LX7-T(&%R<O-L+"!A;6EK;W(@82!C
M[6UZ971T(&5L;VQV87-S82!A(&QE=F5L970_`$$@:^UVX6YT(&QE=NEL(&YE
M;2!T86SA;&AA=/,N`$$@:V5R97-E='0@<WIO;&?A;'1A=.%S(&YE;2!T86SA
M;&AA=/,N`$$@:_9T96QE>O5E;B!M96=A9&%N9/,@(B5S(B!N96T@<WIE<F5P
M96P@)7,@:V]N9FEG=7+A8VGS:N%B86XN`$$@:_9T96QE>O5E;B!M96=A9&%N
M9/,@(B5S(B!N96T@<WIE<F5P96P@82!61E,@:V]N9FEG=7+A8VGS:N%B86XN
M`$$@:_9T96QE>O5E;B!M96=A9&%N9/,@(B5S(B!N96T@<WIE<F5P96P@82!K
M;VYF:6=U<N%C:?-B86XN`%-Z_&MSZ6=E<R!M97KU`'-Z_&MSZ6=E<R!RZ7-Z
M='9E=O4`4F5S970`02!J96QS>O,@X73A;&SM=.%S80!!>B#6;B!J96QS>F%V
MX6YA:R#A=.%L;.UTX7-A`$$@=N%L87-Z863S('-TX71U<WKA="!M96?Z:NUT
M;W1T=6LN`$%Z('5T;VQS\R!K97)E<^ES('9I<W-Z8>%L;.UTX7-A`$5R961M
MZ6YY`$9O;'ET873A<P!&;VQY=&%S<W5K(&$@;&5VZ6SM<N%S=`!6:7-S>F$@
M82`B3&5VZ6SM<N%S(BUH;WH`5FES<WIA(&$@;&5VZ6SA='3V;'3I<VAE>@!6
M:7-S>F$@87H@;W!C:?-K:&]Z`%3I<FK\;FL@=FES<WIA(&$@;&5VZ6QL:7-T
MX6AO>B!T]G)LZ7,L(.%T:&5L>65ZZ7,@=F%G>2!MX7-O;.%S('5TX6X_`$%Z
M(/IJ(&IE;'-Z\W0@[7)J82!B92!I<VWI=`!2Z75N:6]N`,%L;.UT<W5K('9I
M<W-Z82!A(&MO;F9I9W5RX6-I\W0`4FEC:"!497AT($5D:71O<B!O<&-I\VL`
M5&%LX6SS<R!KZ7)DZ7-E:P!J;V)B`$IO8F(@;VQD86QI(&9E:FSI8P!*;V)B
M(&]L9&%L:2#I<G3I:V5K`%-O<B!T=6QA:F1O;G/A9V]K+BXN`%-Z97)E<`!2
M;VWA;FEA`$9O<F=A=.%S(#$X,"!F;VMK86P`0F%L<F$@9F]R9V%TX7,`2F]B
M8G)A(&9O<F=A=.%S`%-O<B!T=6QA:F1O;G/A9V]K`%-O<B!T=6QA:F1O;G/A
M9V]K`%-O<F]K.@!6;VYA;&%K`$UI;F1E;B!S;W(@Z7,@;W-Z;&]P(&OV>O9T
M="!L96=Y96X@=F]N86P`0W-A:R!A>B!O<WIL;W!O:R!K]GKV='0@;&5G>65N
M('9O;F%L`$-S86L@82!S;W)O:R!K]GKV='0@;&5G>65N('9O;F%L`$9U='1A
M=.%S`$]R;W-Z($;V9&5RX6-I\P!2=6%N9&$`4R]-24U%(&1I9VETX6QI<R!A
M;.'M<N%S`$$@;&5VZ6P@=&ET:V]S[73A<V$@4R]-24U%+6UA;`!3+TU)344@
M<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&]T="!L97;I;`!3+TU)344@:&EB
M83H@`%,O34E-12!H:6)A.B!A('-Z96WI;'EE<R!T:71K;W,@:W5L8W,@:&%S
M>F[A;&%TX6AO>B!J96QM;VYD870@<WK\:W/I9V5S+@!3+TU)344@8F7A;&SM
M=.%S;VL`S7)J82!B92!A>B!3+TU)344@:F5L;6]N9&%TX70`07H@4R]-24U%
M('-Z96WI;'EE<R!K=6QC<W#A<B!TX6UO9V%TX7,@=&ET:V]S[71O='0@=V5B
M(&MA<&-S;VQA=&]T(&EGZ6YY96PN`"(E<R(@;GEI=N%N;W,@4R]-24U%(&MU
M;&-SX70@<VEK97)E<V5N('3V<O9L=/QK+@!!(&YY:7;A;F]S(%,O34E-12!K
M=6QC<V]T('-I:V5R97-E;B!F96QV971T_&LN`%,O34E-12!N>6EL=N%N;W,@
M:W5L8W-O:P!!>B!3+TU)344@;GEI;';A;F]S+W1I=&MO<R!K=6QC<W#A<G0@
M<VEK97)E<V5N(&9E;'9E='3\:RX`3.%S<W5K(&5L(&$@;&5V96QE="!3+TU)
M344@9&EG:73A;&ES(&%LX>URX7-S86P`5&ET:V]S[71S=6L@Z7,@9&EG:73A
M;&ES86X@[7)J=6L@86SA(&$@;&5V96QE="!3+TU)344M;6%L`$5Z96X@82!R
M96YD<WIE<F5N(&YI;F-S96X@4R]-24U%('3A;6]G873A<RX`07H@4R]-24U%
M('3A;6]G873A<R!J96QE;FQE9R!N:6YC<R!A:W1I=N%L=F$L(&5ZZ7)T(&$@
M:_-D;VQT(&QE=NEL('1A<G1A;&UA(&YE;2!F96IT:&5T]2!V:7-S>F$N`$%Z
M(%,O34E-12!TX6UO9V%TX7,@:F5L96YL96<@;FEN8W,@86MT:7;A;'9A+"!E
M>NER="!E(&1I9VETX6QI<V%N(&%LX>UR="!L97;I;"!T87)T86QM82!N96T@
M:F5L96[M=&AE=/4@;65G+@!!>B!3+TU)344@=.%M;V=A=.%S(&IE;&5N;&5G
M(&YI;F-S(&%K=&EVX6QV82P@97KI<G0@82!L97;I;"!D:6=I=.%L:7,@86SA
M[7+A<^%N86L@:&ET96QE<W/I9V4@;F5M(&5L;&5N]7)I>FAE=/4N`$%Z(%,O
M34E-12!TX6UO9V%TX7,@9F5L8G5K:V%N\R`H<&]P=7`I(&%B;&%K;VMA="!I
M9^EN>65L+B!(82!A>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82#Z9WD@=F%N(&)E
MX6QL[71V82P@:&]G>2!L971I;'1J82!A(&9E;&)U:VMA;O,@86)L86MO:V%T
M+"!A:VMO<B!V86=Y(';A;'1O>G1A<W-O;B!A(&)EX6QL[73A<V]K;VXL('9A
M9WD@87H@4R]-24U%('-Z;VQGX6QT873A<V]K(&YE;2!F;V=N86L@;65G9F5L
M96SU96X@;?MK]F1N:2X`4T%33"!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M
M('1A;.%L:&%T\RX`4TU3(&O\;&3I<P!344P@<&%R86YC<R!A(&ME<F5SZ7-H
M97H`4U-(`%-)2T52W$Q4`%]4X7)G>0!3>F\`365N='/\;FL@96P@96=Y('#I
M;&3A;GET(&5B8F5N(&$@;6%P<.%B86XZ(`!-96YTZ7,`4WIE;G0@26QO;F$M
M<WII9V5T`%-A:6YT($MI='1S(.ES($YE=FES`%-A:6YT($QU8VEA`%-A:6YT
M(%!I97)R92#I<R!-:7%U96QO;@!386EN="!6:6YC96YT(.ES($=R96YA9&EN
M92US>FEG971E:P!59WEA;F%Z(&$@9G)A;64@*%]S96QF*0!3>F%M;V$`4V%N
M($UA<FEN;P!386\@5&]MZ2#I<R!0<NUN8VEP90!-^VAO;&1A<R!I;G1E<FYE
M=&5LZ7+I<P!3>F'Z9"U!<N%B:6$`365N=.ES`"(E<R(@;65N=.ES90`E<R!M
M96YTZ7-E`$$@;65L;.EK;&5T96ME="!A(&QE=NEL;&5L(&5G>?QT="!M96YT
M<_QK(&5L(&%Z(&5L:_QL9/9T="!L979E;&5K(&UA<'#A:N%B86X_`$UE;G1S
M_&L@96P@;75N:V%PZ6QDX6YY:^EN=`!!(&OI<"!E;&UE;G3I<V4`02!KZ7`@
M9V%LZ7)IX6)A;B!T]G)TZ6[U(&5L;65N=.ES90!-96YTZ7,`02!L97;I;'!A
M<.UR(&5L;65N=.ES90!-96YT<_QK(&5L(&UU7VYK87#I;&3A;GEKZ6YT`$UE
M;G3I<P!!(&UU;FMA<.EL9.%N>6OI;G0@96QM96YT971T(&QE=F5L96ME="!O
M;'9A<V%T;&%N:^EN="!J96SV;&K\:R!M96<_`$UE;G1S_&L@96P@87H@96QK
MZ7-Z_&QT(&MO;F9I9W5RX6-I\W0@4$A0('!R;V=R86T@9F]R;>%JX6)A;B!A
M('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N>6]K870@=&%R=&%L;6%Z\R!A
M;&OV;GEV=.%RX6)A;BX`365N='/\:R!E;"!A=71O;6%T:6MU<V%N(&$@8^UM
M>F5T=&5K(&%D871A:70@87H@86QA<.ER=&5L;65Z971T(&/M;6IE9WEZZ6MB
M96X_`$UE;G1S_&L@96P@82!K97)E<^ES="!V:7)T=>%L:7,@;6%P<&%KZ6YT
M/P!-96YT<_QK(&5L(&%Z(&5L:_QL9/9T="!L979E;&5K970_`"5S(&MO;F9I
M9W5RX6-I\VKA="!E;&UE;G1E='3\:RX`16QM96YT971T_&L@82!S971U<"!U
M<&=R861E('!R;V=R86UO="!I9&4Z("(E<R(`02!M=6YK87#I;&3A;GEKZ6YT
M('9A;/,@;65N=.ES(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R(';A;&%S>F$Z
M("5S`%-Z\W)VX6YY;W,@>FEV871A<F]K`%1U9&]MX6YY`$ME<F5SZ7,`2V5R
M97/I<R!A*'HI("5S(&UA<'#A8F%N`$ME<F5SZ7-I('-Z;VQGX6QT873A<V]K
M`$$@:V5R97/I<W-E;"!K87!C<V]L871O<R!B9>%L;.UTX7-O:P!!(&ME<F5S
MZ7,@97)E9&WI;GEE`&WA<B!O;'9A<V]T=`!6X6QA<W-Z=6L@:VDL("AA;6DI
M`%;A;&%S<WIO;B!K:2!E9WD@;>%S:6L@87IO;F]S[73S=`#!;&QO;>%N>6]K
M(&MI=N%L87-Z=.%S80!6X6QA<W-Z;VX@:VD@96=Y(&3A='5M;W0`5N%L87-S
M>F]N(&MI(&5G>2!M97KU=`!-96QY:6L@8W-O<&]R=&]T(&OM=N%N:F$@:&]Z
M>N%A9&YI`%;A;&%S<WIA(&MI(&%Z(/IJ('1U;&%J9&]N;W-T`%;A;&%S<WIO
M;B!S>F5R=F5R=`!6X6QA<W-Z;VX@:VD@96=Y(&QE=NEL<&%P[7)T.@!-96QY
M:6L@9F5L:&%S>F[A;/-T(&OM=N%N:F$@:&]Z>N%A9&YI`$MI=N%L87-Z=&AA
M=/,L(&AO9WD@;65L>6EK(&/M;6IE9WEZZ6ME:VAE>B!K[7;A;B!H;WIZX71E
M;FYI+"!I;&PN(&UE;'EE:V)E;B!K[7;A;B!K97)E<VYI+@!-:6YD970@:VEJ
M96SV;&K\:P!6X6QA<W-Z82!K:2!A>B#V<W-Z97,@9.%T=6WV<W-Z971E=O5T
M+@!!(&/M;7+I<WIL970@=&5L:F5S(&/M;6WI(&%L86OM=.%S86MO<B!A(&/M
M;6IE9WEZZ6ME:R!M:6YD96X@;65Z]6KI8F5N('3V<G3I;FIE;B!K97)E<^ES
M/P!6X6QA<W-Z;VX@96=Y(&%Z;VYO<^UT\W0`5N%L87-S>F]N(&5G>2!O8FIE
M:W1U;6]T`$5G>2!S92!L96=Y96X@:VEJ96SV;'9E`%;A;&%S<WIA(&MI(&$@
M:^UVX6YT(&MA<F%K=&5R*&5K92ET(&%Z(&%LX6)B:2!L96AE=/5SZ6=E:R!K
M]GK\;"X@17IU=.%N(")C;W!Y+W!A<W1E(B!M\V1S>F5R<F5L(&$@;65G9F5L
M96SU(&AE;'ER92!MX7-O;&AA=&IA(/5K970N`%;A;&%S<WIA(&MI(&$@9.%T
M=6UE;';A;&%S>G3S(&MA<F%K=&5R=#H`5N%L87-S>F$@:VD@82!DX71U;2!F
M;W)MX71U;>%T.@!6X6QA<W-Z82!K:2P@;65L>6EK(&=A;.ER:>%B86X@:^UV
MX6YJ82!A(&OI<&5T(&5L:&5L>65Z;FDN`%;A;&%S<WIA(&MI+"!M96QY:6L@
M87IO;F]S[73S:N%T(&OM=N%N:F$@;65G=N%L=&]Z=&%T;FDZ`%;A;&%S<WIA
M(&MI(&$@;&5V96QE>O5S>F5R=F5R('3M<'5SX70`5N%L87-S>F$@:VD@87H@
M:63U96QVX6QA<WIT\R!K87)A:W1E<G0Z`%;A;&%S<WIA(&MI(&%Z(&ED]2!F
M;W)MX71U;>%T.@!6X6QA<W-Z;VX@:VD@:^ET(&5G>6WA<VYA:R!M96=F96QE
M;/4@;65Z]70N`%;A;&%S<WIA(&MI(&$@:^UVX6YT('-Z[6YE9WG\='1E<W0N
M`%;A;&%S<WIA(&MI(&%Z(-9N;F5K(&UE9V9E;&5L]2!N>65L=F5T.@!!(&MI
M=N%L87-Z=&]T="!C[6UJ96=Y>NEK96LZ`$O\;&1J_&L@96P@82!K=6QC<V]T
M(&5G>2!N>6EL=N%N;W,@:W5L8W-S>F5R=F5R<F4`2^ER96T@82!L96=F<FES
M<V5B8B!I;F9O<FWA8VGS:V%T`$O\;&1J_&L@96P`2&EB86IE;&5N=.ES(&O\
M;&3I<V4`4TU3(&O\;&3I<V4`2_QL9&K\:R!E;"!A(&QE=F5L970@82!4X7)G
M>2!M96=A9.%S82!NZ6QK_&P_`$O\;&1J_&YK(&$@8F7I<FME>O4@;&5VZ6P@
M96QO;'9A<^%SX7+S;"!V:7-S>F%I9V%Z;VSA<W0L(&AA(&OI<G0@:6QY970@
M82!F96QA9/,_`%-Z96YE9^%L`%-Z96YZ;W(Z(`!!>B!E;&O\;&3V='0@;&5V
M96QE:R!M87!PX6IA`$%Z(&5L:_QL9/9T="!L979E;&5K(&UA<'#A:F$Z`'-Z
M97!T96UB97(`4WIE<F)I82#I<R!-;VYT96YE9W+S`%-O<F]Z871S>N%M`%-Z
M97)V97(`4WIE<G9E<B#I<R!M87!P82!I;F9O<FWA8VGS:P!!('-Z97)V97)T
M]6P@:V%P;W1T(&%D870@:&EBX7,L('9A9WD@;F5M(.%L;"!R96YD96QK97KI
M<W)E+@!3>F5R=F5R.@!!(&9E;&AA<WINX6SS:V%P8W-O;&%T;VL@861M:6YI
M<WIT<N%C:?-J80!,96KA<G0@82!F96QH87-Z;N%L\VMA<&-S;VQA="!A>F]N
M;W/M=/-J82`H<V5S<VEO;B!)1"DN`$9E;&AA<WINX6SS:V%P8W-O;&%T;VL`
M2&%L;6%Z`$QE:&5T]7/I9R!J96QS>F%VX6YA:R#A=.%L;.UTX7/A<F$L(&%B
M8F%N(&%Z(&5S971B96XL(&AA(&5L9F5L96IT96[I+@!!(&QE=F5L96L@X71H
M96QY97KI<^EV96P@Z7,@=/9R;.ESZ79E;"!K87!C<V]L871O<R!B9>%L;.UT
MX7-O:RX`3&5VZ6SM<N%S:V]R(&)EX6QL[73S9&KI:RUE(&$@6"U0<FEO<FET
M>2!F96ILZ6-S;W(_`%3A=F]L:2!S>F5R=F5R96L@96SI<NES92#A;&SM=&AA
M=/,@8F4L(&UE;'EE:V5T(&%Z(&EN9'5L\V]L9&%LX6X@:^UVX6X@;65G:F5L
M96[M=&5N:2X`02!K[7;A;G0@;GEE;'8L(&ED]7KS;F$@Z7,@9.%T=6UF;W)M
MX71U;2!B9>%L;.UTX7-A+@!"9>%L;.UT:&%T\RP@:&]G>2!M96QY:6L@86QK
M86QM87KA<R!J96QE;FIE;B!M96<@82!B96IE;&5N=&ME>NES('5TX6XL(&UI
M;'EE;B!S>NUN96=Y_'1T97-T+"!O;&1A;&9R:7-S[73I<VD@9WEA:V]R:7/A
M9V]T(&EL;"X@96=YZ6(@8F7A;&SM=.%S;VMA="!S>F5R971N92X`0F7A;&SM
M=.%S;VL`02!B9>%L;.UTX7-O:V%T(&UE9_IJ[73S('!R;V=R86UO:R#A;&QN
M86L@<F5N9&5L:V5ZZ7-R90!!(&UE9V%D;W1T('!A<F%MZ71E<B!T]F)B(&AE
M;'EE="!I<R!J96QE;G1H970Z(`!397EC:&5L;&4M<WII9V5T96L`36%P<.%I
M;FL@:&]Z>N%FZ7+I<VD@:F]G;W-U;'1SX6?A;F%K(&UE9V]S>G3A<V$`36%P
M<.%I;FMH;WH@=F%L\R!H;WIZX6;I<NES:2!J;V=O<W5L='/A9V]K`$AO>GKA
M9NERZ7-T(&%D:&%T(&WA<R!F96QH87-Z;N%L\VMN86L@96=Y97,@;6%P<.%I
M:&]Z+@!6X7/A<FSA<P!2]G9I9"#V<W-Z969O9VQA;.%S`$5L(&OM=N%N:F$@
MZ7)N:2!A>B!E9WEE<R!F=6YK8VGS:V%T($%L="UB:6QL96YT>?LM:V]M8FEN
MX6-I\VMK86P@:7,_`$$@:&]S<WKZ(&)E:63I>F5T="!L97;I;'+I<WIL971E
M:V5T(&%L87#I<G1E;&UE>NES:^EN="!N92!M=71A<W-U:S\@0N%R:&]G>2!V
MX6QA<WIO;"P@97H@:_9N;GEE;B!K:2]B96MA<&-S;VQH873S+@!!('1E>'0O
M<&QA:6X@;&5V96QE:R!T]G)Z<^ET('9I>G-GX6QJ=6L@=NEG:6<@4$=0(&%D
M871O:V%T(&ME<F5S=F4_`$-S=6OS9&IO;BUE(&)E(&%Z(&%B;&%K+"!H82!L
M97;I;.URX7-K;W(@;75N:V%PZ6QDX6YY:^EN="!E;&UE;G1J_&L@87H@861D
M:6=I(&UU;FOA;FMA=#\`2_QL9&K\:R!E;"!A>B#6;B!01U`@;GEI;';A;F]S
M(&MU;&-SX70@;65L;.EK;&5T:^EN="!M:6YD96X@;&5VZ6QL96P_`$UE9VIE
M;&5N[73I<P!-=71A<W-U:R!A>B#V<W-Z97,@;6%P<.%T`$UU=&%S<W5K(&$@
M;&5VZ6P@=&5L:F5S(&9E:FSI8^ET`$$@=/9R]FQT96ME="!I<R!M=71A<W-U
M:P!#<V%K(&$@<WIO:^%S;W,@9F5J;.EC<NES>F5K970@;75T87-S=6L`02!L
M979E;&5ZZ7-I(&QI<W3A<F$@=F]N871K;WKS(&EN9F]R;>%C:?-K`$-S86L@
M82!H87-Z;N%L871B82!H96QY97IE='0@*'-U8G-C<FEB960I(&UA<'#A*&MA
M*70@;75T87-S=6L`02!H87-Z;N%L871O;B!K[7;\;"!H96QY97IE='0@*'5N
M<W5B<V-R:6)E9"D@;6%P<.%K870@:7,@;75T87-S=6L`4WK\:W/I9V4@=F%N
M+64@;VQY86X@:6MO;G)A+"!A;6EV96P@:VET]G+V;&AE=/4@96=Y(&QE=NEL
M(&UE;&SI:VQE=&4_`$UU=&%S<W5K(&UE9R!A(&O\;/9N8G/I9V5K970@87H@
M96QM96YT971T(.ES(&%Z(/IJ;VYN86X@;.ET<F5H;WIO='0@:V]N9FEG=7+A
M8VGS(&OV>O9T="X`36EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(@[7+S9&KI:R!K
M:2!A(&MO<N%B8FD@=71O;'/S(&)E:F5L96YT:V5ZZ7,@:61E:F4_`$QE9WEE
M;B!J96QM86=Y87+A>F%T(&$@;&5VZ6QL:7-TX6L@;65G:F5L96[M=.ES96MO
M<C\`5N%L87-Z=&AA=/,@;&5G>65N(&%Z(&5R961E=&D@;65G=&%R=.%S80!,
M96=Y96X@9.%T=6UVX6QA<WIT\P!#<V%K(&%Z(&]L=F%S871L86X@;&5V96QE
M:VYE:R!L96=Y96X@96SU;NEZ971E/P!!>B!E;/5NZ7IE="!A:VMO<B!J96QE
M;FIE;B!M96<L(&AA(&%Z(&5G97)E="!A(&QE=NEL('-O<F$@9O9LZ2!V:7-S
M>OQK/P!,96=Y96X@96=Y('3A8FSA>F%T:V5Z96SU(&UE;OQS;W(_`$UU=&%S
M<W5K(&$@)7,@;65N_'0@82!B86P@;VQD86QO;C\`3&5G>65N(&$@;65N_&)E
M;B!E9WD@3&5VZ6SA='3V;'3I<R!I:V]N/P!-=71A<W-U:R!A(&OI<&5K970`
M3NEZ>OQK(&UE9R!TX6)LX7IA="!C96QLX6EN86L@='5L86ID;VYSX6=A:70`
M3NEZ>OQK(&UE9R!TX6)LX7IA="!T=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G
M('3A8FSA>F%T('-O<F%I;F%K('1U;&%J9&]N<^%G86ET`$QE9WEE;B!E9WD@
M:6MO;B!A(&QE=NEL<WK[<NES:&5Z(&$@;65N_'-O<F)A;C\`3NEZ>OQK(&UE
M9R!A(&OI<"!T=6QA:F1O;G/A9V%I=`!-=71A<W-U:R!A(&UA<'!A(/9S<WIE
M<R!L979E;&5I;F5K('-ZX6WA=#\`375T87-S=6L@82!F96QT]FQTZ7-T`%KA
M<&]R;VL`6N%P;W)O:R!DZ6QE;/5T=`!:X7!O<F]K(&3I;'5TX6XO97-T90!(
M96QY:2!ZX7!O<F]K`&UU=&%S<W5K`$MI8W-I;GGM=.ES`$5L]7-Z]G(@:VEC
M<VEN>>UT96YI92!K96QL+"!V86=Y(&5L(&ME;&P@;6]Z9.UT86YI82!A(&AE
M;'EE="!E;&9O9VQA;/,@8FQO:VMO:V%T+@!-Z7)E=`!3:65R<F$@3&5O;F4`
MVFH@9F5L:&%S>F[A;/-K(&)E:F5L96YT:V5ZZ7-E`$1I9VETX6QI<R!A;.'M
M<N%S`$$@9&EG:73A;&ES(&%LX>URX7,@86QG;W)I=&UU<V$`1&EG:73A;&ES
M86X@86SA[7)T`%-Z:6YG87#Z<@!-Z7)E=`!!(&MA<F)A;G1A<G3A<R!K:6AA
M9WGA<V$`4WIL;W;A:VEA`%-Z;&]VZ6YI80!(879A>N%S`$CS>N%P;W(`2/-Z
MX7!O<F]K`$CS>N%P;W)O:R!DZ6QE;/5T=`!+Z7/U(&3I;'5TX6YI+V5S=&D@
M:/-ZX7!O<F]K`$$@:/,@;>EL>7/I9V4Z(`!(\R!V[7IM96YN>6ESZ6=E8F5N
M(&MI9F5J97IV93H@`%-A;&%M;VXM<WII9V5T96L`4WIO;>%L:6$`1&%L;VLL
M('9E<G-E:P!"9>ER:V5ZZ7,@<WIE<FEN=&D@<V]R<F5N9`!)9/5P;VYT('-Z
M97)I;G1I('-O<G)E;F0`1F5L863S('-Z97)I;G1I('-O<G)E;F0`3&5VZ6QM
MZ7)E="!S>F5R:6YT:2!S;W)R96YD`%3A<F=Y('-Z97)I;G1I('-O<G)E;F0`
M3&]G:6MA:2`H=&AR96%D*2!S;W)R96YD`$/M;7IE='0@<WIE<FEN=&D@<V]R
M<F5N9`!!('-O<F)A<F5N9&5ZZ7,@:7+A;GGA;F%K(&MI=N%L87-Z=.%S80!&
M96QA9/-I(&/M;0!$Z6PM069R:6MA`&3I;"UE=7+S<&%I("A)4T\M.#@U.2TS
M*0!$Z6QI+4=E;W)G:6$@Z7,@1.EL:2!386YD=VEC:"US>FEG971E:P!$Z6QI
M(&;I;'1E:V4`4WIO;7-ZZ61O<R!C96QLX6L@:_9Z]G1T:2!TX79O;'/A9P!!
M(&-E;&QA('1A<G1A;&UA(.ES(&ME<F5T92!K]GKV='1I('3A=F]L<^%G`$AE
M;'EK:73V;'3U`%3A=F]L<^%G`%3A=F]L<^%G(.ES(&)E;'/U(&UA<F?S(&)E
MX6QL[73A<P!3<&%N>6]L;W)S>N%G`%-P86UA<W-A<W-I;F4@8F7A;&SM=.%S
M;VL`4W!A;2!M87!P83H`4W!E8VGA;&ES(&MA<F%K=&5R(&)E=FET96QE`%-P
M96-IX6QI<R!K87)A:W1E<F5K`$$@<W!E8VGA;&ES('9I<G1UX6QI<R!M87!P
MX6L@;F5M(&WS9&]S[71H873S:RX`2&5L>65S[7+A<V5L;&5N]7)ZZ7,`2&5L
M>65S[7+A<V5L;&5N]7)Z]0!!(&AE;'EE<^URX7-E;&QE;O5R>NES(&)E9F5J
M97KU9/9T=`!(96QY97/M<N%S96QL96[U<GKI<VMO<B!A>B!E9WD@:^EP97)N
M>?5N(&UE9VIE;&5N[71E='0@:&EBX6L@<WKA;6$N`$$@8V5L;&$@:V5T=.EB
M;VYTX7-A`$%Z(&]S>FQO<"!K971TZ6)O;G3A<V$`02!S;W(@:V5T=.EB;VYT
MX7-A`%-P;W)T`%-R[2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`2V5Z9&5T
M`$%Z(&5L<_4@Z78`P6QL86T@=F%G>2!T87)T;VWA;GD`3&5VZ6QP87#M<@!!
M(&QE=NEL<&%P[7(@;F5V93H`02!L97;I;'!A<.UR(&9A:G3A:F$Z`$QE=NEL
M<&%P[7(Z`%-TX71U<WH`365N=.ES:2!F;W)MX71U;0!#[6T@*'5T8V$I`.%T
M:/IZ;W1T`%-T<FEN9R!L:7-T80!!(&UE;&SI:VQE="!E;'3A=F]L[73A<V$`
M5/9R]FQJ_&L@82!C[6UB]6P@82!`('5TX6YI('+I<WIT`$AA9WEJ=6L@9FEG
M>65L;65N(&OM=OQL(&$@<V]R=/9RZ7-E:V5T/P!3=.UL=7,@6T-34UT`5F$`
M5.%R9WD`02AZ*2`B)7,B(&%L:_9N>79TX7(@;F5M('1A;.%L:&%T\RX`5.%R
M9WD`5.%R9WD@;65Z]0!+_&QD:OQK(&5L`"(E<R(@^FH@9F5L:&%S>F[A;/,@
M8F5J96QE;G1K97KI<VD@:^ER96QMZ70@=&]VX6)B[71O='1U:RX@UFX@8W-A
M:R!KZ7)E;&WI;F5K(&5L9F]G863A<^%T(&OV=F5T]65N('1U9"!M86ID(&)E
M:F5L96YT:V5Z;FDN`$$@;6%P<.$H:V$I="!H96QY97IZ_&L@:&%S>F[A;&%T
M8F$@*'-U8G-C<FEB92D`86QS\R!I;F1E>`!3:6ME<OQL=`!3:6ME<F5S96X@
M:&]Z>N%A9'1U:R`B)7,B+70@82!R96YD<WIE<FAE>BX`(B5S(B!F96QH87-Z
M;N%L\R!A9&%T86ET('-I:V5R97-E;B!T]G+V;'3\:R!A(')E;F1S>F5R8O5L
M+@!3:6ME<F5S96X@=/9R]FQT_&L@(B5S(BUT+@!3:6ME<F5S96X@96QTX79O
M;.UT;W1T=6L@(B5S(BUT(&$@<F5N9'-Z97)B]6PN`$$@:V]N9FEG=7+A8VGS
M="!S:6ME<F5S96X@=FES<WIAX6QL[71O='1U:RX@02!VX6QT;WKA<V]K(&UE
M9W1E:VEN=.ESZ6AE>B!F<FES<^UT<V4@87H@;VQD86QT+@!!(&)A8VMU<"!K
M;VYF:6=U<N%C:?-T(&5L;65N=&5T=/QK+@!3:6ME<F5S96X@96QM96YT971T
M_&L@82AZ*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="X`(B5S(B!A9&%T86EN
M86L@;?-D;W/M=.%S82!S:6ME<F5S96X@;65G=/9R=.EN="X`4VEK97)E<V5N
M(&5L;65N=&5T=/QK(&$@)7,@X6QL;VWA;GET+@!3>G5DX6X`2F%V87-L871O
M:P#6<W-Z969O9VQA;.%S`$YA<&ME;'1E`$YA<&YY=6=T80!N87!O<P!.87!K
M96QT90!.87!K96QT92]N87!N>75G=&$`3F%P:V5L=&4Z(`!.87!N>75G=&$`
M3F%P;GEU9W1A.B``9F5L<_4@:6YD97@`3VYL:6YE(&MO;6UU;FEKX6-I\R`H
M8VAA="D`4W5R:6YA;64`0W-A;.%D;NEV`%-V86QB87)D(.ES($IA;B!-87EE
M;@!3>G;A>FEF]FQD`%-VZ61O<G-ZX6<`5N%L='-U;FL@;&5VZ6SM<N%S:2!M
M\V1O=`!6X6QT<W5N:R!(5$U,(&9O<FWA='5M^B!L97;I;.URX7-R80!6X6QT
M<W5N:R!S:6UA('1E>'0@9F]R;>%T=6WZ(&QE=NEL[7+A<W)A`%-VX6IC`$%Z
M(&%D871S>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>70@=/9R]FQT_&L`
M4WII;G1A:W1I:V%I(&AI8F$@82!K97)E<_5K:69E:F5ZZ7-B96X`4WKM<FEA
M:2!!<F%B($OV>G3A<G-A<^%G`%II=F%T87(`6FEV871A<BP@97+U<R!S>NEL
M`%II=F%T87)O:P!+;W)A:2!Z:79A=&%R;VL`5%-6("A404(@:V%R86MT97)R
M96P@96QVX6QA<WIT;W1T(.ER=.EK96LI(.%L;&]MX6YY`%3A8FSA>F%T`$$@
M=.%B;.%Z870@='5L86ID;VYSX6=A:0!!('3A8FSA>F%T('1U;&%J9&]N<^%G
M86D`5&%J=F%N`%1A:G9A;@!4861Z<VEK:7-Z=.%N`%1A;GKA;FEA:2!%9WEE
M<_QL="!+:7+A;'ESX6<`02!CZ6PZ`$9E;&%D871O:P!?4WKV=F5G`%1E;&5F
M;VYS>N%M`$%Z(&5L;?IL="#S<F$@:/5MZ7)SZ6ML971E.B``2/5MZ7)SZ6ML
M970`2/5MZ7)SZ6ML970Z(`!(]6WI<G/I:VQE=#QB<B`O/B@E<TUA>"5S+R5S
M36EN)7,I("9D96<[)7,`02AZ*2`B)7,B('-A8FQO;B!N96T@=&%LX6QH873S
M+@!386)L;VYO:R!A9&UI;FES>G3A8VGS:F$`1F5L=.ET96QE<SH@`&9E;'3I
M=&5L97-E;B!E;&9O9V%D;VT@82!M96=H[7;A<W0`9F5L=.ET96QE<V5N(&5L
M9F]G861V80!!(&-O;F8N<&AP+6)E;B!N:6YC<R!M96=A9'9A(&$@4WIO;&?A
M;'1A=.%S($9E;'3I=&5L96ET('1A<G1A;&UA>O,@9N%J;"X`4WKV=F5G`&-S
M86L@<WKV=F5G`%-Z]G9E9V5L:&5L>65ZZ7,`<WKV=F5G('1E=&5J90!#<_P`
M=&AA:2`H5$E3+38R,"D`5&AA:6;V;&0`07H@9G1P(&+U=NUTZ7,@;F5M('1A
M;.%L:&%T\RX`02!L97;I;"!&96QA9/,@;W-Z;&]PX7)A(&MA='1I;G1V82!M
M:2!T]G)TZ6YJ96XZ`$$@2&ES=&]R>2!R96YD<WIE<B!M^VOV9.ES92!N:6YC
M<R!E;F=E9.EL>65Z=F4N`$$@2&]R9&4O2V]L86(@:6YT96=RX6-I\R!E>G0@
M;F5M('3A;6]G871J83H@(B5S(@!!>B!)34%0('-Z97)V97(@^F=Y('3[;FEK
M+"!N96T@=.%M;V=A=&IA(&$@:VEVX6QA<WIT;W1T(&9E;&AA<WINX6SS87IO
M;F]S[73A<VD@;?-D<WIE<G0N($9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H
M;WHN`$%Z($E-4U`@;F%P;/-ZX7-T(&YE;2!S:6ME<OQL="!M96=K97ID96YI
M+@!-86-I;G1O<V@@(G)E<V]U<F-E(&9O<FLB`$$@36%C:6YT;W-H(")R97-O
M=7)C92!F;W)K(B!L973V;'1H973U("5S+@!!($UA:6YT96YA;F-E.CH@;W-Z
M=.%L>2!B973V;'3I<V4@;F5M('-I:V5R_&QT`$%Z($]P8VGS(&%B;&%K(&)E
M>N%R;V1O='0N($MI;.EPZ7,@:_9V971K97II:RX`02AZ*2`B)7,B(&%Z;VYO
M<^UT\W0@:VET]G+V;'3\:RX`02AZ*2`B)7,B(&%Z;VYO<^UT\W0@96QM96YT
M971T_&LN`$$@2F]G;W-U;'1SX6=O:R!H87-Z;N%L873A;F%K(&5L]69E;'3I
M=&5L92P@:&]G>2!A(')E;F1S>F5R9V%Z9&$@:V]N9FEG=7+A;&IO;B!E9WD@
M82!J;V=O<W5L='/A9VD@861A=&]K870@=&%R=/-S86X@=.%R;VQN:2!KZ7!E
M<R!A;')E;F1S>F5R="X`02!M96QLZ6ML970@;F5M('1A;.%L:&%T\RX`0W-A
M:R!A;'5L(&QE9WEE;B!K97)E=`!!(&YA<'3A<B!A9&%T;VL@:&EBX7-A:R]E
M;&9O9V%D:&%T871L86YO:P!!('!A<G1N97(@87IO;F]S[73S<WKA;6$@;F5M
M('9O;'0@;65G861V82_\<F5S96X@;6%R861T('9A9WD@87H@861A=&+A>FES
M8F%N(&YE;2!V;VQT(&UE9W1A;.%L:&%T\RX`02!P87)T;F5R(&%D871A:70@
M<VEK97)E<V5N(&AO>GKA861T=6L@82!C[6UJ96=Y>NEKZ6AE>BX`02!-86-I
M;G1O<V@@9N%J;"!T87)T86QM82!A;.%B8B!T96MI;G1H973U(&UE9RX`02`B
M)7,B(&UA<'!A*&MA*70@X71N979E>GK\:R`B)7,B+7)E+@!.96T@<VEK97+\
M;'0@;65G:&%TX7)O>FYI(&%Z;VMN86L@82!F96QH87-Z;N%L\VMN86L@82!L
M:7-TX6KA="!A:VEK(&AO>GKA9NER;F5K(&5H:&5Z(&$@;6%P<.%H;WHN`$O\
M;/9NX6QL\R!01U`@86SA[7+A<VD@8FQO:VL@<WK\:W/I9V5S(&$@9&EG:73A
M;&ES86X@86SA[7)T(/QZ96YE="!H:71E;&5S<^EGZ6YE:R!E;&QE;O5R>NES
MZ6AE>BX`02!K]G)L97;I;&QI<W1A(&%Z;VYO<^UT\W-ZX6UA(&YE;2!V;VQT
M(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871BX7II<V)A;B!N
M96T@=F]L="!M96=T86SA;&AA=/,N`$$@:_9R;&5VZ6QL:7-T82!N96T@=F]L
M="!M96=A9'9A+@!!(&UU;FMA<.EL9.%N>70@82AZ*2`B)7,B(&UA<'#A8F%N
M(&UE;G1E='3\:R!E;"X`02!T:71K;W/M=.%S:2!S>F]L9^%L=&%TX7-O:VAO
M>B!B:7IT;VYSX6=O<R`H=&ET:V]S[71O='0I('=E8B!K87!C<V]L870@:V5L
M;"X`07H@97-E;>EN>70@8F7M<G1U:R!A(&YA<'3A<N%B82X`02AZ*2`B)7,B
M(&UE>O4@=&%R=&%L;6$@;F5M(&5GZ7-Z[71H973U(&MI+@!!*'HI("5S(.%L
M;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@96=Y("5S(&)EX6QL[73A
M<VYA:RX`02AZ*2`E<R#A;&QO;>%N>6)A;B!S>F5R97!E;&YI92!K96QL96YE
M('9A;&%M:6QY96X@)7,@8F7A;&SM=.%S*&]K*6YA:RX`02!FX6IL(&YE;2!M
MX7-O;&AA=/,@]FYM86?A<F$N`$$@9N%J;&)A;B!N96T@=F]L="!A9&%T+@!!
M("(E<R(@;F5V^R!M87!P82!MX7(@;.ET97II:P!!("(E<R(@9F]L9&5R(&YE
M=NEB96X@;F5M(&UE9V5N9V5D971T(&MA<F%K=&5R96L@=F%N;F%K+B!%>B!G
M;VYD;W0@;VMO>FAA="X@2^ER96T@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87ID
MX6AO>BX`02`B)7,B(&UA<'#A="!LZ71R96AO>G1U:RP@9&4@;FEN8W,@:&%S
M>F[A;&%T8F$@:&5L>65Z=F4@*'-TX71U<WIA('5N<W5B<V-R:6)E9"D`02`B
M)7,B(&UA<'#A="!T]G+V;'3\:RP@9&4@=&]VX6)B<F$@:7,@:&%S>F[A;&%T
M<F$@=F%N(&MI:F5L]FQV92`H<W3A='5S>F$@<W5B<V-R:6)E9"D`02`B)7,B
M(&UA<'#A="!N96T@<VEK97+\;'0@;.ET<F5H;WIN:2X@02!S>F5R=F5R(/QZ
M96YE=&4`02AZ*2`B)7,B(&UA<'#A="!N96T@<VEK97+\;'0@=/9R]FQN:2X@
M02!S>F5R=F5R(/QZ96YE=&4`02`B)7,B(&UA<'#A="!S:6ME<F5S96X@;.ET
M<F5H;WIT=6LN`$$@(B5S(B!M87!PX70@<VEK97)E<V5N('3V<O9L=/QK+@!!
M("(E<R(@;6%P<.%T('-I:V5R97-E;B#A=&YE=F5Z=/QK("(E<R(M<F4N`$%Z
M(/QZ96YE="!F96ILZ6-S;W)A:2!A(&OV=F5T:V5Z]6LN`$5H:&5Z(&$@<NES
M>FAE>B!A(&OV=F5T:V5Z]2!FX6IL;VMA="!C<V%T;VQTX6LZ`$$@=&5L:F5S
M(&OI<&5R;GGU<R#\>F5M;?-D('!R;V)LZ6WA:V%T(&]K;WIH870@87H@26YT
M97)N970@17AP;&]R97(@:&%S>F[A;&%T82!E<V5TZ6XL(&UE<G0@96)B96X@
M;VQY86X@<')O9W)A;6AI8N%K('9A;FYA:RP@86UI:V5T(&YE;2!T=61T=6YK
M(&UE9VME<OQL;FDN($$@:^EP97)N>?5J92!O;'9A<VAA=&%T;&%N;N$@=N%L
M:&%T+"!B:7IO;GEO<R!E9&ET;W(@9G5N:V-I\VL@:&GA;GEO>FAA=&YA:R#I
M<R]V86=Y(';A<F%T;&%N=6P@;&5F86=Y:&%T(&$@8O9N9^ES>O5P<F]G<F%M
M+B!7:6YD;W=S(#EX(&AA<WINX6QA=&$@97-E=.EN(&YA9WEO;B!V86SS<WKM
M;OLL(&AO9WD@)T=E;F5R86P@<')O=&5C=&EO;B!F875L="<@:&EB82!M:6%T
M="#Z:G)A(&ME;&P@:6YD[71A;FEA(&UA:F0@82!GZ7#I="Y<;EQN1FEG>65L
M;65Z=&5T=/QK(2!+871T:6YT<V]N(&%Z($]+(&=O;6)R82P@:&$@;>EG:7,@
M;65G(&OM=N%N:F$@:^USZ7)E;&YI(&$@=&5L:F5S(&OI<&5R;GGU<R#\>F5M
M;?-D;W0N`$$@(B5S(B!A>F]N;W/M=/-T(&MI=/9R]FQT_&LN`$$@:^EP(&5L
M;65N=.ESZ6AE>B!S>OQK<^EG97,@86)L86L@;F5M(&YY:71H873S(&UE9RX@
M3&5H970L(&AO9WD@82!B]FYGZ7-Z]7!R;V=R86UJ82!B9>%L;.UTX7-A:6)A
M;B!L971I;'1O='1A(&$@9F5L8G5K:V%N\R`H<&]P=7`I(&%B;&%K;VMA=#\`
M02!KZ7!E:V5T(&UE9VIE;&5N[71J_&LL(&UE<G0@82!F96QA9/,@;65G=&%L
MX6QH873S(&%Z(-9N(&/M;6IE9WEZZ6OI8F5N+@!#<V%K(&)A;"!O;&1A;&]N
M(&QE9WEE;B!K97)E=`!!($=N=5!'('!R;V=R86T@:&5L>>ET(&UE9R!K96QL
M(&%D;FD@82!#<GEP=%]P9W`Z.B!O<WITX6QY(&AA<WINX6QA=.%H;WHN`$$@
M;&5V96QE>O5S>F5R=F5R(&$@:_9V971K97KU(&AI8F'\>F5N971E="!K_&QD
M=&4Z`$$@;&5V96QE>O5S>F5R=F5R(&$@:_9V971K97KU('3A:NEK;WIT873A
M<W0@:_QL9'1E.@!!(&QE=F5L97KU<WIE<G9E<B!A(&OV=F5T:V5Z]2#\>F5N
M971E="!K_&QD=&4Z`$$@(B5S(B!N97;[(&UA<'!A(&WA<B#\<F5S+@!!("(E
M<R(@;&5VZ6P@*&EN;F5N.B`E<RP@;>ER971E.B`E9"!BX6IT*2!N86=Y;V)B
M+"!M:6YT(&$@;65G96YG961E='0@;&5G;F%G>6]B8B#A='3V;'1H973U(&QE
M=NEL+@!!>B#I<'!E;B!F;V=A;&UA>F]T="!L97;I;"!B97KA<F]D;W1T+B!+
M:6SI<.ES(&OV=F5T:V5Z:6LN`$YE;2#M<G0@<V5M;6ET(&$@;&5VZ6P@5.%R
M9WD@;65Z96KI8F4N`$$@;&5V96QE="!K:73V<O9L=/QK+@!!(&QE=NEL('1A
M<G1A;&UA(&UE9V9E;&5L(&$@9&EG:73A;&ES(&%LX>URX7-N86LN`$$@;&5V
MZ6P@=&%R=&%L;6$@;65G9F5L96P@82!D:6=I=.%L:7,@86SA[7+A<VYA:RX@
M02!F96QA9/,Z("5S`$$@;&5VZ6PL(&UE;'EE="`E<R!N87!JX6X@:_QL9/9T
M="`E<R!C[6UZ971T;F5K("(E<R(@=.%R9WEB86XL(&$@8^UM>F5T="!S>N%M
M[73S9^EPZ6X@;65G:F5L96YT+B!!<G)A(&YI;F-S(&=A<F%N8VEA+"!H;V=Y
M(&5L(&ES(&]L=F%S=.%K(&EL;"X@:&]G>2!M96?I<G1E='3I:RX`36D@;&5G
M>65N(&$@;&5VZ6SM<O,@86)L86MH;WH@;75T873S(&QI;FL@96QN979E>NES
M90!!(&UE>O5K('-ZX6UA(&-S86L@;G5M97)I:W5S(.ER=.EK(&QE:&5T+@!!
M>B!O<&5N<W-L(&UO9'5L('-Z_&MSZ6=E<R!A($AO<F1E7T-R>7!T7W-M:6UE
M.CH@;W-Z=.%L>2!H87-Z;N%L873A:&]Z+@!!("(E<R(@<WIE;>EL>65S(&)E
MX6QL[73A<R!N96T@;65N=&AE=/4@96PL(&UE<G0@;>ER971E(&UE9VAA;&%D
M:F$@82!M96=E;F=E9&5T="!M87AI;75M;W0`3F5M('1A;.%L:&%T\R!A>B!A
M('!R;V=R86T@82!S>F5R=F5R96XL(&%M:2!S>OQK<^EG97,@96YN96L@87H@
M861A='3M<'5S;F%K("@E<RD@82!M96=J96QE;NUTZ7/I:&5Z+@!!>B!I9.EZ
M]6IE;"!K87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+@!!
M(%!'4"!N>6EL=N%N;W,@:W5L8W,@;65G:F5L96[M=.ES92!N>65R<R!S>O9V
M96=E<R!F;W)MX71U;6)A;CH@)7,`02!K[7;A;G0@X6QL;VWA;GD@;FEN8W,@
M8F5N;F4@87H@35,M5$Y%1B!M96QLZ6ML971B96XN`$$@:^UVX6YT(.%L;&]M
MX6YY(&YI;F-S(&)E;FYE(&$@6FEP(&UE;&SI:VQE=&)E;BX`2F]B8B#I<R!B
M86P@;VQD86QO;B!L96=Y96X@:V5R970`0W-A:R!J;V)B(&]L9&%L;VX@;&5G
M>65N(&ME<F5T`$$@9F5L863S('9I<W-Z86EG87IO;.%S="!KZ7(@87)R\VPL
M(&AO9WD@UFX@96QO;'9A<W1A(&5Z="!A(&QE=F5L970N($OI<F5M("5S(&MA
M='1I;G1S;VXL(&AA('1E;&IE<^UT96YI(&OM=N%N:F$@97IT(&$@:^ERZ7-T
M+@!!>B!E;';A;&%S>G3S(&MA<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT
M97(@;&5H970N`$$H>BD@(B5S(B!S>F5R=F5R="!T]G+V;'3\:RX`02AZ*2`B
M)7,B('-Z97)V97)T(&5L;65N=&5T=/QK+@!!('-Z97)V97(@;F5M('1U9&]T
M="!P:6-I(';A;'1O>F%T;W0@8W-I;N%L;FD@82!KZ7!B]6PN`$%Z(.%L;&%N
M9/,@;&5VZ6QVZ6=Z]63I<W0@*'-I9VYA='5R92D@;F5M('-I:V5R_&QT(&9E
M;/QL[7)N:2X`07H@X6QL86YD\R!L97;I;';I9WKU9.ES="`H<VEG;F%T=7)E
M*2!S:6ME<F5S96X@;65G=N%L=&]Z=&%T='5K+@`E<R!B96IE;&5N=&ME>NES
M:2!KZ7)E;&WI="!T]G+V;'3\:RX`02!M96=A9&]T="!FX6IL(&YE;2!LZ71E
M>FEK+@!!(&UE9V%D;W1T('-O<B`H)60I(&YE;2!LZ71E>FEK+@!,Z71R96AO
M>G1U:R!A*'HI("(E<R(@;&5VZ6QP87#M<G0N`$$H>BD@(B5S(B!L97;I;'!A
M<.UR="!T]G+V;'3\:RX`02AZ*2`B)7,B(&QE=NEL<&%P[7)T(&WS9&]S[71O
M='1U:RX`02!F96QA9&%T;W0@:&]Z>N'M<G1U:R!A(&QI<W3A:&]Z+@!!*'HI
M("(E<R(@:61E:6=L96YE<R!FX6IL(&YE;2!LZ71E>FEK+@!!(&QE=NEL('-Z
M]G9E9V4`02!L97;I;"!S>O9V96=E(&UE9W1E:VEN=&AE=/4@)7,N`$$@=N%L
M87-Z('-Z]G9E9V4`02!VX6QA<WH@<WKV=F5G92!M96=T96MI;G1H973U("5S
M+@!!>B!E;&O\;&3V='0@;&5VZ6P@<WKV=F5G90!!>B!E;&O\;&3V='0@;&5V
MZ6P@<WKV=F5G92!M96=T96MI;G1H973U("5S+@!!(&)E[7)T('-Z]G9E9R!N
M96T@96=Y97II:R!A(&OI<&5R;GGU;B!L97;U=F5L+@!!;'5L(.ES(&;V;/QL
M(&QE9WEE;B!K97)E=`!#<V%K(&9E;G0@;&5G>65N(&ME<F5T`$$@9F5L=/9L
M=/9T="!A9&%T;VL@87H@96SU>O4@;.EPZ7,@\W1A(&5L=F5S>G1E:RX`02!F
M96QT]FQT]G1T(&;A:FQT(&YE;2!S:6ME<OQL="!E;&UE;G1E;FDN`$$@9F5L
M:&%S>F[A;/,@96QF;V=L86QT<^%G:2!A9&%T86ET('-I:V5R97-E;B!E;&UE
M;G1E='3\:RX`02!W96%T:&5R+F-O;2!B;&]K:R!N96T@:&%S>F[A;&AA=/,N
M`$$@;65G:F5L96[I<VD@<W3M;'5S("AT:&5M97,I(&%L:_9N>79TX7(@(B5S
M(B!N96T@=&%LX6QH873S+@!!(&QE=NEL;F5K(&YI;F-S(&]L>6%N(&%L=&5R
M;F%T[78@<NES>F4L(&UE;'D@82!B]FYGZ7-Z]7!R;V=R86UJX6)A;B!M96=J
M96QE;NUT:&5T]2!L96YN92X`16)B96X@82!M87!PX6)A;B!N:6YC<R!L97;I
M;"X`3FEN8W-E;B!VX6QA<WIT:&%T\R!O<&-I\RX`3FEN8W,@82!L97;I;"!B
M96QS96KI8F5N(&UE9VIE;&5N[71H973U(&UE;&SI:VQE="X`5/IL('-O:R!K
M87)A:W1E<B!V86X@96)B96X@82!M97KU8F5N+B#6;B`E<R!K87)A:W1E<G0@
M861O='0@;65G.R!A(&UA>&EMX6QI<V%N(&UE9V%D:&%T\R!P961I9R!K979E
M<V5B8BP@;6EN="`E<RX`3FEN8W,@82!L97;I;"!B96QS96KI8F5N(&UE9VIE
M;&5N[71H973U('-Z]G9E9RX`(B5S(B!F96QH87-Z;N%L\VYA:R!A(')E;F1S
M>F5R:&5Z(&%DX7-A:V]R(&AI8F$@=/9R=.EN="X@)7,`(B5S(B!F96QH87-Z
M;N%L\R!A9&%T86EN86L@=/9R;.ES92!S;W+A;B!H:6)A(&SI<&5T="!F96PZ
M(`!(:6)A(&IE;&5N=&ME>F5T="!A('3V<O9L="!L979E;&5K;F5K(&$@;&5V
MZ6QLX63A8O-L('3V<G3I;O4@:VG\<NUTZ7-E:V]R+B!!('-Z97)V97(@_'IE
M;F5T93H@)7,`(B5S(B!R96YD<WIE<F+U;"!V86SS('3V<FSI<V5K;W(@:&EB
M82!LZ7!E='0@9F5L.B``(B5S(B!M\V1O<^UTX7-A('-O<N%N(&AI8F$@;.EP
M971T(&9E;#H@)7,`07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V
M97)R92!F96QT]FQT96YI+B`E<R!N96T@=/9L=/5D]G1T(&9E;"X`07H@X6QL
M;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI+B`E
M<R!N86=Y;V)B+"!M:6YT(&$@;6%X:6WA;&ES86X@;65G96YG961E='0@;>ER
M970@*"5D(&+A:G0I+@!!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@<WIE
M<G9E<G)E(&9E;'3V;'1E;FDN($$H>BD@)7,@9N%J;&YA:R!C<V%K(&5G>2!R
MZ7-Z92!T]FQT]63V='0@9O9L+@!!(&QE=F5L96L@(B5S(BUB]6P@(B5S(B!M
M87!PX6)A('3V<G3I;O4@;>%S;VSA<V%K;W(@:&EB82!T]G)TZ6YT+B!!('-Z
M97)V97(@_'IE;F5T90!!(&QE=F5L96L@(B5S(B!M87!PX6+S;"!V86SS('3V
M<FSI<V4@;F5M('-I:V5R_&QT+B!!('-Z97)V97(@_'IE;F5T90!!(&QE=F5L
M96L@(B5S(B!M87!PX6+S;"!V86SS('3V<FSI<V4@;F5M('-I:V5R_&QT+B!!
M('-Z97)V97(@_'IE;F5T90!!(&QE=F5L96L@=/9R;.ES96MO<B!H:6)A('3V
M<G3I;G0N($$@<WIE<G9E<B#\>F5N971E.B`E<P!(:6)A('3V<G3I;G0@87H@
M97-E;>EN>2!T]G)LZ7-E:V]R.B`E<RX`02!L97;I;"!E('+I<WKI;F5K(&UE
M9VIE;&5N[73I<V5K;W(@:&EB82!T]G)TZ6YT`$$@;&5V96QE:R`B)7,B(&UA
M<'#A8F%N('9A;/,@;65G:F5L]FSI<V4@<V]RX6X@:&EB82!T]G)TZ6YT+B!!
M('-Z97)V97(@_'IE;F5T90`E<R!I;7!O<G3A;.%S82!S;W+A;B!H:6)A('3V
M<G3I;G0N`$$@<&%R=&YE<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@:&EB
M82!T]G)TZ6YT+@!!>B!E<V5MZ6YY(&EM<&]R=.%LX7-A('-O<N%N(&AI8F$@
M=/9R=.EN=#H@)7,`07H@:4-A;&5N9&%R(&%D871O:R!I;7!O<G3A;.%S82!S
M;W+A;B!H:6)A('3V<G3I;G0N`$$@9F5L861A="!I;7!O<G3A;.%S82!S;W+A
M;B!H:6)A('3V<G3I;G0Z("5S`$$@9F5L:&%S>F[A;/,@96QF;V=L86QT<^%G
M:2!A9'1A:6YA:R!I;7!O<G3A;.%S82!S;W+A;B!H:6)A('3V<G3I;G0Z("5S
M`$AI8N%S(&$@;65G861O='0@:V]N9FEG=7+A8VGS+B!,96AE="P@:&]G>2!N
M96T@=/9L=/9T="!K:2!E9WD@<WK\:W/I9V5S(&UE>O5T+@!!(&QE=F5L96L@
M(B5S(BUB]6P@(B5S(B!M87!PX6)A('9A;/,@X71H96QY97KI<V4@<V]RX6X@
M:&EB82!T]G)TZ6YT+B!!('-Z97)V97(@_'IE;F5T90!!('!A<G1N97)J96=Y
M>NEK:V5L(&MA<&-S;VQA=&]S(&9E;&%D870@=NEG<F5H86ITX7-A('-O<N%N
M(&AI8F$@;.EP971T(&9E;"X@2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BX`
M02!L97;I;"!M=6YK87#I;&3A;GEKZ6YT('9A;/,@96QM96YTZ7-E:V]R(&AI
M8F$@=/9R=.EN="X`02!L97;I;"!K_&QDZ7-E:V]R(&AI8F$@=/9R=.EN=#H@
M)7,`2&EB82!T]G)TZ6YT(&$@<&%R=&YE<B!A9&%T86EN86L@9G)I<W/M=.ES
M92!S;W+A;BX@2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BX`02!K]G)L97;I
M;&QI<W1A(&%D871A:6YA:R!F<FES<^UTZ7-E('-O<N%N(&AI8F$@=/9R=.EN
M="X@2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BX`07H@97-E;>EN>2!A9&%T
M86EN86L@9F5L_&SM<N%S86MO<B!H:6)A('3V<G3I;G0Z("5S`$$@;&5VZ6P@
M92!RZ7-ZZ6)E;B!N96T@=F]L="!S>O9V96<`17H@82!(5$U,(&QE=NEL(&OI
M<&5K970@=&%R=&%L;6%Z+@!%>B!A($A434P@;&5VZ6P@:^EP96ME="!T87)T
M86QM87HN($$@;F5M(&UE9VIE;&5N[71E='0@:^EP96L@:&5L>>EN(&5Z(&SA
M='-Z:6LZ(`!%>B!A>B!)34%0('-Z97)V97(@;F5M('3A;6]G871J82!A(&UA
M<'#A:VAO>B!V86SS(&AO>GKA9NERZ7,@;65G;W-Z=.%SX70N`$$@;&5VZ6QH
M97H@97IT(&$@4$=0(&YY:6QVX6YO<R!K=6QC<V]T(&-S871O;'3A:RX`17IT
M(&$@=N%L87-Z=.%S:2!L96AE=/5SZ6=E="!A(')E;F1S>F5R(&YE;2!TX6UO
M9V%T:F$N`$5Z="!A(';A;&%S>G3A<VD@;&5H973U<^EG970@82!R96YD<WIE
M<B!E9WEE;/5R92!N96T@=.%M;V=A=&IA+@!%>B!N96T@=/MN:6L@<WIA8N%L
M>6]S(')A<B#A;&QO;>%N>6YA:RX`17H@;F5M('3[;FEK('-Z86+A;'EO<R!Z
M:7`@X6QL;VWA;GEN86LN`$5Z(&YE;2!T^VYI:R#I<G;I;GEE<R!KX7)T>6%S
M>N%M;F%K+@!%>B!A(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y($A4
M5%`M:V%P8W-O;&%T;VX@4TU3+70@:_QL9&K\;FL@82!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI('-Z;VQGX6QT873S;B#A="X`17H@82!M
M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N
M(%--4RUT(&O\;&1J_&YK(&$@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@<WIO
M;&?A;'1A=/-N(.%T+@!%>B!A(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H
M;V=Y($A45%`M:V%P8W-O;&%T;VX@4TU3+70@:_QL9&K\;FL@87H@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@<WIO;&?A;'1A=/-N(.%T+@!%
M>B!A(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y(%--5%`M:V%P8W-O
M;&%T;VX@4TU3+70@:_QL9&K\;FL@5F]D869O;F4@<WKA;6]K<F$@82!6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I('-Z;VQGX6QT873S;B#A
M="X@02!S>F]L9^%L=&%TX7,@:6?I;GEB97;I=&5LZ6AE>B!6;V1A9F]N92!)
M=&%L>2!E;6%I;"!C[6T@<WK\:W/I9V5S+@!%>B!A(&UE>O4@;F5M(&UA<F%D
M:&%T(/QR97,N`$5B8F5N(&$@;65Z]6)E;B!C<V%K(&5GZ7-Z('-ZX6UO:R#A
M;&QH871N86LN`$5B8F5N(&$@;65Z]6)E;B!C<V%K(&5GZ7-Z('-ZX6UO:R#I
M<R!K971T]7-P;VYT(&QE:&5T+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!O:W3A
M;&ES('-ZX6UO:R#A;&QH871N86LN`$5Z(&$@;65Z]2!C<V%K('9E<W-Z]79E
M;"!V86=Y('-Z\VOV>GIE;"!E;';A;&%S>G1O='0@96?I<WH@<WKA;6]K870@
M=&%R=&%L;6%Z:&%T`$5Z(&%Z(.ER=.EK(&-S86L@<WKA;2!L96AE="X`16)B
M96X@82!M97KU8F5N(&AE>&%D96-I;>%L:7,@4D="('-Z[6YK\V0@X6QL:&%T
M+"!P;"X@)R,Q,C,T868G+@!%>F5N(&%D871O:VMA;"!K87!C<V]L871O<R!F
M96QA9&%T;VMA="!A('-Z97)V97(@;>%R(&5L=NEG97IT92X`17H@)7,`17H@
M96=Y($MO;&%B($=R;W5P=V%R92!O8FIE:W1U;2X@07H@:6QY96X@;V)J96MT
M=6T@;65G:F5L96[M=.ESZ6AE>B!O;'EA;B!E;6%I;"!K;&EE;G-P<F]G<F%M
M('-Z_&MSZ6=E<RP@86UE;'D@:^EP97,@82!+;VQA8B!'<F]U<'=A<F4@9F]R
M;>%T=6T@:V5Z96SI<^ER92X@26QY96X@96UA:6P@:VQI96YS96L@;&ES=.%J
M82!LX71H873S(&ET=#H@)7,`17H@:&]S<WIA8F(@:63U="!V96AE="!I9^EN
M>6)E+B!":7IT;W-A;B!F;VQY=&%T;FD@:^UVX6YJ83\`17H@82!L97;I;"!E
M9WD@36%C:6YT;W-H(.%L;&]MX6YY="!T87)T86QM87HN`$5Z(&$@;&5VZ6P@
M4R]-24U%('-Z86)VX6YY('-Z97)I;G0@9&EG:73A;&ES86X@86SA[7)T(&UE
M;&SI:VQE=&5T('1A<G1A;&UA>BX`17H@82!L97;I;"!3+TU)344@<WIA8G;A
M;GD@<WIE<FEN="!T:71K;W/M=&]T="!M96QLZ6ML971E="!T87)T86QM87HN
M`$5Z(&$@;&5VZ6P@:^EZ8F5S[73I<VD@=FES<WIA:6=A>F]LX7-T('1A<G1A
M;&UA>BP@9&4@:7-M97)E=&QE;B!F;W)MX71U;6)A;BX`VF=Y('3[;FEK(&5Z
M(&$@;&5VZ6P@;F5M(%!'4"!S>F%B=N%N>2!S>F5R:6YT('9A;B!T:71K;W/M
M='9A+B!!(&AI8F$Z(`!%>B!A(&QE=NEL(&YE;2!F96QE;"!M96<@82!P;VYT
M;W,@4$=0('-Z86)VX6YY;F%K("AA>B!21D,@,C`Q-2!S>F5R:6YT*2X`17H@
M82!L97;I;"!N96T@9F5L96P@;65G(&$@<&]N=&]S(%,O34E-12!S>F%B=N%N
M>6YA:RX`17H@82!L97;I;"!01U`@<WIA8G;A;GGZ(&1I9VETX6QI<R!A;.'M
M<N%S="!T87)T86QM87HN`$5Z(&$@;&5VZ6P@4R]-24U%('-Z86)VX6YY^B!D
M:6=I=.%L:7,@86SA[7+A<W0@=&%R=&%L;6%Z+@!%>G0@82!L979E;&5T(%,O
M34E-12!S>F%B=N%N>2!S>F5R:6YT('1I=&MO<^UT;W1TX6LN`$5Z="!A(&QE
M=F5L970@4$=0('-Z86)VX6YY('-Z97)I;G0@=&ET:V]S[71O='3A:RX`17IT
M(&$@;&5V96QE="!I9&4N+BX`17IT(&$@;&5V96QE="!MX7,@:V%R86MT97)K
MZ7-Z;&5T=&5L("@E<RD@[7)TX6LL(&UI;G0@86UI="#6;B!H87-Z;N%L+@!%
M>B!A('-ZX6T@;F5M(&QE:&5T(&5G>6[I;"!K:7-E8F(N`$5Z(&$@<WIE<G9E
M<B!N96T@:^EP97,@:VEB;VYT86YI(&$@>FEP(&EL;"X@9WII<"#A;&QO;>%N
M>6]K870N`$5Z(&$@<WIE<G9E<B!N96T@=&5S>FD@;&5H973U=NDL(&AO9WD@
M;>%S(&9E;&AA<WINX6SS:VYA:R!H;WIZX6;I<NES:2!J;V=O="!A9&IU;FL@
M;6%P<.%I;FMH;WHN`$5Z(&$@<F5N9'-Z97(@:F5L96YL96<@:6YA:W1I=N%L
M=F$@=F%N+@!%>B!A>B#I<G3I:R!C<V%K('-ZX6T@;&5H970N`$5Z="!A>B!A
M8FQA:R!C<V%K(&%Z(/IJ(&QE=NEL(&9O9V%L;6%ZX7-A:V]R(&CM=FAA=/,N
M`$5Z="!A>B!A8FQA:R!C<V%K(&%Z($]P8VGS:R!A8FQA:V+S;"!H[79H873S
M`$QO9VEK86D@*'1H<F5A9"D@;NEZ970`3&]G:6MA:2`H=&AR96%D*2!NZ7IE
M=`!6:6QLX6ULX7,`2&EB86)E:F5L96YTZ7,M:V5Z96SI<P!)9/4`375N:V%I
M9/4M;GEI;';A;G1A<G3A<P!)9/4@9F]R;>%T=6T`263U(';A;&%S>G3A<P!+
M96QE="U4:6UO<@!4:71U;'5S`$/M;2`H=&]O;'1I<"D`0^UM>F5T=`!!(&/M
M;7IE='0`2&$@=/9B8B!M97KU="!K[7;A;B!K:6IE;/9L;FDL(&%K:V]R('1A
M<G1S82!N>6]M=F$@82!#;VYT<F]L("A00RUN*2!I;&PN($-O;6UA;F0@*$UA
M8RUE;BD@8FEL;&5N='G[="P@Z7,@^F=Y(&MA='1I;G1S;VX@87H@96?I<G)E
M;"!A('1O=N%B8FD@;65Z]6MR92X`2&$@=/9B8B!E;&5M970@:7,@:VD@86MA
M<B!J96SV;&YI+"!T87)T<V$@;&5N>6]M=F$@82!#;VYT<F]L("A00RD@=F%G
M>2!A($-O;6UA;F0@*$UA8RD@8FEL;&5N='G[="!A(&MA='1I;G3A<R!K]GIB
M96XN`%1,4R!K87!C<V]L870@:&%S>F[A;&%TX6AO>B!A(%!(4"`U+C$N,"US
M+"!V86=Y(/IJ86)B('9E<GII\VKA<F$@=F%N('-Z_&MSZ6<N`$UA`$A434P@
M9F]R<N%S;NEZ970@:VDO8F4`5&]G;P!4;VME;&%U`$AO;&YA<`!4;VYG80!F
M]FS\;`!,96=F96QS]2!F<F%M92`H7W1O<"D`365L;.EK;&5T96L@]G-S>FWI
M<F5T93H`1F]R9.UTX7-O:P!!("=3>F5M971E<R<@*%1R87-H*2!M87!P80!!
M("=3>F5M971E<R<@*%1R87-H*2!M87!P83H`5')I;FED860@Z7,@5&]B86=O
M`$EG87H@=F%G>2!H86UI<P!+90!4=6[I>FEA`%3V<O9K;W)S>N%G`'3V<O9K
M("A)4T\M.#@U.2TY*0!4_')K;65N:7-Z=.%N`%1U<FMS+2#I<R!#86EC;W,M
M<WII9V5T96L`5'5V86QU`,UR:F$@8F4L(&UI="!VX6QA<WIT;W1T.B``558@
M:6YD97@Z(`!54DP`55),+"!M96QY96X@96=Y('!R;V=R86T@96QF;V=A9&IA
M(&$@<WIO;&?A;'1A=/,@X6QT86P@:_QL9/9T="!K_&QD]G1T(&OI>F)E<^UT
MZ7-I(&IE;&5N=.ES=`!54DPZ`%5G86YD80!5:W)A:FYA`$YE;2!S:6ME<OQL
M="!A(%9&4R!A;&OV;GETX7)B82!B96SI<&YI+@!!(&)E:F5L96YT:V5ZZ7-I
M(&IO9V]S=6QT<^%G(&EGZ6YY;.ES96MO<B!N96T@<VEK97+\;'0@87H@861A
M=&]K(&5L=.%R;VSA<V$N`$YE;2!S:6ME<OQL="!A*'HI("(E<R(@5D93(&;A
M:FP@96SI<NES:2!J;V=O<W5L='/A9V%I="!M96=VX6QT;WIT871N:2X`3F5M
M('-I:V5R_&QT(&$H>BD@)7,O)7,@5D93(&;A:FP@96SI<NES:2!J;V=O<W5L
M='/A9V%I="!M96=VX6QT;WIT871N:2X`3F5M('-I:V5R_&QT(&$H>BD@)7,@
M86QK]FYY=G3A<F)A(&)E;.EP;FDN`$$H>BD@(B5S(B#A;&QO;>%N>2!MZ7)E
M=&4@;F5M(.%L;&%P[71H873S(&UE9RX`02AZ*2`B)7,O)7,B(.%L;&]MX6YY
M(&WI<F5T92!N96T@X6QL87#M=&AA=/,@;65G+@!!>B!344P@<WIE<G9E<B!N
M96T@Z7)H973U(&5L+@!!>B!34TP@:V%P8W-O;&%T(&YE;2#I<.UT:&5T]2!F
M96PN`$$@5D93(&;A:FP@;F5M(&WA<V]L:&%T\R#A="X`3F5M('-I:V5R_&QT
M(&$H>BD@(B5S(B!61E,@86QK]FYY=G3A<G0@;.ET<F5H;WIN:2X`3F5M('-I
M:V5R_&QT(&SI=')E:&]Z;FD@82!61E,@86QK]FYY=G3A<G0N`$YE;2!S:6ME
M<OQL="!LZ71R96AO>FYI(&$@5D93(&;A:FQT+@!!*'HI("(E<R(@5D93(&UA
M<'!A(&YE;2!H;WIH873S(&SI=')E+@!.96T@<VEK97+\;'0@;.ET<F5H;WIN
M:2#\<F5S(%9&4R!FX6IL="X`02!T]FWV<NUT971T(.%L;&]MX6YY="!N96T@
M<VEK97+\;'0@:VEB;VYT86YI+@`B)7,B(&YE;2!T]G+V;&AE=/4L(&%Z(&%L
M:_9N>79TX7(@;F5M(/QR97,N`"(E<R(@=/9R;.ES92!N96T@<VEK97+\;'0Z
M("5S+@`E<R!N96T@=/9R]FQH973U+"!A>B!A;&OV;GEV=.%R(&YE;2#\<F5S
M+@!!(%9&4R!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4@<F5K=7)Z[79A;BX`
M02!61E,@86QK]FYY=G3A<B!N96T@=/9R]FQH973U+@!!(%9&4R!A;&OV;GEV
M=.%R(&YE;2!T]G+V;&AE=/4Z("5S+@!!*'HI("(E<R(@5D93(&;A:FP@;F5M
M('3V<O9L:&5T]2X`02!61E,@9N%J;"!N96T@=/9R]FQH973U+@!!*'HI("(E
M<R(@5D93(&UA<'!A(&YE;2!T]G+V;&AE=/4N`$YE;2!VZ6=E>FAE=/,@<F5K
M=7)Z[78@=/9R;.ES(&$@5D93+6)E;CH@)7,N`$YE;2!H873A<F]Z:&%T\R!M
M96<@82!J96QE;FQE9R#I<G;I;GEE<R!A;&OV;GETX7(N`$$@=&%N^G/M=';A
M;GD@<NES>FQE=&5S(&%D871A:2!N96T@:&%TX7)O>FAA=/-K(&UE9P!.96T@
M<VEK97+\;'0@8F5O;'9A<VYI("5S(&1E9FEN[6-I\VKA="X`02!61E,@9N%J
M;"!N96T@:&5L>65Z:&5T\R#A="X`02AZ*2`B)7,B(%9&4R!FX6IL(&YE;2!N
M>6ET:&%T\R!M96<N`$$@5D93(&;A:FP@;F5M(&YY:71H873S(&UE9R#M<N%S
M:2!CZ6QL86PN`$$@5D93(&;A:FP@;F5M(&YY:71H873S(&UE9R`N`$$@=/9M
M]G+M=&5T="#A;&QO;>%N>2!N96T@;GEI=&AA=/,@;65G+@!!(%9&4R!FX6IL
M(&YE;2!O;'9A<VAA=/,@*&$@9FEL97-I>F4H*2!S:6ME<G1E;&5N('9O;'0I
M+@!!(%9&4R!FX6IL(&YE;2!O;'9A<VAA=/,@*&$@9V5T1FEL95-I>F4H*2!S
M:6ME<G1E;&5N('9O;'0I+@!%>B!A(&;A:FP@;F5M(&]L=F%S:&%T\SH@`$$@
M=F9S<F]O="!A;&OV;GEV=.%R(&YE;2!O;'9A<VAA=/,N`"5S(&YE;2!N979E
M>FAE=/4@X70@)7,@;NEV<F4Z(&WA<B!LZ71E>FEK(&EL>65N(&YE=OL@;6%P
M<&$`02!61E,@86QK]FYY=G3A<B!N96T@;F5V97IH973U(.%T+@!!(%9&4R!A
M;&OV;GEV=.%R(&YE;2!N979E>FAE=/4@X70Z("5S+@!!*'HI("(E<R(@5D93
M(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`02AZ*2`E<R\E<R!61E,@9N%J;"!N
M96T@;F5V97IH973U(.%T+@!!(%9&4R!FX6IL(&YE;2!N979E>FAE=/4@X70N
M`$$@:W;S=&$@:6YF;W)MX6-I\R!N96T@Z7)H973U(&5L`$%Z("=M:VES;V9S
M)R!P<F]G<F%M(&YE;2!F=71T871H873S+@!.96T@<VEK97+\;'0@;&5F;W)D
M[71A;FD@97IT(&$@5V]R9"!D;VMU;65N='5M;W0`02AZ*2`B)7,B(%9&4R!F
MX6IL(&YE;2#M<FAA=/,N`$$@5D93(&;A:FP@;F5M(.UR:&%T\R`H82!C;W!Y
M*"D@<VEK97)T96QE;B!V;VQT*2X`02!61E,@9N%J;"!A9&%T86D@;F5M(.UR
M:&%T\VL@:VDN`$$@5D93(&;A:FP@[7+A<V$@:W;S=&%T^FQLZ7#I<R!M:6%T
M="!N96T@9F5J97IH973U(&)E+@!M96=VX6QA<WIO;&%T;&%N`$UE9W;A;&%S
M>F]L871L86X@;&5V96QE:P!4]G)LZ7,@=FES<WIA`&%LX6CZ>F]T=`!!(&/M
M;7IE='1E:R!L:7-TX6IA(&YE;2!I<VUE<G0`3>EG<V4@;65N='/\:R!E;`!6
M:7-S>F%V;VYJ82!A>B!U=&]L<_,@=N%L=&]Z=&%TX7-T`$$@:V%P8W-O;&%T
M(&9E;';I=&5LZ70@:_9V973U96X@=N%R871L86X@=N%L87-Z(.ER:V5Z971T
M(&$@<WIE<G9E<G3U;#H@`%;A<F%T;&%N(';A;&%S>B#I<FME>F5T="!A('-Z
M97)V97)T]6P@87H@05542$5.5$E#051%('!A<F%N8W-R82X`5N%R871L86X@
M=N%L87-Z(.ER:V5Z971T(&$@<WIE<G9E<G3U;"!A($1I9V5S="U-1#4@861A
M=')A+@!6X7)A=&QA;B!VX6QA<WH@Z7)K97IE='0@82!S>F5R=F5R=/5L(&$@
M3$]'24X@<&%R86YC<W)A+@!6X7)A=&QA;B!VX6QA<WH@Z7)K97IE='0@82!S
M>F5R=F5R=/5L(&5R<F4Z(`!"97-O<F]L871L86X`27-M97)E=&QE;B!T[7!U
M<SH@)7,`56YI8V]D92`H551&+3@I`$5G>65S_&QT($%R86(@16WM<G/I9V5K
M`$5G>65S_&QT($MI<N%L>7/A9P!%9WEE<_QL="#!;&QA;6]K`$5G>65S_&QT
M(,%L;&%M;VLL(&MI<V5B8B!K_&QS]2!S>FEG971E:P!E9WESZ6<`27-M97)E
M=&QE;@!)<VUE<F5T;&5N(&3A='5M`$%Z($E-05`@<WIE<G9E<G3U;"!I<VUE
M<F5T;&5N(';A;&%S>B#I<FME>F5T="X@02!S>F5R=F5R(';A;&%S>F$Z("5S
M`$ES;65R971L96X@;65G8F5S>NELZ7,`27-M97)E=&QE;B!C[6UZ971T`$ES
M;65R971L96X@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`27-M97)E=&QE
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!!(&UE9V%D;W1T(&AE
M;'D@:7-M97)E=&QE;BX`27-M97)E=&QE;B!F96QH87-Z;N%L\VD@;NEV('9A
M9WD@:F5L<WKS+@!4X79O;.UT<W5K(&5L(&EN;F5N(&$@;&EN:V5T`$$@;65G
M861O='0@:F5L;6]N9&%T('9I<W-Z87;I=&5L90!.:6YC<R!E;&YE=F5Z=F4`
M0FEZ=&]N<^%G:2!O:V]K8O-L(&$@9F5L:&%S>F[A;/-I('!R;V=R86UO:R!N
M96T@:&%S>F[A;&AA=&KA:R!A($MI=N%GX7,O3>%S;VSA<R]"96EL;&5S>G3I
M<R!M\V1S>F5R="X@2V%T=&EN='-O;B!A>B!/2R!G;VUB<F$L(&AA(&$@;6]Z
M:6QL82YO<F<@=V5B;VQD86QO;B!E;"!K[7;A;FIA(&]L=F%S;FD@82!T96-H
M;FEK86D@;&7M<N%S="!M96QY(&UE9V%D:F$L(&AO9WEA;B!L96AE="!E>G0@
M;>EG:7,@96YG963I;'EE>FYI+@!N96T@;VQV87-O='0`02!S>NUN('9I<W-Z
M8>%L;.UTX7-A`$$@:_9V971K97KU(&UA<'#A*&MA*70@:&5L>65Z>OQK(&AA
M<WINX6QA=&]N(&OM=OQL("AU;G-U8G-C<FEB92D`3F5M('3A;6]G871O='0@
M97AT96YZ:?,`3?-D;W/M=.%S`"5S(&%D871A:6YA:R!M\V1O<^UTX7-A`$WS
M9&]S[71S=6L@82!VX6QA<WIA9/,@<W3A='5S>N%T`$$@9F5L:&%S>F[A;/,@
M861A=&%I;F%K(&WS9&]S[73A<V$`(B5S(B!VX6QT;WKA<V%I="!E;&UE;G1E
M='3\:RX`07H@=7!G<F%D92!P<F]G<F%M;W0@=/9R]FQT_&LN`$9E;'3V;'3I
M<P!!>B#V<W-Z97,@86QK86QM87KA<R!K;VYF:6=U<N%C:?-JX70@9F5L=/9L
M=/9T=/QK(&$@<WIE<G9E<G)E+@!L871I;B!N86=Y8F5T^VL`;F%G>6)E=/MS
M('+S;6%I('-ZX6UO:P!5<G5G=6%Y`$AA<WINX6QJ=6L@82!J96QE;FQE9VET
M.B`E<P!!>B!A;&%PZ7)T96QM97IE='0@Z7)TZ6L`06QK86QM87IZ=6L@87H@
M24U!4"!H87-Z;N%L871B82!VZ71E;&D@*'-U8G-C<FEP=&EO;BD@;65C:&%N
M:7IM=7/A=#\`2&%S>F[A;&IU;FL@4U-,+70`2&%S>F[A;&IU;FL@=FER='7A
M;&ES('-Z96UE=&5S;6%P<.%T/P!!:VMO<B!H87-Z;N%L:G5K+"!H82!A>B!)
M35-0('-Z97)V97)E;B!MX7,@82!B96IE;&5N=&ME>NES:2!N97;\;FLO:F5L
M<WIA=G5N:RX`1F5L:&%S>F[A;/-I(&[I=@`B)7,B(&9E;&AA<WINX6SS;F%K
M('-I:V5R97-E;B!M96=A9'1U:R!A(&MI=N%L87-Z=&]T="`M("(E<R(@;6%P
M<.%H;WH@=/9R=.EN]2`M(&AO>GKA9NERZ7-I(&IO9V]K870N`"5S(&9E;&AA
M<WINX6SS(&YE;2!J;V=O<W5L="`E<RUR92X`1F5L:&%S>F[A;/-K(&%D;6EN
M:7-Z='+A;.%S80!&96QH87-Z;N%L\VD@8F7A;&SM=.%S;VL`0F5J96QE;G1K
M97KI<R!J;V=O<W5L='/A9R!I9^EN>6SI<V4`17IE;B!A(')E;F1S>F5R96X@
M;FEN8W,@96YG963I;'EE>G9E(&%Z(/IJ(&9E;&AA<WINX6SS:R!B96IE;&5N
M=&ME>NES:2!J;V=O<W5L='/A9^%N86L@:6?I;GELZ7-E+@!!>B!F96QH87-Z
M;N%L\VD@87IO;F]S[73S(&YE;2!T86SA;&AA=/,`1F5L:&%S>F[A;/-I(&[I
M=@!!*'HI("(E<R(@9F5L:&%S>F[A;/-I(&[I=B!MX7(@;.ET97II:RX`1F5L
M:&%S>F[A;/-I(&[I=CH`1F5L:&%S>F[A;/-I(&[I=CH@`$$@<F5N9'-Z97(@
M9F5L:&%S>F[A;/-I.@#<>F)E9VES>G3A;@!!(%9&4R!A;&OV;GEV=.%R(&YE
M;2!LZ71E>FEK+@!3>F%B861SX6<@86QA='1I(&%U=&]M871I:W5S(&5M86EL
M+7;A;&%S>@!!(&OV=F5T:V5Z]2!H96QY96ME="!T86SA;'1U:SH@`,ER=NEN
M>65S<^EG`$%Z(.ER=.EK96ME="!P97)C8F5N(&%D:G5K(&UE9RP@;6]S=&%N
M=/-L('-ZX6WM='9A+@!!(.ER=.EK(&YA9WEO8F(L(&UI;G0@82!L96=N86=Y
M;V)B(&UE9V5N9V5D971T(&AO<W-Z^G/A9SH@)7,N`,ER=.EK96L`5N%L87-Z
M=&AA=/,@Z7)TZ6ME:P!686YU871U`';A;'1O>O,`5F5N97IU96QA`$$@:&ET
M96QE<^UTZ7,@;F5M('-I:V5R_&QT("T@;&5H970L(&AO9WD@82!L979E;&5T
M('9A;&%K:2!M96=VX6QT;WIT871T82X`5F5R>FGS`%9E<GII\VOV=F5TZ7,`
M1OQG9RX@96QH96QY97KI<P!&_&=G]6QE9V5S(&)E;'/U(&UA<F?S`&;\9V?U
M;&5G97,Z`&YA9WEO;B!M86=A<P!6:65T;F%M`'9I971N86UI("A625-#24DI
M`$UE9W1E:VEN=.ES`"5S(&UE9W1E:VEN=.ES90`E<R!N>6EL=N%N;W,@:W5L
M8W,@;65G=&5K:6YTZ7-E`$$@2%1-3"!T87)T86QM870@:_QL]FX@86)L86MB
M86X@<WIE<F5T;NEM(&SA=&YI`$QE=F5L96L@;65G=&5K:6YTZ7-E`$$@<WIE
M;>EL>65S('1I=&MO<R!K=6QC<R!M96=T96MI;G3I<V4`02!S>F5MZ6QY97,@
M;GEI;';A;F]S(&MU;&-S(&UE9W1E:VEN=.ES90!6:7-Z;VYT=N%L87-Z;VMK
M86P@96=Y_'1T`$UI;FEKZ7!E:R!M96=J96QE;NUTZ7-E`$O\;'/U('=E8F]L
M9&%L(&UE9VIE;&5N[73I<V4`2F5L96[M='/\:R!M96<L(&UI;G0@)7,`02!M
M96QLZ6ML971E="!K_&SV;B!A8FQA:V)A;B!S>F5R971NZ6T@;.%T;FD`02!T
M87)T86QM870@:_QL]FX@86)L86MB86X@<WIE<F5T;NEM(&SA=&YI`$%Z(&5L
M9F]G;&%L='/A9R!M96=T96MI;G3I<V4`02AZ*2`E<R!M87!P82!M96=T96MI
M;G3I<V4`0F5J96QE;G1K97KI<R!U=.%N(&UI;'EE;B!KZ7!E<FYY]79E;"!K
M[7;A;B!K97ID96YI.@!!(&9E;&%D870@;65G=&5K:6YTZ7-E`$$@:^EP96L@
M;65G:F5L96[M=.ES90!"<FET(%9I<F=I;BUS>FEG971E:P!!;65R:6MA:2!6
M:7)G:6XM<WII9V5T96L`02AZ*2`B)7,B('9I<G1UX6QI<R!M87!PX70@<VEK
M97)E<V5N(&SI=')E:&]Z='5K+@!6:7)T=>%L:7,@;6%P<.%K`$$@=FER='7A
M;&ES(&UA<'#A="!E;"!K96QL(&YE=F5Z;FD@=F%L86UI;F5K+@!6:7)T=>%L
M:7,@24Y"3U@`5FER='7A;&ES($E.0D]8(&UA<'!A`%9I<G1UX6QI<R!S>F5M
M971E<VUA<'!A`%9I<G1UX6QI<R!S>F5M971E<VUA<'!A`$$@=FER='7A;&ES
M(&UA<'!A(&5L;F5V97KI<V4`3.%T\W3A=F]L<^%G`$SA=/-TX79O;'/A9SH@
M`%9O9&%F;VYE($ET86QY('-Z;VQGX6QT873A<R!33510+6X@:V5R97-Z=/QL
M`$9)1UE%3$U%6E1%5,E3`$9)1UE%3$U%6E1%5,E3(2!+R5I:14P@5,%63TS-
M5%-!($5,($$@4T-225!4150@)7,M4M5,+@!724X@<WIO;&?A;'1A=.%S($A4
M5%`M;B#A=`!786QL:7,@Z7,@1G5T=6YA`$9I9WEE;&UE>G1E=.ES`%-Z90!)
M9/5JX7+A<R!E;/5R96IE;'KI<P!!>B!I9/5JX7+A<VD@861A=&]K(&9O<G+A
M<V$`5V5B`%=E8FAE;'EE:P!H971E;G1E`-QD=O9Z]FQJ_&L`W&1V]GKV;&K\
M:R$@17H@82`E<R!L979E;&5Z]7)E;F1S>F5R90#<9';V>O9L:OQK+"`E<P!N
M>75G870M975R\W!A:2`H25-/+3@X-3DM,2D`;GEU9V%T+65U<O-P86D@*$E3
M3RTX.#4Y+3$U*0!.>75G870M4WIA:&%R80!-:6QY96X@86QK86QM87KA<W0@
M;75T87-S;VX@)7,@82!B96IE;&5N=&ME>NES('5TX6X_`$UI(&%Z(&5L=N%L
M87-Z=/,@:V%R86MT97(_`$UI(&%Z(&EDZ7IE=&MA<F%K=&5R/P!-:2!T]G)T
MZ6YJ96X@82!L97;I;&QE;"P@;6EU=.%N('-P86UKZ6YT('9A9WD@;F5M+7-P
M86UKZ6YT(&)E:F5L96YT971T_&L_`%3V<FSI<VMO<B!A('3V<FSI<W)E('9A
M;/,@:VEJ96SV;.ES(&AE;'EE='0@<F%K:G5K(.%T(&$@;&5V96QE:V5T(&$@
M)U-Z96UE=&5S)R`H5')A<V@I(&UA<'#A8F$_`-IJ(&UA<'!A(&UE9VYY:73A
M<V%K;W(@;65L>6EK(&]L9&%L="!K[7;A;FIA(&UE9VIE;&5N[71E;FD_`$%Z
M(&5L:_QL9/9T="!L979E;&5K(&O\;/9N(&UA<'#A8F$@=/9R=.EN]2!M96YT
MZ7-E:V]R(&UE;G1S_&LM92!E;"!A(&UE;&SI:VQE=&5K970@:7,_`$QE=NEL
M:_QL9.ES:V]R(&EL;"X@8^UM96L@:VEE9^ES>NUTZ7-E:V]R(&UI;'EE;B!D
M;VUA:6YT("@B0"(@=73A;FD@<NES>BD@=&5G>?QN:R!A(")`(B!NZ6QK_&QI
M(&/M;65K(';I9^ER93\`5VAE<F5I<R!!=7-Z='+A;&EA('3I<FOI<`!-96QY
M:6L@8VEK;'5S`$UE;'EI:R!M;V1U;&]K870@86MT:7;A;&IU:R!A(%)I8V@@
M5&5X="!E9&ET;W)B86X_`$5N9V5DZ6QY97KI<VD@;&ES=&$`4WKI;&5S<^EG
M`%-ZZ6QE<W/I9R!#4U,@96=Y<^EG8F5N`$$@)7,@;65N_"!S>NEL97-SZ6=E
M(&$@8F%L(&]L9&%L;VX@*&$@:_9V971K97KU(&)E:F5L96YT:V5ZZ7-T(&OV
M=F5T]65N(&QE<WH@Z7)VZ6YY97,I`$$@=.%B;.%Z870@<WKI;&5S<^EG90!!
M('-ZZ6QE<W/I9R!MZ7)TZ6ME9WESZ6=E`%-ZZ6QE<W/I9SH`5VEK:0!3>NEL
M`%-ZZ6P@82!R96=G96QI(/-RX6MB86X`4WKI;'-E8F5S<^EG(&-S;VWS8F%N
M`%-ZZ6PZ`%-ZZ6PZ(`!"]FQC<V5S<^EG`$OM=N%N<^%G;&ES=&$`375N:V$`
M375N:V%H96QY:2!C[6T`375N:V%H96QY:2!T96QE9F]N`$$@)60N('-O<F)A
M;B!N96T@;65G9F5L96SU(&$@;65Z]6L@<WKA;6$N(%;A<G0Z("5D+"!T86SA
M;'0Z("5D+@!.96T@;65G9F5L96SU(&$@;65Z]6L@<WKA;6$N(%;A<G0Z("5D
M+"!T86SA;'0Z("5D+@!(:6+A<R!O9F9S970@*"5D*2!A(%9&4R!FX6IL(&]L
M=F%SX7-A:V]R+@!,:6YU>"!F;W)RX7-K\V0@:V5R97-Z<F5F97)E;F-I80!8
M-3`Y=C,@86QA<'9E=/4@:V]R;.%T;WKA<V]K`%@U,#EV,R!K:71E<FIE<WIT
M971T(&MU;&-S:&%S>F[A;&%T`%@U,#EV,R!T=6QA:F1O;F]S(&%L=&5R;F%T
M[78@;65G;F5V97KI<V4`6#4P.78S('1U;&%J9&]N;W,@:W5L8W-A>F]N;W/M
M=/,`6#4P.78S(&MI=&5R:F5S>G3I<V5K`%E9`%E965D`66%H;V\A('3I<FOI
M<`#I=F5N=&4`2F5M96X`26=E;@!)9V5N+"!B96QE9WEE>F5M+@#6;B!A(&OV
M=F5T:V5Z]2!A>F]N;W/M=/,H:RD@;&5V96QE:70@:^ES>OQL(.%T=/9L=&5N
M:3H`02!K]G9E=&ME>O4@;6%P<.%K('1A<G1A;&WA="!K[7;A;FIA('3V<O9L
M;FDN`$$@:_9V971K97KU(&UA<'#A:V%T(&OM=N%N:F$@=/9R]FQN:2X`VFH@
M;6%P<.%B82!K[7;A;B!MX7-O;&YI+^%T:&5L>65Z;FDN`$%L;6%P<.%T(&OM
M=N%N(&YY:71N:2!A(&OV=F5T:V5Z]2!M87!PX6+S;"``VFH@*&QE9V9E;'/U
M('-Z:6YT^RD@;6%P<.%T(&AO>B!LZ71R92X`36]S="!(5$U,(%1%6%0@;?-D
M8F%N('9A;BX@2&%S>F[A;&IA(&$@6SP^72!G;VUB;W0L(&AA('9I<W-Z82!A
M:V%R(';A;'1A;FD@82!S>F]KX7-O<R!G<F%F:6MU<R`H5UE325=91RD@;65G
M:F5L96[M=.ES<F4N`-9N;F5K(&YI;F-S(&IO9V]S=6QT<^%G82!M87!PX6MA
M="!LZ71R96AO>FYI+@!.96T@:&]Z:&%T(&SI=')E("5D(&)L;VMK;N%L('3V
M8F)E="X`UFYN96L@;FEN8W,@:F]G;W-U;'1SX6=A('3V8F(L(&UI;G0@)60@
M;6%P<.%T(&SI=')E:&]Z;FDN`$%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73A
M<V$@;F5M('3V<G3I;G0@;65G+@!!(&OV=F5T:V5Z]2!M87!PX70@:^UVX6YJ
M82#A=&YE=F5Z;FDZ(`!!(&OV=F5T:V5Z]2!S>FEM8O-L=6UO:V%T(&AA<WIN
MX6QH871J82!A(&QE=NEL<&%P[7)O:V]N.B`E8R!J96QZ:2!A(&QE=NEL('1A
M<G1A;&WA="P@)7,@<&5D:6<@87H@X6QL86YD\R!L97;I;';I9WKU9.ES="`H
M<VEG;F%T=7)E*2X`02!T96QJ97,@;NEV8F5N(&YE;2!S>F5R97!E;&AE="!A
M("=<)R!K87)A:W1E<BX`3F5M('-I:V5R_&QT(&AA<WINX6QA=&]N(&OM=OQL
M<F4@:&5L>65Z;FEE("AU;G-U8G-C<FEB92D@82`B)7,B(&UA<'#A="X`UFX@
M;F5M(&5G>65Z971T(&)E;&4@82!3>F]L9^%L=&%TX7,@1F5L=.ET96QE:6)E
M+"!E>NER="!N96T@:F5L96YT:V5Z:&5T(&)E+@!.96T@861O='0@;65G(.ER
M=NEN>65S(&5M86EL(&/M;65T+@!.96T@861T82!M96<@82!M96=F96QE;'1E
M=.ES="!A>B!I;7!O<G3A;'0@9N%J;"#I<R!A*'HI("5S(&UE>O5I(&OV>O9T
M="X`UFX@;F5M(&IO9V]S=6QT(&UE9W;A;'1O>G1A=&YI(&5N;F5K(&$@;6%P
M<.%N86L@82!H;WIZX6;I<FAE=/5SZ6?I=`#6;B!T;W;A8F+M=&]T=&$@97IT
M(&$@;&5V96QE="`H96MK;W(Z("4E<RD@82!K]G9E=&ME>O4@8^UM>F5T=&5K
M;F5K.B`E<RX`)7,@^FH@;&5V96QE(.ER:V5Z971T+@#)<FME>F5T="!E9WD@
M^FH@;&5V96QE+@!%>G0@87H@;VQD86QT(&WA<B!E;&O\;&1T92!E9WES>F5R
M+@!3:6ME<F5S96X@:VEJ96QE;G1K97IE='0N`-IJ(&QE=F5L92!V86X@82!K
M]G9E=&ME>O4@;6%P<.%B86XZ`-IJ(&QE=F5L92!V86X@82!K]G9E=&ME>O4@
M;6%P<.%K8F%N.@!%9WD@;6]B:6QT96QE9F]N<WKA;6]T(&ME;&P@;65G861N
M:6$L(&-S86L@82!S>N%M:F5G>65K970L(&5S971L96<@96=Y("<K)R!K87)A
M:W1E<G)E;"!K97ID=F4L(&AA(&YE;7IE=&OV>FD@=.%R8W/A>N%S:2!M\V1O
M="!K[7;A;B!H87-Z;N%L;FDN`$5L9F]G861H873S(.ER=.EK970@:V5L;"!M
M96=A9&YI82X`02!$871A5')E92!A;')E;F1S>F5R="!B92!K96QL(.%L;.UT
M86YI(&$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6=O:R!I9^EN>6SI<^EH
M97HN`$$@5D93(&%L<F5N9'-Z97(@;FEN8W,@8F7A;&SM='9A+@!%;/5B8B!L
M92!K96QL(.UR;FEA+"!H;V=Y(&UI;'EE;B!P<F]B;.EMX70@=&%P87-Z=&%L
M="P@;6EE;/5T="!E;&O\;&1I(&$@:&EB86IE;&5N=.ES="X`3&5G86SA8F(@
M96=Y(&/M;7IE='1E="!M96<@:V5L;"!A9&YI82X`365G(&ME;&P@861N:2!E
M9WD@55),+70L(&%H;W9A(&5Z(&$@;&EN:R!M=71A=`!%;FYE:R!A(&QE=NEL
M;F5K(&$@;65G=&5K:6YTZ7/I:&5Z(&UE9R!K96QL(&%D;FEA(&%Z(-9N('1I
M=&MO<R!01U`@:W5L8W/A:&]Z('1A<G1O>O,@:F5L;6]N9&%T;W0N`$5N;F5K
M(&$@;&5VZ6QN96L@82!M96=T96MI;G3I<^EH97H@;65G(&ME;&P@861N:6$@
M87H@UFX@=&ET:V]S(%,O34E-12!K=6QC<^%H;WH@=&%R=&]Z\R!J96QM;VYD
M871O="X`16SU<WKV<B!CZ6QKZ6YT(&MI(&ME;&P@=N%L87-Z=&%N:6$@96=Y
M(&UA<'#A="X`16SU<WKV<B!K:2!K96QL(';A;&%S>G1A;FEA(&$@=/9R;&5N
M9/4@87IO;F]S[73S="X`16SU<WKV<B!K:2!K96QL(';A;&%S>G1A;FEA(&5G
M>2!C[6UE="X`2VD@:V5L;"!VX6QA<WIT86YI(&5G>2!T]G)L96YD]2!S>F5R
M=F5R="X`16SU8F(@;&5G86SA8F(@96=Y(&QE=F5L970@:VD@:V5L;"!VX6QA
M<WIT86YI82X`365G(&ME;&P@861N:6$@82!C[6UZ971T970N`$UE9R!K96QL
M(&%D;FEA+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N
M:F$@=/9R]FQN:2X`365G(&ME;&P@861N:6$@87H@96QTX79O;.UT86YD\R!F
M96QH87-Z;N%L\VD@;F5V970N`$UE9R!K96QL(&%D;FEA(&$@:&]Z>N%A9&%N
M9/,@9F5L:&%S>F[A;/,@;F5VZ70N`$UE9R!K96QL(&%D;FEA+"!H;V=Y(&UE
M;'EI:R!F96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N:F$@X73M<FYI+@!-96<@
M:V5L;"!A9&YI82!E9WD@<&%R86YC<V]T+@!-96<@:V5L;"!A9&YI82!A>B#Z
M:B!K871E9_-R:6$@;F5VZ70N`$5N9V5DZ6QY97IN:64@:V5L;"`B)7,B+70@
M82!K87)B86YT87)TX7-I(&9E;&%D871O:R!B9>%L;.UTX7-A:6)A;BX`3VQA
M<WIO<G-ZX6=I('1E;&5F;VYS>N%M;W0@:V5L;"!M96=A9&YI80#6;B`E<RUR
M92!I<N%N>>UT;W1T82#A="!E>G0@82!L979E;&5T("4E<RUE;BX`17)R92!A
M(&QE=NEL<F4@=N%L87-Z;VQT(&5K:V]R.B`E<RX`02`B)7,B(&UA<'!A(&YE
M;2!V;VQT(&AA<WINX6QA=&)A(';I=F4@*'-TX71U<WIA('5N<W5B<V-R:6)E
M9"DN($$@<WIE<G9E<B#\>F5N971E.@!!("(E<R(@;6%P<&$@:&%S>F[A;&%T
M<F$@=F]L="!K:6IE;/9L=F4@*'-TX71U<WIA('-U8G-C<FEB960I+B!!('-Z
M97)V97(@_'IE;F5T93H`4VEK97)E<V5N(&IE;/9L=&4@:VD@:&%S>F[A;&%T
M<F$@*'-U8G-C<FEB960I(&$@(B5S(B!M87!PX70N`%-I:V5R97-E;B!H96QY
M97IT92!H87-Z;N%L871O;B!K[7;\;')E("AU;G-U8G-C<FEB960I(&$@(B5S
M(B!M87!PX70N`$%Z(-9N("5S(&MA<&-S;VQA=&$@:63U=/IL;.EPZ7,@;6EA
M='0@;65G<WIA:V%D="X@2^ER96T@:F5L96YT:V5Z>F5N(&)E(/IJ<F$N`$%Z
M(-9N(&5M86EL(&/M;64`07H@UFX@9F5L863S:2`H1G)O;3HI(&/M;64Z`%-Z
M96WI;'EE<R!I;F9O<FWA8VGS`$%Z(-9N("5S(&MA<&-S;VQA=.%N86L@:V5Z
M9&5T92#S=&$@;65G=N%L=&]Z;W1T(&%Z(&EN=&5R;F5T(&/M;64N($)I>G1O
M;G/A9^%N86L@Z7)D96OI8F5N(&ES;>ET(&)E(&ME;&P@:F5L96YT:V5Z;FEE
M+@!!>B#6;B!N979E`$%Z(-9N(&YY:6QVX6YO<R]T:71K;W,@4$=0(&MU;&-S
M86D`07H@UFX@<WIE;>EL>65S+"!T:71K;W,@:W5L8W-A`$%Z(-9N(&YY:6QV
MX6YO<R!K=6QC<V$`07H@UFX@=FES>F]N=';A;&%S>B`H4F5P;'DM=&\Z*2!C
M[6UE.B`\96T^*&]P8VEO;N%L:7,I/"]E;3X`07H@UFX@;GEI;';A;F]S+W1I
M=&MO<R!3+TU)344@=&%N^G/M=';A;GEA:0!!>B#6;B!A>F]N;W/M=/-I.@!!
M>B#6;B!A;&EA<R!C[6UE:3H\96T^*&YE;2!K]G1E;&5Z]2P@;6EN9&5N(&/M
M;2!K_&SV;B!S;W)B82!K97+\;&KV;BD\+V5M/@!!>B#6;B!F96QH87-Z;N%L
M\V%Z;VYO<^UT\R!A;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U=ND@87H@
M^FH@9F5L:&%S>F[A;/-K(&SI=')E:&]ZX7/A="X@2&$@82!(;W)D92!R96YD
M<WIE<G)E;"!K[7;A;FIA(&ME>F5L;FD@82!F96QH87-Z;N%L\VD@861A=&]K
M870L(&%K:V]R(&WA<VEK(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z
M97)R92!V86X@<WK\:W/I9V4N`$%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73S
M(&%L<F5N9'-Z97)E(&YE;2!T97-Z:2!L96AE=/5VZ2!A(&9E;&AA<WINX6SS
M:R!L:7-TX7KA<^%T+"!V86=Y('9A;&%M:2!O:V+S;"!L971I;'1O='3A:R!E
M>G0@82!L96AE=/5SZ6=E="X`07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;65G
M=N%L=&]Z;W1T(&%Z(-9N("5S(&UU;FMA:V%P8W-O;&%TX6YA:R!K97ID971E
M(/-T82X@0FEZ=&]N<^%G82#I<F1E:^EB96X@:7-MZ70@8F4@:V5L;"!J96QE
M;G1K97IN:64N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T
M:F$@96YN96L@82!KZ7!T[7!U<VYA:R!A(&OV>G9E=&QE;B!M96=J96QE;NUT
MZ7/I="X`07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;F5M('3A;6]G871J82!E
M>G0@82!L96AE=/5SZ6=E="X`07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;F5M
M('3A;6]G871J82!E>G0@82!N>6]M=&%TX7-I(&]P8VGS="X@4'+S8N%L:F]N
M(&$@0W1R;"U0("AV86=Y($-O;6UA;F0M4"D@;&5N>6]MX7/A=F%L(&YY;VUT
M871N:2X`02!J96QE;FQE9R#I<G;I;GEE<R!I9/5Z\VYA.@!!>B#6;B!A;&%P
MZ7)T96QM97IE='0@:V%R86MT97)KZ7-Z;&5T92!A(&QE=NEL[7+A<VAO>CH`
M07H@UFX@86QA<.ER=&5L;65Z971T('1I=&MO<^UTX7-I(&WS9&IA(&$@;&5V
M96QE>NES:&5Z.@!!>B#6;B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N
M;W/M=/-J82!M96=VX6QT;WIO='0N`$%Z(-9N(&%L87#I<G1E;&UE>NES('-Z
M97)I;G1I(&%Z;VYO<^UT\VIA.@!!>B#6;B!T96QJ97,@;F5V93H`02!H:79A
M=&MO>N%S(&9O<FWA:N%B86X@96QK_&QD]G1T(&UE;&SI:VQE=.ET(&WA<B!L
M96=A;.%B8B!E9WD@8^UM>F5T="!L973V;'3V='1E+@H*02!M96QLZ6ML970@
M;F5V93H@)7,*02!M96QLZ6ML970@9.%T=6UA.B`E<PH*2V%T=&EN='-O;B!A
M(&OV=F5T:V5Z]2!S>O9V96=R92P@:&$@=NEG;&5G('3V<O9L;FD@:^UVX6YJ
M82!A(&UE;&SI:VQE=&5T.@HE<P!,96KA<G0@82!B96IE;&5N=&ME>NES:2!J
M;V=O<W5L='/A9V$N`$%Z(-9N(&QE=F5L92!S:6ME<F5S96X@:^EZ8F5S[73I
M<W)E(&ME<OQL="X`07H@UFX@)7,M<F4@:&%S>F[A;'0@^FH@:F5L<WIA=F$Z
M("5S`$%Z(-9N(/IJ(&)EX6QL[73A<V%I="#I<G;I;GEE<^UT971T_&L@82!M
M;W-T86YI(&)E:F5L96YT:V5ZZ7,@:61E:NER92X`07H@UFX@^FH@8F7A;&SM
M=.%S86ET(&5L;65N=&5T=/QK+@!!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T
M='5K`$%Z(-9N(&IE;'-Z87;A="#A=.%L;.UT;W1T=6LL(&[I>GIE(&UE9R!A
M(&QE=F5L96ET+"!M86ID(&IE;&5N=&ME>GIE;B!B92!A>B#Z:B!J96QS>O-V
M86PN`$%Z(-9N(&IE;'-Z87;A;F%K(&QE:N%R="!A>B#I<G;I;GEE<W/I9VD@
M:61E:F4N`$%Z(-9N(.%L=&%L(&AA<WINX6QT('3A=F]L:2!S>F5R=F5R96LZ
M`$%Z(-9N(.%L;&%N9/,@;&5VZ6QVZ6=Z]63I<V4@*'-I9VYA='5R92DZ`$IU
M9V]S>FSA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;3F4@;75T87-S=6L@
M82!C[6UE:V5T70!;3F4@;75T87-S=6L@82!B96EDZ7IE='0@<WKV=F5G971=
M`%M4X7)G>2!NZ6QK_&Q=`%M(:6)A:F5L96YTZ7-=`%M-=71A<W-U:R!A(&/M
M;65K970@+0!;375T87-S=6L@82!B96EDZ7IE='0@<WKV=F5G970@+0!;375T
M87-S=6L@82!B96EDZ7IE='0@<WKV=F5G970@+2`E<R!S;W)=`%M-=71A<W-U
M:R!A(&/M;65K970@+2`E<R!C[6UZ971T70!;)7,O)7,@<V]R70!?061M:6YI
M<WIT<N%C:?,`7T)C8P!4:6QT\VQI<W1A`%]087)A;F-S<V]R`%]#8P!?5/9R
M;.ES`%-O<G3V<FSI<P!?36%P<.%K`%]#<V]P;W)T;VL`4V5?9^UT<^EG`%]!
M>F]N;W/M=/,`02!KZ7`@='5L86ID;VYSX6=A:2XN+@!?26YB;W@`0F5J96QE
M;G1K97KI<P!?2VEJ96QE;G1K97KI<P!!(&QE=NEL(&9O<G+A<V$`02!L:6YK
M(&WS9&]S[73A<V$N+BX`VFH@;&5V96QE:P!?3W!C:?-K`%]*;V=O<W5L='/A
M9V]K`%].>6]M=&%TX7,`4')I;W)I=.%S("AS_')G]7-SZ6<I`"5S(&9R:7-S
M[73I<V4`02!L:6YK('3V<FSI<V4N+BX`7U;A;&%S>@!+97)E7W/I<P!+_&QD
M:OQK(%]E;`!?0F7A;&SM=.%S;VL`5.%B;.%Z870@='5L86ID;VYSX6=O:P!,
M;V=I:V%I('-O<G)E;F0`0^U?;7IE='0`5/9R;.ES('9I<W-Z80!?1F5L:&%S
M>F[A;/-K`%9I<WIO;G1VX6QA<WIO:VMA;"!?96=Y_'1T`$5N9V5DZ6QY97KI
M<VD@;&ES=&$`8^UM:F5G>7KI:P!A(&/M;7IE='0@:7-M97)E=&QE;@!M96QL
MZ6ML970`8N%J=`!N87!TX7(`;GEU9V]D=`!A(&MI;65N971I(.%L;&]MX6YY
M(&YE;2!H;WIH873S(&SI=')E`&$@8F5M96[U(.%L;&]MX6YY(&YE;2!N>6ET
M:&%T\R!M96<`:V%T=&EN='-O;B!I9&4`<&%R86YC<W-O<FD@:&EB80!K;VYF
M:6=U<N%C:?-S(&AI8F$`:&GA;GEZ:6L@96=Y(&9O;G1O<R!R96YD<WIE<N%L
M;&]MX6YY`&%D871F;W)MX71U;2!H:6)A`&WS9&]S[73A<P!A>B!A9&%T(&YE
M;2!T86SA;&AA=/,`8W/V:VME;@!FX6IL`&ET=``E<R`H)7,I(&ERX6YY8O-L
M+"`E<R`E<R!S96)E<W/I9V=E;`!S>NEL;/9KZ7-E:P!M.@!A(&?I<"!N979E
M(&YE;2!I<VUE<G0`87IO;FYA;&D`:6YP=70O;W5T<'5T(&AI8F$`8F5L<_4@
M<')O9W)A;6AI8F$`:W5L8W,`<V]R70!M86EL8F]X(&;A:FP`07H@;6MS:6]F
M<R!P<F]G<F%M("5D(&AI8F%K\V1D86P@;&7A;&QT(&%Z($E33R#A;&QO;>%N
M>2!KZ7-Z[73I<V4@:_9Z8F5N+@!NZ78`96=Y('-E;0!!('!R;V=R86UN86L@
M97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!!('!R;V=R86UN
M86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!J96=Y>F5T
M=/9M8@!V86=Y`'-ZX7IA;.EK`&YI;F-S(&UE9V9E;&5L]2!J;V=O<W5L='/A
M9V$`<&EX96P`8^UM>F5T=%T`861A=.%T=FET96QI("AP<F]T;VMO;&PI(&AI
M8F$`96UE;&ME9&EK`&$@<WIO;&?A;'1A=.%S(&YE;2#A;&P@<F5N9&5L:V5Z
MZ7-R90!NZ7IZ_&L@;65G(&$@:_QL]FYB<^EG96ME=`!S;7,R96UA:6P@<WIO
M;&?A;'1A=.%S($A45%`M;B#A=`!H96QY97/M<N%S:2!H:6)A`&AE;'EE<^UR
MX7-I(&AI8F$`=N%L=&]Z871L86X`<F5N9'-Z97)H:6)A`&9E;&%D871L:7-T
M80#A=&UE;F5T:2!H:6)A`&UE9V5R]7/M=.ES:^EN="!KZ71S>F5R(.UR:F$@
M8F4@82!J96QS>O-T`&[I=B!NZ6QK_&P`82!F96QH87-Z;N%L\R#A;'1A;"!V
MX6QA<WIT:&%T\P!V0V%R9`!S>CH`=&EL=/-L:7-TX6IA`&5N9V5DZ6QY97KI
M<VD@;&ES=.%J80``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+VQO8V%L92]H=5](52]H96QP+GAM;```````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$T,#$V,``Q,#0Q-S,V,C<V,P`P,C$Q,S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]X;6P@=F5R<VEO
M;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,B(_/@H\(2TM("1(;W)D93H@
M:6UP+VQO8V%L92]H=5](52]H96QP+GAM;"QV(#$N."XV+C0@,C`P-B\P,2\S
M,"`Q-3HU.#HP,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M8V]M<&]S92UB=71T;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M3&5VZ6SM<N%S.B!F=6YK8VGS9V]M8F]K/"]T:71L93X*("`@(#QH96%D:6YG
M/D9U;FMC:?-G;VUB;VL\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@)TQE
M=NEL(&5L:_QL9.ES92<@96QK_&QD:2!A(&QE=F5L970@82!K[7;A;G0@8^UM
M>F5T="AE:REN96LN($5R<F4*("`@(&$@9V]M8G)A(&-S86L@86MK;W(@:V%T
M=&EN='-O;BP@86UI:V]R(&$@;&5VZ6P@;>%R('1E;&IE<V5N(&OI<WHL(&UE
M<G0*("`@(&5Z="!K]G9E=/5E;B!A(&QE=NEL:_QL9.ES(&WA<B!N96T@X6QL
M[71H873S(&QE+"!A(&QE=NEL(&YE;2!H[79H873S(`H@("`@=FES<WIA+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!(82!FZ6QB92!K96QL(&AA9WEJ
M=6L@82!L97;I;.URX7-T+"!K871T:6YT<W5N:R!A(`H@("`@)TUE;G1S_&L@
M96P@;75N:V%PZ6QDX6YY:^EN="<@9V]M8G)A+B!%>B!A("=$<F%F=',G(&YE
M=OL@;6%P<.%B86X@"B`@("!H96QY97II(&5L(&$@;&5V96QE="X@17IT(&$@
M;6%P<.%T(/IG>2#I<FAE=&K\:R!E;"P@:&$@82!L97;I;&QI<W1A(`H@("`@
M86)L86L@9F5L<_4@:^EK(&UE;OQS;W+A;F%K(&IO8F(@<WKI;.EN(&QE=O4@
M;&5G]G)D_&SU(&UE;OQJZ6+U;"`*("`@(&MI=N%L87-Z=&IU:RX@02!FZ6QB
M96AA9WEO='0@;&5V96QE="!KZ7/U8F(@^F=Y(&9E:F5Z:&5T:OQK(&)E+`H@
M("`@:&]G>2!K:6YY:71J=6L@82`G1')A9G1S)R!M87!PX70L('+A:V%T=&EN
M='5N:R!A(&OI<F3I<V5S(&QE=NEL<F4L"B`@("!M86ID(&$@)T9O;'ET873A
M<R<@<WKV=F5G<F4N(,ER9&5M97,@82!L97;I;"!TX7)G>>%T(&UE9V%D;FD@
M82`*("`@(&UU;FMA<.EL9.%N>6OI;G0@=F%L\R!E;&UE;G3I<R!E;/5T="P@
M:&]G>2!KZ7/U8F(@82`G1')A9G1S)R!M87!PX6)A;@H@("`@:_9N;GEE;B!K
M:7;A;&%S>G1H873S(&QE9WEE;B!A(&OM=N%N="!L97;I;"X@02!M=6YK87#I
M;&3A;GEKZ6YT"B`@("!V86SS(&UE;G3I<R!U=.%N(&%Z($E.0D]8+6)A('9A
M9WD@86)B82!A(&UA<'#A8F$@:V5R_&P@=FES<WIA"B`@("!A;6D@=71O;&KA
M<F$@;GEI='9A('9O;'0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($$@
M)TWI9W-E;2!K96QL(&5Z(&$@;&5VZ6PG(&=O;6)R82!K871T:6YT=F$@=FES
M<WIA:V5R_&S\;FL@87H@24Y"3U@M8F$@"B`@("!V86=Y(&%B8F$@82!M87!P
MX6)A+"!A;6D@=71O;&KA<F$@;GEI='9A('9O;'0L(&%NZ6QK_&PL(&AO9WD@
M:^ES>OQL]0H@("`@;&5V96S\;FME="!E;&O\;&1E;NEN:R!V86=Y(&5L;65N
M=&5NZ6YK+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB8V]M<&]S92UB=71T;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D%C=&EO
M;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@365S<V%G92!L875N
M8VAE<R!Y;W5R(&5M86EL('1O('1H92!I;G1E;F1E9"!R96-I<&EE;G0H<RDN
M($)E('-U<F4@>6]U('=A;G0@=&\@<V5N9"!B969O<F4@8VQI8VMI;F<@:&5R
M92!A<R!O;F-E('-E;G0@:70@8V%N;F]T(&)E('1A:V5N(&)A8VLN"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@(%-A=F4@1')A9G0@<&QA8V5S(&%N('5N
M9FEN:7-H960@;65S<V%G92!I;B!A(&9O;&1E<B!C86QL960@)T1R869T<R<*
M86-C97-S:6)L92!B>2!T:&4@<&]P+61O=VX@8F]X(&]N('1H92!R:6=H="!S
M:61E(&]F('1H92!B;'5E(&YA=FEG871I;VX@8F%R(&%T('1O<"X@66]U(&-A
M;B!T:&5N(&9I;FES:"!T:&4@;65S<V%G92!L871E<B!B>2!S=VET8VAI;F<@
M=&\@=&AE("=$<F%F=',G(&9O;&1E<BP@8VQI8VMI;F<@;VX@=&AE('-A=F5D
M(&UE<W-A9V4@=&\@;W!E;B!I="P@86YD('1H96X@8VQI8VMI;F<@;VX@)U)E
M<W5M92<N($)E('-U<F4@=&\@<'5T(&$@<W5B:F5C="!O;B!T:&4@96UA:6P@
M8F5F;W)E('EO=2!S879E('1H92!D<F%F="!S;R!T:&%T('EO=2!C86X@96%S
M:6QY(&ED96YT:69Y('=H:6-H(&UE<W-A9V4@>6]U('=A;G0@=VET:&EN('1H
M92!$<F%F=',@9F]L9&5R+B!!9G1E<B!S879I;F<@87,@82!$<F%F="P@>6]U
M(&%R92!R971U<FYE9"!T;R!Y;W5R($E.0D]8(&]R('=H871E=F5R(&9O;&1E
M<B!Y;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@($-A;F-E;"!-97-S86=E(&1R;W!S('1H92!M97-S86=E(&EN('!R
M;V=R97-S(&%N9"!S:6UP;'D@<F5T=7)N<R!Y;W4@=&\@=&AE($E.0D]8(&]R
M('=H871E=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\
M+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O
M<V4M9G)O;2(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DQE=NEL[7+A
M<SH@02!F96QA9/,@87IO;F]S[73S:F$\+W1I=&QE/@H@("`@/&AE861I;F<^
M(D$@9F5L863S(&%Z;VYO<^UT\VIA(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@5N%L87-S>F$@:VD@87IT(&%Z(&%Z;VYO<^UT\W0L(&UE;'EN96L@;65G
M9F5L96SU('-Z97)E<&)E;B!K[7;A;FIA"B`@("!A(&QE=F5L970@[7)N:2X@
M2_QL9.ES:V]R(&$@;&5VZ6P@)T9R;VTZ)R!M97IE:NEB92`H82!F96QA9/,@
M8^UM96OI;G0I"B`@("!A(&MI=N%L87-Z=&]T="!A>F]N;W/M=/-N86L@;65G
M9F5L96SU(&/M;2!K97+\;"!M86ID+@H@("`@/"]P87)A/@H\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UF<F]M(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!&<F]M/"]T:71L93X*("`@(#QH96%D
M:6YG/B)&<F]M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5P96YD:6YG
M(&]N('EO=7(@<V5T=7`@>6]U(&-A;B!C:&]O<V4@9G)O;2!A(&1R;W`@9&]W
M;B!L:7-T(&%N(&ED96YT:71Y('1H870@>6]U(&5N=&5R960@=6YD97(@(D]P
M=&EO;G,M)F=T.U!E<G-O;F%L($EN9F]R;6%T:6]N(BP@;W(@>6]U(&-A;B!E
M;G1E<B!T:&4@;6%I;"!A9&1R97-S(&EN(&$@=&5X="!F:65L9"!T:&%T('EO
M=2!W86YT('1O('5S92!A<R!T:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92X*
M("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M8V]M<&]S92UT;R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DQE=NEL
M[7+A<SH@0^UM>F5T=#PO=&ET;&4^"B`@("`\:&5A9&EN9SXB0^UM>F5T="(\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(,UR:F$@8F4@82!L97;I;"!C[6UZ
M971T:NEN96LO8^UM>F5T=&IE:6YE:R!P;VYT;W,@96UA:6P@8^UMZ70N($%Z
M(&5G>65S"B`@("!C[6UE:V5T('9E<W-Z]79E;"!K96QL(&5L=N%L87-Z=&%N
M:2P@;>%S(&MA<F%K=&5R(&AA<WINX6QA=&$@:&EBX70@;VMO>BX*("`@($%Z
M(&ED92#M<G0@8^UM96L@87H@96QK_&QD96YD]2!L97;I;"`G5&\Z)R!M97IE
M:NEB92!K97+\;&YE:RX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y
M.@H\96YT<GD@:60](F-O;7!O<V4M=&\B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ(%1O/"]T:71L93X*("`@(#QH96%D:6YG/B)4;R(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL
M(&%D9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@>6]U<B!M97-S86=E
M+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA
M.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@
M66]U<B!E;G1R>2!F;VQL;W=S(")4;SHB(&EN(&]U=&=O:6YG(&UA:6PN"B`@
M("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O
M;7!O<V4M8V,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y,97;I;.UR
MX7,Z($-C/"]T:71L93X*("`@(#QH96%D:6YG/B)#8R`H8V%R8F]N(&-O<'DL
M(&WA<V]L870I(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@261E(.UR:F$@
M8F4@87IO:VYA:R!A('!O;G1O<R!E;6%I;"!C[6WI="P@86MI:VYE:R!MX7-O
M;&%T;W0@:^UVX6X@"B`@("!K_&QD96YI(&$@:^ES>OQL]2!L97;I;&+U;"X@
M07H@96=Y97,*("`@(&/M;65K970@=F5S<WKU=F5L(&ME;&P@96QVX6QA<WIT
M86YI+"!MX7,@:V%R86MT97(@:&%S>F[A;&%T82!H:6+A="!O:V]Z+@H@("`@
M07H@:61E(.UR="!C[6UE:R!A>B!E;&O\;&1E;F3U(&QE=NEL("=#8SHG(&UE
M>F5JZ6)E(&ME<OQL;F5K+B!!>F]K;F%K"B`@("!S>F]KX7,@:6QY96X@;?-D
M;VX@;>%S;VQA=&]T(&O\;&1E;FD@82!L97;I;&+U;"P@86MI:R!N96T@:_9Z
M=F5T;&5N(&WS9&]N+"`*("`@(&1E(.ER9&5K96QT96L@86)B86XL(&AO9WD@
M='5D:F%N86L@82!L97;I;'+U;"X@02`G5&\Z)R#I<R`G0V,Z)R!C[6UZ971T
M96L*("`@(&UI;F1E9WEI:V4@;.%T:F$@;6EN9&OI="!M97KU('1E;&IE<R!T
M87)T86QMX70L(.UG>2!M:6YD86YN>6EA;B!P;VYT;W-A;B`*("`@('1U9&KA
M:RP@:&]G>2!K:2!K87!T82!M96<@82!L979E;&5T+@H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UC8R(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@0V,\+W1I=&QE/@H@("`@
M/&AE861I;F<^(D-C(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@
M=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C
M96EV92!A(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@66]U(&UU<W0@
M<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@<'5N
M8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT<GD@
M9F]L;&]W<R`B0V,Z(B!I;B!O=71G;VEN9R!M86EL+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@
M=&\@<&5O<&QE(&]T:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET=&5N
M('1O(&1I<F5C=&QY(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@;V8@
M=&AE(&5M86EL(&%S('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C=&QY
M(&-O;F-E<FYE9"!A8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN("!!
M;&P@)U1O.B<@<F5C:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C86X@
M<V5E('1H92!E;G1I<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP:65N
M=',N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](F-O;7!O<V4M8F-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M3&5VZ6SM<N%S.B!"8V,\+W1I=&QE/@H@("`@/&AE861I;F<^(D)C8R`H8FQI
M;F0@8V%R8F]N(&-O<'DL('1I=&MO<R!MX7-O;&%T*2(\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($ED92#M<FIA(&)E(&%Z;VMN86L@82!P;VYT;W,@96UA
M:6P@8^UMZ70L(&%K:6MN96L@=&ET:V]S(&WA<V]L871O="!K[7;A;B`*("`@
M(&O\;&1E;FD@82!KZ7-Z_&SU(&QE=NEL8O5L+B!!>B!E9WEE<R!C[6UE:V5T
M('9E<W-Z]79E;"!K96QL(&5L=N%L87-Z=&%N:2P@"B`@("!MX7,@:V%R86MT
M97(@:&%S>F[A;&%T82!H:6+A="!O:V]Z+B!!>B!I9&4@[7)T(&/M;65K(&%Z
M(&5L:_QL9&5N9/4@;&5VZ6P@"B`@("`G0F-C.B<@;65Z96KI8F4@:V5R_&QN
M96LN($5Z96L@82!C[6UZ971T96L@=6=Y86[Z9WD@:V%P;F%K(&5G>2!PZ6QD
MX6YY=`H@("`@82!L97;I;&+U;"P@Z7,@;.%T:N%K(&$@)U1O.B<@Z7,@)T-C
M.B<@8^UM>F5T=&5K('1E;&IE<R!L:7-TX6KA="!I<RX*("`@($5Z('5T\V)B
M:2!C[6UZ971T96L@96SU='0@=FES>F]N="!T96QJ97-E;B!R96IT=F4@;6%R
M860@87H@82!TZ6YY+"!H;V=Y(`H@("`@;>EG(&$@)T)C8SHG(&UE>O5B96X@
M<WIE<F5P;/4@<WIE;>EL>65K(&ES(&MA<'1A:R!A(&QE=NEL8O5L(&5G>2!P
MZ6QDX6YY="X*("`@($$@)V)L:6YD(&-O<'DG('1E:.%T(&%R<F$@=71A;"P@
M:&]G>2!A("="8V,Z)R!C[6UZ971T96MR]6P@<V5M;6EL>65N"B`@("!M\V1O
M;B!N96T@<WIE<F5Z:&5T;F5K('1U9&]MX7-T(&$@;F]R;>%L("A4;SH@Z7,@
M0V,Z*2!C[6UZ971T96LN"B`@("!%>G0@82!MX7-O;&%T:_QL9.ES:2!M\V1S
M>F5R="!A:VMO<B!S>F]KX7,@:&%S>F[A;&YI+"!H82!B:7IO;GGM=&%N:2`*
M("`@(&%K87)J=6L@=F%L86MI;F5K("AR96YD<WIE<FEN="!V86QA;6D@9O5N
M]FLI+"!H;V=Y(&5G>2!H87)M861I:R!S>F5MZ6QY"B`@("!T=61O;>%SX7)A
M(&AO>G1U:R!A(&QE=NEL8F5N(&QE[7)T86MA="P@9&4@86[I;&O\;"P@:&]G
M>2!A>B!I;&QE=/4@='5D:F]N"B`@("!R\VQA+B`*("`@(#PO<&%R83X*/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8F-C(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@
M/&AE861I;F<^(D)C8R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R
M('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E('1O(')E
M8V5I=F4@82!B;&EN9"!C87)B;VX@8V]P>2!O9B!Y;W5R(&UE<W-A9V4N(%EO
M=2!M=7-T('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T
M:&5R('!U;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R
M(&5N=')Y(&9O;&QO=W,@(D)C8SHB(&EN(&]U=&=O:6YG(&UA:6PN"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@($)L:6YD(&-A<F)O;B!C;W!I97,@87)E
M('5S=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!D:7)E8W0@86YD
M(&EN9&ER96-T(')E8VEP:65N=',@*")4;SHB(&%N9"`B0V,Z(B!R96-I<&EE
M;G1S*2!W:&\@;F5E9"!T;R!R96%D('=H870@:7,@8F5I;F<@=W)I='1E;B!A
M<R!W96QL(%=)5$A/550@=&AE(&]T:&5R(')E8VEP:65N=',@:VYO=VEN9R!T
M:&%T('1H97D@87)E(')E8V5I=FEN9R!T:&4@96UA:6PN(%1H=7,@)V)L:6YD
M)R!M96%N<R!T:&%T('1H92!I9&5N=&ET>2!O9B!T:&5S92!R96-I<&EE;G1S
M(&ES(&AI9&1E;B!F<F]M(&%L;"!O=&AE<B!R96-I<&EE;G1S(&]F('1H92!E
M;6%I;"P@86YD(&]N;'D@>6]U(&%N9"!T:&5Y(&MN;W<@=&AE>2!G;W0@82!C
M;W!Y+B!9;W4@='EP:6-A;&QY('5S92!T:&ES('1O('1E;&P@86X@875T:&]R
M:71Y(&9I9W5R92!T:&%T('EO=2!A<F4@=&5L;&EN9R!S;VUE;VYE('-O;65T
M:&EN9R!W:71H;W5T(&%L87)M:6YG('1H92!P97)S;VX@>6]U(&%R92!S96YD
M:6YG('1H92!A8W1U86P@96UA:6P@=&\N"B`@("`\+W!A<F$^"CPO96YT<GD^
M+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<W5B:F5C="(@<W1A
M=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DQE=NEL[7+A<SH@5.%R9WD\+W1I
M=&QE/@H@("`@/&AE861I;F<^(E3A<F=Y(CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@261E(.UR:F$@8F4@82!L97;I;"!TX7)G>>%T+B!%>B!K97+\;"!A
M>B!E;&O\;&3V='0@;&5VZ6P@)U-U8FIE8W0Z)R`*("`@(&UE>F5JZ6)E+B!+
M97)E<W/\;FL@<O9V:60L(&5G>7-Z97+[+"!D92!I;F9O<FUA=.UV(&UE9V9O
M9V%L;6%ZX7-T+@H@("`@02!L97;I;"!TX7)G>6$@*&$@)U-U8FIE8W0Z)R!M
M97KU('1A<G1A;&UA*2!A(&QE9V5G>7-Z97+[8F(@;?-D<WIE<@H@("`@87)R
M82P@:&]G>2!A(&QE=NEL(&/M;7IE='1JZ70@*&1E(&$@9F5L863S:N%T(&ES
M(2D@96ULZ6ME>G1E<W-E"B`@("!A(&QE=NEL('1A<G1A;&WA<F$L(.UG>2!E
M9WD@86QK86QM87-A;B!M96=VX6QA<WIT;W1T('3A<F=Y(&YA9WEB86X*("`@
M('-E9^UT:2!A>B!E;6)E<G0@;&5V96QE:70@<F5N9&)E;B!T87)T86YI+"!I
M;&PN(&5G>2!F;VYT;W,*("`@(&QE=F5L970@:^ES]6)B(&UE9W1A;.%L;FDN
M(`H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!;6EK;W(@82`G5N%L87-Z
M)R`H4F5P;'DI+"!V86=Y("=4;W;A8F+M=.%S)R`H1F]R=V%R9"D@9G5N:V-I
M\R`*("`@('-E9^UT<^EGZ79E;"!VX6QA<WIO;"!E9WD@;&5VZ6QR92!I;&PN
M('1O=N%B8NUT(&5G>2!L979E;&5T+"!A:VMO<@H@("`@82!TX7)G>2`H82`G
M4F4Z)R!I;&PN("<H9G=D*2<@8F5S>OIRX7/A=F%L*2!B96WA<V]L\V1I:R!A
M(&O\;&3V='0*("`@(&QE=NEL('3A<F=Y(&UE>F5JZ6)E+B!%>B!S96?M="!A
M(&QE=F5L97KI<R!RZ7-Z='9E=O5I;F5K(&%B8F%N+"`*("`@(&AO9WD@;.%S
M<^%K+"!M:2!A(&)E<WKI;&=E=.ES(")F;VYA;&$B+B!%>NER="!A:VMO<BP@
M:&$@82!VX6QA<WH*("`@('9A9WD@=&]VX6)B:_QL9.ES(/IJ('3I;>%K870@
M=F5T(&9E;"P@Z7)D96UE<R!A('3A<F=Y870@Z7)T96QE;7-Z97+[96X@"B`@
M("!M96=VX6QT;WIT871N:2!E9WD@:VES<^DL(&5Z>F5L(&IE;&5Z=F4L(&AO
M9WD@82!B97-ZZ6QG973I<R!F;VYA;.%B86X@"B`@("#Z:B!I<N%N>70@:V5Z
M9'3\;FLN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+7-U8FIE8W0B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ(%-U8FIE8W0\+W1I=&QE/@H@("`@/&AE861I;F<^(E-U8FIE
M8W0B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@<W5B:F5C
M="!O9B!Y;W5R(&UE<W-A9V4N(%EO=7(@96YT<GD@9F]L;&]W<R`B4W5B:F5C
M=#HB(&EN(&]U=&=O:6YG(&UA:6PN($ME97`@:70@<VAO<G0L('-I;7!L92!A
M;F0@9&5S8W)I<'1I=F4N("!4:&4@<W5B:F5C="!L:6YE(&ES('1H92!E87-I
M97-T('=A>2!F;W(@>6]U(&%N9"!Y;W5R(&-O<G)E<W!O;F1E;G1S('1O(')E
M;65M8F5R('=H870@=V%S(&EN('1H92!E;6%I;"!A;F0@=&AU<R!I<R!V97)Y
M(&EM<&]R=&%N="!I;B!O<F=A;FEZ:6YG('EO=7(@96UA:6P@86YD(&9I;F1I
M;F<@:6UP;W)T86YT(&]N97,@;&%T97(N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@($%L<V\L('=H96X@>6]U("=297!L>2<@;W(@)T9O<G=A<F0G(&%N
M9"!E;6%I;"!T:&ES('-U8FIE8W0@;&EN92!I<R!C;W!I960@;W9E<B!I;G1O
M('1H92!N97<@;65S<V%G92!A;F0@<V\@:7,@82!V86QU86)L92!W87D@;V8@
M=&5L;&EN9R!W:&%T(&UE<W-A9V5S(&=O('1O9V5T:&5R('1O(&9O<FT@82`B
M=&AR96%D(B!O9B!A(&-O;G9E<G-A=&EO;BX@($AO=V5V97(L(&EF('1H92`G
M4F5P;'DG(&]R("=&;W)W87)D)R!C;VYT86EN<R!N97<@:61E87,L('EO=2!M
M87D@=V%N="!T;R!A9&0@<VEM<&QE(&UO9&EF:6-A=&EO;G,@=&\@=&AE("=3
M=6)J96-T)R!L:6YE('-O('1H92!R96-I<&EE;G0H<RD@8V%N(&9O;&QO=R!T
M:&4@<')O9W)E<W-I;VX@;V8@=&AE(")T:')E860N(@H@("`@/"]P87)A/@H\
M+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO
M;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y,97;I;.URX7,Z($]P
M8VGS:SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB3W!C:?-K(CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@17IE:R!A>B!O<&-I\VL@82!L97;I;"!C[6UZZ7/I
M8F5N+"!M96?M<N%SX6)A;BP@96QM96YTZ7/I8F5N('9A;FYA:PH@("`@<V5G
M[71SZ6?\;FMR92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@06UE;FYY
M:6)E;B!M96=J96QE;FEK(&$@(D/M;6IE9WEZZ6LB(&9E;&ER870L(&%K:V]R
M('1E;&5P[73I<W)E(&ME<OQL=`H@("`@82!H87-O;FSS("AE<F5D971I;&5G
M(")4=7)B82(I(&YE=OL@<')O9W)A;6UO9'5L+B!%8F)E;B!A>B!E<V5T8F5N
M"B`@("!A(&9E;&ER871R82!K871T:6YT=F$@:VEVX6QA<WIT:&%T:G5K(&$@
M8^UM:F5G>7KI:V5I;FMB]6P@82!K[7;A;G0*("`@(&5M86EL(&/M;64H:V4I
M="X@2&%S;VYL\R`B02!C[6URZ7-Z;&5T('1E;&IE<W/I(&5GZ7-Z[73I<V4B
M(&QE:&5T]7/I9RX*("`@($5H:&5Z(.UR:G5N:R!B92!A(&UE9V9E;&5L]2!M
M97KU8F4@*&/M;7IE='0L($-C+"!"8V,I(&$@:^UVX6YT('-Z96WI;'D*("`@
M(&YE=NEN96L@96QS]2!NZ6CA;GD@:V%R86MT97+I="P@;6%J9"!K871T:6YT
M<W5N:R!A(`H@("`@(D$@8^UM<NES>FQE="!T96QJ97-SZ2!E9^ES>NUTZ7-E
M(B!S>O9V96=R92X@06UE;FYY:6)E;B!A(`H@("`@8^UM:F5G>7KI:_QN:V)E
M;B!E9WEE=&QE;B!E;6)E<B!N979E(&ME>F3U9&EK(&$@8F7M<G0@:V%R86MT
M97)E:VME;"P*("`@(&%K:V]R(&5Z(&%Z(&5M86EL(&/M;2!B96WA<V]L\V1I
M:R!A(&UE9V9E;&5L]2!M97KU8F4N($AA('3V8F(@<WIE;>EL>0H@("`@;F5V
M92!I<R!A(&UE9V%D;W1T(&MA<F%K=&5R96MK96P@:V5Z9/5D:6LL(&%K:V]R
M(&$@<')O9W)A;2!E9WD@;&5G]G)D_&SU"B`@("!M96[\8F5N(&9E;&OM;N%L
M:F$@82!L96AE=/5SZ6=E:V5T+"!E>F5K(&OV>OQL(&MI=N%L87-Z=&AA=&IU
M:R!A>G0L(`H@("`@86UE;'EI:W)E(&=O;F1O;'1U;FLN"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@($%M96YN>6EB96X@;65G:F5L96YI:R!A(")(96QY
M97/M<N%S96QL96[U<GKI<R(@<WKV=F5G+"!A:VMO<B!E<G)E(`H@("`@:V%T
M=&EN='9A(&5L;&5N]7)I>FAE=&K\:R!A(&WA<B!M96?M<G0@<WKV=F5G(&AE
M;'EE<^URX7/A="X@07H@"B`@("!E;&QE;O5R>NES(&%Z;VX@82!N>65L=F5N
M('3V<G3I;FEK+"!A;6EL>65N(&YY96QV96X@Z7!P96X@:&%S>F[A;&IU:R`*
M("`@(&$@;&5V96QE>NES="`H9F5L=.EV92P@:&]G>2!A(&OI<F3I<V5S(&YY
M96QV(&AE;'EE<^URX7-E;&QE;O5R>NESZ6AE>@H@("`@<WK\:W/I9V5S(.%L
M;&]MX6YY;VMA="!A(')E;F1S>F5R9V%Z9&$@=&5L97#M=&5T=&4@82!S>F5R
M=F5R<F4I+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!(")3<&5C:>%L
M:7,@:V%R86MT97)E:R(@<WKV=F5G<F4@:V%T=&EN='9A(&]L>6%N(&MA<F%K
M=&5R96ME="!I<R`*("`@(&)E[7)H871U;FL@82!KZ7-Z_&SU(&QE=NEL8F4L
M(&%M:6L@;FEN8W-E;F5K(&5G>65T;&5N(&)I;&QE;G1Y^VCV>B!S96T*("`@
M(&AO>GKA<F5N9&5L=F4N($$@:VEVX6QA<WIT;W1T(&MA<F%K=&5R96ME="`B
M8W5T(&%N9"!P87-T92(@;?-D<WIE<G)E;`H@("`@=FEH971J_&L@X70@82!L
M979E;&5T('1A<G1A;&UA>O,@86)L86MB82X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@02`B365L;.EK;&5T96LB('-Z]G9E9W)E(&MA='1I;G1V82!L
MX71H873S=N$@=N%L:6L@82!L97;I;.UR\R!A8FQA:R!A;&KA;B`*("`@(&QE
M=O4@<NES>BP@;65L>2!A(&UE;&SI:VQE=&5K(&-S871O;.%SX7)A('-Z;VQG
MX6PN($AA(&$@:^EP97)N>?4@96SI9R`*("`@(&YA9WD@86AH;WHL(&AO9WD@
M97H@82!RZ7-Z(&5R961E=&EL96<@:7,@;.%T:&%T\R!V;VQT+"!A:VMO<B!S
M96UM:2!S96T*("`@('3V<G3I;FEK+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("!!;65N;GEI8F5N(&$@(DUE;G1S_&YK(&5L(&5G>2!PZ6QDX6YY(&ET
M=#HB('-Z]G9E9R!K:2!V86X@<&EPX6QV82P@86MK;W(*("`@(&$@;&5VZ6P@
M96QK_&QDZ7-E:V]R(&5G>2!MX7-O;&%T(&ME<OQL(&$@:F5L>F5T="!M87!P
MX6)A("AA;&%PZ7)T96QM97IE='0*("`@(&5S971B96X@82`B4V5N="(@;6%P
M<&$I+B!%>B!N86=Y;VX@:&%S>FYO<R!L96AE="P@:&$@:^ES]6)B('9A;&%M
M:6QY96X@"B`@("!O:V+S;"!P;VYT;W-A;B!V:7-S>F$@86MA<FIU:R!I9.EZ
M;FDL(&AO9WD@;6ET(.UR='5N:RX@071T\VP@9OQG9_5E;BP@"B`@("!H;V=Y
M(&$@<WIE<G9E<F5N(&UE:VMO<F$@82!S>F5MZ6QY97,@<F5N9&5L:V5ZZ7/\
M;FMR92#A;&SS(&QE;65Z=&5R_&QE="`*("`@("CZ;BX@:W;S=&$I+"!D]FYT
M:&5T_&YK(/IG>2P@:&]G>2!M:6YD96X@96QK_&QD]G1T(&QE=F5L_&YK970@
M"B`@("!A<F-H:7;A;&IU:R!I;'D@;?-D;VX@*&5H:&5Z(&YA9WD@:W;S=&$@
M:V5L;"P@:_QL]F[V<V5N+"!H82!G>6%K<F%N(`H@("`@:_QL9/QN:R!M96QL
MZ6ML971E:V5T*2P@=F%G>2!C<V%K(&$@9F]N=&]S86)B86MA="X@02!K=O-T
M82!T96QJ97,@"B`@("!K:73V;'3I<V4@87IZ86P@:N%R+"!H;V=Y(&YE;2!T
M=61U;FL@^FH@;&5V96QE:V5T(&9O9V%D;FDA(-IJ(&%Z;VYO<^UT\VL*("`@
M(&SI=')E:&]ZX7/A=F%L("A/<&-I\VLM)F=T.U-Z96WI;'EE<R!A9&%T;VLM
M)F=T.T%Z(-9N(&%Z;VYO<^UT\VEN86L@;?-D;W/M=.%S82D*("`@(&)EX6QL
M[71H873S+"!H;V=Y('3V<G3I;FIE;BUE(&%U=&]M871I:W5S(&%R8VAI=N%L
MX7,L(.ES(&UE;'EI:R!M87!PX6)A(`H@("`@:V5R_&QJ96YE:R!A(&OI<F3I
M<V5S(&%Z;VYO<^UT\W9A;"#M<G0@;&5V96QE:RX@"B`@("`\+W!A<F$^"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B
M/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($]P=&EO;G,\+W1I
M=&QE/@H@("`@/&AE861I;F<^(D]P=&EO;G,B/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4:&5S92!/<'1I;VYS(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M
M97-S86=E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`B4W!E
M;&P@0VAE8VLB('1O(&-H96-K('EO=7(@<W!E;&QI;F<N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@($-L:6-K(")!='1A8VAM96YT<R(@=&\@9V\@=&\@
M=&AE(&)O='1O;2!O9B!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%T=&%C:"!F
M:6QE<R!T;R!T:&ES(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R`B4V%V92!C
M;W!Y(B!T;R!S879E(&$@8V]P>2!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&9O
M;&1E<B!Y;W4@<V5L96-T960@9F]R('1H:7,@<'5R<&]S92!U;F1E<B`B3W!T
M:6]N<RTF9W0[4&5R<V]N86P@26YF;W)M871I;VXM)F=T.TED96YT:71I97,B
M+B!%=F5N='5A;&QY('1H97)E(&ES(&%L<V\@82!D<F]P(&1O=VX@;&ES="!N
M97AT('1O('1H92!B=71T;VX@=VAE<F4@>6]U(&-A;B!S96QE8W0@86YO=&AE
M<B!F;VQD97(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-A=F4@8V]P
M:65S(&]F(&EM<&]R=&%N="!E;6%I;',@>6]U('-E;F0@<V\@=&AA="!Y;W4@
M:&%V92!S;VUE=&AI;F<@=&\@<F5F97(@8F%C:R!T;R!L871E<B!A;F0@=&\@
M:V5E<"!A;B!A8V-U<F%T92!R96-O<F0@;V8@=VAA="!W87,@<V%I9"X@5V4@
M9&\@;F]T(')E8V]M;65N9"!Y;W4@<V%V92!E=F5R>2!E;6%I;"!S:6YC92!T
M:&5N('EO=7(@9&ES:R!S=&]R86=E('%U;W1A('=I;&P@8F4@=7-E9"!U<"!Q
M=6EC:VQY("AE<W!E8VEA;&QY('=H96X@>6]U('-E;F0@871T86-H;65N=',I
M(&%N9"!Y;W5R(&UA:6QB;W@@=VEL;"!B92!F=6QL(&%N9"!U;F%B;&4@=&\@
M<F5C96EV92!N97<@:6YC;VUI;F<@96UA:6PN(%EO=2!C86XL(&AO=V5V97(L
M('1U<FX@=&AI<R!F96%T=7)E("=O;B<@87,@>6]U<B!D969A=6QT('=I=&AI
M;B!Y;W5R($ED96YT:71Y+"!B>2!G;VEN9R!T;R!/<'1I;VYS+29G=#M097)S
M;VYA;"!);F9O<FUA=&EO;BTF9W0[161I="!Y;W5R(&ED96YT:71I97,N($EN
M('EO=7(@;W!T:6]N<R!Y;W4@8V%N(&%L<V\@<V5T=7`@;6%I;G1E;F%N8V4@
M=&%S:W,@=&AA="!E;7!T>2!O<B!R96YA;64@=&AE<V4@9F]L9&5R<R!P97)I
M;V1I8V%L;'DN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](F-O;7!O<V4M871T86-H(B!S=&%T93TB=6YK;F]W;B(^"B`@
M("`\=&ET;&4^3&5VZ6SM<N%S.B!-96QLZ6ML971E:R!C<V%T;VSA<V$\+W1I
M=&QE/@H@("`@/&AE861I;F<^(DUE;&SI:VQE=&5K(&-S871O;.%S82(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($)I>F]N>6]S(&WI<F5T8F5L:2!K;W)L
MX71O>N%S;VMK86P@=6=Y86XL(&1E(&5L=FEL96<@8N%R;6EL>65N(&;A:FP@
M"B`@("!C<V%T;VQH873S(&$@;&5VZ6QH97HN"B`@("`\+W!A<F$^"B`@("`\
M<&%R83XQ+B!LZ7#I<SH*("`@(%9A9WD@[7)J82!B92!A(&-S871O;&%N9/,@
M9N%J;"!T96QJ97,@96SI<NES:2#Z='9O;F%LX70L('9A9WD@*&5Z(&$@"B`@
M("!B:7IT;W-A8F(I(&MA='1I;G1S;VX@82`B0G)O=W-E(B!G;VUB<F$@Z7,@
M=N%L87-S>F$@:VD@82!B]FYGZ7-Z]7!R;V=R86T*("`@('-E9^UT<^EGZ79E
M;"!A(&-S871O;&%N9/,@X6QL;VWA;GET+B!%;FYE:R!H873A<^%R82!M96=J
M96QE;FEK(&$@9N%J;`H@("`@;F5V92`H82!T96QJ97,@96SI<NES:2#Z='9O
M;F%L;&%L*2!A('-Z]G9E9V5S(&UE>O5B96XN($5K:V]R(&%Z;VYB86X*("`@
M(&$@8W-A=&]LX7,@;>EG($Y%32!T]G)TZ6YT(&UE9R$@16AH97H@82`R+B!L
MZ7#I<R!I<R!S>OQK<^EG97,N"B`@("`\+W!A<F$^"B`@("`\<&%R83XR+B!L
MZ7#I<SH*("`@($MA='1I;G1S;VX@82`B365L;.EK;&5T(&-S871O;.%S82(@
M9V]M8G)A+B!!(&;A:FP@;F5V92P@;>ER971E+"!-24U%('3M<'5S80H@("`@
M:&]Z>N%A9/-D:6L@82!M96QLZ6ML971E:R!L:7-TX6KA:&]Z+B#)<F1E;65S
M('1U9&YI+"!H;V=Y(&YA9WEMZ7)E=/L*("`@(.%L;&]MX6YY;VL@:6QL+B!L
M87-S^B!);G1E<FYE="!K87!C<V]L870@97-E=.EN(&$@9N%J;&YA:R!A('-Z
M97)V97)R90H@("`@=F%L\R!K_&QDZ7-E(.ES(&$@;&5VZ6QH97H@=F%L\R!C
M<V%T;VSA<V$@:&]S<WIA8F(@:63U="!I<R!I9^EN>6)E('9E:&5T+@H@("`@
M26QY96YK;W(@;&5G>65N('3\<F5L96UM96PL(&YE(&MA='1I;G1S;VX@<V5M
M;6ER92P@;>UG(&$@9N%J;"!M96<@;F5M"B`@("!J96QE;F5K(&$@8W-A=&]L
M="!M96QLZ6ML971E:R!L:7-TX6KA8F%N+@H@("`@/"]P87)A/@H\(2TM($5N
M9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B/@H@("`@
M/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SXB071T86-H(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M66]U(&UA>2!A='1A8V@@9FEL97,@=&\@>6]U<B!M97-S86=E(&EF('EO=7(@
M8G)O=W-E<B!S=7!P;W)T<R!U<&QO861I;F<@;V8@9FEL97,N($UO<F4@=&AA
M;B`Q(&9I;&4@8V%N(&)E('5P;&]A9&5D(&%T(&]N8V4N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83Y3=&5P(#$Z($5I=&AE<B!T>7!E('1H92!P871H(&%N9"!N
M86UE(&]F(&$@9FEL92!T:&%T('EO=2!W86YT(&%T=&%C:&5D('1O('1H:7,@
M;65S<V%G92!O<B!C;&EC:R`B0G)O=W-E(B!B=71T;VX@86YD('-E;&5C="!T
M:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N86UE(&]F
M('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N="!B;W@N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($1E8VED92!W:&5T:&5R
M('EO=2!W86YT('1H92!F:6QE('1O(&)E('9I97=E9"!A<R!A;B!A='1A8VAM
M96YT(&]R(&EN;&EN92!W:71H('1H92!R97-T(&]F('1H92!M97-S86=E+B!4
M:&4@<F5C96EV:6YG('!E<G-O;BAS*2!M86EL(')E861I;F<@<V]F='=A<F4@
M;75S="!B92!A8FQE('1O(&AA;F1L92!T:&4@9FEL92!T>7!E(&EN;&EN93L@
M:68@;F]T+"!T:&ES('!A<G0@=VEL;"!B92!V:65W960@87,@86X@871T86-H
M;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`S.B!#
M;&EC:R`B071T86-H(B!B=71T;VXN(%1H92!F:6QE(&YA;64H<RD@86YD('-I
M>F4H<RD@=VEL;"!B92!A9&1E9"!T;R!Y;W5R(&QI<W0@;V8@071T86-H;65N
M=',N(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S(&%N9"]O<B!S
M;&]W97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C97-S(&]F('5P
M;&]A9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T:&4@96UA:6P@
M;6%Y('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@86YD(&1O(&YO
M="!C;&EC:R!O=&AE<B!L:6YK<R]B=71T;VYS('=H:6QE('EO=2!A<F4@=V%I
M=&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/DQE=NEL[7+A<SH@365L;.EK;&5T96L\+W1I=&QE/@H@("`@
M/&AE861I;F<^(DUE;&SI:VQE=&5K(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@271T(&$@;&5VZ6QH97H@8W-A=&]L="!FX6IL;VL@;&ES=.%JX70@;.%T
M:G5K+B!%9WD@;>%R(&-S871O;'0@X6QL;VWA;GET"B`@("!A(&OV=F5T:V5Z
M]6OI<'!E;B!TX79O;.UT:&%T=6YK(&5L(&$@;&ES=.%B\VPZ"B`@("`\+W!A
M<F$^"B`@("`\<&%R83XQ+B!LZ7#I<SH@"B`@("!0:7#A;&IU:R!K:2!A>B!E
M;'3A=F]L[71A;F3S(.%L;&]MX6YY*&]K*6%T+@H@("`@/"]P87)A/B`*("`@
M(#QP87)A/C(N(&SI<.ES.B`*("`@($MA='1I;G1S=6YK(&$@(E9E9WG\:R!K
M:2!A(&MI:F5L]FQT970B('-Z]G9E9W)E+@H@("`@/"]P87)A/@H\(2TM($5N
M9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H;65N=',\
M+W1I=&QE/@H@("`@/&AE861I;F<^071T86-H;65N=',\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1H:7,@<V5C=&EO;B!D:7-P;&%Y<R!A(&QI<W0@;V8@
M9FEL97,@86QR96%D>2!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V4N"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4@871T86-H960@9FEL92AS*3PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&\@9&5L971E(&%N(&%T=&%C:&5D
M(&9I;&4H<RDZ"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-T97`@,3H@
M06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O('1H92!A='1A8VAE
M9"!F:6QE;F%M92AS*2!Y;W4@=V%N="!T;R!D96QE=&4N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@(%-T97`@,CH@0VQI8VL@(D1E;&5T92!!='1A8VAM
M96YT*',I(BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D-H86YG92!!='1A
M8VAM96YT($1I<W!O<VET:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M;R!C:&%N9V4@=&AE(&1I<W!O<VET:6]N(&9O<B!Y;W5R(&%T=&%C:&UE;G1S
M.@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3=&5P(#$Z($-H86YG92!E
M86-H(&%T=&%C:&UE;G0G<R!D:7-P;W-I=&EO;B`M(&5I=&AE<B`G:6YL:6YE
M)R!O<B`G871T86-H;65N="<@+2!T;R!T:&4@9&5S:7)E9"!V86QU92X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@4W1E<"`R.B!#;&EC:R`B57!D871E
M($%T=&%C:&UE;G0@26YF;W)M871I;VXB+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^0VAA;F=E($%T=&%C:&UE;G0@1&5S8W)I<'1I;VX\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1O(&-H86YG92!T:&4@9&5S8W)I<'1I;VX@9F]R
M('EO=7(@871T86-H;65N=',@*'1H92!T97AT('1H92!R96-I<&EE;G0@=VEL
M;"!S964@=&AA="!D97-C<FEB97,@=&AE(&%T=&%C:&UE;G0I.@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("!3=&5P(#$Z($5N=&5R(&$@9&5S8W)I<'1I
M;VX@:6YT;R!T:&4@1&5S8W)I<'1I;VX@9FEE;&0N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@(%-T97`@,CH@0VQI8VL@(E5P9&%T92!!='1A8VAM96YT
M($EN9F]R;6%T:6]N(BX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UP<FEO<FET>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@4')I;W)I='D\+W1I
M=&QE/@H@("`@/&AE861I;F<^4')I;W)I='D\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%1H:7,@<V5T<R!T:&4@(E@M4')I;W)I='DB(&AE861E<B!O;B!Y
M;W5R(&]U=&=O:6YG(&UE<W-A9V4N(%1H92`B6"U0<FEO<FET>2(@=&%G(&ES
M(&$@<V]R="!O9B`B<'-E=61O('-T86YD87)D(B!T:&%T($YE='-C87!E+"!-
M;WII;&QA+"!/<&5R82P@86YD($]U=&QO;VL@;6%I;"!C;&EE;G1S(&%P<&5A
M<B!T;R!A9W)E92!O;BX@06YY(&UA:6P@8VQI96YT<R!T:&%T(&1O(&YO="!H
M86YD;&4@=&AI<R!H96%D97(@=VEL;"!S:6UP;'D@:6=N;W)E(&ET+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US879E+6%T
M=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!3879E($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A
M/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y
M;W5R(&-O;7!O<VET:6]N(&%R92!S879E9"!W:71H('1H92!M97-S86=E('=H
M96X@<W1O<F5D(&EN('1H92!S96YT+6UA:6P@9F]L9&5R+B`@268@(EEE<R(L
M('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S879E9"X@($EF(").;R(L
M('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S=')I<'!E9"!F<F]M('1H
M92!M97-S86=E(&%F=&5R(&ET(&ES('-E;G0@=&\@86QL(')E8VEP:65N=',N
M("!#:&]O<VEN9R`B3F\B('=I;&P@:&5L<"!C;VYS97)V92!D:7-K('-P86-E
M(&)Y(')E;6]V:6YG("AP;W1E;G1I86QL>2!L87)G92D@871T86-H;65N="!I
M;F9O<FUA=&EO;B!F<F]M('1H92!S879E9"!M97-S86=E<RX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;&EN:RUA='1A8VAM
M96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@3&EN:R!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\<&%R83X*("`@
M($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@:6X@>6]U<B!C
M;VUP;W-I=&EO;B!A<F4@<V5N="!A<R!A('!A<G0@;V8@=&AE(&UA:6P@;65S
M<V%G92!O<B!W:&5T:&5R('1H;W-E(&%T=&%C:&UE;G1S(&%R92!K97!T(&]N
M(&$@;&]C86P@<V5R=F5R+B`@268@871T86-H;65N=',@87)E(&QI;FME9"P@
M=&AE(')E8VEP:65N="AS*2!O9B!Y;W5R(&UE<W-A9V4@=VEL;"!B92!P<F]V
M:61E9"!A('=E8FQI;FL@=VAE<F4@=&AE>2!C86X@9&]W;FQO860@=&AE(&%T
M=&%C:&UE;G0H<RDN("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA<R!T:&4@861V
M86YT86=E(&]F('1R96UE;F1O=7-L>2!R961U8VEN9R!T:&4@<VEZ92!O9B!O
M=71G;VEN9R!M97-S86=E<RX@($QI;FMI;F<@871T86-H;65N=',@:&%S('1H
M92!D:7-A9'9A;G1A9V4@=&AA="!T:&4@8V]N=&5N="!O9B!T:&4@871T86-H
M;65N=',@8V%N(&YO="!B92!G=6%R86YT965D('1O(&)E(&%V86EL86)L92!I
M;B!T:&4@9G5T=7)E('-I;F-E('1H92!A='1A8VAM96YT(&1A=&$@:7,@;F]T
M(&QO8V%T960@=VET:&EN('1H92!E+6UA:6P@;65S<V%G92X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-E87)C:"(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/DME<F5SZ7,@82!L979E;&5K(&OV>O9T=#PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY!(&ME<F5SZ7,@;?-D:F$\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($$@;&5V96QE:2!K]GKV='0@=/9B8F;I;&4@<WIE;7!O
M;G0@<WIE<FEN="!I<R!VZ6=E>FAE="!K97)E<^ES="X*("`@(#PO<&%R83X*
M("`@(#QP87)A/C$N(&SI<.ES.@H@("`@S7)J=6L@8F4@82!M96=F96QE;/4@
M;65Z]6)E(&$@:V5R97/I<VD@:W)I=.ER:75M;W0N($$@)T9E;&%D\R<L(`H@
M("`@)T/M;7IE='0G+"`G0V,G(&UE>O5K8F4@87H@96UA:6P@8^UM(&5G>2!R
MZ7-Z;&5T92!I<R#M<FAA=/,L(&$@=.%R9WD*("`@(&EL;"X@;&5VZ6QT]G)Z
M<R!RZ7-Z8F4@<&5D:6<@96=Y('-Z\R!V86=Y('-Z\W+I<WIL970@[7)H873S
M+B`*("`@(#PO<&%R83X*("`@(#QP87)A/C(N(&SI<.ES.B`*("`@($AA('-Z
M_&MSZ6=E<RP@861J82!M96<L(&AO9WD@;6EL>65N(&IE;'IE=/L@;&5V96QE
M:W)E(&OM=N%N:F$@82!K97)E<^ES=`H@("`@;&5S>OMK[71E;FDN"B`@("`\
M+W!A<F$^"B`@("`\<&%R83XS+B!LZ7#I<SH@"B`@("!!9&IA(&UE9RP@:&]G
M>2!M96QY:6L@;6%P<.%K<F$@:^UVX6YJ82!A(&ME<F5SZ7-T(&QE<WK[:^UT
M96YI+@H@("`@/"]P87)A/@H@("`@/'!A<F$^-"X@;.EPZ7,Z(`H@("`@2V%T
M=&EN='-O;B!A(")+97)E<^ES(B!G;VUB<F$N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@($%M96YN>6EB96X@97)E9&WI;GEE<R!V;VQT(&$@:V5R97/I
M<RP@82!T86SA;'0@;&5V96QE:R!TX7)G>6%I(`H@("`@:VEL:7-TX7KS9&YA
M:R!A(")+97)E<^ES(&5R961MZ6YY92(@8RX@86)L86MB86XN"B`@("`\+W!A
M<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)S96%R8V@B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG
M/E-E87)C:"!#<FET97)I83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U
M(&UA>2!S96%R8V@@9F]R(&UE<W-A9V5S(&9R;VT@>6]U<B!F;VQD97)S('5S
M:6YG(&1I9F9E<F5N="!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#$Z($5N=&5R('1E>'0@=&\@=&AE(&9I96QD<R!Y;W4@
M=V%N="!T;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83Y3=&5P(#(Z($-H;V]S92!T:&4@;65S<V%G92!F;&%G
M*',I('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@,SH@0VAO;W-E('1H92!F;VQD97(H<RD@9G)O
M;2!W:&EC:"!T;R!S96%R8V@@9F]R('1H92!M97-S86=E<RX*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@-#H@0VQI8VL@(E-E87)C:"(N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@($EF(&%N>2!M97-S86=E<R!M871C:&5D('EO
M=7(@<V5A<F-H(&-R:71E<FEA+"!T:&5N('1H92!S=6)J96-T<R!O9B!T:&5S
M92!M97-S86=E<R!W:6QL(&)E('-H;W=N(&EN('1H92`B4V5A<F-H(%)E<W5L
M=',B('9I97<N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](F9O;&1E<BUO<'1I;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@
M("`\=&ET;&4^36%P<.%K/"]T:71L93X*("`@(#QH96%D:6YG/DUA<'#A:VMA
M;"!VZ6=Z971T(&W[=F5L971E:SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M("!%;/5S>O9R(&IE;/9L:F4@:VD@82!M96=F96QE;/4@;6%P<.%K870L(&UA
M:F0@=N%L87-S>F$@:VD@82!L96?V<F3\;/4*("`@("`@;65N_&+U;"!A>B!A
M(&W[=F5L971E="P@86UI="!VZ6=R92!K[7;A;B!H86IT86YI+B`@("`*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@("!%;/5F;W)D=6QH870L(&AO9WD@
M=&]VX6)B:2!KZ7)DZ7-E:W)E(&ME;&P@;6%J9"!VX6QA<WIO;&YI82X*("`@
M("`@02!M87!PX6L@=/9R;.ESZ79E;"#I<F1E;65S(/-V871O<VYA:R!L96YN
M:2P@86UE;FYY:6)E;B!VZ6QE=&QE;OQL"B`@("`@(&MI=/9R]FP@96=Y(&UA
M<'#A="P@82!B96YN92!L97;U(/9S<WIE<R!L97;I;"!E;'9E<WII:R$*("`@
M(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F9O;&1E
M<BUO<'1I;VYS(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E;65N=#H@3W!T
M:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY&;VQD97(@3W!T:6]N<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("!9;W4@8V%N('-E;&5C="!A(&9O;&1E
M<B!B>2!U<VEN9R!T:&4@<F%D:6\@8G5T=&]N<R!A;&]N9R!T:&4@;&5F="!C
M;VQU;6XN("!/;F-E('EO=2!H879E(&1O;F4@=&AI<RP@<V5L96-T('1H92!O
M<'1I;VX@>6]U('=I<V@@=&\@<&5R9F]R;2!O;B!T:&4@9F]L9&5R('9I82!T
M:&4@<V5L96-T(&)O>"!T;R!T:&4@;&5F="X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@("!9;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@9G5R=&AE<B!O
M<'1I;VYS+B`@0F4@8V%R969U;"!W:71H('1H92!D96QE=&4@;W!T:6]N+"!A
M<R!Y;W4@8V%N(&QO<V4@86QL('1H92!M97-S86=E<R!I;B!A(&9O;&1E<B!I
M9B!Y;W4@9&5L971E(&ET(&)Y(&UI<W1A:V4A"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY);7!O<G0@;6)O>"!&:6QE/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("`@(%1H:7,@;W!T:6]N('=I;&P@:6UP;W)T(&$@;6)O>"!F;W)M870@
M9FEL92!I;G1O('1H92!F;VQD97(@;V8@>6]U<B!C:&]I8V4N($-H;V]S92`Q
M("AO;F4I(&9O;&1E<B!T;R!I;7!O<G0@=&AE(&UE<W-A9V5S(&EN=&\@86YD
M('1H96X@<V5L96-T('1H:7,@;W!T:6]N+B!9;W4@=VEL;"!T:&5N(&)E('1A
M:V5N('1O(&$@<&%G92!T:&%T('=I;&P@<')O;7!T(&9O<B!T:&4@;6)O>"!F
M:6QE('1O(&EM<&]R="X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9F]L9&5R+7=I9&=E=',B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M96YT.B!$:7-P;&%Y/"]T:71L93X*
M("`@(#QH96%D:6YG/E-H;W<O2&ED92!5;G-U8G-C<FEB960\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EF('5S:6YG($E-05`@9F]L9&5R('-U8G-C<FEP
M=&EO;G,L('-H;W<O:&ED92!T:&4@=6YS=6)S8W)I8F5D(&9O;&1E<G,N("!4
M;R!S=6)S8W)I8F4O=6YS=6)S8W)I8F4@=&\@82!F;VQD97(L('-E;&5C="!T
M:&4@8VAE8VMB;W@@;F5X="!T;R!T:&4@9F]L9&5R;F%M92!A;F0@=7-E('1H
M92!3=6)S8W)I8F4O56YS=6)S8W)I8F4@;W!T:6]N(&EN('1H92!&;VQD97(@
M06-T:6]N(&1R;W`M9&]W;B!M96YU+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^17AP86YD($%L;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17AP86YD
M(&%L;"!F;VQD97(@96YT<FEE<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/D-O;&QA<'-E($%L;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0V]L;&%P
M<V4@86QL(&9O;&1E<B!E;G1R:65S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I
M=&QE/E-Z^W+U:SH@06QK86QM87KA<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M('-Z^W+U:R!B96MA<&-S;VSA<V$\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($MA='1I;G1S;VX@82`B2V%P8W-O;&IU:R!B92!A('-Z^W+U:V5T.B(@:6MO
M;G)A("AE9WD@:VES"B`@("!T]FQC<^ER<WIE<OL@X6)R82DL(&UE;'D@87H@
M24Y"3U@@9F5L:7)A='3S;"#I<R!A(&9R:7-S[73I<VD@:6MO;G3S;"`*("`@
M(&IO8F)R82!T86SA;&AA=/,@87H@^FH@;&5V96QE:R#A='1E:VEN=/4@86)L
M86OA8F%N+B!%;FYE:R!H873A<^%R80H@("`@82!S>OMR]69E;'3I=&5L96MN
M96L@;65G9F5L96SU96X@82!B9>ER:V5Z971T(&QE=F5L96L@:_9Z_&P@82`*
M("`@(&MI<WK[<F5N9/4@;&5V96QE:R!T]G)L]61N96L@:6QL+B!MX7,@;6%P
M<.%B82!H96QY97KU9&YE:RX@"B`@("!%>B!N96T@=/9R=.EN:6L@;65G(&%U
M=&]M871I:W5S86XL(&AA8W-A:R!N96T@X6QL[71J=6L@8F4*("`@(&%Z($]P
M8VGS:RTF9W0[4WK[<O5K(&QE:&5T]7/I9V5K(&OV>O9T="X*("`@($$@<WK[
M<O5F96QTZ71E;&5K(&%K=&EVX6QH873S:R!A>B`*("`@($]P8VGS:RTF9W0[
M4WK[<O5K+29G=#M!('-Z^W+U9F5L=.ET96QE:R!M\V1O<^UTX7-A+29G=#O)
M<G;I;GEE<^UT<_QK(&%Z(`H@("`@]G-S>F5S('-Z86+A;'ET(&%L:V%L;6%Z
MX7/A=F%L(&ES+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB9FEL=&5R<R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@07!P;'D\
M+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B!T:&4@(D%P<&QY($9I;'1E
M<B(@:6-O;B!N97AT('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X
M('9I97<@=&\@9FEL=&5R(&%L;"!M97-S86=E<R!A8V-O<F1I;F<@=&\@=&AE
M('-P96-I9FEE9"!R=6QE<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M<G5L97,B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@1FEL=&5R(%)U;&5S/"]T
M:71L93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!&:6QT97(@4G5L97,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@9FEL
M=&5R(')U;&5S(B!T;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C
M86X@861D+"!D96QE=&4L(&%N9"!E9&ET('1H92!C=7)R96YT;'D@86-T:79E
M('-E="!O9B!F:6QT97(@<G5L97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)F:6QT97(M961I="UB;&%C:VQI<W0B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@0FQA8VML:7-T/"]T:71L93X*
M("`@(#QH96%D:6YG/D5D:70@66]U<B!";&%C:VQI<W0\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@8FQA8VML:7-T(B!T
M;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE
M=&4L(&%N9"!E9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U
M($%,5T%94R!R969U<V4@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M=VAI=&5L:7-T(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET(%=H:71E;&ES=#PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@5VAI=&5L:7-T/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R('=H:71E;&ES
M="(@=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@
M9&5L971E+"!A;F0@961I="!T:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S
M('EO=2!!3%=!65,@86-C97!T(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUO;BUL;V=I;B(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&]N($QO9VEN/"]T:71L
M93X*("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<R!5<&]N($QO9V]N
M/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@
M=&\@86QW87ES(&%P<&QY(&9I;'1E<G,@=VAE;B!F:7)S="!L;V=G:6YG(&]N
M=&\@24U0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL
M=&5R+6]N+61I<W!L87DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E
M<G,Z($9I;'1E<B!O;B!2969R97-H/"]T:71L93X*("`@(#QH96%D:6YG/D%P
M<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T
M;R!A;'=A>7,@87!P;'D@9FEL=&5R<R!W:&5N979E<B!Y;W5R('9I97<@=&AE
M($E.0D]8/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL
M=&5R+6%N>2UM86EL8F]X(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT
M97)S.B!&:6QT97(@86YY($UA:6QB;W@\+W1I=&QE/@H@("`@/&AE861I;F<^
M07!P;'D@9FEL=&5R(')U;&5S('1O(&%N>2!M86EL8F]X/SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@:68@>6]U('=A;G0@
M=&\@8F4@86QL;W=E9"!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA
M:6QB;W@N($YO<FUA;&QY+"!F:6QT97)I;F<@<G5L97,@87)E(&]N;'D@87!P
M;&EE9"!T;R!N97<@;6%I;"!T:&%T(&ES(&1E;&EV97)E9"!T;R!Y;W5R($E.
M0D]8+B`@268@=&AI<R!O<'1I;VX@:7,@8VAE8VME9"P@86X@:6-O;B!W:6QL
M(&%P<&5A<B!O;B!A;&P@;6%I;&)O>"!P86=G97,@=&AA="!W:6QL(&%L;&]W
M('EO=2!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@=&AE(&UE<W-A9V5S(&EN
M('1H92!C=7)R96YT(&UA:6QB;W@N("!.3U1%.B!&:6QT97)I;F<@:6X@;6%I
M;&)O>&5S(&]T:&5R('1H86X@24Y"3U@@;6%Y('!R;V1U8V4@<W1R86YG92`H
M92YG+B!T:&4@9FEL=&5R(&UA>2!C875S92!A(&-O<'D@;V8@;65S<V%G97,@
M=&\@8F4@9&5L:79E<F5D('1O('1H92!S86UE(&UA:6QB;W@I(&%N9"]O<B!U
M;F1E<VER960@<F5S=6QT<R`H92YG+B!I="!M87D@8V%U<V4@;65S<V%G97,@
M=&\@8F4@;6]V960O9&5L971E9"!I9B!N97<@9FEL=&5R:6YG(')U;&5S(&AA
M=F4@8F5E;B!I;7!L96UE;G1E9"!S:6YC92!T:&4@;65S<V%G92!H87,@8F5E
M;B!D96QI=F5R960@=&\@=&AE(&-U<G)E;G0@;6%I;&)O>"DN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M
M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($%T=&%C:"!0
M=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D%T=&%C:"!0=6)L:6,@
M2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N
M(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L
M('=I;&P@8F4@871T86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N("!9
M;W4@8V%N('-E="!T:&4@9&5F875L="!B96AA=FEO<B!V:6$@=&AE(%!'4"!/
M<'1I;VYS('-C<F5E;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UO<'1I;VXM<V-A;BUB;V1Y(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z(%-C86X@5&5X="!";V1I97,\+W1I=&QE/@H@("`@/&AE861I
M;F<^4V-A;B!497AT($)O9&EE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M268@<V5L96-T960@=&AE;B!)35`@=VEL;"!S8V%N('1H92!B;V1Y(&]F(&%L
M;"!T97AT(&UE<W-A9V5S(&9O<B!01U`@9&%T82P@86YD(&1I<W!L87D@=&AE
M(')E<W5L=',@:68@86YY(&1A=&$@:7,@9F]U;F0N("!.;W1E('1H870@=&AI
M<R!M87D@<VQO=R!D;W=N('1H92!S>7-T96T@87,@979E<GD@=&5X="!M97-S
M86=E(&UU<W0@8F4@<V-A;FYE9"!I;B!I=',@96YT:7)E='D@9F]R(%!'4"!D
M871A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UO<'1I;VYS+65N8W)Y<'0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D-O
M;7!O<V4Z($5N8W)Y<'1I;VX@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY.;R!%;F-R>7!T:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD
M('1H92!M97-S86=E('=I=&@@;F\@96YC<GEP=&EO;B`H8VQE87)T97AT*2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!%;F-R>7!T($UE<W-A9V4\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@96YC
M<GEP="!T:&4@8W5R<F5N="!M97-S86=E+"!U<VEN9R!01U`@86YD('1H92!R
M96-I<&EE;G1S('!E<G-O;F%L('!U8FQI8R!K97DL(&%N9"!T:&5N('-E;F0@
M:70N(%EO=2!C86X@;VYL>2!S96YD(&$@;65S<V%G92!T;R!A('-I;F=L92!P
M97)S;VX@=7-I;F<@=&AI<R!O<'1I;VXN(%EO=2!-55-4(&AA=F4@=&AE('!U
M8FQI8R!K97D@;V8@=&AE(')E8VEP:65N="!S=&]R960@:6X@>6]U<B!A9&1R
M97-S8F]O:R!O<B!E;'-E('1H:7,@;W!T:6]N('=I;&P@9F%I;"X@268@>6]U
M(&AA=F4@=&AE('!U8FQI8R!K97D@9F]R('1H92!R96-I<&EE;G0@:6X@>6]U
M<B!A9&1R97-S8F]O:R!A;F0@87)E('-T:6QL(')E8V5I=FEN9R!E<G)O<G,L
M('9E<FEF>2!T:&%T('1H92!E+6UA:6P@861D<F5S<R!I;B!T:&4@<F5C:7!I
M96YT(&9I96QD(&UA=&-H97,@=&AE(&4M;6%I;"!A9&1R97-S('=H97)E('1H
M92!P=6)L:6,@:V5Y(&ES('-T;W)E9"X@5&AE(&5N8W)Y<'1E9"!D871A('=I
M;&P@8F4@871T86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B!-97-S86=E/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL(&1I9VET86QL>2!S
M:6=N('1H92!C=7)R96YT(&UE<W-A9V4@=7-I;F<@4$=0(&%N9"!Y;W5R('!E
M<G-O;F%L('!R:79A=&4@:V5Y+B!)9B!Y;W4@:&%V92!N;W0@86QR96%D>2!E
M;G1E<F5D('1H92!P87-S<&AR87-E(&9O<B!Y;W5R('!R:79A=&4@:V5Y(&1U
M<FEN9R!T:&ES('-E<W-I;VX@>6]U('=I;&P@8F4@<')O;7!T960@9F]R(&ET
M+B`@5&AE(')E8V5I<&EE;G0@;75S="!H879E(&$@8V]P>2!O9B!Y;W5R('!U
M8FQI8R!K97D@=&\@9&EG:71A;&QY('9E<FEF>2!Y;W5R"B`@("!S:6=N871U
M<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B]%;F-R>7!T
M($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N
M('=I;&P@9FER<W0@9&EG:71A;&QY('-I9VX@>6]U<B!M97-S86=E(&%N9"!T
M:&5N('=I;&P@96YC<GEP="!T:&4@<F5S=6QT:6YG(&]U='!U="X@4V5E('1H
M92`G4$=0($5N8W)Y<'0@365S<V%G92<@86YD("=01U`@4VEG;B!-97-S86=E
M)R!E;G1R:65S(&9O<B!F=7)T:&5R(&EN9F]R;6%T:6]N+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^4R]-24U%($5N8W)Y<'0@365S<V%G93PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^4R]-24U%(%-I9VX@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^4R]-24U%(%-I9VXO
M16YC<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I
M97<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@3W9E<G9I97<\+W1I
M=&QE/@H@("`@/&AE861I;F<^5VAA="!I<R!01U`_/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!01U`@:7,@82!T;V]L(&9O<B!S96-U<F4@8V]M;75N:6-A
M=&EO;B!A;F0@9&%T82!S=&]R86=E+"!E<W!E8VEA;&QY(&9O<B!U<V4@=VET
M:"!E+6UA:6PN($ET(&-A;B!B92!U<V5D('1O(&5N8W)Y<'0@9&%T82!A;F0@
M=&\@8W)E871E(&1I9VET86P@<VEG;F%T=7)E<RX@24U0('5S97,@1VYU4$<@
M*$=.52!0<FEV86-Y($=U87)D*2!T;R!P<F]V:61E('1H:7,@9G5N8W1I;VYA
M;&ET>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!01U`@9G5N
M8W1I;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@
M;W!T:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&-R96%T
M92]V:65W('EO=7(@<&5R<V]N86P@4$=0(&ME>7,L(&%D9"]D96QE=&4@<'5B
M;&EC(&ME>7,@9G)O;2!O=&AE<B!I;F1I=FED=6%L<RP@<F5A9"!E;F-R>7!T
M960@;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N
M8W)Y<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C:"UP=6)K97DB
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@3W!T:6]N<R`M($%T=&%C
M:"!0=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D]P=&EO;G,@+2!!
M='1A8V@@4'5B;&EC($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M<V5L96-T960@=&AE;B!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@
M:68@:70@97AI<W1S+"!W:6QL(&)Y(&1E9F%U;'0@8F4@871T86-H960@=&\@
M86QL(&]U=&=O:6YG(&UE<W-A9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<&=P+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*("`@
M(#QH96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M:&ES('-C<F5E;B!L:7-T<R!A;&P@;V8@=&AE(&-U<G)E;G0@=7-E<G,@:6X@
M>6]U<B!A9&1R97-S8F]O:R!T:&%T(&AA=F4@4$=0('!U8FQI8R!K97ES+B!4
M:&5S92!U<V5R<R!A<F4@=&AE($].3%D@=7-E<G,@=&AA="!Y;W4@8V%N(&5I
M=&AE<B`Q*2!S96YD(&%N(&5N8W)Y<'1E9"!M97-S86=E('1O("U/4BT@,BD@
M=F5R:69Y(&$@9&EG:71A;"!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A
M('=I;F1O=R!T;R!V:65W('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!U8FQI
M8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($1E;&5T97,@=&AE('!U8FQI8R!K97D@9G)O
M;2!Y;W5R(&%D9')E<W-B;V]K+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+6EM<&]R="UP=6)K97DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES("T@26UP;W)T/"]T:71L
M93X*("`@(#QH96%D:6YG/DEM<&]R="!0=6)L:6,@2V5Y<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!O<&5N(&$@=VEN9&]W
M('=H97)E('EO=2!C86X@;6%N=6%L;'D@:6UP;W)T(&$@4$=0('!U8FQI8R!K
M97DN("!4:&4@:V5Y(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT
M9FEE;&0@;W(L(&EF('1H92!K97D@<F5S:61E<R!I;B!A(&9I;&4@;VX@>6]U
M<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@:70N("!)9B!T:&4@
M:V5Y(&ES('9A;&ED(&ET('=I;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R(&%D
M9')E<W-B;V]K(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V
M86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA
M:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<&=P+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES/"]T:71L93X*("`@(#QH
M96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!Y
M;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!M97-S86=E<R!O<B!E;F%B;&4@
M;W1H97)S('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M97-S86=E<RP@>6]U(&UU
M<W0@:&%V92!Y;W5R(&]W;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!01U`@
M:V5Y<&%I<BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4'5B;&EC
M($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U<B!P=6)L:6,@:V5Y
M('-H;W5L9"!B92!M861E(&%V86EL86)L92!T;R!A;GD@<&5R<V]N('1H870@
M>6]U('=A;G0@=&\@8F4@86)L92!T;R!S96YD('EO=2!E;F-R>7!T960@;65S
M<V%G97,@=&AA="!O;FQY(%E/52!C86X@9&5C<GEP="`H=7-I;F<@>6]U<B!P
M<FEV871E(&ME>2DN($%D9&ET:6]N86QL>2P@>6]U<B!P=6)L:6,@:V5Y(&YE
M961S('1O(&)E(&UA9&4@879A:6QA8FQE('1O(&%N>6)O9'D@>6]U('-E;F0@
M82!D9&EG:71A;&QY('-I9VYE9"!M97-S86=E('1O("T@=&AE('!U8FQI8R!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!D:6=I=&%L('-I9VYA='5R
M92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4')I=F%T92!+97D\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=7(@<')I=F%T92!K97D@:7,@
M;F5C97-S87)Y('1O(&1E8W)Y<'0@86YY(&UE<W-A9V4@96YC<GEP=&5D('5S
M:6YG('EO=7(@<'5B;&EC(&ME>2X@061D:71I;VYA;&QY+"!Y;W5R('!R:79A
M=&4@:V5Y(&ES(&YE961E9"!I9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG
M;B!A(&UE<W-A9V4N(%EO=7(@<')I=F%T92!K97D@=VEL;"!B92!P<F]T96-T
M960@=FEA(&$@<&%S<W!H<F%S92!C<F5A=&5D('=H96X@=&AE(&ME>7,@87)E
M(&=E;F5R871E9"X@5&AU<RP@=&\@<&5R9F]R;2!A;GD@86-T:79I='D@=&AA
M="!R97%U:7)E<R!Y;W5R('!R:79A=&4@:V5Y+"!)35`@=VEL;"!P<F]M<'0@
M>6]U(&9O<B!Y;W5R('!A<W-P:')A<V4N(%EO=2!O;FQY(&YE960@=&\@:6YS
M97)T('EO=7(@<&%S<W!H<F%S92!O;F-E('!E<B!S97-S:6]N("T@24U0('=I
M;&P@<W1O<F4@>6]U<B!P87-S<&AR87-E('5N=&EL('EO=2!L;V=O=70@*%-O
M(&)E('-U<F4@=&\@;&]G;W5T(2DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<'5B;&EC(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@4'5B
M;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@
M<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T86EL
M<R!A8F]U="!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T92(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y
M<R`M(%!R:79A=&4@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D5N=&5R(%!A
M<W-P:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS('1H92!P
M87-S<&AR87-E(&1I86QO9R!W:6YD;W<N(%1H92!P87-S<&AR87-E(&5N=&5R
M960L(&EF(&-O<G)E8W0L('=I;&P@8F4@<W1O<F5D(&)Y($E-4"!U;G1I;"!Y
M;W5R('-E<W-I;VX@96YD<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5N
M;&]A9"!087-S<&AR87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!296UO
M=F5S('1H92!S=&]R960@<&%S<W!H<F%S92!F<F]M($E-4"`M(&%N>2!A9&1I
M=&EO;F%L('5S86=E(&]F('1H92!P<FEV871E(&ME>2!W:6QL(')E<75I<F4@
M>6]U('1O(')E96YT97(@=&AE('!A<W-P:&5A<V4N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N
M<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@<')I=F%T92!K97DN($1/($Y/
M5"!314Y$(%1(25,@2T59(%1/($%.64].12`M('1H:7,@;W!T:6]N(&ES('-T
M<FEC=&QY('-O('1H870@>6]U(&-A;B!E>'!O<G0@>6]U<B!)35`@<&5R<V]N
M86P@<')I=F%T92!K97D@9F]R('5S92!I;B!A;F]T:&5R('!R;V=R86TN"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'
M4"!P<FEV871E(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UD96QE=&4B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!$96QE=&4\+W1I
M=&QE/@H@("`@/&AE861I;F<^1&5L971E(%!E<G-O;F%L($ME>7,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H:7,@8G5T=&]N('=I;&P@9&5L971E('EO
M=7(@<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<B!F<F]M($E-4"=S
M('!R969E<F5N8V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UN86UE(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!.86UE/"]T
M:71L93X*("`@(#QH96%D:6YG/DYA;64\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1H92!N86UE('EO=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N
M86P@:V5Y<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N
M="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N
M86P@2V5Y("T@0V]M;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY#;VUM96YT
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!(&-O;6UE;G0@<W1R:6YG('EO
M=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@:V5Y<RX@06X@;W!T
M:6]N86P@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM8W)E871E+65M86EL(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!%+6UA:6P@
M061D<F5S<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%+6UA:6P@061D<F5S<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&4M;6%I;"!A9&1R97-S('EO
M=2!W86YT(&%S<V]C:6%T960@=VET:"!Y;W5R('!E<G-O;F%L(&ME>7,N($$@
M<F5Q=6ER960@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@
M2V5Y;&5N9W1H/"]T:71L93X*("`@(#QH96%D:6YG/DME>6QE;F=T:#PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&ME>6QE;F=T:"P@:6X@8GET97,L
M(&]F('EO=7(@9V5N97)A=&5D(&ME>2X@5&AE(&=R96%T97(@=&AE('9A;'5E
M+"!T:&4@9W)E871E<B!T:&4@<')O=&5C=&EO;B`H86YD(&%L<V\@9W)E871E
M<B!G96YE<F%T:6]N('1I;64@86YD(&5N8W)Y<'1I;VX@=&EM92DN(#$P,C0@
M8GET97,@:7,@=&AE(&1E9F%U;'0@+2!T:&ES('9A;'5E('!R;W9I9&5S(&5X
M8V5L;&5N="!P<F]T96-T:6]N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UP87-S<&AR87-E(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+
M97D@+2!087-S<&AR87-E/"]T:71L93X*("`@(#QH96%D:6YG/E!A<W-P:')A
M<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!P87-S<&AR87-E('5S
M960@=&\@<')O=&5C="]E;F-R>7!T('EO=7(@<&5R<V]N86P@<')I=F%T92!K
M97DN(%1H:7,@<VAO=6QD(&)E($%4($Q%05-4(#8@8VAA<F%C=&5R<RP@<VAO
M=6QD($Y/5"!B92!T:&4@<V%M92!A<R!Y;W5R(&QO9VEN('!A<W-W;W)D+"!S
M:&]U;&0@3D]4(&)E(&)A<V5D(&]N(&$@9&EC=&EO;F%R>2!W;W)D+"!A;F0@
M<VAO=6QD(&EN8VQU9&4@8F]T:"!N=6UB97)S(&%N9"!L971T97)S+B!9;W4@
M;75S="!E;G1E<B!T:&ES('!A<W-P:')A<V4@='=I8V4@9F]R('9E<FEF:6-A
M=&EO;B!P=7)P;W-E<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M
M86-T:6]N<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@
M4&5R<V]N86P@2V5Y("T@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY#
M<F5A=&4@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0W)E871E(&%N
M9"!S=&]R92!Y;W5R('!E<G-O;F%L('!U8FQI8R]P<FEV871E(&ME>7!A:7(N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY);7!O<G0@2V5Y<&%I<CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@26UP;W)T(&$@<&5R<V]N86PO<')I=F%T
M92!K97EP86ER+B!4:&ES(&)U='1O;B!O<&5N<R!A('=I;F1O=R!W:&5R92!Y
M;W4@8V%N(&UA;G5A;&QY(&EM<&]R="!Y;W5R(&5X:7-T:6YG(%!'4"!P97)S
M;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER+B`@5&AE(&ME>7,@8V%N(&5I
M=&AE<B!B92!P87-T960@:6YT;R!A('1E>'1F:65L9"!O<BP@:68@=&AE(&ME
M>7,@<F5S:61E(&EN(&$@9FEL92!O;B!Y;W5R(&QO8V%L(&-O;7!U=&5R+"!Y
M;W4@8V%N(&EM<&]R="!T:&5M+B`@268@=&AE(&ME>7,@87)E('9A;&ED('1H
M97D@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD
M('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O
M<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE
M=R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!/=F5R=FEE=SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY7:&%T(&ES(%,O34E-13\\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%,O34E-12!I<R!A('!R:79A=&4O<'5B;&EC(&ME
M>2!P86ER('-Y<W1E;2!W:&EC:"!P<F]V:61E<R!D:6=I=&%L('-I9VYA='5R
M97,L(&UE<W-A9V4@<')I=F%C>2P@86YD('1A;7!E<B!D971E8W1I;VX@:6X@
M82!O<&5N+"!I;G1E<F]P97)A8FQE('=A>2X@(%,O34E-12!C86X@<')O=FED
M92!M97-S86=E('!R:79A8WD@8GD@96YC<GEP=&EN9R!M97-S86=E<R!T:&%T
M(&]N;'D@=&AE('-E;F1E<B!A;F0@=&AE(&EN=&5N9&5D(')E8VEP:65N=',@
M8V%N(&1E8V]D92X@($ET(&%L;&]W<R!Y;W4@=&\@:61E;G1I9GD@=&AE('-E
M;F1E<B!O9B!A(&UE<W-A9V4@=FEA(&$@9&EG:71A;"!S:6=N871U<F4N("!4
M;V=E=&AE<BP@=&AI<R!E;F-R>7!T:6]N(&%N9"!D:6=I=&%L('-I9VYI;F<@
M:&5L<"!P<F]V:61E('1A;7!E<B!D971E8W1I;VXL(&%L;&]W:6YG(')E8VEP
M:65N=',@=&\@9&5T97)M:6YE('=H971H97(@82!M97-S86=E('=A<R!A;'1E
M<F5D(&%F=&5R(&ET('=A<R!S96YT+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@268@=&AI<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W
M:6QL(&)E(&%B;&4@=&\@:6UP;W)T('EO=7(@<&5R<V]N86P@4R]-24U%(&ME
M>7,L(')E860@96YC<GEP=&5D(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG
M;F5D(&UA:6PL(&%N9"!E;F-R>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E
M<G9I97<M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O
M34E-13H@4&5R<V]N86P@2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R
M=FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@>6]U('=A;G0@=&\@
M9&EG:71A;&QY('-I9VX@;W(@96YC<GEP="!M97-S86=E<R!Y;W4@;75S="!H
M879E('EO=7(@;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%,O34E-12!K
M97EP86ER+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI
M;64M:6UP;W)T+7!E<G-O;F%L+6-E<G1S(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y3+TU)344Z($EM<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+W1I
M=&QE/@H@("`@/&AE861I;F<^26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@26UP;W)T('!E<G-O;F%L(&-E
M<G1I9FEC871E<R!F<F]M(&$@4$M#4R`C,3(@9F]R;6%T(&9I;&4N(%!+0U,@
M(S$R(&9I;&5S(&ES('1H92!F:6QE('5S=6%L;'D@9V5N97)A=&5D('=H96X@
M97AP;W)T:6YG(&$@:V5Y(&9R;VT@82!B<F]W<V5R("AE+F<N($EN=&5R;F5T
M($5X<&QO<F5R+"!&:7)E9F]X*2!O<B!F<F]M(&$@8V5R=&EF:6-A=&4@<W1O
M<F4@;6%I;G1A:6YE9"!B>2!A;B!/<&5R871I;F<@4WES=&5M("AE+F<N(%=I
M;F1O=W,@6%`I+B!)9B!T:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E
M(&EN<V5R=&5D(&EN=&\@>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O
M=R!W:6QL(&-L;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@
M=VEL;"!B92!R971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+61E;&5T92UP97)S;VYA;"UC
M97)T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!$96QE=&4@
M4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH96%D:6YG/D1E
M;&5T92!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($1E;&5T92!Y;W5R('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M
M('EO=7(@<')E9F5R96YC97,N("!9;W4@=VEL;"!N;R!L;VYG97(@8F4@86)L
M92!T;R!S:6=N(%,O34E-12!M97-S86=E<R!O<B!V:65W(&%N>2!3+TU)344@
M96YC<GEP=&5D(&UE<W-A9V5S(&%D9')E<W-E9"!T;R!Y;W4N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z($UA;F%G92!0=6)L
M:6,@2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3+TU)344Z($UA;F%G92!0
M=6)L:6,@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@36%N86=E('EO
M=7(@4R]-24U%('!U8FQI8R!K97D@;&ES="X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&AE
M(')A=R!T97AT(&]F('1H92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5FEE
M=R!T96-H;FEC86P@9&5T86EL<R!O9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@1&5L971E<R!T:&4@<V5L96-T960@<'5B;&EC(&ME>2!F<F]M('-T
M;W)A9V4N("!$96QE=&EN9R!A('!U8FQI8R!K97D@9F]R(&$@=7-E<B!W:6QL
M('!R979E;G0@>6]U<B!F<F]M(&5N8W)Y<'1I;F<@82!M97-S86=E('1O('1H
M870@=7-E<BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M:6YT:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<FEN=&EN9SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY0<FEN="!A(&UE<W-A9V4\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1O('!R:6YT(&$@;65S<V%G92!Y;W4@87)E('9I97=I
M;F<L(&-L:6-K(&]N('1H92`B4')I;G0B(&QI;FL@870@96ET:&5R('1H92!T
M;W`@;W(@8F]T=&]M(&]F('1H92!M97-S86=E+B!4:&4@;65S<V%G92!W:6QL
M(&]P96X@:6X@82!N97<@=VEN9&]W(&9O<FUA=&5D(&9O<B!P<FEN=&EN9RX@
M($1E<&5N9&EN9R!O;B!Y;W5R('=E8B!B<F]W<V5R(&%N9"!O<&5R871I;F<@
M<WES=&5M+"!T:&4@<')I;G0@9&EA;&]G(&)O>"!M87D@;W!E;B!F;W(@>6]U
M+B`@268@:70@9&]E<R!N;W0@;W!E;BP@=&AE;B!P=6QL(&1O=VX@=&AE('=E
M8B!B<F]W<V5R)W,@(D9I;&4B(&UE;G4@86YD(&-H;V]S92`B4')I;G0B('1O
M(&]P96X@=&AE('!R:6YT(&1I86QO9R!B;W@N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)S;W)T:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y3;W)T:6YG(&%N9"!4:')E861I;F<\+W1I=&QE/@H@("`@/&AE861I
M;F<^4V]R=&EN9R!%;G1R:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!7
M:&5N('9I97=I;F<@82!L:7-T(&]F(&UE<W-A9V5S+"!Y;W4@8V%N('-O<G0@
M=&AE(&UE<W-A9V5S(&)Y(&%N>2!C;VQU;6X@8GD@8VQI8VMI;F<@;VX@=&AE
M(&%P<')O<')I871E(&-O;'5M;B!H96%D:6YG+B`@5&\@<W=I=&-H(&-O;'5M
M;G,@8F5T=V5E;B!A<V-E;F1I;F<@86YD(&1E<V-E;F1I;F<@;W)D97(L(&-L
M:6-K(&]N('1H92!A<G)O=R!I8V]N(&EN('1H92!C;VQU;6X@:&5A9&EN9RX*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E1H<F5A9&EN9SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&\@9W)O=7`@;65S<V%G97,@8GD@=&AR96%D<R`H
M<W5B:F5C="DL('-O(&5A8V@@;65S<V%G92!I<R!G<F]U<&5D('=I=&@@86QL
M(&ET<R!R97!L:65S+"!C;&EC:R!T:&4@6U1H<F5A9%T@;&EN:R!I;B!T:&4@
M<W5B:F5C="!C;VQU;6X@:&5A9&EN9RX@(%1O(')E='5R;B!T;R!N;W)M86P@
M<W5B:F5C="!S;W)T:6YG+"!C;&EC:R!O;B!T:&4@6U-U8FIE8W1=(&QI;FL@
M:6X@=&AE('-U8FIE8W0@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)A;'1E<FYA=&EV92UM<V<B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/DUU;'1I<&%R="]!;'1E<FYA=&EV92!-97-S86=E
M<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-O;64@;65S<V%G92!H879E(&)E
M96X@<V5N="!A<R!A(")M=6QT:7!A<G0O86QT97)N871I=F4B('1Y<&4@8GD@
M=&AE('-E;F1E<BX@5&AE<V4@;65S<V%G97,@:&%V92!S979E<F%L('!A<G1S
M+"!A;&P@9&ES<&QA>6EN9R!T:&4@4T%-12!#3TY414Y4(&)U="!I;B!$249&
M15)%3E0@1D]234%44RX@5&AE(&UA:6P@86=E;G0@=VEL;"!D:7-P;&%Y('1H
M92!L87-T('!A<G0@:6X@=&AE(&QI<W0@=&AA="!C86X@8F4@<W5C8V5S<V9U
M;&QY(&1I<W!L87EE9"!I;FQI;F4@:6X@=&AE(&)R;W=S97(L(&EF(&%N>2X@
M06QL(&]T:&5R(&9O<FUA=',@=VEL;"!A<'!E87(@=6YD97(@=&AE(&AE861I
M;F<@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXB(&%N9"!C
M86X@8F4@=FEE=V5D(&]R(&1O=VYL;V%D960@<V5P87)A=&5L>2X@270@:7,@
M:6UP;W)T86YT('1O(&YO=&4@=&AA="!T:&5S92!A;'1E<FYA=&EV92!P87)T
M<R!C;VYT86EN('1H92!304U%($-/3E1%3E13(&%S('1H92!P87)T('1H870@
M:7,@<VAO=VX@+2!T:&5Y(&%R92!S:6UP;'D@:6X@82!D:69F97)E;G0@;65D
M:6$@9F]R;6%T("AE+F<N('1E>'0@=G,N($A434P@;W5T<'5T*2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7)E;F%M95]S96YT
M;6%I;%]M;VYT:&QY(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z(%)E;F%M92!396YT+6UA:6P@1F]L9&5R($UO
M;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N
M(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(')E;F%M92!Y;W5R('-E;G0M;6%I
M;"!F;VQD97(@870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H
M92!F;VQD97(@=VEL;"!B92!R96YA;65D("AT;R!A(&YA;64@=&AA="!C;VYT
M86EN<R!T:&4@;6]N=&@@86YD('EE87(I(&%N9"!A(&YE=R!S96YT+6UA:6P@
M9F]L9&5R('=I;&P@8F4@8W)E871E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z($1E;&5T92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L
M9"!L:6ME('1O(&1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@=&AE
M(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H:7,@;6%Y(&)E('5S969U
M;"!I9B!Y;W4@:&%V92!A('%U;W1A+"!F;W(@97AA;7!L92X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]S96YT;6%I
M;%]M;VYT:&QY7VME97`B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E(%-E;G0M;6%I;"!&;VQD97(@
M36]N=&AL>2`M(",@;V8@1F]L9&5R<R!T;R!+965P/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O;&0@<V5N="UM86EL(&9O
M;&1E<G,@979E<GD@;6]N=&@L(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@9F]L
M9&5R<R!D;R!Y;W4@('=A;G0@=&\@:V5E<#\@($%N>2!F;VQD97)S(&]L9&5R
M('1H86X@=&AI<R!M86YY(&UO;G1H<R!W:6QL(&)E(&1E;&5T960N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T
M86-H;65N='-?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE
M;G1S($UO;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@
M;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(&1E;&5T92!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N
M=&@N("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@
M9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL>5]K965P(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($1E;&5T92!,:6YK960@071T86-H;65N=',@36]N=&AL>2`M(",@;V8@36]N
M=&AS('1O($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E
M(&1E;&5T:6YG(&]L9"!L:6YK960@871T86-H;65N=',@979E<GD@;6]N=&@L
M(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@871T86-H;65N=',@9&\@>6]U("!W
M86YT('1O(&ME97`_("!!;GD@871T86-H;65N=',@;VQD97(@=&AA;B!T:&ES
M(&UA;GD@;6]N=&AS('=I;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U
M<F=E(%1R87-H/"]T:71L93X*("`@(#QP87)A/@H@("`@1&\@>6]U('=A;G0@
M=&\@<'5R9V4@>6]U<B!T<F%S:"!F;VQD97(@979E<GD@<V\@;V9T96XN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T
M<F%S:%]I;G1E<G9A;"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:"!);G1E<G9A;#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@<'5R9VEN9R!Y;W5R('1R
M87-H(&9O;&1E<BP@:&]W(&]F=&5N('-H;W5L9"!I="!B92!P=7)G960_"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T
M<F%S:%]K965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@36%I;G1E;F%N8V4Z(%!U<F=E(%1R87-H($ME97`\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD
M97(L(&UE<W-A9V4@;VQD97(@=&AA;B!H;W<@;6%N>2!D87ES('-H;W5L9"!B
M92!P=7)G960_"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUA='1R:6)?=&5X="(@<W1A=&4](FYE=R(^"B`@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-97-S86=E($-O;7!O<VET:6]N.B!!='1R:6)U=&EO;B!4
M97AT/"]T:71L93X*("`@("`\<&%R83X*("`@("!(97)E('EO=2!C86X@96YT
M97(@=&AE('!H<F%S92!T:&%T('EO=2!W:7-H('1O(&%P<&5A<B!B969O<F4@
M86YY('%U;W1E9"!T97AT(&EN(&$@<F5P;'D@=&AA="!Y;W4@<V5N9"X*("`@
M("`\+W!A<F$^"B`@("`@/'!A<F$^"B`@("`@66]U(&-A;B!I;F-L=61E(&]N
M92!O<B!M;W)E('-P96-I86P@<&QA8V5H;VQD97)S('1O(&EN<V5R="!I;F9O
M<FUA=&EO;B!A8F]U="!T:&4@;65S<V%G92!T;R!W:&EC:"!Y;W4@87)E(')E
M<&QY:6YG+B!0;&%C96AO;&1E<G,@8V]N<VES="!O9B!A("<E)R!F;VQL;W=E
M9"!B>2!A('-I;F=L92!L971T97(N(%1H92!F;VQL;W=I;F<@<&QA8V5H;VQD
M97)S(&%R92!A=F%I;&%B;&4Z"B`@("`@/"]P87)A/@H*("`@("`\<&%R83X@
M)68@.B!4:&4@<V5N9&5R)W,@;F%M92!A;F0@96UA:6P@861D<F5S<SPO<&%R
M83X*("`@("`\<&%R83X@)6$@.B!4:&4@<V5N9&5R)W,@96UA:6P@861D<F5S
M<SPO<&%R83X*("`@("`\<&%R83X@)7`@.B!4:&4@<V5N9&5R)W,@;F%M93PO
M<&%R83X*("`@("`\<&%R83X@)7(@.B!4:&4@9G5L;"!21D,@,C@R,B!S='EL
M92!D871E(&%N9"!T:6UE('IO;F4\+W!A<F$^"B`@("`@/'!A<F$^("5D(#H@
M5&AE(&1A=&4@87,@=W=W+"!D9"!M;6T@65E963PO<&%R83X*("`@("`\<&%R
M83X@)7@@.B!4:&4@9&%T92!I;B!T:&4@;&]C86QE)W,@9&5F875L=#PO<&%R
M83X*("`@("`\<&%R83X@)6,@.B!4:&4@9&%T92!A;F0@=&EM92!I;B!T:&4@
M;&]C86QE)W,@9&5F875L=#PO<&%R83X*("`@("`\<&%R83X@)6T@.B!4:&4@
M365S<V%G92U)1#PO<&%R83X*("`@("`\<&%R83X@)7,@.B!4:&4@<W5B:F5C
M=#PO<&%R83X*("`@("`\<&%R83X@)6X@.B!!(&YE=R!L:6YE/"]P87)A/@H@
M("`@(#QP87)A/B`E)2`Z(%1H92`G)2<@8VAA<F%C=&5R/"]P87)A/@H*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?
M<F5A9"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E
M<75E<W0@4F5A9"!296-E:7!T<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(")2
M97%U97-T(&$@4F5A9"!296-E:7!T(B!S96YD<R!A(')E<75E<W0@=&\@=&AE
M(')E8VEP:65N=',@;V8@=&AI<R!M97-S86=E('1O(&YO=&EF>2!Y;W4@=VAE
M;B!T:&ES(&UE<W-A9V4@:7,@;W!E;F5D(&)Y('1H92!R96-I<&EE;G1S+B!.
M;W0@86QL(&-L:65N=',@<W5P<&]R="`O(&AO;F]R('1H:7,N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S
M96YD7VUD;B(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M(%-E;F0@341./"]T:71L93X*("`@(#QP87)A/@H@("`@(E-E;F0@82!-1$XB
M('-E;F1S(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@*&%L
M<V\@:VYO=VX@87,@82!R96%D(')E8V5I<'0I('=H96X@>6]U('9I97<@82!M
M97-S86=E(&EN('=H:6-H('1H92!U<V5R(&AA<R!R97%U97-T960@=&AA="!T
M:&5Y(')E8V5I=F4@;F]T:69I8V%T:6]N('1H870@>6]U(&AA=F4@<F5A9"!T
M:&4@;65S<V%G92X@26X@;6]S="!C87-E<RP@=&AI<R!W:6QL(&AA<'!E;B!A
M=71O;6%T:6-A;&QY('=I=&AO=70@<')O;7!T:6YG('EO=2X@26X@8V5R=&%I
M;B!I<V]L871E9"!C87-E<RP@>6]U(&UA>2!H879E('1O(&UA;G5A;&QY(&1E
M8VED92!T;R!S96YD('1H92!N;W1I9FEC871I;VX@8GD@8VQI8VMI;F<@;VX@
M82!L:6YK+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]D96QI=F5R>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E<75E<W0@1&5L:79E<GD@0V]N
M9FER;6%T:6]N/"]T:71L93X*("`@(#QP87)A/@H@("`@(E)E<75E<W0@1&5L
M:79E<GD@0V]N9FER;6%T:6]N(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!S97)V97(@=&\@;F]T:69Y('EO=2!W:&5N(&ET
M(&AA<R!D96QI=F5R960@=&AE(&UE<W-A9V4@=&\@=&AE(')E8VEP:65N="=S
M(&UA:6QB;W@N($ET(&1O97-N)W0@;65A;B!T:&4@;65S<V%G92!H87,@8F5E
M;B!S965N+"!J=7-T('1H870@:70G<R!S:71T:6YG(&EN(&$@;6%I;&)O>"!S
M;VUE=VAE<F4N($YO="!A;&P@;6%I;"!S97)V97)S('-U<'!O<G0@=&AI<RX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T
M95]S<&%M7V%F=&5R7W)E<&]R="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($1E;&5T92!3<&%M($%F=&5R(%)E<&]R=&EN9SPO=&ET
M;&4^"B`@("`\<&%R83X*("`@(%EO=2!M87D@96QE8W0@=&\@9&\@;VYE(&]F
M('1H<F5E(&ET96US(&%F=&5R(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@96ET
M:&5R('-P86T@;W(@:6YN;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@($9I<G-T+"!Y;W4@8V%N(&1E8VED92!T;R!D;R!N;W1H:6YG("T@=&AE
M(&UE<W-A9V4@=VEL;"!B92!R97!O<G1E9"!A<R!E:71H97(@<W!A;2!O<B!I
M;FYO8V5N="!B=70@=VEL;"!O=&AE<G=I<V4@<F5M86EN('5N8VAA;F=E9"!I
M;B!Y;W5R(&UA:6QB;W@N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-E
M8V]N9"P@:68@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!S<&%M+"!Y;W4@8V%N
M(&EN<W1E860@:&%V92!T:&4@;65S<V%G92!B92!I;6UE9&EA=&5L>2!D96QE
M=&5D+B`@5&AI<R!S971T:6YG(&AA<R!N;R!E9F9E8W0@;VX@<F5P;W)T:6YG
M(&$@;65S<V%G92!A<R!I;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@5&AI<F0L(&%F=&5R(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@<W!A
M;2!T:&4@;65S<V%G92!W:6QL(&)E(&1E;&5T960@9G)O;2!T:&4@8W5R<F5N
M="!M86EL8F]X(&%N9"!M;W9E9"!T;R!Y;W5R('-P86T@9F]L9&5R+B`@06QT
M97)N871I=F5L>2P@:68@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I;FYO8V5N
M="!T:&4@;65S<V%G92!W:6QL(&)E(&1E;&5T960@9G)O;2!T:&4@8W5R<F5N
M="!M86EL8F]X(&%N9"!M;W9E9"!T;R!Y;W5R($E.0D]8+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]R97!L
M86-E;65N="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M($A434P@26UA9V4@4F5P;&%C96UE;G0\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!&;W(@2%1-3"!M97-S86=E<R!D:7-P;&%Y960@:6YL:6YE+"!S:&]U;&0@
M86QL(&EM86=E('1A9W,@8F4@8FQO8VME9"!U;G1I;"!Y;W4@<W!E8VEF:6-A
M;&QY(&1E8VED92!T;R!V:65W('1H;W-E(&EM86=E<S\@3F]T92!T:&%T+"!I
M9B!V:65W:6YG(&%N($A434P@871T86-H;65N="P@=&AE(&EM86=E<R!W:6QL
M(&%L=V%Y<R!B92!D:7-P;&%Y960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUH=&UL7VEM86=E7V%D9')B;V]K(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G92!297!L
M86-E;65N="]!9&1R97-S8F]O:R!3:&]W/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@8FQO8VMI;F<@:6UA9V5S(&9O<B!I;FQI;F4@2%1-3"!M97-S86=E
M<RP@<VAO=6QD('=E(&%U=&]M871I8V%L;'D@9&ES<&QA>2!T:&5M(&EN<W1E
M860@:68@=&AE('-E;F1E<B!A<'!E87)S(&EN('EO=7(@861D<F5S<V)O;VL_
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUM86EL
M8F]X7W-T87)T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@36%I;&)O>"!3=&%R="!086=E/"]T:71L93X*("`@(#QP87)A/@H@("`@
M1&5T97)M:6YE<R!W:&EC:"!P86=E(&EN('1H92!M86EL8F]X('9I97<@=VEL
M;"!B92!D:7-P;&%Y960@=VAE;B!Y;W4@86-C97-S(&$@;6%I;&)O>"!F;W(@
M=&AE(&9I<G-T('1I;64N($YO=&4@=&AA="!T:&4@)W5N<V5E;B<@;65S<V%G
M92!O<'1I;VYS(&1O(&YO="!W;W)K('=I=&@@=&AE("=4:')E860G('-O<G1I
M;F<@;W!T:6]N("T@:6YS=&5A9"P@>6]U('=I;&P@8F4@<V5N="!T;R!T:&4@
M;&%S="!P86=E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M<V%V95]A='1A8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4')E9F5R96YC97,Z(%-A=F4@071T86-H;65N=',@;VX@4V5N="!-97-S
M86=E<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('-A=FEN9R!A(&-O;7!O
M<V5D(&UE<W-A9V4@:6X@82!S96YT+6UA:6P@9F]L9&5R+"!D971E<FUI;F4@
M:68@86QL(&%T=&%C:&UE;G0@9&%T82!I<R!S879E9"X@5&AE(&9O;&QO=VEN
M9R!O<'1I;VYS(&%R92!A=F%I;&%B;&4Z"B`@("`\+W!A<F$^"@H@("`@/'!A
M<F$^*B`B06QW87ES('-A=F4@871T86-H;65N=',B("T@3D5615(@<')O;7!T
M('1O('-A=F4@871T86-H;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A
M='1A8VAM96YT<R!A<F4@04Q705E3('-A=F5D('=I=&@@=&AE(&UE<W-A9V4N
M/"]P87)A/@H@("`@(#QP87)A/BH@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T
M=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B("T@04Q705E3('!R
M;VUP="!T;R!S879E(&%T=&%C:&UE;G1S(&EN('1H92!C;VUP;W-E('-C<F5E
M;CL@=&AE(&1E9F%U;'0@:7,@=&\@<V%V92!A='1A8VAM96YT<RX\+W!A<F$^
M"B`@("`@/'!A<F$^*B`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N
M="!I<R!S96YT.R!D969A=6QT('1O($Y/(B`M($%,5T%94R!P<F]M<'0@=&\@
M<V%V92!A='1A8VAM96YT<R!I;B!T:&4@8V]M<&]S92!S8W)E96X[('1H92!D
M969A=6QT(&ES('1O(&YO="!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@
M("`\<&%R83XJ(").979E<B!S879E(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R
M;VUP="!T;R!S879E(&%T=&%C:&UE;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T
M:&4@871T86-H;65N=',@87)E($Y%5D52('-A=F5D('=I=&@@=&AE(&UE<W-A
M9V4N/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]I;F)O
M>"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6
M:7)T=6%L($EN8F]X/"]T:71L93X*("`@(#QP87)A/@H@("`@5FER=71A;"!)
M;F)O>"!I<R!A('-A=F5D('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H
M92!N965D('1O('-E87)C:"!E=F5R>2!M86EL8F]X(&9O<B!M97-S86=E<R!M
M87)K960@87,@;F5W+B`@26YS=&5A9"P@86QL(&-U<G)E;G1L>2!S=6)S8W)I
M8F5D(&UA:6QB;WAE<R!A<F4@<V5A<F-H960@9F]R(&YE=R!M97-S86=E<R!A
M;F0@=&AE(')E<W5L=',@87)E(&1I<W!L87EE9"!I;B!A('-I;F=L92!M86EL
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A
M;%]T<F%S:"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^5FER='5A;"!&;VQD
M97)S.B!6:7)T=6%L(%1R87-H/"]T:71L93X*("`@(#QP87)A/@H@("`@5FER
M='5A;"!4<F%S:"!I<R!A('-A=F5D('-E87)C:"!T:&%T(&1O97,@87=A>2!W
M:71H('1H92!N965D(&9O<B!A('-E<&%R871E(%1R87-H(&9O;&1E<BX@($EN
M<W1E860@;V8@;6]V:6YG(&UE<W-A9V5S('1O(&$@8V5N=')A;&EZ960@=')A
M<V@@9F]L9&5R+"!M97-S86=E<R!A<F4@<VEM<&QY(&UA<FME9"!A<R!D96QE
M=&5D(&EN('1H92!C=7)R96YT(&9O;&1E<B!T:&5Y(&QI=F4@:6XN("!7:&5N
M("=S:&]W(&1E;&5T960@;65S<V%G97,G(&ES('1U<FYE9"!O9F8L('1H:7,@
M<F5S=6QT<R!I;B!T:&5S92!M97-S86=E<R!N;W0@87!P96%R:6YG(&EN(&$@
M;6%I;&)O>"!V:65W+B`@5VAE;B!A('5S97(@8VQI8VMS(&]N(%9I<G1U86P@
M5')A<V@L("IA;&PJ(&UA:6QB;WAE<R!A;&P@<V5A<F-H960@9F]R(&UE<W-A
M9V5S('1H870@87)E(&9L86=G960@9&5L971E9"!A;F0@=&AE<V4@;65S<V%G
M97,@87)E(&1I<W!L87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM
M<"]L;V-A;&4O:F%?2E`O````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#$W-#,T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]J85]*4"],0U]-15-304=%4R\`
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V
M,P`P,C$R,C$`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VIA
M7TI0+TQ#7TU%4U-!1T53+VEM<"YM;P``````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,S,R-3(Q`#$P-#$W,S8R-S8S`#`R,C,T-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````.0%```<````/"\``-L'
M``!<7@```````,A]```*````R7T```H```#4?0``"@```-]]```.````ZGT`
M``@```#Y?0``#`````)^```*````#WX```0````:?@```0```!]^``!(````
M(7X``"L```!J?@``1````)9^```G````VWX``!<````#?P``"P```!M_```.
M````)W\``"@````V?P``"@```%]_```5````:G\``!(```"`?P``,@```)-_
M```I````QG\``#(```#P?P``$````".````4````-(```!````!)@```)@``
M`%J````G````@8```"8```"I@```'````-"````.````[8````H```#\@```
M#0````>!```G````%8$``"`````]@0``%P```%Z!```B````=H$``#4```"9
M@0``$0```,^!```-````X8$```P```#O@0``#0```/R!```;````"H(``"X`
M```F@@``-P```%6"``!\````C8(``&P````*@P``'````'>#```=````E(,`
M``P```"R@P``10```+^#```H````!80``$$````NA```)````'"$```.````
ME80```\```"DA```#@```+2$```.````PX0```@```#2A```#@```-N$```.
M````ZH0``"X```#YA```&@```"B%```S````0X4``#(```!WA0``.````*J%
M``!4````XX4``%$````XA@``6@```(J&``!7````Y88``#0````]AP``!0``
M`'*'```1````>(<```X```"*AP``"````)F'```E````HH<``"````#(AP``
M$````.F'```/````^H<```\````*B```!P```!J(```#````(H@```\````F
MB```%````#:(```)````2X@```T```!5B```$@```&.(```/````=H@```H`
M``"&B```#P```)&(```(````H8@``"0```"JB```%P```,^(```4````YX@`
M`!8```#\B```"````!.)```<````'(D``!D````YB0``!P```%.)```,````
M6XD```T```!HB0``#@```':)```#````A8D```4```")B0```P```(^)```7
M````DXD```H```"KB0``#P```+:)``!.````QHD``%`````5B@``0P```&:*
M``!"````JHH``#````#MB@``(P```!Z+```.````0HL``!0```!1BP``%P``
M`&:+```7````?HL``!<```"6BP``$P```*Z+```&````PHL``!<```#)BP``
M40```.&+```?````,XP``#4```!3C```#P```(F,```(````F8P``!$```"B
MC```"P```+2,```5````P(P``",```#6C```+P```/J,```'````*HT```4`
M```RC0``$0```#B-```,````2HT``#````!7C0``2````(B-```A````T8T`
M`#L```#SC0``.P```"^.```\````:XX``"L```"HC@``,0```-2.```[````
M!H\``#D```!"CP``-0```'R/```,````LH\```D```"_CP```P```,F/```Y
M````S8\```8````'D```#`````Z0```U````&Y````X```!1D```20```&"0
M```S````JI````H```#>D```+0```.F0```+````%Y$``"<````CD0``+```
M`$N1```J````>)$``"4```"CD0``"0```,F1```)````TY$```H```#=D0``
M!@```.B1```O````[Y$``#<````?D@``+@```%>2``!5````AI(``"T```#<
MD@``+`````J3```M````-Y,``"T```!EDP``0````).3```C````U),``",`
M``#XDP``+0```!R4```S````2I0``!4```!^E```&0```)24```I````KI0`
M`"0```#8E```4````/V4```8````3I4``!$```!GE0``$0```'F5```+````
MBY4```H```"7E0``"@```**5```0````K94``!8```"^E0``%@```-65```#
M````[)4```@```#PE0``"0```/F5```*`````Y8``$4````.E@``!````%26
M```$````698```D```!>E@``!@```&B6```1````;Y8```<```"!E@``!```
M`(F6```G````CI8```T```"VE@```P```,26```#````R)8``!<```#,E@``
M"````.26```(````[98``"H```#VE@``*P```"&7```@````39<```8```!N
MEP``#@```'67```5````A)<``#X```":EP``&````-F7```B````\I<``!T`
M```5F```(0```#.8``!4````59@``"D```"JF```!P```-28```5````W)@`
M``(```#RF```"@```/68```/`````)D```T````0F0``#P```!Z9```-````
M+ID```D````\F0``!@```$:9```3````39D``!0```!AF0``#````':9```&
M````@YD```H```"*F0``#0```)69``!B````HYD``"<````&F@``5````"Z:
M``!?````@YH``!8```#CF@``'````/J:```S````%YL``"@```!+FP``#@``
M`'2;```5````@YL``!$```"9FP``$0```*N;```1````O9L``!P```#/FP``
M-0```.R;``!%````(IP``"$```!HG```$@```(J<```*````G9P``$<```"H
MG```'P```/"<```E````$)T``#,````VG0``*P```&J=```=````EIT``%$`
M``"TG0``$0````:>```Q````&)X``#L```!*G@``0````(:>```X````QYX`
M``4`````GP``#`````:?```1````$Y\```T````EGP``"````#.?```,````
M/)\``!0```!)GP``#P```%Z?```%````;I\```P```!TGP``$````(&?```%
M````DI\```T```"8GP``!@```*:?```'````K9\```T```"UGP``!P```,.?
M```+````RY\```<```#7GP``"0```-^?```7````Z9\``"8````!H```3P``
M`"B@```9````>*````P```"2H```)0```)^@```?````Q:```!````#EH```
M$@```/:@```K````":$``#L````UH0``(````'&A```;````DJ$``#8```"N
MH0``&P```.6A```>`````:(``%P````@H@``+@```'VB```$````K*(```X`
M``"QH@``#@```,"B```'````SZ(```X```#7H@``'@```.:B```;````!:,`
M`"$````AHP``'@```$.C```9````8J,``!X```!\HP``&P```)NC```F````
MMZ,``!L```#>HP``'@```/JC```<````&:0``"8````VI```-@```%VD```S
M````E*0``"D```#(I```00```/*D```Z````-*4``"8```!OI0``*P```):E
M```X````PJ4``"\```#[I0``$@```"NF```I````/J8``!(```!HI@``(P``
M`'NF```H````GZ8``"D```#(I@``'P```/*F```@````$J<``"4````SIP``
M(0```%FG```<````>Z<``"8```"8IP``00```+^G```'`````:@```8````)
MJ```#0```!"H```5````'J@``!H````TJ```$````$^H```=````8*@``!D`
M``!^J```70```)BH```2````]J@``!,````)J0``$@```!VI```,````,*D`
M`#D````]J0``'````'>I```H````E*D```,```"]J0``#0```,&I```"````
MSZD```4```#2J0``!0```-BI```0````WJD```0```#OJ0``#0```/2I```.
M`````JH```@````1J@``#P```!JJ```(````*JH```\````SJ@``#0```$.J
M```0````4:H``!D```!BJ@``&@```'RJ```)````EZH```8```"AJ@``$```
M`*BJ```,````N:H``!$```#&J@``%0```-BJ```+````[JH```T```#ZJ@``
M(@````BK```K````*ZL``!<```!7JP``-````&^K```S````I*L```H```#8
MJP``&````..K```9````_*L``!8````6K```!P```"VL```0````-:P``!P`
M``!&K```'````&.L```-````@*P```P```".K```)@```)NL```*````PJP`
M`!0```#-K```"P```.*L```O````[JP```L````>K0``#P```"JM```7````
M.JT``!<```!2K0``!P```&JM```6````<JT```\```")K0``+0```)FM```:
M````QZT``"@```#BK0``"P````NN```,````%ZX``",````DK@``#0```$BN
M```F````5JX``"H```!]K@``(````*BN``!#````R:X```0````-KP``"```
M`!*O```+````&Z\``!H````GKP``)P```$*O```2````:J\``"````!]KP``
M+P```)ZO```7````SJ\```4```#FKP``#````.RO```.````^:\```8````(
ML```#@````^P```$````'K````X````CL```"@```#*P```,````/;````H`
M``!*L```#P```%6P```0````9;```!<```!VL```$P```(ZP```E````HK``
M``X```#(L```$0```->P```7````Z;```!,````!L0``%@```!6Q```X````
M++$``!,```!EL0``!0```'FQ```-````?[$``!L```"-L0``#P```*FQ```2
M````N;$```P```#,L0``#@```-FQ```-````Z+$``!D```#VL0``'````!"R
M```X````+;(``!@```!FL@``(````'^R```3````H+(```,```"TL@``%0``
M`+BR```.````SK(``!````#=L@``*0```.ZR```L````&+,``"@```!%LP``
M-0```&ZS```%````I+,``!@```"JLP``&0```,.S```;````W;,``!````#Y
MLP``#P````JT```0````&K0```\````KM```"P```#NT```/````1[0```P`
M``!7M```#P```&2T```'````=+0```8```!\M```"@```(.T```2````CK0`
M``T```"AM```#````*^T``!#````O+0``#T`````M0``"0```#ZU```/````
M2+4```@```!8M0``"````&&U```3````:K4``!X```!^M0``(0```)VU```@
M````O[4``!D```#@M0``%P```/JU```E````$K8``!<````XM@``"````%"V
M```*````6;8``"````!DM@``'P```(6V```;````I;8```@```#!M@``!```
M`,JV```3````S[8``!0```#CM@``#````/BV```)````!;<```X````/MP``
M"P```!ZW```;````*K<```X```!&MP``#P```%6W```E````9;<``"H```"+
MMP``!P```+:W```2````OK<``!L```#1MP``!````.VW```2````\K<```H`
M```%N```"````!"X```0````&;@```X````JN```'@```#FX```:````6+@`
M``H```!SN```1````'ZX```%````P[@```8```#)N```!P```-"X```(````
MV+@``!$```#AN```&0```/.X```"````#;D```8````0N0``%0```!>Y```/
M````+;D``!$````]N0``&@```$^Y```%````:KD```P```!PN0``$````'VY
M```)````CKD```0```"8N0``!0```)VY```:````H[D```\```"^N0``&0``
M`,ZY```.````Z+D``"(```#WN0``"@```!JZ```,````);H``!0````RN@``
M'0```$>Z```&````9;H``!$```!LN@``"0```'ZZ```7````B+H``!X```"@
MN@``#@```+^Z```&````SKH```<```#5N@``!@```-VZ```$````Y+H``"<`
M``#IN@``!@```!&[```5````&+L```P````NNP``$0```#N[```$````3;L`
M``T```!2NP``!P```&"[```$````:+L```P```!MNP``"@```'J[```%````
MA;L```\```"+NP``)P```)N[```I````P[L``"0```#MNP``)@```!*\```H
M````.;P``!P```!BO```(````'^\```@````H+P``"8```#!O```*0```.B\
M```6````$KT```H````IO0``#P```#2]```0````1+T``$````!5O0``<```
M`):]```&````![X```H````.O@``#@```!F^```)````*+X```H````RO@``
M!@```#V^```&````1+X```H```!+O@``#@```%:^```.````9;X``!\```!T
MO@``'@```)2^```C````L[X``!$```#7O@``%0```.F^```8````_[X``!$`
M```8OP``$````"J_```C````.[\```\```!?OP``"0```&^_```2````>;\`
M`!T```",OP``$@```*J_```0````O;\```H```#.OP``!0```-F_```Q````
MW[\``"0````1P```'````#;````C````4\````\```!WP```$````(?````$
M````F,````L```"=P```%````*G````,````OL````P```#+P```#P```-C`
M```5````Z,```"D```#^P```*@```"C!```F````4\$``"<```!ZP0``*0``
M`*+!```J````S,$``!D```#WP0``$0```!'"```2````(\(``!,````VP@``
M%````$K"```6````7\(``!<```!VP@``$````(["```1````G\(``!,```"Q
MP@``$@```,7"```U````V,(``!0````.PP``*P```"/#```4````3\,``!<`
M``!DPP``'````'S#```+````F<,``!H```"EPP``(0```,##```@````XL,`
M`!<````#Q```%0```!O$```&````,<0```8````XQ```!@```#_$```'````
M1L0```0```!.Q```!````%/$```'````6,0```X```!@Q```#````&_$```,
M````?,0```T```")Q```*````)?$```,````P,0```\```#-Q```"@```-W$
M```(````Z,0``"L```#QQ```+@```!W%```(````3,4``!$```!5Q0``"0``
M`&?%```.````<<4``!8```"`Q0``$0```)?%```&````J<4``!$```"PQ0``
M(0```,+%```.````Y,4``!````#SQ0``"P````3&```5````$,8``!H````F
MQ@``#@```$'&```/````4,8```@```!@Q@``!@```&G&```,````<,8```<`
M``!]Q@``!0```(7&```+````B\8``$<```"7Q@``#0```-_&```#````[<8`
M``P```#QQ@``$P```/[&```3````$L<``!,````FQP``!@```#K'```"````
M0<<``"4```!$QP``'P```&K'```'````BL<``"(```"2QP``:````+7'```%
M````'L@```@````DR```-P```"W(```B````9<@``!,```"(R```$0```)S(
M```/````KL@```\```"^R```%P```,[(```F````YL@``"8````-R0```P``
M`#3)```4````.,D``!,```!-R0``$````&')```-````<LD```X```"`R0``
M%@```(_)```'````ILD```H```"NR0``"P```+G)```'````Q<D``!,```#-
MR0``#````.')```/````[LD```X```#^R0``#`````W*```.````&LH``%$`
M```IR@``#P```'O*```-````B\H```\```"9R@``#P```*G*```/````N<H`
M`"````#)R@``+@```.K*```:````&<L``"8````TRP``"P```%O+```&````
M9\L```D```!NRP``5P```'C+```"````T,L```L```#3RP``#0```-_+```&
M````[<L```<```#TRP``!````/S+```)`````<P```D````+S```"@```!7,
M```'````(,P```D````HS```#@```#+,```'````0<P```H```!)S```$@``
M`%3,```$````9\P```P```!LS```!P```'G,```%````@<P``!8```"'S```
M`P```)[,```,````HLP```H```"OS```"````+K,```7````P\P```P```#;
MS```!````.C,```,````[<P```D```#ZS````@````3-```4````!\T```T`
M```<S0``$@```"K-```?````/<T``!0```!=S0``'@```'+-```5````D<T`
M`#@```"GS0``"@```.#-```L````Z\T``#,````8S@``,P```$S.```X````
M@,X```\```"YS@``&````,G.```3````XLX``"H```#VS@``&0```"'/```4
M````.\\``!0```!0SP``(````&7/```2````AL\``!0```"9SP``+0```*[/
M```M````W,\``#$````*T```+@```#S0```O````:]```"P```";T```8@``
M`,C0```3````*]$``!(````_T0``#@```%+1```A````8=$``!H```"#T0``
M"0```)[1``!%````J-$``$$```#NT0``#P```##2```$````0-(```8```!%
MT@``"0```$S2```*````5M(```L```!AT@``"0```&W2```-````=](```P`
M``"%T@``%````)+2```6````I](```4```"^T@``"````,32``!$````S=(`
M`#P````2TP``.````$_3```"````B-,```8```"+TP``#@```)+3```'````
MH=,```8```"ITP``#````+#3```C````O=,``"D```#ATP``'P````O4``!<
M````*]0``!0```"(U```/@```)W4```4````W-0```<```#QU```#@```/G4
M```,````"-4```P````5U0``$P```"+5```*````-M4``!T```!!U0``$0``
M`%_5```-````<=4``!$```!_U0``)````)'5```5````MM4``!,```#,U0``
M$@```.#5```+````\]4``#0```#_U0``"P```#36```4````0-8``#X```!5
MU@``#@```)36```2````H]8``!````"VU@``&````,?6```9````X-8``%8`
M``#ZU@``30```%'7```(````G]<```D```"HUP``'````++7```'````S]<`
M``T```#7UP``(@```.77```A````"-@```<````JV```"````#+8```2````
M.]@``"P```!.V```&@```'O8```)````EM@```H```"@V```%0```*O8```%
M````P=@``!0```#'V```$````-S8```'````[=@``!X```#UV```*````!39
M```*````/=D``!H```!(V0``+0```&/9```(````D=D``!0```":V0``!0``
M`*_9```&````M=D``#$```"\V0``(````.[9```I````#]H``"<````YV@``
M00```&':```H````H]H``!H```#,V@``*````.?:```=````$-L``"D````N
MVP``'0```%C;```N````=ML``%<```"EVP``-@```/W;```L````--P``#$`
M``!AW```!0```)/<```K````F=P``"X```#%W```-````/3<```A````*=T`
M`!````!+W0``#0```%S=```%````:MT```X```!PW0``"````'_=```+````
MB-T```<```"4W0``$P```)S=```V````L-T``#<```#GW0``"0```!_>```*
M````*=X``!0````TW@``,@```$G>```.````?-X```T```"+W@``%@```)G>
M```^````L-X``"<```#OW@``!0```!??```7````'=\```4````UWP``'@``
M`#O?```$````6M\``#(```!?WP``10```)+?```)````V-\```@```#BWP``
M$````.O?```5````_-\``!,````2X```%P```";@```'````/N```!X```!&
MX```%0```&7@```4````>^````L```"0X```(P```)S@```6````P.````\`
M``#7X```#@```.?@```J````]N````8````AX0``#````"CA```8````->$`
M``L```!.X0``"P```%KA```/````9N$``!````!VX0``+@```(?A```Z````
MMN$```X```#QX0``#0````#B```%````#N(```L````4X@``#````"#B```-
M````+>(```T````[X@``#@```$GB```-````6.(``"````!FX@``)P```(?B
M```K````K^(```H```#;X@``!@```.;B```.````[>(``!<```#\X@``,@``
M`!3C```>````1^,``!8```!FXP``%````'WC```%````DN,``!H```"8XP``
M!P```+/C```&````N^,``!$```#"XP``2P```-3C```4````(.0``!@````U
MY```!````$[D```.````4^0```X```!BY```!0```''D```#````=^0``!X`
M``![Y```%@```)KD```8````L>0```X```#*Y```-P```-GD```.````$>4`
M`!<````@Y0``00```#CE```5````>N4``#$```"0Y0``$P```,+E```;````
MUN4``"H```#RY0``40```!WF``!0````;^8``"4```#`Y@``"0```.;F```#
M````\.8```(```#TY@``$````/?F```(````".<```0````1YP``!P```!;G
M```R````'N<```H```!1YP``#````%SG```+````:><```<```!UYP``%@``
M`'WG```Z````E.<``"````#/YP``#P```/#G```7`````.@``#D````8Z```
M!@```%+H```)````6>@```X```!CZ```!````'+H```&````=^@``!8```!^
MZ```#0```)7H```.````H^@``!4```"RZ```$@```,CH```/````V^@``!0`
M``#KZ```0P````#I```*````1.D``!$```!/Z0``"P```&'I``!I````;>D`
M`!H```#7Z0``%P```/+I```G````"NH``!L````RZ@``&@```$[J```7````
M:>H``!L```"!Z@``&0```)WJ```?````M^H``!<```#7Z@``%P```._J```,
M````!^L``!,````4ZP``"````"CK```0````,>L``!$```!"ZP``"0```%3K
M```-````7NL```8```!LZP``'0```'/K```'````D>L``$,```"9ZP``,@``
M`-WK```_````$.P``#<```!0[```5P```(CL```-````X.P``!(```#N[```
M*0````'M```-````*^T``"T````Y[0``<````&?M```_````V.T``#D````8
M[@``1@```%+N```$````F>X``!````">[@``$````*_N```,````P.X``!0`
M``#-[@``'0```.+N```1`````.\``#T````2[P``)0```%#O```@````=N\`
M`!\```"7[P``'0```+?O```H````U>\```4```#^[P``!@````3P```Y````
M"_````4```!%\```!P```$OP```)````4_```!,```!=\```!@```''P```$
M````>/```!````!]\```#P```([P```,````GO```!0```"K\```%````,#P
M```/````U?````X```#E\```$@```/3P```.````!_$```<````6\0``$P``
M`![Q```,````,O$``!<````_\0``#0```%?Q```4````9?$``"\```!Z\0``
M!0```*KQ```1````L/$```8```#"\0``#@```,GQ```-````V/$``!````#F
M\0``$0```/?Q```+````"?(```(````5\@``"````!CR```'````(?(```T`
M```I\@``!@```#?R```6````/O(```D```!5\@``!P```%_R```5````9_(`
M``L```!]\@``!P```(GR```+````D?(```<```"=\@``&0```*7R```:````
MO_(``"````#:\@``"````/OR```%````!/,``!`````*\P``$````!OS```%
M````+/,```4````R\P``$````#CS```:````2?,``!0```!D\P``"0```'GS
M```*````@_,```(```".\P``'P```)'S```C````L?,``#$```#5\P``,0``
M``?T```G````.?0``&0```!A]```70```,;T``!5````)/4``#,```!Z]0``
M2@```*[U``!;````^?4``"@```!5]@``.````'[V```E````M_8``!L```#=
M]@``'@```/GV``!U````&/<``#X```".]P``0@```,WW```]````$/@``"D`
M``!.^```*0```'CX```Q````HO@``*D!``#4^```(P```'[Z``!(````HOH`
M`#0```#K^@``'@```"#[``!!````/_L``%L```"!^P``20```-W[```A````
M)_P``!\```!)_```)````&G\```H````COP``"D```"W_```,P```.'\```E
M````%?T``#@````[_0``)@```'3]```P````F_T``&D```#,_0``/@```#;^
M```^````=?X``$<```"T_@``/0```/S^``!E````.O\``$T```"@_P``4P``
M`.[_``!7````0@`!`%4```":``$`1@```/```0`J````-P$!`"\```!B`0$`
M50```)(!`0`@````Z`$!`"X````)`@$`*P```#@"`0`P````9`(!`"H```"5
M`@$`/@```,`"`0!2````_P(!`%H```!2`P$`,@```*T#`0`K````X`,!`$@`
M```,!`$`2@```%4$`0`J````H`0!`"8```#+!`$`,@```/($`0`=````)04!
M`",```!#!0$`+P```&<%`0`L````EP4!`"T```#$!0$`%P```/(%`0`E````
M"@8!`#(````P!@$`*0```&,&`0`^````C08!`%(```#,!@$`)0```!\'`0`[
M````10<!`"\```"!!P$`,@```+$'`0`K````Y`<!`"D````0"`$`#P```#H(
M`0!%````2@@!`"$```"0"`$`,````+((`0`E````XP@!`!P````)"0$`,0``
M`"8)`0`+````6`D!``T```!D"0$`!0```'()`0`"````>`D!``H```!["0$`
M5@```(8)`0!9````W0D!`!<````W"@$`#````$\*`0`-````7`H!``(```!J
M"@$``P```&T*`0`N````<0H!`"\```"@"@$`%P```-`*`0`@````Z`H!`!L`
M```)"P$`&````"4+`0`D````/@L!`!\```!C"P$`&@```(,+`0`@````G@L!
M`!H```"_"P$`,@```-H+`0`O````#0P!`"4````]#`$`(@```&,,`0`E````
MA@P!`!@```"L#`$`)@```,4,`0`*````[`P!`!,```#W#`$`"`````L-`0`)
M````%`T!`!8````>#0$`#````#4-`0`7````0@T!``<```!:#0$`'P```&(-
M`0`'````@@T!``\```"*#0$`!P```)H-`0`&````H@T!`!H```"I#0$`%0``
M`,0-`0`&````V@T!``D```#A#0$`&````.L-`0`+````!`X!`!,````0#@$`
M$P```"0.`0`/````.`X!`!$```!(#@$`'@```%H.`0`R````>0X!``0```"L
M#@$`$P```+$.`0`,````Q0X!`!$```#2#@$`"````.0.`0`)````[0X!``H`
M``#W#@$`%`````(/`0`(````%P\!``@````@#P$`/P```"D/`0`'````:0\!
M``0```!Q#P$`!P```'8/`0`2````?@\!`"8```"1#P$`&0```+@/`0`8````
MT@\!``L```#K#P$`#@```/</`0`*````!A`!`!,````1$`$`)P```"40`0`)
M````31`!``\```!7$`$`*````&<0`0`/````D!`!`!0```"@$`$``@```+40
M`0`&````N!`!``<```"_$`$`#0```,<0`0`+````U1`!`"\```#A$`$`(```
M`!$1`0`<````,A$!`%H```!/$0$`/P```*H1`0`V````ZA$!`#$````A$@$`
M"0```%,2`0`%````71(!`#\```!C$@$`$@```*,2`0`,````MA(!``H```##
M$@$`&````,X2`0`9````YQ(!`!\````!$P$`'0```"$3`0`1````/Q,!``(`
M``!1$P$`!````%03`0`&````61,!``,```!@$P$`#````&03`0`G````<1,!
M`"$```"9$P$`)````+L3`0!%````X!,!`!H````F%`$`'0```$$4`0`U````
M7Q0!`"@```"5%`$`4P```+X4`0`Z````$A4!`!D```!-%0$`%P```&<5`0`9
M````?Q4!`"H```"9%0$`*P```,05`0`@````\!4!`#4````1%@$`10```$<6
M`0`F````C18!`#````"T%@$`)P```.46`0`A````#1<!`"@````O%P$`*P``
M`%@7`0`=````A!<!`"D```"B%P$`)@```,P7`0`E````\Q<!`"@````9&`$`
M*````$(8`0`B````:Q@!`#T```".&`$`00```,P8`0`H````#AD!`"P````W
M&0$`,````&09`0`2````E1D!`!,```"H&0$`$````+P9`0!Y````S1D!`!P`
M``!'&@$`$````&0:`0`/````=1H!``X```"%&@$`<P```)0:`0!\````"!L!
M`$````"%&P$`%P```,8;`0`J````WAL!`#0````)'`$`%@```#X<`0`/````
M51P!`!\```!E'`$`%````(4<`0`/````FAP!``P```"J'`$`$````+<<`0`/
M````R!P!``\```#8'`$`!````.@<`0`*````[1P!``,```#X'`$`!P```/P<
M`0`+````!!T!``@````0'0$`!P```!D=`0`%````(1T!``D````G'0$`%```
M`#$=`0`&````1AT!``<```!-'0$`"````%4=`0`/````7AT!``\```!N'0$`
M"````'X=`0`,````AQT!``8```"4'0$`"0```)L=`0`+````I1T!``\```"Q
M'0$`!@```,$=`0`'````R!T!``T```#0'0$`!@```-X=`0`4````Y1T!``<`
M``#Z'0$``P````(>`0`)````!AX!``8````0'@$`#````!<>`0`*````)!X!
M``P````O'@$`"@```#P>`0`(````1QX!``H```!0'@$`!````%L>`0`$````
M8!X!``0```!E'@$`$P```&H>`0`"````?AX!``<```"!'@$`!@```(D>`0`.
M````D!X!``\```"?'@$`(@```*\>`0`'````TAX!``4```#:'@$`#@```.`>
M`0`.````[QX!`%4!``#^'@$`"````%0@`0`(````72`!``@```!F(`$`"@``
M`&\@`0`'````>B`!``<```""(`$`"````(H@`0`"````DR`!``$```"6(`$`
M-P```)@@`0`O````T"`!`#<`````(0$`+P```#@A`0`0````:"$!``D```!Y
M(0$`"P```(,A`0`1````CR$!``\```"A(0$`"P```+$A`0`5````O2$!`$``
M``#3(0$`+P```!0B`0`O````1"(!`!4```!T(@$`(P```(HB`0`7````KB(!
M`"<```#&(@$`)0```.XB`0`C````%",!`!D````X(P$`#````%(C`0`%````
M7R,!`!$```!E(P$`*P```'<C`0`U````HR,!`"4```#9(P$`-0```/\C`0`Q
M````-20!``\```!G)`$`"P```'<D`0`+````@R0!`!$```"/)`$`&0```*$D
M`0`J````NR0!`"X```#F)`$`+@```!4E`0`B````1"4!`!X```!G)0$`'```
M`(8E`0`*````HR4!`$(```"N)0$`,@```/$E`0`\````)"8!`"P```!A)@$`
M"````(XF`0`)````ER8!``H```"A)@$`"@```*PF`0`'````MR8!``@```"_
M)@$`"````,@F`0`F````T28!`!P```#X)@$`(@```!4G`0`I````."<!`#$`
M``!B)P$`2@```)0G`0!$````WR<!`%`````D*`$`2@```'4H`0`L````P"@!
M``4```#M*`$`%@```/,H`0`.````"BD!``@````9*0$`+P```"(I`0`K````
M4BD!`!8```!^*0$`'@```)4I`0`.````M"D!``0```##*0$`!````,@I`0`2
M````S2D!`!0```#@*0$`"P```/4I`0`4`````2H!`!8````6*@$`$@```"TJ
M`0`,````0"H!`!(```!-*@$`"@```&`J`0`L````:RH!`!0```"8*@$`$0``
M`*TJ`0`6````ORH!``P```#6*@$`%0```.,J`0`F````^2H!``0````@*P$`
M"@```"4K`0`*````,"L!``0````[*P$``P```$`K`0`$````1"L!``8```!)
M*P$`#````%`K`0`.````72L!`!````!L*P$`3P```'TK`0!4````S2L!`#8`
M```B+`$`0````%DL`0!`````FBP!`"H```#;+`$`#@````8M`0`4````%2T!
M`!8````J+0$`%````$$M`0`4````5BT!`!(```!K+0$`!````'XM`0`2````
M@RT!`#T```"6+0$`&@```-0M`0`R````[RT!``X````B+@$`"````#$N`0`.
M````.BX!`!````!)+@$`%@```%HN`0`J````<2X!`"L```"<+@$`!````,@N
M`0`$````S2X!`!@```#2+@$`#````.LN`0`@````^"X!`#0````9+P$`&@``
M`$XO`0`Q````:2\!`#0```";+P$`+@```-`O`0`H````_R\!`"(````H,`$`
M-@```$LP`0`R````@C`!`#(```"U,`$`"````.@P`0`$````\3`!``8```#V
M,`$`+@```/TP`0`$````+#$!``P````Q,0$`(P```#XQ`0`.````8C$!`#H`
M``!Q,0$`-````*PQ`0`$````X3$!`!X```#F,0$`!`````4R`0`J````"C(!
M`"P````U,@$`+````&(R`0`F````CS(!``8```"V,@$`!````+TR`0`$````
MPC(!``0```#',@$`,0```,PR`0`V````_C(!`"X````U,P$`:@```&0S`0`I
M````SS,!`"P```#Y,P$`*0```"8T`0`I````4#0!`#4```!Z-`$`)0```+`T
M`0`E````UC0!`"D```#\-`$`+P```"8U`0`2````5C4!`!8```!I-0$`*```
M`(`U`0`7````J34!`$0```#!-0$`%@````8V`0`6````'38!``@````T-@$`
M"P```#TV`0`)````238!``0```!3-@$`!@```%@V`0`@````7S8!`!X```"`
M-@$``P```)\V`0`&````HS8!``X```"J-@$`#@```+DV`0`Z````R#8!``0`
M```#-P$`!`````@W`0`,````#3<!``(````:-P$`"@```!TW`0`"````*#<!
M``0````K-P$`%````#`W`0`(````13<!``,```!.-P$``P```%(W`0`0````
M5C<!``P```!G-P$`!@```'0W`0`H````>S<!`"@```"D-P$`)0```,TW`0`*
M````\S<!`!8```#^-P$`'````!4X`0`V````,C@!`"````!I.`$`(@```(HX
M`0`F````K3@!`"8```#4.`$`2````/LX`0`R````1#D!``0```!W.0$`#```
M`'PY`0`"````B3D!``@```",.0$`"````)4Y`0`*````GCD!``@```"I.0$`
M"@```+(Y`0`(````O3D!``0```#&.0$`#````,LY`0`.````V#D!``0```#G
M.0$`!````.PY`0`*````\3D!``P```#\.0$`2`````DZ`0`J````4CH!`#``
M``!].@$`/````*XZ`0`.````ZSH!`!P```#Z.@$`'@```!<[`0`D````-CL!
M``P```!;.P$`%````&@[`0`0````?3L!``X```"..P$`#````)T[`0`.````
MJCL!`#0```"Y.P$`0@```.X[`0`@````,3P!`!````!2/`$`"@```&,\`0`_
M````;CP!`"T```"N/`$`+0```-P\`0`S````"CT!`#$````^/0$`)@```'`]
M`0!9````EST!`!(```#Q/0$`,0````0^`0!"````-CX!`#@```!Y/@$`+@``
M`+(^`0`&````X3X!`!(```#H/@$`%````/L^`0`2````$#\!``8````C/P$`
M#@```"H_`0`8````.3\!`!````!2/P$``@```&,_`0`&````9C\!``8```!M
M/P$`!````'0_`0`*````>3\!``H```"$/P$`"````(\_`0`.````F#\!``@`
M``"G/P$`!@```+`_`0`$````MS\!``0```"\/P$`$````,$_`0`J````TC\!
M`$````#]/P$`"@```#Y``0`-````24`!`"@```!70`$`*@```(!``0`0````
MJT`!``H```"\0`$`)@```,=``0`S````[D`!`"$````B00$`$@```$1!`0`D
M````5T$!`"````!\00$`(P```)U!`0!&````P4$!`"`````(0@$`!@```"E"
M`0`&````,$(!`!(````W0@$`!````$I"`0`0````3T(!`"L```!@0@$`*0``
M`(Q"`0`N````MD(!`"P```#E0@$`(````!)#`0`G````,T,!`!X```!;0P$`
M)@```'I#`0`F````H4,!`"D```#(0P$`(````/)#`0`F````$T0!`#8````Z
M1`$`,@```'%$`0`:````I$0!`#H```"_1`$`+````/I$`0`J````)T4!`"P`
M``!210$`+````']%`0`J````K$4!`!\```#710$`*@```/=%`0`5````(D8!
M`"0````X1@$`)@```%U&`0`F````A$8!`!P```"K1@$`'P```,A&`0`J````
MZ$8!`!T````31P$`(````#%'`0`F````4D<!`$````!Y1P$``@```+I'`0`$
M````O4<!``X```#"1P$`$@```-%'`0`8````Y$<!``@```#]1P$`&@````9(
M`0`8````(4@!`%4````Z2`$`$@```)!(`0`2````HT@!`!0```"V2`$`"@``
M`,M(`0`R````UD@!`"(````)20$`.@```"Q)`0`(````9TD!``@```!P20$`
M`@```'E)`0`$````?$D!``8```"!20$`#0```(A)`0`$````EDD!``H```";
M20$`"@```*9)`0`$````L4D!``8```"V20$`"````+U)`0`,````QDD!``P`
M``#320$`#0```.!)`0`8````[DD!`!@````'2@$`"````"!*`0`$````*4H!
M``X````N2@$`#@```#U*`0`.````3$H!`!(```!;2@$`"````&Y*`0`(````
M=TH!`!8```"`2@$`.@```)=*`0`.````TDH!`"H```#A2@$`,`````Q+`0`(
M````/4L!`!````!&2P$`$@```%=+`0`2````:DL!``8```!]2P$`$````(1+
M`0`:````E4L!`!(```"P2P$`"````,-+`0`.````S$L!`!@```#;2P$`!```
M`/1+`0`.````^4L!``0````(3`$`)`````U,`0`$````,DP!`!@````W3`$`
M"@```%!,`0`*````6TP!``0```!F3`$`"@```&M,`0`.````=DP!`"````"%
M3`$`"@```*9,`0`N````L4P!``0```#@3`$`"@```.5,`0`B````\$P!``H`
M```330$`+@```!Y-`0`0````34T!`!8```!>30$`10```'5-`0`$````NTT!
M``P```#`30$`$0```,U-`0`<````WTT!`"D```#\30$`%@```"9.`0`B````
M/4X!`#<```!@3@$`%@```)A.`0`&````KTX!``X```"V3@$`#@```,5.`0`*
M````U$X!``X```#?3@$`!````.Y.`0`4````\TX!``X````(3P$`%````!=/
M`0`.````+$\!`!`````[3P$`$````$Q/`0`5````74\!`!(```!S3P$`&0``
M`(9/`0`4````H$\!`!(```"U3P$`%0```,A/`0`4````WD\!`!0```#S3P$`
M*`````A0`0`4````,5`!``H```!&4`$`#@```%%0`0`K````8%`!`!(```",
M4`$`$````)]0`0`,````L%`!`!(```"]4`$`%````-!0`0`4````Y5`!`!<`
M``#Z4`$`+@```!)1`0`F````05$!`"0```!H40$`$````(U1`0`$````GE$!
M`!0```"C40$`%@```+A1`0`2````SU$!`"X```#B40$`,````!%2`0`N````
M0E(!`#$```!Q4@$`!@```*-2`0`1````JE(!`!P```"\4@$`&@```-E2`0`'
M````]%(!``4```#\4@$`!P````)3`0`&````"E,!``H````14P$`!P```!Q3
M`0`&````)%,!``H````K4P$`!````#93`0`$````.U,!``P```!`4P$`%@``
M`$U3`0`.````9%,!``H```!S4P$`+````'Y3`0`\````JU,!``8```#H4P$`
M"````.]3`0`$````^%,!``8```#]4P$`'0````14`0`D````(E0!`",```!'
M5`$`(@```&M4`0`A````CE0!`!\```"P5`$`(````-!4`0`=````\50!``0`
M```/50$`$````!15`0`B````)54!`"0```!(50$`&P```&U5`0`*````B54!
M``@```"450$`%P```)U5`0`7````M54!`!(```#-50$`"@```.!5`0`,````
MZU4!`!0```#X50$`+@````U6`0`2````/%8!``P```!/5@$`)@```%Q6`0`N
M````@U8!``@```"R5@$`#@```+M6`0`9````RE8!``0```#D5@$`'````.E6
M`0`,````!E<!``8````35P$`#````!I7`0`,````)U<!`!@````T5P$`%@``
M`$U7`0`&````9%<!`#@```!K5P$`"````*17`0`*````K5<!``0```"X5P$`
M!0```+U7`0`0````PU<!`!<```#45P$``@```.Q7`0`"````[U<!``@```#R
M5P$`#````/M7`0`,````"%@!`!`````56`$`"````"98`0`.````+U@!``H`
M```^6`$`!````$E8`0`&````3E@!``8```!56`$`'0```%Q8`0`0````>E@!
M`!4```"+6`$`$````*%8`0`I````LE@!``(```#<6`$`#@```-]8`0`,````
M[E@!`!P```#[6`$`"````!A9`0`0````(5D!``P````R60$`"0```#]9`0`;
M````25D!`!0```!E60$`!@```'I9`0`&````@5D!``0```"(60$`!@```(U9
M`0`:````E%D!``0```"O60$`%````+19`0`0````R5D!`!````#:60$``@``
M`.M9`0`(````[ED!``0```#W60$`!@```/Q9`0`*`````UH!``X````.6@$`
M!0```!U:`0`$````(UH!`!@````H6@$`&@```$%:`0`B````7%H!`!H```!_
M6@$`#@```)I:`0`0````J5H!`"L```"Z6@$`*P```.9:`0`S````$EL!`#(`
M``!&6P$`$````'E;`0`,````BEL!`!(```"76P$`"````*I;`0!%````LUL!
M`%D```#Y6P$`!````%-<`0`*````6%P!``X```!C7`$`"````')<`0`)````
M>UP!``0```"%7`$`"@```(I<`0`.````E5P!`!(```"D7`$`$@```+=<`0`=
M````REP!`!T```#H7`$`(`````9=`0`2````)UT!`!8````Z70$`&0```%%=
M`0`4````:UT!`!X```"`70$`)````)]=`0`7````Q%T!``0```#<70$`#```
M`.%=`0`F````[ET!`!\````57@$`'````#5>`0`&````4EX!``4```!97@$`
M)````%]>`0`B````A%X!`"P```"G7@$`*````-1>`0`,````_5X!``H````*
M7P$`!````!5?`0`2````&E\!`!`````M7P$`"@```#Y?`0`(````25\!``P`
M``!27P$`#@```%]?`0`8````;E\!`!8```"'7P$`&````)Y?`0`6````MU\!
M`!H```#.7P$`&````.E?`0`6`````F`!`!`````98`$`#@```"I@`0`.````
M.6`!``X```!(8`$`$````%=@`0`.````:&`!``X```!W8`$`#````(9@`0`0
M````DV`!`!(```"D8`$`*````+=@`0`0````X&`!`!H```#Q8`$`'`````QA
M`0`=````*6$!`!P```!'80$`"````&1A`0`<````;6$!`!<```"*80$`%P``
M`*)A`0`8````NF$!`!D```#380$`!````.UA`0`&````\F$!``0```#Y80$`
M!````/YA`0`$`````V(!``0````(8@$`!@````UB`0`(````%&(!``@````=
M8@$`!@```"9B`0`&````+6(!`",````T8@$`"````%AB`0`&````86(!``@`
M``!H8@$`!@```'%B`0`H````>&(!`"````"A8@$`"````,)B`0`<````RV(!
M``P```#H8@$`$@```/5B`0`>````"&,!`!0````G8P$`"@```#QC`0`.````
M1V,!`!X```!68P$`$````'5C`0`4````AF,!``@```";8P$`$@```*1C`0`D
M````MV,!`!P```#<8P$`"@```/EC`0`$````!&0!``@````)9`$`#0```!)D
M`0`*````(&0!``@````K9`$`#@```#1D`0`^````0V0!`!@```""9`$``@``
M`)MD`0`(````GF0!`!8```"G9`$`%````+YD`0`4````TV0!``0```#H9`$`
M`@```.UD`0`M````\&0!`!P````>90$`#@```#ME`0`H````2F4!`#````!S
M90$`!````*1E`0`,````J64!`"````"V90$`(@```-=E`0`F````^F4!``X`
M```A9@$`$````#!F`0`<````068!``X```!>9@$`&@```&UF`0`>````B&8!
M``0```"G9@$`#````*QF`0`*````N68!``H```#$9@$`"@```,]F`0`*````
MVF8!``X```#E9@$`!@```/1F`0`.````^V8!``@````*9P$`!@```!-G`0`*
M````&F<!``P````E9P$`%````#)G`0`,````1V<!``P```!49P$`#````&%G
M`0!"````;F<!``H```"Q9P$`#````+QG`0`.````R6<!`!,```#89P$`"```
M`.QG`0`<````]6<!`#4````2:`$`%````$AH`0`P````76@!``X```".:`$`
M"````)UH`0`)````IF@!`%8```"P:`$``@````=I`0`*````"FD!``8````5
M:0$`!````!QI`0`$````(6D!``0````F:0$`!````"MI`0`$````,&D!``0`
M```U:0$`!````#II`0`(````/VD!``X```!(:0$`"````%=I`0`*````8&D!
M``P```!K:0$`!````'AI`0`.````?6D!``P```",:0$`!````)EI`0`0````
MGFD!``0```"O:0$`"````+1I`0`,````O6D!``H```#*:0$`%````-5I`0`*
M````ZFD!``0```#U:0$`"@```/II`0`*````!6H!``0````0:@$`%@```!5J
M`0`,````+&H!`!`````Y:@$`(````$IJ`0`2````:VH!`"L```!^:@$`$@``
M`*IJ`0`F````O6H!``H```#D:@$`,@```.]J`0`H````(FL!`"@```!+:P$`
M+````'1K`0`2````H6L!`!P```"T:P$`'@```-%K`0`V````\&L!`!X````G
M;`$`"````$9L`0`@````3VP!`#0```!P;`$`&@```*5L`0`:````P&P!`",`
M``#;;`$`(P```/]L`0`G````(VT!`"<```!+;0$`)0```'-M`0`H````F6T!
M`%T```#";0$`&````"!N`0`0````.6X!``@```!*;@$`*@```%-N`0`;````
M?FX!``8```":;@$`.````*%N`0`\````VFX!``H````7;P$`!````")O`0`$
M````)V\!``H````L;P$`"@```#=O`0`0````0F\!``P```!3;P$`"@```&!O
M`0`,````:V\!`!8```!X;P$`$````(]O`0`&````H&\!``0```"G;P$`+```
M`*QO`0!`````V6\!`#0````:<`$``@```$]P`0`,````4G`!`!(```!?<`$`
M!````')P`0`(````=W`!``P```"`<`$`(@```(UP`0`R````L'`!`"D```#C
M<`$`0@````UQ`0`4````4'$!`$D```!E<0$`#````*]Q`0`*````O'$!``T`
M``#'<0$`#````-5Q`0`$````XG$!``0```#G<0$`!````.QQ`0`@````\7$!
M`!8````2<@$`$@```"ER`0`2````/'(!`!H```!/<@$`#````&IR`0`*````
M=W(!``H```""<@$`#````(UR`0`L````FG(!``X```#'<@$`%@```-9R`0`S
M````[7(!``H````A<P$`$````"QS`0`(````/7,!`!0```!&<P$`%P```%MS
M`0!(````<W,!`#X```"\<P$`"0```/MS`0`)````!70!`!`````/=`$`!```
M`"!T`0`/````)70!`"`````U=`$`(````%9T`0`&````=W0!``H```!^=`$`
M'````(ET`0`C````IG0!`!````#*=`$`"P```-MT`0`,````YW0!`!H```#T
M=`$`"`````]U`0`(````&'4!`!8````A=0$`"@```#AU`0`2````0W4!`"8`
M``!6=0$`"@```'UU`0`0````B'4!`"@```"9=0$`!@```,)U`0`(````R74!
M``0```#2=0$`"````-=U`0`J````X'4!`!H````+=@$`(0```"9V`0`F````
M2'8!`#X```!O=@$`)@```*YV`0`>````U78!`"(```#T=@$`'@```!=W`0`H
M````-G<!`!P```!?=P$`.````'QW`0!"````M7<!`"P```#X=P$`*P```"5X
M`0`Q````47@!``8```"#>`$`*P```(IX`0`P````MG@!`#,```#G>`$`'```
M`!MY`0`*````.'D!``H```!#>0$`!````$YY`0`$````4WD!``8```!8>0$`
M!@```%]Y`0`$````9GD!``X```!K>0$`)@```'IY`0`G````H7D!``P```#)
M>0$`!@```-9Y`0`2````W7D!`"4```#P>0$`$@```!9Z`0`0````*7H!`!8`
M```Z>@$`+````%%Z`0`D````?GH!``@```"C>@$`$P```*QZ`0`"````P'H!
M`!````##>@$`!````-1Z`0`T````V7H!`$,````.>P$`#@```%)[`0`,````
M87L!`!@```!N>P$`'````(=[`0`6````I'L!``@```"[>P$`!@```,1[`0`9
M````RWL!`!L```#E>P$`$`````%\`0`.````$GP!`!0````A?`$`$````#9\
M`0`<````1WP!`!````!D?`$`+````'5\`0`$````HGP!``X```"G?`$`$```
M`+9\`0`*````QWP!``P```#2?`$`$````-]\`0`0````\'P!`#(````!?0$`
M-````#1]`0`.````:7T!``H```!X?0$`!````(-]`0`*````B'T!``H```"3
M?0$`#````)Y]`0`,````JWT!``X```"X?0$`#````,=]`0`<````U'T!`!L`
M``#Q?0$`&`````U^`0`(````)GX!``4````O?@$`$@```#5^`0`0````2'X!
M`!8```!9?@$`&````'!^`0`8````B7X!``H```"B?@$`"````*U^`0`<````
MMGX!``0```#3?@$`!````-A^`0`0````W7X!`$@```#N?@$`#@```#=_`0`>
M````1G\!``0```!E?P$`!@```&I_`0`&````<7\!``0```!X?P$`!````'U_
M`0`/````@G\!``T```"2?P$`#0```*!_`0`/````KG\!`"\```"^?P$`$P``
M`.Y_`0`;`````H`!`#8````>@`$`$P```%6``0`O````:8`!``L```"9@`$`
M$P```*6``0`R````N8`!`$T```#L@`$`1P```#J!`0`;````@H$!``H```">
M@0$``P```*F!`0`"````K8$!`!D```"P@0$`!@```,J!`0`$````T8$!``D`
M``#6@0$`-@```."!`0`,````%X(!`!`````D@@$`#@```#6"`0`0````1((!
M`"````!5@@$`-@```':"`0`F````K8(!`"````#4@@$`%P```/6"`0`R````
M#8,!``0```!`@P$`!P```$6#`0`(````38,!``0```!6@P$`!````%N#`0`0
M````8(,!``H```!Q@P$`$````'R#`0`B````C8,!`!X```"P@P$`&````,^#
M`0`@````Z(,!`#X````)A`$`#````$B$`0`0````580!`!````!FA`$`4@``
M`'>$`0`D````RH0!`!X```#OA`$`$P````Z%`0`8````(H4!`"0````[A0$`
M'@```&"%`0`J````?X4!`!<```"JA0$`%P```,*%`0`8````VH4!`!````#S
MA0$`#`````2&`0`6````$88!``@````HA@$`$````#&&`0`2````0H8!``0`
M``!5A@$`!````%J&`0`&````7X8!`!8```!FA@$`!P```'V&`0!`````A88!
M`"H```#&A@$`,@```/&&`0`@````)(<!`%<```!%AP$`#````)V'`0`2````
MJH<!`#````"]AP$`#````.Z'`0`\````^X<!`$$````XB`$`(P```'J(`0`R
M````GH@!`"\```#1B`$`!`````&)`0`.````!HD!`!`````5B0$`#@```":)
M`0`6````-8D!`!P```!,B0$`$@```&F)`0`L````?(D!`"X```"IB0$`/```
M`-B)`0`>````%8H!`"0````TB@$`-@```%F*`0`$````D(H!``0```"5B@$`
M,@```)J*`0`(````S8H!``P```#6B@$`"````..*`0`4````[(H!``8````!
MBP$`!@````B+`0`2````#XL!``H````BBP$`!@```"V+`0`0````-(L!``@`
M``!%BP$`#@```$Z+`0`*````78L!``H```!HBP$`#@```'.+`0`$````@HL!
M``H```"'BP$`%````)*+`0`.````IXL!`!````"VBP$`$@```,>+`0`B````
MVHL!``0```#]BP$`"@````*,`0`$````#8P!``@````2C`$`"````!N,`0`*
M````)(P!`!0````OC`$`#@```$2,`0`"````4XP!``8```!6C`$`!````%V,
M`0`&````8HP!``0```!IC`$`#@```&Z,`0`&````?8P!``0```"$C`$`%0``
M`(F,`0`$````GXP!``0```"DC`$`!@```*F,`0`"````L(P!`!(```"SC`$`
M&0```,:,`0`<````X(P!``L```#]C`$``@````F-`0`&````#(T!``8````3
MC0$`!@```!J-`0`&````(8T!``@````HC0$`$````#&-`0`&````0HT!``P`
M``!)C0$`"````%:-`0`"````7XT!`!X```!BC0$`%@```(&-`0`F````F(T!
M`#(```"_C0$`+@```/*-`0!,````(8X!`%P```!NC@$`7````,N.`0`V````
M*(\!`#P```!?CP$`7````)R/`0`D````^8\!`"8````>D`$`(@```$60`0`B
M````:)`!`"\```"+D`$`>0```+N0`0!!````-9$!`$<```!WD0$`-@```+^1
M`0`?````]I$!`!\````6D@$`+0```#:2`0#D````9)(!`!H```!)DP$`1P``
M`&23`0`P````K),!`!P```#=DP$`.````/J3`0!'````,Y0!`$H```![E`$`
M'@```,:4`0`>````Y90!`!P````$E0$`%@```"&5`0`J````.)4!`#(```!C
ME0$`*@```):5`0`:````P94!`"H```#<E0$`)@````>6`0!>````+I8!`#,`
M``"-E@$`00```,&6`0`^`````Y<!`$L```!"EP$`7P```(Z7`0!/````[I<!
M`$(````^F`$`30```(&8`0!-````SY@!`#D````=F0$`*````%>9`0`N````
M@)D!`#<```"OF0$`*0```.>9`0`R````$9H!`#````!$F@$`+P```'6:`0`N
M````I9H!`#````#4F@$`0`````6;`0!.````1IL!`"8```"5FP$`*````+R;
M`0!&````Y9L!`$8````LG`$`*@```'.<`0`,````GIP!`#8```"KG`$`(@``
M`.*<`0`B````!9T!`"L````HG0$`*0```%2=`0`H````?IT!`!H```"GG0$`
M*@```,*=`0`R````[9T!`"L````@G@$`3@```$R>`0!&````FYX!`"0```#B
MG@$`,`````>?`0`I````.)\!`"P```!BGP$`+@```(^?`0`I````OI\!``H`
M``#HGP$`3````/.?`0`I````0*`!`#$```!JH`$`*@```)R@`0`B````QZ`!
M`$(```#JH`$`#````"VA`0`,````.J$!``@```!'H0$``@```%"A`0`$````
M4Z$!`%L```!8H0$`6P```+2A`0`1````$*(!``X````BH@$`$````#&B`0`"
M````0J(!``,```!%H@$`,````$FB`0`Q````>J(!`!4```"LH@$`'````,*B
M`0`6````WZ(!`"````#VH@$`*````!>C`0`B````0*,!`!X```!CHP$`(P``
M`(*C`0`8````IJ,!`#8```"_HP$`-````/:C`0`<````*Z0!`!X```!(I`$`
M(@```&>D`0`8````BJ0!`"````"CI`$`!@```,2D`0`,````RZ0!``P```#8
MI`$`!````.6D`0`,````ZJ0!``X```#WI`$`"`````:E`0`&````#Z4!`!8`
M```6I0$`!````"VE`0`*````,J4!``@````]I0$`!````$:E`0`2````2Z4!
M`!P```!>I0$`!````'NE`0`/````@*4!`!(```"0I0$`$````*.E`0`4````
MM*4!`!0```#)I0$`$@```-ZE`0`0````\:4!`"L````"I@$`.P```"ZF`0`&
M````:J8!``H```!QI@$`$````'RF`0`*````C:8!``@```"8I@$`"@```*&F
M`0`*````K*8!`!0```"WI@$`!````,RF`0`&````T:8!`#,```#8I@$``@``
M``RG`0`$````#Z<!``D````4IP$`$0```!ZG`0`@````,*<!`!(```!1IP$`
M$@```&2G`0`,````=Z<!``X```"$IP$`#@```).G`0`7````HJ<!`!(```"Z
MIP$`"@```,VG`0`*````V*<!`"0```#CIP$`#`````BH`0`4````%:@!``(`
M```JJ`$`!````"VH`0`(````,J@!``T````[J`$`$0```$FH`0`P````6Z@!
M`!8```",J`$`%````*.H`0!2````N*@!`#8````+J0$`*@```$*I`0`L````
M;:D!``X```":J0$``@```*FI`0`Q````K*D!``8```#>J0$`#````.6I`0`0
M````\JD!``\````#J@$`#P```!.J`0`3````(ZH!`!<````WJ@$`#P```$^J
M`0`"````7ZH!``(```!BJ@$`!````&6J`0`$````:JH!``H```!OJ@$`,```
M`'JJ`0`L````JZH!`"H```#8J@$`/0````.K`0`<````0:L!`"````!>JP$`
M)P```'^K`0`H````IZL!`%$```#0JP$`-@```"*L`0`<````6:P!`!L```!V
MK`$`$P```)*L`0`C````IJP!`"@```#*K`$`&@```/.L`0!-````#JT!`#H`
M``!<K0$`(@```)>M`0`C````NJT!`"P```#>K0$`(`````NN`0`B````+*X!
M`"@```!/K@$`&````'BN`0`D````D:X!`"0```"VK@$`)````-NN`0`D````
M`*\!`"8````EKP$`'@```$RO`0`L````:Z\!`#(```"8KP$`&P```,NO`0`;
M````YZ\!`#\````#L`$`$@```$.P`0`7````5K`!`!H```!NL`$`:````(FP
M`0`;````\K`!``X````.L0$`#@```!VQ`0`2````++$!`'8````_L0$`:```
M`+:Q`0!(````'[(!``X```!HL@$`'0```'>R`0`=````E;(!`!4```"SL@$`
M#````,FR`0`8````UK(!``\```#OL@$`!0```/^R`0`*````!;,!`!`````0
MLP$`"@```"&S`0`&````++,!``0````SLP$`$````#BS`0`#````2;,!``8`
M``!-LP$`"@```%2S`0`*````7[,!``H```!JLP$`"````'6S`0`#````?K,!
M`!,```""LP$`!@```):S`0`*````G;,!``P```"HLP$`!@```+6S`0`,````
MO+,!``P```#)LP$`#````-:S`0`&````X[,!``@```#JLP$`"@```/.S`0`,
M````_K,!``8````+M`$`!@```!*T`0`&````&;0!``X````@M`$`"````"^T
M`0`*````.+0!``,```!#M`$`"@```$>T`0`(````4K0!``X```!;M`$`$```
M`&JT`0`*````>[0!``0```"&M`$`!@```(NT`0`.````DK0!``@```"AM`$`
M!````*JT`0`$````K[0!`!8```"TM`$`!@```,NT`0`*````TK0!``@```#=
MM`$`#````.:T`0`,````\[0!`"4`````M0$`!@```":U`0`%````+;4!``X`
M```SM0$`#@```$*U`0`!````%0`````"`````````````&($``!(`@``#`,`
M`!(%``"%`@``#00```P"````````+0(``#H$````````A@```"(```#V!```
MU@$``&@$``#K````[0(``!H%```A````V00``+8"``!C`@````````````!@
M!0``I@$``-`%``#R````]0(```H```"A!0``Z````*4"````````'@,``!\`
M``!R!`````````````!N`P``-@$``+,```"A!```E0```,L$``#_`P``"`0`
M```````F`0``?P,``'8```"6`P``6P0``.@$`````````````.$$``!Y`@``
M.`(``-<!``#L!```KP$``+L$```P`0``2P0`````````````;P```&X$``!"
M!0``#@,```````#R`0``$`$```````!W!```S@(``$P$```L`P``(P,``,4$
M``#`!`````````T#``!&````7P4````````2`@```````-@$````````````
M``````"E`P``3P(``"4$```3`@`````````````$`0``DP0`````````````
M`````$<```!H`P```````-T#``"K````!@0``&$````@`@``]@```"\!```T
M!```)@0``,4#``!M!0```````)4$``!7`@````````````"8`0``F0```&P"
M``#T`0``U@(```````!?!``````````````(`````````%<#````````W04`
M````````````800``*@````!!```"0,``,@%````````N@0``/<"````````
MA@,``,@`````````````````````````<@$``)P!```N`0``A`(``%T%``"X
M!```]0$``(8$``#E`P``HP0``/@$``#W!```2P(```````"]`0``````````
M``#M`````````,,"``!*!```:P0`````````````4````#,```"Z`P``````
M`/\$````````:`(`````````````/`(```````!R!0``QP4`````````````
MO@,``-L!````````S`(```````!=`P```````(P`````````'04``)D%````
M````Z@0``$D%``#<`P```````,$"``"[`P```````/T$``!B!0``L@```'P"
M`````````````'H%``"2!````````'T#````````604``/4$``"7`P``````
M`&X`````````H0```,@$``"(!```10```$0```"Q!```4P```+\````W`0``
M`````+0```#)!`````````````"8`@``#@(``"L%```9`0```````#H%``"<
M````:``````````&````B@(``%P$``!F!0``B`$``%T```"'`0``M0```)D$
M``"P!0``C0,``"P"``#J`@``]````+8%``"4`@``>0$````````A!0``V@$`
M``````"M!0``9P(``)\"``"G!```M@```$H`````````N00`````````````
M`````&8#``"U`@``A`4```````#2`0``V0(``$`$``````````````````!G
M`0```0,```````#?!0``Q0(```````#@!```X`(``'`%``"6`@``>`$`````
M``#4!```.@,``'P%``"/!```,P4``,L#```-`@``20(```````!2`P``3@``
M`)T````Q````F@0``+X!``#?!```?00````````>!`````````(%```T`0``
M6@````````#F`P``*````'\%```````````````````E````:`$```````"7
M`@``:P$``*T"``!4````````````````````FP(```````#-`0``S04``%8%
M````````=0$``.0%``"B````X0,``*<#````````P````&H$``"F!```````
M`-,```#Z`P``_0(``)H```#N`0``````````````````#P4``&H```!N!0``
M``````````"B`P```````,L"```3`0````````````!^!```&0,```````"7
M!0``!`0````````H!```K0```%4$``!>`0``@@0``,8"``#U`P``000`````
M```G!0```@$``&\#```0`P``1P4```````!4`0`````````````'`@``````
M`.`!``"Z`0``8P,``(0!``#:`P``T04``!X!````````;0(```T!``"C````
MA@4``/````!E````-P```'@```#"`P``,`(```````#4````0@(```````!E
M!```]`(``#`````_`0``X04```````!&!0``'`$``'\!``"R`P``@@$``%P#
M``!B`P``QP(````````8`````````.P#``!]`@``.@```&<$````````````
M`"H"``"'!```90(``-\`````````B0(`````````````PP0``#$%``!^`@``
M`````%8!``#A`0```````%`"``#6````W@,````````B`0``J0$```````#%
M`````````$\#``"/`P``\`0``*P!``#D`P``^P(``)<```#V`0``KP,``.(%
M``!M````B@0````````'!0``RP$```````"U`P``D`(``/X#````````/0,`
M`%@#``#``P```P$``"\%```X!```&P,`````````````(@(```````"R`0``
MX0(``)L```#\`@``:0$``$`%``!#`@```````+<!````````_@```+,!```Q
M`@``+00``!P$``!W!0``/P4``&<%``!#`P``>00```````!:`@``20$``*(%
M``""`@```````!4%```O`P``+@,``.($```J!0``.`4``)L$``#E`0``JP$`
M```!````````*0$``'P#``#;`P``N04``.X"``")!```=`,`````````````
MC@(``&D#```H`0```````-@!````````1`0``&P%```2!```3P0``)4#``!;
M`P``_`$``&(`````````)P0``),!``"S`P``L@0``","``!Z!```U`,``#@!
M```H!0``E`0````````*!0``0`(```````#N````R04``,8#```#`P``3`(`
M``````#^!```!@(``!\$```O!```+`4`````````````O````*H#````````
M``````("```6`````````#8```!&`P``\0(``"<"`````````````+\"``"O
M````7@,``+0$``">`0``Z0(``/H```!C!0``&@```*D%``!<`@```````(\"
M`````````````/8#``"#`````````%\!``!M`0```````+<`````````V@4`
M``````"S`@``A`````````!%`0````````4!``````````````H#``"(`P``
M``````````#X`P``8@$``*D$````````3@4``"0`````````^@$``%8#``!$
M`P````````````#N!```:@,``,$%``#O````_P(``!X%``"H`P``T`,``)(%
M``"=!```H`4``#X%````````%0(``)4!``"@`````````!P```#Y!```U`$`
M```%```'`P``S````,$!``!*`@``H`$```X!``"+`@```````!0$``!4!```
MKP0``',#``"C`@```````$,````3!```I````!\"````````K`4`````````
M````9`$``),#```H`P``N@```&8$``#B`0``;`$`````````````(`4``"@"
M````````$00``&L```#]````````````````````,P$``'L%``!&`0``D04`
M`````````````````.,"``#_`0``004``!H#`````````````*P$````````
M!0(``#D!```W!0``30(``-$"``".!0```````&\!`````````````*L%````
M````BP,``,<!````````SP4````````.``````````````"#!0```````+H"
M``"-`@```````!<$``"H!````````-X!```E`0``%P````L!````````V0``
M`.(#``!%!```9`(``%`!``";!0``.P4``/8"``!T``````````````!1`0``
M`````(`#``!K`@``B0```#<$``!+!0```````-`!``!,!0``W`(``/X!````
M````700``(0$````````'P,``+(%```X````D0```-D!``"N`0``F@(``'H!
M````````6`4```````#;!0``60```!L```````````````````#S`P``````
M`*H!```1`0``@P,``/@"```6`0```````.4```"@!```)P$``-$#``!2!```
M<`,``(<#``!B`@``:@(``)P$``#*`````````+8$``"N`P``@@,``+D````=
M!```4P0``!L%``"L`````````/0#```J`P``%P(``/`!``#F`@``B@```%0%
M``#%`0``>`,``!T!```2````*P,``$<$````````*0,````````8`0``#`$`
M`#L$``"A`0``/@````````!/`0``!@$``*("``"7`0```````!P#``#U````
MV`````D`````````[``````````]````90,``+X`````````:0```"0%``"U
M!```%`$``,X```!V!```,@(``%`$``!,`0``H@0``!0#``#O`P``V04``",`
M```[`0`````````````,!0``N0$``.<!````````WP$``+L%````````>P0`
M`&8"````````S00``)H!````````+@0``'<"``!1!0``"00``'0%``!D`P``
MU`(`````````````$0```-(%``":!0``,00``'8#``#O`0``>@(``.0$``!9
M`0``8P$```@"`````````````)0%``#O!```@`````````#R!```NP$``,L`
M``">`P``````````````````3@$``)````#?`@``$P,``($$``"+!```#P``
M`&L%```^`@``````````````````NP```'4#``!*!0```````(T$``#_````
M3@,``'L```#>`@```````&8!``"3`@``>`4``!T"```+````^0$``$L```#F
M````W@4``%D#``!6````6P```$$!`````````````/D````G`P``)@4``+T#
M````````!````'8"``##````YP(``+4%```'````+0$``"D"````````V@(`
M`(`"``!@`P``IP(``!L$``"H!0``@0,``$0%``"Q`0``I`0````````]!0``
MJ0(``,D"``"F!0```````(,$``#>````Y`(``,P#``#F`0``XP0``,D#``!A
M!0````````````!A`0``@04``)(`````````%`4``/<#``"P`P``-@,``%(`
M``";`P```0(```````#S!```O`4``%X```!'`0``5P```'L"``!Q`0``4P4`
M`)("```A!```@`$``'("```(!0``;`,``!T#``!2`0``5@0``%D$````````
M````````````````J0,``/`#``"_`0``#@0``.,!``#Q``````````,"``"^
M!```K@```*0!````````CP````0#``"%!0``UP4``-`````V`@```````&`"
M``#H`@```````*\"``!5`P````````$%`````````````-X$``!:`0``%0,`
M`'`$``!'`P``B@$``+`"``#!````E@0``!P%``"X`@``E@```+H%```M`P``
MC@```#H!``!``P``90$``#8%```T`@```````%4!```,````F`0```````"K
M`@``/P(``-D#``!5`@````````X%```9!````````(<"`````````````.0!
M``"P`0``#04`````````````>0,```H"````````B@,``'X#``"\`0``````
M````````````````````````````?@$``#H"``#C`P```````"H```"/`0``
M9@``````````````70$```````"-!0``D0(```````!/!0``@0```*<!``"E
M`0``<P$``-<"`````````````/L!``#G!```O`(``.,`````````1P(`````
M````````!0,``#X#``"F````YP```-P%``")`P```````````````P``E04`
M`)0````)`@``=0(```````!(`P``C`(``"X"``!&!```(@4``.4"```P!0``
M!`4``+`$``#3`0``7`$``)\$``"6`0``;`0``)(!``!)`P``I@,``'8%``"]
M```````````````````````````````,!```(P$`````````````?@``````
M``#2!````````'4```"B`0``7P(``-,"````````LP4``%$$``!`````````
M`(4```#K!```M`$```````!>`@``^@(``"T```#'!```40``````````````
MC0$``-4$```-`````````%8"```)!0``R0```-4"````````/00``.P!````
M````<P```)P%````````$@$``)H#````````)P```!<%``#^`@```````*$#
M``#5````C@,`````````````X`````$!``#7`````````.(`````````:04`
M`#,"``!D!```B`````````"D`P``MP0``#0%``#L`@``*@0``'@"``!:`P``
M+04``)P#``#P`@````````````#&`0``IP4`````````````4@(``%,!```+
M!````````#8$``#;!```200`````````````SP0``'H`````````)@,``+<"
M``"V`P```````"D$``!R`````````!4$``"?`P``&`(```D!````````````
M`%@"```\!0``8````+X"````````````````````````8`0``-,%````````
M?P````````!<````@P(```,```"9`@``````````````````!0```&$"``#0
M`@``*04``-8%``">!```7P,``(@"``#:``````````L#`````````````!$"
M``#2`P``'`(``+@#``!4`P``T0```#`$``"1!```TP0``$@$``!D````2@,`
M`*P#``",`0```````&L#``!.!```E@4``'\$``!\!````````#L```!-````
M`````!\%``"*!0``=00``*4$``#M`P``T`0``"L!``!;!0```````%T"``"X
M`0``#P,````````1!0```````#4#``#8`@``P0,``%(%````````<0```)(#
M``!;`@``)`,```````#\`````````.L!``!Z`P``<04``,X#```6!0``40(`
M`!X`````````%P,``,L%```````````````````0````C`,``#P#````````
ML0```,@"``!Y`````````*T$``"9`P```````#4%``!Q`@``&`,``-@#``#=
M`0``50````````!-`0``C@$```````"$`P``-P(``,0!```R`P``Q`(``.D#
M```@`0``/P```-4#``#7!````````*0%``#Q`P``[0$``-4!``!$`0``30,`
M`.("```*`0``B0$`````````````5P$``',$```F````J@(``+0"````````
M_0,``#D$```3!0``-P,``"$!`````````````.0```"7!````````+X%``#`
M!0```````'$#````````ZP,``,\#``"\`P``)`(``-P!```Q`P``[P(``+L"
M``"%`P``N0(``)$!````````SP`````````E`P``8`$``'L#``!1`P```P4`
M`%P%````````$P```,\"````````D0,``%4%``#J`0``=@$``#4$``#N`P``
M2P$``%<$``!:!````````,(```"-````/`$``"P$``#,`0``<P4``(D%``"Q
M`P``=`0``"0!``#Q`0``,@$``)X%````````-0```&,````/`@``MP4`````
M````````7P```&4%``!)````R@0```````"A`@``JP,`````````````(0(`
M`!`"```U`0````````````````````````````#,!```/@$``$L#``![`0``
MVP````@#```B!```I04``#($``!I!```.P(`````````````0@,``(\%``#.
M`0``Q@0``"0$````````GP$```````#F!```)0(``#D#``#\!```G@```+``
M``#$````00,``*@"``#H`0``;P4``,H"``````````````````"8!0``````
M`/<!```=````T00```````!M`P``OP,```````!%`P``DP```%X$``"'````
M&0(```````"K!````````'<```#4!0``6````/L`````````!P0``,8%````
M````60(``&P````U`@``N`4```````!>!0``N`````````"`!0```````'T!
M``"V`0``4P,``*,!``",!```E`$``(8!``!8!```R0$``$P```!#!0``?04`
M`$($``##`0```````(@%``!^!0```````#@#``#2`@``)@(``+\$````````
MBP$``!H$``#<!````````,X%``#X````$@,``(4$``"3!0``R@,``&X"``"]
M!````````%`%``".!```?P(``&\"``!W`0``6P$``,T#``"T`P``:`4``(L`
M````````Y00```````!!````K@(``````````````````,@#```J`0``+@``
M`$@%```6`@``Z0```%0"``"J!0```````",%```@````W````*X$``"0!0``
M1`(``'P````O`@``P@0``/@!````````Z0$```````!C!```\P$``(,!````
M`````````-H$``"W`P``%P$``'$$``!%!0``(`,``,0%```/`0``=P,`````
M``"L`@``T0$``*0"```"`````````,(!``"H`0``````````````````````
M`*D``````````````!`%``#K`@```````$`!````````/0$``/D"````````
M"@0```L"```?`0``TP,```````#"!0``=04``#0#``##!0``@0(```````!P
M````)04``#(```#!!```&@(```````"G````,P0``-\#``#*`0``S0```/P#
M``"@`@``Z`,``+("``#/`0````````````!R`P``P@(````````[`P``````
M`*T#``!D!0``Z@```$4"``!-!```@0$```,$``#R`P``U04``.`%``"J!```
M``````````!]````9P,``!L"``#Y`P``;00``,P%``!T`@```````$X"``#R
M`@``R@4``$$"``!#`0``+P```/$$````````=`$``'D%``"_!0``D`$`````
M```;`0```````)P"``"M`0````````````#S`@``;P0```````!*`0``````
M```````_!```P`$``#D```#%!0``<`$```````!G`````````+D#``"S!```
M`````$\```"\!```L04``#(%````````%@0```````"4`P``!P$``,<```!(
M````$0,``&H%````````+`$``!4!```(`0``&`4``#P$``#J`P``AP4``#\#
M``````````````````"+!0``/````*H`````````@`0````````N!0``````
M`$P#```K`@``C`4``,0#``"?!0``,0$```````"N!0``/@0``%`#``"]!0``
M.04``+4!``#=`````````*,%````````S0(``,<#``!"````?`$``.,%``!J
M`0``,P,``(8"``!A`P``I0```'`"``#(`0```````$,$```Y`@``````````
M``````````````````""!0``P`(``",$````````$`0``/L$```]`@``````
M`)D!````````%````$(!````````-````.D$``#=`@``6`$```(#``!-!0``
M`````*\%``"5`@```````)@#``##`P```````"L````>`@``VP(```````"%
M`0``(@,```````#2````HP,``*8"``#S````^@0``%H%``#=!```M`4``)T!
M```K!````````-@%``````````````````!I`@``(`0``/L#````````````
M`!D```!&`@``F````#`#````````(0,````````9!0``;@$```\$``"0!```
M%`(``)`#``"?````<P(``+T"``#]`0``G@(``)T#``"=`@``%@,```````";
M`0```````!H!```8!```Q@````````#G`P``4P(```4$``#7`P``[00`````
M````````H`,``-8$``#6`P```````,X$```````````````````&`P``+```
M``````!(`0```@0```0"``#T!````````.$`````````Q`0````$``#@`P``
M*0```((```"=!0``!04```L%````````5P4``/<````&!0``L0(```````!X
M!````"`@("`@(%1O.B``("`@($1A=&4Z(``@("`@1G)O;3H@`"`H)7,@9&%Y
M<R!A9V\I`"`H=&]D87DI`"`H>65S=&5R9&%Y*0`@4W5B:F5C=#H@`"!I;B``
M(P`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@
M=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`E9"!M97-S86=E<R!H879E
M(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A
M;2X`)60@=&\@)60@;V8@)60@365S<V%G97,`)7,@+2!.;W1I8V4`)7,@1FEN
M9V5R<')I;G0`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E
M861Y(&5X:7-T<RX`)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R
M('=A<R!N;W0@<F5N86UE9"X`)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@=&AE
M('-T87)T(&]F('1H92!M;VYT:"X`)7,@:&%S(&%C8V5P=&5D+@`E<R!H87,@
M8V%N8V5L;&5D("5S+@`E<R!H87,@9&5C;&EN960N`"5S(&AA<R!R97!L:65D
M('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L:65D('1O('1H
M92!I;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+@`E<R!H87,@=&5N=&%T:79E;'D@86-C97!T960N`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!R97%U
M97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@<F5Q=65S=',@
M>6]U<B!P<F5S96YC92!A="`E<RX`)7,@=VES:&5S('1O(&%M;65N9"`E<RX`
M)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E<R!W:7-H97,@
M=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+@`E
M<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E
M<R=S(%1A<VML:7-T`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*0`H07!P
M;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C<F5E;BXI`"A$
M:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@
M<V-R965N+BD`*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@
M87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@
M;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*0`H
M4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@
M=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL
M($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@
M*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`M+2!S96QE8W0@+2T`
M,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2X`,2!M97-S86=E(&AA<R!B965N(')E<&]R
M=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`,2!M
M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN`#$P,"!C:&%R86-T
M97)S`#$P,#`@8VAA<F%C=&5R<P`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O
M<FUA=``R-"!H;W5R<P`R-3`@8VAA<F%C=&5R<P`U,#`@8VAA<F%C=&5R<P!!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@;&%R9V4@:6UA9V4@;F%M
M960@)7,@:7,@871T86-H960@=&\@=&AI<R!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!32]030!!8F]U="!T:&ES(&5D:71O<@!!8V-E<'0@<F5Q=65S=`!!8V-E
M<'1E9`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O
M<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G0G<R!N86UE.@!!8W1I;VYS`$%D
M9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE
M<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1H:7,@
M=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY
M(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B(&%S(&%N(&%T=&%C
M:&UE;G0N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R
M97-S($)O;VL`061D<F5S<R!";V]K<P!!9&UI;FES=')A=&EO;@!!9',`06QI
M87,`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL
M(%!E<FUI<W-I;VYS`$%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE
M.@!!;&P@;65S<V%G97,@:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N
M("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W
M:6QL(&)E(&1E;&5T960N`$%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R
M92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&QO=R!F
M:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O>#\`06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES
M=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O
M<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D
M9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'=A>7,`06QW87ES('-A=F4@
M871T86-H;65N=',`06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG
M('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@<V%I
M9#H@`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W
M;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RX`
M06YO;GEM;W5S(%!R;WAY`$%N<W=E<F5D`$%N<W=E<F5D(&UE<W-A9V5S`$%P
M<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!F:6QT97(@
M<G5L97,@=7!O;B!L;V=G:6YG(&]N/P!!<'!L>2!F:6QT97(@<G5L97,@=VAE
M;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/P!!<'!R;W9E`$%P<FEL`$%R8VAI
M=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R
M96-O;6UE;F1E9"$I`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES
M/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$52
M34%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N
M=#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R
M/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F
M;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE;G1L>2!D
M96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/P!!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/P!!
M<G)I=F%L(%1I;64`07-C96YD:6YG`$%S:P!!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T86-H
M`$%T=&%C:"!&:6QE<P!!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI
M8R!K97D@=&\@>6]U<B!M97-S86=E/P!!='1A8VAE9"!&:6QE.@!!='1A8VAE
M9"!F:6QE("(E<R(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET
M<RX@1FEL92!.3U0@871T86-H960N`$%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@
M82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+@!!='1A8VAM96YT`$%T=&%C
M:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP90!!='1A
M8VAM96YT<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD
M965S`$%T=&5N=&EO;@!!='1R:6)U=&5S`$%U9W5S=`!!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E
M;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$
M2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N`$%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E
M<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@861D<F5S<V)O;VL_`$%V86EL
M86)L92!!9&1R97-S(&)O;VMS.@!!=F%I;&%B;&4@9FEE;&1S.@!!=V%I=&EN
M9R!297-P;VYS90!"86-?:R!T;R`E<P!"86-K('1O("5S`$)A8VMG<F]U;F0`
M0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K
M97)B97)O<R!U<V5R;F%M92X`0F-C`$)I<G1H9&%Y`$)L86-K;&ES=`!";&]C
M:R!4>7!E`$)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S<R!T
M:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/P!";V1Y`$)O;&0`0F]O
M:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O=&@`
M0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E`$)U;&QE
M=&5D($QI<W0`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7VAA
M<G-E=`!#86QE;F1A<@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M
M86EL('-E<G9E<BX`0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I
M;"!S97)V97(Z(`!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#
M86YC96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A
M;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R
M9"!I=',@8V]N=&5N=',N`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X
M:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P
M=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V,`0V5L;"!0:&]N90!#96QL
M(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L
M;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5N=&5R`$-E<G1I9FEC871E($1E=&%I
M;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA:7(@4&5R<V]N`$-H86YG90!#
M:&%N9V4@06QL`$-H86YG92!&;VQD97(`0VAA;F=E(&1I<W!L87D@;W!T:6]N
M<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P
M86=E(&%N9"!H;W<@;65S<V%G97,@87)E('-O<G1E9"X`0VAA;F=E(&UA:6P@
M<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N`$-H86YG92!T:&4@;F%M92!A
M;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V4@=&AE(&YA;64L(&%D9')E
M<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&%R86-T97)S('1O(&1I
M<W!L87DZ`$-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAE8VL@86QL
M(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ`$-H
M96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\`0VAO;W-E
M($%C=&EO;CH`0VAO;W-E(&$@;6%I;"!S97)V97(Z`$-H;V]S92!A('!A<W-W
M;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E('1H92!A9&1R97-S(&)O
M;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E<W-E<RX`0VAO;W-E('1H92!O
M<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+@!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&EC:R`E<R!T;R!C
M;VYV97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B<F]W
M<V5R(&-A;B!V:65W+@!#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@:6UA9V4N
M`$-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G92X`0VQI8VL@
M)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<N
M`$-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92X`
M0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,`0VQI8VL@;VX@;VYE(&]F
M('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@
M86QL(&9I96QD<R!T;R!S96%R8V@N`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K
M('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VL`
M0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U
M<B!!9&1R97-S($)O;VL`0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C
M;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<@!#;&EC:VEN9R!O
M;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A
M9`!#;&]S90!#;&]S92!7:6YD;W<`0VQO<V4@=&AI<R!W:6YD;W<`0VQO<V5D
M($9O;&1E<@!#;VQL87!S90!#;VQL87!S92!!;&P`0V]L;&%P<V4@06QL($9O
M;&1E<G,`0V]L;&%P<V4@1F]L9&5R`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO
M=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA
M;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;7!A;GD`
M0V]M<&QE=&5D`$-O;7!O<V4@86YO=&AE<B!M97-S86=E`$-O;7!O<V4@;65S
M<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_`$-O;7!O<V4@;65S<V%G97,@
M=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O
M<G1S('1H92!F96%T=7)E*3\`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#
M;VYF:6=U<F4@)7,`0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA
M>65D+@!#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N`$-O;F9I<FT@
M4&%S<W=O<F0`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N
M;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S
M97)V97(@9F%I;&5D`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT<F]L(%!'4"!S=7!P;W)T(&9O
M<B`E<RX`0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@
M=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE
M<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O;G9E
M<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\`0V]P
M>0!#;W!Y('-E;&5C=&EO;@!#;W!Y('1O(&9O;&1E<@!#;W)R96-T`$-O<G)E
M8W1E9"!497AT`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R
M>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#
M;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A
M+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@;65S
M<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<P!#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U
M;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RX`0V]U;&0@
M;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.
M148@871T86-H;65N="X`0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E
M9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H:79E+@!#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO
M="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E=')I979E
M(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@
M9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B
M87(@:7,@;W!E;BX`0V]U;G1R>0!#<F5A=&4`0W)E871E($9O;&1E<@!#<F5A
M=&4@5FER='5A;"!&;VQD97(`0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`
M0W)E871E(&$@;F5W(&]N90!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E
M<@!#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@
M<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET
M(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@<W5B(&9O
M;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`
M0W5R<F5N="!4:6UE`$-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@
M;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+@!#=7-T;VUI>F4@:&]W('EO=2!S
M96YD(&UA:6PN`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`1$0`1&%I;'D`1&%T7V4`1&%T851R
M964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&5?;&5T92!#;VQU;6X`
M1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN
M9&5N=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$
M96QE9V%T960`1&5L971E`$1E;&5T92!&;VQD97(H<RD`1&5L971E($=R;W5P
M`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!6:7)T=6%L($9O;&1E<@!$96QE
M=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4`1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO
M=&4@<V5R=F5R/P!$96QE=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E
M;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE
M=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`
M1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T960@=&AE(&%T=&%C:&UE
M;G0@(B5S(BX`1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$96QI=F5R
M>2!T:6UE`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S
M>2!I;F9O<FUA=&EO;@!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M
M`$1E<V-R:7!T:6]N`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1I;2!S:6=N871U<F5S/P!$
M:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M=`!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I
M;VYS`$1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S
M86=E/P!$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G90!$:7-P;&%Y('!O<"UU
M<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_`$1I<W!O<VET:6]N`$1O($Y/
M5"!M871C:`!$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O
M;'5M;@!$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/P!$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z`$1O;F4`1&]W;FQO860`1&]W;FQO860@)7,`1&]W
M;FQO860@)7,@:6X@+GII<"!&;W)M870`1&]W;FQO860@06QL($%T=&%C:&UE
M;G1S("AI;B`N>FEP(&9I;&4I`$1O=VYL;V%D($9O;&1E<BAS*0!$;W=N;&]A
M9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T70!$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$;W=N;&]A9"!I;B`N>FEP
M($9O<FUA=`!$<F%F=`!$<F%F="!F;VQD97(`1')A9G1S(&9O;&1E<CH`12U-
M86EL`$4M;6%I;"!!9&1R97-S`$5D:70`161I="!";&%C:VQI<W0`161I="!"
M;&]C:P!%9&ET($9I;'1E<G,`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`
M161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET
M(%9I<G1U86P@1F]L9&5R`$5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO
M;B!F;W(@)7,`161I="!7:&ET96QI<W0`161I="!O<'1I;VYS(&9O<CH`161I
M="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!Y;W5R(&)L86-K;&ES=`!%9&ET
M('EO=7(@9FEL=&5R(')U;&5S`$5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@
M86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N`$5D:70@>6]U<B!W:&ET
M96QI<W0`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"X`16UP='D@1F]L9&5R*',I`$5M<'1Y(%1R87-H(&9O;&1E<@!%
M;7!T>2!?5')A<V@`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;F%B
M;&4@4$=0(&9U;F-T:6]N86QI='D_`$5N86)L92!3+TU)344@9G5N8W1I;VYA
M;&ET>3\`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'
M86QL97)I97,@:6X@=&5X=#\`16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_`$5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N8W)?>7!T:6]N($]P
M=&EO;G,`16YD`$5N9"!F;W)W87)D960@;65S<V%G90!%;FQA<F=E($5D:71O
M<@!%;G1E<B!087-S<&AR87-E`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE
M=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S
M96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T
M<F%S:"!F;VQD97(`16YT<GD@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('1H92!A9&1R97-S(&)O;VL`17)R;W(`17)R;W(@<V5N9&EN9R!R97!L
M>3H@)7,N`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`179E;G0@<W5C8V5S
M<V9U;&QY(&1E;&5T960N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD
M97)S`$5X<&%N9"!&;VQD97(`17AP86YD($YA;65S`$5X<&%N9"!N86UE<R!I
M;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C
M:V=R;W5N9#\`17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F
M875L="!I;B!T:&4@9F]L9&5R<R!V:65W/P!%>'!A;F1I;F<`17AP:7)A=&EO
M;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C
M;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F5B<G5A<GD`1F5T8V@@
M36%I;`!&971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!&971C:"!M
M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_`$9E=&-H;6%I;#H@;F\@;F5W(&UE
M<W-A9V5S+@!&:5]L=&5R<P!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%-E='1I;F=S`$9I;'1E<B!M
M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\`1FEL=&5R('-U<'!O<G0@
M:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`$9I;'1E<G,`1FEL=&5R<R!.
M3U0@06-T:79E`$9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G90!&:6YD`$9I
M<G-T($UA:6QB;W@@4&%G90!&:7)S="!086=E`$9O7W)W87)D`$9O;&1E<B!.
M879I9V%T;W(`1F]L9&5R(%-U;6UA<GD`1F]L9&5R('-H87)I;F<@:7,@;F]T
M(&5N86)L960N`$9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N`$9O;G0@0V]L
M;W(`1F]R;6%T(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE
M=R!F;W(@;65S<V%G97,@9&%T960@=&]D87D`1F]R;7,`1F]R=6US`$9O<G=A
M<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A
M9V4@9G)O;2`E<P!&<@!&<F%M97,`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R
M964O0G5S>2!297!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q
M=65S="!297-P;VYS90!&<F]?;0!&<F]M($%D9')E<W,`1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($YA;64`1G=D.@!&=V0Z(`!&=V0Z("5U($9O<G=A<F1E9"!-
M97-S86=E<P!'96YE<F%L($]P=&EO;G,`1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;@!'96YE<F%T960@0V]D90!'970@;VYL>2!N97<@;65S<V%G97,_("A)
M34%0(&]N;'DI`$=I=F5N($YA;64`1W)A;G0@86-C97-S`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P
M<P!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`2%1-3"!697)S:6]N(&]F
M($UE<W-A9V4`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA<V@M
M06QG;W)I=&AM`$AE861E<@!(96%D97)S`$AE:6=H=`!(96QP`$AE<F4@:7,@
M=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.@!(:61D96X`2&ED9&5N
M(&EN(%1H<F5A9"!6:65W`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E
M9`!(:6=H`$AI9V@@4')I;W)I='D`2&EG:&5S=`!(;VUE`$AO;64@061D<F5S
M<P!(;VUE(%!H;VYE`$AO<F1E`$AO<FEZ;VYT86P@4G5L90!(;W<@9&\@>6]U
M('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\`2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN
M(&$@<F5P;'D`24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*0!)34%0(&UA
M:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I
M;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I
M;&5D.B`E<P!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$EC;VYS($]N;'D`26-O;G,@
M=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L
M87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W
M+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U
M<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EG;F]R90!)9VYO<F4@06QL`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E<P!);7!O
M<G0`26UP;W)T($ME>0!);7!O<G0@2V5Y<&%I<@!);7!O<G0@4$=0($ME>0!)
M;7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y`$EM<&]R="!097)S;VYA
M;"!0=6)L:6,@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4R]-24U%($-E<G1I
M9FEC871E<P!);7!O<G0@4'5B;&EC($ME>0!);7!O<G0@4'5B;&EC(%!'4"!+
M97D`26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y`$EM<&]R="!3+TU)344@2V5Y
M`$EM<&]R="!M8F]X($9I;&4`26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O
M;&1E<B`E<RX`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O<G1A;G0@
M;65S<V%G97,`26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E<RX`26UP;W)T
M960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26X@4')O8V5S<P!);F)O
M>`!);F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@
M<F5P;'D_`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/P!)
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N`$EN8W)E87-E($EN9&5N=`!);F1I=FED=6%L
M(%5S97)S`$EN9F\`26YF;W)M871I;VX`26YS97)T($-?;VQU;6X@069T97(`
M26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS
M97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&-E;&P@869T97(`26YS
M97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O
M;'5M;B!B969O<F4`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R
M86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F
M;W)E`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=F%L:60@06-T:6]N('-E
M;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV86QI9"!A<'!L:6-A=&EO
M;BX`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+@!);G9A;&ED(&ME>0!);G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2X`26YV86QI
M9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`26YV86QI9"!S;W5R8V4@861D
M<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5R=`!)<W-U97(`271A
M;&EC`$IA;G5A<GD`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`
M2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$ME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T
M:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2V5Y('-U
M8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!,86YG
M=6%G90!,87-T($UA:6QB;W@@4&%G90!,87-T(%!A9V4`3&%S="!L;V=I;CH@
M)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,
M87EO=70`3&E?;FL@071T86-H;65N=',`3&EN:V5D(&%T=&%C:&UE;G1S(&%R
M92!F;W)B:61D96XN`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="!486)L97,`3&ES=&EN9R!I;B!T:&4@2&5A9&5R`$QI<W1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$QO8V%L($UA:6QB;W@Z`$QO8V%L92!A;F0@5&EM
M90!,;V-A=&EO;@!,;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G:6X`
M3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@
M9F%I;&5D+@!,;W<`3&]W(%!R:6]R:71Y`$QO=V5R(&=R965K(&QE='1E<G,`
M3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QO=V5S
M=`!-30!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$UA
M:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SH`36%I;&)O>`!-86EL8F]X
M(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M<F-H`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG
M('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`36%R:R!M97-S86=E<R!A<R!S965N
M/R`H24U!4"!O;FQY*0!-87)K('-I;7!L92!M87)K=7`_`$UA=&-H($%L;"!1
M=65R:65S`$UA=&-H($%N>2!1=65R>0!-871C:&EN9R!F:65L9',`36%X:6UU
M;2!!='1A8VAM96YT(%-I>F4`36%X:6UU;2!N=6UB97(@;V8@871T86-H;65N
M=',@<F5A8VAE9"X`36%X:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A
M8VAE9"X`36%Y`$UE971I;F<@0V%N8V5L;&%T:6]N`$UE971I;F<@26YF;W)M
M871I;VX`365E=&EN9R!0<F]P;W-A;`!-965T:6YG(%)E<&QY`$UE971I;F<@
M57!D871E`$UE971I;F<@57!D871E(%)E<75E<W0`365M8F5R<P!-96YU(&UO
M9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!#;VUP;W-I=&EO;@!-
M97-S86=E($1A=&4`365S<V%G92!/<'1I;VYS`$UE<W-A9V4@4V5A<F-H`$UE
M<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!6:65W:6YG`$UE<W-A9V4@9FQA
M9W,`365S<V%G92!F;VQD97)S`$UE<W-A9V4@9G)O;2`E<P!-97-S86=E(&UA
M=&-H97,`365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2X`365S<V%G
M92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<P!-97-S
M86=E('-E;G0@<W5C8V5S<V9U;&QY+@!-97-S86=E<R!P97(@<&%G92!I;B!T
M:&4@;6%I;&)O>"!V:65W+@!-97-S86=E<R!T;P!-971H;V0`36EM92!4>7!E
M`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-
M;P!-;V)I;&4@36%I;`!-;V1I9FEE9"!$871E`$UO9&EF>0!-;VYT:&QY`$UO
M=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V
M92!D;W=N`$UO=F4@=&\@9F]L9&5R`$UO=F4@=7``37D@06-C;W5N=`!.3RP@
M22!$;R!.3U0@06=R964`3F%M90!.965D<R!!8W1I;VX`3F5T=V]R:P!.979E
M<@!.979E<B!S879E(&%T=&%C:&UE;G1S`$YE=P!.97<@0V%T96=O<GD`3F5W
M($9O;&1E<@!.97<@36%I;`!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@
M;65S<V%G97,`3F5X=`!.97AT($UE<W-A9V4`3F5X="!086=E`$YO`$YO($-E
M<G1I9FEC871E(&9O=6YD`$YO($5N8W)Y<'1I;VX`3F\@2V5Y<R!I;B!+97ER
M:6YG`$YO(%!E<G-O;F%L($-E<G1I9FEC871E(%!R97-E;G0`3F\@4'5B;&EC
M($ME>7,@1F]U;F0`3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N`$YO
M(&%T=&%C:&UE;G1S(&9O=6YD+@!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!C:&%N9V4N`$YO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E
M<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F;VQD97(@<V5L96-T960N`$YO(&9O
M;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M86EL+@!.;R!F;VQD
M97)S('=E<F4@<W!E8VEF:65D`$YO(&UE<W-A9V4@8F]D>2!T97AT`$YO(&UE
M<W-A9V4@<W5P<&QI960N`$YO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R
M8V@N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K
M('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('-P
M96QL:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N<P!.;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`
M3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`3F]N90!.;W)M86P`3F]T($%F
M=&5R`$YO="!"969O<F4`3F]T($1E;&5T960`3F]T($1R869T`$YO="!);7!O
M<G1A;G0`3F]T(%!E<G-O;F%L`$YO="!D96QE=&5D(&UE<W-A9V5S`$YO="!I
M;7!O<G1A;G0@;65S<V%G97,`3F]T97,`3F]V96UB97(`3G5M8F5R(&]F(&UO
M;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L971I
M;F<@;6]N=&AL>2X`3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T
M;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B
M:F5C=`!/8FIE8W0@0W)E871O<@!/8W1O8F5R`$]F9FEC90!/;&0@;65S<V%G
M97,`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"X`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O;F4@
M96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O
M=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@
M<VEG;F5D(%,O34E-12!P87)T+@!/<'1I;VYA;"!087)T:6-I<&%N=`!/<'1I
M;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`
M3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($]P=&EO
M;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP
M="!-97-S86=E`%!'4"!%;F-R>7!T960@1&%T80!01U`@17)R;W(Z(`!01U`@
M17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K
M97DN`%!'4"!/<'1I;VYS`%!'4"!087-S<&AR87-E($EN<'5T`%!'4"!097)S
M;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN`%!'4"!0=6)L:6,@2V5Y`%!'4"!0=6)L:6,@2V5Y<FEN9P!0
M1U`@4VEG;B!-97-S86=E`%!'4"!3:6=N+T5N8W)Y<'0@365S<V%G90!01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R
M96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B
M;&4@=&\@8F4@=F5R:69I960N`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT
M;'D@86-T:79E('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R
M>7!T960N`%!(4"!#;V1E`%!(4"!3:&5L;`!03U`S("A!=71O($1E=&5C="!0
M<F]T;V-O;',I`%!A9&1I;F<`4&%G92`E9"!O9B`E9`!086=E('=I=&@@=&AE
M($9I<G-T(%5N<V5E;B!-97-S86=E`%!A9V4@=VET:"!T:&4@3&%S="!5;G-E
M96X@365S<V%G90!087)T*',I`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C
M=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N
M+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O
M<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C
M;&EP8F]A<F0`4&5N9&EN9R!3:6=N=7!S.@!097)C96YT`%!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VX`4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C86X@;F]T(&)E
M(&-H86YG960N`%!E<G-O;F%L`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE
M`%!I>&5L<P!0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A
M;F0@9F]R=V%R9',_`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.@!0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE
M=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I
M9&4@>6]U<B!P87-S=V]R9"X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M92!A;F0@<&%S<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92X`
M4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S
M+@!0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N
M9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`
M4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY
M(&%C=&EO;G,N`%!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T
M;R!S96%R8V@N`%!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T
M:&ES(&]P97)A=&EO;BX`4&]L;',`4')E8V5D92!Y;W5R('-I9VYA='5R92!W
M:71H(&1A<VAE<R`H)RTM("<I/P!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D
M('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S($UE<W-A9V4`4')E=FEO=7,@
M4&%G90!0<FEN=`!0<FEN="!D;V-U;65N=`!0<FEO<FET>0!0<FEV871E($ME
M>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O;7!T(&5V97)Y('1I
M;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/`%!R;VUP
M="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T
M;R!915,`4')O=&]C;VPZ`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2X`4'5R7V=E($1E;&5T960`4'5R9V4@1&5L971E9`!0=7)G92!4
M<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E
M<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N`%!U<F=E(&]L9"!M
M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/P!1=65R>0!24T$@4'5B;&EC
M($ME>2`H)60@8FET*0!2871I;P!295]Q=65S="!$96QI=F5R>2!#;VYF:7)M
M871I;VX`4F5A9`!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@
M=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D
M:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T($UE<W-A9V4`4F5D:7)E8W0@=&AI
M<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE9"X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!&;VQD97(@5FEE=W,Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z
M`%)E;&]A9"!6:65W`%)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E($UA:6QB;W@Z`%)E
M;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!&:65L9"!&
M<F]M(%-E87)C:`!296UO=F4@<&%I<@!296UO=F4@=7-E<@!296UO=F4@=7-E
M<CH@)7,`4F5N86UE($9O;&1E<BAS*0!296YA;64@<V5N="UM86EL(&9O;&1E
M<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_`%)E;F%M:6YG("(E<R(@=&\@(B5S
M(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;%]Y
M('1O($QI<W0`4F5P;&%C92!W:71H.@!297!L>0!297!L>2!396YT+@!297!L
M>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2!T;R!,:7-T`%)E<&QY('1O
M($QI<W0Z`%)E<&QY('1O(%]!;&P`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D
M($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT
M:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BX`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S(%-P86T`4F5Q=65S="!A
M(%]296%D(%)E8V5I<'0`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S="!D96QI=F5R>2!C;VYF:7)M
M871I;VX_`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`4F5Q=6ER960@4&%R=&EC
M:7!A;G0`4F5S970`4F5S<&]N9&5N="!3=&%T=7,@57!D871E9"X`4F5S=6QT
M<P!297-U;64`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O('1H92!M86EL
M8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN
M9R!A(&UE<W-A9V4_`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<P!2;VQE`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T
M:65S`%)O=W,Z`%)U;@!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`
M4R]-24U%($5N8W)Y<'0@365S<V%G90!3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4`4R]-24U%($5R<F]R.B``4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A
M<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!3+TU)344@3W!T:6]N<P!3
M+TU)344@4&%S<W!H<F%S92!);G!U=`!3+TU)344@4&5R<V]N86P@2V5Y<&%I
M<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!3
M+TU)344@4'5B;&EC($ME>7)I;F<`4R]-24U%(%!U8FQI8R]0<FEV871E($ME
M>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D+@!3+TU)344@4VEG;B!-97-S86=E
M`%,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G90!3+TU)344@<W5P<&]R="!I
M<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`4R]-24U%('-U<'!O<G0@:7,@
M;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L
M92!T;R!B92!D96-R>7!T960N`%,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B
M;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@
M=F5R:69I960N`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4U%,(%-H96QL`%-32`!380!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S
M`%-A=F4`4V%V92`E<P!3879E($%T=&%C:&UE;G1S('=I=&@@;65S<V%G92!I
M;B!S96YT+6UA:6P@9F]L9&5R/P!3879E($1R869T`%-A=F4@3W!T:6]N<P!3
M879E(%]$<F%F=`!3879E(&%S`%-A=F4@9')A9G1S(&%S('5N<V5E;C\`4V%V
M92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D
M<F5S<R!B;V]K/P!3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/P!3
M879E('-E;G0@;6%I;#\`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V:6YG
M('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("5S`%-E87)C:`!396%R8V@@)7,`4V5A<F-H(%)E<W5L=',`4V5E;@!3
M96QE8W0`4V5L96-T($%N;W1H97(@06-C;W5N=`!396QE8W0@82!D871E`%-E
M;&5C="!A(&9I96QD`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N
M97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D
M`%-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S
M96%R8VAI;F<@9F]R(&%D9')E<W-E<RX`4V5L96-T(&%L;`!396QE8W0@86X@
M86-C;W5N=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T
M:&4@;6%I;"!S97)V97(@='EP90!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;&5C=&5D($%D9')E<W,@8F]O:W,Z
M`%-E;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E;F0@365S<V%G90!396YD(%!R
M;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;G0@;6%I;"!F;VQD97(`4V5N="!M
M86EL(&9O;&1E<CH`4V5P=&5M8F5R`%-E<FEA;"!.=6UB97(`4V5R=F5R`%-E
M<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N`%-E<G9E<CH`4V5T('!R969E
M<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L
M971E(&UE<W-A9V5S+@!3970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@
M8V]M<&]S:6YG(&UE<W-A9V5S/P!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA
M="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE
M;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N
M<RX`4VAA<F4@1F]L9&5R<P!3:&%R92!M86EL(&9O;&1E<G,`4VAA<F4@>6]U
M<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RX`4VAO<G0@4W5M;6%R
M>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\`4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W
M;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E('1O9V=L960@96%S
M:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+@!3:&]U;&0@=&AE(&)O9'D@;V8@
M=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\`
M4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V
M:6YG(&$@9')A9G0_`%-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E
M(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\`4VAO=P!3
M:&]W($%L;"!&;VQD97)S`%-H;W<@06QL($AE861E<G,`4VAO=R!$96QE=&5D
M`%-H;W<@3&EM:71E9"!(96%D97)S`%-H;W<@36%I;&EN9R!,:7-T($EN9F]R
M;6%T:6]N`%-H;W<@56YS=6)S8W)I8F5D`%-H;W<@86X@:6-O;B!T;R!A;&QO
M=R!S=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\`4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&QE9V5N
M9"!I;B!T:&4@;6%I;&)O>"!V:65W/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@
M=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=VX`4VAR
M:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S=`!3:5]Z90!3:6=N('5P`%-I9VYA='5R90!3:6=N
M871U<F4@06QG;W)I=&AM`%-I9VYE9`!3:7IE`%-K:7`@36%I;G1E;F%N8V4`
M4V]R="!B>2!!<G)I=F%L`%-O<G0@8GD@1&%T90!3;W)T(&)Y($9R;VT@061D
M<F5S<P!3;W)T(&)Y($UE<W-A9V4@4VEZ90!3;W)T(&)Y(%-U8FIE8W0`4V]R
M="!B>2!4:')E860`4V]R="!B>2!4;R!!9&1R97-S`%-O=7)C92!A9&1R97-S
M`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%M(&9O;&1E<CH`4W!E
M8VEA;"!#:&%R86-T97(@26YP=70`4W!E;&P@0VAE8VME<@!3<&5L;"!C:&5C
M:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P
M96QL(&-H96-K:6YG+@!3=&%R=`!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`
M4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I<"!!='1A8VAM96YT
M`%-T<FEP(&QI;F5B<F5A:W,_`%-T>6QE(%M#4U-=`%-U`%-U8E]J96-T`%-U
M8FIE8W0`4W5B:F5C="!&:65L9`!3=6)M:70`4W5B<V-R:6)E('1O($9O;&1E
M<BAS*0!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@=W)O=&4@)7,`
M4W5G9V5S=&EO;G,`4W5M;6%R>0!3=7!E<G-C<FEP=`!3=7)N86UE`%-W:71C
M:"!#;VUP;W-I=&EO;B!-971H;V0`4W=I=&-H('1O($A434P@8V]M<&]S:71I
M;VX`4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I;VX`5%-6(&9I;&4`
M5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A<VMS
M`%1E7WAT`%1E;&5P:&]N92!.=6UB97(`5&5N=&%T:79E;'D@06-C97!T(')E
M<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5X="!/;FQY`%1E>'0@86QI
M9VX`5&@`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10
M(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@1G)O;3H@8V]L=6UN
M(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z`%1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`
M5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y
M;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O
M=W,_`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`
M5&AE(&-U<G)E;G0@9F]L9&5R*',I("(E<R(@=VEL;"!B92!R96YA;65D('1O
M("(E<R(N`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E
M<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+@!4:&4@979E;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L9&5R("(E<R(@86QR96%D
M>2!E>&ES=',`5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL;&5G86P@8VAA
M<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E('!R;V)L96US+B!0
M;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!F;VQD
M97(@(B5S(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB
M960@=&\@:70N`%1H92!F;VQD97(@(B5S(B!W87,@9&5L971E9"!B=70@>6]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@9F]L9&5R("(E
M<R(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N
M`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%1H
M92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@(B5S
M(BX`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O
M8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D
M:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N
M("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H
M92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@17AI
M=&EN9RX`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N`%1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@
M86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4
M:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B
M92!R97!L86-E9"X`5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E
M<&QA8V5D+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML
M:7-T+@!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A
M=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C
M97-S9G5L;'D@<W1O<F5D+@!4:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI
M<R!M86EL8F]X+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R
M;V)L96T@97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X
M+B!4:&4@<V5R=F5R('-A:60Z("5S`%1H97)E('=A<R!A('!R;V)L96T@97AP
M=6YG:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@
M;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI
M;F<@;65S<V%G97,@9G)O;2`B)7,B('1O("(E<R(N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE
M<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S
M86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<P!4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S
M(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S
M(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE('1A<VLZ("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+@!4:&5R
M92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B
M)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T+@!4:&5R
M92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT
M.B`E<RX`5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0`
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RX`5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I
M;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S
M965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A
M;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G92!H87,@8F5E
M;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N`%1H:7,@;65S<V%G92!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N`%1H:7,@;65S<V%G
M92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E
M(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"X`5&AI<R!M97-S86=E('1O
M`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M`%1H<F5A9"!6:65W`%1I;64@5')A8VMI;F<`5&ET;&4`5&\`5&\@061D<F5S
M<P!4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE(&-L:6-K:6YG+@!4
M;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4
M;W1A;"!!='1A8VAM96YT<R!3:7IE.@!4<F%S:"!F;VQD97(`5')A<V@@9F]L
M9&5R.@!4=0!54DP`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!E>'1R86-T(&-E<G1I
M9FEC871E(&1E=&%I;',`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!R971R:65V92!Q=6]T80!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F%N<W=E<F5D`%5N86YS=V5R960@;65S<V%G
M97,`56YD96QE=&4`56YD97)L:6YE`%5N9&ES8VQO<V5D(%)E8VEP:65N=',`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N9FEL960`
M56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<P!5;FMN;W=N`%5N:VYO
M=VX@365E=&EN9P!5;FYA;65D`%5N<V5E;@!5;G-U8G-C<FEB92!F<F]M($9O
M;&1E<BAS*0!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E
M<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!P97(@
M;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S92!#=7)R96YT
M.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@24U!4"!F;VQD97(@<W5B<V-R
M:7!T:6]N<S\`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BX`57-E<@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@
M3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R;F%M90!5<V5R;F%M93H`
M57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!686-A=&EO;@!686QI
M9&ET>0!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H
M879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!6:65W`%9I97<@)7,`
M5FEE=R`E<R!0=6)L:6,@2V5Y`%9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W`%9I97<@4&5R<V]N86P@4')I=F%T92!+97D`5FEE=R!0
M97)S;VYA;"!0=6)L:6,@2V5Y`%9I97<@5&AR96%D`%9I97<@5&AU;6)N86EL
M`%9I97<@979E;G0`5FEE=R!M97-S86=E<R!I;B`E<P!6:65W(&]R(&UA:6QB
M;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CH`5FEE=R!T87-K`%9I97<@=&AE
M($EM86=E<P!6:7)T=6%L($9O;&1E<B`B)7,B(&-R96%T960@<W5C8V5S9G5L
M;'DN`%9I<G1U86P@1F]L9&5R<P!6:7)T=6%L(&9O;&1E<B!L86)E;`!790!7
M965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@
M87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\`5VAE;B!D96QE=&EN9R!M97-S86=E<RP@;6]V92!T
M:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E860@;V8@;6%R:VEN9R!T
M:&5M(&%S(&1E;&5T960_`%=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W
M:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N/P!7:&5N('-A=FEN
M9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\`
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+@!7:&ET96QI<W0`5VED=&@`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H
M(&]F('1H92!T86)L90!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8-3`Y=C,@
M0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8
M-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T
M($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`665A
M<FQY`%EE<P!997,L($D@06=R964`66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T
M;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R
M('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BX`66]U
M(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W
M:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T
M960N`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO=2!C86X@;F]T
M(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E
M<@!9;W4@:&%V92`E<R!N97<@;65S<V%G97,N`%EO=2!H879E(#$@;F5W(&UE
M<W-A9V4N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@;F5W
M(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M
M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SH`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N`%EO=2!M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N
M`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT
M<R!T;P!9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="X`
M66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E
M;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T
M(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y
M(&$@<F5C:7!I96YT+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!W97)E(&YO="!S=6)S8W)I
M8F5D('1O("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C
M<FEB960@=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I
M8F5D(&9R;VT@(B5S(@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O
M;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,`
M66]U<B!0<FEV871E($ME>0!9;W5R(%!U8FQI8R!+97D`66]U<B!A8V-O=6YT
M<SH`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92X`66]U<B!C
M=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-H87)S970@9F]R('-E
M;F1I;F<@;65S<V%G97,Z`%EO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO
M9"!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&ED96YT:71Y
M.@!9;W5R(&9U;&P@;F%M93H`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9;W5R('-I9VYA='5R93H`6TYO
M(%-U8FIE8W1=`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`%]!
M9&UI;FES=')A=&EO;@!?0F-C`%]";&%C:VQI<W0`7T-C`%]$96QE=&4`7T1E
M;&5T92!2;W<`7T9O;&1E<G,`7T=R;W5P<P!?2&5L<`!?261E;G1I='D`7TEM
M86=E(%!R;W!E<G1I97,N+BX`7TEN8F]X`%],;V<@:6X`7TQO9R!O=70`7TUE
M<W-A9V4@4V]U<F-E`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES
M<VEO;G,`7U!R:6YT`%]0<FEO<FET>0!?4F5F<F5S:"`E<P!?4F5M;W9E($QI
M;FLN+BX`7U)E<&QY`%]396%R8V@`7U-E;F0@365S<V%G90!?4V5T=7``7U1A
M8FQE(%!R;W!E<G1I97,N+BX`7U1H<F5A9`!?5&\`7U5N9&5L971E`%]5<V5R
M<P!?5FEE=R!4:')E860`7U=H:71E;&ES=`!A9&1R97-S(&)O;VL`871T86-H
M;65N=`!C86QE;F1A<@!C;&EC:R!H97)E`&9I;&4`;F%M90!N;VYE`&YO="!Y
M970@:6UP;&5M96YT960`;W(`<&5R8V5N=`!P:7AE;',`<W!E;&QI;F<@97)R
M;W(`<W!E;&QI;F<@97)R;W)S`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FT`=6YN86UE9`!V0V%R9`!Y;W5R(&)L86-K;&ES=`!Y;W5R('=H
M:71E;&ES=`!0<F]J96-T+4ED+59E<G-I;VXZ($E-4"`T+C`N,0I297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#4M,#$M,3,@,#@Z,#`K,#DP,`I,87-T+51R86YS;&%T;W(Z($AI
M<F]M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U:W5B82YA8RYJ<#X*3&%N9W5A
M9V4M5&5A;3H@2F%P86YE<V4@/$Q,0&QI+F]R9SX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/5-(24947TI)
M4PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@((BVD.:!1@`@
M()/ZE72!1@"-MX]OD&R!1@`@*"5S()/ZD4\I`"`HC:&3^BD`("B-\)/Z*0`@
M((R/EKR!1@`@(``C`"5D((S"@LR#@8-B@UJ!6X-7@LU34$%-@L6"R(*B@L:*
MQY>=CM*"R97QC9""LX+J@MR"M8*]@4(`)60@C,*"S(.!@V*#6H%;@U>"S5-0
M04V"Q8+(@J*"QI7QC9""LX+J@MR"M8*]@4(`)60@C,*"S(.!@V*#6H%;@U>"
MS5-004V"Q8*@@NF"QHK'EYV.TH+)E?&-D(*S@NJ"W(*U@KV!0@`E9"",PH+,
M@X&#8H-:@5N#5X+-4U!!38+%@J""Z8+&E?&-D(*S@NJ"W(*U@KV!0@`@)60@
M+2`E9"`O("5D()+*`)+*DFT@+2`E<P`E<R"39(YQCG>6Y``E<R"5VX[GD8"-
M[(+,BFV41@`E<R"#5(-#@Y.#08-B@W8`)7,@DZ^(TX_PC8``)7,@@LV*^8+)
MD;:-W8*U@MR"MX%"`"5S((+-@K>"Q8+)D;:-W8*U@MR"MX%")7,@@W2#2(.+
M@U^"S):\D4^"S97/C5B"LX+J@MR"N8+Q@L6"M8*]@4(`)7,@@LV0LX*U@J*,
M8(ZN@LR#@8%;@XN#>X-B@TZ#6(+%@LV"H(+H@MR"N8+Q@4(`)7,@@W2#2(.+
M@U^"S):\D4^"S8%!EHB,CH+,CXF"WX+)E<^-6(*S@NJ"W(*W@4(`)7,@@LV.
M\Y>=@K."ZH+<@K6"O8%"`"5S((*S@O&"S2`E<R""\(-,@X.#DX-:@XN"M8+<
M@K6"O8%"`"5S((*S@O&"S8ZKD=Z"M8+<@K6"O8%"`"5S((*S@O&"JI=<DNB/
M[I7Q@LR7=HN!@LF5U).:@K6"W(*U@KV!0@`E<R""LX+Q@JH@)7,@@M:"S(^U
MD=*"R974D$V"M8+<@K6"O8%"`"5S((*S@O&"JI=<DNB/[I7Q@O"1EX+!@L2"
MJX+<@K6"O8%"`"5S((*S@O&"JHF\CO.1^(*U@MR"M8*]@4(`)7."JI5+EW:"
MQ8*W`"5S()6J`"5S((*J@J""Z(+<@KF"\8%"`"5S((*S@O&"JH*@@LB"O8+,
MEUR2Z(_NE?&"\)=VBX&"M8+$@J*"W(*W@4(`)7,@@K."\8+-@J""R(*]@JH@
M)7,@@LF/;Y#(@K>"Z8*Q@L:"\)=VBX&"M8+$@J*"W(*W@4(`)7,@@K."\8*J
M("5S((+,B?R2Z(+PBO.678*U@L2"HH+<@K>!0@`E<R""LX+Q@LV"H(+(@KV"
MJB`E<R""\(^SDFV"MX+I@K&"QH+PBO.678*U@L2"HH+<@K>!0@`E<R""LX+Q
M@JH@)7,@@LF"PH*B@L2"S(W%D%:/[I7Q@O"*\Y9=@K6"Q(*B@MR"MX%"`"5S
M((+,@T&#:(.,@UB2H``E<R""S)=<DNB57``E<R""S(.!@X*2H``E<R""S(->
M@UB#3H.*@UB#9P`E<SHE<R`H)60F;F)S<#LO)FYB<W`[)60I`(%IE<^-6(+P
MDTN7<(*U@L2!08Z?@LR)YI;*@M:(VI.N@K6"W(*W@4*!:@"!:97/C5B"\)1P
MBOR"M8+$@4&#@8%;@XN-[)"LB>:6RH+6EM^"Z(+<@K>!0H%J`(%ID5."Q(+,
ME<^-6(+PE&J*_(*U@L2#@8%;@XN-[)"LB>:6RH+)EM^"Z8%"@6H`@6F14X+$
M@LR5SXU8@O"4:HK\@K6"Q)&7D$V"MX+I@4*!:@`J($]+@O"#3H.*@V*#3H*U
M@L22QXG!@K6"W(*W("H`*B"#08-H@XR#6(+PD4F1\(*U@L2)NH*S@J(@*@`M
M+2"129'P("TM`()0@L*"S(.!@V*#6H%;@U>"JE-004V"Q8+(@J*"QH*U@L2#
M5H-8@V6#@(K'EYV.TH+)E?&-D(*S@NJ"W(*U@KV!0@""4(+"@LR#@8-B@UJ!
M6X-7@JI34$%-@L6"R(*B@L:"M8+$E?&-D(*S@NJ"W(*U@KV!0@""4(+"@LR#
M@8-B@UJ!6X-7@JI34$%-@L:"M8+$@U:#6(-E@X"*QY>=CM*"R97QC9""LX+J
M@MR"M8*]@4(`@E""PH+,@X&#8H-:@5N#5X*J4U!!38+&@K6"Q)7QC9""LX+J
M@MR"M8*]@4(`,3`P()6VCIH`,3`P,""5MHZ:`#$RCIZ*U(Q@CJX`,C2.GHK4
MC&".K@`R-"".GHK4`#(U,""5MHZ:`#4P,""5MHZ:`(*Q@LR#=8.-@V*#3H+-
M@V:!6X->@WB!6X-8@JJ52Y=V@L6"MX%"`))VEKV328+(@T>#B8%;@JJ4K9"V
M@K6"W(*U@KT`D>6"JX+(B>:1G"`E<R""JI-9E72"LX+J@L2"HH+<@K>!0@!0
M1U",]HI*C*Z"JH.!@V*#6H%;@U>"S(C#C8:)NX+)E4N7=H+%@K>!0@!01U",
M]HI*C*Z"JH^0EKR"LX+J@KV#@8-B@UJ!6X-7@LR,GX_8@LF52Y=V@L6"MX%"
M`%!'4(SVBDJ,KH%!4$=0E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ(PXV&
MB;N#@8-B@UJ!6X-7@LR5G(V&@LF52Y=V@L6"MX%"`%!'4(SVBDJ,KH%!4$=0
ME.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/D):\@LF5
M2Y=V@L6"MX%"`%,O34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN@JB"YH+1@W"#
M6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7@LR5G(V&@LF52Y=V@L6"MX%"
M`%,O34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9
M@JJ#@8-B@UJ!6X-7@LR/D):\@LF52Y=V@L6"MX%"`%,O34E-18SVBDJ,KH*J
M@X&#8H-:@5N#5X+,B,.-AHF[@LF52Y=V@L6"MX%"`$%-+U!-`(*Q@LR#1X-F
M@T*#7H%;@LF"PH*B@L0`EW:+@8+PCO.1^(*W@ND`CO.1^(W/@MT`5D93@V:#
M0H.,@TZ#9X.*@LR-[)"L@LV#08-.@UJ#6(N1E-N"LX+J@MR"M8*]@4(`5D93
M@W2#0(-#@XN"S(WLD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0@"#08-*
M@T6#DX-G@LR#<(-8@X^!6X-H`(-!@TJ#18.3@V>"S9.`C(N"LX+J@L2"HH+<
M@K>!0@"#08-*@T6#DX-GEKR!1@"/B))U`)+'B<$`@U2#=8-/@XN!6X-V@O"2
MQXG!`(-4@W6#08-.@UJ#6(R@@O"2QXG!`(*Q@K&"R9+'B<$Z`)!6@K6"HH-/
M@XN!6X-V@O"2QXG!`)!6@K6"HH+P@T&#3H-:@UB,H)+'B<$`D%:+2X.&@5N#
M58+PDL>)P8%&`(-2@XF#@(+PDL>)P0"05HM+@X&#DX-O@O"2QXG!@48`@WF#
M08+PDL>)P0`E<R"#@8-J@X6!6X+P($UO>FEL;&$@@LR#5(-#@VB#;X%;@LF2
MQXG!@K>"Z0".A(+,EUR2Z)5<@LF2QXG!@K>"Z0"#08-H@XR#6)*@@LF2QXG!
M.@".A(+,@LR#08-H@XR#6)*@@LF2QXG!`(.&@5N#58+PDL>)P0`B)7,B((+P
MDUF5=(*U@MR"M8*]@4(`@X:!6X-5@LR2QXG!CXB7G8+-EK.,^(+)@LB"P8+$
M@J*"W(*W@4(`CUJ/B@"#08-H@XR#6)*@`(-!@VB#C(-8DJ``BL>7G0!!9',`
ME<J6O`""MX+7@L0`D5.41H_8@X:!6X-5`)%3@L2"S(-/@XN!6X-V`)%3@L2"
MS(-!@TZ#6H-8C*``CI^"S(-T@TB#BX-?D^""S(.!@V*#6H%;@U>"S8*W@M>"
MQ"`Q((+"@LP@34)/6""#=(-`@T.#BX+)@U^#18.3@XV!6X-H@K."ZH+<@K>!
M0@"-[)"L@K6"Q(*I@N<@)3(D<R"3^HC(C^.,;X+!@KV!;2(E,21S(H%N@W2#
M2(.+@U^3X(+,@X&#8H-:@5N#5X+-@K>"UX+$C>V/G(*S@NJ"W(*W@4(`)7.#
MEHR.B,B/XXQOB=^"M8*]C,."HH.*@Y.#3HQ>DUF5=(+-D5."Q(WMCYR"LX+J
M@MR"MX%"`(WLD*R"M8+$@JF"YR5S@Y:,CHC(C^.,;X+!@KV1EY!-C52"IH-T
M@TB#BX-?@LV14X+$C>V/G(*S@NJ"W(*W@4(`@W2#0H.+@UZ#BX%;@XN"\(+'
M@LR#@8%;@XN#>X-B@TZ#6(+%@N"32Y=P@L6"JX+I@N:"I(+)@K6"W(*W@JF!
M2`"4U(V&E72"JX.*@UB#9X+PD-V2Z(+%@JN"Z8+F@J2"R8*U@MR"MX*I@4@`
MBOF"R9&VC=V"M8+<@K<`D>.1UH+,($E-4U`@@XV#3X-#@Y,`D>.1UH+,($E-
M4U`@@W"#6(./@5N#:`"1XY'6@LP@24U34""#AH%;@U66O`"1XY'6@LR#@8%;
M@XN#08-H@XR#6`"1XY'6@LR#98.3@W:#C(%;@V<`C^V"R0"3695T@LV/[8+)
ME=N1MH*W@ND`DUF5=(+PC>V/G(*W@NF-VX+)@T>#B8%;@JJ4K9"V@K6"W(*U
M@KV!0DE-05"#5(%;@V^"J8+G@LR)GI.:.@"5<Y"S@LB2;(*JCG>2Z(*S@NJ"
MQ(*B@MR"MP"05HM+@UZ#6(-.C>R0K)*&@LF,M(CVE7.6OH+,@T>#B8%;@JJ4
MK9"V@K6"W(*U@KV!0@"3O9:\@W:#C8-,@U:!6P"5U)!-C<^"W0"5U)!-C<^"
MW8.!@5N#BP"#08-V@XJ#4(%;@U:#AX.3`(-!@W:#BH-0@5N#5H.'@Y..9Y=P
MB<(`@XV#3X-#@Y..GH+)@W2#0H.+@UZ#BX%;@XN"\)-+EW""M8+<@K>"J8%(
M`$E.0D]8@O"57(ZF@K>"Z9-X@LF#=(-"@XN#7H+PDTN7<(*U@MR"MX*I@4@`
MC[.41@""4XR.`(-!@5N#2H-#@W6#=(-`@T.#BX-4@T.#60"#08%;@TJ#0X-U
MEKP`EGN3EH+)@K&"S(SVBDJ,KH+PC\&+CH*U@MR"MX*I@4@`EGN3EH+)@K&"
MS(RN@WF#08+PC\&+CH*U@MR"MX*I@4B!:8*HBJF"WX*U@MR"N8+Q@4F!:@"6
M>Y.6@LF.P(US@K6"Q(*B@J*"Q8*W@JF!2``E<R""S(-4@T.#DX-!@V*#=I=V
MBX&"\)9[DY:"R8WMCYR"M8+$@J*"HH+%@K>"J8%(`)9[DY:"R8*Q@NJ"YX+,
M@X&#8H-:@5N#5X+PBJZ14X+)C>V/G(*U@L2"HH*B@L6"MX*I@4@`EGN3EH+)
M@K&"ZH+G@LR3695T@O"*KI%3@LF-[8^<@K6"Q(*B@J*"Q8*W@JF!2`"6>Y.6
M@LF"L8+,@W2#2(.+@U^"\(OS@LF"M8+$@J*"HH+%@K>"J8%(`)9[DY:"R8-3
M@WZ4H(+PB_."R8*U@L2"HH*B@L6"MX*I@4@`EGN3EH+)@K&"ZH+G@LR#@8-B
M@UJ!6X-7@O"*KI%3@LF/P8N.@K6"Q(+@@J*"HH+%@K>"J8%(`)9[DY:"R8*Q
M@LR#@8-B@UJ!6X-7@O"6LXI1@L:5\8V0@K6"Q(+@@J*"HH+%@K>"J8%(`)9[
MDY:"R8*Q@LR#@8-B@UJ!6X-7@O!34$%-@L:5\8V0@K6"Q(+@@J*"HH+%@K>"
MJ8%(`).>DH6.GHK4`(^XCX<`D'&"RX+I`)7;CN>-[(O&@LR.P(USD4^"R8IM
ME$:"\(N!@M^"Z8+F@J2"R8*U@MR"MX*I@4@`DUF5=`"3695T@W2#0(-#@XL`
M@J""R(*]@LP@4$=0((SVBDJ,KH+PDUF5=(*U@MR"MX*I@4@`DUF5=(-T@T"#
M0X.+@48`DUF5=(-T@T"#0X.+("(E<R(@@LR#5(-#@UF"JI'E@JN"MX*L@MR"
MMX%"DUF5=(*S@NJ"W(*Y@O&!0@"3695T@W2#0(-#@XN"S8*@@LB"O8*JD9>"
MP8*]EUR2Z)5<EW:+@8+6@LR5U)!-@L6"MX%"`)-9E70`DUF5=(+PCN:"Z(^<
M@JN"W(*U@KTZ()-9E72"S(Q>`)-9E70`D;:-W8*U@LB"HH-/@XN!6X-V@O"-
M[8^<@K6"YH*D@L:"M8+<@K6"O8%"`)&VC=V"M8+(@J*#08-.@UJ#6(R@@O"-
M[8^<@K6"YH*D@L:"M8+<@K6"O8%"`)&VC=V"M8+(@J*#08-.@UJ#6(R@@O"5
MTH]7@K6"YH*D@L:"M8+<@K6"O8%"`)&VC=V"M8+(@J*+I)=,@O"5TH]7@K6"
MYH*D@L:"M8+<@K6"O8%"`(Y1B<&.T@"2C8C3`)&ND*L`@E>,C@!!=71H7V-Y
M<G-Q;#H@E4N7=H+(24U!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U
M=&A?8WER=7,Z((-O@V*#3H-'@Y.#:(+-E4N7=H+(E%R7S8+PETR"M8+$@J*"
MW(*Y@O&!0@!!=71H7V-Y<G5S.B"7=HN!@K>"Z6EM87"*9Y*C@JJ,J8+"@JF"
MZ(+<@KF"\8%"`$%U=&A?9G1P.B!&5%"*9Y*CBT"47(*J@MV"PH*I@NB"W(*Y
M@O$N(%!(4(+P("TM96YA8FQE+69T<""#28-V@U:#AX.3@O""PH*O@L2#4H.3
M@W"#0X.+@K6"R(*H@K6"Q(*M@KZ"LX*B@4(`075T:%]I;6%P.B!)34%0BF>2
MHXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]I;7`Z()5+EW:"R"!)34%0
M((IGDJ."JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]K<F(U.B!K<F(UBF>2HXM`
ME%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]L9&%P.B!,1$%0BF>2HXM`E%R"
MJHRI@L*"J8+H@MR"N8+Q@4(`075T:%]L9&%P.B"#AH%;@U4@)7,@@O"2QXG!
M@L6"JX+<@KF"\8%"@U2!6X-O@LR)GI.:.B``075T:%]L9&%P.B"#AH%;@U4@
M)7,@@O"-[8^<@L6"JX+<@KF"\0!!=71H7VQD87`Z((.&@5N#52`E<R""\(U8
MD%:"Q8*K@MR"N8+Q`$%U=&A?;6-A;#H@34-!4(IGDJ.+0)1<@JJ,J8+"@JF"
MZ(+<@KF"\8%"`$%U=&A?<VUB875T:#H@<VUB875T:(IGDJ.+0)1<@JJ,J8+"
M@JF"Z(+<@KF"\8%"`)1&C]B"R8ZXE'."M8+<@K6"O0"41H_8@LF.N)1S@K6"
MW(*U@KV!0B5S`%)!1$E54X-4@5N#;X+)@N:"Z)1&C]B"JHN1E-N"LX+J@MR"
MM8*]@4(`1E10@U2!6X-O@LR41H_8@LF.N)1S@4(`@T&#:(.,@UB2H(+)DV^8
M7H*S@NJ"Q(*B@NF0;(*I@N>"S"!(5$U,((.!@T.#BX+-B>:1G(+PE5R.IH*U
M@MR"MX*I@4@`CF>7<(G"E%R"R(-!@VB#C(-8DJ"!1@".9Y=PB<*47(+(@W2#
M0H%;@XN#:(%&`(F>DYJ1TH*_`%]+)7,@@LF6WX+I`"5S((+)EM^"Z0"4=XQI
M`)1WC&F01@!+97)O8F5R;W,@@W"#6(./@5N#:(*JEK.,^(+%@K>!0@!+97)O
M8F5R;W,@@X:!6X-5EKR"JI:SC/B"Q8*W@4(`0F-C`))AD+:3^@"#=8.)@V*#
M3H.*@UB#9P"#=8.-@V*#3H->@T.#=@!(5$U,@X&!6X.+DH:"S(GFD9R"S8YW
MCJ:"MX+I@MR"Q95<CJ:"M8+(@J*"YH*D@LF"M8+<@K>"J8%(`)9[E;8`D;Z.
MF@"#=8-B@TZ#?8%;@TX`B8\`B8^"S)&^@K.!1@")CP"7O)7[`(-W@V*#7Y64
M@L:6>Y6V@LF57(ZF`(G3C_"/D8*K`$--4P!#4D,`0U),()1ZE7J#?(-#@Y.#
M9P!?2)6VCIJ#6H-B@V<`EUR2Z)5<`(.*@X*!6X-G@LR#@8-#@XN#5(%;@V^"
MR9#:D;&"Q8*K@MR"N8+Q@4(`@XJ#@H%;@V>"S(.!@T.#BX-4@5N#;X+)D-J1
ML8+%@JN"W(*Y@O$Z(`!)34%0((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&"Q8*U
M@KTZ("5S`(-,@X.#DX-:@XL`@X&#8H-:@5N#5X+,@TR#@X.3@UJ#BP"/X8I1
M@XR#?(%;@V>"\(-,@X.#DX-:@XN"MX+I`(.!@V*#6H%;@U>"\(-,@X.#DX-:
M@XN"MX+I@L:!09/@EV6"S9%3@L24<(K\@K."ZH+<@K>!0@"#=(-`@T.#BR`B
M)7,B((+PC>V/G(+%@JN"W(*Y@O&!0@"-[(O&@V:#0H.,@TZ#9X.*@JJ,J95T
M@JF"Z(+<@KF"\8%"`(-F@T*#C(-.@V>#BH%;("(E<R(@@O"-[8^<@L6"JX+<
M@KF"\8%"`(WMCYR"Q8*K@MR"N8+Q@4*.<9&W@JH@)60@D;:-W8*U@MR"MX%"
M`)7`@M>1UH*F@LR1SH_;@LR0E(*JE=N1MH*S@NJ"Q(*B@NF0E(+&C8>"[8+(
M@J*"S(+%E<""UY'6@J:"JH+%@JN"W(*Y@O&!0@".=Y+H@K."ZH*]E-2-AH+)
M@X&#8H-:@5N#5X+PE'J1EX+%@JN"W(*Y@O&"Q8*U@KV!0@"57)'H`)6JE]Z"
MQH.)@WB#BP!#8P",9Y'1DV288@"#6H.+D:Z0JP"#6H.+EH21D(%&`(-:@XN1
MKI"K`(-:@XN77922@48`C&>1T9-DF&(`DH:)FP"/V):^CY&"S(_:C=<`C]B6
MOH^1@WR#BH-6@5L`BV.2MP"5SXU8`(*W@M>"Q)7/C5@`@W2#2(.+@U^5SXU8
M`(IE@WF!6X-7@LF57(ZF@K."ZH+I@X&#8H-:@5N#5X+,D)2"XH.!@V*#6H%;
M@U>"S)7`@M>5^X+(@L>"\)7/C5B"M8+<@K>!0@"#@8%;@XN#5(%;@V^"XH-T
M@TB#BX-?@LR0W9+H@O"5SXU8@K6"W(*W@4(`DV2.<8.!@T.#BX+)CF>7<(*W
M@NF6O)%/@L:#08-H@XR#6(+PE<^-6(*U@MR"MX%"`(.!@5N#BX+)E5R.IH*S
M@NJ"Z8*@@LB"O8+,EKR13X%!@T&#:(.,@UB!08^0EKR"\)7/C5B"M8+<@K>!
M0@"57(ZF@K>"Z96VCIJ!1@"#=(-(@XN#7Y/@@LR05I*%@X&!6X.+@O"*;91&
M`(.!@5N#BX+PCN:3OH*W@NF#5(%;@V^"\)%)D?"!1@"1EY!-@K>"Z9%/@LF#
M6(-Y@XN#8(-&@V*#3H*U@MR"MX*I@4@`CXB2=8+PD4F1\(%&`(.!@5N#BX-4
M@5N#;X+PD4F1\(%&`(-P@UB#CX%;@VB"\)%)D?``@X:!6X-5EKR"\)%)D?``
MCXB2=8+PD4F1\(%&`)/ZE7257(ZFC&".KH%&`(-!@VB#C(-8@LR2QXG!CIZ"
MR8YG@J2#08-H@XR#6)*@@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`@T&#:(.,@UB"
M\)-7BDJ"MX+IC=N"R8R?C?6"MX+I@T&#:(.,@UB2H(+,CX>/F(+PCG>2Z(*U
M@L2"K8*^@K."HH%"`(-.@XF#6)+HBV`@)7,@@JJ,J95T@JF"Z(+<@KF"\8%"
M`(.&@5N#58+,D=Z+CH%&)7,`@X:!6X-5C\&+C@`E<R""\(-.@XJ#8H-.@K>"
MZ8+&B>:1G(+P@W6#B8-%@U6"Q95<CJ:)PI1<@LB,8(ZN@LF5SXJW@K6"W(*W
M@4(`)7,@@O"#3H.*@V*#3H*W@NF"QHGFD9R"\(-?@T6#DX.-@5N#:(*U@MR"
MMX%"`"5S((+P@TZ#BH-B@TZ"MX+I@L8E<XK'EYV#>8%;@U>"R8C:DZZ"M8+<
M@K>!0@`E<R""\(-.@XJ#8H-.@K>"Z8+&2%1-3(+PE<J#18-#@Y.#:(%;@LF5
M7(ZF@K6"W(*W@4(`)7,@@O"#3H.*@V*#3H*W@NF"QHGFD9R"S(-4@X"#;(-#
M@XN"\)5<CJ:"M8+<@K>!0@""L8*Q@O"#3H.*@V*#3H*W@NF"QHGFD9R"\)5<
MCJ:"M8+<@K>!0@".=Y+H@K6"O8-!@VB#C(-8DJ""S"`Q((+"@O"#3H.*@V*#
M3H*U@L2"J8+G@4&,GXWU@K>"Z8-T@T*!6X.+@VB"\(*W@M>"Q(YWDNB"M8+$
M@JV"OH*S@J*!0@"#3H.*@V*#3H*W@NF"QHZ?@M8`@TZ#BH-B@TZ"MX+I@L8@
M4$=0((SVBDJ,KH+P@T&#:(.,@UB2H(+)E=N1MH*U@MR"MP"#3H.*@V*#3H*W
M@NF"QB`E<R""S"!3+TU)344@C]B6OH^1@O""H(+(@KV"S(-!@VB#C(-8DJ""
MR97;D;:"M8+<@K<`@T&#:(.,@UB"\(-.@XJ#8H-.@K>"Z8+&D9>038[2@M:"
MS)!6BTN#@8%;@XN"\(WLD*R"M8+<@K<`@T&#:(.,@UB"\(-.@XJ#8H-.@K>"
MZ8+&@X&#8H-:@5N#5X+PE5R.IH*U@MR"MP"5PH*V@ND`@T6#0H.3@VB#18+P
ME<*"MH+I`(*Q@LR#18-#@Y.#:(+PE<*"MH+I`)7"@K:"Q(*B@NF#=(-(@XN#
M7P""O8*]@MX`@K>"UX+$@O""O8*]@MX`@K>"UX+$@LR#=(-(@XN#7X+P@KV"
MO8+>`(-T@TB#BX-?@O""O8*]@MX`D$8`D$:129'P`)!&D4F1\`"7\8%&`)?Q
M@UZ#0X-G@XL`@U*#?H-B@TZ#6`"#4H-]@Y.#:`"#4H-]@Y.#:(-6@T:#BP"#
M4H.!@Y.#9P"+I)+*EKP`B>^.T`"*KI>Y`)7*@LR#@8%;@XN"\(WLD*P`E<J"
MS(-%@T*#DX-H@T6"Q9!6BTN#@8%;@XN"\(WLD*R"M8+<@K>"J8%(`(.!@5N#
MBXWLD*R"\$A434R#@H%;@VB"R8*U@MR"MX*I@6F#=8.)@T6#58*J@U2#?(%;
M@V>"MX+I@LB"YX%J@4@`D-V2Z(+,C;>5J@`E<R""\)#=DNB"MX+I`(.!@V*#
M6H%;@U>"\(+'@J257(ZF@K>"Z8*I@O"0W9+H@K6"W(*W@4(`@X&#0X.+@LR#
M=H.,@W*#A8%;@TF#=H-6@X>#DX+PD-V2Z(*U@MR"MX%"`(-P@UB#CX%;@VB"
M\(IME$8`D-J1L8ZXE'.!0@",]H]/C*Z#5(%;@V^"UH+,D-J1L8*JBY&4VX*S
M@NJ"W(*U@KV!0@",]HI*C*Z#5(%;@V^"UH+,D-J1L8*JBY&4VX*S@NJ"W(*U
M@KV!0I>=EU*!1B5S("@E<RD`1E10@U2!6X-O@M:"S)#:D;&"R8ZXE'."M8+<
M@K6"O8%"`(-4@5N#;X+6@LR0VI&QCKB4<P"809>-D.:"S8-!@VB#C(-8DJ""
MR9+'B<&"LX+J@MR"M8*]@4(`)7,@@LP@4$=0((-4@WR!6X-G@O"0W9+H@K6"
MW(*W@4(`)7,@@LP@4R]-24U%((-4@WR!6X-G@O"0W9+H@K6"W(*W@4(`D%:2
MA8.!@5N#BX+PB;V.GHIME$:"MX+I@JF!09!6DH6#@8%;@XN"\)+*DFV"MX+I
M@JF"QX*D@JF"\)#=DNB"M8+<@K>!0@"*1Y6VCIJ"\(-!@T.#4H.3@LF5SXU8
M@K6"W(*W@JF!2`"#4H-S@5L`@U*#<X%;`(-T@TB#BX-?@5N"R8-2@W.!6P"/
M0Y"S`(]#D+.-SX+=@V6#3(-8@V<`@X&#8H-:@5N#5X+,(%!'4""(PXV&B;N"
MJH+%@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@4$=0((^0EKR"JH+%
M@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@4R]-24U%((C#C8:)NX*J
M@L6"JX+<@KF"\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!3+TU)344@CY"6O(*J
M@L6"JX+<@KF"\8+%@K6"O8%"`)A!EXV0YH+PDL>)P8+%@JN"W(*Y@O&"Q8*U
M@KV!0B5S`$Q$05`@@U2!6X-O@LF#;X-#@Y.#:(+%@JN"W(*Y@O&"Q8*U@KV!
M0@".8XV"@JJ*;91&@L6"JX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#6(-G
M@JJ-[)"L@L6"JX+<@KF"\8+%@K6"O8%")7,`4$=0((-F@5N#7H+,E9R-AHF[
M@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(`4R]-24U%((-F@5N#7H+,E9R-AHF[@JJ"
MQ8*K@MR"N8+Q@L6"M8*]@4(`F$&7C9#F@JJ-[8^<@L6"JX+<@KF"\8+%@K6"
MO8%")7,`D9>039#F@XJ#6(-G@JJ-[8^<@L6"JX+<@KF"\8+%@K6"O8%")7,`
M)7,@@LR#@8-B@UJ!6X-7@LV-[8^<@L6"JX+<@KF"\8%"@U2!6X-O@JF"YX+,
MB9Z3FH%&("5S`([SD$V.TH+,DV2.<8.!@5N#BX-!@VB#C(-8@JJ*;9+H@L6"
MJX+<@KF"\8+%@K6"O8%"`)7;CN>-[(O&@O".P(US@L6"JX+<@KF"\8%"`$U3
M+51.148@DUF5=(*I@N>7=HN!@K."ZH*]@W2#0(-#@XN"\([F@NB/;X*Y@MR"
MN8+Q@L6"M8*]@4(`6FEP((^1C,F"J8+G@W2#0(-#@XN"\([F@NB/;X*Y@MR"
MN8+Q@L6"M8*]@4(`@T&#:(.,@UB2H(*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"
M\8+%@K6"O8%"`)&7D$V0YH.*@UB#9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"
M\8+%@K6"O8%"`)&7D$V0YH.*@UB#9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"
M\8+%@K6"O8%"`(SVBDJ,KH+PC*Z#5(%;@V^"J8+GCN:3OH+%@JN"W(*Y@O&"
MQ8*U@KV!0@`E<R""\(-)@5N#=H.3@L6"JX+<@KF"\8+%@K6"O8%"`)7;CN>-
M[(O&@X*#5X.%@5N#BR`E<R""\(I*@J^"W(*Y@O&"Q8*U@KV!0@`E<R""JI/'
M@MV/;X*Y@MR"N8+Q@4(`@T&#:(.,@UB2H(+PCN:3OH+%@JN"W(*Y@O&"Q8*U
M@KV!0B5S`)&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S
M`)&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)#=DNB"
M\(RS@LF6WX*Y@MR"N8+Q@L6"M8*]@4(`)7,@D-V2Z(+PE=N1MH+%@JN"W(*Y
M@O&"Q8*U@KV!0@"0W9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"Q8*K@MR"N8+Q
M@L6"M8*]@4(`3$1!4""#5(%;@V^"JHR?C?6"Q8*K@MR"N8+Q@4(`F$&7C9#F
M@O"-6)!6@L6"JX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#6(-G@O"-6)!6
M@L6"JX+<@KF"\8+%@K6"O8%")7,`36]Z:6QL82""S(-4@T.#:(-O@5N"JHRI
ME72"J8+H@MR"N8+Q@4*#5(-#@VB#;X%;@O"*2H*B@L2)NH*S@J*!0@"-D0"-
M[)"L`(-T@TB#BX-?@O"-[)"L`(F\D7J#=(-(@XN#7X+PC>R0K`")NH^1@JN#
M=(-(@XN#7X+PD%:+2XWLD*P`D%:+2XWLD*P`D9>038U4@J:#=(-(@XN#7X+P
MD%:+2XWLD*P`@U.#?I2@@W2#2(.+@U^"\)!6BTN-[)"L`([SD$V#@8%;@XN"
M\(-T@TB#BX-?@LF058+HE:J"KX*]@NB!05-004T@@X&!6X.+@O"-[8^<@K>"
MZ8-T@T*#BX->@XN!6X.+@O"-[)"L@K6"W(*W@4(`@U2#=8-T@TB#BX-?@O"-
M[)"L`(WLD*R.TH+,@T&#3H-:@UB,H`"#3H.,@U>#8H-G@TJ!6X-HE-2-A@",
MNXW=@LR.GHK4`)&\@LR#5(%;@V^"J8+G@X&!6X.+@O".YI.^@K>"Z8*]@M^"
MS)#=DNB"\(*U@MR"MX%"`(.!@5N#BX+,D9>038+P@TJ#6(->@WV#0X-9@K6"
MW(*W@4(`)7."R8.-@T^#28.3@K6"O8+&@JN"R8[`C7."MX+I@UZ#6(-.@O"#
M2H-8@UZ#?8-#@UF"M8+<@K>!0@"0V(+HCN:"Z`"0V(+HCN:"Z`"3^@"6B)/Z
M`%]%D_J5=`!$871A5')E92")>Y>7`)/ZE70`@V:!6X->CO.030!?3)?Q@LR-
M[8^<`#$RC(X`CUR0:9"4`([3D.*-SX+=`))IB;J"L(+PD/."K0"#9H-T@TB#
MBX-GD$8`@V:#=(-(@XN#9R!)1`"#9H-T@TB#BX-G@LR#7(%;@V>*[H^`@48`
M@V:#=(-(@XN#9X+,@UR!6X-GE?N,_(%&`(C/E$.-SX+=`(WMCYP`@W2#2(.+
M@U^"\(WMCYP`@T^#BX%;@W:"\(WMCYP`@T&#3H-:@UB,H(WMCYP`B;R1>H-T
M@TB#BX-?@O"-[8^<`(-:@XN-[8^<`)?Q@LR-[8^<`)'CD=:#98.3@W:#C(%;
M@V>"S(WMCYP`@XJ#@H%;@V>#5(%;@V^"J8+GCN:"Z(V>@MV-SX+=@LR#@8-B
M@UJ!6X-7@O"-[8^<@K6"W(*W@JF!2`"77)+HE5R"J8+GC>V/G`",PX*B@XJ#
MDX-.C%Z3695T@O",CH+,CXF"WX+)C>V/G(*U@MR"MX*I@4@`BOF1MH+,D9>0
M38U4@J:#=(-(@XN#7X+PC(Z"S(^)@M^"R8WMCYR"M8+<@K>"J8%(`(US@LR-
M[8^<`)%)D?""M8*]242"\(WMCYP`C+N-W8C*DG6"S)?Q@O"-[8^<`(R[C=V(
MRI)U@LR-<X+PC>V/G`"-[8^<C<\`C>V/G(*S@NJ"O8.!@5N#BP"3695T("(E
M<R(@@O"-[8^<@K6"W(*U@KV!0@"#@8%;@XN"S(WMCYR"QHC:DZX`E'J1EXZ>
MBM0`EW:+@8+PBY&4VX*W@ND`EUR2Z(_NE?&"S)=VBX&"\(N1E-N"MX+I`(U^
MCX<`C^&*49/@EV6"S)#@EKX`D."6O@"/VHW7@JJ*QY>=CM*"S(*]@M^"R8M,
MF%Z"LX+J@MR"M8*]@4(`BDJ4K0"/D):\@O"4EH*ME5R.IH*U@MR"MX*I@4@`
MC;:"J8+GB46"U@")18*I@N>-MH+6`)5<CJ8`,C2.GHK4E5R.I@"57(ZF@TF#
M=H-6@X>#DP"1EY!-C.."R8IME$:)YI;*@O"57(ZF@K6"W(*W@JF!2`"6>Y6V
M@LF57(ZF`)!6DH6#@8%;@XN3GI*%CIZ"R8-\@V*#=H-!@V*#=H+%DLJ2;8*U
M@MR"MX*I@4@`C&".K@"(ZI)V@K6"R(*B`(-T@TB#BX-?D^""S)!6DH6#@8%;
M@XN"\(IME$:"M8+(@J(`C>V/G(*U@LB"H@!M86EN=&5N86YC92YP:'`@@LF2
MO)#:@T&#3H-:@UB"M8+(@J*"Q8*M@KZ"LX*B`(F]@N"#BH.3@TZ"M8+(@J(`
M@W2#2(.+@U^"\(I*@JN"W(*W@JF!2`"-Q8^)@LR7\8*J@W2#0H%;@XN#:):\
M@O"*W(+Q@L6"HH+<@K>"J3\@@KN"I(+(@N>#8(-&@V*#3H*U@L2"K8*^@K."
MHBX`CTF7N0"#7X-%@Y.#C8%;@V@`)7,@@LR#7X-%@Y.#C8%;@V@`)7,@@O`@
M>FEP((Q@CJZ"Q8-?@T6#DX.-@5N#:`"3695T@O"14X+$@U^#18.3@XV!6X-H
M@6DN>FEP((-T@T"#0X.+@L6!:@"#=(-(@XN#7X+P@U^#18.3@XV!6X-H`(-T
M@TB#BX-?@O"#7X-%@Y.#C8%;@VB!:7II<"",8(ZN@6H`D+:0K(*U@KV0W9+H
M@O`@4$A0((-8@TZ#BH-V@V>"\(+&@K6"Q(-?@T6#DX.-@5N#:(*W@NF!0@!Z
M:7`@C&".KH+%@U^#18.3@XV!6X-H`(FZCY&"JP")NH^1@JN#=(-(@XN#7P")
MNH^1@JN#=(-(@XN#7P"39(YQ@X&!6X.+`(.!@5N#BX-!@VB#C(-8`)72CU<`
M@W6#B8-B@TZ#BH-8@V>"\)72CU<`@W6#C8-B@TZ"S)72CU<`@W2#0H.+@UZ#
MBX%;@XN"\)72CU<`@T^#BX%;@W:"S)72CU<`@T&#3H-:@UB,H(+,E=*/5P"#
M08-.@UJ#6(R@@LR5TH]7`"5S((+,@T&#3H-:@UB,H(+,E=*/5P")O)%Z@W2#
M2(.+@U^"\)72CU<`)7,@EW""S(F\D7J#=(-(@XN#7X+PE=*/5P"#>H./@T.#
M9X.*@UB#9X+PE=*/5P"#28-V@U:#AX.3@LR5TH]7@48`)7,@@LR#08-.@UJ#
M6(R@@LR5TH]7`(-U@XF#8H-.@XJ#6(-G@O"5TH]7`(-T@T*#BX->@XN!6X.+
M@O"5TH]7`)&\@LR#5(%;@V^"S(-!@TJ#18.3@V>"\)#=DNB"M8+$B;J"LX*B
M@4(`@WJ#CX-#@V>#BH-8@V>"\)72CU<`DV2.<8.!@5N#BP"#@8%;@XN#08-H
M@XR#6`!%@X&!6X.+@T&#:(.,@UB"JHCJDG:"M8+(@J^"ZH+.@J*"KX+<@KF"
M\8%"`(-T@TB#BX-?@O"+\X+)@K>"Z0"#4X-^E*""\(OS@LF"MX+I`%]4@U.#
M?I2@D+21?`"+\X.!@V*#6H%;@U>"Q8*W@4(`B;V"X(RI@L*"J8+H@MR"N8+Q
M@4(`4$=0((+PCF>7<(*U@MR"MX*I@4@`4R]-24U%((+PCF>7<(*U@MR"MX*I
M@4@`@TV#@X.)@XJ!6X*I@N>)YI&<@O"1?9/\@L6"JX+I@N:"I(+)@K6"W(*W
M@JF!2`"#@8-B@UJ!6X-7@LR#=H.,@W*#A8%;@O".9Y=P@K6"W(*W@JF!2`")
M18-.@XJ#8H-.@L6#@8-J@X6!6X+PE5R.IH*U@MR"MX*I@4@`7UF(PXV&@TF#
M=H-6@X>#DP"/29>Y`)-=D9>#@8%;@XN"S8C(C^."Q8*W`(-'@V:#0H->@5N)
MYI;*@O"1Y8*K@JT`@W"#6(-T@XR!6X-9@O"3_)?-`)!6@K6"HHFZCY&"JX-T
M@TB#BX-?@LR6O)%/@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`D%:"M8*BD9>038U4
M@J:#=(-(@XN#7X+,EKR13X+PCG>2Z(*U@L2"K8*^@K."HH%"`)!6@K6"HH-3
M@WZ4H(-T@TB#BX-?@LR6O)%/@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`(B5S(B""
MQH*B@J2#1X.3@V>#BH*J@T&#:(.,@UB2H(+)DL>)P8*S@NJ"W(*U@KV!0@"#
M1X.)@5L`E=2038-'@XF!6X%&("5S@4(`@X&!6X.+@T&#:(.,@UB"S(-'@XF!
M6X+%@K>!0@"#0X-X@Y.#9X+-C>V/G(*S@NJ"W(*U@KV!0@`Q-2"5JI:(`#*5
MJI:(`#,P()5BEH@`-2"5JI:(`(.-@T^#0X.3EH@`,S`@E:J6B``Q()6JEH@`
MCG>2Z))L@LR7X0".P(US`)-7BDH`@K>"UX+$@O"35XI*`(*W@M>"Q(+,@W2#
M2(.+@U^"\)-7BDH`@W2#2(.+@U^"\)-7BDH`EKR13X+PDU>*2@"#@8%;@XN-
M[)"LCIZ"R9:\D4^"S)-7BDJ"S8ZIDZZ"Q8US@J*"W(*W@JF!2`"#=(-(@XN#
M7X+,@V:#=(-(@XN#9Y5<CJ:"Q8-T@TB#BX-?@V.#BH%;D5.1S(+PDU>*2H*U
M@MR"MX*I@4@`DU>*2I*&`)=,C/B*^HS``(YWD)0`D4^,:9!&`)#=DNB"\"!&
M5%`@@L6#08-B@W:#C8%;@VB"MX+I`(-V@XR#=(-`@XR#DX-8D-V2Z(+PCN:3
MOH+%@JN"W(*Y@O&!0@!,1$%0((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&"Q8*U
M@KV!0@!334(@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O8%"`"(E<R(@
M@JF"YX+,@U*#<X%;@LF.N)1S@K6"W(*U@KV!0@`B)7,B((+6@LR#4H-S@5N"
MR8ZXE'."M8+<@K6"O8%"`)!6BTN"S"!305-,()#:D;&"R8ZXE'."M8+<@K6"
MO8%"`"(E<R(@@M:"S(C:DZZ"R8ZXE'."M8+<@K6"O8%"`()1C(X`@X&!6X.+
M@LR.YH+HC9Z"W0"5RH-%@T.#DX-H@5N"Q8[F@NB-GH+=@O""M8+<@K>"J8%(
M`(.-@T^#0X.3CIZ"R8.!@5N#BX+PCN:"Z(V>@MV"W(*W@JF!2`!&971C:&UA
M:6PZ()!6DH6#@8%;@XN"R(*U@4(`7TR#=(-"@XN#7@"#=(-`@T.#BP"#=(-`
M@T.#BY"4.B`E<R"#=(-`@T.#BP"#=(-`@T.#BY"4.B`E<R"#=(-`@T.#BP"#
M=(-`@T.#BX-]@VR!6X-7@X,`@W2#0(-#@XN6O`"#=(-`@T.#BY%)D?``@W2#
M0(-#@XN#08-B@W:#C8%;@V@`@W2#0(-#@XN#08-B@W:#C8%;@VB"S8-4@WR!
M6X-G@K."ZH+$@J*"W(*Y@O&!0@"#=(-"@XN#7H-)@W:#5H.'@Y,`@W2#0H.+
M@UZ0W9+H`)5SDTN0V(+(@X&!6X.+D^"798+P@W2#0H.+@UZ"M8+<@K>"J8%(
M`(-T@T*#BX->@LV"L8+,@U:#6(-E@X""Q8+-EK.,^(+)@LB"P8+$@J*"W(*W
M@4(`@W2#0H.+@UX`@W2#0H.+@UZ"S9:SC/@`@W2#0H.+@UZ!1H%`)7,@BL>7
MG8-Y@5N#5P",GXWU`(.!@5N#BX-[@V*#3H-8@LR-Q8^)@LR#>8%;@U<`C<6/
MB8+,@WF!6X-7`%]2DUV1EP"#=(-(@XN#7Y&`C>P`@W2#2(.+@U^*5)=V`(ND
METR#=(-(@XN#7X+-CF>7<)5SB<*!0@"+I)=,@W2#2(.+@U^.9Y=PB<*47(%"
M`)6VCIJ01@"#@8%;@XN#>X-B@TZ#6)5<CJ:"R8*H@J^"Z8VAD_J"S(.!@V*#
M6H%;@U>"S(Z>BM257(ZFC&".K@"#=(-(@5N#@`"#=(-(@5N#B8.``)-=D9<`
MDUV1ESH`DUV1EX*S@NJ"O8.!@5N#BP`E<R""J8+GDUV1EX*S@NJ"O8.!@5N#
MBP"+X`"89P"77)+HC^Z5\0"77)+HC^Z5\8F>DYH`EUR2Z(_NE?&7=HN!`)=<
MDNB/[I7QEW:+@8F>DYH`7TV-MX]OD&P`D9>038RS@T&#:(.,@U@`C]J"M8*B
MD."6O@".@9:\`)-=D9>!1@"379&7.B``DUV1ESH@)74@DLJ"S)-=D9>"LX+J
M@KV#@8%;@XL`B.J4RI-)@TF#=H-6@X>#DP`E<R"-7)"LC^Z5\8+PD+:0K(*W
M@ND`D+:0K(*S@NJ"O8-2@5N#:`"05I*%@X&!6X.+@LR"W8[F@NB-GH+=@6E)
M34%0((-4@5N#;X+,@MV!:@"0J0"#08-.@UJ#6(+PBY:)P@"#3X.+@5N#=HK'
MEYT`@T^#BX%;@W:6O(+-B_.4DH+%@LV"R(*B@K&"Q@"#3X.+@5N#=@"#48-8
M@V>#08-.@UJ#6(R@`(-1@UB#9X-U@V*#3@!(5$U,((Q@CJX`2%144""41H_8
M@JJ"W8+"@JF"Z(+<@KF"\8%"`(-N@V*#5H.%@T&#BX-3@XJ#68.``(-W@V*#
M7P"#=X-B@U\`C8*"LP"#=X.+@W8`@K&"ZH*JC>R0K)*&@LR#@8%;@XN"Q8*W
M@48`B4*"MP"#6(.,@V*#:)5<CJ:"Q8+-B4*"MP"-[8^<C<^"W8+PE/&57(ZF
M`)3QC7>3QX[2@O"4\95<CJ8`C8(`ET20YI-XC8(`C<6-@@"#>H%;@X``CJF1
M[H+,CUJ/B@".J9'N@LR39)ABE-2-A@!(;W)D90")H9#\`)-9E72"\(+'@J25
M7(ZF@K6"W(*W@JF!2`""HH*M@L*"S)?Q@O",BXV'@K6"W(*W@JF!2`"#=(-"
M@5N#BX-H*(US*8+,D)2"S8*B@JV"PH+%@K>"J8%(`(*B@JV"PH+,C7."\(R+
MC8>"M8+<@K>"J8%(`)74D$V.GH+,B/B7<(OE`$E-05"!:8ZIDZZ4NY7*@6H`
M24U!4""#@8%;@XN#>X-B@TZ#6(+,C>R0K(+)CKB4<X*U@MR"M8*].B`E<P!)
M34%0((.!@5N#BX-[@V*#3H-8@LR-[8^<@LF.N)1S@K6"W(*U@KTZ("5S`$E-
M05`@@X&!6X.+@WN#8H-.@UB#3H-(@5N#7H+,C>R0K(+)CKB4<X*U@MR"M8*]
M.B`E<P!)4(-!@VB#C(-8@JJ+EHG"@K."ZH*]0TE$4H-U@XV#8H-.D^""R8*@
M@NB"W(*Y@O&!0@!)4)65C;V(X92]@L6"MX%"`(-!@T.#4H.3@LR"W0"#08-#
M@U*#DX+&@V6#3(-8@V<`242"S):\D4\`@N""M8+@D+."M8*ME5R.IH*S@NJ"
MR(*B@LB"YX%!)7,@@K6"Q)!6@K6"HH-%@T.#DX-H@5N"\(I*@J*"Q(FZ@K."
MHH%"`(+@@K6"X"!);G1E<FYE="!%>'!L;W)E<B""\(YG@L&"Q(*B@L2!08-!
M@T.#4H.3@JJ57(ZF@K."ZH+(@J*"R(+G@4&"L8*Q@O"129'P@K6"Q(FZ@K."
MHH%"`):SCHL`@K>"UX+$EK..BP")YI&<@W:#C(-R@X6!6P")YI&<(%523`")
MYI&<(%523#H`B>:1G`"#0X.3@WR!6X-G`(RN@LR#0X.3@WR!6X-G`(RN@WF#
M08+,@T.#DX-\@5N#9P!01U`@C*Z"S(-#@Y.#?(%;@V<`C,*0;(+,(%!'4""4
MZ9:GC*Z"\(-#@Y.#?(%;@V<`C,*0;(+,(%!'4"",]HI*C*Z"\(-#@Y.#?(%;
M@V<`C,*0;(+,(%,O34E-12"/V):^CY&"\(-#@Y.#?(%;@V<`C/:*2HRN@LR#
M0X.3@WR!6X-G`%!'4"",]HI*C*Z"S(-#@Y.#?(%;@V<`4R]-24U%((SVBDJ,
MKH+,@T.#DX-\@5N#9P!3+TU)32",KH+,@T.#DX-\@5N#9P!-0D]8C&".KH+,
M@W2#0(-#@XN"\(-#@Y.#?(%;@V<`34)/6(Q@CJZ"S(-T@T"#0X.+)7."\"5S
M@LF#0X.3@WR!6X-G`(-#@Y.#?(%;@V>!08-8@V6#8H-V("5D`(]DEW8`CV27
M=H+(@X&!6X.+`"5D@LR#@8%;@XN"\"5S@JF"YX-#@Y.#?(%;@V>"M8+<@K6"
MO8%"`(-#@Y.#?(%;@V>"LX+J@KV#=(-"@5N#BX-H@48@)7,`@T.#DX-\@5N#
M9X*S@NJ"O8-T@T*!6X.+@VB!1@"/B)>=DH8`24Y"3U@`E=2038Z>@LF#=X-B
M@U^"S(CJE92"\)5TB<&"M8+<@K>"J8%(`)74D$V.GH+)C+."S(.!@5N#BX+P
MB/B7<(*U@MR"MX*I@4@`BM2(X8+!@KV#08-.@U:#AX.3@U*!6X-H@JJ77H*F
M@N>"ZH+$@J*"W(*W@4(`@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI"S@K6"K8*@
M@NB"W(*Y@O&!0@"2:8FZ@K""\)!;@JT`C,*5RH.&@5N#50"/[I7Q`(-#@Y.#
M=(-(@X&!6X-6@X>#DP!?3XSC@NN"R9?Q@O"1?9/\`(GFD9R"\)%]D_P`E5R"
M\)%]D_P`@XJ#DX-.@O"1?9/\`%]#D4^"R9?Q@O"1?9/\`(R[C=V(RI)U@LR,
MXX+K@LF7\8+PD7V3_`",NXW=B,J2=8+,D4^"R9?Q@O"1?9/\`(R[C=V(RI)U
M@LR,XX+K@LF-<X+PD7V3_`",NXW=B,J2=8+,D4^"R8US@O"1?9/\`(R[C=V(
MRI)U@LR,XX+K@LF2:9>.@O"1?9/\`(R[C=V(RI)U@LR13X+)DFF7CH+PD7V3
M_`"1XY'6@V6#DX-V@XR!6X-G@LR1?9/\`(SC@NN"R8-:@XN"\)%]D_P`D4^"
MR8-:@XN"\)%]D_P`C.."ZX+)E_&"\)%]D_P`D4^"R8-:@XN"\)%]D_P`C.."
MZX+)DFF7CH+PD7V3_`"13X+)DFF7CH+PD7V3_`",XX+K@LF-<X+PD7V3_`"1
M3X+)C7."\)%]D_P`B>:1G(+,D7V3_(%>E<^-6`"#BH.3@TZ"S)%]D_R!7I7/
MC5@`D9>039#F@LF1EX+I@KV"WX+,CF.-@H*JE7.1JX*U@L2"HH+<@K>!0@".
M8XV"@JJ5<Y&K@L6"MX%"`)5SD+."R(^(DG6"\)%)D?""M8+<@K6"O8%"`)5S
MD+."R(-!@W:#BH-0@5N#5H.'@Y."Q8*W@4(`EK.,^(+(@V:!6X->@JJ2\8]O
M@K."ZH+<@K6"O2X`D9>"Z)#F@LR#08-H@XR#6(*JE7.0LX+%@K>!0@"5<Y"S
M@LB,K@"/XXC*@LR#08-.@UJ#6(R@@JJ5<Y"S@L6"MX%"`)5SD+."R"!01U`@
ME.F6IXRN@L6"MX%"`)5SD+."R"!01U`@C/:*2HRN@L6"MX%"`(RS@LR#08-H
M@XR#6(*JE7.0LX+%@K>!0@"5<Y"S@LAU;FEC;V1E@V:!6X->@L6"MX%"`)2]
MDUT`E*V-<X[2`([.D<P`@E",C@""5HR.`()5C(X`D;6"IH+I`)*&B9N1M8*F
M`)>\DEN1M8*F`(VVD;6"I@")19&U@J8`2V5R8F5R;W,@@U2!6X-O@JJ41H_8
MBY&4VX*U@MR"M8*]@4(`C*Z-[)"LD_H`C*Z.=Y;D`(RN@LR2MX*S`(RNCNV7
MW@"39(YQC*Z"JH*W@L6"R8SVCT^,KH-4@5N#;X+)D;:-W8*U@MR"MX%"`(RN
M@LV,]HI*C*Z#5(%;@V^"R9&7@N>"ZH+<@K6"O8%"`(R^C.J0W9+H`(.!@5N#
MBX-[@V*#3H-8@LR-Q8SC@LR#>8%;@U<`C<6,XX+,@WF!6X-7`)%/B?&"S(.-
M@T^#0X.3.B`E<P"13XGQ@LR#C8-/@T.#DSH@)3(D<R""J8+G("4Q)',`D4^)
M\8+,@XV#3X-#@Y,Z((+(@K4`@XR#0X-!@T6#9P!?3H.*@Y.#3HQ>DUF5=`"#
MBH.3@TZ,7I-9E72"S8YGEW""Q8*K@MR"N8+Q@4(`@V:!6X->@WB!6X-8B.J7
MEP"#=X.+@W:-@);:@O"57(ZF@K>"Z0"57(+,B.J7EP"#=X-B@U^5E(+)B.J7
MEY5<CJ8`@X:!6X-5@LR#BH-8@V>"S9:SC/B"R8+(@L&"Q(*B@MR"MX%"`(.-
M@5N#2H.+@LR#@8%;@XN#>X-B@TZ#6):\@48`DFZ(YH+&CIZ*U`"/ZH^*`(.-
M@T^#0X.3`"5S((+)@XV#3X-#@Y,`@XV#3X-!@T6#9P"#C8-/@T.#DP"#C8-/
M@T.#DX->@UB#3@"#AH%;@U66O(*I@W"#6(./@5N#:(*JD+."M8*M@LB"HH*]
M@M^"R8.-@T^#0X.3@LF.N)1S@K6"W(*U@KV!0@"#C8-/@T.#DX+)CKB4<X*U
M@MR"M8*]@4(`DN$`DN&71)#FDW@`@TV#BH-6@X.5MHZ:@6F/K)6VCIJ!:@"#
MB8-E@Y.5MHZ:@6F/K)6VCIJ!:@"#C8%;@WV0E(Z:@6F/K)6VCIJ!:@"-Q9+A
M`(R.`)-9E72"LX+J@KT@35,M5$Y%1B""S8-F@5N#7H+PBMR"\8+%@J*"W(*Y
M@O&!0@"0VI&Q@K>"Z8.!@5N#BX-4@5N#;X+,CNV7WH%&`(.!@5N#BX-[@V*#
M3H-8`(.!@5N#BX-[@V*#3H-8@L:#=(-(@XN#7X+,E5R.IH-)@W:#5H.'@Y,`
MD$:5=(*O@K."ZH*]@XF#>(.+@O"1SHF>@K."N8+$E:J7WH+PBL>7G8*U@MR"
MMX%"`()2C(X`B/."\)5T@J^"Z8%&`(CXEW"5E)6J@O"5RH+,D$:"Q95<CJ:"
MM8+<@K>"J8%(`(KYD\>"R8*U@MR"MX*I@4B!:4E-05"#5(%;@V^"S(+=@6H`
MD;Z.FH%!B;J0_(%!CLZ1S(+PDE"/@X+)E5R.IH*U@MR"MX*I@4@`D5."Q(*J
MB.J2=H*W@ND`@L>"ZH*I@JJ(ZI)V@K>"Z0"#=(-"@5N#BX-H@O"(ZI)V@K."
MN8+$@J*"W(*W`(W%D>63695T@U2#0X-9`)-9E720E(+,C^.,P(+)DD*"M8+<
M@K6"O8%"`)-9E72#5(-#@UF"S(_CC,""R9)"@K6"W(*U@KV!0@""5(R.`(GO
MBV."S([FC\&"M0")[XMC@LR/[I7Q`(GOBV."S)+QB,0`B>^+8X+,E=2.E@")
M[XMC@LR5SXU8`(GOBV.5SXU8@LR7=HN!`(.!@Y.#;P"#@8-J@X6!6X."@5N#
M:`"#6H.+C(N-AP"#@8%;@XL`@X&!6X.+C>R0K`"#@8%;@XN"S)/ZE70`@X&#
M8H-:@5N#5X-)@W:#5H.'@Y,`@X&!6X.+@LR,GXWU`(.!@5N#BX-4@T.#60"#
M@8%;@XN#7(%;@U@`@X&#8H-:@5N#5X+-C)^/V(+%@JN"W(*U@KV"JH%!CY"6
MO([2@LR09XRS@LV,GX_8@L6"JX+<@KF"\8+%@K6"O8%"`(.!@5N#BY5<CJ8`
M@X&!6X.+@W2#B8-/`(.!@5N#BX-T@TB#BX-?`"5S((*I@N>"S(.!@V*#6H%;
M@U<`B.J2=H_PC(\`@X&#8H-:@5N#5X+-DUV1EX*S@NJ"W(*U@KV!0@"#@8-B
M@UJ!6X-7@LV1EY!-@K."ZH+<@K6"O8*J@4$E<R""R97;D;:"LX+J@L2"HH+<
M@KF"\0"#@8-B@UJ!6X-7@LR1EY!-D*R,]P"#@8%;@XN#>X-B@TZ#6)5<CJ:"
MS(IE@WF!6X-7@LF57(ZF@K."ZH+I@X&!6X.+D)0`@X&!6X.+@LR(VI.ND.8`
M@X&#7(-B@V@`36EM92!4>7!E`)#=DNB"JH*@@NB"W(*Y@O&!0H*Q@LR#08-V
M@XJ#4(%;@U:#AX.3@O".9Y=P@K>"Z8*]@M^"R8+-D-V2Z(+PC>R0K(*W@NF5
M2Y=V@JJ"H(+H@MR"MX%"`(R.`(QGD=&#@8%;@XL`CT.0LY/Z`(]#D+,`EHB,
MC@"(VI.N`(FZ@M8`C;:"U@")18+6`(_C@M8`B;J"UHC:DZX`@W2#2(.+@U^"
MR8C:DZX`C^."UHC:DZX`@T&#2H-%@Y.#9P"3KXC3@K6"W(*Y@O$`EKR13P"/
MB))U@JJ52Y=V@L6"MP"#;(-B@V>#CX%;@TX`@LB"M0"3695T@LV5VY&V@K6"
MR(*B`)!6BTL`D%:+2Y6JE]X`D%:+2X-T@TB#BX-?`)!6DH6#@8%;@XL`D%:"
MM8*B@X:!6X-5EKPHE$.(TRD`D%:+2X.!@5N#BP".GX+6`(Z?@LR#@8%;@XL`
MCI^"S(-Y@5N#5P""R(*U`(_8EKZ/D8*JC*F5=(*I@NB"W(*Y@O$`B,.-AHF[
M@K6"R(*B`(RN@XJ#DX-/@LV+\X+%@K<`C,*0;(+,C]B6OH^1@JJ77H*F@N>"
MZH+$@J*"W(*Y@O$`C/:*2HRN@JJ"H(+H@MR"N8+Q`%,O34E-12",]HI*C*Z"
MS8-#@Y.#?(%;@V>"LX+J@MR"N8+Q@L6"M8*]@4(`DUF5=(*J@J""Z(+<@KF"
M\8%"`(VWE:J"\)5<CJ:"MX+I@KV"WX+,D-V2Z(*J@J""Z(+<@KF"\8%"`)7/
MC5B"R(*U@4(`@K&"S(-!@TZ#6H-8C*""R8+-@U2#=8-!@TZ#6H-8C*""S9+'
MB<&"Q8*K@MR"N8+Q@4(`1E10(%9&4R""S(U<D*R/[I7Q@JJ.=Y+H@K."ZH+$
M@J*"W(*Y@O&!0@!344P@5D93((+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<
M@KF"\8%"`%-13""#2H-E@U.#BH+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<
M@KF"\8%"`(YCC8*"JH*@@NB"W(*Y@O&!0@"1EY!-D.:"JHYWDNB"LX+J@L2"
MHH+<@KF"\8%"`(-T@TB#BX-?@JJ129'P@K."ZH+$@J*"W(*Y@O&!0@"05I*%
M@X&!6X.+@O"#8(-&@V*#3H*W@NF#=(-(@XN#7X*JCG>2Z(*S@NJ"Q(*B@MR"
MN8+Q@4(`@W2#2(.+@U^"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`)9[E;:"R(*U
M`(.!@V*#6H%;@U>"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`(R?C?6/\(R/@LF(
MZI)V@K>"Z8.!@V*#6H%;@U>"S8RI@L*"J8+H@MR"N8+Q@L6"M8*]@4(`EKR1
M3X*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`E-2-AH*JCG>2Z(*S@NJ"Q(*B@MR"
MN8+Q@4(`2%144""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(`24U!
M4""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(`2V5R8F5R;W,@E$:/
MV(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"`(.-@T^#0X.3()1&C]B"S(-P
M@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@!005-35T0@E$:/V(+,@W"#6(./@5N#
M:(*J@J""Z(+<@KF"\8%"`%--0B"41H_8@LR-7)"LC^Z5\8*JCG>2Z(*S@NJ"
MQ(*B@MR"N8+Q@4(`3W!E;E-33""#=H.-@T^#B8.`@LR#<(-8@JJ.=Y+H@K."
MZH+$@J*"W(*Y@O&!0D]P96Y34TP@@LT@4$M#4R`Q,B""S(-F@5N#7H+PB+6"
MI(+,@LF52Y=V@L6"MX%"`)7;EZ^"S(-4@T.#DX-!@V*#=H+(@K6!0@"#6(-Y
M@XN#1X.)@5N"R(*U`(SSE>*"R(*U`(.&@5N#59:\@JF#<(-8@X^!6X-H@JJ1
MEX+G@NJ"W(*Y@O&"Q8*U@KV!0@"6LXSX@LQ834R#9H%;@UZ"JI74@NB"W(*U
M@KT`DFR"R(*U`(RS@LR0W9+H@LF#;X%;@U>#AX.3@JJ"H(+H@MR"N8+Q@4*-
MQ)-XD-V2Z(+PD+:0K(*U@MR"MX%"`(*@@LB"O8+,D-V2Z(+)@V^!6X-7@X>#
MDX*J@J""Z(+<@KF"\8%"C<23>)#=DNB"\)"VD*R"M8+<@K>!0@".48G!CM*(
MR(I/`(+(@K4`DLJ/[0""L8+J@N:"Z)%/`(*Q@NJ"YH+HC.,`C>V/G(*S@NJ"
MQ(*B@LB"H@")NH^1@JN"Q8+(@J(`CV27=H+%@LB"H@",PI!LDTF"Q8+(@J(`
MC>V/G(*S@NJ"Q(*B@LB"HH.!@5N#BP"/9)=V@L6"R(*B@X&!6X.+`(-M@5N#
M9P`Q,8R.`(S#@J*#BH.3@TZ,7I-9E72"\(WMCYR"MX+IC^J-AX%!E=N1MH*W
M@NF,CI"4`):(C(Z-[8^<@K>"Z8_JC8>"R97;D;:"M8+$@JB"JX*]@J**^9&V
M@LR!;9&7D$V-5(*F@6Z#=(-(@XN#7X+,D)0`D9>039#F@XJ#6(-G@O"-6)!6
M@KV"WX+,E-2-AH*JCG>2Z(*S@NJ"W(*Y@O&"Q8*U@KV!0@!/2P"#28-U@U>#
M1H-.@V<`@TF#=8-7@T:#3H-GC>R0K([2`#$PC(X`@TF#=(-"@U@`BOF1MH+,
M@X&!6X.+`(S#@J*!;9&7D$V-5(*F@6Z#=(-(@XN#7X+,C\&+CI*&@4(`BZ27
M3(-T@TB#BX-?@LT@24U!4""#5(%;@V^"OH*O@JJ#5(-\@5N#9X+%@JN"W(*W
M@4(`DV2.<8.!@5N#BX-!@VB#C(-8@LTQ@L*"OH*OCG>2Z(+%@JN"W(*W@4(`
MCXJ73([2@JF#5H-8@V6#@(K'EYV.TH*^@J^"JHNDETR"S(^*ETR,H(+&@T&#
M3H-:@UB,H(+PE<^-6(+%@JN"W(*W`)!6BTN#18-#@Y.#:(%;@LF57(ZF`$]P
M96Y34TP@@T>#B8%;@493+TU)344@CY"6O(*S@NJ"O8-P@5N#9X*I@N>#9H%;
M@UZ"\([F@NB/;X*Y@MR"N8+Q@L6"M8*]@4(`E$.(TX+,CE&)P8[2`(-)@W:#
M5H.'@Y,`)7,@@TF#=H-6@X>#DP"/AX^8E72#BH-8@V<`D6>01`"5E(^0`)"N
MEYT`C+."S(-!@W:#BH-0@5N#5H.'@Y.#98.3@W:#C(%;@V<`D;R"S(-#@Y.#
M=(-(@X&!6X-6@X>#DP""NX+,D;R"S(-)@W:#5H.'@Y,`CXJ73([2@LR#08-.
M@UJ#6(R@`%!!32"41H_8@LV.9Y=P@L6"JX+<@KF"\8%"`%!'4""39(YQCY"6
MO`!01U`@B,.-AHF[`%!'4""(PXV&E;8`4$=0((-'@XF!6SH@`%!'4""#1X.)
M@5LZ()3IEJ>,KH+,@W"#6(-T@XR!6X-9@JJ52Y=V@L6"MX%"`%!'4""#28-V
M@U:#AX.3`%!'4""#<(-8@W2#C(%;@UF"S)/\E\T`4$=0((S"D&R,KH+,@U2#
M?(%;@V>"R8+-B,"14X+(('=E8B"0VI&Q@JJ52Y=V@L6"MX%"`%!'4"",]HI*
MC*X`4$=0((SVBDJ,KH.*@Y.#3P!01U`@CY"6O`!01U`@DV2.<8^0EKR!7HC#
MC8:)NP!01U`@CY"6O(W/+XC#C8:)NX-F@5N#7@!01U`@@LR#5(-\@5N#9X+-
MC+N-W9:SC/B"R8+(@L&"Q(*B@MR"MX+,@L6!09-DCG&/D):\@LR,GX_8@LV"
MQ8*K@MR"N8+Q@4(`4$=0((+,@U2#?(%;@V>"S8R[C=V6LXSX@LF"R(+!@L2"
MHH+<@K>"S(+%@4&5G(V&@LV"Q8*K@MR"N8+Q@4(`4$A0@U*!6X-H`%!(4(-6
M@T:#BP!03U`S@6F.J9.NE+N5RH%J`):$D9``)60@@5X@)60@@WF!6X-7`(W%
MCXF"S):BD\>#@8-B@UJ!6X-7@O"*W(+>@WF!6X-7`(W%C.."S):BD\>#@8-B
M@UJ!6X-7@O"*W(+>@WF!6X-7`(-P@5N#9P"#<(-8@X^!6X-H`(-P@UB#CX%;
M@VB"JI"S@K6"K8*@@NB"W(*Y@O$`4D%$2553()1&C]B"S(-P@UB#CX%;@VB"
MJI5+EW:"Q8*W@4(`@W"#6(./@5N#:(+,BFV41@"#<(-8@X^!6X-H.@"#<(-8
M@X^!6X-H.B``@W"#6(./@5N#:(*JB.J2=H*U@MR"N8+Q@4(`DUR"Z)5T@J\`
MDUR"Z)5T@J\`E=N7KY*&@LR#5(-#@Y.#08-B@W:!1@"#<(%;@UJ#DX-G`)7;
MCN>1@(WL@O".P(US@K>"Z0"#C8-/@T.#DXZ>@LF"\)7;CN>-[(O&@O".P(US
M@K6"W(*W@JF!2`"#08-.@UJ#6(R@`(-!@TZ#6H-8C*""S(K'EYT`@K&"S(.&
M@5N#58+,@T&#3H-:@UB,H(+-E<^-6(+%@JN"W(*Y@O&!0@".J96JB+8`C,*0
M;(_NE?$`DV288@"#<X-.@UJ#BP"5U)!-@MR"O8+-DUV1EX*W@NF13X+)CY"6
MO(+PDL>)P8*U@MR"MX*I@4@`C(Z"QI1.@O"3_)?-@K6"Q(*M@KZ"LX*B@4(`
MD%:"M8*BE:J7WH+,EKR13X+PD_R7S8*U@L2)NH*S@J(Z`)!6BTN#=(-(@XN#
M7X+,EKR13X+PD_R7S8*U@L2"K8*^@K."HH%&`)"S@K6"HI/ZE72"\)/\E\V"
MM8+$@JV"OH*S@J(N((R.@LR3^I"4@O"#8(-&@V*#3H*U@L2"K8*^@K."HH%"
M`)!6BTN#=(-(@XN#7X+,EKR13X+PD_R7S8*U@L2"K8*^@K."HH%&`)!6@K6"
MHI:\D4^"\(YWDNB"M8+$@JV"OH*S@J*!1@"/X8I1D^"798+PEW:6\8*U@L2"
MLHM,D_R"K8*^@K."HH%"`(-P@UB#CX%;@VB"\(M,D_R"M8+$@JV"OH*S@J*!
M0@"#AH%;@U66O(+&@W"#6(./@5N#:(+PD_R7S8*U@L2"K8*^@K."HH%"`(.&
M@5N#59:\@O"+3)/\@K6"Q(*M@KZ"LX*B@4(`@J""HH+<@J*"R""!:8+<@KV"
MS9:SC/B"R(%J((-!@VB#C(-8@O"/0Y"S@K6"Q(*M@KZ"LX*B@4(`B,B)NH+,
MD^"798+PBFV41H*U@KV"S(*_@4&(R(FZ@LR#@8-J@X6!6X*I@N>/B))U@O"1
M29'P@K6"Q(FZ@K."HH%"`)&`C>R"\([`C7."MX+ID4^"R8-T@TB#BX-?@O"1
M28+Q@L6"K8*^@K."HH%"`(R?C?6"MX+I@W2#2(.+@U^"\"`Q((+"B,B/XY%)
M@O&"Q8*M@KZ"LX*B@4(`@K&"S)&`C>R"\(US@J2#=(-(@XN#7X+P(#$@@L*"
MOH*OD4F"\8+%@JV"OH*S@J*!0@"3BI5;D)0`CY"6O(+,D4^"R8+-@U^#8H-6
M@X6!:2<M+2`G@6J"\)5T@J^"W(*W@JF!2`!0<F5F<U]L9&%P.B"52Y=V@LA,
M1$%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`4')E9G-?;&1A<#H@E4N7
M=H+(<V5S<VEO;HIGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`)!6@K6"HH-%
M@T.#DX-H@5N"R8GFD9R"\)5<CJ8`D4^"S(.!@5N#BP"13X+,@WF!6X-7`(CS
MC?P`B/.-_`"71)#FDW@`E.F6IXRN`(_ABE$`C^&*49/@EV6"S)#@EKX`DUF5
M=(+PD9>038*U@KV.GH+-D'&"RX+I@4>#9H-T@TB#BX-G3D\`DUF5=(+PD9>0
M38*U@KV.GH+-D'&"RX+I@4>#9H-T@TB#BX-G6453`(-V@XV#9X-2@XN!1@",
M]HI*C*X`C/:/3XRN@T&#BX-3@XJ#68.``(SVCT^,KB^4Z9:GC*Z"JI"VD*R"
MQ8*K@MR"N8+Q@L6"M8*]@4(`7T>#4X-^E*""\(OS@LF"MX+I`(-3@WZ4H(+P
MB_."R8*W@ND`@U.#?I2@@O"+\X+)@K>"Z95PDWB!1@"#4X-^E*"#=(-(@XN#
M7Y/@@LR#@8%;@XN"\(OS@LF"MX+I@MR"Q8+,D_J0E`"#4X-^E*"3X(+,C,."
MHH.!@5N#BX+PC\&+CH*U@MR"MX*I@4@`@TZ#1X.*@5L`4E-!C/:/3XRN*"5D
M@W*#8H-G*0"4Y`!?491ZDD**;91&@O"7=HN!`)/'@MX`EGN3EH+)("5S((+P
MC>V/G(*U@MR"MX*I/R""L8+,D8"-[(+-C+."R9;?@KF"W(*Y@O&!0@"6>Y.6
M@LF#AH%;@U4@)7,@@LR#9H%;@UZ"\(WMCYR"M8+<@K>"J8%(((*Q@LR1@(WL
M@LV.YH+HC\&"N8+<@KF"\8%"`%]4@KN"S(+<@MR379&7`(*[@LR"W(+<DUV1
MEP"#@8%;@XN"\(*[@LR"W(+<DUV1EX*W@ND`@K&"S(.!@5N#BX+P@KN"S(+<
M@MR379&7@K>"Z0"379&7@L6"JX+<@KF"\8+%@K6"O8%"`(+B@NB2O(*W`(W$
ME5R.I@"3KI-)@X&#:H.%@5N"S(W$E5R.IHK4BG4Z`(-T@TB#BX-?E5R.IH+,
M@XJ#=(.,@V*#5H.%.@"#?(%;@UZ#BX+,C<257(ZF`)5<CJ:"\(.*@XV!6X-H
M`)=<DNB/[I7Q@O"+3(FO@K>"Z8%"`(W%C.."S)5<CJ:"\(M,B:\`@XJ#@H%;
M@V>"S(.!@5N#BX-[@V*#3H-8EKR!1@"#BH."@5N#9X-4@5N#<H-8`(.*@X*!
M6X-G55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H@`(WMCYP`
M@W6#C8-B@TZ"\(WMCYP`C)^-]8*I@N>/G(I/@K>"Z0"#>8-!@O"-[8^<`(.&
M@5N#58+PC>V/G`"#AH%;@U6"\(WMCYPZ("5S`(-T@TB#BX-?EKR"\)7/C5@`
MD9>038U4@J:#=(-(@XN#7X+,EKR13X+PEHB,CH+,CXF"WX+)E<^-6(*U@MR"
MMX*I@4@`(B5S(B""\"`B)7,B((+)E<^-6(+%@JN"W(*Y@O&"Q8*U@KV!0H-4
M@5N#;X+,@T>#B8%;.@!?68.*@UB#9X+)E=2030".GX+&DG6*MX%&`)74D$T`
ME=2038JNE[F!0@"14XCU@LF5U)!-`)%3B/6"R974D$V!1@"#BH-8@V>"R974
MD$T`@XJ#6(-G@LF5U)!-@48`7T&14XCU@LF5U)!-`(-4@WR!6X-GBD^"S(.!
M@V*#6H%;@U>"Q974D$T`,H.6C(Z5JH+,EUR2Z(_NE?&5=(*K@L65U)!-`)=V
MBX&"LX+J@KV77)+HC^Z5\8+%E=2030`@()74D$V!1@"5U)!-.@!34$%-@L:"
MM8+$@XR#?(%;@V<`7U**2I65BFV41H+PEW:+@0"7=HN!@LF5U).:@L6"JX+<
M@KF"\3H@`)1ZDD**;91&@O"7=HN!@K6"W(*W@JF!2`"*2I65BFV41H+PEW:+
M@8*U@MR"MX*I@4@`E4N0>XY1B<&.T@"#BH-:@V*#9P")\9.:CM*"S(_SB[6"
M\(U8D%:"M8+<@K6"O8%"`(R+B<H`C<2*2@"#28-V@U:#AX.3@LF6WX+I`(.!
M@V*#6H%;@U>"\(WMCYR!08C:DZZ!08-2@W.!6X*U@KV,XX%!@X&!6X.+@WN#
M8H-.@UB#BH-8@V>"R9;?@NB"W(*W@JF!2`",LX+,C5R0K(+)EM^"MP"#98-,
M@UB#9X-'@V:#0H->@5N"S(-)@W:#5H.'@Y,`EO"*A`"-<Y&ND*L`C7.1KI"K
M`(US@48`CL"-<P!3+TU)344@B,.-AH^0EKP`4R]-24U%((C#C8:)NP!3+TU)
M344@B,.-AI6V`%,O34E-12"#1X.)@5LZ(`!3+TU)344@@T>#B8%;.B"4Z9:G
MC*Z"S(-P@UB#=(.,@5N#68*JE4N7=H+%@K>!0@!3+TU)344@@LR#28-V@U:#
MAX.3`%,O34E-12""S(-P@UB#=(.,@5N#68+PD_R7S0!3+TU)344@C,*0;(RN
M@LR#5(-\@5N#9X+)@LV(P)%3@L@@=V5B()#:D;&"JI5+EW:"Q8*W@4(`4R]-
M24U%((SVBDJ,KH.*@Y.#3P!3+TU)344@@LR,]HI*C*Z!7I3IEJ>,KH+,@WF#
M08+-DL>)P8*S@NJ"W(*U@KV!0@!3+TU)344@CY"6O`!3+TU)344@CY"6O(%>
MB,.-AHF[`(*Q@LR#5H-8@V6#@(+%@LT@4R]-24U%((+-@U2#?(%;@V>"LX+J
M@L2"HH+<@KF"\8%"`%,O34E-12"#5(-\@5N#9X+-C+N-W9:SC/B"R8+(@L&"
MQ(*B@NF"O8+?@4&#@8-B@UJ!6X-7@LR5G(V&CXB7G8*J@L6"JX+<@KF"\8%"
M`%,O34E-12"#5(-\@5N#9X+-C+N-W9:SC/B"R8+(@L&"Q(*B@NF"O8+?@4&3
M9(YQCY"6O(+,C)^/V(+-@L6"JX+<@KF"\8%"`%-!4TP@E$:/V(+-CF>7<(+%
M@JN"W(*Y@O&!0@!344P@@U:#1H.+`%-32`"3>0!?5HZ?@LR/ZH^*@LF#4H-S
M@5N"\)7;D;8@`%]6E=N1M@"5VY&V`"5S((+PE=N1M@"3695T@N"#@8-B@UJ!
M6X-7@L:+I(+)D9>038U4@J:#=(-(@XN#7X+)E=N1MH*U@MR"MX*I@4@`B;J/
MD8*K@O"5VY&V`(-)@W:#5H.'@Y."\)7;D;8`7T2)NH^1@JN"\)7;D;8`EKR1
M3X+PE72"KX+$E=N1M@")NH^1@JN"\):BD\>"QH*U@L25VY&V@K6"W(*W@JF!
M2`".\Y!-CM*"\(ZIDZZ328+)@V:#=(-(@XN#9X+,@T&#:(.,@UB2H(+)DL>)
MP8*U@MR"MX*I@4@`C)^-]8R+B<J"\(F\D7J#=(-(@XN#7X+)E=N1MH*U@MR"
MMX*I@4@`D9>038.!@5N#BX+,C52"IH+PE=N1MH*U@MR"MX*I@4@`)7,@D-V2
MZ(+PE=N1MH*U@MR"M8*]@4(`B;J/D8*K@O"5VY&V@L6"JX+<@KF"\8+%@K6"
MO8%"@U2!6X-O@JF"YX+,B9Z3FH%&)7,`C)^-]0",GXWU("5S`(R?C?6,BXG*
M`(KYD\<`D4F1\`"#08-*@T6#DX-G@O"129'P`)/ZE72"\)%)D?``@W2#0H%;
M@XN#:(+PD4F1\`"2QXG!@K>"Z8-/@XN!6X-V@O"129'P@K6"Q(*M@KZ"LX*B
M`)!6@K6"HH^*CIV.TH+PD4F1\(*U@L2"K8*^@K."H@"#5(%;@V^"\)%)D?""
MM8+$@JV"OH*S@J(`DL>)P8*W@NF#AH%;@U6"\)%)D?""M8+$@JV"OH*S@J(`
M@T&#:(.,@UB"S)+'B<&"XHR?C?6"\(US@J2#08-H@XR#6)*@@LR#7(%;@UB"
M\)%)@O&"Q8*M@KZ"LX*B@4(`@K>"UX+$@O"129'P`(-!@TJ#18.3@V>"\)%)
MD?``@L>"ZH+@D4F1\(*U@LB"H@"52Y=V@LB5MHZ:@O")NH+,@WN#8H-.@UB"
MJ8+GD4F"\8+%@U*#<X%;@K>"Z8+&@4&#98-,@UB#9X-'@XJ#08+6@WF!6X-8
M@V>"Q8*K@MR"MX%"`)/ZE72"S(OFD-B"Z)6VCIJ"\(YWDNB"M8+$@JV"OH*S
M@J*!1@"3^I5T@LR,8(ZN@O".=Y+H@K6"Q(*M@KZ"LX*B@48`E<^-6(*U@KV"
MHDE$@O"129'P.@"#@8%;@XN#5(%;@V^"S([ME]Z"\)%)D?``CIZ-CX+,B^:0
MV(+HE;:.FH+PCG>2Z(*U@L2"K8*^@K."HH%&`(Z>C8^"S(Q@CJZ"\(YWDNB"
MM8+$@JV"OH*S@J*!1@"(ZI)V@K>"Z8)1@L*"S(-T@T*!6X.+@VB"\)%)@O&"
MQ8*M@KZ"LX*B@4(`D$:2LH+PD4F1\(*U@L2"K8*^@K."HBX`C+Z,ZH+PD4F1
M\(*U@L2"K8*^@K."HCH`D4F"SH+J@L2"HH+I@T&#:(.,@UB2H(%&`(W%D%:"
MS(_NE?&"\)&7@ND`@X&!6X.+@LR1EY!-`(_ABE&#C(-\@5N#9X+PD9>038*W
M@ND`4TU3()&7D$T`D9>038U4@J:#=(-(@XN#7P"1EY!-C52"IH-T@TB#BX-?
M@48`@EB,C@"2RI34`(-4@5N#;P"#5(%;@V^"QH-T@TB#BX-?@LR/[I7Q`(-4
M@5N#;SH`@X&!6X.+@O"(VI.N@4&-[8^<@K6"O8_JC8>"S(^(DG6"R8K6@K>"
MZ9#=DNB"\(YWDNB"M8+$@JV"OH*S@J*!0@"05HM+C>R0K(Z>@W>#8H-?@LE8
M+5!R:6]R:71Y@O"5=(*O@MR"MX*I@4@`@WR!6X->@XN"Q8-!@TZ#6H-8@K>"
MZ8.*@X*!6X-G@U2!6X-O@O"0W9+H@K6"W(*W@4(`C+Z,ZH%!CIZ*U)'1@4&3
M^I5T@O"0W9+H@K6"W(*W@4(`BDJ.;HZ>@LR#08-V@XJ#4(%;@U:#AX.3@4&0
M1I*R@4&#>8%;@U>-Q)5<CJ:!08*[@LR1O(+,E5R.IH-)@W:#5H.'@Y."\)%)
MD?""M8+$@JV"OH*S@J(N`(NDETR#=(-(@XN#7P"+I)=,@X&#0X.+@W2#2(.+
M@U\`@J""R(*]@LR#@8-#@XN#=(-(@XN#7X+PD;R"S(.&@5N#58+&BZ273(*U
M@MR"MX%"`(K(DE""R)=VEO&!1@"!:8.!@VJ#A8%;@LB"QX+%@6J#5H.'@5N#
M9X-*@V*#9X-,@5N"JHYG@J:"Z8+F@J2"R8*U@MR"MX*I@4@`DK>"HHCXEW""
M\)5<CJ:"M8+<@K>"J8%(B4*"M8+<@K>"J8%(((F]CIZ"Q8+@BLB24(+)E<^-
M6(+%@JN"W(*W@4(`@X&!6X.+@LR6>Y6V@O`@4$=0((+%C)^/V(*U@MR"MX*I
M@4@`B;J/D8*K@LR5VY&VC..!08.!@5N#BXWLD*R#18-"@Y.#:(-%@O"5PH*V
M@MR"MX*I@4@`@V:#=(-(@XN#9X+%(%!'4"",]HI*C*Z"\(.!@5N#BX+)DUF5
M=(*U@MR"MX*I@4@`E5R.I@"14X-T@TB#BX-?E5R.I@"#=X-B@U^"\)%3@L25
M7(ZF`(WMCYR-SX+=@O"57(ZF`(-W@V*#7X+,B.J5E(*^@J^"\)5<CJ8`@X&#
M0X.*@Y.#3X.*@UB#9X+,C^Z5\8+PE5R.I@"4\8UWD\>"R(+@@LR"\)5<CJ8`
MDUF5=(+PC>V/G(*W@NF"O8+?@LR#08-#@U*#DX+PE5R.IH*U@MR"MX*I@4@`
M@XV#3X-#@Y..GH+)D4^)\8+,@XV#3X-#@Y..GHK4@O"57(ZF@K6"W(*W@JF!
M2`"#@8%;@XN(ZI>7E5R.IH+,B;J"R9#@EKZ!:9:BD\>!0974D$V-SR`N+BZ!
M:H+PE72)P8*U@MR"MX*I@4@`E5R1@(WL@X&#:H.%@5N"\)5<CJ:"M8+<@K>"
MJ8%(`(GFELJ-MH+)("5S((.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2`"#@8-J
M@X6!6X-O@5N"R8.!@T.#BX[F@NB-GH+=@LR#08-#@U*#DX+PE5R.IH*U@MR"
MMX*I@4@`E5R.I@"/:X^L`(+<@KB7UX+H@LR#=8.-@V*#3H+PCVN/K(+<@KV"
MS8C:DZZ"LX*Y@L2"K8*^@K."HH%"`%]:@U2#0X-9`(-4@T.#DX-!@V*#=@"3
M9(YQCY"6O`"39(YQCY"6O(-!@XN#4X.*@UF#@`"/D):\E70`@U2#0X-9`)7;
MCN>"\(-8@TR#8H-V@K>"Z0"3GI*%CIZ*U(^'`)/ZE72/AP"1EY!-C+.#08-H
M@XR#6(^'`(-4@T.#68^'`(-4@W6#5X-&@TZ#9X^'`(-8@XR#8H-HCX<`@T&#
M:(.,@UB/AP"1EY!-C+.#08-H@XR#6`"77922`)==E)*"QI:$D9``4U!!38.!
M@T.#BY=P@W2#2(.+@U\`D\&.ZI6VCIJ"S)/\E\T`@UB#>8.+@V"#1H-B@TJ!
M6P"#6(-Y@XN#8(-&@V*#3HJNE[D`@UB#>8.+@V"#1H-B@TZ.GH+)E5R.IH*W
M@NF#1X.)@5N0E`"*2HYN`(]"@MR"O8+-C*<`C_.1U`"/6H^*E-22;@".YH_!
M@K60_`"3695T@O"/G(N.`(G\C7."\(^<BXZ"M8+<@K>"J8%(`(-8@UZ#0X.+
M(%M#4U-=`)/Z`%]*C(^6O`",CY:\`(R/EKR7DP".P(US`(-T@TB#BX-?@O"-
M=Y/'`(FZE72"JP"0K(SW`"5S((+-CY&"JXV>@MR"ZH+<@K6"O0"2\8C$`(I4
MEW8`C^.5=(*K`)"I`)72CU>#@H%;@VB"S)#8D=:"I@!(5$U,()72CU>#@H%;
M@VB"R9#8D=:"IH+I`(-E@TR#6(-GE=*/5X."@5N#:(+)D-B1UH*F@ND`5%-6
M@W2#0(-#@XL`E5P`E5R1KI"K`)5<D:Z0JP"#7H-8@TX`7UB6>Y6V`)-DF&*4
MU(V&`)=VBX&"\(F\CO.1^(*W@ND`B;R.\Y'X`(-E@TR#6(-G@LR"W0"5MHZ:
ME'J2=0"6V`""LI>8EW""H(+H@JJ"QH*D@K*"M(*B@MR"M8*]@4(`1E10((IG
MDJ."JH*@@NB"W(*Y@O&!0@"#@8-B@UJ!6X-7@LP@1G)O;3H@EY."QH.*@Y.#
M3H*W@NF"S(+-.@!-86EN=&5N86YC92"#3H.)@UB"S)/'C9Z"W8*JD+./[8+)
MC7."IH+<@KF"\8+%@K6"O0"#28-V@U:#AX.3@T6#0H.3@VB#18+PE<*"MH+<
M@K6"O8%"CTF7N8*U@MR"MX%"`(-!@TZ#6H-8C*""\)=,C/B"R8*W@NF"R8+-
MBL>7G8[2@JJ"NX+,@V^#8H-.@T>#DX-H@O"0W9+H@K>"Z8*Q@L:"JI5+EW:"
MQ8*W@4(`@X&!6X.+C>R0K(-%@T.#DX-H@5N"JHI*@J^"W(*Y@O&!0H-U@XF#
M18-5@L6#?(-B@W:#08-B@W:#18-#@Y.#:(%;@O"#=8.-@V*#3H*U@L2"HH+<
M@KF"\8*I@4@`F$&7C9#F2424U(V&@JJ.=Y+H@K."ZH+(@JF"P8*]@JF!08OS
M@KZ"P8*]@JF!08*@@NF"HH+-@V:!6X->@WB!6X-8DH:"R8RIE72"J8+H@MR"
MN8+Q@L6"M8*]@4(`C+N-W8+,@W2#2(.+@U\@(B5S(B""S2`B)7,B((+&@J*"
MI):\D4^"R97/C5B"LX+J@MR"MX%"`)-DCG&/D):\@K."ZH*]@X&#8H-:@5N#
M5X+PC)^/V(*W@NF"R8+-@4%01U`@CY"6O(*JE4N7=H+%@K>!0@"1EY!-D.9)
M1)34C8:"JHYWDNB"LX+J@LB"J8+!@KV"J8%!B_."OH+!@KV"J8%!@J""Z8*B
M@LV#9H%;@UZ#>(%;@UB2AH+)C*F5=(*I@NB"W(*Y@O&"Q8*U@KV!0@"1EY!-
MD.9)1)34C8:"JHYWDNB"LX+J@MR"N8+Q@L6"M8*]@4(`B,.-AHF[@LF"S8C`
MD5."R(-%@T:#=9#:D;&"JI5+EW:"Q8*W@4(`@T.#>(.3@V>"S9=<DNB57(+)
MDL>)P8*S@NJ"W(*U@KV!0@"#=(-`@T.#BX*J@V:!6X->@O"*W(+Q@L6"HH+<
M@KF"\8%"`"(E<R(@@L:"HH*DEKR13X+,@W2#2(.+@U^"S8KY@LF1MHW=@K6"
MQ(*B@MR"MX%"`"(E<R(@@W2#2(.+@U^"S):\D4^"R8+-@4&.9X*F@LB"HI6V
MCIJ"JHK<@MR"ZH+$@J*"W(*W@4*6XI'H@LR0MH*V@NF)PI1<D*N"JH*@@NB"
MW(*W@LR"Q8%!@U:#6(-E@X"*QY>=CM*"R8*RBFV41H*M@KZ"LX*B@4(`(B5S
M(B"#=(-(@XN#7X*JC>R0K(*S@NJ"W(*U@KV"JH%!@K&"S(-T@TB#BX-?@O"-
M=Y/'@K6"Q(*B@MR"N8+Q@4(`(B5S(B"#=(-(@XN#7X*JC>V/G(*S@NJ"W(*U
M@KV"JH%!@K&"S(-T@TB#BX-?@LR-=Y/'@O"2AHY^@K6"Q(*B@MR"N8+Q@4(`
M(B5S(B"#=(-(@XN#7X+PC>R0K(+%@JN"W(*Y@O&"Q8*U@KV!0H-4@5N#;X*I
M@N>"S(F>DYHZ`"(E<R(@@W2#2(.+@U^"JHWLD*R"LX+J@MR"M8*]@4(`(B5S
M(B"#=(-(@XN#7X*JC>V/G(*S@NJ"W(*U@KV!0@`B)7,B((-T@TB#BX-?@LR6
MO)%/@JH@(B5S(B""R97/C5B"LX+J@MR"M8*]@4(`DHV(TX%)((-T@XN#6(-.
M@XJ!6X.3@X*!6X-H@LT@26YT97)N970@17AP;&]R97(@@L6"S9;BD>B"JI2M
MD+:"MX+I@K&"QH*J@J""Z(+<@K>!:8-U@XF#18-5@LR#;X-/@L6"MX%J@4*)
MYI;*@LF#4X-^@JJ57(ZF@K."ZH*]@NB!05=I;F1O=W,@@JJ#3H.)@V*#5H.%
M@K6"O8+H@K>"Z8*I@N""M8+J@MR"N8+Q@4)<;H-T@XN#6(-.@XJ!6X.3@X*!
M6X-H@LF"MX+I@LB"YR!/2R""\(F?@K6"Q(FZ@K."HH%"`$E$("(E<R(@@LV-
M[8^<@K."ZH+<@K6"O8%"`$=N=5!'((-O@T.#:8.*@LR#<(-8@JH@0W)Y<'1?
M<&=P((-.@XF#6(+)D-V2Z(*S@NJ"Q(*B@NF52Y=V@JJ"H(+H@MR"MX%"`(WL
MD*R2AH+,@X&#8H-:@5N#5X+-E<*"MH+G@NJ"W(*U@KV!0H])E[F"M8+<@K>!
M0@"#@8-B@UJ!6X-7@LV,GX_8@K."ZH+<@K6"O8%"`$AO<F1E7T-R>7!T7W-M
M:6UE@TZ#B8-8@LF"S6]P96YS<VR#@H-7@X6!6X.+@JJ52Y=V@L6"MX%"`(-V
M@XR#=(-`@XR#DX-8(B5S(H+-@V:!6X->@JJ#5(-#@UF0IXS`@O")>H*F@KV"
MO8+?E=N1MH+%@JN"W(*Y@O&"Q8*U@KTN`(*Q@LR#9H%;@UZ,7B@E<RF"\)5<
MCJ:"MX+I@KV"WX+,@W:#C8-/@XF#@(*J@K&"S(-6@UB#98.`@LF"W8+"@JF"
MZ(+<@KF"\8%"`(-4@5N#;R`B)7,B((+-C>V/G(*S@NJ"W(*U@KV!0@"#5(%;
M@V\@(B5S(B""S97;D;:"LX+J@MR"M8*]@4(`CY"6O(+PDG6*MX+%@JN"W(*Y
M@O&"Q8*U@KV!0@"/D):\@LV2=8JW@K."ZH+<@K6"O8%"`(->@UB#3H+-@J""
MR(*]@LR#7H-8@TZ57(+)DL>)P8*S@NJ"W(*U@KV!0@"#08-B@W:#C8%;@VB#
M9H%;@UZ"JI*\D4^"S(-8@V6#8H-V@L6/P8ZX@K6"W(*U@KV!0@"#08-B@W:#
MC8%;@VB#9H%;@UZ"\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(`EUR2Z(_NE?&"
MS97;D;:"LX+J@MR"M8*]@4(`@K&"S(.!@5N#BX-[@V*#3H-8@LF"S8.!@5N#
MBX+-@J""Z(+<@KF"\8%"`(-#@Y.#B8-#@Y.57(ZF@L6"JX+IE925JH+-@J""
MZ(+<@KF"\8%"`)6VCIJ0E(*J@K&"S(-T@T*!6X.+@VB"R9&]B=^"K(+<@K<N
M("5S((+,E;:.FH*JD_R7S8*S@NJ"Q(*B@MR"MRX@)7,@B,B)NH+%@LB"K8+$
M@LV"HH*O@MR"N8+Q@4(`)7,@@LR-[8^<DH:"R9;BD>B"JI2MD+:"M8+<@K6"
MO8%"@U2!6X-O@JF"YX+,B9Z3FH%&`(.!@5N#BX-[@V*#3H-8@LR-[8^<DH:"
MR9;BD>B"JI2MD+:"M8+<@K6"O8%"@U2!6X-O@JF"YX+,B9Z3FH%&("5S`(.!
M@5N#BX-[@V*#3H-8@LR-[8^<DH:"R9;BD>B"JI2MD+:"M8+<@K6"O8%"@U2!
M6X-O@JF"YX+,B9Z3FH%&`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4
MK9"V@K6"W(*U@KTZ("5S((+-@T&#8H-V@XV!6X-H@K."ZH+$@J*"W(*Y@O&!
M0@"#=(-`@T.#BX-!@V*#=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E
M<R""S8-T@T"#0X.+@LR#5(-#@UF0IXS`DFPH)62#;X-#@V<I@O")>H*F@L2"
MHH+<@K>!0@"#=(-`@T.#BX-!@V*#=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"
MM8*].B`E<R""S8CJE92"S(+=@T&#8H-V@XV!6X-H@K."ZH+<@K6"O8%"`"(E
M<R(@@O`@(B5S(B""R8-2@W.!6Y*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"
M@U2!6X-O@JF"YX+,B9Z3FH%&(``B)7,B((-T@TB#BX-?@JF"YX.!@V*#6H%;
M@U>"\(WMCYR2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0H-4@5N#;X*I@N>"
MS(F>DYJ!1@`B)7,B((-T@TB#BX-?D^""S(.!@V*#6H%;@U>"\(WMCYR2AH+)
M@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0H-4@5N#;X*I@N>"S(F>DYJ!1@"#@8-B
M@UJ!6X-7C>V/G(-'@XF!6X*JE*V0MH*U@MR"M8*]@4*#5(%;@V^"J8+G@LR)
MGI.:@48@)7,`@T.#>(.3@V>-[8^<DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]
M@48E<P"#@8-B@UJ!6X-7@W"!6X-G@LR57(ZF@L6#1X.)@5N"JI2MD+:"M8+<
M@K6"O8%"`(-T@TB#BX-?("5S((+%@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0H-4
M@5N#;X*I@N>"S(F>DYJ!1B``)7,@@O"#0X.3@WR!6X-GDH:"R8-'@XF!6X*J
ME*V0MH*U@MR"M8*]@4(`F$&7C9#F@V:!6X->@LR#0X.3@WR!6X-GDH:"R8-'
M@XF!6X*JE*V0MH*U@MR"M8*]@4(`@T.#>(.3@V>"\(-#@Y.#?(%;@V>2AH+)
M@T>#B8%;@JJ4K9"V@K6"W(*U@KV!1B5S`&E#86QE;F1A<B""S(-#@Y.#?(%;
M@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KTN`(->@UB#3H+P@T.#DX-\@5N#
M9Y*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%&)7,`EUR2Z(_NE?&"\(-#@Y.#
M?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!1B5S`"(E<R(@@O`@(B5S
M(B""R8C:DZZ2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0H-4@5N#;X*I@N>"
MS(F>DYJ!1B``CG>2Z(*S@NJ"O8-!@VB#C(-8DJ""S)&`C>R2AH+)@T>#B8%;
M@JJ4K9"V@K6"W(*U@KV!0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K."HH%"`(FZ
MCY&"JX+,E=N1MI*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"`(.!@5N#BX+,
MD9>039*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O3H@)7,`F$&7C9#F@LR/VHW7
M@O"-6)!6DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4*,XX+%C<23>([`C7."
MM8+$@JV"OH*S@J*!0@"1EY!-D.:#BH-8@V>"S(U8D%:2AH+)@T>#B8%;@JJ4
MK9"V@K6"W(*U@KV!0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K."HH%"`(-#@WB#
MDX-G@LR-6)!6DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@48E<P"6>Y6V@JJ+
M\X+%@K<`@K&"S"!)34%0((-4@5N#;X+-BZ273(-T@TB#BX-?@O"#5(-\@5N#
M9X*U@L2"HH+<@KF"\8%"`(*Q@LR/B))U@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"
MN8+Q@4(`@K&"S(^(DG6"S8+<@KZ.P)&5@K."ZH+$@J*"W(*Y@O&!0@""L8+J
M@LV73(SX@LAR87*#08%;@TJ#0X-U@L6"S8+(@J*"YH*D@L6"MX%"`(*Q@NJ"
MS9=,C/B"R'II<(-T@T"#0X.+@L6"S8+(@J*"YH*D@L6"MX%"`(*Q@NJ"S9=,
MC/B"R(-*@5N#:)34C8:"Q8+-@LB"HH+F@J2"Q8*W@4(`@K&"S(-T@T*!6X.+
M@VB"S95+D'N"Q8*W@4(`@K&"S(-T@T*!6X.+@VB"S9"ND)2"Q8+(@JV"Q(+-
M@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L:#4H.-@Y."Q8+(
M@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LTXD&F0E(+%@LB"
MK8+$@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S8-2@Y.#?8+<@KV"
MS8OSE)*"Q8OFD-B"YX+J@KV0KI"4@LR#BH-8@V>"Q8+(@JV"Q(+-@J*"KX+<
M@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LTQ-I!I4D="E5R+3(+,D$:#4H%;@VB"
MR(*M@L2"S8*B@J^"W(*Y@O&!0I?A.B<C,3(S-&%F)RX`@K&"S(-T@TB!6X.`
M@LV*^8+)CXB7G8*S@NJ"Q(*B@MR"MX%"`(*Q@LR1@(WL@LF"S8Z>BM2"JH*I
M@JF"Z(+<@K>!0I&`C>R"\)&Q@J^"W(*W@JF!2`""L8+,@X&#8H-:@5N#5X+-
M(%!'4"""Q8^0EKR"LX+J@L2"HH+<@K>!0@""L8+,@X&#8H-:@5N#5X+-(%,O
M34E-12""Q8^0EKR"LX+J@L2"HH+<@K>!0@""L8+,@X&#8H-:@5N#5X+-(%,O
M34E-12""Q8C#C8:)NX*S@NJ"Q(*B@MR"MX%"`(*Q@LR#@8-B@UJ!6X-7@LT@
M4$=0((+%B,.-AHF[@K."ZH+$@J*"W(*W`(*Q@LR#@8%;@XL`@K&"S(.!@V*#
M6H%;@U>"S8*@@LB"O8*JCF>7<(*W@NF"S(+&B-F"R(+IE;:.FH-:@V*#9X%I
M)7.!:H+%CY&"J8+J@L2"HH+<@K>!0@""L8+,E-2-AH+-C<6/K(+%@N`Q@L6"
MR(*M@L2"S8*B@J^"W(*Y@O&!0@""L8+,@U2!6X-O@L6"S7II<(+&9WII<(-T
M@T"#0X.+@O"35XI*@L6"JX+<@KF"\8%"`(*Q@LR#5H-8@V6#@(+-B.J.GI-)
M@LF6LXSX@LF"R(+!@L2"HH+<@K>!0@""L8+,DFR"S9"4CIJ"Q8+(@J^"ZH+.
M@LB"Z(+<@KF"\8%"`(*Q@LR#18-"@Y.#:(-%@LV#28-V@U:#AX.3@T6#0H.3
M@VB#18*I@N>,Q(]O@K."ZH+IE4N7=H*J@J""Z(+<@K>!0@"#6(.,@V*#:)5<
MCJ8`@UZ#0X.`@U:!6X-G`(->@T.#9X.+`%1O`(BVD.8`E:&0E(+,C8"6VH+P
MD4F1\(*W@NF"R8+-@4%00X+%@LU#;VYT<F]L@TR#0X%!36%C@LB"YT-O;6UA
M;F2#3(-#@O")GX*U@LB"JH+G@TZ#BH-B@TZ"M8+<@K>!0@"5H9"4@LR-@);:
M@O"129'P@K>"Z8+)@LV!05!#@L6"S4-O;G1R;VR#3(-#@4%-86."R(+G0V]M
M;6%N9(-,@T."\(F?@K6"R(*J@N>#3H.*@V*#3H*U@MR"MX%"`(V'C':"S)-9
ME72#5(-#@UDZ`(-3@WZ4H(-T@TB#BX-?`(-3@WZ4H(-T@TB#BX-?@48`B<X`
M55),`%9&4R"#=(-`@T.#BR`B)7,B((+,@T&#3H-:@UB,H(+-E<^-6(+%@JN"
MW(*Y@O&!0@!61E,@@W2#0(-#@XL@)7,O)7,@@LR#08-.@UJ#6(R@@LV5SXU8
M@L6"JX+<@KF"\8%"`"5S((+)E<^-6(+%@JN"W(*Y@O&!0@!344P@@U2!6X-O
M@LF0VI&Q@L6"JX+<@KF"\8%"`%-33"""Q9#:D;&"Q8*K@MR"N8+Q@4(`5D93
M((-T@T"#0X.+@O"#4H-S@5N"Q8*K@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#
MBB`B)7,B((+PC>R0K(+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*@O"-
M[)"L@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+PC>R0K(+%@JN"W(*Y@O&!
M0@"+\X+,(%9&4R"#=(-`@T.#BX+PC>R0K(+%@JN"W(*Y@O&!0@"#9H%;@UZ"
M\(BSCVN"Q8*K@MR"N8+Q@4(`(B5S(H+PC>V/G(+%@JN"W(*Y@O$N((-F@T*#
MC(-.@V>#BH*JB_."Q8+-@J""Z(+<@KF"\8%"`"5S@O"-[8^<@L6"JX+<@KF"
M\2X@@V:#0H.,@TZ#9X.*@JJ+\X+%@LV"H(+H@MR"N8+Q@4(`C]B6OH^1@LR/
MVHW7@JJ.YH+HCV^"N8+<@KF"\0"(LX]KCY&,R8-T@T"#0X.+@O"*2H*O@MR"
MN8+Q@4(`=F9S<F]O=""#9H-"@XR#3H-G@XJ"\)/'@M^"W(*Y@O&!0@"#3H-(
M@5N#7H*JCN:3OH+%@JN"W(*Y@O$`@K&"S"!7;W)D()6VCY&"\)9\EO."Q8*K
M@MR"N8+Q@4(`EJ*5U)!-`):BE=2038.!@5N#BP"-[8^<CN:"Z(_!@K4`B;J0
M_`"4\8SVBDJ"S(BVD.8`E<^-6(+PCN:"Z(_!@K<`C+."R9;?@K<`EJ*0KI>=
M`(BU@J:"R(*B@V:!6X->@L6"MX%&)7,`E7.6O@"5<Y:^@LB)[XMC`):\D4^"
MR(*U`):BD\<`@W2#2(.+@U^"S(UWD\>2AHY^`(-4@WR!6X-G@K6"Q(*B@LB"
MHHIGDJ..<8+%@K<`C5B05@`E<R""\(U8D%:"MX+I@4(`B?&3FH[2@LR/\XNU
M@O"-6)!6`(.&@5N#58+PC5B05H*W@ND`@XF#98.3E;:.FH%ID>65MHZ:@6H`
M@XV!6X-]D)2.FH%ID>65MHZ:@6H`C+N-W8+,DFR"\(YGEW"!1B5S`(-F@W2#
M2(.+@V>"\(YGEW``24U!4""#=(-(@XN#7X+PC7>3QX%>E/&-=Y/'@L6129'P
M@K6"W(*W@JF!2`!)35-0((-4@5N#;X+,@X:!6X-5EKR!7H-P@UB#CX%;@VB"
MJHC9@LB"Z8_JC8>"R8YGEW""M8+<@K>!0@"#AH%;@U4`@X:!6X-5BL>7G0"#
MAH%;@U6#28-V@U:#AX.3`(.&@5N#59-OF%X`@X:!6X-5EKP`@X:!6X-5EKR!
M1@"#AH%;@U66O#H@`(-6@UB#98.`DH:"S(.&@5N#58%&`(MXB<D`ETR,^)"K
M`(R?C]B.N)1S("T@@K&"S(.!@V*#6H%;@U>"S8G\XH*"LX+J@L2"HH+I@N:"
MI(+%@K>!0@"4Q0"57(ZF`"5S((+PE5R.I@`E<R""S(SVBDJ,KH+PE5R.I@!(
M5$U,@LR3X)=E@O"5RH+,@T6#0X.3@VB!6X+)E5R.I@",PI!L@LR4Z9:GC*Z"
M\)5<CJ8`C,*0;(+,C/:*2HRN@O"57(ZF`(-8@XR#8H-HE5R.I@"#5(.`@VR#
M0X.+E5R.I@"#0X-X@Y.#9X+PE5R.I@`E<R"2AH+,@X&#8H-:@5N#5X+PE5R.
MI@"#C8-/@T.#DXSC@LR57(ZF@48`@UZ#6(-.E5R.I@")YI&<@O"57(ZF`(F\
MD7J#=(-(@XN#7R`B)7,B((*JC>R0K(*S@NJ"W(*U@KV!0@")O)%Z@W2#2(.+
M@U\`B;R1>H-T@TB#BX-?@LR#B8-X@XL`D(4`EHB/5`""YH*D@K&"NP`E<R""
MUH+F@J2"L8*[`"5S((*S@O&!08+F@J2"L8*[`"5S@XV#3X-#@Y.,XX+'@LR#
M08-V@XJ#4(%;@U:#AX.3@O"57(ZF@K6"W(*W@JF!2`"+YI#8@NB5MHZ:@LV)
MO8+%@K>"J8%(`(CXEW"5MHZ:@LV)O8+%@K>"J8%(`(.!@V*#6H%;@U>"S(WM
MCYR"S8%!C>V/G(+&@J*"I(CS@O"5=(*O@NF"S(+%@LV"R(*M@4&#4X-^E*"#
M=(-(@XN#7X+)B-J3KH*U@MR"MX*I@4@`@X&!6X.+@WN#8H-.@UB"\(I*@J*"
MO8Z>@4&"QX+,@WF!6X-7@JF"YY5<CJ:"M8+<@K>"J8%(`)&7D$V-5(*F@O"5
MVY&V@K>"Z8W;@4&3695T@N"5VY&V@K6"W(*W@JF!2`"#98-,@UB#9X-'@V:#
M0H->@5N"S(-V@XF#3X-#@Y."\)%)D?""M8+<@K>!0@"#>H./@T.#9X.*@UB#
M9P"5G0"-MH+)DG6"K25S@X&#:H.%@5N"S)6=@6F.GXGQ@LR#C8-/@T.#DX*I
M@N>73(SX@6HZ`)5<@LR5G0"+SI:QD.:"S(]:CXH`B\Z6L9#F@LR39)ABE-2-
MA@!8-3`Y=C,@BNZ6>Y"GC,``6#4P.78S((RNCF>7<)9``%@U,#EV,R".Y9',
MCM*"S)7*EKP`6#4P.78S(([ED<R.TH+,C*Z.KY7*CG$`6#4P.78S((IGDJ.+
M0)1<`)1.`)1.`):(E$X`@LV"H@"3KXC3@K6"W(*W`)!6@K6"HH-T@TB#BX-?
M@LF#4H-S@5N!7HC:DZZ"M8+F@J2"QH*U@L2"HH+<@K>!0@".GX+,@W2#2(.+
M@U^"S(-4@W6#=(-(@XN#7X+PC>R0K(*U@L2"HH+<@K>!1@"-Q8_CB,J"S(-T
M@TB#BX-?@O"-[)"L@K6"YH*D@L:"M8+$@J*"W(*W@4(`C:&"S8-E@TR#6(-G
M@X*!6X-H@L6"MX%"6SP^78-[@UZ#DX+%1U5)@X*!6X-H@LF5SXU8@L6"JX+<
M@K>!0@""H(+(@KV"S91&C]B"LX+J@L2"HH+<@KF"\8%"`(-T@TB#BX-?@LR6
MO)%/@O"5SXU8@K6"Q(*B@MR"MX%&`):\D4^"S)*&@LD@)UPG((+&@J*"I)6V
MCIJ"S8YG@J:"W(*Y@O&!0@"73(SX@LB39(YQ@X&!6X.+@T&#:(.,@UB"Q8+-
M@J""Z(+<@KF"\8%"`(-#@Y.#?(%;@V>"LX+J@KV#=(-`@T.#BX+,@W2#0H%;
M@XN#:(+P)7.3X(+,D<Z)GH*W@NF#=(-"@5N#BX-H@LF#?8-B@W:"M8+$@MR"
MN8+Q+@""H(+(@KV"R8+-@K&"S(-T@TB#BX-?@O"5SXU8@K>"Z8-!@TZ#6H-8
MC*""JH*@@NB"W(*Y@O$`D%:2A8.!@5N#BX*J("5S()+*@J""Z(+<@K>!0@"0
M5I*%@X&!6X.+@JH@,2"2RH*@@NB"W(*W@4(`@XV#3X-!@T6#9X*U@MR"M8*]
M+@".GX+,@W2#2(.+@U^"R9!6DH6#@8%;@XN"JH*@@NB"W(*W.@""L8+J@N>"
MS(-T@TB#BX-?@LF05I*%@X&!6X.+@JJ"H(+H@MR"MX%&`)"S@K6"HI)L@O"3
M_)?-@K6"Q(FZ@K."HH%"`(-4@T.#DX-!@V*#=H+PEYB7<(*W@NF"O8+?@LF"
MS2!$871A5')E92"#;X-B@TZ#1X.3@VB"\)#=DNB"MX+IE4N7=H*J@J""Z(+<
M@K<N`(_ABE&"S)/@EV6"\(M,CW&"M8+$@JF"YX%!C^&*48.,@WR!6X-G@O"1
MEY!-@K6"Q(*M@KZ"LX*B@4(`,2"0;(C(C^."S(BVD.:"\(YWDNB"M8+$@JV"
MOH*S@J*!0@""L8*Q@LF#BH.3@TZ"MX+I55),@O"3_)?-@K6"Q(FZ@K."H@"6
MVI-)@LR#@8%;@XN#>X-B@TZ#6(+PC<6/B8+)D4F"\8+%@JV"OH*S@J*!0@"#
M08-H@XR#6(+PC<6/B8+)D4F"\8+%@JV"OH*S@J*!0@"-[8^<@K>"Z8-4@5N#
M;X+PCG>2Z(*U@L2"K8*^@K."HH%"`#$@@L*(R(_C@LR#@8%;@XN"\(W%CXF"
MR9%)@O&"Q8*M@KZ"LX*B@4(`B+:0YH+PCG>2Z(*U@L2"K8*^@K."HH%"`(_!
MBXZ"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0@"-[8^<@K>"Z8.&
M@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`DL>)P8*W@NF#AH%;@U66O(+P
MCG>2Z(*U@L2"K8*^@K."HH%"`(U8D%:"MX+I@X:!6X-5EKR"\(YWDNB"M8+$
M@JV"OH*S@J*!0@".P(US@K>"Z8-!@TZ#5H.'@Y."\(YWDNB"M8+$@JV"OH*S
M@J*!0@"05H*U@J*5JI?>EKR"\)/\E\V"M8+$B;J"LX*B@4(`(B5S(B""\(UW
MD\>"M8+$@J*"W(*Y@O&!0H-4@5N#;X*I@N>"S(F>DYJ!1B``(B5S(B""S(UW
MD\>"\)*&CGZ"M8+$@J*"W(*Y@O&!0H-4@5N#;X*I@N>"S(F>DYJ!1B``(B5S
M(B""S(UWD\>"\(I*CFZ"M8+<@K6"O8%"`"(E<R(@@LR-=Y/'@O"2AHY^@K6"
MW(*U@KV!0@`E<R"#6H-B@U:#AX.3@LR73(SXBOJ,P(*JD-B"ZH+$@J*"W(*W
M@4*-Q(.-@T^#0X.3@K6"Q(*M@KZ"LX*B@4(`DV2.<8.!@5N#BX-!@VB#C(-8
M`(*@@LB"O8+,($9R;VTZ((-!@VB#C(-8`(*@@LB"O8+,@T.#DX-T@TB#@8%;
M@U:#AX.3`(-:@V*#5H.'@Y,@)7,@@LR*U(+)@J""R(*]@LR#08-H@XR#6(*J
ME<^-6(*S@NJ"W(*U@KV!0H-:@TR#A8.*@V6#0H%;E=N,[(+,@KV"WX+)@XV#
M3X-#@Y."M9*\@K>"UX*K@L6"MX%"`(*@@LB"O8+,(%!'4"",]HI*C*Z"QI3I
MEJ>,K@""H(+(@KV"S)3IEJ>,K@""H(+(@KV"S(SVBDJ,K@""H(+(@KV"S(-!
M@TJ#18.3@V<`@K&"S)1&C]B#;X-B@TZ#1X.3@VB"Q8+-@4&#AH%;@U6"S(.*
M@UB#9X*J@U2#?(%;@V>"LX+J@L2"HH+(@J*"J8%!@J""Z8*B@LV)O8+G@JF"
MS)>=EU*"Q8*Q@LR+0)1<@JJ6LXSX@LF"R(+!@L2"HH+<@K>!0@"#6H-B@U:#
MAX.3("5S((+,BM2"R8*@@LB"O8+,@W6#B8-%@U6"JI7/C5B"LX+J@MR"M8*]
M@4*#6H-,@X6#BH-E@T*!6Y7;C.R"S(*]@M^"R8.-@T^#0X.3@K62O(*W@M>"
MJX+%@K>!0@""J(YG@J*"S(-U@XF#18-5@L6"S8*Q@LR.[9?>@LR)YI&<@LR#
M0X.3@XF#0X.3E5R.IH+P@U2#?(%;@V>"M8+$@J*"W(*Y@O$`@UZ#0X.`@UV!
M6X.3@48`D9>038Z>@LR#9H-T@TB#BX-GE;:.FH-:@V*#9SH`D9>038Z>@LR#
M9H-T@TB#BX-G@LR(PXV&E?N60#H`@J""R(*]@LR#9H-T@TB#BX-G240Z`(*@
M@LB"O8+,CH&6O`"#28-V@U:#AX.3@O"-6)!6@K6"W(*U@KT`@XJ#@H%;@V>#
M5(%;@V\Z`(^0EKPZ`%N,CY:\@LB"M5T`@6V/X8I1@XR#?(%;@V>!;@!;C7,Z
M)7,O)7-=`%]!BL>7G0!?0F-C`%]"@W6#B8-B@TZ#BH-8@V<`7T-C`%]$C>V/
MG`!?1(US@O"-[8^<`%]&@W2#2(.+@U\`7T>#3X.+@5N#=@!?2(-W@XN#=@!?
M240`7TF)YI&<@W:#C8-P@V6#0BXN+@!?24Y"3U@`7TR#C8-/@T.#DP!?3(.-
M@T^#08-%@V<`7TV,M)6V`%]-@XJ#DX-.E<^-6`!?3X-)@W:#5H.'@Y,`7U"#
M08-.@UJ#6(R@`%]0B/.-_`!?4)=$D.:3>`!?4HW$E5R.IB5S`%]2@XJ#DX-.
MC>V/G`!?4I74D$T`7U.,GXWU`%]3D9>030!?4X-:@V*#9X-!@V*#=@!?5)5<
MD:Z0JP!?5(-8@XR#8H-H`%]4;P!?58WMCYR.YH_!`%]5@X:!6X-5`%]6@UB#
MC(-B@VB57(ZF`%]7@WJ#CX-#@V>#BH-8@V<`@T&#:(.,@UB2H`"3695T`)=<
MDNB57`""L8*Q@O"#3H.*@V*#3@"#=(-`@T.#BP"6O)%/`(+(@K4`@MR"OH[`
MD96"LX+J@L2"HH+<@KF"\0""W(*]@LT`@W"!6X-:@Y.#9P"#<X-.@UJ#BP"#
M6(-Y@XN#1X.)@5L`@UB#>8.+@T>#B8%;`(IME$:"S(*]@M^#<(-8@X^!6X-H
M,I-XD_R7S8*U@L2)NH*S@J(`EKR6LX*U`'9#87)D`(-U@XF#8H-.@XJ#6(-G
M`(-Z@X^#0X-G@XJ#6(-G````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A
M;&4O:7-?25,O````````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#$W-#4W`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+VQO8V%L92]I<U])4R],0U]-15-304=%4R\`````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,C$R
M-#0`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VES7TE3+TQ#
M7TU%4U-!1T53+VEM<"YM;P``````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,34R-S8W
M`#$P-#$W,S8R-S8S`#`R,C0P-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#>$@25``````D#```<````9!@```\$``"L,```
M`````.A````*````Z4````H```#T0```"@```/]````*````"D$```0````5
M00``'@```!I!``!(````.4$``"L```""00``1````*Y!```G````\T$``!<`
M```;0@``,@```#-"```R````9D(``!0```"90@``$````*Y"```G````OT(`
M`"<```#G0@``(`````]#```;````,$,``"X```!,0P``-P```'M#``!\````
MLT,``!P````P1```'0```$U$```;````:T0``$4```"'1```*````,U$``!!
M````]D0``"0````X10``,P```%U%```#````D44```X```"510``"````*1%
M```*````K44```\```"X10``!P```,A%```*````T$4``!@```#;10``'```
M`/1%```,````$48```T````>1@```P```"Q&``!.````,$8``%````!_1@``
M0P```-!&``!"````%$<``!<```!71P``'P```&]'```U````CT<```@```#%
M1P``$0```,Y'```-````X$<``!,```#N1P``(P````)(```O````)D@```4`
M``!62```,````%Q(``!(````C4@``"$```#62```.P```/A(```\````-$D`
M`"L```!Q20``,0```)U)```[````STD``#D````+2@``-0```$5*```,````
M>TH```D```"(2@``!@```))*```,````F4H```X```"F2@``20```+5*```*
M````_TH```L````*2P``"0```!9+```)````($L```8````J2P``&````#%+
M```+````2DL```H```!62P``.````&%+```)````FDL```0```"D2P``!```
M`*E+```6````KDL```@```#%2P``"````,Y+```J````UTL``"L````"3```
M!@```"Y,```.````-4P``#X```!$3```!@```(-,```*````BDP```T```"5
M3```8@```*-,```G````!DT``%\````N30``'````(Y-```H````JTT```X`
M``#430``%0```.--```P````^4T``!$````J3@``-0```#Q.``!%````<DX`
M`!D```"X3@``,P```-).```K````!D\``#4````R3P``0@```&A/``!1````
MJT\```4```#]3P``$0````-0```-````%5````@````C4```#````"Q0```4
M````.5````\```!.4```!P```%Y0```)````9E````<```!P4```%````'A0
M```7````C5```"8```"E4```7````,Q0```$````*5$```X````N40``!P``
M`#U1```.````15$``#8```!440``*0```(M1```&````M5$```T```"\40``
M"P```,I1```5````UE$``!@```#L40``&@````52```=````(%(``!D````^
M4@``70```%A2```<````ME(``"@```#34@``!0```/Q2```$`````E,```@`
M```'4P``"````!!3```*````&5,```<````D4P``$````"Q3```9````/5,`
M`!H```!74P``"0```')3```&````?%,``!0```"#4P``$P```)A3```0````
MK%,``!<```"]4P``%0```-53```K````ZU,``#,````75```!P```$M4```0
M````4U0``!P```!D5```'````(%4```*````GE0```L```"I5```!P```+54
M```/````O50```<```#-5```#P```-54```M````Y50``"@````350``#```
M`#Q5```C````254``"````!M50``!````(Y5```(````DU4```L```"<50``
M&@```*A5```G````PU4``!(```#K50``(````/Y5```7````'U8```4````W
M5@``#````#U6```.````2E8```X```!95@``*P```&A6```$````E%8```X`
M``"95@``#````*A6```3````M58```X```#)5@``$P```-A6```6````[%8`
M`!,````#5P``#0```!=7```=````)5<```\```!#5P``%@```%-7```2````
M:E<```P```!]5P``&````(I7```3````HU<``!4```"W5P``"P```,U7```3
M````V5<``!````#M5P``)P```/Y7```I````)E@``"P```!06```*````'U8
M```.````IE@``#4```"U6```!0```.M8```;````\5@``!`````-60``$```
M`!Y9```/````+UD```\````_60``#````$]9```&````7%D```H```!C60``
M$@```&Y9```-````@5D```P```"/60``/0```)Q9```)````VED```L```#D
M60``"````/!9```*````^5D``"`````$6@``'P```"5:```;````15H``!D`
M``!A6@``&P```'M:```(````EUH```0```"@6@``#@```*5:```/````M%H`
M`"4```#$6@``!P```.I:```2````\EH```0````%6P``$@````I;```*````
M'5L```@````H6P``$````#%;```-````0EL```X```!06P``!P```%];```(
M````9UL``!$```!P6P``&0```();```%````G%L```0```"B6P``#````*=;
M```$````M%L```4```"Y6P``&@```+];```/````VEL``"(```#J6P``#0``
M``U<```@````&UP```0````\7```%P```$%<```'````65P```0```!A7```
M!@```&9<```5````;5P```P```"#7```$0```)!<```/````HEP```0```"R
M7```#0```+=<```'````Q5P``"<```#-7```*````/5<```%````'ET``!``
M```D70``/````#5=```&````<ET```H```!Y70``!@```(1=```/````BUT`
M`!````";70``(P```*Q=```)````T%T``!(```#:70``'0```.U=```%````
M"UX``"0````17@``!````#9>```&````.UX```\```!"7@``"P```%)>```&
M````7EX```<```!E7@``!````&U>```$````<EX```(```!W7@``"````'I>
M```1````@UX```D```"57@``#0```)]>```.````K5X``!8```"\7@``$0``
M`-->```&````Y5X```8```#L7@``!P```/->```$````^UX``!$`````7P``
M!P```!)?```A````&E\``!<````\7P``"0```%1?```.````7E\```@```!M
M7P``!@```'9?```,````?5\```<```"*7P``!0```))?```+````F%\```,`
M``"D7P``#````*A?```&````M5\```X```"\7P``!````,M?```-````T%\`
M``<```#>7P``(@```.9?```&````"6````@````08```"````!E@```$````
M(F````4````G8```!@```"U@```C````-&```"4```!88```"````'Y@```W
M````AV```!````"_8```$0```-!@```/````XF````H```#R8```%P```/U@
M```F````%6$``"8````\80```P```&-A```D````9V$```<```",80``$P``
M`)1A```,````J&$```\```"U80``#@```,5A```,````U&$```X```#A80``
M#P```/!A```.`````&(```T````/8@``#P```!UB```/````+6(``!<````]
M8@``%````%5B```1````:F(```\```!\8@``+@```(QB```:````NV(``"8`
M``#68@``"P```/UB```&````"6,``!\````08P``!@```#!C```-````-V,`
M``(```!%8P``!@```$AC```*````3V,```8```!:8P``!@```&%C```K````
M:&,```0```"48P``"0```)EC```'````HV,```D```"K8P``#@```+5C```'
M````Q&,```0```#,8P``(@```-%C```%````]&,``!8```#Z8P```P```!%D
M```*````%60```@````@9```#````"ED```$````-F0```P````[9```"0``
M`$AD```"````4F0```T```!59```"P```&-D```/````;V0``!0```!_9```
M%0```)1D```3````JF0``!D```"^9```'````-AD```?````]60``!0````5
M90``(````"IE```2````2V4```X```!>90``$@```&UE```$````@&4```8`
M``"%90``"P```(QE```)````F&4```T```"B90``#````+!E```4````O64`
M`!8```#290``"````.EE``!$````\F4``#P````W9@```@```'1F```"````
M=V8```<```!Z9@``#````()F```C````CV8``#(```"S9@``,P```.9F```,
M````&F<```L````G9P``#0```#-G```'````06<```T```!)9P```P```%=G
M```3````6V<```L```!O9P``-````'MG```.````L&<```L```"_9P``%```
M`,MG```Q````X&<``!`````2:```&````"-H```-````/&@```<```!*:```
M"````%)H```H````6V@```@```"$:```%````(UH```Q````HF@``"<```#4
M:```*````/QH```:````)6D``!T```!`:0``*0```%YI```=````B&D``"X`
M``"F:0``-@```-5I```L````#&H``"P````Y:@``,0```&9J```N````F&H`
M`"L```#':@``!P```/-J```0````^VH```T````,:P``!0```!IK```(````
M(&L```X````I:P``#0```#AK```/````1FL``!8```!6:P``/@```&UK```G
M````K&L``"8```#4:P``)````/MK```6````(&P```L````W;```'@```$-L
M```+````8FP```X```!N;```#@```'UL```)````C&P```@```"6;```$```
M`)]L```5````L&P``!,```#&;```!P```-IL```5````XFP```8```#X;```
M"P```/]L```6````"VT```\````B;0``&````#)M```-````2VT``!````!9
M;0``+@```&IM```Z````F6T```X```#4;0``#0```.-M```%````\6T```L`
M``#W;0``#`````-N```-````$&X```T````>;@``#@```"QN```-````.VX`
M``@```!);@``"@```%)N```&````76X``!(```!D;@``#@```'=N```7````
MAFX``!8```">;@``!0```+5N```&````NVX``!$```#";@``2P```-1N```6
M````(&\```X````W;P``$0```$9O```.````6&\``!<```!G;P``$P```']O
M```;````DV\``"H```"O;P``"````-IO```0````XV\```@```#T;P``!```
M`/UO```*`````G````P````-<```"P```!IP```'````)G```"`````N<```
M#P```$]P```Y````7W````8```"9<```"0```*!P```.````JG````0```"Y
M<```!@```+YP```6````Q7````T```#<<```#@```.IP``!#````^7````H`
M```]<0``-0```$AQ```1````?G$```L```"0<0``'P```)QQ```7````O'$`
M``P```#4<0``$````.%Q```1````\G$```D````$<@``!@````YR```'````
M%7(``$,````=<@``.0```&%R```0````FW(``!````"L<@``#````+UR```4
M````RG(``!T```#?<@``$0```/UR```@````#W,```\````P<P``!0```$!S
M```&````1G,```0```!-<P``#@```%)S```/````87,```P```!Q<P``%```
M`'YS```4````DW,```\```"H<P``#@```+AS```2````QW,```P```#:<P``
M$@```.=S```+````^G,```T````&=```%````!1T```O````*70``!````!9
M=```"````&IT```'````<W0```T```![=```!@```(ET```6````D'0```<`
M``"G=```"P```*]T```'````NW0``!H```##=```(````-YT```%````_W0`
M``0````%=0``(@````IU```@````+74``"8```!.=0``'0```'5U```S````
MDW4``"P```#'=0``(0```/1U```>````%G8``'4````U=@``/@```*MV``!"
M````ZG8``#T````M=P``/0```&MW```I````J7<``"D```#3=P``,0```/UW
M```C````+W@``"````!3>```-````'1X```=````J7@``!X```#'>```*@``
M`.9X```D````$7D``"@````V>0``*0```%]Y```7````B7D``"8```"A>0``
M/@```,AY```^````!WH``$<```!&>@``4P```(YZ``!7````XGH``%4````Z
M>P``1@```)![```O````UWL``%4````'?```(````%U\``!2````?GP``#(`
M``#1?```*P````1]```F````,'T``"P```!7?0``.P```(1]```O````P'T`
M`#(```#P?0``*P```"-^```I````3WX```\```!Y?@``(0```(E^```<````
MJWX``#$```#(?@``"P```/I^```"````!G\```H````)?P``%P```!1_```,
M````+'\```T````Y?P``"@```$=_```3````4G\```@```!F?P``%@```&]_
M```,````AG\``!$```"3?P``!P```*5_```&````K7\``!H```"T?P``'0``
M`,]_```&````[7\``!$```#T?P``'@````:````$````)8````P````J@```
M"````#>````)````0(````0```!*@```!P```$^````2````5X```"8```!J
M@```"P```)&````.````G8```"0```"L@```(0```-&````*````\X```!,`
M``#^@```)P```!*!```)````.H$```\```!$@0``*````%2!```/````?8$`
M`"````"-@0``%````*Z!```'````PX$```T```#+@0``(@```-F!```#````
M_($``#L`````@@``3P```#R"```U````C((``"<```#"@@``(0```.J"```D
M````#(,``!T````Q@P``(@```$^#```9````<H,``!<```",@P``*@```*2#
M```K````SX,``"8```#[@P``)P```"*$```I````2H0``"$```!TA```*P``
M`):$```=````PH0``"T```#@A```*0````Z%```B````.(4``#T```!;A0``
M00```)F%```H````VX4``"P````$A@``,````#&&```3````8H8``!````!V
MA@``"0```(>&```<````D88``!````"NA@``#P```+^&```I````SX8```X`
M``#YA@``0`````B'``!3````28<``!<```"=AP``*@```+6'```T````X(<`
M`!8````5B```#P```"R(```H````/(@``!\```!EB```#P```(6(```,````
ME8@```H```"BB```"````*V(```'````MH@```@```"^B```!0```,>(```)
M````S8@```8```#7B```"````-Z(```/````YX@```@```#WB```!@````")
M```)````!XD```L````1B0``!@```!V)```'````)(D```T````LB0``!P``
M`#J)```#````0HD```D```!&B0``#````%")```*````78D```H```!HB0``
M!0```'.)```$````>8D```8```!^B0``!````(6)```,````BHD```0```"7
MB0``!````)R)```"````H8D```X```"DB0``#P```+.)```.````PXD```X`
M``#2B0``60$``.&)```+````.XL```H```!'BP``"@```%*+```,````78L`
M``,```!JBP``'````&Z+``!0````BXL``$,```#<BP``2P```"",```^````
M;(P``!<```"KC```,@```,.,```Q````]HP``!8````HC0``$````#^-```>
M````4(T``#4```!OC0``$0```*6-```;````MXT``"X```#3C0``/@````*.
M``"?````08X``"L```#AC@``$0````V/```5````'X\``$P````UCP``.@``
M`(*/``!'````O8\``#H````%D```+0```$"0```"````;I```!````!QD```
M"````(*0```*````BY````P```"6D```"````*.0```1````K)```!<```"^
MD```&0```-:0```+````\)````T```#\D```"@````J1``!,````%9$``$,`
M``!BD0``50```*:1```^````_)$``!4````[D@``%@```%&2```^````:)(`
M``8```"GD@``&P```*Z2```+````RI(``!0```#6D@``'0```.N2```C````
M"9,```4````MDP``)P```#.3```G````6Y,``"<```"#DP``.@```*N3```]
M````YI,``"T````DE```+@```%*4```Z````@90``$0```"\E```/P````&5
M```(````094```@```!*E0``#P```%.5```3````8Y4```D```!WE0``-0``
M`(&5```(````MY4```@```#`E0``"@```,F5```(````U)4```4```#=E0``
M%P```..5```,````^Y4```P````(E@``-0```!66```*````2Y8```@```!6
ME@``!````%^6```6````9)8```D```![E@``!P```(66```:````C98``"8`
M``"HE@``"0```,^6```0````V98``#,```#JE@``!@```!Z7```,````)9<`
M``\````REP``;@```$*7```D````L9<``%8```#6EP``*0```"V8```C````
M5Y@```T```![F```#P```(F8```<````F9@```T```"VF```0@```,28``!+
M````!YD``!L```!3F0``-````&^9```I````I)D``#````#.F0``-````/^9
M``!*````-)H```0```!_F@``$@```(2:```+````EYH```0```"CF@``"@``
M`*B:```1````LYH```H```#%F@``"@```-":```%````VYH```4```#AF@``
M$0```.>:```1````^9H``!H````+FP``3@```":;```%````=9L```X```![
MFP``"0```(J;```0````E)L``"````"EFP``(P```,:;```'````ZIL```T`
M``#RFP``#0````"<```3````#IP``"$````BG```(````$2<```D````99P`
M`#$```"*G```:````+R<```@````)9T``#@```!&G0``!````'^=```$````
MA)T```@```")G0``!@```)*=```(````F9T```H```"BG0``%````*V=```9
M````PIT``!0```#<G0``"0```/&=```$````^YT``!D`````G@``$@```!J>
M```-````+9X``!(````[G@``$````$Z>```N````7YX``#L```".G@``!```
M`,J>```+````SYX``!8```#;G@``&P```/*>```(````#I\```8````7GP``
M!@```!Z?```B````)9\```4```!(GP``$````$Z?```F````7Y\``"D```"&
MGP``$P```+"?```D````Q)\``!<```#IGP``!0````&@```6````!Z```!D`
M```>H```%@```#B@```@````3Z```!\```!PH```&@```)"@```3````JZ``
M``<```"_H```%````,>@```4````W*````<```#QH```)@```/F@```&````
M(*$``!(````GH0``%P```#JA```2````4J$``!$```!EH0``&````'>A```6
M````D*$``!<```"GH0``!P```+^A```>````QZ$```T```#FH0``$@```/2A
M```4````!Z(```X````<H@``&````"NB```3````1*(``!8```!8H@``#```
M`&^B```;````?*(``!0```"8H@``+0```*VB```L````VZ(``#`````(HP``
M/0```#FC```4````=Z,``"D```",HP``!0```+:C```5````O*,``!````#2
MHP``$````..C```5````]*,``!$````*I```#P```!RD```*````+*0```H`
M```WI```$0```$*D```*````5*0```X```!?I```*@```&ZD```*````F:0`
M``H```"DI```!P```*^D```*````MZ0``!H```#"I```'@```-VD```6````
M_*0``!@````3I0``%P```"RE```$````1*4```0```!)I0``#````$ZE```-
M````6Z4``"<```!II0``!````)&E```0````EJ4```4```"GI0``"P```*VE
M```+````N:4```H```#%I0``"@```-"E```6````VZ4```P```#RI0``"@``
M`/^E```+````"J8``!`````6I@``%P```">F```#````/Z8```,```!#I@``
M#P```$>F```(````5Z8```@```!@I@``&@```&FF```1````A*8``!P```"6
MI@``"P```+.F```H````OZ8```,```#HI@``$P```.RF```&`````*<```4`
M```'IP``!0````VG```5````$Z<``!`````IIP``%@```#JG```.````4:<`
M``,```!@IP``#0```&2G```%````<J<``!L```!XIP``.0```)2G```&````
MSJ<```H```#5IP``+@```."G```&````#Z@```L````6J```"@```"*H```1
M````+:@``!0````_J```)P```%2H```(````?*@```\```"%J```&0```)6H
M```&````KZ@``"P```"VJ```!0```..H```*````Z:@```T```#TJ```#@``
M``*I```(````$:D```8````:J0``!````"&I```$````)JD```(````KJ0``
M"````"ZI```,````-ZD```P```!$J0``#P```%&I```1````8:D``!@```!S
MJ0``%0```(RI```(````HJD```L```"KJ0``!P```+>I```'````OZD``!L`
M``#'J0``!P```..I```K````ZZD``!<````7J@``!P```"^J```)````-ZH`
M``L```!!J@``"````$VJ```+````5JH```8```!BJ@``"````&FJ```5````
M<JH```4```"(J@``#P```(ZJ```&````GJH```X```"EJ@``!@```+2J```/
M````NZH```D```#+J@``$````-6J```&````YJH```@```#MJ@``#@```/:J
M```$````!:L```0````*JP``!P````^K```C````%ZL``"0````[JP``"P``
M`&"K```[````;*L```T```"HJP``$@```+:K```6````R:L```D```#@JP``
M%@```.JK```<`````:P``!0````>K````P```#.L```F````-ZP```8```!>
MK```$0```&6L```%````=ZP``!````!]K```#P```(ZL```-````GJP```<`
M``"LK```#````+2L```%````P:P```4```#'K```!@```,VL```-````U*P`
M`!D```#BK```$P```/RL```5````$*T```X````FK0``-````#6M```1````
M:JT``"P```!\K0``"@```*FM```&````M*T```H```"[K0``!@```,:M```(
M````S:T```(```#6K0``!@```-FM```+````X*T```8```#LK0``!@```/.M
M```O````^JT```8````JK@``#````#&N```*````/JX```H```!)K@``#```
M`%2N```(````8:X```0```!JK@``(0```&^N```&````D:X``!8```"8K@``
M!````*^N```(````M*X```H```"]K@``"0```,BN```%````TJX```P```#8
MK@``"@```.6N```#````\*X```X```#TK@``#`````.O```7````$*\``"@`
M```HKP``%P```%&O```1````::\``!D```![KP``'@```)6O```@````M*\`
M`!,```#5KP``%P```.FO```9`````;````X````;L```&P```"JP```%````
M1K````D```!,L```"0```%:P```,````8+````T```!ML```$````'NP```0
M````C+```!0```"=L```"````+*P``!?````N[```%<````;L0``!@```'.Q
M```#````>K$```<```!^L0``#````(:Q```6````D[$``#$```"JL0``.P``
M`-RQ```*````&+(```H````CL@``"@```"ZR```-````.;(``!````!'L@``
M`P```%BR```6````7+(```D```!SL@``-0```'VR```1````L[(```T```#%
ML@``#0```-.R```J````X;(``!$````,LP``&0```!ZS```-````.+,```8`
M``!&LP``"````$VS```G````5K,```<```!^LP``%@```(:S```O````G;,`
M`!D```#-LP``&0```.>S```6`````;0``!@````8M```(0```#&T```;````
M4[0``#D```!OM```/@```*FT```I````Z+0``"8````2M0``.P```#FU```<
M````=;4``"P```"2M0``"````+^U```,````R+4```X```#5M0``!@```.2U
M```)````Z[4```X```#UM0``#@````2V```-````$[8``"$````AM@``,@``
M`$.V```D````=K8``"0```";M@``)@```,"V```3````Y[8```P```#[M@``
M)`````BW```.````+;<```\````\MP``%````$RW```)````8;<```D```!K
MMP``$````'6W```6````AK<``!@```"=MP``"@```+:W```4````P;<```H`
M``#6MP``#@```.&W```0````\+<``!0````!N```%@```!:X```1````+;@`
M`!`````_N```.@```%"X``!9````B[@```L```#EN```$````/&X```%````
M`KD```H````(N0``"P```!.Y```,````'[D```T````LN0``#@```#JY```+
M````2;D```D```!5N0``"P```%^Y```%````:[D``!H```!QN0``'````(RY
M```@````J;D``"````#*N0``"@```.NY```+````]KD``!$````"N@``5```
M`!2Z```5````:;H```X```!_N@``%````(ZZ```4````H[H``!````"XN@``
M%P```,FZ```5````X;H``"L```#WN@``!````".[```.````*+L```D````W
MNP``!0```$&[```-````1[L``!0```!5NP``#0```&J[```)````>+L``!L`
M``""NP``$@```)Z[``!'````L;L```4```#YNP``"@```/^[```1````"KP`
M``4````<O```!0```"*\```2````*+P``!$````[O```"@```$V\```[````
M6+P```H```"4O```20```)^\```,````Z;P```P```#VO```&@````.]```5
M````'KT```P````TO0``&````$&]```8````6KT```D```!SO0``"````'V]
M```*````AKT``$0```"1O0``20```-:]```1````(+X```\````RO@``$```
M`$*^```:````4[X``!<```!NO@``"P```(:^```9````DKX```X```"LO@``
M!0```+N^```*````P;X```4```#,O@``"@```-*^```5````W;X``!(```#S
MO@``'0````:_```:````)+\``!8````_OP``%P```%:_```?````;K\```X`
M``".OP``!P```)V_```/````I;\```X```"UOP``%0```,2_```Y````VK\`
M``T````4P```!````"+````$````)\````D````LP```!0```#;````/````
M/,````D```!,P```"````%;````)````7\```!,```!IP```$P```'W````%
M````D<````4```"7P```(0```)W````G````O\```"<```#GP```%@````_!
M```S````)L$``"T```!:P0``+0```(C!```;````ML$``(0```#2P0``*0``
M`%?"```H````@<(``$T```"JP@``2P```/C"```9````1,,``!<```!>PP``
M(````';#```>````E\,``!L```"VPP``,@```-+#```:````!<0``!\````@
MQ```+0```$#$```G````;L0``!\```"6Q```-0```+;$```0````[,0``"<`
M``#]Q```40```"7%``!:````=\4``%8```#2Q0``7P```"G&``!I````B<8`
M`&@```#SQ@``7````%S'```Q````N<<``&D```#KQP``(P```%7(``!I````
M><@``#0```#CR```'P```!C)```M````.,D``"<```!FR0``1P```([)```L
M````ULD``"\````#R@``)````#/*```A````6,H``!````!ZR@``(P```(O*
M```@````K\H``$H```#0R@``#P```!O+```#````*\L```X````ORP``%P``
M`#[+```*````5LL```L```!ARP``!P```&W+```.````=<L```H```"$RP``
M&@```(_+```,````JLL``!,```"WRP``!@```,O+```&````TLL``!$```#9
MRP``&0```.O+```(````!<P``!4````.S```%P```"3,```'````/,P``!$`
M``!$S```"P```%;,```,````8LP```4```!OS```!P```'7,```?````?<P`
M`!T```"=S```#P```+O,```-````R\P``!L```#9S```'````/7,```+````
M$LT``!`````>S0``*````"_-```-````6,T```\```!FS0``'@```';-```,
M````E<T``!P```"BS0``%````+_-```'````U,T``!````#<S0``0P```.W-
M```"````,<X``#L````TS@``0````'#.```Q````L<X``",```#CS@``*@``
M``?/```^````,L\``!X```!QSP``'@```)#/```4````K\\``!4```#$SP``
M'P```-K/```D````^L\``"T````?T```.@```$W0```A````B-```"````"J
MT```'P```,O0```6````Z]```"(````"T0``+0```"71```A````4]$``$0`
M``!UT0``10```+K1```2`````-(``!,````3T@``+P```"?2```;````5](`
M``L```!ST@``$````'_2```:````D-(``!L```"KT@``'0```,?2``!*````
MY=(```\````PTP``.P```$#3``!5````?-,``!0```#2TP``)@```.?3```N
M````#M0``!8````]U```$````%34```1````9=0``"8```!WU```$````)[4
M```-````K]0```H```"]U```!0```,C4```$````SM0```8```#3U```!0``
M`-K4```(````X-0```8```#IU```!@```/#4```'````]]0```D```#_U```
M!@````G5```)````$-4```T````:U0``!0```"C5```%````+M4```P````T
MU0``"P```$'5```#````3=4```H```!1U0``#P```%S5```)````;-4```@`
M``!VU0``!````'_5```%````A-4```@```"*U0```P```)/5```)````E]4`
M``0```"AU0``!@```*;5```#````K=4``!(```"QU0``$P```,35```/````
MV-4```X```#HU0```0```````````````P```$8````-`0``B@```/0!```X
M`@``;0$``-L``````````````*H"```1````T@(```````"(````:P$`````
M``!-````$`$``(X```"0````J`````````#,`@``H0```&,```#E`0``````
M`#\!`````````````!4!``#D````<P```,L````&`P``@@$``+8"``!<`0``
MQ0$``*4!````````H@$```````#(`````````$D```#O`0`````````````I
M`@``2@(``'T!``"V````>0````H!``!\````>@(``%("``"Q````R0$``)\"
M``![`@```````*<!``````````````````"O`@``MP````````!,`0``````
M`,T"````````<@```/$"```7````%`(``/H"``!)`@``*0$``-X"````````
M``````````#N````8@$``(4````;````&0(``"`"``"``@```````%`!``!&
M`@``U0``````````````RP$``"$"``""````90``````````````)0(``"4!
M``!T````50$``*`"```J````CP(``"L!``!7`0``%@$`````````````X@``
M`#8"``!]````%0```)<!``!!`0```````!@!````````-P(``(D"``#3`@``
M)````(8```!R`@``70``````````````/0````````!F`0``8`(``/$`````
M````#`$``!H`````````(P$``,\"``"N`@``?P```*<"``#!`@```````(D!
M``"P````@0$``/@"````````Q@$``.4```"$````JP```#0!```4````M`(`
M`-$"``!9`0``>`(``.<"```U`@``'P(``*@"````````60```$@!``"Z````
MI`$``(8!```+`0``W`(``#H````+`@``V`$`````````````Y@```/@```!.
M`@```````(T"``"%`@``Y0(````````(````Q````*0"````````9`$``.$!
M````````MP(``%0``````````````,\!```[`@``"`,```````#`````H0$`
M``````"P`@``M`$``&P!`````````````)D```!P`0``IP````````!<````
ML@```-,```!`````XP(``%(!```O`0``/`$``,<`````````G@$``-4!````
M````$@$``&D"``#X`0``2P```,4"````````>0(```0#````````,0(``(T`
M``#^`0```````)<```"M````<P(``+$"``!<`@```````)P!````````U`$`
M`(H"``#U`0``I0```,@"````````5`(```````!!`````````+4"``#!`0``
MX`$```````"N`0``J@````````#"`0```````*H!``!?`@``D@$```````"Y
M````0`(``'H````]`0``[P(``#8!```Z`@```````-T```"``0```````*,"
M```B````+0(``+$!```@````30$``#D````>````;@$``.H```##````X```
M`$H!````````8P(``'H!``!^`0```````*X```":`0```````!\`````````
M6````/P!```*````70(``'0"``#0`````````+\!``"1`0```````.D"```"
M`0``/@$```4```"B````\@$`````````````=@(``+L```!D`@```````(``
M``"A`@``@@(````````2`````````$X!``#L````ZP(```<`````````````
M```````M`0``K`(```````!R`0``T`(````````$`0``C@$``+X"```0`@``
MV@`````````N`0``F0$````````1`@```````)T"``!J`0``YP```,P!``!Q
M````;P``````````````Z0````<"``!V````O0(``"(!``!;`@``Z`$``$,!
M``#N`0``E0(``#P```!@`````````/("``#Y`@``FP(``"D```"6````^P$`
M``````!A````1`$``*4"``!P`@```````%<"``"_`````````/X```"5````
MAP````````````````````````!8`@``O``````````%`P``X@$``/D!````
M````5@````D!```4`0``N@$``$T"````````"`(``*,````=````HP$``,D`
M``#/````B0```-$!````````0P(```````!A`0````````````!_`@``@0(`
M``````````````````````"<````50```+T```!0````8@```#L!````````
M+@(``.`"````````M@$`````````````+````*P```#6`@```````%$!````
M`````````-0```!I````?`(```````#\`@``?@(`````````````Q@```!("
M``!"`@``)@$``.("````````10```!H!````````-0```.8!``!P````)P``
M`+,```#Q`0```````$$"``"'`@```````#(!``!%`0``J`$``(0!``"R`@``
M`````&\"````````S@````````#6````;P$````````-````@P(`````````
M````C0$````````V````D0```*P!```<`0```````%$`````````+P``````
M````````!0$````````.`0``P0```*T"````````?@```.H"```F`@``````
M`.L````W`0``E@$``!,!``#Z`0``"@(``%,`````````!@(``+H"````````
M.P```.D!```M````"0`````````````````````````5`@``W@```)0`````
M````RP(```````"%`0``>P```/4"```#`P``80(```@!``#?`@``>`$``!L"
M````````?0(```````#S`0``XP$``.8"``!(`@``O`$``"@`````````;0``
M``X```"+````LP(``'$"```@`0```````-8!``"=````0@$``(P"````````
M;@```)@``````````````-(````G`0``X0```(8"``!4`0```````)L!``#9
M````!@$``)0"````````I@(```````#]`0````````````#H````S0```$\`
M``!@`0``5@$``%L`````````0`$````````C`@``\````,8"```"````_0(`
M`$P````J`0``^0````$"``"P`0``*`$``.P"``#U````(0$``%X```"@````
M_0```$<``````````````+@!``"F`0``&0$``&P```!$````TP$```````"3
M`0``9P$``*\!``"0`0```````/8```!:`0``)P(``+0```"U`0```````!\!
M```'`0``VP(``%H```!G`````````.<!``##`@````````P`````````CP$`
M`*`!```,`@``P@``````````````#P```"P!```Y`@``!`(``"0!``"9`@``
M3P$````````P`@``,0````````!G`@````(``&("````````)`(``*D```!(
M````,P$```````!1`@``CP```#X``````````````"8```#9`@``<P$``!L!
M``````````````D#```<`@```````)\`````````60(``/,```"]`0``C`$`
M`-\```#M`0``H@(``,`!``#<````!P,```````#M`@``?`$````````K`@``
M`````-P!``"$`@``10(``*D"````````'0(````````=`0``U`(``'\!````
M````O`(```$#```Y`0``E`$``,X"````````V@(`````````````$P```,`"
M``"2`@``5@(``,P`````````^@``````````````F@```,0"```>`@``&0``
M`!<"``#*`0``-`(`````````````1P$``%<```">````!0(``(X"``"1`@``
M#P(``$X```#'`0```````"@"````````R`$``#,"``!'`@``[@(``#`!```+
M````9@`````````3`@``!@```%@!````````AP$```$!```E````(@(``"H"
M``!0`@````````0``````````````&@!``"#`0``UP(``+,!```_`@``7P$`
M`"$```!X`````````+D!````````T`$``,X!``"8`@``F`$``+(!``#P`@``
MZ@$``$(```!5`@``/@(````````<````*P```/L"``````````````````"7
M`@``KP```/(```#W`@``9````#,```",````4@```,,!``!3`@```P(`````
M````````:0$````!```U`0``#0(``)`"``!T`0``E0$``-D!``"!````70$`
M`#("``#V`@``BP(```X"````````0P`````````]`@``90$````````6`@``
M&````&H"``"D`````````'4"```O`@``UP```&H`````````G0$``&8"``#W
M`0``NP$``%H"``!W`0``JP(```````"(`@``B`$```````#;`0``%@```.$"
M``!K````M0`````````>`0``U0(``-X!``!/`@````,``&@"``#)`@``"0(`
M`),```#T`````````*T!``"2````V````.0"``!E`@``Q0`````````T````
MN0(``$P"``!Y`0```````&P"``":`@````````````!U`0``JP$```````"^
M````WP$``!@"``#K`0``+`(`````````````S0$``+<!`````````````&X"
M``!*````O@$``!$!``"*`0```@,``)X"```:`@``^P`````````X````````
M`#P"``#M````>P$``,0!``#7`0```````,("````````DP(``+L"``!Q`0``
M7P````````#_`0```````/\```"X``````````````#_`@```````#$!``#D
M`0``7@(``'4`````````.`$``/P````7`0```````,H"``!;`0``=P````\!
M```0``````````````!+`@``/P```'<"`````````P$```````";````1@$`
M`/8!``#1``````````````#=`0``N`(```````#W````7@$``#``````````
M@P`````````R````\P(```````!$`@``+@```,<"``!K`@``-P````````#:
M`0``BP$``+\"````````G`(``-T"``!3`0````````````#H`@````````("
M``!M`@``:````.\```"F````20$`````````````XP````````!V`0``````
M`$L!````````J0$``)8"```Z`0```````-@"``#^`@``[`$``&,!```C````
M]`(``/`!````````R@```-(!``"?`0`````````@("`@("!4;SH@`"`@("!$
M871E.B``("`@($9R;VTZ(``@4W5B:F5C=#H@`"!I;B``)60@;65S<V%G97,@
M:&%V92!B965N(&1E;&5T960N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O
M<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN
M`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`"5D(&UE<W-A9V5S(&AA=F4@8F5E
M;B!R97!O<G1E9"!A<R!S<&%M+@`E9"!T;R`E9"!O9B`E9"!-97-S86=E<P`E
M<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA
M;65D+@`E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@
M=&AE(&UO;G1H+@`E<R!H87,@8V%N8V5L;&5D("5S+@`E<R!H87,@9&5C;&EN
M960N`"5S(&AA<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+@`E
M<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R`E<RX`)7,Z("5S("@E9"9N8G-P.V]F
M)FYB<W`[)60I`"A!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE
M>'0@<V-R965N+BD`*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T
M;R!T:&4@8V]M<&]S92!S8W)E96XN*0`H4F5T=7)N('1O('1H92!C;VUP;W-E
M('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@
M9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@
M8F4@87!P;&EE9"XI`"H@061D('1H97-E(&)Y(&-L:6-K:6YG($]+("H`*B!0
M;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("H`,2!M97-S86=E(&AA<R!B965N
M(&1E;&5T960N`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@
M<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN`#$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+@!!
M(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S
M<V%G92X`04Y$`$%C8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5P=&5D.B``
M06-C;W5N="=S(&YA;64Z`$%C=&EO;G,`061D('-O=7)C90!!9&0@=&\@061D
M<F5S<R!B;V]K("@E<RD`061D960@(B5S(B!A<R!A;B!A='1A8VAM96YT+@!!
M9&1R97-S($)O;VL`061D<F5S<R!";V]K<P!!;&P`06QL(&UE<W-A9V5S(&EN
M('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I
M;G1O(&]N92!-0D]8(&9I;&4Z`$%L;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@
M9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY
M(&1E;&5T960N`$%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA
M;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL(&]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E
M(&1E;&5T960N`$%L=V%Y<R!S879E(&%T=&%C:&UE;G1S`$%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D
M('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RX`06YS=V5R960`06YS=V5R
M960@;65S<V%G97,`07!P;'D@1FEL=&5R<P!!<'!L>2!&:6QT97)S('1O("5S
M`$%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_`$%P<&QY(&9I
M;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_`$%P<FEL
M`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@
M:V5Y/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y
M<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D(2D`07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A
M8VAM96YT/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F
M;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R
M87-H(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N
M=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S('-P
M86T_`$%R<FEV86P@5&EM90!!<V-E;F1I;F<`071T86-H`$%T=&%C:"!&:6QE
M<P!!='1A8VAE9"!&:6QE.@!!='1A8VAE9"!F:6QE("(E<R(@97AC965D<R!T
M:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N
M`$%T=&%C:&UE;G0`071T86-H;65N=',`071T96YD965S`$%T=&5N=&EO;@!!
M=6=U<W0`079A:6QA8FQE($%D9')E<W,@8F]O:W,Z`$)A8U]K('1O("5S`$)A
M8VL@=&\@)7,`0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@
M:6YF;W)M871I;VX@;65S<V%G92X`0FQA8VML:7-T`$)O9'D`0F]T:`!"=6EL
M9&EN9R!L;V-A;&4@)7,N+BX@`$-?:&%R<V5T`$-A;&5N9&%R`$-A;B!N;W0@
M8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+@!#86X@;F]T(&-O
M;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@`$-A;F-E;`!#86YC
M96P@365S<V%G90!#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA
M;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+@!#:&%N9V4`0VAA;F=E($%L
M;`!#:&%N9V4@1F]L9&5R`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A
M<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@
M:&]W(&UE<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!M86EL('-E<G9E<B!A
M;F0@9F]L9&5R('-E='1I;F=S+@!#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L
M(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&5C:R!&;VQD97(H<RD@9F]R
M($YE=R!-86EL`$-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S
M<V%G93\`0VAO;W-E($%C=&EO;CH`0VAO;W-E(&$@;6%I;"!S97)V97(Z`$-H
M;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT
M.@!#:&]O<V4@86X@86-T:6]N.@!#:&]O<V4@=&AE(&%D9')E<W,@8F]O:R!T
M;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+@!#:&]O<V4@=&AE(&]R9&5R
M(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D
M9')E<W-E<RX`0VQE86YI;F<@=7`@;&]C86QE("5S+BXN(`!#;&EC:R`E<R!T
M;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI
M8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!#;&EC
M:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN
M9&]W+@!#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T960@
M<&%R="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@;VX@;VYE(&]F('EO
M=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL
M(&9I96QD<R!T;R!S96%R8V@N`$-L;W-E`$-L;W-E('1H:7,@=VEN9&]W`$-L
M;W-E9"!&;VQD97(`0V]L;&%P<V4`0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L
M;"!&;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VUM96YT`$-O;7!L971E9`!#
M;VUP;W-E`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!O<V4@86YO=&AE<B!M
M97-S86=E`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_
M`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A
M;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV
M97,N`$-O<'D`0V]P>2!T;R!F;VQD97(`0V]R<F5C=`!#;W)R96-T960@5&5X
M=`!#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V
M97(@<V%I9#H@)7,`0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<RX`0W)E871E`$-R96%T92!&;VQD97(`0W)E871E($ME>7,`0W)E
M871E(%9I<G1U86P@1F]L9&5R`$-R96%T92!A(&YE=R!3<&%M(&9O;&1E<@!#
M<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@<V5N="!M
M86EL(&9O;&1E<@!#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F
M:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL
M+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#=7-T
M;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN`$-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RX`1&%T7V4`1&%T90!$96-E;6)E<@!$96-L
M:6YE9`!$96-L:6YE9#H@`$1E9F%U;'0`1&5F875L="!)9&5N=&ET>0!$969A
M=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I
M;VXZ`$1E;&5G871E9`!$96QE=&4`1&5L971E("5S(%!U8FQI8R!+97D`1&5L
M971E($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E;&5T92!396QE
M8W1E9"!&;VQD97)S`$1E;&5T92!6:7)T=6%L($9O;&1E<@!$96QE=&4@9F5T
M8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_`$1E;&5T92!O;&0@
M<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/P!$96QE
M=&5D`$1E;&5T960@;65S<V%G97,`1&5L971E9"!T:&4@871T86-H;65N="`B
M)7,B+@!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E<V-E;F1I;F<`
M1&5S8W)I<'1I;VX`1&5T86EL<P!$:6T@<VEG;F%T=7)E<S\`1&ES<&QA>0!$
M:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N
M9&EN9R!A(&UE<W-A9V4_`$1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O
M9B!N97<@;6%I;#\`1&\@3D]4(&UA=&-H`$1O($YO="!#:&5C:R!&;VQD97(H
M<RD@9F]R($YE=R!-86EL`$1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD
M97(_`$1O;F4`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@)7,@:6X@
M+GII<"!&;W)M870`1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP
M(&9I;&4I`$1O=VYL;V%D($9O;&1E<BAS*0!$;W=N;&]A9"!&;VQD97(H<RD@
M6RYZ:7`@9F]R;6%T70!$;W=N;&]A9"!I;B`N>FEP($9O<FUA=`!$<F%F=`!$
M<F%F="!F;VQD97(`1')A9G1S(&9O;&1E<CH`12UM86EL($%D9')E<W,`15)2
M3U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D+@!%9&ET
M`$5D:70@0FQA8VML:7-T`$5D:70@1FEL=&5R<P!%9&ET(%9I<G1U86P@1F]L
M9&5R`$5D:70@5VAI=&5L:7-T`$5D:70@>6]U<B!B;&%C:VQI<W0`161I="!Y
M;W5R(&9I;'1E<B!R=6QE<P!%9&ET('EO=7(@=VAI=&5L:7-T`$5M86EL($%D
M9')E<W,`16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RX`16UP='D@1F]L
M9&5R*',I`$5M<'1Y(%-E;&5C=&5D($9O;&1E<G,`16UP='D@5')A<V@@9F]L
M9&5R`$5M<'1Y(%]4<F%S:`!%;F%B;&4@;65S<V%G92!P<F5V:65W<S\`16YC
M<E]Y<'1I;VX@3W!T:6]N<P!%;F0@9F]R=V%R9&5D(&UE<W-A9V4`16YD(&UE
M<W-A9V4`16YD(&UE<W-A9V4@9G)O;2`E<P!%;G1E<B!087-S<&AR87-E`$5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<@!%;G1E<B!T
M:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R`$5N=&ER92!-97-S86=E
M`$5N=')Y("(E<R(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D
M<F5S<R!B;V]K`$5R<F]R`$5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+@!%
M=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU
M=&5S`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AP86YD`$5X<&%N
M9"!!;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N9"!&;VQD97(`17AP86YD
M($YA;65S`$5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U
M;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\`17AP86YD:6YG`$9?971C:"!-86EL
M`$9E8G)U87)Y`$9E=&-H($UA:6P`1F5T8V@@36%I;"!I;B!A('-E<&%R871E
M('=I;F1O=S\`1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N/P!&971C
M:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,`1F5T8VAE9"`Q(&UE<W-A9V4@9G)O
M;2`E<P!&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RX`1FE?;'1E<G,`1FEL
M90!&:6QT97(@3W!T:6]N<P!&:6QT97(@4V5T=&EN9W,`1FEL=&5R(&UE<W-A
M9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/P!&:6QT97)S`$9I;'1E<G,@3D]4
M($%C=&EV90!&:6YD`$9I<G-T($UA:6QB;W@@4&%G90!&:7)S="!086=E`$9O
M7W)W87)D`$9O;&1E<B!.879I9V%T;W(`1F]L9&5R(%!R969I>`!&;VQD97(@
M4W5M;6%R>0!&;W)W87)D`$9O<G=A<F0Z`$9O<G=A<F1E9"!M97-S86=E`$9O
M<G=A<F1E9"!M97-S86=E(&9R;VT@)7,`1G)O7VT`1G)O;0!&<F]M($%D9')E
M<W,`1G=D.@!&=V0Z(`!&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E<P!'96YE
M<F%L($]P=&EO;G,`1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY
M*0!';R!T;R!-97-S86=E`$=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B`B
M)7,B`$A%4D4`2%1-3"!697)S:6]N(&]F($UE<W-A9V4`2&5A9&5R<P!(96QP
M`$AI9&1E;@!(:61D96X@:6X@5&AR96%D(%9I97<`2&ED92!$96QE=&5D`$AI
M9&4@56YS=6)S8W)I8F5D`$AI9&4@=&AE($EM86=E<P!(:6=H`$AI9V@@4')I
M;W)I='D`2&EG:&5S=`!(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A
M8VAM96YT<S\`2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R
M97!L>0!)3D)/6`!)9&5N=&ET>2=S(&YA;64Z`$EF('EO=2!C;VYT:6YU92P@
M86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(0!)
M9VYO<F4`26=N;W)E($%L;`!);7!O<G0`26UP;W)T($UE<W-A9V5S`$EM<&]R
M="!M8F]X($9I;&4`26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E
M<RX`26UP;W)T86YT`$EM<&]R=&%N="!M97-S86=E<P!);7!O<G1E9"`E9"!M
M97-S86=E<R!F<F]M("5S+@!);F)O>`!);F-L=61E(&]R:6=I;F%L(&UE<W-A
M9V4@:6X@82!R97!L>3\`26YF;P!);FQI;F4`26YV86QI9"!!9&1R97-S`$EN
M=F%L:60@:V5Y`$EN=F5R=`!*86YU87)Y`$IU;'D`2G5N90!+0@!,86YG=6%G
M90!,87-T($UA:6QB;W@@4&%G90!,87-T(%!A9V4`3&%S="!5<&1A=&5D.@!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA='9I80!,87EO=70`3&5B86YO;@!,969T`$QI7VYK($%T
M=&%C:&UE;G1S`$QI8F5R:6$`3&EN:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B
M:61D96XN`$QI;FMS('=I;&P@97AP:7)E(&]N("5S`$QI=&AU86YI80!,;V-A
M;"!-86EL8F]X.@!,;V-A=&EO;@!,;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O
M=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]W`$QO=R!0<FEO<FET>0!,;W=E<W0`
M36%C:6YT;W-H($9I;&4`36%I;`!-86EL(%!R979I97=S`$UA:6QB;W@`36%I
M;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T:6]N<P!-86QA=VD`36%L87ES
M:6$`36%L9&EV97,`36%L:0!-87)C:`!-87)G:6X`36%R:R!!;&P@365S<V%G
M97,@:6X@1F]L9&5R(&%S(%-E96X`36%R:R!!;&P@365S<V%G97,@:6X@1F]L
M9&5R(&%S(%5N<V5E;@!-87)K(&%S.@!-87)K(&1I9F9E<F5N="!L979E;',@
M;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA<G-H86QL($ES
M;&%N9',`36%T8V@@06QL(%%U97)I97,`36%T8V@@06YY(%%U97)Y`$UA=7)I
M=&%N:6$`36%X:6UU;2!!='1A8VAM96YT(%-I>F4`36%X:6UU;2!N=6UB97(@
M;V8@871T86-H;65N=',@<F5A8VAE9"X`36%X:6UU;2!T;W1A;"!A='1A8VAM
M96YT('-I>F4@<F5A8VAE9"X`36%Y`$UE<F=I;F<@=')A;G-L871I;VX@9F]R
M(&UO9'5L92`E<RXN+@!-97-S86=E`$UE<W-A9V4@0V]M<&]S:71I;VX`365S
M<V%G92!$871E`$UE<W-A9V4@3W!T:6]N<P!-97-S86=E(%-E87)C:`!-97-S
M86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!6:65W:6YG`$UE<W-A
M9V4@9FEE;&1S`$UE<W-A9V4@9FQA9W,`365S<V%G92!F;VQD97)S`$UE<W-A
M9V4@9G)O;2`E<P!-97-S86=E(&AA<R!A='1A8VAM96YT<P!-97-S86=E(&ES
M(&5N8W)Y<'1E9`!-97-S86=E(&ES('-I9VYE9`!-97-S86=E(&UA=&-H97,`
M365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E
M<P!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+@!-97-S86=E<R!P97(@<&%G
M92!I;B!T:&4@;6%I;&)O>"!V:65W+@!-97-S86=E<R!T;P!-97AI8V\`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:7)R;W(`36ES8V5L;&%N
M96]U<P!-;P!-;V1I9GD`36]D:69Y(%523`!-;V1U;&4`36]N86-O`$UO<F4@
M=&AA;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@(B5S(BX`36]V90!-
M;W9E($1O=VX`36]V92!5<`!-;W9E(&1O=VX`36]V92!T;R!F;VQD97(`36]V
M92!U<`!.86UE`$YA;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='D`
M3F5V97(`3F5V97(@<V%V92!A='1A8VAM96YT<P!.97<`3F5W($9O;&1E<@!.
M97<@36%I;`!.97<@;65S<V%G97,`3F5X=`!.97AT($UE<W-A9V4`3F5X="!0
M86=E`$YO`$YO($5N8W)Y<'1I;VX`3F\@365S<V%G97,`3F\@4')E=FEE=R!4
M97AT`$YO(%!U8FQI8R!+97ES($9O=6YD`$YO(&%T=&%C:&UE;G1S(&9O=6YD
M+@!.;R!F;VQD97(@<V5L96-T960N`$YO(&9O;&1E<G,@=V5R92!S<&5C:69I
M960`3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<P!.;R!F;VQD97)S('=I
M=&@@=6YS965N(&UE<W-A9V5S`$YO(&UE<W-A9V4@8F]D>2!T97AT`$YO(&UE
M<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N`$YO('-P96QL:6YG(&5R<F]R
M<P!.;R!S=6=G97-T:6]N<P!.;R!U<V5R('-P96-I9FEE9"X`3F]N90!.;W)M
M86P`3F]T($1E;&5T960`3F]T($1R869T`$YO="!);7!O<G1A;G0`3F]T(%!E
M<G-O;F%L`$YO="!D96QE=&5D(&UE<W-A9V5S`$YO="!I;7!O<G1A;G0@;65S
M<V%G97,`3F]V96UB97(`3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L
M:6YK960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R
M(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG
M(&UO;G1H;'DN`$]+`$]2`$]C=&]B97(`3VQD(&UE<W-A9V5S`$]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]N;'D@9&ES<&QA>2!F;VQD
M97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_`$]N;'D@;VYE(&9O
M;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+@!/<&5?
M;B!&;VQD97(`3W!E;B!&;VQD97(`3W!E;F5D($9O;&1E<@!/<'1I;VYS`$]T
M:&5R($]P=&EO;G,`4$=0`%!'4"!%;F-R>7!T($UE<W-A9V4`4$=0($5R<F]R
M.B``4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R
M:79A=&4@:V5Y+@!01U`@3D]4($%C=&EV90!01U`@3W!T:6]N<P!01U`@4&%S
M<W!H<F%S92!);G!U=`!01U`@4'5B;&EC($ME>2!F;W(@(B5S(B!W87,@<W5C
M8V5S<V9U;&QY(&1E;&5T960N`%!'4"!3:6=N($UE<W-A9V4`4$=0(%-I9VXO
M16YC<GEP="!-97-S86=E`%!A9V4@)60@;V8@)60`4&%R="AS*0!087-S=V]R
M9`!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<G-O;F%L`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!L86-E('EO=7(@<VEG;F%T
M=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\`4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@
M;F%M92!O9B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N97<@
M;F%M93H`4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"X`4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92X`4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R
M(&EN=F%L:60@861D<F5S<V5S+@!0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E
M9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RX`4&QE87-E('-E;&5C="!A
M;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('-E;&5C="!A
M="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"X`4&QE87-E('-E;&5C="!O
M;FQY(&]N92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+@!0;&5A<V4@<V5L
M96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z`%!R96-E9&4@
M>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\`4')E=FEE=P!0
M<F5V:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')I;G0`4')I;W)I='D`
M4'5R7V=E($1E;&5T960`4'5R9V4@1&5L971E9`!0=7)G92!&;VQD97(H<RD`
M4'5R9V4@5')A<V@@:&]W(&]F=&5N.@!0=7)G92!M97-S86=E<R!I;B!4<F%S
M:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+@!0=7)G
M92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\`4'5R9VEN9R`E
M9"!M97-S86=E<R!F<F]M(%1R87-H(&9O;&1E<BX`4'5R9VEN9R`Q(&UE<W-A
M9V4@9G)O;2!4<F%S:"!F;VQD97(N`%%U;W1A('-T871U<SH@3D\@3$E-250`
M475O=&EN9R`E9CH`4F5?<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N`%)E
M8V5I=F5D($]N`%)E8V5I=F5D(%-I;F-E`%)E8V5I=F5D(%5N=&EL`%)E9&ER
M96-?=`!2961I<F5C=`!2961I<F5C="!-97-S86=E`%)E9&ER96-T('1H:7,@
M;65S<V%G90!2961I<F5C=&EN9R!F86EL960N`%)E9G)E<V@`4F5F<F5S:"!&
M;VQD97(@5FEE=W,Z`%)E;&]A9`!296QO860@5FEE=P!296UE;6)E<B!T:&4@
M;&%S="!V:65W`%)E;6]T92!-86EL8F]X.@!296UO=F4@1FEE;&0@1G)O;2!3
M96%R8V@`4F5M;W9E('-O=7)C90!296YA;64@1F]L9&5R*',I`%)E;F%M92!S
M96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`4F5N86UI
M;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!297!L7WD@=&\@3&ES=`!297!L86-E('=I=&@Z`%)E<&QY`%)E
M<&QY(%-E;G0N`%)E<&QY('1O($%L;`!297!L>2!T;R!!;&PZ`%)E<&QY('1O
M($QI<W0`4F5P;'D@=&\@3&ES=#H`4F5P;'D@=&\@7T%L;`!297!L>2U4;P!2
M97!L>2U4;SH@`%)E<&QY.@!297!O<G0@87,@26YN;V-E;G0`4F5P;W)T(&%S
M(%-P86T`4F5Q=65S="!A(%]296%D(%)E8V5I<'0`4F5Q=65S="!R96%D(')E
M8V5I<'1S/P!297-E=`!297-U;64`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N
M('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN
M9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%,O34E-12!%;F-R>7!T($UE<W-A
M9V4`4R]-24U%($5R<F]R.B``4R]-24U%($Y/5"!!8W1I=F4`4R]-24U%($]P
M=&EO;G,`4R]-24U%(%!A<W-P:')A<V4@26YP=70`4R]-24U%(%-I9VX@365S
M<V%G90!3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A9V4`4R]-24U%('-U<'!O
M<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`%-?=6)J96-T`%-A7W9E
M(&$@8V]P>2!I;B``4V%?=F4@87,`4V%V90!3879E($1R869T`%-A=F4@3W!T
M:6]N<P!3879E(%]$<F%F=`!3879E(&%S`%-A=F4@<V5A<F-H(&%S(&$@=FER
M='5A;"!F;VQD97(_`%-A=F4@<V5N="!M86EL/P!3879I;F<@=&AE(&1R869T
M(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`4V5A
M<F-H`%-E87)C:"`E<P!396%R8V@@4F5S=6QT<P!3965N`%-E;&5C=`!396QE
M8W0@06YO=&AE<B!!8V-O=6YT`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9FEE
M;&0`4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD
M('-E87)C:&EN9R!F;W(@861D<F5S<V5S+@!396QE8W0@86QL`%-E;&5C="!A
M;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N
M`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!N;VYE`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5L96-T960@061D<F5S<R!B;V]K<SH`4V5N
M9"!-97-S86=E`%-E;G0@;6%I;"!F;VQD97(`4V5N="!M86EL(&9O;&1E<CH`
M4V5P=&5M8F5R`%-E<G9E<@!397)V97(Z`%-E="!P<F5F97)E;F-E<R!F;W(@
M=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S86=E
M<RX`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@
M<V%V:6YG(&$@9')A9G0_`%-H;W<@06QL($9O;&1E<G,`4VAO=R!!;&P@2&5A
M9&5R<P!3:&]W($1E;&5T960`4VAO=R!,:6UI=&5D($AE861E<G,`4VAO=R!-
M86EL:6YG($QI<W0@26YF;W)M871I;VX`4VAO=R!5;G-U8G-C<FEB960`4VAO
M=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!T:&4@26UA9V5S
M`%-I7WIE`%-I9VYE9`!3:7IE`%-O<G0@1&ER96-T:6]N`%-O<G0@8GD@07)R
M:79A;`!3;W)T(&)Y($1A=&4`4V]R="!B>2!&<F]M($%D9')E<W,`4V]R="!B
M>2!-97-S86=E(%-I>F4`4V]R="!B>2!3=6)J96-T`%-O<G0@8GD@5&AR96%D
M`%-O<G0@8GD@5&\@061D<F5S<P!3<&%M(&9O;&1E<CH`4W!E8VEA;"!#:&%R
M86-T97)S`%-P96QL($-H96-K`%-P96QL($-H96-K97(`4W!E;&P@8VAE8VL@
M8V]M<&QE=&4`4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L
M;"!C:&5C:VEN9RX`4W1R:7`@071T86-H;65N=`!3=6)?:F5C=`!3=6)J96-T
M`%-U8FIE8W0@1FEE;&0`4W5B;6ET`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`
M4W5C8V5S<P!3=6=G97-T:6]N<P!3=6UM87)Y`%-W:71C:"!T;R!(5$U,(&-O
M;7!O<VET:6]N`%-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N`%1E
M7WAT`%1E>'0`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4
M:&4@86-C;W5N="`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@861D<F5S<R`B
M)7,B(&AA<R!B965N(&%D9&5D('1O("5S+@!4:&4@871T86-H;65N="!W87,@
M;F]T(&9O=6YD+@!4:&4@8W5R<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E
M(')E;F%M960@=&\@(B5S(BX`5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O
M('1H92`B)7,B(&9O;&1E<BX`5&AE(&9I96QD("(E<R(@8V%N)W0@8F4@97AP
M86YD960N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L
M9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N
M86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A
M=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O
M;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S
M8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T
M960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B
M)7,B('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D
M+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4
M:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E
M<R(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!M
M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN`%1H92!M97-S86=E(&)E:6YG
M(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A
M9V4@:&%S(&)E96X@9&5L971E9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R
M:69I960N`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z
M("5S+@!4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"X`5&AE
M('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+@!4:&4@=&%S
M:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=&5X="!O
M9B!T:&4@;65S<V%G90!4:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M
M86EL8F]X+@!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@82!P<F]B;&5M
M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@
M8V]P>6EN9R!M97-S86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG
M(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S
M<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H
M97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L
M9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R
M(&UO=FEN9R!M97-S86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG
M('1H:7,@;65S<V%G92!A<R!A(&1R869T+@!4:&5R92!W87,@86X@97)R;W(@
M<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H97)E('=A<R!N;R!T97AT(&EN
M('1H:7,@;65S<V%G92!P87)T`%1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G
M97,@96UB961D960@:6X@:70N`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G
M92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N`%1H:7,@;65S
M<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N`%1H
M:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI
M<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"X`5&AI<R!M
M97-S86=E('1O`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RX`5&AR96%D(%9I97<`
M5&\`5&\@061D<F5S<P!4;W1A;"!!='1A8VAM96YT<R!3:7IE.@!4<F%S:"!F
M;VQD97(`5')A<V@@9F]L9&5R.@!5;F%N<W=E<F5D`%5N86YS=V5R960@;65S
M<V%G97,`56YD96QE=&4`56YD:7-C;&]S960@4F5C:7!I96YT<P!5;FMN;W=N
M($1A=&4`56YK;F]W;B!296-I<&EE;G0`56YN86UE9`!5;G-E96X`56YS=6)S
M8W)I8F4@9G)O;2!&;VQD97(H<RD`57!D871E($%T=&%C:&UE;G0@26YF;W)M
M871I;VX`57!L;V%D`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0(&9O;&1E
M<B!S=6)S8W)I<'1I;VYS/P!5<V5R`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5
M<V5R;F%M93H`5FEE=P!6:65W("5S`%9I97<@)7,@4'5B;&EC($ME>0!6:65W
M($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W(%1H<F5A
M9`!6:65W(%1H=6UB;F%I;`!6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<`5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I
M97<@979E;G0`5FEE=R!M97-S86=E<R!I;B`E<P!6:65W(&]R(&UA:6QB;W@@
M=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CH`5FEE=R!T87-K`%9I97<@=&AE($EM
M86=E<P!6:7)T=6%L($9O;&1E<B`B)7,B(&-R96%T960@<W5C8V5S9G5L;'DN
M`%9I<G1U86P@1F]L9&5R<P!6:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA
M8F5L+@!6:7)T=6%L(&9O;&1E<B!L86)E;`!787)N:6YG`%=E;&-O;64@=&\@
M)7,`5W)A<"!T97AT(&%T('1H:7,@;6%N>2!C:&%R86-T97)S+@!997,`66]U
M(&%R92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@
M86-C;W5N="AS*3H`66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@
M;65S<V%G97,@8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I
M+@!9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F;VQL;W=I;F<@
M9F]L9&5R*',I+@!9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O
M;&1E<BX`66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@`%EO=2!A
M<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+@!9;W4@87)E(')E;F%M
M:6YG('1H92!F;VQD97(Z(`!9;W4@8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M
M("(E<R(N`%EO=2!H879E("5S(&YE=R!M97-S86=E<RX`66]U(&AA=F4@,2!N
M97<@;65S<V%G92X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN
M9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@
M9F]L9&5R<SH`66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N
M="X`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO
M=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N`%EO=2!M
M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@
M870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N`%EO=2!M=7-T('-P96-I9GD@
M82!R96-I<&EE;G0N`%EO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I
M;&4@=&\@871T86-H+@!9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@
M)7,@;VX@)25S+@!9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N
M`%EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N($AE<F4@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F
M<F]M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E
M<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S(@!9;W4@=V5R92!S
M=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(@!9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!&
M<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@3F%M90!9;W5R
M(%!'4"!0=6)L:6,O4')I=F%T92!+97ES`%EO=7(@4')I=F%T92!+97D`66]U
M<B!0=6)L:6,@2V5Y`%EO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QI/BAO<'1I
M;VYA;"D\+VD^`%EO=7(@86-C;W5N=',Z`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92X`
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I
M;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R!P<FEN="X`66]U<B!C
M=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-H87)S970@9F]R('-E
M;F1I;F<@;65S<V%G97,Z`%EO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO
M9"!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&ED96YT:71Y
M.@!9;W5R(&9U;&P@;F%M93H`66]U<B!M97-S86=E('=A<R!S=6-C97-S9G5L
M;'D@9&5L:79E<F5D+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M`%EO=7(@<VEG;F%T=7)E.@!;3F\@4W5B:F5C=%T`7T)L86-K;&ES=`!?0V]M
M<&]S90!?1&5L971E`%]&;VQD97)S`%](96QP`%])9&5N=&ET>0!?26YB;W@`
M7TQO9R!O=70`7TUE<W-A9V4@4V]U<F-E`%]/<'1I;VYS`%]0<FEN=`!?4')I
M;W)I='D`7U)E9G)E<V@@)7,`7U)E<&QY`%]396%R8V@`7U-E;F0@365S<V%G
M90!?5&AR96%D`%]4;P!?56YD96QE=&4`7U9I97<@5&AR96%D`%]7:&ET96QI
M<W0`871T86-H;65N=`!B>71E<P!D;VYE`&9A:6QE9`!F<F]M`&UA:6QB;W@@
M9FEL90!N86UE`&YO;F4`;W(`<W!E;&QI;F<@97)R;W(`<W!E;&QI;F<@97)R
M;W)S`'EO=7(@8FQA8VML:7-T`'EO=7(@=VAI=&5L:7-T`%!R;VIE8W0M260M
M5F5R<VEO;CH@24U0(#0N,"XT"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`R+3`Q+3$P
M(#$Y.C`P*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TQ,2TQ.2`R,#HS
M,RLP,#`P"DQA<W0M5')A;G-L871O<CH@0FIO<FX@1&%V:61S<V]N(#QB:F]S
M<VE`<VYE<G!A+FES/@I,86YG=6%G92U496%M.B!)8V5L86YD:6,@/'-U<'!O
M<G1`<VYE<G!A+FES/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@`@("`@("!4:6PZ(``@("!$86=S+CH@`"`@
M("`@1G+A.B``($5F;FES;.UN83H@`"#M(``E9"!S:V5Y='5M(&AE9G5R('9E
M<FGP(&5Y='0N`%1I;&MY;FYI;F<@=6T@)60@<VME>71I(&UE<FMT('-E;2!E
M:VMI(')U<VQP\W-T=7(@:&5F=7(@=F5R:?`@<V5N9"!K97)F:7-U;7-J\VXN
M`%1I;&MY;FYI;F<@=6T@)60@<VME>71I(&UE<FMT('-E;2!E:VMI(')U<VQP
M\W-T=7(@:&5F=7(@=F5R:?`@<V5N9"X`5&EL:WEN;FEN9R!U;2`E9"!S:V5Y
M=&D@;65R:W0@<V5M(')U<VQP\W-T=7(@:&5F=7(@=F5R:?`@<V5N9"!K97)F
M:7-U;7-J\VXN`%1I;&MY;FYI;F<@=6T@)60@<VME>71I(&UE<FMT('-E;2!R
M=7-L</-S='5R(&AE9G5R('9E<FGP('-E;F0N`"5D('1I;"`E9"!A9B`E9"!S
M:V5Y='5M`"5S(&5R(&[Z(/YE9V%R('1I;"X@36%P<&%N("5S('9A<B!E:VMI
M(&5N9'5R;F5F;F0N`$UA<'!A;B`E<R!V97+P=7(@=6UN969N9"#M('5P<&AA
M9FD@:'9E<G,@;>%N8?!A<BX`)7,@:&5F=7(@:6CF='0@=FGP("5S+@`E<R!H
M969U<B!H869N8?`N`"5S(&AE9G5R('-V87)A\"!B;_!I;G4@=&EL("5S+@`E
M<R#S<VMA<B!E9G1I<B!U<'!L_7-I;F=U;2!U;2!H=F]R="#^^B!E<G0@=FGP
M;.%T:6YN+@`E<R!V87(@8N9T="#M("5S+@`E<SH@)7,@*"5D)FYB<W`[868F
M;F)S<#LE9"D`*%-A;?YY:VMJ82!B<F5Y=&EN9V%R(&]G(&9A<F$@[2!NYG-T
M82!G;'5G9V$N*0`H2'5N9'-A(&%L;&%R(&)R97ET:6YG87(@;V<@9F%R82!T
M:6P@8F%K82#M(&'P('-K<FEF82!S:V5Y=&DN*0`H1F%R82!T:6P@8F%K82#M
M(&'P('-K<FEF82!S:V5Y=&D@969T:7(@8?`@:&%F82!V:7-T8?`@8G)E>71I
M;F=A<B!S96T@9V5R\&%R(&AA9F$@=F5R:?`@:&EN9V'P('1I;"X@0G)E>71I
M;F=A<B!S96T@96MK:2!H869A('9E<FGP('-K<N'P87(@=F5R\&$@96MK:2!G
M97EM9&%R+BD`*B!"YG1T=2#^97-S=6T@=FGP(&UE\"#^=NT@8?`@<VUE;&QA
M(.$@3TL@*@`J(%9E;&1U(&YE=&;V;F<@*@!%:6YU('-K97ET:2!V87(@97ET
M="X`5&EL:WEN;FEN9R!U;2!E:71T('-K97ET:2!S96T@96MK:2!R=7-L</-S
M='5R(&AE9G5R('9E<FGP('-E;F0@:V5R9FES=6US:O-N+@!4:6QK>6YN:6YG
M('5M(&5I='0@<VME>71I('-E;2!R=7-L</-S='5R(&AE9G5R('9E<FGP('-E
M;F0N`%1I;&MY;FYI;F<@=6T@96ET="!S:V5Y=&D@<V5M(')U<VQP\W-T=7(@
M:&5F=7(@=F5R:?`@<V5N9"!K97)F:7-U;7-J\VXN`%1I;&MY;FYI;F<@=6T@
M96ET="!S:V5Y=&D@<V5M(')U<VQP\W-T=7(@:&5F=7(@=F5R:?`@<V5N9"X`
M4W3S<B!M>6YD(&YE9FYD("5S(&5R(&AE;F=D('9I\"#^971T82!S:V5Y=&DN
M`$]'`%-A;?YY:VMJ82!B96GP;FD`4V%M_GEK:W0`4V%M_GEK:W0Z(`!.;W1A
M;F1A;F%F;CH`0?!G97+P:7(`8N9T82!V:?`@:&%N9')I=&D`0N9T82#M(&YE
M=&9A;F=A8O-K("@E<RD`5FGP:&5N9VEN=2`B)7,B(&+F='0@=FGP+@!.971F
M86YG86+S:P!.971F86YG86+F:W5R`-9L;"!S:V5Y=&D`UFQL('-K97ET:2#M
M(/YE<W-A<FD@;?9P<'4@+R#^97-S=6T@;?9P<'5N=6T@=F5R\&$@9V5Y;60@
M[2!S=&%K<FD@34)/6"!S:W+A.@#6;&QU;2!S:V5Y='5M(.T@;?9P<'5N;FD@
M(B5S(B!S96T@97)U(&5L9')I(&5N("5S(&1A9V$@=F5R\'5R(&5Y='0N`-9L
M;'5M(&5L9')I('-K97ET=6T@<V5M(/[Z(&AE9G5R('-E;G0@9G+A(/[I<BP@
M;V<@97)U(&5L9')I(&5N("5S(&WA;F'P82!V97+P=7(@97ET="X`UFQL=6T@
M<V5N="UM86EL(&WV<'!U;2!S96T@97)U(&5L9')I(&5N("5S(&WA;F'P82!V
M97+P=7(@97ET="X`06QT868@9V5Y;6$@=FGP:&5N9VDN`--TYFMT(&=I;&1I
M('1I;&=R96EN="X`T_YE:VMT('9I;&QA(&MO;2!U<'`@_F5G87(@<F5Y;G0@
M=F%R(&'P(&9R86UK=N9M82!S:W+A;FEN9W5N82X`4W9A<F'P`%-K97ET:2!S
M96T@8OII\"!E<B!A\"!S=F%R80!6:7)K:F$@<^UU<@!6:7)K:F$@<^UU<B!F
M>7)I<B`E<P!6:7)K:F$@<^UU<B#^96=A<B#^^B!T96YG:7-T+@!6:7)K:F$@
M<^UU<B#^96=A<B!)3D)/6"!E<B!U<'!FYG)T+@!A<'+M;`!%<G0@_OH@=FES
M<R!U;2!A\"#^^B!V:6QJ:7(@9V5R82#^971T83\`17)T(/[Z('9I<W,@=6T@
M8?`@_OH@=FEL:FER(&=E<F$@_F5T=&$_`$5R="#^^B!V:7-S('5M(&'P(/[Z
M('9I;&II<B!G97)A(/YE='1A/P!%<G0@_OH@=FES<R!U;2!A\"#^^B!V:6QJ
M:7(@14Y$04Y,14=!(&5Y\&$@_F5S<W5M('-K97ET=6T_`$5R="#^^B!V:7-S
M('5M(&'P(/[Z('9I;&II<B!%3D1!3DQ%1T$@97GP82#^97-S=6T@=FGP:&5N
M9VIU;3\`17)T(/[Z('9I<W,@=6T@8?`@_OH@=FEL:FER('3F;6$@_F5S<V$@
M;?9P<'4_`$5R="#^^B!V:7-S('5M(&'P(/[Z('9I;&II<B!TYFUA(')U<VQA
M:_9R9G5N83\`17)T(/[Z('9I<W,@=6T@8?`@_OH@=FEL:FER($5.1$%.3$5'
M02!E>?!A(/YE<W-U;2!S:V5Y='5M/P!%<G0@_OH@=FES<R!U;2!A\"#^^B!V
M:6QJ:7(@=&EL:WEN;F$@_F5T=&$@<VME>71I('-E;2!E:VMI(')U<VQP\W-T
M/P!%<G0@_OH@=FES<R!U;2!A\"#^^B!V:6QJ:7(@=&EL:WEN;F$@_F5T=&$@
M<VME>71I('-E;2!R=7-L</-S=#\`2V]M=73M;6D`2.9K:V%N9&D`2&5N9VIA
M('-K<N$@=FGP`$+F=&$@=FGP('9I\&AE;F=J=6T`5FGP:&5N9VDZ`%9I\&AE
M;F=I\"`B)7,B(&5R(&]F('-T\W)T+B!3:W+A:6X@=F%R($5+2TD@=FGP:&5N
M9V0N`%9I\&AE;F=I`%9I\&AE;F=I`%9I\'-T861D:7(`071H=6=A\'4`X6?Z
M<W0`5&EL=.9K87(@;F5T9F%N9V%BYFMU<CH`5&EL8F%K82#M("5S`%1I;&)A
M:V$@[2`E<P!(Z7(@8?`@;F7P86X@97(@:'+A<B!T97AT:2!A9B!S=/;P=75P
M;/US:6YG87-K97ET:6YU+@!3=F%R=&QI<W1I`$UE9VEN;>%L`$+F\&D`0GEG
M9VD@;OH@;&]C86QE("5S("XN+@!3=&%F87-E='0`1&%G871A;`!'970@96MK
M:2!T96YG<W0@</-S=/YJ\VYI+@!'870@96MK:2!T96YG<W0@</-S=/YJ\VYI
M(.$@9FIA<F5N9&$Z(`!(YG1T82!V:?``2.9T=&$@=FGP('-K97ET:0!%9B#^
M^B!HYG1T:7(@=FGP(/[A(&5R(/9L;'4@969N:2!S:V5Y=&ES:6YS(&9A<F=A
M\"X`0G)E>71A`$)R97ET82#V;&QU;0!3:VEP=&$@=6T@;?9P<'4`2.ER(&=E
M='5R(/[Z(&)R97ET="#^=NT@X2!H=F'P82!HX71T('-K97ET=6T@97(@<F'P
M8?`@=7!P(&]G(&AV97)S=2!M87)G87(@<VME>71A;.UN=7(@<VKA<W0@[2!H
M=F5R:G5M(&=L=6=G82X`0G)E>71A('#S<W3^:O-N<R!O9R!M]G!P=7-T:6QL
M:6YG=6TN`$CI<B!G971U<B#^^B!B<F5Y='0@_G;M(&AV8?!A(&YA9FXL(&YE
M=&9A;F<@;V<@<VME>71I<V)O=&X@:V5M=7(@9G)A;2#M('-K97ET=6T@_NUN
M=6TN`$AV8?!A(&WV<'!U<B#A(&'P(&%T:'5G82!M9?`@;OUJ86X@</-S="#M
M`$%T:'5G82!S=&%F<V5T;FEN9W4@9GER:7(@<V5N9&EN9W4_`%9E;&1U(&'P
M9V5R\#H`5F5L9'4@</-S=/YJ\VXZ`%9E;&1U(&7P82!B<F5Y='1U('1I;"!H
MYF=R:3H`5F5L9'4@8?!G97+P.@!696QD=2!N971F86YG86+S:R!S96T@X2!A
M\"!N;W1A(/YE9V%R(&[]:G5M(&YE=&;V;F=U;2!E<B!BYG1T('9I\"X`5F5L
M9'4@=7!P<O;P=6X@;F5T9F%N9V%B\VMA('-E;2#A(&'P(&QE:71A(.TL(/YE
M9V%R(&QE:71A\"!E<B!A\"!N971F]FYG=6TN`$AR96EN<V$@=&EL(.T@;&]C
M86QE("5S("XN+@!3;65L;'4@X2`E<R!T:6P@8?`@<VMO\&$@2%1-3"!I;FYI
M:&%L9"#M('/I<B!G;'5G9V$N`%-M96QL='4@)7,@=&EL(&'P('-K;_!A(&AA
M;F$@<V5M('-MX6UY;F0N`%-M96QL='4@X2`E<R!T:6P@8?`@<VMO\&$@=FGP
M:&5N9VD@[2!SZ7(@9VQU9V=A+@!3;65L;'1U(.$@)7,@=&EL(&'P('-K;_!A
M(/YE;FYA;B!H;'5T82#M('/I<B!G;'5G9V$N`%-M96QL='4@X2!E:6YA(&%F
M(';V;&1U;2!N971F86YG86+S:W5M(&]G('9E;&1U(/[A(')E:71I('-E;2#A
M(&'P(&QE:71A(.TN`$QO:V$`3&]K82#^97-S=6T@9VQU9V=A`$QO:W7P(&UA
M<'!A`$QO:V$`3&]K82#V;&QU;0!,;VMA(/9L;'5M(&WV<'!U;0!,;VMA(&WV
M<'!U`$%T:'5G87-E;60`3&]K:?``4V5M:F$`4V5M:F$@<VME>71I("@E<RD`
M4V5M:F$@;OUT="!S:V5Y=&D`4V5M:F$@<VME>71I(.T@<^ER(&=L=6=G83\`
M4W1J\W)N82!H=F5NYG(@871H=6=A\"!E<B!U;2!P\W-T+"!O9R!H=F5R;FEG
M(.$@8?`@9V5R82!V:?!V87)T('5M(&[]:F%N('#S<W0N`$%F<FET`$%F<FET
M82#M(&WV<'!U`$QE:?!RZ71T80!,96GP<NET='5R('1E>'1I`$=A="!E:VMI
M(&5Y='0@<VME>71U;2!F<N$@)7,Z("5S`$=A="!E:VMI(&9R86UK=N9M="!V
M:?!H86QD<V'P9V5R\&ER`$+Z82!T:6P`0OIA('1I;"!M]G!P=0!"^F$@=&EL
M(&QY:VQA`$+Z82!T:6P@<_UN9&%R;?9P<'4`0OIA('1I;"!N_6IA(&WV<'!U
M('5N9&ER(')U<VQP\W-T`$+Z82!T:6P@;OUJ82!M]G!P=2!U;F1I<B!U<'!K
M]G-T`$+Z82!T:6P@;OUJ82!M]G!P=2!U;F1U<B!S96YD('-K97ET:0!"^F$@
M=&EL(&[]:F$@;?9P<'4@*')U<VQA:_9R9G4I('5N9&ER(&5Y9&0@<VME>71I
M`$+Z82!T:6P@<^UU<F5G;'5R('-E;2!S=&KS<FYA(&UE\&9E<O`@:6YN:V]M
M86YD:2!P\W-T<RP@9N9R82!H86YN(.T@=&EL=&5K;F%R(&WV<'!U<B!E\&$@
M97GP82!R=7-L</-S=&DN`%-T:6QL82!H=F5R;FEG('#S<W1U<B!E<B!S96YD
M=7(N`%-T:6QL82!A\&=E<O!I<B!S96T@97)U(&9R86UK=N9M9&%R(/YE9V%R
M(/[Z('1E;F=I<W0@)7,N`$1A9W,`1&%G<P!D97-E;6)E<@!(869N8?``2&%F
M;F'P.B``4VKA;&9G969I\`!3:N%L9F=E9FGP(&ME;FYI;6%R:P!3:N%L9F=E
M9FEN('+V\'5N87)A\&9E<O`Z`%-JX6QF9V5F:6X@=7!P<O;P=6XZ`%+A\'-T
M869A\`!%>?!A`$5Y\&$@;W!I;F)E<F$@;'EK;&EN=6T@)7,`17GP82!V:7)K
M=6T@;'EK;'5M`$5Y\&$@;?9P<'4H;2D`17GP82!V]FQD=6T@;?9P<'5M`$5Y
M\&$@<_UN9&%R;?9P<'4`2')E:6YS82#Z="!S\W1T('-K97ET:2#A('#S<W3^
M:O-N:2#A(&9J87)E;F1A/P!%>?!A(&?V;6QU;2!M]G!P=6T@;67P('-E;F1U
M;2!P\W-T:2#M('5P<&AA9FD@:'9E<G,@;>%N8?!A<@!%>71T`$5Y9&0@<VME
M>71I`$5Y9&1I('9I\&AE;F=I;G4@(B5S(BX`17GP:6YG(&]G(&9L=71N:6YG
M=7(@<VME>71A`$SF:VMA;F1I`$S]<VEN9P!!=')I\&D`2&%F82!U;F1I<G-K
M<FEF=&ER(&UE\"!D875F=6T@;&ET/P#:=&QI=`#:=&QI='-S=&EL;&EN9V%R
M`%/];F$@<W1A\&9E<W1I;F=U(&'P('-E;F1I;F=U(&QO:VEN;FD_`%/];F$@
M4&]P57`@9VQU9V=A(/YE9V%R(&[]<B!P\W-T=7(@8F5R<W0N`%-E;2!P87-S
M87(@96MK:2!V:?``16MK:2!A=&AU9V$@=6T@;OUJ86X@</-S="#M(&WV<'!U
M*&TI`%9I;'1U(&]P;F$@_F5S<V$@;?9P<'4_`$QO:VGP`%/F:VIA('EF:7(@
MX2!V:6YN=7-T]O``4^9K:F$@)7,@>69I<B#A('9I;FYU<W3V\`!3YFMJ82`E
M<R!S96T@+GII<"!S:W+A`%/F:VIA(/9L;"!V:?!H96YG:2`H[2`N>FEP('-K
M<N$I`%/F:VIA(&WV<'!U*'(I('EF:7(@X2!V:6YN=7-T]O``4^9K:F$@;?9P
M<'4H<BD@6RYZ:7`@<VMRX5T`4^9K:F$@<V5M("YZ:7`@<VMRX0!5<'!K87-T
M`$UA<'!A(&9Y<FER('5P<&OV<W0Z`$UA<'!A(&9Y<FER('5P<&OV<W0Z`$YE
M=&9A;F<`5DE,3$$Z(-YA\"!T\VMS="!E:VMI(&$@<V5N9&$@<VME>71I\"X`
M0G)E>71A`%9I;FYA(.T@<W9A<G1L:7-T80!6:6YN82#M('/M=6T@9GER:7(@
M</-S=`!"<F5Y=&$@<_UN9&%R;?9P<'4`5FEN;F$@[2!H=NUT;&ES=&$`5FEN
M;F$@[2#^[6YU;2!S=F%R=&QI<W1A`$)R97ET82#^[6YU;2!S[75R96=L=6T`
M5FEN;F$@[2#^[6YU;2!H=NUT;&ES=&$`3F5T9F%N9P#6;&P@<VME>71I(&9R
MX2`E<R!H<F5I;G-U\"#Z="X`5.9M82!M]G!P=2AR*0!4YFUA('9A;&1A<B!M
M]G!P=7(`5.9M82!R=7-L86OV<F9U;?9P<'4`5.9M82!R=7-L;?9P<'4`5FER
M:VIA(&9O<G-K;_!U;B!S:V5Y=&$_`$1U;&OS\'5N87)V86QK;W-T:7(`3&KZ
M:V$@9G)A;7-E;F1U('-K97ET:0!,:OIK82!S:V5Y=&D`16YD82!F<F%M<V5N
M="!S:V5Y=&D@9G+A("5S`%-K<N'P=2!I;FX@;'EK:6QK\_!A`%-LX?!U(&EN
M;B!N869N(.$@;OUJ=2!M]G!P=6YN:2!F>7)I<B!R=7-L</-S=`!3;.'P=2!I
M;FX@;F%F;B#A(&[]:G4@;?9P<'5N;FD@9GER:7(@=7!P:_9S=`!3;.'P=2!I
M;FX@;F%F;B#A(&[]:G4@;?9P<'5N;FD@9GER:7(@<V5N9"!S:V5Y=&D`4VSA
M\'4@:6YN(&YA9FX@X2!N_6IU(&WV<'!U;FYI("AR=7-L86OV<F9U*2!F>7)I
M<B!E>61D('-K97ET:0!3:V5Y=&D@[2!H96EL9"!S:6YN:0!.971F86YG:?`@
M(B5S(B!V87(@<VMRX?`@[2!N971F86YG86+S:VEN80!6:6QL80!6:?!B=7+P
M:6YU;2!V87(@97ET="X`P2!K;W)T97)S(&9R97-T:0#!(#,P('-E:RX@9G)E
M<W1I`,$@9FEM;2!M[6[Z=&YA(&9R97-T:0#!(&CA;&9T[6UA(&9R97-T:0#!
M(&WM;OIT=2!F<F5S=&D`3W!N82!A;&QA<@!/<&YA(&%L;&%R`$]P;F$@86QL
M87(@;?9P<'5R`$]P;F$@;?9P<'4`3W!N82!N869N87-K<N$`3W!N82!A;&QT
M(&WV<'!U='+I\"!S:N%L9F=E9FGP(.T@;?9P<'5H86TN`$]P;F$@86QL87(`
M4^9K:F$@</-S=`!F96)R^F%R`%/F:VIA('#S<W0`4^9K:F$@<VME>71I(.T@
M<^ER(&=L=6=G83\`4^9K:F$@<VME>71I(/YE9V%R(/[Z('1E;F=I<W0_`%/S
M='1I("5D('-K97ET:2!F<N$@)7,`4_-T=&D@96ET="!S:V5Y=&D@9G+A("5S
M`-[Z(.%T="!E;F=I;B!N_2!S:V5Y=&DN`%/M=7(`4VMRX0!3[75V86QK;W-T
M:7(`4^UU<W1I;&QI;F=A<@!3[6$@<VME>71I(&=A9VYV87)T(')U9&1A;&5G
M=2!O<O!A;&%G:3\`4^UU<@!3[75R($5+2TD@=FER:V%R`$9I;FYA`$9Y<G-T
M82!S[?!A`$9Y<G-T82!S[?!A`,%F<F%M<V5N9&$`3?9P<'5V[7-I<@!&;W)S
M:V5Y=&D@9GER:7(@;?9P<'5R`$WV<'!U>69I<FQI=`#!9G)A;7-E;F1A`,%F
M<F%M<V5N9&$Z`,%F<F%M<V5N="!S:V5Y=&D`P69R86US96YT('-K97ET:2!F
M<N$@)7,`1G+A`$9RX0!396YD86YD86YE=&9A;F<`P69R86US+CH`P69R86US
M+CH`1G)A;7,N.B`E=2!F<F%M<V5N9"!S:V5Y=&D`5F%L:V]S=&ER(&YO=&%N
M9&$`4^9K:F$@8F%R82!N_2!S:V5Y=&D_("A)34%0*0!/<&YA('-K97ET:0!&
M87)A(.T@;F5T9F%N9V%B\VMA<G-K<N%N:6YG=2!F>7)I<B`B)7,B`&CI<@!(
M5$U,(/IT9^%F82!S:V5Y=&ES`$AA=7-A<@!(:N%L<`!&86QI\`!&86QI\"#M
M(&5F;FES_G+A\'-H86T`1F5L82!E>61D('-K97ET:0!&96QA(/-V:7)K82AR
M*2!L[6YU*'(I`$9E;&$@;7EN9&ER;F%R`$CA<@!(X7(@9F]R9V%N9W5R`$CF
M<W1I`$AV<FYI9R!V:6QT=2!S_6YA('9I\&AE;F=I/P!(=F5R;FEG(.$@8?`@
M;65R:VIA('1E>'1A('-E;2!E<B!V97)I\"!A\"!V[7-A(.T@[2!S=F%R:3H`
M26YN8F]X`$ME;FYI;F%F;CH`UFQL=6T@<VME>71U;2#M(&WV<'!U;FYI+VWV
M<'!U;G5M('9E<O!U<B!E>71T(0!(=6YD<V$`2'5N9'-A(&%L;'0`1FQY=&IA
M(&EN;@!&;'ET:F$@:6YN('-K97ET:0!&;'ET:F$@:6YN(&UB;W@@<VMRX0!&
M;'ET:F$@:6YN(&UB;W@@<VMRX6YA("5S(.T@;?9P<'5N82`E<RX`P7+M\&%N
M9&D`P7+M\&%N9&D@<VME>71I`"5D('-K97ET:2!F<N$@)7,@:6YN<V5T="X`
M26YN8F]X`,$@8?`@<_UN82!E9FYI('5P<')U;F%L96=A(&)RZ69S:6YS(.T@
M<W9A<FD_`%5P<&PN`%-K97ET="!I;FX`TV=I;'0@;F5T9F%N9P#39VEL9'5R
M(&QY:VEL;`!6:?!S;OII\`!J86[Z87(`:OIL[0!J^F[M`$M"`%1U;F=U;>%L
M`'/M\&%S=&$@8FQS+@!S[?!A<W1A(&)L<RX`<^WP87-T('5P<&;F<G0Z`%/M
M\&%S="!T96YG<W0Z("5S`%/M\&%S="!T96YG<W0Z("5S(&9RX2`E<P!3[?!A
M<W0@=&5N9W-T.B!!;&1R96D`3&5T=&QA;F0`1G)A;7-E=&YI;F<`3.UB86YO
M;@!6:6YS=')I`%1E;F=J82!V:?!H96YG:2!M9?`@=F5F<VSS\`!,[6)E<NUA
M`$5K:VD@97(@:.9G="!A\"!T96YG:F$@=FGP:&5N9VD@;67P('9E9G-L\_``
M5&5N9VQA<B#S9VEL9&ER(/YA;FX@)7,`3&ET:.%E;@!0\W-T;6%P<&$`4W1A
M\'-E=&YI;F<`5&5N9VIA<W0`5&5N9VIA<W0@)7,`VG1S:W+A`%1E;F=J87-T
M`%9E<FME9FYI('9I\"!T96YG:6YG=0!,X6=U<@!,X6=U<B!F;W)G86YG=7(`
M3.9G<W1I`$UA8VEN=&]S:"!S:W+A`%#S<W1U<@!&;W)S:V_P=6X@</-S=',`
M4/-S=&UA<'!A`-IT;&ET<W-T:6QL:6YG87(`36%L87;M`$UA;&'M<^UA`$=R
MYFYH]F;P865Y:F%R`$UA;.T`;6%R<P!3<.%S<^UA`$UE<FMJ82#V;&P@<VME
M>71I(.T@;?9P<'4@<V5M(&QE<VEN`$UE<FMJ82#V;&P@<VME>71I(.T@;?9P
M<'4@<V5M(/-L97-I;@!M97)K:F$@<V5M.@#!(&'P(&UE<FMJ82!E;&1R:2!T
M:6QV:71N86YI<B#M('1E>'1A(&UE\"!M:7-M=6YA;F1I(&QI='5M/P!-87)S
M:&%L;&5Y:F%R`$%L;'0@_F%R9B!A\"!P87-S80!%:71T:'9A\"#^87)F(&'P
M('!A<W-A`$WA<NUT86[M80!(X6UA<FMS<W3F<O`@=FGP:&5N9VES`$CA;6%R
M:W-F:O9L9&$@=FGP:&5N9VIA(&[A\"X`5FGP:&5N9VD@97(@;V8@<W3S<G0`
M;6'M`%-A;65I;F$@_OWP:6YG87(@9GER:7(@)7,@96EN:6YG=6YA+BXN`%-K
M97ET:0!396UJ82!N_71T('-K97ET:0!$86=S+@!686QK;W-T:7(@<VME>71A
M`$QE:71A(.T@<VME>71U;0!3=.9R\"!S:V5Y=&ES`$AA;F1R:70`4VMO\&$@
M<VME>71I`%-VYO!I`$9L]F=G`$WV<'!U<@!3:V5Y=&D@9G+A("5S`%-K97ET
M:?`@97(@;67P('9I\&AE;F=J=6T`4VME>71I\"!E<B!D=6QR:71A\`!3:V5Y
M=&GP(&5R('5N9&ER<FET8?``3&5I=&%R<VMI;'ER\&D`4VME>71I\"!V87(@
M<V5N="P@96X@96MK:2!V87(@:.9G="!A\"!G97EM82#^8?`@[2`E<P!3:V5Y
M=&GP('9A<B!S96YT+@!&:O9L9&D@<VME>71A;.UN82#A(&)L<RX@[2!S:V_P
M=6X@</-S=&CS;&9S+@!3:V5Y=&D@=&EL`$UE>.UK\P!-[6MR\VYE<^UA`%-P
M96=L80#=;6ES;&5G=`!-X0!"<F5Y=&$`0G)E>71A('-L\_``16EN:6YG`$WS
M;F%K\P!&;&5I<FD@96X@96ET="!N971F86YG(&9A;FYS="!F>7)I<B!S=N;P
M:?`@(B5S(@!&;'ET:F$`1FQY=&IA(&YI\'5R`$9L>71J82!U<'``9N9R82!N
M:?!U<@!FYG)A(.T@;?9P<'4`9N9R82!U<'``3F%F;@!.869N(&]G+V7P82!N
M971F86YG(&WA(&5K:VD@=F%N=&$`06QD<F5I`$%L9')E:2!G97EM82!V:?!H
M96YG:2X`3OUT=`!._2!M87!P80!._7(@</-S='5R`$[]('-K97ET:0!.YG-T
M80!.YG-T82!S:V5Y=&D`3N9S=&$@<^WP80!.96D`16YG:6X@9'5L:_/P=6X`
M16YG:6X@<VME>71I`$5N9VEN;B!F;W)S:V_P=6YA<G1E>'1I`$5N9VER(&]P
M:6YB97)I<B!D=6QR:71U;F%R;'EK;&%R(&9U;F1U<W0`16YG:6X@=FGP:&5N
M9VD@9G5N9'5S="X`96YG:6X@;6%P<&$@=F%L:6X`16YG:6X@;6%P<&$@=F%R
M('1I;&=R96EN9`!%;F=A<B!M]G!P=7(@;67P(&[]:G5M('-K97ET=6T`16YG
M87(@;?9P<'5R(&UE\"#S;&5S;G5M('-K97ET=6T`16YG:6YN('1E>'1I('-K
M97ET:0!,96ET:6X@8F%R(&5K:VD@X7)A;F=U<@!%;F=A<B!S=&%F<V5T;FEN
M9V%R=FEL;'5R`$5N9V%R('1I;&SV9W5R`$5N9VEN;B!N;W1A;F1I('1I;&=R
M96EN9'5R+@!%;F=I;@!696YJ=6QE9W0`16MK:2!E>71T`$5K:VD@=7!P:V%S
M=`!%:VMI(.%R[?!A;F1I`$5K:VD@<&5R<_-N=6QE9W0`16MK:2!E>61D('-K
M97ET:0!%:VMI(.%R[?!A;F1I('-K97ET:0!N\W9E;6)E<@!!;&1U<B#M(&WA
M;G7P=6T@9GER:7(@=FGP=&5N9V1A<B!V969S;//P:7(L('-E;2!S:W5L=2!G
M97EM87-T+"#^96=A<B!MX6YA\&%R;&5G('1I;'1E:W0@97(@9V5R\`!&:O9L
M9&D@868@;?9P<'5M(&9Y<FER('-E;F0@<VME>71I+"!S96T@<VMU;'4@9V5Y
M;6%S="P@_F5G87(@;>%N8?!A<FQE9R!T:6QT96MT(&5R(&=E<O``S2!L86=I
M`$7000!O:W3S8F5R`$?V;75L('-K97ET:0!']FUL=6T@<VME>71U;2!E>71T
M+BXN`$5I;G5N9VES('/];F$@;?9P<'5R('-E;2!I;FYI:&%L9&$@\VQE<VEN
M('-K97ET:3\`WF'P(&5R(&5I;G5N9VES(&CF9W0@8?`@=F5J82!E:6YA(&WV
M<'!U(&9Y<FER(/YE<W-A(&'P9V5R\"X`3W!N82!M]G!P=0!/<&YA(&WV<'!U
M`$]P:6X@;6%P<&$`5F%L<W1I;&QI;F=A<@!!\')A<B!S=&EL;&EN9V%R`%!'
M4`!$=6QK\_!A('-K97ET:2!M9?`@4$=0`%!'4"!V:6QL80!01U`@=FEL;&$Z
M(%9A;G1A<B!L>6MI;&OS\&$@9GER:7(@<&5R<_-N=6QE9V%N(&QY:VEL+@!0
M1U`@97(@96MK:2!V:7)K=`!01U`@=F%L:V]S=&ER`%!'4"!L>6MI;&OS\&D`
M3W!I;F)E<F$@4$=0(&QY:VQI;G5M(&9Y<FER("(E<R(@=F%R(&5Y='0N`%5N
M9&ER<FET82!M9?`@4$=0`%5N9&ER<FET82]D=6QR:71A(&UE\"!01U``0FQS
M+B`E9"!A9B`E9`!(;'5T87(`3'EK:6QO<O``1G)A;6MVYFUA('9I\&AA;&1S
M8?!G97+P:7(@=FGP('1E;F=I;F=U`%1I;"!M[6X`57!P;/US:6YG87(@=6T@
M;F]T86YD80!3971J82!U;F1I<G-K<FEF="!U;F1I<B!S=F%R(&]G(.%F<F%M
M<V5N9&EN9V%R/P!3;.'P=2!I;FX@;OUT="!M]G!P=6YA9FXZ`%-LX?!U(&EN
M;B!N_71T(&WV<'!U;F%F;CH`4VSA\'4@:6YN(&[]:F$@;F%F;FGP.@!3;.'P
M=2!I;FX@;'EK:6QO<O`@_FET="X`4VSA\'4@:6YN(&YO=&%N9&%N869N(&]G
M(&QY:VQI;W+P`%-LX?!U(&EN;B!N;W1A;F1A;F%F;B#^:71T+@!,96GP<NET
M='4@:'5G<V%N;&5G87(@=FET;&5Y<W5R(.T@;F5T9F%N9VD@9?!A(&YE=&;V
M;F=U;2X`WOH@_F%R9G0@8?`@=F5L:F$@;?9P<'4@X?!U<B!E;B#^^B!G971U
M<B!H869I\"!A\')A<B!A\&=E<O!I<BX`5F5L9'4@8?!G97+P(&%F('9A;&UY
M;F1I;FYI(&CI<B!A\"!N9?!A;BX`5F5L9'4@82YM+FL@96EN82!M]G!P=2!T
M:6P@8?`@;&5I=&$@[2X`WF'P(&5R(&5I;G5N9VES(&CF9W0@8?`@=F5J82!E
M:6YA(&WV<'!U(&9Y<FER(/YE<W-A(&'P9V5R\"X`5F5L9'4@9?!A(&)R97ET
M='4@=&EL(&CF9W)I.@!3971J82!S:VEL;65R:VD@*"<M+2`G*2!O9F%N('9I
M\"!U;F1I<G-K<FEF=`!&;W)S:V_P80!&>7)R82!S:V5Y=&D`1GER<FD@8FQA
M\'/M\&$`4')E;G1A`$9O<F=A;F=U<@!&:F%R;.9G:F$@97ED9`!&:F%R;.9G
M:F$@97ED9`!%>?!A(&WV<'!U*&TI`$AV97)S=2!O9G0@X2!A\"!TYFUA(')U
M<VQA9O9T=6YA.@!%>?!A('-K97ET=6T@[2!R=7-L86OV<F9U('-E;2!E<G4@
M96QD<FD@[2!D]F=U;2!E;@!&:F%R;.9G:F$@9_9M=6P@<VME>71I(.T@<G5S
M;&%K]G)F=3\`1FIA<FSF9VD@)60@<VME>71I(/IR(')U<VQA:_9R9G5N;FDN
M`$9J87)LYF=I(&5I='0@<VME>71I(/IR(')U<VQA:_9R9G5N;FDN`$MV\W1I
M.B#3=&%K;6%R:V'P=7(`5NUS82!T:6P@)68Z`--S:V$@969T:7(@<W1A\&9E
M<W1I;F=U(.$@869H96YD:6YG=0!-\W1T96MI\"#^86YN.@!-\W1T96MI\"!S
M[?!A;CH`3?-T=&5K:?`@_F%N9V'P('1I;#H`16YD=7)V[7-A`$5N9'5R=NUS
M80!%;F1U<G;M<V$@<VME>71I`$5N9'5R=NUS82#^97-S=2!S:V5Y=&D`16YD
M=7)V[7-U;B!M:7-H97!P8?!I<W0N`$5N9'5R:&QA\&$`16YD=7)H;&'P82!M
M]G!P=6AA;3H`16YD=7)H;&'P80!%;F1U<FAL8?!A(&AA;0!-=6YA('/M\&%S
M=&$@:&%M`%#S<W1H\VQF(.$@9FIA<F5N9&$Z`$5K:VD@;F]T82!S=N;P:2#M
M(&QE:70`9FIA<FSF9VIA(&AA;F1R:70`16YD=7)N969N82!M]G!P=0!%;F1U
M<FYE9FYA(&WV<'!U(&UE\"!S96YD=6T@<VME>71U;2#M(&)Y<FIU;B!H=F5R
M<R!MX6YA\&%R`$5N9'5R;F5F;FEN9R#Z<B!N869N:6YU("(E<R(@[2`B)7,B
M(&UI<VAE<'!N8?!I<W0N($YE=/YJ\VYN:6YN(&MO;2!M9?`@969T:7)F87)A
M;F1I('9I;&QU`%-V87)A(/9L;'5M`%-K:7!T82#Z="!F>7)I<CH`4W9A<F$`
M4W9A<B!S96YT+@!3=F%R82#V;&QU;0!3=F%R82#V;&QU;3H`4W9A<F$@X2!L
M:7-T80!3=F%R82#A(&QI<W1A.@!3=F%R82#V;&QU;0!3=F%R82U4:6P`4W9A
M<F$M5&EL.B``4W9A<CH`5&EL:WEN;F$@<V5M(&5K:VD@<G5S;'#S<W0`5&EL
M:WEN;F$@<V5M(')U<VQP\W-T("A34$%-*0#3<VMA(&5F=&ER(&MV:71T=6X@
M9GER:7(@;?-T=/9K=0#3<VMA(&5F=&ER(&MV:71T=6X@9GER:7(@;?-T=/9K
M=0!%;F1U<G-E=&IA`$AA;&1A(.%F<F%M`%9A;&MO<W1I<B!N;W1A;F1A`,$@
M8?`@9F%R82!T:6P@8F%K82#M('#S<W1H\VQF86QI<W1A(&5F=&ER(&'P('-K
M97ET=6T@97(@97ET="P@_F%U(&9L=71T(&7P82!A9G)I='7P/P!3+TU)344@
M9'5L:_/P82!S:V5Y=&D`4R]-24U%('9I;&QA.B``4R]-24U%(&5R(&5K:VD@
M=FER:W0`4R]-24U%('9A;'-T:6QL:6YG87(`4R]-24U%(&QY:VEL:_/P:0!3
M+TU)344@=6YD:7)R:71A('-K97ET:0!3+TU)344@9'5L<FET82!S:V5Y=&D`
M4R]-24U%('-T=?!M:6YG=7(@97(@\W9I<FMU<B#A(/YE<W-U(&ME<F9I+@!%
M9FYI`%9I<W1A(&%F<FET(.T@`%9I<W1A('-E;0!6:7-T80!6:7-T82!U<'!K
M87-T`%9A;&MO<W1I<B!V:?`@=FES='5N`%9I<W1A('5P<&MA<W0`5FES=&$@
M<V5M`$=E>6UA(&QE:70@<V5M('/];F1A<FWV<'!U/P!6:7-T82!S96YD('-K
M97ET:3\`5FES='5N('5P<&MA<W1S:6YS(&UI<W3S:W-T+B!.973^:O-N;FEN
M;B!K;VT@;67P(&5F=&ER9F%R86YD:2!V:6QL=3H@)7,`3&5I=&$`3&5I=&$@
M[2`E<P!.:?!U<G-T8?!A(&QE:71A<@!,97-I\`!696QJ80!696QD=2!A;FYA
M;B!A\&=A;F<`5F5L9'4@9&5G<V5T;FEN9W4`5F5L9'4@<F5I=`!696QD=2!N
M971F86YG86+S:RABYFMU<BD@9GER:7(@=FGP8N9T=7(@;V<@;&5I=&%R;?9G
M=6QE:6MA+@!696QJ82!A;&QT`%9E;&1U(')E:71I(.T@;F5T9F%N9V%B\VL@
M<V5M(.$@8?`@;&5I=&$@[2P@_F5G87(@;&5I=&'P(&5R(&'P(&YE=&;V;F=U
M;2X`5F5L9'4@8?!G86YG`%9E;&IA(&5K:V5R=`!696QD=2!S:N%L9F=E9FGP
M('1U;F=U;>%L.@!686QD87(@;F5T9F%N9V%BYFMU<CH`4V5N9&$@<VME>71I
M`$UA<'!A(&9Y<FER('-E;F0@<VME>71I.@!-87!P82!F>7)I<B!S96YD('-K
M97ET:3H`<V5P=&5M8F5R`$YE=/YJ\VYN`%#S<W3^:O-N;CH`4W1I;&QA(&9O
M<G-K<FEF="!U;2!H=F'P(&=E<FES="P@_F5G87(@<VME>71I(&5R(&5Y='0@
M9?!A(/YA\"!F;'5T="X`P2!A\"!L;VMA(&=L=6=G86YU;2!S96T@;OT@<VME
M>71I(&5R=2!S86UI;B#M(&5F=&ER(&'P('5P<&MA<W0@97(@=FES=&'P/P!3
M_6YA(&%L;&%R(&WV<'!U<@!3_6YA(&%L;&$@:&%U<V$`4_UN82!E>61D('-K
M97ET:0!3_6YA(&5I;G5N9VES(&AE;'-T=2!H875S80!3_6YA('5P<&PN('5M
M('#S<W1L:7-T80!3_6YA(/-V:7)K80!3_6YA('3A:VX@[2!P\W-T;?9P<'5H
M86T_`%/];F$@;7EN9&ER;F%R`%-TYG+P`%5N9&ER<FET8?``4W3F<O``4O;P
M=6YA<N%T=`!&;&]K:V$@969T:7(@:V]M=73M;6$`1FQO:VMA(&5F=&ER(&1A
M9W,N`$9L;VMK82!E9G1I<B!S96YD86YD86YE=&9A;F=I`$9L;VMK82!E9G1I
M<B!S=.9R\"!S:V5Y=&ES`$9L;VMK82!E9G1I<B!E9FYI<VSM;G4`1FQO:VMA
M(&5F=&ER(&5F;FES_G+F\&D`1FQO:VMA(&5F=&ER('9I\'1A:V%N9&%N971F
M86YG:0!2=7-L</-S=&UA<'!A.@!3Z7)TX6MN`%!R\V9A<FMA<FQE<W1U<@!0
M<O-F87)K86QE<V%R:0!0<O-F87)K87)L97-T<FD@;&]K:?``1FKV;&1I('9I
M;&QN82!P<BX@9VQU9V=A(/YE9V%R('!R\V9A<FMA;&5S='5R(&5R(&ME>7+P
M=7(N`$5Y\&$@=FGP:&5N9VD`169N:0!%9FYI`$5F;FES;.UN80#!9G)A;0!6
M:7)K:F$@;?9P<'4H<BD`1G)A;6MVYFUT`%1I;&SV9W5R`%-A;6%N=&5K=`!3
M:VEP=&$@[2!(5$U,(')I=&EL`%-K:7!T82#M('1E>'1A<FET:6P`5&5X=&D`
M5&5X=&D`0?!G86YG:6YU;2`B)7,B(&AE9G5R('9E<FGP(&5Y='0N`$'P9V%N
M9W5R:6YN("`B)7,B(&AE9G5R('9E<FGP('9I<W1A\'5R+@!.971F86YG:6YU
M("`B)7,B(&AE9G5R('9E<FGP(&+F='0@[2`E<RX`5FGP:&5N9VGP(&9A;FYS
M="!E:VMI+@!4:&4@8W5R<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E
M;F%M960@=&\@(B5S(BX`57!P:V%S=&GP(&AE9G5R('9E<FGP('9I<W1A\"#M
M("(E<R(@;?9P<'5N;FDN`$5K:VD@=/-K<W0@8?`@9GEL;&$@<VKA;&9V:7)K
M="#M('-VYO!I\"`B)7,B+@!-87!P86X@(B5S(B!E<B!N^B#^96=A<B!T:6P`
M36%P<&%N("(E<R(@97(@;67P('/I<G3A:VX@9?!A(.US;&5N<VMA('-T869I
M(.T@;F%F;FEN=2X@WF5T=&$@9V5T=7(@;&5I='0@=&EL('9A;F1A;>%L82!S
M96T@_F%R9B!A\"!L97ES82!M9?`@8?!S=&_P(/YJ\VYU<W1U8?!I;&$N`$UA
M<'!A;B`B)7,B('9A<B!B^FEN('1I;"!E;B!E<B!E:VMI('9I<FLN`$WV<'!U
M;FYI("(E<R(@=F%R(&5Y='0L(&5N(&CZ;B!V87(@=FER:RX`36%P<&%N("(E
M<R(@=F%R(&5K:VD@8OII;B!T:6PN(%9I;&QU=&EL:WEN;FEN9R!N973^:O-N
M<VEN<R!F>6QG:7(@:.ER(.$@969T:7(`3?9P<'5N;FD@(B5S(B!V87(@96MK
M:2!E>71T+B!6:6QL=71I;&MY;FYI;F<@;F5T_FKS;G-I;G,@9GEL9VER(&CI
M<B#A(&5F=&ER`$UA<'!A;B`B)7,B('9A<B!B^FEN('1I;"X`3?9P<'5N;FD@
M(B5S(B!V87(@97ET="X`36%P<&%N("(E<R(@=F%R(&5N9'5R;F5F;F0@(B5S
M(BX`2V5N;FEN=2`B)7,B(&AE9G5R('9E<FGP(&5Y='0N`$UA<'!A;B`B)7,B
M(&5R(&[Z(/YE9V%R('3S;0!3:V5Y=&EN=2!S96T@=F5R:?`@=F%R(&'P('-E
M;6IA(&AE9G5R('9E<FGP(&QO:V'P+@!3:V5Y=&EN=2!H969U<B!V97)I\"!E
M>71T+@!3:V5Y=&GP(&AE9G5R('9E<FGP('-A;FYP<O-F8?`N`%-K97ET:?`@
M:&5F=7(@=F5R:?`@<V%N;G!R\V9A\"X@4V5N9&%N9&DZ("5S+@!%:VMI('9A
M<B!HYF=T(&'P('-K:7!T82!U;2!U;F1I<G-K<FEF="X`56YD:7)S:W)I9G0@
M:&5F=7(@=F5R:?`@8G)E>71T+@!697)K969N:6YU("(E<R(@:&5F=7(@=F5R
M:?`@8N9T="!V:?`@=F5R:V5F;F%L:7-T86YN+@!497AT:2!S:V5Y=&ES:6YS
M`-YA\"!E<G4@96YG:6X@<VME>71I(.T@_F5S<W4@</-S=&CS;&9I+@!686YD
M86WA;"!K;VT@=7!P('9I\"!TYFUI;F=U(.$@)7,N(%9I;&QU=&EL:WEN;FEN
M9R!N973^:O-N<VEN<R!F>6QG:7(@:.ER(.$@969T:7(`5F%N9&%MX6P@:V]M
M('5P<"!V:?`@=.9M:6YG=2!P\W-T:/-L9G,N(%9I;&QU=&EL:WEN;FEN9R!N
M973^:O-N<VEN<R!F>6QG:7(@:.ER(.$@969T:7(Z("5S`%9A;F1A;>%L(&MO
M;2!U<'`@=FGP('3F;6EN9W4@</-S=&CS;&9S+B!6:6QL=71I;&MY;FYI;F<@
M;F5T_FKS;G-I;G,@9GEL9VER(&CI<B#A(&5F=&ER`%9A;F1A;>%L(&MO;2!U
M<'`@=FGP(&%F<FET=6X@9G+A("(E<R(@=&EL("`B)7,B+B!6:6QL=71I;&MY
M;FYI;F<@;F5T_FKS;G-I;G,@9GEL9VER(&CI<B#A(&5F=&ER`%9I;&QA(&MO
M;2!U<'`@_F5G87(@X71T:2!A\"!E>?!A('-K97ET=6T@^G(@;?9P<'5N;FD@
M(B5S(BX@5FEL;'5T:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@
MX2!E9G1I<@!6:6QL82!K;VT@=7!P(/YE9V%R(.%T=&D@8?`@97GP82!S:V5Y
M='5M(.T@;?9P<'5N;FD@(B5S(BX@5FEL;'5T:6QK>6YN:6YG(&YE=/YJ\VYS
M:6YS(&9Y;&=I<B!HZ7(@X2!E9G1I<@!6:6QL82!K;VT@=7!P(/YE9V%R(.%T
M=&D@8?`@97GP82!S:V5Y='5M+B!6:6QL=71I;&MY;FYI;F<@;F5T_FKS;G-I
M;G,@9GEL9VER(&CI<B#A(&5F=&ER.B`E<P!6:6QL82!K;VT@=7!P('9I\"!B
M:7)T:6YG=2#^97-S82!H;'5T82!S:V5Y=&ES:6YS`%9I;&QA(&MO;2!U<'`@
M_F5G87(@X71T:2!A\"!M97)K:F$@<VME>71I(.T@;?9P<'5N;FD@(B5S(BX@
M5FEL;'5T:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@X2!E9G1I
M<@!6:6QL82!K;VT@=7!P('9I\"!A\"!F;'ET:F$@:6YN("5S+@!6:6QL82!K
M;VT@=7!P(/YE9V%R(.%T=&D@8?`@9N9R82!S:V5Y=&D@9G+A("(E<R(@=&EL
M("(E<R(N(%9I;&QU=&EL:WEN;FEN9R!N973^:O-N<VEN<R!F>6QG:7(@:.ER
M(.$@969T:7(`5FEL;&$@:V]M('5P<"!V:?`@=FES='5N(/YE<W-A('-K97ET
M:7,@<V5M('5P<&MA<W1S+@!%:VMI('3S:W-T(&'P('-E;F1A('-K97ET:?`Z
M("5S`-YA\"!V87(@96YG:6X@=&5X=&D@[2#^97-S=6T@:&QU=&$@<VME>71I
M<VEN<P#>971T82!(5$U,('-K97ET:2!E<B!I;FEH96QD=7(@;7EN9&ER+BX`
MWF5T=&$@9^9T:2!T96MI\"!N;VMK=7)N('3M;6$N($5R="#^^B!V:7-S('5M
M(&'P(/[Z('9I;&II<B!H86QD82#A9G)A;3\`WF5T=&$@<VME>71I(&5R(&UE
M\"!01U`@<F%F<N9N82!U;F1I<G-K<FEF="X`WF5T=&$@<VME>71I(&5R(&UE
M\"!3+TU)344@<F%F<N9N82!U;F1I<G-K<FEF="X`WF5T=&$@<VME>71I(&5R
M(&1U;')I=&'P(&UE\"!3+TU)344N`-YE='1A('-K97ET:2!E<B!D=6QR:71A
M\"!M9?`@4$=0+@#>971T82!S:V5Y=&D@=&EL`%1A;&%N('9E<O!U<B!A\"!V
M97)A(&'P(&SA9VUA<FMI(#$N`-YE='1A(&=I;&1I('9E<O!U<B!A\"!V97)A
M('1A;&$N`-YE<W-I(&=L=6=G:2#^87)F(&'P('9E<F$@=NUS=6X@9G+A(&=L
M=6=G86YU;2#^87(@<V5M(&[]('-K97ET:2!E<G4@<V%M:6XN`$5F;FES_G+A
M\'-H86UU<@!4:6P`3?-T=/9K=6YE=&9A;F<`2&5I;&1A<G-TYG+P('9I\&AE
M;F=J83H`4G5S;&%K87)F80!2=7-L86MA<F9A.@#3<W9A<F'P`--S=O9R=?`@
M<VME>71I`$5N9'5R=F5K:F$`3?-T=&%K96YD=7(@<V5M(&5K:VD@<VKA<W0`
MT_YE:VMT(&1A9W,N`-/^96MK='5R(&WS='1A:V%N9&D`TVYE9FYT`--L97-I
M\`!!9G9I<FMJ82!M]G!P=2AR*0!5<'!FYG)A('5P<&PN('5M('9I\&AE;F=I
M`$EN;G-E;F1A`$YO=&$@<VKA;&9G969I\"!G:6QD:0!.;W1A('9I<FMA<B!)
M34%0(&WV<'!U<@!.;W1A;F1I`%9A;&MO<W1I<B!N;W1A;F1A`$YO=&%N9&%N
M869N`$YO=&%N9&%N869N.@!3:V_P80!3_6YA("5S`&E3:V_P82!O<&EN8F5R
M86X@;'EK:6P@9GER:7(@)7,`4VMO\&$@2%1-3"UE9FYI(.T@<^ER(&=L=6=G
M82X`4VMO\&$@969N:7/^<N'P`%-K;_!A('-MX6UY;F0`:V_P82!V:?!H96YG
M:2#M('/I<B!G;'5G9V$N`%-K;_!A(&EN;FEH86QD(.T@<^ER(&=L=6=G82X`
M4_UN82!A=&)U<O``4_UN82!S:V5Y=&D@[2`E<P!-87!P82!E\&$@:&%M=7(@
M<V5M(.$@8?`@<_UN82#M('5P<&AA9FDZ`%/];F$@=F5R:V5F;FD`4VMO\&$@
M;7EN9&ER;F%R`%/];F1A<FUA<'!A;B`B)7,B('9A<B!S=&]F;G7P+@!3_6YD
M87)M]G!P=7(`4_UN9&%R;?9P<'5R(/YU<F9A(&%U\&ME;FYI+@!!=?!K96YN
M:2!S_6YD87)M]G!P=0!!\';V<G5N`%9E;&MO;6EN*&XI(.T@)7,`1N9R82!B
M96YD:6P@<VKA9FMR869A(.T@;N9S='4@;.UN=2#^96=A<B#^97-S=6T@<W1A
M9F%F:O9L9&$@97(@;N'P+@!*X0#>^B!E<G0@=6T@_F'P(&)I;"!A\"!SYFMJ
M82!P\W-T(&9Y<FER(&5F=&ER9F%R86YD:2!A\&=A;F=A.@#>^B!E<G0@=6T@
M_F'P(&)I;"!A\"!E>?!A(/9L;'5M('-K97ET=6T@[2!E9G1I<F9A<F%N9&D@
M;?9P<'4H;2DZ`-[Z(&5R="!U;2#^8?`@8FEL(&'P(&5Y\&$@969T:7)F87)A
M;F1I(&WV<'!P=2AM*3H`WOH@97)T(&'P(&%F<FET82]FYG)A(.T@;OUJ82!M
M]G!P=2X`WOH@97)T('5M(/YA\"!B:6P@8?`@8OIA('1I;"!U;F1I<FWV<'!U
M(.T@`-[Z(&5R="!A\"!B^F$@=&EL(&[]:F$@8?!A;&WV<'!U+EQN4VSA\'4@
M:6YN(&YA9FX@;?9P<'5N;F%R.EQN`-[Z(&5R="!A\"!E;F1U<FYE9FYA(&WV
M<'!U;F$Z(`#>^B!G971U<B!E:VMI(&%F=&5N9W0@9G+A("(E<R(`WOH@X71T
M("5S(&[]('-K97ET:2X`WOH@X71T(#$@;OUT="!S:V5Y=&DN`-[Z(.%T="!N
M_6IA;B!P\W-T(.T@;?9P<'5N;FDZ7&X`WOH@X71T(&[]:F%N('#S<W0@[2#^
M97-S=6T@;?9P<'5M.EQN`-YA\"#^87)F(&'P('1I;&=R96EN82!A+FTN:RX@
M96EN;B!V:?!T86MA;F1A+@#>^B#^87)F="!A\"!V96QJ82#M(&AV8?!A(&WV
M<'!U('#S<W1U<FEN;B#A(&'P(&9A<F$@9GER<W0N`%9E;&1U(&AV8?!A(&'P
M9V%N9VD@_OH@=FEL="!E>?!A+@#>^B#^87)F="!A\"!V96QJ82!N971F86YG
M(&9Y<G-T+@!696QD=2!A+FTN:RX@96ET="!S:V5Y=&D@9GER<W0N`%1I;&=R
M96EN9'4@=FGP=&%K86YD82X`WOH@_F%R9G0@9GER<W0@8?`@=F5L:F$@=FGP
M:&5N9VGP+@#>^B!E;F1U<G;M<V'P:7(@_F5S<W4@<VME>71I('1I;"`E<R#^
M86YN("4E<RX`WOH@<W9A<F'P:7(@_F5S<W4@<VME>71I(/YA;FX@)7,N`"(E
M<R(@=F%R(&5K:VD@9V5R\"!V:7)K+B!(Z7(@97(@=&EL:WEN;FEN9VEN('-E
M;2!K;VT@9G+A(&YE=/YJ\VYI;G5M`"(E<R(@=F%R(&5K:VD@9V5R\"#S=FER
M:RX@2.ER(&5R('1I;&MY;FYI;F=I;B!S96T@:V]M(&9RX2!N973^:O-N:6YU
M;0`B)7,B('9A<B!G97+P('9I<FL`(B5S(B!V87(@9V5R\"#S=FER:P!,;W1A
M;B`E<R!E<B!R=6YN:6X@^G0@X2!T[6UA+B!496YG9'4@_FEG(&%F='5R+@!&
M=6QL="!N971F86YG(/YI='0@*$9RX3HI(#H`57!P;/US:6YG87(`1G5L;'0@
M;F%F;B#^:71T.@!01U`@;W!I;F)E<FER+V5I;FMA(&QY:VQA<@!%:6YK82!D
M=6QR:71U;F%R;'EK:6QL(/YI;FX`3W!I;F)E<B!D=6QR:71U;F%R;'EK:6QL
M(/YI;FX`4W9A<FYE=&9A;F<@_FET="!E9B!A;FYA\"!E;B!F=6QL="!N971F
M86YG("A297!L>2UT;SHI(#QI/BAV86QF<FKA;'-T*3PO:3X`0?!G86YG87(@
M_NUN:7(Z`%9E9G-K;V%R:2#^:6YN('-T>?!U<B!E:VMI(&)I<G1I;F=U(.$@
M_F5S<V%R<FD@9V5R\"!M>6YD87(N`%9E9G-K;_!A<FD@_FEN;B!S='GP=7(@
M96MK:2#^97-S82!P<F5N=&'P9V5R\"X@3F]T8?!U($-44DPO3W!T:6]N(&]G
M(%`@=&EL(&'P('!R96YT82X`3OIV97)A;F1I('3M;6%B96QT:3H`4VKA;&9G
M969I\"!S=&%F87-E='0@[2!S96YD=6T@<VME>71U;3H`4VKA;&9V86QI;B!D
M=6QK\_!U;F%R8?!F97+P(&9Y<FER('-E;F0@<VME>71I.@!3:N%L9F=E9FGP
M(&ME;FYI(/YI='0Z`$9U;&QT(&YA9FX@_FET=#H`4VME>71I\"!V87(@<V5N
M="X`4W1I;&QI;F=A<B#^[6YA<B!H869A('9E<FGP('5P<&;F<O!A<BX`56YD
M:7)S:W)I9G0@_NUN.@!;16MK97)T(&5F;FE=`%-V87)T;&ES=&D`4V5M:F$`
M17GP80!-]G!P=7(`2&KA;'``077P:V5N;FD`26YN8F]X`-IT<VMRX0!(86YD
M<FET`%9A;&MO<W1I<@!0<F5N=&$`1F]R9V%N9W5R`$5N9'5R:&QA\&$@)7,`
M4W9A<F$`3&5I=&$`4V5N9&$@<VME>71I`$5F;FES_G+A\'5R`%1I;`!%;F1U
M<G9E:VIA`%-K;_!A(&5F;FES_G+A\`!(=NUT;&ES=&D`5FGP:&5N9VD`8N9T
M:0!L;VMI\`!K;&EK:V'P:0!F<N$`4/-S=&UA<'!A`$YA9FX`96YG:6YN`&7P
M80!S=&%F<V5T;FEN9V%R=FEL;&$`<W1A9G-E=&YI;F=A<G9I;&QU<@!3=F%R
M=&QI<W1I(/YI;FX`2';M=&QI<W1I(/YI;FX`````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VET7TE4+P``````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S8S`#`Q-S0V,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O
M:71?250O3$-?34534T%'15,O````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-C,`,#(Q,C0V`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+VQO8V%L92]I=%])5"],0U]-15-304=%4R]I;7`N;6\`````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#,R,3$S,``Q,#0Q-S,V,C<V,P`P,C(S-C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````"A!0``'````"0M``"+!P``+%H```````!8>```"@```%EX```*````
M9'@```H```!O>```#P```'IX```*````BG@```0```"5>```!````)IX```!
M````GW@``!D```"A>```#````+MX``!(````R'@``"L````1>0``1````#UY
M```G````@GD``!<```"J>0``"P```,)Y```H````SGD``!4```#W>0``,@``
M``UZ```+````0'H``"D```!,>@``,@```'9Z```0````J7H``!0```"Z>@``
M$````,]Z```F````X'H``"<````'>P``)@```"][```<````5GL```H```!S
M>P``#0```'Y[```G````C'L``"````"T>P``#@```-5[```7````Y'L``"(`
M``#\>P``-0```!]\```&````57P``!L```!<?```+@```'A\```W````IWP`
M`'P```#??```;````%Q]```<````R7T``!T```#F?0``#P````1^```8````
M%'X``$4````M?@``*````'-^``!!````G'X``"0```#>?@``#@````-_```/
M````$G\```X````B?P``#@```#%_```(````0'\```X```!)?P``#@```%A_
M```S````9W\``%$```";?P``"@```.U_```%````^'\```,```#^?P``"0``
M``*````)````#(````X````6@```"````"6````0````+H````\````_@```
M"@```$^````'````6H````,```!B@```#P```&:````)````=H````T```"`
M@```#P```(Z````/````GH````@```"N@```"@```+>````7````PH````@`
M``#:@```'````..````9`````($``"@````:@0``'@```$.!```:````8H$`
M`"P```!]@0``(````*J!```R````RX$```P```#^@0``#0````N"```.````
M&8(```,````H@@``!0```"R"```*````,H(```,````]@@``%P```$&"```*
M````68(```\```!D@@``#@```'2"``!.````@X(``%````#2@@``0P```".#
M``!"````9X,``#````"J@P``%P```-N#```7````\X,``!,````+A```#P``
M`!^$```C````+X0```8```!3A```%P```%J$``!1````<H0``#4```#$A```
M!@```/J$```(`````84``!$````*A0``"P```!R%```5````*(4``",````^
MA0``+P```&*%```%````DH4``#````"8A0``2````,F%```A````$H8``#L`
M```TA@``.P```'"&```\````K(8``"L```#IA@``,0```!6'```[````1X<`
M`#D```"#AP``-0```+V'```,````\X<```D`````B````P````J(```Y````
M#H@```8```!(B```-0```$^(```.````A8@``$D```"4B```,P```-Z(```*
M````$HD``"T````=B0``"P```$N)```G````5XD``"P```!_B0``*@```*R)
M```E````UXD```D```#]B0``"0````>*```&````$8H``"P````8B@``4```
M`$6*```8````EHH``!$```"OB@``$0```,&*```+````TXH```H```#?B@``
M"@```.J*```(````]8H```,```#^B@``.`````*+```)````.XL```X```!%
MBP``"@```%2+``!%````7XL```0```"EBP``!````*J+```)````KXL```8`
M``"YBP``!P```,"+```$````R(L``"<```#-BP``!@```/6+```#````_(L`
M`!,`````C```"````!2,```(````'8P```0````FC```*@```"N,```K````
M5HP``%,```""C```!@```-:,```.````W8P``!4```#LC```/@````*-```'
M````08T``!4```!)C0```@```%^-```/````8HT```T```!RC0``#P```("-
M```-````D(T```8```">C0``#````*6-```&````LHT```H```"YC0``#0``
M`,2-``!B````THT``"<````UC@``5````%V.``!?````LHX```0````2CP``
M%@```!>/```.````+H\``!P````]CP``#P```%J/```S````:H\``"@```">
MCP``#@```,>/```5````UH\``!$```#LCP``'````/Z/```U````&Y```$4`
M``!1D```$@```)>0```*````JI````\```"UD```1P```,60```?````#9$`
M`#,````MD0``*P```&&1```=````C9$``%$```"KD0``$0```/V1```Q````
M#Y(``$````!!D@``.````(*2```%````NY(```P```#!D@``$0```,Z2```-
M````X)(```8```#ND@``!@```/62```(````_)(```P````%DP``%````!*3
M```/````)Y,``!$````WDP``!0```$F3```1````3Y,```P```!ADP``!0``
M`&Z3```&````=),```<```![DP``#0```(.3```'````D9,```D```"9DP``
M%P```*.3```F````NY,``$\```#BDP``"@```#*4```,````/90``"4```!*
ME```'P```'"4```0````D)0``!L```"AE```"````+V4```;````QI0``!X`
M``#BE```7`````&5```N````7I4```0```"-E0``#@```)*5```.````H94`
M``<```"PE0``#@```+B5```D````QY4``#8```#LE0``*0```".6``!!````
M398``#H```"/E@``'P```,J6```@````ZI8``"4````+EP``!P```#&7```&
M````.9<```T```!`EP``"P```$Z7```-````6I<``!H```!HEP``$````(.7
M```=````E)<``!D```"REP``70```,R7```3````*I@```P````^F```#@``
M`$N8```/````6I@``!0```!JF```$P```'^8```-````DY@``#D```"AF```
M'````-N8```H````^)@```,````AF0``#0```"69```"````,YD```4````V
MF0``$````#R9```$````39D```T```!2F0```P```&"9```.````9)D```@`
M``!SF0``#P```'R9```(````C)D```T```"5F0``&0```*.9```:````O9D`
M``D```#8F0``!@```.*9```4````Z9D``!,```#^F0``$````!*:```,````
M(YH```L````PF@``#0```#R:```B````2IH``"L```!MF@``-````)F:```S
M````SIH```H````"FP``&`````V;```9````)IL``!8```!`FP``!P```%>;
M```0````7YL``!P```!PFP``'````(V;```,````JIL``"8```"WFP``"@``
M`-Z;```4````Z9L```L```#^FP``!P````J<```+````$IP```D````>G```
M#P```"B<```)````.)P```<```!"G```%@```$J<```/````89P``"T```!Q
MG```&@```)^<```H````NIP```L```#CG```#````.^<```C````_)P```T`
M```@G0``)@```"Z=```J````59T``"````"`G0``0P```*&=```$````Y9T`
M`!H```#JG0``)P````6>```2````+9X``"````!`G@``+P```&&>```7````
MD9X```4```"IG@``#````*^>```.````O)X```X```#+G@``*P```-J>```.
M````!I\```H````5GP``#````""?```*````+9\``!`````XGP``%P```$F?
M```.````89\``!$```!PGP``%P```(*?```3````FI\``!8```"NGP``.```
M`,6?```3````_I\```T````2H```'0```""@```/````/J```!(```!.H```
M#````&&@```9````;J```!P```"(H```&````*6@```3````OJ````,```#2
MH```%0```-:@```+````[*```!,```#XH```$`````RA```I````':$``"P`
M``!'H0``*````'2A```U````G:$```4```#3H0``&````-FA```0````\J$`
M``\````#H@``$````!.B```/````)*(```\````TH@``#````$2B```/````
M4:(```<```!AH@``!@```&FB```*````<*(``!(```![H@``#0```(ZB```,
M````G*(``$,```"IH@``/0```.VB```(````*Z,``!,````THP``!````$BC
M```(````3:,```H```!6HP``#````&&C```*````;J,``"````!YHP``'P``
M`)JC```+````NJ,```L```#&HP``"````-*C```$````VZ,```P```#@HP``
M#@```.VC```/````_*,``"4````,I```*@```#*D```'````7:0``!(```!E
MI```!````'BD```*````?:0``!(```"(I```"@```)ND```-````IJ0```4`
M``"TI```"````+JD```0````PZ0```X```#4I```'@```..D```:`````J4`
M``H````=I0``)@```"BE```5````3Z4``$0```!EI0``!0```*JE```'````
ML*4```P```"XI0``"````,6E```&````SJ4```<```#5I0``"````-VE```1
M````YJ4``!D```#XI0``"````!*F```"````&Z8```8````>I@``%0```"6F
M```/````.Z8``!$```!+I@``&@```%VF```%````>*8```0```!^I@``#```
M`(.F```)````D*8``!````":I@``"0```*NF```)````M:8```0```"_I@``
M!0```,2F```:````RJ8```\```#EI@``&0```/6F```.````#Z<``"(````>
MIP``#0```$&G```-````3Z<```P```!=IP``%````&JG```&````?Z<``!$`
M``"&IP``!````)BG```$````G:<``!<```"BIP``!P```+JG```&````PJ<`
M``0```#)IP``"@```,ZG```G````V:<```8````!J```%0````BH```,````
M'J@``!$````KJ```!````#VH```-````0J@```<```!0J```!0```%BH```%
M````7J@``!(```!DJ```"P```'>H```G````@Z@``"D```"KJ```)````-6H
M```F````^J@``"@````AJ0``"````$JI```$````4ZD``!P```!8J0``#0``
M`'6I```G````@ZD``!L```"KJ0``#````,>I```6````U*D```4```#KJ0``
M$@```/&I```*````!*H```\````/J@``$````!^J```&````,*H```H````W
MJ@``#@```$*J```)````4:H```H```!;J@``!@```&:J```&````;:H```H`
M``!TJ@``#@```'^J```.````CJH``!\```"=J@``'@```+VJ```1````W*H`
M`!4```#NJ@``$0````2K```0````%JL``",````GJP``#P```$NK```)````
M6ZL``!(```!EJP``'0```'BK```2````EJL``!````"IJP``"@```+JK```1
M````Q:L```4```#7JP``,0```-VK```D````#ZP``!`````TK```!````$6L
M```+````2JP``!P```!6K```(P```'.L```B````EZP```8```"ZK```%```
M`,&L```,````UJP```P```#CK```#P```/"L```5`````*T``"D````6K0``
M*@```$"M```F````:ZT``"<```"2K0``&0```+JM```1````U*T``!(```#F
MK0``$P```/FM```4````#:X``!8````BK@``%P```#FN```0````4:X``!$`
M``!BK@``$P```'2N```K````B*X```\```"TK@``%@```,2N```4````VZX`
M``L```#PK@``&@```/RN```A````%Z\``"`````YKP``"0```%JO```&````
M9*\```8```!KKP``!P```'*O```6````>J\```0```"1KP``!````):O```'
M````FZ\```(```"CKP``"@```*:O```N````L:\```<```#@KP``"````.BO
M```1````\:\```D````#L```#`````VP```-````&K````X````HL```%@``
M`#>P```1````3K````8```!@L```!````&>P```1````;+````H```!^L```
M(0```(FP```0````J[```'P```"\L```%0```#FQ```:````3[$```H```!J
ML0``#@```'6Q```,````A+$```\```"1L0``"````*&Q```&````JK$```P`
M``"QL0``!P```+ZQ```%````QK$```L```#,L0```P```-BQ```,````W+$`
M`!,```#IL0``!@```/VQ```"````!+(```X````'L@``!````!:R```*````
M&[(```T````FL@``'P```#2R```'````5+(``"(```!<L@``:````'^R```%
M````Z+(```8```#NL@``(P```/6R```E````&;,```@````_LP``-P```$BS
M```B````@+,``!$```"CLP``#P```+6S```/````Q;,``!<```#5LP``)@``
M`.VS```F````%+0```,````[M```%````#^T```3````5+0``!````!HM```
M#0```'FT```.````A[0``!8```"6M```!P```*VT```0````M;0```L```#&
MM```!P```-*T```3````VK0```P```#NM```#P```/NT```.````"[4```P`
M```:M0``#@```">U```/````-K4```T```!&M0``#P```%2U```/````9+4`
M``\```!TM0``(````(2U```N````I;4``!H```#4M0``)@```.^U```+````
M%K8```T````BM@``&@```#"V``!*````2[8```8```"6M@``!@```)VV```"
M````I+8```L```"GM@``"````+.V```&````O+8```H```##M@``#````,ZV
M```$````V[8```D```#@M@``#@```.JV```'````^;8``!4````!MP``"@``
M`!>W```)````(K<``!`````LMP``$@```#VW```$````4+<```0```!5MP``
M(@```%JW```,````?;<```<```"*MP``!0```)*W```6````F+<```,```"O
MMP``#````+.W```*````P+<```@```#+MP``%P```-2W```,````[+<```0`
M``#YMP``"@```/ZW```$````";@```P````.N```"0```!NX```%````);@`
M``(````KN```%````"ZX```-````0[@``!(```!1N```"P```&2X```;````
M<+@``!4```",N```+````**X```3````S[@``"H```#CN```&0````ZY```<
M````*+D``!\```!%N0``%````&6Y```@````>KD``!,```";N0``)0```*^Y
M```D````U;D```@```#ZN0``"`````.Z```D````#+H``!(````QN@``#@``
M`$2Z```K````4[H``!(```!_N@``10```)*Z``!!````V+H```\````:NP``
M!````"J[```&````+[L```L````VNP``"0```$*[```-````3+L```P```!:
MNP``%P```&>[```4````?[L``!8```"4NP``!P```*N[```A````L[L```4`
M``#5NP``"````-N[```1````Y+L``$0```#VNP``/````#N\```.````>+P`
M``(```"'O````@```(J\```.````C;P```<```"<O```!@```*2\```,````
MJ[P``",```"XO```,@```-R\```S````#[T``!0```!#O0``#0```%B]```?
M````9KT``!0```"&O0``!P```)N]```.````H[T```H```"RO0``'0```+V]
M```%````V[T``!$```#AO0``$P```/.]```-````![X``!$````5O@```P``
M`">^```3````*[X```L````_O@``-````$N^```+````@+X``!0```",O@``
M/@```*&^```3````X+X``#0```#TO@``,0```"F_```2````6[\``!````!N
MOP``&````'^_```C````F+\``"(```"\OP``)P```-^_``!6````!\```$T`
M``!>P```"````*S````-````M<````0```##P```'````,C````-````Y<``
M`"<```#SP```&P```!O!```,````-\$```T```!$P0``(@```%+!```A````
M=<$```<```"7P0``"@```)_!```2````JL$``"$```"]P0``"P```-_!```<
M````Z\$``!@````(P@``"````"'"```)````*L(```H````TP@``%0```#_"
M```%````5<(```0```!;P@``$````&#"```'````<<(``!X```!YP@``*```
M`)C"```*````P<(``!H```#,P@``+0```.?"```(````%<,``!0````>PP``
M+````#/#```G````8,,``"H```"(PP``!@```+/#```&````NL,``#$```#!
MPP``'````//#```T````$,0``#0```!%Q```*0```'K$```G````I,0``"@`
M``#,Q```&@```/7$``!V````$,4``'D```"'Q0``'0````'&```I````'\8`
M`!T```!)Q@``+@```&?&``!7````EL8``#8```#NQ@``+````"7'```L````
M4L<``#$```!_QP``+@```+''```%````X,<``!D```#FQP``&0````#(```K
M````&L@``"$```!&R```"````&C(```7````<<@```H```")R```!P```)3(
M```A````G,@``!````"^R```#0```,_(```%````W<@```X```#CR```"```
M`/+(```'````^\@``!,````#R0``"````!?)```V````(,D``#<```!7R0``
M"0```(_)```O````F<D```X```#)R0``#0```-C)```/````YLD``!8```#V
MR0``/@````W*```G````3,H```4```!TR@``)P```'K*```6````HLH```0`
M``"YR@``"@```+[*```)````R<H```X```#3R@``'@```.+*```$`````<L`
M`#(````&RP``10```#G+```+````?\L```X```"+RP``#@```)K+```)````
MJ<L```@```"SRP``$````+S+```5````S<L``!,```#CRP``!P```/?+```5
M````_\L``!0````5S```"P```"K,```'````-LP``",````^S```%@```&+,
M```/````><P```X```")S```*@```)C,```&````P\P```P```#*S```&```
M`-?,```1````\,P```L````"S0``#0````[-```*````',T```L````GS0``
M#P```#/-```0````0\T``"X```!4S0``.@```(/-```.````OLT```T```#-
MS0``!0```-O-```+````X<T```P```#MS0``#0```/K-```-````",X```X`
M```6S@``#0```"7.```@````,\X``"<```!4S@``*P```'S.```(````J,X`
M``H```"QS@``!@```+S.```2````P\X```X```#6S@``%P```.7.```>````
M_<X``!8````<SP``%````#//```%````2,\```X```!.SP``$P```%W/```:
M````<<\```<```",SP``!@```)3/```3````F\\``!0```"OSP``$0```,3/
M``!+````UL\``!0````BT```&````#?0```'````4-````4```!8T```$@``
M`%[0```$````<=````X```!VT```#@```(70```%````E-````4```":T```
M`P```*#0```&````I-```!8```"KT```-P```,+0```.````^M```!<````)
MT0``00```"'1```Q````8]$``!,```"5T0``&P```*G1```J````Q=$``%$`
M``#PT0``4````$+2```-````D](```@```"AT@```@```*K2```0````K=(`
M``@```"^T@``!````,?2```'````S-(``#(```#4T@``"@````?3```,````
M$M,```L````?TP``!P```"O3```6````,],``%(```!*TP``.@```)W3```@
M````V-,```\```#YTP``%P````G4```Y````(=0```8```!;U```"0```&+4
M```.````;-0```X```![U```!````(K4```&````C]0``!8```"6U```#0``
M`*W4```.````N]0``!4```#*U```$@```.#4```/````\]0``!0````#U0``
M0P```!C5```*````7-4``#4```!GU0``$0```)W5```+````K]4``&D```"[
MU0``&@```"76```7````0-8``!L```!8U@``&@```'36```7````C]8``!L`
M``"GU@``&0```,/6```?````W=8``!<```#]U@``'````!77```7````,M<`
M``P```!*UP``$P```%?7```(````:]<``!````!TUP``$0```(77```)````
ME]<```8```"AUP``'0```*C7```'````QM<``$,```#.UP``,@```!+8```_
M````1=@``#<```"%V```5P```+W8```?````%=D```T````UV0``$@```$/9
M```I````5MD```@```"`V0``#0```(G9```M````E]D``#\```#%V0``.0``
M``7:``!&````/]H```0```"&V@``$````(O:```,````G-H``!0```"IV@``
M'0```+[:```1````W-H``#T```#NV@``)0```"S;```@````4ML``"<```!S
MVP``&@```)O;```?````MML``!T```#6VP``*````/3;```/````'=P``"4`
M```MW```(````%/<```D````=-P``"0```"9W```)0```+[<```'````Y-P`
M``T```#LW```#````/K<```%````!]T```4````-W0``!````!/=```0````
M&-T```P````IW0``#P```#;=```,````1MT``!0```!3W0``%````&C=```/
M````?=T```X```"-W0``$@```)S=```'````K]T```0```"WW0``#````+S=
M```7````R=T``!(```#AW0``#0```/3=```4`````MX``"\````7W@``"@``
M`$?>```,````4MX```D```!?W@``"````&G>```%````<MX```8```!XW@``
M$````'_>```1````D-X```(```"BW@``"````*7>```'````KMX```T```"V
MW@``!@```,3>```6````R]X```D```#BW@``!P```.S>```H````]-X``!4`
M```=WP``"P```#/?```'````/]\```@```!'WP``!P```%#?```'````6-\`
M``X```!@WP``"0```&_?```&````>=\```@```"`WP``"P```(G?```'````
ME=\``!D```"=WP``&@```+??```@````TM\```<```#SWP``"````/O?```0
M````!.```!`````5X```!P```";@```%````+N````4````TX```%````#K@
M```+````3^````T```!;X```%P```&G@```:````@>```!0```"<X```+P``
M`+'@```)````X>````H```#KX```!P```/;@```"````_N```!\````!X0``
M,0```"'A```Q````4^$``"(```"%X0``(````*CA```=````R>$``%T```#G
MX0``+0```$7B```S````<^(``$L```"GX@``+````//B```E````(.,``!X`
M``!&XP``=0```&7C```^````V^,``$(````:Y```/0```%WD```I````F^0`
M`"D```#%Y```,0```._D```C````(>4``$\```!%Y0``-@```)7E```^````
MS.4``#`````+Y@``(````#SF```_````7>8``#0```"=Y@``'0```-+F```>
M````\.8``&`````/YP``-````'#G```\````I><``#@```#BYP``(0```!OH
M```?````/>@``"0```!=Z```*````(+H```K````J^@``"(```#7Z```*0``
M`/KH```7````).D``"D````\Z0``(````&;I```R````A^D``!P```"ZZ0``
M+@```-?I```X````!NH``"<````_Z@``/````&?J```F````I.H``#X```#+
MZ@``/@````KK``!'````2>L``%,```"1ZP``5P```.7K``!5````/>P``$8`
M``"3[```+P```-KL``!5````"NT``"````!@[0``*P```('M```J````K>T`
M`#X```#8[0``4@```!?N```R````:NX``"L```"=[@``*@```,GN```F````
M].X``"P````;[P``3@```$CO```P````E^\``!T```#([P``(P```.;O```+
M````"O```#L````6\```)P```%+P``!)````>O```%4```#$\```+P```!KQ
M```R````2O$``"L```!]\0``*0```*GQ```/````T_$``"T```#C\0``,0``
M`!'R```+````0_(```<```!/\@``!P```%?R```-````7_(```L```!M\@``
M!0```'GR```"````?_(```H```""\@``!0```(WR```(````D_(```,```"<
M\@``%P```*#R```,````N/(```T```#%\@```@```-/R```#````UO(```0`
M``#:\@``&````-_R```*````^/(``!,````#\P``"````!?S```)````(/,`
M`!8````J\P``#````$'S```'````3O,``!\```!6\P``!0```';S```,````
M?/,```\```")\P``$0```)GS```:````J_,``!$```#&\P``!P```-CS```&
M````X/,```L```#G\P``&@```//S```&````#O0```D````5]```'0```!_T
M```8````/?0```L```!6]```%P```&+T```&````>O0``!,```"!]```$0``
M`)7T```>````I_0```0```#&]```$P```,OT```1````W_0``#(```#Q]```
M"````"3U```)````+?4```H````W]0``%````$+U```(````5_4```@```!@
M]0``#P```&GU```.````>?4``!````"(]0``"0```)GU```)````H_4```0`
M``"M]0``!P```++U```2````NO4``"8```#-]0``&0```/3U```8````#O8`
M``L````G]@``#@```#/V```9````0O8```H```!<]@``$P```&?V```G````
M>_8```D```"C]@``#P```*WV```H````O?8```\```#F]@``%````/;V```*
M````"_<```P````6]P```@```"/W```0````)O<```,````W]P``!P```#OW
M```-````0_<```L```!1]P``+P```%WW```@````C?<``!P```"N]P``6@``
M`,OW```)````)O@```4````P^```$@```#;X```*````2?@```8```!4^```
M!0```%OX```&````8?@```(```!H^````P```&OX```,````;_@``#L```!\
M^```)P```+CX```A````X/@``"0````"^0``'0```"?Y```Z````1?D``$(`
M``"`^0``&0```,/Y```7````W?D``!D```#U^0``*@````_Z```K````.OH`
M`"8```!F^@``2P```(WZ``!.````V?H``"<````H^P``*0```%#[```A````
M>OL``"@```"<^P``*P```,7[```=````\?L``"D````/_```)@```#G\```M
M````8/P``"4```"._```*````+3\```I````W?P``"(````'_0``/0```"K]
M``!!````:/T``"@```"J_0``+````-/]```2`````/X``!,````3_@``$```
M`"?^```)````./X``!P```!"_@``$````%_^```/````</X```X```"`_@``
M<P```(_^``!``````_\``"L```!$_P``%P```'#_```J````B/\``#0```"S
M_P``%@```.C_```/````__\``"@````/``$`%````#@``0`/````30`!``P`
M``!=``$`$````&H``0`3````>P`!``\```"/``$`!````)\``0`*````I``!
M``,```"O``$`"0```+,``0`'````O0`!``L```#%``$`"````-$``0`'````
MV@`!``4```#B``$`"0```.@``0`4````\@`!``8````'`0$`"`````X!`0`/
M````%P$!``\````G`0$`"````#<!`0`,````0`$!``8```!-`0$`"0```%0!
M`0`+````7@$!``\```!J`0$`!@```'H!`0`'````@0$!``T```")`0$`%```
M`)<!`0`'````K`$!``,```"T`0$`"0```+@!`0`&````P@$!``P```#)`0$`
M"@```-8!`0`*````X0$!``\```#L`0$`!````/P!`0`9`````0(!``,````;
M`@$`!@```!\"`0`,````)@(!``0````S`@$`!````#@"`0`"````/0(!``<`
M``!``@$`!@```$@"`0`&````3P(!``X```!6`@$`#P```&4"`0`&````=0(!
M`"(```!\`@$`"P```)\"`0`.````JP(!``X```"Z`@$`70$``,D"`0`)````
M)P0!``H````Q!`$`"````#P$`0`4````100!``H```!:!`$`!@```&4$`0`$
M````;`0!``$```!Q!`$`&0```',$`0`*````C00!`$4```"8!`$`+P```-X$
M`0!!````#@4!`"L```!0!0$`&0```'P%`0`/````E@4!`"@```"F!0$`$```
M`,\%`0`U````X`4!``H````6!@$`*````"$&`0`O````2@8!`!````!Z!@$`
M%````(L&`0`0````H`8!`"\```"Q!@$`'@```.$&`0`N``````<!`!<````O
M!P$`"0```$<'`0`/````40<!`#(```!A!P$`(0```)0'`0`-````M@<!`!<`
M``#$!P$`(@```-P'`0`R````_P<!``8````R"`$`&P```#D(`0`]````50@!
M`$0```"3"`$`E0```-@(`0"5````;@D!`!X````$"@$`&P```",*`0`)````
M/PH!`!8```!)"@$`30```&`*`0`L````K@H!`$D```#;"@$`)P```"4+`0`-
M````30L!``X```!;"P$`#@```&H+`0`.````>0L!``8```"("P$`#0```(\+
M`0`-````G0L!`#T```"K"P$`1````.D+`0`)````+@P!``4````X#`$``0``
M`#X,`0`%````0`P!``8```!&#`$`$0```$T,`0`)````7PP!`!````!I#`$`
M$@```'H,`0`,````C0P!``8```":#`$`"````*$,`0`5````J@P!``T```#`
M#`$`%0```,X,`0`9````Y`P!`!@```#^#`$`#0```!<-`0`1````)0T!`!H`
M```W#0$`#P```%(-`0`<````8@T!`"P```!_#0$`-0```*P-`0`@````X@T!
M`"`````##@$`0````"0.`0`I````90X!`$@```"/#@$`!P```-@.`0`(````
MX`X!``\```#I#@$`"@```/D.`0`,````!`\!``T````1#P$`!0```!\/`0`<
M````)0\!``X```!"#P$`$````%$/`0`4````8@\!`$L```!W#P$`7````,,/
M`0!-````(!`!`$T```!N$`$`+````+P0`0`7````Z1`!`!L````!$0$`%P``
M`!T1`0`2````-1$!`"4```!($0$`!@```&X1`0`9````=1$!`%````"/$0$`
M0````.`1`0`(````(1(!``@````J$@$`'````#,2`0`,````4!(!`!<```!=
M$@$`+P```'42`0`]````I1(!``8```#C$@$`,@```.H2`0!)````'1,!`!L`
M``!G$P$`0````(,3`0`Z````Q!,!`#L```#_$P$`,````#L4`0`H````;!0!
M`#L```"5%`$`/0```-$4`0`Y````#Q4!`!````!)%0$`"0```%H5`0`&````
M9!4!`#P```!K%0$`!@```*@5`0`Y````KQ4!``X```#I%0$`6````/@5`0`]
M````418!``@```"/%@$`,````)@6`0`(````R18!`#0```#2%@$`-0````<7
M`0`P````/1<!`#````!N%P$`#````)\7`0`*````K!<!``8```"W%P$`,```
M`+X7`0!;````[Q<!`!4```!+&`$`$@```&$8`0`5````=!@!``H```"*&`$`
M"@```)48`0`&````H!@!``@```"G&`$``P```+`8`0`Z````M!@!``H```#O
M&`$`$P```/H8`0`.````#AD!`$L````=&0$`!0```&D9`0`)````;QD!``D`
M``!Y&0$`!P```(,9`0`'````BQD!``@```"3&0$`.````)P9`0`%````U1D!
M``,```#;&0$`&0```-\9`0`1````^1D!``H````+&@$`!0```!8:`0`R````
M'!H!`#,```!/&@$`80```(,:`0`'````Y1H!`!$```#M&@$`'````/\:`0!(
M````'!L!``<```!E&P$`%0```&T;`0`"````@QL!`!4```"&&P$`#P```)P;
M`0`5````K!L!``T```#"&P$`!@```-`;`0`*````UQL!``@```#B&P$`#```
M`.L;`0`/````^!L!`$@````('`$`-````%$<`0!T````AAP!`'0```#['`$`
M!````'`=`0`6````=1T!`!$```",'0$`(P```)X=`0`7````PAT!`$P```#:
M'0$`-````"<>`0`.````7!X!`!H```!K'@$`%````(8>`0`D````FQX!`#H`
M``#`'@$`20```/L>`0`2````11\!``X```!8'P$`(P```&<?`0!0````BQ\!
M`",```#<'P$`/0`````@`0`U````/B`!`",```!T(`$`1@```)@@`0`5````
MWR`!`#,```#U(`$`1P```"DA`0`O````<2$!``8```"A(0$`$@```*@A`0`6
M````NR$!``\```#2(0$`!@```.(A`0`&````Z2$!``8```#P(0$`#@```/<A
M`0`:````!B(!`!$````A(@$`$@```#,B`0`&````1B(!`!8```!-(@$`$```
M`&0B`0`(````=2(!``@```!^(@$`!P```(<B`0`0````CR(!``@```"@(@$`
M"@```*DB`0`:````M"(!`#8```#/(@$`7@````8C`0`*````92,!``P```!P
M(P$`)P```'TC`0`B````I2,!`!$```#((P$`'0```-HC`0`(````^",!`!T`
M```!)`$`(0```!\D`0`Z````020!`"8```!\)`$`!0```*,D`0`2````J20!
M`!,```"\)`$`"````-`D`0`.````V20!`",```#H)`$`2P````PE`0`S````
M6"4!`#T```",)0$`.0```,HE`0`H````!"8!`"D````M)@$`/````%<F`0`%
M````E"8!``0```":)@$`#0```)\F`0`+````K28!`!0```"Y)@$`'0```,XF
M`0`0````["8!`"@```#])@$`'P```"8G`0!F````1B<!`!0```"M)P$`"P``
M`,(G`0`0````SB<!``T```#?)P$`%0```.TG`0`4`````R@!``T````8*`$`
M.@```"8H`0`A````82@!`#4```"#*`$`!@```+DH`0`0````P"@!``(```#1
M*`$`!0```-0H`0`0````VB@!``0```#K*`$`#0```/`H`0`&````_B@!`!``
M```%*0$`"````!8I`0`/````'RD!``D````O*0$`$0```#DI`0`B````2RD!
M`"0```!N*0$`"````),I`0`'````G"D!`!H```"D*0$`%@```+\I`0`3````
MUBD!``T```#J*0$`#0```/@I`0`/````!BH!`!<````6*@$`+0```"XJ`0`\
M````7"H!`#P```"9*@$`"P```-8J`0`>````XBH!`!L````!*P$`&````!TK
M`0`)````-BL!`!(```!`*P$`&````%,K`0`E````;"L!``X```"2*P$`+P``
M`*$K`0`+````T2L!`!0```#=*P$`"P```/(K`0`(````_BL!``@````'+`$`
M$````!`L`0`?````(2P!``@```!!+`$`"@```$HL`0`>````52P!`!<```!T
M+`$`)0```(PL`0`>````LBP!`#$```#1+`$`#`````,M`0`/````$"T!`#D`
M```@+0$`#0```%HM`0`K````:"T!`"4```"4+0$`'````+HM`0!.````URT!
M``4````F+@$`&P```"PN`0`L````2"X!`!,```!U+@$`(P```(DN`0`S````
MK2X!`!@```#A+@$`!0```/HN`0`.`````"\!``\````/+P$`$````!\O`0`L
M````,"\!`!8```!=+P$`#P```'0O`0`/````A"\!``\```"4+P$`$0```*0O
M`0`8````MB\!`!@```#/+P$`%0```.@O`0`8````_B\!`!H````7,`$`(```
M`#(P`0!"````4S`!`!P```"6,`$`#P```+,P`0`>````PS`!`!(```#B,`$`
M&@```/4P`0`/````$#$!`!D````@,0$`'````#HQ`0`:````5S$!`!,```!R
M,0$`!````(8Q`0`9````BS$!``X```"E,0$`%````+0Q`0`7````R3$!`"P`
M``#A,0$`-P````XR`0`Q````1C(!`#D```!X,@$`!@```+(R`0`E````N3(!
M``X```#?,@$`#0```.XR`0`/````_#(!``T````,,P$`#0```!HS`0`+````
M*#,!`!(````T,P$`"@```$<S`0`'````4C,!``T```!:,P$`&0```&@S`0`0
M````@C,!``P```"3,P$`/@```*`S`0`\````WS,!``D````<-`$`*0```"8T
M`0`&````4#0!``@```!7-`$`#0```&`T`0`/````;C0!``T```!^-`$`*P``
M`(PT`0`A````N#0!`!,```#:-`$`$````.XT`0`'````_S0!``0````'-0$`
M#`````PU`0`.````&34!`!,````H-0$`,P```#PU`0`Q````<#4!``8```"B
M-0$`$0```*DU`0`%````NS4!``L```#!-0$`&@```,TU`0`,````Z#4!``\`
M``#U-0$`!0````4V`0`(````"S8!`!,````4-@$`$0```"@V`0`D````.C8!
M`"````!?-@$`"P```(`V`0`J````C#8!`"````"W-@$`10```-@V`0`&````
M'C<!``@````E-P$`#````"XW`0`(````.S<!``4```!$-P$`!P```$HW`0`(
M````4C<!`!,```!;-P$`&0```&\W`0`'````B3<!``,```"1-P$`!@```)4W
M`0`<````G#<!`!@```"Y-P$`&0```-(W`0`D````[#<!``,````1.`$``@``
M`!4X`0`,````&#@!``0````E.`$`%````"HX`0`*````/S@!``T```!*.`$`
M"````%@X`0`%````83@!`!H```!G.`$`$````((X`0`9````DS@!``\```"M
M.`$`*````+TX`0`0````YC@!``X```#W.`$`#P````8Y`0`6````%CD!``8`
M```M.0$`#P```#0Y`0`#````1#D!``0```!(.0$`&P```$TY`0`,````:3D!
M``<```!V.0$`!0```'XY`0`(````A#D!`!\```"-.0$`"````*TY`0`L````
MMCD!`!(```#C.0$`&0```/8Y`0`$````$#H!``T````5.@$`"0```",Z`0`&
M````+3H!``4````T.@$`%P```#HZ`0`,````4CH!`"````!?.@$`&@```(`Z
M`0`?````FSH!`!@```"[.@$`+P```-0Z`0`'````!#L!``0````,.P$`&@``
M`!$[`0`,````+#L!`"8````Y.P$`&P```&`[`0`/````?#L!`!D```",.P$`
M!0```*8[`0`8````K#L!``H```#%.P$`#P```-`[`0`3````X#L!``8```#T
M.P$`#````/L[`0`2````"#P!``P````;/`$`#````"@\`0`(````-3P!``<`
M```^/`$`#@```$8\`0`2````53P!`!(```!H/`$`)````'L\`0`E````H#P!
M`!<```#&/`$`&P```-X\`0`5````^CP!`!$````0/0$`)P```"(]`0`1````
M2CT!``H```!</0$`$P```&<]`0`<````>ST!`!,```"8/0$`$````*P]`0`+
M````O3T!`!@```#)/0$`#P```.(]`0`\````\CT!`"X````O/@$`$@```%X^
M`0`$````<3X!``P```!V/@$`)0```(,^`0`J````J3X!`"P```#4/@$`"```
M``$_`0`;````"C\!`!4````F/P$`$0```#P_`0`:````3C\!`!@```!I/P$`
M,````((_`0`T````LS\!`"T```#H/P$`,0```!9``0`A````2$`!`!0```!J
M0`$`%0```']``0`5````E4`!`!<```"K0`$`&````,-``0`9````W$`!`!,`
M``#V0`$`%`````I!`0`;````'T$!`"8````[00$`$@```&)!`0`@````=4$!
M`!8```"600$`#P```*U!`0`0````O4$!`"8```#.00$`)P```/5!`0`*````
M'4(!``<````H0@$`!P```#!"`0`'````.$(!`!@```!`0@$`!@```%E"`0`&
M````8$(!``P```!G0@$``@```'1"`0`0````=T(!`"\```"(0@$`"````+A"
M`0`&````P4(!`!L```#(0@$`#0```.1"`0`-````\D(!`!4`````0P$`$@``
M`!9#`0`8````*4,!`!,```!"0P$`!P```%9#`0`(````7D,!`!8```!G0P$`
M#P```'Y#`0`L````CD,!`!T```"[0P$`>P```-E#`0`7````540!`"H```!M
M1`$`"@```)A$`0`8````HT0!``P```"\1`$`#````,E$`0`%````UD0!``4`
M``#<1`$`"P```.)$`0`$````[D0!``4```#S1`$`*````/E$`0`%````(D4!
M``X````H10$`%P```#=%`0`&````3T4!``(```!610$`#@```%E%`0`%````
M:$4!`!@```!N10$`$@```(=%`0`I````FD4!`!````#$10$`)@```-5%`0!6
M````_$4!``4```!31@$`!P```%E&`0`W````848!`#L```"91@$`$@```-5&
M`0`V````Z$8!`"8````?1P$`&0```$9'`0`4````8$<!`!0```!U1P$`(0``
M`(I'`0`P````K$<!`#````#=1P$`!@````Y(`0`6````%4@!`!4````L2`$`
M$0```$)(`0`1````5$@!`!8```!F2`$`(````'U(`0`&````GD@!``X```"E
M2`$`#````+1(`0`)````P4@!`!8```#+2`$`#@```.)(`0`0````\4@!`!$`
M```"20$`%````!1)`0`6````*4D!`!D```!`20$`&@```%I)`0`(````=4D!
M``\```!^20$`$````(Y)`0`E````GTD!`#0```#%20$`'P```/I)`0!#````
M&DH!``H```!>2@$`#0```&E*`0`6````=TH!`"4```".2@$`!P```+1*`0`&
M````O$H!``,```##2@$`"P```,=*`0`(````TTH!``@```#<2@$`#````.5*
M`0`5````\DH!``8````(2P$`"@````]+`0`4````&DL!``D````O2P$`%0``
M`#E+`0`+````3TL!``L```!;2P$`%P```&=+`0`7````?TL!``0```"72P$`
M!````)Q+`0`G````H4L!`!$```#)2P$`!````-M+`0`#````X$L!`!0```#D
M2P$`!0```/E+`0`/````_TL!``X````/3`$`"P```!Y,`0`=````*DP!``X`
M``!(3`$`!P```%=,`0`1````7TP!``H```!Q3`$`%````'Q,`0`1````D4P!
M``4```"C3`$``@```*E,`0`:````K$P!`!$```#'3`$`&@```-E,`0`0````
M]$P!`!T````%30$`%P```"--`0`H````.TT!`!T```!D30$`+0```()-`0`C
M````L$T!`"<```#430$`+````/Q-`0`A````*4X!`"@```!+3@$`(````'1.
M`0`E````E4X!`"8```"[3@$`#@```.).`0`+````\4X!`#8```#]3@$`&P``
M`#1/`0`3````4$\!`#8```!D3P$`&@```)M/`0!4````MD\!`$X````+4`$`
M$````%I0`0`'````:U`!``<```!S4`$`#0```'M0`0`)````B5`!``X```"3
M4`$`#0```*)0`0`;````L%`!`!8```#,4`$`%P```.-0`0`-````^U`!`"X`
M```)40$`!````#A1`0`(````/5$!`!$```!&40$`2````%A1`0!:````H5$!
M``\```#\40$``@````Q2`0`!````#U(!``P````14@$`!P```!Y2`0`'````
M)E(!``\````N4@$`-0```#Y2`0`L````=%(!`#H```"A4@$`%@```-Q2`0`/
M````\U(!`"H````#4P$`%@```"Y3`0`'````15,!``X```!-4P$`"0```%Q3
M`0`4````9E,!``4```![4P$`$@```(%3`0`6````E%,!``T```"K4P$`&0``
M`+E3`0`#````TU,!`!0```#74P$`#````.Q3`0!+````^5,!``L```!%5`$`
M%P```%%4`0!!````:50!`!@```"K5`$`0P```,14`0`_````"%4!`!,```!(
M50$`$P```%Q5`0`:````<%4!`"D```"+50$`*@```+55`0`F````X%4!`%0`
M```'5@$`3````%Q6`0`*````J58!`!(```"T5@$`!````,=6`0`<````S%8!
M``P```#I5@$`)P```/96`0`;````'E<!``\````Z5P$`#P```$I7`0`G````
M6E<!`"<```""5P$`"````*I7`0`-````LU<!`!8```#!5P$`)0```-A7`0`.
M````_E<!`"D````-6`$`(@```#=8`0`(````6E@!``D```!C6`$`"@```&U8
M`0`A````>%@!``<```":6`$`"````*)8`0`8````JU@!``L```#$6`$`)```
M`-!8`0`N````]5@!``@````D60$`'````"U9`0`[````2ED!``D```"&60$`
M%@```)!9`0`H````IUD!`"T```#060$`,````/Y9`0`$````+UH!``4````T
M6@$`,P```#I:`0`H````;EH!`"<```"76@$`(P```+]:`0`I````XUH!`"@`
M```-6P$`)P```#9;`0`8````7EL!`'(```!W6P$`=0```.I;`0`:````8%P!
M`"X```![7`$`'0```*I<`0`L````R%P!`$X```#U7`$`-````$1=`0`G````
M>5T!`"T```"A70$`,@```,]=`0`J`````EX!``@````M7@$`(@```#9>`0`@
M````65X!`"\```!Z7@$`(P```*I>`0`)````SEX!`!X```#87@$`"P```/=>
M`0`)`````U\!`"D````-7P$`%````#=?`0`1````3%\!``8```!>7P$`$0``
M`&5?`0`(````=U\!``@```"`7P$`&````(E?`0`(````HE\!`#T```"K7P$`
M/0```.E?`0`+````)V`!`"D````S8`$`$@```%U@`0`1````<&`!`!(```""
M8`$`(````)5@`0`_````MF`!`"\```#V8`$`!P```"9A`0`G````+F$!`!D`
M``!680$`!P```'!A`0`.````>&$!``T```"'80$`#P```)5A`0`A````I6$!
M``4```#'80$`0P```,UA`0!.````$6(!``L```!@8@$`#````&QB`0`2````
M>6(!``P```",8@$`"P```)EB`0`L````I6(!`#````#28@$`0@````-C`0`(
M````1F,!`"$```!/8P$`)````'%C`0`8````EF,!``0```"O8P$`*````+1C
M`0`@````W6,!`!@```#^8P$`#0```!=D`0`J````)60!``<```!09`$`#@``
M`%AD`0`>````9V0!`!4```"&9`$`#````)QD`0`3````J60!``H```"]9`$`
M#@```,AD`0`2````UV0!`!,```#J9`$`-0```/YD`0!7````-&4!`!,```",
M90$`$````*!E`0`(````L64!`!````"Z90$`$````,ME`0`1````W&4!`!,`
M``#N90$`%`````)F`0`1````%V8!`"4````I9@$`,P```$]F`0`V````@V8!
M``H```"Z9@$`#````,5F`0`)````TF8!`!4```#<9@$`$0```/)F`0`@````
M!&<!`"(````E9P$`(0```$AG`0`6````:F<!``8```"!9P$`$````(AG`0`7
M````F6<!`"$```"Q9P$`"0```--G`0`(````W6<!`!@```#F9P$`%P```/]G
M`0`2````%V@!`%0````J:`$`&0```']H`0`8````F6@!``<```"R:`$`!@``
M`+IH`0`8````P6@!``4```#::`$`%````.!H`0`4````]6@!``8````*:0$`
M!@```!%I`0`&````&&D!``8````?:0$`%P```"9I`0!#````/FD!``X```""
M:0$`&@```)%I`0!*````K&D!`#\```#W:0$`%@```#=J`0`=````3FH!`"X`
M``!L:@$`5````)MJ`0!9````\&H!``P```!*:P$`"````%=K`0`#````8&L!
M`!0```!D:P$`#P```'EK`0`%````B6L!``@```"/:P$`-0```)AK`0`+````
MSFL!``T```#::P$`#P```.AK`0`.````^&L!`!X````';`$`6@```"9L`0`Y
M````@6P!`"P```"[;`$`%````.AL`0`=````_6P!`#T````;;0$`!P```%EM
M`0`*````86T!`!$```!L;0$`%P```'YM`0`%````EFT!``D```"<;0$`&@``
M`*9M`0`2````P6T!`!(```#4;0$`(````.=M`0`?````"&X!`!,````H;@$`
M(0```#QN`0!$````7FX!``\```"C;@$`20```+-N`0`4````_6X!`!(````2
M;P$`<P```"5O`0`B````F6\!`!\```"\;P$`&P```-QO`0`C````^&\!`!L`
M```<<`$`(P```#AP`0`?````7'`!`",```!\<`$`%0```*!P`0`?````MG`!
M`!H```#6<`$`#P```/%P`0`<`````7$!``D````><0$`&0```"AQ`0`9````
M0G$!``D```!<<0$`!@```&9Q`0`B````;7$!``<```"0<0$`2````)AQ`0`[
M````X7$!`#\````=<@$`+P```%UR`0!>````C7(!`"T```#L<@$`$@```!IS
M`0`;````+7,!`#````!)<P$`"````'IS`0`/````@W,!`"T```"3<P$`1```
M`,%S`0`W````!G0!`$<````^=`$`!@```(9T`0`<````C70!`!````"J=`$`
M'````+MT`0`E````V'0!`!D```#^=`$`.P```!AU`0`B````5'4!`$(```!W
M=0$`+0```+IU`0`;````Z'4!`"\````$=@$`(0```#1V`0`K````5G8!`!(`
M``""=@$`(0```)5V`0`;````MW8!`"````#3=@$`*@```/1V`0`R````'W<!
M``H```!2=P$`$@```%UW`0`0````<'<!``8```"!=P$`"P```(AW`0`*````
ME'<!`!(```"?=P$`%0```+)W`0`1````R'<!``\```#:=P$`$P```.IW`0`?
M````_G<!`!(````>>`$`$0```#%X`0`7````0W@!``H```!;>`$`!````&9X
M`0`.````:W@!`!(```!Z>`$`$@```(UX`0`5````H'@!`"````"V>`$`,```
M`-=X`0`,````"'D!``X````5>0$`"P```"1Y`0`(````,'D!``4````Y>0$`
M!@```#]Y`0`0````1GD!`!X```!7>0$``P```'9Y`0`(````>GD!``<```"#
M>0$`#0```(MY`0`%````F7D!`!@```"?>0$`"P```+AY`0`(````Q'D!`!H`
M``#->0$`%P```.AY`0`,`````'H!``\````->@$`!````!UZ`0`(````(GH!
M``0````K>@$`#0```#!Z`0`&````/GH!``@```!%>@$`"@```$YZ`0`+````
M67H!``@```!E>@$`'P```&YZ`0`7````CGH!`!T```"F>@$`"@```,1Z`0`*
M````SWH!`!$```#:>@$`$0```.QZ`0`-````_GH!``@````,>P$`!@```!5[
M`0`8````''L!``L````U>P$`#0```$%[`0`8````3WL!`"4```!H>P$`&P``
M`(Y[`0`W````JGL!``H```#B>P$`$@```.U[`0`-`````'P!``,````.?`$`
M(````!)\`0`S````,WP!`"L```!G?`$`(@```)-\`0`?````MGP!`!\```#6
M?`$`<````/9\`0`M````9WT!`"H```"5?0$`2````,!]`0`M````"7X!`"P`
M```W?@$`&P```&1^`0![````@'X!`#P```#\?@$`3P```#E_`0!%````B7\!
M`"T```#/?P$`,````/U_`0`L````+H`!`",```!;@`$`2P```'^``0`_````
MRX`!`$4````+@0$`-0```%&!`0`=````AX$!`$,```"E@0$`-P```.F!`0`?
M````(8(!`"````!!@@$`<@```&*"`0`W````U8(!`#(````-@P$`+P```$"#
M`0`B````<(,!`"````"3@P$`)@```+2#`0`I````VX,!`#<````%A`$`'P``
M`#V$`0`O````780!`!,```"-A`$`+````*&$`0`>````SH0!`#8```#MA`$`
M&P```"2%`0`S````0(4!`#X```!TA0$`*````+.%`0!$````W(4!`#`````A
MA@$`4P```%*&`0!I````IH8!`&4````0AP$`80```':'`0!K````V(<!`&D`
M``!$B`$`60```*Z(`0!"````"(D!`&\```!+B0$`*````+N)`0`I````Y(D!
M`"L````.B@$`8````#J*`0!?````FXH!`#L```#[B@$`,P```#>+`0`J````
M:XL!`"\```"6BP$`-0```,:+`0!7````_(L!`#D```!4C`$`(````(Z,`0`I
M````KXP!``T```#9C`$`10```.>,`0`L````+8T!`%$```!:C0$`/````*R-
M`0`K````Z8T!`"X````5C@$`'@```$2.`0`;````8XX!`!(```!_C@$`.@``
M`)*.`0!%````S8X!`!T````3CP$`!0```#&/`0`&````-X\!`!(````^CP$`
M"P```%&/`0`&````78\!``$```!DCP$`"P```&:/`0`$````<H\!``8```!W
MCP$`!````'Z/`0`;````@X\!`!````"?CP$`$0```+"/`0`#````PH\!``,`
M``#&CP$`!````,J/`0`:````SX\!``P```#JCP$`%0```/>/`0`(````#9`!
M``H````6D`$`%````"&0`0`4````-I`!``H```!+D`$`(P```%:0`0`%````
M>I`!`!````"`D`$`%````)&0`0`8````II`!`!D```"_D`$`$````-F0`0`*
M````ZI`!``D```#UD`$`#@```/^0`0`H````#I$!``@````WD0$`"P```$"1
M`0`C````3)$!`"$```!PD0$`#P```)*1`0`B````HI$!``8```#%D0$`$0``
M`,R1`0`=````WI$!`"H```#\D0$`!@```">2`0`6````+I(!`!0```!%D@$`
M.````%J2`0`+````DY(!``P```"?D@$`#````*R2`0`3````N9(!``<```#-
MD@$`"0```-62`0`2````WY(!``P```#RD@$`%0```/^2`0`*````%9,!``H`
M```@DP$`"@```"N3`0`-````-I,!`!D```!$DP$`,0```%Z3`0`?````D),!
M`"````"PDP$`$````-&3`0`4````XI,!`"$```#WDP$`$0```!F4`0`;````
M*Y0!`#8```!'E`$`$P```'Z4`0`2````DI0!`#8```"EE`$`$0```-R4`0`<
M````[I0!``H````+E0$`#````!:5`0`#````(Y4!`!`````GE0$``P```#B5
M`0`)````/)4!``X```!&E0$`#0```%65`0`P````8Y4!`!X```"4E0$`(```
M`+.5`0!;````U)4!``P````PE@$`"0```#V6`0`6````1Y8!``\```!>E@$`
M"@```&Z6`0`&````>98!``<```"`E@$``@```(B6`0`"````BY8!`!(```".
ME@$`,P```*&6`0`O````U98!`"(````%EP$`*P```"B7`0`>````5)<!`$``
M``!SEP$`00```+27`0`6````]I<!`!<````-F`$`'@```"68`0`K````1)@!
M`"L```!PF`$`)0```)R8`0!9````PI@!`%P````<F0$`,P```'F9`0`I````
MK9D!`"0```#7F0$`*````/R9`0`K````)9H!`"$```!1F@$`*@```'.:`0`J
M````GIH!`"P```#)F@$`*P```/::`0`K````(IL!`"\```!.FP$`)@```'Z;
M`0!0````I9L!`$\```#VFP$`(@```$:<`0`T````:9P!`!,```">G`$`$P``
M`+*<`0`3````QIP!``L```#:G`$`(P```.:<`0`5````"IT!`!8````@G0$`
M#P```#>=`0"'````1YT!`$H```#/G0$`*0```!J>`0`;````1)X!`#L```!@
MG@$`/````)R>`0`3````V9X!``P```#MG@$`,@```/J>`0`5````+9\!``T`
M``!#GP$`$````%&?`0`G````8I\!`!<```"*GP$`$````**?`0`$````LY\!
M``L```"XGP$``@```,2?`0`)````QY\!``@```#1GP$`#0```-J?`0`)````
MZ)\!``<```#RGP$`!@```/J?`0`)`````:`!`!L````+H`$`$````">@`0`.
M````.*`!`!<```!'H`$`$@```%^@`0`(````<J`!``D```![H`$`!P```(6@
M`0`)````C:`!``P```"7H`$`$````*2@`0`)````M:`!``@```"_H`$`$```
M`,B@`0`8````V:`!``H```#RH`$``@```/V@`0`)`````*$!``<````*H0$`
M&0```!*A`0`-````+*$!``@````ZH0$`#````$.A`0`%````4*$!`!@```!6
MH0$`!@```&^A`0`&````=J$!`!@```!]H0$`!````):A`0`'````FZ$!``$`
M``"CH0$`"````*6A`0`&````KJ$!``L```"UH0$`%````,&A`0`4````UJ$!
M``@```#KH0$`*P```/2A`0`+````(*(!`!8````LH@$`%````$.B`0`!````
MVP```%L#``#3````W@0```````"H`P``;P,``/`$```A!```GP4```8!```E
M`0``O0(``#8$``!<`P``N@(``%@%```+`````````$`!````````````````
M``#``@```````(,#````````````````````````3P4``#T$``!5`P``````
M``D`````````FP$``&\````.!0``P0,``#(#``"1`P``/@(``&L%````````
M&@4```````!'!```=@```-$$``"U!```F@(``$L!````````N0$`````````
M`````````,4``````````````!($``#[`P```````$8#``"D`P```````&0"
M`````````````'\"````````:0(``&(#``#C`@``#04``/@$``!5````&P$`
M`%8```"2!```````````````````1@4```````!*!0``^`$``)P$``":!```
MQP0``+\!`````````````',#``#N`P``>@$``.$`````````'`(``-\$``!D
M`0``9`,```````!W`P``````````````````O`,``'("```:`P``&0```&P%
M``#5!```]P(```````#O````K`,````````3!```=@,``,H"``"9`0``:@$`
M`#0!``!;!```VP0``````````````````.T!``!9`0``Q@$````````!!0``
M``````````#Z`@``L0(```````#,`0``@0(``/X"``!$`@``BP(``$L"````
M````L@(``-4"``!"!0``$P(``!\````+`P````````````"'````80(`````
M```-````?P$```````#@````5@,``-,!``#-`P````````````#_````A@(`
M`(`#`````````````#,$``!S!`````````````!E`0``%@```,(#``"H`@``
MO`$``,X#``#V`P```````/H$``#4`0``7`(``&0```"(````L``````````B
M````_0,````````-`P```````/\#``#:`@```````)$$``!Q`@``5@$``(T%
M``````````````<!``"5`@``U@0````````D````8P,````````F!```-@``
M`(H"``"%!0``:@```!X$```O`0``7P0```````#+!```3P$``(0"``!X`@``
M\0,``-L!```*!0``G00```$$``#Q`````````$8`````````%P0``/`"``"^
M`````````$P"`````````````-T"```?!0```````#P%```W````[P(``)D"
M`````````````,<!``"&````*P,``#@````O````\P```-(!```+!0``````
M`-<```#3!`````0``"T%``#F````=P(````````A!0``.`4``$P$````````
MAP,```4````<````Q0$``.$#``!I`0``-`4``+($````````BP,```````!K
M`@```````"D```!H!````````#T#```D`@``BP```.0```#``0```````(P`
M```3`0```````+X"``"A`P``IP(``,@$``#-`0``8````!P#````````!04`
M``<#``!,`P``U`(``/X!```X`@```````(P"``!:`P``5`4```````!U!0``
M[P$``$D!``";`@``*@```!X```!/`@``)P4``!X!``"D````*P0````````(
M!0``E0$``$$!````````.0````````!"`0``7P(``.H!``#<`P``EP(`````
M``"3!0```````/4!```(!```)P(``((```#&!```=0,``$P%````````````
M`$H#````````@0,```````"F`0``@`(``#$%``#C````D@,``%L!````````
MV```````````````W@$````````Z!0``<````$<%```,`@``,0(``,H!``"*
M````U@$``(8#``"(`@``J`$``"4$``!3````F@,```````!\!0``40``````
M````````"@(``(\````&!0``<04```````"U`@``[@$`````````````4P4`
M``````!R````*`4``,X`````````0@0``*0"````````E`4```````"E`@``
M@@$``)T#````````F@4``(P%````````PP(`````````````M@$``%X#````
M````K@0``+@$````````8@0``,0"``":`````````&P"``#F!```^@$``%D#
M```"`P``_@0``'0#``"G````````````````````[0,``),#``""!```N0(`
M`(H!````````D@$```4"```9`@```````&\!````````%````(<!````````
M`````-,#```H`@``^P$``&@```">!0````````````#=`P``OP,``"T````R
M`0``+P0``+T#``!%`@```````#@!``"F!```A@4``.`$``"#`0``;0,``.L"
M```1`0``'P0``(L%```#`P``Z0$``%(!`````````````,0!````````D`0`
M`$@#```]`0``\0(``*(````8`P````````````#_`0````````8````Q````
M5P,``&X`````````)@$``)`#```C!0``B0(``%T````7!0``!@(``&$#``#0
M!```C00````````;`P``'`$``-0``````````````.(!``#D`0``GP(``'4$
M``#J!```````````````````$@(``*,!````````````````````````4P$`
M`$<!``#6`````0$``#,#``"-````M@0``*X"``"K!````````#8#````````
M#`4``*<#```Z!```=0````````#]`@```````%("```@!```N@,``+<"```L
M!0```````)(%````````40$``&,$``"Q!```$@```,0#`````````````$,%
M``!I````/P````````#/!```$````````````````````#D#```[`P``````
M`"<!``!!!```0````(8$``#O!```'00``"P```#,!````````),!````````
MF0```!(!```W!````````+T`````````2P4````````D!```-P$```````"+
M`0``.00``*`$````````7`$```H`````````5@(``'P``````````````!8!
M``#5````/`(```````#E`@```````'X%``!0!0``B`,``%````"?!```)`4`
M``````#^`P```````)8!```I!0``Z00``(4```"I`0``8`$``&<%``!M!0``
M``(`````````````O`0```````!!`@``A0(``+$!``#^````!0,``"H"```0
M!0``<`$``'0```"8`0```````'X```````````````````"Z!```````````
M````````=P0```````"9!```@````,\"``"2`@``YP0``"L%````````````
M`,$```"5`P``_`0```````#Z`P``&P0``(,```"$`0``Y00``*T$``"4`0``
MK0$``&\"``!+````-P4``*($``"@`0``4@4```````!.!```I@,```````#I
M````=@(```````#R!```,`$````````/!```0@```+<$```D`0``QP(``&8$
M``#8`@``````````````````5P0`````````````=0$``+4!````````LP(`
M`+\$````````V0```/P`````````3@(``+@```"W`P``9`0``"P#```5!0``
M>0,```T"`````P``G0(``(0```"[!````````-\#`````````````%H%````
M`````@4``,8```"'!````````,H#``##`P``#`0``)L$``!X`P``N`$``)4`
M```;!0``10```#D"``!^!```^P(`````````````<`(``+H!```.`0``'@(`
M```````S`0````````D%```$`````````+(#```2`P``P0$``/````!Z`@``
M(@(`````````````[`(``#0#``!)`@```````/L$``!3`P```````/0```#H
M!```B@0````````V!0``XP,``)@```!8`0``6P4``"X"```)`@``@`0``&`%
M````````E`,``*T"``"I!```+P4``'H$``"A`````````'\%````````````
M`#D%``!T`@```````-(```#[````^0`````````=````"`,```<%````````
M$00``.`"``"\````)@4``"T"``#D`@``;0```!4!``!L`0``<P$``$8$``"E
M`P``-P,``#4#``"$!0``D`(``!`#````````9@$```````#I`P```````'D!
M``!'`P`````````````G````T`,``(`%````````CP,``%`"````````````
M``("``#?`````````.X"```0`0``H0$``"$#```(`@``(0```%$"````````
M_0```'0$``#:`0```````-4#``"J`@```````"`%``#>`````P```&4$``"S
M`P```````"8```!/!```Z@(``)X$```5`@```````"X!````````@P4``&,"
M```_!````````/`!````````)`,``&H"``"_`@``M@,```````!E`P``````
M``H#``!9`@``LP```)T%``!-!0``S````#`#```1!0``50$```````!5!0``
M,`4```````!W`````````*`#````````X0$``(@!``#F`@``,`0`````````
M````#P,``#0````X`P``*@4``.P$``"?`0```@$``-H#``#M````NP```#0$
M``".`0``>P0``$0```#_!```K@,``!@"```F`P`````````````1`P``@P0`
M`+D$````````3@4``%T%```N`P```````'T"````````[0(``$X#``#T`@``
M5`,``,("``#'`P``KP````H$``"@`@```````&8#````````*P```)X!````
M````Y`,``(\%``"^`0``20````````"1`0``+00``/P#``!]!0```````.`#
M``"N`0``Z````!8%```I!````````&D$```I`@``7@```'T```!D!0``````
M`(T"``!7`0``8@$```````!F`@``!00````````F`@``M````($%````````
M%`0``$@!````````J0,``````````````````/<#``#7`P``1`$``-($```#
M!0``%`(``!@!```_`P``(@0``,<``````````````%0````N!0```````$H$
M``!2!```:P``````````````(P(``)H!``!Y!0`````````````6`P``A`,`
M`$T"``"%`0``T@,``)$%``#+`@``O@0``%X"``#-`@``80$``-L"```"````
M+`(```````#C`0``^@```%(```#Q`0``I`$``*L#``!>!```````````````
M````B@,`````````````"P0``)8%``"9`P``R0,``.@"``!C````AP(`````
M``#L`P```````,P#``")`P``=P$```````"U`P``ZP0``/0!````````'0,`
M``````"S!```!`(``&@!``#1````R@````````"/`@``600``-("````````
M`````&T"``!Y!```<@4``'X#```8!```MP$``+$```!_!```Y@$``&`"````
M````Q@(```````!X`````````&$```#"`0``.@,``/D$````````L`0``"X`
M``"W````U0$``)T```#*!`````````````"[`0``G`4```````!#`@``L`,`
M``````#8`P``J0(``"`!`````````````'(!``#\`0``````````````````
M``````````!^`0``4@,``$\```!:!```70(`````````````Z`$``)P!``"E
M`0``L`$``$4!``!%!````````+D#``#E````````````````!0```````-P`
M````````PP````````"T`@``$P```)$```!;````+`$``+8````\`P``,0,`
M`*,#``#W`0``P````*8"```9!0```````$D%``">`@``J0```.<!``#X`P``
MOP```/D#````````<0$``)8#````````&P(``*P!```T`@```````$T$```"
M!```Z@,``"@!````````D````/@"``!)`P``:`,``%<%``"F`````````%4"
M``!#````U@,``!0#``!N!````````*L"``"C````00,```````"T`0``R```
M`/0#```A`0```````(D```!N`@``O`(```````##!```,00``&P```"4`@``
M(`,``(X"``````````````````#"````KP$```````!#`P```0(````````^
M`P``E`0``#\%```7`P``/@4``!<!``".!```S@$``'L````C!````````$8!
M``!K`0```````#4$``!G````8@````````!6!0```````",```">`P``P`,`
M`,4$``!G`0``>P$``.T$````````!`,``.(#``"(!```+@0```L!``#=````
M;0$``'\```#E`0``K````#@$``#/````'`4```````"[`@``]0````````#+
M````"00```````"J````G````#8!``#@`0`````````````=`@``I`0``!H$
M```=`0``,P(``&X%``#S`@``I00``*`````\!```$P4``"(%```*`0``````
M``4!``#F`P``C0$````````&`P```````(D!```P`@``.P$```````!F!0``
M^``````````Y`0``&@(````!``!J!0``_P(``/<$``!-````RP$`````````
M````Z@```$H"``#R`@``#0$````````?`P``B`4``$@$````````J@0``#P`
M````````<`,``&$%```E`@``D`$``/,$``!X!0``IP$```P!````````F`(`
M`,\!`````````````*P"``!G`@``#00``/P"``!K`P``H00``"P$````````
M904``*`%```G!```<0```'L%``""`@``%0````````#.`@``I0````````"B
M`P``800```````#B````6````,$"`````````````)\#``#;`P``#P$`````
M``!\`@``3P,``,@!``!$!````````.<`````````!P```-D#``#+`P``,@(`
M`.L!``#V`````````'8!````````W0$```0!``"3!```?`$``-@$``#E`P``
M`````'P#``""!0``90(``/0$``"K`0``"`````````#N!`````````````"N
M````$`(``'P$````````%`$``(,"``!P!0``[`$``'4"``#/`P``$0(``-X"
M``"6````%@0``!H!``",!```2P0``'\#``##`0```````$(#``"7````#P4`
M``````!O!```V0(```````#K````````````````````\`,``(X#``#L````
M````````````````7`0``%0$``"B`@```P0``'T$``"5!0``8`0`````````
M`````````*L```#:!```W`0``!X%``!R!`````````````#B!```\00``(4#
M````````T0(``%$#``!!!0```````)L#```?`0``G`,``",#``!N`P``K0``
M```````#`@``P00``'H#```[!0``$`0```````#3`@``E@0`````````````
MS0```-H`````````*`0``#T"````````%`4``+8"``"&`0``8@(```````#U
M!`````````\"``"?````6`,``'`$``"]`0``6P(``(`!``````````````8$
M````````)04``%X!``!V!```-04``)0`````````104`````````````AP4`
M`*,"``!R`P``F`4```````!-`P``J````-\!`````````````#L"``!E````
M5`(````````7`@``L@```)@$``!&`@``>P(``#P!```S!0``D0(``%$%````
M````<P4``'L#````````&`4```D#````````C0,``#<"````````````````
M``"Q`P```````$P```")!```7P,``.X````H````70$``%<"```O`P``CP$`
M``,!``!G`P``<00``-$!``"6`@``Q`0``+@#``"3`@``1P(```X```!T!0``
M^0(``&L$```M`0``:0,``'T#````````=P4``-P"``!!```````````````B
M`0``G`(``#L$`````````````-<$````````"0$```````#1`P``2P,``+L#
M````````0`,``($$`````````````'T!```@`````````/,!```I`P``.@$`
M`"H!``#V`@``70,```````#)````-0```.$$``"G!```!P0```P#``!O!0``
M`````'H````]````W@,`````````````5@0``"L!````````#@0``.$"``"$
M!```S00``$`$``"T`P```````&X!```:````*@0``%`$``!(````M`0``"$"
M`````````````,4#``!9!0`````````````6`@````````L"````````<P``
M`"4#```>`P``&`````````"M`P``&00```````#?`@```````.0$``!:`@``
M8P4```````#4`P``````````````````O@,`````````````;`,``'D"``#U
M`P```````#L``````````````$H!```_`@```````&T$```J`P``:`(```\`
M````````,P```$X!```Z`@````````````"O`@``]P```-`"``#0`0``G0$`
M`$@"``#O`P``,0$``(D%``"B`0``L@$``%0!``!X`0````````````!C`0``
M`````#X`````````-0(``",!``#.!```YP(```````!(!0``@@,``"@#````
M````8@4``"(#````````6`(``$D$``"!`0``$@4``*H!``#%`@```````-P!
M``#7`0```````$T!`````````````&P$```'`@``4P0``%P%```R````7```
M`$,$``#R`0``J@,``-````!0`0```````)@#``"Z```````````````Z````
M,@4``!<```!@`P``YP,```````"Y`````````)X`````````/04``/,#````
M`````````(X```#9!```10,``$0#``#=!```U@(``*$%```1`````````$`%
M````````400``$0%``"7`0``=`$``&@%``#$````\@```+`"````````>`0`
M`*P$``!``@``P`0``"D!``"3````BP0``+4```!S`@``'04``(P!```9`0``
M6@$``/8!```!`P``3`$```X"````````/@$``)L%``!?`0``9@```/T!``".
M!0``4`,``-@!``#K`P``0P$``$("````````>0````````!.````A00``#8"
M``#,`@````````````!?````CP0```````";`````````!D#````````````
M`#\!``!J!```#@,``'8%``!>!0``R0$``*\$```E````$P,``%@$```(`0``
MLP$```````!J`P``2@```/T$``!Z!0```````/4"```5!```'`0``%\%``"7
M!```R`(```````#9`0``F04``+T$``",`P````````0$```?`@``1P```)<#
M``!3`@``9P0``#4!``"0!0``X@(``,@#````````/@0```````!Q`P``````
M```````O`@``B@4````````5`P``60```*,$``#R`P``*P(``,D$``"7!0``
M#````*$"``#7`@``]@0``,D"``!=!```E00``'X"``"O`P```````%4$```G
M`P``^0$``%H```"X`@```````,8#``#"!```XP0``($````$!0``D@``````
M````````:04``#($`````````````"`"```M`P``&P````````#I`@``Z`,`
M``````#4!````````%<````P````J`0````@("`@("!4;SH@`"`@("!$871E
M.B``("`@($9R;VTZ(``@*$%C8V5S<VME>2`E<RD`(%-U8FIE8W0Z(``@870@
M`"!I;B``(P`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`"5D("5S(&%N9"`E
M<P`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@
M=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`E9"!M97-S86=E<R!H879E
M(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A
M;2X`)60@=&\@)60@;V8@)60@365S<V%G97,`)7,@+2!.;W1I8V4`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!497)M<R!O
M9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R
M('=A<R!N;W0@<F5N86UE9"X`)7,@870@)7,@)7,`)7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R(&)E:6YG(')E
M;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"X`)7,@:&%S(&%C8V5P
M=&5D+@`E<R!H87,@8V%N8V5L;&5D("5S+@`E<R!H87,@9&5C;&EN960N`"5S
M(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R
M97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N="!Y
M;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!H87,@=&5N=&%T:79E;'D@
M86-C97!T960N`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!R97%U97-T
M<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@<F5Q=65S=',@>6]U
M<B!P<F5S96YC92!A="`E<RX`)7,@=&\@)7,@;V8@)7,`)7,@=VES:&5S('1O
M(&%M;65N9"`E<RX`)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S
M+@`E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N
M(&%B;W5T("5S+@`E<SH@)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I
M`"A!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N
M+BD`*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M
M<&]S92!S8W)E96XN*0`H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A
M9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA
M;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE
M9"XI`"A396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@
M;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N
M('=I;&P@3D]4(&)E(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN
M9R!/2R`J`"H@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN
M9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`,2!M97-S86=E(&AA
M<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2X`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86T@
M=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`,2!M97-S86=E(&AA<R!B
M965N(')E<&]R=&5D(&%S('-P86TN`#$P,"!C:&%R86-T97)S`#$P,#`@8VAA
M<F%C=&5R<P`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R
M<P`R-3`@8VAA<F%C=&5R<P`U,#`@8VAA<F%C=&5R<P!!(&QA<F=E(&EM86=E
M(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92X`02!M97-S
M86=E('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO
M=&EF:6-A=&EO;B!F<F]M('1H92!R96-I<&EE;G0N`$%-(%-H;W=E<G,`04TO
M4$T`04Y$`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97!T(')E<75E<W0`06-C
M97!T960`06-C;W5N="!087-S=V]R9`!!8V-O=6YT)W,@;F%M93H`06-C;W5N
M=&EN9P!!8W1I;VYS`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($AE<F4Z`$%D
M9"!.97<@1W)O=7``061D(&$@;F5W('5S97(Z`$%D9"!N97<@;65M8F5R<P!!
M9&0@<&%I<@!!9&0@<V]U<F-E`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D
M9"!U<V5R`$%D9&5D("(E<R(@87,@86X@871T86-H;65N="X`061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B
M92!V:65W960@)7,N`$%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<P!!
M9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@
M9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&UE<W-A9V4@
M97)R;W(@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL
M<R!C86X@8F4@=FEE=V5D("5S+@!!9&1R97-S($)O;VL`061D<F5S<R!";V]K
M<P!!9&UI;FES=')A=&EO;@!!9',`06QI9VX`06QI9VYM96YT.@!!;&P`06QL
M($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO
M;G,`06QL(&9O=7(@<VED97,`06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I
M;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8
M(&9I;&4Z`$%L;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R
M('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L
M;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@
M;VQD('=I;&P@8F4@9&5L971E9"X`06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N`$%L
M;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M86EL8F]X
M/P!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D
M<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;'1E
M<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.@!!;'=A>7,`06QW87ES
M('-A=F4@871T86-H;65N=',`06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E
M;7!T:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V
M97(@<V%I9#H@`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A
M=&EN9R!T:&4@;F5W('1A<VLN`$%N<W=E<@!!;G-W97)E9`!!;G-W97)E9"!M
M97-S86=E<P!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\`07!P;'D@9FEL=&5R
M(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\`07!R:6P`07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_
M`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER
M/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD960A*0!!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@9&\@=&AI<S\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E
M<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T
M92!T:&ES(&%T=&%C:&UE;G0_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E
M;7!T>2!T:&ES(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M
M<'1Y('EO=7(@=')A<V@@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO
M8V5N=#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE
M<W-A9V4@87,@<W!A;3\`07)R:79A;"!4:6UE`$%S8V5N9&EN9P!!<VL`07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_`$%T=&%C:`!!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U
M8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/P!!='1A8VAE9"!&:6QE.@!!='1A
M8VAE9"!F:6QE("(E<R(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI
M;6ET<RX@1FEL92!.3U0@871T86-H960N`$%T=&%C:&5D(&ES(&$@<F5P;'D@
M=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+@!!='1A8VAM96YT`$%T
M=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP90!!
M='1A8VAM96YT<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T
M96YD965S`$%T=&5N=&EO;@!!=6=U<W0`075T:%]I;7`Z(%)E<75I<F5D($E-
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T;VUA=&EC86QL>2!S:&]W(&EM
M86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M
M>2!A9&1R97-S8F]O:S\`079A:6QA8FQE($%D9')E<W,@8F]O:W,Z`$%V86EL
M86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$)A8U]K('1O("5S`$)A
M8VL@=&\@)7,`0F%C:V=R;W5N9`!"87-E;&EN90!"8V,`0F5L;W<@:7,@=&AE
M(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S<V%G92X`
M0FQA8VML:7-T`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQO8VL@:6UA
M9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I9FEC
M86QL>2!R97%U97-T960_`$)O9'D`0F]L9`!";V]K;6%R:W,`0F]R9&5R`$)O
M<F1E<G,`0F]T:`!";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE
M<W-A9V4`0F]T=&]M`$--4P!#7V5L;"!0<F]P97)T:65S+BXN`$-?:&%R<V5T
M`$-A;&5N9&%R`$-A;&T`0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@
M;6%I;"!S97)V97(N`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA
M:6P@<V5R=F5R.B``0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O
M9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@;6%I
M;&)O>"X`0V%N8V5L`$-A;F-E;"!-97-S86=E`$-A;F-E;"!0<F]B;&5M(%)E
M<&]R=`!#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA;F5N=&QY
M(&1I<V-A<F0@:71S(&-O;G1E;G1S+@!#87!T:6]N`$-A=&5G;W)I97,@86YD
M($QA8F5L<P!#8P!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL
M('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96YT97(`0VAA:7(@4&5R<V]N
M`$-H86YG90!#:&%N9V4@06QL`$-H86YG92!&;VQD97(`0VAA;F=E(&1I<W!L
M87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@
M;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@87)E('-O<G1E9"X`0VAA
M;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N`$-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V4@=&AE(&YA
M;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H
M96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&%R`$-H
M87)A8W1E<G,@=&\@9&ES<&QA>3H`0VAE8U]K($QI;FLN+BX`0VAE8VL@1F]L
M9&5R*',I(&9O<B!.97<@36%I;`!#:&5C:R!?06QL+TYO;F4`0VAE8VL@86QL
M(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ`$-H
M96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\`0VAO;W-E
M($%C=&EO;CH`0VAO;W-E(&$@;6%I;"!S97)V97(Z`$-H;V]S92!A;B!A8W1I
M;VXZ`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E('1H92!A
M9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E<W-E<RX`0VAO
M;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N
M(&5X<&%N9&EN9R!A9&1R97-S97,N`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A
M<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R`E<R!T;R!C;VYV97)T('1H
M92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B<F]W<V5R(&-A;B!V
M:65W+@!#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@:6UA9V4N`$-L:6-K("5S
M('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#
M;&EC:R`E<R!T;R!V:65W(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N`$-L
M:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S`$-L:6-K(&]N(&]N92!O9B!Y
M;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L
M;"!F:65L9',@=&\@<V5A<F-H+@!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:R!T
M;R!3879E(%!'4"!0=6)L:6,@2V5Y(&EN('EO=7(@061D<F5S<R!B;V]K`$-L
M:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S
M86=E('1O('1H92!S96YD97(`0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL
M;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860`0VQO<V4`0VQO<V4@5VEN
M9&]W`$-L;W-E('1H:7,@=VEN9&]W`$-L;W-E9"!&;VQD97(`0VQO=61S`$-L
M;W5D>0!#;VQL87!S90!#;VQL87!S92!!;&P`0V]L;&%P<V4@06QL($9O;&1E
M<G,`0V]L;&%P<V4@1F]L9&5R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O
M;&]R($EN9&EC871O<CH@`$-O;&]R(%!I8VME<@!#;VQS.@!#;VUI8W,`0V]M
M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M<&QE=&5D`$-O;7!O<V4@
M86YO=&AE<B!M97-S86=E`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T
M92!W:6YD;W<_`$-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B
M>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92!F96%T=7)E*3\`
M0V]N9&ET:6]N<P!#;VYF:6=U<F4@)7,`0V]N9FEG=7)E(&AO=R!M97-S86=E
M<R!A<F4@9&ES<&QA>65D+@!#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO
M;G,N`$-O;F9I<FT@4&%S<W=O<F0`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I
M;&5D`$-O;G1I;G5E`$-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+@!#;VYT
M<F]L(%,O34E-12!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!W:&5N(&YE=R!M
M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T
M;R!N;W1I9GD@>6]U('=H96X@:70@87)R:79E<RX`0V]N=F5R="!T97AT=6%L
M(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/P!#;W!Y`$-O<'D@<V5L
M96-T:6]N`$-O<'D@=&\@9F]L9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`
M0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z("5S`$-O=6QD(&YO
M="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E
M<P!#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+@!#
M;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@
M35,M5$Y%1B!A='1A8VAM96YT+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q
M=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N`$-O=6QD(&YO="!R
M979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG
M=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+@!#;W5R<V5S`$-R96%T90!#<F5A=&4@1F]L9&5R`$-R96%T92!+97ES`$-R
M96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E871E
M(&$@;F5W(&]N90!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A
M=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@
M=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@
M9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&]R(%!E<FUI<W-I;VYS
M`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`
M0W5R<F5N="!A8V-E<W,@=&\@)7,`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R
M96YT('-T>6QE`$-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@;6%I
M;"!F<F]M(&]T:&5R(&%C8V]U;G1S+@!#=7-T;VUI>F4@:&]W('EO=2!S96YD
M(&UA:6PN`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RX`0W5T`$-U="!S96QE8W1I;VX`1$0`1&%T7V4`1&%T851R964@0G)O=W-E
M<@!$871E`$1A=&4@4F5C96EV960`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M
M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L:6YE9`!$969A=6QT($-O;&]R`$1E
M9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C
M=&EO;CH`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@)7,@4'5B;&EC($ME>0!$
M96QE=&4@0W5R<F5N="!+97ES`$1E;&5T92!&;VQD97(H<RD`1&5L971E($=R
M;W5P`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG
M(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F
M<F]M(')E;6]T92!S97)V97(_`$1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE
M;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(&]L9"!S96YT+6UA
M:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!R;W<`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D`$1E;&5T960@
M;65S<V%G97,`1&5L971E9"!T:&4@871T86-H;65N="`B)7,B+@!$96QE=&EN
M9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E;GD@<F5Q=65S=`!$96YY(')E<75E
M<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;@!$97-C96YD:6YG`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',`1&5V96QO<&UE
M;G0`1&5W(%!O:6YT`$1I;2!S:6=N871U<F5S/P!$:7)E8W1O<GD`1&ES<&QA
M>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P
M;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\`1&ES
M<&QA>2!I;B!";V1Y(&]F($UE<W-A9V4`1&ES<&QA>2!P;W`M=7`@;F]T:69I
M8V%T:6]N(&]F(&YE=R!M86EL/P!$:7-P;W-I=&EO;@!$;R!.3U0@;6%T8V@`
M1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1E
M;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$
M;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6X`1&\@
M>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\`1&]E<R!T:&4@9FER<W0@
M<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H
M:7,@8F]X.@!$;VYE`$1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T`$1O=VYL
M;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*0!$;W=N;&]A9"!&
M;VQD97(H<RD`1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%T`1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`
M1&]W;FQO860@:6X@+GII<"!&;W)M870`1')A9G0`1')A9G0@9F]L9&5R`$1R
M869T<R!F;VQD97(Z`$4M;6%I;"!!9&1R97-S`$524D]2.B!9;W5R(&UE<W-A
M9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`161I="!";&%C:VQI<W0`161I
M="!";&]C:P!%9&ET($9I;'1E<G,`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I
M;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@5VAI=&5L:7-T`$5D
M:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@
M>6]U<B!B;&%C:VQI<W0`161I="!Y;W5R(&9I;'1E<B!R=6QE<P!%9&ET('EO
M=7(@<')E9F5R96YC97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U
M;G1S+@!%9&ET('EO=7(@=VAI=&5L:7-T`$5M86EL($%D9')E<W,`16UP=&EE
M9"!A;&P@;65S<V%G97,@9G)O;2`E<RX`16UP='D@1F]L9&5R*',I`$5M<'1Y
M(%1R87-H(&9O;&1E<@!%;7!T>2!?5')A<V@`16YA8FQE(%!'4"!F=6YC=&EO
M;F%L:71Y/P!%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_`$5N86)L92!M
M97-S86=E('!R979I97=S/P!%;F-R7WEP=&EO;B!/<'1I;VYS`$5N9`!%;F0@
M9F]R=V%R9&5D(&UE<W-A9V4`16YD(&UE<W-A9V4`16YD(&UE<W-A9V4@9G)O
M;2`E<P!%;G1E<B!087-S<&AR87-E`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE
M=R!S96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE
M=R!T<F%S:"!F;VQD97(`16YT<GD@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('1H92!A9&1R97-S(&)O;VL`17)R;W(`17)R;W(@<V5N9&EN9R!R
M97!L>3H@)7,N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y(&AA;&8@:&]U
M<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD
M`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N9"!&;VQD97(`
M17AP86YD($YA;65S`$5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD
M;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\`17AP86YD('1H
M92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R
M<R!V:65W/P!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:7(`1F5B
M<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5T8V@@36%I;`!&971C
M:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!&971C:"!M97-S86=E<R!U
M<&]N(&QO9V=I;F<@;VX_`$9E=&-H;6%I;#H@`$9E=R!3:&]W97)S`$9I7VQT
M97)S`$9I;&4`1FEL92!-86YA9V5R`$9I;'1E<B!/<'1I;VYS`$9I;'1E<B!3
M971T:6YG<P!&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_
M`$9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!&
M:6QT97)S`$9I;'1E<G,@3D]4($%C=&EV90!&:6YD`$9I<G-T($AA;&8`1FER
M<W0@36%I;&)O>"!086=E`$9I<G-T(%!A9V4`1FER<W0@475A<G1E<@!&;&]A
M=`!&;U]R=V%R9`!&;VQD97(@3F%V:6=A=&]R`$9O;&1E<B!3=6UM87)Y`$9O
M;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+@!&;VQD97(@=7-E(&ES(&YO
M="!E;F%B;&5D+@!&;VYT($-O;&]R`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M870@
M;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S
M86=E<R!D871E9"!T;V1A>0!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&
M;W)T=6YE<P!&;W)U;7,`1F]R=V%R9`!&;W)W87)D.@!&;W)W87)D960@;65S
M<V%G90!&;W)W87)D960@;65S<V%G92!F<F]M("5S`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F5E+T)U<WD@26YF;W)M871I;VX`1G)E92]"=7-Y(%)E<&QY`$9R
M964O0G5S>2!297%U97-T`$9R964O0G5S>2!297%U97-T(%)E<W!O;G-E`$9R
M;U]M`$9R;VT`1G)O;2!!9&1R97-S`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T
M:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1G=D.@!&=V0Z(`!&=V0Z("5U($9O
M<G=A<F1E9"!-97-S86=E<P!'96YE<F%L($]P=&EO;G,`1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'970@;VYL>2!N97<@;65S
M<V%G97,_("A)34%0(&]N;'DI`$=O('1O($UE<W-A9V4`1V]O9VQE(%-E87)C
M:`!'<F%N="!A8V-E<W,`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7!S`$=U
M97-T(%!E<FUI<W-I;VYS`$A%4D4`2%1-3`!(5$U,(%9E<G-I;VX@;V8@365S
M<V%G90!(96%D97)S`$AE:6=H=`!(96QP`$AE;6ES<&AE<F4`2&5R92!I<R!T
M:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP;W-I;F<Z`$AI9&1E;@!(:61D96X@
M:6X@5&AR96%D(%9I97<`2&ED92!$96QE=&5D`$AI9&4@56YS=6)S8W)I8F5D
M`$AI9V@`2&EG:"!0<FEO<FET>0!(:6=H97-T`$AO7VUE`$AO<F1E`$AO<FEZ
M;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&\@>6]U('=A;G0@=&\@
M9&ES<&QA>2!A='1A8VAM96YT<S\`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'D`
M2'5M:61I='D`24U!4`!)34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I`$E-
M05`@;W9E<B!34TP`24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF
M:6-A=&4I`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*0!)34%0+"!N;R!4
M3%,`24U!4"]03U`S($UA:6P@4V5R=F5R<P!)3D)/6`!)7VYS97)T(%)O=R!"
M969O<F4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!)9VYO<F4`26=N;W)E($%L;`!);6%G92!0<F5V:65W.@!);6%G92!5
M4DP`26UA9V4@55),.@!);6%G97,`26UP;W)T`$EM<&]R="!+97D`26UP;W)T
M($ME>7!A:7(`26UP;W)T(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D`26UP
M;W)T(%!U8FQI8R!+97D`26UP;W)T(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!3
M+TU)344@2V5Y`$EM<&]R="!M8F]X($9I;&4`26UP;W)T(&UB;W@@9FEL92`E
M<R!I;G1O(&9O;&1E<B`E<RX`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!)
M;7!O<G1A;G0@;65S<V%G97,`26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E
M<RX`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26X@4')O
M8V5S<P!);E]S97)T(%)O=R!!9G1E<@!);F)O>`!);F-L=61E(&$@8G)I968@
M<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_`$EN8VQU9&4@;W)I
M9VEN86P@;65S<V%G92!I;B!A(')E<&QY/P!);F1I=FED=6%L(%5S97)S`$EN
M9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>0!)
M;F9O<FUA=&EO;B!O;B!097)S;VYA;"!0<FEV871E($ME>0!);F9O<FUA=&EO
M;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y`$EN;&EN90!);G-E<G0@0U]O;'5M
M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@
M3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C
M=7)R96YT(&]N90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!C
M96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F
M=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T
M97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!)
M;G-E<G0@<F]W(&)E9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN=F%L:60@
M06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV86QI9"!!
M9&1R97-S`$EN=F%L:60@4F5M;W1E($UA:6QB;W@`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!K97D`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`
M26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN`$EN=F%L:60@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97DN`$EN=F5N=&]R>0!);G9E<G0`271A;&EC
M`$IA;G5A<GD`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*=6QY`$IU;F4`2G5S
M=&EF>0!+0@!+97D@3&5N9W1H`$ME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`3&%?>6]U=`!,86YG=6%G90!,87-T($UA
M:6QB;W@@4&%G90!,87-T(%!A9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E
M9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T
M(&QO9VEN.B!.979E<@!,87EO=70`3&5F=`!,:5]N:R!!='1A8VAM96YT<P!,
M:6=H="!286EN`$QI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+@!,
M:7-T($AE;'`@5&]P:6-S`$QI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN
M9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL
M(&]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC
M:71L>2D`3&ES=&EN9R!I;B!T:&4@2&5A9&5R`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&]C86P@36%I;&)O>#H`3&]C86P@=&EM
M93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&EN('1O
M("5S`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]W`$QO=R!0<FEO<FET
M>0!,;W=E<B!R;VUA;B!N=6UB97)S`$QO=V5S=`!-30!-86-I;G1O<V@@1FEL
M90!-86EL`$UA:6P@061M:6X`36%I;"!0<F5V:65W<P!-86EL('-E<G9E<B!T
M>7!E('1O(&-O;FYE8W0@=&\Z`$UA:6QB;W@`36%I;&)O>"!A;F0@1F]L9&5R
M($1I<W!L87D@3W!T:6]N<P!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87)C:`!-87)G:6X`
M36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%-E96X`36%R:R!!;&P@
M365S<V%G97,@:6X@1F]L9&5R(&%S(%5N<V5E;@!-87)K(&%S.@!-87)K(&1I
M9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO
M<G,_`$UA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2D`36%T8V@@
M06QL(%%U97)I97,`36%T8V@@06YY(%%U97)Y`$UA=&-H:6YG(&9I96QD<P!-
M87AI;75M($%T=&%C:&UE;G0@4VEZ90!-87AI;75M(&YU;6)E<B!O9B!A='1A
M8VAM96YT<R!R96%C:&5D+@!-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ
M92!R96%C:&5D+@!-87D`365E=&EN9R!#86YC96QL871I;VX`365E=&EN9R!)
M;F9O<FUA=&EO;@!-965T:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P;'D`365E
M=&EN9R!5<&1A=&4`365E=&EN9R!5<&1A=&4@4F5Q=65S=`!-96UB97)S`$UE
M;G4@1F]L9&5R($QI<W0`365R9V4@8V5L;',`365S<V%G90!-97-S86=E($-O
M;7!O<VET:6]N`$UE<W-A9V4@1&%T90!-97-S86=E($]P=&EO;G,`365S<V%G
M92!396%R8V@`365S<V%G92!3:7IE`$UE<W-A9V4@4V]U<F-E`$UE<W-A9V4@
M5FEE=VEN9P!-97-S86=E(&9L86=S`$UE<W-A9V4@9F]L9&5R<P!-97-S86=E
M(&9R;VT@)7,`365S<V%G92!M871C:&5S`$UE<W-A9V4@<F5D:7)E8W1E9"!S
M=6-C97-S9G5L;'DN`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N
M;W0@<V%V960@=&\@)7,`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2X`365S
M<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@
M=&\`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971R:6,`36ED9&QE`$UO
M`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF>0!-;V1I9GD@55),`$UO<W1L
M>2!#;&5A<@!-;W9E`$UO=F4@9&]W;@!-;W9E('1O(&9O;&1E<@!-;W9E('5P
M`$UU;'1I<&%R="]A;'1E<FYA=&EV90!->2!!8V-O=6YT`$UY(%!O<G1A;`!-
M>2!0;W)T86P@3&%Y;W5T`$Y/+"!)($1O($Y/5"!!9W)E90!.3U1%`$YA;64`
M3F%M92!A;F0O;W(@96UA:6P@8V%N(&YO="!B92!E;7!T>0!.965D<R!!8W1I
M;VX`3F5T=V]R:P!.979E<@!.979E<B!S879E(&%T=&%C:&UE;G1S`$YE=P!.
M97<@0V%T96=O<GD`3F5W($9O;&1E<@!.97<@36%I;`!.97<@57-E<FYA;64@
M*&]P=&EO;F%L*0!.97<@;65S<V%G97,`3F5W<P!.97=S9W)O=7!S`$YE>'0`
M3F5X="!-97-S86=E`$YE>'0@4&%G90!.:6=H=`!.;P!.;R!#97)T:69I8V%T
M92!F;W5N9`!.;R!%;F-R>7!T:6]N`$YO($ME>7,@:6X@2V5Y<FEN9P!.;R!-
M97-S86=E<P!.;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@871T86-H
M;65N=',@9F]U;F0N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES
M('!E<FUI<W-I;VXN`$YO(&9O;&1E<B!S96QE8W1E9"X`3F\@9F]L9&5R<R!A
M<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN`$YO(&9O;&1E<G,@=V5R
M92!S<&5C:69I960`3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<P!.;R!F
M;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S`$YO(&UE<W-A9V4@8F]D>2!T
M97AT`$YO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N`$YO('!E;F1I
M;F<@<VEG;G5P<RX`3F\@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R
M=&5D+@!.;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@
M<G5L97,`3F\@<VED97,`3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I
M9W5R960N`$YO('-P96QL:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N<P!.;R!T
M96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S
M97(@<W!E8VEF:65D+@!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F]N(%!A<G1I8VEP86YT`$YO;F4`3F]R;6%L`$YO
M="!$96QE=&5D`$YO="!$<F%F=`!.;W0@26UP;W)T86YT`$YO="!097)S;VYA
M;`!.;W0@82!V86QI9"!P=6)L:6,@:V5Y+@!.;W0@9&5L971E9"!M97-S86=E
M<P!.;W0@:6UP;W)T86YT(&UE<W-A9V5S`$YO="!S970`3F]T92!T:&%T('1H
M:7,@8V%N('1A:V4@<V]M92!T:6UE`$YO=&5S`$YO=F5M8F5R`$YU;6)E<B!O
M9B!C;VQU;6YS`$YU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D
M(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E<B!O9B!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT
M:&QY+@!.=6UB97(@;V8@<F]W<P!/2P!/4@!/8FIE8W0@0W)E871O<@!/8W1O
M8F5R`$]F9FEC90!/;&0@;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD97)S
M(&)E:6YG('!U<F=E9"X`3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E
M860@;65S<V%G97,@:6X@=&AE;3\`3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B
M92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I;VXN`$]P96X@:6X@82!N97<@=VEN
M9&]W`$]P96YE9"!&;VQD97(`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=P!/<'1I;VYA;"!087)T:6-I<&%N=`!/<'1I;VYS`$]P=&EO;G,@9F]R
M("5S`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`
M3W1H97(`3W1H97(@26YF;W)M871I;VX`3W1H97(@36%I;"!!8V-O=6YT<P!/
M=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI<W-I;VYS`%!'4`!01U`@16YC<GEP
M="!-97-S86=E`%!'4"!%<G)O<CH@`%!'4"!%<G)O<CH@3F5E9"!P87-S<&AR
M87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4$=0($]P=&EO;G,`4$=0
M(%!A<W-P:')A<V4@26YP=70`4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R
M="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`4$=0(%!U8FQI
M8R!+97D@5&5X=`!01U`@4'5B;&EC($ME>2!F;W(@(B5S("@E<RDB('=A<R!S
M=6-C97-S9G5L;'D@861D960N`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,B('=A
M<R!S=6-C97-S9G5L;'D@9&5L971E9"X`4$=0(%!U8FQI8R!+97ER:6YG`%!'
M4"!3:6=N($UE<W-A9V4`4$=0(%-I9VXO16YC<GEP="!-97-S86=E`%!'4"!P
M<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N`%!'4"!P=6)L:6,@:V5Y
M('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0('-U<'!O<G0@:7,@9&ES86)L960@
M;VX@=&AI<R!S>7-T96TN`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@
M86-T:79E('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@
M8F4@=F5R:69I960N`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T
M:79E('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N
M`%!(4"!#;V1E`%!-($QI9VAT(%)A:6X`4$]0,P!03U`S("A!=71O($1E=&5C
M="!0<F]T;V-O;',I`%!/4#,@;W9E<B!34TP`4$]0,R!O=F5R(%-33"`H<V5L
M9BUS:6=N960@8V5R=&EF:6-A=&4I`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG
M;F5D*0!03U`S+"!N;R!43%,`4&%G92`E9"!O9B`E9`!086=E('=I=&@@=&AE
M($9I<G-T(%5N<V5E;B!-97-S86=E`%!A9V4@=VET:"!T:&4@3&%S="!5;G-E
M96X@365S<V%G90!087)T*',I`%!A<W-P:')A<V4`4&%S<W!H<F%S92`H06=A
M:6XI`%!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+@!087-S<&AR
M87-E.@!087-S<&AR87-E<R!C86X@;F]T(&)E(&5M<'1Y`%!A<W-P:')A<V5S
M(&1O(&YO="!M871C:`!087-S=V]R9`!087-S=V]R9#H`4&%S<W=O<F0Z(`!0
M87-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%T:`!096YD:6YG(%-I9VYU
M<',Z`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)M:7-S:6]N<R!F
M;W(@=&AI<R!U<V5R(&-A;B!N;W0@8F4@8VAA;F=E9"X`4&5R<V]N86P`4&5R
M<V]N86P@26YF;W)M871I;VX`4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2X`4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S
M=6-C97-S9G5L;'DN`%!E<G-O;F%L(%,O34E-12!K97ES(&1E;&5T960@<W5C
M8V5S<V9U;&QY+@!0:&]T;W,`4&EX96QS`%!L86-E('EO=7(@<VEG;F%T=7)E
M(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\`4&QA:6YT97AT(%9E<G-I
M;VX@;V8@365S<V%G90!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@;F%M92!O
M9B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N97<@;F%M93H`
M4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV
M871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N=&5R('1H:7,@<&%S
M<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A<V4@96YT97(@=&AE
M('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@
M=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@
M<&5R("5S('-E<W-I;VXN`%!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64N`%!L96%S92!R97-O;'9E(&%M
M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E(')E=FEE=R!T
M:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@
M86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@82!F
M;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS+@!0;&5A<V4@
M<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@
M<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+@!0;&5A<V4@
M<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN`%!L
M96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#H`
M4&]L;',`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O
M9B!T:&ES('1A8FQE`%!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H
M97,@*"<M+2`G*3\`4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P9&%T960N
M`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``
M4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E
M=FEO=7,@365S<V%G90!0<F5V:6]U<R!086=E`%!R:6YT`%!R:6YT(&1O8W5M
M96YT`%!R:6]R:71Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J
M96-T<P!0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[
M(&1E9F%U;'0@=&\@3D\`4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N
M="!I<R!S96YT.R!D969A=6QT('1O(%E%4P!0<F]T;V-O;#H`4'5B;&EC(%!'
M4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"X`4'5R7V=E
M($1E;&5T960`4'5R9V4@1&5L971E9`!0=7)G92!&;VQD97(H<RD`4'5R9V4@
M5')A<V@@:&]W(&]F=&5N.@!0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F;VQD
M97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+@!0=7)G92!O;&0@
M;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\`475E<GD`475O=&$@<W1A
M='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`%%U;W1A('-T871U<SH@
M3D\@3$E-250`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286YD;VT@1F]R
M='5N90!295]Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VX`4F5A9`!296%L
M;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C96EV960@3VX`4F5C96EV
M960@4VEN8V4`4F5C96EV960@56YT:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E
M9&ER96-T($UE<W-A9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T
M:6YG(&9A:6QE9"X`4F5F<F5S:`!2969R97-H($9O;&1E<B!6:65W<SH`4F5F
M<F5S:"!0;W)T86P@5FEE=SH`4F5L;V%D(%9I97<`4F5M87)K<P!296UE;6)E
M<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!296UE;6)E<B!T:&4@;&%S
M="!V:65W`%)E;6]T92!-86EL8F]X.@!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@1FEE;&0@1G)O;2!396%R8V@`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-O=7)C90!296UO=F4@=&AE
M`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!296YA;64@1F]L9&5R*',I
M`%)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT
M:#\`4F5N86UI;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9`!297!L7WD@=&\@3&ES=`!297!L86-E('=I=&@Z
M`%)E<&QY`%)E<&QY(%-E;G0N`%)E<&QY('1O($%L;`!297!L>2!T;R!!;&PZ
M`%)E<&QY('1O($QI<W0`4F5P;'D@=&\@3&ES=#H`4F5P;'D@=&\@7T%L;`!2
M97!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G90!297!L>2!W:71H(&9R
M964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P;'D@=VET:"!R97%U97-T
M960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L>2U4;P!297!L>2U4;SH@
M`%)E<&QY.@!297!O<G0@87,@26YN;V-E;G0`4F5P;W)T(&%S(%-P86T`4F5Q
M=65S="!A(%]296%D(%)E8V5I<'0`4F5Q=65S="!D96QI=F5R>2!C;VYF:7)M
M871I;VX_`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`4F5Q=6ER960@4&%R=&EC
M:7!A;G0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R
M9`!297-P;VYD96YT(%-T871U<R!5<&1A=&5D+@!297-U;'1S`%)E<W5M90!2
M97-U;64@>6]U<B!S97-S:6]N`%)E='5R;B!T;R!&971C:"!-86EL`%)E='5R
M;B!T;R!/<'1I;VYS`%)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F
M=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/P!2
M979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`
M4FED9&QE<P!2:6=H=`!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;W<@4')O
M<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6X`4R]-24U%
M`%,O34E-12!%;F-R>7!T($UE<W-A9V4`4R]-24U%($5R<F]R.B!.965D('!A
M<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!3+TU)344@3W!T
M:6]N<P!3+TU)344@4&%S<W!H<F%S92!);G!U=`!3+TU)344@4&5R<V]N86P@
M2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T
M:6]N+@!3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L
M;'D@861D960N`%,O34E-12!3:6=N($UE<W-A9V4`4R]-24U%(%-I9VXO16YC
M<GEP="!-97-S86=E`%,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H
M:7,@<WES=&5M+@!3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N
M86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E
M9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET
M86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4TU3($UE
M<W-A9VEN9P!37W5B:F5C=`!380!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S
M`%-A=F4`4V%V92`E<P!3879E($%T=&%C:&UE;G1S('=I=&@@;65S<V%G92!I
M;B!S96YT+6UA:6P@9F]L9&5R/P!3879E($1R869T`%-A=F4@3W!T:6]N<P!3
M879E(%]$<F%F=`!3879E(&%S`%-A=F4@9')A9G1S(&%S('5N<V5E;C\`4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E(')E8VEP
M:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O
M;VL_`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_`%-A=F4@<V5N
M="!M86EL/P!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879I;F<@=&AE(&1R
M869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`
M4V5A<F-H`%-E87)C:"`E<P!396%R8V@@16YG:6YE<P!396%R8V@@4F5S=6QT
M<P!3965N`%-E;&5C=`!396QE8W0@06YO=&AE<B!!8V-O=6YT`%-E;&5C="!A
M(&1A=&4`4V5L96-T(&$@9FEE;&0`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E
M;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E
M<B!T;R!A9&0`4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I
M;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+@!396QE8W0@86QL`%-E
M;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R
M97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!N;VYE`%-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE
M(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4`4V5L
M96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA
M=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3
M96QE8W1E9"!!9&1R97-S(&)O;VMS.@!396YD($ME>2!T;R!0=6)L:6,@2V5Y
M<V5R=F5R`%-E;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E;F0@365S<V%G90!3
M96YD(%!R;V)L96T@4F5P;W)T`%-E;G-O<CH@`%-E;G0@;6%I;"!F;VQD97(`
M4V5N="!M86EL(&9O;&1E<CH`4V5P=&5M8F5R`%-E<G9E<@!397)V97(@86YD
M($9O;&1E<B!);F9O<FUA=&EO;@!397)V97(Z`%-E="!P<F5F97)E;F-E<R!F
M;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S
M86=E<RX`4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN
M9R!M97-S86=E<S\`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A
M;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4VAA<F4@1F]L9&5R<P!3:&%R
M92!M86EL(&9O;&1E<G,`4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O
M=&AE<B!U<V5R<RX`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C
M97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=6QD('1H
M92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@
M4$=0(&1A=&$_`%-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D
M(&%F=&5R('-A=FEN9R!A(&1R869T/P!3:&]U;&0@>6]U<B!01U`@<'5B;&EC
M(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U
M;'0_`%-H;W<`4VAO=R!!;&P@2&5A9&5R<P!3:&]W($1E;&5T960`4VAO=R!,
M:6UI=&5D($AE861E<G,`4VAO=R!-86EL:6YG($QI<W0@26YF;W)M871I;VX`
M4VAO=R!5;G-U8G-C<FEB960`4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP
M<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/P!3:&]W(&QA<W0@
M;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;&5G96YD(&EN('1H
M92!M86EL8F]X('9I97<_`%-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S
M86=E<R!O;FQY/P!3:&]W('!R979I97=S(&EN('1O;VQT:7!S/P!3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_`%-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N
M=6)A<C\`4VAO=R!T:&4@26UA9V5S`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/P!3:&]W('1O=&%L(&YU
M;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_`%-H;W=E<G,`4VAO=V5R<R!%87)L
M>0!3:&]W97)S($QA=&4`4VAO=VX`4VE?>F4`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-N;W<@9&5P=&@Z(`!3;W)T(&)Y($%R<FEV86P`4V]R="!B>2!$871E
M`%-O<G0@8GD@1G)O;2!!9&1R97-S`%-O<G0@8GD@365S<V%G92!3:7IE`%-O
M<G0@8GD@4W5B:F5C=`!3;W)T(&)Y(%1H<F5A9`!3;W)T(&)Y(%1O($%D9')E
M<W,`4W!A8VEN9P!3<&%M`%-P86T@9F]L9&5R.@!3<&5C:6%L($-H87)A8W1E
M<B!);G!U=`!3<&5C:6%L($-H87)A8W1E<G,`4W!E;&P@0VAE8VME<@!3<&5L
M;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W
M:&5N('-P96QL(&-H96-K:6YG+@!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W1A;F1A<F0`4W1A<G0`4W1A='5S`%-T<FEP($%T=&%C:&UE
M;G0`4W1R:7`@;&EN96)R96%K<S\`4W4`4W5B7VIE8W0`4W5B:F5C=`!3=6)J
M96-T($9I96QD`%-U8FUI=`!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U8G-C
M<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9V=E<W1I;VYS`%-U
M;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T
M`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R
M=`!3=VET8V@@0V]M<&]S:71I;VX@365T:&]D`%-W:71C:"!T;R!(5$U,(&-O
M;7!O<VET:6]N`%-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N`%0M
M4W1O<FT`5"U3=&]R;7,`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T
M:65S`%1A<F=E=#H`5&%S:W,`5&5?>'0`5&5M<"!F;W(@;&%S="!H;W5R.B``
M5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A
M=&EO;@!496YT871I=F5L>2!!8V-E<'0@<F5Q=65S=`!496YT871I=F5L>2!!
M8V-E<'1E9`!497)M<R!O9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I
M;B!C;VYF+G!H<`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H
M86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($9R;VTZ(&-O;'5M
M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.@!4:&4@36%C:6YT
M;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N`%1H92!A
M8V-O=6YT("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&%C8V]U;G0@(B5S
M(B!H87,@8F5E;B!S879E9"X`5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N
M9"X`5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P
M<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I
M;F1O=W,_`%1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E
M(&)E;&]W+@!4:&4@8W5R<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E
M;F%M960@=&\@(B5S(BX`5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H
M(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D
M`%1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@(B5S(B!F;VQD97(N
M`%1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9O
M;&1E<B`B)7,B(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!C;VYT
M86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C
M875S92!P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+@!4:&4@9F]L9&5R("(E<R(@=V%S(&-R96%T960@8G5T('EO=2!W
M97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S
M(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I
M="X`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E
M<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F
M=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL
M>2!R96YA;65D('1O("(E<R(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S
M92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U<B!A9&1R97-S8F]O:RX`
M5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R
M(&UE<W-A9V4Z`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO
M=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z`%1H92!M86EL('-E<G9E<B!G
M96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.@!4:&4@;6%I;&)O>"`E
M<R!I<R!A;')E861Y(&5M<'1Y+@!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S
M(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="X`5&AE(&UE
M<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG
M+@!4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+@!4:&4@;65S<V%G92!H
M87,@8F5E;B!V97)I9FEE9"X`5&AE('!A<W-P:')A<V4@=VEN9&]W(&-A;B=T
M(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R
M('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!R87<@=&5X="!O9B!T:&4@
M4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E<RX`5&AE(')E<75E<W1E
M9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE
M;G0N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@
M6FEP(&%T=&%C:&UE;G0N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N
M871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+@!4:&4@<VEG;F%T=7)E('=A
M<R!S=6-C97-S9G5L;'D@<F5P;&%C960N`%1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!F:6QE(&1O
M97,@;F]T(&5X:7-T+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R
M('1A<VML:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G90!4:&4@=&5X="!O
M9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T
M:&4@<F5T=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@
M;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T:&4@<V5N
M="!M97-S86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RX`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@
M=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@
M;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+@!4:&5R92!W87,@82!P<F]B
M;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9`!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@
M5&AE('-E<G9E<B!S86ED.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N
M9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9`!4:&5R92!W87,@86X@97)R;W(@8V]P>6EN9R!M97-S86=E<R!F<F]M("(E
M<R(@=&\@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L
M9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@
M(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN
M9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E
M<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S
M+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M
M97-S86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S
M<V%G92!A<R!A(&1R869T+@!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y
M;W5R(&UE<W-A9V4Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@979E;G0Z("5S+@!4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A
M9V4@<&%R=`!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D
M(&EN(&ET+@!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D
M(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92!T:&ES.B``5&AI
M<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N
M`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES
M(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@:7,@)7,N`%1H:7,@;6%Y('1A
M:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN
M=64_`%1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+@!4
M:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@4$=0
M(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@`%1H:7,@;65S<V%G92!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H
M86-C;W)D:6YG('1O(%)&0R`R,#$U*2X`5&AI<R!M97-S86=E(&AA<R!B965N
M(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"X`5&AI<R!M97-S86=E(&AA<R!B
M965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E
M(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@
M:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+@!4:&ES(&UE<W-A9V4@=&\`
M5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I
M;F1O=RX`5&AR96%D(%9I97<`5&AU;F1E<@!4:6-K971S`%1I;64@5')A8VMI
M;F<`5&EM92!F;W)M870`5&ET;&4`5&\`5&\@061D<F5S<P!4;V1A>0!4;VUO
M<G)O=P!4;W``5&]T86P@071T86-H;65N=',@4VEZ93H`5')A<V@@9F]L9&5R
M`%1R87-H(&9O;&1E<CH`5'4`55),`%523#H`56YA8FQE('1O(')E=')I979E
M('%U;W1A`%5N86YS=V5R960`56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T
M90!5;F1E<FQI;F4`56YD:7-C;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG
M97,`56YF:6QE9`!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S`%5N
M:71S`%5N:VYO=VX@1&%T90!5;FMN;W=N($UE971I;F<`56YK;F]W;B!296-I
M<&EE;G0`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YL;V%D(%!A<W-P
M:')A<V4`56YN86UE9`!5;G-E96X`56YS970@8V]L;W(`56YS=6)S8W)I8F4@
M9G)O;2!&;VQD97(H<RD`57!D871E`%5P9&%T92`E<P!5<&1A=&4@071T86-H
M;65N="!);F9O<FUA=&EO;@!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D
M871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P<&5R
M(')O;6%N(&YU;6)E<G,`57-E($1E9F%U;'0@5F%L=64`57-E($E-05`@9F]L
M9&5R('-U8G-C<FEP=&EO;G,_`%5S97(`57-E<B!!9&UI;FES=')A=&EO;@!5
M<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R;F%M90!5<V5R;F%M93H`57-E
M<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!686-A=&EO;@!687)I86)L
M90!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I97<`5FEE=R`E<P!6:65W("5S
M(%!U8FQI8R!+97D`5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<`5FEE=R!097)S;VYA;"!0<FEV871E($ME>0!6:65W(%!E<G-O;F%L
M(%!U8FQI8R!+97D`5FEE=R!4:')E860`5FEE=R!4:'5M8FYA:6P`5FEE=R!A
M;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&5V96YT`%9I97<@;65S<V%G97,@
M:6X@)7,`5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ
M`%9I97<@=&%S:P!6:65W('1H92!);6%G97,`5FER='5A;"!&;VQD97(@(B5S
M(B!C<F5A=&5D('-U8V-E<V9U;&QY+@!6:7)T=6%L($9O;&1E<G,`5FER='5A
M;"!F;VQD97(@;&%B96P`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5V4`5V5A
M=&AE<B!&;W)E8V%S=`!796(`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T
M97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H
M870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE;B!D96QE=&EN9R!M97-S
M86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E860@
M;V8@;6%R:VEN9R!T:&5M(&%S(&1E;&5T960_`%=H:71E;&ES=`!7:61T:`!7
M:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEN9#H`5VEN
M9#H@`%E9`%EE<P!997,L($D@06=R964`66]U(&%R92!A8F]U="!T;R!F971C
M:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N="AS*3H`66]U(&%R
M92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E
M871I;F<@82!S=6(M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P
M+6QE=F5L(&9O;&1E<BX`66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B``
M66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T
M;R!T:&ES(&9O;&1E<@!9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E
M)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RX`66]U(&AA=F4@
M)7,@;F5W(&UE<W-A9V5S+@!9;W4@:&%V92`Q(&YE=R!M97-S86=E+@!9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E(&YE=R!M86EL(&EN('1H
M92!F;VQL;W=I;F<@9F]L9&5R.@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@
M9F]L;&]W:6YG(&9O;&1E<G,Z`%EO=2!M=7-T(&5N=&5R(&%T(&QE87-T(&]N
M92!R96-I<&EE;G0N`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O
M<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9
M;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@
M<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4`66]U(&UU<W0@<V5L
M96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A
M;B!A8V-O=6YT('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!A
M9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G
M92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF
M>2!A="!L96%S="!O;F4@9FEL92!T;R!A='1A8V@N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@=7!D871E+@!9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A
M9V4@=&\@)7,@;VX@)25S+@!9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@
M;VX@)7,N`%EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N($AE<F4@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N<W5B<V-R
M:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S(@!9;W4@
M=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(@!9;W5R
M($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@3F%M90!9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES
M`%EO=7(@4')I=F%T92!+97D`66]U<B!0=6)L:6,@2V5Y`%EO=7(@86-C;W5N
M=',Z`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G92!T
M>7!E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!C:&%R
M<V5T(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U;'0@96YC<GEP
M=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;65S<V%G92!W87,@
M<W5C8V5S<V9U;&QY(&1E;&EV97)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`
M66]U<B!S:6=N871U<F4Z`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O<G1=
M`%M3:&]W(%%U;W1E9"!497AT("T`7T%D;6EN:7-T<F%T:6]N`%]"8V,`7T)L
M86-K;&ES=`!?0V,`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2;W<`7T9O
M;&1E<G,`7T=R;W5P<P!?2&5L<`!?261E;G1I='D`7TEM86=E(%!R;W!E<G1I
M97,N+BX`7TEN8F]X`%],;V<@;W5T`%]-97-S86=E(%-O=7)C90!?36]D:69Y
M($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]0<FEN=`!?4')I;W)I
M='D`7U)E9G)E<V@@)7,`7U)E;6]V92!,:6YK+BXN`%]297!L>0!?4V5A<F-H
M`%]396YD($UE<W-A9V4`7U1A8FQE(%!R;W!E<G1I97,N+BX`7U1H<F5A9`!?
M5&\`7U5N9&5L971E`%]5<V5R<P!?5FEE=R!4:')E860`7U=H:71E;&ES=`!A
M='1A8VAM96YT`&%T=&%C:&UE;G1S+GII<`!C86QM`&9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,`:V5Y`&QI;F5S70!M86EL8F]X(&9I;&4`;F%M90!N;VYE
M`&]R`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S<&5L;&EN9R!E<G)O<@!S<&5L
M;&EN9R!E<G)O<G,`<W1E861Y`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FT`=V5A=&AE<BYC;VT`>6]U<B!B;&%C:VQI<W0`>6]U<B!W:&ET
M96QI<W0`4')O:F5C="U)9"U697)S:6]N.B!);7`@-"XP+6-V<PI297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#4M,#,M,#$@,3$Z,3<K,#$P,`I,87-T+51R86YS;&%T;W(Z($UA
M<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O=F%N;T!U;FEB;V-C;VYI+FET/@I,
M86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I
M;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/
M+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@("`@
M("!!.B``("`@($1A=&$Z(``@("`@1&$Z(``@*$-H:6%V92!!8V-E<W-O("5S
M*0`@3V=G971T;SH@`"!A;&QE(``@:6X@`",`)2XR9DU"("\@)2XR9DU"("`H
M)2XR9B4E*0`E9"`E<R!E("5S`"5D(&UE<W-A9V=I('-O;F\@<W1A=&D@<V5G
M;F%L871I(&-O;64@;F]N+7-P86T@86P@='5O(&%M;6EN:7-T<F%T;W)E+@`E
M9"!M97-S86=G:2!S;VYO('-T871I('-E9VYA;&%T:2!C;VUE(&YO;BUS<&%M
M+@`E9"!M97-S86=G:2!S;VYO('-T871I('-E9VYA;&%T:2!C;VUE('-P86T@
M86P@='5O(&%M;6EN:7-T<F%T;W)E+@`E9"!M97-S86=G:2!S;VYO('-T871I
M('-E9VYA;&%T:2!C;VUE('-P86TN`&1A("5D(&$@)60@9&D@)60@365S<V%G
M9VD`)7,@+2!!='1E;GII;VYE`"5S($]P97)A>FEO;FD@9&D@36%N=71E;GII
M;VYE("T@0V]N9F5R;6$`)7,@5&5R;6EN:2!D)U5S;P`E<R!E<VES=&4@9VG@
M+B!,82!C87)T96QL82`E<R!N;VX@Z"!S=&%T82!R:6YO;6EN871A+@`E<R!A
M("5S("5S`"5S(&YO;B!S96UB<F$@97-S97)E('5N82!C87-E;&QA('9A;&ED
M82X`3&$@8V%R=&5L;&$@)7,@=F5R<N`@<FEN;VUI;F%T82!A9"!I;FEZ:6\@
M;65S92X`)7,@:&$@86-C971T871O+@`E<R!H82!C86YC96QL871O("5S+@`E
M<R!H82!R:69U:71A=&\N`"5S(&AA(')I<W!O<W1O(&$@=6YA(')I8VAI97-T
M82!L:6)E<F\O;V-C=7!A=&\N`"5S(&AA(')I<W!O<W1O(&%L(&EN=FET;R!A
M("5S+@`E<R!T:2!H82!M86YD871O(&EN9F]R;6%Z:6]N:2!L:6)E<F\O;V-C
M=7!A=&\N`"5S('1E;G1A=&EV:2!A8V-E='1A=&DN`"5S(&UI;G5T:0`E<R!N
M;VX@=')O=F%T;RX`)7,@<FEC:&EE9&4@:6YF;W)M87II;VYS:2!S=6P@='5O
M(&QI8F5R;R]O8V-U<&%T;RX`)7,@<FEC:&EE9&4@;&$@='5A('!R97-E;GIA
M(&$@)7,N`"5S(&$@)7,@9&D@)7,`)7,@=G5O;&4@;6]D:69I8V%R92`E<RX`
M)7,@=F]R<F5B8F4@9F%R=&D@<')E<V5N=&4@9&5L("5S+@`E<R!V;W)R96)B
M92!R:6-E=F5R92!L92!U=&QI;64@:6YF;W)M87II;VYI('-U("5S+@`E<SH@
M)7,`)7,Z("5S("@E9"9N8G-P.V1I)FYB<W`[)60I`"A%9F9E='1U82!Q=65S
M=&4@;6]D:69I8VAE(&4@<&%S<V$@86QL82!F:6YE<W1R82!S=6-C97-S:79A
M+BD`*$EG;F]R82!T=71T92!L92!M;V1I9FEC:&4@92!T;W)N82!A;&QA(&9I
M;F5S=')A($-O;7!O;FD@365S<V%G9VEO+BD`*%1O<FYA(&%L;&$@9FEN97-T
M<F$@0V]M<&]N:2!-97-S86=G:6\@9&]P;R!A=F5R(&%P<&QI8V%T;R!T=71T
M92!L92!M;V1I9FEC:&4@9F%T=&4@9FEN;W)A+B`@3&4@;6]D:69I8VAE(&$@
M<75E<W1A(&9I;F5S=')A($Y/3B!V97)R86YN;R!E9F9E='1U871E+BD`*%1O
M<FYA(&%L;&$@9FEN97-T<F$@0V]M<&]N:2!-97-S86=G:6\@9&]P;R!A=F5R
M(&%P<&QI8V%T;R!T=71T92!L92!M;V1I9FEC:&4@9F%T=&4@9FEN;W)A+B`@
M3&4@;6]D:69I8VAE(&$@<75E<W1A(&9I;F5S=')A($Y/3B!V97)R86YN;R!E
M9F9E='1U871E+BD`*B!!9V=I=6YG:6QI(&-L:6-C86YD;R!S=2!/2R`J`"H@
M4V5L97II;VYA(&=L:2!I;F1I<FEZ>FD@*@`L(&$@)7,@)7,`+"!V87)I86)I
M;&4@9&$@)7,@82`E<P`Q(&UE<W-A9V=I;R#H('-T871O('-E9VYA;&%T;R!C
M;VUE(&YO;B!S<&%M(&%L('1U;R!A;6UI;FES=')A=&]R92!D:2!S:7-T96UA
M+@`Q(&UE<W-A9V=I;R#H('-T871O('-E9VYA;&%T;R!C;VUE(&YO;B!S<&%M
M+@`Q(&UE<W-A9V=I;R#H('-T871O('-E9VYA;&%T;R!C;VUE('-P86T@86P@
M='5O(&%M;6EN:7-T<F%T;W)E(&1I('-I<W1E;6$N`#$@;65S<V%G9VEO(.@@
M<W1A=&\@<V5G;F%L871O(&-O;64@<W!A;0`Q,#`@8V%R871T97)I`#$P,#`@
M8V%R871T97)I`$9O<FUA=&\@,3(@;W)E`$9O<FUA=&\@,C0@;W)E`#(T(&]R
M90`R-3`@8V%R871T97)I`#4P,"!C87)A='1E<FD`56X@:6UM86=I;F4@9W)O
M<W-A(&YO;6EN871A("5S(.@@86QL96=A=&$@82!Q=65S=&\@;65S<V%G9VEO
M+@!5;B!M97-S86=G:6\@8VAE(&AA:2!I;G9I871O(&AA('!R;V1O='1O('5N
M82!N;W1I9FEC82!D86P@<FEC979E;G1E+@!-;W-T<F$@04T`04TO4$T`10!6
M86D@80!296=O;&4`06-C971T82!2:6-H:65S=&4`06-C971T871O`$%C8V]U
M;G0@4&%S<W=O<F0`3F]M92!D96QL)V%C8V]U;G0Z`$-O;G1A8FEL:71A)P!!
M>FEO;FD`06=G:75N9VD`06=G:75N9VD@4V]T=&\@1W)U<'!O`$%G9VEU;F=I
M('%U:3H`06=G:75N9VD@3G5O=F\@571E;G1E`$%G9VEU;F=I('5N(&YU;W9O
M('5T96YT93H`06=G:75N9VD@=6X@;G5O=F\@;65M8G)O`$%G9VEU;F=I('!A
M:6\`06=G:75N9VD@<V]R9V5N=&4`06=G:75N9VD@86P@;6EO(&-A;&5N9&%R
M:6\`06=G:75N9VD@=71E;G1E`"(E<R(@86=G:75N=&\@8V]M92!A;&QE9V%T
M;RX`3&$@9G5N>FEO;F4@9&D@86=G:75N=&$@=71E;G1I(&YO;B#H(&%T=&EV
M82X`56QT97)I;W)I(&EN9F]R;6%Z:6]N:2!P;W-S;VYO(&5S<V5R92!V:7-U
M86QI>GIA=&4@)7,`56QT97)I;W)I($EN9F]R;6%Z:6]N:2!097)S;VYA;&4`
M56QT97)I;W)I(&1E='1A9VQI(&1E;"!M97-S86=G:6\`56QT97)I;W)I(&1E
M='1A9VQI(&1E;"!M97-S86=G:6\@<&]S<V]N;R!E<W-E<F4@=FES=6%L:7IZ
M871I("5S+@!5;'1E<FEO<FD@9&5T=&%G;&D@9&5L(&UE<W-A9V=I;R!D)V5R
M<F]R90!5;'1E<FEO<FD@9&5T=&%G;&D@9&5L(&UE<W-A9V=I;R!D)V5R<F]R
M92!P;W-S;VYO(&5S<V5R92!V:7-U86QI>GIA=&D@)7,`4G5B<FEC80!2=6)R
M:6-H90!!;6UI;FES=')A>FEO;F4`4'5B8FQI8VETX`!!;&QI;F5A;65N=&\`
M06QL:6YE86UE;G1O.@!4=71T:0!4=71T:2!G;&D@571E;G1I($%U=&5N=&EC
M871I`%1U='1I(&D@1W)U<'!I`%1U='1I(&D@4&5R;65S<VD`5'5T=&D@:2!Q
M=6%T=')O(&QA=&D`5'5T=&D@:2!M97-S86=G:2!D96QL92!S96=U96YT:2!C
M87)T96QL92!S87)A;FYO('-C87)I8V%T:2!I;B!U;B!F:6QE($U"3U@Z`%1U
M='1I(&D@;65S<V%G9VD@;F5L;&$@8V%R=&5L;&$@(B5S(BP@<&GY('9E8V-H
M:2!D:2`E<R!G:6]R;FDL('-A<F%N;F\@96QI;6EN871I('!E<B!S96UP<F4N
M`%1U='1E(&QE(&-A<G1E;&QE(&1I(%!O<W1A($EN=FEA=&$@<&GY('9E8V-H
M:64@9&D@)7,@;65S:2!S87)A;FYO(&-A;F-E;&QA=&4N`%1U='1E(&QE(&-A
M<G1E;&QE(&1I(%!O<W1A($EN=FEA=&$@<&GY('9E8V-H:64@9&D@)7,@;65S
M:2!S87)A;FYO(&-A;F-E;&QA=&4N`%!E<FUE='1I(&%P<&QI8V%Z:6]N92!F
M:6QT<FD@:6X@;V=N:2!#87-E;&QA`%5T96YZ82!)35-0(&%L=&5R;F%T:79A
M`$EN9&ER:7IZ;R!E;6%I;"!A;'1E<FYA=&EV;P!!=G9I<V$@<W4@86=G:6]R
M;F%M96YT:0!497-T;R!A;'1E<FYA=&EV;SH`4&%R=&D@86QT97)N871I=F4@
M<&5R('%U97-T82!S97II;VYE.@!396UP<F4`4V%L=F$@<V5M<')E(&=L:2!A
M;&QE9V%T:0!%<G)O<F4@9'5R86YT92!I;"!T96YT871I=F\@9&D@;W1T96YE
M<F4@;"=A;&QE9V%T;RX@26P@<V5R=F5R($E-05`@:&$@<FES<&]S=&\Z(`!3
M:2#H('9E<FEF:6-A=&\@=6X@97)R;W)E('-C;VYO<V-I=71O(&%G9VEU;F=E
M;F1O(&QA(&YU;W9A('9O8V4N`%)I<W!O<W1A`%)I<W!O<W1O`$UE<W-A9V=I
M(&$@8W5I('-I(.@@<FES<&]S=&\`07!P;&EC87II;VYE`$%P<&QI8V%Z:6]N
M92!E)R!P<F]N=&$N`$%P<&QI8V$@;&4@<F5G;VQE(&1E;"!F:6QT<F\@82!I
M;FEZ:6\@<V5S<VEO;F4N`$%P<&QI8V$@;&4@<F5G;VQE(&1E;"!F:6QT<F\@
M;V=N:2!V;VQT82!C:&4@24Y"3U@@Z"!M;W-T<F%T;S\`07!R:6QE`%-I8W5R
M;R!D:2!V;VQE<B!C86YC96QL87)E('%U97-T82!C:&EA=F4@<'5B8FQI8V$_
M`%-E:2!S:6-U<F\@9&D@=F]L97(@96QI;6EN87)E('%U97-T82!R96=O;&$_
M("A1=65S=&\@3D].(.@@<F%C8V]M86YD871O(2D`4V5I('-I8W5R;R!D:2!V
M;VQE<FQO(&9A<F4_`%-E:2!S:6-U<F\@9&D@=F]L97(@96QI;6EN87)E(&QA
M(')I8VAI97-T82!D:2!I<V-R:7II;VYE('!E<B`E<S\`4V5I('-I8W5R;R!D
M:2!V;VQE<B!C86YC96QL87)E(%!%4B!314U04D4@<75E<W1I(&UE<W-A9V=I
M/P!3:6-U<F\@9&D@=F]L97(@8V%N8V5L;&%R92!015)-04Y%3E1%345.5$4@
M<75E<W1O(&%L;&5G871O/P!396D@<VEC=7)O(&1I('9O;&5R('-V=6]T87)E
M(&EL('%U97-T82!C87)T96QL83\`4V5I('-I8W5R;R!D:2!V;VQE<B!S=G5O
M=&%R92!I;"!#97-T:6YO/P!3:6-U<F\@9&D@=F]L97(@8V%N8V5L;&%R92!0
M15)-04Y%3E1%345.5$4@<75E<W1I(&UE<W-A9V=I/P!396D@<VEC=7)O(&1I
M('9O;&5R('-E9VYA;&%R92!Q=65S=&\@;65S<V%G9VEO(&-O;64@8V]R<F5T
M=&\_`%-E:2!S:6-U<F\@9&D@=F]L97(@<V5G;F%L87)E('%U97-T;R!M97-S
M86=G:6\@8V]M92!S<&%M/P!/<F%R:6\@9&D@87)R:79O`$-R97-C96YT90!#
M:&EE9&D`0VAI961I(&-O;F9E<FUA('!R:6UA(&1I(&5S96=U:7)E(&]P97)A
M>FEO;FD@9&D@;6%N=71E;GII;VYE`$%L;&5G80!);F-L=61I(&-O<&EA(&1E
M;&QA('1U82!C:&EA=F4@<'5B8FQI8V$@4$=0(&%L(&UE<W-A9V=I;S\`1FEL
M92!!;&QE9V%T;SH`3&$@9&EM86YD:6]N92!D96P@9FEL92!A;&QE9V%T;R`B
M)7,B(.@@<W5P97)I;W)E(&$@<75E;&QA(&-O;G-E;G1I=&$N($9I;&4@;F]N
M(&%L;&5G871O+@!!;&QE9V%T;R!U;B!F:6QE(&E#86QE;F1A<B!I;B!R:7-P
M;W-T82!A;&QA('9O<W1R82!R:6-H:65S=&$N`$%L;&5G871O`$%L;&5G871O
M('-T<FEP<&%T;SH@5&EP;R!O<FEG:6YA;&4@9&5L;"=A;&QE9V%T;P!!;&QE
M9V%T:0!496YT871I=F\@9&D@8V%N8V5L;&%Z:6]N92!D:2!U;B!G<G5P<&\@
M:6YE<VES=&5N=&4N`%1E;G1A=&EV;R!D:2!E;&EM:6YA>FEO;F4@9&D@=6X@
M<&5R;65S<V\@:6YE<VES=&5N=&4N`%1E;G1A=&EV;R!D:2!M;V1I9FEC82!D
M:2!U;B!P97)M97-S;R!I;F5S:7-T96YT90!496YT871I=F\@9&D@;6]D:69I
M8V$@9&D@=6X@<&5R;65S<V\@:6YE<VES=&5N=&4`4&%R=&5C:7!A;G1I`$%T
M=&5N>FEO;F4`06=O<W1O`$%U=&A?:6UP.B!%<W1E;G-I;VYE($E-05`@4FEC
M:&EE<W1A(&YO;B!T<F]V871A+@!-;W-T<F$@:6X@875T;VUA=&EC;R!L92!I
M;6UA9VEN:2!N96D@;65S<V%G9VD@2%1-3"!Q=6%N9&\@:6P@;6ET=&5N=&4@
M92<@;F5L;&$@;6EA(')U8G)I8V$_`%)U8G)I8VAE(&1I<W!O;FEB:6QI.@!#
M86UP:2!D:7-P;VYI8FEL:3H`26X@871T97-A(&1I(%)I<W!O<W1A`%1O<FYA
M(&$@)7,`5&]R;F$@82`E<P!39F]N9&\`0F%S96QI;F4`0V-N`%%U:2!S;W1T
M;R#H(&EL('1E<W1O(&-O;7!L971O(&1E;&QO(&UE<W-A9V=I;R!I;F9O<FUA
M=&EV;RX`3&ES=&$@;F5R80!);7!O<W1A>FEO;FD@0FQO8V-O`%1I<&\@9&D@
M0FQO8V-O`$)L;V-C82!I;6UA9VEN:2!N96D@;65S<V%G9VD@2%1-3"!F:6YO
M(&$@8VAE(&YO;B!S<&5C:69I8V%T86UE;G1E(')I8VAI97-T;P!#;W)P;P!'
M<F%S<V5T=&\`4')E9F5R:71I`$UA<F=I;F4`36%R9VEN:0!%;G1R86UB90!3
M:6$@;&ES=&$@9&5L;&4@:6YT97-T87II;VYI(&-H92!D96P@8V]R<&\@9&5L
M($UE<W-A9V=I;P!"87-S;P!#35,`4')O<')I973@(&1E;&QE($-?96QL92XN
M+@!#7V]D:6-E(&-A<F%T=&5R:0!#86QE;F1A<FEO`$-A;&UO`$EM<&]S<VEB
M:6QE(&-O;FYE='1E<G-I(&%L('-E<G9E<B!D:2!P;W-T82!R96UO=&\N`$EM
M<&]S<VEB:6QE(&-O;FYE='1E<G-I(&%L('-E<G9E<B!D:2!P;W-T82!R96UO
M=&\Z(`!);7!O<W-I8FEL92!6:7-U86QI>GIA<F4@+2!T<F]V871O('-O;&\@
M)7,@9&D@)7,@<&%R=&D@9&D@<75E<W1O(&UE<W-A9V=I;R!N96QL82!#87-E
M;&QA(&-O<G)E;G1E`$%N;G5L;&$`06YN=6QL82!-97-S86=G:6\`16QI;6EN
M82!287!P;W)T;R!D:2!0<F]B;&5M80!!;FYU;&QA;F1O('%U97-T;R!M97-S
M86=G:6\@<VD@<&5R9&5RX"!I;"!S=6\@8V]N=&5N=71O(&1E9FEN:71I=F%M
M96YT92X`3W!Z:6]N:0!#871E9V]R:64@92!%=&EC:&5T=&4`0V,`4')O<')I
M973@(&1E;&QE(&-E;&QE`%-P97-S;W)E(&-E;&QE.@!0<F]P<FEE=.`@9&5L
M;&4@8V5L;&4`4W!A>FEO(&-E;&QE.@!#96YT<F$`36]D97)A=&]R90!-;V1I
M9FEC80!#86UB:6$@5'5T=&D`0V%M8FEA($-A<G1E;&QA`$UO9&EF:6-A(&QE
M(&EM<&]S=&%Z:6]N:2!D:2!V:7-U86QI>GIA>FEO;F4@960@;W)D:6YA;65N
M=&\@9&5I(&UE<W-A9V=I+@!-;V1I9FEC82!L92!I;7!O<W1A>FEO;FD@9&5L
M('-E<G9E<B!M86EL(&4@8V%R=&5L;&4N`$UO9&EF:6-A(&YO;64L(&EN9&ER
M:7IZ;R!E(&9I<FUA(&-H92!V97)R86YN;R!V:7-U86QI>GIA=&D@9&%L;&4@
M<&5R<V]N92!C:&4@;&5G9V]N;R!E(')I<W!O;F1O;F\@86ET('1U;VD@;65S
M<V%G9VDN`$UO9&EF:6-A(&YO;64L(&EN9&ER:7IZ;RP@92!F:7)M82!C:&4@
M=F5R<F%N;F\@=FES=6%L:7IZ871I(&1A;&QE('!E<G-O;F4@8VAE(&QE9V=O
M;F\@92!R:7-P;VYD;VYO(&%I('1U;VD@;65S<V%G9VDN`$-I860`0V%R871T
M97)I(&1A(&UO<W1R87)E.@!697)I9FE?8V$@3&EN:RXN+@!#;VYT<F]L;&$@
M<V4@Z"!A<G)I=F%T82!.=6]V82!0;W-T80!396QE>FEO;F$@5'5T=&DO3F5S
M<W5N;P!#;VYT<F]L;&$@='5T=&D@:2!S97)V97(@9&D@<&]S=&$@9&%I('%U
M86QI('9U;VD@<V-A<FEC87)E(&D@;G5O=FD@;65S<V%G9VDZ`$-O;G1R;VQL
M;R!O<G1O9W)A9FEC;R!P<FEM82!D:2!M86YD87)E('5N(&UE<W-A9V=I;S\`
M4V-E9VQI($%Z:6]N93H`4V-E9VQI('5N('-E<G9E<B!D:2!P;W-T83H`4V5L
M97II;VYA('5N(&%Z:6]N93H`4V5L97II;VYA(&-O;64@=FES=6%L:7IZ87)E
M(&QE(&1A=&4Z`%-C96=L:2!L82!R=6)R:6-A(&1A('5T:6QI>GIA<F4@<75A
M;F1O(&%G9VEU;F=I(&EN9&ER:7IZ:2X`4V-E9VQI(&PG;W)D:6YE(&EN(&-U
M:2!R:6-E<F-A<F4@;&4@<G5B<FEC:&4@<75A;F1O(&5S<&%N9&D@9VQI(&EN
M9&ER:7IZ:0!%;&EM:6YA('5T96YT93H@)7,`16QI;6EN82!U=&5N=&4`16QI
M;6EN82!L92!I;F9O<FUA>FEO;FD@9&5L;"=U=&5N=&4`0VQI8V-A("5S('!E
M<B!C;VYV97)T:7)E(&PG:6UM86=I;F4@:6X@=6X@9F]R;6%T;R!C;VUP871I
M8FEL92!C;VX@:6P@='5O(&)R;W=S97(`0VQI8V-A("5S('!E<B!S8V%R:6-A
M<F4@;"=I;6UA9VEN92X`0VQI8V-A("5S('!E<B!V961E<F4@8V]N=&5N=71O
M($A434P@:6X@=6YA(&9I;F5S=')A('-E<&%R871A+@!I0VQI8V-A("5S('!E
M<B!V961E<F4@:6P@=&AU;6)N86EL(&1I('%U97-T82!I;6UA9VEN90!#;&EC
M8V$@<75I('!E<B!-3U-44D%212!L92!I;6UA9VEN:0!38V5G;&D@=6YA(&1E
M;&QE('1U92!R=6)R:6-H92P@92!S96QE>FEO;F$@='5T=&D@:2!C86UP:2!D
M82!R:6-E<F-A<F4N`$-L:6-C82!P97(@0V]N=&EN=6%R90!#;&EC8V$@<&5R
M('-A;'9A<F4@;&$@8VAI879E(%!'4"!N96QL82!T=6$@4G5B<FEC82X`0VQI
M8V-A;F1O('-U;&PG:6YD:7)I>GIO('-I(&-O;7!O<G)A('5N(&YU;W9O(&UE
M<W-A9V=I;R!P97(@:6P@;6ET=&5N=&4`0VQI8V-A;F1O('-U;&PG:6YD:7)I
M>GIO('-I(&%P<FERX"!I;"!M97-S86=G:6\`0VAI=61I`$-H:75D:2!L82!&
M:6YE<W1R80!#:&EU9&D@<75E<W1A(&9I;F5S=')A`$-A<G1E;&QA($-H:75S
M80!.=79O;&4`3G5V;VQE`%)I9'5C:0!2:6-H:75D:2!T=71T90!2:6-H:75D
M:2!T=71T92!L92!C87)T96QL90!2:6-H:75D:2!C87)T96QL80!-87)G:6YI
M(&-O;&QA<W-A=&D`0V]L;W)E`$EN9&EC871O<F4@9&5L($-O;&]R93H`4V5L
M97II;VYA($-O;&]R90!#;VQO;FYE.@!6:6=N971T90!#;VUA;F1O`%-H96QL
M(&1I($-O;6%N9&D`0V]M;65N=&\`0V]M<&QE=&%T;P!#;VUP;VYI('5N(&%L
M=')O(&UE<W-A9V=I;P!5=&EL:7IZ82!U;F$@;G5O=F$@9FEN97-T<F$@<&5R
M(&-O;7!O<G)E('5N(&UE<W-A9V=I;RX`0V]M<&]N:2!M97-S86=G:2!C;VX@
M:6YT97)F86-C:6$@2%1-3"!D:2!D969A=6QT("AS92!I;"!T=6\@8G)O=W-E
M<B!S=7!P;W)T82!Q=65S=&$@9G5N>FEO;F4I/P!#;VYD:7II;VYI`$-O;F9I
M9W5R82`E<P!#;VYF:6=U<F$@8V]M92!V:7-U86QI>GIA<F4@:2!M97-S86=G
M:2X`0V]N9FEG=7)A(&]P>FEO;FD@86YT97!R:6UA('!O<W1A+@!#;VYF97)M
M82!087-S=V]R9`!#;VYN97-S:6]N92!A;"!S97)V97(@9F%L;&ET80!#;VYT
M:6YU80!697)I9FEC82!S=7!P;W)T;R!01U`@<&5R("5S+@!#;VYT<F]L;&$@
M<W5P<&]R=&\@4R]-24U%('!E<B`E<RX`1V5S=&ES8VD@:6P@8V]N=')O;&QO
M(&4@;&$@;F]T:69I8V$@9&5L;&$@4&]S=&$@:6X@07)R:79O+@!#;VYV97)T
M:2!%;6]T:6-O;B!T97-T=6%L:2!I;B!G<F%F:6-H90!#;W!I80!396QE>FEO
M;F4@;&$@8V]P:6$`0V]P:6$@86QL82!C87)T96QL80!#;W)R971T;P!497-T
M;R!#;W)R971T;P!.;VX@<&]S<V\@8W)E87)E(&EL(&)A8VME;F0@5D93.B`E
M<P!);7!O<W-I8FEL92!C86YC96QL87)E(&UE<W-A9V=I(&1A("5S+B!1=65S
M=&\@Z"!I;"!M97-S86=G:6\@9&5L('-E<G9E<CH@)7,`26UP;W-S:6)I;&4@
M97-E9W5I<F4@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4N`$EM<&]S
M<VEB:6QE(&5S=')A<G)E(&EL(&9I;&4@<FEC:&EE<W1O(&1A;&PG86QL96=A
M=&\@35,M5$Y%1BX`26UP;W-S:6)I;&4@97-T<F%R<F4@:6P@9FEL92!R:6-H
M:65S=&\@9&%L;"=A<F-H:79I;R!::7`N`$EM<&]S<VEB:6QE(&EN=F5R=&ER
M92!L82!C;VYF:6=U<F%Z:6]N92X`26UP;W-S:6)I;&4@<V%L=F%R92!L82!C
M;VYF:6=U<F%Z:6]N92`E<RX`26UP;W-S:6)I;&4@<V%L=F%R92!U;F$@8V]P
M:6$@9&D@<V-O<G1A(&1E;&QA(&-O;F9I9W5R87II;VYE`$-O<G-I`$-R96$`
M0W)E82!#87)T96QL80!#<F5A($-H:6%V:0!#<F5A('5N(&-O;&QE9V%M96YT
M;P!#<F5A('5N82!N=6]V82!C87)T96QL82!";WIZ90!#<F5A;F4@=6YO(&YU
M;W9O`$-R96$@=6YA(&YU;W9A(&-A<G1E;&QA(&1I(%!O<W1A($EN=FEA=&$`
M0W)E82!U;F$@;G5O=F$@8V%R=&5L;&$@0V5S=&EN;P!#<F5A(&D@9FEL=')I
M('!E<B!O<F=A;FEZ>F%R92!L82!P;W-T82!I;B!E;G1R871A+"!D:7-T<FEB
M=6ER;&$@:6X@8V%R=&5L;&4L(&5D(&5L:6UI;F%R92!L;R!S<&%M;6EN9RX`
M4&5R;65S<VD@9&D@0W)E871O<F4`3W)A(&%T='5A;&4`3&$@55),(&%T='5A
M;&4@Z`!-971E;R!!='1U86QE`$%C8V5S<V\@8V]R<F5N=&4@82`E<P!#;VYD
M:7II;VYI(&%T='5A;&DZ(`!3=&EL92!A='1U86QE`%!E<G-O;F%L:7IZ82!A
M8V-O=6YT('!E<B!S8V%R:6-A<F4@<&]S=&$@9&$@86QT<FD@86-C;W5N="X`
M4&5R<V]N86QI>GIA(&-O;64@:6YV:6D@;&$@<&]S=&$N`$EM<&]S=&$@;&4@
M;W!E<F%Z:6]N:2!D82!E<V5G=6ER92!Q=6%N9&\@96YT<FD@:6X@)7,N`%1A
M9VQI80!396QE>FEO;F4@5&%G;&EA`$='`$1A=%]A`$)R;W=S97(@1&%T851R
M964`1&%T80!$871A(%)I8V5V=71O`$=I;W)N;P!%7VQI;6EN82!#;VQO;FYA
M`$1I8V5M8G)E`$YU;65R;R!D96-I;6%L90!2:69I=71A=&\`0V]L;W)E(&1I
M($1E9F%U;'0`0W)I=&5R:2!D:2!O<F1I;F%M96YT;R!D:2!D969A=6QT.@!$
M:7)E>FEO;F4@9&D@;W)D:6YA;65N=&\@9&D@9&5F875L=#H`1&5L96=A=&\`
M16QI;6EN80!%;&EM:6YA("5S($-H:6%V92!0=6)B;&EC80!%;&EM:6YA($-H
M:6%V:2!!='1U86QI`$5L:6UI;F$@0V%R=&5L;&$H92D`16QM:6YA($=R=7!P
M;P!%;&EM:6YA(&-E;&QA`$5L:6UI;F$@8V]L;VYN80!!=G9I<V$@<W4@86=G
M:6]R;F%M96YT:0!%;&EM:6YA(&UE<W-A9V=I('-C87)I8V%T:2!D86P@<V5R
M=F5R(')E;6]T;S\`16QI;6EN82!L92!V96-C:&EE(&-A<G1E;&QE(&1I(%!O
M<W1A($EN=FEA=&$@860@:6YI>FEO(&UE<V4N`$5L:6UI;F$@;&4@=F5C8VAI
M92!C87)T96QL92!D:2!0;W-T82!);G9I871A(&%D(&EN:7II;R!M97-E+@!%
M;&UI;F$@<FEG80!%;&EM:6YA(&PG:61E;G1I=.`@<V5L97II;VYA=&$`16QI
M;6EN82!L82!C;VQO;FYA(&-O<G)E;G1E`$5L:6UI;F$@;&$@<FEG82!C;W)R
M96YT90!%;&EM:6YA=&\`365S<V%G9VD@96QI;6EN871I`$%L;&5G871O("(E
M<R(@96QI;6EN871O+@!'97-T:6]N92!E(&-A;F-E;&QA>FEO;F4@9&5I($UE
M<W-A9V=I`$YE9V$@<FEC:&EE<W1A`$YE9V$@<FEC:&EE<W1A('!E<B!I;F9O
M<FUA>FEO;FD@;&EB97)O+V]C8W5P871O`$1E8W)E<V-E;G1E`$1E<V-R:79I
M(&EL(%!R;V)L96UA`$1E<V-R:7II;VYE`$1E='1A9VQI`%-V:6QU<'!O`%!U
M;G1O(&1I(%)U9VEA9&$`1&EF9F5R96YZ:6$@;&$@9FER;6$@9&%L('1E<W1O
M+@!#87)T96QL80!6:7-U86QI>GIA`%9I<W5A;&EZ>F$@;F5L(&9O<FUA=&\@
M,C0@;W)E/P!/<'II;VYI(%9I<W5A;&EZ>F%Z:6]N90!-;W-T<F$@8V]N9F5R
M;6$@9&]P;R!I;G9I;R!M97-S86=G:6\_`$UO<W1R82!N96P@0V]R<&\@9&5L
M($UE<W-A9V=I;P!.;W1I9FEC82!C;VX@=6X@<&]P+75P('%U86YD;R!A<G)I
M=F$@3G5O=F$@4&]S=&$N`$1I<W!O<VEZ:6]N90!.;VX@8V]R<FES<&]N9&4`
M3F]N(&-O;G1R;VQL87)E(&PG87)R:79O(&1I($YU;W9A(%!O<W1A(&YE;&QA
M(&-A<G1E;&QA*&4I`$YO;B!E;&EM:6YA<F4`3F]N(&%C8V5D97)E(&1I<F5T
M=&%M96YT92!A(&UA:6YT96YA;F-E+G!H<`!.;VX@9V5N97)A<F4@=6X@;&EN
M:R!N96QL82!C;VQO;F$@1&$Z`%9U;VD@87!R:7)E('%U96QL82!C87)T96QL
M83\`3&$@<')I;6$@<FEG82!C;VYT:65N92!L92!E=&EC:&5T=&4@9&D@8V%M
M<&\_($UA<F-A('-E('-I+"!L87-C:6$@=G5O=&$@<V4@;F\Z`$9A='1O`%-C
M87)I8V$@)7,@:6X@9F]R;6%T=&\@+GII<`!38V%R:6-A(%1U='1I(&=L:2!!
M;&QE9V%T:2`H:6X@=6X@9FEL92`N>FEP*0!38V%R:6-A($-A<G1E;&QA*&4I
M`%-C87)I8V$@0V%R=&5L;&$H92D@6V9O<FUA='1O("YZ:7!=`%-C87)I8V$@
M;&$@8V]N9FEG=7)A>FEO;F4@9V5N97)A=&$@8V]M92!S8W)I<'0@4$A0+@!3
M8V%R:6-A(&EN(&9O<FUA='1O("YZ:7``0F]Z>F$`0V%R=&5L;&$@8F]Z>F4`
M0V%R=&5L;&$@8F]Z>F4Z`$EN9&ER:7IZ;R!%+6UA:6P`15)23U)%.B!);7!O
M<W-I8FEL92!C;VYS96=N87)E(&EL(&UE<W-A9V=I;RX`36]D:69I8V$@;&$@
M3&ES=&$@3F5R80!-;V1I9FEC82!";&]C8V\`36]D:69I8V$@1FEL=')I`$UO
M9&EF:6-A($=R=7!P;P!-;V1I9FEC82!097)M97-S:0!-;V1I9FEC82!P97)M
M97-S:2!P97(@)7,`36]D:69I8V$@;&$@3&ES=&$@0FEA;F-A`$UO9&EF:6-A
M(&]P>FEO;FD@<&5R.@!-;V1I9FEC82!P97)M97-S:2!P97(@)7,`36]D:69I
M8V$@;&$@='5A(&QI<W1A(&YE<F$`36]D:69I8V$@;&4@='5E(')E9V]L92!D
M:2!F:6QT<F\`36]D:69I8V$@;&4@='5E('!R969E<F5N>F4@<&5R(&%C8V5D
M97)E(&%D(&%L=')I(&%C8V]U;G0@9&D@<&]S=&$N`$UO9&EF:6-A(&QA('1U
M82!L:7-T82!B:6%N8V$`26YD:7)I>GIO($5M86EL`%1U='1I(&UE<W-A9V=I
M(&5L:6UI;F%T:2!D82`E<P!3=G5O=&$@0V%R=&5L;&$H92D`4W9U;W1A(&QA
M(&-A<G1E;&QA($-E<W1I;F\`4W9U;W1A(%]#97-T:6YO`$%B:6QI=&$@1G5N
M>FEO;F%L:73@(%!'4#\`06)I;&ET82!F=6YZ:6]N86QI=.`@4R]-24U%/P!!
M='1I=F$@06YT97!R:6UA($UE<W-A9V=I/P!/<'II;VYI($-R:7!?=&%G9VEO
M`$9I;F4`1FEN92!M97-S86=G:6\@:6YO;'1R871O+@!&26YE($UE<W-A9V=I
M;P!&:6YE(&UE<W-A9V=I;R!D82`E<P!);G-E<FES8VD@4&%R;VQA($-H:6%V
M90!);G-E<FES8VD@:6P@;F]M92!D96QL82!N=6]V82!C87)T96QL82!";WIZ
M90!);G-E<FES8VD@:6P@;F]M92!D96QL82!N=6]V82!C87)T96QL82!D:2!0
M;W-T82!);G9I871A`$ES97)I<V-I(&EL(&YO;64@9&5L;&$@=6YA(&YU;W9A
M(&-A<G1E;&QA($-E<W1I;F\`22!D871I("(E<R(@<V]N;R!S=&%T:2!A9V=I
M=6YT:2!A;&QA(%)U8G)I8V$@8V]N('-U8V-E<W-O`$5R<F]R90!%<G)O<F4@
M;F5L;"=I;G9I;R!D96QL82!R:7-P;W-T83H@)7,N`$]G;FD@,34@;6EN=71I
M`$]G;FD@,B!M:6YU=&D`3V=N:2`S,"!S96-O;F1I`$]G;FD@-2!M:6YU=&D`
M3V=N:2!M97IZ)V]R80!/9VYI(&UI;G5T;P!686QO<FD@9&D@97-E;7!I;SH`
M17-E8W5Z:6]N90!%<W!A;F1I`$5S<&%N9&D@5'5T=&4`17-P86YD:2!4=71T
M92!L92!#87)T96QL90!%<W!A;F1I($-A<G1E;&QA`$5S<&%N9&D@3F]M:0!%
M<W!A;F1I(&D@;F]M:2!N96QL82!F:6YE<W1R82!D:2!C;VUP;W-I>FEO;F4@
M875T;VUA=&EC86UE;G1E/P!%<W!A;F1I('1U='1E(&QE(&-A<G1E;&QE(&YE
M;&QA('9I<W5A;&EZ>F%Z:6]N92!P<F5D969I;FET82X`0V]L;W)E($9'`%5P
M;&]A9"`H0V%R:6-A;65N=&\I(&9I;&4@;F]N('-U<'!O<G1A=&\N`$=I=7-T
M;P!&96)B<F%I;P!3:2!S96YT92!C;VUE`%-I('-E;G1E(&-O;64Z(`!38V%R
M:6-A(%!O<W1A`%-C87)I8V$@;65S<V%G9VD@:6X@=6YA(&9I;F5S=')A('-E
M<&%R871A/RX`4V-A<FEC82!-97-S86=G:2!A9"!O9VYI(&%C8V5S<V\_`%-C
M87)I8V%M96YT;R!0;W-T83H`4&]C:&D@06-Q=6%Z>F]N:0!&:5]L=')I`$9I
M;&4`1FEL92!-86YA9V5R`$]P>FEO;FD@1FEL=')I`$EM<&]S=&%Z:6]N:2!&
M:6QT<FD`0V]N=')O;&QA('-E(&YE:2!M97-S86=G:2!C:2!S;VYO('!A<F]L
M92!O9F9E;G-I=F4N`%-U<'!O<G1O(&9I;'1R:2#H(&1I<V%B:6QI=&%T;R!S
M=2!Q=65S=&\@<VES=&5M82X`1FEL=')I`$9I;'1R:2!.3TX@071T:79I`%1R
M;W9A`%!R:6UA($UE=&$G`%!R:6UA(%!A9VEN82!D96QL82!-86EL8F]X`%!R
M:6UA(%!A9VEN80!0<FEM;R!4<FEM97-T<F4`1FQO870`26Y?;VQT<F$`17-P
M;&]R82!L92!C87)T96QL90!3;VUM87)I;R!#87)T96QL80!#;VYD:79I<VEO
M;F4@8V%R=&5L;&4@;F]N(&%B:6QI=&%T;RX`57-O(&1I(&-A<G1E;&QE(&YO
M;B#H(&%B:6QI=&%T;RX`0V]L;W)E($9O;G0`4&5R(&)R;W=S97(@8VAE(&YO
M;B!S;W!P;W)T86YO(&QE(&EM;6%G:6YI`$AA:2!D:6UE;G1I8V%T;R!L82!T
M=6$@<&%S<W=O<F0_`$9O<FUA=&\@9&5L;&$@9&%T82!D96P@;65S<V%G9VEO
M(&YE;&QA(&UA:6QB;W@@<&5R(&D@;65S<V%G9VD@9&D@;V=G:0!-;V1U;&D`
M26YD;W9I;F\`1F]R='5N92!4>7!E`$9O<G1U;F5S`$9O<G5M`$EN;VQT<F$`
M26YO;'1R83H`365S<V%G9VEO($EN;VQT<F%T;P!-97-S86=G:6\@:6YO;'1R
M871O(&1A("5S`$EN;VQT<FD`5F5N`$9R86UE<P!);F9O<FUA>FEO;F4@3&EB
M97)O+T]C8W5P871O`%)I<W!O<W1A($QI8F5R;R]/8V-U<&%T;P!2:6-H:65S
M=&$@3&EB97)O+T]C8W5P871O`%)I<W!O<W1A(&$@<FEC:&EE<W1A($QI8F5R
M;R]/8V-U<&%T;P!$7V$`1&$`1&$@26YD:7)I>GIO`$1A;"``1&5S8W)I>FEO
M;F4@0V]M<&QE=&$`3'5N82!0:65N80!.;VUE($-O;7!L971O`$EN;VQT<F\Z
M`$9W9#H@`$9W9#H@)74@365S<V%G9VD@26YO;'1R871I`$]P>FEO;FD@1V5N
M97)A;&D`1V5N97)A($-O;F9I9W5R87II;VYE("5S(`!#;V1I8V4@1V5N97)A
M=&\`3W1T:65N:2!S;VQO(&YU;W9I(&UE<W-A9V=I/R`H<V]L;R!)34%0*0!6
M86D@86P@365S<V%G9VEO`%)I8V5R8V$@1V]O9VQE`$%S<V5G;F$@06-C97-S
M;P!!;6UI;FES=')A>FEO;F4@1W)U<'!I`$=R=7!P:0!097)M97-S:2!/<W!I
M=&D`455)`$A434P`5F5R<VEO;F4@2%1-3"!D96P@365S<V%G9VEO`$EN=&5S
M=&%Z:6]N:0!!;'1E>GIA`$%I=71O`$5M:7-F97)O`$UE<W-A9V=I;R!C:&4@
M<W1A=FD@8V]M<&]N96YD;SH`3F%S8V]S=&\`3F%S8V]S=&\@;F5L;&$@5FES
M=6%L:7IZ87II;VYE('!E<B!!<F=O;65N=&\`3F%S8V]N9&D@16QI;6EN871I
M`$-A;F-E;&QA(&YO;B!S;W1T;W-C<FET=&D`06QT80!0<FEO<FETX"!A;'1A
M`$%L=&ES<VEM80!(;U]R9&4`2&]R9&4`4FEE;7!I;65N=&\@3W)I>GIO;G1A
M;&4`3W)I>GIO;G1A;&4Z`$-O;64@=G5O:2!M;W-T<F%R92!G;&D@86QL96=A
M=&D_`%%U86YT92!C;VQO;FYE('9U;VD@=6YI<F4_`%%U86YT:2!C86UP:2`H
M8V]L;VYN92D@8VD@<V]N;S\`475A;G1E(')I9VAE('9U;VD@=6YI<F4_`$-O
M;64@871T<FEB=6ER92!L92!L:6YE92!C:71A=&4@:6X@=6YA(')I<W!O<W1A
M`%5M:61I=.``24U!4`!)34%0("A0<F]T;V-O;"!!=71O;6%T:6-O*0!)34%0
M('9I82!34TP`24U!4"!V:6$@4U-,("AC97)T9FEC871O(&%U=&\M9FER;6%T
M;RD`24U!4"!V:6$@4U-,("AA=71O+69I<FUA=&\I`$E-05`L('-E;GIA(%1,
M4P!)34%0+U!/4#,@4V5R=F5R(&1I(%!O<W1A`$E.0D]8`$E?;G-E<FES8VD@
M;&$@<FEG82!P<FEM80!3;VQO($EC;VYE`$EC;VYE(&-O;B!497-T;P!.;VUE
M(&1E;&PG261E;G1I=.`Z`$EG;F]R80!)9VYO<F$@5'5T=&D`06YT97!R:6UE
M($EM;6%G:6YE`%523"!);6UA9VEN90!54DP@26UM86=I;F4`26UM86=I;FD`
M26UP;W)T80!);7!O<G1A($-H:6%V90!);7!O<G1A($-H:6%V92!01U``26UP
M;W)T82!#:&EA=F4@4$=0`$EM<&]R=&$@0VAI879E(%!E<G-O;F%L92!0<FEV
M871A(%!'4`!);7!O<G1A($-H:6%V92!097)S;VYA;&4@4'5B8FQI8V$@4$=0
M`$EM<&]R=&$@0VAI879E(%!U8F)L:6-A`$EM<&]R=&$@0VAI879E(%!U8F)L
M:6-A(%!'4`!);7!O<G1A(&-H:6%V92!3+TU)344`26UP;W)T82!&:6QE(&UB
M;W@`26UP;W)T82!&:6QE(&UB;W@@)7,@;F5L;&$@8V%R=&5L;&$@)7,N`$EM
M<&]R=&$L(%!A<W-O("5D`$EM<&]R=&%N=&4`365S<V%G9VD@:6UP;W)T86YT
M:0!);7!O<G1A=&D@)60@;65S<V%G9VD@9&$@)7,N`$-A;7!O(&EM<&]R=&%T
M;SH@)7,`0V%M<&D@:6UP;W)T871I.@!);B!0<F]C97-S;P!);E]S97)I<V-I
M('5N82!R:6=A(&1O<&\`4&]S=&$@:6X@07)R:79O`$EN8VQU9&D@=6X@8G)E
M=F4@<V]M;6%R:6\@9&5L;&4@:6YT97-T87II;VYI(&YE;&QA(')I<W!O<W1A
M/P!);F-L=61I(&EL(&UE<W-A9V=I;R!O<FEG:6YA;&4@;F5L;&$@<FES<&]S
M=&$N`%5T96YT:2!);F1I=FED=6%L:0!);F9O`$EN9F]R;6%Z:6]N90!);F9O
M<FUA>FEO;FD@<W5L;&$@0VAI879E(%!U8F)L:6-A("5S`$EN9F]R;6%Z:6]N
M:2!S=6QL82!#:&EA=F4@4'5B8FQI8V$@4')I=F%T80!);F9O<FUA>FEO;FD@
M<W5L;&$@0VAI879E(%!U8F)L:6-A(%!E<G-O;F%L90!);B!L:6YE80!);G-E
M<FES8VD@=6YA($-?;VQO;FYA(&1O<&\`26YS97)I<V-I('5N)VEM;6%G:6YE
M`$EN<V5R:7-C:2!486)E;&QA`$EN<V5R:7-C:2!#;VQL96=A;65N=&\@5V5B
M`$EN<V5R:7-C:2!?8V]L;VYN82!0<FEM80!);G-E<FES8VD@=6YA(&YU;W9A
M(&-O;&]N;F$@9&]P;R!Q=65L;&$@8V]R<F5N=&4`26YS97)I<V-I('5N82!N
M=6]V82!C;VQO;FYA('!R:6UA(&1I('%U96QL82!C;W)R96YT90!);G-E<FES
M8VD@=6YA(&YU;W9A(')I9V$@9&]P;R!Q=65L;&$@8V]R<F5N=&4`26YS97)I
M<V-I('5N82!N=6]V82!R:6=A('!R:6UA(&1I('%U96QL82!C;W)R96YT90!)
M;G-E<FES8VD@=6X@=&5M<&QA=&4@86QT97)N871I=F\`26YS97)I<V-I(&-E
M;&QA(&1O<&\`26YS97)I<V-I(&-E;&QA('!R:6UA`$%G9VEU;F=I(&-O;&]N
M;F$@9&]P;P!);G-E<FES8VD@8V]L;VYN82!P<FEM80!);G-E<FES8VD@<&%R
M86=R869O(&1O<&\`26YS97)I<V-I('!A<F%G<F%F;R!P<FEM80!);G-E<FES
M8VD@<FEG82!D;W!O`$EN<V5R:7-C:2!R:6=A('!R:6UA`$EN<V5R:7-C:2]-
M;V1I9FEC82!);6UA9VEN90!!>FEO;F4@:6YV86QI9&$@<&5R('%U97-T;R!C
M;VUP;VYE;G1E+@!);F1I<FEZ>F\@26YV86QI9&\`0V%S96QL82!D:2!P;W-T
M82!R96UO=&$@:6YV86QI9&$`07!P;&EC87II;VYE(&EN=F%L:61A+@!#:&EA
M=F4@:6YV86QI9&$`1&%T;R!N;VX@=F%L:61O+@!#:&EA=F4@4')I=F%T82!0
M1U`@<&5R<V]N86QE(&EN=F%L:61A+@!#:&EA=F4@4'5B8FQI8V$@4$=0('!E
M<G-O;F%L92!I;G9A;&ED82X`26YV96YT87)I;P!);G9E<G1A`$-O<G-I=F\`
M1V5N;F%I;P!':6%P<&]N97-E("A)4T\M,C`R,BU*4"D`3'5G;&EO`$=I=6=N
M;P!':75S=&EF:6-A=&\`2T(`3'5N9VAE>GIA(&-H:6%V90!#:&EA=F4@:6YV
M:6%T82!C;VX@<W5C8V5S<V\@86P@<V5R=F5R('!U8F)L:6-O+@!?1F]R;6%T
M;P!,:6YG=6$`56QT:6UA(%!A9VEN82!D96QL($-A<G1E;&QA`%5L=&EM82!0
M86=I;F$`56QT:6UO(%%U87)T;P!5;'1I;6\@06=G:6]R;F%M96YT;SH`56QT
M:6UO(&%C8V5S<V\Z("5S`%5L=&EM;R!A8V-E<W-O.B`E<R!D82`E<P!5;'1I
M;6\@86-C97-S;SH@36%I`$9O<FUA=&\`<VEN:7-T<F$`0V]L;&5G86UE7VYT
M;R!!;&QE9V%T:0!0:6]G9VEA($QE9V=E<F$`26P@8V]L;&5G86UE;G1O(&%G
M;&D@86QL96=A=&D@;F]N(.@@<&5R;65S<V\`16QE;F-A(&=L:2!A<F=O;65N
M=&D@9&D@06EU=&\`0V%R:6-A('1U='1I(&D@8V]N=&%T=&D@<75A;F1O(&UO
M<W1R:2!S8VAE<FUO(&-O;F%T=&D_("AS92!D:7-A8FEL:71A=&\@=F5D<F%I
M('-O;&\@:2!C;VYT871T:2!C:&4@<FEC97)C:&D@97-P;&EC:71A;65N=&4I
M`$QI<W1A(&YE;&PG26YT97-T87II;VYE`$YO;B#H(&%T=&EV82!L82!F=6YZ
M:6]N92!D:2!E;&5N8V\@=71E;G1I+@!,:71E<F%T=7)A`$-A<V5L;&$@9&D@
M4&]S=&$@;&]C86QE.@!/<F$@;&]C86QE.B``3&EN9W5A(&4@3W)A`$QU;V=O
M`$5N=')A`$5N=')A(&EN("5S`$5S8VD`16YT<F$`3W!E<F%Z:6]N:2!D82!E
M<V5G=6ER92!A(&EN:7II;R!S97-S:6]N90!"87-S80!0<FEO<FETX"!"87-S
M80!N=6UE<FD@<F]M86YI('!I^2!B87-S:0!-:6YI;6\`34T`1FEL92!-86-I
M;G1O<V@`4&]S=&$`26YD:7)I>GIO($%M;6EN:7-T<F%T;W)E`$%N=&5P<FEM
M92!D:2!0;W-T80!4:7!O(%-E<G9E<B!D:2!0;W-T82!P97(@:6P@8V]L;&5G
M86UE;G1O.@!#87-E;&QA(&1I(%!O<W1A`$]P>FEO;FD@9&D@5FES=6%L:7IZ
M87II;VYE(&1I($-A<G1E;&QE`$=E<W1I<V-I(&QA(&QI<W1A(&1E;&QE(&-A
M=&5G;W)I92!D86YD;R!L;W)O('5N)V5T:6-H971T82!E(&%S<V]C:6%N9&\@
M;&]R;R!U;B!C;VQO<F4N`$UA<GIO`$UA<F=I;F4`0V]N=')A<W-E9VYA('1U
M='1I(&D@;65S<V%G9VD@;F5L;&$@8V%R=&5L;&$@8V]M92!L971T:0!#;VYT
M<F%S<V5G;F$@='5T=&D@:2!M97-S86=G:2!N96QL82!C87)T96QL82!C;VUE
M(&YO;B!L971T:0!#;VYT<F%S<V5G;F$@8V]M93H`36]S=')A(&D@=F%R:2!L
M:79E;&QI(&1I(&-I=&%Z:6]N92!C;VX@8V]L;W)I(&1I=F5R<VDN`%-E9VYA
M(&UE<W-A9V=I(&-O;64@=FES=&D_("AS;VQO($E-05`I`$-O;6)A8VEA(%1U
M='1E(&QE($1O;6%N9&4`0V]M8F%C:6$@56YA($1O;6%N9&$`0V%M<&D@8V]R
M<FES<&]N9&5N=&D`36%S<VEM82!$:6UE;G-I;VYE(&1E9VQI($%L;&5G871I
M`$EL(&YU;65R;R!M87-S:6UO(&1I(&%L;&5G871I(.@@<W1A=&\@<F%G9VEU
M;G1O+@!);"!T;W1A;&4@;6%S<VEM;R!D:2!A;&QE9V%T:2#H('-T871O(')A
M9V=I=6YT;RX`36%G9VEO`$-A;F-E;&QA>FEO;F4@4FEU;FEO;F4`26YF;W)M
M87II;VYI(%)I=6YI;VYE`%!R;W!O<W1A(%)I=6YI;VYE`%)I<W!O<W1A(%)I
M=6YI;VYE`$%G9VEO<FYA;65N=&\@4FEU;FEO;F4`4FEC:&EE<W1A(&%G9VEO
M<FYA;65N=&\@4FEU;FEO;F4`365M8G)I`$QI<W1A($-A<G1E;&QA`%5N:7-C
M:2!#96QL90!-97-S86=G:6\`0V]M<&]S:7II;VYE($UE<W-A9V=I;P!$871A
M($UE<W-A9V=I;P!/<'II;VYI($UE<W-A9V=I`%)I8V5R8V$@365S<V%G9VEO
M`$1I;65N<VEO;F4@365S<V%G9VEO`$EN=&5S=&%Z:6]N:2!-97-S86=G:6\`
M5FES=6%L:7IZ87II;VYE($UE<W-A9V=I;P!#;VYT<F%S<V5G;FD@9&5L(&UE
M<W-A9V=I;P!#87)T96QL90!-97-S86=G:6\@9&$@)7,`365S<V%G9VD@=')O
M=F%T:0!-97-S86=G:6\@<F5I;F1I<FEZ>F%T;R!C;VX@<W5C8V5S<V\N`$UE
M<W-A9V=I;R!I;G9I871O(&-O;B!S=6-C97-S;RP@;6$@;F]N('-A;'9A=&\@
M:6X@)7,`365S<V%G9VEO(&EN=FEA=&\@8V]N('-U8V-E<W-O+@!.=6UE<F\@
M9&D@;65S<V%G9VD@<&5R('!A9VEN82!N96QL82!V:7-U86QI>GIA>FEO;F4@
M9&5L;&$@8V%R=&5L;&$N`$UE<W-A9V=I(&$`365T96\@071T=6%L90!";&]C
M:R!N;VX@9&ES<&]N:6)I;&4N`$1E='1A9VQI(&QO9V=A=&D@<&5R(&PG86UM
M:6YI<W1R871O<F4`;65T<FEC;P!#96YT<F\`3'5N`$UO8FEL92!-86EL`$UO
M9&5R871O`$UO9&EF:6-A`$UO9&EF:6-A(%523`!0<FEN8VEP86QM96YT92!3
M97)E;F\`4W!O<W1A`%-P;W-T82!G:?D`4W!O<W1A(&%L;&$@8V%R=&5L;&$`
M4W!O<W1A('-U`$UU;'1I<&%R="]A;'1E<FYA=&EV90!-:6\@06-C;W5N=`!-
M:6\@4&]R=&%L90!&;W)M871O(&1E;"!-:6\@4&]R=&%L90!.3RP@3D].(%-O
M;F\@9"=!8V-O<F1O+@!.3U1!`$YO;64`3F]M92!E+V\@96UA:6P@;F]N('!O
M<W-O;F\@97-S97)E('9U;W1I`$%Z:6]N92!.96-E<W-A<FEA`%)E=&4`36%I
M`$%L;&5G871O(&UA:2!S86QV871I`$YU;W9O`$YU;W9A($-A=&5G;W)I80!.
M=6]V82!#87)T96QL80!.=6]V82!0;W-T80!.=6]V;R!.;VUE(%5T96YT92`H
M3W!Z:6]N86QE*0!.=6]V:2!M97-S86=G:0!.;W1I>FEE`$=R=7!P:2!D:2!N
M;W1I>FEE`%-U8V-E<W-I=F\`365S<V%G9VEO(%-U8V-E<W-I=F\`4&%G:6YA
M(%-U8V-E<W-I=F$`3F]T=&4`3F\`3F5S<W5N(&-E<G1I9FEC871O('1R;W9A
M=&\`3F5S<W5N($-R:7!T86=G:6\`3F5S<W5N82!C:&EA=F4@;F5L($ME>7)I
M;F<`3F5S<W5N($UE<W-A9V=I;P!.97-S=6YA(&-H:6%V92!01U`@:6UP;W)T
M871A+@!.97-S=6X@06QL96=A=&\@5')O=F%T;P!.;VX@<'5O:2!C<F5A<F4@
M9FEG;&D@82!Q=65S=&\@<&5R;65S<V\N`$YE<W-U;F$@8V%R=&5L;&$@<V5L
M97II;VYA=&$N`$YE<W-U;F$@8V%R=&5L;&$@<V5L97II;VYA=&$@<&5R(&YU
M;W9A('!O<W1A+@!.;VX@<V]N;R!S=&%T92!S<&5C:69I8V%T92!C87)T96QL
M90!.97-S=6YA(&-A<G1E;&QA(&-O;B!D96D@;G5O=FD@;65S<V%G9VD`3F5S
M<W5N82!C87)T96QL82!C;VX@9&5I(&UE<W-A9V=I(&YO;B!V:7-T:2X`3F5S
M<W5N('1E<W1O(&1E;"!C;W)P;R!M97-S86=G:6\N`$YE<W-U;B!M97-S86=G
M:6\@8V]R<FES<&]N9&5N=&4@=')O=F%T;RX`3F5S<W5N82!R96=I<W1R87II
M;VYE(&EN(&%T=&5S82X`3F5S<W5N82!C:&EA=F4@<')I=F%T82!01U`@:6UP
M;W)T871A+@!.97-S=6YA(&-H:6%V92!P=6)B;&EC82!01U`@:6UP;W)T871A
M+@!.97-S=6YA(')E9V]L80!.97-S=6X@;&%T;P!.97-S=6X@<')O9W)A;6UA
M(&1I(&-O;G1R;VQL;R!O<G1O9W)A9FEC;R!C;VYF:6=U<F%T;RX`3F5S<W5N
M(&5R<F]R92!D:2!O<G1O9W)A9FEA`$YE<W-U;B!S=6=G97)I;65N=&\`3F5S
M<W5N(&1I<F5T=&]R:6\@=&5M<&]R86YE;R!D:7-P;VYI8FEL92!P97(@;&$@
M8V%C:&4N`$YE<W-U;B!U=&5N=&4@<W!E8VEF:6-A=&\N`$YE<W-U;F$@=F5R
M<VEO;F4@=')O=F%T82!N96QL82!C;VYF:6=U<F%Z:6]N92!O<FEG:6YA;&4N
M(%)E9V5N97)A(&QA(&-O;F9I9W5R87II;VYE+@!.97-S=6YA('9E<G-I;VYE
M('1R;W9A=&$@;F5L;&$@='5A(&-O;F9I9W5R87II;VYE+B!296=E;F5R82!L
M82!C;VYF:6=U<F%Z:6]N92X`3F]N(%!A<G1E8VEP86YT90!.97-S=6YO`$YO
M<FUA;&4`3F]N($5L:6UI;F%T;P!.;VX@0F]Z>F$`3F]N($EM<&]R=&%N=&4`
M3F]N(%!E<G-O;F%L90!#:&EA=F4@<'5B8FQI8V$@;F]N('9A;&ED82X`365S
M<V%G9VD@;F]N(&5L:6UI;F%T:0!-97-S86=G:2!N;VX@:6UP;W)T86YT:0!.
M;VX@:6UP;W-T871O`$YO=&$@8VAE('%U97-T;R!P=6\G(')I8VAE9&5R92!U
M;B!P;R<@9&D@=&5M<&\`3F]T90!.;W9E;6)R90!.=6UE<F\@9&D@8V]L;VYN
M90!1=6%N=&D@;65S:2!C;VYS97)V87)E('9E8V-H:2!A;&QE9V%T:2!S92!I
M;7!O<W1A=&$@96QI;6EN87II;VYE(&UE;G-I;&4`3G5M97)O(&1I('9E8V-H
M:64@8V%R=&5L;&4@9&D@4&]S=&$@26YV:6%T82!D82!M86YT96YE<F4@<V4@
M=F5N9V]N;R!E;&EM:6YA=&4@;65N<VEL;65N=&4N`$YU;65R;R!D:2!R:6=H
M90!/2P!/`%!R;W!R:65T87)I;P!/='1O8G)E`%5F9FEC:6\`5F5C8VAI(&UE
M<W-A9V=I`$5L:6UI;F%Z:6]N92!D96QL92!V96-C:&EE(&-A<G1E;&QE(&1I
M(%!O<W1A($EN=FEA=&$N`$UO<W1R82!S;VQO(&-A<G1E;&QE(&-O;B!M97-S
M96=G:2!N;VX@;&5T=&D_`%-O;&\@=6YA(&-A<G1E;&QA('!U\B!E<W-E<F4@
M<V5L97II;VYA=&\@<&5R('%U97-T82!A>FEO;F4`07!R:2!I;B!N=6]V82!F
M:6YE<W1R80!#87)T96QL82!!<&5R=&$`07!R:2!Q=65S=&\@8V]L;&5G86UE
M;G1O(&EN(&YU;W9A(&9I;F5S=')A`%!A<G1E8VEP86YT92!O<'II;VYA;&4`
M3W!Z:6]N:0!/<'II;VYI(&9O<B`E<P!'<F]U<%=A<F4`87!P;&EC87II;VYE
M(&EN=&5R;F$`06QT<F\`06QT<F4@26YF;W)M87II;VYI`$%L=')I($%C8V]U
M;G0@9&D@4&]S=&$`06QT<F4@3W!Z:6]N:0!097)M97-S:2!D96P@4')O<')I
M971A<FEO`%!'4`!#<FEP=&$@365S<V%G9VEO(%!'4`!%<G)O<F4@4$=0.B``
M17)R;W)E(%!'4#H@Z"!N96-E<W-A<FEA('5N82!P87)O;&$@8VAI879E('!E
M<B!L82!C:&EA=F4@<')I=F%T82!P97)S;VYA;&4N`$]P>FEO;FD@4$=0`$EN
M<'5T(%!A<F]L82!#:&EA=F4@4$=0`$EL('-U<'!O<G1O(&1E;&QA(&-H:6%V
M92!01U`@;F5C97-S:71A(&1I('5N82!C;VYN97-S:6]N92!S:6-U<F$N`%1E
M<W0@0VAI879E(%!'4"!0=6)B;&EC80!,82!C:&EA=F4@4'5B8FQI8V$@4$=0
M('!E<B`B)7,@*"5S*2(@Z"!S=&%T82!A9V=I=6YT82!C;VX@<W5C8V5S<V\N
M`$QA($-H:6%V92!0=6)B;&EC82!01U`@<&5R("(E<R(@Z"!S=&%T82!E;&EM
M:6YA=&$@8V]N('-U8V-E<W-O+@!#:&EA=F4@4'5B8FQI8V$@4$=0`$9I<FUA
M($UE<W-A9V=I;R!01U``1FER;6$O0W)I<'1A(&UE<W-A9V=I;R!01U``0VAI
M879E('!R:79A=&$@4$=0(&%G9VEU;G1A(&-O;B!S=6-C97-S;RX`0VAI879E
M('!U8F)L:6-A(%!'4"!A9V=I=6YT82!C;VX@<W5C8V5S<V\N`%-U<'!O<G1O
M(%!'4"!D:7-A8FEL:71A=&\@<W5L('-I<W1E;6$N`$EL('-U<'!O<G1O(%!'
M4"!N;VX@Z"!A='1I=F\L('!E<B!C=6D@Z"!I;7!O<W-I8FEL92!V97)I9FEC
M87)E(&QA(&9I<FUA(&5L971T<F]N:6-A+@!);"!S=7!P;W)T;R!01U`@;F]N
M(.@@871T:79O+"!P97(@8W5I(.@@:6UP;W-S:6)I;&4@9&5C<FEP=&%R92!I
M;"!M97-S86=G:6\N`$-O9&EC92!02%``4$T@4&EO9V=I82!,96=G97)A`%!/
M4#,`4$]0,R`H4')O=&]C;VQL;R!!=71O;6%T:6-O*0!03U`S('9I82!34TP`
M4$]0,R!V:6$@4U-,("AC97)T:69I8V%T;R!A=71O+69I<FUA=&\I`%!/4#,@
M=FEA(%-33"`H875T;RUF:7)M871O*0!03U`S+"!S96YZ82!43%,`4&%G:6YA
M("5D(&1I("5D`%!A9VEN82!C;VX@:6P@4')I;6\@365S<V%G9VEO($YO;B!6
M:7-T;P!086=I;F$@8V]N(&PG56QT:6UO($UE<W-A9V=I;R!.;VX@5FES=&\`
M4&%R=&4H:2D`4&%R;VQA(&-H:6%V90!087)O;&$@8VAI879E("AA;F-O<F$I
M`%!A<F]L82!C:&EA=F4@<V-A<FEC871A(&-O;B!S=6-C97-S;RX`4&%R;VQA
M(&-H:6%V93H`3&4@<&%R;VQE(&-H:6%V92!N;VX@<&]S<V]N;R!E<W-E<F4@
M=G5O=&4`3&$@<&%R;VQE(&-H:6%V92!N;VX@8V]R<FES<&]N9&]N;P!087-S
M=V]R9`!087-S=V]R9#H`4&%S<W=O<F0Z(`!,92!P87-S=V]R9"!D979O;F\@
M8V]R<FES<&]N9&5R92X`26YC;VQL80!097)C;W)S;P!296=I<W1R87II;VYI
M(&EN($%T=&5S83H`4&5R8V5N='5A;&4`17-E9W5I(&QE($]P97)A>FEO;FD@
M9&D@36%N=71E;GII;VYE`$5S96=U:2!L92!O<&5R87II;VYI(&1I(&UA;G5T
M96YZ:6]N92!A;"!L;V=I;C\`4&5R;65S<VD`06UM:6YI<W1R87II;VYE(&1E
M:2!097)M97-S:0!)('!E<FUE<W-I('!E<B!Q=65S=&\@=71E;G1E(&YO;B!P
M;W-S;VYO(&5S<V5R92!M;V1I9FEC871I+@!097)S;VYA;&4`26YF;W)M87II
M;VYI(%!E<G-O;F%L:0!#;W!P:6$@8VAI879I(%!'4"!G96YE<F%T82!C;VX@
M<W5C8V5S<V\N`$-H:6%V92!P97)S;VYA;&4@4$=0(&-A;F-E;&QA=&$@8V]N
M('-U8V-E<W-O+@!#:&EA=F4@<&5R<V]N86QE(%,O34E-12!C86YC96QL871A
M(&-O;B!S=6-C97-S;RX`1F]T;P!0:7AE;`!);G-E<FES8VD@;&$@='5A(&9I
M<FUA('!R:6UA(&1I(')I<W!O<W1E(&4@:6YO;'1R:2X`36]S=')A(%9E<G-I
M;VYE(%-O;&\@5&5S=&\@9&5L($UE<W-A9V=I;P!0<F5G;R!C;VYF97)M87)E
M(&5L:6UI;F%Z:6]N92!E;&5M96YT;SH`4')E9V\@8V]N9F5R;6%R92!E;&EM
M:6YA>FEO;F4@;&EN:SH`26YS97)I<V-I('5N(&YO;64@<&5R(&QA(&YU;W9A
M(&-A=&5G;W)I83H`26YS97)I<V-I('5N(&YO;64@<&5R(&QA(&YU;W9A(&-A
M<G1E;&QA.@!);G-E<FES8VD@:6P@;F]M92!D96QL82!N=6]V82!C87)T96QL
M83H`26YS97)I<V-I(&EL(&YU;W9O(&YO;64Z`%!E<B!C;W)T97-I82!I;G-E
M<FES8VD@;&$@<&%S<W=O<F0@<&5R(&QA('1U82!C:&EA=F4@<')I=F%T82!0
M1U`N($1O=G)A:2!I;G-E<FER;&$@<V]L;R!U;F$@=F]L=&$@<&5R("5S('-E
M<W-I;VYE+@!097(@8V]R=&5S:6$@:6YS97)I<V-I(&QA('!A<W-W;W)D('!E
M<B!L82!T=6$@8VAI879E('!R:79A=&$@4R]-24U%+B!$;W9R86D@:6YS97)I
M<FQA('-O;&\@=6YA('9O;'1A('!E<B`E<R!S97-S:6]N92X`26YS97)I<V-I
M(&QA('1U82!P87-S=V]R9"X`1&5V:2!I;G-E<FER92!I;"!T=6\@;F]M92!U
M=&5N=&4@92!L82!P87-S=V]R9`!);G-E<FES8VD@:6P@='5O(&YO;64@=71E
M;G1E+@!#;W)R96=G:2!G;&D@:6YD:7)I>GII(&%M8FEG=6D@;R!N;VX@=F%L
M:61I+@!2:79E9&D@;&4@<V5G=65N=&D@:6YF;W)M87II;VYI+"!E('!O:2!S
M96QE>FEO;F4@=6XG87II;VYE(&1A;"!M96YU('%U:2!S;W1T;R``4V5L97II
M;VYA('5N82!C87)T96QL82!P<FEM82!D:2!E<V5G=6ER92!U;F$@87II;VYE
M+@!396QE>FEO;F$@=6XG87II;VYE(&1A;"!M96YU('%U:2!S;W1T;RX`4V5L
M97II;VYA(&%L;65N;R!U;F$@8V%R=&5L;&$@:6X@8W5I(&-E<F-A<F4N`%-E
M;&5Z:6]N82!S;VQO('5N82!C87)T96QL82!P97(@<75E<W1A(&]P97)A>FEO
M;F4N`%-E;&5Z:6]N82!O('-C<FEV:2!N96QL82!C87-E;&QA(&$@9&5S=')A
M.@!3;VYD86=G:0!0;W-I>FEO;F%M96YT;R!D:2!Q=65S=&$@:6UM86=I;F4N
M`%!O<VEZ:6]N86UE;G1O(&1I('%U97-T82!T86)E;&QA`$9A:2!P<F5C961E
M<F4@;&$@='5A(&9I<FUA(&1A('1R871T:6YI("@G+2T@)RD_`%!R969E<F5N
M>F4@86=G:6]R;F%T92!C;VX@<W5C8V5S<V\N`%!R97-S:6]N90!0<F5S<VEO
M;F4@86P@;&EV96QL;R!D:2!M87)E.B``4')E<W-I;VYE.B``06YT97!R:6UA
M`$%N=&5P<FEM82!D96QL)VEM;6%G:6YE(&EN(&YU;W9A(&9I;F5S=')A`$UE
M<W-A9V=I;R!0<F5C961E;G1E`%!A9VEN82!0<F5C961E;G1E`%-T86UP80!3
M=&%M<&$@9&]C=6UE;G1O(`!0<FEO<FETX`!0<F]B;&5M80!$97-C<FEZ:6]N
M92!D96P@<')O8FQE;6$`4')O9V5T=&D`4FEC:&EE9&D@;V=N:2!V;VQT82!C
M:&4@=FEE;F4@:6YV:6%T;R!U;B!A;&QE9V%T;SL@9&5F875L="!.3P!2:6-H
M:65D:2!O9VYI('9O;'1A(&-H92!V:65N92!I;G9I871O('5N(&%L;&5G871O
M.R!D969A=6QT(%-)`%!R;W1O8V]L;&\Z`%-U<'!O<G1O('-E<G9E<B!P=6)B
M;&EC;R!01U`@9&ES86)I;&ET871O`%)I7VUU;W9I($5L:6UI;F%T:0!2:6UU
M;W9I($5L:6UI;F%T:0!3=G5O=&$@0V%R=&5L;&$H92D`3V=N:2!Q=6%N=&\@
M<W9U;W1A<F4@:6P@0V5S=&EN;SH`16QI;6EN82!I(&UE<W-A9V=I(&1A;&QA
M(&-A<G1E;&QA($-E<W1I;F\@<&GY('9E8V-H:2!D:2!G:6]R;FDN`$5L:6UI
M;F$@=F5C8VAI(&UE<W-A9V=I(&YE;&QA(&-A<G1E;&QA($-E<W1I;F\_`$1O
M;6%N9&$`4W1A='5S(%%U;W1A.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I
M`%-T871U<R!156]T83H@3F5S<R!,:6UI=&4`4&EO9V=I80!0:6]G9VEA(%!R
M97-T;P!0:6]G9VEA(%1A<F1I`$9O<G1U;F$@0V%S=6%L90!2:6-H:65D:2!U
M;F$@0V]N9F5R;6$@9&D@0V]N<V5G;F$`3&5G9VD`4VEC=7)O(&1I('9O;&5R
M(&5L:6UI8V%R925S/R!,)V]P97)A>FEO;F4@;F]N('!U;R<@97-S97)E(&%N
M;G5L;&%T80!3:6-U<F\@9&D@=F]L97(@96QI;6EN87)E(&D@9&%T:2!D:2`E
M<S\@3"=O<&5R87II;VYE(&YO;B!P=6\G(&5S<V5R92!A;FYU;&QA=&$`4FEC
M979U=&\@:6P`4FEC979U=&\@9&%L`%)I8V5V=71O(%!R:6UA(&1E;`!296EN
M9&ER:5]Z>F$`4F5I;F1I<FEZ>F$`0V]N<V5G;F$@:6P@365S<V%G9VEO(&%D
M('5N(&%L=')O(&EN9&ER:7IZ;RX`0V]N<V5G;F$@<75E<W1O($UE<W-A9V=I
M;R!A9"!U;B!A;'1R;R!I;F1I<FEZ>F\N`$QA(&-O;G-E9VYA(&1E;"!-97-S
M86=G:6\@860@=6X@86QT<F\@:6YD:7)I>GIO(&YO;B!H82!F=6YZ:6]N871O
M+@!!9V=I;W)N80!!9V=I;W)N82!L)V5L96YC;R!D96QL82!C87)T96QL83H`
M06=G:6]R;F$@;&$@=FES=6%L:7IZ87II;VYE(%!O<G1A;&4Z`$%G9VEO<FYA
M(%9I<W5A;&EZ>F%Z:6]N90!.;W1E`%)I8V]R9&$@;&4@:6YF;W)M87II;VYI
M(&QI8F5R;R]O8V-U<&%T;RX`4FEC;W)D82!L)W5L=&EM82!V:7-U86QI>GIA
M>FEO;F4`0V%S96QL82!D:2!0;W-T82!R96UO=&$Z`%-E<G9E<B!296UO=&D`
M55),(')E;6]T82`H:'1T<#HO+W=W=RYE<V5M<&EO+F-O;2]H;W)D92DZ`$5L
M:6UI;F$`16QI;6EN82!B;&]C8V\`4FEM=6]V:2!I;"!C86UP;R!D86QL82!R
M:6-E<F-A`%)I;75O=FD@1F]R;6%T=&%Z:6]N90!%;&EM:6YA('!A:6\`16QI
M;6EN82!L82!S;W)G96YT90!%;&EM:6YA(&EL`$5L:6UI;F$@=71E;G1E`$5L
M:6UI;F$@=71E;G1E.B`E<P!2:6YO;6EN82!#87)T96QL82]E`%)I;F]M:6YA
M(&QA(&-A<G1E;&QA(&1I(%!O<W1A($EN=FEA=&$@860@:6YI>FEO(&UE<V4_
M`$YO=&EF:6-A(&1A('!A<G1E(&1E;"!S97)V97(Z(&YO;B#H('-T871O('!O
M<W-I8FEL92!C86UB:6%R92!I;"!N;VUE("`@(B5S(B!C;VX@(B5S(B`N(`!2
M:7-P;VYD:2!A;&QA($QI<W1A`%-O<W1I='5I<V-I(&-O;CH`4FES<&]N9&D`
M4FES<&]S=&$@26YV:6%T80!2:7-P;VYD:2!A(%1U='1I`%)I<W!O;F1I(&$@
M5'5T=&DZ`%)I<W!O;F1I(&%L;&$@3&ES=&$`4FES<&]N9&D@86QL82!,:7-T
M83H`4FES<&]N9&D@82!?5'5T=&D`4FES<&]N9&D@8V]N($UE<W-A9V=I;R!.
M;VX@4W5P<&]R=&%T;P!2:7-P;VYD:2!C;VX@;&EB97)O+V]C8W5P871O('!E
M<B!I('!R;W-S:6UI(#(@;65S:2X`4FES<&]N9&D@8V]N(&QE(&EN9F]R;6%Z
M:6]N:2!L:6)E<F\O;V-C=7!A=&\@<FEC:&EE<W1E`%)I<W!O;F1I+4$`4FES
M<&]N9&DM03H@`%)I<W!O;F1I.@!396=N86QA(&-O;64@3F]N+5-P86T`4V5G
M;F%L82!C;VUE(%-P86T`4FEC:&EE9&D@=6YA(%)I8V5V=71A(&1I($QE='1U
M<F$`4FEC:&EE9&D@=6YA(&-O;F9E<FUA(&1I(&-O;G-E9VYA/P!2:6-H:65D
M:2!U;F$@<FEC979U=&$@9&D@;&5T='5R83\`4&%R=&5C:7!A;G1I(%)I8VAI
M97-T;P!!>GIE<F$`06YN=6QL82!087-S=V]R9`!!;FYU;&QA(&QA('1U82!0
M87-S=V]R9`!3=&%T;R!D96P@4FES<&]N9&5N=&4@06=G:6]R;F%T;RX`4FES
M=6QT871I`%)E8W5P97)A`$-O;G1I;G5A(&QA('1U82!S97-S:6]N90!2:71O
M<FYA(&$@4V-A<FEC82!0;W-T80!4;W)N82!A;&PG3W!Z:6]N:2X`5&]R;F$@
M86QL)V5L96YC;R!D96D@;65S<V%G9VD@9&]P;R!A=F5R(&5L:6UI;F%T;RP@
M<W!O<W1A=&\L(&\@8V]P:6%T;R!U;B!M97-S86=G:6\N`$EN=F5R=&D@;&$@
M0V]N9FEG=7)A>FEO;F4`3W!Z:6]N:2!%9&ET;W(@4FEC:"!497AT`%)I9&1L
M97,`1&5S=')A`%!R;W!R:65TX"!D96QL82!27VEG82XN+@!2=6]L;P!0<F]P
M<FEE=&$@9&5L;&$@<FEG80!0<F]P<FEE=.`@9&5L;&$@<FEG80!2:6=H93H`
M4F5G;VQE`$5S96=U:0!3+TU)344`0W)I<'1A(&UE<W-A9V=I;R!3+TU)344`
M17)R;W)E(%,O34E-13H@Z"!N96-E<W-A<FEA(&QA('!A<F]L82!C:&EA=F4@
M<&5R(&QA(&-H:6%V92!P<FEV871A+@!/<'II;VYI(%,O34E-10!);G!U="!0
M87)O;&$@8VAI879E(%,O34E-10!);"!S=7!P;W)T;R!D96QL82!C;W!P:6$@
M9&D@8VAI879I(%,O34E-12!R:6-H:65D92!U;F$@8V]N;F5S<VEO;F4@<VEC
M=7)A+@!#;W!P:6$@9&D@8VAI879I('!U8F)L:6-A+W!R:79A=&$@4R]-24U%
M(&%G9VEU;G1A(&-O;B!S=6-C97-S;RX`1FER;6$@365S<V%G9VEO(%,O34E-
M10!&:7)M82]#<FEP=&$@;65S<V%G9VEO(%,O34E-10!);"!S=7!P;W)T;R!3
M+TU)344@Z"!D:7-A8FEL:71A=&\@<W5L('-I<W1E;6$N`$EL('-U<'!O<G1O
M(%,O34E-12!N;VX@Z"!A8FEL:71A=&\L('!E<G1A;G1O(&EL(&UE<W-A9V=I
M;R!N;VX@<'7R(&5S<V5R92!D96-R:7!T871O+@!);"!S=7!P;W)T;R!3+TU)
M344@;F]N(.@@86)I;&ET871O+"!P97)T86YT;R!L82!F:7)M82!D:6=I=&%L
M92!N;VX@<'7R(&5S<V5R92!V97)I9FEC871A+@!-97-S86=G:2!335,`3U]G
M9V5T=&\`4V%B`%-A;%]V82!U;F$@8V]P:6$@:6X@`%-A;%]V82!C;VX@3F]M
M90!386QV80!386QV82`E<P!386QV82!!;&QE9V%T:2!C;VX@;65S<V%G9VEO
M(&YE;&QA(&-A<G1E;&QA('-E;G0M;6%I;`!386QV82!";WIZ80!386QV82!/
M<'II;VYI`%-A;'9A(&QA(%]";WIZ80!386QV82!C;VX@3F]M90!386QV82!L
M92!B;WIZ92!C;VUE(&YO;B!V:7-T93\`4V%L=F$@;&$@8V]N9FEG=7)A>FEO
M;F4@9V5N97)A=&4@8V]M92!S8W)I<'0@4$A0('-U;&QA(&-A<G1E;&QA('1E
M;7!O<F%N96$@9&5L('1U;R!S97)V97(N`%-A;'9E(&D@9&5S=&EN871A<FD@
M875T;VUA=&EC86UE;G1E(&%L;&$@<G5B<FEC82!D969A=6QT/P!386QV82!L
M82!R:6-E<F-A(&-O;64@=6YA(&-A<G1E;&QA('9I<G1U86QE/P!386QV82!P
M;W-T82!I;G9I871A/P!386QV871O(&QA(&-O;F9I9W5R87II;VYE("5S+@!.
M;VX@Z"!S=&%T;R!P;W-S:6)I;&4@<V%L=F%R92!L82!B;WIZ82X@0V]D:6-E
M(&1E;"!S97)V97(Z("5S`%)I0V5R8V$`4FEC97)C82`E<P!-;W1O<F4@9&D@
M<FEC97)C80!2:7-U;'1A=&D@9&5L;&$@4FEC97)C80!6:7-T;P!396QE>FEO
M;F$`4V5L97II;VYA('5N)T%L=')O($%C8V]U;G0`4V5L97II;VYA('5N82!D
M871A`%-E;&5Z:6]N82!U;B!C86UP;P!3;&5Z:6]N82!U;B!G<G5P<&\@9&$@
M86=G:75N9V5R90!396QE>FEO;F$@=6X@;G5O=F\@<')O<')I971A<FEO`%-E
M;&5Z:6]N82!U;B!S97)V97(`4V5L97II;VYA('5N('5T96YT92!D82!A9V=I
M=6YG97)E`%-E;&5Z:6]N82!L92!F;VYT:2!D96QL82!R=6)R:6-A('!E<B!A
M9V=I=6YG97)E(&4@8V5R8V%R92!I;F1I<FEZ>FDN`%-E;&5Z:6]N82!T=71T
M;P!38V5G;&D@;"=O<F1I;F4@:6X@8W5I(')I8V5R8V%R92!L92!R=6)R:6-H
M92!Q=6%N9&\@97-P86YD:2!G;&D@:6YD:7)I>GII`%-E;&5Z:6]N82!U;B=A
M8V-O=6YT`$1E<V5L97II;VYA('1U='1O+@!396QE>FEO;F$@:2!C87)A='1E
M<FD@9&D@8W5I(&AA:2!B:7-O9VYO(&1A;&QE(&-A<V5L;&4@<75I('-O='1O
M+B!0=6]I('%U:6YD:2!C;W!I87)L92!E(&EN8V]L;&%R;&4@9&%L;&$@=&5X
M=&%R96$N`%-E;&5Z:6]N82!I;"!D96QI;6ET871O<F4@9&D@9&%T83H`4V5S
M8V5G;&D@:6P@9F]R;6%T;R!D96QL82!D871A.@!396QE>FEO;F$@=6X@=&EP
M;R!D:2!S97)V97(`4V5L97II;VYA(&EL(&1E;&EM:71A=&]R92!D96QL)V]R
M83H`4V-E9VQI(&EL(&9O<FUA=&\@9&5L;"=O<F$Z`%-E;&5Z:6]N82!D=64@
M8V%M<&D@8V]R<FES<&]N9&5N=&DN`%-E;&5Z:6]N82!I;"!T=6\@<V-H96UA
M(&-O;&]R:2X`4V5L97II;VYA(&QA(&QI;F=U82!C:&4@<')E9F5R:7-C:3H`
M4G5B<FEC:&4@4V5L97II;VYA=&4Z`$EN=FEA(&-H:6%V92!A;"!S97)V97(@
M<'5B8FQI8V\`04EN=FEA(%5L=&EM92!);F9O<FUA>FEO;FD`26YV:6$@365S
M<V%G9VEO`$EN=FEA(&EL(')E<&]R="!D96P@<')O8FQE;6$`4V5N<V]R93H@
M`$-A<G1E;&QA(&1I('!O<W1A(&EN=FEA=&$`0V%R=&5L;&$@9&D@<&]S=&$@
M:6YV:6%T80!3971T96UB<F4`4V5R=F5R`$EN9F]R;6%Z:6]N:2!S=6P@4V5R
M=F5R(&4@0V%R=&5L;&$`4V5R=F5R.@!);7!O<W1A(&QE(&%Z:6]N:2!D82!E
M<V5G=6ER92!Q=6%N9&\@<VD@<W!O<W1A;F\@;R!E;&EM:6YA;F\@:2!M97-S
M86=G:2X`0V]N9FEG=7)A(&PG:6YT97-T87II;VYE(%@M4')I;W)I='D@<75A
M;F1O(&EN=FEI(&UE<W-A9V=I;S\`26UP;W-T:2!I('-E<G9E<B!R96UO=&D@
M86D@<75A;&D@=G5O:2!A8V-E9&5R92!D86P@='5O('!O<G1A;&4N`%-E;&5Z
M:6]N82!L82!L:6YG=6$@<')E9F5R:71A(&4@:6P@9G5S;R!O<F%R:6\N`$UO
M9&EF:6-A(&QA('1U82!A<'!L:6-A>FEO;F4@9&D@879V:6\L(&=L:2!S8VAE
M;6D@8V]L;W)E+"!E9"!A;'1R92!O<'II;VYI(&1I('9I<W5A;&EZ>F%Z:6]N
M92X`4V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L('-E='5P(&1I<W!O;FEB
M:6QE`$-O;F1I=FED:2!#87)T96QL90!#;VYD:79I9&D@8V%R=&5L;&4@9&D@
M<&]S=&$`0V]N9&EV:61I(&QA(&-A<G1E;&QA(&1I('!O<W1A(&-O;B!A;'1R
M:2!U=&5N=&DN`%-H;W!P:6YG`$)R979E(%)I87-S=6YT;P!$969I;FEA;6\@
M9VQI(&%C8V5S<VD@9&$@=&%S=&EE<F$@<&5R(&D@;&EN:S\`26P@8V]R<&\@
M9&5I(&UE<W-A9V=I(&1I('1E<W1O(&1E=F4@97-S97)E(&-O;G1R;VQL871O
M('!E<B!D871I(%!'4#\`0VAI=61I(&QA(&9I;F5S=')A($-O;7!O;FD@9&]P
M;R!A=F5R('-A;'9A=&\@=6YA($)O>GIA+@!,82!T=6$@8VAI879E(%!'4"!P
M=6)B;&EC82!D979E(&5S<V5R92!A;&QE9V%T82!A:2!M97-S86=G:2!D:2!D
M969A=6QT/P!-;W-T<F$`36]S=')A('1U='1E(&QE($EN=&5S=&%Z:6]N:0!-
M;W-T<F$@16QI;6EN871I`$UO<W1R82!);G1E<W1A>FEO;FD@3&EM:71A=&4`
M36]S=')A($EN9F]M87II;VYI(&1E;&QA($UA:6QI;F<@3&ES=`!-;W-T<F$@
M:2!.;VX@<V]T=&]S8W)I='1I`$UO<W1R82!U;B=I8V]N82!P97(@<&5R;65T
M=&5R92!L;R!S=')I<'!I;F<@9&5G;&D@86QL96=A=&D_`$UO<W1R82!L)W5L
M=&EM;R!L;V=I;B!A;&PG86-C97-S;S\`36]S=')A(&QA(&QE9V5N9&$@9&5I
M(&-O;&]R:2!N96QL82!V:7-U86QI>GIA>FEO;F4@9&5L;&$@8V%R=&5L;&$N
M`$UO<W1R82!A;G1E<')I;6$@<V]L;R!P97(@;65S<V%G9VD@;F]N(&QE='1I
M/P!-;W-T<F$@<')E=FEE=R!I;B!T;V]L=&EP<S\`36]S=')A('1A8F5L;&$@
M;W!E<F%Z:6]N:2!N96QL82!B87)R82!D96P@;65N=3\`36]S=')A(&EL("5S
M($UE;F\@<W5L;&$@<VEN:7-T<F$_`$UO<W1R82!L)VEC;VYA($9E=&-H($UA
M:6P@;F5L;&$@8F%R<F$@;65N=3\`36]S=')A(&QE($EM;6%G:6YI`$UO<W1R
M82!L92!0<F]P<FEE=.`@5&%B96QL82!#96QL80!-;W-T<F$@;&4@4')O<')I
M973@(%1A8F5L;&$`36]S=')A(&QE(%!R;W!R:65TX"!486)E;&QA(%)I9V$`
M36]S=')A(&PG:6-O;F$@9&D@9FEL=')O(&YE;&QA(&)A<G)A(&UE;G4_`$UO
M<W1R82!I;"!N=6UE<F\@=&]T86QE(&1I(&UE<W-A9VD@;F5L;&$@8V%R=&5L
M;&$_`$%C<75A>GIO;FD`06-Q=6%Z>F]N:2!A($)R979E`$%C<75A>GIO;FD@
M5&%R9&D`36]S=')A`$1I7VUE;G-I;VYE`$1I;65N<VEO;F4`4V%L=&$@36%N
M=71E;GII;VYE`%!R;V9O;F1I=&$G(&1I(&YE=F4Z(`!/<F1I;F$@<&5R($%R
M<FEV;P!/<F1I;F$@<&5R($1A=&$`3W)D:6YA('!E<B!-:71T96YT90!/<F1I
M;F$@<&5R($1I;65N<VEO;F4@365S<V%G9VEO`$]R9&EN82!P97(@3V=G971T
M;P!/<F1I;F$@<&5R(%1H<F5A9`!/<F1I;F$@<&5R($1E<W1I;F%T87)I;P!3
M<&%Z:6%T=7)A`%-P86T`0V%R=&5L;&$@<'!A;3H`0V%R871T97)E(%-P96-I
M86QE`$-A<F%T=&5R:2!3<&5C:6%L:0!#;VYT<F]L;&\@3W)T;V=R869I8V\`
M0V]N=')O;&QO(&]R=&]G<F%F:6-O(&-O;7!L971A=&\`3G5M97)O(&1I(&5R
M<F]R:2!O<G1O9W)A9FEC:2!P97(@;V=N:2!S8VAE<FUA=&$N`$1I=FED:2!#
M96QL80!$:79I9&D@8V]L;VYN80!$:79I9&D@4FEG80!3=&%N9&%R9`!!=G9I
M;P!3=&%T:7,`4W1R:7!P82!!;&QE9V%T;P!%;&EM:6YA($EN=&5R<G5Z:6]N
M:2!D:2!,:6YE83\`1&]M`$]?9V=E='1O`$]G9V5T=&\`0V%M<&\@3V=G971T
M;P!);G9I;P!3;W1T;W-C<FEV:2!A($-A<G1E;&QA+V4`4V]T=&]S8W)I=FD`
M4W5C8V5S<V\`4V%L=F%T;R!L82!C;VYF:6=U<F%Z:6]N92X`4V-R:71T;R!C
M;VX@<W5C8V5S<V\@)7,`4W5G9V5R:6UE;G1I`$)R979E(%)I87-S=6YT;P!!
M;&)A`%1R86UO;G1O`$%L8F$`06QB82]4<F%M;VYT;P!!;&)A.B``5')A;6]N
M=&\`5')A;6]N=&\Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T;P!-;V1I9FEC82!-
M971O9&\@9&D@0V]M<&]S:7II;VYE`%9A:2!A(&-O;7!O<VEZ:6]N92!(5$U,
M`%9A:2!A(&-O;7!O<VEZ:6]N92!S;VQO('1E<W1O`%0M5&5M<&5S=&$`5"U4
M96UP97-T90!0<F]P<FEE=.`@5&%B96QL80!0<F]P<FEE=.`@5&%B96QL80!$
M97-T:6YA>FEO;F4Z`$%T=&EV:73@`%1E7W-T;P!496UP97)A='5R82!U;'1I
M;6$@;W)A.B``5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!!;6UI;FES=')A
M>FEO;F4@5&5M<&QA=&4`4FEC:&EE<W1A(&1I(&%C8V5T=&%Z:6]N92!P<F]V
M=FES;W)I80!!8V-E='1A=&\@<')O=FES<V]R:6%M96YT92X`1FEL92!D96D@
M5&5R;6EN:2!D)U5T:6QI>GIO(&YO;B!S<&5C:69I8V%T;R!I;B!C;VYF+G!H
M<`!3;VQO(%1E<W1O`$%L;&EN96%M96YT;R!T97-T;P!497-T;R!I;B!A;'1O
M`$=I;P!'<F%Z:64@9&D@879E<B!U<V%T;R!I;"!S:7-T96UA+@!,82!C;VQO
M;FYA($1A.B!D96P@;65S<V%G9VEO(&1E=F4@97-S97)E(&-O;&QE9V%T83H`
M26P@9FEL92!O<FEG:6YA;&4@<'5O)R!E<W-E<F4@<V-A<FEC871O("5S+@!,
M)R!A8V-O=6YT("(E<R(@Z"!S=&%T;R!E;&EM:6YA=&\N`$PG86-C;W5N="`B
M)7,B(.@@<W1A=&\@<V%L=F%T;RX`3"=A;&QE9V%T;R!N;VX@Z"!S=&%T;R!T
M<F]V871O+@!,82!F:6YE<W1R82!D:2!C;VUP;W-I>FEO;F4@;F]N('!U\B!E
M<W-E<F4@87!E<G1A+B!0<F]B86)I;&UE;G1E(&EL('1U;R!B<F]W<V5R(.@@
M:6UP;W-T871O('!E<B!B;&]C8V%R92!I('!O<'5P`%-E9W5O;F\@<V]T=&\@
M:2!C;VYT96YU=&D@9&5L(&9I;&4@36%C:6YT;W-H+@!,82!C87)T96QL82`B
M)7,B('9E<G+@(')I;F]M:6YA=&$@:6X@(B5S(BX`3&$@;&ES=&$@9&5G;&D@
M=71E;G1I(&-O;B!A8V-E<W-O(&$@<75E<W1A(&-A<G1E;&QA(&YO;B#H('-T
M871A(&]T=&5N=71A`$QA(&)O>GIA(.@@<W1A=&$@<V%L=F%T82!N96QL82!C
M87)T96QL82`B)7,B+@!,)V5V96YT;R#H('-T871O(&%G9VEU;G1O(&%L('1U
M;R!C86QE;F1A<FEO+@!,82!C87)T96QL82`B)7,B(&5S:7-T92!G:>``26P@
M;F]M92!D96QL82!C87)T96QL82`B)7,B(&-O;G1I96YE(&-A<F%T=&5R:2!N
M;VX@=F%L:61I+B!0;W1R96)B92!C875S87)E('!R;V)L96UI+B!#;VYT871T
M82!L)V%M;6EN:7-T<F%T;W)E(&1I('-I<W1E;6$N`$QA(&-A<G1E;&QA("(E
M<R(@Z"!S=&%T82!C<F5A=&$@;6$@;F]N(.@@<W1A=&$@<V]T=&]S8W)I='1A
M+@!,82!C87)T96QL82`B)7,B(.@@<W1A=&$@8V%N8V5L;&%T82!M82!N;VX@
MZ"!S=&%T82!A;FYU;&QA=&$@;&$@<V]T=&]S8W)I>FEO;F4N`$QA(&-A<G1E
M;&QA("(E<R(@;F]N(.@@<W1A=&$@8W)E871A+B!1=65S=&\@Z"!I;"!M97-S
M86=G:6\@9&5L('-E<G9E<@!,82!C87)T96QL82`B)7,B(.@@<W1A=&$@8W)E
M871A(&-O;B!S=6-C97-S;RX`3&$@8V%R=&5L;&$@(B5S(B#H('-T871A(&5L
M:6UI;F%T82!C;VX@<W5C8V5S<V\N`$QA(&-A<G1E;&QA("(E<R(@Z"!S=&%T
M82!R:6YO;6EN871A(&EN("(E<R(N`$PG:61E;G1I=.`@(B5S(B!E)R!S=&%T
M82!E;&EM:6YA=&$N`$QE(&EM;6%G:6YI('-A<F%N;F\@;6]S=')A=&4@<&5R
M8VCI(&EL(&UI='1E;G1E('-I('1R;W9A(&YE;&QA('1U82!R=6)R:6-A+@!)
M;"!S97)V97(@9&D@<&]S=&$@:&$@9V5N97)A=&\@:6P@<V5G=65N=&4@;65S
M<V%G9VEO(&1I(&5R<F]R93H`26P@<V5R=F5R(&1I('!O<W1A(&AA(&=E;F5R
M871O(&EL('-E9W5E;G1E(&UE<W-A9V=I;R!D:2!I;F9O<FUA>FEO;F4Z`$EL
M('-E<G9E<B!D:2!P;W-T82!H82!G96YE<F%T;R!I;"!S96=U96YT92!M97-S
M86=G:6\Z`$QA(&-A<G1E;&QA("(E<R(@Z"!G:>`@=G5O=&$N`$EL(&UE<W-A
M9V=I;R`B)7,B(&1A("(E<R(@*"5D(&)Y=&5S*2!S=7!E<F$@:6P@;&EM:71E
M(&1I(&1I;65N<VEO;F4`26P@;65S<V%G9VEO(&EN(&-O;7!O<VEZ:6]N92#H
M('-T871O(&-H:75S;RX@26X@=7-C:71A+@!);"!M97-S86=G:6\@Z"!S=&%T
M;R!E;&EM:6YA=&\N`$EL(&UE<W-A9V=I;R#H('-T871O('9E<FEF:6-A=&\N
M`$QA(&9I;F5S=')A(&1I(&%U=&5N=&EC87II;VYE(&YO;B!P=?(@97-S97)E
M(&%P97)T82X@4')O8F%B:6QM96YT92!I;"!T=6\@8G)O=W-E<B#H(&EM<&]S
M=&%T;R!P97(@8FQO8V-A<F4@:2!P;W!U<`!);"!T97-T;R!D96QL82!#:&EA
M=F4@4$=0(%!U8F)L:6-A('!U\B!E<W-E<F4@=FES=&\@)7,N`$EL(&9I;&4@
M<FEC:&EE<W1O(&YO;B!E<VES=&4@;F5L;"=A;&5G871O($U3+51.148N`$EL
M(&9I;&4@<FEC:&EE<W1O(&YO;B!E<VES=&4@;F5L;"=A;&QE9V%T;R!Z:7`N
M`$EL('-E<G9E<B`B)7,B(&4G('-T871O(&5L:6UI;F%T;RX`26P@<V5R=F5R
M("(E<R(@92<@<W1A=&\@<V%L=F%T;RX`3F]N(&5R82!P;W-S:6)I;&4@<V]S
M=&ET=6ER92!L82!F:7)M82X`3&$@9FER;6$@Z"!S=&%T82!S;W-T:71U:71A
M(&-O;B!S=6-C97-S;RX`3&$@<FEC:&EE<W1A(&1I(')E9VES=')A>FEO;F4@
M<&5R("5S(.@@<W1A=&$@96QI;6EN871A+@!);"!F:6QE('-P96-I9FEC871O
M(&YO;B!E<VES=&4N`$PG871T:79I=.`@Z"!S=&%T82!A9V=I=6YT82!N96QL
M82!T=6$@=&%S:VQI<W0N`%1E<W1O(&1E;"!M97-S86=G:6\`26P@=&5S=&\@
M9&5L(&UE<W-A9V=I;R!P=6\G(&5S<V5R92!V:7-T;R`E<RX`5&5S=&\@9&5L
M(&UE<W-A9V=I;R!R97-T:71U:71O`$EL('1E<W1O(&1E;"!M97-S86=G:6\@
M<F5S=&ET=6ET;R!P=?(@97-S97)E('9I<W1O("5S+@!497-T;R!D96P@;65S
M<V%G9VEO(&EN=FEA=&\`26P@=&5S=&\@9&5L(&UE<W-A9V=I;R!I;G9I871O
M('!U\B!E<W-E<F4@=FES=&\@)7,N`$EN9F]R;6%Z:6]N:2!L:6)E<F\O;V-C
M=7!A=&\@9&5L;"=U=&5N=&4@<V%L=F%T92!C;VX@<W5C8V5S<V\N`$EL(&UO
M9'5L;R!W96%T:&5R+F-O;2!N;VX@Z"!D:7-P;VYI8FEL92X`3F]N(&-I('-O
M;F\@<&]R>FEO;FD@86QT97)N871I=F4@8VAE('!O<W-O;F\@97-S97)E(&UO
M<W1R871E(&EN;&EN92X`3F]N(&-I('-O;F\@;65S<V%G9VD@:6X@<75E<W1A
M(&-A<V5L;&$@9&D@<&]S=&$N`%-I(.@@=F5R:69I8V%T;R!U;B!E<G)O<F4@
M;F5L;"=E;&EM:6YA>FEO;F4@9&D@)7,N(%%U97-T;R#H(&EL(&UE<W-A9V=I
M;R!D96P@<V5R=F5R`%-I(.@@=F5R:69I8V%T;R!U;B!E<G)O<F4@;F5L;&$@
M96QI;6EN87II;VYE(&1E;&QA(&-A<V5L;&$@9&D@<&]S=&$N(%%U97-T;R#H
M(&EL(&UE<W-A9V=I;R!D96P@<V5R=F5R.B`E<P!3:2#H('9E<FEF:6-A=&\@
M=6X@97)R;W)E(&YE;&QA(&5L:6UI;F%Z:6]N92!D96QL82!C87-E;&QA(&1I
M('!O<W1A+B!1=65S=&\@Z"!I;"!M97-S86=G:6\@9&5L('-E<G9E<@!3:2#H
M('9E<FEF:6-A=&\@=6X@97)R;W)E(&YE;"!C;W!I87)E(&D@;65S<V%G9VD@
M9&$@(B5S(B!A("(E<R(N(%%U97-T;R#H(&EL(&UE<W-A9V=I;R!D96P@<V5R
M=F5R`%-I(.@@=F5R:69I8V%T;R!U;B!E<G)O<F4@;F5L;"=E;&EM:6YA>FEO
M;F4@9&5I(&9I;&5S(&1A;&QA(&-A<G1E;&QA("(E<R(N(%%U97-T;R#H(&EL
M(&UE<W-A9V=I;R!D96P@<V5R=F5R`%-I(.@@=F5R:69I8V%T;R!U;B!E<G)O
M<F4@;F5L(&-A;F-E;&QA<F4@:2!M97-S86=G:2!N96QL82!C87)T96QL82`B
M)7,B+B!1=65S=&\@Z"!I;"!M97-S86=G:6\@9&5L('-E<G9E<@!3:2#H('9E
M<FEF:6-A=&\@=6X@97)R;W)E(&YE;"!C86YC96QL87)E(&D@;65S<V%G9VDN
M(%%U97-T;R#H(&EL(&UE<W-A9V=I;R!D96P@<V5R=F5R.B`E<P!3:2#H('9E
M<FEF:6-A=&\@=6X@97)R;W)E('9I<W5A;&EZ>F%N9&\@<75E<W1A('!A<G1E
M(&1E;"!M97-S86=G:6\`4VD@Z"!V97)I9FEC871O('5N(&5R<F]R92!I;7!O
M<W1A;F1O(&D@9FQA9W,@9&5I(&UE<W-A9V=I(&YE;&QA(&-A<G1E;&QA("(E
M<R(N(%%U97-T;R#H(&EL(&UE<W-A9V=I;R!D96P@<V5R=F5R`%-I(.@@=F5R
M:69I8V%T;R!U;B!E<G)O<F4@:6UP;W)T86YD;R`E<RX`17)R;W)E(&YE;&PG
M:6UP;W)T87II;VYE(&1E;&PG979E;G1O.B`E<RX`17)R;W)E(&YE;&PG:6UP
M;W)T87II;VYE(&1E;&PG871T:79I=.`Z("5S+@!3:2!E)R!V97)I9FEC871O
M('5N(&5R<F]R92!N96QL)VEM<&]R=&%Z:6]N92!D96QL92!I;F9O<FUA>FEO
M;FD@;&EB97)O+V]C8W5P871O(&1E;&PG=71E;G1E.B`E<RX`4VD@Z"!V97)I
M9FEC871O('5N(&5R<F]R92!S<&]S=&%N9&\@:2!M97-S86=G:2!D82`B)7,B
M(&$@(B5S(BX@475E<W1O(.@@:6P@;65S<V%G9VEO(&1E;"!S97)V97(`4VD@
MZ"!V97)I9FEC871O('5N(&5R<F]R92!S86QV86YD;R!I;"!M97-S86=G:6\@
M8V]M92!B;WIZ82X`4VD@Z"!V97)I9FEC871O('5N(&5R<F]R92!I;G9I86YD
M;R!I;"!M97-S86=G:6\Z("5S`$5R<F]R92!N96QL)V%G9VEO<FYA;65N=&\@
M9&5L;"=E=F5N=&\Z("5S+@!.;VX@8R=E<F$@=&5S=&\@:6X@<75E<W1A('!O
M<GII;VYE(&1I(&UE<W-A9V=I;P!1=65S=&\@;65S<V%G9VEO($A434P@:&$@
M;&4@:6UM86=I;FD@:6YS97)I=&4@9&5N=')O+@!1=65S=&\@;65S<V%G9VEO
M($A434P@:&$@;&4@:6UM86=I;FD@:6YS97)I=&4@9&5N=')O+B!);6UA9VEN
M:2!B;&]C8V%T92!A<'!A:6]N;R!C;W/L.B``475E<W1A(&-H:6%V92!P=6)B
M;&EC82!01U`@Z"!S=&%T82!A;&QE9V%T82!A;"!M97-S86=G:6\N`%%U97-T
M82!A>FEO;F4@;F]N(&4G('-U<'!O<G1A=&$N`%%U97-T82!A>FEO;F4@;F]N
M(&4G(&%N8V]R82!I;7!L96UE;G1A=&$N`%%U97-T;R!E)R`E<RX`475E<W1O
M('!O=')E8F)E(')I8VAI961E<F4@9&5L('1E;7!O+B!396D@<VEC=7)O(&1I
M('9O;&5R('!R;W-E9W5I<F4_`%%U97-T;R!M97-S86=G:6\@8V]N=&EE;F4@
M=6X@9FEL92!-86-I;G1O<V@N`%%U97-T;R!M97-S86=G:6\@;F]N(&%P<&%R
M92!E<W-E<F4@=6X@=F%L:61O(&UE<W-A9V=I;R!C<FEP=&%T;R!C;VX@4$=0
M+B!%<G)O<F4Z(`!1=65S=&\@;65S<V%G9VEO(&YO;B!A<'!A<F4@97-S97)E
M(&YE;"!F;W)M871O(&-O<G)E='1O(%!'4"X`365S<V%G9VEO(&9I<FUA=&\@
M96QE='1R;VYI8V%M96YT92!C;VX@4$=0+@!-97-S86=G:6\@9FER;6%T;R!E
M;&5T=')O;FEC86UE;G1E(&-O;B!3+TU)344N`$UE<W-A9V=I;R!C<FEP=&%T
M;R!C;VX@4R]-24U%+@!-97-S86=G:6\@8W)I<'1A=&\@8V]N(%!'4"X`475E
M<W1O(&UE<W-A9V=I;R!A`%%U97-T;R!S97)V97(@;F]N('-U<'!O<G1A(&QA
M(&-O;F1I=FES:6]N92!D96QL92!C87)T96QL92X`475E<W1A(&9I;F5S=')A
M(&1E=F4@97-S97)E(&-H:6%M871A(&1A('5N82!F:6YE<W1R82!D:2!C;VUP
M;W-I>FEO;F4N`%9I<W5A;&EZ>F%Z:6]N92!P97(@07)G;VUE;G1O`%1U;VYO
M`%1I8VME=`!'97-T:6]N92!D96P@5&5M<&\`1F]R;6%T;R!/<F$`5&ET;VQO
M`$$`26YD:7)I>GIO($$`3V=G:0!$;VUA;FD`06QT;P!$:6UE;G-I;VYE(%1O
M=&%L92!!;&QE9V%T:3H`0V%R=&5L;&$@8V5S=&EN;P!#87)T96QL82!#97-T
M:6YO.@!-87(`55),`%523#H`26UP;W-S:6)I;&4@;W1T96YE<F4@<75O=&$`
M3F]N(%)I<W!O<W1O`$UE<W-A9V=I(&YO;B!R:7-P;W-T:0!296-U<&5R80!3
M;W1T;VQI;F5A`$1E<W1I;F%T87)I(&YA<V-O<W1I`$%N;G5L;&$@;&4@36]D
M:69I8VAE`$EN9&5F:6YI=&\`0V]M<&]N96YT92!N;VX@9V5S=&ET;R!D96P@
M=&EP;SH@)7,`56YI=.``1&%T82!38V]N;W-C:75T80!);F-O;G1R;R!38V]N
M;W-C:75T;P!$97-T:6YA=&%R:6\@4V-O;F]S8VEU=&\`16QI;6EN82!%;&5M
M96YT;R!#;W)R96YT90!38V%R:6-A(%!A<W-W;W)D`%-E;GIA(&YO;64`3F]N
M($QE='1O`$5L:6UI;F$@0V]L;W)E`$%N;G5L;&$@<V]T=&]S8W)I>FEO;F4@
M9&%L;&$@8V%R=&5L;&$H92D`06=G:6]R;F$`06=G:6]R;F$@)7,`06=G:6]R
M;F$@:6YF;W)M87II;VYI('-U;&PG86QL96=A=&\`4W1A='5S(&1E;"!R:7-P
M;VYD96YT92!A9V=I;W)N871O`$%G9VEO<FYA('5T96YT90!38W)I<'0@9&D@
M86=G:6]R;F%M96YT;R!E;&EM:6YA=&\N`%5P;&]A9`!.=6UE<B!R;VUA;FD@
M86QT:0!5=&EL:7IZ82!I;"!686QO<F4@9&D@1&5F875L=`!5<V$@;&$@<V]T
M=&]S8W)I>FEO;F4@9&5L;&4@8V%R=&5L;&4@24U!4#\`571E;G1E`$%M;6EN
M:7-T<F%Z:6]N92!5=&5N=&D`4F5G:7-T<F%Z:6]N92!5=&5N=&4`27-C<FEZ
M:6]N92!5=&5N=&4@92<@<W1A=&\@9&ES86)I;&ET871O('!E<B!Q=65S=&\@
M<VET;RX`3F]M92!5=&5N=&4`3F]M92!5=&5N=&4Z`$YO;64@571E;G1E.@!5
M=&5N=&D@;F5L('-I<W1E;6$Z`%9A8V%N>F4`5F%R:6%B:6QE`$-O;G1R;VQL
M;R!697)S:6]N90!!;&QI;F5A;65N=&\`4FEE;7!I;65N=&\@5F5R=&EC86QE
M`%9E<G1I8V%L93H`36]L=&\@06QT;P!6:7-U86QI>GIA`%9I<W5A;&EZ>F$@
M)7,`36]S=')A(&-H:6%V92!P=6)B;&EC82`E<P!-;W-T<F$@:6P@8V]N=&5N
M=71O($A434P@:6X@=6YA(&9I;F5S=')A('-E<&%R871A`$UO<W1R82!C:&EA
M=F4@<&5R<V]N86QE('!R:79A=&$`36]S=')A(&-H:6%V92!P97)S;VYA;&4@
M<'5B8FQI8V$`5F5D:2!$:7-C=7-S:6]N90!6:7-U86QI>GIA(%1H=6UB;F%I
M;`!6:7-U86QI>GIA('5N82!P86=I;F$@=V5B(&5S=&5R;F$`5FES=6%L:7IZ
M82!E=F5N=&\`5FES=6%L:7IZ82!I(&UE<W-A9V=I(&EN("5S`%9I<W5A;&EZ
M>F%Z:6]N92!O(&-A<G1E;&QA(&1A(&UO<W1R87)E(&%P<&5N82!E;G1R871O
M.@!6:7-U86QI>GIA(&%T=&EV:73@`$UO<W1R82!L92!);6UA9VEN:0!,82!#
M87)T96QL82!6:7)T=6%L92`B)7,B(.@@<W1A=&$@8W)E871A(&-O;B!S=6-C
M97-S;RX`0V%R=&5L;&$@5FER='5A;&4`3F]M92!D96QL82!C87)T96QL82!V
M:7)T=6%L90!6:7-I8FEL:73@`%9I<VEB:6QI=.`Z(`!-97(`4')E=FES:6]N
M92!-971E;P!796(`0F5N=F5N=71O`$)E;G9E;G5T;R!A("5S`$)E;G9E;G5T
M;RP@)7,`0VAE(&%P<&QI8V%Z:6]N92`E<R!D979E(&UO<W1R87)E(&1O<&\@
M:6P@;&]G:6X_`$-O<V$@92<@8V%R871T97)E(&1E;&EM:71A=&]R90!#;W-A
M(&4G(&EL(&-A<F%T=&5R92!V:7)G;VQE='1E/P!3<&]S=&$@:2!M97-S86=G
M:2!C86YC96QL871I(&YE;"!#97-T:6YO(&EN=F5C92!D:2!C;VYT<F%S<V5G
M;F%R;&D@8V]M92!M97-S86=G:2!E;&EM:6YA=&DN`$QI<W1A($)I86YC80!,
M87)G:&5Z>F$`06UP:65Z>F$@9&5L;&$@=&%B96QL80!5;FETX"!,87)G:&5Z
M>F$`3&%R9VAE>GIA.@!696YT;SH`5F5N=&\Z(`!!00!3:0!3:2P@<V]N;R!D
M)V%C8V]R9&\`4W1A:2!P97(@<V-A<FEC87)E(&QA('!O<W1A(&1A;&QE('-E
M9W5E;G1E(&-A<V5L;&4Z`%-T86D@8V]M<&EA;F1O+W-P;W-T86YD;R!A9"!U
M;F$@;G5O=F$@8V%R=&5L;&$N`%-T86D@8W)E86YD;R!U;F$@<V]T=&]C87)T
M96QL82!D:2``4W1A:2!C<F5A;F1O('5N82!C87)T96QL82!D:2!P<FEM;R!L
M:79E;&QO+@!3=&%I(')I;F]M:6YA;F1O(&QA(&-A<G1E;&QA.B``3F]N(&AA
M:2!I;"!P97)M97-S;R!P97(@;6]D:69I8V%R92!G;&D@86-C97-S:2!A('%U
M97-T82!C87)T96QL80!(86D@:6YO;'1R871O('%U97-T;R!M97-S86=G:6\@
M82`E)7,@86D@<V5G=65N=&D@9&5S=&EN871A<FDZ("5S+@!(86D@)7,@;G5O
M=FD@;65S<V%G9VDN`$AA:2!U;B!N=6]V;R!M97-S86=G:6\N`$QA('-E<W-I
M;VYE(.@@<W1A=&$@=&5R;6EN871A+@!(86D@;G5O=FD@;65S<V%G9VD@;F5L
M;&$@<V5G=65N=&4@8V%R=&5L;&$Z`$AA:2!N=6]V:2!M97-S86=G:2!N96QL
M92!S96=U96YT:2!C87)T96QL93H`1&5V:2!I;G-E<FER92!A;&UE;F\@=6X@
M9&5S=&EN871A<FEO+@!$979I(&EN<V5R:7)E(&QA('!A<W-W;W)D('!E<B!L
M82!T=6$@8VAI879E('!R:79A=&$@4$=0('!E<B!V:7-U86QI>GIA<F4@<75E
M<W1O(&UE<W-A9V=I;P!$979I(&EN<V5R:7)E(&QA('!A<W-W;W)D('!E<B!L
M82!T=6$@8VAI879E('!R:79A=&$@4R]-24U%('!E<B!V:7-U86QI>GIA<F4@
M<75E<W1O(&UE<W-A9V=I;P!$979I('!R:6UA('-E;&5Z:6]N87)E('5N82!C
M87-E;&QA(&1I(&1E<W1I;F%Z:6]N92X`1&5V:2!S96QE>FEO;F%R92!U;B!A
M8V-O=6YT(&1A(&5L:6UI;F%R92X`1&5V:2!P<FEM82!S96QE>FEO;F%R92!U
M;B!I;F1I<FEZ>F\N`$1E=FD@<W!E8VEF:6-A<F4@:6P@<V5R=F5R(&1A(&5L
M:6UI;F%R92X`1&5V:2!P<FEM82!S<&5C:69I8V%R92!A;&UE;F\@=6X@;65S
M<V%G9VEO+@!$979I('-P96-I9FEC87)E('5N(&1E<W1I;F%T87)I;RX`1&5V
M:2!S<&5C:69I8V%R92!L;R!U<V5R;F%M92!D82!R:6UU;W9E<F4N`$1E=FD@
M<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@9&$@<FEM=6]V97)E+@!$979I('-P
M96-I9FEC87)E(&%L;65N;R!U;B!F:6QE(&1A(&%L;&5G87)E+@!$979I('-P
M96-I9FEC87)E(&QO('5S97)N86UE(&1A(&%G9VEU;F=E<F4N`$1E=FD@<W!E
M8VEF:6-A<F4@;&\@=7-E<FYA;64@9&$@86=G:6]R;F%R92X`2&%I(')E:6YD
M:7)I>GIA=&\@<75E<W1O(&UE<W-A9V=I;R!A("5S(&EL("4E<RX`2&%I(')I
M<W!O<W1O(&$@<75E<W1O(&UE<W-A9V=I;R!I;"`E<RX`3F]T:69I8V$@9&$@
M<&%R=&4@9&5L('-E<G9E<CH@;&$@<V]T=&]S8W)I>FEO;F4@82`B)7,B($Y/
M3B#H(&%N9&%T82!A(&)U;VX@9FEN92X`3F]T:69I8V$@9&$@<&%R=&4@9&5L
M('-E<G9E<CH@3F]N(.@@<W1A=&$@86YN=6QL871A(&QA('-O='1O<V-R:7II
M;VYE(&1A("(E<R(N(`!(86D@<V]T=&]S8W)I='1O(&-O;B!S=6-C97-S;R`B
M)7,B`$AA:2!A;FYU;&QA=&\@8V]N('-U8V-E<W-O(&QA('-O='1O<V-R:7II
M;VYE(&1A("(E<R(`5'5O($EN9&ER:7IZ;R!%;6%I;`!4=6\@26YD:7)I>GIO
M($5M86EL`%9O<W1R82!I;F9O<FUA>FEO;F4`26P@='5O(&YO;64`3&4@='5E
M(&-H:6%V:2!0=6)B;&EC:&4O4')I=F%T92!01U``3&$@='5A(&-H:6%V92!P
M<FEV871A`$QA('1U82!C:&EA=F4@<'5B8FQI8V$`22!T=6]I(&%C8V]U;G0Z
M`$EL('1U;R!B86-K96YD(&1I(&%U=&5N=&EC87II;VYE(&YO;B!S=7!P;W)T
M82!L82!E;&5N8V%Z:6]N92!D96=L:2!U=&5N=&DL(&\@;&$@8V%R871T97)I
M<W1I8V$@Z"!S=&%T82!D:7-A8FEL:71A=&$@<&5R('%U86QC:&4@;6]T:79O
M+@!);"!T=6\@8G)O=W-E<B!N;VX@<W5P<&]R=&$@;&$@=FES=6%L:7IZ87II
M;VYE(&1I('%U97-T;R!T:7!O(&1I(&EM;6%G:6YE+@!);"!T=6\@8G)O=W-E
M<B!N;VX@:&$@<75E<W1A(&-A<&%B:6QI=&$G+@!);"!T=6\@9G5S;R!O<F%R
M:6\@871T=6%L93H`26P@='5O(&-O9&EC92!C87)A='1E<FD@9&D@9&5F875L
M="!P97(@;"=I;G9I;R!D:2!M97-S86=G:3H`26P@='5O(&UE=&]D;R!D:2!C
M<FEP=&%G9VEO(&1E9F%U;'0@<&5R(&PG:6YV:6\@9&D@;65S<V%G9VDZ`$ED
M96YT:73@(&1I($1E9F%U;'0`26P@='5O(&YO;64Z`$EL('1U;R!M97-S86=G
M:6\@92<@<W1A=&\@8V]N<V5G;F%T;R!C;VX@<W5C8V5S<V\N`$D@='5O:2!S
M97)V97(@<F5M;W1I.@!,82!T=6$@9FER;6$Z`%M.97-S=6X@3V=G971T;UT`
M6T1O8W5M96YT;R!D:2!D97-C<FEZ:6]N92!D96P@<')O8FQE;6%=`%M-;W-T
M<F$@5&5S=&\@<75O=&%T;R`M`%]!;6UI;FES=')A>FEO;F4`7T)C8P!,:7-T
M82!?3F5R80!#8P!?1&%T851R964`7T5L:6UI;F$`7T5L:6UI;F$@4FEG80!#
M87)?=&5L;&4`7T=R=7!P:0!?06EU=&\`7TED96YT:73@`%!R;W!R:65TX"!D
M96QL)U]);6UA9VEN92XN+@!?4&]S=&$@:6X@07)R:79O`%]&:6YE('-E<W-I
M;VYE`$EN=&5S=&%Z:6]N:2!?365S<V%G9VEO`%]-;V1I9FEC82!,:6YK+BXN
M.@!?3W!Z:6]N:0!?4&5R;65S<VD`7U-T86UP80!?4')I;W)I=.``7T%G9VEO
M<FYA("5S`%]%;&EM:6YA($QI;FLN+BX`7U)I<W!O;F1I`%]2:6-E<F-A`%])
M;G9I82!-97-S86=G:6\`4')O<')I973@(&1E;&QA(%]486)E;&QA`%]!<F=O
M;65N=&\`7T$`7U)E8W5P97)A`%]5=&5N=&D`7U9I<W5A;&EZ>F$@<&5R($%R
M9V]M96YT;P!,:7-T82!?0FEA;F-A`&%L;&5G871O`&%L;&5G871I+GII<`!C
M86QM;P!D86QL92`E<R`H)7,I(&%L;&4@)7,@)7,`8VAI879E`&QI;F5E70!&
M:6QE(&1I(&-A<V5L;&$@9&D@<&]S=&$`;F]M90!N97-S=6YO`&\`<&5R8V5N
M=&\`<&EX96QS`&%U;65N=&%N9&\G`&5R<F]R92!D:2!O<G1O9W)A9FEA`&5R
M<F]R:2!D:2!O<G1O9W)A9FEA`&-O<W1A;G1E`&1I9VET82!L82!P87-S=V]R
M9"!D=64@=F]L=&4@<&5R(&-O;F9E<FUA<F4`=V5A=&AE<BYC;VT`='5A(&QI
M<W1A(&EN9&5S:61E<F%T80!T=6$@;&ES=&$@8V]N<V5N=&ET80``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C
M86QE+VET7TE4+VAE;'`N>&UL````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,3(W,3`Q`#$P-#$W,S8R-S8S`#`R,3$S,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/WAM;"!V97)S:6]N/2(Q
M+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA+2T@)$AO<F1E.B!I;7`O
M;&]C86QE+VET7TE4+VAE;'`N>&UL+'8@,2XQ."XV+C0@,C`P-B\P,2\S,"`Q
M-3HU.#HP,"!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB8V]M
M<&]S92UB=71T;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^0V]M
M<&]S:7II;VYE($UE<W-A9V=I;SH@07II;VYI/"]T:71L93X*("`@(#QH96%D
M:6YG/D%Z:6]N:3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@26YV:6$@365S
M<V%G9VEO(&UA;F1A(&QA(&UA:6P@86P@9&5S=&EN871A<FEO*&DI(&1E<VED
M97)A=&\H:2DN(%!R:6UA(&1I(&-L:6-C87)E('%U:2!D979I(&5S<V5R92!S
M:6-U<F\@9&D@=F]L97)L;R!I;G9I87)E('!E<F,*:.D@;"=A>FEO;F4@Z"!I
M<G)E=F5R<VEB:6QE+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!386QV
M82!";WIZ82!C;VQL;V-A('5N(&UE<W-A9V=I;R!N;VX@8V]M<&QE=&%T;R!I
M;B!U;F$@8V%R=&5L;&$@8VAI86UA=&$@)T)O>GIE)R!A8V-E<W-I8FEL92!D
M86P@;65N=2!A('1E;F1I;F$@<W5L;&$@9&5S=')A(&EN"F%L=&\@9&5L;&$@
M8F%R<F$@9&D@;F%V:6=A>FEO;F4N($EN('-E9W5I=&\@<'5O:2!C;VUP;&5T
M87)E(&EL(&UE<W-A9V=I;R!A;F1A;F1O(&%L;&$@8V%R=&5L;&$@)T)O>GIE
M)RP@8VQI8V-A;F1O('-U:2!M97-S86=G:2!S86QV80IT:2!P97(@87!R:7)L
M;RP@92!P;VD@8VQI8V-A;F1O('-U("=296-U<&5R82<N(%)I8V]R9&$@9&D@
M;65T=&5R92!U;B!/9V=E='1O(&%L;&$@;6%I;"!P<FEM82!D:2!S86QV87)E
M(&QA(&)O>GIA(&EN(&UO9&\@9&$@<&]T97(@:60*96YT:69I8V%R92!F86-I
M;&UE;G1E('%U86QE(&UE<W-A9V=I;R!V=6]I(&YE;&QA(&-A<G1E;&QA($)O
M>GIE+B!$;W!O(&%V97)L;R!S86QV871O(&-O;64@0F]Z>F$L('9I96YI(')I
M;6%N9&%T;R!A9"!)3D)/6"!O(&%L;&$@=6QT"FEM82!C87)T96QL82!C:&4@
M<W1A=FD@=FES=6%L:7IZ86YD;RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@16QI;6EN82!-97-S86=G:6\@8V%N8V5L;&$@:6P@;65S<V%G9VEO(&4@
M=&D@<FEP;W)T82!A9"!)3D)/6"!O(&%L;&$@=6QT:6UA(&-A<G1E;&QA(&-H
M92!S=&%V:2!V:7-U86QI>GIA;F1O+@H@("`@/"]P87)A/@H\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UB=71T;VYS(CX*("`@(#QT
M:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!8W1I;VYS/"]T:71L93X*("`@
M(#QH96%D:6YG/D%C=&EO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E
M;F0@365S<V%G92!L875N8VAE<R!Y;W5R(&5M86EL('1O('1H92!I;G1E;F1E
M9"!R96-I<&EE;G0H<RDN($)E('-U<F4@>6]U('=A;G0@=&\@<V5N9"!B969O
M<F4@8VQI8VMI;F<@:&5R92!A<R!O;F-E('-E;G0@:70@8V%N;F]T(&)E('1A
M:V5N(&)A8VLN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-A=F4@1')A
M9G0@<&QA8V5S(&%N('5N9FEN:7-H960@;65S<V%G92!I;B!A(&9O;&1E<B!C
M86QL960@)T1R869T<R<*86-C97-S:6)L92!B>2!T:&4@<&]P+61O=VX@8F]X
M(&]N('1H92!R:6=H="!S:61E(&]F('1H92!B;'5E(&YA=FEG871I;VX@8F%R
M(&%T('1O<"X@66]U(&-A;B!T:&5N(&9I;FES:"!T:&4@;65S<V%G92!L871E
M<B!B>2!S=VET8VAI;F<@=&\@=&AE("=$<F%F=',G(&9O;&1E<BP@8VQI8VMI
M;F<@;VX@=&AE('-A=F5D(&UE<W-A9V4@=&\@;W!E;B!I="P@86YD('1H96X@
M8VQI8VMI;F<@;VX@)U)E<W5M92<N($)E('-U<F4@=&\@<'5T(&$@<W5B:F5C
M="!O;B!T:&4@96UA:6P@8F5F;W)E('EO=2!S879E('1H92!D<F%F="!S;R!T
M:&%T('EO=2!C86X@96%S:6QY(&ED96YT:69Y('=H:6-H(&UE<W-A9V4@>6]U
M('=A;G0@=VET:&EN('1H92!$<F%F=',@9F]L9&5R+B!!9G1E<B!S879I;F<@
M87,@82!$<F%F="P@>6]U(&%R92!R971U<FYE9"!T;R!Y;W5R($E.0D]8(&]R
M('=H871E=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@($-A;F-E;"!-97-S86=E(&1R;W!S('1H
M92!M97-S86=E(&EN('!R;V=R97-S(&%N9"!S:6UP;'D@<F5T=7)N<R!Y;W4@
M=&\@=&AE($E.0D]8(&]R('=H871E=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W
M:6YG(&QA<W0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](F-O;7!O<V4M9G)O;2(@<W1A=&4](G5N:VYO=VXB/@H@("`@
M/'1I=&QE/D-O;7!O<VEZ:6]N92!-97-S86=G:6\Z($1A/"]T:71L93X*("`@
M(#QH96%D:6YG/B)$82(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-C<FEV
M92!I;"!T=6\@:6YD:7)I>GIO(&1I('!O<W1A(&-O<G)E='1O+B!);"!T=6\@
M:6YD:7)I>GIO('9I96YE('-C<FET=&\@:6X@875T;VUA=&EC;R!D:2!S96=U
M:71O(&$@(D1A.B(@;F5I(&UE<W-A9V=I(&EN('5S8VET"F$N"B`@("`\+W!A
M<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+69R
M;VTB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($9R;VT\+W1I
M=&QE/@H@("`@/&AE861I;F<^)G%U;W0[1G)O;29Q=6]T.SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@16YT97(@>6]U<B!C;W)R96-T(&5M86EL(&%D9')E
M<W,N(%EO=7(@96UA:6P@861D<F5S<R!I<R!A=71O;6%T:6-A;&QY(&5N=&5R
M960@9F]R('EO=2!F;VQL;W=I;F<@)G%U;W0[1G)O;3HF<75O=#L@:6X@;W5T
M9V]I;F<@96UA:6PN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*
M("`\96YT<GD@:60](F-O;7!O<V4M=&\B('-T871E/2)U;FMN;W=N(CX*("`@
M(#QT:71L93Y#;VUP;W-I>FEO;F4@365S<V%G9VEO(#H@03PO=&ET;&4^"B`@
M("`\:&5A9&EN9SXB02(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-C<FEV
M92!L)VEN9&ER:7IZ;RAI*2!E+6UA:6P@8V]R<F5T=&\H:2D@9&5I(&1E<W1I
M;F%T87)I(&1E;"!T=6\@;65S<V%G9VEO+B!$979I('-E<&%R87)E(&-I87-C
M=6X@:6YD:7)I>GIO(&-O;B!U;F$@=FER9V]L83L@86QT"G)A('!U;G1E9V=I
M871U<F$@9&%R96)B92!E<G)O<F4N($-I\B!C:&4@<V-R:79I('-E9W5E(")!
M.B(@;F5L;&$@<&]S=&$@:6X@=7-C:71A+@H@("`@/"]P87)A/@H\(2TM($5N
M9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UT;R(^"B`@("`\=&ET
M;&4^365S<V%G92!#;VUP;W-I=&EO;CH@5&\\+W1I=&QE/@H@("`@/&AE861I
M;F<^)G%U;W0[5&\F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N
M=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E('1O
M(')E8V5I=F4@>6]U<B!M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E86-H
M(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL
M(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T
M.U1O.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL+B`@"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M8V,B('-T
M871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y#;VUP;W-I>FEO;F4@365S<V%G
M9VEO.B!#8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB0V,B/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!38W)I=F4@;"=I;F1I<FEZ>F\H:2D@92UM86EL(&-O
M<G)E='1O*&DI(&1I(&-O;&]R;R!I('%U86QI(')I8V5V97)A;FYO('!E<B!C
M;VYO<V-E;GIA(&EL(&UE<W-A9V=I;RX@1&5V:2!S97!A<F%R92!O9VYI(&EN
M9&ER:7IZ;PH@8V]N('5N82!V:7)G;VQA+B!#:?(@8VAE('-C<FEV:2!S96=U
M92`B0V,Z(B!N96QL82!P;W-T82!I;B!U<V-I=&$N($QE(&-O<&EE('!E<B!C
M;VYO<V-E;GIA(&EN(&=E;F5R92!S;VYO(&EN=FEA=&4@86D@9&5S=&EN871A
M<FD@:6X*(&%G9VEU;G1A(&$@<75E;&QI(&-U:2!S:2!S8W)I=F4@9&ER971T
M86UE;G1E(&UA('-O;F\@=6=U86QM96YT92!D97-T:6YA=&%R:2!I;7!O<G1A
M;G1I(&1E;"!M97-S86=G:6\L(&EN(&=E;F5R92!Q=6%L8W5N;R!I;G1E<F5S
M<V%T"F\@:6YD:7)E='1A;65N=&4@86QL)V]G9V5T=&\@9&5L;&$@;6%I;"X@
M5'5T=&D@:2!D97-T:6YA=&%R:2`G03HG(&4@)T-C.B<@<&]S<V]N;R!V961E
M<F4@='5T=&$@;&$@;&ES=&$@9&D@96YT<F%M8F4@:2!T:7!I(&1I(&1E<W1I
M;@IA=&%R:2X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT
M<GD@:60](F-O;7!O<V4M8V,B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ($-C/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T-C)G%U;W0[
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E
M;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@8V%R8F]N
M(&-O<'D@;V8@>6]U<B!M97-S86=E+B!397!A<F%T92!E86-H(&%D9')E<W,@
M=VET:"!A(&-O;6UA+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[0V,Z)G%U
M;W0[(&EN(&]U=&=O:6YG(&UA:6PN($-A<F)O;B!C;W!I97,@87)E('5S=6%L
M;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!T:&4@;VYE*',I(&)E:6YG
M('=R:71T96X@=&\@9&ER96-T;'D@8G5T(&%R92!I;7!O<G1A;G0@<F5C:7!I
M96YT<R!O9B!T:&4@96UA:6P@87,@=V5L;"P@=7-U86QL>2!S;VUE;VYE(&EN
M9&ER96-T;'D@8V]N8V5R;F5D(&%B;W5T('1H92!S=6)J96-T(&]F('1H92!E
M;6%I;"X@($%L;"`G5&\Z)R!R96-I<&EE;G1S(&%N9"`G0V,Z)R!R96-I<&EE
M;G1S(&-A;B!S964@=&AE(&5N=&ER92!L:7-T(&]F(&)O=&@@:VEN9',@;V8@
M<F5C:7!I96YT<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB8V]M<&]S92UB8V,B('-T871E/2)U;FMN;W=N(CX*("`@
M(#QT:71L93Y#;VUP;W-I>FEO;F4@365S<V%G9VEO.B!"8V,\+W1I=&QE/@H@
M("`@/&AE861I;F<^(D)C8R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-C
M<FEV92!L)VEN9&ER:7IZ;RAI*2!E+6UA:6P@8V]R<F5T=&\H:2D@9&D@8V]L
M;W)O(&D@<75A;&D@<FEC979E<F%N;F\@<&5R(&-O;F]S8V5N>F$@;F%S8V]S
M=&$@:6P@;65S<V%G9VEO+B!$979I('-E<&%R87)E(&]G;FD*:6YD:7)I>GIO
M(&-O;B!U;F$@=FER9V]L82X@0VGR(&-H92!S8W)I=FD@<V5G=64@(D)C8SHB
M(&YE;&QA('!O<W1A(&EN('5S8VET82X@3&4@8V]P:64@<&5R(&-O;F]S8V5N
M>F$@;F%S8V]S=&$@<V]N;R!I;G9I871E(&%I(&1E<W1I"FYA=&%R:2!I;B!A
M9V=I=6YT82!A('%U96QL:2!D:7)E='1I(&4@:6YD:7)E='1I("AD97-T:6YA
M=&%R:2!D96P@=&EP;R`B03HB(&%N9"`B0V,Z(BD@8VAE(&1E=F]N;R!L96=G
M97)E(&EL(&UE<W-A9V=I;R!314Y:02!C:&4@9VQI"F%L=')I(&1E<W1I;F%T
M87)I(&QO('-A<'!I86UO+B!1=6EN9&D@)VYA<V-O<W1O)R!S:6=N:69I8V$@
M8VAE(&PG:6YD:7)I>GIO(&1I('%U96D@9&5S=&EN871A<FD@Z"!N87-C;W-T
M;R!A('1U='1I(&=L:2!A;'1R:2!D97-T:6YA=`IA<FD@9&5L(&UE<W-A9V=I
M;RP@92!S;VQO('1U(&4@;&]R;R!S86YN;R!C:&4@:&%N;F\@<FEC979U=&\@
M=6YA(&-O<&EA+B!);B!G96YE<F4@=7-I($)C8R!P97(@9&ER92!A9"!U;F$@
M<&5R<V]N82!A=71O<FEZ>F%T82!C:&4@<W0*86D@9&EC96YD;R!Q=6%L8V]S
M82!A('%U86QC=6YO('-E;GIA(&EN=&5R97-S87)E(&EL(&1E<W1I;F%T87)I
M;R!D:7)E='1O(&1E;&QA(&UA:6PN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES
M:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6)C8R(^"B`@("`\=&ET;&4^
M365S<V%G92!#;VUP;W-I=&EO;CH@0F-C/"]T:71L93X*("`@(#QH96%D:6YG
M/B9Q=6]T.T)C8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT
M97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@
M<F5C96EV92!A(&)L:6YD(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@
M66]U(&UU<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@
M;W1H97(@<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO
M=7(@96YT<GD@9F]L;&]W<R`F<75O=#M"8V,Z)G%U;W0[(&EN(&]U=&=O:6YG
M(&UA:6PN($)L:6YD(&-A<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T
M;R!P96]P;&4@;W1H97(@=&AA;B!D:7)E8W0@86YD(&EN9&ER96-T(')E8VEP
M:65N=',@*"9Q=6]T.U1O.B9Q=6]T.R!A;F0@)G%U;W0[0V,Z)G%U;W0[(')E
M8VEP:65N=',I('=H;R!N965D('1O(')E860@=VAA="!I<R!B96EN9R!W<FET
M=&5N(&%S('=E;&P@5TE42$]55"!T:&4@;W1H97(@<F5C:7!I96YT<R!K;F]W
M:6YG('1H870@=&AE>2!A<F4@<F5C96EV:6YG('1H92!E;6%I;"X@5&AU<R`G
M8FQI;F0G(&UE86YS('1H870@=&AE(&ED96YT:71Y(&]F('1H97-E(')E8VEP
M:65N=',@:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R(')E8VEP:65N=',@;V8@
M=&AE(&5M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H97D@:VYO=R!T:&5Y(&=O
M="!A(&-O<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H:7,@=&\@=&5L;"!A;B!A
M=71H;W)I='D@9FEG=7)E('1H870@>6]U(&%R92!T96QL:6YG('-O;65O;F4@
M<V]M971H:6YG('=I=&AO=70@86QA<FUI;F<@=&AE('!E<G-O;B!Y;W4@87)E
M('-E;F1I;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T
M(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^0V]M<&]S:7II;VYE($UE
M<W-A9V=I;SH@3V=G971T;SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB3V=G971T
M;R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-C<FEV92!L)V]G9V5T=&\@
M9&5L(&UE<W-A9V=I;RX@0VGR(&-H92!S8W)I=FD@<V5G=64@(D]G9V5T=&\Z
M(B!N96QL82!P;W-T82!I;B!U<V-I=&$N(%-C<FEV:2!U;B!/9V=E='1O(&)R
M979E+"!S96UP;&EC92!E(&1E<V-R"FET=&EV;RX@($PG3V=G971T;R#H(&EL
M(&UO9&\@<&GY('-E;7!L:6-E('!E<B!T92!I('1U;VD@9&5S=&EN871A<FD@
M9&D@<FEC;W)D87)E(&EL(&-O;G1E;G5T;R!D96P@;65S<V%G9VEO(&4@<75I
M;F1I(.@@;6]L=&\@:6UP;W)T80IN=&4@<&5R(&]R9V%N:7IZ87)E(&D@;65S
M<V%G9VD@92!T<F]V87)E(&EN('-E9W5I=&\@<75E;&QI(&EM<&]R=&%N=&DN
M("!);F]L=')E+"!Q=6%N9&\@)U)I<W!O;F1I)R!O("=);F]L=')I)R!U;B!M
M97-S86=G:6\@<75E<W1O(&\*9V=E='1O('9I96YE(&-O<&EA=&\@;F5I(&YU
M;W9I(&UE<W-A9V=I(&4@8V]S["#H('5N(&)U;VX@;6]D;R!P97(@9&ER92!Q
M=6%L:2!M97-S86=G:2!V86YN;R!A<W-I96UE('!E<B!D87)E('5N(")F:6QO
M(B!A;&QA(&-O;G9E<G-A"GII;VYE+B`@0V]M=6YQ=64L('-E("=2:7-P;W-T
M82<@92`G26YO;'1R82<@8V]N=&5N9V]N;R!N=6]V:2!C;VYC971T:2P@<'5O
M:2!A9V=I=6YG97)E('!I8V-O;&4@;6]D:69I8VAE(&%L;&\@)T]G9V5T=&\G
M(&-O<VD@:6P@9&5S=`II;F%R:6\H:2D@<&]S<V]N;R!S96=U:7)E(&EL(")F
M:6QO(BX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@
M:60](F-O;7!O<V4M<W5B:F5C="(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@4W5B:F5C=#PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M3
M=6)J96-T)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T
M:&4@<W5B:F5C="!O9B!Y;W5R(&UE<W-A9V4N(%EO=7(@96YT<GD@9F]L;&]W
M<R`F<75O=#M3=6)J96-T.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL+B!+965P
M(&ET('-H;W)T+"!S:6UP;&4@86YD(&1E<V-R:7!T:79E+B`@5&AE('-U8FIE
M8W0@;&EN92!I<R!T:&4@96%S:65S="!W87D@9F]R('EO=2!A;F0@>6]U<B!C
M;W)R97-P;VYD96YT<R!T;R!R96UE;6)E<B!W:&%T('=A<R!I;B!T:&4@96UA
M:6P@86YD('1H=7,@:7,@=F5R>2!I;7!O<G1A;G0@:6X@;W)G86YI>FEN9R!Y
M;W5R(&5M86EL(&%N9"!F:6YD:6YG(&EM<&]R=&%N="!O;F5S(&QA=&5R+B`@
M06QS;RP@=VAE;B!Y;W4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@86YD(&5M86EL
M('1H:7,@<W5B:F5C="!L:6YE(&ES(&-O<&EE9"!O=F5R(&EN=&\@=&AE(&YE
M=R!M97-S86=E(&%N9"!S;R!I<R!A('9A;'5A8FQE('=A>2!O9B!T96QL:6YG
M('=H870@;65S<V%G97,@9V\@=&]G971H97(@=&\@9F]R;2!A("9Q=6]T.W1H
M<F5A9"9Q=6]T.R!O9B!A(&-O;G9E<G-A=&EO;BX@($AO=V5V97(L(&EF('1H
M92`G4F5P;'DG(&]R("=&;W)W87)D)R!C;VYT86EN<R!N97<@:61E87,L('EO
M=2!M87D@=V%N="!T;R!A9&0@<VEM<&QE(&UO9&EF:6-A=&EO;G,@=&\@=&AE
M("=3=6)J96-T)R!L:6YE('-O('1H92!R96-I<&EE;G0H<RD@8V%N(&9O;&QO
M=R!T:&4@<')O9W)E<W-I;VX@;V8@=&AE("9Q=6]T.W1H<F5A9"XF<75O=#L*
M("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M8V]M<&]S92UO<'1I;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M0V]M<&]S:7II;VYE($UE<W-A9V=I;SH@3W!Z:6]N:3PO=&ET;&4^"B`@("`\
M:&5A9&EN9SXB3W!Z:6]N:2(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%%U
M97-T92!O<'II;VYI('1I(&%I=71A;F\@82!P<F5P87)A<F4@:6P@;65S<V%G
M9VEO+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#;&EC8V$@(D-O;G1R
M;VQL;R!/<G1O9W)A9FEA(B!P97(@8V]N=')O;&QA<F4@;&$@;W)T;V=R869I
M82X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI8V-A(")!;&QE9V%T
M:2(@<&5R('9I<W5A;&EZ>F%R92!I;B!F;VYD;R!A;&QA('!A9VEN82!U;F$@
M;&ES=&$@9&D@9FEL92!A;&QE9V%T:2!A('%U97-T;R!M97-S86=G:6\N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%T=&EV82!I;"!B;W1T;VYE(&1I
M('-P=6YT82!V:6-I;F\@82`B4V%L=F$@8V]P:6$B('!E<B!S86QV87)E('5N
M82!C;W!I82!D:2!Q=65S=&\@;65S<V%G9VEO(&YE;&QA('1U82!C87)T96QL
M82`B4&]S=&$@26YV:6%T82(N"B!386QV82!C;W!I92!D96D@;65S<V%G9VD@
M:6UP;W)T86YT:2!C:&4@:6YV:6D@:6X@;6]D;R!D82!A=F5R('%U86QC;W-A
M(&-U:2!F87(@<FEF97)I;65N=&\@:6X@<V5G=6ET;R!E('1E;F5R92!U;B!A
M<F-H:79I;R!D:2!C;W-A"G-I(.@@9&5T=&\N($YO;B!D:6-I86UO(&1I('-A
M;'9A<F4@;V=N:2!M97-S86=G:6\@86QT<FEM96YT:2!L;R!S<&%Z:6\@9&5L
M('1U;R!D:7-C;R!S:2!R:61U<G)E8F)E(')A<&ED86UE;G1E("AS;W!R871T
M=71T;R!I;G9I86YD;PH@86QL96=A=&DI(&4@;&$@='5A(&-A<V5L;&$@<V%R
M96)B92!P:65N82!E(&EM<&]S<VEB:6QI=&%T82!A(')I8V5V97)E(&YU;W9A
M('!O<W1A(&EN(&5N=')A=&$N(%!U;VD@8V]M=6YQ=64@871T:79A<F4@<75E
M<W1A(&-A<F%T=&4*<FES=&EC82!C;VUE(&1E9F%U;'0@8V]N(&QE("=0<F5F
M97)E;GIE)R!S=6QL82!B87)R82!D:2!N879I9V%Z:6]N92!B;'4@:6X@86QT
M;RX@071T96YZ:6]N92!A9"!U=&EL:7IZ87)E('%U97-T;R!D969A=6QT('!E
M<F-HZ"!D;W9R"F%I(&1I('1A;G1O(&EN('1A;G1O('-V=6]T87)E(&QA('1U
M82!C87)T96QL82`B4&]S=&$@26YV:6%T82(@86QT<FEM96YT:2!I;B!Q=6%L
M8VAE(&UO;65N=&\@<FEE;7!I<N`@;&$@='5A(&-A<V5L;&$@9&D@<&]S=&$@
M<F5N9&5N9`IO;&$@:6YU=&EL:7IZ86)I;&4N"B`@("`\+W!A<F$^"CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($]P=&EO;G,\+W1I=&QE
M/@H@("`@/&AE861I;F<^)G%U;W0[3W!T:6]N<R9Q=6]T.SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AE<V4@3W!T:6]N<R!H96QP('EO=2!P<F5P87)E
M('EO=7(@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI
M8VL@)G%U;W0[4W!E;&P@0VAE8VLF<75O=#L@=&\@8VAE8VL@>6]U<B!S<&5L
M;&EN9RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI8VL@)G%U;W0[
M071T86-H;65N=',F<75O=#L@=&\@=FEE=R!A="!T:&4@8F]T=&]M(&]F('1H
M92!P86=E(&$@;&ES="!O9B!F:6QE<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A
M9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%C=&EV871E('1H92!C
M:&5C:RUB=71T;VX@;F5X="!T;R`F<75O=#M3879E(&-O<'DF<75O=#L@=&\@
M<V%V92!A(&-O<'D@;V8@=&AI<R!M97-S86=E(&EN('EO=7(@)G%U;W0[4V5N
M="!-86EL)G%U;W0[(&9O;&1E<BX@4V%V92!C;W!I97,@;V8@:6UP;W)T86YT
M(&5M86EL<R!Y;W4@<V5N9"!S;R!T:&%T('EO=2!H879E('-O;65T:&EN9R!T
M;R!R969E<B!B86-K('1O(&QA=&5R(&%N9"!T;R!K965P(&%N(&%C8W5R871E
M(')E8V]R9"!O9B!W:&%T('=A<R!S86ED+B!792!D;R!N;W0@<F5C;VUM96YD
M('EO=2!S879E(&5V97)Y(&5M86EL('-I;F-E('1H96X@>6]U<B!D:7-K('-T
M;W)A9V4@<75O=&$@=VEL;"!B92!U<V5D('5P('%U:6-K;'D@*&5S<&5C:6%L
M;'D@=VAE;B!Y;W4@<V5N9"!A='1A8VAM96YT<RD@86YD('EO=7(@;6%I;&)O
M>"!W:6QL(&)E(&9U;&P@86YD('5N86)L92!T;R!R96-E:79E(&YE=R!I;F-O
M;6EN9R!E;6%I;"X@66]U(&-A;BP@:&]W979E<BP@='5R;B!T:&ES(&9E871U
M<F4@)V]N)R!A<R!Y;W5R(&1E9F%U;'0@=VET:&EN('EO=7(@261E;G1I='DL
M(&)Y(&=O:6YG('1O($]P=&EO;G,M)F=T.U!E<G-O;F%L($EN9F]R;6%T:6]N
M+29G=#M%9&ET('EO=7(@:61E;G1I=&EE<RX@0F4@8V%R969U;"!W:&5N('5S
M:6YG('1H:7,@;6]D:69I960@9&5F875L="!A<R!Y;W4@=VEL;"!N965D('1O
M('!E<FEO9&EC86QL>2!P=7)G92!Y;W5R("9Q=6]T.U-E;G0@36%I;"9Q=6]T
M.R!F;VQD97(@;W(@:70@=VEL;"!E=F5N='5A;&QY(&UA:V4@>6]U<B!M86EL
M8F]X(&9U;&P@86YD('5N=7-E86)L92X*("`@(#PO<&%R83X*/"]E;G1R>3XM
M+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B('-T871E
M/2)U;FMN;W=N(CX*("`@(#QT:71L93Y#;VUP;W-I>FEO;F4@365S<V%G9VEO
M(#H@06QL96=A/"]T:71L93X*("`@(#QH96%D:6YG/B)!;&QE9V$B/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("`@("`@4'5O:2!A;&QE9V%R92!F:6QE<R!A
M;"!T=6\@;65S<V%G9VEO+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4&%S<V\@
M,3H@3R!S8W)I=FD@:6P@<&5R8V]R<V\@92!I;"!N;VUE(&1E;"!F:6QE(&-H
M92!V=6]I(&%L;&5G87)E(&$@<75E<W1O(&UE<W-A9V=I;R!O(&-L:6-C:2!I
M;"!B;W1T;VYE(")"<F]W<V4B(&4@<V5L97H*:6]N:2!I;"!F:6QE(&1A(&%L
M;&5G87)E+B!);"!P97)C;W)S;R!E(&EL(&YO;64@9&D@<75E;"!F:6QE(&]R
M82!C;VUP87)E(&YE;&QA(&)O>"!D96=L:2!A;&QE9V%T:2X@3W)A('9A:2!A
M;"!087-S;R`R+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4&%S<V\@,CH@0VQI
M8V-A(&EL(&)O='1O;F4@(D%L;&5G82(N($EL(&YO;64@92!L82!D:6UE;G-I
M;VYE(&1E;"!F:6QE('9E<G)A;FYO(&%G9VEU;G1I(&%L;&$@='5A(&QI<W1A
M(&1I($%L;&5G871I+B!.;W1A(&,*:&4@<&5R(&9I;&4@<&5S86YT:2!E+V\@
M8V]N;F5S<VEO;FD@26YT97)N970@;&5N=&4L(&EL('!R;V-E<W-O(&-H92!C
M87)I8V$@92!A;&QE9V$@:6P@9FEL92!A;"!M97-S86=G:6\@<'7R(')I8VAI
M961E<F4@9&5L('1E;7!O+B!3"FEI('!A>FEE;G1E(&4@;F]N(&-L:6-C87)E
M('-U(&%L=')E(&-O<V4@;65N=')E(&%T=&5N9&DN"B`@("`\+W!A<F$^"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:"(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H/"]T:71L
M93X*("`@(#QH96%D:6YG/B9Q=6]T.T%T=&%C:"9Q=6]T.SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@66]U(&UA>2!A='1A8V@@9FEL97,@=&\@>6]U<B!M
M97-S86=E.R!O;FQY(&]N92!F:6QE(&UA>2!B92!A='1A8VAE9"!A="!A('1I
M;64N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5I=&AE<BP@='EP
M92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A(&9I;&4@=&AA="!Y;W4@=V%N="!A
M='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@;W(@8VQI8VL@)G%U;W0[0G)O=W-E
M)G%U;W0[(&)U='1O;B!A;F0@<V5L96-T('1H92!F:6QE('1O(&)E(&%T=&%T
M8VAE9"X@5&AE('!A=&@@86YD(&YA;64@;V8@=&AA="!F:6QE(&YO=R!A<'!E
M87)S(&EN('1H92!!='1A8VAM96YT(&)O>"X*("`@(#PO<&%R83X*("`@(#QP
M87)A/E-T97`@,CH@1&5C:61E('=H971H97(@>6]U('=A;G0@=&AE(&9I;&4@
M=&\@8F4@=FEE=V5D(&%S(&%N(&%T=&%C:&UE;G0@;W(@:6YL:6YE9"!W:71H
M('1H92!R97-T(&]F('1H92!M97-S86=E+B!4:&4@<F5C96EV:6YG('!E<G-O
M;BAS*2!M86EL(')E861I;F<@<V]F='=A<F4@;75S="!B92!A8FQE('1O(&AA
M;F1L92!T:&4@9FEL92!T>7!E(&EN;&EN93L@:68@;F]T+"!T:&ES('!A<G0@
M=VEL;"!B92!V:65W960@87,@86X@871T86-H;65N="!I;G-T96%D+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^4W1E<"`S.B!#;&EC:R`F<75O=#M!='1A8V@F
M<75O=#L@8G5T=&]N+B!4:&4@9FEL92!N86UE(&%N9"!S:7IE('=I;&P@8F4@
M861D960@=&\@>6]U<B!L:7-T(&]F($%T=&%C:&UE;G1S+B!0;&5A<V4@;F]T
M92!T:&%T(&9O<B!L87)G92!F:6QE<R!A;F0O;W(@<VQO=V5R($EN=&5R;F5T
M(&-O;FYE8W1I;VYS+"!T:&4@<')O8V5S<R!O9B!U<&QO861I;F<@86YD(&%T
M=&%C:&EN9R!Y;W5R(&9I;&4@=&\@=&AE(&5M86EL(&UA>2!T86ME(&$@=VAI
M;&4N(%!L96%S92!B92!P871I96YT(&%N9"!D;R!N;W0@8VQI8VL@;W1H97(@
M=&AI;F=S('=H:6QE('EO=2!A<F4@=V%I=&EN9RX*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM
M96YT<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/D-O;7!O<VEZ:6]N
M92!-97-S86=G:6\@.B!!;&QE9V%T:3PO=&ET;&4^"B`@("`\:&5A9&EN9SXB
M06QL96=A=&DB/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!1=65S=&$@<V5Z
M:6]N92!M;W-T<F$@=6YA(&QI<W1A(&1I(&9I;&5S(&=IX"!A;&QE9V%T:2!A
M;"!T=6\@;65S<V%G9VEO+B!097(@96QI;6EN87)E('5N(&9I;&4@86QL96=A
M=&\Z"B`@("`\+W!A<F$^"B`@("`\<&%R83Y087-S;R`Q.B!3<'5N=&$@:6P@
M8VAE8VL@8F]X('9I8VEN;R!A;"!N;VUE(&1E;"!F:6QE(&%L;&5G871O(&-H
M92!V=6]I(&5L:6UI;F%R92X*("`@(#PO<&%R83X*("`@(#QP87)A/E!A<W-O
M(#(Z($-L:6-C82`B16QI;6EN82!A;&QE9V%T;RAI*2(N"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C
M:&UE;G1S(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A
M8VAM96YT<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M!='1A8VAM96YT
M<R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S96-T:6]N
M(&1I<W!L87ES(&$@;&ES="!O9B!F:6QE<R!A;')E861Y(&%T=&%C:&5D('1O
M('EO=7(@;65S<V%G92X@5&\@1&5L971E(&%N(&%T=&%C:&5D(&9I;&4Z"B`@
M("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($%C=&EV871E('1H92!C:&5C
M:RUB=71T;VX@;F5X="!T;R!T:&4@871T86-H960@9FEL96YA;64@>6]U('=A
M;G0@=&\@1&5L971E+@H@("`@/"]P87)A/B`*("`@(#QP87)A/E-T97`@,CH@
M0VQI8VL@)G%U;W0[1&5L971E($%T=&%C:&UE;G0H<RDF<75O=#LN"B`@("`\
M+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O
M<V4M<')I;W)I='DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ(%!R:6]R:71Y/"]T:71L93X*("`@(#QH96%D:6YG/B)0
M<FEO<FET>2(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@<V5T<R!T
M:&4@(E@M4')I;W)I='DB(&AE861E<B!O;B!Y;W5R(&]U=&=O:6YG(&UE<W-A
M9V4N(%1H92`B6"U0<FEO<FET>2(@=&%G(&ES(&$@<V]R="!O9B`B<'-E=61O
M('-T86YD87)D(B!T:&%T($YE='-C87!E+"!-;WII;&QA+"!/<&5R82P@86YD
M($]U=&QO;VL@;6%I;"!C;&EE;G1S(&%P<&5A<B!T;R!A9W)E92!O;BX@06YY
M(&UA:6P@8VQI96YT<R!T:&%T(&1O(&YO="!H86YD;&4@=&AI<R!H96%D97(@
M=VEL;"!S:6UP;'D@:6=N;W)E(&ET+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB8V]M<&]S92US879E+6%T=&%C:&UE;G1S(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!3879E($%T
M=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W
M:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N(&%R
M92!S879E9"!W:71H('1H92!M97-S86=E('=H96X@<W1O<F5D(&EN('1H92!S
M96YT+6UA:6P@9F]L9&5R+B`@268@(EEE<R(L('1H92!A='1A8VAM96YT(&1A
M=&$@=VEL;"!B92!S879E9"X@($EF(").;R(L('1H92!A='1A8VAM96YT(&1A
M=&$@=VEL;"!B92!S=')I<'!E9"!F<F]M('1H92!M97-S86=E(&%F=&5R(&ET
M(&ES('-E;G0@=&\@86QL(')E8VEP:65N=',N("!#:&]O<VEN9R`B3F\B('=I
M;&P@:&5L<"!C;VYS97)V92!D:7-K('-P86-E(&)Y(')E;6]V:6YG("AP;W1E
M;G1I86QL>2!L87)G92D@871T86-H;65N="!I;F9O<FUA=&EO;B!F<F]M('1H
M92!S879E9"!M97-S86=E<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F-O;7!O<V4M;&EN:RUA='1A8VAM96YT<R(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@3&EN:R!!='1A8VAM
M96YT<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R;6EN97,@=VAE=&AE
M<B!T:&4@871T86-H;65N=',@:6X@>6]U<B!C;VUP;W-I=&EO;B!A<F4@<V5N
M="!A<R!A('!A<G0@;V8@=&AE(&UA:6P@;65S<V%G92!O<B!W:&5T:&5R('1H
M;W-E(&%T=&%C:&UE;G1S(&%R92!K97!T(&]N(&$@;&]C86P@<V5R=F5R+B`@
M268@871T86-H;65N=',@87)E(&QI;FME9"P@=&AE(')E8VEP:65N="AS*2!O
M9B!Y;W5R(&UE<W-A9V4@=VEL;"!B92!P<F]V:61E9"!A('=E8FQI;FL@=VAE
M<F4@=&AE>2!C86X@9&]W;FQO860@=&AE(&%T=&%C:&UE;G0H<RDN("!,:6YK
M:6YG(&%T=&%C:&UE;G1S(&AA<R!T:&4@861V86YT86=E(&]F('1R96UE;F1O
M=7-L>2!R961U8VEN9R!T:&4@<VEZ92!O9B!O=71G;VEN9R!M97-S86=E<RX@
M($QI;FMI;F<@871T86-H;65N=',@:&%S('1H92!D:7-A9'9A;G1A9V4@=&AA
M="!T:&4@8V]N=&5N="!O9B!T:&4@871T86-H;65N=',@8V%N(&YO="!B92!G
M=6%R86YT965D('1O(&)E(&%V86EL86)L92!I;B!T:&4@9G5T=7)E('-I;F-E
M('1H92!A='1A8VAM96YT(&1A=&$@:7,@;F]T(&QO8V%T960@=VET:&EN('1H
M92!E+6UA:6P@;65S<V%G92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G-E87)C:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/E)I
M8V5R8V$@365S<V%G9VEO(#PO=&ET;&4^"B`@("`\:&5A9&EN9SY#<FET97)I
M;R!D:2!2:6-E<F-A/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@("`@06YC
M;W)A(&EN(&9A<V4@9&D@<W1E<W5R82X*("`@(#PO<&%R83X*/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](G-E87)C:"(^"B`@("`\=&ET;&4^365S
M<V%G92!396%R8V@\+W1I=&QE/@H@("`@/&AE861I;F<^4V5A<F-H($-R:71E
M<FEA/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y('-E87)C:"!F
M;W(@;65S<V%G97,@9G)O;2!Y;W5R(&9O;&1E<G,@=7-I;F<@9&EF9F5R96YT
M('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@
M,3H@16YT97(@=&5X="!T;R!T:&4@9FEE;&1S('EO=2!W86YT('1O(&%D9"!T
M;R!Y;W5R('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*("`@(#QP87)A
M/E-T97`@,CH@0VAO;W-E('1H92!M97-S86=E(&9L86<H<RD@=&\@861D('1O
M('EO=7(@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M4W1E<"`S.B!#:&]O<V4@=&AE(&9O;&1E<BAS*2!F<F]M('=H:6-H('1O('-E
M87)C:"!F;W(@=&AE(&UE<W-A9V5S+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M4W1E<"`T.B!#;&EC:R`F<75O=#M396%R8V@F<75O=#LN"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@($EF(&%N>2!M97-S86=E<R!M871C:&5D('EO=7(@
M<V5A<F-H(&-R:71E<FEA+"!T:&5N('1H92!S=6)J96-T<R!O9B!T:&5S92!M
M97-S86=E<R!W:6QL(&)E('-H;W=N(&EN('1H92`F<75O=#M396%R8V@@4F5S
M=6QT<R9Q=6]T.R!V:65W+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/D=E<W1I;VYE($-A<G1E;&QE/"]T:71L93X*("`@
M(#QH96%D:6YG/D]P>FEO;FD@0V%R=&5L;&$\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@("`@4'5O:2!S96QE>FEO;F%R92!U;F$@8V%R=&5L;&$@=7-A;F1O
M(&D@<F%D:6\@8G5T=&]N(&QU;F=O(&QA(&-O;&]N;F$@<VEN:7-T<F$N($9A
M='1O('%U97-T;RP@<V-E9VQI('1R86UI=&4@;&$@8V%S96QL82!D:2!S96QE
M"GII;VYE(&$@<VEN:7-T<F$@;&$@;W!Z:6]N92!C:&4@=G5O:2!A='1I=F%R
M92!S=6QL82!C87)T96QL82X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M("!0;W1R86D@<V-E9VQI97)E(&%L=')E(&]P>FEO;FDN($%T=&5N>FEO;F4@
M8V]N(&QE(&]P>FEO;FD@96QI;6EN871E+"!P97)C:.D@<&]T<F5S=&D@<&5R
M9&5R92!T=71T:2!I(&UE<W-A9V=I(&EN('5N82!C87)T96QL80IS92!L82!C
M86YC96QL87-S:2!P97(@97)R;W)E(0H@("`@/"]P87)A/@H\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB9F]L9&5R+6]P=&EO;G,B/@H@("`@/'1I
M=&QE/D9O;&1E<B!-86YA9V5M96YT/"]T:71L93X*("`@(#QH96%D:6YG/D9O
M;&1E<B!/<'1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%EO=2!C
M86X@<V5L96-T(&$@9F]L9&5R(&)Y('5S:6YG('1H92!R861I;R!B=71T;VYS
M(&%L;VYG('1H92!L969T(&-O;'5M;BX@($]N8V4@>6]U(&AA=F4@9&]N92!T
M:&ES+"!S96QE8W0@=&AE(&]P=&EO;B!Y;W4@=VES:"!T;R!P97)F;W)M(&]N
M('1H92!F;VQD97(@=FEA('1H92!S96QE8W0@8F]X('1O('1H92!L969T+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%EO=2!W:6QL(&)E('!R;VUP
M=&5D(&9O<B!F=7)T:&5R(&]P=&EO;G,N("!"92!C87)E9G5L('=I=&@@=&AE
M(&1E;&5T92!O<'1I;VXL(&%S('EO=2!C86X@;&]S92!A;&P@=&AE(&UE<W-A
M9V5S(&EN(&$@9F]L9&5R(&EF('EO=2!D96QE=&4@:70@8GD@;6ES=&%K92$*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DEM<&]R="!M8F]X($9I;&4\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@("`@5&AI<R!O<'1I;VX@=VEL;"!I;7!O
M<G0@82!M8F]X(&9O<FUA="!F:6QE(&EN=&\@=&AE(&9O;&1E<B!O9B!Y;W5R
M(&-H;VEC92X@0VAO;W-E(#$@*&]N92D@9F]L9&5R('1O(&EM<&]R="!T:&4@
M;65S<V%G97,@:6YT;R!A;F0@=&AE;B!S96QE8W0@=&AI<R!O<'1I;VXN(%EO
M=2!W:6QL('1H96X@8F4@=&%K96X@=&\@82!P86=E('1H870@=VEL;"!P<F]M
M<'0@9F]R('1H92!M8F]X(&9I;&4@=&\@:6UP;W)T+@H@("`@/"]P87)A/@H\
M+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M=VED9V5T
M<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1F]L9&5R($UA;F%G96UE;G0Z
M($1I<W!L87D\+W1I=&QE/@H@("`@/&AE861I;F<^4VAO=R](:61E(%5N<W5B
M<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=7-I;F<@24U!
M4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO=R]H:61E('1H92!U;G-U8G-C
M<FEB960@9F]L9&5R<RX@(%1O('-U8G-C<FEB92]U;G-U8G-C<FEB92!T;R!A
M(&9O;&1E<BP@<V5L96-T('1H92!C:&5C:V)O>"!N97AT('1O('1H92!F;VQD
M97)N86UE(&%N9"!U<V4@=&AE(%-U8G-C<FEB92]5;G-U8G-C<FEB92!O<'1I
M;VX@:6X@=&AE($9O;&1E<B!!8W1I;VX@9')O<"UD;W=N(&UE;G4N"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY%>'!A;F0@06QL/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!%>'!A;F0@86QL(&9O;&1E<B!E;G1R:65S+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^0V]L;&%P<V4@06QL/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!#;VQL87!S92!A;&P@9F]L9&5R(&5N=')I97,N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97)S(B!S=&%T93TB
M=6YK;F]W;B(^"B`@("`\=&ET;&4^1FEL=')I.B!!<'!L:6-A/"]T:71L93X*
M("`@(#QH96%D:6YG/D%P<&QI8V$@4F5G;VQE(&1I($9I;'1R;SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@0VQI8V-A('-U;&QA(&EC;VYA(")!<'!L:6-A
M($9I;'1R;R(@=FEC:6YO(&%D($E.0D]8(&YE;&QA(&-A<V5L;&$@9&D@<&]S
M=&$@<&5R(&9I;'1R87)E('1U='1I(&D@;65S<V%G9VD@;F]N(&5L:6UI;F%T
M:2!I;B!B87-E(&$*;&QE(')E9V]L92!S<&5C:69I8V%T92X@3RP@:6X@86QT
M97)N871I=F$L(&-L:6-C82!S=2`B07!P;&EC82!T=71T92!L92!R96=O;&4B
M(&YE;"!M96[Y(&1E;"!F:6QT<F\N($YO=&$@8VAE(&D@9FEL=')I(&YO;B!V
M96YG;VYO(&%P"G!L:6-A=&D@875T;VUA=&EC86UE;G1E+@H@("`@/"]P87)A
M/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB9FEL=&5R<R(^"B`@
M("`\=&ET;&4^1FEL=&5R<SH@07!P;'D\+W1I=&QE/@H@("`@/&AE861I;F<^
M07!P;'D@1FEL=&5R(%)U;&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#
M;&EC:R!O;B!T:&4@)G%U;W0[07!P;'D@1FEL=&5R)G%U;W0[(&EC;VX@;F5X
M="!T;R!T:&4@24Y"3U@@;F%M92!I;B!T:&4@;6%I;&)O>"!V:65W('1O(&9I
M;'1E<B!A;&P@=6YD96QE=&5D(&UE<W-A9V5S(&%C8V]R9&EN9R!T;R!T:&4@
M<W!E8VEF:65D(')U;&5S+B`@3W(L(&%L=&5R;F%T979L>2P@8VQI8VL@;VX@
M)G%U;W0[07!P;'D@06QL(%)U;&5S)G%U;W0[(&EN('1H92!F:6QT97(@;65N
M=2X@($YO=&4@=&AA="!F:6QT97)I;F<@:7,@;F]T(&1O;F4@875T;VUA=&EC
M86QL>2X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB9FEL=&5R+65D:70M<G5L97,B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/D9I;'1E<G,Z($5D:70@1FEL=&5R(%)U;&5S/"]T:71L93X*("`@(#QH
M96%D:6YG/D5D:70@66]U<B!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(B!T
M;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE
M=&4L(&%N9"!E9&ET('1H92!C=7)R96YT;'D@86-T:79E('-E="!O9B!F:6QT
M97(@<G5L97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F
M:6QT97(M961I="UB;&%C:VQI<W0B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/D9I;'1E<G,Z($5D:70@0FQA8VML:7-T/"]T:71L93X*("`@(#QH96%D:6YG
M/D5D:70@66]U<B!";&%C:VQI<W0\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($-L:6-K(&]N(")%9&ET('EO=7(@8FQA8VML:7-T(B!T;R!P<F]C965D('1O
M('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L(&%N9"!E9&ET
M('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U($%,5T%94R!R969U
M<V4@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB9FEL=&5R+65D:70M=VAI=&5L:7-T(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y&:6QT97)S.B!%9&ET(%=H:71E;&ES=#PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY%9&ET(%EO=7(@5VAI=&5L:7-T/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!#;&EC:R!O;B`B161I="!Y;W5R('=H:71E;&ES="(@=&\@<')O8V5E
M9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E+"!A;F0@
M961I="!T:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S('EO=2!!3%=!65,@
M86-C97!T(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F9I;'1E<BUO;BUL;V=I;B(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^1FEL=&5R<SH@1FEL=&5R(&]N($QO9VEN/"]T:71L93X*("`@(#QH96%D
M:6YG/D%P<&QY($9I;'1E<B!2=6QE<R!5<&]N($QO9V]N/SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@=&\@86QW87ES(&%P
M<&QY(&9I;'1E<G,@=VAE;B!F:7)S="!L;V=G:6YG(&]N=&\@24U0+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+61I<W!L
M87DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!O
M;B!2969R97-H/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY(&9I;'1E<B!R
M=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T;R!A;'=A>7,@87!P
M;'D@9FEL=&5R<R!W:&5N979E<B!Y;W5R('9I97<@=&AE($E.0D]8/PH@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6%N>2UM86EL
M8F]X(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!&:6QT97(@
M86YY($UA:6QB;W@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@9FEL=&5R
M(')U;&5S('1O(&%N>2!M86EL8F]X/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@0VAE8VL@=&AI<R!O<'1I;VX@:68@>6]U('=A;G0@=&\@8F4@86QL;W=E
M9"!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA:6QB;W@N($YO<FUA
M;&QY+"!F:6QT97)I;F<@<G5L97,@87)E(&]N;'D@87!P;&EE9"!T;R!N97<@
M;6%I;"!T:&%T(&ES(&1E;&EV97)E9"!T;R!Y;W5R($E.0D]8+B`@268@=&AI
M<R!O<'1I;VX@:7,@8VAE8VME9"P@86X@:6-O;B!W:6QL(&%P<&5A<B!O;B!A
M;&P@;6%I;&)O>"!P86=G97,@=&AA="!W:6QL(&%L;&]W('EO=2!T;R!A<'!L
M>2!F:6QT97(@<G5L97,@=&\@=&AE(&UE<W-A9V5S(&EN('1H92!C=7)R96YT
M(&UA:6QB;W@N("!.3U1%.B!&:6QT97)I;F<@:6X@;6%I;&)O>&5S(&]T:&5R
M('1H86X@24Y"3U@@;6%Y('!R;V1U8V4@<W1R86YG92`H92YG+B!T:&4@9FEL
M=&5R(&UA>2!C875S92!A(&-O<'D@;V8@;65S<V%G97,@=&\@8F4@9&5L:79E
M<F5D('1O('1H92!S86UE(&UA:6QB;W@I(&%N9"]O<B!U;F1E<VER960@<F5S
M=6QT<R`H92YG+B!I="!M87D@8V%U<V4@;65S<V%G97,@=&\@8F4@;6]V960O
M9&5L971E9"!I9B!N97<@9FEL=&5R:6YG(')U;&5S(&AA=F4@8F5E;B!I;7!L
M96UE;G1E9"!S:6YC92!T:&4@;65S<V%G92!H87,@8F5E;B!D96QI=F5R960@
M=&\@=&AE(&-U<G)E;G0@;6%I;&)O>"DN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M<'5B:V5Y(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($%T=&%C:"!0=6)L:6,@2V5Y/"]T
M:71L93X*("`@(#QH96%D:6YG/D%T=&%C:"!0=6)L:6,@2V5Y/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N(&$@8V]P>2!O9B!Y
M;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L('=I;&P@8F4@871T
M86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N("!9;W4@8V%N('-E="!T
M:&4@9&5F875L="!B96AA=FEO<B!V:6$@=&AE(%!'4"!/<'1I;VYS('-C<F5E
M;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I
M;VXM<V-A;BUB;V1Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z(%-C
M86X@5&5X="!";V1I97,\+W1I=&QE/@H@("`@/&AE861I;F<^4V-A;B!497AT
M($)O9&EE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@<V5L96-T960@
M=&AE;B!)35`@=VEL;"!S8V%N('1H92!B;V1Y(&]F(&%L;"!T97AT(&UE<W-A
M9V5S(&9O<B!01U`@9&%T82P@86YD(&1I<W!L87D@=&AE(')E<W5L=',@:68@
M86YY(&1A=&$@:7,@9F]U;F0N("!.;W1E('1H870@=&AI<R!M87D@<VQO=R!D
M;W=N('1H92!S>7-T96T@87,@979E<GD@=&5X="!M97-S86=E(&UU<W0@8F4@
M<V-A;FYE9"!I;B!I=',@96YT:7)E='D@9F]R(%!'4"!D871A+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO<'1I;VYS+65N
M8W)Y<'0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D-O;7!O<V4Z($5N8W)Y
M<'1I;VX@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY.;R!%;F-R>7!T
M:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD('1H92!M97-S86=E
M('=I=&@@;F\@96YC<GEP=&EO;B`H8VQE87)T97AT*2X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/E!'4"!%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@96YC<GEP="!T:&4@8W5R
M<F5N="!M97-S86=E+"!U<VEN9R!01U`@86YD('1H92!R96-I<&EE;G1S('!E
M<G-O;F%L('!U8FQI8R!K97DL(&%N9"!T:&5N('-E;F0@:70N(%EO=2!C86X@
M;VYL>2!S96YD(&$@;65S<V%G92!T;R!A('-I;F=L92!P97)S;VX@=7-I;F<@
M=&AI<R!O<'1I;VXN(%EO=2!-55-4(&AA=F4@=&AE('!U8FQI8R!K97D@;V8@
M=&AE(')E8VEP:65N="!S=&]R960@:6X@>6]U<B!A9&1R97-S8F]O:R!O<B!E
M;'-E('1H:7,@;W!T:6]N('=I;&P@9F%I;"X@268@>6]U(&AA=F4@=&AE('!U
M8FQI8R!K97D@9F]R('1H92!R96-I<&EE;G0@:6X@>6]U<B!A9&1R97-S8F]O
M:R!A;F0@87)E('-T:6QL(')E8V5I=FEN9R!E<G)O<G,L('9E<FEF>2!T:&%T
M('1H92!E+6UA:6P@861D<F5S<R!I;B!T:&4@<F5C:7!I96YT(&9I96QD(&UA
M=&-H97,@=&AE(&4M;6%I;"!A9&1R97-S('=H97)E('1H92!P=6)L:6,@:V5Y
M(&ES('-T;W)E9"X@5&AE(&5N8W)Y<'1E9"!D871A('=I;&P@8F4@871T86-H
M960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY01U`@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!4:&ES(&]P=&EO;B!W:6QL(&1I9VET86QL>2!S:6=N('1H92!C=7)R
M96YT(&UE<W-A9V4@=7-I;F<@4$=0(&%N9"!Y;W5R('!E<G-O;F%L('!R:79A
M=&4@:V5Y+B!)9B!Y;W4@:&%V92!N;W0@86QR96%D>2!E;G1E<F5D('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R('!R:79A=&4@:V5Y(&1U<FEN9R!T:&ES('-E
M<W-I;VX@>6]U('=I;&P@8F4@<')O;7!T960@9F]R(&ET+B`@5&AE(')E8V5I
M<&EE;G0@;75S="!H879E(&$@8V]P>2!O9B!Y;W5R('!U8FQI8R!K97D@=&\@
M9&EG:71A;&QY('9E<FEF>2!Y;W5R"B`@("!S:6=N871U<F4N"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@9FER<W0@
M9&EG:71A;&QY('-I9VX@>6]U<B!M97-S86=E(&%N9"!T:&5N('=I;&P@96YC
M<GEP="!T:&4@<F5S=6QT:6YG(&]U='!U="X@4V5E('1H92`G4$=0($5N8W)Y
M<'0@365S<V%G92<@86YD("=01U`@4VEG;B!-97-S86=E)R!E;G1R:65S(&9O
M<B!F=7)T:&5R(&EN9F]R;6%T:6]N+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^4R]-24U%($5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^4R]-24U%(%-I
M9VX@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5$]$3PH@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^4R]-24U%(%-I9VXO16YC<GEP="!-97-S
M86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!'4#H@3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE
M861I;F<^5VAA="!I<R!01U`_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!0
M1U`@:7,@82!T;V]L(&9O<B!S96-U<F4@8V]M;75N:6-A=&EO;B!A;F0@9&%T
M82!S=&]R86=E+"!E<W!E8VEA;&QY(&9O<B!U<V4@=VET:"!E+6UA:6PN($ET
M(&-A;B!B92!U<V5D('1O(&5N8W)Y<'0@9&%T82!A;F0@=&\@8W)E871E(&1I
M9VET86P@<VEG;F%T=7)E<RX@24U0('5S97,@1VYU4$<@*$=.52!0<FEV86-Y
M($=U87)D*2!T;R!P<F]V:61E('1H:7,@9G5N8W1I;VYA;&ET>2X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@;W!T:6]N(&ES('-E
M;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&-R96%T92]V:65W('EO=7(@
M<&5R<V]N86P@4$=0(&ME>7,L(&%D9"]D96QE=&4@<'5B;&EC(&ME>7,@9G)O
M;2!O=&AE<B!I;F1I=FED=6%L<RP@<F5A9"!E;F-R>7!T960@;6%I;"P@=F5R
M:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N8W)Y<'0O<VEG;B!Y
M;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C:"UP=6)K97DB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!'4#H@3W!T:6]N<R`M($%T=&%C:"!0=6)L:6,@2V5Y
M/"]T:71L93X*("`@(#QH96%D:6YG/D]P=&EO;G,@+2!!='1A8V@@4'5B;&EC
M($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@<V5L96-T960@=&AE
M;B!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@:68@:70@97AI<W1S
M+"!W:6QL(&)Y(&1E9F%U;'0@8F4@871T86-H960@=&\@86QL(&]U=&=O:6YG
M(&UE<W-A9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<&=P+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'
M4#H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*("`@(#QH96%D:6YG/D]V
M97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES('-C<F5E;B!L
M:7-T<R!A;&P@;V8@=&AE(&-U<G)E;G0@=7-E<G,@:6X@>6]U<B!A9&1R97-S
M8F]O:R!T:&%T(&AA=F4@4$=0('!U8FQI8R!K97ES+B!4:&5S92!U<V5R<R!A
M<F4@=&AE($].3%D@=7-E<G,@=&AA="!Y;W4@8V%N(&5I=&AE<B`Q*2!S96YD
M(&%N(&5N8W)Y<'1E9"!M97-S86=E('1O("U/4BT@,BD@=F5R:69Y(&$@9&EG
M:71A;"!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T;R!V
M:65W('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1I<W!L87ES
M('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($1E;&5T97,@=&AE('!U8FQI8R!K97D@9G)O;2!Y;W5R(&%D9')E
M<W-B;V]K+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P
M+6EM<&]R="UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@
M36%N86=E(%!U8FQI8R!+97ES("T@26UP;W)T/"]T:71L93X*("`@(#QH96%D
M:6YG/DEM<&]R="!0=6)L:6,@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@5&AI<R!B=71T;VX@=VEL;"!O<&5N(&$@=VEN9&]W('=H97)E('EO=2!C
M86X@;6%N=6%L;'D@:6UP;W)T(&$@4$=0('!U8FQI8R!K97DN("!4:&4@:V5Y
M(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT9FEE;&0@;W(L(&EF
M('1H92!K97D@<F5S:61E<R!I;B!A(&9I;&4@;VX@>6]U<B!L;V-A;"!C;VUP
M=71E<BP@>6]U(&-A;B!I;7!O<G0@:70N("!)9B!T:&4@:V5Y(&ES('9A;&ED
M(&ET('=I;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R(&%D9')E<W-B;V]K(&%N
M9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R
M;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]V97)V:65W
M+7!E<G-O;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA
M;F%G92!097)S;VYA;"!+97ES/"]T:71L93X*("`@(#QH96%D:6YG/D]V97)V
M:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V%N="!T;R!D
M:6=I=&%L;'D@<VEG;B!M97-S86=E<R!O<B!E;F%B;&4@;W1H97)S('1O('-E
M;F0@>6]U(&5N8W)Y<'1E9"!M97-S86=E<RP@>6]U(&UU<W0@:&%V92!Y;W5R
M(&]W;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!01U`@:V5Y<&%I<BX*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4'5B;&EC($ME>3PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@66]U<B!P=6)L:6,@:V5Y('-H;W5L9"!B92!M
M861E(&%V86EL86)L92!T;R!A;GD@<&5R<V]N('1H870@>6]U('=A;G0@=&\@
M8F4@86)L92!T;R!S96YD('EO=2!E;F-R>7!T960@;65S<V%G97,@=&AA="!O
M;FQY(%E/52!C86X@9&5C<GEP="`H=7-I;F<@>6]U<B!P<FEV871E(&ME>2DN
M($%D9&ET:6]N86QL>2P@>6]U<B!P=6)L:6,@:V5Y(&YE961S('1O(&)E(&UA
M9&4@879A:6QA8FQE('1O(&%N>6)O9'D@>6]U('-E;F0@82!D9&EG:71A;&QY
M('-I9VYE9"!M97-S86=E('1O("T@=&AE('!U8FQI8R!K97D@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y('1H92!D:6=I=&%L('-I9VYA='5R92X*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/EEO=7(@4')I=F%T92!+97D\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%EO=7(@<')I=F%T92!K97D@:7,@;F5C97-S87)Y('1O
M(&1E8W)Y<'0@86YY(&UE<W-A9V4@96YC<GEP=&5D('5S:6YG('EO=7(@<'5B
M;&EC(&ME>2X@061D:71I;VYA;&QY+"!Y;W5R('!R:79A=&4@:V5Y(&ES(&YE
M961E9"!I9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!A(&UE<W-A9V4N
M(%EO=7(@<')I=F%T92!K97D@=VEL;"!B92!P<F]T96-T960@=FEA(&$@<&%S
M<W!H<F%S92!C<F5A=&5D('=H96X@=&AE(&ME>7,@87)E(&=E;F5R871E9"X@
M5&AU<RP@=&\@<&5R9F]R;2!A;GD@86-T:79I='D@=&AA="!R97%U:7)E<R!Y
M;W5R('!R:79A=&4@:V5Y+"!)35`@=VEL;"!P<F]M<'0@>6]U(&9O<B!Y;W5R
M('!A<W-P:')A<V4N(%EO=2!O;FQY(&YE960@=&\@:6YS97)T('EO=7(@<&%S
M<W!H<F%S92!O;F-E('!E<B!S97-S:6]N("T@24U0('=I;&P@<W1O<F4@>6]U
M<B!P87-S<&AR87-E('5N=&EL('EO=2!L;V=O=70@*%-O(&)E('-U<F4@=&\@
M;&]G;W5T(2DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M<&5R<V]N86QK97DM<'5B;&EC(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@4'5B;&EC($ME>3PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!/<&5N<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@<'5B;&EC(&ME>2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@
M4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M(%!R:79A=&4@
M2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D5N=&5R(%!A<W-P:')A<V4\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($]P96YS('1H92!P87-S<&AR87-E(&1I
M86QO9R!W:6YD;W<N(%1H92!P87-S<&AR87-E(&5N=&5R960L(&EF(&-O<G)E
M8W0L('=I;&P@8F4@<W1O<F5D(&)Y($E-4"!U;G1I;"!Y;W5R('-E<W-I;VX@
M96YD<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5N;&]A9"!087-S<&AR
M87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!296UO=F5S('1H92!S=&]R
M960@<&%S<W!H<F%S92!F<F]M($E-4"`M(&%N>2!A9&1I=&EO;F%L('5S86=E
M(&]F('1H92!P<FEV871E(&ME>2!W:6QL(')E<75I<F4@>6]U('1O(')E96YT
M97(@=&AE('!A<W-P:&5A<V4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6
M:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T
M;R!V:65W('1H92!01U`@<')I=F%T92!K97DN($1/($Y/5"!314Y$(%1(25,@
M2T59(%1/($%.64].12`M('1H:7,@;W!T:6]N(&ES('-T<FEC=&QY('-O('1H
M870@>6]U(&-A;B!E>'!O<G0@>6]U<B!)35`@<&5R<V]N86P@<')I=F%T92!K
M97D@9F]R('5S92!I;B!A;F]T:&5R('!R;V=R86TN"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$
M:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P<FEV871E(&ME
M>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S
M;VYA;&ME>2UD96QE=&4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@
M36%N86=E(%!E<G-O;F%L($ME>7,@+2!$96QE=&4\+W1I=&QE/@H@("`@/&AE
M861I;F<^1&5L971E(%!E<G-O;F%L($ME>7,\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%1H:7,@8G5T=&]N('=I;&P@9&5L971E('EO=7(@<&5R<V]N86P@
M<'5B;&EC+W!R:79A=&4@:V5Y<&%I<B!F<F]M($E-4"=S('!R969E<F5N8V5S
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O
M;F%L:V5Y+6-R96%T92UN86UE(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M1U`Z($-R96%T92!097)S;VYA;"!+97D@+2!.86UE/"]T:71L93X*("`@(#QH
M96%D:6YG/DYA;64\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!N86UE
M('EO=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@:V5Y<RX@02!R
M97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N="(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@0V]M
M;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY#;VUM96YT/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!!(&-O;6UE;G0@<W1R:6YG('EO=2!W86YT(&5M8F5D
M9&5D(&EN('EO=7(@<&5R<V]N86P@:V5Y<RX@06X@;W!T:6]N86P@9FEE;&0N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N
M86QK97DM8W)E871E+65M86EL(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M1U`Z($-R96%T92!097)S;VYA;"!+97D@+2!%+6UA:6P@061D<F5S<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY%+6UA:6P@061D<F5S<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AE(&4M;6%I;"!A9&1R97-S('EO=2!W86YT(&%S<V]C
M:6%T960@=VET:"!Y;W5R('!E<G-O;F%L(&ME>7,N($$@<F5Q=6ER960@9FEE
M;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R
M<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@2V5Y;&5N9W1H/"]T
M:71L93X*("`@(#QH96%D:6YG/DME>6QE;F=T:#PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&AE(&ME>6QE;F=T:"P@:6X@8GET97,L(&]F('EO=7(@9V5N
M97)A=&5D(&ME>2X@5&AE(&=R96%T97(@=&AE('9A;'5E+"!T:&4@9W)E871E
M<B!T:&4@<')O=&5C=&EO;B`H86YD(&%L<V\@9W)E871E<B!G96YE<F%T:6]N
M('1I;64@86YD(&5N8W)Y<'1I;VX@=&EM92DN(#$P,C0@8GET97,@:7,@=&AE
M(&1E9F%U;'0@+2!T:&ES('9A;'5E('!R;W9I9&5S(&5X8V5L;&5N="!P<F]T
M96-T:6]N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P
M+7!E<G-O;F%L:V5Y+6-R96%T92UP87-S<&AR87-E(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!087-S<&AR
M87-E/"]T:71L93X*("`@(#QH96%D:6YG/DYA;64\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H92!P87-S<&AR87-E('5S960@=&\@<')O=&5C="]E;F-R
M>7!T('EO=7(@<&5R<V]N86P@<')I=F%T92!K97DN(%1H:7,@<VAO=6QD(&)E
M($%4($Q%05-4(#8@8VAA<F%C=&5R<RP@<VAO=6QD($Y/5"!B92!T:&4@<V%M
M92!A<R!Y;W5R(&QO9VEN('!A<W-W;W)D+"!S:&]U;&0@3D]4(&)E(&)A<V5D
M(&]N(&$@9&EC=&EO;F%R>2!W;W)D+"!A;F0@<VAO=6QD(&EN8VQU9&4@8F]T
M:"!N=6UB97)S(&%N9"!L971T97)S+B!9;W4@;75S="!E;G1E<B!T:&ES('!A
M<W-P:')A<V4@='=I8V4@9F]R('9E<FEF:6-A=&EO;B!P=7)P;W-E<RX@02!R
M97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M86-T:6]N<R(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@06-T
M:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY#<F5A=&4@2V5Y<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@0W)E871E(&%N9"!S=&]R92!Y;W5R('!E<G-O
M;F%L+W!R:79A=&4@:V5Y<&%I<BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/DEM<&]R="!+97EP86ER/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!);7!O
M<G0@82!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N(%1H:7,@8G5T=&]N(&]P
M96YS(&$@=VEN9&]W('=H97)E('EO=2!C86X@;6%N=6%L;'D@:6UP;W)T('EO
M=7(@97AI<W1I;F<@4$=0('!E<G-O;F%L('!U8FQI8R]P<FEV871E(&ME>7!A
M:7(N("!4:&4@:V5Y<R!C86X@96ET:&5R(&)E('!A<W1E9"!I;G1O(&$@=&5X
M=&9I96QD(&]R+"!I9B!T:&4@:V5Y<R!R97-I9&4@:6X@82!F:6QE(&]N('EO
M=7(@;&]C86P@8V]M<'5T97(L('EO=2!C86X@:6UP;W)T('1H96TN("!)9B!T
M:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E(&EN<V5R=&5D(&EN=&\@
M>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L;W-E.R!I
M9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R971U<FYE
M9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G-M:6UE+6]V97)V:65W(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y3+TU)344Z($]V97)V:65W/"]T:71L93X*("`@(#QH96%D:6YG/E=H870@
M:7,@4R]-24U%/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4R]-24U%(&ES
M(&$@<')I=F%T92]P=6)L:6,@:V5Y('!A:7(@<WES=&5M('=H:6-H('!R;W9I
M9&5S(&1I9VET86P@<VEG;F%T=7)E<RP@;65S<V%G92!P<FEV86-Y+"!A;F0@
M=&%M<&5R(&1E=&5C=&EO;B!I;B!A(&]P96XL(&EN=&5R;W!E<F%B;&4@=V%Y
M+B`@4R]-24U%(&-A;B!P<F]V:61E(&UE<W-A9V4@<')I=F%C>2!B>2!E;F-R
M>7!T:6YG(&UE<W-A9V5S('1H870@;VYL>2!T:&4@<V5N9&5R(&%N9"!T:&4@
M:6YT96YD960@<F5C:7!I96YT<R!C86X@9&5C;V1E+B`@270@86QL;W=S('EO
M=2!T;R!I9&5N=&EF>2!T:&4@<V5N9&5R(&]F(&$@;65S<V%G92!V:6$@82!D
M:6=I=&%L('-I9VYA='5R92X@(%1O9V5T:&5R+"!T:&ES(&5N8W)Y<'1I;VX@
M86YD(&1I9VET86P@<VEG;FEN9R!H96QP('!R;W9I9&4@=&%M<&5R(&1E=&5C
M=&EO;BP@86QL;W=I;F<@<F5C:7!I96YT<R!T;R!D971E<FUI;F4@=VAE=&AE
M<B!A(&UE<W-A9V4@=V%S(&%L=&5R960@869T97(@:70@=V%S('-E;G0N"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;F%B;&4@4R]-24U%(&9U;F-T:6]N
M86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!T:&ES(&]P=&EO
M;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@86)L92!T;R!I;7!O<G0@>6]U
M<B!P97)S;VYA;"!3+TU)344@:V5Y<RP@<F5A9"!E;F-R>7!T960@;6%I;"P@
M=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N8W)Y<'0O<VEG
M;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=RUP97)S;VYA;&ME>2(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!097)S;VYA;"!+97ES/"]T:71L
M93X*("`@(#QH96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!)9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!O<B!E;F-R>7!T
M(&UE<W-A9V5S('EO=2!M=7-T(&AA=F4@>6]U<B!O=VX@<&5R<V]N86P@<'5B
M;&EC+W!R:79A=&4@4R]-24U%(&ME>7!A:7(N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UI;7!O<G0M<&5R<V]N86PM8V5R=',B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@26UP;W)T(%!E<G-O
M;F%L($-E<G1I9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY);7!O<G0@
M4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!);7!O<G0@<&5R<V]N86P@8V5R=&EF:6-A=&5S(&9R;VT@82!02T-3(",Q
M,B!F;W)M870@9FEL92X@4$M#4R`C,3(@9FEL97,@:7,@=&AE(&9I;&4@=7-U
M86QL>2!G96YE<F%T960@=VAE;B!E>'!O<G1I;F<@82!K97D@9G)O;2!A(&)R
M;W=S97(@*&4N9RX@26YT97)N970@17AP;&]R97(L($9I<F5F;W@I(&]R(&9R
M;VT@82!C97)T:69I8V%T92!S=&]R92!M86EN=&%I;F5D(&)Y(&%N($]P97)A
M=&EN9R!3>7-T96T@*&4N9RX@5VEN9&]W<R!84"DN($EF('1H92!K97ES(&%R
M92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R('!R969E
M<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V86QI
M9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI
M;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI
M;64M9&5L971E+7!E<G-O;F%L+6-E<G1S(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y3+TU)344Z($1E;&5T92!097)S;VYA;"!#97)T:69I8V%T97,\+W1I
M=&QE/@H@("`@/&AE861I;F<^1&5L971E(%!E<G-O;F%L($-E<G1I9FEC871E
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E('EO=7(@<&5R<V]N
M86P@8V5R=&EF:6-A=&5S(&9R;VT@>6]U<B!P<F5F97)E;F-E<RX@(%EO=2!W
M:6QL(&YO(&QO;F=E<B!B92!A8FQE('1O('-I9VX@4R]-24U%(&UE<W-A9V5S
M(&]R('9I97<@86YY(%,O34E-12!E;F-R>7!T960@;65S<V%G97,@861D<F5S
M<V5D('1O('EO=2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G-M:6UE+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*("`@(#QH96%D
M:6YG/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!-86YA9V4@>6]U<B!3+TU)344@<'5B;&EC(&ME>2!L:7-T
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5FEE=R!T:&4@<F%W('1E>'0@;V8@=&AE('!U8FQI8R!K
M97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!6:65W('1E8VAN:6-A;"!D971A:6QS(&]F('1H
M92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5L971E
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&5S('1H92!S96QE8W1E
M9"!P=6)L:6,@:V5Y(&9R;VT@<W1O<F%G92X@($1E;&5T:6YG(&$@<'5B;&EC
M(&ME>2!F;W(@82!U<V5R('=I;&P@<')E=F5N="!Y;W5R(&9R;VT@96YC<GEP
M=&EN9R!A(&UE<W-A9V4@=&\@=&AA="!U<V5R+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')I;G1I;F<B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R:6YT:6YG/"]T:71L93X*("`@(#QH96%D:6YG/E!R:6YT(&$@
M;65S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&\@<')I;G0@82!M
M97-S86=E('EO=2!A<F4@=FEE=VEN9RP@8VQI8VL@;VX@=&AE(")0<FEN="(@
M;&EN:R!A="!E:71H97(@=&AE('1O<"!O<B!B;W1T;VT@;V8@=&AE(&UE<W-A
M9V4N(%1H92!M97-S86=E('=I;&P@;W!E;B!I;B!A(&YE=R!W:6YD;W<@9F]R
M;6%T960@9F]R('!R:6YT:6YG+B`@1&5P96YD:6YG(&]N('EO=7(@=V5B(&)R
M;W=S97(@86YD(&]P97)A=&EN9R!S>7-T96TL('1H92!P<FEN="!D:6%L;V<@
M8F]X(&UA>2!O<&5N(&9O<B!Y;W4N("!)9B!I="!D;V5S(&YO="!O<&5N+"!T
M:&5N('!U;&P@9&]W;B!T:&4@=V5B(&)R;W=S97(G<R`B1FEL92(@;65N=2!A
M;F0@8VAO;W-E(")0<FEN="(@=&\@;W!E;B!T:&4@<')I;G0@9&EA;&]G(&)O
M>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-O<G1I;F<B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E-O<G1I;F<@86YD(%1H<F5A9&EN
M9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3;W)T:6YG($5N=')I97,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%=H96X@=FEE=VEN9R!A(&QI<W0@;V8@;65S
M<V%G97,L('EO=2!C86X@<V]R="!T:&4@;65S<V%G97,@8GD@86YY(&-O;'5M
M;B!B>2!C;&EC:VEN9R!O;B!T:&4@87!P<F]P<FEA=&4@8V]L=6UN(&AE861I
M;F<N("!4;R!S=VET8V@@8V]L=6UN<R!B971W965N(&%S8V5N9&EN9R!A;F0@
M9&5S8V5N9&EN9R!O<F1E<BP@8VQI8VL@;VX@=&AE(&%R<F]W(&EC;VX@:6X@
M=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M5&AR96%D:6YG/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4;R!G<F]U<"!M
M97-S86=E<R!B>2!T:')E861S("AS=6)J96-T*2P@<V\@96%C:"!M97-S86=E
M(&ES(&=R;W5P960@=VET:"!A;&P@:71S(')E<&QI97,L(&-L:6-K('1H92!;
M5&AR96%D72!L:6YK(&EN('1H92!S=6)J96-T(&-O;'5M;B!H96%D:6YG+B`@
M5&\@<F5T=7)N('1O(&YO<FUA;"!S=6)J96-T('-O<G1I;F<L(&-L:6-K(&]N
M('1H92!;4W5B:F5C=%T@;&EN:R!I;B!T:&4@<W5B:F5C="!C;VQU;6X@:&5A
M9&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F%L=&5R
M;F%T:79E+6US9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^375L=&EP87)T
M+T%L=&5R;F%T:79E($UE<W-A9V5S/"]T:71L93X*("`@(#QP87)A/@H@("`@
M4V]M92!M97-S86=E(&AA=F4@8F5E;B!S96YT(&%S(&$@(FUU;'1I<&%R="]A
M;'1E<FYA=&EV92(@='EP92!B>2!T:&4@<V5N9&5R+B!4:&5S92!M97-S86=E
M<R!H879E('-E=F5R86P@<&%R=',L(&%L;"!D:7-P;&%Y:6YG('1H92!304U%
M($-/3E1%3E0@8G5T(&EN($1)1D9%4D5.5"!&3U)-0513+B!4:&4@;6%I;"!A
M9V5N="!W:6QL(&1I<W!L87D@=&AE(&QA<W0@<&%R="!I;B!T:&4@;&ES="!T
M:&%T(&-A;B!B92!S=6-C97-S9G5L;'D@9&ES<&QA>65D(&EN;&EN92!I;B!T
M:&4@8G)O=W-E<BP@:68@86YY+B!!;&P@;W1H97(@9F]R;6%T<R!W:6QL(&%P
M<&5A<B!U;F1E<B!T:&4@:&5A9&EN9R`B06QT97)N871I=F4@<&%R=',@9F]R
M('1H:7,@<V5C=&EO;B(@86YD(&-A;B!B92!V:65W960@;W(@9&]W;FQO861E
M9"!S97!A<F%T96QY+B!)="!I<R!I;7!O<G1A;G0@=&\@;F]T92!T:&%T('1H
M97-E(&%L=&5R;F%T:79E('!A<G1S(&-O;G1A:6X@=&AE(%-!344@0T].5$5.
M5%,@87,@=&AE('!A<G0@=&AA="!I<R!S:&]W;B`M('1H97D@87)E('-I;7!L
M>2!I;B!A(&1I9F9E<F5N="!M961I82!F;W)M870@*&4N9RX@=&5X="!V<RX@
M2%1-3"!O=71P=70I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@4F5N86UE
M(%-E;G0M;6%I;"!&;VQD97(@36]N=&AL>3PO=&ET;&4^"B`@("`\<&%R83X*
M("`@(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U('=O=6QD(&QI:V4@=&\@
M<F5N86UE('EO=7(@<V5N="UM86EL(&9O;&1E<B!A="!T:&4@8F5G:6YN:6YG
M(&]F(&5V97)Y(&UO;G1H+B`@5&AE(&9O;&1E<B!W:6QL(&)E(')E;F%M960@
M*'1O(&$@;F%M92!T:&%T(&-O;G1A:6YS('1H92!M;VYT:"!A;F0@>65A<BD@
M86YD(&$@;F5W('-E;G0M;6%I;"!F;VQD97(@=VEL;"!B92!C<F5A=&5D+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E
M7W-E;G1M86EL7VUO;G1H;'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E(%-E;G0M;6%I;"!&;VQD
M97(@36]N=&AL>3PO=&ET;&4^"B`@("`\<&%R83X*("`@(%1U<FX@=&AI<R!O
M<'1I;VX@;VX@:68@>6]U('=O=6QD(&QI:V4@=&\@9&5L971E(&]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!A="!T:&4@8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H
M+B`@5&AI<R!M87D@8F4@=7-E9G5L(&EF('EO=2!H879E(&$@<75O=&$L(&9O
M<B!E>&%M<&QE+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&5L971E7W-E;G1M86EL7VUO;G1H;'E?:V5E<"(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE
M=&4@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY("T@(R!O9B!&;VQD97)S('1O
M($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E(&1E;&5T
M:6YG(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!E=F5R>2!M;VYT:"P@:&]W(&UA
M;GD@;6]N=&AS(&]F(&]L9"!F;VQD97)S(&1O('EO=2`@=V%N="!T;R!K965P
M/R`@06YY(&9O;&1E<G,@;VQD97(@=&AA;B!T:&ES(&UA;GD@;6]N=&AS('=I
M;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!R969S+61E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E
M;&5T92!,:6YK960@071T86-H;65N=',@36]N=&AL>3PO=&ET;&4^"B`@("`\
M<&%R83X*("`@(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U('=O=6QD(&QI
M:V4@=&\@9&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@870@=&AE(&)E
M9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H:7,@;6%Y(&)E('5S969U;"!I
M9B!Y;W4@:&%V92!A('%U;W1A+"!F;W(@97AA;7!L92X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]A='1A8VAM96YT
M<U]M;VYT:&QY7VME97`B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E($QI;FME9"!!='1A8VAM96YT
M<R!-;VYT:&QY("T@(R!O9B!-;VYT:',@=&\@2V5E<#PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($EF('EO=2!A<F4@9&5L971I;F<@;VQD(&QI;FME9"!A='1A
M8VAM96YT<R!E=F5R>2!M;VYT:"P@:&]W(&UA;GD@;6]N=&AS(&]F(&]L9"!A
M='1A8VAM96YT<R!D;R!Y;W4@('=A;G0@=&\@:V5E<#\@($%N>2!A='1A8VAM
M96YT<R!O;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT:',@=VEL;"!B92!D96QE
M=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M<'5R9V5?=')A<V@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N
M8V5S.B!-86EN=&5N86YC93H@4'5R9V4@5')A<V@\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!$;R!Y;W4@=V%N="!T;R!P=7)G92!Y;W5R('1R87-H(&9O;&1E
M<B!E=F5R>2!S;R!O9G1E;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+7!U<F=E7W1R87-H7VEN=&5R=F%L(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U<F=E
M(%1R87-H($EN=&5R=F%L/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M(&%R92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R+"!H;W<@;V9T96X@<VAO
M=6QD(&ET(&)E('!U<F=E9#\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+7!U<F=E7W1R87-H7VME97`B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@4'5R9V4@5')A
M<V@@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@<'5R
M9VEN9R!Y;W5R('1R87-H(&9O;&1E<BP@;65S<V%G92!O;&1E<B!T:&%N(&AO
M=R!M86YY(&1A>7,@<VAO=6QD(&)E('!U<F=E9#\*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+6%T=')I8E]T97AT(B!S=&%T93TB
M;F5W(CX*("`@("`\=&ET;&4^4')E9F5R96YC97,Z($UE<W-A9V4@0V]M<&]S
M:71I;VXZ($%T=')I8G5T:6]N(%1E>'0\+W1I=&QE/@H@("`@(#QP87)A/@H@
M("`@($AE<F4@>6]U(&-A;B!E;G1E<B!T:&4@<&AR87-E('1H870@>6]U('=I
M<V@@=&\@87!P96%R(&)E9F]R92!A;GD@<75O=&5D('1E>'0@:6X@82!R97!L
M>2!T:&%T('EO=2!S96YD+@H@("`@(#PO<&%R83X*("`@("`\<&%R83X*("`@
M("!9;W4@8V%N(&EN8VQU9&4@;VYE(&]R(&UO<F4@<W!E8VEA;"!P;&%C96AO
M;&1E<G,@=&\@:6YS97)T(&EN9F]R;6%T:6]N(&%B;W5T('1H92!M97-S86=E
M('1O('=H:6-H('EO=2!A<F4@<F5P;'EI;F<N(%!L86-E:&]L9&5R<R!C;VYS
M:7-T(&]F(&$@)R4G(&9O;&QO=V5D(&)Y(&$@<VEN9VQE(&QE='1E<BX@5&AE
M(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@87)E(&%V86EL86)L93H*("`@("`\
M+W!A<F$^"@H@("`@(#QP87)A/B`E9B`Z(%1H92!S96YD97(G<R!N86UE(&%N
M9"!E;6%I;"!A9&1R97-S/"]P87)A/@H@("`@(#QP87)A/B`E82`Z(%1H92!S
M96YD97(G<R!E;6%I;"!A9&1R97-S/"]P87)A/@H@("`@(#QP87)A/B`E<"`Z
M(%1H92!S96YD97(G<R!N86UE/"]P87)A/@H@("`@(#QP87)A/B`E<B`Z(%1H
M92!F=6QL(%)&0R`R.#(R('-T>6QE(&1A=&4@86YD('1I;64@>F]N93PO<&%R
M83X*("`@("`\<&%R83X@)60@.B!4:&4@9&%T92!A<R!W=W<L(&1D(&UM;2!9
M65E9/"]P87)A/@H@("`@(#QP87)A/B`E>"`Z(%1H92!D871E(&EN('1H92!L
M;V-A;&4G<R!D969A=6QT/"]P87)A/@H@("`@(#QP87)A/B`E8R`Z(%1H92!D
M871E(&%N9"!T:6UE(&EN('1H92!L;V-A;&4G<R!D969A=6QT/"]P87)A/@H@
M("`@(#QP87)A/B`E;2`Z(%1H92!-97-S86=E+4E$/"]P87)A/@H@("`@(#QP
M87)A/B`E<R`Z(%1H92!S=6)J96-T/"]P87)A/@H@("`@(#QP87)A/B`E;B`Z
M($$@;F5W(&QI;F4\+W!A<F$^"B`@("`@/'!A<F$^("4E(#H@5&AE("<E)R!C
M:&%R86-T97(\+W!A<F$^"@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M9&ES<&]S:71I;VY?<F5Q=65S=%]R96%D(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@4F5Q=65S="!296%D(%)E8V5I<'1S/"]T:71L
M93X*("`@(#QP87)A/@H@("`@(E)E<75E<W0@82!296%D(%)E8V5I<'0B('-E
M;F1S(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT<R!O9B!T:&ES(&UE<W-A
M9V4@=&\@;F]T:69Y('EO=2!W:&5N('1H:7,@;65S<V%G92!I<R!O<&5N960@
M8GD@=&AE(')E8VEP:65N=',N($YO="!A;&P@8VQI96YT<R!S=7!P;W)T("\@
M:&]N;W(@=&AI<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61I<W!O<VET:6]N7W-E;F1?;61N(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y0<F5F97)E;F-E<SH@4V5N9"!-1$X\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("`B4V5N9"!A($U$3B(@<V5N9',@82!-97-S86=E($1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B`H86QS;R!K;F]W;B!A<R!A(')E860@<F5C96EP
M="D@=VAE;B!Y;W4@=FEE=R!A(&UE<W-A9V4@:6X@=VAI8V@@=&AE('5S97(@
M:&%S(')E<75E<W1E9"!T:&%T('1H97D@<F5C96EV92!N;W1I9FEC871I;VX@
M=&AA="!Y;W4@:&%V92!R96%D('1H92!M97-S86=E+B!);B!M;W-T(&-A<V5S
M+"!T:&ES('=I;&P@:&%P<&5N(&%U=&]M871I8V%L;'D@=VET:&]U="!P<F]M
M<'1I;F<@>6]U+B!);B!C97)T86EN(&ES;VQA=&5D(&-A<V5S+"!Y;W4@;6%Y
M(&AA=F4@=&\@;6%N=6%L;'D@9&5C:61E('1O('-E;F0@=&AE(&YO=&EF:6-A
M=&EO;B!B>2!C;&EC:VEN9R!O;B!A(&QI;FLN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7V1E
M;&EV97)Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VX\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("`B4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VXB('-E;F1S
M(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT)W,@92UM86EL('-E<G9E<B!T
M;R!N;W1I9GD@>6]U('=H96X@:70@:&%S(&1E;&EV97)E9"!T:&4@;65S<V%G
M92!T;R!T:&4@<F5C:7!I96YT)W,@;6%I;&)O>"X@270@9&]E<VXG="!M96%N
M('1H92!M97-S86=E(&AA<R!B965N('-E96XL(&IU<W0@=&AA="!I="=S('-I
M='1I;F<@:6X@82!M86EL8F]X('-O;65W:&5R92X@3F]T(&%L;"!M86EL('-E
M<G9E<G,@<W5P<&]R="!T:&ES+B`*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+61E;&5T95]S<&%M7V%F=&5R7W)E<&]R="(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($1E;&5T92!3<&%M
M($%F=&5R(%)E<&]R=&EN9SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%EO=2!M
M87D@96QE8W0@=&\@9&\@;VYE(&]F('1H<F5E(&ET96US(&%F=&5R(')E<&]R
M=&EN9R!A(&UE<W-A9V4@87,@96ET:&5R('-P86T@;W(@:6YN;V-E;G0N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@($9I<G-T+"!Y;W4@8V%N(&1E8VED
M92!T;R!D;R!N;W1H:6YG("T@=&AE(&UE<W-A9V4@=VEL;"!B92!R97!O<G1E
M9"!A<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="!B=70@=VEL;"!O=&AE<G=I
M<V4@<F5M86EN('5N8VAA;F=E9"!I;B!Y;W5R(&UA:6QB;W@N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@(%-E8V]N9"P@:68@<F5P;W)T:6YG(&$@;65S
M<V%G92!A<R!S<&%M+"!Y;W4@8V%N(&EN<W1E860@:&%V92!T:&4@;65S<V%G
M92!B92!I;6UE9&EA=&5L>2!D96QE=&5D+B`@5&AI<R!S971T:6YG(&AA<R!N
M;R!E9F9E8W0@;VX@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I;FYO8V5N="X*
M("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@5&AI<F0L(&%F=&5R(')E<&]R
M=&EN9R!A(&UE<W-A9V4@87,@<W!A;2!T:&4@;65S<V%G92!W:6QL(&)E(&1E
M;&5T960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M;W9E9"!T;R!Y
M;W5R('-P86T@9F]L9&5R+B`@06QT97)N871I=F5L>2P@:68@<F5P;W)T:6YG
M(&$@;65S<V%G92!A<R!I;FYO8V5N="!T:&4@;65S<V%G92!W:6QL(&)E(&1E
M;&5T960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M;W9E9"!T;R!Y
M;W5R($E.0D]8+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M:'1M;%]I;6%G95]R97!L86-E;65N="(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P;&%C96UE;G0\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!&;W(@2%1-3"!M97-S86=E<R!D:7-P
M;&%Y960@:6YL:6YE+"!S:&]U;&0@86QL(&EM86=E('1A9W,@8F4@8FQO8VME
M9"!U;G1I;"!Y;W4@<W!E8VEF:6-A;&QY(&1E8VED92!T;R!V:65W('1H;W-E
M(&EM86=E<S\@3F]T92!T:&%T+"!I9B!V:65W:6YG(&%N($A434P@871T86-H
M;65N="P@=&AE(&EM86=E<R!W:6QL(&%L=V%Y<R!B92!D:7-P;&%Y960N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUH=&UL7VEM
M86=E7V%D9')B;V]K(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@2%1-3"!);6%G92!297!L86-E;65N="]!9&1R97-S8F]O:R!3:&]W
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@8FQO8VMI;F<@:6UA9V5S(&9O
M<B!I;FQI;F4@2%1-3"!M97-S86=E<RP@<VAO=6QD('=E(&%U=&]M871I8V%L
M;'D@9&ES<&QA>2!T:&5M(&EN<W1E860@:68@=&AE('-E;F1E<B!A<'!E87)S
M(&EN('EO=7(@861D<F5S<V)O;VL_"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUM86EL8F]X7W-T87)T(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;&)O>"!3=&%R="!086=E/"]T
M:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&EC:"!P86=E(&EN
M('1H92!M86EL8F]X('9I97<@=VEL;"!B92!D:7-P;&%Y960@=VAE;B!Y;W4@
M86-C97-S(&$@;6%I;&)O>"!F;W(@=&AE(&9I<G-T('1I;64N($YO=&4@=&AA
M="!T:&4@)W5N<V5E;B<@;65S<V%G92!O<'1I;VYS(&1O(&YO="!W;W)K('=I
M=&@@=&AE("=4:')E860G('-O<G1I;F<@;W!T:6]N("T@:6YS=&5A9"P@>6]U
M('=I;&P@8F4@<V5N="!T;R!T:&4@;&%S="!P86=E+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<V%V95]A='1A8VAM96YT<R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%-A=F4@071T
M86-H;65N=',@;VX@4V5N="!-97-S86=E<SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('-A=FEN9R!A(&-O;7!O<V5D(&UE<W-A9V4@:6X@82!S96YT+6UA
M:6P@9F]L9&5R+"!D971E<FUI;F4@:68@86QL(&%T=&%C:&UE;G0@9&%T82!I
M<R!S879E9"X@5&AE(&9O;&QO=VEN9R!O<'1I;VYS(&%R92!A=F%I;&%B;&4Z
M"B`@("`\+W!A<F$^"@H@("`@/'!A<F$^*B`B06QW87ES('-A=F4@871T86-H
M;65N=',B("T@3D5615(@<')O;7!T('1O('-A=F4@871T86-H;65N=',@:6X@
M8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT<R!A<F4@04Q705E3('-A
M=F5D('=I=&@@=&AE(&UE<W-A9V4N/"]P87)A/@H@("`@(#QP87)A/BH@(E!R
M;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L
M="!T;R!915,B("T@04Q705E3('!R;VUP="!T;R!S879E(&%T=&%C:&UE;G1S
M(&EN('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@:7,@=&\@<V%V
M92!A='1A8VAM96YT<RX\+W!A<F$^"B`@("`@/'!A<F$^*B`B4')O;7!T(&5V
M97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/
M(B`M($%,5T%94R!P<F]M<'0@=&\@<V%V92!A='1A8VAM96YT<R!I;B!T:&4@
M8V]M<&]S92!S8W)E96X[('1H92!D969A=6QT(&ES('1O(&YO="!S879E(&%T
M=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R83XJ(").979E<B!S879E(&%T
M=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP="!T;R!S879E(&%T=&%C:&UE;G1S
M(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@871T86-H;65N=',@87)E($Y%5D52
M('-A=F5D('=I=&@@=&AE(&UE<W-A9V4N/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB=FER='5A;%]I;F)O>"(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L($EN8F]X/"]T:71L93X*("`@
M(#QP87)A/@H@("`@5FER=71A;"!);F)O>"!I<R!A('-A=F5D('-E87)C:"!T
M:&%T(&1O97,@87=A>2!W:71H('1H92!N965D('1O('-E87)C:"!E=F5R>2!M
M86EL8F]X(&9O<B!M97-S86=E<R!M87)K960@87,@;F5W+B`@26YS=&5A9"P@
M86QL(&-U<G)E;G1L>2!S=6)S8W)I8F5D(&UA:6QB;WAE<R!A<F4@<V5A<F-H
M960@9F]R(&YE=R!M97-S86=E<R!A;F0@=&AE(')E<W5L=',@87)E(&1I<W!L
M87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T<F%S:"(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L(%1R87-H/"]T:71L
M93X*("`@(#QP87)A/@H@("`@5FER='5A;"!4<F%S:"!I<R!A('-A=F5D('-E
M87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D(&9O<B!A('-E<&%R
M871E(%1R87-H(&9O;&1E<BX@($EN<W1E860@;V8@;6]V:6YG(&UE<W-A9V5S
M('1O(&$@8V5N=')A;&EZ960@=')A<V@@9F]L9&5R+"!M97-S86=E<R!A<F4@
M<VEM<&QY(&UA<FME9"!A<R!D96QE=&5D(&EN('1H92!C=7)R96YT(&9O;&1E
M<B!T:&5Y(&QI=F4@:6XN("!7:&5N("=S:&]W(&1E;&5T960@;65S<V%G97,G
M(&ES('1U<FYE9"!O9F8L('1H:7,@<F5S=6QT<R!I;B!T:&5S92!M97-S86=E
M<R!N;W0@87!P96%R:6YG(&EN(&$@;6%I;&)O>"!V:65W+B`@5VAE;B!A('5S
M97(@8VQI8VMS(&]N(%9I<G1U86P@5')A<V@L("IA;&PJ(&UA:6QB;WAE<R!A
M;&P@<V5A<F-H960@9F]R(&UE<W-A9V5S('1H870@87)E(&9L86=G960@9&5L
M971E9"!A;F0@=&AE<V4@;65S<V%G97,@87)E(&1I<W!L87EE9"!I;B!A('-I
M;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]K;5]+2"\`````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<V,P`P,3<T-#(`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C
M86QE+VMM7TM(+TQ#7TU%4U-!1T53+P``````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S`#`R,3(R-P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]L;V-A;&4O:VU?2T@O3$-?34534T%'15,O:6UP+FUO
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V,38T,#<`,3`T,3<S-C(W-C,`,#(R
M,S8T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````2@8``!P```!L,@``:0@``+QD````````8(8```H```!AA@``
M"@```&R&```*````=X8```H```""A@``#@```(V&```/````G(8```@```"L
MA@``"P```+6&```,````P88```H```#.A@``)P```-F&```6`````8<``!@`
M```8AP``&P```#&'```!````38<```P```!/AP``"P```%R'```>````:(<`
M`$@```"'AP``*P```-"'``!$````_(<``"<```!!B```%P```&F(```2````
M@8@```4```"4B```!0```)J(```R````H(@```@```#3B```*0```-R(```R
M````!HD``!`````YB0``%@```$J)```0````88D``"8```!RB0``*0```)F)
M```F````PXD``!P```#JB0``)P````>*```B````+XH``"(```!2B@``&0``
M`'6*```D````CXH``#<```"TB@``!@```.R*```;````\XH``"X````/BP``
M-P```#Z+```&````=HL```P```!]BP``?````(J+``!L````!XP``!P```!T
MC```'0```)&,```,````KXP``!````"\C```#@```,V,```/````W(P```X`
M``#LC```#@```/N,```(````"HT```X````3C0``#@```"*-```)````,8T`
M`#,````[C0``40```&^-```#````P8T```@```#%C0``%@```,Z-```=````
MY8T```X````#C@``"````!*.```*````&XX``!,````FC@``#P```#J.```'
M````2HX```,```!2C@``&0```%:.```*````<(X``!<```![C@``$@```)..
M```(````IHX``!P```"OC@``8````,R.```H````+8\``!X```!6CP``&@``
M`'6/```L````D(\``"````"]CP``,@```-Z/```'````$9````P````9D```
M#0```":0``!4````-)```&,```")D```#@```.V0```+````_)````<````(
MD0``!P```!"1```%````&)$```4````>D0```P```"21``!.````*)$``%``
M``!WD0``0P```,B1``!"````#)(``#T```!/D@``%@```(V2```P````I)(`
M`!<```#5D@``(P```.V2```&````$9,``!<````8DP``#@```#"3``!1````
M/Y,``#4```"1DP``-0```,>3```'````_9,```8````%E```"`````R4```(
M````%90``!$````>E```"@```#"4```3````.Y0```L```!/E```#0```%N4
M```3````:90``",```!]E```+P```*&4```%````T90``!4```#7E```/P``
M`.V4```P````+94``$@```!>E0``(0```*>5```[````R94``#P````%E@``
M*P```$*6```P````;I8``#$```"?E@``.P```-&6```Y````#9<``#4```!'
MEP``"0```'V7```'````AY<```P```"/EP``!0```)R7```)````HI<```,`
M``"LEP``#````+"7```U````O9<```X```#SEP``20````*8```S````3)@`
M``H```"`F```%@```(N8```6````HI@``"T```"YF```"P```.>8```)````
M\Y@```D```#]F```"@````>9```&````$ID```D````9F0``!P```".9```L
M````*YD``!4```!8F0``4````&Z9```8````OYD``!$```#8F0``"@```.J9
M```+````]9D```H````!F@``(P````R:```6````,)H```H```!'F@``$```
M`%*:```;````8YH``"X```!_F@``$````*Z:```'````OYH```<```#'F@``
M"@```,^:```(````VIH```,```#CF@``!P```.>:```'````[YH```8```#W
MF@``.````/Z:```6````-YL```4```!.FP``!P```%2;```&````7)L```@`
M``!CFP``"0```&R;``!%````=IL```0```"\FP``!````,&;```'````QIL`
M``D```#.FP``!@```-B;```'````WYL``!8```#GFP``!````/Z;```G````
M`YP```@````KG```!@```#2<```-````.YP```8```!)G```'@```%"<```1
M````;YP```@```"!G```#````(J<```'````EYP```,```"?G```"````*.<
M```(````K)P```@```"UG```"````+Z<```J````QYP``"L```#RG```4P``
M`!Z=```&````<IT```8```!YG0``#@```("=```^````CYT```H```#.G0``
M!P```-F=```'````X9T```X```#IG0```@```/B=```&````^YT``!@````"
MG@``3P```!N>```$````:YX```P```!PG@``!@```'V>```*````A)X```T`
M``"/G@``8@```)V>```G`````)\``%\````HGP``%@```(B?```<````GY\`
M``\```"\GP``,P```,R?```H`````*````4````IH```!0```"^@```-````
M-:```!4```!#H```,````%F@```U````BJ```$4```#`H```$`````:A```%
M````%Z$```L````=H0``1P```"FA```?````<:$``"4```"1H0``*P```+>A
M```U````XZ$``$(````9H@``40```%RB```[````KJ(``$````#JH@``.```
M`"NC```%````9*,```P```!JHP``$0```'>C```-````B:,``!<```"7HP``
M"````*^C```,````N*,``!0```#%HP``#P```-JC```(````ZJ,```4```#S
MHP``$0```/FC```'````"Z0```<````3I```"P```!ND```'````)Z0```<`
M```OI```"0```#>D```7````0:0``"8```!9I```3P```("D```)````T*0`
M``D```#:I```"@```.2D```E````[Z0``!\````5I0``%0```#6E```9````
M2Z4```4```!EI0``(@```&NE```2````CJ4``!L```"AI0``"````+VE```(
M````QJ4``!L```#/I0``'@```.NE```O````"J8``%P````ZI@``+@```)>F
M```,````QJ8```0```#3I@``#@```-BF```'````YZ8```X```#OI@``"@``
M`/ZF```L````":<``"0````VIP``-@```%NG```I````DJ<``$$```"\IP``
M.@```/ZG```]````.:@``#H```!WJ```!P```+*H```&````NJ@```T```#!
MJ```"P```,^H```4````VZ@``!@```#PJ```&@````FI```=````)*D``!D`
M``!"J0``70```%RI```5````NJD``"4```#0J0``!P```/:I```$````_JD`
M``P````#J@``%````!"J```-````):H``#D````SJ@``'````&VJ```H````
MBJH```,```"SJ@``!@```+>J```1````OJH``!<```#0J@``#@```.BJ```"
M````]ZH```4```#ZJ@``!0````"K```$````!JL```,````+JP``"`````^K
M```(````&*L```H````AJP``#P```"RK```'````/*L``!0```!$JP``&0``
M`%FK```:````<ZL```D```".JP``!@```)BK```4````GZL``!,```"TJP``
M$````,BK```7````V:L``!$```#QJP``%0````.L```G````&:P```T```!!
MK```*P```$^L```7````>ZP``#0```"3K```,P```,BL```*````_*P``!0`
M```'K0``!P```!RM```'````)*T``!`````LK0``'````#VM```<````6JT`
M``<```!WK0``#````'^M```F````C*T```H```"SK0``"P```+ZM```,````
MRJT```<```#7K0``"P```-^M```J````ZZT```\````6K@``"0```":N```'
M````,*X``"T````XK@``&@```&:N```H````@:X``"T```"JK@``+@```-BN
M```,````!Z\```@````4KP``#````!VO```C````*J\``"H```!.KP``(```
M`'FO```(````FJ\``!(```"CKP``'P```+:O```$````UJ\```@```#;KP``
M&@```.2O```G````_Z\``!(````GL```(````#JP```7````6[````4```!S
ML```#````'FP```.````AK````P```"5L```!@```**P```.````J;````,`
M``"XL```*P```+RP```'````Z+````0```#PL```$0```/6P```3````![$`
M`"4````;L0``$P```$&Q```6````5;$``!,```!LL0``.````("Q```)````
MN;$```4```##L0``"P```,FQ```%````U;$```T```#;L0``&P```.FQ```)
M````!;(``!T````/L@``+P```"VR```/````7;(``!8```!ML@``$@```(2R
M```+````E[(```P```"CL@``&0```+"R```<````RK(``!@```#GL@``$P``
M``"S```)````%+,```,````>LP``%0```"*S```+````.+,``!,```!$LP``
M$````%BS```G````:;,``"D```"1LP``+````+NS```H````Z+,```X````1
MM```-0```""T```1````5K0```<```!HM```!0```'"T```I````=K0``!D`
M``"@M```&````+JT```'````T[0```@```#;M```!@```.2T```;````Z[0`
M`!`````'M0``$````!BU```/````*;4```\````YM0``#````$FU```'````
M5K4```8```!>M0``"@```&6U```2````<+4```T```"#M0``#````)&U``!#
M````GK4``#T```#BM0``"0```""V```(````*K8```L````SM@``&P```#^V
M```-````6[8```,```!IM@``"````&VV```*````=K8``"````"!M@``'P``
M`**V```;````PK8``!D```#>M@``"P```/BV```;````!+<```@````@MP``
M!````"FW```$````+K<```D````SMP``#@```#VW```/````3+<``"4```!<
MMP``*@```(*W```'````K;<``!(```"UMP``&P```,BW```%````Y+<```<`
M``#JMP``$@```/*W```*````!;@```0````0N```!0```!6X```(````&[@`
M`!T````DN```$````$*X```.````4[@``!X```!BN```&@```(&X```*````
MG+@``$0```"GN```!0```.RX```'````\K@```@```#ZN```$0````.Y```9
M````%;D```8````ON0``!@```#:Y```:````/;D```T```!8N0``$````&:Y
M```;````=[D```4```"3N0``!````)FY```,````GKD```D```"KN0``!```
M`+6Y```%````NKD``!H```#`N0``!0```-NY```&````X;D```\```#HN0``
M!P```/BY```'`````+H``"(````(N@``!0```"NZ```)````,;H```H````[
MN@``#@```$:Z```"````5;H```T```!8N@``(````&:Z```,````A[H```D`
M``"4N@``!@```)ZZ```2````I;H```D```"XN@``!P```,*Z```&````RKH`
M``H```#1N@``!````-RZ```)````X;H```8```#KN@``#0```/*Z```&````
M`+L```0````'NP``!`````R[```7````$;L```4````INP``!@```"^[```'
M````-KL``"$````^NP``!@```&"[```$````9[L``"<```!LNP``!@```)2[
M```5````F[L```P```"QNP``$0```+Z[```$````T+L```T```#5NP``!P``
M`..[```=````Z[L```0````)O```#`````Z\```.````&[P```H````JO```
M"````#6\```)````/KP``"<```!(O```*````'"\```'````F;P```0```"A
MO```'````*:\```W````P[P```T```#[O```)P````F]```B````,;T```P`
M``!4O0``%@```&&]```%````>+T```H```!^O0``!P```(F]```*````D;T`
M`$0```"<O0``/````.&]```&````'KX```H````EO@``!0```#"^```&````
M-KX``#(````]O@``!@```'"^```*````=[X```X```""O@``#P```)&^```.
M````H;X``!L```"PO@``'P```,R^```E````[+X``",````2OP``$0```#:_
M```5````2+\``!L```!>OP``&````'J_```1````D[\``!````"EOP``$```
M`+:_```)````Q[\``!(```#1OP``'0```.2_```*`````L````4````-P```
M,0```!/````D````1<````\```!JP```!0```'K````)````@,````0```"*
MP```"P```(_````<````F\```",```"XP```(@```-S````&````_\```!<`
M```&P0``#````![!```'````*\$``"L````SP0``#P```%_!```6````;\$`
M`"@```"&P0``"P```*_!```F````N\$``"$```#BP0``(`````3"```&````
M)<(```0````LP@``!P```#'"```&````.<(```8```!`P@``!@```$?"```%
M````3L(```<```!4P@``!P```%S"```%````9,(``!8```!JP@``!@```('"
M```$````B,(```0```"-P@``!P```)+"```"````FL(```H```"=P@``!0``
M`*C"```*````KL(```@```"YP@``3P```,+"``!'````$L,``%,```!:PP``
M+@```*[#```(````W<,```\```#FPP``!@```/;#```*````_<,```@````(
MQ```(````!'$```1````,L0```D```!$Q```!@```$[$```&````5<0```<`
M``!<Q```!````&3$```'````:<0```4```!QQ```!P```'?$```6````?\0`
M``T```"6Q```!````*3$```1````J<0``"$```"[Q```!0```-W$```7````
MX\0``'P```#[Q```%0```'C%```)````CL4```H```"8Q0``#@```*/%```(
M````LL4```8```"[Q0``#````,+%```'````S\4```4```#7Q0``"P```-W%
M```$````Z<4```,```#NQ0``#````/+%```&````_\4```H````&Q@```@``
M`!'&```%````%,8```X````:Q@``"@```"G&```$````-,8```T````YQ@``
M'P```$?&```'````9\8``"(```!OQ@``!@```)+&```(````F<8```@```"B
MQ@``!````*O&```%````L,8```4```"VQ@``!@```+S&```C````P\8``"4`
M``#GQ@``"`````W'```W````%L<``"(```!.QP``$P```'''```0````A<<`
M``H```"6QP``$0```*''```/````L\<```H```##QP``"0```,['```7````
MV,<``!D```#PQP``*`````K(```L````,\@``"8```!@R```)@```(?(```#
M````KL@```<```"RR```!P```+K(```0````PL@```<```#3R```$P```-O(
M```,````[\@```T```#\R```#P````K)```/````&LD```\````JR0``#@``
M`#K)```,````2<D```X```!6R0``#P```&7)```/````=<D``!<```"%R0``
M%````)W)```1````LLD``"````#$R0``+@```.7)```:````%,H``"8````O
MR@``"P```%;*```&````8LH```8```!IR@``!@```'#*```)````=\H```8`
M``"!R@``#0```(C*```&````ELH```8```"=R@``"````*3*```.````K<H`
M``<```"\R@``"@```,3*```K````S\H```<```#[R@``!`````/+```)````
M",L```D````2RP``"@```!S+```'````)\L```D````ORP``0````#G+```.
M````>LL```<```")RP``"@```)'+```5````G,L``!4```"RRP``!P```,C+
M```$````T,L```0```#5RP``!````-K+```A````W\L```<````!S```!0``
M``G,```,````#\P```4````<S```"P```"+,```4````+LP```<```!#S```
M!0```$O,```6````4<P```,```!HS```#0```&S,```*````>LP```@```"%
MS```"P```([,```1````FLP```L```"LS```#````+C,```,````Q<P```0`
M``#2S```"@```-?,```$````XLP```P```#GS```"0```/3,```)````_LP`
M``4````(S0``!P````[-```%````%LT```0````<S0```@```"'-```4````
M),T```T````YS0``$@```$?-```+````6LT``!L```!FS0``'P```(+-```/
M````HLT``!0```"RS0``'@```,?-```5````YLT``"\```#\S0``$P```"S.
M```J````0,X``!D```!KS@``'````(7.```?````HLX``!0```#"S@``%```
M`-?.```@````[,X``"4````-SP``)````#//```I````6,\``$@```""SP``
M)````,O/```.````\,\``#<```#_SP``$@```#?0```/````2M````0```!:
MT```#@```%_0```&````;M```!@```!UT```!@```([0```+````E=````D`
M``"AT```#0```*O0```,````N=```!<```#&T```"@```-[0```A````Z=``
M``4````+T0``!P```!'1```J````&=$```@```!$T0``!@```$W1```4````
M5-$``$0```!IT0``/````*[1```"````Z]$```(```#NT0``!@```/'1```'
M````^-$```8`````T@``#`````?2```,````%-(``",````AT@``!````$72
M```R````2M(``#,```!]T@``#````+'2```4````OM(```T```#3T@``$```
M`.'2```4````\M(```<````'TP``!0````_3```3````%=,```T````ITP``
M#P```#?3```#````1],``!,```!+TP``"P```%_3```T````:],```L```"@
MTP``%````*S3```^````P=,``#0`````U```,0```#74```2````9]0``!``
M``!ZU```&````(O4```C````I-0``"(```#(U```)P```.O4``"Y````$]4`
M``0```#-U0``'````-+5```-````[]4``"<```#]U0``#````"76```'````
M,M8```T````ZU@``(@```$C6```A````:]8```@```"-U@``!0```);6```&
M````G-8``!````"CU@``"````+36```'````O=8```H```#%U@``$@```-#6
M```A````X]8```L````%UP``&P```!'7```8````+=<```@```!&UP``"0``
M`$_7```%````6=<```0```!?UP``!@```&37```'````:]<``"@```!SUP``
M"@```)S7```+````I]<``"P```"SUP``"````.#7```4````Z=<``"P```#^
MUP``)P```"O8```K````4]@``"H```!_V```!````*K8```+````K]@```4`
M``"[V```"````,'8```&````RM@``#$```#1V```'`````/9``"B````(-D`
M`"<```##V0``*````.O9```:````%-H``'8````OV@``>0```*;:```<`0``
M(-L``!T````]W```'0```%O<```N````>=P``#8```"HW```+````-_<```Q
M````#-T``"X````^W0``!@```&W=```(````=-T``!````!]W0``*P```([=
M```A````NMT```@```#<W0``!P```.7=```0````[=T```T```#^W0``!0``
M``S>```(````$MX``!0````;W@``"````##>```V````.=X``#<```!PW@``
M"0```*C>```*````LMX``"\```"]W@``"P```.W>```.````^=X```T````(
MWP``#P```!;?```6````)M\``#X````]WP``)P```'S?```F````I-\``"0`
M``#+WP``!0```/#?```%````]M\```4```#\WP``)P````+@```?````*N``
M`!8```!*X```"P```&'@```$````;>```!,```!RX```"P```(;@```.````
MDN````X```"AX```"0```+#@```(````NN```!````##X```%0```-3@```3
M````ZN````<```#^X```%0````;A```-````'.$```8````JX0``"P```#'A
M```'````/>$``",```!%X0``%@```&GA```/````@.$```8```"0X0``&```
M`)?A```-````L.$``!````"^X0``+@```,_A```Z````_N$```X````YX@``
M#0```$CB```%````5N(```L```!<X@``#````&CB```-````=>(```T```"#
MX@``#@```)'B```-````H.(``"````"NX@``)P```,_B```K````]^(```@`
M```CXP``"@```"SC```&````-^,``!(````^XP``#@```%'C```7````8.,`
M`!8```!XXP``'````(_C```4````K.,```4```#!XP``&@```,?C```'````
MXN,```8```#JXP``$P```/'C```?````!>0``!0````EY```$0```#KD``!+
M````3.0```<```"8Y```!0```*#D```$````IN0```<```"KY```"P```+/D
M```,````O^0```4```#,Y````P```-+D```2````UN0```8```#IY```!@``
M`/#D```6````]^0```X````.Y0``-P```!WE```.````5>4``!<```!DY0``
M00```'SE```T````ON4``"4```#SY0``%0```!GF```Q````+^8``!,```!A
MY@``&P```'7F```J````D>8``%$```"\Y@``60````[G``!0````:.<``+\`
M``"YYP``!````'GH```#````?N@```@```""Z```$````(OH```(````G.@`
M``P```"EZ```%0```++H```+````R.@``!D```#4Z```(````.[H```%````
M#^D```H````5Z0``%0```"#I```,````-ND```0```!#Z0``,@```$CI```*
M````>^D```H```"&Z0``%0```)'I```,````I^D```\```"TZ0``"P```,3I
M```'````T.D``!8```#8Z0``*@```._I```Z````&NH``"````!5Z@``#P``
M`';J```Z````ANH``#,```#!Z@``.0```/7J```&````+^L```D````VZP``
M#@```$#K```.````3^L```X```!>ZP``!````&WK```6````<NL```T```")
MZP``#@```)?K``!#````INL```H```#JZP``-0```/7K```1````*^P```L`
M```][```$@```$GL```H````7.P``!L```"%[```!P```*'L```7````J>P`
M`!P```#![```%P```-[L```,````]NP``!\````#[0``+P```"/M```'````
M4^T``!````!;[0``$0```&SM```)````?NT``!4```"([0``#0```)[M```&
M````K.T``!T```"S[0``!P```-'M```(````V>T```,```#B[0``0P```.;M
M```R````*NX```4```!=[@``"@```&/N```-````;NX``!(```!\[@``*0``
M`(_N``!P````N>X``#\````J[P``.0```&KO``!&````I.\```0```#K[P``
M$````/#O```0`````?````P````2\```#````!_P```4````+/```!T```!!
M\```'````%_P```1````?/```#T```".\```(````,SP```G````[?```!H`
M```5\0``*````##Q```D````6?$``"4```!^\0``!0```*3Q```&````JO$`
M``4```"Q\0``#````+?Q```)````Q/$```8```#.\0``"0```-7Q```$````
MW_$```4```#D\0``"````.KQ```(````\_$```\```#\\0``!P````SR```/
M````%/(```P````D\@``%````#'R```4````1O(```\```!;\@``#@```&OR
M```2````>O(```P```"-\@``+````)KR```'````Q_(```4```#/\@``!```
M`-7R```+````VO(```P```#F\@``$@```//R```I````!O,```L````P\P``
M#0```#SS```4````2O,``"D```!?\P``+P```(GS```)````N?,```@```##
M\P``!0```,SS```*````TO,``!````#=\P``$````.[S```+````__,```8`
M```+]```#0```!+T```0````(/0``!$````Q]```"````$/T```'````3/0`
M``T```!4]```!@```&+T```6````:?0```D```"`]```!P```(KT```%````
MDO0```L```"8]```!P```*3T```+````K/0```<```"X]```"````,#T```6
M````R?0```D```#@]```!@```.KT```9````\?0``!H````+]0``(````";U
M```+````1_4``!0```!3]0``!0```&CU```0````;O4``!````!_]0``!@``
M`)#U```*````E_4```4```"B]0``!0```*CU```0````KO4```L```"_]0``
M"P```,OU```:````U_4``!0```#R]0``+P````?V```$````-_8```D````\
M]@``"````$;V```Q````3_8``'@```"!]@``&P```/KV```Q````%O<``"(`
M``!(]P``(````&OW```=````C/<``!P```"J]P``70```,?W```M````)?@`
M`#,```!3^```2P```(?X```L````T_@``"4`````^0``(0```";Y```>````
M2/D``'4```!G^0``/@```-WY``!"````'/H``#T```!?^@``/0```)WZ```I
M````V_H``"D````%^P``,0```"_[```O````8?L``&(```"1^P``-@```/3[
M```^````*_P``#````!J_```(````)O\```_````O/P``#0```#\_```+```
M`#']```=````7OT``$<```!\_0``*@```,3]``!#````[_T``"8````S_@``
M'@```%K^```J````>?X``&````"D_@``/`````7_```X````0O\``*<```![
M_P``/````",``0`D````8``!`"@```"%``$`(@```*X``0`C````T0`!`"4`
M``#U``$`)0```!L!`0`I````00$!`!<```!K`0$`*0```(,!`0`@````K0$!
M`#(```#.`0$`'`````$"`0`N````'@(!`#@```!-`@$`/````(8"`0`F````
MPP(!`"X```#J`@$`/@```!D#`0!3````6`,!`%<```"L`P$`50````0$`0`J
M````6@0!`"\```"%!`$`50```+4$`0`@````"P4!`"L````L!0$`*@```%@%
M`0`^````@P4!`%(```#"!0$`*P```!4&`0`J````008!`"8```!L!@$`,```
M`),&`0`=````Q`8!`",```#B!@$`.P````8'`0`G````0@<!`$X```!J!P$`
M1P```+D'`0!B`````0@!`$D```!D"`$`50```*X(`0!`````!`D!`&0```!%
M"0$`/@```*H)`0!5````Z0D!`"\````_"@$`,@```&\*`0`K````H@H!`&X`
M``#."@$`=0```#T+`0`I````LPL!``\```#="P$`+0```.T+`0`Q````&PP!
M``X```!-#`$`"P```%P,`0`$````:`P!``L```!M#`$`!0```'D,`0`"````
M?PP!``H```""#`$`5@```(T,`0!.````Y`P!``4````S#0$`!````#D-`0`'
M````/@T!``4```!&#0$``P```$P-`0`7````4`T!``P```!H#0$`#0```'4-
M`0`3````@PT!``<```"7#0$`!@```)\-`0`4````I@T!``P```"[#0$`&```
M`,@-`0`&````X0T!``,```#H#0$`!````.P-`0`&````\0T!``<```#X#0$`
M&``````.`0`*````&0X!`!,````D#@$`"````#@.`0`2````00X!``D```!4
M#@$`%@```%X.`0`'````=0X!`!\```!]#@$`#P```)T.`0`4````K0X!`!0`
M``#"#@$`#@```-<.`0`-````Y@X!`"0```#T#@$`!0```!D/`0`'````'P\!
M``P````G#P$`.P```#0/`0`/````<`\!`!$```"`#P$`$0```)(/`0`'````
MI`\!``8```"L#P$`&@```+,/`0`&````S@\!`!@```#5#P$`!@```.X/`0`'
M````]0\!``<```#]#P$`$0````40`0`>````%Q`!`!D````V$`$`!````%`0
M`0!&````51`!`!,```"<$`$`"````+`0`0`)````N1`!``H```##$`$`"```
M`,X0`0`&````UQ`!``<```#>$`$`"````.80`0`)````[Q`!``<```#Y$`$`
M#P````$1`0`$````$1$!``<````6$0$`$@```!X1`0`-````,1$!`!D````_
M$0$`&````%D1`0`+````<A$!``X```!^$0$`)````(T1`0`A````LA$!``H`
M``#4$0$`$P```-\1`0`G````\Q$!``D````;$@$`+````"42`0`4````4A(!
M`"@```!G$@$`#P```)`2`0`@````H!(!``T```#!$@$`%````,\2`0`-````
MY!(!`!0```#R$@$`%0````<3`0`1````'1,!``<````O$P$``P```#<3`0`(
M````.Q,!``8```!$$P$`!P```$L3`0`-````4Q,!``X```!A$P$`5P```'`3
M`0!:````R!,!`#\````C%`$`-@```&,4`0!^````FA0!`$<````9%0$`"0``
M`&$5`0`%````:Q4!``8```!Q%0$`"````'@5`0`,````@14!``H```".%0$`
M`@```)D5`0`$````G!4!``8```"A%0$`!0```*@5`0`#````KA4!`#L```"R
M%0$`3P```.X5`0`U````/A8!`"<```!T%@$`(0```)P6`0`D````OA8!`"8`
M``#C%@$`,P````H7`0!0````/A<!`$````"/%P$`'0```-`7`0!X````[A<!
M`"$```!G&`$`5@```(D8`0`Z````X!@!`$(````;&0$`&0```%X9`0`7````
M>!D!`"4```"0&0$`*@```+89`0`K````X1D!`"8````-&@$`2P```#0:`0!.
M````@!H!`"<```#/&@$`*0```/<:`0`A````(1L!`"L```!#&P$`'0```&\;
M`0`Z````C1L!`"D```#(&P$`(@```/(;`0`]````%1P!`$$```!3'`$`*```
M`)4<`0`L````OAP!``D```#K'`$`'````/4<`0`0````$AT!``\````C'0$`
M*P```#,=`0`G````7QT!``X```"''0$`2P```)8=`0!`````XAT!`"H````C
M'@$`-````$X>`0"O````@QX!`"@````S'P$`#P```%P?`0`*````;!\!``4`
M``!W'P$`!@```'T?`0`(````A!\!`!````"-'P$`#````)X?`0`1````JQ\!
M`"````"]'P$`!````-X?`0`*````XQ\!``,```#N'P$`!P```/(?`0`(````
M^A\!``D````#(`$`!@````T@`0`(````%"`!``\````=(`$`#````"T@`0`&
M````.B`!``D```!!(`$`"P```$L@`0`&````5R`!``<```!>(`$`#0```&8@
M`0`'````="`!``,```!\(`$`"0```(`@`0`,````BB`!``H```"7(`$`$0``
M`*(@`0`*````M"`!``\```"_(`$`!0```,\@`0`9````U2`!`!$```#O(`$`
M&`````$A`0`3````&B$!`!P````N(0$`$0```$LA`0`/````72$!``0```!M
M(0$``@```'(A`0`1````=2$!``(```"'(0$`$@```(HA`0`7````G2$!``L`
M``"U(0$``P```,$A`0`,````Q2$!``(```#2(0$`!````-4A`0`$````VB$!
M``(```#?(0$`$0```.(A`0`&````]"$!``L```#[(0$`&`````<B`0`3````
M("(!``X````T(@$`#P```$,B`0`"````4R(!``P```!6(@$`$0```&,B`0`-
M````=2(!``<```"#(@$`!0```(LB`0`.````D2(!``X```"@(@$`)0$``*\B
M`0`;````U2,!`!(```#Q(P$`*P````0D`0`0````,"0!`"T```!!)`$`1```
M`&\D`0`;````M"0!`"$```#0)`$`'@```/(D`0`?````$24!`(<````Q)0$`
M/````+DE`0`]````]B4!`&H````T)@$``0```)\F`0`2````H28!`!X```"T
M)@$`2P```-,F`0`:`0``'R<!`)D````Z*`$`"0$``-0H`0"*````WBD!`"4`
M``!I*@$`/0```(\J`0`%````S2H!`!4```#3*@$`K@```.DJ`0`)````F"L!
M`'<```"B*P$`I@```!HL`0`@````P2P!`"L```#B+`$`)@````XM`0!W````
M-2T!`'P```"M+0$`?````"HN`0!3````IRX!`'<```#[+@$`7@```',O`0!V
M````TB\!`"D```!),`$`3````',P`0!Y````P#`!``H````Z,0$`'P```$4Q
M`0#8````93$!`,`````^,@$`!@```/\R`0`I````!C,!`/D!```P,P$`Q@$`
M`"HU`0!?````\38!`#T```!1-P$`%0```(\W`0`^````I3<!`"(```#D-P$`
M)0````<X`0`R````+3@!`#(```!@.`$`$P```),X`0`B````IS@!`"(```#*
M.`$`"@```.TX`0"W````^#@!`/H```"P.0$`"0```*LZ`0`2````M3H!`#,`
M``#(.@$`?P```/PZ`0`P````?#L!`!@```"M.P$`'@```,8[`0`P````Y3L!
M`",````6/`$`#````#H\`0`2````1SP!`&T```!:/`$`)````,@\`0!C````
M[3P!`%<```!1/0$`-@```*D]`0!B````X#T!`!(!``!#/@$`:P```%8_`0!F
M````PC\!`%H````I0`$`G````(1``0![````(4$!`+\```"=00$`&P```%U"
M`0`M````>4(!`"T```"G0@$`"0$``-5"`0`S`0``WT,!`"H````310$`)P``
M`#Y%`0`8````9D4!`!X```!_10$`,````)Y%`0`2````ST4!`!4```#B10$`
M[0```/A%`0`$`0``YD8!`+L```#K1P$`Q0```*=(`0#<````;4D!`$4```!*
M2@$`PP```)!*`0!"````5$L!`&````"72P$`%0```/A+`0!:````#DP!`"@`
M``!I3`$``@$``)),`0"N````E4T!`,8```!$3@$`&`````M/`0`;````)$\!
M`!X```!`3P$`)````%]/`0`\````A$\!`"<```#!3P$`/@```.E/`0`8````
M*%`!`"<```!!4`$`,P```&E0`0!V````G5`!`'\````440$`#````)11`0`D
M````H5$!`)````#&40$`@0```%=2`0#!````V5(!`&8```";4P$`I0````)4
M`0"K````J%0!`&D```!450$`J````+Y5`0"-````9U8!`)\```#U5@$`K@``
M`)57`0"L````1%@!`!X```#Q6`$`$@```!!9`0`M````(UD!`!(```!160$`
M"0```&19`0`)````;ED!`#D```!X60$`[0```+)9`0!3````H%H!``(!``#T
M6@$`YP```/=;`0`D````WUP!`%0````$70$`/````%E=`0"N````EET!`"0`
M``!%7@$`'@```&I>`0`V````B5X!`!L```#`7@$`#````-Q>`0`>````Z5X!
M`!4````(7P$`B@```!Y?`0"!````J5\!`"H!```K8`$`10```%9A`0!(````
MG&$!`"T```#E80$`(0```!-B`0`>````-6(!`&\```!48@$`:0```,1B`0`J
M````+F,!`#8```!98P$`80```)!C`0"U````\F,!`#$```"H9`$`&````-ID
M`0`2````\V0!`"0````&90$`&````"ME`0`,````1&4!`!L```!190$`'@``
M`&UE`0`5````C&4!`*0```"B90$`/````$=F`0`2````A&8!`!@```"79@$`
M$@```+!F`0`;````PV8!`!X```#?9@$`YP```/YF`0`&````YF<!``D```#M
M9P$`$@```/=G`0`D````"F@!``P````O:`$`#P```#QH`0!-````3&@!`!4`
M``"::`$`90```+!H`0`;````%FD!``D````R:0$`'@```#QI`0`8````6VD!
M`%@```!T:0$`/````,UI`0`>````"FH!`"H````I:@$`&````%1J`0`#````
M;6H!`"T```!Q:@$`&````)]J`0`5````N&H!`!@```#.:@$`D@```.=J`0"/
M````>FL!`/(````*;`$`$@```/UL`0`2````$&T!`!X````C;0$`J````$)M
M`0`2````ZVT!`!4```#^;0$`,````!1N`0`>````16X!``\```!D;@$`$@``
M`'1N`0!1````AVX!`%8!``#9;@$`"0```#!P`0`2````.G`!`"0```!-<`$`
M/P```')P`0`M````LG`!`&0!``#@<`$`F@```$5R`0`Q`0``X'(!`%`````2
M=`$`:@```&-T`0!2````SG0!`-@````A=0$`?````/IU`0`,````=W8!``D`
M``"$=@$`'@```(YV`0!6````K78!`)0````$=P$`K@```)EW`0#,````2'@!
M`"T````5>0$`#P```$-Y`0`A````4WD!``L!``!U>0$`2````(%Z`0!R````
MRGH!`($````]>P$`D````+][`0#L````4'P!`)H!```]?0$`WP```-A^`0"7
M````N'\!`'P```!0@`$`"0```,V``0`>````UX`!`"H```#V@`$`*@```"&!
M`0`J````3($!``D```!W@0$`(0```(&!`0`J````HX$!`!(```#.@0$`&```
M`.&!`0`)````^H$!`#@````$@@$`(0```#V"`0`P````7X(!`"0```"0@@$`
M'@```+6"`0`;````U((!`!L```#P@@$`,P````R#`0!7````0(,!`.L```"8
M@P$`'@```(2$`0`8````HX0!`!@```"\A`$`J````-6$`0",````?H4!`$(`
M```+A@$`40```$Z&`0`5````H(8!`*,```"VA@$`2@```%J'`0!U````I8<!
M``@````;B`$`#````"2(`0!G````,8@!`&H```"9B`$`CP````2)`0!*`0``
ME(D!`.X```#?B@$`%0```,Z+`0`/````Y(L!`"$```#TBP$`!@```!:,`0`S
M````'8P!`!X```!1C`$`90```'",`0!@````UHP!`)4````WC0$`=````,V-
M`0"P````0HX!`)\```#SC@$`V````)./`0"$````;)`!`!(```#QD`$`$@``
M``21`0`;````%Y$!`"0````SD0$`/````%B1`0!C````E9$!`&````#YD0$`
M=0```%J2`0!(````T)(!`"D!```9DP$`9@```$.4`0"?````JI0!`!4```!*
ME0$`#P```&"5`0`\````<)4!`&````"ME0$`0@````Z6`0"W````498!`'H`
M```)EP$`N@```(27`0`,````/Y@!`!(```!,F`$`(0```%^8`0`M````@9@!
M`"T```"OF`$``@```-V8`0`;````X)@!`"0```#\F`$`(0```"&9`0`,````
M0YD!``P```!0F0$`'@```%V9`0`D````?)D!`#$```"AF0$`&````-.9`0`\
M````[)D!`&@````IF@$`00```)*:`0`P````U)H!``D````%FP$`-@````^;
M`0`_````1IL!`!4```"&FP$`/````)R;`0!.````V9L!`"H````HG`$`70``
M`%.<`0`>````L9P!`)T```#0G`$`3@```&Z=`0"^````O9T!`*\```!\G@$`
M'@```"R?`0`V````2Y\!``P```""GP$`%0```(^?`0`M````I9\!`$8```#3
MGP$`30```!J@`0`8````:*`!`"$```"!H`$`;@```*.@`0`)````$J$!`!4`
M```<H0$`&@```#*A`0`J````3:$!`!@```!XH0$`<@```)&A`0!:````!*(!
M``8```!?H@$`$@```&:B`0!S````>:(!`$@```#MH@$`E@```#:C`0"7````
MS:,!`'P```!EI`$`$0```.*D`0`;````]*0!`"0````0I0$`<P```#6E`0!N
M````J:4!`$L````8I@$`&````&2F`0`\````?:8!`%$```"ZI@$`&`````RG
M`0`/````):<!`#\````UIP$`;@```'6G`0`9````Y*<!`%<```#^IP$`00``
M`%:H`0`G````F*@!`#````#`J`$`-0```/&H`0`M````)ZD!`!(```!5J0$`
M,````&BI`0`;````F:D!`)X```"UJ0$`&P```%2J`0`;````<*H!`$(```",
MJ@$`/````,^J`0!O````#*L!`%<```!\JP$`6@```-2K`0!.````+ZP!`.T`
M``!^K`$`&P```&RM`0`8````B*T!`"<```"AK0$`$@```,FM`0`P````W*T!
M`&@````-K@$`*@```':N`0!?````H:X!`(,````!KP$`&P```(6O`0!%````
MH:\!`"T```#GKP$`0@```!6P`0`J````6+`!`%````"#L`$`4````-2P`0!O
M````);$!`#\```"5L0$`,P```-6Q`0`2````";(!`%H````<L@$`'@```'>R
M`0`J````EK(!`#D```#!L@$`K````/NR`0"7````J+,!`*\```!`M`$`@@``
M`/"T`0`A````<[4!`)H```"5M0$`,````#"V`0`8````8;8!``\```!ZM@$`
MH0```(JV`0!3````++<!`&$```"`MP$`&````.*W`0`8````^[<!`!(````4
MN`$`:````">X`0`O````D+@!`#4```#`N`$`*0```/:X`0`Y````(+D!`"0`
M``!:N0$`'@```'^Y`0`2````GKD!`"H```"QN0$`,P```-RY`0`;````$+H!
M`"0````LN@$`S0```%&Z`0"I````'[L!`!X```#)NP$`*@```.B[`0`_````
M$[P!`$(```!3O`$`(0```):\`0`2````N+P!`!(```#+O`$`00```-Z\`0!^
M````(+T!`&T```"?O0$`6P````V^`0!<````:;X!`$$```#&O@$`=`````B_
M`0`2````?;\!`!L```"0OP$`#P```*R_`0`A````O+\!`#,```#>OP$`+0``
M`!+``0!\````0,`!`,8```"]P`$`#P```(3!`0`M````E,$!`$@```#"P0$`
M"P````O"`0`;````%\(!`$X````SP@$`(0```(+"`0`2````I,(!``\```"W
MP@$`)````,?"`0`G````[,(!`#8````4PP$`0@```$O#`0!3````CL,!`$0`
M``#BPP$`+0```"?$`0!)`0``5<0!`"0```"?Q0$`(0```,3%`0`F````YL4!
M`$4````-Q@$`40```%/&`0`,````I<8!`!(```"RQ@$`4````,7&`0`W````
M%L<!`#,```!.QP$`1@```(+'`0`)````R<<!``8```#3QP$`)````-K'`0`;
M````_\<!`"8````;R`$`)@```$+(`0!O````:<@!`!4```#9R`$`&````._(
M`0`A````",D!`!L````JR0$`'@```$;)`0`[````9<D!`!(```"AR0$`)```
M`+3)`0`8````V<D!`!X```#RR0$`!@```!'*`0`A````&,H!`&(````ZR@$`
M2P```)W*`0`S````Z<H!``\````=RP$`'````"W+`0`5````2LL!`!X```!@
MRP$`#P```'_+`0`G````C\L!`!(```"WRP$`(0```,K+`0`2````[,L!`"$`
M``#_RP$`&P```"',`0`/````/<P!``0```!-S`$`*@```%+,`0`,````?<P!
M`!4```"*S`$`$@```*#,`0!-````L\P!`!(````!S0$`#P```!3-`0!Q````
M),T!``P```"6S0$`70```*/-`0`D`````<X!`#`````FS@$`#P```%?.`0`G
M````9\X!`"$```"/S@$`40```+'.`0`8`````\\!`"H````<SP$`$@```$?/
M`0`G````6L\!`!X```""SP$`$@```*'/`0"*````M,\!`*`````_T`$`%0``
M`.#0`0`$````]M`!`!P```#[T`$`R````!C1`0`/````X=$!`)P```#QT0$`
M:P```([2`0`8````^M(!`$D````3TP$`(0```%W3`0`A````?],!`!@```"A
MTP$`(0```+K3`0"M````W-,!`*\```"*U`$`&````#K5`0`P````4]4!`!(`
M``"$U0$`$@```)?5`0"_````JM4!`!(```!JU@$`)````'W6`0`M````HM8!
M`!X```#0U@$`-P```._6`0!@````)]<!`%P```"(UP$`>@```.77`0!E````
M8-@!`#P```#&V`$`/@````/9`0!<````0MD!`$$```"?V0$`*P```.'9`0`I
M````#=H!`"D````WV@$`$@```&':`0`>````=-H!`#P```"3V@$`/````-#:
M`0`A````#=L!`+H````OVP$`>````.K;`0!"````8]P!``\```"FW`$`'@``
M`+;<`0`5````U=P!`!4```#KW`$`5`````'=`0!I````5MT!`'4```#`W0$`
M&````#;>`0!+````3]X!`"0```";W@$`&P```,#>`0"E````W-X!`$@```""
MWP$`:0```,O?`0"8````->`!`#P```#.X`$`A@````OA`0!V````DN$!`((`
M```)X@$`)````(SB`0`8````L>(!`!(```#*X@$`'@```-WB`0`8````_.(!
M``\````5XP$`%0```"7C`0`5````.^,!``P```!1XP$`#P```%[C`0`@````
M;N,!`!L```"/XP$`$@```*OC`0`2````ON,!`"<```#1XP$``@```/GC`0`G
M````_.,!`!(````DY`$`)````#?D`0`S````7.0!`,0```"0Y`$`-0$``%7E
M`0`[`0``B^8!`,,```#'YP$`&````(OH`0`;````I.@!`!@```#`Z`$`)```
M`-GH`0`,````_N@!`'4````+Z0$`6@```('I`0`M````W.D!`!@````*Z@$`
M$@```"/J`0`/````-NH!``\```!&Z@$`$@```%;J`0`2````:>H!`!L```!\
MZ@$`3P```)CJ`0`A````Z.H!``D````*ZP$`/P```!3K`0!?````5.L!``D`
M``"TZP$`/````+[K`0!_`0``^^L!`#````![[0$`&P```*SM`0`D````R.T!
M`$H```#M[0$`$@```#CN`0`)````2^X!`!4```!5[@$`"0```&ON`0`)````
M=>X!`"0```!_[@$`+0```*3N`0`)````TNX!`"$```#<[@$`&P```/[N`0`>
M````&N\!``(````Y[P$`$@```#SO`0`9````3^\!`"H```!I[P$`%0```)3O
M`0`V````JN\!`*0```#A[P$`*@```(;P`0!E````L?`!`!4````7\0$`&```
M`"WQ`0`8````1O$!``\```!?\0$`%0```&_Q`0`,````A?$!`!L```"2\0$`
M=@```*[Q`0!^````)?(!`",```"D\@$`H````,CR`0!7````:?,!`&````#!
M\P$`$@```"+T`0`;````-?0!`#,```!1]`$`+0```(7T`0`;````L_0!`!@`
M``#/]`$`2P```.CT`0`P````-/4!`&\```!E]0$`A````-7U`0">````6O8!
M`)8```#Y]@$`#````)#W`0`2````G?<!`!(```"P]P$`+0```,/W`0`)````
M\?<!`"$```#[]P$`/P```!WX`0`5````7?@!`!(```!S^`$`*@```(;X`0`M
M````L?@!`"T```#?^`$`)P````WY`0`J````-?D!`"$```!@^0$`%0```(+Y
M`0`\````F/D!`%$```#5^0$`2P```"?Z`0!K````<_H!`,0```#?^@$`7P``
M`*3[`0"9````!/P!`"$```">_`$`(0```,#\`0`8````XOP!`!(```#[_`$`
M%P````[]`0`/````)OT!`!4````V_0$`$@```$S]`0`5````7_T!`!X```!U
M_0$`(````)3]`0`5````M?T!`!L```#+_0$`CP```.?]`0`5````=_X!`!L`
M``"-_@$`.0```*G^`0`V````X_X!`#8````:_P$`,````%'_`0`;````@O\!
M`.X```">_P$`)````(T``@`2````L@`"`"0```#%``(`-````.H``@`V````
M'P$"`!X```!6`0(`#P```'4!`@`/````A0$"``\```"5`0(`;````*4!`@`5
M````$@("``P````H`@(`*@```#4"`@`5````8`("`!@```!V`@(`+0```(\"
M`@`2````O0("``D```#0`@(`3@```-H"`@`,````*0,"`"<````V`P(`%0``
M`%X#`@`D````=`,"`!@```"9`P(`)````+(#`@`G````UP,"`!@```#_`P(`
M-@```!@$`@`5````3P0"`"H```!E!`(`%0```)`$`@`A````I@0"`"<```#(
M!`(`)````/`$`@`5````%04"`"$````K!0(`"0```$T%`@`)````5P4"``\`
M``!A!0(`9@```'$%`@!%````V`4"`#X````>!@(`&P```%T&`@!S````>08"
M`'4```#M!@(`10```&,'`@!G````J0<"`'8````1"`(`2@```(@(`@"8````
MTP@"`$L```!L"0(`F0```+@)`@!,````4@H"`$L```"?"@(`8P```.L*`@!1
M````3PL"`%P```"A"P(`H0```/X+`@"2````H`P"`)L````S#0(`F````,\-
M`@`R`0``:`X"`,D```";#P(`(0```&40`@"D````AQ`"`&8````L$0(`,P``
M`),1`@`/````QQ$"`"$```#7$0(`$@```/D1`@!%````#!("`!(```!2$@(`
M(0```&42`@`_````AQ("`!X```#'$@(`/````.82`@!N````(Q,"`!4```"2
M$P(`A0```*@3`@`/````+A0"`"H````^%`(`S````&D4`@`8````-A4"``D`
M``!/%0(`)P```%D5`@#J````@14"`,\```!L%@(`&````#P7`@`#````51<"
M``\```!9%P(`#````&D7`@`;````=A<"`!@```"2%P(`-@```*L7`@"<````
MXA<"``\```!_&`(`<@```(\8`@"H`````AD"`!4```"K&0(`10```,$9`@`J
M````!QH"`$(````R&@(`40```'4:`@`5````QQH"`!(```#=&@(`.0```/`:
M`@`G````*AL"`$(```!2&P(``P```)4;`@`3````F1L"`!D```"M&P(`NP``
M`,<;`@`6````@QP"`%@```":'`(`TP```/,<`@"F````QQT"`)0```!N'@(`
M$@````,?`@`0````%A\"`!@````G'P(`>0```$`?`@""````NA\"`+8````]
M(`(`>P(``/0@`@`$````<","`!P```!U(P(`#P```)(C`@"<````HB,"`!@`
M```_)`(`$@```%@D`@`<````:R0"`&D```"()`(`=0```/(D`@`>````:"4"
M``\```"')0(`&````)<E`@`J````L"4"`"$```#;)0(`#P```/TE`@`D````
M#28"`#\````R)@(`@````'(F`@`I````\R8"`&`````=)P(`2P```'XG`@`G
M````RB<"`"P```#R)P(`&P```!\H`@`/````.R@"`!(```!+*`(`#P```%XH
M`@!G````;B@"`!(```#6*`(`$@```.DH`@#)````_"@"`"0```#&*0(`/```
M`.LI`@"8````*"H"`(8```#!*@(`H0```$@K`@",````ZBL"`!(```!W+`(`
M&P```(HL`@`8````IBP"`!L```"_+`(`$@```-LL`@"B````[BP"`%$```"1
M+0(`C0(``.,M`@!O````<3`"`%P```#A,`(`1````#XQ`@!A`0``@S$"`&0!
M``#E,@(`G0,``$HT`@!H````Z#<"`&L```!1.`(`I@```+TX`@"6````9#D"
M`(T```#[.0(`E@```(DZ`@"+````(#L"`!(```"L.P(`)````+\[`@`V````
MY#L"`(D````;/`(`Q@```*4\`@`2````;#T"`!X```!_/0(`%0```)X]`@`;
M````M#T"`!@```#0/0(`%0```.D]`@!4````_ST"`!(```!4/@(`U````&<^
M`@#7````/#\"`!H````40`(`)P```"]``@#4````5T`"`!L````L00(`.0``
M`$A!`@`W````@D$"`"<```"Z00(`8@```.)!`@"N````14("`&D```#T0@(`
M>````%Y#`@!Y````UT,"``P```!11`(`$@```%Y$`@`,````<40"`$8```!^
M1`(`5P```,5$`@!.````'44"`!H```!L10(`"0```(=%`@!+````D44"`#$`
M``#=10(`0`````]&`@`N````4$8"`!X```!_1@(`&P```)Y&`@`G````ND8"
M`#,```#B1@(`30```!9'`@`J````9$<"`&(```"/1P(`00```/)'`@`G````
M-$@"`$(```!<2`(`)P```)](`@!)````QT@"`$@````120(`00```%I)`@`2
M````G$D"`$X```"O20(`)````/Y)`@`J````(TH"`+(```!.2@(`X0````%+
M`@`V````XTL"`"`````:3`(`&````#M,`@!1````5$P"`#P```"F3`(`00``
M`.-,`@`S````)4T"`#@```!930(`.0```))-`@!@````S$T"`'\````M3@(`
ME0```*U.`@`B````0T\"`"@```!F3P(`'0```(]/`@`M````K4\"`$X```#;
M3P(`5````"I0`@!(````?U`"`&(```#(4`(`10```"M1`@`G````<5$"`)``
M``"940(`%0```"I2`@`;````0%("`$@```!<4@(`/P```*52`@!I````Y5("
M`#````!/4P(`X@```(!3`@`A````8U0"`!(```"%5`(`$@```)A4`@`5````
MJU0"`"T```#!5`(`+0```.]4`@`:````'54"``P````X50(`+0```$55`@`8
M````<U4"``8```",50(`%@```)-5`@`<````JE4"`,$```#'50(`&0```(E6
M`@!,````HU8"`.@```#P5@(`EP```-E7`@"%````<5@"`!4```#W6`(`F0``
M``U9`@`3````IUD"`!L```"[60(`Q````-=9`@`]`0``G%H"`)(!``#:6P(`
M6`$``&U=`@"!`@``QEX"``0```!(80(``P```$UA`@`>````46$"`%<```!P
M80(`)P```,AA`@`>````\&$"`"P````/8@(`(0```#QB`@!$````7F("`$T`
M``"C8@(`$@```/%B`@`A````!&,"`!4````F8P(`,P```#QC`@`;````<&,"
M`+X```",8P(`1@```$MD`@`M````DF0"`&````#`9`(`,0```"%E`@!=````
M4V4"`$4```"Q90(`)````/=E`@![````'&8"`)H```"89@(`\0```#-G`@!Y
M````)6@"`&D```"?:`(`Z0````EI`@`'`0``\VD"`/@```#[:@(`&````/1K
M`@`;````#6P"`"T````I;`(`*@```%=L`@`M````@FP"`!4```"P;`(`/```
M`,9L`@`S`````VT"`!L````W;0(`Q0```%-M`@`G````&6X"`*X```!!;@(`
M'@```/!N`@`A````#V\"`%D````Q;P(`DP```(MO`@!F````'W`"`!0```"&
M<`(`7````)MP`@"!````^'`"`$4```!Z<0(`&````,!Q`@!4````V7$"`)T`
M```N<@(`'@```,QR`@!%````ZW("`$H````Q<P(`#P```'QS`@!$````C',"
M`"$```#1<P(`)P```/-S`@!0````&W0"`"P```!L=`(`#````)ET`@`/````
MIG0"`.,```"V=`(`8P```)IU`@`/````_G4"`!4````.=@(`)````"1V`@`\
M````278"`)\```"&=@(`NP$``"9W`@#.````XG@"`-P```"Q>0(``@$``(YZ
M`@`2````D7L"`#8```"D>P(`/P```-M[`@`J````&WP"`"H```!&?`(`5```
M`'%\`@!O````QGP"`$@````V?0(`-@```']]`@#&````MGT"`'D```!]?@(`
MB````/=^`@!G````@'\"`)T```#H?P(`?@```(:``@!I````!8$"`!X```!O
M@0(`$@```(Z!`@`/````H8$"`!X```"Q@0(`&````-"!`@`P````Z8$"`!L`
M```:@@(`#````#:"`@`1````0X("`!L```!5@@(`&P```'&"`@`D````C8("
M`!4```"R@@(`/P```,B"`@!%````"(,"`$4```!.@P(`2````)2#`@`\````
MW8,"`#\````:A`(`2````%J$`@`V````HX0"`(````#:A`(`$@```%N%`@`8
M````;H4"`"H```"'A0(`-@```+*%`@!$````Z84"`"<````NA@(`@````%:&
M`@!"````UX8"`%T````:AP(`C0```'B'`@#5````!H@"`+T```#<B`(`&P``
M`)J)`@`>````MHD"`!L```#5B0(`0@```/&)`@!9````-(H"`%P```".B@(`
M1P```.N*`@`8````,XL"`"$```!,BP(`0@```&Z+`@!.````L8L"`!L`````
MC`(`&````!R,`@`G````-8P"`!L```!=C`(`,````'F,`@`M````JHP"`!(`
M``#8C`(`$@```.N,`@`/````_HP"`"H````.C0(`)````#F-`@`2````7HT"
M`!L```!QC0(`1P```(V-`@`D````U8T"`!4```#ZC0(`0@```!".`@`X````
M4XX"`%H```",C@(`$@```.>.`@!&````^HX"``\```!!CP(`/P```%&/`@!1
M````D8\"`!4```#CCP(`+0```/F/`@`8````)Y`"`!4```!`D`(`)````%:0
M`@`>````>Y`"`"H```":D`(`70```,60`@!+````(Y$"`)T```!OD0(`$@``
M``V2`@`8````()("``8````YD@(`A@```$"2`@!P`0``QY("`#H````XE`(`
M?P```'.4`@`^````\Y0"`%`````RE0(`90```(.5`@!L````Z94"`$X!``!6
ME@(`9P```*67`@"7````#9@"`-D```"EF`(`?P```'^9`@"A````_YD"`%8`
M``"AF@(`+0```/B:`@!;`0``)IL"`,````""G`(`K@```$.=`@#&````\IT"
M`+H```"YG@(`90```'2?`@!9````VI\"`(D````TH`(`GP```+Z@`@"-`0``
M7J$"`*T```#LH@(`M@```)JC`@";````4:0"`%H```#MI`(`;P```$BE`@!R
M````N*4"`$T````KI@(`.````'FF`@`7`0``LJ8"`*@```#*IP(`\P```'.H
M`@"$````9ZD"`%,```#LJ0(`?````$"J`@!.`0``O:H"`)X````,K`(`G0``
M`*NL`@!_`0``2:T"`+\```#)K@(`90```(FO`@!N````[Z\"`&@```!>L`(`
M?0```,>P`@!T````1;$"`)X```"ZL0(`H0```%FR`@`M````^[("`&L````I
MLP(`6@```)6S`@"9````\+,"`%0```"*M`(`DP```-^T`@##````<[4"`)X`
M```WM@(`:P```-:V`@"K````0K<"`.````#NMP(`_P```,^X`@#S````S[D"
M`/\```##N@(`A@```,.[`@"1````2KP"`!0!``#<O`(`8````/&]`@",````
M4KX"`(8```#?O@(`Q0```&:_`@`+`0``+,`"`'X````XP0(`N0```+?!`@!P
M````<<("`(\```#BP@(`/@```'+#`@!Z````L<,"`,\````LQ`(`7@```/S$
M`@#0````6\4"`+X````LQ@(`,`$``.O&`@#?````',@"`+(```#\R`(`E```
M`*_)`@!H`0``1,H"`,4```"MRP(`,`$``'/,`@"-````I,T"`)`````RS@(`
M?@```,/.`@#H`0``0L\"`/(!```KT0(`<@```![3`@`>````D=,"`(P```"P
MTP(`>P```#W4`@`_````N=0"`#8```#YU`(`&P```##5`@!+````3-4"`!@`
M``"8U0(`!@```+'5`@`D````N-4"`+P```#=U0(`RP```)K6`@`8````9M<"
M`!(```!_UP(`&P```)+7`@`5````KM<"``\```#$UP(`1P```-37`@`8````
M'-@"`!T````UV`(`1````%/8`@`8````F-@"``\```"QV`(`'````,'8`@`D
M````WM@"`#(````#V0(`&P```#;9`@`#````4MD"``0```!6V0(`'@```%O9
M`@`;````>MD"`#8```"6V0(`,````,W9`@!(````_MD"`!4```!'V@(`,```
M`%W:`@`S````CMH"`$@```#"V@(`)P````O;`@!]````,]L"`!T```"QVP(`
M*@```,_;`@`A````^ML"`#`````<W`(`)P```$W<`@!:````==P"``P```#0
MW`(`'@```-W<`@!1````_-P"`,L```!.W0(`40```!K>`@!(````;-X"`#D`
M``"UW@(`(0```._>`@`D````$=\"`"<````VWP(`,P```%[?`@!I````DM\"
M`!L```#\WP(`(````!C@`@`D````.>`"`#D```!>X`(`.0```)C@`@!`````
MTN`"`!L````3X0(`_@```"_A`@!%````+N("`"T```!TX@(`,@```*+B`@`M
M````U>("`!4````#XP(`#P```!GC`@`A````*>,"``P```!+XP(`)P```%CC
M`@`,````@.,"`$(```"-XP(`"0```-#C`@`,````VN,"`#8```#GXP(`%0``
M`![D`@!4````-.0"`%H```")Y`(`*@```.3D`@`J````#^4"`((````ZY0(`
M5P```+WE`@`S````%>8"`"H```!)Y@(`K0```'3F`@`D````(N<"`&L```!'
MYP(`1@```+/G`@!]````^N<"`!X```!XZ`(`5@```)?H`@`Y````[N@"`$(`
M```HZ0(`)````&OI`@`P````D.D"`#4```#!Z0(`/@```/?I`@`2````-NH"
M``D```!)Z@(`(0```%/J`@`D````=>H"`"0```":Z@(`/P```+_J`@`M````
M_^H"`&4!```MZP(`#0$``)/L`@#0````H>T"```!``!R[@(`O0$``'/O`@#<
M````,?$"`!4````.\@(`#P```"3R`@`0````-/("`"H```!%\@(`2P```'#R
M`@!1````O/("``(````.\P(`!````!'S`@`A````%O,"``\````X\P(`"0``
M`$CS`@"<````4O,"`+H```#O\P(`;@```*KT`@!\````&?4"`%H```"6]0(`
M=````/'U`@",````9O8"`*L```#S]@(`$P$``)_W`@#>````L_@"`%````"2
M^0(`>0$``./Y`@!B````7?L"`#@!``#`^P(`Z````/G\`@"Q````XOT"`#L`
M``"4_@(`/````-#^`@!N````#?\"`(H```!\_P(`C0````<``P"5````E0`#
M`/,````K`0,`^0```!\"`P"<````&0,#`(,```"V`P,`>````#H$`P"0````
MLP0#`&X```!$!0,`P@```+,%`P!G````=@8#`&4```#>!@,`[P```$0'`P#@
M````-`@#`'@````5"0,`=0```(X)`P`J````!`H#`%(````O"@,`/````((*
M`P!%````OPH#`(H````%"P,`=P```)`+`P`O````"`P#`/<````X#`,`X@``
M`#`-`P"<````$PX#`+H```"P#@,`/P(``&L/`P"#````JQ$#`#L````O$@,`
M)````&L2`P`&````D!(#`!@```"7$@,`(0```+`2`P`L````TA(#`"P```#_
M$@,`,P```"P3`P!E````8!,#``\```#&$P,`(0```-83`P`2````^!,#``P`
M```+%`,`"0```!@4`P`A````(A0#`"0```!$%`,`#````&D4`P`G````=A0#
M`!L```">%`,`&P```+H4`P`8````UA0#`"X```#O%`,`&P```!X5`P`;````
M.A4#`!L```!6%0,`)````'(5`P`)````EQ4#`!@```"A%0,`,````+H5`P`5
M````ZQ4#`%0````!%@,`)````%86`P`/````>Q8#``8```"+%@,`40```)(6
M`P!.````Y!8#`&,````S%P,`5````)<7`P!@````[!<#`$L```!-&`,`0@``
M`)D8`P`&````W!@#``(```#C&`,`2````.88`P`/````+QD#`#<````_&0,`
M10```'<9`P`A````O1D#``\```#?&0,`/````.\9`P`(````+!H#``\````U
M&@,`#P```$4:`P`#````51H#`$4```!9&@,`$@```)\:`P`<````LAH#`%<`
M``#/&@,`.0```"<;`P`Y````81L#`#D```";&P,``@```-4;`P`J````V!L#
M`#D````#'`,`,````#T<`P`A````;AP#``4```"0'`,`/````)8<`P`S````
MTQP#``$`````````1@,``+P!``!,`P``,P8``$P$``"4!0``N0(``($````,
M`0```````%0!``"'!0``<0```/\#```8`@``T04```````"W`P``IP4``"D!
M````````PP```"T!````````-@0``#("``#Q!0``%04``,<%``"U`0``````
M`-,"```_!0``$````(H```"?!0``N00``#0```#N!0``.P,``"4$````````
M4P(```````""````>`4``($#``#R`@``\P,``$L%``!B!```#`4``/(%````
M``````````````#2`@``[0$``(D$``!?!0``4P,```````"8!0``'08``",#
M```A!@``B@0```X%``!(`@``:`(```````#-`P``3P4``+T"````````E0$`
M`#<%````````I`4``%\!``#Q`````````````````P``YP4```````!=!```
M``````````!K`P``9@,````````"!0``F@4````````(!@``LP$``-X"``#D
M!```&`8``#`%``!/`@``2`0``-L$````````+00``+$!``!5````A@,`````
M``````````````````#B!````````!H&```F`P``JP,``!0!``!<`@``````
M````````````60,``,T!``"_````"````-@```!=````PP$``*(#```?`@``
MR0,``*<$``"M`0``?P(``(@%``"G`P``]P0``)`!````````0`$``((%``#V
M````^@0``,$!````````OP0``&X#``"B`0```````+H%```-!0``[@$``.@#
M```)!@``!@8`````````````E`$```\#``":``````````````"(`P``U@``
M`%P%`````````````/T```"[`@``+P,``+X"```^`P``=@,``+L#```6`@``
M`P,````````(`0``*`0``/P"``"&`@``H0````````#W!0``E````*P"```Q
M```````````````2`0``M`(```````#N`P```````!D"``#C`0``C0(``(\$
M``"+`@```````$8"``!Z`P``@```````````````A00``/L$``!9`@``?`4`
M`#$!````````Z`$``&4%```.`0`````````````B`@```````+`"````````
MW00``)T!```Z!0``V0,``-$#``!`!@``%08```````"]`P``4@0```````"*
M`@``M00``-(%````````G0(``+4"``",!0``R00``#4!``#J````````````
M```&````JP4````````+!````````!D!````````A@4``,\```"U!0``EP,`
M``````#:`@``^`,``)\#````````8P0``"T````/`@````````````#]!```
M$@,```````"3````H`(``'L"``!%`@``C`,``#T#``!D`0``Q04``$T#``!H
M`P```````(X$``#:````X@````````#_`@``L0,`````````````<0$`````
M``!C`0```````'P#``!5`P```````/($``!L!````````'D"``#J!```````
M``0```"2`P``30(``'\!``!\`0``$00``&L!``#Z!0``HP````````#9!0``
M-0(``*X%```<`0``)P$``%T%``!)!0``8@$``%8```#M````3@$``)0$``":
M`0``G@,``(`%``!Z!0``'@```)4"````````#P$`````````````````````
M``"C!```+P8````%``!*!@```````#<&````````P`0`````````````(00`
M``````!,`@```````````````````````$@%``#*`@``0@$``!0#```V!0``
M/P(```8"``#S!0```````'<$```T!````@```(\!``"-`P```````,P#````
M`````````&8!``!^!```+@8``.D`````````)@4``!H"````````F0,``-\#
M``#:!0``/00``"D%`````````````````````````````%@$````````````
M`'L$``!S`@```````+`%````````5@,``#,"````````=P$``!X!``!`!0``
M*P,```$%``#``P``%`````L"`````````````'H"``"2!```%`0``%D!``#_
M````8`4``*$"```*!```$0,``)X```#B!0```0(``(X#````````6P(`````
M````````.````&`!``"H`````````-,$``!Z````%P0``&\$````````T@``
M`,``````````+P(``$X$``!!`0```````#T!``![`P``<00``,(%``"0`@``
MF`,``)$%```4!@``T00```P`````````>0,```````"@!`````````````!*
M`0``#08`````````````!`4```````"+````RP$``&(```"N!```SP4``+@%
M````````^`(``.T"``#7`0``4@4``,\!``#7````]@(``&X%````````````
M```````\````W0$````````Y!```[`,```8!```?`P``/P8```````!N`@``
M)04```````#C!```6@4```````"3`@````````````!Q`@```````,0#``#]
M`0``R````"4#``#?`````````,L```"V`0``M`4``/<!``!,``````````X"
M``#;!0````````````#U!0``&00``/\!```L!```^`4``",%``!`````@0$`
M`````````````````*T"```#`0``)0```),%``"6``````````````#!!```
ME@4````````[``````````````#4!```_P4``,$"```0!```4````'("```X
M!```[04``$4$````````C@(``+X$```X`0``$@8``%`!```'````Q00``-0`
M``!V`0``,P4``,@#``"K`0``0@,````````<`@``AP```*0#````````UP0`
M```````@`@```````%0```#H````6P```&D%```E`0``@P,``!L!````````
M-`(``/4$``!D`@``KP,````$``!``@``>P```$<!``"\````X04``$0"````
M````)P8```````"F````````````````````D0(```````#Q`@``/@```-4#
M`````````````-P!````````[P,````````B!0``9````,\#````````````
M``````#7!0``,@4``+`!``!6!```GP```((#``#X`0``80````````!T````
MJ0(````````<!````````(P"``!W`````````'````"7````8`(``*8#``!#
M!```Z0(````&``#L!```?P4``"H"``"H`P``?0$```````#-!0``,P``````
M``!=`@``O04``/8%````````OP4``/8#```^!0``H00``","```7`0``?@$`
M``````"(`````````*<```!`!```*P0``(($``"+`P``P04``/D#``!#`P``
M0P(``%8%``!R`P```````'<"``!?`````````.4```"-`0`````````````0
M`@```````"(```!I!```#0```-T```!<`````````!T"```0`P``(`$``$L"
M````````6`4`````````````)`(``!H%``"R`P``ZP```&4```#J`@```P``
M`)L%````````W@,``&4!```3`P```````!8!``"+!```C@4``#D&```I````
M````````````````)P```$X"``#<````Y0(``!X%````````.@$``&H#``!J
M````B04``$,````=`0``&@0``.0#``!*!0``7`0``(H!````````_`4```<$
M```3!0``Z0,````````N`P```````#H#```3`@``#00``"H$```*`@``?P``
M`'<%`````````````/@```"#`@``.0$``+P#``"9`@``1P,``)4#```/!```
MP@,``",&``#'````1@$``$T%````````?@4```````!S`0``MP0```````!+
M`P```````.(#``#8!0``+`(```H````D````#P8``#L$```C`0``&0,``/P!
M````````K`$``+@#```*!0```````&P"`````````````,P!``"1!```````
M`$$%````````1@```$H"``#@`0```````&\````L````T`(``'@!``!!````
M604``#`#````````RP(`````````````@0(``,H%``"4`@````````````!4
M`@```````)P#``#'`0```````$H$```@!```/0(``/4#``";`0``[`4``,D!
M``#4!0``<04``/X```#;`P``*@,``!L&```7`P``*P```+8$````````6P0`
M`'`$`````````````'8```#>`0``U04``!4$```G!0``&P4``-<"``!\`@``
M`````/X"```P````U00``)X%```(!````````),$````````008```````!!
M`@``Y04`````````````S`0``*`%```9!0``@@(``(@"``"9!```6`$``%(!
M``"6`P``G`0``+("``##`P``O00``!H#``"7`@```````"0!``#T````Q`0`
M`#X&``"T````>@$``$H#````````LP(``*L"``";````;0$``,<$``#O!0``
M*`8``/`!````````LP0``*,%``!\!```!`,``-,#``!/`P```````#(!``"$
M!0``_`0``/L#``!$`P````````````#T!````@8```````"F`@``[P$`````
M``#?!```>04``$H````8`0``E@$``+($``#:`0````````L#``"^````7@``
M`!H````L`0``(04``+`#```R````N0,``"4&```+````1`0``'T#``#0!0``
M:0,``#8```#A`0``K@$``&<$```S`P``G0,```(#````````@`,``)`%``"^
M!0``````````````````LP4``-8%```)`P```````+T!````````&P```(0`
M``!$!0``U`$```````````````````````#``@```````#T&``#T`P``-`4`
M`%8"``!?`P``]0$```````"Z````KP(````````\!0``@P0``/@$``!:`@``
MY@0``$<%````````%@0`````````````2P```*H"``"0`P```````(,```"D
M!```D@$```````!5`@``"P4``#H`````````;0(````````1`0```````$$$
M``#M!````````,0"``"I!``````````````J!0``300``',%```F!@````$`
M`,8$````````Z00``+H#``"F!```=`(``.X$`````````````*P`````````
MV0```)<$````````9P,`````````````BP4``)H#``"<````)0(`````````
M````(@,``.`````<!@``[@(`````````````L@$``',#````````@`$``($$
M```Y!0``_0,```````!O`0``"`,```````#R`0``Q`$````````%!0``&P0`
M````````````J0,````````"`0```````'T```"D````8P```&@```"=!0``
M`````,\"``#H!```:`4````````8`P``A0(``'D!````````/P$``/4````1
M!0``^@````````#"`0```````"@!```I`P``M0,`````````````"04``*P$
M``#A`P``!08``%,!``#5`0``B`$``)````"=!````````"X`````````*`,`
M`'0$```9!@``2P0``$T```!7`0``@`(``,H#`````````````'<#````````
MMP````````"M!```````````````````````````````````V@,``(L!``!9
M!```R@0``$8&``"W!0``20$``#8&````````!@4``!8#````````208`````
M``"B!0``XP,``%,````K!0``>````'`#```&!```+P4``/(```!:`0``,`0`
M`&P#``#2!```6@```"`#``!.`P```````!$&`````````````#P&``!%````
M5P(```````#G`````````*\!``!2````?P,``!$```#Z`P``!P$``.`#```/
M````RP0``)H"````````K@(``-`!````````O@,``#0!``!0`@``FP(``-T"
M`````````````-8#````````40(```P$```W````$@4``/`"``!%`0``G`(`
M`%$#```;`P``<P0``,4`````````J@4```,%``":!```?@,`````````````
M)`8``)@"`````````````,@"````````Y@```*P%```M`@```````"T%````
M````/@$```4$``".`````````!0"``!B!0``3P$``#<"````````````````
M````````6````#L!``#%`@``F04``&(#```L`P```````*P#``#%`0``)@(`
M````````````404``*4```!F````V`0``$X%````````9@(``!X#``#[!0``
MO`4``.8%```)`@``QP(``+H"``!\````;P,``)X"``#0!```]P```/D!``"2
M!0``I`$``%$`````````U`(``-4````5`@``R@``````````````3`4``%0%
M``#D`@``TP````T"``"I!0``]P,```````!"````;``````````V`0``````
M`$<"```>`@``=04``#D````=`P``S0````````"[!0``'``````````$!```
MY`````````!L!0``C0````P"``#-`@``:@$``)\!``"?!```Q@```&L```!4
M!```KP0``!4#```I!@``108``%X"``!D!````````$`#```U`P```````(8$
M``"&````+@0```D$``#L`@``*00``&$$```?!0``-`,````````(!0``````
M``````#C`@``Y`4```````"1`0``*@$``"<#``#]!0``=`,```<#````````
MD@```%<$``"X`0``A`,``+D%```3!@``N0```!P#``#[`0``GP(``,X!```_
M````)@$``+H$``"5````A`0``+$"```[!@``#`8``(D!```8````W`(``&D`
M``!J!0````````````#H!0``0@0``````````````````"(!``!#`0``#0,`
M`/D`````````OP$``.X```!M`P```````,8"```@````1`$`````````````
M`````/X#```0`0```````+8#``#"!````````(4%``#C``````````````!)
M`@``+`4``'$#``!P`0``40$``#$"`````````````,,"```B!```K0,``+,`
M````````L04````````X!0````````````!K!0``IP(``-T%``"_`P``1@4`
M`#(&``!7`P``YP,`````````````;00```0"``#``0``````````````````
M-P0````````F````-0```.<$```R!```S`````````!Y!```L0```#P#``"(
M!```F`0``.0!````````?0(``&D!``!H!`````````````#+!0``+P0``*H`
M``!4`P```````'`%``!0`P``90(```````"H!````````&X!``#;````\P0`
M`,@%```B!@```````!T$`````````````&("``"<`0``T`````X#````````
M_P0``&T```!T!0``20```$0&```H````+@$``!P%``!3!0``,P$``-T#````
M````K04``*,#``#M`P``M`,``%<```!>`P``#0$``#<!``"T`0```````+(`
M``#A!```/`(````````H!0``AP0``-H$``#.!```FP,``&<```"9````6`,`
M``````#%`P``AP(```````#T`0``AP$``-@!```/!0```````*$!``!Y````
M,P0``+L!``#\`P``P0,``````````````````-D!````````?P0``/P```!K
M!````````*`#``#.!0````````````#U`@``6@0````````%````.P(`````
M``!U!```1P0``#@&``#Y!0```````/$#``"$`@``Q@,````````8!0``6@,`
M`"P&````````W@0``$,%``#T`@``ZP4``(H%``#-!```0@(```````"<!0``
MZP(``(\%``#T!0``I0$``(\#```7`@``/`0``,$```"D`@```````/<"````
M````-04```````"Z`0``.0(```````!A`P``-@(``$@&```I`@``````````
M````````5@$``-,%```A`P``X`0``(8!``"!!0``R`0``,@!``#J`0``IP$`
M`*$#``!X`P``A0,````````"`@``8P4``&D"``"6`@``/P0``(D#``!R!0``
M`````````````````````(4!````````=`$``!0%```D!```J@$``,0%````
M````_@$``(P!`````````````/$!``!'!@``Q@$``%L!``"W`@``9@0``#`"
M`````````````#(#```Q!```AP,``"$``````````00````````P`0``"0``
M`/`%``"_`@``?@(```````#)!0```P8``/,```!N!```1````*X#````````
M`````!,$``#Y`@```````#T%`````````````'4!``!=`P``>`0``.L#```1
M`@``@P$``)X!```,`P`````````````%`P``%0```!`%``!G`@``)`,``&$%
M````````I@4``#H"``".`0``@`0``-L"`````````````(H#```^!```````
M`(,%````````.`(``$T!``!O`@``Y00``*4$```7!0``\P$``/L"``!!`P``
MW`,``'L!```Y`P``7P0``.4!`````````````!4!````````\`0``*@"````
M````3`$``$@#````````W@4``-`#``"$`0```````)L$````````20,``*("
M``!%!0``L00``&0%``"-!0``[P0``+8````!`0``:P(``/``````````````
M``````!=`0```````)T```"B`````````-0#``"\`@``X0(``#H$````````
M`````&@!``"C`0```````$,&```T!@````````H!```.!```J`4````````!
M!@``WP(````````P!@```````%(#````````80$``"X"``!?`@``Y@$``-P%
M``#G`0``T0$`````````````N````$L!```X`P```````-<#``"K````EP$`
M``D!```@!0``H04``/8!``"5!0````````````!U```````````````3`0``
M`````/D$``#;`0``K0`````````?!```400`````````````!`$```````!/
M````/@(``)$```#J!0``R0(``!T%```2!```,04``',```"3`P``````````
M`````@```````+L$``````````````````"K!````````&$"``!<`P``S@,`
M`(T$``"W`0```````.8"````````T0(``,("``!R`0``````````````````
M`````'8"``"[````*`(````````.!@``:@(``((!``"H`0``-P,``-@#````
M````U0(``%X!``````````````````!L`0``9P4```````!.````^P```$@!
M``#?!0`````````````.````X@(````````6!0```````!<&``!Z!```8P(`
M````````````E@0``$D$``#O`@``V0(```````"1`P```````%`%```A`0``
M`````-8"````````C`0``'@"```K`0``W`0```````#O`````````%4$``")
M`@``M@4``!(```!J!```'P`````````A`@``=@4``%X$``#K`0``J0``````
M```#!````````*4"````````50$``)@`````````X@$```````#^!0``V00`
M`/H!``!G`0``M0````L!``!"!0``Z`(``)("``!P`@```````*D!``"^`0``
M4P0``,8%```!`P```````.<"``"S`P``D`0``%("```J!@``8`0``*\````V
M`P``L````-(!``!U`P``Q````&4#``#J`P``S`(``&````#'`P``"@,`````
M````````X0```"T#```(`@``!P(``.P!````````=0(``",```#S`@``R@$`
M`"0%```9`````````,X"````````T@,``"L"``#6`0```````+D!``!"!@``
MF0$``,`%``#L````R0```#P!````````900``,P%``!@`P```````&0#```[
M!0``$@(``$8$``!]!```*P8`````````````U@0``(4````Q!@``S@```)4$
M```7````,0,``#4$``#C!0``!P8``'($``",````%@8```````!C`P``'@8`
M`.D!```"!```N`0``"`&````````CP(``$\$``"J!```+P$``+@"``"/````
MEP4``&X```#8`@``K@````````![!0``'0```(D`````````SP0``!H!````
M````;04``!8````+!@``6P,``"T&``"8`0``+P```/$$``!8`@``60```*4%
M`````````````/T"``"3`0``/P,``/X$````````^@(`````````````````
M````````````.@8``!,`````````T0```-,!```]````H@0``&\%```G!```
MM`0```````!'````!0$``%P!```C!`````````````!(````4`0``%<%```J
M````7@4`````````````M@(``````````````````.L$```N!0``KP4``!`&
M``!F!0````````````!]!0``\`,```<%````````)@0```,"````````P@``
M```````?`0``H`$``+(%``#F`P``RP,``*H#````````'@0```````#?`0``
MZ04``.`%```8!````````*,"``!^````<@```/8$````````'P8``)0#``##
M!````````)X$``!;!0``I0,```H&```U!@``W@```'8$```&`P``\@,```4"
M```$!@``O`0````````G`@``I@$``*````"P!````````%4%```;`@``PP4`
M``````#@`@``10,``.4#``"]`````"`@("`@($-C.B``("`@("`@5&\Z(``@
M("`@1&%T93H@`"`@("!&<F]M.B``("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@4W5B
M:F5C=#H@`"!;(%-A=F4@=&AE(&ME>2!T;R!Y;W5R($%D9')E<W,@8F]O:R!=
M(``@6R!6:65W('1H92!R87<@:V5Y(%T@`"(E<R(@:7,@;F]T(&$@9&ER96-T
M;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(P`E9"`E<R!A;F0@
M)7,`)60@365S<V%G97,`)60@;65S<V%G97,@:&%V92!B965N(&1E;&5T960N
M`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T
M;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S86=E<R!H879E
M(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN`"5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M+@`E9"!T;R`E9"!O9B`E9"!-97-S86=E<P`E<R!!='1A8VAM96YT<RP@)7,`
M)7,@2T(`)7,@34(`)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R
M('=A<R!N;W0@<F5N86UE9"X`)7,@8GET97,`)7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R(&)E:6YG(')E;F%M
M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"X`)7,@:&%S(&%C8V5P=&5D
M+@`E<R!H87,@8V%N8V5L;&5D("(E<R(N`"5S(&AA<R!D96-L:6YE9"X`)7,@
M:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="X`)7,@:&%S(')E
M<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@(B5S(BX`)7,@:&%S('-E;G0@
M>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S('1E;G1A=&EV96QY
M(&%C8V5P=&5D+@`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`B)7,B+@`E<R!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O("(E<R(N`"5S('=I<VAE<R!T;R!A
M;6UE;F0@(B5S(BX`)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("(E
M<R(N`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I
M;VX@86)O=70@(B5S(BX`)7,Z("5S`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P
M.R5D*0`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C
M<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE
M(&-O;7!O<V4@<V-R965N+BD`*$A434PI`"A0;&%I;B!497AT*0`H4F5T=7)N
M('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA
M;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S
M8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"A396YD(&UE<W-A9V4@869T
M97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG
M97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N
M*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J`"H@4&QE87-E('-E;&5C
M="!A9&1R97-S*&5S*2`J`"TM('-E;&5C="`M+0`Q($%T=&%C:&UE;G0L("5S
M`#$P,"!C:&%R86-T97)S`#$P,#`@8VAA<F%C=&5R<P`Q,B!(;W5R($9O<FUA
M=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`R-3`@8VAA<F%C=&5R<P`U,#`@
M8VAA<F%C=&5R<P`\4')E=FEO=7,`02!L87)G92!I;6%G92!N86UE9"`E<R!I
M<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N`$$@;65S<V%G92!Y;W4@:&%V
M92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@
M9G)O;2!T:&4@<F5C:7!I96YT+@!!3D0`06)O=70N+BX`06)O=F4@=&AE(&UE
M<W-A9V4@=&5X=`!!8V-E<'0@86YD(&%D9"!T;R!M>2!C86QE;F1A<@!!8V-E
M<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E<'1E9#H@`$%C8V]U;G0@26YF;W)M
M871I;VX`06-C;W5N="=S(&YA;64Z`$%C=&EO;G,`061D`$%D9"`E<R!T;R!M
M>2!!9&1R97-S($)O;VL`061D('-O=7)C90!!9&0@=&AI<R!T;R!M>2!C86QE
M;F1A<@!!9&0@=&\@;7D@8V%L96YD87(`061D('5S97(`061D960@(B5S(B!A
M<R!A;B!A='1A8VAM96YT+@!!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES<&QA
M>2!W:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@:&5A
M9&5R(&]N(&$@;F5W(&QI;F4I/"]E;3X`061D:71I;VYA;"!I;F9O<FUA=&EO
M;B!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E
M=&%I;',`061D:71I;VYA;"!M97-S86=E(&1E=&%I;',`061D:71I;VYA;"!M
M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`061D:71I;VYA;"!M
M97-S86=E(&5R<F]R(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E(&5R<F]R
M(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`061D<F5S<P!!9&1R97-S($)O
M;VL`061D<F5S<R!";V]K<P!!9&1R97-S97,@=&\@0D-#(&%L;"!M97-S86=E
M<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W
M(&QI;F4I/"]E;3X`061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H
M:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S
M<R!O;B!A(&YE=R!L:6YE*3PO96T^`$%D;6EN:7-T<F%T:6]N`$%F9VAA;FES
M=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&P`06QL(&UE<W-A
M9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO
M861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z`$%L;"!M97-S86=E<R!I;B!Y;W5R
M("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA
M;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO
M<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL(&]L
M9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W
M:6QL(&)E(&1E;&5T960N`$%L;"!R:6=H=',@;VX@9F]L9&5R("(E<R(@<W5C
M8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@(B5S(BX`06QL;W<@1F]L9&5R
M($-R96%T:6]N/P!!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I
M;B!A;GD@;6%I;&)O>#\`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N
M871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CH`06QW87ES`$%L=V%Y<R!S
M879E(&%T=&%C:&UE;G1S`$%M97)I8V%N(%-A;6]A`$%N(&5R<F]R(&]C8W5R
M960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@
M5&AE($E-05`@<V5R=F5R('-A:60Z(`!!;B!U;FMN;W=N(&5R<F]R(&]C8W5R
M960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N;W1E+@!!;B!U;FMN;W=N(&5R
M<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+@!!;F1O
M<G)A`$%N9V]L80!!;F=U:6QL80!!;G-W97)E9`!!;G-W97)E9"!M97-S86=E
M<P!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`
M07!P;'D@1FEL=&5R<P!!<'!L>2!&:6QT97)S('1O("5S`$%P<&QY(&9I;'1E
M<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_`$%P<&QY(&9I;'1E<B!R=6QE<R!W
M:&5N979E<B!);F)O>"!I<R!D:7-P;&%Y960_`$%P<FEL`$%R86)I8R`H5VEN
M9&]W<RTQ,C4V*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H
M:7,@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;C\`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.
M3U0@<F5C;VUM96YD960A*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@
M=&AI<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E
M;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_`$%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\`07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@<W!A;2!F;VQD97(_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T
M:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R
M="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S('-P86T_`$%R9V5N=&EN
M80!!<FUE;FEA`$%R<FEV86P@5&EM90!!<G5B80!!<V-E;F1I;F<`07-K`$%T
M=&%C:"!&:6QE<P!!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K
M97D@=&\@>6]U<B!M97-S86=E/P!!='1A8VAE9"!&:6QE.@!!='1A8VAE9"!F
M:6QE("(E<R(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@
M1FEL92!.3U0@871T86-H960N`$%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C
M86QE;F1A<B!R97%U97-T('EO=2!S96YT+@!!='1A8VAM96YT`$%T=&%C:&UE
M;G0@)7,@9&5L971E9"X`071T86-H;65N="!);F9O<FUA=&EO;@!!='1A8VAM
M96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4`071T86-H
M;65N=',`071T96YD965S`$%T=&5N=&EO;@!!='1R:6)U=&5S`$%U9W5S=`!!
M=7-T<F%L:6$`075S=')I80!!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T;VUA
M=&EC86QL>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE
M('-E;F1E<B!I<R!I;B!M>2!A9&1R97-S8F]O:S\`079A:6QA8FQE($%D9')E
M<W,@8F]O:W,Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`0F%C7VL@
M=&\@)7,`0F%C:R!T;R`E<P!"86-K('1O($UU;'1I<&QE($UE<W-A9V4@5FEE
M=R!);F1E>`!"86-K('1O(%1H<F5A9"!$:7-P;&%Y`$)A8VMG<F]U;F0`0F%C
M:V=R;W5N9"!#;VQO<@!"860@;&]G:6X@;F%M92!O<B!P87-S=V]R9"X`0F%D
M(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N9&5D.B`E<P!"
M860@<F5Q=65S=#H@)7,N`$)A:&%M87,`0F%H<F%I;@!"86YG;&%D97-H`$)A
M<F)A9&]S`$)C8P!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;&]W(&ES('1H
M92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N
M`$)E;&]W('1H92!M97-S86=E('1E>'0`0F5N:6X`0F5R;75D80!":'5T86X`
M0FER=&AD87D`0FQA8VML:7-T`$)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A
M9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/P!"
M;V1Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<G,`0F]S
M;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O=&@@2&5A9&5R($QI<W1I;F<@
M86YD($)O9'D@;V8@365S<V%G90!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES
M;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R
M=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`$-20P!#7VAA<G-E=`!#86QE;F1A<@!#86UB;V1I80!#86UE<F]O;@!#86X@
M;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<BX`0V%N(&YO
M="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z(`!#86X@;F]T
M(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@
M;65S<V%G92!I;B!T:&4@8W5R<F5N="!M86EL8F]X+@!#86YA9&$`0V%N8V5L
M`$-A;F-E;"!-97-S86=E`$-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@
M<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N`$-A<&4@5F5R9&4`
M0V%P=&EO;@!#87)R:65R`$-A>6UA;B!)<VQA;F1S`$-C`$-E;G1E<@!#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,`0V5R=&EF:6-A=&4@:6UP;W)T(&ES(&YO
M="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H
M:7,@<V5R=F5R+@!#:&%D`$-H86ER(%!E<G-O;@!#:&%N9V4`0VAA;F=E($%L
M;`!#:&%N9V4@1F]L9&5R`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A
M<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@
M:&]W(&UE<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!M86EL('-E<G9E<B!A
M;F0@9F]L9&5R('-E='1I;F=S+@!#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L
M(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&%R86-T97)S('1O(&1I<W!L
M87DZ`$-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAE8VL@7T%L;"].
M;VYE`$-H96-K(&%L;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@
M;6%I;"!F<F]M.@!#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE
M<W-A9V4_`$-H:6QE`$-H:6YA`$-H;V]S92!!8W1I;VX`0VAO;W-E(&$@;6%I
M;"!S97)V97(Z`$-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@
M=&\@=&AE(')I9VAT.@!#:&]O<V4@=&AE(&%D9')E<W,@8F]O:R!T;R!U<V4@
M=VAE;B!A9&1I;F<@861D<F5S<V5S+@!#:&]O<V4@=&AE(&]R9&5R(&]F(&%D
M9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E
M<RX`0VAR:7-T;6%S($ES;&%N9`!#;&5A<@!#;&5A<B!1=65R>0!#;&EC:R`E
M<R!T;R!C;VYV97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U
M<B!B<F]W<V5R(&-A;B!V:65W+@!#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@
M:6UA9V4N`$-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G92X`
M0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!#
M;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@
M=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T
M960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@;VX@;VYE(&]F
M('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@
M86QL(&9I96QD<R!T;R!S96%R8V@N`$-L:6-K('1O(%-A=F4@4R]-24U%(&-E
M<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K`$-L:6-K:6YG
M(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O
M('1H92!S96YD97(`0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N
M('1H92!M97-S86=E('1O(&)E(')E860`0VQO<V4`0VQO<V4@5VEN9&]W`$-L
M;W-E('1H:7,@=VEN9&]W`$-L;W-E9"!&;VQD97(`0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',`0V]L;&%P<V4`0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&
M;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VQO;6)I80!#;VQO<@!#;VQO<B!)
M;F1I8V%T;W(Z(`!#;VUM86YD`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O
M<P!#;VUP86YY`$-O;7!L971E9`!#;VUP;W-E(&%N;W1H97(@;65S<V%G90!#
M;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!#;VUP;W-E
M(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H:68@8G)O
M=W-E<B!S=7!P;W)T<R!T:&4@9F5A='5R92D_`$-O;7!U=&5R<P!#;VYD:71I
M;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P
M;&%Y960N`$-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RX`0V]N9FER
M;2!%;6%I;"!!9&1R97-S`$-O;F9I<FT@;F5W(&5M86EL(&%D9')E<W,`0V]N
M9V\`0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+@!#;VYN96-T
M:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D`$-O;G1A
M8W1S`$-O;G1I;G5E`$-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+@!#;VYT
M<F]L(%,O34E-12!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!O<'1I;VYS(')E
M;&%T:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RX`0V]N=')O;"!W:&5N(&YE
M=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO
M="!T;R!N;W1I9GD@>6]U('=H96X@:70@87)R:79E<RX`0V]N=F5R="!T97AT
M=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/P!#;V]K($ES;&%N
M9',`0V]P>0!#;W!Y('1O(&9O;&1E<@!#;W)R96-T`$-O<G)E8W1E9"!497AT
M`$-O<W1A(%)I8V$`0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E87-O
M;B!':79E;CH@)7,`0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z
M("5S`$-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E
M<G9E<B!S86ED.B`E<P!#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O
M<&5R871I;VYS+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!#;W5L9"!N;W0@97AT
M<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N
M`$-O=6QD(&YO="!O<&5N('-E8W5R92!C;VYN96-T:6]N('1O('1H92!)34%0
M('-E<G9E<BX@)7,@.B`E<RX`0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C
M92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R+@!#;W5N=')Y`$-R96%T
M90!#<F5A=&4@1F]L9&5R`$-R96%T92!+97ES`$-R96%T92!A($YE=R!!8V-O
M=6YT`$-R96%T92!A(&YE=R!3<&%M(&9O;&1E<@!#<F5A=&4@82!N97<@9')A
M9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A
M=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@
M=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@
M9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@;F5W('-T871I;VYE
M<GD`0W)E871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+@!#<F]A
M=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@86-C97-S('1O("5S`$-U
M<G)E;G0@<W1Y;&4`0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M
M86EL(&9R;VT@;W1H97(@86-C;W5N=',N`$-U<W1O;6EZ92!H;W<@>6]U('-E
M;F0@;6%I;"X`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+@!#=70`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=%]E`$1A
M=&4`1&%Y`$1E8V5M8F5R`$1E8VQI;F5D`$1E8VQI;F5D.B``1&5C<F5A<V4@
M26YD96YT`$1E9F%U;'0`1&5F875L="!396%R8V@@1FEE;&0`1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$
M96QE9V%T960`1&5L971E`$1E;&5T92`E<R!0=6)L:6,@2V5Y`$1E;&5T92!#
M=7)R96YT($ME>7,`1&5L971E($9O;&1E<BAS*0!$96QE=&4@4V5L96-T960@
M1F]L9&5R<P!$96QE=&4@4W1A=&EO;F5R>0!$96QE=&4@5FER='5A;"!&;VQD
M97(`1&5L971E(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$1E
M;&5T92!C;VQU;6X`1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO
M=&4@<V5R=F5R/P!$96QE=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E
M;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/P!$96QE=&4@<F]W`$1E;&5T92!S<&%M(&UE<W-A9V5S`$1E;&5T93\`
M1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T960@=&AE(&%T=&%C:&UE
M;G0@(B5S(BX`1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$96YM87)K
M`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O
M<FUA=&EO;@!$97-C96YD:6YG`$1E<V-R:7!T:6]N`$1E<V-R:7!T:6]N.@!$
M971A:6QS`$1E=F5L;W!M96YT`$1I9"!N;W0@871T86-H("(E<R(@87,@=&AE
M(&9I;&4@=V%S(&5M<'1Y+@!$:6T@<VEG;F%T=7)E<S\`1&ER96-T;W)Y`$1I
M<W!L87D`1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE
M<W-A9V4_`$1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E`$1I<W!L87D@<&]P
M+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\`1&ES<&QA>2!T:&4@(D5M
M<'1Y(%-P86TB(&QI;FL@:6X@=&AE(&UE;G5B87(_`$1I<W!L87D@=&AE(")%
M;7!T>2!4<F%S:"(@;&EN:R!I;B!T:&4@;65N=6)A<C\`1&ES<&]S:71I;VXZ
M`$1J:6)O=71I`$1O($Y/5"!M871C:`!$;R!.;W0@0VAE8VL@1F]L9&5R*',I
M(&9O<B!.97<@36%I;`!$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&
M<F]M.B!C;VQU;6X`1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\`
M1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"X`1&]N90!$;W=N;&]A9`!$;W=N;&]A9"`E<R!I;B`N
M>FEP($9O<FUA=`!$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@
M9FEL92D`1&]W;FQO860@1F]L9&5R*',I`$1O=VYL;V%D($9O;&1E<BAS*2!;
M+GII<"!F;W)M871=`$1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T`$1R869T`$1R
M869T(&9O;&1E<@!$<F%F=',@9F]L9&5R.@!$>6YA;6EC($UA:6P`12U-86EL
M`$4M;6%I;"!!9&1R97-S`$5.1`!%4E)/4CH@66]U<B!M97-S86=E(&-O=6QD
M(&YO="!B92!D96QI=F5R960N`$5C=6%D;W(`161I=`!%9&ET(%-E87)C:"!1
M=65R>0!%9&ET(%9I<G1U86P@1F]L9&5R`$5D:70@5FER='5A;"!&;VQD97(@
M1&5F:6YI=&EO;B!F;W(@)7,`161I="!Y;W5R($)L86-K;&ES=`!%9&ET('EO
M=7(@1FEL=&5R(%)U;&5S`$5D:70@>6]U<B!7:&ET96QI<W0`161I="!Y;W5R
M('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT
M<RX`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL($%D
M9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M;W1I8V]N<P!%
M;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+@!%;7!T:65D(&%L;"!M97-S
M86=E<R!F<F]M(%9I<G1U86P@5')A<V@@1F]L9&5R+@!%;7!T>2!&;VQD97(H
M<RD`16UP='D@4V5L96-T960@1F]L9&5R<P!%;7!T>2!4<F%S:"!F;VQD97(`
M16UP='D@7U-P86T`16UP='D@7U1R87-H`$5N86)L92!01U`@9G5N8W1I;VYA
M;&ET>3\`16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/P!%;F%B;&4@;65S
M<V%G92!P<F5V:65W<S\`16YC<E]Y<'1I;VX@3W!T:6]N<P!%;F-R>7!T960`
M16YD`$5N9"!F;W)W87)D960@;65S<V%G90!%;F0@;65S<V%G90!%;F0@;65S
M<V%G92!F<F]M("5S`$5N=&5R(%!A<W-P:')A<V4`16YT97(@=&AE(&YA;64@
M9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y
M;W5R(&YE=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!S96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!T<F%S:"!F;VQD97(`16YT:7)E($UE<W-A9V4`16YT<GD@(B5S(B!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O;VL`17%U
M871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C;VYN96-T:6YG
M('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+@!%<G)O<B!D:7-P;&%Y:6YG(&UE
M<W-A9V4N`$5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+@!%<W1O;FEA`$5T:&EO
M<&EA`$5U<F]P90!%=F5N="!S=6-C97-S9G5L;'D@9&5L971E9"X`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X96-U=&4`17AP86YD`$5X
M<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N9"!&;VQD97(`17AP
M86YD($YA;65S`$5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@
M875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\`17AP86YD('1H92!E
M;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V
M:65W/P!%>'!A;F1I;F<`17AP;VYE;G0`1E]E=&-H($UA:6P`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y
M`$9E=&-H($UA:6P`1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\`
M1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N/P!&971C:&5D("5D(&UE
M<W-A9V5S(&9R;VT@)7,`1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<P!&971C
M:&UA:6PZ(`!&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RX`1FE?;'1E<G,`
M1FEJ:0!&:6QE`$9I;&4@3F%M90!&:6QT97(@3W!T:6]N<P!&:6QT97(@4V5T
M=&EN9W,`1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/P!&
M:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`1FEL
M=&5R<P!&:6QT97)S($Y/5"!!8W1I=F4`1FEL=&5R<SH@)7,@;6%N86=E;65N
M="!P86=E`$9I;F0Z`$9I;FQA;F0`1FER<W0@36%I;&)O>"!086=E`$9I<G-T
M(%!A9V4`1FQI<`!&;&]A=`!&;U]R=V%R9`!&;VQD97(@06-T:6]N<R`M($-O
M;F9I<FUA=&EO;@!&;VQD97(@3F%V:6=A=&]R`$9O;&1E<B!3=6UM87)Y`$9O
M;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+@!&;VQD97(@=7-E(&ES(&YO
M="!E;F%B;&5D+@!&;VYT($-O;&]R`$9O<FUA="!O9B!M97-S86=E(&1A=&5S
M(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y
M`$9O<FUS`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R
M=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&<F%M97,`1G)A;F-E`$9R964O0G5S
M>2!297%U97-T(%)E<W!O;G-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN
M97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O7VT`1G)O;0!&
M<F]M($%D9')E<W,`1G5L;"!.86UE`$9W9#H`1G=D.B``1G=D.B`E=2!&;W)W
M87)D960@365S<V%G97,`1V%B;VX`1V%M8FEA`$=E;F5R86P@3W!T:6]N<P!'
M96]R9VEA`$=E<FUA;GD`1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O
M;FQY*0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N
M<P!';P!';R!T;R!-97-S86=E`$=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O
M9B`B)7,B`$=R86YT(&%C8V5S<P!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)
M4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<',`1W5A9&5L;W5P
M90!'=6%M`$=U871E;6%L80!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`
M2$5210!(5$U,`$A434P@5F5R<VEO;B!O9B!-97-S86=E`$AA:71I`$AE861E
M<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(
M96EG:'0`2&5L<`!(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O
M<VEN9SH`2&ED9&5N`$AI9&1E;B!I;B!4:')E860@5FEE=P!(:61E($1E;&5T
M960`2&ED92!5;G-U8G-C<FEB960`2&EG:`!(:6=H(%!R:6]R:71Y`$AI9VAE
M<W0`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D
M9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_
M`$AO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'D`2'5N
M9V%R>0!)34%0`$E-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RD`24U!4"!3
M97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S<&]N9&5D
M.B`E<P!)34%0(&]V97(@4U-,`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D
M(&-E<G1I9FEC871E*0!)34%0('-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I
M;VXN`$E-05`L(&YO(%1,4P!)34%0+U!/4#,@36%I;"!397)V97)S`$E.0D]8
M`$E0($%D9')E<W,`26-E;&%N9`!)8V]N<R!/;FQY`$EF('5S:6YG(%-33"!O
M<B!43%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L(&5X=&5N<VEO
M;B!L;V%D960N`$EF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H
M92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(0!)9VYO<F4`26=N;W)E($%L;`!)
M;6%G90!);6%G97,`26UA9V5S(&%R92!B;&]C:V5D.B`E<R!T;R!P<F]T96-T
M('EO=7(@<')I=F%C>2X@)7,`26UP;W)T`$EM<&]R="!+97D`26UP;W)T($ME
M>7!A:7(`26UP;W)T($UE<W-A9V5S`$EM<&]R="!01U`@2V5Y`$EM<&]R="!0
M97)S;VYA;"!#97)T:69I8V%T90!);7!O<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y`$EM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R93H`
M26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,`26UP;W)T(%!U
M8FQI8R!+97D`26UP;W)T(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!0=6)L:6,@
M4$=0($ME>2!(97)E.@!);7!O<G0@4'5B;&EC(%,O34E-12!+97D`26UP;W)T
M(%,O34E-12!+97D`26UP;W)T(&UB;W@@1FEL90!);7!O<G0@;6)O>"!F:6QE
M`$EM<&]R=&%N=`!);7!O<G1A;G0@;65S<V%G97,`26UP;W)T960@)60@;65S
M<V%G97,@9G)O;2`E<RX`26X@4')O8V5S<P!);F)O>`!);F-L=61E(&$@8G)I
M968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_`$EN8VQU9&4@
M;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/P!);F-R96%S92!);F1E;G0`
M26YD:6$`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@
M;VX@)7,@4'5B;&EC($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA;"!0<FEV
M871E($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y`$EN
M;&EN90!);G-E<G0@0V5R=&EF:6-A=&4@2&5R90!);G-E<G0@5&%B;&4`26YT
M96=E<@!);G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE
M;G0N`$EN=F%L:60@061D<F5S<P!);G9A;&ED(%)E;6]T92!-86EL8F]X`$EN
M=F%L:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RX`26YV86QI
M9"!K97D`26YV86QI9"!M97-S86=E+"!C86X@;F]T(')E<W5M92!D<F%F="X`
M26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN`$EN=F%L:60@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97DN`$EN=F5R=`!)<F%Q`$ER96QA;F0`27-R
M865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N
M`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F]R9&%N`$IU;'D`2G5N90!*=7-T
M:69Y`$M"`$MA>F%K:'-T86X`2V5N>6$`2V5Y($QE;F=T:`!+97D@5'EP90!+
M97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T
M92X@($-O;G1I;G5E('=I=&@@:V5Y(&=E;F5R871I;VX_`$ME>2!I;7!O<G0@
M:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@
M;VX@=&AI<R!S97)V97(N`$ME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@
M66]U(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@
M8V]N=&%C=',N`$ME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`2VER:6)A=&D`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+
M>7)G>7IS=&%N`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E
M<'5B;&EC`$QA<W0@36%I;&)O>"!086=E`$QA<W0@4&%G90!,871V:6$`3&%Y
M;W5T`$QE8F%N;VX`3&5F=`!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N
M($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI;FL`3&EN:R!!='1A
M8VAM96YT<S\`3&EN:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B:61D96XN`$QI
M;FMS`$QI;FMS('=I;&P@97AP:7)E(&]N("5S`$QI<W0@86QL(&-O;G1A8W1S
M('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L
M960L('EO=2!W:6QL(&]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C
M:"!F;W(@97AP;&EC:71L>2D`3&ES=&EN9R!I;B!T:&4@2&5A9&5R`$QI=&AU
M86YI80!,;V%D:6YG+BXN`$QO8V%L($UA:6QB;W@Z`$QO8V%T:6]N`$QO9R!I
M;@!,;V<@:6X@=&\@)7,`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;W9E
M`$QO=P!,;W<@4')I;W)I='D`3&]W97-T`$QU>&5M8F]U<F<`34T`36%C86\`
M36%C:6YT;W-H($9I;&4`36%D86=A<V-A<@!-86EL`$UA:6P@4')E=FEE=W,`
M36%I;"!S97)V97(@='EP92!T;R!C;VYN96-T('1O.@!-86EL8F]X`$UA:6QB
M;W@@86YD($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,`36%L87=I`$UA;&%Y<VEA
M`$UA;&1I=F5S`$UA;&D`36%L=&$`36%R8V@`36%R9VEN`$UA<FL@06QL($UE
M<W-A9V5S(&EN($9O;&1E<B!A<R!3965N`$UA<FL@06QL($UE<W-A9V5S(&EN
M($9O;&1E<B!A<R!5;G-E96X`36%R:R!A<SH`36%R:R!D:69F97)E;G0@;&5V
M96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/P!-87)K(&UE
M<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI`$UA<FL@<VEM<&QE(&UA<FMU
M<#\`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H($%L;"!1=65R
M:65S`$UA=&-H($%N>2!1=65R>0!-875R:71A;FEA`$UA=7)I=&EU<P!-87AI
M;75M($%T=&%C:&UE;G0@4VEZ90!-87AI;75M($YU;6)E<B!O9B!&;VQD97)S
M`$UA>&EM=6T@3G5M8F5R(&]F(%)E8VEP:65N=',@<&5R($UE<W-A9V4`36%X
M:6UU;2!.=6UB97(@;V8@4F5C:7!I96YT<R!P97(@5&EM92!097)I;V0`36%X
M:6UU;2!N=6UB97(@;V8@871T86-H;65N=',@<F5A8VAE9"X`36%X:6UU;2!T
M;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE9"X`36%Y`$UA>6]T=&4`365M
M8F5R<P!-96YU($9O;&1E<B!,:7-T`$UE<W-A9V4`365S<V%G92!#;VUP;W-I
M=&EO;@!-97-S86=E($1A=&4`365S<V%G92!&;&%G<P!-97-S86=E($9O;&1E
M<G,`365S<V%G92!-871C:&5S`$UE<W-A9V4@3W!T:6]N<P!-97-S86=E(%-E
M87)C:`!-97-S86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!6:65W
M:6YG`$UE<W-A9V4@9G)O;2`E<P!-97-S86=E(&AA<R!A='1A8VAM96YT<P!-
M97-S86=E(&ES(&5N8W)Y<'1E9`!-97-S86=E(&ES('-I9VYE9`!-97-S86=E
M(')E9&ER96-T960@<W5C8V5S<V9U;&QY+@!-97-S86=E('-E;G0@<W5C8V5S
M<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S`$UE<W-A9V4@<V5N="!S=6-C
M97-S9G5L;'DN`$UE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I
M97<N`$UE<W-A9V5S('1O`$UE=&AO9`!-97AI8V\`36ED9&QE`$UI;64@5'EP
M90!-:7)R;W(`36ES8V5L;&%N96]U<P!-;V1I9GD`36]N86-O`$UO;F=O;&EA
M`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;W)E('1H86X@
M;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I96QD("(E<R(N`$UO<F]C8V\`36]V
M90!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E
M(&1O=VX`36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I
M;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6`!-;W9E('1O(&9O;&1E<@!-;W9E
M('5P`$UO>F%M8FEQ=64`375L=&EP87)T+V%L=&5R;F%T:79E`$UU;'1I<&QE
M($UE<W-A9V4@5FEE=P!->6%N;6%R`$Y/3D4`3D]410!.86UE`$YA;64@86YD
M+V]R(&5M86EL(&-A;FYO="!B92!E;7!T>0!.86UI8FEA`$YA=7)U`$YE961S
M($%C=&EO;@!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE
M<P!.971W;W)K`$YE=F5R`$YE=F5R('-A=F4@871T86-H;65N=',`3F5W`$YE
M=R!#86QE9&]N:6$`3F5W($9O;&1E<@!.97<@36%I;`!.97<@365S<V%G90!.
M97<@365S<V%G92!T;R`E<P!.97<@6F5A;&%N9`!.97<@;65S<V%G97,`3F5W
M('!A<W-W;W)D`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@365S<V%G90!.
M97AT(%!A9V4`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.
M;P!.;R!#97)T:69I8V%T92!F;W5N9`!.;R!%;F-R>7!T:6]N`$YO($ME>7,@
M:6X@2V5Y<FEN9P!.;R!-97-S86=E<P!.;R!01U`@<'5B;&EC(&ME>2!I;7!O
M<G1E9"X`3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N=`!.;R!0<F5V
M:65W(%1E>'0`3F\@4'5B;&EC($ME>7,@1F]U;F0`3F\@4R]-24U%('!U8FQI
M8R!K97D@:6UP;W)T960N`$YO(&%T=&%C:&UE;G1S(&9O=6YD+@!.;R!E;6%I
M;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+@!.;R!F
M;VQD97(@<V5L96-T960N`$YO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@
M9F]R(&YE=R!M86EL+@!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&9O
M;&1E<G,@=VET:"!N97<@;65S<V%G97,`3F\@9F]L9&5R<R!W:71H('5N<V5E
M;B!M97-S86=E<P!.;R!M97-S86=E(&)O9'D@=&5X=`!.;R!M97-S86=E(')E
M='5R;F5D+@!.;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H+@!.;R!P
M97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N`$YO('!E<G-O;F%L
M(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!3+TU)344@
M8V5R=&EF:6-A=&5S(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!P<FEV871E(&ME
M>2!E>&ES=',@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y
M<'1E9"X`3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N`$YO
M('-U9V=E<W1I;VYS`$YO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I8V%T:6]N
M(&UE=&AO9"!C;W5L9"!B92!F;W5N9"X`3F\@=7-E<B!S<&5C:69I960N`$YO
M;B!087)T:6-I<&%N=`!.;VYE`$YO<F9O;&L@27-L86YD`$YO<FUA;`!.;W)T
M:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!$96QE=&5D`$YO="!$
M<F%F=`!.;W0@26UP;W)T86YT`$YO="!097)S;VYA;`!.;W0@82!V86QI9"!P
M=6)L:6,@:V5Y+@!.;W0@870@86QL`$YO=&4@=&AA="!T:&ES(&-A;B!T86ME
M('-O;64@=&EM90!.;W1E<P!.;W1H:6YG`$YO=&EF:6-A=&EO;CH@3&EN:V5D
M(&%T=&%C:&UE;G0@9&]W;FQO861E9`!.;W9E;6)E<@!.=6UB97(`3G5M8F5R
M(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L
M:6YK960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R
M(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG
M(&UO;G1H;'DN`$]+`$]2`$]B:F5C=`!/8W1O8F5R`$]F9FEC90!/;&0@;65S
M<V%G97,`3VQD('!A<W-W;W)D`$]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN
M9R!P=7)G960N`$]M86X`3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E
M860@;65S<V%G97,@:6X@=&AE;3\`3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B
M92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I;VXN`$]P96X@1F]?;&1E<@!/<&5N
M(&EN(&$@;F5W('=I;F1O=P!/<&5N960@1F]L9&5R`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/=&AE<@!/=&AE<B!-
M86EL($%C8V]U;G1S`$]T:&5R($]P=&EO;G,`3W5T8F]U;F0@4V5R=F5R`%!'
M4`!01U`@16YC<GEP="!-97-S86=E`%!'4"!%<G)O<CH@`%!'4"!%<G)O<CH@
M3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4$=0
M($]P=&EO;G,`4$=0(%!A<W-P:')A<V4@26YP=70`4$=0(%!E<G-O;F%L($ME
M>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BX`4$=0(%!U8FQI8R!+97D@9F]R("(E<R`H)7,I(B!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D+@!01U`@4'5B;&EC($ME>2!F;W(@(B5S(B!W87,@<W5C8V5S
M<V9U;&QY(&1E;&5T960N`%!'4"!0=6)L:6,@2V5Y<FEN9P!01U`@4VEG;B!-
M97-S86=E`%!'4"!3:6=N+T5N8W)Y<'0@365S<V%G90!01U`@<')I=F%T92!K
M97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@<'5B;&EC(&ME>2!S=6-C97-S
M9G5L;'D@861D960N`%!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@
M<WES=&5M+@!01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O
M(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T
M;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES
M('-E='1I;F<@;W(@96QS92!T:&4@4$=0(&9E871U<F5S('=I;&P@;F]T('=O
M<FL@8V]R<F5C=&QY+@!03U`S`%!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L
M<RD`4$]0,R!O=F5R(%-33`!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C
M97)T:69I8V%T92D`4$]0,RP@;F\@5$Q3`%!A9&1I;F<`4&%G92`E9"!O9B`E
M9`!086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E`%!A9V4@=VET
M:"!T:&4@3&%S="!5;G-E96X@365S<V%G90!086MI<W1A;@!086QA=0!086YA
M;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T*',I`%!A<W-P:')A
M<V4`4&%S<W!H<F%S92`H06=A:6XI`%!A<W-P:')A<V4@<W5C8V5S<V9U;&QY
M('5N;&]A9&5D+@!087-S<&AR87-E.@!087-S<&AR87-E<R!C86YN;W0@8F4@
M96UP='D`4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H`%!A<W-W;W)D`%!A<W-W
M;W)D.@!087-T90!0871H`%!E;W!L90!097)C96YT`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N<P!097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R(&-A;FYO="!B92!C:&%N
M9V5D+@!097)S;VYA;`!097)S;VYA;"!);F9O<FUA=&EO;@!097)S;VYA;"!0
M1U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!097)S;VYA;"!0
M1U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2X`4&5R<V]N86P@4R]-24U%
M(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z(`!097)S;VYA;"!3+TU)344@
M:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2X`4&5R=0!0:&EL:7!P:6YE<P!0
M:&]N90!0:71C86ER;@!0:7AE;',`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F
M;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/P!0;&%I;G1E>'0@5F5R<VEO;B!O
M9B!-97-S86=E`%!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I
M<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D('-O=6YD(&9I
M;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O
M=&AE<B!P;&%T9F]R;7,@=VEL;"!R97%U:7)E(&$@<&QU9VEN+@!0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R
M('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE
M(&YE=R!N86UE.@!0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO
M=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@96YT
M97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN`%!L96%S
M92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T
M92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P
M:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BX`4&QE87-E(&QO9R!I;B!A9V%I
M;B!T;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R
M92!.3U0@=7-I;F<@8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S
M<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R!L;V<@
M:6X@86=A:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES
M('1O(&ME97`@871T86-K97)S(&9R;VT@:&EJ86-K:6YG('EO=7(@<V5S<VEO
M;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92X`4&QE
M87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"X`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92X`4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L
M:60@861D<F5S<V5S+@!0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y
M;W4@<&5R9F]R;2!T:&ES(&%C=&EO;BX`4&QE87-E('-E;&5C="!A="!L96%S
M="!O;F4@9F]L9&5R('1O('-E87)C:"X`4&QE87-E('-E;&5C="!O;FQY(&]N
M92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+@!0;&5A<V4@<V5L96-T(&]R
M(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z`%!O;&%N9`!0;W)T=6=A
M;`!0;W=E<F5D(&)Y($AO<F1E`%!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET
M:"!D87-H97,@*"<M+2`G*3\`4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P
M9&%T960N`%!R97-S=7)E`%!R979I97<`4')E=FEO=7,@365S<V%G90!0<F5V
M:6]U<R!086=E`%!R:6YT`%!R:6]R:71Y`%!R:79A=&4@2V5Y(%!A<W-W;W)D
M`%!R;VIE8W1S`%!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@
M<V5N=#L@9&5F875L="!T;R!.3P!0<F]M<'0@979E<GD@=&EM92!A;B!A='1A
M8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453`%!R;W1O8V]L.@!0=6)L
M:6,@2V5Y`%!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O<G0@:&%S(&)E96X@
M9&ES86)L960N`%!U97)T;R!2:6-O`%!U<E]G92!$96QE=&5D`%!U<F=E($1E
M;&5T960`4'5R9V4@1F]L9&5R*',I`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`
M4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI
M<R!A;6]U;G0@;V8@9&%Y<RX`4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4
M<F%S:"!F;VQD97(_`%!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F
M;VQD97(N`%!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+@!1
M871A<@!1=65R>0!1=6]T80!1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-
M0B`@*"4N,F8E)2D`475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5`!1
M=6]T82!S=&%T=7,Z($Y/($Q)34E4`%%U;W1I;F<@)68Z`%)E860`4F5B=6EL
M9"!&;VQD97(@5')E90!296-E:79E9"!/;@!296-E:79E9"!3:6YC90!296-E
M:79E9"!5;G1I;`!2961I<F5C7W0`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G
M90!2961I<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2
M969R97-H`%)E9G)E<V@@1F]L9&5R(%9I97=S.@!2969R97-H(')A=&4Z`%)E
M;&]A9`!296QO860@5FEE=P!296UA<FMS`%)E;65M8F5R('1H92!F<F5E+V)U
M<WD@:6YF;W)M871I;VXN`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E
M($UA:6QB;W@Z`%)E;6]V90!296UO=F4@1FEE;&0@1G)O;2!396%R8V@`4F5M
M;W9E('-O=7)C90!296YA;64@1F]L9&5R*',I`%)E;F%M92!S96YT+6UA:6P@
M9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`4F5N86UI;F<@(B5S(B!T
M;R`B)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!2
M97!L7WD@=&\@3&ES=`!297!L86-E('=I=&@Z`%)E<&QY`%)E<&QY(%-E;G0N
M`%)E<&QY('1O($%L;`!297!L>2!T;R!!;&PZ`%)E<&QY('1O($QI<W0`4F5P
M;'D@=&\@3&ES=#H`4F5P;'D@=&\@7T%L;`!297!L>2!W:71H($YO="!3=7!P
M;W)T960@365S<V%G90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R
M(&UO;G1H<RX`4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+@!297!L>2U4;P!297!L>2U4;SH@`%)E<&QY.@!297!O<G0@87,@
M26YN;V-E;G0`4F5P;W)T(&%S(%-P86T`4F5Q=65S="!A(%]296%D(%)E8V5I
M<'0`4F5Q=65S="!R96%D(')E8V5I<'1S/P!297%U97-T960@;65S<V%G92!N
M;W0@9F]U;F0N`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<W!O;F1E
M;G0@4W1A='5S(%5P9&%T960N`%)E<W5L=',`4F5S=6UE`%)E<W5M92!Y;W5R
M('-E<W-I;VX`4F5T=7)N('1O(")-97-S86=E($-O;7!O<VET:6]N(@!2971U
M<FX@=&\@1F5T8V@@36%I;`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@
M=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O
M<B!C;W!Y:6YG(&$@;65S<V%G93\`4F5U;FEO;@!2:6=H=`!2;VQE`%)O;6%N
M:6$`4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=W,Z`%)U;@!2=7-S:6%N
M($9E9&5R871I;VX`4G=A;F1A`%,O34E-10!3+TU)344@16YC<GEP="!-97-S
M86=E`%,O34E-12!%<G)O<CH@`%,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR
M87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4R]-24U%($]P=&EO;G,`
M4R]-24U%(%!A<W-P:')A<V4@26YP=70`4R]-24U%(%!E<G-O;F%L($ME>7!A
M:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`
M4R]-24U%(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+@!3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N
M`%,O34E-12!0=6)L:6,@2V5Y<FEN9P!3+TU)344@4'5B;&EC+U!R:79A=&4@
M2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N`%,O34E-12!3:6=N($UE<W-A
M9V4`4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E`%,O34E-12!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!3+TU)344@<W5P<&]R="!I
M<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA
M8FQE('1O(&)E(&1E8W)Y<'1E9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N
M86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@
M8V%N;F]T(&)E(&1I<W!L87EE9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N
M86)L960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B
M92!V97)I9FEE9"X`4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN
M9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L
M>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N
M9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%,O34E-12!F96%T=7)E<R!W
M:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`4TU44`!34T@`4U]U8FIE8W0`4V%?
M=F4@82!C;W!Y(&EN(`!385]V92!A<P!386EN="!(96QE;F$`4V%I;G0@2VET
M=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M;V$`
M4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%U9&D@07)A8FEA
M`%-A=F4`4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM
M86EL(&9O;&1E<C\`4V%V92!$<F%F=`!3879E($EM86=E`%-A=F4@26UA9V4@
M:6X@1V%L;&5R>0!3879E($]P=&EO;G,`4V%V92!3=&%T:6]N97)Y`%-A=F4@
M7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@87,@=6YS965N/P!3879E(&1R
M869T<R!A=71O;6%T:6-A;&QY('=H:6QE(&-O;7!O<VEN9S\`4V%V92!R96-I
M<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S<R!B
M;V]K/P!3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/P!3879E('-E
M;G0@;6%I;#\`4V%V:6YG('1H92!D<F%F="!F86EL960N($-O=6QD(&YO="!C
M<F5A=&4@82!D<F%F=',@9F]L9&5R+@!3879I;F<@=&AE(&1R869T(&9A:6QE
M9"X@3F\@9')A9G0@9F]L9&5R('-P96-I9FEE9"X`4V%V:6YG('1H92!D<F%F
M="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%-E
M87)C:`!396%R8V@@)7,`4V5A<F-H($5N9VEN97,`4V5A<F-H($]P=&EO;G,`
M4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0@06YO=&AE<B!!8V-O=6YT`%-E
M;&5C="!A(&1A=&4`4V5L96-T(&$@9FEE;&0`4V5L96-T(&%D9')E<W,@8F]O
M:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S
M<V5S+@!396QE8W0@86QL`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W
M:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E
M;&5C="!N;VYE`%-E;&5C="!S=&%T:6]N97)Y.@!396QE8W0@=&AE(&=A;&QE
M<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN`%-E;&5C="!T:&4@;6%I;"!S97)V
M97(@='EP90!396QE8W0Z`%-E;&5C=&5D($%D9')E<W,@8F]O:W,Z`%-E;F0@
M2V5Y('1O(%!U8FQI8R!+97ES97)V97(`4V5N9"!,871E<W0@26YF;W)M871I
M;VX`4V5N9"!-97-S86=E`%-E;F0@;65S<V%G92!W:71H;W5T(&$@4W5B:F5C
M=#\`4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE('-E
M;F1E<C\`4V5N96=A;`!396YT(&UA:6P@9F]L9&5R`%-E;G0@;6%I;"!F;VQD
M97(Z`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU
M;6)E<@!397)V97(`4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VX`4V5R
M=F5R.@!397-S:6]N<P!3970`4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA
M<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+@!3970@
M=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S
M/P!3971U<`!397EC:&5L;&5S`%-H87)E($9O;&1E<G,`4VAA<F4@;6%I;"!F
M;VQD97)S`%-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E
M<G,N`%-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO
M=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92!T;V=G;&5D(&5A
M<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92X`4VAO=6QD('1H92!B;V1Y(&]F
M('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@4$=0(&1A=&$_
M`%-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A
M=FEN9R!A(&1R869T/P!3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B
M92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_`%-H;W<`
M4VAO=R!!;&P@1F]L9&5R<P!3:&]W($%L;"!(96%D97)S`%-H;W<@1&5L971E
M9`!3:&]W($EM86=E<S\`4VAO=R!,:6UI=&5D($AE861E<G,`4VAO=R!-86EL
M:6YG($QI<W0@26YF;W)M871I;VX`4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L
M9&5R<P!3:&]W(%5N<W5B<V-R:6)E9`!3:&]W(&%N(&EC;VX@=&\@86QL;W<@
M<W1R:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_`%-H;W<@
M;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_`%-H;W<@<')E=FEE=W,@9F]R
M('5N<F5A9"!M97-S86=E<R!O;FQY/P!3:&]W('!R979I97=S(&EN('1O;VQT
M:7!S/P!3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_
M`%-H;W<@=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/P!3:&]W('1O
M=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_`%-H;W=N`%-H<FEN:P!3
M:5]Z90!3:65R<F$@3&5O;F4`4VEG;F%T=7)E`%-I9VYE9`!3:6YG87!O<F4`
M4VEZ90!3:7IE.@!3;&]V86MI80!3;&]V96YI80!3;VQO;6]N($ES;&%N9',`
M4V]M86QI80!3;W)T(&)Y($%R<FEV86P`4V]R="!B>2!$871E`%-O<G0@8GD@
M1G)O;2!!9&1R97-S`%-O<G0@8GD@365S<V%G92!3:7IE`%-O<G0@8GD@4W5B
M:F5C=`!3;W)T(&)Y(%1H<F5A9`!3;W)T(&)Y(%1O($%D9')E<W,`4V]U=&@@
M069R:6-A`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)
M<VQA;F1S`%-P86-I;F<`4W!A:6X`4W!A;0!3<&%M(&9O;&1E<@!3<&%M(&9O
M;&1E<CH`4W!E8VEA;"!#:&%R86-T97)S`%-P96-I86P@5FER='5A;"!&;VQD
M97)S(&-A;FYO="!B92!E9&ET960N`%-P96QL($-H96-K`%-P96QL($-H96-K
M97(`4W!E;&P@8VAE8VL@8V]M<&QE=&4`4W!E;&P@8VAE8VL@8V]M<&QE=&4@
M+2!.;R!S<&5L;&EN9R!E<G)O<G,`4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E
M96X@=VAE;B!S<&5L;"!C:&5C:VEN9RX`4W)I($QA;FMA`%-T86YD87)D`%-T
M87)T`%-T871I;VYE<GD`4W1A=&EO;F5R>2!N86UE.@!3=&%T:6]N97)Y('1Y
M<&4Z`%-T871I;VYE<GDZ`%-T871U<P!3=')I:V5T:')O=6=H`%-T<FEP($%T
M=&%C:&UE;G0`4W1R:7`@;&EN96)R96%K<S\`4W5B7VIE8W0`4W5B:F5C=`!3
M=6)J96-T($9I96QD`%-U8FUI=`!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U
M8G-C<FEP=`!3=6-C97-S`%-U9&%N`%-U9V=E<W1I;VYS`%-U;6UA<GD`4W5P
M97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA
M>65N`%-W87II;&%N9`!3=V5D96X`4W=I=&-H($-O;7!O<VET:6]N($UE=&AO
M9`!3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO;@!3=VET8V@@=&\@<&QA:6X@
M=&5X="!C;VUP;W-I=&EO;@!3=VET>F5R;&%N9`!3>7)I86X@07)A8B!297!U
M8FQI8P!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`
M5&%I=V%N`%1A:FEK:7-T86X`5&%S:W,`5&5?>'0`5&5L97!H;VYE($YU;6)E
M<@!496UP97)A='5R90!496YT871I=F4Z(`!496YT871I=F5L>2!!8V-E<'0@
M<F5Q=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497)M<R!O9B!397)V:6-E
M(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<`!497AT`%1E>'0@3VYL
M>0!4:&%I;&%N9`!4:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H
M;W5L9"!B92!L:6YK960Z`%1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E
M87(@=&\@<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D('-E;&5C
M=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M+@!4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL`5&AE($UA8VEN=&]S:"!R
M97-O=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+@!4:&4@86-C;W5N
M="`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!A8V-O=6YT("(E<R(@:&%S
M(&)E96X@<V%V960N`%1H92!A='1A8VAM96YT('=A<R!N;W0@9F]U;F0N`%1H
M92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;7!O<V4@=VEN9&]W
M(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B
M<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!C;VYT96YT<R!O
M9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+@!4:&4@8W5R<F5N="!F
M;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M960@=&\@(B5S(BX`5&AE(&-U
M<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E
M<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D`%1H92!D<F%F="!H87,@8F5E;B!S
M879E9"!T;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E=F5N="!W87,@861D960@
M=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9I96QD("(E<R(@8V%N)W0@8F4@97AP
M86YD960N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L
M9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N
M86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A
M=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O
M;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S
M8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T
M960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B
M)7,B('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D
M+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4
M:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E
M<R(N`%1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES
M('!A<G0Z`%1H92!I;6%G92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE
M9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K
M('!O<'5P('=I;F1O=W,_`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE
M(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N
M97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.@!4
M:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G
M93H`5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2X`5&AE(&UE<W-A
M9V4@(B5S(B!F<F]M("(E<R(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I
M>F4@;&EM:70N`%1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N
M(&-L;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A9V4@9&]E<R!N;W0@:&%V92!A
M(%-U8FIE8W0@96YT97)E9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L971E
M9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@
M=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN`%1H92!M97-S86=E(&AA<R!B
M965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BX`5&AE(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2X`
M5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N`%1H92!M97-S86=E(&AA
M<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+@!4:&4@<&%S<W!H<F%S92!W
M:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y
M;W5R(&)R;W=S97(@=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\`5&AE(')E<75E
M<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C
M:&UE;G0N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T
M:&4@6FEP(&%T=&%C:&UE;G0N`%1H92!S96YD97(@;V8@=&AI<R!M97-S86=E
M(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;B!F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E
M+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@;F]T:69I8V%T:6]N(&UE
M<W-A9V4N`%1H92!S97)V97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H
M=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!4:&4@<VEG;F%T=7)E(&-O=6QD(&YO
M="!B92!R97!L86-E9"X`5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY
M(')E<&QA8V5D+@!4:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI<W0N
M`%1H92!S=&%T:6]N97)Y("(E<R(@:&%S(&)E96X@861D960N`%1H92!S=&%T
M:6]N97)Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-T871I;VYE<GD@
M(B5S(B!H87,@8F5E;B!U<&1A=&5D+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E
M9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G90!4
M:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@
M=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@
M<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O
M9B!T:&4@<V5N="!M97-S86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A
M9V4@8V%N(&)E('9I97=E9"`E<RX`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF
M;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE<F4@87)E(&YO
M(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N`%1H
M97)E(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@
M;65S<V%G97,@9G)O;2`B)7,B('1O("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A
M9V5S(&9R;VT@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@
M)7,N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I
M;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RX`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M
M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4
M:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R
M92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES(%!'4"!0
M=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92X`5&AI<R!A
M8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I;VX@:7,@;F]T('EE
M="!I;7!L96UE;G1E9"X`5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\`5&AI<R!M97-S86=E(&-O
M;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N`%1H:7,@;65S<V%G92!C;VYT86EN
M<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE
M9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H
M;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4:&ES
M(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M
M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F('1H:7,@;65S<V%G92!I<R!U;FMN
M;W=N+@!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@`%1H:7,@;65S<V%G
M92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O
M<FUA="`H86-C;W)D:6YG('1O(%)&0R`R,#$U*2X`5&AI<R!M97-S86=E(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R
M;6%T+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!A
M;F0@96YC<GEP=&5D('=I=&@@4$=0+"!B=70@=&AE('-I9VYA='5R92!C86YN
M;W0@8F4@=F5R:69I960N`%1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L
M;'D@<VEG;F5D(&%N9"!E;F-R>7!T960@=VET:"!01U`N`%1H:7,@;65S<V%G
M92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`L(&)U="!T:&4@
M<VEG;F%T=7)E(&-A;FYO="!B92!V97)I9FEE9"X`5&AI<R!M97-S86=E(&AA
M<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"X`5&AI<R!M97-S86=E
M(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`5&AI<R!M
M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4:&ES(&UE
M<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+"!H;W=E=F5R+"!0
M1U`@<W5P<&]R="!I<R!D:7-A8FQE9"!S;R!T:&4@;65S<V%G92!C86YN;W0@
M8F4@9&5C<GEP=&5D+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D
M('=I=&@@4$=0+"!H;W=E=F5R+"!N;R!P97)S;VYA;"!P<FEV871E(&ME>2!E
M>&ES=',@<V\@=&AE(&UE<W-A9V4@8V%N;F]T(&)E(&1E8W)Y<'1E9"X`5&AI
M<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"X`5&AI<R!M
M97-S86=E('1O`%1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@
M8V]M<&]S92!W:6YD;W<N`%1H<F5A9"!$:7-P;&%Y`%1H<F5A9"!6:65W`%1I
M;64`5&EM92!F;W)M870`5&ET;&4`5&\`5&\@061D<F5S<P!4;R!S96QE8W0@
M;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I('=H:6QE(&-L:6-K:6YG+@!4;R!U<V4@82!43%,@
M8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@;V8@
M4$A0(#4N,"XV(&]R(&AI9VAE<BX`5&]D87D`5&]G;P!4;VME;&%U`%1O;F=A
M`%1O<`!4;W1A;"!!='1A8VAM96YT<R!3:7IE.@!4<F%S:"!F;VQD97(`5')A
M<V@@9F]L9&5R.@!4<FEN:61A9"!A;F0@5&]B86=O`%1U;FES:6$`5'5R:V5Y
M`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',`5'5V86QU`%523`!54DPZ`%5G86YD80!5:W)A:6YE
M`%5N86)L92!T;R!R971R:65V92!Q=6]T80!5;F%N<W=E<F5D`%5N86YS=V5R
M960@;65S<V%G97,`56YD96QE=&4`56YD96QE=&5D(&UE<W-A9V5S`%5N9&5R
M;&EN90!5;F1I<V-L;W-E9"!296-I<&EE;G1S`%5N9FEL960`56YH86YD;&5D
M(&-O;7!O;F5N="!O9B!T>7!E.B`E<P!5;FEC;V1E("A55$8M."D`56YI;7!O
M<G1A;G0@;65S<V%G97,`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N($1A=&4`56YK;F]W
M;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O
M;F1E9#H@)7,`56YK;F]W;B!-965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N
M;&]A9"!087-S<&AR87-E`%5N;F%M960`56YS965N`%5N<W5B<V-R:6)E(&9R
M;VT@1F]L9&5R*',I`%5P9&%T90!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`
M57!L;V%D`%5P;&]A9#H`57)U9W5A>0!5<V4@1&5F875L="!686QU90!5<V4@
M24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\`57-E(%9I<G1U86P@5')A<V@@
M1F]L9&5R/P!5<V5R`%5S97(@(B5S(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE
M('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(BX`57-E<B!!
M9&UI;FES=')A=&EO;@!5<V5R;F%M90!5<V5R;F%M93H`57IB96MI<W1A;@!6
M86QI9&ET>0!686QU97,`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R
M<VEO;@!697)S:6]N($-O;G1R;VP`5FEE=P!6:65W("5S`%9I97<@)7,@4'5B
M;&EC($ME>0!6:65W($UE<W-A9V5S`%9I97<@4&5R<V]N86P@4')I=F%T92!+
M97D`5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y`%9I97<@5&AR96%D`%9I97<@
M5&AU;6)N86EL`%9I97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O
M=P!6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!E=F5N
M=`!6:65W(&UE<W-A9V5S(&EN("5S`%9I97<@;W(@;6%I;&)O>"!T;R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN.@!6:65W('1A<VL`5FEE=R!T:&ES($A434P@8V]N
M=&5N="!I;B!A('-E<&%R871E('=I;F1O=RX`5FER9VEN($ES;&%N9',L(%4N
M4RX`5FER='5A;"!&;VQD97(@(B5S(B!C<F5A=&5D('-U8V-E<V9U;&QY+@!6
M:7)T=6%L($9O;&1E<G,`5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E
M;"X`5FER='5A;"!)3D)/6`!6:7)T=6%L($E.0D]8($9O;&1E<@!6:7)T=6%L
M(%1R87-H`%9I<G1U86P@5')A<V@@1F]L9&5R`%9I<G1U86P@9F]L9&5R(&QA
M8F5L.@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E8@!796(@4VET90!7
M965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E<W1E<FX@4V%H87)A`%=H
M870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M(&]R(&EN;F]C96YT/P!7:&5N
M(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F
M;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@87,@9&5L971E9#\`5VAE
M;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A
M;G0@=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD
M('=E('-A=F4@871T86-H;65N="!D871A/P!7:&5N('-E;F1I;F<@;6%I;"!O
M<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@
M87!P96YD('1O('5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S
M<V5S('=I=&AO=70@(D`B*3\`5VAE<F4@9&\@>6]U('=A;G0@=&\@9&ES<&QA
M>2!L:6YK<R!T;R!A;'1E<FYA=&EV92!F;W)M871S(&]F(&$@;65S<V%G93\`
M5VAI=&5L:7-T`%=I9'1H`%=I9'1H.@!7:7-H;&ES=`!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!960!965E9`%EE87)L>0!996UE;@!997,`66]U(&%R92!A
M8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N
M="AS*3H`66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G
M97,@8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I+@!9;W4@
M87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F;VQL;W=I;F<@9F]L9&5R
M*',I+@!9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BX`
M66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@`%EO=2!A<F4@8W)E
M871I;F<@82!T;W`M;&5V96P@9F]L9&5R+@!9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!F;VQD97)S+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@9F]L9&5R<RX`66]U(&%R92!N;W0@86QL;W=E
M9"!T;R!S96YD(&UE<W-A9V5S('1O(&UO<F4@=&AA;B`E9"!R96-I<&EE;G1S
M('=I=&AI;B`E9"!H;W5R<RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!S96YD
M(&UE<W-A9V5S('1O(&UO<F4@=&AA;B`E9"!R96-I<&EE;G1S+@!9;W4@87)E
M(')E;F%M:6YG('1H92!F;VQD97(Z(`!9;W4@8V%N('5S92!T:&4@9F]L;&]W
M:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F
M;W(@=&AE(&-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I
M9VYA='5R92X`66]U(&-A;FYO="!U;G-U8G-C<FEB92!F<F]M("(E<R(N`%EO
M=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E
M;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@=&\@;&]G:6XN`%EO=2!D
M;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI
M<R!F;VQD97(`66]U(&9O<G=A<F1E9"!T:&ES(&UE<W-A9V4@;VX@)25S('1O
M('1H92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N`%EO=2!H879E("5S(&YE
M=R!M97-S86=E<RX`66]U(&AA=F4@,2!N97<@;65S<V%G92X`66]U(&AA=F4@
M86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E+@!9;W4@:&%V92!N97<@;6%I
M;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CH`66]U(&AA=F4@;F5W(&UA:6P@
M:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.@!9;W4@;75S="!E;G1E<B!A="!L
M96%S="!O;F4@<F5C:7!I96YT+@!9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H
M<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE
M<W-A9V4`66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@
M4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E`%EO=2!M
M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+@!9;W4@;75S="!S
M96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S96QE
M8W0@86X@861D<F5S<R!F:7)S="X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T
M(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I
M96YT+@!9;W4@;F5E9"!T;R!H879E("(E<R(@96YA8FQE9"!I;B!Y;W5R(&UA
M:6YT96YA;F-E(&]P=&EO;G,N`%EO=2!R961I<F5C=&5D('1H:7,@;65S<V%G
M92!T;R`E<R!O;B`E)7,N`%EO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O
M;B`E<RX`66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@(B5S(BX@2&5R92!I
M<R!W:&%T('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!N;W0@=6YS=6)S8W)I
M8F5D(&9R;VT@(B5S(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9
M;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R`B)7,B`%EO=2!W
M97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2`B)7,B`%EO=7(@
M3F%M90!9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES`%EO=7(@4')I=F%T
M92!+97D`66]U<B!0=6)L:6,@2V5Y`%EO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z
M(#QE;3XH;W!T:6]N86PI/"]E;3X`66]U<B!3+TU)344@4'5B;&EC+U!R:79A
M=&4@0V5R=&EF:6-A=&5S`%EO=7(@86-C;W5N=',Z`%EO=7(@86QI87,@861D
M<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@
M82!N97<@;&EN92D\+V5M/@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N`%EO=7(@9&5F
M875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U
M;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO
M=7(@;&EN:V5D(&%T=&%C:&UE;G0@:&%S(&)E96X@9&]W;FQO861E9"!B>2!A
M="!L96%S="!O;F4@=7-E<BX*"D%T=&%C:&UE;G0@;F%M93H@)7,*071T86-H
M;65N="!D871E.B`E<PH*0VQI8VL@;VX@=&AE(&9O;&QO=VEN9R!L:6YK('1O
M('!E<FUA;F5N=&QY(&1E;&5T92!T:&4@871T86-H;65N=#H*)7,`66]U<B!M
M97-S86=E('=A<R!S=6-C97-S9G5L;'D@9&5L:79E<F5D+@!9;W5R('-I9VYA
M='5R93H`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6TAI9&4@
M061D<F5S<V5S70!;3F\@4W5B:F5C=%T`6U-H;W<@061D<F5S<V5S("T`6U-H
M;W<@861D<F5S<V5S("T@)7,@<F5C:7!I96YT<UT`7T)C8P!?0FQA8VML:7-T
M`%]#8P!?1&5L971E`%]&;VQD97)S`%])9&5N=&ET>0!?26YB;W@`7TQO9R!O
M=70`7TUE<W-A9V4@4V]U<F-E`%].97<@365S<V%G90!?4')I;G0`7U!R:6]R
M:71Y`%]2969R97-H("5S`%]297!L>0!?4V5A<F-H`%]396YD($UE<W-A9V4`
M7U1H<F5A9`!?5&\`7U5N9&5L971E`%]6:65W(%1H<F5A9`!?5VAI=&5L:7-T
M`&%D9')E<W-E92!U;FMN;W=N`&%T=&%C:&UE;G0`871T86-H;65N=',N>FEP
M`&)Y=&5S`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@
M:6YP=70`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!E;G1R>2!N;W0@9F]U;F0`9G)O;0!H:`!H;W-T(&YA;64@=6YK
M;F]W;@!I;@!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@
M97)R;W(`:6YT;R!F;VQD97(`:V5Y`&UA:6QB;W@@9FEL90!M;0!N86UE`&YO
M;F4`;W(`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E8VEP:65N='-=`')E
M;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!S97)V:6-E('5N879A:6QA8FQE`'-P
M96QL:6YG(&5R<F]R`'-P96QL:6YG(&5R<F]R<P!S<P!S>7-T96T@97)R;W(`
M=&5M<&]R87)Y(&9A:6QU<F4`=6YK;F]W;B!E<G)O<@!U;FYA;65D`'9#87)D
M`'EO=7(@8FQA8VML:7-T`'EO=7(@=VAI=&5L:7-T`%!R;VIE8W0M260M5F5R
M<VEO;CH@24U0"E!/5"U#<F5A=&EO;BU$871E.B`R,#`T+3$R+3`X(#$P.C(X
M*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-BTQ-2`Q,3HU,RLP-S`P
M"DQA<W0M5')A;G-L871O<CH@3&5A;F<@0VAU;7-O8F5N(#QS;V)E;D!K:&UE
M<F]S+FEN9F\^"DQA;F=U86=E+51E86TZ($MH;65R(#QS=7!P;W)T0&MH;65R
M;W,N:6YF;SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/75T9BTX"D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:70*`"`@("`@(.&>A>&>F.&?DN&>F^&>A,*@X9^6(``@("`@("#A
MGI'AGX7"H.&?EB``("`@(.&>@.&>MN&>F^&>E.&>FN&>M^&>A>&?DN&>AN&?
M@>&>D<*@X9^6(``@("`@X9Z6X9ZXPJ#AGY8@`"`H)7,@X9Z0X9^2X9Z$X9^#
MXH"+X9Z`X9Z3X9^2X9Z;X9Z$XH"+X9Z1X9^%*0`HX9Z"X9^2X9Z:X9ZVX9Z4
MX9^+XH"+X9Z%X9Z[X9Z%XH"+X9Z5X9^2X9Z;X9Z\X9Z<XH"+X9Z`X9ZVX9Z/
MX9^+("5S*0`@*.&>D.&?DN&>A.&?@^*`B^&>D^&?@>&?ARD`("CAGI#AGY+A
MGH3AGX/B@(OAGI_AGY+AGJ+AGX+AGH`I`"`HX9Z8X9^2X9Z?X9ZWX9Z;X9Z8
MX9^)X9ZWX9Z)*0`@X9Z4X9^2X9Z:X9Z2X9ZVX9Z3X9Z4X9Z1PJ#AGY8@`"!;
M(.&>FN&>@.&?DN&>G^&>MN&>D>&>N^&>@.*`B^&>@.&>O.&>D^&>G^&?A.*`
MB^&>D>&?A>*`B^&>G^&?@.&>G.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?
MDN&>B^&>MN&>D^*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@"!=(``@
M6R#AGICAGK[AGIOB@(OAGH+AGY+AGIKAGK;AGI3AGXOAGH7AGKOAGH7B@(OA
MGHKAGK[AGICAGX4@72``(B5S(B#AGICAGK?AGI/B@(OAGICAGX+AGI/B@(OA
MGH?AGK;B@(OAGI#AGH_B@(OAGJ'AGK[AGIG"H.&?E``B)7,B(.&>F.&>M^&>
MD^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>A^&>F.&?DN&>FN&>ON&>G^*`
MB^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>H>&>ON&>F<*@
MX9^4`",`)60@)7,@X9Z3X9ZWX9Z$("5S`.&>G^&>MN&>FN*`B^&>A>&?AN&>
MD^&>O>&>DR`E9`#AGI_AGK;AGIKB@(OAGH7AGX;AGI/AGKWAGI,@)60@X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4PJ#AGY0`X9Z?
MX9ZVX9Z:("5D(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>FN&>
MMN&>F>*`B^&>@.&>MN&>FN&>CN&?C>*`B^&>D>&?A>*`B^&>@.&>MN&>D^&?
MB^*`B^&>HN&?DN&>D^&>@.*`B^&>@N&?DN&>FN&>E.&?B^*`B^&>@N&?DN&>
MFN&>A.*`B^&>E.&?DN&>FN&>EN&?D.&>D^&?DN&>DN*`B^&>FN&>E.&>G^&?
MB^*`B^&>HN&?DN&>D^&>@.*`B^&>D.&>MN*`B^&>F.&>M^&>D^*`B^&>F.&?
M@N&>D^*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>
MMN&>FL*@X9^4`.&>G^&>MN&>FB`E9"#AGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGIKAGK;AGIGB@(OAGH#AGK;AGIKAGH[AGXWB@(OAGI#AGK;B
M@(OAGICAGK?AGI/B@(OAGICAGX+AGI/B@(OAGI_AGK;AGIKB@(OAGJ7AGH_B
M@(OAGI3AGK;AGI/B@(OAGH#AGK;AGIK"H.&?E`#AGI_AGK;AGIH@)60@X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z:X9ZVX9Z9XH"+X9Z`X9ZV
MX9Z:X9Z.X9^-XH"+X9Z1X9^%XH"+X9Z`X9ZVX9Z3X9^+XH"+X9ZBX9^2X9Z3
MX9Z`XH"+X9Z"X9^2X9Z:X9Z4X9^+XH"+X9Z"X9^2X9Z:X9Z$XH"+X9Z4X9^2
MX9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3
MX9Z`XH"+X9Z0X9ZVXH"+XH"+X9Z'X9ZVXH"+XH"+X9Z?X9ZVX9Z:XH"+X9ZE
MX9Z/XH"+X9Z4X9ZVX9Z3X9Z`X9ZVX9Z:`.&>G^&>MN&>FB`E9"#AGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIKAGK;AGIGB@(OAGH#AGK;AGIKA
MGH[AGXWB@(OAGI#AGK;B@(OAGH?AGK;B@(OAGI_AGK;AGIKB@(OAGJ7AGH_B
M@(OAGI3AGK;AGI/B@(OAGH#AGK;AGIK"H.&?E``E9"#AGHKAGIOAGXL@)60@
MX9Z3X9^#XH"+X9Z?X9ZVX9Z:("5D`.&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?
MDN&>A^&>MN&>E.&?B^*`B^&>A>&?AN&>D^&>O>&>DR`E<RP@)7,`)7,@2T(`
M)7,@X9Z8X9^!X9Z`X9ZVX9Z4X9^#`"5S(.&>F.&>MN&>D^*`B^&>FN&>O>&>
MA>*`B^&>H.&>ON&>F<*@X9^4(.&>D.&>CR`E<R#AGIKAGI3AGI_AGXOB@(OA
MGJ+AGY+AGI/AGH#B@(OAGICAGK?AGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGI3AGK;AGI/B@(OAGI3AGY+AGH_AGKSAGIKB@(OAGHCAGY+AGICAGX3AGX?B
M@(OAGJ'AGK[AGIG"H.&?E``E<R#AGI3AGX,`)7,@X9Z1X9^&X9Z3X9Z$XH"+
MX9Z'X9ZVXH"+X9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/
MX9^2X9Z:XH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:
MX9Z\X9Z<PJ#AGY0`X9Z0X9Z/("5S(.&>D^&>N>&>A.*`B^*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>B.&?
MDN&>F.&?A.&?A^*`BR#AGI/AGX7B@(OAGI;AGX'AGIOB@(OAGH7AGK;AGI3A
MGXOB@(OAGI7AGY+AGH_AGK[AGICB@(OAGI/AGX/B@(OAGH'AGX+"H.&?E``E
M<R#AGI3AGK;AGI/B@(OAGI'AGI'AGKWAGIO"H.&?E``E<R#AGI3AGK;AGI/B
M@(OAGI3AGX3AGX?AGI3AGH3AGXL@(B5S(L*@X9^4`"5S(.&>E.&>MN&>D^*`
MB^&>E.&>BN&>M^&>G^&?@>&>DL*@X9^4`"5S(.&>E.&>MN&>D^*`B^&>AN&?
MDN&>F^&>ON&>F>*`B^&>C^&>E.*`B^&>D>&?A>*`B^&>D^&>N>&>A.*`B^&>
MG^&?AN&>CN&>OB#AGI'AGX;AGI/AGX'AGIHOX9Z:X9Z<X9Z;X9^+(.&>F.&>
MO>&>F<*@X9^4`"5S(.&>E.&>MN&>D^*`B^&>AN&?DN&>F^&>ON&>F>&>C^&>
ME.*`B^&>D>&?A>*`B^&>G^&?@>&>A>&>@.&?DN&>BN&>N.*`B^&>HN&>B>&?
MDN&>A^&>ON&>B>*`B^&>D>&?A>*`B^&>@.&>MN&>D^&?BR`B)7,BPJ#AGY0`
M)7,@X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z)X9Z^XH"+X9ZRX9^2X9Z9XH"+X9ZB
MX9^2X9Z3X9Z`XH"+X9Z3X9Z\X9Z<XH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3
M(.&>D>&?AN&>D^&?@>&>FB_AGIKAGISAGIOAGXO"H.&?E``E<R#AGI3AGK;A
MGI/B@(OAGI'AGI'AGKWAGIOB@(OAGH?AGK;B@(OAGI3AGH[AGY+AGH_AGX3A
MGX?B@(OAGJ+AGK;AGI_AGI/AGY+AGI/"H.&?E``E<R#AGI_AGY+AGI/AGK[B
M@(OAGI_AGKOAGX;B@(OAGI;AGY#AGH_AGXSAGICAGK;AGI/B@(L@X9Z1X9^&
MX9Z3X9^!X9Z:+^&>FN&>G.&>F^&?B^*`BR#AGIKAGI3AGI_AGXOB@(OAGJ+A
MGY+AGI/AGH#"H.&?E``E<R#AGI_AGKOAGX;B@(OAGK+AGY+AGIGB@(OAGJ+A
MGY+AGI/AGH#B@(OAGICAGK;AGI/B@(OAGISAGH_AGY+AGH_AGICAGK;AGI/B
M@(OAGI/AGX4@(B5S(L*@X9^4`"5S(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>E.&>D^&?DN&>D.&?@N&>F.*`B^&>BN&?A.&>F>*`B^&>A^&?
MA.&>@N&>A^&?D.&>F>*`B^&>D>&?A>*`B^&>@.&>MN&>D^&?BR`B)7,BPJ#A
MGY0`)7,@X9Z%X9Z$X9^+XH"+X9ZRX9^2X9Z9(&%M;65N9"`B)7,BPJ#AGY0`
M)7,@X9Z%X9Z$X9^+XH"+X9ZRX9^2X9Z9XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z*
MX9ZYX9Z$XH"+X9ZBX9^&X9Z6X9ZX("(E<R+"H.&?E``E<R#AGH7AGH3AGXOB
M@(OAGI'AGI'AGKWAGIOB@(OAGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGH7A
MGKOAGH3AGH#AGY+AGIKAGX3AGIGB@(OAGI3AGX;AGI7AGKOAGH_B@(OAGJ+A
MGX;AGI;AGK@@(B5S(L*@X9^4`"5SPJ#AGY8@)7,`)7/"H.&?EB`E<R`H)60F
M;F)S<#MO9B9N8G-P.R5D*0`HX9ZBX9Z3X9Z[X9Z<X9Z/X9^2X9Z/XH"+X9Z`
MX9ZVX9Z:XH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z4X9^2X9Z/X9Z\X9Z:
MXH"+X9Z1X9ZVX9^&X9Z$XH"+X9Z3X9^!X9^'(.&>D^&>M^&>A"#AGI7AGY+A
MGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGI'AGX7B@(OAGH#AGK;AGI/AGXOB
M@(OAGJ+AGX'AGH#AGY+AGIKAGH3AGXOB@(OAGI3AGI/AGY+AGI'AGK;AGI3A
MGXO"H.&?E"D`*.&>E.&?A.&?A^&>A>&?A.&>F^*`B^&>@.&>MN&>FN*`B^&>
ME>&?DN&>F^&>MN&>G^&?B^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>D>&>MN&?
MAN&>A.&>HN&>G^&?BR#AGI/AGK?AGH0@X9Z/X9^2X9Z:X9ZAX9Z4X9^+XH"+
MX9Z1X9^%XH"+X9Z`X9ZVX9Z3X9^+XH"+X9ZBX9^!X9Z`X9^2X9Z:X9Z$X9^+
MXH"+XH"+X9Z/X9^"X9Z$PJ#AGY0I`"A(5$U,*0`HX9ZBX9Z/X9^2X9Z0X9Z4
MX9Z1XH"+X9Z2X9Z8X9^2X9Z8X9Z/X9ZV*0#AGH_AGY+AGIKAGJ'AGI3AGXOB
M@(OAGI'AGX7B@(OAGJ+AGX'AGH#AGY+AGIKAGH3AGXOB@(OAGH_AGX+AGH0@
MX9Z4X9Z3X9^2X9Z1X9ZVX9Z4X9^+XH"+X9Z6X9ZXXH"+X9ZBX9Z3X9Z[X9Z<
MX9Z/X9^2X9Z/XH"+X9Z`X9ZVX9Z:XH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+
MX9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1X9ZVX9^&X9Z$XH"+X9ZBX9Z?X9^+X9Z*
MX9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z2X9^2X9Z<X9Z^XH"+XH"+XH"+X9Z:
MX9Z@X9Z\X9Z/XH"+X9Z*X9Z;X9^+XH"+X9Z6X9^!X9Z;XH"+X9Z3X9^!X9^'
MPJ#AGY0@X9Z`X9ZVX9Z:XH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z4X9^2
MX9Z/X9Z\X9Z:XH"+X9Z;X9Z^XH"+X9ZBX9^!X9Z`X9^2X9Z:X9Z$X9^+XH"+
MX9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2X9Z4X9Z3X9^2X9Z3(.&>D^&>N>&>A.*`
MB^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
MHN&>D^&>N^&>G.&>C^&?DN&>C^*`B^&>H>&>ON&>F<*@X9^4`.&>E>&?DN&>
MB>&>ON*`B^&>G^&>MN&>FB#AGI3AGI/AGY+AGI'AGK;AGI3AGXOB@(OAGI;A
MGKCAGJ+AGI/AGKOAGISAGH_AGY+AGH_B@(OAGH#AGK;AGIKB@(OAGI7AGY+A
MGIOAGK;AGI_AGXOB@(OAGI3AGY+AGH_AGKSAGIKB@(OAGI'AGK;AGX;AGH3A
MGJ+AGI_AGXOB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISA
MGK[B@(OAGIKAGJ#AGKSAGH_B@(OAGHKAGIOAGXOB@(OAGI;AGX'AGIOB@(OA
MGI/AGX'AGX?"H.&?E"#AGH#AGK;AGIKB@(OAGI7AGY+AGIOAGK;AGI_AGXOA
MGI3AGY+AGH_AGKSAGIKB@(OAGIOAGK[B@(OAGJ+AGX'AGH#AGY+AGIKAGH3A
MGXOB@(OAGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+AGI,@X9Z3X9ZY
MX9Z$XH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3
MXH"+X9ZBX9Z3X9Z[X9Z<X9Z/X9^2X9Z/XH"+X9ZAX9Z^X9Z9PJ#AGY0`*B#A
MGI3AGI/AGY+AGI#AGX+AGICB@(OAGI'AGK;AGX;AGH3B@(OAGI/AGX'AGX<@
MX9Z*X9^$X9Z9XH"+X9Z%X9Z[X9Z%XH"+X9Z9X9Z;X9^+X9Z6X9^2X9Z:X9Z8
M("H`*B#AGI_AGKSAGICB@(OAGH?AGY+AGIKAGK[AGI_B@(OAGJ+AGK;AGI_A
MGIGAGHKAGY+AGHOAGK;AGI,@*@`M+2#AGH?AGY+AGIKAGK[AGI\@+2T`X9ZO
MX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z%X9^&X9Z3
MX9Z]X9Z3(.&?H2P@)7,`X9^AX9^@X9^@(.&>C^&>O>*`B^&>HN&>@.&?DN&>
MG^&>F@#AGZ'AGZ#AGZ#AGZ`@X9Z/X9Z]XH"+X9ZBX9Z`X9^2X9Z?X9Z:`.&>
MD>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F2#AGZ'AGZ(@X9Z8X9^)X9^$
MX9Z$`.&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F2#AGZ+AGZ0@X9Z8
MX9^)X9^$X9Z$`.&?HN&?I"#AGICAGXGAGX3AGH0`X9^BX9^EX9^@(.&>C^&>
MO>*`B^&>HN&>@.&?DN&>G^&>F@#AGZ7AGZ#AGZ`@X9Z/X9Z]XH"+X9ZBX9Z`
MX9^2X9Z?X9Z:`#SAGICAGKOAGI,`X9Z:X9Z\X9Z4X9Z7X9ZVX9Z6XH"+X9Z2
MX9^&XH"+X9Z8X9Z]X9Z9XH"+X9Z*X9^"X9Z;XH"+X9Z8X9ZVX9Z3XH"+X9Z(
MX9^2X9Z8X9^$X9^'("5S(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^&>
ME^&?DN&>A^&>MN&>E.&?B^*`B^*`B^&>A^&>MN&>F.&>O>&>F>*`B^*`B^&>
MG^&>MN&>FN*`B^&>D^&?@>&?A\*@X9^4`.&>G^&>MN&>FN*`B^&>F.&>O>&>
MF>*`B^&>BN&?@N&>F^*`B^&>HN&?DN&>D^&>@.*`B^&>E.&>MN&>D^*`B^&>
ME>&?DN&>B>&>OB#AGI3AGK;AGI/B@(OAGI7AGY+AGH_AGIOAGXOB@(OAGIOA
MGI'AGY+AGI+AGI7AGIOB@(OAGH?AGK;B@(OAGH#AGK;AGIKB@(OAGH?AGKSA
MGI/AGHKAGX;AGH[AGKGAGH3B@(OAGH_AGY+AGIKAGJ'AGI3AGXOB@(OAGICA
MGKWAGID@XH"+X9Z6X9ZXXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;
MPJ#AGY0`X9Z3X9ZWX9Z$`.&>HN&?AN&>EN&>N.*`BRXN+@#AGH'AGK;AGH3B
M@(OAGIOAGK[B@(OAGJ+AGH_AGY+AGI#AGI3AGI'B@(OAGI_AGK;AGIH`X9Z6
MX9^2X9Z:X9Z8XH"+X9Z1X9Z1X9Z]X9Z;(.&>H.&>ON&>F>*`B^&>E.&>D^&?
MDN&>D.&?@N&>F.*`B^&>D>&?A>*`B^&>E.&?DN&>FN&>C^&>M^&>D>&>M^&>
MD^*`B^&>FN&>E.&>G^&?B^*`B^&>@>&?DN&>B>&>N^&?A@#AGI;AGY+AGIKA
MGICB@(OB@(OAGI'AGI'AGKWAGIOB@(OB@(OAGI_AGX;AGH[AGKX`X9Z4X9ZV
MX9Z3XH"+X9Z1X9Z1X9Z]X9Z;`.&>E.&>MN&>D^*`B^&>D>&>D>&>O>&>F\*@
MX9^6(`#AGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGJ+AGX;AGI;AGKCAGH+A
MGH[AGI/AGK@`X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z"X9Z.X9Z3X9ZXPJ#AGY8`
MX9ZBX9^&X9Z6X9Z^`.&>E.&>D^&?DN&>D.&?@N&>F`#AGI3AGI/AGY+AGI#A
MGX+AGI@@)7,@X9Z1X9^%XH"+X9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?
MX9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z!X9^2X9Z)
MX9Z[X9^&`.&>E.&>D^&?DN&>D.&?@N&>F.*`B^&>E.&?DN&>FN&>E^&>E@#A
MGI3AGI/AGY+AGI#AGX+AGICB@(OAGI/AGX'AGX?B@(OAGI'AGX7B@(OAGI3A
MGY+AGIKAGH_AGK?AGI'AGK?AGI/B@(OAGIKAGI3AGI_AGXOB@(OAGH'AGY+A
MGHGAGKOAGX8`X9Z4X9Z3X9^2X9Z0X9^"X9Z8XH"+X9Z1X9^%XH"+X9Z4X9^2
MX9Z:X9Z/X9ZWX9Z1X9ZWX9Z3XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z!X9^2X9Z)
MX9Z[X9^&`.&>E.&>D^&?DN&>D.&?@N&>F.*`B^*`B^*`B^&>HN&?DN&>D^&>
M@.*`B^&>E.&?DN&>FN&>O@#AGI3AGK;AGI/B@(OAGI3AGI/AGY+AGI#AGX+A
MGI@@(B5S(B#AGH?AGK;B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?A
MGK;AGI3AGXOB@(OAGICAGKWAGIG"H.&?E`#AGH#AGY+AGI3AGK;AGIOB@(OA
MGI3AGI/AGY+AGI#AGX+AGICB@(OAGI'AGX#AGH\@X9Z*X9^"X9Z;XH"+X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z3X9^%XH"+
MX9Z6X9^!X9Z;XH"+X9Z8X9Z^X9Z;PJ#AGY8@/&5M/BCAGI_AGY+AGIKAGX'A
MGH7B@(OAGH7AGK?AGH_AGY+AGH\@X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z`
MX9^2X9Z4X9ZVX9Z;XH"+X9Z3X9ZXX9Z8X9Z]X9Z9X9^7XH"+X9Z;X9Z^XH"+
MX9Z'X9Z]X9Z:XH"+X9Z0X9^2X9Z8X9ZX*3PO96T^`.&>EN&?D.&>C^&?C.&>
MF.&>MN&>D^*`B^&>E.&>D^&?DN&>D.&?@N&>F.*`B^&>HN&>MN&>A>*`B^&>
MC^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>F.&>ON&>F^*`BR`E<\*@
MX9^4`.&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^&>F^&>F.&?DN&>HN&>M^&>
MC^&>FN&>E.&>G^&?B^*`B^*`B^&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>
ME.&>D^&?DN&>D.&?@N&>F`#AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGIOA
MGICAGY+AGJ+AGK?AGH_B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OA
MGI3AGI/AGY+AGI#AGX+AGI@`X9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZXXH"+X9Z;
MX9Z8X9^2X9ZBX9ZWX9Z/XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+
MX9Z4X9Z3X9^2X9Z0X9^"X9Z8XH"+(.&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>F.&>ON&>F^*`BR`E<\*@X9^4`.&>G^&?
M@>&>A>&>@.&?DN&>C^&>N.*`B^&>F^&>F.&?DN&>HN&>M^&>C^*`B^&>HN&?
MAN&>EN&>N.*`B^&>@.&?AN&>H.&>N^&>G^*`B^&>FN&>E.&>G^&?B^*`B^&>
MG^&>MN&>FN*`B^&>E.&>D^&?DN&>D.&?@N&>F`#AGI_AGX'AGH7AGH#AGY+A
MGH_AGKCB@(OAGIOAGICAGY+AGJ+AGK?AGH_B@(OAGJ+AGX;AGI;AGKCB@(OA
MGH#AGX;AGJ#AGKOAGI_B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OA
MGI3AGI/AGY+AGI#AGX+AGI@@X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z8X9Z^X9Z;XH"+XH"+("5S(.*`B^&?E`#AGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,`X9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZB
MX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3`.&>G^&?@.&>G.&>E^&?A>*`B^&>
MHN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DP#AGJ+AGK;AGI_AGIGAGHKAGY+A
MGHOAGK;AGI/B@(OAGHKAGX+AGIOB@(OAGH_AGY+AGIKAGKSAGISB@(OAGIOA
MGK;AGH#AGXOB@(OAGI_AGK;AGIKB@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXO"
MH.&?EB`\96T^*.&>G^&?DN&>FN&?@>&>A>*`B^&>A>&>M^&>C^&?DN&>CRP@
MX9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZV
MX9Z3XH"+X9Z3X9ZXX9Z8X9Z]X9Z9X9^7XH"+X9Z;X9Z^XH"+X9Z'X9Z]X9Z:
MXH"+X9Z0X9^2X9Z8X9ZX*3PO96T^`.&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>
MMN&>D^*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>A>&>A.*`
MB^&>A^&>MN&>@.&?B^&>F^&>MN&>@.&?B^*`B^&>D^&>N>&>A.*`B^&>HN&>
MC^&?DN&>C^&>G^&>B>&?DN&>B>&>MN&>CN*`B^&>D^&?@>&?A\*@X9^6(#QE
M;3XHX9Z?X9^2X9Z:X9^!X9Z%XH"+X9Z%X9ZWX9Z/X9^2X9Z/+"#AGI3AGHGA
MGY+AGH7AGKSAGIOB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OA
MGI/AGKCAGICAGKWAGIGAGY?B@(OAGIOAGK[B@(OAGH?AGKWAGIKB@(OAGI#A
MGY+AGICAGK@I/"]E;3X`X9Z`X9ZVX9Z:XH"+X9Z"X9^2X9Z:X9Z4X9^+XH"+
MX9Z"X9^2X9Z:X9Z$`.&>HN&>MN&>H.&?DN&>@N&>MN&>D^&>N.&>G^&?DN&>
MD.&>MN&>DP#AGJ+AGK;AGIOAGXOAGI3AGK;AGI/AGK@`X9ZBX9ZVX9Z;X9^+
MX9Z@X9^2X9Z?X9^!X9Z:X9ZX`.&>B.&?DN&>F.&?A.&?A^*`B^&>@.&?DN&>
MF^&?@N&>A.&>@.&?DN&>F^&>MN&>F0#AGH_AGICAGY+AGIKAGKGAGI@`X9Z1
MX9ZVX9^&X9Z$X9ZBX9Z?X9^+`.&>G^&>MN&>FN*`B^&>D>&>MN&?AN&>A.*`
MB^&>HN&>G^&?B^*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>D.&>C^*`B^&>@>&>
MMN&>A.&>@.&?DN&>FN&?A.&>F"#AGI/AGKGAGH3B@(OAGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGI'AGK;AGHGB@(OAGIGAGH#AGHKAGX3AGIGB
M@(OAGHKAGK;AGH#AGXOB@(OAGI'AGX7AGH#AGY+AGI/AGKOAGH3B@(OAGJ_A
MGH#AGI_AGK;AGIH@34)/6"#AGICAGKWAGIG"H.&?E`#AGI_AGK;AGIKB@(OA
MGI'AGK;AGX;AGH3AGJ+AGI_AGXOB@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI#A
MGH\@(B5S(B#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`@X9Z*X9^"X9Z;
MXH"+X9Z%X9ZVX9Z?X9^+XH"+X9Z'X9ZVX9Z$("5S(.&>D.&?DN&>A.&?@R#A
MGI/AGKGAGH3B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIOA
MGKOAGI3B@(OAGH7AGX3AGIOB@(OAGH?AGK;B@(OAGJ+AGH7AGK?AGI/AGY+A
MGH_AGY+AGIKAGX/AGIGAGXW"H.&?E`#AGJ_AGH#AGI_AGK;AGIKB@(OAGI?A
MGY+AGH?AGK;AGI3AGXOB@(OAGH7AGK;AGI_AGXOB@(OAGI'AGK;AGX;AGH3B
M@(OAGJ+AGI_AGXOB@(OAGHKAGX+AGIOB@(OAGH7AGK;AGI_AGXOB@(OAGH?A
MGK;AGH0@)7,@X9Z!X9^"(.&>D^&>N>&>A.*`B^&>C^&?DN&>FN&>O.&>G.*`
MB^&>E.&>MN&>D^*`B^&>F^&>N^&>E.*`B\*@X9^4`.&>D.&>C^*`B^&>G^&?
MAN&>E.&>N^&>C^&?DN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>
ME>&?DN&>B>&>ON&>D>&>MN&?AN&>A.*`B^&>HN&>G^&?BR#AGHKAGX+AGIOB
M@(OAGH7AGK;AGI_AGXOB@(OAGH?AGK;AGH0@)7,@X9Z!X9^"(.&>D^&>N>&>
MA.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>F^&>N^&>E,*@
MX9^4`.&>G^&>M^&>D>&?DN&>DN&>M^*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?
MB^*`B^&>D^&?A>*`B^&>F^&>ON*`B^&>D.&>CR`B)7,B(.&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>F>&>@.*`B^&>A>&?@>&>B>*`B^&>BN&?
MA.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F>*`B^&>G^&>F.&?DN&>FN&>MN&>
ME.&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OB`B)7,BPJ#AGY0`
MX9ZBX9Z3X9Z[X9Z)X9^2X9Z)X9ZVX9Z/XH"+X9ZRX9^2X9Z9XH"+X9Z4X9Z$
MX9^2X9Z`X9Z^X9Z/XH"+X9Z0X9Z/PJ`_`.&>HN&>D^&>N^&>B>&?DN&>B>&>
MMN&>C^*`B^&>LN&?DN&>F>*`B^&>HN&>D^&>N^&>G.&>C^&?DN&>C^*`B^&>
M@.&?DN&>E.&>O>&>D^*`B^&>C^&>F.&?DN&>FN&>A.*`B^&>@.&?DN&>D^&>
MN^&>A.*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?
MDN&>FN*`B^&>CN&>MN&>F.&>O>&>F>*`B^&>K.*`B^&>D>&?@<*@/P#AGI3A
MGY+AGHKAGKSAGIKB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OA
MGJ+AGXKAGKCAGICAGX+AGIL`X9Z5X9^2X9Z3X9^"X9Z`XH"+X9Z3X9^#XH"+
MX9Z'X9Z8X9^2X9Z:X9Z^X9Z?(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>
ME^&>MN&>@N*`B^&>D^&?@>&?A\*@X9^6`.&>A^&>MN&>D^&>M^&>A>&?DN&>
MA0#AGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGJ_AGH#AGI_AGK;A
MGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGH?AGK;AGI/AGK?AGH7AGY+A
MGH4`X9Z?X9ZVX9Z8X9Z\X9ZBX9ZV(.&>HN&>MN&>F.&?@>&>FN&>M^&>@`#A
MGH#AGX;AGJ#AGKOAGI_B@(OAGICAGKWAGIGB@(OAGI3AGK;AGI/B@(OAGH#A
MGK[AGH_B@(OAGJ'AGK[AGH0@X9Z!X9Z.X9^(X9Z6X9^!X9Z;XH"+X9Z4X9^)
MX9Z[X9Z3X9Z4X9^)X9Z$XH"+X9Z%X9^2X9Z4X9Z]X9Z/XH"+X9ZOX9Z`X9Z?
MX9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z%X9^!X9Z)PJ#AGY0@
MX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^($E-05`@
MX9Z4X9ZVX9Z3XH"+X9Z3X9ZWX9Z9X9ZVX9Z9PJ#AGY8`X9Z`X9^&X9Z@X9Z[
MX9Z?XH"+X9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z8X9Z]
MX9Z9XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9Z^X9Z/X9ZAX9Z^X9Z$(.&>@>&>CN&?
MB.*`B^&>EN&?@>&>F^*`B^&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>A>&?AN&>
MCN&>MN&?AN*`B^&>D.&?DN&>F.&>N,*@X9^4`.&>@.&?AN&>H.&>N^&>G^*`
MB^&>BN&?@N&>F^*`B^&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?B^*`
MB^&>F.&>O>&>F>*`B^&>E.&>MN&>D^*`B^&>@.&>ON&>C^*`B^&>H>&>ON&>
MA"#AGH'AGH[AGXCB@(OAGI;AGX'AGIOB@(OAGI3AGH3AGY+AGH#AGK[AGH_B
M@(OAGI?AGK;AGIKAGH#AGK?AGH7AGY+AGH7B@(OAGI#AGY+AGICAGKC"H.&?
ME`#AGJ+AGH3AGXOAGHKAGKSAGIKAGXGAGK8`X9ZBX9Z$X9^+X9Z@X9^2X9Z"
MX9^$X9ZAX9ZV`.&>HN&>A.&?B^&>H.&?DN&>G^&?BN&>N.&>H>&>M@#AGI3A
MGK;AGI/B@(OAGH;AGY+AGIOAGK[AGIGB@(OAGH_AGI0`X9Z?X9ZVX9Z:XH"+
MX9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/
MX9Z4`.&>E^&>MN&>@N*`B^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>A`#A
MGJ+AGH3AGXOAGI'AGKCAGJ#AGY+AGH+AGK8@X9Z3X9ZWX9Z$(.&>E.&>MN&>
ME.&?BN&>N^&>F>&>BN&>M@#AGH#AGICAGY+AGICAGISAGK?AGI+AGK@`X9ZB
MX9Z3X9Z[X9Z<X9Z/X9^2X9Z/XH"+X9Z/X9Z8X9^2X9Z:X9Z$`.&>HN&>D^&>
MN^&>G.&>C^&?DN&>C^*`B^&>C^&>F.&?DN&>FN&>A.*`B^&>D>&?A2`E<P#A
MGJ+AGI/AGKOAGISAGH_AGY+AGH_B@(OAGH#AGY+AGI3AGKWAGI/B@(OAGH_A
MGICAGY+AGIKAGH3B@(L@X9ZBX9ZVX9Z?X9^2X9Z:X9^0X9Z9XH"+X9Z;X9Z^
MXH"+X9Z`X9ZVX9Z:XH"+X9Z%X9Z\X9Z;PJ`_`.&>HN&>D^&>N^&>G.&>C^&?
MDN&>C^*`B^&>@.&?DN&>E.&>O>&>D^*`B^&>C^&>F.&?DN&>FN&>A"#AGI;A
MGX'AGIOB@(OAGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI3AGY+AGIKAGJ+AGI3A
MGXOB@(OAGI'AGI'AGKWAGIO"H#\`X9Z8X9^!X9Z?X9ZV`.&>HN&>MN&>FN&?
MB>&>MN&>E.&?BR`H5VEN9&]W<RTQ,C4V*0#AGH_AGK[B@(OAGJ+AGY+AGI/A
MGH#B@(OAGI;AGK?AGH_B@(OAGH?AGK;B@(OAGH7AGH3AGXOB@(OAGIOAGKOA
MGI3B@(OAGI/AGK?AGIGAGICAGI/AGY#AGIGB@(OAGI#AGH_B@(OAGI/AGK?A
MGICAGY+AGICAGK?AGH_B@(OAGI/AGX'AGX?B@(OAGJS"H#\`X9Z/X9Z^XH"+
MX9ZBX9^2X9Z3X9Z`XH"+X9Z6X9ZWX9Z/XH"+X9Z'X9ZVXH"+X9Z%X9Z$X9^+
MXH"+X9Z;X9Z[X9Z4XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZV
MX9Z:X9Z.X9^(XH"+X9Z3X9^!X9^'XH"+X9ZLPJ`_`.&>C^&>ON*`B^&>HN&?
MDN&>D^&>@.*`B^&>EN&>M^&>C^*`B^&>A^&>MN*`B^&>A>&>A.&?B^*`B^&>
MF^&>N^&>E.*`B^&>@N&>O.*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>FN&>E.&>
MG^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>K,*@/R`HX9Z8X9ZWX9Z3XH"+X9Z8
MX9^"X9Z3XH"+X9Z'X9ZVXH"+X9ZBX9Z3X9Z[X9Z?X9ZVX9Z?X9Z3X9^-(2D`
MX9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z6X9ZWX9Z/XH"+X9Z'X9ZVXH"+
MX9Z%X9Z$X9^+XH"+X9Z2X9^2X9Z<X9Z^XH"+X9Z*X9Z\X9Z%XH"+X9Z3X9^!
MX9^'XH"+X9ZLPJ`_`.&>C^&>ON*`B^&>HN&?DN&>D^&>@.*`B^&>EN&>M^&>
MC^*`B^&>A^&>MN*`B^&>A>&>A.&?B^*`B^&>F^&>N^&>E.*`B^&>G^&>MN&>
MFN*`B^&>D>&>MN&?AN&>A.*`B^&>D^&?@>&?A^*`B^&>A^&>MN*`B^&>HN&>
MA>&>M^&>D^&?DN&>C^&?DN&>FN&?@^&>F>&?C>*`B^&>K.*`B\*@/^*`BP#A
MGH_AGK[B@(OAGJ+AGY+AGI/AGH#B@(OAGI;AGK?AGH_B@(OAGH?AGK;B@(OA
MGH7AGH3AGXOB@(OAGIOAGKOAGI3B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?A
MGY+AGH?AGK;AGI3AGXOB@(OAGI/AGX'AGX?B@(OAGH?AGK;B@(OAGJ+AGH7A
MGK?AGI/AGY+AGH_AGY+AGIKAGX/AGIGAGXWB@(OAGJS"H#\`X9Z/X9Z^XH"+
MX9ZBX9^2X9Z3X9Z`XH"+X9Z6X9ZWX9Z/XH"+X9Z'X9ZVXH"+X9Z%X9Z$X9^+
MXH"+X9Z?X9Z8X9^2X9ZBX9ZVX9Z/XH"+X9Z0X9Z/XH"+X9Z3X9^!X9^'XH"+
MX9ZLPJ`_`.&>C^&>ON*`B^&>HN&?DN&>D^&>@.*`B^&>EN&>M^&>C^*`B^&>
MA^&>MN*`B^&>A>&>A.&?B^*`B^&>G^&>F.&?DN&>HN&>MN&>C^*`B^&>D.&>
MC^*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>
MFN*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>K,*@/P#AGH_A
MGK[B@(OAGJ+AGY+AGI/AGH#B@(OAGI;AGK?AGH_B@(OAGH?AGK;B@(OAGH7A
MGH3AGXOB@(OAGI_AGICAGY+AGJ+AGK;AGH_B@(OAGI#AGH_B@(OAGI_AGX;A
MGIKAGK;AGICB@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGJS"
MH#\`X9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z6X9ZWX9Z/XH"+X9Z'X9ZV
MXH"+X9Z%X9Z$X9^+XH"+X9Z;X9Z[X9Z4XH"+X9Z?X9ZVX9Z:XH"+X9Z1X9ZV
MX9^&X9Z$XH"+X9Z3X9^!X9^'XH"+X9Z'X9ZVXH"+X9ZBX9Z%X9ZWX9Z3X9^2
MX9Z/X9^2X9Z:X9^#X9Z9X9^-XH"+X9ZLPJ`_`.&>C^&>ON*`B^&>HN&?DN&>
MD^&>@.*`B^&>EN&>M^&>C^*`B^&>A^&>MN*`B^&>A>&>A.&?B^*`B^&>FN&>
MMN&>F>*`B^&>@.&>MN&>FN&>CN&?C>*`B^&>HN&?AN&>EN&>N.*`B^&>G^&>
MMN&>FN*`B^&>D^&?@>&?A^*`B^&>D.&>MN*`B^&>A^&>MN*`B^&>G^&>MN&>
MFN*`B^&>F^&?DN&>HN*`B^&>K,*@/P#AGH_AGK[B@(OAGJ+AGY+AGI/AGH#B
M@(OAGI;AGK?AGH_B@(OAGH?AGK;B@(OAGH7AGH3AGXOB@(OAGIKAGK;AGIGB
M@(OAGH#AGK;AGIKAGH[AGXWB@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OA
MGI#AGK8@X9Z'X9ZVXH"+X9Z?X9ZVX9Z:X9ZEX9Z/XH"+X9Z4X9ZVX9Z3X9Z`
MX9ZVX9Z:XH"+X9ZLPJ`_`.&>HN&>MN&>H.&?DN&>G^&>A.&?B^&>D>&>N.&>
MDP#AGJ+AGK;AGICAGX'AGI/AGK@`X9Z6X9^!X9Z;XH"+X9Z<X9^!X9Z;X9ZV
MXH"+X9Z8X9Z`XH"+X9Z*X9Z;X9^+`.&>HN&>MN&>FN&>O.&>E.&>M@#AGJ'A
MGK[AGH0`X9Z?X9Z]X9Z:`.&>E^&?DN&>A^&>MN&>E.&?B^*`B^*`B^&>K^&>
M@.&>G^&>MN&>FN*`B^&>A^&>MN&>F.&>O>&>F0#AGI?AGY+AGH?AGK;AGI3A
MGXOB@(OAGH?AGK;AGICAGKWAGIGB@(OAGI/AGKSAGISB@(OAGH7AGY+AGI3A
MGK;AGI3AGXOB@(OAGH7AGICAGY+AGIOAGH3B@(OAGICAGKWAGIGB@(OAGI/A
MGX/B@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGX@@
M4$=0(.&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`BR#AGI'AGX7B@(OA
MGI_AGK;AGIKB@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"H#\`X9ZO
MX9Z`X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z7X9^2
MX9Z'X9ZVX9Z4X9^+XH"+X9Z'X9ZVX9Z8X9Z]X9Z9PJ#AGY8`X9ZOX9Z`X9Z?
MX9ZVX9Z:XH"+("(E<R(@X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z7X9^2
MX9Z'X9ZVX9Z4X9^+XH"+X9Z'X9ZVX9Z8X9Z]X9Z9(.&>F^&>ON&>G^*`B^&>
M@.&>F.&?DN&>FN&>M^&>C^*`B^&>D>&?AN&>H.&?AN*`B^&>K^&>@.&>G^&>
MMN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B\*@X9^4(.&>K^&>@.&>G^&>MN&>
MFN*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>E^&?DN&>A^&>MN&>E.&?B\*@X9^4`.&>K^&>@.&>G^&>MN&>FN*`B^&>
MBN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>E^&?DN&>A^&>MN&>E.&?BR#AGH+A
MGKKB@(OAGH?AGK;B@(OAGH#AGK;AGIKB@(OAGH;AGY+AGIOAGK[AGIGB@(OA
MGH_AGI3B@(OAGICAGKWAGIGB@(OAGI'AGX7B@(OAGI_AGX;AGH[AGK[B@(OA
MGI3AGY+AGIKAGH_AGK?AGI'AGK?AGI/B@(OAGHKAGX+AGIOAGJ+AGY+AGI/A
MGH#AGI3AGK;AGI/B@(OAGI7AGY+AGHGAGK["H.&?E`#AGJ_AGH#AGI_AGK;A
MGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXL`X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7
MX9^2X9Z'X9ZVX9Z4X9^+("5S(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>F^&>N^&>E,*@X9^4`.&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>
MK^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BP#AGJ_AGH#AGI_A
MGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGHKAGX+AGIOB@(OAGI3A
MGK;AGI/B@(OAGH7AGY+AGI3AGKSAGH_B@(OAGIGAGH#B@(OAGH7AGX'AGHG"
MH.&?EB#AGI3AGY+AGIKAGI?AGX'AGI'B@(OAGJ_AGH#AGI_AGK;AGIKB@(OA
MGI?AGY+AGH?AGK;AGI3AGXOB@(OAGHKAGK[AGI@`X9ZOX9Z`X9Z?X9ZVX9Z:
MXH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+`.&>HN&?DN&>D^&>@.&>A>&>O.&>F^&>
MFN&>O>&>F`#AGH#AGK;AGIKB@(OAGI3AGY+AGIKAGKOAGH3B@(OAGI3AGY+A
MGIKAGIGAGY#AGH_AGY+AGI,`X9Z"X9Z[X9Z.X9Z;X9Z`X9^2X9Z!X9Z.X9^(
M`.&>G^&>N.&>H.&>M@#AGJ+AGKSAGI_AGY+AGH_AGY+AGIKAGK;AGIOAGK@`
MX9ZBX9Z\X9Z1X9^2X9Z:X9ZXX9Z?`$%U=&A?:6UP.B#AGIKAGH#B@(OAGICA
MGK?AGI/B@(OAGH/AGK[AGHGB@(OAGI7AGY+AGI/AGX+AGH#B@(OAGI3AGI/A
MGY+AGI#AGX+AGI@@24U!4"#AGHKAGX+AGIOB@(OAGH_AGY+AGIKAGKSAGISA
MGH#AGK;AGIKB@(OAGJ'AGK[AGIG"H.&?E`#AGH#AGK;AGIKB@(OAGI7AGY+A
MGI'AGX#AGH3B@(OAGI7AGY+AGI'AGK;AGH_AGXOB@(OAGI?AGK;AGI;B@(OA
MGH_AGY+AGIKAGKGAGICB@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGI3AGIKAGK;AGH?AGY#AGID`X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z:
MX9Z\X9Z4X9Z7X9ZVX9Z6XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z?X9ZVX9Z:
M($A434P@X9Z*X9^$X9Z9XH"+X9Z?X9^2X9Z<X9^0X9Z9XH"+X9Z4X9^2X9Z:
MX9Z<X9Z/X9^2X9Z/X9ZW(.&>EN&?@>&>F^*`B^&>HN&?DN&>D^&>@.*`B^&>
ME>&?DN&>B>&>ON*`B^&>G^&?DN&>D.&>M^&>C^*`B^&>D^&?A>*`B^&>@.&?
MDN&>D^&>N^&>A.*`B^&>G^&?@.&>G.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>
MBN&?DN&>B^&>MN&>D^*`B^&>FN&>E.&>G^&?B^*`B^&>@>&?DN&>B>&>N^&?
MAL*@/P#AGI_AGX#AGISAGI?AGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI/B@(OAGHKAGX+AGIOB@(OAGICAGK;AGI,`X9Z`X9^&X9Z6X9Z[X9Z$
MXH"+X9Z:X9Z$X9Z%X9ZVX9^&XH"+X9Z`X9ZVX9Z:XH"+X9Z&X9^2X9Z;X9Z^
MX9Z9XH"+X9Z/X9Z4`.&>HN&>MN&>H.&?DN&>G^&?BN&?@N&>FN&>E.&?@N&>
MH.&?DN&>G^&>A.&?BP!?2^&>C^&?DN&>FN&>H>&>E.&?B^*`B^&>D>&?A2`E
M<R``X9Z/X9^2X9Z:X9ZAX9Z4X9^+XH"+X9Z1X9^%("5S`.&>C^&?DN&>FN&>
MH>&>E.&?B^*`B^&>D>&?A>*`B^&>F^&>M^&>E.&>M^&>@.&?DN&>FN&>F.*`
MB^&>D>&>M^&>BN&?DN&>B^&>E^&>MN&>EN*`B^&>G^&>MN&>FN*`B^&>A>&?
MDN&>FN&>ON&>DP#AGH_AGY+AGIKAGJ'AGI3AGXOB@(OAGI'AGX7B@(OAGH#A
MGK;AGIKB@(OAGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGH?AGK;B@(OAGH'AGY+A
MGI_AGX+B@(OAGI_AGY+AGIKAGJ'AGK;AGID`X9Z5X9^2X9Z1X9^#XH"+X9Z!
MX9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9`.&>EN&>CN&?C.*`B^&>E>&?DN&>
MD>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F0#AGHCAGY+AGICA
MGX3AGX?B@(OAGH7AGKSAGIL@X9ZL(.&>EN&>MN&>@.&?DN&>F>&>G^&>F.&?
MDN&>A.&>MN&>C^&?B^*`B^&>F.&>M^&>D^*`B^&>F^&?DN&>HL*@X9^4`.&>
MG^&?AN&>CN&>ON*`B^&>F.&>M^&>D^*`B^&>F^&?DN&>HB#AGJP@X9Z8X9ZW
MX9Z3XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<PJ#AGY0@X9Z8
MX9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z4X9ZV
MX9Z3XH"+X9Z&X9^2X9Z;X9Z^X9Z9X9Z/X9Z4XH"+X9Z0X9ZVPJ#AGY8@)7,`
MX9Z?X9^&X9Z.X9Z^XH"+X9Z8X9ZWX9Z3XH"+X9Z;X9^2X9ZBPJ#AGY8@)7/"
MH.&?E`#AGI3AGK;AGJ#AGK;AGICAGXGAGK;AGI\`X9Z4X9ZVX9Z:X9^)X9^"
MX9Z3`.&>E.&>A.&?B^&>@.&?DN&>F^&>MN&>BN&?@>&>G^&?DN&>H`#AGI3A
MGK;AGIKAGI3AGK;AGHKAGKSAGI\`X9Z;X9ZVX9Z`X9^+`.&>E.&?@>&>H>&>
MMN&>FN&>N^&>G^&?DN&>GP#AGI3AGX+AGIOB@(OAGJ#AGY+AGI_AGXKAGK?A
MGH``X9Z4X9^!X9Z;X9ZXX9Z@X9^2X9Z?`.&>@>&>MN&>A.*`B^&>@.&?DN&>
MFN&?A.&>F.*`B^&>@N&>NN*`B^&>A^&>MN*`B^&>HN&>C^&?DN&>D.&>E.&>
MD>*`B^&>AN&?A>&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>FN*`B^&>D^&?@^*`
MB^&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>G^&?DN&>D.&>MN&>D^&>E^&>
MMN&>EL*@X9^4`.&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F.*`B^&>HN&>
MC^&?DN&>D.&>E.&>D>*`B^&>G^&>MN&>F@#AGI3AGX'AGH[AGK;AGX;AGH0`
MX9Z4X9^*X9^!X9Z:X9Z8X9Z\X9Z*X9ZV`.&>E.&?BN&>O.&>C^&>MN&>DP#A
MGI#AGY+AGH3AGX/AGH#AGX;AGH[AGK[AGH\`X9Z4X9Z)X9^2X9Z'X9ZXXH"+
MX9Z!X9^2X9Z8X9^%`.&>D>&>E.&?B^&>G^&?DN&>@.&>MN&>C^&?B^*`B^&>
MFN&>O.&>E.&>E^&>MN&>EN*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>G^&>MN&>
MFB!(5$U,(.&>E.&?DN&>FN&>G^&>M^&>D^*`B^&>E.&>ON*`B^&>EN&>O>&>
M@.*`B^&>G.&>MN*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>
ME.&>MN&>D^*`B^&>G^&?DN&>D^&>ON*`B^&>G^&>N^&?AN*`B^&>A^&>MN*`
MB^&>EN&>M^&>G^&?@>&>G\*@/P#AGH_AGKT`X9Z*X9ZWX9Z/`.&>E.&>O.&>
MF^&>N.&>G.&>N`#AGH#AGI/AGY+AGIOAGX+AGH3B@(OAGH7AGX;AGH[AGK;A
MGX8`X9Z?X9^*X9Z[X9Z8`.&>G^&?BN&>N^&>F.*`BP#AGI3AGKSAGI_AGY+A
MGI/AGXKAGK@@X9Z3X9ZWX9Z$(.&>H.&>NN&>H.&?DN&>G^&?BN&?@>&>H.&?
MDN&>@N&?A.&>G.&>N.&>CN&>M@#AGI'AGK;AGX;AGH3AGI;AGKCAGIH`X9Z1
MX9ZVX9^&X9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z:X9ZVX9Z9XH"+X9Z4X9Z+X9Z8
MX9Z`X9Z0X9ZV(.&>D^&>M^&>A"#AGH_AGKWB@(OAGIKAGI3AGI_AGXOB@(OA
MGI_AGK;AGIH`X9Z4X9Z[X9Z/X9Z?X9^2X9Z<X9ZVX9Z.X9ZV`.&>E.&>MN&>
MCP#AGH#AGX3AGX?B@(OAGI3AGXKAGKSAGISAGXGAGX(`X9Z4X9^2X9Z:X9^!
MX9Z?X9^*X9ZXX9Z;`.&>HN&>MN&>CN&>MN&>A>&>@.&?DN&>FN*`B^&>G^&>
MF.&>N^&>D>&?DN&>FN*`B^&>I>&>CN&?DN&>C.&>MB#AGJ+AGH3AGXOAGH+A
MGY+AGIOAGX'AGI\`X9Z4X9^2X9Z:X9^*X9Z[X9Z9X9Z.X9^!XH"+X9Z*X9ZV
MX9Z:X9^*X9Z[X9Z9X9Z?X9ZVX9ZAX9ZVX9Z8`.&>E.&?BN&>N^&>F^&>H.&?
MDN&>@N&>MN&>FN&>N`#AGI3AGXKAGKSAGIKAGH+AGKCAGH[AGK;AGJ#AGY+A
MGISAGK;AGI_AGKP`X9Z4X9^*X9Z\X9Z:X9Z[X9Z3X9Z,X9ZX`$-20P!?2.&>
MG^&?AN&>CN&>N^&?AN*`B^&>C^&>O>*`B^&>HN&>@.&?DN&>G^&>FB``X9Z4
MX9^2X9Z:X9Z/X9ZWX9Z1X9ZWX9Z3`.&>@.&>F.&?DN&>EN&>N^&>A^&>M@#A
MGH#AGK;AGICAGXGAGK;AGIKAGKSAGI,`X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%
MXH"+X9Z/XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z8X9^)
MX9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z?X9^&X9Z4
MX9Z[X9Z/X9^2X9Z:XH"+X9Z&X9^2X9Z$X9ZVX9Z9PJ#AGY0`X9Z8X9ZWX9Z3
MXH"+X9ZBX9ZVX9Z%XH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z1X9^%
MXH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+
MX9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z&X9^2X9Z$X9ZVX9Z9PJ#AGY8`
MX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)("T@
MX9Z:X9Z`XH"+X9Z#X9Z^X9Z)XH"+X9Z/X9^"("5S(.&>D^&?@^*`B^&>E>&?
MDN&>D^&?@N&>@"`E<R#AGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OAGI/A
MGX'AGX<@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+
MX9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2
MX9Z4X9Z3X9^2X9Z3PJ#AGY0`X9Z`X9ZVX9Z.X9ZVX9Z*X9ZV`.&>E.&?A.&?
MA^&>E.&>A.&?BP#AGI3AGX3AGX?AGI3AGH3AGXOB@(OAGI_AGK;AGIH`X9Z4
MX9^$X9^'X9Z4X9Z$X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'(.&>D^&>
MN>&>A.*`B^&>E.&?A.&?A^&>A>&?A.&>F^*`B^&>F.&>MN&>C^&>M^&>@.&>
MMN*`B^&>FN&>E.&>G^&?B^*`B^&>G.&>MN*`B^&>A^&>MN*`B^&>HN&>A>&>
MM^&>D^&?DN&>C^&?DN&>FN&?@^&>F>&?C<*@X9^4`.&>@.&>MN&>E.&>G.&?
M@N&>F@#AGH7AGX;AGH[AGH3AGH?AGK[AGH0`X9Z<X9Z/X9^2X9Z0X9Z[XH"+
MX9Z*X9ZYX9Z`XH"+X9Z'X9Z)X9^2X9Z'X9Z\X9Z3`.&>@.&?A.&?A^*`B^&>
M@.&?@^&>F.&?B>&>MN&>DP#AGH7AGICAGY+AGIOAGH0`X9Z`X9Z.X9^2X9Z/
MX9ZVX9Z;`.&>G^&>MN&>DN&>MN&>FN&>CN&>FN&>BN&?DN&>B^*`B^&>HN&>
MMN&>H.&?DN&>G.&?DN&>FN&>M^&>@.*`B^&>@.&>CN&?DN&>BN&>MN&>FP#A
MGICAGK?AGI/B@(OAGICAGK;AGI/B@(OAGH#AGK;AGIKB@(OAGI/AGK;AGX;A
MGH7AGKSAGIOB@(OAGISAGK?AGHGAGY+AGHGAGK;AGI3AGI/AGI3AGH_AGY+A
MGIKB@(OAGJ'AGK[AGIG"H.&?E"#AGH#AGK;AGIKB@(OAGI7AGY+AGI'AGKOA
MGH#B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGJ'AGK[AGH0@X9Z8X9ZWX9Z3XH"+
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z2X9^2X9Z<X9Z^XH"+
MX9ZRX9^2X9Z9XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^
MX9Z9XH"+X9Z;X9Z^XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8
MX9^2X9Z:X9Z^XH"+X9Z3X9^!X9^'PJ#AGY0`X9Z&X9ZVX9Z*`.&>E.&?DN&>
MFN&>DN&>MN&>DP#AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI3AGY+AGH_AGKSA
MGIH`X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1
MX9ZVX9^&X9Z$XH"+X9ZBX9Z?X9^+`.&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>
ME.&?DN&>C^&>O.&>FN*`B^&>D.&>CP#AGI7AGY+AGIOAGK;AGI_AGXOB@(OA
MGI3AGY+AGH_AGKSAGIKB@(OAGH?AGICAGY+AGIKAGK[AGI_B@(OAGI3AGH3A
MGY+AGJ#AGK;AGHGB@(OAGHKAGKSAGH7AGH?AGK8@X9Z?X9ZVX9Z:XH"+X9Z%
MX9^&X9Z3X9Z]X9Z3XH"+X9Z4X9^)X9Z[X9Z3X9^2X9Z8X9ZVX9Z3XH"+X9Z*
MX9^"X9Z;XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z#X9Z^X9Z)XH"+X9Z;X9Z^XH"+
MX9Z1X9^&X9Z6X9^0X9Z:XH"+X9Z3X9ZWX9Z8X9Z]X9Z9X9^7(.&>D^&>M^&>
MA"#AGI_AGK;AGIKB@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OA
MGH_AGICAGY+AGIKAGX#AGI3B@(OAGIGAGXGAGK;AGH3B@(OAGHKAGKSAGH7A
MGICAGY+AGH_AGX'AGH7"H.&?E`#AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI3A
MGY+AGH_AGKSAGIKB@(OAGH#AGK;AGIKB@(OAGH#AGX;AGH[AGH_AGXOB@(OA
MGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI_A
MGX;AGI3AGKOAGH_AGY+AGIH@X9Z3X9ZWX9Z$(.&>D.&>C\*@X9^4`.&>E>&?
MDN&>F^&>MN&>G^&?B^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>B.&?DN&>F.&?
MA.&?AR#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,@X9Z3X9ZWX9Z$(.&>
MH.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>BN&?@N&>F^*`B^&>F.&>D^&>
MN^&>G^&?DN&>G^*`B^&>@^&>ON&>B>*`BR#AGI;AGX'AGIOB@(OAGI;AGKWA
MGH#B@(OAGH+AGX'B@(OAGJ+AGK;AGI,@X9Z3X9ZWX9Z$(.&>AN&?DN&>F^&>
MON&>F>*`B^&>C^&>E.*`B^&>D>&?A>*`B^&>HN&?BN&>N.&>F.&?@N&>F^*`
MB^&>FN&>E.&>G^&?B^&>HN&?DN&>D^&>@,*@X9^4`.&>C^&>O>*`B^&>HN&>
M@.&?DN&>G^&>FN*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>
ME.&>A.&?DN&>H.&>MN&>B<*@X9^6`.&>EN&>M^&>D^&>M^&>C^&?DN&>F>*`
MB^&>F.&>ON&>F^*`B^&>D.&>C^*`BR#AGI_AGICAGY+AGIKAGK;AGI3AGXOB
M@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI#AGY+AGICAGK@`7T'AGI+A
MGKCAGH#B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXLOX9Z8X9ZWX9Z3XH"+X9Z2
MX9ZXX9Z`XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+(`#AGI;AGK?AGI/AGK?A
MGH_AGY+AGIGB@(OAGICAGK[AGIOB@(OAGICAGXGAGK;AGI_AGXKAGKCAGI/B
M@(OAGI3AGICAGY+AGIKAGK[B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXL@X9Z*
MX9^"X9Z;XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z%X9Z$X9^+XH"+XH"+X9Z1X9^%
MXH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`XH"+X9Z?X9^&X9Z4X9Z[
MX9Z/X9^2X9Z:XH"+X9Z6X9ZXPJ#AGY8`X9Z6X9ZWX9Z3X9ZWX9Z/X9^2X9Z9
MXH"+X9ZBX9Z`X9^2X9Z!X9Z:X9ZVX9Z<X9ZWX9Z:X9Z[X9Z1X9^2X9Z2(.&>
MF.&>N^&>D^*`B^&>EN&?@>&>F^*`B^&>E>&?DN&>B>&>ON*`B^&>G^&>MN&>
MFN&>F.&>O>&>F<*@/P#AGHCAGKCAGIOAGK@`X9Z%X9ZWX9Z3`.&>A^&?DN&>
MFN&>ON&>G^*`B^&>HN&?AN&>EN&>O@#AGH?AGY+AGIKAGK[AGI_B@(OAGICA
MGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI_AGX;A
MGI3AGKOAGH_AGY+AGIK"H.&?E@#AGH?AGY+AGIKAGK[AGI_B@(OAGHKAGX;A
MGH[AGKSAGH7B@(OAGICAGKWAGID@X9ZL(.&>@.&?@N&>G^&>F.&?DN&>FN&>
MO>&>F^*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>D^&?A>*`
MB^&>@>&>MN&>A.*`B^&>G^&?DN&>BN&>MN&?AL*@X9^6`.&>A^&?DN&>FN&>
MON&>G^*`B^&>G^&?@.&>G.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>
MB^&>MN&>D^*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&?
MDN&>FN&>OB#AGI;AGX'AGIOB@(OAGI3AGI/AGY+AGI#AGX+AGICB@(OAGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/"H.&?E`#AGH?AGY+AGIKAGK[AGI_B
M@(OAGIOAGX;AGHKAGK;AGI3AGXOB@(OAGI_AGX#AGISAGI?AGX7B@(OAGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/AGHKAGX+AGIOB@(OAGH_AGY+AGIKA
MGKSAGISB@(OAGI_AGY+AGISAGX+AGH3B@(OAGIKAGH`@X9Z6X9^!X9Z;XH"+
MX9Z6X9Z$X9^2X9Z:X9ZXX9Z`XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZV
MX9Z3PJ#AGY0`X9Z`X9^$X9^'XH"+X9Z"X9^2X9Z:X9ZXX9Z?X9^2X9Z/X9Z8
MX9^)X9ZVX9Z?`.&>A^&>F.&?DN&>FN&?AP#AGH?AGICAGY+AGIKAGX?B@(OA
MGI_AGX;AGH[AGKWAGIH`X9Z%X9Z[X9Z%("5S(.&>BN&>ON&>F.&?DN&>E.&>
MN.*`B^&>E.&>F.&?DN&>F^&?@N&>A.*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>
MFN&>O.&>E.&>E^&>MN&>EN*`B^&>D>&?A>*`B^&>A^&>MN*`B^&>D>&?DN&>
MFN&>A.&?B^*`B^&>D>&?DN&>FN&>MN&>F>*`B^&>BN&?@N&>F^*`B^&>@.&>
MF.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>FN&>N^&>@.&>FN&>@.*`B^&>FN&>
ME.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>HN&>MN&>A>&>E.&>A.&?DN&>
MH.&>MN&>B<*@X9^4`.&>A>&>N^&>A2`E<R#AGHKAGK[AGICAGY+AGI3AGKCB
M@(OAGI'AGK;AGHGAGIGAGH#AGIKAGKSAGI3AGI?AGK;AGI;"H.&?E`#AGH7A
MGKOAGH4@)7,@X9Z*X9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z1X9^%XH"+X9Z`X9ZV
MX9Z3X9^+X9Z1X9^&X9Z6X9^0X9Z:XH"+X9Z"X9^2X9Z:X9Z4X9^+XH"+X9Z"
MX9^2X9Z:X9Z$("5SPJ#AGY3B@(L`X9Z%X9Z[X9Z%("5S(.&>BN&>ON&>F.&?
MDN&>E.&>N.*`B^&>F.&>ON&>F^*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>
MC^&>O.&>A>*`B^&>FN&>E.&>G^&?B^*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`
MB^&>D^&?@>&?A\*@X9^4`.&>A>&>N^&>A2`E<R#AGHKAGK[AGICAGY+AGI3A
MGKCB@(OAGICAGK[AGIOB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?A
MGK;AGI3AGXOB@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI3AGH3AGY+AGJ+AGKWA
MGH7B@(OAGI7AGY+AGI_AGX'AGH3"H.&?E`#AGH7AGKOAGH4@)7,@X9Z*X9Z^
MX9Z8X9^2X9Z4X9ZXXH"+X9Z8X9Z^X9Z;XH"+X9Z5X9^2X9Z3X9^"X9Z`XH"+
MX9Z%X9^2X9Z:X9Z^X9Z3XH"+X9Z5X9^2X9Z3X9^"X9Z`(.&>K"#AGI7AGY+A
MGI/AGX+AGH#B@(OAGI'AGK;AGH#AGXOAGI'AGH3B@(OAGH+AGY+AGI/AGK;B
M@(OAGI/AGX'AGX?B@(OAGI/AGX7B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI3A
MGH3AGY+AGJ+AGKWAGH7B@(OAGI7AGY+AGI_AGX'AGH3"H.&?E`#AGH7AGKOA
MGH7B@(OAGIOAGK[B@(OAGI_AGX#AGISAGI?AGX7B@(OAGJ+AGK;AGI_AGIGA
MGHKAGY+AGHOAGK;AGI/B@(OAGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+
MX9Z%X9^&X9Z.X9^$X9Z8XH"+X9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?
MX9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+
MX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`
M(.&>D^&>M^&>A"#AGI3AGI/AGY+AGI'AGK;AGI3AGXOB@(OAGICAGH#B@(OA
MGH?AGY+AGIKAGK[AGI_B@(OAGH#AGY+AGIKAGJ'AGK;B@(OAGI'AGI'AGKGA
MGH3B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXOB@(OAGHKAGX+AGIOB@(OAGH_A
MGY+AGIKAGKSAGISB@(OAGI_AGY+AGISAGX+AGH3B@(OAGIKAGH#"H.&?E`#A
MGH7AGKOAGH4@X9Z*X9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z:X9Z`X9^2X9Z?X9ZV
MXH"+X9Z1X9Z[X9Z`XH"+X9Z<X9ZWX9Z)X9^2X9Z)X9ZVX9Z4X9Z3X9Z4X9Z/
MX9^2X9Z:XH"+X9Z:X9Z4X9Z?X9^+(%,O34E-12#AGI/AGX,@)7,@X9Z`X9^2
MX9Z3X9Z[X9Z$XH"+X9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9X9Z*
MX9^2X9Z+X9ZVX9Z3XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z``.&>
MA>&>N^&>A>*`B^&>F^&>ON*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>
MD^*`BR#AGI/AGKGAGH3B@(OAGH_AGX+AGH3B@(OAGI_AGK;AGIKB@(OAGI#A
MGY+AGICAGKCB@(OAGICAGKWAGIGB@(OAGI'AGX7B@(OAGJ+AGY+AGI/AGH#B
M@(OAGI7AGY+AGHGAGKX`X9Z%X9Z[X9Z%XH"+X9Z;X9Z^XH"+X9ZBX9ZVX9Z?
MX9Z9X9Z*X9^2X9Z+X9ZVX9Z3(.&>D^&>N>&>A.*`B^&>E.&>ON&>@.*`B^&>
MG^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>HN&>
MMN&>DP#AGI3AGK?AGI$`X9Z4X9ZWX9Z1XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%
M`.&>E.&>M^&>D>*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`B^&>D^&?@>&?AP#A
MGI#AGH_B@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI3AGK?AGI$`X9Z`
MX9^$X9^'XH"+X9Z`X9Z\X9Z`X9Z\("CAGH/AGKCAGIOAGKCAGH0I`.&>G.&?
M@>&>B0#AGISAGX'AGHGB@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXL`X9Z<X9^!
MX9Z)XH"+X9Z0X9Z/XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+`.&>G.&?@>&>
MB>*`B^&>D.&>CP#AGH#AGKSAGJ'AGKOAGX;AGI3AGXKAGK@`X9Z6X9Z.X9^,
M`.&>D>&?DN&>FN&>D^&>M^&>A>&>E.&>A.&?DN&>H.&>MN&>B>*`B^*`B^&>
MEN&>CN&?C,*@X9^6`.&>EN&>MN&>@.&?DN&>F>*`B^&>E.&>B>&?DN&>A^&>
MM@#AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGJ+AGI+AGK?AGI3AGY+AGI3A
MGK;AGID`X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z2X9Z8X9^2X9Z8X9Z/X9ZV`.&>
M@.&>N^&?AN&>F.&?B>&>O.&>FN&?B>&>O.&>GP#AGH#AGY+AGIKAGKOAGICA
MGJ#AGXKAGKOAGI,`X9Z1X9ZVX9^&X9Z$X9Z?X9^2X9Z:X9Z[X9Z$`.&>C^&?
M@N&>A.*`B^&>G^&>MN&>FN*`B^&>F.&>O>&>F>*`B^&>E>&?DN&>G^&?@>&>
MA`#AGH_AGX+AGH3B@(OAGI_AGK;AGIKB@(OAGH#AGY+AGI/AGKOAGH3B@(OA
MGI3AGH3AGY+AGJ+AGKWAGH7B@(OAGI7AGY+AGI_AGX'AGH3B@(OAGJS"H#\`
MX9Z/X9^"X9Z$XH"+X9Z?X9ZVX9Z:XH"+X9Z'X9ZVX9Z8X9Z]X9Z9($A434P@
M1U5)(.&>BN&?A.&>F>*`B^&>F^&?AN&>D^&>MN&?AN&>BN&>ON&>F"`HX9Z4
MX9^2X9Z:X9Z?X9ZWX9Z3XH"+X9Z4X9Z^XH"+X9Z`X9Z8X9^2X9Z8X9Z<X9ZW
MX9Z2X9ZXXH"+X9Z:X9Z[X9Z`X9Z:X9Z`XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:
MXH"+X9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z6X9ZWX9Z?X9^!X9Z?XH"+X9Z3
MX9^!X9^'*<*@/P#AGH#AGKOAGX;AGI;AGY+AGIGAGKSAGI'AGY#AGIH`X9Z;
MX9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,`.&>F^&>@.&?DN&>@>&>@>&>CN&?DN&>
MC`#AGH#AGX;AGH[AGH_AGXOB@(OAGIKAGH7AGI/AGK;B@(OAGI_AGICAGY+A
MGI;AGY#AGI/AGY+AGI+AGI#AGK8@XH"+X9Z/X9Z^XH"+X9Z?X9ZVX9Z:XH"+
MX9Z4X9^)X9Z[X9Z3X9^2X9Z8X9ZVX9Z3XH"+X9Z*X9^"X9Z;XH"+X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)PJ#AGY0`X9Z`X9^&X9Z.
MX9Z/X9^+XH"+X9Z:X9Z%X9Z3X9ZVXH"+X9Z?X9Z8X9^2X9Z6X9^0X9Z3X9^2
MX9Z2XH"+X9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z8X9Z^X9Z;XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z'X9ZVXH"+X9Z8X9Z[X9Z3PJ#AGY0`X9ZB
MX9^'X9ZBX9ZVX9Z$XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+
MX9ZBX9^*X9ZXX9Z8X9^"X9Z;`.&>HN&?A^&>HN&>MN&>A.*`B^&>HN&>MN&>
MG^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>F^*`B^&>
MD.&?DN&>F.&>N`#AGH#AGKOAGH3AGJ#AGY+AGH+AGX0`X9Z`X9ZVX9Z:XH"+
MX9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z1X9Z8X9^2X9Z;X9ZVX9Z`X9^+XH"+X9Z%X9^$X9Z;XH"+
MX9Z*X9^$X9Z9XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2
MX9Z:X9Z^($E-05#"H.&?E`#AGH#AGK;AGIKB@(OAGH_AGI?AGY+AGH?AGK;A
MGI3AGXOB@(OAGI3AGK;AGI/B@(OAGI3AGIKAGK;AGH?AGY#AGIGB@(O"H.&?
ME`#AGH#AGK;AGIKB@(OAGH_AGI?AGY+AGH?AGK;AGI3AGXOB@(OAGI'AGX7B
M@(OAGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OA
MGI3AGK;AGI/B@(OAGI3AGIKAGK;AGH?AGY#AGID`0V]N=&%C=',`X9Z4X9Z3
MX9^2X9Z/`.&>C^&?DN&>FN&>O>&>C^*`B^&>EN&>M^&>D^&>M^&>C^&?DN&>
MF>*`B^&>@.&>MN&>FN&>@N&>MN&?AN&>D>&?DN&>FB!01U`@X9Z?X9Z8X9^2
MX9Z:X9ZVX9Z4X9^+("5SPJ#AGY0`X9Z/X9^2X9Z:X9Z]X9Z/XH"+X9Z6X9ZW
MX9Z3X9ZWX9Z/X9^2X9Z9X9Z`X9ZVX9Z:XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:
M(%,O34E-12#AGI_AGICAGY+AGIKAGK;AGI3AGXL@)7/"H.&?E`#AGI3AGHGA
MGY+AGH?AGK;B@(OAGH?AGICAGY+AGIKAGK[AGI_B@(OAGHKAGX+AGIOB@(OA
MGI'AGK;AGH#AGXOAGI'AGH3B@(OAGI'AGX7B@(OAGI/AGKGAGH3B@(OAGH#A
MGK;AGIKB@(OAGI_AGY+AGISAGX+AGH3AGIKAGH#B@(OAGI_AGK;AGIK"H.&?
ME`#AGH_AGY+AGIKAGKWAGH_B@(OAGI;AGK?AGI/AGK?AGH_AGY+AGID@X9Z6
MX9^!X9Z;XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9^2X9Z8X9ZX
MXH"+X9Z3X9ZYX9Z$XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9Z6X9ZWX9Z3X9ZWX9Z/X9^2X9Z9XH"+X9Z8X9Z^X9Z;(.&>D^&>M^&>A"#A
MGI#AGK;B@(OAGH_AGK[B@(OAGH_AGY+AGIKAGKSAGISB@(OAGH?AGKSAGI/B
M@(OAGHKAGX;AGH[AGKGAGH3B@(OAGHKAGIOAGXOB@(OAGJ+AGY+AGI/AGH#B
M@(OAGJSB@(OAGJ+AGH_AGXL@X9Z6X9^!X9Z;XH"+X9Z<X9ZVXH"+X9Z8X9Z`
MXH"+X9Z*X9Z;X9^+PJ#AGY0`X9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z?X9Z)
MX9^2X9Z)X9ZVXH"+X9ZBX9ZVX9Z:X9Z8X9^2X9Z8X9Z.X9^-XH"+X9Z*X9^"
MX9Z;XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<XH"+XH"+X9Z/
MX9ZVX9Z8XH"+X9ZBX9Z/X9^2X9Z0X9Z4X9Z1(.&>D>&?A>*`B^&>A^&>MN*`
MB^&>G^&>B>&?DN&>B>&>MN*`B^&>HN&>MN&>FN&>F.&?DN&>F.&>CN&?C>*`
MB^&>@.&?DN&>FN&>MN&>H.&?DN&>G.&>M^&>@,*@/P#AGH#AGX3AGX?B@(OA
MGH#AGKSAGH``X9Z%X9Z8X9^2X9Z;X9Z$`.&>A>&>F.&?DN&>F^&>A.*`B^&>
MD>&?A>*`B^&>D.&>CP#AGH#AGX(`X9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z*
MX9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9^"`.&>@.&>O.&>G^&?DN&>C^&>
MMN&>FN&>N.&>@.&>M@#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGHGA
MGY+AGH7AGI3AGXOB@(OAGI_AGX;AGH[AGK["H.&?E"#AGICAGKSAGIOAGJ#A
MGX'AGH_AGKOB@(OAGH+AGKK"H.&?EB`E<P#AGICAGK?AGI/B@(OAGJ+AGK;A
MGH7B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGH7AGKOAGH3B@(OAGH'AGK;A
MGH3B@(OAGH#AGY+AGIKAGX3AGID@5D93PJ#AGY8@)7,`X9Z8X9ZWX9Z3XH"+
MX9ZBX9ZVX9Z%XH"+X9Z;X9Z[X9Z4XH"+X9Z?X9ZVX9Z:XH"+X9Z6X9ZX("5S
MPJ#AGY0@X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^
MXH"+X9Z4X9ZVX9Z3XH"+X9Z3X9ZWX9Z9X9ZVX9Z9XH"+X9Z0X9ZVPJ#AGY8@
M)7,`X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9ZBX9Z3X9Z[X9Z<X9Z/X9^2
MX9Z/XH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z4X9Z/X9^2X9Z/X9ZWX9Z`X9ZVX9Z:
MXH"+X9Z/X9^&X9Z@X9^"X9Z1X9ZVX9^&PJ#AGY0`X9Z8X9ZWX9Z3XH"+X9ZB
MX9ZVX9Z%XH"+X9Z?X9^2X9Z:X9Z$X9^+XH"+X9Z%X9^!X9Z)XH"+X9ZOX9Z`
MX9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z?X9^2X9Z3
MX9Z^X9Z?X9Z[X9^&(.&>EN&>N.*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?
MDN&>A^&>MN&>E.&?BR!-4RU43D5&PJ#AGY0`X9Z8X9ZWX9Z3XH"+X9ZBX9ZV
MX9Z%XH"+X9Z?X9^2X9Z:X9Z$X9^+XH"+X9Z%X9^!X9Z)XH"+X9ZOX9Z`X9Z?
MX9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z?X9^2X9Z3X9Z^
MXH"+X9Z?X9Z[X9^&X9Z6X9ZXX9Z4X9^0X9Z.X9^2X9Z.X9Z?X9ZVX9Z:(%II
M<,*@X9^4`.&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>E.&>ON&>@.*`B^&>
M@.&>MN&>FN*`B^&>C^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>G^&>N^&>G.&>
MC^&?DN&>D.&>M^&>E^&>MN&>EN*`B^&>D>&?A>*`B^&>@.&>MN&>D^&?B^*`
MB^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>OB!)34%0
M(.&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4("5SPJ#AGY8@)7/"H.&?E`#A
MGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI'AGX7B@(OAGIGAGH#B@(OAGI;A
MGY#AGH_AGXSAGICAGK;AGI,@;F%M97-P86-E(.&>EN&>N.*`B^&>F.&?B>&>
MMN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>OB!)34%0PJ#AGY0`X9Z4
MX9^2X9Z:X9Z1X9^!X9Z?`.&>E.&>A.&?DN&>@.&>ON&>CP#AGI3AGH3AGY+A
MGH#AGK[AGH_B@(OAGI#AGH\`X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z`X9Z\
MX9Z3X9Z?X9^$`.&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>@N&>CN&>D^&>N.*`
MB^&>D.&?DN&>F.&>N.*`B^&>F.&>O>&>F0#AGI3AGH3AGY+AGH#AGK[AGH_B
M@(OAGI#AGH_B@(OAGI_AGK;AGIKB@(OAGJ7AGH_B@(OAGI3AGK;AGI/B@(OA
MGH#AGK;AGIKB@(OAGI#AGY+AGICAGKCB@(OAGICAGKWAGID`X9Z4X9Z$X9^2
MX9Z`X9Z^X9Z/XH"+X9Z0X9Z/XH"+X9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZXXH"+
MX9Z6X9^2X9Z:X9ZVX9Z$XH"+X9Z0X9^2X9Z8X9ZXXH"+X9Z8X9Z]X9Z9`.&>
ME.&>A.&?DN&>@.&>ON&>C^*`B^&>D.&>C^*`B^&>G^&?AN&>E.&>N^&>C^&?
MDN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>ON*`
MB^&>D.&?DN&>F.&>N.*`B^&>F.&>O>&>F0#AGI3AGH3AGY+AGH#AGK[AGH_B
M@(OAGI#AGH_B@(OAGI_AGX;AGIKAGK;AGICB@(OAGI#AGY+AGICAGKCB@(OA
MGICAGKWAGID`X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z`X9^2X9Z4X9Z]X9Z3
MXH"+X9Z/X9Z8X9^2X9Z:X9Z$(.&>BN&>ON&>F.&?DN&>E.&>N.*`B^&>FN&?
M@.&>E.*`B^&>A>&?AN*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>A>&>
MO.&>F^*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@"#AGH_AGICAGY+A
MGIKAGX#AGI3B@(OAGISAGK;B@(OAGH7AGKSAGIOB@(OAGH#AGY+AGI/AGKOA
MGH3B@(OAGI#AGH\@X9Z3X9ZWX9Z$(.&>F^&>N^&>E.*`B^&>G^&>MN&>FN*`
MB^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FL*@X9^4`.&>E.&>A.&?
MDN&>@.&>ON&>C^*`B^&>E>&?DN&>D>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?
MDN&>FN&?A.&>F>*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>D.&?DN&>
MF.&>N`#AGI3AGH3AGY+AGH#AGK[AGH_B@(OAGI7AGY+AGI'AGX/B@(OAGH'A
MGK;AGH3B@(OAGH#AGY+AGIKAGX3AGIGB@(OAGI_AGX;AGI3AGKOAGH_AGY+A
MGIH@X9Z@X9Z^X9Z9XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z`X9ZVX9Z:
MXH"+X9Z&X9^2X9Z;X9Z^X9Z9X9Z/X9Z4PJ#AGY0`X9Z`X9^2X9Z:X9Z\X9ZB
MX9ZVX9Z/`.&>@N&>N^&>F>&>E.&>M@#AGI;AGX'AGIOB@(OAGISAGX'AGIOA
MGK;B@(OAGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+AGI,`X9Z`X9ZV
MX9Z:XH"+X9Z%X9Z\X9Z;XH"+X9Z*X9^&X9Z.X9Z^X9Z:X9Z`X9ZVX9Z:XH"+
MX9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2X9Z4X9Z3X9^2X9Z3XH"+X9Z1X9^%("5S
M`.&>FN&>A>&>D^&>MN&>E.&?D.&>D>&?DN&>F.*`B^&>E.&>A>&?DN&>A>&>
MN^&>E.&?DN&>E.&>D^&?DN&>D^*`BP#AGI3AGY+AGH_AGKSAGIKB@(OAGH+A
MGH[AGI/AGKCB@(OAGH_AGK;AGICB@(OAGI3AGX;AGH[AGH0@X9Z*X9Z^X9Z8
MX9^2X9Z4X9ZXXH"+X9Z1X9^%XH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9
MX9Z`XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z6X9ZXX9Z"X9Z.X9Z3
MX9ZXXH"+X9Z5X9^2X9Z?X9^!X9Z$PJ#AGY0`X9Z4X9^2X9Z/X9Z\X9Z:XH"+
MXH"+XH"+X9Z:X9Z4X9^`X9Z4XH"+X9Z*X9^"X9Z;XH"+X9ZBX9^2X9Z3X9Z`
MXH"+X9Z5X9^2X9Z)X9Z^XH"+X9Z?X9ZVX9Z:XH"+X9Z/X9ZVX9Z8XH"+X9Z4
MX9^&X9Z.X9Z$PJ#AGY0`X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z7X9ZVX9Z:X9Z`
MX9ZWX9Z%X9^2X9Z%XH"+X9Z*X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9Z:X9Z/X9^+XH"+X9Z/X9ZVX9Z8XH"+X9Z4X9^&X9Z.X9Z$(.&>HN&>MN&>
MG^&?DN&>FN&?D.&>F>*`B^&>F^&>ON*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>
MF^*`B^&>D>&?A>*`BR`E<\*@X9^4`.&>@.&>MN&>C^&?BP#AGI_AGXKAGKCA
MGI;AGIKAGXT`X9Z?X9^*X9ZXX9Z:X9ZXX9Z;X9ZXX9Z`("A+3TDX+5(I`.*`
MB^*`B^&>G^&?BN&>N.&>FN&>N.&>F^&>N.&>@"`H5VEN9&]W<RTQ,C4Q*0#A
MGI_AGK;AGI+AGK;AGIKAGH[B@(OAGIKAGHKAGY+AGHOB@(OAGH;AGX'AGH``
M1$0`X9Z:X9ZVX9Z;X9^+XH"+X9Z0X9^2X9Z$X9^#`%]%X9Z`X9ZVX9Z;X9Z4
MX9Z:X9ZWX9Z%X9^2X9Z&X9^!X9Z1(`#AGH#AGK;AGIOAGI3AGIKAGK?AGH7A
MGY+AGH;AGX'AGI$`X9Z0X9^2X9Z$X9^#`.&>DN&?DN&>D^&>O`#AGI3AGK;A
MGI/B@(OAGI3AGHKAGK?AGI_AGX'AGI(`X9Z4X9ZVX9Z3XH"+X9Z4X9Z*X9ZW
MX9Z?X9^!X9Z2PJ#AGY8@`.&>E.&>D^&?DN&>D.&>F2#AGH7AGKSAGIOB@(OA
MGI3AGI/AGY+AGI'AGK;AGH_AGXL`X9Z;X9^&X9Z3X9ZVX9^&X9Z*X9Z^X9Z8
M`.&>G.&>MN&>F^*`B^&>G^&?DN&>G.&?@N&>A.&>FN&>@.*`B^&>F^&?AN&>
MD^&>MN&?AN&>BN&>ON&>F`#AGIOAGH#AGY+AGH'AGH[AGXCB@(OAGISAGK?A
MGI/AGK?AGH7AGY+AGH;AGY#AGIGB@(OAGH_AGICAGY+AGIKAGX#AGI3B@(OA
MGIOAGX;AGI/AGK;AGX;B@(OAGHKAGK[AGIC"H.&?E@#AGI'AGK?AGI_B@(OA
MGH_AGICAGY+AGIKAGX#AGI3B@(OAGIOAGX;AGI/AGK;AGX;B@(OAGHKAGK[A
MGIC"H.&?E@#AGI3AGK;AGI/B@(OAGI7AGY+AGH_AGIOAGXOB@(OAGI_AGK?A
MGI'AGK?AGY+AGI(`X9Z;X9Z[X9Z4`.&>F^&>N^&>E.*`B^&>@.&>O.&>D^&>
MG^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B"`E<P#AGIOAGKOAGI3B@(OA
MGH#AGKSAGI/AGI_AGX3B@(OAGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/A
MGY+AGI,`X9Z;X9Z[X9Z4XH"+X9Z0X9Z/XH"+`.&>F^&>N^&>E.*`B^&>D.&>
MC^*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>A^&?DN&>FN&>ON&>GP#A
MGIOAGKOAGI3B@(OAGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+A
MGIKAGX3AGIGB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH`X9Z;X9Z[X9Z4XH"+
MX9Z0X9Z/XH"+X9Z3X9ZWX9Z8X9ZWX9^2X9Z8X9Z/`.&>F^&>N^&>E.*`B^&>
MD^&>M^&>F>&>F.&>D^&?D.&>F>*`B^&>D.&>C^*`B^&>D^&>M^&>F.&?DN&>
MF.&>M^&>C^*`B^&>G^&>F.&?DN&>FN&>MN&>E.&?BR`E<P#AGIOAGKOAGI3B
M@(OAGH?AGKWAGIKB@(OAGHCAGIH`X9Z;X9Z[X9Z4XH"+X9Z?X9ZVX9Z:XH"+
MX9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z1X9^%XH"+X9Z4X9^2X9Z:X9Z8
MX9Z\X9Z;XH"+X9Z9X9Z`XH"+(.&>EN&>N.*`B^&>F.&?B>&>MN&>G^&?BN&>
MN.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>AN&?DN&>A.&>MN&>F<*@/P#A
MGIOAGKOAGI3B@(OAGI;AGKCB@(OAGI3AGY+AGIKAGH_AGK?AGI'AGK?AGI/B
M@(OAGIKAGI3AGI_AGXOB@(OAGH'AGY+AGHGAGKOAGX8`X9Z;X9Z[X9Z4XH"+
MX9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z*X9^"
MX9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z/XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+
MX9Z%X9ZVX9Z?X9^+(.&>D^&?A>*`B^&>EN&?@>&>F^*`B^&>A>&>MN&>E.&?
MB^*`B^&>E>&?DN&>C^&>ON&>F.*`B^&>D^&?@^*`B^&>@>&?@N&>K,*@/P#A
MGIOAGKOAGI3B@(OAGI#AGH_B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OA
MGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI7AGY+AGHGAGK[B@(OAGH7AGK;A
MGI_AGXL@X9Z3X9^%XH"+X9Z6X9^!X9Z;XH"+X9Z%X9ZVX9Z4X9^+XH"+X9Z5
MX9^2X9Z/X9Z^X9Z8XH"+X9Z3X9^#XH"+X9Z!X9^"XH"+X9ZLPJ`_`.&>F^&>
MN^&>E.*`B^&>A^&>O>&>FN&>BN&?@>&>@`#AGIOAGKOAGI3B@(OAGI_AGK;A
MGIKB@(OAGJ7AGH_B@(OAGI3AGK;AGI/B@(OAGH#AGK;AGIH`X9Z;X9Z[X9Z4
MPJ`_`.&>E.&>MN&>D^*`B^&>F^&>N^&>E`#AGI_AGK;AGIKB@(OAGHKAGX+A
MGIOB@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI0`X9Z4X9ZVX9Z3XH"+X9Z;X9Z[
MX9Z4XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+("(E
M<R+"H.&?E`#AGH#AGX;AGI;AGKOAGH3B@(OAGIOAGKOAGI0@X9Z3X9ZWX9Z$
M(.&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`B^&>G^&>MN&>F@#AGHKA
MGK;AGH[AGKKAGICAGXGAGK;AGH``X9Z4X9Z*X9ZWX9Z?X9^!X9Z2XH"+X9Z?
MX9^&X9Z.X9Z^`.&>E.&>BN&>M^&>G^&?@>&>DN*`B^&>G^&?AN&>CN&>ON*`
MB^&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>EN&?D.&>C^&?C.&>F.&>MN&>
MDR#AGI'AGX;AGI/AGX'AGIHOX9Z:X9Z<X9Z;X9^+`.&>A>&>N^&?AP#AGI;A
MGK?AGI;AGH[AGXSAGI/AGK8`X9Z6X9ZWX9Z6X9Z.X9^,X9Z3X9ZVPJ#AGY8`
MX9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZXXH"+X9Z;X9Z8X9^2X9ZBX9ZWX9Z/`.*`
MB^&>HN&>E^&>M^&>G.&>C.&?DN&>C0#AGICAGK?AGI/B@(OAGI3AGK;AGI/B
M@(OAGI?AGY+AGH?AGK;AGI3AGXL@(B5S(B#AGJ'AGK[AGID@X9Z*X9^$X9Z9
MXH"+X9Z?X9ZVX9Z:XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z1X9Z1X9^!PJ#A
MGY0`X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z@X9Z/X9^2X9Z0X9Z;
MX9^!X9Z!X9ZVXH"+X9Z6X9ZWX9Z4X9ZVX9Z`XH"+X9Z8X9Z^X9Z;XH"+X9ZL
MPJ`_`.&>D.&>CP#AGI3AGH3AGY+AGJ#AGK;AGHD`X9Z4X9Z$X9^2X9Z@X9ZV
MX9Z)XH"+X9Z`X9ZVX9Z:XH"+X9ZBX9^'X9ZBX9ZVX9Z$(.&>E.&>D^&?DN&>
MD>&>MN&>E.&?B^*`B^&>EN&>N.&>E>&?DN&>B>&>ON*`B^&>G^&>MN&>FN&>
MF.&>O>&>F<*@/P#AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGH#AGY+AGI/AGKOA
MGH3B@(OAGH_AGKWB@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIH`X9Z4X9Z$
MX9^2X9Z@X9ZVX9Z)XH"+X9Z`X9ZVX9Z:XH"+XH"+X9Z'X9Z\X9Z3X9Z*X9^&
MX9Z.X9ZYX9Z$XH"+X9Z*X9^"X9Z;XH"+X9Z;X9^!X9Z%X9ZAX9Z^X9Z$XH"+
MX9Z:X9Z4X9Z?X9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9^2
MX9Z8X9ZXPJ`_`.&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>C^&?AN&>CB`BX9Z?
MX9Z8X9^2X9ZBX9ZVX9Z/XH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZV
MX9Z3XH"+X9Z`X9ZVX9Z:(B#AGH#AGY+AGI/AGKOAGH3B@(OAGIKAGI3AGK;A
MGIKB@(OAGICAGXGAGKKAGI/AGKOAGIG"H#\`X9Z4X9Z$X9^2X9Z@X9ZVX9Z)
MXH"+X9Z/X9^&X9Z.("+AGI_AGICAGY+AGJ+AGK;AGH_B@(OAGI_AGX;AGIKA
MGK;AGI@B(.&>@.&?DN&>D^&>N^&>A.*`B^&>FN&>E.&>MN&>FN*`B^&>F.&?
MB>&>NN&>D^&>N^&>F<*@/P#AGH7AGIKAGK?AGH_"H.&?E@#AGJ#AGY+AGI_A
MGXKAGKCAGI3AGKSAGI'AGK@`X9Z8X9ZWX9Z3XH"+X9Z5X9^2X9Z"X9Z\X9Z5
MX9^2X9Z"X9Z$`.&>@.&>N^&?AN*`B^&>EN&>M^&>D^&>M^&>C^&?DN&>F>*`
MB^&>F.&>ON&>F^*`B^&>D.&>CR#AGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OA
MGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI#AGY+AGICAGK@`X9Z`X9Z[X9^&
MXH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z/X9^&X9Z.XH"+X9Z8X9Z]X9Z9
MXH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z'X9Z]X9Z:XH"+X9Z(X9Z:XH"+("+A
MGI;AGKC"H.&?EB(`X9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z%X9Z$X9^+
MXH"+X9Z4X9Z^X9Z`XH"+X9Z0X9Z/XH"+X9Z3X9^$X9^'XH"+X9ZLPJ`_`.&>
MBN&>O.&>F.&>N.&>D^&>N.&>@.&>M@#AGI_AGK;AGI+AGK;AGIKAGH[AGIKA
MGHKAGY+AGHOB@(OAGHKAGKSAGICAGKCAGI/AGKCAGH#AGX+AGI,`X9Z8X9ZW
MX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z"X9Z.X9Z3X9ZXPJ`_(.&>G^&>O.&>F.*`
MB^&>A>&>N^&?A^&>B.&?DN&>F.&?A.&?A\*@X9^4`.&>DN&?DN&>G.&>ON*`
MB^&>FN&>O>&>A0#AGI'AGK;AGHGAGIGAGH``X9Z1X9ZVX9Z)X9Z9X9Z`("5S
M(.&>A^&>MN*`B^&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F2`N>FEP
M`.&>D>&>MN&>B>&>F>&>@.*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>
MA^&>MN&>E.&?B^*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?BR`HX9Z'X9ZVXH"+
MX9ZOX9Z`X9Z?X9ZVX9Z:("YZ:7`I`.&>D>&>MN&>B>&>F>&>@"#B@(OAGI#A
MGH\`X9Z1X9ZVX9Z)X9Z9X9Z`XH"+(.&>D.&>C^*`B^&>E>&?DN&>G^&?@>&>
MA.&?ER!;X9Z1X9^2X9Z:X9Z$X9^+XH"+X9Z1X9^2X9Z:X9ZVX9Z9("YZ:7!=
M`.&>D>&>MN&>B>&>F>&>@.*`B^&>A^&>MN*`B^&>D>&?DN&>FN&>A.&?B^*`
MB^&>D>&?DN&>FN&>MN&>F2`N>FEP`.&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`
MB^&>EN&?DN&>FN&>MN&>A`#AGI#AGH_B@(OAGI_AGX'AGH7AGH#AGY+AGH_A
MGKCB@(OAGI;AGY+AGIKAGK;AGH0`X9Z0X9Z/XH"+X9Z?X9^!X9Z%X9Z`X9^2
MX9Z/X9ZXXH"+X9Z6X9^2X9Z:X9ZVX9Z$PJ#AGY8`X9Z?X9^&X9Z4X9Z[X9Z/
MX9^2X9Z:XH"+X9Z0X9ZVX9Z8X9Z<X9Z3X9^2X9Z/`.&>HN&?BN&>N.&>F.&?
M@N&>FP#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCA
MGICAGX+AGIL`X9Z%X9Z[X9Z$X9Z4X9Z)X9^2X9Z%X9Z4X9^+`.&>@.&?AN&>
MH.&>N^&>G\*@X9^6(.&>G^&>MN&>FN*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?
MDN&>D^&>@.*`B^&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>D>&?
MA>&>BN&>F^&?B\*@X9^4`.&>HN&?@>&>@.&?DN&>G.&>MN&>C.&?D.&>F@#A
MGH#AGX+B@(OAGI_AGICAGY+AGIKAGKWAGIL`X9Z`X9^"X9Z?X9Z8X9^2X9Z:
MX9Z]X9Z;XH"+X9Z?X9^&X9Z.X9Z]X9Z:XH"+X9Z?X9^2X9Z<X9^"X9Z$X9Z:
MX9Z``.&>@.&?@N*`B^&>G^&>F.&?DN&>FN&>O>&>F^*`B^&>D.&>C^*`B^&>
MD^&>M^&>F.&>M^&?DN&>F.&>CP#AGH#AGX+B@(OAGI_AGICAGY+AGIKAGKWA
MGIOB@(OAGI/AGK?AGIGAGICAGI/AGY#AGIGB@(OAGI#AGH_B@(OAGI/AGK?A
MGICAGY+AGICAGK?AGH_B@(OAGI_AGICAGY+AGIKAGK;AGI3AGXL@)7,`X9Z`
MX9^"X9Z?X9Z8X9^2X9Z:X9Z]X9Z;XH"+X9Z4X9Z)X9^2X9Z'X9ZXXH"+X9Z!
MX9^2X9Z8X9^%XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z``.&>@.&?
M@N&>G^&>F.&?DN&>FN&>O>&>F^*`B^&>@.&?DN&>E.&>O>&>D^*`B^&>C^&>
MF.&?DN&>FN&>A.*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@`#AGH#A
MGX+AGI_AGICAGY+AGIKAGKWAGIOB@(OAGI3AGHGAGY+AGH?AGKCB@(OAGI_B
M@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH``X9Z`X9^"XH"+X9Z?X9Z8
MX9^2X9Z:X9Z]X9Z;XH"+X9Z%X9^&X9Z.X9Z$X9^+XH"+X9Z%X9^&X9Z.X9Z\
MX9Z;XH"+X9Z%X9ZWX9Z/X9^2X9Z/XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2
MX9Z3X9Z`(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>A>&>O.&>F^*`B^&>
MBN&?AN&>CN&>ON&>FN&>@.&>MN&>FN*`B^&>@N&>CN&>D^&>N.*`B^&>G^&?
MAN&>E.&>N^&>C^&?DN&>FN*`B^&>E>&?DN&>G^&?@>&>A.&?E\*@X9^4`.&>
M@.&>MN&>FN*`B^&>HN&>E.&?B^&>FN&?A@#AGJ+AGX'AGJ#AGY+AGI_AGXKA
MGKCAGI0`X9ZBX9^"X9Z;X9Z?X9ZVX9Z;X9^+X9Z<X9^)X9ZVX9Z,X9^0X9Z:
M`.&>HN&?BN&>N.&>F.&?@N&>FP#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;A
MGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIL`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+
MX9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z/X9^"XH"+X9Z*X9Z\X9Z%X9Z"X9^2X9Z3X9ZVPJ#AGY0`X9Z?X9Z)
MX9^2X9Z)X9ZVXH"+X9ZBX9ZVX9Z:X9Z8X9^2X9Z8X9Z.X9^-`.&>E.&>MN&>
MD^*`B^*`B^&>F^&>N^&>E.*`B^&>E.&?AN&>E.&>MN&>C^&?B^&>G^&>MN&>
MFN*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?B^*`B^&>EN&>N"`E<\*@X9^4`.&>
ME.&>MN&>D^*`B^&>G^&>F.&?DN&>HN&>MN&>C^*`B^&>G^&>MN&>FN*`B^&>
MD>&>MN&?AN&>A.&>HN&>G^&?B^*`B^&>EN&>N.*`B^&>D.&>C^*`B^&>G^&?
MAN&>FN&>MN&>F.*`B^&>D^&>M^&>F.&?DN&>F.&>M^&>C\*@X9^4`.&>G^&>
MF.&?DN&>HN&>MN&>C^*`B^&>D.&>CP#AGI_AGICAGY+AGJ+AGK;AGH_B@(OA
MGI#AGH_B@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGH?AGY+AGIKAGK[A
MGI\`X9Z?X9Z8X9^2X9ZBX9ZVX9Z/XH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZV
MX9Z8`%]3X9Z?X9Z8X9^2X9ZBX9ZVX9Z/XH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/
MXH"+X9Z4X9ZVX9Z3XH"+X9Z`X9ZVX9Z:(`!?5.&>G^&>F.&?DN&>HN&>MN&>
MC^*`B^*`B^&>G^&?AN&>FN&>MN&>F"``X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2
MX9Z9XH"+X9Z8X9Z[X9Z!XH"+X9Z$X9ZVX9Z:(%!'4"#AGI3AGY+AGIKAGK[B
M@(OAGI3AGK;AGI/"H#\`X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z8
MX9Z[X9Z!X9Z$X9ZVX9Z:(%,O34E-12#AGI3AGY+AGIKAGK[B@(OAGI3AGK;A
MGI/"H#\`X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z`X9ZVX9Z:XH"+
MX9Z8X9Z^X9Z;XH"+X9Z?X9ZVX9Z:XH"+X9Z'X9ZVXH"+X9Z8X9Z[X9Z3XH"+
MX9Z4X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3PJ`_`%]9X9Z'X9Z8X9^2X9Z:X9Z^
MX9Z?XH"+X9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z'X9ZVXH"+X9Z`X9Z\X9Z*
M(`#AGI3AGK;AGI/B@(OAGI3AGICAGY+AGIOAGX+AGH3B@(OAGH?AGK;B@(OA
MGH#AGKSAGHH`X9Z4X9Z)X9^2X9Z%X9Z4X9^+`.&>E.&>B>&?DN&>A>&>E.&?
MB^*`B^&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>E.&>
MB>&?DN&>A^&>O.&>D^*`B^&>E.&>D^&?DN&>CP#AGI3AGHGAGY+AGH7AGI3A
MGXOB@(OAGI_AGK;AGIH`X9Z4X9Z)X9^2X9Z%X9Z4X9^+XH"+X9Z?X9ZVX9Z:
MXH"+X9Z6X9ZX("5S`.&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>@^&?DN&>F^&>
MMN*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?BP#AGI3AGHGAGY+AGH7AGKSAGIOB
M@(OAGHCAGY+AGICAGX3AGX?B@(OAGI#AGY+AGICAGK@@X9Z?X9Z8X9^2X9Z:
MX9ZVX9Z4X9^+XH"+X9Z0X9Z/XH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4
MX9ZVX9Z3XH"+X9Z`X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZXXH"+X9Z:X9Z4X9Z?
MX9^+XH"+X9ZBX9^2X9Z3X9Z``.&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>B.&?
MDN&>F.&?A.&?AR#AGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OAGI#AGH_B@(OA
MGI_AGX'AGH7AGH#AGY+AGH_AGKCAGI;AGY+AGIKAGK;AGH3B@(OAGI#AGY+A
MGICAGKCB@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH``X9Z4X9Z)X9^2
MX9Z%X9Z\X9Z;XH"+X9Z(X9^2X9Z8X9^$X9^'(.&>G^&>F.&?DN&>FN&>MN&>
ME.&?B^*`B^&>D.&>C^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>BN&?
M@N&>F^*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>ON*`B^&>D.&?DN&>F.&>
MN.*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@`#AGI3AGHGAGY+AGH7A
MGKSAGIOB@(OAGHCAGY+AGICAGX3AGX<@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+
MXH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8XH"+X9Z0X9^2X9Z8X9ZXXH"+
MX9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z``.&>G^&>MN&>FN*`B^&>D>&>
MMN&?AN&>A.&>F.&>O.&>FP#AGI+AGK;AGH_AGKL@(B5S(B#AGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGI/AGY+AGI#AGX+AGICB@(OAGHKA
MGX3AGIGB@(OAGH?AGX3AGH+AGH?AGY#AGID@X9Z1X9^%XH"+X9Z?X9^`X9Z<
MX9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3`.&>H.&?DN&>
M@N&>N.&>CN&?@>*`B^&>HN&?@>&>@.&?DN&>G.&>MN&>D>&?D.&>F@#AGJ+A
MGX'AGIKAGKCAGI'AGY+AGIKAGK8`X9Z`X9^&X9Z@X9Z[X9Z?`.&>@.&?AN&>
MH.&>N^&>G^*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>C^&>
ME^&?DN&>A^&>MN&>E.&?B^*`B^&>D>&?A>*`B^&>@.&>MN&>D^&?B^*`B^&>
MF.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>OB!)34%0PJ#A
MGY0@)7/"H.&?EB`E<\*@X9^4`.&>@.&?AN&>H.&>N^&>G^*`B^&>@.&?DN&>
MD^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>
MG^&>MN&>FL*@X9^4`.&>@.&?AN&>H.&>N^&>G^*`B^&>E.&>B>&?DN&>A^&>
MO.&>D^*`B^&>@.&>MN&>FN*`B^&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E.*`
MB^&>D>&?A<*@X9^6("5SPJ#AGY0`X9ZBX9^!X9Z?X9^2X9Z/X9Z\X9Z3X9ZX
M`.&>HN&?@>&>C^&?DN&>F>&>O.&>EN&>N`#AGJ+AGKKAGIKAGXGAGKOAGI0`
MX9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4XH"+X9Z6X9^2X9Z:X9ZYX9Z/X9^2X9Z/
MX9ZWX9Z`X9ZVX9Z:X9Z.X9^-XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"XH"+
MX9Z'X9^0X9Z9PJ#AGY0`X9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+(.&?
MH>&?I2#AGI/AGK;AGI'AGK@`X9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+
M(.&?H^&?H"#AGISAGK?AGI/AGK;AGI'AGK@`X9Z:X9^`X9Z$XH"+X9Z:X9ZV
MX9Z;X9^+(.&?I2#AGI/AGK;AGI'AGK@`X9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;
MX9^+XH"+X9Z`X9Z3X9^2X9Z;X9^'XH"+X9Z8X9^)X9^$X9Z$`.&>FN&?@.&>
MA.*`B^&>FN&>MN&>F^&?B^&>D^&>MN&>D>&>N`#AGI3AGY+AGIKAGH_AGK?A
MGI3AGH_AGY+AGH_AGK<`X9Z4X9Z3X9^2X9Z;X9ZVX9Z9`.&>E.&>D^&?DN&>
MF^&>MN&>F>*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?BP#AGI3AGI/AGY+AGIOA
MGK;AGIGB@(OAGI#AGH_B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXL`X9Z4X9Z3
MX9^2X9Z;X9ZVX9Z9XH"+X9Z0X9Z/`.&>E.&>D^&?DN&>F^&>MN&>F>*`B^&>
MB.&?DN&>F.&?A.&?AP#AGI3AGI/AGY+AGIOAGK;AGIGB@(OAGHCAGY+AGICA
MGX3AGX?B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI3AGH3AGY+AGJ+AGKWAGH7B
M@(OAGH_AGX+AGH3AGHKAGX3AGIGB@(OAGI_AGY+AGISAGY#AGIGB@(OAGI3A
MGY+AGIKAGISAGH_AGY+AGH_AGK<@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z5X9^2
MX9Z1X9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9PJ`_`.&>E.&>
MD^&?DN&>F^&>MN&>F>*`B^&>F.&?@N&>@.*`B^&>DN&>MN&>A.*`B^&>D.&>
MC^*`B^&>D>&>MN&?AN&>A.*`B^&>F.&>O.&>F^*`B^&>A^&>MN*`B^&>F^&?
MAN&>D^&>MN&?AN&>BN&>ON&>F"#AGH#AGY+AGI/AGKOAGH3B@(OAGI'AGK?A
MGHKAGY+AGHOAGI?AGK;AGI;B@(OAGI#AGH_"H#\`X9Z`X9ZVX9Z:XH"+X9Z4
MX9Z3X9^2X9Z;X9ZVX9Z9`.&>HN&?BN&>M^&>A>&>G^&?DN&>E.&>O.&>CN&>
MA.&?B^&>G^&?@N&>FP!?1>&>D>&?A>*`B^&>E.&?DN&>FN&>F.&>O.&>F^*`
MB^&>F>&>@.*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FB``X9Z`X9^$X9^'XH"+
MX9Z@X9^2X9Z<X9^)X9Z`X9ZAX9Z$X9^+("CAGICAGXGAGK;AGIOAGXOAGISA
MGKCAGH[AGK8I`.&>@.&?A.&?A^&>H.&?DN&>G.&>MN&>HN&?@>&>FN&>O`#A
MGI'AGKSAGIKAGI_AGK;AGIH`X9Z`X9Z[X9Z8X9^2X9Z7X9^(`"+AGI'AGX7B
M@(OB@(OAGI3AGY+AGIKAGICAGKSAGIOB@(OAGIGAGH#B@(OAGI_AGX;AGI3A
MGKOAGH_AGY+AGIHB`"+AGI'AGX7B@(OAGI3AGY+AGIKAGICAGKSAGIOB@(OA
MGIGAGH#B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIHB(.*`B^&>@.&?DN&>D^&>
MN^&>A.*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`B^&>E>&?DN&>G^&?@>&>A.&>
MK,*@/P#AGI'AGX7B@(OAGI3AGY+AGIKAGICAGKSAGIOB@(OAGIGAGH#B@(OA
MGI_AGK;AGIH@X9ZBX9ZVX9Z?X9^2X9Z:X9^0X9Z9XH"+X9Z;X9Z^XH"+X9Z`
MX9ZVX9Z:XH"+X9Z%X9Z\X9Z;X9ZLPJ`_`.&>E.&>MN&>D^*`B^&>D>&?A>*`
MB^&>E.&?DN&>FN&>F.&>O.&>F^*`B^&>F>&>@.*`B^&>G^&>MN&>FN*`B^&>
MA>&?AN&>D^&>O>&>DR`E9"#AGI;AGK@@)7,`X9Z4X9ZVX9Z3XH"+X9Z1X9^%
MXH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`XH"+X9Z?X9ZVX9Z:XH"+
MX9Z%X9^&X9Z3X9Z]X9Z3(.&?H2#AGI;AGK@@)7,`X9Z1X9^%XH"+X9Z4X9^2
MX9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:
MPJ#AGY8`X9Z1X9^%XH"+XH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`
MXH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:PJ#AGY8@X9Z"X9^2X9Z8X9ZVX9Z3
MXH"+X9Z?X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZXPJ#AGY0`7TSAGH_AGICAGY+A
MGIKAGH0@`.&>H.&?DN&>G.&>N.&>H.&?DN&>G^&?BN&>N`#AGJ_AGH#AGI_A
MGK;AGIH`X9Z(X9^2X9Z8X9^$X9^'XH"+X9ZOX9Z`X9Z?X9ZVX9Z:`.&>A^&>
MF.&?DN&>FN&>ON&>G^*`B^&>FN&>E.&>G^&?B^*`B^&>C^&>F.&?DN&>FN&>
MA`#AGH#AGK;AGIKB@(OAGH#AGX;AGH[AGH_AGXOB@(OAGH_AGICAGY+AGIKA
MGH0`X9Z/X9^2X9Z:X9Z$XH"+X9Z8X9ZVX9Z/X9ZWX9Z`X9ZVXH"+X9Z:X9Z4
MX9Z?X9^+XH"+X9Z?X9ZVX9Z:(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>
ME^&>MN&>EN*`B^&>HN&>MN&>G^&>@N&?DN&>FN&>MN&>F,*@/P#AGH#AGK;A
MGIKB@(OAGH+AGK;AGX;AGI'AGY+AGIKB@(OAGH_AGICAGY+AGIKAGH3B@(OA
MGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISAGK[B@(OA
MGK+AGY+AGIGB@(OAGI3AGY+AGIKAGK[B@(OAGIOAGX+AGH3B@(OAGI3AGK;A
MGI,@XH"+X9Z;X9Z^XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z3
MX9^!X9^'PJ#AGY0`X9Z/X9Z8X9^2X9Z:X9Z$`.&>C^&>F.&?DN&>FN&>A.*`
MB^&>F.&>M^&>D^*`B^&>G^&>@.&>F.&?DN&>F`#AGH_AGICAGY+AGIKAGH3"
MH.&?EB#AGI'AGX;AGI;AGY#AGIKB@(OAGH+AGY+AGIKAGI3AGXOB@(OAGH+A
MGY+AGIKAGH0@)7,`X9Z:X9Z`PJ#AGY8`X9Z@X9^2X9Z<X9ZVX9^&X9Z$X9ZA
MX9Z$X9^+`.&>D>&?AN&>EN&?D.&>FN*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`
MB^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>BN&?AN&>E.&>O.&>A`#AGI'A
MGX;AGI;AGY#AGIKB@(OAGHKAGX;AGI3AGKSAGH0`X9Z/X9^2X9Z:X9ZAX9Z4
MX9^+`.&>D>&>G^&>E^&>MN&>@@!?4N&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>
ME.&>D^&?DN&>CR``X9ZBX9^&X9Z6X9Z^XH"+X9Z0X9Z/("T@X9ZBX9^'X9ZB
MX9ZVX9Z$`.&>@.&>F.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>FN&>N^&>@.*`
MB^&>FN&>@.*`B^&>D.&>CP#AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI_A
MGH3AGY+AGH'AGX'AGI3B@(OAGIKAGI3AGI_AGXOB@(OAGI#AGH\`X9Z`X9ZV
MX9Z:XH"+X9Z%X9^"X9Z`XH"+X9Z:X9^&X9Z;X9^"X9Z`XH"+X9Z0X9Z/XH"+
MX9Z"X9ZZXH"+X9ZBX9Z?X9Z`X9Z8X9^2X9Z8PJ#AGY0`X9Z`X9ZVX9Z:XH"+
MX9Z4X9^2X9Z:X9Z^XH"+X9Z0X9Z/XH"+X9Z"X9ZZXH"+X9ZBX9Z?X9Z`X9Z8
MX9^2X9Z8PJ#AGY0`X9Z6X9Z.X9^,XH"+X9Z6X9Z[X9Z8X9^2X9Z6XH"+X9ZB
MX9Z`X9^2X9Z?X9Z:`.&>D>&?DN&>FN&>A.&?B^*`B^&>D>&?DN&>FN&>MN&>
MF>*`B^*`B^&>D^&?@^*`B^&>@.&>MN&>F^*`B^&>E.&>FN&>M^&>A>&?DN&>
MAN&?@>&>D>*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>FB#AGH#AGY+AGI/A
MGKOAGH3B@(OAGI'AGK?AGHKAGY+AGHOAGI?AGK;AGI;B@(OAGI3AGY+AGIKA
MGJ+AGI3AGXOAGI_AGX;AGI3AGKOAGH_AGY+AGIH@X9Z?X9Z8X9^2X9Z:X9ZV
MX9Z4X9^+X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z%
MX9Z[X9^'XH"+X9Z`X9ZVX9Z;XH"+X9Z4X9Z:X9ZWX9Z%X9^2X9Z&X9^!X9Z1
MXH"+X9Z0X9^2X9Z$X9^#XH"+X9Z3X9^!X9^'`.&>G^&?AN&>CN&>N^&?AN*`
MB^*`B^&>E.&?@N&>E.&>E.&>D0#AGI3AGHGAGY+AGH?AGKSAGI/B@(OAGI3A
MGI/AGY+AGH\`X9Z4X9Z)X9^2X9Z'X9Z\X9Z3XH"+X9Z4X9Z3X9^2X9Z/PJ#A
MGY8`X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z)
MX9^2X9Z'X9Z\X9Z3XH"+X9Z4X9Z3X9^2X9Z/`.&>G^&>MN&>FN*`B^&>BN&?
M@N&>F^*`B^&>E.&>MN&>D^*`B^&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>E.&>
MD^&?DN&>C^*`B^&>EN&>N"`E<P#AGI_AGXKAGKOAGI@`X9Z4X9ZVX9Z:X9ZV
MX9^&X9Z$`.&>@.&>MN&>FN*`B^&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E.*`
MB^&>G^&?AN&>CN&>OB#AGI'AGX;AGI/AGX'AGIHOX9Z:X9Z<X9Z;X9^+`.&>
MH.&?DN&>@N&>O.&>HN&?BN&>N.&>F>&?B>&>MN&>CN&>MB#AGI3AGK;AGIKA
MGK;AGX;AGH0`X9Z4X9^)X9Z\X9Z;X9ZXX9Z3X9^!X9Z?X9^*X9ZXXH"+X9Z4
MX9ZVX9Z:X9ZVX9^&X9Z$`.&>HN&>MN&>CN&>A>&>@.&?DN&>FN*`B^&>@>&>
MMN&>A.*`B^&>C^&?DN&>E.&>O.&>A"#AGI3AGK;AGIKAGK;AGX;AGH0`7TWA
MGI;AGK@@`.&>EN&>N`#AGI;AGKCB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI,`X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z6X9^!X9Z)`.&>E.&>B>&?DN&>
MA^&>O.&>D^*`B^&>E.&>D^&?DN&>C\*@X9^6`.&>E.&>B>&?DN&>A^&>O.&>
MD^*`B^&>E.&>D^&?DN&>C\*@X9^6`.&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>
ME.&>D^&?DN&>C\*@X9^6(.&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>
MMN&>D^*`B^&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>E.&>D^&?DN&>CR`E=0#A
MGJ#AGY+AGH+AGK;AGI3AGKOAGH0`X9Z@X9^2X9Z`X9ZVX9^&X9Z4X9^*X9ZX
M`.&>A^&>F.&?DN&>FN&>ON&>G^*`B^&>D>&>O.&>D>&?A0#AGJ#AGY+AGI_A
MGH#AGJ#AGY+AGI_AGXKAGK@`X9ZBX9ZVX9Z;X9^2X9Z;X9ZZX9Z8X9^)X9Z$
MX9^+`.&>F>&>@.*`B^&>C^&?@N*`B^&>G^&>MN&>FN*`B^&>D.&?DN&>F.&>
MN,*@/R`HX9Z/X9^"($E-05`I`.&>H.&?DN&>@.&>MN&>CN&>M@#AGJ#AGY+A
MGH+AGKCAGI3AGY+AGIKAGK;AGIOAGXOAGH_AGK8`X9Z3X9ZVX9Z8X9Z!X9^2
MX9Z;X9Z]X9Z3`.&>A^&>F.&?DN&>FN&>ON&>G^*`B^&>G^&>@.&>FP#AGI'A
MGX4`X9Z1X9^%XH"+X9Z`X9ZVX9Z3X9^+XH"+X9Z?X9ZVX9Z:`.&>D>&?A>*`
MB^&>@.&>MN&>D^&?B^*`B^&>DN&>MN&>C^&>N^*`B^&>G^&?@.&>G.&>E^&?
MA>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>D^&?@R`B)7,B
M`.&>HN&>D^&>N^&>B>&?DN&>B>&>MN&>C^*`B^&>LN&?DN&>F>*`B^&>A>&>
MO.&>F^*`B^&>BN&?AN&>CN&>ON&>FN&>@.&>MN&>F@#AGICAGK;AGH_AGY+A
MGIKAGHKAGY+AGHOAGK;AGI/B@(OAGI3AGY+AGIKAGI7AGX'AGX<`X9Z`X9^2
MX9Z:X9ZWX9Z``.&>@.&?DN&>FN&>M^&>@"`H25-/+3@X-3DM-RD`X9Z"X9^2
MX9Z:X9ZXX9ZAX9Z$X9^+`.&>H.&?DN&>@N&?DN&>FN&>N.&>CN&>MN&>BN&>
MM@#AGH#AGY+AGIKAGKOAGI@`X9Z@X9^2X9Z"X9Z\X9ZBX9ZVX9Z*X9ZZX9Z;
MX9Z\X9Z4X9^)X9^!`.&>H.&?DN&>@N&>MN&?AN&>F`#AGJ#AGY+AGH+AGK;A
MGH_AGX'AGICAGXGAGK;AGJ'AGK8`X9Z@X9^2X9Z"X9ZXX9Z.X9^!`.&>H.&?
MDN&>@N&>N.&>CN&?@>&>E.&?BN&>N.&>G^&?A0#AGJ#AGY+AGH+AGKCAGIGA
MGXGAGK;AGH[AGK8`X9Z1X9ZXX9Z3X9^!X9^'`$A434P`X9Z`X9^&X9Z.X9^"
M($A434P@X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:`.&>H.&?@^&>D>&>N`#A
MGI3AGHOAGICAGH#AGI#AGK;B@(L`X9Z4X9Z+X9Z8X9Z`X9Z0X9ZV`.&>@.&?
MA.&?A^*`B^&>H.&?BN&>ON&>BB#AGI/AGK?AGH0@X9Z`X9^$X9^'XH"+X9Z8
MX9^)X9ZVX9Z`X9Z*X9Z\X9Z.X9ZVX9Z;X9^+`.&>@.&>F.&?DN&>EN&>G^&?
MBP#AGH?AGX;AGI/AGKWAGID`X9Z3X9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZV
MXH"+X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4
MX9ZVX9Z3XH"+X9Z`X9^&X9Z6X9Z[X9Z$XH"+X9Z/X9^"X9Z$PJ#AGY8`X9Z;
MX9ZVX9Z`X9^+`.&>F^&>MN&>@.&?B^*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>
MD>&>M^&>BN&?DN&>B^&>E^&>MN&>EN*`B^*`B^&>@>&?DN&>G^&?@N*`B^&>
MHN&?AN&>E.&?A.&?AP#AGIOAGK;AGH#AGXL@(N&>E.&>MN&>D^*`B^&>F^&>
MN^&>E"(`X9Z;X9ZVX9Z`X9^+("+AGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OA
MGH?AGK;AGIPB`.&>@>&?DN&>EN&>G^&?BP#AGJ+AGK;AGI'AGK?AGI?AGK;A
MGI;B@(OAGH'AGY+AGI;AGI_AGXL`X9Z!X9^2X9Z6X9Z?X9^+XH"+X9Z4X9^&
MX9Z5X9Z[X9Z/`.&>H.&>O.&>F^&>N.&>G^&?BN&>N"`HX9Z:X9Z*X9^2X9Z+
MXH"+X9Z`X9^2X9Z:X9Z[X9Z$XH"+X9Z<X9^)X9ZVX9Z1X9ZXX9Z`X9Z$X9^+
M*0#AGH+AGX'AGJ#AGI'AGX;AGI;AGY#AGIH`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2
MX9Z+X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9^'`.&>D.&>C^&>E>&?DN&>D>&?AP#A
MGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI'B@(OAGI7AGY+AGI'AGX<`X9Z@X9Z[
MX9Z$X9Z,X9Z\X9Z:X9^)X9ZVX9Z?X9^+`.&>H.&>N^&>A.&>@.&>N^&>A`#A
MGH_AGK[B@(OAGJ+AGY+AGI/AGH#B@(OAGH7AGH3AGXOB@(OAGI3AGH3AGY+A
MGJ#AGK;AGHGB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3A
MGXOB@(OAGIGAGXGAGK;AGH3B@(OAGHKAGKSAGH7AGICAGY+AGH_AGX'AGH7"
MH#\`X9Z:X9Z4X9^`X9Z4XH"+X9Z`X9^&X9Z.X9Z/X9^+XH"+X9Z4X9Z3X9^2
MX9Z1X9ZVX9Z/X9^+XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z*X9Z`
MXH"+X9Z?X9^2X9Z:X9Z$X9^+(.&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>
MFN*`B^&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E`#AGJ#AGKOAGH3AGH+AGY+A
MGIKAGK@`24U!4`!)34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I`.&>F.&?
MB>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>OB!)34%0(.&>E.&>
MMN&>D^*`B^&>E.&>M^&>D>*`B^&>@.&>MN&>FN*`B^&>C^&>E^&?DN&>A^&>
MMN&>E.&?B\*@X9^4(.&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?
MDN&>FN&>ON*`B^&>E.&>MN&>D^*`B^&>AN&?DN&>F^&>ON&>F>&>C^&>E.*`
MB^&>D.&>ML*@X9^6("5S`$E-05`@X9Z;X9Z^(%-33`!)34%0(.&>F^&>OB!3
M4TP@*.&>G.&>M^&>B>&?DN&>B>&>MN&>E.&>D^&>E.&>C^&?DN&>FN*`B^&>
MBN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>A>&>N^&?A^*`B^&>H.&>C^&?DN&>
MD.&>F^&?@>&>@>&>MN*`B^&>BN&?A.&>F>*`B^&>@>&?DN&>F^&>O>&>D^*`
MB^&>K^&>A"D`X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:
MX9Z^($E-05`@X9Z4X9ZVX9Z3XH"+X9Z4X9ZWX9Z1XH"+X9Z`X9ZVX9Z:XH"+
MX9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+PJ#AGY0`24U!4"#AGH+AGY+AGICAGK;A
MGI,@5$Q3`.&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>
MON*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FB!)34%0+U!/4#,`X9Z4X9^2X9Z:
MX9ZBX9Z4X9^+XH"+X9Z1X9Z1X9Z]X9Z;`.&>HN&>MN&>G^&>F>&>BN&?DN&>
MB^&>MN&>D^*`BR!)4`#AGJ+AGXKAGKCAGI_AGY+AGIOAGH3AGXL`X9Z/X9^"
MXH"+X9Z:X9Z\X9Z4X9Z/X9^&X9Z.X9ZVX9Z$`.&>E.&>ON*`B^&>E.&?DN&>
MFN&>OB!34TP@X9ZL(%1,4RP@X9ZBX9^2X9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z/X9^"XH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9Z[X9Z`XH"+
MX9Z5X9^2X9Z3X9^"X9Z`XH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8(&]P96YS<VP@
MX9Z:X9Z4X9Z?X9^+(%!(4,*@X9^4`.&>E.&>ON*`B^&>HN&?DN&>D^&>@.*`
MB^&>E.&>D^&?DN&>CR#AGI_AGK;AGIKB@(OAGI'AGK;AGX;AGH3AGJ+AGI_A
MGXOB@(OAGI/AGX7B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI#AGH_B@(OAGI/A
MGKGAGH3B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGK;A
MGH_AGXOAGI3AGH3AGXO"H"$`X9Z8X9ZWX9Z3XH"+X9ZBX9Z^X9Z6X9Z^`.&>
MF.&>M^&>D^*`B^&>HN&>ON&>EN&>ON*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?
MBP#AGIKAGKSAGI3AGI?AGK;AGI8`X9Z:X9Z\X9Z4X9Z7X9ZVX9Z6`.&>FN&>
MO.&>E.&>E^&>MN&>EN*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>D>&>E.&?B^&>G^&?DN&>@.&>MN&>C^&?B\*@X9^6("5S(.&>BN&>ON&>
MF.&?DN&>E.&>N.*`B^&>@.&>MN&>FN&>EN&>MN&>FN*`B^&>E^&>MN&>EN*`
MB^&>K^&>@.&>A^&>D^*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@,*@
MX9^4("5S`.&>D^&>MN&?AN&>A>&>O.&>FP#AGI/AGK;AGX;AGH7AGKSAGIOB
M@(OAGH#AGKSAGI/AGI_AGX0`X9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z"X9Z\
MXH"+X9Z`X9Z\X9Z3X9Z?X9^$`.&>D^&>MN&?AN&>A>&>O.&>F^*`B^&>G^&>
MMN&>F@#AGI/AGK;AGX;AGH7AGKSAGIOB@(OAGH#AGKSAGI/AGI_AGX3B@(OA
MGIKAGI3AGI_AGXL@4$=0`.&>D^&>MN&?AN&>A>&>O.&>F^*`B^&>G.&>M^&>
MB>&?DN&>B>&>MN&>E.&>D^&>E.&>C^&?DN&>FN*`B^&>E>&?DN&>D>&>MN&>
MF^&?B^*`B^&>@>&?DN&>F^&>O>&>DP#AGI/AGK;AGX;AGH7AGKSAGIOB@(OA
MGH#AGKSAGI/AGI_AGX0@4$=0(.&>K^&>@.&>A^&>D^*`B^&>E>&?DN&>D>&>
MMN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DP#AGI/AGK;AGX;AGH7AGKSAGIOB
M@(OAGH#AGKSAGI/AGI_AGX0@4$=0(.&>K^&>@.&>A^&>D^*`B^&>E>&?DN&>
MD>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DR#AGI/AGX7B@(OAGI'AGKCA
MGI/AGX'AGX?"H.&?E@#AGI/AGK;AGX;AGH7AGKSAGIOB@(OAGISAGK?AGHGA
MGY+AGHGAGK;AGI3AGI/AGI3AGH_AGY+AGIH@4R]-24U%(.&>E>&?DN&>D>&>
MMN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DP#AGI/AGK;AGX;AGH7AGKSAGIOB
M@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGX@`X9Z3
MX9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z`X9Z\X9Z3X9Z?X9^$(%!'4"#AGI_AGK;A
MGI+AGK;AGIKAGH[AGX@`X9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z`X9Z\X9Z3
MX9Z?X9^$(%!'4"#AGI_AGK;AGI+AGK;AGIKAGH[AGX@@X9Z3X9^%XH"+X9Z1
MX9ZXX9Z3X9^!X9^'PJ#AGY8`X9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z`X9Z\
MX9Z3X9Z?X9^$(%,O34E-12#AGI_AGK;AGI+AGK;AGIKAGH[AGX@`X9Z3X9ZV
MX9^&X9Z%X9Z\X9Z;XH"+X9Z`X9Z\X9Z3X9Z?X9^$(%,O34E-10#AGI/AGK;A
MGX;AGH7AGKSAGIOB@(OAGJ_AGH#AGI_AGK;AGIH@;6)O>`#AGI/AGK;AGX;A
MGH7AGKSAGIOB@(OAGJ_AGH#AGI_AGK;AGIH@;6)O>`#AGI_AGX;AGH'AGK;A
MGI/AGXL`X9Z?X9ZVX9Z:XH"+X9Z?X9^&X9Z!X9ZVX9Z3X9^+`.&>E.&>MN&>
MD^*`B^&>D^&>MN&?AN&>A>&>O.&>F^*`B^&>G^&>MN&>FB`E9"#AGI;AGK@@
M)7/"H.&?E`#AGI_AGY+AGI#AGK?AGH_B@(OAGH#AGY+AGI/AGKOAGH3B@(OA
MGHKAGX;AGH[AGK[AGIKAGH#AGK;AGIH`X9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+
MX9Z1X9Z1X9Z]X9Z;`.&>FN&>O>&>F.*`B^&>E.&>B>&?DN&>A>&>O.&>F^*`
MB^&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^&>G^&>A.&?DN&>@>&?@>&>E.*`
MB^&>@>&?DN&>F^&>N.*`B^&>FN&>E.&>G^&?B^*`B^&>E.&>B^&>F.&>@.&>
MD.&>MN*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>AN&?DN&>
MF^&>ON&>F>*`B^&>C^&>E,*@/P#AGIKAGKWAGICB@(OAGI3AGHGAGY+AGH7A
MGKSAGIOB@(OAGI_AGK;AGIKB@(OAGI3AGY+AGIKAGI?AGI;B@(OAGH#AGY+A
MGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OAGH;AGY+AGIOAGK[AGIGB@(OAGH_A
MGI3"H#\`X9Z4X9Z$X9^2X9Z`X9Z^X9Z3XH"+X9Z`X9ZVX9Z:XH"+X9Z%X9Z\
MX9Z;XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+`.&>I>&>CN&?DN&>C.&>M@#A
MGJ7AGH[AGY+AGHSAGKSAGI/AGX'AGI_AGXKAGK@`X9Z6X9^0X9Z/X9^,X9Z8
MX9ZVX9Z3`.&>EN&?D.&>C^&?C.&>F.&>MN&>DP#AGI;AGY#AGH_AGXSAGICA
MGK;AGI/B@(OAGJ+AGX;AGI;AGKCB@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI_A
MGK;AGI+AGK;AGIKAGH[AGXCB@(L@)7,`X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3
MXH"+X9ZBX9^&X9Z6X9ZXXH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZOX9Z`X9Z'
MX9Z3XH"+X9Z5X9^2X9Z1X9ZVX9Z;X9^+X9Z!X9^2X9Z;X9Z]X9Z3`.&>EN&?
MD.&>C^&?C.&>F.&>MN&>D^*`B^&>HN&?AN&>EN&>N.*`B^&>@.&>O.&>D^&>
MG^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B.*`B^&>E>&?DN&>D>&>MN&>
MF^&?B^*`B^&>@>&?DN&>F^&>O>&>DP#AGH#AGY+AGI/AGKOAGH3B@(OAGH_A
MGKT`X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z<X9ZWX9Z)X9^2X9Z)X9ZVX9Z4
MX9Z3X9Z4X9Z/X9^2X9Z:XH"+X9Z1X9ZXX9Z3X9^!X9^'`.&>E.&>B>&?DN&>
MA>&>O.&>F^*`B^&>C^&>MN&>FN&>MN&>A`#AGH7AGX;AGI/AGKWAGI/B@(OA
MGH+AGH_AGXL`X9ZBX9^&X9Z6X9Z^XH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:
MX9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3
MXH"+X9Z'X9^2X9Z:X9Z^X9Z?XH"+(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`
MB^&>G^&>F.&>MN&>G^&>E^&>MN&>@N*`B^&>D^&?@>&?A\*@X9^4`.&>HN&>
MMN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>
MFN&>N>&>F.&>C^&?DN&>FN&>O.&>G`#AGI3AGY+AGIKAGJ+AGI3AGXOB@(OA
MGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGH;AGY+AGH3AGK;AGIGB@(OAGICA
MGK?AGI/B@(OAGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSAGIP`X9Z/X9Z]
MXH"+X9ZBX9Z`X9^2X9Z?X9Z:XH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9ZY
MX9Z8X9Z/X9^2X9Z:X9Z\X9Z<(.*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>HN&>
MMN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>F\*@
MX9^6("5SPJ#AGY0`X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z8X9ZWX9Z3XH"+X9Z/
MX9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<`.&>G^&>MN&>FN*`B^&>F.&>
MM^&>D^*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G"P@X9Z8X9ZW
MX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z3X9^2X9Z/XH"+X9Z?X9^!X9Z%X9Z`
MX9^2X9Z*X9ZXXH"+X9Z6X9^2X9Z:X9ZVX9Z$`.&>@.&>O.&>D^&>G^&?A.*`
MB^&>K^&>@.&>A^&>DR!01U`@X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2
MX9Z;X9Z]X9Z3XH"+X9Z8X9ZWX9Z3X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:
MX9Z\X9Z<PJ#AGY0`X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:
MX9Z.X9^(XH"+(%!'4"#AGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOA
MGKWAGI/B@(OAGICAGK?AGI/AGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSA
MGIS"H.&?E`#AGHKAGK;AGH#AGXOAGI3AGHGAGY+AGH7AGY+AGIKAGK;AGI\`
MX9ZBX9^*X9ZXX9Z:X9^)X9ZVX9Z`X9^+`.&>HN&?@.&>FN&>H>&>A.&?BP#A
MGJ+AGXKAGKCAGI_AGY+AGIKAGK;AGJ+AGX+AGIL`X9ZBX9^2X9Z3X9Z`XH"+
MX9Z%X9^!X9Z)`.&>D>&?DN&>FN&?@>&>CP#AGJ+AGXKAGKCAGH_AGK;AGIOA
MGK@`X9Z%X9ZVX9Z8X9^)X9^#X9Z`X9ZV`.&>F.&>@.&>FN&>M@#AGH?AGI3A
MGXGAGKOAGI,`XH"+X9Z'X9Z4X9^)X9Z[X9Z3("A)4T\M,C`R,BU*4"D`X9Z@
MX9^2X9Z?X9^*X9Z`X9Z*X9ZVX9Z3X9ZX`.&>@.&>@.&?DN&>@.&>BN&>M@#A
MGICAGK?AGI#AGKOAGI/AGK8`X9Z/X9Z8X9^2X9Z:X9ZYX9Z8XH"+X9Z?X9Z$
MXH"+X9Z!X9ZVX9Z$`$M"`.&>@.&>MN&>H.&?DN&>G^&>MN&>@.&?B^&>G^&?
MDN&>C^&>A.&?BP#AGH#AGX+AGI/AGIGAGXGAGK8`X9Z4X9^2X9Z:X9Z<X9^"
MX9Z$XH"+X9Z`X9Z\X9Z3X9Z?X9^$`.&>E.&?DN&>FN&>E^&?@>&>D>*`B^&>
M@N&?DN&>FN&>MN&>E.&?B^*`B^&>A>&>N^&>A0#AGH#AGK;AGIKB@(OAGI3A
MGH3AGY+AGH#AGK[AGH_B@(OAGH#AGKSAGI/AGI_AGX3B@(OAGJ+AGK;AGH7B
M@(OAGI/AGKGAGH3B@(OAGH_AGY+AGIKAGKSAGISB@(OAGH#AGK;AGIKB@(OA
MGIKAGIGAGXCAGI;AGX'AGIOB@(OAGIGAGKSAGIK"H.&?E"`@X9Z4X9Z3X9^2
MX9Z/XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z`X9Z\X9Z3X9Z?X9^$PJ`_
M`.&>F.&>M^&>D^*`B^&>F.&>MN&>D^*`B^&>@.&>MN&>FN*`B^&>D^&>MN&?
MAN&>A>&>O.&>F^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>H>&>ON&>F<*@X9^4
M(.&>@.&>MN&>FN*`B^&>D>&>MN&>B>&>F>&>@.*`B^&>K^&>@.&>G^&>MN&>
MFB#AGICAGK?AGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OA
MGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI3AGY+AGIKAGK[B@(OAGI3A
MGK;AGI/B@(OAGJ'AGK[AGIGB@(OAGIOAGK[B@(OAGICAGXGAGK;AGI_AGXKA
MGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI/AGX'AGX?"H.&?E`#AGICA
MGK?AGI/B@(OAGICAGK;AGI/B@(OAGH#AGK;AGIKB@(OAGI/AGK;AGX;AGH7A
MGKSAGIOB@(OAGH#AGKSAGI/AGI_AGX3B@(OAGJ'AGK[AGIG"H.&?E"#AGJ+A
MGY+AGI/AGH#B@(OAGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGH#AGX;AGH[A
MGH_AGXOB@(OAGI_AGX#AGISAGI?AGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+A
MGHOAGK;AGI,@X9Z*X9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z4X9Z3X9^2X9Z0X9^"
MX9Z8XH"+X9Z1X9^&X9Z3X9ZVX9Z`X9^+XH"+X9Z1X9^&X9Z3X9Z$XH"+X9Z:
MX9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9ZAX9Z^X9Z9PJ#AGY0`X9Z`
MX9Z\X9Z3X9Z?X9^$XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9Z5X9^2X9Z)X9Z^XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"XH"+X9Z'X9^0
MX9Z9(.*`B^&>D>&?A>*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>
MF.&?DN&>FN&>ON*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>
MFN&>CN&?B,*@X9^4`.&>@N&>M^&>FN&>M^&>E.&>MN&>D>&>N`#B@(OAGH#A
MGKSAGIKAGXGAGX$@*$550RU+4BD`X9Z"X9Z[X9Z9XH"+X9Z<X9^)X9^"X9Z/
M`.&>@N&?@.&>FN&>H.&?DN&>@N&>N.&>G^&?DN&>C^&>A.&?BP#AGI?AGK;A
MGI_AGK8`X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9Z4X9^2
MX9Z:X9Z'X9ZVX9Z2X9ZWX9Z4X9Z/X9^!X9Z9X9^2X9Z9XH"+X9Z4X9^2X9Z:
MX9Z'X9ZVX9Z8X9ZVX9Z3X9ZWX9Z/XH"+X9ZAX9ZVX9Z<`.&>D>&?AN&>EN&?
MD.&>FN*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?
MDN&>FN*`B^&>A>&>N^&>A.*`B^&>@.&?DN&>FN&?A.&>F0#AGI'AGX;AGI;A
MGY#AGIKB@(OAGH7AGKOAGH3B@(OAGH#AGY+AGIKAGX3AGID`X9ZAX9ZVX9Z/
MX9Z<X9ZXX9Z9X9^)X9ZV`.&>E.&?DN&>F^&>A.&?B^*`BP#AGIOAGKCAGI3A
MGH3AGXL`X9Z&X9^2X9Z<X9^!X9Z$`.&>H>&?@>&>G^&>O.&>C^&>O`#AGH#A
MGICAGY+AGIKAGK?AGH\`X9Z;X9ZXX9Z4X9^!X9Z:X9ZXX9Z9X9^)X9ZV`.&>
MA>&>MN&>F.&?B>&>MN&>HN&?BN&>M^&>FN&>N.&>F>&?B>&>MN*`B^&>HN&>
MMN&>FN&?B>&>MN&>E.&?BR#AGIOAGKCAGI3AGXKAGK@`X9Z;X9ZWX9Z%X9Z1
MX9^!X9Z3X9Z?X9^2X9Z/X9^"X9Z3`.&>C^&?AN&>C@#AGH_AGI?AGY+AGH?A
MGK;AGI3AGXOB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3A
MGXO"H#\`X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z@X9ZVX9Z8X9Z#X9ZV
MX9Z/X9^+PJ#AGY0`X9Z/X9^&X9Z.`.&>C^&?AN&>CN*`B^&>D^&>N>&>A.*`
MB^&>E>&>N^&>C^&>@.&?AN&>CN&>C^&?B^*`B^&>D^&?A2`E<P#AGIKAGK;A
MGIGB@(OAGH#AGK;AGIKB@(OAGI'AGK;AGH#AGXOB@(OAGI'AGH3B@(OAGI'A
MGK;AGX;AGH3AGJ+AGI_AGXL@X9Z6X9^!X9Z;XH"+X9Z5X9^2X9Z1X9Z[X9Z`
MXH"+X9ZBX9^!X9Z`X9^2X9Z:X9Z$X9^+XH"+X9Z`X9ZVX9Z:XH"+X9Z1X9ZV
MX9Z`X9^+X9Z1X9Z$PJ`_("CAGI3AGY+AGIKAGI_AGK?AGI/B@(OAGI3AGK[B
M@(OAGJ+AGI_AGH#AGICAGY+AGI@@X9ZBX9^2X9Z3X9Z`XH"+X9Z3X9ZYX9Z$
MXH"+X9Z#X9Z^X9Z)XH"+X9Z/X9^"XH"+X9Z`X9ZVX9Z:XH"+X9Z1X9ZVX9Z`
MX9^+XH"+X9Z1X9Z$XH"+X9Z*X9^"X9Z;XH"+X9ZBX9^2X9Z3X9Z`X9Z?X9^2
MX9Z<X9^"X9Z$X9Z:X9Z`XH"+X9Z9X9^)X9ZVX9Z$XH"+X9Z'X9ZVX9Z`X9^+
MXH"+X9Z;X9ZVX9Z`X9^+*0#AGIKAGK;AGIGB@(OAGH#AGY+AGI/AGKOAGH3B
M@(OAGI3AGHOAGICAGH#AGI#AGK8`X9Z;X9ZXX9Z1X9Z[X9Z9X9ZBX9ZVX9Z3
MX9ZX`.&>@.&?AN&>EN&>N^&>A.*`B^&>E>&?DN&>D>&>N^&>@"XN+@#AGI3A
MGY+AGIKAGJ+AGI3AGXOB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGICA
MGKSAGIOAGHKAGY+AGHOAGK;AGI/"H.&?E@#AGI'AGKCAGH_AGK;AGX;AGH0`
MX9Z%X9Z\X9Z;`.&>A>&>O.&>F^*`B^&>D>&?A2`E<P#AGH7AGX'AGHD`X9Z%
MX9Z\X9Z;`.&>E^&>MN&>FN&>@.&>M^&>A>&?DN&>A>*`B^&>A>&>O.&>FP#A
MGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI_AGY+AGIKAGJ'AGK;AGHGAGXL`
MX9Z1X9ZVX9Z4`.&>HN&>MN&>D>&>M^&>E^&>MN&>EN*`B^&>D>&>MN&>E`#A
MGI'AGK;AGI3B@(OAGI3AGX;AGI7AGKOAGH\`X9Z;X9Z[X9Z%X9Z@X9^2X9Z?
MX9^&X9Z4X9Z]X9Z:`$U-`.&>F.&?B>&>MN&>@.&>MN&>G`#AGJ_AGH#AGI_A
MGK;AGIH@36%C:6YT;W-H`.&>F.&?B>&>MN&>BN&>MN&>H.&?DN&>@.&>MN&>
MG^&?DN&>@.&>MN&>F@#AGI_AGX;AGI3AGKOAGH_AGY+AGIH`X9Z8X9Z^X9Z;
MXH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z'X9ZVXH"+X9Z8X9Z[X9Z3
M`.&>E.&?DN&>FN&>E^&?@>&>D>*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`
MB^&>E.&>F.&?DN&>FN&>ON*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>
MBN&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E^&?DN&>A^&>MN&>E.&?
MB^*`B^&>D>&?A>*`B^&>@.&>MN&>D^&?B\*@X9^6`.&>E.&?DN&>FN&>HN&>
ME.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>F@#AGH?AGICAGY+AGIKAGK[A
MGI_B@(OAGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI3AGY+AGIKAGJ+AGI3AGXOB
M@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH@X9Z3X9ZWX9Z$(.&>D.&>CP#AGICA
MGXGAGK;AGJ'AGK;AGISAGX,`X9Z8X9^)X9ZVX9ZAX9^!X9Z?X9^*X9ZX`.&>
MF.&?B>&>MN&>F^&?B^&>C.&>N.&>G`#AGICAGXGAGK;AGIOAGK@`X9Z8X9^)
MX9ZVX9Z;X9^+X9Z/X9ZV`.&>F.&>N.&>D^&>M@#AGIKAGKGAGICB@(OAGI'A
MGX;AGI;AGY#AGIH`X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z?X9ZVX9Z:
MXH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+XH"+(.&>@.&?DN&>D^&>N^&>A.*`
MB^&>D.&>C^*`B^&>D.&>MN*`B^&>E.&>MN&>D^*`B^&>F.&>ON&>FP#AGI_A
MGICAGY+AGH+AGK;AGIOAGXOB@(OAGI_AGK;AGIKB@(OAGI'AGK;AGX;AGH3A
MGJ+AGI_AGXOB@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI#AGH_AGI#AGK8@(N&>
MF.&>M^&>D^*`B^&>E.&>MN&>D^*`B^&>F.&>ON&>FR(`X9Z?X9Z8X9^2X9Z"
MX9ZVX9Z;X9^+XH"+X9Z'X9ZVPJ#AGY8`X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+
MXH"+X9Z`X9Z8X9^2X9Z:X9ZWX9Z/XH"+X9Z!X9Z[X9Z?X9^7XH"+X9Z"X9^2
MX9Z3X9ZVXH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9Z8X9^2X9Z:X9Z$X9^+(.&>
MBN&?A.&>F>*`B^&>EN&>CN&?C.*`B^&>@>&>N^&>G^*`B^&>@N&?DN&>D^&>
MML*@/P#AGI_AGICAGY+AGH+AGK;AGIOAGXOB@(OAGI_AGK;AGIKB@(OAGH?A
MGK8@(N&>E.&>MN&>D^*`B^&>F.&>ON&>FR(@X9ZLPJ`_("CAGH_AGX(@24U!
M4"D`X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z`X9ZVX9Z:XH"+X9Z/X9Z8
MX9^2X9Z;X9Z^X9Z$XH"+X9Z/X9Z8X9^2X9Z;X9^#XH"+X9Z?X9ZVX9Z8X9Z)
MX9^2X9Z)PJ`_`.&>@.&?A.&?AR!-87)S:&%L;`#AGICAGXGAGK;AGIKAGI'A
MGKCAGI/AGKCAGH(`X9Z*X9Z\X9Z%XH"+X9Z?X9^&X9Z.X9Z]X9Z:XH"+X9Z1
MX9ZVX9^&X9Z$X9ZBX9Z?X9^+`.&>BN&>O.&>A>*`B^&>G^&?AN&>CN&>O>&>
MFN*`B^&>CN&>MN&>F.&>O>&>F0#AGICAGXGAGKSAGIKAGKCAGH_AGK;AGI/A
MGK@`X9Z8X9^)X9Z\X9Z:X9ZXX9Z1X9Z[X9Z?`.&>D>&?AN&>H.&?AN*`B^&>
MK^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>HN&>C^&>
MM^&>E.&>FN&>F.&>M@#AGH7AGX;AGI/AGKWAGI/B@(OAGI#AGH_B@(OAGJ+A
MGH_AGK?AGI3AGIKAGICAGK8`X9Z%X9^&X9Z3X9Z]X9Z3XH"+X9ZBX9^2X9Z3
MX9Z`XH"+X9Z1X9Z1X9Z]X9Z;XH"+X9ZBX9Z/X9ZWX9Z4X9Z:X9Z8X9ZVXH"+
MX9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z?X9ZVX9Z:XH"+X9Z8X9Z]X9Z9`.&>A>&?
MAN&>D^&>O>&>D^*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>F^*`B^&>
MA>&?DN&>FN&>ON&>D^*`B^&>E.&?AN&>E>&>N^&>C^*`B^&>@.&?DN&>D^&>
MN^&>A.*`B^&>F.&>O>&>F>*`B^&>FN&>F>&?B.&>EN&?@>&>FP#AGI3AGK;A
MGI/B@(OAGICAGH#B@(OAGHKAGIOAGXOB@(OAGH#AGICAGY+AGIKAGK?AGH_B
M@(OAGI/AGX/B@(OAGH7AGX;AGI/AGKWAGI/B@(OAGJ+AGH_AGK?AGI3AGIKA
MGICAGK;B@(OAGIKAGI3AGI_AGXOAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+A
MGH?AGK;AGI3AGXO"H.&?E`#AGI3AGK;AGI/B@(OAGICAGH#B@(OAGHKAGIOA
MGXOB@(OAGH#AGICAGY+AGIKAGK?AGH_B@(OAGI/AGX/B@(OAGI'AGX;AGJ#A
MGX;B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OA
MGI_AGIKAGKOAGI3AGJ+AGH_AGK?AGI3AGIKAGICAGK8`X9ZGX9Z?X9Z7X9ZV
M`.&>F.&?@^&>HN&>O.&>C^&?@0#AGI_AGICAGK;AGH?AGK?AGH``X9Z4X9Z)
MX9^2X9Z'X9ZXXH"+X9Z0X9Z/XH"+X9Z8X9^)X9ZZX9Z3X9Z[X9Z9`.&>G^&>
MMN&>F@#AGH#AGK;AGIKB@(OAGH_AGX+AGH3B@(OAGI_AGK;AGIH`X9Z`X9ZV
MX9Z;XH"+X9Z4X9Z:X9ZWX9Z%X9^2X9Z&X9^!X9Z1XH"+X9Z:X9Z4X9Z?X9^+
MXH"+X9Z?X9ZVX9Z:`.&>D>&>A.&?B^*`B^&>G^&>MN&>F@#AGI#AGH_B@(OA
MGI_AGK;AGIH`X9Z*X9^&X9Z.X9Z\X9Z%XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?
MX9ZVX9Z:`.&>A^&>F.&?DN&>FN&>ON&>G^*`B^&>FN&>E.&>G^&?B^*`B^&>
MG^&>MN&>F@#AGH#AGK;AGIKB@(OAGI_AGY+AGISAGX+AGH3B@(OAGIKAGH#A
MGI_AGK;AGIH`X9Z1X9^&X9Z@X9^&XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZV
MX9Z:`.&>E.&?DN&>FN&>E^&>EN*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>
MF@#AGH#AGK;AGIKB@(OAGICAGK[AGIOB@(OAGI_AGK;AGIH`X9Z?X9ZVX9Z:
MXH"+X9Z6X9ZX("5S`.&>G^&>MN&>FN*`B^&>F.&>MN&>D^*`B^&>K^&>@.&>
MG^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BP#AGI_AGK;AGIKB@(OAGH_A
MGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGICAGY+AGIOAGX+AGH3B
M@(OAGH?AGK;B@(OAGH#AGKSAGHH`X9Z?X9ZVX9Z:XH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z%X9Z[X9^'X9Z@X9Z/X9^2X9Z0X9Z;X9^!
MX9Z!X9ZV`.&>G^&>MN&>FN*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>D>&>M^&>G^*`B^&>BN&?A.&>F>*`
MB^&>A^&?A.&>@N&>A^&?D.&>F<*@X9^4`.&>G^&>MN&>FN*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>ON*`B^&>BN&?A.&>
MF>*`B^&>A^&?A.&>@N*`B^&>A^&?D.&>F2#AGI3AGXGAGKOAGI/AGY+AGH_A
MGX+B@(OAGICAGK?AGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGI'AGX4@)7,`X9Z?
MX9ZVX9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2
MX9Z)X9Z^XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"XH"+X9Z'X9^0X9Z9PJ#A
MGY0`X9Z?X9ZVX9Z:XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z8X9Z]X9Z9XH"+
MX9Z1X9^&X9Z6X9^0X9Z:(.&>@.&?DN&>D^&>N^&>A.*`B^&>D>&>M^&>BN&?
MDN&>B^&>E^&>MN&>EN*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>
ME.&>N^&>C^&?DN&>FN*`B\*@X9^4`.&>G^&>MN&>FN*`B^&>D>&?A>*`B^&>
M@.&>MN&>D^&?BP#AGISAGK?AGI+AGKCAGI_AGK;AGI_AGY+AGIKAGY+AGH\`
MX9Z8X9^)X9ZWX9Z%X9Z?X9^*X9ZWX9Z``.&>@.&>CN&?DN&>C^&>MN&>FP#A
MGI3AGY+AGIKAGI?AGX'AGI$@36EM90#AGH;AGY+AGIOAGKOAGX<`X9Z5X9^2
MX9Z?X9^!X9Z$X9^7XH"+`.&>@.&?@N&>E.&?DN&>FN&?@@#AGICAGXGAGKSA
MGH[AGK;AGH#AGKP`X9Z8X9^)X9Z[X9Z$X9Z@X9^2X9Z"X9^$X9Z;X9ZX`.&>
M@>&?@B#AGI/AGK?AGH0@X9Z&X9^2X9Z3X9ZVX9^&`.&>FN&>MN&>F^&?B^*`
MB^&>@>&?@@#AGICAGXGAGKOAGH3AGI_AGX'AGIKAGXGAGK8`X9Z4X9ZVX9Z3
MXH"+X9Z:X9Z`X9Z#X9Z^X9Z)XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZV
MX9Z3XH"+X9Z%X9^2X9Z:X9Z^X9Z3XH"+X9Z'X9ZVX9Z$XH"+X9Z8X9Z]X9Z9
M(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>G.&>MN&>FR`B)7,BPJ#AGY0`
MX9Z8X9^)X9ZVX9Z:X9^)X9Z[X9Z``.&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>
MD>&>N`#AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGH7AGKOAGX?B
M@(OAGH#AGY+AGIKAGX3AGI@`X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZX
MXH"+X9Z1X9^%XH"+X9Z&X9^2X9Z<X9^!X9Z$`.&>E>&?DN&>F^&>MN&>G^&?
MB^*`B^&>D>&>N.*`B^&>D>&?A>*`B^&>G^&?DN&>C^&>MN&?A@#AGI7AGY+A
MGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGJ'AGK[AGH3B@(OAGIOAGKX`X9Z%
MX9Z[X9^'XH"+X9Z`X9^2X9Z:X9^$X9Z8`.&>E>&?DN&>F^&>MN&>G^&?B^&>
MD>&>N.*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>
MMN&>FN*`B^&>D>&?A>*`B^&>D.&>C^*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`
MB^&>E.&>MN&>D^*`B^&>@.&>MN&>FB#AGJ#AGK[AGIGB@(OAGI7AGY+AGIOA
MGK;AGI_AGXOAGI'AGKCB@(OAGI_AGK;AGIKB@(OAGIOAGY+AGJ+B@(OAGI'A
MGX7B@(OAGI3AGY+AGIKAGJ+AGI3AGXOB@(OAGI'AGI'AGKWAGIL`X9Z5X9^2
MX9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9Z0X9Z/`.&>H>&>ON&>A.*`B^&>
MF^&>O@#AGICAGXGAGKSAGJ#AGY+AGI_AGK;AGX;AGI3AGXKAGK?AGH``X9Z%
MX9^2X9Z:X9Z^X9Z3XH"+X9Z5X9^2X9Z3X9^"X9Z`+^&>AN&?DN&>F^&>MN&>
MG^&?BP#AGI'AGK?AGHKAGY+AGHOAGI?AGK;AGI;B@(OAGI_AGK;AGIKB@(OA
MGH7AGY+AGIKAGK[AGI,`X9Z8X9ZXX9Z9X9^)X9ZVX9Z3X9^+X9Z8X9^)X9ZV
M`.&>@N&?DN&>F.&>MN&>DP#AGH7AGX;AGH[AGK;AGX8`X9Z(X9^2X9Z8X9^$
MX9^'`.&>B.&?DN&>F.&?A.&?AR#AGI/AGK?AGH0OX9ZL(.&>HN&?BN&>N.&>
MF.&?@N&>F^*`B^&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>D>&>D>&?@>*`
MB^&>E.&>MN&>D^*`B^&>H>&>ON&>F0#AGH[AGK;AGICAGKCAGI3AGXKAGK@`
MX9Z.X9Z\X9Z:X9Z[`.&>C^&?DN&>FN&>O.&>G.*`B^&>@.&>MN&>FN*`B^&>
MHN&?AN&>EN&>O@#AGI/AGX'AGI3AGXGAGK;AGIOAGXL`XH"+X9Z@X9Z[X9Z;
MX9^2X9Z;X9Z$X9^+`.&>HN&>A.&?B^&>D>&>N.&>F>&?C>*`B^&>H.&>O.&>
MF^&?DN&>F^&>A.&?BP#AGI3AGH[AGY+AGH_AGK;AGHD`X9Z`X9Z[X9^&`.&>
M@.&>N^&?AN*`B^&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>K^&>
M@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BP#AGI#AGY+AGICAGK@`
MX9Z3X9Z\X9Z<X9^"X9Z;X9Z`X9ZVX9Z;X9^!X9Z*X9Z\X9Z3X9ZX`.&>D.&>
MC^*`B^&>D.&?DN&>F.&>N`#AGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI#A
MGY+AGICAGK@`X9Z?X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZX`.&>G^&>MN&>FN*`
MB^&>D.&?DN&>F.&>N.*`B^&>D>&?A2`E<P#AGI/AGKSAGISAGX+AGIOAGJ#A
MGXKAGY+AGI_AGX'AGJ'AGH3AGXL`X9Z?X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZX
M`.&>EN&>MN&>@.&?DN&>F>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>
MD.&?DN&>F.&>N`#AGI;AGY#AGH_AGXSAGICAGK;AGI,`X9Z<X9^!X9Z1X9ZW
MX9Z`X9ZVXH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3`.&>E.&>D^&?DN&>D>&>
MMN&>E.&?BP#AGI_AGK;AGIKB@(OAGI3AGI/AGY+AGI'AGK;AGI3AGXL`X9Z1
MX9^&X9Z6X9^0X9Z:XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z4X9^+`.&>D^&>N.&>
M@.&>MN&>FN&?B>&>MN&>H.&?DN&>@N&?D.&>F@#AGI/AGKCAGJ#AGY+AGI_A
MGX'AGIH`X9Z3X9ZXX9Z@X9^2X9Z?X9^!X9Z:X9ZXX9Z9X9^)X9ZV`.&>F>&>
ME.&?BP#AGI/AGKCAGIP`X9Z"X9^2X9Z8X9ZVX9Z3`.&>@N&?DN&>F.&>MN&>
MD^*`B^&>G.&>M^&>B>&?DN&>B>&>MN&>E.&>D^&>E.&>C^&?DN&>FN*`B^&>
MC^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>FN&>@.&>@^&>ON&>B0#A
MGH+AGY+AGICAGK;AGI/B@(OAGH#AGK;AGIKB@(OAGI3AGICAGY+AGIOAGX+A
MGH3B@(OAGH?AGK;B@(OAGH#AGKSAGHH`X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z`
MX9Z\X9Z3XH"+X9Z?X9^$XH"+X9Z`X9^2X9Z3X9Z[X9Z$($ME>7)I;F<`X9Z"
MX9^2X9Z8X9ZVX9Z3XH"+X9Z?X9ZVX9Z:`.&>@N&?DN&>F.&>MN&>D^*`B^&>
M@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B"!01U`@X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z3X9ZVX9^&X9Z%X9Z\X9Z;
MPJ#AGY0`X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z<X9Z/X9^2X9Z/X9Z8X9ZVX9Z3
MXH"+X9Z<X9ZWX9Z)X9^2X9Z)X9ZVX9Z4X9Z3X9Z4X9Z/X9^2X9Z:XH"+X9Z5
MX9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3`.&>@N&?DN&>F.&>
MMN&>D^*`B^&>HN&>C^&?DN&>D.&>E.&>D>*`B^&>F.&>ON&>F^*`B^&>A^&>
MMN*`B^&>F.&>N^&>DP#AGH+AGY+AGICAGK;AGI/B@(OAGH#AGKSAGI/AGI_A
MGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGX@@X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9Z4X9ZVX9Z3XH"+X9Z:X9Z`X9Z#X9Z^X9Z)`.&>@N&?DN&>F.&>MN&>D^*`
MB^&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B"!3+TU)
M344@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z3X9ZVX9^&X9Z%
MX9Z\X9Z;PJ#AGY0`X9Z:X9Z`XH"+X9Z8X9ZWX9Z3XH"+X9Z#X9Z^X9Z)XH"+
MX9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+PJ#AGY0`X9Z8
MX9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3XH"+
MX9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z3X9^%XH"+X9Z`X9^2X9Z3X9Z[X9Z$
MXH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(XH"+
MX9ZAX9Z^X9Z9PJ#AGY0`X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z0X9Z/(.&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>A^&?DN&>FN&>ON&>G\*@X9^4
M`.&>@N&?DN&>F.&>MN&>D^*`B^&>D.&>C^*`B^&>C^&?DN&>FN&>O.&>G.*`
MB^&>E.&>MN&>D^*`B^&>EN&>M^&>D^&>M^&>C^&?DN&>F>*`B^&>F.&>ON&>
MFR#AGI_AGICAGY+AGIKAGK;AGI3AGXOAGI_AGX;AGI3AGKOAGH_AGY+AGIKB
M@(OAGI#AGY+AGICAGKC"H.&?E`#AGH+AGY+AGICAGK;AGI/B@(OAGI#AGH\@
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z'X9ZV
MX9Z`X9^+`.&>@N&?DN&>F.&>MN&>D^*`B^&>D.&>C^*`B^&>BN&?@N&>F^*`
MB^&>F.&>MN&>D^*`B^&>G^&>MN&>FN*`B^&>D.&?DN&>F.&>N`#AGH+AGY+A
MGICAGK;AGI/B@(OAGI#AGH_B@(OAGHKAGX+AGIOB@(OAGICAGK;AGI/B@(OA
MGI_AGK;AGIKB@(OAGICAGK?AGI/B@(OAGI'AGK;AGI/AGXOB@(OAGICAGK[A
MGIL`X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z3
MX9^#XH"+X9Z/X9Z]XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:`.&>F.&>
MM^&>D^*`B^&>F.&>MN&>D^*`B^&>G^&>MN&>FN*`B^&>C^&?DN&>FN&>H>&>
ME.&?B^*`B^&>F.&>@.*`B^&>G.&>M^&>B>*`B^&>H>&>ON&>F<*@X9^4`.&>
M@N&?DN&>F.&>MN&>D^*`B^&>G^&>MN&>FN&>BN&?@N&>F^*`B^*`B^&>E>&?
MDN&>@N&>O.&>E>&?DN&>@N&>A.*`B^&>D>&?A>*`B^&>D^&>N>&>A.*`B^&>
M@.&>MN&>FN*`B^&>G^&?DN&>G.&?@N&>A.*`B^&>FN&>@.*`B^&>FN&>E.&>
MG^&?B^*`B^&>HN&?DN&>D^&>@,*@X9^4`.&>@N&?DN&>F.&>MN&>D^*`B^&>
M@.&>O.&>D^&>G^&?A.*`B^&>K^&>@.&>A^&>DR!01U`@X9Z5X9^2X9Z1X9ZV
MX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3(.*`B^&>C^&?DN&>FN&>O.&>G.*`
MB^&>E.&>MN&>D^*`B^&>D^&>MN&?AN&>A>&>O.&>F\*@X9^4`.&>@N&?DN&>
MF.&>MN&>D^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>
MCN&?B"!01U`@X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3
MXH"+(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>D^&>MN&?AN&>
MA>&>O.&>F\*@X9^4`.&>@N&?DN&>F.&>MN&>D^*`B^&>G.&>M^&>B>&?DN&>
MB>&>MN&>E.&>D^&>E.&>C^&?DN&>FB!3+TU)344@X9Z5X9^2X9Z1X9ZVX9Z;
MX9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>D^&>MN&?AN&>A>&>O.&>F\*@X9^4`.&>F.&>M^&>D^*`B^&>
MF.&>MN&>D^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>K^&>@.&>A^&>D^*`B^&>
ME>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>D^*`B^&>H>&>ON&>
MF2#AGHKAGKSAGH7AGY+AGI/AGX'AGX?B@(OAGI_AGK;AGIKB@(OAGI/AGKGA
MGH3B@(OAGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGH_AGY+AGIKAGKSAGISB
M@(OAGI3AGK;AGI/B@(OAGI3AGICAGY+AGIOAGX+AGH3B@(OAGICAGH#B@(OA
MGH?AGK;B@(OAGI?AGK;AGI;B@(OAGI+AGICAGY+AGICAGH_AGK;B@(OAGISA
MGK?AGHGB@(OAGJ'AGK[AGIG"H.&?E`#AGH+AGY+AGICAGK;AGI/B@(OAGH#A
MGICAGY+AGICAGISAGK?AGI+AGKCB@(OAGI;AGK?AGI/AGK?AGH_AGY+AGIGB
M@(OAGJ+AGH#AGY+AGH'AGIKAGK;AGISAGK?AGIKAGKOAGI'AGY+AGI(@X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9^&X9Z.X9Z/X9^+XH"+
MX9Z:X9Z%X9Z3X9ZVXH"+X9Z?X9Z8X9^2X9Z6X9^0X9Z3X9^2X9Z2PJ#AGY0`
MX9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z9X9^$X9Z4X9Z;X9^+`.&>F.&>M^&>D^*`
MB^&>HN&>MN&>A>*`B^&>FN&>@.&>@^&>ON&>B>*`B^&>G.&>M^&>DN&>N.&>
MG^&>MN&>G^&?DN&>C^&?DN&>FN*`B^&>E>&?DN&>D>&?@.&>A.&>E>&?DN&>
MD>&>MN&>C^&?BR!)34%0(.&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>@N&>
MMN&?AN&>D>&?DN&>FL*@X9^4`.&>@N&?DN&>F.&>MN&>D^*`B^&>HN&?DN&>
MD^&>@.*`B^&>E.&?DN&>FN&>OB#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;A
MGI/B@(OAGI3AGHGAGY+AGH?AGK;AGH#AGXO"H.&?E`#AGH+AGY+AGICAGK;A
MGI/B@(OAGJ+AGY+AGI/AGH#B@(OAGH7AGKSAGIOAGIKAGKWAGI@`X9Z"X9^2
MX9Z8X9ZVX9Z3`.&>@.&?A.&?A^*`B^&>CN&?B>&>H.&?DN&>G.&?B>&>@`#A
MGI+AGICAGY+AGICAGH_AGK8`X9Z`X9^$X9^'XH"+X9Z8X9^)X9ZVX9Z:X9^`
MX9Z.X9ZVXH"+X9Z7X9ZVX9Z"XH"+X9Z!X9ZVX9Z$XH"+X9Z'X9Z^X9Z$`.&>
MD^&?D.&>FN&>G.&?@N&>GP#AGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGIOA
MGKOAGI0`X9Z8X9ZWX9Z3XH"+X9Z8X9^"X9Z3XH"+X9Z?X9^!X9Z%X9Z`X9^2
MX9Z/X9ZXXH"+X9Z6X9^2X9Z:X9ZVX9Z$`.&>F.&>M^&>D^*`B^&>G^&?AN&>
M@>&>MN&>D^&?BP#AGICAGK?AGI/B@(OAGICAGX+AGI/B@(OAGI7AGY+AGI'A
MGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI,`X9Z8X9ZWX9Z3XH"+X9Z8X9^"
MX9Z3XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(
MX9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z8X9Z]X9Z9PJ#A
MGY0`X9ZBX9Z/X9^+XH"+X9Z?X9^$X9^'`.&>A>&?AN&>CN&>MN&?AN*`B^&>
MD.&>MN*`BR#AGISAGK;B@(OAGH_AGY+AGIKAGKSAGISB@(OAGH#AGK;AGIKB
M@(OAGI;AGX'AGIOB@(OAGISAGX'AGIOAGK;B@(OAGI3AGI/AGY+AGH_AGK?A
MGH7B@(OAGI3AGI/AGY+AGH_AGKWAGH4`X9Z%X9^&X9Z.X9ZVX9^&`.&>@N&?
MDN&>F.&>MN&>D^*`B^&>HN&?DN&>G.&>N.*`B^&>G^&?A.&?AP#AGI_AGX'A
MGH7AGH#AGY+AGHKAGKCB@(OAGH?AGKSAGI/B@(OAGHKAGX;AGH[AGKGAGH3"
MH.&?EB#AGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OA
MGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGH_AGI?AGY+AGH?AGK;AGI3AGXL@
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z1X9ZVX9Z)X9Z9X9Z`
MXH"+X9Z@X9Z^X9Z9PJ#AGY0`X9Z<X9ZWX9Z%X9^2X9Z&X9ZWX9Z`X9ZV`.&>
MF^&?@>&>@0#AGH7AGX;AGI/AGKWAGI/B@(OAGH_AGKWAGJ+AGH#AGY+AGI_A
MGIH`X9Z%X9^&X9Z3X9Z]X9Z3XH"+X9Z!X9^"XH"+X9Z*X9^"X9Z;XH"+X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z:X9Z`X9^2X9Z?X9ZVX9ZOX9Z`X9Z?X9ZVX9Z:
MX9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+
MX9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z%X9ZVX9Z?X9^+(.&>E.&?DN&>FN&>
MG^&>M^&>D^*`B^&>E.&>ON*`B^&>F^&>N^&>E.*`B^&>FN&>MN&>F^&?B^*`
MB^&>@>&?@L*@X9^4`.&>A>&?AN&>D^&>O>&>D^&>D^&?@^*`B^&>D.&>C^*`
MB^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>
MB>&>ON*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>FN&>@.&?
MDN&>G^&>MN*`B^&>D>&>N^&>@"#AGI3AGY+AGIKAGI_AGK?AGI/B@(OAGI3A
MGK[AGIOAGKOAGI3B@(OAGIKAGK;AGIOAGXOB@(OAGH'AGX+"H.&?E`#AGIGA
MGIOAGXOB@(OAGI;AGY+AGIKAGI@`X9ZL`.&>G.&>C^&?DN&>D.&>NP#AGH_A
MGKOAGIOAGK8`X9Z`X9ZVX9Z:X9ZWX9Z9X9ZVX9Z;X9^0X9Z9`.&>G^&>MN&>
MFN*`B^&>A>&>MN&>G^&?BP#AGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+A
MGH3AGK;AGH_AGXOB@(OAGH7AGK;AGI_AGXL`X9Z0X9Z/("+AGI_AGX;AGI3A
MGKOAGH_AGY+AGIKB@(OAGI3AGK;AGI/B@(OAGI7AGY+AGHGAGKXB(.&>A>&>
MMN&>G^&?B^*`B^&>@.&?AN&>EN&>N^&>A.*`B^&>C^&?DN&>FN&>O.&>G.*`
MB^&>E.&>MN&>D^*`B^&>F^&>N^&>E.*`B^&>E.&?AN&>E.&>MN&>C^&?B\*@
MX9^4`.&>HN&>O.&>F.&?@N&>DP#AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGH_A
MGX+B@(OAGI#AGH_B@(OAGHKAGX+AGIOB@(OAGICAGK;AGI/B@(OAGI_AGK;A
MGIKB@(OAGICAGK?AGI/B@(OAGI'AGK;AGI/AGXOB@(OAGJ+AGK;AGI/"H#\`
MX9Z/X9^"XH"+X9Z0X9Z/XH"+X9Z8X9Z]X9Z9XH"+X9Z4X9^)X9Z[X9Z.X9^2
MX9Z.X9^$X9^'(.&>@N&>O>&>FN*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>A^&?DN&>FN&>ON&>G^*`B^&>G^&>F.&?DN&>FN&>MN&>E.&?
MB^*`B^&>HN&?AN&>EN&>ON*`B^&>D^&?@>&?A\*@X9^4`%],X9Z4X9Z^X9Z`
MXH"+X9Z0X9Z/(`#AGI3AGK[AGH#B@(OB@(OAGH#AGY+AGI/AGKOAGH3B@(OB
M@(OAGI3AGH3AGY+AGJ+AGKWAGH7B@(OAGI#AGY+AGICAGK@`X9Z0X9Z/XH"+
MX9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z^X9Z``.&>E.&?DN&>FN&>
MEN&?D.&>D^&?DN&>DN*`B^&>E.&?DN&>FN&>C^&>M^&>E.&>C^&?DN&>C^&>
MM^&>@.&>MN&>F@#AGJ+AGY+AGI/AGH#B@(OAGH7AGKSAGIOB@(OAGIKAGKWA
MGICB@(OAGI_AGY+AGIKAGX'AGH7B@(OAGIOAGK[B@(OAGH7AGK?AGH_AGY+A
MGH\`X9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+`.&>E>&?DN&>G^&?@>&>A.&?EP#A
MGH+AGH[AGI/AGKCB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI7AGY+A
MGI_AGX'AGH3AGY<`X9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z5X9^2X9Z?X9^!
MX9Z$X9^7`.&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>
MON*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A0!01U``4$=0($5N8W)Y<'0@
M365S<V%G90#AGH#AGX;AGJ#AGKOAGI\@4$=0PJ#AGY8@`.&>@.&?AN&>H.&>
MN^&>GR!01U#"H.&?EB#AGH_AGY+AGIKAGKSAGISAGH#AGK;AGIKB@(OAGH/A
MGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;AGH_AGXL@X9Z?X9Z8X9^2X9Z:
MX9ZVX9Z4X9^+XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZOX9Z`X9Z'X9Z3XH"+
MX9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3PJ#AGY0`X9Z'
MX9Z8X9^2X9Z:X9Z^X9Z?(%!'4`#AGH#AGK;AGIKB@(OAGI3AGHGAGY+AGH7A
MGKSAGIOB@(OAGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;AGH_AGXOB
M@(OAGIKAGI3AGI_AGXL@4$=0`.&>@.&>MN&>FN*`B^&>@N&>MN&?AN&>D>&?
MDN&>FN&>@N&>O.*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>E>&?DN&>D>&>MN&>
MF^&?B^*`B^&>@>&?DN&>F^&>O>&>DR!01U`@X9Z1X9ZVX9Z8X9Z1X9ZVX9Z:
MXH"+X9Z`X9ZVX9Z:XH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z4X9Z.
MX9^2X9Z/X9ZVX9Z)XH"+X9Z?X9Z[X9Z<X9Z/X9^2X9Z0X9ZWX9Z7X9ZVX9Z6
MPJ#AGY0`X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(
M(%!'4"#AGI_AGICAGY+AGIKAGK;AGI3AGXL@(B5S("@E<RDB("#AGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGI/AGY+AGI#AGX+AGICB@(OA
MGHKAGX3AGIGB@(OAGH?AGX3AGH+B@(OAGH?AGY#AGIG"H.&?E`#AGH#AGKSA
MGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGX@@4$=0(.&>G^&>F.&?
MDN&>FN&>MN&>E.&?BR`B)7,B(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>F^&>N^&>E.*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>
MF<*@X9^4`%!'4"!0=6)L:6,@2V5Y<FEN9P!01U`@4VEG;B!-97-S86=E`%!'
M4"!3:6=N+T5N8W)Y<'0@365S<V%G90#AGH#AGKSAGI/AGI_AGX3B@(OAGJ_A
MGH#AGH?AGI,@4$=0(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
ME.&>D^&?DN&>D.&?@N&>F.*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?
MD.&>F<*@X9^4`.&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>
MCN&?B"!01U`@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z3
MX9^2X9Z0X9^"X9Z8XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"X9Z'X9^0X9Z9
MPJ#AGY0`X9Z`X9ZVX9Z:XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:(%!'4"#AGH_A
MGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISAGK[B@(OAGK+A
MGY+AGIGB@(OAGI3AGY+AGIKAGK[B@(OAGIOAGX+AGH3B@(OAGI3AGK;AGI/B
M@(L@X9Z;X9Z^XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z3X9^!
MX9^'PJ#AGY0`X9Z`X9ZVX9Z:XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:(%!'4"#A
MGI'AGK;AGICAGI'AGK;AGIKB@(OAGK+AGY+AGIGB@(OAGI3AGY+AGIKAGK[B
M@(OAGI3AGH3AGY+AGJ+AGKWAGH7B@(OAGIOAGX'AGH7AGJ'AGK[AGH3"H.&?
ME"#AGI3AGK[B@(OAGH#AGICAGY+AGICAGISAGK?AGI+AGKCB@(OAGIKAGKOA
MGH#AGIKAGH#B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGH#A
MGX;AGI;AGKOAGH3B@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI3A
MGH3AGY+AGJ+AGKWAGH7B@(OAGIOAGX'AGH7AGJ'AGK[AGH3B@(OAGI3AGY+A
MGIKAGK[B@(OAGIOAGX+AGH3B@(OAGI3AGK;AGI,@X9ZBX9^2X9Z3X9Z`XH"+
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+
MX9Z4X9^2X9Z*X9Z\X9Z:XH"+X9Z`X9ZVX9Z:XH"+X9Z`X9^&X9Z.X9Z/X9^+
MXH"+X9Z3X9^!X9^'(.&>E.&>ON*`B^&>EN&>N^&?AN*`B^&>D^&?A.&?A^*`
MB^&>D>&?@>*`B^&>F^&>@.&?DN&>@>&>CN&?B.*`B^&>EN&>M^&>G^&?@>&>
MGR!01U`@X9Z3X9ZYX9Z$XH"+X9Z8X9ZWX9Z3XH"+X9Z*X9^&X9Z.X9Z^X9Z:
MX9Z`X9ZVX9Z:XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9ZAX9Z^X9Z9PJ#AGY0`4$]0,P!03U`S("A!=71O($1E=&5C="!0<F]T;V-O
M;',I`%!/4#,@X9Z;X9Z^(%-33`!03U`S(.&>F^&>OB!34TP@*.&>G.&>M^&>
MB>&?DN&>B>&>MN&>E.&>D^&>E.&>C^&?DN&>FN*`B^&>BN&?@N&>F^*`B^&>
ME.&>MN&>D^*`B^&>A>&>N^&?A^*`B^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>
MMN*`B^&>BN&?A.&>F>*`B^&>@>&?DN&>F^&>O>&>D^*`B^&>K^&>A"D`4$]0
M,R#AGH+AGY+AGICAGK;AGI,@5$Q3`.&>A>&>D^&?DN&>F^&?A.&?AP#AGI'A
MGX;AGI;AGY#AGIH@)60@X9Z3X9^#("5D`.&>D>&?AN&>EN&?D.&>FN*`B^&>
MBN&?@N&>F^*`B^&>F.&>MN&>D^*`B^&>G^&>MN&>FN*`B^&>F.&>M^&>D^*`
MB^&>E.&>MN&>D^*`B^&>F.&>ON&>F^*`B^&>BN&?AN&>E.&>O.&>A`#AGI'A
MGX;AGI;AGY#AGIKB@(OAGHKAGX+AGIOB@(OAGICAGK;AGI/B@(OAGI_AGK;A
MGIKB@(OAGICAGK?AGI/B@(OAGI3AGK;AGI/AGICAGK[AGIOB@(OB@(OAGH7A
MGKOAGH3B@(OAGH#AGY+AGIKAGX3AGID`X9Z4X9^)X9ZVX9Z"X9ZXX9Z?X9^2
MX9Z0X9ZVX9Z3`.&>E.&?B>&>MN&>H>&>O`#AGI3AGXGAGK;AGH[AGK;AGICA
MGXGAGK8`X9Z4X9^)X9ZVX9Z6X9Z\X9Z)X9Z\X9Z<X9Z@X9^2X9Z"X9ZXX9Z.
MX9^!`.&>E.&?B>&>MN&>FN&?B>&>MN&>H.&?DN&>@N&>MN&>F0#AGI7AGY+A
MGI/AGX+AGH``X9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+
M`.&>@^&?DN&>F^&>MN*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?BR`HX9Z8X9^2
MX9Z/X9Z$XH"+X9Z1X9^`X9Z/*0#AGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+A
MGH3AGK;AGH_AGXOB@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OA
MGIKAGK[B@(OAGH7AGX'AGHGB@(OAGHKAGX3AGIGB@(OAGH?AGX3AGH+B@(OA
MGH?AGY#AGIG"H.&?E`#AGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;A
MGH_AGXO"H.&?E@#AGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;AGH_A
MGXOB@(OAGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI'AGI'AGX'B@(OAGI3A
MGK;AGI/B@(OAGJ'AGK[AGID`X9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$
MX9ZVX9Z/X9^+XH"+X9Z8X9ZWX9Z3XH"+X9Z5X9^2X9Z"X9Z\X9Z5X9^2X9Z"
MX9Z$`.&>EN&>MN&>@.&?DN&>F>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?BP#A
MGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;AGH_AGXO"H.&?E@#A
MGI3AGK?AGI'AGI?AGY+AGH?AGK;AGI3AGXL`X9Z5X9^2X9Z;X9Z\X9Z<`.&>
MF.&>D^&>N^&>G^&?DN&>GP#AGI?AGK;AGH+AGIKAGID`X9Z2X9^2X9Z<X9Z^
MXH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z4X9Z/X9^2X9Z/X9ZWX9Z`X9ZVX9Z:XH"+
MX9Z/X9^&X9Z@X9^"X9Z1X9ZVX9^&(.&>EN&?@>&>F^*`B^&>A>&>O.&>F\*@
M/P#AGI_AGK?AGI'AGY+AGI+AGK<`X9Z?X9ZWX9Z1X9^2X9Z2X9ZW`.&>G^&>
MM^&>D>&?DN&>DN&>M^*`B^&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>HN&?
MDN&>D^&>@.*`B^&>E.&?DN&>FN&>ON*`B^&>D^&?@>&?AR#AGICAGK?AGI/B
M@(OAGJ+AGK;AGH7B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OA
MGI7AGY+AGIOAGK;AGI_AGXOAGI3AGY+AGHKAGKSAGIKB@(OAGI3AGK;AGI/B
M@(OAGJ'AGK[AGIG"H.&?E`#AGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+A
MGIOAGKWAGI,`X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9ZV
MX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3`.&>@N&>O.*`B^&>@.&>O.&>D^&>
MG^&?A"!01U`@X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3
M(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>A.&?DN&>@.&>
MON&>C^*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F<*@X9^4`.&>
M@.&>O.&>D^&>G^&?A"!01U`@X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2
MX9Z;X9Z]X9Z3(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>F^&>
MN^&>E.*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F<*@X9^4`.&>
MG.&>M^&>B>&?DN&>B>&>MN&>E.&>D^&>E.&>C^&?DN&>FB!3+TU)344@X9Z5
MX9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3(.&>F.&>M^&>D^*`
MB^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>D^&>MN&?AN*`B^&>
MA>&>O.&>F^*`B^&>H>&>ON&>F<*@X9^6`.&>@.&>O.&>D^&>G^&?A"!3+TU)
M344@X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3XH"+(.&>
MC^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>F^&>N^&>E.*`B^&>BN&?
MA.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F<*@X9^4`.&>E.&?B>&?@>&>FN&?
MB>&>O`#AGJ#AGY+AGISAGKCAGIOAGKCAGI;AGKCAGI,`X9Z1X9Z\X9Z:X9Z?
MX9^0X9Z6X9^2X9Z1`.&>EN&>N.&>C^&>@>&>MN&>F>&>FN&>M^&>DP#AGI?A
MGKCAGH#AGI_AGX+AGIL`X9Z*X9ZVX9Z`X9^+XH"+X9Z@X9Z/X9^2X9Z0X9Z;
MX9^!X9Z!X9ZVXH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(.&>F.&>
MN^&>D^*`B^&>@.&>MN&>FN*`B^&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E"#A
MGI/AGK?AGH0@X9Z4X9Z)X9^2X9Z'X9Z\X9Z3X9Z4X9Z3X9^2X9Z/PJ`_`.&>
M@.&?AN&>CN&?@N*`B^&>HN&>C^&?DN&>D.&>E.&>D>*`B^&>DN&>F.&?DN&>
MF.&>C^&>MN*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>F@#AGH7AGK;AGH#A
MGXOB@(OAGI_AGICAGY+AGIOAGX'AGH3B@(OAGI;AGX'AGIOB@(OAGICAGK;A
MGI/B@(OAGI_AGK;AGIKB@(OAGI#AGY+AGICAGKC"H#\@(.&>G.&>MN*`B^&>
MD>&>MN&>F.&>D>&>MN&>FN*`B^&>LN&?DN&>F>*`B^&>@.&>F.&?DN&>F.&>
MG.&>M^&>DN&>N.*`B^&>FN&>N^&>@.&>FN&>@.*`B^&>FN&>E.&>G^&?B^*`
MB^&>HN&?DN&>D^&>@.*`B^&>@N&>MN&?AN&>D>&?DN&>FN*`B^&>K^&>@.&>
MG^&>MN&>FN*`B^&>G^&>F.&?DN&>F^&?@>&>A.*`B^&>E.&>A.&?DN&>@.&>
ME.&?B\*@X9^4("#AGH#AGICAGY+AGICAGISAGK?AGI+AGKCB@(OAGIKAGKOA
MGH#AGIKAGH#B@(OAGI_AGY+AGI'AGK[AGIKB@(OAGH_AGX+B@(OAGI'AGK;A
MGX;AGH3AGJ+AGI_AGXOB@(OAGI/AGX7B@(OAGIOAGKX@5VEN9&]W<R#AGI/A
MGK?AGH0@36%C(.&>E.&>MN&>D^*`B^&>@N&>MN&?AN&>D>&?DN&>FB#AGI3A
MGXGAGKOAGI/AGY+AGH_AGX+B@(OAGISAGX'AGI'AGK?AGH#AGK;B@(OAGI7A
MGY+AGI_AGX'AGH3B@(OAGI'AGX#AGH_B@(OAGI/AGKGAGH3B@(OAGI'AGK;A
MGICAGI'AGK;AGIKB@(OAGH#AGICAGY+AGICAGISAGK?AGI+AGKCB@(OAGH?A
MGX;AGI/AGKWAGIGB@(OAGH'AGK;AGH3B@(OAGH#AGY+AGI/AGKOAGH3B@(OA
MGICAGKWAGIG"H.&?E`#AGI_AGKSAGICB@(OAGI3AGHGAGY+AGH7AGKSAGIOB
M@(OAGHCAGY+AGICAGX3AGX?B@(OAGICAGKWAGID@X9Z?X9Z8X9^2X9Z:X9ZV
MX9Z4X9^+XH"+X9Z0X9Z/XH"+X9Z0X9^2X9Z8X9ZXPJ#AGY8`X9Z?X9Z\X9Z8
MXH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z:
MX9Z4X9Z?X9^+XH"+X9Z0X9Z/XH"+X9Z0X9^2X9Z8X9ZXPJ#AGY8`X9Z?X9Z\
MX9Z8XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z(X9^2X9Z8X9^$X9^'XH"+
MX9Z0X9^2X9Z8X9ZXPJ#AGY8`X9Z?X9Z\X9Z8XH"+X9Z4X9Z)X9^2X9Z%X9Z\
MX9Z;XH"+X9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+
MX9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZO
MX9Z`X9Z'X9Z3(%!'4"#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"H.&?
ME"#AGJ+AGY+AGI/AGH#B@(OAGH7AGK;AGX;AGI3AGK;AGH7AGXOB@(OAGI3A
MGHGAGY+AGH7AGKSAGIOB@(OAGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3A
MGK;AGH_AGXOB@(OAGI/AGX'AGX?B@(OAGH_AGX+B@(OAGICAGKWAGIGB@(OA
MGHKAGH0@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z8X9Z]X9Z9XH"+X9Z?X9Z8X9^0
MX9Z9("5SPJ#AGY0`X9Z?X9Z\X9Z8XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+
MX9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z?X9Z8
MX9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZOX9Z`X9Z'
MX9Z3(%,O34E-12#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"H.&?E"#A
MGJ+AGY+AGI/AGH#B@(OAGH7AGK;AGX;AGI3AGK;AGH7AGXOB@(OAGI3AGHGA
MGY+AGH7AGKSAGIOB@(OAGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;A
MGH_AGXOB@(OAGI/AGX'AGX?B@(OAGH_AGX+B@(OAGICAGKWAGIGB@(OAGHKA
MGH0@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z8X9Z]X9Z9XH"+X9Z?X9Z8X9^0X9Z9
M("5SPJ#AGY0`X9Z?X9Z\X9Z8XH"+X9Z%X9Z\X9Z;XH"+X9Z8X9^2X9Z/X9Z$
MXH"+X9Z1X9^`X9Z/(.&>BN&>ON&>F.&?DN&>E.&>N.*`B^&>E.&>D^&?DN&>
MC^*`B^&>C^&?@N&>A.*`B^&>G^&>MN&>FN*`B^&>FN&>E.&>G^&?B^*`B^&>
MHN&?DN&>D^&>@,*@X9^4(.&>E.&?DN&>FN&>G^&>M^&>D^*`B^&>E.&>ON*`
MB^&>HN&?DN&>D^&>@.*`B^&>F.&>M^&>D^*`B^&>@.&?AN&>EN&>N^&>A.*`
MB^&>E.&?DN&>FN&>ON*`B^&>@>&>O.&>@N&>N"#AGI/AGK?AGH0@X9ZBX9^2
MX9Z3X9Z`XH"+X9Z`X9^&X9Z6X9Z[X9Z$XH"+X9Z/X9^"X9Z$XH"+X9Z?X9ZV
MX9Z:XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%XH"+
MX9Z;X9^!X9Z%X9ZAX9Z^X9Z$(.&>HN&?DN&>D^&>@.&>A>&>MN&?AN&>E.&>
MMN&>A>&?B^&>C^&?DN&>FN&>O.&>G.*`B^&>A>&>O.&>F^*`B^&>F.&?DN&>
MC^&>A.*`B^&>D>&?@.&>CR#AGH#AGY+AGI/AGKOAGH3B@(OAGI3AGH3AGY+A
MGJ+AGKWAGH7B@(OAGICAGX'B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/A
MGH#B@(OAGI7AGH3B@(OAGHKAGX+AGIK"H.&?E"#AGI/AGX'AGX?B@(OAGH+A
MGKKB@(OAGHKAGK[AGICAGY+AGI3AGKCB@(OAGIKAGK;AGIKAGK;AGX;AGH3B
M@(OAGJ+AGY+AGI/AGH#B@(OAGISAGK;AGIGB@(OAGI3AGY+AGIKAGJ#AGK;A
MGIKB@(OAGI;AGKCB@(OAGH#AGK;AGIKB@(OAGI3AGY+AGIOAGI/AGXOB@(OA
MGJ+AGH_AGY+AGH_AGI_AGHGAGY+AGHGAGK;AGH[B@(OAGI_AGICAGY#AGIGB
M@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"H.&?E"#AGIGAGK[B@(OA
MGH3B@(OAGI_AGKSAGICB@(OAGI'AGX3AGI_B@(OAGI_AGICAGY+AGIKAGK;A
MGI3AGXOB@(OAGI?AGK;AGI;B@(OAGICAGK?AGI/B@(OAGH3AGK;AGIGAGI_A
MGY+AGIKAGKWAGIOB@(OAGH[AGK;AGICAGKWAGIG"H.&?E`#AGI_AGKSAGICB
M@(OAGI7AGY+AGH_AGIOAGXOB@(OAGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICA
MGY+AGH3AGK;AGH_AGXOB@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"
MH.&?E`#AGI_AGKSAGICB@(OAGI7AGY+AGH_AGIOAGXOB@(OAGHCAGY+AGICA
MGX3AGX?B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGK[B@(OAGIKAGI3A
MGI_AGXOAGJ+AGY+AGI/AGH#"H.&?E`#AGI_AGKSAGICB@(OAGHKAGX3AGX?B
M@(OAGI_AGY+AGIKAGK;AGIGB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;A
MGI/B@(OAGHKAGX+AGIOB@(OAGICAGK?AGI/B@(OAGH7AGY+AGI3AGK;AGI_A
MGXL@X9ZL(.&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>
MO.&>G,*@X9^4`.&>G^&>O.&>F.*`B^&>A^&?DN&>FN&>ON&>G^*`B^&>D.&>
MC^*`B^&>F.&>O>&>F2#AGICAGKOAGI/B@(OAGI/AGKGAGH3B@(OAGJ+AGY+A
MGI/AGH#B@(OAGI3AGY+AGIKAGH_AGK?AGI3AGH_AGY+AGH_AGK?B@(OAGJ+A
MGX;AGI;AGK[B@(OAGI/AGX'AGX?"H.&?E`#AGI_AGKSAGICB@(OAGH?AGY+A
MGIKAGK[AGI_B@(OAGIGAGXGAGK;AGH3B@(OAGJ#AGX3AGH7B@(OAGH[AGK;A
MGI_AGXOB@(OAGI#AGH_B@(OAGICAGKWAGID@X9Z*X9Z^X9Z8X9^2X9Z4X9ZX
MXH"+X9Z?X9^2X9Z<X9^"X9Z$XH"+X9Z:X9Z`PJ#AGY0`X9Z?X9Z\X9Z8XH"+
MX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z0X9Z/XH"+X9Z/X9^"XH"+X9Z8X9Z]X9Z9
MXH"+X9Z"X9Z/X9^+(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>E.&?DN&>
MFN&>C^&>M^&>E.&>C^&?DN&>C^&>M^&>@.&>MN&>FN*`B^&>D^&?@>&?A\*@
MX9^4`.&>G^&>O.&>F.*`B^&>A^&?DN&>FN&>ON&>GR#AGJP@X9Z`X9^"X9Z?
MX9Z8X9^2X9Z:X9Z]X9Z;XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z4X9^2X9Z:
MX9ZBX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z!X9ZVX9Z$XH"+X9Z?X9^2X9Z/X9ZV
MX9^&PJ#AGY8`X9Z4X9^)X9Z\X9ZAX9Z\X9Z)`.&>EN&?D.&>FN&>D>&>N^&>
MF>&>H.&?DN&>@N&>MN&>F^&?BP#AGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB
M@(OAGHKAGK[AGIKB@(OAGHKAGX3AGID@2&]R9&4`X9Z3X9ZVX9^&XH"+X9Z8
MX9Z[X9Z!XH"+X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZVXH"+X9Z:X9Z4X9Z?
MX9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z*X9^$X9Z9XH"+X9Z?X9Z)X9^2X9Z)
MX9ZVXH"+X9Z*X9ZVX9Z%X9^+X9^7("@G+2T@)RG"H#\`X9Z%X9^&X9Z.X9Z$
MX9^+XH"+X9Z%X9^&X9Z.X9Z\X9Z;X9Z%X9ZWX9Z/X9^2X9Z/(.*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?
MDN&>F>*`B^&>D>&>MN&>D^&?B^*`B^&>G^&>F.&?D.&>F>*`B^&>BN&?A.&>
MF>*`B^&>G^&?DN&>G.&?D.&>F>*`B^&>E.&?DN&>FN&>G.&>C^&?DN&>C^&>
MM\*@X9^4`.&>G^&>F.&?DN&>EN&>MN&>D@#AGICAGK[AGIOB@(OAGH?AGK;B
M@(OAGICAGKOAGI,`X9Z?X9ZVX9Z:XH"+X9Z8X9Z[X9Z3`.&>D>&?AN&>EN&?
MD.&>FN*`B^&>F.&>N^&>DP#AGI3AGX3AGX?AGI;AGKOAGICAGY+AGI8`X9ZB
MX9ZVX9Z1X9ZWX9Z7X9ZVX9Z6`.&>EN&>MN&>@.&?DN&>F>*`B^&>G^&>F.&?
MDN&>A.&>MN&>C^&?B^*`B^&>FN&>E.&>G^&?B^&>@.&>O.&>D^&>G^&?A.*`
MB^&>K^&>@.&>A^&>DP#AGH+AGICAGY+AGIKAGX3AGH0`X9Z:X9^&X9Z;X9ZY
MX9Z`XH"+X9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+X9Z6X9^!X9Z;XH"+
MX9Z*X9^"X9Z;XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4
MX9^+XH"+X9Z8X9Z]X9Z9XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3
MXH"+X9Z5X9^2X9Z)X9Z^PJ#AGY0@X9Z;X9^&X9Z3X9ZVX9^&X9Z*X9Z^X9Z8
MX9Z"X9ZZXH"+X9Z1X9^!PJ#AGY0`X9Z:X9^&X9Z;X9ZYX9Z`XH"+X9Z:X9^`
MX9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+X9Z6X9^!X9Z;XH"+X9Z*X9^"X9Z;XH"+
MX9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z8X9Z]
MX9Z9XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z)
MX9Z^PJ#AGY0@X9Z;X9^&X9Z3X9ZVX9^&X9Z*X9Z^X9Z8X9Z"X9ZZXH"+X9Z4
MX9ZVX9Z1PJ#AGY0`X9Z6X9ZWX9Z2X9ZXX9Z`X9ZVX9Z:PJ#AGY8`X9Z`X9Z\
MX9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(`.&>@.&>MN&>FN*`
MB^&>@N&>MN&?AN&>D>&?DN&>FN*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`
MB^&>E.&>F.&?DN&>FN&>ON*`B^&>@.&>O.&>D^&>G^&?A"!01U`@X9Z?X9ZV
MX9Z2X9ZVX9Z:X9Z.X9^((.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>DN&?DN&>G.&>ON&>LN&?DN&>F>*`B^&>E.&?DN&>FN&>ON*`B^&>F^&?
M@N&>A.*`B^&>E.&>MN&>D\*@X9^4`.&>EN&?D.&>FN&>C^&>O.&>FN&>N.&>
M@.&>O`!?1^&>F^&>N^&>E.*`B^&>E.&?AN&>E.&>MN&>C^&?BR`BX9Z4X9ZV
MX9Z3XH"+X9Z;X9Z[X9Z4(B``X9Z;X9Z[X9Z4XH"+X9Z4X9^&X9Z4X9ZVX9Z/
MX9^+("+AGI3AGK;AGI/B@(OAGIOAGKOAGI0B(`#AGIOAGKOAGI3B@(OAGI3A
MGX;AGI3AGK;AGH_AGXOB@(OAGI#AGH\`X9Z%X9^&X9Z3X9Z]X9Z3XH"+X9Z*
MX9Z$XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z;X9Z[X9Z4XH"+X9Z4X9^&X9Z4
MX9ZVX9Z/X9^+XH"+X9Z?X9^&X9Z:X9ZVX9Z8PJ#AGY8`X9Z;X9Z[X9Z4XH"+
MX9Z4X9^&X9Z4X9ZVX9Z/X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z`X9^2X9Z3X9Z[
MX9Z$XH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8(.&>BN&?@N&>F^*`B^&>
MA>&>MN&>G^&?B^*`B^&>A^&>MN&>A.*`B^&>A>&?AN&>D^&>O>&>D^*`B^&>
MD.&?DN&>A.&?@^*`B^&>D^&?@>&?A\*@X9^4`.&>F^&>N^&>E.*`B^&>E.&?
MAN&>E.&>MN&>C^&?B^*`B^&>G^&>MN&>FN*`B^&>A>&>MN&>G^&?B^*`B^&>
M@.&?DN&>D^&>N^&>A.*`B^&>D.&>C^*`B^&>G^&?AN&>FN&>MN&>F,*@/P#A
MGH#AGX;AGI;AGKOAGH3B@(OAGIOAGKOAGI3B@(OAGI3AGX;AGI3AGK;AGH_A
MGXOB@(OAGI_AGK;AGIKB@(OAGH7AGX;AGI/AGKWAGI,@)60@X9Z6X9ZXXH"+
MX9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8PJ#AGY0`X9Z`X9^&X9Z6X9Z[X9Z$
MXH"+X9Z;X9Z[X9Z4XH"+X9Z4X9^&X9Z4X9ZVX9Z/X9^+XH"+X9Z?X9ZVX9Z:
MXH"+X9Z%X9^&X9Z3X9Z]X9Z3(.&?H2#AGI;AGKCB@(OAGI#AGH_B@(OAGI_A
MGX;AGIKAGK;AGIC"H.&?E`#AGH#AGK;AGH_AGK8`X9Z?X9^&X9Z.X9Z]X9Z:
MXH"+`.&>@.&>O.&>C^&>M@#AGI_AGY+AGI#AGK;AGI/AGI?AGK;AGI;B@(OA
MGH#AGKSAGH_AGK;"H.&?EB`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`.&>
MG^&?DN&>D.&>MN&>D^&>E^&>MN&>EN*`B^&>@.&>O.&>C^&>ML*@X9^6("4N
M,F9-0B`O(.&>@N&?DN&>F.&>MN&>D^*`B^&>@.&?AN&>CN&>C^&?BP#AGI_A
MGY+AGI#AGK;AGI/AGI?AGK;AGI;B@(OAGH#AGKSAGH_AGK;"H.&?EB#AGH+A
MGY+AGICAGK;AGI/B@(OAGH#AGX;AGH[AGH_AGXL`X9Z?X9Z8X9^2X9Z:X9Z$
MX9^+("5FPJ#AGY8`X9ZBX9ZVX9Z3`.&>G^&?DN&>D.&>MN&>E.&>D^&>MN*`
MB^&>F.&?@N&>@.&>DN&>MN&>A.*`B^&>D.&>C^*`B^&>H>&>ON&>A.*`B^&>
MG.&>M^&>B0#AGI3AGK;AGI/B@(OAGI'AGI'AGKWAGIL@XH"+X9Z3X9^%XH"+
MX9Z0X9^2X9Z$X9^#`.&>E.&>MN&>D^*`B^&>D>&>D>&>O>&>F^*`BR#AGH7A
MGK;AGI3AGXOB@(OAGH_AGK;AGX;AGH3B@(OAGI;AGK@`X9Z4X9ZVX9Z3XH"+
MX9Z1X9Z1X9Z]X9Z;(.&>FN&>H.&>O.&>C^&>BN&>F^&?BP!?5.&>E.&?DN&>
MC^&>O.&>FN*`B^&>D>&>M^&>GR``X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1X9ZW
MX9Z?`.&>E.&?DN&>C^&>O.&>FN*`B^&>D>&>M^&>G^*`B^&>G^&>MN&>F@#A
MGI3AGY+AGH_AGKSAGIKB@(OAGI'AGK?AGI_B@(OAGI_AGK;AGIKB@(OAGI/A
MGX'AGX<`X9Z`X9ZVX9Z:XH"+X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1X9ZWX9Z?
MXH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9PJ#AGY0`X9Z2X9^2
MX9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z?X9^2X9Z:X9Z?X9^+`.&>DN&?DN&>
MG.&>ON*`B^&>LN&?DN&>F>*`B^&>D>&>M^&>BN&?DN&>B^&>E^&>MN&>EN*`
MB^&>FN&>E.&>G^&?B^*`B^&>D.&>C^*`B^&>G^&?DN&>FN&>G^&?B\*@X9^6
M`.&>HN&>C^&?DN&>FN&>MN*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`
MB^&>G^&?DN&>FN&>G^&?B\*@X9^6`.&>E>&?DN&>D>&>N^&>@.*`B^&>H>&>
MON&>A.*`B^&>G.&>M^&>B0#AGI7AGY+AGI'AGKOAGH#B@(OAGI'AGK?AGHKA
MGY+AGHOAGI?AGK;AGI;B@(OAGJ'AGK[AGH3B@(OAGISAGK?AGHD`X9Z`X9^&
MX9Z.X9Z/X9^+XH"+X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+`.&>A>&>A.&>A>&>
MMN&?AN*`B^&>EN&?D.&>C^&?C.&>F.&>MN&>DR#AGI'AGX;AGI/AGX'AGIHO
MX9Z:X9Z<X9Z;X9^+PJ#AGY0`X9Z%X9Z$X9Z%X9ZVX9^&XH"+X9Z1X9ZWX9Z*
MX9^2X9Z+X9Z7X9ZVX9Z6XH"+X9Z%X9Z[X9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9
M`.&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`
MB^&>AN&?DN&>A.&>MN&>F<*@X9^6`.&>F>&>@.*`B^&>A>&?@>&>B0#AGIGA
MGH#B@(OAGISAGK;AGIOB@(OAGH7AGX'AGHGB@(OAGI;AGKCB@(OAGH#AGK;A
MGIKB@(OAGI_AGY+AGISAGX+AGH3B@(OAGIKAGH``X9Z9X9Z`XH"+X9Z4X9^2
MX9Z:X9Z7X9Z6XH"+X9Z%X9^!X9Z)`.&>E.&?DN&>C^&>O.&>FN*`B^&>B.&?
MDN&>F.&?A.&?A^*`B^&>D.&>CP#AGI3AGY+AGH_AGKSAGIKB@(OAGHCAGY+A
MGICAGX3AGX?B@(OAGI#AGH_B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OA
MGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI7AGY+AGHGAGKX@X9Z3X9^%XH"+
MX9Z6X9^!X9Z;XH"+X9Z%X9ZVX9Z4X9^+XH"+X9Z5X9^2X9Z/X9Z^X9Z8XH"+
MX9Z3X9^#XH"+X9Z!X9^"PJ`_`.&>@.&>MN&>FN*`B^&>E.&?DN&>C^&>O.&>
MFN*`B^&>B.&?DN&>F.&?A.&?AR`B)7,B(.&>D>&?A2`B)7,B(.&>E.&>MN&>
MD^*`B^&>E.&>FN&>MN&>A^&?D.&>F<*@X9^4(.&>D^&?@>&?A^*`B^&>@N&>
MNN*`B^&>A^&>MN*`B^&>HN&?DN&>G.&>N.*`B^&>BN&?@N&>F^*`B^&>F.&?
MB>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>E.&>MN&>
MD^*`B^&>D^&>M^&>F>&>MN&>F0!?6>&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>
ME.*`B^&>D>&?A>*`B^&>E.&>B>&?DN&>A^&>N"``X9Z'X9^&X9Z3X9Z]X9Z?
MXH"+X9Z*X9^$X9Z9PJ#AGY8`X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4`.&>
M@.&>MN&>FN*`B^&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E.*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>O@#AGH;AGY+AGIOA
MGK[AGIGB@(OAGH_AGI3B@(OAGI'AGX7B@(OAGI'AGK;AGX;AGH3B@(OAGJ+A
MGI_AGXL`X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4XH"+X9Z1X9^%XH"+X9Z1
MX9ZVX9^&X9Z$XH"+X9ZBX9Z?X9^+PJ#AGY8`X9Z&X9^2X9Z;X9Z^X9Z9XH"+
MX9Z/X9Z4XH"+X9Z1X9^%XH"+X9Z4X9Z)X9^2X9Z'X9ZX`.&>AN&?DN&>F^&>
MON&>F>*`B^&>C^&>E.*`B^&>D>&?A>*`B^&>E.&>B>&?DN&>A^&>N,*@X9^6
M`%]!X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4XH"+X9Z1X9^%X9Z1X9ZVX9^&
MX9Z$X9ZBX9Z?X9^+(`#AGH;AGY+AGIOAGK[AGIGB@(OAGH_AGI3B@(OAGHKA
MGX3AGIGB@(OB@(OAGI_AGK;AGIKB@(OAGHKAGX+AGIOB@(OAGICAGK?AGI/B
M@(OAGH+AGK;AGX;AGI'AGY+AGIH`X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4
MX9Z*X9^$X9Z9(.&>D>&?AN&>D^&?@>&>FB_AGIKAGISAGIOAGXL@X9Z?X9Z8
MX9^2X9Z:X9ZVX9Z4X9^+XH"+(.&?HB#AGH'AGX+B@(OAGI3AGI/AGY+AGI'A
MGK;AGI3AGXO"H.&?E`#AGH;AGY+AGIOAGK[AGIGB@(OAGH_AGI3B@(OAGHKA
MGX3AGIGB@(OB@(OAGI;AGY#AGH_AGXSAGICAGK;AGI/B@(L@X9Z1X9^&X9Z3
MX9^!X9Z:+^&>FN&>G.&>F^&?BR#AGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OA
MGI_AGY+AGI/AGK[B@(OAGI_AGKOAGX;"H.&?E`#AGH;AGY+AGIOAGK[AGIGB
M@(OAGH_AGI3B@(LMX9Z1X9^%`.&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E.*`
MBRWAGI'AGX7"H.&?EB``X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4PJ#AGY8`
MX9Z:X9ZVX9Z9X9Z`X9ZVX9Z:X9Z.X9^-XH"+X9Z0X9ZVXH"+X9Z;X9^2X9ZB
M`.&>FN&>MN&>F>&>@.&>MN&>FN&>CN&?C>*`B^&>A^&>MN*`B^&>G^&>MN&>
MFN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>F@!?4N&>G^&?DN&>
MD^&>ON*`B^&>G^&>N^&?AN*`B^&>E.&>A.&?DN&>@.&>MN&>D^&?B^*`B^&>
MBN&?@^*`B^&>HN&>MN&>D^*`B^&>F.&>O>&>F2``X9Z?X9^2X9Z3X9Z^XH"+
MX9Z?X9Z[X9^&XH"+X9Z4X9Z$X9^2X9Z`X9ZVX9Z3X9^+XH"+X9Z*X9^#XH"+
MX9ZBX9ZVX9Z3PJ`_`.&>FN&>@.*`B^&>F.&>M^&>D^*`B^&>@^&>ON&>B>*`
MB^&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>G^&?DN&>
MD^&>ON*`B^&>G^&>N^&?AL*@X9^4`.&>HN&?DN&>D^&>@.*`B^&>A>&>O.&>
MF^*`B^&>FN&>O>&>F.*`B^&>BN&?@N&>F^*`B^&>D>&>MN&>F.&>D>&>MN&>
MF@#AGH#AGX;AGH[AGH_AGXOB@(OAGJ'AGK[AGH3B@(OAGISAGK?AGHD`X9Z?
MX9^2X9Z0X9ZVX9Z3X9Z7X9ZVX9Z6XH"+X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/
MX9Z4XH"+(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>DN&?DN&>
MG.&>ON*`B^&>LN&?DN&>F>*`B^&>D>&>MN&>D^&?B^*`B^&>G^&>F.&?D.&>
MF<*@X9^4`.&>F^&>D>&?DN&>DN*`B^&>E>&>FP#AGI+AGY+AGISAGK[B@(OA
MGI3AGI/AGY+AGH\`X9Z2X9^2X9Z<X9Z^XH"+X9Z4X9Z3X9^2X9Z/XH"+X9Z?
MX9Z8X9^0X9Z9XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z``.&>C^&?
MDN&>FN&>H>&>E.&?B^*`B^&>D>&?A2`BX9Z`X9ZVX9Z:XH"+X9Z/X9^"X9Z$
MXH"+X9Z?X9ZVX9Z:(@#AGH_AGY+AGIKAGJ'AGI3AGXOB@(OAGI'AGX7B@(OA
MGH#AGK;AGI/AGXL@(N&>D>&?A>*`B^&>E.&?DN&>FN&>F.&>O.&>F^*`B^&>
MF>&>@.*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FB(`X9Z/X9^2X9Z:X9ZAX9Z4
MX9^+XH"+X9Z1X9^%XH"+X9Z'X9Z8X9^2X9Z:X9Z^X9Z?`.&>C^&?DN&>FN&>
MH>&>E.&?B^*`B^&>D>&?A>*`B^&>@.&>MN&>FN*`B^&>FN&>MN&>F>*`B^&>
MFN&>E.&>G^&?B^*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>
MN^&>C^&?DN&>FB#AGI3AGI/AGY+AGI'AGK;AGI3AGXOAGI;AGKCB@(OAGIOA
MGKOAGI0@X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZX(.&>K"#AGH7AGICA
MGY+AGIOAGH3B@(OAGI_AGK;AGIKB@(OAGICAGKWAGIG"H#\`X9Z:X9ZXX9ZB
MX9Z[X9Z9X9Z3X9ZXX9Z9X9^)X9Z[X9Z$`.*`B^&>G^&?DN&>C^&>MN&?A@#A
MGH_AGKWAGI/AGK;AGI'AGK@`X9Z:X9Z\X9Z8X9^)X9ZVX9Z3X9ZX`.&>E.&>
MA.&?DN&>G.&>M^&>F^*`B^&>D>&?A>*`B^&>AN&?DN&>G.&?@>&>A`#AGI3A
MGH3AGY+AGISAGK?AGIOB@(OAGI'AGX7B@(OAGI_AGY+AGHKAGK;AGX8`X9Z'
MX9Z]X9Z:XH"+X9Z*X9^!X9Z`PJ#AGY8`X9Z:X9Z/X9^+XH"+`.&>G^&>H.&>
MEN&?D.&>D^&?DN&>DN*`B^&>FN&>N^&>G^&?DN&>G^&?BN&>N`#AGIKAGISA
MGXGAGK;AGI/AGXOAGHKAGK8`4R]-24U%`%,O34E-12!%;F-R>7!T($UE<W-A
M9V4`X9Z`X9^&X9Z@X9Z[X9Z?(%,O34E-1<*@X9^6(`#AGH#AGX;AGJ#AGKOA
MGI\@4R]-24U%PJ#AGY8@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z`X9ZVX9Z:XH"+
MX9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+(.&>G^&>F.&?
MDN&>FN&>MN&>E.&?B^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>K^&>@.&>A^&>
MD^*`B^&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>D\*@X9^4
M`.&>A^&>F.&?DN&>FN&>ON&>GR!3+TU)344`X9Z`X9ZVX9Z:XH"+X9Z4X9Z)
MX9^2X9Z%X9Z\X9Z;XH"+X9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZV
MX9Z/X9^+(%,O34E-10#AGH#AGK;AGIKB@(OAGH+AGK;AGX;AGI'AGY+AGIKB
M@(OAGH+AGKSB@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI7AGY+AGI'AGK;AGIOA
MGXOB@(OAGH'AGY+AGIOAGKWAGI,@4R]-24U%(.&>D>&>MN&>F.*`B^&>D>&>
MMN&>FN*`B^&>@.&>MN&>FN*`B^&>C^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>
MC^&>MN&>F.*`B^&>E.&>CN&?DN&>C^&>MN&>B>*`B^&>G^&>N^&>G.&>C^&?
MDN&>D.&>M^&>E^&>MN&>EL*@X9^4`.&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>
MMN&>DN&>MN&>FN&>CN&?B"!3+TU)344@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+
M("(E<R(@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4
MXH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"X9Z'X9^0X9Z9PJ#AGY0`X9Z`X9Z\
MX9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^((%,O34E-12#AGH_A
MGY+AGIKAGKSB@(OAGISAGI3AGK;AGI/B@(OAGI3AGI/AGY+AGI#AGX+AGICB
M@(OAGHKAGX3AGIGB@(OAGH?AGX3AGH+AGH?AGY#AGIG"H.&?E`!3+TU)344@
M4'5B;&EC($ME>7)I;F<`X9Z"X9Z\XH"+X9Z`X9Z\X9Z3X9Z?X9^$(.&>G^&>
MMN&>DN&>MN&>FN&>CN&?B"_AGJ_AGH#AGH?AGI,@4R]-24U%(.&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>D^&?DN&>D.&?@N&>F.*`B^&>
MBN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F<*@X9^4`%,O34E-12!3:6=N
M($UE<W-A9V4`4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E`.&>@.&>MN&>
MFN*`B^&>@N&>MN&?AN&>D>&?DN&>FB!3+TU)347B@(L@X9Z"X9ZZXH"+X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z2X9^2X9Z<X9Z^XH"+X9ZR
MX9^2X9Z9XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z;X9^"X9Z$XH"+X9Z4X9ZVX9Z3
MXH"+X9Z;X9Z^XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z3X9^!
MX9^'PJ#AGY0`X9Z`X9ZVX9Z:XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:(%,O34E-
M12#AGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+AGI/B@(OAGICAGK?A
MGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISA
MGK[B@(OAGK+AGY+AGIGAGI3AGY+AGIKAGK[B@(OAGI3AGK;AGI,@X9Z*X9Z\
MX9Z%X9^2X9Z3X9^!X9^'XH"+X9Z?X9ZVX9Z:XH"+X9Z8X9ZWX9Z3XH"+X9ZB
MX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9Z8X9^2X9Z;X9^"X9Z$
MXH"+X9Z8X9Z`XH"+X9Z'X9ZVXH"+X9Z7X9ZVX9Z6XH"+X9Z2X9Z8X9^2X9Z8
MX9Z/X9ZVPJ#AGY0`X9Z`X9ZVX9Z:XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:(%,O
M34E-12#AGICAGK?AGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI3AGY+AGIKAGK[B@(OA
MGI3AGK;AGI/B@(OAGJ'AGK[AGID@X9Z*X9Z\X9Z%X9^2X9Z3X9^!X9^'XH"+
MX9Z8X9ZVX9Z/X9ZWX9Z`X9ZVXH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:
MXH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z%X9Z[X9^'XH"+X9Z@X9Z/
MX9^2X9Z0X9Z;X9^!X9Z!X9ZVXH"+X9Z3X9^!X9^'(.&>D^&>N>&>A.*`B^&>
MF.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>E.&>MN&>D^*`B^&>H>&>
MON&>F<*@X9^4`.&>@.&>MN&>FN*`B^&>@N&>MN&?AN&>D>&?DN&>FB!3+TU)
M344@X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z4
MX9ZVX9Z3XH"+X9ZAX9Z^X9Z9(.&>BN&>O.&>A>&?DN&>D^&?@>&?A^*`B^&>
MH.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>C.&>N.&>A^&>N.&>D.&>F^*`
MB^&>D^&>N>&>A.*`B^&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>D>&?@.&>A.&>E>&?DN&>
MD>&>MN&>C^&?B^*`B^&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4`.&>@.&>
MMN&>FN*`B^&>@N&>MN&?AN&>D>&?DN&>FB!3+TU)344@X9Z1X9ZVX9Z8X9Z1
MX9ZVX9Z:XH"+X9ZRX9^2X9Z9XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z4X9Z$X9^2
MX9ZBX9Z]X9Z%XH"+X9Z;X9^!X9Z%X9ZAX9Z^X9Z$PJ#AGY0@X9Z4X9Z^XH"+
MX9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZXXH"+X9Z:X9Z[X9Z`X9Z:X9Z`XH"+
MX9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z`X9^&X9Z6X9Z[X9Z$
MXH"+X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z4X9Z$X9^2X9ZBX9Z]
MX9Z%XH"+X9Z;X9^!X9Z%X9ZAX9Z^X9Z$XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z;
MX9^"X9Z$XH"+X9Z4X9ZVX9Z3(.&>HN&?DN&>D^&>@.*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>C^&?@N*`B^&>E>&?DN&>F^&>MN&>G^&?B^&>E.&?DN&>BN&>
MO.&>FN*`B^&>@.&>MN&>FN*`B^&>@.&?AN&>CN&>C^&?B^*`B^&>D^&?@>&?
MAR#AGI3AGK[B@(OAGI;AGKOAGX;B@(OAGI/AGX3AGX?B@(OAGI'AGX'B@(OA
MGIOAGH#AGY+AGH'AGH[AGXCB@(OAGI;AGK?AGI_AGX'AGI\@4R]-24U%(.&>
MD^&>N>&>A.*`B^&>F.&>M^&>D^*`B^&>BN&?AN&>CN&>ON&>FN&>@.&>MN&>
MFN*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>H>&>ON&>
MF<*@X9^4`%--5%``4U-(`%]5X9Z4X9^2X9Z:X9Z2X9ZVX9Z3XH"+X9Z4X9Z1
M(`!?5N&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>A>&?DN&>E.&>
MMN&>E.&?B^*`B^&>A>&>F.&?DN&>F^&>A.*`B^&>@.&?DN&>D^&>N^&>A"``
M7U;AGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGH?AGK8@`.&>G^&>
MA.&?B^*`B^&>H.&?@>&>H>&?@>&>CN&>M@#AGI_AGH3AGXOAGH/AGKCAGH\@
MX9Z3X9ZWX9Z$(.&>D^&?@>&>G.&>N.&>GP#AGI_AGH3AGXOAGIOAGKSAGI_A
MGXKAGKCAGIGAGXGAGK8`X9Z?X9Z$X9^+XH"+X9Z6X9^2X9Z9X9^"X9Z:(.&>
MD^&>M^&>A"#AGICAGKCAGH+AGKOAGIGAGJ+AGX'AGJ'AGKOAGH0`X9Z?X9Z$
MX9^+X9Z<X9ZVX9^&X9Z$X9Z?X9Z$X9^+(.&>D^&>M^&>A"#B@(OAGJ#AGY+A
MGH+AGY+AGIKAGKCAGH[AGK;AGHSAGKCAGI,`X9Z?X9ZVX9Z8X9Z\X9ZBX9ZV
M`.&>G^&>MN&>D^&?B^&>F.&?B>&>MN&>FN&>N.&>CN&>O`!386\@5&]M92!A
M;F0@4')I;F-I<&4`X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+XH"+X9Z4X9^*X9ZX
MX9Z?X9ZVX9ZBX9Z\X9Z,X9ZX`.&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>
M@`#AGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGJ_AGH#AGI_AGK;A
MGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGH?AGK;AGICAGKWAGIGB@(OA
MGI_AGK;AGIKB@(L@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z0X9Z/XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z5
MX9^2X9Z)X9Z^PJ`_`.&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@"#B@(OA
MGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI;AGY+AGIKAGK;AGH0`X9Z:X9Z`
MX9^2X9Z?X9ZVX9Z1X9Z[X9Z`XH"+X9Z:X9Z\X9Z4X9Z7X9ZVX9Z6`.&>FN&>
M@.&?DN&>G^&>MN&>D>&>N^&>@.*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>
M@.&?DN&>D^&>N^&>A.*`B^&>G.&>M^&>A>&>M^&>C^&?DN&>FN&>G^&>MN&>
MFP#AGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(L@X9Z'X9Z8X9^2X9Z:
MX9Z^X9Z?`.&>FN&>@.&?DN&>G^&>MN&>D>&>N^&>@.*`B^&>E>&?DN&>D>&?
M@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F>*`B^&>G^&?AN&>E.&>
MN^&>C^&?DN&>F@!?1.&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>
MG^&?@>&>A>&>@.&?DN&>C^&>N.&>EN&?DN&>FN&>MN&>A"``X9Z:X9Z`X9^2
MX9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+X9Z'X9ZV`.&>FN&>@.&?DN&>G^&>MN*`
MB^&>D>&>N^&>@.*`B^&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^&>EN&?DN&>
MFN&>MN&>A.*`B^&>A^&>MN*`B^&>F.&>M^&>D^*`B^&>E.&>MN&>D^*`B^&>
MF.&>ON&>F^*`B^&>K,*@/P#AGIKAGH#AGY+AGI_AGK;AGI'AGKOAGH#B@(OA
MGI_AGX'AGH7AGH#AGY+AGHKAGKCAGI;AGY+AGIKAGK;AGH3B@(OAGHKAGX3A
MGIGB@(OAGI_AGY+AGISAGY#AGIGAGI3AGY+AGIKAGISAGH_AGY+AGH_AGK<@
MX9Z!X9Z.X9^(XH"+X9Z6X9^!X9Z;XH"+X9Z/X9^"X9Z$PJ`_`.&>FN&>@.&?
MDN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>HN&?DN&>D^&>@.&>D>&>D>&>O>&>
MF^*`B^&>D>&>MN&?AN&>A.&>H>&>MN&>F2#AGI'AGX7B@(OAGH#AGK;AGI/A
MGXOB@(OAGI_AGX#AGISAGI?AGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI/B@(OAGIOAGX;AGI/AGK;AGX;B@(OAGHKAGK[AGICB@(OB@(OAGHKA
MGX3AGIGB@(OAGI_AGY+AGISAGY#AGIGB@(OAGI3AGY+AGIKAGISAGH_AGY+A
MGH_AGK?"H#\`X9Z:X9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+X9Z`X9ZV
MX9Z:XH"+X9Z?X9^2X9Z<X9^"X9Z$XH"+X9Z:X9Z`(.&>A^&>MN*`B^&>D.&>
MC^*`B^&>D^&>M^&>F.&?DN&>F.&>M^&>C^&>F.&>O>&>F>&>K,*@/P#AGIKA
MGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGI_AGX;AGI3AGKOAGH_AGY+A
MGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/AGI7AGY+AGHGAGK[B@(OAGJSB
M@(OAGI'AGX'"H#\`X9Z`X9ZVX9Z:XH"+X9Z:X9Z`X9^2X9Z?X9ZVX9Z1X9Z[
MX9Z`XH"+X9Z?X9^!X9Z%X9Z`X9^2X9Z*X9ZXX9Z6X9^2X9Z:X9ZVX9Z$XH"+
MX9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9PJ#AGY0@X9Z8X9ZWX9Z3
MXH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z0X9Z/XH"+
MX9Z?X9^!X9Z%X9Z`X9^2X9Z*X9ZXX9Z6X9^2X9Z:X9ZVX9Z$XH"+X9Z4X9ZV
MX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0`X9Z`X9ZVX9Z:XH"+X9Z:X9Z`X9^2X9Z?
MX9ZVX9Z1X9Z[X9Z`XH"+X9Z?X9^!X9Z%X9Z`X9^2X9Z*X9ZXX9Z6X9^2X9Z:
MX9ZVX9Z$XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9PJ#AGY0@
MX9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z0X9Z/XH"+X9Z?X9^!X9Z%X9Z`
MX9^2X9Z*X9ZXX9Z6X9^2X9Z:X9ZVX9Z$XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9Z4X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z'X9ZVX9Z`X9^+XH"+X9Z;X9Z8X9^2
MX9ZBX9ZWX9Z/PJ#AGY0`X9Z`X9ZVX9Z:XH"+X9Z:X9Z`X9^2X9Z?X9ZVXH"+
MX9Z1X9Z[X9Z`XH"+X9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZXX9Z6X9^2X9Z:X9ZV
MX9Z$XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9PJ#AGY0@X9Z3
MX9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9ZBX9^2X9Z<X9ZXXH"+X9Z*
MX9^"X9Z;XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:
MX9Z^XH"+X9Z4X9ZVX9Z3X9Z3X9ZWX9Z9X9ZVX9Z9PJ#AGY8@)7,`X9Z?X9^2
MX9Z<X9^"X9Z$XH"+X9Z:X9Z``.&>G^&?DN&>G.&?@N&>A.*`B^&>FN&>@"`E
M<P#AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI_AGY+AGISAGX+AGH3AGIKA
MGH``X9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z?X9^2X9Z<X9^"X9Z$X9Z:X9Z`
M`.&>F^&>D>&?DN&>DN&>E>&>F^*`B^&>G^&?DN&>G.&?@N&>A.*`B^&>FN&>
M@`#AGI3AGK;AGI/B@(OAGICAGK[AGIL`X9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z"
MX9Z.X9Z3X9ZXXH"+X9Z8X9Z]X9Z9XH"+X9Z5X9^2X9Z?X9^!X9Z$`.&>A^&?
MDN&>FN&>ON&>G^*`B^&>@.&>MN&>F^&>E.&>FN&>M^&>A>&?DN&>AN&?@>&>
MD0#AGH?AGY+AGIKAGK[AGI_B@(OAGISAGK;AGIL`X9Z'X9^2X9Z:X9Z^X9Z?
MXH"+X9Z4X9^2X9Z:X9Z7X9Z6XH"+X9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZV
MX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`
MB^&>E.&>D^&?DN&>D.&?@N&>F"#AGI/AGK?AGH0@X9Z?X9^2X9Z<X9^"X9Z$
MXH"+X9Z:X9Z`XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3PJ#AGY3B
M@(L`X9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+`.&>
MA^&?DN&>FN&>ON&>G^*`B^&>G.&>MN&>F^*`B^&>BN&?@N&>F^*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>G^&?DN&>G.&?@N&>A.*`B^&>FN&>@.*`B^&>D>&>
MMN&?AN&>A.&>HN&>G^&?BR#AGI;AGX'AGIOB@(OAGI;AGH3AGY+AGIKAGKCA
MGH#B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/"H.&?E`#AGH?AGY+A
MGIKAGK[AGI_B@(OAGH+AGH[AGI/AGK@`X9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z"
MX9^2X9Z8X9ZVX9Z3`.&>A^&?DN&>FN&>ON&>G^*`B^&>E>&?DN&>D>&?@^*`
MB^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F>*`B^&>G^&?AN&>E.&>N^&>
MC^&?DN&>FL*@X9^6`.&>A^&?DN&>FN&>ON&>G^*`B^&>G.&>M^&>A>&>M^&>
MC^&?DN&>FN&>G^&>MN&>FR#AGHKAGK[AGICAGY+AGI3AGKCB@(OAGIKAGH#A
MGY+AGI_AGK;AGI'AGKOAGH#B@(OAGIKAGKSAGI3AGI?AGK;AGI;B@(OAGI/A
MGX7B@(OAGH#AGY+AGI/AGKOAGH3"H.&?E`#AGH?AGY+AGIKAGK[AGI_B@(OA
MGI3AGY+AGIKAGI?AGX'AGI'B@(OAGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OA
MGI3AGICAGY+AGIKAGK[B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH`X9Z'X9^2
MX9Z:X9Z^X9Z?PJ#AGY8`X9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9
MX9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z'
MX9^2X9Z:X9Z^X9Z?PJ#AGY8`X9Z4X9Z)X9^2X9Z'X9Z\X9Z3XH"+X9Z`X9Z\
MX9Z3X9Z?X9^$XH"+X9Z1X9^%XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+
MX9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2
MX9ZVX9Z:X9Z.X9^(`.&>E>&?DN&>B>&>ON*`B^&>EN&?D.&>C^&?C.&>F.&>
MMN&>D^*`B^&>D.&?DN&>F.&>N.*`B^&>E.&?AN&>E>&>N^&>CP#AGI7AGY+A
MGHGAGK[B@(OAGI_AGK;AGIH`X9Z5X9^2X9Z)X9Z^XH"+X9Z?X9ZVX9Z:XH"+
MX9Z*X9^$X9Z9XH"+X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z4X9^2X9Z:X9Z2X9ZV
MX9Z3X9Z4X9Z1PJ`_`.&>E>&?DN&>B>&>ON*`B^&>E.&>A.&?DN&>@.&>MN&>
MD^&?B^&>BN&?@^*`B^&>E.&>MN&>D^*`B^&>HN&>MN&>DR#AGI/AGX7B@(OA
MGI;AGX'AGIOB@(OAGI3AGK;AGI/B@(OAGI_AGY+AGI/AGK[B@(OAGHKAGX3A
MGIGB@(OAGJ+AGY+AGI/AGH#B@(OAGI7AGY+AGHGAGK["H#\`X9Z?X9^!X9Z.
MX9^!X9Z@X9^2X9Z"X9ZVX9Z;X9^+`.&>D.&>C^*`B^&>G^&?AN&>E.&>N^&>
MC^&?DN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>
MO@#AGI#AGH_B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGHKAGX+AGIOB
M@(OAGI3AGK;AGI/B@(OAGI7AGY+AGHGAGK["H.&?E@#AGH#AGHGAGY+AGHGA
MGK8`X9Z?X9^"X9Z4X9^*X9ZX(.&>D^&>M^&>A"#AGICAGXGAGKOAGH3AGH_A
MGX'AGH[AGX'AGJ#AGY+AGH#AGY+AGIKAGKP`X9Z;X9^!X9Z!XH"+X9Z?X9Z8
MX9^2X9Z"X9ZVX9Z;X9^+`.&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>
MF.&?DN&>FN&>O@#AGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGICAGXGAGK;A
MGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGKX@X9Z3X9ZWX9Z$(.&>D.&>
MCP#AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK["H.&?
ME@#AGI_AGICAGY#AGID`X9Z`X9^&X9Z.X9Z/X9^+`.&>@.&?AN&>CN&>C^&?
MB^*`B^&>A>&?AN&>CN&>A.&?B^*`B^&>A>&?AN&>CN&>O.&>F^&>A>&>M^&>
MC^&?DN&>C^&>D.&>MN*`B^&>HN&?DN&>G.&>N.*`B^&>D^&>N>&>A.*`B^&>
MC^&?DN&>FN&>O.&>G.*`B^&>@.&>ON&>C^&>H>&>ON&>A"#AGI;AGX'AGIOB
M@(OAGJ+AGY+AGI/AGH#B@(OAGI7AGY+AGIOAGK;AGI_AGXOAGI'AGK@@X9Z3
MX9ZWX9Z$(.&>F^&>N^&>E.*`B^&>G^&>MN&>FL*@X9^4`.&>@.&?AN&>CN&>
MC^&?B^*`B^&>E.&>B^&>F.&>@.&>D.&>MN*`B^&>HN&>MN&>D>&>M^&>E^&>
MMN&>EB!8(.&>EN&?@>&>F^*`B^&>C^&?@N&>A.*`B^&>G^&>MN&>FL*@/P#A
MGHKAGX;AGJ'AGK[AGH0`X9Z?X9ZXX9Z?X9^2X9Z@X9^"X9Z;`.&>A>&?@N&>
M@.*`B^&>FN&?AN&>F^&?@N&>@.*`B^&>D.&>CP#AGH7AGX+AGH#B@(OAGIKA
MGX;AGIOAGX+AGH#B@(OAGI#AGH_B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH`
MX9Z%X9^"X9Z`XH"+X9Z:X9^&X9Z;X9^"X9Z`XH"+X9Z0X9Z/XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`
M(.&>A^&>MN&>F.&>O>&>F>*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>
MON*`B^&>E>&?DN&>G^&?@>&>A,*@X9^4`.&>A^&>MN*`B^&>F^&?AN&>D^&>
MMN&?AN*`B^&>BN&>ON&>F.*`BR#AGH_AGK[B@(OAGI3AGH[AGY+AGH_AGKOA
MGX;B@(OAGI+AGX;AGI/AGX/B@(OAGJ+AGH_AGY+AGI#AGI3AGI'B@(OAGHKA
MGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI_AGY+AGIKAGH3AGXL@X9Z"X9Z]X9Z:
MXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z$X9^2X9Z@
MX9ZVX9Z)(.&>K"#AGIOAGK;AGH#AGXOB@(OAGJSB@(OAGI'AGX'"H#\@X9Z8
MX9Z]X9Z9XH"+X9Z.X9ZVXH"+X9Z`X9^/XH"+X9Z*X9^$X9Z9XH"+X9Z*X9^"
MX9Z;XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z'X9^2X9Z:X9Z^X9Z?(.&>G.&>MN*`
MB^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
ME.&>M^&>D>*`B^&>E.&>ON&>@.*`B^&>BN&?A.&>F>*`B^&>A.&>MN&>F>&>
MG^&?DN&>FN&>O>&>F\*@X9^4`.&>C^&>ON*`B^&>C^&>O>*`B^&>D^&?@^*`
MB^&>G^&>MN&>FN*`B^&>HN&>C^&?DN&>D.&>E.&>D2_AGI+AGICAGY+AGICA
MGH_AGK8@X9Z"X9Z]X9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3
MXH"+X9Z<X9ZWX9Z7X9ZVX9Z"(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>
MD>&>M^&>D^&?DN&>D^&>D^&?D.&>F2!01U`@X9ZLXH"+X9Z1X9^!PJ`_XH"+
M`.&>C^&>ON*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`B^&>C^&?@N&>A.*`B^&>
M@N&>O>&>FN*`B^&>C^&?@N*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>E.&>M^&>D2#AGI3AGI/AGY+AGI'AGK;AGI3AGXOB@(OAGI;AGKCB
M@(OAGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGI_AGX'AGH7AGH#A
MGY+AGH_AGKCB@(OAGI;AGY+AGIKAGK;AGH3B@(OAGJSAGI'AGX'"H#\`X9Z/
MX9Z^XH"+X9Z`X9Z\X9Z3XH"+X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.
MX9^((%!'4"#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#B@(L@X9Z"X9Z]
MX9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z7X9^2X9Z'
MX9ZVX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z?X9ZVX9Z:XH"+X9Z:X9Z4X9Z?X9^+
MXH"+X9ZBX9^2X9Z3X9Z`XH"+XH"+X9Z'X9ZVXH"+X9Z;X9^&X9Z3X9ZVX9^&
MXH"+X9Z*X9Z^X9Z8XH"+X9ZLXH"+X9Z1X9^!PJ`_`.&>E.&>A.&?DN&>H.&>
MMN&>B0#AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI#AGH_B@(OAGI'AGK;AGX;A
MGH3B@(OAGJ+AGI_AGXL`X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z4X9Z+X9Z8
MX9Z`X9Z0X9ZVXH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+`.&>E.&>A.&?DN&>
MH.&>MN&>B2`BX9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4(@#AGI3AGH3AGY+AGJ#A
MGK;AGHGB@(OAGIKAGKSAGI3AGI?AGK;AGI;"H#\`X9Z4X9Z$X9^2X9Z@X9ZV
MX9Z)("+AGI3AGHOAGICAGH#AGI#AGK;B@(OAGHKAGX+AGIOB@(OAGI3AGK;A
MGI/B@(OAGH#AGICAGY+AGIKAGK?AGH\B`.&>E.&>A.&?DN&>H.&>MN&>B>*`
MB^&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>FN&>E.&>G^&?B^*`B^&>E.&>
MB>&?DN&>A^&>N.*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>FN&>O>&>
MF`#AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGH_AGX+B@(OAGI#AGH_B@(OAGHKA
MGX+AGIOB@(OAGI3AGK;AGI/B@(OAGH?AGK;AGIP`X9Z4X9Z$X9^2X9Z@X9ZV
MX9Z)("+AGI3AGK;AGI/B@(OAGHCAGI3AGXOB@(OAGH?AGK;AGIPB`.&>E.&>
MA.&?DN&>H.&>MN&>B>*`B^&>FN&>O.&>E.*`B^&>C^&?AN&>CN&>MN&>A.*`
MB^&>BN&?@N&>F^*`B^&>HN&>D^&>N^&>B>&?DN&>B>&>MN&>C^*`B^&>LN&?
MDN&>F>*`B^&>A>&?DN&>E.&>O.&>C^*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>
ME^&?DN&>A^&>MN&>E.&?B^*`B^&>A>&?@>&>B>*`B^&>EN&>N.*`B^&>G^&>
MMN&>FN*`B^&>K,*@/P#AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGH_AGK;AGH0@
MX9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z1X9ZWX9Z*X9^2X9Z+X9Z7X9ZVX9Z6XH"+
MX9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:PJ`_
M`.&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>F.&>ON&>F^*`B^&>A^&>MN*`B^&>
MF.&>N^&>DR#AGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OAGH_AGX+B@(OAGI_A
MGK;AGIKB@(OAGICAGK?AGI/B@(OAGI'AGK;AGI/AGXOB@(OAGJ+AGK;AGI/"
MH#\`X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z8X9Z^X9Z;XH"+X9Z'X9ZVXH"+
MX9Z8X9Z[X9Z3(.&>A^&>MN*`B^&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>
MA^&?AN&>D^&>O>&>F<*@/P#AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGIKAGKSA
MGI3B@(OAGH_AGX;AGH[AGK;AGH0@(N&>D>&?A>*`B^&>E.&?DN&>FN&>F.&>
MO.&>F^*`B^&>F>&>@.*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FB(@X9Z;X9Z^
MXH"+X9Z:X9Z4X9ZVX9Z:XH"+X9Z8X9^)X9ZZX9Z3X9Z[X9Z9PJ`_`.&>E.&>
MA.&?DN&>H.&>MN&>B>*`B^&>FN&>O.&>E.&>C^&?AN&>CN&>MN&>A.*`B^&>
MFN&>E.&>G^&?B^*`B^&>C^&>F.&?DN&>FN&>A.*`B^&>F^&>ON*`B^&>FN&>
ME.&>MN&>FN*`B^&>F.&?B>&>NN&>D^&>N^&>F<*@/P#AGI3AGH3AGY+AGJ#A
MGK;AGHGB@(OAGH7AGX;AGI/AGKWAGI/B@(OAGI_AGX;AGI3AGKOAGH_AGY+A
MGIKB@(OAGI_AGIKAGKOAGI3B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI#AGH_"
MH#\`X9Z4X9ZVX9Z3XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)`.&>E.&>A.&?DN&>
MFN&>O>&>B0!?6N&>D>&?AN&>H.&?AB``X9Z?X9^!X9Z:X9^)X9ZVX9ZAX9^!
MX9ZBX9Z\X9Z3`.&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>M@#AGI3AGK;AGI/B
M@(OAGH7AGKOAGX?B@(OAGJ#AGH_AGY+AGI#AGIOAGX'AGH'AGK8`X9Z?X9ZY
MX9Z$X9^2X9Z@X9Z4X9Z[X9Z:X9ZX`.&>D>&?AN&>H.&?A@#AGI'AGX;AGJ#A
MGX;"H.&?E@#AGI_AGY+AGIOAGKSAGISAGXGAGK;AGH+AGK@`X9Z?X9^2X9Z;
MX9Z\X9Z<X9^)X9ZVX9Z3X9ZX`.&>@.&?A.&?A^*`B^&>G^&>O.&>H>&>O.&>
MF.&?B>&>O.&>DP#AGI_AGKSAGICAGXGAGK;AGIOAGK@`X9Z/X9Z8X9^2X9Z:
MX9^`X9Z4XH"+X9Z/X9ZVX9Z8XH"+X9Z`X9ZVX9Z:XH"+X9Z8X9Z`XH"+X9Z*
MX9Z;X9^+`.&>C^&>F.&?DN&>FN&?@.&>E.*`B^&>C^&>MN&>F.*`B^&>@.&>
MMN&>F^*`B^&>E.&>FN&>M^&>A>&?DN&>AN&?@>&>D0#AGH_AGICAGY+AGIKA
MGX#AGI3B@(OAGH_AGK;AGICB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;A
MGI,@(N&>EN&>N"(`X9Z/X9Z8X9^2X9Z:X9^`X9Z4XH"+X9Z/X9ZVX9Z8XH"+
MX9Z1X9^&X9Z@X9^&XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:`.&>C^&>
MF.&?DN&>FN&?@.&>E.*`B^&>C^&>MN&>F.*`B^&>E.&?DN&>FN&>DN&>MN&>
MD^*`B^&>E.&>D0#AGH_AGICAGY+AGIKAGX#AGI3B@(OAGH_AGK;AGICB@(OA
MGH'AGY+AGI_AGX+B@(OAGJ+AGX;AGI3AGX3AGX<`X9Z/X9Z8X9^2X9Z:X9^`
MX9Z4XH"+X9Z/X9ZVX9Z8XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3
MXH"+("+AGI'AGX4B`.&>HN&>MN&>H.&?DN&>FN&>M^&>@.*`B^*`B^&>@>&>
MMN&>A.*`B^&>C^&?DN&>E.&>O.&>A`#AGJ#AGY+AGI_AGH#AGJ#AGY+AGI_A
MGXKAGKCB@(OAGH'AGK;AGH3B@(OAGH_AGY+AGI3AGKSAGH0@X9Z3X9ZWX9Z$
M(.&>@.&?A.&?A^&>G^&>MN&?AN&>A.&>G.&>M^&>A>*`B^&>@>&>MN&>A.*`
MB^&>C^&?DN&>E.&>O.&>A`#AGH+AGICAGY+AGIOAGK;AGH\`X9ZBX9^!X9Z?
MX9^)X9^2X9Z4X9ZVX9Z)`.&>G^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>
MD^*`B^&>@.&>MN&>F@#AGI#AGH_B@(OAGI_AGK;AGIKB@(OAGJ7AGH_B@(OA
MGI3AGK;AGI/B@(OAGH#AGK;AGIKB@(L`X9Z0X9Z/XH"+X9Z:X9Z4X9Z?X9^+
MXH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3X9Z`X9ZVX9Z:PJ#A
MGY8`X9Z/X9Z]X9ZBX9Z`X9^2X9Z?X9Z:XH"+X9Z6X9ZWX9Z?X9^!X9Z?`.&>
MF.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>@.&?@N&>G^&>F.&?DN&>FN&>O>&>
MF^*`B^&>D.&>C^*`B^&>D^&>M^&>F.&?DN&>F.&>M^&>C^*`B^&>EN&>M^&>
MG^&?@>&>G^*`B^&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4`.&>EN&>M^&>
MD^&>M^&>C^&?DN&>F>*`B^*`B^&>HN&>@.&?DN&>@>&>FN&>MN&>G.&>M^&>
MFN&>N^&>D>&?DN&>D@#AGH#AGICAGY+AGICAGISAGK?AGI+AGKCB@(OAGI;A
MGK?AGI/AGK?AGH_AGY+AGIGB@(OB@(OAGJ+AGH#AGY+AGH'AGIKAGK;AGISA
MGK?AGIKAGKOAGI'AGY+AGI(`X9Z`X9ZVX9Z:XH"+X9Z6X9ZWX9Z3X9ZWX9Z/
MX9^2X9Z9XH"+X9ZBX9Z`X9^2X9Z!X9Z:X9ZVX9Z<X9ZWX9Z:X9Z[X9Z1X9^2
MX9Z2XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z%X9Z4X9^+XH"+X9Z1X9ZV
MX9^&X9Z$XH"+X9Z?X9^2X9Z:X9Z[X9Z$`.&>@.&>MN&>FN*`B^&>EN&>M^&>
MD^&>M^&>C^&?DN&>F>&>HN&>@.&?DN&>@>&>FN&>MN&>G.&>M^&>FN&>N^&>
MD>&?DN&>DN*`B^&>E.&>MN&>D^*`B^&>E.&>B>&?DN&>A>&>E.&?B^*`B^&>
MH.&>ON&>F2`M(.&>F.&>M^&>D^*`B^&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>
MN^&>G^*`B^&>HN&>@.&?DN&>@>&>FN&>MN&>G.&>M^&>FN&>N^&>D>&?DN&>
MDN*`B^&>H>&>ON&>F0#AGH#AGX;AGJ#AGKOAGI_B@(OAGJ+AGH#AGY+AGH'A
MGIKAGK;AGISAGK?AGIKAGKOAGI'AGY+AGI+B@(OAGH#AGY+AGI/AGKOAGH3B
M@(OAGICAGKWAGIGB@(OAGJ+AGX'AGH#AGY+AGIKAGH3AGXL@X9Z6X9^!X9Z;
MXH"+X9Z6X9ZWX9Z3X9ZWX9Z/X9^2X9Z9X9ZBX9Z`X9^2X9Z!X9Z:X9ZVX9Z<
MX9ZWX9Z:X9Z[X9Z1X9^2X9Z2PJ#AGY0`X9Z?X9^2X9Z:X9ZXX9Z;X9Z$X9^2
MX9Z`X9ZV`.&>@>&?DN&>D^&>MN&>C^*`B^&>@N&?AN&>FN&>O`#AGH7AGK;A
MGI3AGXOAGI7AGY+AGH_AGK[AGI@`X9Z5X9^2X9Z1X9^#XH"+X9Z!X9ZVX9Z$
MXH"+X9Z`X9^2X9Z:X9^$X9Z9XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:`.&>
MB.&?DN&>F.&?A.&?A^*`B^&>E>&?DN&>D>&?@^*`B^&>@>&>MN&>A.*`B^&>
M@.&?DN&>FN&?A.&>F>*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FL*@X9^6`.&>
ME.&?DN&>FN&>E^&?@>&>D>*`B^&>E>&?DN&>D>&?@^*`B^&>@>&>MN&>A.*`
MB^&>@.&?DN&>FN&?A.&>F>*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FL*@X9^6
M`.&>E>&?DN&>D>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F>*`
MB^&>G^&?AN&>E.&>N^&>C^&?DN&>FL*@X9^6`.&>G^&?DN&>D.&>MN&>D^&>
ME^&>MN&>E@#AGI3AGI/AGY+AGI'AGK;AGH_AGXOB@(OAGH;AGKSAGH\`X9Z%
MX9^2X9Z4X9Z\X9Z/XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZV
MX9Z4X9^+XH"+X9Z%X9^!X9Z)`.&>A>&?DN&>E.&>O.&>C^*`B^&>@.&>MN&>
MFN*`B^&>A>&>N^&?A^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>A>&?
M@>&>B<*@/P!?2N&>E.&?DN&>FN&>DN&>MN&>D^&>E.&>D2``X9Z4X9^2X9Z:
MX9Z2X9ZVX9Z3X9Z4X9Z1`.&>G.&>MN&>F^*`B^*`B^&>E.&?DN&>FN&>DN&>
MMN&>D^&>E.&>D0#AGHKAGK;AGH#AGXOB@(OAGI_AGY+AGI/AGKX`X9Z'X9ZV
MX9Z<XH"+X9Z4X9^2X9Z:X9Z%X9ZVX9^&XH"+X9Z1X9^%XH"+X9Z0X9Z/`.&>
MHN&>@.&?DN&>G^&>FN*`B^&>C^&>O.&>A>*`B^&>@.&?DN&>FN&?A.&>F`#A
MGH?AGX3AGH+AGH?AGY#AGID`X9Z?X9^*X9Z\X9Z*X9Z$X9^+`.&>F>&?A.&>
ME.&>F^&?BP#AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI_AGH3AGY+AGH'A
MGX'AGI0`X9ZBX9Z`X9^2X9Z?X9Z:XH"+X9Z/X9Z\X9Z%XH"+X9Z;X9Z^`.&>
M@N&>MN&?AN&>D>&?DN&>F@#AGI_AGXKAGKSAGIKAGKCAGH[AGK;AGICAGK@`
MX9Z?X9^2X9Z<X9ZVX9Z;X9^+X9Z4X9ZVX9Z/(.&>D^&>M^&>A"#AGJ#AGY+A
MGI_AGH3AGXOAGICAGXGAGK;AGIGAGX'AGI,`X9Z?X9^2X9Z<X9ZVX9Z@X9^2
MX9Z?X9^*X9ZXX9ZAX9Z$X9^+`.&>G^&?BN&>N^&>F>&>HN&?@N&>B@#AGI3A
MGY+AGH_AGKSAGIKB@(OAGISAGK?AGI+AGKCB@(OAGI_AGK;AGI_AGY+AGH_A
MGY+AGIKB@(OAGH_AGX+AGH0`X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1X9^%XH"+
MXH"+X9Z`X9ZVX9Z:X9Z/X9^"X9Z$XH"+($A434P`X9Z4X9^2X9Z/X9Z\X9Z:
MXH"+X9Z1X9^%XH"+X9Z`X9ZVX9Z:XH"+X9Z/X9^"X9Z$XH"+X9ZBX9Z/X9^2
MX9Z0X9Z4X9Z1XH"+X9Z2X9Z8X9^2X9Z8X9Z/X9ZV`.&>G^&?DN&>G.&?BN&>
MN.&>GP#AGI_AGK;AGI+AGK;AGIKAGH[AGIKAGHKAGY+AGHOB@(OAGJ+AGK;A
MGIKAGXGAGK;AGI3AGXL@X9Z?X9^*X9ZXX9Z:X9ZX`.&>C^&>MN&>FN&>MN&>
MA`#AGIOAGH#AGY+AGH'AGH[AGXCB@(OAGI_AGICAGY+AGI3AGH_AGY+AGH_A
MGK?B@(OAGH_AGK;AGIKAGK;AGH0`X9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z?
MX9Z8X9^2X9Z4X9Z/X9^2X9Z/X9ZWXH"+X9Z:X9Z4X9Z?X9^+XH"+XH"+X9Z/
MX9ZVX9Z:X9ZVX9Z$`.&>C^&?@^&>G.&?B>&>MN&>D^&?BP#AGH_AGK;AGHKA
MGJ#AGY+AGI_AGXKAGKCAGH+AGKCAGI_AGY+AGH_AGH3AGXL`X9Z7X9ZVX9Z:
MX9Z`X9ZWX9Z%X9^2X9Z%`%]8X9ZBX9Z/X9^2X9Z0X9Z4X9Z1(`#AGIOAGX'A
MGH'B@(OAGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI$`X9Z?X9ZXX9Z/X9Z[X9Z.
MX9^2X9Z@X9Z7X9ZVX9Z6`.&>E.&>CN&?DN&>BN&?A.&?A^&>HN&>MN&>G^&>
MD^&?DN&>D\*@X9^6(`#AGI;AGY+AGIKAGICB@(OAGI'AGI'AGKWAGIOB@(OA
MGI_AGX;AGH[AGK[B@(OAGH?AGK;B@(OAGI3AGH[AGY+AGHKAGX3AGX?B@(OA
MGJ+AGK;AGI_AGI/AGY+AGI,`X9Z4X9ZVX9Z3XH"+X9Z1X9Z1X9Z]X9Z;XH"+
MX9Z'X9ZVXH"+X9Z4X9Z.X9^2X9Z/X9^$X9^'XH"+X9ZBX9ZVX9Z?X9Z3X9^2
MX9Z3`.&>K^&>@.&>G^&>MN&>FN*`B^&>F^&>@.&?DN&>@>&>@>&>CN&?DN&>
MC.*`B^&>D^&?@^*`B^&>G^&?@>&>G.&>MB#AGICAGK?AGI/B@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGHGAGY+AGH?AGK;AGH#AGXOB
M@(OAGH#AGY+AGI/AGKOAGH0@8V]N9BYP:'``X9ZBX9Z/X9^2X9Z0X9Z4X9Z1
M`.&>C^&?@N&>HN&>C^&?DN&>D.&>E.&>D0#AGI#AGX,`X9Z6X9ZXPJ#AGY8@
MX9Z'X9Z]X9Z:X9Z(X9Z:XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+
MX9Z"X9Z]X9Z:XH"+X9Z/X9^"XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZV
MX9Z3XH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+PJ#AGY8`X9Z8X9^)X9ZVX9Z?
MX9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^($E-05`@X9Z1X9^&X9Z3X9Z$
MXH"+X9Z'X9ZVXH"+X9Z8X9ZWX9Z3XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:XH"+
MX9Z<X9ZWX9Z2X9ZXX9Z?X9ZVX9Z?X9^2X9Z/X9^2X9Z:XH"+X9Z5X9^2X9Z1
MX9^`X9Z$X9Z5X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZV
MX9Z3XH"+X9Z'X9^2X9Z:X9Z^X9Z?XH"+X9ZAX9Z^X9Z9PJ#AGY0@X9Z?X9Z\
MX9Z8XH"+X9Z1X9ZVX9Z`X9^+X9Z1X9Z$XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z"
MX9^2X9Z:X9Z4X9^+X9Z"X9^2X9Z:X9Z$XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3
MX9^2X9Z2XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY0`X9Z5
MX9^2X9Z3X9^"X9Z`XH"+X9Z2X9Z3X9Z2X9ZVX9Z3XH"+X9Z:X9Z4X9Z?X9^+
M($UA8VEN=&]S:`#AGI7AGY+AGI/AGX+AGH#B@(OAGI+AGI/AGI+AGK;AGI/B
M@(OAGIKAGI3AGI_AGXL@36%C:6YT;W-H(.&>HN&>MN&>A>*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>D>&>MN&>B>&>F>&>@.*`BR`E<\*@
MX9^4`.&>@N&>CN&>D^&>N"`B)7,B(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>F^&>N^&>E,*@X9^4`.&>@N&>CN&>D^&>N"`B)7,B(.&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>FN&>@.&?DN&>G^&>MN*`B^&>
MD>&>N^&>@,*@X9^4`.&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>
ME.&?B^*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>FN&>@.&>@^&>ON&>B<*@X9^4`.&>D>&>M^&>D^&?DN&>D^&>D^&?
MD.&>F>*`B^&>E.&?DN&>FN&>C^&>M^&>D>&>M^&>D^*`B^&>F.&>M^&>D^*`
MB^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>H>&>ON&>F0#A
MGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGK[AGH#B@(OAGI3AGH3AGY+A
MGJ+AGKWAGH7B@(OAGH_AGX+AGH3B@(OAGI3AGK;AGI/B@(OAGI'AGX'"H.&?
ME"#AGI3AGY+AGIKAGJ#AGX+AGIOB@(OAGH?AGK;B@(OAGJ+AGY+AGI/AGH#B
M@(OAGI3AGK;AGI/B@(OAGH#AGX;AGH[AGH_AGXOB@(OAGH#AGICAGY+AGICA
MGISAGK?AGI+AGKCB@(OAGIKAGKOAGH#AGIKAGH#B@(OAGIKAGI3AGI_AGXOB
M@(OAGJ+AGY+AGI/AGH#B@(L@X9ZRX9^2X9Z9XH"+X9Z1X9Z4X9^+XH"+X9Z?
MX9^2X9Z`X9ZVX9Z/X9^+XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%XH"+X9Z;X9^!
MX9Z%XH"+X9ZAX9Z^X9Z$PJ`_`.&>F.&>MN&>C^&>M^&>@.&>MN*`B^&>FN&>
ME.&>G^&?B^*`B^&>K^&>@.&>G^&>MN&>FB!-86-I;G1O<V@@X9Z"X9ZZXH"+
MX9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8PJ#AGY0`X9Z0X9Z/XH"+X9Z4
MX9Z%X9^2X9Z%X9Z[X9Z4X9^2X9Z4X9Z3X9^2X9Z3("(E<R(@X9Z3X9ZYX9Z$
MXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9^2X9Z/X9Z\
MX9Z:XH"+X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z1X9^%XH"+X9Z'X9ZV("(E<R+"
MH.&?E`#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI'AGX7B@(OAGIGAGH#B
M@(OAGI3AGHGAGY+AGH?AGKCB@(OAGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3A
MGI/AGY+AGI/B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#AGI3AGY+A
MGIKAGKX@XH"+X9Z*X9^"X9Z;XH"+X9Z%X9Z\X9Z;XH"+X9Z*X9^&X9Z.X9Z^
MX9Z:X9Z`X9ZVX9Z:XH"+X9Z1X9^%XH"+X9Z0X9Z/XH"+X9Z3X9^!X9^'`.&>
MG^&?@>&>A>&>@.&?DN&>C^&>N.*`B^&>EN&?DN&>FN&>MN&>A.*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>FN&>@.&?DN&>G^&>MN*`B^&>
MD>&>N^&>@.*`B^&>D>&?A>*`B^&>D.&>CR`B)7,BPJ#AGY0`X9Z6X9^2X9Z:
MX9ZYX9Z/X9^2X9Z/X9ZWX9Z`X9ZVX9Z:X9Z.X9^-XH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8XH"+X9Z1X9^%
MXH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z1X9ZWX9Z3XH"+X9Z:X9Z4X9Z?X9^+XH"+
MX9ZBX9^2X9Z3X9Z`PJ#AGY0`X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4
MX9Z3X9^2X9Z;X9ZVX9Z9XH"+X9Z<X9ZVX9Z;("(E<R(@X9Z4X9ZVX9Z3XH"+
MX9ZAX9Z^X9Z9PJ#AGY0`X9Z0X9Z/("(E<R(@X9Z8X9ZVX9Z3XH"+X9Z:X9Z]
MX9Z%XH"+X9Z@X9Z^X9Z9`.&>D.&>CR`B)7,B(.&>F.&>MN&>D^*`B^&>C^&>
MO>*`B^&>HN&>@.&?DN&>G^&>FN*`B^&>@>&>N^&>G^*`B^&>A>&?DN&>E.&>
MMN&>E.&?B^&>@.&?DN&>D^&>N^&>A.*`B^&>B.&?DN&>F.&?A.&?A^*`B^&>
MFN&>E.&>G^&?B^*`B^&>G.&>ML*@X9^4(.&>G.&>MN*`B^&>HN&>MN&>A>*`
MB^&>E.&>A.&?DN&>@.*`B^&>E.&>B>&?DN&>H.&>ML*@X9^4(.&>G^&>O.&>
MF.*`B^&>A^&>O>&>E.*`B^&>A^&>MN&>F.&>O>&>F>*`B^&>HN&?DN&>D^&>
M@.*`B^&>@N&?DN&>FN&>E.&?B^*`B^&>@N&?DN&>FN&>A.*`B^&>E.&?DN&>
MFN&>EN&?D.&>D^&?DN&>DN*`B^&>FN&>E.&>G^&?B^&>HN&?DN&>D^&>@,*@
MX9^4`.&>D.&>CR`B)7,B(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>E.&>A.&?DN&>@.&>ON&>CR#AGI3AGXGAGKOAGI/AGY+AGH_AGX+B@(OA
MGJ+AGY+AGI/AGH#B@(OAGICAGK?AGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGI3AGK;AGI/B@(OAGH?AGK;AGISB@(OAGI3AGY+AGIKAGH7AGK;AGX;B@(OA
MGI'AGX7AGISAGK;"H.&?E`#AGI#AGH\@(B5S(B#AGH_AGY+AGIKAGKSAGISB
M@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI0@X9Z4X9^)X9Z[X9Z3X9^2X9Z/X9^"
MXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z(X9Z4X9^+XH"+X9Z'X9ZVX9Z<XH"+X9Z6X9ZX
MX9Z<X9ZVPJ#AGY0`X9Z8X9ZWX9Z3XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z$X9^2
MX9Z`X9Z^X9Z/XH"+X9Z0X9Z/("(E<R(@X9ZAX9Z^X9Z9XH"+PJ#AGY0@X9Z3
MX9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9ZBX9^2X9Z<X9ZXXH"+X9Z*
MX9^"X9Z;XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:
MX9Z^XH"+X9Z4X9ZVX9Z3X9Z3X9ZWX9Z9X9ZVX9Z9`.&>D.&>CR`B)7,B(.&>
MF.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>F^&>N^&>E.*`B^&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4
M(.&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>
ME.&>MN&>D^*`B^&>D.&>MN*`B^&>HN&>B>&?DN&>A>&>N>&>A`#AGI#AGH\@
M(B5S(B#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGH3AGY+A
MGH#AGK[AGH_B@(OAGHKAGX3AGIGB@(OAGH?AGX3AGH+B@(OAGH?AGY#AGIG"
MH.&?E`#AGI#AGH\@(B5S(B#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGIOAGKOAGI3B@(OAGHKAGX3AGIGB@(OAGH?AGX3AGH+AGH?AGY#AGIG"
MH.&?E`#AGI#AGH\@(B5S(B#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGI3AGY+AGH_AGKSAGIKB@(OAGHCAGY+AGICAGX3AGX?B@(OAGI'AGX7B
M@(OAGH?AGK8@(B5S(B#AGHKAGX3AGIGB@(OAGH?AGX3AGH+B@(OAGH?AGY#A
MGIG"H.&?E`#AGJ_AGH#AGI_AGK;AGIKB@(OAGH'AGK;AGH3B@(OAGH#AGY+A
MGIKAGX3AGICB@(L@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z7
MX9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z'X9ZVX9Z8X9Z]X9Z9XH"+
MX9Z5X9^2X9Z3X9^"X9Z`XH"+X9Z3X9^!X9^'PJ#AGY8`X9Z8X9ZWX9Z3XH"+
MX9ZBX9ZVX9Z%XH"+X9Z4X9Z^X9Z`XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%XH"+
MX9Z:X9Z`X9^2X9Z?X9ZVX9Z1X9Z[X9Z`XH"+X9Z:X9Z\X9Z4X9Z7X9ZVX9Z6
MXH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0@X9Z4X9^2X9Z:X9Z@X9^"
MX9Z;XH"+X9Z'X9ZVXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9ZVX9Z3XH"+X9Z`
MX9^&X9Z.X9Z/X9^+XH"+X9ZRX9^2X9Z9XH"+X9Z`X9Z8X9^2X9Z8X9Z<X9ZW
MX9Z2X9ZXXH"+X9Z:X9Z[X9Z`X9Z:X9Z`XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZB
MX9^2X9Z3X9Z`(.&>D>&>E.&?B^&>G^&?DN&>@.&>MN&>C^&?B^*`B^&>E.&>
MA.&?DN&>HN&>O>&>A>*`B^&>F^&?@>&>A>&>H>&>ON&>A.*`B^&>H.&>ON&>
MF>*`B^&>F.&>ON&>F^*`B^&>D>&?A<*@/P#AGICAGXGAGK;AGI_AGXKAGKCA
MGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB
M@(OAGI3AGK;AGI/B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGI_AGK;AGIKB
M@(OAGH#AGX;AGJ#AGKOAGI_B@(OAGHKAGKSAGH7B@(OAGH'AGK;AGH3B@(OA
MGH#AGY+AGIKAGX3AGIC"H.&?E@#AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OA
MGI3AGICAGY+AGIKAGK[B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI3A
MGK;AGI/B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGI_AGK;AGIKB@(OAGI/A
MGX/AGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGHKAGKSAGH7AGH'AGK;AGH3B
M@(OAGH#AGY+AGIKAGX3AGIC"H.&?E@#AGICAGXGAGK;AGI_AGXKAGKCAGI/B
M@(OAGI3AGICAGY+AGIKAGK[B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OA
MGI3AGK;AGI/B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGI_AGK;AGIKB@(OA
MGHKAGKSAGH7B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGIC"H.&?E@#A
MGI3AGY+AGIKAGJ+AGI3AGXOB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH@)7,@
MX9Z"X9ZZXH"+X9Z1X9Z1X9^!XH"+X9Z:X9Z]X9Z%X9Z@X9Z^X9Z9PJ#AGY0`
MX9Z?X9ZVX9Z:("(E<R(@X9Z6X9ZX("(E<R(@X9Z;X9Z^X9Z?("@E9"#AGI3A
MGX,I(.&>@.&>F.&?DN&>FN&>M^&>C^*`B^&>D>&?AN&>H.&?AN*`B^&>D>&>
MMN&>B>*`B^&>F>&>@.*`B\*@X9^4`.&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`
MB^&>@.&?AN&>EN&>N^&>A.*`B^&>C^&?@N&>A.*`BR#AGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGI3AGK?AGI'"H.&?E"#AGH7AGX'AGHG"H.&?
ME`#AGI_AGK;AGIKB@(OAGICAGK?AGI/B@(OAGICAGK;AGI/B@(OAGI3AGY+A
MGIKAGI+AGK;AGI/AGI3AGI'B@(OAGJ'AGK[AGIG"H.&?E`#AGI_AGK;AGIKB
M@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI3"H.&?
ME`#AGI_AGK;AGIKB@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OA
MGIKAGK;AGIGAGH#AGK;AGIKAGH[AGXWB@(OAGI'AGX7B@(OAGJ+AGY+AGI/A
MGH#B@(OAGH+AGY+AGIKAGI3AGXOAGH+AGY+AGIKAGH3B@(OAGI3AGY+AGIKA
MGI;AGY#AGI/AGY+AGI+B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#B
M@(OAGI#AGK8@X9Z8X9ZWX9Z3XH"+X9Z8X9^"X9Z3XH"+X9Z'X9ZVXH"+X9Z?
MX9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9ZVX9Z:XH"+X9ZA
MX9Z^X9Z9PJ#AGY0`X9Z?X9ZVX9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z:X9ZVX9Z9X9Z`X9ZVX9Z:X9Z.X9^-XH"+X9Z0X9ZV(.&>
MF.&>M^&>D^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>G^&>MN&>FN*`B^&>
MI>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FN*`B^&>H>&>ON&>F<*@X9^4
M`.&>G^&>MN&>FN*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
MFN&>MN&>F>&>@.&>MN&>FN&>CN&?C>*`B^&>D>&?A>*`B^&>HN&?DN&>D^&>
M@.*`B^&>@N&?DN&>FN&>E.&?B^&>@N&?DN&>FN&>A.*`B^&>E.&?DN&>FN&>
MEN&?D.&>D^&?DN&>DN*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`
MB^&>D.&>MB#AGH?AGK;B@(OAGI_AGK;AGIKB@(OAGJ7AGH_B@(OAGI3AGK;A
MGI/B@(OAGH#AGK;AGIK"H.&?E`#AGI_AGK;AGIKB@(OAGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGIKAGK;AGIGAGH#AGK;AGIKAGH[AGXWB@(OA
MGI#AGK8@X9Z'X9ZVXH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3
MXH"+X9Z`X9ZVX9Z:PJ#AGY0`X9Z?X9ZVX9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9^`X9Z$XH"+X9Z5X9^2X9Z1X9ZV
MX9Z/X9^+PJ#AGY0`X9Z?X9ZVX9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z5X9^2X9Z1X9^`X9Z$XH"+X9Z5X9^2X9Z1X9ZVX9Z/X9^+
MPJ#AGY0@X9ZBX9^2X9Z3X9Z`XH"+X9Z5X9^2X9Z)X9Z^PJ#AGY8@)7/"H.&?
ME`#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGK[AGH#B@(OAGI3AGH3A
MGY+AGJ+AGKWAGH7B@(OAGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;A
MGH_AGXO"H.&?E"#AGI3AGY+AGIKAGJ#AGX+AGIOB@(OAGH?AGK;B@(OAGJ+A
MGY+AGI/AGH#B@(OAGI3AGK;AGI/B@(OAGH#AGX;AGH[AGH_AGXOB@(OAGH#A
MGICAGY+AGICAGISAGK?AGI+AGKCB@(OAGIKAGKOAGH#B@(OAGIKAGH#B@(OA
MGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`@X9ZRX9^2X9Z9XH"+X9Z1X9Z4
MX9^+X9Z?X9^2X9Z`X9ZVX9Z/X9^+XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%XH"+
MX9Z;X9^!X9Z%X9ZAX9Z^X9Z$PJ`_`.&>K^&>@.&>G^&>MN&>FN*`B^&>BN&?
M@N&>F^*`B^&>E.&>MN&>D^*`B^&>G^&?DN&>D^&>ON*`B^&>G^&>N^&?AB#A
MGICAGK?AGI/B@(OAGICAGK;AGI/B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGJ_A
MGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXL@35,M5$Y%1L*@X9^4
M`.&>K^&>@.&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>
MG^&?DN&>D^&>ON*`B^&>G^&>N^&?AN*`BR#AGICAGK?AGI/B@(OAGICAGK;A
MGI/B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?A
MGY+AGH?AGK;AGI3AGXL@6FEPPJ#AGY0`X9ZBX9^2X9Z3X9Z`XH"+X9Z5X9^2
MX9Z)X9Z^XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+X9Z`X9^&X9Z6X9Z[
MX9Z$XH"+X9Z?X9^2X9Z3X9Z^XH"+X9Z?X9Z[X9^&XH"+("+AGH#AGK;AGIKB
M@(OAGH?AGKSAGI/B@(OAGHKAGX;AGH[AGKGAGH3B@(OAGH7AGIKAGK?AGH_B
M@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIHB(.&>EN&>N.*`B^&>HN&?DN&>
MD^&>@"#AGI;AGX'AGIOAGJ+AGY+AGI/AGH#B@(OAGI3AGK;AGI/B@(OAGJ+A
MGK;AGI/B@(OAGI_AGK;AGIKAGI/AGX'AGX?"H.&?E"#AGI_AGKSAGICB@(OA
MGH7AGKOAGH4@)7,@X9Z*X9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z5X9^2X9Z)X9Z^
MXH"+X9Z?X9ZVX9Z:XH"+X9Z'X9Z\X9Z3XH"+X9Z*X9^&X9Z.X9ZYX9Z$PJ#A
MGY0`X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+
MX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+
MX9Z:X9Z\X9Z4X9Z7X9ZVX9Z6XH"+X9Z/X9Z\X9Z%X9^7XH"+X9Z3X9^#XH"+
MX9Z:X9Z\X9Z4X9Z7X9ZVX9Z6XH"+X9Z3X9^!X9^'XH"+X9Z4X9ZVX9Z3XH"+
MX9ZAX9Z^X9Z9PJ#AGY0`X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZVXH"+X9Z8
MX9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZV
MX9Z3XH"+X9Z'X9^&X9Z3X9Z]X9Z?PJ#AGY0`X9Z@X9Z/X9^2X9Z0X9Z;X9^!
MX9Z!X9ZVXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z'X9^&
MX9Z3X9Z]X9Z?XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"X9Z'X9^0X9Z9PJ#A
MGY0`X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+
MX9Z4X9Z)X9^2X9Z'X9ZVX9Z`X9^+XH"+X9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3
MXH"+X9ZAX9Z^X9Z9PJ#AGY0`X9Z5X9^2X9Z1X9^#XH"+X9Z!X9ZVX9Z$XH"+
MX9Z`X9^2X9Z:X9^$X9Z9XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:("(E<R(@
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z3X9^2X9Z0X9^"
MX9Z8PJ#AGY0`X9Z5X9^2X9Z1X9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:
MX9^$X9Z9XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:("(E<R(@X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4PJ#AGY0`X9Z5X9^2X9Z1
MX9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9XH"+X9Z?X9^&X9Z4
MX9Z[X9Z/X9^2X9Z:("(E<R(@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3
MXH"+X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z1X9ZVX9Z3X9^+X9Z?
MX9Z8X9^0X9Z9PJ#AGY0`X9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%XH"+X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8
MXH"+X9Z1X9^%XH"+X9Z4X9Z)X9^2X9Z'X9ZXXH"+X9Z7X9ZVX9Z:X9Z`X9ZW
MX9Z%X9^2X9Z%XH"+X9Z:X9Z4X9Z?X9^+X9ZBX9^2X9Z3X9Z`PJ#AGY0`X9ZB
MX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:`.&>
MHN&>C^&?DN&>D.&>E.&>D>*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>FN*`
MB^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
MF.&>ON&>FR`E<\*@X9^4`.&>HN&>C^&?DN&>D.&>E.&>D>*`B^&>FN&>E.&>
MG^&?B^*`B^&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>
MC^&?DN&>FN&>H>&>E.&?BP#AGJ+AGH_AGY+AGI#AGI3AGI'B@(OAGIKAGI3A
MGI_AGXOB@(OAGI_AGK;AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OA
MGH_AGY+AGIKAGJ'AGI3AGXL@X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z8X9Z^X9Z;XH"+("5SPJ#AGY0`X9ZBX9Z/X9^2
MX9Z0X9Z4X9Z1XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z*X9^"
MX9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z)X9Z^`.&>HN&>C^&?DN&>D.&>
ME.&>D>*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`
MB^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>OB#AGJ+AGK;AGH7B@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGICAGK[AGIOB@(L@)7/"H.&?E`#A
MGI;AGY#AGH_AGXSAGICAGK;AGI/B@(L@X9Z1X9^&X9Z3X9^!X9Z:+^&>FN&>
MG.&>F^&?B^*`BR#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGI3A
MGY+AGIKAGKX@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z:X9Z`
MX9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"
MX9Z'X9^0X9Z9PJ#AGY0`X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z5X9^2X9Z3X9^"
MX9Z`XH"+X9Z5X9^2X9Z?X9^!X9Z$XH"+X9Z*X9^"X9Z;XH"+X9ZBX9ZVX9Z%
MXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z$X9^2X9Z@
MX9ZVX9Z)XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z/X9Z]PJ#AGY0`X9Z"X9^2
MX9Z8X9ZVX9Z3XH"+X9Z?X9ZVX9Z:XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z4
MX9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z3
MX9^!X9^'PJ#AGY0`X9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9ZBX9Z/X9^2
MX9Z0X9Z4X9Z1(.&>BN&?@N&>F^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>@.&?
MDN&>D^&>N^&>A.*`B^&>C^&>O>*`B^&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@
MX9^4`.&>F.&>MN&>D^*`B^&>E.&>B>&?DN&>H.&>MN*`B^&>@.&?DN&>D^&>
MN^&>A.*`B^&>@.&>MN&>FN*`B^&>E.&?AN&>E.&>MN&>C^&?B^*`B^&>A>&?
MA.&>F^*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?
MDN&>FL*@X9^4(.&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>
MFN&>ON*`B^&>E.&>MN&>D^*`B^&>D^&>M^&>F>&>MN&>F>&>D.&>ML*@X9^6
M("5S`.&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>N^&>G^*`B^&>F.&>O>&>F2#A
MGH#AGY+AGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OAGH7AGICAGY+AGIOAGH3B
M@(OAGI_AGK;AGIKB@(OAGI;AGK@@(B5S(B#AGI'AGX4@(B5S(L*@X9^4(.&>
MD^&?@>&?A^*`B^&>@N&>NN*`B^&>A^&>MN*`B^&>HN&?DN&>G.&>N.*`B^&>
MBN&?@N&>F^*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>
MFN&>ON*`B^&>E.&>MN&>D^*`B^&>D^&>M^&>F>&>MN&>F0#AGICAGK;AGI/B
M@(OAGH#AGX;AGJ#AGKOAGI_B@(OAGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$
MXH"+X9Z`X9ZVX9Z:XH"+X9Z;X9Z[X9Z4XH"+X9Z?X9ZVX9Z:XH"+X9Z6X9ZX
MX9Z0X9Z/("(E<R+"H.&?E"#AGI/AGX'AGX?B@(OAGH+AGKKB@(OAGH?AGK;B
M@(OAGJ+AGY+AGISAGKCB@(OAGHKAGX+AGIOB@(OAGICAGXGAGK;AGI_AGXKA
MGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI3AGK;AGI/B@(OAGI/AGK?A
MGIGAGK;AGID`X9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z8X9Z]
MX9Z9(.&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>F^&>N^&>E.*`
MB^&>G^&>MN&>FN*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>D.&>CR`B)7,BPJ#A
MGY0@X9Z3X9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9ZBX9^2X9Z<X9ZX
MXH"+X9Z*X9^"X9Z;XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8
MX9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+X9Z3X9ZWX9Z9X9ZVX9Z9`.&>F.&>
MMN&>D^*`B^&>@.&?AN&>H.&>N^&>G^*`B^&>F.&>O>&>F2#AGH#AGY+AGI/A
MGKOAGH3B@(OAGH#AGK;AGIKB@(OAGIOAGKOAGI3B@(OAGI;AGY+AGIKAGKGA
MGH_AGY+AGH_AGK?AGH#AGK;AGIKAGH[AGXW"H.&?EB`E<\*@X9^4`.&>F.&>
MMN&>D^*`B^&>@.&?AN&>H.&>N^&>G^*`B^&>F.&>O>&>F2#AGH#AGY+AGI/A
MGKOAGH3B@(OAGH#AGK;AGIKB@(OAGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI7A
MGY+AGI/AGX+AGH#B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OAGI/A
MGX'AGX<`X9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z8X9Z]X9Z9
M(.&>@.&?DN&>D^&>N^&>A.&>@.&>MN&>FN*`B^&>BN&>MN&>@.&?B^&>D>&>
MA.&?B^*`B^&>LN&?DN&>F>*`B^&>G^&>MN&>FN*`B^&>@.&?DN&>D^&>N^&>
MA.*`B^&>D.&>CR`B)7,BPJ#AGY0@X9Z3X9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'
MX9ZVXH"+X9ZBX9^2X9Z<X9ZXXH"+X9Z*X9^"X9Z;XH"+X9Z8X9^)X9ZVX9Z?
MX9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+X9Z3
MX9ZWX9Z9X9ZVX9Z9`.&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>N^&>G^*`B^&>
MF.&>O>&>F2#AGH#AGY+AGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OAGI/AGK;A
MGX;AGH7AGKSAGIL@)7/"H.&?E`#AGICAGK;AGI/B@(OAGH#AGX;AGJ#AGKOA
MGI_AGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z3
MX9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z6X9^2X9Z:X9ZYX9Z/X9^2X9Z/X9ZWX9Z`
MX9ZVX9Z:X9Z.X9^-PJ#AGY8@)7/"H.&?E`#AGICAGK;AGI/B@(OAGH#AGX;A
MGJ#AGKOAGI_B@(OAGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZV
MX9Z:XH"+XH"+XH"+X9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z7X9ZVX9Z:X9Z`
MX9ZWX9Z%X9^2X9Z%PJ#AGY8@)7/"H.&?E`#AGICAGK;AGI/B@(OAGH#AGX;A
MGJ#AGKOAGI_B@(OAGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZV
MX9Z:XH"+X9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZV
MX9Z3(.&>D>&?AN&>D^&?@>&>FB_AGIKAGISAGIOAGXL@X9Z:X9Z4X9Z?X9^+
MXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^PJ#AGY8@)7/"H.&?E`#A
MGICAGK;AGI/B@(OAGH#AGX;AGJ#AGKOAGI_B@(OAGICAGKWAGID@X9Z`X9^2
MX9Z3X9Z[X9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+
MX9Z1X9ZXXH"+X9Z?X9ZVX9Z:XH"+X9Z6X9ZX("(E<R(@X9Z1X9^%("(E<R+"
MH.&?E"#AGI/AGX'AGX?B@(OAGH+AGKKB@(OAGH?AGK;B@(OAGJ+AGY+AGISA
MGKCB@(OAGHKAGX+AGIOB@(OAGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3A
MGICAGY+AGIKAGK[B@(OAGI3AGK;AGI/B@(OAGI/AGK?AGIGAGK;AGID`X9Z8
MX9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z8X9Z]X9Z9(.&>@.&?DN&>
MD^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>E>&?DN&>B>&>ON*`B^&>G^&>MN&>
MFN&>FN&>E.&>G^&?B^&>HN&?DN&>D^&>@,*@X9^6("5S`.&>F.&>MN&>D^*`
MB^&>@.&?AN&>H.&>N^&>G^*`B^&>F.&>O>&>F2#AGH#AGY+AGI/AGKOAGH3B
M@(OAGH#AGK;AGIKB@(OAGI+AGY+AGISAGK[B@(OB@(OAGK+AGY+AGIGB@(OB
M@(OAGI;AGY+AGIKAGKGAGH_AGY+AGH_AGK?AGH#AGK;AGIKAGH[AGXWB@(OA
MGI'AGK;AGI/AGXOB@(OAGI_AGICAGY#AGIG"H.&?EB`E<\*@X9^4`.&>F.&>
MM^&>D^*`B^&>F.&>MN&>D^*`B^&>HN&>C^&?DN&>D.&>E.&>D2#AGH#AGY+A
MGI/AGKOAGH3B@(OAGI7AGY+AGI/AGX+AGH#B@(OAGI/AGX/B@(OB@(OAGI_A
MGK;AGIKB@(OAGI/AGX'AGX<`X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2
MX9ZVX9Z:X9Z.X9^((%!'4"#AGI/AGX'AGX?B@(L@X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z1X9^%XH"+
MX9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'PJ#AGY0`X9Z8X9ZWX9Z3XH"+X9Z"X9ZV
MX9^&X9Z1X9^2X9Z:XH"+X9ZBX9^&X9Z6X9Z^XH"+X9Z3X9^!X9^'PJ#AGY0`
MX9ZBX9^&X9Z6X9Z^XH"+X9Z3X9^!X9^'XH"+X9Z8X9ZWX9Z3XH"+X9Z1X9ZV
MX9Z3X9^+XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9ZBX9Z3
MX9Z[X9Z<X9Z/X9^2X9Z/XH"+X9ZAX9Z^X9Z9PJ#AGY0`X9Z3X9^!X9^'XH"+
MX9Z4X9^2X9Z:X9Z@X9^"X9Z;XH"+X9Z'X9ZVXH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z`X9ZVX9Z:XH"+X9Z6X9^!X9Z;XH"+X9Z4X9Z3X9^2X9Z/X9ZWX9Z%
MXH"+X9Z4X9Z3X9^2X9Z/X9Z]X9Z%PJ#AGY0@X9Z/X9Z^XH"+X9ZBX9^2X9Z3
MX9Z`XH"+X9Z6X9ZWX9Z/XH"+X9Z'X9ZVXH"+X9Z%X9Z$X9^+XH"+X9Z4X9Z3
MX9^2X9Z/XH"+X9ZLPJ`_`.&>G^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>F.&>
MMN&>D^*`B^&>E>&?DN&>D>&>N^&>@.*`B^&>K^&>@.&>G^&>MN&>FB!-86-I
M;G1O<V@@X9Z8X9Z]X9Z9PJ#AGY0`X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+
MX9Z8X9ZVX9Z3XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4
MX9^+(.&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>A>&>N^&?A^*`B^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>C.&>
MN.&>A^&>N.&>D.&>F^*`B^&>C^&>MN&>F.*`B^&>FN&>F>&?B"!3+TU)347"
MH.&?E`#AGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OAGICAGK;AGI/B@(OAGJ_A
MGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXL@X9Z*X9^"X9Z;XH"+
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z8X9^2X9Z;X9^"
MX9Z$XH"+X9Z'X9ZVXH"+X9Z`X9Z\X9Z*XH"+X9Z/X9ZVX9Z8XH"+X9Z:X9Z9
MX9^((%,O34E-1<*@X9^4`.&>G^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>F.&>
MMN&>D^*`B^&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>G^&?DN&>D.&>MN&>
MD^&>E^&>MN&>EN*`B^&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>G^&?AN&>E.&>
MN^&>C^&?DN&>FB#AGI3AGXGAGKOAGI/AGY+AGH_AGX+B@(OAGI'AGY+AGIKA
MGH3AGXOB@(OAGI'AGY+AGIKAGK;AGIGB@(OAGIKAGI3AGI_AGXOB@(OAGI_A
MGK;AGIKB@(OAGI/AGX'AGX<@X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9ZAX9Z^X9Z9
MPJ#AGY0`X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+X9Z8X9ZWX9Z3XH"+X9Z1
MX9^&X9Z3X9Z$XH"+X9Z'X9ZVXH"+X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+
MX9Z4X9ZVX9Z3XH"+X9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z'X9ZVXH"+X9Z`
MX9Z\X9Z*(%!'4"#AGH_AGY+AGIKAGKGAGICB@(OAGH_AGY+AGIKAGKSAGISB
M@(OAGICAGKWAGIGB@(OAGJ'AGK[AGIG"H.&?E"#AGH#AGX;AGJ#AGKOAGI_"
MH.&?E@#AGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OAGICAGK?AGI/B@(OAGI'A
MGX;AGI/AGH3B@(OAGH?AGK;B@(OAGICAGK;AGI/B@(OAGI'AGY+AGIKAGH3A
MGXOB@(OAGI'AGY+AGIKAGK;AGID@4$=0(.&>C^&?DN&>FN&>N>&>F.&>C^&?
MDN&>FN&>O.&>G"`HX9Z9X9^$X9Z$XH"+X9Z/X9ZVX9Z8(%)&0R`R,#$U*<*@
MX9^4`.&>G^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>F.&>M^&>D^*`B^&>D>&?
MAN&>D^&>A.*`B^&>A^&>MN*`B^&>F.&>MN&>D^*`B^&>D>&?DN&>FN&>A.&?
MB^*`B^&>D>&?DN&>FN&>MN&>F2!3+TU)344@X9Z/X9^2X9Z:X9ZYX9Z8X9Z/
MX9^2X9Z:X9Z\X9Z<PJ#AGY0`X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z%X9Z[X9^'XH"+X9Z@X9Z/
MX9^2X9Z0X9Z;X9^!X9Z!X9ZVXH"+X9Z,X9ZXX9Z'X9ZXX9Z0X9Z;(.&>D^&>
MM^&>A"#AGI3AGICAGY+AGIOAGX+AGH3B@(OAGH?AGK;B@(OAGH#AGKSAGHKB
M@(OAGHKAGX3AGIGB@(OAGI3AGY+AGIKAGKX@4$=0(.&>E.&?B>&>N^&>D^&?
MDN&>C^&?@N*`B^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>F.&>M^&>
MD^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>E>&?DN&>D>&?@.&>A.&>E>&?DN&>D>&>MN&>C^&?B^*`B^&>E.&>MN&>
MD^*`B^&>H>&>ON&>F<*@X9^4`.&>G^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>
MC^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>A>&>N^&?A^*`B^&>H.&>
MC^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>C.&>N.&>A^&>N.&>D.&>FR#AGI/A
MGK?AGH0@X9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z'X9ZVXH"+X9Z`X9Z\X9Z*
MXH"+X9Z*X9^$X9Z9XH"+X9Z4X9^2X9Z:X9Z^(%!'4,*@X9^4`.&>G^&>MN&>
MFN*`B^&>D^&?@>&?A^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>A>&>N^&?A^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>C.&>N.&>
MA^&>N.&>D.&>F^*`B^&>C^&>MN&>F.*`B^&>FN&>F>&?B"!01U`@X9Z4X9^)
MX9Z[X9Z3X9^2X9Z/X9^"XH"+X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZVXH"+
MX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z5X9^2X9Z1X9^`X9Z$X9Z5X9^2X9Z1X9ZVX9Z/X9^+XH"+
MX9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0`X9Z?X9ZVX9Z:XH"+X9Z3X9^!
MX9^'XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z%X9Z[X9^'
MXH"+X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZVXH"+X9Z'X9ZVXH"+X9Z;X9^!
MX9Z!XH"+X9Z/X9ZVX9Z8X9Z:X9Z9X9^((%!'4,*@X9^4`.&>G^&>MN&>FN*`
MB^&>D^&?@>&?A^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
MA>&>N^&?A^*`B^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>C.&>N.&>
MA^&>N.&>D.&>F^*`B^&>C^&>MN&>F.&>FN&>F>&?B"!3+TU)347"H.&?E`#A
MGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGI3AGICAGY+AGIOAGX+AGH3B@(OAGH?AGK;B@(OAGH#AGKSA
MGHKB@(OAGH_AGK;AGICAGIKAGIGAGX@@4R]-24U%PJ#AGY0`X9Z?X9ZVX9Z:
MXH"+X9Z3X9^!X9^'XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z'X9ZVXH"+X9Z`X9Z\X9Z*XH"+X9Z*
MX9^$X9Z9XH"+X9Z4X9^2X9Z:X9Z^(%!'4"#AGI'AGX3AGX?B@(OAGIGAGXGA
MGK;AGH3B@(OAGH[AGK8@X9Z`X9ZVX9Z:XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:
M(%!'4"#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISA
MGK[B@(OAGK+AGY+AGIGB@(OAGI3AGY+AGIKAGK[B@(OAGIOAGX+AGH3B@(OA
MGI3AGK;AGI,@X9Z*X9Z\X9Z%X9^2X9Z3X9^!X9^'XH"+X9Z?X9ZVX9Z:XH"+
MX9Z3X9ZYX9Z$XH"+X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z8
MX9Z`XH"+X9Z'X9ZVXH"+X9Z7X9ZVX9Z6XH"+X9Z2X9Z8X9^2X9Z8X9Z/X9ZV
MXH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0`X9Z?X9ZVX9Z:XH"+X9Z3
MX9^!X9^'XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z8
MX9^2X9Z;X9^"X9Z$XH"+X9Z'X9ZVXH"+X9Z`X9Z\X9Z*XH"+X9Z*X9^$X9Z9
MXH"+X9Z4X9^2X9Z:X9Z^(%!'4"#AGI'AGX3AGX?B@(OAGIGAGXGAGK;AGH3B
M@(OAGH[AGK8@X9Z8X9ZWX9Z3XH"+X9Z1X9ZVX9Z3X9^+XH"+X9Z8X9ZVX9Z3
MXH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZOX9Z`X9Z'X9Z3XH"+X9Z5X9^2X9Z1
MX9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3XH"+X9Z3X9^%XH"+X9ZAX9Z^
MX9Z9XH"+X9Z1X9^!(.&>BN&>O.&>A>&?DN&>D^&?@>&?A^*`B^&>G^&>MN&>
MFN*`B^&>D^&>N>&>A.*`B^&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>F.&?DN&>F^&?@N&>A.*`
MB^&>F.&>@.*`B^&>A^&>MN*`B^&>E^&>MN&>EN*`B^&>DN&>F.&?DN&>F.&>
MC^&>MN*`B^&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4`.&>G^&>MN&>FN*`
MB^&>D^&?@>&?A^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
ME.&>F.&?DN&>F^&?@N&>A.*`B^&>A^&>MN*`B^&>@.&>O.&>BN*`B^&>BN&?
MA.&>F2!01U#"H.&?E`#AGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OAGI'AGX4`
MX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z3
MX9^!X9^'XH"+X9Z8X9ZWX9Z3XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:XH"+X9Z0
MX9Z/XH"+X9Z*X9^"X9Z;XH"+X9Z%X9^"X9Z`XH"+X9Z:X9^&X9Z;X9^"X9Z`
MPJ#AGY0`X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+X9Z@X9^%XH"+X9Z4
MX9Z$X9^2X9ZBX9Z]X9Z%XH"+X9Z3X9^!X9^'(.&>EN&>N.*`B^&>E.&>A.&?
MDN&>HN&>O>&>A>*`B^&>C^&?@N&>A.*`B^&>F.&>O>&>F<*@X9^4`.&>E.&>
MA.&?DN&>H.&>MN&>B>*`B^&>A^&>MN*`B^&>@>&?DN&>G^&?@N*`B^&>G^&?
MDN&>FN&>H>&>MN&>F0#AGI'AGK?AGHKAGY+AGHOAGI?AGK;AGI;B@(OAGH'A
MGY+AGI_AGX+AGJ+AGX;AGI3AGX3AGX<`X9Z6X9^!X9Z;XH"+X9Z<X9^!X9Z;
MX9ZVXH"+`.&>D>&?DN&>FN&>A.&?B^*`B^&>D>&?DN&>FN&>MN&>F>*`B^*`
MB^*`B^*`B^&>EN&?@>&>F^*`B^*`B^&>G.&?@>&>F^&>MN*`BP#AGH7AGX;A
MGH[AGH3B@(OAGH?AGK[AGH0`X9Z1X9^%`.&>D>&?A>*`B^&>HN&>MN&>G^&>
MF>&>BN&?DN&>B^&>MN&>DP#AGH?AGY+AGIKAGK[AGI_B@(OAGH#AGY+AGIKA
MGJ'AGK;B@(OAGI'AGI'AGKGAGH3B@(OAGH7AGY+AGIKAGK[AGI,@X9Z?X9Z$
MX9^2X9Z`X9Z/X9^+XH"+X9Z4X9Z)X9^2X9Z'X9ZV("A00RD@X9ZL(.&>E.&>
MB>&?DN&>A^&>MB`H36%C*2#AGH'AGH[AGXCAGI;AGX'AGIOB@(OAGH#AGX;A
MGI;AGKOAGH3B@(OAGH7AGKOAGH7"H.&?E`#AGHKAGK[AGICAGY+AGI3AGKCB
M@(OAGI3AGY+AGIKAGK[B@(OAGH#AGK;AGIKB@(OAGH_AGI?AGY+AGH?AGK;A
MGI3AGXL@5$Q3(.&>HN&?DN&>D^&>@.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>
MC^&?@N*`B^&>@.&?AN&>EN&>N^&>A.*`B^&>FN&>C^&?BR!02%`@X9Z`X9^&
MX9Z.X9^"(#4N,"XV(.&>K"#AGH'AGY+AGI;AGI_AGXOB@(OAGH?AGK;AGH3"
MH.&?E`#AGI#AGY+AGH3AGX/B@(OAGI/AGX'AGX<`X9Z/X9Z\X9Z@X9^2X9Z"
MX9^$`.&>C^&>O.&>@.&?@>&>H>&>MN&>HN&?BN&>O`#AGH_AGKOAGH3AGJ#A
MGY+AGH+AGX0`X9Z`X9^&X9Z6X9Z\X9Z;`.&>D>&?AN&>H.&?AN*`B^&>K^&>
M@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>G^&>FN&>N^&>
ME,*@X9^6`.&>D.&>C^*`B^&>G^&?AN&>FN&>MN&>F`#AGI#AGH_B@(OAGI_A
MGX;AGIKAGK;AGIC"H.&?E@#AGI'AGY+AGIKAGKCAGI/AGKCAGHKAGK;AGHH@
MX9Z3X9ZWX9Z$XH"+XH"+(.&>C^&>O.&>E.&>MN&>H.&?DN&>@N&?A`#AGI'A
MGKOAGIGAGH[AGX'AGI_AGXKAGK@`X9Z1X9Z]X9Z:X9Z"X9ZX`.&>D>&>O>&>
MFN&>@N&>N"`H25-/+3@X-3DM.2D`X9Z1X9Z]X9Z"X9Z8X9^!X9Z3X9ZXX9Z?
MX9^2X9Z/X9Z$X9^+`.&>@.&?A.&?A^*`B^&>D>&>O>&>@"#AGI/AGK?AGH3B
M@(L@X9Z`X9^#X9Z`X9Z\X9Z?`.&>D>&>N^&>F>&>G.&?B>&>MN&>F^&>N^&>
MF0!54DP`55),.@#AGJ+AGXKAGKSAGJ#AGY+AGH+AGH3AGXOAGHKAGK8`X9ZB
MX9^*X9Z[X9Z9X9Z`X9^2X9Z:X9^"X9Z3`.&>F.&>M^&>D^*`B^&>HN&>MN&>
MA>*`B^&>D>&?A>*`B^&>F>&>@.*`B^&>@.&>O.&>C^&>M@#AGICAGK?AGI/B
M@(OAGI3AGK;AGI/B@(OAGH;AGY+AGIOAGK[AGIGB@(OAGH_AGI0`X9Z?X9ZV
MX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z8X9ZWX9Z3XH"+X9Z4X9ZVX9Z3XH"+X9Z&
MX9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4`.&>F.&>M^&>D^*`B^&>F^&>N^&>E`#A
MGI_AGK;AGIKB@(OAGICAGK?AGI/B@(OAGI'AGK;AGI/AGXOB@(OAGIOAGKOA
MGI0`X9Z"X9Z\X9Z?XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z`X9^2
MX9Z:X9^$X9Z8`.&>F.&>M^&>D^*`B^&>E.&>MN&>D^&>E.&?DN&>FN&>@.&>
MMN&>G^*`B^*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>FP#AGICAGK?A
MGI/B@(OAGI3AGK;AGI/B@(OAGIKAGX#AGI3AGH7AGX8`X9Z?X9Z8X9ZVX9Z?
MX9Z7X9ZVX9Z"XH"+X9Z*X9^"X9Z;XH"+X9Z8X9ZWX9Z3XH"+X9Z4X9ZVX9Z3
MXH"+X9Z*X9^$X9^'XH"+X9Z?X9^2X9Z:X9ZVX9Z9XH"+X9Z3X9^#XH"+X9Z4
MX9^2X9Z:X9Z7X9^!X9Z1PJ#AGY8@)7,`X9Z9X9Z\X9Z3X9ZXX9Z`X9Z\X9Z*
M("A55$8M."D`X9Z?X9ZVX9Z:XH"+X9Z8X9ZWX9Z3XH"+X9Z?X9^&X9Z!X9ZV
MX9Z3X9^+`.&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>FN&>O>&>F`#AGH7A
MGH#AGY+AGIKB@(OAGI?AGI;B@(OAGJ+AGH3AGXOAGH+AGY+AGIOAGX'AGI\`
MX9Z?X9Z@X9Z:X9Z*X9^2X9Z+X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z``.&>@.&?
MA.&?A^*`B^&>AN&?DN&>A.&>MN&>F>&?E^*`B^&>FN&>E.&>G^&?B^*`B^&>
MG^&>H.&>FN&>BN&?DN&>B^*`B^&>HN&>MN&>F.&?@>&>FN&>M^&>@`#AGJ_A
MGH#AGH_AGK8`X9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+`.&>@.&>
MMN&>F^*`B^&>E.&>FN&>M^&>A>&?DN&>AN&?@>&>D>*`B^&>BN&?@N&>F^*`
MB^&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?BP#AGICAGK?AGI/B@(OA
MGI_AGY+AGH+AGK;AGIOAGXOB@(OAGH7AGICAGY+AGIOAGK[AGID@24U!4"#A
MGI;AGKCB@(OAGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKA
MGK["H.&?E"#AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKA
MGK[B@(OAGI3AGK;AGI/B@(OAGH;AGY+AGIOAGK[AGIGAGH_AGI3B@(OAGI#A
MGK;"H.&?EB`E<P#AGH#AGK?AGH7AGY+AGH7B@(OAGI3AGY+AGIKAGH?AGKOA
MGX;B@(OAGHKAGX+AGIOB@(OAGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOA
MGXL`X9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;XH"+X9Z*X9^"X9Z;XH"+
MX9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+`.&>FN&>ON*`B^&>@^&?
MDN&>F^&>MN*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>A>&?@>&>B0#A
MGH+AGY+AGICAGK;AGI/B@(OAGHCAGY+AGICAGX3AGX<`X9Z8X9ZWX9Z3XH"+
MXH"+X9Z4X9ZVX9Z3XH"+X9Z8X9Z^X9Z;`.&>B.&>E.&?B^*`B^&>A^&>MN&>
MG.*`B^&>EN&>N.*`B^&>D.&>CP#AGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB
M@(OAGI'AGK;AGI/AGXOAGI_AGICAGY#AGID`X9Z2X9^2X9Z<X9Z^XH"+X9ZR
MX9^2X9Z9XH"+X9Z?X9^2X9Z0X9ZVX9Z3X9Z7X9ZVX9Z6XH"+X9Z&X9^2X9Z;
MX9Z^X9Z9XH"+X9Z/X9Z4XH"+X9Z1X9ZVX9Z3X9^+X9Z?X9Z8X9^0X9Z9`.&>
ME>&?DN&>D>&>N^&>@.*`B^&>H>&>ON&>A`#AGI7AGY+AGI'AGKOAGH#B@(OA
MGJ'AGK[AGH3"H.&?E@#AGJ+AGXKAGKOAGIGAGIKAGXGAGK;AGJ#AGY+AGH+A
MGK;AGID`X9Z4X9^2X9Z:X9Z^XH"+X9Z/X9Z8X9^2X9Z;X9^#XH"+X9Z;X9^&
MX9Z3X9ZVX9^&X9Z*X9Z^X9Z8`.&>E.&?DN&>FN&>ON*`B^&>@.&>MN&>FN*`
MB^&>A^&>MN&>G.*`B^&>D.&>CR!)34%0(.&>K,*@/P#AGI3AGY+AGIKAGKX@
MX9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8XH"+X9Z3X9ZWX9Z8X9^2X9Z8X9ZW
MX9Z/PJ`_`.&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>O@#AGJ+AGY+AGI/A
MGH#B@(OAGI3AGY+AGIKAGKX@(B5S(B#AGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGI7AGY+AGHKAGIOAGXOB@(OAGI_AGK?AGI'AGY+AGI+AGK?B
M@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI3AGHGAGY+AGH?AGK;AGH#A
MGXOB@(OAGIOAGICAGY+AGJ+AGK?AGH_B@(OAGHKAGX3AGIGB@(OAGH?AGX3A
MGH+AGH?AGY#AGIGB@(OAGJ#AGK[AGID@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+
MXH"+X9Z0X9Z/("(E<R+"H.&?E`#AGH#AGK;AGIKB@(OAGH+AGY+AGIKAGI3A
MGXOAGH+AGY+AGIKAGH3B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKX`
MX9Z(X9^2X9Z8X9^$X9^'XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^
M`.&>B.&?DN&>F.&?A.&?A^*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>
MOL*@X9^6`.&>HN&?BN&>O.&>H.&?DN&>G^&>E.&?@>&>@N&>N.&>G^&?DN&>
MC^&>A.&?BP#AGI_AGKOAGI;AGIOAGI?AGK;AGI8`X9Z/X9Z8X9^2X9Z;X9^#
M`.&>G.&?B>&>MN&>D^&>N^&>F>&>HN&>MN&>D>&>N^&>F0#AGJ+AGI#AGX'A
MGIH`X9Z<X9^!X9Z.X9^!X9Z@X9^2X9Z?X9Z[X9Z9X9ZBX9^!X9ZAX9ZV`.&>
M@.&?AN&>CN&?@@#AGH#AGK;AGIKB@(OAGH_AGY+AGIKAGKWAGH_B@(OAGI;A
MGK?AGI/AGK?AGH_AGY+AGIGB@(OAGH#AGX;AGH[AGX(`X9Z8X9Z^X9Z;`.&>
MF.&>ON&>FR`E<P#AGICAGK[AGIOB@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI_A
MGK;AGI+AGK;AGIKAGH[AGX@@)7,`X9Z8X9Z^X9Z;XH"+X9Z?X9ZVX9Z:`.&>
MF.&>ON&>F^*`B^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>K^&>@.&>A^&>D^*`
MB^&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DP#AGICAGK[A
MGIOB@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGXCB
M@(OAGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI,`X9Z8X9Z^
MX9Z;XH"+X9Z!X9^2X9Z?X9^"XH"+X9ZBX9^&X9Z4X9^$X9^'`.&>F.&>ON&>
MF^*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>C^&>O.&>A0#AGICAGK[AGIOB
M@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXL@XH"+XH"+
MX9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%XH"+X9Z*X9ZV
MX9Z%X9^+XH"+X9Z*X9^$X9Z9XH"+X9ZAX9^"X9Z``.&>F.&>ON&>F^*`B^&>
MF.&>MN&>C^&>M^&>@.&>MN*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>E.&>A.&?
MDN&>HN&>O>&>A>*`B^&>E>&?DN&>G^&?@>&>A`#AGICAGK[AGIOB@(OAGI;A
MGY+AGIKAGKGAGH_AGY+AGH_AGK?AGH#AGK;AGIKAGH[AGXT`X9Z8X9Z^X9Z;
MXH"+X9Z?X9ZVX9Z:XH"+X9Z`X9^2X9Z3X9Z[X9Z$("5S`.&>D>&>M^&>BN&?
MDN&>B^&>E^&>MN&>EB#AGJP@X9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+(.&>E.&>D^&?DN&>D>&>MN&>E.&?
MB^*`B^&>EN&>N.*`B^&>A>&>O.&>F\*@X9^6`.&>F.&>ON&>F^*`B^&>E^&>
MMN&>FN&>@.&>M^&>A>&?DN&>A0#AGICAGK[AGIOB@(OAGICAGK;AGH_AGK?A
MGH#AGK8@2%1-3"#AGI/AGX'AGX?B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI3A
MGH3AGY+AGJ+AGKWAGH7B@(OAGI7AGY+AGI_AGX'AGH3"H.&?E`#AGH#AGX3A
MGX?B@(OAGISAGKCAGH?AGKCAGI,@X9Z?X9Z@X9Z:X9Z*X9^2X9Z+XH"+X9ZB
MX9ZVX9Z8X9^!X9Z:X9ZWX9Z``.&>D.&>C^*`B^&>D^&>M^&>F.&>M^&?DN&>
MF.&>CR`B)7,B(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>
MA.&?DN&>@.&>ON&>C^*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>@N*`B^&>A^&?
MD.&>F<*@X9^4`.&>D.&>C^*`B^&>D^&>M^&>F.&>M^&?DN&>F.&>CP#AGI#A
MGH_B@(OAGI/AGK?AGICAGY+AGICAGK?AGH_B@(OAGI'AGK;AGICAGI'AGK;A
MGIKB@(OAGI_AGY+AGIOAGK;AGH#B@(OAGICAGKWAGIG"H.&?E`#AGI3AGY+A
MGIKAGJ+AGI3AGXOB@(OAGI'AGI'AGKWAGIOB@(OAGI/AGK?AGICAGY+AGICA
MGK?AGH\`X9Z0X9Z/XH"+X9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z1X9Z1X9Z]
MX9Z;XH"+X9Z3X9ZWX9Z8X9^2X9Z8X9ZWX9Z/`.&>G^&?AN&>FN&>MN&>F.*`
MB^&>D^&>M^&>F.&?DN&>F.&>MP#AGI#AGH_B@(OAGI_AGX;AGIKAGK;AGICB
M@(OAGI/AGK?AGICAGY+AGICAGK?AGH\`X9Z?X9^2X9Z;X9ZVX9Z`XH"+X9Z0
MX9Z/XH"+X9Z3X9ZWX9Z8X9^2X9Z8X9ZWX9Z/PJ#AGY8`X9Z<X9^)X9ZVX9Z;
MX9ZXX9Z?(.&>D^&>M^&>A"#AGJ#AGY+AGISAGXKAGKSB@(OAGI'AGKOAGIGA
MGH[AGK8`X9Z6X9^2X9Z:X9Z8X9ZVX9Z3`.&>G.&>M^&>E`#AGH_AGX;AGI3A
MGI/AGXOAGI3AGH[AGY+AGH_AGK;AGHD`X9Z:X9ZVX9Z;X9^+XH"+X9Z?X9Z4
MX9^2X9Z*X9ZVX9Z@X9^-`.&>G^&>O.&>F.*`B^&>G^&?DN&>G.&>MN&>@N&>
MF.&>D^&?C0#AGI_AGKSAGICB@(OAGI_AGY+AGISAGK;AGH+AGICAGI/AGXWB
M@(OAGICAGH#B@(OAGH#AGK;AGI/AGXL@)7,`X9Z?X9ZVX9Z@X9ZVX9Z:X9^)
MX9ZVXH"+X9Z!X9ZVX9Z$XH"+X9Z;X9ZWX9Z%`.&>C^&>ON*`B^&>F>&>ON&>
MA.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>DN&?DN&>G.&>ON*`B^&>F>&?B>&>
MMN&>A.*`B^&>BN&>O.&>A>&>F.&?DN&>BN&?@>&>A>*`B^&>A^&>MN&>F.&>
MO>&>F>*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>
MMN&>FB#AGI3AGI/AGY+AGI'AGK;AGI3AGXOB@(OAGI;AGKCB@(OAGI;AGKWA
MGH#B@(OAGISAGK;B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OA
MGIKAGK;AGIGAGH#AGK;AGIKAGH[AGXWB@(OAGI#AGK;B@(OAGH?AGK;B@(OA
MGI_AGK;AGIKB@(OAGJ7AGH_B@(OAGI3AGK;AGI/B@(OAGH#AGK;AGIH@X9ZL
M(.&>G^&>MN&>FN*`B^&>F^&?DN&>HL*@/P#AGI;AGX'AGIOB@(OAGIOAGKOA
MGI3B@(OAGI_AGK;AGIH@X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+
MX9Z6X9Z]X9Z`XH"+X9Z<X9ZVXH"+X9Z1X9^%XH"+X9Z0X9Z/XH"+X9Z?X9^&
MX9Z:X9ZVX9Z8XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(.&>A^&?
MAN&>D^&>O>&>G^*`B^&>LN&?DN&>F>*`B^&>@.&>MN&>FN*`B^&>G^&>F.&?
MDN&>@N&>MN&>F^&?B^*`B^&>EN&>O>&>@.*`B^&>G.&>MN*`B^&>D.&>MN*`
MB^&>E.&>MN&>D^*`B^&>F^&>N^&>E,*@/P#AGI;AGX'AGIOB@(OAGI3AGK[A
MGH#B@(OAGI3AGY+AGIKAGJ+AGI3AGXOB@(OAGI_AGX;AGI3AGKOAGH_AGY+A
MGIKB@(OAGI#AGY+AGICAGKCB@(OAGICAGKWAGID@X9Z1X9^&X9Z6X9^0X9Z:
MXH"+X9Z.X9ZVX9Z8X9Z]X9Z9XH"+X9Z*X9^"X9Z;XH"+X9ZBX9^2X9Z3X9Z`
MXH"+X9Z%X9Z$X9^+XH"+X9Z%X9ZVX9Z4X9^+X9Z5X9^2X9Z/X9Z^X9Z8XH"+
MX9Z6X9ZXPJ`_`.&>EN&?@>&>F^*`B^&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>
MN^&>@.*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^*`B^*`B^&>BN&?@N&>
MF^*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>ON*`BR#AGH_AGK[B@(OAGIGA
MGK[AGH3B@(OAGH+AGKWAGIKB@(OAGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOA
MGH#B@(OAGI'AGK?AGI/AGY+AGI/AGI/AGY#AGIGB@(OAGJ_AGH#AGI_AGK;A
MGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGJSB@(OAGI'AGX'"H#\`X9Z3
MX9^%XH"+X9Z6X9^!X9Z;XH"+X9Z5X9^2X9Z)X9Z^XH"+X9Z?X9^&X9Z4X9Z[
MX9Z/X9^2X9Z:(.&>K"#AGI3AGI/AGY+AGIOAGK;AGIGB@(OAGJ+AGK;AGI_A
MGIGAGHKAGY+AGHOAGK;AGI,@X9Z/X9Z^XH"+X9Z*X9^"X9Z3XH"+X9ZBX9^2
MX9Z<X9ZXXH"+X9Z*X9^"X9Z;XH"+X9Z9X9Z^X9Z$XH"+X9Z"X9Z]X9Z:XH"+
MX9Z4X9Z3X9^2X9Z0X9^"X9Z8XH"+X9Z1X9^%XH"+X9Z!X9ZVX9Z$XH"+X9Z%
MX9Z[X9Z$XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z*X9^"
MX9Z;XH"+X9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z;X9Z`X9^2X9Z!X9Z.
MX9^(XH"+X9Z"X9^2X9Z:X9Z4X9^+X9Z"X9^2X9Z:X9ZVX9Z3X9^+("CAGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIOB
M@(OAGHKAGX+AGIOB@(OAGH+AGY+AGICAGK;AGI,@(D`B*<*@/P#AGH_AGK[B
M@(OAGJ+AGY+AGI/AGH#B@(OAGH7AGH3AGXOB@(OAGI3AGH3AGY+AGJ#AGK;A
MGHGB@(OAGH_AGX;AGH[B@(OAGI'AGX7B@(OAGH#AGK;AGI/AGXOB@(OAGI'A
MGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGIGB@(OAGH?AGX;AGI/AGKWAGI_B
M@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OAGICAGKWAGID@X9Z3X9^%
MXH"+X9Z`X9Z3X9^2X9Z;X9^"X9Z$XH"+X9Z.X9ZVPJ`_`.&>E.&>B>&?DN&>
MA^&>N.*`B^&>GP#AGI'AGI'AGKGAGH3B@(L`X9Z1X9Z1X9ZYX9Z$(.&?E@#A
MGI3AGHGAGY+AGH?AGKCB@(OAGI3AGY+AGIKAGK;AGI#AGY+AGI/AGK8`X9ZB
MX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z`X9Z3X9^2X9Z;X9^"X9Z$
MXH"+X9Z2X9^2X9Z<X9Z^XH"+X9Z`X9ZVX9Z:`.&>D>&>O.&>FN&>G^&?D.&>
MEN&?DN&>D>*`B^*`B^*`B^&>@.&>D^&?DN&>F^&?@N&>A.*`B^*`B^*`B^&>
MDN&?DN&>G.&>ON&>@.&>MN&>F@!960!965E9`.&>E.&?DN&>FN&>A>&>MN&?
MAN&>AN&?DN&>D^&>MN&?A@#AGIGAGX'AGICAGX+AGI,`X9Z4X9ZVX9Z1`.&>
MHN&?DN&>D^&>@.*`B^&>D>&?AN&>D^&>A.*`B^&>A^&>MN&>D>&?A>*`B^&>
ME.&?DN&>FN&>F.&>O.&>F^*`B^&>F>&>@.*`B^*`B^&>HN&?BN&>N.&>F.&?
M@N&>FR#AGI;AGKCB@(OAGH+AGH[AGI/AGKCB@(OAGH'AGK;AGH3B@(OAGH#A
MGY+AGIKAGX3AGICB@(O"H.&?E@#AGJ+AGY+AGI/AGH#B@(OAGH#AGX;AGI;A
MGKOAGH3B@(OAGI3AGXGAGKOAGI/AGI3AGXGAGH3B@(OAGIOAGKOAGI3B@(OA
MGI_AGK;AGIKB@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXL@X9Z*X9^"X9Z;XH"+
MX9Z8X9ZVX9Z3XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z0X9Z/XH"+X9Z!X9ZV
MX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8PJ#AGY0`X9ZBX9^2X9Z3X9Z`XH"+X9Z`
MX9^&X9Z6X9Z[X9Z$XH"+X9Z4X9^)X9Z[X9Z3X9Z4X9^)X9Z$XH"+X9Z;X9Z[
MX9Z4XH"+X9Z0X9Z/XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8PJ#A
MGY0`X9ZBX9^2X9Z3X9Z`XH"+X9Z`X9^&X9Z6X9Z[X9Z$XH"+X9Z%X9Z8X9^2
MX9Z;X9Z$+^&>E>&?DN&>F^&>MN&>G^&?B^&>D>&>N.*`BR#AGI'AGX7B@(OA
MGI#AGH_AGI#AGY+AGICAGKCB@(OAGICAGKWAGIG"H.&?E.*`BP#AGJ+AGY+A
MGI/AGH#B@(OAGH#AGX;AGI;AGKOAGH3B@(OAGI3AGH3AGY+AGH#AGK[AGH_B
M@(OAGI#AGH_B@(OAGIKAGH3B@(OAGICAGKWAGIGB@(OAGI/AGX,`X9ZBX9^2
MX9Z3X9Z`XH"+X9Z`X9^&X9Z6X9Z[X9Z$XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/
MXH"+X9Z0X9Z/XH"+X9Z`X9Z8X9^2X9Z:X9ZWX9Z/XH"+X9Z`X9^&X9Z6X9Z\
MX9Z;XH"+X9Z8X9Z]X9Z9PJ#AGY0`X9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZWX9Z3
MXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9ZBX9Z3X9Z[X9Z)
MX9^2X9Z)X9ZVX9Z/XH"+X9ZRX9^2X9Z9XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/
MXH"+X9Z0X9Z/XH"+X9ZAX9Z^X9Z9PJ#AGY0`X9ZBX9^2X9Z3X9Z`XH"+X9Z8
MX9ZWX9Z3XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9ZBX9Z3
MX9Z[X9Z)X9^2X9Z)X9ZVX9Z/XH"+X9ZRX9^2X9Z9XH"+X9Z4X9Z$X9^2X9Z`
MX9Z^X9Z/XH"+X9Z0X9Z/XH"+X9Z%X9^2X9Z:X9Z^X9Z3XH"+X9Z'X9ZVX9Z$
M("5D(.&>H>&>ON&>F<*@X9^4`.&>HN&?DN&>D^&>@.*`B^&>F.&>M^&>D^*`
MB^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>HN&>D^&>N^&>B>&?
MDN&>B>&>MN&>C^*`B^&>LN&?DN&>F>*`B^&>E>&?DN&>B>&>ON*`B^&>G^&>
MMN&>FN*`B^&>D>&?A>*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>F^*`
MB^&>A>&?DN&>FN&>ON&>D^*`B^&>A^&>MN&>A"`E9"#AGI/AGK;AGH#AGXOB
M@(OAGJ'AGK[AGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z:X9Z9X9^(X9Z6X9^!
MX9Z;("5D(.&>F.&?B>&?A.&>A,*@X9^4`.&>HN&?DN&>D^&>@.*`B^&>F.&>
MM^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>HN&>D^&>
MN^&>B>&?DN&>B>&>MN&>C^*`B^&>LN&?DN&>F>*`B^&>E>&?DN&>B>&>ON*`
MB^&>G^&>MN&>FN*`B^&>D>&?A>*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>
MO>&>F^*`B^&>A>&?DN&>FN&>ON&>D^*`B^&>A^&>MN&>A"`E9"#AGI/AGK;A
MGH#AGXOB@(OAGJ'AGK[AGIG"H.&?E`#AGJ+AGY+AGI/AGH#B@(OAGH#AGX;A
MGI;AGKOAGH3B@(OAGI3AGY+AGH_AGKSAGIKB@(OAGHCAGY+AGICAGX3AGX?B
M@(OAGI#AGH_"H.&?E@#AGJ+AGY+AGI/AGH#B@(OAGJ+AGK;AGH7B@(OAGI3A
MGY+AGIKAGK[B@(OAGH#AGI/AGY+AGIOAGX+AGH3B@(OAGHKAGK;AGH#AGXOB
M@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGI@@X9Z3X9^%XH"+X9Z`X9^2
MX9Z3X9Z[X9Z$XH"+X9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z5X9^2X9Z1X9^#
MXH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9XH"+X9Z?X9^&X9Z4X9Z[
MX9Z/X9^2X9Z:PJ#AGY8@)6,@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z8
MX9ZVX9Z/X9ZWX9Z`X9ZVXH"+X9Z?X9ZVX9Z:XH"+X9Z4X9Z%X9^2X9Z%X9Z[
MX9Z4X9^2X9Z4X9Z3X9^2X9Z3.R`E<R#AGI_AGICAGY+AGIKAGK;AGI3AGXOB
M@(OAGJ#AGH_AGY+AGI#AGIOAGX'AGH'AGK;"H.&?E`#AGJ+AGY+AGI/AGH#B
M@(OAGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGHCAGI3AGXOAGH?AGK;AGISB
M@(OAGI;AGK@@(B5S(B#AGI3AGK;AGI/B@(OAGJ'AGK[AGIG"H.&?E`#AGJ+A
MGY+AGI/AGH#B@(OAGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGIGAGIOAGXOB
M@(OAGI;AGY+AGIKAGICB@(OAGI'AGX7B@(OAGIOAGH#AGY+AGH'AGH'AGH[A
MGY+AGHSB@(OAGH#AGK?AGH7AGY+AGH7B@(OAGI/AGX/B@(OAGI;AGY+AGIKA
MGICB@(OAGI;AGY+AGIKAGX#AGH3B@(OB@(OAGI_AGX'AGISAGK8@X9Z*X9Z\
MX9Z%X9^2X9Z3X9^!X9^'XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZWX9Z3XH"+
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9ZBX9Z3X9Z[X9Z)X9^2
MX9Z)X9ZVX9Z/XH"+X9ZRX9^2X9Z9XH"+X9Z%X9Z\X9Z;PJ#AGY0`X9ZBX9^2
MX9Z3X9Z`XH"+XH"+X9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z?X9^!X9Z%
MX9Z`X9^2X9Z/X9ZXXH"+X9ZBX9Z3X9Z[X9Z)X9^2X9Z)X9ZVX9Z/XH"+(.&>
MBN&>ON&>F.&?DN&>E.&>N.*`B^&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>E.&?
MDN&>C^&>O.&>FN*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>F^*`B^&>BN&?AN&>
MCN&>ON&>FN&>@.&>MN&>FN*`B^&>D>&?A>*`B^&>D.&>C^*`B^&>D^&?@>&?
MAP#AGJ+AGY+AGI/AGH#B@(OAGI3AGK;AGI/B@(OAGI3AGHGAGY+AGH?AGKSA
MGI/B@(OAGI3AGI/AGY+AGH_B@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OA
MGIOAGKX@)25S(.&>D>&?A>*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>
MF^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F,*@X9^6("5SPJ#AGY0`
MX9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZVX9Z3XH"+X9Z?X9ZVX9Z:XH"+X9Z0X9^2
MX9Z8X9ZX("5SPJ#AGY0`X9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZVX9Z3XH"+X9Z?
MX9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZX(.&?H<*@X9^4`.&>HN&?DN&>D^&>@.*`
MB^&>E.&>MN&>D^*`B^&>BN&>MN&>@.&?B^&>G^&?DN&>D^&>ON*`B^&>D>&?
MAN&>EN&?D.&>FN*`B^&>D^&?@>&?A^*`B^&>FN&>O>&>A>*`B^&>H.&>ON&>
MF<*@X9^4`.&>HN&?DN&>D^&>@.*`B^&>F.&>MN&>D^*`B^&>G^&?AN&>E.&>
MN^&>C^&?DN&>FN*`B^&>D.&?DN&>F.&>N"#AGH#AGY+AGI/AGKOAGH3B@(OA
MGI#AGH_B@(OAGHKAGKSAGH7B@(OB@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKA
MGX3AGIC"H.&?E@#AGJ+AGY+AGI/AGH#B@(OAGICAGK;AGI/B@(OAGI_AGX;A
MGI3AGKOAGH_AGY+AGIKB@(OAGI#AGY+AGICAGK@@X9Z`X9^2X9Z3X9Z[X9Z$
MXH"+X9Z0X9Z/XH"+XH"+XH"+X9Z*X9Z\X9Z%XH"+X9Z!X9ZVX9Z$XH"+X9Z`
MX9^2X9Z:X9^$X9Z8PJ#AGY8`X9ZBX9^2X9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z/X9^"XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z9X9^)X9ZV
MX9Z$XH"+X9Z@X9^$X9Z%XH"+X9Z.X9ZVX9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`
MXH"+X9Z1X9Z1X9Z]X9Z;XH"+X9Z8X9Z]X9Z9PJ#AGY0`X9ZBX9^2X9Z3X9Z`
MXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+X9Z4X9Z)X9^2X9Z%X9Z\
MX9Z;XH"+X9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+
MX9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZO
MX9Z`X9Z'X9Z3(%!'4"#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`@X9Z*
MX9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z8X9Z^X9Z;XH"+X9Z?X9ZVX9Z:XH"+X9Z3
MX9^!X9^'`.&>HN&?DN&>D^&>@.*`B^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>
MC^&?@N*`B^&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>@^&?DN&>F^&>MN*`B^&>
MG^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`
MB^&>@.&>O.&>D^&>G^&?A.*`B^&>K^&>@.&>A^&>DR!3+TU)344@X9Z:X9Z4
MX9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(.&>BN&>ON&>F.&?DN&>E.&>N.*`B^&>
MF.&>ON&>F^*`B^&>G^&>MN&>FN*`B^&>D^&?@>&?AP#AGHKAGX;AGI3AGKSA
MGH0@X9ZBX9^2X9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+
MX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z"X9^$X9Z;XH"+X9Z*X9^%XH"+X9Z8X9Z]
MX9Z9PJ#AGY0`X9ZBX9^2X9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/
MX9^"XH"+X9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z"X9Z.X9Z3X9ZXXH"+X9Z*X9^"
MX9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z;X9Z[X9Z4XH"+X9Z8X9Z]X9Z9
MPJ#AGY0`X9Z*X9^&X9Z4X9Z\X9Z$(.&>HN&?DN&>D^&>@.*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>C^&?@N*`B^&>A^&?DN&>FN&>ON&>G^*`B^&>HN&>MN&>
MG^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>F.&>O>&>F<*@X9^4`.&>BN&?AN&>
ME.&>O.&>A"#AGJ+AGY+AGI/AGH#B@(OAGH_AGY+AGIKAGKSAGISB@(OAGH_A
MGX+B@(OAGH?AGY+AGIKAGK[AGI_B@(OAGIGAGXGAGK;AGH3B@(OAGJ#AGX3A
MGH7B@(OAGH[AGK;AGI_AGXOB@(OAGI_AGK;AGIKB@(OAGICAGKWAGIG"H.&?
ME`#AGJ+AGY+AGI/AGH#B@(OAGH_AGY+AGIKAGKSAGISB@(OAGH_AGX+B@(OA
MGI3AGHGAGY+AGH?AGK;AGH#AGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGI'AGI'A
MGKWAGIOB@(OAGICAGKWAGIG"H.&?E`#AGJ+AGY+AGI/AGH#B@(OAGH_AGY+A
MGIKAGKSAGISAGH_AGX+B@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGID@(B5S
M(B#AGI3AGY+AGIKAGK[B@(OAGI3AGK;AGI/B@(OAGI/AGX7B@(OAGH#AGY+A
MGI/AGKOAGH3B@(OAGH?AGICAGY+AGIKAGK[AGI_B@(OAGI#AGX+AGI'AGK;A
MGX;B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"H.&?E`#AGJ+AGY+A
MGI/AGH#AGI3AGK;AGI/B@(OAGI3AGY+AGH_AGKSAGIKB@(OAGI'AGK?AGI_B
M@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OAGI'AGX4@)7,@X9Z;X9Z^("4E
M<\*@X9^4`.&>HN&?DN&>D^&>@.*`B^&>E.&>MN&>D^*`B^&>AN&?DN&>F^&>
MON&>F>*`B^&>C^&>E.*`B^&>D>&?A>*`B^&>G^&>MN&>FN*`B^&>D^&?@>&?
MA^*`B^&>F^&>OB`E<\*@X9^4`.&>HN&?DN&>D^&>@.*`B^*`B^&>F.&>M^&>
MD^*`B^&>C^&?DN&>FN&>O.&>G.*`B^*`B^&>E.&>MN&>D^*`B^&>A^&>MN&>
MG.*`B^&>E.&?DN&>FN&>A>&>MN&?AN*`B^&>D>&?A2`B)7,BPJ#AGY0@X9Z3
MX9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9ZBX9^2X9Z<X9ZXXH"+X9Z*
MX9^"X9Z;XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:
MX9Z^XH"+X9Z4X9ZVX9Z3XH"+X9Z3X9ZWX9Z9X9ZVX9Z9`.&>HN&?DN&>D^&>
M@.*`B^&>F.&>M^&>D^&>C^&?DN&>FN&>O.&>G.*`B^*`B^&>E.&>MN&>D^*`
MB^&>B.&>E.&?B^*`B^&>A^&>MN&>G.*`B^&>EN&>N"`B)7,BPJ#AGY0@X9Z3
MX9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9ZBX9^2X9Z<X9ZXXH"+X9Z*
MX9^"X9Z;XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:
MX9Z^XH"+X9Z4X9ZVX9Z3XH"+X9Z3X9ZWX9Z9X9ZVX9Z9`.&>HN&?DN&>D^&>
M@.&>C^&?DN&>FN&>O.&>G.*`B^*`B^&>E.&>MN&>D^*`B^&>A^&>MN&>G.*`
MB^&>E.&?DN&>FN&>A>&>MN&?AN*`B^&>D>&?A2`B)7,B(.&>BN&?A.&>F>*`
MB^&>A^&?A.&>@N&>A^&?D.&>F0#AGJ+AGY+AGI/AGH#B@(OAGH_AGY+AGIKA
MGKSAGISB@(OB@(OAGI3AGK;AGI/B@(OAGHCAGI3AGXOB@(OAGH?AGK;AGISB
M@(OAGI;AGK@@(B5S(B#AGHKAGX3AGIGB@(OAGH?AGX3AGH+B@(OAGH?AGY#A
MGID`X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z:X9Z4X9Z?X9^+X9ZBX9^2X9Z3X9Z`
M`.&>@.&>O.&>D^&>G^&?A"#AGI_AGK;AGI+AGK;AGIKAGH[AGX@OX9ZOX9Z`
MX9Z'X9Z3(%!'4"#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH``X9Z`X9Z\
MX9Z3X9Z?X9^$XH"+X9ZOX9Z`X9Z'X9Z3XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZB
MX9^2X9Z3X9Z``.&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>
MCN&?B.*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@`#AGJ+AGK;AGI_A
MGIGAGHKAGY+AGHOAGK;AGI/B@(OAGH;AGY+AGIOAGK[AGIGAGH_AGI0MX9Z1
MX9^%XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY8@/&5M/BCA
MGI_AGY+AGIKAGX'AGH7B@(OAGH7AGK?AGH_AGY+AGH\I/"]E;3X`X9Z<X9ZW
MX9Z)X9^2X9Z)X9ZVX9Z4X9Z3X9Z4X9Z/X9^2X9Z:XH"+(.&>G^&>MN&>DN&>
MMN&>FN&>CN&?B"_AGJ_AGH#AGH?AGI/B@(L@X9Z3X9^#(%,O34E-12#AGIKA
MGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH``X9Z"X9Z.X9Z3X9ZXXH"+X9Z:X9Z4
MX9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY8`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2
MX9Z+X9ZVX9Z3XH"+X9Z`X9^2X9Z;X9^"X9Z$X9Z`X9^2X9Z;X9ZVX9Z9XH"+
MX9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY8@/&5M/BCAGI_AGY+A
MGIKAGX'AGH7B@(OAGH7AGK?AGH_AGY+AGH\L(.&>E.&>B>&?DN&>A>&>O.&>
MF^*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>D^&>N.&>F.&>
MO>&>F>&?E^*`B^&>F^&>ON*`B^&>A^&>O>&>FN*`B^&>D.&?DN&>F.&>N"D\
M+V5M/@#AGH#AGICAGY+AGICAGISAGK?AGI+AGKCB@(OAGIKAGKOAGH#AGIKA
MGH#B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#B@(L@X9Z8X9ZWX9Z3
MX9Z"X9ZVX9^&X9Z1X9^2X9Z:XH"+X9Z`X9ZVX9Z:XH"+X9Z4X9Z$X9^2X9Z@
MX9ZVX9Z)XH"+X9Z`X9^2X9Z3X9Z[X9Z$X9Z/X9Z](.&>D^&?@^*`B^&>E.&?
MDN&>FN&>E^&?@>&>D>*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>D^&?@>&?
MA\*@X9^4`.&>G^&?AN&>CN&>N^&?AN*`B^&>C^&>O>*`B^&>HN&>@.&?DN&>
MG^&>FN*`B^&>F^&?AN&>D^&>MN&?AN*`B^&>BN&>ON&>F.*`B^&>FN&>E.&>
MG^&?B^&>HN&?DN&>D^&>@"#AGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OB@(OA
MGI7AGY+AGHGAGK[B@(OAGI_AGK;AGIK"H.&?E@#AGISAGK?AGI+AGKCAGI_A
MGK;AGI_AGY+AGH_AGY+AGIKB@(OAGI3AGICAGY+AGIOAGX+AGH3B@(OAGH?A
MGK;B@(OAGH#AGKSAGHKB@(OAGIOAGX;AGI/AGK;AGX;AGHKAGK[AGICB@(OA
MGIKAGI3AGI_AGXOAGJ+AGY+AGI/AGH`@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+
MXH"+XH"+X9Z5X9^2X9Z)X9Z^XH"+X9Z?X9ZVX9Z:PJ#AGY8`X9ZOX9Z`X9Z?
MX9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z:X9Z4X9Z?X9^+XH"+
MX9ZBX9^2X9Z3X9Z`XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z/X9Z7
MX9^2X9Z'X9ZVX9Z4X9^+(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>D>&>MN&>B>&>F>&>@.*`B^&>BN&?A.&>F>*`B^&>HN&?DN&>D^&>@.*`
MB^&>E.&?DN&>FN&>ON*`B^&>F>&?B>&>MN&>A.*`B^&>C^&>M^&>A>*`B^&>
MF.&?DN&>D^&>MN&>@,*@X9^4"@KAGHCAGY+AGICAGX3AGX?B@(OAGJ_AGH#A
MGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXO"H.&?EB`E<PKAGH#AGK;A
MGIOAGI3AGIKAGK?AGH7AGY+AGH;AGX'AGI'B@(OAGJ_AGH#AGI_AGK;AGIKB
M@(OAGI?AGY+AGH?AGK;AGI3AGXO"H.&?EB`E<PH*X9Z%X9Z[X9Z%XH"+X9Z/
MX9^&X9Z.XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8XH"+X9Z*X9Z^
MX9Z8X9^2X9Z4X9ZXXH"+X9Z;X9Z[X9Z4XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+
MX9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z'X9ZVXH"+X9ZBX9Z%X9ZWX9Z3X9^2
MX9Z/X9^2X9Z:X9^#X9Z9X9^-PJ#AGY8*)7,`X9Z?X9ZVX9Z:XH"+X9Z:X9Z4
MX9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z'X9Z\X9Z3XH"+X9Z*X9^$X9Z9XH"+X9Z'
MX9^$X9Z"XH"+X9Z'X9^0X9Z9PJ#AGY0`X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!
MX9ZVXH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY8`X9Z9X9Z\
MX9Z@X9^2X9Z"X9^$X9Z?X9^2X9Z;X9ZVX9Z<X9ZX`.&>G^&?@P#AGJ#AGY+A
MGI_AGK;AGX;AGI3AGXKAGK@`X9Z@X9^2X9Z?X9^*X9ZXX9Z8X9Z4X9ZVX9Z<
MX9^)X9^!`%OAGIOAGK;AGH#AGXOB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI-=`%OAGH+AGY+AGICAGK;AGI/B@(OAGI3AGY+AGIKAGI+AGK;AGI/A
MGI3AGI%=`%OAGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGJ+AGK;AGI_AGIGAGHKA
MGY+AGHOAGK;AGI,@+0!;X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9ZBX9ZVX9Z?
MX9Z9X9Z*X9^2X9Z+X9ZVX9Z3("T@X9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]
MX9Z;XH"+X9Z%X9^&X9Z3X9Z]X9Z3("5S70!?0N&>F^&>MN&>@.&?BR``7T+A
MGI3AGHGAGY+AGH?AGKCB@(OAGH'AGY+AGICAGX4@`%]#X9Z%X9Z8X9^2X9Z;
MX9Z$(`!?1.&>F^&>N^&>E"``7T;AGI#AGH\@`%])X9ZBX9Z/X9^2X9Z/X9Z?
MX9Z)X9^2X9Z)X9ZVX9Z.(`!?2>&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>D>&>
MD>&>O>&>FR``7TSAGH7AGX'AGHD@`%]-X9Z`X9Z\X9Z*XH"+X9Z:X9Z4X9Z?
MX9^+XH"+X9Z?X9ZVX9Z:(`!?3N&>G^&>MN&>FN*`B^&>D.&?DN&>F.&>N"``
M7U#AGI3AGX3AGX?AGI;AGKOAGICAGY+AGI8@`%]0X9ZBX9ZVX9Z1X9ZWX9Z7
MX9ZVX9Z6(`!?4N&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F2`E<R#AGI_AGY+A
MGIKAGI_AGXL@`%]2X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4(`!?4^&>G^&?
MDN&>G.&?@N&>A.*`B^&>FN&>@"``7U/AGI7AGY+AGHGAGK[B@(OAGI_AGK;A
MGIH@`%]4X9Z!X9^2X9Z?X9^#XH"+X9Z?X9^2X9Z:X9ZAX9ZVX9Z9(`!?5.&>
MD>&?A2``7U7AGICAGK?AGI/B@(OAGIOAGKOAGI0@`%]6X9Z8X9Z^X9Z;XH"+
MX9Z!X9^2X9Z?X9^"XH"+X9Z?X9^2X9Z:X9ZAX9ZVX9Z9(`!?5^&>E.&>B>&?
MDN&>A^&>N.&>GR``X9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+
MX9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;XH"+X9Z?X9^&X9Z4X9Z[X9Z/
MX9^2X9Z:`.&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BP!A
M='1A8VAM96YT<RYZ:7``X9Z4X9^#`.&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`
MB^&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>F^&>
MD>&?DN&>DN&>E>&>FP#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGK[A
MGH#B@(OAGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGI3AGHGAGY+AGH7AGKSA
MGIL`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z^
MXH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z6X9ZVX9Z`X9^2X9Z9X9Z4
MX9Z)X9^2X9Z'X9ZV`.&>@.&?AN&>H.&>N^&>G^*`B^&>@.&>MN&>FN*`B^&>
M@.&?AN&>CN&>C^&?B^*`B^&>FN&>A>&>D^&>MN&>G^&>F.&?DN&>EN&?D.&>
MD^&?DN&>D@#AGI3AGK;AGH_AGXOB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI3A
MGY+AGIKAGI;AGY#AGI/AGY+AGI+B@(OAGI_AGX;AGH'AGK;AGI/AGXOB@(OA
MGI3AGX;AGI7AGKOAGH\`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z1X9^2X9Z:X9Z$
MX9^+X9Z1X9^2X9Z:X9ZVX9Z9XH"+X9Z1X9ZWX9Z3X9^2X9Z3X9Z3X9^0X9Z9
M`.&>FN&>@.*`B^&>F.&>M^&>D^*`B^&>@^&>ON&>B>*`B^&>DN&>MN&>C^&>
MN^*`B^&>E.&>B>&?DN&>A>&>O.&>FP#AGI;AGK@`:&@`X9Z8X9ZWX9Z3XH"+
MX9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z8X9^)
MX9ZVX9Z?X9^*X9ZXX9Z3`.&>@.&?DN&>D^&>N^&>A`#AGH#AGX;AGJ#AGKOA
MGI_B@(OAGI3AGHGAGY+AGH7AGX'AGHDOX9Z4X9Z)X9^2X9Z%X9Z\X9Z;`.&>
M@.&?AN&>H.&>N^&>G^*`B^&>@.&>F.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>
M@>&>MN&>A.*`B^&>@.&?DN&>FN&?A0#AGI'AGX7B@(OAGH#AGY+AGI/AGKOA
MGH3B@(OAGI#AGH\`X9Z`X9Z\X9Z3X9Z?X9^$`.&>K^&>@.&>G^&>MN&>FN*`
MB^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>F@#A
MGI@NX9Z8+@#AGHCAGY+AGICAGX3AGX<`X9Z"X9^2X9Z8X9ZVX9Z3`.&>K`#A
MGI_AGK?AGI'AGY+AGI+AGK?B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;A
MGI/B@(OAGI3AGHKAGK?AGI_AGX'AGI(`X9Z7X9ZXX9Z`X9Z?X9^"X9Z;`.&>
MHN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>FUT`X9Z`X9^&X9Z@X9Z[X9Z?XH"+
MX9Z6X9ZXXH"+X9Z%X9Z8X9^2X9Z$X9ZVX9Z9XH"+X9Z`X9^2X9Z3X9Z[X9Z$
MXH"+X9Z6X9ZWX9Z2X9ZXX9Z`X9ZVX9Z:`.&>F.&>M^&>D^*`B^&>HN&>MN&>
MA>*`B^&>FN&>@.*`B^&>G^&?@>&>G.&>MN*`B^&>E.&>MN&>DP#AGH#AGX;A
MGJ#AGKOAGI_B@(OAGJ+AGH#AGY+AGH'AGIKAGK;AGISAGK?AGIKAGKOAGI'A
MGY+AGI(`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9ZBX9Z`X9^2X9Z!X9Z:X9ZVX9Z<
MX9ZWX9Z:X9Z[X9Z1X9^2X9Z2`'-S`.&>@.&?AN&>H.&>N^&>G^*`B^&>E.&?
MDN&>FN&>EN&?D.&>D^&?DN&>D@#AGI3AGIKAGK;AGH?AGY#AGIGB@(OAGI3A
MGH[AGY+AGHKAGX3AGX?AGJ+AGK;AGI_AGI/AGY+AGI,`X9Z8X9ZWX9Z3XH"+
MX9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z`X9^&X9Z@X9Z[X9Z?`.&>@N&?DN&>
MF.&>MN&>D^*`B^&>B.&?DN&>F.&?A.&?AP!V0V%R9`#AGI3AGHGAGY+AGH?A
MGKCB@(OAGH'AGY+AGICAGX7B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/A
MGH``X9Z4X9Z)X9^2X9Z'X9ZXXH"+X9Z?XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZB
MX9^2X9Z3X9Z`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]K;U]+4B\`````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V
M,P`P,3<T-38`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VMO
M7TM2+TQ#7TU%4U-!1T53+P``````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S8S`#`R,3(T,P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]L;V-A;&4O:V]?2U(O3$-?34534T%'15,O:6UP+FUO````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`Q-C0Q,#<`,3`T,3<S-C(W-C,`,#(R,S<S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-X2!)4`
M````K0,``!P```"$'0``ZP0``.PZ````````F$X```H```"93@``"@```*1.
M```*````KTX```\```"Z3@``"````,I.```+````TTX```P```#?3@``"@``
M`.Q.```$````]TX``!<```#\3@``*````!1/```2````/4\``#(```!03P``
M*0```(-/```R````K4\``!L```#@3P``+@```/Q/```W````*U```'P```!C
M4```;````.!0```<````35$``!T```!J40``#@```(A1```/````EU$```@`
M``"G40``#@```+!1```.````OU$``#,```#.40``!0````)2```#````"%(`
M`!$````,4@``#P```!Y2```#````+E(```\````R4@``"````$)2```*````
M2U(```@```!64@``'````%]2```9````?%(```<```"64@``#````)Y2```-
M````JU(```X```"Y4@``!0```,A2```%````SE(```H```#44@```P```-]2
M```.````XU(``$X```#R4@``4````$%3``!#````DE,``$(```#64P``,```
M`!E4```/````2E0``",```!:5```!@```'Y4```7````A50``!\```"=5```
M"````+U4```1````QE0```T```#85```$P```.94```C````^E0``"\````>
M50``!0```$Y5```A````5%4``#L```!V50``/````+)5```K````[U4``#$`
M```;5@``.P```$U6```,````B58```D```"65@```P```*!6```Y````I%8`
M``8```#>5@``#````.56```.````\E8``$D````!5P``"@```$M7```+````
M5E<```D```!B5P``!@```&Q7``!0````<U<``!@```#$5P``$0```-U7```+
M````[U<```H```#[5P``"@````98```0````$5@```,````B6```"````"98
M```)````+U@``$4````Y6```!````']8```$````A%@```8```")6```$0``
M`)!8```'````HE@```0```"J6```)P```*]8```&````UU@```T```#>6```
M$P```.Q8```(`````%D```@````)60``*@```!)9```K````/5D```8```!I
M60``#@```'!9```5````?UD``#X```"560``!P```-19```"````W%D```H`
M``#?60``#P```.I9```-````^ED```\````(6@``#0```!A:```)````)EH`
M``8````P6@``!@```#=:```*````/EH```T```!)6@``8@```%=:```G````
MNEH``%\```#B6@``#@```$);```<````45L``"@```!N6P``!0```)=;```.
M````G5L``"H```"L6P``$P```-=;``!'````ZUL``!\````S7```)0```%-<
M```S````>5P``"L```"M7```-0```-E<``!"````#UT``!T```!270``0```
M`'!=```X````L5T```P```#J70``$0```/==```-````"5X```@````77@``
M#````"!>```4````+5X```\```!"7@``$````%)>```1````8UX```4```!U
M7@``!0```'M>```&````@5X```<```"(7@``%P```)!>```F````J%X``$\`
M``#/7@``)0```!]?```0````15\``!L```!67P``7````')?```N````SU\`
M``0```#^7P``#@````-@```.````$F````<````A8```#@```"E@```I````
M.&````8```!B8```#0```&E@```5````=V````T```"-8```&@```)M@```=
M````MF```!D```#48```70```.Y@```.````3&$```T```!;80``.0```&EA
M```<````HV$```,```#`80``#0```,1A```"````TF$```4```#580``!0``
M`-MA```$````X6$```X```#F80``"````/5A```/````_F$```\````.8@``
M$````!YB```9````+V(``!H```!)8@``!@```&1B```0````:V(``!4```!\
M8@``"P```))B```-````GF(``"L```"L8@``-````-AB```S````#6,```H`
M``!!8P``&0```$QC```6````9F,```<```!]8P``$````(5C```<````EF,`
M`!P```"S8P``"@```-!C```4````VV,```L```#P8P``+P```/QC```/````
M+&0```D````\9```!P```$9D```/````3F0``"T```!>9```&@```(QD```H
M````IV0```L```#09```#````-QD```C````Z60``"8````-90``*@```#1E
M```@````7V4``$,```"`90``!````,1E```(````R64```L```#290``&@``
M`-YE```G````^64``!(````A9@``(````#1F```7````568```4```!M9@``
M#````'-F```.````@&8```X```"/9@``!````)YF```.````HV8```P```"R
M9@``%P```+]F```.````UV8``!$```#F9@``$P```/AF```6````#&<``#@`
M```C9P``$P```%QG```*````<&<```(```![9P``!0```'YG```-````A&<`
M``D```"29P``#P```)QG```2````K&<```P```"_9P``#0```,QG```3````
MVF<``!4```#N9P``#@````1H```8````$V@``"D````L:```+````%9H```H
M````@V@``#4```"L:```!0```.)H```0````Z&@``!````#Y:```#P````II
M```+````&FD```\````F:0``#````#9I```/````0VD```8```!3:0``"@``
M`%II```2````96D```T```!X:0``#````(9I```.````DVD``$,```"B:0``
M/0```.9I```)````)&H```@````N:@``'@```#=J```A````5FH```,```!X
M:@``"````'QJ```*````A6H``"````"0:@``'P```+%J```;````T6H```@`
M``#M:@``!````/9J```,````^VH```X````(:P``#P```!=K```'````)VL`
M``0````O:P``$@```#1K```*````1VL```@```!2:P``$````%MK```.````
M;&L```H```![:P``1````(9K```'````RVL```@```#3:P``$0```-QK```9
M````[FL```8````(;```!0````]L```$````%6P```P````:;```!````"=L
M```%````+&P``!H````R;```#P```$UL```'````76P``"(```!E;```#0``
M`(AL```$````EFP``!<```";;```!P```+-L```&````NVP```0```#";```
M$0```,=L```B````V6P```8```#\;```%0````-M```,````&6T``!$````F
M;0``#````#AM```*````16T```4```!0;0``#P```%9M```2````9FT```L`
M``!Y;0``)P```(5M```I````K6T``"0```#7;0``)@```/QM```H````(VX`
M`!P```!,;@``%@```&EN```%````@&X``!(```"&;@``"@```)EN```/````
MI&X``!````"T;@``!@```,5N```*````S&X```X```#7;@``"0```.9N```*
M````\&X```8```#[;@``#P````)O```0````$F\``",````C;P``"0```$=O
M```2````46\``!(```!D;P``$````'=O```1````B&\```4```":;P``,0``
M`*!O```D````TF\```\```#W;P``!`````=P```4````#'````P````A<```
M#````"YP```/````.W```!4```!+<```*0```&%P```J````BW```"8```"V
M<```)P```-UP```I````!7$``"H````O<0``$0```%IQ```2````;'$``!,`
M``!_<0``%````)-Q```6````J'$``!<```"_<0``$````-=Q```1````Z'$`
M`!,```#Z<0``$@````YR```/````(7(``"@````Q<@``!@```%IR```&````
M87(```<```!H<@``!0```'!R```6````=G(```0```"-<@``!````))R```'
M````EW(```X```"?<@``#````*YR```,````NW(```T```#(<@``$@```-9R
M```/````Z7(```@```#Y<@``$0````)S```)````%',```X````><P``%@``
M`"US```1````1',```8```!6<P``!````%US```1````8G,``!````!T<P``
M?````(5S```5`````G0``!H````8=```#@```#-T```&````0G0```P```!)
M=```!P```%9T```%````7G0```L```!D=```$P```'!T```3````A'0``!,`
M``"8=````@```*QT```$````KW0``!\```"T=```!P```-1T```B````W'0`
M``T```#_=```!0````UU```&````$W4``",````:=0``)0```#YU```(````
M9'4``#<```!M=0``(@```*5U```3````R'4``!$```#<=0``#P```.YU```/
M````_G4``!<````.=@```P```"9V```*````*G8```L````U=@``!P```$%V
M```3````278```P```!==@``#P```&IV```.````>G8```P```")=@``#@``
M`)9V```/````I78```T```"U=@``#P```,-V```/````TW8```\```#C=@``
M(````/-V```N````%'<``!H```!#=P``)@```%YW```+````A7<```8```"1
M=P``!@```)AW```*````GW<```<```"J=P``!````+)W```)````MW<```<`
M``#!=P``"0```,EW```.````TW<```<```#B=P``!````.IW```$````[W<`
M``<```#T=P``!0```/QW```6`````G@```,````9>```"@```!UX```(````
M*'@```P````Q>```$P```#YX```$````4G@```P```!7>```"0```&1X```"
M````;G@```L```!Q>```,P```'UX```S````L7@``#@```#E>```&0```!YY
M```<````.'D``!\```!5>0``%````'5Y```@````BGD``!(```"K>0``!```
M`+YY```+````PWD```D```#/>0``#0```-EY```,````YWD``!0```#T>0``
M%@````EZ```%````('H```@````F>@``$0```"]Z```\````07H```X```!^
M>@```@```(UZ```'````D'H```P```"8>@``(P```*5Z```-````R7H``!\`
M``#7>@``!P```/=Z```.````_WH```P````.>P``#````!M[```%````*'L`
M`!$````N>P``$P```$![```-````5'L``!P```!B>P``!P```'][```-````
MAWL``"(```"5>P``(0```+A[```'````VGL```@```#B>P``%0```.M[```%
M`````7P``!0````'?```!````!Q\```'````(7P``!X````I?```*````$A\
M```(````<7P``!0```!Z?```!0```(]\```&````E7P``#$```"<?```'```
M`,Y\```G````ZWP``"@````3?0``&@```#Q]```H````5WT``"D```"`?0``
M+@```*I]```V````V7T``"P````0?@``,0```#U^```K````;WX``"$```";
M?@``!P```+U^```A````Q7X``!````#G?@``#0```/A^```%````!G\```X`
M```,?P``"````!M_```3````)'\``#8````X?P``-P```&]_```)````IW\`
M``X```"Q?P``#0```,!_```/````SG\``!8```#>?P``/@```/5_```G````
M-(````L```!<@```'@```&B````+````AX````X```"3@```#@```**````)
M````L8````@```"[@```$````,2````5````U8```!,```#K@```%P```/^`
M```'````%X$``!4````?@0``!@```#6!```+````/($``!8```!(@0``#P``
M`%^!```+````;X$```T```![@0``$````(F!```N````FH$``#H```#)@0``
M#@````2"```-````$X(```4````A@@``#````">"```-````-((```T```!"
M@@``#@```%""```-````7X(```@```!M@@``"@```':"```&````@8(```X`
M``"(@@``%P```)>"```>````KX(``!8```#.@@``!0```.6"```&````ZX(`
M`!0```#R@@``$0````>#``!+````&8,```4```!E@P``$@```&N#```$````
M?H,```X```"#@P``#@```)*#```%````H8,```@```"G@P``$````+"#```(
M````P8,``!(```#*@P``!````-V#```R````XH,```H````5A```#````""$
M```+````+80```<````YA```%@```$&$```Z````6(0``"````"3A```#P``
M`+2$```Y````Q(0```8```#^A```"0````6%```.````#X4```0````>A0``
M!@```".%```6````*H4```T```!!A0``#@```$^%``!#````7H4```H```"B
MA0``-0```*V%```1````XX4```L```#UA0``:0````&&```:````:X8``!<`
M``"&A@``&P```)Z&```7````NH8``!L```#2A@``'P```.Z&```7````#H<`
M``P````FAP``$P```#.'```0````1X<``!$```!8AP``"0```&J'```&````
M=(<``!T```![AP``!P```)F'``!#````H8<```T```#EAP``<````/.'```Y
M````9(@``!````">B```$````*^(```,````P(@``!0```#-B```'0```.*(
M```<`````(D``!$````=B0``/0```"^)```@````;8D``"@```".B0``)0``
M`+>)```@````W8D``"0```#^B0``)````".*```@````2(H``"4```!IB@``
M!0```(^*```%````E8H```8```";B@``!````***```0````IXH``!0```"X
MB@``%````,V*```/````XHH```X```#RB@``$@````&+```<````%(L``"@`
M```QBP``!P```%J+```3````8HL```P```!VBP``%P```(.+```2````FXL`
M``L```"NBP``#0```+J+```4````R(L``"\```#=BP``"@````V,```,````
M&(P```D````EC```#0```"^,```0````/8P```L```!.C```"````%J,```'
M````8XP```T```!KC```!@```'F,```6````@(P```D```"7C```!P```*&,
M```+````J8P```L```"UC```&@```,&,```@````W(P``!````#]C```$```
M``Z-```%````'XT```4````EC0``"0```"N-```*````-8T``!\```!`C0``
M,0```&"-```B````DHT``"````"UC0``,P```-:-```L````"HX``!L````W
MC@``'@```%..``!U````<HX``#X```#HC@``0@```">/```]````:H\``#T`
M``"HCP``*0```.:/```I````$)```#$````ZD```/@```&R0```C````JY``
M`"````#/D```'0```/"0```D````#I$``"@````SD0``%P```%R1```F````
M=)$``!\```";D0``/@```+N1``!'````^I$``#T```!"D@``5P```("2``!5
M````V)(``"\````NDP``50```%Z3```@````M),``"H```#5DP``4@````"4
M```R````4Y0``"L```"&E```)@```+*4```L````V90``$X````&E0``.P``
M`%65```/````D94``"$```"AE0``'````,.5```+````X)4```4```#LE0``
M$````/*5```"`````Y8```H````&E@``$@```!&6```#````))8``!`````H
ME@``%P```#F6```,````498```T```!>E@```P```&R6```O````<)8``"``
M``"@E@``)````,&6```E````YI8``"`````,EP``)@```"V7```*````5)<`
M`!,```!?EP``"````'.7```)````?)<``!8```"&EP``#````)V7```7````
MJI<```X```#"EP``#0```-&7```1````WY<``!H```#QEP``!P````R8```&
M````%)@```L````;F```&@```">8```=````0I@``!,```!@F```$P```'28
M```1````B)@``!X```":F```#````+F8```(````QI@```D```#/F```%```
M`-F8```.````[I@``!````#]F```!`````Z9```'````$YD``"8````;F0``
M)````$*9```A````9YD``!,```")F0``)P```)V9```/````Q9D``"@```#5
MF0``#P```/Z9```@````#IH``!0````OF@``!P```$2:```&````3)H```<`
M``!3F@``"P```%N:```@````9YH``!P```"(F@``6@```*6:```_`````)L`
M`#8```!`FP``"0```'>;```%````@9L``!(```"'FP``"@```)J;```&````
MI9L```P```"LFP``"@```+F;```"````Q)L```8```#'FP```P```,Z;```G
M````TIL``"$```#ZFP``)````!R<``!%````09P``!T```"'G```&0```*6<
M```7````OYP``!D```#7G```*@```/&<```K````')T``$4```!(G0``)@``
M`(Z=```P````M9T``"<```#FG0``(0````Z>```K````,)X``!T```!<G@``
M)@```'J>```M````H9X``"4```#/G@``(@```/6>```]````&)\``$$```!6
MGP``*````)B?```L````P9\``#````#NGP``$@```!^@```3````,J```!``
M``!&H```#@```%>@``!S````9J```$````#:H```*P```!NA```7````1Z$`
M`"H```!?H0``%@```(JA```/````H:$``"@```"QH0``0````-JA```?````
M&Z(```\````[H@``$@```$NB```,````7J(``!````!KH@``$P```'RB```=
M````D*(```\```"NH@``#P```+ZB```$````SJ(```H```#3H@```P```-ZB
M```'````XJ(```L```#JH@``"````/:B```%````_Z(```D````%HP``%```
M``^C```&````)*,```@````KHP``#P```#2C```/````1*,```@```!4HP``
M!@```%VC```)````9*,```\```!NHP``!@```'ZC```'````A:,```T```"-
MHP``%````)NC```'````L*,```,```"XHP``"0```+RC```,````QJ,```H`
M``#3HP``!0```-ZC```$````Y*,```8```#IHP``#````/"C```$````_:,`
M``0````"I````@````>D```'````"J0```8````2I```#@```!FD```/````
M**0```<````XI```!0```$"D```.````1J0```X```!5I```4`$``&2D```*
M````M:4```8```#`I0``"@```,>E```,````TJ4```<```#?I0``!P```.>E
M```'````[Z4```8```#WI0```P```/ZE```2`````J8``!<````5I@``%0``
M`"VF```]````0Z8``"H```"!I@``)0```*RF```:````TJ8``"4```#MI@``
M(P```!.G``!+````-Z<``%````"#IP``'````-2G```5````\:<```4````'
MJ```!@````VH```'````%*@```4````<J```!0```"*H```G````**@```D`
M``!0J```!@```%JH```+````8:@```H```!MJ```!````'BH```3````?:@`
M``\```"1J```"0```*&H```+````JZ@``!4```"WJ```%````,VH```$````
MXJ@```8```#GJ```!@```.ZH```$````]:@```H```#ZJ```!`````6I```%
M````"JD```D````0J0``"````!JI```\````(ZD``#$```!@J0``-````)*I
M```N````QZD``#````#VJ0``!P```">J```>````+ZH```0```!.J@``%@``
M`%.J```7````:JH```8```""J@``"P```(FJ```-````E:H``!D```"CJ@``
M%0```+VJ```;````TZH```,```#OJ@``%@```/.J```>````"JL``"(````I
MJP``&P```$RK```C````:*L``!X```",JP``"0```*NK```(````M:L```@`
M``"^JP``%P```,>K```)````WZL```D```#IJP``#````/.K```W`````*P`
M``@````XK```"0```$&L```$````2ZP```,```!0K```2P```%2L```2````
MH*P```P```"SK```#P```,"L```-````T*P```0```#>K```"0```..L```(
M````[:P```0```#VK```"````/NL```J````!*T```0````OK0``!````#2M
M```$````.:T```D````^K0``!````$BM```$````3:T```L```!2K0``!```
M`%ZM```+````8ZT```P```!OK0``!@```'RM```$````@ZT``",```"(K0``
M)````*RM```$````T:T```D```#6K0``$@```."M```Q````\ZT```0````E
MK@``!````"JN```&````+ZX```<````VK@``!P```#ZN```'````1JX```<`
M``!.K@``!@```%:N```&````7:X```0```!DK@``"0```&FN```+````<ZX`
M`"L```!_K@``&P```*NN```T````QZX```X```#\K@``%P````NO```<````
M(Z\```0```!`KP``"0```$6O```5````3Z\``!0```!EKP``1````'JO```D
M````OZ\``",```#DKP``*P````BP```H````-+```"8```!=L```*P```(2P
M```@````L+```"P```#1L```(@```/ZP```'````(;$```<````IL0``"P``
M`#&Q```$````/;$```D```!"L0``$````$RQ```+````7;$```T```!IL0``
M"P```'>Q```$````@[$```,```"(L0``!@```(RQ```$````D[$```P```"8
ML0``$P```*6Q``!-````N;$``!P````'L@``"0```"2R```.````+K(``!L`
M```]L@``(@```%FR```$````?+(```0```"!L@``#P```(:R```$````EK(`
M``L```";L@``*P```*>R```&````T[(``!````#:L@``$@```.NR```+````
M_K(``!8````*LP``%````"&S```4````-K,``"X```!+LP``"@```'JS```+
M````A;,``"\```"1LP``'````,&S```&````WK,```8```#ELP```@```.RS
M```$````[[,```0```#TLP``!````/FS```)````_K,```0````(M```!```
M``VT```(````$K0```L````;M```#P```">T```.````-[0```8```!&M```
M#0```$VT```2````6[0```<```!NM```!P```':T```D````?K0``"(```"C
MM```'P```,:T```'````YK0```P```#NM```#````/NT```&````"+4```L`
M```/M0``%````!NU```3````,+4```@```!$M0``"0```$VU```*````5[4`
M`"H```!BM0``%````(VU```(````HK4```D```"KM0``"0```+6U```F````
MO[4``!0```#FM0``'@```/NU```$````&K8```T````?M@``%0```"VV```G
M````0[8``"<```!KM@``$````).V``!#````I+8```0```#HM@``"````.VV
M```+````]K8``!\````"MP``(````"*W```/````0[<``!\```!3MP``&```
M`'.W```(````C+<```L```"5MP``"P```*&W```,````K;<```0```"ZMP``
M$@```+^W```)````TK<```P```#<MP``$@```.FW```.````_+<``!(````+
MN```#@```!ZX```P````+;@``!(```!>N```!P```'&X```"````>;@```8`
M``!\N```"P```(.X```(````C[@```L```"8N```#P```*2X```1````M+@`
M``D```#&N```#0```-"X```,````WK@```L```#KN```#0```/>X```9````
M!;D``!D````?N0``%P```#FY```?````4;D```0```!QN0``!````':Y```(
M````>[D```<```"$N0``"P```(RY```(````F+D```@```"AN0```P```*JY
M```$````KKD```D```"SN0``%````+VY```+````TKD```D```#>N0``#0``
M`.BY```C````]KD``#$````:N@``"````$RZ```&````5;H``!,```!<N@``
M$P```'"Z```$````A+H```,```")N@``$0```(VZ```<````G[H``!X```"\
MN@``&P```-NZ```&````][H```0```#^N@``"P````.[```-````#[L```D`
M```=NP``!````">[```$````++L```@````QNP``"````#J[```&````0[L`
M``T```!*NP``"P```%B[```)````9+L``"0```!NNP``!````).[```%````
MF+L```L```">NP``%````*J[```&````O[L```H```#&NP``"````-&[```-
M````VKL```4```#HNP``!0```.Z[```2````]+L```T````'O```!````!6\
M```E````&KP```L```!`O```!````$R\```)````4;P```8```!;O```!```
M`&*\```&````9[P```8```!NO```'@```'6\```&````E+P``!,```";O```
M$@```*^\```9````PKP```<```#<O```"P```.2\```%````\+P```8```#V
MO```"0```/V\```%````![T``"@````-O0``$P```#:]```.````2KT``!,`
M``!9O0``%0```&V]```:````@[T``!,```">O0``"@```+*]```.````O;T`
M``8```#,O0``#0```-.]```,````X;T```0```#NO0``"0```/.]```.````
M_;T```@````,O@``"0```!6^```(````'[X```T````HO@``$P```#:^```<
M````2KX```8```!GO@``"P```&Z^```/````>KX```P```"*O@``$````)>^
M```*````J+X``"<```"SO@``'@```-N^```(````^KX```0````#OP``$```
M``B_```)````&;\```<````COP``#````"N_```.````.+\``!<```!'OP``
M%P```%^_```7````=[\``!<```"/OP``&````*>_```8````P+\```P```#9
MOP``#````.:_```,````\[\```P`````P```#@````W````.````',````P`
M```KP```#````#C````.````1<````X```!4P```"P```&/````6````;\``
M``D```"&P```"````)#````#````F<````0```"=P```%````*+````#````
MM\````,```"[P```!````+_````+````Q,````D```#0P```"0```-K````+
M````Y,````@```#PP```#P```/G````$````"<$```T````.P0``#0```!S!
M```1````*L$``"`````\P0``$P```%W!```(````<<$```0```!ZP0``$P``
M`'_!```+````D\$``&0```"?P0``$0````3"```;````%L(```X````RP@``
M!@```$'"```+````2,(```@```!4P@``!@```%W"```/````9,(```T```!T
MP@``"P```(+"```0````CL(```(```"?P@``!````*+"```7````I\(```8`
M``"_P@``$````,;"```0````U\(```,```#HP@``"````.S"```B````]<(`
M`"<````8PP``"@```$##```H````2\,``"<```!TPP``&P```)S#```0````
MN,,``!4```#)PP``#0```-_#```2````[<,```,`````Q```"0````3$```)
M````#L0```0````8Q```"0```!W$```)````)\0```T````QQ```"0```#_$
M```)````2<0```T```!3Q```"0```&'$```)````:\0```8```!UQ```"0``
M`'S$```)````AL0``"$```"0Q```.0```++$```?````[,0``!D````,Q0``
M"P```";%```&````,L4```0````YQ0``"````#[%```$````1\4```0```!,
MQ0``"P```%'%```)````7<4```L```!GQ0``#P```'/%```)````@\4```0`
M``"-Q0``!````)+%```(````E\4```T```"@Q0``$0```*[%```'````P,4`
M``D```#(Q0``!P```-+%```'````VL4```T```#BQ0``!````/#%```)````
M]<4```L```#_Q0``!@````O&```)````$L8``",````<Q@``'````$#&```A
M````7<8``!,```!_Q@``&@```)/&```A````KL8```X```#0Q@``%0```-_&
M```.````]<8```X````$QP``#0```!/'```-````(<<```T````OQP``#0``
M`#W'```2````2\<``!(```!>QP``!````'''```$````=L<```<```![QP``
M-@```(/'```'````NL<```0```#"QP``!````,?'```)````S,<``#$```#6
MQP``"P````C(```1````%,@```@````FR```"P```"_(```)````.\@```0`
M``!%R```!````$K(```)````3\@```X```!9R```"0```&C(```:````<L@`
M``0```"-R```#@```)+(```C````H<@``",```#%R```!````.G(```$````
M[L@``!D```#SR```!@````W)```3````%,D```0````HR0``!@```"W)```3
M````-,D``!P```!(R0``"````&7)```)````;LD```@```!XR0``!````(')
M```D````ALD``!0```"KR0``'@```,#)```>````W\D``!4```#^R0``(0``
M`!3*```>````-LH``"8```!5R@``'0```'S*```I````FLH``"(```#$R@``
M)````.?*```G````#,L```@````TRP``$````#W+```)````3LL```L```!8
MRP``!````&3+```)````:<L```@```!SRP``"0```'S+```F````ALL``"(`
M``"MRP``"0```-#+```2````VLL``!````#MRP``#0```/[+```;````#,P`
M`#D````HS```)````&+,```)````A\P``!````"1S```"@```*+,```*````
MK<P```@```"XS```"P```,',```)````S<P```D```#7S```"0```.',```/
M````Z\P``!````#[S```"0````S-```1````%LT```D````HS0``"0```#+-
M```0````/,T```P```!-S0``#P```%K-```+````:LT``!````!VS0``*@``
M`(?-```U````LLT```T```#HS0``#````/;-```$`````\X```D````(S@``
M"@```!+.```+````'<X```P````IS@``"P```#;.```%````0LX```4```!(
MS@``!0```$[.```)````5,X```L```!>S@``#@```&K.```)````><X```@`
M``"#S@``!@```(S.```<````D\X``!4```"PS@``,@```,;.```&````^<X`
M``P`````SP``!`````W/```'````$L\```<````:SP```P```"+/```&````
M)L\``!0````MSP``$@```$+/```2````5<\```0```!HSP``(P```&W/```1
M````D<\```T```"CSP``$0```+'/```1````P\\``"````#5SP``*````/;/
M```C````']```!$```!#T```(P```%70```$````>=````<```!^T```"0``
M`(;0```$````D-````D```"5T```#@```)_0```)````KM````D```"XT```
M)````,+0```)````Y]```!P```#QT```"0````[1```)````&-$``#L````B
MT0``$P```%[1```.````<M$``!,```"!T0``#@```)71```9````I-$``!\`
M``"^T0``#@```-[1```+````[=$``!@```#YT0``"@```!+2```+````'=(`
M``,````IT@``!````"W2```2````,M(```4```!%T@``'0```$O2```+````
M:=(``&D```!UT@``)P```-_2```0````!],``!`````8TP``$````"G3```0
M````.M,``!8```!+TP``%@```&+3```9````>=,``"L```"3TP``&0```+_3
M```F````V=,```X`````U```#@````_4```.````'M0``"(````MU```$```
M`%#4```C````8=0```@```"%U```!@```([4```(````E=0```0```">U```
M#0```*/4```-````L=0```X```"_U```"0```,[4```-````V-0```T```#F
MU```!@```/34```:````^]0```0````6U0``#0```!O5```+````*=4```X`
M```UU0``"0```$35```)````3M4```L```!8U0``#@```&35```E````<]4`
M``<```"9U0``!P```*'5```'````J=4```@```"QU0``#0```+K5```+````
MR-4```8```#4U0``!````-O5```$````X-4```0```#EU0``#P```.K5```(
M````^M4```0````#U@``!`````C6```&````#=8``!0````4U@``%@```"G6
M```'````0-8```<```!(U@``!````%#6```&````5=8```0```!<U@``"0``
M`&'6```8````:]8``"(```"$U@``&@```*?6```<````PM8``"4```#?U@``
M+@````77```>````--<``!X```!3UP``;P```'+7```P````XM<``#D````3
MV```,````$W8```N````?M@``!T```"MV```&P```,O8```B````Y]@``"T`
M```*V0``'@```#C9```<````5]D```L```!TV0``&@```(#9```6````F]D`
M``D```"RV0``'````+S9```?````V=D``!D```#YV0``'0```!/:```_````
M,=H``#$```!QV@``+P```*/:```.````T]H``"P```#BV@``$`````_;```1
M````(-L``"8````RVP``$@```%G;```4````;-L``!````"!VP``(P```)+;
M``!)````MML``#@`````W```#0```#G<```I````1]P``!@```!QW```"0``
M`(K<```$````E-P```T```"9W```"````*?<```-````L-P```X```"^W```
M`@```,W<```1````T-P``!(```#BW```"@```/7<```+`````-T```,````,
MW0``+0```!#=```>````/MT``!L```!=W0``)````'G=```H````GMT``"$`
M``#'W0``#0```.G=```2````]]T```0````*W@``!`````_>```0````%-X`
M`!$````EW@``$````#?>```$````2-X```0```!-W@``$0```%+>```5````
M9-X```D```!ZW@``"````(3>```)````C=X``!0```"7W@``%@```*S>```-
M````P]X``!````#1W@``"P```.+>```=````[MX```\````,WP``"````!S?
M```)````)=\``!`````OWP``"0```$#?```)````2M\```0```!4WP``!P``
M`%G?```8````8=\``!,```!ZWP``$P```([?```.````HM\``!,```"QWP``
M"0```,7?```B````S]\```L```#RWP``'P```/[?```/````'N````0````N
MX```!````#/@```$````..````X````]X```%P```$S@```7````9.```#\`
M``!\X```-@```+S@```M````\^````@````AX0``!````"KA```)````+^$`
M``D````YX0``!0```$/A```*````2>$```T```!4X0```@```&+A```$````
M9>$```(```!JX0``(@```&WA```8````D.$``!@```"IX0``/0```,+A```2
M`````.(``!H````3X@``&0```"[B```4````2.(``",```!=X@``(P```('B
M```^````I>(``!8```#DX@``*0```/OB```C````)>,``!P```!)XP``%P``
M`&;C```2````?N,``"4```"1XP``(0```+?C```E````V>,```\```#_XP``
M*`````_D```M````..0``!D```!FY```(````(#D```L````H>0```P```#.
MY```"@```-OD```$````YN0```4```#KY```<P```/'D```L````9>4``"<`
M``"2Y0``#````+KE```@````Q^4```P```#HY0``"@```/7E```A`````.8`
M`!\````BY@``%@```$+F```%````6>8```T```!?Y@``"P```&WF```/````
M>>8```P```")Y@``$P```);F```.````JN8```8```"YY@``"@```,#F```*
M````R^8```8```#6Y@``"````-WF```)````YN8```@```#PY@``!@```/GF
M```(`````.<```X````)YP``#````!CG```*````)><```\````PYP``#@``
M`$#G```*````3^<```8```!:YP``"````&'G```-````:N<```8```!XYP``
M!@```'_G```-````AN<```P```"4YP``"````*'G```*````JN<```8```"U
MYP``"@```+SG```*````Q^<```8```#2YP``!````-GG```#````WN<```L`
M``#BYP``!````.[G```$````\^<```0```#XYP``!@```/WG```$````!.@`
M``D````)Z```"0```!/H```)````'>@```4````GZ```#````"WH```,````
M.N@```$```#A`@``E@$``(P!``#Z````L@(``$`#```/`0``50,``(L"````
M`````0$``&("```A`0``M0(``/P```#"`0```````-$```!Y`0``````````
M````````D@$``#@!``!!````Q0````````!"`@``?P(```````#%`@``````
M```````,`@``ZP$``#\!``#$`@``Z0```+<!````````(0,```````#8````
M1@(``+``````````$`````````":`P``L`$```````!9`@```````#<!```J
M`````````%<!```U`@``2@,```````!F`P``M@(`````````````U@```"T!
M````````JP(`````````````+@(``.T"```?`0````````````!;`0``80(`
M`-L"``!'`P````````````#\`@``IP````````"B````ZP```+P```!E`@``
ME0,````````O`@``8`,`````````````,P(``"`#```G`0``(0```+4```"X
M````2@(```````#X`@``[@$``#4```#-`0```````-0"```1`P``:`(``'X!
M``!0`P``_P````````!^`````````,X````8````?`$``*P```!_````6P``
M`&L!```>`P``8P(```````!S`P``3`,``/4``````````````(\"``#S`@``
MY````````````````````)T"``">`0``-`,```D"````````5`$``,D!``!#
M`0``00(`````````````E0(``&,!``!J`0``)0,``#X````-````X@$`````
M``"]````;@,````````J`@```````,,!````````*````/L"```\`P``````
M```````U`0``H0```)0"``!%`0``EP(``/0"````````00$```0"``"T`0``
M\````&8"```/`P``'````'0```"$`@``7`(``*$"``!3`@``B@(`````````
M````J`,``*@"``#&`0`````````````L`````````-`"```,````J0(``!T`
M``"N`0``[0$```````!8`0``:@,``'L"``"J`@``30,``(\#``!\````50$`
M```````2`P``"P(``.,!``"#`P``6P(``-,"``!9`0``R@(``"P!``#R`0``
M`````-D````.`@``*P,```L#``"A`0``S0(``-(!````````-0,```````!4
M`@``>@```+0"```@`@``N0$````````(`````````$8```!^`@``````````
M```L`P``3````(,"``!O`0``XP(``&0```##`@``K@(``+D`````````````
M`)L```"V````^@$````````6````E@(`````````````G````'T"``"=````
M`````*0"``">`P``F@$``#@```!%`@```@````````"(`````````"<"```W
M`@``[`(```````!R`@``SP````<```!7`P```````%T#```]`@``;0,``,0`
M``!M`0``3@,``'T`````````B0$````````@`0``BP```.4!````````X@``
M`#(```!)`0```````#0`````````[`$``'D#``!>````<`$``"0!``#U`@``
M`````#X!```3`0``!0$````````B`P``!@$``(D"```D````U`$``)8```!Q
M`@```````(<!````````P`(``!\```"M`@```````+H!````````````````
M``"K`````````)(#````````S````%,```"3````@`$``',"```C`0``\`(`
M``````!.`@``P0``````````````@0(``/$"````````0P```'H#``#X````
M?0,``.<!```6`@`````````````%````$0$``!T!``"#`0````````X!````
M`````````&0!``#U`0``4@(```````!``@``_P$``#X#``"-`0```````$`!
M```%`P``%0$``,T``````````````&<```"8`@``EP,``+L"``"A`P``R`$`
M`!D```#+````#0,``(D```#1`0``10`````````[`@``@`,``'<!``!#`@``
M$@```%(`````````0@$``"8#``!]`0``%P$``*<"``#/`@``````````````
M``````````````!<`P```@$``$H!```X`@``:@(``!L"``"M`0``````````
M``!B`P````,``)4`````````F`$``-8"``!1````%0```'4"``#?`@``````
M`!\"``#V`@``B@`````````_`P``$`(``)`"````````C@(````````3`@``
M=@$``/T"``"I`P``W`(``.,`````````C`(```\"``!O````4P$``,0!``"'
M`P``O@(``!<#```'`@```````(8"``""````.@```!,#``!*````D0,`````
M``#T`0```````'8#``!8`````````)D"``#]`0`````````````8`P``90,`
M`(\```"J`````````-`!``"C`P```````,@"````````8`$``&P"``!F````
M`0(``&L#``#N`````````*8````Y`P``V@(``"0#``"J`0``!P,``#`"``#F
M`0``5P```/\"``!6`````````+@!``!2`P``Z@```#P`````````^0$`````
M``">`@``/P(```````"0````/`$``-D!``"4`P``Z0(``%\!``!+`@``^0(`
M`'8```#&````F0$`````````````D0```%$#````````=P,`````````````
M`````&\#``"3`0``Y0(```````#>`@``K@```+8!``"L`0````````````"-
M`@``K`,```````"O`0``=`(``)$!``#5`@``*`,``&D!``#@````I0$``"P"
M```4`@``I`,``($```#H````````````````````WP$`````````````]```
M`$,#````````>P,```L```!F`0``B@,``#D!```)````9P$``(4!```Y`@``
M@`````````#]````S@$``-T`````````"@,``($#``"^`0``D`$``*,!``";
M`P``A`,```````!H```````````````3````U````+<"``!?````````````
M``"4`0``Z0$``),"````````U0$``($!```=`@```````/8```!"````*@$`
M``````!U`0```````'$#```I`P``A@,``+T!```V`0``7@$``!8#``#2````
M`````%<"``"E`P``G`(``(@"``!(`@```````.$```#W````#P```+X````-
M`@``-@```&X````T`0``V0(``%X"``":````D@(`````````````<@,`````
M````````-@,``(L!````````LP(``$D````````````````````2`0``3P,`
M`-@"``"C`````````'@"```[`0``"P$``%@"``#G`@``````````````````
MUP(``%4`````````)0(```P#```I`0```````#H"``"F`P``FP$``/$```!R
M````4@$``%T!```D`@``!0(``*<!``!%`P``+0```!P"```S`0``+0(`````
M``!M````J0``````````````,@(``+@"````````)@(``/X!``#:````(@$`
M``````!M`@``+@$``$\"``#E`````````"(```"<`0``1`$``#,````R`P``
M,`,``#<#``"L`@``.P,```,#``"@````5@$````````#`@```````(@#```0
M`P``/0,```````!C`P```````.@!````````.@,``(<"```9`@``%0(``&H`
M``#0````W```````````````C0```%,#``!-`0``JP$``&$#```>`0``````
M``````#[`0``@@,```````!'`0```````*8!``!D`@`````````````Q`0``
M(P,``,,```"B`0``N@(```````"``@``H`,```````!Y`@``-`(``'`"```(
M`@``7`$``-<!``#,`0``8@$``*L#````````>@(``"X```#F````8@``````
M``!P````#@,```````!>`P``2`,``+\```!1`0```````!X"``#S`0``SP$`
M`-X```!@`@``@P```*T```!/`0``2`$````````````````````````F`0``
M4`(`````````````_@(``-("``#R`@``HP(``)\```!&`P``:`$``/<!````
M````*@,```````!A`0``%`,``!X```""`0``)@```+<```!$`@``E0$``&``
M````````J0$``*\"``"J`P``2P,``,L!``!$`P```````)D```"/`0``BP,`
M`.\`````````*0```!$`````````20,``&X!```P`````````'\!``#M````
M>`````````!L`0``]@$``!H```!K`@``````````````````+P$``'4````;
M`P```````!8!``#W`@``FP(``,X"````````)P,``#<`````````&P$``$P"
M``#``0``R@$``*8"``"H`0``A@$```````!O`@``Q@(````````K````````
M`'$````"`@``(P```%`!````````W@$```````!E`0``^0```,L"````````
M`````),#``!C````N0(``*4"````````GP(``-L!```B`@```````#T!``!`
M````=@(``*`!``!I````(````+\!```#````?@,```D!`````````````%T`
M````````=P(`````````````J````(@!``#"`@```````%D#``"Q`@``L0$`
M`'$!````````L`(``$0```"R`0``80```-<````R`0``!````"X#```Y````
M-@(`````````````'0,```X````$`P```````,<"````````7````,H`````
M`@````````````")`P```````',!``!+````7P(````````Z`0``/0```,(`
M``"7````M````)$"````````P0(``%4"```P`0``"`$```````"S`0``"0,`
M`(<```#1`@``*P(``%T"````````/`(``&D"``"B`@``9P,`````````````
M`P$``#$```#%`0``(P(``)0````[````*`(``!P#````````&`$```````!W
M````A````-4```````````````````#`````;@(``%8#```5`P``KP```)H"
M``"-`P```````!D#``#@`@````````````!'````````````````````^`$`
M`'4#``!&`0``;````(4"````````NP$``-,!``"=`P````````0!``!.`0``
M+P```%L#```A`@```````%H#``"]`@``6@$```H"``!!`P``````````````
M``````$```````"8`P``Z@(``+$```#K`@``S`(``)X`````````I0````H!
M``#O`0``,0(``!H"``!T`P``A@```)`#```K`0``/P```.0!````````&0$`
M``````"U`0``90```'L`````````,P,``,@```"\`0``&@,``-H!```X`P``
M1P(``'(!``#8`0```````-T"```8`@```````%8"````````;`,``*<#``!K
M````^@(```8```!\`@````````````",`P``6`,````````:`0``0@,`````
M``!I`P``QP$``%H"``#S````%P````````!D`P``A`$```H`````````W`$`
M``````"B`P``!@(``/P!```!`P``Y`(``'\#````````LP````````"M`P``
M30```*`"``#[`````````-\````M`P```````)D#``#O`@``$`$``+H```"\
M`@``C`````````!X`P````````````"<`P``W0$`````````````X@(``.P`
M``!T`0``@@(``&<"``"?`P```````(X!``"%`P``D@```.H!``"[````4```
M`)<!``#Q`0```````,$!`````````````)T!````````)0```$X````2`@``
M``````````!S````C@````@#``!4````>0```$P!````````OP(`````````
M````%P(``,<```!)`@```````#$#``#F`@```@,````````&`P``)P```.<`
M``"?`0``#`$```````#@`0````````````!H`P``X0$``%$"````````````
M`$L!```I`@```````'L!```'`0``U@$``$@```"6`P``$0(```````#^````
M?`,``/`!`````````````!P!``#N`@```````'H!``"R````60`````````4
M`0``+P,``'@!``#;````*`$```T!``"8````\@````````#3````)0$``*0!
M```4`````````'`#``!-`@``&P```#X"``````````````````!/````A0``
M`%0#``"*`0``I````(X#````````'P,``,D"``#)````Z`(``%\#``!:````
M`"`@("`@(%1O.B``("`@($1A=&4Z(``@("`@1G)O;3H@`"`H06-C97-S:V5Y
M("5S*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(%-U8FIE
M8W0Z(``@:6X@`"5D('1O("5D(&]F("5D($UE<W-A9V5S`"5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@86QR96%D>2!E>&ES
M=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T
M(')E;F%M960N`"5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA
M:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O
M9B!T:&4@;6]N=&@N`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*0`H07!P
M;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C<F5E;BXI`"A$
M:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@
M<V-R965N+BD`*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@
M87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@
M;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*0`H
M4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@
M=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL
M($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@
M*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`Q,#`@8VAA<F%C=&5R
M<P`Q,#`P(&-H87)A8W1E<G,`,C0@:&]U<G,`,C4P(&-H87)A8W1E<G,`-3`P
M(&-H87)A8W1E<G,`02!L87)G92!I;6%G92!N86UE9"`E<R!I<R!A='1A8VAE
M9"!T;R!T:&ES(&UE<W-A9V4N`$%-+U!-`$%.1`!!8F]U="!T:&ES(&5D:71O
M<@!!8V-O=6YT)W,@;F%M93H`061D`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I
M<@!!9&0@<V]U<F-E`$%D9"!U<V5R`$%D9&5D("(E<R(@87,@86X@871T86-H
M;65N="X`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!9&1R97-S($)O;VMS`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%L
M:6=N`$%L:6=N;65N=#H`06QL`$%L;"!F;W5R('-I9&5S`$%L;"!M97-S86=E
M<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D
M960@:6YT;R!O;F4@34)/6"!F:6QE.@!!;&P@;65S<V%G97,@:6X@>6]U<B`B
M)7,B(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE
M;G1L>2!D96QE=&5D+@!!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N`$%L;"!O;&0@
M<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL
M;"!B92!D96QE=&5D+@!!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE
M9"!I;B!A;GD@;6%I;&)O>#\`06QT97)N871E('1E>'0Z`$%L=&5R;F%T:79E
M('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ`$%L=V%Y<P!!;'=A>7,@<V%V92!A
M='1A8VAM96YT<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M<W=E<F5D`$%N<W=E<F5D(&UE<W-A9V5S`$%P<&QY($9I;'1E<G,`07!P;'D@
M1FEL=&5R<R!T;R`E<P!!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG
M(&]N/P!!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES
M<&QA>65D/P!!<')I;`!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI
M<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T
M92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%
M4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_`$%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE
M<W-A9V5S/P!!<G)I=F%L(%1I;64`07-C96YD:6YG`$%S:P!!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\`071T86-H`$%T=&%C:"!&:6QE<P!!='1A8VAE9"!&:6QE.@!!='1A8VAE
M9"!F:6QE("(E<R(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET
M<RX@1FEL92!.3U0@871T86-H960N`$%T=&%C:&UE;G0`071T86-H;65N=',`
M071T96YT:6]N`$%U9W5S=`!!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN
M($A434P@;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY(&%D9')E
M<W-B;V]K/P!!=F%I;&%B;&4@061D<F5S<R!B;V]K<SH`079A:6QA8FQE(&9I
M96QD<SH`0F%C7VL@=&\@)7,`0F%C:R!T;R`E<P!"86-K9W)O=6YD`$)A8VMG
M<F]U;F0@0V]L;W(`0F-C`$)I<G1H9&%Y`$)L86-K;&ES=`!";&]C:R!I;6%G
M97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A
M;&QY(')E<75E<W1E9#\`0F]D>0!";VQD`$)O<F1E<@!";W)D97(@=&AI8VMN
M97-S.@!";W)D97)S`$)O=&@`0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D
M>2!O9B!-97-S86=E`$)O='1O;0!"=6QL971E9"!,:7-T`$-?96QL(%!R;W!E
M<G1I97,N+BX`0U]H87)S970`0V%L96YD87(`0V%N(&YO="!C;VYN96-T('1O
M('1H92!R96UO=&4@;6%I;"!S97)V97(N`$-A;B!N;W0@8V]N;F5C="!T;R!T
M:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B``0V%N8V5L`$-A;F-E;"!-97-S86=E
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YC96QL:6YG('1H:7,@;65S<V%G
M92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+@!#87!T
M:6]N`$-C`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E
M;G1E<@!#:&%N9V4`0VAA;F=E($%L;`!#:&%N9V4@1F]L9&5R`$-H86YG92!D
M:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@
M<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W(&UE<W-A9V5S(&%R92!S;W)T960N
M`$-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+@!#:&%N
M9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P
M;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL
M+@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL
M`$-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\`0VAI
M;F$`0VAO;W-E($%C=&EO;CH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I`$-L96%R($U33V9F:6-E('1A9W,`0VQI8VL@)7,@
M=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@
M8G)O=W-E<B!C86X@=FEE=RX`0VQI8VL@)7,@=&\@9&]W;FQO860@=&AE(&EM
M86=E+@!#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M96YT('!A9V4N`$-L
M:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN
M9&]W+@!#;&EC:R`E<R!T;R!V:65W(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA
M9V4N`$-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A
M<F%T92!W:6YD;W<N`$-L:6-K("5S('1O('9I97<@=&AI<R!M=6QT:7!A<G0O
M<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R!H97)E
M('1O(%-(3U<@=&AE($EM86=E<P!#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W
M:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R`$-L:6-K
M:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B
M92!R96%D`$-L;W-E(%=I;F1O=P!#;&]S92!T:&ES('=I;F1O=P!#;&]S960@
M1F]L9&5R`$-O;&QA<'-E`$-O;&QA<'-E($%L;`!#;VQL87!S92!!;&P@1F]L
M9&5R<P!#;VQL87!S92!&;VQD97(`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S
M960@8F]R9&5R<P!#;VQO<@!#;VQS.@!#;VUI8W,`0V]M<&%N>0!#;VUP;W-E
M(&%N;W1H97(@;65S<V%G90!#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A
M=&4@=VEN9&]W/P!#;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@
M8GD@9&5F875L="`H:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@9F5A='5R92D_
M`$-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I<W!L87EE9"X`0V]N9FER
M;2!087-S=V]R9`!#;VYN96-T:6]N('1O('-E<G9E<B!F86EL960`0V]N=')O
M;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T
M:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U('=H96X@:70@87)R:79E<RX`0V]N
M=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/P!#
M;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'D@=&\@9F]L9&5R`$-O<G)E8W0`0V]R
M<F5C=&5D(%1E>'0`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,`0W)E871E`$-R96%T92!&;VQD97(`0W)E871E(%9I<G1U86P@
M1F]L9&5R`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&1R869T<R!F;VQD
M97(`0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(`0W)E871E(&$@;F5W
M('1R87-H(&9O;&1E<@!#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N
M:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L
M(&%N9"!D96QE=&4@<W!A;2X`0W5R<F5N="!54DP@:7,`0W5R<F5N="!S='EL
M90!#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O;2!O
M=&AE<B!A8V-O=6YT<RX`0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+@!#
M=70`0W5T('-E;&5C=&EO;@!$1`!$86EL>0!$871?90!$871E`$1E7VQE=&4@
M0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E
M;G0`1&5F875L="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z
M`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T90!$96QE=&4@1F]L
M9&5R*',I`$1E;&5T92!6:7)T=6%L($9O;&1E<@!$96QE=&4@8V5L;`!$96QE
M=&4@8V]L=6UN`$1E;&5T92!F971C:&5D(&UE<W-A9V5S(&9R;VT@<F5M;W1E
M('-E<G9E<C\`1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G
M:6YN:6YG(&]F(&UO;G1H/P!$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S
M(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(')O=P!$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E
M9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T960@=&AE(&%T=&%C:&UE;G0@(B5S
M(BX`1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$97-C96YD:6YG`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I;2!S:6=N871U
M<F5S/P!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA
M>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_`$1I<W!L
M87D@:6X@0F]D>2!O9B!-97-S86=E`$1I<W!L87D@<&]P+75P(&YO=&EF:6-A
M=&EO;B!O9B!N97<@;6%I;#\`1&ES<&]S:71I;VX`1&\@3D]4(&UA=&-H`$1O
M($YO="!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O(&YO="!G96YE<F%T92!A
M(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;@!$;R!Y;W4@=V%N="!T;R!O<&5N
M('1H870@9F]L9&5R/P!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@
M9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;F4`1&]W
M;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870`
M1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I`$1O=VYL
M;V%D($9O;&1E<BAS*0!$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T
M70!$;W=N;&]A9"!I;B`N>FEP($9O<FUA=`!$<F%F=`!$<F%F="!F;VQD97(`
M1')A9G1S(&9O;&1E<CH`12UM86EL($%D9')E<W,`161I=`!%9&ET($)L86-K
M;&ES=`!%9&ET($9I;'1E<G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I
M="!7:&ET96QI<W0`161I="!O<'1I;VYS(&9O<CH`161I="!Y;W5R(&)L86-K
M;&ES=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D:70@>6]U<B!P<F5F97)E
M;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N`$5D:70@
M>6]U<B!W:&ET96QI<W0`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R
M97-S`$5M;W1I8V]N<P!%;7!T>2!&;VQD97(H<RD`16UP='D@5')A<V@@9F]L
M9&5R`$5M<'1Y(%]4<F%S:`!%;7!T>2!R97-U;'0N`$5N8W)?>7!T:6]N($]P
M=&EO;G,`16YD(&9O<G=A<F1E9"!M97-S86=E`$5N;&%R9V4@161I=&]R`$5N
M=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@<V5N="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@=')A<V@@9F]L9&5R`$5N=')Y("(E<R(@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K`$5R<F]R`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AP86YD`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N
M9"!&;VQD97(`17AP86YD($YA;65S`$5X<&%N9"!3:61E8F%R`$5X<&%N9"!N
M86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T
M:&4@8F%C:V=R;W5N9#\`17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@
M8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/P!%>'!A;F1I;F<`1D<@
M0V]L;W(`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`1F5B<G5A<GD`1F5T8V@@
M36%I;`!&971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!&971C:"!M
M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_`$9E=&-H;6%I;#H@;F\@;F5W(&UE
M<W-A9V5S+@!&:5]L=&5R<P!&:6QE`$9I;&4@36%N86=E<@!&:6QT97(@3W!T
M:6]N<P!&:6QT97(@4V5T=&EN9W,`1FEL=&5R<P!&:6YD`$9I<G-T($UA:6QB
M;W@@4&%G90!&:7)S="!086=E`$9O7W)W87)D`$9O;&1E<B!.879I9V%T;W(`
M1F]L9&5R(%-U;6UA<GD`1F]N="!#;VQO<@!&;W)M870@;V8@;65S<V%G92!D
M871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T
M;V1A>0!&;W)W87)D`$9O<G=A<F0Z`$9O<G=A<F1E9"!M97-S86=E`$9O<G=A
M<F1E9"!M97-S86=E(&9R;VT@)7,`1G)A;65S`$9R;U]M`$9R;VT`1G)O;2!!
M9&1R97-S`$9W9#H`1G=D.B``1G=D.B`E=2!&;W)W87)D960@365S<V%G97,`
M1V5N97)A;"!/<'1I;VYS`$=E<FUA;GD`1V5T(&]N;'D@;F5W(&UE<W-A9V5S
M/R`H24U!4"!O;FQY*0!';R!T;R!-97-S86=E`$A%4D4`2%1-3"!697)S:6]N
M(&]F($UE<W-A9V4`2&5A9&5R<P!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D
M:71O<@!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9&1E
M;@!(:61D96X@:6X@5&AR96%D(%9I97<`2&ED92!$96QE=&5D`$AI9&4@56YS
M=6)S8W)I8F5D`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO<FEZ
M;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W
M(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_`$AO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I
M96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@=&\@871T<FEB=71E('%U;W1E9"!L
M:6YE<R!I;B!A(')E<&QY`$E-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RD`
M24U!4"]03U`S($UA:6P@4V5R=F5R<P!)3D)/6`!)7VYS97)T(%)O=R!"969O
M<F4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE
M.@!)9VYO<F4`26=N;W)E($%L;`!);6%G92!0<F5V:65W.@!);6%G92!54DP`
M26UA9V4@55),.@!);7!O<G0`26UP;W)T($UE<W-A9V5S`$EM<&]R="!M8F]X
M($9I;&4`26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RX`26UP
M;W)T86YT`$EM<&]R=&%N="!M97-S86=E<P!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F)O>`!);F-L
M=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_
M`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/P!);F-R96%S
M92!);F1E;G0`26YF;P!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA
M9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M
M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&-E;&P@
M869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`
M26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T('!A<F%G<F%P:"!A9G1E<@!)
M;G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R
M="!R;W<@8F5F;W)E`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF
M>2!,:6YK`$EN=F%L:60@061D<F5S<P!);G9A;&ED(&-H87)A8W1E<B!I;B!E
M+6UA:6P@861D<F5S<SH@)7,N`$EN=F5R=`!)=&%L:6,`2F%N=6%R>0!*87!A
M;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$QA
M;F=U86=E`$QA<W0@36%I;&)O>"!086=E`$QA<W0@4&%G90!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA>6]U=`!,969T`$QI7VYK($%T=&%C:&UE;G1S`$QI<W0@2&5L<"!4;W!I
M8W,`3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT86-T
M<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@;VYL>2!S964@8V]N
M=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*0!,:7-T:6YG
M(&EN('1H92!(96%D97(`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]C
M86P@36%I;&)O>#H`3&]G(&EN`$QO9R!I;B!T;R`E<P!,;V<@;W5T`$QO9VEN
M`$QO9VEN(%1A<VMS`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@
M;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$U-`$UA:6P`36%I;"!S97)V
M97(@='EP92!T;R!C;VYN96-T('1O.@!-86EL8F]X`$UA:6QB;W@@86YD($9O
M;&1E<B!$:7-P;&%Y($]P=&EO;G,`36%K92!L:6Y?:RXN+@!-87)C:`!-87)G
M:6X`36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%-E96X`36%R:R!!
M;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%5N<V5E;@!-87)K(&%S.@!-87)K
M(&1I9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C
M;VQO<G,_`$UA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2D`36%R
M:R!S:6UP;&4@;6%R:W5P/P!-871C:"!!;&P@475E<FEE<P!-871C:"!!;GD@
M475E<GD`36%T8VAI;F<@9FEE;&1S`$UA>&EM=6T@071T86-H;65N="!3:7IE
M`$UA>0!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!#
M;VUP;W-I=&EO;@!-97-S86=E($1A=&4`365S<V%G92!/<'1I;VYS`$UE<W-A
M9V4@4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E
M(%9I97=I;F<`365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G
M92!F<F]M("5S`$UE<W-A9V4@;6%T8VAE<P!-97-S86=E(')E9&ER96-T960@
M<W5C8V5S<V9U;&QY+@!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@
M;F]T('-A=F5D('1O("5S`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN`$UE
M<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N`$UE<W-A9V5S
M('1O`$UI9&1L90!-;V1I9GD`36]D:69Y(%523`!-;VYT:&QY`$UO=F4`36]V
M92!$;W=N`$UO=F4@57``36]V92!D;W=N`$UO=F4@=&\@9F]L9&5R`$UO=F4@
M=7``3D]410!.86UE`$YE='=O<FL`3F5V97(`3F5V97(@<V%V92!A='1A8VAM
M96YT<P!.97<`3F5W($9O;&1E<@!.97<@36%I;`!.97<@;65S<V%G97,`3F5W
M('=I;F1O=R`H7V)L86YK*0!.97AT`$YE>'0@365S<V%G90!.97AT(%!A9V4`
M3F\`3F\@365S<V%G97,`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!F
M;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&9O;&1E<G,@=VET:"!N97<@;65S
M<V%G97,`3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<P!.;R!M97-S
M86=E(&)O9'D@=&5X=`!.;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H
M+@!.;R!S<&5L;&EN9R!E<G)O<G,`3F]N90!.;W0@1&5L971E9`!.;W0@1')A
M9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&1E;&5T960@;65S
M<V%G97,`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.;W1E<P!.;W9E;6)E<@!.
M=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD
M97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F(')O
M=W,`3U(`3V-T;V)E<@!/;&0@;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD
M97)S(&)E:6YG('!U<F=E9"X`3W!E;F5D($9O;&1E<@!/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D
M97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO
M;@!/=&AE<B!-86EL($%C8V]U;G1S`$]T:&5R($]P=&EO;G,`4$]0,R`H075T
M;R!$971E8W0@4')O=&]C;VQS*0!0861D:6YG`%!A9V4@)60@;V8@)60`4&%G
M92!W:71H('1H92!&:7)S="!5;G-E96X@365S<V%G90!086=E('=I=&@@=&AE
M($QA<W0@56YS965N($UE<W-A9V4`4&%R="AS*0!087-S=V]R9`!087-S=V]R
M9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T
M:`!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<G-O;F%L
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!I>&5L<P!0;&%C92!Y;W5R
M('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_`%!L86EN
M=&5X="!697)S:6]N(&]F($UE<W-A9V4`4&QE87-E(&5N=&5R(&$@;F%M92!F
M;W(@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T
M:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N97<@;F%M93H`4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5S
M;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N`%!L96%S92!S
M96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS
M+@!0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H
M+@!0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R
M871I;VXN`%!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M
M+2`G*3\`4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P9&%T960N`%!R979I
M97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S
M($UE<W-A9V4`4')E=FEO=7,@4&%G90!0<FEN=`!0<FEN="!D;V-U;65N=`!0
M<FEO<FET>0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VUP="!E=F5R>2!T:6UE
M(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3P!0<F]M<'0@
M979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@
M6453`%!R;W1O8V]L.@!0=7)?9V4@1&5L971E9`!0=7)G92!$96QE=&5D`%!U
M<F=E($9O;&1E<BAS*0!0=7)G92!4<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE
M<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT
M(&]F(&1A>7,N`%!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L
M9&5R/P!1=6]T:6YG("5F.@!295]Q=65S="!$96QI=F5R>2!#;VYF:7)M871I
M;VX`4F5C96EV960@3VX`4F5C96EV960@4VEN8V4`4F5C96EV960@56YT:6P`
M4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T($UE<W-A9V4`4F5D:7)E8W0@
M=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE9"X`4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($9O;&1E<B!6:65W<SH`4F5L
M;V%D`%)E;&]A9"!6:65W`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W1E
M($UA:6QB;W@Z`%)E;6]V92!P86ER`%)E;6]V92!S;W5R8V4`4F5N86UE($9O
M;&1E<BAS*0!296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@
M;V8@;6]N=&@_`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;%]Y('1O($QI<W0`4F5P;&%C
M92!W:71H.@!297!L>0!297!L>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L
M>2!T;R!,:7-T`%)E<&QY('1O($QI<W0Z`%)E<&QY('1O(%]!;&P`4F5P;'DM
M5&\`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S(%-P86T`4F5Q=65S="!A
M(%]296%D(%)E8V5I<'0`4F5Q=65S="!D96QI=F5R>2!C;VYF:7)M871I;VX_
M`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`4F5S970`4F5S=6UE`%)E='5R;B!T
M;R!&971C:"!-86EL`%)E='5R;B!T;R!/<'1I;VYS`%)E='5R;B!T;R!T:&4@
M;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O
M<'EI;F<@82!M97-S86=E/P!2:6=H=`!2;U]W(%!R;W!E<G1I97,N+BX`4F]L
M90!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!37W5B:F5C
M=`!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S`%-A;64@9G)A;64@*%]S96QF
M*0!3879E`%-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M
M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`4V%V92!/<'1I;VYS`%-A=F4@7T1R
M869T`%-A=F4@87,`4V%V92!D<F%F=',@87,@=6YS965N/P!3879E(')E8VEP
M:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O
M;VL_`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_`%-A=F4@<V5N
M="!M86EL/P!3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@)7,`4V5A<F-H`%-E87)C:"`E<P!396%R8V@@
M4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@06YO=&AE<B!!8V-O=6YT`%-E
M;&5C="!A(&1A=&4`4V5L96-T(&$@9FEE;&0`4V5L96-T(&%D9')E<W,@8F]O
M:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S
M<V5S+@!396QE8W0@86QL`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W
M:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E
M;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&UA
M:6P@<V5R=F5R('1Y<&4`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93H`4V5L96-T960@061D<F5S<R!B;V]K<SH`4V5N9"!-97-S86=E
M`%-E;F0@4')O8FQE;2!297!O<G0`4V5N="!M86EL(&9O;&1E<@!396YT(&UA
M:6P@9F]L9&5R.@!397!T96UB97(`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R
M($EN9F]R;6%T:6]N`%-E<G9E<CH`4V5T('!R969E<F5N8V5S(&9O<B!W:&%T
M(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+@!3
M:&%R92!&;VQD97)S`%-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E
M>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92!T
M;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92X`4VAO=6QD('1H
M92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A
M9G0_`%-H;W<@06QL($9O;&1E<G,`4VAO=R!!;&P@2&5A9&5R<P!3:&]W($1E
M;&5T960`4VAO=R!,:6UI=&5D($AE861E<G,`4VAO=R!-86EL:6YG($QI<W0@
M26YF;W)M871I;VX`4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<P!3:&]W
M(%5N<W5B<V-R:6)E9`!3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG
M(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_`%-H;W<@;&5G96YD(&EN
M('1H92!M86EL8F]X('9I97<_`%-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O
M;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@9FEL
M=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O
M;&1E<C\`4VAO=VX`4VE?>F4`4VEG;F5D`%-I>F4`4VMI<"!-86EN=&5N86YC
M90!3;W)T(&)Y($9R;VT@061D<F5S<P!3;W)T(&)Y($UE<W-A9V4@4VEZ90!3
M;W)T(&)Y(%-U8FIE8W0`4V]R="!B>2!4:')E860`4V]R="!B>2!4;R!!9&1R
M97-S`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C:6YG`%-P86-I;F<@
M86YD('!A9&1I;F<`4W!A;2!F;VQD97(Z`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5L;"!#:&5C:P!3<&5L;"!#:&5C
M:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R<F]R<R!P97(@
M<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-P;&ET(&-E;&P`4W!L:70@
M8V]L=6UN`%-P;&ET(')O=P!3=')I:V5T:')O=6=H`%-T<FEP($%T=&%C:&UE
M;G0`4W1Y;&4@6T-34UT`4W5B7VIE8W0`4W5B:F5C=`!3=6)J96-T($9I96QD
M`%-U8FUI=`!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U8G-C<FEP=`!3=6-C
M97-S`%-U9V=E<W1I;VYS`%-U<&5R<V-R:7!T`%-W:71C:"!T;R!(5$U,(&-O
M;7!O<VET:6]N`%-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N`%1A
M8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!487-K<P!495]X=`!4
M97AT($]N;'D`5&5X="!A;&EG;@!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S
M>7-T96TN`%1H92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD
M(&)E(&QI;FME9#H`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!D96QE=&5D
M+@!4:&4@86-C;W5N="`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@8W5R<F5N
M="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M960@=&\@(B5S(BX`5&AE
M(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92`B)7,B(&9O;&1E<BX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQD97(@(B5S(B!A;')E
M861Y(&5X:7-T<P!4:&4@9F]L9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C
M:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N
M(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O
M;&1E<B`B)7,B('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R
M:6)E9"!T;R!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y
M;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@
M(B5S(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@9&5L971E9"X@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U
M8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E
M<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F
M=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!I
M9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!M86EL8F]X("5S
M(&ES(&%L<F5A9'D@96UP='DN`%1H92!M97-S86=E(&AA<R!B965N(&1E;&5T
M960N`%1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+@!4:&4@
M<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N`%1H92!T97AT
M(&]F('1H92!M97-S86=E`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES
M(&UA:6QB;W@N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@
M=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S
M<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A
M9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G
M97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+@!4:&5R92!W
M87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E
M<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N`%1H97)E('=A
M<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,`5&AE<F4@=V%S
M(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0`5&AI<R!(5$U,(&UE<W-A
M9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X`5&AI<R!(5$U,(&UE<W-A
M9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@
M87!P96%R(&QI:V4@=&AI<SH@`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G
M92!T;P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:')E860@5FEE=P!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O($%D9')E<W,`5&]G9VQE($A434P@4V]U<F-E
M`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z
M`%1R87-H(&9O;&1E<@!4<F%S:"!F;VQD97(Z`%523`!5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%N<W=E<F5D
M`%5N86YS=V5R960@;65S<V%G97,`56YD96QE=&4`56YD97)L:6YE`%5N9&ES
M8VQO<V5D(%)E8VEP:65N=',`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YK;F]W
M;B!296-I<&EE;G0`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE
M9`!5;G-E96X`56YS970@8V]L;W(`56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H
M<RD`57!D871E($%T=&%C:&UE;G0@26YF;W)M871I;VX`57!P97(@;&%T:6X@
M;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S92!$969A=6QT(%9A;'5E
M`%5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/P!5<V5R($]P=&EO;G,`
M57-E<FYA;64`57-E<FYA;64Z`%5S97)S(&EN('1H92!S>7-T96TZ`%9E<G1I
M8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5FEE=P!6:65W("5S`%9I97<@
M2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I97<@871T86-H
M;65N="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W(&-O;G1E;G0@:6X@82!S
M97!A<F%T92!W:6YD;W<`5FEE=R!M97-S86=E<R!I;B`E<P!6:65W(&]R(&UA
M:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CH`5FEE=R!T:&4@26UA9V5S
M`%9I<G1U86P@1F]L9&5R("(E<R(@8W)E871E9"!S=6-C97-F=6QL>2X`5FER
M='5A;"!&;VQD97)S`%9I<G1U86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN
M`%9I<G1U86P@9F]L9&5R(&QA8F5L`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64`
M5V5L8V]M92P@)7,`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`
M5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5N(&1E;&5T:6YG(&UE
M<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A
M9"!O9B!M87)K:6YG('1H96T@87,@9&5L971E9#\`5VAE;B!O<&5N:6YG(&$@
M;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@
M;VX_`%=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD('=E('-A=F4@871T
M86-H;65N="!D871A/P!7:&ET96QI<W0`5VED=&@`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE
M`%E9`%EE87)L>0!997,`66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE
M=R!F;VQD97(N`%EO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O(`!9
M;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BX`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@
M`%EO=2!H879E("5S(&YE=R!M97-S86=E<RX`66]U(&AA=F4@,2!N97<@;65S
M<V%G92X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!N97<@
M;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CH`66]U(&AA=F4@;F5W(&UA
M:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.@!9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="X`66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T
M+@!9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="X`66]U(&UU<W0@
M<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S
M<&5C:69Y(&$@<F5C:7!I96YT+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!F
M:6QE('1O(&%T=&%C:"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N`%EO
M=2!W97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N($AE<F4@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M
M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@
M<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S(@!9;W4@=V5R92!S=6-C
M97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R(&%C8V]U;G1S.@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F
M('1H:7,@:6UA9V4@='EP92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D
M969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!M97-S86=E
M('=A<R!S=6-C97-S9G5L;'D@9&5L:79E<F5D+@!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I
M;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!S:6=N
M871U<F4Z`%M(:61E(%%U;W1E9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L
M96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T)C8P!?0FQA8VML:7-T`%]#8P!?1&5L971E`%]$96QE=&4@4F]W`%]&
M;VQD97)S`%](96QP`%])9&5N=&ET>0!?26UA9V4@4')O<&5R=&EE<RXN+@!?
M26YB;W@`7TQO9R!O=70`7TUE<W-A9V4@4V]U<F-E`%]-;V1I9GD@3&EN:RXN
M+@!?3W!T:6]N<P!?4')I;G0`7U!R:6]R:71Y`%]296UO=F4@3&EN:RXN+@!?
M4F5P;'D`7U-E87)C:`!?4V5N9"!-97-S86=E`%]486)L92!0<F]P97)T:65S
M+BXN`%]4:')E860`7U1O`%]5;F1E;&5T90!?5FEE=R!4:')E860`7U=H:71E
M;&ES=`!B>71E<P!F<F]M`&QI;F5S70!M86EL8F]X(&9I;&4`;F%M90!N;VYE
M`&]R`'!E<F-E;G0`<&EX96QS`'-P96QL:6YG(&5R<F]R`'-P96QL:6YG(&5R
M<F]R<P!U;FYA;65D`'9#87)D`'EO=7(@8FQA8VML:7-T`'EO=7(@=VAI=&5L
M:7-T`%!R;VIE8W0M260M5F5R<VEO;CH@24U0(#0N,"UC=G,*4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E
M.B`R,#`Q+3$Q+3`Y(#$V.C(Y*S`Y,#`*3&%S="U4<F%N<VQA=&]R.B!*:6YH
M>6]K($AE;R`\;F]V96UB<F5`;W5R;F%T=7)E+F]R9SX*3&%N9W5A9V4M5&5A
M;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4550RU+4@I#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@"YWK3"N^>V]SH@`+.OPJ4Z(`"Z
MN+.]N^>V]SH@`"`HM-S#X,6P("5S*0`@*+_`M,,I`"`HL[O`SRD`("B^[L&F
M*0#!IKCQ.B``(#H@`"5D("\@)60@*,;MP?8Z("5D*0`E<R#`K\'VL/RXKB#`
MV[[W("T@R*[`S@`B)7,BM,(@P,RYS"#`UKW`M,^TV2X`)7,@L*$@P,RYS"#!
MN,#GQ]6TS[39+B`E<R#&[<'VQ]3`QR#`S+BGP+L@NJ^PYL?2(+SV(+[XO<"T
MS[39+@`E<R"TPB#!I+OSP/O`SB#&[<'VQ]3`N+?.(+JXP,S!]B"^RKW`M,^T
MV2X`)7,@QNW!]L?4P,<@P,RXI\"[(+C%O_G#RB"ZK[#FQ]6TS[39+@`E<SH@
M)7,@*"5D)FYB<W`[+R9N8G-P.R5D*0`HNJ^PYKOGQ]<@P/N_ZR#(Q""TV<"]
M(,BMN.G`N+?.(,#,M;\I`"BX\+7G(+JOL.:[Y\?7(,/KO-(@R,0@M<>UN;[&
ML*&QXBXI`"BX\+7G(+JOL.:[Y\?7(,#[O^L@R,0@M<>UN;[&L*@N(,?VP.<@
MR*VXZ<#'(+JOL.:SN[_KP+H@P/N_Z[7'P?8@OLJ]P+3/M-DN*0`HN/"UYR"Z
MK[#FL[N_Z\"[(,#[O^L@R,0@QNW!]B"ZN+.[L>(N(,?VP.<@R*VXZ<#'(+JO
ML.:SN[_KP+H@P/N_Z[7'P?8@OLJ]P+3/M-DN*0`J($]+N*8@Q:RXK\?/OZD@
MP]^PH<?/O+R_Y"`J`"H@P=:\TKBF(+RQQ</'S[R\O^0@*@`Q,##`V@`Q,#`P
MP-H`,C0@O<.PHP`R-3#`V@`U,##`V@`E<[;SM,(@Q:L@L=>XLL#,(,;MP?:_
MH2##M[K.M<>^^KW`M,^TV2X`O\#`_"^_P,C$`+'7N*ZP[0#`S""_H;7PQ<VT
MP@"PZ,&D(,#,N*<Z`,/?L*$`N_6WSK_N(+OGO^O`VB##W["A.@#&Y+[N*'!A
M:7(I(,/?L*$`O-*]NB##W["A`+OGO^O`VB##W["A`,.WNL[&Q,#/*"(E<R(I
M(,/?L*&UR@"[Y[_KP-H@P]^PH2"[Y[_KOLC'U`#!UKS2`,'6O-*WSP#!UKS2
MM\\`L/RXK@"^\[;SP,R^[KVZ`,&DM\0`P:2WQ#H`N/"USB"\L<7#`+CPM><@
M-+CI`+39P+T@QNW!]L?4P,<@N/"UYR#&[<'VN*8@Q\^SJL#'($U"3U@@QL3`
MS[?.(+39O^ZWSK7EQ]6TS[39+@`B)7,B(,;MP?;'U+^AO*T@)7,@P,^ZN+39
M(+_`MZ&UR"#&[<'VN*8@P?:_\[3/M-DN`"5S(+"SO_FZN+39(+_`MZ&UR"#&
M[<'VP,<@N+7%J2##M[K.(,;$P,_`NR#!]K_SM,^TV2X`)7,@L+._^;JXM-D@
MO\"WH;7((+JXL[W&[<'VQ]3`NR"X\+7.(,'VO_.TS[39+@"X\+7G(,;MP?;'
MU+^A(,?*Q<T@L=3$HL"[(,#[O^O'TB"\]B#`UK#4(,?2L>Z_Y#\`M.O#O""Q
MVP#`S""ZSKK0OZ$@M.O'T2"TV;BE(+3KP[P@L[N_ZSH`Q]>[\P#'U[OS(,.W
MNL[&Q,#/(,#ZP.7'S['B`,#?N/BUR""YKL#:L*$@P-:]P+3/M-DN`+3DP.7'
MU`"TY,#EQ]$@QNW!]@#'RL7-(,#[O^O'S['B`"5S(,;MP?;'U+^A(,?*Q<T@
MP/N_Z\?/L>(`M\ZQU\#.Q](@MJ<@Q\K%S2#`^[_K`+G>P+K&[<'VQ]0@L+N]
MQ;W#(,?*Q<T@P/N_ZP`TO_D`L.B\TR#!^,?@Q\^]P[#:O<"TS['N/P#`S"#&
M[<'VN*8@O[6_^,CW(,'VO^RPVKW`M,^Q[C\`P,P@P[>ZSL;$P,_`NR"_M;_X
MR/<@P?:_[+#:O<"TS['N/P#`S"#&[<'VQ]3`NR"Z\;_LO<.PVKW`M,^Q[C\`
MP?:_[L;MP?;'U"A4<F%S:"G`NR"Z\;_LO<.PVKW`M,^Q[C\`P,P@QNW!]KBF
M(+_/P/S(]R#!]K_LL-J]P+3/L>X_`+6UPO@@O<.PHP"_P+BGPO>\^`"YL+[N
MNKBQX@#`K\'VL/RXKKW'Q^#`_"#(KL#.Q\^QX@#&Q,#/(,.WNLX`QL3`SR##
MM[K.`,.WNLZUR"#&Q,#/.@`E<[3"(,;$P,_#M[K.(,6IL>(@Q]&PZ+BF(,/*
ML/K'S[^I(,.WNLZUQ\'V(+[*OM*]P+3/M-DN`,;$P,_#M[K.`,;$P,\@P[>Z
MS@"^R[BR`#B_^0"ZN+.]N^>V]\#,(,'6O-*WS[^A(+7ION[`UK3"(+#FO^P@
M2%1-3"#&[<'VP,<@P,RYS,'VN*8@P-JUO\"XM\X@NKB_J<'9L>Z_Y#\`P,R_
MZ["AM,G'T2#!UKS2M\\Z`+"AM,G'T2#'RK7E.@!?:R5SM\X@M;F^QK"AL>(`
M)7.WSB"UN;[&L*&QX@"YZ+#F`+GHL.8@N_:Q\@"\^\"ZPOS!M@"[_<#/`+SV
MO<6PQ;K.`+_DP[O`S""^^+39N.D@2%1-3"#&[<'VP,<@L=>XLL"[(+BWP+NQ
M[K_D/P"ZN[FN`+&]L-0`L.:PZ`"PYK#H(+7.LK(`L.:PZ`"X\+7.`+7.L*'!
M]B"X\+7.`+[&MZ$`L>+(HR"XKKVZQJX`7V6\OR"\T[RZ+BXN`+FNP-J\P@"T
MWK?"`+_<NLX@N-[`S[RMN?:_H2#!HKS3Q](@O/8@OOB]P+3/M-DN`+_<NLX@
MN-[`S[RMN?:_H2#!HKS3Q](@O/8@OOB]P+3/M-DZ(`##Z[S2`,;MP?8@P^N\
MT@"_P+?Y(+JXL.W'S['B(,/KO-(`P^N\TL?/N.D@P,P@QNW!]L#'(+.[O^O`
MNB"_M;&XR/<@P?:_]L'VL-0@M<NTS[39+@#$N+S'`,+\P;8`R-ZTZ\;Y`+R_
M(+S3O+H`O+\@QN2U^0"\OR"\T[RZ`+R_(+"CL-T`R-ZTZ\;Y`+"AO^ZUI0"Z
MK[#F`+CPM<X@NJ^PY@#&[<'VQ]0@NJ^PY@"PHB#&Y,#,P?:TYR#&[<'V(+"Y
MO/:_S2#&[<'V(,&DM\0@O/B\K2"\L\&D`+C>P,^\K;GVO\T@QNW!]L?4(+RS
MP:0@NJ^PY@#&[<'VN*8@NKBSOB"VIR"[Y[_KQ](@P,RXIRP@P=:\TBP@O*VX
M[<"[(+JOL.;'U;3/M-DN`%]KN+7%J2"PR[OG+BXN`,;MP?;'U+^AO*T@N_4@
MN-[`SR"PR[OG`,;MP?8@NKBSN['B(,#\(,.VP-H@L,N[Y\?/L>(`P=^QN0"\
ML<7#N^?'USH`O/B\K2"XKKVZQJX@P;ZW^2"\L<7#`$U3O\#'Q[VZ(,77L=<@
MP?:_[+'B`+KJMO._[,&NL*$@NKP@O/8@P-:TPB#'_+W$P+BWSB"QU[BR(,;$
MP,_`NR"ZK\BOQ\^WP;CI("5SN*8@M*FXH[R\O^0N`,#,N<S!]KBF(+.[M\&Y
MWL"XM\&XZ2`E<[BF(+2IN*.\O+_D+@`E<[BF(+2IN*.XZ2`E<R"P_+BNQN3`
MS,'VM\X@L*FTS[39+@"[]2##HK^AO*T@:'1M;""SN[_KP+L@NKBWP;CI("5S
MN*8@M*FXH[R\O^0N`,#,(+'7N++`QR"]YK/7P,_`NR"ZN+?!N.D@)7.XIB"T
MJ;BCO+R_Y"X`N_4@PZ*_H;RM(,.WNLZXIB"ZN+?!N.D@)7.XIB"TJ;BCO+R_
MY"X`P,P@NLZZT,"[(+OU(,.BOZ&\K2"ZN+?!N.D@)7.XIB#%K+BOQ\^\O+_D
M+@#`S+G,P?:XIB"ZN+?!N.D@OZFQXKBF(+2IN*.\O+_D+@#!UKS2N*8@Q:RX
MK\?/N.D@NKBSO<#,OZ&PU""[]2#&[<'VN*8@OKFTS[39+@#!UKS2N*8@Q:RX
MK\?/N.D@QNW!]KBF(+JXOZG!W;3/M-DN`,.B(+3=L>(`PZ(@M-VQX@"TW<CY
M(,;MP?;'U`"TW;'B`+CPM<X@M-VQX@"X\+7G(,;MP?;'U""TW;'B`,;MP?;'
MU""TW;'B`+_>PLJXM[3K(+3=L>(`Q]7#Q,'X(+#FL.@`N_:Q\@"_K3H`0V]M
M:6-S`,BXN^<`N_4@QNW!]B#`V[RZ`+OU(,.BOZ&\K2#&[<'V(,#;O+H`*+KJ
MMO._[,&NL*$@L>*TR<"[(,'VO_C'TB"PYK_L*2#&[<'VN*8@OK4@MJ<@2%1-
M3"#`V[RZN/"UY;BF(+'BNKO`N+?.(,?2L>Z_Y#\`QNW!]B"ZN+3"(+GFN?W`
MNR"\L\&DQ]6TS[39+@"^S\BC(,BNP,X`O*VY]B"_K+#A(+W'QM``N_4@QNW!
M]B"UM<+X(+[+N+(@N^>_ZR"\L\&D`+FNP-H@P,RX\,:\Q-S`NR"QU[BRP+BW
MSB"YV;+<L>Z_Y#\`NKF[YP"ZN;OG`,;MP?;'U,"XM\X@NKF[YP"QL\&D`+&S
MP:2UR""ZN[FN`$UA:6YT96YA;F-E7U1A<VL@N/"UXB`E<R"XIB"_K2"\]B"^
M^+W`M,^TV2X`N+BUZ;'B`+OU(,;MP?;'U""XN+7IL>(`L*&[\R#&[<'VQ]0@
MN+BUZ;'B`+BUQ:D@N+BUZ;'B`,#3O<.ZN+#\Q]0@N_6WSB"XN+7IL>(`N_4@
MNKBSO<;MP?;'U""XN+7IL>(`N_4@P?:_[L;MP?;'U""XN+7IL>(`Q\K%S2"Q
MU,2B(+BXM>FQXBP@QNW!]L?4(,&DM\2\^+RM+""]NL;4(,'VO^RQX@#']L#G
M(%523,"Z`,?VP.<@O;K%N,#/`+39N*4@L.C!I,"XM\ZZSL7-(+C>P,_`NR"P
MH<&NO\"UM;?/(+RSP:3'U;3/M-DN`,;MP?8@NKBSN[3"(+GFN?T@O+/!I,?5
MM,^TV2X`P-JXH['B`,#:N*.QX@!$1`#`S[JP`+.OPJ4`LZ_"I0!?;+^M(+OH
MP:8`,3*_^0"\_<#:`+.[ONZ^LK'B`+'BNKL@O<2ZL,#:`+'BNKL@P:2WQ"#'
MU[CQ.@"QXKJ[(,&DM\0@N>:Y_0#!]K_LL>(`QNW!]L?4(,'VO^RQX@"PH;OS
M(,;MP?;'U"#!]K_LL>(`O+\@N^C!I@"_K2"[Z,&F`+_<NLZ\K;GVOZ&\K2"P
MH<&NO\(@QNW!]KBF(,'VO^^Q[K_D/P"XQ;_YP\H@O\"WH;7((+BUQ:D@P[>Z
MSL;$P,\@P?:_[+'B`+C%O_G#RB"_P+>AM<@@NKBSO<;MP?;'U"#!]K_LL>(`
MQ^`@N^C!I@#']L#G(+^M(,'VO_(`Q_;`YR#'X"#!]K_R`,'VO_;!_`#!]K_V
MP?@@QNW!]@##M[K.QL3`SR`B)7,B(,'VO_;!_`#&[<'V(,'VO^RQXB"YUR#`
MS+6_`+.[N++"][SX`+_`M_D@O+.X[0##M[K.(+RSN.TZ`+R\NL[!I+JXL*$@
ML/RXKL#:N*8@P*?'V""QXK?/M<>^[L&SO<"TS[39+@"\K;CMP+L@R.6XM,?/
ML-0@QZ6]PP"U\+>ZQ>2XK@#'I;W#(,?\O<0`R*VXZ2"\L\&D`,;MP?:XIB"Z
MN+.[L.T@LZJ\K2#(KL#.(,>EO<.XIB#'TK'NO^0_`,;MP?8@NKNYKK^A(+JX
MOZG!UK'B`+OU(,;MP?8@M;7"^+W#(,;+OO?#HL"XM\X@OLNXL@"YZ,2A`,#/
MQ*''S\'V(+[*L>(`N_4@QNW!]B"PR[OGQ\_!]B"^RL"]`&UA:6YT96YA;F-E
M+G!H<+^A(,'WP:(@P:*QV<?/P?8@N+:\O+_D+@"YWK3"N^>V]R#'U[CQOZ$@
MN+7%J;BF(+BXM>G!]B"^RKW`M,^TV2X`QNW!]L?4P+L@OZVQ[K_D/P##N;GX
MPK`@Q^#`NB#'U[CQ(,#,N*?`NR"PKK#M(,#6O<"TS['N/R"QU[>XM-FXZ2P@
MOZFQXKBF(,.\Q:G'S[R\O^0Z`+_/M^$`L[NWP;G>L>(`)7,@L[NWP;G>L>(`
M)7.XIB"^T,/@QL3`SRAZ:7`IP+BWSB"SN[?!N=ZQX@"^T,/@QL3`SRAZ:7`I
MM\X@Q]$@N?B_H2"SN[?!N=ZQX@#&[<'VQ]0@L[NWP;G>L>(`OM##X,;$P,\H
M>FEP*;?.(,;MP?;'U""SN[?!N=ZQX@"^T,/@QL3`SRAZ:7`IM\X@L[NWP;G>
ML>(`P-.]P\;MP?8`P-.]P[JXL/S'U#H`P-.]P[JXL/S'U#H`P,RXWL#/(,'6
MO-(Z`,;MP?T`O/:]Q;#%NLX@N/&WSR"\]L&D`,?*Q<T@O/;!I``E<R"QQ\?1
M(+SVP:0`O/:]Q;W"P,X@N/&WSR"\]L&D`+RQQ<.[Y\?7(+SVP:0Z`+SVO<6P
MQ;K.(+CQM\\@O/;!I`#'RL7-(+'4Q*(@O/;!I`"_W+K.(+C>P,\@L.C!I+^A
M(,&BL=G'S['B(,"GQ]$@O+'%P[OGQ]<@O/;!I,?/L>(`O/:]Q;W"P,X@N/&W
MSR"\]L&D`+_DO-(N+BX`96T`P,RXWL#/`,#,N-[`SR#!UKS2`,#,N/#&O,3<
M`,;MP?;'U""Z\;_R`,'VO^[&[<'VQ]0@NO&_\@!?=,'VO^[&[<'VQ]0@NO&_
M\@"PX;#Z(+[XP+T`7WF^S\BCR*T@O\F\QP#`_+3>(,;MP?8@LZ$`QNW!_;'B
M(,BNM.L`L=>XLB!54DP@P-2WP@"[]2#`T[W#NKBP_,?4P,<@P,RXIR#`U+?"
M`+OU(+JXL[W&[<'VQ]3`QR#`S+BG(,#4M\(`N_4@P?:_[L;MP?;'U"#`S+BG
M(,#4M\(`(B5S(K"A(,'6O-*WS[^A(,/?L*&UQ[[ZO<"TS[39+@"_P+?Y`#$U
MNM``,S##RKBVM-D`-;K0N+:TV0"X\+7G(+?.L=?`S@`S,+K0N+:TV0"XQ;K0
MN+:TV0"_N3H`R*[`Y0"X\+7.(,BNP.4`N/"UYR#&[<'VQ]0@R*[`Y<?/L>(`
MQNW!]L?4(,BNP.4`P,RXIR"_S[RZ`+_>PLJXM[3K(,BNP.4`QNW!]B#`V[RZ
MQ](@MJ<@P,RXI\"[(,#:M;_`N+?.(+_/O+H`QNW!]L?4(+CQM\_`NR"ZO""V
MIR"QXKJ[P+BWSB#`_,.\(,;MP?;'U"#(KL#EQ\^QX@#`VK6_O\^\N@#`_+#F
MN_8`R*^PYKRSP:0@P-"QXB"_P+?Y+@!,1$%0(+RMN?8@P:*\TR"]Q\;0`,;1
MO;H`,K_Y`+_<NL[&[<'V(+"AP:Z_P+'B`+OU(,.BOZ&\K2"_W+K.(,;MP?8@
ML*'!KK_`L>(`M\ZQU\#.Q](@MJ<@O]RZSB#&[<'V(+"AP:Z_P+'B`,;MP?:P
MH<&NO\"QXCH@N_4@QNW!]B"^^,"]+@!?3,?*Q<T`QL3`SP#&Q,#/(+#\N*[`
MV@#'RL7-(+RQQ<.[Y\?7`,?*Q<T@O+/!I`#'RL7-`,.CL>(`P[G&Y,#,P?8`
MP[G&Y,#,P?8`7W+`_+3>`,;MP?;'U"#%O;OVL>(`QNW!]L?4(+_DON``L=O`
MVB"[]K'R`+_`M,,@LZ_"I2#&[<'VOZ$@M.O'T2"SK\*E(,>EO<,@Q_R]Q`#`
M_+3>`,#\M-XZ`,#\M-ZUR"#&[<'V`"5SM\ZZSL7-(,#\M-ZUR"#&[<'V`,?!
MM[G`TP!?;;JXL[V[Y[;W`+JXL[V[Y[;W`+JXL[V[Y[;W(,'6O-(`P/RTWCH`
MP/RTWCH`P/RTWCH@)74@P/RTWB#&[<'V`,#/N=W`^\#.(+_)O,<`M;;`SP"[
M];?.O^X@N-[`S[BX(+"AP:Z_P['NO^0_("A)34%0(,#\O^LI`,;MP?:WSB"P
MH;'B`+^IL>(`2%1-3"#'_+W$`+C3N+2QVP"S],#,`+6UO_*XNP"UM;_RN+L`
MQL3`S\#'(+W#P-O`S""TV<"]L/H@L+"]P+3/M-DZ`+"HP]^QX@"T\;';NKBQ
MXK^AO*T@L*C#W['B`,'VO_;!^"#&[<'V(+S[L>*QX@"[Y[_KQ\_!]B"^RK3"
M(,;MP?;'U""\^['H`,'](,'6O-(`P?T@P/S(K;GXR*,`2&]R9&4`O/;&\KRQ
M`+"AM\X@PZ2_\@"PH;?..@##M[K.QL3`S\"[(+[NMKNPU"#'I;W#Q\^QXKBF
M(+_XQ\^]RK3/L>X_`,?5Q*&P[2"]S<"Z(+^MP,<@O/8`Q]>X\2B_K2G`QR"\
M]C\`Q]7$H;#M(+W-P+H@Q^#`QR"\]@"TY,#EOZ$@N^>_Z\?2(,#.O^NYKCH`
M24U!4"`H4')O=&]C;VQS(,#:M;\@L*C!]BD`24U!4"]03U`S(+C>P,\@O*VY
M]@"YWL"ZQNW!]L?4`%]NOM6_H2#'X"##W["A`+[&P,S$W`"^QL#,Q-RP^B"Y
MKL#:`+W$NK#`VB#`S+BG.@"YJ[W#`+CPM<X@N:N]PP"QU[BR(+G,N*ZZN+'B
M.@"QU[BR(%523`"QU[BR(%523#H`L*'!KK_`L>(`QNW!]B"PH<&NO\"QX@!M
M8F]X(,;$P,\@L*'!KK_`L>(@`"5S(&UB;W@@QL3`S\"[("5SM\X@L*'!KK_`
ML>(`P=^_Y,?4`,'?O^3'T2#&[<'V`+"AP:Z_PB#'U[CQ.B`E<P"PH<&NO\(@
MQ]>X\3H`7W.TV<"]OZ$@Q^`@P]^PH0"YWL"ZQNW!]L?4`+3DP.6_H2"PH[3<
MQ]$@N-.XM+B[(+_DON#`NR#&]\?4Q]*Q[K_D/P"TY,#EOZ$@L>+!N"#&[<'V
MN*8@QO?'U,?2L>Z_Y#\`M>F_J;ZRL>(`P:2ZN`!?;[39P+V_H2"_K2##W["A
M`+'7N+(@P]^PH0#'I2##W["A`,"E(+BUQ:D@P]^PH0!?8[[5OZ$@OZT@P]^P
MH0#']L#G(+^M(+7:OZ$@N_4@OZT@P]^PH0#']L#G(+^M(+[5OZ$@N_4@OZT@
MP]^PH0#']L#G(,?@(+7:OZ$@N_4@Q^`@P]^PH0#']L#G(,?@(+[5OZ$@N_4@
MQ^`@P]^PH0#']L#G(,'VP:$@M=J_H2"TW+;T(,/?L*$`Q_;`YR#!]L&A(+[5
MOZ$@M-RV]"##W["A`+7:OZ$@O+\@P]^PH0"^U;^A(+R_(,/?L*$`M=J_H2"_
MK2##W["A`+[5OZ$@OZT@P]^PH0"UVK^A(+3<MO0@P]^PH0"^U;^A(+3<MO0@
MP]^PH0"UVK^A(,?@(,/?L*$`OM6_H2#'X"##W["A`+'7N+(@P]^PH2^\]L&D
M`+BUQ:D@P]^PH2^\]L&D`,#?N/BUR"#!UKS2`,#?N/BUR"#`S+C>P,\@P=:\
MTCH@)7,`O+'%PR"YW<#\`+'BO^_`S+'B`#&_^0#`S[J[`,#/NKN^[B`H25-/
M+3(P,C(M2E`I`#>_^0`VO_D`P:2WQ`"PH;_NM:4@P:2WQ`"^Y\+*(,&DM\0`
MO]["RB#!I+?$`+_`N*7"RB#!I+?$`+3KQ]&YSK&Y`,?1L;F^[B`H155#+4M2
M*0"^\+[N`+BVP?:XMR#&Y,#,P?8`N+;!]KBW(,;DP,S!]@"XML'VN+<@M\ZQ
MU\#..B`E<P"XML'VN+<@M\ZQU\#..B`E<RP@P:*\TR#`I\2A.B`E<P"XML'V
MN+<@M\ZQU\#..B"^^,"]`+>YP,R^QK_T`+_>PLH`7V[#M[K.QL3`SR"XM<6I
MQ\^QX@"UM;_ROLL@N/'"]P#!UKS2M\\@R*VXZ<"[(,/BM\+'TK:G(+CPM><@
MP=:\TKBF(,/BM\+'TK'NO^0_("B\L<7#Q\_!]B"^RL"XN.DL(,'WP:(@L,N[
M]L?1(,'6O-*XN""ZO""\]B#`UKW`M,^TV2XI`+C3N+2XN[^A(+.JOZW'S['B
M`+OGO^O'TB"\]B"^^+3"(+OGO^O`VB"X\;?/+@"[Y[_KQ](@O^S&[<?4.@"W
MSK'7P,X`)7._H2"WSK'7P,X`M\ZQU[[&O_0`M\ZQU\#.`+?.L=?`SB"]P\#;
MP-N^]P"QU[BNO;H@O-*YKL#:`+;SQKX@O-*YKL#:`+?.N+8@O-*YKL#:(+S]
MP-H`34T`N-[`SP#!HKS3Q](@N-[`S[RMN?;`QR#!OK?Y.@"_[,;MQ]0`QNW!
M]L?4(,/BM\(@O+/!I`!?:[BUQ:D@N+BUZ;'B+BXN`#._^0"PH<#EP-JXK@#&
M[<'VQ]3`QR"X\+7G(,;MP?:XIB#`T,"]P+BWSB#'I;W#`,;MP?;'U,#'(+CP
MM><@QNW!]KBF(,#0P?8@OLK`O<"XM\X@QZ6]PP#&[<'V(,>EO<,Z`,#.O^L@
MM-RPZ+BVM-D@M-FXI2"[]L"XM\X@QZ6]P[BF(,?2L>Z_Y#\`QNW!]KBF(,#0
MP+W`N+?.(,>EO</'TK'NO^0_("A)34%0(,#\O^LI`+"CM-S'T2!M87)K=7#`
MNR#'I;W#Q]*Q[K_D/P"PR[OVONX@N/"USB#`S\2A`+#+N_:^[B#'S[.J(,#,
MN_,@P,_$H0#`S\2AQ\^TPB#'U[CQ`,.WNL[&Q,#/(,/6M.L@Q:FQX@`UO_D`
MN-ZTNB"X\+7E`+R_(,?5Q*&QX@#&[<'V`,;MP?8@P-N\N@#&[<'V(+.OPJ4`
MQNW!]B"\L<7#N^?'UP#&[<'V(,.CL>(`QNW!]B#%J;'B`,;MP?8@O-*]NKJX
ML>(`QNW!]B"ZN+'B`,;MP?8@L;BZT`#&[<'VQ]0`)7/`QR#&[<'V`,;MP?8@
MP,_$H0#&[<'VL*$@O+JP^,#[P+BWSB#`_+3>M<>^^KW`M,^TV2X`QNW!]K"A
M(+RZL/C`^\"XM\X@N=^\V[7'OOK!]KBX+"`E<[^A(,#ZP.6UQ\'V(+[*OM*]
MP+3/M-DN`,;MP?:PH2"\NK#XP/O`N+?.(+JXL[O!L[W`M,^TV2X`QNW!]L?4
M(,;DP,S!]K3G(,;MP?8@L+F\]@#&[<'VQ]0@O+'%PP"PH;_NM:4`NJ^PY@!5
M4DP@O/;!I`"XQ;_Y`,#,M;\`OL:WH;?.(,#,M;\`P*>WSB#`S+6_`+[&MZ&W
MSB#`S+6_`,;MP?;'U,"XM\X@P,RUOP#`I[?.(,#,M;\`P=;`QP#`S+BG`+/7
MQJZ_]L6I`+OGO^O'S\'V(+[*P+T`P[>ZSL;$P,\@P/K`Y;[(Q]0`N_4@QNW!
M]@"[]2#&[<'VQ]0`N_4@QNW!]@"[]2#&[<'V`+OU(,.B*%]B;&%N:RD`M-G`
MO0"TV<"](,;MP?8`M-G`O2#&Y,#,P?8`OL:TS[_``,;MP?8@OOC`O0!&5%`@
M5D93N*8@P*?'T2"\L\&DP:2ZN+"A(+[XO<"TS[39+@!344P@5D93(+RSP:3!
MI+JXL*$@OOB]P+3/M-DN`%-13"U&:6QE(%9&4R"\L\&DP:2ZN+"A(+[XO<"T
MS[39+@#&[<'VQ]3`NR"\L<7#Q\^\O+_D`+OU(,;MP?:PH2#`UK3"(,;MP?;'
MU""^^,"]`,#0P?8@OLK`NB#&[<'VL*$@P-:TPB#&[<'VQ]0@OOC`O0#&[<'V
M(+J[N:X@OOC`O0##H[3"(,;MP?:PH2"^^+W`M,^TV2X`P[;`VB"_P+?Y(+[X
MP+T`N/"USB"\L<7#(+[(Q]0`P?:_]L'VP?8@OLK`O0#`T[W#QNW!]B"^QK34
M`,'?O^3'S\'V(+[*P+T`L+/`SL;MP?8@OL:TU`#!]K_VP?;!]B"^RL"Z(,;M
MP?8`P=^_Y,?/P?8@OLK`NB#&[<'V`,+\P;8`,3&_^0"_K<#'(+SV`+C%O_D@
MQNW!]L?4P+L@P?:_[R"PYK_L(+JXL/S'TB"_N<#\(+JXL[T@QNW!]L?4P,<@
ML+F\]@#'X,#'(+SV`,BDP+H`,3"_^0"_OK.O(,;MP?8`NKBSO<;MP?;'U"A3
M96YT*<#'(+_`MZ&UR"#&[<'VN*8@P?:_[+#M(,#6O<"TS[39+@"_K;BP(,;M
MP?;'U`"[]2##HK^A(+BUQ:D@OZVQX@"\L<7#N^?'UP`E<R"\L<7#N^?'UP"\
M_<#:(+CQM\\`M-S#O`"QXL6X`+'BQ;@@P:2ZN`"TV;BE(+C>P,\@L.C!I`"Q
MXL6X(+RSP:0`4$]0,R`H4')O=&]C;VQS(,#:M;\@L*C!]BD`QN2U^0`E9"`O
M("5D(,;DP,S!]@#`T,'V(+[*P+H@P[FY^,*P(,;MP?:PH2#`UK3"(,;DP,S!
M]@#`T,'V(+[*P+H@N+;!]KBW(,;MP?:PH2#`UK3"(,;DP,S!]@"ZSKK0`+[/
MR*,`OL_(H["A(,#/Q*''S\'V(+[*O<"TS[39+@"ZV<#,L>(`Q:RXL[JXM>6_
MH;RM(+K9P,RQX@"PYK?.`,;;O+[&K@#`K\'V(+#\N*X@P-N^]R"]Q\?@`+?.
ML=?`SB"]PR#`K\'VL/RXKB#`V[[W(+W'Q^``L+/`SL;MP?8`L+/`SB#!I+JX
M`,#\R*VY^,BC`,?(O+\`R+B]Q2"YUR#`_+3>(+[5OZ$@O*VX[<"[(,/?L*''
MU;3/M-DN`,;RN:XH4&QA:6YT97AT*2#'_+W$`+OU(,;MP?;'U,#'(,#,N*?`
MNR#`U+?"Q\^\O+_D.@"[]2#&[<'VQ]3`QR#`S+BGP+L@P-2WPL?/O+R_Y#H`
MN_4@P,RXI\"[(,#4M\+'S[R\O^0Z`+FNP::_H2"TZ\?1(+_DON#`NR#`U+?"
MQ]@@P=:\O+_D+@"[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'S[R\O^0`N-[`
MSR#!UKS2L*$@N/#(H\?/L,6SJB#`W[CXM<>^^KW`M,^TV2X`O<?'X,#\OZ$@
MQNW!]L?4P+L@O+'%P\?/O+R_Y"X`L,N[]L?2(,/6O-+'T2#'T;"SP,<@QNW!
M]L?4P+L@O+'%P\?/O+R_Y"X`O<?'X,?2(,?/LZK`QR#&[<'VQ]3`NR"\L<7#
MQ\^\O+_D+@"\K;CMP+L@*"<M+2`G*;?.(+W#P-O'U;3/M-DHP]_#M<?4*2X`
MO+'%P[OGQ]>UZ<#,(+RZL/C`^\"XM\X@P/K`Y;7'OOJ]P+3/M-DN`+G,N*ZZ
MN+'B`+OU(,.BOZ$@N<RXKKJXL>(`P,S`_"#&[<'V`,#,P/P@QN3`S,'V`,#.
MO.(`N:Z\K2#`SKSB`+_LO+&\^,"G`+FNP:8@O+.X[0##M[K.Q](@MJ>XMK39
M(+FPONZZN+'B*+'BNKNPJCH@OL:TS[_`*0##M[K.Q](@MJ>XMK39(+FPONZZ
MN+'B*+'BNKNPJCH@O[DI`,?!M\[%Y,3=.@!?9\'VO^X@QNW!]B"Z\;_LL>(`
MP?:_[B#&[<'V(+KQO^RQX@#&[<'VQ]0@P?:_[+'B`,'VO^[&[<'VQ]0@NO&_
M[+'B(+W'Q^#!UK'B.@#!]L&DM<@@P,\@O/:ZN+39(+_`MZ&UR""_P+>AM<@@
MQNW!]B#!]K_NQNW!]L?4OZ&\K2#!]K_LL>(`P?:_[L;MP?;'U+^AO*T@O\"W
MH;7((,;MP?8@P?:_[['NO^0_`"5F('=R;W1E.@!?4;SVO<4@R*[`SB"_Y,.[
M`+SVO<4@LZ_"I3H`LZ_"I2"]P\#;.@"SK\*E(+.A.@!?5+G9M\X@P/RTW@"Y
MV;?.(,#\M-X`QNW!]B#`_+3>`,;MP?8@P/RTW@#&[<'V(,#\M-X@O\"W^3H`
MN+;!]KBW(+CMM\D@N=VZN0"[];?.(,#0L>(`QNW!]L?4(+OUM\X@P-"QXCH`
MN_6WSB"P[<2G`+OUM\X@L.W$IP"XML'VN+<@R*VXZ2"QXK[O`+_<NLX@QNW!
M]L?4.@#&Y+[N*'!A:7(I(+OHP:8`O-*]NB#!]K_LL>(`QNW!]L?4(,#,N*<@
MNJ^PY@"ZN+.]QNW!]L?4*%-E;G0I(,#,N*?`NR"XQ;_YP\H@NJ^PYL?5M,^T
MV2X`(B5S(KBF("(E<R*WSB#`S+BGP+L@NJ^PYL?/P?8@N/C'W[W`M,^TV2X@
MO*VY]B"_P+?Y.B``7WFXKKVZQJX@R+B]Q0"YV;+<(+FNP-J_K3H`R+B]Q0#`
M_,.\(,BXO<4`P/S#O"#(N+W%.@"XKKVZQJX@R+B]Q0"XKKVZQJX@R+B]Q3H`
M7T'`_,.\(,BXO<4`R+B]Q3H`R+B]Q3H`R+B]Q3H`O;K&U""P[;G?`%]2M.3`
MY2"_Y,.[`+SVO<4@R*[`SB"_Y,.[`+3DP.4@O^3#NP"[];?.P-N\N@#`Y\#;
MO+H`O]RZSL;MP?8@L*'!KK_`L>*WSB"UN;[&L*&QX@"\L<7#N^?'U\"XM\X@
MM;F^QK"AL>(`QNW!]L#'(+OHP:8L(,#,M;\L(+JYN^?(Q+^AM,(@QNW!]L?4
MP+BWSB"UN;[&L*&QXC\`O\"XI<+*`%]WQ^`@O-.\NBXN+@"_JL?2`,?@(+S3
MO+H`Q^`@O-.\N@#'X#H`7W7!IKCQ`%]VOZ$@NKF[Y[J[(,#ZP.7'S['B`+39
MN*4@P,RXI\"XM\X@P/K`Y0"PL,"Z(,?!M[G`TRA?<V5L9BD`P/K`Y0##M[K.
MQL3`S\"[(+JXL[W&[<'VQ]2_H2#`^L#EQ]*Q[K_D/P#`T[W#NKBP_,?4OZ$@
MP/K`Y0"\L<7#N^?'UR#`^L#E`,#3O<.ZN+#\Q]2_H2#`^L#E`+39N*7`S+BG
MP+BWSB#`^L#E`,#3O</&[<'VN*8@P-#!]B"^RL"](+OSQ<*WSB#`^L#E`+G>
MM,*[Y[;WP+L@P-JUO\"XM\X@P=:\TK?/OZ$@P]^PH<?2L>Z_Y#\`L,N[]K#A
ML/JTPB"PH;OSQNW!]L?4OZ$@P/K`Y<?2L>Z_Y#\`NKBSO<;MP?;'U+^A(,#Z
MP.4`P-.]P\;MP?8@P/K`Y2"_P+?Y+B"\K;GVP,<@O\"W^3H@)7,`PZ.QX@`E
M<R"PR[OV`+#+N_8@L.&P^@#`T,"]`,;MP?8@O+'%PP"TV;BE(+#HP:0@O+'%
MPP"SK\*E(+RQQ<,`Q]>X\2"\L<7#`,'6O-(@L,N[]B"YUR##W["AN*8@P*?'
MT2#!UKS2M\\@O+'%PP"X\+7.(+RQQ<,`P=:\TB#(KL#EO<,@L,N[]L?2(,?7
MN/$@O+'%PP"PZ,&D(+RQQ<,`O+'%PR##Z[S2`+[&MZ$@N_/`VK^AO*T@Q\J_
MY,?1(+FNP-JXIB"\L<7#Q\^P[2"ZN;OGQ\^_J2"ZV;^IL];`N+R\O^0N`+.O
MP-H@L;BZT,>EO<,@O+'%PSH`LZ_`VB#'_+W$(+RQQ<,`N-[`S[RMN?8@P;ZW
M^2"\L<7#.@"]P["C(,?\O<0@O+'%PP"USK"SP,<@P,_$H<?/M,(@Q]>X\2"\
ML<7#`,#:P=:[Y[_KQ\^TPB"^\+[NN*8@O+'%P\?/O+R_Y"X`O+'%P[7((,'6
MO-*WSSH`QNW!]B"ZN+.[L>(`N:[!IKG?N_T@NKBP[;RM(,#\O-O'S['B`+JX
ML[W&[<'VQ]0`NKBSO<;MP?;'U#H`.;_Y`+RMN?8`O*VY]K_-(,;MP?;'U"#!
MI+JX`+RMN?8Z`,;MP?8@N^C!IB"YUR#`S+6_O<,@R*^PYB"\L\&D`+#XP*\@
MQNW!]L?4`+'D(,#.O^NQV\#'(+#FO^P@L>*ZN\"XM\X@NKB_J<'9L>Z_Y"P@
MOL:TS[CI(+"HP^*Q[K_D/R"^[K:R(+#-P+L@O+'%P\?/M/6V\[6U+""PH[3<
MR/<@P/S(K\?2(+SV(,#6O<"TS[39+@#`T[W#NKBP_,?4OZ$@P/K`Y2#(Q"#`
MV[RZPZ+`NR"TW<"[L>Z_Y#\`N/"UYR#&[<'VQ]0@NKBQX@"X\+7G(+C3N+2Q
MVR"ZN+'B`,'VO_;!^"#&[<'V(+JXL>(`L>*ZNR"XT[BTL=L@NKBQX@"XWL#/
MN+6XKKVZQJX@P:2ZN""ZN+'B`+OGO^O'S[3"(,;MP?;'U+BX(+JXL>(`N^>_
MZ\?/P?8@OLJTPB#&[<'VQ]0@NKBQX@#&[<'VOZ&\K2##M[K.QL3`SR"[Z,&F
M(+[&P,S$W,"[(+JXOZG!V;'NO^0_`,;MP?;'U""ZN+'BOZ&\K2"Y_,'6(+JX
ML>(`L*'!KK_`L>(@OL;`S,3<P+L@N-ZTNKG9OZ$@NKB_J<'9L>Z_Y#\`O+\@
MO-.\NL.B(+JXL>(`QZ4@O-.\NL.B(+JXL>(`OZT@O-.\NL.B(+JXL>(`N-ZT
MNKG9OZ$@Q\K%S2"^QL#,Q-S`NR"ZN+^IP=FQ[K_D/P"QU[BR(+S3O+K#HB"Z
MN+'B`,;MP?;'U"#`_,.\(,;MP?8@L+F\]KBF(,>EO</'TK'NO^0_`+JXOZG!
MUK'B`%]ZQ:FQX@"^S\BCR*VUR@#%J;'B`,"OP?:P_+BN(+O]MZL`NKBSO;OG
MMO<@P:2WQ`#&[<'V(,6IL>(@P:2WQ`#!IKCQ(,&DM\0`M/&QV[JXL>(@P:2W
MQ`"YWK3"N^>V]R#!I+?$`+R_L*.PW0"\OR"PYK#HO\T@L[N_ZR"[Y\#,P,<@
ML*.PW0"PQ;BN`+#%N*Z_S2##I+_LL>(`O;K&Z,;MP?;'U#H`QJ^\]B"YKL#:
M(,#4M\(`QJ^\]B"YKL#:`,.VP-H@L,N[YP##ML#:(+#+N^>QX@##ML#:(+#+
MN^<@O\^WX0##ML#:(+#+N^>]PR#'T2#(K;CIOZ$@QZ6]P\?2(+_`M_FPN;SV
M`+R_(+K0Q](`OZT@NM#'T@#'X""ZT,?2`+"AO^ZUI<'9`,.WNL[&Q,#/(,&F
ML,4`O;K%N,#/6T-34UT`7TK!IKCQ`,&FN/$`P::X\0#`U+?"`,;MP?;'U""[
MY[_KQ\^QX@"^QK>AP[?`V@"\NK#X`,&FOL@`P*W#M\#:`$A434P@P-N\NKCP
MM>6WSB#`_,BO`,78O;K&KB#`V[RZN/"UY;?.(,#\R*\`QZ4@O-.\N@#'I2"\
MT[RZ`,#;OO<`7WBZN[FN`+FNP-H`N:[`VB#!I+?$`+OGO^O'V,'6O,6\K2"P
MJ+OGQ]6TS[39+@"YWK3"N^>V]R#'U[CQP,P@OZRPX;7)(+#W(+RQQ</'S['B
M`+#HP:0@(B5S(B"PH2#!]K_VP;.]P+3/M-DN`+#HP:0@(B5S(B"PH2#`^L#E
MM<>^^KW`M,^TV2X`Q_;`YR#&[<'VQ]0@(B5S(KBF("(E<R*WSB"ZK[#FQ]6T
MS[39+@#`V[RZ(,'?P,X@QNW!]K"A("<E<R<@QNW!]L?4OZ$@P/K`Y;7'OOJ]
MP+3/M-DN`,;$P,^_H2"^QKFKM[$@P-JWX;"A(+[XO<"TS[39+@`B)7,B(,;M
MP?;'U+3"(,#,N<P@P;C`Y\?5M,^TV2X`QNW!]L?4("(E<R*TPB#`W[CXM<@@
MN:[`VKBF(,;WQ]3'S[#M(,#6O<"TS[39+B#`S+#FO^P@N:[!IKBF(,#/P+C%
ML+3"(+#FO^P@O<.]NL7;(+#\N*[`VK^A(+FNP,?'S[W#L>(@N=FV^+3/M-DN
M`,;MP?;'U"`B)7,BM,(@N_V\NK7'OOK!]KBX+""[Y[_KP=_`S,'V(+[*O<"T
MS[39+@#&[<'VQ]0@(B5S(K3"(,'VO_;!L\'VN+@L(+OGO^N[\\7"N*8@Q]C!
MIL?/P?8@OLJ^TKW`M,^TV2X`QNW!]L?4("(E<R*PH2"XN+7ION[!]L'V(+[*
MOM*]P+3/M-DN(+RMN?8@O\"W^3H@`,;MP?;'U"`B)7,BL*$@P?:_]L'VP?8@
MOLJ^TKW`M,^TV2X@O*VY]B"_P+?Y.B``QNW!]L?4("(E<R*PH2"XN+7ION[!
ML[W`M,^TV2X`QNW!]L?4("(E<R*PH2#!]K_VP;.]P+3/M-DN`,;MP?;'U"`B
M)7,BL*$@(B5S(K?.(+G9LNZ^^KW`M,^TV2X`OL:WH;3"(,#,(&UE<W-A9V4O
M<F9C.#(R(,;MP?;`QR"XT[BTN+O`U+3/M-DN`+W$NK#`VB`B)7,B(+"A(+OH
MP::UQ[[ZO<"TS[39+@#&[<'VQ]0@(B5S(K3"(,#,N<P@NO&^[L#6P+TN`,;M
MP?8@P?:_]L'\`+RMN.W`NR"ZK[#FQ](@O/8@OOB]P+3/M-DN`+RMN.W`S""Z
MK[#FM<>^^KW`M,^TV2X`QNW!]B"SN[_K`,#,(,;MP?;'U+^A(,;MP?:PH2"^
M^+W`M,^TV2X`P,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+@`E<R"[
MZ,&F(+_`M_DN(+RMN?8@O\"W^3H@`,;MP?;'U""[Z,&F(+_`M_DN(+RMN?8@
MO\"W^3H@`,;$P,\@O\.XKK'BOZ$@N:[!IK"A(,#6O<"TS[39+B`E<R#&Q,#/
MP,P@OO>WSK7EM<?!]B"^RK[2O<"TS[39+@#&[<'VQ]0@(B5S(K?.NL[%S2#&
M[<'V(,'VO^RQXB"_P+?Y+B"\K;GVP,<@O\"W^3H@`,;MP?;'U"`B)7,BOZ&\
MK2#&[<'V(,'VO^RQXB"_P+?Y+B"\K;GVP,<@O\"W^3H@`,;MP?8@QZ6]PR"_
MP+?Y`,;MP?;'U"`B)7,BOZ&\K2#&[<'V(,>EO<._P+?Y+B"\K;GVP,<@O\"W
M^3H@`"5S(+"AP:Z_P+'B(+_`M_D`L*'!KK_`L>(@O\"W^3H@)7,`(B5S(K^A
MO*T@(B5S(K?.(,#,M;\@O\"W^2X@O*VY]B"_P+?Y.B``P-.]P\;MP?8@P/K`
MY2"_P+?Y`,;MP?8@NKBSN['B(+_`M_DZ("5S`+.[O^O`S""^^+W`M,^TV2X`
MP,P@2%1-3"#&[<'VM,(@L=>XLL#,(+7ION[`UKW`M,^TV2X`P,P@2%1-3"#&
M[<'VM,(@L=>XLL#,(+7ION[`UKW`M,^TV2X@NKB^R+OS(+'7N++`NB"TV<"]
ML/H@L+#`S"#'I;W#M<NTS[39.@#`S,#;OO?`NB"^X+"CP,<@O<.PH\#,(+S2
MO^2UR[3/M-DN(+#HO-/!^,?@Q\^]P[#:O<"TS['N/P#&[<'V(,#,M;_'S['B
M`,#,(+S]P-JTPB##UKS2Q]$@,<#:N*X@P,R[\\#,ONZ^WR#'U;3/M-DN`,#,
M(+"JP+H@O/W`VK^IOM\@Q]6TS[39+@"T\;';(+JXL>(`P::X\0#%N,#,QK(H
MQ?C&P2DZ`+G>M,*[Y[;W`+G>M,*[Y[;W(,'6O-(`2%1-3""\TKVZ(+JXL>(`
MP*<`N_/`IR#'P;>YP-,H7W1O<"D`P/S#O"##M[K.QL3`SR#%J;'B`,'VO^[&
M[<'VQ]0`P?:_[L;MP?;'U#H`55),`%9&4R#&Q,#/("5S+R5SP,<@QMNYS+S'
MP+L@NJ^PYL?2(+SV(+[XO<"TS[39+@!344P@O*VY]K^A(,&BO-/'TB"\]B"^
M^+W`M,^TV2X`)7,@P:3`Q[BF(,#0P+L@O/8@OOB]P+3/M-DN`'9F<W)O;W0@
MM?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+@!61E,@QL3`SR`E<R\E<\"[
M*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN`,#,(+_VM>6YKKRMN*8@NJ^PYL?2
M(+SV(+[XO<"TS[39+@"TY,#EQ\_!]B"^RL"]`+3DP.7'S\'V(+[*P+H@QNW!
M]@"ZN;&X`+G8P=D`OLN\]B"^^+3"(+SVO<7`S@"ZK[#FN^?'UR"UQ[6YN*ZQ
MX@"XML'VN+<@N.VWR2##Z[S2`+^UL;D`N<RQN0"^RR"\]B"^^+3"(+SVO<7`
MS@#']L#G(+_DO-*_H2"XM<6I(,&FL,4`P,RXIR"^^,"]`,#0P?:^RL"]`+OV
ML?(@P::PQ0#&[<'VQ]0@N^>_Z\?/P?8@OLK`O0##M[K.QL3`SR#!I+JX(+OU
MM\ZP[<2G`+;SQKZ^[B"TZ[FNP-H`M\ZXMB"TZ[FNP-H@O/W`V@"QXKJ[L*H@
MN^>_ZP!)34%0(,;MP?;'U"!3=6)S8W)I<'1I;VX@N^>_ZP"[Y[_KP-H@O+'%
MP[OGQ]<`N^>_Z\#:N.T`N^>_Z\#:N.TZ`+W#O;K%V\#'(+OGO^O`VCH`O/;!
M]R#!I+?$`+SVP?<@PZ2_\@"ZN+'B`"5S(+JXL>(`N_4@PZ*_H;RM($A434P@
ML[N_ZR"ZN+'B`+OU(,.BOZ&\K2##M[K.(+JXL>(`N_4@PZ*_H;RM(+.[O^L@
MNKBQX@`E<\#'(,;MP?8@NKBQX@"WSK'7P,X@R,0@NKB_J<'9(+#W`+'7N+(@
MNKBQX@"PH;OS(,;MP?;'U"`B)7,BL*$@N_V\NK7'OOJ]P+3/M-DN`+"AN_,@
MQNW!]L?4`+"AP.7&[<'VQ]3`NB#`S+BGP,P@Q\J_Y,?5M,^TV2X`L*'`Y<;M
MP?;'U"#`S+BG`+#FL.T`N,7!U@#(K[^U`,BOO[7'U;3/M-DL("5S`+&XNM`@
MN:[`VK3"(+FKOOG`U+3/L>X_`,#.O^L@NL[(H[3"(+FKOOG`U+3/L>X_`,;M
MP?:XIB#!]K_LN.DL(,'VO_(@QZ6]P[BF(,?/M,(@M.N]Q2#!]K_NQNW!]L?4
MP+BWSB#`S+6_Q]6TS[39+@#&[<'VQ]3`NR"_K2"VIRP@ONZVLB#&Y,#,P?:_
MH;RM(+W#P-O'S['BN*8@O_C'S[W*M,^Q[C\`NKBSO2#&[<'VN*8@P/K`Y<?2
M(+:G+"##M[K.QL3`S\"[(,#ZP.7'TK'NO^0_`+SVO<6]PL#.`+/*NO$`QZ7`
MQR"SRKKQ`+/*NO$@M-S`IP"SRKKQ.@#!]\#E(,'6O-(Z`,'WP.4@P/S(K;GX
MR*,`65D`N,6SX@"_N0"[]2#&^K3UM\X@NKF[YR_`S+6_(,?/M\&P[2#'U;3/
MM-DN`,?/P*<@QNW!]L?4P+L@N+BU[+3/M-DN(`"[\\"G(,;MP?;'U,"[(+BX
MM>RTS[39+B``5$585+CPM>7`U+3/M-DN(%L\/ET@N?;&L,"[(+2IN*.XZ2!7
M65-)5UE'(+CPM>6WSB"UN;[&L*FTS[39+@#&[<'VQ]0@P,RXIR"ZK[#F.B``
M)7.PL\#'(+OU(,;MP?:PH2#`UKW`M,^TV2X`,;"SP,<@N_4@QNW!]K"A(,#6
MO<"TS[39+@"WSK'7OL:_]"#'S[^TO<"TS[39+@"TV<"]P,<@QNW!]L?4OZ$@
MN_4@QNW!]K"A(,#6O<"TS[39.@"TV<"]P,<@QNW!]L?4OZ$@N_4@QNW!]K"A
M(,#6O<"TS[39.@"YKL&F(+JXL.V\K;BF(+JXL[NQXL#\OZ$@P,RYKL&FOZ$@
MM.O'T2"\L[CMP+L@P-2WPL?8OM\@Q]6TS[39+@"YWK3"N^>V]\"[(,#4M\+'
MS[R\O^0N`,#,(+BUQ:FPH2"PH;BNQ*&TPB!54DS`NR#`U+?"Q]B^WR#'U;3/
MM-DN`+3KN_,@QNW!]L?4P+L@N-7`^B"\L<7#Q]B^WR#'U;3/M-DN`,'6O-*X
MIB"XU<#Z(+RQQ</'V+[?(,?5M,^TV2X`QNW!]KBF(+C5P/H@O+'%P\?/O+R_
MY"X`O/:]Q<#.P,P@OOB]P+3/M-DN`+OHP:;'TB"[Y[_KP-H@P,RXI\"[(,#4
MM\+'V+[?(,?5M,^TV2X`QL3`SR##M[K.N*8@N-7`^B#`U+?"Q]B^WR#'U;3/
MM-DN`,/?L*''TB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2X`)7._
MH2"TY,#E(+JXL[\N`"(E<R(@QNW!]L?4(+OGO^O'S['B(+_`M_DN(+RMN?;`
MQR"_P+?Y.B``(B5S(B#&[<'VQ]0@N^>_Z\?/P?8@OLK`O2"_P+?Y+B"\K;GV
MP,<@O\"W^3H@`"(E<R(@QNW!]L?4P+L@N^>_Z\?5M,^TV2X`(B5S(B#&[<'V
MQ]3`NR"[Y[_KQ\_!]B"^RKW`M,^TV2X`)7,@O+R\Q\#,(+BXM^&UQ[[ZO<"T
MS[39+B"TV;W#(+?.L=?`SL?/O+R_Y"X`P,RXWL#/(,'6O-(Z`+C>P,\@P=:\
MTCH`P:2ZN`"PZ,&D.@"TY[W%P,<@P,[!]<6LMO/`S+[PQJZPH2"[Y[_KP-H@
MN/&WS[JXL>*XIB#!]K_XQ\_!]B"^RKW`M,^TV2X@ML>TPB"TV;BE(,#,P*^W
MSB"[Y[_KP-H@N/&WS[JXL>*XIB"[Y[_KQ](@O/8@OOB]P+3/M-DN`+KJMO._
M[,&NL*$@P,P@L=>XLB#'_+W$P+L@QZ6]P\?/P?8@N/C'U;3/M-DN`+KJMO._
M[,#ZL*$@P,P@L>*TR<"[(,'VO_C'S\'V(+[*O<"TS[39+@#']L#G(+W#L*.T
MZSH`QNW!]B"ZN+.^(+:G(+OGO^O'TB"QXKJ[(+FNP-J\PCH`L>*ZNR"]Q+JP
MP-HZ`,#\P[P@P,RXISH`QNW!]K"A(+RZL/C`^\"XM\X@P/R\V[7'OOJ]P+3/
MM-DN`,#,(+R\O,<@M;^^R""_R;S'P,P@P/K`Y;7+M,^TV2X`O\F\Q\#,(,#Z
MP.6UQ[[ZO<"TS[39+@"\K;CM.@!;P,Z_ZR"\^['BL>)=`%O!IKCQ(+[XP+U=
M`%N_P+?Y(+JXL.W'S['B70!;P,Z_ZR"ZN+'B("T`6\#.O^L@NKBQXB`M("5S
M(,'970!;MO/`SB`E<R`O("5S70!?0;#\N*X`7T*\^\"ZPOS!M@!?0KSVO<6P
MQ;K.`%]#POS!M@!?1,'VO^RQX@!?1,?@(,'VO_(`7T;&[<'VQ]0`M;6_\KB[
M`%])O<2ZL,#:`%])L=>XLB"\T[RZ+BXN`%])N=[`NL;MP?;'U`!?3+?.L=>^
MQK_T`%]-QNW!]B"\TKVZNKBQX@!?;;BUQ:D@O/;!I"XN+@!?3[RQQ<.[Y\?7
M`%]0P,Z\X@!?4,'?O^2UM0!?<KBUQ:D@N^C!IBXN`%]2M.3`Y0!?4[#+N_8`
M7U/&[<'V(+JXL[NQX@!?=,>E(+S3O+HN+BX`7U2T\;';O/@`7U2YWK3"N^>V
M]P!?5;JYL;@`7U:T\;';NKBQX@!?5[SVO<6]PL#.`+G9P,S&K@#`I\2A`,'9
M70"_[,;MQ]0@QL3`SP#`S+BG`+[XP+T`ML>TP@#&V[R^QJX`Q\B\OP##ML#:
M(+_`M_D`P[;`VB"_P+?Y`,#,N*<@OOC`O0!V0V%R9`"\]KW%L,6ZSKCQM\\`
MO/:]Q;W"P,ZX\;?/````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]K;U]+
M4B]H96QP+GAM;```````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R
M-C0T-P`Q,#0Q-S,V,C<V,P`P,C$Q-#,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA
M+2T@)$AO<F1E.B!I;7`O;&]C86QE+VMO7TM2+VAE;'`N>&UL+'8@,2XQ-BXV
M+C0@,C`P-B\P,2\S,"`Q-3HU.#HP,"!J86X@17AP("0@+2T^"CQH96QP/@H@
M(#QE;G1R>2!I9#TB8V]M<&]S92UB=71T;VYS(B!S=&%T93TB=6YK;F]W;B(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@06-T:6]N<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY!8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!396YD($UE<W-A9V4@;&%U;F-H97,@>6]U<B!E;6%I;"!T;R!T:&4@
M:6YT96YD960@<F5C:7!I96YT*',I+B!"92!S=7)E('EO=2!W86YT('1O('-E
M;F0@8F5F;W)E(&-L:6-K:6YG(&AE<F4@87,@;VYC92!S96YT(&ET(&-A;FYO
M="!B92!T86ME;B!B86-K+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3
M879E($1R869T('!L86-E<R!A;B!U;F9I;FES:&5D(&UE<W-A9V4@:6X@82!F
M;VQD97(@8V%L;&5D("=$<F%F=',G"F%C8V5S<VEB;&4@8GD@=&AE('!O<"UD
M;W=N(&)O>"!O;B!T:&4@<FEG:'0@<VED92!O9B!T:&4@8FQU92!N879I9V%T
M:6]N(&)A<B!A="!T;W`N(%EO=2!C86X@=&AE;B!F:6YI<V@@=&AE(&UE<W-A
M9V4@;&%T97(@8GD@<W=I=&-H:6YG('1O('1H92`G1')A9G1S)R!F;VQD97(L
M(&-L:6-K:6YG(&]N('1H92!S879E9"!M97-S86=E('1O(&]P96X@:70L(&%N
M9"!T:&5N(&-L:6-K:6YG(&]N("=297-U;64G+B!"92!S=7)E('1O('!U="!A
M('-U8FIE8W0@;VX@=&AE(&5M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A
M9G0@<V\@=&AA="!Y;W4@8V%N(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S
M86=E('EO=2!W86YT('=I=&AI;B!T:&4@1')A9G1S(&9O;&1E<BX@069T97(@
M<V%V:6YG(&%S(&$@1')A9G0L('EO=2!A<F4@<F5T=7)N960@=&\@>6]U<B!)
M3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#86YC96P@365S<V%G92!D
M<F]P<R!T:&4@;65S<V%G92!I;B!P<F]G<F5S<R!A;F0@<VEM<&QY(')E='5R
M;G,@>6]U('1O('1H92!)3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E
M<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UB=71T;VYS(CX*("`@(#QT:71L93Y-
M97-S86=E($-O;7!O<VET:6]N.B!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D
M:6YG/D%C=&EO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@365S
M<V%G92!L875N8VAE<R!Y;W5R(&5M86EL('1O('1H92!I;G1E;F1E9"!R96-I
M<&EE;G0H<RDN($)E('-U<F4@>6]U('=A;G0@=&\@<V5N9"!B969O<F4@8VQI
M8VMI;F<@:&5R92!A<R!O;F-E('-E;G0@:70@8V%N;F]T(&)E('1A:V5N(&)A
M8VLN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-A=F4@1')A9G0@<&QA
M8V5S(&%N('5N9FEN:7-H960@;65S<V%G92!I;B!A(&9O;&1E<B!C86QL960@
M)T1R869T<R<*86-C97-S:6)L92!B>2!T:&4@<&]P+61O=VX@8F]X(&]N('1H
M92!R:6=H="!S:61E(&]F('1H92!B;'5E(&YA=FEG871I;VX@8F%R(&%T('1O
M<"X@66]U(&-A;B!T:&5N(&9I;FES:"!T:&4@;65S<V%G92!L871E<B!B>2!S
M=VET8VAI;F<@=&\@=&AE("=$<F%F=',G(&9O;&1E<BP@8VQI8VMI;F<@;VX@
M=&AE('-A=F5D(&UE<W-A9V4@=&\@;W!E;B!I="P@86YD('1H96X@8VQI8VMI
M;F<@;VX@)U)E<W5M92<N($)E('-U<F4@=&\@<'5T(&$@<W5B:F5C="!O;B!T
M:&4@96UA:6P@8F5F;W)E('EO=2!S879E('1H92!D<F%F="!S;R!T:&%T('EO
M=2!C86X@96%S:6QY(&ED96YT:69Y('=H:6-H(&UE<W-A9V4@>6]U('=A;G0@
M=VET:&EN('1H92!$<F%F=',@9F]L9&5R+B!!9G1E<B!S879I;F<@87,@82!$
M<F%F="P@>6]U(&%R92!R971U<FYE9"!T;R!Y;W5R($E.0D]8(&]R('=H871E
M=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@($-A;F-E;"!-97-S86=E(&1R;W!S('1H92!M97-S
M86=E(&EN('!R;V=R97-S(&%N9"!S:6UP;'D@<F5T=7)N<R!Y;W4@=&\@=&AE
M($E.0D]8(&]R('=H871E=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA
M<W0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](F-O;7!O<V4M9G)O;2(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/DUE<W-A9V4@0V]M<&]S:71I;VXZ($9R;VT\+W1I=&QE/@H@("`@/&AE861I
M;F<^(D9R;VTB/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!Y;W5R
M(&-O<G)E8W0@96UA:6P@861D<F5S<RX@66]U<B!E;6%I;"!A9&1R97-S(&ES
M(&%U=&]M871I8V%L;'D@96YT97)E9"!F;W(@>6]U(&9O;&QO=VEN9R`B1G)O
M;3HB(&EN(&]U=&=O:6YG(&5M86EL+@H@("`@/"]P87)A/@H\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UF<F]M(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!&<F]M/"]T:71L93X*("`@(#QH96%D
M:6YG/B9Q=6]T.T9R;VTF<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($5N=&5R('EO=7(@8V]R<F5C="!E;6%I;"!A9&1R97-S+B!9;W5R(&5M86EL
M(&%D9')E<W,@:7,@875T;VUA=&EC86QL>2!E;G1E<F5D(&9O<B!Y;W4@9F]L
M;&]W:6YG("9Q=6]T.T9R;VTZ)G%U;W0[(&EN(&]U=&=O:6YG(&5M86EL+@H@
M("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C
M;VUP;W-E+71O(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@5&\\+W1I=&QE/@H@("`@/&AE861I;F<^(E1O(CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA
M:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!Y;W5R(&UE<W-A
M9V4N(%EO=2!M=7-T('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M
M;6$[(&]T:&5R('!U;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R
M+B!9;W5R(&5N=')Y(&9O;&QO=W,@(E1O.B(@:6X@;W5T9V]I;F<@;6%I;"X@
M(`H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB
M8V]M<&]S92UT;R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@
M5&\\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[5&\F<75O=#L\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D
M9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@>6]U<B!M97-S86=E+B!9
M;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O
M=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U
M<B!E;G1R>2!F;VQL;W=S("9Q=6]T.U1O.B9Q=6]T.R!I;B!O=71G;VEN9R!M
M86EL+B`@"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT
M<GD@:60](F-O;7!O<V4M8V,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!#8SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SXB0V,B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R
M<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@
M8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E+B!397!A<F%T92!E86-H(&%D
M9')E<W,@=VET:"!A(&-O;6UA+B!9;W5R(&5N=')Y(&9O;&QO=W,@(D-C.B(@
M:6X@;W5T9V]I;F<@;6%I;"X@0V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S
M96YT('1O('!E;W!L92!O=&AE<B!T:&%N('1H92!O;F4H<RD@8F5I;F<@=W)I
M='1E;B!T;R!D:7)E8W1L>2!B=70@87)E(&EM<&]R=&%N="!R96-I<&EE;G1S
M(&]F('1H92!E;6%I;"!A<R!W96QL+"!U<W5A;&QY('-O;65O;F4@:6YD:7)E
M8W1L>2!C;VYC97)N960@86)O=70@=&AE('-U8FIE8W0@;V8@=&AE(&5M86EL
M+B`@06QL("=4;SHG(')E8VEP:65N=',@86YD("=#8SHG(')E8VEP:65N=',@
M8V%N('-E92!T:&4@96YT:7)E(&QI<W0@;V8@8F]T:"!K:6YD<R!O9B!R96-I
M<&EE;G1S+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB8V]M<&]S92UC8R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@0V,\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[0V,F<75O=#L\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M
M86EL(&%D9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@82!C87)B;VX@
M8V]P>2!O9B!Y;W5R(&UE<W-A9V4N(%-E<&%R871E(&5A8V@@861D<F5S<R!W
M:71H(&$@8V]M;6$N(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O=#M#8SHF<75O
M=#L@:6X@;W5T9V]I;F<@;6%I;"X@0V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL
M>2!S96YT('1O('!E;W!L92!O=&AE<B!T:&%N('1H92!O;F4H<RD@8F5I;F<@
M=W)I='1E;B!T;R!D:7)E8W1L>2!B=70@87)E(&EM<&]R=&%N="!R96-I<&EE
M;G1S(&]F('1H92!E;6%I;"!A<R!W96QL+"!U<W5A;&QY('-O;65O;F4@:6YD
M:7)E8W1L>2!C;VYC97)N960@86)O=70@=&AE('-U8FIE8W0@;V8@=&AE(&5M
M86EL+B`@06QL("=4;SHG(')E8VEP:65N=',@86YD("=#8SHG(')E8VEP:65N
M=',@8V%N('-E92!T:&4@96YT:7)E(&QI<W0@;V8@8F]T:"!K:6YD<R!O9B!R
M96-I<&EE;G1S+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+6)C8R(@<W1A=&4](G5N:VYO=VXB/@H@("`@
M/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($)C8SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SXB0F-C(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@
M=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C
M96EV92!A(&)L:6YD(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@66]U
M(&UU<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H
M97(@<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@
M96YT<GD@9F]L;&]W<R`B0F-C.B(@:6X@;W5T9V]I;F<@;6%I;"X@0FQI;F0@
M8V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S96YT('1O('!E;W!L92!O=&AE
M<B!T:&%N(&1I<F5C="!A;F0@:6YD:7)E8W0@<F5C:7!I96YT<R`H(E1O.B(@
M86YD(")#8SHB(')E8VEP:65N=',I('=H;R!N965D('1O(')E860@=VAA="!I
M<R!B96EN9R!W<FET=&5N(&%S('=E;&P@5TE42$]55"!T:&4@;W1H97(@<F5C
M:7!I96YT<R!K;F]W:6YG('1H870@=&AE>2!A<F4@<F5C96EV:6YG('1H92!E
M;6%I;"X@5&AU<R`G8FQI;F0G(&UE86YS('1H870@=&AE(&ED96YT:71Y(&]F
M('1H97-E(')E8VEP:65N=',@:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R(')E
M8VEP:65N=',@;V8@=&AE(&5M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H97D@
M:VYO=R!T:&5Y(&=O="!A(&-O<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H:7,@
M=&\@=&5L;"!A;B!A=71H;W)I='D@9FEG=7)E('1H870@>6]U(&%R92!T96QL
M:6YG('-O;65O;F4@<V]M971H:6YG('=I=&AO=70@86QA<FUI;F<@=&AE('!E
M<G-O;B!Y;W4@87)E('-E;F1I;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*("`@
M(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O
M<V4M8F-C(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\
M+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[0F-C)G%U;W0[/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R
M97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@8FQI;F0@8V%R8F]N(&-O
M<'D@;V8@>6]U<B!M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D
M9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E
M<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T)C
M8SHF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@0FQI;F0@8V%R8F]N(&-O<&EE
M<R!A<F4@=7-U86QL>2!S96YT('1O('!E;W!L92!O=&AE<B!T:&%N(&1I<F5C
M="!A;F0@:6YD:7)E8W0@<F5C:7!I96YT<R`H)G%U;W0[5&\Z)G%U;W0[(&%N
M9"`F<75O=#M#8SHF<75O=#L@<F5C:7!I96YT<RD@=VAO(&YE960@=&\@<F5A
M9"!W:&%T(&ES(&)E:6YG('=R:71T96X@87,@=V5L;"!7251(3U54('1H92!O
M=&AE<B!R96-I<&EE;G1S(&MN;W=I;F<@=&AA="!T:&5Y(&%R92!R96-E:79I
M;F<@=&AE(&5M86EL+B!4:'5S("=B;&EN9"<@;65A;G,@=&AA="!T:&4@:61E
M;G1I='D@;V8@=&AE<V4@<F5C:7!I96YT<R!I<R!H:61D96X@9G)O;2!A;&P@
M;W1H97(@<F5C:7!I96YT<R!O9B!T:&4@96UA:6PL(&%N9"!O;FQY('EO=2!A
M;F0@=&AE>2!K;F]W('1H97D@9V]T(&$@8V]P>2X@66]U('1Y<&EC86QL>2!U
M<V4@=&AI<R!T;R!T96QL(&%N(&%U=&AO<FET>2!F:6=U<F4@=&AA="!Y;W4@
M87)E('1E;&QI;F<@<V]M96]N92!S;VUE=&AI;F<@=VET:&]U="!A;&%R;6EN
M9R!T:&4@<&5R<V]N('EO=2!A<F4@<V5N9&EN9R!T:&4@86-T=6%L(&5M86EL
M('1O+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)C;VUP;W-E+7-U8FIE8W0B('-T871E/2)U;FMN;W=N(CX*("`@(#QT
M:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!3=6)J96-T/"]T:71L93X*("`@
M(#QH96%D:6YG/B)3=6)J96-T(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M16YT97(@=&AE('-U8FIE8W0@;V8@>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y
M(&9O;&QO=W,@(E-U8FIE8W0Z(B!I;B!O=71G;VEN9R!M86EL+B!+965P(&ET
M('-H;W)T+"!S:6UP;&4@86YD(&1E<V-R:7!T:79E+B`@5&AE('-U8FIE8W0@
M;&EN92!I<R!T:&4@96%S:65S="!W87D@9F]R('EO=2!A;F0@>6]U<B!C;W)R
M97-P;VYD96YT<R!T;R!R96UE;6)E<B!W:&%T('=A<R!I;B!T:&4@96UA:6P@
M86YD('1H=7,@:7,@=F5R>2!I;7!O<G1A;G0@:6X@;W)G86YI>FEN9R!Y;W5R
M(&5M86EL(&%N9"!F:6YD:6YG(&EM<&]R=&%N="!O;F5S(&QA=&5R+B`@06QS
M;RP@=VAE;B!Y;W4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@86YD(&5M86EL('1H
M:7,@<W5B:F5C="!L:6YE(&ES(&-O<&EE9"!O=F5R(&EN=&\@=&AE(&YE=R!M
M97-S86=E(&%N9"!S;R!I<R!A('9A;'5A8FQE('=A>2!O9B!T96QL:6YG('=H
M870@;65S<V%G97,@9V\@=&]G971H97(@=&\@9F]R;2!A(")T:')E860B(&]F
M(&$@8V]N=F5R<V%T:6]N+B`@2&]W979E<BP@:68@=&AE("=297!L>2<@;W(@
M)T9O<G=A<F0G(&-O;G1A:6YS(&YE=R!I9&5A<RP@>6]U(&UA>2!W86YT('1O
M(&%D9"!S:6UP;&4@;6]D:69I8V%T:6]N<R!T;R!T:&4@)U-U8FIE8W0G(&QI
M;F4@<V\@=&AE(')E8VEP:65N="AS*2!C86X@9F]L;&]W('1H92!P<F]G<F5S
M<VEO;B!O9B!T:&4@(G1H<F5A9"XB"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES
M:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+7-U8FIE8W0B/@H@("`@/'1I
M=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%-U8FIE8W0\+W1I=&QE/@H@("`@
M/&AE861I;F<^)G%U;W0[4W5B:F5C="9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@16YT97(@=&AE('-U8FIE8W0@;V8@>6]U<B!M97-S86=E+B!9
M;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[4W5B:F5C=#HF<75O=#L@:6X@;W5T
M9V]I;F<@;6%I;"X@2V5E<"!I="!S:&]R="P@<VEM<&QE(&%N9"!D97-C<FEP
M=&EV92X@(%1H92!S=6)J96-T(&QI;F4@:7,@=&AE(&5A<VEE<W0@=V%Y(&9O
M<B!Y;W4@86YD('EO=7(@8V]R<F5S<&]N9&5N=',@=&\@<F5M96UB97(@=VAA
M="!W87,@:6X@=&AE(&5M86EL(&%N9"!T:'5S(&ES('9E<GD@:6UP;W)T86YT
M(&EN(&]R9V%N:7II;F<@>6]U<B!E;6%I;"!A;F0@9FEN9&EN9R!I;7!O<G1A
M;G0@;VYE<R!L871E<BX@($%L<V\L('=H96X@>6]U("=297!L>2<@;W(@)T9O
M<G=A<F0G(&%N9"!E;6%I;"!T:&ES('-U8FIE8W0@;&EN92!I<R!C;W!I960@
M;W9E<B!I;G1O('1H92!N97<@;65S<V%G92!A;F0@<V\@:7,@82!V86QU86)L
M92!W87D@;V8@=&5L;&EN9R!W:&%T(&UE<W-A9V5S(&=O('1O9V5T:&5R('1O
M(&9O<FT@82`F<75O=#MT:')E860F<75O=#L@;V8@82!C;VYV97)S871I;VXN
M("!(;W=E=F5R+"!I9B!T:&4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@8V]N=&%I
M;G,@;F5W(&ED96%S+"!Y;W4@;6%Y('=A;G0@=&\@861D('-I;7!L92!M;V1I
M9FEC871I;VYS('1O('1H92`G4W5B:F5C="<@;&EN92!S;R!T:&4@<F5C:7!I
M96YT*',I(&-A;B!F;VQL;W<@=&AE('!R;V=R97-S:6]N(&]F('1H92`F<75O
M=#MT:')E860N)G%U;W0["B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R
M>3X*("`\96YT<GD@:60](F-O;7!O<V4M;W!T:6]N<R(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($]P=&EO;G,\
M+W1I=&QE/@H@("`@/&AE861I;F<^(D]P=&EO;G,B/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!4:&5S92!/<'1I;VYS(&AE;'`@>6]U('!R97!A<F4@>6]U
M<B!M97-S86=E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`B
M4W!E;&P@0VAE8VLB('1O(&-H96-K('EO=7(@<W!E;&QI;F<N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@($-L:6-K(")!='1A8VAM96YT<R(@=&\@=FEE
M=R!A="!T:&4@8F]T=&]M(&]F('1H92!P86=E(&$@;&ES="!O9B!F:6QE<R!A
M='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R`B4V%V
M92!C;W!Y(B!T;R!S879E(&$@8V]P>2!O9B!T:&ES(&UE<W-A9V4@:6X@>6]U
M<B`B4V5N="!-86EL(B!F;VQD97(N(%-A=F4@8V]P:65S(&]F(&EM<&]R=&%N
M="!E;6%I;',@>6]U('-E;F0@<V\@=&AA="!Y;W4@:&%V92!S;VUE=&AI;F<@
M=&\@<F5F97(@8F%C:R!T;R!L871E<B!A;F0@=&\@:V5E<"!A;B!A8V-U<F%T
M92!R96-O<F0@;V8@=VAA="!W87,@<V%I9"X@5V4@9&\@;F]T(')E8V]M;65N
M9"!Y;W4@<V%V92!E=F5R>2!E;6%I;"!S:6YC92!T:&5N('EO=7(@9&ES:R!S
M=&]R86=E('%U;W1A('=I;&P@8F4@=7-E9"!U<"!Q=6EC:VQY("AE<W!E8VEA
M;&QY('=H96X@>6]U('-E;F0@871T86-H;65N=',I(&%N9"!Y;W5R(&UA:6QB
M;W@@=VEL;"!B92!F=6QL(&%N9"!U;F%B;&4@=&\@<F5C96EV92!N97<@:6YC
M;VUI;F<@96UA:6PN(%EO=2!C86XL(&AO=V5V97(L('1U<FX@=&AI<R!F96%T
M=7)E("=O;B<@87,@>6]U<B!D969A=6QT('=I=&@@)U!R969E<F5N8V5S)R!O
M;B!T:&4@8FQU92!N879I9V%T:6]N(&)A<B!A="!T;W`N($)E(&-A<F5F=6P@
M=VAE;B!U<VEN9R!T:&ES(&UO9&EF:65D(&1E9F%U;'0@87,@>6]U('=I;&P@
M;F5E9"!T;R!P97)I;V1I8V%L;'D@<'5R9V4@>6]U<B`B4V5N="!-86EL(B!F
M;VQD97(@;W(@:70@=VEL;"!E=F5N='5A;&QY(&UA:V4@>6]U<B!M86EL8F]X
M(&9U;&P@86YD('5N=7-E86)L92X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H
M(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M;W!T:6]N<R(^"B`@("`\=&ET
M;&4^365S<V%G92!#;VUP;W-I=&EO;CH@3W!T:6]N<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SXF<75O=#M/<'1I;VYS)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4:&5S92!/<'1I;VYS(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M
M97-S86=E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`F<75O
M=#M3<&5L;"!#:&5C:R9Q=6]T.R!T;R!C:&5C:R!Y;W5R('-P96QL:6YG+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`F<75O=#M!='1A8VAM
M96YT<R9Q=6]T.R!T;R!V:65W(&%T('1H92!B;W1T;VT@;V8@=&AE('!A9V4@
M82!L:7-T(&]F(&9I;&5S(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@06-T:79A=&4@=&AE(&-H96-K+6)U
M='1O;B!N97AT('1O("9Q=6]T.U-A=F4@8V]P>29Q=6]T.R!T;R!S879E(&$@
M8V]P>2!O9B!T:&ES(&UE<W-A9V4@:6X@>6]U<B`F<75O=#M396YT($UA:6PF
M<75O=#L@9F]L9&5R+B!3879E(&-O<&EE<R!O9B!I;7!O<G1A;G0@96UA:6QS
M('EO=2!S96YD('-O('1H870@>6]U(&AA=F4@<V]M971H:6YG('1O(')E9F5R
M(&)A8VL@=&\@;&%T97(@86YD('1O(&ME97`@86X@86-C=7)A=&4@<F5C;W)D
M(&]F('=H870@=V%S('-A:60N(%=E(&1O(&YO="!R96-O;6UE;F0@>6]U('-A
M=F4@979E<GD@96UA:6P@<VEN8V4@=&AE;B!Y;W5R(&1I<VL@<W1O<F%G92!Q
M=6]T82!W:6QL(&)E('5S960@=7`@<75I8VML>2`H97-P96-I86QL>2!W:&5N
M('EO=2!S96YD(&%T=&%C:&UE;G1S*2!A;F0@>6]U<B!M86EL8F]X('=I;&P@
M8F4@9G5L;"!A;F0@=6YA8FQE('1O(')E8V5I=F4@;F5W(&EN8V]M:6YG(&5M
M86EL+B!9;W4@8V%N+"!H;W=E=F5R+"!T=7)N('1H:7,@9F5A='5R92`G;VXG
M(&%S('EO=7(@9&5F875L="!W:71H:6X@>6]U<B!)9&5N=&ET>2P@8GD@9V]I
M;F<@=&\@3W!T:6]N<RTF9W0[4&5R<V]N86P@26YF;W)M871I;VXM)F=T.T5D
M:70@>6]U<B!I9&5N=&ET:65S+B!"92!C87)E9G5L('=H96X@=7-I;F<@=&AI
M<R!M;V1I9FEE9"!D969A=6QT(&%S('EO=2!W:6QL(&YE960@=&\@<&5R:6]D
M:6-A;&QY('!U<F=E('EO=7(@)G%U;W0[4V5N="!-86EL)G%U;W0[(&9O;&1E
M<B!O<B!I="!W:6QL(&5V96YT=6%L;'D@;6%K92!Y;W5R(&UA:6QB;W@@9G5L
M;"!A;F0@=6YU<V5A8FQE+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:"(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:#PO
M=&ET;&4^"B`@("`\:&5A9&EN9SXB071T86-H(CPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@("`@(%EO=2!M87D@871T86-H(&9I;&5S('1O('EO=7(@;65S
M<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,3H@16ET:&5R+"!T
M>7!E('1H92!P871H(&%N9"!N86UE(&]F(&$@9FEL92!T:&%T('EO=2!W86YT
M(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92!O<B!C;&EC:R`B0G)O=W-E(B!B
M=71T;VX@86YD('-E;&5C="!T:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H
M92!P871H(&%N9"!N86UE(&]F('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T
M:&4@071T86-H;65N="!B;W@N($YO=R!P<F]C965D('1O"E-T97`@,BX*("`@
M(#PO<&%R83X*("`@(#QP87)A/E-T97`@,CH@0VQI8VL@(D%T=&%C:"(@8G5T
M=&]N+B!4:&4@9FEL92!N86UE(&%N9"!S:7IE('=I;&P@8F4@861D960@=&\@
M>6]U<B!L:7-T(&]F($%T=&%C:&UE;G1S+B!0;&5A<V4@;F]T92!T:&%T(&9O
M<B!L87)G92!F:6QE<R!A;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O;FYE8W1I
M;VYS+"!T:&4@<')O8V5S<R!O9B!U<&QO861I;F<@86YD(&%T=&%C:&EN9R!Y
M;W5R(&9I;&4@=&\@=&AE(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N(%!L96%S
M92!B92!P871I96YT(&%N9"!D;R!N;W0@8VQI8VL@;VX@;W1H97(@=&AI;F=S
M('=H:6QE('EO=2!A<F4@=V%I=&EN9RX*("`@(#PO<&%R83X*/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M871T86-H(CX*("`@(#QT
M:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8V@\+W1I=&QE/@H@("`@
M/&AE861I;F<^)G%U;W0[071T86-H)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!9;W4@;6%Y(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4[
M(&]N;'D@;VYE(&9I;&4@;6%Y(&)E(&%T=&%C:&5D(&%T(&$@=&EM92X*("`@
M(#PO<&%R83X*("`@(#QP87)A/E-T97`@,3H@16ET:&5R+"!T>7!E('1H92!P
M871H(&%N9"!N86UE(&]F(&$@9FEL92!T:&%T('EO=2!W86YT(&%T=&%C:&5D
M('1O('1H:7,@;65S<V%G92!O<B!C;&EC:R`F<75O=#M"<F]W<V4F<75O=#L@
M8G5T=&]N(&%N9"!S96QE8W0@=&AE(&9I;&4@=&\@8F4@871T871C:&5D+B!4
M:&4@<&%T:"!A;F0@;F%M92!O9B!T:&%T(&9I;&4@;F]W(&%P<&5A<G,@:6X@
M=&AE($%T=&%C:&UE;G0@8F]X+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E
M<"`R.B!$96-I9&4@=VAE=&AE<B!Y;W4@=V%N="!T:&4@9FEL92!T;R!B92!V
M:65W960@87,@86X@871T86-H;65N="!O<B!I;FQI;F5D('=I=&@@=&AE(')E
M<W0@;V8@=&AE(&UE<W-A9V4N(%1H92!R96-E:79I;F<@<&5R<V]N*',I(&UA
M:6P@<F5A9&EN9R!S;V9T=V%R92!M=7-T(&)E(&%B;&4@=&\@:&%N9&QE('1H
M92!F:6QE('1Y<&4@:6YL:6YE.R!I9B!N;W0L('1H:7,@<&%R="!W:6QL(&)E
M('9I97=E9"!A<R!A;B!A='1A8VAM96YT(&EN<W1E860N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83Y3=&5P(#,Z($-L:6-K("9Q=6]T.T%T=&%C:"9Q=6]T.R!B
M=71T;VXN(%1H92!F:6QE(&YA;64@86YD('-I>F4@=VEL;"!B92!A9&1E9"!T
M;R!Y;W5R(&QI<W0@;V8@071T86-H;65N=',N(%!L96%S92!N;W1E('1H870@
M9F]R(&QA<F=E(&9I;&5S(&%N9"]O<B!S;&]W97(@26YT97)N970@8V]N;F5C
M=&EO;G,L('1H92!P<F]C97-S(&]F('5P;&]A9&EN9R!A;F0@871T86-H:6YG
M('EO=7(@9FEL92!T;R!T:&4@96UA:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE
M87-E(&)E('!A=&EE;G0@86YD(&1O(&YO="!C;&EC:R!O=&AE<B!T:&EN9W,@
M=VAI;&4@>6]U(&%R92!W86ET:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM
M/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(B!S
M=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO
M;CH@071T86-H;65N=',\+W1I=&QE/@H@("`@/&AE861I;F<^(D%T=&%C:&UE
M;G1S(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S96-T:6]N(&1I
M<W!L87ES(&$@;&ES="!O9B!F:6QE<R!A;')E861Y(&%T=&%C:&5D('1O('EO
M=7(@;65S<V%G92X@5&\@1&5L971E(&%N(&%T=&%C:&5D(&9I;&4Z"B`@("`\
M+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($%C=&EV871E('1H92!C:&5C:RUB
M=71T;VX@;F5X="!T;R!T:&4@871T86-H960@9FEL96YA;64@>6]U('=A;G0@
M=&\@1&5L971E+@H@("`@/"]P87)A/B`*("`@(#QP87)A/E-T97`@,CH@0VQI
M8VL@(D1E;&5T92!!='1A8VAM96YT*',I(BX*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M871T86-H;65N=',B
M/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:&UE;G1S
M/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T%T=&%C:&UE;G1S)G%U;W0[
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES('-E8W1I;VX@9&ES<&QA
M>7,@82!L:7-T(&]F(&9I;&5S(&%L<F5A9'D@871T86-H960@=&\@>6]U<B!M
M97-S86=E+B!4;R!$96QE=&4@86X@871T86-H960@9FEL93H*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@,3H@06-T:79A=&4@=&AE(&-H96-K+6)U='1O
M;B!N97AT('1O('1H92!A='1A8VAE9"!F:6QE;F%M92!Y;W4@=V%N="!T;R!$
M96QE=&4N"B`@("`\+W!A<F$^(`H@("`@/'!A<F$^4W1E<"`R.B!#;&EC:R`F
M<75O=#M$96QE=&4@071T86-H;65N="AS*29Q=6]T.RX*("`@(#PO<&%R83X*
M/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UP<FEO
M<FET>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@4')I;W)I='D\+W1I=&QE/@H@("`@/&AE861I;F<^(E!R:6]R:71Y
M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S971S('1H92`B6"U0
M<FEO<FET>2(@:&5A9&5R(&]N('EO=7(@;W5T9V]I;F<@;65S<V%G92X@5&AE
M(")8+5!R:6]R:71Y(B!T86<@:7,@82!S;W)T(&]F(")P<V5U9&\@<W1A;F1A
M<F0B('1H870@3F5T<V-A<&4L($UO>FEL;&$L($]P97)A+"!A;F0@3W5T;&]O
M:R!M86EL(&-L:65N=',@87!P96%R('1O(&%G<F5E(&]N+B!!;GD@;6%I;"!C
M;&EE;G1S('1H870@9&\@;F]T(&AA;F1L92!T:&ES(&AE861E<B!W:6QL('-I
M;7!L>2!I9VYO<F4@:70N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)C;VUP;W-E+7-A=F4M871T86-H;65N=',B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%-A=F4@071T86-H;65N
M=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H971H97(@
M=&AE(&%T=&%C:&UE;G1S(&EN('EO=7(@8V]M<&]S:71I;VX@87)E('-A=F5D
M('=I=&@@=&AE(&UE<W-A9V4@=VAE;B!S=&]R960@:6X@=&AE('-E;G0M;6%I
M;"!F;VQD97(N("!)9B`B665S(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W:6QL
M(&)E('-A=F5D+B`@268@(DYO(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W:6QL
M(&)E('-T<FEP<&5D(&9R;VT@=&AE(&UE<W-A9V4@869T97(@:70@:7,@<V5N
M="!T;R!A;&P@<F5C:7!I96YT<RX@($-H;V]S:6YG(").;R(@=VEL;"!H96QP
M(&-O;G-E<G9E(&1I<VL@<W!A8V4@8GD@<F5M;W9I;F<@*'!O=&5N=&EA;&QY
M(&QA<F=E*2!A='1A8VAM96YT(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-A=F5D
M(&UE<W-A9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M8V]M<&]S92UL:6YK+6%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!,:6YK($%T=&%C:&UE;G1S/"]T
M:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A
M='1A8VAM96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N(&%R92!S96YT(&%S(&$@
M<&%R="!O9B!T:&4@;6%I;"!M97-S86=E(&]R('=H971H97(@=&AO<V4@871T
M86-H;65N=',@87)E(&ME<'0@;VX@82!L;V-A;"!S97)V97(N("!)9B!A='1A
M8VAM96YT<R!A<F4@;&EN:V5D+"!T:&4@<F5C:7!I96YT*',I(&]F('EO=7(@
M;65S<V%G92!W:6QL(&)E('!R;W9I9&5D(&$@=V5B;&EN:R!W:&5R92!T:&5Y
M(&-A;B!D;W=N;&]A9"!T:&4@871T86-H;65N="AS*2X@($QI;FMI;F<@871T
M86-H;65N=',@:&%S('1H92!A9'9A;G1A9V4@;V8@=')E;65N9&]U<VQY(')E
M9'5C:6YG('1H92!S:7IE(&]F(&]U=&=O:6YG(&UE<W-A9V5S+B`@3&EN:VEN
M9R!A='1A8VAM96YT<R!H87,@=&AE(&1I<V%D=F%N=&%G92!T:&%T('1H92!C
M;VYT96YT(&]F('1H92!A='1A8VAM96YT<R!C86X@;F]T(&)E(&=U87)A;G1E
M960@=&\@8F4@879A:6QA8FQE(&EN('1H92!F=71U<F4@<VEN8V4@=&AE(&%T
M=&%C:&UE;G0@9&%T82!I<R!N;W0@;&]C871E9"!W:71H:6X@=&AE(&4M;6%I
M;"!M97-S86=E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<V5A<F-H(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!3
M96%R8V@\+W1I=&QE/@H@("`@/&AE861I;F<^4V5A<F-H($-R:71E<FEA/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("`@("`@2&5L<"!T97AT('1O(&)E('=R
M:71T96XN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)S96%R8V@B/@H@("`@/'1I=&QE/DUE<W-A9V4@4V5A<F-H/"]T:71L
M93X*("`@(#QH96%D:6YG/E-E87)C:"!#<FET97)I83PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@66]U(&UA>2!S96%R8V@@9F]R(&UE<W-A9V5S(&9R;VT@
M>6]U<B!F;VQD97)S('5S:6YG(&1I9F9E<F5N="!S96%R8V@@8W)I=&5R:6$N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5N=&5R('1E>'0@=&\@
M=&AE(&9I96QD<R!Y;W4@=V%N="!T;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I
M=&5R:6$N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($-H;V]S92!T
M:&4@;65S<V%G92!F;&%G*',I('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C<FET
M97)I82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,SH@0VAO;W-E('1H
M92!F;VQD97(H<RD@9G)O;2!W:&EC:"!T;R!S96%R8V@@9F]R('1H92!M97-S
M86=E<RX*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@-#H@0VQI8VL@)G%U
M;W0[4V5A<F-H)G%U;W0[+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!)
M9B!A;GD@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"!C<FET97)I82P@
M=&AE;B!T:&4@<W5B:F5C=',@;V8@=&AE<V4@;65S<V%G97,@=VEL;"!B92!S
M:&]W;B!I;B!T:&4@)G%U;W0[4V5A<F-H(%)E<W5L=',F<75O=#L@=FEE=RX*
M("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M9F]L9&5R+6]P=&EO;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y&
M;VQD97(@36%N86=E;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY&;VQD97(@
M3W!T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!9;W4@8V%N('-E
M;&5C="!A(&9O;&1E<B!B>2!U<VEN9R!T:&4@<F%D:6\@8G5T=&]N<R!A;&]N
M9R!T:&4@;&5F="!C;VQU;6XN("!/;F-E('EO=2!H879E(&1O;F4@=&AI<RP@
M<V5L96-T('1H92!O<'1I;VX@>6]U('=I<V@@=&\@<&5R9F]R;2!O;B!T:&4@
M9F]L9&5R('9I82!T:&4@<V5L96-T(&)O>"!T;R!T:&4@;&5F="X*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@("!9;W4@=VEL;"!B92!P<F]M<'1E9"!F
M;W(@9G5R=&AE<B!O<'1I;VYS+B`@0F4@8V%R969U;"!W:71H('1H92!D96QE
M=&4@;W!T:6]N+"!A<R!Y;W4@8V%N(&QO<V4@86QL('1H92!M97-S86=E<R!I
M;B!A(&9O;&1E<B!I9B!Y;W4@9&5L971E(&ET(&)Y(&UI<W1A:V4A"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F;VQD97(M
M;W!T:6]N<R(^"B`@("`\=&ET;&4^1F]L9&5R($UA;F%G96UE;G0\+W1I=&QE
M/@H@("`@/&AE861I;F<^1F]L9&5R($]P=&EO;G,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@82!F;VQD97(@8GD@=7-I;F<@
M=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE(&QE9G0@8V]L=6UN+B`@3VYC
M92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C="!T:&4@;W!T:6]N('EO=2!W
M:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E<B!V:6$@=&AE('-E;&5C="!B
M;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@
M66]U('=I;&P@8F4@<')O;7!T960@9F]R(&9U<G1H97(@;W!T:6]N<RX@($)E
M(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO;BP@87,@>6]U(&-A;B!L
M;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD97(@:68@>6]U(&1E;&5T
M92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^26UP
M;W)T(&UB;W@@1FEL93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!4:&ES
M(&]P=&EO;B!W:6QL(&EM<&]R="!A(&UB;W@@9F]R;6%T(&9I;&4@:6YT;R!T
M:&4@9F]L9&5R(&]F('EO=7(@8VAO:6-E+B!#:&]O<V4@,2`H;VYE*2!F;VQD
M97(@=&\@:6UP;W)T('1H92!M97-S86=E<R!I;G1O(&%N9"!T:&5N('-E;&5C
M="!T:&ES(&]P=&EO;BX@66]U('=I;&P@=&AE;B!B92!T86ME;B!T;R!A('!A
M9V4@=&AA="!W:6QL('!R;VUP="!F;W(@=&AE(&UB;W@@9FEL92!T;R!I;7!O
M<G0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](F9O;&1E<BUW:61G971S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&
M;VQD97(@36%N86=E;65N=#H@1&ES<&QA>3PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY3:&]W+TAI9&4@56YS=6)S8W)I8F5D/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!)9B!U<VEN9R!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS+"!S:&]W
M+VAI9&4@=&AE('5N<W5B<V-R:6)E9"!F;VQD97)S+B`@5&\@<W5B<V-R:6)E
M+W5N<W5B<V-R:6)E('1O(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K8F]X
M(&YE>'0@=&\@=&AE(&9O;&1E<FYA;64@86YD('5S92!T:&4@4W5B<V-R:6)E
M+U5N<W5B<V-R:6)E(&]P=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D<F]P
M+61O=VX@;65N=2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9"!!
M;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5X<&%N9"!A;&P@9F]L9&5R
M(&5N=')I97,N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S92!!
M;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-O;&QA<'-E(&%L;"!F;VQD
M97(@96YT<FEE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(F9I;'1E<G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y&:6QT97)S
M.B!!<'!L>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L
M97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N('1H92`B07!P
M;'D@1FEL=&5R(B!I8V]N(&YE>'0@=&\@=&AE($E.0D]8(&YA;64@:6X@=&AE
M(&UA:6QB;W@@=FEE=R!T;R!F:6QT97(@86QL('5N9&5L971E9"!M97-S86=E
M<R!A8V-O<F1I;F<@=&\@=&AE('-P96-I9FEE9"!R=6QE<RX@($]R+"!A;'1E
M<FYA=&5V;'DL(&-L:6-K(&]N(")!<'!L>2!!;&P@4G5L97,B(&EN('1H92!F
M:6QT97(@;65N=2X@($YO=&4@=&AA="!F:6QT97)I;F<@:7,@;F]T(&1O;F4@
M875T;VUA=&EC86QL>2X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y
M.@H\96YT<GD@:60](F9I;'1E<G,B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($%P
M<&QY/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@;VX@=&AE("9Q=6]T.T%P
M<&QY($9I;'1E<B9Q=6]T.R!I8V]N(&YE>'0@=&\@=&AE($E.0D]8(&YA;64@
M:6X@=&AE(&UA:6QB;W@@=FEE=R!T;R!F:6QT97(@86QL('5N9&5L971E9"!M
M97-S86=E<R!A8V-O<F1I;F<@=&\@=&AE('-P96-I9FEE9"!R=6QE<RX@($]R
M+"!A;'1E<FYA=&5V;'DL(&-L:6-K(&]N("9Q=6]T.T%P<&QY($%L;"!2=6QE
M<R9Q=6]T.R!I;B!T:&4@9FEL=&5R(&UE;G4N("!.;W1E('1H870@9FEL=&5R
M:6YG(&ES(&YO="!D;VYE(&%U=&]M871I8V%L;'DN"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUE9&ET+7)U
M;&5S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET($9I
M;'1E<B!2=6QE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@1FEL
M=&5R(%)U;&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B
M161I="!Y;W5R(&9I;'1E<B!R=6QE<R(@=&\@<')O8V5E9"!T;R!T:&4@<&%G
M92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E+"!A;F0@961I="!T:&4@8W5R
M<F5N=&QY(&%C=&EV92!S970@;V8@9FEL=&5R(')U;&5S+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M8FQA8VML:7-T
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET($)L86-K
M;&ES=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@0FQA8VML:7-T
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R
M(&)L86-K;&ES="(@=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@
M8V%N(&%D9"P@9&5L971E+"!A;F0@961I="!T:&4@;&ES="!O9B!E+6UA:6P@
M861D<F5S<V5S('EO=2!!3%=!65,@<F5F=7-E(&UA:6P@9G)O;2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUE9&ET+7=H:71E
M;&ES="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!7
M:&ET96QI<W0\+W1I=&QE/@H@("`@/&AE861I;F<^161I="!9;W5R(%=H:71E
M;&ES=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@
M>6]U<B!W:&ET96QI<W0B('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@
M>6]U(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@=&AE(&QI<W0@;V8@92UM
M86EL(&%D9')E<W-E<R!Y;W4@04Q705E3(&%C8V5P="!M86EL(&9R;VTN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM;&]G
M:6XB('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!O
M;B!,;V=I;CPO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L
M97,@57!O;B!,;V=O;C\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K
M('1H:7,@;W!T:6]N('1O(&%L=V%Y<R!A<'!L>2!F:6QT97)S('=H96X@9FER
M<W0@;&]G9VEN9R!O;G1O($E-4"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F9I;'1E<BUO;BUD:7-P;&%Y(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y&:6QT97)S.B!&:6QT97(@;VX@4F5F<F5S:#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@
M:7,@9&ES<&QA>65D/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@
M=&AI<R!O<'1I;VX@=&\@86QW87ES(&%P<&QY(&9I;'1E<G,@=VAE;F5V97(@
M>6]U<B!V:65W('1H92!)3D)/6#\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F9I;'1E<BUA;GDM;6%I;&)O>"(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&%N>2!-86EL8F]X/"]T:71L93X*
M("`@(#QH96%D:6YG/D%P<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@;6%I;&)O
M>#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N
M(&EF('EO=2!W86YT('1O(&)E(&%L;&]W960@=&\@87!P;'D@9FEL=&5R(')U
M;&5S('1O(&%N>2!M86EL8F]X+B!.;W)M86QL>2P@9FEL=&5R:6YG(')U;&5S
M(&%R92!O;FQY(&%P<&QI960@=&\@;F5W(&UA:6P@=&AA="!I<R!D96QI=F5R
M960@=&\@>6]U<B!)3D)/6"X@($EF('1H:7,@;W!T:6]N(&ES(&-H96-K960L
M(&%N(&EC;VX@=VEL;"!A<'!E87(@;VX@86QL(&UA:6QB;W@@<&%G9V5S('1H
M870@=VEL;"!A;&QO=R!Y;W4@=&\@87!P;'D@9FEL=&5R(')U;&5S('1O('1H
M92!M97-S86=E<R!I;B!T:&4@8W5R<F5N="!M86EL8F]X+B`@3D]413H@1FEL
M=&5R:6YG(&EN(&UA:6QB;WAE<R!O=&AE<B!T:&%N($E.0D]8(&UA>2!P<F]D
M=6-E('-T<F%N9V4@*&4N9RX@=&AE(&9I;'1E<B!M87D@8V%U<V4@82!C;W!Y
M(&]F(&UE<W-A9V5S('1O(&)E(&1E;&EV97)E9"!T;R!T:&4@<V%M92!M86EL
M8F]X*2!A;F0O;W(@=6YD97-I<F5D(')E<W5L=',@*&4N9RX@:70@;6%Y(&-A
M=7-E(&UE<W-A9V5S('1O(&)E(&UO=F5D+V1E;&5T960@:68@;F5W(&9I;'1E
M<FEN9R!R=6QE<R!H879E(&)E96X@:6UP;&5M96YT960@<VEN8V4@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@9&5L:79E<F5D('1O('1H92!C=7)R96YT(&UA:6QB
M;W@I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6-O
M;7!O<V4M871T86-H+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4$=0.B!!='1A8V@@4'5B;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M='1A8V@@4'5B;&EC($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M<V5L96-T960@=&AE;B!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@
M:68@:70@97AI<W1S+"!W:6QL(&)E(&%T=&%C:&5D('1O('1H92!O=71G;VEN
M9R!M97-S86=E+B`@66]U(&-A;B!S970@=&AE(&1E9F%U;'0@8F5H879I;W(@
M=FEA('1H92!01U`@3W!T:6]N<R!S8W)E96XN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+7-C86XM8F]D>2(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!38V%N(%1E>'0@0F]D:65S/"]T:71L
M93X*("`@(#QH96%D:6YG/E-C86X@5&5X="!";V1I97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@24U0('=I;&P@<V-A;B!T
M:&4@8F]D>2!O9B!A;&P@=&5X="!M97-S86=E<R!F;W(@4$=0(&1A=&$L(&%N
M9"!D:7-P;&%Y('1H92!R97-U;'1S(&EF(&%N>2!D871A(&ES(&9O=6YD+B`@
M3F]T92!T:&%T('1H:7,@;6%Y('-L;W<@9&]W;B!T:&4@<WES=&5M(&%S(&5V
M97)Y('1E>'0@;65S<V%G92!M=7-T(&)E('-C86YN960@:6X@:71S(&5N=&ER
M971Y(&9O<B!01U`@9&%T82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F-O;7!O<V4M;W!T:6]N<RUE;F-R>7!T(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y#;VUP;W-E.B!%;F-R>7!T:6]N($]P=&EO;G,\+W1I=&QE
M/@H@("`@/&AE861I;F<^3F\@16YC<GEP=&EO;CPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@4V5N9"!T:&4@;65S<V%G92!W:71H(&YO(&5N8W)Y<'1I;VX@
M*&-L96%R=&5X="DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@16YC
M<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P
M=&EO;B!W:6QL(&5N8W)Y<'0@=&AE(&-U<G)E;G0@;65S<V%G92P@=7-I;F<@
M4$=0(&%N9"!T:&4@<F5C:7!I96YT<R!P97)S;VYA;"!P=6)L:6,@:V5Y+"!A
M;F0@=&AE;B!S96YD(&ET+B!9;W4@8V%N(&]N;'D@<V5N9"!A(&UE<W-A9V4@
M=&\@82!S:6YG;&4@<&5R<V]N('5S:6YG('1H:7,@;W!T:6]N+B!9;W4@3553
M5"!H879E('1H92!P=6)L:6,@:V5Y(&]F('1H92!R96-I<&EE;G0@<W1O<F5D
M(&EN('EO=7(@861D<F5S<V)O;VL@;W(@96QS92!T:&ES(&]P=&EO;B!W:6QL
M(&9A:6PN($EF('EO=2!H879E('1H92!P=6)L:6,@:V5Y(&9O<B!T:&4@<F5C
M:7!I96YT(&EN('EO=7(@861D<F5S<V)O;VL@86YD(&%R92!S=&EL;"!R96-E
M:79I;F<@97)R;W)S+"!V97)I9GD@=&AA="!T:&4@92UM86EL(&%D9')E<W,@
M:6X@=&AE(')E8VEP:65N="!F:65L9"!M871C:&5S('1H92!E+6UA:6P@861D
M<F5S<R!W:&5R92!T:&4@<'5B;&EC(&ME>2!I<R!S=&]R960N(%1H92!E;F-R
M>7!T960@9&%T82!W:6QL(&)E(&%T=&%C:&5D('1O('1H92!O=71G;VEN9R!M
M97-S86=E+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0(%-I9VX@365S
M<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL
M;"!D:6=I=&%L;'D@<VEG;B!T:&4@8W5R<F5N="!M97-S86=E('5S:6YG(%!'
M4"!A;F0@>6]U<B!P97)S;VYA;"!P<FEV871E(&ME>2X@268@>6]U(&AA=F4@
M;F]T(&%L<F5A9'D@96YT97)E9"!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!P
M<FEV871E(&ME>2!D=7)I;F<@=&AI<R!S97-S:6]N('EO=2!W:6QL(&)E('!R
M;VUP=&5D(&9O<B!I="X@(%1H92!R96-E:7!I96YT(&UU<W0@:&%V92!A(&-O
M<'D@;V8@>6]U<B!P=6)L:6,@:V5Y('1O(&1I9VET86QL>2!V97)I9GD@>6]U
M<@H@("`@<VEG;F%T=7)E+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0
M(%-I9VXO16YC<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4:&ES(&]P=&EO;B!W:6QL(&9I<G-T(&1I9VET86QL>2!S:6=N('EO=7(@
M;65S<V%G92!A;F0@=&AE;B!W:6QL(&5N8W)Y<'0@=&AE(')E<W5L=&EN9R!O
M=71P=70N(%-E92!T:&4@)U!'4"!%;F-R>7!T($UE<W-A9V4G(&%N9"`G4$=0
M(%-I9VX@365S<V%G92<@96YT<FEE<R!F;W(@9G5R=&AE<B!I;F9O<FUA=&EO
M;BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-12!%;F-R>7!T($UE
M<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/E,O34E-12!3:6=N($UE<W-A9V4\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5$]$3PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+6]V97)V:65W(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z
M($]V97)V:65W/"]T:71L93X*("`@(#QH96%D:6YG/E=H870@:7,@4$=0/SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4$=0(&ES(&$@=&]O;"!F;W(@<V5C
M=7)E(&-O;6UU;FEC871I;VX@86YD(&1A=&$@<W1O<F%G92P@97-P96-I86QL
M>2!F;W(@=7-E('=I=&@@92UM86EL+B!)="!C86X@8F4@=7-E9"!T;R!E;F-R
M>7!T(&1A=&$@86YD('1O(&-R96%T92!D:6=I=&%L('-I9VYA='5R97,N($E-
M4"!U<V5S($=N=5!'("A'3E4@4')I=F%C>2!'=6%R9"D@=&\@<')O=FED92!T
M:&ES(&9U;F-T:6]N86QI='DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%
M;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!)9B!T:&ES(&]P=&EO;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@
M86)L92!T;R!C<F5A=&4O=FEE=R!Y;W5R('!E<G-O;F%L(%!'4"!K97ES+"!A
M9&0O9&5L971E('!U8FQI8R!K97ES(&9R;VT@;W1H97(@:6YD:79I9'5A;',L
M(')E860@96YC<GEP=&5D(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG;F5D
M(&UA:6PL(&%N9"!E;F-R>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO;BUA
M='1A8V@M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($]P
M=&EO;G,@+2!!='1A8V@@4'5B;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY/<'1I;VYS("T@071T86-H(%!U8FQI8R!+97D\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@82!C;W!Y(&]F('EO=7(@4$=0
M('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T<RP@=VEL;"!B>2!D969A=6QT(&)E
M(&%T=&%C:&5D('1O(&%L;"!O=71G;VEN9R!M97-S86=E<RX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UM86YA9V4M<'5B:V5Y(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!S8W)E96X@;&ES=',@86QL(&]F('1H92!C=7)R
M96YT('5S97)S(&EN('EO=7(@861D<F5S<V)O;VL@=&AA="!H879E(%!'4"!P
M=6)L:6,@:V5Y<RX@5&AE<V4@=7-E<G,@87)E('1H92!/3DQ9('5S97)S('1H
M870@>6]U(&-A;B!E:71H97(@,2D@<V5N9"!A;B!E;F-R>7!T960@;65S<V%G
M92!T;R`M3U(M(#(I('9E<FEF>2!A(&1I9VET86P@<VEG;F%T=7)E+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!U8FQI8R!K
M97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@
M=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M1&5L971E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&5S('1H92!P
M=6)L:6,@:V5Y(&9R;VT@>6]U<B!A9&1R97-S8F]O:RX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UI;7!O<G0M<'5B:V5Y(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y<R`M
M($EM<&]R=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY);7!O<G0@4'5B;&EC($ME
M>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@8G5T=&]N('=I;&P@
M;W!E;B!A('=I;F1O=R!W:&5R92!Y;W4@8V%N(&UA;G5A;&QY(&EM<&]R="!A
M(%!'4"!P=6)L:6,@:V5Y+B`@5&AE(&ME>2!C86X@96ET:&5R(&)E('!A<W1E
M9"!I;G1O(&$@=&5X=&9I96QD(&]R+"!I9B!T:&4@:V5Y(')E<VED97,@:6X@
M82!F:6QE(&]N('EO=7(@;&]C86P@8V]M<'5T97(L('EO=2!C86X@:6UP;W)T
M(&ET+B`@268@=&AE(&ME>2!I<R!V86QI9"!I="!W:6QL(&)E(&EN<V5R=&5D
M(&EN=&\@>6]U<B!A9&1R97-S8F]O:R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L
M;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R
M971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UO=F5R=FEE=RUP97)S;VYA;&ME>2(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@268@>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@;65S<V%G
M97,@;W(@96YA8FQE(&]T:&5R<R!T;R!S96YD('EO=2!E;F-R>7!T960@;65S
M<V%G97,L('EO=2!M=7-T(&AA=F4@>6]U<B!O=VX@<&5R<V]N86P@<'5B;&EC
M+W!R:79A=&4@4$=0(&ME>7!A:7(N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY9;W5R(%!U8FQI8R!+97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO
M=7(@<'5B;&EC(&ME>2!S:&]U;&0@8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY
M('!E<G-O;B!T:&%T('EO=2!W86YT('1O(&)E(&%B;&4@=&\@<V5N9"!Y;W4@
M96YC<GEP=&5D(&UE<W-A9V5S('1H870@;VYL>2!93U4@8V%N(&1E8W)Y<'0@
M*'5S:6YG('EO=7(@<')I=F%T92!K97DI+B!!9&1I=&EO;F%L;'DL('EO=7(@
M<'5B;&EC(&ME>2!N965D<R!T;R!B92!M861E(&%V86EL86)L92!T;R!A;GEB
M;V1Y('EO=2!S96YD(&$@9&1I9VET86QL>2!S:6=N960@;65S<V%G92!T;R`M
M('1H92!P=6)L:6,@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@9&EG
M:71A;"!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY9;W5R
M(%!R:79A=&4@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!R
M:79A=&4@:V5Y(&ES(&YE8V5S<V%R>2!T;R!D96-R>7!T(&%N>2!M97-S86=E
M(&5N8W)Y<'1E9"!U<VEN9R!Y;W5R('!U8FQI8R!K97DN($%D9&ET:6]N86QL
M>2P@>6]U<B!P<FEV871E(&ME>2!I<R!N965D960@:68@>6]U('=A;G0@=&\@
M9&EG:71A;&QY('-I9VX@82!M97-S86=E+B!9;W5R('!R:79A=&4@:V5Y('=I
M;&P@8F4@<')O=&5C=&5D('9I82!A('!A<W-P:')A<V4@8W)E871E9"!W:&5N
M('1H92!K97ES(&%R92!G96YE<F%T960N(%1H=7,L('1O('!E<F9O<FT@86YY
M(&%C=&EV:71Y('1H870@<F5Q=6ER97,@>6]U<B!P<FEV871E(&ME>2P@24U0
M('=I;&P@<')O;7!T('EO=2!F;W(@>6]U<B!P87-S<&AR87-E+B!9;W4@;VYL
M>2!N965D('1O(&EN<V5R="!Y;W5R('!A<W-P:')A<V4@;VYC92!P97(@<V5S
M<VEO;B`M($E-4"!W:6QL('-T;W)E('EO=7(@<&%S<W!H<F%S92!U;G1I;"!Y
M;W4@;&]G;W5T("A3;R!B92!S=7)E('1O(&QO9V]U="$I+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!U8FQI
M8R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N
M86P@2V5Y<R`M(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^5FEE
M=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@
M=FEE=R!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y
M<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y
M+7!R:79A=&4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E
M(%!E<G-O;F%L($ME>7,@+2!0<FEV871E($ME>3PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY%;G1E<B!087-S<&AR87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!/<&5N<R!T:&4@<&%S<W!H<F%S92!D:6%L;V<@=VEN9&]W+B!4:&4@<&%S
M<W!H<F%S92!E;G1E<F5D+"!I9B!C;W)R96-T+"!W:6QL(&)E('-T;W)E9"!B
M>2!)35`@=6YT:6P@>6]U<B!S97-S:6]N(&5N9',N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY5;FQO860@4&%S<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@4F5M;W9E<R!T:&4@<W1O<F5D('!A<W-P:')A<V4@9G)O;2!)
M35`@+2!A;GD@861D:71I;VYA;"!U<V%G92!O9B!T:&4@<')I=F%T92!K97D@
M=VEL;"!R97%U:7)E('EO=2!T;R!R965N=&5R('1H92!P87-S<&AE87-E+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!R:79A
M=&4@:V5Y+B!$3R!.3U0@4T5.1"!42$E3($M%62!43R!!3EE/3D4@+2!T:&ES
M(&]P=&EO;B!I<R!S=')I8W1L>2!S;R!T:&%T('EO=2!C86X@97AP;W)T('EO
M=7(@24U0('!E<G-O;F%L('!R:79A=&4@:V5Y(&9O<B!U<V4@:6X@86YO=&AE
M<B!P<F]G<F%M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS
M(&%B;W5T('1H92!01U`@<')I=F%T92!K97DN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM9&5L971E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES
M("T@1&5L971E/"]T:71L93X*("`@(#QH96%D:6YG/D1E;&5T92!097)S;VYA
M;"!+97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&)U='1O;B!W
M:6QL(&1E;&5T92!Y;W5R('!E<G-O;F%L('!U8FQI8R]P<FEV871E(&ME>7!A
M:7(@9G)O;2!)35`G<R!P<F5F97)E;F-E<RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M;F%M92(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@
M2V5Y("T@3F%M93PO=&ET;&4^"B`@("`\:&5A9&EN9SY.86UE/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&4@;F%M92!Y;W4@=V%N="!E;6)E9&1E9"!I
M;B!Y;W5R('!E<G-O;F%L(&ME>7,N($$@<F5Q=6ER960@9FEE;&0N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM
M8W)E871E+6-O;6UE;G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@
M0W)E871E(%!E<G-O;F%L($ME>2`M($-O;6UE;G0\+W1I=&QE/@H@("`@/&AE
M861I;F<^0V]M;65N=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@02!C;VUM
M96YT('-T<FEN9R!Y;W4@=V%N="!E;6)E9&1E9"!I;B!Y;W5R('!E<G-O;F%L
M(&ME>7,N($%N(&]P=&EO;F%L(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UE;6%I;"(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@
M2V5Y("T@12UM86EL($%D9')E<W,\+W1I=&QE/@H@("`@/&AE861I;F<^12UM
M86EL($%D9')E<W,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!E+6UA
M:6P@861D<F5S<R!Y;W4@=V%N="!A<W-O8VEA=&5D('=I=&@@>6]U<B!P97)S
M;VYA;"!K97ES+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UK97EL
M96YG=&@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E
M<G-O;F%L($ME>2`M($ME>6QE;F=T:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY+
M97EL96YG=&@\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!K97EL96YG
M=&@L(&EN(&)Y=&5S+"!O9B!Y;W5R(&=E;F5R871E9"!K97DN(%1H92!G<F5A
M=&5R('1H92!V86QU92P@=&AE(&=R96%T97(@=&AE('!R;W1E8W1I;VX@*&%N
M9"!A;'-O(&=R96%T97(@9V5N97)A=&EO;B!T:6UE(&%N9"!E;F-R>7!T:6]N
M('1I;64I+B`Q,#(T(&)Y=&5S(&ES('1H92!D969A=6QT("T@=&AI<R!V86QU
M92!P<F]V:61E<R!E>&-E;&QE;G0@<')O=&5C=&EO;BX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M
M<&%S<W!H<F%S92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A
M=&4@4&5R<V]N86P@2V5Y("T@4&%S<W!H<F%S93PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY.86UE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@<&%S<W!H
M<F%S92!U<V5D('1O('!R;W1E8W0O96YC<GEP="!Y;W5R('!E<G-O;F%L('!R
M:79A=&4@:V5Y+B!4:&ES('-H;W5L9"!B92!!5"!,14%35"`V(&-H87)A8W1E
M<G,L('-H;W5L9"!.3U0@8F4@=&AE('-A;64@87,@>6]U<B!L;V=I;B!P87-S
M=V]R9"P@<VAO=6QD($Y/5"!B92!B87-E9"!O;B!A(&1I8W1I;VYA<GD@=V]R
M9"P@86YD('-H;W5L9"!I;F-L=61E(&)O=&@@;G5M8F5R<R!A;F0@;&5T=&5R
M<RX@66]U(&UU<W0@96YT97(@=&AI<R!P87-S<&AR87-E('1W:6-E(&9O<B!V
M97)I9FEC871I;VX@<'5R<&]S97,N($$@<F5Q=6ER960@9FEE;&0N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM
M8W)E871E+6%C=&EO;G,B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@
M0W)E871E(%!E<G-O;F%L($ME>2`M($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE
M861I;F<^0W)E871E($ME>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-R
M96%T92!A;F0@<W1O<F4@>6]U<B!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY);7!O<G0@2V5Y<&%I<CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@26UP;W)T(&$@<&5R<V]N86PO<')I=F%T
M92!K97EP86ER+B!4:&ES(&)U='1O;B!O<&5N<R!A('=I;F1O=R!W:&5R92!Y
M;W4@8V%N(&UA;G5A;&QY(&EM<&]R="!Y;W5R(&5X:7-T:6YG(%!'4"!P97)S
M;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER+B`@5&AE(&ME>7,@8V%N(&5I
M=&AE<B!B92!P87-T960@:6YT;R!A('1E>'1F:65L9"!O<BP@:68@=&AE(&ME
M>7,@<F5S:61E(&EN(&$@9FEL92!O;B!Y;W5R(&QO8V%L(&-O;7!U=&5R+"!Y
M;W4@8V%N(&EM<&]R="!T:&5M+B`@268@=&AE(&ME>7,@87)E('9A;&ED('1H
M97D@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD
M('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O
M<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE
M=R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!/=F5R=FEE=SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY7:&%T(&ES(%,O34E-13\\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%,O34E-12!I<R!A('!R:79A=&4O<'5B;&EC(&ME
M>2!P86ER('-Y<W1E;2!W:&EC:"!P<F]V:61E<R!D:6=I=&%L('-I9VYA='5R
M97,L(&UE<W-A9V4@<')I=F%C>2P@86YD('1A;7!E<B!D971E8W1I;VX@:6X@
M82!O<&5N+"!I;G1E<F]P97)A8FQE('=A>2X@(%,O34E-12!C86X@<')O=FED
M92!M97-S86=E('!R:79A8WD@8GD@96YC<GEP=&EN9R!M97-S86=E<R!T:&%T
M(&]N;'D@=&AE('-E;F1E<B!A;F0@=&AE(&EN=&5N9&5D(')E8VEP:65N=',@
M8V%N(&1E8V]D92X@($ET(&%L;&]W<R!Y;W4@=&\@:61E;G1I9GD@=&AE('-E
M;F1E<B!O9B!A(&UE<W-A9V4@=FEA(&$@9&EG:71A;"!S:6=N871U<F4N("!4
M;V=E=&AE<BP@=&AI<R!E;F-R>7!T:6]N(&%N9"!D:6=I=&%L('-I9VYI;F<@
M:&5L<"!P<F]V:61E('1A;7!E<B!D971E8W1I;VXL(&%L;&]W:6YG(')E8VEP
M:65N=',@=&\@9&5T97)M:6YE('=H971H97(@82!M97-S86=E('=A<R!A;'1E
M<F5D(&%F=&5R(&ET('=A<R!S96YT+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@268@=&AI<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W
M:6QL(&)E(&%B;&4@=&\@:6UP;W)T('EO=7(@<&5R<V]N86P@4R]-24U%(&ME
M>7,L(')E860@96YC<GEP=&5D(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG
M;F5D(&UA:6PL(&%N9"!E;F-R>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E
M<G9I97<M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O
M34E-13H@4&5R<V]N86P@2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R
M=FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@>6]U('=A;G0@=&\@
M9&EG:71A;&QY('-I9VX@;W(@96YC<GEP="!M97-S86=E<R!Y;W4@;75S="!H
M879E('EO=7(@;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%,O34E-12!K
M97EP86ER+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI
M;64M:6UP;W)T+7!E<G-O;F%L+6-E<G1S(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y3+TU)344Z($EM<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+W1I
M=&QE/@H@("`@/&AE861I;F<^26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@26UP;W)T('!E<G-O;F%L(&-E
M<G1I9FEC871E<R!F<F]M(&$@4$M#4R`C,3(@9F]R;6%T(&9I;&4N(%!+0U,@
M(S$R(&9I;&5S(&ES('1H92!F:6QE('5S=6%L;'D@9V5N97)A=&5D('=H96X@
M97AP;W)T:6YG(&$@:V5Y(&9R;VT@82!B<F]W<V5R("AE+F<N($EN=&5R;F5T
M($5X<&QO<F5R+"!&:7)E9F]X*2!O<B!F<F]M(&$@8V5R=&EF:6-A=&4@<W1O
M<F4@;6%I;G1A:6YE9"!B>2!A;B!/<&5R871I;F<@4WES=&5M("AE+F<N(%=I
M;F1O=W,@6%`I+B!)9B!T:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E
M(&EN<V5R=&5D(&EN=&\@>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O
M=R!W:6QL(&-L;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@
M=VEL;"!B92!R971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+61E;&5T92UP97)S;VYA;"UC
M97)T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!$96QE=&4@
M4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH96%D:6YG/D1E
M;&5T92!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($1E;&5T92!Y;W5R('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M
M('EO=7(@<')E9F5R96YC97,N("!9;W4@=VEL;"!N;R!L;VYG97(@8F4@86)L
M92!T;R!S:6=N(%,O34E-12!M97-S86=E<R!O<B!V:65W(&%N>2!3+TU)344@
M96YC<GEP=&5D(&UE<W-A9V5S(&%D9')E<W-E9"!T;R!Y;W4N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z($UA;F%G92!0=6)L
M:6,@2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3+TU)344Z($UA;F%G92!0
M=6)L:6,@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@36%N86=E('EO
M=7(@4R]-24U%('!U8FQI8R!K97D@;&ES="X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&AE
M(')A=R!T97AT(&]F('1H92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5FEE
M=R!T96-H;FEC86P@9&5T86EL<R!O9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@1&5L971E<R!T:&4@<V5L96-T960@<'5B;&EC(&ME>2!F<F]M('-T
M;W)A9V4N("!$96QE=&EN9R!A('!U8FQI8R!K97D@9F]R(&$@=7-E<B!W:6QL
M('!R979E;G0@>6]U<B!F<F]M(&5N8W)Y<'1I;F<@82!M97-S86=E('1O('1H
M870@=7-E<BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M:6YT:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<FEN=&EN9SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY0<FEN="!A(&UE<W-A9V4\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1O('!R:6YT(&$@;65S<V%G92!Y;W4@87)E('9I97=I
M;F<L(&-L:6-K(&]N('1H92`B4')I;G0B(&QI;FL@870@96ET:&5R('1H92!T
M;W`@;W(@8F]T=&]M(&]F('1H92!M97-S86=E+B!4:&4@;65S<V%G92!W:6QL
M(&]P96X@:6X@82!N97<@=VEN9&]W(&9O<FUA=&5D(&9O<B!P<FEN=&EN9RX@
M($1E<&5N9&EN9R!O;B!Y;W5R('=E8B!B<F]W<V5R(&%N9"!O<&5R871I;F<@
M<WES=&5M+"!T:&4@<')I;G0@9&EA;&]G(&)O>"!M87D@;W!E;B!F;W(@>6]U
M+B`@268@:70@9&]E<R!N;W0@;W!E;BP@=&AE;B!P=6QL(&1O=VX@=&AE('=E
M8B!B<F]W<V5R)W,@(D9I;&4B(&UE;G4@86YD(&-H;V]S92`B4')I;G0B('1O
M(&]P96X@=&AE('!R:6YT(&1I86QO9R!B;W@N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)S;W)T:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y3;W)T:6YG(&%N9"!4:')E861I;F<\+W1I=&QE/@H@("`@/&AE861I
M;F<^4V]R=&EN9R!%;G1R:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!7
M:&5N('9I97=I;F<@82!L:7-T(&]F(&UE<W-A9V5S+"!Y;W4@8V%N('-O<G0@
M=&AE(&UE<W-A9V5S(&)Y(&%N>2!C;VQU;6X@8GD@8VQI8VMI;F<@;VX@=&AE
M(&%P<')O<')I871E(&-O;'5M;B!H96%D:6YG+B`@5&\@<W=I=&-H(&-O;'5M
M;G,@8F5T=V5E;B!A<V-E;F1I;F<@86YD(&1E<V-E;F1I;F<@;W)D97(L(&-L
M:6-K(&]N('1H92!A<G)O=R!I8V]N(&EN('1H92!C;VQU;6X@:&5A9&EN9RX*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E1H<F5A9&EN9SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&\@9W)O=7`@;65S<V%G97,@8GD@=&AR96%D<R`H
M<W5B:F5C="DL('-O(&5A8V@@;65S<V%G92!I<R!G<F]U<&5D('=I=&@@86QL
M(&ET<R!R97!L:65S+"!C;&EC:R!T:&4@6U1H<F5A9%T@;&EN:R!I;B!T:&4@
M<W5B:F5C="!C;VQU;6X@:&5A9&EN9RX@(%1O(')E='5R;B!T;R!N;W)M86P@
M<W5B:F5C="!S;W)T:6YG+"!C;&EC:R!O;B!T:&4@6U-U8FIE8W1=(&QI;FL@
M:6X@=&AE('-U8FIE8W0@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)A;'1E<FYA=&EV92UM<V<B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/DUU;'1I<&%R="]!;'1E<FYA=&EV92!-97-S86=E
M<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-O;64@;65S<V%G92!H879E(&)E
M96X@<V5N="!A<R!A(")M=6QT:7!A<G0O86QT97)N871I=F4B('1Y<&4@8GD@
M=&AE('-E;F1E<BX@5&AE<V4@;65S<V%G97,@:&%V92!S979E<F%L('!A<G1S
M+"!A;&P@9&ES<&QA>6EN9R!T:&4@4T%-12!#3TY414Y4(&)U="!I;B!$249&
M15)%3E0@1D]234%44RX@5&AE(&UA:6P@86=E;G0@=VEL;"!D:7-P;&%Y('1H
M92!L87-T('!A<G0@:6X@=&AE(&QI<W0@=&AA="!C86X@8F4@<W5C8V5S<V9U
M;&QY(&1I<W!L87EE9"!I;FQI;F4@:6X@=&AE(&)R;W=S97(L(&EF(&%N>2X@
M06QL(&]T:&5R(&9O<FUA=',@=VEL;"!A<'!E87(@=6YD97(@=&AE(&AE861I
M;F<@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXB(&%N9"!C
M86X@8F4@=FEE=V5D(&]R(&1O=VYL;V%D960@<V5P87)A=&5L>2X@270@:7,@
M:6UP;W)T86YT('1O(&YO=&4@=&AA="!T:&5S92!A;'1E<FYA=&EV92!P87)T
M<R!C;VYT86EN('1H92!304U%($-/3E1%3E13(&%S('1H92!P87)T('1H870@
M:7,@<VAO=VX@+2!T:&5Y(&%R92!S:6UP;'D@:6X@82!D:69F97)E;G0@;65D
M:6$@9F]R;6%T("AE+F<N('1E>'0@=G,N($A434P@;W5T<'5T*2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7)E;F%M95]S96YT
M;6%I;%]M;VYT:&QY(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z(%)E;F%M92!396YT+6UA:6P@1F]L9&5R($UO
M;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N
M(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(')E;F%M92!Y;W5R('-E;G0M;6%I
M;"!F;VQD97(@870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H
M92!F;VQD97(@=VEL;"!B92!R96YA;65D("AT;R!A(&YA;64@=&AA="!C;VYT
M86EN<R!T:&4@;6]N=&@@86YD('EE87(I(&%N9"!A(&YE=R!S96YT+6UA:6P@
M9F]L9&5R('=I;&P@8F4@8W)E871E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z($1E;&5T92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L
M9"!L:6ME('1O(&1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@=&AE
M(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H:7,@;6%Y(&)E('5S969U
M;"!I9B!Y;W4@:&%V92!A('%U;W1A+"!F;W(@97AA;7!L92X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]S96YT;6%I
M;%]M;VYT:&QY7VME97`B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E(%-E;G0M;6%I;"!&;VQD97(@
M36]N=&AL>2`M(",@;V8@1F]L9&5R<R!T;R!+965P/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O;&0@<V5N="UM86EL(&9O
M;&1E<G,@979E<GD@;6]N=&@L(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@9F]L
M9&5R<R!D;R!Y;W4@('=A;G0@=&\@:V5E<#\@($%N>2!F;VQD97)S(&]L9&5R
M('1H86X@=&AI<R!M86YY(&UO;G1H<R!W:6QL(&)E(&1E;&5T960N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T
M86-H;65N='-?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE
M;G1S($UO;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@
M;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(&1E;&5T92!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N
M=&@N("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@
M9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL>5]K965P(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($1E;&5T92!,:6YK960@071T86-H;65N=',@36]N=&AL>2`M(",@;V8@36]N
M=&AS('1O($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E
M(&1E;&5T:6YG(&]L9"!L:6YK960@871T86-H;65N=',@979E<GD@;6]N=&@L
M(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@871T86-H;65N=',@9&\@>6]U("!W
M86YT('1O(&ME97`_("!!;GD@871T86-H;65N=',@;VQD97(@=&AA;B!T:&ES
M(&UA;GD@;6]N=&AS('=I;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U
M<F=E(%1R87-H/"]T:71L93X*("`@(#QP87)A/@H@("`@1&\@>6]U('=A;G0@
M=&\@<'5R9V4@>6]U<B!T<F%S:"!F;VQD97(@979E<GD@<V\@;V9T96XN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T
M<F%S:%]I;G1E<G9A;"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:"!);G1E<G9A;#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@<'5R9VEN9R!Y;W5R('1R
M87-H(&9O;&1E<BP@:&]W(&]F=&5N('-H;W5L9"!I="!B92!P=7)G960_"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T
M<F%S:%]K965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@36%I;G1E;F%N8V4Z(%!U<F=E(%1R87-H($ME97`\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD
M97(L(&UE<W-A9V4@;VQD97(@=&AA;B!H;W<@;6%N>2!D87ES('-H;W5L9"!B
M92!P=7)G960_"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUA='1R:6)?=&5X="(@<W1A=&4](FYE=R(^"B`@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-97-S86=E($-O;7!O<VET:6]N.B!!='1R:6)U=&EO;B!4
M97AT/"]T:71L93X*("`@("`\<&%R83X*("`@("!(97)E('EO=2!C86X@96YT
M97(@=&AE('!H<F%S92!T:&%T('EO=2!W:7-H('1O(&%P<&5A<B!B969O<F4@
M86YY('%U;W1E9"!T97AT(&EN(&$@<F5P;'D@=&AA="!Y;W4@<V5N9"X*("`@
M("`\+W!A<F$^"B`@("`@/'!A<F$^"B`@("`@66]U(&-A;B!I;F-L=61E(&]N
M92!O<B!M;W)E('-P96-I86P@<&QA8V5H;VQD97)S('1O(&EN<V5R="!I;F9O
M<FUA=&EO;B!A8F]U="!T:&4@;65S<V%G92!T;R!W:&EC:"!Y;W4@87)E(')E
M<&QY:6YG+B!0;&%C96AO;&1E<G,@8V]N<VES="!O9B!A("<E)R!F;VQL;W=E
M9"!B>2!A('-I;F=L92!L971T97(N(%1H92!F;VQL;W=I;F<@<&QA8V5H;VQD
M97)S(&%R92!A=F%I;&%B;&4Z"B`@("`@/"]P87)A/@H*("`@("`\<&%R83X@
M)68@.B!4:&4@<V5N9&5R)W,@;F%M92!A;F0@96UA:6P@861D<F5S<SPO<&%R
M83X*("`@("`\<&%R83X@)6$@.B!4:&4@<V5N9&5R)W,@96UA:6P@861D<F5S
M<SPO<&%R83X*("`@("`\<&%R83X@)7`@.B!4:&4@<V5N9&5R)W,@;F%M93PO
M<&%R83X*("`@("`\<&%R83X@)7(@.B!4:&4@9G5L;"!21D,@,C@R,B!S='EL
M92!D871E(&%N9"!T:6UE('IO;F4\+W!A<F$^"B`@("`@/'!A<F$^("5D(#H@
M5&AE(&1A=&4@87,@=W=W+"!D9"!M;6T@65E963PO<&%R83X*("`@("`\<&%R
M83X@)7@@.B!4:&4@9&%T92!I;B!T:&4@;&]C86QE)W,@9&5F875L=#PO<&%R
M83X*("`@("`\<&%R83X@)6,@.B!4:&4@9&%T92!A;F0@=&EM92!I;B!T:&4@
M;&]C86QE)W,@9&5F875L=#PO<&%R83X*("`@("`\<&%R83X@)6T@.B!4:&4@
M365S<V%G92U)1#PO<&%R83X*("`@("`\<&%R83X@)7,@.B!4:&4@<W5B:F5C
M=#PO<&%R83X*("`@("`\<&%R83X@)6X@.B!!(&YE=R!L:6YE/"]P87)A/@H@
M("`@(#QP87)A/B`E)2`Z(%1H92`G)2<@8VAA<F%C=&5R/"]P87)A/@H*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?
M<F5A9"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E
M<75E<W0@4F5A9"!296-E:7!T<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(")2
M97%U97-T(&$@4F5A9"!296-E:7!T(B!S96YD<R!A(')E<75E<W0@=&\@=&AE
M(')E8VEP:65N=',@;V8@=&AI<R!M97-S86=E('1O(&YO=&EF>2!Y;W4@=VAE
M;B!T:&ES(&UE<W-A9V4@:7,@;W!E;F5D(&)Y('1H92!R96-I<&EE;G1S+B!.
M;W0@86QL(&-L:65N=',@<W5P<&]R="`O(&AO;F]R('1H:7,N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S
M96YD7VUD;B(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M(%-E;F0@341./"]T:71L93X*("`@(#QP87)A/@H@("`@(E-E;F0@82!-1$XB
M('-E;F1S(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@*&%L
M<V\@:VYO=VX@87,@82!R96%D(')E8V5I<'0I('=H96X@>6]U('9I97<@82!M
M97-S86=E(&EN('=H:6-H('1H92!U<V5R(&AA<R!R97%U97-T960@=&AA="!T
M:&5Y(')E8V5I=F4@;F]T:69I8V%T:6]N('1H870@>6]U(&AA=F4@<F5A9"!T
M:&4@;65S<V%G92X@26X@;6]S="!C87-E<RP@=&AI<R!W:6QL(&AA<'!E;B!A
M=71O;6%T:6-A;&QY('=I=&AO=70@<')O;7!T:6YG('EO=2X@26X@8V5R=&%I
M;B!I<V]L871E9"!C87-E<RP@>6]U(&UA>2!H879E('1O(&UA;G5A;&QY(&1E
M8VED92!T;R!S96YD('1H92!N;W1I9FEC871I;VX@8GD@8VQI8VMI;F<@;VX@
M82!L:6YK+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]D96QI=F5R>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E<75E<W0@1&5L:79E<GD@0V]N
M9FER;6%T:6]N/"]T:71L93X*("`@(#QP87)A/@H@("`@(E)E<75E<W0@1&5L
M:79E<GD@0V]N9FER;6%T:6]N(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!S97)V97(@=&\@;F]T:69Y('EO=2!W:&5N(&ET
M(&AA<R!D96QI=F5R960@=&AE(&UE<W-A9V4@=&\@=&AE(')E8VEP:65N="=S
M(&UA:6QB;W@N($ET(&1O97-N)W0@;65A;B!T:&4@;65S<V%G92!H87,@8F5E
M;B!S965N+"!J=7-T('1H870@:70G<R!S:71T:6YG(&EN(&$@;6%I;&)O>"!S
M;VUE=VAE<F4N($YO="!A;&P@;6%I;"!S97)V97)S('-U<'!O<G0@=&AI<RX@
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE
M=&5?<W!A;5]A9G1E<E]R97!O<G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!$96QE=&4@4W!A;2!!9G1E<B!297!O<G1I;F<\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y(&5L96-T('1O(&1O(&]N92!O
M9B!T:')E92!I=&5M<R!A9G1E<B!R97!O<G1I;F<@82!M97-S86=E(&%S(&5I
M=&AE<B!S<&%M(&]R(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("!&:7)S="P@>6]U(&-A;B!D96-I9&4@=&\@9&\@;F]T:&EN9R`M('1H
M92!M97-S86=E('=I;&P@8F4@<F5P;W)T960@87,@96ET:&5R('-P86T@;W(@
M:6YN;V-E;G0@8G5T('=I;&P@;W1H97)W:7-E(')E;6%I;B!U;F-H86YG960@
M:6X@>6]U<B!M86EL8F]X+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3
M96-O;F0L(&EF(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@<W!A;2P@>6]U(&-A
M;B!I;G-T96%D(&AA=F4@=&AE(&UE<W-A9V4@8F4@:6UM961I871E;'D@9&5L
M971E9"X@(%1H:7,@<V5T=&EN9R!H87,@;F\@969F96-T(&]N(')E<&]R=&EN
M9R!A(&UE<W-A9V4@87,@:6YN;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@(%1H:7)D+"!A9G1E<B!R97!O<G1I;F<@82!M97-S86=E(&%S('-P
M86T@=&AE(&UE<W-A9V4@=VEL;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E
M;G0@;6%I;&)O>"!A;F0@;6]V960@=&\@>6]U<B!S<&%M(&9O;&1E<BX@($%L
M=&5R;F%T:79E;'DL(&EF(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN;V-E
M;G0@=&AE(&UE<W-A9V4@=VEL;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E
M;G0@;6%I;&)O>"!A;F0@;6]V960@=&\@>6]U<B!)3D)/6"X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6AT;6Q?:6UA9V5?<F5P
M;&%C96UE;G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!(5$U,($EM86=E(%)E<&QA8V5M96YT/"]T:71L93X*("`@(#QP87)A/@H@
M("`@1F]R($A434P@;65S<V%G97,@9&ES<&QA>65D(&EN;&EN92P@<VAO=6QD
M(&%L;"!I;6%G92!T86=S(&)E(&)L;V-K960@=6YT:6P@>6]U('-P96-I9FEC
M86QL>2!D96-I9&4@=&\@=FEE=R!T:&]S92!I;6%G97,_($YO=&4@=&AA="P@
M:68@=FEE=VEN9R!A;B!(5$U,(&%T=&%C:&UE;G0L('1H92!I;6%G97,@=VEL
M;"!A;'=A>7,@8F4@9&ES<&QA>65D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]A9&1R8F]O:R(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P
M;&%C96UE;G0O061D<F5S<V)O;VL@4VAO=SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF(&)L;V-K:6YG(&EM86=E<R!F;W(@:6YL:6YE($A434P@;65S<V%G
M97,L('-H;W5L9"!W92!A=71O;6%T:6-A;&QY(&1I<W!L87D@=&AE;2!I;G-T
M96%D(&EF('1H92!S96YD97(@87!P96%R<R!I;B!Y;W5R(&%D9')E<W-B;V]K
M/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M;6%I
M;&)O>%]S=&%R="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6QB;W@@4W1A<G0@4&%G93PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($1E=&5R;6EN97,@=VAI8V@@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W('=I
M;&P@8F4@9&ES<&QA>65D('=H96X@>6]U(&%C8V5S<R!A(&UA:6QB;W@@9F]R
M('1H92!F:7)S="!T:6UE+B!.;W1E('1H870@=&AE("=U;G-E96XG(&UE<W-A
M9V4@;W!T:6]N<R!D;R!N;W0@=V]R:R!W:71H('1H92`G5&AR96%D)R!S;W)T
M:6YG(&]P=&EO;B`M(&EN<W1E860L('EO=2!W:6QL(&)E('-E;G0@=&\@=&AE
M(&QA<W0@<&%G92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+7-A=F5?871T86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!3879E($%T=&%C:&UE;G1S(&]N(%-E;G0@365S
M<V%G97,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!S879I;F<@82!C;VUP
M;W-E9"!M97-S86=E(&EN(&$@<V5N="UM86EL(&9O;&1E<BP@9&5T97)M:6YE
M(&EF(&%L;"!A='1A8VAM96YT(&1A=&$@:7,@<V%V960N(%1H92!F;VQL;W=I
M;F<@;W!T:6]N<R!A<F4@879A:6QA8FQE.@H@("`@/"]P87)A/@H*("`@(#QP
M87)A/BH@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP
M="!T;R!S879E(&%T=&%C:&UE;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@
M871T86-H;65N=',@87)E($%,5T%94R!S879E9"!W:71H('1H92!M97-S86=E
M+CPO<&%R83X*("`@("`\<&%R83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453(B`M($%,5T%94R!P
M<F]M<'0@=&\@<V%V92!A='1A8VAM96YT<R!I;B!T:&4@8V]M<&]S92!S8W)E
M96X[('1H92!D969A=6QT(&ES('1O('-A=F4@871T86-H;65N=',N/"]P87)A
M/@H@("`@(#QP87)A/BH@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE
M;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(@+2!!3%=!65,@<')O;7!T('1O
M('-A=F4@871T86-H;65N=',@:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@
M9&5F875L="!I<R!T;R!N;W0@<V%V92!A='1A8VAM96YT<RX\+W!A<F$^"B`@
M("`@/'!A<F$^*B`B3F5V97(@<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P
M<F]M<'0@=&\@<V%V92!A='1A8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@
M=&AE(&%T=&%C:&UE;G1S(&%R92!.159%4B!S879E9"!W:71H('1H92!M97-S
M86=E+CPO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U86Q?:6YB
M;W@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E9I<G1U86P@1F]L9&5R<SH@
M5FER='5A;"!);F)O>#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%9I<G5T86P@
M26YB;W@@:7,@82!S879E9"!S96%R8V@@=&AA="!D;V5S(&%W87D@=VET:"!T
M:&4@;F5E9"!T;R!S96%R8V@@979E<GD@;6%I;&)O>"!F;W(@;65S<V%G97,@
M;6%R:V5D(&%S(&YE=RX@($EN<W1E860L(&%L;"!C=7)R96YT;'D@<W5B<V-R
M:6)E9"!M86EL8F]X97,@87)E('-E87)C:&5D(&9O<B!N97<@;65S<V%G97,@
M86YD('1H92!R97-U;'1S(&%R92!D:7-P;&%Y960@:6X@82!S:6YG;&4@;6%I
M;&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U
M86Q?=')A<V@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E9I<G1U86P@1F]L
M9&5R<SH@5FER='5A;"!4<F%S:#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%9I
M<G1U86P@5')A<V@@:7,@82!S879E9"!S96%R8V@@=&AA="!D;V5S(&%W87D@
M=VET:"!T:&4@;F5E9"!F;W(@82!S97!A<F%T92!4<F%S:"!F;VQD97(N("!)
M;G-T96%D(&]F(&UO=FEN9R!M97-S86=E<R!T;R!A(&-E;G1R86QI>F5D('1R
M87-H(&9O;&1E<BP@;65S<V%G97,@87)E('-I;7!L>2!M87)K960@87,@9&5L
M971E9"!I;B!T:&4@8W5R<F5N="!F;VQD97(@=&AE>2!L:79E(&EN+B`@5VAE
M;B`G<VAO=R!D96QE=&5D(&UE<W-A9V5S)R!I<R!T=7)N960@;V9F+"!T:&ES
M(')E<W5L=',@:6X@=&AE<V4@;65S<V%G97,@;F]T(&%P<&5A<FEN9R!I;B!A
M(&UA:6QB;W@@=FEE=RX@(%=H96X@82!U<V5R(&-L:6-K<R!O;B!6:7)T=6%L
M(%1R87-H+"`J86QL*B!M86EL8F]X97,@86QL('-E87)C:&5D(&9O<B!M97-S
M86=E<R!T:&%T(&%R92!F;&%G9V5D(&1E;&5T960@86YD('1H97-E(&UE<W-A
M9V5S(&%R92!D:7-P;&%Y960@:6X@82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M;&]C86QE+VQT7TQ4+P``````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S`#`Q-S0V-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O;'1?3%0O3$-?34534T%'15,O````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`
M,#(Q,C4T`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]L=%],
M5"],0U]-15-304=%4R]I;7`N;6\`````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#4U
M,C,S-P`Q,#0Q-S,V,C<V,P`P,C(T,3(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````WA($E0````#E"0``'````$1/```]#0``
M;)X```````!@TP``"@```&'3```*````;-,```H```!WTP``#@```(+3```/
M````D=,```@```"ATP``#````*K3```*````M],```0```#"TP``!````,?3
M```!````S-,``!D```#.TP``#````.C3``!(````]=,``"L````^U```1```
M`&K4```G````K]0``!<```#7U```#P```._4```+````_]0```X````+U0``
M!0```!K5```H````(-4```H```!)U0``%0```%35```2````:M4``#(```!]
MU0``"P```+#5```I````O-4``#(```#FU0``$````!G6```4````*M8``!``
M```_U@``)@```%#6```G````=]8``"8```"?U@``'````,;6```.````X]8`
M``H```#RU@``#0```/W6```G````"]<``"`````SUP``#@```%37```7````
M8]<``"(```![UP``-0```)[7```1````U-<```T```#FUP``#````/37```-
M`````=@```8````/V```&P```!;8```N````,M@``#<```!AV```?````)G8
M``!L````%MD``!P```"#V0``'0```*#9```/````OMD``!@```#.V0``#```
M`.?9``!%````]-D``"@````ZV@``00```&/:```D````I=H```X```#*V@``
M#P```-G:```.````Z=H```X```#XV@``"`````?;```.````$-L```X````?
MVP``+@```"[;```:````7=L``#,```!XVP``40```*S;```R````_ML``#@`
M```QW```5````&K<``!1````O]P``%H````1W0``5P```&S=```T````Q-T`
M``H```#YW0``!0````3>```#````"MX```8````.W@``$0```!7>```(````
M)]X```D````PW@``"0```#K>```.````1-X```@```!3W@``)0```%S>```@
M````@MX``!````"CW@``#P```+3>```/````Q-X```H```#4W@``!P```-_>
M```#````Y]X```\```#KW@``%````/O>```)````$-\```T````:WP``$@``
M`"C?```/````.]\```H```!+WP``#P```%;?```(````9M\```H```!OWP``
M)````'K?```7````G]\``!0```"WWP``%@```,S?```(````X]\``!P```#L
MWP``&0````G@```H````(^```!X```!,X```&@```&O@```L````AN```"``
M``"SX```,@```-3@```'````!^$```P````/X0``#0```!SA```L````*N$`
M``X```!7X0```P```&;A```+````:N$```<```!VX0``!P```'[A```%````
MAN$```4```",X0``"@```)+A```#````G>$``!<```"AX0``"@```+GA```/
M````Q.$```X```#4X0``3@```./A``!0````,N(``$,```"#X@``0@```,?B
M```P````"N,``!@````[XP``(P```%3C```.````>.,``!0```"'XP``%P``
M`)SC```7````M.,``!<```#,XP``$P```.3C```/````^.,``",````(Y```
M!@```"SD```7````,^0```X```!+Y```40```%KD```?````K.0``#4```#,
MY```!P````+E```&````"N4```@````1Y0``#P```!KE```&````*N4```@`
M```QY0``$0```#KE```*````3.4``!,```!7Y0``"P```&OE```5````=^4`
M`",```"-Y0``+P```+'E```5````X>4```<```#WY0``!0```/_E```5````
M!>8``!$````;Y@``#````"WF```P````.N8``$@```!KY@``(0```+3F```[
M````UN8``#L````2YP``/````$[G```K````B^<``#$```"WYP``.P```.GG
M```Y````)>@``#4```!?Z```"0```)7H```'````G^@``!0```"GZ```#```
M`+SH```#````R>@```4```#-Z```"0```-/H```0````W>@```D```#NZ```
M$P```/CH```#````#.D``#D````0Z0``$@```$KI```&````7>D```P```!D
MZ0``-0```''I```.````I^D``$D```"VZ0``,P````#J```*````-.H``"T`
M```_Z@``"P```&WJ```G````>>H``"P```"AZ@``*@```,[J```E````^>H`
M``D````?ZP``"0```"GK```*````,^L```8````^ZP``"0```$7K```'````
M3^L``"\```!7ZP``-P```(?K```N````O^L``%4```#NZP``+0```$3L```L
M````<NP``"T```"?[```+0```,WL``!`````^^P``",````\[0``(P```&#M
M```M````A.T``#,```"R[0``%0```.;M```9````_.T``"D````6[@``)```
M`$#N``!0````9>X``!@```"V[@``$0```,_N```1````X>X```H```#S[@``
M#````/[N```+````"^\```H````7[P``"@```"+O```0````+>\``!8````^
M[P``%@```%7O```'````;.\```<```!T[P``%````'SO```*````D>\```@`
M``"<[P``"````*7O```#````KN\```<```"R[P``!P```+KO```&````PN\`
M`#@```#)[P``!0````+P```'````"/````8````0\```"````!?P```)````
M(/````X````J\```"@```#GP``!%````1/````0```"*\```!````(_P```'
M````E/````D```"<\```!@```*;P```1````K?````<```"_\```%@```,?P
M```$````WO```"<```#C\```"`````OQ```&````%/$```T````;\0``!@``
M`"GQ```>````,/$``!$```!/\0``"````&'Q```-````:O$```P```!X\0``
M!P```(7Q```#````C?$```,```"1\0``%P```)7Q```3````K?$```@```#!
M\0``"````,KQ```$````T_$```@```#8\0``"````.'Q```J````ZO$``"L`
M```5\@``4P```$'R``!!````E?(``"````#7\@``!@```/CR```&````__(`
M``X````&\P``%0```!7S```^````*_,``!@```!J\P``(@```(/S```N````
MIO,``!T```#5\P``(0```//S``!4````%?0``"D```!J]```"@```)3T```'
M````G_0``!4```"G]```#@```+WT```"````S/0```H```#/]```#P```-KT
M```-````ZO0```\```#X]```#0````CU```)````%O4``!0````@]0``!@``
M`#7U```8````//4``!T```!5]0``$P```'/U```4````A_4```0```"<]0``
M#````*'U```&````KO4```H```"U]0``#0```,#U``!B````SO4``"<````Q
M]@``5````%GV``!?````KO8```0````.]P``%@```!/W```.````*O<``!P`
M```Y]P``#P```%;W```S````9O<``"@```":]P``!0```,/W```%````R?<`
M`!L```#/]P``&@```.OW```.````!O@``!4````5^```$0```"OX```1````
M/?@``!$```!/^```'````&'X```J````?O@``#4```"I^```10```-_X```0
M````)?D``"$````V^0``!0```%CY```3````7OD``!(```!R^0``"@```(7Y
M```/````D/D``$<```"@^0``'P```.CY```E````"/H``#,````N^@``*P``
M`&+Z```=````COH``%$```"L^@``$0```/[Z```Q````$/L``!,```!"^P``
M0````%;[```X````E_L```4```#0^P``#````-;[```1````X_L```T```#U
M^P``!@````/\```&````"OP``!<````1_```"````"G\```,````,OP``!0`
M```__```#P```%3\```1````9/P```@```!V_```!0```'_\```1````A?P`
M``P```"7_```$````*3\```%````M?P```T```"[_```!@```,G\```'````
MT/P```T```#8_```!P```.;\```+````[OP```<```#Z_```!P````+]```)
M````"OT``!<````4_0``)@```"S]``!/````4_T```D```"C_0``"@```*W]
M```9````N/T```P```#2_0``)0```-_]```?````!?X``!`````E_@``!0``
M`#;^```E````//X``!(```!B_@``$P```'7^```K````B?X``#L```"U_@``
M(````/'^```;````$O\``#8````N_P``"````&7_```;````;O\``!X```"*
M_P``7````*G_```N````!@`!``P````U``$`!@```$(``0`$````20`!``X`
M``!.``$`#@```%T``0`'````;``!``X```!T``$`"@```(,``0`-````C@`!
M`!X```"<``$`&P```+L``0`A````UP`!`!X```#Y``$`&0```!@!`0`>````
M,@$!`!L```!1`0$`)@```&T!`0`D````E`$!`!L```"Y`0$`'@```-4!`0`<
M````]`$!`"8````1`@$`-@```#@"`0`S````;P(!`"D```"C`@$`00```,T"
M`0`Z````#P,!`"8```!*`P$`*P```'$#`0`X````G0,!`"\```#6`P$`$@``
M``8$`0`I````&00!`!(```!#!`$`H@```%8$`0`6````^00!`",````0!0$`
M*````#0%`0`I````704!`"@```"'!0$`'P```+`%`0`@````T`4!`"4```#Q
M!0$`(0```!<&`0`<````.08!`"8```!6!@$`00```'T&`0`,````OP8!``<`
M``#,!@$`!P```-0&`0`&````W`8!``T```#C!@$`"P```/$&`0`5````_08!
M``T````3!P$`&@```"$'`0`0````/`<!`!T```!-!P$`&0```&L'`0!=````
MA0<!`!(```#C!P$`$P```/8'`0`2````"@@!``<````="`$`!````"4(`0`,
M````*@@!``X````W"`$`#P```$8(`0`4````5@@!`!,```!K"`$`#0```'\(
M`0`Y````C0@!`!P```#'"`$`*````.0(`0`#````#0D!``T````1"0$`!@``
M`!\)`0`1````)@D!`!<````X"0$`&P```%`)`0`.````;`D!``(```!["0$`
M!0```'X)`0`%````A`D!`!````"*"0$`!````)L)`0`-````H`D!``X```"N
M"0$``P```+T)`0`.````P0D!``@```#0"0$`#P```-D)`0`(````Z0D!``\`
M``#R"0$`#0````(*`0`0````$`H!`!D````A"@$`&@```#L*`0`+````5@H!
M``D```!B"@$`!@```&P*`0`4````<PH!`!,```"("@$`$````)P*`0`,````
MK0H!`!$```"Z"@$`%0```,P*`0`9````X@H!``L```#\"@$`#0````@+`0`B
M````%@L!`"L````Y"P$`%P```&4+`0`T````?0L!`#,```"R"P$`"@```.8+
M`0`8````\0L!`!D````*#`$`%@```"0,`0`'````.PP!`!````!##`$`'```
M`%0,`0`<````<0P!``T```".#`$`!P```)P,`0`,````I`P!`"8```"Q#`$`
M"@```-@,`0`4````XPP!``L```#X#`$`!P````0-`0`B````#`T!`"\````O
M#0$`"P```%\-`0`)````:PT!`!D```!U#0$`"P```(\-`0`/````FPT!`!<`
M``"K#0$`%P```,,-`0`)````VPT!``<```#E#0$`%@```.T-`0`/````!`X!
M`"T````4#@$`%@```$(.`0`.````60X!`!H```!H#@$`*````(,.`0`+````
MK`X!`!@```"X#@$`"````-$.`0`,````V@X!`",```#G#@$`#0````L/`0`F
M````&0\!`"H```!`#P$`(````&L/`0!#````C`\!``@```#0#P$`$@```-D/
M`0`$````[`\!``@```#Q#P$`"P```/H/`0`:````!A`!`"<````A$`$`$@``
M`$D0`0`@````7!`!`"\```!]$`$`%P```*T0`0`%````Q1`!``P```#+$`$`
M#@```-@0`0`.````YQ`!``4```#V$`$`!@```/P0`0`.`````Q$!``,````2
M$0$`*P```!81`0`'````0A$!``0```!*$0$`#@```$\1`0`*````7A$!``P`
M``!I$0$`"@```'81`0`/````@1$!`!````"1$0$`%P```*(1`0`3````NA$!
M`"4```#.$0$`#@```/01`0`1`````Q(!`!<````5$@$`$P```"T2`0`6````
M01(!`#@```!8$@$`$P```)$2`0`)````I1(!``4```"O$@$`"P```+42`0`*
M````P1(!``(```#,$@$`!0```,\2`0`-````U1(!`!L```#C$@$`%P```/\2
M`0`)````%Q,!`!T````A$P$`#P```#\3`0`2````3Q,!``P```!B$P$`#@``
M`&\3`0`-````?A,!`!(```",$P$`&0```)\3`0`<````N1,!`#@```#6$P$`
M&`````\4`0`@````*!0!`!,```!)%`$``P```%T4`0`5````810!``L```!W
M%`$`$P```(,4`0`(````EQ0!``X```"@%`$`$````*\4`0![````P!0!`!@`
M```\%0$`*0```%45`0`L````?Q4!`"@```"L%0$`-0```-45`0`1````"Q8!
M``<````=%@$`!0```"46`0`8````*Q8!`!D```!$%@$`!P```%X6`0`(````
M9A8!``8```!O%@$`!@```'86`0`;````?18!`!````"9%@$`#P```*H6`0`0
M````NA8!``\```#+%@$`"P```-L6`0`/````YQ8!``P```#W%@$`#P````07
M`0`'````%!<!``8````<%P$`"@```",7`0`2````+A<!``T```!!%P$`#```
M`$\7`0!#````7!<!`#T```"@%P$`"0```-X7`0`,````Z!<!`"@```#U%P$`
M#P```!X8`0`(````+A@!``@````W&`$`$P```$`8`0`>````5!@!`"$```!S
M&`$`(````)48`0`9````MA@!`!<```#0&`$`)0```.@8`0`7````#AD!``0`
M```F&0$`&P```"L9`0`-````1QD!``,```!5&0$`"````%D9`0`*````8AD!
M``P```!M&0$`"@```'H9`0`@````A1D!`!\```"F&0$`"P```,89`0`;````
MTAD!``L```#N&0$`"````/H9`0`$`````QH!``0````(&@$`$P````T:`0`4
M````(1H!``P````V&@$`"0```$,:`0`.````31H!``L```!<&@$`&P```&@:
M`0`.````A!H!``\```"3&@$`)0```*,:`0`J````R1H!``<```#T&@$`$@``
M`/P:`0`;````#QL!``0````K&P$`!P```#`;`0`*````.!L!`!(```!#&P$`
M"@```%8;`0`-````81L!``D```!O&P$`!````'D;`0`%````?AL!``@```"$
M&P$``P```(T;`0`8````D1L!`!````"J&P$`#@```+L;`0`>````RAL!`!H`
M``#I&P$`"@````0<`0`$````#QP!`"8````4'`$`#@```#L<`0!\````2AP!
M`!4```#''`$`1````-T<`0`%````(AT!``<````H'0$`#````#`=`0`(````
M/1T!``H```!&'0$`!@```%$=`0`'````6!T!``@```!@'0$`$0```&D=`0`9
M````>QT!``@```"5'0$``@```)X=`0`&````H1T!``8```"H'0$`%````*\=
M`0`5````Q!T!``\```#:'0$`$0```.H=`0`:````_!T!``T````7'@$`$```
M`"4>`0`;````-AX!``4```!2'@$`!````%@>`0`,````71X!``D```!J'@$`
M$````'0>`0`)````A1X!``D```"/'@$`!````)D>`0`%````GAX!`!H```"D
M'@$`!0```+\>`0`:````Q1X!``@```#@'@$`!@```.D>`0`/````\!X!`!D`
M````'P$`#@```!H?`0`'````*1\!``<````Q'P$`(@```#D?`0`%````7!\!
M``D```!B'P$`"@```&P?`0`-````=Q\!``8```"%'P$`#0```(P?`0`,````
MFA\!``D```"G'P$`!@```+$?`0`2````N!\!``D```#+'P$`!P```-4?`0`4
M````W1\!`!T```#R'P$`!@```!`@`0`*````%R`!``0````B(`$`"0```"<@
M`0`(````,2`!`!$````Z(`$`"0```$P@`0`&````5B`!``T```!=(`$`!@``
M`&L@`0`$````<B`!``0```!W(`$`%P```'P@`0`Y````E"`!`#T```#.(`$`
M.@````PA`0`>````1R$!``4```!F(0$`#@```&PA`0`$````>R$!``8```"`
M(0$`!P```(<A`0`A````CR$!`!4```"Q(0$`!@```,<A`0`$````SB$!`!$`
M``#3(0$`!@```.4A`0`*````["$!`"(```#W(0$`)P```!HB`0`&````0B(!
M`!4```!)(@$`#````%\B`0`1````;"(!``0```!^(@$`#0```(,B`0`'````
MD2(!``4```"9(@$`'0```)\B`0`$````O2(!``P```#"(@$`"@```,\B`0`(
M````VB(!``D```#C(@$`!0```.TB`0`Z````\R(!`#`````N(P$`-0```%\C
M`0`I````E2,!`$<```"_(P$`.`````<D`0`I````0"0!`#\```!J)`$`+@``
M`*HD`0`M````V20!`!\````')0$`#P```"<E`0`2````-R4!``L```!*)0$`
M)@```%8E`0`G````?24!`"D```"E)0$`)````,\E`0`F````]"4!`"@````;
M)@$`"````$0F`0`*````328!``D```!8)@$`!P```&(F`0`$````:B8!`!P`
M``!O)@$`(````(PF`0`@````K28!`"8```#.)@$`#0```/4F`0`G`````R<!
M`!L````K)P$`#````$<G`0`6````5"<!``4```!K)P$`"@```'$G`0`9````
M?"<!`"D```"6)P$`%@```,`G`0`2````UR<!``<```#J)P$`"@```/(G`0`/
M````_2<!`!`````-*`$`0````!XH`0!F````7R@!``8```#&*`$`"@```,TH
M`0`.````V"@!``D```#G*`$`"@```/$H`0`2````_"@!`!,````/*0$`#```
M`",I`0`&````,"D!``8````W*0$`"@```#XI`0`.````22D!``X```!8*0$`
M'P```&<I`0`>````ARD!`",```"F*0$`$0```,HI`0`5````W"D!`!@```#R
M*0$`$0````LJ`0`0````'2H!`",````N*@$`#P```%(J`0`)````8BH!`!(`
M``!L*@$`'0```'\J`0`2````G2H!`!````"P*@$`"@```,$J`0`1````S"H!
M``4```#>*@$`,0```.0J`0`D````%BL!`!P````[*P$`(P```%@K`0!J````
M?"L!``\```#G*P$`!0```/<K`0`0````_2L!``D````.+`$`!````!@L`0`+
M````'2P!`!P````I+`$`(P```$8L`0`B````:BP!``8```"-+`$`%````)0L
M`0`7````J2P!``P```#!+`$`)````,XL`0`C````\RP!`!H````7+0$`#```
M`#(M`0`/````/RT!`!4```!/+0$`*0```&4M`0`J````CRT!`"8```"Z+0$`
M)P```.$M`0`I````"2X!`"H````S+@$`&0```%XN`0!"````>"X!`!$```"[
M+@$`$@```,TN`0`3````X"X!`!0```#T+@$`#P````DO`0`6````&2\!`!<`
M```P+P$`$````$@O`0`1````62\!`#0```!K+P$`$P```*`O`0`2````M"\!
M`#4```#'+P$`%````/TO`0`'````$C`!``P````:,`$`*P```"<P`0`/````
M4S`!`!8```!C,`$`(````'HP`0`4````FS`!`!$```"P,`$`%P```,(P`0`<
M````VC`!`!,```#W,`$`"P````LQ`0`1````%S$!`!H````I,0$`'@```$0Q
M`0`:````8S$!`"$```!^,0$`(````*`Q`0`1````P3$!`!0```#3,0$`%P``
M`.@Q`0`5`````#(!``D````6,@$`!@```"`R`0`9````)S(!``0```!!,@$`
M!P```$8R`0`+````3C(!`!$```!:,@$`!@```&PR`0`&````<S(!``8```!Z
M,@$`!0```($R`0`'````AS(!``<```"/,@$`!0```)<R`0`6````G3(!``8`
M``"T,@$`!@```+LR`0`$````PC(!``0```#',@$`!P```,PR`0`.````U#(!
M``P```#C,@$`#````/`R`0`-````_3(!``(````+,P$`"@````XS`0`.````
M&3,!``4````H,P$`*````"XS`0`.````5S,!``P```!F,P$`#P```',S`0`*
M````@S,!``@```".,P$`"0```)<S`0`K````H3,!`"X```#-,P$`!````/PS
M`0`(`````30!`"8````*-`$`$@```#$T`0`/````1#0!``8```!4-`$`"@``
M`%LT`0`'````9C0!``@```!N-`$`(````'<T`0`)````F#0!`!$```"B-`$`
M"0```+0T`0`,````OC0!``T```#+-`$`#@```-DT`0`6````Z#0!`!$```#_
M-`$`!@```!$U`0`#````&#4!``8````<-0$`&0```",U`0`'````/34!``0`
M``!%-0$`"P```$HU`0`+````5C4!``<```!B-0$`$0```&HU`0`'````?#4!
M`!8```"$-0$`#0```)LU`0`-````J34!``H```"W-0$`$````,(U`0`/````
MTS4!`!$```#C-0$`%P```/4U`0`*````#38!`!$````8-@$`"````"HV`0`$
M````,S8!``\````X-@$`.@```$@V`0`A````@S8!``4```"E-@$`#````*LV
M`0`>````N#8!``X```#7-@$`$````.8V`0`+````]S8!`'P````#-P$`#```
M`(`W`0`)````C3<!``<```"7-P$`"@```)\W`0`)````JC<!``X```"T-P$`
M$````,,W`0`5````U#<!`!H```#J-P$`"@````4X`0`)````$#@!``H````:
M.`$`#@```"4X`0`,````-#@!``\```!!.`$`"````%$X`0`&````6C@!``P`
M``!A.`$`!P```&XX`0`%````=C@!``L```!\.`$`1P```(@X`0`-````T#@!
M``D```#>.`$`!````.@X`0`#````[3@!``P```#Q.`$`$P```/XX`0`3````
M$CD!`!,````F.0$`!@```#HY`0`*````03D!``(```!,.0$`!````$\Y`0`E
M````5#D!``,```!Z.0$`!0```'XY`0`J````A#D!``X```"O.0$`"@```+XY
M`0`%````R3D!``0```#/.0$`"@```-0Y`0`-````WSD!`!\```#M.0$`!P``
M``TZ`0`B````%3H!``T````X.@$`!@```$8Z`0`(````33H!``@```!6.@$`
M!````%\Z`0`%````9#H!`&@```!J.@$`"0```-,Z`0`,````W3H!``4```#J
M.@$`!@```/`Z`0`C````]SH!`"4````;.P$`"````$$[`0`W````2CL!`"(`
M``"".P$`$P```*4[`0`;````N3L!`"\```#5.P$`$`````4\`0`*````%CP!
M`!$````A/`$`#P```#,\`0`/````0SP!``H```!3/`$`"0```%X\`0`3````
M:#P!`!L```!\/`$`&````)@\`0`7````L3P!`!<```#)/`$`#@```.$\`0`F
M````\#P!`"8````7/0$``P```#X]`0`'````0CT!``@```!*/0$`%````%,]
M`0`3````:#T!`!````!\/0$`#0```(T]`0`.````FST!`!8```"J/0$`!P``
M`,$]`0`0````R3T!``H```#:/0$`"P```.4]`0`'````\3T!`!,```#Y/0$`
M#`````T^`0`/````&CX!``X````J/@$`#````#D^`0`.````1CX!`%$```!5
M/@$`#P```*<^`0`0````MSX!``T```#(/@$`#P```-8^`0`/````YCX!``\`
M``#V/@$`(`````8_`0`N````)S\!`!H```!6/P$`#````'$_`0`F````?C\!
M``L```"E/P$`#0```+$_`0`:````OS\!`$H```#:/P$`!@```"5``0`&````
M+$`!``8````S0`$`'P```#I``0`&````6D`!``D```!A0`$`&````&M``0`7
M````A$`!``8```"<0`$`#0```*-``0`B````L4`!`%<```#40`$`$P```"Q!
M`0`C````0$$!`!,```!D00$``@```'A!`0`+````>T$!``@```"'00$`#0``
M`)!!`0`&````GD$!``H```"E00$`!P```+!!`0`4````N$$!``8```#-00$`
M"````-1!`0`.````W4$!``<```#L00$`"@```/1!`0`+````_T$!``<````+
M0@$`#````!-"`0`-````($(!``P````N0@$`!````#M"`0`)````0$(!``D`
M``!*0@$`"@```%1"`0`'````7T(!``D```!G0@$`#@```'%"`0`'````@$(!
M``H```"(0@$`&P```)-"`0`5````KT(!`!(```#%0@$`"@```-A"`0`)````
MXT(!`!````#M0@$`!P```/Y"`0`2````!D,!``0````90P$`!````!Y#`0`B
M````(T,!``<```!&0P$`!0```$Y#`0`,````5$,!``4```!A0P$`"P```&=#
M`0`4````<T,!`!$```"(0P$`&@```)I#`0`6````M4,!`!0```#,0P$`%P``
M`.%#`0`8````^4,!`!P````21`$`&0```"]$`0`'````240!``4```!11`$`
M%@```%=$`0`#````;D0!``T```!R1`$`#````(!$`0`*````C40!``@```"8
M1`$`"````*%$`0`7````JD0!``L```#"1`$`#````,Y$`0`3````VT0!``0`
M``#O1`$`"@```/1$`0`$````_T0!``P````$10$`"0```!%%`0`,````&T4!
M``D````H10$`!0```#)%`0`'````.$4!``4```!`10$`!````$9%`0`"````
M2T4!`!0```!.10$`#0```&-%`0`2````<44!``L```"$10$`&P```)!%`0`?
M````K$4!`!0```#,10$`'@```.%%`0`5`````$8!`#@````61@$`+````$]&
M`0`2````?$8!`"D```"/1@$`,@```+E&`0`*````[$8!`"P```#W1@$`+@``
M`"1'`0`S````4T<!`#,```"'1P$`.````+M'`0`/````]$<!`!@````$2`$`
M$````!U(`0`3````+D@!`"H```!"2`$`&0```&U(`0`<````AT@!`!\```"D
M2`$`$P```,1(`0`4````V$@!`!0```#M2`$`(`````))`0`2````(TD!`!0`
M```V20$`%0```$M)`0`M````84D!`"T```"/20$`,0```+U)`0`N````[TD!
M`"\````>2@$`+````$Y*`0!B````>TH!`!,```#>2@$`)0```/)*`0`D````
M&$L!`"D````]2P$`"````&=+`0`(````<$L!`"0```!Y2P$`$@```)Y+`0`.
M````L4L!`"L```#`2P$`$@```.Q+`0`A````_TL!`!H````A3`$`"0```#Q,
M`0!%````1DP!`$$```",3`$`#P```,Y,`0`$````WDP!`!,```#C3`$`%```
M`/=,`0`.````#$T!``8````;30$`$P```")-`0`8````-DT!``8```!/30$`
M"0```%9-`0`*````8$T!``L```!K30$`"0```'=-`0`-````@4T!``P```"/
M30$`#P```)Q-`0`7````K$T!`!0```#$30$`$````-E-`0`6````ZDT!``<`
M```!3@$`#@````E.`0`A````&$X!``4````Z3@$`&P```$!.`0`(````7$X!
M``8```!E3@$`%````&Q.`0`1````@4X!`$0```"33@$`/````-A.`0`.````
M%4\!`#@````D3P$``@```%U/`0`"````8$\!``8```!C3P$`#@```&I/`0`%
M````>4\!``<```!_3P$`#@```(=/`0`&````ED\!``P```"=3P$`(P```*I/
M`0`$````SD\!`"D```#33P$`,@```/U/`0`7````,%`!`!\```!(4`$`,P``
M`&A0`0!<````G%`!`!0```#Y4`$`#0````Y1`0`?````'%$!`!`````\40$`
M%````$U1`0`'````8E$!``X```!J40$`#````'E1`0`,````AE$!`!,```"3
M40$`"@```*=1`0`=````LE$!`!D```#040$`!0```.I1`0`1````\%$!`!,`
M```"4@$`#0```!92`0`1````)%(!`"0````V4@$``P```%M2`0`5````7U(!
M`!,```!U4@$`$@```(E2`0`+````G%(!`#0```"H4@$`"P```-U2`0`4````
MZ5(!`#X```#^4@$`#@```#U3`0`3````3%,!`#0```!@4P$`,0```)53`0`2
M````QU,!`!````#:4P$`&````.M3`0`9````!%0!`",````>5`$`(@```$)4
M`0`G````950!`%8```"-5`$`30```.14`0`(````,E4!``D````[50$`#0``
M`$55`0`*````4U4!``L```!>50$`!````&I5`0`<````;U4!``T```",50$`
M)P```)I5`0`;````PE4!``P```#>50$`"@```.M5`0`'````]E4!``T```#^
M50$`(@````Q6`0`A````+U8!``@```!15@$`!0```%I6`0`?````8%8!``8`
M``"`5@$`$````(=6`0`(````F%8!``<```"A5@$`#0```*E6`0`*````MU8!
M`!(```#"5@$`(0```-56`0`+````]U8!`!P````#5P$`&````"!7`0`(````
M.5<!`!(```!"5P$`+````%57`0`:````@E<!``D```"=5P$`"@```*=7`0`5
M````LE<!``4```#(5P$`%````,Y7`0`$````XU<!`!````#H5P$`!@```/E7
M`0`'`````%@!`!X````(6`$`*````"=8`0`*````4%@!`!H```!;6`$`+0``
M`'98`0`(````I%@!`!0```"M6`$`+````,)8`0`G````[U@!`"L````760$`
M*@```$-9`0`$````;ED!``0```!S60$`"P```'A9`0`%````A%D!``8```"*
M60$`"````)%9`0`&````FED!`#$```"A60$`'````--9`0`*````\%D!`!L`
M``#[60$`-````!=:`0`T````3%H!`"````"!6@$`*0```*):`0`G````S%H!
M`"````#T6@$`00```!5;`0`:````5UL!`"@```!R6P$`&@```)M;`0!V````
MMEL!`'D````M7`$`'`$``*=<`0`H````Q%T!`!T```#M70$`*0````M>`0`=
M````-5X!`"X```!37@$`5P```()>`0`V````VEX!`"P````17P$`+````#Y?
M`0`Q````:U\!`"X```"=7P$`(@```,Q?`0`&````[U\!``@```#V7P$`!0``
M`/]?`0`(````!6`!`!D````.8`$`&0```"A@`0`J````0F`!`!````!M8`$`
M*P```'Y@`0`C````JF`!`"$```#.8`$`+@```/!@`0`T````'V$!``@```!4
M80$`%P```%UA`0`*````=6$!``<```"`80$`(0```(AA`0`0````JF$!``T`
M``"[80$`$````,EA`0`%````VF$!``X```#@80$`"````.]A`0`+````^&$!
M``<````$8@$`$P````QB`0`(````(&(!`#8````I8@$`-P```&!B`0`+````
MF&(!``D```"D8@$`"@```*YB`0`4````N6(!`"\```#.8@$`,@```/YB`0`+
M````,6,!``X````]8P$`#0```$QC`0`/````6F,!`!8```!J8P$`/@```(%C
M`0`G````P&,!``4```#H8P$`!0```.YC`0`G````]&,!`!\````<9`$`%@``
M`#QD`0`7````4V0!``\```!K9`$`!````'MD`0`*````@&0!``D```"+9`$`
M"P```)5D`0`.````H60!``4```"P9`$`'@```+9D`0`$````U60!``T```#:
M9`$`,@```.AD`0!%````&V4!``L```!A90$`#@```&UE`0`.````?&4!``D`
M``"+90$`"````)5E`0`0````GF4!`!4```"O90$`$P```,5E`0`7````V64!
M``<```#Q90$`'@```/EE`0`5````&&8!`!0````N9@$`!0```$-F`0`4````
M268!``L```!>9@$`!P```&IF`0`C````<F8!`!8```"69@$`#P```*UF`0`.
M````O68!`"H```#,9@$`!@```/=F`0`,````_F8!`!@````+9P$`#0```"1G
M`0`1````,F<!``L```!$9P$`-@```%!G`0`-````AV<!``H```"59P$`(@``
M`*!G`0`+````PV<!``\```#/9P$`$````-]G`0`N````\&<!`#H````?:`$`
M#@```%IH`0`-````:6@!``4```!W:`$`"P```'UH`0`,````B6@!``T```"6
M:`$`#0```*1H`0`.````LF@!``T```#!:`$`(````,]H`0`G````\&@!`"L`
M```8:0$`"````$1I`0`*````36D!``8```!8:0$`$@```%]I`0`.````<FD!
M`!<```"!:0$`,@```)EI`0`>````S&D!`!8```#K:0$`'`````)J`0`4````
M'VH!``4````T:@$`#@```#IJ`0`3````26H!`!H```!=:@$`!P```'AJ`0`&
M````@&H!`!,```"':@$`%````)MJ`0`1````L&H!`$L```#":@$`!P````YK
M`0`4````%FL!`!@````K:P$`!P```$1K`0`%````3&L!``P```!2:P$`#```
M`%]K`0`2````;&L!``0```!_:P$`!P```(1K`0`*````C&L!``L```"7:P$`
M#````*-K`0`.````L&L!``X```"_:P$`!0```,YK`0`%````U&L!`"X```#:
M:P$`)@````EL`0`C````,&P!``,```!4;`$`$@```%AL`0`&````:VP!``8`
M``!R;`$`'@```'EL`0`6````F&P!`!@```"O;`$`#@```,AL`0`W````UVP!
M``X````/;0$`%P```!YM`0!!````-FT!`#0```!X;0$`)0```*UM`0`5````
MTVT!`#$```#I;0$`$P```!MN`0`;````+VX!`"H```!+;@$`40```'9N`0!0
M````R&X!`"4````9;P$`#0```#]O`0`)````36\!``,```!7;P$`!P```%MO
M`0`*````8V\!``@```!N;P$``@```'=O`0`0````>F\!``@```"+;P$`#```
M`)1O`0`5````H6\!``L```"W;P$`&0```,-O`0`@````W6\!`!(```#^;P$`
M!0```!%P`0`*````%W`!`!4````B<`$`$@```#AP`0`,````2W`!``0```!8
M<`$`!P```%UP`0`R````97`!``H```"8<`$`#````*-P`0`+````L'`!``<`
M``"\<`$`%@```,1P`0!2````VW`!`#H````N<0$`(````&EQ`0`/````BG$!
M`!<```":<0$`.0```+)Q`0`'````['$!``8```#T<0$`"0```/MQ`0`.````
M!7(!``X````4<@$`!````"-R`0`&````*'(!`!8````O<@$`#````$9R`0`-
M````4W(!``X```!A<@$`%0```'!R`0`2````AG(!``\```"9<@$`%````*ER
M`0!#````OG(!``H````"<P$`&P````US`0`U````*7,!`!$```!?<P$`$```
M`'%S`0`+````@G,!`&D```".<P$`&@```/AS`0`7````$W0!`"<````K=`$`
M&P```%-T`0`:````;W0!`!<```"*=`$`&P```*)T`0`9````OG0!`!\```#8
M=`$`%P```/AT`0`<````$'4!`!<````M=0$`#````$5U`0`3````4G4!``@`
M``!F=0$`!P```&]U`0`(````=W4!`!````"`=0$`$0```)%U`0`)````HW4!
M`!4```"M=0$`#0```,-U`0`&````T74!`!T```#8=0$`!P```/9U`0`3````
M_G4!``,````2=@$`1@```!9V`0!#````778!`#(```"A=@$`/P```-1V`0`W
M````%'<!`%<```!,=P$`'P```*1W`0`O````Q'<!``H```#T=P$`#0```/]W
M`0`2````#7@!`"D````@>`$`"````$IX`0`-````4W@!`"T```!A>`$`<```
M`(]X`0`_`````'D!`#D```!`>0$`1@```'IY`0`$````P7D!`!````#&>0$`
M$````-=Y`0`,````Z'D!`!0```#U>0$`'0````IZ`0`<````*'H!`!$```!%
M>@$`/0```%=Z`0!/````E7H!`"4```#E>@$`(`````M[`0`<````+'L!``L`
M``!)>P$`)P```%5[`0`:````?7L!`!\```"8>P$`'0```+A[`0`H````UGL!
M``\```#_>P$`)0````]\`0`@````-7P!`"0```!6?`$`)````'M\`0`@````
MH'P!`"4```#!?`$`"P```.=\`0`'````\WP!``T```#[?`$`#`````E]`0`%
M````%GT!``8````<?0$`.0```"-]`0`%````77T!``P```!C?0$`!P```'!]
M`0`)````>'T!`!,```""?0$`!@```)9]`0`)````G7T!``0```"G?0$`$```
M`*Q]`0`(````O7T!``@```#&?0$`"P```,]]`0`,````VWT!`!H```#H?0$`
M#P````-^`0`'````$WX!``T````;?@$`#P```"E^`0`,````.7X!`!0```!&
M?@$`%````%M^`0`/````<'X!``X```"`?@$`$@```(]^`0`4````HGX!``X`
M``"W?@$`#````,9^`0`;````TWX!`"P```#O?@$`$P```!Q_`0`<````,'\!
M`"@```!-?P$`!@```'9_`0`'````?7\!`!,```"%?P$`!0```)E_`0`$````
MGW\!``P```"D?P$`%P```+%_`0`2````R7\!``L```#<?P$`#0```.A_`0`4
M````]G\!`"\````+@`$`"@```#N``0`,````1H`!``D```!3@`$`!@```%V`
M`0`)````9(`!``@```!N@`$`"0```'>``0`%````@8`!``H```"'@`$`$0``
M`)*``0`&````I(`!``X```"K@`$`#@```+J``0`-````R8`!``L```#7@`$`
M$````..``0`=````](`!`!$````2@0$`"P```"2!`0`"````,($!``@````S
M@0$`!P```#R!`0`-````1($!``8```!2@0$`%@```%F!`0`)````<($!``<`
M``!Z@0$`.P```(*!`0`H````OH$!`!4```#G@0$`!0```/V!`0`+`````X(!
M``<````/@@$`"````!>"`0`'````(((!``4````H@@$`!P```"Z"`0`.````
M-H(!``D```!%@@$`!@```$^"`0`(````5H(!``L```!?@@$`!P```&N"`0`(
M````<X(!``<```!\@@$`%@```(2"`0`)````FX(!``8```"E@@$`&0```*R"
M`0`:````QH(!`"````#A@@$`"P````*#`0`<````#H,!`!0````K@P$`!P``
M`$"#`0`(````2(,!``@```!1@P$`!0```%J#`0`0````8(,!`!````!Q@P$`
M!@```(*#`0`9````B8,!``H```"C@P$`'````*Z#`0`'````RX,!``4```#3
M@P$`!0```-F#`0`0````WX,!`!0```#P@P$`"P````6$`0`-````$80!`!<`
M```?A`$`&@```#>$`0`4````4H0!`"\```!GA`$`"0```)>$`0`*````H80!
M``<```"LA`$``@```+2$`0`.````MX0!``@```#&A`$`'P```,^$`0`C````
M[X0!`#$````3A0$`.````$6%`0`;````?H4!`#$```":A0$`,0```,R%`0`G
M````_H4!`"(````FA@$`(````$F&`0!D````:H8!`!T```#/A@$`%````.V&
M`0!=`````H<!`%4```!@AP$`.````+:'`0`M````[X<!`#,````=B`$`2P``
M`%&(`0!*````G8@!`%L```#HB`$`*````$2)`0`L````;8D!`#@```":B0$`
M)0```-.)`0`H````^8D!`"P````BB@$`)P```$^*`0`;````=XH!`!X```"3
MB@$`=0```+**`0`^````*(L!`$(```!GBP$`/0```*J+`0`I````Z(L!`"D`
M```2C`$`,0```#R,`0`^````;HP!`"\```"MC`$`J0$``-V,`0`C````AXX!
M`$\```"KC@$`%P```/N.`0!(````$X\!`#8```!<CP$`/@```)./`0`P````
MTH\!`"`````#D`$`/P```"20`0`T````9)`!`!T```"9D`$`'@```+>0`0"%
M````UI`!`#````!<D0$`00```(V1`0!@````SY$!`%L````PD@$`20```(R2
M`0`T````UI(!`#P````+DP$`.````$B3`0`=````@9,!`!@```"?DP$`IP``
M`+B3`0`A````8)0!`!\```""E`$`)````**4`0`H````QY0!`"L```#PE`$`
M(@```!R5`0`A````/Y4!`"D```!AE0$`%P```(N5`0`I````HY4!`"````#-
ME0$`,@```.Z5`0`<````(98!`"X````^E@$`'0```&V6`0`1````BY8!`#,`
M``"=E@$`)0```-&6`0`X````]Y8!`"<````PEP$`/````%B7`0`F````E9<!
M`!\```"\EP$`,````-R7`0!I````#9@!`#X```!WF`$`/@```+:8`0!'````
M]9@!`#T````]F0$`90```'N9`0!-````X9D!`%,````OF@$`5P```(.:`0!5
M````VYH!`$8````QFP$`*@```'B;`0`O````HYL!`%4```#3FP$`(````"F<
M`0`N````2IP!`"L```!YG`$`,````*6<`0`J````UIP!`#X````!G0$`5```
M`$"=`0!2````E9T!`%H```#HG0$`,@```$.>`0`K````=IX!`$@```"BG@$`
M2@```.N>`0`J````-I\!`"8```!AGP$`+````(B?`0!.````M9\!`#(````$
MH`$`,````#>@`0`=````:*`!`",```"&H`$`+P```*J@`0`L````VJ`!`"T`
M```'H0$`<0```#6A`0!O````IZ$!`+,````7H@$`%P```,NB`0`E````XZ(!
M`#(````)HP$`*0```#RC`0`^````9J,!`"(```"EHP$`4@```,BC`0`E````
M&Z0!``L```!!I`$`L0```$VD`0`[````_Z0!`"<````[I0$`8@```&.E`0!)
M````QJ4!`%4````0I@$`0````&:F`0`O````IZ8!`#(```#7I@$`*P````JG
M`0`I````-J<!``\```!@IP$`10```'"G`0`A````MJ<!`#````#8IP$`+0``
M``FH`0`E````-Z@!`!P```!=J`$`,0```'JH`0`Q````K*@!``L```#>J`$`
M!P```.JH`0`'````\J@!``0```#ZJ`$`#0```/^H`0`+````#:D!``X````9
MJ0$`"P```"BI`0`%````-*D!`!`````ZJ0$``@```$NI`0`*````3JD!`%8`
M``!9J0$`60```+"I`0`%````"JH!`!(````0J@$`!````".J`0`'````**H!
M``@````PJ@$`!0```#FJ`0`#````/ZH!`!````!#J@$`%P```%2J`0`,````
M;*H!``P```!YJ@$`#0```(:J`0`3````E*H!``T```"HJ@$``@```+:J`0`'
M````N:H!``8```#!J@$`%````,BJ`0`,````W:H!`!@```#JJ@$`!@````.K
M`0`2````"JL!``P````=JP$``P```"JK`0`J````+JL!``0```!9JP$`!@``
M`%ZK`0`'````9:L!`!\```!MJP$`-0```(VK`0`N````PZL!`"\```#RJP$`
M%P```"*L`0`@````.JP!`!L```!;K`$`&````'>L`0`D````D*P!`!\```"U
MK`$`&@```-6L`0`@````\*P!`!H````1K0$`,@```"RM`0`O````7ZT!`"L`
M``"/K0$`'P```+NM`0`C````VZT!`!\```#_K0$`&@```!^N`0`E````.JX!
M`"8```!@K@$`)0```(>N`0`D````K:X!`!@```#2K@$`'0```.NN`0`D````
M":\!`!@````NKP$`(@```$>O`0`E````:J\!`#P```"0KP$`'P```,VO`0`C
M````[:\!`!\````1L`$`(````#&P`0`:````4K`!`!@```!ML`$`&````(:P
M`0`F````G[`!`!X```#&L`$`*0```.6P`0`>````#[$!``H````NL0$`$P``
M`#FQ`0`(````3;$!``D```!6L0$`%@```&"Q`0`,````=[$!`!<```"$L0$`
M+P```)RQ`0`D````S+$!``<```#QL0$`'P```/FQ`0`/````&;(!`!0````I
ML@$`#@```#ZR`0`-````3;(!`"0```!;L@$`!0```("R`0`'````AK(!``P`
M``".L@$`#P```)NR`0`1````J[(!`"(```"]L@$`)0```."R`0`=````!K,!
M`!H````DLP$`$0```#^S`0`'````4;,!`,<```!9LP$`!@```"&T`0`+````
M*+0!`!H````TM`$`%0```$^T`0`&````9;0!``D```!LM`$`'0```':T`0`8
M````E+0!``L```"MM`$`%P```+FT`0`&````T;0!`#,```#8M`$`$P````RU
M`0`3````(+4!``<````TM0$`#P```#RU`0`1````3+4!`!X```!>M0$`!P``
M`'VU`0`R````A;4!``0```"XM0$`(0```+VU`0`3````W[4!``P```#SM0$`
M$0````"V`0`R````$K8!``@```!%M@$`"0```$ZV`0`*````6+8!`!0```!C
MM@$`"@```'BV`0`=````@[8!``@```"AM@$`'P```*JV`0`(````RK8!`!H`
M``#3M@$`!@```.ZV`0`5````];8!``<````+MP$`"````!.W`0`)````'+<!
M`#\````FMP$`!P```&:W`0`/````;K<!``X```!^MP$`$````(VW`0`)````
MGK<!``D```"HMP$`"````+*W`0`3````N[<!``0```#/MP$`!P```-2W`0`2
M````W+<!`"8```#OMP$`&0```!:X`0`8````,+@!``L```!)N`$`#@```%6X
M`0`9````9+@!``H```!^N`$`"@```(FX`0`3````E+@!`"<```"HN`$`"0``
M`-"X`0`/````VK@!`!<```#JN`$`%`````*Y`0`H````%[D!``\```!`N0$`
M%````%"Y`0`*````9;D!``P```!PN0$`%P```'VY`0`$````E;D!`"H```":
MN0$`$0```,6Y`0`"````U[D!`!````#:N0$`&````.NY`0`+````!+H!``,`
M```0N@$`"````!2Z`0`&````';H!``<````DN@$`#0```"RZ`0`+````.KH!
M`!0```!&N@$`%0```%NZ`0`.````<;H!`"\```"`N@$`(````+"Z`0`<````
MT;H!`%H```#NN@$`/P```$F[`0`V````B;L!``P```#`NP$`,0```,V[`0`)
M````_[L!``4````)O`$`$@````^\`0`_````(KP!`!(```!BO`$`"@```'6\
M`0`&````@+P!``0```"'O`$`$P```(R\`0`%````H+P!``8```"FO`$`!@``
M`*V\`0`$````M+P!``P```"YO`$`"@```,:\`0`%````T;P!`!@```#7O`$`
M&0```/"\`0`?````"KT!`!T````JO0$`$0```$B]`0`"````6KT!``0```!=
MO0$`"@```&*]`0`&````;;T!``4```!TO0$``P```'J]`0`,````?KT!`#L`
M``"+O0$`)P```,>]`0`A````[[T!`"0````1O@$`10```#:^`0`:````?+X!
M`!T```"7O@$`-0```+6^`0!6````Z[X!`"@```!"OP$`4P```&N_`0`Z````
MO[\!`$(```#ZOP$`&0```#W``0`7````5\`!`(L```!OP`$`&0```/O``0`J
M````%<$!`"L```!`P0$`<@```&S!`0`@````W\$!`#4`````P@$`10```#;"
M`0`F````?,(!`#````"CP@$`2P```-3"`0!.````(,,!`"<```!OPP$`*0``
M`)?#`0`A````P<,!`"@```#CPP$`*P````S$`0`=````.,0!`"D```!6Q`$`
M)@```(#$`0`M````I\0!`"4```#5Q`$`*````/O$`0`H````),4!`"(```!-
MQ0$`*0```'#%`0`B````FL4!`#T```"]Q0$`00```/O%`0`H````/<8!`"P`
M``!FQ@$`,````)/&`0`2````Q,8!`!,```#7Q@$`$````.O&`0!Y````_,8!
M``D```!VQP$`'````(#'`0`0````G<<!``\```"NQP$`)P```+['`0`.````
MYL<!`',```#UQP$`?````&G(`0!`````YL@!`"L````GR0$`%P```%/)`0`J
M````:\D!`#0```"6R0$`%@```,O)`0`/````XLD!`"@```#RR0$`'P```!O*
M`0`?````.\H!`!P```!;R@$`40```'C*`0`4````RLH!``\```#?R@$`"@``
M`._*`0`%````^LH!``8`````RP$`"`````?+`0`%````$,L!`!(````6RP$`
M#````"G+`0`0````-LL!`!,```!'RP$`'0```%O+`0`/````><L!``\```")
MRP$`!````)G+`0`*````GLL!``0```"IRP$``P```*[+`0`)````LLL!``<`
M``"\RP$`"P```,3+`0`(````T,L!``<```#9RP$`!0```.'+`0`)````Y\L!
M`!0```#QRP$`!@````;,`0`'````#<P!``@````5S`$`#P```![,`0`/````
M+LP!``@````^S`$`#````$?,`0`&````5,P!``D```!;S`$`"P```&7,`0`/
M````<<P!``8```"!S`$`!P```(C,`0`-````D,P!``8```">S`$`%````*7,
M`0`'````NLP!``,```#"S`$`"0```,;,`0`&````T,P!``P```#7S`$`"@``
M`.3,`0`,````[\P!``H```#\S`$`#P````?-`0`%````%\T!``@````=S0$`
M!````";-`0`*````*\T!``<````VS0$`!````#[-`0`9````0\T!``(```!=
MS0$`"0```&#-`0`&````:LT!``,```!QS0$`!@```'7-`0`,````?,T!`"<`
M``")S0$`!````+'-`0`$````MLT!``\```"[S0$`$P```,O-`0`'````W\T!
M``(```#GS0$`!P```.K-`0`&````\LT!``8```#YS0$`$`````#.`0`2````
M$<X!``X````DS@$`#P```#/.`0`&````0\X!``D```!*S@$`(@```%3.`0`'
M````=\X!``<```!_S@$`"P```(?.`0`%````D\X!``(```"9S@$`"P```)S.
M`0`.````J,X!``X```"WS@$`50$``,;.`0`+````'-`!``H````HT`$`"0``
M`#/0`0`2````/=`!``X```!0T`$`"P```%_0`0`(````:]`!``<```!TT`$`
M`0```'S0`0`*````?M`!``$```")T`$`&0```(O0`0`+````I=`!`$8```"Q
MT`$`,P```/C0`0!#````+-$!`#````!PT0$`&P```*'1`0`1````O=$!``P`
M``#/T0$`#0```-S1`0`%````ZM$!`"D```#PT0$`#P```!K2`0`,````*M(!
M`!(````WT@$`-````$K2`0`(````?](!`!T```"(T@$`+````*;2`0`,````
MT](!``\```#@T@$`"P```/#2`0`>````_-(!`!P````;TP$`(0```#C3`0`5
M````6M,!`!$```!PTP$`"@```(+3`0`,````C=,!`"0```":TP$`&@```+_3
M`0`3````VM,!`!4```#NTP$`*`````34`0`L````+=0!`!$```!:U`$`#@``
M`&S4`0`1````>]0!`!````"-U`$`!@```)[4`0`;````I=0!`#8```#!U`$`
M-0```/C4`0!;````+M4!`%4```"*U0$`(0```.#5`0`:`````M8!``X````=
MU@$`%0```"S6`0`1````0M8!`$0```!4U@$`-````)G6`0!!````SM8!`#$`
M```0UP$`#````$+7`0`-````3]<!`!,```!=UP$`$P```''7`0`+````A=<!
M``P```"1UP$`#````)[7`0`L````J]<!`!(```#8UP$`/P```.O7`0`T````
M*]@!`#T```!@V`$`20```)[8`0!E````Z-@!`&8```!.V0$`:````+79`0!I
M````'MH!`$````"(V@$`"@```,G:`0`%````U-H!``(```#:V@$`!@```-W:
M`0`2````Y-H!``<```#WV@$`$0```/_:`0`3````$=L!`!`````EVP$`!P``
M`#;;`0`K````/ML!`"@```!JVP$`"P```)/;`0`3````G]L!`!H```"SVP$`
M"````,[;`0`(````U]L!``<```#@VP$`#P```.C;`0`0````^-L!`!`````)
MW`$`$P```!K<`0`5````+MP!`!H```!$W`$`$````%_<`0`6````<-P!``P`
M``"'W`$`#P```)3<`0`M````I-P!`!T```#2W`$`&@```/#<`0`?````"]T!
M`!$````KW0$`&````#W=`0`<````5MT!`"0```!SW0$`'@```)C=`0`<````
MM]T!`"0```#4W0$`'@```/G=`0`P````&-X!``<```!)W@$`#@```%'>`0`/
M````8-X!`#D```!PW@$`"````*K>`0`(````L]X!``P```"\W@$`"````,G>
M`0`'````TMX!``@```#:W@$`"````./>`0`+````[-X!``4```#XW@$`&@``
M`/[>`0`,````&=\!``P````FWP$`%````#/?`0!.````2-\!`$````"7WP$`
M0P```-C?`0!"````'.`!`"P```!?X`$`%````(S@`0`A````H>`!``X```##
MX`$`'P```-+@`0`=````\N`!`"(````0X0$`'@```#/A`0`5````4N$!`!0`
M``!HX0$`#````'WA`0`&````BN$!`",```"1X0$`#@```+7A`0`^````Q.$!
M`!L````#X@$`(P```!_B`0`&````0^(!``8```!*X@$`!P```%'B`0`9````
M6>(!``D```!SX@$`"````'WB`0`0````AN(!``H```"7X@$`$@```*+B`0`'
M````M>(!`!4```"]X@$`)P```-/B`0`Y````^^(!`!<````UXP$`"P```$WC
M`0`(````6>,!`!<```!BXP$`$P```'KC`0`9````CN,!`"L```"HXP$`/@``
M`-3C`0`>````$^0!`#,````RY`$`*````&;D`0`K````C^0!`"8```"[Y`$`
M)P```.+D`0`H````"N4!`#P````SY0$`.0```'#E`0`)````JN4!``@```"T
MY0$`%0```+WE`0`%````T^4!``4```#9Y0$`!0```-_E`0`/````Y>4!`!T`
M``#UY0$`"P```!/F`0`@````'^8!``<```!`Y@$`+@```$CF`0`5````=^8!
M``H```"-Y@$`$0```)CF`0`Q````JN8!``L```#<Y@$`.````.CF`0`[````
M(><!``8```!=YP$`*0```&3G`0`1````CN<!`"@```"@YP$`*@```,GG`0`K
M````].<!`"L````@Z`$`#0```$SH`0`'````6N@!``D```!BZ`$`"0```&SH
M`0`*````=N@!``@```"!Z`$`+P```(KH`0`L````NN@!`"X```#GZ`$`4```
M`!;I`0`M````9^D!`"P```"5Z0$`+0```,+I`0`M````\.D!`#\````>Z@$`
M*0```%[J`0`K````B.H!`"T```"TZ@$`,P```.+J`0`4````%NL!`!@````K
MZP$`*@```$3K`0`G````;^L!`%P```"7ZP$`&````/3K`0`.````#>P!`!$`
M```<[`$`#0```"[L`0`1````/.P!``P```!.[`$`"P```%OL`0`%````9^P!
M``L```!M[`$`(0```'GL`0`F````F^P!``<```#"[`$`"0```,KL`0`6````
MU.P!``H```#K[`$`"@```/;L`0`.`````>T!``,````0[0$`"P```!3M`0`'
M````(.T!``<````H[0$`%@```##M`0`'````1^T!``@```!/[0$`!P```%CM
M`0`+````8.T!``@```!L[0$`$````'7M`0`+````ANT!`$<```"2[0$`#@``
M`-KM`0`*````Z>T!``@```#T[0$`!P```/WM`0`'````!>X!`!`````-[@$`
M!P```![N`0`6````)NX!``,````][@$`'@```$'N`0`(````8.X!``@```!I
M[@$`"@```'+N`0`)````?>X!`"````"'[@$`%0```*CN`0`)````ONX!`!$`
M``#([@$`#@```-KN`0`)````Z>X!``,```#S[@$``P```/?N`0`7````^^X!
M`!0````3[P$`"````"CO`0`+````,>\!``0````][P$`"````$+O`0`)````
M2^\!`#,```!5[P$`-````(GO`0!'````ON\!`$\````&\`$`*@```%;P`0`&
M````@?`!``D```"(\`$`$0```)+P`0`<````I/`!`#$```#!\`$`'````//P
M`0`A````$/$!`"@````R\0$`'P```%OQ`0`I````>_$!`%@```"E\0$`+```
M`/[Q`0`*````*_(!``L````V\@$`"P```$+R`0`-````3O(!``(```!<\@$`
M$0```%_R`0`0````<?(!``X```""\@$`$````)'R`0`2````HO(!`!,```"U
M\@$`$P```,GR`0`&````W?(!`!P```#D\@$`'@````'S`0`3````(/,!`!(`
M```T\P$`!0```$?S`0`'````3?,!``@```!5\P$`#@```%[S`0`1````;?,!
M`&H```!_\P$`)@```.KS`0!B````$?0!`&8```!T]`$`"````-OT`0`'````
MY/0!`!8```#L]`$`'`````/U`0`5````(/4!`#4````V]0$`*@```&SU`0`$
M````E_4!``8```"<]0$`'````*/U`0`;````P/4!`!0```#<]0$`&@```/'U
M`0`6````#/8!`!L````C]@$`%````#_V`0`A````5/8!`"0```!V]@$`/@``
M`)OV`0!"````VO8!``L````=]P$`#P```"GW`0`&````.?<!`!@```!`]P$`
M'0```%GW`0`;````=_<!`!L```"3]P$`4P```*_W`0`L`````_@!`#0````P
M^`$`/````&7X`0`T````HO@!`!8```#7^`$`4P```.[X`0`%````0OD!`$4`
M``!(^0$`$P```([Y`0`U````HOD!`#$```#8^0$`"`````KZ`0`.````$_H!
M`!$````B^@$`$P```#3Z`0`)````2/H!``D```!2^@$`%@```%SZ`0`*````
M<_H!`!````!^^@$`&@```(_Z`0`3````JOH!`!L```"^^@$`"0```-KZ`0`&
M````Y/H!`!8```#K^@$`$@````+[`0`4````%?L!``L````J^P$`%0```#;[
M`0`(````3/L!``<```!5^P$`$````%W[`0`*````;OL!``X```!Y^P$`!P``
M`(C[`0`)````D/L!``<```":^P$`%P```*+[`0`?````NOL!`$(```#:^P$`
M#````!W\`0`'````*OP!`!0````R_`$`#P```$?\`0`9````5_P!`"@```!Q
M_`$`%0```)K\`0`&````L/P!`!P```"W_`$`%0```-3\`0`6````ZOP!`#$`
M```!_0$`/@```#/]`0`G````<OT!`"(```":_0$`,@```+W]`0`%````\/T!
M`!H```#V_0$`'0```!'^`0`W````+_X!`"P```!G_@$`"@```)3^`0`.````
MG_X!``D```"N_@$`%0```+C^`0`4````SOX!``<```#C_@$`$````.O^`0`*
M````_/X!`!8````'_P$`'@```![_`0`?````/?\!`"$```!=_P$`(@```'__
M`0`=````HO\!`"@```#`_P$`'P```.G_`0`I````"0`"`",````S``(`'P``
M`%<``@`B````=P`"`!X```":``(`*@```+D``@`S````Y``"`"L````8`0(`
M)P```$0!`@`X````;`$"`"(```"E`0(`(P```,@!`@`I````[`$"`#`````6
M`@(`+P```$<"`@`6````=P("`"X```".`@(`%0```+T"`@"W````TP("`!(`
M``"+`P(`(@```)X#`@`G````P0,"`"<```#I`P(`)0```!$$`@`<````-P0"
M`"````!4!`(`+P```'4$`@`@````I00"`"````#&!`(`+````.<$`@!'````
M%`4"``\```!<!0(`"````&P%`@`&````=04"``<```!\!0(`$````(0%`@`.
M````E04"`!D```"D!0(`#P```+X%`@`A````S@4"`!0```#P!0(`)`````4&
M`@`:````*@8"`'4```!%!@(`%````+L&`@`0````T`8"`!L```#A!@(`"```
M`/T&`@`$````!@<"`!$````+!P(`$0```!T'`@`6````+P<"`!8```!&!P(`
M%````%T'`@`2````<@<"`#````"%!P(`'````+8'`@`S````TP<"``@````'
M"`(`%````!`(`@`&````)0@"`!$````L"`(`%P```#X(`@`?````5@@"`!(`
M``!V"`(``@```(D(`@`'````C`@"``4```"4"`(`%P```)H(`@`$````L@@"
M``4```"W"`(`$@```+T(`@`%````T`@"`!(```#6"`(`!P```.D(`@`5````
M\0@"``@````'"0(`%0```!`)`@`2````)@D"`!0````Y"0(`#P```$X)`@`2
M````7@D"``L```!Q"0(`#0```'T)`@`(````BPD"`!D```"4"0(`&P```*X)
M`@`5````R@D"``X```#@"0(`#@```.\)`@`:````_@D"`!D````9"@(`#0``
M`#,*`@`1````00H"`"H```!3"@(`+P```'X*`@`=````K@H"`#\```#,"@(`
M.0````P+`@`/````1@L"`!H```!6"P(`%````'$+`@`3````A@L"``@```":
M"P(`$````*,+`@`6````M`L"`!T```#+"P(`$0```.D+`@`&````^PL"`!(`
M```"#`(`+````!4,`@`/````0@P"`!,```!2#`(`"0```&8,`@`(````<`P"
M`"X```!Y#`(`+0```*@,`@`(````U@P"``D```#?#`(`'0```.D,`@`+````
M!PT"`!$````3#0(`&@```"4-`@`:````0`T"``D```!;#0(`!@```&4-`@`:
M````;`T"`!4```"'#0(`)````)T-`@`5````P@T"`!,```#8#0(`%````.P-
M`@`S`````0X"``P````U#@(`'````$(.`@`(````7PX"``H```!H#@(`%P``
M`',.`@`(````BPX"`"H```"4#@(`(P```+\.`@`@````XPX"`"(````$#P(`
M"````"</`@`4````,`\"``<```!%#P(`"@```$T/`@`-````6`\"`!H```!F
M#P(`,````($/`@`7````L@\"`"<```#*#P(`-````/(/`@`7````)Q`"``L`
M```_$`(`%````$L0`@`5````8!`"`!D```!V$`(`!P```)`0`@`1````F!`"
M`!$```"J$`(``P```+P0`@`H````P!`"``D```#I$`(`"0```/,0`@`8````
M_1`"`!<````6$0(`$0```"X1`@`/````0!$"`!````!0$0(`$````&$1`@`5
M````<A$"`!L```"($0(`*0```*01`@`8````SA$"`!(```#G$0(`%0```/H1
M`@`8````$!("`!X````I$@(`+````$@2`@`8````=1("``<```".$@(`!P``
M`)82`@`*````GA("``P```"I$@(``@```+82`@`*````N1("`!$```#$$@(`
M'P```-82`@`A````]A("``H````8$P(`%P```",3`@`5````.Q,"`!H```!1
M$P(`%@```&P3`@`.````@Q,"`!,```"2$P(`&P```*83`@`6````PA,"`!D`
M``#9$P(`.P```/,3`@`G````+Q0"`"8```!7%`(`%````'X4`@`'````DQ0"
M`!@```";%`(`#@```+04`@`5````PQ0"``X```#9%`(`$P```.@4`@`7````
M_!0"`'(````4%0(`&0```(<5`@`M````H14"`#````#/%0(`*``````6`@`O
M````*18"`!(```!9%@(`"````&P6`@`&````=18"`!X```!\%@(`#@```)L6
M`@`&````JA8"``@```"Q%@(`!P```+H6`@`&````PA8"`!L```#)%@(`#@``
M`.46`@`-````]!8"`!`````"%P(`#0```!,7`@`;````(1<"``X````]%P(`
M"@```$P7`@`+````5Q<"``<```!C%P(`"@```&L7`@`0````=A<"`!H```"'
M%P(`$P```*(7`@`3````MA<"`#0```#*%P(`,````/\7`@`-````,!@"``\`
M```^&`(`/````$X8`@`.````BQ@"``H```":&`(`#0```*48`@`<````LQ@"
M`!T```#0&`(`*````.X8`@`G````%QD"`!T````_&0(`'````%T9`@`B````
M>AD"`!D```"=&0(`!P```+<9`@`:````OQD"``P```#:&0(`!@```.<9`@`'
M````[AD"``H```#V&0(`#`````$:`@`.````#AH"`!\````=&@(`(0```#T:
M`@`0````7QH"`!4```!P&@(`$P```(8:`@`(````FAH"``8```"C&@(`!@``
M`*H:`@`9````L1H"`!P```#+&@(`#P```.@:`@`1````^!H"`!(````*&P(`
M#P```!T;`@`B````+1L"`!$```!0&P(`$0```&(;`@`=````=!L"`"$```"2
M&P(`!P```+0;`@`1````O!L"`!P```#.&P(`!P```.L;`@`'````\QL"``P`
M``#[&P(`'P````@<`@`/````*!P"`!(````X'`(`%P```$L<`@`+````8QP"
M``H```!O'`(`"@```'H<`@`%````A1P"`!D```"+'`(`$0```*4<`@`/````
MMQP"`!\```#''`(`$P```.<<`@`-````^QP"``<````)'0(`*0```!$=`@`2
M````.QT"`(<```!.'0(`&@```-8=`@`D````\1T"``8````6'@(`!0```!T>
M`@`,````(QX"``8````P'@(`"````#<>`@`*````0!X"``D```!+'@(`"@``
M`%4>`@`2````8!X"`!D```!S'@(`#````(T>`@`%````FAX"``D```"@'@(`
M"@```*H>`@`6````M1X"`!0```#,'@(`%P```.$>`@`>````^1X"`"D````8
M'P(`$@```$(?`@`6````51\"`"````!L'P(`!````(T?`@`#````DA\"``8`
M``"6'P(`!````)T?`@`0````HA\"``@```"S'P(`#0```+P?`@`$````RA\"
M``4```#/'P(`&0```-4?`@`'````[Q\"`#4```#W'P(`"0```"T@`@`'````
M-R`"`!<````_(`(`%P```%<@`@`2````;R`"``<```""(`(`"0```(H@`@`E
M````E"`"``0```"Z(`(`"P```+\@`@`&````RR`"``T```#2(`(`!P```.`@
M`@`.````Z"`"``\```#W(`(`"P````<A`@`(````$R$"`!8````<(0(`"P``
M`#,A`@`'````/R$"`!8```!'(0(`(0```%XA`@`&````@"$"``D```"'(0(`
M!0```)$A`@`)````ER$"``<```"A(0(`#0```*DA`@`,````MR$"``<```#$
M(0(`#@```,PA`@`&````VR$"``,```#B(0(`!````.8A`@`3````ZR$"`#,`
M``#_(0(`-P```#,B`@`V````:R("`"````"B(@(`!@```,,B`@`/````RB("
M``4```#:(@(`"````.`B`@`)````Z2("`!X```#S(@(`%@```!(C`@`'````
M*2,"``<````Q(P(`(````#DC`@`-````6B,"``D```!H(P(`&P```'(C`@`C
M````CB,"``@```"R(P(`(@```+LC`@`2````WB,"`!0```#Q(P(`!@````8D
M`@`&````#20"``P````4)`(`"0```"$D`@`D````*R0"``@```!0)`(`#```
M`%DD`@`.````9B0"``@```!U)`(`"0```'XD`@`(````B"0"`#,```"1)`(`
M+P```,4D`@`R````]20"`"8````H)0(`1@```$\E`@`Z````EB4"`"H```#1
M)0(`,@```/PE`@`R````+R8"`#,```!B)@(`)0```)8F`@`2````O"8"`!,`
M``#/)@(`#@```.,F`@`@````\B8"`"H````3)P(`'P```#XG`@`?````7B<"
M`!T```!^)P(`)P```)PG`@`)````Q"<"``L```#.)P(`"@```-HG`@`(````
MY2<"``0```#N)P(`*````/,G`@`G````'"@"`"@```!$*`(`,````&TH`@`,
M````GB@"`"````"K*`(`&P```,PH`@`,````Z"@"`!D```#U*`(`!0````\I
M`@`*````%2D"`!D````@*0(`(P```#HI`@`.````7BD"`!<```!M*0(`"0``
M`(4I`@`/````CRD"`!4```"?*0(`$P```+4I`@`H````R2D"`&D```#R*0(`
M"0```%PJ`@`/````9BH"`!4```!V*@(`$````(PJ`@`1````G2H"`!D```"O
M*@(`&@```,DJ`@`5````Y"H"``<```#Z*@(`!@````(K`@`,````"2L"`!$`
M```6*P(`$````"@K`@`B````.2L"`"$```!<*P(`(@```'XK`@`4````H2L"
M`!@```"V*P(`&P```,\K`@`3````ZRL"`!$```#_*P(`(P```!$L`@`5````
M-2P"``<```!++`(`#P```%,L`@`7````8RP"`!(```![+`(`#@```(XL`@`)
M````G2P"`!@```"G+`(`!0```,`L`@`Q````QBP"`"(```#X+`(`&@```!LM
M`@`Q````-BT"`*,```!H+0(`%0````PN`@`&````(BX"`!<````I+@(`"@``
M`$$N`@`+````3"X"``L```!8+@(`(0```&0N`@`H````ABX"`"<```"O+@(`
M"P```-<N`@`;````XRX"`!<```#_+@(`$P```!<O`@`G````*R\"`"8```!3
M+P(`'````'HO`@`/````ER\"``\```"G+P(`&0```+<O`@`O````T2\"`"X`
M```!,`(`+````#`P`@`K````73`"`",```"),`(`(@```*TP`@`;````T#`"
M`$$```#L,`(`$@```"XQ`@`6````03$"`!D```!8,0(`&````'(Q`@`/````
MBS$"`!<```";,0(`&P```+,Q`@`4````SS$"`!@```#D,0(`+P```/TQ`@`=
M````+3("`!D```!+,@(`,0```&4R`@`2````ES("``@```"J,@(`#P```+,R
M`@`R````PS("`!H```#V,@(`(````!$S`@`D````,C,"`!0```!7,P(`#P``
M`&PS`@`;````?#,"`!0```"8,P(`&@```*TS`@`2````R#,"`!4```#;,P(`
M'0```/$S`@`C````#S0"`!X````S-`(`*P```%(T`@`J````?C0"`!<```"I
M-`(`%````,$T`@`=````UC0"`!P```#T-`(`"P```!$U`@`(````'34"`!H`
M```F-0(`!@```$$U`@`&````2#4"``D```!/-0(`$P```%DU`@`(````;34"
M``D```!V-0(`"````(`U`@`'````B34"``<```"1-0(`!@```)DU`@`(````
MH#4"`!<```"I-0(`!P```,$U`@`)````R34"``4```#3-0(`"````-DU`@`&
M````XC4"``\```#I-0(`#@```/DU`@`0````"#8"`!$````9-@(``@```"LV
M`@`+````+C8"`!0````Z-@(`!@```$\V`@`L````5C8"`!,```"#-@(`#0``
M`)<V`@`/````I38"``L```"U-@(`"P```,$V`@`2````S38"`"<```#@-@(`
M,P````@W`@`&````/#<"``D```!#-P(`)P```$TW`@`2````=3<"`!4```"(
M-P(`"````)XW`@`)````IS<"``L```"Q-P(`!0```+TW`@`E````PS<"``H`
M``#I-P(`(0```/0W`@`3````%C@"`!0````J.`(`"P```#\X`@`<````2S@"
M`"D```!H.`(`&````)(X`@`'````JS@"``4```"S.`(`"@```+DX`@`P````
MQ#@"``<```#U.`(`!P```/TX`@`1````!3D"`!,````7.0(`!P```"LY`@`;
M````,SD"``@```!/.0(`%@```%@Y`@`.````;SD"``X```!^.0(`$````(TY
M`@`5````GCD"`!<```"T.0(`#P```,PY`@`=````W#D"`!$```#Z.0(`$@``
M``PZ`@`)````'SH"``<````I.@(`"@```#$Z`@`Y````/#H"`"4```!V.@(`
M"````)PZ`@`4````I3H"`"\```"Z.@(`&P```.HZ`@`5````!CL"`!8````<
M.P(`80```#,[`@`6````E3L"`!4```"L.P(`$````,([`@`8````TSL"`!4`
M``#L.P(`'@````(\`@`<````(3P"`!$````^/`(`'0```%`\`@`*````;CP"
M``<```!Y/`(`"0```($\`@`5````BSP"`!$```"A/`(`$````+,\`@`%````
MQ#P"``L```#*/`(`$P```-8\`@`*````ZCP"``L```#U/`(`$P````$]`@!4
M````%3T"`!4```!J/0(`#0```(`]`@`%````CCT"``@```"4/0(`"0```)T]
M`@`:````IST"`!H```#"/0(`&@```-T]`@`1````^#T"``T````*/@(``@``
M`!@^`@`$````&SX"`"@````@/@(``P```$D^`@`%````33X"``H```!3/@(`
M$0```%X^`@`,````<#X"``8```!]/@(`!0```(0^`@`.````BCX"`!H```"9
M/@(`(@```+0^`@`)````USX"`"\```#A/@(`$P```!$_`@`'````)3\"``D`
M```M/P(`"````#<_`@`%````0#\"``4```!&/P(`5P```$P_`@`/````I#\"
M`!(```"T/P(`!0```,<_`@`'````S3\"`"4```#5/P(`)P```/L_`@`.````
M(T`"`#(````R0`(`*P```&5``@`3````D4`"`",```"E0`(`,0```,E``@`-
M````^T`"``D````)00(`%@```!-!`@`7````*D$"``\```!"00(`"P```%)!
M`@`*````7D$"`!0```!I00(`*P```'Y!`@`:````JD$"`!D```#%00(`(0``
M`-]!`@`0`````4("`"\````20@(`+````$)"`@`&````;T("``8```!V0@(`
M"````'U"`@`7````AD("`!<```">0@(`%@```+9"`@`:````S4("`!@```#H
M0@(`(`````%#`@`&````(D,"`!8````I0P(`#@```$!#`@`.````3T,"``<`
M``!>0P(`#@```&9#`@`+````=4,"`!$```"!0P(`#@```)-#`@`,````HD,"
M``P```"O0P(`3````+Q#`@`/````"40"`!(````91`(`#````"Q$`@`0````
M.40"``X```!*1`(`$````%E$`@`=````:D0"`#4```"(1`(`'````+Y$`@`-
M````VT0"`",```#I1`(`"0````U%`@`+````%T4"`!8````C10(`1````#I%
M`@`'````?T4"``4```"'10(`!P```(U%`@`B````E44"``@```"X10(`"@``
M`,%%`@`9````S$4"`!H```#F10(`"0````%&`@`%````"T8"`",````11@(`
M20```#5&`@`0````?T8"`"<```"01@(`$````+A&`@`%````R48"``X```#/
M1@(`"0```-Y&`@`/````Z$8"``8```#X1@(`"@```/]&`@`'````"D<"`!,`
M```21P(`!P```"9'`@`)````+D<"`!$````X1P(`"@```$I'`@`*````54<"
M``T```!@1P(`!P```&Y'`@`1````=D<"`!0```"(1P(`$@```)U'`@`(````
ML$<"``\```"Y1P(`$````,E'`@`1````VD<"`!$```#L1P(`#@```/Y'`@`3
M````#4@"`!`````A2`(`"@```#)(`@`F````/4@"``L```!D2`(`$P```'!(
M`@`-````A$@"``T```"22`(`%P```*!(`@`)````N$@"``T```#"2`(`!P``
M`-!(`@`&````V$@"`#(```#?2`(`"````!))`@`&````&TD"`!0````B20(`
M!P```#=)`@`+````/TD"`!(```!+20(`%0```%Y)`@`A````=$D"`!\```"6
M20(`&````+9)`@`6````STD"`!P```#F20(`'@````-*`@`:````(DH"``<`
M```]2@(`!P```$5*`@`D````34H"``8```!R2@(`$@```'E*`@`0````C$H"
M`!````"=2@(`#0```*Y*`@`.````O$H"`",```#+2@(`$0```.]*`@`-````
M`4L"`!8````/2P(`"0```"9+`@`/````,$L"``@```!`2P(`$````$E+`@`1
M````6DL"`!,```!L2P(`"0```(!+`@`'````BDL"``@```"22P(`!@```)M+
M`@`%````HDL"``(```"H2P(`%0```*M+`@`-````P4L"`!4```#/2P(`"P``
M`.5+`@`C````\4L"`!H````53`(`$@```#!,`@`F````0TP"`!8```!J3`(`
M)0```(%,`@`B````ITP"`!<```#*3`(`(````.),`@`T`````TT"``X````X
M30(`(P```$=-`@`H````:TT"`"T```"430(`+0```,)-`@`R````\$T"`!0`
M```C3@(`$@```#A.`@`2````2TX"`!@```!>3@(`.@```'=.`@`:````LDX"
M`!$```#-3@(`&0```-].`@`4````^4X"`!,````.3P(`$@```")/`@`V````
M-4\"`!````!L3P(`$@```'U/`@`<````D$\"`"T```"M3P(`+0```-M/`@`Q
M````"5`"`"X````[4`(`+P```&I0`@`L````FE`"`&````#'4`(`(````"A1
M`@`D````25$"`",```!N40(`(P```))1`@`2````ME$"`!$```#)40(`*P``
M`-M1`@`3````!U("``X````;4@(`)````"I2`@`9````3U("`#$```!I4@(`
M&0```)M2`@`-````M5("`$````##4@(`0`````13`@`)````15,"``4```!/
M4P(`!````%53`@`5````6E,"``X```!P4P(`!P```']3`@`2````AU,"`!@`
M``":4P(`"0```+-3`@`(````O5,"``P```#&4P(`"@```--3`@`.````WE,"
M``D```#M4P(`#0```/=3`@`,````!50"`!L````25`(`$@```"Y4`@`-````
M050"`!$```!/5`(`"@```&%4`@`-````;%0"`!$```!Z5`(`!P```(Q4`@`A
M````E%0"``D```"V5`(`!P```,!4`@`1````R%0"`!(```#:5`(`3````.U4
M`@!'````.E4"`!````""50(`,P```)-5`@`"````QU4"``0```#*50(`"```
M`,]5`@`2````V%4"``L```#K50(`!@```/=5`@`0````_E4"``8````/5@(`
M#````!96`@`J````(U8"``8```!.5@(`+P```%56`@`Q````A58"`!@```"W
M5@(`*````-!6`@`M````^58"`%8````G5P(`%P```'Y7`@`4````EE<"`",`
M``"K5P(`$@```,]7`@`4````XE<"``H```#W5P(`#0````)8`@`3````$%@"
M``P````D6`(`"0```#%8`@`,````.U@"`!\```!(6`(`%P```&A8`@`$````
M@%@"`!````"%6`(`$P```)98`@`/````JE@"`!$```"Z6`(`)0```,Q8`@`#
M````\E@"`!@```#V6`(`#0````]9`@`9````'5D"``P````W60(`/@```$19
M`@`.````@UD"`!L```"260(`.P```*Y9`@`3````ZED"`!D```#^60(`.```
M`!A:`@`R````45H"`!H```"$6@(`#@```)]:`@`;````KEH"`"$```#*6@(`
M*@```.Q:`@`I````%UL"`!D```!!6P(`0P```%M;`@`U````GUL"``D```#5
M6P(`!P```-];`@`1````YUL"``D```#Y6P(`"@````-<`@`$````#EP"`"@`
M```37`(`#````#Q<`@`@````25P"`!L```!J7`(`#````(9<`@`(````DUP"
M``T```"<7`(`$0```*I<`@`F````O%P"`"H```#C7`(`"@````Y=`@`%````
M&5T"`!X````?70(`!@```#Y=`@`5````15T"``H```!;70(`"0```&9=`@`1
M````<%T"``P```""70(`&````(]=`@`@````J%T"``T```#)70(`'P```-==
M`@`8````]UT"``L````07@(`%P```!Q>`@`L````-%X"`!L```!A7@(`#```
M`'U>`@`-````BEX"`!L```"87@(`!@```+1>`@`K````NUX"``8```#G7@(`
M'0```.Y>`@`&````#%\"``D````37P(`'P```!U?`@`Y````/5\"``8```!W
M7P(`%@```'Y?`@`G````E5\"``H```"]7P(`%````,A?`@`N````W5\"`"D`
M```,8`(`*0```#9@`@`L````8&`"``0```"-8`(`!P```))@`@`)````FF`"
M``D```"D8`(`"@```*Y@`@`)````N6`"``D```##8`(`.0```,U@`@`7````
M!V$"``D````?80(`&P```"EA`@`U````16$"`#X```![80(`&0```+IA`@`G
M````U&$"`",```#\80(`'````"!B`@`\````/6("`!@```!Z8@(`(P```)-B
M`@`5````MV("`$\```#-8@(`4@```!UC`@`$`0``<&,"`!0```!U9`(`&P``
M`(ID`@`N````IF0"`"````#59`(`(````/9D`@!0````%V4"`#H```!H90(`
M)````*-E`@`I````R&4"`"T```#R90(`+````"!F`@`F````368"``<```!T
M9@(`"0```'QF`@`*````AF8"``L```"19@(`%0```)UF`@`1````LV8"`"D`
M``#%9@(`%@```.]F`@`D````!F<"`"`````K9P(`(````$QG`@`N````;6<"
M`#,```"<9P(`!@```-!G`@`5````UV<"``@```#M9P(`"````/9G`@`D````
M_V<"`!(````D:`(`$P```#=H`@`4````2V@"``H```!@:`(`%@```&MH`@`&
M````@F@"`!````"):`(`"````)IH`@`3````HV@"``D```"W:`(`1@```,%H
M`@!(````"&D"`!````!1:0(`"P```&)I`@`/````;FD"`!@```!^:0(`,P``
M`)=I`@`J````RVD"``P```#V:0(`$P````-J`@`2````%VH"`!4````J:@(`
M'@```$!J`@`[````7VH"`"8```";:@(`!P```,)J`@`'````RFH"`"L```#2
M:@(`)````/YJ`@`;````(VL"`!X````_:P(`%````%YK`@`&````<VL"``L`
M``!Z:P(`#0```(9K`@`&````E&L"`!$```";:P(`"````*UK`@`B````MFL"
M``@```#9:P(`$P```.)K`@`P````]FL"`$,````G;`(`!0```&ML`@`)````
M<6P"``D```![;`(`"0```(5L`@`)````CVP"`!````"9;`(`$@```*IL`@`5
M````O6P"`!L```#3;`(`"@```.]L`@`D````^FP"`!L````?;0(`&@```#MM
M`@`%````5FT"`!````!<;0(`$0```&UM`@`(````?VT"`"````"(;0(`&P``
M`*EM`@`6````Q6T"`!````#<;0(`+````.UM`@`(````&FX"``\````C;@(`
M'````#-N`@`3````4&X"`!8```!D;@(`#0```'MN`@`\````B6X"`!(```#&
M;@(`"0```-EN`@`B````XVX"`!(````&;P(`%@```!EO`@`8````,&\"`#4`
M``!);P(`/@```']O`@`8````OF\"``P```#7;P(`"````.1O`@`4````[6\"
M`!`````"<`(`$0```!-P`@`7````)7`"`!@````]<`(`$````%9P`@`B````
M9W`"`#@```"*<`(`(0```,-P`@`(````Y7`"``H```#N<`(`"@```/EP`@`9
M````!'$"`!8````><0(`(P```#5Q`@`L````67$"`",```"&<0(`)````*IQ
M`@`;````SW$"`!,```#K<0(`"````/]Q`@`3````"'("`!4````<<@(`'@``
M`#)R`@`*````47("``D```!<<@(`$0```&9R`@`7````>'("`!,```"0<@(`
M00```*1R`@`(````YG("`!<```#O<@(`'`````=S`@`&````)',"``@````K
M<P(`$@```#1S`@`4````1W,"`!8```!<<P(`!````'-S`@`(````>',"``L`
M``"!<P(`#@```(US`@`/````G',"`!(```"L<P(`$@```+]S`@`(````TG,"
M``D```#;<P(`*````.5S`@`<````#G0"`!H````K=`(`!P```$9T`@`2````
M3G0"``8```!A=`(`!@```&AT`@`.````;W0"`!T```!^=`(`&0```)QT`@`/
M````MG0"`$$```#&=`(`$0````AU`@`>````&G4"`#X````Y=0(`-0```'AU
M`@`J````KG4"`!T```#9=0(`-````/=U`@`1````+'8"`!X````^=@(`&0``
M`%UV`@`X````=W8"`$8```"P=@(`)@```/=V`@`+````'G<"``<````J=P(`
M`P```#)W`@`&````-G<"``@````]=P(`!0```$9W`@`%````3'<"`!L```!2
M=P(`#P```&YW`@`/````?G<"`!<```".=P(`#0```*9W`@`=````M'<"`!T`
M``#2=P(`&@```/!W`@`%````"W@"``L````1>`(`%````!UX`@`)````,G@"
M``T````\>`(`"0```$IX`@`,````5'@"`$0```!A>`(`$P```*9X`@`4````
MNG@"`!0```#/>`(`#@```.1X`@`G````\W@"`%8````;>0(`,````')Y`@`S
M````HWD"`!P```#7>0(`&````/1Y`@`[````#7H"``<```!)>@(`!P```%%Z
M`@`3````67H"``<```!M>@(`$P```'5Z`@`(````B7H"``L```"2>@(`&0``
M`)YZ`@`2````N'H"`!````#+>@(`$P```-QZ`@`1````\'H"`!L````">P(`
M$P```!Y[`@`5````,GL"`#D```!(>P(`#@```()[`@`D````D7L"`#T```"V
M>P(`%````/1[`@`3````"7P"`!`````=?`(`8@```"Y\`@`;````D7P"`!H`
M``"M?`(`*0```,A\`@`?````\GP"`!L````2?0(`&@```"Y]`@`D````27T"
M`!H```!N?0(`&0```(E]`@`<````HWT"`!\```#`?0(`'````.!]`@`-````
M_7T"`!H````+?@(`"@```"9^`@`)````,7X"``L````[?@(`%P```$=^`@`8
M````7WX"``@```!X?@(`%@```(%^`@`/````F'X"``@```"H?@(`(````+%^
M`@`)````TGX"`!4```#<?@(`"````/)^`@!0````^WX"`$$```!,?P(`+@``
M`(Y_`@!!````O7\"`"@```#_?P(`3P```"B``@`;````>(`"`"L```"4@`(`
M"````,"``@`3````R8`"`!H```#=@`(`,````/B``@`*````*8$"`!$````T
M@0(`*0```$:!`@!$````<($"`#$```"U@0(`.P```.>!`@!,````(X("``8`
M``!P@@(`%@```'>"`@`6````CH("`!````"E@@(`'````+:"`@`@````TX("
M`"8```#T@@(`&````!N#`@!!````-(,"`$T```!V@P(`)0```,2#`@`E````
MZH,"`"$````0A`(`$@```#*$`@`W````180"`"<```!]A`(`(````*6$`@`8
M````QH0"`"8```#?A`(`%@````:%`@`<````'84"`!\````ZA0(`'@```%J%
M`@`<````>84"`",```"6A0(`)@```+J%`@`4````X84"``8```#VA0(`"P``
M`/V%`@`-````"88"``8````7A@(`"0```!Z&`@`J````*(8"``4```!3A@(`
M"P```%F&`@`,````988"``<```!RA@(`$0```'J&`@`*````C(8"``H```"7
MA@(`!0```**&`@`6````J(8"``D```"_A@(`"0```,F&`@`$````TX8"``X`
M``#8A@(`&````.>&`@`.`````(<"``<````/AP(`%0```!>'`@`:````+8<"
M`!P```!(AP(`%P```&6'`@`:````?8<"`!D```"8AP(`$P```+*'`@`7````
MQH<"`!X```#>AP(`$````/V'`@`,````#H@"`!H````;B`(`*````#:(`@`1
M````7X@"`!$```!QB`(`)@```(.(`@`&````JH@"`!$```"QB`(`!@```,.(
M`@`(````RH@"``8```#3B`(`)P```-J(`@`=`````HD"`!,````@B0(`$0``
M`#2)`@`1````1HD"`!D```!8B0(`,0```'*)`@`.````I(D"`!(```"SB0(`
M$````,:)`@`'````UXD"``D```#?B0(`"@```.F)`@`,````](D"``<````!
MB@(`#P````F*`@`7````&8H"``@````QB@(`$@```#J*`@`.````38H"``D`
M``!<B@(`#@```&:*`@`9````=8H"`!@```"/B@(`&0```*B*`@`-````PHH"
M``4```#0B@(`!````-:*`@`$````VXH"``P```#@B@(`!@```.V*`@`9````
M](H"``@````.BP(`"````!>+`@!4````((L"`#0```!UBP(`&0```*J+`@`'
M````Q(L"``H```#,BP(`!P```->+`@`*````WXL"``H```#JBP(`!P```/6+
M`@`*````_8L"`!4````(C`(`#````!Z,`@`*````*XP"``P````VC`(`"```
M`$.,`@`,````3(P"``D```!9C`(`!P```&.,`@`8````:XP"``L```"$C`(`
M!P```)",`@`>````F(P"`!````"WC`(`&P```,B,`@`*````Y(P"`"4```#O
MC`(`&````!6-`@`'````+HT"``@````VC0(`"@```#^-`@`'````2HT"`!,`
M``!2C0(`$P```&:-`@`(````>HT"`!P```"#C0(`#0```*"-`@`>````KHT"
M``D```#-C0(`!@```->-`@`(````WHT"`!````#GC0(`%0```/B-`@`+````
M#HX"``T````:C@(`%P```"B.`@`9````0(X"`!$```!:C@(`,````&R.`@`+
M````G8X"``\```"IC@(`#@```+F.`@`%````R(X"`!@```#.C@(`"0```.>.
M`@`<````\8X"`!$````.CP(`*````""/`@`S````28\"`!(```!]CP(`+```
M`)"/`@`F````O8\"`",```#DCP(`%P````B0`@`8````()`"`'L````YD`(`
M'````+60`@`4````TI`"`$T```#GD`(`/P```#61`@`T````=9$"`"P```"J
MD0(`.````->1`@`N````$)("`$4````_D@(`0P```(62`@`?````R9("`"0`
M``#ID@(`9`````Z3`@`B````<Y,"`"8```"6DP(`,P```+V3`@`J````\9,"
M`!,````<E`(`'0```#"4`@!V````3I0"`"T```#%E`(`/0```/.4`@`S````
M,94"`!@```!EE0(`&0```'Z5`@`C````F)4"`!@```"\E0(`)P```-65`@!]
M`0``_94"`!<```![EP(`1````).7`@`2````V)<"`#@```#KEP(`%@```"28
M`@`;````.Y@"`!8```!7F`(`&0```&Z8`@`^````B)@"`"(```#'F`(`$@``
M`.J8`@`4````_9@"`($````2F0(`/````)29`@`W````T9D"`%,````)F@(`
M20```%V:`@!$````IYH"`#\```#LF@(`*P```"R;`@`<````6)L"`!X```!U
MFP(`$P```)2;`@!X````J)L"`!@````AG`(`&0```#J<`@`9````5)P"`!P`
M``!NG`(`)````(N<`@`>````L)P"`!T```#/G`(`)0```.V<`@`.````$YT"
M`"@````BG0(`%P```$N=`@`Q````8YT"`!<```"5G0(`,0```*V=`@`C````
MWYT"`!0````#G@(`&P```!B>`@`A````-)X"`#,```!6G@(`%P```(J>`@`S
M````HIX"`!L```#6G@(`#P```/*>`@`P`````I\"`%L````SGP(`+@```(^?
M`@`S````OI\"`#0```#RGP(`+````">@`@!2````5*`"`#D```"GH`(`0P``
M`.&@`@!!````):$"`#X```!GH0(`*P```*:A`@`;````TJ$"`"0```#NH0(`
M/P```!.B`@`3````4Z("`"8```!GH@(`)````(ZB`@`C````LZ("`!H```#7
MH@(`,P```/*B`@!'````)J,"`$(```!NHP(`1P```+&C`@`G````^:,"`!L`
M```AI`(`/0```#VD`@`\````>Z0"`!T```"XI`(`'P```-:D`@`C````]J0"
M`$H````:I0(`,````&6E`@`U````EJ4"`!8```#,I0(`'P```..E`@`J````
M`Z8"`"H````NI@(`+0```%FF`@!G````AZ8"`&4```#OI@(`JP```%6G`@`6
M`````:@"`"T````8J`(`,0```$:H`@`P````>*@"`$D```"IJ`(`'@```/.H
M`@!.````$JD"`!8```!AJ0(`!P```'BI`@"Q````@*D"`"X````RJ@(`*0``
M`&&J`@!3````BZH"`$,```#?J@(`,````".K`@`K````5*L"`"<```"`JP(`
M*@```*BK`@`E````TZL"`"(```#YJP(`"P```!RL`@!%````**P"`"@```!N
MK`(`,P```)>L`@`K````RZP"`!H```#WK`(`'@```!*M`@`S````,:T"`"X`
M``!EK0(`$@```)2M`@`)````IZT"``@```"QK0(`!@```+JM`@`.````P:T"
M``X```#0K0(`$@```-^M`@`*````\JT"``@```#]K0(`#`````:N`@`#````
M$ZX"``D````7K@(`;````"&N`@!L````CJX"``@```#[K@(`$`````2O`@`%
M````%:\"``<````;KP(`!0```".O`@`%````*:\"``<````OKP(`&0```#>O
M`@`=````4:\"``@```!OKP(`#````'BO`@`-````A:\"`!4```"3KP(`#```
M`*FO`@`%````MJ\"``<```"\KP(`!P```,2O`@`5````S*\"``H```#BKP(`
M%P```.VO`@`&````!;`"`!L````,L`(`#P```"BP`@`#````.+`"`"8````\
ML`(`!````&.P`@`&````:+`"``<```!OL`(`(@```'>P`@!!````FK`"`"@`
M``#<L`(`*@````6Q`@`6````,+$"`"<```!'L0(`(````&^Q`@`?````D+$"
M`",```"PL0(`'@```-2Q`@`;````\[$"`"(````/L@(`'@```#*R`@`K````
M4;("`"D```!]L@(`*P```*>R`@`?````T[("`",```#SL@(`(0```!>S`@`<
M````.;,"`"8```!6LP(`)P```'VS`@`C````I;,"`!X```#)LP(`'````.BS
M`@`B````!;0"`"4````HM`(`'0```$ZT`@`E````;+0"`"8```"2M`(`.@``
M`+FT`@`A````]+0"`"4````6M0(`(P```#RU`@`D````8+4"`!X```"%M0(`
M)P```*2U`@`<````S+4"`"0```#IM0(`(`````ZV`@`K````+[8"`",```!;
MM@(`"@```'^V`@`2````BK8"`!,```"=M@(`"0```+&V`@`2````N[8"`!,`
M``#.M@(`&@```.*V`@`:````_;8"`!H````8MP(`"@```#.W`@`A````/K<"
M`!````!@MP(`&0```'&W`@`2````B[<"`!,```">MP(`(@```+*W`@`(````
MU;<"``D```#>MP(`#0```.BW`@`6````]K<"`!,````-N`(`)````"&X`@`G
M````1K@"`"\```!NN`(`(0```)ZX`@`5````P+@"``P```#6N`(`^@```..X
M`@`*````WKD"`!$```#IN0(`'````/NY`@`5````&+H"``H````NN@(`#0``
M`#FZ`@`=````1[H"`!L```!EN@(`%````(&Z`@`?````EKH"``@```"VN@(`
M,0```+^Z`@`<````\;H"`!H````.NP(`"0```"F[`@`5````,[L"`!L```!)
MNP(`(@```&6[`@`+````B+L"`$4```"4NP(`"@```-J[`@`O````Y;L"`!D`
M```5O`(`%````"^\`@`6````1+P"`"````!;O`(`$````'R\`@`1````C;P"
M`!(```"?O`(`&P```+*\`@`,````SKP"`!L```#;O`(`"0```/>\`@`;````
M`;T"``H````=O0(`'````"B]`@`(````1;T"`",```!.O0(`!P```'*]`@`)
M````>KT"``D```"$O0(`,0```(Z]`@`'````P+T"`!````#(O0(`%````-F]
M`@`1````[KT"``L`````O@(`#0````R^`@`)````&KX"`!<````DO@(`!@``
M`#R^`@`)````0[X"`!<```!-O@(`(@```&6^`@`5````B+X"`!0```">O@(`
M#````+.^`@`4````P+X"`!8```#5O@(`$@```.R^`@`0````_[X"`!X````0
MOP(`'P```"^_`@`0````3[\"`!0```!@OP(`%P```'6_`@`5````C;\"`"P`
M``"COP(`$P```-"_`@`?````Y+\"``D````$P`(`"P````[``@`9````&L`"
M``0````TP`(`*@```#G``@`/````9,`"``4```!TP`(`#````'K``@`2````
MA\`"``L```":P`(``P```*;``@`,````JL`"``L```"WP`(`!@```,/``@`2
M````RL`"``D```#=P`(`$P```.?``@`4````^\`"``X````0P0(`*P```!_!
M`@`7````2\$"`!8```!CP0(`5````'K!`@`S````S\$"`$(````#P@(`#```
M`$;"`@`D````4\("``T```!XP@(`!@```(;"`@`1````C<("`$8```"?P@(`
M#P```.;"`@`,````]L("``<````#PP(`!`````O#`@`4````$,,"``8````E
MPP(`!P```"S#`@`(````-,,"``8````]PP(`#0```$3#`@`/````4L,"``4`
M``!BPP(`'@```&C#`@`B````A\,"`!H```"JPP(`'0```,7#`@`/````X\,"
M``(```#SPP(`!````/;#`@`0````^\,"``8````,Q`(`!P```!/$`@`$````
M&\0"`!`````@Q`(`-````#'$`@`K````9L0"`"````"2Q`(`%0```+/$`@!'
M````R<0"`!$````1Q0(`&P```"/%`@`I````/\4"`$8```!IQ0(`)````+#%
M`@!$````U<4"`"P````:Q@(`,P```$?&`@`=````>\8"`!H```"9Q@(`:@``
M`+3&`@`0````'\<"`"<````PQP(`*P```%C'`@!E````A,<"`!L```#JQP(`
M6`````;(`@`N````7\@"`"(```".R`(`%@```+'(`@!*````R,@"`$T````3
MR0(`)````&')`@`K````ALD"`"(```"RR0(`,````-7)`@`D````!LH"`!<`
M```KR@(`,P```$/*`@`D````=\H"`",```"<R@(`(P```,#*`@`G````Y,H"
M`!,````,RP(`,````"#+`@`@````4<L"`!P```!RRP(`-@```(_+`@`V````
MQLL"`"0```#]RP(`)````"+,`@`P````1\P"`!<```!XS`(`$@```)#,`@`4
M````H\P"`$\```"XS`(`$P````C-`@`B````',T"`!4````_S0(`%````%7-
M`@`K````:LT"``\```"6S0(`;0```*;-`@!4````%,X"`#T```!IS@(`)P``
M`*?.`@`2````S\X"`"H```#BS@(`-`````W/`@`:````0L\"`!0```!=SP(`
M'@```'+/`@`B````D<\"`!L```"TSP(`&@```-#/`@!<````Z\\"`!8```!(
MT`(`#0```%_0`@`+````;=`"``8```!YT`(`!P```(#0`@`(````B-`"``H`
M``"1T`(`&P```)S0`@`/````N-`"`!8```#(T`(`&@```-_0`@`F````^M`"
M`!$````AT0(`"0```#/1`@`$````/=$"``D```!"T0(`!````$S1`@`#````
M4=$"``X```!5T0(`"0```&31`@`0````;M$"``H```!_T0(`!P```(K1`@`(
M````DM$"``@```";T0(`&P```*31`@`&````P-$"``P```#'T0(`"P```-31
M`@`,````X-$"`!$```#MT0(`"P```/_1`@`'````"]("``L````3T@(`!P``
M`!_2`@`-````)]("`!0````UT@(`"0```$K2`@`(````5-("``X```!=T@(`
M#@```&S2`@`7````>]("``8```"3T@(`!````)K2`@`)````G]("``L```"I
MT@(`#````+72`@`.````PM("``X```#1T@(`!@```.#2`@`5````Y]("``8`
M``#]T@(`"P````33`@`%````$-,"``T````6TP(`!@```"33`@`&````*],"
M`!$````RTP(``@```$33`@`*````1],"``@```!2TP(`!@```%O3`@`(````
M8M,"``\```!KTP(`)@```'O3`@`&````HM,"``0```"ITP(`#````*[3`@`0
M````N],"``X```#,TP(`!````-O3`@`)````X-,"``D```#JTP(`!````/33
M`@`0````^=,"`!(````*U`(`#@```!W4`@`/````+-0"``<````\U`(`#0``
M`$34`@`C````4M0"``H```!VU`(`!0```('4`@`6````A]0"``4```">U`(`
M`@```*34`@`+````I]0"`!4```"SU`(`%0```,G4`@`!````9@$``.4!````
M````2P$``,0$```X"0```````-0&````````UP````0"``#P!0````@``)$$
M````````D@0``/<!``#Y!P```````'X$``#4`P``&@8``/,$``#;`0``V`8`
M``````#?`0``E0D``#L"``!>!````0<``-P$````````I`D```P`````````
M````````````````30D``````````````````%@"```K!0``F0<```````#I
M`0``4P,```````````````````T!`````````````$<"``"L!P````````P%
M````!```DP8``!8&``!."```5``````````;!0``#@<``/\!```$`0``[P@`
M`!\#``!J"0``[0,`````````````/P,``#@#``!<`0``Q@,``(8)````````
MP`<```$%``#H````B`<`````````````JP4`````````````J`````````"8
M!@``*P0``+`)``#\`0``20(````````#!P``$`@``+0(``#R!P``:`$````!
M``#+!0``S0$``,@$````````7P<``*4&``!(!P``0P<``,<)``"$`P``````
M`.$%`````````````$H!``#P`P```````-\&``!="0``SP0``%,(``#!!P``
M+08``!L#``!9`P``90,```````![!0``'P4``$,#````````-P(```````!%
M`0````````````!X!P``H00``!@````W!@````````<(```Q"```````````
M``#("```C`,``&\#``!W`P``:P<```````#4"0``]@(``%@%``"P!```,0``
M`)0"``">"0``I0<``,(%```F!0``$`<```````"T!0```````-X'````````
M6@4```````#L"```6P<``-(#``!E"```M@,``)\'``"@!0``T00``-0(````
M````7`(```````#Z"```.0,``"`"````````/P8```````"+"```C@(``)P)
M``#K`@``"@<```````"<`@``I`8````````M!```/@$``-("``",````````
M`%$)``!)"`````````````#?"0`````````````+!```%P$```````!S"0``
M.@<``,4&``!<"```X08```````#*`P```````-,"````````T@$```D!``"-
M`@``%04````````B!```^P(``"\)``#=`````````$\)``!=`@``S0@```H&
M``"[!P``$@(```````#_`@``Z04``,<```!S````L0D`````````````-00`
M`/T!``#4`@``X@0``.$$``#)"0``H@@``/`"````````O04``&H!```\!P``
MK0```!D)````````&P$``"H"``!`````````````````````9`,``"<'```G
M`@``$@```%8#```7`P``-@$`````````````2@0```````#C`P``XP(``&P`
M``"4"0``X0(````````I`0``YP@````````+"````````,D(``#N!```TP,`
M``L)````````;@0``%L#``"""````````"D"``"N`0``^`,``)@#````````
M"0(``)\&```8!@``CP<```4$``!O!0``Y@(``',$``!W`0```````'4#``!J
M!0```````!\```#``0``G`<``/@!``"K````"P4``+<$````````,PD``-<"
M``"#"0```````"P%```C!P``)0<`````````````8`$``&$!``!:!P``"04`
M`%H&````````;@@```````!R"```?0$``(@#``#D`@``Y`<```(````M"0``
MO@(````)```."0``Y@8```("``````````````````"@`@``/0$````````1
M"````P4````````O`@````````````"=!@``T0<`````````````60D``$T&
M``#U`P```````/P(````````H@<``*0#```````````````````9`@``````
M`-H)``!#!@``>P<``&("``#/!0``(`,``"`!`````````````(T```!I````
M60@``%L```"R!```6`<``)8'``!B"0``5`D``'X!``!3!P``50(``!L)``"2
M"````````)0'``!.!```%`D``,D````3`P````````````#`````9`(``&8(
M````````"@,``($!````````9`8`````````````E`8``+P$```6`0```@<`
M``````"U!````````/8```#3!0``,P4``),#````````[`4```````!%!@``
M>0(``-\$``"Y````X0```*(%``"P!0``T`(``+8(````````F@<````````^
M"````````*,#````````&@(``#<$``#`"0````````L```#G`0```````+X#
M````````#@8``,L'```/`0``%`<``/D$``!5`````````.X'``!K`0``ZP4`
M```````W"0```````-P#```W!0``^````%P$``"H`@``9P```-4!``#B````
M\00``-D&``!W`@``;`<`````````````%@@``*$%``"P`0``8`@```````"N
M!@``X@8``.T$``#H!P``4P8``!P)``"W`0``D@4```````"C!P``H0@``/D!
M``#%"````````,X'````````.@4``-\'````````O@4````````1!P``.`0`
M`#D(``!J`@``Z`8`````````````````````````````T0$``(0"``!U"```
M`````(H"``"+`@``&P(``'<$``!Q!0``M0```,P!````````'`<``%L%``!_
M`P``/08``)('````````M08``$X)``"I`@``A`$``&T&``!5!@``J`,`````
M````````F`(```````#I!P``V@0`````````````OP4```````!\"```````
M`'X(``"*!0``8P````````````````````````"F!0```````!@'``#C!0``
M7`D``$@(```-"```$0(``)````#9"0``ZP````````"%`0````````````"M
M`@````````````"&`0```````-8(```V"```#P(```````#J!P``I@,``$T`
M````````\@`````````Q!P```````,X"``"]"```3P<``-X&``"]!@``````
M``$"``#%!P````````````!F!```0P$``-P)````````W0<``!H#````````
MG`,```D(````````3`<`````````````9@(``/T%````````1`D``%L)``"W
M"0````````````!C`P``_@,``(,'``#L`0``JPD``+<&``!L`P``50$`````
M``"Z"0``G@$```````!O"0``Q@4``/<$``!V!0``B@@``$L#``"G!@``+04`
M`)\#```/!P``/P(`````````````)P@``,H)``!A!@``?P$```````"7"```
M,0(```L'``!#!```5@8```````!/`P``4`$``"<&````````7`,``"P$````
M````'@$``!<)````````*P@``*(```!K"0``@`(``,H"``!8`P``104``(,!
M``#K`0``$`D``.D$```F"```?P4``&`%````````.0(``%4%```*`0``40<`
M``````!+!P``BP$````````E`0``K08``",)```>"0````````````"P`P``
M@0D```(&````````9P@```@&``!4!P```````'L$`````````````+D'``"9
M!0``FP$``"$)``!R"0``$@D```L"``"4"```K@D```````#9"```0P```"X(
M``#0!P```````#,#``#C"0``&@D``%<%````````20$``'P#``#J!0``;00`
M`+0$````````,@```#@&``!\!0``"`@``!4$``!@"0``L```````````````
MAP4``%$```"H!@```````,T"``#5"```V0<``-L$``!B`P``4@$``!8$```@
M"0``Y@```,$"````````P0```)D"``!3!0``I@D``!@)``"T`P``C0@``%T!
M``">"```[0$```````!`!@``9P8``-,)``#'`P``Q`@``!P```#(````Z`0`
M`!$$``"Q!P``S`,`````````````!`0``$D```!4`P``O00``.$#```I!@``
M:0(``/("``"F!P``P@(````````5!@``````````````````U08``%,```"7
M`0``$P4``$(%`````````````"<)````````*`4``*\)``!2!@``7PD``#0$
M```\"0``&0,``````````````@,``!T#````````E08`````````````%`8`
M````````````>`4``%,"``"6"0```````)8$``````````````````!=!P``
MI0(``&4"``!U"0````````````#5````+P$```````"%"0``[`8``'$)``!U
M````<P<```\#```O!@``?````%<#``!=!@``K@(``&`'``#<`0``O@0``+L(
M``"3!0``;0<```T"```D!```,P@``$((```&"````````-H(``#-"0``O0(`
M`)T)```Z"```I`````````#-!P``<`0```````#3`0``>@$``/L$``"0`0``
M6`8``'P"``";`@``\@4``%(```#?!0``[@4``(<(``#6`````````,(&````
M````>P$``/\#``"^"```/`4```````!N`````````````````````````"`%
M````````4@D``&<"````````=`(``!T`````````CP```)L%```?`0``"`<`
M`/L!``!U`0``0`$``*8"`````````````+8%``"$!P``"@0``/4````&!P``
MP@$```````"F````O0D``'X#``#:`````````(D#``"B`@``N@8```````!]
M!P``*0,`````````````=@<``)L$``"?!```W0(``&8%```7````T0@``'`&
M```K`0````````````"E"0``D0<``(\)``"5!```U`$``+<(``!I!P``^P@`
M`*\&``#2!P``)@(``(0$````````<`$```````"V!P``8`0``.H```"9````
M`````.H"`````````````(X&``!*````^`8```````!(!@``G04```4```#W
M"```%P0``"X!``"^`0```````,$$```U`@``+@(``'L"``"/`P``.@```(8`
M``#U"```#0<``-<$```_!```$`,```````!7````+0@``/,(````````(@<`
M``````!B!```N@$``,X#`````````````#$)``"G!P```````)0```!O````
MW`<```````!$!0``Y00```````!I"0```````)<)``"A`P```````$P)``"?
M`0``]`$``*@%````````\0,```<%``````````````T%``"%`P``\P8``"(`
M````````F@0```````#1!@``G0<``.0$``!/`@```P@```````#+````0@D`
M`%8"``"T`0``7P````````!0!@``/P```*X#``#%`P```````!\)````````
MB0<``($`````````W````#P!``".`P``<0<````````<`P```````/H!````
M````+0$``((#````````40$``/P#```O`````````.,'``#:`P``-04``,(`
M`````````````+$!````````\`<``!@%``!:`0``;`4``"$&``!N!0``A@@`
M``````#F"```Q`8``,D"``#'`@``NP(``/0&``!1!@``N@@``(`)``#Q!0``
M`````)8"``"-!```"````#8'``"C"0``LP8``/0#``!]"0```````*D```"$
M!0```````#('````````$0D```````"8!0``;`D``)T#``"G`P``?08``#0#
M```&`0``DPD````````^!```3@8``*H)``!I`P```````$$!``!/!@``*0<`
M`*,```!P"```V`0``/0`````````!0(``*X$````````VP@``!X'``#D`0``
M`````+4%``"#"```M`8``"0&```E!@``H08``.X#``#>`@``0@```#H&````
M````VP8``)$(```X`@```````$H'````````J@(``%X(```_!0``$P````P)
M````````B04``"$````C"```V`$``'H$``"7`````````+0)``"_`@``````
M`/8#```.`0``<@```+D!```V`P```````-X````""````````,4%``!J````
M$@4```````#*"````````-()``!]`P``8@``````````````[@```-@"``#O
M`0`````````````E!```;`@``'8)````````?P``````````````5`4``#X#
M``!5"0``````````````````+@``````````````500``$X`````````:P8`
M``````!-`0``"08``,('``!=!```:`8``"`'``"Z!```(0$``(T%``!@`P``
MN`8``#X````C!@```````-\"````````C`@```````"V!```KP<`````````
M`````````/8$```)!`````````````#5"0````````````"X!````````!<"
M``"I"```$P@``.(#````````BPD``*X```!J!@```````*X'``#@!@``_P4`
M`"4````4"```J0D``#````#$`0``)P0`````````````4P$``$<(``!``@``
M`````%8(````````1@4``#(&``!1!0``GP```,X&``#W!P```````,<(````
M````:00``$H&``!`!0``D`D``)D)``!Q!@``L@,``$X!``#!!0``````````
M``"P!@```````*0!``!P`P```````+@!``#M!P``F`<``-<&``"7!@``````
M`$P#``#``P``?`$``$0$``#G!0``F`$``#L!```*"```=04``"\%```E`P``
MI0@``,T$``!(`0``J00``%`#`````````````/8'``!Q`````````'`"````
M````2`D``/`(``"!!P``E0@````````9!0``7@,``"D%``"?`@``````````
M````!@``:08``$\!``"`"```!`4``-\#``",!0``U@$``+,"``!!"0``Q`<`
M`,4$````````=P4``,@!```<"`````````P(```A!````````.T&````````
MG@8``(X'``#8````S@```/(&`````````````"4%``!8`````````-<'``!W
M!P``!P```/<#```A"```8P(``!D'``!X"0``!0<`````````````I00``*$"
M``"#`````````($"````````]`4``,$)```6"0```````*<$```C`P``HP(`
M`)4'```3"0```````!X#``"\!@````````````"%!0```````.L(```9!@``
M`````$$%``"@````GPD``)T``````````````.8'``!7`0``1P0``(H'``!<
M!@``SP@``&0'``!H"0```````(`'``!<````U`0``#@!``#N"```S@D``,,'
M``!C"```RP(``/$(``!"!```(04```````#Q!P``7P4```````!.`P``````
M```````<!0```PD``"8```"8"```QP<````````#`@``_`8``+@)```9!```
MC0,```````#,!@``-0@````'````````2P0```8)````````=`@``-D#``",
M`0```````#L'```B!0```````.$(``#+"0```````"@#````````_`<``,P'
M````````V04``.D(````````I`(``/D(``"@!P```````(@"```\!@``````
M`%P'```W"```/PD``*0%`````````````&H$``!(!0``.0```(8$```5`0``
M)@$`````````````@@$``+4!``#V`0``!P(``!$&````````B@```&T"``#I
M!@``I`<``)H"```3!```.P,``-T&``#]"```>0<``-4$``"B!@``U````,,`
M``#_````D`0```````!!`@``.@D``)0$````````/P@```````#:!P``:@<`
M`.`"``!P"0``Q0(``,4!``#1!0```````"D(``"R!0``608``!D`````````
M;`0``(H)````````>````'D$``"X!0``O0$```````"S````9````,,$``!O
M`0``Z`@``(`#````````-@4``"P&`````````````+L```"K!P``/P$``%4#
M``#[!P``'P(``(($````````A0```"X#````````7`4```@$```I!```````
M``<!``"M!```CP@```````!%`@``40(```````!>`0``2@@``.()``!"`0``
M.@,``.('```&````2P4```````!^!0``K0,``)H(````````:`(``!,'``!\
M!@``````````````````(@D```````!F"0``70```$8&````````KP(```4!
M``#&````*@@``$('``#B!0``IP4``#T'```0`@``S````'\$``#>`P``@`0`
M`(<"``#@`0``!`D``(D"``#(!0``^`(``/8(`````````````*\#````````
M`````+H%````````L@(``-L#```"`0```````%H(````````9PD```````"B
M`P```````,$&````````5@D``#("```?!P``%0<``&<%````````\@0``*H'
M````````40@``#,$``!$!P``20<```X%``"M!0```````#L$``#7"```(`0`
M`&T%``!U!@```````-H!``"S`0```````$X"````````H0``````````````
M$`4``"0(``#)`0``S04``'H(``"8!````````+\#``!Y!@````````````!=
M"```S`D``.\'````````+@4``#<!`````````````+(````R"```IPD``(X!
M```F!@``7P$``/,#``!0````JP0```````"J"```,`$``'0'``"<!0``````
M`#8$``!?!````````,L$``!>!0``V`4``!@#``#J`0```````+0```!(`@``
MY`D``!H!``#.!````````/D&````````*````.P```"."```Z`,``/,```"9
M!```+`,``&,$``#D`P``+P<``,D$``!A````G@(````````Z`0``%@``````
M``#6!@``;P(```0&````````.@(```````"F"```]08``/D%``!R`P``````
M```````V!@``NP8``',!``!@!@`````````````Y`0``3`$``'\&````````
MU`4``$D$```[``````````````#1`P``A`````$&```!"```&P<``%0&``#G
M`@``````````````````+@0``(@%``#[````````````````````````````
M``"6`0```````'0!````````XP$``$0"```]!0``(@,``-,&````````$P(`
M`%$$````````W0,``-`&``!`"0``<0,``)$)``!!!P```````/0"```#`0``
M`````#D)````````$`````````")"0``$@<``#D%````````*@D`````````
M````X`,``,D'``!*`P``N0D```````!X!```G0@``+,(`````````````"0`
M``!T"0``2@D``)X%``#@"0``,`4``-@#`````````````(P'````````````
M`+(&``````````````````"\````80D``+8"``")"```9@<``/H%```Q!```
M!`<``*D%``"!"```<00``"@"```-!```YP<``$<%``!A!P``-`D``#T#``#>
M"0```````"0#````````&`(```H````,`P``%P@``%H"``":!@```````*`&
M``#T!P``@@<```````!O!```%P4``(,"``!E!@``IP(``#X"```4!0``F@$`
M`'X&```>"````@D``.D"```I"0``P0$```````!N"0``-`8``&L"````````
M`````/@%``!+!@````````````"Y!@```````"@$``#)!@``#`0``)()``"F
M!@``>@D``/,"``"<`````````.P#``"L`P``"P$``!4(``!.!0```````',%
M```Y!@``OP$```P!``#L`@``!PD``````````````````,4)``"R`0``^@``
M`%\"```X!P```````-$)``!6!````````*X(```X"```Q@<```````#_!@``
M`````(\%``"[`0``50<``.L#```'!@``S0```)("```````````````````Q
M!@``"`,``#(%``##`P``UPD``.H$``".!0``T`@``)P&```T!P```````,\`
M````````$04``+`(`````````````.<&``#$!0``6@0``#0`````````)@<`
M`"4"``#`!@``)0@``#$#``!N!@``B@$```````"I!@``1@(``!H(``#6!0``
M208``%\#``"'`0``>04````````4!```K`$```4%``!E!0``!`,``&L(``#+
M"```E@,``!4"````````7@(`````````````&@4``/(#````````<@(`````
M`````````````+$"``"%`@```````!T"``"F!```#P@``.,&````````*0``
M```````D`0``U0(``!L&````````````````````````.P4``"@&``!C"0``
M`````-<#````````"0```+$&``!O!P``&`0``'T`````````/0D````%````
M````+P,```````"X`````````(\$``"L!0``K````+D"````````````````
M``#`"```P0@``%("``#E"```&`$``!$!``!B!0``Y````",$``"<`0``304`
M`)X````!`P``R`8``#8)``!H`P``B`D``'P'````````;0@``*8!``#8!P``
MH0D``-H%``""!0``\0```"P(````````YP```,\!``#E!@``O@<``%,)``#]
M!@``PPD```````!$!@``M`<```````!;!@````(``"<%```L````NP0`````
M``!D"0``"@(``+\)``"5!0```````#L)```,`@``S08``,H```"Q`P``#@,`
M`'8"``"=`0``O`,```8%``"I`P``&`@``,,%``!:"0``Y0(``(D&``"_"```
M%P<``!((``#@!```1@,````````:!```U@<``/4$````````>0D``+0"````
M`````````````````````````*@$```\`P``U@,``.\&``#L!P``&P0`````
M````````;P8```````````````````````"9`0``BP0``)$#````````X`<`
M`(8#``"6!0``$0````````";!P````````````!4!````````/X!``#D!@``
M`````$("``!!!@``@@`````````F!```C`(``*L(````````J`@``.`%```^
M!@``3P0```````#&"0``WP@`````````````<@<``%$#````````604`````
M```!"0``BP8``#`#``!2!0``;`$``/`$``!.!P``R`D``,H'``"J````$P8`
M`%\(```S`@```````$0#``!W````:````'H````````````````````2`0``
M)P```/<&````````A00``/T'`````````````+$```!V`0``K`0``(8"```T
M"```QP4``*@!``"-!P``2@4``,0```!C`0``3`8``,8$````````_@```!8'
M``"\!0``Y`@````````K!P``4@@``````````````````.D```!9````RP8`
M``````#A!P``"P,``)L)```O"`````````````!E````(P(``.8!```.`@``
M`````(P)``"M!P``V0```',&````````[P,``#$!``!*`@``^0(``&<#``!)
M!0```````),!````````T`D``%(#``")`````````#0%``"S"0``G@0``$$$
M````````M0@``$8'````````[P0``%`)``!!"```90<``&L$``"H!P``````
M```````=!```VP```+P"``#@`````````#T`````````!@(``'8#``"Y`P``
M`````'0&````````4`0```````#.`0``]0<``!0``````P``30(``!8#``!$
M`0``T@4``"T```!P````P@D``!,!``#&`@``ZP8`````````````L`<``%X&
M``"L`@``8@8```````!M````B@,``'H#````````H`$``!<&```=!@``\0(`
M`'4'````````*@<``*$!````````80,``!0"``"_!```````````````````
MDP(``'`%````````Z@8``*<!````````[@$``/4!```S````1P$``'@"``#R
M`0``U@0``&0%````````7@```,T#``"0"```(@$``&8#``"O!0``*`$`````
M````````]P```%L!``"!!0```P8```````"X!P```````-,$````````````
M``````#;!P``G`0``&$$``"Q!```R@$``.\"``"R"0```````$`#``#"!```
M8P<``,0"````````4`4``(L#``!]`@``2`,``&L`````````T`4``#@%````
M````FP,``'T%````````80@``,H$```Z!```C`0``#()```U!P``1@$``/<%
M``#H`0``T`,``%`'``"_!@``90D``$<)```/`````````&0!``!H!P``````
M`+@#``#)!0``*@$``$@$```&!````````$P$```J!```MP,``+<%````````
M`````/H#```%`P``/@<``$P```#3"``````````````=!P``D0```#\'``"[
M`P``-`$``+<```"D"```O0```%T#````````\P$```````!!````````````
M```="0``[@8``)(#``#B`@``^P,``)4#``#\!```4`@``(()```H"```.0<`
M`$\```#:!@``7P8``&0$``!^!P``X0D``%X'``"6"```>`@``$,(``#F!```
M`````````````````````(,&````````'0@``(<&`````````````#@```"'
M!P``B`@``'D(````````,`0````````]!```!P<`````````````^0```-$`
M```5`P``@`````````##"`````````````"R!P``C0$``+H'````````````
M`!L```#C````-P<``````````````````$$#``"-"0``B`$```H%``#""```
M(`@``$8```":````N`(``/T$``!+````@@(``$D#`````````````/`!```,
M!@```````-X(``!M`P```````/X"```D"0``4@0``(\"`````````````)`"
M````````+P0``%@$``#Q`0``*@,`````````````]`@``%<)```P`@``````
M`(0&``"C!0``1P,```````#C"```(`8``%0"``"7`P``10```/@(``!;"```
M`````%D$````````P`(``(0(``"4!0``R`,``-````!M`0``@`8``!$#````
M````:`@```````#,`@``D08``%0!``!_`@``0`@``)X'``"R"```Z@@`````
M````````U0,``#<#````````B00``-D$``"O`0``M0D```````![!@``0`0`
M`#0"````````:@,``*(!``"P`@``]0(``(<$```0!@``T@0``%<&```)!P``
MR`(``(,$``"1`0``C@D```````!K!0``10D``#`(`````````````(@&``"Y
M!0```````*T!````````HP@```<$``!N`@```````+$%``#Z!```704```8&
M``!A!0``6@```(8'`````````````"X&``!N`P``N0@``!8%```@````````
M`"L"``"S!0``HP8``&$"``!Q"```_@<``(X$``"/`0``H`,``.4```!;!```
M>@8``$P"``"O"```&P@```````#$"0``)`<``-,'````````0@8``)`'``#,
M!```_P<``!T!````````=P8````````````````````````?!@``DP```+P'
M````````QP$``.D#```P!P``?P@``'0#``"U`P``_P0```````![````2```
M``$$``"-!@```````*@)``#'!@```````,L#````````-P`````````%"0``
M>`,``,P(``!F!@``.00`````````````I`0`````````````F`D```````#Y
M`P``&0$``$`'``!"`P``8@$``+H#``"&!0``J@8``',(````````U`<``!X%
M```H!P``K0@``%<'``".````,`8``,H&``"1!0```````+L)``!B"```9P$`
M`!4```!)"0``M@```)H)```-!@``>0,``+4"``"7!P``\08``$8(```C!0``
M>@<```($`````````````/,%``"'"0``O0,``+,'``#[!0``MP(``"("``!L
M`@````````,$````````2PD``%4(``!C!@```````&8``````````````)<$
M``#6"0``3`4``!8"``````````````````#X!P``J@$``'0$``"%!P``````
M`!0!``!-!P``#0```,,&``#[!@``FP````````!K`P``OP<`````````````
M=@0``/H'``!S`@```````#,'````````S@4``+8&`````````````$T#```L
M`@``U0<`````````````5`@``!P$``"I!P```````*D!``#]`````````)P(
M``";!@``=````$T(``!@````[0(``),'``!R`0``^@8```0````S`0``FP@`
M```````["```K`D``+8)``"0!@```````*4!````````+`$``,\)```"!0``
MT`$```````"0`P``/`@``*P&``"J!```#@@``-T%``!P!P``Q`,``(0)````
M`````````'0%````````#@````````!%!P```````.@"``!C!0```````)T"
M`````````````,D#````````)0D```````#O````;@$```````"3!```?@``
M``````"4`0``10@``$,)``!S`P``>`$``(L'``"8````V`D`````````````
M`````#P"```%!@``;P@``!H```!>"0``'P@``.H#``#&`0```````*X%````
M````/@D``*\```":!0``=@8``.(!````````-@(``.T%``"K`@``'`$```\&
M`````````````+P(````````B`0``"H&```<!@``XP0``(L```#%````JP$`
M`*<(``"S!````````)(!```L!P````````H)``!Z`@```````'<)``#R"```
MS`4```````!I!0``W00````````````````````````,!P``\P<``.4'``#D
M!0``1`@``.T`````````(P$```````#7!0``,@,``%8'``"[!0```````"(&
M`````````````!4)``!8"0``:`4``!H'``#9`0```````.T(``!U`@``D0(`
M`(4(````````5P(``)D#````````F08````````Q!0``CP8````````+!@``
M`````,,!```>!@``\````#T(``!G!P``D`4`````````````=@@````````U
M`0``)`4```````#E!0``N@(```T#```>!````P``````````````_0,``*T)
M``!'`````````!T%``!Y`````````-((``#0!```]P(``!0#```&`P``V@(`
M``````!,"```1P8```0(````````YP0``-\```##`@``N00``+X```#F!0``
M_`(``*<```"K!@``AP,`````````````LP,```````",!@``9`@``,8&``!^
M"0```````&4!```0`0```````#`)``#F`P``:0@``'X"````````T@```-X%
M``#^!0``E@8``(H&````````]@4``!`$```<`@``H@D``-$"```\!```O`$`
M`!(&``!%!````````&H(````````'@```#(!``"U!P``K`@```````!E!```
M?`D`````````````AP```,`%```%"````````)<%``!9`@``3P4``$L(````
M`````````)(&````````<@0``"$"``"@"```6P(```````!H!````P,``%`"
M``````````````````!#!0``300``'H%``#;"0``;0D``,(#```S!@``+0(`
M`'T$````````J@4``%<(````````_P@``'8```!B!P```````+8!```(!0``
M,@0``#P`````````W`4`````````````GP4``#4)````````W0@``+\`````
M````5@$``'T(``":`P``?`0``-P"``!/"```>`8```````"5`0```````-<!
M``!U!```_@8``+@(```U````60$``/X$```H"0``W`8``,X(``!L!@``)`(`
M`%<$``"K`P``X`@``/P```#X!````````,\&```G`0``L0@``'L)``"``0``
M#0D``)<"``"9"```GP@``(@````/!0``_@@``(,#````````60<`````````
M````G@,``.$!````````U04``-(&``"!!@``O@8```D)``#L!````````#X%
M``"E````R`<``&X'```>`@``J@,``*`$```K"0``6`@``%H#``#E`P``SP,`
M```````?!````````````````````````*,!````````#PD``'$"``!%`P``
MRP$``$0```"*!```0P(``-T)``"^"0````````````#!`P``6`$```@)``!_
M"0``+@D``,\"`````````0$``$<'```'`P``W0$``%('```L"0``D@```(L%
M``#<"```-0,``(`%````````Z`4``.X"````````U@(``/4%````````````
M``````````````````````!6!0``(0<``-L"``#&"```H0<``/H"```V````
M$@0``(4&``"4`P``"`(``*`)``#>`0``>P@``$8)```(`0`````````````M
M!P````````````#]`@``*@```($#``"E!0``P`0``((&````````SP<``'D!
M``"=!````````&`"``"B!```5@``````````````R@4```````"#!0``\`8`
M`(8&``#E"0``&0@``#4&```.!```TP```",```#9`@```````'(%````````
M[P4```````!G!```*P,``"T#```N!P```````*,$``#8"````````+P)``#K
M!````````*4#``!R!@``E@`````````)`P``)@D``"<#`````````````.L'
M``"5`@``.P8``'<(````````(@@``,<$``"!!```4P0```\$```A`P``2P(`
M`'\'`````````````)4`````````KP0``-L%``"W!P``<0$``#T"``!I`0``
M>P,``+H```")`0``DP@``"L`````````*@4```````#\!0``$@,``+T'```K
M!@``X@@```````#V!@````````````#G`P``1@0``-X$``#T!```)@,````@
M("`@("!4;SH@`"`@("!$871E.B``("`@($9R;VTZ(``@*"5S(&1A>7,@86=O
M*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AY97-T97)D87DI`"!3=6)J
M96-T.B``(&%T(``@:6X@`",`)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0`E
M9"`E<R!A;F0@)7,`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`"5D(&UE
M<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2X`)60@;65S
M<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T
M96T@861M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R
M=&5D(&%S('-P86TN`"5D('1O("5D(&]F("5D($UE<W-A9V5S`"5D+61A>2!F
M;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-I9VX@
M57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E
M<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA
M;65D+@`E<R!A="`E<R`E<P`E<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!M86EL8F]X+@`E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@
M<W1A<G0@;V8@=&AE(&UO;G1H+@`E<R!H87,@86-C97!T960N`"5S(&AA<R!C
M86YC96QL960@)7,N`"5S(&AA<R!D96-L:6YE9"X`)7,@:&%S(')E<&QI960@
M=&\@82!F<F5E+V)U<WD@<F5Q=65S="X`)7,@:&%S(')E<&QI960@=&\@=&AE
M(&EN=FET871I;VX@=&\@)7,N`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN`"5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"X`)7,@
M:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(')E<75E
M<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y
M;W5R('!R97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@
M=&\@86UM96YD("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@
M)7,N`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I
M;VX@86)O=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`
M)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B`E<R`H)60F
M;F)S<#MO9B9N8G-P.R5D*0`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V
M92!T;R!N97AT('-C<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R
M971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BD`*%)E='5R;B!T;R!T:&4@
M8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D
M92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I
M;&P@3D]4(&)E(&%P<&QI960N*0`H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY
M:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H
M92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@
M=&AE<V4@8GD@8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S
M<RAE<RD@*@`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O
M("5S`"TM('-E;&5C="`M+0`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`,2!M
M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`Q(&UE<W-A
M9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@
M<W!A;2X`,3`P(&-H87)A8W1E<G,`,3`P,"!C:&%R86-T97)S`#$R($AO=7(@
M1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#(U,"!C:&%R86-T97)S
M`#4P,"!C:&%R86-T97)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`
M02!L87)G92!I;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE
M<W-A9V4N`$$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I
M;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@<F5C:7!I96YT+@!!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A
M('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G
M92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!32!3:&]W97)S`$%-+U!-`$%.1`!!4$D@240`06)O=70@
M=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E
M<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G0G<R!N
M86UE.@!!8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"!#:&EL9"!'<F]U<`!!
M9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!
M9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`
M061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!S;W5R8V4`061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A
M;&5N9&%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S
M(&)O;VL`061D('5S97(`061D960@(B5S(B!A<R!A;B!A='1A8VAM96YT+@!!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@:6YF;W)M871I
M;VX@8V%N(&)E('9I97=E9"`E<RX`061D:71I;VYA;"!I;F9O<FUA=&EO;B!D
M971A:6QS`$%D9&ET:6]N86P@;65S<V%G92!D971A:6QS`$%D9&ET:6]N86P@
M;65S<V%G92!D971A:6QS(&-A;B!B92!V:65W960@)7,N`$%D9&ET:6]N86P@
M;65S<V%G92!E<G)O<B!D971A:6QS`$%D9&ET:6]N86P@;65S<V%G92!E<G)O
M<B!D971A:6QS(&-A;B!B92!V:65W960@)7,N`$%D9')E<W,`061D<F5S<R!"
M;V]K`$%D9')E<W,@0F]O:W,`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES
M=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L
M;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M
M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&P@;65S<V%G97,@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE
M($U"3U@@9FEL93H`06QL(&UE<W-A9V5S(&EN('EO=7(@(B5S(B!F;VQD97(@
M;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E
M9"X`06QL(&]L9"!L:6YK960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO
M;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&P@;VQD('-E;G0M;6%I;"!F
M;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E
M9"X`06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA
M:6QB;W@_`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA
M=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA
M=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E
M<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;'1E<FYA=&EV92!P
M87)T<R!F;W(@=&AI<R!S96-T:6]N.@!!;'=A>7,`06QW87ES('-A=F4@871T
M86-H;65N=',`06UE<FEC86X@4V%M;V$`06X@97)R;W(@;V-C=7)E9"!W:&EL
M92!A='1E;7!T:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!
M4"!S97)V97(@<V%I9#H@`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H
M92!N97<@=&%S:RX`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S
M(%!R;WAY`$%N<W=E<@!!;G-W97)E9`!!;G-W97)E9"!M97-S86=E<P!!;G1A
M<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I
M;F<@;VX_`$%P<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D
M:7-P;&%Y960_`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<FEL
M`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H
M:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES
M('!U8FQI8R!K97D_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@
M>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD960A*0!!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T
M:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!
M3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/P!!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE<W-A
M9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S
M<V%G92!A<R!I;FYO8V5N=#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E
M<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\`07)G96YT:6YA`$%R;65N:6$`
M07)M96YI86X@*$%235-#24DM."D`07)R:79A;"!4:6UE`$%R=`!!<G5B80!!
M<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I
M9FEC(%)E9VEO;@!!<VL`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O
M:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN
M<P!!='1A8V@`071T86-H($9I;&5S`$%T=&%C:"!A(&-O<'D@;V8@>6]U<B!0
M1U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_`$%T=&%C:&5D($9I;&4Z
M`$%T=&%C:&5D(&9I;&4@(B5S(B!E>&-E961S('1H92!A='1A8VAM96YT('-I
M>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"X`071T86-H960@:7,@82!R
M97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N`$%T=&%C:&UE
M;G0`071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N="!T
M>7!E`$%T=&%C:&UE;G1S`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+@!!='1E;F1E97,`071T96YT:6]N`$%T=')I8G5T97,`075G=7-T`$%U<W1R
M86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VEM<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U
M:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT
M:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T;VUA=&EC86QL>2!S
M:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I
M<R!I;B!M>2!A9&1R97-S8F]O:S\`079A:6QA8FQE($%D9')E<W,@8F]O:W,Z
M`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ
M86X`0D]&2"!%>&-U<V5S`$)A8U]K('1O("5S`$)A8VL@=&\@)7,`0F%C:V=R
M;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`
M0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN90!"
M8V,`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96QO=R!I<R!T:&4@<F%W('1E
M>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+@!"96YI;@!"
M97)M=61A`$)H=71A;@!":7)T:&1A>0!";&%C:VQI<W0`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";&]C:R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!U
M;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E<W1E9#\`0F]D>0!"
M;VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S
M.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1H($AE
M861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4`0F]T<W=A;F$`0F]T
M=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E
M9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#7VAA<G-E=`!#
M86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@8V]N;F5C
M="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+@!#86X@;F]T(&-O;FYE8W0@
M=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@`$-A;B!N;W0@9&ES<&QA>2`M
M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN
M('1H92!C=7)R96YT(&UA:6QB;W@N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`
M0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;F-E;&QI
M;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@
M8V]N=&5N=',N`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N
M`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN
M;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E
M<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA
M;F1S`$-C`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E
M;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A
M=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86ER(%!E
M<G-O;@!#:&%N9V4`0VAA;F=E($%L;`!#:&%N9V4@1F]L9&5R`$-H86YG92!D
M:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@
M<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W(&UE<W-A9V5S(&%R92!S;W)T960N
M`$-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+@!#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=E('1H
M92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;"X`0VAA
M<@!#:&%R86-T97)S('1O(&1I<W!L87DZ`$-H96-?:R!,:6YK+BXN`$-H96-K
M($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAE8VL@7T%L;"].;VYE`$-H96-K
M(&%L;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M
M.@!#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_`$-H
M:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@06-T:6]N.@!#:&]O<V4@82!M
M86EL('-E<G9E<CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA
M;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG
M(&%D9')E<W-E<RX`0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS
M('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`$-H<FES=&UA
M<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L
M96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L
M96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K("5S('1O(&-O;G9E<G0@
M=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N
M('9I97<N`$-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92X`0VQI8VL@
M)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+@!#;&EC:R`E<R!T;R!V
M:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@
M)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!#;&EC:R!H
M97)E('1O(%-(3U<@=&AE($EM86=E<P!#;&EC:R!O;B!O;F4@;V8@>6]U<B!S
M96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE
M;&1S('1O('-E87)C:"X`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VL@=&\@4V%V
M92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:P!#;&EC:V%T
M96QL('9I82!(5%10`$-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M
M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(`0VQI8VMI;F<@;VX@
M=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860`
M0VQO<V4`0VQO<V4@5VEN9&]W`$-L;W-E('1H:7,@=VEN9&]W`$-L;W-E9"!&
M;VQD97(`0VQO=61S`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#
M;VQL87!S90!#;VQL87!S92!!;&P`0V]L;&%P<V4@06QL($9O;&1E<G,`0V]L
M;&%P<V4@1F]L9&5R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R
M`$-O;&]R($EN9&EC871O<CH@`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T
M:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N
M9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#
M;VUP;&5T960`0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4`0V]M<&]S92!M97-S
M86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\`0V]M<&]S92!M97-S86=E<R!W
M:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R
M=',@=&AE(&9E871U<F4I/P!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:6=U<F4@:&]W
M(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N`$-O;F9I9W5R92!M86EL('!R979I
M97<@;W!T:6]N<RX`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE
M($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D
M+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@
M9F%I;&5D`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+@!#;VYT:6YU90!#;VYT<F]L(%!'4"!S=7!P;W)T
M(&9O<B`E<RX`0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N`$-O;G1R
M;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE
M=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O
M;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\`
M0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'D@
M=&\@9F]L9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]S=&$@4FEC80!#
M;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E
M;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E
M+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U
M;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&-R96%T92!T:&4@5D93(&)A8VME;F0Z("5S`$-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S
M(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,`0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO
M="!E>&5C=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N`$-O=6QD(&YO="!E
M>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T
M=&%C:&UE;G0N`$-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL
M92!F<F]M('1H92!::7`@87)C:&EV92X`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN
M('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E
M;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S
M<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@
M=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V
M92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B
M:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD
M(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`
M0W)E871E($9O;&1E<@!#<F5A=&4@2V5Y<P!#<F5A=&4@5FER='5A;"!&;VQD
M97(`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<@!#
M<F5A=&4@82!N97<@;VYE`$-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R
M`$-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(`0W)E871E(&9I;'1E<FEN9R!R
M=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@
M:6YT;R!F;VQD97)S+"!A;F0@9&5L971E('-P86TN`$-R96%T92!S=6(@9F]L
M9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#
M<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E
M;G0@5V5A=&AE<@!#=7)R96YT(&%C8V5S<R!T;R`E<P!#=7)R96YT(&-O;F1I
M=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F
M971C:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N`$-U<W1O;6EZ92!H
M;W<@>6]U('-E;F0@;6%I;"X`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL
M:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A
M=%]E`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@
M<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L
M(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@0V]L
M;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z
M`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5G
M871E9`!$96QE=&4`1&5L971E("5S(%!U8FQI8R!+97D`1&5L971E($-U<G)E
M;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E;&5T92!'<F]U<`!$96QE=&4@
M4&5R;6ES<VEO;@!$96QE=&4@5FER='5A;"!&;VQD97(`1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&9E=&-H960@
M;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/P!$96QE=&4@9G)O;2!M>2!C
M86QE;F1A<@!$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I
M;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@
M870@8F5G:6YN:6YG(&]F(&UO;G1H/P!$96QE=&4@<F]W`$1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T
M92!T:&4@8W5R<F5N="!R;W<`1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E
M;&5T960@=&AE(&%T=&%C:&UE;G0@(B5S(BX`1&5L971I;F<@86YD($UO=FEN
M9R!-97-S86=E<P!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5N>2!R97%U97-T
M`$1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N`$1E<V-E
M;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL
M<P!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L
M;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E
M=R!P;VEN=#H@`$1I;2!S:6=N871U<F5S/P!$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA
M>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P
M;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\`1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;&%Y(&EN
M($)O9'D@;V8@365S<V%G90!$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@
M;V8@;F5W(&UA:6P_`$1I<W!O<VET:6]N`$1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;@!$:FEB;W5T:0!$;R!.3U0@;6%T8V@`1&\@3F]T($-H96-K($9O;&1E
M<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!N;W0@9V5N97)A=&4@82!L
M:6YK(&EN('1H92!&<F]M.B!C;VQU;6X`1&\@>6]U('=A;G0@=&\@;W!E;B!T
M:&%T(&9O;&1E<C\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$
M;VUI;FEC86X@4F5P=6)L:6,`1&]N90!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA=`!$;W=N;&]A9"!!;&P@071T86-H
M;65N=',@*&EN("YZ:7`@9FEL92D`1&]W;FQO860@1F]L9&5R*',I`$1O=VYL
M;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=`$1O=VYL;V%D(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O=VYL;V%D(&EN("YZ
M:7`@1F]R;6%T`$1R869T`$1R869T(&9O;&1E<@!$<F%F=',@9F]L9&5R.@!$
M<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`12UM86EL($%D9')E<W,`15)2
M`$524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`
M16-U861O<@!%9&ET`$5D:70@0FQA8VML:7-T`$5D:70@0FQO8VL`161I="!&
M:6QT97)S`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES
M<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!6:7)T=6%L($9O
M;&1E<@!%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$5D
M:70@5VAI=&5L:7-T`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@>6]U<B!B;&%C:VQI<W0`161I="!Y;W5R(&9I;'1E
M<B!R=6QE<P!%9&ET('EO=7(@<')E9F5R96YC97,@9F]R(&%C8V5S<VEN9R!O
M=&AE<B!M86EL(&%C8V]U;G1S+@!%9&ET('EO=7(@=VAI=&5L:7-T`$5D=6-A
M=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T:65D(&%L;"!M97-S
M86=E<R!F<F]M("5S+@!%;7!T>2!&;VQD97(H<RD`16UP='D@5')A<V@@9F]L
M9&5R`$5M<'1Y(%]4<F%S:`!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N
M`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_
M`$5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\`16YA8FQE(&EN<V5R=&EO
M;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA
M8FQE(&UE<W-A9V4@<')E=FEE=W,_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_`$5N8W)?>7!T:6]N($]P=&EO;G,`16YD`$5N9"!F;W)W87)D
M960@;65S<V%G90!%;F0@;65S<V%G90!%;F0@;65S<V%G92!F<F]M("5S`$5N
M9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(%!A<W-P:')A<V4`16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!5
M4DP@:&5R90!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O
M;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O
M;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R
M`$5N=')Y("(E<R(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D
M<F5S<R!B;V]K`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R
M;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92X`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V96YT('-U8V-E
M<W-F=6QL>2!D96QE=&5D+@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN
M=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,
M;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L
M=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@06QL`$5X<&%N9"!!;&P@1F]L
M9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.86UE<P!%>'!A;F0@;F%M97,@
M:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A
M8VMG<F]U;F0_`$5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E
M9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\`17AP86YD:6YG`$5X<&5C=&5D
M("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D
M(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&
M86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X
M`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=&-H($UA:6P`
M1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\`1F5T8V@@;65S<V%G
M97,@=7!O;B!L;V=G:6YG(&]N/P!&971C:&UA:6PZ(`!&971C:&UA:6PZ(&YO
M(&YE=R!M97-S86=E<RX`1F5W(%-H;W=E<G,`1FE?;'1E<G,`1FEJ:0!&:6QE
M`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL
M92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A
M9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R($]P=&EO;G,`
M1FEL=&5R(%-E='1I;F=S`$9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R
M;V9A;FET>3\`1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S
M>7-T96TN`$9I;'1E<G,`1FEL=&5R<R!.3U0@06-T:79E`$9I;'1E<G,Z("5S
M(&UA;F%G96UE;G0@<&%G90!&:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S
M="!-86EL8F]X(%!A9V4`1FER<W0@4&%G90!&:7)S="!1=6%R=&5R`$9I>"!R
M871I;P!&;&EP`$9L;V%T`$9O7W)W87)D`$9O9P!&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0`1F]L9&5R($YA=FEG871O<@!&;VQD97(@4W5M;6%R>0!&;VQD
M97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"X`1F]L9&5R('5S92!I<R!N;W0@
M96YA8FQE9"X`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_
M`$9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@
M9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y`$9O<FUS`$9O<G1U;F4`1F]R='5N
M92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R
M=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A9V4@9G)O
M;2`E<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P
M;VQI=&%N`$9R964O0G5S>2!);F9O<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`
M1G)E92]"=7-Y(%)E<75E<W0`1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`
M1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R
M;B!497)R:71O<FEE<P!&<F]?;0!&<F]M`$9R;VT@061D<F5S<P!&<F]M('1H
M92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9W9#H`
M1G=D.B``1G=D.B`E=2!&;W)W87)D960@365S<V%G97,`1V%B;VX`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@
M3W!T:6]N<P!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#
M;V1E`$=E;W)G:6$`1V5R;6%N>0!'970@;VYL>2!N97<@;65S<V%G97,_("A)
M34%0(&]N;'DI`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O('1O($UE
M<W-A9V4`1V]E9&5L`$=O;V=L92!396%R8V@`1W)A;G0@86-C97-S`$=R87ES
M8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N
M861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U
M97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=7EA;F$`2$5210!(5$U,`$A434P@5F5R<VEO;B!O9B!-
M97-S86=E`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA
M<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(
M96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R
M90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AE<F4@:7,@
M=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.@!(:61D96X`2&ED9&5N
M(&EN(%1H<F5A9"!6:65W`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E
M9`!(:6=H`$AI9V@@4')I;W)I='D`2&EG:&5S=`!(;U]M90!(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H
M;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV
M86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO
M<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E
M<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA
M<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO
M<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I`$AO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/P!(
M;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W('1O(&%T=')I8G5T92!Q
M=6]T960@;&EN97,@:6X@82!R97!L>0!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU
M;6]R:7-T<P!(=6YG87)Y`$E-05``24U!4"`H075T;R!$971E8W0@4')O=&]C
M;VQS*0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&]V97(@4U-,`$E-05`@;W9E<B!3
M4TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*0!)34%0(&]V97(@4U-,("AS
M96QF+7-I9VYE9"D`24U!4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL(%-E<G9E
M<G,`24Y"3U@`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0
M(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA
M;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE
M.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E
M;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!)9VYO<F4`26=N
M;W)E($%L;`!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!)
M;6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U
M<&QO860`26UA9V5S`$EM<&]R=`!);7!O<G0@2V5Y`$EM<&]R="!+97EP86ER
M`$EM<&]R="!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+
M97D`26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!097)S
M;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S`$EM<&]R="!0=6)L:6,@2V5Y`$EM
M<&]R="!0=6)L:6,@4$=0($ME>0!);7!O<G0@4'5B;&EC(%,O34E-12!+97D`
M26UP;W)T(%,O34E-12!+97D`26UP;W)T(&UB;W@@1FEL90!);7!O<G0@;6)O
M>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+@!);7!O<G0L(%-T97`@)60`26UP
M;W)T86YT`$EM<&]R=&%N="!M97-S86=E<P!);7!O<G1E9"`E9"!M97-S86=E
M<R!F<F]M("5S+@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8F]X`$EN8VQU9&4@
M82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\`26YC
M;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_`$EN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD
M:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO
M;@!);F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y`$EN9F]R;6%T:6]N(&]N
M(%!E<G-O;F%L(%!R:79A=&4@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L
M(%!U8FQI8R!+97D`26YL:6YE`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R
M="!#97)T:69I8V%T92!(97)E`$EN<V5R="!);6%G90!);G-E<G0@4&5R<V]N
M86P@4')I=F%T92!01U`@2V5Y($AE<F4`26YS97)T(%!E<G-O;F%L(%!U8FQI
M8R!01U`@2V5Y($AE<F4`26YS97)T(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS
M97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O
M<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A
M9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T
M97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS
M97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A
M9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O
M=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D
M(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I
M9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC
M:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@06-T
M:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV86QI9"!!9&1R
M97-S`$EN=F%L:60@4F5M;W1E($UA:6QB;W@`26YV86QI9"!51$@N("A5<V5R
M($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B
M871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M:V5Y`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E
M(&ME>2X`26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`26YV86QI
M9"!P<F]T;V-O;"X`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R
M8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)
M;G9E<G0`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)
M=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*
M=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I
M9GD@4FEG:'0`2T(`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE
M;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE
M;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97D@<W5C8V5S<V9U;&QY('-E;G0@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B
M;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y
M;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M`$QA<W0@2&%L9@!,87-T($UA:6QB;W@@4&%G90!,87-T(%!A9V4`3&%S="!1
M=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA
M>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,
M969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI7VYK($%T=&%C:&UE
M;G1S`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T
M96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY
M`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN
M('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI
M;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN
M:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B:61D96XN`$QI;FMS`$QI;G5X($-O
M;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A
M8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T(&%L;"!C
M;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF
M(&1I<V%B;&5D+"!Y;W4@=VEL;"!O;FQY('-E92!C;VYT86-T<R!T:&%T('EO
M=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI`$QI<W0M07)C:&EV90!,:7-T+4AE
M;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB
M90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@:6X@=&AE($AE861E<@!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,
M;V%D:6YG+BXN`$QO8V%L($UA:6QB;W@Z`$QO8V%L('1I;64Z(`!,;V-A;&4@
M86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!I;B!T;R`E<P!,;V<@;W5T
M`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=R!0<FEO<FET
M>0!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W
M97(@<F]M86X@;G5M8F5R<P!,;W=E<W0`3'5X96UB;W5R9P!-30!-3U1$`$U3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O
M`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-
M86-I;G1O<V@@1FEL90!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI
M;@!-86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T
M;SH`36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS
M`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`
M36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-
M87)C:`!-87)G:6X`36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%-E
M96X`36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%5N<V5E;@!-87)K
M(&%S.@!-87)K(&1I9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I
M9F9E<F5N="!C;VQO<G,_`$UA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@
M;VYL>2D`36%R:R!S:6UP;&4@;6%R:W5P/P!-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H
M($%L;"!1=65R:65S`$UA=&-H($%N>2!1=65R>0!-871C:&EN9R!F:65L9',`
M36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@
M;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@071T86-H;65N
M="!3:7IE`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&%T=&%C
M:&UE;G1S(')E86-H960N`$UA>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE
M(')E86-H960N`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE971I;F<@0V%N8V5L
M;&%T:6]N`$UE971I;F<@26YF;W)M871I;VX`365E=&EN9R!0<F]P;W-A;`!-
M965T:6YG(%)E<&QY`$UE971I;F<@57!D871E`$UE971I;F<@57!D871E(%)E
M<75E<W0`365M8F5R<P!-96YU($9O;&1E<B!,:7-T`$UE;G4@;6]D93H`365R
M9V4@8V5L;',`365S<V%G90!-97-S86=E($-O;7!O<VET:6]N`$UE<W-A9V4@
M1&%T90!-97-S86=E($]P=&EO;G,`365S<V%G92!396%R8V@`365S<V%G92!3
M:7IE`$UE<W-A9V4@4V]U<F-E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U
M;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E
M('9E<FEF:65D+@!-97-S86=E(%9I97=I;F<`365S<V%G92!E>'!I<F5D+@!-
M97-S86=E(&9L86=S`$UE<W-A9V4@9F]L9&5R<P!-97-S86=E(&9R;VT@)7,`
M365S<V%G92!M871C:&5S`$UE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L
M;'DN`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V960@
M=&\@)7,`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2X`365S<V%G92!T>7!E
M`$UE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N`$UE<W-A
M9V5S('1O`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=')I
M8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D
M;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A
M=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT
M('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N
M`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@
M<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@
M1&%T90!-;V1I9GD`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B
M;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY
M`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE87(`
M36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V90!-;W9E($1O=VX`36]V
M92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!T;R!F
M;VQD97(`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<P!-=6QT:7!A<G0O86QT97)N871I=F4`375L=&EP;&4@<V5L96-T
M:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA
M;FUA<@!.3RP@22!$;R!.3U0@06=R964`3D]410!.86UE`$YA;64@86YD+V]R
M(&5M86EL(&-A;B!N;W0@8F4@96UP='D`3F%M:6)I80!.875R=0!.965D<R!!
M8W1I;VX`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`
M3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.
M971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA
M;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T
M:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5V97(@<V%V92!A='1A8VAM
M96YT<P!.97<`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($9O;&1E
M<@!.97<@36%I;`!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.
M97<@6F5A;&%N9`!.97<@;65S<V%G97,`3F5W('=I;F1O=R`H7V)L86YK*0!.
M97=S`$YE=W-G<F]U<',`3F5X=`!.97AT($UE<W-A9V4`3F5X="!086=E`$YE
M>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E
M`$YO`$YO($-E<G1I9FEC871E(&9O=6YD`$YO($5N8W)Y<'1I;VX`3F\@2V5Y
M<R!I;B!+97ER:6YG`$YO($UE<W-A9V5S`$YO(%!'4"!P=6)L:6,@:V5Y(&EM
M<&]R=&5D+@!.;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT`$YO(%!U
M8FQI8R!+97ES($9O=6YD`$YO(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D
M+@!.;R!A='1A8VAM96YT<R!F;W5N9"X`3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA
M8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@
M=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL
M92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE
M9"X`3F\@9FEL92!U<&QO861E9`!.;R!F;VQD97(@<V5L96-T960N`$YO(&9O
M;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M86EL+@!.;R!F;VQD
M97)S('=E<F4@<W!E8VEF:65D`$YO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G
M97,`3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<P!.;R!L;V-A=&EO
M;B!I<R!S970N`$YO(&UE<W-A9V4@8F]D>2!T97AT`$YO(&UE<W-A9V4@<W5P
M<&QI960N`$YO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N`$YO(&YA
M;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I
M=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E
M<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S
M:6=N=7!S+@!.;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N
M`$YO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!P97)S
M;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+@!.;R!R=6QE<P!.
M;R!S:61E<P!.;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"X`
M3F\@<W!E;&QI;F<@97)R;W)S`$YO('-U9V=E<W1I;VYS`$YO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<B!S<&5C
M:69I960N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V
M86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!087)T:6-I
M<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U
M.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R;6%L`$YO<G1H97)N($AE;6ES<&AE
M<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`
M3F]T($)E9F]R90!.;W0@1&5L971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N
M=`!.;W0@4&5R<V]N86P`3F]T(&$@9&ER96-T;W)Y`$YO="!A('9A;&ED('!U
M8FQI8R!K97DN`$YO="!D96QE=&5D(&UE<W-A9V5S`$YO="!I;7!L96UE;G1E
M9"X`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.;W0@<V5T`$YO="!S=7!P;W)T
M960N`$YO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM90!.;W1E<P!.
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU
M;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E
M;&5T:6YG(&UO;G1H;'DN`$YU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E
M<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+@!.=6UB97(@;V8@<F]W
M<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+@!/2P!/4@!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T
M86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&UE<W-A9V5S
M`$]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]M86X`3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!D
M:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\`
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+@!/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D
M(&9O<B!T:&ES(&%C=&EO;BX`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R
M;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E
M;F5D($9O;&1E<@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P
M97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/
M<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N
M:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C;W5N=',`3W1H97(@3W!T
M:6]N<P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92X`4$=0`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@
M16YC<GEP="!-97-S86=E`%!'4"!%;F-R>7!T960@1&%T80!01U`@17)R;W(Z
M(`!01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I
M=F%T92!K97DN`%!'4"!/<'1I;VYS`%!'4"!087-S<&AR87-E($EN<'5T`%!'
M4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN`%!'4"!0=6)L:6,@2V5Y`%!'4"!0=6)L:6,@2V5Y
M(%1E>'0`4$=0(%!U8FQI8R!+97D@9F]R("(E<R`H)7,I(B!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D+@!01U`@4'5B;&EC($ME>2!F;W(@(B5S(B!W87,@<W5C
M8V5S<V9U;&QY(&1E;&5T960N`%!'4"!0=6)L:6,@2V5Y<FEN9P!01U`@4VEG
M;B!-97-S86=E`%!'4"!3:6=N+T5N8W)Y<'0@365S<V%G90!01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A`%!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@
M861D960N`%!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0
M('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`%!'4"!S=7!P
M;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I
M9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@=F5R:69I960N`%!'4"!S=7!P;W)T
M(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!M97-S86=E(&ES('5N
M86)L92!T;R!B92!D96-R>7!T960N`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,
M:6=H="!286EN`%!-(%-H;W=E<G,`4$T@5"U3=&]R;7,`4$]0,P!03U`S("A!
M=71O($1E=&5C="!0<F]T;V-O;',I`%!/4#,@;W9E<B!34TP`4$]0,R!O=F5R
M(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I`%!/4#,@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D*0!03U`S+"!N;R!43%,`4%](4"!3:&5L;`!0861D:6YG
M`%!A9V4@)60@;V8@)60`4&%G92!W:71H('1H92!&:7)S="!5;G-E96X@365S
M<V%G90!086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4`4&%K:7-T
M86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA
M;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T*',I`%!A<G1L>2!#
M;&]U9'D`4&%S<W!H<F%S90!087-S<&AR87-E("A!9V%I;BD`4&%S<W!H<F%S
M92!S=6-C97-S9G5L;'D@=6YL;V%D960N`%!A<W-P:')A<V4Z`%!A<W-P:')A
M<V5S(&-A;B!N;W0@8F4@96UP='D`4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H
M`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S
M="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD
M:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VX`4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C86X@;F]T(&)E(&-H86YG
M960N`%!E<G-O;F%L`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G-O;F%L(%!'
M4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!E<G-O;F%L(%!'
M4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)S;VYA;"!3+TU)344@
M8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@`%!E<G-O;F%L(%,O34E-12!K
M97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)U`%!E=',`4&AI;&EP<&EN
M97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%C92!Y;W5R('-I
M9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_`%!L86EN=&5X
M="!697)S:6]N(&]F($UE<W-A9V4`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@9F]L9&5R.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+@!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z`%!L
M96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N
M;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@
M<V5S<VEO;BX`4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N
M=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A
M<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S
M86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R!C;V]K:65S($%.1"!Y;W4@87)E
M(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL
M;"!H879E('1O(&QO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S
M('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2!H:6IA8VMI
M;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O
M;G9E;FEE;F-E+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R
M;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64N`%!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O
M<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W
M:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@82!F;VQD97(@8F5F
M;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS+@!0;&5A<V4@<V5L96-T(&%N
M(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T(&%T
M(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+@!0;&5A<V4@<V5L96-T(&]N
M;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN`%!L96%S92!S96QE
M8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#H`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0;W=E<F5D(&)Y($AO<F1E`%!R96-E9&4@>6]U
M<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\`4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9F5R96YC97,@<W5C8V5S<V9U
M;&QY('5P9&%T960N`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S
M96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S($UE<W-A9V4`4')E=FEO=7,@
M4&%G90!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT`%!R:6YT(&1O8W5M96YT`%!R
M:6]R:71Y`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO
M;@!0<F]J96-T<P!0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES
M('-E;G0[(&1E9F%U;'0@=&\@3D\`4')O;7!T(&5V97)Y('1I;64@86X@871T
M86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4P!0<F]M<'0@=&5X=`!0
M<F]T;V-O;#H`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L
M:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+@!0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!0=65R=&\@4FEC;P!0=7)?9V4@1&5L971E9`!0=7)G92!$96QE=&5D
M`%!U<F=E($9O;&1E<BAS*0!0=7)G92!4<F%S:"!H;W<@;V9T96XZ`%!U<F=E
M(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO
M=6YT(&]F(&1A>7,N`%!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@
M9F]L9&5R/P!1871A<@!1=65R>0!1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N
M,F9-0B`@*"4N,F8E)2D`475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)
M5`!1=6]T82!S=&%T=7,Z($Y/($Q)34E4`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E
M`%)A:6X@4VAO=V5R`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E7W%U97-T($1E
M;&EV97)Y($-O;F9I<FUA=&EO;@!296%D`%)E860@;65S<V%G97,`4F5A;&QY
M(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8V5I=F5D($]N`%)E8V5I=F5D
M(%-I;F-E`%)E8V5I=F5D(%5N=&EL`%)E9&ER96-?=`!2961I<F5C=`!2961I
M<F5C="!-97-S86=E`%)E9&ER96-T('1H:7,@;65S<V%G90!2961I<F5C=&EN
M9R!F86EL960N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F
M<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@1F]L9&5R(%9I
M97=S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@
M0G)O=W-E<@!296QO860@5FEE=P!296UA<FMS`%)E;65M8F5R('1H92!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M
M;W1E($UA:6QB;W@Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K
M`%)E;6]V92!&:65L9"!&<F]M(%-E87)C:`!296UO=F4@8V]L=6UN`%)E;6]V
M92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@<V]U
M<F-E`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5N86UE($9O;&1E
M<BAS*0!296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@
M;6]N=&@_`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;%]Y('1O($QI<W0`4F5P;&%C92!W
M:71H.@!297!L>0!297!L>2!396YT+@!297!L>2!T;R!!;&P`4F5P;'D@=&\@
M06QL.@!297!L>2!T;R!,:7-T`%)E<&QY('1O($QI<W0Z`%)E<&QY('1O(%]!
M;&P`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET
M:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q
M=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DM5&\`4F5P;'DM
M5&\Z(`!297!L>3H`4F5P;W)T(&%S($EN;F]C96YT`%)E<&]R="!A<R!3<&%M
M`%)E<75E<W0@82!?4F5A9"!296-E:7!T`%)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W0@9&5L:79E
M<GD@8V]N9FER;6%T:6]N/P!297%U97-T(')E860@<F5C96EP=',_`%)E<75E
M<W1E9"!M97-S86=E(&YO="!F;W5N9"X`4F5Q=6ER960@4&%R=&EC:7!A;G0`
M4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-P
M;VYD96YT(%-T871U<R!5<&1A=&5D+@!297-U;'1S`%)E<W5M90!297-U;64@
M>6]U<B!S97-S:6]N`%)E='5R;B!T;R!&971C:"!-86EL`%)E='5R;B!T;R!/
M<'1I;VYS`%)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E
M;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/P!2975N:6]N
M`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N
M<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?
M=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T
M92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R
M=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-10!3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'0@365S
M<V%G90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4R]-24U%($5R<F]R.B``
M4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R
M:79A=&4@:V5Y+@!3+TU)344@3W!T:6]N<P!3+TU)344@4&%S<W!H<F%S92!)
M;G!U=`!3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!3+TU)344@4'5B;&EC($ME>2!F
M;W(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%,O34E-12!0=6)L
M:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`4R]-24U%(%!U8FQI8R!+97ER
M:6YG`%,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL
M>2!A9&1E9"X`4R]-24U%(%-I9VX@365S<V%G90!3+TU)344@4VEG;B]%;F-R
M>7!T($UE<W-A9V4`4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI
M<R!S>7-T96TN`%,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@96YA
M8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D
M+@!3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A
M;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E('9E<FEF:65D+@!305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`
M4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4U]U8FIE8W0`4V$`
M4V%?=F4@82!C;W!Y(&EN(`!385]V92!A<P!386EN="!(96QE;F$`4V%I;G0@
M2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M
M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD
M(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V
M90!3879E("5S`%-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E
M;G0M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`4V%V92!/<'1I;VYS`%-A=F4@
M7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@87,@=6YS965N/P!3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F4@<F5C:7!I96YT
M<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\`
M4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E<C\`4V%V92!S96YT(&UA
M:6P_`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=FEN9R!T:&4@9')A9G0@
M9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<P!38VEE
M;F-E`%-E87)C:`!396%R8V@@)7,`4V5A<F-H($5N9VEN97,`4V5A<F-H(%)E
M<W5L=',`4V5E;@!396QE8W0`4V5L96-T($%N;W1H97(@06-C;W5N=`!396QE
M8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!F:65L9`!396QE8W0@
M82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E
M<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@861D<F5S<R!B;V]K
M('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S
M97,N`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E
M;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R
M97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!A;B!O8FIE8W0`4V5L
M96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@
M=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE(&UA:6P@<V5R
M=F5R('1Y<&4`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396QE8W1E9"!!9&1R97-S(&)O;VMS.@!396YD($ME>2!T
M;R!0=6)L:6,@2V5Y<V5R=F5R`%-E;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E
M;F0@365S<V%G90!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G
M86P`4V5N<V]R.B``4V5N="!M86EL(&9O;&1E<@!396YT(&UA:6P@9F]L9&5R
M.@!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB
M97(`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N`%-E<G9E
M<CH`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+@!3970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N
M('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N`%-E="!T:&4@6"U0<FEO
M<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F4@1F]L9&5R<P!3:&%R92!M86EL
M(&9O;&1E<G,`4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U
M<V5R<RX`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=6QD(&QA<F=E(&)L
M;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F
M875L=#\@270@8V%N(&)E('1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@
M8VAO;W-E+@!3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E
M<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\`4VAO=6QD('1H92!C;VUP;W-E
M('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W5L
M9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@
M;65S<V%G97,@8GD@9&5F875L=#\`4VAO=P!3:&]W($%L;"!&;VQD97)S`%-H
M;W<@06QL($AE861E<G,`4VAO=R!$96QE=&5D`%-H;W<@3&EM:71E9"!(96%D
M97)S`%-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N`%-H;W<@3VYL>2!3
M=6)S8W)I8F5D($9O;&1E<G,`4VAO=R!5;G-U8G-C<FEB960`4VAO=R!A;B!I
M8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE
M<W-A9V5S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E
M;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('!R979I97=S(&9O<B!U;G)E860@
M;65S<V%G97,@;VYL>3\`4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\`4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/P!3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE
M(&UE;G5B87(_`%-H;W<@=&AE($EM86=E<P!3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@
M:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T;W1A;"!N=6UB97(@;V8@
M;6%I;',@:6X@9F]L9&5R/P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@
M16%R;'D`4VAO=V5R<R!,871E`%-H;W=N`%-H<FEN:P!3:')I;FL@;W(@;6]V
M92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`
M4VE?>F4`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R
M92!!;&=O<FET:&T`4VEG;F5D`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E
M;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=R!3:&]W97(`4VYO=R!D97!T
M:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD
M<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!B>2!!<G)I=F%L`%-O<G0@
M8GD@1&%T90!3;W)T(&)Y($9R;VT@061D<F5S<P!3;W)T(&)Y($UE<W-A9V4@
M4VEZ90!3;W)T(&)Y(%-U8FIE8W0`4V]R="!B>2!4:')E860`4V]R="!B>2!4
M;R!!9&1R97-S`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S
M`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U
M=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A
M8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P
M86T@9F]L9&5R.@!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&5C:6%L($-H
M87)A8W1E<G,`4W!E;&P@0VAE8VL`4W!E;&P@0VAE8VME<@!3<&5L;"!C:&5C
M:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P
M96QL(&-H96-K:6YG+@!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R
M;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0`
M4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F
M;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES
M=`!3=')I<"!!='1A8VAM96YT`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R
M97-S`%-T<FEP(&QI;F5B<F5A:W,_`%-T>6QE(%M#4U-=`%-U`%-U8E]J96-T
M`%-U8FIE8W0`4W5B:F5C="!&:65L9`!3=6)M:70`4W5B<V-R:6)E('1O($9O
M;&1E<BAS*0!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C
M97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F
M=6QL>2!W<F]T92`E<P!3=61A;@!3=6=G97-T:6]N<P!3=6UM87)Y`%-U;B!2
M:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR
M:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R
M:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N
M9`!3=V5D96X`4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9`!3=VET8V@@=&\@
M2%1-3"!C;VUP;W-I=&EO;@!3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I
M=&EO;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS
M`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;7,`5%-6(&9I
M;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A
M:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N
M>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E7WAT
M`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R
M871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!4
M96YT871I=F5L>2!!8V-E<'0@<F5Q=65S=`!496YT871I=F5L>2!!8V-E<'1E
M9`!497)M<R!O9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF
M+G!H<`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)
M4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E
M;2X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($9R
M;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.@!4
M:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U
M<'!O<G0@(B5S(@!4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL`5&AE($UA
M8VEN=&]S:"!R97-O=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+@!4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4
M:&4@86-C;W5N="`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!A8V-O=6YT
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!A9&UI;FES=')A=&]R(&YE961S
M('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD
M(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&%T=&%C:&UE
M;G0@=V%S(&YO="!F;W5N9"X`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O
M;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V
M92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@
M8F5L;W<N`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N
M86UE9"!T;R`B)7,B+@!4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@
M86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!D<F%F="!H87,@8F5E
M;B!S879E9"!T;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E
M=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L
M9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N
M86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A
M=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O
M;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S
M8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T
M960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B
M)7,B('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"X`5&AE(&9O;&1E<B`B)7,B
M('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"X`5&AE(&9O;&1E<B`B)7,B('=A
M<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R`B)7,B+@!4:&4@9F]L;&]W:6YG
M(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S
M86=E+@!4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@=&AI
M<R!P87)T.@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S
M92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@
M;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A
M<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y
M(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N
M($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O
M('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA
M>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@861D
M<F5S<V)O;VLN`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H
M92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93H`5&AE(&UA:6P@<V5R=F5R(&=E
M;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S<V%G93H`
M5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A
M9V4Z`%1H92!M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN`%1H92!M97-S
M86=E("(E<R(@9G)O;2`B)7,B("@E9"!B>71E<RD@97AC965D<R!F971C:"!S
M:7IE(&QI;6ET+@!4:&4@;65S<V%G92!B96EN9R!C;VUP;W-E9"!H87,@8F5E
M;B!C;&]S960N($5X:71I;F<N`%1H92!M97-S86=E(&AA<R!B965N(&1E;&5T
M960N`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+@!4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N
M(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S
M<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+@!4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@
M;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@
M8FQO8VL@<&]P=7`@=VEN9&]W<S\`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN`%1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N
M(&)E('9I97=E9"`E<RX`5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X
M:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N`%1H92!R97%U97-T960@
M9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N`%1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I
M9&4@;VYL>0!4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T
M:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@9G)O;2!Y
M;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L
M:6-K("5S('1O('-E;F0@=&AE(&YO=&EF:6-A=&EO;B!M97-S86=E+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R
M97!L86-E9"X`5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA
M8V5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N`%1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="X`5&AE('-P
M96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T87-K(&AA<R!B965N
M(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H92!T97AT(&]F('1H92!M97-S
M86=E`%1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N
M`%1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E`%1H92!T97AT(&]F
M('1H92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T
M97AT(&]F('1H92!S96YT(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE('-E;G0@
M;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T
M82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E
M(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N
M`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@82!P<F]B;&5M
M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H
M97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T
M;R`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@
M(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E
M<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E
M=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S
M86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RX`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q
M=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G
M97,@9G)O;2`B)7,B('1O("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E
M(&%S(&$@9')A9G0N`%1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@
M;65S<V%G93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C
M;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@;F\@=&5X="!I;B!T
M:&ES(&UE<W-A9V4@<&%R=`!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S
M(&5M8F5D9&5D(&EN(&ET+@!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S
M(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92!T
M:&ES.B``5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I
M;F<@9F]L9&5R<RX`5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@
M=&\@=&AE(&UE<W-A9V4N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N
M`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@
M9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6
M;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT
M86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E
M>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@
M<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W
M87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D
M(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'
M<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI
M96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M87D@=&%K92!S;VUE('1I;64N
M($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\`5&AI<R!M97-S
M86=E(&-O;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N`%1H:7,@;65S<V%G92!C
M;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T
M('1H92!F;W)M870@;V8@=&AI<R!M97-S86=E(&ES('5N:VYO=VXN`%1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC
M<GEP=&5D(&UE<W-A9V4N($5R<F]R.B``5&AI<R!M97-S86=E(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T("AA8V-O
M<F1I;F<@=&\@4D9#(#(P,34I+@!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F;W)M870N`%1H:7,@
M;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N`%1H
M:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)
M344N`%1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-
M12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"X`
M5&AI<R!M97-S86=E('1O`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A
M(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N
M)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES('-Y<W1E
M;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A
M(&-O;7!O<V4@=VEN9&]W+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H<F5A9"!6:65W`%1H=6YD97(`5&EC
M:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE
M8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4
M;R!!9&1R97-S`%1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@8VQI
M8VMI;F<N`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI
M8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`
M5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5&]T86P@071T
M86-H;65N=',@4VEZ93H`5')A;G-L871I;VYS`%1R87-H(&9O;&1E<@!4<F%S
M:"!F;VQD97(Z`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4
M=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO
M=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN
M90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A
M9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5
M;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S
M:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T
M;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R
M86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E
M9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E
M860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R971R:65V92!Q=6]T
M80!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%N<W=E<F5D
M`%5N86YS=V5R960@;65S<V%G97,`56YD96QE=&4`56YD97)L:6YE`%5N9&ES
M8VQO<V5D(%)E8VEP:65N=',`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@
M8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z(`!5;F9I;&5D`%5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`
M56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+
M:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!$871E`%5N:VYO
M=VX@365E=&EN9P!5;FMN;W=N(%)E8VEP:65N=`!5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL
M:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YL;V%D(%!A<W-P:')A<V4`56YN
M86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5E;@!5;G-E="!C;VQO<@!5
M;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS*0!5;G-U<'!O<G1E9"!%>'1E;G-I
M;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@071T86-H;65N="!);F9O<FUA
M=&EO;@!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!G
M<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I
M;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R
M<F5N=#H@)7,`57-E($1E9F%U;'0@5F%L=64`57-E($E-05`@9F]L9&5R('-U
M8G-C<FEP=&EO;G,_`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@
M9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO
M="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R
M($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@
M:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`57-E
M<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI
M<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!6
M86QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E
M(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T
M(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N
M`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA
M;0!6:65T;F%M97-E("A625-#24DI`%9I97<`5FEE=R`E<P!6:65W("5S(%!U
M8FQI8R!+97D`5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD
M;W<`5FEE=R!097)S;VYA;"!0<FEV871E($ME>0!6:65W(%!E<G-O;F%L(%!U
M8FQI8R!+97D`5FEE=R!4:')E860`5FEE=R!4:'5M8FYA:6P`5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I97<@979E;G0`5FEE=R!M
M97-S86=E<R!I;B`E<P!6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E
M<B!L;V=I;CH`5FEE=R!T87-K`%9I97<@=&AE($EM86=E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7)T=6%L($9O
M;&1E<B`B)7,B(&-R96%T960@<W5C8V5S9G5L;'DN`%9I<G1U86P@1F]L9&5R
M<P!6:7)T=6%L(&9O;&1E<B!L86)E;`!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ
M(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@86YD($9U='5N
M80!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B
M>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!7
M97-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/P!7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@
M=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@
M87,@9&5L971E9#\`5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H
M('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E
M;G0M;6%I;"P@<VAO=6QD('=E('-A=F4@871T86-H;65N="!D871A/P!7:&EC
M:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+@!7:&ET96QI<W0`5VED=&@`5VED=&@@:6X@0U-3('5N
M:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED
M=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z
M`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8
M+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS
M`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!
M9W)E90!9;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O
M;&QO=VEN9R!A8V-O=6YT*',I.@!9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O
M(&$@;F5W(&9O;&1E<BX`66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@
M=&\@`%EO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+@!9;W4@
M87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I
M=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"X`66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B``66]U(&-A;B!N;W0@
M:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U
M(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M
M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"!T;R!L;V=I;BX`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R`%EO
M=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W
M:6YG(')E8VEP:65N=',Z("5S+@!9;W4@:&%V92`E<R!N97<@;65S<V%G97,N
M`%EO=2!H879E(#$@;F5W(&UE<W-A9V4N`%EO=2!H879E(&%T(&QE87-T(&]N
M92!A='1A8VAM96YT('-E;&5C=&5D('1H870@>6]U(&1I9&XG="!U<&QO860@
M>65T+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<V5N9"!T:&ES(&UE<W-A
M9V4@=VET:&]U="!T:&5S92!A='1A8VAM96YT<S\`66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG
M(&9O;&1E<CH`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F
M;VQD97)S.@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N
M=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T
M:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T
M851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE
M;G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;P!9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U
M<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4`66]U(&UU
M<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A
M=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E`%EO=2!M=7-T('-E;&5C="!A
M('1A<F=E="!M86EL8F]X(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@86-C
M;W5N="!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S96QE8W0@86X@861D<F5S
M<R!F:7)S="X`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE
M=&5D+@!9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER
M<W0N`%EO=2!M=7-T('-P96-I9GD@82!R96-I<&EE;G0N`%EO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@870@
M;&5A<W0@;VYE(&9I;&4@=&\@871T86-H+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T
M;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M`%EO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N`%EO
M=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RX`66]U('=E<F4@;F]T
M('-U8G-C<FEB960@=&\@(B5S(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@
M<V%I9`!9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(BX@2&5R
M92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!S=6-C97-S9G5L
M;'D@<W5B<V-R:6)E9"!T;R`B)7,B`%EO=2!W97)E('-U8V-E<W-F=6QL>2!U
M;G-U8G-C<FEB960@9G)O;2`B)7,B`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`
M66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@4$=0(%!U
M8FQI8R]0<FEV871E($ME>7,`66]U<B!0<FEV871E($ME>0!9;W5R(%!U8FQI
M8R!+97D`66]U<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S
M`%EO=7(@86-C;W5N=',Z`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U
M<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E
M('1Y<&4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-H
M87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO=7(@9&5F875L="!E;F-R
M>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!M97-S86=E('=A
M<R!S=6-C97-S9G5L;'D@9&5L:79E<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F
M;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`66]U
M<B!S:6=N871U<F4Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E
M`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L
M96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T)C8P!?0FQA8VML:7-T`%]#3$D`7T-C`%]$871A5')E90!?1&5L971E
M`%]$96QE=&4@4F]W`%]&;VQD97)S`%]'<F]U<',`7TAE;'``7TED96YT:71Y
M`%]);6%G92!0<F]P97)T:65S+BXN`%]);F)O>`!?3&]G(&EN`%],;V<@;W5T
M`%]-97-S86=E(%-O=7)C90!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E
M<FUI<W-I;VYS`%]0<FEN=`!?4')I;W)I='D`7U)E9G)E<V@@)7,`7U)E;6]V
M92!,:6YK+BXN`%]297!L>0!?4V5A<F-H`%]396YD($UE<W-A9V4`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]4:')E860`7U1O`%]5;F1E;&5T90!?
M57-E<G,`7U9I97<@5&AR96%D`%]7:&ET96QI<W0`861D<F5S<R!B;V]K`&%T
M=&%C:&UE;G0`871T86-H;65N=',N>FEP`&)Y=&5S`&-A;&5N9&%R`&-A;&T`
M8VQI8VL@:&5R90!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&ME>0!L:6YE<UT`;6%I;&)O>"!F
M:6QE`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!N
M86UE`&YO;F4`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`
M;F]T97!A9`!O<@!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E
M;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W!E;&QI;F<@97)R;W(`<W!E;&QI
M;F<@97)R;W)S`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@
M='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`
M=D-A<F0`=SH`=V5A=&AE<BYC;VT`>6]U<B!B;&%C:VQI<W0`>6]U<B!W:&ET
M96QI<W0`4')O:F5C="U)9"U697)S:6]N.B!)35`@-"XP+6-V<PI297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#0M,3$M,CD@,3@Z,S@K,#(P,`I,87-T+51R86YS;&%T;W(Z(%9I
M;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT/@I,86YG=6%G92U496%M.B!,
M:71H=6%N:6%N(#QV:6QI=7-`;&YK+FQT/@I-24U%+59E<G-I;VXZ(#$N,`I#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,3,*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("`@("`@2V%M.B``
M("`@($1A=&$Z(``@("`@3G5O.B``("AP<FEE\"`E<R!D:65N87,I`"`H37EG
M='5K87,@)7,I`"`H\&EA;F1I96XI`"`H=F%K87(I`"!496UA.B``(``@96EL
M=73K:F4@`",`)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0`E9"`E<R!I<B`E
M<P`E9"!L86GP:V%I*/@I(&YU<VGX<W1A(&%D;6EN:7-T<F%T;W)I=6D@:V%I
M<"!N92!N97!A9V5I9&%U:F%M:2`H<W!A;2DN`"5D(&QA:?!K86DH^"D@<&%S
M:V5L8G1I(&YE(&YE<&%G96ED875J86UA:7,@*'-P86TI+@`E9"!L86GP:V%I
M*/@I(&YU<VGX<W1A(&%D;6EN:7-T<F%T;W)I=6D@:V%I<"!N97!A9V5I9&%U
M:F%M:2`H<W!A;2DN`"5D(&QA:?!K86DH^"D@<&%S:V5L8G1I(&YE<&%G96ED
M875J86UA:7,@*'-P86TI+@!,86GP:V%I(&YU;R`E9"!I:VD@)60@:?`@)60`
M)60M9&EE;O@@<')O9VYO>NL`)7,@+2!P87-T86)A`"5S(&%N='-P875D87,`
M)7,@2T(`)7,@<')O9FEL86MT:6MO<R!V96EK<VUA:2`M('!A='9I<G1I;FEM
M87,`)7,@<F5G:7-T<F%C:6IA`"5S(&YU;W-T871O<P`E<R!J874@96=Z:7-T
M=6]J82X`)7,@:F%U(&5G>FES='5O:F$N($K[<_@@:V%T86QO9V%S("5S(&YE
M<&5R=F%R9&EN=&%S+@`E<R`E<R`E<P!086YA\'4L(&MA9"!K871A;&]G;R`E
M<R!NZW)A+@`E<R!K871A;&]G87,@<&5R=F%D:6YA;6%S(&WK;F5S:6\@<')A
M9/YI;VIE+@`E<R!P<FEI;71A<RX`)7,@;G5T<F%U:^L@)7,N`"5S(&)A:6?K
M<VDN`"5S(&%T<V%KZR#A('7^:6UT=6UO('7^:VQA=7/@+@`E<R!A='-A:^L@
MX2!P86MV:65T:6W@(.$@)7,N`"5S(&%T<VEU;G3K('7^:6UT=6UO(&EN9F]R
M;6%C:6K@+@`E<R!L86EK:6YA:2!P<FEI;71A<RX`)7,@>7)A('!R:79A;&]M
M87,`)7,@;6EN=73K<P`E<R!N97)A<W1A<RX`)7,@<')A\&\@:OMS^"!U_FEM
M='5M;R!I;F9O<FUA8VEJ;W,N`"5S('!R8?!O(&IU<R!D86QY=F%U=&D@)7,N
M`&YU;R`E<R!I:VD@)7,@:?`@)7,`)7,@;F]R:2!P87!I;&1Y=&D@)7,N`"5S
M(&YO<FD@<')A;F7P=&D@2G5M<R!A<&EE(&%R=.MJ86YTX2`E<RX`)7,@;F]R
M:2!G875T:2!N875J875S:>`@:6YF;W)M86-I:N`@87!I92`E<RX`)7,@861R
M97/X(&MN>6=E;.L`)7,@:V%L96YD;W)I=7,`)7,@=?YR8?#X(&MN>6=E;.L`
M)7,@9&%R8O@@<^!R8?!A<P`E<SH@)7,`)7,Z("5S("@E9"9N8G-P.VGP)FYB
M<W`[)60I`"A!=&QI:W1I(/!I=6]S('!A:V5I=&EM=7,@:7(@<&5R96ET:2!P
M<FEE(&MI=&\@;&%N9V\N*0`H073P875K=&D@=FES=7,@<&%K96ET:6UU<R!I
M<B!G<N'^=&D@X2!R8?!Y;6\@;&%N9^`N*0`H1W+A_G1I(.$@<F'P>6UO(&QA
M;F?@('!O('9I<_@@<&%K96ET:6WX(&%T;&EK:6UO+B!086ME:71I;6%I(&5S
M86UA;64@;&%N9V4@;F5B=7,@871L:6MT:2XI`"A)\'-I^'-T:2!L86GP:^`@
M<&\@=FES^"!P86ME:71I;?@@871L:6MI;6\N(%!A:V5I=&EM86D@97-A;6%M
M92!L86YG92!N96)U<R!A=&QI:W1I+BD`*B!.;W+K9&%M:2!P<FEDZW3A('-P
M875S:VET92!/2R`J`"H@4&%S:7)I;FMI=&4@861R97/@*'5S*2`J`"P@9_MS
M:6%I("5S("5S`"P@:VEN=&$@;G5O("5S(&EK:2`E<P`M+2!P87-I<FEN:VET
M92`M+0`Q(&QA:?!K87,@;G5S:?AS=&%S(&%D;6EN:7-T<F%T;W)I=6D@:V%I
M<"!N92!N97!A9V5I9&%U:F%M87,@*'-P86TI+@`Q(&QA:?!K87,@<&%S:V5L
M8G1A<R!K86EP(&YE(&YE<&%G96ED875J86UA<R`H<W!A;2DN`#$@;&%I\&MA
M<R!N=7-I^'-T87,@861M:6YI<W1R871O<FEU:2!K86EP(&YE<&%G96ED875J
M86UA<R`H<W!A;2DN`#$@;&%I\&MA<R!P87-K96QB=&%S(&MA:7`@;F5P86=E
M:61A=6IA;6%S("AS<&%M*2X`,3`P('-I;6)O;&GX`#$P,#`@<VEM8F]L:?@`
M,3(@=F%L86YD^"!F;W)M871A<P`R-"!V86QA;F3X(&9O<FUA=&%S`#(T('9A
M;&%N9&]S`#(U,"!S:6UB;VQI^``U,#`@<VEM8F]L:?@`T&EA;2!B;&]K=6D@
M<F5I:V%L:6YG82!V:65T82!D=6]M96[X(&)A>NMJ92X`P79Y:V\@<FEM=&$@
M:VQA:61A`%!R:64@\&EO(&QA:?!K;R!P<FEK86)I;G1A<R!D:61E;&ES('!A
M=F5I:W-LZVQI<R!P879A9&EN:6UU("5S+@!!=.MJ;R!P871V:7)T:6YI;6%S
M+"!K860@861R97-A=&%S(&=A=F\@:OMS^"!L86GP:^`N`$YO<NMD86UI('7^
M:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%!'4"!R
M86MTX"X`3F]RZV1A;6D@<&%T:6MR:6YT:2!P87-I<F'P>73@(&QA:?!KX"!P
M<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4$=0(')A:W3@+@!.;W+K9&%M:2!A
M=&MO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S
M;&%P=.!JX2!01U`@<F%K='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF
M+@!.;W+K9&%M:2!P87-I<F'P>71I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I
M('9I9?#@:N$@:7(@<VQA<'3@:N$@4$=0(')A:W1U<RP@8F5I(/YI;F]T:2!S
M;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@871K;V1U;W1I(&QA:?!KX"!P<FEV
M86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%(')A:W1U
M<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@<&%S:7)A
M\'ET:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!T
MX&KA(%,O34E-12!R86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N
M`$YO<NMD86UI('7^:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V
M:67PX&KA(%,O34E-12!R86MTX"X`04T@<F]D>6UA<P!!32]030!)4@!!4$D@
M240`07!I92#PX2!R961A:W1O<FGX`$%P:64N+BX`5FES:?!K86D@87!AZ&EO
M:F4`5FES:?!K86D@<&5R('9I9'5RX0!0<FEI;71I('7^:VQA=7/@`%!R:6EM
M=&$`4VES=&5M82!N971U<FD@=&5I<VGX('-U:W5R=&D@5D93(&MA=&%L;V?@
M+@!3:7-T96UA(&YE='5R:2!T96ES:?@@<W5K=7)T:2!61E,@9F%I;.`N`%-L
M87!T8?YO9&ES`%/@<VMA:71A('7^\&%L9'ET82X`4&'P=&\@9.O^=73K<R!P
M879A9&EN:6UA<SH`07!S:V%I=&$`5F5I:W-M86D`4W5K=7)T:0!3=6MU<G1I
M('!O9W)U<.$`4W5K=7)T:2!P;W1E:7-E<P!";&]K;R#A=&5R<&EM87,Z`%-U
M:W5R=&D@;F%U:N`@9W)U<.8`4W5K=7)T:2!N875J87,@=&5I<V5S`$YA=6IO
M('9A<G1O=&]J;R!S=6O[<FEM87,Z`%!R:63K=&D@<W1U;'!E;.$`3F%U:O@@
M;F%R:?@@<')I9.MJ:6UA<P!3=6MU<G1I('!O<N``4')I9.MT:2#P86QT:6[A
M`%!R:63K=&D@)7,@;65N:74@<')I92!-;WII;&]S(.%R86YK:?@@:G5O<W1O
M<P#!<F'P>71I('1A:2#A(&UA;F\@:V%L96YD;W)I^`#!=')A=6MT:2#A(&%D
M<F5S^"!K;GEG96SF.@#!=')A=6MT:2#A(&UA;F\@861R97/X(&MN>6=E;.8Z
M`%-U:W5R=&D@=F%R=&]T;VK@`$9A:6QA<R`B)7,B('!R:6MA8FEN=&%S+@!6
M87)T;W1O:O@@:_MR:6UA<R!I\&IU;F=T87,N`%!A<&EL9&]M;W,@:6YF;W)M
M86-I:F]S('!E<OYI^W)A("5S+@!087!I;&1O;6$@:6YF;W)M86-I:F$@9&5T
M86QI874`4&%P:6QD;VUA(&QA:?!K;R!I;F9O<FUA8VEJ80!087!I;&1O;6]S
M(&EN9F]R;6%C:6IO<R!P97+^:?MR82`E<RX`1&5T86QI(&EN9F]R;6%C:6IA
M(&%P:64@:VQA:63@`%!A<&EL9&]M;W,@:6YF;W)M86-I:F]S(&%P:64@:VQA
M:63@('!E<OYI^W)A("5S+@!!9')E<V%S`$%D<F5S^"!K;GEG96SK`$%D<F5S
M^"!K;GEG96SK<P!!9&UI;FES=')U;W1I("T@9V%L:2!N=7-T871Y=&D@=&5I
M<V5S(&MI=&EE;7,@=F%R=&]T;VIA;7,`5F%L9'EM87,`0F%N97)I86D`069G
M86YI<W1A;F%S`$%L8F%N:6IA`$%L_GER87,`4')A=F%R9.L`3'EG:75O=&D`
M3'EG:6%V:6UA<SH`5FES:^``5FES:2!P<FES:6IU;F?F('9A<G1O=&]J86D`
M5FES;W,@9W)U<.MS`%9I<V]S('1E:7/K<P!6:7-O<R!K971U<FEO<R!P=7/K
M<P!6:7-I(&QA:?!K86D@<V5K86[H:6%M92AI=6]S92D@:V%T86QO9V4H=6]S
M92D@8G5S('!E<FME;'1I(.$@=FEE;N`@34)/6"!F86ELX#H`5FES:2!L86GP
M:V%I(&MA=&%L;V=E("(E<R(@:7(@<V5N97-N:2!N96D@)7,@9&EE;O@@8G5S
M(&GP=')I;G1I+@!6:7-I('-E;F5S;FD@;F5I("5S(&WK;F5S:6%I('-U<VEJ
MYB!P<FEK86)I;G1I(&9A:6QA:2!B=7,@:?!T<FEN=&DN`%9I<VD@<V5N97-N
M:2!N96D@)7,@;>MN97-I86D@<VGX<W3X(&QA:?!K^"!K871A;&]G86D@8G5S
M(&GP=')I;G1I+@!,96ES=&D@=&%I:WET:2!F:6QT<G5S(&)E="!K=7)I86UE
M(&MA=&%L;V=E/P!,96ES=&D@:V5L973@(&%D<F5S^`!,96ES=&D@;F%U9&]T
M:2!S=7+[\&EU;W3@('/@<F'PX#\`2F%U(&5G>FES='5O:F$`06QT97)N871Y
M=G5S($E-4U`@<')I<VEJ=6YG:6UA<P!!;'1E<FYA='EV=7,@24U34"!S;&%P
M=&'^;V1I<P!!;'1E<FYA='EV=7,@24U34"!V87)T;W1O:F\@=F%R9&%S`$%L
M=&5R;F%T>79U<R!E;"X@<&'P=&\@861R97-A<P!!;'1E<FYA='EV^W,@\&%B
M;&]N86D`06QT97)N871Y=G5S('1E:W-T87,`2VET;W,@9&%L>7,Z`%9I<V%D
M80!6:7-A9&$@:?!S875G;W1I('!R:6MA8FEN='5S(&9A:6QU<P!!;65R:6MO
M<R!386UO80!+;&%I9&$@8F%N9&%N="!I\'1I;G1I('!R:6MA8FEN=.`@9F%I
M;.`N($E-05`@<V5R=F5R:6\@:VQA:61A.@#!=F5DZW1E(&YE;&5I<W1I;N`@
M<F5I:_!MYBX`4')I9&5D86YT(&YA=6K@(&1A<F+@(.%V>6MO(&ML86ED82X`
M06YD;W)A`$%N9V]L80!!;F=I;&%I`$%N;VYI;6EN:7,@<')O>'D@<V5R=F5R
M:7,`071S86MY;6%S`$%T<V%K>71I`$%T<V%K>71I(&QA:?!K86D`06YT87)K
M=&ED80!!;G1I9W5A(&ER($)A<F)U9&$`36]D=6QI<P!-;V1U;&ES('9E:6MI
M82!G97)A:2X`07(@9FEL=')U;W1I(&QA:?!K=7,@<')I<VEJ=6YG:6UO(&UE
M='4_`$%R(&9I;'1R=6]T:2!L86GP:W5S(&MI96MV:65NX"!K87)TX"!K86D@
M<&%R;V1O;6%S($E.0D]8/P!0<FET86EK>71I(&ER('!O\&%K:6%M<P!0871V
M:7)T:6YT:0!"86QA;F1I<P!!<F%B:?!K82`H5VEN9&]W<RTQ,C4V*0!!<F-H
M>79O(&9A:6QO(&1Y9&ES`$%R8VAY=F\@9F%I;&\@<&%V861I;FEM87,`07(@
M=&EK<F%I(&YO<FET92!I\'1R:6YT:2#PX2!V:67PX&KA(')A:W3@/P!!<B!T
M:6MR86D@;F]R:71E(&GP=')I;G1I('-A=F\@<F%K=/@@<&]RX#\@*$Y%4D5+
M3TU%3D153TI!34$A*0!!<B!T:6MR86D@;F]R:71E('1A:2!P861A<GET:3\`
M07(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2`E<R!R96=I<W1R86-I:F]S('!R
M8?!Y;>`_`$%R('1I:W)A:2!N;W)I=&4@2=!44DE.5$D@\&EU;W,@;&%I\&MU
M<S\`07(@=&EK<F%I(&YO<FET92!)T%1224Y422!P<FEK86)I;G3@(&9A:6S@
M/P!!<B!T:6MR86D@;F]R:71E(&GP=F%L>71I(/#A(&MA=&%L;V?@/P!!<B!T
M:6MR86D@;F]R:71E(&GP=F%L>71I(/!I=6OP;&EA9.O^YC\`07(@=&EK<F%I
M(&YO<FET92!)T%1224Y422#P:75O<R!L86GP:W5S/P!!<B!T:6MR86D@;F]R
M:71E('!A<VME;&)T:2#PX2!L86GP:^`@:V%I<"!N92!N97!A9V5I9&%U:F%M
MX#\`07(@=&EK<F%I(&YO<FET92!P87-K96QB=&D@\.$@;&%I\&O@(&MA:7`@
M;F5P86=E:61A=6IA;>`_`$%R9V5N=&EN80!!<FWK;FEJ80!!<FWK;FGP:V$@
M*$%235-#24DM."D`1V%U=&$`365N87,`07)U8F$`1&EDZVII;6\@='9A<FMA
M`$MR:7-T875S(/YE;F=I;6\@X2!D86YG^"!S86QA`$%C<VEI(&UE;F%S`$%Z
M:6IA+U)A;6EO:F\@=F%N9&5N>6YO(')E9VEO;F%S`$ML875S=&D`07(@<')A
M\'ET:2!P871V:7)T:6YT:2!P<F]F:6QA:W1I:V]S('9E:6MS;75S/P!0<FES
M:WER:6UO('-T=6QP96QI86D`4')I:V%B:6YT:0!0<FEK86)I;G1I(&9A:6QU
M<P!!<B!P<FEK86)I;G1I(&K[<_@@=FEE\.!JX2!01U`@<F%K=.`@<')I92!L
M86GP:V\_`%!R:6MA8FEN=&$Z`$9A:6QA<R`B)7,B('9I<O!Y:F\@;&5I<W1I
M;N`@9'EDX2X@1F%I;&%S($Y%4%))2T%"24Y405,N`%!R:6MA8FEN=&%S(&9A
M:6QA<R!Y<F$@871S86MY;6%S(.$@:OMS^"!I0V%L96YD87(@=?YK;&%U<^`N
M`$9A:6QA<P!0<FEK86)I;G1A<R!F86EL87,@:?!T<FEN=&%S.B!F86EL;R!T
M:7!A<P!0<FEK86)I;G1I(&9A:6QA:0!"86YD;W1E(&GP=')I;G1I(&YE96=Z
M:7-T=6]J86[H:>`@9W)U<.8N`$)A;F1O=&4@:?!T<FEN=&D@;F5E9WII<W1U
M;VIA;NAI87,@=&5I<V5S+@!"86YD;W1E(')E9&%G=6]T:2!N965G>FES='5O
M:F%NZ&EA<R!T96ES97,N`$)A;F1O=&4@<F5D86=U;W1I(&YE96=Z:7-T=6]J
M86YTX2!E;&5M96YTX"X`4W5S:6KF(/YM;V[K<P!$ZVUE<VEO`$%T<FEB=71A
M:0!2=6=P:OMT:7,`075S=')A;&EJ80!!=7-T<FEJ80!!=71H7V-Y<G-Q;#H@
M;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+@!!=71H7V-Y<G5S
M.B!C>7)U<R!N971U<FD@<F5I:VEA;?@@9V%L:6UY8FGX+@!!=71H7V-Y<G5S
M.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0(&UO9'5L:7,N`$%U=&A?9G1P
M.B!N97)A<W1A<R!R96EK86QI;F=A<R!&5%`@;6]D=6QI<RX@4W5K;VUP:6QI
M=6]K:71E(%!(4"!S=2`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@;F5R87-T
M87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+@!!=71H7VEM<#H@;F5R87-T
M87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+@!!=71H7VMR8C4Z(&YE<F%S
M=&%S(')E:6MA;&EN9V%S(&MR8C4@;6]D=6QI<RX`075T:%]L9&%P.B!N97)A
M<W1A<R!R96EK86QI;F=A<R!,1$%0(&UO9'5L:7,N`$%U=&A?;&1A<#H@<W5K
M=7)T:2!V87)T;W1O:N`@)7,@;F5P879Y:V\N(%-E<G9E<FEO('!R86YE\&EM
M87,Z(`!!=71H7VQD87`Z(&GP=')I;G1I('9A<G1O=&]JX"`E<R!N97!A=GEK
M;P!!=71H7VQD87`Z(&%T;F%U:FEN=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO
M`$%U=&A?;6-A;#H@;F5R87-T87,@<F5I:V%L:6YG87,@34-!3"!M;V1U;&ES
M+@!!=71H7W-M8F%U=&@Z(&YE<F%S=&%S(')E:6MA;&EN9V%S('-M8F%U=&@@
M;6]D=6QI<RX`4')I<VEJ=6YG=&D@;F5P879Y:V\`4')I<VEJ=6YG=&D@;F5P
M879Y:V\N("5S`%)!1$E54R!S97)V97)I<R!N96QE:63^:6$@875T96YT:69I
M:W5O=&ES+@!0<FES:6IU;F=T:2!P<FEE($944"!S97)V97)I;R!N97!A=GEK
M;RX`075T;VUA=&GP:V%I(')O9'ET:2!P879E:6MS;.ML:75S($A434P@;&%I
M\&MU;W-E+"!J96EG=2!S:75N=.MJ87,@>7)A(&UA;F\@861R97/X(&MN>6=E
M;.MJ93\`1V%L:6UO<R!A9')E<_@@:VYY9V5LZW,Z`$=A;&EM:2!L875K86DZ
M`$QA=6MI86UA(&%T<V%K>6UO`$%Z97)B86ED_F%N87,`0D]&2"!A='-I<')A
M\'EM86D`1W+A_E]T:2#A("5S`$=RX?YT:2#A("5S`$9O;F%S`$9O;F\@<W!A
M;'9A`$YE=&5I<VEN9V%S(&ME<F)E<F]S('-L87!T8?YO9&ES+@!.971E:7-I
M;F=A<R!K97)B97)O<R!V87)T;W1O:F\@=F%R9&%S+@!"86AA;6%I`$)A:')E
M:6YA<P!"86QT:?!K82`H25-/+3@X-3DM,3,I`$)A9VQA9&7P87,`0F%R8F%D
M;W-A<P!086=R+B!L:6YI:F]J90!"8V,`0F%L=&%R=7-I:F$`0F5L9VEJ80!"
M96QI>F%S`$1E=&%L=7,@;&%I\&MO('1E:W-T87,`0F5N:6YA<P!"97)M=61A
M:0!"=71A;F%S`$=I;71A9&EE;FES`$)L;VMU;W1I`$)L;VMO('!A<F%M971R
M86D`0FQO:V\@=&EP87,`0FQO:W5O=&D@<&%V96EK<VSK;&EU<R!(5$U,(&QA
M:?!K=6]S92P@;F5B96YT(&)U=F\@<&%R96EK86QA=71A(&MI=&%I<#\`3&%I
M\&MO('1U<FEN>7,`4&%S=&]R:6YT:0!";VQI=FEJ80!!=/YY;6]S`$MR8?!T
M87,`2W)A\'1O('-T;W)U;6%S.@!+<F'P=&%I`$)O<VYI:F$@:7(@2&5R8V5G
M;W9I;F$`06)U`$ER(&%N=')A\'3K<R!I<B!L86GP:V\@=&5K<W1A<P!";W1S
M=F%N80!!<&'H:6]J90!"=79E="!S86QA`$)R87II;&EJ80!"<FET^"!);F1I
M:F]S('9A;F1E;GEN;R!T97)I=&]J80!"<G5NZVIA=7,@9&%R=7-A;&5M87,`
M0G5L9V%R:6IA`%-U_GEMZW1A<R!SX')A\&%S`$)U<FMI;F%S($9A<V%S`$)U
M<G5N9&EJ80!45E,`0U)#`$-23"!P87-K:7)S='EM;R!P=6YK=&%I`%]#96SK
M<R!N=7-T871Y;6%I+BXN`$M?;V1U;W3K`$MA;&5N9&]R:75S`%)A;74`2V%M
M8F]D_F$`2V%M97+[;F%S`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@;G5T
M;VQU<VEO('!A\'1O('-E<G9E<FEO+@!.97!A=GEK;R!P<FES:6IU;F=T:2!P
M<FEE(&YU=&]L=7-I;R!P8?!T;R!S97)V97)I;SH@`$YE<&%V>6MO('!A<F]D
M>71I(/!I;R!L86GP:V\@+2#P:6]J92!DZ_YU=.MJ92!R87-T82!T:6L@)7,@
M9&%L:7,@:?`@)7,N`$YE=F5I:VEA(&%U=&]M871I;FES('-L87!T8?YO9/YI
M;R!P86ME:71I;6%S+"!S=7-I<VEE:VET92!S=2!A9&UI;FES=')A=&]R:75M
M:2X`3F5G86QI=2!P<FES:6IU;F=T:2!P<FEE($E-05`@<V5R=F5R:6\Z("5S
M`$MA;F%D80!.=71R875K=&D`071S:7-A:WET:2!L86GP:V\`073P875K=&D@
M<')O8FQE;6]S('!R86YE\&EMX`!!='-I<V%K>61A;6D@;&%I\&MO(&K[<R!P
M<F%R87-I=&4@=FESX"!J;R!T=7)I;N$N`$YE9V%L:74@:?!T<FEN=&D@9F%I
M;&\@(B5S(BX`3F5G86QI=2!R87-T:2!L86EK:6YO:F\@:V%T86QO9V\N`$YE
M9V%L:74@87!D;W)O=&D@)W1A<F=E=$9I;&4G('!A<F%M971R;RX`3F5G86QI
M=2!I\'1R:6YT:2!K871A;&]G;R`B)7,B+@!.96=A;&EU(&GP=')I;G1I+B!%
M9WII<W1U;VIA("5D('!O\&%K:6%I+@!.96=A;&EU('!E<G+[\&EU;W1I+B#!
M=F5S=&%S(.%R8?#X('-K86GH:75S(&YE<W5T86UP82!S=2#A<F'P^"!S:V%I
MZ&EU;6D@9'5O;65N^"!B87KK:F4N`$YE9V%L:74@;G5K<F5I<'1I(/YI;G5T
MZW,@X2!N=7)O9'ETX"!N=6UE<N$N`$ME:7!V97)D:7,`4&%V861I;FEM87,`
M2V%T96=O<FEJ;W,`2V%I;6%N^"!S86QO<P!#8P!-;V)I;'5S('1E;&5F;VYA
M<P!#96SK<R!N=7-T871Y;6%I`%1A<G!A:2!C96SK<V4Z`$-E;.MS(&YU<W1A
M='EM86D`5&%R<&%I('1A<G`@8V5L:?@Z`$UO8FEL=7-I<R!T96QE9F]N87,`
M2V5L=/@@*$E33RTX.#4Y+3$T*0!#96YT<F4`0V5N=')I;NMS($%F<FEK;W,@
M4F5S<'5B;&EK80!#96YT<FENZW,@175R;W!O<R`H25-/+3@X-3DM,BD`4V5R
M=&EF:6MA=&\@9&5T86SK<P!397)T:69I:V%T;R!T96ESZW,`R&%D87,`5F%D
M;W9A<P!086ME:7-T:0!086ME:7-T:2!V:7-U<P!086ME:7-T:2!K871A;&]G
MX`!686EZ9&%V:6UO+"!T;VMI^"!K86EP+"!K:65K(&QA:?!K^"!R;V1Y=&D@
M=FEE;F%M92!L86YG92!I<B!K86EP(&QA:?!K86D@='5R:2!B^W1I('-U<OOP
M:75O=&DL(&YU<W1A='EM86DN`%!A\'1O('-E<G9E<FEO(&ER(&MA=&%L;V?X
M(&YU<W1A='EM86DN`$K[<_@@=F%R9&\@:7(@861R97-O+"!K=7)I=6]S(&UA
M='ES(/YM;V[K<RP@<VMA:71A;G1Y<R!I<B!A='-A:VENZVIA;G1Y<R#A($K[
M<_@@;&%I\&MU<RP@:V5I=&EM87,N`%9A<F1O+"!A9')E<V\@:7(@<&%R8?!O
M+"!K=7)I=6]S(&UA='ES(/YM;V[K<RP@<VMA:71A;G1Y<R!I<B!A='-A:VEN
MZVIA;G1Y<R#A($K[<_@@;&%I\&MU<R!N=7-T871Y;6%I+@!3:6UB;VQI<P!2
M;V1Y=&DZ`%!A7W1I:W)I;G1I(&YU;W)O9.`N+BX`5&EK<FEN=&D@87(@>7)A
M(&YA=6KX(&QA:?!K^`!085_^>6WK=&D@=FES=7,O;FEE:V\`4&%S:7)I;FMI
M=&4@<V5R=F5R:75S(&GP(&MU<FGX(&YO<FET92!P86EM=&D@;&%I\&MU<SH`
M5&EK<FEN=&D@:VQA:61A<R!P<FEE\"!I\'-I=6[H:6%N="!L86GP:^`_`,AI
M;.L`2VEN:6IA`$MI;FEE=&GP:V$@<&%P<F%S=&$@*$=",C,Q,BD`2VEN:65T
M:?!K82!T<F%D:6-I;NL@*$)I9S4I`%!A<VER:6YK:71E('9E:6MS;>`Z`%!A
M<VER:6YK:71E('!A\'1O('-E<G9E<N$Z`%!A<VER:6YK:71E('-L87!T8?YO
M9.$`4&%S:7)I;FMI=&4@=F%R=&]T;VIO('9A<F3@`%!A<VER:6YK:71E('9E
M:6MS;>`Z`%!A<VER:6YK:71E(&MA:7`@=F%I>F1U;W1I(&1A=&%S.@!087-I
M<FEN:VET92!S=7+[\&EU;W1O('/@<F'P;R!S=&EL:?@`4&%S:7)I;FMI=&4@
M861R97/X(&MN>6=E;.8L(&MU<FG@(&YA=61O<VET92!P<FEDZV1A;6D@861R
M97-U<RX`4&%S:7)I;FMI=&4@861R97/X(&MN>6=E;&GX('1V87)KX"P@;F%U
M9&]J86W@(&%D<F5S^"!P871I:W)I;FEM=6DN`$MA;.MD^"!S86QA`$ML87/K
M<R`E<R!NZW)A+@!':65D<F$`2?!T<FEN=&D@35,@3V9F:6-E(/YY;65S`%9A
M<G1O=&]J;R!D=6]M96[X('9A;'EM87,Z("5S`$GP=F%L>71I('9A<G1O=&]J
M;R!D=6]M96YI<P!)\'9A;'ET:2!V87)T;W1O:F\@9'5O;65N:7,`3F]RZV1A
M;6D@<&%K96ES=&D@<&%V96EK<VSK;.$@X2!F;W)M873@+"!K=7+A('-U<')A
M;G1A(&K[<_@@;F%R\'EK;.LL('-P875S:VET92`E<RX`3F]RZV1A;6D@871S
M:?AS=&D@<&%V96EK<VSK;.$L('-P875S:VET92`E<RX`4W!A=7-K:71E("5S
M+"!N;W+K9&%M:2!P871E:W1I(.$@)7,@=F%L9'EM;R!P=7-L87#A+@!.;W+K
M9&%M:2!P86UA='ET:2!(5$U,('1U<FENX2!A='-K:7)A;64@;&%N9V4L('-P
M875S:VET92`E<RX`3F]RZV1A;6D@<&%M871Y=&D@;6'^97-NX2!P879E:6MS
M;.MLX2P@<W!A=7-K:71E("5S+@!005)/1%E422!P879E:6MS;.ML:75S`%!E
M;&4@<&'^>6WK:VET92!V:65NX"!I\"!*^W/X(&%D<F5S^"!K;GEG96QI^"P@
M;R!P;R!T;R!P87-I<FEN:VET92!L875K=7,@<&%I9?!K86DN`%3F<W1I`%-P
M875S:VET92#H:6$@:F5I(&YO<FET92!I\'-A=6=O=&D@4$=0('9I9?#@:N$@
M<F%K=.`@861R97/X(&MN>6=E;.MJ90!#;&EC:V%T96QL('!E<B!(5%10`%!A
M<W!A=63F(&%N="!A9')E<V\L('-U:W5R<VET92!N875JX"!L86GP:^`@861R
M97-A='5I`%!A<W!A=63F(&%N="!A9')E<V\L(&%T:61A<GES:71E(&QA:?!K
MX"!S:V%I='EM=6D`5?YD87)Y=&D`5?YD87)Y=&D@;&%N9^``5?YD87)Y=&D@
M\.$@;&%N9^``5?YD87)Y=&%S(&MA=&%L;V=A<P!$96)E<W5O=&$`1&5B97-U
M;W1A`$MO:V]S;R`H2WEL:6YG;RD@<V%L;W,`4W5S:VQE:7-T:0!3=7-K;&5I
M<W1I('9I<VO@`%-U<VML96ES=&D@=FES=7,@:V%T86QO9W5S`%-U<VML96ES
M=&D@:V%T86QO9^``5'7PZ&GX(&-E;&GX(&MR8?!T^"!R;V1Y;6%S`$MO;'5M
M8FEJ80!3<&%L=F$`4W!A;'9O<R!I;F1I:V%T;W)I=7,Z(`!087-I<FEN:VET
M92!S<&%L=N``4W!A;'9O<R!P87-I<FEN:VEM87,`4W1U;'!E;&EA:3H`4W1U
M;'!E;&GX('!A=F%D:6YI;6%I`$MO;6EK<V%I`$MO;6%N9&$`2V]M86YD:6[K
M(&5I;'5TZP!+;VUE;G1A<F%S`%9A<F1A<R]P879A<F3K`$MO;6]R86D`2V]M
M<&%N:6IA`$%T;&EK=&$`4F'P>71I(&1A<B!V:65NX"!L86GP:^``4F'P>71I
M(&QA:?!K=7,@871S:VER86UE(&QA;F=E/P!28?!Y=&D@;&%I\&MU<R!(5$U,
M(&9O<FUA='4@*&IE:6=U(&YA<O!Y:VSK('!A;&%I:V\@\&G@(&9U;FMC:6K@
M*3\`2V]M<&EU=&5R:6%I`%/@;'EG;W,`3G5S=&%T>6WX('!A:V5I=&EM86D`
M2V]N9FEG^W)U;W1I("5S`$QA:?!K^"!R;V1Y;6\@;G5S=&%T>6UA:2X`2?!A
M;FMS=&ENZW,@;&%I\&OX('!E<OYI^W)O<R!N=7-T871Y;6%I+@!3;&%P=&'^
M;V1I<R!D87(@:V%R=.``2V]N9V%S`$1E;6]K<F%T:6[K($MO;F=O(%)E<W!U
M8FQI:V$`4')I<VEJ=6YG=&D@;F5P879Y:V\N`%!R:7-I:G5N9W1I(&YE<&%V
M>6MO.B``4')I<VEJ=6YG=&D@<')I92!V:67P^&KX(')A:W3X('-E<G9E<FEO
M(&YE<&%V>6MO+@!0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R
M=F5R:6\@;F5P879Y:V\L(&YE<SH@)7,@*"5S*0!0<FES:6IU;F=T:2!P<FEE
M($944"!S97)V97)I;R!N97!A=GEK;RX`3F5P879Y:V\@<')I<VEJ=6YG=&D@
M<')I92!S97)V97)I;P!+;VYK86MT86D@<^MK;6EN9V%I(.%T<F%U:W1I(.$@
M2OMS^"!A9')E<_@@:VYY9V5LY@!4YG-T:0`E<R!01U`@<&%L86EK>6UO('9A
M;&1Y;6%S+@`E<R!3+TU)344@<&%L86EK>6UO('9A;&1Y;6%S+@!.875J;R!P
M8?!T;R!T:6MR:6YI;6\@:7(@<')A;F7P:6WX(&%P:64@=&%I(&YU<W1A='EM
M86DN`$MO;G9E<G1U;W1I('1E:W-T:6YE<R#P>7!S96[K;&5S(.$@9W)A9FEN
M97,_`$MU:V\@<V%L;W,`3&%I;>MS(/YI;G5TZW,`2V]P:6IU;W1I`$MO<&EJ
M=6]T:2!P87-I<FEN:VEMX`!+;W!I:G5O=&D@X2!K871A;&]GX`!486ES>71I
M`%1A:7-Y=&%S('1E:W-T87,`2V]S=&$@4FEK80!$<F%M8FQI;R!+875L;R!+
M<F%N=&%S`$YE<&%V>6MO('7^:V]D=6]T:2!01U`@;&%I\&MO+@!.97!A=GEK
M;R!P87-I<F'P>71I(%!'4"!L86GP:V\N`$YE<&%V>6MO('7^:V]D=6]T:2!3
M+TU)344@;&%I\&MO+@!.97!A=GEK;R!P87-I<F'P>71I(%,O34E-12!L86GP
M:V\N`$YE<&%V>6MO('!R:63K=&D@:V]N=&%K=&\N("5S`$YE<&%V>6MO(&%U
M=&5N=&EF:6MU;W1I<R#A($Q$05`@<V5R=F5RX2X`3F5P879Y:V\@<&%T:6MR
M:6YT:2!B86QA;G-O+B`E<P!.97!A=GEK;R!S=6MU<G1I(&1I<W1R:6)U8VEJ
M;W,@<^!R8?!O+B`E<P!.97!A=GEK;R!S=6MU<G1I(%9&4R!P;W-I<W1E;>MS
M.B`E<P!.97!A=GEK;R!A=&MO9'5O=&D@4$=0(&1U;VUE;O@N`$YE<&%V>6MO
M(&%T:V]D=6]T:2!3+TU)344@9'5O;65N^"X`3F5P879Y:V\@:?!T<FEN=&D@
M:V]N=&%K=&\N("5S`$YE<&%V>6MO(&GP=')I;G1I(&1I<W1R:6)U8VEJ;W,@
M<^!R8?!O+B`E<P!.97!A=GEK;R!I\'1R:6YT:2!L86GP:_@@:?`@)7,N(%-E
M<G9E<FEO(&ML86ED83H@)7,`3F5P879Y:V\@;G5S=&%T>71I(&=A=NMJ;R!E
M;"X@<&'P=&\@861R97-O+@!.97!A=GEK;R!A=&QI:W1I('!R;V9I;&%K=&EK
M;W,@=F5I:W-M^"X`3F5P879Y:V\@:?!A<F-H>79U;W1I(&YU<F]D>71O(&9A
M:6QO(&GP($U3+51.148@9F]R;6%T;RX`3F5P879Y:V\@:?!A<F-H>79U;W1I
M(%II<"!A<F-H>79O+@!0879Y:V\@9V%U=&D@=FES;W,@861R97/X(&MN>6=E
M;.MS+@!.97!A=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?!O
M+@!.97!A=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?#X('/@
M<F'P;RX`3F5P879Y:V\@9V%U=&D@=FEE\&]J;R!R86MT;R!I\"!R86MT^"!S
M97)V97)I;RX`3F5P879Y:V\@871I9&%R>71I("5S+@!.97!A=GEK;R!A=&ED
M87)Y=&D@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&EO("5S`$YE<&%V>6MO('-K
M86ET>71I("5S+@!.97!A=GEK;R!P86ME:7-T:2!S;&%P=&'^;V3^:6\@\&EA
M;2!V87)T;W1O:G5I+B!+86D@:W5R:2!A<F)A('9I<V$@:6YF;W)M86-I:F$@
M>7)A(&YE=&EK<VQI+B!086)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S=7-I
M<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA
M;&EN9V$@<&%G86QB82X`3F5P879Y:V\@9V%U=&D@04-,`$YE<&%V>6MO(&=A
M=71I(&%D<F5S^"!K;GEG96SK<RX@)7,`3F5P879Y:V\@9V%U=&D@9&ES=')I
M8G5C:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ
M;W,@<^!R8?#X+B`E<P!.97!A=GEK;R!N=7-T871Y=&D@<V5R=F5R:6\@9V%L
M:6UY8FGX`$YE<&%V>6MO(&%T:V5I<W1I(&YU<W1A='EM^"X`3F5P879Y:V\@
M:?!S875G;W1I("5S(&YU<W1A='EM^"X`3F5P879Y:V\@<&%D87)Y=&D@871S
M87)G:6[K<R!N=7-T871Y;?@@:V]P:6IO<RX`3F5P879Y:V\@<&%I9?!K82!,
M1$%0('-E<G9E<GEJ92X`3F5P879Y:V\@871N875J:6YT:2!K;VYT86MT;RX@
M)7,`3F5P879Y:V\@871N875J:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@
M)7,`3F5P879Y:V\@<F%S=&D@36]Z:6QO<R#A<F%N:VGX(&IU;W-T;W,N(,%S
M:71I:VEN:VET92P@:V%D(&II(&%T:61A<GET82X`4FEB;W1A<R!T96MS=&%S
M`%9A;'-T>6+K`$MU<G-A:0!3=6MU<G1I`%-U:W5R=&D@:V%T86QO9^``4W5K
M=7)T:2!R86MT=7,`4W5K=7)T:2!V:7)T=6%L^"!K871A;&]GX`!3=6MU<G1I
M(&YU;W)O9.``4W5K=7)T:2!N875JX"!P87)U;_!I;FGX(&MA=&%L;V?@`%-U
M:W5R=&D@;F%U:N`@87!R8?#@`%-U:W5R=&D@;F%U:N`@<VGX<W3X(&QA:?!K
M^"!K871A;&]GX`!3=6MU<G1I(&YA=6K@(/!I=6OP;&EA9.O^Y@!&:6QT<F%V
M:6UO('1A:7-Y:VQI^"!S=6MU<FEM87,L(&%T96EN86[H:6\@<&'P=&\@='9A
M<FMY;6%S+"!I\'+[\&EU;VIA;G0@:N$@X2!K871A;&]G=7,@:7(@:?!T<FEN
M86YT(&YE<&%G96ED875J86UU<RX`4W5K=7)T:2!P86MA=&%L;V=I=7,`4V%V
M:6YI;FMO('1E:7/K<P!+<F5D:71I;NMS(&MO<G1E;.MS(&YU;65R:7,`2W)O
M871I:F$`2W5B80!$86)A<G1I;FES(&QA:6MA<P#0:75O(&UE='4@55),('ER
M80!$86)A<G1I;NMS(&]R;R!SX&QY9V]S`$1A8F%R=&ENZW,@=&5I<^MS(.$@
M)7,`1&%B87)T:6[K<R!SX&QY9V]S.B``1&%B87)T:6YI<R!S=&EL:75S`$QA
M:?!K^"!P8>MM:6UO(&GP(&MI=/@@<&'P=&\@9.O^=>AI^"!N=7-T871Y;6%I
M+@!3:75NZ&EA;?@@;&%I\&OX(&YU<W1A='EM86DN`%9E:6MS;?@L(&%T;&EE
M:V%M^"!P<FES:6IU;F=U<R!P<FEE("5S+"!N=7-T871Y;6%I+@!097)K96QT
M:0!097)K96QT:2!P87-I<FEN:VEMX`!+:7!R87,`2VER:6QI8V$@*$M/23@M
M4BD`2VER:6QI8V$@*%=I;F1O=W,M,3(U,2D`2VER:6QI8V$O56MR86EN:65T
M:?!K82`H2T])."U5*0#(96MI:F]S(%)E<W!U8FQI:V$`1$0`2V%S9&EE;@!$
M7V%T80!$=6]M96[X(&UE9/YI;R!N87+P>6MLZP!$871A`$=A=71A`$1A=&]S
M('!A<VER:6YK:6UA<P!$:65N80!)\'1R:6YT:2!?<W1U;'!E;.$`1W)U;V1I
M<P!$9?!I;71A:6YI86D@<VMA:>AI86D`071M97-T87,`4W5M8?YI;G1I(&%T
M:71R875K:6W@`%-T86YD87)T:6[K('-P86QV80!3=&%N9&%R=&EN:7,@87!R
M8?!A<P!2^_!I=6]T:2!P86=A;#H`4OOP:6%V:6UO(&MR>7!T:7,Z`$%P:6)R
MZ_YI;6%I`$%T<W1O=F%U:F%M87,`2?!T<FEN=&D`2?!T<FEN=&D@)7,@=FEE
M\.!JX2!R86MTX`!)\'1R:6YT:2!D86)A<G1I;FEU<R!R86MT=7,`2?!T<FEN
M=&D@:V%T86QO9^`H=7,I`$GP=')I;G1I(&=R=7#F`$GP=')I;G1I('1E:7/F
M`$GP=')I;G1I('9I<G1U86SX(&MA=&%L;V?@`%9I<VGP:V%I(&GP=')I;G1I
M(&QA:?!K=7,`2?!T<FEN=&D@8V5LY@!)\'1R:6YT:2!S='5L<&5LX0!)\'1R
M:6YT:2!E9WII<W1U;VIA;G3A(&%L=&5R;F%T>7;X(/!A8FQO;N``2?!T<FEN
M=&D@<&%I;71U<R!L86GP:W5S(&GP(&YU=&]L=7-I;R!S97)V97)I;S\`2?!T
M<FEN=&D@:?`@;6%N;R!K86QE;F1O<FEA=7,`2?!T<FEN=&D@<V5N=7,@<W5S
M:6IU<VEU<R!P<FEK86)I;G1U<R!F86EL=7,@;>MN97-I;R!P<F%D_FEO:F4_
M`$GP=')I;G1I('-E;G5S('-I^'-T^"!L86GP:_@@:V%T86QO9W5S(&WK;F5S
M:6\@<')A9/YI;VIE/P!)\'1R:6YT:2!E:6QU=.8`2?!T<FEN=&D@<&%S:7)I
M;FMTX"!A<')A\.``2?!T<FEN=&D@\.$@<W1U;'!E;.$`2?!T<FEN=&D@\&G@
M(&5I;'5TY@!)\'1R:6YT:0!)\'1R:6YT:2!L86GP:V%I`$9A:6QA<R`B)7,B
M(&GP=')I;G1A<RX`3&%I\&OX('1R>6YI;6%S(&ER('!E<FOK;&EM87,`4')I
M<W1A='EM;R!L86EK87,`1&%N:6IA`%7^9')A=7-T:2!U_FML875SX`!5_F1R
M875S=&D@=?YK;&%U<^`@9.ML('7^:6UT=6UO(&EN9F]R;6%C:6IO<P!-8?[K
M:FEM;R!T=F%R:V$`4')O8FQE;6]S(&%P<F'P>6UA<P!!<')A\'EM87,`4VUU
M;&MI874`1&5T86QI874@*'1A:7`@<&%T(/YI^W+K:VET92!(;W)D92!L;V<@
M9F%I;&4I.@!!9&UI;FES=')A=&]R:75I(&GP<VGX<W1A<R!D971A;'5S(&%P
M<F'P>6UA<RX`5GES='EM87,`1'+K9VYU;6%S`$1RZV=N=6UA<R!P87-K=71I
M;N8@=F%L86YDX#H@`$1RZV=N=6UA<SH@`$)L=6MI;G1I('!A<F'P=7,_`$MR
M>7!T:7,@:?`@:V%I<NMS(.$@9&7P:6[F`$MR>7!T:7,@:?`@9&7P:6[K<R#A
M(&MA:7+F`$MA=&%L;V=A<P!2;V1Y=&D`4F]D>71I(#(T+6GX('9A;"X@9F]R
M;6%TX#\`5F%I>F1A=FEM;R!N=7-T871Y;6%I`%)O9'ET:2!I\'-I^'-T;R!L
M86GP:V\@<&%T=FER=&EN:6W@/P!2;V1Y=&D@<')O9W)O;N8@*%1!1BD`5F%I
M>F1A=FEM;R!F;W)M871A<P!2;V1Y=&D@;&%I\&MO('1E:W-T90!2;V1Y=&D@
M:?#P;VMA;G3A('!R86YE\&EMX"!A<&EE(&=A=73@(&YA=6K@(&QA:?!KX#\`
M2?!S:63K<W1Y;6%S`$QA:?!K;R!P<FES=&%T>6UO('!R86YE\&EM86D`1/YI
M8G5T:7,`3D5!5$E424Y+00!.971I:W)I;G1I(&YA=6KX(&QA:?!K^`!.971R
M:6YT:0!.97-I:W)E:7!K:71E('1I97-I;V=I86D@X2!M86EN=&5N86YC92YP
M:'``3F5G96YE<G5O=&D@;G5O<F]D;W,@;&%U:V5L>6IE($YU;SH`07(@;F]R
M:71E(&%T:61A<GET:2#PX2!K871A;&]GX#\`07(@<&ER;6%S(.%R8?!A<R!Y
M<F$@;&%U:V\@=F%R9&%I/P!$;VUI;FEK80!$;VUI;FEK;W,@4F5S<'5B;&EK
M80!!=&QI:W1A`$%T<VES:?AS=&D`071S:7-I^'-T:2`E<P!!='-I<VGX<W1I
M("5S("YZ:7`@9F]R;6%T=0!!='-I<VGX<W1I('9I<W5S('!R:6MA8FEN='5S
M(&9A:6QU<R`H+GII<"!F86EL92D`071S:7-I^'-T:2!K871A;&]GX"AU<RD`
M071S:7-I^'-T:2!K871A;&]GX"AU<RD@6RYZ:7`@9F]R;6%T87-=`$%T<VES
M:?AS=&D@<W5G96YE<G5O='5S(&YU<W1A='EM=7,@:V%I<"!02%`@<VMR:7!T
MX"X`071S:7-I^'-T:2`N>FEP(&9O<FUA='4`4&%R=6_P:6YI86D`4&%R=6_P
M:6YI^"!K871A;&]G87,`4&%R=6_P:6YI^"!K871A;&]G87,Z`$GP<VES:VQE
M:63^:6%N=&ES('/@<F'P87,`5F%I<W1A:0!%;"X@<&'P=&\@861R97-A<P!%
M;"X@<&'P=&\@861R97-A<P!%4E(`2TQ!241!.B!*^W/X(&QA:?!K87,@;F5P
M87-I96OK(&%D<F5S871O+@!%:W9A9&]R87,`4F5D86=U;W1I`%)E9&%G=6]T
M:2!J=6]DX&KA('/@<F'PX`!+96ES=&D@8FQO:V\@<&%R86UE=')U<P!2961A
M9W5O=&D@9FEL=')U<P!2961A9W5O=&D@9W)U<.8`4F5D86=U;W1I('1E:7-E
M<P!2961A9W5O=&D@=&5I<V5S`"5S('1E:7-I^"!R961A9V%V:6UA<P!2961A
M9W5O=&D@=FER='5A;/@@:V%T86QO9^``4F5D86=U;W1I("5S('9I<G1U86QA
M=7,@:V%T86QO9V\@87!R8?!Y;>``4F5D86=U;W1I(&)A;'3@:N$@<^!R8?#@
M`$ME:7-T:2!N=7-T871Y;75S.@`E<R!T96ES:?@@<F5D86=A=FEM87,`4F5D
M86=U;W1I(&IU;V3@:N$@<^!R8?#@`%)E9&%G=6]T:2!F:6QT<F%V:6UO('1A
M:7-Y:VQE<P!2961A9W5O=&D@:VET^"!E;"X@<&'P=&\@9.O^=>AI^"!N=7-T
M871Y;75S+@!2961A9W5O=&D@8F%L=.!JX2!SX')A\.``56=D>6UA<P!%9VEP
M=&%S`%-A;'9A9&]R87,`16QE;65N=&%S+BXN`$5M`$5L+B!P8?!T87,`16PN
M('!A\'1O(&%D<F5S87,`16PN('!A\'1O(&%D<F5S86D@='5R:2!S=71A<'1I
M+@!%;"X@<&'P=&\@861R97-A<R!S=2!P871V:7)T:6YI;74`T'EP<V5NZVSK
M<P!+871A;&]G87,@)7,@:?!V86QY=&%S+@!)\'9A;'ET:2!K871A;&]GX"AU
M<RD`2?!V86QY=&D@\&EU:_!L:?@@:V%T86QO9^``2?!?=F%L>71I(/!I=6OP
M;&EA9.O^Y@#>:6YU=.L@='7PZ&EA+@!297IU;'1A=&%S('1U\.AI87,N`$YE
M;G5R;V3K=&4@<&%I9?!K;W,@=&5R;6EN^`#!:G5N9W1I(%!'4"!G86QI;7EB
M97,_`,%J=6YG=&D@4R]-24U%(&=A;&EM>6)E<S\`3&5I<W1I('1E:W-T92#A
M=&5R<'1I('!A=F5I:W-LZVQI=7,@:?`@3G5O=')A=6OX(&=A;&5R:6IO<S\`
MP6IU;F=T:2!L86GP:_@@:?!A;FMS=&ENX2!P97+^:?MRZVII;>`_`,%J=6YG
M=&D@9&7P:6YI;VIO('!E;.MS(&UY9W1U:V\@;65N:74_`$MO7V1A=FEM;R!P
M87)A;65T<F%I`%!A8F%I9V$`4&5R<VGX<W1O(&QA:?!K;R!P86)A:6=A`$QA
M:?!K;R!P86)A:6=A`$QA:?!K;R!N=6\@)7,@<&%B86EG80!'86QI;FEA:2!M
M971A:0!)\'!LZW-T:2!R961A:W1O<FGX`,%V97-K:71E('-L87!TX&K@(&9R
M87KF`,%R8?!Y:VET92!K;&%U<VEMX"P@:W5R:7,@:G5M<R!B=7,@=?YD=6]T
M87,@:F5I9W4@<&%M:7+P:71E('-A=F\@<VQA<'1A_F]DX2P@<'9Z+CH@)VMO
M:W,@>7)A($K[<_@@9WEV^VYO('9A<F1A<S\G.@#!=F5S:VET92!P879E:6MS
M;.ML:6\@55),`,%V97-K:71E(&YA=6IO('!A<G5O\&EN:?@@:V%T86QO9V\@
M<&%V861I;FEMX`#!=F5S:VET92!N875J;R!S:?AS=/@@;&%I\&OX(&MA=&%L
M;V=O('!A=F%D:6YI;>``P79E<VMI=&4@;F%U:F]S(/!I=6OP;&EA9.O^ZW,@
M<&%V861I;FEMX`#!<F'P87,@(B5S(B!SZVMM:6YG86D@X7)A\'ET87,@X2!A
M9')E<_@@:VYY9V5LY@!%:W9A=&]R:6[K($=V:6[K:F$`17)I='+K:F$`2VQA
M:61A`$ML86ED82!S:75NZ&EA;G0@871S86MY;>`Z("5S+@!+;&%I9&$@;&%I
M\&ME+@!%<W1I:F$`171I;W!I:F$`171N:6[K<P!%=7)O<&$`P79Y:VES('/K
M:VUI;F=A:2!I\'1R:6YT87,N`$MA<R`Q-2!M:6YUZ&GX`$MA<R`R(&UI;G5T
M97,`2V%S(#,P('-E:W5N9/YI^`!+87,@-2!M:6YU=&5S`$MI96MV:65N;R!P
M<FES:6IU;F=I;6\@;65T=0!+87,@,S`@;6EN=>AI^`!+87,@;6EN=73F`%!A
M=GEZ9/YI=6DZ`%9Y:V1Y=&D`2?!S:VQE:7-T:0!)\'-K;&5I<W1I('9I<VO@
M`$GP<VML96ES=&D@=FES=7,@:V%T86QO9W5S`$GP<VML96ES=&D@:V%T86QO
M9^``061R97/X(&GP<VML96ED:6UA<P!!=71O;6%T:?!K86D@:?!S:VQE:7-T
M:2!A9')E<W5S(&QA:?!K;R!R8?!Y;6\@;&%N9V4_`$MA=&%L;V?X('/@<F'P
M92!R;V1Y=&D@:?!S:VQE:7-TX"!K871A;&]G^"!M963A/P!)\'-K;&5I9/YI
M86UA`%)E:6MA;&EN9V%S("<I)P!296EK86QI;F=A<R#^;V1I<R!A<F)A(&MA
M8G5TZW-E(.%R8?!Y=&%S('!A:67P:V]S(&MR:71E<FEJ=7,`1V%L:6]J:6UO
M(&1A=&$`16MS<&]N96YTZP!496MS=&\@<W!A;'9A`$YU<W1A='EM^"!S:75N
M=&EM87,@<&5R($944"X`2VQA:61A(&YU<VMA:71A;G0@;G5S=&%T>6UU<RX`
M3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!,1$%0('-E<G9E<FEO+@!.97!A
M=GEK;R!P<FES:6IU;F=T:2!P<FEE(%--0B!S97)V97)I;RX`3F5P879Y:V\@
M;G5K;W!I:G5O=&D@:?`@(B5S(BX`3F5P879Y:V\@;G5K;W!I:G5O=&D@X2`B
M)7,B+@!.97!A=GEK;R!S=6MU<G1I(&YA=6IO(%-!4TP@<GGP:6\N`$YE<&%V
M>6MO('!E<FME;'1I(.$@(B5S(BX`T'9E;&YU<P!&;VQK;&%N9/@@<V%L;W,@
M*$UA;'9I;F%I*0!&87)E<O@@<V%L;W,`1F%K<V%S`%9A<V%R:7,`071R;V1O
M(&QY9P!!=')O9&\@;'EG.B``4&%I;71I(&QA:?!K=7,`4&%I;71I(&QA:?!K
M=7,@871S:VER86UE(&QA;F=E/P!086EM=&D@;&%I\&MU<R!P<FES:6IU;F=I
M;6\@;65T=3\`4&%I;71I(&QA:?!K86DZ(`!086EM=&D@;&%I\&MA:3H@;NMR
M82X`5')U;7!A;&%I:VES(&QI971U<P!?1FEL=')A:0!&:63^:7,`1F%I;&%S
M`$9A:6SX('-K86GH:75S.B`E<R!F86EL87,`1F%I;/@@<VMA:>AI=7,Z("5S
M(&9A:6QA:2CX*0!&86EL^"!T=F%R:WEM87,`1F%I;&\@<&%V861I;FEM87,`
M1F%I;&\@<&%S:7)I;FMI;6%S`$9A:6QO('-I=6YT:6UA<P!.87+P>6MLZR!N
M97!A;&%I:V\@9F%I;/@@<VEU;G1I;6\N`$9I;'1R^"!P87)A;65T<F%I`$9I
M;'1R^"!N=7-T871Y;6%I`$9I;'1R=6]T:2!N9?!V86YK:75S(&QA:?!K=7,_
M`$9I;'1R86D@\&EO:F4@<VES=&5M;VIE(&GP:G5N9W1I+@!&:6QT<F%I`$9I
M;'1R86D@3D5!2U195MM3`$9I;'1R86DZ("5S('9A;&1Y;6\@<'5S;&%P:7,`
M267P:V]T:0!3=6]M:6IA`%!I<FUO:FD@<'5SZP!0:7)M87-I<R!P8?!T;R!D
MZ_YU=.MS('!U<VQA<&ES`%!I<FUA<R!P=7-L87!I<P!0:7)M87-I<R!K971V
M:7)T:7,`3G5S=&%T>71A<R!K;V5F:6-I96YT87,`071V:7)K\.AI87,`2?!D
MZW-T>6UA<P!?4&5R<VGX<W1I`%+[:V%S`$MA=&%L;V=A<R`E<R!N965G>FES
M='5O:F$`2V%T86QO9_@@;F%R\'EK;.L`5')U;7!A<R!T=7)I;GES`$MA=&%L
M;V?X(&1A;&EJ:6UA<VES(&GP:G5N9W1A<RX`2V%T86QO9V%I(&GP:G5N9W1I
M+@!496MS=&\@<W!A;'9A`$UA:7-T87,`3F%R\'EK;.MM<RP@:W5R:6]S(&YE
M<&%L86EK;R!P879E:6MS;.ML:?@`3W+X('!R;V=N;WKK("A4048I`$]R^"!P
M<F]G;F]ZZW,@87!I;71I<R`HX7-I9.MMZVMI=&4L(&MA9"#P:2!F=6YK8VEJ
M82!G<F'^:6YA(&ER(&1I96YO<R!I<B!N86MT:65S('!R;V=N;WKF.R!P97(@
M9&ED96QI<R!S:V%IZ&EU<R!G86QI('-U9&%R:WET:2!D:7IA:6[@*0!086UI
M<O!O=&4@<V%V;R!S;&%P=&'^;V3A/P#0:6%N9&EE;B!G875T^"!L86GP:_@@
M9&%T;W,@9F]R;6%T87,`1F]R;6]S`$9R87KK`$9R87II^"!T:7!A<P!&<F%Z
MZW,`1G)A>NMS(#(`1&ES:W5S:6IO<P!097)S:?AS=&D`4&5R<VGX<W1I.@!0
M97)S:?AS=&%S(&QA:?!K87,`4&5R<VGX<W1A<R!L86GP:V%S(&YU;R`E<P!0
M97)S:75N=&EM86D`4&5N:RX`2W)A\'1I;NMS`%!R86YC^WII:F$`4')A;F/[
M>FEJ82P@365T<F]P;VQI<P!5_FEM='5M;R!I;F9O<FUA8VEJ80!!='-A:WEM
M87,@87!I92!U_FEM='5MX`!0<F'P>6UA<R!U_FEM='5M;R!I;F9O<FUA8VEJ
M86D`071S86MY;6%S('7^:6UT=6UO(&EN9F]R;6%C:6IO<R!U_FML875S86D`
M4')A;F/[>FEJ;W,@1W9I86YA`%!R86YC^WII:F]S(%!O;&EN97II:F$`4')A
M;F/[>FEJ;W,@<&EE=&ENZW,@=&5R:71O<FEJ;W,`3E]U;P!.=6\`3G5O(&MO
M`$YU;R``4&EL;F%S(&%P<F'P>6UA<P!0:6QN871I<P!0:6QN87,@=F%R9&%S
M`$9W9#H`1G=D.B``1G=D.B`E=2!P97)S:?AS=&D@;&%I\&MA:0!'86)O;F%S
M`$=A;&5R:6IA(&GP(&MU<FEO<R!I\"!K=7)I;W,@8G5S(')O9&]M87,@<&%V
M96EK<VSK;&ES`$=A;&5R:6IA.@!'86UB:6IA`%!A9W)I;F1I;FEA:2!N=7-T
M871Y;6%I`$=E;F5R=6]T:2`E<R!N=7-T871Y;75S`%-U9V5N97)U;W1A<R!K
M;V1A<P!'<G5Z:6IA`%9O:VEE=&EJ80!086EM=&D@=&EK(&YA=6IU<R!L86GP
M:W5S/R`H=&EK($E-05`I`$=A;F$`1VEB<F%L=&%R87,`5F%R9&%S`%)O9'ET
MX2!L86GP:^``1V%D96QI<P!';V]G;&4@<&%I9?!K80!3=71E:6MT:2!T96ES
M97,`3F5S<&%L=F]T87,`1W)A:6MI:F$`1W)A:6MI\&MA("A)4T\M.#@U.2TW
M*0!'<F5N;&%N9&EJ80!'<F5N861A`$=R=7!I^"!A9&UI;FES=')A=FEM87,`
M1W)U<.MS('9A<F1A<R!T=7)I(&+[=&D@;F5T=?#H:6%S`$=R=7#K<P!'=F%D
M96QU<.L`1W5A;6$`1W9A=&5M86QA`$=E<FYS:7,`4W9EZ&GX('1E:7/K<P!3
M=F7H:?@@:VYY9V$`1W9I;NMJ80!":7-S874M1W9I;NMJ80!'86IA;F$`R$E!
M`$A434P`3&%I\&MO($A434P@=F5R<VEJ80!(5$U,07)E82!N96=A;&D@:?!T
M<FEN=&D@<&%S:W5T:6[K<R!C96SK<R!E:6QU=.MJ92X`2%1-3$%R96$@;F5G
M86QI(&GP<FEN=&D@<&%S:W5T:6YI;R!S='5L<&5L:6\@;&5N=&5LZVIE+@!(
M5$U,07)E82!N96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!E:6QU=.MS(&QE
M;G1E;.MJ92X`4F5I:V%L:6YG82!(5%10(&%U=&5N=&EF:6MA8VEJ82X`2&%I
M=&ES`$AA<V@M06QG;W)I=&UA<P!-:6=L80!!;G1R8?!TZP!!;G1R8?!TZW,`
M2&5R9&\@<V%L82!I<B!-86MD;VYA;&1O('-A;&]S`$AE8G)A:O@@*$E33RTX
M.#4Y+3@M22D`075K\'1I<P!086=A;&)A`%)E9&%K=&]R:6%U<R!N875D;VII
M;6]S:2!P86=A;&)A`%!A9V%L8FEN:6YK87,`2&5M:7-F97)A`-!T86D@Z&EA
M('ER82!F86EL;R!P<F%D_FEA.@!,86GP:V%S(&MU<N$@<F'PZW1E(&GP<V%U
M9V]T87,@Z&EA.@!087-LZW!T:0!087-LZW!T:2!V86EZ9'5O:F%N="!G:6K@
M("AT:')E860I`%!A<VSK<'1I(&GP=')I;G1U<P!087-LZW!T:2!A='-I<V%K
M>71U<P!3=F%R8G4`4W9A<F)U`$QA8F%I('-V87)B=0!?4&]R=&%L87,`T'9E
M;G1A<VES(%-O<W1A<R`H5F%T:6MA;F\@=F%L<W1I:F$I`%!O<G1A;&%S`$YA
M;?@@861R97-A<P!.86WX('1E;&5F;VYA<P!(;VYD^W)A<P!(;VYK;VYG87,`
M4&]R=&%L87,`2&]R9&4O2V]L86(Z(&YE=&5I<VEN9VD@)7,@6$U,(&1U;VUE
M;GES(/YI;G5TZVIE("5S`$AO<F1E+TMO;&%B.B!O8FIE:W1O("5S(&YE871I
M=&EN:V$@:F]K:6$@_FEN=73K`$AO<F1E+TMO;&%B.B!O8FIE:W1O('1I<&%S
M("5S(&YE<F%S=&%S(/YI;G5TZVIE("5S`$AO<F1E+TMO;&%B.B`E<R`B)7,B
M('/K:VUI;F%I(&GP=')I;G1A`$AO<F1E+TMO;&%B.B!I;G1E9W)A8VEJ;W,@
M=F%R:6ML:75K=6D@<F5I:V%L:6YG87,@)V1O;7AM;"<@4$A0(&UO9'5L:7,`
M2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U:W5R=&D@;F%U:F\@6$U,(&UE9/YI
M;R!O8FIE:W1U:2`E<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@:?!T<FEN=&D@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO(&=A=71I($U)344@
M240@9&%L:6%I("5S('1I<&\`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN
M8VAR;VYI>G5O=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO
M('-U<VEN8VAR;VYI>G5O=&D@96QE;65N=/@Z("5S`$AO<F1E+TMO;&%B.B!N
M9?YI;F]M87,@96QE;65N=&%S("(E<R(`2&]R:7IO;G1A;&D@;&EN:6IA`$AO
M<FEZ;VYT86QU<R!T87)P87,`2&]R:7IO;G1A;&EA:3H`2V%I<"#H:6$@<&%T
M96MO=&4_("A0<F%N9?!K:71E(2D`2V%I<"!N;W)I=&4@<&5R_FG[<NMT:2!P
M<FEK86)I;G1U<R!F86EL=7,_`$MI96L@<W1U;'!E;&GX(&YO<FET92!S=6IU
M;F=T:3\`2VEE:R!L875K^"`H<W1U;'!E;&GX*2!T96X@>7)A/P!+:65K(&5I
M;'7H:?@@;F]R:71E('-U:G5N9W1I/P!+86EP('!A_GEMZW1I(&-I='5O:F%M
MX"!T96MS=.`@871S86MY;64`1'+K9VYU;6%S`$1RZV=N=6UA<SH@`$IU;6]R
M97-K;W,`5F5N9W)I:F$`24U!4`!)34%0("A!=71O;6%T:6YI<R!P<F]T;VMO
M;&\@871P8?YI;FEM87,I`$YE<&%V>6MO('-U:W5R=&D@24U!4"!P8?!T;R!D
MZ_YU=.MS.B`E<P!.97!A=GEK;R!I\'1R:6YT:2!)34%0('!A\'1O(&3K_G5T
MZW,Z("5S`$YE<&%V>6MO(&YU<W1A='ET:2!)34%0('!A\'1O(&3K_G5TZW,@
M9'ED_FEO.B`E<P!)34%0('!E<B!34TP`24U!4"!P97(@4U-,("AB92!#02!S
M97)T:69I:V%T;RD`24U!4"!P97(@4U-,("AB92!#02!P87)A\&\I`$E-05`L
M(&)E(%1,4P!)34%0+U!/4#,@<&'P=&\@<V5R=F5R:6%I`$E.0D]8`$E0(&%D
M<F5S87,`3F5P879Y:V\@9V%U=&D@25`@861R97-O+@!)4"!A9')E<V%S(&YE
M=&5I<VEN9V%M92!#2412(&)L;VME+@!)4"!U_G)A:VEN=&%S+@!?P71E<G!T
M:2!E:6QU=.8@=FER\'5J90!)<VQA;F1I:F$`5&EK('!I:W1O9W)A;6]S`%!I
M:W1O9W)A;6]S('-U('1E:W-T=0!!<')A\&\@<&%V861I;FEM87,Z`$IE:2!N
M96=A;&ET92!P97)S:V%I='ET:2#P:6\@;&%I\&MO+"`E<RX`2F5I9W4@;6%T
M;W1E(/!IX"#^:6YU=.8@=FEE=&]J('!A=F5I:W-LZVQI;RP@:W5RX2!N;W)I
M=&4@X6ME;'1I+"!T86D@2OMS^"!N87+P>6MLZR!N96=A;&D@:F\@871V86EZ
M9'5O=&DN`$EG;F]R=6]T:0!)9VYO<G5O=&D@=FES=7,`4&%V96EK<VSK;&EO
M('!E<OYI^W)A`%!A=F5I:W-LZVQI;R!54DP`4&%V96EK<VSK;&EO(%523#H`
M4&%V96EK<VSK;&ES(&GP(&=A;&5R:6IO<P!0879E:6MS;.ML:7,@:?`@9V%L
M97)I:F]S.@!0879E:6MS;.ML:6\@X6OK;&EM87,`5F%I>F1A:0#!:V5L=&D`
MP6ME;'1I(')A:W3@`,%K96QT:2!R86MT^"!P;W+@`,%K96QT:2!01U`@<F%K
M=.``P6ME;'1I(&%S;65N:6[A('-L87!TX&KA(%!'4"!R86MTX`#!:V5L=&D@
M87-M96YI;N$@=FEE\.!JX2!01U`@<F%K=.``P6ME;'1I(&%S;65N:6[A(%,O
M34E-12!S97)T:69I:V%TX`#!:V5L=&D@=FEE\.!JX2!R86MTX`#!:V5L=&D@
M=FEE\.!JX2!01U`@<F%K=.``P6ME;'1I('9I9?#@:N$@4R]-24U%(')A:W3@
M`,%K96QT:2!3+TU)344@<F%K=.``P6ME;'1I(&UB;W@@9F%I;.``P6ME;'1I
M(&UB;W@@9F%I;.`@)7,@X2!K871A;&]GX"`E<RX`P6OK;&EM87,L("5D(/YI
M;F=S;FES`%-V87)B^W,`4W9A<F+[<R!L86GP:V%I`,%K96QT82`E9"!L86GP
M:_@@:?`@)7,N`$QA=6MA<R#A:V5L=&%S.B`E<P#!:V5L=&D@;&%U:V%I.@!!
M=&QI96MA;6$`P5]T97)P=&D@96EL=73F(&%P8>AI;VIE`$EN8F]X`$%R(&%T
M<V%K86YT(.%T97)P=&D@;&%I\&MO('!A9W)I;F1I;F5S(&%N=')A\'1E<S\`
M07(@871S86MA;G0@X71E<G!T:2!L86GP:V\@=&5K<W3@/P!.971E:7-I;F=A
M<R!V96EK<VUO(&MO9&%S+@!.971E:7-I;F=A<R!V87)T;W1O:F\@=F%R9&%S
M(&ER+V%R8F$@<VQA<'1A_F]D:7,N`$YE:71E:7-I;F=A<R!V87)T;W1O:F\@
M=F%R9&%S(&%R8F$@86QT97)N871Y=G5S(&5L+B!P8?!T;R!A9')E<V%S+B!"
M86YD>6MI=&4@9&%R(&MA<G3@(&%R8F$@<W5S:7-I96MI=&4@<W4@<V%V;R!A
M9&UI;FES=')A=&]R:75M:2!J96EG=2!R96EK86QI;F=A('1O;&5S;NL@<&%G
M86QB82X`4&%D:61I;G1I(&%T:71R875K:6W@`$EN9&EJ80!);F1I=FED=6%L
M^W,@=F%R=&]T;VIA:0!);F1O;F5Z:6IA`$EN9F]R;6%C:6IA`$EN9F]R;6%C
M:6IA`$EN9F]R;6%C:6IA(&%P:64@)7,@=FEE\.!JX2!R86MTX`!);F9O<FUA
M8VEJ82!A<&EE(&%S;65N:6[A('-L87!TX&KA(')A:W3@`$EN9F]R;6%C:6IA
M(&%P:64@87-M96YI;N$@=FEE\.!JX2!R86MTX`!+86EP('1E:W-TX`#!=')A
M=6MT:2!S='5L<&5LX2!?9&7P:6[K:F4`P71E<G!T:2!S97)T:69I:V%TX"#H
M:6$`P71E<G!T:2!P879E:6MS;.MLX0#!=&5R<'1I(&%S;65N:6[A('-L87!T
MX&KA(%!'4"!R86MTX"#H:6$`P71E<G!T:2!A<VUE;FENX2!V:67PX&KA(%!'
M4"!R86MTX"#H:6$`P6ME;'1I('9I9?#@:N$@4$=0(')A:W3@(.AI80#!=&5R
M<'1I(&QE;G1E;.8`P71E<G!T:2!N=6]R;V3@`,%T97)P=&D@<W1U;'!E;.$@
M7VMA:7+K:F4`P71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L
M:6\@9&7P:6[K:F4`P71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L
M<&5L:6\@:V%I<NMJ90#!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL
M=73K<R!A<&'H:6]J90#!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL
M=73K<R!V:7+P=6IE`,%T97)P=&D@<&%R86=R86;@(&5L96UE;G1O(&%P8>AI
M;VIE`,%T97)P=&D@<&%R86=R86?@(&5L96UE;G1O('9I<O!U:F4`P71E<G!T
M:2!A;'1E<FYA='EV^"#P86)L;V[@`,%R8?!Y:VET92!E;"X@<&'P=&\@861R
M97/@+"#A(&MU<N$@;F]R:71E(&=A=71I(&YA=6K@('-L87!T8?YO9.$Z`,%T
M97)P=&D@8V5LYB!P;R!T;P#!=&5R<'1I(&-E;.8@<')I9?`@=&%I`,%T97)P
M=&D@<W1U;'!E;.$@9&7P:6[K:F4`P71E<G!T:2!S='5L<&5LX2!K86ERZVIE
M`,%T97)P=&D@;&%I\&MU<P#!=&5R<'1I('!A<F%G<F%FX"!P;R!T;P#!=&5R
M<'1I('!A<F%G<F%FX"!P<FEE\"!T86D`P71E<G!T:2!E:6QU=.8@<&\@=&\`
MP71E<G!T:2!E:6QU=.8@<')I9?`@=&%I`,%R8?!Y:VET92!R96EK:6%MX"!A
M='-A:WEMX"#A(&ML875S:6W@('9I<O!U:F4Z`,%T97)P=&DO<F5D86=U;W1I
M('!A=F5I:W-LZVSA`,%T97)P=&DO4F5D86=U;W1I(&YU;W)O9.``1&ES=')I
M8G5C:6IO<R!SX')A\'5I(&YU<VGX<W1I(&YE=?YT96YK82!K<F5D:71O+@!.
M977^=&5N:V$@:W)E9&ET;RX`4VMA:>AI=7,`4VMA:>AI^"!SX')A\&%S`%!A
M<VER:6YK=&%S(&YE=&5I<VEN9V%S('9E:6MS;6%S(/!I86T@:V]M<&]N96YT
M=6DN`$YE=&5I<VEN9V$@861R97/X(&MN>6=E;.LN`$YE=&5I<VEN9V$@;G5T
M;VQU<VD@<&'P=&\@9.O^=73K`$YE=&5I<VEN9V%S(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+@!.971E:7-I;F=A<R!M;V1U;&ES+@!.971E:7-I;F=A<R!)
M1"X`P79E<W1I(&YE=&5I<VEN9VD@9'5O;65N>7,N`$YE=&5I<VEN9V%S(&%D
M<F5S87,N`$YE=&5I<VEN9V%S(&9A:6QO(&9O<FUA=&%S`$YE=&5I<VEN9V%S
M(')A:W1A<P!.971E:7-I;F=A<R!M<V=?='EP92X`3F5T96ES:6YG87,@87)B
M82!NZW)A(&%P:5]I9"X`4&%R86UE=')A:2!N971E:7-I;F=I(&%R8F$@:O@@
M;NMR82X`3F5T96ES:6YG;W,@<&%V96QD:6UO<R!T96ESZW,N`$YE=&5I<VEN
M9V%S(&%S;65N:6YI<R!01U`@<VQA<'1A<VES(')A:W1A<RX`3F5T96ES:6YG
M87,@87-M96YI;FES(%!'4"!V:67P87-I<R!R86MT87,N`$YE=&5I<VEN9V%S
M('!R;W1O:V]L87,N`$YE=&5I<VEN9V%S(&]B:F5K=&%S`$YE=&5I<VEN9V%S
M('-I=6YTZVIO(&%D<F5S87,N`$YE=&5I<VEN9VD@=6YI:V]D;R!D=6]M96YY
M<RX`26YV96YT;W)I=7,`07!V97)S=&D`27-L86UI\&MA($ER86YO(%)E<W!U
M8FQI:V$`27)A:V%S`$%I<FEJ80!-96YO('-A;&$`27IO;&EU;W1O<R!4+6%U
M9')O<P!)>G)A96QI<P!)\&1A=NMJ87,`2W5R<WEV87,`271A;&EJ80!*86UA
M:6MA`%-A=7-I<P!*87!O;FEJ80!*87!O;FGP:V$@*$E33RTR,#(R+4I0*0!$
M_F5R<VES`$IO<F1A;FEJ80!,:65P80!":7+^96QI<P!0:6QN86D`3'EG:75O
M=&D@8V5N=')E`$QY9W5O=&D@<&EL;F%I`$QY9VEU;W1I(&MA:7+K:F4`3'EG
M:75O=&D@9&7P:6[K:F4`2T(`2V%Z86MS=&%N87,`2?!S875G;W1I(&]R:6=I
M;F%LX#\`2V5N:6IA`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@2V5R8F5R
M;W,@<V5R=F5R:6\N`$)R86YD=6]L:6\@;F%U:F]K86D`4F%K=&\@:_MR:6UA
M<P!286MT;R!A='-P875D87,`4F%K=&\@:6QG:7,`4F%K=&\@=&EP87,`4F%K
M=&\@<&%N875D;VII;6%S`%)A:W1A<R!J874@>7)A('9I9?#X:O@@<F%K=/@@
M<V5R=F5R>6IE+@!286MT87,@<^MK;6EN9V%I(&YU<VGX<W1A<R#A('9I9?#X
M:O@@<F%K=/@@<V5R=F5RX2X`5F%I:V%I`$MI<FEB871I<P!$96UO:W)A=&EN
MZR!+;W+K:F]S($QI875D:65S(%)E<W!U8FQI:V$`2V]RZVIO<R!297-P=6)L
M:6MA`$MO<NMJ:65T:?!K82`H155#+4M2*0!+=79E:71A<P!+:7)G:7II:F$`
M7TGP9.MS='EM87,`2V%L8F$`3&%O<V\@1&5M;VMR871I;NL@3&EA=61I97,@
M4F5S<'5B;&EK80!!;G1R82!P=7/K`%!A<VMU=&EN:7,@<&'P=&\@9.O^=73K
M<R!P=7-L87!I<P!087-K=71I;FES('!U<VQA<&ES`%!A<VMU=&EN:7,@:V5T
M=FER=&ES`$%T;F%U:FEN=&$Z`%!A<VMU=&EN:7,@<')I<VEJ=6YG:6UA<SH@
M)7,`4&%S:W5T:6YI<R!P<FES:6IU;F=I;6%S.B`E<R!I\"!A9')E<V\@)7,`
M4')I<VEJ=6YGZW1E('!I<FW@(&MA<G3@`$QA='9I:F$`5&5I<^L`2?!DZW-T
M>6UA<P!*96EG=2!N96YO<FET92!N96YA=61O=&D@:W)A\'3X+"!P86QI:VET
M92!T=?#H:>``3&EB86YA<P!+86ERZVIE`$MA:7)I;VII(&%N=')A\'3K`$MA
M:7)I;W-I;W,@<F5I:_!MZW,`3&5S;W1A<P!3=7-I971I('!R:6MA8FEN='5S
M(%]F86EL=7,`3&EB97)I:F$`3&EB:6IO<R!!<F%B^"!%;7ER871A:0!,:6-H
M=&5N\'1E:6YA<P!3;75L:W5S(&QI971U<P!.961I9&5L:7,@;&EE='5S`$YE
M9&ED96QI<R!L:65T=7,@<GET90!.961I9&5L:7,@;&EE='5S('9A:V%R90!.
M961I9&5LZR!L:?MT:7,`3F5D:61E;&ES(&QI971U<R!S=2!P97)K^VYI:F$`
M3F5D:61E;&ES('-N:65G87,`3F5D:61E;.L@\&QA<&1R:6)A`$QI;65R:6MA
M<P!.=6]R;V1A`$YU;W)O9&$@X3H`4&%D87)Y=&D@96PN('!A\'1O(&%D<F5S
MX"!N=6]R;V1A(.$@;&%I\&MO(')A\'EM;R!P=7-L87#A`%-U<VEE=&D@<')I
M:V%B:6YT:2!F86EL86D@9')A=63^:6%M:2X`3G5O<F]D;W,`3&EN=7@@;&%I
M;>MS(/YI;G5TZW,`4F]D>71I("T@=F%R=&]T;VIA<R!G86QI(&UA='ET:2!K
M871A;&]G;R!T=7)I;N$`4F]D>71I(&1U;VUE;O@@8F%Z:?@@<^!R8?#@`%)O
M9'ET:2!P86=A;&)O<R!T96UA<P!2;V1Y=&D@;&5N=&5L:?@@<^!R8?#@`%)O
M9'ET:2!V:7-U<R!A9')E<W5S+"!A9')E<_@@:VYY9V5LZVIE/R`H:F5I9W4@
M:?!J=6YG<VET92P@;6%T>7-I=&4@=&EK(&%D<F5S=7,L(&MU<FGX(&EE\&MO
M:F]T92D`2V]N9F5R96YC:6IO<R!A<F-H>79A<P!+;VYF97)E;F-I:F]S('!A
M9V%L8F$`2V]N9F5R96YC:6IO<R!)1`!+;VYF97)E;F-I:F]S('-A=FEN:6YK
M87,`4F'P>71I(.$@:V]N9F5R96YC:6K@`%!R:7-I:G5N9W1I('!R:64@:V]N
M9F5R96YC:6IO<P!!='-I:G5N9W1I(&YU;R!K;VYF97)E;F-I:F]S`$%N=')A
M\.AI^"!SX')A\&%S`%9A<G1O=&]J^"!SX')A\&%S('7^9')A=7-T87,N`$QI
M=&5R873[<F$`3&EE='5V80!+<F%U;F$N+BX`5FEE=&ENZR!P8?!T;R!DZ_YU
M=.LZ`%9I971I;FES(&QA:6MA<SH@`$QO:V%LZR!I<B!L86EK87,`5FEE=&$`
M4')I<VEJ=6YG=&D`4')I<VEJ=6YG=&D@<')I92`E<P!!='-I:G5N9W1I`%!R
M:7-I:G5N9W1I`%!R:7-I:G5N9VEM;R!D87)B86D`4')I<VEJ=6YG=&D@;F5P
M879Y:V\N($YE=&5I<VEN9V%S($K[<_@@;G5R;V1Y=&%S('9A<G1O=&]J;R!V
M87)D87,@:7(O87(@<VQA<'1A_F]D:7,N`%!R:7-I:G5N9W1I(&YE<&%V>6MO
M+@!);&=A<R!T96MS=&%S`$UE:6SK`$YE<W9A<F)U`$YE<W9A<F+[<P!-8?YO
M<VEO<R!G<F%I:VGP:V]S(')A:63K<P!-8?YO<VEO<R!L;W1Y;FGP:V]S(')A
M:63K<P!-8?YI96II(')O;>MN:?!K:2!S:V%IZ&EA:0!6:7-I\&MA:2!N97-V
M87)B=0!,:75K<V5M8G5R9V%S`$U-`$U/5$0`4')I:V%B:6YT86UE($U3+51.
M148@9F%I;&4@;NMR82!D=6]MZV[X+@!-4T<`36%K86\`36%K961O;FEJ80!-
M86-H:6YT;W-H(&9A:6QA<P!-861A9V%S:V%R87,`36%G:6IA`%!A\'1O`%!A
M\'1O('9A;&1Y;6%S`$GP86YK<W1I;NL@;&%I\&OX('!E<OYI^W)A`%!A\'1O
M('-E<G9E<FEO('!R:7-I:G5N9VEM;R!T:7!A<SH`2V%T86QO9V%S`%!A\'1O
M(&3K_G5TZW,@:7(@:V%T86QO9_@@=F%I>F1A=FEM;R!N=7-T871Y;6%I`%-U
M:W5R=&D@7VYU;W)O9.`N+BX`36%L879I<P!-86QA:7II:F$`36%L9'EV86D`
M36%L:7,`36%L=&$`2V%T96=O<FEJ^"!SX')A\&\L(&MU<FEO;7,@<')I<VMI
M<FEA;6D@;V)J96MT86DL(&ER('-U(&IO;6ES('-U<VEJ=7-I^"!S<&%L=O@@
M:V5I=&EM87,N`$UA<#(T(/YE;>ML87!I<P!-87!1=65S="#^96WK;&%P:7,`
M2V]V87,`4&%R8?!TZP!08?YY;>MT:2!V:7-U<R!L86GP:W5S(&MA:7`@<VMA
M:71Y='5S`%!A_GEMZW1I('9I<W5S(&QA:?!K=7,@:V%I<"!N97-K86ET>71U
M<P!08?YY;>MT:2!K86EP.@!#:71U;VIA;>`@=&5K<W3@('-P86QV:6YT:2!S
M:VER=&EN9V]M:7,@<W!A;'9O;6ES/P!08?YY;>MT:2!L86GP:W5S(&MA:7`@
M<VMA:71Y='5S/R`H=&EK($E-05`I`%-U_GEMZW1I('!A<')A<W1A:3\`4&'^
M>6WK=&D@:V%I<"!S:V%I='ET=7,O;F5S:V%I='ET=7,`4&'^>6WK=&D@:VET
M86ES(&%T<FEB=71A:7,@*'!V>BX@<W9A<F)U+V%T<V%K>71A*0!-87+P86QO
M('-A;&]S`$UA<G1I;FEK80!!=&ET:6YK82!V:7-U<R#^;V3^:75S`$%T:71I
M;FMA(&)E="!K=7+A(/YO9/[A`%-U:G5N9W1I(&QA=6MA:0!-875R:71A;FEJ
M80!-875R:6-I:G5S`$UA:W-I;6%L=7,@:W)E9&ET87,N`$UA:W-I;6%L=7,@
M_FEN=>AI^"!D86QI^"!K:65K:7,@:?!E:6MV;W1A<RX`36%K<RX@=&5M<"X@
M<&%S:RX@,C0@=F%L.B``36%K<RX@=&5M<"X@<&%S:RX@-B!V86PZ(`!-86MS
M:6UA;'5S('!R:6MA8FEN=/@@9F%I;/@@9'ED:7,`36%K<VEM86QU<R!I;&=I
M<P!087-I96MT87,@;6%K<VEM86QU<R!P<FEK86)I;G3X(&9A:6SX('-K86GH
M:75S+@!087-I96MT87,@;6%K<VEM86QU<R!P<FEK86)I;G3X(&9A:6SX(&1Y
M9&ES+@!'96=U_NL`36]J;W3K`$UE9&EC:6YA`%-U<VER:6YK:6UO(&YU=')A
M=6MI;6%S`%-U<VER:6YK:6UO(&EN9F]R;6%C:6IA`%-U<VER:6YK:6UO('!A
M<VG[;'EM87,`071S86MY;6%S(&%P:64@<W5S:7)I;FMI;>``4W5S:7)I;FMI
M;6\@871N875J:6YI;6%S`%-U<VER:6YK:6UO(&%T;F%U:FEN:6UO('7^:VQA
M=7-A`$YA<FEA:0!-96YI=2!K871A;&]G^"!SX')A\&%S`$UE;FEU(')E_FEM
M87,Z`%-U:G5N9W1I(&-E;&5S`$QA:?!K87,`3&%I\&MO(')A\'EM87,`3&%I
M\&MO(&1A=&$`3&%I\&MO(&YU<W1A='EM86D`3&%I\&MO('!A:67P:V$`3&%I
M\&MO(&1Y9&ES`$QA:?!K;R!K;V1A<P!,86GP:V%S('!A=FER=&EN=&%S+"!T
M8>AI874@;F5P871V:7)T:6YT87,@<&%S:7)A\&EU<VEO(&%S;65N<R!S97)T
M:69I:V%T87,N`$QA:?!K;R!P97+^:?MR80#>:6YU=.L@;F5I\'-I^'-T82X`
M3&%I\&MO(/YY;>MS`$QA:?!K^"!K871A;&]G86D`3&%I\&MA<R!N=6\@)7,`
M3&%I\&MA<R!A=&ET:6YK80!,86GP:V%S('!E<G-I^'-T87,@<^MK;6EN9V%I
M+@!,86GP:V%S(&GP<VGX<W1A<R!SZVMM:6YG86DL('1AZ&EA=2!N96GP<V%U
M9V]T87,@X2`E<P!,86GP:V%S(&GP<VGX<W1A<R!SZVMM:6YG86DN`-YI;G5T
MZW,@=&EP87,`3&%I\&OX('-K86GH:75S(&MA=&%L;V=O('!U<VQA<'EJ92X`
M;&%I\&MU<R#A`$]R;R!S86QY9V]S`$]R;R!SX&QY9_@@8FQO:V\@;NMR82X`
M3W)O('/@;'EG^"!B;&]K;R!NZW)A+B!!9&UI;FES=')A=&]R:75I(&GP<VGX
M<W1A<R!D971A;'5S(&%P<F'P>6UA<RX`365T;V1A<P!-871A:0!-96MS:6MA
M`$UI:W)O;F5Z:6IO<R!&961E<F%C:6[K<R!686QS=&EJ;W,`5FED=7)Y:F4`
M34E-12!T:7!A<P!-:6XN('1E;7`N('!A<VLN(#(T('9A;#H@`$UI;BX@=&5M
M<"X@<&%S:RX@-B!H;W5R<SH@`$%T<W!I;F1Y<P!+:71O<P!.97)A<W1A<R!0
M14%2($A45%!?4F5Q=65S="!P86ME=&%S+@!.=7-T871Y;?@@;NMR82X@2F5I
M9W4@;F]R:71E(&YA=61O=&D@\.$@;6]D=6SA+"!T=7)I=&4@:N$@<W5K;VYF
M:6?[<G5O=&DN`$[K<F$@_FEN=73K<R!)1"X`3F5R87-T87,@<F5I:V%L:6YG
M87,@4$5!4B!-86EL('!A:V5T87,N`$[K<F$@<V5S:6IO<R!)1"X`4&ER;2X`
M36]B:6QU<R!P8?!T87,`5FED=71I;FES`%)E9&%G879I;6\@9&%T80!+96ES
M=&D`2V5I<W1I(%523`!-;V1U;&ES`$UO;&1O=F]S(%)E<W!U8FQI:V$`36]N
M86MA<P!-;VYG;VQI:F$`3>MN97-I86D@:7(@;65T86D`2V%S(&WK;F5SX0!-
M;VYS97)A=&%S`$WK;G5L:6\@9F%ZZW,`36%R;VMA<P!$875G:6%U<VEA(&=I
M961R80!$875G:6%U<VEA(&%P<VEN875KY@!$875G:6%U<VEA('-A=6SK=&$`
M4&5R:V5L=&D`4&5R:V5L=&D@_F5M:6%U`%!E<FME;'1I(&MA:7)I874`4&5R
M:V5L=&D@9&7P:6YI874`4&5R:V5L=&D@875K\.AI874`4&5R:V5L=&D@_F5M
M>6X`4&5R:V5L=&D@X2!K871A;&]GX`!097)K96QT:2!A=6OP='EN`$UO>F%M
M8FEK87,`2V5L971O(&QY9VGX(&GP<VES:VQE:63^:6%N=&ES('/@<F'P87,`
M2VET;W,@9&%L>7,`2V5L971A<R!P87-I<FEN:VEM^`!-86YO('/@<VMA:71A
M`$UA;F\@<&]R=&%L87,`36%N;R!P;W)T86QO(&GP9.MS='EM87,`36%I;FUA
M<F%S`$Y%+"!.15-55$E.2U4`4$%35$%"00!687)D87,`5F%R9&%S(&ER+V%R
M8F$@96PN('!A\'1O(&%D<F5S87,@;F5G86QI(&+[=&D@='7P=&D`3F%M:6)I
M:F$`3F%U<F%S`%)E:6MA;&EN9V%S('9E:6MS;6%S`$YE<&%L87,`3GED97)L
M86YD86D`3GED97)L86YD^"!!;G1I;&%I`$YE='-C<&%P92!B87II;FES(%52
M3`!.971S8W!A92!S97)I9FEK871O(&%T\&%U:VEM;R!54DP`3F5T<V-P864@
M<V5R=&EF:6MA=&\@=&5I<VGX(%523`!.971S8V%P92!A=&YA=6II;F]M;R!5
M4DP`3F5T<V-A<&4@873P875K:6UO(%523`!.971S8V%P92!34TP@<V5R=F5R
M:6\@=F%R9&%S`$YE='-C87!E('-E<G1I9FEK871O(&%P<F'P>6UA<P!.971S
M8V%P92!S97)T:69I:V%T;R!T:7!A<P!4:6YK;&%S`$YI96MA9&$`3FEE:V%D
M82!N96GP<V%U9V]T:2!P<FEK86)I;G3X(&9A:6SX`$YA=6IA<P!.875J;VII
M($MA;&5D;VYI:F$`3F%U:F$@:V%T96=O<FEJ80!.875J87,@:V%T86QO9V%S
M`$YA=6IA<R!P8?!T87,`3F%U:F%S(&WK;G5L:7,`3F%U:F%S('9A<G1O=&]J
M;R!V87)D87,@*&YE8OMT:6YA<RD`3F%U:F]J:2!:96QA;F1I:F$`3F%U:FD@
M;&%I\&MA:0!.875J86UE(&QA;F=E("A?8FQA;FLI`$YA=6II96YO<P!.875J
M:65N^"!G<G5PZW,`4V5K86YT:7,`4V5K86YT:7,@;&%I\&MA<P!396MA;G1I
M<R!P=7-L87!I<P!396MA;G1Y<R!N=7-T871Y;6%I`$YI:V%R86=V80!.:6=E
M<FES`$YI9V5R:6IA`$YA:W1I<P!.:75JZP!.90!397)T:69I:V%T87,@;F5R
M87-T87,`2V]D879I;6\@;NMR80!3875G>6ML;VIE(&[K<F$@<F%K=/@`3&%I
M\&OX(&[K<F$`3F7A:V5L=&D@:F]K:64@4$=0('9I9?!I96II(')A:W1A:2X`
M3NMR82!A<VUE;FEN:6\@<V5R=&EF:6MA=&\`3NMR82!V:65T^&KX(')A:W3X
M`$YEX6ME;'1I(&IO:VEE(%,O34E-12!V:67P:65J:2!R86MT86DN`%!R:6MA
M8FEN=/@@9F%I;/@@;NMR82X`3F5U_G1E;FMA(&1U;VUE;O@@<VMI<G1U;?@@
M<&%R;V1Y;75I+@!.96YU<F]D>71A('-T<F%T96=I:F$@25-/(')A\'EM=6DN
M`$[K<F$@<W5DZW1I;FEO(/!A8FQO;F\N`$YU<F]D>71O:F4@<&]Z:6-I:F]J
M92!B;&]K;R!NZW)A`$YEX79E9.MT92!K86QE;F1O<FEA=7,@=F%R9&\@34-!
M3"!A=71E;G1I9FEK86-I:F]J92X`4VMI<G1U;?@@;NMR82X`T&EO<R!T96ES
MZW,@;F5G86QI('1U<NMT:2!P;W1E:7-I^"X`3NMR82!I;F9O<FUA8VEJ;W,@
M87!I92`E<R!K;VYF:6?[<F%C:6K@+@!.ZW)A(&EN9F]R;6%C:6IO<R!A<&EE
M($944"!61E,@:V]N9FEG^W)A8VEJX"X`3NMR82!I;F9O<FUA8VEJ;W,@87!I
M92!344P@5D93(&MO;F9I9_MR86-I:N`N`$[K<F$@:6YF;W)M86-I:F]S(&%P
M:64@4U%,+49I;&4@5D93(&MO;F9I9_MR86-I:N`N`$MR961I=&%S(&GP96EK
M=F]T87,N`$YEX79E<W1A<R!G87;K:F%S+@!&86EL87,@;F5N=7-I^'-T87,`
M3F5P87-I<FEN:W1A<R!K871A;&]G87,N`$YE:2!V:65N87,@:V%T86QO9V%S
M(&YE;G5S=&%T>71A<R!T:6MR:6YT:2!N875J=7,@;&%I\&MU<RX`3F5N=7)O
M9'ET87,@:F]K<R!K871A;&]G87,`3F%U:O@@;&%I\&OX(&[K<F$`3F5P97)S
M:V%I='ET^"!L86GP:_@@;NMR80!.96YU<W1A='ET82!V:65T;W;K+@!,86GP
M:V4@;NMR82!T=7)I;FEO`$YEX7)A\.MT92#^:6YU=.MS+@!.97)A<W1A<R!N
M96D@=FEE;F%S(&QA:?!K87,@871I=&EN:V%N=&ES(&K[<_@@<&%I9?!KX"X`
M3F7A<F'PZW1E('9A<F1O+@!.9>%R8?#K=&4@;G5M97)I;RX`3F5R;V1Y=&D@
MX?YE:63^:6%NZ&GX(&9R87II^`!.9>%V963K=&4@<VQA<'1A_F]D_FEO($A4
M5%`@875T96YT:69I:V%C:6IA:2X`3F7A=F5DZW1E('-L87!T8?YO9/YI;R!)
M34%0(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT92!S;&%P=&'^;V3^:6\@
M2V5R8F5R;W,@875T96YT:69I:V%C:6IA:2X`3F7A=F5DZW1E('-L87!T8?YO
M9/YI;R!,;V=I;B!A=71E;G1I9FEK86-I:F%I+@!.9>%V963K=&4@<VQA<'1A
M_F]D_FEO(%!!4U-71"!A=71E;G1I9FEK86-I:F%I+@!.9>%V963K=&4@<VQA
M<'1A_F]D_FEO(%--0B!A=71E;G1I9FEK86-I:F%I+@!.9>%V97-T87,@:V5L
M:6%S(&EK:2!/<&5N4U-,('!A9W)I;F1I;FGX(&9A:6SX+B!/<&5N4U-,(')E
M:6MA;&EN9V$@9&%R8G5I('-U(%!+0U,@,3(@9'5O;65N:6UI<RX`3F5P871V
M:7)T:6YT^"!R96=I<W1R86-I:O@@;NMR82X`3F7A:V5L=&D@:F]K:64@4$=0
M('-L87!T:65J:2!R86MT86DN`$YEX6ME;'1I(&IO:VEE(%!'4"!V:67P:65J
M:2!R86MT86DN`$YEX6ME;'1I(&IO:VEE(%,O34E-12!S97)T:69I:V%T86DN
M`$YE;F%U9&]T:2!S:VER='5K^`!.ZR!V:65N;VIE('!U<^MJ90!+;&%I9/@@
M=&EK<FEN:6UO('!R;V=R86UA(&YE<W5K;VYF:6?[<G5O=&$N`%)A\'EB;W,@
M:VQA:63X(&[K<F$`4&%S:?ML>6WX(&[K<F$`4W!A<G1I;FEM=6D@;NMR82!L
M86EK:6YO:F\@:V%T86QO9V\N`$YE<&%S:7)I;FMT87,@=F%R=&]T;VIA<RX`
M5F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES(&YE;G5S:?AS
M=&%S+@!496ES:6YG^"!834P@9'5O;65N^"!NZW)A`$[K<F$@<F5I:_!M:?@`
M2V]N9FEG^W)A8VEN:6%M92!F86EL92!NZW)A('9E<G-I:F]S+B!097)G96YE
M<G5O:VET92!N=7-T871Y;75S+@!+;VYF:6?[<F%C:6YI86UE(&9A:6QE(&[K
M<F$@=F5R<VEJ;W,N(%!E<F=E;F5R=6]K:71E(&YU<W1A='EM=7,N`$YE9&%L
M>79I<P!.:65K;P!.ZW)A`-!I875RZW,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK
M;R!S86QO<P!.;W)M86QU`-!I875R:6[K(&AE;6ES9F5R80#0:6%U<FENZW,@
M36%R:6IA;O@@<V%L;W,`3F]R=F5G:6IA`$YE('!O('1O`$YE('!R:67P('1A
M:0!.96GP=')I;G1I`$YE('!A<G5O\&EN:6%I`$YE<W9A<F+[<P!.92!A<VUE
M;FEN:6%I`$YE(&MA=&%L;V=A<P!.971I;FMA;6%S('9I9?!A<VES(')A:W1A
M<RX`3F5I\'1R:6YT:2!L86GP:V%I`$YE<F5A;&EZ=6]T82X`3F5S=F%R8OMS
M(&QA:?!K86D`3F5N=7)O9'ET80!.97!A;&%I:V]M87,N`%1A:2!G86QI('7^
M=')U:W1I`%7^<F'P86D`3NMR82!KX"!P97+^:?MRZW1I+"!E:6MI=&4@871G
M86PN`$QA<&MR:71I<P!.=6UE<FES`%-I;6)O;&GX('-K86GH:75S`%-T=6QP
M96QI^"!S:V%IZ&EU<P!+:65K(&WK;F5S:?@@;&%I:WET:2!S=7-I:G5S:75S
M('!R:6MA8FEN='5S(&9A:6QU<R!J96EG=2!T<FEN86UA(&MA<R!MZVYE<^$N
M`%-E;O@@<VGX<W3X(&QA:?!K^"!K871A;&]G^"!S:V%IZ&EU<R!I\'-A=6=O
M;6%S(&IE:2!T<FEN86UA(&MA<R!MZVYE<^$N`$5I;'7H:?@@<VMA:>AI=7,`
M3F7A=F5S=&D@9&ES=')I8G5C:6IO<R!SX')A\&\@871N875J:6YI;6\@<VMA
M:>AI86DN`$]+`$%20D$`3V)J96MT87,`3V)J96MT;R!S879I;FEN:V%S`$'P
M='5N=&%I;FES`%-P86QI<P#>:6%U<G5M;R!F:6QT<F%S`$]F:7-A<P!396YI
M(&QA:?!K86D`4V5N:2!S:?AS=/@@;&%I\&OX(&MA=&%L;V=A:2!B=7,@:?!V
M86QY=&DN`$]M86YA<P!+871A;&]G^"!D86QI:FEMX'-I('!A;&%I:V\@=&EK
M($E-05`@<V5R=F5R:6%I+@!2;V1Y=&D@=&EK(&MA=&%L;V=U<R!S=2!N97!E
M<G-K86ET>71A:7,@;&%I\&MA:7,_`%1I:R#A_F5I9/YI86[H:6]S(&9R87KK
M<P!,96ED_FEA;6%S('1I:R!V:65N87,@96PN('!A\'1O(&%D<F5S87,N`%!A
M<VER:6YK:71E('1I:R!V:65NX"!K871A;&]GX"#P:6%M('9E:6MS;75I+@!%
M;&5M96YT;R!S879I;FEN:V\@=&5I<V5S(&=A;&D@:V5I<W1I('1I:R!J;R!S
M879I;FEN:V%S(&%R8F$@<VES=&5M;W,@861M:6YI<W1R871O<FEU<P!!=&ED
M87)Y=&D@;F%U:F%M92!L86YG90!!=&ED87)Y=&%S(&MA=&%L;V=A<P!!=&ED
M87)Y=&D@\&G@(&YU;W)O9.`@;F%U:F%M92!L86YG90!/<')A8VENZW,@<VES
M=&5M;W,`4&%G86QB:6YI86D@9&%L>79I86D`3G5S=&%T>6UA:0`E<R!N=7-T
M871Y;6%I`%-U<OOP:75O=&%S('/@<F'P87,`3W)G86YI>F%C:6IA`%!A9&%L
M:6YY<P!3:7-T96UI;FEM87,`3W)I9VEN86QU<R!A<&QI:V%C:6IO<R#P86)L
M;VYA<P!/<FEG:6YA;/AS(/!A8FQO;F%I("5S.@!+:71A`$MI=&$@:6YF;W)M
M86-I:F$`2VET;W,@<&'P=&\@9.O^=73K<P!+:71I(&YU<W1A='EM86D`4V%V
M:6YI;FEK;R!T96ESZW,`3NMR82!004T@875T96YT:69I:V%C:6IO<R!M96-H
M86YI>FUO+@!01U``4$=0('-K86ET;65N:6YI<R!P87)A\&%S`%!'4"!U_FMO
M9'5O=&D`4$=0('7^:V]D=6]T82!I;F9O<FUA8VEJ80!01U`@:VQA:61A.B``
M4$=0(&ML86ED83H@87-M96YI;FEA;2!S;&%P=&%M(')A:W1U:2!R96EK86QI
M;F=A('-L87!T82!F<F%ZZRX`4$=0(&YU<W1A='EM86D`4$=0('-L87!T;W,@
M9G)A>NMS(.%V961I;6%S`%!'4"!R86MT^"!P;W)O<R!O<&5R86-I:F]S(')E
M:6MA;&%U:F$@<V%U9V%U<R!P<FES:6IU;F=I;6\N`%!'4"!V:67P87-I<R!R
M86MT87,`4$=0('9I9?!O:F\@<F%K=&\@=&5K<W1A<P!01U`@=FEE\&%S:7,@
M<F%K=&%S("(E<R`H)7,I(B!B=79O('/K:VUI;F=A:2!P<FEJ=6YG=&%S+@!0
M1U`@=FEE\&%S:7,@<F%K=&%S("(E<R(@8G5V;R!SZVMM:6YG86D@:?!T<FEN
M=&%S+@!01U`@=FEE\/AJ^"!R86MT^"!S875G>6ML80!01U`@<&%S:7)A\'ET
M:0!01U`@<&%S:7)A\'ET:2!I<B!U_FMO9'5O=&D`4$=0('!A<VER8?!Y=&DO
M=?YK;V1U;W1I(&1U;VUE;GES`%!'4"!S;&%P=&%S:7,@<F%K=&%S('/K:VUI
M;F=A:2!P<FEJ=6YG=&%S+@!01U`@=FEE\&%S:7,@<F%K=&%S('/K:VUI;F=A
M:2!P<FEJ=6YG=&%S+@!01U`@<&%L86EK>6UA<R!I\&IU;F=T87,N`%!A=&EK
M<FEN=&D@<VMA:71M96YI;FEO('!A<F'P;R!N96=A;&EM82P@;F5S(&GP:G5N
M9W1A(%!'4"!G86QI;7EBZRX`071K;V1U;W1I(&QA:?!K;R!N96=A;&EM82P@
M;F5S(&GP:G5N9W1A(%!'4"!G86QI;7EBZRX`4$A0(&MO9&%S`%!(4"!#3$D`
M4$T@;&5N9W9A<R!L:65T=7,`4$T@;&G[=&ES`%!-(%0M875D<F$`4$]0,P!0
M3U`S("A!=71O;6%T:6YI<R!P<F]T;VMO;&\@871P8?YI;FEM87,I`%!/4#,@
M<&5R(%-33`!03U`S('!E<B!34TP@*&)E($-!('-E<G1I9FEK871O*0!03U`S
M('!E<B!34TP@*&)E($-!('!A<F'P;RD`4$]0,RP@8F4@5$Q3`%!?2%`@0TQ)
M`%1A<G!A:2!C96SK<V4`4'5S;&%P:7,@)60@:?`@)60`4'5S;&%P:7,@<W4@
M<&ER;6$@;F5P97)S:V%I='ET82#^:6YU=&4`4'5S;&%P:7,@<W4@<&%S:W5T
M:6YE(&YE<&5R<VMA:71Y=&$@_FEN=71E`%!A:VES=&%N87,`4&%L874`5?YI
M;71O:FD@4&%L97-T:6YO<R!T97)I=&]R:6IA`%!A;F%M80!087!U82!.875J
M;VII($=V:6[K:F$`4&%R86=V86IU<P!$86QI<RAY<RD`1&%L:6YA:2!D96)E
M<W5O=&$`4VQA<'1A(&9R87KK`%-L87!T82!F<F%ZZR`H9&%R(&MA<G3@*0!3
M;&%P=&$@9G)A>NL@<^MK;6EN9V%I(&%T:G5N9W1A+@!3;&%P=&$@9G)A>NLZ
M`%-L87!T82!F<F%ZZR!N96=A;&D@8OMT:2!T=?#H:6$`4VQA<'1O<R!F<F%Z
MZW,@;F5S=71A;7!A`%-L87!T8?YO9&ES`%-L87!T8?YO9&ES(&YE=&5I<VEN
M9V%S`%)!1$E54R!A=71E;G1I9FEK86-I:F%I(')E:6MI82!S;&%P=&'^;V3^
M:6\N`%-L87!T8?YO9&ES('-U('!A='9I<G1I;FEM=0!3;&%P=&'^;V1I<SH`
M4VQA<'1A_F]D:7,Z(`!3;&%P=&'^;V3^:6%I('1U<FD@<W5T87!T:2X`P6ME
M;'1I`,%K96QT:2!I\"!L86EK:6YO<VEO<R!S875G>6ML;W,@*&-L:7!B;V%R
M9"D`2V5L:6%S`$YE<&%T=FER=&EN=&]S(')E9VES=')A8VEJ;W,Z`-YM;V[K
M<P!0<F]C96YT86D`071L:6MT:2!P<F]F:6QA:W1I;FEU<R!V96EK<VUU<P!0
M87-I<FEN:W1I(&%R('9Y:V1Y=&D@<')O9FEL86MT:6MO<R!V96EK<VUU<R!P
M<FES:6IU;F=U<S\`5&5I<^MS`%1E:7-I^"!A9&UI;FES=')A=FEM87,`2V5I
M<W1I('1E:7-I^"#P:6%M('9A<G1O=&]J=6D@;F5G86QI;6$N`$%S;65N:6YI
M86D`07-M96YI;NL@:6YF;W)M86-I:F$`07-M96YI;NL@4$=0(')A:W3X('!O
M<F$@<^MK;6EN9V%I('-U9V5N97)U;W1A+@!!<VUE;FEN:6%I(%!'4"!R86MT
M86D@<^MK;6EN9V%I(&GP=')I;G1I+@!!<VUE;FEN:6%I(%,O34E-12!S97)T
M:69I:V%T86D@3D7!2T5,5$DZ(`!!<VUE;FEN:6%I(%,O34E-12!R86MT86D@
M<^MK;6EN9V%I(&GP=')I;G1I+@!097)U`$=Y=OMN86D`1FEL:7!I;F%I`%1E
M;&5F;VYA<P!.=6]T<F%U:V]S`%!I=&MR86YA<P!0:6MS96QI86D`4')I9.MT
M:2!P87)A\.`@<')I9?`@=&5K<W3@(&%T<V%K:6[K:F%N="!I<B!P97)S:75N
MZ&EA;G0_`%1E:W-T:6[K(&QA:?!K;R!V97)S:6IA`$)A;F%L>6+K<P!)\'-I
M<FEN:VET92!K=7)IX"!N;W)S(&-E;.8`4&%T=FER=&EN:VET92P@87(@=&EK
M<F%I(&YO<FET92!I\'1R:6YT:2#PX2!E;&5M96YTX#H`4&%T=FER=&EN:VET
M92P@87(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#P:6\@96QE;65N=&\@;G5O
M<F]DX"X`P79E<VMI=&4@;>MN97/A(&ER(&UE='5S+@#!=F5S:VET92!N875J
M;W,@:V%T96=O<FEJ;W,@<&%V861I;FEMX#H`P79E<VMI=&4@;F%U:F\@:V%T
M86QO9V\@<&%V861I;FEMX#H`P79E<VMI=&4@=&5I<VEN9^`@25`@861R97/@
M+@#!=F5S:VET92!T96ES:6YGX"!D873@+"!P871I:W)I;FMI=&4@9&EE;O@@
M<VMA:>AI^"!MZVYE<WEJ92X`P79E<VMI=&4@=&5I<VEN9^`@;&%I:^`N`,%V
M97-K:71E(&YA=6IO(&MA=&%L;V=O('!A=F%D:6YI;>`Z`,%V97-K:71E(&YA
M=6K@('9A<F3@.@#!=F5S:VET92!01U`@<F%K=&\@<VQA<'3@:N`@9G)A>N8N
M($K@(')E:6OK<R#A=F5D:6[K=&D@=&EK(&MA<G3@('!E<B`E<R!S97-I:N`N
M`,%V97-K:71E(%,O34E-12!R86MT;R!S;&%P=.!JX"!F<F%ZYBX@2N`@<F5I
M:^MS(.%V961I;NMT:2!T:6L@:V%R=.`@<&5R("5S('-E<VEJX"X`3F]RZV1A
M;6D@=.9S=&DL('!R:7-I:G5N:VET92!I\"!N875J;RX@2F5I9W4@:OMS($Y%
M3D%51$]*051%("=S875S86ENZVQI^"<@25(@<F'P;W1E(&QA:?!K=7,@871S
M:VER86UE(&QA;F=E+"!T86EP('!A="!T=7+K<VET92!P<FES:6IU;F=T:2!I
M<B!P86=R:6YD:6YA;64@;&%N9V4N(%1A:7`@9&%R;VUA+"!N;W)I;G0@87!S
M875G;W1I(&K[<_@@<V5S:6IO<R!)1"!N=6\@9V%L:6WX(.%S:6QA=?[K;&GX
M+B!!='-I<')A\&]M92!U_B!N97!A=&]G=6UU<RX`07!R8?!Y:VET92!P<F]B
M;&5MX"X`3G5R;V1Y:VET92!S879O('-L87!T8?YO9.$N`$YU<F]D>6MI=&4@
M<V%V;R!V87)T;W1O:F\@=F%R9.`@8F5I('-L87!T8?YO9.$`3G5R;V1Y:VET
M92!S879O('9A<G1O=&]J;R!V87)DX"X`2?!T86ES>6MI=&4@;F5T96ES:6YG
M=7,@861R97-U<RX`4&5R<VMA:71Y:VET92!I;F9O<FUA8VEJX"!I<B!I\"#^
M96UI874@97-A;NAI;R!M96YI=2!P87-I<FEN:VET92!N;W)I;>`@=F5I:W-M
MX"X`4&%S:7)I;FMI=&4@:V%T86QO9^`@<')I9?`@871L:6MD86UI(&)E;G0@
M:V]K:75S('9E:6MS;75S+@!087-I<FEN:VET92!V96EK<VW@(&GP(&UE;FEU
M(/YE;6EA=2X`4&%S:7)I;FMI=&4@8F5N="!V:65NX"!K871A;&]GX"!P86EE
M\&MA:2X`4&%S:7)I;FMI=&4@=&EK('9I96[@(&MA=&%L;V?@(/!I86T@=F5I
M:W-M=6DN`%!A<VER:6YK:71E(&%R8F$@<F5D86=U;VMI=&4@;&%U:^`@9&7P
M:6[K:F4Z`,%V97-K:71E(&YA=6K@(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z
M`$QE;FMI:F$`4&]L:71I:V%I`$)A;'-A=FEM86D`4&]R='5G86QI:F$`4&%V
M96EK<VSK;&EO('!O>FEC:6IA`$QE;G1E;.MS('!O>FEC:6IA`$GP<V%U9V]T
M:2#P:6%M92!K871A;&]G92`H;F5G86QI;VIA($E-05`I`%-E<G9E<GEJ92!V
M96EK:6$@2&]R9&4`4')A9.MT:2!P87)A\.`@8G+[:_!N96QI86ES("@G+2T@
M)RD_`$MR:71U;&EA:2!P87-K+B`E<R!V86QA;F3@*&%S*3H@`$YU<W1A='EM
M86D@<^MK;6EN9V%I(&%T;F%U:FEN=&DN`%!R969S7VQD87`Z(&YE<F%S=&%S
M(')E:6MA;&EN9V%S($Q$05`@;6]D=6QI<RX`4')E9G-?<V5S<VEO;CH@;F5R
M87-T87,@<F5I:V%L:6YG87,@<V5S:6KX(&UO9'5L:7,N`%-LZV=I<P!3;.MG
M:7,@:OMR;W,@;'EG>6IE.B``4VSK9VES.B``4&5R_FG[<F$`4&5R_FG[<NMT
M:2!P879E:6MS;.MLX2!N875J86UE(&QA;F=E`$%N:W-T97-N:7,@;&%I\&MA
M<P!!;FMS=&5S;FES('!U<VQA<&ES`$%N:W-T97-N:2!N=7-T871Y;6%I`%-P
M875S9&EN=&D`071S<&%U<V1I;G1I(&1O:W5M96YTX`!3=F%R8F$`4VQA<'1A
M<VES(')A:W1A<P!0<F]B;&5M80!0<F]B;&5M;W,@87!R8?!Y;6%S`%!R;VIE
M:W1A:0!+;&%U<W1I(&MI96MV:65NX"!K87)TX"!K86D@<VEU;NAI86UA<R!P
M<FEK86)I;G1A<R!F86EL87,[('!R861I;FES($Y%`$ML875S=&D@:VEE:W9I
M96[@(&MA<G3@(&MA:2!S:75NZ&EA;6%S('!R:6MA8FEN=&%S(&9A:6QA<SL@
M<')A9&EN:7,@5$%)4`!0<F'P>6UA<R!T96MS='5I`%!R;W1O:V]L87,Z`%9I
M9?!A<VES(')A:W1A<P!6:67P;VIO(')A:W1O(&%L9V]R:71M87,`5FEE\&]S
M:6]S(%!'4"!R86MT^"!S875G>6ML;W,@<&%L86EK>6UA<R!I\&IU;F=T87,N
M`%9I9?!O:F\O<VQA<'1O:F\@<F%K=/@@<&]R82!N97-U9V5N97)U;W1A+@!0
M=65R=&\@4FEK87,`25_P=F%L>71I(&GP=')I;G1U<P!)\'9A;'ET:2!I\'1R
M:6YT=7,`2?!V86QY=&D@:V%T86QO9^`H=7,I`-!I=6OP;&EA9.O^ZW,@=F%L
M>6UO(&1A_FYU;6%S.@!)\'1R:6YT:2!L86GP:W5S(&GP(/!I=6OP;&EA9.O^
MZW,@<V5N97-N:75S(&YE:2!T:65K(&1I96[X+@!)\'1R:6YT:2!S96YU<R!L
M86GP:W5S(/!I=6OP;&EA9.O^ZVIE/P!+871A<F%S`%-A:VEN>7,`3F%U9&]J
M86UA('9I971A.B`E+C)F34(@:?`@)2XR9DU"("`H)2XR9B4E*0!.875D;VIA
M;6$@=FEE=&$Z("4N,F9-0B`O($Y%05!224)/5$$`3F%U9&]J86UA('9I971A
M.B!.14%04DE"3U1!`%)302!V:67P87-I<R!R86MT87,@*"5D(&)I=&%I*0`G
M4F%D:6\G('!A<VER:6YK:6UA<P!,:65T=7,`3&EE='5S(')Y=&4`3&EE='5S
M('9A:V%R90!,:?MT:7,`071S:71I:W1I;NL@9G)A>NL`4V%N='EK:7,`4F5I
M:V%L875T:2!P<FES=&%T>6UO('!A='9I<G1I;FEM;P!3:V%I='ET:0!097)S
M:V%I='ET:2!L86GP:V%I`%1I:W)A:2!I\'1R:6YT:2`E<S\@1W)A_FEN=&D@
M871G86P@;F5B96=A;.MS:71E+@!4:6MR86D@:?!T<FEN=&D@=F%R=&]T;VIO
M("5S(&1U;VUE;FES/R!'<F'^:6YT:2!A=&=A;"!N96)E9V%LZW-I=&4N`$=A
M=71A`$=A=71A(&YU;P!'875T82!I:VD`3G5K<F5I<'1I`$YU:W)E:7!T:0!.
M=6MR96EP=&D@;&%I\&O@`$QA:?!K;R!N=6MR96EP:6UA<P!.=6MR96EP:6UA
M<R!N97!A=GEK;RX`4&%K87)T;W1I(&%N:W-T97-NX2!V96EK<VW@`$%T;F%U
M:FEN=&D`071N875J:6YT:2!K86ER:6]J;R!M96YI=2!E;&5M96YT=7,Z`$%T
M;F%U:FEN=&D@:V%T86QO9V\@=F%I>F3@.@!!=&YA=6II;G1I('!O<G1A;&\@
M=F%I>F3@.@!296=E>`!3X')Y\&GX(&YA<O!Y:VSK`$%T;F%U:FEN=&D@=F%I
M>F3@`%!A<W1A8F]S`%!R:7-I;6EN=&D@=?YI;71U;6\@:6YF;W)M86-I:N`N
M`%!R:7-I;6EN=&D@<&%S:W5T:6[A('9A:7IDX`!.=71O;'5S:2!P8?!T;R!D
MZ_YU=.LZ`$YU=&]LYB!S97)V97)I86D`3G5T;VSF<R!54DP@*&AT='`Z+R]W
M=W<N<&%V>7ID>7,N8V]M+VAO<F1E*3H`2?!T<FEN=&D`4&'P86QI;G1I(&)L
M;VO@`%!A\&%L:6YT:2!L875K=7,@:?`@<&%I9?!K;W,`4&%N86EK:6YT:2!S
M='5L<&5LX0!086YA:6MI;G1I(&9O<FUA=&%V:6W@`$GP=')I;G1I('!O<N``
M2?!T<FEN=&D@871N875J:6YI;6\@<VMR:7!TX"!I\"!S97)V97)I;R!L86EK
M:6YO:F\@:V%T86QO9V\N`%!A;F%I:VEN=&D@\&%L=&ENX0!08?!A;&EN=&D`
M4&'P86QI;G1I(/#A(&5L96UE;G3@(&GP(&1O:W5M96YT;P!)\'1R:6YT:2!V
M87)T;W1O:N``5F%R=&]T;VIO('1R>6YI;6%S.B`E<P!097)V87)D:6YT:2!K
M871A;&]GX"AU<RD`4&5R=F%R9&EN=&D@<VGX<W3X(&QA:?!K^"!K871A;&]G
MX"!MZVYE<VEO('!R863^:6]J93\`4&5R=F%D:6YI;6%S(&GP("(E<R(@X2`B
M)7,B(&YE<&%V>6MO+B!397)V97)I;R!P<F%N9?!I;6%S('1O:W,`071S86MY
M=&D@X2!K;VYF97)E;E]C:6K@`%-U:V5I<W1I('-U.@!!='-A:WET:0!!='-A
M:WEM87,@:?!S:?AS=&%S+@!!='-A:WET:2!V:7-I96US`$%T<V%K>71I('9I
M<VEE;7,Z`$%T<V%K>71I(.$@:V]N9F5R96YC:6K@`$%T<V%K>71I(.$@:V]N
M9F5R96YC:6K@.@!!='-A:WET:2!V:7-I96US`$%T<V%K>6UO(&QA:?!K;R!T
M:7!A<R!N97!A;&%I:V]M87,`071S86MY=&D@<W4@=?YI;71U;6\@:6YF;W)M
M86-I:F$@<V5K86YT:65M<R`R(&WK;F5S:6%M<RX`071S86MY=&D@<W4@=?YI
M;71U;6\@:6YF;W)M86-I:F$N`%)E<&QY+51O`%)E<&QY+51O.B``071S86MY
M;6%S.@!.92!N97!A9V5I9&%U:F%M87,@*'-P86TI`$YE<&%G96ED875J86UA
M<R`H<W!A;2D`4F5I:V%L875T:2!P97)S:V%I='EM;R!P871V:7)T:6YI;6\`
M3F5G86QI=2!A='-A:WET:2#A('7^:VQA=7/@+B!+;&%I9&]S(&MO9&%S.B``
M4F5I:V%L875T:2!P<FES=&%T>6UO('!A='9I<G1I;FEM;S\`4F5I:V%L875T
M:2!P97)S:V%I='EM;R!P871V:7)T:6YI;6\_`$YU<F]D>71A<R!L86GP:V%S
M(&YE<F%S=&%S+@!296EK86QI;F=A<R!D86QY=FES`$GP=F%L>71I`%!A:V5I
M<W1I('-L87!T8?YO9.$`4VQA<'1A_F]D_FEO(&ME:71I;6%S`$%T<V%K;W9O
M('-T871U<V%S(&%T;F%U:FEN=&%S+@!297IU;'1A=&%I`%)E9&%G=6]T:0!4
MYG-T:2!J^W/X('-E<VEJX`!'<N'^=&D@X2!L86GP:_@@<&'K;6EMX`!'<N'^
M=&D@X2!N=7-T871Y;75S`$=RX?YT:2#A('!A\'1O(&3K_G5TYB!P;R!L86GP
M:V\@=')Y;FEM;RP@<&5R:^ML:6UO(&%R(&MO<&EJ879I;6\_`%)E:OMN:6IA
M`$%T<W1A='ET:2!K;VYF:6?[<F%C:6K@`$A434P@<F5D86MT;W)I875S(&YU
M<W1A='EM86D`3>%S;.MS`$1E\&ENZVIE`$1E\&EN:6]J:2!A;G1R8?!TZP!$
M9?!I;FEO<VEO<R!R96EK\&WK<P!?16EL=73K<R!N=7-T871Y;6%I+BXN`%)O
M;.L`4G5M=6YI:F$`4&%S=6MT:2`Q.#``4&%S=6MT:2!K86ERZVX`4&%S=6MT
M:2!D9?!I;NMN`$5I;'5TZW,@;G5S=&%T>6UA:0!%:6QU=.MS(&YU<W1A='EM
M86D`16EL=73K<SH`4VMI<G1U:V%I`%-K:7)T=6MA:2!T87)P('9I<_@@96EL
M=>AI^"!I<B!S='5L<&5L:?@`4VMI<G1U:V%I('1I:R!T87)P('-T=6QP96QI
M^`!3:VER='5K86D@=&EK('1A<G`@96EL=>AI^`!6>6MD>71I`%)U<VEJ;W,@
M1F5D97)A8VEJ80!2=6%N9&$`4R]-24U%`%,O34E-12!P87)A\&%S`%7^:V]D
M=6]T:2!L86GP:^`@4R]-24U%(')A:W1U`%,O34E-12!U_FMO9'5O=&%S(&QA
M:?!K87,`4R]-24U%(&ML86ED83H@`%,O34E-12!K;&%I9&$Z(&%S;65N:6YI
M86T@<VQA<'1A;2!R86MT=6D@<F5I:V%L:6YG82!S;&%P=&$@9G)A>NLN`%,O
M34E-12!N=7-T871Y;6%I`%,O34E-12!S;&%P=&]S(&9R87KK<R#A=F5D:6UA
M<P!3+TU)344@<F%K=/@@<&]R;W,@;W!E<F%C:6IO<R!R96EK86QA=6IA('-A
M=6=A=7,@<')I<VEJ=6YG:6UO+@!3+TU)344@=FEE\&%S:7,@<F%K=&%S("(E
M<R(@8G5V;R!SZVMM:6YG86D@:?!T<FEN=&%S+@!3+TU)344@=FEE\&%S:7,@
M<F%K=&%S('/K:VUI;F=A:2!P<FEDZW1A<RX`4R]-24U%('9I9?#X:O@@<F%K
M=/@@<V%U9WEK;&$`4R]-24U%('9I9?!O:FDO<V%U9VD@<F%K=/@@<&]R82!S
MZVMM:6YG86D@<')I:G5N9W1A+@!3+TU)344@<&%S:7)A\'ET:0!3+TU)344@
M<&%S:7)A\'ET:2!I<B!U_FMO9'5O=&D`4R]-24U%(&=A;&EM>6+K(&GP:G5N
M9W1A+@!!=&MO9'5O=&D@;&%I\&MO(&YE9V%L:6UA+"!N97,@4R]-24U%(&=A
M;&EM>6+K(&GP:G5N9W1A+@!0871I:W)I;G1I('-K86ET;65N:6YI;R!P87)A
M\&\@;F5G86QI;6$L(&YE<R!3+TU)344@9V%L:6UY8NL@:?!J=6YG=&$N`$[K
M<F$@4T%33"!A=71E;G1I9FEK86-I:F]S(&UE8VAA;FEZ;6\N`%--4R#^:6YU
M=.MS`%-13"!#3$D`4U-(`%!!5EE+3P!37U%,($-,20!?5&5M80#09?!T+@!)
M\'-A=5]G;W1I(&MO<&EJX"!K871A;&]G92``2?!S875G7V]T:2!K86EP`-!V
M96YT;VII($AE;&5N80!386EN="!+:71S87,@:7(@3F5V:7-A<P!386EN="!,
M:75C:6IA`-!V96YT87-I<R!0971R87,@:7(@36EG96QO;F%S`%-A:6YT(%9I
M;F-E;G1A<R!I<B!'<F5N861I;F%I`%1A;64@<&'H:6%M92!L86YG92`H7W-E
M;&8I`%-A;6]A`%-A;B!-87)I;F%S`%-A;R!4;VUE(&ER(%!R:6YC:7#K`%!A
M;'ED;W9A<P!3875D;R!!<F%B:6IA`$GP<V%U9V]T:0!)\'-A=6=O=&D@)7,`
M2?!S875G;W1I('!R:6MA8FEN='5S(&9A:6QU<R!K87)T=2!S=2!L86GP:W4@
M<VGX<W3X(&QA:?!K^"!K871A;&]G93\`2?!S875G;W1I('!A<G5O\&ENX0!)
M\'-A=6=O=&D@;G5S=&%T>6UU<P!)\'-A=6=O=&D@7W!A<G5O\&ENX0!)\'-A
M=6=O=&D@:V%I<`!)\'-A=6=O=&D@<&%R=6_P:6[A(&MA:7`@;F5P97)S:V%I
M='ETX#\`2?!S875G;W1I('-U9V5N97)U;W1U<R!N=7-T871Y;75S(&MA:7`@
M4$A0('-K<FEP=.`@:OMS^"!S97)V97)I;R!L86EK:6YA:F%M92!K871A;&]G
M92X`2?!S875G;W1I(&=A=NMJ=7,@875T;VUA=&GP:V%I(.$@861R97/X(&MN
M>6=E;.8_`$GP<V%U9V]T:2!P86EE\&MO<R!R97IU;'1A='5S('9I<G1U86QI
M86UE(&MA=&%L;V=E/P!)\'-A=6=O=&D@:?!S:?AS='5S(&QA:?!K=7,_`"5S
M(&YU<W1A='EM86D@:?!S875G;W1I+@!)\'-A=6=O=&D@<&%R=6_P:6YI;R!N
M97!A=GEK;RX@4V5R=F5R:6\@<')A;F7P:6UA<R!T;VMS.B`E<P!-;VMS;&%S
M`$EE\&MO=&D`267P:V]T:2!K871A;&]G92`E<P!086EE\&MA`%!A:67P:V]S
M(')E>G5L=&%T86D`4VMA:71Y=&D`4&%S:7)I;FMI=&4`4&%S:7)I;FMI=&4@
M:VETX"!SX'-K86ETX`!087-I<FEN:VET92!F86EL=7,`4&%S:7)I;FMI=&4@
M9&%TX`!087-I<FEN:VET92!L875K96SA`%!A<VER:6YK:71E(&=R=7#F`%!A
M<VER:6YK:71E(&YA=6K@('-A=FEN:6YKX`!087-I<FEN:VET92!S97)V97+A
M`%!A<VER:6YK:71E('9A<G1O=&]JX`!087-I<FEN:VET92!A9')E<_@@:VYY
M9V5LYB!A9')E<_@@<&%I9?!K86D@:7(@<')I9.MJ:6UU:2X`4&'^>6WK=&D@
M=FES:^``4&%S:7)I;FMI=&4@=FES=7,@9&%T;W,@:V]M<&]N96YT=7,N`%!A
M<VER:6YK:71E(&QA=6ME;&EU<RP@:W5R:75O<R!N875D;W-I=&4@861R97/X
M(&GP<VML96ED:6UU:2X`4&%S:7)I;FMI=&4@<^!S:V%I=.``4&%S:7)I;FMI
M=&4@;V)J96MTX`!.97!A_GEMZW1I(&YI96MO`$GP(/YE;6EA=2!E<V%NZ&GX
M('/@<F'P^"!P87-I<FEN:VET92!R96EK:6%M=7,@<VEM8F]L:75S+B!6ZVQI
M874@9V%L:71E(&IU;W,@;G5K;W!I:G5O=&D@X2!L86GP:^`N`%!A<VER:6YK
M:71E(&1A=&]S('-K:7)T=6O@.@!087-I<FEN:VET92!D871O<R!F;W)M873@
M.@!087-I<FEN:VET92!A<')A\.`@:W5RX2!N;W)I=&4@<F5D86=U;W1I.@!0
M87-I<FEN:VET92!P8?!T;R!S97)V97)I;R!T:7#@`%!A<VER:6YK:71E(&QA
M:6MO('-K:7)T=6O@.@!087-I<FEN:VET92!L86EK;R!F;W)M873@.@!087-I
M<FEN:VET92!D=2!A=&ET:6YK86[H:75S(&QA=6MU<RX`4&%S:7)I;FMI=&4@
M<W!A;';X(&1E<FENX2X`4&%S:7)I;FMI=&4@;F]R:6W@(&MA;&+@.@!087-I
M<FEN:W1O<R!A9')E<_@@:VYY9V5LZW,Z`$YU<VGX<W1I(')A:W3@(.$@<F%K
M=/@@<V%U9WEK;.``4VGX<W1I(&YA=6IA=7-IX"!I;F9O<FUA8VEJX`!3:?AS
M=&D@;&%I\&O@`%-I^'-T:2!P<F]B;&5M;W,@<')A;F7P:6W@`%-I^'-T:2!3
M35,`4V5N96=A;&%S`%-E;G-O<FEU<SH@`%-I^'-T^"!L86GP:_@@:V%T86QO
M9V%S`%-I^'-T^"!L86GP:_@@:V%T86QO9V%S.@!2=6=SZVII<P!397)B:6IA
M(&ER($UO;G1E;F5G<F%S`%-E<FEJ;W,@;G5M97)I<P!397)V97)I<P!397)V
M97)I;R!I<B!K871A;&]G^"!I;F9O<FUA8VEJ80!397)V97)I<SH`4V5S:6IO
M<R!)1"!P87-I8F%I9^LN`%)I;FMI;GES`$YU<W1A='EM86D@;&5I9/YI86YT
M>7,@2G5M<R!P87-I:V5I<W1I('-L87!T8?YO9.$L(&IE:6=U(&KA(&MA9&$@
M;F]R<R!P86UI<O!I=&4N`$MA<R!B=7,@=GEK9&]M82!S=2!J^W/X(&QA:?!K
M86ES(&MA:2!J:64@=')I;F%M:2!A<F)A('!E<FME;&EA;6DN`$%R(&YA=61O
M=&D@<W9A<F)O<R!A;G1R8?!TYB!S:75NZ&EA;G0@;&%I\&MU<S\`3G5T;VQU
M<VGX('-E<G9E<FGX+"!K=7)I=6]S(&YO<FET92!M871Y=&D@:?`@<&]R=&%L
M;RP@;G5S=&%T>6UA:2X`2V%L8F]S+"!L86EK;R!Z;VYO<R!I<B!D871O<R!N
M=7-T871Y;6%I+@!0=7-L87!I;R!S<&%L=O@L(&%T<VEN875J:6YI;6\@9&'^
M;G5M;R!I<B!K:73X('9A:7ID879I;6\@<&%R86UE='+X(&YU<W1A='EM86DN
M`%)A<W1A<R!A=&YA=6II;FEM;R!S:W)I<'1A<P!3=2#P:75O('!A<F%M971R
M=2!G86QI;6]S(&ME;&EO<R!V:65T;W;K<SH@`%-E:?!E;&%I`$1A;&EN=&ES
M(&MA=&%L;V=A:7,`1&%L:6YT:7,@<&'P=&\@:V%T86QO9V%I<SH`1&%L:6YT
M:7,@<&'P=&\@:V%T86QO9V%I<R!S=2!K:71A:7,@=F%R=&]T;VIA:7,N`%!A
M<F1U;W1U=NL`5')U;7!A<R!A<')A\'EM87,`07(@;F%U9&]T:2!K;&%V:6%T
M^W)O<R!M>6=T=6MU<R!V86QD>6UU:3\`07(@9&ED96QI(&-I=&%T;W,@8FQO
M:V%I('-T86YD87)T:?!K86D@='5R:2!B^W1I(')O9&]M:2!A<B!P87-LZW!T
M:3\`07(@;F]R:71E(&QA:?!K;R!T96MS=&4@:67P:V]T:2!01U`@:6YF;W)M
M86-I:F]S/P!!<B!R8?!Y;6\@;&%N9V%S('1U<FD@=?YS:61A<GET:2!P;R!P
M87)U;_!I;FEO(&GP<V%U9V]J:6UO/P!!<B!N;W)I=&4@<')I92!K:65K=FEE
M;F\@<VEU;NAI86UO(&QA:?!K;R!P<FEK86)I;G1I('-A=F\@4$=0('9I9?#@
M:N$@<F%K=.`_`%)O9'ET:0!2;V1Y=&D@=FES=7,@:V%T86QO9W5S`%)O9'ET
M:2!V:7-A<R!A;G1R8?!T97,`4F]D>71I(&GP=')I;G1U<P!2;V1Y=&D@<&%G
M<FEN9&EN97,@86YT<F'P=&5S`%)O9'ET:2!K;VYF97)E;F-I:F]S(&EN9F]R
M;6%C:6K@`%)O9'ET:2!T:6L@=?YS:7!R96YU;65R=6]T=7,@:V%T86QO9W5S
M`%)O9'ET:2!N977^<')E;G5M97)U;W1U<P!2;V1Y=&D@=')Y;FEM;R!P:6MT
M;V=R86W@('!R:64@:VEE:W9I96YO('!R:6MA8FEN=&\@9F%I;&\@;&%I\&ME
M/P!087)O9'ET:2!S:VER='5M=7,@=&%R<"!I\'-A=6=O=&\@:7(@:^`@=&EK
M('-U9V5N97)U;W1O(&MO;F9I9_MR86-I;FEO(&9A:6QO+@!2;V1Y=&D@<&%S
M:W5T:6YI;R!P<FES:6IU;F=I;6\@;&%I:^`_`$QA:?!K^"!SX')A\&4@<F]D
M>71I('-P86QV^"!R96EK\&UE<S\`4F]D>71I(&=A;&EM>6+F('!A;&EK=&D@
M;W)I9VEN86S@`%)O9'ET:2!P87)I<VEN:VEMX`!)\&%N:W-T:6YI<R!P97+^
M:?MRZVII;6%S('1I:R!N97!E<G-K86ET>71O;7,@_FEN=73K;7,_`$%L=&5R
M;F%T>79U<R!N875J;R!P8?!T;R!P97+^:?MRZVII;6%S/P!2;V1Y=&D@;&5N
M=&5LZW,@;W!E<F%C:6KX(&UE;FEU/P!2;V1Y=&D@)7,@;65N:74@:V%I<NMJ
M93\`4F]D>71I("=086EM=&D@;&%I\&MU<R<@;7EG='5KX"!M96YI=3\`4&%R
M;V1Y=&D@<&%V96EK<VSK;&EU<P!2;V1Y=&D@8V5LZW,@;G5S=&%T>6WX(&QA
M;F?@`%)O9'ET:2!L96YT96SK<R!N=7-T871Y;?@@;&%N9^``4F]D>71I(&5I
M;'5TZW,@;G5S=&%T>6WX(&QA;F?@`%)O9'ET:2!F:6QT<O@@;7EG='5KX"!M
M96YI=3\`4F]D>71I('!A=F5I:W-LZVQI;R!N=7-T871Y;?@@;&%N9^``4F]D
M>71I(&)E;F1RX"!L86GP:_@@<VMA:>AI^"!K871A;&]G93\`4F]D>71I(&9A
M:6SX(.%KZVQI;>``3&G[=&ES`$QI^W1I<R!R>71E`$QI^W1I<R!V86MA<F4`
M4F]D>71I`%-U;6'^:6YT:0!3=6UA_FEN=&D@87)B82!P87-T=6UT:2!K86EM
M>6YI;FEU<R!B;&]K=7,`1'ED:7,`4VEE<F$@3&5O;NL`4F5G:7-T<F%C:6IA
M`%!A<F'P87,`4&%R8?!O(&%L9V]R:71M87,`4&%S:7)A\'ET:0!3:6YG87#[
M<F%S`$1Y9&ES`%!R86QE:7-T:2!P<F]F:6QA:W1I:^``4VQO=F%K:6IA`%-L
M;W;K;FEJ80!0^V=A`%-N:65G;R!G>6QI<SH@`%-N:65G;R!K:65K:7,@=F%N
M9&5N:74Z(`!3;VQO;6]N;R!S86QO<P!3;VUA;&EA`$1A:6YO<R!I<B!%:6SK
M<F'PZ&EA:0!2^_!I=6]T:2!P86=A;"!G879I;6\@9&%TX`!2^_!I=6]T:2!P
M86=A;"!P87)A\'EM;R!D873@`%+[\&EU;W1I('!A9V%L('-I=6YTZVK@`%+[
M\&EU;W1I('!A9V%L(&QA:?!K;R!D>63A`%+[\&EU;W1I('!A9V%L('!A=F%D
M:6YI;>``4OOP:75O=&D@<&%G86P@=&5MX`!2^_!I=6]T:2!P86=A;"!A9')E
M<V%TX`!2^_!I879I;6\@='9A<FMO<R!P87-I<FEN:VEM87,`4VEU;G3K:F\@
M861R97-A<P!0:65T^"!!9G)I:V$`4&EE=/@@175R;W!O<R`H25-/+3@X-3DM
M,RD`4&EE=/@@1/YO<F3^:6IO<R!I<B!0:65T^"!386YD=FGH;R!S86QO<P!0
M:65T:6[K(&AE;6ES9F5R80!487)P87,@=&%R<"!C96QI^`!487)P87,@=&%R
M<"!C96SK<R!T=7)I;FEO(&ER(&MR8?!T:6[K<P!487)P87,`5&%R<&%I('1A
M<G`@8V5L:?@`5&%R<&%I`$ES<&%N:6IA`%-P86UA<P!.97!A9V5I9&%U:F%M
M^"`H<W!A;2D@;&%I\&OX(&MA=&%L;V=A<SH`4W!E8VEF:6YI^"!S:6UB;VQI
M^"#A=&5R<&EM87,`4W!E8VEA;/MS('-I;6)O;&EA:0!+;&%I9/@@=&EK<FEN
M:6UA<P!+;&%I9/@@=&EK<FEN:6UA<P!+;&%I9/@@=&EK<FEN:6UA<R!B86EG
M=&%S`$ML86ED^"!S:V%IZ&EU<R!P=7-L87!Y:F4@<F'P>6)O<R!T:6MR:6YI
M;6\@;65T=2X`4&5R<VME;'1I(&-E;.8`4&5R<VME;'1I('-T=6QP96SA`%!E
M<G-K96QT:2!E:6QU=.8`4W!O<G1A<P#0<FD@3&%N:V$`4W1A;F1A<G1A<P!3
M=&%R(%1R96LG87,`4')A9.MT:0!0<F%D:6YI86D@;65T86D`4F%J;VYA<R!A
M<F)A('!R;W9I;F-I:F$`4W1A='5S87,`4V%U9V]J:6UO(&9O<FUA=&%S`$=A
M=';K<R!A9')E<V%S`%7^8G)A=6MT:0#>;V3^:?@@<^!R8?!A<P!)\'1R:6YT
M:2!P<FEK86)I;G3@(&9A:6S@`$YU:6UT:2!D;VUE;N`@;G5O(&%D<F5S;P!)
M\'9A;'ET:2!T=?#H:6%S(&5I;'5T97,_`%-T:6QI=7,@6T-34UT`4V5K;2X`
M5&5M80!496UA`%1E;6]S(&QA=6MA<P#!=F5S=&D`4')E;G5M97)U;W1I(&MA
M=&%L;V?@*'5S*0!);F1E:W-A<P!3ZVMM:6YG80!+;VYF:6?[<F%C:6IA(&%T
M<W1A='ET82!SZVMM:6YG86DN(%!E<FMR875K:71E('!U<VQA<.$L(&MA9"!P
M86UA='ET=6WK=&4@<&%K96ET=6UU<RX`071S87)G:6[K(&MO;F9I9_MR86-I
M:F]S(&MO<&EJ82!SZVMM:6YG86D@:?!S875G;W1A+@`G)7,G('/K:VUI;F=A
M:2!U_G)A\'ET87,N`%-U9&%N87,`4&%S:?ML>6UA:0!4=7)I;GES`%-A=6SK
M=&5K:7,`4V%U;.ML>6=I<P!3875LZW1A`%-A=6SK=&5K:7,`4V%U;.MT96MI
M<R]3875LZVQY9&ES`%-A=6SK=&5K:7,Z(`!3875LZVQY9VES`%-A=6SK;'EG
M:7,Z(`!,86EP<VYI<P!!<'1A<FYA=FEM87,`4W5R:6YA;6%S`%!A=F%R9.L`
M4W9A;&)A<F1A<R!I<B!$_F%N;6%I;F%S`%-V87II;&%N9&%S`-!V961I:F$`
M3&%I\&MO(')A\'EM;R!B^V1O('!E<FIU;F=I;6%S`%!E<FIU;F=T:2#A($A4
M34P`4&5R:G5N9W1I(.$@<&%P<F%S=.`@=&5K<W3@`-!V96EC87)I:F$`4VEN
M=&%K<^MS(&ML86ED82!P86EE\&MO<R!K<FET97)I:G5J90!3:7)I:F]S($%R
M86+X(%)E<W!U8FQI:V$`5"UA=61R80!4+6%U9')O<P!44U8@9F%I;&%S`$QE
M;G1E;.L`3&5N=&5LZW,@;G5S=&%T>6UA:0!,96YT96SK<R!N=7-T871Y;6%I
M`%1A:79A;F%S`%1A:79A;F%S+"!+:6YI:F]S('!R;W9I;F-I:F$`5&%D_FEK
M:7-T86YA<P!*=6YG=&ENZR!486YZ86YI:F]S(%)E<W!U8FQI:V$`5&%I:VEN
M>7,Z`$1A<F)A:0!47V5K<W1A<P!496QE9F]N;R!N=6UE<FES`%1E;7`N('!A
M<VLN('9A;&%N9.`Z(`!496UP97)A=/MR80!496UP97)A=/MR83H@`-!A8FQO
M;O@@861M:6YI<W1R879I;6%S`$QA:6MI;F%I('!R:6EM=&D@=?YK;&%U<^``
M3&%I:VEN86D@<')I:6UT87,`4F5G:7-T<F%C:6IO<R!SX&QY9V]S(&YE;G5R
M;V1Y=&]S(&-O;F8N<&AP(&9A:6QE`%1I:R!T96MS=&%S`$QY9VEU;W1I('1E
M:W-TX`!496MS=&\@=FER\'5J90!+971V+@!486EL86YD:65T:?!K82`H5$E3
M+38R,"D`5&%I;&%N9&%S`$'H:?L@:V%D(&YA=61O:F%TZW,@<VES=&5M82X`
M3NMR82!&5%`@;6]D=6QI;RX`3&%I\&MO($YU;SH@;&%U:V5L:7,@='5R:2!B
M^W1I('-U<VEE=&%S.@!(;W)D92]+;VQA8B!I;G1E9W)A8VEJ;W,@=F%R:6ML
M:75K87,@;F5P86QA:6MO("(E<R(`36%C:6YT;V-H(')E<W5R<V%I`$UA8VEN
M=&]S:"!R97-U<G-A:2!G86QI(&+[=&D@871S:?AS=&D@:?`@)7,N`$YE<&%V
M>6MO('7^:W)A=71I($UA:6YT96YA;F-E.CH@:VQA<^MS`$YU<W1A='EM^"!L
M86YG87,@=?YD87)Y=&%S+B!)\&5I;G4N`%/@<VMA:71A("(E<R(@:?!T<FEN
M=&$N`%/@<VMA:71A("(E<R(@:?!S875G;W1A+@!*96EG=2!N;W)I=&4@;F%U
M9&]T:2!N=7-T871Y;75S+"!P87!R8?!Y:VET92!K860@861M:6YI<W1R871O
M<FEU<R!S=6MO;F9I9_MR=6]T^"!P87-T;W9IX"!D=6]M96[X(&)A>N8@;G5S
M=&%T>6UA;7,@<V%U9V]T:2X`4')I:V%B:6YT87,@9F%I;&%S(&YE<F%S=&%S
M+@!4:6L@87!A=&ENZVIE('!U<^MJ90!.97!A=GEK;R!A=&ED87)Y=&D@<F'P
M>6UO(&QA;F=O+B!'86QB^W0@:OMS^"!N87+P>6MLZR!B;&]K=6]J82!N875J
M=7,@;&%N9W5S/P!.9>%R8?#K=&4@8V]N=&%K=&\@240@;G5M97)I;R!A<F)A
M(&II<R!N97)A<W1A<R!D=6]M96[X(&)A>NMJ92X`2V]N=&%K=&%S('/K:VUI
M;F=A:2#A=')A=6MT87,@X2!*^W/X(&%D<F5S^"!K;GEG96SF+@!-86-I;G1O
M<V@@9F%I;&\@='5R:6YY<R!I\&3K<W1Y=&%S(&%P8>AI;VIE+@!%<V%M87,H
M:2D@:V%T86QO9V%S*&%I*2`B)7,B(&)U<R!P97)V87)D:6YT87,H:2D@X2`B
M)7,B+@!.97!A=GEK;R!G875T:2!V87)T;W1O:O@@=&5I<VGX(/!I86T@:V%T
M86QO9W5I`$YO<NMD86UI('!A=&EK<FEN=&D@;&%I\&O@('!R:79A;&]T92!T
M=7+K=&D@871S:VERX"!01U`@<&%R8?!O(&)L;VO@+@!.9>%R8?#K=&4@9&ES
M=')I8G5C:6IO<R!SX')A\&\@240@87)B82!J:7,@;F5R87-T87,@9'5O;65N
M^"!B87KK:F4N`$YEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P;RX`4&%R
M=6_P:6YY<R!I\'-A=6=O=&%S(&MA=&%L;V=E("(E<R(N`%!'4"!U_FMO9&%V
M:6UO(&=A;&EM>6+K(')E:6MA;&%U:F$@<V%U9V%U<R!P<FES:6IU;F=I;6\N
M($)A;F1Y:VET92!R8?!Y=&D@:'1T<',Z+R\@861R97-O('!R863^:6]J92X`
MP79Y:VES(.%R8?!Y=&%S(.$@:OMS^"!K86QE;F1O<FGX+@!&86EL87,@)7,@
M<')I=F%L;R!T=7+K=&D@)7,@<&%R86UE='+@+@!&86EL87,@)7,@<')I=F%L
M;R!T=7+K=&D@:V%I(&MU<FEU;W,@)7,@<&%R86UE=')U<RX`1F%I;&%S(&YE
M9V%L:2!B^W1I(&YU:V]P:6IU;W1A<R!A;G0@<V%VYG,N`$9A:6QE(&[K<F$@
M9'5O;65N^"X`2V%T86QO9V%S("(E<R(@:F%U(&5G>FES='5O:F$`2V%T86QO
M9V\@(B5S(B!P879A9&EN:6UE('ER82!N96QE:7-T:6[X('-I;6)O;&GX+B!4
M86D@9V%L:2!S=6ME;'1I(&YE<VML86YD=6WX+B!+<F5I<&MI=.MS(.$@<VES
M=&5M;W,@861M:6YI<W1R871O<FGX+@!+871A;&]G87,@(B5S(B!S=6MU<G1A
M<RP@=&'H:6%U(&YE86MT>79U;W1A<RX`2V%T86QO9V%S("(E<R(@:?!T<FEN
M=&%S+"!T8>AI874@:FES('9I<R!D87(@=?YP<F5N=6UE<G5O=&%S+@!+871A
M;&]G87,@(B5S(B!N97-U:W5R=&%S+B!397)V97)I;R!P<F%N9?!I;6%S('1O
M:W,`2V%T86QO9V%S("(E<R(@<W5K=7)T87,N`$MA=&%L;V=A<R`B)7,B(&GP
M=')I;G1A<RX`2V%T86QO9V%S("(E<R(@<&5R=F%R9&EN=&%S(.$@(B5S(BX`
M4D9#.#@R(&QA:?!K;R!A;G1R8?!TZW,N`%!R:64@\&EO<R!D86QI97,@<')I
M:V%B:6YT:2#P:64@9F%I;&%I.@!*96EG=2!D:7)B871E($EN=&5R;F5T($5X
M<&QO<F5R(&YA<O!Y:VQE+"!P:6QN865K<F%N:7,@<F5D86MT;W)I875S(')E
M_FEM87,@9V%L:2!S=6ME;'1I('!R;V)L96WX+"!DZVP@\&EO<R!N87+P>6ML
MZW,@:VQA:63X+B!'86QI=&4@;F5M871Y=&D@:V%I(&MU<FGX(')E9&%K=&]R
M:6%U<R!E;&5M96YT^"X@2F5I9W4@;F%U9&]J871E(%=I;F1O=W,@.7@@3U,@
M9W)E:>AI875S:6%I(&K[<_@@:V]M<&EU=&5R:7,@<&%P<F'PZ&EA=7-I86D@
M;G5L=?`@<&%S:V5L8F1A;6%S(&%P:64@<&%G<FEN9&ENYB!K;&%I9.`N7&Y<
M;DK[<R!B=79O=&4@<&5R<W#K=&%S+B!*96EG=2!V:7-T:65K(&YO<FET92!I
M\&)A;F1Y=&D@<&EL;F%E:W)A;N$@<F7^:6W@('-P875S:VET92!/2RX`07!R
M8?!A<R`B)7,B(&GP=')I;G1A<RX`4&%V96EK<VSK;&EA:2!B=7,@<&%R;V1Y
M=&DL(&)E<R!S:75N=.MJ87,@>7)A(&K[<_@@861R97/X(&MN>6=E;.MJ92X`
M5&EK(&MA:7+K:F4@<'5SZVIE`$-R>7!T7W!Q<#HZ(&ML87-E:2!R96EK:6$@
M;G5R;V1Y=&D@:W5R('ER82!';G501R!F86EL86DN`%!A\'1O('-E<G9E<FEO
M(&ML86ED83H`4&'P=&\@<V5R=F5R:6\@:6YF;W)M86-I:F$Z`%!A\'1O('-E
M<G9E<FEO(/YI;G5TZSH`2V%T86QO9V%S("5S(&IA=2!T=?#H:6%S+@!,86GP
M:V%S("(E<R(@;G5O("(E<R(@*"5D(&)A:71A:2D@=FER\'EJ82!P86EM86WX
M(&QA:?!K^"!D>63A+@!28?!O;6%S(&QA:?!K87,@=?YD87)Y=&%S+B!)\&5I
M;G4N`$QA:?!K87,@:?!T<FEN=&%S+@!,86GP:V%S('!A=&EK<FEN=&%S+@!,
M86GP:V%S(&GP<VGX<W1A<R`E<R!A9')E<V%T=6D@)7,@=&5M82`B)7,B(&)U
M=F\@<&%R;V1Y=&%S+@I48>AI874@=&%I(&YE9V%R86YT=6]J82!K860@;&%I
M\&MA<R!B=79O('!E<G-K86ET>71A<R!A<F)A('-U<')A<W1A<RX`4&%V861I
M;FEM87,@:W5RX2!N875D;W-I=&4@;G5O<F]D;VIE(.$@;&%I\&MO(')A\'EM
M;R!P=7-L87#A`$AO<F1E7T-R>7!T7W-M:6UE.CH@:VQA<V5I(')E:6MA;&EN
M9V%S($]P96Y34TP@;6]D=6QI<RX`3F5P879Y:V\@871I9&%R>71I('-L87!T
M8?YO9/YI;R!L86YG;RX@1V%L8OMT(&K[<_@@;F%R\'EK;.L@8FQO:W5O:F$@
M;F%U:G5S(&QA;F=U<RX`3F5G86QI=2!I\'-A=6=O=&D@;G5S=&%T>6UO("(E
M<R(L(&YE<R!D=6]M96[X(&1Y9&ES('9I<O!Y:F$@;&5I<W1I;N`@<FEBX`!0
M<F]G<F%M82P@<VMI<G1A('!E<OYI^W+K=&D@\.$@9'5O;65N^"!T:7#@("@E
M<RDL(&YE<F%S=&$@<VES=&5M;VIE+@!.96%P9&ER8G1A<R!01U`@=FEE\&]J
M;R!R86MT;R!T96MS=&%S(&=A;&D@8OMT:2!P97+^:?MRZW1A<R`E<RX`T&EO
M(&9A:6QO(&[K<F$@35,M5$Y%1B!P<FEK86)I;G1O:F4@9&%L>6IE+@#0:6]S
M(&)Y;&]S(&[K<F$@6FEP(&%R8VAY=F4N`%1I:R!K86ERZVIE(&ER(&1E\&EN
MZVIE('!U<^MS90!4:6L@9&7P:6[K:F4@<'5SZVIE`$QA:?!K;R!S:75N=.MJ
M87,@<F5I:V%L875J82!A='-A:WEM;R!A<&EE(&QA:?!K;R!G879I;>`L(&MA
M:2!T:6L@:N$@<&5R<VMA:71Y<VET92X@3F]RZV1A;6D@=&%I<"!P861A<GET
M:2P@<W!A=7-K:71E("5S+@!397)V97)I<R`B)7,B(&GP=')I;G1A<RX`4V5R
M=F5R:7,@(B5S(B!I\'-A=6=O=&%S+@!.97!A=GEK;R!P86ME:7-T:2!P87)A
M\&\N`%!A<F'P87,@<^MK;6EN9V%I('!A:V5I<W1A<RX`)7,@<F5G:7-T<F%C
M:6IO<R!P<F'P>6UA<R!I\'1R:6YT87,N`$YU<F]D>71A<R!F86EL87,@;F5E
M9WII<W1U;VIA+@!.=7)O9'ET82!E:6QU=.L@;F5E9WII<W1U;VIA+@!5_F1U
M;W1I<R#A<F'P>71A(.$@:OMS^"!D87)B^"!SX')A\.`N`$QA:?!K;R!T96MS
M=&%S`$QA:?!K;R!T96MS=&%S(&=A;&D@8OMT:2!P97+^:?MRZW1A<R`E<RX`
M1W)A_FEN=&\@;&%I\&MO('1E:W-T87,`1W)A_FEN=&\@;&%I\&MO('1E:W-T
M87,@9V%L:2!B^W1I('!E<OYI^W+K=&%S("5S+@!.=7-I^'-T;R!L86GP:V\@
M=&5K<W1A<P!.=7-I^'-T;R!L86GP:V\@=&5K<W1A<R!G86QI(&+[=&D@<&5R
M_FG[<NMT87,@)7,N`%1I:R!V:7+P=71I;NMJ92!I<B!A<&%T:6[K:F4@<'5S
MZW-E`%1I:R!A<&%T:6[K:F4@<'5SZVIE`$YU<VGX<W1I(&1U;VUE;GES('!R
M87)A<W1I+@!.96=A;&EU(&GP<V%U9V]T:2!N=7-I^'-T;R!F86EL;RX`5F%R
M=&]T;VIO('7^:6UT=6UO(&EN9F]R;6%C:6IA('/K:VUI;F=A:2!I\'-A=6=O
M=&$N`%=E871H97(N8V]M(&)L;VMO(&[K<F$N`$MI=/@@9&%L:?@L(&MU<FEA
M<R!G86QI;6$@8OMT^"!R;V1Y=&D@=&5K<W1E+"!NZW)A+@#0:6%M92!K871A
M;&]G92!NZW)A(&QA:?!K^"X`3G5S=&%T>6WX(&[K<F$N`$1A;&GX+"!K=7)I
M87,@9V%L:6UA(')O9'ET:2!L86GP:V\@=&5K<W1E+"!NZW)A+@#0:6%M92!L
M875K92#A=F5S=&$@<&5R(&1A=6<@<VEM8F]L:?@N($K[<R#A=F5DZW1E("5S
M+"!O(&UA:W-I;6%L=7,@<VMA:>AI=7,@+2`E<R!S:6UB;VQI86DN`$YE<&%V
M>6MO(&GP=F%L>71I("5S+B!397)V97)I;R!P<F%N9?!I;6%S('1O:W,`3F5P
M879Y:V\@:?!V86QY=&D@:V%T86QO9V\N(%-E<G9E<FEO('!R86YE\&EM87,Z
M("5S`$YE<&%V>6MO(&GP=F%L>71I(&MA=&%L;V=O+B!397)V97)I;R!P<F%N
M9?!I;6%S('1O:W,`4')O8FQE;6]S('-U(&9A:6SX('-I=6YT:6UU.B`E<R!N
M96YU<VGX<W1A<RX`3G5S:?AS=&D@9F%I;&\@;F5P879Y:V\N($9A:6QA<R`E
M<R!Y<F$@9&ED97-N:7,@;F5G=2!L96ED_FEA;6%S(&1Y9&ES("@E9"!B86ET
M86DI+@!.=7-I^'-T:2!F86EL;R!N97!A=GEK;RX@1F%I;&%S("5S('1I:R!D
M86QI;F%I(&YU<VGX<W1A<RX`2VQA:61A(&MO<&EJ=6]J86YT(&QA:?!K=7,@
M:?`@(B5S(B#A("(E<R(N(%-E<G9E<FEO('!R86YE\&EM87,@=&]K<P!+;&%I
M9&$@=')I;F%N="!L86GP:W5S(&GP(&MA=&%L;V=O("(E<R(N(%-E<G9E<FEO
M('!R86YE\&EM87,@=&]K<P!+;&%I9&$@=')I;F%N="!L86GP:W5S(&MA=&%L
M;V=E("(E<R(N(%-E<G9E<FEO('!R86YE\&EM87,@=&]K<P!+;&%I9&$@=')I
M;F%N="!L86GP:W5S+B!397)V97)I;R!K;&%I9&$Z("5S`$ML86ED82!I\'1R
M:6YA;G0@X79Y:^$Z("5S+@!.97!A=GEK;R!P87)O9'ET:2#P:6]S(&QA:?!K
M;R!D86QI97,`2VQA:61A('!A_GEM:6YT(&QA:?!K=7,@:V%T86QO9V4@(B5S
M(BX@4V5R=F5R:6\@<')A;F7P:6UA<R!T;VMS`$ML86ED82#A:V5L:6%N="`E
M<RX`2VQA:61A(.%K96QI86YT(&MO;G1A:W1I;FEU<R!D=6]M96YI<RX`2VQA
M:61A(.%K96QI86YT(.%V>6MI;R!D=6]M96YI<SH@)7,N`$ML86ED82#A:V5L
M:6%N="!I0V%L96YD87(@9'5O;65N:7,N`$ML86ED82#A:V5L:6%N="!D87)B
MX#H@)7,N`$ML86ED82#A:V5L:6%N="!V87)T;W1O:F\@=?YI;71U;6\@:6YF
M;W)M86-I:N`Z("5S+@!+;&%I9&$@:V]N9FEG^W)A8VEJ;W,@9F]R;6]J92X@
M1W)E:>AI875S:6%I(&YE=?YP:6QDZW1E(')E:6MI86WX(&QA=6OX+@!+;&%I
M9&$@<&5R:V5L:6%N="!L86GP:W5S(&GP("(E<R(@X2`B)7,B+B!397)V97)I
M;R!P<F%N9?!I;6%S('1O:W,`2VQA:61A(&%T;&EE:V%N="!N=7)O9'ETX"!A
M9')E<_@@:VYY9V5LZW,@9G5N:V-I:N`N(%!A8F%N9'EK:71E(';K;&EA=2X`
M2VQA:61A(&GP<V%U9V%N="!L86GP:^`@:V%I<"!P87)U;_!I;N$N`$ML86ED
M82!S:75NZ&EA;G0@;&%I\&O@.B`E<P!+;&%I9&$@871N875J:6YA;G0@:V]N
M=&%K=&EN:75S(&1U;VUE;FES+B!086)A;F1Y:VET92!VZVQI874N`$ML86ED
M82!A=&YA=6II;F%N="!D:7-T<FEB=6-I:F]S('/@<F'PX"X@4&%B86YD>6MI
M=&4@=NML:6%U+@!+;&%I9&$@871N875J:6YA;G0@X79Y:^$Z("5S+@#0:6]J
M92!L86GP:V\@9&%L>6IE(&[K<F$@=&5K<W1O`-!I86UE($A434P@;&%I\&ME
M('ER82!P879E:6MS;.ML:?@N`-!I86UE($A434P@;&%I\&ME('ER82!P879E
M:6MS;.ML:?@N(%7^8FQO:W5O=&D@<&%V96EK<VSK;&EA:2!R;V1O;6D@:V%I
M<#H@`-!I<R!)34%0('-E<G9E<FES(&YE<&%L86EK;R!K871A;&]G^"!D86QI
M:FEM;W-I+@#0:7,@4$=0('9I9?!A<VES(')A:W1A<R!B=79O('!R:6MA8FEN
M=&%S('!R:64@;&%I\&MO+@!696EK<VUA<R!N97!A;&%I:V]M87,N`-!I<R!V
M96EK<VUA<R!D87(@;F5R96%L:7IU;W1A<RX`071R;V1O+"!K860@=&%I(&YE
M='9A<FMI;F=A<R!205(@87)C:'EV87,N`$%T<F]D;RP@:V%D('1A:2!N971V
M87)K:6YG87,@6DE0(&%R8VAY=F%S+@!!=')O9&\L(&MA9"!T86D@;F5T96ES
M:6YG87,@:V]R=&5LZW,@;G5M97)I<RX`T&D@='9A<FMY:VSK(&QE:63^:6$@
M<VGX<W1I(/YI;G5T97,@<&5R($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@<&%S:6YA=61O:F%N="!(5%10('!R;W1O:V]L=0#0:2!T=F%R
M:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!P97(@<VUS,F5M86EL("AH
M='1P.B\O<VUS,F5M86EL+F-O;2D@<&%S:6YA=61O:F%N="!(5%10('!R;W1O
M:V]L=0#0:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!33510
M('!R;W1O:V]L=2!P97(@5F]D869O;F4@271A;&EJ;W,@=F%R='5S+"!T:6L@
M5F]D869O;F4@;G5M97)I86US+B!*:2!R96EK86QA=6IA(&5L+B!P8?!T;R!A
M9')E<V\@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`T&ES
M(&QA=6MA<R!P<FEV86QO;6%S+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK
M('-V96EK:65J:2!S:V%IZ&EA:2X`T&EA;64@;&%U:V4@9V%L:2!B^W1I('1I
M:R!S:V%IZ&EA:2!I<B!D=FET8?!K:6%I+@#0:6%M92!L875K92!G86QI(&+[
M=&D@=&EK(&'P='5N=&%I;FEA:2!S:V%IZ&EA:2X`T&EA;64@;&%U:V4@='5R
M:2!B^W1I(&MA8FQE;&EA:7,@87)B82!T87)P86ES(&%T<VMI<G1I('-V96EK
M:65J:2!S:V%IZ&EA:0#0:2!R96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RX`
MT&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S<&%L=F]S(&MO9&%S(%)'0B!(
M97@@9F]R;6%T92P@<&%V>7ID_FEU:2`G(S$R,S1!1B<N`-!I(&9O<FUA(&IA
M=2!A<&1O<F]T82X`5&%I("5S+@!486D@2V]L86(@1W)O=7!W87)E(&]B:F5K
M=&%S+B!.;W+K9&%M:2!P97+^:?MRZW1I(&]B:F5K=.`@<')I=F%L;W1E('1U
M<NMT:2!E;"X@<&'P=&\@:VQI96YTX"P@:W5R:7,@<W5P<F%N=.`@\.$@9F]R
M;6%TX"X@5&]K:?@@96PN('!A\'1O(&ML:65N=/@@<^!R8?#@(&=A;&ET92!R
M87-T:2!A<'-I;&%N:^8@)7,`5&%I(&=A;&D@=?YT<G5K=&DN($%R(&K[<R!T
M:6MR86D@;F]R:71E('1E<W1I/P!,86GP:V%S('1U<FD@<')I:V%B:6YTX"!-
M86-H:6YT;W-H(&9A:6S@+@#0:6%M92!L86GP:V4@>7)A(&EN9F]R;6%C:6IA
M(&%P:64@;&%I\&OX('!R:7-T871Y;>`L('1AZ&EA=2!N9?YI;F]M87,@:F]S
M(&9O<FUA=&%S+@!!=')O9&\L(&MA9"!T86D@;F5T=F%R:VEN9V%S(%!'4"!R
M86MT=2!U_FMO9'5O=&%S(&QA:?!K87,N($ML86ED83H@`$QA:?!K87,@;F5A
M=&ET:6YK82!T96ES:6YG;R!01U`@4D9#,C`Q-2!F;W)M871O+@!,86GP:V%S
M(&YE871I=&EN:V$@=&5I<VEN9V\@4R]-24U%(&9O<FUA=&\N`-!I<R!L86GP
M:V%S('ER82!P87-I<F'P>71A<R!01U`@<&%R8?!U+@#0:7,@;&%I\&MA<R!Y
M<F$@<&%S:7)A\'ET87,@4R]-24U%('!A<F'P=2X`T&ES(&QA:?!K87,@>7)A
M('7^:V]D=6]T87,@<W4@4R]-24U%+@#0:7,@;&%I\&MA<R!Y<F$@=?YK;V1U
M;W1A<R!S=2!01U`N`/#A(&QA:?!KX"#A`-!I<R!L86GP:V%S(&)U=F\@<&%R
M8?!Y=&%S("5S(&MO9'5O=&4N($K[<R!N875D;VIA=&4@:VET;VMIX"!K;V1U
M;W3F+@#0:7,@<VMA:>AI=7,@='5R:2!B^W1I(&1I9&5S;FES('7^(&YU;.$N
M`-!I<R!S97)V97)I<R!N96=A;&D@:?!A<F-H>79U;W1I('II<"!I<B!G>FEP
M(&9A:6SX+@#0:7,@<V5R=F5R:7,@;F5P86QA:6MO(&MA=&%L;V?X(&1A;&EJ
M:6UO<VDN`-!I('-I<W1E;6$@9&%B87(@:?!J=6YG=&$N`-!I(')E:6OP;>L@
M='5R:2!B^W1I('-K86GH:75S+@#0X2!L86YGX"!R96EK:6$@871I9&%R:6[K
M=&D@:?`@;&%I\&MO(')A\'EM;R!L86YG;RX`T.$@;&%N9^`@<F5I:VEA(&%T
M:61A<FENZW1I(&GP(&YU<W1A='EM^"!L86YG;P!'<G5P=6]J86UI(&QA:?!K
M86D`4&5R:_MN:6IA`$)I;&EE=&%I`$QA:6MA<P!,86EK;R!A<'-K86ET80!,
M86EK;R!F;W)M871A<P!,86EK;R!P87-I<FEN:VEM87,`5&EM;W)L97-TZP!0
M87)E:6=O<P!0879A9&EN:6UA<SH`2V%M`$%D<F5S871A<P!.;W+K9&%M:2!P
M87-I<FEN:W1I(&ME;&5TX"!R96EK\&UI^"P@;&%I:WEK:71E($-O;G1R;VP@
M*%!#*2!A<F)A($-O;6UA;F0@*$UA8RD@:VQA=FGPX"P@:7(@<&%S:7)I;FMI
M=&4@<&5L92X`3F]RZV1A;6D@<&%S:7)I;FMT:2!K96QE=.`@96QE;65N=/@L
M(&QA:6MY:VET92!#;VYT<F]L("A00RD@87)B82!#;VUM;F%D("A-86,I(&ML
M879I\.`L(&ER('!A<VER:6YK:71E('!E;&4N`-!I86YD:65N`%)O9'ET:2!(
M5$U,(&MO9.``5&]G87,`5&]K96QA=0!2>71O:@!4;VYG80!6:7+P=6IE`%9I
M<O!U=&EN:6%M92!L86YG92`H7W1O<"D`5FES87,@<')I:V%B:6YT^"!F86EL
M^"!D>61I<SH`5F5R=&EM86D`T&EU:_!L:6%DZ_[K`-!I=6OP;&EA9.O^ZSH`
M5')I;FED861A<R!I<B!4;V)A9V%S`%1A:7`@87)B82!N90!!;G1R+@!4=6YI
M<V%S`%1U<FMI:F$`5'5R:VGP:V$@*$E33RTX.#4Y+3DI`%1U<FMMZVYI:F$`
M5'5R:W-O(&ER($MA:6MO<V\@<V%L;W,`5'5V86QU`,%V97-K:71E('-A=F\@
M<&%S:7)I;FMI;>`Z(`!5+E8N(&EN9&5K<V%S.B``55),`%-K<FEP=&\@<')I
M<W1A='EM;R!S=&%T=7-O(')A<&]R=&\@55),`%523#H`56=A;F1A`%5K<F%I
M;F$`3F5P879Y:V\@<&5R<VMA:71Y=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK
M;R!P<FEDZW1I('!A<&EL9&]M;W,@=F%R=&]T;VIO(')E9VES=')A8VEJ;W,@
M:6YF;W)M86-I:F]S+@!.97!A=GEK;R!P86ME:7-T:2!61E,@9F%I;&\@(B5S
M(B!T96ES:?@N`$YE<&%V>6MO('!A:V5I<W1I('1E:7-I^"!61E,@9F%I;'5I
M("5S+R5S+@!.97!A=GEK;R!P97)E:71I(.$@)7,N`$YE<&%V>6MO('!R:7-I
M:G5N9W1I('!R:64@4U%,('-E<G9E<FEO+@!.97!A=GEK;R!P<FES:6IU;F=T
M:2!34TP@<F7^:6UU+@!.97!A=GEK;R!N=6MO<&EJ=6]T:2!61E,@9F%I;&\N
M`$YE<&%V>6MO('-U:W5R=&D@5D93(&MA=&%L;V=O("(E<R(N`$YE<&%V>6MO
M('-U:W5R=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!S=6MU<G1I(%9&4R!F
M86EL;RX`3F5P879Y:V\@<W5K=7)T:2!T=?#H:6\@5D93(&9A:6QO+@!.97!A
M=GEK;R!I\&%R8VAY=G5O=&D@9'5O;65N^"X`3F5P879Y:V\@:?!T<FEN=&D@
M(B5S(BP@:V%T86QO9V%S(&YE='7PZ&EA<P!.97!A=GEK;R!I\'1R:6YT:2`E
M<RP@:V%T86QO9V%S(&YE='7PZ&EA<P!.97!A=GEK;R!R96MU<G-I\&MA:2!I
M\'1R:6YT:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO(&GP=')I;G1I(%9&4R!K
M871A;&]G;RX`3F5P879Y:V\@:?!T<FEN=&D@5D93(&MA=&%L;V=O.B`E<RX`
M3F5P879Y:V\@:?!T<FEN=&D@5D93(&9A:6QO("(E<R(N`$YE<&%V>6MO(&GP
M=')I;G1I(%9&4R!F86EL;RX`3F5P879Y:V\@<F5K=7)S:?!K86D@:?!T<FEN
M=&D@5D93.B`E<RX`3F5P879Y:V\@;G5S=&%T>71I(&1A8F%R=&EN:6\@:V%T
M86QO9V\N`$YE<&%V>6MO(&=A=71I('-E<G1I9FEK871O(&%P<F'P>6UO`$YE
M<&%V>6MO('7^:W)A=71I("5S(&%P<F'P>6UO+@!.97!A=GEK;R!P97)K96QT
M:2!61E,@9F%I;&\N`$YE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\@(B5S
M(BX`3F5P879Y:V\@871I9&%R>71I(%9&4R!F86EL;R!R8?!Y;75I+@!.97!A
M=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO+@!.97!A=GEK;R!A=&ED87)Y=&D@
M<W5S<&%U<W1O(&%R8VAY=F\N`$YE<&%V>6MO('!E<G-K86ET>71I('9F<W)O
M;W0@:V%T86QO9V\N`$YE<&%V>6MO('!E<G9A9&EN=&D@)7,@X2`E<SH@=&]K
M<R!K871A;&]G87,@:F%U(&5G>FES='5O:F$`3F5P879Y:V\@<&5R=F%D:6YT
M:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO('!E<G9A9&EN=&D@5D93(&MA=&%L
M;V=O.B`E<RX`3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\@(B5S(BX`
M3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\@)7,O)7,N`$YE<&%V>6MO
M('!E<G9A9&EN=&D@5D93(&9A:6QO+@!.97!A=GEK;R!A<'-K86GH:75O=&D@
M;F%U9&]J86UO<R!V:65T;W,`3F5P879Y:V\@<&%L96ES=&D@)VUK:7-O9G,G
M+@!.97!A=GEK;R!I\'9E<G-T:2#P:6\@5V]R9"!D;VMU;65N=&\`3F5P879Y
M:V\@X7)A\'ET:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y:V\@X7)A\'ET:2!6
M1E,@9F%I;&\@*&-O<'DH*2!K;&%I9&$I+@!.97!A=GEK;R#A<F'P>71I(%9&
M4R!F86EL;R!D=6]M96[X+@!.96%T<V%K>71I`$YE871S86MY=&D@;&%I\&MA
M:0!!='-T871Y=&D@:?!T<FEN='5S`%!A8G)A=6MT:0!!9')E<V%T86D@;F5R
M;V1O;6D`073P875K=&D@<&%K96ET:6UU<P!!=/!A=6MT:2!A;FMS=&5S;N$@
M=F5I:W-MX`!.971I:^MT82!S97)V97)I;R!K;&%I9&$Z(`!.971I:^MT82!S
M97)V97)I;R!K;&%I9&$Z(`!.96YU<F]D>71A`$YE<&%L86EK;VUA<R!K;VUP
M;VYE;G1O('1I<&%S.B`E<P!5;FEK;V1A<R`H551&+3@I`$IU;F=T:6YI86D@
M07)A8O@@16UY<F%T86D`2G5N9W1I;NL@2V%R86QY<W3K`$IU;F=T:6[K<R!6
M86QS=&EJ;W,`2G5N9W1I;FGX(%9A;'-T>6KX($%T;VME<V[K<R!S86QO<P!6
M:65N971A:0!.9?YI;F]M87,`1&%T82!N9?YI;F]M80!.9?YI;F]M87,@<W5S
M:7)I;FMI;6%S`$YE_FEN;VUA<R!A9')E<V%T87,`3F7^:6YO;6%S(&%P:6US
M9VED("A!4$D@365S<V%G92!)1"DN`$YE_FEN;VUA<R!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!.9?YI;F]M87,@=F%R=&]T;VIO('9A<F1A<R!I
M<B]A<F)A('-L87!T8?YO9&ES+@!086YA:6MI;G1I(&YU;W)O9.`@\&EA;2!E
M;&5M96YT=6D`071J=6YG=&D@<VQA<'3@(&9R87KF`$YEX79A<F1I;G1A<P!3
M875G=6UO('-U;65T:6UA:7,@;F5P<FEV:6QE9VEJ=6]T:2!S:W)I<'1A:2!N
M96=A;&D@871L:6MT:2!097)KZVQI;6\O2V]P:6IA=FEM;R_!:^ML:6UO('!R
M;V=R86UI\&MA:2X@3F]RZV1A;6D@<&5R_FG[<NMT:2!T96-H;FEN97,@9&5T
M86QE<R!M;WII;&QA+F]R9R!T:6YK;&%P>6IE+"!I<B!S=?YI;F]T:2!K86EP
M('-K<FEP=&%M<R!L96ES=&D@<')I96ET:2!P<FEE(&QA:6MI;F]S:6]S('-A
M=6=Y:VQO<RP@<&%S<&%U<VMI=&4@3TLN`$YE<VMA:71Y=&D`3F5N875D;W1I
M('-P86QV;W,`3F5B97!R96YU;65R=6]T:2!K871A;&]G;RCX*0!0;.MT:6YY
M<R!N97!A;&%I:V]M87,`071N875J:6YT:0!!=&YA=6II;G1I("5S`$%T;F%U
M:FEN=&D@<')I:V%B:6YT=7,@9F%I;'5S`$%T;F%U:FEN=&D@871S86MO=O@@
M<W1A='5SX`!!=&YA=6II;G1I('9A<G1O=&]JX`!!=&YA=6II;FEM;R!S:W)I
M<'1A<R!I\'1R:6YT87,N`$YU<VGX<W1I`%9I<VD@;6]D=6QI^"!A=&YA=6II
M;FEM;R!F86EL86D@X6ME;'1I(.$@<V5R=F5RX2X`1&ED_FEO<VEO<R!L;W1I
M;FGP:V]S(')A:63K<P!$:61I96II(')O;>MN:?!K:2!S:V%IZ&EA:0!5<G5G
M=F%J=7,`3F%U9&]T:2!D86)A<G1I;N8Z("5S`$YA=61O=&D@<W1A;F1A<G1I
M;N8@<F5I:_!MY@!.875D;W1I($E-05`@:V%T86QO9_@@<')E;G5M97)A=.`_
M`$YA=61O=&D@4U-,`$YA=61O=&D@:F5I9W4@=F%R=&]T;VIO('9A<F1A<R]S
M;&%P=&'^;V1I<R!)35-0('-E<G9E<FEU:2!Y<F$@:VET;VMS+@!687)T;W1O
M:F%S`%9A<G1O=&]J87,@)7,@;F5A=71O<FEZ=6]T87,@<')IZVII;75I('!R
M:64@)7,N`%9A<G1O=&]J^"!A9&UI;FES=')A=FEM87,`5F%R=&]T;VIO(&YU
M<W1A='EM86D`5F%R=&]T;VKX(')E9VES=')A8VEJ80!687)T;W1O:O@@<F5G
M:7-T<F%C:6IA(&GP:G5N9W1A+@!687)T;W1O:F\@=F%R9&%S`%9A<G1O=&]J
M;R!V87)D87,Z`%9A<G1O=&]J;R!V87)D87,Z(`!687)T;W1O:F%I(/!I;VIE
M('-I<W1E;6]J93H`57IB96MI<W1A;F%S`%9&4R!K871A;&]G87,@;F5E9WII
M<W1U;VIA+@!!=&]S=&]G;W,`4F%S=&]S('1E:7-I;F=O<R!V:65T;W;K<SH@
M`$=A;&EO:FEM87,`4F5I:_!MZR!M:6YU=.MM:7,@;G5O(&1A8F%R+@!296EK
M\&WK<P!296EK\&WK<R!I\"!K=7)I^"!G86QI;6$@<&%S:7)I;FMT:0!686YU
M871U`$MI;G1A;G1I<P!696YE<W5E;&$`4&%T=FER=&EN:6UA<R!N96)A:6=T
M87,@+2#P:7,@;&%I\&MA<R!S=6=A9&EN=&%S+@!697)S:6IA`%9E<G-I:O@@
M:V]N=')O;.L`3'EG:75O=&D@=F5R=&EK86QI86D`5F5R=&EK86QU<R!T87)P
M87,`5F5R=&EK86QU<SH`3&%B86D@9&ED96QI<P!6:65T;F%M87,`5FEE=&YA
M;6EE=&GP:V$@*%9)4T-)22D`4F]D>71I`%)O9'ET:2`E<P!2;V1Y=&D@)7,@
M=FEE\.!JX2!R86MTX`!2;V1Y=&D@2%1-3"!T=7)I;N$@871S:VER86UE(&QA
M;F=E`%)O9'ET:2!S;&%P=.!JX2!R86MTX`!2;V1Y=&D@=FEE\.!JX2!R86MT
MX`!2;V1Y=&D@9W)U<.8`4F]D>71I('!A=F5I:W-LZVQI=7,`4F]D>71I(&GP
M;W)I;N$@<'5S;&%PX0!097+^:?MRZW1I(&MA:7`@)7,`4&5R_FG[<NMT:2#A
M=GEKX0!097+^:?MRZW1I(&QA:?!K=7,@:V%T86QO9V4@)7,`4')I<VEJ=6YG
M=7,@<F]D>71I(/#A(&MA=&%L;V?@.@!097+^:?MRZW1I(&1A<F+@`%)O9'ET
M:2!P879E:6MS;.ML:75S`$)R:73X(%9I<F3^:6YI:F]S('-A;&]S`$I!5B!6
M:7)D_FEN:6IO<R!S86QO<P!6:7)T=6%L=7,@:V%T86QO9V%S("(E<R(@<W5K
M=7)T87,@<^MK;6EN9V%I+@!6:7)T=6%L^W,@:V%T86QO9V%I`%9I<G1U86QA
M=7,@:V%T86QO9V\@<&%V861I;FEM87,`36%T;VUU;6%S`$UA=&]M=6UA<SH@
M`%9O9&%F;VYE($ET86QI:F$@<&5R(%--5%``5T%23@!$RTU%4TE/(2$A(%!!
M5%E3($G05%))3DM)5$4@4TM225!4P"!)T"`E<RX`5F%L:7,@:7(@1G5T=6YA
M`%1R9>@N`$]R^"!P<F]G;F]ZZP!/<O@@<')O9VYO>NL@<&%G86P`5V5A=&AE
M<BYC;VT`5U=7`%=75R!P=7-L87!I<P!+87,@<V%V86ETY@!3=F5I:VD`4W9E
M:6MI(&%T=GEKYB#A("5S`$QA8F%S+"`E<P!686MA<O@@*$E33RTX.#4Y+3$I
M`%9A:V%R^"`H25-/+3@X-3DM,34I`%9A:V%R^"!386-H87)A`$MO:^$@;6]D
M=6SA("5S('1U<FD@<F]D>71I('!O('!R:7-I:G5N9VEM;S\`2V]K<R!S:VER
M='5K;R!S:6UB;VQI<S\`2V]K<R!K86)UZ&GX('-I;6)O;&ES/P!+86D@;&%I
M\&MA<R!I\'1R:6YA;6%S+"!J:7,@<&5R:V5L:6%M87,@X2#P:75K\&QI863K
M_N8L(&\@;F4@_GEM:6UA<R!K86EP(&GP=')I;G1A<S\`2W5RX2!P=7-L87#A
M(&YO<FET92!M871Y=&DL(&%T:61A<FEU<R!P8?!T;R!DZ_YU=.8_`$MA:2!I
M\'-A=6=O;64@:?!S:?AS=.`@;&%I\&O@+"!A<B!I\'-A=6=O=&D@:7(@<')I
M:V%B:6YT=7,@9F%I;'5S/P!+=7)I;W,@9F%ZZW,`2%1-3"!R961A:W1O<FEA
M=7,@;6]D=6QI^"#A:G5N9VEM87,N`%9I<V%D82!L96ES=&D`4&QO=&ES`%!L
M;W1I<R!#4U,@;6%T86ES`"5S(&MA:7)I;VIO(&UE;FEU('!L;W1I<R`H<&%K
M96ET:6UA:2!B=7,@;6%T>71I('!O(&MI=&\@<')I<VEJ=6YG:6UO*3H`3&5N
M=&5LZW,@<&QO=&ES`%!L;^AI;R!M871A<P!0;&]T:7,Z`%=I:VD`5NMJ;R!G
M<F5I=&ES(&UA>F=A:7,`5NMJ87,Z`%;K:F%S.B``2?!M:6YT:7,`1&%R8F%S
M`$1A<F)O(&%D<F5S87,`1&%R8F\@=&5L969O;F%S`%@M4F5F`%@U,#EV,R!P
M86=R:6YD:6YI86D@;G5S=&%T>6UA:0!8-3`Y=C,@:?!P;.MS=&\@<F%K=&\@
M<&%N875D;VII;6%S`%@U,#EV,R!A;'1E<FYA='EV=7,@=F%R9&%S`%@U,#EV
M,R!R86MT;R!I9&5N=&EF:6MA=&]R:75S`%@U,#EV,R!M;V1U;&EA:0!960!9
M65E9`%EA:&]O(2#^96WK;&%P:7,`2V%S;65T`$IE;65N87,`5&%I<`!486EP
M+"!A\"!S=71I;FMU`$K[<R!B86YD;W1E('!A:6UT:2!L86GP:W5S(&GP(/!I
M;W,H:?@I('/@<VMA:71O<RCX*3H`2OMS(&MO<&EJ=6]J871E+W!E<FME;&EA
M=&4@X2!K:73@(&MA=&%L;V?@+@!*^W,@:W5R:6%T92!P86MA=&]L;V?A(&MA
M=&%L;V=E(`!*^W,@:W5R:6%T92!K871A;&]GX"X`2OMS(&5S871E(%1%2U-4
M24Y)04U%(%)%WDE-12X@3F]RZV1A;6D@9W+A_G1I(.$@5UE325=91R!S<&%U
M<VMI=&4@6SP^72X`2OMS(&YE<')I<VEJ=6YGYBX`2OMS('!E<G9A<F1I;F%T
M92!K871A;&]GX#H@`%-A=F\@=F%R9&4@;F5G86QI=&4@;F%U9&]T:2!S:6UB
M;VQI;R`G7"<N`$K[<R!N97-U=&EK;W1E('-U(')E9VES=')A8VEJ;W,@<^!L
M>6=O;6ES+"!T;V3K;"!P<FES:6IU;F=T:2!N96=A;&ET92X`P79E9.MT92!N
M971E:7-I;F?@(&5L+B!P8?!T;R!A9')E<^`N`$YE<')I:G5N9^MT92!J;VMI
M^"!L875K^"!I\"#A:V5L:6%M;R!F86EL;R!P<FEE("5S(&%T:71I;FMA;?@@
M;&%U:_@N`$YE='5R:71E('1E:7-I^"!K96ES=&D@=&5I<VGX(.$@\.$@:V%T
M86QO9^`N`"4E<R!J^W,@<&5R<VEU;G3K=&4@\.$@;&%I\&O@(/!I96US(&%D
M<F5S871A;7,Z("5S+@!*^W,@9V%V;W1E("5S(&YA=6IU<R!L86GP:W5S+@!*
M^W,@9V%V;W1E(#$@;F%U:N`@;&%I\&O@+@!*^W,@<&%S:7)I;FMO=&4@8F5N
M="!V:65NX"!F86ELX"P@:W5R:6\@9&%R(&YE<')I:V%B:6YO=&4N($%R('1I
M:W)A:2!N;W)I=&4@<VGX<W1I(/#A(&QA:?!KX"!B92#P:?@@9F%I;/@_`$K[
M<R!A='-I:G5N9^MT92X`2OMS('1U<FET92!N875J^"!L86GP:_@@\&EA;64@
M:V%T86QO9V4Z`$K[<R!T=7)I=&4@;F%U:O@@;&%I\&OX(/!I=6]S92!K871A
M;&]G=6]S93H`5'5R:71E(.%V97-T:2!T96ES:6YGX"!T96QE9F]N;R!N=6UE
M<N$@*'1I:R!S:V%IZ&EU<R!I<B`G*R<L(&IE:6=U(&YO<FET92!N=7)O9'ET
M:2!T87)P=&%U=&ENX2!K;V3@*2X`P79E9.MT92!N971E:7-I;F?@(')E:6OP
M;>8N`$YO<NMD86UI(&YA=6=O=&ES(')E9VES=')A8VEJ;W,@<VES=&5M82P@
M='5R:71E('-U:V]N9FEG^W)U;W1I(&1U;VUE;O@@;65D_FEO('!O<VES=&5M
MYBX`4')I9?`@<VGX<V1A;6D@<')A;F7P:6W@+"!A<')A\'EK:71E('!R;V)L
M96W@+@!4=7)I=&4@;G5R;V1Y=&D@8F5N="!V:65NX"!G87;K:N`N`,%R8?!Y
M:VET92!N=6]R;V1O<R!54DP`3F]RZV1A;6D@<&5R_FG[<NMT:2#PX2!L86GP
M:^`L(.%V97-K:71E(%!'4"!P<FEV871A=7,@<F%K=&\@<VQA<'3@:N`@9G)A
M>N8`3F]RZV1A;6D@<&5R_FG[<NMT:2#PX2!L86GP:^`L(.%V97-K:71E(%,O
M34E-12!P<FEV871A=7,@<F%K=&\@<VQA<'3@:N`@9G)A>N8`4')I;6EA=7-I
M82!R96EK:6$@;G5R;V1Y=&D@:V%T86QO9^`N`$YU<F]D>6MI=&4@<^!S:V%I
M=.`L(&MU<FG@(&YO<FET92!I\'1R:6YT:2X`5FES^"!P:7)M82!R96EK:6$@
M;G5R;V1Y=&D@861R97/@+@!4=7)I=&4@<&%S:7)I;FMT:2!S97)V97+A+"!K
M=7+A(&YO<FET92!I\'1R:6YT:2X`4F5I:VEA('!A<VER:6YK=&D@8F5N="!V
M:65NX"!L86GP:^`N`%)E:6MI82!N=7)O9'ET:2!G87;K:N`N`$YU<F]D>6MI
M=&4@=F%R=&]T;VIO('9A<F3@+"!K=7)I;R!D=6]M96YI<R!T<FEN871E+@!.
M=7)O9'EK:71E('9A<G1O=&]J;R!V87)DX"!T<GEN:6UU:2X`5'5R:71E('!R
M:6MA8FEN=&D@8F5N="!V:65NX"!F86ELX"X`3G5R;V1Y:VET92!K=7)I86UO
M('9A<G1O=&]J;R!V87)DX"X`3G5R;V1Y:VET92!A=&YA=6II;F%M;R!V87)T
M;W1O:F\@=F%R9.`N`$YU<F]D>6MI=&4@=F5I:W-MX"X`2OMS('1U<FET92#A
M=F5S=&D@;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`N`$K[<R!N=6MR
M96EPZW1E(/#A(&QA:?!KX"`E<R`E)7,N`$K[<R!A='-A:^MT92#A(/#A(&QA
M:?!KX"`E<RX`2OMS(&YE=?YS:7!R96YU;65R879O=&4@(B5S(BX@4V5R=F5R
M:6\@<')A;F7P:6UA<R!T;VMS`$K[<R!N96%T<VEP<F5N=6UE<F%V;W1E("(E
M<R(N(%-E<G9E<FEO('!R86YE\&EM87,@=&]K<P!*^W,@<^MK;6EN9V%I('7^
M<VEP<F5N=6UE<F%V;W1E("(E<R(`2OMS('/K:VUI;F=A:2!A='-I<')E;G5M
M97)A=F]T92`B)7,B`"5S('-E<VEJ82!B86EGZW-I+B!0<F'P;VUE('!R:7-I
M:G5N9W1I(&GP(&YA=6IO+@!*^W/X(&5L+B!P8?!T;R!A9')E<V%S.@!%;"X@
M<&'P=&\@861R97-A<SH`26YF;W)M86-I:F$@87!I92!*=7,`3G5O("5S('-E
M<VEJ;W,@<')A9/YI;W,@:OMS^"!)4"!A9')E<V%S('!A<VEK96ETZRX@5'5R
M:71E('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X('9A<F1A<R]P879A<F3K
M`$K[<_@@4$=0('9I9?!I96II+W-P86QT:65J:2!R86MT86D`2OMS^"!S;&%P
M=&%S:7,@<F%K=&%S`$K[<_@@=FEE\&%S:7,@<F%K=&%S`$K[<_@@4R]-24U%
M('9I9?!I96II+W-L87!T:65J:2!S97)T:69I:V%T86D`2OMS^"!SX'-K86ET
M;W,Z`$K[<_@@875T96YT:69I:V%V:6UO('-I<W1E;6$@;F5P86QA:6MO('9A
M<G1O=&]J^"!SX')A\&\L(&%R8F$@\&D@9G5N:V-I:F$@=?YD<F%U<W1A(&3K
M;"!T86T@=&EK<O@@<')I9?YA<^AI^"X`3G5O("5S('-E<VEJ;W,@<')A9/YI
M;W,@:OMS^"!N87+P>6MLZW,@=&EP87,@<&%S:6ME:73K+B!4=7)I=&4@<')I
M<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@;F%R\'EK;.L@;F5G86QI('!A<F]D
M>71I(/!I;R!P879E:6MS;.ML:6\@;&%I\&MO('1E:W-T92X`2OMS^"!N87+P
M>6MLZR!N97!A;&%I:V\@\&EO<R!G86QI;7EBZW,N`$K[<_@@;&%I:V\@:G5O
M<W1A.@!3=&%N9&%R=&ENZR!K;V1U;W3K('-I=6[H:6%M:65M<R!L86GP:V%I
M<SH`4W1A;F1A<G1I;FES(&MO9&%V:6UO(&UE=&]D87,@<VEU;NAI86UI96US
M(&QA:?!K86ES.@!*^W/X('-T86YD87)T:6YI<R!A<')A\&%S.@!*^W/X('9A
M<F1A<R]P879A<F3K.@!,86GP:V%S('/K:VUI;F=A:2!P<FES=&%T>71A<RX`
M2OMS^"!N875J87,@)7,@<VQA<'1A_F]D:7,@>7)A.B`E<P!*^W/X(&YU<W1A
M='EM86D@871N875J:6YT:2X`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,`
M2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,N(%!A<VET:6MR:6YK:71E('-A
M=F\@<&'P=.`@:7(@<')I<VEJ=6YK:71E('-U(&YA=6IU('-L87!T8?YO9/YI
M=2X`2OMS^"!N=71O;.8@<V5R=F5R:6%I.@!*^W/X('!A<F'P87,Z`$IU9V]S
M;&%V:6IA`%IA:7)A<P!:86UB:6IA`%II;6)A8G;K`$5N97)G:6YG;W,`6U!A
M<VSK<'1I(&-I='5O:F%MX"!T96MS=.!=`%MB92!P879A9&EN:6UO70!;4')O
M8FQE;6]S('!R86YE\&EM87-=`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M
M`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M("5S(&5I;'5T97-=`%ME:6QU
M=.L@)7,@:?`@)7-=`%]686QD>6UA<P!?0F-C`%]";&]K=6]T:0!?0TQ)`%]#
M8P!?1'5O;65N^"!M961I<P!?2?!T<FEN=&D`7TGP=')I;G1I(&5I;'5TY@!?
M2V%T86QO9V%I`$=?<G5PZW,`4&%?9V%L8F$`07!?<F'P87,`7U!A=F5I:W-L
MZVQI;R!N=7-T871Y;6%I+BXN`$EN8F]?>`!0<FES:5]J=6YG=&D`071S:5]J
M=6YG=&D`3&%I\&MO(&MO9&%S`%]+96ES=&D@;G5O<F]DX"XN`%].=7-T871Y
M;6%I`%]496ESZW,`7U-P875S9&EN=&D`4U]V87)B80!!=&YA=6II;G1I("5S
M`%])\'1R:6YT:2!N=6]R;V3@+BXN`$%T<V%K7WET:0!)7V7P:V]T:0!?4VGX
M<W1I(&QA:?!KX`!?2V]N9FEG^W)A8VEJ80!?3&5N=&5LZW,@;G5S=&%T>6UA
M:2XN+@!'<G5PZW,`7TMA;0!!='-T871Y=&D`5E]A<G1O=&]J86D`4F]D>71I
M(&=R=7#F`%9I<V%D82!?;&5I<W1I`&%D<F5S^"!K;GEG96SK`&9A:6QA<P!P
M<FEK86)I;G1I7V9A:6QA:2YZ:7``8F%I=&%I`$MA;&5N9&]R:75S`')A;75S
M`'-P875S:VET92#H:6$`:W)E;G1A`&9A:6QA<P!N=6\@)7,@*"5S*2`E<R`E
M<P!A.@!T=6]J874@<&%T`'!A<')A<W1I`')A:W1A<P!E:6QU=&5S70!K871A
M;&]G;R!F86EL87,`;6MI<V]F<R!K;&%I9&]S(&MO9&%S("5D(&)E9&%R86YT
M($E33RX`=F%R9&%S`&[K<F$`;F5R96%L:7IU;W1A`&1A<B!N97)E86QI>G5O
M=&$`=?YR8?#X(&MN>6=E;.L`87)B80!P<F]C96YT86D`<&EK<V5L:6%I`&MY
M;&$`<F]D>71I('-K:7)T=6UU<P!S;7,R96UA:6P@<&5R($A45%``<F'P>6)O
M<R!K;&%I9&$`<F'P>6)O<R!K;&%I9&]S`'-T86)I;&D`9&%R8O@@<^!R8?!A
M<P!S;&%P=&'^;V3A('1U<FET92#A<F'P>71I(&1U(&MA<G1U<P!U;FEF:6MU
M;W1I`&1A;&ES`'9A<G1O=&]J;R!P87-I<FEN:VEM87,`=D-A<F0`<#H`=V5A
M=&AE<BYC;VT`:OMS^"!J=6]D87-I<R!SX')A\&%S`&K[<_@@8F%L=&%S:7,@
M<^!R8?!A<P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O;&]C86QE+VUK7TU++P``````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S`#`Q-S0T
M-P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O;6M?34LO3$-?
M34534T%'15,O````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-C,`,#(Q,C,T`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+VQO8V%L92]M:U]-2R],0U]-15-304=%4R]I;7`N;6\`````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`U,S0T,``Q,#0Q-S,V,C<V,P`P,C(S-C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````WA($E0````!$`0``
M'````#P*``"Q`0``7!0````````@&P``"@```"$;```*````+!L```H````W
M&P``"@```$(;```$````31L``!<```!2&P``*````&H;```R````DQL``#(`
M``#&&P``&P```/D;```N````%1P``#<```!$'```?````'P<```(````^1P`
M``4````"'0``#P````@=```(````&!T```@````A'0``&0```"H=```'````
M1!T```X```!,'0``!0```%L=```#````81T``$X```!E'0``4````+0=``!"
M````!1X```@```!('@``$0```%$>```[````8QX```P```"?'@``"0```*P>
M```&````MAX```H```"]'@``"P```,@>```1````U!X```H```#F'@```P``
M`/$>```(````]1X```D```#^'@``!`````@?```$````#1\```8````2'P``
M#@```!D?```5````*!\```(````^'P``"@```$$?```&````3!\```H```!3
M'P``#0```%X?``!B````;!\``%\```#/'P``'````"\@```.````3"````P`
M``!;(```#0```&@@```,````=B```!0```"#(```#P```)@@```'````J"``
M`!````"P(```7````,$@```$````'B$```<````C(0``#@```"LA```I````
M.B$```8```!D(0``#0```&LA```:````>2$``!T```"4(0``&0```+(A``!=
M````S"$```(````J(@``!0```"TB```$````,R(``!`````X(@``&0```$DB
M```:````8R(```8```!^(@``$````(4B```'````EB(``!````">(@``'```
M`*\B```*````S"(``!0```#7(@``(P```.PB```F````$",```0````W(P``
M$@```#PC```%````3R,```X```!5(P``!````&0C```%````:2,```T```!O
M(P``%0```'TC```I````DR,``"P```"](P``*````.HC```%````$R0``!``
M```9)```$````"HD```/````.R0```L```!+)```#P```%<D```,````9R0`
M``\```!T)```"@```(0D```2````CR0```T```"B)```#````+`D```A````
MO20```,```#?)```!P```.,D```*````ZR0``!````#V)```!P````<E```(
M````#R4``!D````8)0``!````#(E```,````-R4```0```!$)0``!````$DE
M```,````3B4``!$```!;)0``#````&TE```*````>B4```4```"%)0``!0``
M`(LE```&````D24```H```"8)0``"0```*,E```2````K24``!(```#`)0``
M$````-,E```(````Y"4```D```#M)0``$````/<E```:````""8```8````C
M)@``#````"HF```'````-R8```L````_)@```@```$LF```'````3B8```@`
M``!6)@``#P```%\F```'````;R8``!,```!W)@``#````(LF```.````F"8`
M``P```"G)@``#@```+0F```/````PR8```T```#3)@``#P```.$F```F````
M\28```L````8)P``!@```"0G```'````*R<```0````S)P``!0```#@G```#
M````/B<```@```!")P``#````$LG```$````6"<```P```!=)P``"0```&HG
M```"````="<``!D```!W)P``$@```)$G```$````I"<```L```"I)P``"0``
M`+4G```-````OR<```P```#-)P``%````-HG```6````[R<```4````&*```
M#`````PH```C````&2@```T````]*```#0```$LH```'````62@```@```!A
M*```%0```&HH```>````@"@```@```"?*```%````*@H```%````O2@``#$`
M``##*```&@```/4H```H````$"D``"D````Y*0``+@```&,I```V````DBD`
M`"P```#)*0``,0```/8I```0````*"H```T````Y*@``!0```$<J```3````
M32H```T```!A*@``%@```&\J```(````ABH``!````"/*@``%0```*`J```3
M````MBH```<```#**@``%0```-(J```+````Z"H``!8```#T*@``"P````LK
M```Z````%RL```T```!2*P``!0```&`K```,````9BL```T```!S*P``"@``
M`($K```&````C"L```X```"3*P``!0```*(K```&````J"L``$L```"O*P``
M"@```/LK```'````!BP``#D````.+```!@```$@L```.````3RP```0```!>
M+```!@```&,L```*````:BP```L```!U+```&@```($L```7````G"P``!<`
M``"T+```&P```,PL```,````Z"P``!,```#U+```$0````DM```&````&RT`
M`$,````B+0``.0```&8M```,````H"T``!$```"M+0``!````+\M```0````
MQ"T``!<```#5+0``$@```.TM```+`````"X```T````,+@``%````!HN```O
M````+RX```<```!?+@``#0```&<N```6````=2X```<```",+@``"P```)0N
M```$````H"X``#,```"E+@``'@```-DN``!U````^"X``#X```!N+P``0@``
M`*TO```]````\"\``#T````N,```*0```&PP```I````EC```#$```#`,```
M*````/(P```F````&S$``#X```!",0``1P```($Q``!7````R3$``%4````A
M,@``50```'<R```[````S3(```\````),P``!0```!DS```"````'S,```T`
M```B,P```P```#`S```@````-#,``"8```!5,P``"@```'PS```3````AS,`
M``@```";,P``%@```*0S```,````NS,```<```#(,P``!@```-`S```:````
MUS,```@```#R,P``%````/LS```'````$#0```<````8-```!@```"`T```-
M````)S0```L````U-```#````$$T```*````3C0```(```!9-```!@```%PT
M```#````8S0``"$```!G-```'0```(DT```9````IS0``!<```#!-```10``
M`-DT```G````'S4``"L```!'-0``'0```',U```F````D34``"4```"X-0``
M/0```-XU``!!````'#8``"@```!>-@``+````(<V``!S````M#8```\````H
M-P``$````#@W```$````23<```(```!.-P``#@```%$W```/````8#<``'`!
M``!P-P``"@```.$X```+````[#@```@```#X.```"0````$Y```$````"SD`
M`!4````0.0``(@```"8Y```Q````23D``"D```![.0``&P```*4Y```P````
MP3D``#4```#R.0``AP```"@Z```'````L#H```4```"X.@``%````+XZ```*
M````TSH```\```#>.@``)P```.XZ```&````%CL```X````=.P``!0```"P[
M```$````,CL``#P````W.P``40```'0[```]````QCL```H````$/```$0``
M``\\```O````(3P``!8```!1/```"````&@\```'````<3P```T```!Y/```
M$0```(<\```0````F3P```L```"J/```$````+8\```(````QSP```H```#0
M/```!````-L\```'````X#P```8```#H/```$@```.\\```5`````CT```8`
M```8/0``!P```!\]```'````)ST```\````O/0``#0```#\]``!4````33T`
M`&D```"B/0``'@````P^```0````*SX``!4````\/@``#P```%(^```.````
M8CX``!0```!Q/@``#````(8^```%````DSX```\```"9/@``=0```*D^```'
M````'S\```D````G/P``#P```#$_```[````03\```<```!]/P``#0```(4_
M```G````DS\``"0```"[/P``'@```.`_``"&````_S\```(```"&0```!@``
M`(E````%````D$```!0```"60```(0```*M````A````S4````<```#O0```
M$````/=````)````"$$``!`````200``'0```"-!```(````04$``!$```!*
M00``)@```%Q!```J````@T$```8```"N00``$0```+5!```*````QT$``!$`
M``#200``!0```.1!```'````ZD$``!````#R00``'0````-"```P````(4(`
M`"T```!20@``)P```(!"```&````J$(```\```"O0@``$````+]"```.````
MT$(``!$```#?0@``#@```/%"```-`````$,```<````.0P``#@```!9#```4
M````)4,```T````Z0P``#````$A#```E````54,```0```![0P``!@```(!#
M```+````AT,``!(```"30P``"````*9#```)````KT,``!<```"Y0P```@``
M`-%#```)````U$,```D```#>0P``!0```.A#```4````[D,``!<````#1```
M#P```!M$```/````*T0```4````[1```!P```$%$```)````240```P```!3
M1```!0```&!$```,````9D0``!0```!S1```$P```(A$```%````G$0```\`
M``"B1```%@```+)$```F````R40```L```#P1```$````/Q$```%````#44`
M`!8````310```@```"I%```1````+44```X````_10``%@```$Y%```&````
M944``!(```!L10``#P```']%```,````CT4``!(```"<10``#P```*]%```3
M````OT4``!(```#310``#P```.9%```Z````]D4```D````Q1@``"P```#M&
M```'````1T8```@```!/1@``!P```%A&```#````8$8```L```!D1@``"P``
M`'!&```&````?$8```T```"#1@``#0```)%&```"````GT8``!0```"B1@``
M%@```+=&```&````SD8```P```#51@``%0```.)&```'````^$8```@`````
M1P``$P````E'```.````'4<```D````L1P``#````#9'```E````0T<```L`
M``!I1P``#P```'5'```(````A4<```<```".1P``'0```)9'```<````M$<`
M``4```#11P``$````-='```'````Z$<``#L```#P1P``%@```"Q(```@````
M0T@``#````!D2```*0```)5(```Q````OT@``"<```#Q2```*0```!E)```0
M````0TD``!````!420``!@```&5)```1````;$D``!$```!^20``00```)!)
M```)````TDD``!$```#<20``%@```.Y)```9````!4H```8````?2@``%P``
M`"9*```-````/DH``!@```!,2@``#````&5*```^````<DH```H```"Q2@``
M"````+Q*```0````Q4H``!$```#62@``#0```.A*```)````]DH``!\`````
M2P``!@```"!+```(````)TL``$T````P2P``$@```'Y+```,````D4L``$4`
M``">2P``"@```.1+```:````[TL```D````*3```!@```!1,```.````&TP`
M``T````J3```'````#A,```9````54P``!D```!O3```'@```(E,```.````
MJ$P``!L```"W3```#@```--,```&````XDP``$P```#I3```30```#9-```1
M````A$T``!0```"630``"````*M-```3````M$T``!T```#(30``$````.9-
M```4````]TT``!8````,3@``'0```"-.```W````04X```0```!Y3@``#@``
M`'Y.```1````C4X```<```"?3@``"````*=.```%````L$X``#````"V3@``
M&````.=.``!Z`````$\``#D```![3P``.0```+5/```Q````[T\``#(````A
M4```(````%10```A````=5```"P```"74```&P```,10```E````X%```#@`
M```&40``20```#]1``!-````B5$``$T```#740``6@```"52```_````@%(`
M``X```#`4@``!@```,]2```"````UE(```X```#94@```P```.A2```J````
M[%(``"L````74P``#````$-3```3````4%,```<```!D4P``$0```&Q3```3
M````?E,```H```"24P``"P```)U3```/````J5,```X```"Y4P``%@```,A3
M```*````WU,```@```#J4P``!P```/-3```3````^U,```X````/5```$```
M`!Y4```1````+U0```(```!!5```!P```$14```"````3%0``!<```!/5```
M&````&=4```5````@%0``!<```"65```,````*Y4```Q````WU0``"@````1
M50``%P```#I5```K````4E4``"D```!^50``.@```*A5```W````XU4``"0`
M```;5@``(0```$!6``!N````8E8```<```#15@``%P```-E6```&````\58`
M``,```#X5@``$0```/Q6```1````#E<```$```",`````P```#(!``#]````
M6P````````!'````60````(!``"'````WP```.H````A````(````"0```"A
M``````````\````C`0``+`````````#9````>@```+T```!>````^P```(\`
M``#X``````````````#(````F0```%````#L````;0``````````````\```
M``````"\`````````.(```#Q`````````"4```"O````:````%\```!1````
M`````$\```!+````&0```$0````^`0```````"L````%````TP```)<```"J
M`````````!P``````````````&L```"R````"P$``#H!```H`0``V```````
M```D`0````````````!8````=@```"(```!Q````)P`````````F`0``,```
M``````"U````+P```'(```!T````!`$```````!2````F@```*P````[````
MM````+8```"?````]P````T!``";````YP```(T````K`0``&@$``&0`````
M````<````#@!```T````=P```,P``````````````*4```"%````S0``````
M````````,P$``!`````U````U````(L````H````Q0```"<!``!-````4P``
M``````#T````80```)@````R`````````)8`````````?0``````````````
M,0```#4!```#`0``DP```*<````3`0``?P`````````V`0```````)`````"
M````20```!(```!Y````0P```!<!``#Y````0@$```$!``!!`0``[0```!T`
M``#^````+@$``$````!U`````````"$!``#!````50``````````````1@``
M`/(``````````````&X````1````/0```,8```!``0``2`````````!B````
M`````,<```#D````ZP``````````````.`````<!``#*````J``````````\
M`````````/P````9`0``N````%<`````````@@`````````:````;P```*(`
M`````````````"H````Q`0```````)P````)````"@$``"`!````````#0``
M`.$`````````-`$``!@!```M`0````````````#/````S@```#D!````````
M%P````4!````````8P```*0`````````J0```$$````]`0``+`$```X`````
M`````````/,````V````?````-X```"_````90```+````"*````$P```&P`
M````````A`````0```#V`````````!4!``````````````````"5````H```
M```````>`````````"\!``#H````Y@````````"C````[@```#`!``">````
MNP````<```!J````O@```"4!`````````````#P!````````_P```$0!``##
M````5@``````````````&`````8!``"&````$@$``````````````````"H!
M``#I````P``````````,`0``G0```,D`````````+@```&`````4````````
M`$(```!S`````````(X`````````X`````@!``!I````@0`````!````````
M?@```!P!```6`0``%`$``*8```#:````3````!L!````````#```````````
M``````````````"K````U0```,(```"S`````````&8```"`````'0$``#X`
M``"(``````````````"W````L0````@```!:``````````````#C````````
M`*T```!4````U@```.\````>`0````````````!#`0``/P```(D```"Z````
M&P```.4````Y``````````````#+````>````-(```#0````Q````-T````+
M`````````'L````)`0``3@```-<```#U`````````!$!``"Y````.@```-P`
M`````````````)(```#;`````````"8```"N`````````#\!````````%0``
M`"D!```&````+0```#<!````````*0````X!```?````E````/H````S````
M``````\!````````70```$H````0`0``T0```#<```!G`````````",```"#
M````D0```!\!```B`0``7````#L!```6````10`````````*````````````
M````("`@("`@5&\Z(``@("`@1&%T93H@`"`@("!&<F]M.B``(%-U8FIE8W0Z
M(``@:6X@`"5D('1O("5D(&]F("5D($UE<W-A9V5S`"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@86QR96%D>2!E>&ES=',N
M(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE9"X`)7,@9F]L9&5R(&)E
M:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"X`)7,Z("5S
M("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!<'!L>2!T:&5S92!C:&%N9V5S(&%N
M9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A<F0@86QL(&-H86YG97,@
M86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*0`H4F5T=7)N('1O
M('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E
M<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E
M96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`#(T(&AO=7)S`$%-+U!-`$%D9"!A
M(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061M:6YI<W1R871I;VX`06QI87,`06QL`$%L
M;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E
M(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE.@!!;&P@;65S<V%G97,@
M:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B
M92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD('-E;G0M;6%I;"!F;VQD
M97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`
M06YS=V5R960`06YS=V5R960@;65S<V%G97,`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)R
M:79A;"!4:6UE`$%S8V5N9&EN9P!!='1A8V@`071T86-H;65N=`!!='1A8VAM
M96YT<P!!=F%I;&%B;&4@9FEE;&1S.@!"86-K('1O("5S`$)C8P!":7)T:&1A
M>0!";&%C:VQI<W0`0F]D>0!";W1H`$-A;F-E;`!#86YC96P@365S<V%G90!#
M86YC96P@4')O8FQE;2!297!O<G0`0V,`0V5L;"!0:&]N90!#:&%N9V4`0VAA
M;F=E($%L;`!#:&%N9V4@1F]L9&5R`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@
M<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G
M92!A;F0@:&]W(&UE<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!T:&4@;F%M
M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6PN`$-H96-K($9O
M;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAO;W-E($%C=&EO;CH`0VQO<V4@5VEN
M9&]W`$-L;W-E9"!&;VQD97(`0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&
M;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VUP86YY`$-O;F9I<FT@4&%S<W=O
M<F0`0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L
M(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U('=H96X@:70@87)R
M:79E<RX`0V]P>0!#;W)R96-T`$-O<G)E8W1E9"!497AT`$-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-R96%T90!#<F5A=&4@
M1F]L9&5R`$-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R`$-R96%T92!A(&YE
M=R!S96YT(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(`
M0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M
M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"!A;F0@9&5L971E('-P
M86TN`$1$`$1A:6QY`$1A=&4`1&5F875L="!)9&5N=&ET>0!$969A=6QT('-O
M<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E
M;&5T90!$96QE=&4@1F]L9&5R*',I`$1E;&5T960`1&5L971E9"!M97-S86=E
M<P!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E<V-E;F1I;F<`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@
M3F5W($UA:6P`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'``1&]N90!$;W=N;&]A9"!&;VQD97(H<RD`1')A9G0`1')A9G1S(&9O;&1E
M<CH`161I=`!%;6%I;`!%;7!T>2!R97-U;'0N`$5N9"!F;W)W87)D960@;65S
M<V%G90!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E
M<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E
M<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R`$5R
M<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U
M(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI
M;G5T90!%>&%M<&QE('9A;'5E<SH`17AP86YD($%L;`!%>'!A;F0@06QL($9O
M;&1E<G,`17AP86YD($9O;&1E<@!%>'!A;F0@3F%M97,`1F%I;&5D('1O(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&:6QT97)S`$9I<G-T(%!A9V4`
M1F]L9&5R($YA=FEG871O<@!&;W)W87)D`$9O<G=A<F0Z`$9O<G=A<F1E9"!M
M97-S86=E(&9R;VT@)7,`1G)O;0!&<F]M($%D9')E<W,`1G=D.@!(96QP`$AI
M9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E9`!(;VUE($%D9')E<W,`2&]M
M92!0:&]N90!(;W)D90!)3D)/6`!)9VYO<F4`26=N;W)E($%L;`!);7!O<G1A
M;G0`26UP;W)T86YT(&UE<W-A9V5S`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O
M<G1E9"!F:65L9',Z`$QA;F=U86=E`$QA<W0@4&%G90!,:7-T($AE;'`@5&]P
M:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO9R!I;@!,;V<@:6X@
M=&\@)7,`3&]G(&]U=`!,;V=I;B!487-K<P!-30!-86EL8F]X`$UA<FL@87,Z
M`$UA=&-H:6YG(&9I96QD<P!-97-S86=E`$UE<W-A9V4@0V]M<&]S:71I;VX`
M365S<V%G92!$871E`$UE<W-A9V4@4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S
M86=E(%-O=7)C90!-97-S86=E(%9I97=I;F<`365S<V%G92!F;&%G<P!-97-S
M86=E(&9O;&1E<G,`365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@
M=FEE=RX`365S<V%G97,@=&\`36]D:69Y`$UO;G1H;'D`36]V90!.979E<@!.
M97<`3F5W($UA:6P`3F5W(&UE<W-A9V5S`$YE>'0`3F5X="!-97-S86=E`$YE
M>'0@4&%G90!.;P!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO('-P96QL
M:6YG(&5R<F]R<P!.;VYE`$YO="!$96QE=&5D`$YO="!$<F%F=`!.;W0@26UP
M;W)T86YT`$YO="!097)S;VYA;`!.;W0@9&5L971E9"!M97-S86=E<P!.;W0@
M:6UP;W)T86YT(&UE<W-A9V5S`$YO=&5S`$]L9"!M97-S86=E<P!/;&0@<V5N
M="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D+@!/=&AE<B!/<'1I;VYS`%!A
M9V4@)60@;V8@)60`4&%R="AS*0!087-S=V]R9`!087-S=V]R9',@;75S="!M
M871C:"X`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<G-O;F%L
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!L86-E('EO=7(@<VEG;F%T
M=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\`4&QE87-E(&5N=&5R
M('1H92!N97<@;F%M93H`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H
M92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P
M87-S=V]R9`!0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A
M9&1R97-S97,N`%!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P
M97)F;W)M(&%N>2!A8W1I;VYS+@!0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N
M92!F;VQD97(@=&\@<V5A<F-H+@!0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O
M;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN`%!R979I;W5S($UE<W-A9V4`4')E
M=FEO=7,@4&%G90!0<FEN=`!0<F]B;&5M($1E<V-R:7!T:6]N`%!U<F=E($1E
M;&5T960`4'5R9V4@5')A<V@@:&]W(&]F=&5N.@!2961I<F5C=`!2961I<F5C
M="!-97-S86=E`%)E9&ER96-T('1H:7,@;65S<V%G90!2961I<F5C=&EN9R!F
M86EL960N`%)E9G)E<V@`4F5F<F5S:"!&;VQD97(@5FEE=W,Z`%)E;&]A9"!6
M:65W`%)E;65M8F5R('1H92!L87-T('9I97<`4F5M;W9E('!A:7(`4F5N86UI
M;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!297!L86-E('=I=&@Z`%)E<&QY`%)E<&QY('1O($%L;`!297!L
M>2!T;R!!;&PZ`%)E<&QY+51O.B``4F5P;'DZ`%)E<&]R="!A<R!3<&%M`%)E
M<V5T`%)E<W5M90!2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E
M<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\`4V%V
M92!$<F%F=`!3879E(&%S`%-A=FEN9R!T:&4@9')A9G0@9F%I;&5D+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<P!396%R8V@`4V5A<F-H(%)E
M<W5L=',`4V5E;@!396QE8W0`4V5L96-T(&%L;`!396QE8W0@;F]N90!396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RX`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE;2!297!O<G0`4V5N
M="!M86EL(&9O;&1E<CH`4V5R=F5R`%-E="!P<F5F97)E;F-E<R!F;W(@=VAA
M="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S86=E<RX`
M4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V
M:6YG(&$@9')A9G0_`%-H;W<@1&5L971E9`!3:&]W(%5N<W5B<V-R:6)E9`!3
M:7IE`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`
M4W!E8VEA;"!#:&%R86-T97)S`%-P96QL($-H96-K`%-P96QL($-H96-K97(`
M4W!E;&P@8VAE8VL@8V]M<&QE=&4`4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E
M96X@=VAE;B!S<&5L;"!C:&5C:VEN9RX`4W5B:F5C=`!3=6)J96-T($9I96QD
M`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5C8V5S<P!3=6=G97-T:6]N<P!4
M97AT`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N86UE
M9"!T;R`B)7,B+@!4:&4@9F]L9&5R("(E<R(@86QR96%D>2!E>&ES=',`5&AE
M(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I
M=',@;F%M92X@270@;6%Y(&-A=7-E('!R;V)L96US+B!0;&5A<V4@<V5E('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!F;VQD97(@(B5S(B!W87,@
M8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@:70N`%1H
M92!F;VQD97(@(B5S(B!W87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N
M<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S(&YO="!C
M<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H92!F;VQD
M97(@(B5S(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@8W)E
M871E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@9&5L971E
M9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T
M;R`B)7,B+@!4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C
M960N`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N`%1H
M97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG
M('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H
M97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F
M;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E
M<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A
M<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E
M<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AI<R!M87D@=&%K
M92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU
M93\`5&AI<R!M97-S86=E('1O`%1I=&QE`%1O`%1R87-H(&9O;&1E<CH`55),
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86YS=V5R960`56YA;G-W
M97)E9"!M97-S86=E<P!5;F1E;&5T90!5;F1I<V-L;W-E9"!296-I<&EE;G1S
M`%5N9&\@0VAA;F=E<P!5;FYA;65D`%5N<V5E;@!5;G-U8G-C<FEB92!F<F]M
M($9O;&1E<BAS*0!5<V5R;F%M90!5<V5R<R!I;B!T:&4@<WES=&5M.@!6:65W
M("5S`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EE<P!9;W4@87)E
M(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R``66]U(&%R92!R96YA;6EN9R!T
M:&4@9F]L9&5R.B``66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+@!9;W4@:&%V
M92`Q(&YE=R!M97-S86=E+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U
M(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T
M('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G92!F:7)S="X`66]U(&UU<W0@
M<W!E8VEF>2!A(')E8VEP:65N="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(97)E
M(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U8G-C
M<FEB960@9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%EO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`66]U
M('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R('-I9VYA='5R93H`6U!R;V)L
M96T@4F5P;W)T70!N;VYE`&]R`'-P96QL:6YG(&5R<F]R`'-P96QL:6YG(&5R
M<F]R<P!0<F]J96-T+4ED+59E<G-I;VXZ(&UK7TU+"E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,RTP-BTR-B`Q-#HU,RLP,C`P"DQA<W0M5')A;G-L871O<CH@4W1O:F%N(%!E
M<V]V(#QS<W!`975R96MA+F-O;2YM:SX*3&%N9W5A9V4M5&5A;3H@36%C961O
M;FEA;B`\:3$X;D!L:7-T+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+34*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E;F5R871O<CH@
M2T)A8F5L(#$N,"XQ"@`@("`@(""TWCH@`"`@(""TT.+CW#H@`"`@(""^U#H@
M`""]T.';WM(Z(``@TMX@`"5D(-3>("5D(-[4("5D(-_>X-#:V``E<R"^W]7@
MT.;8V"#7T"#>U.#6X]+0^M4@+2"_WN+2X-30`"5S(-+5_-4@W][AXM[8+B"R
MT.C0XM`@)7,@W]#?VM`@W=4@U2#@U=C<U=WCTM#=T"X`)7,@U2#@U=C<U=WC
MTM#=T"#=T"#?WN?5XM[:WN(@W=`@W-7AU>;>XBX`)7,Z("5S("@E9"9N8G-P
M.][4)FYB<W`[)60I`"B_X-C<U=W8(-/8(-_@WMS5W=CBU2#8(-[4V"#=T"#A
MV]74W=C>XB#?X-[7WN`N*0`HON+DX-O8(-/8(-_@WMS5W=CBU2#8(-+@T.+8
M(.'5(-W0(,'>X>+0TM@@W^#>U][@WN(N*0`HLN#0XM@@X=4@W=`@P=[AXM#2
MV"#?X-[7WN#>XB#?WB#?X-C<U=WCTM#ZU2#=T"#AV.+5(-_@WMS5W=@@W=#?
MX-#2U=W8(-3>(.'5T]`N(+_@WMS5W=CBU2#>U"#BU=K>TMW8WN(@W^#>U][@
M(+VUO+`@U-`@T=C4T.(@W^#8W-7=U>+8+BD`,C0@Y]#AT`!!32]030"TWM30
MU-@@W=[2(-K>X-CAW=C:.@"TWM30U-@@W]#@`+3>U-#4V"#:WN#8X=W8V@"T
MWM30TM#ZU>+>(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=WBX`L-3@U>'0
M`+#4W-C=V.'BX-#FV/C0`$%L:6%S`,'8XM4`P=CBU2#?WN#0VM@@WM0@W]#?
MVM#2T"#\U2#1V-30XB#?X-7DX-O5W=@@TMX@U=35W2!-0D]8(.30^-LZ`,'8
MXM4@W][@T-K8(-[4(-+0Z-#BT"`B)7,B(-_0W]K0(-_>X>+0X-@@WM0@)7,@
MU-7=WM+8(/S5(-'8U-#B(.;5V][AW=X@V-?1X-CHT-W8+@#!V.+5('-E;G0M
M;6%I;"#?T-_:V"#?WN'BT.#8(-[4("5S(-S5X=7FV"#\U2#1V-30XB#8U]'@
MV.C0W=@N`+[4T][2WN#5W=@`OM33WM+>X-7=V"#?WN#0VM@`M-#;V"#AT-K0
MXM4@NKZ\O[NUPKV^(-30(-/8(-C7T>#8Z-7BU2#?WN#0VMC2U3\`LN#5W-4@
MW=`@W^#8X>+8T]WCTM#ZU0#`T.'BU>?:V`"_X-C:T.?8`+_@V-K0Y]7=(.30
M^-L`O^#8VM#GU=W8(.30^-O>TM@`M-[AXM#?W=@@W][;V/K0.@"]T-?0U"#4
MWB`E<P"]U=+8U-O8TM`@VM[?V/C0`,#>U-7=U-7=`,;@W=`@V]CAXM``PM7;
MW@"X(-32U>+5`+[BVM#6V`"^XMK0UM@@^-`@W][@T-K0XM``ON+:T-;8(+_@
MWM';U=P@P-7?WN#B`+K>W]CXT`"\WM'8V]7=`+_@WMS5W=@`O^#>W-7=V"#3
MV"#AV.+5`+_@WMS5W=@@W]#?VM``O^#>W-7=V"#3V"#>W^;8V.+5(-?0(-_@
MV-K0UR#=T"#1X-[XWN(@W=`@W][@T-K8(-_>(.'BX-#=T"#8(-_@T-+8V]#B
MT"#7T"#AWN#BV.#0^M4N`+_@WMS5W=@@T]@@V-S5XMXL(-#4X-7AT.+0(-@@
MW][BW]CAWN(@Z.+>(-OC\]7BWB#3V"#3V]74T-#B(-K>T]`@T]@@Y]CBT-#B
M(-@@WM33WM+0X-#0XB#=T"#BTM[8XM4@W][@T-K8+@"]T-?=T.?8(-_0W]K0
M*-@I(-?0(-W>TM`@W][HXM``N-?1U>#8(-35^.'BTMC5.@"WT.+2WN#8(-/>
M(-_@WM?>X-7FWN(`M]#BTM[@U=W0(-_0W]K0`,'>T=7@V"#3V"#AV.+5`,'>
MT=7@V"#3V"#AV.+5(-_0W]K8`,'>T=7@V"#?T-_:T`#$V.#<T`"_WN+2X-38
M(-O>U]C=VM``NM[=XN#>V]`@W=#4(.3@U=K2U=WBW=[AXB#=T"#?X-[2U>#C
MTM#ZU2#4T-O8(-C<T"#=WM+8(-_>X-#:V"#8(-30V]@@U-`@X=4@TN#HV"#8
MU]+5X>+CTM#ZU2#7T"#=V-+=WN+>(-_@V.'BV-/=X]+0^M4N`+K>W]C@T/@`
MNM[@U=/8X-#X`+K>X-73V.#0W2#BU=KAX@"\WM3CV][B(-W0(-?0U-#GT.+0
M(-?0(-[4X-;CTM#ZU2`E<R#=U2#<WM;5(-30(-'8U-4@WN+2WN#5W0"ZX-78
MX-#X`+K@U=C@T/@@W]#?VM``NN#5V.#0^"#=WM+0(-_0W]K0(-?0(-W5U]#2
MX.C5W=@@W][@T-K8`+K@U=C@T/@@W=[2T"#?T-_:T"#7T"#?X-#BU=W8(-_>
MX-#:V`"ZX-78X-#X(-W>TM`@W]#?VM`@U]`@WN+?T-3>YM@`NN#5V.#0^"#?
MX-#2V-O0(-?0(.38V^+@V.#0^M4@V"#>X-/0W=C7V.#0^M4@W=`@W][@T-K8
MXM4@Z.+>(.'5(-_@V-S0T.(L(.'>X.+8X-#ZU2#=T"#8X>+8XM4@TMX@W]#?
MVM@@V"#1X-CHU?K5(-W0(-W5W][6U=O=V.+5(-_>X-#:V"X`1$0`M-W5TMW>
M`+30XN/<`,'BT-W4T.#4U=T@V-35W>+8XM7B`,'BT-W4T.#4U=T@VN#8XM7@
MX]P@U]`@X=[@XMC@T/K5.@#!XM#=U-#@U-7=(.#5U-[AV]74(-?0(.'>X.+8
MX-#ZU3H`N-?1X-CHV`"XU]'@V.C8(-_0W]K0*-@I`+C7T>#8Z-#=V`"XU]'@
MV.C0W=@@W][@T-K8`+'@V.C5^M4@V"#?X-7<U>'BX]+0^M4@W][@T-K8`+[?
MT//0Y]K8`+[?V.$@W=`@W^#>T=O5W-[B`+W5(/C0(-_@WM+5X./2T/@@W]#?
MVM#BT"#7T"#=WM+0(-_>Z.+0`+W5(-_@V.'BT-_CTM#X(-38X-7:XMW>(-3>
M(&UA:6YT96YA;F-E+G!H<`"WT-+@Z-@`O^#5TM?5W-@@W]#?VM`HV"D`O=77
MT-+@Z-7=V`"_T-_:T""]U=?0TN#HU=W8.@##X-74V`#5+=_>Z.+0`+_@T-?5
MW2#@U=?CV^+0XBX`M]#2X.C8(/C0(-_@U=_@T.+5W=#BT"#?WN#0VM``LMW5
MX=7BU2#8W-4@U]`@W=[2T.+0(-_0W]K0(-?0(-W5U]#2X.C5W=@@W][@T-K8
M`++=U>'5XM4@V-S5(-?0(-W>TM#BT"#?T-_:T"#7T"#?X-#BU=W8(-_>X-#:
MV`"RW=7AU>+5(-C<U2#7T"#=WM+0XM`@W]#?VM`@U]`@WN+?T-3>YM@`L^#5
MZ-K0`,'5VM[8(#$U(-S8W>/BV`#!U=K>V"`S,"#AU=KCW=38`,'5VM[8(#4@
MW-C=X^+8`,'5VM[5(-_@V/C0TN/2T/K5`,'5VM[X(-_>V]`@Y]#A`,'5VM[X
MT"#<V-WCXM``O^#8W-7@.@#`T.C8X-@@T]@@X=CBU0#`T.C8X-@@T]@@X=CB
MU2#?T-_:V`#`T.C8X-@@Y-[;U-7@`,#0Z-C@V"#8W-CZT`"]U>/AW]7HW=`@
MVM[=U=KFV/C0(.'>($Q$05`@X=7@TM7@WN(N`,30VN$`Q-C;XN#8`+_@TM`@
MX>+@T-W0`+W0TMC3T.+>X"#7T"#?T-_:V`"_X-7?X-#BV`"_X-7?X-#BV#H`
MO^#5W^#0XM7=T"#?WN#0VM`@WM0@)7,`OM0`OM0@T-3@U>'0`+_@U=_@T.+8
M.@"_WMS>Z`#!VN#8^"#3V"#8U]'@V.C0W=CBU0#!VN#8^"#3V"#=U=_@U=+7
MU=S0W=CBU0"TWMS0Z-W0(-#4X-7AT#H`M-[<T.C5W2#BU=O5Y-[=`$AO<F1E
M`,'0W=30Y]4`N-/=WN#8X-#X`+C3W=[@V.#0^"#AU0"RT-;=V`"RT-;=V"#?
MWN#0VM@`N-S?WN#BV.#0W=X@W][;U3H@)7,`N-S?WN#BV.#0W=@@W][;V/K0
M.@"HT-?8V@"_WN';U=3=T"#AXN#0W=``N-?;V.'BT/@@XM7<V"#7T"#?WMS>
MZ`"[V.'BT/K5XMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>+@"_X-CX
MT-+CTM#ZU0"_X-CXT-+8(.'5(-+>("5S`+C7V]77`+?0U-#GV"#?X-@@W^#8
M^-#2X]+0^M4`34T`O][HXM7=X=K>(.'0W=30Y]4`O-#@VMC@T/@@VM#:WCH`
MNM[@U>'?WMW4V.#0Y]K8(-_>V]CZT`"_WN#0VM``P=[AXM#2X]+0^M4@W][@
MT-K0`+30XN/<(-W0(-_>X-#:T`"QT.#0^"#?WN#0VM``L][;U=S8W=`@W=`@
MW][@T-K0`+C7TM[@(-W0(-_>X-#:T`"_X-73V]74X]+0^M4@W][@T-K8`+#B
MX-C1X^+8(-W0(-_>X-#:T`"_T-_:V"#7T"#?WN#0VM@`L>#>^"#=T"#?WN#0
MVM@@W]X@X>+@T-W0(-_@V"#?X-C:T-<@W=`@W][HXM7=X=K>XMX@X=#=U-#G
MU0"_WN#0VM@@U-X`O-[4V.38YMC@T/@`O-7AU>?=W@"_X-7<U>'BV`"]V-K>
MT]#H`+W>T@"]WM+0(-_>X-#:T`"]WM+8(-_>X-#:V`#!V]74W=X`P=O5U-W0
M(-_>X-#:T`#!V]74W=`@X>+@T-W0`+W5`+W5(.'5(-W0TM74U=W8(-_0W]K8
M`+W5W-`@W^#0TM[?V.'=V"#3X-7HVM@`O=C5U-W0`+W5(-C7T>#8Z-#=V`"]
MU2#=U=?0TN#HU=W8("A$<F%F="D`O=72T-;=V`"]U2#;V.?=V`"]U2#8U]'@
MV.C0W=@@W][@T-K8`+W5TM#6W=@@W][@T-K8`+?0T=7;U>C:V`#!XM#@V"#?
MWN#0VM@`P>+0X-CBU2!S96YT+6UA:6P@W]#?VM@@X=4@V.'GV.'BU=W8+@"T
MX./3V"#>W^;8V`#!XN#0W=`@)60@WM0@)60`M-7;*-[2V"D`N][7V-W:T`"[
MWM?8W=K8XM4@W-[@T"#4T"#1V-30XB#8X>+8+@"XU]+@Z-@@WM_5X-#FV-@@
MU]`@WM3@UN/2T/K5`+O8Y]W>`+O8Y]W8(-C=Y-[@W-#FV-@`PM7;U>3>W0"R
MW-7BW=@@W][BW]CA(-_@U=0@XM7:X>+>XB#=T"#:WO@@X=4@WM33WM+0X-`@
MV-O8(-_@U=_@T/S0/P"RW=7AU>+5(-/>(-W>TM[BWB#8W-4Z`++5(-S>V]C<
MU2#=T-+5U-7BU2#3WB#?X-[1V]7<WN(N`++5(-S>V]C<U2#=T-+5U-7BU2#2
MT.C5(-K>X-CAW=CGVMX@V-S5(-@@V][7V-W:T`#`T-?@U>C8(-32WN'<V.';
MU=W8(-C;V"#=U=+0V]C4W=@@T-3@U>'8+@"XU]'5X-@@W]#?VM`@W^#5U"#8
MU]+@Z./2T/K5(-W0(-'8V]X@VM[XT"#0VN;8^-`N`+C7T=7@V"#1T.#5W"#5
MU-W0(-_0W]K0(-?0(-_@U='0X./2T/K5+@"XU]'5X-@@X=#<WB#5U-W0(-_0
MW]K0(-?0(-[2T-`@WM_5X-#FV/C0+@"_X-7BY=[4W=`@W][@T-K0`+_@U>+E
MWM3=T"#AXN#0W=``O]7GT.+8`+[?V.$@W=`@W^#>T=O5W-[B`+[AXN#0W=@@
MV-?1X-CHT-W8`+K>V]KC(.?5X>+>(-30(-/8(-[BX>+@T-WCTM#<(-C7T>#8
MZ-#=V.+5(-[4(-_0W]K0XM`@U]`@WN+?T-3>YM@Z`+_@U=W0X=[GV`"_X-7=
MT.'>Y]@@W][@T-K0.@"_X-7=T.'>Y]@@^-`@W][@T-K0TM`Z`+W5(./AW]7H
MW=X@W^#5W=#AWN?CTM#ZU2X`ON'2U=;8`+[ATM76V"#?X-C:T-<@W=`@W]#?
MVM@Z`+[ATM76V"#?X-C:T-<`M]#?T-S5XM@@W][AV]74U=T@W^#8VM#7`+[4
MX>+@T-W8(-_0X`"_X-78W-7=X]+0^M7BWB#=T"`B)7,B(-+>("(E<R(@W=4@
MX^'?U=`N(+[2T"#3WB#2X-#BV"#AU>#2U>#>X@"WT-S5W=@@X=XZ`+[4T][2
MWN#8`+[4T][2WN#8(-W0(.'8XM4`OM33WM+>X-@@W=`@X=CBU3H`OM33WM+>
MX-@@W=`Z(`"^U-/>TM[@V#H`M-7DV-W8X-#X(-K0VMX@O=7?WM;5V]W0(-_>
MX-#:T`"^U-W>TMX`O^#>U-[;UM@`LN#0XM@@X=4@W=`@W][HXM7=X=K>XMX@
MX=#=U-#GU2#?WB#1X-CHU?K5+"#?X-7<U>'BX]+0^M4@V-O8(-K>W]C@T/K5
M(-_>X-#:V#\`M]#GX]+0^"#=U=?0TN#HU=W0`+?0Y^/2T/@@VM#:W@"]U>/A
MW]7HW=X@U]#GX]+CTM#ZU2#2WB#?T-_:T.+0(+W5U]#2X.C5W=@N(+[2T"#3
MWB#2X-#BV"#AU>#2U>#>XCH@)7,`O^#5T=#@X]+0^`#`U=?CV^+0XM@@WM0@
MW^#5T=#@X]+0^M7BW@"_X-[GV.+0W=@`N-?1U>#8`+C7T=7@V"#3V"#AV.+5
M`+C7T=7@V"#=V-74W=X`N-?1U>#8(.'5W]#@T.+>X"#7T"#4T.+CW-[B.@"X
MU]'5X-@@Y-[@W-#B(-?0(-30XN/<WN(Z`+C7T=7@V"#DWN#<T.(@U]`@TN#5
MW-7BWCH`N-?1U>#8(-32U2#>U-/>TM#@T.?:V"#?WMO8^M`N`+CAW^#0XM@@
MW][@T-K0`+_@T.+8(-C7TM7HXM#X(-?0(-_@WM';U=S>X@"_T-_:T""_X-#B
MU=W8.@#!U>#2U>``N-?1U>#5XM4@W][4U>'CTM#ZT"#7T"#>W=`@Z.+>(.'5
M(.';X^?CTM`@W^#8(-_@U=S5X>+CTM#ZU2#8(-'@V.C5^M4@W][@T-K8+@"T
MT-O8(-30(-/>(-?0XM+>X-#<(-_@WM?>X-[B(,'>X>+0TM@@W]X@U]#GX]+C
MTM#ZU2#=T"#?WN#0VM#BT"#2WB"]U=?0TN#HU=W8/P"_X-C:T-;8(-C7T>#8
MZ-#=V`"_X-C:T-;8(-W5W^#5TM?5W-#=V`"SWMO5W-C=T`"_X-7AVM[:W=@@
MWM3@UN/2T/K5`++=U>'CTM#ZU2#=T"#AW]7FV/C0V]W8(-?=T.;8`,'?U>;8
M^-#;W=@@U]W0YM@`O^#>TM7@VM`@W=`@W^#0TM[?V.$`O^#>TM7@X]+0YR#=
MT"#?X-#2WM_8X0"WT-+@Z-@@W^#>TM7@VM#BT"#=T"#?X-#2WM_8X0"_X-#2
MWM_8X=W8(-/@U>C:V"#?WB#?X-[7WN`@W^#8(-_@WM+5X-K0(-W0(-_@T-+>
MW]CAWN(N`,+5W-``PM7<T"#=T"#?WN#0VM``O^#5TM?5W-@@W]#?VM`HV"D`
MP^'?U>C=W@"_X-74V][7V`#"U=KAX@"_T-_:T.+0*-CBU2D@(B5S(B#\U2#1
MV-30XB#?X-78W-7=X]+0W=@@TMX@(B5S(BX`O]#?VM#BT"`B)7,B(-+5_-4@
MW][AXM[8`+_0W]K0XM`@(B5S(B#AWM3@UM@@W=72T-O8U-W8(-?=T.;8(-+>
M(-C<U>+>+"#HXMX@W-[6U2#4T"#?X-74V-?2V-K0(-_@WM';U=S8+B"^T>#0
MXM7BU2#AU2#4WB#2T.C8WN(@X=CAXM7<(-#4W-C=V.'BX-#BWN`N`+_0W]K0
MXM`@(B5S(B#5(-K@U=C@T-W0+"#=WB#AU2#CZ.+5(/C0(-W5W-#BU2#?X-72
MU]7<T-W>+@"_T-_:T.+0("(E<R(@U2#8U]'@V.C0W=`L(-W>(.'5(./HXM4@
M^-`@V-S0XM4@W^#5TM?5W-#=WBX`O]#?VM#BT"`B)7,B(-W5(-4@VN#5V.#0
MW=`N(+[2T"#3WB#2X-#BV"#AU>#2U>#>X@"_T-_:T.+0("(E<R(@W=4@U2#8
MU]'@V.C0W=`N(+[2T"#3WB#2X-#BV"#AU>#2U>#>X@"_T-_:T.+0("(E<R(@
MU2#CX=_5Z-W>(-K@U=C@T-W0+@"_T-_:T.+0("(E<R(@U2#CX=_5Z-W>(-C7
MT>#8Z-#=T"X`O]#?VM#BT"`B)7,B(-4@X^'?U>C=WB#?X-78W-7=X]+0W=`@
MTMX@(B5S(BX`O][BW]CAWN(@U2#CX=_5Z-W>(-?0W-7=U>(N`+W5W-`@W][@
MT-K8(-+>(-[2T"#?WNCBU=WAVMX@X=#=U-#GU2X`O=#AXM#=T"#?X-[1V]7<
M(-_@V"#1X-CHU?K5(-W0("5S+B"^TM`@T]X@TN#0XM@@X=7@TM7@WN(`O=#A
MXM#=T"#?X-[1V]7<(-_@V"#1X-CHU?K5(-W0(-_>Z.+5W>':WN+>(.'0W=30
MY]4N(+[2T"#3WB#2X-#BV"#AU>#2U>#>X@"]T.'BT-W0(-/@U>C:T"#?X-@@
MT>#8Z-7ZU2#=T"#?WN#0VMCBU2#>U"#?T-_:T.+0("(E<R(N(+[2T"#3WB#2
MX-#BV"#AU>#2U>#>X@"]T.'BT-W0(-/@U>C:T"#?X-@@T>#8Z-7ZU2#=T"#?
MWN#0VMCBU2#2WB#?T-_:T.+0("(E<R(N(+[2T"#3WB#2X-#BV"#AU>#2U>#>
MX@"]T.'BT-W0(-/@U>C:T"#?X-@@W][AXM#2X]+0^M4@T.+@V-'CXM@@W=`@
MW][@T-K8XM4@TMX@W]#?VM#BT"`B)7,B+B"^TM`@T]X@TN#0XM@@X=7@TM7@
MWN(`OM+0(-S>UM4@U-`@W][BX-#5+B"TT-O8(.'BU2#AV-/CX-W8(-35VM`@
MX=#:T.+5(-30(-_@WM3>V];8XM4_`+[2T-`@W][@T-K0(-3>`+W0X=O>T@"T
MW@"_T-_:T""^XM_0U-[:.@!54DP`O=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0
MW"#AWB!344P@X=7@TM7@WN(N`+W5(-S>UM72(-30(-/>(-_@U=+5U-#<(-[2
MWO@@5V]R9"#4WMKCW-7=XBX`O=7>U-/>TM[@U=W8`+W5WM33WM+>X-7=V"#?
MWN#0VM@`O][2X-#BV`"]U=_>U]W0XB#?X-C<T.+5VP"^XMK0UM@@T]@@W^#>
MW-7=V.+5`+W5V-S5W>/2T-T`O=7?X-[GV.+0W=@`P=[:X-CX(-_0W]K0*-@I
M`+K>X-CAW=CGVMX@V-S5`+K>X-CAW=CFV"#2WB#AV.'BU=S>XCH`O^#8VM#6
MV"`E<P"RW=C<T-W8U0"]U=35V]W>`+3>T>#5U-[XU-[2XM4@TMX@)7,`M-[1
MX-74WOC4U2P@)7,`L-3@U>'0(-W0(.#0T=[BT`#"U=O5Y-[=(-W0(.#0T=[B
MT`"SLP"SWM38Z-W>`+30`+K@U=C@T.+5(-W>TM`@W]#?VM`@TMX@`*C0(.#5
MV-S5W>/2T.+5(-_0W]K0XM`Z(`"XW-#BU2`E<R#=WM+8(-_>X-#:V"X`N-S0
MXM4@U=3=T"#=WM+0(-_>X-#:T"X`OM_8Z-7BU2#3WB#?X-[1V]7<WN(@W^#5
MU"#4T"#8X=_@T.+5XM4@V-?2U>CBT/@N`+S>X-`@W^#2WB#4T"#AU=O5VN+8
MX-#BU2#FU=O=WB#?WNCBU=WAVMX@X=#=U-#GU2X`O-[@T"#?X-+>(-30(-C7
MT=7@U>+5(-'0X-7<(-74W=`@W][@T-K0+@"\WN#0(-30(-+=U>'5XM4@W^#8
MW-#G+@"]T-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8W-4@U-`@X=4@WN+AXN#0
MW=@N`+W0TM74U>+5(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#4WM30U-4N
M`+W5(/C0(-C<T.+5(-_@U=+7U=S0W=X@W]#?VM#BT"`B)7,B+B"^TM`@T]X@
MTN#0XM@@X=7@TM7@WN(`O=4@^-`@V-S0XM4@X=K@V-7=WB#?T-_:T.+0("(E
M<R(N(+[2T"#3WB#2X-#BV"#AU>#2U>#>X@##X=_5Z-W>(/C0(-_@U=+7U=S0
MTN+5(-_0W]K0XM`@(B5S(BX`P^'?U>C=WB#XT"#AWMK@V-+BU2#?T-_:T.+0
M("(E<R(N`++0Z-C>XB#0TN+>X-C7T.;8WMW5W2#?X-[BWMK>VR#=U2#?WM3@
MUN/2T"#;V.'BT/K5(-K>X-CAW=CFV"P@V-O8(.+0T"#<WM;=WN'B(-4@WMW5
MTM[7W-[6U=W0(-[4(-3@X]/8(-_@V.?8W=@N`+_>XM_8X3H`6[C7TM7HXM#X
M(-?0(-_@WM';U=S>XET`W=C5U-W0`-C;V`#?X-#2WM_8X=W0(-/@U>C:T`#?
MX-#2WM_8X=W8(-/@U>C:V```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+VQO8V%L92]L=E],5B\`````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,3<T-S,`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VQV7TQ6+TQ#7TU%4U-!1T53+P``
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S
M`#`R,3(V,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O;'9?
M3%8O3$-?34534T%'15,O:6UP+FUO````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M-C`S-C8`,3`T,3<S-C(W-C,`,#(R-#$R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-X2!)4`````:@$``!P```!L"P``YP$`
M`+P6````````6!X```H```!9'@``"@```&0>```*````;QX```H```!Z'@``
M!````(4>```!````BAX``!<```",'@``*````*0>```R````S1X``#(`````
M'P``&P```#,?```N````3Q\``#<```!^'P``?````+8?```<````,R```!T`
M``!0(```"````&X@```%````=R````@```!](```!P```(8@```,````CB``
M``4```";(````P```*$@``!.````I2```%````#T(```0@```$4A```?````
MB"$```@```"H(0``$0```+$A```A````PR$``#L```#E(0``*P```"$B```Q
M````32(```P```!_(@``"0```(PB```&````EB(```H```"=(@``"P```*@B
M```1````M"(```H```#&(@```P```-$B```(````U2(```D```#>(@``!```
M`.@B```$````[2(```8```#R(@``#@```/DB```5````"",``#X````>(P``
M`@```%TC```*````8",```8```!K(P``"@```'(C``!B````?2,``%\```#@
M(P``'````$`D```.````720```P```!L)```#0```'DD```,````AR0``!0`
M``"4)```#P```*DD```'````N20``%P```#!)```!````!XE```'````(R4`
M``X````K)0``*0```#HE```&````9"4```T```!K)0``&@```'DE```=````
ME"4``!D```"R)0``70```,PE```H````*B8```(```!3)@``!0```%8F```$
M````7"8``!````!A)@``&0```'(F```:````C"8```8```"G)@``$````*XF
M```'````OR8``!````#')@``'````-@F```*````]28``!0`````)P``+P``
M`!4G```/````12<```<```!5)P``#P```%TG```C````;2<``"8```"1)P``
M(````+@G```$````V2<``!(```#>)P``!0```/$G```.````]R<```0````&
M*```%@````LH```%````(B@```T````H*```#P```#8H```2````1B@```T`
M``!9*```%0```&<H```I````?2@``"P```"G*```*````-0H```%````_2@`
M`!`````#*0``$````!0I```/````)2D```L````U*0``#P```$$I```,````
M42D```\```!>*0``"@```&XI```2````>2D```T```",*0``#````)HI```>
M````IRD``"$```#&*0```P```.@I```'````["D```0```#T*0``"@```/DI
M```0````!"H```<````5*@``"````!TJ```9````)BH```0```!`*@``#```
M`$4J```$````4BH```0```!7*@``#````%PJ```1````:2H```P```![*@``
M"@```(@J```%````DRH```4```"9*@``!@```)\J```*````IBH```D```"Q
M*@``$@```+LJ```2````SBH``!````#A*@``)````/(J```(````%RL```D`
M```@*P``$````"HK```&````.RL```P```!"*P``!P```$\K```+````5RL`
M``(```!C*P``!P```&8K```(````;BL``#<```!W*P``#P```*\K```'````
MORL``!,```#'*P``#````-LK```.````Z"L```P```#W*P``#@````0L```/
M````$RP```T````C+```#P```#$L```F````02P```L```!H+```!@```'0L
M```'````>RP```0```"#+```!````(@L```%````C2P```,```"3+```"```
M`)<L```,````H"P```0```"M+```#````+(L```)````ORP```(```#)+```
M&0```,PL```2````YBP```X```#Y+```!`````@M```+````#2T```D````9
M+0``#0```",M```,````,2T``!0````^+0``%@```%,M```%````:BT```(`
M``!P+0``#````',M```C````@"T```<```"D+0``$0```*PM```-````OBT`
M``T```#,+0``!P```-HM```(````XBT``!X```#K+0``"`````HN```4````
M$RX```4````H+@``,0```"XN```H````8"X``!H```")+@``*````*0N```I
M````S2X``"X```#W+@``-@```"8O```L````72\``#$```"*+P``$````+PO
M```-````S2\```4```#;+P``$P```.$O```-````]2\``!8````#,```"```
M`!HP```0````(S```!4````T,```$P```$HP```'````7C```!4```!F,```
M"P```'PP```6````B#````L```"?,```.@```*LP```-````YC````4```#T
M,```#````/HP```-````!S$```H````5,0``!@```"`Q```.````)S$```4`
M```V,0``!@```#PQ``!+````0S$```H```"/,0``!P```)HQ```Y````HC$`
M``8```#<,0``#@```.,Q```$````\C$```8```#W,0``"@```/XQ```+````
M"3(``!H````5,@``%P```#`R```7````2#(``!L```!@,@``'P```'PR```,
M````G#(``!,```"I,@``$0```+TR```&````SS(``$,```#6,@``.0```!HS
M```,````5#,``!$```!A,P``!````',S```0````>#,``!<```"),P``$@``
M`*$S```+````M#,```T```#`,P``%````,XS```O````XS,```<````3-```
M#0```!LT```6````*30```<```!`-```"P```$@T```%````5#0```0```!:
M-```,P```%\T```>````DS0``'4```"R-```/@```"@U``!"````9S4``#T`
M``"J-0``/0```.@U```I````)C8``"D```!0-@``,0```'HV```H````K#8`
M`"8```#5-@``/@```/PV``!'````.S<``%<```"#-P``50```-LW```O````
M,3@``%4```!A.```*P```+<X```[````XS@```\````?.0``(0```"\Y```<
M````43D```L```!N.0``!0```'HY```"````@#D```T```"#.0```P```)$Y
M```@````E3D``"8```"V.0``"@```-TY```3````Z#D```@```#\.0``%@``
M``4Z```,````'#H```<````I.@``!@```#$Z```:````.#H``!$```!3.@``
M#````&4Z```(````<CH```<```![.@``)P```(,Z```'````JSH```8```"S
M.@``#0```+HZ```+````R#H```P```#4.@``"@```.$Z```"````[#H```8`
M``#O.@```P```/8Z```A````^CH``"0````<.P``'0```$$[```9````7SL`
M`!<```!Y.P``*@```)$[```K````O#L``$4```#H.P``)P```"X\```A````
M5CP``"L```!X/```'0```*0\```]````PCP``$$`````/0``*````$(]```L
M````:ST``#````"8/0``$````,D]```?````VCT```\```#Z/0``#`````H^
M```0````%SX```\````H/@``!````#@^```$````/3X```(```!"/@``#@``
M`$4^```/````5#X```4```!D/@``50$``&H^```*````P#\```H```#+/P``
M"@```-8_```*````X3\```,```#L/P```0```/`_```9````\C\``"H````,
M0```*P```#=````E````8T```!L```")0```.0```*5```!`````WT```'$`
M```@00``'@```))!```A````L4$```H```#300``!0```-Y!```.````Y$$`
M``8```#S00``"````/I!```,`````T(```0````00@``1````!5"``!;````
M6D(``$H```"V0@``&0````%#```)````&T,``!,````E0P``,````#E#``!,
M````:D,``"D```"W0P``,````.%#```0````$D0```8````C1```"0```"I$
M```)````-$0```D````^1```$````$A$```-````640```,```!G1```#P``
M`&M$```0````>T0```@```",1````P```)5$```&````F40```X```"@1```
M&P```*]$```Z````RT0```(````&10``$0````E%```&````&T4```X````B
M10``70```#%%``!'````CT4``!T```#710``%````/5%```,````"D8```T`
M```71@``#````"5&```3````,D8```P```!&1@``"````%-&``!%````7$8`
M``4```"B1@``!P```*A&```/````L$8``"L```#`1@``"````.Q&```-````
M]48``"`````#1P``*````"1'```?````34<``%D```!M1P``-0```,='```"
M````_4<```@`````2```!@````E(```2````$$@``"$````C2```(````$5(
M```%````9D@```\```!L2```"````'Q(```2````A4@``!L```"82```"```
M`+1(```3````O4@``"\```#12```$`````%)```'````$DD``!(````:20``
M'0```"U)```B````2TD``"````!N20``"0```(])```1````F4D```H```"K
M20``$````+9)```'````QTD``!L```#/20``!P```.M)```.````\TD``!(`
M```"2@``%P```!5*```0````+4H``!H````^2@``*@```%E*```N````A$H`
M`"D```"S2@``!0```-U*```1````XTH``!(```#U2@``$`````A+```8````
M&4L```\````R2P``#````$)+```.````3TL```P```!>2P``$@```&M+```+
M````?DL```X```"*2P``'@```)E+```D````N$L```4```#=2P``!@```.-+
M```&````ZDL```H```#Q2P``#@```/Q+```(````"TP```D````43```%P``
M`!Y,```(````-DP```\````_3````P```$],```)````4TP``!$```!=3```
M%0```&],```,````A4P```X```"23```!0```*%,```%````ITP```<```"M
M3```#0```+5,```'````PTP``!$```#+3```%````-U,```0````\DP``"(`
M```#30``!@```"9-```+````+4T``!H````Y30``"P```%1-```.````8$T`
M``4```!O30``%0```'5-```"````BTT```D```".30``"P```)A-```T````
MI$T``!````#930``!P```.I-```3````\DT```\````&3@``$0```!9.```/
M````*$X``!,````X3@``$````$Q.```2````74X```T```!P3@``+P```'Y.
M```+````KDX```8```"Z3@``#````,%.```)````SDX```4```#83@``!0``
M`-Y.```%````Y$X```T```#J3@``#P```/A.```(````"$\```X````13P``
M"P```"!/```"````+$\``!,````O3P``"0```$-/```-````34\```<```!;
M3P``#````&-/```.````<$\```L```!_3P``#@```(M/```6````FD\``!4`
M``"Q3P``"````,=/```"````T$\```X```#33P``*@```.)/```'````#5``
M`!`````54```#0```"90```-````-%````<```!"4```!@```$I0```?````
M45````L```!Q4```%0```'U0```(````DU```#$```"<4```)@```,Y0```?
M````]5```",````540``+0```#E1```W````9U$``#<```"?40``+P```-=1
M```R````!U(``!,````Z4@``$````$Y2```&````7U(``!(```!F4@``$0``
M`'E2```;````BU(```H```"G4@``$@```+)2```5````Q5(``!4```#;4@``
M"````/%2```:````^E(``!(````54P``&P```"A3```,````1%,``#X```!1
M4P``"P```)!3```(````G%,```\```"E4P``$````+53```*````QE,```D`
M``#14P``$0```-M3```+````[5,```@```#Y4P``6`````)4```3````6U0`
M``L```!O5```/````'M4```)````N%0``!0```#"5```!P```-=4```(````
MWU0```T```#H5```$0```/94```>````"%4``!L````G50``&@```$-5```C
M````7E4``!,```""50``#0```)95```<````I%4``!8```#!50``"````-A5
M```R````X54``$,````45@``$0```%A6```5````:E8```8```"`5@``$@``
M`(=6```4````FE8```X```"O5@``&````+Y6```<````UU8``"$```#T5@``
M2P```!97```&````8E<```P```!I5P``&0```'97```'````D%<```D```"8
M5P``"````*)7```&````JU<``"P```"R5P``%0```-]7``!4````]5<``#L`
M``!*6```/````(98```X````PU@``#8```#\6```'@```#-9```=````4ED`
M`"<```!P60``'@```)A9```;````MUD``#,```#360``.0````=:``!$````
M05H``$````"&6@``)````,=:``!$````[%H``!T````Q6P``,@```$];```-
M````@EL``!\```"06P``'P```+!;```3````T%L```H```#D6P``"````.];
M```/````^%L```,````(7```)P````Q<```K````-%P```L```!@7```%0``
M`&Q<```(````@EP``!,```"+7```#P```)]<```*````KUP```D```"Z7```
M&@```,1<```8````WUP``!$```#X7```#P````I=```)````&ET``#`````D
M70``"P```%5=```,````85T``!````!N70``$````']=```,````D%T```X`
M``"=70```@```*Q=```*````KUT```(```"Z70``%P```+U=```A````U5T`
M`!0```#W70``&P````Q>```<````*%X``"(```!%7@``)````&A>```O````
MC5X``"<```"]7@``&@```.5>```H`````%\``!$````I7P``/@```#M?```Y
M````>E\``"<```"T7P``)P```-Q?```\````!&```!````!!8```&P```%)@
M```.````;F```!````!]8```%````(Y@```0````HV````(```"T8```!P``
M`+=@```#````OV```!4```##8```%@```-E@```%````\&````$````^`0``
M`````$H!``#W`````````'`````Y`0``!@```"(!```]`0```````"<!``"A
M`````````-P```#>````$````+`````)`0````$```,!``"8````7P$`````
M``!F`````````*````!I````=@``````````````@0```#$!```K````!P``
M```````7````*`$``$P!````````MP```%\```#O````BP````\!```O`0``
M80`````````[`0``V@```(X````>`0``"@$``$X!``````````````T```#?
M```````````````````````````````&`0``*0$```````!=`0``&@```)\`
M``!0`0``X@```$0````J````6P$``&0!```]````#0$``$`````P`0``````
M`,L```!D````E@```.,````Q````S0```#\!``#!````40$``$$!``#(````
M/```````````````4P```%L`````````H@```",```#)````````````````
M````8P```),```!)`0``$P```'4````>`````````+(```!^````'P```&H`
M```A````<P```%X`````````$P$```````````````````````"Z````'0$`
M`#4!``",`````````#0!``#&````O@```$H```#M`````````*P`````````
M`````&,!````````>````$4`````````D@```/(```!\````G````"P```":
M````M@```$4!```=````0`$``/L`````````Z````&````!_````````````
M``"H````P``````````9`````````$T!``"C````O````&8!``#7````2P$`
M`+0````$````60```"H!``"E````1`$``,(```!8`````````)D```!4````
M30```"0!``"$````2P````````!:`0``G@```*H````;````!0$``"L!``!R
M`````````#@```!#`0``,P````P!````````]0```",!``#,`````````#(!
M```)````D````$@``````````````%<!``#.````7`$``#<```")````-@``
M`!H!```E`0``M0```&$!````````!`$``#0````8`0```````#L```!L````
M`````````````````````!$!```6````+@```````````````````#H!``!Y
M````;0````````#G````"P$``#8!```D````K@```#H````L`0``PP```"(`
M````````/P````P````M````4`````````#D````00```%8```#=````5`$`
M`%(```!<````N````$(!``"&`````````-$````P`````````!\!``#6````
M(`$``#4```"F````LP```%D!``!Q````#P```#X```!(`0``V0```&4!```%
M````SP```((````#`````````&4````(````:0$``%4!``"%`````````!0!
M``#P````40```*T```"4````\P```````````````````!4```![````U0``
M````````````(0$``'0```````````````````#$````3@```(,````6`0``
M4@$``!P!```N`0``8@```)L`````````)P````````#J````JP````````!6
M`0``T@```.$````(`0``EP```&\```#K````E0````(```"[````V````*D`
M```"`0```````+T```#Q````B`````````#V``````````X!```7`0``CP``
M`!P```#Z````+0$`````````````1P```%@!````````(`````````"O````
M8@$```````#\````Q0`````````I````8`$``!4!```R````@`````````!H
M`0``7@$``!D!``!/`0````````L`````````Y@```-````!5`````````$8!
M``"Y````0@```/X`````````!P$``#<!``!H````)@$`````````````L0``
M`&<```!J`0```````)$```#]````#@````````!]````*````'H`````````
M``````````!K``````````````````````````````!3`0```````$,```#Y
M``````````````"'````Z0````````#'`````````$P`````````[@```&<!
M```;`0``_P```*0```!&````=P```+\```"G````+P```/0`````````````
M``````!7````$0````$!```\`0``1P$``(H`````````C0`````````2````
M```````````*````3P`````````8````````````````````VP```,H````Y
M````%`````````!N````[````/@```!:````$@$```````#3````G0```"8`
M``!)````Y0```-0`````````$`$````````E````X````#,!```X`0``70``
M````````("`@("`@5&\Z(``@("`@1&%T93H@`"`@("!&<F]M.B``(%-U8FIE
M8W0Z(``@:6X@`",`)60@=&\@)60@;V8@)60@365S<V%G97,`)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!A;')E861Y(&5X
M:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA;65D+@`E<R!F;VQD
M97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+@`E
M<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"D`*$%P<&QY('1H97-E(&-H86YG
M97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*0`H1&ES8V%R9"!A;&P@8VAA
M;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI`"A2971U
M<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C
M:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT
M('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`R
M-"!H;W5R<P!!32]030!!9&0@<&%I<@!!9&1R97-S`$%D9')E<W,@0F]O:P!!
M;&EA<P!!;&P`06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R
M*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z`$%L
M;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@
M9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@<V5N
M="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B
M92!D96QE=&5D+@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M<W=E<F5D`$%N<W=E<F5D(&UE<W-A9V5S`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.
M14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@96UP='D@=&AI<R!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\`07)R:79A;"!4:6UE
M`$%S8V5N9&EN9P!!='1A8V@`071T86-H;65N=`!!='1A8VAM96YT<P!!=F%I
M;&%B;&4@9FEE;&1S.@!"86-K('1O("5S`$)C8P!":7)T:&1A>0!";&%C:VQI
M<W0`0F]D>0!";W1H`$-A;F-E;`!#86YC96P@365S<V%G90!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M
M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RX`0V,`0V5L;"!0:&]N90!#
M:&%N9V4`0VAA;F=E($%L;`!#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@
M87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD
M(&AO=R!M97-S86=E<R!A<F4@<V]R=&5D+@!#:&%N9V4@=&AE(&YA;64L(&%D
M9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&5C:R!&;VQD97(H
M<RD@9F]R($YE=R!-86EL`$-H;V]S92!!8W1I;VXZ`$-L;W-E(%=I;F1O=P!#
M;&]S960@1F]L9&5R`$-O;&QA<'-E($%L;`!#;VQL87!S92!!;&P@1F]L9&5R
M<P!#;VQL87!S92!&;VQD97(`0V]M<&%N>0!#;VYT<F]L('=H96X@;F5W(&UA
M:6P@=VEL;"!B92!C:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O
M(&YO=&EF>2!Y;W4@=VAE;B!I="!A<G)I=F5S+@!#;W!Y`$-O<G)E8W0`0V]R
M<F5C=&5D(%1E>'0`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,`0W)E871E`$-R96%T92!&;VQD97(`0W)E871E(&$@;F5W(&1R
M869T<R!F;VQD97(`0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(`0W)E
M871E(&$@;F5W('1R87-H(&9O;&1E<@!#<F5A=&4@9FEL=&5R:6YG(')U;&5S
M('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O
M(&9O;&1E<G,L(&%N9"!D96QE=&4@<W!A;2X`0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!$1`!$86EL>0!$871E`$1E9F%U;'0@
M261E;G1I='D`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O
M<G1I;F<@9&ER96-T:6]N.@!$96QE=&4`1&5L971E($9O;&1E<BAS*0!$96QE
M=&5D`$1E;&5T960@;65S<V%G97,`1&5L971I;F<@86YD($UO=FEN9R!-97-S
M86=E<P!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I;2!S
M:6=N871U<F5S/P!$:7-P;&%Y`$1I<W!L87D@3W!T:6]N<P!$;R!.;W0@0VAE
M8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@
M9F]L9&5R/P!$;VYE`$1O=VYL;V%D($9O;&1E<BAS*0!$<F%F=`!$<F%F=',@
M9F]L9&5R.@!%9&ET`$5D:70@>6]U<B!F:6QT97(@<G5L97,`16UA:6P`16UA
M:6P@061D<F5S<P!%;7!T>2!&;VQD97(H<RD`16UP='D@5')A<V@@9F]L9&5R
M`$5M<'1Y(')E<W5L="X`16YD(&9O<G=A<F1E9"!M97-S86=E`$5N=&5R('1H
M92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N
M86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N
M86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(`17)R;W(`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>'!A;F0@06QL`$5X<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@
M1F]L9&5R`$5X<&%N9"!.86UE<P!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&
M:6QT97)S`$9I;F0`1FER<W0@4&%G90!&;VQD97(@3F%V:6=A=&]R`$9O<G=A
M<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&<F]M`$9R
M;VT@061D<F5S<P!&=V0Z`$AE;'``2&ED92!$96QE=&5D`$AI9&4@56YS=6)S
M8W)I8F5D`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$E.0D]8`$EG
M;F]R90!)9VYO<F4@06QL`$EM<&]R=&%N=`!);7!O<G1A;G0@;65S<V%G97,`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YC;'5D92!O
M<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_`$QA;F=U86=E`$QA<W0@4&%G
M90!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@:6X@=&\@)7,`3&]G(&]U
M=`!,;V=I;B!487-K<P!-30!-86EL8F]X`$UA<FL@87,Z`$UA<FL@9&EF9F5R
M96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`
M36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`365S<V%G92!#;VUP;W-I=&EO;@!-
M97-S86=E($1A=&4`365S<V%G92!396%R8V@`365S<V%G92!3:7IE`$UE<W-A
M9V4@4V]U<F-E`$UE<W-A9V4@5FEE=VEN9P!-97-S86=E(&9L86=S`$UE<W-A
M9V4@9F]L9&5R<P!-97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V
M:65W+@!-97-S86=E<R!T;P!-;V1I9GD`36]N=&AL>0!-;W9E`$YA;64`3F5V
M97(`3F5W`$YE=R!-86EL`$YE=R!M97-S86=E<P!.97AT`$YE>'0@365S<V%G
M90!.97AT(%!A9V4`3F\`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!S
M<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S=&EO;G,`3F]N90!.;W0@1&5L971E
M9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&1E
M;&5T960@;65S<V%G97,`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.;W1E<P!/
M2P!/;&0@;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U
M<F=E9"X`3W!T:6]N<P!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS
M`%!A9V4@)60@;V8@)60`4&%R="AS*0!087-S=V]R9`!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R<V]N86P`4&5R<V]N86P@26YF;W)M871I
M;VX`4&AO;F4`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@
M86YD(&9O<G=A<F1S/P!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE
M=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E<V]L=F4@
M86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+@!0;&5A<V4@<V5L96-T
M(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RX`4&QE
M87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"X`4&QE
M87-E('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N
M+@!0<F5V:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')I;G0`4')O8FQE
M;2!$97-C<FEP=&EO;@!0=7)G92!$96QE=&5D`%!U<F=E(%1R87-H(&AO=R!O
M9G1E;CH`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I<F5C="!T:&ES
M(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2969R97-H`%)E9G)E<V@@
M1F]L9&5R(%9I97=S.@!296QO860@5FEE=P!296UE;6)E<B!T:&4@;&%S="!V
M:65W`%)E;6]V92!P86ER`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;&%C92!W:71H.@!2
M97!L>0!297!L>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2U4;SH@`%)E
M<&QY.@!297!O<G0@87,@4W!A;0!297-E=`!297-U;64`4F5T=7)N('1O('1H
M92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@
M8V]P>6EN9R!A(&UE<W-A9V4_`%-A=F4@1')A9G0`4V%V92!A<P!3879I;F<@
M=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@)7,`4V5A<F-H`%-E87)C:"!297-U;'1S`%-E96X`4V5L96-T`%-E;&5C
M="!A;&P`4V5L96-T(&YO;F4`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA
M=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE;2!2
M97!O<G0`4V5N="!M86EL(&9O;&1E<CH`4V5R=F5R`%-E="!P<F5F97)E;F-E
M<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M
M97-S86=E<RX`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@
M869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W<@1&5L971E9`!3:&]W(%5N<W5B
M<V-R:6)E9`!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T
M97(@26YP=70`4W!E8VEA;"!#:&%R86-T97)S`%-P96QL($-H96-K`%-P96QL
M($-H96-K97(`4W!E;&P@8VAE8VL@8V]M<&QE=&4`4W!E;&QI;F<@97)R;W)S
M('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RX`4W5B:F5C=`!3=6)J
M96-T($9I96QD`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5C8V5S<P!3=6=G
M97-T:6]N<P!487-K<P!497AT`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B
M('=I;&P@8F4@<F5N86UE9"!T;R`B)7,B+@!4:&4@9F]L9&5R("(E<R(@86QR
M96%D>2!E>&ES=',`5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL;&5G86P@
M8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E('!R;V)L96US
M+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!F
M;VQD97(@(B5S(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C
M<FEB960@=&\@:70N`%1H92!F;VQD97(@(B5S(B!W87,@9&5L971E9"!B=70@
M>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@9F]L9&5R
M("(E<R(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&1E;&5T960N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!S
M=6-C97-S9G5L;'D@8W)E871E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@9&5L971E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S
M9G5L;'D@<F5N86UE9"!T;R`B)7,B+@!4:&4@<VEG;F%T=7)E('=A<R!S=6-C
M97-S9G5L;'D@<F5P;&%C960N`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T
M:&ES(&UA:6QB;W@N`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A('!R
M;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S
M86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G
M97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E
M<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S86=E
M.B`E<P!4:&ES(&UA>2!T86ME('-O;64@=&EM92X@07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(&-O;G1I;G5E/P!4:&ES(&UE<W-A9V4@=&\`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BX`5&AR96%D(%9I97<`5&ET;&4`5&\`5')A<V@@9F]L9&5R.@!5
M4DP`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA;G-W97)E9`!5;F%N
M<W=E<F5D(&UE<W-A9V5S`%5N9&5L971E`%5N9&ES8VQO<V5D(%)E8VEP:65N
M=',`56YD;R!#:&%N9V5S`%5N;F%M960`56YS965N`%5N<W5B<V-R:6)E(&9R
M;VT@1F]L9&5R*',I`%5S92!$969A=6QT(%9A;'5E`%5S97(@3W!T:6]N<P!5
M<V5R;F%M90!6:65W("5S`%9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN.@!787)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`
M66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@`%EO=2!A<F4@8W)E
M871I;F<@82!T;W`M;&5V96P@9F]L9&5R+@!9;W4@87)E(')E;F%M:6YG('1H
M92!F;VQD97(Z(`!9;W4@:&%V92`E<R!N97<@;65S<V%G97,N`%EO=2!H879E
M(#$@;F5W(&UE<W-A9V4N`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R.@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W
M:6YG(&9O;&1E<G,Z`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S
M="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="X`66]U(&UU<W0@<V5L
M96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A="!L96%S
M="!O;F4@;65S<V%G92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP
M:65N="X`66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@(B5S(BX@2&5R92!I
M<R!W:&%T('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!N;W0@=6YS=6)S8W)I
M8F5D(&9R;VT@(B5S(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9
M;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R`B)7,B`%EO=2!W
M97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2`B)7,B`%EO=7(@
M)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9
M;W5R($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!S:6=N871U<F4Z`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O
M<G1=`%ML:6YE("5S(&]F("5S70!F<F]M`&YO;F4`;W(`<W!E;&QI;F<@97)R
M;W(`<W!E;&QI;F<@97)R;W)S`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@
M24U0(#,N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P
M"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,3$M,C@@,3@Z,3`K,#(P,`I,87-T
M+51R86YS;&%T;W(Z($MA<W!A<G,@2V%P96YI96MS(#QK87-P87)S0')C8RYL
M=CX*3&%N9W5A9V4M5&5A;3H@3&%T=FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO
M<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U#4#$R-3<*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M."UB:70*`%-A\N=MYVIS.B``("!$871U;7,Z(`!3^W3N=.)J<SH@`"`@5&5M
M871S.B``("T@`",`)60@;.YD>B`E9"!N;R`E9"!VYW-T=6SG;0`E<R!5>G1U
M<N?P86YA<R!O<&5RXF-I:F%S("T@87!S=&EP<FENXFIU;7,`)7,@:F%U(&5K
M<VES=.<N($UA<&D@)7,@<.)R<V%U:W0@;F5I>F1E=N)S+@!-87!E("5S('1I
M96L@<.)R<V%U:W1A(&WG;F7P82!SXFMU;>(N`"5S.B`E<R`H)60F;F)S<#MN
M;R9N8G-P.R5D*0`H4V%G;&%BXG0@\.YS(&EZ;6%I\F%S('5N('#B<G9I971O
M=&EE<R!U>B!NXFMA;6\@96MRXFYU+BD`*$%T8V5L="!V:7-A<R!I>FUA:?)A
M<R!U;B!A=&=R:65Z=&EE<R!P:64@=N=S='5L97,@<F5D:>SG\&%N87,N*0`H
M071G<FEE>G1I97,@<&EE(';G<W1U;&5S(')E9&GLY_!A;F%S('#G8R!I>FUA
M:?)U('-A9VQA8N+P86YA<RX@(-!A:N(@96MRXF[B('9E:6MTXG,@:7IM86GR
M87,@3D5424M3('-A9VQA8N)T87,N*0`J(%!I979I96YO="#P;W,@;F]S<&EE
M_F]T($]+("H`*B!,^V1Z=2!I>G;G;&EE=&EE<R!A9')E<VDH+65S*2`J`#(T
M('-T=6YD87,`04TO4$T`4&EE=FEE;F]T('#B<FD`061R97-E`$MO;G1A:W1I
M`$%I>G-TXFIVXG)D<P!6:7-I`%9I<V%S(';G<W1U;&5S(&YO('-E:V]J;_!A
M:N)M(&UA<.=M('1I:W,@:65LXF3G=&%S('9I96[B($U"3U@@9F%I;.(Z`%9I
M<V%S(';G<W1U;&5S(&K[<W4@(B5S(B!M87#G+"!K87,@:7(@=F5CXFMA<R!P
M87(@)7,@9&EE;N)M('1I:W,@;F5A=&=R:65Z96YI<VMI(&EZ9'KG<W1A<RX`
M5FES87,@;F]S^W3N=&\@<&%S='4@;6%P97,L(&MA<R!I<B!V96/B:V%S('!A
M<B`E<R!MYVYE\&EE;2!T:6MS(&EZ9'KG<W1A<RX`3F]RXF3N=&$@;F5D97+N
M9V$@=N=R=.YB80!!=&)I;&3G=',`071B:6QDYW3B<R!VYW-T=6QE<P!686D@
M:OMS(&5S870@<.)R;&EE8VENXG1S+"!K82!VYVQA=&EE<R!T;R!D87+N=#\`
M5F%I(&K[<R!E<V%T('#B<FQI96-I;N)T<RP@:V$@=N=L871I97,@3D5!5$=2
M245:14Y)4TM)(&EZ9'KG<W0@\.YS(';G<W1U;&5S/P!686D@:OMS('1I9?#B
M;2!VYVQA=&EE<R!I>G1U:_!O="#P;R!M87!I/P!686D@:OMS('1I9?#B;2!V
MYVQA=&EE<R!I>G1U:_!O="!A=&MR:71U;74@;6%P:3\`4V'R96WP86YA<R!L
M86EK<P!!=6=O\&D`4&EE=FEE;F]T`%!I96QI:W5M<P!0:65L:6MU;6D`4&EE
M96IA;6EE(&QA=6MI.@!!='!A:V'O('5Z("5S`$)C8P!$>FEM\&%N87,@9&EE
M;F$`365L;F%I<R!S87)A:W-T<P#-97)M96YI<P!!8FD`071C96QT`$%T8V5L
M="!VYW-T=6QI`$%T8V5L="!P<F]B;.=M87,@<&EE=&5I:W5M=0!!=&-E[V]T
M(';G<W1U;&DL('1I:W,@;F5A=&=R:65Z96YI<VMI(&EZ9'KG<W1S('3B<R!S
M871U<G,N`$-C`$UO8FEL86ES('3B;')U;FES`$UA:6[N=`!)>FUA:6[N="!V
M:7-U<P!)>FUA:6[N="!E:W+B;F$@<&%R86UE=')U<RP@<&EE;>=R86TL(';G
M<W1U[W4@<VMA:71U(&MA='+B(&QA<.(@=6X@:^(@=N=S='5L97,@=&EK<R!K
MXG)T;W1A<RX`27IM86EN[G0@=N)R9'4L(&%D<F5S:2!U;B!P87)A:W-T=2P@
M:V%S(&+[<R!R961Z86UI(';G<W1U[W4@<V'RYVWG:FEE;2X`4.)R8F%U9.YT
M(&UA<.<H<RD@:F%U;F\@<&%S='4`27IVYVQI971I97,@9&%R8NYB=3H`06EZ
M=N=R="!L;V=U`$UA<&4@86EZ=N=R=&$`06EZ=N=R="!V:7-U`$%I>G;G<G0@
M=FES87,@;6%P97,`06EZ=N=R="!M87!I`%5Z\N=M=6US`$EE<W3B9.YT+"!K
M860@<.)R8F%U9.YT('!A<W1U('5N(&)R[F1I;N)T('!A<B!J875N82!P87-T
M82!P:65NXFOP86YU+@!+;W#G=`!087)E:7II`$EZ;&%B;W1S('1E:W-T<P!.
M96EZ9&5VXG,@871VYW)T($UA:6YT96YA;F-E7U1A<VL@;6]D=6QI("5S`$EZ
M=F5I9&]T`$EZ=F5I9&]T(&UA<&D`27IV96ED;W0@:F%U;G4@;6%P:2!M96QN
M<F%K<W1I96T`27IV96ED;W0@:F%U;G4@;6%P:2!N;W/[=.YT86KB;2!VYW-T
M=6SG;0!)>G9E:61O="!J875N=2!M87!I(&%T:W)I='5M:65M`$EZ=F5I9&]T
M(&9I;'1RY_!A;F%S(&QI:W5M=7,@:65NXFMO\.(@<&%S=&$@;W)G86YI>N?P
M86YA:2X@2^)R=&_P86YA('!A(&UA<.=M('5N(&1ZY_!A;F$N`%!I96SB9V]T
M('5Z9&5V=6UU<RP@:V%S('1I96L@=F5I:W1I('!I97-LYV1Z;W1I97,@)7,N
M`$1$`$EK9&EE;F%S`$1A='5M<P!087)A<W3B(&ED96YT:73B=&4`3F]K;'5S
MYW1I92!KXG)T;_!A;F%S(&YO<V%C[FIU;6DZ`$YO:VQU<^=T86ES(&OB<G1O
M\&%N87,@=FER>FEE;G,Z`$1ZYW-T`$1ZYW-T(&UA<&DH+65S*0!)>F1ZYW-T
M<P!)>F1ZYW-TXG,@=N=S='5L97,`1'KG<W0@=6X@<.)R=FEE=&]T(';G<W1U
M;&5S`$1I;'-T;_!I`$%P<F%K<W1I970@<')O8FSG;74`4^YKXFMA(&EN9F]R
M;>)C:6IA(&ER(&YO<_MT[G1A(&%D;6EN:7-T<F%T;W)A;2X`36%TYW0@<&%R
M86MS='5S/P!087+B9.YT`$5K<N)N82!I97-T873N:G5M:0!.97#B<F)A=63N
M="!J875N;R!P87-T=2!M87#G<P!.878@=&EE\&%S('!I965J87,@;6%I;G1E
M;F%N8V4N<&AP`%9A:2!J^W,@=N=L871I97,@871VYW)T(/!O(&UA<&D_`$EZ
M<&EL9.YT<P!)96SB9.=T(&UA<&DH+65S*0!-96QN<F%K<W1S`$UE;&YR86MS
M='4@;6%P93H`4F5D:>SG=`!2961I[.=T(&9I;'1RY_!A;F%S(&QI:W5M=7,`
M12UP87-T<P!%+7!A<W1A(&%D<F5S90!)>G1U:_!O="!M87!I*"UE<RD`27IT
M=6OP;W0@871K<FET=6UU(&UA<&D`5'5K\',@<F5Z=6QTXG1S+@!0XG)S^W3N
M=.)S(';G<W1U;&5S(&)E:6=A<P!)979A9&EE="!J875NXG,@;65L;G)A:W-T
M=2!M87!E<R!N;W-A=6MU;74`265V861I970@:N)U;N)S(&YO<_MT[G1O('!A
M<W1U(&UA<&5S(&YO<V%U:W5M=0!)979A9&EE="!J875NXG,@871K<FET=6UU
M(&UA<&5S(&YO<V%U:W5M=0!+[_MD80!+871R87,@,34@;6EN^W1E<P!+871R
M87,@,S`@<V5K=6YD97,`2V%T<F%S(#4@;6EN^W1E<P!+871RXB!P:65S;.=G
M\&%NXG,@<F5I>N<`2V%T<G4@<'5S<W1U;F1U`$MA=')U(&UI;OMT:0!087)A
M=6=VYW)T[F)A<P!!=';G<G0@=FES=7,`071VYW)T('9I<V%S(&UA<&5S`$%T
M=N=R="!M87!I`%!A<N)D[G0@=N)R9'5S`$YE:7ID97;B<R!S8?)E;70@:65S
M=&%T[FIU;75S+@!.96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I
M;2X`1F%K<W,`1FEL=')I`$UE:VSG=`!0:7)MXB!L87!A`$UA<&IU(&-E[W9E
M9&ES`%#B<G/[=.YT`%#B<G/[=.YT.@!0XG)S^W3N=&$@=N=S='5L92!N;R`E
M<P!3^W3N=.)J<P!3^W3N=.)J82!A9')E<V4`1G<Z`%!A;.YD>NYB80!087-L
MYW!T(&EZ9'KG<W1O<P!087-LYW!T(&YE<&%R86MS=.YT;W,`3>)J87,@861R
M97-E`$WB:F%S('1E;&5F;VYS`$AO<F1E`$E.0D]8`$EG;F]RYW0`26=N;W+G
M="!V:7-U<P!3=F%R[F=I`%-V87+N9V%S(';G<W1U;&5S`$EE;.)DYW1A:7,@
M;&%U:W,Z("5S`$EE;.)DYW1I92!L875K:3H`265K[V%U="!SXFMO=&[G:F\@
M=N=S='5L:2!A=&)I;&3G/P!686QO9&$`4.=DYVIA(&QA<&$`4&%RXF3N="!P
M86SN9'KN8F%S('1E;6%T=7,`4&EE<VSG9W1I97,`4&EE<VSG9W1I97,@)7,`
M27II970`4&EE<VSG9_!A;N)S('5Z9&5V=6UI`$U-`%!A<W1K87-T90!!='KN
M;>=T(&OB.@!!='KN;>=T(&1A_N)D=7,@8VETY_!A;F%S(&SN;67R=7,@873P
M[6ER[F?B<R!K<N)SXG,_`%-A<VMA;F_P:64@;&%U:VD`5N=S='5L90!6YW-T
M=6QE<R!R86MS=.[P86YA`%;G<W1U;&5S(&1A='5M<P!6YW-T=>]U(&UE:VSG
M\&%N80!6YW-T=6QE<R!I>FWG<G,`5N=S='5L97,@<&ER;71E:W-T<P!6YW-T
M=6QE<R!A<'-K871E`%;G<W1U;&5S(&MA<F]D>FGR:0!6YW-T=>]U(&UA<&5S
M`%;G<W1U[W4@<VMA:71S('9I96[B(&QA<.(@<&%S=&MA<W1E<R!S:V%T[FIU
M;>(N`%;G<W1U;&5S('5Z`$UA:6[N=`!+871R=2!MYVYE<VD`4.)R=FEE=&]T
M`%;B<F1S`$YE:V%D`$IA=6YS`$IA=6YA(';G<W1U;&4`2F%U;F%S(';G<W1U
M;&5S`$[B:V%M86ES`$[B:V%MXB!VYW-T=6QE`$[B:V%MXB!L87!A`$[G`$YA
M=B!N;W+B9.YT87,@;6%P97,`2^_[9'4@;F%V`$EE=&5I:W5M=2!N878`3F5V
M:65N<P!.878@:7ID>N=S=',`3F%V(&UE;&YR86MS=',`3F%V('-V87+N9W,`
M3F%V('!E<G-O;FES:W,`3F%V(&EZ9'KG<W1A<R!VYW-T=6QE<P!.878@<W9A
M<NYG87,@=N=S='5L97,`4&EE>NYM97,`3TL`5F5CXG,@=N=S='5L97,`5&EE
M:R!T[G+N=&%S('9E8^)S(&YO<_MT[G1O(';G<W1U[W4@;6%P97,N`$]P8VEJ
M87,`0VET82!I;F9O<FWB8VEJ80!#:71A<R!O<&-I:F%S`$QA<&$@)60@;F\@
M)60`1&'O82AS*0!087)O;&4`27IP:6QD[G0@=7IT=7+G\&%N87,@;W!E<N)C
M:6IA<P!097)S;V[N9V%I<P!097)S;V[N9^(@:6YF;W)MXF-I:F$`5.)L<G5N
M:7,`265V:65T;W0@<&%R86MS='4@<&ER;7,@871B:6QDYVT@=6X@<.)R<_MT
M[O!A;N)M/P!,^V1Z=2!I979A9&EE="!J875NXG,@;6%P97,@;F]S875K=6UU
M.@!,^V1Z=2!I979A9&EE="!J875N;R!N;W-A=6MU;74Z`$S[9'IU(&YO<N)D
M:65T('!R;V)LYVUA<R!A;F]TXF-I:G4N`$S[9'IU(&YO<N)D:65T('-A=G4@
M;&EE=&]TXFIA(';B<F1U('5N('!A<F]L:0!,^V1Z=2!I>FQA8F]J:65T(&YE
M=FEE;FYO>NYM[F=A<R!V86D@;F5D97+N9V%S(&%D<F5S97,N`$S[9'IU(&EZ
M=N=L:65T:65S(&OB9'4@;6%P:2!P:7)M<R!V96EK="!D87)B[F)A<R!A<B!T
M;RX`3/MD>G4@:7IVYVQI971I97,@;65K;.?P86YA:2!V:7-M87H@=FEE;G4@
M;6%P:2X`3/MD>G4@:7IVYVQI971I97,@=&EK86D@=FEE;G4@;6%P:2#P86D@
M;W!E<N)C:6IA:2X`265P<FEE:_#G:N(@=N=S='5L90!)97!R:65K\.=JXB!L
M87!A`$1R=6OB=`!0<F]B;.=M87,@87!R86MS=',`27IT[G+N="!I>F1ZYW-T
M;W,`0VEK(&)I9?YI('3N<NYT(&%T:W)I='5M=7,Z`%#B<F%D<F5SYW0`4.)R
M861R97/G="!VYW-T=6QI`%#B<F%D<F5SYW0@\&\@=N=S='5L:0!0XG)A9')E
M<^=T(&YE:7ID97;B<RX`071J875N;W0`071J875N;W0@;6%P:G4@<VMA=.YJ
M=6UU<SH`4.)R;.)DYW0@<VMA=.YJ=6UU`$%T8V5RYW1I97,@<.=DYVIO('-K
M873N:G5M=0!)>F1ZYW-T('#B<FD`3F5I>F1E=N)S('#B<G-A=6MT(&YO("(E
M<R(@=7H@(B5S(BX@T.)D82!B:6IA('-E<G9E<F$@871B:6QD92X`06EZ<W3B
M="!A<CH`071B:6QDYW0`071B:6QDYW0@=FES:65M`$%T8FEL9.=T('9I<VEE
M;3H`4F5P;'DM5&\Z(`!!=&)I;&3G=#H`4&EE=&5I:W0@:^(@<W!A;74`1'KG
M<W0@=FES=7,`5'5R<&ENXG0`071G<FEE>G1I97,@<&EE(';G<W1U[W4@<V%R
M86MS=&$@<.=C(';G<W1U;&5S(&EZ9'KG\&%N87,L('#B<G9I971O\&%N87,@
M=F%I(&YO:V]PY_!A;F%S/P!386=L86+B="!M96QN<F%K<W1U`%-A9VQA8N)T
M(&OB`$YE:7ID97;B<R!S86=L86+B="!M96QN<F%K<W1U+B#0XF1A(&)I:F$@
M<V5R=F5R82!A=&)I;&1E.B`E<P!-96MLY_!A;F$`365K;.?P86YA<R!R97IU
M;'3B=&D`4F5D>N=T<P!)>G;G;&EE<P!)97KN;>=T('9I<W5S`$YE:7IVYVSG
M=&EE<R!N96MO`$EZ=N=L:65T:65S(&1A='5M82!A=&1A;.YTXFIU.@!)>G;G
M;&EE=&EE<R!D871U;6$@9F]R;>)T=3H`27IVYVQI971I97,@;&%I:V$@9F]R
M;>)T=3H`27IVYVQI971I97,@9&EV=7,@<V%D97+N9W5S(&QA=6MU<RX`27IV
MYVQI971I97,@=F%L;V1U.@!3^W3N="!VYW-T=6QI`$YO<_MT[G0@<')O8FSG
M;6%S('!I971E:6MU;74`3F]S^W3N=&\@=N=S='7O=2!M87!E.@!397)V97)I
M<P!)97-TXF3N="!K;R!D87+N="!K860@:7ID>N?P('9A:2!PXG)V:65T;R!V
MYW-T=6QI+@!686D@=N=S='5L97,@<F5D:>SG\&%N87,@;&]G<R!JXF%I>G9E
M<B!PYV,@;65L;G)A:W-T82!S86=L86+B\&%N87,_`%!A<N)D[G0@:7ID>N=S
M=&]S`%!A<N)D[G0@;F5P87)A:W-T[G1O<P!)>FWG<G,`27IL86ES="!U>G1U
M<N?P86YU`,YP8?!O('-I;6)O;'4@:65V861E`,YP8?!I92!S:6UB;VQI`%!A
M<F5I>G)A:W-T[F)A<R!PXG)B875D90!087)E:7IR86MS=.YB87,@<.)R8F%U
M9.YTXFIS`%!A<F5I>G)A:W-T[F)A<R!PXG)B875D92!P86)E:6=T80!087)E
M:7IR86MS=.YB87,@:^_[9'4@<VMA:71S('9I96[B(&5K<N)NXBP@=F5I8V]T
M('!A<F5I>G)A:W-T[F)A<R!PXG)B875D:2X`5&5M871S`%1E;6%T82!L875K
M<P!087)A:W-T[G1I97,@=7H@;6%P:2@MYVTI`%9E:6MS;64`265T96EK=6UI
M`%5Z9&5V=6UI`%1E:W-T<P!496MO\.(@;6%P92AS*2`B)7,B('1I:W,@<.)R
M<V%U:W1A('!A<B`B)7,B+@!-87!E("(E<R(@:F%U(&5K<VES=.<`36%P97,@
M(B5S(B!N;W-A=6MU;7,@<V%T=7(@;F5A=.]A=71U<R!S:6UB;VQU<RX@3/MD
M>G4@<V%Z:6YI971I97,@87(@861M:6YI<W1R871O<G4N`$UA<&4@(B5S(B!T
M:6MA(&EZ=F5I9&]T82!B970@:OMS('5Z('1O(&YE97-A="!P87)A:W-T[FII
M97,N`$UA<&4@(B5S(B!T:6MA(&EZ9'KG<W1A+"!B970@:OMS(&YE97-A="!N
M;R!TXG,@871R86MS=.YJ:65S+@!-87!I("(E<R(@;F5I>F1E=N)S(&EZ=F5I
M9&]T+B!397)V97)A(&%T8FEL9&4@8FEJ82#PXF1A+@!-87!I("(E<R(@;F5I
M>F1E=N)S(&EZ9'KG<W0N(%-E<G9E<F$@871B:6QD92!B:6KB(/#B9&$`36%P
M92`B)7,B('9E:6MS;>YG:2!I>G9E:61O=&$N`$UA<&4@(B5S(B!V96EK<VWN
M9VD@:7ID>N=S=&$N`$UA<&4@(B5S(B!V96EK<VWN9VD@<.)R<V%U:W1A('!A
M<B`B)7,B+@!087)A:W-T<R!V96EK<VWN9VD@86EZ=FEE=&]T<RX`T&%JXB!P
M87-T:V%S=.<@;F%V(';G<W1U[W4N`%)A9.)S('!R;V)LYVUA(&1ZY_!O="`E
M<RX@T.)D82!B:6IA('-E<G9E<F$@871B:6QD90!2863B<R!P<F]B;.=M82!T
M[G)O="!P87-T:V%S=&DN(-#B9&$@8FEJ82!S97)V97)A(&%T8FEL9&4`4F%D
MXG,@:^_[9&$@9'KG\&]T(';G<W1U;&5S(&YO(&UA<&5S("(E<R(N(-#B9&$@
M8FEJ82!S97)V97)A(&%T8FEL9&4`4F%DXG,@:^_[9&$@9'KG\&]T(';G<W1U
M;&5S(&UA<.<@(B5S(BX@T.)D82!B:6IA('-E<G9E<F$@871B:6QD90!2863B
M<R!K[_MD82!P87+B9&]T(/!O(';G<W1U;&5S(&1A[W4`4F%DXG,@:^_[9&$@
M:V%R;V=O:F]T(';G<W1U;&5S(&UA<.<@(B5S(BX@T.)D82!B:6IA('-E<G9E
M<F$@871B:6QD92X`4F%DXG,@:^_[9&$@<_MT;W0@=N=S='5L:3H@)7,`5&%S
M('9A<B!P<F%S[G0@9&%U9'H@;&%I:V$N(%9A:2!VYVQA=&EE<R!T=7)P:6[B
M=#\`T&\@=N=S='5L:2!U>@#0:6T@<VMA:71L:6T@:7(@:N)B^W0@=FES;6%Z
M(#$N`-!A:2!VYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI;2X`4&%V961I96YU
M('-K873N:G5M<P!6:7)S<F%K<W1S`%-A\N=MYVIS`$%T:W)I='5M=2!M87!E
M.@!54DP`3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN
M`$YA=B!I97-PYVIA;7,@:6YT97)P<F5TYW0@\&\@5V]R9"!D;VMU;65N='4`
M3F5A=&)I;&3G=',`3F5A=&)I;&3G=.)S(';G<W1U;&5S`$%T:F%U;F]T`$YE
M871K;.)T:64@<V'RYVWG:FD`071C96QT(&EZ;6%I\F%S`$YE;F]S875K=',`
M3F5R961ZYW1S`$%T<F%K<W3N=.YE<R!N;R!M87!E<R@MYVTI`$QI971O="!N
M;VML=7/G=&\@=N=R=.YB=0!,:65T;W3B:F$@;W!C:6IA<P!,:65T;W3B:F$@
M=N)R9',`4VMA=.YT("5S`%-K871S('9A:2!P87-T:V%S=&4@:V\@<&%RXF3N
M="!PYV,@<&EE<VSG9_!A;N)S.@!"<NYD:6[B:G5M<P!+871R=2!N963G[W4`
M3&%I<&YI(&S[9'IA;2`E<P!,86EP;FD@;/MD>FTL("5S`$1A<F)A(&%D<F5S
M90!$87)B82!TXFQR=6YI<P!'1P!+871R=2!G861U`$KB`$K[<R!V96ED;VIA
M="!A<&%K\&UA<&D@`$K[<R!V96ED;VIA="!A=6?PYVKB(&SN;67R82!M87!I
M+@!*^W,@<.)R<V%U8V%T(&UA<&DZ(`!*=6US(&ER("5S(&IA=6YA<R!VYW-T
M=6QE<RX`2G5M<R!I<B!V:65N82!J875N82!VYW-T=6QE+@!*=6US(&ER(&IA
M=6YS('!A<W1S('-E:V]J;_#B(&UA<.<Z`$IU;7,@:7(@:F%U;G,@<&%S=',@
M<V5K;VIO\.)S(&UA<.=S.@!!<')A:W-T:65T('!R;V)LYVUU('!I<FUS('!I
M971E:6MU;6$@<_MT[O!A;F%S+@!*=6US('9I<W!I<FUS(&KB;F]RXF1A(&WG
M<NUA('!A<W1K87-T92X`5FES<&ER;7,@:N)I>G;G;&%S(&%D<F5S92X`5FES
M<&ER;7,@:N)I>G;G;&%S('9I<VUA>B!V:65N82!VYW-T=6QE+@!*XFYO<N)D
M82!S8?+G;>=J<P!.96EZ9&5VXG,@<&%R86MS=.YT:65S('5Z(&UA<&D@(B5S
M(BX@T.)D82!B:6IA('-E<G9E<F$@871B:6QD90!.96EZ9&5VXG,@871R86MS
M=.YT:65S(&YO("(E<R(N(-#B9&$@8FEJ82!S97)V97)A(&%T8FEL9&4`2OMS
M(&5S870@=F5I:W-M[F=I('!A<F%K<W3N:FEE<R!U>B`B)7,B`$K[<R!E<V%T
M('9E:6MS;>YG:2!A=')A:W-T[FII97,@;F\@(B5S(@!*^W-U("5S('-E<VEJ
M82!I<B!B96EG=7-I97,N($S[9'IU('!I97-LYV1Z:65T:65S(&%T:^)R=&]T
M:2X`2OMS=2!I;F9O<FWB8VEJ80!*^W-U(&]P8VEJ87,@:7(@<V%G;&%BXG1A
M<RX`2OMS=2!P87)A:W-T<SH`6T)E>B!V:7)S<F%K<W1A70!;4')O8FSG;6%S
M('II\F]J=6US70!;<FEN9&$@)7,@;F\@)7-=`&YO`&YE=FEE;G,`=F%I`'!A
M<F5I>G)A:W-T[F)A<R!K[_MD80!P87)E:7IR86MS=.YB87,@:^_[9&%S`'9#
M87)D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VYB7TY/+P``
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S8S`#`Q-S0T-``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM
M<"]L;V-A;&4O;F)?3D\O3$-?34534T%'15,O````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#(Q,C,Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]N8E].3R],0U]-15-304=%4R]I
M;7`N;6\````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W-#0U-P`Q,#0Q-S,V,C<V
M,P`P,C(S-S$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````#0`0``'````)P.``!K`@``'!T```````#()@``"@``
M`,DF```*````U"8```H```#?)@``"@```.HF```$````]28```$```#Z)@``
M%P```/PF```H````%"<``#(````])P``*0```'`G```R````FB<``!L```#-
M)P``+@```.DG```W````&"@``'P```!0*```'````,TH```=````ZB@```@`
M```(*0``!0```!$I```(````%RD```<````@*0``#````"@I```%````-2D`
M``,````[*0``3@```#\I``!0````CBD``$(```#?*0``(P```"(J```?````
M1BH```@```!F*@``$0```&\J```C````@2H``"$```"E*@``.P```,<J```K
M`````RL``#$````O*P``#````&$K```)````;BL```8```!X*P``"@```'\K
M```+````BBL``!$```"6*P``"P```*@K```*````M"L```,```"_*P``"```
M`,,K```)````S"L```0```#6*P``!````-LK```(````X"L```8```#I*P``
M#@```/`K```5````_RL``#X````5+````@```%0L```*````5RP```8```!B
M+```"@```&DL``!B````="P``%\```#7+```'````#<M```S````5"T```X`
M``"(+0``%0```)<M```S````K2T``!T```#A+0``!0```/\M```,````!2X`
M``T````2+@``#````"`N```4````+2X```\```!"+@``!P```%(N```F````
M6BX``%P```"!+@``!````-XN```'````XRX```X```#K+@``*0```/HN```&
M````)"\```T````K+P``&@```#DO```=````5"\``!D```!R+P``70```(PO
M```H````ZB\```(````3,```!0```!8P```%````'#````0````B,```$```
M`"<P```9````.#```!H```!2,```!@```&TP```0````=#```#,```"%,```
M!P```+DP```0````P3```!P```#2,```"@```.\P```4````^C```"\````/
M,0``#P```#\Q```'````3S$```\```!7,0``*````&<Q```,````D#$``",`
M``"=,0``)@```,$Q```@````Z#$```0````),@``$@````XR```%````(3(`
M``X````G,@``!````#8R```6````.S(```4```!2,@``#0```%@R```/````
M9C(``!(```!V,@``#0```(DR```5````ES(``"D```"M,@``+````-<R```H
M````!#,```4````M,P``$````#,S```0````1#,```\```!5,P``"P```&4S
M```/````<3,```P```"!,P``#P```(XS```*````GC,``!(```"I,P``#0``
M`+PS```,````RC,``#T```#7,P``'@```!4T```A````-#0```,```!6-```
M"@```%HT```E````930```<```"+-```!````),T```*````F#0```@```"C
M-```$````*PT```'````O30```@```#%-```&0```,XT```%````Z#0```0`
M``#N-```#````/,T```$`````#4```0````%-0``!P````HU```$````$C4`
M``P````7-0``$0```"0U```%````-C4```P````\-0``"@```$DU```%````
M5#4```4```!:-0``"@```&`U```/````:S4```8```![-0``"@```((U```)
M````C34``!(```"7-0``$@```*HU```0````O34```4```#.-0``)````-0U
M```'````^34```@````!-@``"0````HV```)````%#8```P````>-@``#0``
M`"LV```.````.38``!8```!(-@``$0```%\V```1````<38``!````"#-@``
M!@```)0V```,````FS8```<```"H-@``"P```+`V```"````O#8```<```"_
M-@``"````,<V```W````T#8``!$````(-P``#P```!HW```/````*C<``!<`
M```Z-P``)@```%(W```F````>3<```H```"@-P``!P```*LW```3````LS<`
M``P```#'-P``#@```-0W```,````XS<```X```#P-P``#P```/\W```-````
M#S@```\````=.```#P```"TX```F````/3@```L```!D.```!@```'`X```'
M````=S@```0```!_.```!````(0X```%````B3@```,```"/.```"@```),X
M```(````GC@```P```"G.```!````+0X```$````N3@```P```"^.```"0``
M`,LX```"````U3@``!D```#8.```$@```/(X```.````!3D```0````4.0``
M"P```!DY```)````)3D```T````O.0``#````#TY```4````2CD``!8```!?
M.0``!0```'8Y```\````?#D```(```"Y.0``#````+PY```C````R3D```<`
M``#M.0``"@```/4Y```1`````#H``!,````2.@``#0```"8Z```-````-#H`
M``<```!".@``"````$HZ```>````4SH``"@```!R.@``"````)LZ```4````
MI#H```4```"Y.@``,0```+\Z```G````\3H``"@````9.P``&@```$([```H
M````73L``"D```"&.P``+@```+`[```V````WSL``"P````6/```,0```$,\
M```0````=3P```T```"&/```!0```)0\```3````FCP```X```"N/```#0``
M`+T\```6````RSP``#X```#B/```'@```"$]```+````0#T```X```!,/0``
M#@```%L]```)````:CT```@```!T/0``$````'T]```5````CCT``!,```"D
M/0``!P```+@]```5````P#T```L```#6/0``%@```.(]```+````^3T``"X`
M```%/@``.@```#0^```-````;SX```4```!]/@``#````(,^```-````D#X`
M``T```">/@``"@```*P^```&````MSX```X```"^/@``%P```,T^```%````
MY3X```8```#K/@``2P```/(^```(````/C\``!````!'/P``"````%@_```*
M````83\``"````!L/P``.0```(T_```&````QS\```D```#./P``#@```-@_
M```$````YS\```8```#L/P``#@```/,_```*`````D````L````-0```&@``
M`!E````7````-$```!<```!,0```&P```&1````?````@$````P```"@0```
M$P```*U````1````P4````8```#30```0P```-I````Y````'D$``!````!8
M00``#````&E!```4````=D$``!$```"+00``(````)U!```%````OD$```0`
M``#$00``$````,E!```7````VD$``!(```#R00``"P````5"```-````$4(`
M`!0````?0@``+P```#1"```(````9$(```<```!M0@``#0```'5"```&````
M@T(``!8```"*0@``!P```*%"```+````J4(``!H```"U0@``(````-!"```%
M````\4(```4```#W0@``!````/U"```)`````D,``#,````,0P``'@```$!#
M``!U````7T,``#X```#50P``0@```!1$```]````5T0``#T```"51```*0``
M`--$```I````_40``#$````G10``*````%E%```F````@D4``#X```"I10``
M1P```.A%``!7````,$8``%4```"(1@``+P```-Y&``!5````#D<``"L```!D
M1P``+````)!'``!.````O4<``#L````,2```#P```$A(```A````6$@``!P`
M``!Z2```"P```)=(```%````HT@```(```"I2```#0```*Q(```#````ND@`
M`"````"^2```)@```-](```*````!DD``!,````120``"````"5)```6````
M+DD```P```!%20``!P```%))```&````6DD``!H```!A20``$0```'Q)```>
M````CDD```P```"M20``"````+I)```'````PTD``"<```#+20``#P```/-)
M```4`````TH```<````82@``!@```"!*```-````)TH```L````U2@``6@``
M`$%*```)````G$H```P```"F2@``"@```+-*```"````ODH```8```#!2@``
M`P```,A*```G````S$H``"$```#T2@``)````!9+```=````.TL``$(```!9
M2P``&0```)Q+```7````MDL``"H```#.2P``*P```/E+``!%````)4P``"<`
M``!K3```(0```)-,```K````M4P``!T```#A3```(@```/],```]````(DT`
M`$$```!@30``*````*)-```L````RTT``#````#X30``$````"E.```?````
M.DX```\```!:3@``#````&I.```0````=TX```\```"(3@``!````)A.```*
M````G4X```,```"H3@``!P```*Q.```(````M$X```4```"]3@``"0```,-.
M```&````S4X```@```#43@``#P```-U.```(````[4X```8```#V3@``!@``
M`/U.```'````!$\```<````,3P```P```!1/```)````&$\```P````B3P``
M"@```"]/```$````.D\```0````_3P```@```$1/```.````1T\```\```!6
M3P``!0```&9/``!Q`0``;$\```H```#>4```"@```.E0```*````]%````H`
M``#_4````P````I1```!````#E$``!<````040``*````"A1```V````45$`
M`"@```"(40``.0```+%1```;````ZU$``"X````'4@``-````#92``!N````
M:U(``"(```#:4@``'@```/U2```(````'%,```4````E4P``#````"M3```'
M````.%,```T```!`4P``!0```$Y3```$````5%,``$4```!94P``4P```)]3
M``!!````\U,``"8````U5```'0```%Q4```'````>E0``!(```""5```(```
M`)54```I````ME0``#D```#@5```.0```!I5```Y````5%4```H```".50``
M"````)E5```(````HE4```<```"K50``!P```+-5```3````NU4```X```#/
M50``#@```-Y5```/````[54```<```#]50``"P````56```-````$58```4`
M```?5@``"````"56```&````+E8```X````U5@``%0```$16```V````6E8`
M``@```"15@``#````)I6```%````IU8```D```"M5@``2````+=6``!2````
M`%<``!P```!35P``*@```'!7```.````FU<``!4```"J5P``,0```,!7```<
M````\E<```0````/6```"@```!18```,````'U@```\````L6```%P```#Q8
M```0````5%@```4```!E6```'P```&M8``!(````BU@```8```#46```!P``
M`-M8```,````XU@``"D```#P6```!P```!I9```-````(ED``!(````P60``
M(@```$-9```2````9ED``%D```!Y60``,@```--9```"````!EH```8````)
M6@``!````!!:```$````%5H``!$````:6@``'````"Q:```>````25H```4`
M``!H6@``#P```&Y:``!"````?EH```<```#!6@``$@```,E:```:````W%H`
M``@```#W6@``$0````!;```N````$EL``!0```!!6P```P```%9;```,````
M6EL``"(```!G6P``$@```(I;```A````G5L``!\```"_6P``%P```-];```&
M````]UL``!(```#^6P``!0```!%<```,````%UP```<````D7```%P```"Q<
M```%````1%P```T```!*7```#P```%A<```,````:%P```X```!U7```'```
M`(1<```?````H5P``"P```#!7```'P```.Y<```$````#ET``!`````370``
M$````"1=```/````-5T```\```!%70``#0```%5=```,````8UT``!````!P
M70``"@```(%=```2````C%T```L```"?70``"@```*M=```U````MET``!T`
M``#L70``(@````I>```#````+5X```L````Q7@``(````#U>```&````7EX`
M``,```!E7@``"P```&E>```*````=5X```X```"`7@``"@```(]>```+````
MFEX``!H```"F7@``"````,%>```#````REX```L```#.7@``!````-I>```#
M````WUX```T```#C7@``!0```/%>```8````]UX``!`````07P``!````"%?
M```-````)E\```X````T7P``!0```$-?```'````25\```H```!17P``$```
M`%Q?```'````;5\```L```!U7P``!@```(%?```1````B%\``!,```":7P``
M$````*Y?```'````OU\``"$```#'7P``"````.E?```%````\E\```T```#X
M7P``"@````9@```-````$6```!(````?8```%````#)@```;````1V```!<`
M``!C8```#````'M@```-````B&````@```"68```#@```)]@```'````KF``
M`!,```"V8````@```,I@```(````S6````L```#68```0@```.)@```<````
M)6$``!L```!"80``$````%YA```9````;V$``!@```")80``)````*)A```*
M````QV$```<```#280``#0```-IA```,````Z&$``!$```#U80``$0````=B
M```-````&6(```\````G8@``#0```#=B```.````16(``!<```!48@``+P``
M`&QB```-````G&(```4```"J8@``"0```+!B```%````NF(```0```#`8@``
M!0```,5B```"````RV(```@```#.8@``!P```-=B```-````WV(```<```#M
M8@``!0```/5B```-````^V(```H````)8P```P```!1C```4````&&,```\`
M```M8P``#0```#UC```%````2V,```P```!18P``"@```%YC```'````:6,`
M``X```!Q8P``%P```(!C```2````F&,```<```"K8P``40```+-C```"````
M!60```\````(9```+P```!AD```$````2&0```P```!-9```$0```%ID```1
M````;&0```H```!^9```#0```(ED```'````EV0```<```"?9```'0```*=D
M```M````Q60```D```#S9```%0```/UD```'````$V4``#8````;90``+0``
M`%)E```M````@&4``",```"N90``*````-)E```H````^V4``#$````D9@``
M-P```%9F```G````CF8``#,```"V9@``#P```.IF```,````^F8```@````'
M9P``$@```!!G```8````(V<``!@````\9P``(0```%5G```_````=V<``!H`
M``"W9P``#````-)G```-````WV<``!````#M9P``"0```/YG```*````"&@`
M`!(````3:```&@```"9H```5````06@```@```!7:```%@```&!H```4````
M=V@``!(```",:```"0```)]H```Y````J6@``#0```#C:```#````!AI```$
M````)6D```T````J:0``#@```#AI```-````1VD```H```!5:0``!0```&!I
M```2````9FD``!4```!Y:0``"0```(]I```)````F6D``%,```"C:0``!```
M`/=I```-````_&D```D````*:@``"P```!1J```@````(&H``"P```!!:@``
M`P```&YJ```&````<FH```P```!Y:@``!````(9J```$````BVH```P```"0
M:@``"0```)UJ```*````IVH``!0```"R:@``#P```,=J```0````UVH``!D`
M``#H:@``$@````)K```,````%6L``!,````B:P``$0```#9K```&````2&L`
M`$,```!/:P``2````)-K```6````W&L``!8```#S:P``'`````IL```.````
M)VP``"L````V;```"0```&)L```)````;&P``!4```!V;```%0```(QL```+
M````HFP```T```"N;```#0```+QL```;````RFP``"<```#F;```!`````YM
M```$````$VT```@````8;0``!````"%M```3````)FT```<````Z;0``!P``
M`$)M```4````2FT``!L```!?;0``"````'MM```%````A&T```4```"*;0``
M"0```)!M```@````FFT``!L```"[;0``>````-=M```T````4&X``$$```"%
M;@``,````,=N```R````^&X``!H````K;P``&````$9O```:````7V\``!D`
M``!Z;P``*@```)1O``!#````OV\``$<````#<```50```$MP``!3````H7``
M`#X```#U<```40```#1Q```R````AG$``"8```"Y<0``0P```.!Q```[````
M)'(``!,```!@<@``'0```'1R```6````DG(```L```"I<@``!@```+5R```#
M````O'(```P```#`<@```P```,UR```?````T7(``"@```#Q<@``"````!IS
M```3````(W,```L````W<P``$0```$-S```/````57,```D```!E<P``!0``
M`&]S```=````=7,``!,```"3<P``&0```*=S```*````P7,```H```#,<P``
M!@```-=S```W````WG,``!`````6=```%@```"=T```(````/G0```@```!'
M=```$````%!T```-````870``%P```!O=```"@```,QT```,````UW0```P`
M``#D=````@```/%T```%````]'0```(```#Z=```)````/UT```9````(G4`
M`!H````\=0``'0```%=U``!"````=74``!@```"X=0``%````-%U```@````
MYG4``"$````'=@``/````"EV```B````9G8``!T```")=@``(P```*=V```>
M````RW8``",```#J=@``,P````YW```^````0G<``!<```"!=P``'@```)EW
M```V````N'<```\```#O=P``'0```/]W```-````'7@```P````K>```$```
M`#AX```0````27@```H```!:>```$P```&5X```(````>7@```4```"">```
M!@```(AX```%````CW@```D```"5>```!P```)]X```'````IW@```T```"O
M>```!````+UX```)````PG@```4```#,>````P```-)X```$````UG@```,`
M``#;>```"P```-]X```'````ZW@``!$```#S>````P````5Y```%````"7D`
M``4````/>0``"0```!5Y```)````'WD```4````I>0```0```#D!``!O`0``
M_P```(0!````````50```"\!``!R````+@```(4!``````````````````!\
M`````````!8!``!?`````````&\````P`````````&0`````````3@```#T!
M``"$`````````*,!``"#````Z`````X```#F````"0$````````'````SP``
M``````#<````>P$``"\```"J````!@```)D```!]````&P$``"0!``#+`0``
M9@$``*4!``"?`0``PP$```````"'`0``=0$`````````````G````!<```!'
M`0``VP```&P````G`0``TP```+8!``#>````^@`````````(````IP$`````
M``"R`````````!H```"@````PP```"@!``"!````80````````!'````K@$`
M`%$!``"%``````````````#J````1@$``,$```"P`0``9P```%8```!U````
M@````'H!``#@````````````````````40```*X```#Q`````````,(````@
M````F0$``'0!```Q`0``<P$``)\```#%````M0$``)X!``!C`0``W0```$,`
M```:`0``F@$``'P!``!N`````````)4````;`````````)T```!0````U@``
M`+T!````````L0```*,```#A````<`$``#(!````````````````````````
M!0$``%4!````````2`$`````````````:`````````"1`0``P````/(```"+
M`0``6P```!T````J````S0$``$0``````````````+\````I`````````#8!
M````````(0$``'@`````````U````)P!````````)P`````````_````>@``
M`*\```#:```````````````Y````+0$````````_`0``B`$``#X```")`0``
M`````*@`````````A@$```````!T`````````#0```"R`0``=@``````````
M``````````````!#`0``$@$``,X```"E`````````#H!```S`0``/`$`````
M```5`0``00$``&P!``#W````'`$``(\`````````30```#4`````````P`$`
M`/4```"S````!0```"P!```K`0```````!\```#1`````````%T!```C`0``
M:0````````!P````#````%D!````````'@```/@```"Z``````````0!````
M`````````'$```":````+0`````````B````AP```.0````E`0``O@$``"X!
M``!7`0``>0``````````````.P$``,<!``!,````,0```!\!````````````
M````````````S`$```````#)````2P```%0!``#+````]``````````C````
M`````.\```";`0````````````#N````C@$```````"A`0``BP`````````^
M`0``_````*P```!H`0``3`$```````",`````````(P!````````O```````
M``#0`0``)@```&4```"/`0```@```'$!``!)`0``FP```+0!``""`0``````
M``0`````````DP$``%0```"0````#0$``+$!````````$`$``!D!````````
M````````````````N`$``+,!``#C````B````%,!``"M`````````'T!``#5
M````9@````L!````````#0```#,````2````JP$```D```"Y`````````.4`
M``#)`0``<@$``#T````=`0``JP```&T!```7`0``-P```%8!``!3````7@$`
M``````!J`0``6P$``)8```"4`0``&````$(````3`0```````)8!``#?````
MK0$`````````````=P$``````````````````$\`````````C0```#`!``"=
M`0``R````*H!``!(````]@```*$```"@`0``Q0$``,T```!*`0``NP```!$!
M``!=````P@$``&0!``"2````9P$```````""`````P$``*<```#9````Q@``
M``\!``"I`0``#P```.<``````````````(X```#$`0``_@```*8```"L`0``
M00````H`````````@P$```````#]````I`$``&L!``"]````;@$``%P!``"7
M`0```````$\!````````$P````````"_`0```````(D`````````>P```"8!
M``"^````H@```($!``#!`0``+````%D```"2`0```````'X!```>`0``>`$`
M`!$`````````R`$``(8```"*`0```0$``"0```"U````!@$``"H!````````
MR@````````!M````D0```-<```#/`0``J0```.T```"T`````````#<!``!2
M`0``ZP```#P```#Y````$`````````#[````6`$``"@````8`0```````$``
M```V````)0```/,```!0`0``F`$```````!@`0``.`$```````#8````````
M``````!?`0``NP$``&(!``!Y`0```````)X`````````=@$``$`!```R````
MQP````(!``"B`0``E````+H!``!I`0``.P`````````T`0``Z0````L`````
M````"@$``````````````````$8`````````90$````````4`0```````%X`
M````````2P$``&H```!<````&0````````#0````Q@$``&,```"8````?P``
M`$(!``"\`0``20```'X```!*````6``````!``#2``````````P!``!$`0``
M*P````````!%`0``M@````````!:````(0````````"7````.````*\!``#B
M````#@$``&$!``````````````````!B````R@$``+@````6`````````(`!
M````````10```)4!``````````````````#,````J`$````````B`0``:P``
M`+````!W````I`````````"0`0``S@$``+<`````````30$``(H````(`0``
M?P$````````I`0`````````````4````(`$``.P```!.`0``I@$````````<
M````C0$``/````!2````MP$``,0````5`````P```&````!:`0``N0$``',`
M``"3```````````````Z`````````#4!```'`0``5P`````@("`@("!4;SH@
M`"`@("!$871E.B``("`@($9R;VTZ(``@4W5B:F5C=#H@`"!I;B``(P`E9"!T
M;R`E9"!O9B`E9"!-97-S86=E<P`E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O
M;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T
M('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S.B`E<R`H)60F;F)S<#MO9B9N
M8G-P.R5D*0`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT
M('-C<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@
M=&AE(&-O;7!O<V4@<V-R965N+BD`*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S
M8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A
M<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E
M(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J`"H@4&QE
M87-E('-E;&5C="!A9&1R97-S*&5S*2`J`#(T(&AO=7)S`$%-+U!-`$%D9"!P
M86ER`$%D9')E<W,`061D<F5S<R!";V]K`$%L:6%S`$%L;`!!;&P@;65S<V%G
M97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A
M9&5D(&EN=&\@;VYE($U"3U@@9FEL93H`06QL(&UE<W-A9V5S(&EN('EO=7(@
M(B5S(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N
M96YT;'D@9&5L971E9"X`06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N`$%L=&5R;F%T
M:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ`$%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"X`06YS=V5R960`06YS=V5R960@;65S<V%G97,`07!P
M;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\`07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\`07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/P!!<G)I
M=F%L(%1I;64`07-C96YD:6YG`$%T=&%C:`!!='1A8VAM96YT`$%T=&%C:&UE
M;G1S`$%V86EL86)L92!F:65L9',Z`$)A8U]K('1O("5S`$)A8VL@=&\@)7,`
M0F-C`$)I<G1H9&%Y`$)L86-K;&ES=`!";V1Y`$)O=&@`0U]H87)S970`0V%N
M8V5L`$-A;F-E;"!-97-S86=E`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YC
M96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@
M:71S(&-O;G1E;G1S+@!#8P!#96QL(%!H;VYE`$-H86YG90!#:&%N9V4@06QL
M`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S
M86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W(&UE<W-A9V5S(&%R
M92!S;W)T960N`$-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA
M='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@96UA:6PN`$-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`
M0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL
M(&9R;VTZ`$-H;V]S92!!8W1I;VXZ`$-H;V]S92!A(&UA:6P@<V5R=F5R.@!#
M;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I
M;F1O=RX`0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,`0VQO<V4`0VQO
M<V4@5VEN9&]W`$-L;W-E9"!&;VQD97(`0V]L;&%P<V4@06QL`$-O;&QA<'-E
M($%L;"!&;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VUP86YY`$-O;7!O<V4@
M;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_`$-O;G1R;VP@=VAE;B!N
M97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N
M;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O<'D`0V]R<F5C
M=`!#;W)R96-T960@5&5X=`!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#<F5A=&4`0W)E871E($9O;&1E<@!#<F5A=&4@82!N
M97<@9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E
M<@!#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@
M<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET
M(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$1$`$1A:6QY`$1A=%]E`$1A
M=&4`1&5F875L="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z
M`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T90!$96QE=&4@1F]L
M9&5R*',I`$1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN
M:6YG(&]F(&UO;G1H/P!$96QE=&5D`$1E;&5T960@;65S<V%G97,`1&5L971I
M;F<@86YD($UO=FEN9R!-97-S86=E<P!$97-C96YD:6YG`$1E<V-R:6)E('1H
M92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$1I;2!S:6=N871U<F5S/P!$:7-P;&%Y`$1I<W!L87D@
M3W!T:6]N<P!$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA
M:6P_`$1O($Y/5"!M871C:`!$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.
M97<@36%I;`!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/P!$;VYE`$1O=VYL
M;V%D($9O;&1E<BAS*0!$<F%F=`!$<F%F=',@9F]L9&5R.@!%9&ET`$5D:70@
M>6]U<B!F:6QT97(@<G5L97,`16UA:6P`16UA:6P@061D<F5S<P!%;7!T>2!&
M;VQD97(H<RD`16UP='D@5')A<V@@9F]L9&5R`$5M<'1Y(')E<W5L="X`16YD
M(&9O<G=A<F1E9"!M97-S86=E`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE
M=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S
M96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T
M<F%S:"!F;VQD97(`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>'!A;F0@06QL
M`$5X<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.86UE
M<P!%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN
M('1H92!F;VQD97)S('9I97<_`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$9E
M=&-H($UA:6P`1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y
M/P!&:6QT97)S`$9I;F0`1FER<W0@4&%G90!&;U]R=V%R9`!&;VQD97(@3F%V
M:6=A=&]R`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4@9G)O
M;2`E<P!&<F]?;0!&<F]M`$9R;VT@061D<F5S<P!&=V0Z`$A%4D4`2&5A9&5R
M<P!(96QP`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E9`!(;U]M90!(
M;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)3D)/6`!)8V]N<R!/;FQY
M`$EC;VYS('=I=&@@=&5X=`!)9VYO<F4`26=N;W)E($%L;`!);7!O<G1A;G0`
M26UP;W)T86YT(&UE<W-A9V5S`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN8F]X`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A
M(')E<&QY/P!,85]Y;W5T`$QA;F=U86=E`$QA<W0@2&%L9@!,87-T(%!A9V4`
M3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S
M="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,:5]N:R!!
M='1A8VAM96YT<P!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@:6X@=&\@
M)7,`3&]G(&]U=`!,;V=I;B!487-K<P!-30!-86EL8F]X`$UA<FL@87,Z`$UA
M<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT
M(&-O;&]R<S\`36%T8V@@06QL(%%U97)I97,`36%T8V@@06YY(%%U97)Y`$UA
M=&-H:6YG(&9I96QD<P!-87AI;75M($%T=&%C:&UE;G0@4VEZ90!-87AI;75M
M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D+@!-87AI;75M('1O=&%L
M(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+@!-96YU(&UO9&4Z`$UE<W-A9V4`
M365S<V%G92!#;VUP;W-I=&EO;@!-97-S86=E($1A=&4`365S<V%G92!396%R
M8V@`365S<V%G92!3:7IE`$UE<W-A9V4@4V]U<F-E`$UE<W-A9V4@5FEE=VEN
M9P!-97-S86=E(&9L86=S`$UE<W-A9V4@9F]L9&5R<P!-97-S86=E(&UA=&-H
M97,`365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S
M<V%G97,@=&\`36]D:69Y`$UO;G1H;'D`36]V90!.86UE`$YE=F5R`$YE=P!.
M97<@1F]L9&5R`$YE=R!-86EL`$YE=R!M97-S86=E<P!.97=S`$YE>'0`3F5X
M="!-97-S86=E`$YE>'0@4&%G90!.;P!.;R!F;VQD97)S('=E<F4@<W!E8VEF
M:65D`$YO('-P96QL:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N<P!.;VYE`$YO
M="!$96QE=&5D`$YO="!$<F%F=`!.;W0@26UP;W)T86YT`$YO="!097)S;VYA
M;`!.;W0@9&5L971E9"!M97-S86=E<P!.;W0@:6UP;W)T86YT(&UE<W-A9V5S
M`$YO=&5S`$YU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E
M<"!I9B!D96QE=&EN9R!M;VYT:&QY+@!/2P!/;&0@;65S<V%G97,`3VQD('-E
M;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"X`3W!T:6]N<P!/<F=A;FEZ
M:6YG`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C;W5N=',`3W1H
M97(@3W!T:6]N<P!086=E("5D(&]F("5D`%!A<G0H<RD`4&%S<W=O<F0`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R<V]N86P`4&5R<V]N86P@26YF
M;W)M871I;VX`4&AO;F4`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E
M<&QI97,@86YD(&9O<G=A<F1S/P!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N
M97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.@!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R97-O;'9E
M(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E('-E;&5C
M="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N`%!L
M96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N`%!L
M96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO
M;BX`4')E=FEO=7,@365S<V%G90!0<F5V:6]U<R!086=E`%!R:6YT`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4'5R7V=E($1E;&5T960`4'5R9V4@1&5L971E9`!0
M=7)G92!4<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S(&EN(%1R87-H
M(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N`%)E7W%U
M97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;@!296-E:79E9"!/;@!296-E:79E
M9"!3:6YC90!296-E:79E9"!5;G1I;`!2961I<F5C7W0`4F5D:7)E8W0`4F5D
M:7)E8W0@365S<V%G90!2961I<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E8W1I
M;F<@9F%I;&5D+@!2969R97-H`%)E9G)E<V@@1F]L9&5R(%9I97=S.@!296QO
M860@5FEE=P!296UE;6)E<B!T:&4@;&%S="!V:65W`%)E;6]V92!P86ER`%)E
M;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`
M4F5N86UI;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9`!297!L86-E('=I=&@Z`%)E<&QY`%)E<&QY('1O($%L
M;`!297!L>2!T;R!!;&PZ`%)E<&QY('1O(%]!;&P`4F5P;'DM5&\Z(`!297!L
M>3H`4F5P;W)T(&%S(%-P86T`4F5Q=65S="!A(%]296%D(%)E8V5I<'0`4F5S
M970`4F5S=6UE`%)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R
M(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/P!37W5B
M:F5C=`!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S`%-A=F4@1')A9G0`4V%V
M92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E<C\`4V%V:6YG('1H92!D<F%F
M="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%-E
M87)C:`!396%R8V@@)7,`4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`4V5L
M96-T(&$@9FEE;&0`4V5L96-T(&%L;`!396QE8W0@;F]N90!396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD($UE<W-A
M9V4`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YT(&UA:6P@9F]L9&5R.@!397)V
M97(`4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@
M;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+@!3:&]U;&0@=&AE(&-O;7!O<V4@
M=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=R!!
M;&P@2&5A9&5R<P!3:&]W($1E;&5T960`4VAO=R!,:6UI=&5D($AE861E<G,`
M4VAO=R!5;G-U8G-C<FEB960`4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@
M=FEE=S\`4VE?>F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5L;"!#:&5C:P!3
M<&5L;"!#:&5C:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R
M<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-U8E]J96-T
M`%-U8FIE8W0`4W5B:F5C="!&:65L9`!3=6)M:70`4W5B<V-R:6)E('1O($9O
M;&1E<BAS*0!3=6-C97-S`%-U9V=E<W1I;VYS`%-W:71C:"!T;R!(5$U,(&-O
M;7!O<VET:6]N`%-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N`%1A
M<VMS`%1E7WAT`%1E>'0`5&5X="!/;FQY`%1H92!C=7)R96YT(&9O;&1E<BAS
M*2`B)7,B('=I;&P@8F4@<F5N86UE9"!T;R`B)7,B+@!4:&4@9F]L9&5R("(E
M<R(@86QR96%D>2!E>&ES=',`5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL
M;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E('!R
M;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M`%1H92!F;VQD97(@(B5S(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T
M('-U8G-C<FEB960@=&\@:70N`%1H92!F;VQD97(@(B5S(B!W87,@9&5L971E
M9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@
M9F]L9&5R("(E<R(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&1E;&5T960N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B
M('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"X`5&AE(&9O;&1E<B`B)7,B('=A
M<R!S=6-C97-S9G5L;'D@9&5L971E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S
M=6-C97-S9G5L;'D@<F5N86UE9"!T;R`B)7,B+@!4:&4@<VEG;F%T=7)E('=A
M<R!S=6-C97-S9G5L;'D@<F5P;&%C960N`%1H97)E(&%R92!N;R!M97-S86=E
M<R!I;B!T:&ES(&UA:6QB;W@N`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG
M:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A
M<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M
M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M
M97-S86=E.B`E<P!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D
M9&5D(&EN(&ET+@!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D
M9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92!T:&ES.B``
M5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!C;VYT:6YU93\`5&AI<R!M97-S86=E('1O`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N`%1H<F5A9"!6:65W`%1I=&QE`%1O`%1R87-H(&9O;&1E<CH`55),`%5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86YS=V5R960`56YA;G-W97)E
M9"!M97-S86=E<P!5;F1E;&5T90!5;F1I<V-L;W-E9"!296-I<&EE;G1S`%5N
M9&\@0VAA;F=E<P!5;FYA;65D`%5N<V5E;@!5;G-U8G-C<FEB92!F<F]M($9O
M;&1E<BAS*0!5<V4@1&5F875L="!686QU90!5<V4@24U!4"!F;VQD97(@<W5B
M<V-R:7!T:6]N<S\`57-E<B!/<'1I;VYS`%5S97)N86UE`%9I97<@)7,`5FEE
M=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ`%9I<G1U86P@
M1F]L9&5R<P!6:7)T=6%L(&9O;&1E<B!L86)E;`!787)N:6YG`%=E96ML>0!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H96X@9&5L971I;F<@;65S<V%G
M97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F
M(&UA<FMI;F<@=&AE;2!A<R!D96QE=&5D/P!7:&ET96QI<W0`5V]R:R!!9&1R
M97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EE<P!9;W4@87)E(&-O<'EI;F<O
M;6]V:6YG('1O(&$@;F5W(&9O;&1E<BX`66]U(&%R92!C<F5A=&EN9R!A('-U
M8BUF;VQD97(@=&\@`%EO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L
M9&5R+@!9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z(`!9;W4@9F]R=V%R
M9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I
M<&EE;G1S.B`E<RX`66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+@!9;W4@:&%V
M92`Q(&YE=R!M97-S86=E+@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L
M;&]W:6YG(&9O;&1E<CH`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO
M=VEN9R!F;VQD97)S.@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T('-E
M;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@870@;&5A
M<W0@;VYE(&UE<W-A9V4@9FER<W0N`%EO=2!M=7-T('-P96-I9GD@82!R96-I
M<&EE;G0N`%EO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RX`66]U
M('=E<F4@;F]T('-U8G-C<FEB960@=&\@(B5S(BX@2&5R92!I<R!W:&%T('1H
M92!S97)V97(@<V%I9`!9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@
M(B5S(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!S
M=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R`B)7,B`%EO=2!W97)E('-U8V-E
M<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2`B)7,B`%EO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!S
M:6=N871U<F4Z`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O<G1=`%ML:6YE
M("5S(&]F("5S70!?0F-C`%]";&%C:VQI<W0`7T-C`%]$96QE=&4`7T9O;&1E
M<G,`7TAE;'``7TED96YT:71Y`%]);F)O>`!?3&]G(&]U=`!?365S<V%G92!3
M;W5R8V4`7T]P=&EO;G,`7U!R:6YT`%]297!L>0!?4V5A<F-H`%]4:')E860`
M7U1O`%]5;F1E;&5T90!?5FEE=R!4:')E860`7U=H:71E;&ES=`!F<F]M`&YO
M;F4`;W(`<W!E;&QI;F<@97)R;W(`<W!E;&QI;F<@97)R;W)S`'9#87)D`%!R
M;VIE8W0M260M5F5R<VEO;CH@24U0(#,N,BXQ"E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TP
M-2TQ."`R,SHS-RLP,C`P"DQA<W0M5')A;G-L871O<CH@06YD<F5A<R!'=6YL
M96EK<VMA87,@/&%N9')E87-`9W5N;&5I:W-K86%S+FYO/@I,86YG=6%G92U4
M96%M.B!.;W)W96=I86X@*$)O:VUA;"D@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET"@`@("`@(%1I;#H@`"`@("!$871O.B``("`@("!&<F$Z(``@("`@
M16UN93H@`"!I(``C`"5D("T@)60@878@)60@;65L9&EN9V5R`"5S('9E9&QI
M:V5H;VQD<V]P97)A<VIO;F5R("T@0F5K<F5F=&5L<V4`)7,@9FEN;F5S(&%L
M;&5R961E+B!-87!P96X@)7,@8FQE(&EK:V4@9VET="!N>71T(&YA=FXN`"5S
M('-E<B!I:VME('5T('-O;2!E<B!E;B!G>6QD:6<@<&]S=&)O:W,`36%P<&5N
M("<E<R<@8FQI<B!G:71T(&YY='0@;F%V;B!I(&)E9WEN;F5L<V5N(&%V(&WE
M;F5D96XN`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*0`H0G)U:R!D:7-S
M92!R971T:6YG96YE+"!O9R!GY2!T:6P@;F5S=&4@<VED92XI`"A&;W)K87-T
M(&%L;&4@96YD<FEN9V5R+"!O9R!R971U<FYE<B!T:6P@;65L9&EN9V5N+BD`
M*%)E='5R;F5R92!T:6P@;65L9&EN9V5N(&5T=&5R(&%T(&5N9')I;F=E;F4@
M<^4@;&%N9W0@97(@9VIO<G0N($5N9')I;F=E;F4@:2!D971T92!B:6QD970@
M=FEL($E+2T4@8FQI(&=J;W)T+BD`*B!,96=G('1I;"!D:7-S92!V960@Y2!K
M;&EK:V4@3TL@*@`J(%9E;FYL:6=S="!V96QG(&%D<F5S<V4H;F4I("H`,C0@
M=&EM97(`04TO4$T`3&5G9R!T:6P@<&%R`$%D<F5S<V4`061D<F5S<V5B^&ME
M<@!!;&EA<P!!;&QE`$%L;&4@;65L9&EN9V5N92!I(&;X;&=E;F1E(&UA<'!E
M*'(I('9I;"!B;&D@;&%S=&5T(&YE9"!I(.EN($U"3U@M9FEL.@!!;&QE(&UE
M;&1I;F=E;F4@:2`B)7,B+6UA<'!E;B!S;VT@97(@96QD<F4@96YN("5S(&1A
M9V5R+"!V:6P@8FQI('-L971T970@<&5R;6%N96YT+@!-87!P97(@;65D('-E
M;G1E(&UE;&1I;F=E<B!E;&1R92!E;FX@)7,@;>5N961E<BP@=FEL(&)L:2!S
M;&5T=&5T+@!!;'1E<FYA=&EV92!D96QE<B!F;W(@9&5N;F4@<V5K<VIO;F5N
M.@!%;B!U;&]V;&EG('9E<F1I('9A<B!O<'!G:71T+@!"97-V87)T`$)E<W9A
M<G1E(&UE;&1I;F=E<@!"<G5K(&9I;'1E<G)E9VQE<B!V960@<.5L;V=G:6YG
M+@!%<B!D=2!324M+15(@<.4@870@9'4@^&YS:V5R(.4@9F]R='-E='1E/P!%
M<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('-L971T92!D96YN92!M96QD:6YG
M96X@1D]2($=/1%0`17(@9'4@<VEK:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@
M9&5N;F4@;65L9&EN9V5N($9/4B!'3T14`$5R(&1U('-I:VME<B!PY2!A="!D
M=2!V:6P@<VQE='1E(&1E;FYE(&UE;&1I;F=E;B!&3U(@1T]$5`!!;FMO;7-T
M=&ED`%-T:6=E;F1E`$QE9V<@=F5D`%9E9&QE9V<`5F5D;&5G9P!4:6QG:F5N
M9V5L:6=E(&9E;'0Z`%1I;&)A:V4@=&EL("5S`%1I;&)A:V4@=&EL("5S`%-K
M:G5L="!K;W!I('1I;`!"=7)S9&%G`%-V87)T96QI<W1E`$UE;&1I;F=S=&5K
M<W0`0F5G9V4`5&5G;G-E='0`079B<GET`$%V8G)Y="!M96QD:6YG`$%V8G)Y
M="!P<F]B;&5M<F%P<&]R=`!(=FES(&1U(&%V8G)Y=&5R(&1E;FYE(&UE;&1I
M;F=E;BP@;6ES=&5R(&1U(&EN;FAO;&1E="X`2V]P:2!T:6P`36]B:6QT96QE
M9F]N`$5N9')E`$5N9')E(&%L=`!%;F1R92!V:7-N:6YG<W9A;&<@<V]M(&%N
M=&%L;&5T(&UE;&1I;F=E<B!P97(@<VED92!O9R!M96QD:6YG<W-O<G1E<FEN
M9RX`16YD<F4@;F%V;BP@861R97-S92!O9R!S:6=N871U<B!S;VT@9F]L:R!S
M97(@;N5R(&1E(&QE<V5R(&]G('-V87)E<B!PY2!P;W-T96X@9&EN+@!392!E
M='1E<B!N>2!P;W-T(&D@;6%P<&5N*&4I`%9E;&<@86QL92!S97)V97)E(&1U
M('9I;"!H96YT92!E+7!O<W0@9G)A.@!696QG(&AA;F1L:6YG.@!696QG(&5N
M(&4M<&]S='-E<G9E<CH`5')Y:VL@)7,@9F]R(.4@=FES92!(5$U,+6EN;FAO
M;&0@:2!E="!E9V5T('9I;F1U+@!4<GEK:R!H97(@9F]R(.4@5DE312!B:6QD
M96YE`$QU:VL`3'5K:R!V:6YD=0!,=6MK970@;6%P<&4`4VSE('-A;6UE;B!A
M;&QE`%-LY2!S86UM96X@86QL92!M87!P96YE`%-LY2!S86UM96X@;6%P<&4`
M1FER;6$`3&%G(&YY(&UE;&1I;F<@:2!E="!E9V5T('9I;F1U+@!3971T(&AV
M;W(@;V9T92!D970@<VMA;"!S:F5K:V5S(&5T=&5R(&YY('!O<W0L(&]G(&]M
M(&1U(/AN<VME<B!V87)S;&EN9RX`2V]P:65R`$MO<G)E:W0`4F5T=&5T('1E
M:W-T`$MA;B!I:VME(.5P;F4@36%I;G1E;F%N8V5?5&%S:RUM;V1U;&5T("5S
M`$]P<')E='0`3W!P<F5T="!M87!P90!,86<@;GD@:VQA9&1E;6%P<&4`3&%G
M(&5N(&YY("=396YD=&4@96QE;65N=&5R)RUM87!P90!,86<@;GD@<_AP<&5L
M;6%P<&4`3&%G(&9I;'1R92!F;W(@Y2!O<F=A;FES97)E(&EN;FMO;6UE;F1E
M('!O<W0L(&9O<F1E;&4@9&5N(&D@;6%P<&5R+"!O9R!F;W(@Y2!S;&5T=&4@
M<W!A;2X`5&EL<&%S<R!O<'!G879E<B!S;VT@:VKX<F5S('9E9"!I;FYL;V=G
M:6YG('1I;"`E<RX`1$0`1&%G;&EG`$1A=&\`1&%T;P!3=&%N9&%R9&ED96YT
M:71E=`!3=&%N9&%R9"!S;W)T97)I;F=S:W)I=&5I97(Z`%-T86YD87)D('-O
M<G1E<FEN9W-R96MK96;X;&=E.@!3;&5T=`!3;&5T="!M87!P96XH92D`4VQE
M='0@9V%M;&4@;6%P<&5R(&UE9"!S96YD=&4@;65L9&EN9V5R('#E(&)E9WEN
M;F5L<V5N(&%V(&WE;F5D96X_`%-L971T970`4VQE='1E9&4@;65L9&EN9V5R
M`%-L971T92!O9R!F;'ET=&4@;65L9&EN9V5R`%-Y;FME;F1E`$)E<VMR:78@
M<')O8FQE;65T`$1E=&%L:F5R(&AA<B!B;&ET="!L;V=G970@9F]R(&%D;6EN
M:7-T<F%T;W)E;BX`4VMY9V=E;&5G9R!S:6=N871U<C\`5FES`%9I<VYI;F=S
M=F%L9P!687)S;&4@;GD@<&]S="!M960@<&]P+75P(&UE;&1I;F<_`$E+2T4@
M=&EL9G)E9'-S=&EL;`!):VME('-E(&5T=&5R(&YY('!O<W0@:2!M87!P96XH
M92D`26MK92#E<&X@;6%I;F5N86YC92YP:'`@9&ER96MT90!6:6P@9'4@Y7!N
M92!D96X@;6%P<&5N/P!&97)D:6<`3&%S="!N960@;6%P<&5N*&4I`$ML861D
M`$ML861D96UA<'!E.@!2961I9V5R`$5N9')E(&UI;F4@9FEL=&5R<F5G;&5R
M`&5P;W-T`$4M<&]S=&%D<F5S<V4`4VQE='0@;6%P<&5N*&4I`%/X<'!E;&UA
M<'!E.@!4;VUT(')E<W5L=&%T+@!3;'5T="!PY2!V:61E<F5S96YD="!M96QD
M:6YG`$YA=FYG:2!D96X@;GEE(&ML861D96UA<'!E;B!D:6X`3F%V;F=I(&1E
M;B!N>64@)U-E;F1T92!E;&5M96YT97(G+6UA<'!E;B!D:6X`3F%V;F=I(&1E
M;B!N>64@<_AP<&5L;6%P<&5N(&1I;@!&96EL`$AV97)T(#$U+B!M:6YU='0`
M2'9E<G0@,S`N('-E:W5N9`!(=F5R="`U+B!M:6YU='0`2'9E<B!I;FYL;V=G
M:6YG`$AV97(@:&%L=G1I;64`2'9E<G0@;6EN=71T`$5K<V5M<&5L=F5R9&EE
M<CH`571V:60@86QL90!5='9I9"!A;&QE(&UA<'!E;F4`571V:60@;6%P<&4`
M571V:60@;F%V;@!5='9I9"!H96QE(&UA<'!E=')E970@<V]M('-T86YD9&%R
M9"!I(&UA<'!E=FES;FEN9V5N/P!+86X@:6MK92!E;F1R92!I;G-T:6QL96EN
M9V5R+@!4:6QK;V)L:6YG('1I;"!,1$%0+7-E<G9E<B!F96EL970N`$9A>`!(
M96YT(&4M<&]S=`!&:6QT<F5R('9U;&?F<G0@;65L9&EN9W-I;FYH;VQD+@!&
M:6QT<F4`4_AK`$;X<G-T92!S:61E`%9I9&5R97-E;F0`36%P<&5N879I9V%T
M^'(`5FED97)E<V5N9`!6:61E<F5S96YD.@!6:61E<F5S96YD="!M96QD:6YG
M(&9R82`E<P!!=G-E;F1E<@!&<F$`1G)A+6%D<F5S<V4`1G=D.@!(15(`365L
M9&EN9W-H;V1E<@!(:F5L<`!3:VIU;"!S;&5T=&5D92!E;&5M96YT97(`4VMJ
M=6P@=6%B;VYN97)T90!(:F5M`$AJ96UM96%D<F5S<V4`5&5L969O;B!H:F5M
M;64`2&]R9&4`24Y.0D]+4P!+=6X@:6MO;F5R`$EK;VYE<B!M960@=&5K<W0`
M26=N;W+I<@!)9VYO<NER(&%L=`!6:6MT:6<`5FEK=&EG92!M96QD:6YG97(`
M26UP;W)T97)T92!F96QT.B`E<P!);7!O<G1E<G1E(&9E;'0Z`$EN;F)O:W,`
M26YN:VQU9&5R(&]R9VEN86P@;65L9&EN9R!I('-V87(_`%5T<V5E;F1E`%-P
M<N5K`%-I<W1E(&AA;'1I;64`4VES=&4@<VED90!3:7-T92!K=F%R=&5R`%-I
M<W1E(&]P<&1A=&5R:6YG.@!3:7-T92!I;FYL;V=G:6YG.B`E<P!3:7-T92!I
M;FYL;V=G:6YG.B`E<R!F<F$@)7,`4VES=&4@:6YN;&]G9VEN9SH@06QD<FD`
M3&EN:R!V961L96=G`$5M;F5R(&D@2&IE;'``3&]G9R!I;FX`3&]G9R!I;FX@
M<.4@)7,`3&]G9R!U=`!);FYL;V=G:6YG<V]P<&=A=F5R`$U-`%!O<W1B;VMS
M`$UA<FME<B!S;VTZ`$UE<FL@9F]R<VMJ96QL:6=E(&YI=N5E<B!A=B!S=F%R
M;65L9&EN9V5R(&UE9"!F;W)S:VIE;&QI9V4@9F%R9V5R/P!4:6QF<F5D<W-T
M:6QL(&%L;&4@:W)I=&5R:65R`%1I;&9R961S<W1I;&P@971T(&MR:71E<FEU
M;0!386US=F%R96YD92!F96QT`$UA:W,@<W3X<G)E;'-E('#E('9E9&QE9V<`
M36%K<R!A;G1A;&P@=F5D;&5G9R!NY61D`$UA:W,@=&]T86P@<W3X<G)E;'-E
M('#E('9E9&QE9V<@;N5D9`!-96YY;6]D=7,Z`$UE;&1I;F<`4VMR:78@;65L
M9&EN9P!-96QD:6YG<V1A=&\`4_AK(&5T=&5R(&UE;&1I;F<`365L9&EN9W-S
M=/AR<F5L<V4`365L9&EN9W-K:6QD90!-96QD:6YG<W9I<VYI;F<`365L9&EN
M9W-F;&%G9P!-96QD:6YG<VUA<'!E<@!-96QD:6YG('1I;&9R961S<W1I;&QE
M<@!!;G1A;&P@;65L9&EN9V5R('!R+B!S:61E(&[E<B!P;W-T8F]K<V5N('9I
M<V5S+@!-96QD:6YG97(@=&EL`$5N9')E`$WE;F5D=&QI9P!&;'ET=`!.879N
M`$%L9')I`$YY`$YY(&UA<'!E`$YY('!O<W0`3GEE(&UE;&1I;F=E<@!.>6AE
M=&5R`$YE<W1E`$YE<W1E(&UE;&1I;F<`3F5S=&4@<VED90!.96D`26YG96X@
M;6%P<&4@97(@=F%L9W0`26YG96X@<W1A=F5F96EL`$EN9V5N(&9O<G-L86<`
M26YG96X`26MK92!S;&5T=&5T`$EK:V4@:VQA9&0`579I:W1I9P!):VME('!E
M<G-O;FQI9P!):VME('-L971T961E(&UE;&1I;F=E<@!5=FEK=&EG92!M96QD
M:6YG97(`3F]T871E<@!!;G1A;&P@9V%M;&4@;6%P<&5R(&UE9"!S96YD=&4@
M96QE;65N=&5R('-O;2!S:V%L(&)E:&]L9&5S('9E9"!MY6YE9'1L:6<@<VQE
M='1I;F<`3TL`1V%M;&4@;65L9&EN9V5R`$=A;6QE(&UA<'!E<B!M960@<V5N
M9'1E(&5L96UE;G1E<B!B;&ER(&9J97)N970N`%9A;&<`3W)G86YI<V5R:6YG
M`$%N;F5N(&EN9F]R;6%S:F]N`$%N9')E(&UA:6QK;VYT;V5R`$%N9')E('9A
M;&<`4VED92`E9"!A=B`E9`!$96PH97(I`%!A<W-O<F0`571F^'(@=F5D;&EK
M96AO;&1S;W!E<F%S:F]N97(`571F^'(@=F5D;&EK96AO;&1S;W!E<F%S:F]N
M97(@=F5D(&EN;FQO9V=I;F<_`%!E<G-O;FQI9P!097)S;VYL:6<@:6YF;W)M
M87-J;VX`5&5L969O;@!,96=G92!T:6P@<VEG;F%T=7)E;B!D:6X@9F]R<F%N
M('-V87(@;V<@=FED97)E<V5N9&EN9S\`5F5N;FQI9W-T('-K<FEV(&EN;B!N
M879N970@<.4@9&5N(&YY92!M87!P96XZ`%9E;FYL:6=S="!S:W)I=B!I;FX@
M;F%V;F5T('#E(&1E;B!N>64@;6%P<&5N.@!696YN;&EG<W0@<VMR:78@:6YN
M(&1E="!N>64@;F%V;F5T.@!696YN;&EG<W0@9VD@970@<V%M;65N9')A9R!A
M=B!P<F]B;&5M970N`%9E;FYL:7-T('-K<FEV(&EN;B!B<G5K97)N879N(&]G
M('!A<W-O<F0`5F5N;FQI9W-T(')E='0@='9E='ED:6=E(&5L;&5R('5G>6QD
M:6=E(&%D<F5S<V5R+@!696YN;&EG<W0@=F5L9R!E;B!M87!P92!F^'(@9'4@
M=71F^')E<B!N;V5N(&AA;F1L:6YG97(N`%9E;FYL:6=S="!V96QG(&UI;G-T
M(.EN(&UA<'!E(.4@<_AK92!I+@!696YN;&EG<W0@=F5L9R!B87)E(.EN(&UA
M<'!E(&9O<B!D96YN92!O<&5R87-J;VYE;BX`1F]R<FEG92!M96QD:6YG`$9O
M<G)I9V4@<VED90!3:W)I=B!U=`!0<F]B;&5M8F5S:W)I=F5L<V4`1FIE<FX@
M<VQE='1E9&4@96QE;65N=&5R`$9J97)N('-L971T961E(&5L96UE;G1E<@!(
M=F]R(&]F=&4@<VMA;"!3^'!P96QE="!F:F5R;F5S.B``1FIE<FX@;65L9&EN
M9V5R(&D@4_AP<&5L970@<V]M(&5R(&5L9')E(&5N;B!D971T92!A;G1A;&P@
M9&%G97(N`$)E(&]M(&QE=F5R:6YG<V)E:W)E9G1E;'-E`$UO='1A='0@9&%T
M;P!-;W1T871T('-I9&5N`$UO='1A='0@9G)E;2!T:6P`4F5D:7)I9V5R`$]M
M861R97-SZ7(`3VUA9')E<W/I<B!M96QD:6YG`$]M861R97-SZ7(@9&5N;F4@
M;65L9&EN9V5N`$]M861R97-S97)I;F<@9F5I;&5T+@!/<'!D871E<@!/<'!D
M871E<B!M87!P979I<VYI;F<Z`$QA<W0@=FES;FEN9R!PY2!N>71T`$AU<VL@
M<VES=&4@=FES;FEN9P!&:F5R;B!P87(`1VD@)U-E;F1T92!E;&5M96YT97(G
M(&YY='0@;F%V;B!PY2!B96=Y;FYE;'-E;B!A=B!MY6YE9&5N`$MU;FYE(&EK
M:V4@9VD@(B5S(B!N879N970@(B5S(BX@365L9&EN9R!F<F$@<V5R=F5R96X`
M17)S=&%T="!M960Z`%-V87(`4W9A<B!T:6P@86QL90!3=F%R('1I;"!A;&QE
M.@!3=F%R('1I;"!A;&QE`%-V87(M=&EL.B``4W9A<CH`4F%P<&]R=&5R('-O
M;2!S<&%M`$)E(&]M(&QE<V5B96MR969T96QS90!.=6QL<W1I;&P`1VIE;F]P
M<'1A`$?E('1I;&)A:V4@=&EL('!O<W1B;VMS;&ES=&5N(&5T=&5R(.4@:&$@
M<VQE='1E="P@9FQY='1E="!E;&QE<B!K;W!I97)T(&5N(&UE;&1I;F<_`$5M
M;F4`3&%G<F4@:V]P:2!I(`!,86=R92!S;VT`3&%G<F4@:VQA9&0`3&%G<F4@
M<_AK('-O;2!E;B!V:7)T=65L;"!M87!P93\`3&%G<F4@:VQA9&0@9F5I;&5T
M+B!-96QD:6YG(&9R82!S97)V97)E;CH@)7,`4_AK`%/X:R`E<P!3^&ME<F5S
M=6QT870`3&5S=`!696QG`%9E;&<@970@9F5L=`!696QG(&%L;&4`5F5L9R!I
M;F=E;@!696QG(&1A=&]S:VEL;&5T96=N.@!696QG(&1A=&]F;W)M870`5F5L
M9R!T:61S9F]R;6%T.@!696QG('1O('-A;7-V87)E;F1E(&9E;'0N`%9E;&<@
M^&YS:V5T('-P<N5K.@!396YD(&UE;&1I;F<`4V5N9"!P<F]B;&5M<F%P<&]R
M=`!396YD=&4@96QE;65N=&5R.@!397)V97(`26YN<W1I;&QN9V5R(&9O<B!H
M=F$@<V]M('-K:F5R(&[E<B!D=2!F;'ET=&5R(&]G('-L971T97(@;65L9&EN
M9V5R+@!3:V%L('9I;F1U970@)TYY(&UE;&1I;F<G(&QU:VME<R!E='1E<B!A
M="!M96QD:6YG96X@97(@;&%G<F5T('-O;2!K;&%D9#\`5FES(&%L;&4@;65L
M9&EN9W-H;V1E<@!6:7,@<VQE='1E9&4@96QE;65N=&5R`%9I<R!B96=R96YS
M971E(&UE;&1I;F=S:&]D97(`5FES('5A8F]N;F5R=&4`5FES(&9A<F=E9F]R
M:VQA<FEN9V5R(&[E<B!P;W-T;&ES=&5N('9I<V5S/P!3=/AR<F5L<V4`4W3X
M<G)E;'-E`$AO<'`@;W9E<B!V961L:6ME:&]L9`!3<&5S:6%L=&5G;FEN;G1A
M<W1I;F<`4W!E<VEA;'1E9VX`4W1A=F5K;VYT<F]L;`!3=&%V96MO;G1R;VQL
M`%-T879E:V]N=')O;&QE;B!E<B!F=6QL9OAR=`!3=&%V969E:6P@<'(N('-I
M9&4@=6YD97(@<W1A=F5K;VYT<F]L;"X`16UN90!%;6YE`$5M;F5F96QT`%-E
M;F0`06)O;F[I<B!PY2!M87!P92AR*0!3=6MS97-S`$9O<G-L86<`0GET="!T
M:6P@2%1-3"!E9&ET;W(`0GET="!T:6P@=F%N;&EG('1E:W-T961I=&]R`$]P
M<&=A=F5R`%1E:W-T`%1E:W-T`$MU;B!T96MS=`!-87!P96XH92D@(B5S(B!V
M:6P@;N4@:&5T92`B)7,B+@!-87!P96X@(B5S(B!F:6YN97,@86QL97)E9&4`
M36%P<&5N("(E<R(@:6YN96AO;&1E<B!U9WEL9&EG92!T96=N(&D@;F%V;F5T
M+B!$971T92!K86X@<VMA<&4@<')O8FQE;65R+B!696YN;&EG<W0@<VYA:VL@
M;65D('-Y<W1E;6%D;6EN:7-T<F%T;W)E;B!D:6XN`$UA<'!E;B`B)7,B(&)L
M92!L86=E="P@;65N(&1U(&%B;VYN97)E<B!I:VME('#E(&1E;BX`36%P<&5N
M("(E<R(@8FQE('-L971T970L(&UE;B!D=2!H861D92!I:VME('-A9W0@;W!P
M(&%B;VYN96UE;G1E="X`36%P<&5N("(E<R(@8FQE(&EK:V4@;&%G970N($UE
M;&1I;F<@9G)A('-E<G9E<F5N`$UA<'!E;B`B)7,B(&)L92!I:VME('-L971T
M970N($UE;&1I;F<@9G)A('-E<G9E<F5N`$UA<'!E;B`B)7,B(&)L92!O<'!R
M971T970N`$UA<'!E;B`B)7,B(&)L92!S;&5T=&5T+@!-87!P96X@(B5S(B!H
M971E<B!NY2`B)7,B+@!3:6=N871U<F5N(&)L92!E<G-T871T970N`$1E="!E
M<B!I;F=E;B!M96QD:6YG97(@:2!D96YN92!P;W-T8F]K<V5N+@!$970@;W!P
M<W1O9"!E="!P<F]B;&5M('5N9&5R('-L971T:6YG96X@878@)7,N($UE;&1I
M;F<@9G)A('-E<G9E<F5N`$1E="!O<'!S=&]D(&5T('!R;V)L96T@=F5D(&9J
M97)N:6YG(&%V('!O<W1B;VMS96XN($UE;&1I;F<@9G)A('-E<G9E<F5N`$1E
M="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@<VQE='1I;F<@878@;65L9&EN9V5R
M(&9R82!M87!P96X@(B5S(BX@365L9&EN9R!F<F$@<V5R=F5R96X`1&5T(&]P
M<'-T;V0@96X@9F5I;"!V960@<VQE='1I;F<@878@8F5S:VIE9&5R(&9R82!M
M87!P96X@(B5S(BX@365L9&EN9R!F<F$@<V5R=F5R96X`1&5T(&]P<'-T;V0@
M96X@9F5I;"!U;F1E<B!F;W)S^&L@<.4@Y2!V:7-E(&1E;FYE(&UE;&1I;F=S
M9&5L96X`1&5T(&]P<'-T;V0@96X@9F5I;"!V960@9FQA9V=I;F<@878@;65L
M9&EN9V5R(&D@;6%P<&5N("(E<R(N($UE;&1I;F<@9G)A('-E<G9E<F5N`$1E
M="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@<V5N9&EN9R!A=B!M96QD:6YG96XZ
M("5S`$1E;FYE($A434PM;65L9&EN9V5N(&AA<B!B:6QD97(@:2!S96<N`$1E
M;FYE($A434P@;65L9&EN9V5N(&AA<B!B:6QD97(@:2!S96<N($)L;VMK97)T
M92!B:6QD97(@=FES97,@<VQI:SH`1&5T=&4@:V%N('1A(&QI='0@=&ED+B!%
M<B!D=2!S:6MK97(@<.4@870@9'4@=FEL(&9O<G1S971T93\`1&5N;F4@;65L
M9&EN9V5N('1I;`!$971T92!T86QL970@;>4@=N9R92!M:6YS="`Q+@!$971T
M92!MY2!VYG)E(&5T('1A;&PN`%1RY61V:7-N:6YG`%1I='1E;`!4:6P`4_AP
M<&QE;6%P<&4Z`%523`!+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN
M`$MA;B!I:VME(&]V97)S971T92!D971T92!7;W)D+61O:W5M96YT970`56)E
M<W9A<G0`56)E<W9A<G1E(&UE;&1I;F=E<@!':F5N;W!P<F5T=`!3:VIU;'1E
M(&UO='1A:V5R90!!;F=R92!E;F1R:6YG97(`571E;B!N879N`%5L97-T`%-I
M(&]P<"!A8F]N;F5M96YT('#E(&UA<'!E*'(I`$)R=6L@<W1A;F1A<F0@=F5R
M9&D`0G)U:R!)34%0(&UA<'!E86)O;FYE;65N=`!,86=R92!686QG`$)R=6ME
M<FYA=FX`5FES("5S`%9I<VYI;F<@96QL97(@<&]S=&)O:W,@<V]M('-K86P@
M=FES97,@971T97(@:6YN;&]G9VEN9SH`5FER='5E;&QE(&UA<'!E<@!.879N
M('#E('9I<G1U96QL(&UA<'!E`$%D=F%R<V5L`%5K96YT;&EG`%9E;&MO;6UE
M;B!T:6P@)7,`5F5L:V]M;65N+"`E<P!6960@<VQE='1I;F<@878@;65L9&EN
M9V5R+"!F;'ET="!D96T@=&EL(%/X<'!E;&UA<'!E;B!I<W1E9&5T(&9O<B#E
M(&UA<FME<F4@9&5M('-O;2!S;&5T=&5T/P!(=FET;&ES=&5T`$9I<FUA861R
M97-S90!&:7)M871E;&5F;VX`Y>4`Y7)L:6<`2F$`1'4@:V]P:65R97(O9FQY
M='1E<B!T:6P@96X@;GD@;6%P<&4N`$1U(&QA9V5R(&5N('5N9&5R;6%P<&4@
M:2``1'4@;&%G97(@96X@=&]P<&YI=N5M87!P92X`1'4@9VER(&YY='0@;F%V
M;B!T:6P@;6%P<&5N.B``1'4@=FED97)E<V5N9'1E(&1E;FYE(&UE;&1I;F=E
M;B!PY2`E)7,@=&EL(&;X;&=E;F1E(&UO='1A:V5R93H@)7,N`$1U(&AA<B`E
M<R!N>64@;65L9&EN9V5R(0!$=2!H87(@,2!N>2!M96QD:6YG(0!$=2!H87(@
M;GD@<&]S="!I(&;X;&=E;F1E(&UA<'!E.@!$=2!H87(@;GD@<&]S="!I(&;X
M;&=E;F1E(&UA<'!E<CH`1'4@;>4@8F5S:W)I=F4@<')O8FQE;65T(&;X<B!D
M=2!K86X@<V5N9&4@96X@<')O8FQE;7)A<'!O<G0N`$1U(&WE('9E;&=E(&5N
M(&WE;"UP;W-T8F]K<R!F^')S="X`1'4@;>4@=F5L9V4@96X@861R97-S92!F
M^')S="X`1'4@;>4@=F5L9V4@;6EN<W0@Z6X@;65L9&EN9R!F^')S="X`1'4@
M;>4@<W!E<VEF:7-E<F4@96X@;6]T=&%K97(N`$1U('-V87)T92!PY2!D96YN
M92!M96QD:6YG96X@<.4@)7,N`$1U(&9I:VL@:6MK92!A8F]N;F5R92!PY2`B
M)7,B+B!-96QD:6YG(&9R82!S97)V97)E;@!$=2!F:6MK(&EK:V4@<VD@;W!P
M(&%B;VYN96UE;G1E="!PY2`B)7,B+B!-96QD:6YG(&9R82!S97)V97)E;@!$
M=2!A8F]N;F5R97(@;N4@<.4@(B5S(@!$=2!S82!O<'`@86)O;FYE;65N=&5T
M('#E("(E<R(`1&EN("5S('1I;&MO8FEN9R!H87(@9^5T="!U="X@5F5N;FQI
M9W-T(&QO9R!I;FX@:6=J96XN`$1I;B!I;F9O<FUA<VIO;@!$:6YE('9A;&<@
M:&%R(&)L:71T(&]P<&1A=&5R=`!$:6X@<VEG;F%T=7(Z`%M);G1E="!E;6YE
M70!;4')O8FQE;7)A<'!O<G1=`%ML:6YJ92`E<R!A=B`E<UT`0FQI;F0@:V]P
M:0!3=F%R=&5L:7-T(&%V<V5N9&5R`$MO<&D@=&EL`%-L971T`$UA<'!E<@!(
M:F5L<`!)9&5N=&ET970`26YN8F]K<P!,;V=G('5T`$UE;&1I;F=S:VEL9&4`
M5F%L9P!?4VMR:78@=70`7U-V87(`4_AK`%1RY60`5&EL`$=J96YO<'!R971T
M`%-E('1RY60`2'9I=&QI<W0@879S96YD97(`9G)A`&EN9V5N`&5L;&5R`'-T
M879E9F5I;`!S=&%V969E:6P`=D-A<F0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O
M;F)?3D\O:&5L<"YX;6P`````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`Q,C8T-#<`,3`T,3<S-C(W-C,`,#(Q,3,Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_
M/@H\(2TM("1(;W)D93H@:6UP+VQO8V%L92]N8E].3R]H96QP+GAM;"QV(#$N
M,38N-BXT(#(P,#8O,#$O,S`@,34Z-3@Z,#`@:F%N($5X<"`D("TM/@H\:&5L
M<#X*("`\96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%C=&EO;G,\
M+W1I=&QE/@H@("`@/&AE861I;F<^06-T:6]N<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@4V5N9"!-97-S86=E(&QA=6YC:&5S('EO=7(@96UA:6P@=&\@
M=&AE(&EN=&5N9&5D(')E8VEP:65N="AS*2X@0F4@<W5R92!Y;W4@=V%N="!T
M;R!S96YD(&)E9F]R92!C;&EC:VEN9R!H97)E(&%S(&]N8V4@<V5N="!I="!C
M86YN;W0@8F4@=&%K96X@8F%C:RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@4V%V92!$<F%F="!P;&%C97,@86X@=6YF:6YI<VAE9"!M97-S86=E(&EN
M(&$@9F]L9&5R(&-A;&QE9"`G1')A9G1S)PIA8V-E<W-I8FQE(&)Y('1H92!P
M;W`M9&]W;B!B;W@@;VX@=&AE(')I9VAT('-I9&4@;V8@=&AE(&)L=64@;F%V
M:6=A=&EO;B!B87(@870@=&]P+B!9;W4@8V%N('1H96X@9FEN:7-H('1H92!M
M97-S86=E(&QA=&5R(&)Y('-W:71C:&EN9R!T;R!T:&4@)T1R869T<R<@9F]L
M9&5R+"!C;&EC:VEN9R!O;B!T:&4@<V%V960@;65S<V%G92!T;R!O<&5N(&ET
M+"!A;F0@=&AE;B!C;&EC:VEN9R!O;B`G4F5S=6UE)RX@0F4@<W5R92!T;R!P
M=70@82!S=6)J96-T(&]N('1H92!E;6%I;"!B969O<F4@>6]U('-A=F4@=&AE
M(&1R869T('-O('1H870@>6]U(&-A;B!E87-I;'D@:61E;G1I9GD@=VAI8V@@
M;65S<V%G92!Y;W4@=V%N="!W:71H:6X@=&AE($1R869T<R!F;VQD97(N($%F
M=&5R('-A=FEN9R!A<R!A($1R869T+"!Y;W4@87)E(')E='5R;F5D('1O('EO
M=7(@24Y"3U@@;W(@=VAA=&5V97(@9F]L9&5R('EO=2!W97)E('9I97=I;F<@
M;&%S="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0V%N8V5L($UE<W-A
M9V4@9')O<',@=&AE(&UE<W-A9V4@:6X@<')O9W)E<W,@86YD('-I;7!L>2!R
M971U<FYS('EO=2!T;R!T:&4@24Y"3U@@;W(@=VAA=&5V97(@9F]L9&5R('EO
M=2!W97)E('9I97=I;F<@;&%S="X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H
M(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(^"B`@("`\=&ET
M;&4^365S<V%G92!#;VUP;W-I=&EO;CH@06-T:6]N<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY!8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD
M($UE<W-A9V4@;&%U;F-H97,@>6]U<B!E;6%I;"!T;R!T:&4@:6YT96YD960@
M<F5C:7!I96YT*',I+B!"92!S=7)E('EO=2!W86YT('1O('-E;F0@8F5F;W)E
M(&-L:6-K:6YG(&AE<F4@87,@;VYC92!S96YT(&ET(&-A;FYO="!B92!T86ME
M;B!B86-K+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3879E($1R869T
M('!L86-E<R!A;B!U;F9I;FES:&5D(&UE<W-A9V4@:6X@82!F;VQD97(@8V%L
M;&5D("=$<F%F=',G"F%C8V5S<VEB;&4@8GD@=&AE('!O<"UD;W=N(&)O>"!O
M;B!T:&4@<FEG:'0@<VED92!O9B!T:&4@8FQU92!N879I9V%T:6]N(&)A<B!A
M="!T;W`N(%EO=2!C86X@=&AE;B!F:6YI<V@@=&AE(&UE<W-A9V4@;&%T97(@
M8GD@<W=I=&-H:6YG('1O('1H92`G1')A9G1S)R!F;VQD97(L(&-L:6-K:6YG
M(&]N('1H92!S879E9"!M97-S86=E('1O(&]P96X@:70L(&%N9"!T:&5N(&-L
M:6-K:6YG(&]N("=297-U;64G+B!"92!S=7)E('1O('!U="!A('-U8FIE8W0@
M;VX@=&AE(&5M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A9G0@<V\@=&AA
M="!Y;W4@8V%N(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S86=E('EO=2!W
M86YT('=I=&AI;B!T:&4@1')A9G1S(&9O;&1E<BX@069T97(@<V%V:6YG(&%S
M(&$@1')A9G0L('EO=2!A<F4@<F5T=7)N960@=&\@>6]U<B!)3D)/6"!O<B!W
M:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("!#86YC96P@365S<V%G92!D<F]P<R!T:&4@
M;65S<V%G92!I;B!P<F]G<F5S<R!A;F0@<VEM<&QY(')E='5R;G,@>6]U('1O
M('1H92!)3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN
M9R!L87-T+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)C;VUP;W-E+69R;VTB('-T871E/2)U;FMN;W=N(CX*("`@(#QT
M:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!&<F]M/"]T:71L93X*("`@(#QH
M96%D:6YG/B)&<F]M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@
M>6]U<B!C;W)R96-T(&5M86EL(&%D9')E<W,N(%EO=7(@96UA:6P@861D<F5S
M<R!I<R!A=71O;6%T:6-A;&QY(&5N=&5R960@9F]R('EO=2!F;VQL;W=I;F<@
M(D9R;VTZ(B!I;B!O=71G;VEN9R!E;6%I;"X*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M9G)O;2(^"B`@("`\
M=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@1G)O;3PO=&ET;&4^"B`@("`\
M:&5A9&EN9SXF<75O=#M&<F]M)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%;G1E<B!Y;W5R(&-O<G)E8W0@96UA:6P@861D<F5S<RX@66]U<B!E
M;6%I;"!A9&1R97-S(&ES(&%U=&]M871I8V%L;'D@96YT97)E9"!F;W(@>6]U
M(&9O;&QO=VEN9R`F<75O=#M&<F]M.B9Q=6]T.R!I;B!O=71G;VEN9R!E;6%I
M;"X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UT;R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE
M<W-A9V4@0V]M<&]S:71I;VXZ(%1O/"]T:71L93X*("`@(#QH96%D:6YG/B)4
M;R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T
M(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@>6]U<B!M
M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A
M(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E
M<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S(")4;SHB(&EN(&]U=&=O:6YG(&UA
M:6PN("`*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@
M:60](F-O;7!O<V4M=&\B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I
M;VXZ(%1O/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.U1O)G%U;W0[/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I
M;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E('EO=7(@;65S<V%G
M92X@66]U(&UU<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM
M83L@;W1H97(@<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N
M(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O=#M4;SHF<75O=#L@:6X@;W5T9V]I
M;F<@;6%I;"X@(`H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+6-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\
M=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@0V,\+W1I=&QE/@H@("`@/&AE
M861I;F<^(D-C(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE
M(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV
M92!A(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@4V5P87)A=&4@96%C
M:"!A9&1R97-S('=I=&@@82!C;VUM82X@66]U<B!E;G1R>2!F;VQL;W=S(")#
M8SHB(&EN(&]U=&=O:6YG(&UA:6PN($-A<F)O;B!C;W!I97,@87)E('5S=6%L
M;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!T:&4@;VYE*',I(&)E:6YG
M('=R:71T96X@=&\@9&ER96-T;'D@8G5T(&%R92!I;7!O<G1A;G0@<F5C:7!I
M96YT<R!O9B!T:&4@96UA:6P@87,@=V5L;"P@=7-U86QL>2!S;VUE;VYE(&EN
M9&ER96-T;'D@8V]N8V5R;F5D(&%B;W5T('1H92!S=6)J96-T(&]F('1H92!E
M;6%I;"X@($%L;"`G5&\Z)R!R96-I<&EE;G1S(&%N9"`G0V,Z)R!R96-I<&EE
M;G1S(&-A;B!S964@=&AE(&5N=&ER92!L:7-T(&]F(&)O=&@@:VEN9',@;V8@
M<F5C:7!I96YT<RX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\
M96YT<GD@:60](F-O;7!O<V4M8V,B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ($-C/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T-C)G%U
M;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C
M="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@8V%R
M8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E+B!397!A<F%T92!E86-H(&%D9')E
M<W,@=VET:"!A(&-O;6UA+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[0V,Z
M)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN($-A<F)O;B!C;W!I97,@87)E('5S
M=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!T:&4@;VYE*',I(&)E
M:6YG('=R:71T96X@=&\@9&ER96-T;'D@8G5T(&%R92!I;7!O<G1A;G0@<F5C
M:7!I96YT<R!O9B!T:&4@96UA:6P@87,@=V5L;"P@=7-U86QL>2!S;VUE;VYE
M(&EN9&ER96-T;'D@8V]N8V5R;F5D(&%B;W5T('1H92!S=6)J96-T(&]F('1H
M92!E;6%I;"X@($%L;"`G5&\Z)R!R96-I<&EE;G1S(&%N9"`G0V,Z)R!R96-I
M<&EE;G1S(&-A;B!S964@=&AE(&5N=&ER92!L:7-T(&]F(&)O=&@@:VEN9',@
M;V8@<F5C:7!I96YT<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UB8V,B('-T871E/2)U;FMN;W=N(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@
M("`@/&AE861I;F<^(D)C8R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N
M=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E('1O
M(')E8V5I=F4@82!B;&EN9"!C87)B;VX@8V]P>2!O9B!Y;W5R(&UE<W-A9V4N
M(%EO=2!M=7-T('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[
M(&]T:&5R('!U;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9
M;W5R(&5N=')Y(&9O;&QO=W,@(D)C8SHB(&EN(&]U=&=O:6YG(&UA:6PN($)L
M:6YD(&-A<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T;R!P96]P;&4@
M;W1H97(@=&AA;B!D:7)E8W0@86YD(&EN9&ER96-T(')E8VEP:65N=',@*")4
M;SHB(&%N9"`B0V,Z(B!R96-I<&EE;G1S*2!W:&\@;F5E9"!T;R!R96%D('=H
M870@:7,@8F5I;F<@=W)I='1E;B!A<R!W96QL(%=)5$A/550@=&AE(&]T:&5R
M(')E8VEP:65N=',@:VYO=VEN9R!T:&%T('1H97D@87)E(')E8V5I=FEN9R!T
M:&4@96UA:6PN(%1H=7,@)V)L:6YD)R!M96%N<R!T:&%T('1H92!I9&5N=&ET
M>2!O9B!T:&5S92!R96-I<&EE;G1S(&ES(&AI9&1E;B!F<F]M(&%L;"!O=&AE
M<B!R96-I<&EE;G1S(&]F('1H92!E;6%I;"P@86YD(&]N;'D@>6]U(&%N9"!T
M:&5Y(&MN;W<@=&AE>2!G;W0@82!C;W!Y+B!9;W4@='EP:6-A;&QY('5S92!T
M:&ES('1O('1E;&P@86X@875T:&]R:71Y(&9I9W5R92!T:&%T('EO=2!A<F4@
M=&5L;&EN9R!S;VUE;VYE('-O;65T:&EN9R!W:71H;W5T(&%L87)M:6YG('1H
M92!P97)S;VX@>6]U(&%R92!S96YD:6YG('1H92!A8W1U86P@96UA:6P@=&\N
M"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C
M;VUP;W-E+6)C8R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@
M0F-C/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T)C8R9Q=6]T.SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@
M861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&)L:6YD(&-A<F)O
M;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@66]U(&UU<W0@<V5P87)A=&4@96%C
M:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@<'5N8W1U871I;VX@=VEL
M;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O
M=#M"8V,Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN($)L:6YD(&-A<F)O;B!C
M;W!I97,@87)E('5S=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!D
M:7)E8W0@86YD(&EN9&ER96-T(')E8VEP:65N=',@*"9Q=6]T.U1O.B9Q=6]T
M.R!A;F0@)G%U;W0[0V,Z)G%U;W0[(')E8VEP:65N=',I('=H;R!N965D('1O
M(')E860@=VAA="!I<R!B96EN9R!W<FET=&5N(&%S('=E;&P@5TE42$]55"!T
M:&4@;W1H97(@<F5C:7!I96YT<R!K;F]W:6YG('1H870@=&AE>2!A<F4@<F5C
M96EV:6YG('1H92!E;6%I;"X@5&AU<R`G8FQI;F0G(&UE86YS('1H870@=&AE
M(&ED96YT:71Y(&]F('1H97-E(')E8VEP:65N=',@:7,@:&ED9&5N(&9R;VT@
M86QL(&]T:&5R(')E8VEP:65N=',@;V8@=&AE(&5M86EL+"!A;F0@;VYL>2!Y
M;W4@86YD('1H97D@:VYO=R!T:&5Y(&=O="!A(&-O<'DN(%EO=2!T>7!I8V%L
M;'D@=7-E('1H:7,@=&\@=&5L;"!A;B!A=71H;W)I='D@9FEG=7)E('1H870@
M>6]U(&%R92!T96QL:6YG('-O;65O;F4@<V]M971H:6YG('=I=&AO=70@86QA
M<FUI;F<@=&AE('!E<G-O;B!Y;W4@87)E('-E;F1I;F<@=&AE(&%C='5A;"!E
M;6%I;"!T;RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB8V]M<&]S92US=6)J96-T(B!S=&%T93TB=6YK;F]W;B(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@4W5B:F5C=#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SXB4W5B:F5C="(\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($5N=&5R('1H92!S=6)J96-T(&]F('EO=7(@;65S<V%G92X@66]U<B!E
M;G1R>2!F;VQL;W=S(")3=6)J96-T.B(@:6X@;W5T9V]I;F<@;6%I;"X@2V5E
M<"!I="!S:&]R="P@<VEM<&QE(&%N9"!D97-C<FEP=&EV92X@(%1H92!S=6)J
M96-T(&QI;F4@:7,@=&AE(&5A<VEE<W0@=V%Y(&9O<B!Y;W4@86YD('EO=7(@
M8V]R<F5S<&]N9&5N=',@=&\@<F5M96UB97(@=VAA="!W87,@:6X@=&AE(&5M
M86EL(&%N9"!T:'5S(&ES('9E<GD@:6UP;W)T86YT(&EN(&]R9V%N:7II;F<@
M>6]U<B!E;6%I;"!A;F0@9FEN9&EN9R!I;7!O<G1A;G0@;VYE<R!L871E<BX@
M($%L<V\L('=H96X@>6]U("=297!L>2<@;W(@)T9O<G=A<F0G(&%N9"!E;6%I
M;"!T:&ES('-U8FIE8W0@;&EN92!I<R!C;W!I960@;W9E<B!I;G1O('1H92!N
M97<@;65S<V%G92!A;F0@<V\@:7,@82!V86QU86)L92!W87D@;V8@=&5L;&EN
M9R!W:&%T(&UE<W-A9V5S(&=O('1O9V5T:&5R('1O(&9O<FT@82`B=&AR96%D
M(B!O9B!A(&-O;G9E<G-A=&EO;BX@($AO=V5V97(L(&EF('1H92`G4F5P;'DG
M(&]R("=&;W)W87)D)R!C;VYT86EN<R!N97<@:61E87,L('EO=2!M87D@=V%N
M="!T;R!A9&0@<VEM<&QE(&UO9&EF:6-A=&EO;G,@=&\@=&AE("=3=6)J96-T
M)R!L:6YE('-O('1H92!R96-I<&EE;G0H<RD@8V%N(&9O;&QO=R!T:&4@<')O
M9W)E<W-I;VX@;V8@=&AE(")T:')E860N(@H@("`@/"]P87)A/@H\(2TM($5N
M9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!3=6)J96-T/"]T:71L93X*
M("`@(#QH96%D:6YG/B9Q=6]T.U-U8FIE8W0F<75O=#L\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($5N=&5R('1H92!S=6)J96-T(&]F('EO=7(@;65S<V%G
M92X@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.U-U8FIE8W0Z)G%U;W0[(&EN
M(&]U=&=O:6YG(&UA:6PN($ME97`@:70@<VAO<G0L('-I;7!L92!A;F0@9&5S
M8W)I<'1I=F4N("!4:&4@<W5B:F5C="!L:6YE(&ES('1H92!E87-I97-T('=A
M>2!F;W(@>6]U(&%N9"!Y;W5R(&-O<G)E<W!O;F1E;G1S('1O(')E;65M8F5R
M('=H870@=V%S(&EN('1H92!E;6%I;"!A;F0@=&AU<R!I<R!V97)Y(&EM<&]R
M=&%N="!I;B!O<F=A;FEZ:6YG('EO=7(@96UA:6P@86YD(&9I;F1I;F<@:6UP
M;W)T86YT(&]N97,@;&%T97(N("!!;'-O+"!W:&5N('EO=2`G4F5P;'DG(&]R
M("=&;W)W87)D)R!A;F0@96UA:6P@=&AI<R!S=6)J96-T(&QI;F4@:7,@8V]P
M:65D(&]V97(@:6YT;R!T:&4@;F5W(&UE<W-A9V4@86YD('-O(&ES(&$@=F%L
M=6%B;&4@=V%Y(&]F('1E;&QI;F<@=VAA="!M97-S86=E<R!G;R!T;V=E=&AE
M<B!T;R!F;W)M(&$@)G%U;W0[=&AR96%D)G%U;W0[(&]F(&$@8V]N=F5R<V%T
M:6]N+B`@2&]W979E<BP@:68@=&AE("=297!L>2<@;W(@)T9O<G=A<F0G(&-O
M;G1A:6YS(&YE=R!I9&5A<RP@>6]U(&UA>2!W86YT('1O(&%D9"!S:6UP;&4@
M;6]D:69I8V%T:6]N<R!T;R!T:&4@)U-U8FIE8W0G(&QI;F4@<V\@=&AE(')E
M8VEP:65N="AS*2!C86X@9F]L;&]W('1H92!P<F]G<F5S<VEO;B!O9B!T:&4@
M)G%U;W0[=&AR96%D+B9Q=6]T.PH@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B('-T871E/2)U
M;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!/<'1I
M;VYS/"]T:71L93X*("`@(#QH96%D:6YG/B)/<'1I;VYS(CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AE<V4@3W!T:6]N<R!H96QP('EO=2!P<F5P87)E
M('EO=7(@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI
M8VL@(E-P96QL($-H96-K(B!T;R!C:&5C:R!Y;W5R('-P96QL:6YG+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`B071T86-H;65N=',B('1O
M('9I97<@870@=&AE(&)O='1O;2!O9B!T:&4@<&%G92!A(&QI<W0@;V8@9FEL
M97,@871T86-H960@=&\@=&AI<R!M97-S86=E+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@
M(E-A=F4@8V]P>2(@=&\@<V%V92!A(&-O<'D@;V8@=&AI<R!M97-S86=E(&EN
M('EO=7(@(E-E;G0@36%I;"(@9F]L9&5R+B!3879E(&-O<&EE<R!O9B!I;7!O
M<G1A;G0@96UA:6QS('EO=2!S96YD('-O('1H870@>6]U(&AA=F4@<V]M971H
M:6YG('1O(')E9F5R(&)A8VL@=&\@;&%T97(@86YD('1O(&ME97`@86X@86-C
M=7)A=&4@<F5C;W)D(&]F('=H870@=V%S('-A:60N(%=E(&1O(&YO="!R96-O
M;6UE;F0@>6]U('-A=F4@979E<GD@96UA:6P@<VEN8V4@=&AE;B!Y;W5R(&1I
M<VL@<W1O<F%G92!Q=6]T82!W:6QL(&)E('5S960@=7`@<75I8VML>2`H97-P
M96-I86QL>2!W:&5N('EO=2!S96YD(&%T=&%C:&UE;G1S*2!A;F0@>6]U<B!M
M86EL8F]X('=I;&P@8F4@9G5L;"!A;F0@=6YA8FQE('1O(')E8V5I=F4@;F5W
M(&EN8V]M:6YG(&5M86EL+B!9;W4@8V%N+"!H;W=E=F5R+"!T=7)N('1H:7,@
M9F5A='5R92`G;VXG(&%S('EO=7(@9&5F875L="!W:71H("=0<F5F97)E;F-E
M<R<@;VX@=&AE(&)L=64@;F%V:6=A=&EO;B!B87(@870@=&]P+B!"92!C87)E
M9G5L('=H96X@=7-I;F<@=&AI<R!M;V1I9FEE9"!D969A=6QT(&%S('EO=2!W
M:6QL(&YE960@=&\@<&5R:6]D:6-A;&QY('!U<F=E('EO=7(@(E-E;G0@36%I
M;"(@9F]L9&5R(&]R(&ET('=I;&P@979E;G1U86QL>2!M86ME('EO=7(@;6%I
M;&)O>"!F=6QL(&%N9"!U;G5S96%B;&4N"B`@("`\+W!A<F$^"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B/@H@("`@
M/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($]P=&EO;G,\+W1I=&QE/@H@
M("`@/&AE861I;F<^)G%U;W0[3W!T:6]N<R9Q=6]T.SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AE<V4@3W!T:6]N<R!H96QP('EO=2!P<F5P87)E('EO
M=7(@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI8VL@
M)G%U;W0[4W!E;&P@0VAE8VLF<75O=#L@=&\@8VAE8VL@>6]U<B!S<&5L;&EN
M9RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI8VL@)G%U;W0[071T
M86-H;65N=',F<75O=#L@=&\@=FEE=R!A="!T:&4@8F]T=&]M(&]F('1H92!P
M86=E(&$@;&ES="!O9B!F:6QE<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%C=&EV871E('1H92!C:&5C
M:RUB=71T;VX@;F5X="!T;R`F<75O=#M3879E(&-O<'DF<75O=#L@=&\@<V%V
M92!A(&-O<'D@;V8@=&AI<R!M97-S86=E(&EN('EO=7(@)G%U;W0[4V5N="!-
M86EL)G%U;W0[(&9O;&1E<BX@4V%V92!C;W!I97,@;V8@:6UP;W)T86YT(&5M
M86EL<R!Y;W4@<V5N9"!S;R!T:&%T('EO=2!H879E('-O;65T:&EN9R!T;R!R
M969E<B!B86-K('1O(&QA=&5R(&%N9"!T;R!K965P(&%N(&%C8W5R871E(')E
M8V]R9"!O9B!W:&%T('=A<R!S86ED+B!792!D;R!N;W0@<F5C;VUM96YD('EO
M=2!S879E(&5V97)Y(&5M86EL('-I;F-E('1H96X@>6]U<B!D:7-K('-T;W)A
M9V4@<75O=&$@=VEL;"!B92!U<V5D('5P('%U:6-K;'D@*&5S<&5C:6%L;'D@
M=VAE;B!Y;W4@<V5N9"!A='1A8VAM96YT<RD@86YD('EO=7(@;6%I;&)O>"!W
M:6QL(&)E(&9U;&P@86YD('5N86)L92!T;R!R96-E:79E(&YE=R!I;F-O;6EN
M9R!E;6%I;"X@66]U(&-A;BP@:&]W979E<BP@='5R;B!T:&ES(&9E871U<F4@
M)V]N)R!A<R!Y;W5R(&1E9F%U;'0@=VET:&EN('EO=7(@261E;G1I='DL(&)Y
M(&=O:6YG('1O($]P=&EO;G,M)F=T.U!E<G-O;F%L($EN9F]R;6%T:6]N+29G
M=#M%9&ET('EO=7(@:61E;G1I=&EE<RX@0F4@8V%R969U;"!W:&5N('5S:6YG
M('1H:7,@;6]D:69I960@9&5F875L="!A<R!Y;W4@=VEL;"!N965D('1O('!E
M<FEO9&EC86QL>2!P=7)G92!Y;W5R("9Q=6]T.U-E;G0@36%I;"9Q=6]T.R!F
M;VQD97(@;W(@:70@=VEL;"!E=F5N='5A;&QY(&UA:V4@>6]U<B!M86EL8F]X
M(&9U;&P@86YD('5N=7-E86)L92X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B('-T871E/2)U
M;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A
M8V@\+W1I=&QE/@H@("`@/&AE861I;F<^(D%T=&%C:"(\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@("`@("!9;W4@;6%Y(&%T=&%C:"!F:6QE<R!T;R!Y;W5R
M(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5I=&AE
M<BP@='EP92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A(&9I;&4@=&AA="!Y;W4@
M=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@;W(@8VQI8VL@(D)R;W=S
M92(@8G5T=&]N(&%N9"!S96QE8W0@=&AE(&9I;&4@=&\@8F4@871T871C:&5D
M+B!4:&4@<&%T:"!A;F0@;F%M92!O9B!T:&%T(&9I;&4@;F]W(&%P<&5A<G,@
M:6X@=&AE($%T=&%C:&UE;G0@8F]X+B!.;W<@<')O8V5E9"!T;PI3=&5P(#(N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($-L:6-K(")!='1A8V@B
M(&)U='1O;BX@5&AE(&9I;&4@;F%M92!A;F0@<VEZ92!W:6QL(&)E(&%D9&5D
M('1O('EO=7(@;&ES="!O9B!!='1A8VAM96YT<RX@4&QE87-E(&YO=&4@=&AA
M="!F;W(@;&%R9V4@9FEL97,@86YD+V]R('-L;W=E<B!);G1E<FYE="!C;VYN
M96-T:6]N<RP@=&AE('!R;V-E<W,@;V8@=7!L;V%D:6YG(&%N9"!A='1A8VAI
M;F<@>6]U<B!F:6QE('1O('1H92!E;6%I;"!M87D@=&%K92!A('=H:6QE+B!0
M;&5A<V4@8F4@<&%T:65N="!A;F0@9&\@;F]T(&-L:6-K(&]N(&]T:&5R('1H
M:6YG<R!W:&EL92!Y;W4@87)E('=A:71I;F<N"B`@("`\+W!A<F$^"CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:"(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H/"]T:71L93X*
M("`@(#QH96%D:6YG/B9Q=6]T.T%T=&%C:"9Q=6]T.SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@66]U(&UA>2!A='1A8V@@9FEL97,@=&\@>6]U<B!M97-S
M86=E.R!O;FQY(&]N92!F:6QE(&UA>2!B92!A='1A8VAE9"!A="!A('1I;64N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5I=&AE<BP@='EP92!T
M:&4@<&%T:"!A;F0@;F%M92!O9B!A(&9I;&4@=&AA="!Y;W4@=V%N="!A='1A
M8VAE9"!T;R!T:&ES(&UE<W-A9V4@;W(@8VQI8VL@)G%U;W0[0G)O=W-E)G%U
M;W0[(&)U='1O;B!A;F0@<V5L96-T('1H92!F:6QE('1O(&)E(&%T=&%T8VAE
M9"X@5&AE('!A=&@@86YD(&YA;64@;V8@=&AA="!F:6QE(&YO=R!A<'!E87)S
M(&EN('1H92!!='1A8VAM96YT(&)O>"X*("`@(#PO<&%R83X*("`@(#QP87)A
M/E-T97`@,CH@1&5C:61E('=H971H97(@>6]U('=A;G0@=&AE(&9I;&4@=&\@
M8F4@=FEE=V5D(&%S(&%N(&%T=&%C:&UE;G0@;W(@:6YL:6YE9"!W:71H('1H
M92!R97-T(&]F('1H92!M97-S86=E+B!4:&4@<F5C96EV:6YG('!E<G-O;BAS
M*2!M86EL(')E861I;F<@<V]F='=A<F4@;75S="!B92!A8FQE('1O(&AA;F1L
M92!T:&4@9FEL92!T>7!E(&EN;&EN93L@:68@;F]T+"!T:&ES('!A<G0@=VEL
M;"!B92!V:65W960@87,@86X@871T86-H;65N="!I;G-T96%D+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^4W1E<"`S.B!#;&EC:R`F<75O=#M!='1A8V@F<75O
M=#L@8G5T=&]N+B!4:&4@9FEL92!N86UE(&%N9"!S:7IE('=I;&P@8F4@861D
M960@=&\@>6]U<B!L:7-T(&]F($%T=&%C:&UE;G1S+B!0;&5A<V4@;F]T92!T
M:&%T(&9O<B!L87)G92!F:6QE<R!A;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O
M;FYE8W1I;VYS+"!T:&4@<')O8V5S<R!O9B!U<&QO861I;F<@86YD(&%T=&%C
M:&EN9R!Y;W5R(&9I;&4@=&\@=&AE(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N
M(%!L96%S92!B92!P871I96YT(&%N9"!D;R!N;W0@8VQI8VL@;W1H97(@=&AI
M;F=S('=H:6QE('EO=2!A<F4@=V%I=&EN9RX*("`@(#PO<&%R83X*/"]E;G1R
M>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT
M<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QH96%D:6YG/B)!='1A
M8VAM96YT<R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@<V5C=&EO
M;B!D:7-P;&%Y<R!A(&QI<W0@;V8@9FEL97,@86QR96%D>2!A='1A8VAE9"!T
M;R!Y;W5R(&UE<W-A9V4N(%1O($1E;&5T92!A;B!A='1A8VAE9"!F:6QE.@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`Q.B!!8W1I=F%T92!T:&4@8VAE
M8VLM8G5T=&]N(&YE>'0@=&\@=&AE(&%T=&%C:&5D(&9I;&5N86UE('EO=2!W
M86YT('1O($1E;&5T92X*("`@(#PO<&%R83X@"B`@("`\<&%R83Y3=&5P(#(Z
M($-L:6-K(")$96QE=&4@071T86-H;65N="AS*2(N"B`@("`\+W!A<F$^"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE
M;G1S(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8VAM
M96YT<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M!='1A8VAM96YT<R9Q
M=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S96-T:6]N(&1I
M<W!L87ES(&$@;&ES="!O9B!F:6QE<R!A;')E861Y(&%T=&%C:&5D('1O('EO
M=7(@;65S<V%G92X@5&\@1&5L971E(&%N(&%T=&%C:&5D(&9I;&4Z"B`@("`\
M+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($%C=&EV871E('1H92!C:&5C:RUB
M=71T;VX@;F5X="!T;R!T:&4@871T86-H960@9FEL96YA;64@>6]U('=A;G0@
M=&\@1&5L971E+@H@("`@/"]P87)A/B`*("`@(#QP87)A/E-T97`@,CH@0VQI
M8VL@)G%U;W0[1&5L971E($%T=&%C:&UE;G0H<RDF<75O=#LN"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M<')I;W)I='DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ(%!R:6]R:71Y/"]T:71L93X*("`@(#QH96%D:6YG/B)0<FEO
M<FET>2(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@<V5T<R!T:&4@
M(E@M4')I;W)I='DB(&AE861E<B!O;B!Y;W5R(&]U=&=O:6YG(&UE<W-A9V4N
M(%1H92`B6"U0<FEO<FET>2(@=&%G(&ES(&$@<V]R="!O9B`B<'-E=61O('-T
M86YD87)D(B!T:&%T($YE='-C87!E+"!-;WII;&QA+"!/<&5R82P@86YD($]U
M=&QO;VL@;6%I;"!C;&EE;G1S(&%P<&5A<B!T;R!A9W)E92!O;BX@06YY(&UA
M:6P@8VQI96YT<R!T:&%T(&1O(&YO="!H86YD;&4@=&AI<R!H96%D97(@=VEL
M;"!S:6UP;'D@:6=N;W)E(&ET+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB8V]M<&]S92US879E+6%T=&%C:&UE;G1S(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!3879E($%T=&%C
M:&UE;G1S/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&5T
M:&5R('1H92!A='1A8VAM96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N(&%R92!S
M879E9"!W:71H('1H92!M97-S86=E('=H96X@<W1O<F5D(&EN('1H92!S96YT
M+6UA:6P@9F]L9&5R+B`@268@(EEE<R(L('1H92!A='1A8VAM96YT(&1A=&$@
M=VEL;"!B92!S879E9"X@($EF(").;R(L('1H92!A='1A8VAM96YT(&1A=&$@
M=VEL;"!B92!S=')I<'!E9"!F<F]M('1H92!M97-S86=E(&%F=&5R(&ET(&ES
M('-E;G0@=&\@86QL(')E8VEP:65N=',N("!#:&]O<VEN9R`B3F\B('=I;&P@
M:&5L<"!C;VYS97)V92!D:7-K('-P86-E(&)Y(')E;6]V:6YG("AP;W1E;G1I
M86QL>2!L87)G92D@871T86-H;65N="!I;F9O<FUA=&EO;B!F<F]M('1H92!S
M879E9"!M97-S86=E<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](F-O;7!O<V4M;&EN:RUA='1A8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@3&EN:R!!='1A8VAM96YT
M<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R;6EN97,@=VAE=&AE<B!T
M:&4@871T86-H;65N=',@:6X@>6]U<B!C;VUP;W-I=&EO;B!A<F4@<V5N="!A
M<R!A('!A<G0@;V8@=&AE(&UA:6P@;65S<V%G92!O<B!W:&5T:&5R('1H;W-E
M(&%T=&%C:&UE;G1S(&%R92!K97!T(&]N(&$@;&]C86P@<V5R=F5R+B`@268@
M871T86-H;65N=',@87)E(&QI;FME9"P@=&AE(')E8VEP:65N="AS*2!O9B!Y
M;W5R(&UE<W-A9V4@=VEL;"!B92!P<F]V:61E9"!A('=E8FQI;FL@=VAE<F4@
M=&AE>2!C86X@9&]W;FQO860@=&AE(&%T=&%C:&UE;G0H<RDN("!,:6YK:6YG
M(&%T=&%C:&UE;G1S(&AA<R!T:&4@861V86YT86=E(&]F('1R96UE;F1O=7-L
M>2!R961U8VEN9R!T:&4@<VEZ92!O9B!O=71G;VEN9R!M97-S86=E<RX@($QI
M;FMI;F<@871T86-H;65N=',@:&%S('1H92!D:7-A9'9A;G1A9V4@=&AA="!T
M:&4@8V]N=&5N="!O9B!T:&4@871T86-H;65N=',@8V%N(&YO="!B92!G=6%R
M86YT965D('1O(&)E(&%V86EL86)L92!I;B!T:&4@9G5T=7)E('-I;F-E('1H
M92!A='1A8VAM96YT(&1A=&$@:7,@;F]T(&QO8V%T960@=VET:&EN('1H92!E
M+6UA:6P@;65S<V%G92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G-E87)C:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A
M9V4@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG/E-E87)C:"!#<FET97)I
M83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("`@($AE;'`@=&5X="!T;R!B
M92!W<FET=&5N+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB<V5A<F-H(CX*("`@(#QT:71L93Y-97-S86=E(%-E87)C:#PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY396%R8V@@0W)I=&5R:6$\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%EO=2!M87D@<V5A<F-H(&9O<B!M97-S86=E<R!F
M<F]M('EO=7(@9F]L9&5R<R!U<VEN9R!D:69F97)E;G0@<V5A<F-H(&-R:71E
M<FEA+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`Q.B!%;G1E<B!T97AT
M('1O('1H92!F:65L9',@>6]U('=A;G0@=&\@861D('1O('EO=7(@<V5A<F-H
M(&-R:71E<FEA+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`R.B!#:&]O
M<V4@=&AE(&UE<W-A9V4@9FQA9RAS*2!T;R!A9&0@=&\@>6]U<B!S96%R8V@@
M8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#,Z($-H;V]S
M92!T:&4@9F]L9&5R*',I(&9R;VT@=VAI8V@@=&\@<V5A<F-H(&9O<B!T:&4@
M;65S<V%G97,N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#0Z($-L:6-K
M("9Q=6]T.U-E87)C:"9Q=6]T.RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@268@86YY(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@@8W)I=&5R
M:6$L('1H96X@=&AE('-U8FIE8W1S(&]F('1H97-E(&UE<W-A9V5S('=I;&P@
M8F4@<VAO=VX@:6X@=&AE("9Q=6]T.U-E87)C:"!297-U;'1S)G%U;W0[('9I
M97<N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](F9O;&1E<BUO<'1I;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET
M;&4^1F]L9&5R($UA;F%G96UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^1F]L
M9&5R($]P=&EO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@66]U(&-A
M;B!S96QE8W0@82!F;VQD97(@8GD@=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@
M86QO;F<@=&AE(&QE9G0@8V]L=6UN+B`@3VYC92!Y;W4@:&%V92!D;VYE('1H
M:7,L('-E;&5C="!T:&4@;W!T:6]N('EO=2!W:7-H('1O('!E<F9O<FT@;VX@
M=&AE(&9O;&1E<B!V:6$@=&AE('-E;&5C="!B;W@@=&\@=&AE(&QE9G0N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@66]U('=I;&P@8F4@<')O;7!T
M960@9F]R(&9U<G1H97(@;W!T:6]N<RX@($)E(&-A<F5F=6P@=VET:"!T:&4@
M9&5L971E(&]P=&EO;BP@87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@;65S<V%G
M97,@:6X@82!F;VQD97(@:68@>6]U(&1E;&5T92!I="!B>2!M:7-T86ME(0H@
M("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB9F]L
M9&5R+6]P=&EO;G,B/@H@("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M96YT/"]T
M:71L93X*("`@(#QH96%D:6YG/D9O;&1E<B!/<'1I;VYS/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("`@(%EO=2!C86X@<V5L96-T(&$@9F]L9&5R(&)Y('5S
M:6YG('1H92!R861I;R!B=71T;VYS(&%L;VYG('1H92!L969T(&-O;'5M;BX@
M($]N8V4@>6]U(&AA=F4@9&]N92!T:&ES+"!S96QE8W0@=&AE(&]P=&EO;B!Y
M;W4@=VES:"!T;R!P97)F;W)M(&]N('1H92!F;VQD97(@=FEA('1H92!S96QE
M8W0@8F]X('1O('1H92!L969T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("`@(%EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!F=7)T:&5R(&]P=&EO;G,N
M("!"92!C87)E9G5L('=I=&@@=&AE(&1E;&5T92!O<'1I;VXL(&%S('EO=2!C
M86X@;&]S92!A;&P@=&AE(&UE<W-A9V5S(&EN(&$@9F]L9&5R(&EF('EO=2!D
M96QE=&4@:70@8GD@;6ES=&%K92$*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/DEM<&]R="!M8F]X($9I;&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@
M5&AI<R!O<'1I;VX@=VEL;"!I;7!O<G0@82!M8F]X(&9O<FUA="!F:6QE(&EN
M=&\@=&AE(&9O;&1E<B!O9B!Y;W5R(&-H;VEC92X@0VAO;W-E(#$@*&]N92D@
M9F]L9&5R('1O(&EM<&]R="!T:&4@;65S<V%G97,@:6YT;R!A;F0@=&AE;B!S
M96QE8W0@=&AI<R!O<'1I;VXN(%EO=2!W:6QL('1H96X@8F4@=&%K96X@=&\@
M82!P86=E('1H870@=VEL;"!P<F]M<'0@9F]R('1H92!M8F]X(&9I;&4@=&\@
M:6UP;W)T+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)F;VQD97(M=VED9V5T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^1F]L9&5R($UA;F%G96UE;G0Z($1I<W!L87D\+W1I=&QE/@H@("`@/&AE
M861I;F<^4VAO=R](:61E(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@268@=7-I;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@
M<VAO=R]H:61E('1H92!U;G-U8G-C<FEB960@9F]L9&5R<RX@(%1O('-U8G-C
M<FEB92]U;G-U8G-C<FEB92!T;R!A(&9O;&1E<BP@<V5L96-T('1H92!C:&5C
M:V)O>"!N97AT('1O('1H92!F;VQD97)N86UE(&%N9"!U<V4@=&AE(%-U8G-C
M<FEB92]5;G-U8G-C<FEB92!O<'1I;VX@:6X@=&AE($9O;&1E<B!!8W1I;VX@
M9')O<"UD;W=N(&UE;G4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%>'!A
M;F0@06QL/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%>'!A;F0@86QL(&9O
M;&1E<B!E;G1R:65S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^0V]L;&%P
M<V4@06QL/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;VQL87!S92!A;&P@
M9F]L9&5R(&5N=')I97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)F:6QT97)S(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^1FEL
M=&5R<SH@07!P;'D\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@1FEL=&5R
M(%)U;&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B!T:&4@
M(D%P<&QY($9I;'1E<B(@:6-O;B!N97AT('1O('1H92!)3D)/6"!N86UE(&EN
M('1H92!M86EL8F]X('9I97<@=&\@9FEL=&5R(&%L;"!U;F1E;&5T960@;65S
M<V%G97,@86-C;W)D:6YG('1O('1H92!S<&5C:69I960@<G5L97,N("!/<BP@
M86QT97)N871E=FQY+"!C;&EC:R!O;B`B07!P;'D@06QL(%)U;&5S(B!I;B!T
M:&4@9FEL=&5R(&UE;G4N("!.;W1E('1H870@9FEL=&5R:6YG(&ES(&YO="!D
M;VYE(&%U=&]M871I8V%L;'DN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E
M;G1R>3H*/&5N=')Y(&ED/2)F:6QT97)S(CX*("`@(#QT:71L93Y&:6QT97)S
M.B!!<'!L>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L
M97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N('1H92`F<75O
M=#M!<'!L>2!&:6QT97(F<75O=#L@:6-O;B!N97AT('1O('1H92!)3D)/6"!N
M86UE(&EN('1H92!M86EL8F]X('9I97<@=&\@9FEL=&5R(&%L;"!U;F1E;&5T
M960@;65S<V%G97,@86-C;W)D:6YG('1O('1H92!S<&5C:69I960@<G5L97,N
M("!/<BP@86QT97)N871E=FQY+"!C;&EC:R!O;B`F<75O=#M!<'!L>2!!;&P@
M4G5L97,F<75O=#L@:6X@=&AE(&9I;'1E<B!M96YU+B`@3F]T92!T:&%T(&9I
M;'1E<FEN9R!I<R!N;W0@9&]N92!A=71O;6%T:6-A;&QY+@H@("`@/"]P87)A
M/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I
M="UR=6QE<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I
M="!&:6QT97(@4G5L97,\+W1I=&QE/@H@("`@/&AE861I;F<^161I="!9;W5R
M($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@
M;VX@(D5D:70@>6]U<B!F:6QT97(@<G5L97,B('1O('!R;V-E960@=&\@=&AE
M('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@=&AE
M(&-U<G)E;G1L>2!A8W1I=F4@<V5T(&]F(&9I;'1E<B!R=6QE<RX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUE9&ET+6)L86-K
M;&ES="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!"
M;&%C:VQI<W0\+W1I=&QE/@H@("`@/&AE861I;F<^161I="!9;W5R($)L86-K
M;&ES=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@
M>6]U<B!B;&%C:VQI<W0B('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@
M>6]U(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@=&AE(&QI<W0@;V8@92UM
M86EL(&%D9')E<W-E<R!Y;W4@04Q705E3(')E9G5S92!M86EL(&9R;VTN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UW
M:&ET96QI<W0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D
M:70@5VAI=&5L:7-T/"]T:71L93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!7
M:&ET96QI<W0\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N(")%
M9&ET('EO=7(@=VAI=&5L:7-T(B!T;R!P<F]C965D('1O('1H92!P86=E('=H
M97)E('EO=2!C86X@861D+"!D96QE=&4L(&%N9"!E9&ET('1H92!L:7-T(&]F
M(&4M;6%I;"!A9&1R97-S97,@>6]U($%,5T%94R!A8V-E<'0@;6%I;"!F<F]M
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N
M+6QO9VEN(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!&:6QT
M97(@;VX@3&]G:6X\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@1FEL=&5R
M(%)U;&5S(%5P;VX@3&]G;VX_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#
M:&5C:R!T:&ES(&]P=&EO;B!T;R!A;'=A>7,@87!P;'D@9FEL=&5R<R!W:&5N
M(&9I<G-T(&QO9V=I;F<@;VYT;R!)35`N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM9&ES<&QA>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&]N(%)E9G)E<V@\+W1I=&QE
M/@H@("`@/&AE861I;F<^07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.
M0D]8(&ES(&1I<W!L87EE9#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H
M96-K('1H:7,@;W!T:6]N('1O(&%L=V%Y<R!A<'!L>2!F:6QT97)S('=H96YE
M=F5R('EO=7(@=FEE=R!T:&4@24Y"3U@_"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)F:6QT97(M86YY+6UA:6QB;W@B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!A;GD@36%I;&)O>#PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA
M:6QB;W@_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P
M=&EO;B!I9B!Y;W4@=V%N="!T;R!B92!A;&QO=V5D('1O(&%P<&QY(&9I;'1E
M<B!R=6QE<R!T;R!A;GD@;6%I;&)O>"X@3F]R;6%L;'DL(&9I;'1E<FEN9R!R
M=6QE<R!A<F4@;VYL>2!A<'!L:65D('1O(&YE=R!M86EL('1H870@:7,@9&5L
M:79E<F5D('1O('EO=7(@24Y"3U@N("!)9B!T:&ES(&]P=&EO;B!I<R!C:&5C
M:V5D+"!A;B!I8V]N('=I;&P@87!P96%R(&]N(&%L;"!M86EL8F]X('!A9V=E
M<R!T:&%T('=I;&P@86QL;W<@>6]U('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T
M;R!T:&4@;65S<V%G97,@:6X@=&AE(&-U<G)E;G0@;6%I;&)O>"X@($Y/5$4Z
M($9I;'1E<FEN9R!I;B!M86EL8F]X97,@;W1H97(@=&AA;B!)3D)/6"!M87D@
M<')O9'5C92!S=')A;F=E("AE+F<N('1H92!F:6QT97(@;6%Y(&-A=7-E(&$@
M8V]P>2!O9B!M97-S86=E<R!T;R!B92!D96QI=F5R960@=&\@=&AE('-A;64@
M;6%I;&)O>"D@86YD+V]R('5N9&5S:7)E9"!R97-U;'1S("AE+F<N(&ET(&UA
M>2!C875S92!M97-S86=E<R!T;R!B92!M;W9E9"]D96QE=&5D(&EF(&YE=R!F
M:6QT97)I;F<@<G5L97,@:&%V92!B965N(&EM<&QE;65N=&5D('-I;F-E('1H
M92!M97-S86=E(&AA<R!B965N(&1E;&EV97)E9"!T;R!T:&4@8W5R<F5N="!M
M86EL8F]X*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UC;VUP;W-E+6%T=&%C:"UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@071T86-H(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I
M;F<^071T86-H(%!U8FQI8R!+97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($EF('-E;&5C=&5D('1H96X@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K
M97DL(&EF(&ET(&5X:7-T<RP@=VEL;"!B92!A='1A8VAE9"!T;R!T:&4@;W5T
M9V]I;F<@;65S<V%G92X@(%EO=2!C86X@<V5T('1H92!D969A=6QT(&)E:&%V
M:6]R('9I82!T:&4@4$=0($]P=&EO;G,@<V-R965N+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO;BUS8V%N+6)O9'DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@4V-A;B!497AT($)O9&EE<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY38V%N(%1E>'0@0F]D:65S/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N($E-4"!W:6QL('-C
M86X@=&AE(&)O9'D@;V8@86QL('1E>'0@;65S<V%G97,@9F]R(%!'4"!D871A
M+"!A;F0@9&ES<&QA>2!T:&4@<F5S=6QT<R!I9B!A;GD@9&%T82!I<R!F;W5N
M9"X@($YO=&4@=&AA="!T:&ES(&UA>2!S;&]W(&1O=VX@=&AE('-Y<W1E;2!A
M<R!E=F5R>2!T97AT(&UE<W-A9V4@;75S="!B92!S8V%N;F5D(&EN(&ET<R!E
M;G1I<F5T>2!F;W(@4$=0(&1A=&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,M96YC<GEP="(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^0V]M<&]S93H@16YC<GEP=&EO;B!/<'1I;VYS/"]T
M:71L93X*("`@(#QH96%D:6YG/DYO($5N8W)Y<'1I;VX\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%-E;F0@=&AE(&UE<W-A9V4@=VET:"!N;R!E;F-R>7!T
M:6]N("AC;&5A<G1E>'0I+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0
M($5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI
M<R!O<'1I;VX@=VEL;"!E;F-R>7!T('1H92!C=7)R96YT(&UE<W-A9V4L('5S
M:6YG(%!'4"!A;F0@=&AE(')E8VEP:65N=',@<&5R<V]N86P@<'5B;&EC(&ME
M>2P@86YD('1H96X@<V5N9"!I="X@66]U(&-A;B!O;FQY('-E;F0@82!M97-S
M86=E('1O(&$@<VEN9VQE('!E<G-O;B!U<VEN9R!T:&ES(&]P=&EO;BX@66]U
M($U54U0@:&%V92!T:&4@<'5B;&EC(&ME>2!O9B!T:&4@<F5C:7!I96YT('-T
M;W)E9"!I;B!Y;W5R(&%D9')E<W-B;V]K(&]R(&5L<V4@=&AI<R!O<'1I;VX@
M=VEL;"!F86EL+B!)9B!Y;W4@:&%V92!T:&4@<'5B;&EC(&ME>2!F;W(@=&AE
M(')E8VEP:65N="!I;B!Y;W5R(&%D9')E<W-B;V]K(&%N9"!A<F4@<W1I;&P@
M<F5C96EV:6YG(&5R<F]R<RP@=F5R:69Y('1H870@=&AE(&4M;6%I;"!A9&1R
M97-S(&EN('1H92!R96-I<&EE;G0@9FEE;&0@;6%T8VAE<R!T:&4@92UM86EL
M(&%D9')E<W,@=VAE<F4@=&AE('!U8FQI8R!K97D@:7,@<W1O<F5D+B!4:&4@
M96YC<GEP=&5D(&1A=&$@=VEL;"!B92!A='1A8VAE9"!T;R!T:&4@;W5T9V]I
M;F<@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!3:6=N
M($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N
M('=I;&P@9&EG:71A;&QY('-I9VX@=&AE(&-U<G)E;G0@;65S<V%G92!U<VEN
M9R!01U`@86YD('EO=7(@<&5R<V]N86P@<')I=F%T92!K97DN($EF('EO=2!H
M879E(&YO="!A;')E861Y(&5N=&5R960@=&AE('!A<W-P:')A<V4@9F]R('EO
M=7(@<')I=F%T92!K97D@9'5R:6YG('1H:7,@<V5S<VEO;B!Y;W4@=VEL;"!B
M92!P<F]M<'1E9"!F;W(@:70N("!4:&4@<F5C96EP:65N="!M=7-T(&AA=F4@
M82!C;W!Y(&]F('EO=7(@<'5B;&EC(&ME>2!T;R!D:6=I=&%L;'D@=F5R:69Y
M('EO=7(*("`@('-I9VYA='5R92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!F:7)S="!D:6=I=&%L;'D@<VEG;B!Y
M;W5R(&UE<W-A9V4@86YD('1H96X@=VEL;"!E;F-R>7!T('1H92!R97-U;'1I
M;F<@;W5T<'5T+B!3964@=&AE("=01U`@16YC<GEP="!-97-S86=E)R!A;F0@
M)U!'4"!3:6=N($UE<W-A9V4G(&5N=')I97,@9F]R(&9U<G1H97(@:6YF;W)M
M871I;VXN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@16YC<GEP
M="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG;B!-97-S86=E/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UO=F5R=FEE=R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4$=0.B!/=F5R=FEE=SPO=&ET;&4^"B`@("`\:&5A9&EN9SY7:&%T(&ES(%!'
M4#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%!'4"!I<R!A('1O;VP@9F]R
M('-E8W5R92!C;VUM=6YI8V%T:6]N(&%N9"!D871A('-T;W)A9V4L(&5S<&5C
M:6%L;'D@9F]R('5S92!W:71H(&4M;6%I;"X@270@8V%N(&)E('5S960@=&\@
M96YC<GEP="!D871A(&%N9"!T;R!C<F5A=&4@9&EG:71A;"!S:6=N871U<F5S
M+B!)35`@=7-E<R!';G501R`H1TY5(%!R:79A8WD@1W5A<F0I('1O('!R;W9I
M9&4@=&AI<R!F=6YC=&EO;F%L:71Y+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@268@=&AI<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W:6QL
M(&)E(&%B;&4@=&\@8W)E871E+W9I97<@>6]U<B!P97)S;VYA;"!01U`@:V5Y
M<RP@861D+V1E;&5T92!P=6)L:6,@:V5Y<R!F<F]M(&]T:&5R(&EN9&EV:61U
M86QS+"!R96%D(&5N8W)Y<'1E9"!M86EL+"!V97)I9GD@9&EG:71A;&QY('-I
M9VYE9"!M86EL+"!A;F0@96YC<GEP="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I
M;"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I
M;VXM871T86-H+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0
M.B!/<'1I;VYS("T@071T86-H(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE
M861I;F<^3W!T:6]N<R`M($%T=&%C:"!0=6)L:6,@2V5Y/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N(&$@8V]P>2!O9B!Y;W5R
M(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L('=I;&P@8GD@9&5F875L
M="!B92!A='1A8VAE9"!T;R!A;&P@;W5T9V]I;F<@;65S<V%G97,N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;6%N86=E+7!U8FME
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC
M($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1H:7,@<V-R965N(&QI<W1S(&%L;"!O9B!T:&4@
M8W5R<F5N="!U<V5R<R!I;B!Y;W5R(&%D9')E<W-B;V]K('1H870@:&%V92!0
M1U`@<'5B;&EC(&ME>7,N(%1H97-E('5S97)S(&%R92!T:&4@3TY,62!U<V5R
M<R!T:&%T('EO=2!C86X@96ET:&5R(#$I('-E;F0@86X@96YC<GEP=&5D(&UE
M<W-A9V4@=&\@+4]2+2`R*2!V97)I9GD@82!D:6=I=&%L('-I9VYA='5R92X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P=6)L
M:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B
M;W5T('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T
M:&4@<'5B;&EC(&ME>2!F<F]M('EO=7(@861D<F5S<V)O;VLN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M:6UP;W)T+7!U8FME>2(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME
M>7,@+2!);7!O<G0\+W1I=&QE/@H@("`@/&AE861I;F<^26UP;W)T(%!U8FQI
M8R!+97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&)U='1O;B!W
M:6QL(&]P96X@82!W:6YD;W<@=VAE<F4@>6]U(&-A;B!M86YU86QL>2!I;7!O
M<G0@82!01U`@<'5B;&EC(&ME>2X@(%1H92!K97D@8V%N(&5I=&AE<B!B92!P
M87-T960@:6YT;R!A('1E>'1F:65L9"!O<BP@:68@=&AE(&ME>2!R97-I9&5S
M(&EN(&$@9FEL92!O;B!Y;W5R(&QO8V%L(&-O;7!U=&5R+"!Y;W4@8V%N(&EM
M<&]R="!I="X@($EF('1H92!K97D@:7,@=F%L:60@:70@=VEL;"!B92!I;G-E
M<G1E9"!I;G1O('EO=7(@861D<F5S<V)O;VL@86YD('1H92!W:6YD;W<@=VEL
M;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@
M8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<M<&5R<V]N86QK97DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME
M>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&UE
M<W-A9V5S(&]R(&5N86)L92!O=&AE<G,@=&\@<V5N9"!Y;W4@96YC<GEP=&5D
M(&UE<W-A9V5S+"!Y;W4@;75S="!H879E('EO=7(@;W=N('!E<G-O;F%L('!U
M8FQI8R]P<FEV871E(%!'4"!K97EP86ER+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^66]U<B!0=6)L:6,@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!9;W5R('!U8FQI8R!K97D@<VAO=6QD(&)E(&UA9&4@879A:6QA8FQE('1O
M(&%N>2!P97)S;VX@=&AA="!Y;W4@=V%N="!T;R!B92!A8FQE('1O('-E;F0@
M>6]U(&5N8W)Y<'1E9"!M97-S86=E<R!T:&%T(&]N;'D@64]5(&-A;B!D96-R
M>7!T("AU<VEN9R!Y;W5R('!R:79A=&4@:V5Y*2X@061D:71I;VYA;&QY+"!Y
M;W5R('!U8FQI8R!K97D@;F5E9',@=&\@8F4@;6%D92!A=F%I;&%B;&4@=&\@
M86YY8F]D>2!Y;W4@<V5N9"!A(&1D:6=I=&%L;'D@<VEG;F5D(&UE<W-A9V4@
M=&\@+2!T:&4@<'5B;&EC(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M(&1I9VET86P@<VEG;F%T=7)E+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M66]U<B!0<FEV871E($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U
M<B!P<FEV871E(&ME>2!I<R!N96-E<W-A<GD@=&\@9&5C<GEP="!A;GD@;65S
M<V%G92!E;F-R>7!T960@=7-I;F<@>6]U<B!P=6)L:6,@:V5Y+B!!9&1I=&EO
M;F%L;'DL('EO=7(@<')I=F%T92!K97D@:7,@;F5E9&5D(&EF('EO=2!W86YT
M('1O(&1I9VET86QL>2!S:6=N(&$@;65S<V%G92X@66]U<B!P<FEV871E(&ME
M>2!W:6QL(&)E('!R;W1E8W1E9"!V:6$@82!P87-S<&AR87-E(&-R96%T960@
M=VAE;B!T:&4@:V5Y<R!A<F4@9V5N97)A=&5D+B!4:'5S+"!T;R!P97)F;W)M
M(&%N>2!A8W1I=FET>2!T:&%T(')E<75I<F5S('EO=7(@<')I=F%T92!K97DL
M($E-4"!W:6QL('!R;VUP="!Y;W4@9F]R('EO=7(@<&%S<W!H<F%S92X@66]U
M(&]N;'D@;F5E9"!T;R!I;G-E<G0@>6]U<B!P87-S<&AR87-E(&]N8V4@<&5R
M('-E<W-I;VX@+2!)35`@=VEL;"!S=&]R92!Y;W5R('!A<W-P:')A<V4@=6YT
M:6P@>6]U(&QO9V]U="`H4V\@8F4@<W5R92!T;R!L;V=O=70A*2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP
M=6)L:6,B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!E
M<G-O;F%L($ME>7,@+2!0=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG
M/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W
M('1O('9I97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES
M<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<'5B;&EC(&ME>2X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA
M;&ME>2UP<FEV871E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA
M;F%G92!097)S;VYA;"!+97ES("T@4')I=F%T92!+97D\+W1I=&QE/@H@("`@
M/&AE861I;F<^16YT97(@4&%S<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@3W!E;G,@=&AE('!A<W-P:')A<V4@9&EA;&]G('=I;F1O=RX@5&AE
M('!A<W-P:')A<V4@96YT97)E9"P@:68@8V]R<F5C="P@=VEL;"!B92!S=&]R
M960@8GD@24U0('5N=&EL('EO=7(@<V5S<VEO;B!E;F1S+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^56YL;V%D(%!A<W-P:')A<V4\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%)E;6]V97,@=&AE('-T;W)E9"!P87-S<&AR87-E(&9R
M;VT@24U0("T@86YY(&%D9&ET:6]N86P@=7-A9V4@;V8@=&AE('!R:79A=&4@
M:V5Y('=I;&P@<F5Q=6ER92!Y;W4@=&\@<F5E;G1E<B!T:&4@<&%S<W!H96%S
M92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P
M<FEV871E(&ME>2X@1$\@3D]4(%-%3D0@5$A)4R!+15D@5$\@04Y93TY%("T@
M=&AI<R!O<'1I;VX@:7,@<W1R:6-T;'D@<V\@=&AA="!Y;W4@8V%N(&5X<&]R
M="!Y;W5R($E-4"!P97)S;VYA;"!P<FEV871E(&ME>2!F;W(@=7-E(&EN(&%N
M;W1H97(@<')O9W)A;2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I
M;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T
M86EL<R!A8F]U="!T:&4@4$=0('!R:79A=&4@:V5Y+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@
M2V5Y<R`M($1E;&5T93PO=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R
M<V]N86P@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!B=71T
M;VX@=VEL;"!D96QE=&4@>6]U<B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!K
M97EP86ER(&9R;VT@24U0)W,@<')E9F5R96YC97,N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6YA
M;64B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O
M;F%L($ME>2`M($YA;64\+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&YA;64@>6]U('=A;G0@96UB961D
M960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!(')E<75I<F5D(&9I96QD+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L
M:V5Y+6-R96%T92UC;VUM96YT(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M1U`Z($-R96%T92!097)S;VYA;"!+97D@+2!#;VUM96YT/"]T:71L93X*("`@
M(#QH96%D:6YG/D-O;6UE;G0\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@
M8V]M;65N="!S=')I;F<@>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S
M;VYA;"!K97ES+B!!;B!O<'1I;VYA;"!F:65L9"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M96UA
M:6PB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O
M;F%L($ME>2`M($4M;6%I;"!!9&1R97-S/"]T:71L93X*("`@(#QH96%D:6YG
M/D4M;6%I;"!!9&1R97-S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@
M92UM86EL(&%D9')E<W,@>6]U('=A;G0@87-S;V-I871E9"!W:71H('EO=7(@
M<&5R<V]N86P@:V5Y<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M
M:V5Y;&5N9W1H(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T
M92!097)S;VYA;"!+97D@+2!+97EL96YG=&@\+W1I=&QE/@H@("`@/&AE861I
M;F<^2V5Y;&5N9W1H/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@:V5Y
M;&5N9W1H+"!I;B!B>71E<RP@;V8@>6]U<B!G96YE<F%T960@:V5Y+B!4:&4@
M9W)E871E<B!T:&4@=F%L=64L('1H92!G<F5A=&5R('1H92!P<F]T96-T:6]N
M("AA;F0@86QS;R!G<F5A=&5R(&=E;F5R871I;VX@=&EM92!A;F0@96YC<GEP
M=&EO;B!T:6UE*2X@,3`R-"!B>71E<R!I<R!T:&4@9&5F875L="`M('1H:7,@
M=F%L=64@<')O=FED97,@97AC96QL96YT('!R;W1E8W1I;VXN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E
M871E+7!A<W-P:')A<V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@
M0W)E871E(%!E<G-O;F%L($ME>2`M(%!A<W-P:')A<V4\+W1I=&QE/@H@("`@
M/&AE861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE('!A
M<W-P:')A<V4@=7-E9"!T;R!P<F]T96-T+V5N8W)Y<'0@>6]U<B!P97)S;VYA
M;"!P<FEV871E(&ME>2X@5&AI<R!S:&]U;&0@8F4@050@3$5!4U0@-B!C:&%R
M86-T97)S+"!S:&]U;&0@3D]4(&)E('1H92!S86UE(&%S('EO=7(@;&]G:6X@
M<&%S<W=O<F0L('-H;W5L9"!.3U0@8F4@8F%S960@;VX@82!D:6-T:6]N87)Y
M('=O<F0L(&%N9"!S:&]U;&0@:6YC;'5D92!B;W1H(&YU;6)E<G,@86YD(&QE
M='1E<G,N(%EO=2!M=7-T(&5N=&5R('1H:7,@<&%S<W!H<F%S92!T=VEC92!F
M;W(@=F5R:69I8V%T:6]N('!U<G!O<V5S+B!!(')E<75I<F5D(&9I96QD+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L
M:V5Y+6-R96%T92UA8W1I;VYS(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M1U`Z($-R96%T92!097)S;VYA;"!+97D@+2!!8W1I;VYS/"]T:71L93X*("`@
M(#QH96%D:6YG/D-R96%T92!+97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!#<F5A=&4@86YD('-T;W)E('EO=7(@<&5R<V]N86PO<')I=F%T92!K97EP
M86ER+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^26UP;W)T($ME>7!A:7(\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($EM<&]R="!A('!E<G-O;F%L+W!R
M:79A=&4@:V5Y<&%I<BX@5&AI<R!B=71T;VX@;W!E;G,@82!W:6YD;W<@=VAE
M<F4@>6]U(&-A;B!M86YU86QL>2!I;7!O<G0@>6]U<B!E>&ES=&EN9R!01U`@
M<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<BX@(%1H92!K97ES(&-A
M;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT9FEE;&0@;W(L(&EF('1H
M92!K97ES(')E<VED92!I;B!A(&9I;&4@;VX@>6]U<B!L;V-A;"!C;VUP=71E
M<BP@>6]U(&-A;B!I;7!O<G0@=&AE;2X@($EF('1H92!K97ES(&%R92!V86QI
M9"!T:&5Y('=I;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R('!R969E<F5N8V5S
M(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@
M97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E
M<G9I97<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@3W9E<G9I
M97<\+W1I=&QE/@H@("`@/&AE861I;F<^5VAA="!I<R!3+TU)344_/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!3+TU)344@:7,@82!P<FEV871E+W!U8FQI
M8R!K97D@<&%I<B!S>7-T96T@=VAI8V@@<')O=FED97,@9&EG:71A;"!S:6=N
M871U<F5S+"!M97-S86=E('!R:79A8WDL(&%N9"!T86UP97(@9&5T96-T:6]N
M(&EN(&$@;W!E;BP@:6YT97)O<&5R86)L92!W87DN("!3+TU)344@8V%N('!R
M;W9I9&4@;65S<V%G92!P<FEV86-Y(&)Y(&5N8W)Y<'1I;F<@;65S<V%G97,@
M=&AA="!O;FQY('1H92!S96YD97(@86YD('1H92!I;G1E;F1E9"!R96-I<&EE
M;G1S(&-A;B!D96-O9&4N("!)="!A;&QO=W,@>6]U('1O(&ED96YT:69Y('1H
M92!S96YD97(@;V8@82!M97-S86=E('9I82!A(&1I9VET86P@<VEG;F%T=7)E
M+B`@5&]G971H97(L('1H:7,@96YC<GEP=&EO;B!A;F0@9&EG:71A;"!S:6=N
M:6YG(&AE;'`@<')O=FED92!T86UP97(@9&5T96-T:6]N+"!A;&QO=VEN9R!R
M96-I<&EE;G1S('1O(&1E=&5R;6EN92!W:&5T:&5R(&$@;65S<V%G92!W87,@
M86QT97)E9"!A9G1E<B!I="!W87,@<V5N="X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EF('1H:7,@;W!T:6]N(&ES('-E;&5C=&5D+"!Y
M;W4@=VEL;"!B92!A8FQE('1O(&EM<&]R="!Y;W5R('!E<G-O;F%L(%,O34E-
M12!K97ES+"!R96%D(&5N8W)Y<'1E9"!M86EL+"!V97)I9GD@9&EG:71A;&QY
M('-I9VYE9"!M86EL+"!A;F0@96YC<GEP="]S:6=N('EO=7(@;W5T9V]I;F<@
M;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE
M+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y3+TU)344Z(%!E<G-O;F%L($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^
M3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('EO=2!W86YT
M('1O(&1I9VET86QL>2!S:6=N(&]R(&5N8W)Y<'0@;65S<V%G97,@>6]U(&UU
M<W0@:&%V92!Y;W5R(&]W;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!3+TU)
M344@:V5Y<&%I<BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G-M:6UE+6EM<&]R="UP97)S;VYA;"UC97)T<R(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4R]-24U%.B!);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S
M/"]T:71L93X*("`@(#QH96%D:6YG/DEM<&]R="!097)S;VYA;"!#97)T:69I
M8V%T97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EM<&]R="!P97)S;VYA
M;"!C97)T:69I8V%T97,@9G)O;2!A(%!+0U,@(S$R(&9O<FUA="!F:6QE+B!0
M2T-3(",Q,B!F:6QE<R!I<R!T:&4@9FEL92!U<W5A;&QY(&=E;F5R871E9"!W
M:&5N(&5X<&]R=&EN9R!A(&ME>2!F<F]M(&$@8G)O=W-E<B`H92YG+B!);G1E
M<FYE="!%>'!L;W)E<BP@1FER969O>"D@;W(@9G)O;2!A(&-E<G1I9FEC871E
M('-T;W)E(&UA:6YT86EN960@8GD@86X@3W!E<F%T:6YG(%-Y<W1E;2`H92YG
M+B!7:6YD;W=S(%A0*2X@268@=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL
M;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD('1H92!W
M:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S
M86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UD96QE=&4M<&5R<V]N
M86PM8V5R=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@1&5L
M971E(%!E<G-O;F%L($-E<G1I9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY$96QE=&4@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!$96QE=&4@>6]U<B!P97)S;VYA;"!C97)T:69I8V%T97,@
M9G)O;2!Y;W5R('!R969E<F5N8V5S+B`@66]U('=I;&P@;F\@;&]N9V5R(&)E
M(&%B;&4@=&\@<VEG;B!3+TU)344@;65S<V%G97,@;W(@=FEE=R!A;GD@4R]-
M24U%(&5N8W)Y<'1E9"!M97-S86=E<R!A9&1R97-S960@=&\@>6]U+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;6%N86=E+7!U
M8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!-86YA9V4@
M4'5B;&EC($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^4R]-24U%.B!-86YA
M9V4@4'5B;&EC($ME>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($UA;F%G
M92!Y;W5R(%,O34E-12!P=6)L:6,@:V5Y(&QI<W0N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W
M('1H92!R87<@=&5X="!O9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%9I97<@=&5C:&YI8V%L(&1E=&%I;',@;V8@=&AE('!U8FQI8R!K97DN"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($1E;&5T97,@=&AE('-E;&5C=&5D('!U8FQI8R!K97D@9G)O
M;2!S=&]R86=E+B`@1&5L971I;F<@82!P=6)L:6,@:V5Y(&9O<B!A('5S97(@
M=VEL;"!P<F5V96YT('EO=7(@9G)O;2!E;F-R>7!T:6YG(&$@;65S<V%G92!T
M;R!T:&%T('5S97(N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<FEN=&EN9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')I;G1I;F<\
M+W1I=&QE/@H@("`@/&AE861I;F<^4')I;G0@82!M97-S86=E/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4;R!P<FEN="!A(&UE<W-A9V4@>6]U(&%R92!V
M:65W:6YG+"!C;&EC:R!O;B!T:&4@(E!R:6YT(B!L:6YK(&%T(&5I=&AE<B!T
M:&4@=&]P(&]R(&)O='1O;2!O9B!T:&4@;65S<V%G92X@5&AE(&UE<W-A9V4@
M=VEL;"!O<&5N(&EN(&$@;F5W('=I;F1O=R!F;W)M871E9"!F;W(@<')I;G1I
M;F<N("!$97!E;F1I;F<@;VX@>6]U<B!W96(@8G)O=W-E<B!A;F0@;W!E<F%T
M:6YG('-Y<W1E;2P@=&AE('!R:6YT(&1I86QO9R!B;W@@;6%Y(&]P96X@9F]R
M('EO=2X@($EF(&ET(&1O97,@;F]T(&]P96XL('1H96X@<'5L;"!D;W=N('1H
M92!W96(@8G)O=W-E<B=S(")&:6QE(B!M96YU(&%N9"!C:&]O<V4@(E!R:6YT
M(B!T;R!O<&5N('1H92!P<FEN="!D:6%L;V<@8F]X+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V]R=&EN9R(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4V]R=&EN9R!A;F0@5&AR96%D:6YG/"]T:71L93X*("`@(#QH
M96%D:6YG/E-O<G1I;F<@16YT<FEE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@5VAE;B!V:65W:6YG(&$@;&ES="!O9B!M97-S86=E<RP@>6]U(&-A;B!S
M;W)T('1H92!M97-S86=E<R!B>2!A;GD@8V]L=6UN(&)Y(&-L:6-K:6YG(&]N
M('1H92!A<'!R;W!R:6%T92!C;VQU;6X@:&5A9&EN9RX@(%1O('-W:71C:"!C
M;VQU;6YS(&)E='=E96X@87-C96YD:6YG(&%N9"!D97-C96YD:6YG(&]R9&5R
M+"!C;&EC:R!O;B!T:&4@87)R;W<@:6-O;B!I;B!T:&4@8V]L=6UN(&AE861I
M;F<N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY4:')E861I;F<\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1O(&=R;W5P(&UE<W-A9V5S(&)Y('1H<F5A
M9',@*'-U8FIE8W0I+"!S;R!E86-H(&UE<W-A9V4@:7,@9W)O=7!E9"!W:71H
M(&%L;"!I=',@<F5P;&EE<RP@8VQI8VL@=&AE(%M4:')E861=(&QI;FL@:6X@
M=&AE('-U8FIE8W0@8V]L=6UN(&AE861I;F<N("!4;R!R971U<FX@=&\@;F]R
M;6%L('-U8FIE8W0@<V]R=&EN9RP@8VQI8VL@;VX@=&AE(%M3=6)J96-T72!L
M:6YK(&EN('1H92!S=6)J96-T(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB86QT97)N871I=F4M;7-G(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y-=6QT:7!A<G0O06QT97)N871I=F4@365S
M<V%G97,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3;VUE(&UE<W-A9V4@:&%V
M92!B965N('-E;G0@87,@82`B;75L=&EP87)T+V%L=&5R;F%T:79E(B!T>7!E
M(&)Y('1H92!S96YD97(N(%1H97-E(&UE<W-A9V5S(&AA=F4@<V5V97)A;"!P
M87)T<RP@86QL(&1I<W!L87EI;F<@=&AE(%-!344@0T].5$5.5"!B=70@:6X@
M1$E&1D5214Y4($9/4DU!5%,N(%1H92!M86EL(&%G96YT('=I;&P@9&ES<&QA
M>2!T:&4@;&%S="!P87)T(&EN('1H92!L:7-T('1H870@8V%N(&)E('-U8V-E
M<W-F=6QL>2!D:7-P;&%Y960@:6YL:6YE(&EN('1H92!B<F]W<V5R+"!I9B!A
M;GDN($%L;"!O=&AE<B!F;W)M871S('=I;&P@87!P96%R('5N9&5R('1H92!H
M96%D:6YG(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N(B!A
M;F0@8V%N(&)E('9I97=E9"!O<B!D;W=N;&]A9&5D('-E<&%R871E;'DN($ET
M(&ES(&EM<&]R=&%N="!T;R!N;W1E('1H870@=&AE<V4@86QT97)N871I=F4@
M<&%R=',@8V]N=&%I;B!T:&4@4T%-12!#3TY414Y44R!A<R!T:&4@<&%R="!T
M:&%T(&ES('-H;W=N("T@=&AE>2!A<F4@<VEM<&QY(&EN(&$@9&EF9F5R96YT
M(&UE9&EA(&9O<FUA="`H92YG+B!T97AT('9S+B!(5$U,(&]U='!U="DN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUR96YA;65?
M<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!296YA;64@4V5N="UM86EL($9O;&1E
M<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P
M=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!R96YA;64@>6]U<B!S96YT
M+6UA:6P@9F]L9&5R(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N
M("!4:&4@9F]L9&5R('=I;&P@8F4@<F5N86UE9"`H=&\@82!N86UE('1H870@
M8V]N=&%I;G,@=&AE(&UO;G1H(&%N9"!Y96%R*2!A;F0@82!N97<@<V5N="UM
M86EL(&9O;&1E<B!W:6QL(&)E(&-R96%T960N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!$96QE=&4@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L
M93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@
M=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T
M('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&ES(&UA>2!B92!U
M<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N
M=&UA:6Q?;6]N=&AL>5]K965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T92!396YT+6UA:6P@1F]L
M9&5R($UO;G1H;'D@+2`C(&]F($9O;&1E<G,@=&\@2V5E<#PO=&ET;&4^"B`@
M("`\<&%R83X*("`@($EF('EO=2!A<F4@9&5L971I;F<@;VQD('-E;G0M;6%I
M;"!F;VQD97)S(&5V97)Y(&UO;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@;VQD
M(&9O;&1E<G,@9&\@>6]U("!W86YT('1O(&ME97`_("!!;GD@9F]L9&5R<R!O
M;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT:',@=VEL;"!B92!D96QE=&5D+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E
M7V%T=&%C:&UE;G1S7VUO;G1H;'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E($QI;FME9"!!='1A
M8VAM96YT<R!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T
M:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!A="!T:&4@8F5G:6YN:6YG(&]F(&5V97)Y
M(&UO;G1H+B`@5&AI<R!M87D@8F4@=7-E9G5L(&EF('EO=2!H879E(&$@<75O
M=&$L(&9O<B!E>&%M<&QE+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'E?:V5E<"(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE;G1S($UO;G1H;'D@+2`C(&]F
M($UO;G1H<R!T;R!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M(&%R92!D96QE=&EN9R!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&5V97)Y(&UO
M;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@;VQD(&%T=&%C:&UE;G1S(&1O('EO
M=2`@=V%N="!T;R!K965P/R`@06YY(&%T=&%C:&UE;G1S(&]L9&5R('1H86X@
M=&AI<R!M86YY(&UO;G1H<R!W:6QL(&)E(&1E;&5T960N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!0=7)G92!4<F%S:#PO=&ET;&4^"B`@("`\<&%R83X*("`@($1O('EO=2!W
M86YT('1O('!U<F=E('EO=7(@=')A<V@@9F]L9&5R(&5V97)Y('-O(&]F=&5N
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R
M9V5?=')A<VA?:6YT97)V86PB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@4'5R9V4@5')A<V@@26YT97)V86P\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E('!U<F=I;F<@>6]U
M<B!T<F%S:"!F;VQD97(L(&AO=R!O9G1E;B!S:&]U;&0@:70@8F4@<'5R9V5D
M/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R
M9V5?=')A<VA?:V5E<"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:"!+965P/"]T:71L93X*
M("`@(#QP87)A/@H@("`@268@>6]U(&%R92!P=7)G:6YG('EO=7(@=')A<V@@
M9F]L9&5R+"!M97-S86=E(&]L9&5R('1H86X@:&]W(&UA;GD@9&%Y<R!S:&]U
M;&0@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M871T<FEB7W1E>'0B('-T871E/2)N97<B/@H@("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@365S<V%G92!#;VUP;W-I=&EO;CH@071T<FEB=71I
M;VX@5&5X=#PO=&ET;&4^"B`@("`@/'!A<F$^"B`@("`@2&5R92!Y;W4@8V%N
M(&5N=&5R('1H92!P:')A<V4@=&AA="!Y;W4@=VES:"!T;R!A<'!E87(@8F5F
M;W)E(&%N>2!Q=6]T960@=&5X="!I;B!A(')E<&QY('1H870@>6]U('-E;F0N
M"B`@("`@/"]P87)A/@H@("`@(#QP87)A/@H@("`@(%EO=2!C86X@:6YC;'5D
M92!O;F4@;W(@;6]R92!S<&5C:6%L('!L86-E:&]L9&5R<R!T;R!I;G-E<G0@
M:6YF;W)M871I;VX@86)O=70@=&AE(&UE<W-A9V4@=&\@=VAI8V@@>6]U(&%R
M92!R97!L>6EN9RX@4&QA8V5H;VQD97)S(&-O;G-I<W0@;V8@82`G)2<@9F]L
M;&]W960@8GD@82!S:6YG;&4@;&5T=&5R+B!4:&4@9F]L;&]W:6YG('!L86-E
M:&]L9&5R<R!A<F4@879A:6QA8FQE.@H@("`@(#PO<&%R83X*"B`@("`@/'!A
M<F$^("5F(#H@5&AE('-E;F1E<B=S(&YA;64@86YD(&5M86EL(&%D9')E<W,\
M+W!A<F$^"B`@("`@/'!A<F$^("5A(#H@5&AE('-E;F1E<B=S(&5M86EL(&%D
M9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^("5P(#H@5&AE('-E;F1E<B=S(&YA
M;64\+W!A<F$^"B`@("`@/'!A<F$^("5R(#H@5&AE(&9U;&P@4D9#(#(X,C(@
M<W1Y;&4@9&%T92!A;F0@=&EM92!Z;VYE/"]P87)A/@H@("`@(#QP87)A/B`E
M9"`Z(%1H92!D871E(&%S('=W=RP@9&0@;6UM(%E965D\+W!A<F$^"B`@("`@
M/'!A<F$^("5X(#H@5&AE(&1A=&4@:6X@=&AE(&QO8V%L92=S(&1E9F%U;'0\
M+W!A<F$^"B`@("`@/'!A<F$^("5C(#H@5&AE(&1A=&4@86YD('1I;64@:6X@
M=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^("5M(#H@
M5&AE($UE<W-A9V4M240\+W!A<F$^"B`@("`@/'!A<F$^("5S(#H@5&AE('-U
M8FIE8W0\+W!A<F$^"B`@("`@/'!A<F$^("5N(#H@02!N97<@;&EN93PO<&%R
M83X*("`@("`\<&%R83X@)24@.B!4:&4@)R4G(&-H87)A8W1E<CPO<&%R83X*
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U
M97-T7W)E860B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!297%U97-T(%)E860@4F5C96EP=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("`B4F5Q=65S="!A(%)E860@4F5C96EP="(@<V5N9',@82!R97%U97-T('1O
M('1H92!R96-I<&EE;G1S(&]F('1H:7,@;65S<V%G92!T;R!N;W1I9GD@>6]U
M('=H96X@=&AI<R!M97-S86=E(&ES(&]P96YE9"!B>2!T:&4@<F5C:7!I96YT
M<RX@3F]T(&%L;"!C;&EE;G1S('-U<'!O<G0@+R!H;VYO<B!T:&ES+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I
M;VY?<V5N9%]M9&XB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N
M8V5S.B!396YD($U$3CPO=&ET;&4^"B`@("`\<&%R83X*("`@(")396YD(&$@
M341.(B!S96YD<R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M("AA;'-O(&MN;W=N(&%S(&$@<F5A9"!R96-E:7!T*2!W:&5N('EO=2!V:65W
M(&$@;65S<V%G92!I;B!W:&EC:"!T:&4@=7-E<B!H87,@<F5Q=65S=&5D('1H
M870@=&AE>2!R96-E:79E(&YO=&EF:6-A=&EO;B!T:&%T('EO=2!H879E(')E
M860@=&AE(&UE<W-A9V4N($EN(&UO<W0@8V%S97,L('1H:7,@=VEL;"!H87!P
M96X@875T;VUA=&EC86QL>2!W:71H;W5T('!R;VUP=&EN9R!Y;W4N($EN(&-E
M<G1A:6X@:7-O;&%T960@8V%S97,L('EO=2!M87D@:&%V92!T;R!M86YU86QL
M>2!D96-I9&4@=&\@<V5N9"!T:&4@;F]T:69I8V%T:6]N(&)Y(&-L:6-K:6YG
M(&]N(&$@;&EN:RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?9&5L:79E<GDB('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!297%U97-T($1E;&EV97)Y
M($-O;F9I<FUA=&EO;CPO=&ET;&4^"B`@("`\<&%R83X*("`@(")297%U97-T
M($1E;&EV97)Y($-O;F9I<FUA=&EO;B(@<V5N9',@82!R97%U97-T('1O('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@<V5R=F5R('1O(&YO=&EF>2!Y;W4@=VAE
M;B!I="!H87,@9&5L:79E<F5D('1H92!M97-S86=E('1O('1H92!R96-I<&EE
M;G0G<R!M86EL8F]X+B!)="!D;V5S;B=T(&UE86X@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<V5E;BP@:G5S="!T:&%T(&ET)W,@<VET=&EN9R!I;B!A(&UA:6QB
M;W@@<V]M97=H97)E+B!.;W0@86QL(&UA:6P@<V5R=F5R<R!S=7!P;W)T('1H
M:7,N(`H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M9&5L971E7W-P86U?869T97)?<F5P;W)T(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@1&5L971E(%-P86T@069T97(@4F5P;W)T:6YG
M/"]T:71L93X*("`@(#QP87)A/@H@("`@66]U(&UA>2!E;&5C="!T;R!D;R!O
M;F4@;V8@=&AR964@:71E;7,@869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A
M<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@1FER<W0L('EO=2!C86X@9&5C:61E('1O(&1O(&YO=&AI;F<@
M+2!T:&4@;65S<V%G92!W:6QL(&)E(')E<&]R=&5D(&%S(&5I=&AE<B!S<&%M
M(&]R(&EN;F]C96YT(&)U="!W:6QL(&]T:&5R=VES92!R96UA:6X@=6YC:&%N
M9V5D(&EN('EO=7(@;6%I;&)O>"X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@4V5C;VYD+"!I9B!R97!O<G1I;F<@82!M97-S86=E(&%S('-P86TL('EO
M=2!C86X@:6YS=&5A9"!H879E('1H92!M97-S86=E(&)E(&EM;65D:6%T96QY
M(&1E;&5T960N("!4:&ES('-E='1I;F<@:&%S(&YO(&5F9F5C="!O;B!R97!O
M<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!4:&ER9"P@869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A
M<R!S<&%M('1H92!M97-S86=E('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C
M=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D('1O('EO=7(@<W!A;2!F;VQD97(N
M("!!;'1E<FYA=&EV96QY+"!I9B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN
M;F]C96YT('1H92!M97-S86=E('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C
M=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D('1O('EO=7(@24Y"3U@N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUH=&UL7VEM86=E
M7W)E<&QA8V5M96YT(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@2%1-3"!);6%G92!297!L86-E;65N=#PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($9O<B!(5$U,(&UE<W-A9V5S(&1I<W!L87EE9"!I;FQI;F4L('-H
M;W5L9"!A;&P@:6UA9V4@=&%G<R!B92!B;&]C:V5D('5N=&EL('EO=2!S<&5C
M:69I8V%L;'D@9&5C:61E('1O('9I97<@=&AO<V4@:6UA9V5S/R!.;W1E('1H
M870L(&EF('9I97=I;F<@86X@2%1-3"!A='1A8VAM96YT+"!T:&4@:6UA9V5S
M('=I;&P@86QW87ES(&)E(&1I<W!L87EE9"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+6AT;6Q?:6UA9V5?861D<F)O;VLB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!(5$U,($EM86=E
M(%)E<&QA8V5M96YT+T%D9')E<W-B;V]K(%-H;W<\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!)9B!B;&]C:VEN9R!I;6%G97,@9F]R(&EN;&EN92!(5$U,(&UE
M<W-A9V5S+"!S:&]U;&0@=V4@875T;VUA=&EC86QL>2!D:7-P;&%Y('1H96T@
M:6YS=&5A9"!I9B!T:&4@<V5N9&5R(&%P<&5A<G,@:6X@>6]U<B!A9&1R97-S
M8F]O:S\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+6UA:6QB;WA?<W1A<G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EL8F]X(%-T87)T(%!A9V4\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!$971E<FUI;F5S('=H:6-H('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE
M=R!W:6QL(&)E(&1I<W!L87EE9"!W:&5N('EO=2!A8V-E<W,@82!M86EL8F]X
M(&9O<B!T:&4@9FER<W0@=&EM92X@3F]T92!T:&%T('1H92`G=6YS965N)R!M
M97-S86=E(&]P=&EO;G,@9&\@;F]T('=O<FL@=VET:"!T:&4@)U1H<F5A9"<@
M<V]R=&EN9R!O<'1I;VX@+2!I;G-T96%D+"!Y;W4@=VEL;"!B92!S96YT('1O
M('1H92!L87-T('!A9V4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUS879E7V%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y0<F5F97)E;F-E<SH@4V%V92!!='1A8VAM96YT<R!O;B!396YT
M($UE<W-A9V5S/"]T:71L93X*("`@(#QP87)A/@H@("`@268@<V%V:6YG(&$@
M8V]M<&]S960@;65S<V%G92!I;B!A('-E;G0M;6%I;"!F;VQD97(L(&1E=&5R
M;6EN92!I9B!A;&P@871T86-H;65N="!D871A(&ES('-A=F5D+B!4:&4@9F]L
M;&]W:6YG(&]P=&EO;G,@87)E(&%V86EL86)L93H*("`@(#PO<&%R83X*"B`@
M("`\<&%R83XJ(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P
M<F]M<'0@=&\@<V%V92!A='1A8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@
M=&AE(&%T=&%C:&UE;G1S(&%R92!!3%=!65,@<V%V960@=VET:"!T:&4@;65S
M<V%G92X\+W!A<F$^"B`@("`@/'!A<F$^*B`B4')O;7!T(&5V97)Y('1I;64@
M86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4R(@+2!!3%=!
M65,@<')O;7!T('1O('-A=F4@871T86-H;65N=',@:6X@=&AE(&-O;7!O<V4@
M<V-R965N.R!T:&4@9&5F875L="!I<R!T;R!S879E(&%T=&%C:&UE;G1S+CPO
M<&%R83X*("`@("`\<&%R83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A
M8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B("T@04Q705E3('!R;VUP
M="!T;R!S879E(&%T=&%C:&UE;G1S(&EN('1H92!C;VUP;W-E('-C<F5E;CL@
M=&AE(&1E9F%U;'0@:7,@=&\@;F]T('-A=F4@871T86-H;65N=',N/"]P87)A
M/@H@("`@(#QP87)A/BH@(DYE=F5R('-A=F4@871T86-H;65N=',B("T@3D56
M15(@<')O;7!T('1O('-A=F4@871T86-H;65N=',@:6X@8V]M<&]S92!S8W)E
M96X[('1H92!A='1A8VAM96YT<R!A<F4@3D5615(@<V%V960@=VET:"!T:&4@
M;65S<V%G92X\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L
M7VEN8F]X(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E
M<G,Z(%9I<G1U86P@26YB;W@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)U
M=&%L($EN8F]X(&ES(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I
M=&@@=&AE(&YE960@=&\@<V5A<F-H(&5V97)Y(&UA:6QB;W@@9F]R(&UE<W-A
M9V5S(&UA<FME9"!A<R!N97<N("!);G-T96%D+"!A;&P@8W5R<F5N=&QY('-U
M8G-C<FEB960@;6%I;&)O>&5S(&%R92!S96%R8VAE9"!F;W(@;F5W(&UE<W-A
M9V5S(&%N9"!T:&4@<F5S=6QT<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN9VQE
M(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V
M:7)T=6%L7W1R87-H(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L
M($9O;&1E<G,Z(%9I<G1U86P@5')A<V@\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!6:7)T=6%L(%1R87-H(&ES(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A
M=V%Y('=I=&@@=&AE(&YE960@9F]R(&$@<V5P87)A=&4@5')A<V@@9F]L9&5R
M+B`@26YS=&5A9"!O9B!M;W9I;F<@;65S<V%G97,@=&\@82!C96YT<F%L:7IE
M9"!T<F%S:"!F;VQD97(L(&UE<W-A9V5S(&%R92!S:6UP;'D@;6%R:V5D(&%S
M(&1E;&5T960@:6X@=&AE(&-U<G)E;G0@9F]L9&5R('1H97D@;&EV92!I;BX@
M(%=H96X@)W-H;W<@9&5L971E9"!M97-S86=E<R<@:7,@='5R;F5D(&]F9BP@
M=&AI<R!R97-U;'1S(&EN('1H97-E(&UE<W-A9V5S(&YO="!A<'!E87)I;F<@
M:6X@82!M86EL8F]X('9I97<N("!7:&5N(&$@=7-E<B!C;&EC:W,@;VX@5FER
M='5A;"!4<F%S:"P@*F%L;"H@;6%I;&)O>&5S(&%L;"!S96%R8VAE9"!F;W(@
M;65S<V%G97,@=&AA="!A<F4@9FQA9V=E9"!D96QE=&5D(&%N9"!T:&5S92!M
M97-S86=E<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+VQO8V%L92]N;%].3"\`````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,3<T-3,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VYL7TY,+TQ#7TU%4U-!1T53
M+P``````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S8S`#`R,3(T,``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O
M;FQ?3DPO3$-?34534T%'15,O:6UP+FUO````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`U-S`R-C(`,3`T,3<S-C(W-C,`,#(R,S<S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````^`D``!P```#<3P``
M3PT``)R?````````V-0```H```#9U```"@```.34```*````[]0```X```#Z
MU```#P````G5```(````&=4```P````BU0``"@```"_5```$````.M4```0`
M```_U0```0```$35```9````1M4```P```!@U0``2````&W5```K````MM4`
M`$0```#BU0``)P```"?6```7````3]8```\```!GU@``"P```'?6```.````
M@]8```4```"2U@``*````)C6```*````P=8``!4```#,U@``$@```.+6```R
M````]=8```L````HUP``*0```#37```R````7M<``!````"1UP``%````*+7
M```0````M]<``"8```#(UP``)P```._7```F````%]@``!P````^V```#@``
M`%O8```*````:M@```T```!UV```)P```(/8```@````J]@```X```#,V```
M%P```-O8```B````\]@``#4````6V0``$0```$S9```-````7MD```P```!L
MV0``#0```'G9```&````A]D``!L```".V0``+@```*K9```W````V=D``'P`
M```1V@``;````([:```<````^]H``!T````8VP``#P```#;;```8````1ML`
M``P```!?VP``10```&S;```H````LML``$$```#;VP``)````!W<```.````
M0MP```\```!1W```#@```&'<```.````<-P```@```!_W```#@```(C<```.
M````E]P``"X```"FW```&@```-7<```S````\-P``%$````DW0``,@```';=
M```X````J=T``%0```#BW0``40```#?>``!:````B=X``%<```#DW@``-```
M`#S?```*````<=\```4```!\WP```P```(+?```&````AM\``!$```"-WP``
M"````)_?```)````J-\```D```"RWP``#@```+S?```(````R]\``"4```#4
MWP``(````/K?```0````&^````\````LX```#P```#S@```*````3.````<`
M``!7X````P```%_@```/````8^```!0```!SX```"0```(C@```-````DN``
M`!(```"@X```#P```+/@```*````P^````\```#.X```"````-[@```*````
MY^```"0```#RX```%P```!?A```4````+^$``!8```!$X0``"````%OA```<
M````9.$``!D```"!X0``*````)OA```>````Q.$``!H```#CX0``+````/[A
M```@````*^(``#(```!,X@``!P```'_B```,````A^(```T```"4X@``+```
M`*+B```.````S^(```,```#>X@``"P```.+B```'````[N(```<```#VX@``
M!0```/[B```%````!.,```H````*XP```P```!7C```7````&>,```H````Q
MXP``#P```#SC```.````3.,``$X```!;XP``4````*KC``!#````^^,``$(`
M```_Y```,````(+D```8````L^0``",```#,Y```#@```/#D```4````_^0`
M`!<````4Y0``%P```"SE```7````1.4``!,```!<Y0``#P```'#E```C````
M@.4```8```"DY0``%P```*OE```.````P^4``%$```#2Y0``'P```"3F```U
M````1.8```<```!ZY@``!@```(+F```(````B>8```\```"2Y@``!@```*+F
M```(````J>8``!$```"RY@``"@```,3F```3````S^8```L```#CY@``%0``
M`._F```-````!><``!,````3YP``(P```"?G```O````2^<``!4```![YP``
M!P```)'G```%````F><``!4```"?YP``$0```+7G```,````Q^<``#````#4
MYP``2`````7H```A````3N@``#L```!PZ```.P```*SH```\````Z.@``"L`
M```EZ0``,0```%'I```[````@^D``#D```"_Z0``-0```/GI```)````+^H`
M``<````YZ@``%````$'J```,````5NH```,```!CZ@``!0```&?J```)````
M;>H``!````!WZ@``"0```(CJ```3````DNH```,```"FZ@``.0```*KJ```2
M````Y.H```8```#WZ@``#````/[J```U````"^L```X```!!ZP``20```%#K
M```S````FNL```H```#.ZP``+0```-GK```+````!^P``"<````3[```+```
M`#OL```J````:.P``"4```"3[```"0```+GL```)````P^P```H```#-[```
M!@```-CL```)````W^P```<```#I[```+P```/'L```W````(>T``"X```!9
M[0``50```(CM```M````WNT``"P````,[@``+0```#GN```M````9^X``$``
M``"5[@``(P```-;N```C````^NX``"T````>[P``,P```$SO```5````@.\`
M`!D```"6[P``*0```+#O```D````VN\``%````#_[P``&````%#P```1````
M:?```!$```![\```"@```(WP```,````F/````L```"E\```"@```+'P```*
M````O/```!````#'\```%@```-CP```6````[_````<````&\0``!P````[Q
M```4````%O$```H````K\0``"````#;Q```(````/_$```,```!(\0``!P``
M`$SQ```'````5/$```8```!<\0``.````&/Q```%````G/$```<```"B\0``
M!@```*KQ```(````L?$```D```"Z\0``*0```,3Q```.````[O$```H```#]
M\0``10````CR```$````3O(```0```!3\@``!P```%CR```)````8/(```8`
M``!J\@``$0```''R```'````@_(``!8```"+\@``!````*+R```G````I_(`
M``@```#/\@``!@```-CR```-````W_(```8```#M\@``'@```/3R```1````
M$_,```@````E\P``#0```"[S```,````//,```<```!)\P```P```%'S```#
M````5?,``!<```!9\P``$P```''S```(````A?,```@```".\P``!````)?S
M```(````G/,```@```"E\P``*@```*[S```K````V?,``%,````%]```00``
M`%GT```@````F_0```8```"\]```!@```,/T```.````RO0``!4```#9]```
M/@```._T```8````+O4``"(```!']0``+@```&KU```=````F?4``"$```"W
M]0``5````-GU```I````+O8```H```!8]@``!P```&/V```5````:_8```X`
M``"!]@```@```)#V```*````D_8```\```">]@``#0```*[V```/````O/8`
M``T```#,]@``"0```-KV```4````Y/8```8```#Y]@``&`````#W```=````
M&?<``!,````W]P``%````$OW```$````8/<```P```!E]P``!@```'+W```*
M````>?<```T```"$]P``8@```)+W```G````]?<``%0````=^```7P```'+X
M```$````TO@``!8```#7^```#@```.[X```<````_?@```\````:^0``,P``
M`"KY```H````7OD```4```"'^0``!0```(WY```;````D_D``!H```"O^0``
M#@```,KY```5````V?D``!$```#O^0``$0````'Z```1````$_H``!P````E
M^@``*@```$+Z```U````;?H``$4```"C^@``$````.GZ```A````^OH```4`
M```<^P``$P```"+[```2````-OL```H```!)^P``#P```%3[``!'````9/L`
M`!\```"L^P``)0```,S[```S````\OL``"L````F_```-0```%+\```=````
MB/P``%$```"F_```$0```/C\```Q````"OT``#L````\_0``$P```'C]``!`
M````C/T``#@```#-_0``!0````;^```,````#/X``!$````9_@``#0```"O^
M```&````.?X```8```!`_@``%P```$?^```(````7_X```P```!H_@``%```
M`'7^```/````BOX``!$```":_@``"````*S^```%````M?X``!$```"[_@``
M#````,W^```0````VOX```4```#K_@``#0```/'^```&````__X```<````&
M_P``#0````[_```'````'/\```L````D_P``!P```##_```'````./\```D`
M``!`_P``%P```$K_```F````8O\``$\```")_P``"0```-G_```*````X_\`
M`!D```#N_P``#`````@``0`E````%0`!`!\````[``$`$````%L``0`%````
M;``!`"4```!R``$`$@```)@``0`3````JP`!`"L```"_``$`.P```.L``0`@
M````)P$!`!L```!(`0$`-@```&0!`0`(````FP$!`!L```"D`0$`'@```,`!
M`0!<````WP$!`"X````\`@$`#````&L"`0`&````>`(!``0```!_`@$`#@``
M`(0"`0`.````DP(!``<```"B`@$`#@```*H"`0`*````N0(!``T```#$`@$`
M'@```-("`0`;````\0(!`"$````-`P$`'@```"\#`0`9````3@,!`!X```!H
M`P$`&P```(<#`0`F````HP,!`"0```#*`P$`&P```.\#`0`>````"P0!`!P`
M```J!`$`)@```$<$`0`V````;@0!`#,```"E!`$`*0```-D$`0!!`````P4!
M`#H```!%!0$`)@```(`%`0`K````IP4!`#@```#3!0$`+P````P&`0`2````
M/`8!`"D```!/!@$`$@```'D&`0"B````C`8!`!8````O!P$`(P```$8'`0`H
M````:@<!`"D```"3!P$`*````+T'`0`?````Y@<!`"`````&"`$`)0```"<(
M`0`A````30@!`!P```!O"`$`)@```(P(`0!!````LP@!``P```#U"`$`!P``
M``()`0`'````"@D!``8````2"0$`#0```!D)`0`+````)PD!`!4````S"0$`
M#0```$D)`0`:````5PD!`!````!R"0$`'0```(,)`0`9````H0D!`%T```"[
M"0$`$@```!D*`0`3````+`H!`!(```!`"@$`!P```%,*`0`$````6PH!``P`
M``!@"@$`#@```&T*`0`/````?`H!`!0```","@$`$P```*$*`0`-````M0H!
M`#D```##"@$`'````/T*`0`H````&@L!``,```!#"P$`#0```$<+`0`&````
M50L!`!$```!<"P$`%P```&X+`0`;````A@L!``X```"B"P$``@```+$+`0`%
M````M`L!``4```"Z"P$`$````,`+`0`$````T0L!``T```#6"P$`#@```.0+
M`0`#````\PL!``X```#W"P$`"`````8,`0`/````#PP!``@````?#`$`#P``
M`"@,`0`-````.`P!`!````!&#`$`&0```%<,`0`:````<0P!``L```",#`$`
M"0```)@,`0`&````H@P!`!0```"I#`$`$P```+X,`0`0````T@P!``P```#C
M#`$`$0```/`,`0`5`````@T!`!D````8#0$`"P```#(-`0`-````/@T!`"(`
M``!,#0$`*P```&\-`0`7````FPT!`#0```"S#0$`,P```.@-`0`*````'`X!
M`!@````G#@$`&0```$`.`0`6````6@X!``<```!Q#@$`$````'D.`0`<````
MB@X!`!P```"G#@$`#0```,0.`0`'````T@X!``P```#:#@$`)@```.<.`0`*
M````#@\!`!0````9#P$`"P```"X/`0`'````.@\!`"(```!"#P$`+P```&4/
M`0`+````E0\!``D```"A#P$`&0```*L/`0`+````Q0\!``\```#1#P$`%P``
M`.$/`0`7````^0\!``D````1$`$`!P```!L0`0`6````(Q`!``\````Z$`$`
M+0```$H0`0`6````>!`!``X```"/$`$`&@```)X0`0`H````N1`!``L```#B
M$`$`&````.X0`0`(````!Q$!``P````0$0$`(P```!T1`0`-````01$!`"8`
M``!/$0$`*@```'81`0`@````H1$!`$,```#"$0$`"`````82`0`2````#Q(!
M``0````B$@$`"````"<2`0`+````,!(!`!H````\$@$`)P```%<2`0`2````
M?Q(!`"````"2$@$`+P```+,2`0`7````XQ(!``4```#[$@$`#`````$3`0`.
M````#A,!``X````=$P$`!0```"P3`0`&````,A,!``X````Y$P$``P```$@3
M`0`K````3!,!``<```!X$P$`!````(`3`0`.````A1,!``H```"4$P$`#```
M`)\3`0`*````K!,!``\```"W$P$`$````,<3`0`7````V!,!`!,```#P$P$`
M)0````04`0`.````*A0!`!$````Y%`$`%P```$L4`0`3````8Q0!`!8```!W
M%`$`.````(X4`0`3````QQ0!``D```#;%`$`!0```.44`0`+````ZQ0!``H`
M``#W%`$``@````(5`0`%````!14!``T````+%0$`&P```!D5`0`7````-14!
M``D```!-%0$`'0```%<5`0`/````=14!`!(```"%%0$`#````)@5`0`.````
MI14!``T```"T%0$`$@```,(5`0`9````U14!`!P```#O%0$`.`````P6`0`8
M````118!`"````!>%@$`$P```'\6`0`#````DQ8!`!4```"7%@$`"P```*T6
M`0`3````N18!``@```#-%@$`#@```-86`0`0````Y18!`'L```#V%@$`&```
M`'(7`0`I````BQ<!`"P```"U%P$`*````.(7`0`U````"Q@!`!$```!!&`$`
M!P```%,8`0`%````6Q@!`!@```!A&`$`&0```'H8`0`'````E!@!``@```"<
M&`$`!@```*48`0`&````K!@!`!L```"S&`$`$````,\8`0`/````X!@!`!``
M``#P&`$`#P````$9`0`+````$1D!``\````=&0$`#````"T9`0`/````.AD!
M``<```!*&0$`!@```%(9`0`*````61D!`!(```!D&0$`#0```'<9`0`,````
MA1D!`$,```"2&0$`/0```-89`0`)````%!H!``P````>&@$`*````"L:`0`/
M````5!H!``@```!D&@$`"````&T:`0`3````=AH!`!X```"*&@$`(0```*D:
M`0`@````RQH!`!D```#L&@$`%P````8;`0`E````'AL!`!<```!$&P$`!```
M`%P;`0`;````81L!``T```!]&P$``P```(L;`0`(````CQL!``H```"8&P$`
M#````*,;`0`*````L!L!`"````"[&P$`'P```-P;`0`+````_!L!`!L````(
M'`$`"P```"0<`0`(````,!P!``0````Y'`$`!````#X<`0`3````0QP!`!0`
M``!7'`$`#````&P<`0`)````>1P!``X```"#'`$`"P```)(<`0`;````GAP!
M``X```"Z'`$`#P```,D<`0`E````V1P!`"H```#_'`$`!P```"H=`0`2````
M,AT!`!L```!%'0$`!````&$=`0`'````9AT!``H```!N'0$`$@```'D=`0`*
M````C!T!``T```"7'0$`"0```*4=`0`$````KQT!``4```"T'0$`"````+H=
M`0`#````PQT!`!@```#''0$`$````.`=`0`.````\1T!`!X`````'@$`&@``
M`!\>`0`*````.AX!``0```!%'@$`)@```$H>`0`.````<1X!`'P```"`'@$`
M%0```/T>`0!$````$Q\!``4```!8'P$`!P```%X?`0`,````9A\!``@```!S
M'P$`"@```'P?`0`&````AQ\!``<```".'P$`"````)8?`0`1````GQ\!`!D`
M``"Q'P$`"````,L?`0`"````U!\!``8```#7'P$`!@```-X?`0`4````Y1\!
M`!4```#Z'P$`#P```!`@`0`1````("`!`!H````R(`$`#0```$T@`0`0````
M6R`!`!L```!L(`$`!0```(@@`0`$````CB`!``P```"3(`$`"0```*`@`0`0
M````JB`!``D```"[(`$`"0```,4@`0`$````SR`!``4```#4(`$`&@```-H@
M`0`%````]2`!`!H```#[(`$`"````!8A`0`&````'R$!``\````F(0$`&0``
M`#8A`0`.````4"$!``<```!?(0$`!P```&<A`0`B````;R$!``4```"2(0$`
M"0```)@A`0`*````HB$!``T```"M(0$`!@```+LA`0`-````PB$!``P```#0
M(0$`"0```-TA`0`&````YR$!`!(```#N(0$`"0````$B`0`'````"R(!`!0`
M```3(@$`'0```"@B`0`&````1B(!``H```!-(@$`!````%@B`0`)````72(!
M``@```!G(@$`$0```'`B`0`)````@B(!``8```",(@$`#0```),B`0`&````
MH2(!``0```"H(@$`!````*TB`0`7````LB(!`#D```#*(@$`/0````0C`0`Z
M````0B,!`!X```!](P$`!0```)PC`0`.````HB,!``0```"Q(P$`!@```+8C
M`0`'````O2,!`"$```#%(P$`%0```.<C`0`&````_2,!``0````$)`$`$0``
M``DD`0`&````&R0!``H````B)`$`(@```"TD`0`G````4"0!``8```!X)`$`
M%0```'\D`0`,````E20!`!$```"B)`$`!````+0D`0`-````N20!``<```#'
M)`$`!0```,\D`0`=````U20!``0```#S)`$`#````/@D`0`*````!24!``@`
M```0)0$`"0```!DE`0`%````(R4!`#H````I)0$`,````&0E`0`U````E24!
M`"D```#+)0$`1P```/4E`0`X````/28!`"D```!V)@$`/P```*`F`0`N````
MX"8!`"T````/)P$`'P```#TG`0`/````72<!`!(```!M)P$`"P```(`G`0`F
M````C"<!`"<```"S)P$`*0```-LG`0`D````!2@!`"8````J*`$`*````%$H
M`0`(````>B@!``H```"#*`$`"0```(XH`0`'````F"@!``0```"@*`$`'```
M`*4H`0`@````PB@!`"````#C*`$`)@````0I`0`-````*RD!`"<````Y*0$`
M&P```&$I`0`,````?2D!`!8```"**0$`!0```*$I`0`*````IRD!`!D```"R
M*0$`*0```,PI`0`6````]BD!`!(````-*@$`!P```"`J`0`*````*"H!``\`
M```S*@$`$````$,J`0!`````5"H!`'````"5*@$`9@````8K`0`&````;2L!
M``H```!T*P$`#@```'\K`0`)````CBL!``H```"8*P$`$@```*,K`0`3````
MMBL!``P```#**P$`!@```-<K`0`&````WBL!``H```#E*P$`#@```/`K`0`.
M````_RL!`!\````.+`$`'@```"XL`0`C````32P!`!$```!Q+`$`%0```(,L
M`0`8````F2P!`!$```"R+`$`$````,0L`0`C````U2P!``\```#Y+`$`"0``
M``DM`0`2````$RT!`!T````F+0$`$@```$0M`0`0````5RT!``H```!H+0$`
M$0```',M`0`%````A2T!`#$```"++0$`)````+TM`0`<````XBT!`",```#_
M+0$`:@```",N`0`/````CBX!``4```">+@$`$````*0N`0`)````M2X!``0`
M``"_+@$`"P```,0N`0`<````T"X!`",```#M+@$`(@```!$O`0`&````-"\!
M`!0````[+P$`%P```%`O`0`,````:"\!`"0```!U+P$`(P```)HO`0`:````
MOB\!``P```#9+P$`#P```.8O`0`5````]B\!`"D````,,`$`*@```#8P`0`F
M````83`!`"<```"(,`$`*0```+`P`0`J````VC`!`!D````%,0$`0@```!\Q
M`0`1````8C$!`!(```!T,0$`$P```(<Q`0`4````FS$!``\```"P,0$`%@``
M`,`Q`0`7````US$!`!````#O,0$`$0`````R`0`T````$C(!`!,```!',@$`
M$@```%LR`0`U````;C(!`!0```"D,@$`!P```+DR`0`,````P3(!`"L```#.
M,@$`#P```/HR`0`6````"C,!`"`````A,P$`%````$(S`0`1````5S,!`"@`
M``!I,P$`%P```)(S`0`<````JC,!`!,```#',P$`"P```-LS`0`1````YS,!
M`!H```#Y,P$`'@```!0T`0`:````,S0!`"$```!.-`$`(````'`T`0`1````
MD30!`!0```"C-`$`%P```+@T`0`5````T#0!``D```#F-`$`!@```/`T`0`9
M````]S0!``0````1-0$`!P```!8U`0`+````'C4!`!$````J-0$`!@```#PU
M`0`&````0S4!``8```!*-0$`!0```%$U`0`'````5S4!``<```!?-0$`!0``
M`&<U`0`6````;34!``8```"$-0$`!@```(LU`0`$````DC4!``0```"7-0$`
M!P```)PU`0`.````I#4!``P```"S-0$`#````,`U`0`-````S34!``(```#;
M-0$`"@```-XU`0`.````Z34!``4```#X-0$`*````/XU`0`.````)S8!``P`
M```V-@$`#P```$,V`0`*````4S8!``@```!>-@$`"0```&<V`0`K````<38!
M`"X```"=-@$`!````,PV`0`(````T38!`"8```#:-@$`$@````$W`0`/````
M%#<!``8````D-P$`"@```"LW`0`'````-C<!``@````^-P$`(````$<W`0`)
M````:#<!`!$```!R-P$`"0```(0W`0`,````CC<!``T```";-P$`#@```*DW
M`0`6````N#<!`!$```#/-P$`!@```.$W`0`#````Z#<!``8```#L-P$`&0``
M`/,W`0`'````#3@!``0````5.`$`"P```!HX`0`+````)C@!``<````R.`$`
M$0```#HX`0`'````3#@!`!8```!4.`$`#0```&LX`0`-````>3@!``H```"'
M.`$`$````)(X`0`/````HS@!`!$```"S.`$`%P```,4X`0`*````W3@!`!$`
M``#H.`$`"````/HX`0`$`````SD!``\````(.0$`.@```!@Y`0`A````4SD!
M``4```!U.0$`#````'LY`0`>````B#D!``X```"G.0$`$````+8Y`0`+````
MQSD!`'P```#3.0$`#````%`Z`0`)````73H!``<```!G.@$`"@```&\Z`0`)
M````>CH!``X```"$.@$`$````),Z`0`5````I#H!`!H```"Z.@$`"@```-4Z
M`0`)````X#H!``H```#J.@$`#@```/4Z`0`,````!#L!``\````1.P$`"```
M`"$[`0`&````*CL!``P````Q.P$`!P```#X[`0`%````1CL!``L```!,.P$`
M1P```%@[`0`-````H#L!``D```"N.P$`!````+@[`0`#````O3L!``P```#!
M.P$`$P```,X[`0`3````XCL!`!,```#V.P$`!@````H\`0`*````$3P!``(`
M```</`$`!````!\\`0`E````)#P!``,```!*/`$`!0```$X\`0`J````5#P!
M``X```!_/`$`"@```(X\`0`%````F3P!``0```"?/`$`"@```*0\`0`-````
MKSP!`!\```"]/`$`!P```-T\`0`B````Y3P!``T````(/0$`!@```!8]`0`(
M````'3T!``@````F/0$`!````"\]`0`%````-#T!`&@````Z/0$`"0```*,]
M`0`,````K3T!``4```"Z/0$`!@```,`]`0`C````QST!`"4```#K/0$`"```
M`!$^`0`W````&CX!`"(```!2/@$`$P```'4^`0`;````B3X!`"\```"E/@$`
M$````-4^`0`*````YCX!`!$```#Q/@$`#P````,_`0`/````$S\!``H````C
M/P$`"0```"X_`0`3````.#\!`!L```!,/P$`&````&@_`0`7````@3\!`!<`
M``"9/P$`#@```+$_`0`F````P#\!`"8```#G/P$``P````Y``0`'````$D`!
M``@````:0`$`%````"-``0`3````.$`!`!````!,0`$`#0```%U``0`.````
M:T`!`!8```!Z0`$`!P```)%``0`0````F4`!``H```"J0`$`"P```+5``0`'
M````P4`!`!,```#)0`$`#````-U``0`/````ZD`!``X```#Z0`$`#`````E!
M`0`.````%D$!`%$````E00$`#P```'=!`0`0````AT$!``T```"800$`#P``
M`*9!`0`/````MD$!``\```#&00$`(````-9!`0`N````]T$!`!H````F0@$`
M#````$%"`0`F````3D(!``L```!U0@$`#0```(%"`0`:````CT(!`$H```"J
M0@$`!@```/5"`0`&````_$(!``8````#0P$`'P````I#`0`&````*D,!``D`
M```Q0P$`&````#M#`0`7````5$,!``8```!L0P$`#0```'-#`0`B````@4,!
M`%<```"D0P$`$P```/Q#`0`C````$$0!`!,````T1`$``@```$A$`0`+````
M2T0!``@```!71`$`#0```&!$`0`&````;D0!``H```!U1`$`!P```(!$`0`4
M````B$0!``8```"=1`$`"````*1$`0`.````K40!``<```"\1`$`"@```,1$
M`0`+````ST0!``<```#;1`$`#````.-$`0`-````\$0!``P```#^1`$`!```
M``M%`0`)````$$4!``D````:10$`"@```"1%`0`'````+T4!``D````W10$`
M#@```$%%`0`'````4$4!``H```!810$`&P```&-%`0`5````?T4!`!(```"5
M10$`"@```*A%`0`)````LT4!`!````"]10$`!P```,Y%`0`2````UD4!``0`
M``#I10$`!````.Y%`0`B````\T4!``<````61@$`!0```!Y&`0`,````)$8!
M``4````Q1@$`"P```#=&`0`4````0T8!`!$```!81@$`&@```&I&`0`6````
MA48!`!0```"<1@$`%P```+%&`0`8````R48!`!P```#B1@$`&0```/]&`0`'
M````&4<!``4````A1P$`%@```"='`0`#````/D<!``T```!"1P$`#````%!'
M`0`*````74<!``@```!H1P$`"````'%'`0`7````>D<!``L```"21P$`#```
M`)Y'`0`3````JT<!``0```"_1P$`"@```,1'`0`$````ST<!``P```#41P$`
M"0```.%'`0`,````ZT<!``D```#X1P$`!0````)(`0`'````"$@!``4````0
M2`$`!````!9(`0`"````&T@!`!0````>2`$`#0```#-(`0`2````04@!``L`
M``!42`$`&P```&!(`0`?````?$@!`!0```"<2`$`'@```+%(`0`5````T$@!
M`#@```#F2`$`+````!])`0`2````3$D!`"D```!?20$`,@```(E)`0`*````
MO$D!`"P```#'20$`+@```/1)`0`S````(TH!`#,```!72@$`.````(M*`0`/
M````Q$H!`!@```#42@$`$````.U*`0`3````_DH!`"H````22P$`&0```#U+
M`0`<````5TL!`!\```!T2P$`$P```)1+`0`4````J$L!`!0```"]2P$`(```
M`-)+`0`2````\TL!`!0````&3`$`%0```!M,`0`M````,4P!`"T```!?3`$`
M,0```(U,`0`N````OTP!`"\```#N3`$`+````!Y-`0!B````2TT!`!,```"N
M30$`)0```,)-`0`D````Z$T!`"D````-3@$`"````#=.`0`(````0$X!`"0`
M``!)3@$`$@```&Y.`0`.````@4X!`"L```"03@$`$@```+Q.`0`A````STX!
M`!H```#Q3@$`"0````Q/`0!%````%D\!`$$```!<3P$`#P```)Y/`0`$````
MKD\!`!,```"S3P$`%````,=/`0`.````W$\!``8```#K3P$`$P```/)/`0`8
M````!E`!``8````?4`$`"0```"90`0`*````,%`!``L````[4`$`"0```$=0
M`0`-````45`!``P```!?4`$`#P```&Q0`0`7````?%`!`!0```"44`$`$```
M`*E0`0`6````NE`!``<```#14`$`#@```-E0`0`A````Z%`!``4````*40$`
M&P```!!1`0`(````+%$!``8````U40$`%````#Q1`0`1````45$!`$0```!C
M40$`/````*A1`0`.````Y5$!`#@```#T40$``@```"U2`0`"````,%(!``8`
M```S4@$`#@```#I2`0`%````25(!``<```!/4@$`#@```%=2`0`&````9E(!
M``P```!M4@$`(P```'I2`0`$````GE(!`"D```"C4@$`,@```,U2`0`7````
M`%,!`!\````84P$`,P```#A3`0!<````;%,!`!0```#)4P$`/@```-Y3`0`-
M````'50!`!\````K5`$`$````$M4`0`4````7%0!``<```!Q5`$`#@```'E4
M`0`,````B%0!``P```"55`$`$P```*)4`0`*````ME0!`!T```#!5`$`&0``
M`-]4`0`%````^50!`!$```#_5`$`$P```!%5`0`-````)54!`!$````S50$`
M)````$55`0`#````:E4!`!4```!N50$`$P```(15`0`2````F%4!``L```"K
M50$`-````+=5`0`+````[%4!`!0```#X50$`/@````U6`0`.````3%8!`!,`
M``!;5@$`-````&]6`0`Q````I%8!`!(```#65@$`$````.E6`0`8````^E8!
M`!D````35P$`(P```"U7`0`B````45<!`"<```!T5P$`5@```)Q7`0!-````
M\U<!``@```!!6`$`"0```$I8`0`-````5%@!``H```!B6`$`"P```&U8`0`$
M````>5@!`!P```!^6`$`#0```)M8`0`G````J5@!`!L```#16`$`#````.U8
M`0`*````^E@!``<````%60$`#0````U9`0`B````&UD!`"$````^60$`"```
M`&!9`0`%````:5D!`!\```!O60$`!@```(]9`0`0````EED!``@```"G60$`
M!P```+!9`0`-````N%D!``H```#&60$`$@```-%9`0`A````Y%D!``L````&
M6@$`'````!):`0`8````+UH!``@```!(6@$`$@```%%:`0`L````9%H!`!H`
M``"16@$`"0```*Q:`0`*````MEH!`!4```#!6@$`!0```-=:`0`4````W5H!
M``0```#R6@$`$````/=:`0`&````"%L!``<````/6P$`'@```!=;`0`H````
M-EL!``H```!?6P$`&@```&I;`0`M````A5L!``@```"S6P$`%````+Q;`0`L
M````T5L!`"<```#^6P$`*P```"9<`0`J````4EP!``0```!]7`$`!````()<
M`0`+````AUP!``4```"37`$`!@```)E<`0`(````H%P!``8```"I7`$`,0``
M`+!<`0`<````XEP!``H```#_7`$`&P````I=`0`T````)ET!`#0```!;70$`
M(````)!=`0`I````L5T!`"<```#;70$`(`````->`0!!````)%X!`!H```!F
M7@$`*````(%>`0`:````JEX!`'8```#%7@$`>0```#Q?`0`<`0``ME\!`"@`
M``#38`$`'0```/Q@`0`I````&F$!`!T```!$80$`+@```&)A`0!7````D6$!
M`#8```#I80$`+````"!B`0`L````36(!`#$```!Z8@$`+@```*QB`0`B````
MVV(!``8```#^8@$`"`````5C`0`%````#F,!``@````48P$`&0```!UC`0`9
M````-V,!`"H```!18P$`$````'QC`0`K````C6,!`",```"Y8P$`(0```-UC
M`0`N````_V,!`#0````N9`$`"````&-D`0`7````;&0!``H```"$9`$`!P``
M`(]D`0`A````EV0!`!````"Y9`$`#0```,ID`0`0````V&0!``4```#I9`$`
M#@```.]D`0`(````_F0!``L````'90$`%````!-E`0`'````*&4!`!,````P
M90$`"````$1E`0`V````364!`#<```"$90$`"P```+QE`0`)````R&4!``H`
M``#290$`%````-UE`0`O````\F4!`#(````B9@$`"P```%5F`0`.````868!
M``T```!P9@$`#P```'YF`0`6````CF8!`#X```"E9@$`)P```.1F`0`%````
M#&<!``4````29P$`)P```!AG`0`?````0&<!`!8```!@9P$`%P```'=G`0`/
M````CV<!``0```"?9P$`"@```*1G`0`)````KV<!``L```"Y9P$`#@```,5G
M`0`%````U&<!`!X```#:9P$`!````/EG`0`-````_F<!`#(````,:`$`10``
M`#]H`0`+````A6@!``X```"1:`$`#@```*!H`0`)````KV@!``@```"Y:`$`
M$````,)H`0`5````TV@!`!,```#I:`$`%P```/UH`0`'````%6D!`!X````=
M:0$`%0```#QI`0`4````4FD!``4```!G:0$`%````&UI`0`&````@FD!``L`
M``"):0$`!P```)5I`0`C````G6D!`!8```#!:0$`#P```-AI`0`.````Z&D!
M`"H```#W:0$`!@```")J`0`,````*6H!`!@````V:@$`#0```$]J`0`1````
M76H!``L```!O:@$`-@```'MJ`0`-````LFH!``H```#`:@$`(@```,MJ`0`+
M````[FH!``\```#Z:@$`$`````IK`0`N````&VL!`#H```!*:P$`#@```(5K
M`0`-````E&L!``4```"B:P$`"P```*AK`0`,````M&L!``T```#!:P$`#0``
M`,]K`0`.````W6L!``T```#L:P$`(````/IK`0`G````&VP!`"L```!#;`$`
M"````&]L`0`*````>&P!``8```"#;`$`$@```(IL`0`.````G6P!`!<```"L
M;`$`,@```,1L`0`>````]VP!`!8````6;0$`'````"UM`0`4````2FT!``4`
M``!?;0$`#@```&5M`0`3````=&T!`!H```"(;0$`!P```*-M`0`&````JVT!
M`!,```"R;0$`%````,9M`0`1````VVT!`$L```#M;0$`!P```#EN`0`4````
M06X!`!@```!6;@$`!P```&]N`0`%````=VX!``P```!];@$`#````(IN`0`2
M````EVX!``0```"J;@$`!P```*]N`0`*````MVX!``L```#";@$`#````,YN
M`0`.````VVX!``X```#J;@$`!0```/EN`0`%````_VX!`"X````%;P$`)@``
M`#1O`0`C````6V\!``,```!_;P$`$@```(-O`0`&````EF\!``8```"=;P$`
M'@```*1O`0`6````PV\!`!@```#:;P$`#@```/-O`0`W`````G`!``X````Z
M<`$`%P```$EP`0!!````87`!`#0```"C<`$`)0```-AP`0`5````_G`!`#$`
M```4<0$`$P```$9Q`0`;````6G$!`"H```!V<0$`40```*%Q`0!0````\W$!
M`"4```!$<@$`#0```&IR`0`)````>'(!``,```""<@$`!P```(9R`0`*````
MCG(!``@```"9<@$``@```*)R`0`0````I7(!``@```"V<@$`#````+]R`0`5
M````S'(!``L```#B<@$`&0```.YR`0`@````"',!`!(````I<P$`!0```#QS
M`0`*````0G,!`!4```!-<P$`$@```&-S`0`,````=G,!``0```"#<P$`!P``
M`(AS`0`R````D',!``H```##<P$`#````,YS`0`+````VW,!``<```#G<P$`
M%@```.]S`0!2````!G0!`#H```!9=`$`(````)1T`0`/````M70!`!<```#%
M=`$`.0```-UT`0`'````%W4!``8````?=0$`"0```"9U`0`.````,'4!``X`
M```_=0$`!````$YU`0`&````4W4!`!8```!:=0$`#````'%U`0`-````?G4!
M``X```",=0$`%0```)MU`0`2````L74!``\```#$=0$`%````-1U`0!#````
MZ74!``H````M=@$`&P```#AV`0`U````5'8!`!$```"*=@$`$````)QV`0`+
M````K78!`&D```"Y=@$`&@```"-W`0`7````/G<!`"<```!6=P$`&P```'YW
M`0`:````FG<!`!<```"U=P$`&P```,UW`0`9````Z7<!`!\````#>`$`%P``
M`"-X`0`<````.W@!`!<```!8>`$`#````'!X`0`3````?7@!``@```"1>`$`
M!P```)IX`0`(````HG@!`!````"K>`$`$0```+QX`0`)````SG@!`!4```#8
M>`$`#0```.YX`0`&````_'@!`!T````#>0$`!P```"%Y`0`3````*7D!``,`
M```]>0$`1@```$%Y`0!#````B'D!`#(```#,>0$`/P```/]Y`0`W````/WH!
M`%<```!W>@$`'P```,]Z`0`O````[WH!``H````?>P$`#0```"I[`0`2````
M.'L!`"D```!+>P$`"````'5[`0`-````?GL!`"T```",>P$`<````+I[`0`_
M````*WP!`#D```!K?`$`1@```*5\`0`$````['P!`!````#Q?`$`$`````)]
M`0`,````$WT!`!0````@?0$`'0```#5]`0`<````4WT!`!$```!P?0$`/0``
M`()]`0!/````P'T!`"4````0?@$`(````#9^`0`<````5WX!``L```!T?@$`
M)P```(!^`0`:````J'X!`!\```##?@$`'0```.-^`0`H`````7\!``\````J
M?P$`)0```#I_`0`@````8'\!`"0```"!?P$`)````*9_`0`@````RW\!`"4`
M``#L?P$`"P```!*``0`'````'H`!``T````F@`$`#````#2``0`%````08`!
M``8```!'@`$`.0```$Z``0`%````B(`!``P```".@`$`!P```)N``0`)````
MHX`!`!,```"M@`$`!@```,&``0`)````R(`!``0```#2@`$`$````->``0`(
M````Z(`!``@```#Q@`$`!````/J``0`+````_X`!``P````+@0$`$0```!B!
M`0`,````*H$!`!H````W@0$`#P```%*!`0`'````8H$!``T```!J@0$`#P``
M`'B!`0`,````B($!`!0```"5@0$`%````*J!`0`/````OX$!``X```#/@0$`
M$@```-Z!`0`4````\8$!``X````&@@$`#````!6"`0`;````(H(!`"P````^
M@@$`$P```&N"`0`<````?X(!`"@```"<@@$`!@```,6"`0`'````S((!`!,`
M``#4@@$`!0```.B"`0`$````[H(!``P```#S@@$`%P````"#`0`2````&(,!
M``L````K@P$`#0```#>#`0`4````18,!`"\```!:@P$`"@```(J#`0`,````
ME8,!``D```"B@P$`!@```*R#`0`)````LX,!``@```"]@P$`"0```,:#`0`%
M````T(,!``H```#6@P$`$0```.&#`0`&````\X,!``X```#Z@P$`#@````F$
M`0`-````&(0!``L````FA`$`$````#*$`0`=````0X0!`!$```!AA`$`"P``
M`'.$`0`"````?X0!``@```""A`$`!P```(N$`0`-````DX0!``8```"AA`$`
M%@```*B$`0`)````OX0!``<```#)A`$`.P```-&$`0`H````#84!`!4````V
MA0$`!0```$R%`0`+````4H4!``<```!>A0$`"````&:%`0`'````;X4!``4`
M``!WA0$`!P```'V%`0`.````A84!``D```"4A0$`!@```)Z%`0`(````I84!
M``L```"NA0$`!P```+J%`0`(````PH4!``<```#+A0$`%@```-.%`0`)````
MZH4!``8```#TA0$`&0```/N%`0`:````%88!`"`````PA@$`"P```%&&`0`<
M````788!`!0```!ZA@$`!P```(^&`0`(````EX8!``@```"@A@$`!0```*F&
M`0`0````KX8!`!````#`A@$`!@```-&&`0`9````V(8!``H```#RA@$`'```
M`/V&`0`'````&H<!``4````BAP$`!0```"B'`0`0````+H<!`!0````_AP$`
M"P```%2'`0`-````8(<!`!<```!NAP$`&@```(:'`0`4````H8<!`"\```"V
MAP$`"0```.:'`0`*````\(<!``<```#[AP$``@````.(`0`.````!H@!``@`
M```5B`$`'P```!Z(`0`C````/H@!`#$```!BB`$`.````)2(`0`;````S8@!
M`#$```#IB`$`,0```!N)`0`G````38D!`"(```!UB0$`(````)B)`0!D````
MN8D!`!T````>B@$`%````#R*`0!=````48H!`%4```"OB@$`.`````6+`0`M
M````/HL!`#,```!LBP$`2P```*"+`0!*````[(L!`%L````WC`$`*````).,
M`0`L````O(P!`#@```#IC`$`)0```"*-`0`H````2(T!`"P```!QC0$`)P``
M`)Z-`0`;````QHT!`!X```#BC0$`=0````&.`0`^````=XX!`$(```"VC@$`
M/0```/F.`0`I````-X\!`"D```!ACP$`,0```(N/`0`^````O8\!`"\```#\
MCP$`J0$``"R0`0`C````UI$!`$\```#ZD0$`%P```$J2`0!(````8I(!`#8`
M``"KD@$`/@```.*2`0`P````(9,!`"````!2DP$`/P```'.3`0`T````LY,!
M`!T```#HDP$`'@````:4`0`J````)90!`(4```!0E`$`,````-:4`0!!````
M!Y4!`&````!)E0$`6P```*J5`0!)````!I8!`#0```!0E@$`/````(66`0`X
M````PI8!`!T```#[E@$`&````!F7`0"G````,I<!`"$```#:EP$`'P```/R7
M`0`D````')@!`"@```!!F`$`*P```&J8`0`B````EI@!`"$```"YF`$`*0``
M`-N8`0`7````!9D!`"D````=F0$`(````$>9`0`R````:)D!`!P```";F0$`
M+@```+B9`0`=````YYD!`!$````%F@$`,P```!>:`0`E````2YH!`#@```!Q
MF@$`)P```*J:`0`\````TIH!`"8````/FP$`'P```#:;`0`P````5IL!`&D`
M``"'FP$`/@```/&;`0`^````,)P!`$<```!OG`$`/0```+><`0!E````]9P!
M`$T```!;G0$`4P```*F=`0!7````_9T!`%4```!5G@$`1@```*N>`0`J````
M\IX!`"\````=GP$`50```$V?`0`@````HY\!`"X```#$GP$`*P```/.?`0`P
M````'Z`!`"H```!0H`$`/@```'N@`0!4````NJ`!`%(````/H0$`6@```&*A
M`0`R````O:$!`"L```#PH0$`2````!RB`0!*````9:(!`"H```"PH@$`)@``
M`-NB`0`L`````J,!`$X````OHP$`,@```'ZC`0`P````L:,!`!T```#BHP$`
M(P````"D`0`O````)*0!`"P```!4I`$`+0```(&D`0!Q````KZ0!`&\````A
MI0$`LP```)&E`0`7````1:8!`"4```!=I@$`,@```(.F`0`I````MJ8!`#X`
M``#@I@$`(@```!^G`0!2````0J<!`"4```"5IP$`"P```+NG`0"Q````QZ<!
M`#L```!YJ`$`)P```+6H`0!.````W:@!`$<````LJ0$`8@```'2I`0!)````
MUZD!`%4````AJ@$`0````'>J`0`O````N*H!`#(```#HJ@$`*P```!NK`0`I
M````1ZL!``\```!QJP$`10```(&K`0`A````QZL!`#````#IJP$`+0```!JL
M`0`E````2*P!`!P```!NK`$`,0```(NL`0`Q````O:P!``L```#OK`$`!P``
M`/NL`0`'`````ZT!``0````+K0$`#0```!"M`0`+````'JT!``X````JK0$`
M"P```#FM`0`%````1:T!`!````!+K0$``@```%RM`0`*````7ZT!`%8```!J
MK0$`60```,&M`0`%````&ZX!`!(````AK@$`!````#2N`0`'````.:X!``@`
M``!!K@$`!0```$JN`0`#````4*X!`!````!4K@$`%P```&6N`0`,````?:X!
M``P```"*K@$`#0```)>N`0`3````I:X!``T```"YK@$``@```,>N`0`'````
MRJX!``8```#2K@$`%````-FN`0`,````[JX!`!@```#[K@$`!@```!2O`0`2
M````&Z\!``P````NKP$``P```#NO`0`J````/Z\!``0```!JKP$`!@```&^O
M`0`'````=J\!`!\```!^KP$`-0```)ZO`0`N````U*\!`"\````#L`$`%P``
M`#.P`0`@````2[`!`!L```!LL`$`&````(BP`0`D````H;`!`!\```#&L`$`
M&@```.:P`0`@`````;$!`!H````BL0$`,@```#VQ`0`O````<+$!`"L```"@
ML0$`'P```,RQ`0`C````[+$!`!\````0L@$`&@```#"R`0`E````2[(!`"8`
M``!QL@$`)0```)BR`0`D````OK(!`!@```#CL@$`'0```/RR`0`D````&K,!
M`!@````_LP$`(@```%BS`0`E````>[,!`#P```"ALP$`'P```-ZS`0`C````
M_K,!`!\````BM`$`(````$*T`0`:````8[0!`!@```!^M`$`&````)>T`0`F
M````L+0!`!X```#7M`$`*0```/:T`0`>````(+4!``H````_M0$`$P```$JU
M`0`(````7K4!``D```!GM0$`%@```'&U`0`,````B+4!`!<```"5M0$`+P``
M`*VU`0`D````W;4!``<````"M@$`'P````JV`0`/````*K8!`!0````ZM@$`
M#@```$^V`0`-````7K8!`"0```!LM@$`!0```)&V`0`'````E[8!``P```"?
MM@$`#P```*RV`0`1````O+8!`"(```#.M@$`)0```/&V`0`=````%[<!`!H`
M```UMP$`$0```%"W`0`'````8K<!`,<```!JMP$`!@```#*X`0`+````.;@!
M`!H```!%N`$`%0```&"X`0`&````=K@!``D```!]N`$`'0```(>X`0`8````
MI;@!``L```"^N`$`%P```,JX`0`&````XK@!`#,```#IN`$`$P```!VY`0`3
M````,;D!``<```!%N0$`#P```$VY`0`1````7;D!`!X```!ON0$`!P```(ZY
M`0`R````EKD!``0```#)N0$`(0```,ZY`0`3````\+D!``P````$N@$`$0``
M`!&Z`0`R````([H!``@```!6N@$`"0```%^Z`0`*````:;H!`!0```!TN@$`
M"@```(FZ`0`=````E+H!``@```"RN@$`'P```+NZ`0`(````V[H!`!H```#D
MN@$`!@```/^Z`0`5````!KL!``<````<NP$`"````"2[`0`)````+;L!`#\`
M```WNP$`!P```'>[`0`/````?[L!``X```"/NP$`$````)Z[`0`)````K[L!
M``D```"YNP$`"````,.[`0`3````S+L!``0```#@NP$`!P```.6[`0`2````
M[;L!`"8`````O`$`&0```">\`0`8````0;P!``L```!:O`$`#@```&:\`0`9
M````=;P!``H```"/O`$`)````)J\`0`*````O[P!`!,```#*O`$`)P```-Z\
M`0`)````!KT!``\````0O0$`%P```""]`0`4````.+T!`"@```!-O0$`#P``
M`':]`0`4````AKT!``H```";O0$`#````*:]`0`7````L[T!``0```#+O0$`
M*@```-"]`0`1````^[T!``(````-O@$`$````!"^`0`8````(;X!``L````Z
MO@$``P```$:^`0`(````2KX!``8```!3O@$`!P```%J^`0`-````8KX!``L`
M``!PO@$`%````'R^`0`5````D;X!``X```"GO@$`+P```+:^`0`@````YKX!
M`!P````'OP$`6@```"2_`0`_````?[\!`#8```"_OP$`#````/:_`0`Q````
M`\`!``D````UP`$`!0```#_``0`2````1<`!`#\```!8P`$`$@```)C``0`*
M````J\`!``8```"VP`$`!````+W``0`$````PL`!`!,```#'P`$`!0```-O`
M`0`&````X<`!``8```#HP`$`!````._``0`,````],`!``H````!P0$`!0``
M``S!`0`8````$L$!`!D````KP0$`'P```$7!`0`=````9<$!`!$```"#P0$`
M`@```)7!`0`$````F,$!``H```"=P0$`!@```*C!`0`%````K\$!``,```"U
MP0$`#````+G!`0`[````QL$!`"<````"P@$`(0```"K"`0`D````3,(!`$4`
M``!QP@$`&@```+?"`0`=````TL(!`#4```#PP@$`5@```";#`0`H````?<,!
M`%,```"FPP$`.@```/K#`0!"````-<0!`!D```!XQ`$`%P```)+$`0"+````
MJL0!`!D````VQ0$`*@```%#%`0`K````>\4!`'(```"GQ0$`(````!K&`0`U
M````.\8!`$4```!QQ@$`)@```+?&`0`P````WL8!`$L````/QP$`3@```%O'
M`0`G````JL<!`"D```#2QP$`(0```/S'`0`H````'L@!`"L```!'R`$`'0``
M`'/(`0`I````D<@!`"8```"[R`$`+0```.+(`0`E````$,D!`"@````VR0$`
M*````%_)`0`B````B,D!`"D```"KR0$`(@```-7)`0`]````^,D!`$$````V
MR@$`*````'C*`0`L````H<H!`#````#.R@$`$@```/_*`0`3````$LL!`!``
M```FRP$`>0```#?+`0`)````L<L!`!P```"[RP$`$````-C+`0`/````Z<L!
M`"<```#YRP$`#@```"',`0!S````,,P!`'P```"DS`$`0````"'-`0`K````
M8LT!`!<```".S0$`*@```*;-`0`T````T<T!`!8````&S@$`#P```!W.`0`H
M````+<X!`!\```!6S@$`'P```';.`0`<````ELX!`%$```"SS@$`%`````7/
M`0`/````&L\!``H````JSP$`!0```#7/`0`&````.\\!``@```!"SP$`!0``
M`$O/`0`2````4<\!``P```!DSP$`$````''/`0`3````@L\!`!T```"6SP$`
M#P```+3/`0`/````Q,\!``0```#4SP$`"@```-G/`0`$````Y,\!``,```#I
MSP$`"0```.W/`0`'````]\\!``L```#_SP$`"`````O0`0`'````%-`!``4`
M```<T`$`"0```"+0`0`4````+-`!``8```!!T`$`!P```$C0`0`(````4-`!
M``\```!9T`$`#P```&G0`0`(````>=`!``P```""T`$`!@```(_0`0`)````
MEM`!``L```"@T`$`#P```*S0`0`&````O-`!``<```##T`$`#0```,O0`0`&
M````V=`!`!0```#@T`$`!P```/70`0`#````_=`!``D````!T0$`!@````O1
M`0`,````$M$!``H````?T0$`#````"K1`0`*````-]$!``\```!"T0$`!0``
M`%+1`0`(````6-$!``0```!AT0$`"@```&;1`0`'````<=$!``0```!YT0$`
M!````'[1`0`9````@]$!``(```"=T0$`"0```*#1`0`&````JM$!``,```"Q
MT0$`!@```+71`0`,````O-$!`"<```#)T0$`!````/'1`0`$````]M$!``\`
M``#[T0$`$P````O2`0`'````'](!``(````GT@$`!P```"K2`0`&````,M(!
M``8````YT@$`$````$#2`0`2````4=(!``X```!DT@$`#P```'/2`0`&````
M@](!``D```"*T@$`(@```)32`0`'````M](!``<```"_T@$`"P```,?2`0`%
M````T](!``(```#9T@$`"P```-S2`0`.````Z-(!``X```#WT@$`80$```;3
M`0`+````:-0!``L```!TU`$`"P```(#4`0`3````C-0!``\```"@U`$`"@``
M`+#4`0`+````N]0!``P```#'U`$`!````-34`0`$````V=0!``$```#>U`$`
M&````.#4`0`+````^=0!`$8````%U0$`+@```$S5`0!!````>]4!`"D```"]
MU0$`&0```.?5`0`3`````=8!``X````5U@$`#P```"36`0`%````--8!`"@`
M```ZU@$`#@```&/6`0`9````<M8!``X```",U@$`+0```)O6`0`+````R=8!
M`"H```#5U@$`-@````#7`0`6````-]<!`!4```!.UP$`$````&37`0`N````
M==<!`"X```"DUP$`+0```-/7`0`=`````=@!``T````?V`$`"@```"W8`0`1
M````.-@!`",```!*V`$`(0```&[8`0`0````D-@!`!H```"AV`$`*@```+S8
M`0`T````Y]@!``X````<V0$`"P```"O9`0`0````-]D!``\```!(V0$`!@``
M`%C9`0`<````7]D!`#L```!\V0$`0@```+C9`0"<````^]D!`'T```"8V@$`
M&0```!;;`0`@````,-L!`!(```!1VP$`&````&3;`0`0````?=L!`$$```".
MVP$`*0```-#;`0`\````^ML!`"0````WW`$`#0```%S<`0`.````:MP!``\`
M``!YW`$`#P```(G<`0`'````F=P!``T```"AW`$`#0```*_<`0`N````O=P!
M`"@```#LW`$`-0```!7=`0!=````2]T!`#X```"IW0$`30```.C=`0!H````
M-MX!`&L```"?W@$`;@````O?`0!Q````>M\!`$````#LWP$`%````"W@`0`%
M````0N`!``(```!(X`$`!@```$O@`0`0````4N`!``<```!CX`$`"0```&O@
M`0`)````=>`!`!(```!_X`$`#````)+@`0`R````G^`!`#````#2X`$`$0``
M``/A`0`1````%>$!``P````GX0$`#@```#3A`0`+````0^$!``D```!/X0$`
M%0```%GA`0`5````;^$!``\```"%X0$`%@```)7A`0`5````K.$!`!L```#"
MX0$`#P```-[A`0`6````[N$!``X````%X@$`#@```!3B`0`M````(^(!`!T`
M``!1X@$`%P```&_B`0`;````A^(!`!,```"CX@$`'````+?B`0`J````U.(!
M`"<```#_X@$`%P```"?C`0`4````/^,!`"X```!4XP$`&````(/C`0`R````
MG.,!``4```#/XP$`"0```-7C`0`+````W^,!`#$```#KXP$`!@```!WD`0`,
M````).0!``H````QY`$`!P```#SD`0`(````1.0!``4```!-Y`$`"0```%/D
M`0`+````7>0!``0```!IY`$`(````&[D`0`,````C^0!``P```"<Y`$`$```
M`*GD`0!/````NN0!`%<````*Y0$`3@```&+E`0!*````L>4!`#0```#\Y0$`
M&@```#'F`0`L````3.8!``H```!YY@$`'````(3F`0`;````H>8!`"````"]
MY@$`%P```-[F`0`6````]N8!`!,````-YP$`*0```"'G`0`&````2^<!`!<`
M``!2YP$`$````&KG`0!'````>^<!`!\```##YP$`/P```./G`0`'````(^@!
M``8````KZ`$`"````#+H`0`.````.^@!``@```!*Z`$`"@```%/H`0`5````
M7N@!``H```!TZ`$`$@```'_H`0`*````DN@!`!4```"=Z`$`$0```+/H`0`7
M````Q>@!`"8```#=Z`$`-P````3I`0`8````/.D!``H```!5Z0$`!0```&#I
M`0`7````9ND!`!8```!^Z0$`"P```)7I`0`Z````H>D!`%````#<Z0$`(0``
M`"WJ`0!"````3^H!`#X```"2Z@$`/````-'J`0`K````#NL!`#`````ZZP$`
M/@```&OK`0`_````JNL!`#D```#JZP$`"@```"3L`0`'````+^P!`!,````W
M[`$`#````$OL`0`%````6.P!``4```!>[`$`"0```&3L`0`0````;NP!``L`
M``!_[`$`%0```(OL`0`&````H>P!`$4```"H[`$`$0```.[L`0`)`````.T!
M`!8````*[0$`/P```"'M`0`3````8>T!`%L```!U[0$`0@```-'M`0`'````
M%.X!`"<````<[@$`"````$3N`0`R````3>X!`#$```"`[@$`+@```++N`0`O
M````X>X!``H````1[P$`"````!SO`0`*````)>\!``@````P[P$`"0```#GO
M`0`*````0^\!`#(```!.[P$`.````('O`0`Q````NN\!`%<```#L[P$`,```
M`$3P`0`O````=?`!`#````"E\`$`,````-;P`0!&````!_$!`#0```!.\0$`
M,P```(/Q`0`P````M_$!`#8```#H\0$`%0```!_R`0`9````-?(!`"X```!/
M\@$`)````'[R`0!I````H_(!`!@````-\P$`$P```";S`0`:````.O,!``P`
M``!5\P$`#````&+S`0`.````;_,!``T```!^\P$`"P```(SS`0`0````F/,!
M`!@```"I\P$`'0```,+S`0`'````X/,!``<```#H\P$`%@```/#S`0`*````
M!_0!``@````2]`$`"0```!OT`0`#````)?0!``L````I]`$`!@```#7T`0`&
M````//0!`#X```!#]`$`!0```(+T`0`'````B/0!``8```"0]`$`"@```)?T
M`0`,````HO0!`"P```"O]`$`$````-ST`0`(````[?0!`%(```#V]`$`!```
M`$GU`0`#````3O4!``<```!2]0$`"0```%KU`0`$````9/4!``H```!I]0$`
M!@```'3U`0`5````>_4!``4```"1]0$`,0```)?U`0`(````R?4!``D```#2
M]0$`#0```-SU`0`(````ZO4!`"$```#S]0$`$0```!7V`0`)````)_8!`!$`
M```Q]@$`#````$/V`0`'````4/8!``,```!8]@$``P```%SV`0`5````8/8!
M`!0```!V]@$`#````(OV`0`&````F/8!``0```"?]@$`"````*3V`0`(````
MK?8!`#````"V]@$`,0```.?V`0!@````&?<!`%(```!Z]P$`)@```,WW`0`&
M````]/<!``@```#[]P$`$`````3X`0`8````%?@!`$$````N^`$`(@```'#X
M`0`E````D_@!`#````"Y^`$`)````.KX`0`J````#_D!`'H````Z^0$`-0``
M`+7Y`0`*````Z_D!``D```#V^0$`%0````#Z`0`/````%OH!``(````F^@$`
M#0```"GZ`0`0````-_H!`!$```!(^@$`$````%KZ`0`.````:_H!``T```!Z
M^@$`%@```(CZ`0`&````G_H!`!T```"F^@$`'@```,3Z`0`2````X_H!`!$`
M``#V^@$`!@````C[`0`*````#_L!``@````:^P$`#````"/[`0`*````,/L!
M`'$````[^P$`*0```*W[`0!A````U_L!`&`````Y_`$`"````)K\`0`8````
MH_P!`!,```"\_`$`(@```-#\`0`6````\_P!`#D````*_0$`,0```$3]`0`%
M````=OT!``4```!\_0$`'@```(+]`0`;````H?T!``\```"]_0$`%````,W]
M`0`3````XOT!`!<```#V_0$`$P````[^`0`3````(OX!`"P````V_@$`,P``
M`&/^`0!*````E_X!`!````#B_@$`)````//^`0`&````&/\!`!0````?_P$`
M$0```#3_`0`-````1O\!`!(```!4_P$`60```&?_`0`G````P?\!`"L```#I
M_P$`-P```!4``@`^````30`"`#8```",``(`*@```,,``@!N````[@`"`!8`
M``!=`0(`.P```'0!`@!!````L`$"`!,```#R`0(`00````8"`@`W````2`("
M``<```"``@(`#````(@"`@`1````E0("``P```"G`@(`!@```+0"`@`'````
MNP("`!@```##`@(`"0```-P"`@`/````Y@("`!4```#V`@(`#0````P#`@`1
M````&@,"``@````L`P(`!0```#4#`@`0````.P,"``T```!,`P(`#0```%H#
M`@`)````:`,"``L```!R`P(`!@```'X#`@`(````A0,"``T```".`P(`"0``
M`)P#`@`-````I@,"``<```"T`P(`!P```+P#`@`(````Q`,"`!8```#-`P(`
M*P```.0#`@!8````$`0"``D```!I!`(`"0```',$`@`;````?00"``\```"9
M!`(`*P```*D$`@`<````U00"`!,```#R!`(`!0````8%`@`H````#`4"`!,`
M```U!0(`%````$D%`@`X````7@4"`$<```"7!0(`(@```-\%`@`@`````@8"
M`#4````C!@(`"````%D&`@`@````8@8"`",```"#!@(`A````*<&`@`T````
M+`<"``T```!A!P(`!@```&\'`@`(````=@<"`!````!_!P(`$````)`'`@`*
M````H0<"`!,```"L!P(`"@```,`'`@`)````RP<"`!T```#5!P(`(@```/,'
M`@`@````%@@"`"4````W"`(`'````%T(`@`M````>@@"`!\```"H"`(`(P``
M`,@(`@`A````[`@"`!P````."0(`'P```"L)`@`>````2PD"`"D```!J"0(`
M.0```)0)`@`R````S@D"`"L````!"@(`.P```"T*`@`X````:0H"`"0```"B
M"@(`*P```,<*`@`W````\PH"`#T````K"P(`$P```&D+`@`H````?0L"`!(`
M``"F"P(`Q````+D+`@`4````?@P"`!X```"3#`(`)0```+(,`@`G````V`P"
M`",`````#0(`(@```"0-`@`A````1PT"`"0```!I#0(`(P```(X-`@`<````
ML@T"`"<```#/#0(`1P```/<-`@`-````/PX"``0```!-#@(`"0```%(.`@`%
M````7`X"``@```!B#@(`#@```&L.`@`1````>@X"``T```",#@(`%P```)H.
M`@`/````L@X"`!8```#"#@(`&@```-D.`@!N````]`X"``X```!C#P(`#P``
M`'(/`@`0````@@\"``<```"3#P(`!````)L/`@`,````H`\"``X```"M#P(`
M"P```+P/`@`6````R`\"`!(```#?#P(`#0```/(/`@!%`````!`"`"8```!&
M$`(`+@```&T0`@`'````G!`"`!````"D$`(`!@```+40`@`3````O!`"`!D`
M``#0$`(`&P```.H0`@`5````!A$"``(````<$0(`"0```!\1`@`&````*1$"
M`!`````P$0(`!0```$$1`@`/````1Q$"``X```!7$0(``P```&81`@`0````
M:A$"``@```![$0(`$0```(01`@`)````EA$"`!4```"@$0(`#P```+81`@`4
M````QA$"`!H```#;$0(`&@```/81`@`*````$1("``P````<$@(`"P```"D2
M`@`?````-1("`!P```!5$@(`$@```'(2`@`1````A1("`!$```"7$@(`%@``
M`*D2`@`:````P!("``T```#;$@(`#P```.D2`@`I````^1("`#@````C$P(`
M&0```%P3`@`^````=A,"`#H```"U$P(`#0```/`3`@`D````_A,"`!H````C
M%`(`&````#X4`@`*````5Q0"`!4```!B%`(`&P```'@4`@`H````E!0"``L`
M``"]%`(`"@```,D4`@`.````U!0"`"D```#C%`(`"`````T5`@`6````%A4"
M``P````M%0(`!P```#H5`@`D````0A4"`"T```!G%0(`#````)45`@`(````
MHA4"`"$```"K%0(`"@```,T5`@`4````V!4"`!D```#M%0(`&@````<6`@`)
M````(A8"``D````L%@(`%0```#86`@`.````3!8"`#,```!;%@(`'0```(\6
M`@`/````K18"`!T```"]%@(`,0```-L6`@`-````#1<"`!D````;%P(`"```
M`#47`@`1````/A<"`"<```!0%P(`$````'@7`@`F````B1<"`!P```"P%P(`
M%P```,T7`@`]````Y1<"``@````C&`(`%@```"P8`@`*````0Q@"``H```!.
M&`(`#0```%D8`@`;````9Q@"`"@```"#&`(`$0```*P8`@`@````OA@"`#(`
M``#?&`(`&````!(9`@`$````*QD"``<````P&0(`"````#@9`@`/````01D"
M``4```!1&0(`!@```%<9`@`+````7AD"``,```!J&0(`+````&X9`@`'````
MFQD"``@```"C&0(`%0```*P9`@`-````PAD"`!0```#0&0(`#@```.49`@`.
M````]!D"`!`````#&@(`&0```!0:`@`3````+AH"`"8```!"&@(`%````&D:
M`@`5````?AH"`!<```"4&@(`&````*P:`@`8````Q1H"`#P```#>&@(`%P``
M`!L;`@`)````,QL"``8````]&P(`"P```$0;`@`*````4!L"``(```!;&P(`
M!@```%X;`@`+````91L"`",```!Q&P(`%@```)4;`@`)````K!L"`"8```"V
M&P(`$@```-T;`@`4````\!L"`!4````%'`(`#0```!L<`@`/````*1P"``\`
M```Y'`(`(````$D<`@`C````:AP"`#X```".'`(`&@```,T<`@`F````Z!P"
M`!`````/'0(`!0```"`=`@`:````)AT"``T```!!'0(`%````$\=`@`(````
M9!T"``\```!M'0(`&````'T=`@"+````EAT"`!X````B'@(`(@```$$>`@`A
M````9!X"`"4```"&'@(`,P```*P>`@`2````X!X"``<```#S'@(`!````/L>
M`@`D`````!\"`!<````E'P(`!P```#T?`@`(````11\"``<```!.'P(`!@``
M`%8?`@`B````71\"``\```"`'P(`#@```)`?`@`0````GQ\"``X```"P'P(`
M#P```+\?`@`,````SQ\"``L```#<'P(`$0```.@?`@`)````^A\"``H````$
M(`(`$`````\@`@`6````("`"``X````W(`(`$````$8@`@!9````5R`"`#@`
M``"Q(`(`#@```.H@`@`.````^2`"`"X````((0(`"P```#<A`@`(````0R$"
M``X```!,(0(`%````%LA`@`F````<"$"`"D```"7(0(`*````,$A`@`=````
MZB$"`!X````((@(`+````"<B`@`A````5"("``0```!V(@(`'````'LB`@`/
M````F"("``,```"H(@(`"````*PB`@`)````M2("``L```"_(@(`#````,LB
M`@`A````V"("`"$```#Z(@(`&P```!PC`@`A````.","``P```!:(P(`"```
M`&<C`@`$````<","``<```!U(P(`'````'TC`@`>````FB,"``T```"Y(P(`
M#````,<C`@`.````U","``T```#C(P(`)P```/$C`@`,````&20"`!(````F
M)`(`*P```#DD`@`U````920"``<```";)`(`$P```*,D`@`8````MR0"``8`
M``#0)`(`!P```-<D`@`,````WR0"`!0```#L)`(`#0````$E`@`/````#R4"
M`!4````?)0(`!P```#4E`@`'````/24"``L```!%)0(`!````%$E`@`3````
M5B4"``P```!J)0(`$@```'<E`@`F````BB4"`"@```"Q)0(`"0```-HE`@`'
M````Y"4"`#````#L)0(`%P```!TF`@""````-28"`!<```"X)@(`50```-`F
M`@`+````)B<"``<````R)P(`"P```#HG`@`(````1B<"``H```!/)P(`!@``
M`%HG`@`*````82<"``L```!L)P(`%````'@G`@`;````C2<"``H```"I)P(`
M`@```+0G`@`&````MR<"``D```"^)P(`&0```,@G`@`5````XB<"`!,```#X
M)P(`$@````PH`@`;````'R@"``P````[*`(`#P```$@H`@`<````6"@"``0`
M``!U*`(``P```'HH`@`(````?B@"``<```"'*`(`%@```(\H`@`*````IB@"
M``X```"Q*`(`!````,`H`@`%````Q2@"`!\```#+*`(`!0```.LH`@`S````
M\2@"``8````E*0(`!@```"PI`@`/````,RD"`!@```!#*0(`$0```%PI`@`'
M````;BD"``D```!V*0(`+@```(`I`@`%````KRD"``D```"U*0(`"````+\I
M`@`/````R"D"``8```#8*0(`#0```-\I`@`1````[2D"``L```#_*0(`"P``
M``LJ`@`3````%RH"``D````K*@(`!P```#4J`@`,````/2H"`!\```!**@(`
M!P```&HJ`@`*````<BH"``0```!]*@(`"0```((J`@`(````C"H"``P```"5
M*@(`"@```*(J`@`&````K2H"``T```"T*@(`!@```,(J`@`$````R2H"``0`
M``#.*@(`%P```-,J`@!`````ZRH"`$0````L*P(`0@```'$K`@`A````M"L"
M``4```#6*P(`#P```-PK`@`%````["L"``,```#R*P(`!P```/8K`@`A````
M_BL"`!@````@+`(`!@```#DL`@`$````0"P"`!L```!%+`(`!@```&$L`@`(
M````:"P"`"(```!Q+`(`+````)0L`@`)````P2P"`!L```#++`(`$@```.<L
M`@`5````^BP"``0````0+0(`#P```!4M`@`'````)2T"``4````M+0(`%P``
M`#,M`@`$````2RT"``T```!0+0(`#P```%XM`@`(````;BT"``D```!W+0(`
M!0```($M`@`]````ART"`#8```#%+0(`.P```/PM`@`J````."X"`#@```!C
M+@(`.@```)PN`@`M````URX"`%(````%+P(`,````%@O`@`Y````B2\"`"D`
M``##+P(`$````.TO`@`8````_B\"``P````7,`(`)````"0P`@`>````23`"
M`"0```!H,`(`(@```(TP`@`A````L#`"`"8```#2,`(`"P```/DP`@`-````
M!3$"``H````3,0(`"0```!XQ`@`$````*#$"`!P````M,0(`(@```$HQ`@`H
M````;3$"`"@```"6,0(`#````+\Q`@`?````S#$"`!\```#L,0(`#@````PR
M`@`5````&S("``4````Q,@(`"````#<R`@`:````0#("`#,```!;,@(`&```
M`(\R`@`2````J#("``<```"[,@(`$P```,,R`@`6````US("`!````#N,@(`
M40```/\R`@"1````43,"`(0```#C,P(`!P```&@T`@`,````<#0"`!<```!]
M-`(`#@```)4T`@`/````I#0"`!0```"T-`(`%0```,DT`@`1````WS0"``P`
M``#Q-`(`"@```/XT`@`2````"34"`!8````<-0(`%@```#,U`@`I````2C4"
M`"P```!T-0(`*0```*$U`@`;````RS4"`!\```#G-0(`(@````<V`@`9````
M*C8"`!<```!$-@(`)0```%PV`@`3````@C8"``H```"6-@(`%0```*$V`@`A
M````MS8"`!4```#9-@(`%0```.\V`@`.````!3<"``\````4-P(`!0```"0W
M`@`[````*C<"`"P```!F-P(`(@```),W`@`I````MC<"`(T```#@-P(`%```
M`&XX`@`%````@S@"`!8```").`(`"0```*`X`@`$````JC@"``H```"O.`(`
M(P```+HX`@`J````WC@"`"T````).0(`!@```#<Y`@`1````/CD"`!D```!0
M.0(`$P```&HY`@`H````?CD"`"L```"G.0(`'@```-,Y`@`.````\CD"`!``
M```!.@(`%````!(Z`@`G````)SH"`"D```!/.@(`)0```'DZ`@`E````GSH"
M`#````#%.@(`,````/8Z`@`=````)SL"`$4```!%.P(`#P```(L[`@`1````
MFSL"`!$```"M.P(`$P```+\[`@`2````TSL"`!4```#F.P(`%P```/P[`@`/
M````%#P"`!$````D/`(`.0```#8\`@`=````<#P"`!<```"./`(`.@```*8\
M`@`3````X3P"``<```#U/`(`#0```/T\`@`T````"ST"``X```!`/0(`'```
M`$\]`@`B````;#T"`!4```"//0(`$@```*4]`@`E````N#T"`!D```#>/0(`
M&0```/@]`@`4````$CX"`!$````G/@(`$@```#D^`@`>````3#X"`"0```!K
M/@(`%@```)`^`@`I````ISX"`"P```#1/@(`$@```/X^`@`7````$3\"`!,`
M```I/P(`%P```#T_`@`*````53\"``H```!@/P(`(````&L_`@`$````C#\"
M``<```"1/P(`"@```)D_`@`8````I#\"``8```"]/P(`"````,0_`@`'````
MS3\"``8```#5/P(`!P```-P_`@`'````Y#\"``4```#L/P(`%````/(_`@`&
M````!T`"``@````.0`(`!````!=``@`$````'$`"``D````A0`(`%0```"M`
M`@`2````04`"``\```!40`(`$````&1``@`"````=4`"``H```!X0`(`$P``
M`(-``@`%````ET`"`"<```"=0`(`#@```,5``@`-````U$`"`!,```#B0`(`
M#0```/9``@`+````!$$"``X````000(`,P```!]!`@`]````4T$"``@```"1
M00(`"````)I!`@`G````HT$"`!0```#+00(`$0```.!!`@`'````\D$"``D`
M``#Z00(`!P````1"`@`$````#$("`"`````10@(`#0```#)"`@`5````0$("
M``X```!60@(`$````&5"`@`2````=D("`!8```")0@(`'0```*!"`@`9````
MOD("``<```#80@(`!P```.!"`@`&````Z$("`!@```#O0@(`!P````A#`@`%
M````$$,"``H````60P(`#@```"%#`@`'````,$,"`!`````X0P(`!P```$E#
M`@`=````44,"``T```!O0P(`#````'U#`@`,````BD,"`!(```"70P(`#```
M`*I#`@`/````MT,"`!<```#'0P(`#0```-]#`@`0````[4,"``@```#^0P(`
M!`````=$`@`0````#$0"`$$````=1`(`*0```%]$`@`%````B40"``P```"/
M1`(`(0```)Q$`@`-````OD0"`!D```#,1`(`"@```.9$`@",````\40"``T`
M``!^10(`"@```(Q%`@`(````ET4"``X```"@10(`"@```*]%`@`1````ND4"
M`!(```#,10(`%@```-]%`@`O````]D4"``H````F1@(`"````#%&`@`(````
M.D8"``\```!#1@(`#````%-&`@`6````8$8"``<```!W1@(`"0```']&`@`0
M````B48"``@```":1@(`"0```*-&`@`,````K48"`$X```"Z1@(`$P````E'
M`@`+````'4<"``8````I1P(`!````#!'`@`/````-4<"`!8```!%1P(`%P``
M`%Q'`@`8````=$<"``<```"-1P(`"0```)5'`@`"````GT<"``0```"B1P(`
M(@```*='`@`#````RD<"``4```#.1P(`,P```-1'`@`0````"$@"``H````9
M2`(`!0```"1(`@`&````*D@"``T````Q2`(`#````#](`@`P````3$@"``<`
M``!]2`(`&@```(5(`@`-````H$@"``8```"N2`(`"````+5(`@`)````OD@"
M``0```#(2`(`!0```,U(`@!B````TT@"``L````V20(`#0```$))`@`%````
M4$D"``4```!620(`*````%Q)`@`J````A4D"``P```"P20(`/@```+U)`@`K
M````_$D"`!L````H2@(`)@```$1*`@`W````:TH"`!$```"C2@(`"@```+5*
M`@`>````P$H"`!P```#?2@(`%0```/Q*`@`*````$DL"``D````=2P(`'```
M`"=+`@`G````1$L"`"T```!L2P(`+````)I+`@`6````QTL"``\```#>2P(`
M(````.Y+`@`F````#TP"``,````V3`(`!P```#I,`@`+````0DP"`!4```!.
M3`(`%@```&1,`@`4````>TP"`!0```"03`(`$@```*5,`@`9````N$P"``4`
M``#23`(`$````-A,`@`*````Z4P"`!(```#T3`(`!P````=-`@`4````#TT"
M``P````D30(`#0```#%-`@`.````/TT"``X```!.30(`#0```%U-`@!I````
M:TT"`!````#530(`$0```.9-`@`2````^$T"``T````+3@(`#@```!E.`@`8
M````*$X"`!P```!!3@(`.````%Y.`@`=````ETX"``L```"U3@(`*P```,%.
M`@`.````[4X"``H```#\3@(`'P````=/`@!-````)T\"``<```!U3P(`"```
M`'U/`@`&````AD\"`!\```"-3P(`!@```*U/`@`)````M$\"`"T```"^3P(`
M+````.Q/`@`&````&5`"``H````@4`(`)0```"M0`@!A````45`"`!8```"S
M4`(`*````,I0`@`5````\U`"``(````)40(`#@````Q1`@`)````&U$"``\`
M```E40(`"````#51`@`*````/E$"``<```!)40(`%P```%%1`@`&````:5$"
M``@```!P40(`#0```'E1`@`+````AU$"``H```"340(`"0```)Y1`@`'````
MJ%$"`!8```"P40(`%````,=1`@`3````W%$"``L```#P40(`#````/Q1`@`*
M````"5("``L````44@(`"@```"!2`@`,````*U("`!(````X4@(`"@```$M2
M`@`*````5E("`!T```!A4@(`%0```']2`@`4````E5("``P```"J4@(`#```
M`+=2`@`2````Q%("``4```#74@(`)0```-U2`@`)`````U,"``0````-4P(`
M*````!)3`@`'````.U,"``4```!#4P(`#P```$E3`@`%````65,"``D```!?
M4P(`$P```&E3`@`2````?5,"`!H```"04P(`%@```*M3`@`8````PE,"`!<`
M``#;4P(`%P```/-3`@`>````"U0"`!@````J5`(`!P```$-4`@`%````2U0"
M`!8```!15`(`!0```&A4`@`/````;E0"`!````!^5`(`"@```(]4`@`+````
MFE0"``L```"F5`(`(0```+)4`@`-````U%0"`!````#B5`(`%0```/-4`@`&
M````"54"``T````050(`"````!Y5`@`/````)U4"``\````W50(`#P```$=5
M`@`)````5U4"``4```!A50(`!P```&=5`@`%````;U4"``0```!U50(``P``
M`'I5`@`9````?E4"``T```"850(`'````*95`@`.````PU4"`"0```#250(`
M)0```/=5`@`>````'58"`"H````\5@(`%P```&=6`@`_````?U8"`#D```"_
M5@(`$P```/E6`@`L````#5<"`#(````Z5P(`$0```&U7`@`Z````?U<"`"X`
M``"Z5P(`,P```.E7`@`S````'5@"`#L```!16`(`$@```(U8`@`:````H%@"
M`!4```"[6`(`%@```-%8`@`S````Z%@"`!4````<60(`(````#)9`@`C````
M4UD"`!T```!W60(`%0```)59`@`6````JUD"`"\```#"60(`%````/)9`@`5
M````!UH"`!D````=6@(`,@```#=:`@`R````:EH"`#4```"=6@(`,P```--:
M`@`T````!UL"`#$````\6P(`:P```&Y;`@`=````VEL"`#$```#X6P(`-```
M`"I<`@`Q````7UP"``X```"17`(`"P```*!<`@`O````K%P"``\```#<7`(`
M#P```.Q<`@`P````_%P"`!@````M70(`+P```$9=`@`C````=ET"``P```":
M70(`20```*==`@!"````\5T"``X````T7@(`!````$->`@`0````2%X"`!P`
M``!97@(`#@```'9>`@`'````A5X"`!,```"-7@(`"````*%>`@`)````JEX"
M``<```"T7@(`"0```+Q>`@`/````QEX"``D```#67@(`#P```.!>`@`0````
M\%X"``X````!7P(`&P```!!?`@`:````+%\"`!4```!'7P(`&@```%U?`@`.
M````>%\"`!$```"'7P(`)````)E?`@`(````OE\"`!P```#'7P(`"````.1?
M`@`%````[5\"`!````#S7P(`#P````1@`@!@````%&`"`$T```!U8`(`#```
M`,-@`@`_````T&`"``(````080(``@```!-A`@`&````%F$"``X````=80(`
M!@```"QA`@`'````,V$"`!`````[80(`!P```$QA`@`.````5&$"`"<```!C
M80(`!````(MA`@`Q````D&$"`#````#"80(`&P```/-A`@`B````#V("`#P`
M```R8@(`6````&]B`@`8````R&("`$@```#A8@(`#````"IC`@`C````-V,"
M`!````!;8P(`#P```&QC`@`&````?&,"``X```"#8P(`#P```))C`@`,````
MHF,"`!,```"O8P(`"P```,-C`@`=````SV,"`!H```#M8P(`!@````AD`@`1
M````#V0"`!,````A9`(`#0```#5D`@`/````0V0"`"8```!39`(``P```'ID
M`@`9````?F0"`!,```"89`(`$P```*QD`@`*````P&0"`$(```#+9`(`"@``
M``YE`@`:````&64"`%`````T90(`%````(5E`@`9````FF4"`#\```"T90(`
M.@```/1E`@`8````+V8"`!@```!(9@(`(````&%F`@`@````@F8"`"@```"C
M9@(`*P```,QF`@`V````^&8"`&8````O9P(`6````)9G`@`(````[V<"``D`
M``#X9P(`&0````)H`@`2````'&@"`!D````O:`(`!````$EH`@`<````3F@"
M``P```!K:`(`*P```'AH`@`?````I&@"``X```#$:`(`"@```--H`@`,````
MWF@"`!````#K:`(`(@```/QH`@`C````'VD"``@```!#:0(`!0```$QI`@`=
M````4FD"``8```!P:0(`$@```'=I`@`(````BFD"``H```"3:0(`%````)YI
M`@`/````LVD"`!D```##:0(`(@```-UI`@`0`````&H"`"8````1:@(`(P``
M`#AJ`@`*````7&H"`!(```!G:@(`,````'IJ`@`:````JVH"``L```#&:@(`
M#````-)J`@`A````WVH"``<````!:P(`%@````EK`@`#````(&L"`!@````D
M:P(`!@```#UK`@`'````1&L"`"$```!,:P(`,0```&YK`@`%````H&L"``T`
M``"F:P(`.0```+1K`@`+````[FL"`!<```#Z:P(`,P```!)L`@`P````1FP"
M`#(```!W;`(`,P```*IL`@`$````WFP"``H```#C;`(`#````.YL`@`(````
M^VP"``8````$;0(`"`````MM`@`&````%&T"`$,````;;0(`'@```%]M`@`*
M````?FT"`!<```");0(`-````*%M`@`T````UFT"`"(````+;@(`,P```"YN
M`@`I````8FX"`"````",;@(`1P```*UN`@`=````]6X"`"<````3;P(`'```
M`#MO`@!N````6&\"`'$```#';P(`&@$``#EP`@`N````5'$"`!H```"#<0(`
M+````)YQ`@`>````RW$"`#,```#J<0(`80```!YR`@`Z````@'("`#D```"[
M<@(`-````/5R`@`U````*G,"`#(```!@<P(`)0```)-S`@`%````N7,"``@`
M``"_<P(`"0```,AS`@`(````TG,"`"$```#;<P(`'````/US`@`P````&G0"
M`!````!+=`(`+P```%QT`@`C````C'0"`"P```"P=`(`,0```-UT`@`V````
M#W4"``D```!&=0(`&````%!U`@`+````:74"``H```!U=0(`*P```(!U`@`-
M````K'4"``T```"Z=0(`#0```,AU`@`)````UG4"`!(```#@=0(`"@```/-U
M`@`-````_G4"`!@````,=@(`"````"5V`@`4````+G8"``D```!#=@(`1@``
M`$UV`@!%````E'8"``P```#:=@(`"0```.=V`@`0````\78"`!L````"=P(`
M+````!YW`@`L````2W<"``L```!X=P(`#P```(1W`@`.````E'<"``X```"C
M=P(`&@```+)W`@!`````S7<"`"L````.>`(`!@```#IX`@`%````07@"`"8`
M``!'>`(`(@```&YX`@`9````D7@"`!T```"K>`(`%````,EX`@`%````WG@"
M``L```#D>`(`"@```/!X`@`(````^W@"``X````$>0(`"@```!-Y`@`?````
M'GD"``4````^>0(`#@```$1Y`@!%````4WD"`&(```"9>0(`#````/QY`@`/
M````"7H"``T````9>@(`"0```"=Z`@`(````,7H"`!`````Z>@(`%````$MZ
M`@`1````8'H"`!P```!R>@(`"0```(]Z`@`C````F7H"`!4```"]>@(`&0``
M`--Z`@`%````[7H"`!0```#S>@(`"@````A[`@`3````$WL"``L````G>P(`
M(@```#-[`@`<````5GL"`!,```!S>P(`$@```(=[`@`N````FGL"``L```#)
M>P(`$````-5[`@`9````YGL"`!$`````?`(`$@```!)\`@`0````)7P"`$D`
M```V?`(`$````(!\`@`,````D7P"`"0```">?`(`%0```,-\`@`7````V7P"
M`!````#Q?`(`+@````)]`@`_````,7T"`!<```!Q?0(`#0```(E]`@`,````
MEWT"`!,```"D?0(`$````+A]`@`1````R7T"`!8```#;?0(`%P```/)]`@`1
M````"GX"`"4````<?@(`,P```$)^`@`M````=GX"``X```"D?@(`#P```+-^
M`@`-````PWX"`!D```#1?@(`$P```.M^`@`F````_WX"`#T````F?P(`'P``
M`&1_`@`B````A'\"`"````"G?P(`$@```,A_`@`*````VW\"`!````#F?P(`
M$P```/=_`@`A````"X`"``H````M@`(`"0```#B``@`1````0H`"`"0```!4
M@`(`$0```'F``@!3````BX`"``<```#?@`(`&````.>``@`7`````($"``@`
M```8@0(`!@```"&!`@`+````*($"``\````T@0(`%````$2!`@`#````68$"
M``@```!=@0(`"P```&:!`@`2````<H$"`!,```"%@0(`$0```)F!`@`1````
MJX$"``8```"]@0(`"0```,2!`@`W````SH$"`#`````&@@(`+0```#>"`@`'
M````98("`!,```!M@@(`!@```(&"`@`&````B(("`",```"/@@(`%@```+."
M`@`8````RH("``T```#C@@(`10```/&"`@`-````-X,"`!T```!%@P(`4P``
M`&.#`@`]````MX,"`"X```#U@P(`&P```"2$`@`X````0(0"`!L```!YA`(`
M(P```)6$`@`Y````N80"`%L```#SA`(`7P```$^%`@`G````KX4"``T```#7
MA0(`"0```.6%`@`#````[X4"``8```#SA0(`"@```/J%`@`*````!88"``(`
M```0A@(`%0```!.&`@`,````*88"``D````VA@(`$0```$"&`@`(````4H8"
M`!4```!;A@(`&P```'&&`@`4````C88"``4```"BA@(`"@```*B&`@`4````
MLX8"`!$```#(A@(`#````-J&`@`'````YX8"``H```#OA@(`,0```/J&`@`0
M````+(<"``X````]AP(`$0```$R'`@`+````7H<"`!H```!JAP(`70```(6'
M`@`V````XX<"`"8````:B`(`%@```$&(`@`:````6(@"`"T```!SB`(`"@``
M`*&(`@`&````K(@"``T```"SB`(`#````,&(`@`.````SH@"``8```#=B`(`
M"@```.2(`@`<````[X@"``X````,B0(`$P```!N)`@`2````+XD"`"0```!"
MB0(`'0```&>)`@`4````A8D"`"@```":B0(`00```,.)`@`/````!8H"`"``
M```5B@(`/P```#:*`@`5````=HH"`!0```",B@(`#P```*&*`@!T````L8H"
M`",````FBP(`&P```$J+`@`L````9HL"`!P```"3BP(`(@```+"+`@`;````
MTXL"`"4```#OBP(`&0```!6,`@`;````+XP"`!H```!+C`(`*P```&:,`@`:
M````DHP"``\```"MC`(`&0```+V,`@`+````UXP"``<```#CC`(`"````.N,
M`@`&````](P"``<```#[C`(`"0````.-`@`4````#8T"``L````BC0(`!@``
M`"Z-`@`8````-8T"``<```!.C0(`$P```%:-`@`)````:HT"`%X```!TC0(`
M2````-.-`@`_````'(X"`$<```!<C@(`.````*2.`@!;````W8X"`"$````Y
MCP(`,@```%N/`@`*````CH\"``P```"9CP(`$````*:/`@`I````MX\"``@`
M``#ACP(`$@```.J/`@`_````_8\"`(X````]D`(`/````,R0`@!(````"9$"
M`$X```!2D0(`"0```*&1`@`5````JY$"`!8```#!D0(`#P```-B1`@`:````
MZ)$"`"`````#D@(`)````"22`@`2````29("`#T```!<D@(`:````)J2`@`P
M`````Y,"`"@````TDP(`)P```%V3`@`0````A9,"`#(```"6DP(`'P```,F3
M`@`B````Z9,"`"0````,E`(`,````#&4`@`9````8I0"`"X```!\E`(`*P``
M`*N4`@`N````UY0"`"H````&E0(`,0```#&5`@`E````8Y4"`!````")E0(`
M!0```)J5`@`+````H)4"``H```"LE0(`"P```+>5`@`*````PY4"`"P```#.
ME0(`"````/N5`@`,````!)8"``D````1E@(`#````!N6`@`7````*)8"``L`
M``!`E@(`"0```$R6`@`'````5I8"`!,```!>E@(`"0```'*6`@`(````?)8"
M``8```"%E@(`"P```(R6`@`+````F)8"`!````"DE@(`#@```+66`@`;````
MQ)8"`!````#@E@(`!P```/&6`@`5````^98"`!@````/EP(`$0```"B7`@`4
M````.I<"`!H```!/EP(`%0```&J7`@`2````@)<"`!D```"3EP(`&````*V7
M`@`)````QI<"``L```#0EP(`&@```-R7`@`I````]Y<"`!(````AF`(`)0``
M`#28`@`G````6I@"``\```""F`(`"@```)*8`@`:````G9@"``8```"XF`(`
M!````+^8`@`)````Q)@"`!@```#.F`(`$@```.>8`@`1````^I@"`!$````,
MF0(`&@```!Z9`@`P````.9D"``X```!JF0(`$````'F9`@`.````BID"``4`
M``"9F0(`"0```)^9`@`)````J9D"``D```"SF0(`!0```+V9`@`)````PYD"
M`!(```#-F0(`!@```."9`@`-````YYD"``4```#UF0(`"0```/N9`@`+````
M!9H"`!`````1F@(`&@```"*:`@`8````/9H"``L```!6F@(``@```&*:`@`*
M````99H"``D```!PF@(`#0```'J:`@`*````B)H"`!@```"3F@(`"0```*R:
M`@`&````MIH"`$0```"]F@(`*@````*;`@`8````+9L"``8```!&FP(`"@``
M`$V;`@`,````6)L"``H```!EFP(`#0```'";`@`&````?IL"``H```"%FP(`
M&````)";`@`,````J9L"``T```"VFP(`#P```,2;`@`+````U)L"``T```#@
MFP(`"````.Z;`@`*````]YL"`!@````"G`(`"0```!N<`@`&````)9P"`"$`
M```LG`(`(````$Z<`@`H````;YP"``L```"8G`(`&````*2<`@`<````O9P"
M``H```#:G`(`#````.6<`@`+````\IP"``4```#^G`(`$@````2=`@`2````
M%YT"``8````JG0(`&P```#&=`@`,````39T"`"$```!:G0(`!0```'R=`@`%
M````@IT"``8```"(G0(`#@```(^=`@`C````GIT"``L```#"G0(`#0```,Z=
M`@`.````W)T"`!P```#KG0(`%@````B>`@`Q````'YX"``P```!1G@(`#P``
M`%Z>`@`.````;IX"``(```!]G@(`#P```(">`@`(````D)X"`"L```"9G@(`
M)````,6>`@`V````ZIX"`"\````AGP(`&````%&?`@`R````:I\"`"@```"=
MGP(`*````,:?`@`>````[Y\"`!X````.H`(`70```"V@`@`<````BZ`"`!,`
M``"HH`(`>@```+R@`@!9````-Z$"`#0```"1H0(`,P```,:A`@`Y````^J$"
M`%$````TH@(`7@```(:B`@!;````Y:("`"8```!!HP(`)@```&BC`@`]````
MCZ,"`"L```#-HP(`,P```/FC`@`W````+:0"`#4```!EI`(`'@```)ND`@`6
M````NJ0"`(````#1I`(`0````%*E`@!"````DZ4"`#$```#6I0(`)P````BF
M`@`G````,*8"`"X```!8I@(`.P```(>F`@`X````PZ8"`.0!``#\I@(`(0``
M`.&H`@!1`````ZD"`!0```!5J0(`5````&JI`@`R````OZD"`#@```#RJ0(`
M+@```"NJ`@`9````6JH"`$H```!TJ@(`+@```+^J`@`:````[JH"`!P````)
MJP(`*@```":K`@""````4:L"`$(```#4JP(`/P```!>L`@!U````5ZP"`'(`
M``#-K`(`4@```$"M`@!`````DZT"`#D```#4K0(`-0````ZN`@`@````1*X"
M`!4```!EK@(`F@```'NN`@`=````%J\"`!T````TKP(`*P```%*O`@`I````
M?J\"`"T```"HKP(`(P```-:O`@`>````^J\"`"<````9L`(`&````$&P`@`O
M````6K`"`"8```"*L`(`/0```+&P`@`B````[[`"`#D````2L0(`'0```$RQ
M`@`3````:K$"`#H```!^L0(`*````+FQ`@!#````XK$"`"D````FL@(`2@``
M`%"R`@`G````F[("`!@```##L@(`0````-RR`@!I````';,"`#(```"'LP(`
M/@```+JS`@`Z````^;,"`#H````TM`(`8P```&^T`@!,````T[0"`$L````@
MM0(`2P```&RU`@!*````N+4"`#\````#M@(`-````$.V`@`R````>+8"`$<`
M``"KM@(`(P```/.V`@`M````%[<"`#,```!%MP(`,0```'FW`@`L````J[<"
M`$L```#8MP(`5````"2X`@!.````>;@"`%L```#(N`(`,@```"2Y`@`M````
M5[D"`$T```"%N0(`40```-.Y`@`R````);H"`"L```!8N@(`)````(2Z`@!6
M````J;H"`#0`````NP(`-P```#6[`@`F````;;L"`"H```"4NP(`+@```+^[
M`@`N````[KL"`"X````=O`(`B````$R\`@"&````U;P"`-````!<O0(`$P``
M`"V^`@`F````0;X"`#D```!HO@(`+````**^`@!(````S[X"`"L````8OP(`
M3````$2_`@`@````D;\"``H```"ROP(`P0```+V_`@`^````?\`"`"<```"^
MP`(`10```.;``@`Z````+,$"`%P```!GP0(`2P```,3!`@!+````$,("`#L`
M``!<P@(`-0```)C"`@`X````SL("`"0````'PP(`(0```"S#`@`0````3L,"
M`$<```!?PP(`)@```*?#`@`U````SL,"`"\````$Q`(`)P```#3$`@`D````
M7,0"`$<```"!Q`(`/@```,G$`@`.````",4"``8````7Q0(`!P```![%`@`$
M````)L4"``P````KQ0(`"P```#C%`@`,````1,4"``L```!1Q0(`!0```%W%
M`@`0````8\4"``,```!TQ0(`#0```'C%`@!H````AL4"`&<```#OQ0(`!P``
M`%?&`@`5````7\8"``0```!UQ@(`!P```'K&`@`&````@L8"``4```")Q@(`
M"0```(_&`@`5````F<8"`!8```"OQ@(`"P```,;&`@`*````TL8"``L```#=
MQ@(`$@```.G&`@`-````_,8"``(````*QP(`!P````W'`@`'````%<<"`!(`
M```=QP(`#````##'`@`8````/<<"``8```!6QP(`#@```%W'`@`,````;,<"
M``,```!YQP(`*P```'W'`@`$````J<<"``<```"NQP(`"````+;'`@`K````
MO\<"`$<```#KQP(`.@```#/(`@`[````;L@"`"(```"JR`(`+0```,W(`@`C
M````^\@"`"8````?R0(`*@```$;)`@`E````<<D"`",```"7R0(`+````+O)
M`@`A````Z,D"`#P````*R@(`.@```$?*`@`U````@LH"`"L```"XR@(`+@``
M`.3*`@`N````$\L"`"D```!"RP(`+@```&S+`@`K````F\L"`#````#'RP(`
M+@```/C+`@`I````)\P"`"D```!1S`(`,P```'O,`@`D````K\P"`"X```#4
MS`(`*@````/-`@!#````+LT"`"D```!RS0(`+````)S-`@`L````R<T"`"T`
M``#VS0(`)P```"3.`@`B````3,X"`!T```!OS@(`*P```(W.`@`L````N<X"
M`#<```#FS@(`+````![/`@`,````2\\"`!<```!8SP(`"@```'#/`@`,````
M>\\"`!0```"(SP(`$P```)W/`@`@````L<\"`#$```#2SP(`)`````30`@`)
M````*=`"`"0````ST`(`#P```%C0`@`<````:-`"`!0```"%T`(`$````)K0
M`@`Q````J]`"``@```#=T`(`"````.;0`@`/````[]`"`!4```#_T`(`$P``
M`!71`@`C````*=$"`"8```!-T0(`)P```'31`@`?````G-$"`!8```"\T0(`
M"0```-/1`@#A````W=$"``@```"_T@(`$@```,C2`@`9````V]("`!H```#U
MT@(`"0```!#3`@`,````&M,"`!L````GTP(`'````$/3`@`4````8-,"`!H`
M``!UTP(`!@```)#3`@`W````E],"`!4```#/TP(`%P```.73`@`'````_=,"
M`!,````%U`(`%P```!G4`@`A````,=0"``L```!3U`(`/````%_4`@`)````
MG-0"`"L```"FU`(`$````-+4`@`0````X]0"`!4```#TU`(`-`````K5`@`.
M````/]4"``\```!.U0(`$````%[5`@`:````;]4"``L```"*U0(`&P```);5
M`@`+````LM4"`"0```"^U0(`"@```./5`@`;````[M4"``<````*U@(`)P``
M`!+6`@`'````.M8"``D```!"U@(`"0```$S6`@`[````5M8"``8```"2U@(`
M#@```)G6`@`3````J-8"`!8```"\U@(`"@```-/6`@`(````WM8"``<```#G
MU@(`$P```._6`@`(`````]<"``L````,UP(`'````!C7`@`H````-=<"`",`
M``!>UP(`)@```(+7`@`/````J=<"`!````"YUP(`'````,K7`@`/````Y]<"
M`"0```#WUP(`$@```!S8`@`6````+]@"`",```!&V`(`"P```&K8`@`3````
M=M@"`!@```"*V`(`%@```*/8`@`P````NM@"``\```#KV`(`%@```/O8`@`%
M````$MD"``<````8V0(`%P```"#9`@`$````.-D"`#,````]V0(`$````''9
M`@`"````@MD"`!$```"%V0(`(@```)?9`@`+````NMD"``,```#&V0(`!P``
M`,K9`@`)````TMD"``8```#<V0(`#0```./9`@`*````\=D"`!0```#\V0(`
M%0```!':`@`1````)]H"`#8````YV@(`'@```'#:`@`:````C]H"`%L```"J
MV@(`1`````;;`@!'````2]L"``L```"3VP(`,P```)_;`@`+````T]L"``<`
M``#?VP(`%P```.?;`@!+````_]L"`!0```!+W`(`#P```&#<`@`(````<-P"
M``0```!YW`(`!````'[<`@`6````@]P"``4```":W`(`!@```*#<`@`(````
MI]P"``0```"PW`(`"0```+7<`@`.````O]P"``4```#.W`(`%P```-3<`@`@
M````[-P"`"$````-W0(`)0```"_=`@`0````5=T"``(```!FW0(`!````&G=
M`@`*````;MT"``D```!YW0(`!0```(/=`@`"````B=T"`!\```",W0(`,0``
M`*S=`@`J````WMT"`!8````)W@(`%0```"#>`@!.````-MX"`!X```"%W@(`
M$P```*3>`@`S````N-X"`&@```#LW@(`*@```%7?`@!@````@-\"`#H```#A
MWP(`20```!S@`@`<````9N`"`!@```"#X`(`C0```)S@`@`0````*N$"`"<`
M```[X0(`*@```&/A`@!\````CN$"`"<````+X@(`4P```#/B`@!2````A^("
M`"P```#:X@(`.`````?C`@!C````0.,"`&8```"DXP(`*@````OD`@`[````
M-N0"`"8```!RY`(`,P```)GD`@`R````S>0"`"(`````Y0(`-````"/E`@`Y
M````6.4"`#@```"2Y0(`.````,OE`@`_````!.8"`#\```!$Y@(`+0```(3F
M`@`P````LN8"`"4```#CY@(`+P````GG`@`P````.><"`"0```!JYP(`)0``
M`(_G`@`S````M><"``X```#IYP(`#@```/CG`@`-````!^@"`(,````5Z`(`
M"````)GH`@`>````HN@"`!````#!Z`(`$P```-+H`@`E````YN@"``P````,
MZ0(`C0```!GI`@"(````I^D"`$0````PZ@(`+@```'7J`@`4````I.H"`#H`
M``"YZ@(`1````/3J`@`8````.>L"`!(```!2ZP(`)@```&7K`@`C````C.L"
M`!H```"PZP(`&````,OK`@!6````Y.L"`!8````[[`(`$0```%+L`@`+````
M9.P"``4```!P[`(`!@```';L`@`(````?>P"``4```"&[`(`&P```(SL`@`0
M````J.P"`!$```"Y[`(`'@```,OL`@`?````ZNP"`!$````*[0(`!P```!SM
M`@`$````).T"``T````I[0(`!````#?M`@`#````/.T"``D```!`[0(`#```
M`$KM`@`.````5^T"``<```!F[0(`"````&[M`@`%````=^T"``L```!][0(`
M'````(GM`@`&````INT"``H```"M[0(`"0```+CM`@`.````PNT"``\```#1
M[0(`!P```.'M`@`(````Z>T"``H```#R[0(`"P```/WM`@`+````">X"`!(`
M```5[@(`#0```"CN`@`'````-NX"`!`````^[@(`"@```$_N`@`6````6NX"
M``<```!Q[@(`!````'GN`@`+````?NX"``L```"*[@(`$````);N`@`,````
MI^X"``D```"T[@(`!P```+[N`@`,````QNX"``4```#3[@(`"````-GN`@`$
M````XNX"``D```#G[@(`!@```/'N`@`'````^.X"``,`````[P(`%P````3O
M`@`"````'.\"``L````?[P(`!@```"OO`@`'````,N\"``<````Z[P(`#@``
M`$+O`@`M````4>\"``0```!_[P(`!````(3O`@`3````B>\"`!<```"=[P(`
M"P```+7O`@`"````P>\"``<```#$[P(`!@```,SO`@`(````T^\"`!````#<
M[P(`$@```.WO`@`(`````/`"``H````)\`(`!P```!3P`@`*````'/`"`#(`
M```G\`(`!P```%KP`@`)````8O`"`!$```!L\`(`!0```'[P`@`"````A/`"
M``L```"'\`(`#P```)/P`@`.````H_`"``$```#%!```0P,``%P&``#1`P``
M.`D``$8'```[`0``[`(``/P!``````````````(%``#;!P``````````````
M````UP<````````M!```0@4```````#A!@``\P8```````"6`P```````$8(
M``#\`P```````#H$````````R@@``.X`````````#````'H'````````````
M`#X!````````'0D`````````````E@```)T%``#``0```````(,)```]"```
M10@``*((```M"0``2P$``,,$``"8`0``$`<``-P%``!""0```````#@'``!,
M"0`````````````(`P``=`@```````#X!0```````/0%``"K`0``OP@`````
M``#_!0``?@D``$('``#*`@``.`,``!@#``!U"```W0@```````"0!@``````
M`*\!``#Z`@``^0<``)$$``"8!@``>`0```````!`!```(`,``$X'````````
M"@$``'X&````````>`$`````````````)P8``)('```G!0``H@D``,P(``#O
M!0``TP0````````V`@```````!T%``#X"0``900``&$)````````@0,```4'
M``!%````W0$``,(#``#7`@```````&`%``"9!@````````````!F!P```@8`
M`'8(``#4`P`````````"```+!@``^`@`````````````*@D``"L```":!P``
M;@4``%`(`````````````-X%``#Y````@@4``/X(``#0`0``"`@``,D)``#6
M````[@D``!@)``!+`@``9@8```````","0```P<```````"%`@``;@(``#T%
M``!@`P```````.4%```$`P``W@$```````"H!P``Y`<``-0"````````````
M``````"`````Y@0``!<)``!=!@``CP,``+0```#\"```J@$``/8%``"I!0``
M$`4``*L$``"@!@``Q`8```````!R!0``P0$```````````````````````#_
M`@```````%,`````````#PD``)P&``!0!0``+P<`````````````M0```&(#
M``#K`P```````"H#````````H@0``.L&``#;`@``(`D``)T)``#U!0``UP4`
M`'@'```""```40$``$0)```\"`````````````#L"````````"(!``!G"```
MMP(``,X!```U`@``=P(```````"?"```6`,``)($`````````````.L```#]
M````%`,``+@)````````B`8```````!0!@``.0@``'@%```&`@``EP4``&X'
M``"N"0``8`@``*4#``"<`@``40@```L"``"G!P``^P(``,@%````````````
M`'$&``#7!@``-`D``-T'``!I!```$@<``'D&````````V@<````````[`P``
MK@,``+X#``"I`0``K`(``*``````````_P<``#`&```&"0``$P@``/`'``!]
M"```1`$``/$$``"O`@``MP$``$T#```U!P```````(L&```S!P``````````
M`````````````(0"`````````````'8'``"&!```F00``&T(````````70,`
M`&@(``#W`0``L`,``+@#``#=`@``F@@```8`````````&P4``+T'``"%````
M``````````!0`0``3P0``*(!``!J"0``2P8``!`"``!#````T04```````!`
M````]00```````"[````!`@``#8&```I!P``@P(``'8)````````G@(`````
M``"C!0``!@8```````!U````I0D``&L(````````TP@``)H`````````A`D`
M``````!<`@``@P$``)(&```7!P```````$8$````````0@8```````#'!P``
M`````&L#````````*0@```````#%`0``*`(```````">`P``_@,````````!
M"```60D``%H!``!5!@``K@4``-D%`````````````!X(``"1!0```````.(!
M````````DPD``($&````````20```%,(``#M!@```````!X!```-"```````
M```````B"`````````````!E`````````&P)``!)`@``?````!4&``!%!0``
M?PD`````````````IP@``,4```#%!0``[P0``-<$``"+!0``,0,```````#G
M`P``,0``````````````]P0``',&``"1!P``A`<``$,)````````````````
M``#&!0```````!D!````````(P,```````"F"````````-8(```#"```%0(`
M`)P'``!O"0```````!\'````````8PD``%,"``"$!0```````(P```"^!```
M@0```(D#``"L!``````````(``##`@``?`@``-L)````````O`,``-X#```M
M!0````````````#8!0````````````````````````````"M"```$P$`````
M````````CP8``.4(``!G!```W@8``)`#``!<"```/0D````````?!@``OPD`
M`,8"``#W"````````$T&``",!```D@```'`&``````````````````#U`@``
M,P```%P#``")!0``F@$`````````````]P8``&````![`0``^0(``-L&````
M````-@```/0```"N"```N`4``#$"````````NP@``#(&`````````0D``%P$
M``".`P``W@<``%0)``!<`````````/\!````````Y08``"<'``!S`@``FP,`
M`+H)``!E`P``0@@``+\"```V!```)`,``.,$````````(04``/$)``#P"```
MK0(``",'``#L````=0$``````````````````$D!`````````````&D`````
M````BPD```$%``"I`P``D`$``),"`````````````"````"!"0```````!0"
M````````M0,``%@%````````'P$``,0"``!#`0``RPD``+0%``#P`@``I0@`
M`+(%``"*"```50,`````````````N@0``*D)````````^@4``'<```!;!@``
M`````,\(``"7````F0D``$L'``````````````````#'"```@@8```````#D
M"0```````,$'```H````_P8``/L'``!#!```>@(``*@%`````````````'P%
M````````E`<``.H`````````H`4````````I!`````````````"R!@``XP``
M`(`#```)!0``BP``````````````1P@``,4"``#7"0```````*,)````````
M%`@``"T!```/`0```````/\$``!K!0```````$H````V!0``,P@``%0"``!(
M`@``2P0```````!M``````````````".!@``G````"H&``#,`````````'L`
M``!O````/@4`````````````:`(``#X)``"K"0``"`(``%8)````````H0<`
M`',$```T!@``"0```"`%```E`0``<P,``&(%`````````````$T%```6"0``
MSP4``,,!````````N@(````````P!```[`$``)0````!`@``*`$`````````
M````CP@``.P#``"@!````````-P&```L`0``#`8```````"("```^08``#L&
M``"3!P``H0,`````````````)`4````````L"```O0$``-`)```8`@``````
M`&4&````````G@D```````#8!```````````````````PP<``.4```#O`P``
M3@D```````!:!```5P(``,X$``!+!0``_`4``.@$``#E!P``)`0``+0"```^
M!```F`,``+8$``![!0``?P<`````````````H0$``(4&``"I!```!`<```P#
M``!,`@``Y@D``/@#``"!`0``%@8````````#!@``,`$```````#N!P``_0(`
M`%H&````````]`8``$$'``#L!P``%@$``!L```!2`@``]P4``.4#``!6"```
M`````.,!`````````````#L$```A````^00``%,&```1`````````#($````
M````8`D``-('```K"```R0,``-\!```.!```#P<```0$````````#@8``.(%
M```H!`````8``-(```#Z````*08``#\"``#?!P``?`(``/D#```D"```9PD`
M``````"N!P``H@4``*0)``"J!@```````#,%``#0`@``I`4```````!&`0``
M`````%T(``!3`P```````/H(``#_`P```````!T"``#A`0``3`<``&0#````
M````'P4```````#@````!`8```T```!R!```N`$````````R````A@,``!(&
M``"$!```N@<``'0"``")"```>P8``"`(``#(!```?@```,<&```X!0``P@``
M`*L"````````9`$``!@(``!M`0``=P@``$\````:!0`````````````4!P``
M^`````````"/`@``#P```#L%``"!!P``F0$``.L"```L!P```````,$&````
M`P``.04``$(#`````````````.H"``""!P```````&4!````````(P$``#P%
M````````9`4``(\$``"*`@```````"T&```]!P``9`@``&D#``!L`@``UP``
M``````"]!@``'0$``#P```!G!P``'08`````````````I`<```````#6"0``
M``````````#-!`````````X!``"W````=P4``!\#``#M````R`$`````````
M````?0$``$<%``#2!0``P0(``%<````9"0``7@0```````"6!0``*0D``'`"
M``!G!0```````*4&````````:@8``!H$``"7"```E@(```````"M`0``%@,`
M``\(```]`0``"`0``'T$``"A!```80@``$\'``#D!0``>P@``!\"``!N!@``
M``````````!5"0``*@(```D&```1"````````!L(``"2`0``P@4``',(``!I
M!0```````)<&````````^0@``-X(```3````U@8``/P'``#`!@```````'$(
M``!_"````````$L````B!````````````````````````-H#``#@!@``90@`
M`#()````````'`(``&\"``"V"0``.@@``(X"``!I!P``'P@```````#*`0``
M8P,``"X'``#B!@``]P````$!``#0!0``:`0``/,#```_!P``[`0``#X"``#^
M!@``#@4``````````````````,8```#G"````````.X$````````U`<``#((
M````````K`,``%\%```["```\`,``%\&``#$````50$```````"A"```(P8`
M``````"0"```"@0``-\```````````````````#3!P``-P0``#\```!Q`@``
M`````````````````````+D%````````1PD``)\&````````5PD``#`#``!-
M"```P````#0#```^````*04```````#G````$00``)$&``!&`@``X@```(\!
M````````L`8`````````````,04``*@"``![`P``"@```(X$```*!0``L`<`
M``````!:````.P<``#P"``"N!@````````````"!!```/00``+X)````````
MO`(``*0`````````/`8``!<!````````A`$``*8"``#B!P``E0```'@#````
M````!P(``,@"```````````````````^`P````D`````````````N08``*("
M```)`0``7@```'P$``!T!```9@0``#4)````````.@4``+<(``"C!P``````
M``L'```"`@``Q`0``$`)```N!`````````````!I`0```````/,(```+`P``
MC04``(H#```?"0```````-\$````````U@,``)H%``"K````LP@``$X(``#^
M`@``5P,``(<#````````V`````````!A`````````.T%``!Z"````````-,#
M``#M"```'@0``!0````*`@``CP```*H"```'`P``T````$<$````````Z0D`
M`.\(```=````BP<````````E`@```````#`"``!'`0``F0```.D$``!9`0``
M`````/(%````````U0@``)<"``#'````'`$``)0!``#B"0````````````"T
M"0``;0<``)`)`````````````,\````F!@``8P````````!,"```I`0`````
M``!;!P``804``"T#``!H!P``L`@``)D'``!Q!0``&@,````````6`@``$`,`
M`)4)````````L0$```````#F`0````````````#]`P```````+H(```K!P``
M>@,``)\"```M````!0$````````=`P```````%<$```M"```_`8```````#[
M!```9`0``(<'```*`P``!P4``*D"``")`0``GP4``'('``#`"0``AP@`````
M``!=!```V@@``&('``#1"```5`8```````!P"0``:@@``*8!````````[00`
M`*$%````````?P4```````"&!0``)````-L````+!0``X00``(8)``"R`P``
MSP(``!`$```Z"0``(P@```````#,!@``L@<``+4$``"6!P``3P8``#L)````
M````C`,````````T"```;@D``$\)``!^!````````!0&```<`````````.8(
M``!'!P```````/X'``"""```]`,```````!L!0``T00```````"=`0``'@<`
M`"P#``"&````@P8``````````````````&8`````````"0<``#H&``"0`@``
M,@(``"T'``!(````W`,```````````````````````#A!0``"P@``(,`````
M````N`0``#8)``!K"0``'`0`````````````GP```&<"```"!P``(`(``%\$
M``")"0``\P0``````````````````-0(``#)!```(`8``#4&```F`0``U`0`
M`*H'````````?04`````````````QP4``(@)```3`P``T`,````````@!P``
M-`$``&H```"#!```7@4``/,```!9"```A`8```````"]`@``K0D``)L%````
M`````````"L)``#P!@```````&<```"C!@``.@<```````"O"0``<@8``'4$
M``!K````S`<``+4%```G`0``YPD``/8(``#^!0``8@$``*8'``">"```````
M`%$'``!;`P``N@4``(\)``#&"````````%(#``"U"0```````&8#``#B`@``
M+`4``(T"`````````````'8#``"T"```-P,``.`#`````````````"\)```C
M!```10,``"()``#,!`````````4#``!.`0``RP$``$$$``!^`P``S0,``,8)
M`````````````,8&``!L"```O`D``'("``!^`0``U0$``$P&``"M````R`@`
M``````#N"```80$``,X)```C`@``1P,``(D&``"*`````````'<&```5"```
M:@$``%\)``!A`P``Q0<```````"#`P```````-`(``!G`0``\0$```\#``#(
M"0``W`<```$#```7!```>@```(4(````````````````````````V`@`````
M``!C"```^`$`````````````<PD``.0$````````'@(``"D"``!5!```]0<`
M`%`)``"_`0``[0<``!("````````N`<``+$(``!W`P``NP8``$H$``#A`@``
M`````!4!````````)`D``'D#``#Q`P``*@$``#<(``"-"0``:@0``!T'```9
M`P``/@<``&P&````````B`<``+8%```(!P``0@$``$@!````````=PD```,)
M```Z`P``T`0``'0'``"L!@``)P@``'H)````````]`<``'H$``!.!@``PP``
M``````!`!P``/@@``.X!````````+@@``````````````````-P!``"9!0``
MV08``*`#```,"0``NP$``,L"``"`"0``1P8``*T'``"<`0``!P$``,@`````
M````'`<```````"P"0``"P0``+T#``#.````(0<``'D%``#A`P``B0(``.@!
M``````````````H)````````#P8``&<#``"[`@``"````"0"``#(!@``G@8`
M````````````H@<````````3"0```````)H$````````U@<``-4#``"3!0``
MF`0```````"5`@```````$$(``#P!```?P```!(%``!*`P``2@<```````"`
M!0```````$$"``#\!```VP@```````"G`P``]`0`````````````BP@`````
M````````G`4``%0$``"0!P``-`0``.H#``#<"```:P8``-(#````````?@@`
M``````!<!P``%`D``.$'```#!```@@$``+D"``!%!@```````+0&``".`0``
MXP4``-L!``!I!@``_04``.H'````````!`D``!4```#.`P````````4%``!(
M"```XP8``!L"````````J`0``$\"``"C````,@<``+$"``#G!P``P@$``#$(
M``#[````F@,```````#.!0``G0```%P)````````Q`4````````G````+`(`
M`.D(``#S`@``R@8``!H&``````````````````"K!P``WP(``$H(``#3!@``
MP0,``'P'````````V@0``)(%``"^!P``2@4``#$&``"-!````````'H&``#9
M````$P<``/8)``!T``````````````"7!````@0``+,$```+`0``^P@`````
M`````````````#L```#E`0``I@0`````````````E`4``,L&``"5`0``[@,`
M``<'```K!0``,PD``((```!("0``FP0``,((````````]PD``(4)``!S!P``
M2@D```````";````6`````````!A`@``60(``-H)`````````````-8"````
M````2PD``.\&``!6`P```````,\'``!2!0``?`D``%`"````````5P$`````
M``"'`0``X`0``"X```#:````;P8`````````````4@@``)@)``!4````*0``
M``````"5!0``6`0``*T&````````QP(``$,%``"."0``'@D`````````````
M*P8```````"8````V0D```````","```6@<``-T&````````90D```````!2
M````(0$````````%`@``7@D``+$&````````8`0``.((``"R"0``````````
M``"N`@``*P(``)L)``!8"```1`@```````!Q````,0<``*4!``!%!P``)00`
M``````#P````;```````````````;08``&X``````````````%,%``">````
M`````$D%```;`0``=P0``,T```#O`0``TP(``%L```"4"```1P(````````'
M````_`````````!,````&`<``'@``````````````#0%```B`P``?@4`````
M``#T`@``QPD``,P)``"=`P``:`4``.P&`````````````$$!````````?P$`
M`(<```!?"```&00``(X````8!0``+P0``*P```##"0```````(8!``"N`0``
M`````$$%``!\`P```````*8``````````````+X```!``@``&P,``/T'````
M````7P```-("```@!```J@0``!8$````````)@`````````0!@``&@(``!$!
M``"'!@``A04``$X$````````M`$``````````````````"X%``#``P``B00`
M`*L(``!A!````````.,(````````L0```%$)```W`0```````+\'``!)!@``
MK`4``,()``#R`0```````$$&``"F"0``O`0``+X%````````L`0``&P!````
M````H@,``"0&``!V`0``4@8``$0$``!K!P```````*\'```!!@``=`$``%,)
M````````T@0```````#``@``T0$```````#<!```R0$``,H)``#I`@``M08`
M``()``"(``````````````#[!@``M@(``%8!`````````````"<"``#V`P``
M`````)<)```7!@``<`@``*0#``"S!@``Z@8``+L)`````````````(<%```E
M!0``V@4``(@%``#W`P``"0,``(`&``#8`@``%@4`````````````A0$``!<#
M``!!``````````<(``#'`P````````````""!```Y`,``*<%```;"0``Y`@`
M`)\!````````L04````````>!@``9@4``$<```"H````<@@``*`(````````
MV0(``&X#````````*@@````````J!P``'`,``!\$```-!@``M@<`````````
M````+@,`````````````$@``````````````F`@```````#<`@``L0D``/,)
M``!%`@```````"4)``#<`````````*,!`````````````.@"```5!P``:`,`
M`'8&````````XP(```````!J`@``G0<``(,(```&`P``^`0``"$$``!S!0``
M0P@``+<&``#V`@```````'L)`````````````(D`````````10D``%<&```<
M"````````"D#``!3`0``.0D``!$"`````````````*D'``#&!P``X`@``*\$
M``#U!@``ZPD``+,"``#8`P``Q@$``%\!``!$`@``$P(``$8&```2`0``0@0`
M`.T#````````S`4``%,'```%"0``!`(```````!:"0```````%($``#U````
M/`D``,<!``````````````````!;!0``I@8``#,"`````````````.@)````
M`````````"P$``#@`0```````#$)``"(`0``S@<```X"``!:"```M@,``.D&
M````````^`(``'P&`````````````(,'``#/!````P(``.8'````````M`<`
M``````"O````Q`$``/0!``".!P``8@```+D```#*!0``IP8``+D)``"5!@``
M(@(``+P'`````````````/$````9!@``J`@``'@)``!``P``-00``'4'``!,
M!0``60,```````#2"```'0@``*<$```5!````````%T"``#:`0``O@$``"0'
M``#:`@``?P,```````"S`P`````````````[`@```````.X&````````+P(`
M`$T)````````50@``&`!``"C!```W`D```T'``#=!```>@4``"8$````````
M6P0``+P%``#J!```Z0<``.<%````````.0,``,\!``!H````]P<``%H"``"8
M!P``:P$```````"A`@`````````````9"``````````````;!@```````,D&
M``"]````2@8``.8&``"!!0``&@<``!`(````````Z@D``*H)````````2`<`
M``````#!"```Q`,``+@```"F`P``"PD``.L$``#"!@``604``+X(``"+`@``
ML`$``#@"````````/P4``*H(``!,!```(@8``,0)``#5!````````"L$``#=
M"0``K`<```````!``0``8@0``)8!````````Z````,D```#,`P``````````
M``#>````.08```D$``#F!0``3@,```D"``"V`0``U`8`````````````V`<`
M`/8```#>`@``?`$```````#"`@```````%H%``!<!0```````$0%``#(`P``
M70```+L%``"%`P``)P0``-0%````````4@$````````L!@```````-$'``"-
M`0``-0$``*<)``"*!0``````````````````:@<```````#%"0``<`,``/8!
M``#1!@``LPD```0%```D`0``I00``"T"``"?!P``\P<````````0`0``'`8`
M`,,(``"S````?0D``$4$``#>"0``D@D``&0&````````:0(``&4'``!L!P``
M``````P(````````20<``$D)``"W"0``Z`4`````````````[0$``(`'````
M````FP<``)`$``!J`P``.@```&,&``#N`@``N@```"X)````````<0,```P$
M``#^`0```````$L(````````<@D``*D&``!>"```?P8``#D'``!?`@``<0<`
M`+````!^!P``%@<``.H(``!N`0``/PD``$(````_`0``FP(````````-`P``
M3@```.8#````````G0(``"$(``!0`P```````&T#```(!@````````````#[
M`P``Q08``"$)``"*"0``9@@`````````````*P$``"8#``#4"0``1`<`````
M```&!0```````&X(````````<`<``)8)``"\`````````!D%``!O!```7@8`
M`-L%`````````````+\````_!@``.````/`!```W`@``<0D```````!K`@``
M*`8``-$````%!```JP4``,L'``````````````````!;"```BP0```````#$
M!P``FP8```\"```\`P``#0D``#8'``"O`P``-0```.$)``!9!@``$@,``$D#
M``#[`0```````#8#`````````````-L#````````<P$``#T#``!B!@``C`(`
M```````,!P``_00``(("```F"```8`(``$8```````````````````"4`P``
M`````"(````]!@```````(4'`````````````!$#```X`0```````/L%``#C
M`P```````(8'```%````:0@``$T$``!9````'@4``-X$``#E!```D@(``+D(
M``"R`@``4@D``'T&````````=08``#@&``#&!```R@````````!V````N0$`
M`)X'``#I````N@,``.D!``"5!P````````````!D`@``-`(```````"\`0``
MK0,``/4)````````2`0``'0%``"N````G`D``!X#``"5"```30`````````0
M"0````$``.@&``````````````H&``!D````O04````````]````G`@``%L"
M``"[!P``!`$```````">`0``Y`````````!K!```````````````````E`0`
M`'@&``#W`@``\`D``((#````````P0D``!D'``!#!P``X@,``-()``"D`@``
M!P0``#4(``":"0``G`0``%@)```E"```RP,``"8"````````8@D``.`"``!_
M`@``%`$``"$&``#+!````````````````````````*L#```.````S0@``/H'
M``"8`@``J@4```````!]````CP<``+,%`````````````,8#``#-`@``I0``
M`%@"`````````@`````````(`0``>0@``&4"```7````[@4``,0(```:````
M`P$```````#5!P``PP4``*H#``",!P```````#@$`````````````.@'````
M`````````!D"``!C!```````````````````K`$```````"6!```/`$`````
M``#Z!@```````'H!````````*`D``$("````````F`4```````#Q!P``/0(`
M``````"3`P``.0(``$$#``!O`0``E@@``.`'``#5````4`<``-D$``!R`0``
M10$``.0"````````OP4``'`$``!=!0``I`@``(4$```U`P```````'4%````
M````#0$``.$(```,`0``V0<``/$&````````9P8```````#R"0```````/`%
M``#;!```GP,``,@'``#)!0````````````!7!P````````````!Q`0``P`0`
M`&@!``#%"```S04``'0&````````?0(``+@(````````(`$``$P!````````
M'@```)4$``#7`0``,P,``"8'``"V`````````*8%````````<@,``,`(````
M`````````/8$```W````&`0``/T&``!L`P```````-\#````````````````
M````````$0<``/('````````8`<``(P%``"?"0``Y0(``-,!``"0````\@``
M`"@'``#,`0``8P4``#`'``"6!@```````#D$```T!P``,P$```````!I"0``
M&````(X(````````\@8```````"3!```30<``&H%````````'00``&((``#O
M`@```````)0"```$````/`0``-\%``#"!```T`<``*@#```,!0``H`<``!H)
M``#2`0``9@D``"$"```4!```\0@``'(````6````P04``*D```!!"0``6`$`
M`)D"``"*!```EP<``/\(````````50(``*H```#]`0``+P$``$,"``";"```
MA@(```H(``"M!0``IP```'X"````````D0,```````![!P``<`4```````!Y
M`0``EP,``-T#``#R`@```````.L'``"I"````````````````````````/0)
M``#6`0```````.@(````````408```````!V!0``!PD```````#)!P``````
M`$\#```Z`0``$@@``.L!``"Y!`````````````"D!@``6`8``*`)``#)`@``
MH08```````!1!0``A`@``%8```!9!P``MP,```````":!@``(P4```````"\
M"```NP,``,P"``!4!0```````'0)``#G!````````(@$``"R`0``F0,`````
M```C````!@$``%@'```"`0``)@4``%P!``"-`P``>00``/D!``#7"```\P4`
M```````&"```>P0``,<$``#Z`P``80<``,D(````````&@@``+H!``#%`P``
M]@8`````````````O@8``$P#``#M"0``#`(``/P"```O"```@`(``,`%``!=
M!P``TP```-D#```&!P```````#`(```9`````````-0````:`0``DP8`````
M````````A@8``!$&``"R````G`,``,('``"Z!@``=0(``&0)````!0``6P$`
M`.($```I`0``M@8``-D(``"!"````````%X'````````C0```!4)```W!0``
M``````````"E!P``\@0``+$$````````B@<``%0!```'!@``/P0``#@(``#/
M"0```P```&0'``"C"```1````$\%````````````````````````70$``%<(
M``"U`@``KP@```````"4!@``-@@``+L$``!H"0```P,``(<"``!$!@``,00`
M``````"C`P``2`4```````"*`0``RP4```````!O"```1`,```````"+`0``
M`````/8'``!O!0```````(8(``!0!```V`$```````#G`@````````D)``"X
M`@`````````````E!P``-P8`````````````'`4``/((``#1`@``V`D`````
M````````O0D``!4#```8`0``,0$````'```0````2`8``.H!```L````>0<`
M`"(%````````T@8``$8)```J!````````!8(``"/!0``40,``%<%````````
M-04``+T(``#."```[P`````````&!````````'D```"O!@``\@,````````%
M"```)@D``+X"``!]`P``-PD``,$$```O!@```````)T$``#D!@``HP(`````
M``"Y`P``$04``)((``#G!@```00``&T%`````````````'$$````````8P(`
M`#(#`````````````(<)````````M0@``($"``#F````U@0``,T'```C"0``
MWP@``-4%```+````"@<```X#``!.!0``XP<``-`&````````&P<``%T)``#@
M!0``X0```$\(````````TPD````````A`P```````!P)```O!0``/P,``.<!
M````````0P8```````!&!0``5@<``%L)``"(`@```````-4&``!.`@``````
M`#,&``"@`0``J`D``!($``#=````Z0,``/@'``"3`````````*(&``!Y"0``
M2@$``"\```"T`P``5`,``&T$```("0``C`8``+$'``"U`0``A````-\)``!1
M````M0<``+P&``"*!@``FP$``+((```."0``$P8``/H$``!E!0``M@@``+$#
M``#1"0``I0(``*@&``"_!```@`@``,H#````````0`8``),!``#-`0``0`4`
M`)4#`````````````/@&````````EP$```X'````````/@8``$T"``"G`@``
M``````````!)"```/P@``+($````````S@8``/X```#Y!0``\04`````````
M````LP<```````!&`P```````%$$```N`@``,@4```````#/!@``=@0``-<#
M``#.`@```````'@"``!Y`@``D0D``%D$``"'!```/`<````````-!```````
M`-T%```7"```H0````````#T"```GP0``&T)````````O00`````````````
M`````)D(````````I`$``!L$``!(`P````````````!S``````````````"=
M"```)0,``,`'````````,@$``-4"```8!@``9@(``+\&```?````+@$``/4(
M```2"0``#@@``"P)````````_P```,$```!5!P``ZP@``$\!````````X`D`
M`'@(````````B`,``)X$```J````LP$````````!!P``7@$``)$!``!*`@``
MM`0``)0)``![`@``0`@``+`"```P"0``=0,``%\#```Y````@@D``&@&```J
M!0```````+D'``".!0````````````!O!P``````````````````8P<``.8"
M``"E!0``7P<````````S!``````````$``!]!P``5`<``$D$``"N!```L`4`
M`!,%````````OP,``-@&``#*!```808`````````````U0D````````H!0``
M"`4``(`$`````````````'0#``!5!0``;`0``%X#``"W!0```````+<$```5
M!0``C`$``%8"`````````````,\#```B!P``V@8```````"1`@``C0<``#8!
M``!+`P``G@4``'<!```G"0``JP8``!<%``!P`0``Z`,``.P%``"B````_0@`
M`(0#````````)0```,L(``":`@``?P0``!,$```P````"0@``(T(``!1`@``
M=0D``(,%```1"0``MP<``.,)````````*`@``.P)``!6!0``[P<``-8%````
M````IP$``"<#````````Z04``%4```!3!```5@8``-0!``#U`P``=P<``.T"
M``!4"```;P,``/X$``##!@``#P4``,T)``"A"0``*P,````````T````````
M`.0!```/!```[PD```,%``"L"0``=@(``,L```#E"0``TP4``*\%``!-`0``
M.0$``"4&``"=!@```````"@#``!>`@``4````(`!``!B`@``]0$```````"-
M!@```````%8$```P!0``8`8``),(````````%`4```4&````````6@,`````
M````````+@8```(#``#J!0``R@<``!<"``!P````\0(``*T$````````H`(`
M`#<'```-!0``D0````T"``!C`0```````/H!``!N!```4@<```````#-!@``
M````````````````\P$``(L#`````````````"\#``#?!@``.@(``&T"``"1
M"````````)`%````````PP,``*@!``#9`0````````````")!P``N`8``.L%
M````````D@,``*P(``!F`0```"`@("`@(%1O.B``("`@($1A=&4Z(``@("`@
M1G)O;3H@`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y
M*0`@*'EE<W1E<F1A>2D`(%-U8FIE8W0Z(``@870@`"!I;B``(P`E+C)F34(@
M+R`E+C)F34(@("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!M97-S86=E<R!H
M879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D
M(&%S(&YO="!S<&%M+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S
M86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2X`)60@=&\@)60@;V8@
M)60@365S<V%G97,`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I
M;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`
M)7,@86QR96%D>2!E>&ES=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S
M(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&%T("5S("5S`"5S(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B
M96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S(&AA
M<R!A8V-E<'1E9"X`)7,@:&%S(&-A;F-E;&QE9"`E<RX`)7,@:&%S(&1E8VQI
M;F5D+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E
M<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S
M('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S('1E;G1A
M=&EV96QY(&%C8V5P=&5D+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S
M(&YO="!F;W5N9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('1O
M("5S(&]F("5S`"5S('=I<VAE<R!T;R!A;6UE;F0@)7,N`"5S('=I<VAE<R!T
M;R!M86ME('EO=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I=F4@
M=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!<'!L>2!T
M:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A
M<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E
M96XN*0`H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L
M>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T
M:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"A396YD
M(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S
M(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4
M(&)E(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J`"H@
M4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN9R`E<R`E<P`L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@;65S<V%G
M92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86TN`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S
M<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H
M87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+@`Q,#`@8VAA<F%C=&5R<P`Q,#`P
M(&-H87)A8W1E<G,`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@
M:&]U<G,`,C4P(&-H87)A8W1E<G,`-3`P(&-H87)A8W1E<G,`02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9`!!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES
M(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92X`02!M97-S86=E('EO=2!H879E
M('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F
M<F]M('1H92!R96-I<&EE;G0N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-(%-H;W=E<G,`04TO
M4$T`04Y$`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B
M;W1T;VT`06)S;6ED9&QE`$%C8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT
M(&9R;WIE;BX`06-C;W5N="=S(&YA;64Z`$%C8V]U;G1I;F<`06-T:6]N<P!!
M9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(
M97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N
M97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`
M061D('-O=7)C90!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1H:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O
M:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B
M(&%S(&%N(&%T=&%C:&UE;G0N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D:71I;VYA;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+@!!9&1I
M=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E
M(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I
M97=E9"`E<RX`061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',`061D
M:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E
M<RX`061D<F5S<P!!9&1R97-S($)O;VL`061D<F5S<R!";V]K<P!!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES
M=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S
M`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S
M`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L
M;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E
M(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE.@!!;&P@;65S<V%G97,@
M:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B
M92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD(&QI;FME9"!A='1A8VAM
M96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N
M`$%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H
M<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&QO=R!F:6QT97(@<G5L97,@=&\@
M8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O>#\`06QL;W<@;75L=&EP;&4@861D
M<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L
M<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)
M35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T
M92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E
M('1E>'0Z`$%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ`$%L
M=V%Y<P!!;'=A>7,@<V%V92!A='1A8VAM96YT<P!!;65R:6-A;B!386UO80!!
M;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE
M(&%T=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B!S86ED.B``06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&]C8W5R
M960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+@!!;F1O<G)A`$%N9V]L
M80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N<W=E<F5D`$%N
M<W=E<F5D(&UE<W-A9V5S`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D
M80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@1FEL
M=&5R<P!!<'!L>2!&:6QT97)S('1O("5S`$%P<&QY(&9I;'1E<B!R=6QE<R!U
M<&]N(&QO9V=I;F<@;VX_`$%P<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)
M3D)/6"!I<R!D:7-P;&%Y960_`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R
M;W9E`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@
M4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E
M;&5T92!T:&ES('!U8FQI8R!K97D_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD
M960A*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\`07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9
M(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\`07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H
M97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T
M('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\`07)G96YT:6YA
M`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)R:79A;"!4:6UE`$%R
M=`!!<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`
M07-I82]086-I9FEC(%)E9VEO;@!!<VL`07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE
M;G0@8V]L=6UN<P!!='1A8V@`071T86-H($9I;&5S`$%T=&%C:"!A(&-O<'D@
M;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_`$%T=&%C
M:&5D($9I;&4Z`$%T=&%C:&5D(&9I;&4@(B5S(B!E>&-E961S('1H92!A='1A
M8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"X`071T86-H
M960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N
M`$%T=&%C:&UE;G0`071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T
M86-H;65N="!T>7!E`$%T=&%C:&UE;G1S`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+@!!='1E;F1E97,`071T96YT:6]N`$%T=')I8G5T97,`075G
M=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VEM<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T;VUA
M=&EC86QL>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE
M('-E;F1E<B!I<R!I;B!M>2!A9&1R97-S8F]O:S\`079A:6QA8FQE($%D9')E
M<W,@8F]O:W,Z`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E
M`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8U]K('1O("5S`$)A8VL@=&\@
M)7,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P
M87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A
M:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"
M87-E;&EN90!"8V,`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96QO=R!I<R!T
M:&4@<F%W('1E>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E
M+@!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&%C:VQI<W0`0FQO
M8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@
M4V5T=&EN9W,`0FQO8VL@5'EP90!";&]C:R!I;6%G97,@:6X@2%1-3"!M97-S
M86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E<W1E9#\`
M0F]D>0!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI
M8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!"
M;W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4`0F]T<W=A
M;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"
M=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#7VAA
M<G-E=`!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@
M8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+@!#86X@;F]T(&-O
M;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@`$-A;B!N;W0@9&ES
M<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S
M86=E(&EN('1H92!C=7)R96YT(&UA:6QB;W@N`$-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#
M86YC96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A
M;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R
M9"!I=',@8V]N=&5N=',N`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V
M92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@
M97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D
M+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#
M87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA
M;B!)<VQA;F1S`$-C`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@
M<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H
M;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R
M=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H
M86ER(%!E<G-O;@!#:&%N9V4`0VAA;F=E($%L;`!#:&%N9V4@1F]L9&5R`$-H
M86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E
M<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W(&UE<W-A9V5S(&%R92!S
M;W)T960N`$-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S
M+@!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E
M('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA
M;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;"X`0VAA<@!#:&%R86-T97)S('1O(&1I<W!L87DZ`$-H96-?:R!,:6YK+BXN
M`$-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAE8VL@7T%L;"].;VYE
M`$-H96-K(&%L;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I
M;"!F<F]M.@!#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A
M9V4_`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#
M:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@06-T:6]N.@!#:&]O
M<V4@82!M86EL('-E<G9E<CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@
M=7-E<FYA;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E
M9"!L:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@
M861D:6YG(&%D9')E<W-E<RX`0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S
M(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`$-H
M<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z
M("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K("5S('1O(&-O
M;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S
M97(@8V%N('9I97<N`$-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92X`
M0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+@!#;&EC:R`E
M<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RX`
M0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!#
M;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@
M=VEN9&]W+@!#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM86=E<P!#;&EC:R!O
M;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N
M('-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"X`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E
M<W,@8F]O:P!#;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O9B`E
M<R!I;B!Y;W5R($%D9')E<W,@0F]O:P!#;&EC:V%T96QL('9I82!(5%10`$-L
M:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S
M86=E('1O('1H92!S96YD97(`0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL
M;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860`0VQO<V4`0VQO<V4@5VEN
M9&]W`$-L;W-E('1H:7,@=VEN9&]W`$-L;W-E9"!&;VQD97(`0VQO=61S`$-L
M;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S90!#;VQL87!S
M92!!;&P`0V]L;&%P<V4@06QL($9O;&1E<G,`0V]L;&%P<V4@1F]L9&5R`$-O
M;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R($EN9&EC871O
M<CH@`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M
M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT
M`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S
M92!A;F]T:&5R(&UE<W-A9V4`0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R
M871E('=I;F1O=S\`0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@1U5)
M(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE(&9E871U<F4I
M/P!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S`$-O;F9I9W5R92`E<P!#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D
M:7-P;&%Y960N`$-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RX`0V]N
M9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P
M=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A
M:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D`$-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!#;VYT:6YU90!#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RX`0V]N=')O
M;"!3+TU)344@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@=VAE;B!N97<@;6%I
M;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@
M;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O;G9E<G0@=&5X='5A;"!E
M;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\`0V]O:R!)<VQA;F1S`$-O
M;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'D@=&\@9F]L9&5R`$-O<G)E
M8W0`0V]R<F5C=&5D(%1E>'0`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-R96%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&-R96%T92!T:&4@5D93
M(&)A8VME;F0Z("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S
M97)V97(@<V%I9#H@)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!E>&5C=71E(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,N`$-O=6QD(&YO="!E>'1R86-T('1H92!R97%U
M97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N`$-O=6QD
M(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@
M87)C:&EV92X`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I
M8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E
M860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@
M<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3
M:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E
M9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E($9O;&1E<@!#
M<F5A=&4@2V5Y<P!#<F5A=&4@5FER='5A;"!&;VQD97(`0W)E871E(&$@;&EN
M:P!#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@;VYE
M`$-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE=R!T
M<F%S:"!F;VQD97(`0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ
M92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"!A
M;F0@9&5L971E('-P86TN`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E
M<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R
M<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R
M96YT(&%C8V5S<R!T;R`E<P!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@
M<W1Y;&4`0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R
M;VT@;W1H97(@86-C;W5N=',N`$-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I
M;"X`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#
M=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER
M:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX
M+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=%]E`$1A=&%4<F5E($)R
M;W=S97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$
M95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C;&EN
M960`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N
M=&ET>0!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN
M9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5G871E9`!$96QE=&4`1&5L
M971E("5S(%!U8FQI8R!+97D`1&5L971E($-U<G)E;G0@2V5Y<P!$96QE=&4@
M1F]L9&5R*',I`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE
M=&4@5FER='5A;"!&;VQD97(`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$
M96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4`1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R
M96UO=&4@<V5R=F5R/P!$96QE=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@
M;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M`$1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F
M(&UO;G1H/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$
M96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R
M;W<`1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T960@=&AE(&%T=&%C
M:&UE;G0@(B5S(BX`1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$96QI
M=F5R>2!T:6UE`$1E;FUA<FL`1&5N>2!R97%U97-T`$1E;GD@<F5Q=65S="!F
M;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N`$1E<V-E;F1I;F<`1&5S8W)I8F4@
M=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<P!$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN
M=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I;2!S
M:6=N871U<F5S/P!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@
M<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&-O;F9I<FUA=&EO
M;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\`1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G
M90!$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_`$1I
M<W!O<VET:6]N`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$
M;R!.3U0@;6%T8V@`1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA
M:6P`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<`!$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M
M.B!C;VQU;6X`1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\`1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L
M:6,`1&]N90!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"`E<R!I;B`N
M>FEP($9O<FUA=`!$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@
M9FEL92D`1&]W;FQO860@1F]L9&5R*',I`$1O=VYL;V%D($9O;&1E<BAS*2!;
M+GII<"!F;W)M871=`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N`$1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T`$1R869T
M`$1R869T(&9O;&1E<@!$<F%F=',@9F]L9&5R.@!$<F]P(&1O=VX@;&ES=`!$
M<G5G<P!%+4UA:6P`12UM86EL($%D9')E<W,`15)2`$524D]2.B!9;W5R(&UE
M<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`16-U861O<@!%9&ET`$5D
M:70@0FQA8VML:7-T`$5D:70@0FQO8VL`161I="!&:6QT97)S`$5D:70@1W)O
M=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M
M:7-S:6]N<R!F;W(@)7,`161I="!6:7)T=6%L($9O;&1E<@!%9&ET(%9I<G1U
M86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$5D:70@5VAI=&5L:7-T`$5D
M:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@
M>6]U<B!B;&%C:VQI<W0`161I="!Y;W5R(&9I;'1E<B!R=6QE<P!%9&ET('EO
M=7(@<')E9F5R96YC97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U
M;G1S+@!%9&ET('EO=7(@=VAI=&5L:7-T`$5D=6-A=&EO;@!%9WEP=`!%;"!3
M86QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T
M:6]N`$5M;W1I8V]N<P!%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+@!%
M;7!T>2!&;VQD97(H<RD`16UP='D@5')A<V@@9F]L9&5R`$5M<'1Y(%]4<F%S
M:`!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_`$5N86)L92!3+TU)344@
M9G5N8W1I;VYA;&ET>3\`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(&UE<W-A9V4@<')E
M=FEE=W,_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N8W)?
M>7!T:6]N($]P=&EO;G,`16YD`$5N9"!F;W)W87)D960@;65S<V%G90!%;F0@
M;65S<V%G90!%;F0@;65S<V%G92!F<F]M("5S`$5N9"!Y96%R`$5N;&%R9V4@
M161I=&]R`$5N=&5R(%!A<W-P:')A<V4`16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T
M:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R`$5N=')Y("(E<R(@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K`$5Q=6%T
M;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@<V5N9&EN9R!R97!L
M>3H@)7,N`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17-T;VYI80!%=&AI
M;W!I80!%=&AN:6,`175R;W!E`$5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D
M+@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M<&%N9`!%>'!A;F0@06QL`$5X<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L
M9&5R`$5X<&%N9"!.86UE<P!%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@
M=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_`$5X<&%N
M9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O
M;&1E<G,@=FEE=S\`17AP86YD:6YG`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T
M90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T
M;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y`$9E96QS
M($QI:V4`1F5E;',@;&EK93H@`$9E=&-H($UA:6P`1F5T8V@@36%I;"!I;B!A
M('-E<&%R871E('=I;F1O=S\`1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG
M(&]N/P!&971C:&UA:6PZ(`!&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RX`
M1F5W(%-H;W=E<G,`1FE?;'1E<G,`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@
M3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@
M;F]T('-U<'!O<G1E9"X`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%-E='1I;F=S
M`$9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\`1FEL=&5R
M('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`$9I;'1E<G,`
M1FEL=&5R<R!.3U0@06-T:79E`$9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G
M90!&:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!-86EL8F]X(%!A9V4`
M1FER<W0@4&%G90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T
M`$9O7W)W87)D`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]L9&5R
M($YA=FEG871O<@!&;VQD97(@4W5M;6%R>0!&;VQD97(@<VAA<FEN9R!I<R!N
M;W0@96YA8FQE9"X`1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"X`1F]N="!#
M;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED
M92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUA="!O9B!M97-S
M86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A
M=&5D('1O9&%Y`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S
M`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D
M(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&;W)W87)D<P!&
M<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R964O0G5S
M>2!);F9O<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E
M<W0`1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]?;0!&<F]M`$9R;VT@061D<F5S<P!&<F]M('1H92``1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9W9#H`1G=D.B``1G=D.B`E=2!&
M;W)W87)D960@365S<V%G97,`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@3W!T:6]N<P!'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R
M;6%N>0!'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI`$=H86YA
M`$=I8G)A;'1A<@!':79E;B!.86UE`$=O('1O($UE<W-A9V4`1V]E9&5L`$=O
M;V=L92!396%R8V@`1W)A;G0@86-C97-S`$=R87ES8V%L90!'<F5E8V4`1W)E
M96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P
M<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E
M<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA
M;F$`2$5210!(5$U,`$A434P@5F5R<VEO;B!O9B!-97-S86=E`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA
M>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP
M('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AE<F4@:7,@=&AE(&UE<W-A9V4@>6]U
M('=E<F4@8V]M<&]S:6YG.@!(:61D96X`2&ED9&5N(&EN(%1H<F5A9"!6:65W
M`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E9`!(:6=H`$AI9V@@4')I
M;W)I='D`2&EG:&5S=`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO
M;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M
M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@
M3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R
M96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E
M<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N
M=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!D;R!Y;W4@
M=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/P!(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@
M82!R97!L>0!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y
M`$E-05``24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*0!)34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&]V97(@4U-,`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D
M(&-E<G1I9FEC871E*0!)34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"D`24U!
M4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL(%-E<G9E<G,`24Y"3U@`25`@061D
M<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T
M('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA
M=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)
M8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EG
M;F]R90!)9VYO<F4@06QL`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G
M92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ
M`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T`$EM<&]R="!+97D`26UP;W)T
M($ME>7!A:7(`26UP;W)T(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D`26UP
M;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,`26UP;W)T(%!U8FQI
M8R!+97D`26UP;W)T(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!0=6)L:6,@4R]-
M24U%($ME>0!);7!O<G0@4R]-24U%($ME>0!);7!O<G0@;6)O>"!&:6QE`$EM
M<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N`$EM<&]R="P@4W1E
M<"`E9`!);7!O<G1A;G0`26UP;W)T86YT(&UE<W-A9V5S`$EM<&]R=&5D("5D
M(&UE<W-A9V5S(&9R;VT@)7,N`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T97(`26YB;W@`
M26YC;'5D92!A(&)R:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A(')E
M<&QY/P!);F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\`26YC
M;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN
M9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN
M9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97D`26YF;W)M
M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97D`26YF;W)M871I;VX@;VX@
M4&5R<V]N86P@4'5B;&EC($ME>0!);FQI;F4`26YS97)T($-?;VQU;6X@069T
M97(`26YS97)T($-E<G1I9FEC871E($AE<F4`26YS97)T($EM86=E`$EN<V5R
M="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R90!);G-E<G0@4&5R<V]N
M86P@4'5B;&EC(%!'4"!+97D@2&5R90!);G-E<G0@4'5B;&EC(%!'4"!+97D@
M2&5R90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L
M=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT
M97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@
M8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A
M9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS
M97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!)
M;G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS
M97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`
M26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV
M86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+@!);G9A
M;&ED($%D9')E<W,`26YV86QI9"!296UO=&4@36%I;&)O>`!);G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!)
M;G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@
M861D<F5S<SH@)7,N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@
M9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A
M;&ED(&ME>0!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@
M87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P97)S;VYA;"!01U`@<')I
M=F%T92!K97DN`$EN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN`$EN
M=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@
M<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O
M<GD`26YV97)T`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L
M86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U
M97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S
M92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I
M9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*
M=7-T:69Y(%)I9VAT`$M"`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N
M>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+
M97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME
M>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T
M<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2V5Y('-U8V-E<W-F=6QL>2!S
M96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!2
M97!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`
M3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8P!,87-T($AA;&8`3&%S="!-86EL8F]X(%!A9V4`3&%S="!086=E`$QA
M<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@
M;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA
M=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE
M9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:5]N:R!!='1A
M8VAM96YT<P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT
M96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%
M87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E
M<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M`$QI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+@!,:6YK<P!,:6YU
M>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="!A
M;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E96X_
M("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@;VYL>2!S964@8V]N=&%C=',@=&AA
M="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*0!,:7-T+4%R8VAI=F4`3&ES
M="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S
M8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG(&EN('1H92!(96%D97(`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N
M:6$`3&]A9&EN9RXN+@!,;V-A;"!-86EL8F]X.@!,;V-A;"!T:6UE.B``3&]C
M86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@:6X@=&\@)7,`3&]G
M(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y
M;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C
M=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W<@4')I
M;W)I='D`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S
M`$QO=V5R(')O;6%N(&YU;6)E<G,`3&]W97-T`$QU>&5M8F]U<F<`34T`34]4
M1`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-
M86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8`36%C:6YT;W-H($9I;&4`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@
M061M:6X`36%I;"!0<F5V:65W<P!-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE
M8W0@=&\Z`$UA:6QB;W@`36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T
M:6]N<P!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M
M87``36%R8V@`36%R9VEN`$UA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A
M<R!3965N`$UA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96X`
M36%R:R!A<SH`36%R:R!D:69F97)E;G0@;&5V96QS(&]F('%U;W1I;F<@=VET
M:"!D:69F97)E;G0@8V]L;W)S/P!-87)K(&UE<W-A9V5S(&%S('-E96X_("A)
M34%0(&]N;'DI`$UA<FL@<VEM<&QE(&UA<FMU<#\`36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-
M871C:"!!;&P@475E<FEE<P!-871C:"!!;GD@475E<GD`36%T8VAI;F<@9FEE
M;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($%T=&%C
M:&UE;G0@4VEZ90!-87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!A
M='1A8VAM96YT<R!R96%C:&5D+@!-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@
M<VEZ92!R96%C:&5D+@!-87D`36%Y;W1T90!-961I8VEN90!-965T:6YG($-A
M;F-E;&QA=&EO;@!-965T:6YG($EN9F]R;6%T:6]N`$UE971I;F<@4')O<&]S
M86P`365E=&EN9R!297!L>0!-965T:6YG(%5P9&%T90!-965T:6YG(%5P9&%T
M92!297%U97-T`$UE;6)E<G,`365N=2!&;VQD97(@3&ES=`!-96YU(&UO9&4Z
M`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!#;VUP;W-I=&EO;@!-97-S
M86=E($1A=&4`365S<V%G92!/<'1I;VYS`$UE<W-A9V4@4V5A<F-H`$UE<W-A
M9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92!V97)I9FEE9"X`365S<V%G92!6:65W:6YG`$UE<W-A9V4@97AP:7)E
M9"X`365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G92!F<F]M
M("5S`$UE<W-A9V4@;6%T8VAE<P!-97-S86=E(')E9&ER96-T960@<W5C8V5S
M<V9U;&QY+@!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A
M=F5D('1O("5S`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN`$UE<W-A9V4@
M='EP90!-97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W+@!-
M97-S86=E<R!T;P!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-
M971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`
M36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN
M('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S
M:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF
M:65D($1A=&4`36]D:69Y`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!2
M97!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N
M=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`36]S=&QY($-L
M96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4`36]V92!$;W=N
M`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@
M=&\@9F]L9&5R`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',`375L=&EP87)T+V%L=&5R;F%T:79E`$UU;'1I<&QE('-E
M;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T
M`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$Y/5$4`3F%M90!.86UE(&%N
M9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y`$YA;6EB:6$`3F%U<G4`3F5E
M9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL
M;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=F5R('-A=F4@871T
M86-H;65N=',`3F5W`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!&
M;VQD97(`3F5W($UA:6P`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA
M;"D`3F5W(%IE86QA;F0`3F5W(&UE<W-A9V5S`$YE=R!W:6YD;W<@*%]B;&%N
M:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!-97-S86=E`$YE>'0@4&%G
M90!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`
M3FEU90!.;P!.;R!#97)T:69I8V%T92!F;W5N9`!.;R!%;F-R>7!T:6]N`$YO
M($ME>7,@:6X@2V5Y<FEN9P!.;R!-97-S86=E<P!.;R!01U`@<'5B;&EC(&ME
M>2!I;7!O<G1E9"X`3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N=`!.
M;R!0=6)L:6,@2V5Y<R!&;W5N9`!.;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O
M<G1E9"X`3F\@871T86-H;65N=',@9F]U;F0N`$YO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A
M=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@9F]L9&5R('-E;&5C=&5D+@!.
M;R!F;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"X`3F\@
M9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!F;VQD97)S('=I=&@@;F5W(&UE
M<W-A9V5S`$YO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,`3F\@;&]C
M871I;VX@:7,@<V5T+@!.;R!M97-S86=E(&)O9'D@=&5X=`!.;R!M97-S86=E
M('-U<'!L:65D+@!.;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H+@!.
M;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F
M96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME
M<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P
M96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@
M;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I
M;F<@<VEG;G5P<RX`3F\@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R
M=&5D+@!.;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@
M<&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"X`3F\@<G5L
M97,`3F\@<VED97,`3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R
M960N`$YO('-P96QL:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N<P!.;R!T96UP
M;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97(@
M<W!E8VEF:65D+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R
M=&EC:7!A;G0`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/
M+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<FUA;`!.;W)T:&5R;B!(96UI
M<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F
M=&5R`$YO="!"969O<F4`3F]T($1E;&5T960`3F]T($1R869T`$YO="!);7!O
M<G1A;G0`3F]T(%!E<G-O;F%L`$YO="!A(&1I<F5C=&]R>0!.;W0@82!V86QI
M9"!P=6)L:6,@:V5Y+@!.;W0@9&5L971E9"!M97-S86=E<P!.;W0@:6UP;&5M
M96YT960N`$YO="!I;7!O<G1A;G0@;65S<V%G97,`3F]T('-E=`!.;W0@<W5P
M<&]R=&5D+@!.;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I;64`3F]T
M97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E
M<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB
M97(@;V8@;6]N=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I
M9B!D96QE=&EN9R!M;VYT:&QY+@!.=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F
M;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F
M(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D
M:7-T<FEB=71I;VX@;&ES="X`3TL`3U(`3V)J96-T`$]B:F5C="!#<F5A=&]R
M`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!M97-S
M86=E<P!/;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D+@!/;6%N
M`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N
M;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H
M96T_`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"X`3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE
M8W1E9"!F;W(@=&AI<R!A8W1I;VXN`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W
M`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S
M:6=N960@4R]-24U%('!A<G0N`$]P96YE9"!&;VQD97(`3W!E;G,@=&AI<R!L
M:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;F%L
M(%!A<G1I8VEP86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,
M:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II
M;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M
M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!-
M86EL($%C8V]U;G1S`$]T:&5R($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4`!01U`@
M1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'0@365S<V%G90!01U`@16YC
M<GEP=&5D($1A=&$`4$=0($5R<F]R.B``4$=0($5R<F]R.B!.965D('!A<W-P
M:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!01U`@3W!T:6]N<P!0
M1U`@4&%S<W!H<F%S92!);G!U=`!01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P
M;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!01U`@4'5B
M;&EC($ME>0!01U`@4'5B;&EC($ME>2!497AT`%!'4"!0=6)L:6,@2V5Y(&9O
M<B`B)7,@*"5S*2(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0(%!U8FQI
M8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!01U`@
M4'5B;&EC($ME>7)I;F<`4$=0(%-I9VX@365S<V%G90!01U`@4VEG;B]%;F-R
M>7!T($UE<W-A9V4`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!01U`@<')I
M=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@<'5B;&EC(&ME>2!S
M=6-C97-S9G5L;'D@861D960N`%!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N
M('1H:7,@<WES=&5M+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C
M=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E
M('9E<FEF:65D+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV
M92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+@!0
M2%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-
M(%0M4W1O<FUS`%!/4#,`4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*0!0
M3U`S(&]V97(@4U-,`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I
M9FEC871E*0!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"D`4$]0,RP@;F\@
M5$Q3`%!?2%`@4VAE;&P`4&%D9&EN9P!086=E("5D(&]F("5D`%!A9V4@=VET
M:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4`4&%G92!W:71H('1H92!,87-T
M(%5N<V5E;B!-97-S86=E`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R
M86=U87D`4&%R="AS*0!087)T;'D@0VQO=61Y`%!A<W-P:')A<V4`4&%S<W!H
M<F%S92`H06=A:6XI`%!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D
M+@!087-S<&AR87-E.@!087-S<&AR87-E<R!C86X@;F]T(&)E(&5M<'1Y`%!A
M<W-P:')A<V5S(&1O(&YO="!M871C:`!087-S=V]R9`!087-S=V]R9"!I;F-O
M<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A
M=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A
M<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R
M;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R
M8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O<B!T:&ES
M('5S97(@8V%N(&YO="!B92!C:&%N9V5D+@!097)S;VYA;`!097)S;VYA;"!)
M;F9O<FUA=&EO;@!097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+@!097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F
M=6QL>2X`4&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T
M960Z(`!097)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL
M>2X`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER
M;@!0:7AE;',`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@
M86YD(&9O<G=A<F1S/P!0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E`%!L
M871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R
M(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T
M92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&5N=&5R('1H92!N86UE
M(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE
M.@!0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R
M:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P
M87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN`%!L96%S92!E;G1E<B!T
M:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO
M=2!W:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC
M92!P97(@)7,@<V5S<VEO;BX`4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U
M;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@=7-I
M;F<@8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@
M<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R!L;V<@:6X@86=A:6X@
M:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@
M871T86-K97)S(&9R;VT@:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@
M87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92X`4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y
M;W5R('!A<W-W;W)D+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE+@!0;&5A
M<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N`%!L
M96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H
M96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A
M<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T
M:6]N<RX`4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B
M96QO=RX`4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E
M87)C:"X`4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H:7,@
M;W!E<F%T:6]N+@!0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T
M;R!T:&4@<FEG:'0Z`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M
M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG
M(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4&]W97)E
M9"!B>2!(;W)D90!0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S
M("@G+2T@)RD_`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M`%!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0
M<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V
M:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0
M<FEN=`!0<FEN="!D;V-U;65N=`!0<FEO<FET>0!0<FEV871E($ME>0!0<FEV
M871E($ME>2!087-S=V]R9`!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4')O:F5C=',`4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S
M96YT.R!D969A=6QT('1O($Y/`%!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C
M:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,`4')O;7!T('1E>'0`4')O
M=&]C;VPZ`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC
M(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"X`4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2X`4'5E<G1O(%)I8V\`4'5R7V=E($1E;&5T960`4'5R9V4@1&5L971E9`!0
M=7)G92!&;VQD97(H<RD`4'5R9V4@5')A<V@@:&]W(&]F=&5N.@!0=7)G92!M
M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N
M="!O9B!D87ES+@!0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O
M;&1E<C\`46%T87(`475E<GD`475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F
M34(@("@E+C)F)24I`%%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250`
M475O=&$@<W1A='5S.B!.3R!,24U)5`!24T$@4'5B;&EC($ME>2`H)60@8FET
M*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!2
M86EN(%-H;W=E<@!286YD;VT@1F]R='5N90!2871I;P!295]Q=65S="!$96QI
M=F5R>2!#;VYF:7)M871I;VX`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296-E:79E9"!/;@!296-E:79E9"!3
M:6YC90!296-E:79E9"!5;G1I;`!2961I<F5C7W0`4F5D:7)E8W0`4F5D:7)E
M8W0@365S<V%G90!2961I<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E8W1I;F<@
M9F%I;&5D+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H($9O;&1E<B!6:65W
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R
M;W=S97(`4F5L;V%D`%)E;&]A9"!6:65W`%)E;6%R:W,`4F5M96UB97(@=&AE
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M96UB97(@=&AE(&QA<W0@=FEE
M=P!296UO=&4@36%I;&)O>#H`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@
M0FQO8VL`4F5M;W9E($9I96QD($9R;VT@4V5A<F-H`%)E;6]V92!C;VQU;6X`
M4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V
M92!S;W5R8V4`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE
M(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!296YA;64@
M1F]L9&5R*',I`%)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN
M9R!O9B!M;VYT:#\`4F5N86UI;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!297!L7WD@=&\@3&ES=`!297!L
M86-E('=I=&@Z`%)E<&QY`%)E<&QY(%-E;G0N`%)E<&QY('1O($%L;`!297!L
M>2!T;R!!;&PZ`%)E<&QY('1O($QI<W0`4F5P;'D@=&\@3&ES=#H`4F5P;'D@
M=&\@7T%L;`!297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G90!297!L
M>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P;'D@=VET
M:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L>2U4;P!2
M97!L>2U4;SH@`%)E<&QY.@!297!O<G0@87,@26YN;V-E;G0`4F5P;W)T(&%S
M(%-P86T`4F5Q=65S="!A(%]296%D(%)E8V5I<'0`4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S="!D
M96QI=F5R>2!C;VYF:7)M871I;VX_`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`
M4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+@!297%U:7)E9"!087)T:6-I
M<&%N=`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D
M`%)E<W!O;F1E;G0@4W1A='5S(%5P9&%T960N`%)E<W5L=',`4F5S=6UE`%)E
M<W5M92!Y;W5R('-E<W-I;VX`4F5T=7)N('1O($9E=&-H($UA:6P`4F5T=7)N
M('1O($]P=&EO;G,`4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T
M97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%)E
M=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/
M<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E
M<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``
M4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P
M<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%
M`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP
M="!-97-S86=E`%,O34E-12!%;F-R>7!T960@365S<V%G90!3+TU)344@17)R
M;W(Z(`!3+TU)344@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N
M86P@<')I=F%T92!K97DN`%,O34E-12!/<'1I;VYS`%,O34E-12!087-S<&AR
M87-E($EN<'5T`%,O34E-12!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q
M=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%,O34E-12!0=6)L:6,@
M2V5Y(&9O<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"X`4R]-24U%
M(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!3+TU)344@4'5B;&EC
M($ME>7)I;F<`4R]-24U%(%!U8FQI8R]0<FEV871E($ME>7!A:7(@<W5C8V5S
M<V9U;&QY(&%D9&5D+@!3+TU)344@4VEG;B!-97-S86=E`%,O34E-12!3:6=N
M+T5N8W)Y<'0@365S<V%G90!3+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O
M;B!T:&ES('-Y<W1E;2X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L
M>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R
M>7!T960N`%,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D
M:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@=F5R:69I960N`%-!
M4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A
M9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!37W5B:F5C
M=`!380!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S`%-A:6YT($AE;&5N80!3
M86EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M
M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I
M80!3879E`%-A=F4@)7,`4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@
M:6X@<V5N="UM86EL(&9O;&1E<C\`4V%V92!$<F%F=`!3879E($]P=&EO;G,`
M4V%V92!?1')A9G0`4V%V92!A<P!3879E(&1R869T<R!A<R!U;G-E96X_`%-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V92!R96-I
M<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S<R!B
M;V]K/P!3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/P!3879E('-E
M;G0@;6%I;#\`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V:6YG('1H92!D
M<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S
M`%-C:65N8V4`4V5A<F-H`%-E87)C:"`E<P!396%R8V@@16YG:6YE<P!396%R
M8V@@4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@06YO=&AE<B!!8V-O=6YT
M`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E
M;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T
M(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A9&1R97-S
M(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D
M9')E<W-E<RX`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RX`4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG
M(&%D9')E<W-E<RX`4V5L96-T(&%N(&%C8V]U;G0`4V5L96-T(&%N(&]B:F5C
M=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@;6%I
M;"!S97)V97(@='EP90!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;&5C=&5D($%D9')E<W,@8F]O:W,Z`%-E;F0@
M2V5Y('1O(%!U8FQI8R!+97ES97)V97(`4V5N9"!,871E<W0@26YF;W)M871I
M;VX`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`
M4V5N96=A;`!396YS;W(Z(`!396YT(&UA:6P@9F]L9&5R`%-E;G0@;6%I;"!F
M;VQD97(Z`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L
M($YU;6)E<@!397)V97(`4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VX`
M4V5R=F5R.@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N`%-E="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS
M('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S86=E<RX`4V5T('1H92!8
M+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN9R!M97-S86=E<S\`4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P('5P9W)A9&4@<V-R:7!T
M<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T
M:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&%R92!&;VQD97)S`%-H87)E
M(&UA:6P@9F]L9&5R<P!3:&%R92!Y;W5R(&UA:6P@9F]L9&5R<R!W:71H(&]T
M:&5R('5S97)S+@!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E
M<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]U;&0@;&%R
M9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B
M>2!D969A=6QT/R!)="!C86X@8F4@=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R
M('EO=2!C:&]O<V4N`%-H;W5L9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE
M<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D871A/P!3:&]U;&0@=&AE(&-O
M;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\`
M4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@
M>6]U<B!M97-S86=E<R!B>2!D969A=6QT/P!3:&]W`%-H;W<@06QL($9O;&1E
M<G,`4VAO=R!!;&P@2&5A9&5R<P!3:&]W($1E;&5T960`4VAO=R!,:6UI=&5D
M($AE861E<G,`4VAO=R!-86EL:6YG($QI<W0@26YF;W)M871I;VX`4VAO=R!/
M;FQY(%-U8G-C<FEB960@1F]L9&5R<P!3:&]W(%5N<W5B<V-R:6)E9`!3:&]W
M(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R
M;VT@;65S<V%G97,_`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M(&QE9V5N9"!I;B!T:&4@;6%I;&)O>"!V:65W/P!3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@<')E=FEE=W,@9F]R('5N
M<F5A9"!M97-S86=E<R!O;FQY/P!3:&]W('!R979I97=S(&EN('1O;VQT:7!S
M/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O
M;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@26UA9V5S`%-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/P!3:&]W
M('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('1O=&%L(&YU;6)E
M<B!O9B!M86EL<R!I;B!F;VQD97(_`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO
M=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=VX`4VAR:6YK`%-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S=`!3:5]Z90!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6=N960`4VEN9V%P;W)E`%-I>F4`4VMI<"!-
M86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R
M`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``
M4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O
M;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&)Y($%R<FEV86P`4V]R="!B>2!$
M871E`%-O<G0@8GD@1G)O;2!!9&1R97-S`%-O<G0@8GD@365S<V%G92!3:7IE
M`%-O<G0@8GD@4W5B:F5C=`!3;W)T(&)Y(%1H<F5A9`!3;W)T(&)Y(%1O($%D
M9')E<W,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U
M=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R
M;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`
M4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!A;2!F
M;VQD97(Z`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P96-I86P@0VAA<F%C
M=&5R<P!3<&5L;"!#:&5C:P!3<&5L;"!#:&5C:V5R`%-P96QL(&-H96-K(&-O
M;7!L971E`%-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@
M8VAE8VMI;F<N`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3
M<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R
M="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA
M=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T
M<FEP($%T=&%C:&UE;G0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`
M4W1R:7`@;&EN96)R96%K<S\`4W1Y;&4@6T-34UT`4W4`4W5B7VIE8W0`4W5B
M:F5C=`!3=6)J96-T($9I96QD`%-U8FUI=`!3=6)S8W)I8F4@=&\@1F]L9&5R
M*',I`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('=R;W1E("5S`%-U9&%N`%-U9V=E<W1I;VYS`%-U;6UA<GD`4W5N(%)I<V4`
M4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z
M(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M
M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W
M961E;@!3=VET8V@@0V]M<&]S:71I;VX@365T:&]D`%-W:71C:"!T;R!(5$U,
M(&-O;7!O<VET:6]N`%-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N
M`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER
M:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!4
M86)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N
M`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5?>'0`5&5L
M97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R
M90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E;G1A
M=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E
M<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@1G)O;3H@
M8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z`%1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="`B)7,B`%1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:P!4:&4@36%C:6YT
M;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A
M8V-O=6YT("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&%C8V]U;G0@(B5S
M(B!H87,@8F5E;B!S879E9"X`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@
M8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@
M>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@871T86-H;65N="!W
M87,@;F]T(&9O=6YD+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]M<&]S
M92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E
M="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\`5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!4:&4@8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO
M=RX`5&AE(&-U<G)E;G0@9F]L9&5R*',I("(E<R(@=VEL;"!B92!R96YA;65D
M('1O("(E<R(N`%1H92!C=7)R96YT(&QI<W0@;V8@=7-E<G,@=VET:"!A8V-E
M<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E=')I979E9`!4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&1R869T(&AA<R!B965N('-A
M=F5D('1O('1H92`B)7,B(&9O;&1E<BX`5&AE(&5N8W)Y<'1I;VX@9F5A='5R
M97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&5V96YT
M('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82X`5&AE(&9O;&1E<B`B)7,B(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD97(@
M(B5S(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N
M($ET(&UA>2!C875S92!P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+@!4:&4@9F]L9&5R("(E<R(@=V%S(&-R96%T960@
M8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+@!4:&4@9F]L9&5R
M("(E<R(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB
M960@9G)O;2!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@8W)E871E9"X@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@
M=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S
M('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U
M8V-E<W-F=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M`%1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A
M<G0Z`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@
M8F5C875S92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U<B!A9&1R97-S
M8F]O:RX`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F
M('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O
M;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A
M=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.@!4:&4@
M;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93H`
M5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2X`5&AE(&UE<W-A9V4@
M(B5S(B!F<F]M("(E<R(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@
M;&EM:70N`%1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L
M;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"X`
M5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N`%1H92!M97-S86=E(&AA
M<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+@!4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L
M87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H
M87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+@!4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D
M+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@
M<&]P=7`@=VEN9&]W<S\`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I
M97=E9"`E<RX`5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N`%1H92!R97%U97-T960@9FEL92!D
M;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N`%1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL
M>0!4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@
M365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@9G)O;2!Y;W4@=VAE
M;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S
M('1O('-E;F0@=&AE(&YO=&EF:6-A=&EO;B!M97-S86=E+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N('-A=F5D+@!4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E
M9"X`5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+@!4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="X`5&AE('-P96-I9FEE
M9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T87-K(&AA<R!B965N(&%D9&5D
M('1O('EO=7(@=&%S:VQI<W0N`%1H92!T97AT(&]F('1H92!M97-S86=E`%1H
M92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T
M97AT(&]F('1H92!R971U<FYE9"!M97-S86=E`%1H92!T97AT(&]F('1H92!R
M971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT(&]F
M('1H92!S96YT(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G
M92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&%L
M=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N`%1H97)E
M(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+@!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N
M9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<P!4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A
M<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E
M<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@
M)7,N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I
M;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RX`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@
M9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O
M;2`B)7,B('1O("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A
M9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@
M9')A9G0N`%1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G
M93H@)7,`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D
M9&5D(&EN(&ET+@!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D
M9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92!T:&ES.B``
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RX`5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE
M(&UE<W-A9V4N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@
M86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC
M:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G
M:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N
M92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T
M86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@
M8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE
M("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S
M<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B
M:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M
M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A
M<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,`5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\`5&AI<R!M97-S86=E(&-O
M;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N`%1H:7,@;65S<V%G92!C;VYT86EN
M<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE
M9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H
M;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4:&ES
M(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M
M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F('1H:7,@;65S<V%G92!I<R!U;FMN
M;W=N+@!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@`%1H:7,@;65S<V%G
M92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O
M<FUA="`H86-C;W)D:6YG('1O(%)&0R`R,#$U*2X`5&AI<R!M97-S86=E(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R
M;6%T+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V
M:6$@4$=0+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE
M9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D
M('9I82!3+TU)344N`%1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@
M=VET:"!01U`N`%1H:7,@;65S<V%G92!T;P!4:&ES(&UE<W-A9V4@=V%S('=R
M:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R
M(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4
M:&ES('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A
M;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RX`5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:')E860@5FEE=P!4
M:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T
M`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L
M=&EP*3H`5&\`5&\@061D<F5S<P!4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M('=H:6QE(&-L:6-K:6YG+@!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I
M`%1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z`%1R86YS;&%T:6]N<P!4<F%S:"!F
M;VQD97(`5')A<V@@9F]L9&5R.@!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@
M;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM
M.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A
M;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A
M;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE
M('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E
M<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S
M+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<F5T
M<FEE=F4@<75O=&$`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O
M<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`
M56YA;G-W97)E9`!5;F%N<W=E<F5D(&UE<W-A9V5S`%5N9&5L971E`%5N9&5R
M;&EN90!5;F1I<V-L;W-E9"!296-I<&EE;G1S`%5N9&\@0VAA;F=E<P!5;F1O
M97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FAA;F1L960@8V]M<&]N96YT(&]F
M('1Y<&4Z("5S`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E
M<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@
M1&%T90!5;FMN;W=N($UE971I;F<`56YK;F]W;B!296-I<&EE;G0`56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;&]A9"!087-S
M<&AR87-E`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C
M8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E96X`56YS
M970@8V]L;W(`56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RD`56YS=7!P;W)T
M960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E($%T=&%C:&UE
M;G0@26YF;W)M871I;VX`57!D871E(')E<W!O;F1E;G0@<W1A='5S`%5P9&%T
M92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`
M57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U
M87D`57-E($-U<G)E;G0Z("5S`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0
M(&9O;&1E<B!S=6)S8W)I<'1I;VYS/P!5<V4@4U-,`%5S92!I9B!N86UE+W!A
M<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R
M871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S
M97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S
M('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E
M<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E
M;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T
M:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI
M9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W`%9I97<@)7,`
M5FEE=R`E<R!0=6)L:6,@2V5Y`%9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W`%9I97<@4&5R<V]N86P@4')I=F%T92!+97D`5FEE=R!0
M97)S;VYA;"!0=6)L:6,@2V5Y`%9I97<@5&AR96%D`%9I97<@5&AU;6)N86EL
M`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W(&%T
M=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!E=F5N=`!6:65W
M(&UE<W-A9V5S(&EN("5S`%9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN.@!6:65W('1A<VL`5FEE=R!T:&4@26UA9V5S`%9I<F=I;B!)
M<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<G1U86P@
M1F]L9&5R("(E<R(@8W)E871E9"!S=6-C97-F=6QL>2X`5FER='5A;"!&;VQD
M97)S`%9I<G1U86P@9F]L9&5R(&QA8F5L`%9I<VEB:6QI='D`5FES:6)I;&ET
M>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T
M=6YA`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D
M(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I
M`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_`%=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE
M;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@=&AE
M;2!A<R!D96QE=&5D/P!7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI
M8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\`5VAE;B!S879I;F<@
M<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_`%=H
M:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:61T:`!7:61T:"!I;B!#4U,@
M=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7
M:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!S<&5E9"!I;B!K;F]T
M<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT
M96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!9
M97,L($D@06=R964`66]U(&%R92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M
M('1H92!F;VQL;W=I;F<@86-C;W5N="AS*3H`66]U(&%R92!C;W!Y:6YG+VUO
M=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E871I;F<@82!S=6(M
M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E
M<BX`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO=2!C
M86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N`%EO=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E
M(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@=&\@;&]G:6XN
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O
M;&1E<@!9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE
M(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RX`66]U(&AA=F4@)7,@;F5W(&UE
M<W-A9V5S+@!9;W4@:&%V92`Q(&YE=R!M97-S86=E+@!9;W4@:&%V92!A="!L
M96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@
M=7!L;V%D('EE="X@07)E('EO=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI
M<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N=',_`%EO=2!H879E
M(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R<SH`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@
M<F5C:7!I96YT+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@
M9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E
M`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-
M12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9;W4@;75S="!S
M96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="X`66]U(&UU<W0@<V5L96-T
M(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%N
M(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@
M8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S
M86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C
M:69Y(&%T(&QE87-T(&]N92!F:6QE('1O(&%T=&%C:"X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+@!9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@
M)25S+@!9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N`%EO=2!W
M97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N($AE<F4@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E
M<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@<W5C
M8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S
M9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(@!9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!
M9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R
M(%!'4"!0=6)L:6,O4')I=F%T92!+97ES`%EO=7(@4')I=F%T92!+97D`66]U
M<B!0=6)L:6,@2V5Y`%EO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I
M9FEC871E<P!9;W5R(&%C8V]U;G1S.@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI
M<R!I;6%G92!T>7!E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES(&9E871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U
M;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO
M=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;65S
M<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"X`66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G
M(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E
M<G,Z`%EO=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!:
M:6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6TYO(%-U8FIE8W1=
M`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN
M:7-T<F%T:6]N`%]"8V,`7T)L86-K;&ES=`!?0TQ)`%]#8P!?1&%T851R964`
M7T1E;&5T90!?1&5L971E(%)O=P!?1F]L9&5R<P!?1W)O=7!S`%](96QP`%])
M9&5N=&ET>0!?26UA9V4@4')O<&5R=&EE<RXN+@!?26YB;W@`7TQO9R!I;@!?
M3&]G(&]U=`!?365S<V%G92!3;W5R8V4`7TUO9&EF>2!,:6YK+BXN`%]/<'1I
M;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U!R:6]R:71Y`%]2969R97-H("5S
M`%]296UO=F4@3&EN:RXN+@!?4F5P;'D`7U-E87)C:`!?4V5N9"!-97-S86=E
M`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?5&AR96%D`%]4;P!?56YD
M96QE=&4`7U5S97)S`%]6:65W(%1H<F5A9`!?5VAI=&5L:7-T`&%D9')E<W,@
M8F]O:P!A='1A8VAM96YT`&%T=&%C:&UE;G1S+GII<`!B>71E<P!C86QE;F1A
M<@!C86QM`&-L:6-K(&AE<F4`9F%L;&EN9P!F:6QE`&9R;VT`9G)O;2!T:&4@
M)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&ME>0!L:6YE
M<UT`;6%I;&)O>"!F:6QE`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!N86UE`&YO;F4`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@
M:6UP;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT`'!I>&5L<P!R:7-I;F<`
M<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W!E;&QI;F<@
M97)R;W(`<W!E;&QI;F<@97)R;W)S`'-T96%D>0!T87-K(&QI<W0`='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`
M=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`>6]U<B!B;&%C:VQI
M<W0`>6]U<B!W:&ET96QI<W0`4')O:F5C="U)9"U697)S:6]N.B!)35`@-"XP
M+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#0M,3(M,#<@,3(Z-34K,#$P,`I,87-T+51R
M86YS;&%T;W(Z($IA;B!+=6EP97)S(#QJ<FMU:7!E<G-`;&%U=V5R<V-O;&QE
M9V4N;FP^"DQA;F=U86=E+51E86TZ($1U=&-H(#QI,3AN0&QI<W1S+FAO<F1E
M+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=`H`("`@("`@06%N.B``("`@($1A='5M.B``("`@("`@5F%N
M.B``("@E<R!D86=E;B!G96QE9&5N*0`@*%-N96QT;V5T<R`E<RD`("AV86YD
M86%G*0`@*&=I<W1E<F5N*0`@3VYD97)W97)P.B``(&]P(``@:6X@`",`)2XR
M9DU"("\@)2XR9DU"("@E+C)F)24I`"5D("5S(&5N("5S`"5D(&)E<FEC:'1E
M;B!Z:6IN(&%A;B!U=R!S>7-T965M8F5H965R9&5R(&=E<F%P<&]R=&5E<F0@
M86QS(&=E96X@<W!A;2X`)60@8F5R:6-H=&5N('II:FX@9V5R87!P;W)T965R
M9"!A;',@9V5E;B!S<&%M+@`E9"!B97)I8VAT96X@>FEJ;B!A86X@=7<@<WES
M=&5E;6)E:&5E<F1E<B!G97)A<'!O<G1E97)D(&%L<R!S<&%M+@`E9"!B97)I
M8VAT96X@>FEJ;B!G97)A<'!O<G1E97)D(&%L<R!S<&%M+@`E9"!T;R`E9"!V
M86X@)60@8F5R:6-H=&5N`"5D+61A9R!V;V]R=6ET>FEC:'0`)7,@+2!/<&UE
M<FMI;F<`)7,@=FEN9V5R869D<G5K`"5S($M"`"5S($]N9&5R:&]U9'-W97)K
M>F%A;6AE9&5N("T@0F5V97-T:6=I;F<`)7,@:6YS8VAR:6IV96X`)7,@9V5B
M<G5I:V5R<V]V97)E96YK;VUS=``E<R!B97-T86%T(&%L+@`E<R!B97-T86%T
M(')E961S+B!5=R`E<R!M87`@:7,@;FEE="!H97)N;V5M9"X`)7,@;W`@)7,@
M)7,`)7,@;&EJ:W0@;FEE="!E96X@9V5L9&EG92!M86EL8F]X('1E('II:FXN
M`"5S(&UA<"!Z86P@=V]R9&5N(&AE<FYO96UD(&%A;B!H970@8F5G:6X@=F%N
M(&1E(&UA86YD+@`E<R!H965F="!G96%C8V5P=&5E<F0N`"5S(&AE969T("5S
M(&%F9V5Z96=D+@`E<R!I<R!A9F=E;F]M96XN`"5S(&AE969T(&=E86YT=V]O
M<F0@;W`@965N('9R:6HO8F5Z970@=F5R>F]E:RX`)7,@:&5E9G0@9V5A;G1W
M;V]R9"!O<"!D92!U:71N;V1I9VEN9R!V;V]R("5S+@`E<R!H965F="!U('9R
M:6HO8F5Z970@:6YF;W)M871I92!T;V5G97IO;F1E;BX`)7,@:7,@=F]O<FQO
M<&EG(&=E86-C97!T965R9"X`)7,@:7,@=F5R96ES=``E<R!M:6YU=&5N`"5S
M(&YI970@9V5V;VYD96XN`"5S('9R86%G="!U=R!V<FEJ+V)E>F5T(&EN9F]R
M;6%T:64N`"5S('9R86%G="!U=R!A86YW97II9VAE:60@8FEJ("5S+@`E<R!T
M;W0@)7,@=F%N("5S`"5S('=E;G-T("5S(&EN('1E(&)R96YG96XN`"5S('=E
M;G-T('4@;W`@9&4@:&]O9W1E('1E(&)R96YG96X@=F%N("5S+@`E<R!W96YS
M="!D92!L86%T<W1E(&EN9F]R;6%T:64@=&4@;VYT=F%N9V5N(&]V97(@)7,N
M`"5S)W,@861R97-B;V5K`"5S)W,@86=E;F1A`"5S)W,@;F]T:71I96)O96L`
M)7,G<R!T86ME;FQI:G-T`"5S.B`E<P`E<SH@)7,@*"5D)FYB<W`[=F%N)FYB
M<W`[)60I`"A"979E<W1I9R!D97IE('=I:GII9VEN9V5N(&5N(&=A(&YA87(@
M:&5T('9O;&=E;F1E('-C:&5R;2XI`"A-86%K(&%L;&4@=VEJ>FEG:6YG96X@
M;VYG961A86X@96X@9V$@=&5R=6<@;F%A<B`B3FEE=7<@8F5R:6-H="(N*0`H
M1V$@=&5R=6<@;F%A<B`B3FEE=7<@8F5R:6-H="(@;F$@8F5V97-T:6=I;F<@
M=F%N(&%L;&4L('1O="!D=7,@=F5R+"!A86YG96)R86-H=&4@=VEJ>FEG:6YG
M96XN(%9E<F%N9&5R:6YG96X@;W`@:&5T(&AU:61I9V4@<V-H97)M('=O<F1E
M;B!.2454(&1O;W)G979O97)D+BD`*%9E<GIE;F0@8F5R:6-H="!N82!U:71V
M;V5R:6YG('9A;B!A;&QE('=I:GII9VEN9V5N('1O="!N=2!T;V4N(%9E<F%N
M9&5R:6YG96X@;W`@:&5T(&AU:61I9V4@<V-H97)M('=O<F1E;B!.2454(&1O
M;W)G979O97)D+BD`*B!4;V5V;V5G96XL(&ML:6L@;W`@3TL@*@`J(%-E;&5C
M=&5E<B!A9')E<RAS96XI+"!A+G4N8BX@*@`L('=I;F1V;&%G96X@)7,@)7,`
M+"!V87)I86)E;"!V86X@)7,@=&]T("5S`"TM('-E;&5C=&5R96X@+2T`,2!B
M97)I8VAT(&ES(&%A;B!U=R!S>7-T965M8F5H965R9&5R(&=E<F%P<&]R=&5E
M<F0@86QS(&=E96X@<W!A;2X`,2!B97)I8VAT(&ES(&=E<F%P<&]R=&5E<F0@
M86QS(&=E96X@<W!A;2X`,2!B97)I8VAT(&ES(&%A;B!U=R!S>7-T965M8F5H
M965R9&5R(&=E<F%P<&]R=&5E<F0@86QS('-P86TN`#$@8F5R:6-H="!I<R!G
M97)A<'!O<G1E97)D(&%L<R!S<&%M+@`Q,#`@:V%R86MT97)S`#$P,#`@:V%R
M86MT97)S`#$R('5U<G-W965R9V%V90`R-"!U=7)S=V5E<F=A=F4`,C0@=75R
M<P`R-3`@:V%R86MT97)S`#4P,"!K87)A:W1E<G,`165N(&1A=&%B87-E(&)A
M8VME;F0@:7,@=F5R96ES="!V;V]R(&1I="!B;&]K+@!%<B!H965F="!Z:6-H
M(&5E;B!F871A;&4@9F]U="!V;V]R9V5D86%N`$5E;B!G<F]T92!A9F)E96QD
M:6YG("5S(&ES(&=E:V]P<&5L9"!M970@9&ET(&)E<FEC:'0N`$5E;B!D;V]R
M('4@=F5R<W1U=7)D(&)E<FEC:'0@:&5E9G0@9V5R97-U;'1E97)D(&EN(&5E
M;B!O;G1V86YG<W1B979E<W1I9VEN9R!V86X@9&4@;VYT=F%N9V5R+@!%96X@
M;W!E;F)A<F4@4$=0('-L975T96P@:7,@=F5R96ES="!O;2!E96X@8F5R:6-H
M="!T92!C;V1E<F5N+@!%96X@;W!E;F)A<F4@4$=0('-L975T96P@:7,@=F5R
M96ES="!O;2!E96X@;VYD97)T96ME;F0@8F5R:6-H="!T92!V97)I9FGK<F5N
M+@!%96X@;W!E;F)A<F4@4$=0('-L975T96PL('!R:7;I(%!'4"!S;&5U=&5L
M(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@;VT@965N(&)E<FEC
M:'0@=&4@9&5C;V1E<F5N+@!%96X@;W!E;F)A<F4@4$=0('-L975T96PL('!R
M:7;I(%!'4"!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I
M<W0@;VT@965N(&)E<FEC:'0@=&4@;VYD97)T96ME;F5N+@!%96X@;W!E;F)A
M<F4@4R]-24U%('-L975T96PL('!R:7;I(%,O34E-12!S;&5U=&5L(&5N('=A
M8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@
M9&5C;V1E<F5N+@!%96X@;W!E;F)A<F4@4R]-24U%('-L975T96PL('!R:7;I
M(%,O34E-12!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I
M<W0@;VT@965N(&)E<FEC:'0@=&4@;VYD97)T96ME;F5N+@!%96X@;W!E;F)A
M<F4@4TU)344@<VQE=71E;"!I<R!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E
M(&-O9&5R96XN`$)U:65N('9O;W(@,3(N,#`@=75R`$%-+U!-`$5.`$%022!)
M1`!/=F5R(&1E>F4@961I=&]R`$]V97(N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!697)Z;V5K(&%C8V5P=&5R96X`1V5A8V-E<'1E97)D`%1O96=A;F<@9V5W
M96EG97)D(&)I:B!H970@;6%K96X@=F%N(%9&4R!D:7)E8W1O<GDN`%1O96=A
M;F<@9V5W96EG97)D(&)I:B!H970@;6%K96X@=F%N(%9&4R!B97-T86YD+@!!
M8V-O=6YT=V%C:'1W;V]R9`!!8V-O=6YT(&)E=G)O<F5N+@!!8V-O=6YT;F%A
M;3H`5F5R86YT=V]O<F1I;F<`0F5W97)K:6YG96X`5&]E=F]E9V5N`$-H:6QD
M(&=R;V5P('1O979O96=E;@!#:&EL9"!R96-H="!T;V5V;V5G96X`2&EE<B!T
M;V5V;V5G96XZ`$YI975W92!G<F]E<"!T;V5V;V5G96X`3FEE=7<@<F5C:'0@
M=&]E=F]E9V5N`$YI975W92!G96)R=6EK97(@=&]E=F]E9V5N.@!+;VQO;2!T
M;V5V;V5G96X`3FEE=7=E(&QE9&5N('1O979O96=E;@!086%R('1O979O96=E
M;@!"<F]N('1O979O96=E;@!(970@)7,@;65N=2!T;V5V;V5G96X@86QS(&5E
M;B!-;WII;&QA(%-I9&5B87(`1&ET(&%A;B!M:6IN(&%G96YD82!T;V5V;V5G
M96X`5F]E9R!T;V4@86%N(&%D<F5S8F]E:SH`5F]E9R!T;V4@86%N(&UI:FX@
M861R97-B;V5K`$=E8G)U:6ME<B!T;V5V;V5G96X`(B5S(B!A;',@8FEJ;&%G
M92!T;V5G979O96=D+@!4;V5V;V5G96X@=F%N(&=E8G)U:6ME<G,@:7,@=6ET
M9V5S8VAA:V5L9"X`17AT<F$@:6YF;W)M871I92!K86X@=V]R9&5N(&)E:V5K
M96X@)7,N`$5X=')A(&EN9F]R;6%T:65D971A:6QS`$5X=')A(&)E<FEC:'1D
M971A:6QS`$5X=')A(&)E<FEC:'1D971A:6QS(&MU;FYE;B!B96ME:V5N('=O
M<F1E;B`E<RX`17AT<F$@8F5R:6-H=&9O=71D971A:6QS`$5X=')A(&)E<FEC
M:'1F;W5T9&5T86EL<R!K=6YN96X@8F5K96ME;B!W;W)D96X@)7,N`$%D<F5S
M`$%D<F5S8F]E:P!!9')E<V)O96ME;@!"96AE97(@+2!R96-H=&5N('9O;W(@
M86YD97)E(&=E8G)U:6ME<G,@:6YS=&5L;&5N`$)E:&5E<@!!9'9E<G1E;G1I
M97,`069G86YI<W1A;@!!;&)A;FGK`$%L9V5R:6IE`$%L:6%S`%5I=&QI:FYE
M;@!5:71L:6IN:6YG.@!!;&QE`$%L;&4@9V5A=71H96YT:6-E97)D92!G96)R
M=6EK97)S`$%L;&4@9W)O97!E;@!!;&QE(')E8VAT96X`06QL92!V:65R('II
M:F1E;@!!;&QE(&)E<FEC:'1E;B!I;B!D92!V;VQG96YD92!M87`H<&5N*2!W
M;W)D96X@9V5D;W=N;&]A9"!N86%R(.GI;B!-0D]8(&)E<W1A;F0Z`$%L;&4@
M8F5R:6-H=&5N(&EN('5W("(E<R(@;6%P+"!O=61E<B!D86X@)7,@9&%G96XL
M('IU;&QE;B!D969I;FET:65F('=O<F1E;B!V97)W:6ID97)D+@!!;&QE(&]U
M9&4@9V5K;W!P96QD92!B:6IL86=E;BP@;W5D97(@9&%N("5S(&UA86YD96XL
M('IU;&QE;B!W;W)D96X@=F5R=VEJ9&5R9"X`06QL92!O=61E(")/551"3U@B
M(&UA<'!E;BP@;W5D97(@9&%N("5S(&UA86YD96XL('IU;&QE;B!W;W)D96X@
M=F5R=VEJ9&5R9"X`5&]E<&%S<V5N('9A;B!F:6QT97)R96=E;',@;W`@96QK
M92!M86EL8F]X('1O97-T86%N/P!-965R9&5R92!A9')E<W-E;B!T;V5S=&%A
M;@!);G-T96QL96X@=F%N(&=E;W)D96YD92!L:6IS="!T>7!E('1O97-T86%N
M/P!"97-T86%T(&%L`$%L=&5R;F%T:65V92!)35-0(&%A;FUE;&1I;F<`06QT
M97)N871I968@24U34"!W86-H='=O;W)D`$%L=&5R;F%T:65V92!)35-0(&=E
M8G)U:6ME<G-N86%M`$%L=&5R;F%T:65F(&4M;6%I;&%D<F5S`$%L=&5R;F%T
M:65V92!S:F%B;&]N96X`06QT97)N871I979E('1E:W-T.@!!;'1E<FYA=&EE
M=F4@;VYD97)D96QE;B!V;V]R(&1E>F4@<V5C=&EE.@!!;'1I:F0`06QT:6ID
M(&)I:FQA9V5N(&]P<VQA86X`06UE<FEK86%N<R!386UO80!%96X@9F]U="!B
M:6H@9&4@<&]G:6YG(&]M(&1E(&)I:FQA9V4@=&4@<W1R:7!P96XN($1E($E-
M05`@<V5R=F5R(&UE;&1T.@!%96X@;VYG96QD:6=E('=A87)D92!O<&=E9V5V
M96XN`$5E;B!O;F)E:V5N9&4@9F]U="!O<&=E=')E9&5N(&)I:B!H970@;6%K
M96X@=F%N(&1E(&YI975W92!T86%K+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL
M80!!;F]N:65M92!P<F]X>0!!;G1W;V]R9`!"96%N='=O;W)D`$)E86YT=V]O
M<F1E(&)E<FEC:'1E;@!!;G1A<F-T:6-A`$%N=&EG=6$@96X@0F%R8G5D80!4
M;V5P87-S:6YG`%1O97!A<W-I;F<@:7,@9V5R965D+@!&:6QT97)S('1O97!A
M<W-E;@!&:6QT97)S('1O97!A<W-E;B!O<"`E<P!&:6QT97)R96=E;',@=&]E
M<&%S<V5N(&)I:B!A86YM96QD:6YG/P!&:6QT97)R96=E;',@=&]E<&%S<V5N
M('=A;FYE97(@24Y"3U@@=V]R9'0@=V5E<F=E9V5V96X_`$]P(&-H:6QD<VAA
M<F5S('1O97!A<W-E;@!';V5D:V5U<F5N`$%P<FEL`$%R86)I<V-H("A7:6YD
M;W=S+3$R-38I`$%R8VAI969B97-T86YD<V=R;V]T=&4`07)C:&EE9FYA86T`
M5V5E="!U('IE:V5R(&1A="!U(&1E>F4@;W!E;F)A<F4@<VQE=71E;"!W:6QT
M('9E<G=I:F1E<F5N/P!7965T('4@>F5K97(@9&%T('4@=7<@<VQE=71E;'!A
M87(@=VEL="!V97)W:6ID97)E;C\@*$1I="!W;W)D="!.2454(&%A;F)E=F]L
M96XA*0!7965T('4@>F5K97(@9&%T('4@9&ET('=I;'0@9&]E;C\`5V5E="!U
M('IE:V5R(&1A="!U(&AE="!A86YM96QD:6YG<W9E<GIO96L@=F%N("5S('=I
M;'0@=F5R=VEJ9&5R96X_`%=E970@=2!Z96ME<B!D870@=2!D97IE(&)E<FEC
M:'1E;B!$149)3DE4245&('=I;'0@=F5R=VEJ9&5R96X_`%=E970@=2!Z96ME
M<B!D870@=2!D97IE(&)I:FQA9V4@1$5&24Y)5$E%1B!W:6QT('9E<G=I:F1E
M<F5N/P!7965T('4@>F5K97(@9&%T('4@9&5Z92!M87`@=VEL="!L965G;6%K
M96X_`%=E970@=2!Z96ME<B!D870@=2!U=R!P<G5L;&5N8F%K('=I;'0@;&5E
M9VUA:V5N/P!7965T('4@>F5K97(@9&%T('4@9&5Z92!B97)I8VAT96X@1$5&
M24Y)5$E%1B!W:6QT('9E<G=I:F1E<F5N/P!7965T('4@>F5K97(@9&%T('4@
M9&ET(&)E<FEC:'0@86QS(&]N<V-H=6QD:6<@=VEL="!R87!P;W)T97)E;C\`
M5V5E="!U('IE:V5R(&1A="!U(&1I="!B97)I8VAT(&%L<R!S<&%M('=I;'0@
M<F%P<&]R=&5R96X_`$%R9V5N=&EN:>L`07)M96YIZP!!<FUE96YS("A!4DU3
M0TE)+3@I`$%A;FMO;7-T=&EJ9`!+=6YS=`!!<G5B80!4;V5N96UE;F0`07-C
M96YS:6]N(&5I;&%N9`!!<V-I:2!K=6YS=`!!>FGK+U!A8VEF:7-C:&4@4F5G
M:6\`5G)A9V5N`$]M(&)E=F5S=&EG:6YG('9R86=E;B!V;V]R(&AE="!U:71V
M;V5R96X@=F%N(&]N9&5R:&]U9'-W97)K>F%A;6AE9&5N/P!/<&1R86-H="!K
M;VQO;6UE;@!4;V5V;V5G96X`5&]E9V5V;V5G9&4@8F5S=&%N9&5N.@!%96X@
M:V]P:64@=F%N('5W(&]P96YB87)E(%!'4"!S;&5U=&5L(&%A;B!U=R!B97)I
M8VAT('1O979O96=E;C\`5&]E9V5V;V5G9"!B97-T86YD.@!4;V5G979O96=D
M(&)E<W1A;F0@(B5S(B!O=F5R<V-H<FEJ9'0@9&4@;6%X:6UU;2!B:6IL86=E
M9W)O;W1T92X@0F5S=&%N9"!I<R!.2454('1O96=E=F]E9V0N`$5E;B!A;G1W
M;V]R9"!O<"!E96XL(&1O;W(@=2!G97IO;F1E;B!A9V5N9&%V97)Z;V5K+"!I
M<R!T;V5G979O96=D+@!":6IL86=E`$)I:FQA9V4@9V5S=')I<'0Z(&]R:6=I
M;F5E;"!B:6IL86=E='EP90!":6IL86=E;@!0;V=I;F<@;VT@965N(&YI970@
M8F5S=&%A;F1E(&=R;V5P('1E('9E<G=I:F1E<F5N+@!0;V=I;F<@;VT@965N
M(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@=F5R=VEJ9&5R96XN`%!O9VEN9R!O
M;2!E96X@;FEE="!B97-T86%N9"!R96-H="!T92!B97=E<FME;BX`4&]G:6YG
M(&]M(&5E;B!N:65T(&)E<W1A86YD92!S:&%R92!T92!B97=E<FME;BX`06%N
M=V5Z:6=E;@!!86YD86-H=`!!='1R:6)U=&5N`$%U9W5S='5S`$%U<W1R86QI
MZP!/;W-T96YR:6IK`$%U=&A?8WER<W%L.B!V97)E:7-T92!I;6%P(&5X=&5N
M=&EE(&YI970@9V5V;VYD96XN`$%U=&A?8WER=7,Z(&)A8VME;F0@:&5E9G0@
M;FEE="!D92!V97)E:7-T92!B96MW86%M:&5D96XN`$%U=&A?8WER=7,Z('9E
M<F5I<W1E(&EM87`@97AT96YT:64@;FEE="!G979O;F1E;BX`075T:%]F='`Z
M('9E<F5I<W1E($944"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B!#;VUP:6QE
M97(@4$A0(&UE="!D92`M+65N86)L92UF='`@;W!T:64N`$%U=&A?:6UA<#H@
M=F5R96ES=&4@24U!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7VEM
M<#H@5F5R96ES=&4@24U!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H
M7VMR8C4Z('9E<F5I<W1E(&MR8C4@97AT96YT:64@;FEE="!G979O;F1E;BX`
M075T:%]L9&%P.B!V97)E:7-T92!,1$%0(&5X=&5N=&EE(&YI970@9V5V;VYD
M96XN`$%U=&A?;&1A<#H@3FEE="!I;B!S=&%A="!G96)R=6EK97(@)7,@=&]E
M('1E('9O96=E;BX@1&4@<V5R=F5R(&UE;&1T.B``075T:%]L9&%P.B!.:65T
M(&EN('-T86%T(&=E8G)U:6ME<B`E<R!T92!V97)W:6ID97)E;@!!=71H7VQD
M87`Z($YI970@:6X@<W1A870@9V5B<G5I:V5R("5S(&)I:B!T92!W97)K96X`
M075T:%]M8V%L.B!V97)E:7-T92!-0T%,(&5X=&5N=&EE(&YI970@9V5V;VYD
M96XN`$%U=&A?<VUB875T:#H@=F5R96ES=&4@<VUB875T:"!E>'1E;G1I92!N
M:65T(&=E=F]N9&5N+@!!=71H96YT:6-A=&EE(&UI<VQU:W0`075T:&5N=&EC
M871I92!M:7-L=6MT+B`E<P!!=71H96YT:6-A=&EE(&=E=V5I9V5R9"!D;V]R
M(&1E(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:64@;W`@1E10('-E<G9E
M<B!M:7-L=6MT+@!!=71O;6%T:7-C:"!A9F)E96QD:6YG96X@:6X@2%1-3"!B
M97)I8VAT96X@=V5E<F=E=F5N+"!W86YN965R(&1E(&%F>F5N9&5R('II8V@@
M:6X@;6EJ;B!A9')E<V)O96L@8F5V:6YD=#\`0F5S8VAI:V)A<F4@861R97-B
M;V5K96XZ`$)E<V-H:6MB87)E('9E;&1E;CH`26X@869W86-H=&EN9R!V86X@
M86YT=V]O<F0`07IE<F)A:61Z:F%N`$)/1D@@17AC=7-E<P!?5&5R=6<@;F%A
M<B`E<P!497)U9R!N86%R("5S`$%C:'1E<F=R;VYD`$%C:'1E<F=R;VYD:VQE
M=7(`1F]U="!K97)B97)O<W=A8VAT=V]O<F0N`$9O=71E(&ME<F)E<F]S9V5B
M<G5I:V5R<VYA86TN`$)A:&%M87,`0F%H<F5I;@!"86QT:7-C:"`H25-/+3@X
M-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S:7-L:6IN`$)C8P!7:70@
M<G5S;&%N9`!"96QG:>L`0F5L:7IE`$AI97)O;F1E<B!S=&%A="!D92!R=7=E
M('1E:W-T('9A;B!H970@<W1A='5S:6YF;W)M871I96)E<FEC:'0N`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`%9E<FIA87)D86<`6G=A<G1E(&QI:G-T`$)L;VL@
M(B5S(B!V86X@=&]E<&%S<VEN9R`B)7,B(&YI970@9V5V;VYD96XN`$)L;VMI
M;G-T96QL:6YG96X`0FQO:W1Y<&4`0FQO:VME97(@869B965L9&EN9V5N(&EN
M($A434P@8F5R:6-H=&5N+"!T96YZ:6H@9&5Z92!S<&5C:69I96L@86%N9V5V
M<F%A9V0@=V]R9&5N/P!";V1Y`%9E=`!";VQI=FEA`$)O;VMM87)K<P!286YD
M`%)A;F1D:6MT93H`4F%N9&5N`$)O<VYIZR!E;B!(97)Z96=O=FEN80!"96ED
M90!:;W=E;"!I;B!H96%D97(@86QS(&EN(&)O9'D@=F%N(&)E<FEC:'0@=V5E
M<F=E=F5N`$)O='-W86YA`$]N9&5R:V%N=`!";W5V970@96EL86YD`$)R87II
M;&GK`$)R:71S($EN9&ES8VAE($]C96%A;B!497)R:71O<FEU;0!"<G5N96D@
M1&%R=7-S86QA;0!"=6QG87)I:F4`3VYG96]R9&5N9&4@;&EJ<W0`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:65P=6YT96X`
M0U]E;&5I9V5N<V-H87!P96XN+BX`2V%R86M?=&5R<V5T`$%G96YD80!+86QM
M`$-A;6)O9&IA`$MA;65R;V5N`$MA;B!N:65T('9E<F)I;F1E;B!M970@9&4@
M;6%I;'-E<G9E<B!O<"!A9G-T86YD+@!+86X@;FEE="!V97)B:6YD96X@;65T
M(&1E(&UA:6QS97)V97(@;W`@869S=&%N9#H@`$MA;B!N:65T('=E97)G979E
M;B`M(&%L;&5E;B`E<R!V86X@)7,@;VYD97)D96QE;B!V86X@9&ET(&)E<FEC
M:'0@:6X@9&4@:'5I9&EG92!M86EL8F]X(&=E=F]N9&5N+@!+86X@=V%C:'1W
M;V]R9"!N:65T(&%U=&]M871I<V-H(')E<V5T=&5N+"!N965M(&-O;G1A8W0@
M;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(N`$MA;B!N:65T('9E<F)I;F1E
M;B!M970@24U!4"!S97)V97(Z("5S`$-A;F%D80!!9F)R96ME;@!"97)I8VAT
M(&%F8G)E:V5N`%!R;V)L965M<F%P<&]R="!A9F)R96ME;@!":6H@869B<F5K
M96X@=F%N(&1I="!B97)I8VAT+"!G86%T(&1E(&EN:&]U9"!D969I;FET:65F
M('9E<FQO<F5N+@!+86X@8F5S=&%N9"`B)7,B(&YI970@=F5R=VEJ9&5R96XN
M`$MA;B!G965N('1I:F1E;&EJ:V4@9&ER96-T;W)Y('9I;F1E;BX`2V%N(&YI
M970@9&]O<F=A86X@>F]N9&5R("=T87)G971&:6QE)R!P87)A;65T97(N`$MA
M;B!D:7)E8W1O<GD@(B5S(B!N:65T('9E<G=I:F1E<F5N+@!+86X@;FEE="!V
M97)W:6ID97)E;CL@)60@8VAI;&1R96X@8F5S=&%A;BX`2V%N(&YI970@;W!N
M:65U=R!R86YG<V-H:6MK96XL(&AE="!A86YT86P@:6YV;V5R96X@;VT@;W!N
M:65U=R!T92!R86YG<V-H:6MK96X@:V]M="!N:65T(&]V97)E96X@;65T(&AE
M="!O<&=E<VQA9V5N(&%A;G1A;"X`2V%N(&)E<FEC:'0@;FEE="!N86%R(&AE
M="!O<&=E9V5V96X@;G5M;65R('9E<G-T=7)E;BX`2V%A<"!697)D90!/<'-C
M:')I9G0`0V%T96=O<FEEZVX@96X@;&%B96QS`$-A>6UA;B!E:6QA;F1E;@!#
M8P!496PN;G(N;6]B:65L`$-E;&5I9V5N<V-H87!P96X`0V5L('9R:6IE(')U
M:6UT93H`0V5L96EG96YS8VAA<'!E;@!#96QS<&%T:>MR:6YG.@!496PN;G(N
M;6]B:65L`$ME;'1I<V-H("A)4T\M.#@U.2TQ-"D`36ED9&5N`$-E;G1R86%L
M($%F<FEK86%N<V4@4F5P=6)L:65K`$-E;G1R86%L($5U<F]P965S("A)4T\M
M.#@U.2TR*0!#97)T:69I8V%A=&1E=&%I;',`0V5R=&EF:6-A871B96QE:60`
M5'-J86%D`%9O;W)Z:71T97(`5VEJ>FEG96X`5VEJ>FEG(&%L;&5S`%=I:GII
M9R!M87``5VEJ>FEG('=E97)G879E;W!T:65S+"!Z;V%L<R!H;V5V965L(&)E
M<FEC:'1E;B!P97(@<&%G:6YA('=O<F1E;B!A9F=E8F5E;&0@96X@:&]E(&1E
M(&)E<FEC:'1E;B!W;W)D96X@9V5S;W)T965R9"X`5VEJ>FEG('5W(&UA:6QS
M97)V97(M(&5N(&UA<&EN<W1E;&QI;F=E;BX`5VEJ>FEG(&1E(&YA86TL(&%D
M<F5S(&5N(&]N9&5R=&5K96YI;F<@9&EE(&UE;B!Z:65T(&)I:B!H970@;&5Z
M96X@96X@8F5A;G1W;V]R9&5N('9A;B!U=R!E+6UA:6QS+@!7:6IZ:6<@9&4@
M;F%A;2P@861R97,@96X@;VYD97)T96ME;FEN9R!D:64@;65N('II970@8FEJ
M(&AE="!L97IE;B!E;B!B96%N='=O;W)D96X@=F%N('5W(&4M;6%I;"X`2V%R
M86MT97(`5V5E<B!T92!G979E;B!K87)A:W1E<G,Z`$-O;G1?<F]L965R(&QI
M;FLN+BX`0V]N=')O;&5E<B!M87`H<&5N*2!O<"!N:65U=V4@;6%I;`!#;VYT
M<F]L965R(%]!;&QE<R]'965N`$-O;G1R;VQE97(@86QL92!M86EL<V5R=F5R
M<RP@=V%A<G9A;B!U(&UA:6P@=VEL="!O<&AA;&5N.@!3<&5L;&EN9W-C;VYT
M<F]L92!V;V]R('9E<G-T=7)E;B!V86X@965N(&)E<FEC:'0_`$-H:6QI`$-H
M:6YA`$-H:6YE97,@=F5R965N=F]U9&EG9"`H1T(R,S$R*0!#:&EN965S('1R
M861I=&EO;F5E;"`H0FEG-2D`2VEE<R!B97=E<FMI;F<Z`$MI97,@965N(&UA
M:6QS97)V97(Z`$MI97,@965N('=A8VAT=V]O<F0`2VEE<R!E96X@9V5B<G5I
M:V5R<VYA86T`2VEE<R!E96X@8F5W97)K:6YG.@!+:65S(&1A='5M=V5E<F=A
M=F4Z`$MI97,@;&EJ<W1S=&EJ;'1Y<&4@*'9O;W(@9V5O<F1E;F1E(&QI:G-T
M96XI`$MI97,@:&5T(&%D<F5S8F]E:R!V;V]R(&AE="!T;V5V;V5G96X@=F%N
M(&%D<F5S<V5N+@!+:65S(&1E('9O;&=O<F1E('9A;B!A9')E<V)O96ME;B!O
M;2!T92!D;V]R>F]E:V5N('0N8BYV+B!N86%M<W5I=&)R96ED:6YG+@!#:')I
M<W1M87,@96EL86YD`$-L87-S9&5F:6YI=&EE('9A;B`E<R!N:65T(&=E=F]N
M9&5N+@!(96QD97(`35-/9F9I8V4@=&%G<R!W:7-S96X`5VES(&=E8G)U:6ME
M<CH@)7,`5VES(&=E8G)U:6ME<@!7:7,@9V5B<G5I:V5R<V1A=&$`2VQI:R!O
M<"`E<R!O;2!D92!A9F)E96QD:6YG('1E(&-O;G9E<G1E<F5N(&YA87(@965N
M(&9O<FUA870@=V%T('5W(&)R;W=S97(@:V%N('=E97)G979E;BX`2VQI:R`E
M<R!O;2!D92!A9F)E96QD:6YG('1E(&1O=VYL;V%D96XN`$ML:6L@)7,@;VT@
M;F%A<B!D92`E<R!B96AE97)P86=I;F$@=&4@9V%A;BX`2VQI:R`E<R!O;2!(
M5$U,(&EN:&]U9"!I;B!E96X@87!A<G0@<V-H97)M('1E(&)E:VEJ:V5N+@!+
M;&EK(&]P("5S(&]M(&5E;B!T:'5M8FYA:6P@=F%N(&1E>F4@869B965L9&EN
M9R!W965R('1E(&=E=F5N+@!+;&EK("5S(&]M(&1E(&)I:FQA9V4@:6X@965N
M(&%P87)T('-C:&5R;2!T92!B96MI:FME;BX`2VQI:R!H:65R(&]M(&1E(&%F
M8F5E;&1I;F=E;B!W965R('1E(&=E=F5N`$ML:6L@;W`@Z>EN('9A;B!U=R!G
M97-E;&5C=&5E<F1E(&%D<F5S8F]E:V5N(&5N('-E;&5C=&5E<B!D86%R;F$@
M86QL92!V96QD96X@=V5L:V4@9&]O<GIO8VAT(&1I96YE;B!T92!W;W)D96XN
M`$ML:6L@;VT@=F5R9&5R('1E(&=A86X`2VQI:R!O;2!D92!O<&5N8F%R92!0
M1U`@<VQE=71E;"!I;B!U=R!A9')E<V)O96L@;W`@=&4@<VQA86X`2VQI:R!O
M;2!H970@4R]-24U%(&-E<G1I9FEC86%T('9A;B`E<R!I;B!U=R!A9')E<V)O
M96L@;W`@=&4@<VQA86X`0VQI8VMA=&5L;"!V:6$@2%144`!+;&EK:V5N(&]P
M(&AE="!A9')E<R!Z86P@965N(&YI975W(&)E<FEC:'0@;6%K96X@=F]O<B!D
M92!A9GIE;F1E<@!+;&EK:V5N(&]P(&AE="!A9')E<R!Z86P@:&5T(&)E<FEC
M:'0@;W!E;F5N(&]M('1E(&QE>F5N`%-L=6ET96X`4VQU:70@<V-H97)M`%-L
M=6ET(&1I="!V96YS=&5R`$=E<VQO=&5N(&UA<`!7;VQK96X`0F5W;VQK=`!#
M;V-O<R`H2V5E;&EN9RD@96EL86YD96X`26YK;&%P<&5N`$%L;&5S(&EN:VQA
M<'!E;@!!;&QE(&UA<'!E;B!I;FML87!P96X`36%P(&EN:VQA<'!E;@!);F=E
M:VQA<'1E(')A;F1E;@!#;VQO;6)I80!+;&5U<@!+;&5U<FEN9&EC871O<CH@
M`$ML975R96YK:65Z97(`2VQE=7)S96QE8W1I90!+;VQO;6UE;CH`2V]L;VUT
M:71E;',`4W1R:7!S`$]P9')A8VAT`$]P9')A8VAT<VAE;&P`3W!M97)K:6YG
M`$%L9V5M96YE(&YA86T`0V]M;W)E;@!"961R:6IF`$%F9V5R;VYD`$UA86L@
M965N(&%N9&5R(&)E<FEC:'0`36%A:R!E96X@;FEE=7<@8F5R:6-H="!I;B!E
M96X@87!A<G0@<V-H97)M/P!-86%K(&)E<FEC:'1E;B!M+F(N=BX@965N($A4
M34P@9V5B<G5I:V5R<VEN=&5R9F%C92`H=V%N;F5E<B!D92!B<F]W<V5R(&1I
M="!O;F1E<G-T975N="D_`$-O;7!U=&5R<P!#;VYD:71I97,`5F5R<V-H:6QL
M96X@:6X@8V]N9FEG=7)A=&EE`"5S(&-O;F9I9W5R97)E;@!);G-T96QL96X@
M:&]E(&)E<FEC:'1E;B!W;W)D96X@=V5E<F=E9V5V96XN`$UA:6QP<F5V:65W
M;W!T:65S(&EN<W1E;&QE;BX`0F5V97-T:6<@=V%C:'1W;V]R9`!+;VYG;P!+
M;VYG;RP@1&4@1&5M;V-R871I<V-H92!297!U8FQI96L@=F%N(&1E`%9E<F)I
M;F1I;F<@;6ES;'5K="X`5F5R8FEN9&EN9R!M:7-L=6MT.B``5F5R8FEN9&EN
M9RP@;65T(&1E(&]P96YB87)E('-L975T96QS97)V97(L(&ES(&=E=V5I9V5R
M9"X`5F5R8FEN9&EN9RP@;65T(&1E(&]P96YB87)E('-L975T96QS97)V97(L
M(&ES(&=E=V5I9V5R9"X@4F5D96XZ("5S("@E<RD`5F5R8FEN9&EN9R!M970@
M1E10('-E<G9E<B!M:7-L=6MT+@!697)B:6YD:6YG(&UE="!D92!S97)V97(@
M;6ES;'5K=`!!9')E<W-E;B!Z:6IN(&UE="!S=6-C97,@86%N('5W(&%D<F5S
M8F]E:R!T;V5G979O96=D+@!$;V]R9V%A;@!"96AE97(@4$=0(&]N9&5R<W1E
M=6YI;F<@=F%N("5S+@!"96AE97(@4R]-24U%(&]N9&5R<W1E=6YI;F<@=F%N
M("5S+@!"97!A86P@=V%N;F5E<B!G96-O;G1R;VQE97)D('=O<F1T(&]P(&YI
M975W92!M86EL(&5N(&]F('4@=F%N(&1E(&%A;FMO;7-T(&AI97)V86XL('=E
M;"!O9B!N:65T('9A;B!O<"!D92!H;V]G=&4@9V5B<F%C:'0@=VEL('=O<F1E
M;BX`0V]N=F5R=&5E<B!T96MS="!E;6]T:6-O;G,@;F%A<B!G<F%F:7-C:&4@
M96UO=&EC;VYS/P!#;V]K(&5I;&%N9&5N`$-O;VMI90!+;W!IZW)E;@!+;W!I
M965R('-E;&5C=&EE`$MO<&EE97(@;F%A<B!M87``0V]R<FEG97)E;@!'96-O
M<G)I9V5E<F1E('1E:W-T`$-O<W1A(%)I8V$`279O;W)K=7-T`$MO;B!01U`@
M8F5R:6-H="!N:65T(&-O9&5R96XN`$MO;B!01U`@8F5R:6-H="!N:65T(&]N
M9&5R=&5K96YE;BX`2V]N(&)E<FEC:'0@;FEE="!3+TU)344@8V]D97)E;BX`
M2V]N(&)E<FEC:'0@;FEE="!3+TU)344@;VYD97)T96ME;F5N+@!+;VX@861R
M97,@)7,@;FEE="!T;V5V;V5G96XN`$MO;B!G965N('9E<F)I;F1I;F<@;65T
M(&1E($Q$05`M<V5R=F5R(&UA:V5N+@!+;VX@=&5G;V5D("5S(&YI970@8V]N
M=')O;&5R96XN`$MO;B!G965N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;6%K96XN
M`$MO;B!H970@5D93(&)A8VME;F0@)7,@;FEE="!M86ME;@!+;VX@4$=0(&1A
M=&$@;FEE="!D96-O9&5R96XN`$MO;B!3+TU)344@9&%T82!N:65T(&1E8V]D
M97)E;BX`2V]N(&%D<F5S("5S(&YI970@=F5R=VEJ9&5R96XN`$MO;B!D:7-T
M<FEB=71I96QI:G-T("5S(&YI970@=F5R=VEJ9&5R96XN`$MO;B!B97)I8VAT
M96X@:6X@)7,@;FEE="!V97)W:6ID97)E;BX@1&4@<V5R=F5R(&UE;&1T.B`E
M<P!+;VX@:&5T(&4M;6%I;&%D<F5S('9A;B!D92!O;G1V86YG97(@;FEE="!B
M97!A;&5N+@!+;VX@;VYD97)H;W5D<W=E<FMZ86%M:&5D96X@;FEE="!U:71V
M;V5R96XN`$MO;B!H970@9V5W96YS=&4@8F5S=&%N9"!N:65T('5I="!D92!-
M4RU43D5&(&)I:FQA9V4@:&%L96XN`$MO;B!H970@9V5W96YS=&4@8F5S=&%N
M9"!N:65T('5I="!H970@>FEP+6)E<W1A;F0@:&%L96XN`$MO;B!C;VUP;&5T
M92!A9')E<V)O96L@;FEE="!O<&AA;&5N+@!+;VX@8V]M<&QE=&4@9&ES=')I
M8G5T:65L:6IS="!N:65T(&]P:&%L96XN`$MO;B!C;VUP;&5T92!L:6IS="!V
M86X@9&ES=')I8G5T:65L:6IS=&5N(&YI970@;W!H86QE;BX`2V]N(&1E(&]P
M96YB87)E('-L975T96P@;FEE="!V97)K<FEJ9V5N('9A;B!D92!S;&5U=&5L
M<V5R=F5R+@!+;VX@)7,@;FEE="!O<&5N96XN`$MO;B!O;F1E<FAO=61S=&%K
M96YM;V1U;&4@)7,@;FEE="!O<&5N96X`2V]N("5S(&YI970@;&5Z96XN`$MO
M;B!H970@=V%C:'1W;V]R9"!V86X@9&4@9V5W96YS=&4@9V5B<G5I:V5R(&YI
M970@<F5S971T96XN(%-O;6UI9V4@;V8@86QL92!D971A:6QS('II:FX@;FEE
M="!J=6ES="X@4')O8F5E<B!O<&YI975W(&]F(&YE96T@8V]N=&%C="!O<"!M
M970@9&4@<WES=&5E;6)E:&5E<F1E<BP@=V%N;F5E<B!U('9E<F1E<F4@:'5L
M<"!N;V1I9R!H965F="X`2V]N($%#3"!N:65T(&]P:&%L96X`2V]N(&%D<F5S
M8F]E:R`E<R!N:65T(&]P:&%L96XN`$MO;B!D:7-T<FEB=71I96QI:G-T("5S
M(&YI970@;W!H86QE;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W1E;B`E<R!N:65T
M(&]P:&%L96XN`$MO;B!S97)V97)B96MW86%M:&5D96X@;FEE="!O<&AA;&5N
M`$MO;B!C;VYF:6=U<F%T:64@;FEE="!T97)U9WIE='1E;BX`2V]N(&-O;F9I
M9W5R871I92`E<R!N:65T(&]P<VQA86XN`$MO;B!G965N(&)A8VMU<&-O;F9I
M9W5R871I92!O<'-L86%N+@!+;VX@9&4@3$1!4"US97)V97(@;FEE="!D;V]R
M>F]E:V5N+@!+;VX@861R97,@)7,@;FEE="!B:6IW97)K96XN`$MO;B!D:7-T
M<FEB=71I96QI:G-T("5S(&YI970@8FEJ=V5R:V5N+@!+;VX@9&4@36]Z:6QL
M82!3:61E8F%R(&YI970@=FEN9&5N+B!:;W)G(&5R=F]O<B!D870@9&4@<VED
M96)A<B!O<&5N(&ES+@!'971E;&1E('1E:W-T`$QA;F0`0W5R<W5S<V5N`$UA
M:V5N`$UA86L@;6%P`%-L975T96QS(&UA:V5N`$UA86L@=FER='5E;&4@;6%P
M`$UA86L@965N(&QI;FL`36%A:R!E96X@;FEE=7=E(&ML861M87``36%A:R!E
M96X@;FEE=7=E`$UA86L@965N(&YI975W92!/551"3U@`36%A:R!E96X@;FEE
M=7=E('!R=6QL96YB86L`36%A:R!F:6QT97)R96=E;',@;VT@=7<@:6YK;VUE
M;F1E(&UA:6P@=&4@;W)G86YI<V5R96XL(&(N=BX@<V]R=&5R96X@;F%A<B!M
M87!P96XL(&]F(&AE="!V97)W:6ID97)E;B!V86X@<W!A;2X`36%A:R!S=6)M
M87!P96X`16EG96YA87)R96-H=&5N`$-R961I=&-A<F1N=6UM97(`2W)O871I
MZP!#=6)A`$AU:61I9V4@=&EJ9`!(=6ED:6=E(%523"!I<P!(=6ED:6<@=V5E
M<@!(=6ED:6=E('1O96=A;F<@=&]T("5S`$AU:61I9V4@8V]N9&ET:64Z(`!(
M=6ED:6=E('-T:6IL`$EN<W1E;&QE;B!V86X@86-C;W5N=',@=F]O<B!H970@
M;W!H86QE;B!V86X@;6%I;"!V86X@86YD97)E(&%C8V]U;G1S+@!!86YP87-S
M96X@:&]E('5W(&UA:6P@=V]R9'0@=F5R>F]N9&5N+@!!86YP87-S96X@=F%N
M('1A:V5N('1I:F1E;G,@86%N;65L9&EN9R!B:6H@)7,N`$MN:7!P96X`4V5L
M96-T:64@:VYI<'!E;@!#>7!R=7,`0WER:6QL:7-C:"`H2T])."U2*0!#>7)I
M;&QI<V-H("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&ES8V@O56MR86EN<R`H2T])
M."U5*0!4<VIE8VAI<V-H92!297!U8FQI96L`1$0`1&%G96QI:FMS`%]$871U
M;0!$871A5')E92!B<F]W<V5R`$1A='5M`$1A='5M($]N='9A;F=E;@!$871U
M;2!S96QE8W1I90!$86<`5F5R7W=I:F1E<B!K;VQO;0!$96-E;6)E<@!$96-I
M;6%L92!G971A;&QE;@!!9F=E;F]M96X`26YS<')I;F=E;B!V97)K;&5I;F5N
M`%-T86YD86%R9"!K;&5U<@!3=&%N9&%A<F0@:61E;G1I=&5I=`!3=&%N9&%A
M<F0@<V]R=&5E<F-R:71E<FEA.@!3=&%N9&%A<F0@<V]R=&5E<G9O;&=O<F1E
M.@!$969I;FET:65S`$]V97)G961R86=E;@!697)W:6ID97)E;@!/<&5N8F%R
M92!S;&5U=&5L("5S('9E<G=I:F1E<F5N`$AU:61I9V4@<VQE=71E;',@=F5R
M=VEJ9&5R96X`5F5R=VEJ9&5R(&UA<"AP96XI`$=R;V5P('9E<G=I:F1E<F5N
M`%)E8VAT('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!V:7)T=65L92!M87``5F5R
M=VEJ9&5R(&5N('=I<R!B97)I8VAT96X`5F5R=VEJ9&5R(&-E;`!697)W:6ID
M97(@:V]L;VT`0F5S=&%A;F0@86QT97)N871I968@<VIA8FQO;VX@=F5R=VEJ
M9&5R96X`5F5R=VEJ9&5R(&]P9V5H86%L9&4@8F5R:6-H=&5N('9A;B!D92!S
M97)V97(@;W`@869S=&%N9#\`5F5R=VEJ9&5R('5I="!M:6IN(&%G96YD80!6
M97)W:6ID97(@;W5D92!G96MO<'!E;&1E(&)I:FQA9V5N(&%A;B!H970@8F5G
M:6X@=F%N(&1E(&UA86YD/P!697)W:6ID97(@;W5D92`B3U540D]8(B!M87!P
M96X@86%N(&AE="!B96=I;B!V86X@9&4@;6%A;F0_`%9E<G=I:F1E<B!R:6H`
M1V5S96QE8W1E97)D92!I9&5N=&ET96ET('9E<G=I:F1E<F5N`%9E<G=I:F1E
M<B!D92!H=6ED:6=E(&MO;&]M`%9E<G=I:F1E<B!D92!H=6ED:6=E(')I:@!6
M97)W:6ID97)D`%9E<G=I:F1E<F1E(&)E<FEC:'1E;@!":6IL86=E("(E<R(@
M:7,@=F5R=VEJ9&5R9"X`5F5R=VEJ9&5R96X@96X@=F5R<&QA871S96X@=F%N
M(&)E<FEC:'1E;@!!9FQE=F5R=&EJ9`!$96YE;6%R:V5N`%=E:6=E<B!V97)Z
M;V5K`%=E:6=E<B!V97)Z;V5K('9O;W(@=G)I:B]B97IE="!I;F9O<FUA=&EE
M`$%F;F5M96YD`$)E<V-H<FEJ9B!H970@<')O8FQE96T`0F5S8VAR:6IV:6YG
M`$1E=&%I;',`1&5T86EL<R`H;V]K(&EN($AO<F1E)W,@;&]G8F5S=&%N9"DZ
M`$1E=&%I;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S>7-T965M8F5H965R9&5R
M+@!/;G1W:6MK96QI;F<`1&%U=W!U;G0`1&%U=W!U;G0@=F]O<B!H970@869G
M96QO<&5N('5U<CH@`$1A=7=P=6YT.B``1&EM(&]N9&5R=&5K96YI;F=E;C\`
M4FEC:'1I;F<@;&EN:W,@;F%A<B!R96-H=`!2:6-H=&EN9R!R96-H=',@;F%A
M<B!L:6YK<P!$:7)E8W1O<GD`5V5E<F=E=F5N`#(T+75U<G,@=&EJ9'=E97)G
M879E/P!7965R9V%V96]P=&EE<P!"979E<W1I9VEN9R!W965R9V5V96X@;F$@
M=F5R<W1U<F5N('9A;B!E96X@8F5R:6-H=#\`5V5E<G-V;V]R<W!E;&QI;F<@
M=&]N96X@*%1!1BD`5V5E<F=A=F5F;W)M86%T`%=E97)G979E;B!I;B!B;V1Y
M('9A;B!B97)I8VAT`%=E97)G979E;B!V86X@<&]P+75P(&YO=&EF:6-A=&EE
M('9A;B!N:65U=V4@;6%I;#\`5F]O<F)E<F5I9&EN9P!6;V]R8F5R96ED:6YG
M<VYO=&EF:6-A=&EE`$1J:6)O=71I`$MO;70@3DE%5"!O=F5R965N`$-O;G1R
M;VQE97(@;6%P*'!E;BD@;FEE="!O<"!N:65U=V4@;6%I;`!.:65T('9E<G=I
M:F1E<F5N`&UA:6YT96YA;F-E+G!H<"!N:65T(&1I<F5C="!A86YS<')E:V5N
M`$UA86L@9V5E;B!L:6YK(&EN(%9A;CH@:V]L;VT`5VEL="!U(&1E>F4@;6%P
M(&]P96YE;C\`0F5V870@9&4@965R<W1E(')I:B!D92!V96QD;F%M96X_(%IO
M(&IA+"!D:70@:&]K:F4@86%N=FEN:V5N.@!$;VUI;FEC80!$;VUI;FEC86%N
M<V4@4F5P=6)L:65K`%5I=&=E=F]E<F0`1&]W;FQO861E;@`E<R!D;W=N;&]A
M9&5N`$1O=VYL;V%D("5S(&EN("YZ:7`@9F]R;6%A=`!$;W=N;&]A9"!A;&QE
M(&)I:FQA9V5N("AI;B`N>FEP(&)E<W1A;F0I`$1O=VYL;V%D(&UA<"AP96XI
M`$1O=VYL;V%D(&UA<"AP96XI(%LN>FEP(&9O<FUA871=`$1O=VYL;V%D(&=E
M9V5N97)E97)D92!C;VYF:6=U<F%T:64@86QS(%!(4"!S8W)I<'0N`$1O=VYL
M;V%D(&EN("YZ:7`@9F]R;6%A=`!+;&%D`$ML861M87``2VQA9&UA<#H`1')O
M<"!D;W=N(&QI:G-T`$1R=6=S`$4M36%I;`!%+6UA:6QA9')E<P!%4E(`1D]5
M5#H@57<@8F5R:6-H="!K;VX@;FEE="!W;W)D96X@869G96QE=F5R9"X`16-U
M861O<@!"97=E<FME;@!:=V%R=&4@;&EJ<W0@8F5W97)K96X`0FQO:R!B97=E
M<FME;@!-86EL9FEL=&5R<R!B97=E<FME;@!'<F]E<"!B97=E<FME;@!296-H
M="!B97=E<FME;@!296-H=&5N(&)E=V5R:V5N`%)E8VAT96X@=F%N("<E<R<@
M8F5W97)K96X`0F5W97)K('9I<G1U96QE(&UA<`!"97=E<FMT('9I<G1U96QE
M(&UA<"!D969I;FET:64@=F]O<B`E<P!7:71T92!L:6IS="!B97=E<FME;@!/
M<'1I97,@8F5W97)K96X@=F]O<CH`4F5C:'1E;B!V86X@)7,@8F5W97)K96X`
M57<@>G=A<G1E(&QI:G-T(&)E=V5R:V5N`%5W(&9I;'1E<G)E9V5L<R!B97=E
M<FME;@!5=R!V;V]R:V5U<G-I;G-T96QL:6YG96X@=F]O<B!A;F1E<F4@;6%I
M;&%C8V]U;G1S(&EN<W1E;&QE;BX`57<@=VET=&4@;&EJ<W0@8F5W97)K96X`
M3VYD97)W:6IS`$5G>7!T90!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$4M
M;6%I;`!%+6UA:6QA9')E<P!%+6UA:6QA9')E<W-E;B!M;V5T96X@;W9E<F5E
M;FMO;65N+@!%+6UA:6P@;65T(&)E=F5S=&EG:6YG`$5M;W1I8V]N<P!!;&QE
M(&)E<FEC:'1E;B!U:70@)7,@>FEJ;B!V97)W:6ID97)D+@!-87`H<&5N*2!L
M965G;6%K96X`4')U;&QE;F)A:R!L965G;6%K96X`4')U;&QE;E]B86L@;&5E
M9VUA:V5N`$QE96<@8F5R:6-H="X`1V5E;B!R97-U;'1A870N`$QE9V4@>F]E
M:W1E<FUE;@!01U`@9G5N8W1I;VYA;&ET96ET(&EN<V-H86ME;&5N/P!3+TU)
M344@9G5N8W1I;VYA;&ET96ET(&EN<V-H86ME;&5N/P!);G9O96=E;B!V86X@
M869B965L9&EN9V5N('5I="!F;W1O86QB=6US(&EN('1E:W-T(&EN<V-H86ME
M;&5N/P!"97)I8VAT<')E=FEE=W,@86-T:79E<F5N/P!296-H=&ML:6MK96X@
M8V]N=&5X="!M96YU(&EN<V-H86ME;&5N/P!#;V1E<E]I;F=S;W!T:65S`$5I
M;F1E`$5I;F1E(&1O;W)G97-T=75R9"!B97)I8VAT`$5I;F1E(&)E<FEC:'0`
M16EN9&4@8F5R:6-H="!V86X@)7,`16EN9&IA87(`5F5R9W)O;W0@961I=&]R
M`%=A8VAT=V]O<F1R96=E;"!I;G9O97)E;@!'965F(&5E;B!B979E:6QI9VEN
M9W-V<F%A9R!D:64@=2!G979R86%G9"!W;W)D="P@=V%N;F5E<B!H970@;F]D
M:6<@:7,@;VT@=7<@=V%C:'1W;V]R9"!T92!R97-E='1E;BP@8BYV+B`G=V%T
M(&ES(&1E(&YA86T@=F%N('5W(&AU:7-D:65R/R<Z`%9O97(@9&4@869B965L
M9&EN9R!54DP@:&EE<B!I;@!'965F(&1E(&YA86T@=F%N('5W(&YI975W92!K
M;&%D;6%P`$=E968@9&4@;F%A;2!V86X@=7<@;FEE=7=E($]55$)/6`!'965F
M(&1E(&YA86T@=F%N('5W(&YI975W92!P<G5L;&5N8F%K`$EN=F]E<B`B)7,B
M(&UE="!S=6-C97,@86%N(&AE="!A9')E<V)O96L@=&]E9V5V;V5G9`!%<75A
M=&]R:6%A;"!'=6EN964`17)I=')E80!&;W5T`$9O=70@8FEJ('9E<GIE;F1E
M;B!V86X@86YT=V]O<F0Z("5S+@!&;W5T(&UE="!E+6UA:6QB97)I8VAT+@!%
M<W1L86YD`$5T:&EO<&GK`$5T;FES8V@`175R;W!A`$=E8F5U<G1E;FES(&UE
M="!S=6-C97,@=F5R=VEJ9&5R9"X`16QK92`Q-2!M:6YU=&5N`$5L:V4@,B!M
M:6YU=&5N`$5L:V4@,S`@<V5C;VYD96X`16QK92`U(&UI;G5T96X`16QK92!A
M86YM96QD:6YG`$5L:R!H86QF('5U<@!%;&ME(&UI;G5U=`!6;V]R8F5E;&1W
M86%R9&5N.@!5:71V;V5R96X`56ET:VQA<'!E;@!!;&QE<R!U:71K;&%P<&5N
M`$%L;&4@;6%P<&5N('5I=&ML87!P96X`36%P('5I=&ML87!P96X`3F%A;7-U
M:71B<F5I9&EN9P!.86%M<W5I=&)R96ED:6YG(&EN(&AE="`B3FEE=7<@8F5R
M:6-H="(@<V-H97)M(&%U=&]M871I<V-H+"!O<"!D92!A8VAT97)G<F]N9"P@
M=6ET=F]E<F5N/P!3=&%N9&%A<F0@9&4@8V]M<&QE=&4@=')E92!U:71K;&%P
M<&5N(&EN(&1E(&UA<'=E97)G879E/P!5:71K;&%P<&5N("XN+@!697)W86-H
M='1E("<I)P!697)W86-H='1E(&5N:V5L('=O;W)D(&]F(&%A;F=E:&%A;&1E
M('IO96MT97)M`%9E<G9A;&1A='5M`$5X<&]N96YT`%9O;W)G<F]N9&ML975R
M`$944"!U<&QO860@=F%N('-E='5P`$]P:&%L96X@=F]O<FME=7)S:6YS=&5L
M;&EN9V5N(&UI<VQU:W0N`%9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R
M(&ES(&UI<VQU:W0N`%9E<F)I;F1I;F<@;65T(&1E(%--0BUS97)V97(@:7,@
M;6ES;'5K="X`2V]P:>MR96X@=6ET("(E<R(@:7,@;6ES;'5K="X`2V]P:>MR
M96X@;F%A<B`B)7,B(&ES(&UI<VQU:W0N`$UA:V5N('9A;B!N:65U=V4@4T%3
M3"!V97)B:6YD:6YG(&ES(&UI<VQU:W0N`%9E<G!L86%T<V5N(&YA87(@(B5S
M(B!I<R!M:7-L=6MT+@!-;V]I`$9A;&ML86YD(&5I;&%N9&5N("A-86QV:6YA
M<RD`1F%R;^MR(&5I;&%N9&5N`$9A>`!&96)R=6%R:0!6;V5L="!A;',`5F]E
M;'0@86QS.B``36%I;"!O<&AA;&5N`$UA:6P@;W!H86QE;B!I;B!E96X@87!A
M<G0@<V-H97)M/P!"97)I8VAT96X@;W!H86QE;B!B:6H@86%N;65L9&EN9S\`
M06YD97)E(%!/4#,O24U!4"!A8V-O=6YT<SH@`$9E=&-H;6%I;#H@9V5E;B!N
M:65U=V4@8F5R:6-H=&5N+@!%;FME;&4@8G5I96X`1FE?;'1E<G,`1FEJ:0!"
M97-T86YD`$%A;G1A;"!B97-T86YD96XZ("5S(&)E<W1A;F0`06%N=&%L(&)E
M<W1A;F1E;CH@)7,@8F5S=&%N9&5N`$)E<W1A;F1B96AE97(`0F5S=&%N9'-N
M86%M`$)E<W1A;F0@:VEE>F5N`$)E<W1A;F1U<&QO860`0F5S=&%N9'5P;&]A
M9',@=V]R9&5N(&YI970@;VYD97)S=&5U;F0N`$9I;'1E<F]P=&EE<P!&:6QT
M97)I;G-T96QL:6YG96X`0F5R:6-H="!F:6QT97)E;B!O<"!A86YS=&]O=&=E
M=F5N9&4@:6YH;W5D/P!&:6QT97(@;VYD97)S=&5U;FEN9R!I<R!U:71G97-C
M:&%K96QD(&]P(&1I="!S>7-T965M+@!&:6QT97)S`$9I;'1E<G,@3DE%5"!A
M8W1I968`1FEL=&5R<SH@)7,@8F5H965R<&%G:6YA`%9I;F1E;@!&:6YL86YD
M`$5E<G-T92!H96QF=`!%97)S=&4@;6%I;&)O>'!A9VEN80!%97)S=&4@<&%G
M:6YA`$5E<G-T92!K=V%R=&%A;`!697)H;W5D:6YG(&AE<G-T96QL96X`3VUK
M97)E;@!$<FEJ=F5N`$1O;W)?<W1U<F5N`$UI<W0`36%P("5S(&)E<W1A870@
M;FEE=`!-87!N879I9V%T;W(`36%P<&5N<V%M96YV871T:6YG`$1E;&5N('9A
M;B!M87!P96X@:7,@;FEE="!I;F=E<V-H86ME;&0N`$=E8G)U:6L@=F%N(&UA
M<'!E;B!I<R!N:65T(&EN9V5S8VAA:V5L9"X`1F]N=&ML975R`%9O961S96P`
M5F]O<B!B<F]W<V5R<R!D:64@9V5E;B!A9F)E96QD:6YG96X@;VYD97)S=&5U
M;F5N`%=E97)S=F]O<G-P96QL:6YG("A4048I`%9O;W)U:71Z:6-H=&1A9V5N
M("AM97)K(&]P(&1A="!H970@9V5G979E;B!V;V]R=6ET>FEC:'0@9&%G96X@
M96X@;F%C:'1E;B!G965F=#L@965N(&=R;V]T(&%A;G1A;"!K86X@<F5S=6QT
M97)E;B!I;B!E96X@8G)E960@8FQO:RD`57<@=V%C:'1W;V]R9"!V97)G971E
M;C\`1F]R;6%A="!V86X@8F5R:6-H=&1A=&$@:6X@9&4@;6%I;&)O>'=E97)G
M879E('9O;W(@8F5R:6-H=&5N(&UE="!D92!D871U;2!V86X@=F%N9&%A9P!&
M;W)M=6QI97)E;@!&;W)T=6YE`$9O<G1U;F5T>7!E`$9O<G1U;F5S`$9O<G1U
M;F5S(#(`1F]R=6US`$1O;W)S='5R96X`1&]O<G-T=7)E;CH`1&]O<F=E<W1U
M=7)D(&)E<FEC:'0`1&]O<F=E<W1U=7)D(&)E<FEC:'0@=F%N("5S`$1O;W)S
M='5R96X`5G(`1G)A;65S`$9R86YK<FEJ:P!&<F%N:W)I:FLL($AO;V9D<W1E
M9&5L:6IK`%9R:6HO0F5Z970@:6YF;W)M871I90!6<FEJ+T)E>F5T(&%N='=O
M;W)D`%9R:6HO0F5Z970@=F5R>F]E:P!6<FEJ+T)E>F5T('9E<GIO96L@86YT
M=V]O<F0`1G)A;G,@1W5Y86YA`$9R86YS(%!O;'EN97-IZP!&<F%N<V4@6G5I
M9&5L:6IK92!497)R:71O<FEA`%]686X`5F%N`$%F>F5N9&5R`%9A;B!D92``
M5F]L;&5D:6=E(&)E<V-H<FEJ=FEN9P!6;VQL92!M86%N`%9O;&QE9&EG92!N
M86%M`$9W9#H`1G=D.B``1G=D.B`E=2!D;V]R9V5S='5U<F1E(&)E<FEC:'1E
M;@!'86)O;@!!;&)U;2!W86%R=6ET(&1E(&%F8F5E;&1I;F<@9V5H86%L9"!D
M:65N="!T92!W;W)D96X`06QB=6TZ`$=A;6)I80!!;&=E;65N92!O<'1I97,`
M1V5N97)E97(@)7,@8V]N9FEG=7)A=&EE`$=E9V5N97)E97)D92!C;V1E`$=E
M;W)G:>L`1'5I='-L86YD`$%L;&5E;B!N:65U=V4@8F5R:6-H=&5N(&]P:&%L
M96X_("AA;&QE96X@24U!4"D`1VAA;F$`1VEB<F%L=&%R`%9O;W)N86%M`$=A
M(&YA87(@8F5R:6-H=`!';V5D96P`1V]O9VQE('IO96ME;@!4;V5G86YG('1O
M96ME;FYE;@!'<FEJ<W-C:&%A;`!'<FEE:V5N;&%N9`!'<FEE:W,@*$E33RTX
M.#4Y+3<I`$=R;V5N;&%N9`!'<F5N861A`$=R;V5P<V)E:&5E<@!'<F]E<&YA
M;65N(&UO9V5N(&YI970@;&5E9R!Z:6IN`$=R;V5P96X`1W5A9&5L;W5P90!'
M=6%M`$=U871E;6%L80!'=65R;G-E>0!'87-T(')E8VAT96X`1V%S=&5N8F]E
M:P!'=6EN964`1W5I;F5E+4)I<W-A=0!'=7EA;F$`2$E%4@!(5$U,`$A434P@
M=F5R<VEE('9A;B!B97)I8VAT`$A434Q!<F5A('=E:6=E<G0@;&%F(&]M(&1E
M(&QA871S=&4@8V5L(&EN(&1E(')I:B!T92!V97)W:6ID97)E;BX`2%1-3$%R
M96$@=V5I9V5R="!L868@;VT@9&4@;&%A='-T92!K;VQO;2!I;B!D92!T86)E
M;"!T92!V97)W:6ID97)E;BX`2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@
M;&%A='-T92!R:6H@:6X@9&4@=&%B96P@=&4@=F5R=VEJ9&5R96XN`$A45%`@
M875T:&5N=&EC871I92!N:65T(&=E=F]N9&5N+@!(86ET:0!(87-H+6%L9V]R
M:71H;64`3F5V96P`2V]P`$AE861E<G,`2&5A<F0@96EL86YD(&5N($UC1&]N
M86QD(&5I;&%N9&5N`$AE8G)E975W<R`H25-/+3@X-3DM."U)*0!(;V]G=&4`
M2&5L<`!(96QP(&)I:B!G96)R=6EK('9A;B!E9&ET;W(`2&5L<&5R`$AA;&9R
M;VYD`$AI97(@:7,@:&5T(&)E9VEN('9A;B!H970@8F5S=&%N9#H`2&EE<B!I
M<R!H970@8F5R:6-H="!D870@=2!A86X@:&5T(&UA:V5N('=A<SH`5F5R8F]R
M9V5N`%9E<F)O<F=E;B!I;B!T:')E861W965R9V%V90!697)B97)G('9E<G=I
M:F1E<F0`5F5R8F5R9R!U:71G97-C:')E=F5N`$AO;V<`2&]G92!P<FEO<FET
M96ET`$AO;V=S=&4`2&]?;64`2&]L>2!3964@*%9A=&EC86%N<W1A9"D`2&]M
M90!!9')E<R`H<')I=NDI`%1E;"YN<BX@*'!R:7;I*0!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($]N9V5L9&EG92`E<R!834P@9&%T
M82!T96=E;F=E:V]M96X@:6X@8F5R:6-H="`E<P!(;W)D92]+;VQA8CH@1V5E
M;B!B97)I8VAT(&-O<G)E<W!O;F1E97)T(&UE="!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($=E96X@;V)J96-T('9A;B!T>7!E("5S(&=E=F]N9&5N(&EN(&)E
M<FEC:'0@)7,`2&]R9&4O2V]L86(Z("5S(&UE="!S=6-C97,@=F5R=VEJ9&5R
M9"`B)7,B`$AO<F1E+TMO;&%B.B!$92!I;G1E<F=R871I92!V97)E:7-T(&1E
M("=D;VUX;6PG(&5X=&5N<VEE`$AO<F1E+TMO;&%B.B!+86X@9V5E;B!N:65U
M=V4@6$U,(&)O;VT@;6%K96X@=F]O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M($MA;B`E<R`B)7,B(&YI970@=F5R=VEJ9&5R96XZ("5S`$AO<F1E+TMO;&%B
M.B!.:65T(&EN('-T86%T(&AE="!-24U%($E$+"!V;V]R(&AE="!G961E96QT
M92!M970@='EP92`E<RP@;W`@=&4@:&%L96X`2&]R9&4O2V]L86(Z($MA;B`E
M<R`B)7,B(&YI970@<WEN8VAR;VYI<V5R96XZ("5S`$AO<F1E+TMO;&%B.B!+
M86X@9V5D965L9&4@8G)O;FYE;B!N:65T('-Y;F-H<F]N:7-E<F5N.B`E<P!(
M;W)D92]+;VQA8CH@3VYB96ME;F1E(&=E9&5E;&1E(&)R;VX@(B5S(@!(;W)I
M>F]N=&%L92!L:6IN`$AO<FEZ;VYT86QE('9R:6IE(')U:6UT90!(;W)I>F]N
M=&%A;#H`2&]E(&MW86T@=2!H:65R/R`H1W)A86<@<F%P<&]R=&%G92$I`$AO
M92!W:6QT('4@8FEJ;&%G96X@=V5E<F=E=F5N/P!(;V5V965L(&MO;&]M;65N
M('=I;'0@=2!S86UE;G9O96=E;C\`2&]E=F5E;"!V96QD96X@*&MO;&]M;65N
M*2!Z:6IN(&5R/P!(;V5V965L(')I:F5N('=I;'0@=2!S86UE;G9O96=E;C\`
M071T<FEB=75T('9O;W(@8VET871E;B!I;B!E96X@86YT=V]O<F0`5F]C:'1I
M9VAE:60`5F]C:'1I9VAE:60Z(`!(=6UO<FES=&5N`$AO;F=A<FEJ90!)34%0
M`$E-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RD`36%K96X@=F%N($E-05`@
M;6%I;&)O>"!M:7-L=6MT.B`E<P!697)W:6ID97)E;B!V86X@24U!4"!M86EL
M8F]X(&UI<VQU:W0Z("5S`$UA:V5N('9A;B!)34%0(&UA:6QB;W@@<75O=&$@
M;6ES;'5K=#H@)7,`24U!4"!V:6$@4U-,`$E-05`@=FEA(%-33"`H>F5L9B!O
M;F1E<G1E:V5N9"D`24U!4"!V:6$@4U-,("AZ96QF(&]N9&5R=&5K96YD*0!)
M34%0+"!G965N(%1,4P!)34%0+U!/4#,@;6%I;'-E<G9E<G,`24Y"3U@`25`@
M061R97,`25`@861R97,@;FEE="!B97-C:&EK8F%A<BX`25`@861R97,@=F%L
M="!N:65T(&)I;FYE;B!H970@=&]E9V5S=&%N92!#2412(&)L;VLN`$E0(&QO
M8VMD;W=N(&]V97)T<F5D:6YG+@!2:6H@:5]N=F]E9V5N('9O;W(`24IS;&%N
M9`!!;&QE96X@<&EC=&]G<F%M;65N`%!I8W1O9W)A;6UE;B!M970@=&5K<W0`
M261E;G1I=&5I='-N86%M.@!786YN965R(&AE="!N:65T(&=O960@=V]R9'0@
M=V5E<F=E9V5V96XL("5S(&]M(&AE="!I;B!E96X@;FEE=7<@<V-H97)M('1E
M(&]P96YE;BX`06QS('4@9V5E;B!P:6-T;V=R86UM96X@>FEE="P@8FEJ(&=E
M8G)U:6L@=F%N($EN=&5R;F5T($5X<&QO<F5R+"!K86X@:&5T(&YO9&EG('II
M:FX@9&ET('9A:VIE(&%A;B!T92!V:6YK96X@;VT@4$Y'('1R86YS<&%R871I
M92!U:70@=&4@<V-H86ME;&5N+@!786YN965R('4@9&ET(&)E<FEC:'0@>FEE
M="P@;6%A<B!G965N(&%F8F5E;&1I;F<L(&1A;B!K86X@9&4@869B965L9&EN
M9R!D:64@=2!W:6QT('5P;&]A9&5N(&YI970@9&]O<B!U=R!B<F]W<V5R('=O
M<F1E;B!W965R9V5G979E;BX`3F5G97)E;@!.96=E97(@86QL97,`069B965L
M9&EN9W-B96]O<F1E;&EN9SH`069B965L9&EN9R!54DP`069B965L9&EN9R!5
M4DPZ`$%F8F5E;&1I;F<@=6ET(&%L8G5M`$%F8F5E;&1I;F<@=6ET(&%L8G5M
M.@!!9F)E96QD:6YG<W5P;&]A9`!!9F)E96QD:6YG96X`26UP;W)T97)E;@!3
M;&5U=&5L(&EM<&]R=&5R96X`4VQE=71E;'!A87(@:6UP;W)T97)E;@!01U`@
M<VQE=71E;"!I;7!O<G1E<F5N`%!E<G-O;VYL:6IK92!P<FEV92!01U`@<VQE
M=71E;"!I;7!O<G1E<F5N`%!E<G-O;VYL:6IK92!O<&5N8F%R92!01U`@<VQE
M=71E;"!I;7!O<G1E<F5N`%!E<G-O;VYL:6IK(%,O34E-12!C97)T:69I8V%A
M="!I;7!O<G1E<F5N`$]P96YB87)E('-L975T96P@:6UP;W)T97)E;@!/<&5N
M8F%R92!01U`@<VQE=71E;"!I;7!O<G1E<F5N`$]P96YB87)E(%,O34E-12!S
M;&5U=&5L(&EM<&]R=&5R96X`4R]-24U%('-L975T96P@:6UP;W)T97)E;@!-
M8F]X(&)E<W1A;F0@:6UP;W)T97)E;@!-8F]X(&)E<W1A;F0@)7,@:6X@;6%P
M("5S(&EM<&]R=&5R96XN`$EM<&]R=&5R96XL('-T87`@)60`0F5L86YG<FEJ
M:P!"96QA;F=R:6IK92!B97)I8VAT96X`)60@8F5R:6-H=&5N('5I="`E<R!G
M96EM<&]R=&5E<F0N`$=E:6UP;W)T965R9"!V96QD.B`E<P!'96EM<&]R=&5E
M<F1E('9E;&1E;CH`26X@8F5H86YD96QI;F<`4FEJ(&EN=F]E9V5N(&YA`$EN
M8F]X`$MO<G1E('-A;65N=F%T=&EN9R!V86X@9&4@:&5A9&5R(&)I:G9O96=E
M;B!I;B!E96X@86YT=V]O<F0_`$]R:6=I;F5E;"!B97)I8VAT(&)I:G9O96=E
M;B!I;B!E96X@86YT=V]O<F0_`$]N:G5I<W1E(&)E=V5R:VEN9W-C;V1E(&]P
M9V5G979E;BX`3VYJ=6ES=&4@9V5B<G5I:V5R<VYA86T@96XO;V8@=V%C:'1W
M;V]R9"X`3VYJ=6ES=&4@9V5B<G5I:V5R<VYA86T@;V8@86QT97)N871I968@
M861R97,N(%!R;V)E97(@;W!N:65U=R!O9B!N965M(&-O;G1A8W0@;W`@;65T
M(&1E('-Y<W1E96UB96AE97)D97(L('=A;FYE97(@=2!V97)D97)E(&AU;'`@
M;F]D:6<@:&5E9G0N`%9E<F=R;V]T(&EN<W!R:6YG:6YG`$EN9&EA`$EN9&EV
M:61U96QE(&=E8G)U:6ME<G,`26YD;VYE<VGK`$EN9F\`26YF;W)M871I90!)
M;F9O<FUA=&EE(&]V97(@;W!E;F)A<F4@<VQE=71E;"`E<P!);F9O<FUA=&EE
M(&]V97(@<&5R<V]O;FQI:FME('!R:79E('-L975T96P`26YF;W)M871I92!O
M=F5R('!E<G-O;VYL:6IK92!O<&5N8F%R92!S;&5U=&5L`$EN;&EN90!+;VQO
M;2!I;G9O96=E;B!N80!#97)T:69I8V%A="!H:65R(&EN=F]E9V5N`$%F8F5E
M;&1I;F<@:6YV;V5G96X`4&5R<V]O;FQI:FME('!R:79E(%!'4"!S;&5U=&5L
M('1O979O96=E;@!097)S;V]N;&EJ:V4@;W!E;F)A<F4@4$=0('-L975T96P@
M=&]E=F]E9V5N`$]P96YB87)E(%!'4"!S;&5U=&5L('1O979O96=E;@!486)E
M;"!I;G9O96=E;@!796)L:6YK(&EN=F]E9V5N`%]+;VQO;2!I;G9O96=E;B!V
M;V]R`$5E;B!N:65U=V4@:V]L;VT@:6YV;V5G96X@;F$@9&4@:'5I9&EG90!%
M96X@;FEE=7=E(&MO;&]M(&EN=F]E9V5N('9O;W(@9&4@:'5I9&EG90!%96X@
M;FEE=7=E(')I:B!I;G9O96=E;B!N82!D92!H=6ED:6=E`$5E;B!N:65U=V4@
M<FEJ(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4`165N(&YI975W92!P87)A9W)A
M868@:6YV;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E`$5E;B!N:65U=V4@<&%R
M86=R86%F(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4@;F]D90!!;'1E<FYA=&EE
M9B!S:F%B;&]O;B!I;G9O96=E;@!%96X@92UM86EL861R97,@:6YV;V5G96XL
M('=A87(@=2!H970@;FEE=7=E('=A8VAT=V]O<F0@:V%N(&]N='9A;F=E;CH`
M0V5L(&EN=F]E9V5N(&YA`$-E;"!I;G9O96=E;B!V;V]R`$MO;&]M(&EN=F]E
M9V5N(&YA`$MO;&]M(&EN=F]E9V5N('9O;W(`0F5R:6-H=&5N(&EN=F]E9V5N
M`%!A<F%G<F%A9B!I;G9O96=E;B!N80!087)A9W)A868@:6YV;V5G96X@=F]O
M<@!2:6H@:6YV;V5G96X@;F$`4FEJ(&EN=F]E9V5N('9O;W(`2&5T(&=E=V5N
M<W1E(&%N='=O;W)D('9O;W(@9&4@8F5V96EL:6=I;F=S=G)A86<@:6YV;V5G
M96XZ`$%F8F5E;&1I;F<@:6YV;V5G96XO86%N<&%S<V5N`$QI;FL@:6YV;V5G
M96XO86%N<&%S<V5N`$]N=F]L9&]E;F1E(&MR961I970@;VT@;F%A<B!D92!D
M:7-T<FEB=71I96QI:G-T('1E('IE;F1E;BX`3VYV;VQD;V5N9&4@:W)E9&EE
M=`!);G1E9V5R`$EN=&5G97(@;&EJ<W0`3VYG96QD:6=E(&)E=V5R:VEN9R!G
M97-E;&5C=&5E<F0@=F]O<B!D:70@;VYD97)D965L+@!/;F=E;&1I9R!A9')E
M<P!/;F=E;&1I9V4@;6%I;&)O>"!O<"!A9G-T86YD`$]N9V5L9&EG92!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`3VYG96QD:6=E('1O97!A<W-I;F<N`$]N
M9V5L9&EG(&)A=&-H($E$+@!/;F=E;&1I9R!K87)A:W1E<B!I;B!E+6UA:6QA
M9')E<SH@)7,N`$]N9V5L9&EG92!D871A(&]P9V5G979E;BX`3VYG96QD:6<@
M8F5S=&5M;6EN9V%D<F5S+@!/;F=E;&1I9R!T:6ID9F]R;6%A=`!/;F=E;&1I
M9V4@<VQE=71E;`!/;F=E;&1I9R!M<V=?='EP92X`3VYG96QD:6<@;V8@;VYT
M8G)E:V5N9"!A<&E?:60N`$]N9V5L9&EG92!O9B!O;G1B<F5K96YD92!P87)A
M;65T97)S+@!/;F=E;&1I9R!P87)E;G0@<F5C:'0N`$]N9V5L9&EG92!P97)S
M;V]N;&EJ:V4@<')I=F4@4$=0('-L975T96PN`$]N9V5L9&EG92!P97)S;V]N
M;&EJ:V4@;W!E;F)A<F4@4$=0('-L975T96PN`$]N9V5L9&EG('!R;W1O8V]L
M+@!/;F=E;&1I9V4@9V5D965L9&4@8G)O;@!/;F=E;&1I9R!B<F]N861R97,N
M`$]N9V5L9&EG92!U;FEC;V1E(&1A=&$N`$EN=F5N=&%R:7,`26YV97)T97)E
M;@!)<F%N+"!)<VQA;6ET:7-C:&4@4F5P=6)L:65K('9A;@!)<F%K`$EE<FQA
M;F0`16EL86YD($UA;@!'96ES;VQE97)D92!O;G=E97)S8G5I96X`27-R8>ML
M`%5I=&=E=F5R`$-U<G-I968`271A;&GK`$IA;6%I8V$`2F%N=6%R:0!*87!A
M;@!*87!A;G,@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:>L`2G5L:0!*
M=6YI`'5I=&QI:FYE;@!'96-E;G1R965R9"!U:71L:6IN96X`5F]L;&5D:6<@
M=6ET;&EJ;F5N`$QI;FMS('5I=&QI:FYE;@!296-H=',@=6ET;&EJ;F5N`$M"
M`$MA>F%C:'-T86X`3W)I9VEN965L(&)E:&]U9&5N/P!+96YI80!+97)B97)O
M<R!S97)V97(@=V5I9V5R9&4@875T:&5N=&EC871I92X`2V5R;F5L($YE=V)I
M97,`4VQE=71E;"!M86ME;@!3;&5U=&5L=FEN9V5R869D<G5K`%-L975T96QL
M96YG=&4`4VQE=71E;'1Y<&4`4VQE=71E;&=E8G)U:6L`1&4@<VQE=71E;"!B
M97-T86%T(&%L(&]P(&1E(&]P96YB87)E('-L975T96QS97)V97(N`%-L975T
M96P@;65T('-U8V-E<R!N86%R(&1E(&]P96YB87)E('-L975T96QS965R=F5R
M('9E<G-T=75R9"X`2VEN9&5R96X`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T
M:7-C:&4@5F]L:W-R97!U8FQI96L@=F%N`$MO<F5A+"!297!U8FQI96L@=F%N
M`$MO<F5A86YS("A%54,M2U(I`$MO97=E:70`2WER9VEE<VGK`$]?<&UA86L`
M5&%A;`!$96UO8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K($QA;P!,86%T<W1E
M(&AE;&9T`$QA871S=&4@;6%I;&)O>'!A9VEN80!,86%T<W1E('!A9VEN80!,
M86%T<W1E(&MW87)T:65R`$QA871S="!B:6IG97=E<FMT.@!,86%T<W1E(&%A
M;FUE;&1I;F<Z("5S`$QA871S=&4@86%N;65L9&EN9SH@)7,@=F%N("5S`$QA
M871S=&4@86%N;65L9&EN9SH@3F]O:70`3&5T;&%N9`!296-H=&5N`$]P;6%A
M:P!,86%T(&QE96<@=F]O<B!G965N(')A;F0`3&EB86YO;@!,:6YK<P!,:6YK
M<V4@:V]P`$QI;FMS92!W86%R9&5N`$QE<V]T:&\`2V]P<&5?;"!B:6IL86=E
M;@!,:6)E<FEA`$QI8FES8VAE($%R86)I<V-H92!*86UA:&ER:7EA`$QI96-H
M=&5N<W1E:6X`6F%C:'0@8G5I=&IE`$QI8VAT92!R96=E;@!6<F]E9R!L:6-H
M=&4@<F5G96X`3&EC:'1E(')E9V5N`$QI8VAT92!R96=E;F)U:0!,:6-H=&4@
M<F5G96X@;65T(&]N=V5E<@!,:6-H=&4@<VYE975W`$QI8VAT92!S;F5E=7=B
M=6D`3&EM97)I8VL`3&EN:P!,:6YK('=I:G-T(&YA87(Z`$QI;FL@:&5T(&4M
M;6%I;&%D<F5S(&%A;B!D92!N:65U=R!B97)I8VAT('!A9VEN82!T:6ID96YS
M('=E97)G879E`$=E:V]P<&5L9&4@8FEJ;&%G96X@>FEJ;B!N:65T('1O96=E
M<W1A86XN`$QI;FMS`$QI;G5X($-O;VMI90!,:6IS="`M(&=E8G)U:6ME<B!K
M86X@9&4@;6%P('II96X`1&%T86)A<V5L:6IS=`!,:6IS="!V86X@:&5L<"!O
M;F1E<F1E;&5N`%1A8F5L;&EJ<W0`06QL92!A9')E<W-E;B!W965R9V5V96X@
M8FEJ(&AE="!L861E;B!V86X@:&5T(&%D<F5S<V-H97)M/R`H5V%N;F5E<B!D
M:70@:7,@=6ET9V5S8VAA:V5L9"P@>FEE('4@86QL965N(&AE="!A9')E<R!W
M86%R('4@<W!E8VEA86P@;F%A<B!Z;V5K="D`3&EJ<W0M07)C:&EE9@!,:6IS
M="U(96QP`$QI:G-T+4ED`$QI:G-T+45I9V5N86%R`$QI:G-T+5!O<W0`3&EJ
M<W0M26YS8VAR:6IV96X`3&EJ<W0M56ET<V-H<FEJ=F5N`%=E97)G979E;B!I
M;B!D92!H96%D97(`5V5E<F=E=F5N('9A;B!G96)R=6EK97)S;&EJ<W0@:7,@
M=6ET9V5S8VAA:V5L9"X`3&ET97)A='5U<@!,:71O=7=E;@!,861E;BXN+@!,
M;VMA;&4@;6%I;&)O>#H`3&]K86QE('1I:F0Z`$QA;F1I;G-T96QL:6YG(&5N
M('1I:F0`3&]C871I90!!86YM96QD96X`06%N;65L9&5N(&)I:B`E<P!!9FUE
M;&1E;@!!86YM96QD96X`06%N;65L9'1A:V5N`$%A;FUE;&1I;F<@;6ES;'5K
M="!O;61A="!U=R!G96)R=6EK97)S;F%A;2!O9B!W86-H='=O;W)D(&]N:G5I
M<W0@:7,@:6YG979O97)D+@!!86YM96QD:6YG(&UI<VQU:W0N`$QA;F=E('1E
M:W-T`$QI969D90!,86%G`$QA9V4@<')I;W)I=&5I=`!'<FEE:W-E(&ML96EN
M92!L971T97)S`$QA=&EJ;G-E(&ML96EN92!L971T97)S`$ML96EN92!2;VUE
M:6YS92!G971A;&QE;@!,86%G<W1E`$QU>&5M8G5R9P!-30!-3U1$`$U3+51.
M148@8FEJ;&%G92!B979A='1E(&=E96X@9&%T82X`35-'`$UA8V%O`$UA8V5D
M;VYIZRP@1&4@=G)O96=E<F4@2F]E9V]S;&%V:7-C:&4@4F5P=6)L:65K('9A
M;@!-86-I;G1O<VAB97-T86YD`$UA9&%G87-C87(`36%G:64`12UM86EL`$UA
M:6QB96AE97)D97(`36%I;'!R979I97=S`$UA:6QS97)V97)T>7!E('=A87)M
M964@=F5R8FEN9&EN9R!G96UA86MT('=O<F1T.@!-86EL8F]X`$UA:6QB;W@M
M(&UA<'=E97)G879E;W!T:65S`$UA86L@;&EN7VLN+BX`36%L87=I`$UA;&5I
M<VGK`$UA;&%D:79E;@!-86QI`$UA;'1A`$)E:&5E<B!U=R!L:6IS="!M970@
M8V%T96=O<FEEZVX@96X@9&4@8V]R<F5S<&]N9&5R96YD92!K;&5U<F5N+"!W
M86%R;65E(&]N9&5R9&5L96X@=V]R9&5N(&=E;&%B96QD`$UA<#(T(&MA87)T
M`$UA<%%U97-T:V%A<G0`36%A<G0`36%R9V4`36%R:V5E<B!A;&QE(&)E<FEC
M:'1E;B!I;B!M87`@86QS($=E>FEE;@!-87)K965R(&%L;&4@8F5R:6-H=&5N
M(&EN(&UA<"!A;',@3VYG97II96X`36%R:V5E<B!A;',Z`$UA<FME97(@=F5R
M<V-H:6QL96YD92!C:71A871N:79E875S(&UE="!V97)S8VAI;&QE;F1E(&ML
M975R96X_`$UA<FME97(@8F5R:6-H=&5N(&%L<R!G97II96X_("AA;&QE96X@
M24U!4"D`165N=F]U9&EG92!O<&UA86L@;6%R:V5R96X_`$UA<FME97(@;65T
M($=E>FEE;B].:65T($=E>FEE;B!V;&%G9V5N`$UA<FME97(@;65T(&%N9&5R
M92!V;&%G9V5N("AB+G8N($)E;&%N9W)I:FLO0F5A;G1W;V]R9"D`36%R8VAA
M;&P@96EL86YD96X`36%R=&EN:7%U90!/=F5R965N:V]M96YD(&UE="!A;&QE
M('%U97)I97,`3W9E<F5E;FMO;65N9"!M970@96QK92!Q=65R>0!/=F5R965N
M:V]M96YD92!V96QD96X`36%U<F5T86YIZP!-875R:71I=7,`36%X:6UA86P@
M=&]E9V5S=&%A;B!K<F5D:65T+@!-87AI;75M(&)E<FEC:'1O;F1E<F1E;&5N
M(&]V97)S8VAR961E;BX`36%X:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G
M96QO<&5N(#(T('5U<CH@`$UA>&EM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F
M9V5L;W!E;B`V('5U<CH@`$UA>&EM=6T@8FEJ;&%G96=R;V]T=&4`36%X:6UA
M;&4@;&5N9W1E`$UA>&EM=6T@86%N=&%L(&)I:FQA9V5N(&)E<F5I:W0N`$UA
M>&EM=6T@=&]T86QE(&)I:FQA9V5G<F]O='1E(&)E<F5I:W0N`$UE:0!-87EO
M='1E`$=E;F5E<VMU;F1E`%9E<F=A9&5R:6YG<V%F>F5G9VEN9P!697)G861E
M<FEN9W-I;F9O<FUA=&EE`%9E<F=A9&5R:6YG<W9O;W)S=&5L`%9E<F=A9&5R
M:6YG<V%N='=O;W)D`%9E<F=A9&5R:6YG<W5P9&%T90!697)G861E<FEN9W-U
M<&1A=&5V97)Z;V5K`$QE9&5N`$UE;G4@;6%P<&5N;&EJ<W0`365N=2!M;V1E
M.@!#96QL96X@<V%M96YV;V5G96X`0F5R:6-H=`!"97)I8VAT<V%M96YS=&5L
M;&EN9P!"97)I8VAT9&%T=6T`0F5R:6-H=&]P=&EE<P!"97)I8VAT('IO96ME
M;@!"97)I8VAT9W)O;W1T90!"97)I8VAT<V]U<F-E`$)E<FEC:'0@;65T('-U
M8V-E<R!G979E<FEF:65E<F0L(&UA87(@:&5T(&-E<G1I9FEC86%T('9A;B!D
M92!O;F1E<F=E=&5K96YD92!K;VX@;FEE="!W;W)D96X@9V5V97)I9FEE97)D
M+@!"97)I8VAT(&)E:VEJ:V5N`$)E<FEC:'0@=F5R;&]P96XN`$)E<FEC:'1M
M87)K97)I;F=E;@!"97)I8VAT;6%P<&5N`$)E<FEC:'0@=F%N("5S`$)E<FEC
M:'0@:V]M="!O=F5R965N(&UE=`!"97)I8VAT(&UE="!S=6-C97,@;VUG96QE
M:60N`$)E<FEC:'0@;65T('-U8V-E<R!V97)S='5U<F0L(&UA87(@;FEE="!O
M<&=E<VQA9V5N(&EN("5S`$)E<FEC:'0@;65T('-U8V-E<R!V97)S='5U<F0N
M`$)E<FEC:'1T>7!E`$)E<FEC:'1E;B!P97(@<&%G:6YA(&EN(&1E(&UA:6QB
M;WAW965R9V%V92X`0F5R:6-H=&5N(&YA87(`365T87(@5V5E<@!-151!4B!B
M;&]K(&ES(&YI970@8F5S8VAI:V)A87(N`$U%5$%2(&)L;VL@:7,@;FEE="!B
M97-C:&EK8F%A<BX@1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E
M96UB96AE97)D97(N`$UE=&AO9&4`365T<FES8V@`365X:6-O`$UI8W)O;F5S
M:>LL($9E9&5R86QE(%-T871E;B!V86X`36ED9&5N`$UI;64@='EP90!-:6YI
M;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@,C0@=75R.B``36EN
M:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N(#8@=75R.B``36ER
M<F]R`$%L;&5R:&%N9&4`3VYT8G)E:V5N9&4@4$5!4B!M;V1U;&4@2%144%]2
M97%U97-T+@!/;G1B<F5K96YD92!C;VYF:6=U<F%T:64N(%4@9&EE;G0@9&5Z
M92!N=2!T92!G96YE<F5R96XL('=A;FYE97(@=2!D97IE('1O97!A<W-I;F<@
M=VEL="!G96)R=6EK96XN`$]N=&)R96ME;F0@8F5R:6-H="!)1"X`3VYT8G)E
M:V5N9&4L('9E<F5I<W1E+"!014%2(&UO9'5L92!-86EL+@!/;G1B<F5K96YD
M('-E<W-I92!)1"X`36$`36]B:65L92!E+6UA:6P`1V5M:61D96QD`%=I:GII
M9VEN9W-D871U;0!7:6IZ:6=E;@!7:6IZ:6<@55),`$UO9'5L=7,`36]L9&%V
M:>LL(%)E<'5B;&EE:R!V86X`36]N86-O`$UO;F=O;&GK`$UA86YD(&5N(&IA
M87(`36%A;F1E;&EJ:W,`36]N='-E<G)A=`!-86%N9F%S96X`36%R;VMK;P!6
M;V]R;F%M96QI:FL@;VYB97=O;&MT`%9O;W)N86UE;&EJ:R!B97=O;&MT`%9O
M;W)N86UE;&EJ:R!Z;VYN:6<`5F5R<&QA871S96X`3F%A<B!B96YE9&5N`$YA
M87(@;&EN:W,`3F%A<B!R96-H=',`3F%A<B!B;W9E;@!.86%R(&)E;F5D96X`
M5F5R<&QA871S(&YA87(@;6%P`$YA87(@8F]V96X`36]Z86UB:7%U90!-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&EJ<W1E;@!-=6QT:7!A<G0O86QT97)N871I
M=F4`365E<G9O=61I9V4@<V5L96-T:64`36EJ;B!A8V-O=6YT`$UI:FX@<&]R
M=&%A;`!-:6IN('!O<G1A86QL87EO=70`0FER;6$`3F5E+"!I:R!A8V-E<'1E
M97(@9&4@=F]O<G=A87)D96X@3DE%5`!/4$U%4DM)3D<`3F%A;0!.86%M(&5N
M+V]F(&5M86EL861R97,@:V%N(&YI970@;&5E9R!Z:6IN`$YA;6EB:>L`3F%U
M<G4`2&%N9&5L:6YG(&YO9&EG`$YE<&%L`$YE9&5R;&%N9`!.961E<FQA;F1S
M($%N=&EL;&5N`$YE='-C87!E($)A<VES(%523`!.971S8V%P92!#02!I;G1R
M96MK:6YG(%523`!.971S8V%P92!#02!B96QE:60@55),`$YE='-C87!E('9E
M<FYI975W:6YG(%523`!.971S8V%P92!I;G1R96MK:6YG(%523`!.971S8V%P
M92!34TP@<V5R=F5R;F%A;0!.971S8V%P92!C97)T:69I8V%A=&-O;6UE;G1A
M87(`3F5T<V-A<&4@8V5R=&EF:6-A871T>7!E`$YE='=E<FL`3F]O:70`3F]O
M:70@8FEJ;&%G96X@;W!S;&%A;@!.:65U=P!.:65U=R!#86QE9&]N:>L`3FEE
M=7=E(&-A=&5G;W)I90!.:65U=V4@;6%P`$YI975W92!M86EL`$YI975W92!M
M86%N`$YI975W92!G96)R=6EK97)S;F%A;2`H;W!T:6]N965L*0!.:65U=R!:
M965L86YD`$YI975W92!B97)I8VAT96X`3FEE=7<@<V-H97)M("A?8FQA;FLI
M`$YI975W<P!.:65U=W-G<F]E<&5N`%9O;&=E;F1E`%9O;&=E;F0@8F5R:6-H
M=`!6;VQG96YD92!P86=I;F$`5F]L9V5N9&4@;W!T:65S`$YI8V%R86=U80!.
M:6=E<@!.:6=E<FEA`$YA8VAT`$YI=64`3F5E`$=E96X@8V5R=&EF:6-A870@
M9V5V;VYD96X`1V5E;B!C;V1E<FEN9P!'965N('-L975T96QS(&EN('-L975T
M96QR:6YG`$=E96X@8F5R:6-H=&5N`$=E96X@;W!E;F)A<F4@<VQE=71E;',@
M9V5I;7!O<G1E97)D+@!'965N('!E<G-O;VYL:6IK(&-E<G1I9FEC86%T(&%A
M;G=E>FEG`$=E96X@;W!E;F)A<F4@<VQE=71E;"!G979O;F1E;@!'965N(&]P
M96YB87)E(%,O34E-12!S;&5U=&5L(&=E:6UP;W)T965R9"X`1V5E;B!B:6IL
M86=E;B!G979O;F1E;BX`1V5E;B!B97-C:&EK8F%R92!C;VYF:6=U<F%T:65D
M871A(&]M('9E<G-C:&EL;&5N('1E(&QA=&5N('II96XN`$=E96X@8F5S8VAI
M:V)A<F4@<W1R871E9VEE('9O;W(@:&5T(&UA:V5N('9A;B!)4T\@:6UA9V5S
M+@!'965N(&)A=&-H<VIA8FQO;VXN`$5R(&)E<W1A870@9V5E;B!B;&]K(&]P
M(&1E(&=E=G)A86=D92!P;W-I=&EE`$=E96X@86=E;F1A;F%A;2!O<&=E9V5V
M96X@=F]O<B!-0T%,(&%U=&AE;G1I8V%T:64N`$=E96X@=VEJ>FEG:6YG96XN
M`$%A;B!D:70@<F5C:'0@:W5N;F5N(&=E96X@8VAI;&0@<F5C:'1E;B!W;W)D
M96X@=&]E9V5V;V5G9"X`1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P
M9V5G979E;B!V;V]R("5S+@!'965N(&-O;F9I9W5R871I96EN9F]R;6%T:64@
M;W!G96=E=F5N('9O;W(@1E10(%9&4RX`1V5E;B!C;VYF:6=U<F%T:65I;F9O
M<FUA=&EE(&]P9V5G979E;B!V;V]R(%-13"!61E,N`$=E96X@8V]N9FEG=7)A
M=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!344PM8F5S=&%N9"!61E,N
M`$=E96X@:W)E9&EE="!M965R+@!'965N(&)E<W1E;6UI;F<@;W!G96=E=F5N
M+@!'965N(&)E<W1A;F0@=7!L;V%D960`1V5E;B!M87`@9V5S96QE8W1E97)D
M+@!%<B!W;W)D96X@9V5E;B!M87!P96X@9V5C;VYT<F]L965R9"!O<"!N:65U
M=V4@;6%I;"X`1V5E;B!M87!P96X@;W!G96=E=F5N`$=E96X@;6%P<&5N(&UE
M="!N:65U=V4@8F5R:6-H=&5N`$=E96X@;6%P<&5N(&UE="!O;F=E>FEE;F4@
M8F5R:6-H=&5N`$5R(&ES(&=E96X@;&]C871I92!I;F=E<W1E;&0N`$=E96X@
M8F5R:6-H=&)O9'ET96MS=`!'965N(&)E<FEC:'0@9V5L979E<F0N`$=E96X@
M8F5R:6-H=&5N(&1I92!A86X@=7<@>F]E:V-R:71E<FEA('9O;&1O96XN`$=E
M96X@;F%A;2!O<&=E9V5V96XN`$=E96X@9V5T86P@;W!G96=E=F5N+@!'965N
M(&)E;&5D:6=E;F1E(&9O<G1U;F5S`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V
M96X@=F]O<B!(5%10(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O
M<&=E9V5V96X@=F]O<B!)34%0(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W
M;V]R9"!O<&=E9V5V96X@=F%N($ME<F)E<F]S(&%U=&AE;G1I8V%T:64N`$=E
M96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!,;V=I;B!A=71H96YT:6-A
M=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!3
M34(@875T:&5N=&EC871I92X`1V5E;B!P860@;F%A<B!D92!/<&5N4U-,(&)I
M;F%R>2!O<&=E9V5V96XN($1E($]P96Y34TP@8FEN87)Y(&ES(&YO9&EG(&]M
M('1E(&MU;FYE;B!W97)K96X@;65T(%!+0U,@,3(@9&%T82X`1V5E;B!H86YG
M96YD92!I;G-C:')I:G9I;F=E;BX`1V5E;B!P97)S;V]N;&EJ:V4@<')I=F4@
M4$=0('-L975T96P@9V5I;7!O<G1E97)D+@!'965N('!E<G-O;VYL:6IK92!O
M<&5N8F%R92!01U`@<VQE=71E;"!G96EM<&]R=&5E<F0N`$=E96X@<&5R<V]O
M;FQI:FL@4R]-24U%(&-E<G1I9FEC86%T(&=E:6UP;W)T965R9"X`1V5E;B!L
M:6YIZW)I;F<`1V5E;B!Z:6ID96X`1V5E;B!S<&5L;&EN9W-C;VYT<F]L97!R
M;V=R86UM82!G96-O;F9I9W5R965R9"X`1V5E;B!S<&5L9F]U=&5N`$=E96X@
M<W5G9V5S=&EE<P!'965N('1I:F1E;&EJ:R!D:7)E8W1O<GD@8F5S8VAI:V)A
M87(@=F]O<B!C86-H92X`1V5E;B!G96)R=6EK97(@;W!G96=E=F5N`$=E96X@
M9V5B<G5I:V5R<VYA86T@96XO;V8@=V%C:'1W;V]R9"!V97)Z;VYD96XN`$=E
M96X@9V5L9&EG92!834P@9&%T82!T97)U9V=E<W1U=7)D`$=E96X@=V%A<F1E
M;@!'965N('9E<G-I92!G979O;F1E;B!I;B!O<FEG:6YE;&4@8V]N9FEG=7)A
M=&EE+B!(97)G96YE<F5E<B!C;VYF:6=U<F%T:64N`$=E96X@=F5R<VEE(&=E
M=F]N9&5N(&EN('5W(&-O;F9I9W5R871I92X@2&5R9V5N97)E97(@8V]N9FEG
M=7)A=&EE+@!'965N(&1E96QN96UE<@!'965N`$=E96X@*'9E<G!L:6-H="D`
M3F]O<F0@175R;W!E97,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK(&5I;&%N9`!.
M;W)M86%L`$YO;W)D96QI:FL@:&%L9G)O;F0`36%R:6%N96X`3F]O<G=E9V5N
M`$YI970@;F$`3FEE="!V;V]R`$YI970@=F5R=VEJ9&5R9`!.:65T(&ML860`
M3FEE="!B96QA;F=R:6IK`$YI970@<&5R<V]O;FQI:FL`1V5E;B!D:7)E8W1O
M<GD`3VYG96QD:6=E(&]P96YB87)E('-L975T96PN`$YI970@=F5R=VEJ9&5R
M9&4@8F5R:6-H=&5N`$YI970@9V5I;7!L96UE;G1E97)D+@!.:65T(&)E;&%N
M9W)I:FME(&)E<FEC:'1E;@!.:65T(&EN9V5S=&5L9`!.:65T(&]N9&5R<W1E
M=6YD+@!-97)K(&]P(&1A="!D:70@96YI9V4@=&EJ9"!K86X@9'5R96X`3F]T
M:71I97,`3FEE=',@=&4@8FQA9&5R96XL(&=A('1E<G5G+@!.;W9E;6)E<@!'
M971A;`!!86YT86P@:V%R86MT97)S`$%A;G1A;"!K;VQO;6UE;@!!86YT86P@
M;6%A;F1E;BP@=V5L:V4@;W5D92!G96MO<'!E;&1E(&)I:FQA9V5N(&)E=V%A
M<F0@;6]E=&5N('=O<F1E;B!B:6H@;6%A;F1E;&EJ:W-E(&]P<G5I;6EN9RX`
M06%N=&%L(&]U9&4@(D]55$)/6"(@;6%P<&5N+"!W96QK92!B97=A87)D('=O
M<F1E;B!B:6H@;6%A;F1E;&EJ:W-E(&]P<G5I;6EN9RX`06%N=&%L(')I:F5N
M`$=E=&%L;&5N(&YI970@;W!G96=E=F5N('9O;W(@8FEJ=V5R:V5N(&EN(&5E
M;B!D:7-T<FEB=71I96QI:G-T+@!/2P!/1@!/8FIE8W0`3V)J96-T96EG96YA
M87(`3V-T86%L`$]K=&]B97(`0F5L961I9VEN9V9I;'1E<@!+86YT;V]R`$]U
M9&4@8F5R:6-H=&5N`$]U9&4@(D]55$)/6"(@;6%P<&5N('=O<F1E;B!V97)W
M:6ID97)D+@!/;6%N`$%L;&5E;B!)34%0('-E<G9E<G,@;VYD97)S=&5U;F5N
M(&=E9&5E;&1E(&UA<'!E;BX`06QL965N(&UA<'!E;B!M970@;VYG96QE>F5N
M(&)E<FEC:'1E;B!W965R9V5V96X_`$%L;&5E;B!B96QE9&EG96YD92!F;W)T
M=6YE<P!3;&5C:'0@Z>EN(&4M;6%I;&%D<F5S('1O96=E<W1A86XN`%9O;W(@
M9&5Z92!B97=E<FMI;F<@;6%G('-L96-H=',@Z>EN(&UA<"!G97-E;&5C=&5E
M<F0@=V]R9&5N+@!!;&QE96X@9&4@96EG96YA87(@;V8@965N('-Y<W1E96UB
M96AE97)D97(@;6%G(&1E(&5I9V5N86%R<F5C:'1E;B!V86X@965N('-H87)E
M('=I:GII9V5N`$]P96X@:6X@965N(&YI975W('-C:&5R;0!/<&5N4U-,(&9O
M=70Z(&MO;B!G965N(&1A=&$@=6ET(&AE="!O;F1E<G1E:V5N9&4@4R]-24U%
M(&]N9&5R9&5E;"!H86QE;BX`1V5O<&5N9&4@;6%P`$]P96YT(&1E>F4@;&EN
M:R!I;B!E96X@;FEE=7<@<V-H97)M`$)E<W1U<FEN9W-S>71E96T`17AT<F$@
M9&5E;&YE;65R`$]P=&EE<P!/<'1I97,@=F]O<B`E<P!'96]R9&5N9&4@;&EJ
M<W0`3W)G86YI<W1A=&EE`$]R9V%N:7-A=&EE(&5E;FAE:60`3W)G86YI<V5R
M96X`3W)I9VEN965L('1O97!A<W-I;F=S<VIA8FQO;VX`3W)I9VEN96QE('-J
M86)L;VYE;B!I;B`E<SH`06YD97)E`$%N9&5R92!I;F9O<FUA=&EE`$%N9&5R
M92!M86EL86-C;W5N=',`06YD97)E(&]P=&EE<P!%:6=E;F%A<G)E8VAT96X`
M4$%-(&%U=&AE;G1I8V%T:64@:7,@;FEE="!B97-C:&EK8F%A<BX`4$=0`$1I
M9VET86QE(%!'4"!H86YD=&5K96YI;F<`0F5R:6-H="!01U`@8V]D97)E;@!'
M96-O9&5E<F1E(%!'4"!D871A`%!'4"!F;W5T.B``4$=0(&9O=70Z('=A8VAT
M=V]O<F1R96=E;"!V97)E:7-T('9O;W(@<&5R<V]O;FQI:FME('!R:79E('-L
M975T96PN`%!'4"!O<'1I97,`4$=0('=A8VAT=V]O<F1R96=E;"!I;G9O97(`
M4&5R<V]O;FQI:FME(%!'4"!S;&5U=&5L<&%A<B!O;F1E<G-T975N:6YG('9E
M<F5I<W0@965N(&)E=F5I;&EG9&4@=V5B=F5R8FEN9&EN9RX`3W!E;F)A<F4@
M4$=0('-L975T96P`3W!E;F)A<F4@4$=0('-L975T96QT96MS=`!/<&5N8F%R
M92!01U`@<VQE=71E;"!V;V]R("(E<R`H)7,I(B!W97)D(&UE="!S=6-C97,@
M=&]E9V5V;V5G9"X`3W!E;F)A<F4@4$=0('-L975T96P@=F]O<B`B)7,B('=E
M<F0@;65T('-U8V-E<R!V97)W:6ID97)D+@!/<&5N8F%R92!01U`@<VQE=71E
M;')I;F<`0F5R:6-H="!01U`@;VYD97)T96ME;F5N`$)E<FEC:'0@4$=0(&]N
M9&5R=&5K96YE;B]C;V1E<F5N`$]N9&5R=&5K96YD92]G96-O9&5E<F1E(%!'
M4"!D871A`%!R:79E(%!'4"!S;&5U=&5L(&UE="!S=6-C97,@=&]E9V5V;V5G
M9"X`3W!E;F)A<F4@4$=0('-L975T96P@;65T('-U8V-E<R!T;V5G979O96=D
M+@!01U`@;VYD97)S=&5U;FEN9R!I<R!N:65T(&EN9V5S8VAA:V5L9"!O<"!D
M:70@<WES=&5E;2X`4$=0(&]N9&5R<W1E=6YI;F<@:7,@;6]M96YT965L(&YI
M970@86-T:65F+"!D92!D:6=I=&%L92!H86YD=&5K96YI;F<@:V%N(&1U<R!N
M:65T(&=E=F5R:69I965R9"!W;W)D96XN`%!'4"!O;F1E<G-T975N:6YG(&ES
M(&UO;65N=&5E;"!N:65T(&%C=&EE9BP@:&5T(&)E<FEC:'0@:V%N(&1U<R!N
M:65T(&=E9&5C;V1E97)D('=O<F1E;BX`4$A0(&-O9&4`4$A0('-H96QL`$QI
M8VAT92!R96=E;B!N82`Q,BXP,"!U=7(`0G5I96X@;F$@,3(N,#`@=75R`$]N
M=V5E<G-B=6EE;B!N82`Q,BXP,"!U=7(`4$]0,P!03U`S("A!=71O($1E=&5C
M="!0<F]T;V-O;',I`%!/4#,@=FEA(%-33`!03U`S('9I82!34TP@*'IE;&8@
M;VYD97)T96ME;F0@8V5R=&EF:6-A870I`%!/4#,@=FEA(%-33"`H>F5L9B!O
M;F1E<G1E:V5N9"D`4$]0,RP@9V5E;B!43%,`4$A0(%]3:&5L;`!6<FEJ92!R
M=6EM=&4`4&%G:6YA("5D('9A;B`E9`!086=I;F$@;65T(&5E<G-T92!O;F=E
M>FEE;B!B97)I8VAT`%!A9VEN82!M970@;&%A='-T92!O;F=E>FEE;B!B97)I
M8VAT`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EJ;G,@5&5R<FET;W)I=6TL($)E
M>F5T`%!A;F%M80!087!U82!.:65U=R!'=6EN96$`4&%R86=U87D`3VYD97)D
M96QE;@!'961E96QT96QI:FL@8F5W;VQK=`!786-H='=O;W)D<F5G96P`5V%C
M:'1W;V]R9')E9V5L("AO<&YI975W*0!786-H='=O;W)D<F5G96P@;65T('-U
M8V-E<R!G96QO<W0N`%=A8VAT=V]O<F1R96=E;#H`5V%C:'1W;V]R9')E9V5L
M<R!K=6YN96X@;FEE="!L965G('II:FX`5V%C:'1W;V]R9')E9V5L<R!K;VUE
M;B!N:65T(&]V97)E96X`5V%C:'1W;V]R9`!786-H='=O;W)D(&]N:G5I<W0`
M5V%C:'1W;V]R9"!I<R!V97)E:7-T('9O;W(@4D%$2553(&%U=&AE;G1I8V%T
M:64N`%=A8VAT=V]O<F0@;65T(&)E=F5S=&EG:6YG`%=A8VAT=V]O<F0Z`%=A
M8VAT=V]O<F0Z(`!786-H='=O;W)D96X@;6]E=&5N(&]V97)E96YK;VUE;BX`
M4&QA:VME;@!0;&%K:V5N('9A;F%F('!R:6MB;W)D`%!A9`!(86YG96YD92!I
M;G-C:')I:G9I;F=E;CH`365N<V5N`%!R;V-E;G0`3VYD97)H;W5D<W=E<FMZ
M86%M:&5D96X@=6ET=F]E<F5N`$]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I
M='9O97)E;B!B:6H@86%N;65L9&EN9S\`4F5C:'0`4F5C:'1E;F)E:&5E<@!2
M96-H=&5N('9O;W(@9&5Z92!G96)R=6EK97(@:W5N;F5N(&YI970@=V]R9&5N
M(&=E=VEJ>FEG9"X`4&5R<V]O;FQI:FL`4&5R<V]O;FQI:FME(&EN9F]R;6%T
M:64`4&5R<V]O;FQI:FL@4$=0('-L975T96QP86%R(&UE="!S=6-C97,@9V5G
M96YE<F5E<F0N`%!E<G-O;VYL:6IK92!01U`@<VQE=71E;',@;65T('-U8V-E
M<R!V97)W:6ID97)D+@!097)S;V]N;&EJ:R!3+TU)344@8V5R=&EF:6-A870@
M3DE%5"!G96EM<&]R=&5E<F0Z(`!097)S;V]N;&EJ:V4@4R]-24U%('-L975T
M96QS(&UE="!S=6-C97,@=F5R=VEJ9&5R9"X`4&5R=0!(=6ES9&EE<F5N`%!H
M:6QI<'!I:FYE;@!496QE9F]O;@!&;W1O)W,`4&ET8V%I<FX`4&EX96QS`%!L
M86%T<R!U=R!O;F1E<G1E:V5N:6YG('9O;W(@86YT=V]O<F1E;B!E;B!D;V]R
M9V5S='5U<F1E(&)E<FEC:'1E;C\`4&QA='1E+71E:W-T=F5R<VEE('9A;B!B
M97)I8VAT`%!L871I='5D97,`2VQI:R!I;B!E96X@8V5L+"!A+G4N8BX`0F5V
M97-T:6<L(&1A="!U(&1I="!E;&5M96YT('=I;'0@=F5R=VEJ9&5R96XL(&$N
M=2YB.@!"979E<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!L;W-K;W!P
M96QE;BP@82YU+F(N`$=E968@965N(&UA86YD(&5N(&5E;B!J86%R+"!A+G4N
M8BX`165N(&YA86T@=F]O<B!D92!N:65U=V4@8V%T96=O<FEE(&EN=F]E<F5N
M+"!A+G4N8BXZ`$=E968@965N(&YA86T@=F]O<B!D92!N:65U=V4@;6%P+"!A
M+G4N8BXZ`$=E968@965N(&=E;&1I9R!)4"!A9')E<RP@82YU+F(N`$=E968@
M965N(&=E;&1I9V4@9&%T=6T@82YU+F(N+"!C;VYT<F]L965R(&AE="!A86YT
M86P@9&%G96X@:6X@9&4@;6%A;F0N`$=E968@965N(&=E;&1I9V4@=&EJ9"P@
M82YU+F(N`$=E968@9&4@;F%A;2!V86X@9&4@;FEE=7=E(&UA<"P@82YU+F(N
M.@!'965F(&1E(&YI975W92!N86%M+"!A+G4N8BXZ`$=E968@9&4@=V%C:'1W
M;V]R9')E9V5L('9A;B!U=R!P<FEV92!01U`@<VQE=71E;"P@82YU+F(N(%4@
M:&]E9G0@9&ET('-L96-H="!E96YM86%L('!E<B`E<R!S97-S:64@;W`@=&4@
M9V5V96XN`$=E968@9&4@=V%C:'1W;V]R9')E9V5L('9A;B!U=R!P<FEV92!3
M+TU)344@<VQE=71E;"P@82YU+F(N(%4@:&]E9G0@9&ET('-L96-H="!E96YM
M86%L('!E<B`E<R!S97-S:64@;W`@=&4@9V5V96XN`$UE;&1T('4@;W!N:65U
M=R!A86X@;VT@=F5R9&5R('1E(&=A86X@;65T(&AE="!M86ME;B!V86X@=7<@
M8F5R:6-H="X@5V%N;F5E<B!U($=%14X@8V]O:VEE<R!G96)R=6EK="!%3B!U
M(&)E<FEC:'1E;B!I;B!E96X@<&]P=7`@<V-H97)M(&UA86MT+"!D:65N="!U
M('1E=F5N<R!A86X@=&4@;65L9&5N(&EN('5W(&AO;V9D<V-H97)M+B!$:70@
M:7,@;VT@=&4@=F]O<FMO;65N(&1A="!A86YV86QL97)S('5W('-E<W-I92!)
M1"!O=F5R;F5M96XN($]N>F4@97AC=7-E<R!V;V]R(&AE="!O;F=E;6%K+@!'
M965F(&5E;B!S86UE;G9A='1I;F<@=F%N(&AE="!P<F]B;&5E;2P@82YU+F(N
M`$=E968@=7<@=V%C:'1W;V]R9"P@82YU+F(N`$=E968@=7<@9V5B<G5I:V5R
M<VYA86T@96X@=V%C:'1W;V]R9"P@82YU+F(N`$=E968@=7<@9V5B<G5I:V5R
M<VYA86TL(&$N=2YB+@!(97)S=&5L(&1U8F)E;'II;FYI9V4@;V8@;VYG96QD
M:6=E(&%D<F5S<V5N+"!A+G4N8BX`0F5K:6IK(&1E('9O;&=E;F1E(&EN9F]R
M;6%T:64@82YU+F(N(&5N('-E;&5C=&5E<B!D86%R;F$@965N(&)E=V5R:VEN
M9R!U:70@:&5T(&]N9&5R<W1A86YD92!M96YU+@!396QE8W1E97(@965N(&UA
M<"!V;V]R9&%T('4@965N(&)E=V5R:VEN9R!U:71V;V5R="P@82YU+F(N`%-E
M;&5C=&5E<B!E96X@8F5W97)K:6YG('5I="!H970@;VYD97)S=&%A;F1E(&UE
M;G4L(&$N=2YB+@!396QE8W1E97(@=&5N;6EN<W1E(.GI;B!M87`@;VT@=&4@
M9&]O<GIO96ME;BP@82YU+F(N`%-E;&5C=&5E<B!S;&5C:'1S(.GI;B!M87`@
M=F]O<B!D97IE(&)E=V5R:VEN9RP@82YU+F(N`%-E;&5C=&5E<B!O9B!B97=E
M<FL@:6X@:&5T('9A:R!A86X@9&4@<F5C:'1E<FMA;G0Z`$=E968@9&4@;FEE
M=7=E(&-A=&5G;W)I96YA86TL(&$N=2YB+CH`4&]L96X`4&]L:71I96L`4&5I
M;&EN9V5N`%!O<G1U9V%L`%!O<VET:6]N97)I;F<@=F%N(&1E>F4@869B965L
M9&EN9P!0;W-I=&EO;F5R:6YG('9A;B!D97IE('1A8F5L`%-T=75R(&YA87(@
M9&5Z92!M87`@*&YI970@869G961W;VYG96X@9&]O<B!)34%0*0!0;W=E<F5D
M(&)Y($AO<F1E`$]N9&5R=&5K96YI;F<@=F]O<F%F9V%A;B!M970@<W1R965P
M:F5S("@G+2T@)RD_`$YE97)S;&%G('9A;B!D92!A9F=E;&]P96X@)7,@=7)E
M;CH@`%9O;W)K975R<VEN<W1E;&QI;F=E;B!M970@<W5C8V5S(&)I:F=E=V5R
M:W0N`%!R969S7VQD87`Z('9E<F5I<W1E($Q$05`@97AT96YT:64@;FEE="!G
M979O;F1E;BX`4')E9G-?<V5S<VEO;CH@=F5R96ES=&4@<V5S<VEE(&5X=&5N
M=&EE(&YI970@9V5V;VYD96XN`$QU8VAT9')U:P!,=6-H=&1R=6L@;W`@>F5E
M;FEV96%U.B``3'5C:'1D<G5K.B``0F5O;W)D96QE;@!"96]O<F1E96P@9&4@
M869B965L9&EN9R!I;B!E96X@;FEE=7<@<V-H97)M`%9O<FEG(&)E<FEC:'0`
M5F]R:6=E('!A9VEN80!6;W)I9V4@;W!T:65S`$%F9')U:VME;@!$;V-U;65N
M="!A9F1R=6MK96X`4')I;W)I=&5I=`!0<FEV92!S;&5U=&5L`%!R:79E('-L
M975T96P@=V%C:'1W;V]R9`!0<F]B;&5E;0!0<F]B;&5E;6)E<V-H<FEJ=FEN
M9P!0<F]J96-T96X`16QK92!K965R('9R86=E;B!W86YN965R(&5E;B!B:6IL
M86=E('=O<F1T('9E<GIO;F1E;CL@<W1A;F1A87)D(&]P($Y%10!%;&ME(&ME
M97(@=G)A9V5N('=A;FYE97(@965N(&)I:FQA9V4@=V]R9'0@=F5R>F]N9&5N
M.R!S=&%N9&%A<F0@;W`@2D$`4')O;7!T('1E:W-T`%!R;W1O8V]L.@!/<&5N
M8F%R92!S;&5U=&5L`$]P96YB87)E('-L975T96P@86QG;W)I=&AM90!/<&5N
M8F%R92!01U`@<VQE=71E;'-E<G9E<B!I<R!U:71G97-C:&%K96QD+@!/<&5N
M8F%A<B]0<FEV92!S;&5U=&5L<&%A<B!N:65T(&=E9V5N97)E97)D+@!0=65R
M=&\@4FEC;P!?5VES('9E<G=I:F1E<F0`5VES('9E<G=I:F1E<F0`36%P*'!E
M;BD@;&5G96X`2&]E('9A86L@<')U;&QE;F)A:R!L96=E;CH`5F5R=VEJ9&5R
M(&)E<FEC:'1E;B!I;B!D92!P<G5L;&5N8F%K(&]U9&5R(&1A;B!D:70@86%N
M=&%L(&1A9V5N+@!697)W:6ID97(@;W5D92!B97)I8VAT96X@=6ET(&1E('!R
M=6QL96YB86L_`%%U871A<@!1=65R>0!1=6]T82!S=&%T=7,Z("4N,F9-0B`O
M("4N,F9-0B`H)2XR9B4E*0!1=6]T82!S=&%T=7,Z("4N,F9-0B`O($=%14X@
M3$E-2454`%%U;W1A('-T871U<SH@1T5%3B!,24U)150`4E-!(&]P96YB87)E
M('-L975T96P@*"5D(&)I="D`2V5U>F5R;VYD:F4@<V5L96-T:64`4F5G96X`
M5G)O96<@<F5G96X`3&%A="!R96=E;@!296=E;F)U:0!286YD;VT@1F]R='5N
M90!697)H;W5D:6YG`%9E<E]Z;V5K(&%F;&5V97)I;F=S8F5V97-T:6=I;F<`
M3&5Z96X`3&5E<R!B97)I8VAT96X`)7,@96-H="!V97)W:6ID97)E;C\@1&5Z
M92!B97=E<FMI;F<@:V%N(&YI970@;VYG961A86X@9V5M86%K="!W;W)D96XN
M`$=E8G)U:6ME<G-D871A('9A;B!G96)R=6EK97(@)7,@96-H="!V97)W:6ID
M97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@;VYG961A86X@9V5M86%K
M="!W;W)D96XN`$]N='9A;F=E;B!O<`!/;G1V86YG96X@<VEN9',`3VYT=F%N
M9V5N('1O=`!/;5]L96ED96X`3VUL96ED96X`0F5R:6-H="!O;6QE:61E;@!$
M:70@8F5R:6-H="!O;6QE:61E;@!/;6QE:61E;B!M:7-L=6MT+@!(97)H86%L
M="!U=R!V;W)I9V4@8F5W97)K:6YG`%9E<G9E<G-E;@!697)V97)S(&1Y;F%M
M:7-C:&4@;65N=2!O;F1E<F1E;&5N.@!697)V97)S(&UA<'=E97)G879E<SH`
M4&]R=&%L=V5E<F=A=F4@=F5R=F5R<V5N.@!296=E>`!"971R96MK:6YG96X@
M8G)O=W-E<@!697)N:65U=V5N`%=E97)G879E('9E<FYI975W96X`3W!M97)K
M:6YG96X`3VYT:&]U9'0@9&4@=G)I:B]B97IE="!I;F9O<FUA=&EE+@!/;G1H
M;W5D="!D92!L86%T<W1E('=E97)G879E`$UA:6QB;W@@;W`@869S=&%N9#H`
M4V5R=F5R<R!O<"!A9G-T86YD`%523"!O<"!A9G-T86YD("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`5F5R=VEJ9&5R96X`0FQO:R!V97)W:6ID
M97)E;@!697)W:6ID97(@=F5L9"!U:70@>F]E:V5N`$MO;&]M('9E<G=I:F1E
M<F5N`$]P;6%A:R!V97)W:6ID97)E;@!086%R('9E<G=I:F1E<F5N`%9E<G=I
M:F1E<B!H970@;W!G97-L86=E;B!S8W)I<'0@=6ET(&1E('1I:F1E;&EJ:V4@
M9&ER96-T;W)Y(&]P(&1E('-E<G9E<BX`0G)O;B!V97)W:6ID97)E;@!697)W
M:6ID97(@9&4`5F5R=VEJ9&5R(&1E>F4@;F]D92!U:70@:&5T(&1O8W5M96YT
M`$=E8G)U:6ME<B!V97)W:6ID97)E;@!697)W:6ID97(@9V5B<G5I:V5R.B`E
M<P!(97)N;V5M(&UA<"AP96XI`$AE<FYO96T@3U540D]8(&UA<"!A86X@:&5T
M(&)E9VEN('9A;B!D92!M86%N9#\`2&5R;F]E;65N('9A;B`B)7,B('1O="`B
M)7,B(&UI<VQU:W0N($1I="!I<R!W870@9&4@<V5R=F5R(&UE;&1T`$)E86YT
M7W=O;W)D(&UA:6QI;F=L:7-T`%9E<G9A;F<@9&]O<CH`0F5A;G1W;V]R9&5N
M`$%N='=O;W)D('9E<GIO;F1E;BX`0F5A;G1W;V]R9"!A;&QE;@!"96%N='=O
M;W)D(&%L;&5N.@!"96%N='=O;W)D(&UA:6QI;F=L:7-T`$)E86YT=V]O<F0@
M;6%I;&EN9VQI<W0Z`$)E86YT=V]O<F0@7V%L;&5N`$%N='=O;W)D(&UE="!.
M:65T($]N9&5R<W1E=6YD($)E<FEC:'0`06YT=V]O<F0@;65T('9R:6HO8F5Z
M970@=F]O<B!D92!V;VQG96YD92`R(&UA86YD96XN`$%N='=O;W)D(&UE="!G
M979R86%G9&4@=G)I:B]B97IE="!I;F9O<FUA=&EE+@!!;G1W;V]R9&5N(&%A
M;@!!;G1W;V]R9&5N(&%A;CH`0F5A;G1W;V]R9&5N.@!287!P;W)T965R(&%L
M<R!O;G-C:'5L9&EG`%)A<'!O<G1E97(@86QS('-P86T`5F5R>F]E:R!E96X@
M;&5E<R!?;VYT=F%N9W-T8F5V97-T:6=I;F<`5F5R>F]E:R!K;VX@;FEE="!W
M;W)D96X@8F5A;G1W;V]R9"X@1V5R971O=7)N965R9&4@9F]U=&-O9&4Z(`!6
M97)Z;V5K(&%F;&5V97)I;F=S8F5V97-T:6=I;F<_`%9E<GIO96L@;&5E<R!O
M;G1V86YG<W1B979E<W1I;F=E;C\`1V5V<F%A9V1E(&)E<FEC:'0@;FEE="!G
M979O;F1E;BX`5F5R96ES=&4@9&5E;&YE;65R`$AE<G-T96QL96X`4F5S970@
M=V%C:'1W;V]R9`!297-E="!U=R!W86-H='=O;W)D`%-T871U<R!V86X@8F5A
M;G1W;V]R9&5R(&=E=7!D871E+@!297-U;'1A=&5N`%9E<G9O;&=E;@!697)V
M;VQG('5W('-E<W-I90!497)U9R!N86%R(&%N9&5R92!03U`S+TE-05`@86-C
M;W5N=',`5&5R=6<@;F%A<B!O<'1I97,`5&5R=6<@;F%A<B!D92!M86EL8F]X
M;&EJ<W0@;F$@=F5R=VEJ9&5R96XL('9E<G!L86%T<V5N(&]F(&MO<&GK<F5N
M('9A;B!E96X@8F5R:6-H=#\`4F5U;FEO;@!#;VYF:6=U<F%T:64@=&5R=6=Z
M971T96X`4FEC:"!497AT($5D:71O<B!O<'1I97,`4F%A9'-E;',`4F5C:'1S
M`%)E8VAT<V4@:V]P`%)E8VAT<V4@=V%A<F1E;@!2:5]J96EG96YS8VAA<'!E
M;BXN+@!2;VP`4F]E;65N:>L`,3@P(&1R86%I96X`3F%A<B!L:6YK<R!D<F%A
M:65N`$YA87(@<F5C:'1S(&1R86%I96X`4FEJ(&5I9V5N<V-H87!P96X`4FEJ
M(&5I9V5N<V-H87!P96X`4FEJ96XZ`$QI;FGK<FEN9P!,:6YIZW)I;F<@>F%L
M('9E<G-C:&EJ;F5N('1U<W-E;B!A;&QE(')I:F5N(&5N(&MO;&]M;65N`$QI
M;FGK<FEN9R!Z86P@86QL965N('1U<W-E;B!K;VQO;6UE;B!V97)S8VAI:FYE
M;@!,:6YIZW)I;F<@>F%L(&%L;&5E;B!T=7-S96X@<FEJ96X@=F5R<V-H:6IN
M96X`4W1A<G1E;@!2=7-S:7-C:&4@1F5D97)A=&EE`%)W86YD80!3+TU)344`
M0W)Y<'1O9W)A9FES8VAE(%,O34E-12!H86YD=&5K96YI;F<`0F5R:6-H="!3
M+TU)344@8V]D97)E;@!3+TU)344@9V5C;V1E97)D(&)E<FEC:'0`4R]-24U%
M($9O=70Z(`!3+TU)344@9F]U=#H@=V%C:'1W;V]R9')E9V5L('9E<F5I<W0@
M=F]O<B!P97)S;V]N;&EJ:V4@<')I=F4@<VQE=71E;"X`4R]-24U%(&]P=&EE
M<P!3+TU)344@=V%C:'1W;V]R9')E9V5L(&EN=F]E<@!097)S;V]N;&EJ:V4@
M4R]-24U%('-L975T96QP86%R(&]N9&5R<W1E=6YI;F<@=F5R96ES="!E96X@
M8F5V96EL:6=D92!W96)V97)B:6YD:6YG+@!/<&5N8F%R92!3+TU)344@<VQE
M=71E;"!V;V]R("(E<R(@=V5R9"!M970@<W5C8V5S('9E<G=I:F1E<F0N`$]P
M96YB87)E(%,O34E-12!S;&5U=&5L(&UE="!S=6-C97,@=&]E9V5V;V5G9"X`
M3W!E;F)A<F4@4R]-24U%('-L975T96QR:6YG`$]P96YB86%R+W!R:79E(%,O
M34E-12!S;&5U=&5L<&%A<B!M970@<W5C8V5S('1O96=E=F]E9V0N`$)E<FEC
M:'0@4R]-24U%(&]N9&5R=&5K96YE;@!"97)I8VAT(%,O34E-12!O;F1E<G1E
M:V5N96XO8V]D97)E;@!3+TU)344@;VYD97)S=&5U;FEN9R!I<R!N:65T(&EN
M9V5S8VAA:V5L9"!O<"!D:70@<WES=&5E;2X`4R]-24U%(&]N9&5R<W1E=6YI
M;F<@:7,@;6]M96YT965L(&YI970@86-T:65F+"!H970@8F5R:6-H="!K86X@
M9'5S(&YI970@9V5D96-O9&5E<F0@=V]R9&5N+@!3+TU)344@;VYD97)S=&5U
M;FEN9R!I<R!N:65T(&%C=&EE9BP@9&4@9&EG:71A;&4@:&%N9'1E:V5N:6YG
M(&MA;B!D=7,@;FEE="!G979E<FEF:65E<F0@=V]R9&5N+@!305-,(&%U=&AE
M;G1I8V%T:64@:7,@;FEE="!B97-C:&EK8F%A<BX`4TU3('9E<G-T=7)E;@!3
M44P@<VAE;&P`4U-(`%-50T-%4P!37U%,('-H96QL`$]N9&5R=V5?<G``6F$`
M0F5?=V%A<B!E96X@:V]P:64@:6X@`$]P7W-L86%N(&%L<P!3="!(96QE;F$`
M4W0@2VET=',@96X@3F5V:7,`4W0@3'5C:6$`4W0@4&EE<G)E(&5N($UI<75E
M;&]N`%-T(%9I;F-E;G0@96X@9&4@1W)E;F%D:6YE<P!:96QF9&4@9G)A;64@
M*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&5N(%!R:6YC:7!E
M`%-A=&5L;&EE='!R;W9I9&5R`%-A=61I($%R86)IZP!/<'-L86%N`"5S(&]P
M<VQA86X`0FEJ;&%G96X@<V%M96X@;65T(&)E<FEC:'0@;W!S;&%A;B!I;B!O
M=71B;W@@;6%P/P!/<'-L86%N(&%L<R!K;&%D`$]P=&EE<R!O<'-L86%N`$]P
M<VQA86X@86QS(%]K;&%D`$]P<VQA86X@86QS`$ML860@;W!S;&%A;B!A;',@
M;VYG97II96X_`$=E9V5N97)E97)D92!C;VYF:6=U<F%T:64@86QS(%!(4"!S
M8W)I<'0@;W!G97-L86=E;B!I;B!D92!T:6ID96QI:FME(&1I<F5C=&]R>2!V
M86X@=7<@<V5R=F5R+@!/;G1V86YG97)S(&%U=&]M871I<V-H(&EN('-T86YD
M86%R9"!A9')E<V)O96L@;W!S;&%A;C\`6F]E:V]P9')A8VAT(&)E=V%R96X@
M86QS('9I<G1U96QE(&UA<#\`0F5W86%R('9E<GIO;F1E;B!M86EL/P`E<R!C
M;VYF:6=U<F%T:64@;W!G97-L86=E;@!"97=A<F5N('9A;B!K;&%D(&UI<VQU
M:W0N($1E('-E<G9E<B!M96QD=#H@)7,`5V5T96YS8VAA<`!:;V5K96X`)7,@
M9&]O<GIO96ME;@!:;V5K;6%C:&EN97,`6F]E:W)E<W5L=&%T96X`1V5Z:65N
M`%-E;&5C=&5R96X`4V5L96-T965R(&5E;B!A;F1E<F4@86-C;W5N=`!+:65S
M(&)E<W1A;F1E;@!396QE8W1E97(@965N(&1A='5M`%-E;&5C=&5E<B!E96X@
M=F5L9`!396QE8W1E97(@965N(&=R;V5P(&]M('1O92!T92!V;V5G96X`4V5L
M96-T965R(&5E;B!N:65U=V4@96EG96YA87(`4V5L96-T965R(&5E;B!S97)V
M97(`4V5L96-T965R(&5E;B!G96)R=6EK97(@;VT@=&]E('1E('9O96=E;@!3
M96QE8W1E97(@861R97-B;V5K8G)O;FYE;B!V;V]R('1O979O96=E;B!E;B!Z
M;V5K96X@=F%N(&%D<F5S<V5N+@!396QE8W1E97(@86QL97,`4V5L96-T965R
M(&%L;&4@9&%T=6UC;VUP;VYE;G1E;BX`4V5L96-T965R(&%L;&4@=F5L9&5N
M(&]M('1E(&1O;W)Z;V5K96X@="YB+G8N(&YA86US=6ET8G)E:61I;F<N`%-E
M;&5C=&5E<B!E96X@86-C;W5N=`!396QE8W1E97(@965N(&]B:F5C=`!396QE
M8W1E97(@;FEE=',`4V5L96-T965R(&1E(&)E;F]D:6=D92!K87)A:W1E<G,@
M=6ET(&1E(&]N9&5R<W1A86YD92!V86MJ97,N(%4@:W5N="!D97IE(&1A;B!K
M;W!IZW)E;B!E;B!P;&%K:V5N(&EN(&AE="!T96MS=&=E8FEE9"X`4V5L96-T
M965R(&AE="!D871U;7-C:&5I9&EN9W-T96ME;CH`4V5L96-T965R(&AE="!D
M871U;69O<FUA870Z`%-E;&5C=&5E<B!D92!I9&5N=&ET96ET(&1I92!U('=I
M;'0@=VEJ>FEG96XZ`%-E;&5C=&5E<B!H970@;6%I;'-E<G9E<G1Y<&4`4V5L
M96-T965R(&AE="!T:6ID<V-H96ED:6YG<W1E:V5N.@!396QE8W1E97(@:&5T
M('1I:F1S9F]R;6%A=#H`4V5L96-T965R('1W964@;W9E<F5E;FMO;65N9&4@
M=F5L9&5N+@!396QE8W1E97(@=7<@:VQE=7)S8VAE;6$N`%-E;&5C=&5E<B!U
M=R!G97=E;G-T92!T86%L.@!'97-E;&5C=&5E<F1E(&%D<F5S8F]E:V5N.@!6
M97)Z96YD('-L975T96P@;F%A<B!O<&5N8F%R92!S;&5U=&5L<V5R=F5R`%9E
M<GIE;F0@;&%A='-T92!I;F9O<FUA=&EE`%9E<GIE;F0@8F5R:6-H=`!0<F]B
M;&5E;7)A<'!O<G0@=F5R>F5N9&5N`%9E<GIE;F0@4TU3`%-E;F5G86P`4V5N
M<V]R.B``3U540D]8`$]55$)/6#H`4V5P=&5M8F5R`%-E<G9IZR!E;B!-;VYT
M96YE9W)O`%-E<FEE;G5M;65R`%-E<G9E<@!397)V97(M(&5N(&UA<&EN9F]R
M;6%T:64`4V5R=F5R.@!397-S:64@240@=F5R;&]P96XN`$EN<W1E;&QE;@!)
M;G-T96QL96X@=F%N(&]P=&EE<R!O;2!U('1O92!T92!S=&%A;B!U=R!W86-H
M='=O;W)D('1E(')E<V5T=&5N+"!W86YN965R('4@9&ET(&)E;G0@=F5R9V5T
M96XN`%9O;W)K975R<VEN<W1E;&QI;F=E;B!V;V]R(&AE="!V97)P;&%A='-E
M;B!E;B!V97)W:6ID97)E;B!V86X@8F5R:6-H=&5N+@!);G-T96QL96X@=F%N
M(&1E(%@M4')I;W)I='D@:&5A9&5R(&)I:B!H970@;6%K96X@=F%N(&)E<FEC
M:'1E;C\`26YS=&5L;&5N('9A;B!S97)V97)S(&]P(&%F<W1A;F0@9&EE('4@
M=VEL="!B96YA9&5R96X@=F%N=6ET('5W('!O<G1A;"X`26YS=&5L;&5N('9A
M;B!U=R!G97=E;G-T92!T86%L+"!T:6ID>F]N92!E;B!D871U;6]P=&EE<RX`
M26YS=&5L;&5N('9A;B!U=R!O<'-T87)T=&]E<&%S<VEN9RP@:VQE=7)S8VAE
M;6$L('!A9VEN879E<G9E<G-I;F<@96X@86YD97)E('=E97)G879E;W!T:65S
M+@!3971U<"!U<&=R861E('-C<FEP=',@8F5S8VAI:V)A87(`5F5R<V-H:6QL
M96YD92!L;V-A=&EE<R!M;V=E;&EJ:R!M970@9&4@<&%R86UA=&5R.B``4V5Y
M8VAE;&QE;@!-87!P96X@9&5L96X`36%I;&UA<'!E;B!D96QE;@!$965L('5W
M(&UA:6QM87!P96X@;65T(&%N9&5R92!G96)R=6EK97)S+@!7:6YK96QE;@!+
M;W)T92!S86UE;G9A='1I;F<`1&EE;F5N('-N96QT;V5T<V5N('9O;W(@9&4@
M;65E<W1E(&QI;FMS(&=E9&5F:6YI965R9"!T92!W;W)D96X_`$1I96YE;B!G
M<F]T92!B;&]K:V5N(&%A;F=E:&%A;&1E('1E:W-T('-T86YD86%R9"!W965R
M9V5G979E;B!O9B!V97)B;W)G96X@=&4@=V]R9&5N/R!(970@:V%N(&5E;G9O
M=61I9R!O;6=E<V-H86ME;&0@=V]R9&5N+"!W96QK92!U(&]O:R!K:65S="X`
M5VEL="!U(&1E(&)O9'D@=F%N('1E>'0O<&QA:6X@8F5R:6-H=&5N('-C86YN
M96X@;W`@4$=0(&1A=&$_`$1I96YT(&AE="`B3FEE=7<@8F5R:6-H="(@<V-H
M97)M(&=E<VQO=&5N('1E('=O<F1E;B!N82!O<'-L86%N('9A;B!K;&%D/P!$
M:65N="!U=R!O<&5N8F%R92!01U`@<VQE=71E;"!S=&%N9&%A<F0@86%N('5W
M(&)E<FEC:'1E;B!T;V5G979O96=D('1E('=O<F1E;C\`5V5E<F=E=F5N`$%L
M;&4@;6%P<&5N('=E97)G979E;@!!;&QE(&AE861E<G,@=V5E<F=E=F5N`%1O
M;VX@=F5R=VEJ9&5R9`!"97!E<FMT92!H96%D97)S('=E97)G979E;@!-86EL
M:6YG;&ES="!I;F9O<FUA=&EE('=E97)G979E;@!!;&QE96X@:6YG97-C:')E
M=F5N(&UA<'!E;B!W965R9V5V96X`5&]O;B!U:71G97-C:')E=F5N`%!I8W1O
M9W)A;2!V;V]R(&AE="!V97)W:6ID97)E;B!V86X@8F5R:6-H=&)I:FQA9V5N
M('=E97)G979E;C\`5F5R<V-H:6QL96X@;&%T96X@>FEE;B!T=7-S96X@9&4@
M:'5I9&EG92!O<&=E<VQA9V5N(&-O;F9I9W5R871I92!E;B!D92!N:65U=V4@
M9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92X`3&%A='-T92!A86YM96QD:6YG
M<W1I:F0@=V5E<F=E=F5N(&)I:B!A86YM96QD96X_`$QE9V5N9&$@=V5E<F=E
M=F5N(&EN(&1E(&UA:6QB;WAW965R9V%V93\`3W!T:64@=V5E<F=E=F5N(&]M
M(&]R:6=I;F5E;"!T92!B97=A<F5N`$MI97IE<B!W965R9V5V96X`06QL965N
M('!R979I97=S('=E97)G979E;B!V86X@;VYG96QE>F5N(&)E<FEC:'1E;C\`
M4')E=FEE=W,@:6X@=&]O;'1I<',@=V5E<F=E=F5N/P!486)E;&)E=V5R:VEN
M9W-T86%K8F%L:R!W965R9V5V96X_`"5S(&UE;G4@86%N(&1E(&QI;FME<FMA
M;G0@=V5E<F=E=F5N/P!-86EL(&]P:&%L96X@<&EC=&]G<F%M('=E97)G979E
M;B!O<"!D92!M96YU8F%L:S\`1&4@869B965L9&EN9V5N('=E97)G979E;@!4
M86)E;&-E;&5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N
M`%1A8F5L96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96X`
M5&%B96QR:6IE:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS=&5R('=E97)G979E
M;@!&:6QT97(@<&EC=&]G<F%M('=E97)G979E;B!O<"!D92!M96YU8F%L:S\`
M069B965L9&EN9W-E:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS=&5R('=E97)G
M979E;@!4;W1A86P@86%N=&%L(&UA:6QS(&EN(&UA<"!W965R9V5V96X_`%5P
M;&]A9"!W965R9V5V96X`0G5I96X`0G5I96X@=G)O96<`0G5I96X@;&%A=`!7
M965R9V5G979E;@!697)K;&5I;F5N`%9E<FML96EN(&]F('9E<G!L86%T<R!N
M86)U<FEG92!B;&]K:V5N(&5E<G-T`%]'<F]O='1E`%-I97)R82!,96]N90!)
M;G1E:V5N96X`2&%N9'1E:V5N:6YG`$AA;F1T96ME;FEN9R!A;&=O<FET:&UE
M`$]N9&5R=&5K96YD`%-I;F=A<&]R90!'<F]O='1E`$]N9&5R:&]U9"!O=F5R
M<VQA86X`4VQO=V%K:6IE`%-L;W9E;FGK`%-N965U=P!3;F5E=7=V;&%A9P!3
M;F5E=7=B=6EE;@!3;F5E=7=B=6EE;B!L86%T`%-N965U=V1I97!T93H@`%-N
M965U=V5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N(&5I;&%N9&5N`%-O
M;6%L:>L`3&EE9&5R96X@96X@9V5D:6-H=&5N`%-O<G1E<F5N(&]P(&%A;FMO
M;7-T=&EJ9`!3;W)T97)E;B!O<"!D871U;0!3;W)T97)E;B!O<"!A9GIE;F1E
M<@!3;W)T97)E;B!O<"!B97)I8VAT9W)O;W1T90!3;W)T97)E;B!O<"!O;F1E
M<G=E<G``4V]R=&5R96X@;W`@=&AR96%D`%-O<G1E<F5N(&]P(&=E861R97-S
M965R9&4`4V]R=&5E<G9O;&=O<F1E('-E;&5C=&EE`$)R;VYA9')E<P!:=6ED
M($%F<FEK80!:=6ED($5U<F]P965S("A)4T\M.#@U.2TS*0!:=6ED($=E;W)G
M:>L@96X@9&4@6G5I9"!386YD=VEC:"!E:6QA;F1E;@!:=6ED96QI:FL@:&%L
M9G)O;F0`4W!A=&GK<FEN9R!T=7-S96X@86%N9W)E;GIE;F1E(&-E;&QE;@!3
M<&%T:>MR:6YG('1U<W-E;B!I;FAO=60@96X@<F%N9"!I;B!C96P`4V-H96ED
M:6YG<W1E:V5N`%-P871IZW)I;F<`4W!A=&GK<FEN9R!E;B!V<FEJ92!R=6EM
M=&4`4W!A;FIE`%-P86T`4W!A;2!M87`Z`%-P96-I86%L(&MA<F%K=&5R(&EN
M=F]E<@!3<&5C:6%L92!K87)A:W1E<G,`4W!E;&QI;F=S8V]N=')O;&4`4W!E
M;&QI;F=S8V]N=')O;&4`4W!E;&QI;F=S8V]N=')O;&4@8V]M<&QE970`4W!E
M;&9O=71E;B!P97(@<&%G:6YA('1I:F1E;G,@<W!E;&QI;F=S8V]N=')O;&4N
M`$-E;"!O<'-P;&ET<V5N`$MO;&]M(&]P<W!L:71S96X`4FEJ(&]P<W!L:71S
M96X`4W!O<G0`4W)I($QA;FMA`%-T86YD86%R9`!3=&%R(%1R96L`4W1A<G0`
M4W1A<G1J86%R`%-T86%T(&]F('!R;W9I;F-I90!3=&%T=7,`3W!S;&%G9F]R
M;6%A=`!!9')E<P!$;V]R:&%L96X`4W1R:6YG;&EJ<W0`0FEJ;&%G92!S=')I
M<'!E;@!3=')I<"!D;VUE:6X@=F%N(&AE="!A9')E<P!296=E;&5I;F1E;B!V
M97)W:6ID97)E;C\`4W1I:FP@6T-34UT`6F\`3VYD95]R=V5R<`!/;F1E<G=E
M<G``3VYD97)W97)P=F5L9`!"979E<W1I9V5N`$EN<V-H<FEJ=F5N('9A;B!M
M87`H<&5N*0!3=6)S8W)I<'0`4W5C8V5S`$-O;F9I9W5R871I92!M970@<W5C
M8V5S('1E<G5G9V5Z970N(%9E<FYI975W(&]M('=I:GII9VEN9V5N('1E('II
M96XN`$)A8VMU<&-O;F9I9W5R871I92!M970@<W5C8V5S<R!O<&=E<VQA9V5N
M+@`E<R!M970@<W5C8V5S(&=E<V-H<F5V96X`4V]E9&%N`%-U9V=E<W1I97,`
M4V%M96YV871T:6YG`%IO;G-O<&=A;F<`6F]N<V]N9&5R9V%N9P!:;VYN:6<`
M6F]N<V]P9V%N9P!:;VYS;W!G86YG+UIO;G-O;F1E<F=A;F<`6F]N<V]P9V%N
M9SH@`%IO;G-O;F1E<F=A;F<`6F]N<V]N9&5R9V%N9SH@`%-U<&5R<V-R:7!T
M`$]N9&5R<W1E=6YI;F<`4W5R:6YA;64`06-H=&5R;F%A;0!3<&ET<V)E<F=E
M;B!E;B!*86X@36%Y96X`4W=A>FEL86YD`%IW961E;@!/;7-C:&%K96QE;B!V
M86X@8V]M<&]S:71I96UE=&AO9&4`3VUS8VAA:V5L96X@;F%A<B!(5$U,(&-O
M;7!O<VET:64`3VUS8VAA:V5L96X@;F%A<B!P;&%T=&4@=&5K<W0@8V]M<&]S
M:71I90!:=VET<V5R;&%N9`!3>6YT87AF;W5T(&EN('IO96MT97)M96X`4WER
M:7-C:&4@07)A8FES8VAE(%)E<'5B;&EE:P!/;G=E97)S8G5I`$]N=V5E<G-B
M=6EE;@!44U8@8F5S=&%N9`!486)E;`!486)E;&5I9V5N<V-H87!P96X`5&%B
M96QE:6=E;G-C:&%P<&5N`%1A:7=A;@!486EW86XL(%!R;W9I;F-I92!V86X@
M0VAI;F$`5&%D>FII:VES=&%N`%1A;GIA;FEA+"!697)E;FEG9&4@4F5P=6)L
M:65K('9A;@!$;V5L.@!486ME;@!47V5K<W0`5&5L969O;VYN=6UM97(`5&5M
M<&5R871U=7(@=F%N(&AE="!A9F=E;&]P96X@=75R.B``5&5M<&5R871U=7(`
M5&5M<&5R871U=7(Z(`!3:F%B;&]O;F)E:&5E<@!697)Z;V5K('9O;W)L;W!I
M9R!A8V-E<'1E<F5N`%9O;W)L;W!I9R!G96%C8V5P=&5E<F0`1V5B<G5I:V5R
M<V]V97)E96YK;VUS="!N:65T(&]P9V5G979E;B!I;B!C;VYF+G!H<`!!;&QE
M96X@=&5K<W0`5&5K<W0@=6ET;&EJ;F5N`%1E:W-T8F]V96YK86YT`$1O`%1H
M86ES("A425,M-C(P*0!4:&%I;&%N9`!"961A;FMT('9O;W(@:&5T(&=E8G)U
M:6ME;B!V86X@:&5T('-Y<W1E96TN`$1E($944"!E>'1E;G1I92!I<R!N:65T
M(&)E<V-H:6MB86%R+@!$92!686XZ(&MO;&]M('9A;B!H970@8F5R:6-H="!D
M:65N="!G96QI;FMT('1E('=O<F1E;CH`1&4@2&]R9&4O2V]L86(@:6YT96=R
M871I92!O;F1E<G-T975N="`B)7,B(&YI970`2&5T($UA8VEN=&]S:"!B<F]N
M<')O8V5S`$AE="!-86-I;G1O<V@@8G)O;G!R;V-E<R!K86X@=V]R9&5N(&=E
M9&]W;FQO860@)7,N`$1E($UA:6YT96YA;F-E.CH@8VQA<W,@=V5R9"!N:65T
M(&=E;&%D96X`2&5T($]P=&EE<W-C:&5R;2!I<R!G97-L;W1E;BX@069S;'5I
M=&5N+@!$92!A8V-O=6YT("(E<R(@:7,@=F5R=VEJ9&5R9"X`1&4@86-C;W5N
M="`B)7,B(&ES(&]P9V5S;&%G96XN`$1E(&)E:&5E<F1E<B!D:65N="!E96X@
M<&5R;6%N96YT(')E8VAT96YB86-K96YD('1E(&-O;F9I9W5R97)E;B!A;',@
M=2!R96-H=&5N('=I;'0@9V5B<G5I:V5N+@!$92!B:6IL86=E(&ES(&YI970@
M9V5V;VYD96XN`$%L;&5E;B!D92!O;F1E<FMA;G0`2&5T(").:65U=R!B97)I
M8VAT(B!S8VAE<FT@:V%N(&YI970@=V]R9&5N(&=E;W!E;F0N($UI<W-C:&EE
M;B!H965F="!U('5W(&)R;W=S97(@:6YG97-T96QD(&]M('!O<'5P('-C:&5R
M;65N('1E(&)L;VMK97)E;C\`2&5T(&-O;G1A8W0@240@;G5M;65R(&ES(&YI
M970@;W!G96=E=F5N+"!L965G(&=E;&%T96X@;V8@:7,@;FEE="!G979O;F1E
M;B!I;B!D92!D871A8F%S92X`2&5T(&%D<F5S(&ES(&UE="!S=6-C97,@86%N
M('5W(&%D<F5S8F]E:R!T;V5G979O96=D+@!$92!I;FAO=60@=F%N(&AE="!-
M86-I;G1O<VAB97-T86YD('-T86%T(&AI97)O;F1E<BX`1&4@:'5I9&EG92!M
M87`H<&5N*2`B)7,B('IU;&QE;B!W;W)D96X@:&5R;F]E;60@=&]T("(E<R(N
M`$1E(&AU:61I9V4@;&EJ<W0@;65T(&=E8G)U:6ME<G,@;65T('1O96=A;F<@
M;W`@9&5Z92!M87`@:V]N(&YI970@=V]R9&5N(&]P9V5H86%L9`!(970@;&]S
M9V5K;W!P96QD92!01U`@;VYD97)T96ME;FEN9W-B;&]K(&ES('9E<F5I<W0@
M;VT@:&5T(&]N9&5R=&5K96YD92!B97)I8VAT('1E('9E<FEF:>MR96XN`$AE
M="!D:7-T<G5B=71I96QI:G-T($E$(&ES(&YI970@;W!G96=E=F5N+"!L965G
M(&=E;&%T96X@;V8@:7,@;FEE="!G979O;F1E;B!I;B!D92!D871A8F%S92X`
M1&4@9&ES=')I8G5T:65L:6IS="!I<R!N:65T(&]P9V5G979E;BX`2&5T(&ML
M860@:7,@;W!G97-L86=E;B!I;B!D92`B)7,B(&UA<"X`1&4@8V]D965R;6]G
M96QI:FMH961E;B!V97)E:7-E;B!E96X@8F5V96EL:6=D92!W96)V97)B:6YD
M:6YG+@!$92!G96)E=7)T96YI<R!I<R!A86X@=7<@86=E;F1A('1O96=E=F]E
M9V0N`$AE="!B97-T86YD("5S(&1I96YT(&5E;B`E<R!I;G-T96QL:6YG('1E
M(&)E=F%T=&5N+@!(970@8F5S=&%N9"`E<R!D:65N="!E;FEG92`E<R!I;G-T
M96QL:6YG96X@=&4@8F5V871T96XN`$AE="!B97-T86YD(&MA;B!N:65T(&YA
M87(@>FEC:'IE;&8@9V5K;W!I965R9"!W;W)D96XN`$AE="!B97-T86YD(&)E
M=F%T=&4@9V5E;B!D871A+@!$92!M87`@(B5S(B!B97-T86%T(&%L`$1E(&UA
M<&YA86T@(B5S(B!B979A="!O;F=E;&1I9V4@:V%R86MT97)S+B!$:70@>F]U
M('!R;V)L96UE;B!K=6YN96X@=F5R;V]R>F%K96XN($YE96T@8V]N=&%C="!O
M<"!M970@9&4@<WES=&5E;6)E:&5E<F1E<BP@82YU+F(N`$1E(&UA<"`B)7,B
M('=E<F0@86%N9V5M86%K="!M86%R('4@:&5E9G0@9&5Z92!N:65T(&EN9V5S
M8VAR979E;BX`1&4@;6%P("(E<R(@=V5R9"!V97)W:6ID97)D+"!M86%R('4@
M:&5E9G0@9&5Z92!N:65T('5I=&=E<V-H<F5V96XN`$1E(&UA<"`B)7,B('=E
M<F0@;FEE="!A86YG96UA86MT+B!$92!S97)V97(@;65L9'0`1&4@;6%P("(E
M<R(@=V5R9"!M970@<W5C8V5S(&%A;F=E;6%A:W0N`$1E(&UA<"`B)7,B('=E
M<F0@;65T('-U8V-E<R!V97)W:6ID97)D+@!$92!M87`@(B5S(B!W97)D(&UE
M="!S=6-C97,@:&5R;F]E;60@=&]T("(E<R(N`$AE="!V;VQG96YD92!Z:6IN
M(&1E(&MO<'!E;B!V86X@9&ET(&UE<W-A9V4O<F9C.#(R(&)E<FEC:'0N`$1E
M('9O;&=E;F1E(&)E<W1A;F1E;B!W87)E;B!G96MO<'!E;&0@86%N(&1I="!O
M;F1E<F1E96PZ`%9A;B!D92!V;VQL961I9R!S8VAE<FT@;6]D92!I<R!B96ME
M;F0L(&1A="!D:70@<')O8FQE;65N(&MA;B!V97)O;W)Z86ME;B!M970@26YT
M97)N970@17AP;&]R97(L('9A;G=E9V4@8G)O=W-E<F)U9W,@=V%A<B!W:6H@
M;FEE="!O;6AE96X@:W5N;F5N+B!(970@:7,@;6]G96QI:FL@9&%T('4@<F]M
M;65L(&EN(&AE="!B965L9'-C:&5R;2P@9V5B<F5K(&%A;B!E9&ET;W)F=6YC
M=&EE<R!E;B]O9B!R86YD;VT@8G)O=W-E<BT@8W)A<VAE<R!E<G9A87)T+B!7
M86YN965R('5W('-Y<W1E96T@5VEN9&]W<R`Y>"!I<RP@:7,@:&5T('=A87)S
M8VAI:FYL:6IK(&1A="!U(&5E;B`G06QG96UE;F4@0F5V96EL:6=I;F=S($9O
M=70G(&MR:6IG="P@96X@;W!N:65U=R!D:65N="!T92!H97)S=&%R=&5N+EQN
M7&Y5(&)E;G0@9V5W86%R<V-H=7=D+B!$<G5K(&]P($]+('=A;FYE97(@=2!T
M;V-H(&1E('9O;&QE9&EG('-C:&5R;2!E9&ET;W(@=VEL="!P<F]B97)E;BX`
M1&4@:61E;G1I=&5I="`B)7,B(&ES('9E<G=I:F1E<F0N`$1E(&%F8F5E;&1I
M;F=E;B!W;W)D96X@=V5E<F=E=F5N+"!O;61A="!D92!A9GIE;F1E<B!Z:6-H
M(&EN('5W(&%D<F5S8F]E:R!B979I;F1T+@!!;&QE96X@9&4@;&EN:V5R:V%N
M=`!$92!P;&%A=',@=F%N(&AE="!';G501R!P<F]G<F%M;6$@9&EE;G0@;W!G
M96=E=F5N('1E('=O<F1E;B!I;B!D92!#<GEP=%]P9W`Z.B!C;&%S<RX`1&4@
M;6%I;'-E<G9E<B!G96YE<F5E<F1E(&AE="!V;VQG96YD92!F;W5T8F5R:6-H
M=#H`1&4@;6%I;'-E<G9E<B!G96YE<F5E<F1E(&AE="!V;VQG96YD92!I;F9O
M<FUA=&EE8F5R:6-H=#H`1&4@;6%I;'-E<G9E<B!G96YE<F5E<F1E(&AE="!V
M;VQG96YD92!B97)I8VAT.@!$92!M86EL8F]X("5S(&ES(&%L(&QE96<N`$AE
M="!B97)I8VAT("(E<R(@=F%N("(E<R(@*"5D(&)Y=&5S*2!O=F5R<V-H<FEJ
M9'0@9&4@;W!H86%L9W)O;W1T92!L:6UI970N`$AE="!B97=E<FMT92!B97)I
M8VAT(&ES(&%F9V5S;&]T96XN($%F<VQU:71E;BX`2&5T(&)E<FEC:'0@:7,@
M=F5R=VEJ9&5R9"X`2&5T(&)E<FEC:'0@:7,@9V5V97)I9FEE97)D+@!(970@
M8F5R:6-H="!I<R!G979E<FEF:65E<F0N($%F>F5N9&5R.B`E<RX`2&5T(&)E
M<FEC:'0@=F5R<W1U=7)D(&]P("5S(&%A;B`E<R!M970@;VYD97)W97)P("(E
M<R(@:7,@=V5E<F=E9V5V96XN"D1I="!I<R!G965N(&=A<F%N=&EE(&1A="!H
M970@8F5R:6-H="!I<R!G96QE>F5N(&]F(&)E9W)E<&5N+@!$92!N86%M(&1I
M92!G96)R=6EK="!W;W)D="!B:6H@;&EN:V5N(&YA87(@9&4@;FEE=7<@8F5R
M:6-H="!P86=I;F$`1&4@;W!E;G-S;"!M;V1U;&4@:7,@=F5R96ES="!V;V]R
M(&1E($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`$AE="!W86-H='=O;W)D
M('-C:&5R;2!K86X@;FEE="!W;W)D96X@9V5O<&5N9"X@36ES<V-H:65N(&AE
M969T('4@=7<@8G)O=W-E<B!I;F=E<W1E;&0@;VT@<&]P=7`@<V-H97)M96X@
M=&4@8FQO:VME<F5N/P!$92!V;V]R:V5U<G-I;G-T96QL:6YG("(E<R(@:V]N
M(&YI970@=V]R9&5N(&]P9V5S;&%G96XL(&]M9&%T(&1E(&1A=&$@9&4@;6%X
M:6UU;2!T;V5L86%T8F%R92!G<F]O='1E(&]V97)S8VAR:6ID="X`2&5T('!R
M;V=R86UM82!O;2!D:70@9&%T871Y<&4@*"5S*2!T92!B96MI:FME;BP@=V5R
M9"!N:65T(&]P(&AE="!S>7-T965M(&=E=F]N9&5N+@!$92!R=7=E('1E:W-T
M('9A;B!D92!O<&5N8F%R92!01U`@<VQE=71E;"!K86X@=V]R9&5N(&)E:V5K
M96X@)7,N`$AE="!G979R86%G9&4@8F5S=&%N9"!B97-T86%T(&YI970@:6X@
M9&4@35,M5$Y%1B!B:6IL86=E+@!(970@9V5V<F%A9V1E(&)E<W1A;F0@8F5S
M=&%A="!N:65T(&EN(&1E(%II<"!B:6IL86=E+@!!;&QE96X@9&4@<F5C:'1E
M<BT@96X@;&EN:V5R:V%N=`!!;&QE96X@9&4@<F5C:'1E<FMA;G0`1&4@869Z
M96YD97(@=F%N(&1I="!B97)I8VAT('9R86%G="!U(&]M(&5E;B!O;G1V86YG
M<W1B979E<W1I9VEN9RP@=V%N;F5E<B!U(&1I="!B97)I8VAT(&AE969T(&=E
M;&5Z96XN($ML:6L@;W`@)7,@;VT@9&4@;VYT=F%N9W-T8F5V97-T:6=I;F<@
M=&4@=F5R>F5N9&5N+@!$92!S97)V97(@(B5S(B!I<R!V97)W:6ID97)D+@!$
M92!S97)V97(@(B5S(B!I<R!O<&=E<VQA9V5N+@!$92!O;F1E<G1E:V5N:6YG
M(&MO;B!N:65T('=O<F1E;B!V97)V86YG96XN`$1E(&]N9&5R=&5K96YI;F<@
M:7,@;65T('-U8V-E<R!V97)V86YG96XN`$AE="!A86YM96QD:6YG<W9E<GIO
M96L@=F]O<B`E<R!I<R!V97)W:6ID97)D+@!(970@;W!G96=E=F5N(&)E<W1A
M;F0@8F5S=&%A="!N:65T+@!$92!O<&=E9V5V96X@<FEJ(&)E<W1A870@;FEE
M="X`1&4@=&%A:R!I<R!A86X@=7<@=&%A:VQI:G-T('1O96=E=F]E9V0N`$1E
M('1E:W-T('9A;B!H970@8F5R:6-H=`!$92!T96MS="!V86X@:&5T(&)E<FEC
M:'0@:V%N('=O<F1E;B!B96ME:V5N("5S+@!$92!T96MS="!V86X@:&5T(&=E
M<F5T;W5R;F5E<F0@8F5R:6-H=`!$92!T96MS="!V86X@:&5T(&=E<F5T;W5R
M;F5E<F0@8F5R:6-H="!K86X@=V]R9&5N(&)E:V5K96X@)7,N`$1E('1E:W-T
M('9A;B!H970@=F5R>F]N9&5N(&)E<FEC:'0`1&4@=&5K<W0@=F%N(&AE="!V
M97)Z;VYD96X@8F5R:6-H="!K86X@=V]R9&5N(&)E:V5K96X@)7,N`$%L;&5E
M;B!D92!B;W9E;BT@96X@;VYD97)K86YT`$%L;&5E;B!D92!B;W9E;FMA;G0`
M1&4@=7!L;V%D960@9&%T82!I<R!N82!D92!V;V]R9V%A;F1E('-T87`@=F5R
M;&]R96X@9V5G86%N+@!(970@=7!L;V%D960@8F5S=&%N9"!I<R!N:65T(&]P
M9V5S;&%G96XN`$1E('9R:6HO8F5Z970@:6YF;W)M871I92!V86X@9&4@9V5B
M<G5I:V5R(&ES(&UE="!S=6-C97,@;W!G97-L86=E;BX`2&5T('=E871H97(N
M8V]M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX`17(@>FEJ;B!G965N(&%L
M=&5R;F%T:65V92!O;F1E<F1E;&5N(&1I92!I;FQI;F4@=V5E<F=E9V5V96X@
M:W5N;F5N('=O<F1E;BX`17(@>FEJ;B!G965N(&)E<FEC:'1E;B!I;B!D97IE
M(&UA:6QB;W@N`$=E96X@;W!T:65S(&)E<V-H:6MB86%R+@!%<B!Z:6IN(&=E
M96X@;VYD97)D96QE;BP@=V5L:V4@:6YL:6YE('=E97)G96=E=F5N(&MU;FYE
M;B!W;W)D96XN`$5R('II:FX@=&4@=F5E;"!K87)A:W1E<G,@:6X@9&ET('9E
M;&0N(%4@:&5E9G0@)7,@:V%R86MT97)S(&]P9V5G979E;CL@=2!D:65N="!M
M:6YD97(@9&%N("5S(&]P('1E(&=E=F5N+@!%96X@9F]U="!B:6H@:&5T('-C
M:')A<'!E;B!V86X@)7,N($1E('-E<G9E<B!M96QD=`!%96X@9F]U="!B:6H@
M:&5T('5I='=I<W-E;B!V86X@9&4@;6%I;&)O>"X@1&4@<V5R=F5R(&UE;&1T
M.B`E<P!%96X@9F]U="!B:6H@:&5T('5I='=I<W-E;B!V86X@9&4@;6%I;&)O
M>"X@1&4@<V5R=F5R(&UE;&1T`$5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N
M9'-U<&QO860Z($=E96X@)7,@=V5R9"!G975P;&]A9"X`165N('!R;V)L965M
M(&UE="!D92!B97-T86YD<W5P;&]A9#H@2&5T("5S(&ES(&=R;W1E<B!D86X@
M9&4@;6%X:6UU;2!T;V5L86%T8F%R92!G<F]O='1E("@E9"!B>71E<RDN`$5E
M;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($AE="`E<R!I<R!S
M;&5C:'1S(&=E9&5E;'1E;&EJ:R!G975P;&]A9"X`165N(&9O=70@8FEJ(&AE
M="!K;W!IZW)E;B!V86X@8F5R:6-H=&5N('9A;B`B)7,B(&YA87(@(B5S(BX@
M1&4@<V5R=F5R(&UE;&1T`$5E;B!F;W5T(&)I:B!H970@=F5R=VEJ9&5R96X@
M=F%N(&)E<FEC:'1E;B!U:70@9&4@;6%P("(E<R(N($1E('-E<G9E<B!M96QD
M=`!%96X@9F]U="!B:6H@:&5T('9E<G=I:F1E<F5N('9A;B!B97)I8VAT96X@
M:6X@9&4@;6%P("(E<R(N($1E('-E<G9E<B!M96QD=`!%96X@9F]U="!B:6H@
M:&5T('9E<G=I:F1E<F5N('9A;B!B97)I8VAT96XN($1E('-E<G9E<B!M96QD
M=#H@)7,`165N(&9O=70@8FEJ(&AE="!V97)W:6ID97)E;B!V86X@9&4@9V5B
M975R=&5N:7,Z("5S+@!%96X@9F]U="!B:6H@:&5T(&)E:VEJ:V5N('9A;B!D
M:70@8F5R:6-H=&]N9&5R9&5E;`!%96X@9F]U="!B:6H@:&5T(&UA<FME<F5N
M('9A;B!B97)I8VAT96X@:6X@9&4@;6%P("(E<R(N($1E('-E<G9E<B!M96QD
M=`!%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R96X@=F%N("5S+@!%96X@9F]U
M="!B:6H@:&5T(&EM<&]R=&5R96X@=F%N(&1E(&%D<F5S9&%T82X`165N(&9O
M=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D92!G96)E=7)T96YI<SH@)7,N
M`$5E;B!F;W5T(&)I:B!H970@:6UP;W)T97)E;B!V86X@9&4@:4-A;&5N9&%R
M9&%T82X`165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D92!T86%K
M.B`E<RX`165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!V<FEJ+V)E
M>F5T(&EN9F]R;6%T:64@=F%N(&1E(&=E8G)U:6ME<CH@)7,N`$5E;B!F;W5T
M(&EN(&AE="!C;VYF:6=U<F%T:65F;W)M=6QI97(N($UI<W-C:&EE;B!B96YT
M('4@965N('9E<G!L:6-H="!V96QD('9E<F=E=&5N+@!%96X@9F]U="!B:6H@
M:&5T('9E<G!L86%T<V5N('9A;B!B97)I8VAT96X@=F%N("(E<R(@;F%A<B`B
M)7,B+B!$92!S97)V97(@;65L9'0`165N(&9O=70@8FEJ(&AE="!U:71V;V5R
M96X@=F%N(&1E(&]P9V5G979E;B!A9')E<V)O96MF=6YC=&EE+B!0<F]B965R
M(&QA=&5R(&]P;FEE=7<L(&$N=2YB+@!%96X@9F]U="!B:6H@:&5T(&]P<VQA
M86X@=F%N(&1I="!B97)I8VAT(&%L<R!K;&%D+@!%96X@9F]U="!B:6H@:&5T
M('9E<GIE;F1E;B!V86X@=7<@8F5R:6-H=#H@)7,`165N(&9O=70@;65T(&AE
M="!B:6IW97)K96X@=F%N(&1E(&%D<F5S9&5T86EL<RX@4')O8F5E<B!L871E
M<B!O<&YI975W+"!A+G4N8BX`165N(&9O=70@;65T(&AE="!B:6IW97)K96X@
M=F%N(&1E(&1I<W1R:6)U=&EE;&EJ<W0N(%!R;V)E97(@;&%T97(@;W!N:65U
M=RP@82YU+F(N`$5E;B!F;W5T(&UE="!H970@8FEJ=V5R:V5N('9A;B!D92!G
M96)E=7)T96YI<SH@)7,N`$5R('-T;VYD(&=E96X@=&5K<W0@:6X@9&ET(&)E
M<FEC:'1O;F1E<F1E96P`1&ET($A434P@8F5R:6-H="!B979A="!A9F)E96QD
M:6YG96XN`$1I="!(5$U,(&)E<FEC:'0@8F5V870@869B965L9&EN9V5N+B!'
M96)L;VMK965R9&4@869B965L9&EN9V5N('9E<G-C:&EJ;F5N(&%L<R!V;VQG
M=#H@`$1E>F4@24U!4"!S97)V97(@;VYD97)S=&5U;G0@9V5E;B!D96QI;F<@
M=F%N(&UA<'!E;BX`1&5Z92!O<&5N8F%R92!01U`@<VQE=71E;"!I<R!G96MO
M<'!E;&0@;65T(&AE="!B97)I8VAT+@!$97IE(&)E=V5R:VEN9R!W;W)D="!N
M:65T(&]N9&5R<W1E=6YD+@!$97IE(&)E=V5R:VEN9R!I<R!N;V<@;FEE="!V
M86X@=&]E<&%S<VEN9RX`1&ET(&QI:FMT(&YI970@965N(&=E;&1I9R!R87(@
M8F5S=&%N9"!T92!Z:6IN+@!$:70@;&EJ:W0@;FEE="!E96X@9V5L9&EG('II
M<"!B97-T86YD('1E('II:FXN`$1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@
M:V%A<G1N=6UM97(@=&4@>FEJ;BX`1&ET('-T=75R<')O9W)A;6UA(&=E969T
M(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD
M96XL(&0N;2YV+B!D92!(5%10($%020!$:70@<W1U=7)P<F]G<F%M;6$@9V5E
M9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD
M96XL(&0N;2YV+B!D92!(5%10($%020!$:70@<W1U=7)P<F]G<F%M;6$@9V5E
M9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@4TU44"!D+FTN
M=BX@9&4@5F]D869O;F4@271A;'D@9V%T97=A>2!T92!V97)Z96YD96X@;F%A
M<B!6;V1A9F]N92!N=6UM97)S+B!(:65R=F]O<B!I<R!E96X@5F]D869O;F4@
M271A;'D@92UM86EL861R97,@*&AT='`Z+R]W=W<N,3DP+FET*2!N;V]D>F%K
M96QI:FLN`$1I="!V96QD(&ES('9E<F5I<W0`1&ET('9E;&0@;6%G(&%L;&5E
M;B!I;G1E9V5R<R!B979A='1E;BX`1&ET('9E;&0@;6%G(&%L;&5E;B!G971A
M;&QE;B!E;B!D92!D=6)B96QE('!U;G0@8F5V871T96XN`$1I="!V96QD(&UA
M9R!A;&QE96X@;V-T86%L('=A87)D96X@8F5V871T96XN`$1I="!V96QD(&1I
M96YT(&5E;B!K;VUM82!O9B!S<&%T:64@9V5S8VAE:61E;B!L:6IS="!M970@
M:6YT96=E<G,@=&4@>FEJ;@!$97IE('=A87)D92!D:65N="!E96X@9V5L9&EG
M(&=E=&%L('1E('II:FXN`$1I="!V96QD(&1I96YT(&5E;B!K;&5U<F-O9&4@
M:6X@4D="($A%6"UF;W)M86%T('1E(&)E=F%T=&5N+"!B+G8N("<C,3(S-&%F
M)RX`1&ET(&9O<FUU;&EE<B!I<R!R965D<R!V97)W97)K="X`1&ET(&ES("5S
M+@!$:70@:7,@965N($MO;&%B($=R;W5P=V%R92!O8FIE8W0N($]M(&1I="!O
M8FIE8W0@=V5E<B!T92!G979E;B!H965F="!U(&5E;B!E+6UA:6P@8VQI96YT
M(&YO9&EG(&1I92!H970@2V]L86(@1W)O=7!W87)E(&9O<FUA870@8F5G<FEJ
M<'0N(%9O;W(@965N(&QI:G-T(&UE="!D97IE(&4M;6%I;&-L:65N=',L(&)E
M>F]E:R`E<RP@82YU+F(N`$1I="!K86X@96YI9V4@=&EJ9"!D=7)E;BX@5V5E
M="!U('IE:V5R(&1A="!U('9E<F1E<B!W:6QT(&=A86X_`$1I="!B97)I8VAT
M(&)E=F%T(&5E;B!-86-I;G1O<VAB97-T86YD+@!$:70@8F5R:6-H="!B979A
M="!E96X@8FEJ;&%G92!D:64@9&EG:71A86P@=FEA(%,O34E-12!I<R!O;F1E
M<G1E:V5N9"X`1&ET(&)E<FEC:'0@8F5V870@965N(&)I:FQA9V4@9&EE('9I
M82!3+TU)344@:7,@9V5C;V1E97)D+@!$:70@8F5R:6-H="!B979A="!A9FQE
M=F5R:6YG<W-T871U<VEN9F]R;6%T:64L(&UA87(@:&5T(&9O<FUA870@=F%N
M(&1I="!B97)I8VAT(&ES(&]N8F5K96YD+@!$:70@8F5R:6-H="!L:6IK="!N
M:65T(&AE="!E96X@9V5L9&EG(%!'4"!G96-O9&5E<F0@8F5R:6-H="!T92!Z
M:6IN+B!&;W5T.B``1&ET(&)E<FEC:'0@;&EJ:W0@;FEE="!H970@:G5I<W1E
M(%!'4"!F;W)M86%T('1E(&AE8F)E;B`H=F]L9V5N<R!21D,@,C`Q-2DN`$1I
M="!B97)I8VAT(&QI:FMT(&YI970@:&5T(&IU:7-T92!3+TU)344@9F]R;6%A
M="!T92!H96)B96XN`$AE="!V;VQG96YD92!B97)I8VAT(&ES(&1I9VET86%L
M(&]N9&5R=&5K96YD('9I82!01U`N`$AE="!V;VQG96YD92!B97)I8VAT(&ES
M(&1I9VET86%L(&]N9&5R=&5K96YD('9I82!3+TU)344N`$1I="!B97)I8VAT
M(&ES(&=E8V]D965R9"!M970@4R]-24U%+@!$:70@8F5R:6-H="!I<R!G96-O
M9&5E<F0@;65T(%!'4"X`1&ET(&)E<FEC:'0@;F%A<@!$:70@8F5R:6-H="!I
M<R!I;B!E96X@86YD97)E(&MA<F%K=&5R<V5T("@E<RD@9V5S8VAR979E;BP@
M9&%N('5W(&5I9V5N+@!$:70@9V5T86P@9&EE;G0@=&5N;6EN<W1E(.GI;B!T
M92!Z:6IN+@!$97IE('-E<G9E<B!K86X@9V5E;B!Z:7`@96X@9WII<"!B97-T
M86YD96X@=6ET<&%K:V5N+@!$97IE('-E<G9E<B!O;F1E<G-T975N="!G965N
M(&1E;&EN9R!V86X@;6%P<&5N+@!(970@<WES=&5E;2!I<R!M;VUE;G1E96P@
M=6ET9V5S8VAA:V5L9"X`1&5Z92!W86%R9&4@9&EE;G0@965N(&=E=&%L('1E
M('II:FXN`$1I="!S8VAE<FT@9&EE;G0@86%N9V5R;V5P96X@=&4@=V]R9&5N
M('9A;G5I="!H970@;FEE=7<@8F5R:6-H="!S8VAE<FTN`$1I="!S8VAE<FT@
M9&EE;G0@86%N9V5R;V5P96X@=&4@=V]R9&5N('9A;G5I="!E96X@3W!T:65S
M<V-H97)M`%1H<F5A9'=E97)G879E`$]N=V5E<@!4:6-K971S`%1I:F0`5&EJ
M9'!L86YN:6YG`%1I:F1F;W)M86%T`%1I:F1S96QE8W1I90!4:6UO<BU,97-T
M90!4:71E;`!4:71E;"`H=&]O;'1I<"DZ`$%A;@!'96%D<F5S<V5E<F1E`$]M
M(&UE97)D97)E('9E;&1E;B!T92!S96QE8W1E<F5N+"!H;W5D(&1E($-O;G1R
M;VP@*%!#*2!O9B!#;VUM86YD("A-86,I('1O971S(&EN9V5D<G5K="!T:6ID
M96YS(&ML:6MK96XN`$]M(&UE97)D97)E(&]N9&5R9&5L96X@=&4@<V5L96-T
M97)E;BP@:&]U9"!D92!#;VYT<F]L("A00RD@;V8@0V]M;6%N9"`H36%C*2!T
M;V5T<R!V87-T('1I:F1E;G,@:VQI:VME;BX`5F%N9&%A9P!(5$U,(&)R;VX@
M;VUS8VAA:V5L96X`5&]G;P!4;VME;&%U`$UO<F=E;@!4;VYG80!";W9E;FMA
M;G0`0F]V96YS=&4@9G)A;64@*%]T;W`I`%1O=&%L92!B:6IL86=E9W)O;W1T
M93H`5F5R=&%L:6YG96X`4')U;&QE;F)A:P!0<G5L;&5N8F%K.@!4<FEN:61A
M9"!E;B!4;V)A9V\`5')U92!O9B!F86QS90!$:0!4=6YE<VGK`%1U<FMI:F4`
M5'5R:W,@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!E;B!#86EC
M;W,@96EL86YD96X`5'5V86QU`%1Y<"!U=R!K975Z93H@`%4N5BX@:6YD97@Z
M(`!54DP`55),('9O;W(@=7<@869L979E<FEN9W-S=&%T=7-R87!P;W)T('-C
M<FEP=`!54DPZ`$]E9V%N9&$`3V5K<F'O;F4`3FEE="!I;B!S=&%A="!61E,@
M9&ER96-T;W)Y(&%A;B!T92!S<')E:V5N+@!.:65T(&EN('-T86%T(&5X=')A
M(&=E8G)U:6ME<G-I;F9O<FUA=&EE('1O92!T92!V;V5G96X@8FEJ(&EN<V-H
M<FEJ=F5N+@!.:65T(&EN('-T86%T(&1E(')E8VAT96X@=F%N(%9&4R!B97-T
M86YD("(E<R(@=&4@=VEJ>FEG96XN`$YI970@:6X@<W1A870@9&4@<F5C:'1E
M;B!V86X@5D93(&)E<W1A;F0@)7,O)7,@=&4@=VEJ>FEG96XN`$YI970@:6X@
M<W1A870@=&4@=VEJ>FEG96X@;F%A<B`E<RX`3FEE="!I;B!S=&%A="!M970@
M9&4@4U%,('-E<G9E<B!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@;65T
M(%-33"!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M=&4@:V]P:>MR96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`B)7,B
M('1E(&UA:V5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@;6%K
M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@
M:6X@<W1A870@965N(&QE96<@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@
M:6X@<W1A870@9&%T82!U:70@=&4@<&%K:V5N+@!.:65T(&EN('-T86%T("(E
M<R(@=&4@=F5R=VEJ9&5R96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE96<`
M3FEE="!I;B!S=&%A="`E<R!T92!V97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y
M(&ES(&YI970@;&5E9P!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@<F5C
M=7)S:65F('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E
M8W1O<GD@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C
M=&]R>2`E<R!T92!V97)W:6ID97)E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S
M=&%N9"`B)7,B('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R!B
M97-T86YD('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R`E<R!R
M96-U<G-I968@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@:'5I9&EG
M92!D:7)E8W1O<GD@=&4@8F5P86QE;BX`3FEE="!I;B!S=&%A="!C97)T:69I
M8V%A=&1E=&%I;',@=6ET('1E(&9I;'1E<F5N`$YI970@:6X@<W1A870@;VT@
M9&4@9&5F:6YI=&EE('9A;B`E<R!T92!L861E;BX`3FEE="!I;B!S=&%A="!6
M1E,@8F5S=&%N9"!T92!V97)P;&%A='-E;BX`3FEE="!I;B!S=&%A="!61E,@
M8F5S=&%N9"`B)7,B('1E(&]P96YE;BX`3FEE="!I;B!S=&%A="!61E,@8F5S
M=&%N9"!T92!O<&5N96X@=F]O<B!S8VAR:6IV96XN`$YI970@:6X@<W1A870@
M5D93(&)E<W1A;F0@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&AE="!I;F=E
M<&%K=&4@8F5S=&%N9"!T92!O<&5N96XN`$YI970@:6X@<W1A870@=F9S<F]O
M="!D:7)E8W1O<GD@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&]M("5S('1E
M(&AE<FYO96UE;B!N86%R("5S.B!B97-T96UM:6YG<VUA<"!B97-T86%T(&%L
M`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!H97)N;V5M96XN`$YI
M970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!H97)N;V5M96XN`$YI
M970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!H97)N;V5M96XN`$YI
M970@:6X@<W1A870@5D93(&)E<W1A;F0@)7,O)7,@=&4@:&5R;F]E;65N+@!.
M:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&AE<FYO96UE;BX`3FEE="!I
M;B!S=&%A="!O;2!Q=6]T82!O<"!T92!H86QE;@!+86X@)VUK:7-O9G,G(&YI
M970@=6ET=F]E<F5N+@!.:65T(&EN('-T86%T(&1I="!7;W)D(&1O8W5M96YT
M('1E('9E<G1A;&5N`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T
M92!S8VAR:6IV96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@<V-H
M<FEJ=F5N("AC;W!Y*"D@9F%I;&5D*2X`3FEE="!I;B!S=&%A="!61E,@8F5S
M=&%N9'-D871A('1E('-C:')I:G9E;BX`3VYB96%N='=O;W)D`$]N8F5A;G1W
M;V]R9&4@8F5R:6-H=&5N`%1E<G5G:&%L96X`3VYD97)S=')E<&5N`$]N8F5K
M96YD92!O;G1V86YG97)S`$AE<G-T96P@=VEJ>FEG:6YG96X`1&]E="!U=R!L
M86%T<W1E(&)E=V5R:VEN9R!T96YI970`3VYV97)W86-H="!A;G1W;V]R9"!V
M86X@9&4@<V5R=F5R(&]P('9E<F)I;F1I;F<Z(`!/;G9E<G=A8VAT(&%N='=O
M;W)D('9A;B!S97)V97(@86%N.B``3VYB96YO96UD`$YI970@=F5R=V5R:W0@
M;VYD97)D965L('9A;B!T>7!E.B`E<P!5;FEC;V1E("A55$8M."D`5F5R96YI
M9V1E($%R86)I<V-H92!%;6ER871E;@!697)E;FEG9"!+;VYI;F=K<FEJ:P!6
M97)E;FEG9&4@4W1A=&5N`%9E<F5N:6=D92!3=&%T96XL(&ML96EN92!B=6ET
M96X@;&EG9V5N9&4@96EL86YD96X`165N:&5D96X`3VYB96ME;F0`3VYB96ME
M;F1E(&1A='5M`$]N8F5K96YD92!V97)G861E<FEN9P!/;F)E:V5N9&4@;VYT
M=F%N9V5R`$]N8F5K96YD(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`$]N
M8F5K96YD(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$]N8F5K96YD
M92!G96)R=6EK97)S;F%A;2!O9B!W86-H='=O;W)D+@!(970@:'5I9&EG92!E
M;&5M96YT(&QO<VMO<'!E;&5N`%=A8VAT=V]O<F1R96=E;"!L;W-S96X`3VYB
M96YO96UD`$YI970@9V5R96-H=&EG9&4@<V-R:7!T<R!K=6YN96X@<')O9W)A
M;6UA;6%T:6<@;FEE="!+;FEP<&5N+TMO<&GK<F5N+U!L86MK96XL('9A;G=E
M9V4@8F5V96EL:6=I;F=S<F5D96YE;BX@2VQI:R!O<"!/2R!O;2!E96X@=&5C
M:&YI<V-H92!O<&UE<FMI;F<@;W`@;6]Z:6QL82YO<F<@=&4@8F5K:6IK96X@
M:&]E('4@965N('-C<FEP="!T;V5S=&%A="!H970@<')I:V)O<F0@=&4@8F5N
M861E<F5N+@!/;F=E>FEE;@!+;&5U<B!T97)U9W-T96QL96X`56ET<V-H<FEJ
M=F5N('9A;B!M87`H<&5N*0!.:65T(&]N9&5R<W1E=6YD92!E>'1E;G1I90!"
M:6IW97)K96X`)7,@8FEJ=V5R:V5N`$)I:FQA9V5I;F9O<FUA=&EE(&)I:G=E
M<FME;@!"96%N='=O;W)D97)S=&%T=7,@8FEJ=V5R:V5N`$=E8G)U:6ME<B!B
M:6IW97)K96XN`%5P9W)A9&4@<V-R:7!T('9E<G=I:F1E<F0N`%5P;&]A9`!!
M;&QE('1O97!A<W-I;F<@<V5T=7!B97-T86YD96X@;F%A<B!D92!S97)V97(@
M9V5U<&QO860N`$QA=&EJ;G-E(&AO;V9D;&5T=&5R<P!'<F]T92!2;VUE:6YS
M92!G971A;&QE;@!5<G5G=6%Y`$=E8G)U:6L@:'5I9&EG93H@)7,`1V5B<G5I
M:R!S=&%N9&%A<F1W86%R9&4`24U!4"!M87!I;G-C:')I:G9I;F=E;B!G96)R
M=6EK96X_`$=E8G)U:6L@4U-,`$=E8G)U:6ME;B!W86YN965R(&YA86TO=V%C
M:'1W;V]R9"!V97)S8VAI;'0@;65T($E-4U`@<V5R=F5R+@!'96)R=6EK97(`
M1V5B<G5I:V5R("5S(&ES(&YI970@9V5A=71O<FES965R9"!V;V]R("5S+@!'
M96)R=6EK97)S8F5H965R`$=E8G)U:6ME<G-O<'1I97,`1V5B<G5I:V5R<W)E
M9VES=')A=&EE`$=E8G)U:6ME<G-R96=I<W1R871I92!I<R!U:71G97-C:&%K
M96QD(&]P(&1E>F4@<VET92X`1V5B<G5I:V5R<VYA86T`1V5B<G5I:V5R<VYA
M86TZ`$=E8G)U:6ME<G-N86%M.B``1V5B<G5I:V5R<R!I;B!H970@<WES=&5E
M;3H`3V5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!B97-T86%T(&YI970N`$%F
M=V5Z:6=H96ED`$=E=F]N9&5N(&=E;&1I9V4@;&]C871I97,@8F5V871T96XZ
M(`!'96QD:6=H96ED`%=A87)D92!I;B!M:6YU=&5N('9A;F%F(&YU+@!786%R
M9&5N`%=A87)D96X@=V%A<G5I="!G97-E;&5C=&5E<F0@:V%N('=O<F1E;@!6
M86YU871U`%9A<FEA8F5L90!696YE>G5E;&$`5F5R:69I8V%T:64@;6ES;'5K
M="`M(&5R(&MA;B!M970@9&ET(&)E<FEC:'0@9V5K;F]E:60@>FEJ;BX`5F5R
M<VEE`%9E<G-I96-O;G1R;VQE`%9E<G1I:V%A;"!U:71L:6IN96X`5F5R=&EK
M86QE('9R:6IE(')U:6UT90!697)T:6MA86PZ`$5R9R!H;V]G`%9I971N86T`
M5FEE=&YA;65E<R`H5DE30TE)*0!"96MI:FME;@`E<R!B96MI:FME;@`E<R!O
M<&5N8F%R92!S;&5U=&5L(&)E:VEJ:V5N`$A434P@:6YH;W5D(&EN(&5E;B!A
M<&%R="!S8VAE<FT@8F5K:6IK96X`4&5R<V]O;FQI:FME('!R:79E('-L975T
M96P@8F5K:6IK96X`4&5R<V]O;FQI:FME(&]P96YB87)E('-L975T96P@8F5K
M:6IK96X`5&AR96%D(&)E:VEJ:V5N`$)E:VEJ:R!T:'5M8FYA:6P`0F5K:6IK
M(&5E;B!E>'1E<FYE('=E8G!A9VEN80!"96MI:FME;B!A;',@)7,`0FEJ;&%G
M92!I;B!E96X@87!A<G0@<V-H97)M(&)E:VEJ:V5N`$)E:VEJ:R!G96)E=7)T
M96YI<P!"96MI:FL@8F5R:6-H=&5N(&EN("5S`%=E97)G879E('9A;B!M86EL
M8F]X(&YA(&%A;FUE;&1I;F<Z`$)E:VEJ:R!T86%K`$)E:VEJ:R!D92!B97)I
M8VAT96X`36%A9V1E;B!E:6QA;F1E;BP@0G)I='-E`$UA86=D96X@96EL86YD
M96XL(%8N4RX`1&4@=FER='5E;&4@;6%P("(E<R(@=V5R9"!M970@<W5C8V5S
M(&%A;F=E;6%A:W0N`%9I<G1U96QE(&UA<'!E;@!.86%M('9O;W(@=FER='5E
M;&4@;6%P`%II8VAT`%II8VAT.B``5F]D869O;F4@271A;'D@=FEA(%--5%``
M5T%23@!704%24T-(55=)3D<A(2$@(%9%4E=)2D1%4B!30U))4%0@2$%.1$U!
M5$E'(%5)5"`E<RX`5V%L;&ES(&5N($9U='5N80!7;P!7965R<W9O;W)U:71Z
M:6-H=`!7965R8F5R:6-H="!G96=E=F5N<R!G96QE=F5R9"!D;V]R`%=E871H
M97(N8V]M`%=E8@!796)S:71E`%=E:V5L:6IK<P!796QK;VT`5V5L:V]M(&)I
M:B`E<P!796QK;VTL("5S`%=E<W1E<G,@*$E33RTX.#4Y+3$I`%=E<W1E<G,@
M*$E33RTX.#4Y+3$U*0!797-T96QI:FME(%-A:&%R80!796QK92!T;V5P87-S
M:6YG(&1I96YT("5S('=E97(@=&4@9V5V96X@;F$@86%N;65L9&EN9S\`5V%T
M(&ES(&AE="!S8VAE:61I;F=S:V%R86MT97(_`%=A="!I<R!H970@8VET86%T
M:V%R86MT97(_`%9E<G!L86%T<R!V97)W:6ID97)D92!B97)I8VAT96X@;F%A
M<B!D92!P<G5L;&5N8F%K+"!I+G`N=BX@9&5Z92!A;',@=F5R=VEJ9&5R9"!T
M92!M87)K97)E;C\`3W`@=V5L:V4@<&%G:6YA+"!B:6H@;W!E;F5N('9A;B!E
M96X@;FEE=7=E(&UA:6QB;W@L('=I;'0@=2!B96=I;FYE;C\`1&EE;G0@8FEJ
M(&]P<VQA86X@=F%N('9E<GIO;F1E;B!M86EL+"!B:6IL86=E9&%T82!O<&=E
M<VQA9V5N('1E('=O<F1E;C\`5V5L:V4@9F%S96X`5V5L:V4@<&QU9VEN<R!V
M;V]R(&1E(%)I8V@@5&5X="!E9&ET;W(@:6YS8VAA:V5L96XN`%=I='1E(&QI
M:G-T`$)R965D=&4`0G)E961T92!I;B!#4U,@965N:&5D96X`0G)E961T92!V
M86X@:&5T("5S(&UE;G4@86%N(&1E(&QI;FME<FMA;G0@*&%K=&EE9B!B:6H@
M=F]L9V5N9&4@86%N;65L9&EN9RDZ`$)R965D=&4@=F%N(&1E('1A8F5L`$)R
M965D=&4@965N:&5I9`!"<F5E9'1E.@!7:6MI`%=I;F0`5VEN9'-N96QH96ED
M(&EN(&MN;W!E;@!7:6YD.@!7:6YD.B``5VEJ<VAE:60`5V5R:P!797)K861R
M97,`5&5L+FYR+B`H=V5R:RD`6"U2968`6#4P.78S(&)A<VES8F5P97)K:6YG
M96X`6#4P.78S('5I=&=E8G)E:60@<VQE=71E;&=E8G)U:6L`6#4P.78S(&%L
M=&5R;F%T:65V92!O;F1E<G=E<G!N86%M`%@U,#EV,R!O;F1E<G=E<G`@<VQE
M=71E;&ED96YT:69I8V%T;W(`6#4P.78S(&5X=&5N=&EE<P!*2@!*2DI*`%EA
M:&]O(2!M87``2F%A<FQI:FMS`$IE;65N`$IA`$IA+"!I:R!A8V-E<'1E97(@
M9&4@=F]O<G=A87)D96X`52!G86%T(&4M;6%I;"!V86X@9&4@=F]L9V5N9&4@
M86-C;W5N="AS*2!O<&AA;&5N.@!5(&MO<&EE97)T+W9E<G!L86%T<W0@;F%A
M<B!E96X@;FEE=7=E(&UA<"X`52!M86%K="!E96X@<W5B;6%P(&EN(`!5(&UA
M86MT(&5E;B!H;V]F9&UA<"X`52!B96YT(&EN(%1%2U-4($U/1$4N($=E8G)U
M:6L@9&4@6SP^72!K;F]P(&]M(&YA87(@5UE325=91R!T97)U9R!T92!S8VAA
M:V5L96XN`%4@8F5N="!N:65T(&=E875T:&5N=&EF:6-E97)D+@!5(&AE<FYO
M96UT(&1E(&UA<#H@`%4@:W5N="!G965N("=<)R!K87)A:W1E<B!I;B!U=R!V
M;VQL96=E(&YA86T@:&5B8F5N+@!5(&)E;G0@;FEE="!A:VMO;W)D(&=E9V%A
M;B!M970@9&4@9V5B<G5I:V5R<V]V97)E96YK;VUS="P@9'5S(&ES(&AE="!U
M(&YI970@=&]E9V5S=&%A;B!O;2!A86X@=&4@;65L9&5N+@!5(&AE969T(&=E
M96X@9V5L9&EG(&4M;6%I;&%D<F5S(&]P9V5G979E;BX`52!H965F="!G965N
M('9E;&1E;B!U:70@:&5T(&=E:6UP;W)T965R9&4@8F5S=&%N9"!G96MO<'!E
M;&0@;65T(&1E(&]V97)E96YK;VUS=&EG92!V96QD96X@:6X@)7,N`%4@:&5E
M9G0@9V5E;B!R96-H=&5N(&]M(&1E('1O96=A;F<@;W`@9&5Z92!M87`@=&4@
M=VEJ>FEG96X`52!H965F="!D:70@8F5R:6-H="!D;V]R9V5S='5U<F0@;W`@
M)25S+"!N86%R(&1E('9O;&=E;F1E(&]N='9A;F=E<G,Z("5S+@!5(&AE969T
M("5S(&YI975W92!B97)I8VAT96XN`%4@:&5E9G0@,2!N:65U=R!B97)I8VAT
M+@!5(&AE969T('1E;FUI;G-T92#IZ6X@8FEJ;&%G92!G97-E;&5C=&5E<F0@
M9&%T('4@;F]G(&YI970@:&5E9G0@9V5U<&QO860N(%=E970@=2!Z96ME<B!D
M870@=2!D:70@8F5R:6-H="!W:6QT('9E<GIE;F1E;B!Z;VYD97(@9&5Z92!B
M:6IL86=E;C\`52!B96YT(&%F9V5M96QD+@!5(&AE969T(&YI975W92!M86EL
M(&EN(&1E('9O;&=E;F1E(&UA<#H`52!H965F="!N:65U=V4@;6%I;"!I;B!D
M92!V;VQG96YD92!M87!P96XZ`%4@9&EE;G0@965N(&=E;&1I9R!M;V)I96P@
M;G5M;65R(&EN('1E('9O97)E;BP@86QL965N(&-I:F9E<G,@;65T(&5E;B!O
M<'1I;VYE;&4@)RLG('9O;W(@:&5T(&EN=&5R;F%T:6]N86QE(&MI97-V;V]R
M=F]E9W-E;"X`52!D:65N="!E96X@9V5L9&EG92!W86%R9&4@;W`@=&4@9V5V
M96XN`%4@9&EE;G0@965N($1A=&%4<F5E(&)A8VME;F0@=&4@8V]N9FEG=7)E
M<F5N(&]M(&EN<V-H<FEJ=FEN9V5N('1E(&MU;FYE;B!G96)R=6EK96XN`%4@
M9&EE;G0@:&5T('!R;V)L965M('1E(&)E<V-H<FEJ=F5N+"!V;V]R9&%T('4@
M:&5T('!R;V)L965M<F%P<&]R="!K=6YT('9E<GIE;F1E;BX`52!D:65N="!T
M96YM:6YS=&4@Z>EN(&]N='9A;F=E<B!O<"!T92!G979E;BX`52!D:65N="!E
M96X@55),(&EN('1E('9O97)E;B!W86%R;F%A<B!D97IE(&QI;FL@=F5R=VEJ
M<W0`52!D:65N="!D92!W86-H='=O;W)D<F5G96P@=F%N('5W('!R:79E(%!'
M4"!S;&5U=&5L(&EN('1E('9O97)E;BP@;VT@9&ET(&)E<FEC:'0@=&4@:W5N
M;F5N(&)E:VEJ:V5N`%4@9&EE;G0@9&4@=V%C:'1W;V]R9')E9V5L('9A;B!U
M=R!P<FEV92!3+TU)344@<VQE=71E;"!I;B!T92!V;V5R96XL(&]M(&1I="!B
M97)I8VAT('1E(&MU;FYE;B!B96MI:FME;@!5(&1I96YT(&5E<G-T(&5E;B!D
M;V5L;6%I;&)O>"!O<"!T92!G979E;BX`52!D:65N="!E96X@86-C;W5N="!T
M92!S96QE8W1E<F5N('=E;&ME('4@=VEL="!V97)W:6ID97)E;BX`52!D:65N
M="!E97)S="!E96X@861R97,@=&4@<V5L96-T97)E;BX`52!D:65N="!E96X@
M<V5R=F5R('1E('-E;&5C=&5R96X@;VT@=&4@=F5R=VEJ9&5R96XN`%4@9&EE
M;G0@965R<W0@=&5N;6EN<W1E(.GI;B!B97)I8VAT('1E('-E;&5C=&5R96XN
M`%4@9&EE;G0@965N(&]N='9A;F=E<B!O<"!T92!G979E;BX`52!D:65N="!E
M96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@=&4@=VES<V5N+@!5
M(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!T92!V
M97)W:6ID97)E;BX`4W!E8VEF:6-E97(@=&5N;6EN<W1E(.GI;B!B97-T86YD
M(&]M('1E(&MO<'!E;&5N+"!A+G4N8BX`52!D:65N="!E96X@9V5B<G5I:V5R
M<VYA86T@;W`@=&4@9V5V96X@;VT@=&]E('1E('9O96=E;BX`52!D:65N="!E
M96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@8FEJ('1E(&MU;FYE
M;B!W97)K96XN`%4@9&EE;G0@965N(&)E=V5R:VEN9R!O<"!T92!G979E;B!W
M96QK92!U:71G979O97)D(&UO970@=V]R9&5N+@!5(&1I96YT(&5E;B!N:65U
M=V4@8V%T96=O<FEE;F%A;2!O<"!T92!G979E;BX`52!H965F="!D:70@8F5R
M:6-H="!D;V]R9V5S='5U<F0@;F%A<B`E<R!O<"`E)7,N`%4@:&5E9G0@9&ET
M(&)E<FEC:'0@8F5A;G1W;V]R9"!O<"`E<RX`52!H965F="`B)7,B(&YI970@
M:6YG97-C:')E=F5N+B!$92!S97)V97(@;65L9'0`52!H965F="`B)7,B(&YI
M970@=6ET9V5S8VAR979E;BX@1&4@<V5R=F5R(&UE;&1T`%4@:&5E9G0@(B5S
M(B!M970@<W5C8V5S(&EN9V5S8VAR979E;@!5(&AE969T("(E<R(@;65T('-U
M8V-E<R!U:71G97-C:')E=F5N`%5W("5S('-E<W-I92!I<R!V97)L;W!E;BX@
M3W!N:65U=R!A86YM96QD96XL(&$N=2YB+@!5=R!E+6UA:6QA9')E<P!5=R!6
M86XZ(&%D<F5S.@!5=R!I;F9O<FUA=&EE`%5W(&EN=&5R;F5T861R97,@:7,@
M9V5W:6IZ:6=D('-I;F1S(&AE="!B96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/
M;2!U=R!V96EL:6=H96ED('1E(&)E<V-H97)M96XL(&1I96YT('4@>FEC:"!O
M<&YI975W(&%A;B!T92!M96QD96XN`%5W(&YA86TZ`%5W(&]P96YB87)E+W!R
M:79E(%!'4"!S;&5U=&5L<P!5=R!P<FEV92!S;&5U=&5L`%5W(&]P96YB87)E
M('-L975T96P`57<@;W!E;F)A<F4O<')I=F4@4R]-24U%(&-E<G1I9FEC871E
M;@!5=R!A8V-O=6YT<SH`2&5T('=E97)G979E;B!V86X@965N(&=E8G)U:6ME
M<G-L:6IS="!W;W)D="!N:65T(&]N9&5R<W1E=6YD(&1O;W(@=7<@875T:&5N
M=&EC871I92!B86-K96YD+"!O9B!D97IE(&]P=&EE(&ES(&]M(&%N9&5R92!R
M961E;F5N('5I=&=E<V-H86ME;&0N`%5W(&)R;W=S97(@;&EJ:W0@=&4@>FEJ
M;B!G97=I:GII9V0@<VEN9',@:&5T(&)E9VEN('9A;B!U=R`E<R!S97-S:64N
M($]M('5W('9E:6QI9VAE:60@=&4@8F5S8VAE<FUE;BP@9&EE;G0@=2!Z:6-H
M(&]P;FEE=7<@86%N('1E(&UE;&1E;BX`57<@8G)O=W-E<B!O;F1E<G-T975N
M="!G965N(&EN;&EN92!W965R9V%V92!V86X@9&ET(&%F8F5E;&1I;F=S='EP
M92X`57<@8G)O=W-E<B!O;F1E<G-T975N="!D97IE(&UO9V5L:6IK:&5I9"!N
M:65T+@!5=R!H=6ED:6=E('1I:F1Z;VYE.@!5=R!S=&%N9&%A<F0@:V%R86MT
M97)S970@=F]O<B!H970@=F5R>F5N9&5N('9A;B!B97)I8VAT96XZ`%5W('-T
M86YD86%R9"!V97)S;&5U=&5L:6YG<VUE=&AO9&4@=F]O<B!H970@=F5R>F5N
M9&5N('9A;B!B97)I8VAT96XZ`%5W('-T86YD86%R9"!I9&5N=&ET96ET.@!5
M=R!V;VQL961I9V4@;F%A;3H`57<@8F5R:6-H="!W97)D(&UE="!S=6-C97,@
M869G96QE=F5R9"X`57<@;FEE=7=E('=A8VAT=V]O<F0@=F]O<B`E<R!I<SH@
M)7,`57<@;W!T:65S('II:FX@8FEJ9V5W97)K="X`57<@=V%C:'1W;V]R9"!I
M<R!G97)E<V5T`%5W('=A8VAT=V]O<F0@:7,@=F5R;FEE=7=D+"!C;VYT<F]L
M965R('5W(&4M;6%I;"!E;B!M96QD(&%A;B!M970@=7<@;FEE=7=E('=A8VAT
M=V]O<F0N`%5W('-E<G9E<G,@;W`@869S=&%N9#H`57<@;VYD97)T96ME;FEN
M9SH`2F]E9V]S;&%V:>L`6F'O<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M6
M97)B97)G(&%A;F=E:&%A;&1E('1E:W-T70!;1V5E;B!O;F1E<G=E<G!=`%M0
M<F]B;&5E;7)A<'!O<G1=`%M!86YG96AA86QD92!T96MS="!W965R9V5V96X@
M+0!;06%N9V5H86%L9&4@=&5K<W0@+2`E<R!R96=E;'-=`%MR96=E;"`E<R!V
M86X@)7-=`$)?96AE97(`7T)C8P!:7W=A<G1E(&QI:G-T`%]#3$D`7T-C`%]$
M871A5')E90!697)?=VEJ9&5R96X`5F5R7W=I:F1E<B!R:6H`7TUA<'!E;@!?
M1W)O97!E;@!?2&5L<`!?261E;G1I=&5I=`!?069B965L9&EN9W-E:6=E;G-C
M:&%P<&5N+BXN`%]);F)O>`!?06%N;65L9&5N`%]!9FUE;&1E;@!?0F5R:6-H
M='-O=7)C90!?5VEJ>FEG(&QI;FLN+BX`7T]P=&EE<P!?4F5C:'1E;@!!7V9D
M<G5K:V5N`%]0<FEO<FET96ET`%]697)V97)S("5S`%]697)W:6ID97(@;&EN
M:RXN+@!?0F5A;G1W;V]R9&5N`%]:;V5K96X`7U9E<GIE;F0@8F5R:6-H=`!?
M26YS=&5L;&5N`%]486)E;&5I9V5N<V-H87!P96XN+BX`7U1H<F5A9`!?06%N
M`%]497)U9VAA;&5N`$=E7V)R=6EK97)S`%]4:')E860@8F5K:6IK96X`5VET
M=&4@;&E?:G-T`$%D<F5S8F]E:P!B:6IL86=E`&)I:FQA9V5N+GII<`!B>71E
M<P!+86QE;F1E<@!+86QM`$ML:6L@:&EE<@!D86QE;F0`8F5S=&%N9`!V86X`
M=F%N(&1E("5S("@E<RD@;W`@)7,@)7,`:#H`;VYM:61D96QI:FL`:6YL:6YE
M`'-L975T96P`<F5G96QS70!-86EL8F]X8F5S=&%N9`!M:VES;V9S(&9O=71C
M;V1E("5D(&)I:B!H970@86%N;6%K96X@=F%N($E33RX`;F%A;0!G965N`&YI
M970@=F%N('1O97!A<W-I;F<`3F]G(&YI970@=F%N('1O97!A<W-I;F<`;F]T
M:71I96)O96L`;V8`<')O8V5N=`!P:7AE;',`<W1I:F=E;F0`=&]O;B!V97)S
M8VAI;&QE;@!S;7,R96UA:6P@=FEA($A45%``<W!E;&9O=70`<W!E;&9O=71E
M;@!S=&%B:65L`'1A:V5N;&EJ<W0`5F]E<BP@=&5R(&)E=F5S=&EG:6YG+"!H
M970@=V%C:'1W;V]R9"!T=V5E(&UA86P@:6X`=6YI9FEE9`!O;F)E;F]E;60`
M1V5B<G5I:V5R<V5L96-T:64`=D-A<F0`=SH`=V5A=&AE<BYC;VT`=7<@>G=A
M<G1E(&QI:G-T`'5W('=I='1E(&QI:G-T````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O;FQ?3DPO:&5L
M<"YX;6P`````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S`Q-S``
M,3`T,3<S-C(W-C,`,#(Q,3(T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(
M;W)D93H@:6UP+VQO8V%L92]N;%].3"]H96QP+GAM;"QV(#$N,3<N-BXT(#(P
M,#8O,#$O,S`@,34Z-3<Z-3@@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](F-O;7!O<V4M8G5T=&]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@
M/'1I=&QE/DYI975W(&)E<FEC:'0Z($)E=V5R:VEN9V5N/"]T:71L93X*("`@
M(#QH96%D:6YG/D)E=V5R:VEN9V5N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("`B5F5R>F5N9"!B97)I8VAT(B!S='5U<G0@=7<@96UA:6P@;F%A<B!D92!O
M<&=E9V5V96X@9V5A9')E<W-E97)D92AN*2X@5F5R9V5W:7,@=2!E<G9A;B!D
M870@=2!H970@8F5R:6-H="!W:6QT('9E<GIE;F1E;B!V;V]R9&%T('4@:&EE
M<B!O<"!K;&EK="X@165N(&5E;FUA86P@=F5R>F]N9&5N(&)E<FEC:'0@:V%N
M(&YI970@=&5R=6<@9V5H86%L9"!W;W)D96XN"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@(")/<'-L86%N(&%L<R!K;&%D(B!P;&%A='-T(&5E;B!N;V<@
M;FEE="!A9F=E;6%A:W0@8F5R:6-H="!I;B!E96X@;6%P(&UE="!D92!N86%M
M(")+;&%D(BX@1&5Z92!M87`@:7,@=&]E9V%N:V5L:6IK('9A;G5I="!H970@
M<&]P+61O=VX@;65N=2P@<F5C:'1S8F]V96X@:6X@9&4@;F%V:6=A=&EE8F%L
M:RP@;V8@=FEA(&AE="!M96YU(")-87!P96XB+B!5(&MU;G0@:&5T(&)E<FEC
M:'0@;W`@965N(&QA=&5R('1I:F1S=&EP(&%F;6%K96X@9&]O<B!I;B!D92!K
M;&%D;6%P(&AE="!B971R969F96YD92!B97)I8VAT('1E(&]P96YE;BX@5F5R
M>F5K97(@=2!E<G9A;B!D870@:&5T(&)E<FEC:'0@965N(&]N9&5R=V5R<"!H
M965F="P@=F]O<F1A="!U(&AE="!A;',@:VQA9"!O<'-L86%T+B!/<"!D97IE
M(&UA;FEE<B!I<R!H970@;&%T97(@;6%K:V5L:6IK97(@=&5R=6<@=&4@=FEN
M9&5N(&EN(&1E(&ML861M87`N($YA(&AE="!O<'-L86%N(&%L<R!K;&%D(&MO
M;70@=2!T97)U9R!I;B!U=R!)3D)/6"!O9B!E96X@86YD97)E(&UA<"P@9&EE
M('4@86QS(&QA871S=&4@9V5O<&5N9"!H860N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@("`B0F5R:6-H="!A9F)R96ME;B(@=VES="!H970@8F5R:6-H
M="!W86%R;65E('4@8F5Z:6<@8F5N="P@=V%A<FYA('4@=&5R=6<@:V]M="!I
M;B!D92!)3D)/6"P@;V8@965N(&%N9&5R92!M87`@9&EE('4@86QS(&QA871S
M=&4@9V5O<&5N9"!H860N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R
M>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6)U='1O;G,B/@H@("`@/'1I=&QE/DUE
M<W-A9V4@0V]M<&]S:71I;VXZ($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I
M;F<^06-T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5N9"!-97-S
M86=E(&QA=6YC:&5S('EO=7(@96UA:6P@=&\@=&AE(&EN=&5N9&5D(')E8VEP
M:65N="AS*2X@0F4@<W5R92!Y;W4@=V%N="!T;R!S96YD(&)E9F]R92!C;&EC
M:VEN9R!H97)E(&%S(&]N8V4@<V5N="!I="!C86YN;W0@8F4@=&%K96X@8F%C
M:RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V%V92!$<F%F="!P;&%C
M97,@86X@=6YF:6YI<VAE9"!M97-S86=E(&EN(&$@9F]L9&5R(&-A;&QE9"`G
M1')A9G1S)PIA8V-E<W-I8FQE(&)Y('1H92!P;W`M9&]W;B!B;W@@;VX@=&AE
M(')I9VAT('-I9&4@;V8@=&AE(&)L=64@;F%V:6=A=&EO;B!B87(@870@=&]P
M+B!9;W4@8V%N('1H96X@9FEN:7-H('1H92!M97-S86=E(&QA=&5R(&)Y('-W
M:71C:&EN9R!T;R!T:&4@)T1R869T<R<@9F]L9&5R+"!C;&EC:VEN9R!O;B!T
M:&4@<V%V960@;65S<V%G92!T;R!O<&5N(&ET+"!A;F0@=&AE;B!C;&EC:VEN
M9R!O;B`G4F5S=6UE)RX@0F4@<W5R92!T;R!P=70@82!S=6)J96-T(&]N('1H
M92!E;6%I;"!B969O<F4@>6]U('-A=F4@=&AE(&1R869T('-O('1H870@>6]U
M(&-A;B!E87-I;'D@:61E;G1I9GD@=VAI8V@@;65S<V%G92!Y;W4@=V%N="!W
M:71H:6X@=&AE($1R869T<R!F;VQD97(N($%F=&5R('-A=FEN9R!A<R!A($1R
M869T+"!Y;W4@87)E(')E='5R;F5D('1O('EO=7(@24Y"3U@@;W(@=VAA=&5V
M97(@9F]L9&5R('EO=2!W97)E('9I97=I;F<@;&%S="X*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@0V%N8V5L($UE<W-A9V4@9')O<',@=&AE(&UE<W-A
M9V4@:6X@<')O9W)E<W,@86YD('-I;7!L>2!R971U<FYS('EO=2!T;R!T:&4@
M24Y"3U@@;W(@=VAA=&5V97(@9F]L9&5R('EO=2!W97)E('9I97=I;F<@;&%S
M="X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UF<F]M(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M3FEE=7<@8F5R:6-H=#H@5F%N/"]T:71L93X*("`@(#QH96%D:6YG/B)686XB
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6;V5R(&AI97(@=7<@96UA:6QA
M9')E<R!I;B!O9B!K:65S(&5E;B!I9&5N=&ET96ET+B!5=R!E;6%I;&%D<F5S
M('=O<F1T(&%U=&]M871I<V-H('9O;W(@=2!I;F=E=F]E<F0@86-H=&5R(")&
M<F]M.B(@:6X@9&4@=6ET9V%A;F1E(&5M86EL+@H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UF<F]M(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!&<F]M/"]T:71L93X*("`@
M(#QH96%D:6YG/B9Q=6]T.T9R;VTF<75O=#L\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($5N=&5R('EO=7(@8V]R<F5C="!E;6%I;"!A9&1R97-S+B!9;W5R
M(&5M86EL(&%D9')E<W,@:7,@875T;VUA=&EC86QL>2!E;G1E<F5D(&9O<B!Y
M;W4@9F]L;&]W:6YG("9Q=6]T.T9R;VTZ)G%U;W0[(&EN(&]U=&=O:6YG(&5M
M86EL+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)C;VUP;W-E+71O(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M3FEE=7<@8F5R:6-H=#H@06%N/"]T:71L93X*("`@(#QH96%D:6YG/B)!86XB
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6;V5R(&AI97(@:&5T(&5M86EL
M861R97,@=F%N(&1E(&=E861R97-S965R9&4H;BD@:6XN(%4@:W5N="!M965R
M9&5R92!E;6%I;&%D<F5S<V5N(&EN=F]E<F5N(&1O;W(@965N(&MO;6UA(&%L
M<R!S8VAE:61I;F=S=&5K96X@=&4@9V5B<G5I:V5N('1U<W-E;B!D92!V97)S
M8VAI;&QE;F1E(&5M86EL861R97-S96XN($5L:V4@86YD97)E(&EN=&5R<'5N
M8W1I92!R97-U;'1E97)T(&EN(&5E;B!F;W5T+B!5=R!I;G9O97(@=V]R9'0@
M86-H=&5R(")4;SHB(&EN(&1E('5I=&=A86YD92!E;6%I;"!G97!L86%T<W0N
M"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C
M;VUP;W-E+71O(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!4
M;SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M4;R9Q=6]T.SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D
M<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!Y;W5R(&UE<W-A9V4N(%EO
M=2!M=7-T('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T
M:&5R('!U;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R
M(&5N=')Y(&9O;&QO=W,@)G%U;W0[5&\Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA
M:6PN("`*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UC8R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/DYI975W(&)E<FEC:'0Z($-C/"]T:71L93X*("`@(#QH96%D:6YG/B)#8R(\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($AI97(@:W5N="!U(&1E(&5M86EL
M861R97-S96X@:6YV;V5R96X@=F%N(&1E9V5N96X@9&EE(&5E;B`B8V%R8F]N
M(&-O<'DB('9A;B!U=R!B97)I8VAT(&]N='9A;F=E;BX@1V5B<G5I:R!E96X@
M:V]M;6$@;VT@;65E<F1E<F4@96UA:6QA9')E<W-E;B!V86X@96QK86%R('1E
M('-C:&5I9&5N+B!%;&ME(&%N9&5R92!I;G1E<G!U;F-T:64@<F5S=6QT965R
M="!I;B!E96X@9F]U="X@57<@:6YV;V5R('=O<F1T(&%C:'1E<B`B0V,Z(B!I
M;B!D92!U:71G86%N9&4@;6%I;"!G97!L86%T<W0N(")#87)B;VX@8V]P:65S
M(B!W;W)D96X@;65E<W1A;"!G97-T=75R9"!N86%R('!E<G-O;F5N(&%N9&5R
M<R!D86X@9&4@9&ER96-T(&=E861R97-S965R9&4H;BDL(&UA87(@=V5L:V4@
M;V]K(&)E;&%N9W)I:FME(&=E861R97-S965R9&5N('II:FXN($UE97-T86P@
M8F5T<F5F="!H970@:&EE<B!P97)S;VYE;B!D:64@:6YD:7)E8W0@;65T(&AE
M="!O;F1E<G=E<G`@=F%N(&AE="!B97)I8VAT('1E(&UA:V5N(&AE8F)E;BX@
M06QL92`B06%N.B(@9V5A9')E<W-E97)D96X@96X@(D-C.B(@9V5A9')E<W-E
M97)D96X@:W5N;F5N(&1E(&-O;7!L971E(&QI:G-T('9A;B!B96ED92!T>7!E
M;B!G96%D<F5S<V5E<F1E;B!Z:65N+@H@("`@/"]P87)A/@H\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UC8R(^"B`@("`\=&ET;&4^
M365S<V%G92!#;VUP;W-I=&EO;CH@0V,\+W1I=&QE/@H@("`@/&AE861I;F<^
M)G%U;W0[0V,F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R
M('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E('1O(')E
M8V5I=F4@82!C87)B;VX@8V]P>2!O9B!Y;W5R(&UE<W-A9V4N(%-E<&%R871E
M(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$N(%EO=7(@96YT<GD@9F]L;&]W
M<R`F<75O=#M#8SHF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@0V%R8F]N(&-O
M<&EE<R!A<F4@=7-U86QL>2!S96YT('1O('!E;W!L92!O=&AE<B!T:&%N('1H
M92!O;F4H<RD@8F5I;F<@=W)I='1E;B!T;R!D:7)E8W1L>2!B=70@87)E(&EM
M<&]R=&%N="!R96-I<&EE;G1S(&]F('1H92!E;6%I;"!A<R!W96QL+"!U<W5A
M;&QY('-O;65O;F4@:6YD:7)E8W1L>2!C;VYC97)N960@86)O=70@=&AE('-U
M8FIE8W0@;V8@=&AE(&5M86EL+B`@06QL("=4;SHG(')E8VEP:65N=',@86YD
M("=#8SHG(')E8VEP:65N=',@8V%N('-E92!T:&4@96YT:7)E(&QI<W0@;V8@
M8F]T:"!K:6YD<R!O9B!R96-I<&EE;G1S+@H@("`@/"]P87)A/@H\+V5N=')Y
M/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6)C8R(@<W1A=&4]
M(G5N:VYO=VXB/@H@("`@/'1I=&QE/DYI975W(&)E<FEC:'0Z($)C8SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SXB0F-C(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@2&EE<B!K=6YT('4@9&4@96UA:6QA9')E<W-E;B!I;G9O97)E;B!V86X@
M9&5G96YE;B!D92!E96X@(F)L:6YD(&-A<F)O;B!C;W!Y(B!V86X@:&5T(&)E
M<FEC:'0@;VYT=F%N9V5N+B!'96)R=6EK(&5E;B!K;VUM82!O;2!M965R9&5R
M92!E;6%I;&%D<F5S<V5N('9A;B!E;&MA87(@=&4@<V-H96ED96XN($5L:V4@
M86YD97)E(&EN=&5R<'5N8W1I92!R97-U;'1E97)T(&EN(&5E;B!F;W5T+B!5
M=R!I;G9O97(@=V]R9'0@86-H=&5R(")"8V,Z(B!I;B!D92!U:71G86%N9&4@
M96UA:6P@9V5P86%T<W0N(")";&EN9"!C87)B;VX@8V]P:65S(B!W;W)D96X@
M;65E<W1A;"!G97-T=75R9"!N86%R('!E<G-O;F5N(&%N9&5R<R!D86X@9&4@
M9&ER96-T(&5N(&EN9&ER96-T(&=E861R97-S965R9&5N("@B06%N.B(@96X@
M(D-C.B(@9V5A9')E<W-E97)D96XI(&1I92!O;VL@:&5T(&)E<FEC:'0@9&EE
M;F5N('1E(&MU;FYE;B!L97IE;BP@>F]N9&5R(&1A="!D92!A;F1E<F4@9V5A
M9')E<W-E97)D96X@=V5T96X@9&%T(&1E>F4@<&5R<V]N96X@9&4@96UA:6P@
M;VYT=F%N9V5N+B`B0FQI;F0B(&)E=&5K96YT(&1U<R!I;B!D:70@9V5V86P@
M9&%T(&1E(&ED96YT:71E:70@=F%N(&1E>F4@9V5A9')E<W-E97)D96X@=F5R
M8F]R9V5N(&ES('9O;W(@9&4@86YD97)E(&=E861R97-S965R9&5N('9A;B!D
M92!E;6%I;"!E;B!A;&QE96X@=2!E;B!D97IE(&=E861R97-S965R9&5N('=E
M=&5N(&1A="!Z:6H@965N(&MO<&EE('9A;B!H970@8F5R:6-H="!O;G1V86YG
M96X@:&5B8F5N+B!$:70@=F5L9"!W;W)D="!M965S=&%L(&=E8G)U:6MT(&]M
M(&5E;B!L96ED:6YG9V5V96YD92!V86X@:65T<R!O<"!D92!H;V]G=&4@=&4@
M8G)E;F=E;BP@>F]N9&5R(&1A87)B:6H@9&4@86YD97)E(&=E861R97-S965R
M9&5N('1E(&%L87)M97)E;BX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N
M=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8F-C(CX*("`@(#QT:71L93Y-97-S
M86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U
M;W0[0F-C)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T
M:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E
M:79E(&$@8FQI;F0@8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E+B!9;W4@
M;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE
M<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E
M;G1R>2!F;VQL;W=S("9Q=6]T.T)C8SHF<75O=#L@:6X@;W5T9V]I;F<@;6%I
M;"X@0FQI;F0@8V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S96YT('1O('!E
M;W!L92!O=&AE<B!T:&%N(&1I<F5C="!A;F0@:6YD:7)E8W0@<F5C:7!I96YT
M<R`H)G%U;W0[5&\Z)G%U;W0[(&%N9"`F<75O=#M#8SHF<75O=#L@<F5C:7!I
M96YT<RD@=VAO(&YE960@=&\@<F5A9"!W:&%T(&ES(&)E:6YG('=R:71T96X@
M87,@=V5L;"!7251(3U54('1H92!O=&AE<B!R96-I<&EE;G1S(&MN;W=I;F<@
M=&AA="!T:&5Y(&%R92!R96-E:79I;F<@=&AE(&5M86EL+B!4:'5S("=B;&EN
M9"<@;65A;G,@=&AA="!T:&4@:61E;G1I='D@;V8@=&AE<V4@<F5C:7!I96YT
M<R!I<R!H:61D96X@9G)O;2!A;&P@;W1H97(@<F5C:7!I96YT<R!O9B!T:&4@
M96UA:6PL(&%N9"!O;FQY('EO=2!A;F0@=&AE>2!K;F]W('1H97D@9V]T(&$@
M8V]P>2X@66]U('1Y<&EC86QL>2!U<V4@=&AI<R!T;R!T96QL(&%N(&%U=&AO
M<FET>2!F:6=U<F4@=&AA="!Y;W4@87)E('1E;&QI;F<@<V]M96]N92!S;VUE
M=&AI;F<@=VET:&]U="!A;&%R;6EN9R!T:&4@<&5R<V]N('EO=2!A<F4@<V5N
M9&EN9R!T:&4@86-T=6%L(&5M86EL('1O+@H@("`@/"]P87)A/@H\+V5N=')Y
M/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7-U8FIE8W0B('-T
M871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y.:65U=R!B97)I8VAT.B!/;F1E
M<G=E<G`\+W1I=&QE/@H@("`@/&AE861I;F<^(D]N9&5R=V5R<"(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($AI97(@:W5N="!U(&AE="!O;F1E<G=E<G`@
M=F%N(&AE="!B97)I8VAT(&EN=F]E<F5N+B!5=R!I;G9O97(@=V]R9'0@86-H
M=&5R(")3=6)J96-T.B(@:6X@9&4@=6ET9V%A;F1E(&5M86EL(&=E<&QA871S
M="X@2&]U9"!H970@:V]R="P@965N=F]U9&EG(&5N(&1U:61E;&EJ:RX@1&4@
M;VYD97)W97)P<F5G96P@:7,@9&4@;6%K:V5L:6IK<W1E(&UA;FEE<B!V;V]R
M('4@96X@=7<@8V]R<F5S<&]N9&5N=&5N(&]M('1E('II96X@=V%A<B!H970@
M8F5R:6-H="!O=F5R(&=A870@96X@:7,@9'5S(&5R9R!B96QA;F=R:6IK('9O
M;W(@:&5T(&QA=&5R('1E<G5G('9I;F1E;B!E;B!A<F-H:79E<F5N('9A;B!H
M970@8F5R:6-H="X@5&5V96YS('=O<F1T(&)I:B!H970@8F5A;G1W;V]R9&5N
M(&]F(&1O;W)S='5R96X@=F%N(&5E;B!B97)I8VAT(&1E(&]N9&5R=V5R<')E
M9V5L(&=E:V]P:65E<F0@;F%A<B!H970@;FEE=7=E(&)E<FEC:'0@96X@:7,@
M;W`@9&5Z92!M86YI97(@9'5S(&5E;B!W86%R9&5V;VQL92!M86YI97(@;VT@
M86%N('1E(&=E=F5N('=E;&ME(&)E<FEC:'1E;B!B:6H@96QK86%R(&AO<F5N
M(&5N(&1A87)B:6H@965N('HN9RYN+B`B=&AR96%D(B!C;VYV97)S871I92!V
M;W)M96XN(%=A;FYE97(@96-H=&5R(&AE="!B96%N='=O;W)D92!O9B!D;V]R
M9V5S='5U<F1E(&)E<FEC:'0@;FEE=7=E(&ED965E;B!B979A="P@:W5N="!U
M(&5E;G9O=61I9R!K;&5I;F4@=VEJ>FEG:6YG96X@:6X@9&4@;VYD97)W97)P
M<F5G96P@86%N8G)E;F=E;B!Z;V1A="!D92!G96%D<F5S<V5E<F1E*&XI(&1E
M('!R;V=R97-S:64@=F%N(&1E(")T:')E860B(&MA;B!V;VQG96XN"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E
M+7-U8FIE8W0B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%-U
M8FIE8W0\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[4W5B:F5C="9Q=6]T
M.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE('-U8FIE8W0@
M;V8@>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[4W5B
M:F5C=#HF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@2V5E<"!I="!S:&]R="P@
M<VEM<&QE(&%N9"!D97-C<FEP=&EV92X@(%1H92!S=6)J96-T(&QI;F4@:7,@
M=&AE(&5A<VEE<W0@=V%Y(&9O<B!Y;W4@86YD('EO=7(@8V]R<F5S<&]N9&5N
M=',@=&\@<F5M96UB97(@=VAA="!W87,@:6X@=&AE(&5M86EL(&%N9"!T:'5S
M(&ES('9E<GD@:6UP;W)T86YT(&EN(&]R9V%N:7II;F<@>6]U<B!E;6%I;"!A
M;F0@9FEN9&EN9R!I;7!O<G1A;G0@;VYE<R!L871E<BX@($%L<V\L('=H96X@
M>6]U("=297!L>2<@;W(@)T9O<G=A<F0G(&%N9"!E;6%I;"!T:&ES('-U8FIE
M8W0@;&EN92!I<R!C;W!I960@;W9E<B!I;G1O('1H92!N97<@;65S<V%G92!A
M;F0@<V\@:7,@82!V86QU86)L92!W87D@;V8@=&5L;&EN9R!W:&%T(&UE<W-A
M9V5S(&=O('1O9V5T:&5R('1O(&9O<FT@82`F<75O=#MT:')E860F<75O=#L@
M;V8@82!C;VYV97)S871I;VXN("!(;W=E=F5R+"!I9B!T:&4@)U)E<&QY)R!O
M<B`G1F]R=V%R9"<@8V]N=&%I;G,@;F5W(&ED96%S+"!Y;W4@;6%Y('=A;G0@
M=&\@861D('-I;7!L92!M;V1I9FEC871I;VYS('1O('1H92`G4W5B:F5C="<@
M;&EN92!S;R!T:&4@<F5C:7!I96YT*',I(&-A;B!F;VQL;W<@=&AE('!R;V=R
M97-S:6]N(&]F('1H92`F<75O=#MT:')E860N)G%U;W0["B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;W!T
M:6]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DYI975W(&)E<FEC
M:'0Z($]P=&EE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB3W!T:65S(CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@1&5Z92!O<'1I97,@:&5L<&5N('4@8FEJ
M(&AE="!S86UE;G-T96QL96X@=F%N('5W(&)E<FEC:'0N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@($ML:6L@;W`@(E-P96QL:6YG<V-O;G1R;VQE(B!O
M;2!D92!S<&5L;&EN9R!T92!C;VYT<F]L97)E;BX*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@2VQI:R!O<"`B071T86-H;65N=',B(&]M(&]N9&5R86%N
M(&1E('!A9VEN82!E96X@;&EJ<W0@;65T+"!A86X@:&5T(&)E<FEC:'0L(&=E
M:V]P<&5L9&4@8F5S=&%N9&5N('1E(&)E:VEJ:V5N+B`*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@5FEN:R!H970@<V5L96-T:65V86MJ92P@;F%A<W0@
M(D)E=V%A<B!E96X@:V]P:64@:6X@(D]55$)/6"(B+"!A86X@;VT@965N(&MO
M<&EE('9A;B!H970@8F5R:6-H="!O<"!T92!S;&%A;B!I;B!D92!/551"3U@N
M($)E=V%A<B!K;W!I965N('9A;B!B96QA;F=R:6IK92!E;6%I;',L('IO9&%T
M('4@;&%T97(@:65T<R!H965F="!O;2!N86%R('1E(')E9F5R97)E;B!E;B!O
M;2!E>&%C="!B:6H@=&4@:&]U9&5N('=A="!E<B!I<R!G97IE9V0N(%=I:B!R
M861E;B!U(&YI970@86%N(&]M(&5L:V4@96UA:6P@;W`@=&4@<VQA86XL(&]M
M9&%T(&1E(&QI;6EE="!V86X@=7<@<75O=&$@9&%N('-N96QL97(@8F5R96EK
M="!Z86P@>FEJ;B`H>F5K97(@=V%N;F5E<B!O;VL@;F]G(&%T=&%C:&UE;G1S
M('9E<GIO;F1E;B!W;W)D96XI('=A87)D;V]R('5W(&UA:6QB;W@@=F]L('IA
M;"!R86ME;B!E;B!G965N(&EN:V]M96YD92!E;6%I;"!M965R(&MA;B!O;G1V
M86YG96XN(%4@:W5N="!E8VAT97(@9&5Z92!O<'1I92!S=&%N9&%A<F0@86%N
M>F5T=&5N('9I82!H970@(D]P=&EE<R(@;65N=2`H3W!T:65S("T@0F5R:6-H
M='-A;65N<W1E;&QI;F<I(&EN(&1E(&YA=FEG871I96)A;&LN($1E;FL@97)O
M;2!W86YN965R('4@9&ET('-T86YD86%R9"!A86YS8VAA:V5L="P@9&%T('4@
M<F5G96QM871I9R!U=R`B3U540D]8(B!O<'-C:&]O;G0L(&%N9&5R<R!K86X@
M=7<@;6%I;&)O>"!N82!E;FEG92!T:6ID(&]N8G)U:6MB86%R('=O<F1E;BX*
M("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O
M;7!O<V4M;W!T:6]N<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO
M;CH@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M/<'1I;VYS
M)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&5S92!/<'1I;VYS
M(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M97-S86=E+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!#;&EC:R`F<75O=#M3<&5L;"!#:&5C:R9Q=6]T.R!T
M;R!C:&5C:R!Y;W5R('-P96QL:6YG+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("!#;&EC:R`F<75O=#M!='1A8VAM96YT<R9Q=6]T.R!T;R!V:65W(&%T
M('1H92!B;W1T;VT@;V8@=&AE('!A9V4@82!L:7-T(&]F(&9I;&5S(&%T=&%C
M:&5D('1O('1H:7,@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O("9Q=6]T.U-A
M=F4@8V]P>29Q=6]T.R!T;R!S879E(&$@8V]P>2!O9B!T:&ES(&UE<W-A9V4@
M:6X@>6]U<B`F<75O=#M396YT($UA:6PF<75O=#L@9F]L9&5R+B!3879E(&-O
M<&EE<R!O9B!I;7!O<G1A;G0@96UA:6QS('EO=2!S96YD('-O('1H870@>6]U
M(&AA=F4@<V]M971H:6YG('1O(')E9F5R(&)A8VL@=&\@;&%T97(@86YD('1O
M(&ME97`@86X@86-C=7)A=&4@<F5C;W)D(&]F('=H870@=V%S('-A:60N(%=E
M(&1O(&YO="!R96-O;6UE;F0@>6]U('-A=F4@979E<GD@96UA:6P@<VEN8V4@
M=&AE;B!Y;W5R(&1I<VL@<W1O<F%G92!Q=6]T82!W:6QL(&)E('5S960@=7`@
M<75I8VML>2`H97-P96-I86QL>2!W:&5N('EO=2!S96YD(&%T=&%C:&UE;G1S
M*2!A;F0@>6]U<B!M86EL8F]X('=I;&P@8F4@9G5L;"!A;F0@=6YA8FQE('1O
M(')E8V5I=F4@;F5W(&EN8V]M:6YG(&5M86EL+B!9;W4@8V%N+"!H;W=E=F5R
M+"!T=7)N('1H:7,@9F5A='5R92`G;VXG(&%S('EO=7(@9&5F875L="!W:71H
M:6X@>6]U<B!)9&5N=&ET>2P@8GD@9V]I;F<@=&\@3W!T:6]N<RTF9W0[4&5R
M<V]N86P@26YF;W)M871I;VXM)F=T.T5D:70@>6]U<B!I9&5N=&ET:65S+B!"
M92!C87)E9G5L('=H96X@=7-I;F<@=&AI<R!M;V1I9FEE9"!D969A=6QT(&%S
M('EO=2!W:6QL(&YE960@=&\@<&5R:6]D:6-A;&QY('!U<F=E('EO=7(@)G%U
M;W0[4V5N="!-86EL)G%U;W0[(&9O;&1E<B!O<B!I="!W:6QL(&5V96YT=6%L
M;'D@;6%K92!Y;W5R(&UA:6QB;W@@9G5L;"!A;F0@=6YU<V5A8FQE+@H@("`@
M/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6%T=&%C:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DYI975W
M(&)E<FEC:'0Z(%1O979O96=E;CPO=&ET;&4^"B`@("`\:&5A9&EN9SXB5&]E
M=F]E9V5N(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@52!K=6YT(&)E<W1A
M;F1E;B!A86X@=7<@8F5R:6-H="!T;V5V;V5G96XN"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&%P(#$Z($]F('4@='EP="!H970@<&%D(&5N(&1E(&)E<W1A
M;F1S;F%A;2!V86X@:&5T(&)E<W1A;F0@9&%T('4@86%N(&AE="!B97)I8VAT
M('=I;'0@=&]E=F]E9V5N(&]F('4@:VQI:W0@;W`@9&4@(D)R;W=S92(@:VYO
M<"!E;B!K:65S="!H970@8F5S=&%N9"!D870@=2!W:6QT('1O979O96=E;BX@
M2&5T('!A9"!E;B!D92!B97-T86YD<VYA86T@=F%N(&AE="!B97-T86YD('9E
M<G-C:&EJ;F5N(&YU(&EN(&AE="`B071T86-H;65N="(@=F5L9"X@1V$@;G4@
M=F5R9&5R(&YA87(@<W1A<"`R+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1A
M<"`R.B!+;&EK(&]P(&1E(")4;V5V;V5G96XB(&MN;W`N($1E(&)E<W1A;F1S
M;F%A;2!E;B!D92!G<F]O='1E('=O<F1E;B!T;V5G979O96=D(&%A;B!D92!L
M:6IS="!M970@071T86-H;65N=',N($1E;FL@97)O;2!D870@8FEJ(&=R;W1E
M(&)E<W1A;F1E;B!E;B]O9B!L86YG>F%M92!I;G1E<FYE='9E<F)I;F1I;F=E
M;B!H970@<')O8V5S('9A;B!U<&QO861E;B!E;B!T;V5V;V5G96X@=F%N(&AE
M="!B97-T86YD(&%A;B!D92!E;6%I;"!E;FEG92!T:6ID(&MA;B!D=7)E;BX@
M02YU+F(N(&)L:6IF="!U(&=E9'5L9&EG(&5N(&ML:6L@;FEE="!O<"!A;F1E
M<F4@9&EN9V5N('1E<G=I:FP@=2!W86-H="X*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M871T86-H(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8V@\+W1I=&QE/@H@
M("`@/&AE861I;F<^)G%U;W0[071T86-H)G%U;W0[/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!9;W4@;6%Y(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A
M9V4[(&]N;'D@;VYE(&9I;&4@;6%Y(&)E(&%T=&%C:&5D(&%T(&$@=&EM92X*
M("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,3H@16ET:&5R+"!T>7!E('1H
M92!P871H(&%N9"!N86UE(&]F(&$@9FEL92!T:&%T('EO=2!W86YT(&%T=&%C
M:&5D('1O('1H:7,@;65S<V%G92!O<B!C;&EC:R`F<75O=#M"<F]W<V4F<75O
M=#L@8G5T=&]N(&%N9"!S96QE8W0@=&AE(&9I;&4@=&\@8F4@871T871C:&5D
M+B!4:&4@<&%T:"!A;F0@;F%M92!O9B!T:&%T(&9I;&4@;F]W(&%P<&5A<G,@
M:6X@=&AE($%T=&%C:&UE;G0@8F]X+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M4W1E<"`R.B!$96-I9&4@=VAE=&AE<B!Y;W4@=V%N="!T:&4@9FEL92!T;R!B
M92!V:65W960@87,@86X@871T86-H;65N="!O<B!I;FQI;F5D('=I=&@@=&AE
M(')E<W0@;V8@=&AE(&UE<W-A9V4N(%1H92!R96-E:79I;F<@<&5R<V]N*',I
M(&UA:6P@<F5A9&EN9R!S;V9T=V%R92!M=7-T(&)E(&%B;&4@=&\@:&%N9&QE
M('1H92!F:6QE('1Y<&4@:6YL:6YE.R!I9B!N;W0L('1H:7,@<&%R="!W:6QL
M(&)E('9I97=E9"!A<R!A;B!A='1A8VAM96YT(&EN<W1E860N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83Y3=&5P(#,Z($-L:6-K("9Q=6]T.T%T=&%C:"9Q=6]T
M.R!B=71T;VXN(%1H92!F:6QE(&YA;64@86YD('-I>F4@=VEL;"!B92!A9&1E
M9"!T;R!Y;W5R(&QI<W0@;V8@071T86-H;65N=',N(%!L96%S92!N;W1E('1H
M870@9F]R(&QA<F=E(&9I;&5S(&%N9"]O<B!S;&]W97(@26YT97)N970@8V]N
M;F5C=&EO;G,L('1H92!P<F]C97-S(&]F('5P;&]A9&EN9R!A;F0@871T86-H
M:6YG('EO=7(@9FEL92!T;R!T:&4@96UA:6P@;6%Y('1A:V4@82!W:&EL92X@
M4&QE87-E(&)E('!A=&EE;G0@86YD(&1O(&YO="!C;&EC:R!O=&AE<B!T:&EN
M9W,@=VAI;&4@>6]U(&%R92!W86ET:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y
M/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S
M(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^3FEE=7<@8F5R:6-H=#H@
M071T86-H;65N=',\+W1I=&QE/@H@("`@/&AE861I;F<^(D%T=&%C:&UE;G1S
M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5Z92!S96-T:64@;&%A="!E
M96X@;&EJ<W0@;65T+"!A86X@=7<@8F5R:6-H="P@=&]E9V5V;V5G9&4@8F5S
M=&%N9&5N('II96XN($]M(&5E;B!T;V5G979O96=D(&)E<W1A;F0@=&4@=F5R
M=VEJ9&5R96XZ"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&%P(#$Z(%9I;FL@
M:&5T('-E;&5C=&EE=F%K:F4L(&YA87-T(&AE="!B97-T86YD(&1A="!U('=I
M;'0@=F5R=VEJ9&5R96XL(&%A;BX*("`@(#PO<&%R83X@"B`@("`\<&%R83Y3
M=&%P(#(Z($ML:6L@;W`@(E9E<G=I:F1E<B!G97-E;&5C=&5E<F0B+@H@("`@
M/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S
M92UA='1A8VAM96YT<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO
M;CH@071T86-H;65N=',\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[071T
M86-H;65N=',F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@
M<V5C=&EO;B!D:7-P;&%Y<R!A(&QI<W0@;V8@9FEL97,@86QR96%D>2!A='1A
M8VAE9"!T;R!Y;W5R(&UE<W-A9V4N(%1O($1E;&5T92!A;B!A='1A8VAE9"!F
M:6QE.@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`Q.B!!8W1I=F%T92!T
M:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@=&AE(&%T=&%C:&5D(&9I;&5N86UE
M('EO=2!W86YT('1O($1E;&5T92X*("`@(#PO<&%R83X@"B`@("`\<&%R83Y3
M=&5P(#(Z($-L:6-K("9Q=6]T.T1E;&5T92!!='1A8VAM96YT*',I)G%U;W0[
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)C;VUP;W-E+7!R:6]R:71Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-
M97-S86=E($-O;7!O<VET:6]N.B!0<FEO<FET>3PO=&ET;&4^"B`@("`\:&5A
M9&EN9SXB4')I;W)I='DB/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES
M('-E=',@=&AE(")8+5!R:6]R:71Y(B!H96%D97(@;VX@>6]U<B!O=71G;VEN
M9R!M97-S86=E+B!4:&4@(E@M4')I;W)I='DB('1A9R!I<R!A('-O<G0@;V8@
M(G!S975D;R!S=&%N9&%R9"(@=&AA="!.971S8V%P92P@36]Z:6QL82P@3W!E
M<F$L(&%N9"!/=71L;V]K(&UA:6P@8VQI96YT<R!A<'!E87(@=&\@86=R964@
M;VXN($%N>2!M86EL(&-L:65N=',@=&AA="!D;R!N;W0@:&%N9&QE('1H:7,@
M:&5A9&5R('=I;&P@<VEM<&QY(&EG;F]R92!I="X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<V%V92UA='1A8VAM96YT<R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@
M4V%V92!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R
M;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@:6X@>6]U<B!C;VUP;W-I
M=&EO;B!A<F4@<V%V960@=VET:"!T:&4@;65S<V%G92!W:&5N('-T;W)E9"!I
M;B!T:&4@<V5N="UM86EL(&9O;&1E<BX@($EF(")997,B+"!T:&4@871T86-H
M;65N="!D871A('=I;&P@8F4@<V%V960N("!)9B`B3F\B+"!T:&4@871T86-H
M;65N="!D871A('=I;&P@8F4@<W1R:7!P960@9G)O;2!T:&4@;65S<V%G92!A
M9G1E<B!I="!I<R!S96YT('1O(&%L;"!R96-I<&EE;G1S+B`@0VAO;W-I;F<@
M(DYO(B!W:6QL(&AE;'`@8V]N<V5R=F4@9&ES:R!S<&%C92!B>2!R96UO=FEN
M9R`H<&]T96YT:6%L;'D@;&%R9V4I(&%T=&%C:&UE;G0@:6YF;W)M871I;VX@
M9G)O;2!T:&4@<V%V960@;65S<V%G97,N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6QI;FLM871T86-H;65N=',B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($QI;FL@
M071T86-H;65N=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S
M('=H971H97(@=&AE(&%T=&%C:&UE;G1S(&EN('EO=7(@8V]M<&]S:71I;VX@
M87)E('-E;G0@87,@82!P87)T(&]F('1H92!M86EL(&UE<W-A9V4@;W(@=VAE
M=&AE<B!T:&]S92!A='1A8VAM96YT<R!A<F4@:V5P="!O;B!A(&QO8V%L('-E
M<G9E<BX@($EF(&%T=&%C:&UE;G1S(&%R92!L:6YK960L('1H92!R96-I<&EE
M;G0H<RD@;V8@>6]U<B!M97-S86=E('=I;&P@8F4@<')O=FED960@82!W96)L
M:6YK('=H97)E('1H97D@8V%N(&1O=VYL;V%D('1H92!A='1A8VAM96YT*',I
M+B`@3&EN:VEN9R!A='1A8VAM96YT<R!H87,@=&AE(&%D=F%N=&%G92!O9B!T
M<F5M96YD;W5S;'D@<F5D=6-I;F<@=&AE('-I>F4@;V8@;W5T9V]I;F<@;65S
M<V%G97,N("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA<R!T:&4@9&ES861V86YT
M86=E('1H870@=&AE(&-O;G1E;G0@;V8@=&AE(&%T=&%C:&UE;G1S(&-A;B!N
M;W0@8F4@9W5A<F%N=&5E9"!T;R!B92!A=F%I;&%B;&4@:6X@=&AE(&9U='5R
M92!S:6YC92!T:&4@871T86-H;65N="!D871A(&ES(&YO="!L;V-A=&5D('=I
M=&AI;B!T:&4@92UM86EL(&UE<W-A9V4N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)S96%R8V@B('-T871E/2)U;FMN;W=N(CX*("`@(#QT
M:71L93Y:;V5K96X\+W1I=&QE/@H@("`@/&AE861I;F<^6F]E:V-R:71E<FEA
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@("`@1&5Z92!H96QP=&5K<W0@
M;6]E="!N;V<@9V5S8VAR979E;B!W;W)D96XN"B`@("`\+W!A<F$^"CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)S96%R8V@B/@H@("`@/'1I=&QE
M/DUE<W-A9V4@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG/E-E87)C:"!#
M<FET97)I83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA>2!S96%R
M8V@@9F]R(&UE<W-A9V5S(&9R;VT@>6]U<B!F;VQD97)S('5S:6YG(&1I9F9E
M<F5N="!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3
M=&5P(#$Z($5N=&5R('1E>'0@=&\@=&AE(&9I96QD<R!Y;W4@=V%N="!T;R!A
M9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83Y3=&5P(#(Z($-H;V]S92!T:&4@;65S<V%G92!F;&%G*',I('1O(&%D
M9"!T;R!Y;W5R('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*("`@(#QP
M87)A/E-T97`@,SH@0VAO;W-E('1H92!F;VQD97(H<RD@9G)O;2!W:&EC:"!T
M;R!S96%R8V@@9F]R('1H92!M97-S86=E<RX*("`@(#PO<&%R83X*("`@(#QP
M87)A/E-T97`@-#H@0VQI8VL@)G%U;W0[4V5A<F-H)G%U;W0[+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("!)9B!A;GD@;65S<V%G97,@;6%T8VAE9"!Y
M;W5R('-E87)C:"!C<FET97)I82P@=&AE;B!T:&4@<W5B:F5C=',@;V8@=&AE
M<V4@;65S<V%G97,@=VEL;"!B92!S:&]W;B!I;B!T:&4@)G%U;W0[4V5A<F-H
M(%)E<W5L=',F<75O=#L@=FEE=RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]L9&5R+6]P=&EO;G,B('-T871E/2)U
M;FMN;W=N(CX*("`@(#QT:71L93Y-87!P96XZ($UA<&YA=FEG871O<CPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY-87!N879I9V%T;W(\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%4@:W5N="!E96X@;6%P('-E;&5C=&5R96X@;2YB+G8N(&1E
M('-E;&5C=&EE=F%K:F5S(&EN(&1E(&QI;FME<B!K;VQO;2X@2&EE<FYA(&MU
M;G0@=2P@;&EN:W-B;W9E;B!I;B!H970@<V5L96-T:65M96YU+"!E96X@8F5W
M97)K:6YG(&MI97IE;BP@9&EE('4@;W`@9&4@;6%P('=I;'0@=6ET=F]E<F5N
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!697)D97)E(&]P=&EE<R!W
M;W)D96X@86%N9V5G979E;BX@5V5E<R!V;V]R>FEC:'1I9R!M970@9&4@;W!T
M:64@(E9E<G=I:F1E<B!M87`H<&5N*2(L(&]M9&%T('4@86QL92!B97)I8VAT
M96X@9&EE('II8V@@:6X@965N(&UA<"!B979I;F1E;B!V97)L:65S="P@=V%N
M;F5E<B!U(&1E(&UA<"!P97(@;VYG96QU:R!V97)W:6ID97)T(0H@("`@/"]P
M87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB9F]L9&5R+6]P
M=&EO;G,B/@H@("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M96YT/"]T:71L93X*
M("`@(#QH96%D:6YG/D9O;&1E<B!/<'1I;VYS/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("`@(%EO=2!C86X@<V5L96-T(&$@9F]L9&5R(&)Y('5S:6YG('1H
M92!R861I;R!B=71T;VYS(&%L;VYG('1H92!L969T(&-O;'5M;BX@($]N8V4@
M>6]U(&AA=F4@9&]N92!T:&ES+"!S96QE8W0@=&AE(&]P=&EO;B!Y;W4@=VES
M:"!T;R!P97)F;W)M(&]N('1H92!F;VQD97(@=FEA('1H92!S96QE8W0@8F]X
M('1O('1H92!L969T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%EO
M=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!F=7)T:&5R(&]P=&EO;G,N("!"92!C
M87)E9G5L('=I=&@@=&AE(&1E;&5T92!O<'1I;VXL(&%S('EO=2!C86X@;&]S
M92!A;&P@=&AE(&UE<W-A9V5S(&EN(&$@9F]L9&5R(&EF('EO=2!D96QE=&4@
M:70@8GD@;6ES=&%K92$*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DEM<&]R
M="!M8F]X($9I;&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@5&AI<R!O
M<'1I;VX@=VEL;"!I;7!O<G0@82!M8F]X(&9O<FUA="!F:6QE(&EN=&\@=&AE
M(&9O;&1E<B!O9B!Y;W5R(&-H;VEC92X@0VAO;W-E(#$@*&]N92D@9F]L9&5R
M('1O(&EM<&]R="!T:&4@;65S<V%G97,@:6YT;R!A;F0@=&AE;B!S96QE8W0@
M=&AI<R!O<'1I;VXN(%EO=2!W:6QL('1H96X@8F4@=&%K96X@=&\@82!P86=E
M('1H870@=VEL;"!P<F]M<'0@9F]R('1H92!M8F]X(&9I;&4@=&\@:6UP;W)T
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)F;VQD97(M=VED9V5T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1F]L
M9&5R($UA;F%G96UE;G0Z($1I<W!L87D\+W1I=&QE/@H@("`@/&AE861I;F<^
M4VAO=R](:61E(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@268@=7-I;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO=R]H
M:61E('1H92!U;G-U8G-C<FEB960@9F]L9&5R<RX@(%1O('-U8G-C<FEB92]U
M;G-U8G-C<FEB92!T;R!A(&9O;&1E<BP@<V5L96-T('1H92!C:&5C:V)O>"!N
M97AT('1O('1H92!F;VQD97)N86UE(&%N9"!U<V4@=&AE(%-U8G-C<FEB92]5
M;G-U8G-C<FEB92!O<'1I;VX@:6X@=&AE($9O;&1E<B!!8W1I;VX@9')O<"UD
M;W=N(&UE;G4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%>'!A;F0@06QL
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%>'!A;F0@86QL(&9O;&1E<B!E
M;G1R:65S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^0V]L;&%P<V4@06QL
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;VQL87!S92!A;&P@9F]L9&5R
M(&5N=')I97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F
M:6QT97)S(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^1FEL=&5R<SH@
M5&]E<&%S<V5N/"]T:71L93X*("`@(#QH96%D:6YG/D9I;'1E<G)E9V5L<R!T
M;V5P87-S96X\+VAE861I;F<^"B`@("`\<&%R83X*("`@($ML:6L@;W`@:&5T
M(")&:6QT97)S('1O97!A<W-E;B!O<"!)3D)/6"(@:6-O;BP@;F%A<W0@9&4@
M24Y"3U@@;F%A;2!I;B!D92!M86EL8F]X=V5E<F=A=F4L(&]M(&%L;&4@;FEE
M="!V97)W:6ID97)D92!B97)I8VAT96X@=&4@9FEL=&5R96X@=F]L9V5N<R!D
M92!O<&=E9V5V96X@9FEL=&5R<F5G96PL(&]F(&ML:6L@;W`@(D%L;&4@9FEL
M=&5R<F5G96QS('1O97!A<W-E;B(@:6X@:&5T(&9I;'1E<FUE;G4@*$]P=&EE
M<R`M($9I;'1E<G,@+2!&:6QT97)R96=E;',@8F5W97)K96XI+B!/<&UE<FMI
M;F<Z(&9I;'1E<FEN9R!W;W)D="!N:65T(&%U=&]M871I<V-H('5I=&=E=F]E
M<F0N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)F:6QT97)S(CX*("`@(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-L:6-K(&]N('1H92`F<75O=#M!<'!L>2!&:6QT97(F
M<75O=#L@:6-O;B!N97AT('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL
M8F]X('9I97<@=&\@9FEL=&5R(&%L;"!U;F1E;&5T960@;65S<V%G97,@86-C
M;W)D:6YG('1O('1H92!S<&5C:69I960@<G5L97,N("!/<BP@86QT97)N871E
M=FQY+"!C;&EC:R!O;B`F<75O=#M!<'!L>2!!;&P@4G5L97,F<75O=#L@:6X@
M=&AE(&9I;'1E<B!M96YU+B`@3F]T92!T:&%T(&9I;'1E<FEN9R!I<R!N;W0@
M9&]N92!A=71O;6%T:6-A;&QY+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UR=6QE<R(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!&:6QT97(@4G5L97,\
M+W1I=&QE/@H@("`@/&AE861I;F<^161I="!9;W5R($9I;'1E<B!2=6QE<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!F
M:6QT97(@<G5L97,B('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U
M(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@=&AE(&-U<G)E;G1L>2!A8W1I
M=F4@<V5T(&]F(&9I;'1E<B!R=6QE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](F9I;'1E<BUE9&ET+6)L86-K;&ES="(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!";&%C:VQI<W0\+W1I=&QE
M/@H@("`@/&AE861I;F<^161I="!9;W5R($)L86-K;&ES=#PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!B;&%C:VQI<W0B
M('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E
M;&5T92P@86YD(&5D:70@=&AE(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y
M;W4@04Q705E3(')E9G5S92!M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UW:&ET96QI<W0B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@5VAI=&5L:7-T/"]T
M:71L93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!7:&ET96QI<W0\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@=VAI=&5L
M:7-T(B!T;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D
M+"!D96QE=&4L(&%N9"!E9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S
M97,@>6]U($%,5T%94R!A8V-E<'0@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!&:6QT97(@;VX@3&]G:6X\+W1I
M=&QE/@H@("`@/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S(%5P;VX@3&]G
M;VX_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO
M;B!T;R!A;'=A>7,@87!P;'D@9FEL=&5R<R!W:&5N(&9I<G-T(&QO9V=I;F<@
M;VYT;R!)35`N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F
M:6QT97(M;VXM9&ES<&QA>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL
M=&5R<SH@1FEL=&5R(&]N(%)E9G)E<V@\+W1I=&QE/@H@("`@/&AE861I;F<^
M07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE
M9#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N
M('1O(&%L=V%Y<R!A<'!L>2!F:6QT97)S('=H96YE=F5R('EO=7(@=FEE=R!T
M:&4@24Y"3U@_"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F
M:6QT97(M86YY+6UA:6QB;W@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I
M;'1E<G,Z($9I;'1E<B!A;GD@36%I;&)O>#PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY!<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA:6QB;W@_/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!I9B!Y;W4@=V%N
M="!T;R!B92!A;&QO=V5D('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@
M;6%I;&)O>"X@3F]R;6%L;'DL(&9I;'1E<FEN9R!R=6QE<R!A<F4@;VYL>2!A
M<'!L:65D('1O(&YE=R!M86EL('1H870@:7,@9&5L:79E<F5D('1O('EO=7(@
M24Y"3U@N("!)9B!T:&ES(&]P=&EO;B!I<R!C:&5C:V5D+"!A;B!I8V]N('=I
M;&P@87!P96%R(&]N(&%L;"!M86EL8F]X('!A9V=E<R!T:&%T('=I;&P@86QL
M;W<@>6]U('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!T:&4@;65S<V%G97,@
M:6X@=&AE(&-U<G)E;G0@;6%I;&)O>"X@($Y/5$4Z($9I;'1E<FEN9R!I;B!M
M86EL8F]X97,@;W1H97(@=&AA;B!)3D)/6"!M87D@<')O9'5C92!S=')A;F=E
M("AE+F<N('1H92!F:6QT97(@;6%Y(&-A=7-E(&$@8V]P>2!O9B!M97-S86=E
M<R!T;R!B92!D96QI=F5R960@=&\@=&AE('-A;64@;6%I;&)O>"D@86YD+V]R
M('5N9&5S:7)E9"!R97-U;'1S("AE+F<N(&ET(&UA>2!C875S92!M97-S86=E
M<R!T;R!B92!M;W9E9"]D96QE=&5D(&EF(&YE=R!F:6QT97)I;F<@<G5L97,@
M:&%V92!B965N(&EM<&QE;65N=&5D('-I;F-E('1H92!M97-S86=E(&AA<R!B
M965N(&1E;&EV97)E9"!T;R!T:&4@8W5R<F5N="!M86EL8F]X*2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C
M:"UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@071T86-H
M(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^071T86-H(%!U8FQI
M8R!+97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H
M96X@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T
M<RP@=VEL;"!B92!A='1A8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X@
M(%EO=2!C86X@<V5T('1H92!D969A=6QT(&)E:&%V:6]R('9I82!T:&4@4$=0
M($]P=&EO;G,@<V-R965N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+6]P=&EO;BUS8V%N+6)O9'DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@4V-A;B!497AT($)O9&EE<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY38V%N(%1E>'0@0F]D:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!)9B!S96QE8W1E9"!T:&5N($E-4"!W:6QL('-C86X@=&AE(&)O9'D@;V8@
M86QL('1E>'0@;65S<V%G97,@9F]R(%!'4"!D871A+"!A;F0@9&ES<&QA>2!T
M:&4@<F5S=6QT<R!I9B!A;GD@9&%T82!I<R!F;W5N9"X@($YO=&4@=&AA="!T
M:&ES(&UA>2!S;&]W(&1O=VX@=&AE('-Y<W1E;2!A<R!E=F5R>2!T97AT(&UE
M<W-A9V4@;75S="!B92!S8V%N;F5D(&EN(&ET<R!E;G1I<F5T>2!F;W(@4$=0
M(&1A=&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6]P=&EO;G,M96YC<GEP="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M0V]M<&]S93H@16YC<GEP=&EO;B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D
M:6YG/DYO($5N8W)Y<'1I;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E
M;F0@=&AE(&UE<W-A9V4@=VET:"!N;R!E;F-R>7!T:6]N("AC;&5A<G1E>'0I
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0($5N8W)Y<'0@365S<V%G
M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!E
M;F-R>7!T('1H92!C=7)R96YT(&UE<W-A9V4L('5S:6YG(%!'4"!A;F0@=&AE
M(')E8VEP:65N=',@<&5R<V]N86P@<'5B;&EC(&ME>2P@86YD('1H96X@<V5N
M9"!I="X@66]U(&-A;B!O;FQY('-E;F0@82!M97-S86=E('1O(&$@<VEN9VQE
M('!E<G-O;B!U<VEN9R!T:&ES(&]P=&EO;BX@66]U($U54U0@:&%V92!T:&4@
M<'5B;&EC(&ME>2!O9B!T:&4@<F5C:7!I96YT('-T;W)E9"!I;B!Y;W5R(&%D
M9')E<W-B;V]K(&]R(&5L<V4@=&AI<R!O<'1I;VX@=VEL;"!F86EL+B!)9B!Y
M;W4@:&%V92!T:&4@<'5B;&EC(&ME>2!F;W(@=&AE(')E8VEP:65N="!I;B!Y
M;W5R(&%D9')E<W-B;V]K(&%N9"!A<F4@<W1I;&P@<F5C96EV:6YG(&5R<F]R
M<RP@=F5R:69Y('1H870@=&AE(&4M;6%I;"!A9&1R97-S(&EN('1H92!R96-I
M<&EE;G0@9FEE;&0@;6%T8VAE<R!T:&4@92UM86EL(&%D9')E<W,@=VAE<F4@
M=&AE('!U8FQI8R!K97D@:7,@<W1O<F5D+B!4:&4@96YC<GEP=&5D(&1A=&$@
M=VEL;"!B92!A='1A8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!3:6=N($UE<W-A9V4\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@9&EG:71A;&QY
M('-I9VX@=&AE(&-U<G)E;G0@;65S<V%G92!U<VEN9R!01U`@86YD('EO=7(@
M<&5R<V]N86P@<')I=F%T92!K97DN($EF('EO=2!H879E(&YO="!A;')E861Y
M(&5N=&5R960@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@<')I=F%T92!K97D@
M9'5R:6YG('1H:7,@<V5S<VEO;B!Y;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@
M:70N("!4:&4@<F5C96EP:65N="!M=7-T(&AA=F4@82!C;W!Y(&]F('EO=7(@
M<'5B;&EC(&ME>2!T;R!D:6=I=&%L;'D@=F5R:69Y('EO=7(*("`@('-I9VYA
M='5R92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!3:6=N+T5N8W)Y
M<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I
M;VX@=VEL;"!F:7)S="!D:6=I=&%L;'D@<VEG;B!Y;W5R(&UE<W-A9V4@86YD
M('1H96X@=VEL;"!E;F-R>7!T('1H92!R97-U;'1I;F<@;W5T<'5T+B!3964@
M=&AE("=01U`@16YC<GEP="!-97-S86=E)R!A;F0@)U!'4"!3:6=N($UE<W-A
M9V4G(&5N=')I97,@9F]R(&9U<G1H97(@:6YF;W)M871I;VXN"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY3+TU)344@16YC<GEP="!-97-S86=E/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY3+TU)344@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG
M;B]%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/
M1$\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R
M=FEE=R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!/=F5R=FEE=SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY7:&%T(&ES(%!'4#\\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%!'4"!I<R!A('1O;VP@9F]R('-E8W5R92!C;VUM=6YI
M8V%T:6]N(&%N9"!D871A('-T;W)A9V4L(&5S<&5C:6%L;'D@9F]R('5S92!W
M:71H(&4M;6%I;"X@270@8V%N(&)E('5S960@=&\@96YC<GEP="!D871A(&%N
M9"!T;R!C<F5A=&4@9&EG:71A;"!S:6=N871U<F5S+B!)35`@=7-E<R!';G50
M1R`H1TY5(%!R:79A8WD@1W5A<F0I('1O('!R;W9I9&4@=&AI<R!F=6YC=&EO
M;F%L:71Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16YA8FQE(%!'4"!F
M=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=&AI
M<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@8W)E
M871E+W9I97<@>6]U<B!P97)S;VYA;"!01U`@:V5Y<RP@861D+V1E;&5T92!P
M=6)L:6,@:V5Y<R!F<F]M(&]T:&5R(&EN9&EV:61U86QS+"!R96%D(&5N8W)Y
M<'1E9"!M86EL+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@
M96YC<GEP="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I;VXM871T86-H+7!U8FME
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!/<'1I;VYS("T@071T
M86-H(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^3W!T:6]N<R`M
M($%T=&%C:"!0=6)L:6,@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)
M9B!S96QE8W1E9"!T:&5N(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y
M+"!I9B!I="!E>&ES=',L('=I;&P@8GD@9&5F875L="!B92!A='1A8VAE9"!T
M;R!A;&P@;W5T9V]I;F<@;65S<V%G97,N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@
M("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1H:7,@<V-R965N(&QI<W1S(&%L;"!O9B!T:&4@8W5R<F5N="!U<V5R<R!I
M;B!Y;W5R(&%D9')E<W-B;V]K('1H870@:&%V92!01U`@<'5B;&EC(&ME>7,N
M(%1H97-E('5S97)S(&%R92!T:&4@3TY,62!U<V5R<R!T:&%T('EO=2!C86X@
M96ET:&5R(#$I('-E;F0@86X@96YC<GEP=&5D(&UE<W-A9V4@=&\@+4]2+2`R
M*2!V97)I9GD@82!D:6=I=&%L('-I9VYA='5R92X*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS
M(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<'5B
M;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T:&4@<'5B;&EC(&ME>2!F
M<F]M('EO=7(@861D<F5S<V)O;VLN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M:6UP;W)T+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME>7,@+2!);7!O<G0\+W1I
M=&QE/@H@("`@/&AE861I;F<^26UP;W)T(%!U8FQI8R!+97ES/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&ES(&)U='1O;B!W:6QL(&]P96X@82!W:6YD
M;W<@=VAE<F4@>6]U(&-A;B!M86YU86QL>2!I;7!O<G0@82!01U`@<'5B;&EC
M(&ME>2X@(%1H92!K97D@8V%N(&5I=&AE<B!B92!P87-T960@:6YT;R!A('1E
M>'1F:65L9"!O<BP@:68@=&AE(&ME>2!R97-I9&5S(&EN(&$@9FEL92!O;B!Y
M;W5R(&QO8V%L(&-O;7!U=&5R+"!Y;W4@8V%N(&EM<&]R="!I="X@($EF('1H
M92!K97D@:7,@=F%L:60@:70@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@
M861D<F5S<V)O;VL@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T
M('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP
M;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M;W9E<G9I97<M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,\+W1I=&QE/@H@("`@
M/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF
M('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&UE<W-A9V5S(&]R(&5N86)L
M92!O=&AE<G,@=&\@<V5N9"!Y;W4@96YC<GEP=&5D(&UE<W-A9V5S+"!Y;W4@
M;75S="!H879E('EO=7(@;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%!'
M4"!K97EP86ER+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0=6)L
M:6,@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!U8FQI8R!K
M97D@<VAO=6QD(&)E(&UA9&4@879A:6QA8FQE('1O(&%N>2!P97)S;VX@=&AA
M="!Y;W4@=V%N="!T;R!B92!A8FQE('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M
M97-S86=E<R!T:&%T(&]N;'D@64]5(&-A;B!D96-R>7!T("AU<VEN9R!Y;W5R
M('!R:79A=&4@:V5Y*2X@061D:71I;VYA;&QY+"!Y;W5R('!U8FQI8R!K97D@
M;F5E9',@=&\@8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY8F]D>2!Y;W4@<V5N
M9"!A(&1D:6=I=&%L;'D@<VEG;F5D(&UE<W-A9V4@=&\@+2!T:&4@<'5B;&EC
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE(&1I9VET86P@<VEG;F%T
M=7)E+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0<FEV871E($ME
M>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U<B!P<FEV871E(&ME>2!I
M<R!N96-E<W-A<GD@=&\@9&5C<GEP="!A;GD@;65S<V%G92!E;F-R>7!T960@
M=7-I;F<@>6]U<B!P=6)L:6,@:V5Y+B!!9&1I=&EO;F%L;'DL('EO=7(@<')I
M=F%T92!K97D@:7,@;F5E9&5D(&EF('EO=2!W86YT('1O(&1I9VET86QL>2!S
M:6=N(&$@;65S<V%G92X@66]U<B!P<FEV871E(&ME>2!W:6QL(&)E('!R;W1E
M8W1E9"!V:6$@82!P87-S<&AR87-E(&-R96%T960@=VAE;B!T:&4@:V5Y<R!A
M<F4@9V5N97)A=&5D+B!4:'5S+"!T;R!P97)F;W)M(&%N>2!A8W1I=FET>2!T
M:&%T(')E<75I<F5S('EO=7(@<')I=F%T92!K97DL($E-4"!W:6QL('!R;VUP
M="!Y;W4@9F]R('EO=7(@<&%S<W!H<F%S92X@66]U(&]N;'D@;F5E9"!T;R!I
M;G-E<G0@>6]U<B!P87-S<&AR87-E(&]N8V4@<&5R('-E<W-I;VX@+2!)35`@
M=VEL;"!S=&]R92!Y;W5R('!A<W-P:')A<V4@=6YT:6P@>6]U(&QO9V]U="`H
M4V\@8F4@<W5R92!T;R!L;V=O=70A*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP=6)L:6,B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!0
M=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'
M4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A
M:6QS(&%B;W5T('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP<FEV871E(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+
M97ES("T@4')I=F%T92!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^16YT97(@
M4&%S<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@=&AE
M('!A<W-P:')A<V4@9&EA;&]G('=I;F1O=RX@5&AE('!A<W-P:')A<V4@96YT
M97)E9"P@:68@8V]R<F5C="P@=VEL;"!B92!S=&]R960@8GD@24U0('5N=&EL
M('EO=7(@<V5S<VEO;B!E;F1S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M56YL;V%D(%!A<W-P:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%)E
M;6]V97,@=&AE('-T;W)E9"!P87-S<&AR87-E(&9R;VT@24U0("T@86YY(&%D
M9&ET:6]N86P@=7-A9V4@;V8@=&AE('!R:79A=&4@:V5Y('=I;&P@<F5Q=6ER
M92!Y;W4@=&\@<F5E;G1E<B!T:&4@<&%S<W!H96%S92X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P
M96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P<FEV871E(&ME>2X@1$\@
M3D]4(%-%3D0@5$A)4R!+15D@5$\@04Y93TY%("T@=&AI<R!O<'1I;VX@:7,@
M<W1R:6-T;'D@<V\@=&AA="!Y;W4@8V%N(&5X<&]R="!Y;W5R($E-4"!P97)S
M;VYA;"!P<FEV871E(&ME>2!F;W(@=7-E(&EN(&%N;W1H97(@<')O9W)A;2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@
M4$=0('!R:79A=&4@:V5Y+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M($1E;&5T93PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@2V5Y<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!D96QE=&4@
M>6]U<B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER(&9R;VT@24U0
M)W,@<')E9F5R96YC97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6YA;64B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($YA;64\
M+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AE(&YA;64@>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S
M;VYA;"!K97ES+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UC;VUM
M96YT(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S
M;VYA;"!+97D@+2!#;VUM96YT/"]T:71L93X*("`@(#QH96%D:6YG/D-O;6UE
M;G0\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@8V]M;65N="!S=')I;F<@
M>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!;B!O
M<'1I;VYA;"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M96UA:6PB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($4M;6%I
M;"!!9&1R97-S/"]T:71L93X*("`@(#QH96%D:6YG/D4M;6%I;"!!9&1R97-S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@92UM86EL(&%D9')E<W,@
M>6]U('=A;G0@87-S;V-I871E9"!W:71H('EO=7(@<&5R<V]N86P@:V5Y<RX@
M02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M:V5Y;&5N9W1H(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@
M+2!+97EL96YG=&@\+W1I=&QE/@H@("`@/&AE861I;F<^2V5Y;&5N9W1H/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@:V5Y;&5N9W1H+"!I;B!B>71E
M<RP@;V8@>6]U<B!G96YE<F%T960@:V5Y+B!4:&4@9W)E871E<B!T:&4@=F%L
M=64L('1H92!G<F5A=&5R('1H92!P<F]T96-T:6]N("AA;F0@86QS;R!G<F5A
M=&5R(&=E;F5R871I;VX@=&EM92!A;F0@96YC<GEP=&EO;B!T:6UE*2X@,3`R
M-"!B>71E<R!I<R!T:&4@9&5F875L="`M('1H:7,@=F%L=64@<')O=FED97,@
M97AC96QL96YT('!R;W1E8W1I;VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+7!A<W-P:')A<V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L
M($ME>2`M(%!A<W-P:')A<V4\+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE('!A<W-P:')A<V4@=7-E9"!T
M;R!P<F]T96-T+V5N8W)Y<'0@>6]U<B!P97)S;VYA;"!P<FEV871E(&ME>2X@
M5&AI<R!S:&]U;&0@8F4@050@3$5!4U0@-B!C:&%R86-T97)S+"!S:&]U;&0@
M3D]4(&)E('1H92!S86UE(&%S('EO=7(@;&]G:6X@<&%S<W=O<F0L('-H;W5L
M9"!.3U0@8F4@8F%S960@;VX@82!D:6-T:6]N87)Y('=O<F0L(&%N9"!S:&]U
M;&0@:6YC;'5D92!B;W1H(&YU;6)E<G,@86YD(&QE='1E<G,N(%EO=2!M=7-T
M(&5N=&5R('1H:7,@<&%S<W!H<F%S92!T=VEC92!F;W(@=F5R:69I8V%T:6]N
M('!U<G!O<V5S+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UA8W1I
M;VYS(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S
M;VYA;"!+97D@+2!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D-R96%T
M92!+97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#<F5A=&4@86YD('-T
M;W)E('EO=7(@<&5R<V]N86PO<')I=F%T92!K97EP86ER+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^26UP;W)T($ME>7!A:7(\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($EM<&]R="!A('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX@
M5&AI<R!B=71T;VX@;W!E;G,@82!W:6YD;W<@=VAE<F4@>6]U(&-A;B!M86YU
M86QL>2!I;7!O<G0@>6]U<B!E>&ES=&EN9R!01U`@<&5R<V]N86P@<'5B;&EC
M+W!R:79A=&4@:V5Y<&%I<BX@(%1H92!K97ES(&-A;B!E:71H97(@8F4@<&%S
M=&5D(&EN=&\@82!T97AT9FEE;&0@;W(L(&EF('1H92!K97ES(')E<VED92!I
M;B!A(&9I;&4@;VX@>6]U<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O
M<G0@=&AE;2X@($EF('1H92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@
M:6YS97)T960@:6YT;R!Y;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W
M('=I;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W
M:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E,O34E-13H@3W9E<G9I97<\+W1I=&QE/@H@("`@
M/&AE861I;F<^5VAA="!I<R!3+TU)344_/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!3+TU)344@:7,@82!P<FEV871E+W!U8FQI8R!K97D@<&%I<B!S>7-T
M96T@=VAI8V@@<')O=FED97,@9&EG:71A;"!S:6=N871U<F5S+"!M97-S86=E
M('!R:79A8WDL(&%N9"!T86UP97(@9&5T96-T:6]N(&EN(&$@;W!E;BP@:6YT
M97)O<&5R86)L92!W87DN("!3+TU)344@8V%N('!R;W9I9&4@;65S<V%G92!P
M<FEV86-Y(&)Y(&5N8W)Y<'1I;F<@;65S<V%G97,@=&AA="!O;FQY('1H92!S
M96YD97(@86YD('1H92!I;G1E;F1E9"!R96-I<&EE;G1S(&-A;B!D96-O9&4N
M("!)="!A;&QO=W,@>6]U('1O(&ED96YT:69Y('1H92!S96YD97(@;V8@82!M
M97-S86=E('9I82!A(&1I9VET86P@<VEG;F%T=7)E+B`@5&]G971H97(L('1H
M:7,@96YC<GEP=&EO;B!A;F0@9&EG:71A;"!S:6=N:6YG(&AE;'`@<')O=FED
M92!T86UP97(@9&5T96-T:6]N+"!A;&QO=VEN9R!R96-I<&EE;G1S('1O(&1E
M=&5R;6EN92!W:&5T:&5R(&$@;65S<V%G92!W87,@86QT97)E9"!A9G1E<B!I
M="!W87,@<V5N="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!3
M+TU)344@9G5N8W1I;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($EF('1H:7,@;W!T:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE
M('1O(&EM<&]R="!Y;W5R('!E<G-O;F%L(%,O34E-12!K97ES+"!R96%D(&5N
M8W)Y<'1E9"!M86EL+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A
M;F0@96YC<GEP="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W+7!E<G-O
M;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z(%!E<G-O
M;F%L($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($EF('EO=2!W86YT('1O(&1I9VET86QL>2!S
M:6=N(&]R(&5N8W)Y<'0@;65S<V%G97,@>6]U(&UU<W0@:&%V92!Y;W5R(&]W
M;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!3+TU)344@:V5Y<&%I<BX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6EM<&]R="UP
M97)S;VYA;"UC97)T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%
M.B!);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH
M96%D:6YG/DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EM<&]R="!P97)S;VYA;"!C97)T:69I8V%T97,@
M9G)O;2!A(%!+0U,@(S$R(&9O<FUA="!F:6QE+B!02T-3(",Q,B!F:6QE<R!I
M<R!T:&4@9FEL92!U<W5A;&QY(&=E;F5R871E9"!W:&5N(&5X<&]R=&EN9R!A
M(&ME>2!F<F]M(&$@8G)O=W-E<B`H92YG+B!);G1E<FYE="!%>'!L;W)E<BP@
M1FER969O>"D@;W(@9G)O;2!A(&-E<G1I9FEC871E('-T;W)E(&UA:6YT86EN
M960@8GD@86X@3W!E<F%T:6YG(%-Y<W1E;2`H92YG+B!7:6YD;W=S(%A0*2X@
M268@=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E9"!I
M;G1O('EO=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S
M93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T
M=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)S;6EM92UD96QE=&4M<&5R<V]N86PM8V5R=',B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@1&5L971E(%!E<G-O;F%L($-E
M<G1I9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N
M86P@0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE
M=&4@>6]U<B!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!Y;W5R('!R969E
M<F5N8V5S+B`@66]U('=I;&P@;F\@;&]N9V5R(&)E(&%B;&4@=&\@<VEG;B!3
M+TU)344@;65S<V%G97,@;W(@=FEE=R!A;GD@4R]-24U%(&5N8W)Y<'1E9"!M
M97-S86=E<R!A9&1R97-S960@=&\@>6]U+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<VUI;64M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I
M=&QE/@H@("`@/&AE861I;F<^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($UA;F%G92!Y;W5R(%,O34E-12!P
M=6)L:6,@:V5Y(&QI<W0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W('1H92!R87<@=&5X="!O
M9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E
M=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&5C:&YI8V%L
M(&1E=&%I;',@;V8@=&AE('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY$96QE=&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T
M97,@=&AE('-E;&5C=&5D('!U8FQI8R!K97D@9G)O;2!S=&]R86=E+B`@1&5L
M971I;F<@82!P=6)L:6,@:V5Y(&9O<B!A('5S97(@=VEL;"!P<F5V96YT('EO
M=7(@9G)O;2!E;F-R>7!T:6YG(&$@;65S<V%G92!T;R!T:&%T('5S97(N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<FEN=&EN9R(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')I;G1I;F<\+W1I=&QE/@H@("`@/&AE
M861I;F<^4')I;G0@82!M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4;R!P<FEN="!A(&UE<W-A9V4@>6]U(&%R92!V:65W:6YG+"!C;&EC:R!O
M;B!T:&4@(E!R:6YT(B!L:6YK(&%T(&5I=&AE<B!T:&4@=&]P(&]R(&)O='1O
M;2!O9B!T:&4@;65S<V%G92X@5&AE(&UE<W-A9V4@=VEL;"!O<&5N(&EN(&$@
M;F5W('=I;F1O=R!F;W)M871E9"!F;W(@<')I;G1I;F<N("!$97!E;F1I;F<@
M;VX@>6]U<B!W96(@8G)O=W-E<B!A;F0@;W!E<F%T:6YG('-Y<W1E;2P@=&AE
M('!R:6YT(&1I86QO9R!B;W@@;6%Y(&]P96X@9F]R('EO=2X@($EF(&ET(&1O
M97,@;F]T(&]P96XL('1H96X@<'5L;"!D;W=N('1H92!W96(@8G)O=W-E<B=S
M(")&:6QE(B!M96YU(&%N9"!C:&]O<V4@(E!R:6YT(B!T;R!O<&5N('1H92!P
M<FEN="!D:6%L;V<@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<V]R=&EN9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4V]R=&EN
M9R!A;F0@5&AR96%D:6YG/"]T:71L93X*("`@(#QH96%D:6YG/E-O<G1I;F<@
M16YT<FEE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5VAE;B!V:65W:6YG
M(&$@;&ES="!O9B!M97-S86=E<RP@>6]U(&-A;B!S;W)T('1H92!M97-S86=E
M<R!B>2!A;GD@8V]L=6UN(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T
M92!C;VQU;6X@:&5A9&EN9RX@(%1O('-W:71C:"!C;VQU;6YS(&)E='=E96X@
M87-C96YD:6YG(&%N9"!D97-C96YD:6YG(&]R9&5R+"!C;&EC:R!O;B!T:&4@
M87)R;W<@:6-O;B!I;B!T:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY4:')E861I;F<\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1O(&=R;W5P(&UE<W-A9V5S(&)Y('1H<F5A9',@*'-U8FIE8W0I+"!S
M;R!E86-H(&UE<W-A9V4@:7,@9W)O=7!E9"!W:71H(&%L;"!I=',@<F5P;&EE
M<RP@8VQI8VL@=&AE(%M4:')E861=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L
M=6UN(&AE861I;F<N("!4;R!R971U<FX@=&\@;F]R;6%L('-U8FIE8W0@<V]R
M=&EN9RP@8VQI8VL@;VX@=&AE(%M3=6)J96-T72!L:6YK(&EN('1H92!S=6)J
M96-T(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB86QT97)N871I=F4M;7-G(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y-=6QT:7!A<G0O06QT97)N871I=F4@365S<V%G97,\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!3;VUE(&UE<W-A9V4@:&%V92!B965N('-E;G0@87,@
M82`B;75L=&EP87)T+V%L=&5R;F%T:79E(B!T>7!E(&)Y('1H92!S96YD97(N
M(%1H97-E(&UE<W-A9V5S(&AA=F4@<V5V97)A;"!P87)T<RP@86QL(&1I<W!L
M87EI;F<@=&AE(%-!344@0T].5$5.5"!B=70@:6X@1$E&1D5214Y4($9/4DU!
M5%,N(%1H92!M86EL(&%G96YT('=I;&P@9&ES<&QA>2!T:&4@;&%S="!P87)T
M(&EN('1H92!L:7-T('1H870@8V%N(&)E('-U8V-E<W-F=6QL>2!D:7-P;&%Y
M960@:6YL:6YE(&EN('1H92!B<F]W<V5R+"!I9B!A;GDN($%L;"!O=&AE<B!F
M;W)M871S('=I;&P@87!P96%R('5N9&5R('1H92!H96%D:6YG(")!;'1E<FYA
M=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N(B!A;F0@8V%N(&)E('9I97=E
M9"!O<B!D;W=N;&]A9&5D('-E<&%R871E;'DN($ET(&ES(&EM<&]R=&%N="!T
M;R!N;W1E('1H870@=&AE<V4@86QT97)N871I=F4@<&%R=',@8V]N=&%I;B!T
M:&4@4T%-12!#3TY414Y44R!A<R!T:&4@<&%R="!T:&%T(&ES('-H;W=N("T@
M=&AE>2!A<F4@<VEM<&QY(&EN(&$@9&EF9F5R96YT(&UE9&EA(&9O<FUA="`H
M92YG+B!T97AT('9S+B!(5$U,(&]U='!U="DN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUR96YA;65?<V5N=&UA:6Q?;6]N=&AL
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!296YA;64@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L
M93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@
M=V]U;&0@;&EK92!T;R!R96YA;64@>6]U<B!S96YT+6UA:6P@9F]L9&5R(&%T
M('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&4@9F]L9&5R('=I
M;&P@8F4@<F5N86UE9"`H=&\@82!N86UE('1H870@8V]N=&%I;G,@=&AE(&UO
M;G1H(&%N9"!Y96%R*2!A;F0@82!N97<@<V5N="UM86EL(&9O;&1E<B!W:6QL
M(&)E(&-R96%T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@
M4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@
M("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!D
M96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T('1H92!B96=I;FYI;F<@
M;V8@979E<GD@;6]N=&@N("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA
M=F4@82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K
M965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($1E;&5T92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D@+2`C
M(&]F($9O;&1E<G,@=&\@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF
M('EO=2!A<F4@9&5L971I;F<@;VQD('-E;G0M;6%I;"!F;VQD97)S(&5V97)Y
M(&UO;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@;VQD(&9O;&1E<G,@9&\@>6]U
M("!W86YT('1O(&ME97`_("!!;GD@9F]L9&5R<R!O;&1E<B!T:&%N('1H:7,@
M;6%N>2!M;VYT:',@=VEL;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO
M;G1H;'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-
M86EN=&5N86YC93H@1&5L971E($QI;FME9"!!='1A8VAM96YT<R!-;VYT:&QY
M/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I
M9B!Y;W4@=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD(&QI;FME9"!A='1A8VAM
M96YT<R!A="!T:&4@8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AI<R!M
M87D@8F4@=7-E9G5L(&EF('EO=2!H879E(&$@<75O=&$L(&9O<B!E>&%M<&QE
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L
M971E7V%T=&%C:&UE;G1S7VUO;G1H;'E?:V5E<"(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN
M:V5D($%T=&%C:&UE;G1S($UO;G1H;'D@+2`C(&]F($UO;G1H<R!T;R!+965P
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O
M;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&5V97)Y(&UO;G1H+"!H;W<@;6%N>2!M
M;VYT:',@;V8@;VQD(&%T=&%C:&UE;G1S(&1O('EO=2`@=V%N="!T;R!K965P
M/R`@06YY(&%T=&%C:&UE;G1S(&]L9&5R('1H86X@=&AI<R!M86YY(&UO;G1H
M<R!W:6QL(&)E(&1E;&5T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:#PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($1O('EO=2!W86YT('1O('!U<F=E('EO
M=7(@=')A<V@@9F]L9&5R(&5V97)Y('-O(&]F=&5N+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:6YT97)V
M86PB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN
M=&5N86YC93H@4'5R9V4@5')A<V@@26YT97)V86P\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!)9B!Y;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L
M(&AO=R!O9G1E;B!S:&]U;&0@:70@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:V5E<"(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!0=7)G92!4<F%S:"!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@
M268@>6]U(&%R92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R+"!M97-S86=E
M(&]L9&5R('1H86X@:&]W(&UA;GD@9&%Y<R!S:&]U;&0@8F4@<'5R9V5D/PH@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB
M7W1E>'0B('-T871E/2)N97<B/@H@("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M365S<V%G92!#;VUP;W-I=&EO;CH@071T<FEB=71I;VX@5&5X=#PO=&ET;&4^
M"B`@("`@/'!A<F$^"B`@("`@2&5R92!Y;W4@8V%N(&5N=&5R('1H92!P:')A
M<V4@=&AA="!Y;W4@=VES:"!T;R!A<'!E87(@8F5F;W)E(&%N>2!Q=6]T960@
M=&5X="!I;B!A(')E<&QY('1H870@>6]U('-E;F0N"B`@("`@/"]P87)A/@H@
M("`@(#QP87)A/@H@("`@(%EO=2!C86X@:6YC;'5D92!O;F4@;W(@;6]R92!S
M<&5C:6%L('!L86-E:&]L9&5R<R!T;R!I;G-E<G0@:6YF;W)M871I;VX@86)O
M=70@=&AE(&UE<W-A9V4@=&\@=VAI8V@@>6]U(&%R92!R97!L>6EN9RX@4&QA
M8V5H;VQD97)S(&-O;G-I<W0@;V8@82`G)2<@9F]L;&]W960@8GD@82!S:6YG
M;&4@;&5T=&5R+B!4:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!A<F4@879A
M:6QA8FQE.@H@("`@(#PO<&%R83X*"B`@("`@/'!A<F$^("5F(#H@5&AE('-E
M;F1E<B=S(&YA;64@86YD(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A
M<F$^("5A(#H@5&AE('-E;F1E<B=S(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@
M("`@/'!A<F$^("5P(#H@5&AE('-E;F1E<B=S(&YA;64\+W!A<F$^"B`@("`@
M/'!A<F$^("5R(#H@5&AE(&9U;&P@4D9#(#(X,C(@<W1Y;&4@9&%T92!A;F0@
M=&EM92!Z;VYE/"]P87)A/@H@("`@(#QP87)A/B`E9"`Z(%1H92!D871E(&%S
M('=W=RP@9&0@;6UM(%E965D\+W!A<F$^"B`@("`@/'!A<F$^("5X(#H@5&AE
M(&1A=&4@:6X@=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A
M<F$^("5C(#H@5&AE(&1A=&4@86YD('1I;64@:6X@=&AE(&QO8V%L92=S(&1E
M9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^("5M(#H@5&AE($UE<W-A9V4M240\
M+W!A<F$^"B`@("`@/'!A<F$^("5S(#H@5&AE('-U8FIE8W0\+W!A<F$^"B`@
M("`@/'!A<F$^("5N(#H@02!N97<@;&EN93PO<&%R83X*("`@("`\<&%R83X@
M)24@.B!4:&4@)R4G(&-H87)A8W1E<CPO<&%R83X*"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7W)E860B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!297%U97-T(%)E860@
M4F5C96EP=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!A(%)E
M860@4F5C96EP="(@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G1S
M(&]F('1H:7,@;65S<V%G92!T;R!N;W1I9GD@>6]U('=H96X@=&AI<R!M97-S
M86=E(&ES(&]P96YE9"!B>2!T:&4@<F5C:7!I96YT<RX@3F]T(&%L;"!C;&EE
M;G1S('-U<'!O<G0@+R!H;VYO<B!T:&ES+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<V5N9%]M9&XB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!396YD($U$3CPO
M=&ET;&4^"B`@("`\<&%R83X*("`@(")396YD(&$@341.(B!S96YD<R!A($UE
M<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("AA;'-O(&MN;W=N(&%S
M(&$@<F5A9"!R96-E:7!T*2!W:&5N('EO=2!V:65W(&$@;65S<V%G92!I;B!W
M:&EC:"!T:&4@=7-E<B!H87,@<F5Q=65S=&5D('1H870@=&AE>2!R96-E:79E
M(&YO=&EF:6-A=&EO;B!T:&%T('EO=2!H879E(')E860@=&AE(&UE<W-A9V4N
M($EN(&UO<W0@8V%S97,L('1H:7,@=VEL;"!H87!P96X@875T;VUA=&EC86QL
M>2!W:71H;W5T('!R;VUP=&EN9R!Y;W4N($EN(&-E<G1A:6X@:7-O;&%T960@
M8V%S97,L('EO=2!M87D@:&%V92!T;R!M86YU86QL>2!D96-I9&4@=&\@<V5N
M9"!T:&4@;F]T:69I8V%T:6]N(&)Y(&-L:6-K:6YG(&]N(&$@;&EN:RX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET
M:6]N7W)E<75E<W1?9&5L:79E<GDB('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!297%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;CPO
M=&ET;&4^"B`@("`\<&%R83X*("`@(")297%U97-T($1E;&EV97)Y($-O;F9I
M<FUA=&EO;B(@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@<V5R=F5R('1O(&YO=&EF>2!Y;W4@=VAE;B!I="!H87,@9&5L:79E
M<F5D('1H92!M97-S86=E('1O('1H92!R96-I<&EE;G0G<R!M86EL8F]X+B!)
M="!D;V5S;B=T(&UE86X@=&AE(&UE<W-A9V4@:&%S(&)E96X@<V5E;BP@:G5S
M="!T:&%T(&ET)W,@<VET=&EN9R!I;B!A(&UA:6QB;W@@<V]M97=H97)E+B!.
M;W0@86QL(&UA:6P@<V5R=F5R<R!S=7!P;W)T('1H:7,N(`H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7W-P86U?869T
M97)?<F5P;W)T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@1&5L971E(%-P86T@069T97(@4F5P;W)T:6YG/"]T:71L93X*("`@(#QP
M87)A/@H@("`@66]U(&UA>2!E;&5C="!T;R!D;R!O;F4@;V8@=&AR964@:71E
M;7,@869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!E:71H97(@<W!A;2!O
M<B!I;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@1FER<W0L
M('EO=2!C86X@9&5C:61E('1O(&1O(&YO=&AI;F<@+2!T:&4@;65S<V%G92!W
M:6QL(&)E(')E<&]R=&5D(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C96YT(&)U
M="!W:6QL(&]T:&5R=VES92!R96UA:6X@=6YC:&%N9V5D(&EN('EO=7(@;6%I
M;&)O>"X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V5C;VYD+"!I9B!R
M97!O<G1I;F<@82!M97-S86=E(&%S('-P86TL('EO=2!C86X@:6YS=&5A9"!H
M879E('1H92!M97-S86=E(&)E(&EM;65D:6%T96QY(&1E;&5T960N("!4:&ES
M('-E='1I;F<@:&%S(&YO(&5F9F5C="!O;B!R97!O<G1I;F<@82!M97-S86=E
M(&%S(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!4:&ER
M9"P@869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!S<&%M('1H92!M97-S
M86=E('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@
M86YD(&UO=F5D('1O('EO=7(@<W!A;2!F;VQD97(N("!!;'1E<FYA=&EV96QY
M+"!I9B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT('1H92!M97-S
M86=E('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@
M86YD(&UO=F5D('1O('EO=7(@24Y"3U@N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUH=&UL7VEM86=E7W)E<&QA8V5M96YT(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G
M92!297!L86-E;65N=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($9O<B!(5$U,
M(&UE<W-A9V5S(&1I<W!L87EE9"!I;FQI;F4L('-H;W5L9"!A;&P@:6UA9V4@
M=&%G<R!B92!B;&]C:V5D('5N=&EL('EO=2!S<&5C:69I8V%L;'D@9&5C:61E
M('1O('9I97<@=&AO<V4@:6UA9V5S/R!.;W1E('1H870L(&EF('9I97=I;F<@
M86X@2%1-3"!A='1A8VAM96YT+"!T:&4@:6UA9V5S('=I;&P@86QW87ES(&)E
M(&1I<W!L87EE9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+6AT;6Q?:6UA9V5?861D<F)O;VLB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!(5$U,($EM86=E(%)E<&QA8V5M96YT+T%D
M9')E<W-B;V]K(%-H;W<\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!B;&]C
M:VEN9R!I;6%G97,@9F]R(&EN;&EN92!(5$U,(&UE<W-A9V5S+"!S:&]U;&0@
M=V4@875T;VUA=&EC86QL>2!D:7-P;&%Y('1H96T@:6YS=&5A9"!I9B!T:&4@
M<V5N9&5R(&%P<&5A<G,@:6X@>6]U<B!A9&1R97-S8F]O:S\*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A<G0B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EL8F]X
M(%-T87)T(%!A9V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S
M('=H:6-H('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=R!W:6QL(&)E(&1I<W!L
M87EE9"!W:&5N('EO=2!A8V-E<W,@82!M86EL8F]X(&9O<B!T:&4@9FER<W0@
M=&EM92X@3F]T92!T:&%T('1H92`G=6YS965N)R!M97-S86=E(&]P=&EO;G,@
M9&\@;F]T('=O<FL@=VET:"!T:&4@)U1H<F5A9"<@<V]R=&EN9R!O<'1I;VX@
M+2!I;G-T96%D+"!Y;W4@=VEL;"!B92!S96YT('1O('1H92!L87-T('!A9V4N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E
M7V%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@4V%V92!!='1A8VAM96YT<R!O;B!396YT($UE<W-A9V5S/"]T:71L
M93X*("`@(#QP87)A/@H@("`@268@<V%V:6YG(&$@8V]M<&]S960@;65S<V%G
M92!I;B!A('-E;G0M;6%I;"!F;VQD97(L(&1E=&5R;6EN92!I9B!A;&P@871T
M86-H;65N="!D871A(&ES('-A=F5D+B!4:&4@9F]L;&]W:6YG(&]P=&EO;G,@
M87)E(&%V86EL86)L93H*("`@(#PO<&%R83X*"B`@("`\<&%R83XJ(")!;'=A
M>7,@<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A
M='1A8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S
M(&%R92!!3%=!65,@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"B`@
M("`@/'!A<F$^*B`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I
M<R!S96YT.R!D969A=6QT('1O(%E%4R(@+2!!3%=!65,@<')O;7!T('1O('-A
M=F4@871T86-H;65N=',@:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F
M875L="!I<R!T;R!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R
M83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[
M(&1E9F%U;'0@=&\@3D\B("T@04Q705E3('!R;VUP="!T;R!S879E(&%T=&%C
M:&UE;G1S(&EN('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@:7,@
M=&\@;F]T('-A=F4@871T86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@
M(DYE=F5R('-A=F4@871T86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A
M=F4@871T86-H;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM
M96YT<R!A<F4@3D5615(@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7VEN8F]X(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@26YB
M;W@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)U=&%L($EN8F]X(&ES(&$@
M<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@=&\@
M<V5A<F-H(&5V97)Y(&UA:6QB;W@@9F]R(&UE<W-A9V5S(&UA<FME9"!A<R!N
M97<N("!);G-T96%D+"!A;&P@8W5R<F5N=&QY('-U8G-C<FEB960@;6%I;&)O
M>&5S(&%R92!S96%R8VAE9"!F;W(@;F5W(&UE<W-A9V5S(&%N9"!T:&4@<F5S
M=6QT<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7W1R87-H(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U
M86P@5')A<V@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)T=6%L(%1R87-H
M(&ES(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE
M960@9F]R(&$@<V5P87)A=&4@5')A<V@@9F]L9&5R+B`@26YS=&5A9"!O9B!M
M;W9I;F<@;65S<V%G97,@=&\@82!C96YT<F%L:7IE9"!T<F%S:"!F;VQD97(L
M(&UE<W-A9V5S(&%R92!S:6UP;'D@;6%R:V5D(&%S(&1E;&5T960@:6X@=&AE
M(&-U<G)E;G0@9F]L9&5R('1H97D@;&EV92!I;BX@(%=H96X@)W-H;W<@9&5L
M971E9"!M97-S86=E<R<@:7,@='5R;F5D(&]F9BP@=&AI<R!R97-U;'1S(&EN
M('1H97-E(&UE<W-A9V5S(&YO="!A<'!E87)I;F<@:6X@82!M86EL8F]X('9I
M97<N("!7:&5N(&$@=7-E<B!C;&EC:W,@;VX@5FER='5A;"!4<F%S:"P@*F%L
M;"H@;6%I;&)O>&5S(&%L;"!S96%R8VAE9"!F;W(@;65S<V%G97,@=&AA="!A
M<F4@9FQA9V=E9"!D96QE=&5D(&%N9"!T:&5S92!M97-S86=E<R!A<F4@9&ES
M<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"CPO:&5L<#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O;FY?3D\O````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-C,`,#$W-#8P`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+VQO8V%L92]N;E].3R],0U]-15-304=%4R\`````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,C$R-#4`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+VYN7TY/+TQ#7TU%4U-!1T53+VEM
M<"YM;P```````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3$P-C(R`#$P-#$W,S8R-S8S
M`#`R,C,V-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#>$@25`````!,"```<````M!```,4"``!,(0```````&`L```*````
M82P```H```!L+```"@```'<L```*````@BP```0```"-+````0```)(L```7
M````E"P```L```"L+```*````+@L```5````X2P``#(```#W+```,@```"HM
M```;````72T``"X```!Y+0``-P```*@M``!\````X"T``!P```!=+@``'0``
M`'HN```(````F"X```4```"A+@``#P```*<N```#````MRX```\```"[+@``
M"````,LN```(````U"X``!D```#=+@``!P```/<N```,````_RX```X````,
M+P``!0```!LO```#````(2\``$X````E+P``4````'0O``!"````Q2\``!\`
M```(,```"````"@P```1````,3```#````!#,```2````'0P```A````O3``
M`#L```#?,```*P```!LQ```Q````1S$```P```!Y,0``"0```(8Q```Y````
MD#$```8```#*,0``-0```-$Q```.````!S(```H````6,@``"P```"$R```G
M````+3(``"P```!5,@``*@```((R```1````K3(```H```"_,@```P```,HR
M```(````SC(```D```#7,@``!````.$R```$````YC(``"<```#K,@``!@``
M`!,S```.````&C,``!4````I,P``/@```#\S```"````?C,```H```"!,P``
M!@```(PS```*````DS,``%\```">,P``'````/XS```.````&S0``!$````J
M-```#````#PT```1````230```T```!;-```#````&DT```4````=C0```\`
M``"+-```!P```)LT```'````HS0``!<```"K-```$````,,T```K````U#0`
M`%P`````-0``!````%TU```'````8C4```X```!J-0``'@```'DU```;````
MF#4``!L```"T-0``,P```-`U``!!````!#8``"\```!&-@``*0```'8V```&
M````H#8```T```"G-@``"P```+4V```:````P38``!T```#<-@``&0```/HV
M``!=````%#<``"@```!R-P```@```)LW```%````GC<```0```"D-P``$```
M`*DW```9````NC<``!H```#4-P``!@```.\W```4````]C<``!,````+.```
M$````!\X```'````,#@``!`````X.```'````$DX```*````9C@``!0```!Q
M.```!P```(8X```O````CC@```\```"^.```!P```,XX```/````UC@``"T`
M``#F.```&@```!0Y```C````+SD``"8```!3.0``(````'HY```$````FSD`
M`!(```"@.0``!0```+,Y```.````N3D```X```#(.0``!````-<Y```6````
MW#D```4```#S.0``#0```/DY```/````!SH``!(````7.@``#0```"HZ```9
M````.#H``!4```!2.@``$````&@Z```I````>3H``"P```"C.@``*````-`Z
M```%````^3H``!````#_.@``$````!`[```/````(3L```L````Q.P``#P``
M`#T[```,````33L```\```!:.P``"@```&H[```2````=3L```T```"(.P``
M#````)8[```>````HSL``"$```#".P```P```.0[```*````Z#L``"````#S
M.P``#````!0\```'````(3P```0````I/```"@```"X\```0````.3P```<`
M``!*/```"````%(\```1````6SP``!D```!M/```!````(<\```,````C#P`
M``0```"9/```%````)X\```&````LSP```<```"Z/```!````,(\```,````
MQSP``!$```#4/```!````.8\```-````ZSP```<```#Y/```#`````$]```*
M````#CT```4````9/0``)P```!\]```$````1ST```T```!,/0``&P```%H]
M```,````=CT```4```"#/0``!@```(D]```*````D#T```H```";/0``#@``
M`*8]```.````M3T``!\```#$/0``'@```.0]```1`````SX``!4````5/@``
M"0```"L^```2````-3X``!(```!(/@``$````%L^```D````;#X``!P```"1
M/@``(P```*X^```B````TCX``!8```#U/@``"P````P_```A````&#\``"``
M```Z/P``"@```%L_```(````9C\```D```!O/P``$````'D_```5````BC\`
M`!H```"@/P``#@```+L_```&````RC\```P```#1/P``!P```-X_```+````
MYC\```,```#R/P``#````/8_```&`````T````(````*0```)0````U````'
M````,T````@````[0```-P```$1````/````?$````<```",0```$P```)1`
M```,````J$````X```"U0```#````,1````.````T4````\```#@0```#0``
M`/!````/````_D```!H````.00``)@```"E!```+````4$$```D```!<00``
M!@```&9!```'````;4$```0```!U00``$@```'I!```$````C4$``"(```"2
M00``!P```+5!```%````O4$```,```##00``"````,=!```,````T$$```0`
M``#=00``#````.)!```)````[T$```(```#Y00``$@```/Q!```;````#T(`
M`!4````K0@``,P```$%"```9````=4(``!0```"/0@``)0```*1"```D````
MRD(``!(```#O0@``#@````)#```:````$4,```0````L0P``!@```#%#```+
M````.$,```D```!$0P``#0```$Y#```,````7$,``!<```!I0P``%````(%#
M```6````ED,```4```"M0P```@```+-#```,````MD,``",```##0P``!P``
M`.=#```1````[T,```T````!1````P````]$```T````$T0```L```!(1```
M%````%1$```^````:40``#0```"H1```,0```-U$```2````#T4``!`````B
M10``&````#-%```G````3$4``%8```!T10``30```,M%```$````&48``!L`
M```>1@``#````#I&```-````1T8```<```!51@``"@```%U&```2````:$8`
M`"$```![1@``"P```)U&```<````J48``!@```#&1@``"````-]&```5````
MZ$8``!X```#^1@``*````!U'```+````1D<``!H```!21P``"````&U'```4
M````=D<``"P```"+1P``)P```+A'```%````X$<``#$```#F1P``*````!A(
M```:````04@``"@```!<2```*0```(5(```N````KT@``#8```#>2```+```
M`!5)```Q````0DD``"$```!T20``$````)9)```-````ITD```4```"U20``
M"````+M)```3````Q$D```D```#820``+P```.))```R````$DH```T```!%
M2@``%@```%-*```$````:DH```@```!O2@``$````'A*```5````B4H``!,`
M``"?2@``!P```+-*```5````NTH```L```#12@``%@```-U*```/````]$H`
M``8````$2P``"P````M+```Z````%TL```T```!22P``!0```&!+```,````
M9DL```T```!S2P``#0```(%+```.````CTL```H```">2P``!@```*E+```.
M````L$L```4```"_2P``!@```,5+``!+````S$L```H````83```#````"-,
M```'````,$P``#D````X3```!@```'),```.````>4P```0```"(3```!@``
M`(U,```*````E$P``!$```"?3```"P```+%,```:````O4P``!<```#83```
M%P```/!,```;````"$T``!D````D30``'P```#Y-```,````7DT``!,```!K
M30``$0```']-```&````D4T```<```"830``0P```*!-```R````Y$T``#D`
M```73@``!````%%.```0````5DX```P```!G3@``%````'1.```=````B4X`
M`!$```"G3@``*````+E.```$````XDX``!````#G3@``%P```/A.```2````
M$$\```L````C3P``#0```"]/```4````/4\``"\```!23P``!@```()/```'
M````B4\```T```"13P``!@```)]/```6````ID\```<```"]3P``"P```,5/
M```%````T4\``"\```#73P``!`````=0```Q````#%```"(````^4```(```
M`&%0```S````@E```#@```"V4```'@```.]0``!U````#E$``#X```"$40``
M0@```,-1```]````!E(``"D```!$4@``*0```&Y2```Q````F%(``#P```#*
M4@``*`````=3```F````,%,``#X```!74P``1P```)93``!7````WE,``%4`
M```V5```1@```(Q4```O````TU0``%4````#50``*P```%E5```P````A54`
M`#L```"V50``50```/)5```O````2%8``"D```!X5@``#P```*)6```A````
MLE8``!P```#45@``"P```/%6```%````_58```(````#5P``#0````97```#
M````%%<``"`````85P``)@```#E7```*````8%<``!,```!K5P``"````']7
M```6````B%<```P```"?5P``$0```*Q7```'````OE<```8```#&5P``&@``
M`,U7```&````Z%<```8```#O5P``$0```/97```3````"%@```P````<6```
M"````"E8```)````,E@``!0````\6```!````%%8```'````5E@``!(```!>
M6```&0```'%8```8````BU@``"<```"D6```!@```,Q8```-````TU@```L`
M``#A6```#````.U8```*````^E@```(````%60``!@````A9```#````#UD`
M``P````360``(0```"!9```D````0ED``!T```!G60``&0```(59```7````
MGUD``"H```"W60``*P```.)9``!%````#EH``$L```!46@``)P```*!:```I
M````R%H``"$```#R6@``*P```!1;```=````0%L``"8```!>6P``)0```(5;
M```]````JUL``$$```#I6P``*````"M<```L````5%P``#````"!7```$```
M`+)<```)````PUP``!P```#-7```$````.I<```/````^UP```X````+70``
M<P```!I=```?````CET```\```"N70``#````+Y=```0````RUT```\```#<
M70``!````.Q=```$````\5T```(```#V70``#@```/E=```/````"%X```4`
M```87@``8`$``!Y>```*````?U\```H```"*7P``"@```)5?```*````H%\`
M``,```"K7P```0```*]?```9````L5\```H```#+7P``*````-9?```4````
M_U\``#P````48```,0```%%@```;````@V```#4```"?8```4````-5@``"@
M````)F$``"(```#'80``$@```.IA```(````_6$```4````&8@``#@````QB
M```(````&V(``!,````D8@``#````#AB```/````16(``!X```!58@``!P``
M`'1B```*````?&(```X```"'8@``!0```)9B```$````G&(``$8```"A8@``
M4````.AB``!0````.6,``",```"*8P``"````*YC```9````MV,``#L```#1
M8P``3`````UD```F````6F0``#P```"!9```+````+YD```O````ZV0```L`
M```;90``"````"=E```[````,&4```@```!L90``.@```'5E```,````L&4`
M``<```"]90``!P```,5E```M````S64``"\```#[90``+@```"MF```3````
M6F8```X```!N9@``"@```'UF```'````B&8```H```"09@``!0```)MF```%
M````H68``"T```"G9@``!@```-5F```.````W&8``!4```#K9@``/0````%G
M```$````/V<```P```!$9P``!0```%%G```*````5V<``%,```!B9P``'```
M`+9G```-````TV<``!8```#A9P``#@```/AG```4````!V@```L````<:```
M#P```"AH```6````.&@``!````!/:```"0```&!H```%````:F@``!0```!P
M:```$````(5H```K````EF@``&(```#":```!@```"5I```(````+&D```\`
M```U:0``'0```$5I```@````8VD``!P```"$:0``,````*%I```I````TFD`
M`#8```#\:0``+````#-J```'````8&H```P```!H:@``#@```'5J```:````
MA&H``!\```"?:@``'P```+]J```5````WVH``#<```#U:@```@```"UK```&
M````,&L```0````W:P``$0```#QK```=````3FL``!\```!L:P``!0```(QK
M```9````DFL``!8```"L:P``#P```,-K```&````TVL``!````#::P``(0``
M`.MK```(````#6P``!$````6;```"````"AL```F````,6P```\```!8;```
M`P```&AL```1````;&P``"P```!^;```$P```*ML```B````OVP``",```#B
M;```%@````9M```&````'6T``!$````D;0``!0```#9M```,````/&T```T`
M``!);0``!0```%=M```8````76T```8```!V;0``#0```'UM```,````BVT`
M``X```"8;0``#@```*=M```:````MFT``!D```#1;0``%@```.MM```F````
M`FX``"X````I;@``)0```%AN```$````?FX``!````"#;@``$````)1N```/
M````I6X```\```"U;@``#P```,5N```,````U6X``!````#B;@``"````/-N
M```/````_&X```D````,;P``#P```!9O```?````)F\``",```!&;P``!```
M`&IO```+````;V\``!H```![;P``#0```)9O```&````I&\```0```"K;P``
M"P```+!O```/````O&\```H```#,;P``"P```-=O```3````XV\``!P```#W
M;P```P```!1P```+````&'````,````D<```%````"AP```'````/7````T`
M``!%<```!0```%-P```,````67```!(```!F<````P```'EP```-````?7``
M``8```"+<```#P```))P```/````HG````4```"R<```'````+AP```$````
MU7````T```#:<```'0```.AP```/````!G$```<````6<0``!P```!YQ```,
M````)G$```\````S<0``$@```$-Q```3````5G$``"0```!J<0``)P```(]Q
M```9````MW$``!T```#1<0``!@```.]Q```1````]G$``!,````(<@``$```
M`!QR```B````+7(``"(```!0<@``)@```'-R```I````FG(``!D```#$<@``
M$P```-YR```C````\G(``"<````6<P``#````#YS```%````2W,```H```!1
M<P``$@```%QS```7````;W,``"````"'<P``$````*AS```(````N7,```\`
M``#"<P``!P```-)S```7````VG,```,```#R<P``#0```/9S```&````!'0`
M``(````+=```)0````YT```)````-'0```L````^=```+0```$IT```0````
M>'0```D```")=```#0```)-T```,````H70```L```"N=```$````+IT```.
M````RW0```X```#:=```#0```.ET```.````]W0```X````&=0``)````!5U
M```-````.G4```D```!(=0``"@```%)U```(````774```4```!F=0``%0``
M`&QU```$````@G4``"X```"'=0``"````+9U```%````OW4```(```#%=0``
M"0```,AU```-````TG4```4```#@=0``#0```.9U```*````]'4```,```#_
M=0``&P````-V```E````'W8``!(```!%=@``.````%AV```?````D78``!H`
M``"Q=@``+````,QV```O````^78```\````I=P``#0```#EW```@````1W<`
M``4```!H=P``!@```&YW```,````=7<```L```""=P``#````(YW```/````
MFW<``"(```"K=P``%@```,YW```7````Y7<```<```#]=P```@````5X```/
M````"'@``"@````8>```"@```$%X```1````3'@``!````!>>````P```&]X
M```Y````<W@```X```"M>```'@```+QX```^````VW@``#$````:>0``*@``
M`$QY```8````=WD``!(```"0>0``&P```*-Y```I````OWD``%8```#I>0``
M1P```$!Z```$````B'H``!T```"->@``#P```*MZ```-````NWH```<```#)
M>@``#````-%Z```4````WGH``!L```#S>@``#0````][```B````'7L``!T`
M``!`>P``!P```%Y[```5````9GL``!P```!\>P``+````)E[```'````QGL`
M`!8```#.>P``"0```.5[```5````[WL``"8````%?```(0```"Q\```'````
M3GP``"D```!6?```(@```(!\```9````HWP``"4```"]?```)````.-\```P
M````"'T``#8````Y?0``'````'!]```G````C7T``!X```"U?0``#P```-1]
M```,````Y'T```@```#Q?0``"0```/I]```6````!'X```H````;?@``,0``
M`"9^```O````6'X```P```"(?@``&0```)5^```#````KWX```D```"S?@``
M$0```+U^```8````SWX``!<```#H?@``"0````!_```8````"G\```\````C
M?P``$0```#-_```2````17\```4```!8?P``"0```%Y_``!`````:'\```P`
M``"I?P``!````+9_```-````NW\```X```#)?P``#@```-A_```/````YW\`
M``H```#W?P``!0````*````7````"(````D````@@```"0```"J```!0````
M-(````L```"%@```$````)&````)````HH```#0```"L@````P```.&````,
M````Y8````0```#R@````P```/>````(````^X````T````$@0``"0```!*!
M```9````'($```\````V@0``#P```$:!```8````5H$``!````!O@0``$```
M`("!```,````D8$``!,```">@0``%0```+*!```%````R($```8```#.@0``
M2````-6!```U````'H(``$D```!4@@```P```)Z"```6````HH(```H```"Y
M@@``&@```,2"```>````WX(``!````#^@@``(0````^#```(````,8,``!4`
M```Z@P``&@```%"#```,````:X,```T```!X@P``#0```(:#```4````E(,`
M`"T```"I@P``!@```->#```$````WH,```@```#C@P``!````.R#```4````
M\8,```<````&A```!P````Z$```(````%H0``#0````?A```!0```%2$```I
M````6H0``!D```"$A```&````)Z$```Y````MX0``#4```#QA```'@```">%
M``!G````1H4``#@```"NA0``.0```.>%```W````(88``!D```!9A@``%P``
M`'.&```?````BX8``#D```"KA@``&0```.6&```I````_X8``#(````IAP``
M.0```%R'``!)````EH<``$<```#@AP``/@```"B(```I````9X@``$<```"1
MB```)@```-F(```T`````(D``#\````UB0``4````'6)```K````QHD``",`
M``#RB0``$@```!:*```>````*8H``!X```!(B@``"@```&>*```&````<HH`
M``,```!YB@``"P```'V*```#````B8H``!X```"-B@``*````*R*```(````
MU8H``!,```#>B@``"P```/**```/````_HH```\````.BP``%````!Z+```)
M````,XL```4````]BP``'@```$.+```(````8HL```@```!KBP``$@```'2+
M```4````AXL``!````"<BP``"@```*V+```+````N(L``!0```#$BP```P``
M`-F+```&````W8L``!<```#DBP``&P```/R+```>````&(P``#<````WC```
M"0```&^,```/````>8P```P```")C```#P```):,```/````IHP```(```"V
MC```!0```+F,```"````OXP```X```#"C```'@```-&,```?````\(P``!@`
M```0C0``&````"F-```4````0HT``"$```!7C0``(@```'F-```Z````G(T`
M`%(```#7C0``'@```"J.```H````28X``!T```!RC@``(P```)".```?````
MM(X``"H```#4C@``+0```/^.```U````+8\``$0```!CCP``%P```*B/```C
M````P(\``#(```#DCP``#P```!>0```)````)Y```"(````QD```$@```%20
M```5````9Y````T```!]D```>0```(N0```F````!9$```T````LD0``"P``
M`#J1```0````1I$``!````!7D0```P```&B1```%````;)$```4```!RD0``
M"0```'B1```)````@I$```4```",D0```0```"T```#"`````@$`````````
M`@``*@$````````0`@``R````)@!``!8`0```````&8```!I````3P$``#T!
M``````````````$"````````````````````````7P$``%L```#,````%`$`
M`+X!``#,`0````````````"W`0``=P```'(!```'````[P$``+X`````````
M`````%8!``"=`0``(````)<!````````W0````````#@`0``PP```(D```#[
M`0``Q@```!X```!#````MP```#@!```%`@``<0$```````"7````A@``````
M```_````(P$``)H```!<`0``%@````````!_`````````%D!``#4`0``?```
M`+T```!N`````````,`!```N````V0```.4`````````&0```(\!```:````
M3@```+H!``"X`0```````)\!``"-`0```````'D!``!3`````````*@```#I
M`0``/@````````"A`0```````'L```#.`````````(<```"8````````````
M````````-`$``"T!````````X@$``-\!``!T`0``;0$``&D!````````L```
M`.T```"'`0```````*X```"&`0``#P$``&P!``#F````]P$``)(`````````
MV@`````````[`0``0@```,``````````#P(``(X!``#S````50````````#L
M`0```````*\````,`0``B0$``#H````F````)0$``%4!```K`````````%``
M`````````````'X```#7````_0````\``````````````%D`````````=P$`
M`(H```"S````!````-L```!2````9`$``$0!``#<`0``#````+4```#^````
M)@$``)4!``#J````L0$``.L!``"9`0``K`````````"\`````````!P!```P
M`0``5P````X```"(```````````````D````90```*$```"@`0```````'T`
M``#Q````TP```$8!````````"P(`````````````)`$``)D```"$````I0``
M`%$`````````$0(``.X````"`@`````````````I`0`````````````=````
M!@````4```"4`0``"0$``.0```#D`0``:````!,"``"Y````$P```$@```!C
M`````````/@!```2`0``70$```````"1````]@$``-$!``"/````N````,X!
M```G`0``\`$``"\!```O````^0$``,@!``!X````:`$``&8!``#5`0``E@``
M````````````\@$``((`````````G````)P!``"?````I@```/@`````````
MQ`$`````````````C````-\```"M`0``80`````!``"Z`````````&,!``#Z
M`0````````````#A`0``P0```.8!````````E0```+P!``"Y`0``J`$``'`!
M````````>@$``!(````S````,@```-0```"I````\@```)X!```I````#`(`
M`&4!``#$`````0$``%T````#`0``L`$``+,!``#B`````````!\`````````
M`````*<```#6````1@```/0`````````:P`````````4````1P$``*<!````
M````^P````````!Z````FP```$<```#%`0```````*,!````````H```````
M``"]`0```````*L!``"+````'0$```````"V`0``;````!$```"T`0``6@``
M``````!"`0``40$``!,!``!+`0``XP$``&(`````````0````(4!````````
M`````/8`````````Q0```+\```#+````3@$``$D!``"-````(@$````````2
M`@``]0```.@!```U````@P$``.P```"V````6P$```````!#`0``````````
M`````````````$4`````````9``````````Q`0``W@````D```#!`0``-@``
M`'P!```H````@P```.<!```V`0``2@```*(!````````E@$``!$!````````
M[@$``(@!``!Q````@@$``.D```!G````#@$``*X!``#P````8@$``-P`````
M````7````%0!```$`@````````D"``#O``````````````!S`````````.``
M```T`````````(````"F`0``=@````<!``#-````0`$```8!````````&@$`
M`!````#0`0``JP``````````````8`$``!L```#*````NP$``%X```"%````
M'`````````#S`0``:@````@"``"C````PP$``-D!````````@0$``-$`````
M````QP```/<````Z`0``,@$``,H!```G````1```````````````+@$```T"
M``!T````"P```+4!```5`0``D````$P!````````OP$``````````````@``
M`$@!````````(`$``&\```!P````/P$``.T!``"Q````20````````!%`0``
M>P$``.4!``#K``````````````#G````TP$```````#Y``````````````!X
M`0``E````/T!``!3`0``-P````````!N`0``C`$```````"J`0``+`$`````
M```\````R0$``$$```"E`0``30$`````````````RP$``%0```!K`0``````
M`#````#\`0``V`````````"R`0``#0$``-L!``"3`0``3`````````#0````
M-0$```````"D`0```````+(```#-`0```````&H!``!+````3P`````````Q
M`````````/$!```9`0``D0$``%`!````````J0$``&\!```>`0``R0```"@!
M``!!`0``DP```-4```#/`0``?P$````````&`@```````#<!```]````UP$`
M```````J````K`$``!`!````````'P$``(0!``#"`0``=@$``'D```!G`0``
M/`$````````Y````7P```'(`````````/@$``%8`````````"P$``/P```"*
M`0````````,`````````J@`````````K`0``M````)(!````````6````'T!
M````````%@$``)`!``#J`0``W0$``&`````-`````````-(`````````````
M`"$!``#&`0``%P`````````[````NP````````````````````````#2`0``
MSP```"$`````````+````&$!```*`0``&`````````".````V@$```````"O
M`0```````',!```#`@``]`$``%<!`````````````$H!``#>`0```````/X!
M```X````F@$```H"```(`0``QP$````````7`0````````````#H````G0``
M````````````FP$``/\```"``0```````"4```">````"```````````````
M;0````H```"B``````````````#C````6@$`````````````X0````4!``#Z
M````30```!4````;`0``V`$``/4!```C````U@$```X"````````7@$``#,!
M``!^`0``!P(``%(!```B````BP$``($`````````K0`````````$`0``=0$`
M`#D!``#_`0``=0```*0`````````&`$````@("`@("!4;SH@`"`@("!$871E
M.B``("`@($9R;VTZ(``@4W5B:F5C=#H@`"!I;B``(P`E9"!T;R`E9"!O9B`E
M9"!-97-S86=E<P`E<R`M($YO=&EC90`E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A
M;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA;65D
M+@`E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE
M(&UO;G1H+@`E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"D`*$%P<&QY('1H
M97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*0`H1&ES8V%R
M9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E
M;BXI`"A2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY
M:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H
M92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@
M=&AE<V4@8GD@8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S
M<RAE<RD@*@`R-"!H;W5R<P!!32]030!!8V-O=6YT)W,@;F%M93H`061D`$%D
M9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T
M:6]N`$%L:6%S`$%L;`!!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F
M;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@9FEL
M93H`06QL(&UE<W-A9V5S(&EN('EO=7(@(B5S(B!F;VQD97(@;VQD97(@=&AA
M;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E9"X`06QL(&]L
M9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W
M:6QL(&)E(&1E;&5T960N`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`06YS=V5R960`06YS=V5R960@;65S<V%G97,`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.
M3U0@<F5C;VUM96YD960A*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@
M=&AI<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E
M;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&5M<'1Y('1H:7,@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M96UP='D@>6]U<B!T<F%S:"!F;VQD97(_`$%R<FEV86P@5&EM90!!<V-E;F1I
M;F<`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_`$%T=&%C:`!!='1A8V@@82!C;W!Y(&]F('EO=7(@
M4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/P!!='1A8VAE9"!&:6QE
M.@!!='1A8VAM96YT`$%T=&%C:&UE;G1S`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`079A:6QA8FQE(&9I96QD<SH`0F%C:R!T;R`E
M<P!"8V,`0FER=&AD87D`0FQA8VML:7-T`$)O9'D`0F]T:`!";W1H($AE861E
M<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4`0V%N8V5L`$-A;F-E;"!-
M97-S86=E`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YC96QL:6YG('1H:7,@
M;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S
M+@!#8P!#96QL(%!H;VYE`$-H86YG90!#:&%N9V4@06QL`$-H86YG92!T:&4@
M;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6PN`$-H96-K
M($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAO;W-E($%C=&EO;CH`0VQI8VL@
M=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-L;W-E('1H:7,@=VEN9&]W`$-L
M;W-E9"!&;VQD97(`0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&;VQD97)S
M`$-O;&QA<'-E($9O;&1E<@!#;VUM96YT`$-O;7!A;GD`0V]M<&]S92!A;F]T
M:&5R(&UE<W-A9V4`0V]N9FER;2!087-S=V]R9`!#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;G1R;VP@=VAE;B!N97<@
M;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@
M=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O<'D`0V]R<F5C=`!#
M;W)R96-T960@5&5X=`!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E
M<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="X`0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0W)E871E
M`$-R96%T92!&;VQD97(`0W)E871E($ME>7,`0W)E871E(&$@;F5W(&1R869T
M<R!F;VQD97(`0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(`0W)E871E
M(&$@;F5W('1R87-H(&9O;&1E<@!#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O
M(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O
M;&1E<G,L(&%N9"!D96QE=&4@<W!A;2X`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!$1`!$86EL>0!$871E`$1E9F%U;'0@261E
M;G1I='D`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I
M;F<@9&ER96-T:6]N.@!$96QE=&4`1&5L971E("5S(%!U8FQI8R!+97D`1&5L
M971E($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E;&5T960`1&5L
M971E9"!M97-S86=E<P!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E
M<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<P!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:6T@
M<VEG;F%T=7)E<S\`1&ES<&QA>0!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!C
M;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_`$1I<W!L87D@
M:6X@0F]D>2!O9B!-97-S86=E`$1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R
M($YE=R!-86EL`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD97(_`$1O;F4`1&]W
M;FQO860@1F]L9&5R*',I`$1R869T`$1R869T<R!F;VQD97(Z`$4M;6%I;"!!
M9&1R97-S`$5D:70`161I="!Y;W5R(&9I;'1E<B!R=6QE<P!%;6%I;`!%;6%I
M;"!!9&1R97-S`$5M<'1Y($9O;&1E<BAS*0!%;7!T>2!4<F%S:"!F;VQD97(`
M16UP='D@<F5S=6QT+@!%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_`$5N9"!F
M;W)W87)D960@;65S<V%G90!%;G1E<B!087-S<&AR87-E`$5N=&5R('1H92!N
M86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(`17)R;W(`179E<GD@,34@;6EN
M=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,
M;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L
M=65S.@!%>'!A;F0@06QL`$5X<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L
M9&5R`$5X<&%N9"!.86UE<P!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&971C
M:"!-86EL`$9E=&-H($UA:6P@:6X@82!S97!A<F%T92!W:6YD;W<_`$9I;&4@
M36%N86=E<@!&:6QT97)S`$9I;F0`1FER<W0@4&%G90!&;VQD97(@3F%V:6=A
M=&]R`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R
M9&5D(&UE<W-A9V4@9G)O;2`E<P!&<F]M`$9R;VT@061D<F5S<P!&=V0Z`$=R
M;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P<P!(96%D97)S`$AE;'``2&ED92!$
M96QE=&5D`$AI9&4@56YS=6)S8W)I8F5D`$AI9V@`2&EG:"!0<FEO<FET>0!(
M:6=H97-T`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO=R!D;R!Y
M;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/P!)34%0`$E-05`@;W9E
M<B!34TP`24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960I`$E-05`L(&YO(%1,
M4P!)3D)/6`!)9VYO<F4`26=N;W)E($%L;`!);7!O<G0@2V5Y`$EM<&]R="!+
M97EP86ER`$EM<&]R="!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!0<FEV871E
M(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y`$EM<&]R
M="!0=6)L:6,@2V5Y`$EM<&]R="!0=6)L:6,@4$=0($ME>0!);7!O<G1A;G0`
M26UP;W)T86YT(&UE<W-A9V5S`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY
M/P!);F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y`$EN9F]R;6%T:6]N(&]N
M(%!E<G-O;F%L(%!R:79A=&4@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L
M(%!U8FQI8R!+97D`26YV86QI9"!296UO=&4@36%I;&)O>`!);G9A;&ED(&ME
M>0!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2X`26YV86QI9"!P
M97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`2V5Y($QE;F=T:`!,86YG=6%G90!,
M87-T(%!A9V4`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG(&EN('1H92!(96%D
M97(`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]C86P@36%I;&)O>#H`
M3&]G(&EN`$QO9R!I;B!T;R`E<P!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO=P!,
M;W<@4')I;W)I='D`3&]W97-T`$U-`$U3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82X`36%I;&)O>`!-87)K(&%S.@!-87)K(&1I9F9E<F5N
M="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA
M=&-H:6YG(&9I96QD<P!-96UB97)S`$UE<W-A9V4@0V]M<&]S:71I;VX`365S
M<V%G92!$871E`$UE<W-A9V4@4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S86=E
M(%-O=7)C90!-97-S86=E(%9I97=I;F<`365S<V%G92!F;&%G<P!-97-S86=E
M(&9O;&1E<G,`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2X`365S<V%G97,@
M<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`36EM
M92!4>7!E`$UO9&EF>0!-;VYT:&QY`$UO=F4`3D\L($D@1&\@3D]4($%G<F5E
M`$YA;64`3F%M92!A;F0O;W(@96UA:6P@8V%N(&YO="!B92!E;7!T>0!.971W
M;W)K`$YE=F5R`$YE=P!.97<@36%I;`!.97<@;65S<V%G97,`3F5X=`!.97AT
M($UE<W-A9V4`3F5X="!086=E`$YO`$YO($ME>7,@:6X@2V5Y<FEN9P!.;R!0
M1U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@871T86-H;65N=',@9F]U;F0N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+@!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&UE<W-A9V4@
M8F]D>2!T97AT`$YO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E
M9"X`3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N`$YO('-P
M96QL:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N<P!.;R!V86QI9"!834P@9&%T
M82!R971U<FYE9`!.;VYE`$YO<FUA;`!.;W0@1&5L971E9`!.;W0@1')A9G0`
M3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&$@=F%L:60@<'5B;&EC
M(&ME>2X`3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&]R=&%N="!M97-S
M86=E<P!.;W1E<P!/2P!/;&0@;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD
M97)S(&)E:6YG('!U<F=E9"X`3W!T:6]N<P!/=&AE<B!);F9O<FUA=&EO;@!/
M=&AE<B!/<'1I;VYS`%!'4`!01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F
M;W(@<&5R<V]N86P@<')I=F%T92!K97DN`%!'4"!/<'1I;VYS`%!'4"!087-S
M<&AR87-E($EN<'5T`%!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q
M=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%!'4"!0=6)L:6,@2V5Y
M(&9O<B`B)7,@*"5S*2(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0(%!U
M8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!0
M1U`@4'5B;&EC($ME>7)I;F<`4$=0(%-I9VX@365S<V%G90!01U`@4VEG;B]%
M;F-R>7!T($UE<W-A9V4`4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI
M<R!S>7-T96TN`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E
M('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@=F5R
M:69I960N`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O
M('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N`%!/4#,`
M4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I`%!/4#,L(&YO(%1,4P!086=E
M("5D(&]F("5D`%!A<G0H<RD`4&%S<W!H<F%S90!087-S<&AR87-E("A!9V%I
M;BD`4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@=6YL;V%D960N`%!A<W-P:')A
M<V4Z`%!A<W-P:')A<V5S(&-A;B!N;W0@8F4@96UP='D`4&%S<W!H<F%S97,@
M9&\@;F]T(&UA=&-H`%!A<W-W;W)D`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N<P!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;`!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2X`
M4&AO;F4`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD
M(&9O<G=A<F1S/P!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F
M;VQD97(Z`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E<V]L=F4@86UB
M:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+@!0;&5A<V4@<V5L96-T(&$@
M9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RX`4&QE87-E
M('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"X`4&QE87-E
M('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+@!0
M<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4')E=FEO=7,@365S
M<V%G90!0<F5V:6]U<R!086=E`%!R:6YT`%!R:6]R:71Y`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O=&]C;VPZ`%!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O
M<G0@:&%S(&)E96X@9&ES86)L960N`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U<F=E($1E;&5T960`4'5R
M9V4@5')A<V@@:&]W(&]F=&5N.@!296%D`%)E9&ER96-T`%)E9&ER96-T($UE
M<W-A9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE
M9"X`4F5F<F5S:`!2969R97-H($9O;&1E<B!6:65W<SH`4F5L;V%D(%9I97<`
M4F5M96UB97(@=&AE(&QA<W0@=FEE=P!296UO=&4@36%I;&)O>#H`4F5M;W9E
M`%)E;6]V92!P86ER`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;&%C92!W:71H.@!297!L
M>0!297!L>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2!T;R!,:7-T`%)E
M<&QY('1O($QI<W0Z`%)E<&QY+51O.B``4F5P;'DZ`%)E<&]R="!A<R!3<&%M
M`%)E<V5T`%)E<W5M90!2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A
M9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\`
M4V%V92!$<F%F=`!3879E($]P=&EO;G,`4V%V92!A<P!3879I;F<@=&AE(&1R
M869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`
M4V5A<F-H`%-E87)C:"!297-U;'1S`%-E96X`4V5L96-T`%-E;&5C="!A;&P`
M4V5L96-T(&%N(&%C8V]U;G0`4V5L96-T(&YO;F4`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396YD($UE<W-A9V4`4V5N9"!0<F]B;&5M(%)E<&]R=`!3
M96YT(&UA:6P@9F]L9&5R.@!397)V97(`4V5R=F5R.@!3970@<')E9F5R96YC
M97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@
M;65S<V%G97,N`%-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP
M;W-I;F<@;65S<V%G97,_`%-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@
M8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/P!3:&]W`%-H;W<@06QL($AE
M861E<G,`4VAO=R!$96QE=&5D`%-H;W<@3&EM:71E9"!(96%D97)S`%-H;W<@
M36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N`%-H;W<@56YS=6)S8W)I8F5D`%-H
M;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VEZ90!3
M:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P96-I
M86P@0VAA<F%C=&5R<P!3<&5L;"!#:&5C:P!3<&5L;"!#:&5C:V5R`%-P96QL
M(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H
M96X@<W!E;&P@8VAE8VMI;F<N`%-T871U<P!3=6)J96-T`%-U8FIE8W0@1FEE
M;&0`4W5B;6ET`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5C8V5S<P!3=6=G
M97-T:6]N<P!487-K<P!497)M<R!O9B!397)V:6-E(&9I;&4@;F]T('-P96-I
M9FEE9"!I;B!C;VYF+G!H<`!497AT`%1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE(&%C8V]U;G0@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@86-C;W5N="`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&4@8W5R<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M
M960@=&\@(B5S(BX`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9O;&1E<B`B)7,B(&%L<F5A
M9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!C;VYT86EN<R!I;&QE9V%L(&-H
M87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S92!P<F]B;&5M<RX@
M4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4:&4@9F]L
M9&5R("(E<R(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I
M8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S(&1E;&5T960@8G5T('EO
M=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="X`5&AE(&9O;&1E<B`B
M)7,B('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D
M+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4
M:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E
M<R(N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@
M35,M5$Y%1B!A='1A8VAM96YT+@!4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S
M9G5L;'D@<F5P;&%C960N`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES
M(&UA:6QB;W@N`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A('!R;V)L
M96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@
M:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N
M(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R
M;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H:7,@4$=0(%!U8FQI8R!+
M97D@=V%S(&%T=&%C:&5D('1O('1H92!M97-S86=E+@!4:&ES(&UA>2!T86ME
M('-O;64@=&EM92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O;G1I;G5E
M/P!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C
M;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R!21D,@,C`Q-2DN`%1H
M:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N
M`%1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N`%1H
M:7,@;65S<V%G92!T;P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:')E860@5FEE=P!4
M:71L90!4;P!4<F%S:"!F;VQD97(Z`%523`!5;F%B;&4@=&\@8V]N;F5C="!T
M;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N=`!5;F%N<W=E<F5D`%5N86YS=V5R960@;65S<V%G97,`56YD96QE
M=&4`56YD:7-C;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`56YL;V%D
M(%!A<W-P:')A<V4`56YN86UE9`!5;G-E96X`56YS=6)S8W)I8F4@9G)O;2!&
M;VQD97(H<RD`57!D871E`%5P;&]A9`!5<V4@1&5F875L="!686QU90!5<V5R
M($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5<V5R;F%M
M93H`57-E<G,@:6X@=&AE('-Y<W1E;3H`5FEE=P!6:65W("5S`%9I97<@)7,@
M4'5B;&EC($ME>0!6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y`%9I97<@4&5R
M<V]N86P@4'5B;&EC($ME>0!6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A
M9G1E<B!L;V=I;CH`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EE<P!997,L($D@
M06=R964`66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@`%EO=2!A
M<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+@!9;W4@87)E(')E;F%M
M:6YG('1H92!F;VQD97(Z(`!9;W4@:&%V92`E<R!N97<@;65S<V%G97,N`%EO
M=2!H879E(#$@;F5W(&UE<W-A9V4N`%EO=2!H879E(&YE=R!M86EL(&EN('1H
M92!F;VQL;W=I;F<@9F]L9&5R.@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@
M9F]L;&]W:6YG(&9O;&1E<G,Z`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9
M;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I
M=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4`66]U(&UU<W0@<V5L96-T
M(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!A
M8V-O=6YT('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R
M97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A
M9V4@9FER<W0N`%EO=2!M=7-T('-P96-I9GD@82!R96-I<&EE;G0N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U('=E<F4@;F]T('-U8G-C
M<FEB960@=&\@(B5S(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9
M;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(BX@2&5R92!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B
M<V-R:6)E9"!T;R`B)7,B`%EO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C
M<FEB960@9G)O;2`B)7,B`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@3F%M
M90!9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES`%EO=7(@4')I=F%T92!+
M97D`66]U<B!0=6)L:6,@2V5Y`%EO=7(@86-C;W5N=',Z`%EO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE
M(&]T:&5R(')E87-O;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+@!9;W5R('-I9VYA='5R93H`6TYO(%-U8FIE8W1=`%M0<F]B;&5M(%)E<&]R
M=%T`6VQI;F4@)7,@;V8@)7-=`&9R;VT`;F]N90!O<@!S<&5L;&EN9R!E<G)O
M<@!S<&5L;&EN9R!E<G)O<G,`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!)
M35`@-"XP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#8M,#@@,C(Z,S0K,#$P,`I,
M87-T+51R86YS;&%T;W(Z(%!E<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R
M9SX*3&%N9W5A9V4M5&5A;3H@3F]R=V5G:6%N($YY;F]R<VL@/&YY;F]R<VM`
M;W)S=&$N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET"@`@("`@(%1I;#H@`"`@("!$871O.B``("`@("!&
M<N4Z(``@("`@16UN93H@`"!I(``C`"5D('1I;"`E9"!A=B`E9"!M96QD:6YG
M87(`)7,@+2!.;W1I<P`E<R!V961L:6ME:&%L9'-O<&5R87-J;VYA<B`M(%-T
M861F97-T:6YG`"5S(%9I;&OE<B!F;W(@879T86QE`"5S(&5K<VES=&5R97(@
M86QL97)E:64N($YA;6YE="!PY2!M87!P82`E<R!V87)T(&EK:VIE(&5N9')A
M+@!-87!P82`E<R!FY7(@96YD<F$@;F%M;F5T('9E9"!S=&%R=&5N(&%V(&WE
M;F%D96XN`"5S.B`E<R`H)60F;F)S<#MA=B9N8G-P.R5D*0`H0G)U:R!D97-S
M92!E;F1R:6YG86YE(&]G(&?E('1I;"!N97-T92!S:VIE<FUB:6QE=&4N*0`H
M5&EL8F%K97-T:6QL(&%L;&4@96YD<FEN9V%R(&]G(&?E('1I;&)A:V4@=&EL
M('-K:F5R;6)I;&5T970@9F]R('-K<FEV(&UE;&1I;F<N*0`H1^4@=&EL8F%K
M92!T:6P@<VMJ97)M8FEL971E="!F;W(@<VMR:78@;65L9&EN9R!E='1E<B#E
M(&AA(&%K=&EV97)T(&%L;&4@96YD<FEN9V%N92!D=2!H87(@9VIO<G0@<^4@
M;&%N9W0N($5N9')I;F=A<B!I(&1E='1E('-K:F5R;6)I;&5T970@=FEL($E+
M2TI%(&)L:2!B<G5K="XI`"H@3&5G9R!T:6P@9&5S<V4@=F5D(.4@:VQI:VME
M($]+("H`*B!696P@861R97-S92AR*2`J`#(T('1I;6%R`$%-+U!-`$YA;6X@
M<.4@:V]N=&\Z`$QE9V<@=&EL`$QE9V<@=&EL(&YY(&)R=6MA<CH`3&5G9R!T
M:6P@<&%R`$QE9V<@=&EL(&)R=6MA<@!,96=G('1I;"!B<G5K87)A<B!E<B!S
M;.5T="!A=BX`061R97-S90!!9')E<W-E8F]K`$%D;6EN:7-T<F5R:6YG`$%L
M:6%S`$%L;&4`06QL92!M96QD:6YG87(@:2!F^&QG:F%N9&4@;6%P<&4H<BD@
M=FEL(&)L:2!L87-T82!N960@=&EL(&5I($U"3U@M9FEL.@!!;&QE(&UE;&1I
M;F=A<B!I(&UA<'!A("(E<R(@<V]M(&5R(&5L9')E(&5N;B`E<R!D86=A<BP@
M=FEL(&)L:2!S;&5T=&$@<&5R;6%N96YT+@!!;&QE(&=A;6QE(&MA=&%L;V=A
M<B!M960@<V5N9'0@<&]S="!S;VT@97(@96QD<F4@96YN("5S(&WE;F%D97(L
M('9I;"!B;&D@<VQE='1A+@!%:6X@=6QO=FQE9R!V97)D:2!V87)T('-P97-I
M9FES97)T+@!3=F%R="!PY0!-96QD:6YG87(@9'4@:&%R('-V87)T('#E`$5R
M(&1U('-I:VME<B!PY2!A="!D=2!V:6P@<VQE='1E(&1E;FYE(&]F9F5N=&QE
M9V4@;OAK:V5L96X_`$5R(&1U('-I:VME<B!PY2!A="!D=2!V:6P@<VQE='1E
M(&[X:VME;'!A<F5T(&1I='0_("A$971T92!E<B!)2TM*12!T:6QRY61D(2D`
M17(@9'4@<VEK:V5R('#E(&%T(&1U('9I;"!G:F5R92!D971T93\`17(@9'4@
M<VEK:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@9&5S<V4@;65L9&EN9V%N92!0
M15)-04Y%3E0_`$5R(&1U('-I:VME<B!PY2!A="!D=2!V:6P@=/AM;64@9&5N
M;F4@;6%P<&$_`$5R(&1U('-I:VME<B!PY2!A="!D=2!V:6P@=/AM;64@<_AP
M<&5L:V]R9V$@9&D_`%1I9"!M;W1T96ME`%-T:6=A;F1E`%-P^'(@;VT@<W1A
M9&9E<W1I;F<@9OAR(&OX>7)I;F<@878@=F5D;&EK96AA;&1S;W!E<F%S:F]N
M87(_`$QE9V<@=F5D`$QE9V<@=F5D(&5I;B!K;W!I(&%V(&1I;B!O9F9E;G1L
M96=E(%!'4"UN^&MK96P@:2!M96QD:6YG83\`5F5D;&%G="!F:6PZ`%9E9&QE
M9V<`5F5D;&5G9P!0<OAV9&4@Y2!S;&5T=&4@96D@:6MK:F4M96MS:7-T97)A
M;F1E(&=R=7!P92X`4'+X=F1E(.4@<VQE='1E(&5I;B!I:VMJ92UE:W-I<W1E
M<F%N9&4@=&EL9V%N9RX`4'+X=F1E(.4@96YD<F4@96EN(&EK:VIE+65K<VES
M=&5R86YD92!T:6QG86YG+@!4:6QG:F5N9V5L96=E(&9E;'0Z`%1I;&)A:V4@
M=&EL("5S`$)L:6YD(&MO<&D`0G5R<V1A9P!3=F%R=&5L:7-T`$MR;W!P`$)E
M9V=E`$+E9&4@=FES:6YG(&%V(&UE;&1I;F=S:&]V=60@;V<@;65L9&EN9W-K
M<F]P<`!!=F)R>70`079B<GET(&UE;&1I;F<`079B<GET('!R;V)L96UR87!P
M;W)T`%9E9"#E(&%V8G)Y=&4@9&5N;F4@;65L9&EN9V$@=FEL(&1U(&UI<W1E
M(&EN;FAA;&1E="!F;W(@9V]D="X`2V]P:0!-;V)I;'1E;&5F;VX`16YD<F4`
M16YD<F4@86QL90!%;F1R92!N86UN+"!A9')E<W-E(&]G('-I9VYA='5R96X@
M9F]L:R!S97(@;N5R(&1E:2!L97,@;V<@<W9A<F%R('#E(&4M<&]S="!F<N4@
M9&5G+@!3:F5K:R!M87!P92AR*2!F;W(@;GD@92UP;W-T`%9E;"!H86YD;&EN
M9SH`2VQI:VL@9F]R(.4@:&%L9&4@9G)A;0!,=6MK('9I;F1A=6=E=`!,=6MK
M(&1E='1E('9I;F1A=6=E=`!,=6MK82!M87!P90!&;VQD('-A;6%N(&%L;&4`
M1F]L9"!S86UA;B!A;&QE(&UA<'!E<@!&;VQD('-A;6%N(&UA<'!E`$MO;6UE
M;G1A<@!&:7)M80!3:W)I=B!E:2!M96QD:6YG('1I;`!3=&%D9F5S="!P87-S
M;W)D`$]P<&MO<&QI;F<@;6]T(&]F9F5N=&QE9R!N^&MK96QT96YA<B!N96MT
M82X`2V]N=')O;&QE<B!NY7(@9&5T('-K86P@<VIE:VMA<W0@9F]R(&YY('!O
M<W0L(&]G(&]M(&1U('-K86P@=F%R<VQA<W0@96QL97(@:6MK:F4@;N5R(&YY
M('!O<W0@:VIE;2X`2V]P:65R`$MO<G)I9V5R`$MO<G)I9V5R="!T96MS=`!+
M=6YN92!I:VMJ92!01U`M:V]D92!M96QD:6YG+@!+=6YN92!I:VMJ92!01U`M
M<VEG;F5R92!M96QD:6YG+@!+=6YN92!I:VMJ92!D96MO9&4@4$=0+61A=&$N
M`$MU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E+7!O<W1A9')E
M<W-E+@!+=6YN92!I:VMJ92!T<F5K:V4@=70@9&5N(&;X<F5S<'5R9&4@9FEL
M80!+=6YN92!I:VMJ92!S:V%F9F4@;V9F96YT;&5G(&[X:VME;"!F<N4@;OAK
M:V5L=&5N87)E;BX`2W5N;F4@:6MK:F4@;W!N92!-86EN=&5N86YC95]487-K
M+6UO9'5L96X@)7,`3W!P<F5T=`!/<'!R970@;6%P<&4`3W!P<F5T="!N^&ML
M87(`3W!P<F5T="!N>2!M87!P92!F;W(@:VQA9&0`3W!P<F5T="!N>2!M87!P
M92!F;W(@<V5N9'0@<&]S=`!/<'!R971T(&YY(&UA<'!E(&9O<B!S^'!P96QK
M;W)G`$]P<')E='0@9FEL=&5R<F5G;&%R(`!4:6QP87-S(&]P<&?E=F5R('-O
M;2!S:V%L(&OX>7)A<W0@=F5D('#E;&]G9VEN9R!T:6P@)7,N`$1$`$1A9VQE
M9P!$871O`%-T86YD87)D:61E;G1I=&5T`%-T86YD87)D('-O<G1E<FEN9W-K
M<FET97)I=6TZ`%-T86YD87)D('-O<G1E<FEN9W-R96MK96;X;&=J93H`4VQE
M='0`4VQE='0@)7,@;V9F96YT;&5G(&[X:VME;`!3;&5T="!N;W9E<F%N9&4@
M;OAK;&%R`%-L971T92!M87!P92AR*0!3;&5T=&$`4VQE='1A(&UE;&1I;F=A
M<@!3;&5T=&EN9R!O9R!F;'ET=&EN9R!A=B!M96QD:6YG87(`4WEN:V%N9&4`
M4VMI;&1R92!P<F]B;&5M970`1&5T86QJ87(`1&5T86QJ87(@97(@;&]G9V$@
M9F]R(&%D;6EN:7-T<F%T;W)E;BX`1&EM('-I9VYA='5R87(_`%9I<P!6:7-I
M;F=S86QT97)N871I=@!6:7,@<W1A9&9E<W1I;F<@971T97(@Y2!H82!S96YD
M="!E:2!M96QD:6YG/P!6:7,@:2!M96QD:6YG<VMR;W!P`$EK:VIE('-J96MK
M(&UA<'!E*'(I(&9O<B!N>2!E+7!O<W0`26MK:F4@8G)U:R!M86EN=&5N86YC
M92YP:'`@9&ER96MT92X`5FEL(&1U(&]P;F4@9&5N(&UA<'!A/P!&97)D:6<`
M3&%S="!N960@;6%P<&4H<BD`2VQA9&0`2VQA9&0M;6%P<&4Z`$4M<&]S=&%D
M<F5S<V4`16YD<F4`16YD<F4@9FEL=&5R<F5G;&%N92!D:6YE`$4M<&]S=`!%
M+7!O<W1A9')E<W-E`%3X;2!M87!P92AR*0!4^&T@<_AP<&5L:V]R9P!4;VUT
M(')E<W5L=&%T+@!3;.4@<.4@4$=0+69U;FMS:F]N86QI=&5T/P!3;'5T="!V
M:61A<F5S96YD="!M96QD:6YG`%-K<FEV(&EN;B!P87-S;W)D9G)A<V4`4VMR
M:78@:6YN(&YA;6YE="!PY2!D:2!N>64@:VQA9&0M;6%P<&4`4VMR:78@:6YN
M(&YA;65T('#E(&1I(&YY92!M87!P92!F;W(@<V5N9'0@<&]S=`!3:W)I=B!I
M;FX@;F%M;F5T('#E(&1I(&YY92!S^'!P96QK;W)G`$9E:6P`2W9A<G0@,34N
M(&UI;G5T=`!+=F%R="`S,"X@<V5K=6YD`$MV87)T(#4N(&UI;G5T=`!+=F%R
M(&EN;FQO9V=I;F<`2W9A<B!H86QV92!T:6UE`$MV87)T(&UI;G5T=`!%:W-E
M;7!E;'9E<F1I87(Z`%9I<R!A;&QE`%9I<R!A;&QE(&UA<'!E<@!6:7,@;6%P
M<&4`2V]N=')O;&QE<B!N86UN`$MU;FYE(&EK:VIE(&AE;G1E(&EN;G-T:6QL
M:6YG87(`2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BX`1F%K
M<P!(96YT(&4M<&]S=`!(96YT('!O<W0@:2!E:6=E('9I;F1A=6=E/P!&:6QH
M86YD<V%M:6YG`$9I;'1E<@!&:6YN`$;X<G-T92!S:61E`$UA<'!E;F%V:6=E
M<FEN9P!6:61A<F5S96YD`%9I9&%R97-E;F0Z`%9I9&%R97-E;F1T(&UE;&1I
M;F<`5FED87)E<V5N9&4@;65L9&EN9V%R(&9RY2`E<P!&<N4`1G+E+6%D<F5S
M<V4`5E,Z`$=R=7!P96%D;6EN:7-T<F5R:6YG`$=R=7!P97(`365L9&EN9W-H
M;W9U9`!(:F5L<`!3:VIU;"!S;&5T=&$`4VMJ=6P@=2]A8F]N;F5M96YT`$CX
M9P!(^&<@<')I;W)I=&5T`$CX9V%S=`!!9')E<W-E+"!P<FEV870`5&5L969O
M;BP@<')I=F%T`$AO<F1E`$MO<FQE:7,@=FEL(&1U('9I<V4@=F5D;&5G9S\`
M24U!4`!)34%0(&]V97(@4U-,`$E-05`@;W9E<B!34TP@*'-J^&QV+7-I9VYE
M<G0I`$E-05`L(&EK:VIE(%1,4P!);FYB;VMS`$EG;F]R97(`26=N;W)E<B!A
M;&QE`$EM<&]R=&5R(&[X:VME;`!);7!O<G1E<B!N^&MK96QP87(`26UP;W)T
M97(@4$=0+6[X:VME;`!);7!O<G1E<B!P97)S;VYL96<@<')I=F%T(%!'4"UN
M^&MK96P`26UP;W)T97(@<&5R<V]N;&5G(&]F9F5N=&QE9R!01U`M;OAK:V5L
M`$EM<&]R=&5R(&]F9F5N=&QE9R!N^&MK96P`26UP;W)T97(@;V9F96YT;&5G
M(%!'4"UN^&MK96P`5FEK=&EG`%9I:W1I9V4@;65L9&EN9V%R`$EM<&]R=&5R
M=&4@9F5L=#H@)7,`26UP;W)T97)T92!F96QT.@!);FML=61E<F4@;W)I9VEN
M86P@;65L9&EN9R!I('-V87(_`$EN9F]R;6%S:F]N(&]M("5S(&]F9F5N=&QE
M9R!N^&MK96P`26YF;W)M87-J;VX@;VT@<&5R<V]N;&5G('!R:79A="!N^&MK
M96P`26YF;W)M87-J;VX@;VT@<&5R<V]N;&5G(&]F9F5N=&QE9R!N^&MK96P`
M56=Y;&1I9R!E:W-T97)N('!O<W1K87-S90!59WEL9&EG(%!'4"UN^&MK96PN
M`%5G>61L:6<@<&5R<V]N;&5G('!R=F%T(%!'4"UN^&MK96PN`%5G>6QD:6<@
M<&5R<V]N;&5G(&]F9F5N=&QE9R!01U`M;OAK:V5L+@!.^&MK96QL96YG9&4`
M4W!RY6L`4VES=&4@<VED90!6:7,@96UN92!F<N4@2&IE;'``3&ES=&EN9R!I
M(&UE;&1I;F=S:&]V=60`3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S;.5T="!A
M=BX`3&]K86P@<&]S=&MA<W-E.@!,;V=G(&EN;@!,;V=G(&EN;B!T:6P@)7,`
M3&]G9R!U=`!/<'!GY79E<B!V960@:6YN;&]G9VEN9P!,878`3&%V('!R:6]R
M:71E=`!,879A<W0`34T`35,M5$Y%1BUV961L96=G(&EN;F5H96QD="!I;F=E
M;B!D871A+@!0;W-T:V%S<V4`36%R:V5R('-O;3H`365R:R!U;&EK92!N:7;E
M(&%V('-I=&5R:6YG(&UE9"!U;&EK92!F87)G87(_`%-A;7-V87)A;F1E(&9E
M;'0`365D;&5M;6%R`%-K<FEV(&UE;&1I;F<`365L9&EN9W-D871O`$UE;&1I
M;F=S<_AK`$UE;&1I;F=S<W1O<FQE:6L`365L9&EN9W-K:F5L9&4`365L9&EN
M9W-V:7-I;F<`365L9&EN9W-F;&%G9P!-96QD:6YG<VUA<'!E<@!-96QD:6YG
M('-E;F1T+@!-96QD:6YG87(@<&5R('-I9&4@:2!P;W-T8F]K<W9I<VEN9RX`
M;65L9&EN9V%R('1I;`!-24U%+71Y<&4`36]D:69I<V5R90!-Y6YA9&QE9P!&
M;'ET=`!.14DL(&5G(&5R($E+2TI%('-A;60`3F%M;@!.86UN(&]G+V5L;&5R
M(&4M<&]S=&%D<F5S<V4@:V%N(&EK:VIE('9E<F4@=&]M`$YE='1V97)K`$%L
M9')I`$YY`$YY(&4M<&]S=`!.>64@;65L9&EN9V%R`$YE<W1E`$YE<W1E(&UE
M;&1I;F<`3F5S=&4@<VED90!.96D`26YG96X@;OAK;&%R(&D@;OAK:V5L:VYI
M<'!E`$EN9V5N(&]F9F5N=&QE9R!01U`M;OAK:V5L(&EM<&]R=&5R="X`1F%N
M;B!I;F=E;B!V961L96=G`$EN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J
M;VX@<W!E<VEF:7-E<G0@9F]R(%-13"!61E,N`$EN9V5N(&UA<'!E*'(I('9A
M<G0@<W!E<VEF:7-E<G0`26YG82!T96MS="!I(&UE;&1I;F=S:W)O<'``26YG
M96X@<&5R<V]N;&5G('!R:79A="!01U`M;OAK:V5L(&EM<&]R=&5R="X`26YG
M96X@<&5R<V]N;&5G(&]F9F5N=&QE9R!01U`M;OAK:V5L(&EM<&]R=&5R="X`
M26YG96X@<W1A=F5F96EL`$EN9V5N(&9O<G-L86<`26YG96X@9WEL9&EG92!8
M34PM9&%T82!R971U<FYE<G0`26YG96X`3F]R;6%L`$EK:VIE('-L971T80!)
M:VMJ92!K;&%D9`!):VMJ92!V:6MT:6<`26MK:F4@<&5R<V]N;&5G`$EK:VIE
M(&5I;B!G>6QD:6<@;V9F96YT;&5G(&[X:VME;"X`26MK:F4@<VQE='1A(&UE
M;&1I;F=A<@!):VMJ92!V:6MT:6=E(&UE;&1I;F=A<@!.;W1A=&%R`$]+`$=A
M;6QE(&UE;&1I;F=A<@!'86UL92!M87!P97(@;65D('-E;F1T('!O<W0@8FQI
M<B!S;&5T=&$N`$%L=&5R;F%T:78`06YN86X@:6YF;W)M87-J;VX`06YD<F4@
M86QT97)N871I=@!01U``4$=0+69E:6PZ(%1R96YG('!A<W-O<F1F<F%S92!F
M;W(@<&5R<V]N;&5G('!R:79A="!N^&MK96PN`%!'4"!!;'1E<FYA=&EV`%!'
M4"!I;FYT87-T:6YG(&%V('!A<W-O<F1F<F%S90!3=/AT=&4@9F]R('!E<G-O
M;FQE9R!01U`M;OAK:V5L<&%R(&MR978@96D@<VEK:V5R('=E8BUK;W!L:6YG
M+@!/9F9E;G1L96<@4$=0+6[X:VME;"!F;W(@(B5S("@E<RDB('9A<G0@;&%G
M="!T:6PN`$]F9F5N=&QE9R!01U`M;OAK:V5L(&9O<B`B)7,B('9A<G0@<VQE
M='1A+@!/9F9E;G1L96<@4$=0+6[X:VME;')I;F<`4$=0(%-I9VYE<B!M96QD
M:6YG`%!'4"US:6=N97(O+6MR>7!T97(@;65L9&EN9P!01U`M<W3X='1E(&5R
M('-LY71T(&%V('#E(&1E='1E('-Y<W1E;65T+@!01U`M<W3X='1E(&5R(&9O
M<B!T:61A(&EK:VIE(&%K=&EV+"!SY2!D96X@9&EG:71A;&4@<VEG;F%T=7)E
M;B!K86X@:6MK:F4@=F5R:69I<V5R87-T+@!01U`M<W3X='1E(&5R(&9O<B!T
M:61A(&EK:VIE(&%K=&EV+"!SY2!M96QD:6YG82!K86X@:6MK:F4@9&5K<GEP
M=&5R87-T+@!03U`S`%!/4#,@;W9E<B!34TP@*'-J^&QV+7-I9VYE<G0I`%!/
M4#,L(&EK:VIE(%1,4P!3:61E("5D(&%V("5D`$1E;"AA<BD`4&%S<V]R9&9R
M87-E`%!A<W-O<F1F<F%S92`H:6=J96XI`%!A<W-O<F1F<F%S92!V87)T(&QA
M<W1A('5T+@!087-S;W)D9G)A<V4Z`%!A<W-O<F1F<F%S87(@:V%N(&EK:VIE
M('9E<F4@=&]M;64`4&%S<V]R9&9R87-A<B!S86US=F%R87(@:6MK:F4`4&%S
M<V]R9`!087-S;W)D82!MY2!S86US=F%R92X`2_AY<B!V961L:6ME:&%L9'-O
M<&5R87-J;VYA<@!+^'ER('9E9&QI:V5H86QD<V]P97)A<VIO;F%R('9E9"!I
M;FYL;V=G:6YG/P!4:6QG86YG`%1I;&=A;F=S861M:6YI<W1R97)I;F<`4&5R
M<V]N;&5G`%!E<G-O;FQE9R!I;F9O<FUA<VIO;@!097)S;VYL96<@4$=0+6[X
M:VME;'!A<B!V87)T(&=E;F5R97)T+@!097)S;VYL96<@4$=0+6[X:VQA<B!V
M87)T('-L971T82X`5&5L969O;@!0;&%S<V5R('-I9VYA='5R(&;X<B!S=F%R
M(&]G('9I9&%R97-E;F1T/P!3:W)I=B!I;FX@;F%M;F5T('#E(&1E;B!N>64@
M;6%P<&$Z`%-K<FEV(&EN;B!D970@;GEE(&YA;6YE=#H`4VMR:78@:6YN(&5I
M="!S86UA;F1R86<@878@<')O8FQE;65T+@!3:W)I=B!I;FX@9&ET="!B<G5K
M87)N86UN(&]G('!A<W-O<F0`3W)D;F4@;W!P(&D@9FQE:7)T>61I9V4@96QL
M97(@=6=Y;&1I9V4@861R97-S97(N`%9E;"!E:2!M87!P92!F^'(@9'4@:_AY
M<F5R(&5I(&5L;&5R(&9L96ER92!H86YD;&EN9V%R+@!696P@;6EN<W0@96D@
M;6%P<&4@Y2!S^&ME(&DN`%9E;"!K=6X@96D@;6%P<&4@9F]R(&1E;FYE(&]P
M97)A<VIO;F5N+@!);FYS=&EL;&EN9V%R('9A<G0@;W!P9&%T97)T92X`1F]R
M<FEG92!M96QD:6YG`$9O<G)I9V4@<VED90!3:W)I=B!U=`!0<FEO<FET970`
M4VMI;&1R:6YG(&%V('!R;V)L96UE=`!0<F]T;VMO;&PZ`%-T^'1T92!F;W(@
M;V9F96YT;&5G(%!'4"UN^&MK96QT96YA<B!E<B!S;.5T="!A=BX`3V9F96YT
M;&5G+W!R:79A="!N^&MK96QP87(@=F%R="!I:VMJ92!G96YE<F5R="X`1FIE
M<FX@<VQE='1A`%3X;2!S^'!P96QK;W)G82!K;W(@;V9T93H`3&5S`$]M9&ER
M:6=E<@!/;61I<FEG97(@;65L9&EN9P!/;61I<FEG97(@9&5N;F4@;65L9&EN
M9V$`2W5N;F4@:6MK:F4@;VUD:7)I9V5R92X`1G)I<VL@;W!P`$9R:7-K(&]P
M<"!M87!P979I<VEN9V%R.@!/<'!D871E<B!V:7-I;F<`2'5G<R!S:7-T92!V
M:7-I;F<`16MS=&5R;B!P;W-T:V%S<V4Z`$9J97)N`$9J97)N('!A<@!+=6YN
M92!I:VMJ92!E;F1R92!N86UN('#E("(E<R(@=&EL("(E<R(N($1E='1E(&5R
M(&MV82!T96YA<F5N('-A`$5R<W1A='0@;65D.@!3=F%R`%-V87(@=&EL(&%L
M;&4`4W9A<B!T:6P@86QL93H`4W9A<B!T:6P@;&ES=&4`4W9A<B!T:6P@;&ES
M=&4Z`%-V87(@=&EL.B``4W9A<CH`4F%P;W)T97(@<V]M('/X<'!E;'!O<W0`
M3G5L;'-T:6QL`$=J96YO<'!T80!'Y2!T:6QB86ME('1I;"!P;W-T8F]K<VQI
M<W1A(&5T=&5R(.4@:&$@<VQE='1A+"!F;'ET=&$@96QL97(@:V]P:65R="!E
M:2!M96QD:6YG/P!,86=R92!K;&%D9`!,86=R92!A;'1E<FYA=&EV`$QA9W)E
M('-O;0!+=6YN92!I:VMJ92!L86=R92!K;&%D9"X@1&5T=&4@97(@:W9A('1E
M;F%R96X@<V$Z("5S`%/X:P!3^&ME<F5S=6QT870`3&5S=`!696P`5F5L(&%L
M;&4`5F5L(&5I;B!K;VYT;P!696P@:6YG96X`5F5L('-K:6QJ971E:6MN(&9O
M<B!D871O.@!696P@9&%T;V9O<FUA=#H`5F5L('1I9'-F;W)M870Z`%9E;"!T
M;R!S86US=F%R86YD92!F96QT+@!696P@9F%R9V5S:VIE;6$N`%9E;"#X;G-K
M82!S<'+E:SH`4V5N9"!M96QD:6YG`%-E;F0@<')O8FQE;7)A<'!O<G0`36%P
M<&4@9F]R('-E;F1T('!O<W0Z`%1E;F%R`%1E;F%R.@!3970@:6YN<W1I;&QI
M;F=A<B!F;W(@:W9A('-O;2!S:VIE<B!NY7(@9'4@9FQY='1A<B!O9R!S;&5T
M=&%R(&UE;&1I;F=A<BX`4V5T(%@M4')I;W)I='DM;65L9&EN9W-H;W9U9"!N
MY7(@96EN('-K<FEV(&UE;&1I;F=A<C\`4VMA;"!V:6YD875G970@9F]R('-K
M<FEV(&UE;&1I;F<@;'5K:V%S="!E='1E<B!A="!D=2!H87(@;&%G<F$@96EN
M(&ML861D/P!6:7,`5FES(&%L;&4@;65L9&EN9W-H;W9U9`!6:7,@<VQE='1A
M`%9I<R!A=F=R96YS82!M96QD:6YG<VAO=G5D`%9I<R!I;F9O<FUA<VIO;B!O
M;2!E+7!O<W1L:7-T90!6:7,@=2]A8F]N;F5M96YT`%9I<R!(96YT('!O<W0M
M:6MO;F5T(&D@;65N>6QI;FIE/P!3=&]R;&5I:P!(;W!P(&]V97(@=F5D;&EK
M96AA;&0`26YN=&%S=&EN9R!A=B!S<&5S:6%L=&5I:VX`4W!E<VEA;'1E:6MN
M`%-T879E:V]N=')O;&P`4W1A=F5K;VYT<F]L;`!3=&%V96MO;G1R;VQL(&9E
M<F1I9P!3=&%V969E:6P@<&5R('-K:F5R;6)I;&5T92!V960@<W1A=F5K;VYT
M<F]L;"X`4W1A='5S`$5M;F4`16UN969E;'0`4V5N9`!!8F]N;F5R92!PY2!M
M87!P92AR*0!3=6MS97-S`$9O<G-L86<`3W!P9^5V97(`5FEL:^5R(&9O<B!T
M96YE<W1A+69I;&$@:6MK:F4@<W!E<VEF:7-E<G0@:2!C;VYF+G!H<`!496MS
M=`!+;&%S<V$@36%I;G1E;F%N8V4Z.B!V87)T(&EK:VIE(&QA<W1A(&EN;@!+
M;VYT;V5N("(E<R(@=F%R="!S;&5T=&$N`$MO;G1O96X@(B5S(B!V87)T(&QA
M9W)A+@!.86UN970@<.4@9VIE;&1A;F1E(&UA<'!E*'(I("(E<R(@=FEL(&)L
M:2!E;F1R82!T:6P@(B5S(BX`2W)Y<'1E<FEN9W-F=6YK<VIO;F%N92!K<F5V
M(&5I('-I:VME<B!N971T;W!P:V]P;&EN9RX`36%P<&$@(B5S(B!E:W-I<W1E
M<F5R(&%L;&5R96EE`$YA;6YE="!PY2!M87!P82`B)7,B(&EN;F5H96QD('5L
M;W9L96=E('1E:6MN+B!$971T92!K86X@<VMA<&4@<')O8FQE;2X@2V]N=&%K
M="!D:6X@<WES=&5M861M:6YI<W1R871O<BX`36%P<&$@(B5S(B!V87)T(&]P
M<')E='1A+"!M96X@9'4@86)O;FYE<F5R(&EK:VIE('#E(&1E;BX`36%P<&$@
M(B5S(B!V87)T('-L971T82P@;65N(&1U(&%B;VYN97)E<B!F<F%M;&5I<R!P
MY2!D96XN`$UA<'!A("(E<R(@=F%R="!I:VMJ92!O<'!R971T82X@1&5T=&4@
M97(@:W9A('1E;F%R96X@<V$`36%P<&$@(B5S(B!V87)T(&]P<')E='1A+@!-
M87!P82`B)7,B('9A<G0@<VQE='1A+@!-87!P82`B)7,B(&5N9')A(&YA;6X@
M=&EL("(E<R(N`$1E;B!F^')E<W!U<F1E(&9I;&$@96MS:7-T97)E<B!I:VMJ
M92!I($U3+51.148M=F5D;&5G9V5T+@!3:6=N871U<F5N('9A<G0@97)S=&%T
M=&$N`$1E="!E<B!I;F=E;B!M96QD:6YG87(@:2!D96YN92!P;W-T:V%S<V$N
M`%!R;V)L96T@=F5D('3X;6UI;F<@878@)7,N($1E='1E(&5R(&MV82!T96YA
M<F5N('-A`%!R;V)L96T@=F5D('3X;6UI;F<@878@<&]S=&MA<W-E+B!$971T
M92!E<B!K=F$@=&5N87)E;B!S80!0<F]B;&5M('9E9"!S;&5T=&EN9R!A=B!M
M96QD:6YG87(@9G+E(&UA<'!A("(E<R(N($1E='1E(&5R(&MV82!T96YA<F5N
M('-A`%!R;V)L96T@=F5D('-L971T:6YG(&%V(&UE;&1I;F=A<B!I(&UA<'!A
M("(E<R(N($1E='1E(&5R(&MV82!T96YA<F5N('-A`%!R;V)L96T@=F5D('-L
M971T:6YG(&%V(&UE;&1I;F=A<BX@1&5T=&4@97(@:W9A('1E;F%R96X@<V$Z
M("5S`%!R;V)L96T@=F5D('9I<VEN9R!A=B!D96YN92!M96QD:6YG<V1E;&5N
M`%!R;V)L96T@=F5D(&9L86=G:6YG(&%V(&UE;&1I;F=A<B!I(&UA<'!A("(E
M<R(N($1E='1E(&5R(&MV82!T96YA<F5N('-A`%!R;V)L96T@=F5D('-E;F1I
M;F<@878@;65L9&EN9V$@9&DZ("5S`$1E;FYE(&]F9F5N=&QE9V4@4$=0+6[X
M:VME;&5N('9A<B!L86=T('9E9"!M96QD:6YG82X`1&5T=&4@:V%N('1A(&5I
M;B!D96P@=&ED+B!%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL(&AA;&1E(&9R
M86T_`$1E;FYE(&UE;&1I;F=A('-E<B!I:VMJ92!U="!T:6P@Y2!V97)E(&D@
M:V]R<F5K="!01U`M9F]R;6%T("AI(&;X;&=J92!21D,@,C`Q-2DN`$1E;FYE
M(&UE;&1I;F=A(&5R(&1I9VET86QT('-I9VYE<G0@=FEA(%!'4"X`1&5N;F4@
M;65L9&EN9V$@97(@:W)Y<'1E<G0@;65D(%!'4"X`1&5N;F4@;65L9&EN9V$@
M=&EL`$1E='1E('1A;&5T(&WE('9E<F4@;6EN<W0@96EN+@!$96YN92!V97)D
M:65N(&WE('9E<F4@96ET('1A;"X`5'+E9'9I<VEN9P!4:71T96P`5&EL`%/X
M<'!E;&MO<F<Z`%523`!+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BX`
M2V%N(&EK:VIE(&]M<V5T:F4@9&5T=&4@5V]R9"UD;VMU;65N=&5T+@!58F5S
M=F%R=`!58F5S=F%R=&4@;65L9&EN9V%R`$%N9W)E('-L971T`%-K:G5L="!M
M;W1T86MA<@!!;F=R92!E;F1R:6YG87(`3&%S="!U="!P87-S;W)D9G)A<V4`
M571A;B!N86UN`%5L97-T`%-E:2!O<'`@86)O;FYE;65N="!PY2!M87!P92AR
M*0!/<'!D871E<@!,87-T(&]P<`!"<G5K('-T86YD87)D=F5R9&D`0G)U:V%R
M861M:6YI<W1R97)I;F<`0G)U:V%R86QT97)N871I=@!"<G5K87)N86UN`$)R
M=6MA<FYA;6XZ`$)R=6MA<F%R(&D@<WES=&5M970Z`%9I<P!6:7,@)7,`5FES
M("5S(&]F9F5N=&QE9R!N^&MK96P`5FES('!E<G-O;FQE9R!P<FEV870@;OAK
M:V5L`%9I<R!P97)S;VYL96<@;V9F96YT;&5G(&[X:VME;`!6:7-I;F<@96QL
M97(@<&]S=&)O:W,@<V]M('-K86P@=FES87-T(&5T=&5R(&EN;FQO9V=I;F<Z
M`$MV87(@=F5K90!696QK;VUE;B!T:6P@)7,`5F5L:V]M96XL("5S`$%D<F5S
M<V4L(&%R8F5I9`!496QE9F]N+"!A<F)E:60`Q<4`Q7)L96<`2F$`2F$L(&5G
M(&5R('-A;60`1'4@;W!P<F5T=&%R(&5I('5N9&5R;6%P<&4@=&EL`$1U(&]P
M<')E='1A<B!E:2!T;W!P;FEVY2UM87!P92X`1'4@96YD<F%R(&YA;6X@<.4@
M;6%P<&$Z`$1U(&AA<B`E<R!N>64@;65L9&EN9V%R+@!$=2!H87(@,2!N>2!M
M96QD:6YG+@!$=2!H87(@;GD@<&]S="!I(&;X;&=J86YD92!M87!P93H`1'4@
M:&%R(&YY('!O<W0@:2!F^&QG:F%N9&4@;6%P<&5R.@!$=2!MY2!S:VEL9')E
M('!R;V)L96UE="!F^'(@9'4@:V%N('-E;F1E('!R;V)L96UR87!P;W)T96XN
M`$1U(&WE('-K<FEV92!I;FX@<&%S<V]R9&9R87-A(&9O<B!D:6X@<')I=F%T
M92!01U`M;OAK:V5L(&9O<B#E('9I<V4@9&5N;F4@;65L9&EN9V$`1'4@;>4@
M9OAR<W0@=F5L:F4@96D@;>5L;6%P<&4N`$1U(&WE('9E;&IE(&5I;B!K;VYT
M;R!S;VT@<VMA;"!S;&5T=&%S="X`1'4@;>4@9OAR<W0@=F5L:F4@96D@861R
M97-S92X`1'4@;>4@9OAR<W0@=F5L:F4@;6EN<W0@96D@;65L9&EN9RX`1'4@
M;>4@<W!E<VEF:7-E<F4@96EN(&UO='1A:V%R+@!$=2!MY2!S<&5S:69I<V5R
M92!E:70@8G)U:V%R;F%M;B#E(&9J97)N92X`1'4@;>4@<W!E<VEF:7-E<F4@
M96ET(&)R=6MA<FYA;6X@Y2!L96=G92!T:6PN`$MU;FYE(&EK:VIE(&%B;VYN
M97)E('#E("(E<R(N($1E='1E(&5R(&MV82!T96YA<F5N('-A`$1I='0@86)O
M;FYE;65N="!PY2`B)7,B('9A<G0@:6MK:F4@<V%G="!O<'`N($1E='1E(&5R
M(&MV82!T96YA<F5N('-A`$1U(&%B;VYN97)E<B!N;R!PY2`B)7,B`$1I='0@
M86)O;FYE;65N="!PY2`B)7,B(&5R('-A9W0@;W!P`-AK=&$@9&D@*"5S*2!H
M87(@9^5T="!U="!PY2!T:60N($QO9V<@:6YN('#E(&YY='0N`$1I;B!I;F9O
M<FUA<VIO;@!$:71T(&YA;6X`1&EN92!O9F9E;G1L96=E+W!R:79A=&4@4$=0
M+6[X:VQA<@!$:6X@<')I=F%T92!N^&MK96P`1&EN(&]F9F5N=&QE9V4@;OAK
M:V5L`$1I;F4@:V]N=&]A<CH`3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!I:VMJ
M92!S=/AT=&$@878@8F%K<F4@875T96YT:7-E<FEN9RP@96QL97(@9G5N:W-J
M;VYE;B!H87(@878@96EN(&5L;&5R(&%N;F%N(&=R=6YN(&)L:71T('-LY71T
M(&%V+@!!;'1E<FYA=&EV82!D:6YE(&AA<B!B;&ET="!O<'!D871E<G1E+@!$
M:6X@<VEG;F%T=7(Z`%M4;VUT(&5M;F5=`%M0<F]B;&5M<F%P<&]R=%T`6VQI
M;FIE("5S(&%V("5S70!F<N4`:6YG96X`96QL97(`<W1A=F5F96EL`'-T879E
M9F5I;`!V0V%R9```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]P;%]03"\`````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P
M,3<T-3<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+W!L7U!,
M+TQ#7TU%4U-!1T53+P``````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S8S`#`R,3(T-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]L;V-A;&4O<&Q?4$PO3$-?34534T%'15,O:6UP+FUO````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`T,#4S,C(`,3`T,3<S-C(W-C,`,#(R,S<Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
M!@<``!P```!,.```7PD``'QP````````^)4```H```#YE0``"@````26```*
M````#Y8``$@````:E@``#@```&.6```/````<I8```T```""E@``"````)"6
M```+````F98```P```"EE@``"@```+*6```$````O98``!L```#"E@``+0``
M`-Z6```D````#)<``"D````QEP``&0```%N7```!````=9<``!D```!WEP``
M#````)&7```>````GI<``$@```"]EP``*P````:8``!$````,I@``"<```!W
MF```%P```)^8```+````MY@``!$```##F```#@```-68```%````Y)@``"@`
M``#JF```%0```!.9```8````*9D```@```!"F0``"@```$N9```2````5ID`
M`#(```!IF0``*0```)R9```R````QID``!````#YF0``%`````J:```F````
M'YH``"<```!&F@``)@```&Z:```<````E9H```X```"RF@``"@```,&:```-
M````S)H``"<```#:F@``(`````*;```.````(YL``"`````RFP``%P```%.;
M```B````:YL``#4```".FP``$0```,2;```-````UIL```P```#DFP``#0``
M`/&;```&````_YL``!L````&G```+@```"*<```W````49P``'P```")G```
M;`````:=```<````<YT``!T```"0G0``#````*Z=```;````NYT``$4```#7
MG0``*````!V>``!!````1IX``"0```"(G@``#@```*V>```/````O)X```X`
M``#,G@``#@```-N>```(````ZIX```X```#SG@``#@````*?```)````$9\`
M`!H````;GP``,P```#:?``!1````:I\``#(```"\GP``.````.^?``!4````
M**```%$```!]H```6@```,^@``!7````*J$``#0```""H0``!0```+>A```#
M````O:$``!$```#!H0``"````-.A```.````W*$```@```#KH0``"@```/2A
M```0````_Z$```\````0H@``#P```""B```*````,*(```<````[H@```P``
M`$.B```)````1Z(```T```!1H@``$@```%^B```/````<J(```H```""H@``
M#P```(VB```(````G:(```H```"FH@``)````+&B```7````UJ(``!@```#N
MH@``%`````>C```6````'*,```@````SHP``'````#RC```M````6:,``!D`
M``"'HP``7@```*&C```H`````*0``!X````II```&@```$BD```L````8Z0`
M`"````"0I```,@```+&D```'````Y*0```P```#LI```#0```/FD``!2````
M!Z4``&$```!:I0``#@```+RE```#````RZ4```L```#/I0``!P```-NE```'
M````XZ4```4```#KI0```P```/&E```7````]:4```H````-I@``#P```!BF
M``!.````**8``%````!WI@``0P```,BF``!"````#*<``#T```!/IP``,```
M`(VG```8````OJ<```X```#7IP``%````.:G```7````^Z<``!<````3J```
M%P```"NH```/````0Z@``",```!3J```!@```'>H```7````?J@``%$```"6
MJ```'P```.BH```U````"*D```<````^J0``!@```$:I```(````3:D```\`
M``!6J0``!@```&:I```(````;:D``!$```!VJ0``"@```(BI```+````DZD`
M`!4```"?J0``#0```+6I```3````PZD``",```#7J0``+P```/NI```'````
M*ZH```4````SJ@``$0```#FJ```,````2ZH``#````!8J@``2````(FJ```A
M````TJH``#L```#TJ@``/````#"K```K````;:L``#$```"9JP``.P```,NK
M```Y````!ZP``#4```!!K```"0```'>L```'````@:P```P```")K```!0``
M`):L```)````G*P```,```"FK```.0```*JL```&````Y*P```P```#KK```
M-0```/BL```.````+JT``$D````]K0``"@```(>M```M````DJT```L```#`
MK0``"0```,RM```)````UJT```H```#@K0``!@```.NM```)````\JT```<`
M``#\K0``+P````2N```N````-*X``%4```!CK@``+0```+FN```L````YZX`
M`"T````4KP``+0```$*O```C````<*\``",```"4KP``+0```+BO```S````
MYJ\``!4````:L```&0```#"P```I````2K```"0```!TL```4````)FP```8
M````ZK```!$````#L0``$0```!6Q```*````)[$```P````RL0``"P```#^Q
M```*````2[$```H```!6L0``$````&&Q```6````<K$``!8```")L0``!P``
M`*"Q```'````J+$``!0```"PL0``"@```,6Q```#````T+$```<```#4L0``
M!P```-RQ```&````Y+$``#@```#KL0``!0```"2R```'````*K(```8````R
ML@``"````#FR```)````0K(```X```!,L@``"@```%NR``!%````9K(```0`
M``"LL@``!P```+&R```)````N;(``!8```##L@``!````-JR```G````W[(`
M``8````'LP``"`````ZS```#````%[,```,````;LP``$P```!^S```(````
M,[,```@````\LP``"````$6S```(````3K,``"H```!7LP``*P```(*S``!3
M````KK,``$$````"M```(````$2T```&````9;0```8```!LM```#@```'.T
M```5````@K0``#X```"8M```&````->T```B````\+0``!T````3M0``"@``
M`#&U```5````/+4```(```!2M0``"@```%6U```/````8+4```\```!PM0``
M"0```("U```4````BK4``!@```"?M0``'0```+BU```3````UK4``!$```#J
MM0``!````/RU```,`````;8```8````.M@``"@```!6V```-````(+8``&(`
M```NM@``)P```)&V``!4````N;8``%\````.MP``%@```&ZW```.````A;<`
M`!P```"4MP``#P```+&W```S````P;<``"@```#UMP``1````!ZX```%````
M8[@```4```!IN```#@```&^X```5````?K@``!$```"4N```$0```*:X```1
M````N+@``!P```#*N```-0```.>X``!%````';D``!````!CN0``1P```'2Y
M```?````O+D``"4```#<N0``,P````*Z```K````-KH``#4```!BN@``0@``
M`)BZ```=````V[H``!T```#YN@``40```!>[```1````:;L``#$```![NP``
M.P```*V[``!`````Z;L``#@````JO```!0```&.\```,````:;P``!$```!V
MO```#0```(B\```7````EKP```@```"NO```#````+>\```4````Q+P```\`
M``#9O```$````.F\```(````^KP```4````#O0``$0````F]```,````&[T`
M`!`````HO0``#0```#F]```'````1[T```T```!/O0``!P```%V]```'````
M9;T```<```!MO0``"0```'6]```'````?[T``!0```"'O0``%P```)R]```F
M````M+T``$\```#;O0``"0```"N^```*````-;X```P```!`O@``)0```$V^
M```?````<[X``!````"3O@``!0```*2^```E````JKX``!(```#0O@``$P``
M`..^```K````][X``#L````COP``(````%^_```;````@+\``#8```"<OP``
M$````-._```(````Y+\``!L```#MOP``'@````G```!<````*,```"X```"%
MP```#````+3````$````P<````X```#&P```#@```-7````'````Y,````X`
M``#LP```'@```/O````;````&L$``"$````VP0``'@```%C!```>````=\$`
M`"X```"6P0``)````,7!```;````ZL$``!X````&P@``-@```"7"```S````
M7,(``"D```"0P@``00```+K"```Z````_,(``"\````WPP``(````&?#```2
M````B,,``"D```";PP``'@```,7#```6````Y,,``$$```#[PP``!P```#W$
M```&````1<0```T```!,Q```"P```%K$```5````9L0``!0```!\Q```#0``
M`)'$```8````G\0``!H```"XQ```$````-/$```=````Y,0``!D````"Q0``
M70```!S%```2````>L4```<```"-Q0``!````)7%```,````FL4``!0```"G
MQ0``.0```+S%```<````]L4``"@````3Q@```P```#S&```&````0,8```X`
M``!'Q@```@```%;&```%````6<8```4```!?Q@``!````&7&```.````:L8`
M``@```!YQ@``"````(+&```*````B\8```<```"6Q@``#0```)[&```0````
MK,8``!,```"]Q@``$P```-'&```9````Y<8``!H```#_Q@``"0```!K'```&
M````),<``!0````KQP``$P```$#'```0````5,<```P```!EQP``$0```'+'
M```7````A,<``!4```"<QP``&0```++'```+````S,<```T```#8QP``*P``
M`.;'```7````$L@``#0````JR```,P```%_(```;````D\@``#0```"OR```
M"@```.3(```8````[\@``#L````(R0``&0```$3)```6````7LD``"\```!U
MR0``!P```*7)```0````K<D``!P```"^R0``'````-O)```'````^,D```P`
M````R@``)@````W*```*````-,H``!0````_R@``"P```%3*```'````8,H`
M`"\```!HR@``#P```)C*```)````J,H```<```"RR@``%@```+K*```/````
MT<H``"T```#AR@``&@````_+```H````*LL``"X```!3RP``"P```(++```(
M````CLL```P```"7RP``(P```*3+```-````R,L``"8```#6RP``*@```/W+
M```@````*,P```@```!)S```$@```%+,```$````9<P```@```!JS```"P``
M`'/,```:````?\P``"<```":S```$@```,+,```@````U<P``!<```#VS```
M!0````[-```,````%,T```X````AS0``!0```##-```&````-LT```X````]
MS0```P```$S-```K````4,T```<```!\S0``!````(3-```.````B<T```P`
M``"8S0``"@```*7-```/````L,T``!````#`S0``%P```-'-```3````Z<T`
M`"4```#]S0``#@```"/.```1````,LX``!<```!$S@``$P```%S.```6````
M<,X``#@```"'S@``$P```,#.```%````U,X```L```#:S@``!0```.;.```-
M````[,X``!L```#ZS@``"0```!;/```=````(,\```\````^SP``%@```$[/
M```2````9<\```P```!XSP``#@```(7/```-````E,\``!D```"BSP``'```
M`+S/```8````V<\``"````#RSP``$P```!/0```#````)]```!4````KT```
M"P```$'0```3````3=```!````!AT```)P```'+0```I````FM```"P```#$
MT```*````/'0```.````&M$``#4````IT0``$0```%_1```'````<=$```4`
M``!YT0``&````'_1```3````F-$```<```"LT0``"````+31```&````O=$`
M`!L```#$T0``$````.#1```/````\=$``!`````!T@``#P```!+2```+````
M(M(```\````NT@``#````#[2```/````2](```<```!;T@``!@```&/2```*
M````:M(``!(```!UT@``#0```(C2```,````EM(```X```"CT@``0P```++2
M```]````]M(```D````TTP``"P```#[3```A````2M,``!D```!LTP``%P``
M`(;3```7````GM,``!L```"VTP``#0```-+3```,````X-,```,```#MTP``
M"````/'3```*````^M,``"`````%U```'P```";4```;````1M0``!D```!B
MU```"P```'S4```;````B-0```@```"DU```!````*W4```$````LM0```P`
M``"WU```"0```,34```.````SM0```L```#=U```&P```.G4```.````!=4`
M``\````4U0``)0```"35```J````2M4```<```!UU0``$@```'W5```;````
MD-4```0```"LU0``!P```+'5```2````N=4```H```#,U0``"````-?5```=
M````X-4``!````#^U0``#0````_6```.````'=8``!X````LU@``&@```$O6
M```$````9M8``!4```!KU@``!P```('6```(````B=8``!$```"2U@``&0``
M`*36```&````OM8``!4```#%U@``#P```-O6```1````Z]8``!H```#]U@``
M#0```!C7```0````)M<``!L````WUP``!0```%/7```$````6=<```P```!>
MUP``!````&O7```%````<-<``!H```!VUP``!0```)'7```&````E]<```\`
M``">UP``!P```*[7```B````MM<```4```#9UP``"0```-_7```"````Z=<`
M``T```#LUP``(````/K7```-````&]@```P````IV```!@```#;8```)````
M/=@```<```!'V```!@```$_8```*````5M@```0```!AV```"0```&;8```(
M````<-@```8```!YV```#0```(#8```&````CM@```0```"5V```!````)K8
M```7````G]@```4```"WV```!P```+W8```A````Q=@```0```#GV```)P``
M`.S8```&````%-D``!4````;V0``#````#'9```1````/MD```\```!0V0``
M!````&#9```-````9=D```<```!SV0``!0```'O9```=````@=D```0```"?
MV0``#````*39```*````L=D```@```"\V0``"0```,79```%````S]D``"D`
M``#5V0``)P```/_9```H````)]H```<```!0V@``!````%C:```<````7=H`
M``T```!ZV@``)P```(C:```;````L-H```P```#,V@``%@```-G:```%````
M\-H```<```#VV@``"@```/[:```/````"=L``!`````9VP``/````"K;```&
M````9]L```H```!NVP``!@```'G;```&````@-L```H```"'VP``#@```)+;
M```/````H=L```X```"QVP``'````,#;```?````W=L``!X```#]VP``(P``
M`!S<```1````0-P``!4```!2W```&````&C<```1````@=P``!````"3W```
M(P```*3<```)````R-P``!(```#2W```'0```.7<```2`````]T``!`````6
MW0``"@```"?=```%````,MT``#$````XW0``)````&K=```%````C]T```D`
M``"5W0``!````)_=```<````I-T``",```#!W0``(@```.7=```&````"-X`
M`!<````/W@``#````"?>```D````--X``",```!9W@``&@```'W>```K````
MF-X```\```#$W@``%@```-3>```H````Z]X``!<````4WP``'````"S?```3
M````2=\```L```!=WP``%````&G?```A````?M\``"````"@WP``!@```,'?
M```9````R-\```0```#BWP``!P```.??```&````[]\```8```#VWP``!0``
M`/W?```'`````^````<````+X```!0```!/@```&````&>````0````@X```
M!````"7@```"````*N````H````MX```!0```#C@```,````/N````\```!+
MX```"@```%O@```(````9N```"L```!OX```3P```)O@```N````Z^````0`
M```:X0``"````!_A```F````*.$``!(```!/X0``!@```&+A```*````:>$`
M``<```!TX0``"````'SA```@````A>$``!$```"FX0``"0```+CA```.````
MPN$``!8```#1X0``$0```.CA```&````^N$```<````!X@``$0````GB```'
M````&^(``!8````CX@``#0```#KB```A````2.(``!<```!JX@``$````(+B
M``!\````D^(``!4````0XP``&@```";C```)````0>,```H```!+XP``#@``
M`%;C```,````9>,```\```!RXP``"````(+C```&````B^,```P```"2XP``
M!P```)_C```%````I^,```L```"MXP``1P```+GC```-`````>0```,````/
MY```#````!/D```&````(.0```H````GY````@```#+D```$````->0```,`
M```ZY```!0```#[D```J````1.0```X```!OY```"@```'[D```$````B>0`
M``T```".Y```'P```)SD```'````O.0``"(```#$Y```!@```.?D```(````
M[N0```@```#WY```!`````#E```%````!>4``&@````+Y0``!0```'3E```&
M````>N4``",```"!Y0``)0```*7E```(````R^4``#<```#4Y0``(@````SF
M```0````+^8```H```!`Y@``$0```$OF```/````7>8```\```!MY@``"@``
M`'WF```)````B.8``!<```"2Y@``)@```*KF```F````T>8```,```#XY@``
M!P```/SF```4````!.<``!,````9YP``$````"WG```-````/N<```X```!,
MYP``%@```%OG```0````<N<```H```"#YP``"P```([G```'````FN<``!,`
M``"BYP``#````+;G```/````P^<```X```#3YP``#````.+G```.````[^<`
M``\```#^YP``#@````[H```-````'>@```\````KZ```#P```#OH```7````
M2^@``!0```!CZ```$0```'CH```/````BN@``"````":Z```+@```+OH```:
M````ZN@``"8````%Z0``"P```"SI```:````..D``$H```!3Z0``!@```)[I
M```)````I>D```T```"OZ0``!@```+WI```*````Q.D```<```#/Z0``%```
M`-?I```&````[.D```@```#SZ0``!P```/SI```*````!.H```L````/Z@``
M*P```!OJ```'````1^H```0```!/Z@``"0```%3J```)````7NH```H```!H
MZ@``!P```'/J```)````>^H```X```"%Z@``!P```)3J```*````G.H``!4`
M``"GZ@``"@```+WJ```)````R.H```<```#2Z@``!````-KJ```$````W^H`
M`"(```#DZ@``!P````?K```%````#^L```P````5ZP``!0```"+K```+````
M*.L``!0````TZP``!P```$GK```%````4>L``!8```!7ZP```P```&[K```-
M````<NL```P```"`ZP``"@```(WK```(````F.L```L```"AZP``#````*WK
M```$````NNL```0```"_ZP``#````,3K```)````T>L```P```#;ZP``"0``
M`.CK```%````\NL```<```#XZP``!`````#L```"````!>P``!0````([```
M#0```!WL```2````*^P```L````^[```&P```$KL```?````9NP```\```"&
M[```%````);L```>````J^P``!4```#*[```"@```.#L```N````Z^P``!``
M```:[0``$P```"OM```J````/^T``!D```!J[0``'````(3M```?````H>T`
M`!0```#![0``(````-;M```M````]^T``"T````E[@``,0```%/N```M````
MA>X``"X```"S[@``+P```.+N```L````$N\``"4````_[P``)````&7O```I
M````BN\``"0```"T[P``$@```-GO```.````[.\``!(```#[[P``#P````[P
M```$````'O````X````C\```!@```#+P```&````.?````L```!`\```"0``
M`$SP```-````5O````P```!D\```%P```''P```4````B?```!````">\```
M%@```*_P```'````QO````X```#.\```(0```-WP```%````__````8````%
M\0``"`````SQ```1````%?$``$0````G\0``/````&SQ```.````J?$```(`
M``"X\0```@```+OQ```'````OO$```8```#&\0``#````,WQ```C````VO$`
M``0```#^\0``,@````/R```?````-O(``#,```!6\@``#````(KR```+````
ME_(``!0```"C\@``#0```+CR```4````QO(```<```#;\@``#@```./R```,
M````\O(``!,```#_\@``"@```!/S```%````'O,``!$````D\P``$P```#;S
M```-````2O,``!$```!8\P``)````&KS```#````C_,``!4```"3\P``$P``
M`*GS```2````O?,```L```#0\P``-````-SS```.````$?0```L````@]```
M%````"ST```^````0?0```X```"`]```$P```(_T```T````H_0``#$```#8
M]```$@````KU```0````'?4``!@````N]0``&0```$?U```C````8?4``"(`
M``"%]0``)P```*CU``!6````T/4``$T````G]@``N````'7V```(````+O<`
M``D````W]P``!````$'W```<````1O<```T```!C]P``)P```''W```;````
MF?<```P```"U]P``"@```,+W```-````S?<``"(```#;]P``(0```/[W```(
M````(/@```4````I^```!@```"_X```0````-O@```@```!'^```!P```%#X
M```*````6/@``!(```!C^```(0```';X```+````F/@``!P```"D^```&```
M`,'X```(````VO@``!(```#C^```&@```/;X```)````$?D```H````;^0``
M%0```";Y```%````//D``!0```!"^0``'@```%?Y```H````=OD```H```"?
M^0``#P```*KY```M````NOD```@```#H^0``%````/'Y```L````!OH``"<`
M```S^@``*P```%OZ```J````A_H```0```"R^@``"P```+?Z```%````P_H`
M``@```#)^@``,0```-+Z```<````!/L``#0````A^P``-````%;[```G````
MB_L``"````"S^P``&@```-3[```H````[_L``!H````8_```=@```#/\``!Y
M````JOP``!P!```D_0``*````$'^```=````:OX``"D```"(_@``'0```++^
M```N````T/X``%<```#__@``-@```%?_```L````CO\``"P```"[_P``,0``
M`.C_```N````&@`!``8```!)``$`"````%```0`0````60`!`"L```!J``$`
M(0```)8``0`'````N``!`!````#```$`#0```-$``0`%````WP`!``@```#E
M``$`"P```.X``0`4````^@`!``<````/`0$`$P```!<!`0`V````*P$!`#<`
M``!B`0$`"0```)H!`0`*````I`$!`!0```"O`0$`#P```,0!`0`O````U`$!
M`#(````$`@$`"P```#<"`0`.````0P(!``T```!2`@$`#P```&`"`0`6````
M<`(!`#X```"'`@$`)P```,8"`0`F````[@(!`"0````5`P$`!0```#H#`0`%
M````0`,!`"<```!&`P$`'P```&X#`0`6````C@,!``L```"E`P$`%P```+$#
M`0`>````R0,!``L```#H`P$`#@```/0#`0`.`````P0!``D````2!`$`"```
M`!P$`0`0````)00!`!4````V!`$`$P```$P$`0`'````8`0!`!X```!H!`$`
M%0```(<$`0`4````G00!``8```"R!`$`"P```+D$`0`C````Q00!`!8```#I
M!`$`#P`````%`0`.````$`4!``8````?!0$`#````"8%`0`8````,P4!``T`
M``!,!0$`"P```%H%`0`-````9@4!``H```!T!0$`"P```'\%`0`/````BP4!
M`!````";!0$`+@```*P%`0`Z````VP4!``X````6!@$`#0```"4&`0`%````
M,P8!``L````Y!@$`#````$4&`0`-````4@8!``T```!@!@$`#@```&X&`0`-
M````?08!`"````"+!@$`)P```*P&`0`K````U`8!``@`````!P$`"@````D'
M`0`&````%`<!`!(````;!P$`#@```"X'`0`7````/0<!`!X```!5!P$`%@``
M`'0'`0`<````BP<!`!0```"H!P$`!0```+T'`0`.````PP<!`!,```#2!P$`
M&@```.8'`0`'`````0@!``8````)"`$`$P```!`(`0`4````)`@!`!$````Y
M"`$`2P```$L(`0`'````EP@!`!@```"?"`$`!````+@(`0`'````O0@!``H`
M``#%"`$`"P```-`(`0`,````W`@!``X```#I"`$`$@```/@(`0`&````"PD!
M``8````2"0$`%@```!D)`0`8````,`D!``X```!)"0$`-P```%@)`0`1````
MD`D!``X```"B"0$`%P```+$)`0!!````R0D!`#0````+"@$`)0```$`*`0`5
M````9@H!`#$```!\"@$`$P```*X*`0`;````P@H!`"H```#>"@$`40````D+
M`0!:````6PL!`%````"V"P$`O@````<,`0`E````Q@P!``D```#L#`$``P``
M`/8,`0`*````^@P!``@````%#0$`$`````X-`0`(````'PT!``P````H#0$`
M%0```#4-`0`+````2PT!`!D```!7#0$`(````'$-`0`%````D@T!``H```"8
M#0$`#````*,-`0`$````L`T!``D```"U#0$`!P```+\-`0`R````QPT!``H`
M``#Z#0$`#`````4.`0`+````$@X!``<````>#@$`%@```"8.`0`Z````/0X!
M`"````!X#@$`#P```)D.`0`Y````J0X!``8```#C#@$`"0```.H.`0`.````
M]`X!``0````##P$`!@````@/`0`6````#P\!``P````F#P$`#0```#,/`0`.
M````00\!`$,```!0#P$`"@```)0/`0`U````GP\!`!$```#5#P$`"P```.</
M`0`:````\P\!`!<````.$`$`)P```"80`0`;````3A`!`!H```!J$`$`%P``
M`(40`0`;````G1`!`!D```"Y$`$`'P```-,0`0`7````\Q`!`!P````+$0$`
M%P```"@1`0`,````0!$!`!,```!-$0$`+P```&$1`0`'````D1$!`!````"9
M$0$`$0```*H1`0`)````O!$!``T```#&$0$`!@```-01`0`=````VQ$!``<`
M``#Y$0$``P````$2`0!#````!1(!`#(```!)$@$`/P```'P2`0`W````O!(!
M`%<```#T$@$`!0```$P3`0`*````4A,!``T```!=$P$`$@```&L3`0`I````
M?A,!``T```"H$P$`<````+83`0`_````)Q0!`#D```!G%`$`1@```*$4`0`$
M````Z!0!`!````#M%`$`$````/X4`0`,````#Q4!`!0````<%0$`'0```#$5
M`0`<````3Q4!`!$```!L%0$`/0```'X5`0`E````O!4!`"````#B%0$`)P``
M``,6`0`:````*Q8!`!T```!&%@$`*````&06`0`/````C18!`"0```"=%@$`
M)0```,(6`0`%````Z!8!``4```#N%@$`#````/06`0`9`````1<!``D````;
M%P$`$P```"47`0`&````.1<!``D```!`%P$`!````$H7`0`0````3Q<!``@`
M``!@%P$`"````&D7`0`/````<A<!``<```""%P$`#@```(H7`0`/````F1<!
M``P```"I%P$`%````+87`0`4````RQ<!``\```#@%P$`#@```/`7`0`2````
M_Q<!``P````2&`$`&P```!\8`0`L````.Q@!``4```!H&`$`!````&X8`0`,
M````<Q@!`!<```"`&`$`$@```)@8`0`+````JQ@!``T```"W&`$`%````,48
M`0`O````VA@!``H````*&0$`#````!49`0`)````(AD!``D````L&0$`!0``
M`#89`0`1````/!D!``8```!.&0$`#@```%49`0`0````9!D!`!$```!U&0$`
M"````(<9`0`'````D!D!``T```"8&0$`!@```*89`0`6````K1D!``<```#$
M&0$`)@```,P9`0`X````\QD!`!H````L&@$`*@```$<:`0`9````<AH!``4`
M``",&@$`"P```)(:`0`'````GAH!``X```"F&@$`"````+4:`0`)````OAH!
M``8```#(&@$`&0```,\:`0`:````Z1H!`"`````$&P$`"P```"4;`0`4````
M,1L!``8```!&&P$`&0```$T;`0`*````9QL!`!P```!R&P$`!0```(\;`0`%
M````E1L!`!````";&P$`&@```*P;`0`4````QQL!`"\```#<&P$`"0````P<
M`0`(````%AP!`!\````?'`$`,0```#\<`0`B````<1P!`"````"4'`$`)@``
M`+4<`0`=````W!P!`!P```#Z'`$`70```!<=`0`M````=1T!`#,```"C'0$`
M2P```-<=`0`L````(QX!`"4```!0'@$`(0```'8>`0`>````F!X!`'4```"W
M'@$`/@```"T?`0!"````;!\!`#T```"O'P$`/0```.T?`0`I````*R`!`"D`
M``!5(`$`,0```'\@`0`O````L2`!`",```#A(`$`3P````4A`0`V````52$!
M`#X```",(0$`,````,LA`0`@````_"$!`#\````=(@$`-````%TB`0`=````
MDB(!`!X```"P(@$`*@```,\B`0!@````^B(!`#0```!;(P$`/````)`C`0`X
M````S2,!`*<````&)`$`(0```*XD`0`?````T"0!`#P```#P)`$`)````"TE
M`0`H````4B4!`"(```![)0$`*0```)XE`0`7````R"4!`"D```#@)0$`(```
M``HF`0`R````*R8!`!P```!>)@$`+@```'LF`0`X````JB8!`"<```#C)@$`
M/`````LG`0`F````2"<!`!\```!O)P$`,0```(\G`0!!````P2<!`#X````#
M*`$`/@```$(H`0!'````@2@!`#,```#)*`$`)0```/TH`0!3````(RD!`%<`
M``!W*0$`50```,\I`0!&````)2H!`"H```!L*@$`+P```)<J`0!5````QRH!
M`"`````=*P$`*P```#XK`0`P````:BL!`"H```";*P$`/@```,8K`0!2````
M!2P!`#(```!8+`$`*P```(LL`0`J````MRP!`"8```#B+`$`+`````DM`0!.
M````-BT!`#````"%+0$`'0```+8M`0`C````U"T!`"\```#X+0$`+````"@N
M`0`7````52X!`"(```!M+@$`.P```)`N`0`G````S"X!`$X```#T+@$`1P``
M`$,O`0!B````BR\!`$D```#N+P$`50```#@P`0!`````CC`!`"\```#/,`$`
M,@```/\P`0`K````,C$!`"D```!>,0$`#P```(@Q`0!%````F#$!`#````#>
M,0$`+0````\R`0`Q````/3(!``L```!O,@$`!````'LR`0`+````@#(!``4`
M``",,@$``@```)(R`0`*````E3(!`%8```"@,@$`60```/<R`0`%````43,!
M``0```!7,P$`!P```%PS`0`(````9#,!``4```!M,P$`%P```',S`0`,````
MBS,!``T```"8,P$`$P```*8S`0`-````NC,!``<```#(,P$`!@```-`S`0`4
M````US,!``P```#L,P$`!@```/DS`0`#`````#0!``0````$-`$`!@````DT
M`0`'````$#0!`!<````8-`$`(````#`T`0`:````430!`!@```!L-`$`)@``
M`(4T`0`*````K#0!`!,```"W-`$`"````,LT`0`6````U#0!``P```#K-`$`
M'P```/@T`0`4````&#4!``X````M-0$`#0```#PU`0`'````2C4!``P```!2
M-0$`#P```%\U`0`1````;S4!`!$```"!-0$`!P```),U`0`&````FS4!`!H`
M``"B-0$`%0```+TU`0`&````TS4!`!T```#:-0$`&````/@U`0`&````$38!
M``<````8-@$`$0```"`V`0`>````,C8!``0```!1-@$`1@```%8V`0`,````
MG38!`!$```"J-@$`"````+PV`0`=````Q38!``D```#C-@$`"@```.TV`0`4
M````^#8!``H````--P$`"````!@W`0`'````(3<!``D````I-P$`!P```#,W
M`0`(````.S<!``0```!$-P$`!P```$DW`0`2````43<!`"8```!D-P$`&0``
M`(LW`0`8````I3<!``L```"^-P$`#@```,HW`0`9````V3<!``H```#S-P$`
M)````/XW`0`A````(S@!``H```!%.`$`$P```%`X`0`G````9#@!``D```",
M.`$`#P```)8X`0`7````IC@!`!0```"^.`$`*````-,X`0`/````_#@!`"``
M```,.0$`%````"TY`0`1````0CD!``<```!4.0$``P```%PY`0`&````8#D!
M``<```!G.0$`#0```&\Y`0`+````?3D!`!0```").0$`%0```)XY`0`.````
MM#D!`"\```##.0$`6@```/,Y`0`_````3CH!`#8```"..@$`,0```,4Z`0`)
M````]SH!`#\````!.P$`#````$$[`0`*````3CL!`"(```!9.P$``@```'P[
M`0`$````?SL!``8```"$.P$`!0```(L[`0`#````D3L!``P```"5.P$`.P``
M`*([`0!/````WCL!`#4````N/`$`)P```&0\`0`A````C#P!`"0```"N/`$`
M'0```-,\`0!6````\3P!`#H```!(/0$`0@```(,]`0`9````QCT!`!<```#@
M/0$`BP```/@]`0`9````A#X!`"H```">/@$`*P```,D^`0!%````]3X!`"8`
M```[/P$`2P```&(_`0!.````KC\!`"<```#]/P$`*0```"5``0`A````3T`!
M`"L```!Q0`$`'0```)U``0`F````NT`!`"T```#B0`$`)0```!!!`0`I````
M-D$!`"(```!@00$`/0```(-!`0!!````P4$!`"@````#0@$`+````"Q"`0`2
M````64(!`!,```!L0@$`$````(!"`0!Y````D4(!``D````+0P$`'````!5#
M`0`0````,D,!``\```!#0P$`*0```%-#`0`G````?4,!``X```"E0P$`20``
M`+1#`0!R````_D,!`',```!Q1`$`0````.5$`0!3````)D4!`!<```!Z10$`
M*@```))%`0`T````O44!`!8```#R10$`#P````E&`0`H````&48!`!\```!"
M1@$`0````&)&`0`?````HT8!`!0```##1@$`#P```-A&`0`*````Z$8!``4`
M``#S1@$`!@```/E&`0`(`````$<!``P````)1P$`$````!9'`0`/````)T<!
M``0````W1P$`"@```#Q'`0`$````1T<!``,```!,1P$`"````%!'`0`'````
M64<!``L```!A1P$`"````&U'`0`'````=D<!``4```!^1P$`"0```(1'`0`&
M````CD<!``<```"51P$`"````)U'`0`/````ID<!``\```"V1P$`"````,9'
M`0`,````ST<!``8```#<1P$`"0```.-'`0`+````[4<!``\```#Y1P$`!@``
M``E(`0`'````$$@!``T````82`$`!@```"9(`0`'````+4@!``,````U2`$`
M"0```#E(`0`&````0T@!``P```!*2`$`"@```%=(`0`,````8D@!``H```!O
M2`$`#P```'I(`0`%````BD@!``@```"02`$`!````)E(`0`$````GD@!``,`
M``"C2`$`#````*=(`0`$````M$@!``0```"Y2`$`!P```+Y(`0`"````QD@!
M``X```#)2`$`#P```-A(`0`'````Z$@!``4```#P2`$`#@```/9(`0`.````
M!4D!`%P!```420$`"@```'%*`0`*````?$H!``@```"'2@$`0P```)!*`0`.
M````U$H!`!(```#C2@$`$0```/9*`0`'````"$L!``@````02P$`"@```!E+
M`0`(````)$L!``,````M2P$`(@```#%+`0`O````5$L!`!T```"$2P$`(@``
M`*)+`0`>````Q4L!``$```#D2P$`&0```.9+`0`*`````$P!`!\````+3`$`
M2@```"M,`0`P````=DP!`$8```"G3`$`*P```.Y,`0`8````&DT!``H````S
M30$`$````#Y-`0`/````3TT!``4```!?30$`)P```&5-`0`4````C4T!`!<`
M``"B30$`#P```+I-`0`.````RDT!`!````#930$`.0```.I-`0`>````)$X!
M`#<```!#3@$`$0```'M.`0`.````C4X!`"D```"<3@$`)````,9.`0`8````
MZTX!`!D````$3P$`$````!Y/`0`(````+T\!`!$````X3P$`.````$I/`0`?
M````@T\!``T```"C3P$`(0```+%/`0`2````TT\!`!X```#F3P$`)0````50
M`0`3````*U`!``P````_4`$`"P```$Q0`0`.````6%`!``8```!G4`$`&@``
M`&Y0`0`P````B5`!`#````"Z4`$`;@```.M0`0!C````6E$!`!\```"^40$`
M%````-Y1`0`-````\U$!`!T````!4@$`1@```!]2`0`L````9E(!`$(```"3
M4@$`*````-92`0`*````_U(!``L````*4P$`$@```!93`0`2````*5,!``@`
M```\4P$`"@```$53`0`*````4%,!``H```!;4P$`%P```&93`0`P````?E,!
M`#L```"O4P$`/P```.M3`0!(````*U0!`%P```!T5`$`60```-%4`0!B````
M*U4!`%\```".50$`00```.Y5`0`%````,%8!``$````V5@$`#@```#A6`0`.
M````1U8!`!````!65@$`"````&=6`0`/````<%8!``X```"`5@$`$@```(]6
M`0`,````HE8!``4```"O5@$`!0```+56`0`%````NU8!``P```#!5@$`$```
M`,Y6`0`6````WU8!`!D```#V5@$`#0```!!7`0`5````'E<!``H````T5P$`
M#````#]7`0`>````3%<!`!H```!K5P$`)0```(97`0`;````K%<!`"````#(
M5P$`$0```.E7`0`@````^U<!`"T````<6`$`)@```$I8`0!O````<5@!`"L`
M``#A6`$`*@````U9`0`I````.%D!`$````!B60$`(````*-9`0`X````Q%D!
M``4```#]60$`$`````-:`0`0````%%H!`%T````E6@$`90```(-:`0`-````
MZ5H!``<```#W6@$`"@```/]:`0`'````"EL!``@````26P$`!0```!M;`0`(
M````(5L!`",````J6P$`#P```$Y;`0`5````7EL!`$D```!T6P$`60```+Y;
M`0!,````&%P!`%(```!E7`$`1P```+A<`0`Y`````%T!`!<````Z70$`#```
M`%)=`0`7````7UT!`!<```!W70$`(P```(]=`0`8````LUT!`!,```#,70$`
M(P```.!=`0`&````!%X!`!D````+7@$`4````"5>`0`E````=EX!`#@```"<
M7@$`!@```-5>`0`&````W%X!``@```#C7@$`#P```.Q>`0`)````_%X!``T`
M```&7P$`&````!1?`0`*````+5\!``D````X7P$`$````$)?`0`/````4U\!
M`!4```!C7P$`)````'E?`0`P````GE\!``D```#/7P$`"````-E?`0`1````
MXE\!``X```#T7P$`)@````-@`0`S````*F`!`!X```!>8`$`*P```'U@`0`K
M````J6`!`!\```#58`$`&0```/5@`0`K````#V$!`#(````[80$`*@```&YA
M`0`)````F6$!``<```"C80$`#@```*MA`0`%````NF$!``L```#`80$`!P``
M`,QA`0`]````U&$!``8````28@$`#````!EB`0`Z````)F(!`!````!A8@$`
M3````')B`0`)````OV(!`"T```#)8@$`"@```/=B`0`,`````F,!``4````/
M8P$`"````!5C`0`(````'F,!``D````G8P$`!P```#%C`0`X````.6,!`#@`
M``!R8P$`6P```*MC`0`W````!V0!`#0````_9`$`-P```'1D`0`W````K&0!
M`"X```#D9`$`,@```!-E`0`W````1F4!`#T```!^90$`(0```+QE`0`E````
MWF4!`"\````$9@$`,0```#1F`0!M````9F8!`!H```#49@$`#@```.]F`0`7
M````_F8!``L````69P$`#````")G`0`1````+V<!``P```!!9P$``P```$YG
M`0`)````4F<!`!0```!<9P$`'P```'%G`0`,````D6<!``<```">9P$`%@``
M`*9G`0`*````O6<!``,```#(9P$`"````,QG`0`&````U6<!``8```#<9P$`
M-0```.-G`0`%````&6@!``<````?:`$`!@```"=H`0`.````+F@!``P````]
M:`$`$````$IH`0`)````6V@!`$0```!E:`$`!0```*IH`0`'````L&@!``@`
M``"X:`$`%````,%H`0`#````UF@!`!````#::`$`"````.MH`0`(````]&@!
M``,```#]:`$``P````%I`0`;````!6D!`!$````A:0$`"0```#-I`0`(````
M/6D!``<```!&:0$`*P```$YI`0`L````>FD!`%D```"G:0$`3P````%J`0`M
M````46H!``8```!_:@$`!@```(9J`0`0````C6H!`!D```">:@$`/````+AJ
M`0`=````]6H!`"P````3:P$`(````$!K`0`9````86L!`!8```![:P$``@``
M`))K`0`)````E6L!`!,```"?:P$`$P```+-K`0`)````QVL!`!8```#1:P$`
M&@```.AK`0`?`````VP!`!4````C;`$`%@```#EL`0`$````4&P!``@```!5
M;`$`!@```%YL`0`.````96P!``P```!T;`$`<P```(%L`0`I````]6P!`$8`
M```?;0$`7@```&9M`0`6````Q6T!``\```#<;0$`*````.QM`0`5````%6X!
M`"(````K;@$`+@```$YN`0`S````?6X!``4```"Q;@$`!0```+=N`0`.````
MO6X!`!@```#,;@$`"P```.5N`0`7````\6X!`!$````);P$`(````!MO`0`Y
M````/&\!`%$```!V;P$`%P```,AO`0!/````X&\!`"8````P<`$`+P```%=P
M`0`W````AW`!`#````"_<`$`,@```/!P`0`S````(W$!`!\```!7<0$`(0``
M`'=Q`0!A````F7$!`!8```#[<0$`2@```!)R`0!+````77(!`$,```"I<@$`
M/0```.UR`0`'````*W,!``P````S<P$`#P```$!S`0`0````4',!`!D```!A
M<P$`!````'MS`0`-````@',!`!8```".<P$`"P```*5S`0`-````L7,!``@`
M``"_<P$`!0```,AS`0`2````SG,!``T```#A<P$`#````.]S`0`-````_',!
M``<````*=`$`!P```!)T`0`)````&G0!``8````D=`$`!0```"MT`0`)````
M,70!``4````[=`$`%````$%T`0`4````5G0!`",```!K=`$`2@```(]T`0`)
M````VG0!``<```#D=`$`#@```.QT`0`K````^W0!`"$````G=0$`#P```$EU
M`0`%````674!`!T```!?=0$`'````'UU`0`=````FG4!`"P```"X=0$`.P``
M`.5U`0`I````(78!`",```!+=@$`/@```&]V`0`.````KG8!``@```"]=@$`
M'0```,9V`0`@````Y'8!`$X````%=P$`*@```%1W`0`+````?W<!``4```"+
M=P$`#0```)%W`0`1````GW<!``<```"Q=P$`$0```+EW`0`K````RW<!`"@`
M``#W=P$`+@```"!X`0`K````3W@!`"H```![>`$`.0```*9X`0`G````X'@!
M`"4````(>0$`*````"YY`0!"````5WD!`"T```":>0$`*P```,AY`0`T````
M]'D!`"T````I>@$`,P```%=Z`0`F````BWH!`!8```"R>@$`+0```,EZ`0`@
M````]WH!`"(````8>P$`10```#M[`0`$````@7L!``4```"&>P$`#````(Q[
M`0`,````F7L!`!8```"F>P$`$0```+U[`0`+````SWL!`!H```#;>P$`(@``
M`/9[`0`+````&7P!`"@````E?`$`'@```$Y\`0!H````;7P!`!8```#6?`$`
M"0```.U\`0`$````]WP!``L```#\?`$`$P````A]`0`T````''T!`"````!1
M?0$`00```')]`0`&````M'T!``0```"[?0$`#P```,!]`0`"````T'T!``H`
M``#3?0$`"0```-Y]`0`$````Z'T!``T```#M?0$`"````/M]`0`)````!'X!
M``L````.?@$`"````!I^`0`.````(WX!`!(````R?@$`%````$5^`0`4````
M6GX!`!T```!O?@$`&P```(U^`0`,````J7X!``0```"V?@$`&P```+M^`0`2
M````UWX!``X```#J?@$`"@```/E^`0`0````!'\!`!0````5?P$`%0```"I_
M`0`9````0'\!``P```!:?P$`#````&=_`0`N````='\!`!@```"C?P$`.0``
M`+Q_`0!%````]G\!`!L````\@`$`.@```%B``0`+````DX`!`!@```"?@`$`
M,P```+B``0`5````[(`!`!0````"@0$`-````!>!`0`(````3($!`!,```!5
M@0$`&````&F!`0`B````@H$!``4```"E@0$`$````*N!`0`J````O($!``@`
M``#G@0$`#0```/"!`0`$````_H$!``D````#@@$`,`````V"`0`1````/H(!
M``<```!0@@$`#````%B"`0`F````98(!`!(```",@@$`+0```)^"`0`>````
MS8(!`#````#L@@$`,0```!V#`0`.````3X,!``<```!>@P$`#@```&:#`0`K
M````=8,!``D```"A@P$`+@```*N#`0`D````VH,!`!\```#_@P$`'0```!^$
M`0`C````/80!``@```!AA`$`"````&J$`0`+````<X0!`!H```!_A`$`*P``
M`)J$`0`1````QH0!`!\```#8A`$`%P```/B$`0`'````$(4!``X````8A0$`
M#P```">%`0`)````-X4!``8```!!A0$`#````$B%`0`&````584!`"\```!<
MA0$`!P```(R%`0`&````E(4!`!,```";A0$`#0```*^%`0`*````O84!`!$`
M``#(A0$`$0```-J%`0`8````[(4!`!<````%A@$`*P```!V&`0`2````288!
M`!4```!<A@$`&````'*&`0`:````BX8!`!0```"FA@$`-0```+N&`0`;````
M\88!``4````-AP$`"````!.'`0`%````'(<!``L````BAP$`)0```"Z'`0`)
M````5(<!`"4```!>AP$`$@```(2'`0`8````EX<!`!4```"PAP$`$@```,:'
M`0`0````V8<!`!````#JAP$`%````/N'`0`7````$(@!`!L````HB`$`-@``
M`$2(`0`4````>X@!``8```"0B`$`'0```)>(`0`1````M8@!`!<```#'B`$`
M#@```-^(`0`Q````[H@!`#,````@B0$`.@```%2)`0`O````CXD!``X```"_
MB0$`/0```,Z)`0`0````#(H!``<````=B@$`!````"6*`0`=````*HH!`!<`
M``!(B@$`!P```&"*`0`'````:(H!``8```!PB@$`'````'>*`0`+````E(H!
M`!$```"@B@$`#````+**`0`*````OXH!`!0```#*B@$`#@```-^*`0`)````
M[HH!`!4```#XB@$`!P````Z+`0`&````%HL!``\````=BP$`&````"V+`0`-
M````1HL!``P```!4BP$`#````&&+`0`Z````;HL!`"P```"IBP$`"@```-:+
M`0`3````X8L!`"H```#UBP$`'P```"",`0`@````0(P!`"(```!AC`$`$P``
M`(2,`0`+````F(P!`!````"DC`$`!````+6,`0`$````NHP!``X```"_C`$`
M'@```,Z,`0`B````[8P!`!H````0C0$`&````"N-`0`)````1(T!`"````!.
MC0$`!P```&^-`0`%````=XT!``0```!]C0$`#P```(*-`0`+````DHT!``L`
M``">C0$`#P```*J-`0`F````NHT!`!$```#AC0$`$0```/.-`0`V````!8X!
M`"\````\C@$`!@```&R.`0`2````<XX!`!T```"&C@$`!@```*2.`0`)````
MJXX!`"(```"UC@$`#P```-B.`0`,````Z(X!`"<```#UC@$`$@```!V/`0`.
M````,(\!`!0````_CP$`)P```%2/`0`@````?(\!``@```"=CP$`$@```*:/
M`0`'````N8\!``@```#!CP$`%````,J/`0`:````WX\!``<```#ZCP$`%P``
M``*0`0`6````&I`!`!8````QD`$`(P```$B0`0`0````;)`!`!,```!]D`$`
M+@```)&0`0`'````P)`!``(```#(D`$`"````,N0`0`$````U)`!``4```#9
MD`$`'0```-^0`0`%````_9`!``8````#D0$`#`````J1`0`&````%Y$!`"L`
M```>D0$`!0```$J1`0`)````4)$!``,```!:D0$`$0```%Z1`0`E````<)$!
M`!,```"6D0$`#P```*J1`0`&````NI$!``H```#!D0$`!P```,R1`0`0````
MU)$!``D```#ED0$`!````.^1`0`)````])$!``@```#^D0$`!@````>2`0`-
M````#I(!``8````<D@$`!0```".2`0`$````*9(!`!<````ND@$`!0```$:2
M`0`(````3)(!`!<```!5D@$`!0```&V2`0`N````<Y(!``8```"BD@$`&0``
M`*F2`0`.````PY(!`!8```#2D@$`#0```.F2`0`&````]Y(!`!````#^D@$`
M"0````^3`0`&````&9,!`!P````@DP$`"````#V3`0`,````1I,!``D```!3
MDP$`"````%V3`0`(````9I,!``4```!ODP$`)0```'63`0`:````FY,!`"L`
M``"VDP$`!0```.*3`0`$````Z),!`"8```#MDP$`%P```!24`0`K````+)0!
M`"<```!8E`$`#0```("4`0`:````CI0!``@```"IE`$`"````+*4`0`+````
MNY0!``\```#'E`$`$0```->4`0!5````Z90!``<````_E0$`$````$>5`0`'
M````6)4!``8```!@E0$`$P```&>5`0`8````>Y4!`!,```"4E0$`(P```*B5
M`0`C````S)4!`"(```#PE0$`,````!.6`0`L````1)8!`!\```!QE@$`(P``
M`)&6`0`F````M98!`!H```#<E@$`%P```/>6`0`I````#Y<!``4````YEP$`
M$````#^7`0`?````4)<!`!0```!PEP$`$0```(67`0`'````EY<!``@```"?
MEP$`+````*B7`0`K````U9<!``4````!F`$`"0````>8`0`$````$9@!`"$`
M```6F`$`)P```#B8`0`H````8)@!``4```")F`$`%````(^8`0`-````I)@!
M`"H```"RF`$`*P```-V8`0`B````"9D!`"8````LF0$`$0```%.9`0`D````
M99D!`"8```"*F0$`&P```+&9`0`=````S9D!`!H```#KF0$`$0````::`0`=
M````&)H!`"@````VF@$`*0```%^:`0`&````B9H!``0```"0F@$`!````)6:
M`0`(````FIH!``8```"CF@$`!P```*J:`0`&````LIH!``<```"YF@$`!P``
M`,&:`0`'````R9H!``8```#1F@$`!@```-B:`0`(````WYH!``(```#HF@$`
M"@```.N:`0`%````]IH!`!````#\F@$`#0````V;`0`.````&YL!``H````J
MFP$`,0```#6;`0`V````9YL!`#,```">FP$`!@```-*;`0`(````V9L!`"@`
M``#BFP$`#P````N<`0`&````&YP!``D````BG`$`"P```"R<`0`%````.)P!
M``0````^G`$`&````$.<`0`/````7)P!`!8```!LG`$`&P```(.<`0`9````
MGYP!``4```"YG`$`!P```+^<`0`2````QYP!``<```#:G`$`!0```.*<`0`-
M````Z)P!`"<```#VG`$`(@```!Z=`0`6````09T!`'H```!8G0$`%P```-.=
M`0`G````ZYT!``4````3G@$`#````!F>`0`1````)IX!``X````XG@$`&0``
M`$>>`0`+````89X!``L```!MG@$`$0```'F>`0`'````BYX!`!$```"3G@$`
M%@```*6>`0!7````O)X!`!L````4GP$`!0```#"?`0`/````-I\!``D```!&
MGP$`"@```%"?`0`"````6Y\!``0```!>GP$``P```&.?`0`%````9Y\!``D`
M``!MGP$`#P```'>?`0`*````AY\!``8```"2GP$`#@```)F?`0`A````J)\!
M``@```#*GP$`)0```-.?`0`&````^9\!``<`````H`$`"`````B@`0`$````
M$:`!``4````6H`$`6P```!R@`0`&````>*`!``@```!_H`$`-````(B@`0`W
M````O:`!``T```#UH`$`+@````.A`0`O````,J$!``\```!BH0$`"0```'*A
M`0`A````?*$!`!\```">H0$`#0```+ZA`0`*````S*$!``D```#7H0$`'0``
M`.&A`0`I````_Z$!`#,````IH@$``P```%VB`0`'````8:(!`!0```!IH@$`
M%@```'ZB`0`4````E:(!`!P```"JH@$`$````,>B`0`<````V*(!`!(```#U
MH@$`"@````BC`0`.````$Z,!``D````BHP$`%````"RC`0`/````0:,!`!``
M``!1HP$`$P```&*C`0`2````=J,!`!$```")HP$`%P```)NC`0`/````LZ,!
M`!4```##HP$`$0```-FC`0`/````ZZ,!`!<```#[HP$`&P```!.D`0`8````
M+Z0!`!````!(I`$`(P```%FD`0`H````?:0!`!(```"FI`$`,0```+FD`0`-
M````ZZ0!`!\```#YI`$`6@```!FE`0`&````=*4!``@```![I0$`%````(2E
M`0`&````F:4!``H```"@I0$`"````*NE`0`2````M*4!``8```#'I0$`"```
M`,ZE`0`*````UZ4!``H```#BI0$`#0```.VE`0`P````^Z4!``8````LI@$`
M"````#.F`0`-````/*8!``X```!*I@$`#P```%FF`0`.````::8!``X```!X
MI@$`$P```(>F`0`/````FZ8!``@```"KI@$`%0```+2F`0`%````RJ8!``H`
M``#0I@$`!0```-NF`0`$````X:8!``4```#FI@$`)````.RF`0`'````$:<!
M``4````9IP$`$````!^G`0`%````,*<!``@````VIP$`$P```#^G`0`$````
M4Z<!``4```!8IP$`'0```%ZG`0`$````?*<!``X```"!IP$`#@```)"G`0`+
M````GZ<!``L```"KIP$`#0```+>G`0`/````Q:<!``H```#5IP$`"````."G
M`0`2````Z:<!``\```#\IP$`#@````RH`0`)````&Z@!``4````EJ`$`!P``
M`"NH`0`$````,Z@!``,````XJ`$`&@```#RH`0`.````5Z@!`!4```!FJ`$`
M#P```'RH`0`I````C*@!`!L```"VJ`$`#0```-*H`0`A````X*@!`"P````"
MJ0$`&P```"^I`0`*````2ZD!`!D```!6J0$`$````'"I`0`4````@:D!`#P`
M``"6J0$`(0```-.I`0`C````]:D!`"H````9J@$`'P```$2J`0`^````9*H!
M`"L```"CJ@$`*P```,^J`0`O````^ZH!`"L````KJP$`+````%>K`0`M````
MA*L!`"H```"RJP$`+0```-VK`0`N````"ZP!`"P````ZK`$`-````&>L`0`5
M````G*P!``T```"RK`$`&````,"L`0`1````V:P!``4```#KK`$`!P```/&L
M`0`(````^:P!``@````"K0$`"P````NM`0`)````%ZT!``@````AK0$`"P``
M`"JM`0`4````-JT!`!8```!+K0$`%0```&*M`0`3````>*T!``P```",K0$`
M#@```)FM`0`E````J*T!``4```#.K0$`!0```-2M`0`(````VJT!``T```#C
MK0$`9@```/&M`0!?````6*X!``X```"XK@$``@```,>N`0`#````RJX!``L`
M``#.K@$`!0```-JN`0`0````X*X!`"H```#QK@$`!````!RO`0`V````(:\!
M`"<```!8KP$`,@```("O`0`2````LZ\!``T```#&KP$`%````-2O`0`.````
MZ:\!`!D```#XKP$`!0```!*P`0`(````&+`!``L````AL`$`%P```"VP`0`+
M````1;`!``0```!1L`$`#P```%:P`0`3````9K`!``H```!ZL`$`$````(6P
M`0`G````EK`!``,```"^L`$`$@```,*P`0`6````U;`!`!H```#LL`$`"@``
M``>Q`0`Z````$K$!``X```!-L0$`"0```%RQ`0`6````9K$!`$$```!]L0$`
M$P```+^Q`0`<````T[$!`#````#PL0$`+0```"&R`0`<````3[(!`!\```!L
ML@$`*````(RR`0`L````M;(!`!H```#BL@$`&P```/VR`0`K````&;,!`%4`
M``!%LP$`4````)NS`0##````[+,!``<```"PM`$`"P```+BT`0`$````Q+0!
M`"@```#)M`$`#@```/*T`0`K`````;4!`!X````MM0$`#0```$RU`0`,````
M6K4!``X```!GM0$`*0```':U`0`I````H+4!``@```#*M0$`!0```-.U`0`&
M````V;4!`!$```#@M0$`"````/*U`0`&````^[4!``4````"M@$`$`````BV
M`0`:````&;8!``8````TM@$`&````#NV`0`6````5+8!``4```!KM@$`$P``
M`'&V`0`6````A;8!``8```"<M@$`!P```*.V`0`3````J[8!``4```"_M@$`
M$````,6V`0`:````UK8!`"P```#QM@$`"P```!ZW`0`/````*K<!`#@````Z
MMP$`"````'.W`0`3````?+<!`#(```"0MP$`)P```,.W`0`N````Z[<!`"H`
M```:N`$`!````$6X`0`(````2K@!``<```!3N`$`"````%NX`0!`````9+@!
M`"````"EN`$`)````,:X`0`@````Z[@!`"8````,N0$`'P```#.Y`0`;````
M4[D!`"(```!ON0$`&````)*Y`0!J````J[D!`&T````6N@$`0@$``(2Z`0`6
M````Q[L!`!@```#>NP$`)@```/>[`0`D````'KP!`"\```!#O`$`40```'.\
M`0`T````Q;P!`"````#ZO`$`+0```!N]`0`L````2;T!`!L```!VO0$`!@``
M`)*]`0`*````F;T!`!4```"DO0$`*@```+J]`0`=````Y;T!``<````#O@$`
M%`````N^`0`1````(+X!``8````RO@$`"0```#F^`0`.````0[X!`!<```!2
MO@$`!P```&J^`0`-````<KX!`#\```"`O@$`/P```,"^`0`)`````+\!``\`
M```*OP$`&P```!J_`0`>````-K\!`#D```!5OP$`.@```(^_`0`)````RK\!
M`!4```#4OP$`$````.J_`0`/````^[\!`!H````+P`$`-````";``0`?````
M6\`!`!\```![P`$`'@```)O``0`%````NL`!``D```#`P`$`.0```,K``0`T
M````!,$!`"L````YP0$`#0```&7!`0`>````<\$!`"0```"2P0$`"0```+?!
M`0`.````P<$!``P```#0P0$`#P```-W!`0`*````[<$!`!0```#XP0$`%P``
M``W"`0`8````)<(!``<````^P@$`(0```$;"`0`6````:,(!`!8```!_P@$`
M"0```);"`0`/````H,(!`",```"PP@$`&````-3"`0`/````[<(!``X```#]
MP@$`!`````S#`0`)````$<,!`!0````;PP$`#````###`0`)````/<,!``L`
M``!'PP$`!````%/#`0`0````6,,!`!8```!IPP$`(````(##`0!)````H<,!
M`#\```#KPP$`%0```"O$`0`)````0<0!``D```!+Q`$`$@```%7$`0`3````
M:,0!`!@```!\Q`$`$````)7$`0`3````IL0!`!@```"ZQ`$`,P```-/$`0`T
M````!\4!`"H````\Q0$`#````&?%`0`-````=,4!``H```""Q0$`&@```(W%
M`0`2````J,4!`#L```"[Q0$`(0```/?%`0`M````&<8!`"$```!'Q@$`$@``
M`&G&`0`%````?,8!``T```""Q@$`$P```)#&`0`C````I,8!``8```#(Q@$`
M!0```,_&`0`1````U<8!`"$```#GQ@$`#P````G'`0!2````&<<!``<```!L
MQP$`&0```'3'`0`$````CL<!``<```"3QP$`$@```)O'`0`,````KL<!``T`
M``"[QP$`'````,G'`0`%````YL<!``8```#LQP$`!@```//'`0`A````^L<!
M`!T````<R`$`#0```#K(`0`]````2,@!`!$```"&R`$`#````)C(`0`=````
MI<@!`#(```##R`$`,P```/;(`0`H````*LD!`!\```!3R0$`.````'/)`0`4
M````K,D!`"L```#!R0$`+@```.W)`0!4````',H!`&T```!QR@$`6````-_*
M`0##````.,L!`"@```#\RP$`"P```"7,`0`#````,<P!``P````US`$`"@``
M`$+,`0`3````3<P!`!````!AS`$`#0```'+,`0`3````@,P!``L```"4S`$`
M%P```*#,`0`9````N,P!``4```#2S`$`"@```-C,`0`0````X\P!``8```#T
MS`$`"P```/O,`0`)````!\T!`$$````1S0$`#````%/-`0`,````8,T!`!$`
M``!MS0$`"P```'_-`0`B````B\T!`$````"NS0$`)@```._-`0`<````%LX!
M`#@````SS@$`!@```&S.`0`)````<\X!`!,```!]S@$`"````)'.`0`'````
MFLX!`!(```"BS@$`#0```+7.`0`,````P\X!``P```#0S@$`/P```-W.`0`0
M````'<\!`$8````NSP$`#0```'7/`0`,````@\\!`!L```"0SP$`%````*S/
M`0`<````P<\!`!X```#>SP$`&P```/W/`0`5````&=`!`!H````OT`$`&```
M`$K0`0`?````8]`!`!D```"#T`$`*@```)W0`0`=````R-`!`!````#FT`$`
M&0```/?0`0!!````$=$!``<```!3T0$`%@```%O1`0`7````<M$!``@```"*
MT0$`#0```)/1`0`&````H=$!`"````"HT0$`!P```,G1`0`%````T=$!`#4`
M``#7T0$`2@````W2`0`^````6-(!`#4```"7T@$`5@```,W2`0`,````)-,!
M``@````QTP$`$P```#K3`0`<````3M,!`#4```!KTP$`"P```*'3`0!?````
MK=,!`#(````-U`$`1````$#4`0`^````A=0!``4```#$U`$`%P```,K4`0`8
M````XM0!``X```#[U`$`&@````K5`0`?````)=4!`"$```!%U0$`%@```&?5
M`0!#````?M4!`#,```#"U0$`)0```/;5`0`Y````'-8!`!X```!6U@$`%P``
M`'76`0`U````C=8!``P```##U@$`*0```-#6`0`R````^M8!``@````MUP$`
M"````#;7`0`,````/]<!`#````!,UP$`!@```'W7`0`0````A-<!``D```"5
MUP$`"````)_7`0`'````J-<!`!@```"PUP$`"````,G7`0`(````TM<!``X`
M``#;UP$`!P```.K7`0`1````\M<!`!D````$V`$`#@```![8`0`6````+=@!
M`!T```!$V`$`$````&+8`0`/````<]@!`!<```"#V`$`$0```)O8`0`A````
MK=@!`!(```#/V`$`"0```.+8`0`$````[-@!``T```#QV`$`&0```/_8`0`/
M````&=D!`!,````IV0$`$P```#W9`0`>````4=D!`#0```!PV0$`#P```*79
M`0`/````M=D!``X```#%V0$`"0```-39`0`%````WMD!`!0```#DV0$`!@``
M`/G9`0`,`````-H!`!$````-V@$`#P```!_:`0`*````+]H!``4````ZV@$`
M"P```$#:`0`&````3-H!`"(```!3V@$`"0```';:`0`@````@-H!`"````"A
MV@$`%@```,+:`0`@````V=H!`!D```#ZV@$`!0```!3;`0`(````&ML!``P`
M```CVP$`%````##;`0`'````1=L!``4```!-VP$`!P```%/;`0`9````6]L!
M`!<```!UVP$`&````(W;`0`*````IML!``4```"QVP$`!@```+?;`0`&````
MOML!``L```#%VP$`"````-';`0`'````VML!``H```#BVP$`#@```.W;`0`9
M````_-L!`!4````6W`$`.@```"S<`0`+````9]P!``D```!SW`$`)````'W<
M`0`R````HMP!`!P```#5W`$`'````/+<`0`?````#]T!`"`````OW0$`)```
M`%#=`0!N````==T!`"<```#DW0$`.P````S>`0!,````2-X!`"8```"5W@$`
M,````+S>`0`E````[=X!`"(````3WP$`?P```#;?`0!&````MM\!`$(```#]
MWP$`.@```$#@`0`[````>^`!`!T```"WX`$`'````-7@`0`O````\N`!`#(`
M```BX0$`(````%7A`0!2````=N$!`#L```#)X0$`/P````7B`0`R````1>(!
M`!L```!XX@$`/0```)3B`0`R````TN(!`!L````%XP$`(````"'C`0`M````
M0N,!`%\```!PXP$`.P```-#C`0`O````#.0!`"L````\Y`$`=P```&CD`0`<
M````X.0!`!P```#]Y`$`-0```!KE`0`?````4.4!`!P```!PY0$`'````(WE
M`0`M````JN4!`!````#8Y0$`*0```.GE`0`2````$^8!`"L````FY@$`$0``
M`%+F`0`J````9.8!`#H```"/Y@$`(P```,KF`0!$````[N8!`!D````SYP$`
M(````$WG`0`S````;N<!`$<```"BYP$`0P```.KG`0!+````+N@!`%$```!Z
MZ`$`+@```,SH`0`L````^^@!`%0````HZ0$`4@```'WI`0!3````T.D!`$<`
M```DZ@$`1P```&SJ`0`X````M.H!`%4```#MZ@$`)@```$/K`0`P````:NL!
M`#,```";ZP$`+@```,_K`0!/````_NL!`%X```!.[`$`*0```*WL`0`N````
MU^P!`#$````&[0$`'0```#CM`0`R````5NT!`%$```")[0$`.````-OM`0`A
M````%.X!`"0````V[@$`*@```%ON`0`J````ANX!`!8```"Q[@$`(0```,CN
M`0`O````ZNX!`"T````:[P$`0@```$CO`0!#````B^\!`(8```#/[P$`20``
M`%;P`0!$````H/`!`#,```#E\`$`-0```!GQ`0`X````3_$!`#$```"(\0$`
M+@```+KQ`0`,````Z?$!`$(```#V\0$`.````#GR`0`P````<O(!`#\```"C
M\@$`#0```./R`0`$````\?(!``P```#V\@$`!0````/S`0`"````"?,!``@`
M```,\P$`5P```!7S`0!>````;?,!``0```#,\P$`!````-'S`0`'````UO,!
M``4```#>\P$`!0```.3S`0`?````ZO,!``P````*]`$`#0```!?T`0`1````
M)?0!`!`````W]`$`!P```$CT`0`&````4/0!`!0```!7]`$`#````&ST`0`&
M````>?0!``,```"`]`$`!````(3T`0`&````B?0!``<```"0]`$`&@```)CT
M`0`I````L_0!`",```#=]`$`*`````'U`0`M````*O4!``X```!8]0$`&0``
M`&?U`0`'````@?4!`!4```")]0$`#0```)_U`0`B````K?4!`!P```#0]0$`
M#P```.WU`0`#````_?4!``@````!]@$`#0````KV`0`2````&/8!`!`````K
M]@$`"@```#SV`0`)````1_8!``L```!1]@$`&@```%WV`0`;````>/8!``H`
M``"4]@$`(@```)_V`0`A````PO8!``<```#D]@$`!P```.SV`0`7````]/8!
M`!X````,]P$`"@```"OW`0!%````-O<!`!$```!\]P$`%P```([W`0`1````
MIO<!`"8```"X]P$`$@```-_W`0`3````\O<!`!<````&^`$`"@```![X`0`'
M````*?@!``<````Q^`$`"0```#GX`0`&````0_@!``<```!*^`$`!0```%+X
M`0`(````6/@!`!L```!A^`$`)P```'WX`0`@````I?@!`"$```#&^`$`#@``
M`.CX`0`3````]_@!`!`````+^0$`#0```!SY`0`B````*OD!`"(```!-^0$`
M$@```'#Y`0`<````@_D!`"T```"@^0$`$````,[Y`0`7````W_D!`!H```#W
M^0$`)````!+Z`0`G````-_H!`!$```!?^@$`)````''Z`0`<````EOH!``\`
M``"S^@$`"P```,/Z`0`#````S_H!``H```#3^@$`!@```-[Z`0`+````Y?H!
M``H```#Q^@$`%0```/SZ`0`6````$OL!`!`````I^P$`,P```#K[`0!5````
M;OL!`#T```#$^P$`1P````+\`0`W````2OP!``L```""_`$`3P```([\`0`.
M````WOP!``T```#M_`$`(@```/O\`0`"````'OT!``0````A_0$`!@```";]
M`0`%````+?T!``,````S_0$`$````#?]`0`J````2/T!`$````!S_0$`)0``
M`+3]`0`G````VOT!`!H````"_@$`%P```!W^`0`;````-?X!`$$```!1_@$`
M-@```)/^`0`]````ROX!`!H````(_P$`%@```"/_`0!S````.O\!`!````"N
M_P$`*0```+__`0`K````Z?\!`"<````5``(`,````#T``@!4````;@`"`%<`
M``##``(`*0```!L!`@`A````10$"`!T```!G`0(`-````(4!`@`<````N@$"
M`#,```#7`0(`.0````L"`@`R````10("`"8```!X`@(`)P```)\"`@!)````
MQP("`$@````1`P(`'@```%H#`@`I````>0,"`!$```"C`P(`#@```+4#`@`0
M````Q`,"`($```#5`P(`"P```%<$`@`C````8P0"`!,```"'!`(`%````)L$
M`@`O````L`0"`"8```#@!`(`#`````<%`@!,````%`4"`%T```!A!0(`7@``
M`+\%`@!+````'@8"`%\```!J!@(`'````,H&`@`P````YP8"`#`````8!P(`
M$P```$D'`@`<````70<"`"0```!Z!P(`(````)\'`@!`````P`<"`"8````!
M"`(`%0```"@(`@`,````/@@"``H```!+"`(`!````%8(`@`&````6P@"``@`
M``!B"`(`#0```&L(`@`4````>0@"``X```"."`(`!````)T(`@`1````H@@"
M``0```"T"`(``P```+D(`@`*````O0@"``D```#("`(`#````-((`@`(````
MWP@"``8```#H"`(`!@```.\(`@`.````]@@"``T````%"0(`"````!,)`@`(
M````'`D"`!(````E"0(`#0```#@)`@`&````1@D"``P```!-"0(`"P```%H)
M`@`*````9@D"``\```!Q"0(`#````($)`@`.````C@D"``<```"="0(`$```
M`*4)`@`-````M@D"``8```#$"0(`!P```,L)`@`,````TPD"``P```#@"0(`
M$P```.T)`@`0`````0H"`!`````2"@(`"0```",*`@`.````+0H"``8````\
M"@(`"0```$,*`@`$````30H"``(```!2"@(`!0```%4*`@`-````6PH"``4`
M``!I"@(`!0```&\*`@`(````=0H"``,```!^"@(`#````((*`@`-````CPH"
M``D```"="@(`!0```*<*`@`2````K0H"`!$```#`"@(``0```#4%```2!```
M804```````````````````@"``"!`0``)@$`````````````1P(``#<````W
M`P``U@0``/($```9`0```````'X%`````````````)0#``"U`````````((&
M````````70,``+0&``""!```+`8```````!A`P``[08``!(````3````!0<`
M`!H%``!``@``LP,```````#1`@```````/8#```U``````````X#``"?!```
MX@`````````U`0``^`(``(X!``!#!0``V@$``/0"`````````````",%````
M````W0(``-0!````````0@```#T!``"A!0``A0$``%0!``"/`0``'P(``,0!
M```[`0``JP``````````````TP$``/P%```J`@``G`,````&````````000`
M`+D#``#.!@``E@8``#4$``![!@```@4``(0!``#A`@``L@8``$,!````````
M[@0``%H%``#G!````````"4$``!X!@``````````````````I@$``,P&```8
M`0``&`0``*D&`````````````-\```"^!0```````+0#``#8!@``````````
M````````7@0``-8%````````%08``%P%``#2`P```````+@%````````=08`
M`&P```"0!0``M`0``$X&``"8`0```````*$```#K`0```````'X"````````
M`````)<%``#"````'P```'$#````````Z````*T%``"Z`````````+T$``",
M!@``[0$``)X%````````$@8``)H#``!2!@```0(``',&``!;`P``EP,``,H"
M``#D!0``=04``-H%``"*!```)P4``)$`````````5@```%T&``"O!0``````
M`'X$```]`P````````<&``"W`P```````"<&``"Q!@``]@````D&``"P`P``
M`````.\```#8````L````/P#```T`P``*P,``,4&````````;P,```D`````
M````S@```#$"``!.`@``Z`(```````"U!0````````,$``#S!````````*("
M`````````````#`$``"]`0``6@8``-4"```4!0``$@4``&0!````````908`
M``````!)`P``W00``'T&``#*````H@```(L```#H!````````!T&``"6````
M`````#8`````````80(``,T&````````JP0```8%``!D!@``3`8``%T%``"4
M````K@4`````````````;04``*8$````````5@,``/@```#Q`@``````````
M``#;`0``5@8``&4#`````````````(<$``#!````(@$``,8#````````*P$`
M`*`#``````````````````#;!0``DP(``$@&``"H!@``=0```+D&```/`0``
ME@0```````!M`0``%P$``````````````````/X#`````````````&0"```.
M`0```````&<!``#,`0``4`8`````````````'`0```$#````````60,``!L#
M``!_`@``Y0```%$&``#"!```5P4``"P!``#N`@```````$8`````````*0(`
M`#L$```M!0```````#P&``!N````+`(``,(!```M`@``A@8``!H&``"?!@``
MB0,``#P```"Y````M08```````!=`0``F`,```H#````````7`8``*T"``!C
M````40$```X&``#@````9P4``-`$````````#P8``.$$```_````K0``````
M``!J`P```````.0"``#2````\`(``'H````E`0``I08```````"C````````
M`+L&``!8`@``W0,``$0&``"F`@```````),!``!3`P``0`8``$L````6````
M6@```.L$````````#`(```P%`````````````&`%``!P!```"@8``-(&``"@
M!@``S@4```````!%`@``_04``+<%```S`0``YP$```````!"`0```````"("
M``!V`````````````````````````#$!``!I!@``V00``.P!````````````
M`$<$````````G@0``"0!``"X!```Z@````````##!0``-@0```````"V!0``
M'P,``',#``"]`P```````#4#``#S!@``5`8``'8!````````&@$``(D!````
M````W0```"H!```#!P``.@8``)$%``!1````B@4``$D````_`@```````$D&
M```````````````````I`0``S@$``*\$```>`@``WP0``.("``"C!@``[```
M````````````BP8```````#9`@``)@0``,0"````````80````````!+!0``
M,`(``*H!``#D!`````````('````````^0(``/@#``!Y`P``!P0```````#J
M`P``4P```,`"``#/`@``5P8``!P#````````<@$``"@"``#A`P``````````
M```Q!```;0,``$$&``#S`@``#04``#$&``#]!````````$4$``!W`0``PP,`
M`&X#````````U0$``/4&````````B@,``)D!```C`@`````````````$!```
M:`8```````"J`@```````"(#``!(`0``B04``$$```!D````9@```*`%``!-
M`@``RP4``/\%``#+!```5@0``/D%``#[`0``>@(``*\#``#,!0``AP(``"T&
M``#B!@``.````-@#``"W`0``C@8```````!7````M@(``#<"````````````
M`#\#``"E````8@$``-D```#[!0```````(@"`````````@0``)@&``!;!@``
MG04``````````````````-H$``#>````#0(``(H!```P!@``9@$```````!0
M!0``D````!L`````````T00``"H&```0````+P4``"$%``#Y!```[P0`````
M``!+!@``O@8``(`$``````````````4#``!'`0``@`$```````"N````+`,`
M`$`%``!\!0``P@,``*0!``#Q````J`(``,@$``#<`0``,@8``-D#``"A`P``
M?`$``$T$```/!```B@```+0```#H!0``8`0``/`#``!5!```:@(```$!``",
M`@``O`8`````````````)P$```L"```Q`P``\@8``.,`````````C0$``'L%
M``"_!@``,0````````#W!@``_@```#<$``!3!````````+4#```[!0``=P(`
M``````"B!0``UP8``,8$``!)`0```````!0"````````L@(``&4%``"2!0``
M;@4```````"<!@````````````#K`P```````$L$``!.!```(@```"$&``"Y
M`0```````"0#```G`@``0P(```````"5`0```````#($``"U`0``5`,``)X`
M```T`@``F0(``!<&``"R````Q00``'8#``"#!```C@4``(P#``#L`@``H`$`
M`%D$``#6`P``+0$``!(!````````/00``````````````````&@#``#;````
M$`0``+$$````````FP$``(L%````````30$``#\$````````,04``$,`````
M````'@0``&,&````````M0(``!\&``#`````W@8``$4!```D`@``-````&@$
M```&`@``P@(```````""!0``/08```````#[!@```````"<```!Q!```M@8`
M`"D&``"X`0````````0&```M`P```````"@&``!T`0``@P8````````$````
MF@```'L$``!D!```\P$```````".````&0(``%D%``#`!0``E`8``*P$```"
M!@``4`,`````````````L`4```4&````````D0,``,P$``#-`0``:P(`````
M````````]`4``(L$````````KP8````````B!@``NP4``"P$``"3`P``````
M```````K!0```````(D"``#)`0````````````!U`P``1@(``-0`````````
M/@0```$$``#]`@``^P(``&("``#0`0``7@8`````````````L04``-D%``!1
M!```(0```"D``````````````/\"```F`@``_@4``'8"````````A04`````
M````````$@,```````!J!0``+@0``,$$```G!````````/`$``"&`@``J00`
M``````"!!@``UP(``#\&```S!````````*L&``#F!````````/,#````````
M``````@!````````RP(``%T"````````3P8``&P"```>!0``````````````
M!0``@`,``#X!``!V!@``<08```````!'`P````````````!5`@````````0"
M````````!0$``-<`````````K@0``#\%``#Z`P``W`8``"@$````````.P``
M``````"J`P``8@8``#0$````````LP(```4"```0`@``G@$``$H"````````
M3`(`````````````X`4``*<```"9!@``4P$``#X```#Q!0```````)0%```9
M````K`,``$L#``!C!0````````````""````.0,`````````````2`4`````
M``#D`0``.00``"H%``````````````````":`0``<@,``%(#``!`!```PP(`
M`.8```#F`0``6@0``/L#``````````````````"B!@``Z@0``%8"``#_`0``
M```````````&````DP0``$8&``#?`0````````````!<`P``UP4``'L"``!!
M`0``[00``)<"``#1!@``HP(``)`"``"4!`````````````"E`0```P$```T$
M``#C!````````%X"``#\````TP8``)T$``#6`0``JP4``"L$``#Z````````
M`+D$```C`P``,P(``/<"````````R08``/4#``"B`P``*P(```````#(`P``
MK`$`````````````E0,``.X!``"``@``1P8``-0$```@!```WP,````````,
M!@``8@,``'0&``#-`P``I0(``%\```"9!```(P8```````#Q!@``RP$`````
M``";`P```````(,#```B!```"`8``'L#````````I0,``(0````O!@``````
M`#X&````````M`4```````#G`P````````````#Q`0``0@4``%P$````````
M2@,````````@`P``>@4``/8&````````QP0```````"*!@``W@$``%,&```X
M`P```````!0$``!$!```A0```.4$````````D@,``&4!``#5`P``KP$``!P!
M``!8!````````-@"````````W@0``$0"```%!0``K@$``/<#``!8`0``!@0`
M`$`#``".`@```````"\"``!O!@``EP$``)D%``#*!@``[0(```T&``#^!@``
MXP$``````````````````-H#````````_0````````!"!@``&@0``'`#``#L
M`P``=`,``"8&````````=P4``&H&``#V`@``]P```/L$``"4`@``90(``.4"
M````````.P8``'D$````````/04``%@#````````T`8``%$%````````-P4`
M`'L!``"'!@``````````````````Y0$``#P%``!N`@``"P0``)4$```#!@``
M?`(````````Z`@```````(0"`````````````/H$``!Z`P```````$X```!?
M`0```````'(%``"5`@``K0,``%`!````````NP(``(\&``!X`P``L@0``'H!
M``!W!````````'T#``#M`P``^@(```````#'!@``1@$``&T$``"!`@``````
M`!L$````````5`0``$X%``"/`@``@P(`````````````%`$``-H"``!;````
M;`4``(P!````````(0$``&<"``![````S0(````````+`0```````#@!``#*
M`P``(`(``"4&``"Q`@``^`8``'\```#6`@``N@0``"````!S!0```````"0$
M``#*!0``:P$``"4%``!8!@``<P0``+8!````````@0,``#L"``#,````6P$`
M`+<```!>```````````````8!@``.04``(,!``"P!@```````!\!```'`@``
M900``,4!``"!!0``*@0``*@%``"\````ZP(``+T%````````QP$```````##
M````P`8````````A`P``*@,``+$!``"7!@``=0(``(0#```'`0``"`,``,P#
M``!4````*00``/`````H`0``I00`````````````````````````````.`4`
M`*<#``"D`````````)\```#?`@````````````#!`@``Y@8````````T!0``
MD00``*@#````````_@$```````!9`0````````D"``#^`@``N@8``*H%``!G
M`P``'0(``+(%````````U00``+\```!^````^`$``!8$````````Y@4`````
M``!0````H0$```````"/````D@0``*D%``";`@```````/<$````````C@0`
M`!\%``!^!@``6@(```````"6`P``!@,``'@```"H````DP4``$\!``!P!@``
ME`$``,$#``#+````$P,``/$$``!.`P``AP$``)T!```#`P``2@8````````\
M`P``[@```(0%```C!````````,8&``"O`@``XP,``!D#``!\!```Q`0`````
M``!I!```<0(``+,$``"N`@```````,(%```*!0```````-P````\!```````
M`%$#````````;08``$P```"1`0``!P```&T"``"3!@``A@0``(T%``"U!```
MO0(``$@#``"!!```EP````````#T`P````(````````R````P`,```````#G
M`@``Q@``````````````'0$``/P!``"N!@``?P$``(X#``#8!0``````````
M``#/!````````!L!``"F`````````%(```"J````>0```#T"``"0`0``````
M``````#X!0``=`````````#_`P```````#0!`````````````%8!``!,`0``
M`````$\#``!Q````=`4```````"R`P``Q`,``,8!``!B!0``A@4```````#?
M!0``X`$``````````````P````````#\`@``^0$`````````````;`$``/\$
M``"M`0``CP4```````#A!@``3@$``-`%````!P``4@0``)\#````````````
M`"$$``#L!```.@4``"L&``";!0``Z0,```@```!L`P``?@$```\"``"L!0``
M`````%<#``#J`0``,````!X#````````G0``````````````S@0``#X%``!\
M````#0```)X&`````````````*,#``"W!```?0(``.(!``##!@````````T#
M``!3`@``504``$P#``#2`0``@`4``"X#```<!@``Q04``/D&``#K!@``!0``
M```````1!0```````#T````!!@```````+\%``"A!@``2@4``&H$``"`````
M@P4``!$#``#B!```R0(``)4%```,!```$P0``*<$```&!@``U08`````````
M````9@0``-`"````````30```,4#``!J````T0,```````#I`@```````)`$
M```&!P``X`8```L#```K````-0(``$$"``!X`@```````!T````$!0``.@0`
M`(L"```V!@``'@$```````!;!0```````"X%``!A!@``?P,``*`"``"S!@``
M,@4``+$```#+!@````````L%````````108``'D!``#-!0```````%P"````
M````;P4``"D%``"6!0```@$``````````````````%H!``!A`0``2@$``&P$
M`````````````.0#``#P!@``D`8``%T$``!I!0``%0,```D%``"Z`@``,P,`
M`-H`````````[04``*,!`````````````+P$``!#!```-@4``%@```"H`0``
M``````````"'`P``5P(`````````````&@```*L!``#<`P```````/,%``#3
M!```TP```(@#``!I````Z0```&0#``!_!@``_0,``.,&````````BP$``-<!
M````````+@8``%$"``!(````<@0``"$"``"(````3P4``*,%``"T`0``````
M`/8!``"D`P``3P(``&8#``!'!0``F`4``%\#``"D!0``8P0``%\&````````
M`````(4$``````````````````"^````(P$```$'``"2````KP```%X#```3
M!0``4@(``````````````````$(#`````````````,8%``"9````:P0``#\!
M``#]`0``A@```!8"````````'`(``!4!``!H`@``X0````````"-!@``<@``
M`*P```!@`````````!`&```M`````````)(&````````H0(```````!P`@``
M&P(``!@```!_!```R`$```````!G!```#`$``%\$``"M!```J`0``.P%````
M````>`0``%L$``#J!@``?00``.H%``!P````*0,```````"<`@``%P,``+L!
M```*`````````-0%``!H`0```````!`%``"J!```UP0``!`!```-`0``N@,`
M`-T&``"V`P``:0$``+@&```,````?`8``)$&```V`P``!P4``.P&````````
M``````````#>`@``I04``)H&````````"0$``"<#``!%!0```````-0"``!U
M`0``I@,``(L#````````C0```(<```!W`P``$P8``)8"```7!0``;`8`````
M```"````T0$``.,"``#N!@``Z@(```````"?`@``````````````````````
M`!D%``!A!```NP,``,\%```V`@``J0,``,D$``#O`@``R0,```````!;`@``
M;@8``-P%``":!```H@$``````````````````&8&``!,!0``T````'X#````
M`````````*($```O`P``,@(```````"-!```%@,``/\```!=`````````(@%
M````````I`(```H!``!O````X`,`````````````F@4```````#(!@``=@0`
M`.<%````````FP0``-0#````````8@0``&8%````````R@$`````````````
M_@0`````````````=P8````````=!0``2`(``*0&``"/!```(`$``(D`````
M````-`8```````#N!0``?P4````````1`@``]0```#<!``"W`@``.0(``/(%
M````````R`(```````#9!@``[P8``/0```!5!@``G`0``'0$```>!@``"`0`
M`(@&```^`@``Q0```!<$````````K08`````````````0P,```````#U`0``
M2`0``'$!``#2!0``J0$``$\```#G!@``A0(``"0```!O!```&@(``,<"``"-
M`P``60(``-@!``!-!0``9@(``&\!```6!@``)`4``(<%``!I`P```````/@$
M``#U!0``90```.`"``##!```,P8``'T!`````````````.\!``")!```;@$`
M`$("````````K`8````````3`0``IP(``.D&```.!```NP0``/H%```6!0``
MZ`8``#@"``"A!```^P```#L#````````9`4``!@"````````@@$``$D"``#-
M!```QP```&L&````````W`(```````!-!@``R@0``&`#````````&00``.(#
M````````]`0``"@%``!\`P``200``%`"``#E`P``````````````````````
M`(T"```H`P``"@0``(4&``":`@``Q@(``$<`````````%`,``+@`````````
M+@```-L$``"3````<P(```````"Z!0``J@8````!``">`@```````(8#````
M````S`(``.L```!T`@``\`4```\#``#H`P```````,`!``"G!@``\`$`````
M``"_`0``.@````````"2`@``B@(``*0$```X!@``!`,``+P#````````004`
M`(0&```)`P``>0(``-P$```1`0```````.D%````````L`0``#4&``#@!```
M1@4```L```"=`@``<@8```````"S````>08```````#(!0``&`,``)4```!5
M````TP,``)`#``"Y!0``7P(``"\!``#/````T0````,"``"T`@``5`(``/("
M````````$0```)\!```J````:P``````````````&P8``#X#````````7P4`
M`%,%``!&`P``-@$``!4"``"Y`@``7`$``.D!```\`@``T@(````````X!```
M.@,``,L#``#"!@``E@$```````!P`0``:`4``,\&````````+`4``)@"``"%
M`P``PP$``.<`````````V`0`````````````,P4``'4$``!8!0``(`4``/(`
M````````8`8``$\$```=!````04``!\$``#:!@``V0$``/8%```.`@``````
M`-,"``"[````=@4``*8%``#?!@``I@8``)P````Y`0``]0(``$($``#5````
MVP8````````N`@``)@,``#`!```E`@```````)(!``"7!````````&`"``"\
M!0``N`,``&L%````````QP4``$4`````````0````````````````````)P%
M``#W`0``.@$``+P!``!Z!```G08````````5````:0(``",````E````````
M`/P$``#$!0``Q`8``&,"``#A!0``S@,```````!5`0``#`,``.0`````````
M<@(``'T```#!!0```````&X$``"X`@``$08``&T```!S`0``F0,``($`````
M`````````)P!``"K`@``2P(``$0````)!```J0(``$,&```N`0``%00``#D&
M``!)!0``C`0``!X````\`0``````````````````IP$``-($````````$00`
M`*L#```0`P``2P$``+T&``"`!@````````````"Q`P``'`4``,<#``#Z!@``
MO@,``"(%``!S````Z`$```(#```/`````````.8"``"=`P``[P4``#,```#O
M`P``N@$``!0&``!C`P````````````"^`@``]`8``"@`````````````````
M```(!0``W@4```````!7`0``%@$``$H```!<````"P8``/H!``!X!0``K@,`
M`#<&``#;`P``&`4`````````````&08``%(%``!$`P``T`,```````#E!0``
M`````%<$````````B08``$0%``!&!``````````````7`@````,```````"8
M````@P```$`!`````````````,4"``"_`P``&P4``$4#````````?04`````
M``#Q`P``"@(``"4#```R`0````````````!5`P``:P,``+\"``!W````&@,`
M`/P&``"I````S0``````````````L@$``'$%`````````````%0%````````
MW@,``/D```#=`0``+````.$!`````````P4```````"1`@``````````````
M````>@8``)@$``#U!```00,```````"@!````````&(``````````````#(#
M`````````````&`!````````_08``!,"``",!0````````````"^!```Z00`
M``X%````````1`$`````````````HP0```````#3!0``%P``````````````
M`````%D&``!>!0```````!0```!*!```$@(```````#V!````````,0```"5
M!@``>04````````<````U`8``.X#``!G````_P8``$P$``#=!0``U@8```0'
M```P!0``60`````````&`0``U@```(@$```%!```\P````````!J`0``P0$`
M`"8%````````A@$``+<&`````````````)\%``"P`@``B`$`````````````
MH````,`$```P`P``)@```"\`````````ZP4```X`````````O`(``.(%````
M````OP0``&\"````````L`$```````#W!0```````,$&````````]`$`````
M``"$!```@@,``"\$````````O0```(P```#)````[0```)L&``#D!@``````
M`+8`````````'0,``&<&```"`@``6@,```````";````LP4``/D#````````
M%04``%X!``#F`P```````+,!``!H````UP,`````````````4`0``*<%``">
M`P``VP(````````'`P``SP,```````#C!0`````````````````````````$
M````````+00``+X!```Y````R04``&,!``!X`0```````.4&``!P!0``30,`
M`*P"``#/`0````````\%``#(`````````%(!``"/`P``@@(``+8$``#1!0``
M`````/(#``#5!0``)`8```0!````````(`8``/(!``!6!0```````,X"````
M("`@("`@5&\Z(``@("`@1&%T93H@`"`@("!&<F]M.B``("8C,34Q.R`E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S
M*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R
M9&%Y*0`@4W5B:F5C=#H@`"!I;B``(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I
M8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES
M=')Y+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W
M87,@;F]T(&-R96%T960Z("5S+@`C`"4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2D`)60@)7,@86YD("5S`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D
M+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@
M=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`E9"!M97-S86=E<R!H879E
M(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A
M;2X`)60@=&\@)60@;V8@)60@365S<V%G97,`)7,@+2!.;W1I8V4`)7,@061M
M:6YI<W1R871I;VX`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!01U`@061M:6YI<W1R
M871I;VX`)7,@4R]-24U%($%D;6EN:7-T<F%T:6]N`"5S(%-E='5P`"5S(%-I
M9VX@57``)7,@86QR96%D>2!E>&ES=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9
M;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R
M96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S(&AA<R!A8V-E
M<'1E9"X`)7,@:&%S(&-A;F-E;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@
M82!F<F5E+V)U<WD@<F5Q=65S="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN
M=FET871I;VX@=&\@)7,N`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN`"5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"X`)7,@:7,@
M<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(')E<75E<W1S
M('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R
M('!R97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O("5S+@`E<R!W:7-H97,@=&\@86UM96YD("5S+@`E
M<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N`"5S('=I<VAE<R!T
M;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N`"5S
M)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S
M)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D
M*0`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C<F5E
M;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O
M;7!O<V4@<V-R965N+BD`*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@
M869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H
M86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI
M960N*0`H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S
M(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E
M;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI
M;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`M+2!S96QE
M8W0@+2T`,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N`#$@;65S<V%G92!H
M87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@
M;F]T('-P86TN`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M+@`Q,#`@8VAA<F%C=&5R<P`Q,#`P(&-H
M87)A8W1E<G,`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U
M<G,`,C4P(&-H87)A8W1E<G,`-3`P(&-H87)A8W1E<G,`/%!R979I;W5S`$$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@;&%R9V4@:6UA9V4@;F%M960@
M)7,@:7,@871T86-H960@=&\@=&AI<R!M97-S86=E+@!!(&UE<W-A9V4@>6]U
M(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T
M:6]N(&9R;VT@=&AE(')E8VEP:65N="X`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`04Y$
M`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%C8V5P="!R97%U97-T`$%C
M8V5P=&5D`$%C8V5P=&5D.B``06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R
M;WIE;BX`06-C;W5N="=S(&YA;64Z`$%C8V]U;G1I;F<`06-T:6]N<P!!9&0`
M061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D
M9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@
M<&%I<@!!9&0@<V]U<F-E`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&AI<R!T;R!M>2!C86QE;F1A<@!!9&0@=&\@061D<F5S
M<R!B;V]K("@E<RD`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D
M9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B(&%S(&%N(&%T=&%C:&UE
M;G0N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9&ET:6]N86P@:&5A
M9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&D^*&]P=&EO;F%L+"!E
M;G1E<B!E86-H(&AE861E<B!O;B!A(&YE=R!L:6YE*3PO:3X`061D:71I;VYA
M;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&EN
M9F]R;6%T:6]N(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E(&1E=&%I;',`
M061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`
M061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',`061D:71I;VYA;"!M
M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`061D<F5S
M<P!!9&1R97-S($)O;VL`061D<F5S<R!";V]K<P!!9&1R97-S97,@=&\@0D-#
M(&%L;"!M97-S86=E<SH@/&D^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E
M<W,@;VX@82!N97<@;&EN92D\+VD^`$%D9')E<W-E<R!T;R!E>'!L:6-I=&QY
M('1I92!T;R!T:&ES(&ED96YT:71Y.B`\:3XH;W!T:6]N86PL(&5N=&5R(&5A
M8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO:3X`061M:6YI<W1R871I;VX`
M061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&P`06QL
M($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO
M;G,`06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I
M;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z`$%L;"!M97-S
M86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W
M:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@;&EN:V5D(&%T
M=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L
M971E9"X`06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@
M;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N`$%L;"!R:6=H=',@;VX@9F]L
M9&5R("(E<R(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@(B5S(BX`
M06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB
M;W@_`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;')E861Y(&5X:7-T<P!!
M;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!
M;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S
M<P!!;'1E<FYA=&4@=&5X=#H`06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@
M<V5C=&EO;CH`06QW87ES`$%L=V%Y<R!S879E(&%T=&%C:&UE;G1S`$%N(&5R
M<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T
M86-H;65N="X@5&AE($E-05`@<V5R=F5R('-A:60Z(`!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W
M:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`06YS=V5R
M960@;65S<V%G97,`06YT87)C=&EC80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO
M;B!I<R!R96%D>2X`07!P;'D@1FEL=&5R<P!!<'!L>2!&:6QT97)S('1O("5S
M`$%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_`$%P<&QY(&9I
M;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_`$%P<')O
M=F4`07!R:6P`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/P!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@
M*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D(2D`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-
M04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT
M/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F;VQD97(_
M`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O
M;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E
M;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(')E<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_`$%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S('-P86T_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R<FEV86P@5&EM90!!<G5B80!!<V-E;F1I;F<`
M07-K`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!='1A8V@`071T86-H($9I;&5S`$%T=&%C:"!A
M(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_
M`$%T=&%C:&5D($9I;&4Z`$%T=&%C:&5D(&9I;&4@(B5S(B!E>&-E961S('1H
M92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"X`
M071T86-H;65N=`!!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A
M8VAM96YT('1Y<&4`071T86-H;65N=',`071T96YD965S`$%T=&5N=&EO;@!!
M='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:6UP
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B
M-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F
M86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T;VUA=&EC86QL>2!S:&]W(&EM86=E
M<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2!A
M9&1R97-S8F]O:S\`079A:6QA8FQE($%D9')E<W,@8F]O:W,Z`$%V86EL86)L
M92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`0D]&2"!%
M>&-U<V5S`$)A8U]K('1O("5S`$)A8VL@=&\@)7,`0F%C:V=R;W5N9`!"86-K
M9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E
M<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U
M.2TQ,RD`0F%N9VQA9&5S:`!"8V,`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"
M96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO
M;B!M97-S86=E+@!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&%C
M:VQI<W0`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";&]C:R!I;6%G97,@
M:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY
M(')E<75E<W1E9#\`0F]D>0!";VQI=FEA`$)O;VMM87)K<P!";W-N:6$@86YD
M($AE<GIE9V]V:6YA`$)O=&@`0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D
M>2!O9B!-97-S86=E`$)R87II;`!"=6QG87)I80!#35,`0U)#`$-?96QL(%!R
M;W!E<G1I97,N+BX`0U]H87)S970`0V%L96YD87(`0V%M8F]D:6$`0V%M97)O
M;VX`0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N
M`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B``
M0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O
M9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@;6%I;&)O>"X`0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N861A`$-A;F-E;`!#86YC96P@365S<V%G90!#86YC96P@4')O8FQE
M;2!297!O<G0`0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE
M;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RX`0V%N;F]T(&1E;&5T92!F:6QE
M("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N
M;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%P92!697)D90!#871E9V]R
M:65S(&%N9"!,86)E;',`0V,`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`
M0V5L;"!P<F]P97)T:65S`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T
M*0!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/
M=VYE<@!#:&%D`$-H86ER(%!E<G-O;@!#:&%N9V4`0VAA;F=E($%L;`!#:&%N
M9V4@1F]L9&5R`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@
M;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W(&UE
M<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L
M9&5R('-E='1I;F=S+@!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M(&5M86EL<RX`0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T
M=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B!E;6%I;"X`0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.@!#:&5C7VL@
M3&EN:RXN+@!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$-H96-K(%]!
M;&PO3F]N90!#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E
M=&-H(&UA:6P@9G)O;3H`0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@
M82!M97-S86=E/P!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&EL90!#:&EN
M80!#:&]O<V4@06-T:6]N.@!#:&]O<V4@82!M86EL('-E<G9E<CH`0VAO;W-E
M(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%C=&EO
M;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@=&AE(&%D
M9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+@!#:&]O
M<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@
M97AP86YD:6YG(&%D9')E<W-E<RX`0VAR:7-T;6%S($ES;&%N9`!#;&EC:R`E
M<R!T;R!C;VYV97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U
M<B!B<F]W<V5R(&-A;B!V:65W+@!#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@
M:6UA9V4N`$-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G92X`
M0VQI8VL@)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<N`$-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I
M;6%G92X`0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E
M<&%R871E('=I;F1O=RX`0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R
M="]R96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N`$-L:6-K(&AE
M<F4@=&\@2$E$12!T:&4@26UA9V5S`$-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@
M26UA9V5S`$-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@
M8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H+@!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:R!T;R!3879E(%!'4"!0=6)L:6,@2V5Y
M(&EN('EO=7(@061D<F5S<R!B;V]K`$-L:6-K('1O(%-A=F4@4R]-24U%(&-E
M<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K`$-L:6-K:6YG
M(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O
M('1H92!S96YD97(`0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N
M('1H92!M97-S86=E('1O(&)E(')E860`0VQO<V4`0VQO<V4@5VEN9&]W`$-L
M;W-E('1H:7,@=VEN9&]W`$-L;W-E9"!&;VQD97(`0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',`0V]L;&%P<V4`0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&
M;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VQL87!S92!3:61E8F%R`$-O;&]M
M8FEA`$-O;&]R`$-O;&]R($EN9&EC871O<CH@`$-O;&]R(%!I8VME<@!#;VQO
M=7(@<V5L96-T:6]N`$-O;'5M;B!T:71L97,`0V]M;6%N9`!#;VUM86YD(%-H
M96QL`$-O;6UE;G0`0V]M;W)O<P!#;VUP86YY`$-O;7!L971E9`!#;VUP;W-E
M`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!O<V4@86YO=&AE<B!M97-S86=E
M`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_`$-O;7!O
M<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B
M<F]W<V5R('-U<'!O<G1S('1H92!F96%T=7)E*3\`0V]M<'5T97)S`$-O;F1I
M=&EO;G,`0V]N9FEG=7)E("5S`$-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E
M(&1I<W!L87EE9"X`0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+@!#
M;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@
M9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!#;VYN96-T:6]N('1O('-E<G9E<B!F86EL960`0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]N=')O;"!01U`@<W5P
M<&]R="!F;W(@)7,N`$-O;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+@!#
M;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C:&5C:V5D(&9O<BP@86YD
M('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@=VAE;B!I="!A<G)I=F5S
M+@!#;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN=&\@9W)A<&AI8V%L(&]N
M97,_`$-O;VL@27-L86YD<P!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'D@=&\@
M9F]L9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&
M5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E
M<RX@5&AE('-E<G9E<B!S86ED.B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&5X96-U
M=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RX`0V]U;&0@;F]T(&5X=')A8W0@
M=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N
M="X`0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@
M=&AE(%II<"!A<F-H:79E+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@
M9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W
M<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y("(E<R(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BX`0V]U;G1R>0!#<F5A=&4`0W)E871E($9O;&1E<@!#<F5A=&4@
M2V5Y<P!#<F5A=&4@5FER='5A;"!&;VQD97(`0W)E871E(&$@3F5W($%C8V]U
M;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@4W!A;2!F;VQD97(`0W)E
M871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E871E(&$@;F5W(&]N90!#<F5A
M=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@82!N97<@=')A<V@@
M9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U
M<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@86YD(&1E
M;&5T92!S<&%M+@!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U
M<G)E;G0@5&EM90!#=7)R96YT(&%C8V5S<R!T;R`E<P!#=7-T;VUI>F4@86-C
M;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RX`
M0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+@!#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#>7!R=7,`0WIE8V@@4F5P
M=6)L:6,`1$0`1&%I;'D`1&%T7V4`1&%T90!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-L:6YE9`!$96-L:6YE9#H@`$1E9F%U;'0`1&5F875L="!#;VQO
M<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L
M="!P97)M:7-S:6]N<P!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U
M;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5G871E9`!$96QE=&4`1&5L971E
M("5S(%!U8FQI8R!+97D`1&5L971E($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L
M9&5R*',I`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@
M4V5L96-T960@1F]L9&5R<P!$96QE=&4@5FER='5A;"!&;VQD97(`1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!F971C:&5D(&UE<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\`
M1&5L971E(&9R;VT@;7D@8V%L96YD87(`1&5L971E(&]L9"!L:6YK960@871T
M86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H/P!$96QE=&4@;VQD('-E
M;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-P86T@;65S<V%G97,@869T
M97(@=&AE>2!H879E(&)E96X@<F5P;W)T960@87,@<W!A;3\`1&5L971E('1H
M92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T
M92!T:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E
M;&5T960`1&5L971E9"!M97-S86=E<P!$96QE=&5D('1H92!A='1A8VAM96YT
M("(E<R(N`$1E;&5T:6YG(&%N9"!-;W9I;F<@365S<V%G97,`1&5N;6%R:P!$
M96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VX`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP
M=&EO;@!$971A:6QS`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1I;2!S:6=N871U<F5S/P!$:7)E8W1O<GD`1&ES
M<&QA>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$
M:7-P;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\`
M1&ES<&QA>2!I;B!";V1Y(&]F($UE<W-A9V4`1&ES<&QA>2!P;W`M=7`@;F]T
M:69I8V%T:6]N(&]F(&YE=R!M86EL/P!$:7-P;&%Y('1H92`G16UP='D@5')A
M<V@G(&QI;FL@:6X@=&AE(&UE;G5B87(_`$1I<W!O<VET:6]N`$1J:6)O=71I
M`$1O($Y/5"!M871C:`!$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@
M36%I;`!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R
M;VTZ(&-O;'5M;@!$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/P!$
M;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N90!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA=`!$;W=N;&]A9"!!
M;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92D`1&]W;FQO860@1F]L9&5R
M*',I`$1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=`$1O=VYL;V%D
M(&EN("YZ:7`@1F]R;6%T`$1R869T`$1R869T(&9O;&1E<@!$<F%F=',@9F]L
M9&5R.@!$<G5G<P!%+4UA:6P`12UM86EL($%D9')E<W,`14Y$`$524D]2.B!9
M;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`16-U861O<@!%
M9&ET`$5D:70@0FQA8VML:7-T`$5D:70@1FEL=&5R<P!%9&ET($=R;W5P`$5D
M:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@5FER='5A;"!&;VQD97(`161I="!6:7)T=6%L($9O
M;&1E<B!$969I;FET:6]N(&9O<B`E<P!%9&ET(%=H:71E;&ES=`!%9&ET(&]P
M=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET('EO=7(@
M8FQA8VML:7-T`$5D:70@>6]U<B!F:6QT97(@<G5L97,`161I="!Y;W5R('!R
M969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RX`
M161I="!Y;W5R('=H:71E;&ES=`!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%
M;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6]T
M:6-O;G,`16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RX`16UP='D@1F]L
M9&5R*',I`$5M<'1Y(%-E;&5C=&5D($9O;&1E<G,`16UP='D@5')A<V@@9F]L
M9&5R`$5M<'1Y(%]4<F%S:`!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N
M`$5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\`16YA8FQE(%,O34E-12!F=6YC
M=&EO;F%L:71Y/P!%;F%B;&4@;65S<V%G92!P<F5V:65W<S\`16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YC<E]Y<'1I;VX@3W!T:6]N<P!%
M;F0`16YD(&9O<G=A<F1E9"!M97-S86=E`$5N9"!M97-S86=E`$5N9"!M97-S
M86=E(&9R;VT@)7,`16YT97(@4&%S<W!H<F%S90!%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@4W!A;2!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO
M=7(@;F5W(&1R869T<R!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@
M;F5W('-E;G0@;6%I;"!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@
M;F5W('1R87-H(&9O;&1E<@!%;G1I<F4@365S<V%G90!%;G1R>2`B)7,B('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:P!%<75A
M=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R('-E;F1I;F<@<F5P
M;'DZ("5S+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`
M175R;W!E`$5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+@!%=F5R>2`Q-2!M
M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@
M06QL`$5X<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.
M86UE<P!%>'!A;F0@4VED96)A<@!%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O
M<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_`$5X
M<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE
M(&9O;&1E<G,@=FEE=S\`17AP86YD:6YG`$9?971C:"!-86EL`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M
M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!M;W9E
M('1O("(E<R(N`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)
M<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`1F5T8V@@36%I;`!&
M971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!&971C:"!M97-S86=E
M<R!U<&]N(&QO9V=I;F<@;VX_`$9E=&-H960@)60@;65S<V%G97,@9G)O;2`E
M<P!&971C:&5D(#$@;65S<V%G92!F<F]M("5S`$9E=&-H;6%I;#H@`$9E=&-H
M;6%I;#H@;F\@;F5W(&UE<W-A9V5S+@!&:5]L=&5R<P!&:6II`$9I;&4`1FEL
M92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A
M9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R($]P=&EO;G,`
M1FEL=&5R(%-E='1I;F=S`$9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R
M;V9A;FET>3\`1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S
M>7-T96TN`$9I;'1E<G,`1FEL=&5R<R!.3U0@06-T:79E`$9I;'1E<G,Z("5S
M(&UA;F%G96UE;G0@<&%G90!&:6YD`$9I;FQA;F0`1FER<W0@36%I;&)O>"!0
M86=E`$9I<G-T(%!A9V4`1F]?<G=A<F0`1F]L9&5R($%C=&EO;G,@+2!#;VYF
M:7)M871I;VX`1F]L9&5R($YA=FEG871O<@!&;VQD97(@4')E9FEX`$9O;&1E
M<B!3=6UM87)Y`$9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+@!&;VQD
M97(@=7-E(&ES(&YO="!E;F%B;&5D+@!&;V]D`$9O<F=O="!Y;W5R('!A<W-W
M;W)D/P!&;W)W87)D`$9O<G=A<F0Z`$9O<G=A<F1E9"!M97-S86=E`$9O<G=A
M<F1E9"!M97-S86=E(&9R;VT@)7,`1G)A;F-E`$9R964O0G5S>2!);F9O<FUA
M=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`1G)E92]"
M=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L
M>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]?;0!&<F]M
M`$9R;VT@061D<F5S<P!&=V0Z`$9W9#H@`$9W9#H@)74@1F]R=V%R9&5D($UE
M<W-A9V5S`$=A8F]N`$=A;6)I80!'96YE<F%L($]P=&EO;G,`1V5R;6%N>0!'
M970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI`$=H86YA`$=I8G)A
M;'1A<@!';P!';R!T;R!-97-S86=E`$=O('1O(&%D9')E<W,@8F]O:R!E;G1R
M>2!O9B`B)7,B`$=O;V=L92!396%R8V@`1W)A;G0@86-C97-S`$=R965C90!'
M<F5E;FQA;F0`1W)E;F%D80!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E
M;6%L80!'=65R;G-E>0!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2$52
M10!(5$U,`$A434P@5F5R<VEO;B!O9B!-97-S86=E`$AA:71I`$AE861E<G,`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE;'``2&5R92!I
M<R!T:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP;W-I;F<Z`$AI9&1E;@!(:61D
M96X@:6X@5&AR96%D(%9I97<`2&ED92!$96QE=&5D`$AI9&4@56YS=6)S8W)I
M8F5D`$AI9&4@=&AE($EM86=E<P!(:6=H`$AI9V@@4')I;W)I='D`2&EG:&5S
M=`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO
M;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(
M;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\`2&]W('1O
M(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R97!L>0!(=6YG87)Y`$E-
M05``24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*0!)34%0(&]V97(@4U-,
M`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*0!)34%0
M(&]V97(@4U-,("AS96QF+7-I9VYE9"D`24U!4"P@;F\@5$Q3`$E-05`O4$]0
M,R!-86EL(%-E<G9E<G,`24Y"3U@`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS
M('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF('EO=2!C;VYT:6YU92P@
M86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(0!)
M9VYO<F4`26=N;W)E($%L;`!);6%G97,`26UP;W)T`$EM<&]R="!+97D`26UP
M;W)T($ME>7!A:7(`26UP;W)T($UE<W-A9V5S`$EM<&]R="!01U`@2V5Y`$EM
M<&]R="!097)S;VYA;"!#97)T:69I8V%T97,`26UP;W)T(%!E<G-O;F%L(%!R
M:79A=&4@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D`
M26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,`26UP;W)T(%!U
M8FQI8R!+97D`26UP;W)T(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!0=6)L:6,@
M4R]-24U%($ME>0!);7!O<G0@4R]-24U%($ME>0!);7!O<G0@;6)O>"!&:6QE
M`$EM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N`$EM<&]R=&%N
M=`!);7!O<G1A;G0@;65S<V%G97,`26UP;W)T960@)60@;65S<V%G97,@9G)O
M;2`E<RX`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26X@
M4')O8V5S<P!);F)O>`!);F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@
M:&5A9&5R(&EN(&$@<F5P;'D_`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I
M;B!A(')E<&QY/P!);F1I80!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;B!O
M;B`E<R!0=6)L:6,@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A
M=&4@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97D`26YL
M:6YE`$EN<V5R="!#97)T:69I8V%T92!(97)E`$EN<V5R="!);6%G90!);G-E
M<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4`26YS97)T(%!E<G-O
M;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS97)T(%!U8FQI8R!01U`@2V5Y
M($AE<F4`26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N
M96YT+@!);G9A;&ED($%D9')E<W,`26YV86QI9"!296UO=&4@36%I;&)O>`!)
M;G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N`$EN=F%L
M:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&ME>0!);G9A;&ED(&QI
M8V5N<V4@:V5Y+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2X`
M26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`26YV97)T`$ER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES<F%E;`!)<W-U
M97(`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IO<F1A;@!*=6QY`$IU
M;F4`2T(`2V%Z86MH<W1A;@!+96YY80!+97D@0W)E871I;VX`2V5Y($9I;F=E
M<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97D@9V5N97)A=&EO;B!M87D@
M=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@
M:V5Y(&=E;F5R871I;VX_`$ME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`
M2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($UA:6QB;W@@4&%G90!,87-T
M(%!A9V4`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,
M87-T(&QO9VEN.B!.979E<@!,871V:6$`3&5S;W1H;P!,:5]N:R!!='1A8VAM
M96YT<P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS
M=&5I;@!,:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BX`3&EN:W,@
M=VEL;"!E>'!I<F4@;VX@)7,`3&ES="!(96QP(%1O<&EC<P!,:7-T(&%L;"!C
M;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF
M(&1I<V%B;&5D+"!Y;W4@=VEL;"!O;FQY('-E92!C;VYT86-T<R!T:&%T('EO
M=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI`$QI<W1I;F<@:6X@=&AE($AE861E
M<@!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71H=6%N:6$`3&]A9&EN
M9RXN+@!,;V-A;"!-86EL8F]X.@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4
M:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@:6X@=&\@)7,`3&]G(&]U=`!,;V=I
M;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I
M;B!F86EL960N`$QO=P!,;W<@4')I;W)I='D`3&]W97-T`$QU>&5M8F]U<F<`
M34T`34]41`!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F`$UA8VEN=&]S:"!&:6QE`$UA9&%G87-C87(`36%I
M;`!-86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T
M;SH`36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS
M`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G
M;W)I97,N`$UA<F-H`$UA<F=I;@!-87)K($%L;"!-97-S86=E<R!I;B!&;VQD
M97(@87,@4V5E;@!-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS
M965N`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG
M('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`36%R:R!M97-S86=E<R!A<R!S965N
M/R`H24U!4"!O;FQY*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T
M8V@@06QL(%%U97)I97,`36%T8V@@06YY(%%U97)Y`$UA=&-H:6YG(&9I96QD
M<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87AI;75M($%T=&%C:&UE;G0@4VEZ
M90!-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D+@!-87AI
M;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+@!-87D`36%Y;W1T
M90!-965T:6YG($-A;F-E;&QA=&EO;@!-965T:6YG($EN9F]R;6%T:6]N`$UE
M971I;F<@4')O<&]S86P`365E=&EN9R!297!L>0!-965T:6YG(%5P9&%T90!-
M965T:6YG(%5P9&%T92!297%U97-T`$UE;G4@1F]L9&5R($QI<W0`365N=2!M
M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@0V]M<&]S:71I;VX`
M365S<V%G92!$871E`$UE<W-A9V4@3W!T:6]N<P!-97-S86=E(%-E87)C:`!-
M97-S86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!6:65W:6YG`$UE
M<W-A9V4@9FEE;&1S`$UE<W-A9V4@9FQA9W,`365S<V%G92!F;VQD97)S`$UE
M<W-A9V4@9G)O;2`E<P!-97-S86=E(&AA<R!A='1A8VAM96YT<P!-97-S86=E
M(&ES(&5N8W)Y<'1E9`!-97-S86=E(&ES('-I9VYE9`!-97-S86=E(&UA=&-H
M97,`365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2X`365S<V%G92!S
M96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<P!-97-S86=E
M('-E;G0@<W5C8V5S<V9U;&QY+@!-97-S86=E<R!P97(@<&%G92!I;B!T:&4@
M;6%I;&)O>"!V:65W+@!-97-S86=E<R!T;P!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-97AI8V\`
M36EM92!4>7!E`$UO9&EF:65D($1A=&4`36]D:69Y`$UO9&EF>2!54DP`36]D
M=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N
M=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@=&AA;B!O;F4@861D
M<F5S<R!F;W5N9"!F;W(@9FEE;&0@(B5S(BX`36]R;V-C;P!-;W9E`$UO=F4@
M1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-
M;W9E('1O(&9O;&1E<@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&EP87)T+V%L
M=&5R;F%T:79E`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY86YM87(`3D]410!.
M86UE`$YA;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='D`3F%M:6)I
M80!.875R=0!.965D<R!!8W1I;VX`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R
M;&%N9',@06YT:6QL97,`3F5T=V]R:P!.979E<@!.979E<B!S879E(&%T=&%C
M:&UE;G1S`$YE=P!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@1F]L
M9&5R`$YE=R!-86EL`$YE=R!:96%L86YD`$YE=R!M97-S86=E<P!.97=S`$YE
M>'0`3F5X="!-97-S86=E`$YE>'0@4&%G90!.97AT(&]P=&EO;G,`3FEC87)A
M9W5A`$YI9V5R`$YI9V5R:6$`3FEU90!.;P!.;R!#97)T:69I8V%T92!F;W5N
M9`!.;R!%;F-R>7!T:6]N`$YO($ME>7,@:6X@2V5Y<FEN9P!.;R!-97-S86=E
M<P!.;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@4&5R<V]N86P@0V5R
M=&EF:6-A=&4@4')E<V5N=`!.;R!0<F5V:65W(%1E>'0`3F\@4'5B;&EC($ME
M>7,@1F]U;F0`3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N`$YO(&%T
M=&%C:&UE;G1S(&9O=6YD+@!.;R!C:&%N9V4N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@9FEL92!U<&QO861E
M9`!.;R!F;VQD97(@<V5L96-T960N`$YO(&9O;&1E<G,@87)E(&)E:6YG(&-H
M96-K960@9F]R(&YE=R!M86EL+@!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D
M`$YO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,`3F\@9F]L9&5R<R!W:71H
M('5N<V5E;B!M97-S86=E<P!.;R!M97-S86=E(&)O9'D@=&5X=`!.;R!M97-S
M86=E<R!M871C:&5D('EO=7(@<V5A<F-H+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($Q$05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&5R
M<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!0
M1U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@<&5R<V]N86P@4R]-24U%(&-E
M<G1I9FEC871E<R!I;7!O<G1E9"X`3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M
M(&-O;F9I9W5R960N`$YO('-P96QL:6YG(&5R<F]R<P!.;R!S=6=G97-T:6]N
M<P!.;R!U<V5R('-P96-I9FEE9"X`3F]N(%!A<G1I8VEP86YT`$YO;F4`3F]R
M9F]L:R!)<VQA;F0`3F]R;6%L`$YO<G=A>0!.;W0@1&5L971E9`!.;W0@1')A
M9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&$@=F%L:60@<'5B
M;&EC(&ME>2X`3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&QE;65N=&5D
M+@!.;W0@:6UP;W)T86YT(&UE<W-A9V5S`$YO="!S970`3F]T('-U<'!O<G1E
M9"X`3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE`$YO=&5S`$YO
M=&EC90!.;W9E;6)E<@!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@;6]N
M=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE=&EN
M9R!M;VYT:&QY+@!.=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O
M(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F(')O=W,`3TL`
M3U(`3V-T;V)E<@!/9F9I8V4`3VQD(&UE<W-A9V5S`$]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!B96EN9R!P=7)G960N`$]M86X`3VYL>2!D:7-P;&%Y(&9O;&1E
M<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\`3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E
M('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO;BX`3W!E7VX@1F]L9&5R`$]P96X@
M1F]L9&5R`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96YE9"!&;VQD97(`3W!T
M:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A
M;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]T:&5R
M`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C;W5N=',`3W1H97(@
M3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4$=0`%!'4"!$:6=I=&%L(%-I9VYA='5R90!0
M1U`@16YC<GEP="!-97-S86=E`%!'4"!%;F-R>7!T960@1&%T80!01U`@17)R
M;W(Z(`!01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@
M<')I=F%T92!K97DN`%!'4"!.3U0@06-T:79E`%!'4"!/<'1I;VYS`%!'4"!0
M87-S<&AR87-E($EN<'5T`%!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@
M<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%!'4"!0=6)L:6,@
M2V5Y`%!'4"!0=6)L:6,@2V5Y(%1E>'0`4$=0(%!U8FQI8R!+97D@9F]R("(E
M<R`H)7,I(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@4'5B;&EC($ME
M>2!F;W(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%!'4"!0=6)L
M:6,@2V5Y<FEN9P!01U`@4VEG;B!-97-S86=E`%!'4"!3:6=N+T5N8W)Y<'0@
M365S<V%G90!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!'4"!P<FEV871E
M(&ME>2!S=6-C97-S9G5L;'D@861D960N`%!'4"!P=6)L:6,@:V5Y('-U8V-E
M<W-F=6QL>2!A9&1E9"X`4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI
M<R!S>7-T96TN`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E
M('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@=F5R
M:69I960N`%!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O
M('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N`%!'4"!S
M=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF
M('EO=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P
M=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E
M;'-E('1H92!01U`@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'D`
M4$A0($-O9&4`4$A0(%-H96QL`%!/4#,`4$]0,R`H075T;R!$971E8W0@4')O
M=&]C;VQS*0!03U`S(&]V97(@4U-,`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG
M;F5D(&-E<G1I9FEC871E*0!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"D`
M4$]0,RP@;F\@5$Q3`%!?2%`@4VAE;&P`4&%G92`E9"!O9B`E9`!086=E('=I
M=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E`%!A9V4@=VET:"!T:&4@3&%S
M="!5;G-E96X@365S<V%G90!086MI<W1A;@!086QA=0!086YA;6$`4&%P=6$@
M3F5W($=U:6YE80!087)A9W5A>0!087)T*',I`%!A<W-P:')A<V4`4&%S<W!H
M<F%S92`H06=A:6XI`%!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D
M+@!087-S<&AR87-E.@!087-S<&AR87-E<R!C86X@;F]T(&)E(&5M<'1Y`%!A
M<W-P:')A<V5S(&1O(&YO="!M871C:`!087-S=V]R9`!087-S=V]R9"!I;F-O
M<G)E8W0`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A
M<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R
M;VT@8VQI<&)O87)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI
M<W-I;VX`4&5R;6ES<VEO;G,@9F]R`%!E<FUI<W-I;VYS(&9O<B!T:&ES('5S
M97(@8V%N(&YO="!B92!C:&%N9V5D+@!097)S;VYA;`!097)S;VYA;"!);F9O
M<FUA=&EO;@!097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+@!097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL
M>2X`4&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z
M(`!097)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2X`
M4&5R=0!0:&EL:7!P:6YE<P!0:&]N90!0:71C86ER;@!0;&%C92!Y;W5R('-I
M9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_`%!L86EN=&5X
M="!697)S:6]N(&]F($UE<W-A9V4`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@
M82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+@!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z`%!L
M96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N
M;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@
M<V5S<VEO;BX`4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N
M=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A
M<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S
M86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R!C;V]K:65S($%.1"!Y;W4@87)E
M(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL
M;"!H879E('1O(&QO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S
M('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2!H:6IA8VMI
M;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O
M;G9E;FEE;F-E+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R
M;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64N`%!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O
M<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W
M:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@82!F;VQD97(@8F5F
M;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS+@!0;&5A<V4@<V5L96-T(&%N
M(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T(&%T
M(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+@!0;&5A<V4@<V5L96-T(&]N
M;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN`%!L96%S92!S96QE
M8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#H`4&]L86YD`%!O
M<G1U9V%L`%!O=V5R960@8GD@2&]R9&4`4')E8V5D92!Y;W5R('-I9VYA='5R
M92!W:71H(&1A<VAE<R`H)RTM("<I/P!0<F5F97)E;F-E<R!S=6-C97-S9G5L
M;'D@=7!D871E9"X`4')E=FEE=P!0<F5V:6]U<R!-97-S86=E`%!R979I;W5S
M(%!A9V4`4')I;G0`4')I;W)I='D`4')I=F%T92!+97D`4')I=F%T92!+97D@
M4&%S<W=O<F0`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VUP="!E
M=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.
M3P!0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E
M9F%U;'0@=&\@6453`%!R;W1O8V]L.@!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@
M06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,@4$=0(&ME>7-E<G9E
M<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+@!0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC
M;P!0=7)?9V4@1&5L971E9`!0=7)G92!$96QE=&5D`%!U<F=E($9O;&1E<BAS
M*0!0=7)G92!4<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S(&EN(%1R
M87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N`%!U
M<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/P!0=7)G:6YG
M("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+@!0=7)G:6YG(#$@;65S
M<V%G92!F<F]M(%1R87-H(&9O;&1E<BX`46%T87(`475E<GD`475O=&$@<W1A
M='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`%%U;W1A('-T871U<SH@
M)2XR9DU"("\@3D\@3$E-250`475O=&$@<W1A='5S.B!.3R!,24U)5`!1=6]T
M:6YG("5F.@!24T$@4'5B;&EC($ME>2`H)60@8FET*0!295]Q=65S="!$96QI
M=F5R>2!#;VYF:7)M871I;VX`4F5C96EV960@3VX`4F5C96EV960@4VEN8V4`
M4F5C96EV960@56YT:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T($UE
M<W-A9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE
M9"X`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F
M<F5S:"!&;VQD97(@5FEE=W,Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;&]A
M9`!296QO860@5FEE=P!296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+@!296UE;6)E<B!T:&4@;&%S="!V:65W`%)E;6]T92!-86EL8F]X.@!2
M96UO=&4@4V5R=F5R<P!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!&:65L
M9"!&<F]M(%-E87)C:`!296UO=F4@8V]L=6UN`%)E;6]V92!P86ER`%)E;6]V
M92!S;W5R8V4`4F5M;W9E('1H90!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@
M)7,`4F5N86UE($9O;&1E<BAS*0!296YA;64@<V5N="UM86EL(&9O;&1E<B!A
M="!B96=I;FYI;F<@;V8@;6]N=&@_`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F
M86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;%]Y('1O
M($QI<W0`4F5P;&%C92!W:71H.@!297!L>0!297!L>2!396YT+@!297!L>2!T
M;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2!T;R!,:7-T`%)E<&QY('1O($QI
M<W0Z`%)E<&QY('1O(%]!;&P`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE
M<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N
M`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`
M4F5P;'DM5&\`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S($EN;F]C96YT
M`%)E<&]R="!A<R!3<&%M`%)E<75E<W0@82!?4F5A9"!296-E:7!T`%)E<75E
M<W0@9&5L:79E<GD@8V]N9FER;6%T:6]N/P!297%U97-T(')E860@<F5C96EP
M=',_`%)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"X`4F5Q=6ER960@4&%R
M=&EC:7!A;G0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-P;VYD96YT(%-T871U<R!5<&1A=&5D+@!297-U;'1S`%)E<W5M
M90!297-U;64@>6]U<B!S97-S:6]N`%)E='5R;B!T;R!&971C:"!-86EL`%)E
M='5R;B!T;R!/<'1I;VYS`%)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG
M(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E
M/P!2975N:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2;VQE`%)O;6%N
M:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W('!R
M;W!E<G1I97,`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344`4R]-
M24U%($5N8W)Y<'0@365S<V%G90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`
M4R]-24U%($5R<F]R.B``4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@
M9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!3+TU)344@3D]4($%C=&EV90!3
M+TU)344@3W!T:6]N<P!3+TU)344@4&%S<W!H<F%S92!);G!U=`!3+TU)344@
M4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+@!3+TU)344@4'5B;&EC($ME>2!F;W(@(B5S(B!W87,@
M<W5C8V5S<V9U;&QY(&1E;&5T960N`%,O34E-12!0=6)L:6,@2V5Y('-U8V-E
M<W-F=6QL>2!A9&1E9"X`4R]-24U%(%!U8FQI8R!+97ER:6YG`%,O34E-12!0
M=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E9"X`4R]-
M24U%(%-I9VX@365S<V%G90!3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A9V4`
M4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`%,O
M34E-12!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@96YA8FQE9"!S;R!T:&4@
M;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+@!3+TU)344@<W5P
M<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S
M:6=N960@;65S<V%G92!C86X@;F]T(&)E(&1I<W!L87EE9"X`4R]-24U%('-U
M<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E
M(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4R]-24U%('-U<'!O<G0@<F5Q
M=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W
M<V5R(&ES(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S
M+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%,O
M34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>0!305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%-13"!3:&5L;`!34T@`
M4U]13"!3:&5L;`!37W5B:F5C=`!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S
M`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N
M9"!T:&4@1W)E;F%D:6YE<P!386UO80!386X@36%R:6YO`%-A=61I($%R86)I
M80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@071T86-H;65N=',@=VET
M:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`4V%V
M92!/<'1I;VYS`%-A=F4@7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@87,@
M=6YS965N/P!3879E(')E8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@
M9&5F875L="!A9&1R97-S(&)O;VL_`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A
M;"!F;VQD97(_`%-A=F4@<V5N="!M86EL/P!3879I;F<@=&AE(&1R869T(&9A
M:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`4V5A<F-H
M`%-E87)C:"`E<P!396%R8V@@4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@
M06YO=&AE<B!!8V-O=6YT`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E
M;&5C="!A(&9I96QD`%-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@
M861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RX`4V5L96-T(&%L
M;`!396QE8W0@86QL(&9I96QD<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@
M861D<F5S<V5S+@!396QE8W0@86X@86-C;W5N=`!396QE8W0@;F]N90!396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L
M96-T('1H92!M86EL('-E<G9E<B!T>7!E`%-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@061D<F5S<R!B
M;V]K<SH`4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<@!396YD($QA=&5S
M="!);F9O<FUA=&EO;@!396YD($UE<W-A9V4`4V5N9"!0<F]B;&5M(%)E<&]R
M=`!396YD(')E860@<F5C96EP="!W:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N
M9&5R/P!396YE9V%L`%-E;G0@;6%I;"!F;VQD97(`4V5N="!M86EL(&9O;&1E
M<CH`4V5P=&5M8F5R`%-E<FEA;"!.=6UB97(`4V5R=F5R`%-E<G9E<B!A;F0@
M1F]L9&5R($EN9F]R;6%T:6]N`%-E<G9E<CH`4V5T`%-E="!P<F5F97)E;F-E
M<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M
M97-S86=E<RX`4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O
M<VEN9R!M97-S86=E<S\`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P`%-E>6-H96QL97,`4VAA<F4@1F]L9&5R<P!3:&%R92!M86EL(&9O;&1E
M<G,`4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RX`
M4VAO<G0@4W5M;6%R>0!3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T
M97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@
M=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N`%-H;W5L9"!T
M:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R
M(%!'4"!D871A/P!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E
M9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=6QD('EO=7(@4$=0('!U8FQI
M8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A
M=6QT/P!3:&]W`%-H;W<@06QL($9O;&1E<G,`4VAO=R!!;&P@2&5A9&5R<P!3
M:&]W($1E;&5T960`4VAO=R!,:6UI=&5D($AE861E<G,`4VAO=R!-86EL:6YG
M($QI<W0@26YF;W)M871I;VX`4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R
M<P!3:&]W(%5N<W5B<V-R:6)E9`!3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R
M:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_`%-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E;F0@:6X@
M=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE
M<W-A9V5S(&]N;'D_`%-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_`%-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE($9E=&-H($UA:6P@
M:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@26UA9V5S`%-H;W<@=&AE
M(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/P!3:&]W('1O=&%L(&YU;6)E
M<B!O9B!M86EL<R!I;B!F;VQD97(_`%-H;W=N`%-I7WIE`%-I97)R82!,96]N
M90!3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U
M<F4@06QG;W)I=&AM`%-I9VYE9`!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT
M96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-O;&]M;VX@27-L86YD<P!3;VUA
M;&EA`%-O<G0@1&ER96-T:6]N`%-O<G0@8GD@07)R:79A;`!3;W)T(&)Y($1A
M=&4`4V]R="!B>2!&<F]M($%D9')E<W,`4V]R="!B>2!-97-S86=E(%-I>F4`
M4V]R="!B>2!3=6)J96-T`%-O<G0@8GD@5&AR96%D`%-O<G0@8GD@5&\@061D
M<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-P86EN`%-P86T`4W!A;2!F;VQD97(Z`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5L;"!#:&5C:P!3<&5L;"!#:&5C
M:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R<F]R<R!P97(@
M<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-P;&ET(&-E;&P`4W!L:70@
M8V]L=6UN`%-P;&ET(')O=P!3<FD@3&%N:V$`4W1A<G0`4W1A=&4@;W(@4')O
M=FEN8V4`4W1A='5S`%-T<F5E="!!9&1R97-S`%-T<FEP($%T=&%C:&UE;G0`
M4W1R:7`@;&EN96)R96%K<S\`4W5B7VIE8W0`4W5B:F5C=`!3=6)J96-T($9I
M96QD`%-U8FUI=`!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U8V-E<W,`4W5C
M8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U
M;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E
M;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!U<&1A
M=&5D("(E<R(`4W5D86X`4W5G9V5S=&EO;G,`4W5M;6%R>0!3=6YR:7-E+U-U
M;G-E=`!3=7)I;F%M90!3=V%Z:6QA;F0`4W=E9&5N`%-W:71C:"!#;VUP;W-I
M=&EO;B!-971H;V0`4W=I=&-H('1O($A434P@8V]M<&]S:71I;VX`4W=I=&-H
M('1O('!L86EN('1E>'0@8V]M<&]S:71I;VX`4W=I='IE<FQA;F0`4WER:6%N
M($%R86(@4F5P=6)L:6,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<VMS`%1E7WAT`%1E;&5P:&]N92!.=6UB97(`5&5N=&%T:79E;'D@06-C97!T
M(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5R;7,@;V8@4V5R=FEC
M92!F:6QE(&YO="!S<&5C:69I960@:6X@8V]N9BYP:'``5&5X="!/;FQY`%1H
M86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($9R
M;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.@!4
M:&4@86-C;W5N="`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!A8V-O=6YT
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!A9&1R97-S("(E<R(@:&%S(&)E
M96X@861D960@=&\@)7,N`%1H92!A='1A8VAM96YT('=A<R!N;W0@9F]U;F0N
M`%1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;7!O<V4@=VEN
M9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U
M<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!C;VYT96YT
M<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+@!4:&4@8W5R<F5N
M="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M960@=&\@(B5S(BX`5&AE
M(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O
M;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D`%1H92!D<F%F="!H87,@8F5E
M;B!S879E9"!T;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E=F5N="!W87,@861D
M960@=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9I96QD("(E<R(@8V%N)W0@8F4@
M97AP86YD960N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@
M9F]L9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET
M<R!N86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U
M<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C
M<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE
M(&9O;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS
M=6)S8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R
M96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E
M<B`B)7,B('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A
M=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D
M+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O
M("(E<R(N`%1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T
M:&ES('!A<G0Z`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N
M`%1H92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N
M9&5R(&ES('!R97-E;G0@:6X@>6]U<B!A9&1R97-S8F]O:RX`5&AE(&UA:6P@
M<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z
M`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O
M<FUA=&EO;F%L(&UE<W-A9V4Z`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@
M=&AE(&9O;&QO=VEN9R!M97-S86=E.@!4:&4@;6%I;&)O>"`E<R!I<R!A;')E
M861Y(&5M<'1Y+@!4:&4@;65S<V%G92`B)7,B(&9R;VT@(B5S(B`H)60@8GET
M97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="X`5&AE(&UE<W-A9V4@8F5I
M;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG+@!4:&4@;65S
M<V%G92!H87,@8F5E;B!D96QE=&5D+@!4:&4@;65S<V%G92!H87,@8F5E;B!V
M97)I9FEE9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E
M<CH@)7,N`%1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N
M(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B;&]C:R!P
M;W!U<"!W:6YD;W=S/P!4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@
M2V5Y(&-A;B!B92!V:65W960@)7,N`%1H92!R97%U97-T960@9FEL92!D;V5S
M(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!4:&4@<F5Q
M=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM
M96YT+@!4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG
M(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@9G)O;2!Y;W4@
M=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K
M("5S('1O('-E;F0@=&AE(&YO=&EF:6-A=&EO;B!M97-S86=E+@!4:&4@<V5R
M=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA
M<R!B965N('-A=F5D+@!4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A
M=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92X`5&AE('-I9VYA='5R92!C
M;W5L9"!N;W0@8F4@<F5P;&%C960N`%1H92!S:6=N871U<F4@=V%S('-U8V-E
M<W-F=6QL>2!R97!L86-E9"X`5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T
M(&5X:7-T+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML
M:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@
M;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T:&4@<F5T
M=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G
M92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S
M86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E
M9"`E<RX`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U
M8V5S<V9U;&QY('-T;W)E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@;F\@;65S
M<V%G97,@:6X@=&AI<R!M86EL8F]X+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@
M=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S
M(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA
M:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R
M;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@
M(B5S(CH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G97,@
M9G)O;2`B)7,B('1O("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@
M=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!I;B!T:&4@
M9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE
M<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`E<P!4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&9L
M86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N
M=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T
M87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R
M(&UO=FEN9R!M97-S86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG
M('1H:7,@;65S<V%G92!A<R!A(&1R869T+@!4:&5R92!W87,@86X@97)R;W(@
M<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@;F\@=&5X="!I;B!T
M:&ES(&UE<W-A9V4@<&%R=`!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S
M(&5M8F5D9&5D(&EN(&ET+@!4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S
M(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92!T
M:&ES.B``5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE
M(&UE<W-A9V4N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@
M86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BX`5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!C;VYT:6YU93\`5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@36%C
M:6YT;W-H(&9I;&4N`%1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM
M96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-24U%
M+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA
M<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@8V]N
M=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M871I;VXL(&)U="!T
M:&4@9F]R;6%T(&]F('1H:7,@;65S<V%G92!I<R!U;FMN;W=N+@!4:&ES(&UE
M<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y
M<'1E9"!M97-S86=E+B!%<G)O<CH@`%1H:7,@;65S<V%G92!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D
M:6YG('1O(%)&0R`R,#$U*2X`5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R;6%T+@!4:&ES(&UE
M<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+@!4:&ES
M(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-24U%
M+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N
M`%1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N`%1H
M:7,@;65S<V%G92!T;P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C
M:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H
M:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD
M;W<N`%1H<F5A9"!6:65W`%1I;64`5&EM92!F;W)M870`5&ET;&4`5&\`5&\@
M061D<F5S<P!4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE(&-L:6-K
M:6YG+@!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K
M:6YG+@!4;V1A>0!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]T86P@
M071T86-H;65N=',@4VEZ93H`5')A<V@@9F]L9&5R`%1R87-H(&9O;&1E<CH`
M5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U;FES:6$`5'5R
M:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=79A;'4`
M55),`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&-H86YG92!T;R`E
M<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(')E=')I979E('%U;W1A`%5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86YS=V5R
M960`56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T90!5;F1I<V-L;W-E9"!2
M96-I<&EE;G1S`%5N9&\@0VAA;F=E<P!5;FAA;F1L960@8V]M<&]N96YT(&]F
M('1Y<&4Z("5S`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M
M`%5N:71E9"!3=&%T97,`56YK;F]W;@!5;FMN;W=N($1A=&4`56YK;F]W;B!-
M965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N;&]A9"!087-S<&AR87-E`%5N
M;F%M960`56YS965N`%5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I`%5N<W5P
M<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E($%T=&%C:&UE;G0@26YF
M;W)M871I;VX`57!D871E(')E<W!O;F1E;G0@<W1A='5S`%5P;&]A9`!5<G5G
M=6%Y`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0(&9O;&1E<B!S=6)S8W)I
M<'1I;VYS/P!5<V5R`%5S97(@(B5S(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE
M('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(BX`57-E<B!/
M<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N86UE`%5S97)N86UE("(E
M<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S
M(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5F%C871I;VX`5F%N=6%T=0!6
M96YE>G5E;&$`5F5R<VEO;@!6:65T($YA;0!6:65W`%9I97<@)7,`5FEE=R`E
M<R!0=6)L:6,@2V5Y`%9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@
M=VEN9&]W`%9I97<@4&5R<V]N86P@4')I=F%T92!+97D`5FEE=R!097)S;VYA
M;"!0=6)L:6,@2V5Y`%9I97<@5&AR96%D`%9I97<@5&AU;6)N86EL`%9I97<@
M86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W(&%T=&%C:&UE
M;G0@:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!C;VYT96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W`%9I97<@979E;G0`5FEE=R!M97-S86=E<R!I;B`E<P!6
M:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CH`5FEE=R!T
M87-K`%9I97<@=&AE($EM86=E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6
M:7)G:6X@27-L86YD<RP@52Y3+@!6:7)T=6%L($9O;&1E<B`B)7,B(&-R96%T
M960@<W5C8V5S9G5L;'DN`%9I<G1U86P@1F]L9&5R<P!6:7)T=6%L($9O;&1E
M<G,@<F5Q=6ER92!A(&QA8F5L+@!6:7)T=6%L(&9O;&1E<B!L86)E;`!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=E8@!7965K;'D`5V5L8V]M90!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E
M<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&5N(&1E
M;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD
M97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@87,@9&5L971E9#\`5VAE;B!O
M<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A;G0@
M=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD('=E
M('-A=F4@871T86-H;65N="!D871A/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3H`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)A<"!T97AT
M(&%T('1H:7,@;6%N>2!C:&%R86-T97)S+@!960!965E9`%EE87)L>0!996UE
M;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA
M:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ`%EO=2!A<F4@871T
M96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T
M:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!A='1E;7!T:6YG('1O
M(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!C;W!Y
M:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E871I;F<@
M82!S=6(M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L
M(&9O;&1E<BX`66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B``66]U(&1I
M9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT
M+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"!T;R!L;V=I;BX`66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O
M;&1E<@!9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE
M(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RX`66]U(&AA=F4@)7,@;F5W(&UE
M<W-A9V5S+@!9;W4@:&%V92`Q(&YE=R!M97-S86=E+@!9;W4@:&%V92!A="!L
M96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@
M=7!L;V%D('EE="X@07)E('EO=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI
M<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N=',_`%EO=2!H879E
M(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R<SH`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M
M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N`%EO=2!M=7-T(&5N
M=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T
M;R!V:65W('1H:7,@;65S<V%G90!9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H
M<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES
M(&UE<W-A9V4`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER
M<W0N`%EO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N
M`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S
M96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N`%EO=2!M=7-T('-P
M96-I9GD@82!R96-I<&EE;G0N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I
M;&4@=&\@871T86-H+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N`%EO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E
M)7,N`%EO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RX`66]U('=E
M<F4@;F]T('-U8G-C<FEB960@=&\@(B5S(BX@2&5R92!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@(B5S
M(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!S=6-C
M97-S9G5L;'D@<W5B<V-R:6)E9"!T;R`B)7,B`%EO=2!W97)E('-U8V-E<W-F
M=6QL>2!U;G-U8G-C<FEB960@9G)O;2`B)7,B`%EO=7(@16UA:6P@061D<F5S
M<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!01U`@
M4'5B;&EC+U!R:79A=&4@2V5Y<P!9;W5R(%!R:79A=&4@2V5Y`%EO=7(@4'5B
M;&EC($ME>0!9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\:3XH;W!T:6]N86PI
M/"]I/@!9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,`
M66]U<B!A8V-O=6YT<SH`66]U<B!A;&EA<R!A9&1R97-S97,Z(#QI/BAO<'1I
M;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]I/@!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES
M<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P
M=&EO;B`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO
M=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R
M(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G
M97,Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO
M=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"X`66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!R96UO=&4@
M<V5R=F5R<SH`66]U<B!S:6=N871U<F4Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M
M8FEA`%II;6)A8G=E`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O<G1=`%]!
M9&UI;FES=')A=&EO;@!?0F-C`%]";&%C:VQI<W0`7T-,20!?0V,`7T-O;7!O
M<V4`7T1E;&5T90!?1&5L971E(%)O=P!?1F]L9&5R<P!?1W)O=7!S`%](96QP
M`%])9&5N=&ET>0!?26YB;W@`7TQO9R!I;@!?3&]G(&]U=`!?365S<V%G92!3
M;W5R8V4`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?
M4')I;G0`7U!R:6]R:71Y`%]2969R97-H("5S`%]296UO=F4@3&EN:RXN+@!?
M4F5P;'D`7U-E87)C:`!?4V5N9"!-97-S86=E`%]3971U<`!?5&AR96%D`%]4
M;P!?56YD96QE=&4`7U5S97)S`%]6:65W(%1H<F5A9`!?5VAI=&5L:7-T`&%D
M9')E<W,@8F]O:P!A='1A8VAM96YT`&%T=&%C:&UE;G1S+GII<`!B>71E<P!C
M86QE;F1A<@!F:6QE`&9R;VT`:V5Y`&UA:6QB;W@@9FEL90!N86UE`&YO;F4`
M;F]T97!A9`!O<@!S<&5L;&EN9R!E<G)O<@!S<&5L;&EN9R!E<G)O<G,`=6YN
M86UE9`!V0V%R9`!Y;W5R(&)L86-K;&ES=`!Y;W5R('=H:71E;&ES=`!0<F]J
M96-T+4ED+59E<G-I;VXZ($EM<"!H,RTT+C`N,PI297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@
M,C`P-2TQ,2TR-"`R,#HS-2LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M
M,3$M,C0@,C`Z-#4K,#$P,`I,87-T+51R86YS;&%T;W(Z($MR>GES>G1O9B!+
M;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#X*3&%N9W5A9V4M5&5A;3H@4&]L:7-H
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("`@("`@1&\Z(``@("`@
M1&%T83H@`"`@("!/9#H@`"5S("T@9V]T;W=Y(&1O('=Y:V]N86YI82!C>6ML
M:6-Z;GEC:"!O<&5R86-J:2!Z87IN86-Z;VYY8V@@<&]N:;]E:BX`("@E<R!D
M;FD@=&5M=2D`*&ML=6-Z(&1O<W3J<'4@)7,I`"`H=R!C:;%G=2`E<R!D;FDI
M`"`H9'IIMBD`("AJ=71R;RD`("AW8WIO<F%J*0`@5&5M870Z(``@=R``(B5S
M(B!N:64@:F5S="!P<F%W:62S;W=Y;2!W>6)O<F5M+@`B)7,B(&YI92!J97-T
M('-K;VYF:6=U<F]W86YY('<@<F5J97-T<GIE($AO<F1E+@!59&&S;R!S:>H@
M9&]D8>8@(B5S(B!D;R!G<G5P+@!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!U
M<')A=VYI9?$N`"(E<R(@;FEE('IO<W1ALR!U='=O<GIO;GDZ("5S+@`C`"4N
M,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`)60@)7,@:2`E<P`E9"!W:6%D;VUO
MMF-I('IO<W1ALV\@=7-U;FGJ=&4N`"5D('=I861O;6^V8VD@>F]S=&&S;R!Z
M9[-O<WIO;GEC:"!J86MO(&YI92US<&%M(&1O(%1W;VIE9V\@861M:6YI<W1R
M871O<F$N`"5D('=I861O;6^V8VD@>F]S=&&S;R!Z9[-O<V]Z;GEC:"!J86MO
M(&YI92US<&%M+@`E9"!W:6%D;VUOMF-I('IO<W1ALV\@>F>S;W-Z;VYY8V@@
M:F%K;R!S<&%M(&1O(%1W;VIE9V\@861M:6YI<W1R871O<F$N`"5D('=I861O
M;6^V8VD@>F]S=&&S;R!Z9[-O<WIO;GEC:"!J86MO('-P86T`)60@9&\@)60@
M>B`E9"!W:6%D;VUOMF-I`"5S("T@57=A9V$`061M:6YI<W1R86-J82`E<P`E
M<R!O9&-I<VL@<&%L8V$`)7,@2T(`)7,@+2!O<&5R86-J92!C>6ML:6-Z;F4@
M+2!P;W1W:65R9'IE;FEE`"5S($%D;6EN:7-T<F%C:F$@4$=0`"5S($%D;6EN
M:7-T<F%C:F$@4R]-24U%`$MO;F9I9W5R86-J82`E<P!296IE<W1R86-J82`E
M<P`E<R!J=;\@:7-T;FEE:F4N`"5S(&IUOR!I<W1N:65N:64N($YA>G=A(&9O
M;&1E<G4@)7,@;FEE('IO<W1ALV$@>FUI96YI;VYA+@!F;VQD97(@)7,@;FEE
M(&IE<W0@<')A=VEDLV]W>2X`9F]L9&5R("5S('IM:65N:2!N87IWZB!N82!P
M;V-ZL71K=2!P<GIY<WJS96=O(&UI97-IL6-A+@`E<R!Z86%K8V5P=&]W86YE
M+@`E<R!S:V%S;W=ALR`E<P`E<R!O9'!O=VEE9'II8;,@;F$@>F%P>71A;FEE
M('=O;&YY+WIA:NIT>0`E<R!O9'!O=VEE9'II8;,@;F$@>F%P<F]S>F5N:64@
M9&\@)7,`)7,@=WESLV&S($-I(&EN9F]R;6%C:F4N`"5S("!P<O-B;FEE('IA
M86MC97!T;W=ALRX`)7,@:F5S="!W>6UA9V%N>0`E<R!M:6YU=``E<R!N:65Z
M;F%L97II;VYY+@`E<R!W>7.S8;,@>F%P>71A;FEE(&1O($-I96)I92!O(&EN
M9F]R;6%C:NH@=V]L;GDO>F%JZG1Y+@`E<R!P>71A(&\@5'=O:K$@;V)E8VYO
MMN8@;F$@)7,N`"5S(&1O("5S('H@)7,`)7,@>F]S=&&S('!O<')A=VYI92!D
M;V1A;GD@9&\@)7,N`"5S(+]Y8WIY('-O8FEE("5S+@`E<R!C:&-E($-IZB!P
M;VEN9F]R;6]W8>8@;R`E<RX`)7,@<')O<VD@;R!N86IN;W=S>F4@:6YF;W)M
M86-J92!O("5S+@!+<VFQOVMA(&%D<F5S;W=A("5S`$MA;&5N9&%R>B`E<P!.
M;W1A=&YI:R`E<P!,:7-T82!Z861A\2`E<P`E<SH@)7,`)7,Z("5S("@E9"9N
M8G-P.WHF;F)S<#LE9"D`*$%K8V5P='5J('1E('IM:6%N>2!I(&EDO"!D;R!N
M87-TZG!N96=O(&5K<F%N=2XI`"A!;G5L=6H@=W-Z>7-T:VEE('IM:6%N>2!I
M('=R\V,@9&\@;VMN82!E9'EC:FDN*0`H4&]W<O/F(&1O(&]K;F$@961Y8VII
M('!O('IA<W1O<V]W86YI=2!D;W1Y8VAC>F%S;W=Y8V@@>FUI86XN("!:;6EA
M;GD@=R!B:65R>K%C>6T@;VMN:64@;FEE(&+J9+$@>F%S=&]S;W=A;F4N*0`H
M5WFV;&EJ('=I861O;6^VYB!P;R!Z87-T;W-O=V%N:74@=W-Z>7-T:VEC:"!Z
M;6EA;BX@(%IM:6%N>2!W(&)I9;^Q8WEM(&]K;FEE(&YI92!BZF2Q('IA<W1O
M<V]W86YE+BD`*B!$;V1A:B!P;W!R>F5Z(&ML:6MN:>IC:64@3TL@*@`J(%=Y
M8FEE<GH@861R97,H>2D@*@`M+2!W>6)I97)Z("TM`#$@=VEA9&]M;[;F('IO
M<W1ALV$@=7-U;FGJ=&$N`#$@=VEA9&]M;[;F('IO<W1ALV$@>F>S;W-Z;VYA
M(&IA:V\@;FEE+7-P86T@9&\@5'=O:F5G;R!A9&UI;FES=')A=&]R82X`,2!W
M:6%D;VUOMN8@>F]S=&&S82!Z9[-O<WIO;F$@:F%K;R!N:64M<W!A;2X`,2!W
M:6%D;VUOMN8@>F]S=&&S82!Z9[-O<WIO;F$@:F%K;R!S<&%M(&1O(%1W;VIE
M9V\@861M:6YI<W1R871O<F$N`#$@=VEA9&]M;[;F('IO<W1ALV$@>F>S;W-Z
M;VYA(&IA:V\@<W!A;2X`,3`P('IN86OS=P`Q,#`P('IN86OS=P`Q,BUG;V1Z
M:6YN>2!F;W)M870`,C0M9V]D>FEN;GD@9F]R;6%T`#(T(&=O9'HN`#(U,"!Z
M;F%K\W<`-3`P('IN86OS=P`\4&]P<GIE9&YI`$YA<W2Q<&FS(&*SL60@:W)Y
M='EC>FYY`$1UOWD@;V)R87IE:R`E<R!J97-T(&1OL[%C>F]N>2!D;R!T96H@
M=VEA9&]M;[9C:0!:=W+S8V]N;R!N;W3J(&]D(&]D8FEO<F-Y('=I861O;6^V
M8VD@=WESLV%N96H@<')Z97H@0VEE8FEE+@!0;W1R>F5B;GD@:F5S="!K;'5C
M>B!P=6)L:6-Z;GD@4$=0(&1O('IA<WIY9G)O=V%N:6$@=VEA9&]M;[9C:2X`
M4&]T<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!S<')A=V1Z
M96YI82!P;V1P:7-A;F5J('=I861O;6^V8VDN`%!O=')Z96)N92!SL2!K;'5C
M>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A>B!H87.S
M;R!D;R!O9'-Z>69R;W=A;FEA('=I861O;6^V8VDN`%!O=')Z96)N92!SL2!K
M;'5C>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A>B!H
M87.S;R!D;R!P;V1P:7-A;FEA('=I861O;6^V8VDN`%!O=')Z96)N92!SL2!K
M;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C>B!P<GEW871N>2!3+TU)344@
M;W)A>B!H87.S;R!D;R!O9'-Z>69R;W=A;FEA('=I861O;6^V8VDN`%!O=')Z
M96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C>B!P<GEW871N
M>2!3+TU)344@;W)A>B!H87.S;R!D;R!P;V1P:7-A;FEA('=I861O;6^V8VDN
M`%!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!334E-12!D;R!Z87-Z
M>69R;W=A;FEA('=I861O;6^V8VDN`$%-+U!-`$D`3R!T>6T@961Y=&]R>F4`
M3R!P<F]G<F%M:64N+BX`06MC971P=6H@O[%D86YI90!!:V-E<'1U:@!:86%K
M8V5P=&]W86YE.B``2&%SLV\@9&\@:V]N=&$`2V]N=&\@>F%B;&]K;W=A;F4N
M`$YA>G=A(&MO;G1A.@!+;VYT80!!:V-J90!$;V1A:@!$;V1A:B!T=71A:CH`
M1&]D86H@;F]WL2!G<G5PZ@!$;V1A:B!N;W=E('5P<F%W;FEE;FEE`$1O9&%J
M(&YO=V5G;R!UOWET:V]W;FEK83H`1&]D86H@:V]L=6UNZ@!$;V1A:B!N;W=Y
M8V@@8WJS;VYK\W<`1&]D86H@<&%RZ@!$;V1A:B"\<O-DLV\`1&]D86H@;65N
M=2`E<R!D;R!P87-K82!-;WII;&QI`$1O9&%J(&1O(&UO:F5G;R!K86QE;F1A
M<GIA`$1O9&%J(&1O(&UO:F5J(&MS:;&_:VD@861R97-O=V5J("@E<RD`1&]D
M86H@9&\@:W-IL;]K:2!A9')E<V]W96HZ`$1O9&%J(&1O(&UO:F5J(&MS:;%Z
M:VD@861R97-O=V5J`$1O9&%J('6_>71K;W=N:6MA`%!L:6L@(B5S(B!D;V1A
M;GD@:F%K;R!Z8;.Q8WIN:6LN`$1O9&%N;R`B)7,B(&1O('-Y<W1E;74N($UO
MOV5S>B!S:>H@>F%L;V=O=V'F+@!$;V1A=V%N:64@=;]Y=&MO=VYI:_-W(&IE
M<W0@=WFS86-Z;VYE+@!$;V1A=&MO=V4@;F%GL_-W:VD@=WFV=VEE=&QA;F4@
M<&]D8WIA<R!P;V1G;+%D86YI83H@/&D^*&]P8VIO;F%L;FEE+"!W<')O=V%D
MO"!K8;]D>2!N86>S\W=E:R!W(&YO=V5J(&QI;FEI*3PO:3X`1&]D871K;W=E
M(&EN9F]R;6%C:F4@;6]GL2!B>>8@>F%W87)T92!W("5S+@!3>F-Z96?SLWD@
M9&]T>6-ZL6-E(&1O9&%T:V]W>6-H(&EN9F]R;6%C:FD`4WIC>F5G\[-Y(&1O
M='EC>K%C92!D;V1A=&MO=V5J('=I861O;6^V8VD`4WIC>F5G\[-Y(&1O='EC
M>K%C92!D;V1A=&MO=V5J('=I861O;6^V8VD@;6]GL2!B>>8@>F%W87)T92!W
M("5S+@!3>F-Z96?SLV]W92!I;F9O<FUA8VIE(&\@8K/J9'II90!3>F-Z96?S
MLV]W92!I;F9O<FUA8VIE(&\@8K/J9'II92!M;[]N82!P<GIE9VRQ9&ZQYB!W
M("5S+@!!9')E<P!+<VFQOVMA(&%D<F5S;W=A`$MS:;&_:VD@861R97-O=V4`
M061R97,@0D-#(&1L82!W<WIY<W1K:6-H('=I861O;6^V8VDZ(#QI/BAO<&-J
M;VYA;&YI92P@=W!R;W=A9+P@:V&_9'D@861R97,@=R!N;W=E:B!L:6YI:2D\
M+VD^`$%D<F5S>2"V8VFV;&4@<')Z>7=IL7IA;F4@9&\@=&5J('1OOW-A;6^V
M8VDZ(#QI/BAO<&-J;VYA;&YI92P@=W!R;W=A9+P@:V&_9'D@861R97,@=R!N
M;W=E:B!L:6YI:2D\+VD^`$%D;6EN:7-T<F%C:F$`4F5K;&%M>0!!9F=A;FES
M=&%N`$%L8F%N:6$`06QG:65R:6$`06QI87,`5W-Z>7-T:V\`5W-Z>7-C>2!U
M=VEE<GIY=&5L;FEE;FD@=;]Y=&MO=VYI8WD`5W-Z>7-T:VEE(&=R=7!Y`%=S
M>GES=&MI92!U<')A=VYI96YI80!7<WIY<W1K:64@=VEA9&]M;[9C:2!W(&9O
M;&1E<GIE*&%C:"D@8NIDL2"V8VFQ9V%N92!D;R!J961N96=O('!L:6MU($U"
M3U@Z`%=S>GES=&MI92!W:6%D;VUOMF-I('<@9F]L9&5R>F4@(B5S(BP@<W1A
M<G-Z92!N:;\@)7,@9&YI+"!Z;W-T86ZQ(&)E>G!O=W)O=&YI92!S:V%S;W=A
M;F4N`%=S>GES=&MI92!S=&%R92!L:6YK:2!Z8;.Q8WIN:6OS=R!S=&%R<WIE
M(&YIOR`E<R!M:65S:>IC>2!Z;W-T86ZQ('-K87-O=V%N92X`5W-Z>7-T:VEE
M('-T87)E(&9O;&1E<GD@<V5N="UM86EL+"!Z82!W>6JQ=&MI96T@)7,@;F%J
M;F]W<WIY8V@L('IO<W1A;K$@<VMA<V]W86YE+@!7<WIY<W1I92!U<')A=VYI
M96YI82!F;VQD97)U("(E<R(@9&QA('6_>71K;W=N:6MA("(E<R(@>F]S=&&S
M>2!U<W5N:>IT90!0;WIW;VQIYB!N82!Z87-T;W-O=V%N:64@9FEL='+S=R!D
M;&$@=W-Z>7-T:VEC:"!S:W)Z>6YE:S\`4&]Z=_-L(&YA('=I96QE(&%D<F5S
M\W<`2G6_(&ES=&YI96IE`$%L=&5R;F%T>7=N>2!L;V=I;B!)35-0`$%L=&5R
M;F%T>7=N>2!H87.S;R!)35-0`$%L=&5R;F%T>7=N82!N87IW82!UOWET:V]W
M;FEK82!)35-0`$%L=&5R;F%T>7=N>2!A9')E<R!E;6%I;`!!;'1E<FYA='EW
M;GD@=&5K<W0Z`$%L=&5R;F%T>7=N92!C>NJV8VD@9&QA('1E:B!S96MC:FDZ
M`%IA=W-Z90!:87=S>F4@>F%P:7-U:B!Z8;.Q8WIN:6MI`%=Y<W2Q<&FS(&*S
ML60@<&]D8WIA<R!P<O-B>2!U<W5N:>IC:6$@>F&SL6-Z;FEK82X@4V5R=V5R
M($E-05`@>G=R\V-ILR!O9'!O=VEE9+PZ`%IO<W1ALV$@<&]D86YA(&YI97!R
M87=I9+-O=V$@=V%R=&^VYBX`5WES=+%P:;,@;FEE>FYA;GD@8K.Q9"!P;V1C
M>F%S('1W;W)Z96YI82!N;W=E9V\@>F%D86YI82X`06YD;W)A`$%N9V]L80!!
M;F=U:6QL80!!;F]N:6UO=V4@4')O>'D`3V1P;W=I962\`$]D<&]W:65D>FEA
M;F4`5VEA9&]M;[9C:2!Z(&]D<&]W:65D>FFQ`$%N=&%R:W1Y9&$`07!L:6MA
M8VIA`$%P;&EK86-J82!G;W1O=V$`6F%S=&]S=6H@9FEL=')Y`%IA<W1O<W5J
M(&9I;'1R>2!D;R`E<P!:87-T;W-O=V'F(&9I;'1R>2!P;V1C>F%S(&QO9V]W
M86YI83\`6F%S=&]S;W=AYB!F:6QT<GD@<&]D8WIA<R!W>;9W:65T;&%N:64@
M3V1E8G)A;F4_`%IA='=I97)DO`!+=VEE8VEE\0!7:65L:V^VYB!A<F-H:7=U
M;0!.87IW82!A<F-H:7=U;0!#>GD@8VAC97-Z('5S=6ZQYB!T96X@:VQU8WH@
M<'5B;&EC>FYY/P!#>GD@8VAC97-Z('5S=6ZQYB!4=V]JL2!P87)A(&ML=6-Z
M>3\@*&YI97IA;&5C86YE(2D`0WIY(&-H8V5S>B!N82!P97=N;R!T;R!Z<F]B
M:>8_`$-Z>2!C:&-E<WH@=7-U;K'F(&-ALVMO=VEC:64@=&4@=VEA9&]M;[9C
M:3\`0WIY(&-H8V5S>B!U<W5NL>8@8V&S:V]W:6-I92!T92!Z8;.Q8WIN:6MI
M/P!#>GD@8VAC97-Z(&]P<O._;FGF('1E;B!F;VQD97(_`$-Z>2!C:&-E<WH@
M;W!R\[]N:>8@:V]S>C\`0WIY(&-H8V5S>B!U<W5NL>8@8V&S:V]W:6-I92!T
M92!W:6%D;VUOMF-I/P!#>GD@8VAC97-Z('IGLV]S:>8@=.H@=VEA9&]M;[;F
M(&IA:V\@;FEE<WIK;V1L:7>Q/P!#>GD@8VAC97-Z('IGLV]S:>8@=.H@=VEA
M9&]M;[;F(&IA:V\@<W!A;3\`07)G96YT>6YA`$%R;65N:6$`0WIA<R!P<GIY
M8GEC:6$`07)U8F$`5WIR87-T86JQ8V\`6F%P>71A:@!0;W!R;[8@;R!P;W1W
M:65R9'IE;FEE('!R>F5D('=Y:V]N86YI96T@;W!E<F%C:FD@8WEK;&EC>FYY
M8V@_`%IAL[%C>@!:8;.Q8WH@<&QI:VD`6F&SL6-Z>>8@:V]P:>H@5'=O:F$@
M:VQU8WIA('!U8FQI8WIN96=O(%!'4"!D;R!W:6%D;VUOMF-I/P!:8;.Q8WIO
M;F4@<&QI:VDZ`%IAL[%C>F]N>2!P;&EK("(E<R(@<')Z96MR86-Z82!L:6UI
M="!R;WIM:6%R=2!Z8;.Q8WIN:6MA+B!0;&EK(&YI97IAL[%C>F]N>2X`6F&S
ML6-Z;FEK`%IAL[%C>FYI:R!W>6UA>F%N>3H@3W)Y9VEN86QN>2!T>7`@>F&S
ML6-Z;FEK80!:8;.Q8WIN:6MI`%5C>F5S=&YI8W1W80!5=V%G80!!=')Y8G5T
M>0!3:65R<&EE\0!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G5S.B!.:64@
M>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!I;6%P+@!!=71H
M7V-Y<G5S.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI
M82!I;6%P+@!!=71H7V9T<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R
M;WIS>F5R>F5N:6$@1E10+B!3:V]M<&EL=6H@4$A0('H@<&%R86UE=')E;2`M
M+65N86)L92`N`$%U=&A?:6UA<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G
M;R!R;WIS>F5R>F5N:6$@24U!4"X`075T:%]I;7`Z(%=Y;6%G86YE(')O>G-Z
M97)Z96YI92!)34%0(&YI92!Z;F%L97II;VYE+@!!=71H7VMR8C4Z($YI92!Z
M;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&MR8C4N`$%U=&A?
M;&1A<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@
M3$1!4"X`075T:%]L9&%P.B!.:64@=61ALV\@<VGJ('5S=6ZQYB!UOWET:V]W
M;FEK82`E<P!!=71H7VQD87`Z($YI92!U9&&S;R!S:>H@=6%K='5A;&YIYB!U
MOWET:V]W;FEK82`E<P!!=71H7VUC86PZ($YI92!Z;F%L97II;VYO('=Y;6%G
M86YE9V\@<F]Z<WIE<GIE;FEA($U#04PN`$%U=&A?<VUB875T:#H@3FEE('IN
M86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@<VUB875T:"X`57=I
M97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ`%5W:65R>GET96QN:65N
M:64@;FEE('!O=VEO9+-O('-IZBX@)7,`57=I97)Z>71E;&YI96YI92!O9')Z
M=6-O;F4@<')Z97H@<V5R=V5R(%)!1$E54RX`57=I97)Z>71E;&YI96YI92!D
M;R!S97)W97)A($944"!N:64@<&]W:6]DLV\@<VGJ+@!!=71O;6%T>6-Z;FEE
M('!O:V%Z>7=AYB!Z9&KJ8VEA('<@=VEA;6]M;[9C:6%C:"!(5$U,(&]D(&%U
M=&]R82P@:W3S<GD@>FYA:F1U:F4@<VGJ('<@;6]J96H@:W-IL;]C92!A9')E
M<V]W96H_`$1O<W3J<&YE(&MS:;&_:VD@861R97-O=V4Z`$1O<W3J<&YE('!O
M;&$Z`$]C>F5K=6JQ8V4@;F$@;V1P;W=I962\`$%Z97)B96IDOV%N`%=Y;?-W
M:VD@0D]&2`!0;W=R\W0@9&\@)7,@*%]K*0!0;W=R\W0@9&\@)7,`5+-O`$MO
M;&]R('2S80!:LV4@:&%SLV\@2V5R8F5R;W-A+@!:LV$@;F%Z=V$@=;]Y=&MO
M=VYI:V$@2V5R8F5R;W-A`%=Y<W!Y($)A:&%M80!"86AR86IN`$)ALW1Y8VMI
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S>@!"8V,`0FEALV]R=;8`0F5L9VEA
M`$)E;&EZ90!0;VYIOV5J(&IE<W0@>G=Y:[-Y('1E:W-T('H@=VEA9&]M;[9C
M:2!I;F9O<FUA8WEJ;F5J+@!"96YI;@!"97)M=61Y`$)H=71A;@!$871A('5R
M;V1Z96YI80!#>F%R;F$@;&ES=&$`57-T87=I96YI82!B;&]K=0!4>7`@8FQO
M:W4`0FQO:W5J(&]B<F%Z:VD@=R!W:6%D;VUOMF-I86-H($A434PL(&-H>6)A
M(+]E(&IE<W0@<W!E8VIA;&YA('!R;[9B83\`5')EMN8`0F]L:7=I80!:86NS
M861K:0!";[9N:6$@:2!(97)C96=O=VEN80!/8F$`3F%GL_-W96L@:2!T<F6V
MY@!"<F%Z>6QI80!"=;-G87)I80!#35,`0U)#`%>S8;9C:7=OMF-I(&MO;?-R
M:VDN+BX@*%]C*0!5:[-A9"!Z;F%K\W<@*%]H*0!+86QE;F1A<GH`2V%M8F]D
MOV$`2V%M97)U;@!"L[%D('!OL[%C>F5N:6$@>F4@>F1A;&YY;2!S97)W97)E
M;2!P;V-Z='DN`$*SL60@<&^SL6-Z96YI82!Z92!Z9&%L;GEM('-E<G=E<F5M
M('!O8WIT>3H@`$YI92!M;V?J('=YMG=I971L:>8@+2!Z;F%L87JS96T@='EL
M:V\@)7,@>B`E<R!C>NJV8VD@=&5J('=I861O;6^V8VD@=R!S:W)Z>6YC92!P
M;V-Z=&]W96HN`$YI92!U9&&S;R!S:>H@>G)E<V5T;W=AYB!H87.S82!A=71O
M;6%T>6-Z;FEE+"!S:V]N=&%K='5J('-IZB!Z(&%D;6EN:7-T<F%T;W)E;2X`
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($E-05`Z("5S
M`$MA;F%D80!!;G5L=6H`06YU;'5J('=I861O;6^VY@!!;G5L=6H@<F%P;W)T
M(&\@<')O8FQE;6EE`$%N=6QO=V%N:64@=&5J('=I861O;6^V8VD@=7-U;FEE
M(&IE:B!Z87=A<G1OMN8@8F5Z<&]W<F]T;FEE+@!.:64@;6^_;F$@<VMA<V]W
M8>8@<&QI:W4@(B5S(@!.:64@=61ALV\@<VGJ('IN86QEO.8@:V%T86QO9W4@
M='EM8WIA<V]W96=O+@!.:64@;6^_;F$@<VMA<V]W8>8@:V%T86QO9W4@(B5S
M(@!7>7-P>2!::65L;VYE9V\@4')Z>6RQ9&MA`$MA=&5G;W)I92!I(&]Z;F%C
M>F5N:6$`0V,`5&5L+B!K;VTN`%>S8;9C:7=OMF-I(&MO;?-R:VD`5[-AMF-I
M=V^V8VD@:V]M\W)K:0!496PN(&MO;2X`0V5L='EC:VD@*$E33RTX.#4Y+3$T
M*0!297!U8FQI:V$@IG)O9&MO=V5J($%F<GEK:0"F<F]D:V]W;V5U<F]P96IS
M:VD@*$E33RTX.#4Y+3(I`%-Z8WIE9_.S>2!C97)T>69I:V%T=0!7LV&V8VEC
M:65L(&-E<G1Y9FEK871U`$-Z860`3F%C>F5L;GD`6FUN:67Q`%IM:67Q(%=S
M>GES=&MO`%IM:67Q(&9O;&1E<@!:;6EA;GD@;W!C:FD@=WFV=VEE=&QA;FEA
M('1A:VEC:"!J86LZ(&EL;[;F('=I861O;6^V8VD@=VED;V-Z;GEC:"!N82!P
M;W-Z8WIE9_-L;GEC:"!S=')O;F%C:"P@<V]R=&]W86YI92!W:6%D;6^V8VDN
M`%IM:67Q('-E<G=E<B!P;V-Z='D@:2!U<W1A=VEE;FEA(&9O;&1E<G4N`%IM
M:67Q(&EM:>HL(&YA>G=I<VMO(&D@861R97,L(&MT\W)Y(&EN;FD@=VED>K$@
M=R!4=V]I8V@@;&ES=&%C:"!E;6%I;"X`6FUI9?$@;F%Z=^HL(&%D<F5S(&D@
M<&]D<&ES+"!K=/-R>2!L=61Z:64@=VED>K$@<&]D8WIA<R!C>GET86YI82!I
M(&]D<&]W:6%D86YI82!N82!4=_-J(&5M86EL+@!:;F%K:2!D;R!W>;9W:65T
M;&5N:6$Z`%-P<F%W9+P@;&EN:RXN+@!3<')A=V1Z86H@9F]L9&5R*'DI(&-Z
M>2!J97-T(&YO=V$@<&]C>G1A`%I?87IN86-Z(%=S>GES=&MO+TYI8P!3<')A
M=V1Z86H@=W-Z>7-T:VEE('-E<G=E<GD@<&]C>G1Y`%-P<F%W9'IAYB!P:7-O
M=VYIZB!P<GIE9"!W>7.S86YI96T@=VEA9&]M;[9C:3\`6F%Z;F%C>B!P;WIY
M8VKJ(&1L82!K=/-R96H@8VAC97-Z('=Y:V]N8>8@;W!E<F%C:NHN`$-H:6QE
M`$-H:6YY`%=Y8FEE<GH@86MC:NHZ`%=Y8FEE<GH@<V5R=V5R('!O8WIT;W=Y
M.@!0;V1A:B!H87.S;P!0;V1A:B!N87IWZB!UOWET:V]W;FEK80!7>6)I97)Z
M(&]P97)A8VKJ.@!7>6)I97)Z('-P;W/S8B!W>;9W:65T;&%N:6$@9&%T.@!7
M>6)I97)Z(&MS:;&_:^H@861R97-O=[$L(&1O(&MT\W)E:B!BZF2Q(&1O9&%W
M86YE(&%D<F5S>2X`5WEB:65R>B!K;VQE:FYOMN8@<')Z97-Z=6MI=V%N:6$@
M:W-IL;]E:R!A9')E<V]W>6-H('!O9&-Z87,@<F]Z<WIE<GIA;FEA(&%D<F5S
M\W<N`%=Y<W!A($)OOV5G;R!.87)O9'IE;FEA`$ML:6MN:6H@)7,L(&%B>2!Z
M;6EE;FGF(&9O<FUA="!O8G)A>FMA(&YA(&]B<[-U9VEW86YY('!R>F5Z('1W
M;VJQ('!R>F5G;+%D87)KZBX`2VQI:VYI:B!T=71A:BP@86)Y('IA<&ES86,@
M;V)R87IE:R`E<RX`2VQI:VYI:B`E<RP@86)Y('#S:K;F(&1O('-T<F]N>2!Z
M87)ZL61Z86YI82`E<RX`2VQI:VYI:B`E<R!A8GD@>F]B86-Z>>8@>F%W87)T
M;[;F($A434P@=R!O<V]B;GEM(&]K;FEE+@!+;&EK;FEJ("5S(&%B>2!Z;V)A
M8WIYYB!M:6YI871U<FOJ('1E9V\@;V)R87IK82X`2VQI:VYI:B`E<R!A8GD@
M>F]B86-Z>>8@>F&SL6-Z;FEK('<@;W-O8FYY;2!O:VYI92X`2VQI:VYI:B`E
M<RP@86)Y('IO8F%C>GGF('IAL[%C>FYI:R!W(&]S;V)N>6T@;VMN:64N`$ML
M:6MN:6H@='5T86H@86)Y('5K<GGF(&]B<F%Z:VD`2VQI:VYI:B!T=71A:B!A
M8GD@<&]K87IAYB!O8G)A>FMI`$ML:6MN:6H@;F$@:F5D;GEM('H@=WEB<F%N
M>6-H(&MS:;&_96L@861R97-O=WEC:"!I(&]K<F6V;"!P;VQA('=E9+-U9R!K
M=/-R>6-H(')O>G!O8WJQYB!S>G5K86YI92X`2VQI:VYI:B!B>2!K;VYT>6YU
M;W=AY@!+;&EK;FEJ('1U=&%J+"!A8GD@>F%C:&]W8>8@:VQU8WH@<'5B;&EC
M>FYY(%!'4"!W(%1W;VIE:B!K<VFQOV-E(&%D<F5S;W=E:@!+;&EK;FEJ('1U
M=&%J+"!A8GD@>F%C:&]W8>8@8V5R='EF:6MA="!3+TU)344@)7,@=R!4=V]J
M96H@:W-IL;]C92!A9')E<V]W96H`2VQI:VYIZF-I92!N82!A9')E<R!S<&]D
M;W=U:F4@<W1W;W)Z96YI92!N;W=E:B!W:6%D;VUOMF-I(&1O(&%U=&]R80!+
M;&EK;FGJ8VEE(&YA(&%D<F5S('-P;W=O9'5J92!O='=A<F-I92!W:6%D;VUO
MMF-I(&1O(&-Z>71A;FEA`%IA;6MN:6H`6F%M:VYI:B!O:VYO`%IA;6MN:6H@
M=&\@;VMN;P!&;VQD97(@>F%M:VYIZG1Y`%=Y<W!Y($MO:V]S;W=E("A+965L
M:6YG82D`6G=I\0!:=VGQ('=S>GES=&MO`%IW:?$@=W-Z>7-T:VEE(&9O;&1E
M<GD`6G=I\2!F;VQD97(`4V-H;W=A:B!P87-E:P!+;VQU;6)I80!+;VQO<@!+
M;VQO<B!W<VMA>G5JL6-Y.B``5WEB:65R>B!K;VQO<@!7>6+S<B!K;VQO<G4`
M5'ET=;-Y(&MO;'5M;@!+;VUE;F1A`%!O=[-O:V$`2V]M96YT87)Z`$MO;6]R
M>0!&:7)M80!5:V_Q8WIO;F4`5'?S<GH`5'?S<GH@=VEA9&]M;[;F("@E<RD`
M5'?S<GH@:6YNL2!W:6%D;VUOMN8`5'=O<GIYYB!W:6%D;VUOMN8@=R!O<V]B
M;GEM(&]K:6YI93\`5'?S<GH@9&]M>;9L;FEE('=I861O;6^V8VD@>B!'54D@
M2%1-3"`H:F6V;&D@5'=O:F$@<')Z96=LL61A<FMA(&]B<[-U9W5J92D`2V]M
M<'5T97)Y`%=A<G5N:VD`4VMO;F9I9W5R=6H@)7,`2V]N9FEG=7)U:F4@<W!O
M<_-B('=YMG=I971L86YI82!W:6%D;VUOMF-I+@!+;VYF:6=U<G5J92!O<&-J
M92!P;V1G;+%D=2!L:7-T=2X`4&]T=VEE<F2\(&AA<[-O`$MO;F=O`$1E;6]K
M<F%T>6-Z;F$@4F5P=6)L:6MA($MO;F=O`%!OL[%C>F5N:64@;FEE('!O=VEO
M9+-O('-IZBX`4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@<VGJ.B``3V1M\W=I
M;VYO('!OL[%C>F5N:6$@9&\@<'5B;&EC>FYE9V\@<V5R=V5R82X`3V1M\W=I
M;VYO('!OL[%C>F5N:6$@9&\@<'5B;&EC>FYE9V\@<V5R=V5R82X@4&]W\V0Z
M("5S("@E<RD`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M
M($944"X`3FEE(&YA=VFQ>F%N;R!P;[.Q8WIE;FEA('H@<V5R=V5R96T`2V]N
M=&%K='D@>F]S=&&S>2!P;VUYMFQN:64@9&]D86YE(&1O(%1W;VIE:B!K<VFQ
MOVMI(&%D<F5S;W=E:BX`6F%W87)T;[;F("(E<R(`2V]N>6YU=6H`6F%R>K%D
M>F%N:64@;W!C:F%M:2!01U`@+2`E<RX`6F%R>K%D>F%N:64@;W!C:F%M:2!3
M+TU)344@+2`E<RX`6F%R>K%D>F%N:64@<W!R87=D>F%N:65M(&YO=WEC:"!W
M:6%D;VUOMF-I(&]R87H@:6YF;W)M;W=A;FEE;2!O(&EC:"!N861E:K9C:74N
M`%IA;6EE;FEAYB!T96MS=&]W92!E;6]T:6MO;GD@;F$@9W)A9FEC>FYE/P!7
M>7-P>2!#;V]K80!+;W!I80!3:V]P:75J('=Y8O-R`$MO<&EU:B!D;R!F;VQD
M97)U`$MO<F5K=&$`4VMO<GEG;W=A;GD@=&5K<W0`3FEE('5D8;-O('-IZB!Z
M87-Z>69R;W=AYB`H4$=0*2!W:6%D;VUOMF-I+@!.:64@=61ALV\@<VGJ('!O
M9'!I<V'F("A01U`I('=I861O;6^V8VDN`$YI92!U9&&S;R!S:>H@>F%S>GEF
M<F]W8>8@*%,O34E-12D@=VEA9&]M;[9C:2X`3FEE('5D8;-O('-IZB!P;V1P
M:7-AYB`H4R]-24U%*2!W:6%D;VUOMF-I+@!"L[%D('!O9&-Z87,@L[%C>F5N
M:6$@<VGJ('H@<V5R=V5R96T@3$1!4"X`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA
M('-IZB!Z('-E<G=E<F5M("(E<R(@<&]P<GIE>B!&5%`Z("5S`$YI92!M;[]L
M:7=E('5T=V]R>F5N:64@=W-P87)C:6$@5D93.B`E<P!.:64@=61ALV\@<VGJ
M(&]D<WIY9G)O=V'F(&1A;GEC:"!01U`N`$YI92!U9&&S;R!S:>H@;V1S>GEF
M<F]W8>8@9&%N>6-H(%,O34E-12X`3FEE(&UOOVQI=V4@=7-U;FGJ8VEE('=I
M861O;6^V8VD@>B`E<RY397)W97(@>G=R\V-ILR!O9'!O=VEE9+PZ("5S`$YI
M92!U9&&S;R!S:>H@=7-T86QIYB!A9')E<W4@92UM86EL(&]D8FEO<F-Y+@!.
M:64@;6^_;&EW92!U<G5C:&]M:65N:64@;W!C:FD@:V]N<V5R=V%C:FDN`$YI
M92!M;[]L:7=E(')O>G!A:V]W86YI92!P;&EK=2!Z('IAL[%C>FYI:V$@35,M
M5$Y%1BX`3FEE(&UOOVQI=V4@<F]Z<&%K;W=AYB!P;&EK\W<@>B!A<F-H:7=U
M;2!::7`N`$YI92!U9&&S;R!S:>H@=7IY<VMAYB!Z('-E<G=E<F$@:VQU8WIA
M('!B=6QI8WIN96=O+@!.:64@=61ALV\@<VGJ(&]T=V]R>GGF("(E<R(@9&\@
M>F%P:7-U+@!.:64@;6^_;F$@;W1W;W)Z>>8@)7,N`$YI92!M;[]N82!O='=O
M<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<P!.:64@;6^_;F$@;W1W
M;W)Z>>8@:V%T86QO9W4@(B5S(@!.:64@=61ALV\@<VGJ('-K87-O=V'F('!L
M:6MU("(E<R(N`$YI92!U9&&S;R!S:>H@>FYA;&6\YB!P87-K82!-;WII;&QI
M+B!5<&5W;FEJ('-IZBP@OV4@:F5S="!O;B!O='=A<G1Y+@!+<F%J`%1W\W)Z
M`%1W\W)Z(&9O;&1E<@!4=_-R>B!K;'5C>F4`5'?S<GH@=VER='5A;&YY(&9O
M;&1E<@!3='?S<GH@;F]W92!K;VYT;P!3='?S<GH@;&EN:P!3='?S<GH@;F]W
M>2!F;VQD97(@;F$@<W!A;0!4=V]R>F5N:64@;F]W96=O(&9O;&1E<G4@<F]B
M;V-Z96=O`%-T=_-R>B!N;W>Q`%1W;W)Z96YI92!N;W=E9V\@9F]L9&5R=2!P
M;V-Z='D@=WESLV%N96H`5'=O<GIE;FEE(&YO=V5G;R!F;VQD97)U(&MO<WIA
M`%1W;W)Z96YI92!R96=ULR!F:6QT<F]W86YI82!I(&]R9V%N:7IO=V%N:6$@
M;F%D8VAO9'JQ8V5J('!O8WIT>2P@<V]R=&]W86YI92!D;R!F;VQD97+S=RP@
M=7-U=V%N:64@<W!A;74N`$YU;65R(&MA<G1Y(&MR961Y=&]W96H`0VAO<G=A
M8VIA`$MU8F$`3V)E8VYY(&-Z87,`3V)E8VYY(&1O<W3J<"!D;R`E<P!$969I
M;FEO=V%N:64@:V]N="!O9&)I97)A:K%C>6-H('!O8WITZB!Z(&EN;GEC:"!K
M;VYT`$1O<W1O<W5J('-P;W/S8B!W>7-YLV%N:6$@<&]C>G1Y`%=Y8FEE<GH@
M>F%D86YI82P@:W3S<F4@;6%JL2!B>>8@=WEK;VYA;F4@<&]D8WIA<R!L;V=O
M=V%N:6$@9&\@)7,N`%=Y=&YI:@!#>7!R`%)E<'5B;&EK82!#>F5C:`!$1`!#
M;V1Z:65N;FEE`$1A=&$@*%]E*0!$871A`%]5<W7Q(&MO;'5M;NH`1W)U9'II
M9?$`3V1R>G5C;VYE`$]D<GIU8V]N93H@`$1O;7FV;&YE`$1O;7FV;&YY(&MO
M;&]R`$1O;7FV;&YA('1OOW-A;6^VY@!$;VUYMFQN92!U<')A=VYI96YI80!$
M;VUYMFQN92!U<')A=VYI96YI80!$;VUYMFQN92!K<GET97)I82!S;W)T;W=A
M;FEA.@!$;VUYMFQN>2!S<&]S\V(@<V]R=&]W86YI83H`3V1D96QE9V]W86YE
M`%5S=?$`2VQU8WH@<'5B;&EC>FYY("5S('5S=6YIZG1Y`%5S=?$@;V)E8VYE
M(&ML=6-Z90!5<W7Q(&9O;&1E<BAY*0!5<W7Q($=R=7#J`%5S=?$@=7!R87=N
M:65N:6$`57-U\2!W>6)R86YE(&9O;&1E<GD`57-U\2!W:7)T=6%L;GD@9F]L
M9&5R`%5S=?$@:2!W>6-Z>;;F('=I861O;6^V8VD`57-U\2!K;VWS<FOJ`%5S
M=?$@:V]L=6UNZ@!5<W5NL>8@=VEA9&]M;[9C:2!P;V)R86YE('IE('ID86QN
M96=O('-E<G=E<F$_`%5S=?$@>B!M;VIE9V\@:V%L96YD87)Z80!#>GD@=7-U
M=V'F('-T87)E('IAL[%C>FYI:VD@;F$@<&]C>K%T:W4@:V&_9&5G;R!M:65S
M:;%C83\`0WIY('5S=7=AYB!S=&%R>2!F;VQD97(@<&]C>G1Y('=Y<[-A;F5J
M(&YA('!O8WJQ=&MU(&MAOV1E9V\@;6EE<VFQ8V$_`%-K87-U:B!U<')A=VYI
M96YI82!D;&$@(B5S(@!3:V%S;W=AYB!U<')A=VYI96YI82!D;&$@(B5S(B!I
M('=S>GES=&MI92!P;V0M=7!R87=N:65N:6$_`%5S=?$@=VEE<G-Z`%-K87-U
M:B!W>6)R86ZQ('1OOW-A;6^VY@!#>GD@=7-U=V'F('=I861O;6^V8VD@<W!A
M;2!P;R!Z9[-O<WIE;FEU(&IA:V\@<W!A;3\`57-U\2!A:W1U86QNL2!K;VQU
M;6[J`%5S=?$@86MT=6%L;GD@=VEE<G-Z`%-K87-O=V'F('1O('5P<F%W;FEE
M;FEE(&D@=W-Z>7-T:VEE('!O9"UU<')A=VYI96YI83\`57-U;FGJ=&4`57-U
M;FGJ=&4@=VEA9&]M;[9C:0!5<W5N:>IT;R!Z8;.Q8WIN:6L@(B5S(BX`57-U
M=V%N:64@:2!P<GIE;F]S>F5N:64@=VEA9&]M;[9C:0!$86YI80!/9')Z=>8@
M>F%P>71A;FEE`$]D<GIUYB!Z87!Y=&%N:64@;R!I;F9O<FUA8VKJ('=O;&YY
M+WIA:NIT>0!-86QE:K%C;P!/<&ES>B!P<F]B;&5M`$]P:7,`4WIC>F5G\[-Y
M`%-Z8WIE9_.S>2!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D;6EN:7-T<F%T
M;W)A+@!:87.S;VYIYB!P;V1P:7-Y/P!+871A;&]G`%=YMG=I971L86YI90!7
M>;9W:65T;"!C>F%S('<@9F]R;6%C:64@,C0M9V]D>FEN;GEM/P!5<W1A=VEE
M;FEA('=Y9VRQ9'4`5WFV=VEE=&QAYB!P;W1W:65R9'IE;FEE('=Y<[-A;F5J
M('=I861O;6^V8VD_`%=YMG=I971L86H@=R!T<F6V8VD@=VEA9&]M;[9C:0!/
M='=I97)AYB!N;W=E(&]K;F\@>B!I;F9O<FUA8VJQ(&\@;F]W96H@<&]C>F-I
M93\`4&]K87IY=V'F('!R>GEC:7-K("=/<'+SOVYI:B!K;W-Z)R!N82!P87-K
M=2!M96YU/P!2;WIM:65S>F-Z96YI90!$OVEB=71I`$YI92!Z9V%D>F$@<VGJ
M`$YI92!S<')A=V1Z86H@9F]L9&5R\W<@8WIY(&IE<W0@;F]W82!P;V-Z=&$`
M3FEE(&MA<W5J`$)R86L@8F5Z<&^V<F5D;FEE9V\@9&]S=.IP=2!D;R!M86EN
M=&5N86YC92YP:'``3FEE(&=E;F5R=6H@;&EN:V$@=R!P;VQU($]D.B!K;VQU
M;6YA`$-Z>2!C:&-E<WH@;W1W;W)Z>>8@=&5N(&9O;&1E<C\`1&]M:6YI:V$@
M*%=S</-L;F]T82!$;VUI;FEK:2D`1&]M:6YI:V%N82`H4F5P=6)L:6MA($1O
M;6EN:6MA\7-K82D`6G)O8FEO;F\`IF-IL6=N:6H`IF-IL6=N:6H@)7,`4&]B
M:65R>B`E<R!W(&9O<FUA8VEE("YZ:7``4&]B:65R>B!W<WIY<W1K:64@>F&S
ML6-Z;FEK:2`H=R!P;&EK=2`N>FEP*0!0;V)I97)Z(&9O;&1E<BAY*0!0;V)I
M97)Z(&9O;&1E<BAY*2!;9F]R;6%T("YZ:7!=`%!O8FEE<GH@=R!F;W)M86-I
M92`N>FEP`%)O8F]C>GD`1F]L9&5R(')O8F]C>GD`1F]L9&5R(')O8F]C>GDZ
M`$YA<FMO='EK:0!%+6UA:6P`061R97,@92UM86EL`$M/3DE%0P!"L[%D.B!4
M=V]J82!W:6%D;VUOMN8@;FEE(&UOOV4@8GGF(&1O<W1A<F-Z;VYA+@!%:W=A
M9&]R`$5D>71U:@!%9'ET=6H@8WIA<FZQ(&QI<W3J`$5D>71U:B!F:6QT<GD`
M57-U\2!'<G5PZ@!:;6EE\2!U<')A=VYI96YI90!:;6EE\2!U<')A=VYI96YI
M80!:;6EE\2!U<')A=VYI96YI82!D;&$@)7,`161Y='5J(&9O;&1E<B!V:7)T
M=6%L;GD`161Y='5J(&1E9FEN:6-J92!F;VQD97)U('=I<G1U86QN96=O(&1L
M82`E<P!%9'ET=6H@8FEAL[$@;&ES=.H`6FUI9?$@=7-T87=I96YI82!D;&$Z
M`%IM:67Q('5P<F%W;FEE;FEA(&1L82`E<P!%9'ET=6H@=[-A<VZQ(&-Z87)N
ML2!L:7-TZ@!%9'ET=6H@=[-A<VYE(&9I;'1R>0!%9'EC:F$@<')E9F5R96YC
M:FD@9&]S=.IP=2!D;R!I;FYY8V@@:V]N="!P;V-Z=&]W>6-H+@!%9'EC:F$@
M=[-A<VYE:B!B:6&S96H@;&ES='D`16=I<'0`4V%L=V%D;W(`16UA:6P`061R
M97,@96UA:6P`061R97-Y(&5M86EL(&UU<WJQ(&1O('-I96)I92!P87-O=V'F
M+@!%;6]T:6MO;GD`3W!R\[QN:6]N;R!W<WIY<W1K:64@=VEA9&]M;[9C:2!Z
M("5S+@!/<'+SOVYI:B!F;VQD97(H>2D`3W!R\[]N:6H@=WEB<F%N92!F;VQD
M97)Y`$]P<O._;FEJ(&9O;&1E<B!K;W-Z80!/<'+SOVYI:B!K;W-Z("A?="D`
M4'5S=&$@=VEA9&]M;[;F+@!"<F%K(')E>G5L=&%T\W<N`%>SL6-Z>>8@9G5N
M:V-J92!01U`_`%>SL6-Z>>8@9G5N:V-J92!3+TU)344_`%>SL6-Z>>8@<&]D
M9VRQ9"!W:6%D;VUOMF-I/P!7L[%C>GGF(&UE;G4@:V]N=&5K<W1O=V4@<&]D
M('!R87=Y;2!P<GIY8VES:VEE;2!M>7-Z>3\`3W!C:F4@:V]D;W=A;FEA("A?
M>2D`2V]N:65C`$MO;FEE8R!P<GIE:V%Z86YE:B!W:6%D;VUOMF-I`$MO;FEE
M8R!W:6%D;VUOMF-I`$MO;FEE8R!W:6%D;VUOMF-I(&]D("5S`%=P<F]W862\
M(&AA<[-O`%=P<F]W862\(&YA>G?J(&1L82!T=V]J96=O(&YO=V5G;R!F;VQD
M97)U(&YA('-P86T`5W!R;W=A9+P@;F%Z=^H@9&QA('1W;VIE9V\@;F]W96=O
M(&9O;&1E<G4@<F]B;V-Z96=O`%=P<F]W862\(&YA>G?J(&1L82!T=V]J96=O
M(&YO=V5G;R!K871A;&]G=2!P;V-Z='D@=WESLV%N96H`5W!R;W=A9+P@;F%Z
M=^H@9&QA('1W;VIE9V\@;F]W96=O(&9O;&1E<G4@:V]S>F$`0V&S82!W:6%D
M;VUOMN8`5W!I<R`B)7,B('IO<W1ALR!P;W!R87=N:64@9&]D86YY(&1O(%1W
M;VIE:B!K<VFQOVMI(&%D<F5S;W=E:@!'=VEN96$@4O-W;FEK;W=A`$5R>71R
M96$`0K.Q9`!"L[%D('=Y<[-A;FEA(&]D<&]W:65D>FDZ("5S+@!"L[%D('!R
M>GD@>F%P:7-I92`B)7,B+@!%<W1O;FEA`$5T:6]P:6$`175R;W!A`%=Y9&%R
M>F5N:64@>F]S=&&S;R!U<W5N:>IT92X`0V\@,34@;6EN=70`0V\@:V&_9&4@
M,B!M:6YU='D`0V\@,S`@<V5K=6YD`$-O(#4@;6EN=70`0V\@:V&_9&4@>F%L
M;V=O=V%N:64`0V\@</.S(&=O9'II;GD`0V\@;6EN=73J`%!R>GEKLV%D;W=E
M('=A<G1OMF-I.@!7>6MO;F%J`%)O>G=I\0!2;WIW:?$@=W-Z>7-T:V\`4F]Z
M=VGQ('=S>GES=&MI92!F;VQD97)Y`%)O>G=I\2!F;VQD97(`4F]Z=VGQ(&YA
M>G=Y`%)O>G=I\2!P87-E:P!!=71O;6%T>6-Z;FEE(')O>G=I:F'F(&YA>G=Y
M('<@;VMN:64@='=O<GIE;FEA('=I861O;6^V8VD_`%)O>G=I:F'F(&1O;7FV
M;&YI92!D<GIE=V\@=R!W:61O:W4@9F]L9&5R\W<_`%)O>G=I:F%N:64`4&]B
M:65R>B!P;V-Z=.H@*%]F*0!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@3$1!4"X`0K.Q9"!P;V1C>F%S(&MO<&EO=V%N:6$@>B`B)7,B
M+@!"L[%D('!O9&-Z87,@:V]P:6]W86YI82!D;R`B)7,B+@!"L[%D('!O9&-Z
M87,@<')Z96YO<WIE;FEA(&1O("(E<R(N`$9A;&ML86YD>2`H36%L=VEN>2D`
M5WES<'D@3W=C>F4`0K.Q9"!K<GET>6-Z;GDZ(`!&86MS`$QU='D`4&]B:65R
M>B!P;V-Z=.H`4&]B<F'F('!O8WITZB!W(&]S;V)N>6T@;VMN:64_`%!O8FEE
M<F'F('!O8WITZB!P;V1C>F%S(&QO9V]W86YI83\`4&]B<F%N;R`E9"!W:6%D
M;VUOMF-I('H@)7,`4&]B<F%N;R`Q('=I861O;6^VYB!Z("5S`%!O8G)A;F\Z
M(`!0;V)R86YO.B!B<F%K(&YO=WEC:"!W:6%D;VUOMF-I+@!&:5]L=')Y`$9I
M9+]I`%!L:6L`365N962_97(@<&QI:_-W`$YA>G=A('!L:6MU`%=Y8O-R('!L
M:6MU`%=G<GEW86YI92!P;&EK=0!79W)Y=V%N:64@<&QI:_-W(&YI92!J97-T
M(&]B<[-U9VEW86YE+@!/<&-J92!F:6QT<F]W86YI80!5<W1A=VEE;FEA(&9I
M;'1R=0!&:6QT<G5J('IA=V%R=&^VYB!W:6%D;VUOMF-I('IE('=Z9VSJ9'4@
M;F$@=W5L9V%R;F^VYC\`3V)SLW5G82!F:6QT<O-W(&IE<W0@=WFSL6-Z;VYA
M(&YA('1Y;2!S>7-T96UI92X`1FEL=')Y`$9I;'1R>2!.244@86MT>7=N90!&
M:6QT<GDZ('-T<F]N82!Z87)ZL61Z86YI82`E<P!:;F%J9+P`1FEN;&%N9&EA
M`%!I97)W<WIA('-T<F]N82!S:W)Z>6YK:2!P;V-Z=&]W96H`4&EE<G=S>F$@
M<W1R;VYA`%!R>F5K8;\@*%]R*0!#>GEN;F^V8VD@;F$@:V%T86QO9V%C:"`M
M('!O='=I97)D>F5N:64`3F%W:6=A=&]R(&9O;&1E<O-W`%!R969I>"!F;VQD
M97)U`%!O9'-U;6]W86YI92!F;VQD97)U`%5D;W-TZG!N:6%N:64@9F]L9&5R
M=2!N:64@:F5S="!A:W1Y=VYE+@!5OWEC:64@9F]L9&5R=2!N:64@:F5S="!A
M:W1Y;G=E+@!*961Z96YI90!:87!O;6YI8;-EMB!H87.S83\`4')Z96MAOP!0
M<GIE:V&_.@!0<GIE:V%Z86YA('=I861O;6^VY@!0<GIE:V%Z86YA('=I861O
M;6^VYB!O9"`E<P!&<F%N8VIA`$EN9F]R;6%C:F$@=V]L;GDO>F%JZG1Y`$]D
M<&]W:65DO"!W;VQN>2]Z86KJ='D`6F%P>71A;FEE('=O;&YY+WIA:NIT>0!/
M9'!O=VEE9+P@;F$@>F%P>71A;FEE('=O;&YY+WIA:NIT>0!'=6IA;F$@1G)A
M;F-U<VMA`%!O;&EN97IJ82!&<F%N8W5S:V$`1G)A;F-U<VMI92!497)Y=&]R
M:6$@4&^S=61N:6]W92!I($%N=&%R:W1Y8WIN90!/9"`H7VTI`$]D`$%D<F5S
M(&]D`$9W9#H`1G=D.B``1G=D.B`E=2!P<GIE:V%Z86YE('=I861O;6^V8VD`
M1V%B;VX`1V%M8FEA`$]P8VIE(&>S\W=N90!.:65M8WD`4&]B:65R86H@='EL
M:V\@;F]W92!W:6%D;VUOMF-I("AT>6QK;R!)34%0*0!':&%N80!':6)R86QT
M87(`262\`$EDO"!D;R!W:6%D;VUOMF-I`$EDO"!D;R!W<&ES=2`B)7,B('<@
M:W-IL;]C92!A9')E<V]W96H`5WES>G5K:7=A<FMA($=O;V=L90!0<GIY>FYA
M:B!D;W-TZG``1W)E8VIA`$=R96YL86YD:6$`1W)E;F%D80!'<G5P>2!D>7-K
M=7-Y:FYE`$=W861E;'5P80!'=6%M`$=W871E;6%L80!'=65R;G-E>0!'=VEN
M96$`1W=I;F5A($)I<W-A=0!'=6IA;F$`5%5404H`2%1-3`!7:6%D;VUOMN8@
M=R!W97)S:FD@2%1-3`!(86ET:0!.86>S\W=K:0!7>7-P>2!(96%R9"!I($UC
M1&]N86QD80!0;VUO8P!4=71A:B!Z;F%J9'5J92!S:>H@=VEA9&]M;[;F+"!K
M=/-RL2!T=V]R>GFS9;8Z`%5K<GET90!5:W)Y=&4@=R!P;V1G;+%D>FEE('>Q
M=&MU`%5K<GEJ('5S=6YIZG1E`%5K<GEJ(&YI97-U8G-K<GEB;W=A;F4`56MR
M>6H@;V)R87IK:0!7>7-O:VD`5WES;VMI('!R:6]R>71E=`!.86IW>;]S>GD`
M7U-T87)T`%=A='EK86X@*%-T;VQI8V$@07!O<W1O;'-K82D`4&]C>K%T96L`
M061R97,@9&]M;W=Y`%1E;"X@9&]M+@!(;VYD=7)A<P!(;VYG2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@561ALV\@<VGJ('5S=6ZQYB`E<R`B)7,B`$IA:R!W
M>;9W:65T;&'F('IAL[%C>FYI:VD_`$IA:R!P<GIY<&ES>7=AYB!C>71O=V%N
M92!L:6YI92!W(&]D<&]W:65D>FD`5^IG<GD`24U!4`!)34%0("AA=71O;6%T
M>6-Z;F$@9&5T96MC:F$@<')O=&]K;[-U*0!0;[.Q8WIE;FEE(%-33"!D;&$@
M24U!4`!0;[.Q8WIE;FEE(%-33"!D;&$@24U!4"`H=[-A<VYY(&-E<G1Y9FEK
M870I`%!OL[%C>F5N:64@4U-,(&1L82!)34%0("AWLV%S;GD@<&]D<&ES*0!)
M34%0+"!B97H@5$Q3`%-E<G=E<GD@<&]C>G1O=V4@24U!4"]03U`S`$]D96)R
M86YE`$ES;&%N9&EA`%1Y;&MO(&EK;VYY`$EK;VYY('H@=&5K<W1E;0!.87IW
M82!T;[]S86UOMF-I.@!*9;9L:2!BZF1Z:65S>B!K;VYT>6YU;W=ALRP@=&\@
M=W-Z>7-T:VEE('=I861O;6^V8VD@=R!F;VQD97)Z92AA8V@I('IO<W1A;K$@
M=71R86-O;F4A`$EG;F]R=6H`26=N;W)U:B!W<WIY<W1K;P!'<F%F:6MA`$EM
M<&]R=`!);7!O<G1O=V%N:64@:VQU8WIA`$EM<&]R=&]W86YI92!P87)Y(&ML
M=6-Z80!);7!O<G1U:B!W:6%D;VUOMF-I`$EM<&]R=&]W86YI92!K;'5C>F$@
M<'5B;&EC>FYE9V\@4$=0`$EM<&]R=&]W86YI92!O<V]B:7-T96=O(&-E<G1Y
M9FEK871U`$EM<&]R=&]W86YI92!P<GEW871N96=O(&ML=6-Z82!01U``26UP
M;W)T;W=A;FEE('!U8FQI8WIN96=O('!E<G-O;F%L;F5G;R!K;'5C>F$@4$=0
M`$EM<&]R=&]W86YI92!C97)T>69I:V%T=2!P97-R;VYA;&YE9V\@4R]-24U%
M`$EM<&]R=&]W86YI92!K;'5C>F$@<'5B;&EC>FYE9V\`26UP;W)T;W=A;FEE
M(&ML=6-Z82!P=6)L:6-Z;F5G;R!01U``26UP;W)T;W=A;FEE(&ML=6-Z82!P
M=6)L:6-Z;F5G;R!3+TU)344`26UP;W)T;W=A;FEE(&ML=6-Z82!3+TU)344`
M26UP;W)T;W=A;FEE('!L:6MU(&UB;W@`26UP;W)T;W=A;FEE('!L:6MU(&UB
M;W@@)7,@9&\@9F]L9&5R=2`E<RX`5V&_;F4`5V&_;F4@=VEA9&]M;[9C:0!)
M;7!O<G1O=V%N;R`E9"!W:6%D;VUOMF-I('H@)7,N`$EM<&]R=&]W86YE('!O
M;&4Z("5S`$EM<&]R=&]W86YE('!O;&$Z`$%K='EW;F4`3V1E8G)A;F4`6F&S
ML6-Z8>8@<&]D<W5M;W=A;FEE('<@;F%GL_-W:W4@;V1P;W=I961Z:3\`6F&S
ML6-Z8>8@;W)Y9VEN86QNL2!W:6%D;VUOMN8@=R!O9'!O=VEE9'II/P!);F1I
M90!);F1O;F5Z:F$`26YF;P!);F9O<FUA8VIE(&\@:VQU8WIU('!U8FQI8WIN
M>6T@)7,`26YF;W)M86-J92!O(&]S;V)I<W1Y;2!K;'5C>G4@<')Y=V%T;GEM
M`$EN9F]R;6%C:F4@;R!O<V]B:7-T>6T@:VQU8WIU('!U8FQI8WIN>6T`3&EN
M:6$`5W!R;W=A9+P@:VQU8WH@='5T86H`5VML96H@;V)R87IE:P!7<')O=V%D
MO"!O<V]B:7-T>2!K;'5C>B!P<GEW871N>2!01U`@='5T86H`5W!R;W=A9+P@
M;W-O8FES='D@:VQU8WH@<'5B;&EC>FYY(%!'4"!T=71A:@!7<')O=V%DO"!K
M;'5C>B!P=6)L:6-Z;GD@4$=0('1U=&%J`%=Y8G)A;F\@>K.Q(&]P8VKJ(&1L
M82!T96=O(&MO;7!O;F5N='4N`$YI97!O<')A=VYY(&%D<F5S`$YI97!O<')A
M=VYA('ID86QN82!S:W)Z>6YK82!P;V-Z=&]W80!.:65P;W!R87=N>2!Z;F%K
M('<@861R97-I92!E+6UA:6PZ("5S+@!7>7.S86YE(&YI97!R87=I9+-O=V4@
M9&%N92X`3FEE<')A=VEDLV]W>2!A9')E<R!D;V-E;&]W>2X`3FEE<')A=VED
MLV]W>2!F;W)M870@<&QI:W4`3FEE<&]P<F%W;GD@:VQU8WH`3FEE<')A=VED
MLV]W>2!K;'5C>B!L:6-E;F-J:2X`3FEE<&]P<F%W;GD@;W-O8FES='D@:VQU
M8WH@<')Y=V%T;GD@4$=0+@!.:65P;W!R87=N>2!O<V]B:7-T>2!K;'5C>B!P
M=6)L:6-Z;GD@4$=0+@!/9'=R\^8`27)A;@!)<F%K`$ER;&%N9&EA`$EZ<F%E
M;`!7>61A=V-A`%>S;V-H>0!*86UA:FMA`%-T>6-Z9?$`2F%P;VYI80!*;W)D
M86X`3&EP:65C`$-Z97)W:65C`$M"`$MA>F%C:'-T86X`2V5N:6$`5'=O<GIE
M;FEE(&ML=6-Z80!/9&-I<VL@:VQU8WIA`$2S=6=OMN8@:VQU8WIA`%1Y<"!K
M;'5C>F$`2VQU8WH@:G6_(&ES=&YI96IE(&YA('!U8FQI8WIN>6T@<V5R=V5R
M>F4@:VQU8WIY+@!'96YE<F]W86YI92!K;'5C>F$@;6^_92!Z86JQYB!D=;]O
M(&-Z87-U+B!+;VYT=6YU;W=AYC\`2VQU8WH@=WESLV%N>2!P;VUYMFQN:64@
M;F$@<'5B;&EC>FYY('-E<G=E<B!K;'5C>GDN`$1Z:65C:0!+:7)I8F%T:0!+
M;W)E8?%S:V$@4F5P=6)L:6MA($QU9&]W;RU$96UO:W)A='EC>FYA`%)E<'5B
M;&EK82!+;W)E:0!+=7=E:G0`2VER9VES=&%N`%=Y9VRQ9"`H7WDI`$KJ>GEK
M`$QA;W,`3W-T871N:6$@<W1R;VYA('-K<GIY;FMI`$]S=&%T;FEA('-T<F]N
M80!/<W1A=&YI92!L;V=O=V%N:64Z("5S`$]S=&%T;FEE(&QO9V]W86YI93H@
M)7,@>B`E<P!/<W1A=&YI92!L;V=O=V%N:64Z(&YI9V1Y`*-O='=A`$QE<V]T
M:&\`3&E?;FMU:B!Z8;.Q8WIN:6MI`$QI8F5R:6$`3&EB:6$`3&EE8VAT96YS
M=&5I;@!,:6YK;W=A;FEE('IAL[%C>FYI:_-W(&IE<W0@>F%B<F]N:6]N92X`
M3V1N;[9N:6MI('-T86ZQ('-IZB!N:65A:W1U86QN92`E<P!7>;9W:65T;"!T
M96UA='D@<&]M;V-Y`%!O:V%Z>7=AYB!W<WIY<W1K:64@:V]N=&%K='D@<&]D
M8WIA<R"S861O=V%N:6$@;VMN82!K;VYT86MT\W<_*&IEMFQI('=YL[%C>F]N
M92P@=VED;V-Z;F4@8NIDL2!J961Y;FEE('!O8WIU:VEW86YE(&MO;F%K='DI
M`%=YMG=I971L86YI92!W(&YA9[/S=VMU`$QI<W1O=V%N:64@=;]Y=&MO=VYI
M:_-W(&IE<W0@=WFSL6-Z;VYE+@!,:71W80"C861O=V%N:64N+BX`3&]K86QN
M82!S:W)Z>6YK83H`0WIA<R!L;VMA;&YY.B``57-T87=I96YI82!L;VMA;&YE
M(&D@8WIA<P!,;VMA;&EZ86-J80!:86QO9W5J('-IZ@!:86QO9W5J('-IZB!D
M;R`E<P!7>6QO9W5J`$YA>G=A('6_>71K;W=N:6MA`%IA9&%N:6$@<')Z>2!L
M;V=O=V%N:74`3&]G;W=A;FEE(&YI92!P;W=I;V2S;R!S:>HL('!O;FEE=V&_
M('!O9&&S9;8@;FEE<')A=VEDLV]W92!H87.S;R!L=6(@;F%Z=^H@=;]Y=&MO
M=VYI:V$N`$QO9V]W86YI92!N:64@<&]W:6]DLV\@<VGJ+@!.:7-K:0!.:7-K
M:2!P<FEO<GET970`3F%J;FF_<WIY`$QU:W-E;6)U<F<`34T`34]41`!-4T<`
M36%K874`36%C961O;FEA`%!L:6L@36%C:6YT;W-C:`!-861A9V%S:V%R`%!O
M8WIT80!0;V1G;+%D('!O8WIT>0!4>7`@<&^SL6-Z96YI82!Z('-E<G=E<F5M
M('!O8WIT>3H`4VMR>GEN:V$`3W!C:F4@=WFV=VEE=&QA;FEA('-K<GIY;FMI
M(&D@9F]L9&5R=0!-86QA=VD`36%L97IJ80!-86QE9&EW>0!-86QI`$UA;'1A
M`%IA<GJQ9'IA:B!L:7-TL2!K871E9V]R:6DL(&MT\W)Y;6D@8NID>FEE<WH@
M;WIN86-Z8;,@<&]Z>6-J92P@:2!K;VQO<F%M:2!Z(&YI;6D@>G=IL7IA;GEM
M:2X`36%R>F5C`$UA<F=I;F5S`$]Z;F%C>B!W<WIY<W1K:64@=VEA9&]M;[9C
M:2!W(&9O;&1E<GIE(&IA:V\@=VED>FEA;F4`3WIN86-Z('=S>GES=&MI92!W
M:6%D;VUOMF-I('<@9F]L9&5R>F4@:F%K:2!N:65W:61Z:6%N90!:87IN86-Z
M(&IA:V\Z`$]Z;F%C>F'F('+SOVYY;6D@:V]L;W)A;6D@<&]Z:6]M>2!P<FEO
M<GET973S=S\`3WIN86-Z>>8@=VEA9&]M;[9C:2!J86MO('=I9'II86YE/R`H
M='EL:V\@24U!4"D`5WES<'D@36%R<VAA;&QA`$UA<G1Y;FEK80!7<WIY<W1K
M:64@>F%P>71A;FEA(&UU<WJQ('!A<V]W8>8`2F%K:65K;VQW:65K('!A<W5J
ML6-E('IA<'ET86YI90!087-U:K%C92!P;VQA`$UA=7)E=&%N:6$`36%U<FET
M:75S`$UA:W-Y;6%L;GD@<F]Z;6EA<B!Z8;.Q8WIN:6MA`$UA:W-Y;6%L;F$@
M;&EC>F)A('IAL[%C>FYI:_-W(&]S:;%G;FGJ=&$N`$-ALVMO=VET>2!M86MS
M>6UA;&YY(')O>FUI87(@>F&SL6-Z;FEK82!O<VFQ9VYIZG1Y+@!-86H`36%J
M;W1T80!!;G5L;W=A;FEE('-P;W1K86YI80!);F9O<FUA8VIE(&\@<W!O=&MA
M;FEU`%!R;W!O>GEC:F$@<W!O=&MA;FEA`$]D<&]W:65DO"!O9&YOMFYI92!S
M<&]T:V%N:6$`6FUI86YA('-P;W1K86YI80!:87!Y=&%N:64@;R!Z;6EA;NH@
M<W!O=&MA;FEA`$QI<W1A(&UE;G4@9F]L9&5R=0!4<GEB(&UE;G4Z`%!OL[%C
M>B!K;VWS<FMI`%=I861O;6^VY@!4=V]R>F5N:64@=VEA9&]M;[9C:0!$871A
M('=I861O;6^V8VD`3W!C:F4@=VEA9&]M;[9C:0!3>G5K86YI92!W:6%D;VUO
MMF-I`%)O>FUI87(@=VEA9&]M;[9C:0"L<O-DLV\@=VEA9&]M;[9C:0!7>;9W
M:65T;&%N:64@=VEA9&]M;[9C:0!0;VQE('=I861O;6^V8VD`3WIN86-Z96YI
M82!W:6%D;VUOMF-I`$9O;&1E<B!W:6%D;VUOMF-I`%=I861O;6^VYB!O9"`E
M<P!7:6%D;VUOMN8@;6$@>F&SL6-Z;FEK:0!7:6%D;VUOMN8@:F5S="!Z87-Z
M>69R;W=A;F$`5VEA9&]M;[;F(&IE<W0@<&]D<&ES86YA`%=I861O;6^VYB!P
M87-U:F4`5VEA9&]M;[;F('!R>F5K:65R;W=A;F$@<')A=VEDLV]W;RX`5VEA
M9&]M;[;F('=Y<[-A;F$L(&%L92!N:64@>F%P:7-A;F$@=R`E<P!7:6%D;VUO
MMN8@=WESLV%N82X`26QOMN8@=VEA9&]M;[9C:2!W>;9W:65T;&%N>6-H(&YA
M(&IE9&YE:B!S=')O;FEE+@!7:6%D;VUOMF-I(&1O`$)L;VL@(DUE=&%R(B!N
M:64@:F5S="!D;W-TZG!N>2X`0FQO:R`B365T87(B(&YI92!J97-T(&1O<W3J
M<&YY+B!3>F-Z96?SLWD@>F1A<GIE;FEA('IO<W1ALWD@>F%L;V=O=V%N92!D
M;&$@861M:6YI<W1R871O<F$N`$UE:W-Y:P!4>7`@36EM90!/<W1A=&YI82!M
M;V1Y9FEK86-J80!:;6EA;F$`6FUI9?$@;&EN:P!-;[-D87=I80!297!U8FQI
M:V$@36^S9&%W:6D`36]N86MO`$UO;F=O;&EA`$-O(&UI97-IL6,`36]N='-E
M<G)A=`!&87IY(&MS:>J_>6-A`%=IZF-E:B!N:;\@:F5D96X@861R97,@>FYA
M;&5Z:6]N>2!D;&$@<&]L82`B)7,B+@!-87)O:V\`4')Z96YI9;8`4')Z97-U
M\2!W(&3SLP!0<GIE<W7Q('<@;&5W;P!0<GIE<W7Q('<@<')A=V\`4')Z97-U
M\2!W(&?S<NH`4')Z96YI9;8@=R!D\[,`4')Z96YI9;8@9&\@9F]L9&5R=0!0
M<GIE;FEEMB!W(&?S<NH`36]Z86UB:6L`375L=&EP87)T+V%L=&5R;F%T:79E
M`$MO;G1O`$WS:B!P;W)T86P`0FER;6$`3D]400!.87IW80!.87IW82!I+VQU
M8B!A9')E<R!N:64@;6]GL2!B>>8@<'5S=&4`3F%M:6)I80!.875R=0!7>6UA
M9V$@=WEK;VYA;FEA`$YE<&%L`$AO;&%N9&EA`$%N='EL92!(;VQE;F1E<G-K
M:64`4VEEY@!.:6=D>0!.:6=D>2!N:64@>F%P:7-U:B!Z8;.Q8WIN:6OS=P!.
M;W=Y`$YO=V$@2V%L961O;FEA`$YO=V$@:V%T96=O<FEA`$YO=WD@9F]L9&5R
M`$YO=V$@<&]C>G1A`$YO=V$@6F5L86YD:6$`3F]W92!W:6%D;VUOMF-I`%=I
M861O;6^V8VD`3F%S=.IP;F4`3F%S=.IP;F$@=VEA9&]M;[;F`$YA<W3J<&YA
M('-T<F]N80!.87-TZG!N92!O<&-J90!.:6MA<F%G=6$`3FEG97(`3FEG97)I
M80!.:75E`$YI90!.:64@>FYA;&5Z:6]N;R!C97)T>69I:V%T=0!"<F%K(&MO
M9&]W86YI80!"<F%K(&ML=6-Z>2!W('IB:6]R>F4`0G)A:R!W:6%D;VUOMF-I
M`$YI92!Z86EM<&]R=&]W86YO('!U8FQI8WIN96=O(&ML=6-Z82!01U`N`$)R
M86L@;W-O8FES=&5G;R!C97)T>69I:V%T=0!"<F%K('!O9&=LL61U`$YI92!Z
M;F%L97II;VYO('!U8FQI8WIN96=O(&ML=6-Z80!.:64@>F%I;7!O<G1O=V%N
M;R!P=6)L:6-Z;F5G;R!K;'5C>F$@4R]-24U%+@!.:64@>FYA;&5Z:6]N;R!Z
M8;.Q8WIN:6OS=RX`0F5Z('IM:6%N+@!"<F%K(&MO;F9I9W5R86-J:2!D;&$@
M)7,N`$YI92!W9W)A;F\@<&QI:W4`3FEE('=Y8G)A;F\@9F]L9&5R82X`KV%D
M96X@9F]L9&5R(&YI92!Z;W-T8;,@=WEB<F%N>2!D;R!S<')A=V1Z86YI82!N
M;W=E:B!P;V-Z='DN`$YI92!Z9&5F:6YI;W=A;F\@OV%D;GEC:"!F;VQD97+S
M=P!"<F%K(&9O;&1E<G4@>B!N;W=Y;6D@=VEA9&]M;[9C:6%M:0!"<F%K(&9O
M;&1E<G4@>B!N:65W:61Z:6%N>6UI('=I861O;6^V8VEA;6D`0G)A:R!T96MS
M='4@=R!T<F6V8VD@=VEA9&]M;[9C:0!.:64@>FYA;&5Z:6]N;R!W:6%D;VUO
MMF-I('-P9;-N:6%JL6-Y8V@@:W)Y=&5R:6$@=WES>G5K:7=A;FEA+@!.:64@
M<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($A45%`N`$YI92!P
M;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@24U!4"X`3FEE('!O
M9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!+97)B97)O<RX`3FEE
M('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!,1$%0+@!.:64@
M<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($Q/1TE.+@!.:64@
M<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA(%!!4U-71"X`3FEE
M('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!334(N`$]S;V)I
M<W1Y(&ML=6-Z('!R>7=A=&YY(%!'4"!N:65Z86EM<&]R=&]W86YY+@!/<V]B
M:7-T>2!K;'5C>B!P=6)L:6-Z;GD@4$=0(&YI97IA:6UP;W)T;W=A;GDN`$]S
M;V)I<W1Y(&-E<G1Y9FEK870@4R]-24U%(&YI97IA:6UP;W)T;W=A;GDN`$YI
M92!S:V]N9FEG=7)O=V%N;R!P<F]G<F%M=2!S<')A=V1Z86JQ8V5G;R!P:7-O
M=VYIZBX`0G)A:R!BL^ID\W<@=R!P:7-O=VYI`$)R86L@<W5G97-T:6D`3FEE
M('=Y8G)A;F\@=;]Y=&MO=VYI:V$N`$)R86L@=6-Z97-T;FEC='=A`*]A9&5N
M`$YO<F9O;&L`3F]R;6%L;GD`3F]R=V5G:6$`3FEE=7-U;FGJ='D`3FEE('-Z
M:VEC`$YI97=AOVYE`$YI96]S;V)I<W1E`%JS>2!K;'5C>B!P=6)L:6-Z;GDN
M`$YI975S=6YIZG1E('=I861O;6^V8VD`3FEE('IA:6UP;&5M96YT;W=A;F\N
M`$YI97=AOVYE('=I861O;6^V8VD`3FEE=7-T87=I;VYE`$YI96]B<[-U9VEW
M86YE`%1A(&]P97)A8VIA(&UOOV4@=')W8>8@9+-UOW-ZL2!C:'=I;.H`57=A
M9VD`57=A9V$`3&ES=&]P860`3&EC>F)A(&MO;'5M;@!);&^VYB!M:65S:>IC
M>2!P<GIE>B!K=/-R92!M86JQ(&)YYB!Z86-H;W=A;F4@<W1A<F4@;&EN:VD@
M>F&SL6-Z;FEK\W<@<&]D8WIA<R!C;VUI97-IZF-Z;F5G;R!U<W5W86YI82X`
M26QOMN8@<W1A<GEC:"!F;VQD97+S=R!P;V-Z='D@=WESLV%N96HL(&MT\W)A
M(&UA(&)YYB!Z86-H;W=A;F$@<&]D8WIA<R!C;VUI97-IZF-Z;F5G;R!U<W5W
M86YI82X`3&EC>F)A('=I97)S>GD`3TL`3%5"`%!AO&1Z:65R;FEK`$)I=7)O
M`%-T87)E('=I861O;6^V8VD`4W1A<F4@9F]L9&5R>2!S96YT+6UA:6P@>F]S
M=&%NL2!S:V%S;W=A;F4N`$]M86X`5WFV=VEE=&QIYB!T>6QK;R!F;VQD97)Y
M('H@;FEE8WIY=&%N>6UI('=I861O;6^V8VEA;6D_`%1W\VH@:F5D96X@861R
M97,@92UM86EL(&IE<W0@9&]Z=V]L;VYY+@!-;[]E(&)YYB!W>6)R86YY('1Y
M;&MO(&IE9&5N(&9O;&1E<B!D;&$@=&5J(&%K8VII+@!/='?S<GH@1F]L9&5R
M("A?;BD`3W1W\W)Z($9O;&1E<@!/='?S<GH@=R!N;W=Y;2!O:VYI90!&;VQD
M97(@;W1W87)T>0!/<&-J;VYA;&YE('!R>GEN86QEOVYOMF-I`$]P8VIE`$]P
M8VIE("5S`$]R9V%N:7IA8VIA`$IE9&YO<W1K82!O<F=A;FEZ86-Y:FYA`$]R
M9V%N:7IA=&]R`$EN;F4`26YN92!I;F9O<FUA8VIE`$EN;F4@:V]N=&$@<&]C
M>G1O=V4`26YN92!O<&-J90!);FYE('5P<F%W;FEE;FEA`%5W:65R>GET96QN
M:65N:64@4$%-(&YI92!J97-T(&1O<W3J<&YE+@!01U``0WEF<F]W>2!P;V1P
M:7,@4$=0`%=I861O;6^VYB!K;V1O=V%N82!01U``5VEA9&]M;[;F('IA<WIY
M9G)O=V%N82!01U``0K.Q9"!01U`Z(`!"L[%D(%!'4#H@5WEM86=A;F4@:&%S
MLV\@9&QA(&]S;V)I<W1E9V\@:VQU8WIA('!R>7=A=&YE9V\N`%!'4"!.:65A
M:W1Y=VYE`$]P8VIE(%!'4`!7<')O=V%D>F5N:64@:&%SLV$@4$=0`$]B<[-U
M9V$@;W-O8FES=&5G;R!K;'5C>F$@4$=0('=Y;6%G82!B97IP:65C>FYE9V\@
M<&^SL6-Z96YI82!W=W<N`$ML=6-Z('!U8FQI8WIN>2!01U``5&5K<W1O=WD@
M:VQU8WH@<'5B;&EC>FYY(%!'4`!0=6)L:6-Z;GD@:VQU8WH@4$=0(&1L82`B
M)7,@*"5S*2(@>F]S=&&S(&1O9&%N>2X`4'5B;&EC>FYY(&ML=6-Z(%!'4"!D
M;&$@(B5S(B!Z;W-T8;,@=7-U;FGJ='DN`%IB:?-R('!U8FQI8WIN>6-H(&ML
M=6-Z>2!01U``5VEA9&]M;[;F(&]Z;F%C>F]N82!K;'5C>F5M(%!'4`!7:6%D
M;VUOMN8@:V]D;W=A;F$O<&]D<&ES86YA(&ML=6-Z96T@4$=0`%=I861O;6^V
MYB!Z87-Z>69R;W=A;F$O<&]D<&ES86YA(&ML=6-Z96T@4$=0`%!R>7=A=&YY
M(&ML=6-Z(%!'4"!D;V1A;GDN`%!U8FQI8WIN>2!K;'5C>B!01U`@9&]D86YY
M+@!/8G.S=6=A(%!'4"!J97-T('=YL[%C>F]N82!N82!T>6T@<WES=&5M:64N
M`$]B<[-U9V$@4$=0(&YI92!Z;W-T8;-A(&%K='EW;W=A;F$@9&QA=&5G;R!C
M>69R;W=Y('!O9'!I<R!N:64@;6^_92!B>>8@>G=E<GEF:6MO=V%N>2X`3V)S
MLW5G82!01U`@;FEE('IO<W1ALV$@86MT>7=O=V%N82!D;&%T96=O('=I861O
M;6^VYB!N:64@;6^_92!Z;W-T8>8@;V1K;V1O=V%N82X`3V)SLW5G82!01U`@
M=WEM86=A('>SL6-Z96YI82!O<&-J:2!N;W=Y8V@@;VMI96X@=R!4=V]J96H@
M<')Z96=LL61A<F-E+B!*9;9L:2!M87-Z('=YL[%C>F]NL2!TL2!O<&-JZB!P
M;W=I;FEE;F6V('1O('IM:65N:>8N(%<@<')Z96-I=VYY;2!W>7!A9&MU('!E
M=VYE(&9U:VYC:F4@4$=0(&UO9[$@;FEE(&9U;FMC:F]N;W=AYB!P<F%W:62S
M;W=O`$MO9"!02%``4&]WLV]K82!02%``4$]0,P!03U`S("A!=71O;6%T>6-Z
M;F4@=WEK<GEW86YI92!P<F]T;VMOLW4I`%!/4#,@<')Z97H@4U-,`%!/4#,@
M<')Z97H@4U-,("AWLV%S;GD@<&]D<&ES(&-E<G1Y9FEK871E;2D`4$]0,R!P
M<GIE>B!34TP@*'>S87-N>2!P;V1P:7,I`%!/4#,L(&)E>B!43%,`4&]WLV]K
M82!07TA0`%-T<F]N82`E9"!Z("5D`%-T<F]N82!Z('!I97)W<WJQ(&YI97=I
M9'II86ZQ('=I861O;6^V8VFQ`%-T<F]N82!Z(&]S=&%T;FFQ(&YI97=I9'II
M86ZQ('=I861O;6^VYFFQ`%!A:VES=&%N`%!A;&%U`%!A;F%M80!087!U82U.
M;W=A($=W:6YE80!087)A9W=A:@!#>NJV8VD`2&%SLV\`2&%SLV\@*'!O;F]W
M;FEE*0!(87.S;R!P<F%W:62S;W=O('5S=6YIZG1E+@!(87.S;SH`2&%SLV$@
M;FEE(&UO9[$@8GGF('!U<W1E`$AA<[-A(&YI92!Z9V%D>F%JL2!S:>H`2&%S
MLV\`2&%SLV\@;FEE<')A=VEDLV]W90!(87.S;R!Z('!O='=I97)D>F5N:65M
M`$AA<[-O.@!(87.S;SH@`$AA<[-O(&UU<VD@<&%S;W=AYBX`5VML96H`5VML
M96H@>F4@<V-H;W=K80!7>6MO;F%J(&-Y:VQI8WIN92!O<&5R86-J90!7>6MO
M;GEW8>8@;W!E<F%C:F4@8WEK;&EC>FYE('!O('IA;&]G;W=A;FEU/P!5<')A
M=VYI96YI90!5<')A=VYI96YI82!D;&$`57!R87=N:65N:6$@9&QA('1E9V\@
M=;]Y=&MO=VYI:V$@;FEE(&UO9[$@8GGF('IM:65N:6]N92X`3W-O8FES=&4`
M26YF;W)M86-J92!O<V]B:7-T90!087)A(&ML=6-Z>2!O<V]B:7-T>6-H(%!'
M4"!W>6=E;F5R;W=A;F$@<&]M>;9L;FEE+@!+;'5C>F4@;W-O8FES=&4@4$=0
M('5S=6YIZG1E('!O;7FV;&YI92X`3W-O8FES=&4@8V5R='EF:6MA='D@4R]-
M24U%(&YI97IA:6UP;W)T;W=A;F4Z(`!/<V]B:7-T92!K;'5C>F4@4R]-24U%
M('5S=6YIZG1E('!O;7FV;&YI92X`4&5R=0!&:6QI<&EN>0!496QE9F]N`%!I
M=&-A:7)N`$-Z>2!Z86UI97-Z8WIAYB!4=_-J('!O9'!I<R!P<GIE9"!O9'!O
M=VEE9'II86UI(&D@<')Z96MA>F%N:6%M:3\`5V5R<VIA(&-Z>71E9V\@=&5K
M<W1U('=I861O;6^V8VD`3F$@<&5W;F\@=7-U;K'F('1E;B!W>6)R86YY(&5L
M96UE;G0Z`$YA('!E=VYO('5S=6ZQYB!W>6)R86YY(&5L96UE;G0Z`%!R;W-Z
MZB!P;V1AYB!N87IWZB!D;&$@;F]W96=O(&9O;&1E<G4Z`%!R;W-ZZB!P;V1A
MYB!P;W!R87=N>2!A9')E<R!)4"X`4')O<WKJ('!O9&'F('!O<')A=VYY(&-Z
M87,N`%!R;W-ZZB!P;V1AYB!N87IWZB!N;W=E9V\@9F]L9&5R=3H`4')O<WKJ
M('!O9&'F(&YO=[$@;F%Z=^HZ`%=P<F]W862\(&AA<[-O(&1L82!S=V]J96=O
M('!R>7=A;G1E9V\@:VQU8WIA(%!'4"X@5W!R;W=A9'IE;FEE(&AA<[-A('=Y
M;6%G86YE(&IE<W0@='EL:V\@<F%Z(&1L82`E<R!S97-J:2X`5W!R;W=A9+P@
M:&%SLV\@9&QA('-W;VIE9V\@<')Y=V%T;F5G;R!K;'5C>F$@4R]-24U%+B!7
M<')O=V%D>F5N:64@:&%SLV$@=WEM86=A;F4@:F5S="!T>6QK;R!R87H@9&QA
M("5S('-E<VII+@!:86QO9W5J('-IZB!P;VYO=VYI92!B>2!W>FYO=VGF('1W
M;W)Z96YI92!S=V]J96H@=VEA9&]M;[9C:2X@2F6V;&D@5'=O:F$@<')Z96=L
ML61A<FMA(&YI92!UOWEW82!P;&EK\W<@='EP=2`G8V]O:VEE<R<L(&$@='=O
M<GIO;F$@<')Z97H@0VEE8FEE('=I861O;6^VYB!Z;F%J9'5J92!S:>H@=R!N
M;W=Y;2!O:VYI92P@=WEM86=A;F4@:F5S="!P;VYO=VYE(&QO9V]W86YI92X@
M3W!E<F%C:F$@=&$@=WEM86=A;F$@:F5S="!Z92!W>F=LZF1U(&YA(&)E>G!I
M96-Z9?%S='=O(%1W;VIE:B!S97-J:2X@4')Z97!R87-Z86UY('IA('=S>F5L
M:VEE(&YI961O9V]D;F^V8VDN`%!R;W-ZZB!O<&ES8>8@<')O8FQE;2X`4')O
M<WKJ('=P<F]W861Z:>8@:&%SLV\N`%!R;W-ZZB!P;V1AYB!N87IWZB!UOWET
M:V]W;FEK82!I(&AA<[-O`%!R;W-ZZB!W<')O=V%D>FGF(&YA>G?J('6_>71K
M;W=N:6MA+@!0;W!R87<@;FEE:F5D;F]Z;F%C>FYY(&QU8B!N:65P<F%W:62S
M;W=Y(&%D<F5S+@!0<GIE9VRQ9&YI:B!P;VYIOW-ZL2!I;F9O<FUA8VKJ+"!A
M('!O=&5M('=Y8FEE<GH@:F5D;K$@>B!O<&-J:2!D;W-TZG!N>6-H('<@;65N
M=2X`5WEB:65R>B!F;VQD97(@<')Z960@=WEK;VYA;FEE;2!J86MI96IK;VQW
M:65K(&%K8VII+@!7>6)I97)Z(&]P8VKJ('H@<&]N:;]S>F5G;R!M96YU+@!7
M>6)I97)Z(&-H;V-I8;\@:F5D96X@9F]L9&5R(&1O('!R>F5S>G5K86YI82X`
M5WEB:65R>B!T>6QK;R!J961E;B!F;VQD97(@9&QA('1E:B!O<&5R86-J:2X`
M5WEB:65R>B!L=6(@961Y='5J('<@;VMN:64Z`%!O;'-K80!0;W)T=6=A;&EA
M`$YA<.ID>F%N92!P<GIE>B!(;W)D90!0;W!R>F5D>FGF(%1W\VH@<&]D<&ES
M(&UYMFQN:6MA;6D@*"<M+2`G*3\`57-T87=I96YI82!Z;W-T8;-Y('IM:65N
M:6]N92X`4&]D9VRQ9`!0;W!R>F5D;FEA('=I861O;6^VY@!0;W!R>F5D;FEA
M('-T<F]N80!$<G5K=6H`4')I;W)Y=&5T`$ML=6-Z('!R>7=A=&YY`$AA<[-O
M('!R>7=A=&YE9V\@:VQU8WIA`%!R;V)L96T`3W!I<R!P<F]B;&5M=0!0>71A
M:B!Z82!K8;]D>6T@<F%Z96T@9V1Y('IAL[%C>FYI:R!J97-T('=Y<[-A;GD[
M(&1O;7FV;&YI92!.244`4'ET86H@>F$@:V&_9'EM(')A>F5M(&=D>2!Z8;.Q
M8WIN:6L@:F5S="!W>7.S86YY.R!D;VUYMFQN:64@5$%+`%!R;W1O:_.S.@!+
M;'5C>B!P=6)L:6-Z;GD`06QG;W)Y=&T@:VQU8WIA('!U8FQI8WIN96=O`$EN
M9F]R;6%C:F4@;R!K;'5C>G4@<'5B;&EC>FYY;0!/8G.S=6=A('-E<G=E<F$@
M<'5B;&EC>FYY8V@@:VQU8WIY(%!'4"!Z;W-T8;-A('=YL[%C>F]N82X`4&%R
M82!K;'5C>GD@;W-O8FES='EC:"!N:64@>F]S=&&S82!W>6=E;F5R;W=A;F$@
M<&]M>;9L;FEE+@!0;W)T;W)Y:V\`5WEC>GFVYB!U<W5N:>IT92`H7V<I`%=Y
M8WIYMN8@=7-U;FGJ=&4`5WEC>GFVYB!F;VQD97)Y`$IA:R!C>NIS=&\@;W!R
M\[]N:6'F($MO<WHZ`%5S=7=A:B!W:6%D;VUOMF-I('H@2V]S>F$@<W1A<G-Z
M92!N:;\@=&$@;&EC>F)A(&1N:2X`57-U;K'F('-T87*Q('=I861O;6^VYB!Z
M($MO<WIA/P!5<W5W86YI92`E9"!W:6%D;VUOMF-I('H@2V]S>F$N`%5S=7=A
M;FEE(#$@=VEA9&]M;[9C:2!Z($MO<WIA+@!+871A<@!:87!Y=&%N:64`5WEK
M;W)Z>7-T86YI92!P;VIE;6YOMF-I(&MO;G1A.B`E+C)F34(@+R`E+C)F34(@
M("@E+C)F)24I`%=Y:V]R>GES=&%N:64@<&]J96UN;[9C:2!K;VYT83H@)2XR
M9DU"("\@0E)!2R!,24U)5%4`5WEK;W)Z>7-T86YI92!P;VIE;6YOMF-I(&MO
M;G1A.B!"4D%+($Q)34E450!#>71O=V%N:64@)68Z`$ML=6-Z('!U8FQI8WIN
M>2!24T$@*"5D(&)I=/-W*0!7>6UA9V%J('!O='=I97)D>F5N:6$@;V1E8G)A
M;FEA("A?<2D`3W1R>GEM86YE`$]T<GIY;6%N92!P>F5D`$]T<GIY;6%N92!D
M;P!0<GIE:VEE<G5J("A?="D`4')Z96MI97)U:@!0<GIE:VEE<G5J('=I861O
M;6^VY@!0<GIE:VEE<G5J('2Q('=I861O;6^VY@!0<GIE:VEE<F]W86YI92!N
M:65U9&%N92X`3V2V=VEEOP!/9+9W:66_(&1Y;F%M:6-Z;F4@96QE;65N='D@
M;65N=3H`3V2V=VEEOR!W:61O:R!F;VQD97)A.@!/9+9W:66_('=I9&]K('-E
M<G=I<W4Z`%!R>F6S861U:@!0<GIELV%D=6H@=VED;VL`4&%M:>IT86H@;R!I
M;F9O<FUA8VII('=O;&YY+WIA:NIT>2X`6F%P86UIZG1A:B!O<W1A=&YI('=I
M9&]K`%ID86QN82!S:W)Z>6YK80!:9&%L;F4@<V5R=V5R>0!5<W7Q`%5S=?$@
M8FQO:P!5<W7Q('!O;&4@>B!S>G5K86YI80!5<W7Q(&MO;'5M;NH`57-U\2!P
M87+J`%5S=?$@O'+S9+-O`%5S=?$`57-U\2!UOWET:V]W;FEK80!:9&%L;F4@
M=;]Y=&MO=VYI:V$Z("5S`%IM:67Q(&YA>G?J(&9O;&1E<G4@;'5B(&9O;&1E
M<O-W`%IM:65N:6'F(&YA>G?J(&9O;&1E<F$@=VEA9&]M;[9C:2!W>7.S86YY
M8V@@;F$@<&]C>K%T:W4@:V&_9&5G;R!M:65S:;%C83\`6FUI86YA(&YA>G=Y
M('H@(B5S(B!N82`B)7,B(&YI92!U9&%N82X@4V5R=V5R('IW<O-C:;,@;V1P
M;W=I962\`$]D<&]W:65D>B!G<G5P:64@*%]Y*0!:86UI9?$@>CH`3V1P;W=I
M961Z`$]D<&]W:65DO"!W>7.S86YA+@!/9'!O=VEE9'H@=W-Z>7-T:VEM`$]D
M<&]W:65DO"!D;R!W<WIY<W1K:6-H.@!/9'!O=VEE9'H@9W)U<&EE`$]D<&]W
M:65DO"!D;R!G<G5P>3H`3V1P;W=I961Z('=S>GES=&MI;2`H7V$I`$]D<&]W
M:65DO"!Z87=I97)A(&YI92!O8G.S=6=I=V%N>2!F;W)M870@=VEA9&]M;[9C
M:0!/9'!O=VEA9&%J('!R>F5Z(&MO;&5J;F4@9'=A(&UI97-IL6-E("AW;VQN
M>2]Z86KJ='DI`$]D<&]W:6%D86H@O[%D86ZQ(&EN9F]R;6%C:K$@=V]L;GDO
M>F%JZG1Y+@!/9'!O=VEE9'HM1&\`3V1P;W=I961Z+41O.@!/9'!O=VEE9'HZ
M`%)A<&]R='5J(&IA:V\@;FEE<WIK;V1L:7=Y`%)A<&]R='5J(&IA:V\@<W!A
M;0"OL61A:B!P;W1W:65?<F1Z96YI82!Z('IA<&]Z;F%N:65M('-IZB!Z('1R
M9;9C:;$@=VEA9&]M;[9C:0"O861AYB!P;W1W:65R9'IE;FEA(&1O<W1A<F-Z
M96YI83\`K[%D8>8@<&]T=VEE<F1Z96YI82!Z87!O>FYA;FEA('-IZB!Z('1R
M9;9C:;$_`%=Y;6%G86YA('=I861O;6^VYB!N:65Z;F%L97II;VYA+@!7>6UA
M9V%N>2!U8WIE<W1N:6L`4F5S970`5WEC>GFVYB!H87.S;P!7>6-Z>;;F(%1W
M;VIE(&AA<[-O`%-T871U<R!O9'!O=VEA9&%JL6-E9V\@=6%K='5A;&YI;VYY
M`%=Y;FEK:0!7>F[S=P!7>F[S=R!S=V]JL2!S97-JZ@!0;W=R\W0@9&\@;W!C
M:FD@<&]B:65R86YI82!P;V-Z='D`4&]W<O-T(&1O(&]P8VII`%!O=W+S="!D
M;R!W:61O:W4@<VMR>GEN:VD@<&\@<VMA<V]W86YI=2P@<')Z96YI97-I96YI
M=2!L=6(@<VMO<&EO=V%N:74@=VEA9&]M;[9C:3\`4F5U;FEO;@!2;WIB=61O
M=V%N>2!E9'ET;W(@=&5K<W1U`%)O;&$`4G5M=6YI80!/8G+SYB!O(#$X,"!S
M=&]P;FD`3V)R\^8@=R!L97=O`$]B<O/F('<@<')A=V\`5[-AMF-I=V^V8VD@
M<GKJ9'4@4')O<&5R=&EE<P!2;W-J80!2=6%N9&$`4R]-24U%`%=I861O;6^V
MYB!K;V1O=V%N82!K;'5C>F5M(%,O34E-10!7:6%D;VUOMN8@>F%S>GEF<F]W
M86YA(%,O34E-10!"L[%D(%,O34E-13H@`$*S860@4R]-24U%.B!7>6UA9V%N
M92!H87.S;R!D;&$@;W-O8FES=&5G;R!K;'5C>F$@<')Y=V%T;F5G;RX`4R]-
M24U%(&YI96%K='EW;F4`3W!C:F4@4R]-24U%`%=P<F]W861Z96YI92!H87.S
M82!D;&$@4R]-24U%`$]B<[-U9V$@4R]-24U%('=Y;6%G82!B97IP:65C>FYE
M9V\@<&^SL6-Z96YI82!34TPN`$ML=6-Z('!U8FQI8WIN>2!3+TU)344@9&QA
M("(E<R(@<&]M>;9L;FEE('5S=6YIZG1Y+@!+;'5C>B!P=6)L:6-Z;GD@4R]-
M24U%(&1O9&%N>2!P;VUYMFQN:64N`%IB:?-R('!U8FQI8WIN>6-H(&ML=6-Z
M>2!3+TU)344`4'5B;&EC>FYA+U!R>7=A=&YA('!A<F$@:VQU8WIY(%,O34E-
M12!D;V1A;F$@<')A=VEDLV]W;RX`4&]D<&ES(&ML=6-Z82!3+TU)344`5VEA
M9&]M;[;F('!O9'!I<V%N82]K;V1O=V%N82!K;'5C>F5M(%,O34E-10!/8G.S
M=6=A(%,O34E-12!J97-T('=YL[%C>F]N82!N82!T>6T@<WES=&5M:64N`$]B
M<[-U9V$@4R]-24U%(&YI92!Z;W-T8;-A(&%K='EW;W=A;F$@9&QA=&5G;R!W
M:6%D;VUOMN8@;FEE(&UOOV4@>F]S=&'F('ID96MO9&]W86YA+@!/8G.S=6=A
M(%,O34E-12!N:64@>F]S=&&S82!A:W1Y=V]W86YA(&1L871E9V]Z87=A<G1O
MMN8@=&5J('!O9'!I<V%N96H@=VEA9&]M;[9C:2!N:64@;6^_92!Z;W-T8>8@
M=WFV=VEE=&QO;F$N`$]B<[-U9V$@4R]-24U%(&YI92!Z;W-T8;-A(&%K='EW
M;W=A;F$@9&QA=&5G;R!P;V1P:7,@8WEF<F]W>2!N:64@;6^_92!B>>8@>G=E
M<GEF:6MO=V%N>2X`3V)SLW5G82!3+TU)344@=WEM86=A(&]B<[-U9VEW86YI
M82!W>7-K86MU:K%C>6-H(&]K:65N96LN($IEMFQI('1W;VIA('!R>F5G;+%D
M87)K82!O8F5C;FEE(&UA('=YL[%C>F]N92!W>6MS:V%K=6JQ8V4@;VMI96YK
M82P@;75S:7-Z('IM:65N:>8@=&\@=7-T87=I96YI92!A;&)O(%,O34E-12!N
M:64@8NID>FEE(&1Z:6&S8>8@<&]P<F%W;FEE`%5W:65R>GET96QN:65N:64@
M4T%33"!N:64@:F5S="!D;W-TZG!N92X`4&]W;&]K82!344P`4U-(`%!O=[-O
M:V$@4U]13`!496UA="`H7W4I`%IA<&ES>B!K;W!I92!W("A?=BD`6F%P:7-Z
M(&IA:V\@*%]V*0"F=VGJ=&$@2&5L96YA`%-A:6YT($MI='1S(&D@3F5V:7,`
M4V%I;G0@3'5C:6$`4V%I;G0M4&EE<G)E(&D@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="!I($=R96YA9'EN>0!386UO80!386X@36%R:6YO`$%R86)I82!3875D
M>6IS:V$`6F%P:7-Z`%IA<&ES>B`B)7,B`%IA<&ES>B`E<P!:87!I<WEW8>8@
M>F&SL6-Z;FEK:2!Z('=I861O;6^V8VFQ('<@9F]L9&5R>F4@=WESLV%N92UW
M:6%D;VUOMF-I/P!:87!I<WH@<WIK:6,`6F%P:7-Z(&]P8VIE`%IA<&ES>B!S
M>FMI8R`H7V0I`%IA<&ES>B!J86MO`%IA<&ES>7=AYB!S>FMI8V4@:F%K;R!N
M:65W:61Z:6%N93\`6F%P:7-Y=V'F(&%U=&]M871Y8WIN:64@861R97-A=/-W
M('<@9&]M>;9L;F5J(&MS:;&_8V4@861R97-O=V5J/P!:87!I<WH@<WIU:V%N
M:64@:F%K;R!W:7)T=6%L;GD@9F]L9&5R/P!:87!I<WEW8>8@=WESLV%NL2!W
M:6%D;VUOMF,_`%IA<&ES>F%N:64@<WIK:6-U(&YI975D86YE+B!397)W97(@
M>G=R\V-ILR!O9'!O=VEE9+PZ("5S`%-Z=6MA:@!3>G5K86H@)7,`5WEN:6MI
M('=Y<WIU:VEW86YI80!7:61Z:6%N90!7>6)I97)Z`%=Y8FEE<GH@:6YN92!K
M;VYT;P!7>6)I97)Z('!L:6MI`%=Y8FEE<GH@9&%TZ@!7>6)I97)Z('!O;&4`
M5WEB:65R>B!K<VFQOVOJ(&%D<F5S;W>Q(&1O('!R>F5S>G5K:7=A;FEA(&D@
M9&]D87=A;FEA(&%D<F5S\W<N`%=Y8FEE<GH@=W-Z>7-T:V\`5WEB:65R>B!W
M<WIY<W1K:64@<&]L82!D;R!P<GIE<WIU:VEW86YI82!P;V1C>F%S(')O>G-Z
M97)Z86YI82!A9')E<_-W+@!7>6)I97)Z(&MO;G1O`$YI92!W>6)I97)A:@!7
M>6)I97)Z('IN86L@<&]D>FEALW4@9&%T>3H`5WEB:65R>B!F;W)M870@9&%T
M>3H`5WEB:65R>B!T;[]S86UOMN8@9&\@>FUI86YY.@!7>6)I97)Z('1Y<"!S
M97)W97)A('!O8WIT;W=E9V\`5WEB:65R>B!Z;F%K('!O9'II8;-U(&1A='DZ
M`%=Y8FEE<GH@9F]R;6%T(&-Z87-U.@!7>6)I97)Z(&1W82!P87-U:K%C92!P
M;VQA+@!7>6)I97)Z('-C:&5M870@:V]L;W+S=RX`5WEB:65R>B!T=_-J('!R
M969E<F]W86YY(&KJ>GEK.@!7>6)R86YE(&MS:;&_:VD@861R97-O=V4Z`%=Y
MMFQI:B!K;'5C>B!D;R!P=6)L:6-Z;F5G;R!S97)W97)A(&ML=6-Z>0!7>;9L
M:6H@;F%JMG=I9;]S>K$@:6YF;W)M86-JZ@!7>;9L:6H@=VEA9&]M;[;F`%=Y
MMFQI:B!R87!O<G0@;R!P<F]B;&5M:64`5WES>;-AYB!P;W1W:65R9'IE;FEE
M('!R>F5C>GET86YI82!K:65D>2!Z8;]Y8WIO;F4@<')Z97H@;F%D87=CZC\`
M4V5N96=A;`!&;VQD97(@<&]C>G1Y('=Y<[-A;F5J`$9O;&1E<B!P;V-Z='D@
M=WESLV%N96HZ`%=R>F5S:67Q`$YU;65R('-E<GEJ;GD`4V5R=V5R`$EN9F]R
M;6%C:F4@;R!S97)W97)Z92!I(&9O;&1E<GIE`%-E<G=E<CH`57-T87<`57-T
M87<@<')E9F5R96YC:F4@<')Z96YO<WIE;FEA(&D@=7-U=V%N:6$@=VEA9&]M
M;[9C:2X`6F&SL6-Z8>8@=R!N86>S\W=K=2!I;F9O<FUA8VKJ(&\@<')I;W)Y
M=&5C:64@<&]D8WIA<R!T=V]R>F5N:6$@=VEA9&]M;[9C:3\`57-T87<@>F1A
M;&YE('-E<G=E<GDL(&1O(&MT\W)Y8V@@8VAC97-Z(&UI9>8@9&]S=.IP('H@
M<V5R=VES=2X`57-T87<@<')E9F5R;W=A;GD@:NIZ>6LL('-T<F5FZB!C>F%S
M;W>Q(&D@;W!C:F4@9&%T>2X`57-T87<@=7.S=6?J('!O8WJQ=&MO=[$L('-C
M:&5M870@:V]L;W+S=RP@;V2V=VEEOV%N:64@<W1R;VYY(&D@:6YN92!O<&-J
M92!W>;9W:65T;&%N:6$`2V]N9FEG=7)A8VIA`%-Z97-Z96QE`%5D;W-TZG!N
M:6%J(&9O;&1E<GD`561O<W3J<&YI86H@9F]L9&5R>2!P;V-Z=&]W90!59&]S
M=.IP;FEA:B!F;VQD97)Y('!O8WIT;W=E(&1L82!I;FYY8V@@=;]Y=&MO=VYI
M:_-W+@!+<O-T:VD@;W!I<P!#>GD@<&]K87IY=V'F(&QU8B!U:W)Y=V'F(&1O
M;7FV;&YI92!D=;]E(&)L;VMI('1E:W-T=2!C>71O=V%N96=O/R!496X@=WEB
M\W(@;6^_92!B>>8@<')Z>61A=&YY+@!#>GD@<W!R87=D>F'F(&]B96-N;[;F
M(&1A;GEC:"!01U`@=R!W:6%D;VUOMF-I86-H/P!#>GD@>F%M:VZQYB!O:VYO
M('1W;W)Z96YI82!W:6%D;VUOMF-I+"!G9'D@<WIK:6,@>F]S=&%N:64@>F%C
M:&]W86YY/P!#>GD@9&]M>;9L;FEE('IAL[%C>F'F(&1O('=I861O;6^V8VD@
M5'?S:B!K;'5C>B!P=6)L:6-Z;GD@4$=0/P!0;VMAOP!0;VMAOR!W<WIY<W1K
M:64@9F]L9&5R>0!0;VMAOR!W<WIY<W1K:64@;F%GL_-W:VD`4&]K8;\@=7-U
M;FGJ=&4`4&]K8;\@;V=R86YI8WIO;F4@;F%GL_-W:VD`4&]K8;\@:6YF;W)M
M86-J92!L:7-T>2!M86EL;W=E:@!0;VMAOR!T>6QK;R!S=6)S:W)Y8F]W86YE
M(&9O;&1E<GD`4&]K8;\@;FEE<W5B<VMR>6)O=V%N90!0;VMA>GEW8>8@:6MO
M;NH@<&]Z=V%L86JQ8[$@;F$@<&]B:65R86YI92!Z8;.Q8WIN:6OS=R!Z('=I
M861O;6^V8VD_`%!O:V%Z>7=AYB!C>F%S(&]S=&%T;FEE9V\@>F%L;V=O=V%N
M:6$@<&\@;&]G;W=A;FEU/P!7>;9W:65T;&'F(&QE9V5N9.H@=R!W:61O:W4@
M<VMR>GEN:VD_`%=YMG=I971L8>8@<&]D9VRQ9"!T>6QK;R!D;&$@;FEE<')Z
M96-Z>71A;GEC:"!W:6%D;VUOMF-I/P!7>;9W:65T;&'F('!O9&=LL60@=R!P
M;W)A9&%C:#\`4&]K8;\@;65N=2`E<R!P;R!L97=E:C\`5WFV=VEE=&QAYB!I
M;F9O<FUA8VKJ(&\@;F]W96H@<&]C>F-I92!N82!P87-K=2!Z861A\3\`4&]K
M8;\@;V)R87IY`%=YMG=I971L8>8@:6MO;NH@9FEL=&5R\W<@;F$@<&%S:W4@
M>F%D8?$_`%=YMG=I971L8>8@8V&S:V]W:72Q(&QI8WIBZB!W:6%D;VUOMF-I
M('<@9F]L9&5R>F4_`%!O:V%Z86YE`%)O7WIM:6%R`%-I97)R82!,96]N90!:
M87)E:F5S=')U:B!S:>HL(&IEMFQI(&IE<WIC>F4@=&5G;R!N:64@>G)O8FFS
M9;8`4&]D<&ES`$%L9V]R>71M('!O9'!I<W4`4&]D<&ES86YE`%-I;F=A<'5R
M`%)O>FUI87(`4&]M:?$@;W!E<F%C:F4@8WEK;&EC>FYE`%.S;W=A8VIA`%.S
M;W=E;FEA`%=Y<W!Y(%-A;&]M;VYA`%-O;6%L:6$`4W!O<_-B('-O<G1O=V%N
M:6$`4V]R='5J('=G(&-Z87-U('!R>GEB>6-I80!3;W)T=6H@=V<@9&%T>0!3
M;W)T=6H@=V<@<&]L82!N861A=V-Y`%-O<G1U:B!W9R!R;WIM:6%R=2!W:6%D
M;VUOMF-I`%-O<G1U:B!W9R!T96UA='4`4V]R='5J('=G('>Q=&MU`%-O<G1U
M:B!W9R!P;VQA(&%D<F5S871A`%!OLW5D;FEO=V$@069R>6MA`%!OLW5D;FEO
M=V]E=7)O<&5J<VMI("A)4T\M.#@U.2TS*0!'96]R9VEA(%!OLW5D;FEO=V$`
M2&ES>G!A;FEA`%-P86T`1F]L9&5R('-P86UU.@!%9'EC:F$@>FYA:_-W('-P
M96-J86QN>6-H`%IN86MI('-P96-J86QN90!3<')A=V1Z86YI92!P:7-O=VYI
M`%-P<F%W9'IA;FEE('!I<V]W;FD`4W!R87=D>F%N:64@<&ES;W=N:2!Z86MO
M\6-Z;VYE`$*SZF3S=R!P:7-O=VYI(&YA(&5K<F%N('!O9&-Z87,@<W!R87=D
M>F%N:6$@<&ES;W=N:2X`4&]D>FEE;"!K;VWS<FOJ`%!O9'II96P@:V]L=6UN
MZ@!0;V1Z:65L('=I97)S>@!3<FD@3&%N:V$`4W1A<G0`5V]J97?S9+QT=V\@
M;'5B('-T86X`4W1A='5S`$%D<F5S(&1O;6]W>0!0;V)I97)Z('IAL[%C>FYI
M:P!5<W5NL>8@<')Z97)W>3\`5&5M870@*%]J*0!496UA=`!0;VQE('1E;6%T
M=0!7>;9L:6H`4')Z96YOMB!S=6)S:W)Y<&-JZB!D;R!F;VQD97)U*/-W*0!0
M;VUYMFQN:64`561ALV\@<VGJ(&1O9&'F("(E<R(@9&\@<WES=&5M=2X`561A
MLV\@<VGJ('5S=6ZQYB`B)7,B('H@<WES=&5M=2X`561ALV\@<VGJ('5S=6ZQ
MYB`B)7,B+@!59&&S;R!S:>H@=7-U;K'F("(E<R(@>B!S>7-T96UU+@!59&&S
M;R!S:>H@=6%K='5A;&YIYB`B)7,B`%-U9&%N`%-U9V5S=&EE`%!O9'-U;6]W
M86YI90!7<V-H\V0O>F%C:/-D('.S;_%C80!3=7)I;F%M`%-U87II`%-Z=V5C
M:F$`4')Z9;.Q8WH@;65T;V3J('1W;W)Z96YI80!0<GIEL[%C>B!N82!F;W)M
M870@2%1-3`!0<GIEL[%C>B!N82!Z=WEKLWD@=&5K<W0`4WIW86IC87)I80!3
M>7)I80!486IW86X`5&%J=V%N`%1A9+]Y:VES=&%N`%1A;GIA;FEA`%IA9&%N
M:6$`5&5K<W0@*%]X*0!.=6UE<B!T96QE9F]N=0!0<O-B;F$@86MC97!T86-J
M82"_L61A;FEA`%!R\V)N:64@>F%A:V-E<'1O=V%N90!0;&EK(%1O4R`H5V%R
M=6YK:2!K;W)Z>7-T86YI82D@;FEE('ID969I;FEO=V%N>2!W(&-O;F8N<&AP
M`%1Y;&MO('1E:W-T`%1A:FQA;F1I80!$>FGJ:W5J96UY('IA(&MO<GIY<W1A
M;FEE('H@<V5R=VES=2X`4&]L92!/9#H@:V]L=6UN82!W:6%D;VUOMF-I('!O
M=VEN;F$@8GGF('!OL[%C>F]N83H`2V]N=&\@(B5S(B!Z;W-T8;-O('5S=6YI
MZG1E+@!+;VYT;R`B)7,B('IO<W1ALV\@>F%P:7-A;F4N`$%D<F5S("(E<R(@
M>F]S=&&S(&1O9&%N>2!D;R`E<RX`6F&SL6-Z;FEK(&YI92!Z;W-T8;,@>FYA
M;&5Z:6]N>2X`1&%T82!W(&MA;&5N9&%R>G4@:F5S="!N:65P<F%W:62S;W=A
M`$]K:65N:V\@='=O<GIE;FEA('=I861O;6^V8VD@;FEE(&UOOV4@>F]S=&'F
M(&]T=V%R=&4N($-Z>;]B>2!T=V]J82!P<GIE9VRQ9&%R:V$@8FQO:V]W8;-A
M('=Y<VMA:W5JL6-E(&]K:65N:V$_`%IA=V%R=&^VYB!P;&EK=2!-86-I;G1O
M<V@@:F5S="!P;VYIOV5J+@!.87IW82!O8F5C;F5G;R!F;VQD97)A*/-W*2`B
M)7,B('IO<W1A;FEE('IM:65N:6]N82!N82`B)7,B+@!/8F5C;F$@;&ES=&$@
M=;]Y=&MO=VYI:_-W('H@9&]S=.IP96T@9&\@=&5G;R!F;VQD97)A(&YI92!M
M;[]E(&)YYB!O9'1W;W)Z;VYA`%-Z:VEC('IO<W1ALR!Z87!I<V%N>2!D;R!F
M;VQD97)A("(E<R(N`%=Y9&%R>F5N:64@>F]S=&&S;R!D;V1A;F4@9&\@='=O
M:F5G;R!K86QE;F1A<GIA+@!0;VQE("(E<R(@;FEE(&UOOV4@>F]S=&'F(')O
M>G=I;FGJ=&4N`$ES=&YI96IE(&IUOR!F;VQD97(@;R!N87IW:64@(B5S(BX`
M3F%Z=V$@9F]L9&5R82`B)7,B('IA=VEE<F$@;FEE('!R87=I9+-O=V4@>FYA
M:VDN($UOOV4@8GGF('1O(+QR\V2S96T@</.\;FEE:G-Z>6-H('!R;V)L96WS
M=RX@6F]B86-Z('-W\VH@<&%N96P@861M:6YI<W1R86-Y:FYY+@!&;VQD97(@
M(B5S(B!Z;W-T8;,@=71W;W)Z;VYY+"!A;&4@;FEE('IO<W1ALV6V(&1O(&YI
M96=O('-U8G-K<GEB;W=A;GDN`$9O;&1E<B`B)7,B('IO<W1ALR!S:V%S;W=A
M;GDL(&%L92!N:64@=7-U;FGJ=&\@5'=O:F5J('-U8G-K<GEP8VII+@!&;VQD
M97(@(B5S(B!N:64@>F]S=&&S('5T=V]R>F]N>2X@4V5R=V5R('IW<O-C:;,@
M;V1P;W=I962\`$9O;&1E<B`B)7,B(&YI92!Z;W-T8;,@=7-U;FEE='DN($]T
M;R!C;R!O9'!O=VEE9'II8;,@<V5R=V5R`$9O;&1E<B`B)7,B('IO<W1ALR!U
M='=O<GIO;GDN`$9O;&1E<B`B)7,B('IO<W1ALR!U<W5N:>IT>2X`6FUI96YI
M;VYO(&YA>G?J(&9O;&1E<F$@(B5S(B!N82`B)7,B('!O;7FV;&YI92X`3F%S
M=.IP=6JQ8V4@<&QI:VD@>F]S=&&S>2!D;[.Q8WIO;F4@9&\@=&5J(&-ZZK9C
M:3H`5&^_<V%M;[;F("(E<R(@>F]S=&&S82!U<W5N:>IT82X`3V)R87IK:2!B
MZF2Q('=YMG=I971L86YE('!O;FEE=V&_(&YA9&%W8V$@>FYA:F1U:F4@<VGJ
M('<@='=O:F5J(&MS:;&_8V4@861R97-O=V5J+@!397)W97(@<&]C>G1O=WD@
M=WEG96YE<F]W8;,@;F%S=.IP=6JQ8[$@=VEA9&]M;[;F('H@8K/J9&5M.@!3
M97)W97(@<&]C>G1O=WD@=WEG96YE<F]W8;,@;F%S=.IP=6JQ8[$@=VEA9&]M
M;[;F(&EN9F]R;6%C>6INL3H`4V5R=V5R('!O8WIT;W=Y('=Y9V5N97)O=V&S
M(&YA<W3J<'5JL6.Q('=I861O;6^VYCH`4VMR>GEN:V$@)7,@:F5S="!J=;\@
M<'5S=&$N`%=I861O;6^VYB`B)7,B(&]D("(E<R(@*"5D(&)A:G3S=RD@<')Z
M96MR86-Z82!L:6UI="!R;WIM:6%R=2X`5'=O<GIO;F$@=VEA9&]M;[;F('IO
M<W1ALV$@>F%M:VYIZG1A+B!7>6-H;V1Z96YI92X`5VEA9&]M;[;F('IO<W1A
MLV$@=7-U;FGJ=&$N`%=I861O;6^VYB!Z;W-T8;-A('IW97)Y9FEK;W=A;F$N
M`%=I861O;6^VYB!Z;W-T8;-A('IW97)Y9FEK;W=A;F$N($YA9&%W8V$Z("5S
M+@!/:VYO('H@:&%SLV5M(&YI92!M;[]E('IO<W1AYB!O='=A<G1E+B!#>GF_
M8GD@='=O:F$@<')Z96=LL61A<FMA(&)L;VMO=V&S82!W>7-K86MU:K%C92!O
M:VEE;FMA/P"L<O-DLV]W>2!T96MS="!K;'5C>F$@<'5B;&EC>FYE9V\@4$=0
M(&UOOV4@8GGF('=I9'II86YY("5S+@"OL61A;GD@<&QI:R!N:64@=WES=.IP
M=6IE('<@>F&SL6-Z;FEK=2!-4RU43D5&+@"OL61A;GD@<&QI:R!N:64@=WES
M=.IP=6IE('<@>F&SL6-Z;FEK=2!::7`N`$YA9&%W8V$@=&5J('=I861O;;9C
M:2!W>6UA9V$@<&]T=VEE<F1Z96YI82!P>F5C>GET86YI82!T96H@=VEA9&UO
MMF-I+B!+;&EK;FEJ("5S(&%B>2!W>7.S8>8@=VEA9&]M;[;F('H@>F%W:6%D
M;VUI96YI96TN`%-E<G=E<B`B)7,B('IO<W1ALR!U<W5N:>IT>2X`4V5R=V5R
M("(E<R(@>F]S=&&S('IA<&ES86YY+@!397)W97(@;FEE('!O=')A9FFS('-T
M=V]R>GGF(&UI;FEA='5R:VD@=&5G;R!O8G)A>FMA+@!0;V1P:7,@;FEE(&UO
MOV4@8GGF('IA<W2Q<&EO;F$N`%!O9'!I<R!Z87-TL7!I;VYA('!O;7FV;&YI
M92X`3VMR9;9L;VYY('!L:6L@;FEE(&ES=&YI96IE+@!:861A;FEE('IO<W1A
MLV\@9&]D86YE(&1O('1W;VIE:B!L:7-T>2!Z861A\2X`5&5K<W0@=VEA9&]M
M;[9C:0!496MS="!W:6%D;VUOMF-I(&UOOV4@8GGF('=YMG=I971L;VYY("5S
M+@!:=W+S8V]N;R!O9'!O=VEE9+P`6G=R\V-O;F$@;V1P;W=I962\(&UOOV4@
M8GGF('=YMG=I971L;VYA("5S+@!7:6%D;VUOMN8@=WESLV%N80!7:6%D;VUO
MMN8@=WESLV%N82!M;[]E(&)YYB!W>;9W:65T;&]N82`E<RX`26YF;W)M86-J
M82!O('6_>71K;W=N:6MU("AW;VQN>2]Z86KJ='DI('IO<W1ALV$@>F%C:&]W
M86YA+@!";&]K('=E871H97(N8V]M(&YI92!J97-T(&1O<W3J<&YY+@!.:64@
M;6$@OV%D;GEC:"!A;'1E<FYA='EW;GEC:"!C>NJV8VDL(&MT\W)E(&UO9[-Y
M8GD@>F]S=&'F('!O:V%Z86YE+@!.:64@;6$@;F]W>6-H('=I861O;6^V8VDN
M`$YI92!M82"_861N>6-H(&1O<W3J<&YY8V@@;W!C:FDN`%=Y<W2Q<&FS('!R
M;V)L96T@<')Z>2!D;V1A=V%N:74@(B5S(B!D;R!S>7-T96UU.B`E<P!7>7-T
ML7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@9&%N>6-H(&1L82!UOWET:V]W
M;FEK82`B)7,B('<@<WES=&5M:64Z(`!7>7-TL7!ILR!P<F]B;&5M('!O9&-Z
M87,@=WEM87IY=V%N:6$@)7,N($]T;R!C;R!O9'!O=VEE9'II8;,@<V5R=V5R
M`%=Y<W2Q<&FS('!R;V)L96T@<&]D8WIA<R!W>6UA>GEW86YI82!S:W)Z>6YK
M:2X@4V5R=V5R('IW<O-C:;,@;V1P;W=I962\.B`E<P!7>7-TL7!ILR!P<F]B
M;&5M('!O9&-Z87,@=WEM87IY=V%N:6$@<VMR>GEN:VD@<&]C>G1O=V5J+B!/
M=&\@8V\@<&]W:65D>FEALR!S97)W97(`5WES=+%P:;,@<')O8FQE;2!P<GIY
M('5S=7=A;FEU("(E<R(@>B!S>7-T96UU+@!7>7-TL7!ILR!P<F]B;&5M('!R
M>GD@=6%K='5A;&YI86YI=2`B)7,B.B`E<P!7>7-TL7!ILR!BL[%D('!O9&-Z
M87,@:V]P:6]W86YI82!W:6%D;VUOMF-I('H@(B5S(B!D;R`B)7,B+B!397)W
M97(@>G=R\V-ILR!O9'!O=VEE9+P`5WES=+%P:;,@8K.Q9"!P;V1C>F%S('5S
M=7=A;FEA('=I861O;6^V8VD@>B!F;VQD97)A("(E<R(N(%-E<G=E<B!Z=W+S
M8VFS(&]D<&]W:65DO`!7>7-TL7!ILR!BL[%D('!O9&-Z87,@=7-U=V%N:6$@
M=VEA9&]M;[9C:2!W(&9O;&1E<GIE("(E<R(N(%-E<G=E<B!Z=W+S8VFS(&]D
M<&]W:65DO`!7>7-TL7!ILR!BL[%D('!O9&-Z87,@=7-U=V%N:6$@=VEA9&]M
M;[9C:2X@4V5R=V5R('IW<O-C:;,@;V1P;W=I962\.B`E<P!7>7-TL7!ILR!B
ML[%D('!O9&-Z87,@=7-U=V%N:6$@=VEA9&]M;[9C:2X@4V5R=V5R('IW<O-C
M:;,@;V1P;W=I962\.B`E<P!7>7-TL7!ILR!BL[%D('!O9&-Z87,@=WFV=VEE
M=&QA;FEA('1E:B!C>NJV8VD@=VEA9&]M;[9C:0!7>7-TL7!ILR!BL[%D('!O
M9&-Z87,@;WIN86-Z86YI82!W:6%D;VUOMF-I('<@9F]L9&5R>F4@(B5S(BX@
M4V5R=V5R('IW<O-C:;,@;V1P;W=I962\`%=Y<W2Q<&FS(&*SL60@<&]D8WIA
M<R!I;7!O<G1O=V%N:6$@)7,N`%=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!I;7!O
M<G1O=V%N:6$@>F1A<GIE;FEA("5S+@!7>7-TL7!ILR!BL[%D('!O8WIA<R!I
M;7!O<G1O=V%N:6$@9&%N>6-H(&E#86QE;F1A<BX`5WES=+%P:;,@8K.Q9"!P
M;V1C>F%S(&EM<&]R=&]W86YI82!Z861A;FEA("5S+@!7>7-TL7!ILR!BL[%D
M('!O9&-Z87,@:6UP;W)T;W=A;FEA(&EN9F]R;6%C:FD@*'=O;&YY+WIA:NIT
M>2D@;R!UOWET:V]W;FEK=3H@)7,N`%=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!P
M<GIE;F]S>F5N:6$@=VEA9&]M;[9C:2!Z(&9O;&1E<G4@(B5S(B!D;R`B)7,B
M+B!397)W97(@>G=R\V-ILR!O9'!O=VEE9+P`5WES=+%P:;,@8K.Q9"!P;V1C
M>F%S('IA<&ES>7=A;FEA('-Z:VEC=2X`5WES=+%P:;,@8K.Q9"!P;V1C>F%S
M('=Y<WFS86YI82!W:6%D;VUOMF-I(#HE<P!7>7-TL7!ILR!BLV%D('!O9&-Z
M87,@86MT=6%L:7IA8VII('ID87)Z96YI83H@)7,N`$)R86L@=&5K<W1U('<@
M<&]L=2!W:6%D;VUOMF-I`%=I861O;6^VYB!W(&9O<FUA8VEE($A434P@>F%W
M:65R82!P;&EK:2!G<F%F:6-Z;F4N`%=I861O;6^VYB!W(&9O<FUA8VEE($A4
M34P@>F%W:65R82!P;&EK:2!G<F%F:6-Z;F4N($)L;VMO=V%N92!O8G)A>FMI
M('!O9&]B;F\@9&\Z(`!4=_-J('!U8FQI8WIN>2!K;'5C>B!01U`@>F]S=&&S
M('IAL[%C>F]N>2!D;R!W:6%D;VUOMF-I+@!482!O<&5R86-J82!N:64@:F5S
M="!O8G.S=6=I=V%N82X`5&$@;W!C:F$@;FEE(&IE<W0@:F5S>F-Z92!Z8;.Q
M8WIO;F$N`%!L:6L@;FEE('=Y9VRQ9&$@;F$@<&]P<F%W;F4@87)C:&EW=6T@
M4D%2+@!0;&EK(&YI92!W>6=LL61A(&YA('!O<')A=VYE(&%R8VAI=W5M(%I)
M4"X`5&\@<&]L92!J97-T('=Y;6%G86YE+@!4;R!P;VQE(&UU<VD@8GGF('!O
M<')A=VZQ(&QI8WIBL2X`5&\@;6^_92!Z86JQYB!T<F]C:.H@8WIA<W4N($-H
M8V5S>B!K;VYT>6YU;W=AYC\`5&\@:F5S="!W:6%D;VUOMN8@>F%W:65R86JQ
M8V$@<&QI:R!-86-I;G1O<V@N`%1A('=I861O;6^VYB!Z87=I97)A('IAL[%C
M>FYI:RP@:W3S<GD@:F5S="!P;V1P:7-A;GD@<')Z97H@4R]-24U%+@!482!W
M:6%D;VUOMN8@>F%W:65R82!Z8;.Q8WIN:6LL(&MT\W)Y(&IE<W0@>F%K;V1O
M=V%N>2!P<GIE>B!3+TU)344N`%1A('=I861M;[;F('IA=VEE<F$@=VEA9&]M
M;[;F(&EN9F]R;6%C>6INL2!O('-T871U<VEE(&1O<W1A<F-Z96YI82`H9&5L
M:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N*2P@86QE(&9O<FUA="!W:6%D;VUO
MMF-I(&IE<W0@;FEE>FYA;GDN`%1A('=I861O;6^V8R!N:64@=WEG;+%D82!N
M82!P;W!R87=NL2!W:6%D;VUOMN8@:V]D;W=A;K$@<')Z97H@4$=0+B!"L[%D
M.B``5&$@=VEA9&UOMN8@;FEE('=Y9VRQ9&$@;F$@<&]P<F%W;GD@9F]R;6%T
M(%!'4"`H>F=O9&YI92!Z(%)&0R`R,#$U*2X`5&$@=VEA9&]M;[;F(&YI92!W
M>6=LL61A(&YA('!O<')A=VYY(&9O<FUA="!3+TU)344N`%1A('=I861O;6^V
MYB!Z;W-T8;-A('!O9'!I<V%N82!C>69R;W=O('IA('!O;6]CL2!01U`N`%1A
M('=I861O;6^VYB!Z;W-T8;-A('!O9'!I<V%N82!C>69R;W=O('IA('!O;6]C
ML2!3+TU)344N`%1A('=I861O;6^VYB!Z;W-T8;-A('IA:V]D;W=A;F$@>F$@
M<&]M;V.Q(%,O34E-12X`5&$@=VEA9&]M;[9C('IO<W1ALV$@>F%K;V1O=V%N
M82!Z82!P;VUO8[$@4$=0+@!7:6%D;VUOMN8@9&\`5VEA9&]M;[;F('IO<W1A
MLV$@;F%P:7-A;F$@=R!I;FYE:B!N:;\@='=O:F$@<W1R;VYI92!K;V1O=V5J
M("@E<RDN`%1E;B!S97)W97(@;FEE('!O=')A9FD@<F]Z<&%K;W=Y=V'F(&%R
M8VAI=_-W('II<"!I(&=Z:7`N`%1E;B!S97)W97(@;FEE(&]B<[-U9W5J92!U
M9&]S=.IP;FEA;FEA(&9O;&1E<O-W+@!4;R!O:VYO(&UU<VD@>F]S=&'F('=Y
M=V^S86YE('!R>F5Z(&]K;F\@:V]M<&]Z>71O<F$@=VEA9&]M;[9C:2X`4&]D
M9VRQ9"!WL71K=0!#>F%S`$9O<FUA="!C>F%S=0!4>71ULP!$;P!.82!A9')E
M<P!!8GD@=WEB<F'F('=I96QO:W)O=&YE('!O;&$@<')Z>71R>GEM86H@0V]N
M=')O;"`H4$,I(&QU8B!#;VUM86YD("A-86,@<&]D8WIA<R!K;&EK86YI82X`
M06)Y('=Y8G)AYB!W:65L;VMR;W1N92!P;VQA('!R>GET<GIY;6%J('!R>GEC
M:7-K($-T<FP@*%!#*2!L=6(@0V]M;6%N9"`H36%C*2!P;V1C>F%S(&ML:6MA
M;FEA+@!$>FFV`%1O9V\`5&]K96QA=0!*=71R;P!4;VYG80!2;WIM:6%R('=S
M>GES=&MI8V@@>F&SL6-Z;FEK\W<Z`$9O;&1E<B!K;W-Z80!&;VQD97(@:V]S
M>F$Z`%1R>6YI9&%D(&D@5&]B86=O`%!R87=D82!L=6(@9F&S<WH`5'5N97IJ
M80!4=7)C:F$`5'5R96-K:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U
M=F%L=0!54DP`55),.@!59V%N9&$`56MR86EN80!"L[%D('!O9&-Z87,@>FUI
M86YY(&1O("5S+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@4U%,+@!"L[%D('!O9&-Z87,@<F]Z<&%K;W=Y=V%N:6$@9&%N>6-H+@!.
M:64@;6^_;&EW92!S<')A=V1Z96YI92!P;VIE;6YOMF-I(&MO;G1A`$YI92!M
M;[]N82!P<GIE=+-U;6%C>GGF('1E9V\@9&]K=6UE;G1U(%=O<F0M80!"97H@
M;V1P;W=I961Z:0!7:6%D;VUOMF-I(&)E>B!O9'!O=VEE9'II`$]D='?S<GH`
M3FEE=6IA=VYI96YI(&%D<F5S86-I`$-O9FYI:B!Z;6EA;GD`3FEE(&]B<[-U
M9VEW86YY(&MO;7!O;F5N="!T>7!U.B`E<P!::F5D;F]C>F]N92!%;6ER871Y
M($%R86)S:VEE`%=I96QK82!"<GET86YI80!54T$`3FEE>FYA;F4`3FEE>FYA
M;F$@9&%T80!.:65Z;F%N92!S<&]T:V%N:64`3FEE>FYA;GD@861R97-A=`!5
M<W7Q(&AA<[-O`$)E>B!N87IW>0!.:65W:61Z:6%N90!5<W7Q('-U8G-K<GEP
M8VKJ('H@9F]L9&5R80!.:65O8G.S=6=I=V%N92!R;WIS>F5R>F5N:64`56%K
M='5A;&YI:@!586MT=6%L;FEJ(&EN9F]R;6%C:F4@;R!Z8;.Q8WIN:6MU`%5A
M:W1U86QN:6H@<W1A='5S(&]D<&]W:6%D86JQ8V5G;P!:8;-A9'5J`%5R=6=W
M86H`5;]Y:B!D;VUYMFQN96H@=V%R=&^V8VD`5;]YYB!S=6)S:W)Y<&-J:2!F
M;VQD97)U($E-05`_`%6_>71K;W=N:6L`5;]Y=&MO=VYI:R`B)7,B('!R87=I
M9+-O=V\@>F1E9FEN:6]W8;,@<')A=V$@9&]S=.IP=2!D;R!F;VQD97)A("(E
M<R(N`$]P8VIE('6_>71K;W=N:6MA`%)E:F5S=')A8VIA('6_>71K;W=N:6MA
M`$YA>G=A('6_>71K;W=N:6MA`%6_>71K;W=N:6L@;R!N87IW:64@(B5S(B!J
M=;\@:7-T;FEE:F4N`$YA>G=A('6_>71K;W=N:6MA.@!.87IW82!UOWET:V]W
M;FEK83H@`%6_>71K;W=N:6-Y('<@<WES=&5M:64Z`%5Z8F5K:7-T86X`5V%K
M86-J90!686YU871U`%=E;F5Z=65L80!797)S:F$`5VEE=&YA;0!7:61O:P!7
M:61O:R`E<P!7>;9W:65T;"`E<R!K;'5C>B!P=6)L:6-Z;GD`5WFV=VEE=&P@
M>F%W87)T;[;F($A434P@=R!O<V]B;GEM(&]K;FEE`%=YMG=I971L(&]S;V)I
M<W1Y(&ML=6-Z('!R>7=A=&YY`%=YMG=I971L(&]S;V)I<W1Y(&ML=6-Z('!U
M8FQI8WIN>0!7>;9W:65T;"!WL71E:P!7>;9W:65T;"!M:6YI871U<FOJ`%!O
M:V&_('-T<F]NZB!75U<`4&]K8;\@:F%K;R`E<P!7>;9W:65T;"!Z8;.Q8WIN
M:6L@=R!O<V]B;GEM(&]K;FEE`%=YMG=I971L('IA=V%R=&^VYB!W(&]S;V)N
M>6T@;VMN:64`5WFV=VEE=&P@>F1A<GIE;FEE`%=YMG=I971L96YI92!W:6%D
M;VUOMF-I('<@)7,`5VED;VL@;'5B('-K<GIY;FMA(&1O('!O:V%Z86YI82!P
M;R!L;V=O=V%N:74Z`%=YMG=I971L('IA9&%N:64`4&]K87IU:B!P;&EK:2!G
M<F%F:6-Z;F4`0G)Y='EJ<VMI92!7>7-P>2!$>FEE=VEC>F4`5WES<'D@1'II
M97=I8WIE(%-T86[S=R!::F5D;F]C>F]N>6-H`%=I<G1U86QN>2!F;VQD97(@
M(B5S(B!Z;W-T8;,@=71W;W)Z;VYY+@!7:7)T=6%L;F4@9F]L9&5R>0!7:7)T
M=6%L;F4@9F]L9&5R>2!W>6UA9V%JL2!E='EK:65T>2X`171Y:VEE=&$@=VER
M='5A;&YE9V\@9F]L9&5R=0!786QL:7,@:2!&=71U;F$`3W-T<GIEOV5N:64`
M5U=7`$-O('1Y9'II9?$`5VET86UY`%=I=&%M>2!W("5S`%=I=&%M>2P@)7,`
M6F%C:&]D;FD@*$E33RTX.#4Y+3$I`%IA8VAO9&YI("A)4T\M.#@U.2TQ-2D`
M4V%H87)A(%IA8VAO9&YI80!*86NQ(&%P;&EK86-JZB!M82`E<R!W>;9W:65T
M;&'F('!O('IA;&]G;W=A;FEU('-IZC\`2VEE9'D@=7-U=V%S>B!W:6%D;VUO
MMF-I+"!P<GIE;FEEMB!J92!D;R!K;W-Z82!Z86UI87-T('IA>FYA8WIA;FEA
M(&EC:"!J86MO('5S=6YIZG1E+@!+:65D>2!O='=O<GIY<WH@;F]WL2!S:W)Z
M>6YKZBP@:W3S<K$@<W1R;V[J(&-H8V5S>B!U<G5C:&]M:>8_`$MI961Y('IA
M<&ES=6IE<WH@=R!W:6%D;VUOMF-I+7=Y<[-A;F4L('!O=VEN:65N96T@>F%P
M:7-Y=V'F('IAL[%C>FYI:VD_`$IA:VEE('=T>6-Z:VD@86MT>7=O=V'F('<@
M4F]Z8G5D;W=A;GEM(&5D>71O<GIE('1E:W-T=2X`0FEALV$@;&ES=&$`4WIE
M<F]K;[;F(&QE=V5G;R!M96YU("5S("AZ;6EA;F$@>F%C>FYI92!O8F]W:;%Z
M>7=AYB!P<GIY(&YA<W3J<&YY;2!L;V=O=V%N:74I.@!!9')E<R!D;R!P<F%C
M>0!496PN(&1O('!R86-Y`%IA=VGQ('1E:W-T('!O('1E:B!L:6-Z8FEE('IN
M86OS=RX`4E(`4E)24@!#;R!R;VL`2F5M96X`5&%K`%1A:RP@>F=A9'IA;2!S
M:>H`4&]B:65R87-Z('=I861O;6^V8VD@>B!N87-TZG!U:K%C>6-H(&MO;G0Z
M`%!R\V)U:F5S>B!U<W5NL>8@=W-Z>7-T:VEE('=I861O;6^V8VD@=R!N87-T
MZG!U:K%C>6-H(&9O;&1E<F%C:"X`4'+S8G5J97-Z('5S=6ZQYB!N87-TZG!U
M:K%C92!F;VQD97)Y+@!+;W!I=6IE<WHO<')Z96YO<VES>B!D;R!N;W=E9V\@
M9F]L9&5R=2X`5'=O<GIY<WH@;F]W>2!P;V1F;VQD97(@=R``5'=O<GIY<WH@
M9F]L9&5R('=YOW-Z>2X`6FUI96YI87-Z(&YA>G?J(&9O;&1E<F]W:3H@`$YI
M92!Z9V]D>FFS9;8@<VGJ('H@=V%R=6YK86UI(%1O4RP@=VGJ8R!N:64@;6^_
M97-Z('-IZB!Z86QO9V]W8>8N`$YI92!M87-Z('!R87<@86)Y('IM:65N:>8@
M=7!R87=N:65N:6$@9&QA('1E9V\@9F]L9&5R80!0<GIE:V%Z=6IE<WH@=+$@
M=VEA9&]M;[;F("4E<R!D;R!N87-TZG!U:K%C>6-H(&%D<F5S873S=SH@)7,N
M`$UA<WH@)7,@;F]W>6-H('=I861O;6^V8VDN`$UA<WH@,2!N;W>Q('=I861O
M;6^VYBX`36%S>B!W>6)R86YY('!R>GEN86IM;FEE:B!J961E;B!Z8;.Q8WIN
M:6LL(&%L92!J97-Z8WIE(+]A9&YE9V\@;FEE(&1OL[%C>GFS9;8N(%=Y<[-A
MYB!TZB!W:6%D;VUOMN8@8F5Z('IAL[%C>FYI:_-W/P!7>6QO9V]W8;-EMB!S
M:>HN`$UA<WH@;F]WL2!P;V-Z=.H@=R!N87-TZG!U:K%C>6T@9F]L9&5R>F4Z
M`$UA<WH@;F]WL2!P;V-Z=.H@=R!N87-TZG!U:K%C>6-H(&9O;&1E<F%C:#H`
M375S:7-Z(&]P:7-AYB!P<F]B;&5M('IA;FEM(&=O('=YMFQE<WHN`$UU<VES
M>B!W<')O=V%D>FGF('!R>GEN86IM;FEE:B!J961N96=O(&%D<F5S871A+@!-
M=7-I<WH@=W!R;W=A9'IIYB!H87.S;R!D;&$@<W=O:F5G;R!P<GEA=&YE9V\@
M:VQU8WIA(%!'4"!A8GD@=WFV=VEE=&QIYB!TL2!W:6%D;VUOMN8`375S:7-Z
M('=P<F]W861Z:>8@:&%SLV\@9&QA('-W;VIE9V\@<')Y871N96=O(&ML=6-Z
M82!3+TU)344@86)Y('=YMG=I971L:>8@=+$@=VEA9&]M;[;F`$UU<VES>B!N
M86IP:65R=R!W>6)R8>8@9&]C96QO=[$@<VMR>GEN:^HN`$UU<VES>B!W>6)R
M8>8@:V]N=&\@9&\@=7-U;FGJ8VEA+@!-=7-I<WH@;F%J<&EE<G<@=WEB<F'F
M(&%D<F5S+@!-=7-I<WH@;F%J<&EE<G<@=WEB<F'F('!R>GEN86IM;FEE:B!J
M961NL2!W:6%D;VUOMN8N`$UU<VES>B!Z9&5F:6YI;W=AYB!A9')E<V%T82X`
M375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U
M<W5NL>8N`$UU<VES>B!Z9&5F:6YI;W=AYB!P<GIY;F%J;6YI96H@:F5D96X@
M<&QI:R!D;R!D;[.Q8WIE;FEA+@!-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI
M:V$L(&MT\W)E9V\@8VAC97-Z(&1O9&'F+@!0<GIE:VEE<F]W8;-EMB!W:6%D
M;VUOMN8@9&\@)7,@;F$@)25S+@!/9'!O=VEE9'II8;-EMB!N82!TZB!W:6%D
M;VUOMN8@9&YI82`E<RX`5'=O:F$@<W5B<VMR>7!C:F$@=R`B)7,B(&YI92!Z
M;W-T8;-A(&%K='EW;W=A;F$N(%-E<G=E<B!Z=W+S8VFS(&]D<&]W:65DO`!4
M=V]J82!S=6)S:W)Y<&-J82!W("(E<R(@;FEE('IO<W1ALV$@86YU;&]W86YA
M+B!397)W97(@>G=R\V-ILR!O9'!O=VEE9+P`6F]S=&&S9;8@<W5B<VMR>6)O
M=V%N>2!D;R`B)7,B`%1W;VIA('-U8G-K<GEP8VIA('IO<W1ALV$@=7-U;FGJ
M=&$@>B`B)7,B`%1W\VH@861R97,@92UM86EL`%1W\VH@861R97,@3V0Z`%1W
M;VIE(&EN9F]R;6%C:F4`5'?S:B!A9')E<R!I;G1E<FYE=&]W>2!S:>H@>FUI
M96YILR!O9"!P;V-ZL71K=2!S97-J:2`E<RX@5R!Z=VFQ>FMU('H@8F5Z<&EE
M8WIE\7-T=V5M(%1W;VIE9V\@:V]N=&$@;75S:7-Z('IA;&]G;W=AYB!S:>H@
M<&]N;W=N:64N`%1W;VIA(&YA>G=A`%1W;VIE('!U8FQI8WIN92]P<GEW871N
M92!K;'5C>F4@4$=0`%1W\VH@:VQU8WH@<')Y=V%T;GD`5'?S:B!K;'5C>B!P
M=6)L:6-Z;GD`5'=O:F$@3V1P;W=I962\+61O.B!A9')E<SH@/&D^*&]P8VIO
M;F%L;FEE*3PO:3X`5'=O:F4@<'5B;&EC>FYE+W!R>7=A=&YE(&ML=6-Z92!3
M+TU)344`5'=O:F4@:V]N=&$Z`%1W;VIE(&%L:6%S>2!A9')E<W4Z(#QI/BAO
M<&-J;VYA;&YI92P@=W!R;W=A9+P@:V&_9'D@861R97,@=R!N;W=E:B!L:6YI
M*3PO:3X`5&5N('-Y<W1E;2!A=71E;G1Y:V%C:FD@;FEE(&]B<[-U9W5J92!D
M;V1A=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@=&$@;W!C:F$@>F]S=&&S82!W
M>;.Q8WIO;F$N`%1E;B!S>7-T96T@875T96YT>6MA8VII(&YI92!O8G.S=6=U
M:F4@;&ES=&]W86YI82!UOWET:V]W;FEK\W<L(&QU8B!T82!O<&-J82!Z;W-T
M8;-A('=YL[%C>F]N82X`5'=O:F$@<')Z96=LL61A<FMA(&YI92!O8G.S=6=U
M:F4@=WFV=VEE=&QA;FEA('!L:6OS=R!G<F%F:6-Z;GEC:"!T96=O('1Y<'4N
M`%1W;VIA('!R>F5G;+%D87)K82!N:64@;V)SLW5G=6IE('1E:B!O<&-J:2!D
M<G5K;W=A;FEA+B!.86IC:;9N:6H@0W1R;"]/<&-J82`K(%`@86)Y('=Y9')U
M:V]W8>8N`%1W;VIA(&]B96-N82!S=')E9F$@8WIA<V]W83H`1&]M>;9L;GD@
M=6NS860@>FYA:_-W(&1L82!W>7-YLV%N>6-H('=I861O;6^V8VDZ`$1O;7FV
M;&YA(&UE=&]D82!K;V1O=V%N:6$@=WES>;-A;GEC:"!W:6%D;VUOMF-I.@!$
M;VUYMFQN82!T;[]S86UOMN8Z`%1W;VIE('!ELVYE(&EM:>H@:2!N87IW:7-K
M;SH`5'=O:F$@=VEA9&]M;[;F('IO<W1ALV$@9&]S=&%R8WIO;F$N`%1W;VEM
M(&YO=WEM(&AA<[-E;2!W("5S(&IE<W0Z("5S`%1W;VIE('5S=&%W:65N:6$@
M>F]S=&&S>2!U86MT=6%L;FEO;F4@;F$@8WIA<R!T<G=A;FEA('1E:B!S97-J
M:2X`5'=O:F4@=7-T87=I96YI82!Z;W-T8;-Y('5A:W1U86QN:6]N92X`5'=O
M:F4@>F1A;&YE('-E<G=E<GDZ`%1W\VH@<&]D<&ES.@!*=6=O<[-A=VEA`%IA
M:7(`6F%M8FEA`%II;6)A8G=E`%MB<F%K('1E;6%T=5T`6U)A<&]R="!O('!R
M;V)L96UI95T`7T%D;6EN:7-T<F%C:F$`7T)C8P!#>F%R;F$@;&ES=&$@*%]B
M*0!?0TQ)`%]#8P!4=_-R>B`H7V,I`%5S=?$@*%]D*0!?57-U\2!W:65R<WH`
M7T9O;&1E<GD`7T=R=7!Y`%]0;VUO8P!4;[]S86UOMN8@*%]I*0!/9&5B<F%N
M92`H7VDI`%]:86QO9W5J`%=Y7VQO9W5J`*QR\V2S;R!W:6%D;U]M;[9C:0!:
M;6EE\2!L:6YK+BXN`%]/<&-J90!?57!R87=N:65N:6$`1')U:W5J("A?<"D`
M7U!R:6]R>71E=`!/9+9W:66_("5S("A?<BD`57-U\2!L:6YK+BXN`$]D<&]W
M:65D>B`H7W(I`%]3>G5K86H`5WFV;&EJ('=I861O;6^VY@!?2V]N9FEG=7)A
M8VIA`%>Q7W1E:P!$;R`H7W0I`$]D='?S<GH@*%]U*0!?5;]Y=&MO=VYI8WD`
M5WFV=VEE=&P@=[%T96L@*%]V*0!":6&S82!L:7-T82`H7W<I`&MS:;&_:V$@
M861R97-O=V$`>F&SL6-Z;FEK`'IAL[%C>FYI:VDN>FEP`&)A:G3S=P!K86QE
M;F1A<GH`<&QI:P!O9`!K;'5C>@!P;&EK('-K<GIY;FMI`&YA>G=A`+]A9&5N
M`&YO=&%T;FEK`&QU8@!BL[%D('!I<V]W;FD`8K/J9'D@<&ES;W=N:0!B97H@
M;F%Z=WD`=D-A<F0`='=O:F$@8WIA<FYA(&QI<W1A`'1W;VIA(&)I8;-A(&QI
M<W1A````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+W!L7U!,+VAE;'`N>&UL````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3(V-#0W`#$P-#$W,S8R
M-S8S`#`R,3$T-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&EM
M<"]L;V-A;&4O<&Q?4$PO:&5L<"YX;6PL=B`Q+C$V+C8N-"`R,#`V+S`Q+S,P
M(#$U.C4W.C4X(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)C
M;VUP;W-E+6)U='1O;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-
M97-S86=E($-O;7!O<VET:6]N.B!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D
M:6YG/D%C=&EO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@365S
M<V%G92!L875N8VAE<R!Y;W5R(&5M86EL('1O('1H92!I;G1E;F1E9"!R96-I
M<&EE;G0H<RDN($)E('-U<F4@>6]U('=A;G0@=&\@<V5N9"!B969O<F4@8VQI
M8VMI;F<@:&5R92!A<R!O;F-E('-E;G0@:70@8V%N;F]T(&)E('1A:V5N(&)A
M8VLN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-A=F4@1')A9G0@<&QA
M8V5S(&%N('5N9FEN:7-H960@;65S<V%G92!I;B!A(&9O;&1E<B!C86QL960@
M)T1R869T<R<*86-C97-S:6)L92!B>2!T:&4@<&]P+61O=VX@8F]X(&]N('1H
M92!R:6=H="!S:61E(&]F('1H92!B;'5E(&YA=FEG871I;VX@8F%R(&%T('1O
M<"X@66]U(&-A;B!T:&5N(&9I;FES:"!T:&4@;65S<V%G92!L871E<B!B>2!S
M=VET8VAI;F<@=&\@=&AE("=$<F%F=',G(&9O;&1E<BP@8VQI8VMI;F<@;VX@
M=&AE('-A=F5D(&UE<W-A9V4@=&\@;W!E;B!I="P@86YD('1H96X@8VQI8VMI
M;F<@;VX@)U)E<W5M92<N($)E('-U<F4@=&\@<'5T(&$@<W5B:F5C="!O;B!T
M:&4@96UA:6P@8F5F;W)E('EO=2!S879E('1H92!D<F%F="!S;R!T:&%T('EO
M=2!C86X@96%S:6QY(&ED96YT:69Y('=H:6-H(&UE<W-A9V4@>6]U('=A;G0@
M=VET:&EN('1H92!$<F%F=',@9F]L9&5R+B!!9G1E<B!S879I;F<@87,@82!$
M<F%F="P@>6]U(&%R92!R971U<FYE9"!T;R!Y;W5R($E.0D]8(&]R('=H871E
M=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@($-A;F-E;"!-97-S86=E(&1R;W!S('1H92!M97-S
M86=E(&EN('!R;V=R97-S(&%N9"!S:6UP;'D@<F5T=7)N<R!Y;W4@=&\@=&AE
M($E.0D]8(&]R('=H871E=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA
M<W0N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)C;VUP;W-E+6)U='1O;G,B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^06-T:6]N<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5N9"!-97-S86=E(&QA=6YC:&5S
M('EO=7(@96UA:6P@=&\@=&AE(&EN=&5N9&5D(')E8VEP:65N="AS*2X@0F4@
M<W5R92!Y;W4@=V%N="!T;R!S96YD(&)E9F]R92!C;&EC:VEN9R!H97)E(&%S
M(&]N8V4@<V5N="!I="!C86YN;W0@8F4@=&%K96X@8F%C:RX*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@4V%V92!$<F%F="!P;&%C97,@86X@=6YF:6YI
M<VAE9"!M97-S86=E(&EN(&$@9F]L9&5R(&-A;&QE9"`G1')A9G1S)PIA8V-E
M<W-I8FQE(&)Y('1H92!P;W`M9&]W;B!B;W@@;VX@=&AE(')I9VAT('-I9&4@
M;V8@=&AE(&)L=64@;F%V:6=A=&EO;B!B87(@870@=&]P+B!9;W4@8V%N('1H
M96X@9FEN:7-H('1H92!M97-S86=E(&QA=&5R(&)Y('-W:71C:&EN9R!T;R!T
M:&4@)T1R869T<R<@9F]L9&5R+"!C;&EC:VEN9R!O;B!T:&4@<V%V960@;65S
M<V%G92!T;R!O<&5N(&ET+"!A;F0@=&AE;B!C;&EC:VEN9R!O;B`G4F5S=6UE
M)RX@0F4@<W5R92!T;R!P=70@82!S=6)J96-T(&]N('1H92!E;6%I;"!B969O
M<F4@>6]U('-A=F4@=&AE(&1R869T('-O('1H870@>6]U(&-A;B!E87-I;'D@
M:61E;G1I9GD@=VAI8V@@;65S<V%G92!Y;W4@=V%N="!W:71H:6X@=&AE($1R
M869T<R!F;VQD97(N($%F=&5R('-A=FEN9R!A<R!A($1R869T+"!Y;W4@87)E
M(')E='5R;F5D('1O('EO=7(@24Y"3U@@;W(@=VAA=&5V97(@9F]L9&5R('EO
M=2!W97)E('9I97=I;F<@;&%S="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@0V%N8V5L($UE<W-A9V4@9')O<',@=&AE(&UE<W-A9V4@:6X@<')O9W)E
M<W,@86YD('-I;7!L>2!R971U<FYS('EO=2!T;R!T:&4@24Y"3U@@;W(@=VAA
M=&5V97(@9F]L9&5R('EO=2!W97)E('9I97=I;F<@;&%S="X*("`@(#PO<&%R
M83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UF
M<F]M(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@1G)O;3PO=&ET;&4^"B`@("`\:&5A9&EN9SXB1G)O;2(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('EO=7(@8V]R<F5C="!E;6%I
M;"!A9&1R97-S+B!9;W5R(&5M86EL(&%D9')E<W,@:7,@875T;VUA=&EC86QL
M>2!E;G1E<F5D(&9O<B!Y;W4@9F]L;&]W:6YG(")&<F]M.B(@:6X@;W5T9V]I
M;F<@96UA:6PN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N
M=')Y(&ED/2)C;VUP;W-E+69R;VTB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ($9R;VT\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[1G)O
M;29Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@>6]U<B!C
M;W)R96-T(&5M86EL(&%D9')E<W,N(%EO=7(@96UA:6P@861D<F5S<R!I<R!A
M=71O;6%T:6-A;&QY(&5N=&5R960@9F]R('EO=2!F;VQL;W=I;F<@)G%U;W0[
M1G)O;3HF<75O=#L@:6X@;W5T9V]I;F<@96UA:6PN"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M=&\B('-T
M871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N
M.B!4;SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB5&\B/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S
M*2!O9B!T:&]S92!T;R!R96-E:79E('EO=7(@;65S<V%G92X@66]U(&UU<W0@
M<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@<'5N
M8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT<GD@
M9F]L;&]W<R`B5&\Z(B!I;B!O=71G;VEN9R!M86EL+B`@"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+71O(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!4;SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SXF<75O=#M4;R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@
M=&AO<V4@=&\@<F5C96EV92!Y;W5R(&UE<W-A9V4N(%EO=2!M=7-T('-E<&%R
M871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R('!U;F-T=6%T
M:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N=')Y(&9O;&QO
M=W,@)G%U;W0[5&\Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN("`*("`@(#PO
M<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UC8R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ($-C/"]T:71L93X*("`@(#QH96%D:6YG/B)#8R(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D
M9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@82!C87)B;VX@8V]P>2!O
M9B!Y;W5R(&UE<W-A9V4N(%-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@
M8V]M;6$N(%EO=7(@96YT<GD@9F]L;&]W<R`B0V,Z(B!I;B!O=71G;VEN9R!M
M86EL+B!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O<&QE
M(&]T:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET=&5N('1O(&1I<F5C
M=&QY(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@;V8@=&AE(&5M86EL
M(&%S('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C=&QY(&-O;F-E<FYE
M9"!A8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN("!!;&P@)U1O.B<@
M<F5C:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C86X@<V5E('1H92!E
M;G1I<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP:65N=',N"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E
M+6-C(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!#8SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SXF<75O=#M#8R9Q=6]T.SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE
M<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&-A<F)O;B!C;W!Y(&]F('EO=7(@
M;65S<V%G92X@4V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM82X@
M66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T-C.B9Q=6]T.R!I;B!O=71G;VEN
M9R!M86EL+B!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O
M<&QE(&]T:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET=&5N('1O(&1I
M<F5C=&QY(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@;V8@=&AE(&5M
M86EL(&%S('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C=&QY(&-O;F-E
M<FYE9"!A8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN("!!;&P@)U1O
M.B<@<F5C:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C86X@<V5E('1H
M92!E;G1I<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP:65N=',N"B`@
M("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O
M;7!O<V4M8F-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@0F-C/"]T:71L93X*("`@(#QH96%D:6YG/B)"8V,B
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E
M;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@8FQI;F0@
M8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E+B!9;W4@;75S="!S97!A<F%T
M92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO
M;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S
M(")"8V,Z(B!I;B!O=71G;VEN9R!M86EL+B!";&EN9"!C87)B;VX@8V]P:65S
M(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O<&QE(&]T:&5R('1H86X@9&ER96-T
M(&%N9"!I;F1I<F5C="!R96-I<&EE;G1S("@B5&\Z(B!A;F0@(D-C.B(@<F5C
M:7!I96YT<RD@=VAO(&YE960@=&\@<F5A9"!W:&%T(&ES(&)E:6YG('=R:71T
M96X@87,@=V5L;"!7251(3U54('1H92!O=&AE<B!R96-I<&EE;G1S(&MN;W=I
M;F<@=&AA="!T:&5Y(&%R92!R96-E:79I;F<@=&AE(&5M86EL+B!4:'5S("=B
M;&EN9"<@;65A;G,@=&AA="!T:&4@:61E;G1I='D@;V8@=&AE<V4@<F5C:7!I
M96YT<R!I<R!H:61D96X@9G)O;2!A;&P@;W1H97(@<F5C:7!I96YT<R!O9B!T
M:&4@96UA:6PL(&%N9"!O;FQY('EO=2!A;F0@=&AE>2!K;F]W('1H97D@9V]T
M(&$@8V]P>2X@66]U('1Y<&EC86QL>2!U<V4@=&AI<R!T;R!T96QL(&%N(&%U
M=&AO<FET>2!F:6=U<F4@=&AA="!Y;W4@87)E('1E;&QI;F<@<V]M96]N92!S
M;VUE=&AI;F<@=VET:&]U="!A;&%R;6EN9R!T:&4@<&5R<V]N('EO=2!A<F4@
M<V5N9&EN9R!T:&4@86-T=6%L(&5M86EL('1O+@H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UB8V,B/@H@("`@
M/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($)C8SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SXF<75O=#M"8V,F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H
M;W-E('1O(')E8V5I=F4@82!B;&EN9"!C87)B;VX@8V]P>2!O9B!Y;W5R(&UE
M<W-A9V4N(%EO=2!M=7-T('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@
M8V]M;6$[(&]T:&5R('!U;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R
M<F]R+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[0F-C.B9Q=6]T.R!I;B!O
M=71G;VEN9R!M86EL+B!";&EN9"!C87)B;VX@8V]P:65S(&%R92!U<W5A;&QY
M('-E;G0@=&\@<&5O<&QE(&]T:&5R('1H86X@9&ER96-T(&%N9"!I;F1I<F5C
M="!R96-I<&EE;G1S("@F<75O=#M4;SHF<75O=#L@86YD("9Q=6]T.T-C.B9Q
M=6]T.R!R96-I<&EE;G1S*2!W:&\@;F5E9"!T;R!R96%D('=H870@:7,@8F5I
M;F<@=W)I='1E;B!A<R!W96QL(%=)5$A/550@=&AE(&]T:&5R(')E8VEP:65N
M=',@:VYO=VEN9R!T:&%T('1H97D@87)E(')E8V5I=FEN9R!T:&4@96UA:6PN
M(%1H=7,@)V)L:6YD)R!M96%N<R!T:&%T('1H92!I9&5N=&ET>2!O9B!T:&5S
M92!R96-I<&EE;G1S(&ES(&AI9&1E;B!F<F]M(&%L;"!O=&AE<B!R96-I<&EE
M;G1S(&]F('1H92!E;6%I;"P@86YD(&]N;'D@>6]U(&%N9"!T:&5Y(&MN;W<@
M=&AE>2!G;W0@82!C;W!Y+B!9;W4@='EP:6-A;&QY('5S92!T:&ES('1O('1E
M;&P@86X@875T:&]R:71Y(&9I9W5R92!T:&%T('EO=2!A<F4@=&5L;&EN9R!S
M;VUE;VYE('-O;65T:&EN9R!W:71H;W5T(&%L87)M:6YG('1H92!P97)S;VX@
M>6]U(&%R92!S96YD:6YG('1H92!A8W1U86P@96UA:6P@=&\N"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M<W5B:F5C="(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ(%-U8FIE8W0\+W1I=&QE/@H@("`@/&AE861I;F<^(E-U
M8FIE8W0B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@<W5B
M:F5C="!O9B!Y;W5R(&UE<W-A9V4N(%EO=7(@96YT<GD@9F]L;&]W<R`B4W5B
M:F5C=#HB(&EN(&]U=&=O:6YG(&UA:6PN($ME97`@:70@<VAO<G0L('-I;7!L
M92!A;F0@9&5S8W)I<'1I=F4N("!4:&4@<W5B:F5C="!L:6YE(&ES('1H92!E
M87-I97-T('=A>2!F;W(@>6]U(&%N9"!Y;W5R(&-O<G)E<W!O;F1E;G1S('1O
M(')E;65M8F5R('=H870@=V%S(&EN('1H92!E;6%I;"!A;F0@=&AU<R!I<R!V
M97)Y(&EM<&]R=&%N="!I;B!O<F=A;FEZ:6YG('EO=7(@96UA:6P@86YD(&9I
M;F1I;F<@:6UP;W)T86YT(&]N97,@;&%T97(N("!!;'-O+"!W:&5N('EO=2`G
M4F5P;'DG(&]R("=&;W)W87)D)R!A;F0@96UA:6P@=&AI<R!S=6)J96-T(&QI
M;F4@:7,@8V]P:65D(&]V97(@:6YT;R!T:&4@;F5W(&UE<W-A9V4@86YD('-O
M(&ES(&$@=F%L=6%B;&4@=V%Y(&]F('1E;&QI;F<@=VAA="!M97-S86=E<R!G
M;R!T;V=E=&AE<B!T;R!F;W)M(&$@(G1H<F5A9"(@;V8@82!C;VYV97)S871I
M;VXN("!(;W=E=F5R+"!I9B!T:&4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@8V]N
M=&%I;G,@;F5W(&ED96%S+"!Y;W4@;6%Y('=A;G0@=&\@861D('-I;7!L92!M
M;V1I9FEC871I;VYS('1O('1H92`G4W5B:F5C="<@;&EN92!S;R!T:&4@<F5C
M:7!I96YT*',I(&-A;B!F;VQL;W<@=&AE('!R;V=R97-S:6]N(&]F('1H92`B
M=&AR96%D+B(*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT
M<GD@:60](F-O;7!O<V4M<W5B:F5C="(^"B`@("`\=&ET;&4^365S<V%G92!#
M;VUP;W-I=&EO;CH@4W5B:F5C=#PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O
M=#M3=6)J96-T)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E
M<B!T:&4@<W5B:F5C="!O9B!Y;W5R(&UE<W-A9V4N(%EO=7(@96YT<GD@9F]L
M;&]W<R`F<75O=#M3=6)J96-T.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL+B!+
M965P(&ET('-H;W)T+"!S:6UP;&4@86YD(&1E<V-R:7!T:79E+B`@5&AE('-U
M8FIE8W0@;&EN92!I<R!T:&4@96%S:65S="!W87D@9F]R('EO=2!A;F0@>6]U
M<B!C;W)R97-P;VYD96YT<R!T;R!R96UE;6)E<B!W:&%T('=A<R!I;B!T:&4@
M96UA:6P@86YD('1H=7,@:7,@=F5R>2!I;7!O<G1A;G0@:6X@;W)G86YI>FEN
M9R!Y;W5R(&5M86EL(&%N9"!F:6YD:6YG(&EM<&]R=&%N="!O;F5S(&QA=&5R
M+B`@06QS;RP@=VAE;B!Y;W4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@86YD(&5M
M86EL('1H:7,@<W5B:F5C="!L:6YE(&ES(&-O<&EE9"!O=F5R(&EN=&\@=&AE
M(&YE=R!M97-S86=E(&%N9"!S;R!I<R!A('9A;'5A8FQE('=A>2!O9B!T96QL
M:6YG('=H870@;65S<V%G97,@9V\@=&]G971H97(@=&\@9F]R;2!A("9Q=6]T
M.W1H<F5A9"9Q=6]T.R!O9B!A(&-O;G9E<G-A=&EO;BX@($AO=V5V97(L(&EF
M('1H92`G4F5P;'DG(&]R("=&;W)W87)D)R!C;VYT86EN<R!N97<@:61E87,L
M('EO=2!M87D@=V%N="!T;R!A9&0@<VEM<&QE(&UO9&EF:6-A=&EO;G,@=&\@
M=&AE("=3=6)J96-T)R!L:6YE('-O('1H92!R96-I<&EE;G0H<RD@8V%N(&9O
M;&QO=R!T:&4@<')O9W)E<W-I;VX@;V8@=&AE("9Q=6]T.W1H<F5A9"XF<75O
M=#L*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UO<'1I;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET
M;&4^365S<V%G92!#;VUP;W-I=&EO;CH@3W!T:6]N<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SXB3W!T:6]N<R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H
M97-E($]P=&EO;G,@:&5L<"!Y;W4@<')E<&%R92!Y;W5R(&UE<W-A9V4N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-L:6-K(")3<&5L;"!#:&5C:R(@
M=&\@8VAE8VL@>6]U<B!S<&5L;&EN9RX*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@0VQI8VL@(D%T=&%C:&UE;G1S(B!T;R!V:65W(&%T('1H92!B;W1T
M;VT@;V8@=&AE('!A9V4@82!L:7-T(&]F(&9I;&5S(&%T=&%C:&5D('1O('1H
M:7,@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@06-T:79A
M=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O(")3879E(&-O<'DB('1O('-A
M=F4@82!C;W!Y(&]F('1H:7,@;65S<V%G92!I;B!Y;W5R(")396YT($UA:6PB
M(&9O;&1E<BX@4V%V92!C;W!I97,@;V8@:6UP;W)T86YT(&5M86EL<R!Y;W4@
M<V5N9"!S;R!T:&%T('EO=2!H879E('-O;65T:&EN9R!T;R!R969E<B!B86-K
M('1O(&QA=&5R(&%N9"!T;R!K965P(&%N(&%C8W5R871E(')E8V]R9"!O9B!W
M:&%T('=A<R!S86ED+B!792!D;R!N;W0@<F5C;VUM96YD('EO=2!S879E(&5V
M97)Y(&5M86EL('-I;F-E('1H96X@>6]U<B!D:7-K('-T;W)A9V4@<75O=&$@
M=VEL;"!B92!U<V5D('5P('%U:6-K;'D@*&5S<&5C:6%L;'D@=VAE;B!Y;W4@
M<V5N9"!A='1A8VAM96YT<RD@86YD('EO=7(@;6%I;&)O>"!W:6QL(&)E(&9U
M;&P@86YD('5N86)L92!T;R!R96-E:79E(&YE=R!I;F-O;6EN9R!E;6%I;"X@
M66]U(&-A;BP@:&]W979E<BP@='5R;B!T:&ES(&9E871U<F4@)V]N)R!A<R!Y
M;W5R(&1E9F%U;'0@=VET:"`G4')E9F5R96YC97,G(&]N('1H92!B;'5E(&YA
M=FEG871I;VX@8F%R(&%T('1O<"X@0F4@8V%R969U;"!W:&5N('5S:6YG('1H
M:7,@;6]D:69I960@9&5F875L="!A<R!Y;W4@=VEL;"!N965D('1O('!E<FEO
M9&EC86QL>2!P=7)G92!Y;W5R(")396YT($UA:6PB(&9O;&1E<B!O<B!I="!W
M:6QL(&5V96YT=6%L;'D@;6%K92!Y;W5R(&UA:6QB;W@@9G5L;"!A;F0@=6YU
M<V5A8FQE+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB8V]M<&]S92UO<'1I;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T
M.T]P=&EO;G,F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H97-E
M($]P=&EO;G,@:&5L<"!Y;W4@<')E<&%R92!Y;W5R(&UE<W-A9V4N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@($-L:6-K("9Q=6]T.U-P96QL($-H96-K
M)G%U;W0[('1O(&-H96-K('EO=7(@<W!E;&QI;F<N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@($-L:6-K("9Q=6]T.T%T=&%C:&UE;G1S)G%U;W0[('1O
M('9I97<@870@=&AE(&)O='1O;2!O9B!T:&4@<&%G92!A(&QI<W0@;V8@9FEL
M97,@871T86-H960@=&\@=&AI<R!M97-S86=E+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@
M)G%U;W0[4V%V92!C;W!Y)G%U;W0[('1O('-A=F4@82!C;W!Y(&]F('1H:7,@
M;65S<V%G92!I;B!Y;W5R("9Q=6]T.U-E;G0@36%I;"9Q=6]T.R!F;VQD97(N
M(%-A=F4@8V]P:65S(&]F(&EM<&]R=&%N="!E;6%I;',@>6]U('-E;F0@<V\@
M=&AA="!Y;W4@:&%V92!S;VUE=&AI;F<@=&\@<F5F97(@8F%C:R!T;R!L871E
M<B!A;F0@=&\@:V5E<"!A;B!A8V-U<F%T92!R96-O<F0@;V8@=VAA="!W87,@
M<V%I9"X@5V4@9&\@;F]T(')E8V]M;65N9"!Y;W4@<V%V92!E=F5R>2!E;6%I
M;"!S:6YC92!T:&5N('EO=7(@9&ES:R!S=&]R86=E('%U;W1A('=I;&P@8F4@
M=7-E9"!U<"!Q=6EC:VQY("AE<W!E8VEA;&QY('=H96X@>6]U('-E;F0@871T
M86-H;65N=',I(&%N9"!Y;W5R(&UA:6QB;W@@=VEL;"!B92!F=6QL(&%N9"!U
M;F%B;&4@=&\@<F5C96EV92!N97<@:6YC;VUI;F<@96UA:6PN(%EO=2!C86XL
M(&AO=V5V97(L('1U<FX@=&AI<R!F96%T=7)E("=O;B<@87,@>6]U<B!D969A
M=6QT('=I=&AI;B!Y;W5R($ED96YT:71Y+"!B>2!G;VEN9R!T;R!/<'1I;VYS
M+29G=#M097)S;VYA;"!);F9O<FUA=&EO;BTF9W0[161I="!Y;W5R(&ED96YT
M:71I97,N($)E(&-A<F5F=6P@=VAE;B!U<VEN9R!T:&ES(&UO9&EF:65D(&1E
M9F%U;'0@87,@>6]U('=I;&P@;F5E9"!T;R!P97)I;V1I8V%L;'D@<'5R9V4@
M>6]U<B`F<75O=#M396YT($UA:6PF<75O=#L@9F]L9&5R(&]R(&ET('=I;&P@
M979E;G1U86QL>2!M86ME('EO=7(@;6%I;&)O>"!F=6QL(&%N9"!U;G5S96%B
M;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](F-O;7!O<V4M871T86-H(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET
M;&4^365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H/"]T:71L93X*("`@(#QH
M96%D:6YG/B)!='1A8V@B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@("`@
M66]U(&UA>2!A='1A8V@@9FEL97,@=&\@>6]U<B!M97-S86=E+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^4W1E<"`Q.B!%:71H97(L('1Y<&4@=&AE('!A=&@@
M86YD(&YA;64@;V8@82!F:6QE('1H870@>6]U('=A;G0@871T86-H960@=&\@
M=&AI<R!M97-S86=E(&]R(&-L:6-K(")"<F]W<V4B(&)U='1O;B!A;F0@<V5L
M96-T('1H92!F:6QE('1O(&)E(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD(&YA
M;64@;V8@=&AA="!F:6QE(&YO=R!A<'!E87)S(&EN('1H92!!='1A8VAM96YT
M(&)O>"X@3F]W('!R;V-E960@=&\*4W1E<"`R+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^4W1E<"`R.B!#;&EC:R`B071T86-H(B!B=71T;VXN(%1H92!F:6QE
M(&YA;64@86YD('-I>F4@=VEL;"!B92!A9&1E9"!T;R!Y;W5R(&QI<W0@;V8@
M071T86-H;65N=',N(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S
M(&%N9"]O<B!S;&]W97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C
M97-S(&]F('5P;&]A9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T
M:&4@96UA:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@
M86YD(&1O(&YO="!C;&EC:R!O;B!O=&AE<B!T:&EN9W,@=VAI;&4@>6]U(&%R
M92!W86ET:6YG+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O
M=#M!='1A8V@F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=2!M
M87D@871T86-H(&9I;&5S('1O('EO=7(@;65S<V%G93L@;VYL>2!O;F4@9FEL
M92!M87D@8F4@871T86-H960@870@82!T:6UE+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^4W1E<"`Q.B!%:71H97(L('1Y<&4@=&AE('!A=&@@86YD(&YA;64@
M;V8@82!F:6QE('1H870@>6]U('=A;G0@871T86-H960@=&\@=&AI<R!M97-S
M86=E(&]R(&-L:6-K("9Q=6]T.T)R;W=S929Q=6]T.R!B=71T;VX@86YD('-E
M;&5C="!T:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N
M86UE(&]F('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N
M="!B;W@N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($1E8VED92!W
M:&5T:&5R('EO=2!W86YT('1H92!F:6QE('1O(&)E('9I97=E9"!A<R!A;B!A
M='1A8VAM96YT(&]R(&EN;&EN960@=VET:"!T:&4@<F5S="!O9B!T:&4@;65S
M<V%G92X@5&AE(')E8V5I=FEN9R!P97)S;VXH<RD@;6%I;"!R96%D:6YG('-O
M9G1W87)E(&UU<W0@8F4@86)L92!T;R!H86YD;&4@=&AE(&9I;&4@='EP92!I
M;FQI;F4[(&EF(&YO="P@=&AI<R!P87)T('=I;&P@8F4@=FEE=V5D(&%S(&%N
M(&%T=&%C:&UE;G0@:6YS=&5A9"X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T
M97`@,SH@0VQI8VL@)G%U;W0[071T86-H)G%U;W0[(&)U='1O;BX@5&AE(&9I
M;&4@;F%M92!A;F0@<VEZ92!W:6QL(&)E(&%D9&5D('1O('EO=7(@;&ES="!O
M9B!!='1A8VAM96YT<RX@4&QE87-E(&YO=&4@=&AA="!F;W(@;&%R9V4@9FEL
M97,@86YD+V]R('-L;W=E<B!);G1E<FYE="!C;VYN96-T:6]N<RP@=&AE('!R
M;V-E<W,@;V8@=7!L;V%D:6YG(&%N9"!A='1A8VAI;F<@>6]U<B!F:6QE('1O
M('1H92!E;6%I;"!M87D@=&%K92!A('=H:6QE+B!0;&5A<V4@8F4@<&%T:65N
M="!A;F0@9&\@;F]T(&-L:6-K(&]T:&5R('1H:6YG<R!W:&EL92!Y;W4@87)E
M('=A:71I;F<N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\
M96YT<GD@:60](F-O;7!O<V4M871T86-H;65N=',B('-T871E/2)U;FMN;W=N
M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8VAM96YT
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB071T86-H;65N=',B/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&ES('-E8W1I;VX@9&ES<&QA>7,@82!L:7-T
M(&]F(&9I;&5S(&%L<F5A9'D@871T86-H960@=&\@>6]U<B!M97-S86=E+B!4
M;R!$96QE=&4@86X@871T86-H960@9FEL93H*("`@(#PO<&%R83X*("`@(#QP
M87)A/E-T97`@,3H@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O
M('1H92!A='1A8VAE9"!F:6QE;F%M92!Y;W4@=V%N="!T;R!$96QE=&4N"B`@
M("`\+W!A<F$^(`H@("`@/'!A<F$^4W1E<"`R.B!#;&EC:R`B1&5L971E($%T
M=&%C:&UE;G0H<RDB+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ
M"CQE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(^"B`@("`\=&ET;&4^
M365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H;65N=',\+W1I=&QE/@H@("`@
M/&AE861I;F<^)G%U;W0[071T86-H;65N=',F<75O=#L\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1H:7,@<V5C=&EO;B!D:7-P;&%Y<R!A(&QI<W0@;V8@
M9FEL97,@86QR96%D>2!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V4N(%1O($1E
M;&5T92!A;B!A='1A8VAE9"!F:6QE.@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M4W1E<"`Q.B!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@=&AE
M(&%T=&%C:&5D(&9I;&5N86UE('EO=2!W86YT('1O($1E;&5T92X*("`@(#PO
M<&%R83X@"B`@("`\<&%R83Y3=&5P(#(Z($-L:6-K("9Q=6]T.T1E;&5T92!!
M='1A8VAM96YT*',I)G%U;W0[+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7!R:6]R:71Y(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!0<FEO<FET
M>3PO=&ET;&4^"B`@("`\:&5A9&EN9SXB4')I;W)I='DB/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!4:&ES('-E=',@=&AE(")8+5!R:6]R:71Y(B!H96%D
M97(@;VX@>6]U<B!O=71G;VEN9R!M97-S86=E+B!4:&4@(E@M4')I;W)I='DB
M('1A9R!I<R!A('-O<G0@;V8@(G!S975D;R!S=&%N9&%R9"(@=&AA="!.971S
M8V%P92P@36]Z:6QL82P@3W!E<F$L(&%N9"!/=71L;V]K(&UA:6P@8VQI96YT
M<R!A<'!E87(@=&\@86=R964@;VXN($%N>2!M86EL(&-L:65N=',@=&AA="!D
M;R!N;W0@:&%N9&QE('1H:7,@:&5A9&5R('=I;&P@<VEM<&QY(&EG;F]R92!I
M="X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M<V%V92UA='1A8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S
M<V%G92!#;VUP;W-I=&EO;CH@4V%V92!!='1A8VAM96YT<SPO=&ET;&4^"B`@
M("`\<&%R83X*("`@($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N
M=',@:6X@>6]U<B!C;VUP;W-I=&EO;B!A<F4@<V%V960@=VET:"!T:&4@;65S
M<V%G92!W:&5N('-T;W)E9"!I;B!T:&4@<V5N="UM86EL(&9O;&1E<BX@($EF
M(")997,B+"!T:&4@871T86-H;65N="!D871A('=I;&P@8F4@<V%V960N("!)
M9B`B3F\B+"!T:&4@871T86-H;65N="!D871A('=I;&P@8F4@<W1R:7!P960@
M9G)O;2!T:&4@;65S<V%G92!A9G1E<B!I="!I<R!S96YT('1O(&%L;"!R96-I
M<&EE;G1S+B`@0VAO;W-I;F<@(DYO(B!W:6QL(&AE;'`@8V]N<V5R=F4@9&ES
M:R!S<&%C92!B>2!R96UO=FEN9R`H<&]T96YT:6%L;'D@;&%R9V4I(&%T=&%C
M:&UE;G0@:6YF;W)M871I;VX@9G)O;2!T:&4@<V%V960@;65S<V%G97,N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6QI;FLM
M871T86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($QI;FL@071T86-H;65N=',\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!$971E<FUI;F5S('=H971H97(@=&AE(&%T=&%C:&UE;G1S(&EN
M('EO=7(@8V]M<&]S:71I;VX@87)E('-E;G0@87,@82!P87)T(&]F('1H92!M
M86EL(&UE<W-A9V4@;W(@=VAE=&AE<B!T:&]S92!A='1A8VAM96YT<R!A<F4@
M:V5P="!O;B!A(&QO8V%L('-E<G9E<BX@($EF(&%T=&%C:&UE;G1S(&%R92!L
M:6YK960L('1H92!R96-I<&EE;G0H<RD@;V8@>6]U<B!M97-S86=E('=I;&P@
M8F4@<')O=FED960@82!W96)L:6YK('=H97)E('1H97D@8V%N(&1O=VYL;V%D
M('1H92!A='1A8VAM96YT*',I+B`@3&EN:VEN9R!A='1A8VAM96YT<R!H87,@
M=&AE(&%D=F%N=&%G92!O9B!T<F5M96YD;W5S;'D@<F5D=6-I;F<@=&AE('-I
M>F4@;V8@;W5T9V]I;F<@;65S<V%G97,N("!,:6YK:6YG(&%T=&%C:&UE;G1S
M(&AA<R!T:&4@9&ES861V86YT86=E('1H870@=&AE(&-O;G1E;G0@;V8@=&AE
M(&%T=&%C:&UE;G1S(&-A;B!N;W0@8F4@9W5A<F%N=&5E9"!T;R!B92!A=F%I
M;&%B;&4@:6X@=&AE(&9U='5R92!S:6YC92!T:&4@871T86-H;65N="!D871A
M(&ES(&YO="!L;V-A=&5D('=I=&AI;B!T:&4@92UM86EL(&UE<W-A9V4N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S96%R8V@B('-T871E
M/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E(%-E87)C:#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY396%R8V@@0W)I=&5R:6$\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@("`@("!(96QP('1E>'0@=&\@8F4@=W)I='1E;BX*("`@(#PO
M<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G-E87)C:"(^
M"B`@("`\=&ET;&4^365S<V%G92!396%R8V@\+W1I=&QE/@H@("`@/&AE861I
M;F<^4V5A<F-H($-R:71E<FEA/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9
M;W4@;6%Y('-E87)C:"!F;W(@;65S<V%G97,@9G)O;2!Y;W5R(&9O;&1E<G,@
M=7-I;F<@9&EF9F5R96YT('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*
M("`@(#QP87)A/E-T97`@,3H@16YT97(@=&5X="!T;R!T:&4@9FEE;&1S('EO
M=2!W86YT('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C<FET97)I82X*("`@(#PO
M<&%R83X*("`@(#QP87)A/E-T97`@,CH@0VAO;W-E('1H92!M97-S86=E(&9L
M86<H<RD@=&\@861D('1O('EO=7(@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^4W1E<"`S.B!#:&]O<V4@=&AE(&9O;&1E<BAS*2!F
M<F]M('=H:6-H('1O('-E87)C:"!F;W(@=&AE(&UE<W-A9V5S+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^4W1E<"`T.B!#;&EC:R`F<75O=#M396%R8V@F<75O
M=#LN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($EF(&%N>2!M97-S86=E
M<R!M871C:&5D('EO=7(@<V5A<F-H(&-R:71E<FEA+"!T:&5N('1H92!S=6)J
M96-T<R!O9B!T:&5S92!M97-S86=E<R!W:6QL(&)E('-H;W=N(&EN('1H92`F
M<75O=#M396%R8V@@4F5S=6QT<R9Q=6]T.R!V:65W+@H@("`@/"]P87)A/@H\
M+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N
M<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M
M96YT/"]T:71L93X*("`@(#QH96%D:6YG/D9O;&1E<B!/<'1I;VYS/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("`@(%EO=2!C86X@<V5L96-T(&$@9F]L9&5R
M(&)Y('5S:6YG('1H92!R861I;R!B=71T;VYS(&%L;VYG('1H92!L969T(&-O
M;'5M;BX@($]N8V4@>6]U(&AA=F4@9&]N92!T:&ES+"!S96QE8W0@=&AE(&]P
M=&EO;B!Y;W4@=VES:"!T;R!P97)F;W)M(&]N('1H92!F;VQD97(@=FEA('1H
M92!S96QE8W0@8F]X('1O('1H92!L969T+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("`@(%EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!F=7)T:&5R(&]P
M=&EO;G,N("!"92!C87)E9G5L('=I=&@@=&AE(&1E;&5T92!O<'1I;VXL(&%S
M('EO=2!C86X@;&]S92!A;&P@=&AE(&UE<W-A9V5S(&EN(&$@9F]L9&5R(&EF
M('EO=2!D96QE=&4@:70@8GD@;6ES=&%K92$*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F9O;&1E<BUO<'1I;VYS(CX*("`@
M(#QT:71L93Y&;VQD97(@36%N86=E;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY&;VQD97(@3W!T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!9
M;W4@8V%N('-E;&5C="!A(&9O;&1E<B!B>2!U<VEN9R!T:&4@<F%D:6\@8G5T
M=&]N<R!A;&]N9R!T:&4@;&5F="!C;VQU;6XN("!/;F-E('EO=2!H879E(&1O
M;F4@=&AI<RP@<V5L96-T('1H92!O<'1I;VX@>6]U('=I<V@@=&\@<&5R9F]R
M;2!O;B!T:&4@9F]L9&5R('9I82!T:&4@<V5L96-T(&)O>"!T;R!T:&4@;&5F
M="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("!9;W4@=VEL;"!B92!P
M<F]M<'1E9"!F;W(@9G5R=&AE<B!O<'1I;VYS+B`@0F4@8V%R969U;"!W:71H
M('1H92!D96QE=&4@;W!T:6]N+"!A<R!Y;W4@8V%N(&QO<V4@86QL('1H92!M
M97-S86=E<R!I;B!A(&9O;&1E<B!I9B!Y;W4@9&5L971E(&ET(&)Y(&UI<W1A
M:V4A"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY);7!O<G0@;6)O>"!&:6QE
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%1H:7,@;W!T:6]N('=I;&P@
M:6UP;W)T(&$@;6)O>"!F;W)M870@9FEL92!I;G1O('1H92!F;VQD97(@;V8@
M>6]U<B!C:&]I8V4N($-H;V]S92`Q("AO;F4I(&9O;&1E<B!T;R!I;7!O<G0@
M=&AE(&UE<W-A9V5S(&EN=&\@86YD('1H96X@<V5L96-T('1H:7,@;W!T:6]N
M+B!9;W4@=VEL;"!T:&5N(&)E('1A:V5N('1O(&$@<&%G92!T:&%T('=I;&P@
M<')O;7!T(&9O<B!T:&4@;6)O>"!F:6QE('1O(&EM<&]R="X*("`@(#PO<&%R
M83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]L9&5R+7=I
M9&=E=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M
M96YT.B!$:7-P;&%Y/"]T:71L93X*("`@(#QH96%D:6YG/E-H;W<O2&ED92!5
M;G-U8G-C<FEB960\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('5S:6YG
M($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,L('-H;W<O:&ED92!T:&4@=6YS
M=6)S8W)I8F5D(&9O;&1E<G,N("!4;R!S=6)S8W)I8F4O=6YS=6)S8W)I8F4@
M=&\@82!F;VQD97(L('-E;&5C="!T:&4@8VAE8VMB;W@@;F5X="!T;R!T:&4@
M9F]L9&5R;F%M92!A;F0@=7-E('1H92!3=6)S8W)I8F4O56YS=6)S8W)I8F4@
M;W!T:6]N(&EN('1H92!&;VQD97(@06-T:6]N(&1R;W`M9&]W;B!M96YU+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^17AP86YD($%L;#PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@17AP86YD(&%L;"!F;VQD97(@96YT<FEE<RX*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D-O;&QA<'-E($%L;#PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0V]L;&%P<V4@86QL(&9O;&1E<B!E;G1R:65S+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R<R(@<W1A
M=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/D9I;'1E<G,Z($%P<&QY/"]T:71L
M93X*("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0VQI8VL@;VX@=&AE(")!<'!L>2!&:6QT97(B(&EC
M;VX@;F5X="!T;R!T:&4@24Y"3U@@;F%M92!I;B!T:&4@;6%I;&)O>"!V:65W
M('1O(&9I;'1E<B!A;&P@=6YD96QE=&5D(&UE<W-A9V5S(&%C8V]R9&EN9R!T
M;R!T:&4@<W!E8VEF:65D(')U;&5S+B`@3W(L(&%L=&5R;F%T979L>2P@8VQI
M8VL@;VX@(D%P<&QY($%L;"!2=6QE<R(@:6X@=&AE(&9I;'1E<B!M96YU+B`@
M3F]T92!T:&%T(&9I;'1E<FEN9R!I<R!N;W0@9&]N92!A=71O;6%T:6-A;&QY
M+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB
M9FEL=&5R<R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@07!P;'D\+W1I=&QE/@H@
M("`@/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!#;&EC:R!O;B!T:&4@)G%U;W0[07!P;'D@1FEL=&5R)G%U
M;W0[(&EC;VX@;F5X="!T;R!T:&4@24Y"3U@@;F%M92!I;B!T:&4@;6%I;&)O
M>"!V:65W('1O(&9I;'1E<B!A;&P@=6YD96QE=&5D(&UE<W-A9V5S(&%C8V]R
M9&EN9R!T;R!T:&4@<W!E8VEF:65D(')U;&5S+B`@3W(L(&%L=&5R;F%T979L
M>2P@8VQI8VL@;VX@)G%U;W0[07!P;'D@06QL(%)U;&5S)G%U;W0[(&EN('1H
M92!F:6QT97(@;65N=2X@($YO=&4@=&AA="!F:6QT97)I;F<@:7,@;F]T(&1O
M;F4@875T;VUA=&EC86QL>2X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M<G5L97,B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@1FEL=&5R(%)U;&5S/"]T
M:71L93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!&:6QT97(@4G5L97,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@9FEL
M=&5R(')U;&5S(B!T;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C
M86X@861D+"!D96QE=&4L(&%N9"!E9&ET('1H92!C=7)R96YT;'D@86-T:79E
M('-E="!O9B!F:6QT97(@<G5L97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)F:6QT97(M961I="UB;&%C:VQI<W0B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@0FQA8VML:7-T/"]T:71L93X*
M("`@(#QH96%D:6YG/D5D:70@66]U<B!";&%C:VQI<W0\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@8FQA8VML:7-T(B!T
M;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE
M=&4L(&%N9"!E9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U
M($%,5T%94R!R969U<V4@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M=VAI=&5L:7-T(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET(%=H:71E;&ES=#PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@5VAI=&5L:7-T/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R('=H:71E;&ES
M="(@=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@
M9&5L971E+"!A;F0@961I="!T:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S
M('EO=2!!3%=!65,@86-C97!T(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUO;BUL;V=I;B(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&]N($QO9VEN/"]T:71L
M93X*("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<R!5<&]N($QO9V]N
M/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@
M=&\@86QW87ES(&%P<&QY(&9I;'1E<G,@=VAE;B!F:7)S="!L;V=G:6YG(&]N
M=&\@24U0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL
M=&5R+6]N+61I<W!L87DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E
M<G,Z($9I;'1E<B!O;B!2969R97-H/"]T:71L93X*("`@(#QH96%D:6YG/D%P
M<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T
M;R!A;'=A>7,@87!P;'D@9FEL=&5R<R!W:&5N979E<B!Y;W5R('9I97<@=&AE
M($E.0D]8/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL
M=&5R+6%N>2UM86EL8F]X(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT
M97)S.B!&:6QT97(@86YY($UA:6QB;W@\+W1I=&QE/@H@("`@/&AE861I;F<^
M07!P;'D@9FEL=&5R(')U;&5S('1O(&%N>2!M86EL8F]X/SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@:68@>6]U('=A;G0@
M=&\@8F4@86QL;W=E9"!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA
M:6QB;W@N($YO<FUA;&QY+"!F:6QT97)I;F<@<G5L97,@87)E(&]N;'D@87!P
M;&EE9"!T;R!N97<@;6%I;"!T:&%T(&ES(&1E;&EV97)E9"!T;R!Y;W5R($E.
M0D]8+B`@268@=&AI<R!O<'1I;VX@:7,@8VAE8VME9"P@86X@:6-O;B!W:6QL
M(&%P<&5A<B!O;B!A;&P@;6%I;&)O>"!P86=G97,@=&AA="!W:6QL(&%L;&]W
M('EO=2!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@=&AE(&UE<W-A9V5S(&EN
M('1H92!C=7)R96YT(&UA:6QB;W@N("!.3U1%.B!&:6QT97)I;F<@:6X@;6%I
M;&)O>&5S(&]T:&5R('1H86X@24Y"3U@@;6%Y('!R;V1U8V4@<W1R86YG92`H
M92YG+B!T:&4@9FEL=&5R(&UA>2!C875S92!A(&-O<'D@;V8@;65S<V%G97,@
M=&\@8F4@9&5L:79E<F5D('1O('1H92!S86UE(&UA:6QB;W@I(&%N9"]O<B!U
M;F1E<VER960@<F5S=6QT<R`H92YG+B!I="!M87D@8V%U<V4@;65S<V%G97,@
M=&\@8F4@;6]V960O9&5L971E9"!I9B!N97<@9FEL=&5R:6YG(')U;&5S(&AA
M=F4@8F5E;B!I;7!L96UE;G1E9"!S:6YC92!T:&4@;65S<V%G92!H87,@8F5E
M;B!D96QI=F5R960@=&\@=&AE(&-U<G)E;G0@;6%I;&)O>"DN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M
M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($%T=&%C:"!0
M=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D%T=&%C:"!0=6)L:6,@
M2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N
M(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L
M('=I;&P@8F4@871T86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N("!9
M;W4@8V%N('-E="!T:&4@9&5F875L="!B96AA=FEO<B!V:6$@=&AE(%!'4"!/
M<'1I;VYS('-C<F5E;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UO<'1I;VXM<V-A;BUB;V1Y(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z(%-C86X@5&5X="!";V1I97,\+W1I=&QE/@H@("`@/&AE861I
M;F<^4V-A;B!497AT($)O9&EE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M268@<V5L96-T960@=&AE;B!)35`@=VEL;"!S8V%N('1H92!B;V1Y(&]F(&%L
M;"!T97AT(&UE<W-A9V5S(&9O<B!01U`@9&%T82P@86YD(&1I<W!L87D@=&AE
M(')E<W5L=',@:68@86YY(&1A=&$@:7,@9F]U;F0N("!.;W1E('1H870@=&AI
M<R!M87D@<VQO=R!D;W=N('1H92!S>7-T96T@87,@979E<GD@=&5X="!M97-S
M86=E(&UU<W0@8F4@<V-A;FYE9"!I;B!I=',@96YT:7)E='D@9F]R(%!'4"!D
M871A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UO<'1I;VYS+65N8W)Y<'0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D-O
M;7!O<V4Z($5N8W)Y<'1I;VX@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY.;R!%;F-R>7!T:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD
M('1H92!M97-S86=E('=I=&@@;F\@96YC<GEP=&EO;B`H8VQE87)T97AT*2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!%;F-R>7!T($UE<W-A9V4\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@96YC
M<GEP="!T:&4@8W5R<F5N="!M97-S86=E+"!U<VEN9R!01U`@86YD('1H92!R
M96-I<&EE;G1S('!E<G-O;F%L('!U8FQI8R!K97DL(&%N9"!T:&5N('-E;F0@
M:70N(%EO=2!C86X@;VYL>2!S96YD(&$@;65S<V%G92!T;R!A('-I;F=L92!P
M97)S;VX@=7-I;F<@=&AI<R!O<'1I;VXN(%EO=2!-55-4(&AA=F4@=&AE('!U
M8FQI8R!K97D@;V8@=&AE(')E8VEP:65N="!S=&]R960@:6X@>6]U<B!A9&1R
M97-S8F]O:R!O<B!E;'-E('1H:7,@;W!T:6]N('=I;&P@9F%I;"X@268@>6]U
M(&AA=F4@=&AE('!U8FQI8R!K97D@9F]R('1H92!R96-I<&EE;G0@:6X@>6]U
M<B!A9&1R97-S8F]O:R!A;F0@87)E('-T:6QL(')E8V5I=FEN9R!E<G)O<G,L
M('9E<FEF>2!T:&%T('1H92!E+6UA:6P@861D<F5S<R!I;B!T:&4@<F5C:7!I
M96YT(&9I96QD(&UA=&-H97,@=&AE(&4M;6%I;"!A9&1R97-S('=H97)E('1H
M92!P=6)L:6,@:V5Y(&ES('-T;W)E9"X@5&AE(&5N8W)Y<'1E9"!D871A('=I
M;&P@8F4@871T86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B!-97-S86=E/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL(&1I9VET86QL>2!S
M:6=N('1H92!C=7)R96YT(&UE<W-A9V4@=7-I;F<@4$=0(&%N9"!Y;W5R('!E
M<G-O;F%L('!R:79A=&4@:V5Y+B!)9B!Y;W4@:&%V92!N;W0@86QR96%D>2!E
M;G1E<F5D('1H92!P87-S<&AR87-E(&9O<B!Y;W5R('!R:79A=&4@:V5Y(&1U
M<FEN9R!T:&ES('-E<W-I;VX@>6]U('=I;&P@8F4@<')O;7!T960@9F]R(&ET
M+B`@5&AE(')E8V5I<&EE;G0@;75S="!H879E(&$@8V]P>2!O9B!Y;W5R('!U
M8FQI8R!K97D@=&\@9&EG:71A;&QY('9E<FEF>2!Y;W5R"B`@("!S:6=N871U
M<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B]%;F-R>7!T
M($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N
M('=I;&P@9FER<W0@9&EG:71A;&QY('-I9VX@>6]U<B!M97-S86=E(&%N9"!T
M:&5N('=I;&P@96YC<GEP="!T:&4@<F5S=6QT:6YG(&]U='!U="X@4V5E('1H
M92`G4$=0($5N8W)Y<'0@365S<V%G92<@86YD("=01U`@4VEG;B!-97-S86=E
M)R!E;G1R:65S(&9O<B!F=7)T:&5R(&EN9F]R;6%T:6]N+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^4R]-24U%($5N8W)Y<'0@365S<V%G93PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^4R]-24U%(%-I9VX@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^4R]-24U%(%-I9VXO
M16YC<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I
M97<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@3W9E<G9I97<\+W1I
M=&QE/@H@("`@/&AE861I;F<^5VAA="!I<R!01U`_/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!01U`@:7,@82!T;V]L(&9O<B!S96-U<F4@8V]M;75N:6-A
M=&EO;B!A;F0@9&%T82!S=&]R86=E+"!E<W!E8VEA;&QY(&9O<B!U<V4@=VET
M:"!E+6UA:6PN($ET(&-A;B!B92!U<V5D('1O(&5N8W)Y<'0@9&%T82!A;F0@
M=&\@8W)E871E(&1I9VET86P@<VEG;F%T=7)E<RX@24U0('5S97,@1VYU4$<@
M*$=.52!0<FEV86-Y($=U87)D*2!T;R!P<F]V:61E('1H:7,@9G5N8W1I;VYA
M;&ET>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!01U`@9G5N
M8W1I;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@
M;W!T:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&-R96%T
M92]V:65W('EO=7(@<&5R<V]N86P@4$=0(&ME>7,L(&%D9"]D96QE=&4@<'5B
M;&EC(&ME>7,@9G)O;2!O=&AE<B!I;F1I=FED=6%L<RP@<F5A9"!E;F-R>7!T
M960@;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N
M8W)Y<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C:"UP=6)K97DB
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@3W!T:6]N<R`M($%T=&%C
M:"!0=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D]P=&EO;G,@+2!!
M='1A8V@@4'5B;&EC($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M<V5L96-T960@=&AE;B!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@
M:68@:70@97AI<W1S+"!W:6QL(&)Y(&1E9F%U;'0@8F4@871T86-H960@=&\@
M86QL(&]U=&=O:6YG(&UE<W-A9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<&=P+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*("`@
M(#QH96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M:&ES('-C<F5E;B!L:7-T<R!A;&P@;V8@=&AE(&-U<G)E;G0@=7-E<G,@:6X@
M>6]U<B!A9&1R97-S8F]O:R!T:&%T(&AA=F4@4$=0('!U8FQI8R!K97ES+B!4
M:&5S92!U<V5R<R!A<F4@=&AE($].3%D@=7-E<G,@=&AA="!Y;W4@8V%N(&5I
M=&AE<B`Q*2!S96YD(&%N(&5N8W)Y<'1E9"!M97-S86=E('1O("U/4BT@,BD@
M=F5R:69Y(&$@9&EG:71A;"!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A
M('=I;F1O=R!T;R!V:65W('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!U8FQI
M8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($1E;&5T97,@=&AE('!U8FQI8R!K97D@9G)O
M;2!Y;W5R(&%D9')E<W-B;V]K+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+6EM<&]R="UP=6)K97DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES("T@26UP;W)T/"]T:71L
M93X*("`@(#QH96%D:6YG/DEM<&]R="!0=6)L:6,@2V5Y<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!O<&5N(&$@=VEN9&]W
M('=H97)E('EO=2!C86X@;6%N=6%L;'D@:6UP;W)T(&$@4$=0('!U8FQI8R!K
M97DN("!4:&4@:V5Y(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT
M9FEE;&0@;W(L(&EF('1H92!K97D@<F5S:61E<R!I;B!A(&9I;&4@;VX@>6]U
M<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@:70N("!)9B!T:&4@
M:V5Y(&ES('9A;&ED(&ET('=I;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R(&%D
M9')E<W-B;V]K(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V
M86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA
M:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<&=P+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES/"]T:71L93X*("`@(#QH
M96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!Y
M;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!M97-S86=E<R!O<B!E;F%B;&4@
M;W1H97)S('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M97-S86=E<RP@>6]U(&UU
M<W0@:&%V92!Y;W5R(&]W;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!01U`@
M:V5Y<&%I<BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4'5B;&EC
M($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U<B!P=6)L:6,@:V5Y
M('-H;W5L9"!B92!M861E(&%V86EL86)L92!T;R!A;GD@<&5R<V]N('1H870@
M>6]U('=A;G0@=&\@8F4@86)L92!T;R!S96YD('EO=2!E;F-R>7!T960@;65S
M<V%G97,@=&AA="!O;FQY(%E/52!C86X@9&5C<GEP="`H=7-I;F<@>6]U<B!P
M<FEV871E(&ME>2DN($%D9&ET:6]N86QL>2P@>6]U<B!P=6)L:6,@:V5Y(&YE
M961S('1O(&)E(&UA9&4@879A:6QA8FQE('1O(&%N>6)O9'D@>6]U('-E;F0@
M82!D9&EG:71A;&QY('-I9VYE9"!M97-S86=E('1O("T@=&AE('!U8FQI8R!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!D:6=I=&%L('-I9VYA='5R
M92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4')I=F%T92!+97D\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=7(@<')I=F%T92!K97D@:7,@
M;F5C97-S87)Y('1O(&1E8W)Y<'0@86YY(&UE<W-A9V4@96YC<GEP=&5D('5S
M:6YG('EO=7(@<'5B;&EC(&ME>2X@061D:71I;VYA;&QY+"!Y;W5R('!R:79A
M=&4@:V5Y(&ES(&YE961E9"!I9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG
M;B!A(&UE<W-A9V4N(%EO=7(@<')I=F%T92!K97D@=VEL;"!B92!P<F]T96-T
M960@=FEA(&$@<&%S<W!H<F%S92!C<F5A=&5D('=H96X@=&AE(&ME>7,@87)E
M(&=E;F5R871E9"X@5&AU<RP@=&\@<&5R9F]R;2!A;GD@86-T:79I='D@=&AA
M="!R97%U:7)E<R!Y;W5R('!R:79A=&4@:V5Y+"!)35`@=VEL;"!P<F]M<'0@
M>6]U(&9O<B!Y;W5R('!A<W-P:')A<V4N(%EO=2!O;FQY(&YE960@=&\@:6YS
M97)T('EO=7(@<&%S<W!H<F%S92!O;F-E('!E<B!S97-S:6]N("T@24U0('=I
M;&P@<W1O<F4@>6]U<B!P87-S<&AR87-E('5N=&EL('EO=2!L;V=O=70@*%-O
M(&)E('-U<F4@=&\@;&]G;W5T(2DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<'5B;&EC(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@4'5B
M;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@
M<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T86EL
M<R!A8F]U="!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T92(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y
M<R`M(%!R:79A=&4@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D5N=&5R(%!A
M<W-P:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS('1H92!P
M87-S<&AR87-E(&1I86QO9R!W:6YD;W<N(%1H92!P87-S<&AR87-E(&5N=&5R
M960L(&EF(&-O<G)E8W0L('=I;&P@8F4@<W1O<F5D(&)Y($E-4"!U;G1I;"!Y
M;W5R('-E<W-I;VX@96YD<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5N
M;&]A9"!087-S<&AR87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!296UO
M=F5S('1H92!S=&]R960@<&%S<W!H<F%S92!F<F]M($E-4"`M(&%N>2!A9&1I
M=&EO;F%L('5S86=E(&]F('1H92!P<FEV871E(&ME>2!W:6QL(')E<75I<F4@
M>6]U('1O(')E96YT97(@=&AE('!A<W-P:&5A<V4N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N
M<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@<')I=F%T92!K97DN($1/($Y/
M5"!314Y$(%1(25,@2T59(%1/($%.64].12`M('1H:7,@;W!T:6]N(&ES('-T
M<FEC=&QY('-O('1H870@>6]U(&-A;B!E>'!O<G0@>6]U<B!)35`@<&5R<V]N
M86P@<')I=F%T92!K97D@9F]R('5S92!I;B!A;F]T:&5R('!R;V=R86TN"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'
M4"!P<FEV871E(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UD96QE=&4B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!$96QE=&4\+W1I
M=&QE/@H@("`@/&AE861I;F<^1&5L971E(%!E<G-O;F%L($ME>7,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H:7,@8G5T=&]N('=I;&P@9&5L971E('EO
M=7(@<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<B!F<F]M($E-4"=S
M('!R969E<F5N8V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UN86UE(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!.86UE/"]T
M:71L93X*("`@(#QH96%D:6YG/DYA;64\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1H92!N86UE('EO=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N
M86P@:V5Y<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N
M="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N
M86P@2V5Y("T@0V]M;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY#;VUM96YT
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!(&-O;6UE;G0@<W1R:6YG('EO
M=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@:V5Y<RX@06X@;W!T
M:6]N86P@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM8W)E871E+65M86EL(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!%+6UA:6P@
M061D<F5S<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%+6UA:6P@061D<F5S<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&4M;6%I;"!A9&1R97-S('EO
M=2!W86YT(&%S<V]C:6%T960@=VET:"!Y;W5R('!E<G-O;F%L(&ME>7,N($$@
M<F5Q=6ER960@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@
M2V5Y;&5N9W1H/"]T:71L93X*("`@(#QH96%D:6YG/DME>6QE;F=T:#PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&ME>6QE;F=T:"P@:6X@8GET97,L
M(&]F('EO=7(@9V5N97)A=&5D(&ME>2X@5&AE(&=R96%T97(@=&AE('9A;'5E
M+"!T:&4@9W)E871E<B!T:&4@<')O=&5C=&EO;B`H86YD(&%L<V\@9W)E871E
M<B!G96YE<F%T:6]N('1I;64@86YD(&5N8W)Y<'1I;VX@=&EM92DN(#$P,C0@
M8GET97,@:7,@=&AE(&1E9F%U;'0@+2!T:&ES('9A;'5E('!R;W9I9&5S(&5X
M8V5L;&5N="!P<F]T96-T:6]N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UP87-S<&AR87-E(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+
M97D@+2!087-S<&AR87-E/"]T:71L93X*("`@(#QH96%D:6YG/DYA;64\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%1H92!P87-S<&AR87-E('5S960@=&\@
M<')O=&5C="]E;F-R>7!T('EO=7(@<&5R<V]N86P@<')I=F%T92!K97DN(%1H
M:7,@<VAO=6QD(&)E($%4($Q%05-4(#8@8VAA<F%C=&5R<RP@<VAO=6QD($Y/
M5"!B92!T:&4@<V%M92!A<R!Y;W5R(&QO9VEN('!A<W-W;W)D+"!S:&]U;&0@
M3D]4(&)E(&)A<V5D(&]N(&$@9&EC=&EO;F%R>2!W;W)D+"!A;F0@<VAO=6QD
M(&EN8VQU9&4@8F]T:"!N=6UB97)S(&%N9"!L971T97)S+B!9;W4@;75S="!E
M;G1E<B!T:&ES('!A<W-P:')A<V4@='=I8V4@9F]R('9E<FEF:6-A=&EO;B!P
M=7)P;W-E<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M86-T:6]N
M<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N
M86P@2V5Y("T@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY#<F5A=&4@
M2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0W)E871E(&%N9"!S=&]R
M92!Y;W5R('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/DEM<&]R="!+97EP86ER/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!);7!O<G0@82!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N(%1H
M:7,@8G5T=&]N(&]P96YS(&$@=VEN9&]W('=H97)E('EO=2!C86X@;6%N=6%L
M;'D@:6UP;W)T('EO=7(@97AI<W1I;F<@4$=0('!E<G-O;F%L('!U8FQI8R]P
M<FEV871E(&ME>7!A:7(N("!4:&4@:V5Y<R!C86X@96ET:&5R(&)E('!A<W1E
M9"!I;G1O(&$@=&5X=&9I96QD(&]R+"!I9B!T:&4@:V5Y<R!R97-I9&4@:6X@
M82!F:6QE(&]N('EO=7(@;&]C86P@8V]M<'5T97(L('EO=2!C86X@:6UP;W)T
M('1H96TN("!)9B!T:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E(&EN
M<V5R=&5D(&EN=&\@>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O=R!W
M:6QL(&-L;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL
M;"!B92!R971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y3+TU)344Z($]V97)V:65W/"]T:71L93X*("`@(#QH
M96%D:6YG/E=H870@:7,@4R]-24U%/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@4R]-24U%(&ES(&$@<')I=F%T92]P=6)L:6,@:V5Y('!A:7(@<WES=&5M
M('=H:6-H('!R;W9I9&5S(&1I9VET86P@<VEG;F%T=7)E<RP@;65S<V%G92!P
M<FEV86-Y+"!A;F0@=&%M<&5R(&1E=&5C=&EO;B!I;B!A(&]P96XL(&EN=&5R
M;W!E<F%B;&4@=V%Y+B`@4R]-24U%(&-A;B!P<F]V:61E(&UE<W-A9V4@<')I
M=F%C>2!B>2!E;F-R>7!T:6YG(&UE<W-A9V5S('1H870@;VYL>2!T:&4@<V5N
M9&5R(&%N9"!T:&4@:6YT96YD960@<F5C:7!I96YT<R!C86X@9&5C;V1E+B`@
M270@86QL;W=S('EO=2!T;R!I9&5N=&EF>2!T:&4@<V5N9&5R(&]F(&$@;65S
M<V%G92!V:6$@82!D:6=I=&%L('-I9VYA='5R92X@(%1O9V5T:&5R+"!T:&ES
M(&5N8W)Y<'1I;VX@86YD(&1I9VET86P@<VEG;FEN9R!H96QP('!R;W9I9&4@
M=&%M<&5R(&1E=&5C=&EO;BP@86QL;W=I;F<@<F5C:7!I96YT<R!T;R!D971E
M<FUI;F4@=VAE=&AE<B!A(&UE<W-A9V4@=V%S(&%L=&5R960@869T97(@:70@
M=V%S('-E;G0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;F%B;&4@4R]-
M24U%(&9U;F-T:6]N86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)
M9B!T:&ES(&]P=&EO;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@86)L92!T
M;R!I;7!O<G0@>6]U<B!P97)S;VYA;"!3+TU)344@:V5Y<RP@<F5A9"!E;F-R
M>7!T960@;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD
M(&5N8W)Y<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=RUP97)S;VYA
M;&ME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!097)S;VYA
M;"!+97ES/"]T:71L93X*("`@(#QH96%D:6YG/D]V97)V:65W/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG
M;B!O<B!E;F-R>7!T(&UE<W-A9V5S('EO=2!M=7-T(&AA=F4@>6]U<B!O=VX@
M<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@4R]-24U%(&ME>7!A:7(N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UI;7!O<G0M<&5R
M<V]N86PM8V5R=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@
M26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!);7!O<G0@<&5R<V]N86P@8V5R=&EF:6-A=&5S(&9R
M;VT@82!02T-3(",Q,B!F;W)M870@9FEL92X@4$M#4R`C,3(@9FEL97,@:7,@
M=&AE(&9I;&4@=7-U86QL>2!G96YE<F%T960@=VAE;B!E>'!O<G1I;F<@82!K
M97D@9G)O;2!A(&)R;W=S97(@*&4N9RX@26YT97)N970@17AP;&]R97(L($9I
M<F5F;W@I(&]R(&9R;VT@82!C97)T:69I8V%T92!S=&]R92!M86EN=&%I;F5D
M(&)Y(&%N($]P97)A=&EN9R!3>7-T96T@*&4N9RX@5VEN9&]W<R!84"DN($EF
M('1H92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS97)T960@:6YT
M;R!Y;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[
M(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R
M;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<VUI;64M9&5L971E+7!E<G-O;F%L+6-E<G1S(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y3+TU)344Z($1E;&5T92!097)S;VYA;"!#97)T
M:69I8V%T97,\+W1I=&QE/@H@("`@/&AE861I;F<^1&5L971E(%!E<G-O;F%L
M($-E<G1I9FEC871E<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E
M('EO=7(@<&5R<V]N86P@8V5R=&EF:6-A=&5S(&9R;VT@>6]U<B!P<F5F97)E
M;F-E<RX@(%EO=2!W:6QL(&YO(&QO;F=E<B!B92!A8FQE('1O('-I9VX@4R]-
M24U%(&UE<W-A9V5S(&]R('9I97<@86YY(%,O34E-12!E;F-R>7!T960@;65S
M<V%G97,@861D<F5S<V5D('1O('EO=2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G-M:6UE+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L
M93X*("`@(#QH96%D:6YG/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!-86YA9V4@>6]U<B!3+TU)344@<'5B
M;&EC(&ME>2!L:7-T+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5FEE=R!T:&4@<F%W('1E>'0@;V8@
M=&AE('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A
M:6QS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W('1E8VAN:6-A;"!D
M971A:6QS(&]F('1H92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^1&5L971E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&5S
M('1H92!S96QE8W1E9"!P=6)L:6,@:V5Y(&9R;VT@<W1O<F%G92X@($1E;&5T
M:6YG(&$@<'5B;&EC(&ME>2!F;W(@82!U<V5R('=I;&P@<')E=F5N="!Y;W5R
M(&9R;VT@96YC<GEP=&EN9R!A(&UE<W-A9V4@=&\@=&AA="!U<V5R+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')I;G1I;F<B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R:6YT:6YG/"]T:71L93X*("`@(#QH96%D
M:6YG/E!R:6YT(&$@;65S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5&\@<')I;G0@82!M97-S86=E('EO=2!A<F4@=FEE=VEN9RP@8VQI8VL@;VX@
M=&AE(")0<FEN="(@;&EN:R!A="!E:71H97(@=&AE('1O<"!O<B!B;W1T;VT@
M;V8@=&AE(&UE<W-A9V4N(%1H92!M97-S86=E('=I;&P@;W!E;B!I;B!A(&YE
M=R!W:6YD;W<@9F]R;6%T960@9F]R('!R:6YT:6YG+B`@1&5P96YD:6YG(&]N
M('EO=7(@=V5B(&)R;W=S97(@86YD(&]P97)A=&EN9R!S>7-T96TL('1H92!P
M<FEN="!D:6%L;V<@8F]X(&UA>2!O<&5N(&9O<B!Y;W4N("!)9B!I="!D;V5S
M(&YO="!O<&5N+"!T:&5N('!U;&P@9&]W;B!T:&4@=V5B(&)R;W=S97(G<R`B
M1FEL92(@;65N=2!A;F0@8VAO;W-E(")0<FEN="(@=&\@;W!E;B!T:&4@<')I
M;G0@9&EA;&]G(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G-O<G1I;F<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E-O<G1I;F<@
M86YD(%1H<F5A9&EN9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3;W)T:6YG($5N
M=')I97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%=H96X@=FEE=VEN9R!A
M(&QI<W0@;V8@;65S<V%G97,L('EO=2!C86X@<V]R="!T:&4@;65S<V%G97,@
M8GD@86YY(&-O;'5M;B!B>2!C;&EC:VEN9R!O;B!T:&4@87!P<F]P<FEA=&4@
M8V]L=6UN(&AE861I;F<N("!4;R!S=VET8V@@8V]L=6UN<R!B971W965N(&%S
M8V5N9&EN9R!A;F0@9&5S8V5N9&EN9R!O<F1E<BP@8VQI8VL@;VX@=&AE(&%R
M<F]W(&EC;VX@:6X@=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^5&AR96%D:6YG/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4;R!G<F]U<"!M97-S86=E<R!B>2!T:')E861S("AS=6)J96-T*2P@<V\@
M96%C:"!M97-S86=E(&ES(&=R;W5P960@=VET:"!A;&P@:71S(')E<&QI97,L
M(&-L:6-K('1H92!;5&AR96%D72!L:6YK(&EN('1H92!S=6)J96-T(&-O;'5M
M;B!H96%D:6YG+B`@5&\@<F5T=7)N('1O(&YO<FUA;"!S=6)J96-T('-O<G1I
M;F<L(&-L:6-K(&]N('1H92!;4W5B:F5C=%T@;&EN:R!I;B!T:&4@<W5B:F5C
M="!C;VQU;6X@:&5A9&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F%L=&5R;F%T:79E+6US9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^375L=&EP87)T+T%L=&5R;F%T:79E($UE<W-A9V5S/"]T:71L93X*("`@
M(#QP87)A/@H@("`@4V]M92!M97-S86=E(&AA=F4@8F5E;B!S96YT(&%S(&$@
M(FUU;'1I<&%R="]A;'1E<FYA=&EV92(@='EP92!B>2!T:&4@<V5N9&5R+B!4
M:&5S92!M97-S86=E<R!H879E('-E=F5R86P@<&%R=',L(&%L;"!D:7-P;&%Y
M:6YG('1H92!304U%($-/3E1%3E0@8G5T(&EN($1)1D9%4D5.5"!&3U)-0513
M+B!4:&4@;6%I;"!A9V5N="!W:6QL(&1I<W!L87D@=&AE(&QA<W0@<&%R="!I
M;B!T:&4@;&ES="!T:&%T(&-A;B!B92!S=6-C97-S9G5L;'D@9&ES<&QA>65D
M(&EN;&EN92!I;B!T:&4@8G)O=W-E<BP@:68@86YY+B!!;&P@;W1H97(@9F]R
M;6%T<R!W:6QL(&%P<&5A<B!U;F1E<B!T:&4@:&5A9&EN9R`B06QT97)N871I
M=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;B(@86YD(&-A;B!B92!V:65W960@
M;W(@9&]W;FQO861E9"!S97!A<F%T96QY+B!)="!I<R!I;7!O<G1A;G0@=&\@
M;F]T92!T:&%T('1H97-E(&%L=&5R;F%T:79E('!A<G1S(&-O;G1A:6X@=&AE
M(%-!344@0T].5$5.5%,@87,@=&AE('!A<G0@=&AA="!I<R!S:&]W;B`M('1H
M97D@87)E('-I;7!L>2!I;B!A(&1I9F9E<F5N="!M961I82!F;W)M870@*&4N
M9RX@=&5X="!V<RX@2%1-3"!O=71P=70I+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DB
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@4F5N86UE(%-E;G0M;6%I;"!&;VQD97(@36]N=&AL>3PO=&ET;&4^
M"B`@("`\<&%R83X*("`@(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U('=O
M=6QD(&QI:V4@=&\@<F5N86UE('EO=7(@<V5N="UM86EL(&9O;&1E<B!A="!T
M:&4@8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AE(&9O;&1E<B!W:6QL
M(&)E(')E;F%M960@*'1O(&$@;F%M92!T:&%T(&-O;G1A:6YS('1H92!M;VYT
M:"!A;F0@>65A<BD@86YD(&$@;F5W('-E;G0M;6%I;"!F;VQD97(@=VEL;"!B
M92!C<F5A=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&5L971E7W-E;G1M86EL7VUO;G1H;'DB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E(%-E
M;G0M;6%I;"!&;VQD97(@36]N=&AL>3PO=&ET;&4^"B`@("`\<&%R83X*("`@
M(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U('=O=6QD(&QI:V4@=&\@9&5L
M971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!T:&4@8F5G:6YN:6YG(&]F
M(&5V97)Y(&UO;G1H+B`@5&AI<R!M87D@8F4@=7-E9G5L(&EF('EO=2!H879E
M(&$@<75O=&$L(&9O<B!E>&%M<&QE+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7W-E;G1M86EL7VUO;G1H;'E?:V5E
M<"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!$96QE=&4@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY("T@(R!O
M9B!&;VQD97)S('1O($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y
M;W4@87)E(&1E;&5T:6YG(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!E=F5R>2!M
M;VYT:"P@:&]W(&UA;GD@;6]N=&AS(&]F(&]L9"!F;VQD97)S(&1O('EO=2`@
M=V%N="!T;R!K965P/R`@06YY(&9O;&1E<G,@;VQD97(@=&AA;B!T:&ES(&UA
M;GD@;6]N=&AS('=I;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]A='1A8VAM96YT<U]M;VYT
M:&QY(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($1E;&5T92!,:6YK960@071T86-H;65N=',@36]N=&AL>3PO
M=&ET;&4^"B`@("`\<&%R83X*("`@(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@
M>6]U('=O=6QD(&QI:V4@=&\@9&5L971E(&]L9"!L:6YK960@871T86-H;65N
M=',@870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H:7,@;6%Y
M(&)E('5S969U;"!I9B!Y;W4@:&%V92!A('%U;W1A+"!F;W(@97AA;7!L92X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T
M95]A='1A8VAM96YT<U]M;VYT:&QY7VME97`B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E($QI;FME
M9"!!='1A8VAM96YT<R!-;VYT:&QY("T@(R!O9B!-;VYT:',@=&\@2V5E<#PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@9&5L971I;F<@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!E=F5R>2!M;VYT:"P@:&]W(&UA;GD@;6]N
M=&AS(&]F(&]L9"!A='1A8VAM96YT<R!D;R!Y;W4@('=A;G0@=&\@:V5E<#\@
M($%N>2!A='1A8VAM96YT<R!O;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT:',@
M=VEL;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M<'5R9V5?=')A<V@B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@4'5R9V4@5')A<V@\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!$;R!Y;W4@=V%N="!T;R!P=7)G92!Y;W5R
M('1R87-H(&9O;&1E<B!E=F5R>2!S;R!O9G1E;BX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H7VEN=&5R=F%L
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E
M;F%N8V4Z(%!U<F=E(%1R87-H($EN=&5R=F%L/"]T:71L93X*("`@(#QP87)A
M/@H@("`@268@>6]U(&%R92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R+"!H
M;W<@;V9T96X@<VAO=6QD(&ET(&)E('!U<F=E9#\*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H7VME97`B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@4'5R9V4@5')A<V@@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF
M('EO=2!A<F4@<'5R9VEN9R!Y;W5R('1R87-H(&9O;&1E<BP@;65S<V%G92!O
M;&1E<B!T:&%N(&AO=R!M86YY(&1A>7,@<VAO=6QD(&)E('!U<F=E9#\*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6%T=')I8E]T
M97AT(B!S=&%T93TB;F5W(CX*("`@("`\=&ET;&4^4')E9F5R96YC97,Z($UE
M<W-A9V4@0V]M<&]S:71I;VXZ($%T=')I8G5T:6]N(%1E>'0\+W1I=&QE/@H@
M("`@(#QP87)A/@H@("`@($AE<F4@>6]U(&-A;B!E;G1E<B!T:&4@<&AR87-E
M('1H870@>6]U('=I<V@@=&\@87!P96%R(&)E9F]R92!A;GD@<75O=&5D('1E
M>'0@:6X@82!R97!L>2!T:&%T('EO=2!S96YD+@H@("`@(#PO<&%R83X*("`@
M("`\<&%R83X*("`@("!9;W4@8V%N(&EN8VQU9&4@;VYE(&]R(&UO<F4@<W!E
M8VEA;"!P;&%C96AO;&1E<G,@=&\@:6YS97)T(&EN9F]R;6%T:6]N(&%B;W5T
M('1H92!M97-S86=E('1O('=H:6-H('EO=2!A<F4@<F5P;'EI;F<N(%!L86-E
M:&]L9&5R<R!C;VYS:7-T(&]F(&$@)R4G(&9O;&QO=V5D(&)Y(&$@<VEN9VQE
M(&QE='1E<BX@5&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@87)E(&%V86EL
M86)L93H*("`@("`\+W!A<F$^"@H@("`@(#QP87)A/B`E9B`Z(%1H92!S96YD
M97(G<R!N86UE(&%N9"!E;6%I;"!A9&1R97-S/"]P87)A/@H@("`@(#QP87)A
M/B`E82`Z(%1H92!S96YD97(G<R!E;6%I;"!A9&1R97-S/"]P87)A/@H@("`@
M(#QP87)A/B`E<"`Z(%1H92!S96YD97(G<R!N86UE/"]P87)A/@H@("`@(#QP
M87)A/B`E<B`Z(%1H92!F=6QL(%)&0R`R.#(R('-T>6QE(&1A=&4@86YD('1I
M;64@>F]N93PO<&%R83X*("`@("`\<&%R83X@)60@.B!4:&4@9&%T92!A<R!W
M=W<L(&1D(&UM;2!965E9/"]P87)A/@H@("`@(#QP87)A/B`E>"`Z(%1H92!D
M871E(&EN('1H92!L;V-A;&4G<R!D969A=6QT/"]P87)A/@H@("`@(#QP87)A
M/B`E8R`Z(%1H92!D871E(&%N9"!T:6UE(&EN('1H92!L;V-A;&4G<R!D969A
M=6QT/"]P87)A/@H@("`@(#QP87)A/B`E;2`Z(%1H92!-97-S86=E+4E$/"]P
M87)A/@H@("`@(#QP87)A/B`E<R`Z(%1H92!S=6)J96-T/"]P87)A/@H@("`@
M(#QP87)A/B`E;B`Z($$@;F5W(&QI;F4\+W!A<F$^"B`@("`@/'!A<F$^("4E
M(#H@5&AE("<E)R!C:&%R86-T97(\+W!A<F$^"@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]R96%D(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4F5Q=65S="!296%D(%)E
M8V5I<'1S/"]T:71L93X*("`@(#QP87)A/@H@("`@(E)E<75E<W0@82!296%D
M(%)E8V5I<'0B('-E;F1S(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT<R!O
M9B!T:&ES(&UE<W-A9V4@=&\@;F]T:69Y('EO=2!W:&5N('1H:7,@;65S<V%G
M92!I<R!O<&5N960@8GD@=&AE(')E8VEP:65N=',N($YO="!A;&P@8VQI96YT
M<R!S=7!P;W)T("\@:&]N;W(@=&AI<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W-E;F1?;61N(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4V5N9"!-1$X\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("`B4V5N9"!A($U$3B(@<V5N9',@82!-97-S
M86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`H86QS;R!K;F]W;B!A<R!A
M(')E860@<F5C96EP="D@=VAE;B!Y;W4@=FEE=R!A(&UE<W-A9V4@:6X@=VAI
M8V@@=&AE('5S97(@:&%S(')E<75E<W1E9"!T:&%T('1H97D@<F5C96EV92!N
M;W1I9FEC871I;VX@=&AA="!Y;W4@:&%V92!R96%D('1H92!M97-S86=E+B!)
M;B!M;W-T(&-A<V5S+"!T:&ES('=I;&P@:&%P<&5N(&%U=&]M871I8V%L;'D@
M=VET:&]U="!P<F]M<'1I;F<@>6]U+B!);B!C97)T86EN(&ES;VQA=&5D(&-A
M<V5S+"!Y;W4@;6%Y(&AA=F4@=&\@;6%N=6%L;'D@9&5C:61E('1O('-E;F0@
M=&AE(&YO=&EF:6-A=&EO;B!B>2!C;&EC:VEN9R!O;B!A(&QI;FLN"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO
M;E]R97%U97-T7V1E;&EV97)Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VX\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M
M871I;VXB('-E;F1S(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT)W,@92UM
M86EL('-E<G9E<B!T;R!N;W1I9GD@>6]U('=H96X@:70@:&%S(&1E;&EV97)E
M9"!T:&4@;65S<V%G92!T;R!T:&4@<F5C:7!I96YT)W,@;6%I;&)O>"X@270@
M9&]E<VXG="!M96%N('1H92!M97-S86=E(&AA<R!B965N('-E96XL(&IU<W0@
M=&AA="!I="=S('-I='1I;F<@:6X@82!M86EL8F]X('-O;65W:&5R92X@3F]T
M(&%L;"!M86EL('-E<G9E<G,@<W5P<&]R="!T:&ES+B`*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]S<&%M7V%F=&5R
M7W)E<&]R="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M($1E;&5T92!3<&%M($%F=&5R(%)E<&]R=&EN9SPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(%EO=2!M87D@96QE8W0@=&\@9&\@;VYE(&]F('1H<F5E(&ET96US
M(&%F=&5R(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@96ET:&5R('-P86T@;W(@
M:6YN;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($9I<G-T+"!Y
M;W4@8V%N(&1E8VED92!T;R!D;R!N;W1H:6YG("T@=&AE(&UE<W-A9V4@=VEL
M;"!B92!R97!O<G1E9"!A<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="!B=70@
M=VEL;"!O=&AE<G=I<V4@<F5M86EN('5N8VAA;F=E9"!I;B!Y;W5R(&UA:6QB
M;W@N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-E8V]N9"P@:68@<F5P
M;W)T:6YG(&$@;65S<V%G92!A<R!S<&%M+"!Y;W4@8V%N(&EN<W1E860@:&%V
M92!T:&4@;65S<V%G92!B92!I;6UE9&EA=&5L>2!D96QE=&5D+B`@5&AI<R!S
M971T:6YG(&AA<R!N;R!E9F9E8W0@;VX@<F5P;W)T:6YG(&$@;65S<V%G92!A
M<R!I;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@5&AI<F0L
M(&%F=&5R(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@<W!A;2!T:&4@;65S<V%G
M92!W:6QL(&)E(&1E;&5T960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N
M9"!M;W9E9"!T;R!Y;W5R('-P86T@9F]L9&5R+B`@06QT97)N871I=F5L>2P@
M:68@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I;FYO8V5N="!T:&4@;65S<V%G
M92!W:6QL(&)E(&1E;&5T960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N
M9"!M;W9E9"!T;R!Y;W5R($E.0D]8+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]R97!L86-E;65N="(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($A434P@26UA9V4@
M4F5P;&%C96UE;G0\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!&;W(@2%1-3"!M
M97-S86=E<R!D:7-P;&%Y960@:6YL:6YE+"!S:&]U;&0@86QL(&EM86=E('1A
M9W,@8F4@8FQO8VME9"!U;G1I;"!Y;W4@<W!E8VEF:6-A;&QY(&1E8VED92!T
M;R!V:65W('1H;W-E(&EM86=E<S\@3F]T92!T:&%T+"!I9B!V:65W:6YG(&%N
M($A434P@871T86-H;65N="P@=&AE(&EM86=E<R!W:6QL(&%L=V%Y<R!B92!D
M:7-P;&%Y960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUH=&UL7VEM86=E7V%D9')B;V]K(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G92!297!L86-E;65N="]!9&1R
M97-S8F]O:R!3:&]W/"]T:71L93X*("`@(#QP87)A/@H@("`@268@8FQO8VMI
M;F<@:6UA9V5S(&9O<B!I;FQI;F4@2%1-3"!M97-S86=E<RP@<VAO=6QD('=E
M(&%U=&]M871I8V%L;'D@9&ES<&QA>2!T:&5M(&EN<W1E860@:68@=&AE('-E
M;F1E<B!A<'!E87)S(&EN('EO=7(@861D<F5S<V)O;VL_"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUM86EL8F]X7W-T87)T(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;&)O>"!3
M=&%R="!086=E/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W
M:&EC:"!P86=E(&EN('1H92!M86EL8F]X('9I97<@=VEL;"!B92!D:7-P;&%Y
M960@=VAE;B!Y;W4@86-C97-S(&$@;6%I;&)O>"!F;W(@=&AE(&9I<G-T('1I
M;64N($YO=&4@=&AA="!T:&4@)W5N<V5E;B<@;65S<V%G92!O<'1I;VYS(&1O
M(&YO="!W;W)K('=I=&@@=&AE("=4:')E860G('-O<G1I;F<@;W!T:6]N("T@
M:6YS=&5A9"P@>6]U('=I;&P@8F4@<V5N="!T;R!T:&4@;&%S="!P86=E+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<V%V95]A
M='1A8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z(%-A=F4@071T86-H;65N=',@;VX@4V5N="!-97-S86=E<SPO=&ET;&4^
M"B`@("`\<&%R83X*("`@($EF('-A=FEN9R!A(&-O;7!O<V5D(&UE<W-A9V4@
M:6X@82!S96YT+6UA:6P@9F]L9&5R+"!D971E<FUI;F4@:68@86QL(&%T=&%C
M:&UE;G0@9&%T82!I<R!S879E9"X@5&AE(&9O;&QO=VEN9R!O<'1I;VYS(&%R
M92!A=F%I;&%B;&4Z"B`@("`\+W!A<F$^"@H@("`@/'!A<F$^*B`B06QW87ES
M('-A=F4@871T86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A=F4@871T
M86-H;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT<R!A
M<F4@04Q705E3('-A=F5D('=I=&@@=&AE(&UE<W-A9V4N/"]P87)A/@H@("`@
M(#QP87)A/BH@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@
M<V5N=#L@9&5F875L="!T;R!915,B("T@04Q705E3('!R;VUP="!T;R!S879E
M(&%T=&%C:&UE;G1S(&EN('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U
M;'0@:7,@=&\@<V%V92!A='1A8VAM96YT<RX\+W!A<F$^"B`@("`@/'!A<F$^
M*B`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D
M969A=6QT('1O($Y/(B`M($%,5T%94R!P<F]M<'0@=&\@<V%V92!A='1A8VAM
M96YT<R!I;B!T:&4@8V]M<&]S92!S8W)E96X[('1H92!D969A=6QT(&ES('1O
M(&YO="!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R83XJ(").
M979E<B!S879E(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP="!T;R!S879E
M(&%T=&%C:&UE;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@871T86-H;65N
M=',@87)E($Y%5D52('-A=F5D('=I=&@@=&AE(&UE<W-A9V4N/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]I;F)O>"(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L($EN8F]X
M/"]T:71L93X*("`@(#QP87)A/@H@("`@5FER=71A;"!);F)O>"!I<R!A('-A
M=F5D('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D('1O('-E
M87)C:"!E=F5R>2!M86EL8F]X(&9O<B!M97-S86=E<R!M87)K960@87,@;F5W
M+B`@26YS=&5A9"P@86QL(&-U<G)E;G1L>2!S=6)S8W)I8F5D(&UA:6QB;WAE
M<R!A<F4@<V5A<F-H960@9F]R(&YE=R!M97-S86=E<R!A;F0@=&AE(')E<W5L
M=',@87)E(&1I<W!L87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T<F%S:"(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L
M(%1R87-H/"]T:71L93X*("`@(#QP87)A/@H@("`@5FER='5A;"!4<F%S:"!I
M<R!A('-A=F5D('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D
M(&9O<B!A('-E<&%R871E(%1R87-H(&9O;&1E<BX@($EN<W1E860@;V8@;6]V
M:6YG(&UE<W-A9V5S('1O(&$@8V5N=')A;&EZ960@=')A<V@@9F]L9&5R+"!M
M97-S86=E<R!A<F4@<VEM<&QY(&UA<FME9"!A<R!D96QE=&5D(&EN('1H92!C
M=7)R96YT(&9O;&1E<B!T:&5Y(&QI=F4@:6XN("!7:&5N("=S:&]W(&1E;&5T
M960@;65S<V%G97,G(&ES('1U<FYE9"!O9F8L('1H:7,@<F5S=6QT<R!I;B!T
M:&5S92!M97-S86=E<R!N;W0@87!P96%R:6YG(&EN(&$@;6%I;&)O>"!V:65W
M+B`@5VAE;B!A('5S97(@8VQI8VMS(&]N(%9I<G1U86P@5')A<V@L("IA;&PJ
M(&UA:6QB;WAE<R!A;&P@<V5A<F-H960@9F]R(&UE<W-A9V5S('1H870@87)E
M(&9L86=G960@9&5L971E9"!A;F0@=&AE<V4@;65S<V%G97,@87)E(&1I<W!L
M87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H\+VAE;'`^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O<'1?0E(O
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-C,`,#$W-#4W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+VQO8V%L92]P=%]"4B],0U]-15-304=%4R\`````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,C$R-#0`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+W!T7T)2+TQ#7TU%4U-!1T53
M+VEM<"YM;P``````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S`R-C4S`#$P-#$W,S8R
M-S8S`#`R,C0P,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````(0+```<````/%P``%L/``!<N````````,CU```*
M````R?4```H```#4]0``"@```-_U```*````ZO4```X```#U]0``#P````3V
M```-````%/8```@````B]@``"P```"OV```,````-_8```H```!$]@``!```
M`$_V```$````5/8``!@```!9]@``&P```'+V```M````CO8``!T```"\]@``
M)````-KV```I````__8``!D````I]P```0```$/W```9````1?<``"8```!?
M]P``#````(;W```+````D_<``"0```"?]P``'@```,3W``!(````X_<``"L`
M```L^```1````%CX```G````G?@``!<```#%^```#P```-WX```+````[?@`
M``X```#Y^```!0````CY```H````#OD```@````W^0``"@```$#Y```5````
M2_D``!(```!A^0``,@```'3Y```+````I_D``"D```"S^0``,@```-WY```0
M````$/H``!8````A^@``$````#CZ```F````2?H``"D```!P^@``)@```)KZ
M```<````P?H``(4```#>^@``#@```&3[```*````<_L```T```!^^P``)P``
M`(S[```B````M/L```X```#7^P``(@```.;[```9````"?P``"0````C_```
M-P```$C\```1````@/P```T```"2_```#````*#\```-````K?P```8```"[
M_```&P```,+\``"4````WOP``"X```!S_0``-P```*+]```&````VOT```P`
M``#A_0``?````.[]``!L````:_X``!P```#8_@``'0```/7^```*````$_\`
M``\````>_P``&````"[_```,````1_\``!L```!4_P``10```'#_```H````
MMO\``$$```#?_P``)````"$``0`.````1@`!``\```!5``$`#@```&4``0`.
M````=``!``@```"#``$`#@```(P``0`.````FP`!``D```"J``$`+@```+0`
M`0`:````XP`!`#,```#^``$`40```#(!`0`R````A`$!`#@```"W`0$`5```
M`/`!`0!1````10(!`%H```"7`@$`5P```/("`0`T````2@,!``D```!_`P$`
M#0```(D#`0`'````EP,!``H```"?`P$`#P```*H#`0`%````N@,!``,```#`
M`P$`!@```,0#`0`1````RP,!``@```#=`P$`"0```.8#`0`)````\`,!`!T`
M``#Z`P$`#@```!@$`0`(````)P0!``H````P!`$`)0```#L$`0`@````800!
M`!,```""!`$`$````)8$`0`/````IP0!``\```"W!`$`"@```,<$`0`'````
MT@0!``,```#:!`$`&0```-X$`0`/````^`0!`!0````(!0$`"0```!T%`0`-
M````)P4!`!(````U!0$`&0```$@%`0`>````8@4!``\```"!!0$`"@```)$%
M`0`/````G`4!``@```"L!0$`"@```+4%`0`D````P`4!`!<```#E!0$`%```
M`/T%`0`6````$@8!`!(````I!@$`"````#P&`0`<````108!`$X```!B!@$`
M+0```+$&`0`9````WP8!`&````#Y!@$`*````%H'`0`>````@P<!`!H```"B
M!P$`+````+T'`0`@````Z@<!`#(````+"`$`!P```#X(`0`,````1@@!``T`
M``!3"`$`5````&$(`0!C````M@@!`"P````:"0$`#@```$<)`0`#````5@D!
M``L```!:"0$`!P```&8)`0`'````;@D!``4```!V"0$`!0```'P)`0`*````
M@@D!``,```"-"0$`%P```)$)`0`*````J0D!``\```"T"0$`#@```,0)`0!.
M````TPD!`%`````B"@$`0P```',*`0!"````MPH!`#T```#Z"@$`%@```#@+
M`0`P````3PL!`!@```"`"P$`(P```)D+`0`.````O0L!`!0```#,"P$`%P``
M`.$+`0`7````^0L!`!<````1#`$`$P```"D,`0`/````/0P!`",```!-#`$`
M!@```'$,`0`7````>`P!``X```"0#`$`40```)\,`0`?````\0P!`!T````1
M#0$`-0```"\-`0`U````90T!``<```";#0$`!@```*,-`0`(````J@T!``\`
M``"S#0$`!@```,,-`0`(````R@T!`!$```#3#0$`"@```.4-`0`3````\`T!
M``L````$#@$`$````!`.`0`5````(0X!``T````W#@$`$P```$4.`0`C````
M60X!`"\```!]#@$`%0```*T.`0`'````PPX!`!````#+#@$`!0```-P.`0`5
M````X@X!`!$```#X#@$`#`````H/`0`_````%P\!`#````!7#P$`2````(@/
M`0`A````T0\!`#L```#S#P$`.P```"\0`0`\````:Q`!`#@```"H$`$`*P``
M`.$0`0`P````#1$!`#$````^$0$`.P```'`1`0`Y````K!$!`#4```#F$0$`
M"0```!P2`0`'````)A(!`!0````N$@$`#````$,2`0`#````4!(!``4```!4
M$@$`"0```%H2`0`0````9!(!``D```!U$@$`$P```'\2`0`#````DQ(!`#D`
M``"7$@$`$@```-$2`0`,````Y!(!`#4```#Q$@$`#@```"<3`0!)````-A,!
M`#,```"`$P$`"@```+03`0`6````OQ,!`!8```#6$P$`+0```.T3`0`+````
M&Q0!`"<````G%`$`+````$\4`0`J````?!0!`"4```"G%`$`"0```,T4`0`)
M````UQ0!``H```#A%`$`!@```.P4`0`)````\Q0!``<```#]%`$`+P````45
M`0`W````-14!`"X```!M%0$`50```)P5`0`M````\A4!`"P````@%@$`+0``
M`$T6`0`]````>Q8!`#\```"Y%@$`+0```/D6`0!`````)Q<!`",```!H%P$`
M(P```(P7`0!`````L!<!`"T```#Q%P$`,P```!\8`0`E````4Q@!`!4```!Y
M&`$`&0```(\8`0`I````J1@!`"0```#3&`$`*````/@8`0!0````(1D!`!@`
M``!R&0$`$0```(L9`0`1````G1D!``H```"O&0$`#````+H9`0`+````QQD!
M``H```#3&0$`(P```-X9`0`6`````AH!``H````9&@$`$````"0:`0`6````
M-1H!`!8```!,&@$`&P```&,:`0`N````?QH!`!````"N&@$`!P```+\:`0`'
M````QQH!`!0```#/&@$`"@```.0:`0`(````[QH!`"<```#X&@$`"````"`;
M`0`#````*1L!``<````M&P$`!P```#4;`0`&````/1L!`#@```!$&P$`!0``
M`'T;`0`'````@QL!``8```"+&P$`"````)(;`0`)````FQL!`"D```"E&P$`
M#@```,\;`0`*````WAL!`$4```#I&P$`!````"\<`0`$````-!P!``<````Y
M'`$`"0```$$<`0`&````2QP!`!$```!2'`$`!P```&0<`0`6````;!P!``0`
M``"#'`$`)P```(@<`0`(````L!P!``8```"Y'`$`#0```,`<`0`&````SAP!
M`!X```#5'`$`$0```/0<`0`(````!AT!``T````/'0$`#````!T=`0`'````
M*AT!``,````R'0$``P```#8=`0`7````.AT!`!,```!2'0$`"````&8=`0`=
M````;QT!``@```"-'0$`!````)8=`0`(````FQT!``@```"D'0$`*@```*T=
M`0`K````V!T!`%,````$'@$`00```%@>`0`:````FAX!`"L```"U'@$`(```
M`.$>`0`5`````A\!``8````8'P$`!@```!\?`0`.````)A\!`!4````U'P$`
M/@```$L?`0`8````BA\!`"(```"C'P$`+@```,8?`0`=````]1\!`"$````3
M(`$`5````#4@`0`I````BB`!``H```"T(`$`!P```+\@`0`'````QR`!`!4`
M``#/(`$`#@```.4@`0`"````]"`!``H```#W(`$`#P````(A`0`-````$B$!
M``\````@(0$`#0```#`A`0`)````/B$!`!0```!((0$`!@```%TA`0`8````
M9"$!`!T```!](0$`$P```)LA`0`1````KR$!`!0```#!(0$`3P```-8A`0`$
M````)B(!``P````K(@$`!@```#@B`0`*````/R(!``T```!*(@$`%````%@B
M`0!B````;2(!`"<```#0(@$`5````/@B`0!?````32,!`&0```"M(P$`!```
M`!(D`0`6````%R0!``X````N)`$`'````#TD`0`/````6B0!`#,```!J)`$`
M*````)XD`0`%````QR0!``4```#-)`$`&P```-,D`0`:````[R0!``X````*
M)0$`$P```!DE`0`5````+24!`#````!#)0$`$0```'0E`0`1````AB4!`!P`
M``"8)0$`*@```+4E`0`U````X"4!`$4````6)@$`$````%PF`0`A````;28!
M``4```"/)@$`$P```)4F`0`+````J28!`!(```"U)@$`"@```,@F`0`/````
MTR8!``T```#C)@$`1P```/$F`0`?````.2<!`"4```!9)P$`,P```'\G`0`K
M````LR<!`#4```#?)P$`0@```!4H`0`=````6"@!`%$```!V*`$`$0```,@H
M`0`Q````VB@!`#L````,*0$`$P```$@I`0!`````7"D!`#@```"=*0$`!0``
M`-8I`0`,````W"D!`!$```#I*0$`#0```/LI`0`&````"2H!``P````0*@$`
M!@```!TJ`0`7````)"H!``@````\*@$`#````$4J`0`4````4BH!``\```!G
M*@$`$````'<J`0`1````B"H!``@```":*@$`!0```*,J`0`1````J2H!``P`
M``"[*@$`$````,@J`0`%````V2H!``T```#?*@$`!@```.TJ`0`'````]"H!
M``T```#\*@$`!P````HK`0`+````$BL!``<````>*P$`!P```"8K`0`)````
M+BL!`!<````X*P$`)@```%`K`0!/````=RL!``D```#'*P$`"0```-$K`0`*
M````VRL!`!D```#F*P$`/0`````L`0`=````/BP!``P```!<+`$`)0```&DL
M`0`?````CRP!`!````"O+`$`!0```,`L`0`E````QBP!`"(```#L+`$`$@``
M``\M`0`3````(BT!`"L````V+0$`.P```&(M`0`@````GBT!`!L```"_+0$`
M"````-LM`0`V````Y"T!`"$````;+@$`$````#TN`0`(````3BX!`!L```!7
M+@$`'@```',N`0`O````DBX!`%P```#"+@$`+@```!\O`0`,````3B\!``8`
M``!;+P$`!````&(O`0`/````9R\!``X```!W+P$`#@```(8O`0`'````E2\!
M``X```"=+P$`!P```*PO`0`*````M"\!``T```"_+P$`'P```,TO`0`<````
M[2\!`"$````*,`$`'@```"PP`0`9````2S`!`!X```!E,`$`&P```(0P`0`L
M````H#`!`"$```#-,`$`+@```.\P`0`F````'C$!`"0```!%,0$`'````&HQ
M`0`>````AS$!`!P```"F,0$`)@```,,Q`0`V````ZC$!`"L````A,@$`,P``
M`$TR`0`I````@3(!`$$```"K,@$`.@```.TR`0`F````*#,!`"L```!/,P$`
M.````'LS`0`=````M#,!`!4```#2,P$`+P```.@S`0`@````&#0!`!(````Y
M-`$`*0```$PT`0`>````=C0!`#T```"5-`$`(````-,T`0`2````]#0!`*(`
M```'-0$`%@```*HU`0`C````P34!`"@```#E-0$`*0````XV`0`Z````.#8!
M`"@```!S-@$`'P```)PV`0`5````O#8!`"````#2-@$`)0```/,V`0`H````
M&3<!`"T```!"-P$`,````'`W`0"2````H3<!`"$````T.`$`%@```%8X`0`<
M````;3@!`"8```"*.`$`*@```+$X`0!!````W#@!`$0````>.0$`#````&,Y
M`0`'````<#D!``<```!X.0$`!@```(`Y`0`-````ASD!``L```"5.0$`%```
M`*$Y`0`-````MCD!`!@```#$.0$`&@```-TY`0`0````^#D!`!T````).@$`
M&0```"<Z`0!=````03H!`!4```"?.@$`)0```+4Z`0`2````VSH!`!,```#N
M.@$`$@````([`0`'````%3L!``0````=.P$`$````"([`0`0````,SL!``P`
M``!$.P$`#@```%$[`0`-````8#L!``\```!N.P$`%````'X[`0`3````DSL!
M``T```"G.P$`.0```+4[`0`<````[SL!`"@````,/`$``P```#4\`0`-````
M.3P!``8```!'/`$`$0```$X\`0`7````8#P!`!L```!X/`$`#@```)0\`0`"
M````HSP!`$D```"F/`$`!0```/`\`0`%````]CP!`!````#\/`$`#P````T]
M`0`$````'3T!``T````B/0$`#@```#`]`0`#````/ST!``X```!#/0$`"```
M`%(]`0`/````6ST!``@```!K/0$`"@```'0]`0`/````?ST!``<```"//0$`
M#0```)<]`0`0````I3T!`!0```"V/0$`#0```,L]`0`9````V3T!`!H```#S
M/0$`"P````X^`0`)````&CX!``8````D/@$`%````"L^`0`+````0#X!`!,`
M``!,/@$`$````&`^`0`,````<3X!``H```!^/@$`$0```(D^`0`7````FSX!
M`!$```"S/@$`%0```,4^`0`G````VSX!`!D````#/P$`"P```!T_`0`-````
M*3\!`"(````W/P$`*P```%H_`0`7````AC\!`#0```">/P$`,P```-,_`0`;
M````!T`!`#0````C0`$`"@```%A``0`8````8T`!`!0```!\0`$`&0```)%`
M`0`6````JT`!``<```#"0`$`$````,I``0`B````VT`!`!P```#^0`$`'```
M`!M!`0`-````.$$!``<```!&00$`#````$Y!`0`F````6T$!``H```""00$`
M%````(U!`0`+````HD$!``<```"N00$`(@```+9!`0`O````V4$!``L````)
M0@$`"0```!5"`0`9````'T(!``L````Y0@$`*@```$5"`0`/````<$(!`!<`
M``"`0@$`%P```)A"`0`)````L$(!``<```"Z0@$`%@```,)"`0`/````V4(!
M`"T```#I0@$`&0```!=#`0`6````,4,!``X```!(0P$`&@```%=#`0`H````
M<D,!`"T```";0P$`+@```,E#`0`+````^$,!`!@````$1`$`"````!U$`0`,
M````)D0!`",````S1`$`#0```%=$`0`F````940!`"H```",1`$`(````+=$
M`0!#````V$0!``@````<10$`$@```"5%`0`?````.$4!``0```!810$`"```
M`%U%`0`+````9D4!`!H```!R10$`)P```(U%`0`2````M44!`"````#(10$`
M+P```.E%`0`7````&48!``4````Q1@$`#````#=&`0`.````1$8!``X```!3
M1@$`!0```&)&`0`&````:$8!``X```!O1@$`10```'Y&`0`#````Q$8!``,`
M``#(1@$`*P```,Q&`0`'````^$8!``0`````1P$`#@````5'`0`*````%$<!
M``P````?1P$`"@```"Q'`0`/````-T<!`!````!'1P$`%P```%A'`0`1````
M<$<!`!,```""1P$`)0```)9'`0`.````O$<!`!$```#+1P$`&0```-U'`0`7
M````]T<!`!,````/2`$`%@```"-(`0`X````.D@!`!,```!S2`$`"0```(=(
M`0`%````D4@!``L```"72`$`"@```*-(`0`"````KD@!``4```"Q2`$`#0``
M`+=(`0`;````Q4@!`!<```#A2`$`%````/E(`0`)````#DD!`!T````820$`
M+P```#9)`0`/````9DD!`!8```!V20$`$@```(U)`0`+````H$D!``P```"L
M20$`#@```+E)`0`-````R$D!`!(```#620$`&0```.E)`0`<`````TH!`#@`
M```@2@$`&````%E*`0`@````<DH!`!,```"32@$`"0```*=*`0`#````L4H!
M`!4```"U2@$`"P```,M*`0`3````UTH!``@```#K2@$`#@```/1*`0`0````
M`TL!`'L````42P$`&````)!+`0`8````J4L!`"<```#"2P$`*0```.I+`0`L
M````%$P!`"@```!!3`$`#@```&I,`0`U````>4P!`!$```"O3`$`!P```,%,
M`0`%````R4P!`"D```#/3`$`&````/E,`0`>````$DT!`!L````Q30$`&0``
M`$U-`0`8````9TT!`!L```"`30$`&0```)Q-`0`3````MDT!``<```#*30$`
M"````-)-`0`&````VTT!``8```#B30$`&P```.E-`0`0````!4X!``\````6
M3@$`$````"9.`0`/````-TX!``L```!'3@$`#P```%-.`0`,````8TX!``\`
M``!P3@$`!P```(!.`0`&````B$X!``H```"/3@$`$@```)I.`0`-````K4X!
M``P```"[3@$`#@```,A.`0!#````UTX!`#T````;3P$`"0```%E/`0`,````
M8T\!`"@```!P3P$`#P```)E/`0`(````J4\!``@```"R3P$`$P```+M/`0`+
M````ST\!`!X```#;3P$`(0```/I/`0`@````'%`!`!D````]4`$`%P```%=0
M`0`E````;U`!`!<```"54`$`%@```*U0`0`$````Q%`!`!L```#)4`$`#0``
M`.50`0`,````\U`!``,`````40$`!0````11`0`(````"E$!``H````340$`
M#````!Y1`0`*````*U$!`"`````V40$`'P```%=1`0`;````=U$!`!D```"3
M40$`"P```*U1`0`;````N5$!``L```#540$`$````.%1`0`(````\E$!``P`
M``#[40$`#@````A2`0`+````%U(!``0````C4@$`!````"A2`0`3````+5(!
M`!0```!!4@$`#````%92`0`)````8U(!``X```!M4@$`"P```'Q2`0`;````
MB%(!``X```"D4@$`#P```+-2`0`E````PU(!`"H```#I4@$`!P```!13`0`2
M````'%,!`!L````O4P$`!````$M3`0`'````4%,!``H```!84P$`$@```&-3
M`0`*````=E,!``T```"!4P$`"0```(]3`0`$````F5,!``4```">4P$`"```
M`*13`0`#````K5,!`!@```"Q4P$`'0```,I3`0`0````Z%,!``X```#Y4P$`
M'@````A4`0`:````)U0!``H```!"5`$`!````$U4`0`F````4E0!``X```!Y
M5`$`?````(A4`0`5````!54!`$0````;50$`!0```&!5`0`'````9E4!``P`
M``!N50$`"````'M5`0`*````A%4!``8```"/50$`!P```)95`0`(````GE4!
M`!$```"G50$`&0```+E5`0`(````TU4!``(```#<50$`!@```-]5`0`&````
MYE4!`!0```#M50$`&@````)6`0`-````'58!`!`````K5@$`&P```#Q6`0`%
M````6%8!``0```!>5@$`#````&-6`0`)````<%8!`!````!Z5@$`"0```(M6
M`0`)````E58!``0```"?5@$`!0```*16`0`:````JE8!``4```#%5@$`&@``
M`,M6`0`(````YE8!``8```#O5@$`#P```/96`0`9````!E<!``X````@5P$`
M!P```"]7`0`'````-U<!`"(````_5P$`!0```&)7`0`)````:%<!``H```!R
M5P$`#@```'U7`0`"````C%<!``T```"/5P$`(````)U7`0`&````OE<!``L`
M``#%5P$`#0```-%7`0`,````WU<!``D```#L5P$`!@```/97`0`2````_5<!
M``D````06`$`!P```!I8`0`4````(E@!`!T````W6`$`0@```%58`0`E````
MF%@!`"4```"^6`$`!@```.18`0`*````ZU@!``0```#V6`$`"0```/M8`0`(
M````!5D!`!$````.60$`"0```"!9`0`&````*ED!``T````Q60$`!@```#]9
M`0`$````1ED!``0```!+60$`%P```%!9`0`Y````:%D!`#T```"B60$`.@``
M`.!9`0`>````&UH!``4````Z6@$`#@```$!:`0`$````3UH!``8```!46@$`
M!P```%M:`0`A````8UH!``T```"%6@$`%0```)-:`0`&````J5H!``0```"P
M6@$`$0```+5:`0`&````QUH!``H```#.6@$`(@```-E:`0`G````_%H!``8`
M```D6P$`%0```"M;`0`,````05L!`!$```!.6P$`!````&!;`0`-````95L!
M``<```!S6P$`!0```'M;`0`=````@5L!``0```"?6P$`#````*1;`0`.````
ML5L!``H```#`6P$`"````,M;`0`)````U%L!``4```#>6P$`.@```.1;`0`P
M````'UP!`#4```!07`$`*0```(9<`0!'````L%P!`#@```#X7`$`*0```#%=
M`0`_````6UT!`"X```";70$`+0```,I=`0`?````^%T!``\````87@$`$@``
M`"A>`0`+````.UX!`"8```!'7@$`)P```&Y>`0`I````EEX!`"0```#`7@$`
M)@```.5>`0`H````#%\!``@````U7P$`"@```#Y?`0`)````25\!``<```!3
M7P$`!````%M?`0`<````8%\!`#<```!]7P$`(````+5?`0`@````UE\!`"8`
M``#W7P$`#0```!Y@`0`G````+&`!`!L```!48`$`(@```'!@`0`,````DV`!
M`!8```"@8`$`!0```+=@`0`*````O6`!`!D```#(8`$`*0```.)@`0`6````
M#&$!`!(````C80$`!P```#9A`0`*````/F$!``P```!)80$`#P```%9A`0`0
M````9F$!`$````!W80$`1````+AA`0`\````_6$!`'`````Z8@$`9@```*MB
M`0`&````$F,!``H````98P$`!0```"1C`0`.````*F,!``D````Y8P$`"@``
M`$-C`0`2````3F,!`!,```!A8P$`#````'5C`0`&````@F,!``8```")8P$`
M"@```)!C`0`.````FV,!``\```"J8P$`#@```+IC`0`;````R6,!`!\```#E
M8P$`'@````5D`0`C````)&0!`!$```!(9`$`%0```%ID`0`8````<&0!`!$`
M``")9`$`$````)MD`0`C````K&0!``\```#09`$`"0```.!D`0`2````ZF0!
M`!T```#]9`$`$@```!ME`0`0````+F4!``H````_90$`$0```$IE`0`%````
M7&4!`#$```!B90$`)````)1E`0`<````N64!`",```#690$`:@```/IE`0`/
M````968!``4```!U9@$`$````'MF`0`)````C&8!``0```"69@$`"P```)MF
M`0`@````IV8!`!P```#(9@$`(P```.5F`0`B````"6<!``8````L9P$`%```
M`#-G`0`7````2&<!``P```!@9P$`)````&UG`0`C````DF<!`!H```"V9P$`
M#````-%G`0`/````WF<!`!4```#N9P$`*0````1H`0`J````+F@!`"8```!9
M:`$`)P```(!H`0`I````J&@!`"H```#2:`$`&0```/UH`0!"````%VD!`!$`
M``!::0$`$@```&QI`0`3````?VD!`!0```"3:0$`#P```*AI`0`6````N&D!
M`!<```#/:0$`$````.=I`0`1````^&D!`#0````*:@$`$P```#]J`0`2````
M4VH!`#4```!F:@$`%````)QJ`0`'````L6H!``P```"Y:@$`*P```,9J`0`/
M````\FH!`!8````":P$`(````!EK`0`0````.FL!`!0```!+:P$`$0```&!K
M`0`H````<FL!`!<```";:P$`'````+-K`0`3````T&L!``L```#D:P$`%```
M`/!K`0`:````!6P!`!$````@;`$`&@```#)L`0`>````36P!`!H```!L;`$`
M$P```(=L`0`A````FVP!`"````"];`$`%0```-YL`0`1````]&P!`!<````&
M;0$`%````!YM`0`7````,VT!`!4```!+;0$`"0```&%M`0`&````:VT!`!``
M``!R;0$`&0```(-M`0`$````G6T!``<```"B;0$`"P```*IM`0`1````MFT!
M``8```#(;0$`!@```,]M`0`&````UFT!``4```#=;0$`!P```.-M`0`'````
MZVT!``4```#S;0$`%@```/EM`0`&````$&X!``8````7;@$`!````!YN`0`$
M````(VX!``<````H;@$`#@```#!N`0`,````/VX!``P```!,;@$`#0```%EN
M`0`"````9VX!``H```!J;@$`#@```'5N`0`%````A&X!`"@```"*;@$`#@``
M`+-N`0`,````PFX!``\```#/;@$`"@```-]N`0`(````ZFX!``D```#S;@$`
M*P```/UN`0!/````*6\!`$<```!Y;P$`4P```,%O`0`N````%7`!``0```!$
M<`$`"````$EP`0`F````4G`!`!(```!Y<`$`#P```(QP`0`&````G'`!``H`
M``"C<`$`!P```*YP`0`(````MG`!`"````"_<`$`"0```.!P`0`1````ZG`!
M``D```#\<`$`%`````9Q`0`,````&W$!``T````H<0$`#@```#9Q`0`6````
M17$!`!$```!<<0$`!@```&YQ`0`#````=7$!``8```!Y<0$`&0```(!Q`0`'
M````FG$!``0```"B<0$`"P```*=Q`0`+````LW$!``<```"_<0$`!0```,=Q
M`0`'````S7$!`!8```#5<0$`#0```.QQ`0`-````^G$!``H````(<@$`$```
M`!-R`0`/````)'(!`!$````T<@$`%P```$9R`0`*````7G(!`!$```!I<@$`
M"````'MR`0`$````A'(!`!$```")<@$`#P```)MR`0`Z````JW(!`"$```#F
M<@$`!0````AS`0`7````#G,!``P````F<P$`'@```#-S`0`.````4G,!`!``
M``!A<P$`"P```')S`0!\````?G,!``P```#[<P$`"0````AT`0`'````$G0!
M``H````:=`$`"0```"5T`0`.````+W0!`!`````^=`$`%0```$]T`0`;````
M970!`!@```"!=`$`&@```)IT`0`*````M70!``D```#`=`$`"@```,IT`0`.
M````U70!``P```#D=`$`#P```/%T`0`(`````74!``8````*=0$`#````!%U
M`0`<````'G4!``<````[=0$`!0```$-U`0`+````274!`$<```!5=0$`#0``
M`)UU`0`)````JW4!``0```"U=0$``P```+IU`0`,````OG4!`!,```#+=0$`
M$P```-]U`0`3````\W4!``8````'=@$`"@````YV`0`"````&78!``0````<
M=@$`)0```"%V`0`#````1W8!``4```!+=@$`*@```%%V`0`.````?'8!``H`
M``"+=@$`!0```)9V`0`$````G'8!``H```"A=@$`#0```*QV`0`?````NG8!
M``<```#:=@$`(@```.)V`0`-````!7<!``8````3=P$`"````!IW`0`(````
M(W<!``0````L=P$`!0```#%W`0!H````-W<!``D```"@=P$`#````*IW`0`0
M````MW<!``4```#(=P$`!@```,YW`0`C````U7<!`"4```#Y=P$`"````!]X
M`0`W````*'@!`"(```!@>`$`$P```(-X`0`;````EW@!`"\```"S>`$`$```
M`.-X`0`*````]'@!`!$```#_>`$`#P```!%Y`0`/````(7D!``H````Q>0$`
M"0```#QY`0`3````1GD!`!L```!:>0$`&````'9Y`0`7````CWD!`!<```"G
M>0$`&0```+]Y`0`?````V7D!``X```#Y>0$`)@````AZ`0`F````+WH!``,`
M``!6>@$`!P```%IZ`0`(````8GH!``<```!K>@$`$````'-Z`0`*````A'H!
M``L```"/>@$`!P```)MZ`0`3````HWH!``P```"W>@$`#P```,1Z`0`.````
MU'H!``P```#C>@$`#@```/!Z`0!1````_WH!``\```!1>P$`$````&%[`0`-
M````<GL!``\```"`>P$`#P```)![`0`7````H'L!`!0```"X>P$`$0```,U[
M`0`/````WWL!`"````#O>P$`+@```!!\`0`:````/WP!``P```!:?`$`)@``
M`&=\`0`+````CGP!``T```":?`$`&@```*A\`0!*````PWP!`!D````.?0$`
M!@```"A]`0`:````+WT!`"4```!*?0$`!@```'!]`0`&````=WT!`!\```!^
M?0$`!@```)Y]`0`)````I7T!`!@```"O?0$`%P```,A]`0`H````X'T!``8`
M```)?@$`#0```!!^`0`B````'GX!`%<```!!?@$`$P```)E^`0`C````K7X!
M`!,```#1?@$``@```.5^`0`+````Z'X!``@```#T?@$`#0```/U^`0`&````
M"W\!``H````2?P$`!P```!U_`0`4````)7\!``8````Z?P$`"````$%_`0`.
M````2G\!``<```!9?P$`"@```&%_`0`+````;'\!`#(```!X?P$`*P```*M_
M`0`'````UW\!``P```#??P$`#0```.Q_`0`,````^G\!``0````'@`$`"0``
M``R``0`)````%H`!``H````@@`$`!P```"N``0`)````,X`!`$`````]@`$`
M#@```'Z``0`'````C8`!``H```"5@`$`&P```*"``0`/````O(`!`!4```#,
M@`$`%0```.*``0`2````^(`!``H````+@0$`%@```!:!`0`)````+8$!`!``
M```W@0$`!P```$B!`0`2````4($!``0```!C@0$`!````&B!`0`$````;8$!
M`"$```!R@0$`!P```)2!`0`%````G($!``P```"B@0$`!0```*^!`0`+````
MM8$!`!0```#!@0$`$0```-:!`0`:````Z($!`!8````#@@$`%````!J"`0`7
M````+X(!`!@```!'@@$`'````&""`0`9````?8(!``<```"7@@$`!0```)^"
M`0`6````I8(!``,```"\@@$`#0```,""`0`,````SH(!``H```#;@@$`"```
M`.:"`0`+````[X(!`!$```#[@@$`"`````V#`0`7````%H,!``L````N@P$`
M#````#J#`0`,````1X,!`!\```!4@P$`&@```'2#`0`3````CX,!``0```"C
M@P$`"@```*B#`0`$````LX,!``T```"X@P$`#````,:#`0`)````TX,!``P`
M``#=@P$`!0```.J#`0`)````\(,!``4```#Z@P$`!P````"$`0`%````"(0!
M``0````.A`$``@```!.$`0`4````%H0!``T````KA`$`$@```#F$`0`+````
M3(0!`!L```!8A`$`'P```'2$`0`/````E(0!`!0```"DA`$`'@```+F$`0`5
M````V(0!`#@```#NA`$`+````">%`0`2````5(4!`"D```!GA0$`,@```)&%
M`0`*````Q(4!`"P```#/A0$`+@```/R%`0`S````*X8!`#,```!?A@$`.```
M`).&`0`/````S(8!`!@```#<A@$`+P```/6&`0`0````)8<!`!,````VAP$`
M*@```$J'`0`9````=8<!`!P```"/AP$`'P```*R'`0`/````S(<!`!,```#<
MAP$`%0```/"'`0`4````!H@!`!0````;B`$`%````#"(`0`@````18@!`!(`
M``!FB`$`%````'F(`0`5````CH@!`"T```"DB`$`+0```-*(`0`Q`````(D!
M`"X````RB0$`+P```&&)`0`L````D8D!`&(```"^B0$`$P```"&*`0`E````
M-8H!`"0```!;B@$`*0```("*`0!(````JHH!``T```#SB@$`"`````&+`0`7
M````"HL!``@````BBP$`)````"N+`0`2````4(L!``P```!CBP$`#@```'"+
M`0`W````?XL!`"L```"WBP$`$@```..+`0`A````]HL!`!H````8C`$`"0``
M`#.,`0!%````/8P!`$$```"#C`$`#P```,6,`0`$````U8P!`!,```#:C`$`
M%````.Z,`0`.`````XT!``8````2C0$`$P```!F-`0`8````+8T!``8```!&
MC0$`"0```$V-`0`*````5XT!``L```!BC0$`"0```&Z-`0`-````>(T!``P`
M``"&C0$`#P```).-`0`7````HXT!`!0```"[C0$`$````-"-`0`6````X8T!
M``<```#XC0$`#@````".`0`A````#XX!``4````QC@$`!P```#>.`0`;````
M/XX!`"H```!;C@$`"````(:.`0`&````CXX!`!0```"6C@$`$0```*N.`0!$
M````O8X!`#P````"CP$`#@```#^/`0`X````3H\!``(```"'CP$``@```(J/
M`0`&````C8\!``X```"4CP$`!0```*./`0`'````J8\!``X```"QCP$`!@``
M`,"/`0`H````QX\!``P```#PCP$`#````/V/`0`<````"I`!`",````GD`$`
M!````$N0`0`I````4)`!`#(```!ZD`$`%P```*V0`0`?````Q9`!`#,```#E
MD`$`7````!F1`0`,````=I$!`!0```"#D0$`/@```)B1`0`-````UY$!`!\`
M``#ED0$`$`````62`0`4````%I(!``<````KD@$`#@```#.2`0`,````0I(!
M``P```!/D@$`$P```%R2`0`*````<)(!`!T```![D@$`&0```)F2`0`%````
MLY(!`!$```"YD@$`$P```,N2`0`-````WY(!``\```#MD@$`$0```/V2`0`D
M````#Y,!`!(````TDP$``P```$>3`0`5````2Y,!`!,```!ADP$`$@```'63
M`0`+````B),!`#0```"4DP$`"P```,F3`0`4````U9,!`#X```#JDP$`#@``
M`"F4`0`3````.)0!`#0```!,E`$`,0```(&4`0`2````LY0!`!````#&E`$`
M&````->4`0`9````\)0!`",````*E0$`(@```"Z5`0`G````494!`%8```!Y
ME0$`30```-"5`0"Y````'I8!``@```#8E@$`"0```.&6`0`-````ZY8!``<`
M``#YE@$`"@````&7`0`'````#)<!``\````4EP$`!@```"27`0`+````*Y<!
M``0````WEP$`'````#R7`0`-````69<!`"<```!GEP$`&P```(^7`0`,````
MJY<!`!H```"XEP$`"@```-.7`0`'````WI<!``T```#FEP$`(@```/27`0`A
M````%Y@!``@````YF`$`!0```$*8`0`?````2)@!``8```!HF`$`$````&^8
M`0`(````@)@!``<```")F`$`#0```)&8`0`*````GY@!`!(```"JF`$`(0``
M`+V8`0`+````WY@!`!L```#KF`$`&`````>9`0`(````()D!`!X````IF0$`
M$@```$B9`0`L````6YD!`!H```"(F0$`"0```*.9`0`*````K9D!`!4```"X
MF0$`!0```,Z9`0`4````U)D!``0```#IF0$`$````.Z9`0`&````_YD!``<`
M```&F@$`'@````Z:`0`H````+9H!``H```!6F@$`'````&&:`0`1````?IH!
M``L```"0F@$`&@```)R:`0`L````MYH!``@```#DF@$`%````.V:`0`L````
M`IL!`"<````OFP$`*P```%>;`0`J````@YL!``0```"NFP$`!````+.;`0`+
M````N)L!``4```#$FP$`!@```,J;`0`(````T9L!``8```#:FP$`,0```.&;
M`0`<````$YP!``H````PG`$`H@```#N<`0`;````WIP!`#0```#ZG`$`-```
M`"^=`0`@````9)T!`"D```"%G0$`)P```*^=`0`@````UYT!`$$```#XG0$`
M&@```#J>`0`H````59X!`!H```!^G@$`=@```)F>`0!Y````$)\!`!P!``"*
MGP$`*````*>@`0`=````T*`!`"D```#NH`$`'0```!BA`0!0````-J$!`"X`
M``"'H0$`-@```+:A`0`L````[:$!`#$````:H@$`+@```$RB`0`B````>Z(!
M``8```">H@$`"````*6B`0`%````KJ(!``@```"TH@$`&0```+VB`0`9````
MUZ(!`"H```#QH@$`$````!RC`0`K````+:,!`",```!9HP$`&0```'VC`0`A
M````EZ,!`"X```"YHP$`-````.BC`0`(````':0!`!<````FI`$`"@```#ZD
M`0`'````2:0!`"$```!1I`$`$````'.D`0`-````A*0!`!````"2I`$`!0``
M`*.D`0`.````J:0!``@```"XI`$`"P```,&D`0`4````S:0!``<```#BI`$`
M$P```.JD`0`(````_J0!`#8````'I0$`-P```#ZE`0`+````=J4!``D```""
MI0$`"@```(RE`0`4````EZ4!``\```"LI0$`+P```+RE`0`R````[*4!``L`
M```?I@$`#@```"NF`0`-````.J8!``\```!(I@$`%@```%BF`0`^````;Z8!
M`"<```"NI@$`)@```-:F`0`D````_:8!``4````BIP$`!0```"BG`0`%````
M+J<!`"<````TIP$`'P```%RG`0`6````?*<!``L```"3IP$`%P```)^G`0`/
M````MZ<!``0```#'IP$`"@```,RG`0`)````UZ<!``L```#AIP$`#0```.VG
M`0`,````^Z<!``X````(J`$`!0```!>H`0`$````':@!``T````BJ`$`,@``
M`#"H`0!%````8Z@!`!,```"IJ`$`"P```+VH`0`.````R:@!``X```#8J`$`
M"0```.>H`0`(````\:@!`!````#ZJ`$`%0````NI`0`3````(:D!`!<````U
MJ0$`!P```$VI`0`>````5:D!`!4```!TJ0$`%````(JI`0`%````GZD!`!0`
M``"EJ0$`!@```+JI`0`+````P:D!``<```#-J0$`(P```-6I`0`6````^:D!
M``\````0J@$`#@```""J`0`J````+ZH!``8```!:J@$`#````&&J`0`8````
M;JH!``T```"'J@$`$0```)6J`0`+````IZH!`#8```"SJ@$`#0```.JJ`0`*
M````^*H!`"(````#JP$`"P```":K`0`/````,JL!`!````!"JP$`+@```%.K
M`0`Z````@JL!``X```"]JP$`#0```,RK`0`%````VJL!``L```#@JP$`#```
M`.RK`0`-````^:L!``T````'K`$`#@```!6L`0`-````)*P!`"`````RK`$`
M)P```%.L`0`K````>ZP!``@```"GK`$`"@```+"L`0`&````NZP!`!(```#"
MK`$`#@```-6L`0`7````Y*P!`#(```#\K`$`%@```"^M`0`<````1JT!`"4`
M``!CK0$`,````(FM`0`Q````NJT!`"T```#LK0$`#@```!JN`0`4````*:X!
M``4````^K@$`#@```$2N`0`3````4ZX!`!H```!GK@$`$@```(*N`0`'````
ME:X!``8```"=K@$`$P```*2N`0`?````N*X!`!0```#8K@$`$0```.VN`0!+
M````_ZX!`!,```!+KP$`!P```%^O`0`4````9Z\!`!@```!\KP$`!P```)6O
M`0`%````G:\!``P```"CKP$`#````+"O`0`2````O:\!``0```#0KP$`!P``
M`-6O`0`*````W:\!``L```#HKP$`#````/2O`0`.`````;`!``X````0L`$`
M!0```!^P`0`%````);`!`"X````KL`$`)@```%JP`0`C````@;`!``,```"E
ML`$`$@```*FP`0`&````O+`!``8```##L`$`'@```,JP`0`6````Z;`!`!@`
M````L0$`#@```!FQ`0`W````*+$!``X```!@L0$`%P```&^Q`0!!````A[$!
M`#0```#)L0$`)0```/ZQ`0`5````)+(!`#$````ZL@$`$P```&RR`0`;````
M@+(!`"H```"<L@$`40```,>R`0!9````&;,!`%````!SLP$`OP```,2S`0`E
M````A+0!``T```"JM`$`!````+BT`0`)````O;0!`!\```#'M`$``P```.>T
M`0`'````Z[0!``H```#SM`$`"````/ZT`0`"````![4!`!`````*M0$`"```
M`!NU`0`,````)+4!`!4````QM0$`"P```$>U`0`9````4[4!`"````!MM0$`
M$@```(ZU`0`%````H;4!``H```"GM0$`%0```+*U`0`2````R+4!``P```#;
MM0$`!````.BU`0`)````[;4!``<```#WM0$`,@```/^U`0`*````,K8!``H`
M```]M@$`%0```$BV`0`,````7K8!``\```!KM@$`"P```'NV`0`'````A[8!
M`!8```"/M@$`4@```*:V`0`Z````^;8!`"`````TMP$`#P```%6W`0`7````
M9;<!`"0```!]MP$`.0```**W`0`2````W+<!``<```#OMP$`!@```/>W`0`)
M````_K<!``X````(N`$`#@```!>X`0`.````)K@!``0````UN`$`!@```#JX
M`0`6````0;@!``P```!8N`$`#0```&6X`0`.````<[@!`!4```""N`$`$@``
M`)BX`0`/````J[@!`!0```"[N`$`%````-"X`0!#````Y;@!``H````IN0$`
M&P```#2Y`0`U````4+D!`!$```"&N0$`$````)BY`0`+````J;D!`&D```"U
MN0$`&@```!^Z`0`7````.KH!`"@```!2N@$`)P```'NZ`0`;````H[H!`!H`
M``"_N@$`%P```-JZ`0`;````\KH!`!D````.NP$`'P```"B[`0`7````2+L!
M`!P```!@NP$`%P```'V[`0`,````E;L!`!,```"BNP$`"````+:[`0`?````
MO[L!`"\```#?NP$`!P````^\`0`(````%[P!`!`````@O`$`$0```#&\`0`)
M````0[P!`!4```!-O`$`#0```&.\`0`&````<;P!`!T```!XO`$`(P```):\
M`0`'````NKP!``T```#"O`$`$P```-"\`0`(````Y+P!``,```#MO`$`1@``
M`/&\`0!#````.+T!`#(```!\O0$`/P```*^]`0`W````[[T!`%<````GO@$`
M!0```'^^`0`?````A;X!`"\```"EO@$`"@```-6^`0`-````X+X!`!(```#N
MO@$`*0````&_`0`(````*[\!``T````TOP$`+0```$*_`0!P````<+\!`#\`
M``#AOP$`.0```"'``0!&````6\`!``0```"BP`$`$````*?``0`0````N,`!
M``P```#)P`$`%````-;``0`=````Z\`!`!P````)P0$`$0```";!`0`]````
M.,$!`$\```!VP0$`)0```,;!`0`@````[,$!`!P````-P@$`"P```"K"`0`G
M````-L(!`!H```!>P@$`'P```'G"`0`=````F<(!`"@```"WP@$`#P```.#"
M`0`E````\,(!`"`````6PP$`)````#?#`0`D````7,,!`"````"!PP$`)0``
M`*+#`0`+````R,,!``<```#4PP$`#0```-S#`0`,````ZL,!`!<```#WPP$`
M!0````_$`0`&````%<0!`#D````<Q`$`!0```%;$`0`,````7,0!``<```!I
MQ`$`"0```''$`0`3````>\0!``8```"/Q`$`"0```);$`0`$````H,0!`!``
M``"EQ`$`"````+;$`0`(````O\0!``0```#(Q`$`"P```,W$`0`,````V<0!
M`!(```#FQ`$`$0```/G$`0`,````"\4!`!H````8Q0$`#P```#/%`0`'````
M0\4!``T```!+Q0$`#P```%G%`0`,````:<4!`!0```!VQ0$`%````(O%`0`/
M````H,4!``X```"PQ0$`$@```+_%`0`4````TL4!``X```#GQ0$`#````/;%
M`0`;`````\8!`"P````?Q@$`$P```$S&`0`<````8,8!`"@```!]Q@$`!@``
M`*;&`0`'````K<8!`!,```"UQ@$`!0```,G&`0`$````S\8!``P```#4Q@$`
M%P```.'&`0`2````^<8!`"D````,QP$`"P```#;'`0`-````0L<!`!0```!0
MQP$`+P```&7'`0`*````E<<!``P```"@QP$`"0```*W'`0`&````M\<!``D`
M``"^QP$`"````,C'`0`)````T<<!``4```#;QP$`"@```.''`0`1````[,<!
M``H```#^QP$`$`````G(`0`0````&L@!``L````KR`$`!@```#?(`0`.````
M/L@!``X```!-R`$`#0```%S(`0`+````:L@!`!````!VR`$`'0```(?(`0`1
M````I<@!``L```"WR`$``@```,/(`0`(````QL@!`!P```#/R`$`!P```.S(
M`0`-````],@!``8````"R0$`9`````G)`0`6````;LD!``D```"%R0$`!P``
M`(_)`0`F````E\D!`#@```"^R0$`&@```/?)`0`J````$LH!`#L````]R@$`
M*````'G*`0`T````HLH!`!D```#7R@$`%0```/'*`0`%````!\L!``L````-
MRP$`!P```!G+`0`(````(<L!``<````JRP$`!0```#++`0`'````.,L!``X`
M``!`RP$`"0```$_+`0`&````6<L!``@```!@RP$`"P```&G+`0`'````=<L!
M``@```!]RP$`!P```(;+`0`6````CLL!``D```"ERP$`!@```*_+`0`9````
MMLL!`!H```#0RP$`(````.O+`0`+````#,P!`!`````8S`$`!@```"G,`0`<
M````,,P!`!0```!-S`$`!P```&+,`0`1````:LP!``@```!\S`$`#@```(7,
M`0`(````E,P!``4```"=S`$`$````*/,`0`)````M,P!`!````"^S`$`!@``
M`,_,`0`9````ULP!``H```#PS`$`'````/O,`0`'````&,T!``4````@S0$`
M!0```";-`0`0````+,T!`!0````]S0$`"P```%+-`0`-````7LT!`"@```!L
MS0$`&````)7-`0`7````KLT!``L```#&S0$`&@```-+-`0`4````[<T!`"\`
M```"S@$`!````#+.`0`)````-\X!``H```!!S@$`!P```$S.`0`"````5,X!
M``X```!7S@$`"````&;.`0`C````;\X!`#$```"3S@$`'P```,7.`0`X````
MY<X!`'@````>SP$`)@```)?/`0`;````OL\!`#$```#:SP$`,0````S0`0`G
M````/M`!`"(```!FT`$`(````(G0`0!D````JM`!`!T````/T0$`%````"W1
M`0`<````0M$!`%T```!?T0$`50```+W1`0`X````$](!`"T```!,T@$`,P``
M`'K2`0!+````KM(!`$H```#ZT@$`6P```$73`0`H````H=,!`"P```#*TP$`
M.````/?3`0`E````,-0!`"$```!6U`$`*````'C4`0`L````H=0!`"8```#.
MU`$`&P```/74`0`>````$=4!`'4````PU0$`/@```*;5`0!"````Y=4!`#T`
M```HU@$`/0```&;6`0`I````I-8!`"D```#.U@$`,0```/C6`0`^````*M<!
M`"\```!IUP$`J0$``)G7`0`C````0]D!`&(```!GV0$`3P```,K9`0`7````
M&MH!`$@````RV@$`-@```'O:`0`^````LMH!`#````#QV@$`(````"+;`0`_
M````0]L!`#0```"#VP$`+````+C;`0`=````Y=L!`!X````#W`$`*@```"+<
M`0"%````3=P!`#````#3W`$`)0````3=`0!!````*MT!`&````!LW0$`6P``
M`,W=`0!)````*=X!`#$```!SW@$`-````*7>`0`\````VMX!`#@````7WP$`
M'0```%#?`0`8````;M\!`*<```"'WP$`*P```"_@`0`A````6^`!`!\```!]
MX`$`/````)W@`0`D````VN`!`"@```#_X`$`*P```"CA`0`B````5.$!`"8`
M``!WX0$`(P```)[A`0`E````PN$!`"4```#HX0$`*0````[B`0`G````..(!
M`!<```!@X@$`*0```'CB`0`@````HN(!`#(```##X@$`'````/;B`0`N````
M$^,!`#H```!"XP$`'0```'WC`0`1````F^,!`#,```"MXP$`)0```.'C`0`X
M````!^0!`"<```!`Y`$`(````&CD`0`\````B>0!`"8```#&Y`$`'P```.WD
M`0`P````#>4!`&D````^Y0$`+@```*CE`0`Q````U^4!`$$````)Y@$`/@``
M`$OF`0`S````BN8!`"4```"^Y@$`/0```.3F`0!E````(N<!`$T```"(YP$`
M4P```-;G`0!7````*N@!`%4```""Z`$`1@```-CH`0`J````'^D!`"\```!*
MZ0$`50```'KI`0`@````T.D!`"X```#QZ0$`*P```"#J`0`P````3.H!`"H`
M``!]Z@$`/@```*CJ`0!4````Y^H!`%(````\ZP$`6@```(_K`0`R````ZNL!
M`"L````=[`$`2````$GL`0!*````DNP!`"H```#=[`$`)@````CM`0`L````
M+^T!`$X```!<[0$`,@```*OM`0`P````WNT!`!T````/[@$`(P```"WN`0`O
M````4>X!`"P```"![@$`+0```*[N`0!Q````W.X!`&8```!.[P$`;P```+7O
M`0"S````)?`!`!<```#9\`$`)0```/'P`0`R````%_$!`"D```!*\0$`/@``
M`'3Q`0`B````L_$!`%(```#6\0$`)0```"GR`0`+````3_(!`+$```!;\@$`
M.P````WS`0`G````2?,!`$X```!Q\P$`1P```,#S`0!B````"/0!`$D```!K
M]`$`50```+7T`0!`````"_4!`"\```!,]0$`,@```'SU`0`K````K_4!`"D`
M``#;]0$`#P````7V`0!%````%?8!`"$```!;]@$`,````'WV`0`M````KO8!
M`"4```#<]@$`'`````+W`0`Q````'_<!`#$```!1]P$`#@```(/W`0`+````
MDO<!``<```">]P$`!P```*;W`0`$````KO<!``T```"S]P$`"P```,'W`0`.
M````S?<!``L```#<]P$`!0```.CW`0`0````[O<!``(```#_]P$`"@````+X
M`0!6````#?@!`%D```!D^`$`3@```+[X`0`%````#?D!`!(````3^0$`!```
M`";Y`0`'````*_D!``@````S^0$`!0```#SY`0`#````0OD!`!````!&^0$`
M%P```%?Y`0`,````;_D!``P```!\^0$`#0```(GY`0`3````E_D!``T```"K
M^0$``@```+GY`0`'````O/D!``8```#$^0$`%````,OY`0`,````X/D!`!@`
M``#M^0$`!@````;Z`0`2````#?H!``P````@^@$``P```"WZ`0`J````,?H!
M``0```!<^@$`!@```&'Z`0`'````:/H!`!\```!P^@$`-0```)#Z`0`N````
MQOH!`"\```#U^@$`%P```"7[`0`B````/?L!`"4```!@^P$`(````(;[`0`;
M````I_L!`!@```##^P$`)````-S[`0`?`````?P!`!H````A_`$`(0```#S\
M`0`@````7OP!`!H```!__`$`,@```)K\`0`:````S?P!`"\```#H_`$`*P``
M`!C]`0`?````1/T!`",```!D_0$`'P```(C]`0`:````J/T!`"$```##_0$`
M)0```.7]`0`F````"_X!`"4````R_@$`)````%C^`0`8````??X!`!T```"6
M_@$`)````+3^`0`8````V?X!`"(```#R_@$`+````!7_`0`O````0O\!`!4`
M``!R_P$`)0```(C_`0`\````KO\!`!\```#K_P$`(P````L``@`?````+P`"
M`"````!/``(`&@```'```@`8````BP`"`!@```"D``(`)@```+T``@`>````
MY``"`"D````#`0(`'@```"T!`@`Q````3`$"``H```!^`0(`$P```(D!`@`(
M````G0$"``D```"F`0(`%@```+`!`@`,````QP$"`!<```#4`0(`+P```.P!
M`@`D````'`("``<```!!`@(`'P```$D"`@`/````:0("`!0```!Y`@(`#@``
M`(X"`@`-````G0("`"0```"K`@(`!0```-`"`@`'````U@("``P```#>`@(`
M.P```.L"`@`/````)P,"`!$````W`P(`(@```$D#`@`E````;`,"`!H```"2
M`P(`'0```*T#`@`:````RP,"`!$```#F`P(`!P```/@#`@#'``````0"``8`
M``#(!`(`"P```,\$`@`:````VP0"`!4```#V!`(`!@````P%`@`)````$P4"
M`!@````=!0(`"P```#8%`@`-````0@4"`!<```!0!0(`!@```&@%`@`S````
M;P4"`!,```"C!0(`$P```+<%`@`'````RP4"``\```#3!0(`$0```.,%`@`>
M````]04"``<````4!@(`&0```!P&`@`R````-@8"``0```!I!@(`1@```&X&
M`@`A````M08"`!,```#7!@(`#````.L&`@`1````^`8"`#(````*!P(`%@``
M`#T'`@`(````5`<"`!T```!=!P(`"0```'L'`@`*````A0<"`!0```"0!P(`
M"@```*4'`@`=````L`<"``@```#.!P(`'P```-<'`@`(````]P<"`!H`````
M"`(`)P```!L(`@`&````0P@"`!4```!*"`(`!P```&`(`@`(````:`@"``D`
M``!Q"`(`/P```'L(`@`'````NP@"``\```##"`(`#@```-,(`@`0````X@@"
M``D```#S"`(`"0```/T(`@`(````!PD"`!,````0"0(`!````"0)`@`'````
M*0D"`!(````Q"0(`)@```$0)`@`-````:PD"`!D```!Y"0(`&````),)`@`+
M````K`D"``X```"X"0(`&0```,<)`@`*````X0D"`"0```#L"0(`(0```!$*
M`@`*````,PH"`!,````^"@(`)P```%(*`@`)````>@H"``\```"$"@(`%P``
M`)0*`@`4````K`H"`"@```#!"@(`#P```.H*`@`@````^@H"``T````;"P(`
M%````"D+`@`-````/@L"`!0```!,"P(`%````&$+`@`*````=@L"``P```"!
M"P(`%P```(X+`@`$````I@L"`"H```"K"P(`#````-8+`@`1````XPL"``<`
M``#U"P(``@```/T+`@`0``````P"`!@````1#`(`"P```"H,`@`#````-@P"
M``@````Z#`(`!@```$,,`@`'````2@P"``T```!2#`(`"P```&`,`@`4````
M;`P"`!4```"!#`(`#@```)<,`@`O````I@P"`"````#6#`(`'````/<,`@!7
M````%`T"`%H```!L#0(`/P```,<-`@`V````!PX"`'X````^#@(`%0```+T.
M`@`,````TPX"`#$```#@#@(`"0```!(/`@`%````'`\"`!(````B#P(`/P``
M`#4/`@`2````=0\"``H```"(#P(`!@```),/`@`$````F@\"``0```"?#P(`
M"@```*0/`@`3````KP\"``4```###P(`!@```,D/`@`&````T`\"``@```#7
M#P(`!````.`/`@`,````Y0\"``H```#R#P(`.0```/T/`@`N````-Q`"`"D`
M``!F$`(`!0```)`0`@`8````EA`"`!D```"O$`(`'P```,D0`@`=````Z1`"
M`!$````'$0(``@```!D1`@`$````'!$"``H````A$0(`!@```"P1`@`%````
M,Q$"``,````Y$0(`#````#T1`@`[````2A$"`$\```"&$0(`-0```-81`@`G
M````#!("`"$````T$@(`)````%82`@!%````>Q("`"8```#!$@(`,@```.@2
M`@`S````&Q,"`!H```!/$P(`'0```&H3`@!X````B!,"`#0````!%`(`(0``
M`#84`@!6````6!0"`"@```"O%`(`4P```-@4`@`Z````+!4"`$(```!G%0(`
M&0```*H5`@`7````Q!4"`"4```#<%0(`&0````(6`@`J````'!8"`"L```!'
M%@(`<@```',6`@`@````YA8"`#4````'%P(`(0```#T7`@!%````7Q<"`"8`
M``"E%P(`,````,P7`@!+````_1<"`$X```!)&`(`)P```)@8`@`I````P!@"
M`"$```#J&`(`*`````P9`@`K````-1D"`!T```!A&0(`*0```'\9`@`F````
MJ1D"`"4```#0&0(`*````/89`@`H````'QH"`"(```!(&@(`.@```&L:`@`K
M````IAH"`"D```#2&@(`(@```/P:`@`]````'QL"`$$```!=&P(`*````)\;
M`@`L````R!L"`#````#U&P(`$@```"8<`@`3````.1P"`!````!-'`(`>0``
M`%X<`@`)````V!P"`!P```#B'`(`$````/\<`@`/````$!T"`"L````@'0(`
M)P```$P=`@`.````=!T"`$L```"#'0(`H0```,\=`@!S````<1X"`'P```#E
M'@(`0````&(?`@`K````HQ\"`%0```#/'P(`%P```"0@`@`J````/"`"`#0`
M``!G(`(`)P```)P@`@`6````Q"`"``\```#;(`(`KP```.L@`@`7````FR$"
M`"@```"S(0(`'P```-PA`@!`````_"$"`!\````](@(`'````%TB`@!1````
M>B("`!H```#,(@(`%````.<B`@`/````_"("``H````,(P(`!0```!<C`@`&
M````'2,"``@````D(P(`!0```"TC`@`0````,R,"`!(```!$(P(`#````%<C
M`@`0````9","`!$```!U(P(`$P```(<C`@`=````FR,"`"````"Y(P(`#P``
M`-HC`@`/````ZB,"``0```#Z(P(`"@```/\C`@`$````"B0"``,````/)`(`
M"0```!,D`@`'````'20"``L````E)`(`"````#$D`@`'````.B0"``4```!"
M)`(`"0```$@D`@`4````4B0"``8```!G)`(`!P```&XD`@`(````=B0"``\`
M``!_)`(`#P```(\D`@`,````GR0"``@```"L)`(`#````+4D`@`&````PB0"
M``D```#))`(`"P```-,D`@`/````WR0"``8```#O)`(`!P```/8D`@`-````
M_B0"``8````,)0(`%````!,E`@`'````*"4"``,````P)0(`"0```#0E`@`&
M````/B4"``P```!%)0(`"@```%(E`@`,````724"`!$```!J)0(`"@```'PE
M`@`/````AR4"``4```"7)0(`"````)TE`@`$````IB4"`!D```"K)0(`$0``
M`,4E`@`*````UR4"`!@```#B)0(`$P```/LE`@`<````#R8"`!$````L)@(`
M!````#XF`@`/````0R8"``<```!3)@(`!````%LF`@`$````8"8"`!D```!E
M)@(`!P```'\F`@`"````AR8"``(```"*)@(`$0```(TF`@`)````GR8"``8`
M``"I)@(`$@```+`F`@`7````PR8"``,```#;)@(`!@```-\F`@`,````YB8"
M`"<```#S)@(``@```!LG`@`$````'B<"``0````C)P(`#P```"@G`@`3````
M."<"``<```!,)P(``@```%0G`@`'````5R<"`!$```!?)P(`!@```'$G`@`+
M````>"<"`!@```"$)P(`!@```)TG`@`3````I"<"`!````"X)P(`$@```,DG
M`@`.````W"<"``\```#K)P(``@```/LG`@`&````_B<"``P````%*`(`"0``
M`!(H`@`1````'"@"`"(````N*`(`!P```%$H`@`'````62@"``L```!A*`(`
M!0```&TH`@`"````<R@"``L```!V*`(`#@```((H`@`.````D2@"`*,!``"@
M*`(`"@```$0J`@`,````3RH"``H```!<*@(`"````&<J`@`0````<"H"`!4`
M``"!*@(`#0```)<J`@`'````I2H"``D```"M*@(`"````+<J`@`*````P"H"
M``,```#+*@(`!````,\J`@`8````U"H"`!X```#M*@(`+P````PK`@`K````
M/"L"`"D```!H*P(`+0```)(K`@`9````P"L"``$```#:*P(`&0```-PK`@`J
M````]BL"``H````A+`(`#````"PL`@`>````.2P"`"4```!8+`(`3````'XL
M`@`L````RRP"`$@```#X+`(`*````$$M`@`7````:BT"`!(```""+0(`"@``
M`)4M`@`7````H"T"``4```"X+0(`*````+XM`@`2````YRT"``X```#Z+0(`
M$P````DN`@`-````'2X"`"T````K+@(`"@```%DN`@`C````9"X"`#$```"(
M+@(`#@```+HN`@`1````R2X"``L```#;+@(`.@```.<N`@`B````(B\"`"X`
M``!%+P(`&P```'0O`@"2````D"\"`!`````C,`(`"@```#0P`@`2````/S`"
M`"L```!2,`(`(@```'XP`@`-````H3`"`"0```"O,`(`&````-0P`@`C````
M[3`"`#$````1,0(`&P```$,Q`@`,````7S$"``\```!L,0(`%@```'PQ`@`&
M````DS$"`!L```":,0(`F0```+8Q`@`T````4#("`#T```"%,@(`!@```,,R
M`@`,````RC("`((```#7,@(`>````%HS`@`A````TS,"`"@```#U,P(`"```
M`!XT`@`-````)S0"`!@````U-`(`#P```$XT`@`8````7C0"`$<```!W-`(`
M)P```+\T`@!#````YS0"`",````K-0(`#@```$\U`@`/````7C4"`!````!N
M-0(`$````'\U`@`(````D#4"``X```"9-0(`#@```*@U`@`0````MS4"`#P`
M``#(-0(`%0````4V`@`Y````&S8"`%0```!5-@(`0P```*HV`@!)````[C8"
M`%4````X-P(`30```(XW`@!R````W#<"`&H```!/.`(`1@```+HX`@`0````
M`3D"`!8````2.0(`#@```"DY`@`0````.#D"`!(```!).0(`!0```%PY`@`!
M````8CD"``8```!D.0(`$0```&LY`@`(````?3D"``D```"&.0(`"0```)`Y
M`@`B````FCD"`!,```"].0(`!@```-$Y`@`(````V#D"`"4```#A.0(`(P``
M``<Z`@`0````*SH"``X````\.@(`$0```$LZ`@`.````73H"``8```!L.@(`
M!0```',Z`@`)````>3H"`"4```"#.@(`&P```*DZ`@`A````Q3H"``X```#G
M.@(`%````/8Z`@`8````"SL"`"4````D.P(`*@```$H[`@`:````=3L"`!``
M``"0.P(`%P```*$[`@`-````N3L"``\```#'.P(`-0```-<[`@`=````#3P"
M`",````K/`(`)@```$\\`@`8````=CP"`!$```"//`(`'@```*$\`@!8````
MP#P"`#8````9/0(`)0```%`]`@!N````=CT"`#$```#E/0(`(0```!<^`@`?
M````.3X"`#H```!9/@(`)P```)0^`@!"````O#X"``@```#_/@(`%0````@_
M`@`6````'C\"`&,````U/P(`;P```)D_`@`W````"4`"``T```!!0`(`"```
M`$]``@`+````6$`"``<```!D0`(`!P```&Q``@`'````=$`"``<```!\0`(`
M#````(1``@`%````D4`"`!L```"70`(`#````+-``@`0````P$`"`!(```#1
M0`(`4````.1``@!>````-4$"`$(```"400(`10```-=!`@!,````'4("`!L`
M``!J0@(`0P```(9"`@`<````RD("`"\```#G0@(`"0```!=#`@`6````(4,"
M`!8````X0P(`&````$]#`@`>````:$,"`!0```"'0P(`$@```)Q#`@`D````
MKT,"``8```#40P(`%````-M#`@`/````\$,"`$(`````1`(`(0```$-$`@`=
M````940"`#(```"#1`(`-````+9$`@`'````ZT0"``8```#S1`(`"````/I$
M`@`-`````T4"``@````110(`"@```!I%`@`5````)44"``D````[10(`$@``
M`$5%`@`)````6$4"`!,```!B10(`&````'9%`@`/````CT4"`!4```"?10(`
M)0```+5%`@!#````VT4"`"H````?1@(`!P```$I&`@`2````4D8"``4```!E
M1@(`%@```&M&`@`2````@D8"``\```"51@(`0@```*5&`@`U````Z$8"`$X`
M```>1P(`)0```&U'`@!"````DT<"`$0```#61P(`/P```!M(`@`Z````6T@"
M`#````"62`(`.````,=(`@`Q`````$D"`$0````R20(`00```'=)`@`]````
MN4D"``D```#W20(`!P````%*`@`3````"4H"``\````=2@(`!````"U*`@`%
M````,DH"``H````X2@(`#0```$-*`@`*````44H"`!<```!<2@(`"0```'1*
M`@!#````?DH"`!4```#"2@(`$0```-A*`@`Z````ZDH"`!`````E2P(`4```
M`#9+`@!+````ATL"``4```#32P(`$@```-E+`@`3````[$L"`"8`````3`(`
M!@```"=,`@`D````+DP"`"L```!33`(`*@```'],`@`P````JDP"``T```#;
M3`(`!P```.E,`@`)````\4P"``8```#[3`(`"0````)-`@`'````#$T"`#L`
M```430(`/0```%!-`@`Z````CDT"`%\```#)30(`.0```"E.`@`R````8TX"
M`#D```"63@(`10```-!.`@!%````%D\"`#D```!<3P(`4@```)9/`@`J````
MZ4\"`"P````44`(`20```$%0`@`Y````BU`"`#\```#%4`(`)0````51`@`5
M````*U$"`!D```!!40(`+````%M1`@`F````B%$"`"8```"O40(`=````-91
M`@`B````2U("`!,```!N4@(`$P```()2`@`*````EE("`!$```"A4@(`$0``
M`+-2`@`0````Q5("`#L```#64@(`(P```!)3`@`%````-E,"``P````\4P(`
M&0```$E3`@`;````8U,"`!D```!_4P(`/````)E3`@`9````UE,"``<```#P
M4P(`!P```/A3`@`5`````%0"``H````65`(`"````"%4`@`T````*E0"`!``
M``!?5`(``P```'!4`@`*````=%0"``<```!_5`(`!@```(=4`@!`````CE0"
M``4```#/5`(`"````-54`@`%````WE0"``L```#D5`(`"P```/!4`@`R````
M_%0"`!8````O50(`#0```$95`@!3````5%4"``4```"H50(`!P```*Y5`@`'
M````ME4"``D```"^50(`!0```,A5`@`1````SE4"``8```#@50(`%````.=5
M`@`%````_%4"`"\````"5@(`"````#)6`@`&````.U8"``L```!"5@(`!@``
M`$Y6`@`B````558"``8```!X5@(`"````']6`@`4````B%8"``P```"=5@(`
M!P```*I6`@`#````LE8"``,```"V5@(`&@```+I6`@`:````U58"`!<```#P
M5@(`+0````A7`@`&````-E<"``4````]5P(`"````$-7`@`(````3%<"`#,`
M``!55P(`-````(E7`@!7````OE<"`%H````66`(`(0```'%8`@`\````DU@"
M`"P```#06`(`(0```/U8`@`&````'UD"``@````F60(`$0```"]9`@`>````
M05D"`#\```!@60(`)@```*!9`@`Q````QUD"`#8```#Y60(`*````#!:`@`O
M````65H"`&T```")6@(`.@```/=:`@`*````,EL"``8````]6P(`"0```$1;
M`@`2````3EL"``P```!A6P(``@```&Y;`@`0````<5L"`!8```""6P(`$0``
M`)E;`@`6````JUL"`!8```#"6P(`$````-E;`@`5````ZEL"``8`````7`(`
M&P````=<`@`;````(UP"`!<````_7`(`&P```%=<`@`8````<UP"`&<```",
M7`(`!@```/1<`@`)````^UP"``<````%70(`#0````U=`@`-````&UT"`!``
M```I70(`=P```#I=`@`U````LET"`%P```#H70(`90```$5>`@!@````JUX"
M``0````,7P(`%````!%?`@`2````)E\"`"@````Y7P(`%````&)?`@!,````
M=U\"`#(```#$7P(`!0```/=?`@`%````_5\"`!P````#8`(`&0```"!@`@`/
M````.F`"`!0```!*8`(`'P```%]@`@`P````?V`"`!$```"P8`(`$@```,)@
M`@`:````U6`"`#H```#P8`(`10```"MA`@!-````<6$"``\```"_80(`+P``
M`,]A`@`&````_V$"`!0````&8@(`#P```!MB`@`3````*V("``\````_8@(`
M&````$]B`@`2````:&("`%P```![8@(`(@```-AB`@`Z````^V("`#T````V
M8P(`,0```'1C`@`T````IF,"`%D```#;8P(`(@```#5D`@!G````6&0"`!4`
M``#`9`(`0P```-9D`@!*````&F4"`!,```!E90(`0````'EE`@`R````NF4"
M``8```#M90(`#0```/1E`@`2`````F8"``P````59@(`!@```")F`@`2````
M*68"``<````\9@(`#@```$1F`@`(````4V8"``X```!<9@(`%0```&MF`@`.
M````@68"`!8```"09@(`#P```*=F`@`(````MV8"``,```#`9@(`$@```,1F
M`@`0````UV8"``X```#H9@(`!0```/=F`@`3````_68"``H````19P(`!P``
M`!QG`@`0````)&<"``@````U9P(`!````#YG`@`'````0V<"``<```!+9P(`
M"0```%-G`@`5````76<"`"@```!S9P(`7````)QG`@`,````^6<"``@````&
M:`(`"0````]H`@`:````&6@"`#X````T:`(`)@```'-H`@`-````FF@"`"@`
M``"H:`(`,0```-%H`@`0`````VD"``4````4:0(`'P```!II`@`F````.FD"
M`!$```!A:0(`$@```'-I`@`R````AFD"`$(```"Y:0(`(0```/QI`@`?````
M'FH"``@````^:@(`1P```$=J`@`H````CVH"`!````"X:@(`"0```,EJ`@`?
M````TVH"`"(```#S:@(`.````!9K`@!H````3VL"`"L```"X:P(`"@```.1K
M`@`&````[VL"``8```#V:P(`$@```/UK`@`.````$&P"`!,````?;`(`"```
M`#-L`@`/````/&P"``L```!,;`(`"@```%AL`@`/````8VP"`"P```!S;`(`
M)P```*!L`@`T````R&P"`"\```#];`(`)@```"UM`@`K````5&T"`"8```"`
M;0(`+0```*=M`@`E````U6T"`#T```#[;0(`,@```#EN`@`F````;&X"`"D`
M``"3;@(`+P```+UN`@`F````[6X"`#0````4;P(`/0```$EO`@!&````AV\"
M`$$```#.;P(`,0```!!P`@`[````0G`"`#D```!^<`(`/0```+AP`@`]````
M]G`"`$<````T<0(`+````'QQ`@`H````J7$"`$8```#2<0(`*@```!ER`@`:
M````1'("`#4```!?<@(`*````)5R`@`Y````OG("`"P```#X<@(`&````"5S
M`@#)````/G,"`!P````(=`(`,@```"5T`@`R````6'0"`#0```"+=`(`-P``
M`,!T`@`Q````^'0"`"D````J=0(`*@```%1U`@`J````?W4"`#(```"J=0(`
M-0```-UU`@!)````$W8"`#L```!==@(`J0```)EV`@`L````0W<"`"4```!P
M=P(`*````)9W`@`V````OW<"`#(```#V=P(`60```"EX`@!.````@W@"``T`
M``#2>`(`!````.!X`@`&````Y7@"``4```#L>`(`"P```/)X`@`,````_G@"
M`!@````+>0(`#0```"1Y`@`<````,GD"`"$```!/>0(`#@```'%Y`@`G````
M@'D"`!8```"H>0(`70```+]Y`@`<````'7H"`"\````Z>@(`$````&IZ`@`5
M````>WH"`!L```"1>@(`!P```*UZ`@`$````M7H"``X```"Z>@(`#@```,EZ
M`@`*````V'H"``T```#C>@(`$P```/%Z`@`+````!7L"`!$````1>P(`$```
M`"-[`@`,````-'L"`#@```!!>P(`)````'I[`@`V````GWL"``8```#6>P(`
M#@```-U[`@`&````['L"`!$```#S>P(`%P````5\`@`;````'7P"`!`````Y
M?`(``@```$I\`@!*````37P"``L```"8?`(`!0```*1\`@`5````JGP"`!H`
M``#`?`(`!````-M\`@`3````X'P"``\```#T?`(``P````1]`@`/````"'T"
M``@````8?0(`$````"%]`@`(````,GT"``@````[?0(`$````$1]`@`'````
M57T"``H```!=?0(`$0```&A]`@`8````>GT"``P```"3?0(`'0```*!]`@`<
M````OGT"``H```#;?0(`"````.9]`@`'````[WT"`!@```#W?0(`#@```!!^
M`@`5````'WX"`!`````U?@(`#0```$9^`@`+````5'X"`!$```!@?@(`&P``
M`')^`@`6````CGX"`!<```"E?@(`*P```+U^`@`:````Z7X"``X````$?P(`
M#@```!-_`@`C````(G\"`"X```!&?P(`%P```'5_`@`Q````C7\"`#X```"_
M?P(`'````/Y_`@`\````&X`"``T```!8@`(`'@```&:``@`-````A8`"`!8`
M``"3@`(`%0```*J``@`(````P(`"`!,```#)@`(`-````-V``@`4````$H$"
M`!T````G@0(`#P```$6!`@`)````58$"`!$```!?@0(`+0```'&!`@`+````
MGX$"`!,```"K@0(`"0```+^!`@`(````R8$"`#4```#2@0(`-P````B"`@`/
M````0(("`!````!0@@(`)0```&&"`@`2````AX("`"P```":@@(`%0```,>"
M`@`@````W8("`"````#^@@(`"0```!^#`@`&````*8,"`!L````P@P(`$@``
M`$R#`@`L````7X,"`!D```",@P(`%0```*:#`@`.````O(,"`!L```#+@P(`
M+@```.>#`@`P````%H0"`#0```!'A`(`"@```'R$`@`9````AX0"``<```"A
MA`(`#P```*F$`@`K````N80"``L```#EA`(`)@```/&$`@`A````&(4"`!L`
M```ZA0(`2````%:%`@`*````GX4"`!0```"JA0(`(@```+^%`@`%````XH4"
M``8```#HA0(`"0```.^%`@`9````^84"`"4````3A@(`#P```#F&`@`>````
M288"`#````!HA@(`%@```)F&`@`(````L(8"`!$```"YA@(`$@```,N&`@`0
M````WH8"``8```#OA@(`!P```/:&`@`2````_H8"`%0````1AP(``P```&:'
M`@`#````:H<"`"D```!NAP(`!P```)B'`@`&````H(<"`!(```"GAP(`#```
M`+J'`@`.````QX<"``P```#6AP(`$````..'`@`1````](<"`!D````&B`(`
M&P```""(`@`4````/(@"`"D```!1B`(`$P```'N(`@`1````CX@"`!D```"A
MB`(`&0```+N(`@`6````U8@"`!P```#LB`(`.P````F)`@`7````18D"``@`
M``!=B0(`!0```&:)`@`+````;(D"``L```!XB0(``@```(2)`@`&````AXD"
M`!(```".B0(`)P```*&)`@`8````R8D"`!D```#BB0(`"0```/R)`@`F````
M!HH"`#8````MB@(`$0```&2*`@`@````=HH"`!````"7B@(`#````*B*`@`1
M````M8H"`!,```#'B@(`%````-N*`@`<````\(H"`!T````-BP(`(````"N+
M`@!&````3(L"`"<```"3BP(`+P```+N+`@`7````ZXL"``T````#C`(`!0``
M`!&,`@`=````%XP"`!$````UC`(`%P```$>,`@`,````7XP"``\```!LC`(`
M#P```'R,`@"*````C(P"`!P````7C0(`&````#2-`@`I````38T"`"T```!W
MC0(`-@```*6-`@`B````W(T"``\```#_C0(`00````^.`@`0````48X"``@`
M``!BC@(`!````&N.`@`I````<(X"`!<```":C@(`*P```+*.`@`H````WHX"
M`!H````'CP(`'````"*/`@`=````/X\"`!$```!=CP(`$P```&^/`@`'````
M@X\"``<```"+CP(`!@```)./`@`&````FH\"`!P```"ACP(`#P```+Z/`@`.
M````SH\"`!````#=CP(`#@```.Z/`@`,````_8\"``X````*D`(`"P```!F0
M`@`3````)9`"``@````YD`(`"````$*0`@`.````2Y`"`!4```!:D`(`#@``
M`'"0`@`.````?Y`"`!8```".D`(`2````*60`@!0````[I`"``H````_D0(`
M#````$J1`@`U````5Y$"`!$```"-D0(`"````)^1`@`5````J)$"`"4```"^
MD0(`$````.21`@`;````]9$"`",````1D@(`(@```#62`@`8````6)("`!H`
M``!QD@(`)0```(R2`@`9````LI("`!(```#,D@(`!0```-^2`@`9````Y9("
M``L```#_D@(`"P````N3`@`#````%Y,"``4````;DP(`"0```"&3`@`0````
M*Y,"`!(````\DP(`$````$^3`@`H````8),"`!T```")DP(`&P```*>3`@`8
M````PY,"`!(```#<DP(`)@```.^3`@`1````%I0"``H````HE`(`"````#.4
M`@`/````/)0"``X```!,E`(`#````%N4`@`$````:)0"``<```!ME`(`(```
M`'64`@`A````EI0"`!<```"XE`(`#P```-"4`@`2````X)0"`!````#SE`(`
M(@````25`@`0````)Y4"`!<````XE0(`)P```%"5`@`T````>)4"``<```"M
ME0(`$@```+65`@`F````R)4"``D```#OE0(`"0```/F5`@`/`````Y8"`!@`
M```3E@(`#P```"R6`@`/````/)8"``D```!,E@(`!0```%:6`@`*````7)8"
M``L```!GE@(`!0```'.6`@`3````>98"`!T```"-E@(`$P```*N6`@`0````
MOY8"`#$```#0E@(`*P````*7`@`,````+I<"``8````[EP(`*0```$*7`@`.
M````;)<"`(,```![EP(`$0```/^7`@!<````$9@"``L```!NF`(`!0```'J8
M`@`-````@)@"``8```".F`(`"````)68`@`&````GI@"``H```"EF`(`"P``
M`+"8`@`4````O)@"`!H```#1F`(`$0```.R8`@`#````_I@"``<````"F0(`
M!@````J9`@`4````$9D"`#,````FF0(`#P```%J9`@`2````:ID"`!P```!]
MF0(``P```)J9`@`"````GID"`!4```"AF0(`!0```+>9`@`2````O9D"``D`
M``#0F0(`#0```-J9`@`$````Z)D"``4```#MF0(`'@```/.9`@`%````$IH"
M`"`````8F@(`"````#F:`@`&````0IH"``T```!)F@(`&@```%>:`@`-````
M<IH"``<```"`F@(`"````(B:`@`M````D9H"``0```"_F@(`"0```,2:`@`-
M````SIH"``X```#<F@(``@```.N:`@`2````[IH"`#,````!FP(`!@```#6;
M`@`,````/)L"`!,```!)FP(`#P```%V;`@`0````;9L"``8```!^FP(`$@``
M`(6;`@`*````F)L"``<```"CFP(`%P```*N;`@`I````PYL"`$H```#MFP(`
M)P```#B<`@`I````8)P"``8```"*G`(`"0```)&<`@`$````FYP"``D```"@
MG`(`"````*J<`@`7````LYP"`!````#+G`(`!0```-R<`@`,````XIP"``8`
M``#OG`(`!````/:<`@`$````^YP"`!<`````G0(`00```!B=`@!"````6IT"
M`$$```"=G0(`(0```-^=`@`%`````9X"``X````'G@(`!P```!:>`@`)````
M'IX"``H````HG@(`&P```#.>`@`0````3YX"`!4```!@G@(`!@```':>`@`%
M````?9X"``\```"#G@(`"@```).>`@`*````GIX"`!X```"IG@(`+@```,B>
M`@`&````]YX"`"0```#^G@(`$0```".?`@`5````-9\"``0```!+GP(`#P``
M`%"?`@`)````8)\"``<```!JGP(`)````'*?`@`&````EY\"`!0```">GP(`
M$0```+.?`@`0````Q9\"``@```#6GP(`"0```-^?`@`%````Z9\"`#L```#O
MGP(`-@```"N@`@!#````8J`"`"D```"FH`(`0@```-"@`@!"````$Z$"`"L`
M``!6H0(`2@```(*A`@`O````S:$"`#D```#]H0(`+P```#>B`@`0````9Z("
M`!$```!XH@(`"P```(JB`@`M````EJ("`!\```#$H@(`*0```.2B`@`A````
M#J,"`"@````PHP(`+````%FC`@`'````AJ,"``D```".HP(`"@```)BC`@`'
M````HZ,"``0```"KHP(`'P```+"C`@`Z````T*,"`"0````+I`(`)@```#"D
M`@`M````5Z0"``X```"%I`(`*@```)2D`@`>````OZ0"`"$```#>I`(`#0``
M``"E`@`?````#J4"`!`````NI0(`"P```#^E`@`;````2Z4"`"T```!GI0(`
M&````)6E`@`3````KJ4"``@```#"I0(`#@```,NE`@`.````VJ4"``X```#I
MI0(`$P```/BE`@!$````#*8"`%$```!1I@(`,0```*.F`@!^````U:8"`'$`
M``!4IP(`!P```,:G`@`-````SJ<"``8```#<IP(`&P```..G`@`-````_Z<"
M``X````-J`(`$0```!RH`@`2````+J@"``\```!!J`(`!P```%&H`@`(````
M6:@"``X```!BJ`(`%@```'&H`@`2````B*@"`!(```";J`(`'@```*ZH`@`B
M````S:@"`"(```#PJ`(`)0```!.I`@`6````.:D"`!H```!0J0(`'0```&NI
M`@`5````B:D"`!4```"?J0(`*0```+6I`@`2````WZD"``H```#RJ0(`%0``
M`/VI`@`>````$ZH"`!,````RJ@(`$@```$:J`@`+````6:H"`!,```!EJ@(`
M$````'FJ`@`Q````BJH"`"8```"\J@(`*````..J`@`>````#*L"`(0````K
MJP(`$@```+"K`@`%````PZL"`!0```#)JP(`"0```-ZK`@`*````Z*L"``H`
M``#SJP(`'P```/ZK`@`C````'JP"`"8```!"K`(`)@```&FL`@`+````D*P"
M`!0```"<K`(`&0```+&L`@`.````RZP"`"<```#:K`(`)P````*M`@`?````
M*JT"``X```!*K0(`$P```%FM`@`5````;:T"`"0```"#K0(`)@```*BM`@`C
M````SZT"`"4```#SK0(`(0```!FN`@`C````.ZX"`!T```!?K@(`10```'VN
M`@`3````PZX"`!0```#7K@(`$P```.RN`@`4`````*\"`!$````5KP(`%@``
M`">O`@`7````/J\"`!(```!6KP(`$P```&FO`@`\````?:\"`!8```"ZKP(`
M%````-&O`@`^````YJ\"`!4````EL`(`#@```#NP`@`1````2K`"`"\```!<
ML`(`$0```(RP`@`<````GK`"`"T```"[L`(`$P```.FP`@`3````_;`"`"``
M```1L0(`+````#*Q`@`=````7[$"`!\```!]L0(`'0```)VQ`@`.````N[$"
M`!L```#*L0(`(0```.:Q`@`<````"+("`",````EL@(`(0```$FR`@`@````
M:[("`"````",L@(`(P```*VR`@`C````T;("`!T```#UL@(`$P```!.S`@`;
M````)[,"`!T```!#LP(`&P```&&S`@`8````?;,"``H```"6LP(`"````*&S
M`@`0````JK,"`!H```"[LP(`!@```-:S`@`'````W;,"``T```#ELP(`%```
M`/.S`@`&````"+0"``<````/M`(`!P```!>T`@`&````'[0"``<````FM`(`
M!P```"ZT`@`%````-K0"`!4````\M`(`!@```%*T`@`(````6;0"``4```!B
MM`(`!0```&BT`@`*````;K0"`!$```!YM`(`"@```(NT`@`2````EK0"`!$`
M``"IM`(``@```+NT`@`+````OK0"`!(```#*M`(`!@```-VT`@`J````Y+0"
M`!$````/M0(`$````"&U`@`:````,K4"`!````!-M0(`#0```%ZU`@`,````
M;+4"`"\```!YM0(`6@```*FU`@!9````!+8"`&X```!>M@(`/0```,VV`@`(
M````"[<"``@````4MP(`*````!VW`@`4````1K<"`!````!;MP(`!@```&RW
M`@`+````<[<"``<```!_MP(`!@```(>W`@`A````CK<"``T```"PMP(`%@``
M`+ZW`@`-````U;<"`!````#CMP(`#0```/2W`@`3`````K@"`!`````6N`(`
M'P```">X`@`3````1[@"``<```!;N`(``P```&.X`@`&````9[@"`!\```!N
MN`(`!@```(ZX`@`(````E;@"`!(```">N`(`$P```+&X`@`&````Q;@"``0`
M``#,N`(`!P```-&X`@`6````V;@"``T```#PN`(`#0```/ZX`@`+````#+D"
M`!0````8N0(`%@```"VY`@`7````1+D"`!D```!<N0(`"@```':Y`@`-````
M@;D"``8```"/N0(`!````):Y`@`8````F[D"`!$```"TN0(`.P```,:Y`@`C
M`````KH"``4````FN@(`&````"RZ`@`/````1;H"`"$```!5N@(`%@```'>Z
M`@`7````CKH"``X```"FN@(`B0```+6Z`@`,````/[L"``D```!,NP(`!P``
M`%:[`@`*````7KL"``D```!INP(`#@```'.[`@`0````@KL"`!4```"3NP(`
M(````*F[`@`A````RKL"`"<```#LNP(`"@```!2\`@`(````'[P"``T````H
MO`(`$P```#:\`@`,````2KP"`!(```!7O`(`!@```&J\`@`(````<;P"``T`
M``!ZO`(`)P```(B\`@`+````L+P"``@```"\O`(`$@```,6\`@`\````V+P"
M``\````5O0(`"P```"6]`@`$````,;T"``4````VO0(`$````#R]`@`;````
M3;T"`!P```!IO0(`'````(:]`@`*````H[T"``H```"NO0(``@```+F]`@`$
M````O+T"`"$```#!O0(``P```..]`@`%````Y[T"`"D```#MO0(`$0```!>^
M`@`*````*;X"``8````TO@(`!P```#N^`@`8````0[X"`!T```!<O@(`)P``
M`'J^`@`,````HKX"`"\```"OO@(`#@```-^^`@`&````[KX"``<```#UO@(`
M"````/V^`@`$````!K\"``4````+OP(`/````!&_`@`0````3K\"`!,```!?
MOP(`%0```'._`@`%````B;\"``8```"/OP(`+0```):_`@`Q````Q+\"``P`
M``#VOP(`.0````/``@`K````/<`"`!L```!IP`(`'@```(7``@`S````I,`"
M``X```#8P`(`"0```.?``@`/````\<`"`!8````!P0(`%@```!C!`@`*````
M+\$"``@````ZP0(`&0```$/!`@`L````7<$"`"D```"*P0(`*````+3!`@`7
M````W<$"`!<```#UP0(`(0````W"`@`.````+\("`"$````^P@(`(@```&#"
M`@`$````@\("``<```"(P@(`"````)#"`@`'````F<("`!<```"AP@(`#0``
M`+G"`@`/````Q\("``@```#7P@(`%@```.#"`@`0````]\("`!(````(PP(`
M$P```!O#`@`3````+\,"`!@```!#PP(`5P```%S#`@`8````M,,"`!(```#-
MPP(`%@```.##`@`2````]\,"``X````*Q`(`%0```!G$`@`=````+\0"`!@`
M``!-Q`(`%````&;$`@`C````>\0"`#4```"?Q`(`'0```-7$`@`0````\\0"
M`#4````$Q0(`#@```#K%`@`+````2<4"`!L```!5Q0(`4````''%`@`=````
MPL4"``8```#@Q0(`'0```.?%`@`G````!<8"``<````MQ@(`!@```#7&`@`@
M````/,8"``0```!=Q@(`"0```&+&`@`I````;,8"`"@```"6Q@(`)P```+_&
M`@`'````Y\8"``@```#OQ@(`(@```/C&`@!9````&\<"`!@```!UQP(`)@``
M`(['`@`6````M<<"``,```#,QP(`#0```-#'`@`'````WL<"``\```#FQP(`
M!P```/;'`@`+````_L<"``8````*R`(`%0```!'(`@`&````)\@"``@````N
MR`(`"0```#?(`@`+````0<@"``H```!-R`(`#````%C(`@`]````9<@"`"T`
M``"CR`(`"````-'(`@`2````VL@"`!0```#MR`(`%P````+)`@`%````&LD"
M``P````@R0(`$````"W)`@`/````/LD"``L```!.R0(`!@```%K)`@!+````
M8<D"`!(```"MR0(`!0```,#)`@`*````QLD"`"4```#1R0(`%P```/?)`@`5
M````#\H"`",````ER@(`$````$G*`@`+````6LH"`!````!FR@(`"@```'?*
M`@`4````@LH"``@```"7R@(`%````*#*`@`&````M<H"``0```"\R@(`!```
M`,'*`@`C````QLH"``<```#JR@(`!0```/+*`@`1````^,H"``4````*RP(`
M!P```!#+`@`3````&,L"`!0````LRP(`(@```$'+`@`B````9,L"`!P```"'
MRP(`'````*3+`@`@````P<L"`"4```#BRP(`'P````C,`@`$````*,P"``4`
M```MS`(`$P```#/,`@`$````1\P"``X```!,S`(`#@```%O,`@`*````:LP"
M``T```!US`(`#0```(/,`@`5````D<P"``@```"GS`(`%P```+#,`@`-````
MR,P"``\```#6S`(`"@```.;,`@`:````\<P"`!\````,S0(`%````"S-`@`(
M````0<T"`!(```!*S0(`!P```%W-`@`0````9<T"`!````!VS0(`#@```(?-
M`@`/````ELT"``@```"FS0(`"0```*_-`@`%````N<T"``<```"_S0(`!0``
M`,?-`@`$````S<T"``,```#2S0(`'0```-;-`@`0````],T"`!8````%S@(`
M#0```!S.`@`D````*LX"`",```!/S@(`'0```'/.`@`@````D<X"`"<```"R
MS@(`&````-K.`@!!````\\X"`#4````USP(`%P```&O/`@`I````@\\"`#D`
M``"MSP(`$@```.?/`@`X````^L\"`#@````ST`(`/0```&S0`@`]````JM`"
M`$(```#HT`(`&````"O1`@`9````1-$"`"H```!>T0(`%@```(G1`@`:````
MH-$"`#T```"[T0(`'@```/G1`@`A````&-("`"4````ZT@(`&````&#2`@`@
M````>=("`"````":T@(`(0```+O2`@`;````W=("`!L```#YT@(`+0```!73
M`@`9````0],"`!L```!=TP(`%````'G3`@`Q````CM,"`#$```#`TP(`-0``
M`/+3`@`R````*-0"`#,```!;U`(`,````(_4`@!W````P-0"`!D````XU0(`
M,````%+5`@`O````@]4"`#````"SU0(`70```.35`@`6````0M8"``H```!9
MU@(`(@```&36`@`)````A]8"`#T```"1U@(`&0```,_6`@`3````Z=8"``T`
M``#]U@(`/0````O7`@`T````2=<"`!P```!^UP(`)0```)O7`@`@````P=<"
M``L```#BUP(`40```.[7`@!-````0-@"`!$```".V`(`!P```*#8`@`7````
MJ-@"`!4```#`V`(`#````-;8`@`&````X]@"`!````#JV`(`%@```/O8`@`'
M````$MD"``@````:V0(`"0```"/9`@`,````+=D"``P````ZV0(`#@```$?9
M`@`+````5MD"`!(```!BV0(`'P```'79`@`7````E=D"`!$```"MV0(`&0``
M`+_9`@`/````V=D"``X```#IV0(`)````/C9`@`)````'=H"``0````GV@(`
M&````"S:`@`:````1=H"``@```!@V@(`!@```&G:`@`4````<-H"`!$```"%
MV@(`50```)?:`@!9````[=H"`!````!'VP(`0@```%C;`@`"````F]L"``(`
M``">VP(`!@```*';`@`1````J-L"``4```"ZVP(`!P```,#;`@`/````R-L"
M``H```#8VP(`*@```./;`@`1````#MP"``P````@W`(`'@```"W<`@`^````
M3-P"``,```"+W`(`-P```(_<`@`N````Q]P"`!@```#VW`(`*`````_=`@`V
M````.-T"`(8```!OW0(`#````/;=`@`8`````]X"`$$````<W@(`#````%[>
M`@`A````:]X"`!,```"-W@(`%0```*'>`@`&````M]X"``P```"^W@(`#@``
M`,O>`@`+````VMX"`!8```#FW@(`"P```/W>`@`<````"=\"`!8````FWP(`
M!0```#W?`@`2````0]\"`!@```!6WP(`#0```&_?`@`1````?=\"`!H```"/
MWP(`)0```*K?`@`3````T-\"``,```#DWP(`%@```.C?`@`>````_]\"`!P`
M```>X`(`#0```#O@`@`[````2>`"``T```"%X`(`%P```)/@`@!#````J^`"
M`!$```#OX`(`&@````'A`@`Z````'.$"`#,```!7X0(`%````(OA`@`9````
MH.$"`"<```"ZX0(`)@```.+A`@`I````">("`"D````SX@(`+@```%WB`@!C
M````C.("`%\```#PX@(`T@```%#C`@`*````(^0"`!0````NY`(`%@```$/D
M`@`0````6N0"`!(```!KY`(`#P```'[D`@`2````CN0"``\```"AY`(`%0``
M`+'D`@`$````Q^0"`!\```#,Y`(`#@```.SD`@`J````^^0"`!X````FY0(`
M#0```$7E`@`>````4^4"`!4```!RY0(`!@```(CE`@`/````C^4"`"H```"?
MY0(`+````,KE`@`)````]^4"``4````!Y@(`'0````?F`@`&````)>8"`!``
M```LY@(`"````#WF`@`(````1N8"`!0```!/Y@(`!0```&3F`@`1````:N8"
M`!\```!\Y@(`!@```)SF`@`C````H^8"`!<```#'Y@(`!0```-_F`@`;````
MY>8"``\````!YP(`+0```!'G`@`5````/^<"``8```!5YP(`!P```%SG`@`8
M````9.<"``4```!]YP(`'@```(/G`@`$````HN<"`!0```"GYP(`!P```+SG
M`@`+````Q.<"`"````#0YP(`+0```/'G`@`)````'^@"`!P````IZ`(`$```
M`$;H`@`*````5^@"`!L```!BZ`(`.````'[H`@`'````M^@"`!0```"_Z`(`
M+0```-3H`@`J`````ND"`#,````MZ0(`+0```&'I`@`$````C^D"`!0```"4
MZ0(`"0```*GI`@`(````L^D"``4```"\Z0(`"````,+I`@`&````R^D"`#P`
M``#2Z0(`(`````_J`@`&````,.H"`,@````WZ@(`(0````#K`@`W````(NL"
M`#\```!:ZP(`(@```)KK`@`P````O>L"`"P```#NZP(`*````!OL`@!%````
M1.P"`"(```"*[`(`*P```*WL`@`>````V>P"`'<```#X[`(`>@```'#M`@!%
M`0``Z^T"`"@````Q[P(`'````%KO`@`E````=^\"`!X```"=[P(`50```+SO
M`@`R````$O`"`#H```!%\`(`.````(#P`@`Y````N?`"`#````#S\`(`*@``
M`"3Q`@`'````3_$"``@```!7\0(`!P```&#Q`@`(````:/$"`!0```!Q\0(`
M%````(;Q`@`P````F_$"`!````#,\0(`*@```-WQ`@`M````"/("`!@````V
M\@(`)0```$_R`@`U````=?("`#T```"K\@(`!P```.GR`@`9````\?("``D`
M```+\P(`$````!7S`@`B````)O,"`!$```!)\P(`#P```%OS`@`1````:_,"
M``@```!]\P(`$@```(;S`@`*````F?,"``T```"D\P(`%@```++S`@`(````
MR?,"`!4```#2\P(`"````.CS`@`U````\?,"`#4````G]`(`"P```%WT`@`*
M````:?0"``T```!T]`(`&@```(+T`@`-````G?0"`#@```"K]`(`/````.3T
M`@`*````(?4"`!$````L]0(`$````#[U`@`1````3_4"`"$```!A]0(`1@``
M`(/U`@`E````RO4"`"4```#P]0(`(````!;V`@`%````-_8"``D````]]@(`
M!0```$?V`@`L````3?8"`"8```!Z]@(`'0```*'V`@`+````O_8"`!H```#+
M]@(`$0```.;V`@`%````^/8"``X```#^]@(`$`````WW`@`1````'O<"``P`
M```P]P(`#P```#WW`@`/````3?<"``<```!=]P(``P```&7W`@`-````:?<"
M`#H```!W]P(`3@```++W`@`>`````?@"``L````@^`(`#@```"SX`@`,````
M._@"``T```!(^`(`#````%;X`@`5````8_@"`!H```!Y^`(`&````)3X`@`5
M````K?@"``D```##^`(`)@```,WX`@`A````]/@"`!T````6^0(`!0```#3Y
M`@`5````.OD"``D```!0^0(`%@```%KY`@`+````<?D"`",```!]^0(`'0``
M`*'Y`@`4````O_D"`!(```#4^0(`*@```.?Y`@`'````$OH"``T````:^@(`
M&0```"CZ`@`.````0OH"`!(```!1^@(`"P```&3Z`@`[````</H"``X```"L
M^@(`"0```+OZ`@`<````Q?H"``\```#B^@(`$P```/+Z`@`1````!OL"`"4`
M```8^P(`/P```#[[`@`B````?OL"``\```"A^P(`"0```+'[`@`1````N_L"
M`!$```#-^P(`$@```-_[`@`C````\OL"`"0````6_`(`$0```#O\`@`D````
M3?P"`#<```!R_`(`-@```*K\`@`(````X?P"`",```#J_`(`"@````[]`@`6
M````&?T"`!(````P_0(`(0```$/]`@`_````9?T"`"$```"E_0(`*0```,?]
M`@`N````\?T"`#D````@_@(`.@```%K^`@`V````E?X"`!$```#,_@(`&```
M`-[^`@`&````]_X"`!````#^_@(`$`````__`@`@````(/\"``T```!!_P(`
M"@```$__`@`)````6O\"`!0```!D_P(`)@```'G_`@`=````H/\"`!$```"^
M_P(`3P```-#_`@`=````(``#``<````^``,`%0```$8``P`:````7``#``@`
M``!W``,`!P```(```P`1````B``#`!(```":``,`&0```*T``P`&````QP`#
M``<```#.``,`#P```-8``P`5````Y@`#`!0```#\``,`%0```!$!`P`5````
M)P$#``<````]`0,`!@```$4!`P`Q````3`$#`"<```!^`0,`)@```*8!`P`(
M````S0$#``\```#6`0,`!@```.8!`P`&````[0$#`!\```#T`0,`(0```!0"
M`P`A````-@(#`!````!8`@,`/@```&D"`P`0````J`(#`!<```"Y`@,`1@``
M`-$"`P`V````&`,#`"P```!/`P,`%P```'P#`P`\````E`,#`!P```#1`P,`
M*@```.X#`P`Q````&00#`&<```!+!`,`70```+,$`P!K````$04#`.$```!]
M!0,`)@```%\&`P`+````A@8#``0```"2!@,`%````)<&`P`F````K`8#``,`
M``#3!@,`!P```-<&`P`5````WP8#``@```#U!@,``P```/X&`P`5`````@<#
M``L````8!P,`#````"0'`P`1````,0<#``L```!#!P,`%````$\'`P`8````
M9`<#`!0```!]!P,`!0```)('`P`*````F`<#`!,```"C!P,`%````+<'`P`.
M````S`<#``8```#;!P,`"0```.('`P`)````[`<#`#P```#V!P,`#P```#,(
M`P`+````0P@#`!@```!/"`,`#0```&@(`P`5````=@@#`!````","`,`"P``
M`)T(`P`@````J0@#`%H```#*"`,`20```"4)`P`G````;PD#`!````"7"0,`
M%@```*@)`P`U````OPD#`#L```#U"0,`%````#$*`P`'````1@H#``D```!.
M"@,`#````%@*`P`4````90H#`!(```!Z"@,`%@```(T*`P`$````I`H#``H`
M``"I"@,`%@```+0*`P`5````RPH#`!(```#A"@,`$@```/0*`P`A````!PL#
M`!@````I"P,`%0```$(+`P`<````6`L#`",```!U"P,`2````)D+`P`0````
MX@L#`"<```#S"P,`00```!L,`P`4````70P#`!,```!R#`,`%0```(8,`P!P
M````G`P#`"$````-#0,`'````"\-`P`J````3`T#`"T```!W#0,`)P```*4-
M`P`A````S0T#`!P```#O#0,`)@````P.`P`?````,PX#`!\```!3#@,`)```
M`',.`P`O````F`X#`!H```#(#@,`#P```.,.`P`<````\PX#``H````0#P,`
M(0```!L/`P`L````/0\#``<```!J#P,`"````'(/`P`.````>P\#``\```"*
M#P,`"````)H/`P`3````HP\#``\```"W#P,`"````,</`P`@````T`\#`"T`
M``#Q#P,`"0```!\0`P`7````*1`#`!4```!!$`,`!P```%<0`P`'````7Q`#
M`$\```!G$`,`30```+<0`P`S````!1$#`$D````Y$0,`/@```(,1`P!F````
MPA$#``P````I$@,`,@```#82`P`P````:1(#``D```":$@,`%0```*02`P`3
M````NA(#`#<```#.$@,`!P````83`P`&````#A,#`$`````5$P,`?P```%83
M`P!+````UA,#`$`````B%`,`0@```&,4`P`&````IA0#`!8```"M%`,`&@``
M`,04`P`0````WQ0#`!L```#P%`,`*`````P5`P`?````-14#`!0```!5%0,`
M.@```&H5`P!`````I14#`#0```#F%0,`+P```!L6`P`C````2Q8#``X```!O
M%@,`-P```'X6`P`L````MA8#`"T```#C%@,`'````!$7`P`Q````+A<#`!$`
M``!@%P,`,P```'(7`P`H````IA<#`#(```#/%P,`*P````(8`P`H````+A@#
M`"P```!7&`,`#0```(08`P`&````DA@#``\```"9&`,`$@```*D8`P`5````
MO!@#``@```#2&`,`!P```-L8`P!"````XQ@#``@````F&0,`"@```"\9`P`)
M````.AD#``H```!$&0,`%P```$\9`P`(````9QD#``D```!P&0,`!P```'H9
M`P`2````@AD#``H```"5&0,`"0```*`9`P`$````JAD#``<```"O&0,`"```
M`+<9`P`/````P!D#`!0```#0&0,`%@```.49`P`=````_!D#``T````:&@,`
M!P```"@:`P`0````,!H#`!L```!!&@,`$````%T:`P`A````;AH#`!\```"0
M&@,`$P```+`:`P`5````Q!H#`"0```#:&@,`#P```/\:`P`2````#QL#``T`
M```B&P,`&````#`;`P`H````21L#``X```!R&P,`'P```($;`P`I````H1L#
M``D```#+&P,`"P```-4;`P`4````X1L#``<```#V&P,`!````/X;`P`.````
M`QP#`!\````2'`,`%````#(<`P`Q````1QP#`!0```!Y'`,`%P```(X<`P`@
M````IAP#`#T```#''`,`#@````4=`P`.````%!T#``T````C'0,`"````#$=
M`P`)````.AT#``8```!$'0,`"0```$L=`P`'````51T#``L```!='0,`$P``
M`&D=`P`.````?1T#`!<```",'0,`%P```*0=`P`/````O!T#``@```#,'0,`
M&````-4=`P`+````[AT#``<```#Z'0,`'@````(>`P`-````(1X#`"8````O
M'@,`&0```%8>`P`,````<!X#``,```!]'@,`"````($>`P`A````BAX#``<`
M``"L'@,`#0```+0>`P`&````PAX#`'0```#)'@,`&@```#X?`P`*````61\#
M``<```!D'P,`)P```&P?`P!`````E!\#`!H```#5'P,`)0```/`?`P!$````
M%B`#`"D```!;(`,`/0```(4@`P`;````PR`#`!8```#?(`,`!0```/8@`P`)
M````_"`#``8````&(0,`"0````TA`P`*````%R$#``H````B(0,`"0```"TA
M`P`4````-R$#``L```!,(0,`"@```%@A`P`,````8R$#``P```!P(0,`!P``
M`'TA`P`(````A2$#``D```".(0,`%````)@A`P`+````K2$#``8```"Y(0,`
M'0```,`A`P`9````WB$#`"(```#X(0,`!0```!LB`P`+````(2(#``8````M
M(@,`)@```#0B`P`8````6R(#``H```!T(@,`%@```'\B`P`+````EB(#`!0`
M``"B(@,`"P```+<B`P`&````PR(#`!8```#*(@,`!@```.$B`P`6````Z"(#
M``8```#_(@,`&@````8C`P`+````(2,#`!8````M(P,`!0```$0C`P`'````
M2B,#``8```!2(P,`$@```%DC`P`@````;",#``L```"-(P,`#0```)DC`P`M
M````IR,#`!L```#5(P,`&````/$C`P`,````"B0#`",````7)`,`%@```#LD
M`P`Y````4B0#``8```",)`,`#0```),D`P`4````H20#`!<```"V)`,``P``
M`,XD`P`3````TB0#``D```#F)`,`(P```/`D`P`K````%"4#`"D```!`)0,`
M,P```&HE`P"$````GB4#`"4````C)@,`&@```$DF`P`O````9"8#`#0```"4
M)@,`)P```,DF`P`:````\28#`!<````,)P,`:0```"0G`P`;````CB<#`!<`
M``"J)P,`&P```,(G`P!N````WB<#`&<```!-*`,`0@```+4H`P`L````^"@#
M`#X````E*0,`10```&0I`P!4````JBD#`&X```#_*0,`+0```&XJ`P`C````
MG"H#`#L```#`*@,`)@```/PJ`P`D````(RL#`#,```!(*P,`.````'PK`P`N
M````M2L#`!L```#D*P,`%@`````L`P"*````%RP#`#<```"B+`,`/````-HL
M`P`V````%RT#`#P```!.+0,`)````(LM`P`F````L"T#`#$```#7+0,`-```
M``DN`P`R````/BX#`-<!``!Q+@,`'P```$DP`P!N````:3`#`%@```#8,`,`
M%P```#$Q`P!*````23$#`#@```"4,0,`/````,TQ`P`P````"C(#`"`````[
M,@,`2P```%PR`P`N````J#(#`"$```#7,@,`&````/DR`P`:````$C,#`"D`
M```M,P,`=P```%<S`P`S````SS,#`"4````#-`,`00```"DT`P!D````:S0#
M`%P```#0-`,`6@```"TU`P`J````B#4#`#H```"S-0,`,0```.XU`P`M````
M(#8#`",```!.-@,`%@```'(V`P"\````B38#`"@```!&-P,`'0```&\W`P`:
M````C3<#`#H```"H-P,`)@```.,W`P`I````"C@#`"T````T.`,`(@```&(X
M`P`E````A3@#`"4```"K.`,`(P```-$X`P`E````]3@#`"\````;.0,`)0``
M`$LY`P`3````<3D#`"P```"%.0,`'@```+(Y`P`W````T3D#`!L````).@,`
M-````"4Z`P`Z````6CH#`",```"5.@,`%@```+DZ`P`X````T#H#`"4````)
M.P,`00```"\[`P`J````<3L#`"T```"<.P,`1````,H[`P`I````#SP#`!\`
M```Y/`,`.````%D\`P!M````DCP#`$0`````/0,`,0```$4]`P!"````=ST#
M`$(```"Z/0,`+@```/T]`P`G````+#X#`$````!4/@,`8P```)4^`P!(````
M^3X#`%(```!"/P,`40```)4_`P!/````YS\#`$H````W0`,`)@```()``P`N
M````J4`#`%0```#80`,`'0```"U!`P`N````2T$#`"<```!Z00,`,````*)!
M`P`G````TT$#`$0```#[00,`7P```$!"`P!1````H$(#`&\```#R0@,`-```
M`&)#`P`I````ET,#`%@```#!0P,`60```!I$`P`H````=$0#`"<```"=1`,`
M,@```,5$`P!<````^$0#`#4```!510,`,````(M%`P`:````O$4#`"8```#7
M10,`*@```/Y%`P`J````*48#`"\```!41@,`:P```(1&`P!Q````\$8#`'$`
M``!B1P,`N0```-1'`P`9````CD@#`"\```"H2`,`,````-A(`P`M````"4D#
M`%(````W20,`)0```(I)`P!3````L$D#`"(````$2@,`"@```"=*`P#8````
M,DH#`$(````+2P,`*@```$Y+`P!'````>4L#`#\```#!2P,`80````%,`P!.
M````8TP#`%$```"R3`,`.0````1-`P`P````/DT#`#,```!O30,`*P```*--
M`P`H````STT#`!(```#X30,`6`````M.`P`C````9$X#`#@```"(3@,`+0``
M`,%.`P`H````[TX#`!X````83P,`/0```#=/`P`Y````=4\#`!4```"O3P,`
M&@```,5/`P`$````X$\#``@```#E3P,`!````.Y/`P`9````\T\#``\````-
M4`,`#P```!U0`P`+````+5`#``8````Y4`,`#P```$!0`P`$````4%`#`!D`
M``!54`,`3@```&]0`P!8````OE`#`%`````740,`!````&A1`P`7````;5$#
M``0```"%40,`!P```(I1`P`&````DE$#``4```"940,`!````)]1`P`5````
MI%$#`!D```"Z40,`"0```-11`P`'````WE$#``@```#F40,`$0```.]1`P`3
M`````5(#``,````54@,`!P```!E2`P`'````(5(#`!(````I4@,`#0```#Q2
M`P`4````2E(#``8```!?4@,`&@```&92`P`-````@5(#``,```"/4@,`*P``
M`)-2`P`$````OU(#``8```#$4@,`!P```,M2`P`A````TU(#`$````#U4@,`
M,0```#93`P`R````:%,#`!L```";4P,`,@```+=3`P`U````ZE,#`"0````@
M5`,`(P```$54`P`>````:50#`"0```"(5`,`'P```*U4`P`=````S50#`"4`
M``#K5`,`(P```!%5`P`>````-54#`#0```!450,`'````(E5`P`Q````IE4#
M`#(```#850,`(0````M6`P`E````+58#`"0```!35@,`'P```'A6`P`D````
MF%8#`"H```"]5@,`*````.A6`P`J````$5<#`"8````\5P,`'P```&-7`P`B
M````@U<#`"L```"F5P,`'0```-)7`P`D````\%<#`"\````56`,`,@```$58
M`P`:````>%@#`"<```"36`,`/````+M8`P`D````^%@#`"8````=60,`)0``
M`$19`P`F````:ED#`"````"160,`%@```+)9`P`>````R5D#`"<```#H60,`
M(P```!!:`P`N````-%H#`"<```!C6@,`+@```(M:`P`.````NEH#`!D```#)
M6@,`"0```.-:`P`*````[5H#`!L```#X6@,`$P```!1;`P`6````*%L#`#,`
M```_6P,`)@```'-;`P`-````FEL#`"0```"H6P,`#P```,U;`P`6````W5L#
M``L```#T6P,`#@````!<`P`L````#UP#``@````\7`,`#````$5<`P`1````
M4EP#`$````!D7`,`%````*5<`P`9````NEP#`"<```#47`,`*@```/Q<`P`@
M````)UT#`!\```!(70,`'````&A=`P`1````A5T#``@```"770,`U````*!=
M`P`(````=5X#``T```!^7@,`'@```(Q>`P`6````JUX#``D```#"7@,`#0``
M`,Q>`P`>````VEX#`!$```#Y7@,`$`````M?`P`?````'%\#``8````\7P,`
M2P```$-?`P`<````CU\#`!P```"L7P,`!P```,E?`P`2````T5\#`!4```#D
M7P,`(P```/I?`P`,````'F`#`!D````K8`,`-@```$5@`P`'````?&`#`$T`
M``"$8`,`)P```-)@`P`9````^F`#`!(````480,`%````"=A`P`R````/&$#
M`!\```!O80,`!P```(]A`P`7````EV$#``@```"O80,`"0```+AA`P`4````
MPF$#``L```#780,`&P```.-A`P`&````_V$#`"H````&8@,`"````#%B`P`C
M````.F(#`"L```!>8@,`!P```(IB`P`7````DF(#``<```"J8@,`"````+)B
M`P`)````NV(#`#X```#%8@,`!@````1C`P`2````"V,#`!0````>8P,`#P``
M`#-C`P`)````0V,#``H```!-8P,`!@```%AC`P`3````7V,#``,```!S8P,`
M!@```'=C`P`4````?F,#`"@```"38P,`#0```+QC`P`9````RF,#`!D```#D
M8P,`#0```/YC`P`-````#&0#`"$````:9`,`$@```#QD`P`?````3V0#`"P`
M``!O9`,`"@```)QD`P`3````IV0#`"T```"[9`,`"@```.ED`P`.````]&0#
M`!D````#90,`%0```!UE`P`F````,V4#``\```!:90,`)@```&IE`P`/````
MD64#`!@```"A90,`#P```+IE`P`/````RF4#`!4```#:90,`#````/!E`P`.
M````_64#`!H````,9@,`!P```"=F`P`M````+V8#``P```!=9@,`#P```&IF
M`P`%````>F8#``,```"`9@,`$0```(1F`P`<````EF8#``L```"S9@,``P``
M`+]F`P`(````PV8#``P```#,9@,`"0```-EF`P`/````XV8#``T```#S9@,`
M%@````%G`P`7````&&<#`!`````P9P,`+P```$%G`P`=````<6<#`!P```"/
M9P,`30```*QG`P!3````^F<#`$0```!.:`,`+P```)-H`P"(````PV@#`!H`
M``!,:0,`"P```&=I`P`P````<VD#``P```"D:0,`!P```+%I`P`7````N6D#
M`$4```#1:0,`$0```!=J`P`2````*6H#``@````\:@,`!````$5J`P`%````
M2FH#`!$```!0:@,`&@```&)J`P`&````?6H#``<```"$:@,`"0```(QJ`P`0
M````EFH#``@```"G:@,`$@```+!J`P`.````PVH#`$4```#2:@,`-@```!AK
M`P`I````3VL#``4```!Y:P,`&0```']K`P`D````F6L#`"(```"^:P,`*```
M`.%K`P`0````"FP#``(````;;`,`!````!YL`P`+````(VP#``H````O;`,`
M!0```#IL`P`#````0&P#`!````!$;`,`0````%5L`P!2````EFP#`#4```#I
M;`,`+P```!]M`P`B````3VT#`"8```!R;0,`3P```)EM`P`F````Z6T#`#,`
M```0;@,`,P```$1N`P`:````>&X#`!X```"3;@,`>0```+)N`P`K````+&\#
M`"8```!8;P,`7````']O`P`O````W&\#`%,````,<`,`.0```&!P`P!)````
MFG`#`!P```#D<`,`&0````%Q`P`;````&W$#`!8````W<0,`*P```$YQ`P`N
M````>G$#`(4```"I<0,`)````"]R`P!"````5'(#`"4```"7<@,`1P```+UR
M`P`N````!7,#`"L````T<P,`4P```&!S`P!6````M',#`#H````+=`,`+```
M`$9T`P`J````<W0#`#,```">=`,`-@```-)T`P`F````"74#`"X````P=0,`
M+@```%]U`P`P````CG4#`#````"_=0,`+0```/!U`P`R````'G8#`$````!1
M=@,`-````))V`P`O````QW8#`"(```#W=@,`/P```!IW`P!"````6G<#`"4`
M``"==P,`*````,-W`P`W````['<#`!8````D>`,`(````#MX`P`0````7'@#
M`'P```!M>`,`"````.IX`P`?````\W@#`!$````3>0,`$0```"5Y`P`P````
M-WD#`"@```!H>0,`#````)%Y`P!?````GGD#`'````#^>0,`<@```&]Z`P"`
M````XGH#`$0```!C>P,`)@```*A[`P!>````SWL#`!<````N?`,`.````$9\
M`P`X````?WP#`",```"X?`,`%@```-Q\`P`2````\WP#`)<````&?0,`%```
M`)Y]`P`E````LWT#`!P```#9?0,`0````/9]`P`>````-WX#`!D```!6?@,`
M4````'!^`P`2````P7X#`!@```#4?@,`#P```.U^`P`*````_7X#``4````(
M?P,`!@````Y_`P`(````%7\#``4````>?P,`$P```"1_`P`6````.'\#``T`
M``!/?P,`%P```%U_`P`3````=7\#`!8```")?P,`(0```*!_`P`E````PG\#
M`!````#H?P,`#@```/E_`P`$````"(`#``P````-@`,`!````!J``P`#````
M'X`#``D````C@`,`"````"V``P`/````-H`#``<```!&@`,`!P```$Z``P`&
M````5H`#``L```!=@`,`&@```&F``P`1````A(`#``D```"6@`,`#````*"`
M`P`9````K8`#`!````#'@`,`#0```-B``P`'````YH`#``L```#N@`,`"0``
M`/J``P`+````!($#``T````0@0,`$````!Z!`P`*````+X$#``H````Z@0,`
M$````$6!`P`+````5H$#`!H```!B@0,`"@```'V!`P`%````B($#``H```".
M@0,`"0```)F!`P`.````HX$#``T```"R@0,`%0```,"!`P`9````UH$#``4`
M``#P@0,`"@```/:!`P`%`````8(#``8````'@@,`!0````Z"`P`C````%((#
M`!<````X@@,`"P```%""`P`C````7((#`!0```"`@@,`*P```)6"`P`9````
MP8(#``8```#;@@,`%P```.*"`P`%````^H(#``<`````@P,``@````B#`P`;
M````"X,#``4````G@P,``@```"V#`P`"````,(,#`!L````S@P,`"````$^#
M`P`+````6(,#`!4```!D@P,`&````'J#`P`%````DX,#``<```"9@P,`#P``
M`*&#`P`S````L8,#``(```#E@P,`!````.B#`P`'````[8,#`!````#U@P,`
M%@````:$`P`.````'80#``(````LA`,`"P```"^$`P`0````.X0#``8```!,
MA`,`#@```%.$`P`8````8H0#``@```![A`,`%````(2$`P`1````F80#`!(`
M``"KA`,`$@```+Z$`P`3````T80#``(```#EA`,`!P```.B$`P`/````\(0#
M`!``````A0,`$````!&%`P`L````(H4#``D```!/A0,`"````%F%`P`2````
M8H4#``4```!UA0,``@```'N%`P`+````?H4#``\```"*A0,`$````)J%`P`!
M`````````*X%````````>PH``!`+``!9"P``9`H``%(%``#]"@``9P$`````
M````````%0D```````#1`@``SP4```````"8!P``#@8``"T)``"7`0``[`,`
M``````!&`@``+@L```````!N````````````````````=`@``,@!````````
MP@H``!8````6!0``H@,``,D%```+!P``M@D``/P"```V"```1`L``*4*````
M````Y@0```,$``"4!@``!`8``$T+`````````````-L$``"K!@``J`0``#0&
M``#@"```N0D``/<&``!#!0``-0(````````\`@```````"L+````````````
M`'<#```G"0```````*,(``!-````"P```````````````````.\!````````
MQ0(``#$#````````Z@4``+D'````````A@8``%T+``#>`P``E0<``%\(````
M````ZP8``-\```!W!0``"P@``"X!`````````````"P"```Y"0``````````
M``"3!0``IP@``'D$````````)`@```````!/`0```````+0"````````2@``
M`/@$````````,@,``,P!```W`@``YP@`````````````8@4``*,*````````
MS`8``/<*``"U"```100``&L&``#`````````````````````?P``````````
M````(P<``#$'``"X"````````"4*``!,"P```````,$)``"2`P``@@8``*<`
M``!.!@``P@8``+,*``#1"```[@<``+`(``!\"@``.P,``!H```!K`0``*0@`
M`"L%``#'`@``Q@(```8&```5"@````````````"2!0``/@,``)L```")`0``
M70(``(0&````````>`D``.D%``"I"```J`8``)D(``#;!P``R`<``&X+``!5
M`P```````)(&````````L````"D+````````X0$``$L&``!9!P``G04``+D$
M``")"0```````)`#```[`0````4``#(!``#X"```Q@<``&@$```+"P``7`H`
M`(L)```@`@``.04```````!<````&`L`````````````M0<``&0)``#]`P``
M`````*4(``#P"0```````)L(```?!0``A@D```````!F!0``$0D```````"B
M`0```````!@!````````_@D``"T!``!I"0``^P@``*H%```M!P``PP``````
M``##!0```````*`"```-!@``O@$``$0#``#?`@``F@D``,T$``!_"```\P@`
M```````*"0``3P```",````D!@``!P4``'$!`````````````%T#````````
MUPD``%0(```@!0``!`(``&T)```'`@```````,,#``"H!0``X0```"@*``#3
M!0``UP(``((#``!3"P``0`$`````````````.`(``*L'``!'"```R@<`````
M``!L"````````````````0```````+L%```%`@``;0<``!((``#G!P``7P``
M`#L'````````'@H```````#6"@````````4%```!"```40,``!`#```Y!@``
M/@4``#0#````````408``*0)````````=@L``.0%````````^P(`````````
M````%`8``)`&``"3`0``504````````E````,`@``%X$```U"P```````#<*
M````````@PH```````",!0``7`4```````!_`P``V08``#<)```5!```WP@`
M`/H&``";`P``J04``)((``#V"````````"H+```O````[@0````*``!"`0``
M`````"((````````K0<`````````````U@<```````"_`@````````X+``#4
M!@``$`(``,X(``!A"```APD`````````````!@4``!0!``#J!@``U08``%L)
M``!Q"```O`@```````"3!P`````````````="@```````&D%``#Y!P``50H`
M````````````'@,``%(#``#M!@```````'`"``!F!@```````!H)````````
MXP8```````"+!```>@0``%X&``"'!0``$@8```````#Q`0``!P,``'0+``#(
M`@``;`D``-,)``#T`P``HP<``+T*``!Y`0``G0$``&`$````````[0@``!\*
M```4!0````````````#2!0``'`(``'L+``!_`0``7@,```H%```F"P``````
M`*8(``!M`P``+`<``+H#``````````````````"[`0``F`(``-0```!%`P``
M]@$```````#%"0``=P```!@#````````4P````````"6"0``,P$````````:
M!P```````/$#````````%P<``'8)``!U"0``C0``````````````W````'P$
M``!0!P``(00````````H`@``[PH``&8*``#N"@``BP$``'P(``!<`@``````
M`*0"``#="0``^`8`````````````*@D`````````````3P@```````"1`@``
M``````````#""0``"@8```````!="0``70@``$X(``!7!@``^@```%D)``"U
M`0```````$`"``#@````'PD``#X```!I````W@<````````;!@``IPH``.D`
M```S`P``O0<``&0(```W"P``<00``'\*``!."P```````"`(``"V!0``(0<`
M`,P```!Z"0```````+H"``"T"@``.@(``&4"``"0"@````````T'````````
M[0H```````!W"```O@4``*H#``!D`P````````````"U`P``BP8``((!````
M`````````!\```#\!P``R0<``"8$```B"@``+P8``!L+``"6`0```````,8%
M```-`````````/P*``#Z"0``2@8``,((``#D!P````````````!<"0``:0,`
M`!<"``!D`0```````,L````>!```.`$``'$&``!@`@``;PH``'8%``!(`P``
M````````````````@0H``"\%``````````````````````````````````!<
M"P``,@4``(<!````````!PD``)@!``#M!`````````(`````````/P<`````
M``#T!0``6@0``/(!```E`@``=@<``+X)``!0`0``>`$``#D```"+"@``H@``
M`/T```!F"```L0H``)D)````````7@4``"@#``#2`0``?0,``/`(````````
M`````(`#``"%"@```````*,#````````(@D``"T`````````)@(`````````
M````*0D``+`)```Z`P``````````````````7@H`````````````K@,``!0+
M``!M!@````````````![````.@L```8!``#0!@```````),&``#Z"@``````
M`,L)````````CP```!X+``!P!@``2PH``-@'``#?!@`````````````3!P``
M%@@``)`$```J`````````&@*``!``P``50D````````!"@```````.(!``!I
M"P``5`0```````"#"P```````(<&``"K"```U`,`````````````0PH``#,`
M``"T!@``%`0```````!Y!0``_@(``````````````@L``*4"``!+"0``]@,`
M`%```````````````"H$``"M!````````%@(``!&!```$P(``%,$``"/!P``
M`````$X%``!9`````````!T$````````CP@``/4!``!T`0``]@4``$@!``!?
M"P``MP@``#H)``!L````H0$``"@&```X`P``TP$````````1`P``L`<``/L&
M````````U0$``+L"````````)P0``%(+``!#`@``@@0``(H$````````@@@`
M`(T&`````````````)\#``!,"```3`$``$D#````````[0,``(X'```J!P``
M````````````````A00```L*``#[`P```````*P$``"/"@``=@8``.8)``"E
M!0``Z@$``!L$``#0"0```````!@"``"U"0```````$0)``#^"```6P``````
M``!\!P``+0(```````#>!```/0H``,\"```;`0```````!$&````````@0@`
M`.$$```%"P``:P<``&@#``#F!@``600``+@)``#"!P``'@<``.\%``"3!```
M>@H```````!+`@```0$``),)``#``0``Z0H```,"``!?`0``M@```+$%``#5
M!0``#@4``-H$```S"@````````("`````````````'H(``#&`P``+P(`````
M``#=`````````)@)``#+!0``K0$``````````````````,,&``#+`@``H@@`
M`-@(``"J!````````-8$``#U!```;`4``+@%``"7`@``G00``,0&``#E`@``
M#@0``(`(``!S"@```````#4$```]`@``)@,``'P&````````;P8``*`(````
M````%P```,("``!)"```D@$```````"-`@``"0@``%8)``#C"@```````+,)
M``!-!0``8@<``!@*``"S!P``^PH``%,*``!5"P``N0H``-\)````````````
M```````.!P``'04``-`!``"``0```````'X#```E!```P`(``%X!````````
M0P0``%\&```D!P```````````````````````+4&``!N!```+`4``#$$````
M````8`<``%,"``"\`@``R@,``&H*``""`````````&$'````````A@<``#P(
M``!L`0``,`8```T"````````X@````````"-!```>`4```````!X`P``00H`
M`$X"`````````````,0#````````=@$``#\(```R"0``3`H``!`)``"L"0``
M(@$``/`'``!J`@``X`,``",!````````"`<```````#^!0````````````"5
M`P``"@@````````8!P``>0,``/4&``!4`@```````#T$``!&`P``/0<``"T(
M``#G"0``!P$```````"O!@``<@H``-P#````````6`L``(D$````````W`0`
M`(,)````````/@(```````!,!@````````````````````````````"\````
M)P<``!L#``!7`````````&D"``#(`````````%4'``#%!@```````)@&``#/
M`0````````8+``"L!P``]`<``````````````````-@$``#K`@``V@8``*P*
M```K!```]04``/`*````````$@L``+(&``"*!@```````*<#``!]`@``704`
M``@+``"R`@```````#D"``"Q!@``O@```*P!``!:"P``.PD``/L!```3`P``
M=P0``*\%``#>!0``B````%($```""@``<P@``$@'``#I`0``]@D``"X%``#,
M!0``?`,``,\&``"O"```>P8```````#Q!@``>P0```````#:`@``.P@``'0'
M``#Y`0``-P<``-P(``#H`P```````+0)````````0@L``(T%```L"```````
M```````K"@``?@$``-`*```C"0``(@4``-<*```8"```004```````#*!```
M?0$``&P"``#I!P``"04```````"="```>`0````````("@````````T#``"`
M"@``:08``-8)```,"```]`8``!<&``")"@``W`<``````````````````+8"
M``#*`````````!D(````````I`@``'8"``!""```[@8``*8&````````<`4`
M`+H!``!N`@``^@$``$\$```(!0````````````"X`@``OPH``%8$````````
M.00```````!"`@``````````````````;P@``%\)``":!P``S0@``)P(````
M````.P````````#H`````````#\+``#9````*P(``-`%```@!@``$````,<$
M``#7````'P,``.H)``#F!0``^0@``"T%```Q`0``<0``````````````'`<`
M`$,&``"_````G@,`````````````N````/X'``#*`0``>`(```````"Y"```
M$`8```````#B!````````$,````!"0````````````#R`P```````+H$```/
M!```B`$```($```E`P```````)4```#9"0``M@,``'0$``!6!0```````$\%
M``"?`0``&0$``#0"``"?"`````````````#Q"````````/()```%````5P$`
M`#D*``!O`0``T@```/8"``!>"```_0$```````"9`@``LP$````$``#5!```
MTP0```````#5!P``=PH``&@(````````JPD``$P"``"<!P``"`,``/$*```A
M!@``KP0`````````````H0<``"D!````````1P<```````!8!@``^@4``&$*
M````````=P<````````N`@``T0D```````"A`@``JP,``)`"```9"P``6@D`
M`/4"``#L`@``E````%0'``!6!P``T04``"8&````````@`<``,L#```*````
M`````/@*````````_P<````````L"P``J08``%L%``"Q!```M@0``&H'```V
M`@``]P@`````````````U`<``/T&``!"````10H``"$"```?"```Q0H```D!
M```Q`@````````L!````````'@``````````````#@,``/\$``#L"````P,`
M````````````\P4``````````````````-D(``#G`0``6P$```````!)!0``
MV@H```````"`!0```````.0!``!Z`P``*0<``/P#``!S!P``5P0``.0#``!(
M````'`D``(4)````````,`4```````#7"```]@```%`*``!C"@``=`,`````
M``#'`0``[P````,&``!)`0``C`,``$0%````````````````````````9P,`
M`,P"````````1P4``'P%``#0````R`4``-,````Z!@``H00`````````````
M_P4``````````````````(8%``"_`P```````%L&``#/!```O04`````````
M````/@H```````!T"@``=04``+P'``#@"0``10$```````#R!0``K`,``)$$
M````````Z`8````````""0``C@D``.<*````````!PL``.("```2!P``#`D`
M```````,`P``5@```/\```!J!```Y0D``$0*````````^0H``.@%``#^!```
M``````````!'`P``30(``!$%``"F!P````````````!Z````H`4```H"```1
M"P``K@D``&,"``#M!P```````%8&``":"@``_@8``/<$``!&!P``,@<``&P#
M``!E"P```````'@(```S"```+0,``'`(`````````````!X&```?"P``<@<`
M``````!0`@```````!D)``"<!`````````````!H!P``0@0````````Z"@``
M)`0``(T*``#E`P```````+,"``#5````Y04```````!-`0```````)0)``!A
M"0``````````````````900``)X$``!Z!0```````%H```"&`0```````/,&
M``#G!0``=PD```````"X`0``,P4``(0+``"M"0``I@H``&T$```P````KP(`
M`'T%``"J`@```````,P)````````,P8```````#$`@``UP<``.L$````````
MN@8``+,&``!@"@``:0@``"P*```_````X@<``+((````````W@D``"`*``"T
M!P``4P8``(H"``!=````*@4```0!````````&PH``'X*```H"```5@,``)`!
M``!'`0``ZPH``/\#```P!P``F@4`````````````L@$``!T"```@!P``(`D`
M````````````Z@,``#,'```/!P``C@$``/<)````````?0```%4(``#N`P``
MGPH``+`!``#8!@``"0L```D&``!+!P``S0<``+L*``#D`@``(`L`````````
M````[@D```````!2````&@4``#$*``"P!0``?0D``'X&``!V"```I@0`````
M````````C@@``"$(``#)!@``(@0`````````````GP0``*<%````````````
M``````#W`0``Y````%T*``!,````]`0`````````````%0<``$,#``"]"0``
M$@0``#X+``"D!```]`@``!L%```;````K0,``!8*``"""P```````-X"``"6
M!@``]`$``"X'``!9"@``%@0``$(&``"2!P``*00``'(+```'````#`$``&0+
M``#9!P``:P@``"````">!P``3@```'X'``"S````RP@``*0#``"("```1@@`
M`!H(```<!0```````+$"````````T@0``*0&```S!```R`8``/8&``!8!0``
M7P0``*`'``#-````MP<``#L&````````Q`@``-T$````````W0<````````'
M!````````(P"``!R!0``V`$```````#M`````````&`````7!```#`4`````
M``!E````W04```H#``"Q!P``/08``)<#``#.!```;@$``)T"````````9P<`
M```````J`@``XPD``'X```"<!@```````-@#``"<!0``#P8``'D"``"5`@``
MD@```,P'````````X@@``-D*````````(@,``(H#````````N0,`````````
M````108``-L!```]!0``-`L``"@!``#@!0``Q0$``.$&```0!```D`<``#@`
M``""!P``N@```(\"``"/`P``9@D``)P)``!7"P``V0(``!,$``![`P``VP8`
M`````````````````,8*```A"0````````````"'````*04``-X(``#Z`@``
M-`H``'$*``"2"@````````````"*!P``;`<```````!>!P````````````"6
M`P``P`0```L%``!O````0`D``-X```!?"@``40$`````````````<P,``-<%
M``#5`P```````/`"``!M"@``LP,```````!`!P```````&0%``"O"@``-0@`
M``````!)"0``P00``&@%``";`0``\`8``"<&``!4"0``$0``````````````
MWP0`````````````6`(``,$#````````+P@``,H&``#\`0```````,4$````
M````I`4``-8(``````````````````".!```K@```'<!``#1"@``10L`````
M``""`@``6PL``'\%``!N"```/````*<!``#F!P``#`<``&X&````````"`8`
M````````````V@<````)``"R`````````+,(```J"```FPH``%X"``#4!```
MN@4```T(```;`@``!@```(@)``!:`0``XP$`````````````P@$``!0*``!U
M`@```````-D#``!2!P``X@8```@`````````@P8``(T#````````)0L`````
M````````MPH``)4!````````Y0```-P%``!-`P``M`$``$0"``"P`@``I0$`
M`)D!```2`0``_04```````"$`0````````,(``"C!0````````````"G`@``
M*P````$%``!`````=0H``/$)``"O!P``.0$``.\$``!S!````````,$!``#$
M"@```````)`(```/`@``!@0```````!0!@```````*\```#``P``80$`````
M```>"0```````)X!``#_"0``G@(``%,%````````#@H``$`(``#E"```]P4`
M```````X!P```````!`(```P"@``!@@``)H"``!5`0```````)T#```6!P``
M`P```%0+```P`@``V@4`````````````O@<``/H#``#:"0``1@```"8!``!K
M"P``^0```+$)```1"@``8@(``-L)````````1P0`````````````;P<`````
M``#.`0```````$H%```:`P``P0<``"(```"\!```2P4``!\!````````C@H`
M`*0'``!J"````````)T&``!_!P``5P<``#<$````````JP4```````#1`0``
M)P````````"]!```^`4``*L"```<`0````````````"!``````````````!Z
M`0``*@H``'``````````9@0``)$#```&"@``0@H``/0```!P`0``@P@``!P$
M``"9"@``0@,``,8```"C````X`0``$X*``!2"0``.`H``'<+``!9`0``U@8`
M``4(````````E`0```````!5`@``)`,``-T*```\"P```````#\#````````
M^P0`````````````#`8``(D```"*`0``XP,``)L'``!C````8@H``$X'```T
M!```E@4``.H````R`@```````'@'```A`P``+@H```````#I!@``@`(`````
M``#A"0``/`,``-8!```:!```X@H``.4'``"["```20H``$4```!B!```````
M`#\*``!#"```TP,``$,)``"5"````````$H#``!G!```2`(```````#/"0``
M`````-@*``#8!0``H0H````````3````7P<``'4```"N!@``E0H``)8(``"#
M!```N0```&,+``!E!0``/`0``#X(````````=0$``'L)`````````0<``"4'
M``#5"0``U@```#T(``!@"```A08``$4%``#P`P``2@D``+@$``!2"@``Z0(`
M`-8%``!G"@``H@(``&(&``"_"0``"`D```````"U!0````````````"&`P``
M90D``+()```,!```T`0``(@%``!E!@``208```````!3`P``C0D``*(%``#O
M"0``)`4``&$"````````#@(``.@*````````%08``(H%````````PP@``(,#
M```Z"```MP0```H'````````N0$``!(````3"0``-P,``&T!``#3"```@@D`
M`````````````````+4$````````````````````````````````````````
MB0<```0(``#0!P```````,L&`````````````#T!```O"0``-````&`!``"^
M"````````/<````\!P``'P<``)\```"(`P```````/4)``"O`P```````'X)
M````````G`````P*``!J!0``````````````````[@```#4%````````````
M`"8%``#Z!P``XP@``($!`````````````$0$````````[04``'H'````````
M'0L``$H'`````````````%H'``!1````IPD``%P(```I!@``[P@``)L)```T
M!P``0P<```P"``"\`0``9P@``'4&``"T!````````%<"`````````````,8(
M```)````$PH``!,(``"5!```G@4``%@!``#%!0````````X)``"<`@``F0``
M``````!'"0```````,@$``#<`@``'`L``$`+``!6`0``N@<`````````````
MF08``#(*```]"0````````````"&"```7`0``,,$``!%"0``XP0``,T*``"4
M!0``<@0```````"M"@```````*T(`````````````$@%``#_"@``)08`````
M``"C!```^0D```$"````````%````+$!````````%@L``)<&```[!0``````
M``````"@`P``4@8``#8#``!R````2`D``!8!```M!```SP,``/P(````````
MTP8``#<%````````$0@``!<%```$!0``[`4``,$```#_`@```````*@)``!0
M`P``2`L``/(*``#U"@```````"<+```U"0``"0D```````!O"0``2@L``"<!
M```/`P```````*P(``"A````/`8``````````````````"$+````````*P<`
M``````!,!```BP@```\```!K`P``=````'8#``!/!P``RP<``.P```#N"```
MDP@``)0*``#@`@``D08```````#+"@``$0(```````"1"0``%@(``#4!````
M````ZP@``.P&``!6"P``8`,``$$'```L!```5````+8(````````@0D``*,)
M```L"0``/@<```````"T"````````-T"``#G!@``.0<``%P&``"^`@``00,`
M`,T#``#)"@``'@@``+L)``!`!@``M0(`````````````'P0``&D*``"4"```
M\0<```````",!@``HP8``(4"`````````````%$+``!*"@``(P(```````!O
M!0```````/X*```=!P``[P<``!4```#R!@``Q@D``````````````````"L#
M``"E`P``[@4``/$```!(!````````&X'``"$"@``JP``````````````````
M`'\+```````````````````^"0``R`,``/T'`````````````#8$```P"0``
M`````.P$```;"```S`0```,+``#S`P```````!P````V"0``^P```+@#```O
M"P``FP0``!D$````````J`,```````#5`@``'`,``)D$```X"P``[`<`````
M```*"P``:@```.8(``"]``````````````"/"0``D0@``+T(``!\`@```@8`
M`!@````B!P```00```$+``#&!```\04``.`!````````T@,``!T(``!+````
M,0L``.0)```^`0``O`8``-0!``!1!P``!`L``*8%``````````````````"N
M`@``0@D``)$%``!/"@``[0$```````#J!P```````(<(`````````````,`*
M``#I"```?````/('``"%"```M@$``&8'``!D````AP,``*P&``!G`@``P0(`
M`.,"``!H`@``=0L```````"&`@``L@,```````!_!```!0<````````Q!@``
MY`8``((*``!X!@``T@<```````#$!0``EP4``,0!```%`0``,0D``'4$```Y
M"P``]`(``+4*```7"P``OP<```````"K`0``20````````"S!```J`H`````
M```A````]0<````````<"```N`<``"L)````````>@L``-,"``#W`@``%0L`
M`,$*```"!P``S`@``%@*``!^!`````````X```#S`@``<P```)<'```O!```
M(P0``$D'```P`0``+P<``(0)``#:"```G@D``&$#`````````````'D+````
M````8P,``#,)``#B"0``3@0``%P!``!R`@``=0@``!<)```H!P``8`8`````
M``":`P``WP,``'`+``!3`0````````````!J`0``H@0``-(*``!K"0``````
M`$4'``#X"0``?P8``"P#``":`0``:PH``$0!````````5`8``,X*```9`P``
M30<````````E"```/PD``#@(````````M`4```````!A"P`````````#``!!
M"```Y@H``)@#``#K`0``CP0``#0%``"9`P``!P8``",+``#J`@``H`H``!0'
M``"D`0``R@@```````!6`@``S@,```````#D"```````````````````@P<`
M`(H*````````+`8``(X%``!B"0```````(,%``#H!```$P$``%@$``!A!0``
M.@<``%0%``#/````B`(``(P*````````=@```-8#````````<@,``$@&``"F
M````T@@``(@&``"I`0``X@,```````"$````8@```%T'````````/`$``(T(
M````````I@,````````;"0```````!H+````````!`H``'X"``"J````````
M`)$'``"4!P``GPD```0#``"7!```:P0````````N````J@$``"\#``!M"P``
M6`<````(``".`````````&H+``!]"`````L``$\&``#7`P``Z`(````````F
M"0``!`D```````#%`P``000```````":!@``\@(``/<'``!0!0```````-<!
M````````)`L``!4%```J`0``#0$``#\%````````404```L"```!`P``J0H`
M`%X+``!:!@```````&D!```/"```>0<````````4"0``L@H``)@%````````
M;`H``(4!``":````ZP4``!X!``!D!P``C````&D$```C"@``"0,`````````
M````Y00``'$+``#)`````````$`$``#)!```H0D``$\+``"R!P``-P```/T$
M````````)@H``,D!``"A!0````````````"G!P``J`(``%$)``#`"```````
M`)8"`````````````.,```#1````=@H``'T+``#.````/0```-\%``!U`P``
MS@<``%@#``!A!```DP,```````"M````]P,``!()``#?`0``90$``'0)```_
M`@``[@(``,@*``!;!````````-T#``![!P``L0````4#````````604`````
M``!&!0``H@D```````#X!P``1`@``+X$``#E`0```````(`&``#*"0``(0H`
M`!,+``"+!0``J0<``-()``#U"`````````````![`@``500```````"X!@``
M``````````#+`0``W`H```````!P"@```````),*````````B`<``-8"``#H
M!P``G0D``($"```I````5`$```````#0`P``8@,``(4%``#$!````````.,%
M``#_`0``7@D``)4%``#2!@``(@L``&8!``"J"0``OP4```````"V!P``````
M`+8*`````````````#L$``"#````GP(````````"`0```````+P)``"H"```
M00$```L)```#`0``$@4```\*``"W`0``9P8```4$``!!`@``B08``",(``"O
M`0``J@@``,@)``"$!```;0(``$P%````````/@0``!4#``!=!@``````````
M``!?`@``NP<``+D&```:`0``O`4``"\!``#/"@```````$,!``#X````%@8`
M``````!Z`@``V04``&,!````````_@```!`!``!@"0``(`$```````!'!@``
M``````H*``"("@``7P,``#8%``#^`0``%P@``````````````````+P*``"P
M"@```````'((``````````````````!S"0``40H``````````````````*$(
M```^!@``,04``-0"``````````````(#```;!P``&08``-$'```$!P``````
M`+T"```W"```!@(``-@`````````700```````"W`P``Q0<`````````````
M)````,D)````````3P(``+`$``!:!0```````%`$````````_`0```````#:
M`0``[`$```````"B"@```````,X&``!`"@``-`$``*H'````````>0D`````
M```*!````````-0%``#=`0```````!4!``#0`@`````````````W`0``OP$`
M`'@*```V"P``[0D``+T!````````%`,```````#\"0```````'(!``"4`@``
M$0<``&0$``","```SP@``,$%``"K!```;@H``%,)``"?!P``+0H``)<(````
M````P0@````````G!0``G0<``%`(``"!!0``!08``&<``````````````&4'
M``"<`P``D`D``/,)``!P!```#PD`````````````Y`H```D*``!)`@``F@@`
M`,,'``"L`@```````*8!``"[`P```````/@#`````````````#@)``#?!P``
MJ0```-4(``"N"@``90H```````">"``````````````:"@```````)D'``!W
M`@``^PD`````````````O@,``"4%````````D0H``(P)`````````````%$"
M``!5!@``C0$```````#Q`@``3@D``(H```#-`0````````````#V!```````
M`&P&````````PPH``!\"````````1@L``(L```!1"```Z@@``/L'``"*"```
MH08```D"```&"0``.@0```$&``"J!@``6@(``/\(``!&!@```````,(%````
M````A0<`````````````X0<``%L'``#O`@``Z0D``/0*``!.`P```````,D(
M``!V!```A@0``(H)``#`"0``HP(``,H%``#?"@``R0,````````2`P``1`<`
M`/D$``".!@``!P<``%@```#'!@``4@(``%<#``"W!@``UP8``(P'```E`0``
M``````8'```9"@``!0H``,4```"M!0```````````````````@4```````!N
M!0``@08```````"$`P``;@D```````!A`````````/,!``!&"@``_`4`````
M``"!!P``:`$``!D%```=`P``90@``-X&````````-`D```````"A`P``ZP,`
M``````!Y````$0$```\!``#@!P``-08``'L!```H````6@,``&X#``#P!```
M`````.4*``#;`P``9@L``*X$```?!@``,0```&H&``#'"```G`$````````4
M"```O`,```````!-"0``60,``-0)``!\`0`````````````B`@````````P+
M``"7"0``````````````````H`D```8#````````L@4``+X&``#J!```G`H`
M`&,&``!7"```+@,```````!O`P``1````&(!``"G!```,PL``"X&````````
M`````*4``````````````),````C!@``'`H``/T"``#[!0``>0H```````!-
M"```QP````````#'!P``Q`<``*(&``#L"0``S`H``"@$``"Q"```"`$`````
M``"W`@``/`4``-("``"3`@``;`L``.D#``!C"0``L`8```````!+"```N@H`
M`-4*``"W!0``S@4``!H"````````]0,``(8```#`!0``TP<````````V!P``
M1PL``!D"``#`!@``Q`````````"+!P````````T$```5"````````+L```#K
M!P``\PH```T*````````YP,``+T&````````EP```/,$`````````````&0&
M`````````````/,'``#'"@``[0(`````````````*0(``(8*```-"P``90,`
M````````````J`<``!`*``!0"P``<P(``$<````L````/0,``)T````F!P``
MBP,``(@$``!)!````````!8)``"E!```````````````````B0@``$T*``##
M`@```````&,'``!["```P@0``-0(``#'`P``:`D``#8&````````-0,``!@$
M`````````````&L"``"#`0```````*\)``#:````6P,````````Y"```I08`
M``4)``"T`P``A`(```````#S``````````````"B!P``1@D``&@&``"[!```
M^0(``*D"``!.`0```````(P!``!G"P``4P<``)<*``!K!0``O@H``/D#``!Q
M`P``%0(``&8```!6"```E`$```,)``!\"0``/0L`````````````)@@```((
M``#("```.`0```````#K"0``=`(``(<*``!0"0````````````#."0``&0``
M`$H(``!("@``608``!<#```L`0``'@(````````="0``W08``&0"``#J"@``
M,`,``'X(``!=`0```````/@!``!("```Y08``(0%``!9"```<0D``"L!``"/
M!@```````'<&``#$"0``>P4``$L$``"F"0```````,`'```+`P``_P8``.\#
M``!-!```-0<``.<"``#!!@``(P4``$H"````````NP8``"0*``">!@``'08`
M`(`$``",!```/P$``*8"```(`@``@`L``+($``!S!0``"P8```````#F`P``
MV0$``%L(````````$`<``+,%``#1!```:@,``'$"````````N0(````````+
M!```-@$```````"`````*`D```````"D"@``C@,``&,$``"'`@``QPD``)@*
M``#D!````````!X%```A!0````````````!_"0``+@@```````#0"```,`L`
M`&\$``#<"0``K@<```````";!@``^`(`````````````R@H``'(&````````
M`````'@```!M!0``D`4``,X"``!7"@``+@0```P`````````)`D``*H*```'
M"````````(4#``!]!@``@P(`````````````:@D``$$)```2`@``7`<`````
M````````>`L``&`%```=`0``<P$``#<&```_!@``X`8``)0#````````````
M`$P'``")`@``*P@``-<$``"'!P``S0D``$D+``!:"@``O0,``)4&``#"`P``
M%@,``/8'``#]"0``X04``$\#`````````````&T(``!O"P```````.8!``"!
M`P```````%L*```/!0``.0,````````R"P``C@(``,\'```3!0``````````
M``#P`0``Q@$```````"2!```,@0``)8*``!`!0``8P@````"````````XP<`
M`!P&``"_!```7`,``/(```"8"```W@H``/P````0!0``9@(```````!"!P``
M`````.(%````````,P(``'$%````````9P4``#L+```R````,0@``#\$``!+
M`P```````+0`````````<@D``.$"```G`@```````)$!````````Y@``````
M``">`````````,,)`````````````$T&``#1`P``00```+H)``"_!@``1P(`
M`'T$``"L````5PD``,T&```'"@``,@8``.<```!*!``````````````)!P``
M`````"D#``!4"@```````&\"``#4"@``:0<`````````!P``#@$``,H"``#T
M"0``5P4```0```#"````J0D``$8!````````.@4```````!2"```H`8`````
M``!8"0``(@8``!,&``#<!@``[@$`````````!@``H`$```````"/`0``2PL`
M`*L*```("```OP@``'T*`````````````',+``#F`@``?P(``%8*```(!```
M`````"@%````````8@@``',&```V````+0L``/((``!*`0``ZP```%$$``"8
M````)P@``)\&````````&`D``)L"```8!0```````"`$``#A`P``2P$``$$+
M```7"@``VP@```````"1````E@<```````!"!0````````````"N`0``808`
M````````````\````%D"``!M````D@(`````````````BP(```````"M`@``
M`````)H$```O"@```````````````````````+@*``#U````&0<````````7
M`0``N04``/P&````````R0(``(4```#H"````P<``/H(``!Y!@```````*@`
M```P!```E@``````````````.P(``*D$``#3"@``*0H``#@%``"N"```````
M`$0&```#"@``8P4``"<#```$!``````````````E"0```````(0'```\"@``
MVP4``#4*``#A"@``.@```#((```=`````````'D(````````-0````````#H
M"0``3PD``-H#```C`P``4P@``/`%``"W````G0H```````!:"````````+8&
M````````H````/D%```J`P```````,,!``!H`````````*T&````````````
M`%0#``!%`@``V`D``!(*````````-@H`````````````.PH``*,!``#A"```
M*P8``,8&```N"0``VPH`````````````YP0``(`)``#O!@``J0,``(<$``#I
M!````````'T'```D`@``<`,``)X*````````9PD``$4(``!U!P``````````
M``"E!P````````````"?!0```````($$`````````````"`#``!2`0``````
M`)4)``!H"P```````(D%``#;````[`H``!H&``"/!0``_0@```````#>`0``
M``````````#-!0```````(T'``#;`@``D````*0```!^!0``^@0```\+``"8
M!```>@8``-P!``"E"0``Q0@``)()``"U````7P4``&P$`````````````(0(
M```X!@``-`@````````Z`0``<`<``&(+````````1PH``*@!``"L!0```P4`
M````````````S`,```````#1!@```````)8$``#8`@````````````"9!0``
M6P(``"@+````````=`8``/D&```F````)`$```````#H`0``9@,``+`#``!,
M`P````````D$```8!@``/`D``/$$``#9!```"@$``"<*```M!@``<0<``+H(
M```."``````````````````````````````J!@``\@0``,T"````````=`4`
M`$P)``#^`P``(0$`````````````IP8``/8*```1!```008``+$#``!^"P``
MW0@``'`)``!\"P``7@````````#@"@``@@4````````4`@``8`L``)L%````
M````50`````````-"0``MPD``*`$```-!0``:P```,<%``")`P``@0L``,L$
M``````````````````!#"P```"`@("`@($-C.B``("`@("`@5&\Z(``@("`@
M1&%T93H@`"`@("!&<F]M.B``("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@
M)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T
M97)D87DI`"!3=6)J96-T.B``(&%T(``@:6X@`"(E<R(@:7,@;F]T(&$@9&ER
M96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO
M;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`",`)2XR9DU"
M("\@)2XR9DU"("`H)2XR9B4E*0`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL
M;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@365S<V%G97,`)60@9&%Y
M<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D(&UE<W-A9V5S(&AA
M=F4@8F5E;B!D96QE=&5D+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`
M)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`E
M9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@
M<F5P;W)T960@87,@<W!A;2X`)60@=&\@)60@;V8@)60@365S<V%G97,`)60M
M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"
M`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@
M4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR
M96%D>2!E>&ES=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E
M<B!W87,@;F]T(')E;F%M960N`"5S(&%T("5S("5S`"5S(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R
M96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S(&AA<R!A8V-E
M<'1E9"X`)7,@:&%S(&-A;F-E;&QE9"`B)7,B+@`E<R!H87,@9&5C;&EN960N
M`"5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA
M<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("(E<R(N`"5S(&AA<R!S
M96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(&AA<R!T96YT871I
M=F5L>2!A8V-E<'1E9"X`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@
M8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@
M870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO
M="!F;W5N9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@(B5S(BX`)7,@=&\@
M)7,@;V8@)7,`)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R`B)7,B+@`E
M<R!W:7-H97,@=&\@86UM96YD("(E<R(N`"5S('=I<VAE<R!T;R!M86ME('EO
M=2!A=V%R92!O9B`B)7,B+@`E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T
M97-T(&EN9F]R;6%T:6]N(&%B;W5T("(E<R(N`"5S)W,@061D<F5S<R!";V]K
M`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z
M("5S`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*0`E<SH@5&AI<R!M97-S
M86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W
M87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED
M:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN
M`"A!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N
M+BD`*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M
M<&]S92!S8W)E96XN*0`H2%1-3"D`*%!L86EN(%1E>'0I`"A2971U<FX@=&\@
M=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S
M(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E
M;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*%-E;F0@;65S<V%G92!A9G1E<B!A
M<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O
M;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"H@
M061D('1H97-E(&)Y(&-L:6-K:6YG($]+("H`*B!0;&5A<V4@<V5L96-T(&%D
M9')E<W,H97,I("H`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I
M86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q(&UE<W-A9V4@:&%S
M(&)E96X@9&5L971E9"X`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2X`,2!M97-S86=E
M(&AA<R!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BX`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P
M86TN`#$P,"!C:&%R86-T97)S`#$P,#`@8VAA<F%C=&5R<P`Q,B!(;W5R($9O
M<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`R-3`@8VAA<F%C=&5R<P`U
M,#`@8VAA<F%C=&5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9`!!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O
M('1H:7,@;65S<V%G92X`02!M97-S86=E('EO=2!H879E('-E;G0@:&%S(')E
M<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H92!R96-I
M<&EE;G0N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-
M(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`04Y$`$%0
M22!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S
M;6ED9&QE`$%C8V5P="!A;F0@861D('1O(&UY(&-A;&5N9&%R`$%C8V5P="!R
M97%U97-T`$%C8V5P=&5D`$%C8V5P=&5D.B``06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`
M06-C;W5N="!F<F]Z96XN`$%C8V]U;G0G<R!N86UE.@!!8V-O=6YT:6YG`$%C
M=&EO;G,`061D`$%D9"`E<R!T;R!M>2!!9&1R97-S($)O;VL`061D($-H:6QD
M($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W
M($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T
M;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N
M97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`
M061D('-O=7)C90!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1H:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O
M:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=&\@;7D@8V%L96YD87(`
M061D('5S97(`061D960@(B5S(B!A<R!A;B!A='1A8VAM96YT+@!!9&1E9"`B
M)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V
M:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B!O;B!A
M(&YE=R!L:6YE*3PO96T^`$%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E
M('9I97=E9"`E<RX`061D:71I;VYA;"!I;F9O<FUA=&EO;B!D971A:6QS`$%D
M9&ET:6]N86P@;65S<V%G92!D971A:6QS`$%D9&ET:6]N86P@;65S<V%G92!D
M971A:6QS(&-A;B!B92!V:65W960@)7,N`$%D9&ET:6]N86P@;65S<V%G92!E
M<G)O<B!D971A:6QS`$%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS
M(&-A;B!B92!V:65W960@)7,N`$%D9')E<W,`061D<F5S<R!";V]K`$%D9')E
M<W,@0F]O:W,`061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH
M;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO
M96T^`$%D9')E<W-E<R!T;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES(&ED96YT
M:71Y.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N
M97<@;&EN92D\+V5M/@!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`
M06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L
M;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I
M;VYS`$%L;"!F;W5R('-I9&5S`$%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W
M:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/
M6"!F:6QE.@!!;&P@;65S<V%G97,@:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E
M<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2!D96QE=&5D+@!!
M;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS
M(&]L9"!W:6QL(&)E(&1E;&5T960N`$%L;"!O;&0@<V5N="UM86EL(&9O;&1E
M<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!
M;&P@<FEG:'1S(&]N(&9O;&1E<B`B)7,B('-U8V-E<W-F=6QL>2!R96UO=F5D
M(&9O<B!U<V5R("(E<R(N`$%L;&]W($9O;&1E<B!#<F5A=&EO;C\`06QL;W<@
M9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_`$%L
M;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,
M;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5
M<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M
M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;'1E<FYA=&EV92!P87)T<R!F;W(@
M=&AI<R!S96-T:6]N.@!!;'=A>7,`06QW87ES('-A=F4@871T86-H;65N=',`
M06UE<FEC86X@4V%M;V$`06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T
M:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@
M<V%I9#H@`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06X@=6YK;F]W;B!E<G)O<B!O8V-U
M<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T92X`06X@=6YK;F]W;B!E
M<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RX`06YD
M;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!
M;G-W97)E9`!!;G-W97)E9"!M97-S86=E<P!!;G1A<F-T:6-A`$%N=&EG=6$@
M86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L
M:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@1FEL=&5R<P!!<'!L>2!&:6QT97)S
M('1O("5S`$%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_`$%P
M<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_
M`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I
M>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3
M:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L
M971E('1H:7,@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;C\`07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI
M<R!I<R!.3U0@<F5C;VUM96YD960A*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@9&\@=&AI<S\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES
M(&%T=&%C:&UE;G0_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&5M<'1Y('EO=7(@<W!A;2!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E
M<S\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A
M9V4@87,@:6YN;V-E;G0_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O
M<G0@=&AI<R!M97-S86=E(&%S('-P86T_`$%R9V5N=&EN80!!<FUE;FEA`$%R
M;65N:6%N("A!4DU30TE)+3@I`$%R<FEV86P@5&EM90!!<G0`07)U8F$`07-C
M96YD:6YG`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I
M8R!296=I;VX`07-K`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`
M071T86-H($9I;&5S`$%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC
M(&ME>2!T;R!Y;W5R(&UE<W-A9V4_`$%T=&%C:&5D($9I;&4Z`$%T=&%C:&5D
M(&9I;&4@(B5S(B!E>&-E961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S
M+B!&:6QE($Y/5"!A='1A8VAE9"X`071T86-H960@:7,@82!R97!L>2!T;R!A
M(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N`$%T=&%C:&UE;G0`071T86-H
M;65N="`E<R!D96QE=&5D+@!!='1A8VAM96YT($EN9F]R;6%T:6]N`$%T=&%C
M:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP90!!='1A
M8VAM96YT<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD
M965S`$%T=&5N=&EO;@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S
M=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T
M:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I
M8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T
M:&4@4TU"('-E<G9E<B!F86EL960N`$%U=&]M871I8V%L;'D@<VAO=R!I;6%G
M97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@
M861D<F5S<V)O;VL_`$%V86EL86)L92!!9&1R97-S(&)O;VMS.@!!=F%I;&%B
M;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!!>F5R8F%I:F%N`$)/1D@@
M17AC=7-E<P!"86-?:R!T;R`E<P!"86-K('1O("5S`$)A8VL@=&\@375L=&EP
M;&4@365S<V%G92!6:65W($EN9&5X`$)A8VL@=&\@5&AR96%D($1I<W!L87D`
M0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S
M=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"860@;&]G:6X@;F%M92!O
M<B!P87-S=V]R9"X`0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@
M4F5S<&]N9&5D.B`E<P!"860@<F5Q=65S=#H@)7,N`$)A:&%M87,`0F%H<F%I
M;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN
M90!"8V,`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96QO=R!I<R!T:&4@<F%W
M('1E>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+@!"96YI
M;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&%C:VQI<W0`0FQO8VL@(B5S
M(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";&]C:R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!U
M;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E<W1E9#\`0F]D>0!"
M;VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S
M.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1H($AE
M861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4`0F]T<W=A;F$`0F]T
M=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E
M9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#7VAA<G-E=`!#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A
M;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E
M(&UA:6P@<V5R=F5R+@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M
M86EL('-E<G9E<CH@`$-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@
M;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT(&UA
M:6QB;W@N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@
M9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H
M86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N
M)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L($UE<W-A
M9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;F-E;&QI;F<@=&AI<R!M97-S
M86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N`$-A
M;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`
M0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R
M9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D
M;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S
M<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`
M0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`
M0V,`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#
M96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC
M("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI
M8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$
M971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S
M`$-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P
M;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BX`0VAA9`!#:&%I
M<B!097)S;VX`0VAA;F=E`$-H86YG92!!;&P`0VAA;F=E($9O;&1E<@!#:&%N
M9V4@66]U<B!087-S=V]R9`!#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@
M87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD
M(&AO=R!M97-S86=E<R!A<F4@<V]R=&5D+@!#:&%N9V4@;6%I;"!S97)V97(@
M86YD(&9O;&1E<B!S971T:6YG<RX`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B!E;6%I;',N`$-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD
M('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@96UA:6PN`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&%R86-T
M97)S('1O(&1I<W!L87DZ`$-H96-?:R!,:6YK+BXN`$-H96-K($9O;&1E<BAS
M*2!F;W(@3F5W($UA:6P`0VAE8VL@7T%L;"].;VYE`$-H96-K(&%L;"!M86EL
M('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.@!#:&5C:R!S
M<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@06-T:6]N.@!#:&]O<V4@07!P;&EC871I;VXZ
M`$-H;V]S92!A(&UA:6P@<V5R=F5R.@!#:&]O<V4@82!M871C:"!O<B!E9&ET
M('1H92!A9&1R97-S('1O('1H92!R:6=H=#H`0VAO;W-E(&$@<&%S<W=O<F0`
M0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S
M.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`
M0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D
M9')E<W-E<RX`0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O
M('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`$-H<FES=&UA<R!)
M<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R
M`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S
M97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA
M=&4`0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@
M9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RX`0VQI8VL@)7,@=&\@9&]W
M;FQO860@=&AE(&EM86=E+@!#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M
M96YT('!A9V4N`$-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@
M<V5P87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W(&$@=&AU;6)N86EL
M(&]F('1H:7,@:6UA9V4N`$-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE
M;G0@:6X@82!S97!A<F%T92!W:6YD;W<N`$-L:6-K("5S('1O('9I97<@=&AI
M<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W
M+@!#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM86=E<P!#;&EC:R!O;B!O;F4@
M;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C
M="!A;&P@9FEE;&1S('1O('-E87)C:"X`0VQI8VL@=&\@0V]N=&EN=64`0VQI
M8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O
M:P!#;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y
M;W5R($%D9')E<W,@0F]O:P!#;&EC:V%T96QL('9I82!(5%10`$-L:6-K:6YG
M(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O
M('1H92!S96YD97(`0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N
M('1H92!M97-S86=E('1O(&)E(')E860`0VQO<V4`0VQO<V4@5VEN9&]W`$-L
M;W-E('1H:7,@=VEN9&]W`$-L;W-E9"!&;VQD97(`0VQO=61S`$-L;W5D<R!%
M87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4`
M0V]L;&%P<V4@06QL`$-O;&QA<'-E($%L;"!&;VQD97)S`$-O;&QA<'-E($9O
M;&1E<@!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M
M8FEA`$-O;&]R`$-O;&]R($EN9&EC871O<CH@`$-O;&]R(%!I8VME<@!#;VQO
M=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA
M;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`
M0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4`0V]M
M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\`0V]M<&]S92!M
M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S
M97(@<W5P<&]R=',@=&AE(&9E871U<F4I/P!#;VUP=71E<G,`0V]N9&ET:6]N
M`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U
M<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD
M($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I
M9W5R92`E<P!#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N
M`$-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RX`0V]N9FER;2!087-S
M=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE`$-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0('-E<G9E<BX`0V]N;F5C
M=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S
M*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYN96-T:6]N
M('1O('-E<G9E<B!F86EL960`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@
M='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O
M;G1I;G5E`$-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+@!#;VYT<F]L(%,O
M34E-12!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG
M('1O(&UE<W-A9V5S('-E87)C:&EN9RX`0V]N=')O;"!W:&5N(&YE=R!M86EL
M('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N
M;W1I9GD@>6]U('=H96X@:70@87)R:79E<RX`0V]N=F5R="!T97AT=6%L(&5M
M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/P!#;V]K($ES;&%N9',`0V]O
M:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<'D@
M=&\@9F]L9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]S="!)1`!#;W-T
M82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE
M<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N
M8V4N("5S`$-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV
M96XZ("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O
M=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<P!#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#
M;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@;65S<V%G
M97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<P!#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N
M;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+@!#;W5L9"!N;W0@
M97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A
M='1A8VAM96YT+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T
M92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD
M(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S
M+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(&]P96X@
M<V5C=7)E(&-O;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R+B`E<R`Z("5S
M+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A
M<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO
M="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O
M:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R;VT@
M24U!4"!S97)V97(N`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L
M9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L
M9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@
M=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`
M0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E($9O
M;&1E<@!#<F5A=&4@2V5Y<P!#<F5A=&4@82!.97<@06-C;W5N=`!#<F5A=&4@
M82!L:6YK`$-R96%T92!A(&YE=R!3<&%M(&9O;&1E<@!#<F5A=&4@82!N97<@
M9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@;VYE`$-R96%T92!A(&YE=R!S
M96YT(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(`0W)E
M871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG
M(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"!A;F0@9&5L971E('-P86TN
M`$-R96%T92!N97<@<W1A=&EO;F5R>0!#<F5A=&4@<W1A=&EO;F5R>2!A;F0@
M9F]R;2!R97-P;VYS97,N`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E
M<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R
M<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#
M=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#
M=7)R96YT(&%C8V5S<R!T;R`E<P!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E
M;G0@<W1Y;&4`0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL
M(&9R;VT@;W1H97(@86-C;W5N=',N`$-U<W1O;6EZ92!H;W<@>6]U('-E;F0@
M;6%I;"X`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<"D`1&%I;'D`1&%T7V4`1&%T851R964@0G)O=W-E<@!$871A8F%S
M92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A
M>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C
M;&EN960`1&5C;&EN960Z(`!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A
M=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!396%R8V@@1FEE
M;&0`1&5F875L="!3:&5L;`!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E
M9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN:71I;VYS`$1E;&5G871E
M9`!$96QE=&4`1&5L971E("5S(%!U8FQI8R!+97D`1&5L971E($-E;&P`1&5L
M971E($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E;&5T92!'<F]U
M<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!396QE8W1E
M9"!&;VQD97)S`$1E;&5T92!3=&%T:6]N97)Y`$1E;&5T92!6:7)T=6%L($9O
M;&1E<@!$96QE=&4@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/P!$96QE
M=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM
M96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/P!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W!A;2!M97-S86=E<P!$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L
M971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`1&5L971E9"!T:&4@871T86-H;65N="`B)7,B+@!$96QE
M=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E;&EV97)Y('1I;64`1&5N;6%R
M:P!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF
M;W)M871I;VX`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$971A:6QS`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ED(&YO="!A='1A8V@@(B5S(B!A
M<R!T:&4@9FEL92!W87,@96UP='DN`$1I;2!S:6=N871U<F5S/P!$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E
M8W1O<GD`1&ES<&QA>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@
M3W!T:6]N<P!$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@
M;65S<V%G93\`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O
M<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!L87D@:6X@0F]D>2!O
M9B!-97-S86=E`$1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@
M;6%I;#\`1&ES<&QA>2!T:&4@(D5M<'1Y(%-P86TB(&QI;FL@:6X@=&AE(&UE
M;G5B87(_`$1I<W!L87D@=&AE(")%;7!T>2!4<F%S:"(@;&EN:R!I;B!T:&4@
M;65N=6)A<C\`1&ES<&]S:71I;VX`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M`$1J:6)O=71I`$1O($Y/5"!M871C:`!$;R!.;W0@0VAE8VL@1F]L9&5R*',I
M(&9O<B!.97<@36%I;`!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O(&YO="!G96YE<F%T92!A(&QI;FL@
M:6X@=&AE($9R;VTZ(&-O;'5M;@!$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@
M9F]L9&5R/P!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN
M:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M`$1O;F4`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@)7,@:6X@+GII
M<"!&;W)M870`1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I
M;&4I`$1O=VYL;V%D($9O;&1E<BAS*0!$;W=N;&]A9"!&;VQD97(H<RD@6RYZ
M:7`@9F]R;6%T70!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+@!$;W=N;&]A9"!I;B`N>FEP($9O<FUA=`!$<F%F=`!$
M<F%F="!F;VQD97(`1')A9G1S(&9O;&1E<CH`1')O<"!D;W=N(&QI<W0`1')U
M9W,`12U-86EL`$4M;6%I;"!!9&1R97-S`$5-86EL+71O+5--4R!G871E=V%Y
M(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V
M:6-E+@!%3D0`15)2`$524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E
M(&1E;&EV97)E9"X`16-U861O<@!%9&ET`$5D:70@0FQA8VML:7-T`$5D:70@
M0FQO8VL`161I="!&:6QT97)S`$5D:70@1W)O=7``161I="!097)M:7-S:6]N
M`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I
M="!396%R8V@@475E<GD`161I="!6:7)T=6%L($9O;&1E<@!%9&ET(%9I<G1U
M86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$5D:70@5VAI=&5L:7-T`$5D
M:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I
M="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!Y;W5R(&)L86-K;&ES=`!%9&ET
M('EO=7(@9FEL=&5R(')U;&5S`$5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@
M86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N`$5D:70@>6]U<B!W:&ET
M96QI<W0`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`
M16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A
M=&5W87D`16UO=&EC;VYS`$5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N
M`$5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@5FER='5A;"!4<F%S:"!&;VQD
M97(N`$5M<'1Y($9O;&1E<BAS*0!%;7!T>2!396QE8W1E9"!&;VQD97)S`$5M
M<'1Y(%1R87-H(&9O;&1E<@!%;7!T>2!?4W!A;0!%;7!T>2!?5')A<V@`16UP
M='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`
M16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/P!%;F%B;&4@4R]-24U%(&9U;F-T
M:6]N86QI='D_`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO
M=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!M97-S86=E('!R979I97=S
M/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F-R7WEP=&EO
M;B!/<'1I;VYS`$5N8W)Y<'1E9`!%;F0`16YD(&9O<G=A<F1E9"!M97-S86=E
M`$5N9"!M97-S86=E`$5N9"!M97-S86=E(&9R;VT@)7,`16YD('EE87(`16YL
M87)G92!%9&ET;W(`16YT97(@4&%S<W!H<F%S90!%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N
M=&5R('1H92!L971T97)S(&)E;&]W.@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@4W!A;2!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W
M(&1R869T<R!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E
M;G0@;6%I;"!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R
M87-H(&9O;&1E<@!%;G1I<F4@365S<V%G90!%;G1R>2`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:P!%<75A=&]R:6%L
M($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-O;FYE8W1I;F<@=&\@24U!
M4"!S97)V97(N("5S(#H@)7,N`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@
M<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E
M<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S
M(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V96YT('-U8V-E
M<W-F=6QL>2!D96QE=&5D+@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN
M=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,
M;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L
M=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@06QL`$5X<&%N9"!!;&P@1F]L
M9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.86UE<P!%>'!A;F0@4VED96)A
M<@!%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I
M8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_`$5X<&%N9"!T:&4@96YT:7)E(&9O
M;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\`17AP
M86YD:6YG`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O
M=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#
M;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9?971C:"!-86EL`$9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`
M1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B
M)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A
M:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`
M1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD
M<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`
M1F5E;',@;&EK93H@`$9E=&-H($UA:6P`1F5T8V@@36%I;"!I;B!A('-E<&%R
M871E('=I;F1O=S\`1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N/P!&
M971C:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,`1F5T8VAE9"`Q(&UE<W-A9V4@
M9G)O;2`E<P!&971C:&UA:6PZ(`!&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E
M<RX`1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:5]L=&5R<P!&:65L
M9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE
M`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL
M92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A
M9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R($]P=&EO;G,`
M1FEL=&5R(%-E='1I;F=S`$9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R
M;V9A;FET>3\`1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S
M>7-T96TN`$9I;'1E<G,`1FEL=&5R<R!.3U0@06-T:79E`$9I;'1E<G,Z("5S
M(&UA;F%G96UE;G0@<&%G90!&:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S
M="!-86EL8F]X(%!A9V4`1FER<W0@4&%G90!&:7)S="!1=6%R=&5R`$9I>"!R
M871I;P!&;&EP`$9L;V%T`$9O7W)W87)D`$9O9P!&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0`1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I;VX`1F]L9&5R
M($YA=FEG871O<@!&;VQD97(@4W5M;6%R>0!&;VQD97(@<VAA<FEN9R!I<R!N
M;W0@96YA8FQE9"X`1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"X`1F]N="!#
M;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED
M92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUA="!O9B!M97-S
M86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A
M=&5D('1O9&%Y`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S
M`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D
M(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&;W)W87)D<P!&
M<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R964O0G5S
M>2!297%U97-T(%)E<W!O;G-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN
M97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O7VT`1G)O;0!&
M<F]M($%D9')E<W,`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-
M;V]N`$9U;&P@3F%M90!&=V0Z`$9W9#H@`$9W9#H@)74@1F]R=V%R9&5D($UE
M<W-A9V5S`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE
M<GDZ`$=A;6)I80!'96YE<F%L($]P=&EO;G,`1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1V5T(&]N
M;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*0!':&%N80!':6)R86QT87(`
M1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';R!T;R!-97-S86=E`$=O
M('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B`B)7,B`$=O961E;`!';V]G;&4@
M36%P<P!';V]G;&4@4V5A<F-H`$=R86YT(&%C8V5S<P!'<F%Y<V-A;&4`1W)E
M96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U
M<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U
M97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=7EA;F$`2$5210!(5$U,`$A434P@5F5R<VEO;B!O9B!-
M97-S86=E`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA
M<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93H`2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP;W-I;F<Z
M`$AI9&1E;@!(:61D96X@:6X@5&AR96%D(%9I97<`2&ED92!$96QE=&5D`$AI
M9&4@56YS=6)S8W)I8F5D`$AI9V@`2&EG:"!0<FEO<FET>0!(:6=H97-T`$AO
M7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!
M9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N
M9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A
M(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE
M<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.
M;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S
M.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT
M86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I
M9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&1O('EO=2!W
M86YT('1O(&1I<W!L87D@871T86-H;65N=',_`$AO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@=&\@871T<FEB=71E('%U;W1E9"!L:6YE<R!I;B!A
M(')E<&QY`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`
M24U!4`!)34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I`$E-05`@4V5R=F5R
M(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,`
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T
M:6]N(&9A:6QE9#H@)7,`24U!4"!O=F5R(%-33`!)34%0(&]V97(@4U-,("AS
M96QF+7-I9VYE9"!C97)T:69I8V%T92D`24U!4"!O=F5R(%-33"`H<V5L9BUS
M:6=N960I`$E-05`@<V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX`24U!
M4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL(%-E<G9E<G,`24Y"3U@`25`@061D
M<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T
M('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA
M=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)
M8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+@!)9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@
M;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+@!)
M9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I
M('=I;&P@8F4@;&]S="$`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T
M:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@
M<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@
M=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O
M=W-E<BX`26=N;W)E`$EG;F]R92!!;&P`26UA9V4`26UA9V4@4')E=FEE=SH`
M26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E
M(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0`26UP
M;W)T($ME>0!);7!O<G0@2V5Y<&%I<@!);7!O<G0@365S<V%G97,`26UP;W)T
M(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E`$EM<&]R="!0
M97)S;VYA;"!0<FEV871E(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L(%!U8FQI
M8R!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S
M`$EM<&]R="!0=6)L:6,@2V5Y`$EM<&]R="!0=6)L:6,@4$=0($ME>0!);7!O
M<G0@4'5B;&EC(%,O34E-12!+97D`26UP;W)T(%,O34E-12!+97D`26UP;W)T
M(&UB;W@@1FEL90!);7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S
M+@!);7!O<G0L(%-T97`@)60`26UP;W)T86YT`$EM<&]R=&%N="!M97-S86=E
M<P!);7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+@!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W
M($%F=&5R`$EN8F]X`$EN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H
M96%D97(@:6X@82!R97!L>3\`26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN
M(&$@<F5P;'D_`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O
M;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@
M879A:6QA8FQE+@!);F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y`$EN9F]R
M;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y`$EN9F]R;6%T:6]N(&]N
M(%!E<G-O;F%L(%!U8FQI8R!+97D`26YL:6YE`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!#97)T:69I8V%T92!(97)E`$EN<V5R="!);6%G90!);G-E
M<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4`26YS97)T(%!E<G-O
M;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS97)T(%!U8FQI8R!01U`@2V5Y
M($AE<F4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV
M86QI9"!!9&1R97-S`$EN=F%L:60@4F5M;W1E($UA:6QB;W@`26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A
M;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&-H
M87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N`$EN=F%L:60@9&%T82!S
M=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI
M9"!F:6QE(&9O<FUA=`!);G9A;&ED(&ME>0!);G9A;&ED(&QI8V5N<V4@:V5Y
M+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E
M+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV
M86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E
M(&ME>2X`26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`26YV86QI
M9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C
M:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U
M<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`
M26YV97)T`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R
M;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y
M`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*
M=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`
M2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2T(`2V%Z86MH<W1A;@!+965P
M(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@
M1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+97D@
M9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@
M($-O;G1I;G5E('=I=&@@:V5Y(&=E;F5R871I;VX_`$ME>2!I;7!O<G0@:7,@
M;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@
M=&AI<R!S97)V97(N`$ME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U
M(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@8V]N
M=&%C=',N`$ME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%
M54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@
M36%I;&)O>"!086=E`$QA<W0@4&%G90!,87-T(%!A<W-W;W)D($-H86YG90!,
M87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T
M(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,
M87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,
M969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB
M97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG
M:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@
M4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4
M:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`
M3&EN:P!,:6YK($%T=&%C:&UE;G1S/P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9P!,:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BX`3&EN
M:W,`3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,`3&EN=7@@0V]O:VEE`$QI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T
M($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0@86QL(&-O;G1A8W1S('=H
M96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L
M('EO=2!W:6QL(&]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F
M;W(@97AP;&EC:71L>2D`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED
M`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS
M=6)S8W)I8F4`3&ES=&EN9R!I;B!T:&4@2&5A9&5R`$QI<W1I;F<@<V5S<VEO
M;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A
M9&EN9RXN+@!,;V-A;"!-86EL8F]X.@!,;V-A;"!T:6UE.B``3&]C86QE(&%N
M9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@:6X@=&\@)7,`3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS
M`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N
M9R!T97AT`$QO=F4`3&]W`$QO=R!0<FEO<FET>0!,;W=E<B!G<F5E:R!L971T
M97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,
M;W=E<W0`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C
M;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-86-I;G1O<V@@1FEL90!-861A
M9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86EL(%!R979I97=S`$UA
M:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SH`36%I;&)O>`!-86EL8F]X
M(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS`$UA:V4@;&EN7VLN+BX`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA
M<F-H`$UA<F=I;@!-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E
M;@!-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N`$UA<FL@
M87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF
M9F5R96YT(&-O;&]R<S\`36%R:R!M97-S86=E<R!A<R!S965N/R`H24U!4"!O
M;FQY*0!-87)K('-I;7!L92!M87)K=7`_`$UA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT
M+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8V@@
M06QL(%%U97)I97,`36%T8V@@06YY(%%U97)Y`$UA=&-H:6YG(&9I96QD<P!-
M875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!!='1A8VAM96YT
M(%-I>F4`36%X:6UU;2!.=6UB97(@;V8@1F]L9&5R<P!-87AI;75M($YU;6)E
M<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M
M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N`$UA>&EM=6T@=&]T86P@871T
M86-H;65N="!S:7IE(')E86-H960N`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE
M;6)E<G,`365N=2!&;VQD97(@3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS
M`$UE<W-A9V4`365S<V%G92!#;VUP;W-I=&EO;@!-97-S86=E($1A=&4`365S
M<V%G92!/<'1I;VYS`$UE<W-A9V4@4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S
M86=E(%-O=7)C90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@
M=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE
M9"X`365S<V%G92!6:65W:6YG`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!F
M;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G92!F<F]M("5S`$UE<W-A9V4@
M:&%S(&%T=&%C:&UE;G1S`$UE<W-A9V4@:7,@96YC<GEP=&5D`$UE<W-A9V4@
M:7,@<VEG;F5D`$UE<W-A9V4@;6%T8VAE<P!-97-S86=E(')E9&ER96-T960@
M<W5C8V5S<V9U;&QY+@!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@
M;F]T('-A=F5D('1O("5S`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN`$UE
M<W-A9V4@='EP90!-97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V
M:65W+@!-97-S86=E<R!T;P!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE
M=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES
M(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-
M:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A
M+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`
M36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O
M=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F4@=&AA
M;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@(B5S(BX`36]R;V-C;P!-
M;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V90!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO
M8V5N="!M97-S86=E<R!T;R!)3D)/6`!-;W9E('1O(&9O;&1E<@!-;W9E('5P
M`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I
M;6%P(%5+(&UA<`!-=6QT:7!A<G0O86QT97)N871I=F4`375L=&EP;&4@365S
M<V%G92!6:65W`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C
M8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`
M37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3D].10!.3U1%`$YA;64`3F%M
M92!A;F0O;W(@96UA:6P@8V%N;F]T(&)E(&5M<'1Y`$YA;6EB:6$`3F%U<G4`
M3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N
M=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I
M;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A
M;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=F5R('-A=F4@
M871T86-H;65N=',`3F5W`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE
M=R!&;VQD97(`3F5W($UA:6P`3F5W($UE<W-A9V4`3F5W($UE<W-A9V4@=&\@
M)7,`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA
M;F0`3F5W(&UE<W-A9V5S`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE
M=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T
M(%!H87-E<P!.97AT($UE<W-A9V4`3F5X="!086=E`$YE>'0@;W!T:6]N<P!.
M97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO
M($-E<G1I9FEC871E(&9O=6YD`$YO($5N8W)Y<'1I;VX`3F\@2V5Y<R!I;B!+
M97ER:6YG`$YO($UE<W-A9V5S`$YO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D
M+@!.;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT`$YO(%!R979I97<@
M5&5X=`!.;R!0=6)L:6,@2V5Y<R!&;W5N9`!.;R!3+TU)344@<'5B;&EC(&ME
M>2!I;7!O<G1E9"X`3F\@871T86-H;65N=',@9F]U;F0N`$YO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N
M`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I
M;VX@<W5P<&QI960N`$YO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@
M=&AE('!U8FQI8R!K97DN`$YO(&9I;&4@=7!L;V%D960`3F\@9F]L9&5R('-E
M;&5C=&5D+@!.;R!F;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@
M;6%I;"X`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!F;VQD97)S('=I
M=&@@;F5W(&UE<W-A9V5S`$YO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G
M97,`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C
M871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@8F]D>2!T97AT`$YO(&UE<W-A
M9V4@<F5T=7)N960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&UE<W-A9V5S
M(&UA=&-H960@>6]U<B!S96%R8V@N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N
M=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!P97)S;VYA
M;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N`$YO('!E<G-O;F%L(%!'4"!P
M=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!3+TU)344@8V5R=&EF
M:6-A=&5S(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!P<FEV871E(&ME>2!E>&ES
M=',@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`
M3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D
M+@!.;R!S:61E<P!.;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E
M9"X`3F\@<W!E;&QI;F<@97)R;W)S`$YO('-U8V@@9FEL90!.;R!S=6=G97-T
M:6]N<P!.;R!S=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@
M8V]U;&0@8F4@9F]U;F0N`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92X`3F\@=7-E<B!S<&5C:69I960N`$YO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;B!087)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S
M92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA
M;F0`3F]R;6%L`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@1&5L
M971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T
M(&$@9&ER96-T;W)Y`$YO="!A('9A;&ED('!U8FQI8R!K97DN`$YO="!D96QE
M=&5D(&UE<W-A9V5S`$YO="!I;7!L96UE;G1E9"X`3F]T(&EM<&]R=&%N="!M
M97-S86=E<P!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&4@=&AA="!T:&ES
M(&-A;B!T86ME('-O;64@=&EM90!.;W1E<P!.;W1H:6YG`$YO=&AI;F<@=&\@
M8G)O=W-E+"!G;R!B86-K+@!.;W1I9FEC871I;VXZ($QI;FME9"!A='1A8VAM
M96YT(&1O=VYL;V%D960`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R
M86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!M;VYT:',@=&\@
M:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H
M;'DN`$YU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I
M9B!D96QE=&EN9R!M;VYT:&QY+@!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+@!/2P!/4@!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/
M9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU
M<W0@8F4@9&EF9F5R96YT+@!/;&0@;65S<V%G97,`3VQD('!A<W-W;W)D`$]L
M9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VQD('-E;G0M;6%I;"!F;VQD
M97)S(&)E:6YG('!U<F=E9"X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P
M;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&1I<W!L87D@9F]L9&5R<R!W:71H
M('5N<F5A9"!M97-S86=E<R!I;B!T:&5M/P!/;FQY(&]F9F5N<VEV92!F;W)T
M=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE
M(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+@!/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R
M90!/<&5N($9O7VQD97(`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E
M<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)
M344@<&%R="X`3W!E;F5D($9O;&1E<@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N
M97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A
M;G0`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI
M<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C;W5N
M=',`3W1H97(@3W!T:6]N<P!/=71B;W5N9"!397)V97(`3W=N97(@4&5R;6ES
M<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%
M05(Z.DUA:6P@8F%C:V5N9`!01U``4$=0($1I9VET86P@4VEG;F%T=7)E`%!'
M4"!%;F-R>7!T($UE<W-A9V4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!%<G)O
M<CH@`%!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P
M<FEV871E(&ME>2X`4$=0($]P=&EO;G,`4$=0(%!A<W-P:')A<V4@26YP=70`
M4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`4$=0(%!U8FQI8R!+97D`4$=0(%!U8FQI8R!+
M97D@5&5X=`!01U`@4'5B;&EC($ME>2!F;W(@(B5S("@E<RDB('=A<R!S=6-C
M97-S9G5L;'D@861D960N`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,B('=A<R!S
M=6-C97-S9G5L;'D@9&5L971E9"X`4$=0(%!U8FQI8R!+97ER:6YG`%!'4"!3
M:6=N($UE<W-A9V4`4$=0(%-I9VXO16YC<GEP="!-97-S86=E`%!'4"!3:6=N
M960O16YC<GEP=&5D($1A=&$`4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL
M>2!A9&1E9"X`4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!0
M1U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`4$=0('-U
M<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@
M<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4$=0('-U<'!O
M<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@
M=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`4$=0('-U<'!O<G0@<F5Q=6ER97,@
M<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES
M(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@
M;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"!F96%T
M=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`4$A0($-O9&4`4$A0(%-H
M96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`
M4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U`S`%!/4#,@
M*$%U=&\@1&5T96-T(%!R;W1O8V]L<RD`4$]0,R!O=F5R(%-33`!03U`S(&]V
M97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92D`4$]0,R!O=F5R(%-3
M3"`H<V5L9BUS:6=N960I`%!/4#,L(&YO(%1,4P!03U-)6"!E>'1E;G-I;VX@
M:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%G92`E9"!O9B`E9`!0
M86=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E`%!A9V4@=VET:"!T
M:&4@3&%S="!5;G-E96X@365S<V%G90!086MI<W1A;@!086QA=0!086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I
M;F5A`%!A<F%G=6%Y`%!A<G0H<RD`4&%R=&QY($-L;W5D>0!087-S<&AR87-E
M`%!A<W-P:')A<V4@*$%G86EN*0!087-S<&AR87-E('-U8V-E<W-F=6QL>2!U
M;FQO861E9"X`4&%S<W!H<F%S93H`4&%S<W!H<F%S97,@8V%N;F]T(&)E(&5M
M<'1Y`%!A<W-P:')A<V5S(&1O(&YO="!M871C:`!087-S=V]R9`!087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@
M`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B
M;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N
M("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I
M;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O
M<B!T:&ES('5S97(@8V%N;F]T(&)E(&-H86YG960N`%!E<G-O;F%L`%!E<G-O
M;F%L($EN9F]R;6%T:6]N`%!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN`%!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C
M8V5S<V9U;&QY+@!097)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I
M;7!O<G1E9#H@`%!E<G-O;F%L(%,O34E-12!K97ES(&1E;&5T960@<W5C8V5S
M<V9U;&QY+@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I
M=&-A:7)N`%!I>&5L<P!0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P
M;&EE<R!A;F0@9F]R=V%R9',_`%!L86EN=&5X="!697)S:6]N(&]F($UE<W-A
M9V4`4&QA=&ET=61E<P!0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@5&AI<R!R
M97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E9"!S;W5N
M9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A;F0@36%C+"!B
M=70@;W1H97(@<&QA=&9O<FUS('=I;&P@<F5Q=6ER92!A('!L=6=I;BX`4&QE
M87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92X`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@
M9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.@!0;&5A<V4@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9
M;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N
M8V4@<&5R("5S('-E<W-I;VXN`%!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S
M92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@
M;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S
M<VEO;BX`4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG
M('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@8V]O:VEE<R!!
M3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W
M<RP@>6]U('=I;&P@:&%V92!T;R!L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN
M('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R
M;VT@:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O
M<B!A;GD@:6YC;VYV96YI96YC92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D
M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE+@!0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@
M;W(@:6YV86QI9"!A9&1R97-S97,N`%!L96%S92!S96QE8W0@82!F;VQD97(@
M8F5F;W)E('EO=2!P97)F;W)M('1H:7,@86-T:6]N+@!0;&5A<V4@<V5L96-T
M(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+@!0;&5A<V4@<V5L96-T
M(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN`%!L96%S92!S
M96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#H`4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`
M4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*0!0;W=E<F5D(&)Y($AO<F1E`%!R96-E9&4@
M>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\`4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O
M/F-H86YC90!0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"X`4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S
M=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<`4')E=FEO=7,@365S<V%G90!0<F5V:6]U<R!086=E`%!R979I;W5S(&]P
M=&EO;G,`4')I;G0`4')I;G0@9&]C=6UE;G0`4')I;W)I='D`4')I=F%T92!+
M97D`4')I=F%T92!+97D@4&%S<W=O<F0`4')O8FQE;0!0<F]B;&5M($1E<V-R
M:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE
M;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3P!0<F]M<'0@979E<GD@=&EM92!A
M;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453`%!R;VUP="!T
M97AT`%!R;W1O8V]L.@!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM
M`%!U8FQI8R!+97D@26YF;P!0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T
M(&AA<R!B965N(&1I<V%B;&5D+@!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)?9V4@
M1&5L971E9`!0=7)G92!$96QE=&5D`%!U<F=E($9O;&1E<BAS*0!0=7)G92!4
M<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E
M<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N`%!U<F=E(&]L9"!M
M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/P!0=7)G:6YG("5D(&UE<W-A
M9V5S(&9R;VT@5')A<V@@9F]L9&5R+@!0=7)G:6YG(#$@;65S<V%G92!F<F]M
M(%1R87-H(&9O;&1E<BX`46%T87(`475E<GD`475O=&$`475O=&$@<W1A='5S
M.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`%%U;W1A('-T871U<SH@)2XR
M9DU"("\@3D\@3$E-250`475O=&$@<W1A='5S.B!.3R!,24U)5`!1=6]T:6YG
M("5F.@!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`
M4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N
M9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D
M`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M`%)E8G5I;&0@1F]L9&5R(%1R964`4F5C96EV960@3VX`4F5C96EV960@4VEN
M8V4`4F5C96EV960@56YT:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER96-T
M($UE<W-A9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A
M:6QE9"X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!&;VQD97(@5FEE=W,Z
M`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W
M<V5R`%)E;&]A9`!296QO860@5FEE=P!296UA<FMS`%)E;65M8F5R('1H92!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E;65M8F5R('1H92!L87-T('9I97<`
M4F5M;W1E($UA:6QB;W@Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L
M;V-K`%)E;6]V92!&:65L9"!&<F]M(%-E87)C:`!296UO=F4@8V]L=6UN`%)E
M;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I
M<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@
M<V]U<F-E`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D
M;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5N86UE($9O
M;&1E<BAS*0!296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@
M;V8@;6]N=&@_`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;%]Y('1O($QI<W0`4F5P;&%C
M92!W:71H.@!297!L>0!297!L>2!396YT+@!297!L>2!T;R!!;&P`4F5P;'D@
M=&\@06QL.@!297!L>2!T;R!,:7-T`%)E<&QY('1O($QI<W0Z`%)E<&QY('1O
M(%]!;&P`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@
M=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@
M<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DM5&\`4F5P
M;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S($EN;F]C96YT`%)E<&]R="!A<R!3
M<&%M`%)E<75E<W0@82!?4F5A9"!296-E:7!T`%)E<75E<W0@8V]U;&1N)W0@
M8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W0@<F5A
M9"!R96-E:7!T<S\`4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+@!297%U
M97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E
M<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"!&:65L9`!297%U:7)E9"!087)T:6-I<&%N=`!297-E=`!297-E
M="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W!O;F1E;G0@4W1A
M='5S(%5P9&%T960N`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E<W5M
M90!297-U;64@>6]U<B!S97-S:6]N`%)E='5R;B!T;R`B365S<V%G92!#;VUP
M;W-I=&EO;B(`4F5T=7)N('1O($9E=&-H($UA:6P`4F5T=7)N('1O($]P=&EO
M;G,`4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I
M;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%)E='EP92!N97<@
M<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E
M>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`
M4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`
M4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E
M<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W
M86YD80!3+TU)344`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O
M34E-12!%;F-R>7!T($UE<W-A9V4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M`%,O34E-12!%<G)O<CH@`%,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR87-E
M(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4R]-24U%($]P=&EO;G,`4R]-
M24U%(%!A<W-P:')A<V4@26YP=70`4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@
M<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`4R]-
M24U%(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE
M=&5D+@!3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N`%,O
M34E-12!0=6)L:6,@2V5Y<FEN9P!3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y
M<&%I<B!S=6-C97-S9G5L;'D@861D960N`%,O34E-12!3:6=N($UE<W-A9V4`
M4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E`%,O34E-12!S=7!P;W)T(&ES
M(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!3+TU)344@<W5P<&]R="!I<R!N
M;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE
M('1O(&)E(&1E8W)Y<'1E9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L
M960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N
M;F]T(&)E(&1I<W!L87EE9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L
M960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92!V
M97)I9FEE9"X`4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W
M<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2!S
M970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@
M=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%,O34E-12!F96%T=7)E<R!W:6QL
M(&YO="!W;W)K(&-O<G)E8W1L>2X`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%--5%``4U%,(%-H96QL`%-1
M3"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]1
M3"!3:&5L;`!37W5B:F5C=`!380!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S
M`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N
M9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I
M9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@
M071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_
M`%-A=F4@1')A9G0`4V%V92!);6%G90!3879E($EM86=E(&EN($=A;&QE<GD`
M4V%V92!/<'1I;VYS`%-A=F4@4W1A=&EO;F5R>0!3879E(%]$<F%F=`!3879E
M(&%S`%-A=F4@9')A9G1S(&%S('5N<V5E;C\`4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!3879E(')E8VEP:65N=',@875T;VUA=&EC
M86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_`%-A=F4@<V5A<F-H
M(&%S(&$@=FER='5A;"!F;VQD97(_`%-A=F4@<V5N="!M86EL/P!3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@(B5S(BX`4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("5S`%-C871T97)E9"!4+5-T;W)M<P!38VEE
M;F-E`%-E87)C:`!396%R8V@@)7,`4V5A<F-H($5N9VEN97,`4V5A<F-H($]P
M=&EO;G,`4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`4V5L96-T($%N;W1H
M97(@06-C;W5N=`!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@
M82!F:65L9`!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W
M;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!S=&%T:6]N97)Y.@!396QE
M8W0@82!U<V5R('1O(&%D9`!396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@
M9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N`%-E;&5C
M="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;&P@
M9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`%-E
M;&5C="!A;B!A8V-O=6YT`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@9V%L;&5R>2!T;R!S
M879E('1H92!I;6%G92!I;BX`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP90!396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;&5C=&5D($%D9')E<W,@8F]O:W,Z`%-E;F0@2V5Y('1O(%!U8FQI8R!+97ES
M97)V97(`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N9"!-97-S86=E`%-E
M;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N9"!M97-S86=E('=I=&AO
M=70@82!3=6)J96-T/P!396YD(')E860@<F5C96EP="!W:&5N(')E<75E<W1E
M9"!B>2!T:&4@<V5N9&5R/P!396YE9V%L`%-E;G-O<CH@`%-E;G0@;6%I;"!F
M;VQD97(`4V5N="!M86EL(&9O;&1E<CH`4V5P=&5M8F5R`%-E<F)I82!A;F0@
M36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<@!397)V97(@86YD($9O
M;&1E<B!);F9O<FUA=&EO;@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A
M:6QA8FQE+@!397)V97(Z`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I
M<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3
M970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E
M(&%N9"!D96QE=&4@;65S<V%G97,N`%-E="!T:&4@6"U0<FEO<FET>2!H96%D
M97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_`%-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA
M>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@`%-E>6-H96QL97,`4VAA<F4@1F]L9&5R<P!3:&%R92!M86EL(&9O
M;&1E<G,`4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R
M<RX`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@
M8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=6QD(&QA<F=E(&)L;V-K
M<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L
M=#\@270@8V%N(&)E('1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO
M;W-E+@!3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B
M92!S8V%N;F5D(&9O<B!01U`@9&%T83\`4VAO=6QD('1H92!C;VUP;W-E('=I
M;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W5L9"!Y
M;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S
M<V%G97,@8GD@9&5F875L=#\`4VAO=P!3:&]W($%L;"!&;VQD97)S`%-H;W<@
M06QL($AE861E<G,`4VAO=R!$96QE=&5D`%-H;W<@3&EM:71E9"!(96%D97)S
M`%-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N`%-H;W<@3VYL>2!3=6)S
M8W)I8F5D($9O;&1E<G,`4VAO=R!5;G-U8G-C<FEB960`4VAO=R!A;B!I8V]N
M('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A
M9V5S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E;F0@
M:6X@=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG
M:6YA;`!3:&]W('!I8VME<@!3:&]W('!R979I97=S(&9O<B!U;G)E860@;65S
M<V%G97,@;VYL>3\`4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\`4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/P!3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE
M;G5B87(_`%-H;W<@=&AE($EM86=E<P!3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I
M;',@:6X@9F]L9&5R/P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R
M;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H;W=N
M`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0`4VE?>F4`4VEE<G)A($QE;VYE`%-I9VX@
M=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEG;F5D`%-I;F=A
M<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`
M4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A
M<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG
M<R`F(%!O96US`%-O<G0@8GD@07)R:79A;`!3;W)T(&)Y($1A=&4`4V]R="!B
M>2!&<F]M($%D9')E<W,`4V]R="!B>2!-97-S86=E(%-I>F4`4V]R="!B>2!3
M=6)J96-T`%-O<G0@8GD@5&AR96%D`%-O<G0@8GD@5&\@061D<F5S<P!3;W)T
M(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD
M('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE
M<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N
M(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P
M86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&%M(&9O;&1E<CH`4W!E
M8VEA;"!#:&%R86-T97(@26YP=70`4W!E8VEA;"!#:&%R86-T97)S`%-P96-I
M86P@5FER='5A;"!&;VQD97)S(&-A;FYO="!B92!E9&ET960N`%-P96QL($-H
M96-K`%-P96QL($-H96-K97(`4W!E;&P@8VAE8VL@8V]M<&QE=&4`4W!E;&QI
M;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RX`4W!L
M:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N
M:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T`%-T87)T('EE87(`4W1A=&4@
M;W(@4')O=FEN8V4`4W1A=&EO;F5R>0!3=&%T:6]N97)Y(&YA;64Z`%-T871I
M;VYE<GD@='EP93H`4W1A=&EO;F5R>3H`4W1A='5S`%-T;W)A9V4@9F]R;6%T
M`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R
M:7`@071T86-H;65N=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3
M=')I<"!L:6YE8G)E86MS/P!3='EL92!;0U-370!3=0!3=6)?:F5C=`!3=6)D
M:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B:F5C="!&:65L
M9`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T
M(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U
M8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E
M<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M
M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D
M('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O
M;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S
M(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5G9V5S=&EO;G,`4W5M
M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3
M=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3
M=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE
M;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0`
M4W=I=&-H('1O($A434P@8V]M<&]S:71I;VX`4W=I=&-H('1O('!L86EN('1E
M>'0@8V]M<&]S:71I;VX`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3
M>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A
M8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS
M`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I
M97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5?>'0`5&5L97!H;VYE($YU
M;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A
M='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T
M<F%T:6]N`%1E;G1A=&EV93H@`%1E;G1A=&EV96QY($%C8V5P="!R97%U97-T
M`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E<FUS(&]F(%-E<G9I8V4@9FEL92!N
M;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP`%1E>'0`5&5X="!/;FQY`%1E>'0@
M86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@
M1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@1G)O;3H@8V]L
M=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z`%1H92!(:7-T
M;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G
M<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-05`@
M<V5R=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT
M:6-A=&EO;B!M971H;V0@<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N`%1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:P!4
M:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@
M)7,N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N`%1H92!A8V-O=6YT("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&%C
M8V]U;G0@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@871T
M86-H;65N="!W87,@;F]T(&9O=6YD+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4
M:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED`%1H92!C;VUP;W-E('=I;F1O
M=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@
M8G)O=W-E<B!T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/P!4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!C
M;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+@!4:&4@
M8W5R<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M960@=&\@(B5S
M(BX`5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T
M:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D`%1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+@!4:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@
M=&AE("(E<R(@9F]L9&5R+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@979E;G0@=V%S(&%D
M9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F:65L9"`B)7,B(&-A;B=T(&)E
M(&5X<&%N9&5D+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N
M`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L9&5R("(E<R(@
M86QR96%D>2!E>&ES=',`5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL;&5G
M86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E('!R;V)L
M96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H
M92!F;VQD97(@(B5S(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U
M8G-C<FEB960@=&\@:70N`%1H92!F;VQD97(@(B5S(B!W87,@9&5L971E9"!B
M=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@9F]L
M9&5R("(E<R(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&1E;&5T960N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A
M<R!S=6-C97-S9G5L;'D@8W)E871E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S
M=6-C97-S9G5L;'D@9&5L971E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@<F5N86UE9"!T;R`B)7,B+@!4:&4@9F]L;&]W:6YG(&%R92!T
M:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4
M:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@=&AI<R!P87)T
M.@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B
M;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B
M=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@
M;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I
M=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@
M($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L
M>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT
M)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T
M:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!4:&4@:6UA9V4@<V%V92!W:6YD;W<@8V%N(&YO="!B
M92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T
M;R!B;&]C:R!P;W!U<"!W:6YD;W=S/P!4:&4@:6UA9V5S('=I;&P@8F4@9&ES
M<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@
M861D<F5S<V)O;VLN`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D
M('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93H`5&AE(&UA:6P@<V5R=F5R
M(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S<V%G
M93H`5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE
M<W-A9V4Z`%1H92!M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN`%1H92!M
M97-S86=E("(E<R(@9G)O;2`B)7,B("@E9"!B>71E<RD@97AC965D<R!F971C
M:"!S:7IE(&QI;6ET+@!4:&4@;65S<V%G92!B96EN9R!C;VUP;W-E9"!H87,@
M8F5E;B!C;&]S960N($5X:71I;F<N`%1H92!M97-S86=E(&1O97,@;F]T(&AA
M=F4@82!3=6)J96-T(&5N=&5R960N`%1H92!M97-S86=E(&AA<R!B965N(&1E
M;&5T960N`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+@!4:&4@;65S
M<V%G92!H87,@8F5E;B!V97)I9FEE9"X@4V5N9&5R.B`E<RX`5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E
M;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+@!4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D
M+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@
M<&]P=7`@=VEN9&]W<S\`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE(')A=R!T97AT(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@
M8F4@=FEE=V5D("5S+@!4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI
M<W0@:6X@=&AE($U3+51.148@871T86-H;65N="X`5&AE(')E<75E<W1E9"!F
M:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H;65N="X`5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY`%1H92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I
M;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B!F<F]M('EO
M=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI
M8VL@)7,@=&\@<V5N9"!T:&4@;F]T:69I8V%T:6]N(&UE<W-A9V4N`%1H92!S
M97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!S879E9"X`5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E
M871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N`%1H92!S:6=N871U<F4@
M8V]U;&0@;F]T(&)E(')E<&QA8V5D+@!4:&4@<VEG;F%T=7)E('=A<R!S=6-C
M97-S9G5L;'D@<F5P;&%C960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T
M(&5X:7-T+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T
M+@!4:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B965N(&%D9&5D+@!4:&4@<W1A
M=&EO;F5R>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S=&%T:6]N97)Y
M("(E<R(@:&%S(&)E96X@=7!D871E9"X`5&AE('1A<VL@:&%S(&)E96X@861D
M960@=&\@>6]U<B!T87-K;&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@
M9&]E<R!N;W0@97AI<W0N`%1H92!T97AT(&]F('1H92!M97-S86=E`%1H92!T
M97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT
M(&]F('1H92!R971U<FYE9"!M97-S86=E`%1H92!T97AT(&]F('1H92!R971U
M<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT(&]F('1H
M92!S96YT(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92!C
M86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T
M(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O
M='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!U<V5R)W,@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N
M`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M
M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@86QT
M97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`
M5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M`%1H97)E(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92X`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES
M=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B
M;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@
M<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA
M>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P
M87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG
M(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S
M86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G
M97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A
M;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O;2`B)7,B('1O("(E<R(N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N`%1H97)E('=A<R!A
M;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S+@!4
M:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES($A4
M34P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+@!4:&ES($A4
M34P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D
M(&EM86=E<R!A<'!E87(@;&EK92!T:&ES.B``5&AI<R!)34%0('-E<G9E<B!D
M;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!01U`@4'5B
M;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N`%1H:7,@86-T
M:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@
M:6UP;&5M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A
M;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R
M,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`
M5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E
M('9I<VET("5S`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G92!C;VYT86EN
M<R!A($UA8VEN=&]S:"!F:6QE+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@
M871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA
M(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@
M=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S
M86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N
M+"!B=70@=&AE(&9O<FUA="!O9B!T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BX`
M5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'
M4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z(`!4:&ES(&UE<W-A9V4@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@
M*&%C8V]R9&EN9R!T;R!21D,@,C`Q-2DN`%1H:7,@;65S<V%G92!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="X`
M5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'
M4"X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA
M(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@
M4R]-24U%+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@
M4$=0+@!4:&ES(&UE<W-A9V4@=&\`5&AI<R!M97-S86=E('=A<R!W<FET=&5N
M(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&$@8V]M<&]S92!W:6YD;W<N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AR96%D($1I<W!L87D`5&AR
M96%D(%9I97<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4
M:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4
M:71L92`H=&]O;'1I<"DZ`%1O`%1O($%D9')E<W,`5&\@<V5L96-T(&UU;'1I
M<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!W:&EL92!C;&EC:VEN9RX`5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&\@=7-E(&$@5$Q3(&-O;FYE
M8W1I;VXL('EO=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U
M+C`N-B!O<B!H:6=H97(N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`
M5&]T86P@071T86-H;65N=',@4VEZ93H`5')A;G-L871I;VYS`%1R87-H(&9O
M;&1E<@!4<F%S:"!F;VQD97(Z`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O
M<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY
M*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L
M=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N
M9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L
M9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E
M860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L
M9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$`56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W
M:6QL(&)E(&5X8V5E9&5D+@!5;F%N<W=E<F5D`%5N86YS=V5R960@;65S<V%G
M97,`56YD96QE=&4`56YD97)L:6YE`%5N9&ES8VQO<V5D(%)E8VEP:65N=',`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!$871E`%5N:VYO=VX@24U!4"!R97-P;VYS92!F
M<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S`%5N:VYO=VX@
M365E=&EN9P!5;FMN;W=N(%)E8VEP:65N=`!5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U
M<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0`56YL;V%D(%!A<W-P:')A<V4`56YN86UE9`!5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N`%5N<V5E;@!5;G-E="!C;VQO<@!5;G-U8G-C<FEB92!F<F]M($9O;&1E
M<BAS*0!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5
M<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E9"`B
M)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y
M`%5S92!#=7)R96YT.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@24U!4"!F
M;VQD97(@<W5B<V-R:7!T:6]N<S\`57-E(%-33`!5<V4@5FER='5A;"!4<F%S
M:"!&;VQD97(_`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N`%5S97(`57-E<B`B)7,B('-U8V-E<W-F=6QL>2!G
M:79E;B!T:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B
M+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI
M;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B
M)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R
M<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E
M<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE
M>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@
M:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT
M<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ
M`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<`
M5FEE=R`E<P!6:65W("5S(%!U8FQI8R!+97D`5FEE=R!(5$U,(&-O;G1E;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!-97-S86=E<P!6:65W(%!E<G-O
M;F%L(%!R:79A=&4@2V5Y`%9I97<@4&5R<V]N86P@4'5B;&EC($ME>0!6:65W
M(%1H<F5A9`!6:65W(%1H=6UB;F%I;`!6:65W(&%N(&5X=&5R;F%L('=E8B!P
M86=E`%9I97<@87,@)7,`5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@
M=VEN9&]W`%9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W
M(&5V96YT`%9I97<@;65S<V%G97,@:6X@)7,`5FEE=R!O<B!M86EL8F]X('1O
M(&1I<W!L87D@869T97(@;&]G:6XZ`%9I97<@=&%S:P!6:65W('1H92!);6%G
M97,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N
M4RX`5FER='5A;"!&;VQD97(@(B5S(B!C<F5A=&5D('-U8V-E<V9U;&QY+@!6
M:7)T=6%L($9O;&1E<G,`5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E
M;"X`5FER='5A;"!)3D)/6`!6:7)T=6%L($E.0D]8($9O;&1E<@!6:7)T=6%L
M(%1R87-H`%9I<G1U86P@5')A<V@@1F]L9&5R`%9I<G1U86P@9F]L9&5R(&QA
M8F5L`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I
M82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9
M($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N
M:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D
M(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I
M`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_`%=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S
M86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M(&]R
M(&EN;F]C96YT/P!7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@
M=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@
M87,@9&5L971E9#\`5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H
M('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E
M;G0M;6%I;"P@<VAO=6QD('=E('-A=F4@871T86-H;65N="!D871A/P!7:&5N
M('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O
M;6%I;B!S:&]U;&0@=V4@87!P96YD('1O('5N<75A;&EF:65D(&%D9')E<W-E
M<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@(D`B*3\`5VAE<F5I<R!!=7-T
M<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:61T:`!7
M:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE
M(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F
M('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%
M87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`
M5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O
M=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F
M:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.
M86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E
M;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE
M<RP@22!!9W)E90!9;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@
M=&AE(&9O;&QO=VEN9R!A8V-O=6YT*',I.@!9;W4@87)E(&%T=&5M<'1I;F<@
M=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO
M=VEN9R!F;VQD97(H<RDN`%EO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@
M=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN`%EO=2!A<F4@8V]P>6EN9R]M;W9I
M;F<@=&\@82!N97<@9F]L9&5R+@!9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O
M;&1E<B!T;R``66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N
M`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T
M;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!F;VQD97)S+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L9&5R<RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B``
M66]U(&-A;B!U<V4@=&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE
M('-T871I;VYE<GD@=&5X=#H@)6,@9F]R('1H92!C=7)R96YT(&UE<W-A9V4@
M8V]N=&5N=#L@)7,@9F]R('1H92!S:6=N871U<F4N`%EO=2!C86YN;W0@:&%V
M92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A
M;FYO="!U;G-U8G-C<FEB92!F<F]M("(E<R(N`%EO=2!D:60@;F]T(&%G<F5E
M('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E
M<F4@;F]T(&%L;&]W960@=&\@;&]G:6XN`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<@!9;W4@9F]R=V%R9&5D('1H
M:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S
M.B`E<RX`66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+@!9;W4@:&%V92`Q(&YE
M=R!M97-S86=E+@!9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A
M9V4N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@;F5W(&UA
M:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL
M(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SH`66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N
M(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P
M<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE
M(')E8VEP:65N="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E
M(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G
M90!9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)
M344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4`66]U(&UU<W0@
M<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T('-E;&5C
M="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A
M;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S
M<V%G92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+@!9;W4@;F5E9"!T;R!H879E("(E<R(@96YA8FQE9"!I;B!Y;W5R
M(&UA:6YT96YA;F-E(&]P=&EO;G,N`%EO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(`66]U(')E9&ER96-T960@=&AI<R!M97-S
M86=E('1O("5S(&]N("4E<RX`66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E
M(&]N("5S+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(97)E
M(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U8G-C
M<FEB960@9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%EO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`66]U
M('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<P!9;W5R(%!R
M:79A=&4@2V5Y`%EO=7(@4'5B;&EC($ME>0!9;W5R(%)E<&QY+71O.B!A9&1R
M97-S.B`\96T^*&]P=&EO;F%L*3PO96T^`%EO=7(@4R]-24U%(%!U8FQI8R]0
M<FEV871E($-E<G1I9FEC871E<P!9;W5R(&%C8V]U;G1S.@!9;W5R(&%L:6%S
M(&%D9')E<W-E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S
M(&]N(&$@;F5W(&QI;F4I/"]E;3X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES
M:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N
M9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92X`66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT
M('1I;64@>F]N93H`66]U<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@
M;65S<V%G97,Z`%EO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@
M<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B
M965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL
M(&YA;64Z`%EO=7(@;&EN:V5D(&%T=&%C:&UE;G0@:&%S(&)E96X@9&]W;FQO
M861E9"!B>2!A="!L96%S="!O;F4@=7-E<BX*"D%T=&%C:&UE;G0@;F%M93H@
M)7,*071T86-H;65N="!D871E.B`E<PH*0VQI8VL@;VX@=&AE(&9O;&QO=VEN
M9R!L:6YK('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&4@871T86-H;65N=#H*
M)7,`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!M97-S86=E('=A<R!S
M=6-C97-S9G5L;'D@9&5L:79E<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9;W5R
M('-I9VYA='5R93H`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`
M6FEP<'D`6TAI9&4@061D<F5S<V5S70!;2&ED92!1=6]T960@5&5X=%T`6TYO
M(%-U8FIE8W1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@061D<F5S<V5S("T`
M6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI
M;F5S70!;4VAO=R!A9&1R97-S97,@+2`E<R!R96-I<&EE;G1S70!;;&EN92`E
M<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"8V,`7T)L86-K;&ES=`!?0TQ)
M`%]#8P!?1&%T851R964`7T1E;&5T90!?1&5L971E(%)O=P!?1F]L9&5R<P!?
M1W)O=7!S`%](96QP`%])9&5N=&ET>0!?26UA9V4@4')O<&5R=&EE<RXN+@!?
M26YB;W@`7TQO9R!I;@!?3&]G(&]U=`!?365S<V%G92!3;W5R8V4`7TUO9&EF
M>2!,:6YK+BXN`%].97<@365S<V%G90!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`
M7U!R:6YT`%]0<FEO<FET>0!?4F5F<F5S:"`E<P!?4F5M;W9E($QI;FLN+BX`
M7U)E<&QY`%]396%R8V@`7U-E;F0@365S<V%G90!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U1H<F5A9`!?5&\`7U5N9&5L971E`%]5<V5R<P!?5FEE
M=R!4:')E860`7U=H:71E;&ES=`!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N
M:VYO=VX`871T86-H;65N=`!A='1A8VAM96YT<RYZ:7``8GET97,`8V%L96YD
M87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N
M(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O
M;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL
M:6YG`&9I;&4`9G)O;0!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I
M;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I
M;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`:V5Y
M`&QI;F5S70!M86EL8F]X(&9I;&4`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]N90!N;W0@:6UP;&5M96YT960`
M;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`&]R`'!E<F-E;G0`<&5R;6ES
M<VEO;B!D96YI960`<&EX96QS`')E8VEP:65N='-=`')E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I
M9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<&5L;&EN9R!E<G)O<@!S
M<&5L;&EN9R!E<G)O<G,`<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI
M<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@
M=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`
M=SH`=V5A=&AE<BYC;VT`>6]U<B!B;&%C:VQI<W0`>6]U<B!W:&ET96QI<W0`
M4')O:F5C="U)9"U697)S:6]N.B!);7`*4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$U
M(#$S.C`Q+3`R,#`*3&%S="U4<F%N<VQA=&]R.B!&86)I;R!';VUE<R`\9FQG
M;VUS0'5O;"YC;VTN8G(^"DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T
M=6=U97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E;F5R871O
M<CH@2T)A8F5L(#$N,RXQ"E!L=7)A;"U&;W)M<SH@(&YP;'5R86QS/3([('!L
M=7)A;#TH;B`^(#$I.PH`("`@("`@0V,Z(``@("`@("!087)A.B``("`@($1A
M=&$Z(``@("`@1&4Z(``@*"5S(&1I87,@871RX7,I`"`H5&5C;&$@9&4@071A
M;&AO("5S*0`@*&5M("5S(&1I87,I`"`H:&]J92D`("AA;6%N:.,I`"`H;VYT
M96TI`"!!<W-U;G1O.B``(&$@`"!E;2``(B5S(B!.XV\@Z2!U;2!D:7)E=/-R
M:6\N`"<E<R<@;N-O(.D@=6UA(&5S8V]L:&$@=N%L:61A+@`G)7,G(&[C;R!E
M<W3A(&-O;F9I9W5R861O(&YO(%)E9VES=')O(&1O($AO<F1E+@!R96YD97)I
M>F%D;W(@9&4@X7)V;W)E("(E<R(@;N-O(&5N8V]N=')A9&\N`"(E<R(@9F]I
M(&%D:6-I;VYA9&\@86\@<VES=&5M82!D92!G<G5P;W,N`"(E<R(@9F]I(&%D
M:6-I;VYA9&\@86\@<VES=&5M82!D92!P97)M:7-S]65S+@`B)R5S(B!NXV\@
M9F]I(&-R:6%D;SH@)7,N`",`)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0`E
M+C)F34(@=7-A9&]S(&1E)2XR9DU"('!E<FUI=&ED;W,@*"4N,F8E)2D`)60@
M)7,@92`E<P`E9"!-96YS86=E;G,`)60@9&EA<R!A=.D@<W5A('-E;FAA(&5X
M<&ER87(N`"5D(&UE;G-A9V5M*&YS*2!F;VDH<F%M*2!E>&-L=>UD82AS*2X`
M)60@;65N<V%G96YS(&9O<F%M(')E<&]R=&%D87,@8V]M;R!NXV\@<W!A;2!A
M;R!S974@861M:6YI<W1R861O<B!D92!S:7-T96UA+@`E9"!M96YS86=E;G,@
M9F]R86T@<F5P;W)T861A<R!C;VUO(&[C;R!S<&%M+@`E9"!M96YS86=E;G,@
M9F]R86T@<F5P;W)T861A<R!C;VUO('-P86T@86\@<V5U(&%D;6EN:7-T<F%D
M;W(@9&4@<VES=&5M82X`)60@;65N<V%G96YS(&9O<F%M(')E<&]R=&%D87,@
M8V]M;R!S<&%M+@`E9"#@("5D(&1E("5D($UE;G-A9V5N<P`E9"!P<F5V:7/C
M;R!D;R!D:6$`)7,@+2!!=FES;P!);7!R97-SXV\@1&EG:71A;"!D92`E<P`E
M<R!+0@`E<R!/<&5R8>?U97,@9&4@36%N=71E;N?C;R`M($-O;F9I<FUAY^-O
M`$-O;F9I9W5R8>?C;R!D92`E<P!#861A<W1R;R!D92`E<P`E<R!497)M;W,@
M9&\@06-O<F1O`"5S(&KA(&5X:7-T92X`)7,@:N$@97AI<W1E+B!3=6$@<&%S
M=&$@)7,@;N-O(&9O:2!R96YO;65A9&$N`"5S(&$@)7,@)7,`)7,@;N-O('!A
M<F5C92!S97(@=6UA('!A<W1A(';A;&ED82X`02!P87-T82`E<R!E<W3A('-E
M;F1O(')E;F]M96%D82!N;R!I;NUC:6\@9&\@;>IS+@`E<R!F;VD@86-E:71O
M+@`E<R!C86YC96QO=2`B)7,B+@`E<R!R96-U<V]U+@`E<R!R97-P;VYD974@
M82!U;6$@<F5Q=6ES:>?C;R!D92!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\N
M`"5S(')E<W!O;F1E=2!A;R!C;VYV:71E('!A<F$@(B5S(BX`)7,@96YV:6]U
M(&$@=F]CZB!U;6$@:6YF;W)M8>?C;R!L:79R92]O8W5P861O+@`E<R!A8V5I
M=&]U('!R;W9I<V]R:6%M96YT92X`)7,@97-TX2!P<F]N=&\@<&%R82!E>&5C
M=71A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!M87)C861A<R!A8F%I
M>&\N($UA<G%U92!A(&-A:7AA('!A<F$@<75A;'%U97(@;W!E<F'GXV\@<75E
M('9O8^H@<75E:7)A(&5X96-U=&%R(&1E<W1A('9E>BX`)7,@Z2!O8G)I9V%T
M\W)I;P`E<R!M:6YU=&]S`"5S(&[C;R!E;F-O;G1R861O+@`E<R!R97%U:7-I
M=&]U('-U82!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\N`"5S('-O;&EC:71O
M=2!S=6$@<')E<V5NYV$@96T@(B5S(BX`)7,@82`E<R!D92`E<P`E<R!F;VD@
M861I8VEO;F%D;R!C;VT@<W5C97-S;R!E;2`E<RX`)7,@9&5S96IA(&-O<G)I
M9VER("(E<R(N`"5S(&1E<V5J82!I;F9O<FUA<B!V;V/J('-O8G)E("(E<R(N
M`"5S(&1E<V5J82!R96-E8F5R(&$@^FQT:6UA(&EN9F]R;6'GXV\@<V]B<F4@
M(B5S(BX`0V%TX6QO9V\@9&4@16YD97)EYV]S(&1E("5S`$%G96YD82!D92`E
M<P!!;F]T8>?U97,@9&4@)7,`3&ES=&$@9&4@5&%R969A<R!D92`E<P`E<SH@
M)7,`)7,Z("5S("@E9"9N8G-P.V1E)FYB<W`[)60I`"5S.B!%<W1A(&UE;G-A
M9V5M('!O9&4@;N-O('-E<B!D92!Q=65M(&5L82!D:7H@<V5R+B!4;VUE(&-U
M:61A9&\@8V]M('%U86QQ=65R(&QI;FL@<')E<V5N=&4@;F5L82!O=2!E;2!F
M;W)N96-E<B!A;R!R96UE=&5N=&4@<75A;'%U97(@:6YF;W)M8>?C;R!P97-S
M;V%L+@`H07!L:6-A<B!E<W1A<R!A;'1E<F'G]65S(&4@:7(@<&%R82!A('!R
M\WAI;6$@=&5L82XI`"A$97-C87)T87(@=&]D87,@86QT97)AY_5E<R!E(')E
M=&]R;F%R(.`@=&5L82!D92!C;VUP;W-IY^-O+BD`*$A434PI`"A497AT;R!0
M=7)O*0`H4F5T;W)N87(@X"!T96QA(&1E(&-O;7!O<VGGXV\@87#S<R!A<&QI
M8V%R('1O9&%S(&%L=&5R8>?U97,@<F5A;&EZ861A<R!A=.D@86=O<F$N("!!
M;'1E<F'G]65S(&YA('1E;&$@871U86P@3L-/('-E<N-O(&%P;&EC861A<RXI
M`"A%;G9I92!A(&UE;G-A9V5M(&%P\W,@87!L:6-A<B!T;V1A<R!A<R!A;'1E
M<F'G]65S(')E86QI>F%D87,@873I(&%G;W)A+B`@06QT97)AY_5E<R!N82!T
M96QA(&%T=6%L($[#3R!S97+C;R!A<&QI8V%D87,N*0`J($%D:6-I;VYE(&5S
M=&5S(&-L:6-A;F1O(&5M($]+("H`*B!0;W(@9F%V;W(@<V5L96-I;VYE(&\H
M<RD@96YD97)EYV\H<RD@*@`L(&)R:7-A(``L(&)R:7-A("5S("5S`"P@=F%R
M:>%V96P@9&4@)7,@<&%R82`E<P`M+2!S96QE8VEO;F4@+2T`,2!M96YS86=E
M;2!F;VD@97AC;'7M9&$N`#$@;65N<V%G96T@9F]I(')E<&]R=&%D82!C;VUO
M(&[C;R!S<&%M(&%O('-E=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6$N`#$@
M;65N<V%G96T@9F]I(')E<&]R=&%D82!C;VUO(&[C;R!S<&%M+@`Q(&UE;G-A
M9V5M(&9O:2!R97!O<G1A9&$@8V]M;R!S<&%M(&%O('-E=2!A9&UI;FES=')A
M9&]R(&1E('-I<W1E;6$N`#$@;65N<V%G96T@9F]I(')E<&]R=&%D82!C;VUO
M('-P86TN`#$P,"!C87)A8W1E<F5S`#$P,#`@8V%R86-T97)E<P!&;W)M871O
M(#$R($AO<F%S`$9O<FUA=&\@,C0@2&]R87,`,C0@:&]R87,`,C4P(&-A<F%C
M=&5R97,`-3`P(&-A<F%C=&5R97,`/%#A9VEN82!!;G1E<FEO<@!5;2!C;VYE
M8W1O<B!D92!B86YC;R!D92!D861O<R#I(&]B<FEG873S<FEO('!A<F$@97-T
M92!B;&]C;RX`56T@97)R;R!F871A;"!O8V]R<F5U`%5M(&EM86=E;2!G<F%N
M9&4@9&4@;F]M92`E<R!E<W3A(&%N97AA9&$@82!E<W1A(&UE;G-A9V5M+@!5
M;6$@;65N<V%G96T@<75E('9O8^H@96YV:6]U(')E<W5L=&]U(&5M('5M82!N
M;W1I9FEC8>?C;R!D92!R971O<FYO(&1O(&1E<W1I;F%TX7)I;RX`56UA(&-H
M879E('#Z8FQI8V$@4$=0(.D@;V)R:6=A=/-R:6$@<&%R82!C<FEP=&]G<F%F
M87(@=6UA(&UE;G-A9V5M+@!5;6$@8VAA=F4@</IB;&EC82!01U`@Z2!O8G)I
M9V%T\W)I82!P87)A('9E<FEF:6-A<B!U;6$@;65N<V%G96T@87-S:6YA9&$N
M`%5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!S96YH82!SXV\@;V)R:6=A
M=/-R:6%S('!A<F$@9&5S8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`56UA
M(&-H879E('!R:79A9&$@4$=0(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I
M87,@<&%R82!A<W-I;F%R('5M82!M96YS86=E;2X`56UA(&-H879E('#Z8FQI
M8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@<V5N
M:&$@<^-O(&]B<FEG873S<FEA<R!P87)A(&1E<V-R:7!T;V=R869A<B!U;6$@
M;65N<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E
M('!R:79A9&$@4R]-24U%(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I87,@
M<&%R82!A<W-I;F%R('5M82!M96YS86=E;2X`56UA(&-H879E('#Z8FQI8V$@
M4R]-24U%(.D@;V)R:6=A=/-R:6$@<&%R82!C<FEP=&]G<F%F87(@=6UA(&UE
M;G-A9V5M+@!.=79E;G,@;6%T=71I;F%S`$-H=79A($9R86-A(%9E<W!E<G1I
M;F$`0VAU=F$@;6%T=71I;F$`0VAU=F%S(&UA='5T:6YA<P!.979A<V-A<R!-
M871U=&EN87,`04TO4$T`10!!4$D@240`4V]B<F4@97-T92!E9&ET;W(`4V]B
M<F4N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V5I=&%R(&4@861I8VEO;F%R
M(&$@;6EN:&$@86=E;F1A`$%C96ET87(@<V]L:6-I=&'GXV\`06-E:71A`$%C
M96ET83H@`$%C97-S;R!N96=A9&\@86\@8W)I87(@9&ER973S<FEO(%9&4RX`
M06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O(%9&4RX`4W5A<R!);F9O
M<FUAY_5E<P!396YH82!D82!#;VYT80!#;VYT82!D97-A=&EV861A+@!.;VUE
M(&1A(&-O;G1A.@!#;VYT87,`0>?U97,`061I8VEO;F%R`$%D:6-I;VYA<B`E
M<R!A;R!#873A;&]G;R!D92!%;F1E<F7G;W,`061I8VEO;F%R($=R=7!O(%-U
M8F]R9&EN861O`$%D:6-I;VYA<B!097)M:7-S]65S(%-U8F]R9&EN861A<P!!
M9&EC:6]N92!!<75I.@!!9&EC:6]N87(@3F]V;R!'<G5P;P!!9&EC:6]N87(@
M3F]V82!097)M:7-SXV\`061I8VEO;F%R('5M(&=R=7!O('-U8F]R9&EN861O
M(&$@)R5S)P!!9&EC:6]N87(@=6UA('!E<FUI<W/C;R!S=6)O<F1I;F%D82!A
M("<E<R<`061I8VEO;F%R('5M(&YO=F\@=7-UX7)I;SH`061I8VEO;F%R(&-O
M;'5N80!!9&EC:6]N87(@;F]V;W,@;65M8G)O<P!!9&EC:6]N87(@<&%R`$%D
M:6-I;VYA<B!F;VYT90!!9&EC:6]N87(@;R!-96YU("5S(&-O;6\@=6UA($)A
M<G)A($QA=&5R86P@9&\@36]Z:6QL80!!9&EC:6]N87(@:7-T;R!A(&UI;FAA
M(&%G96YD80!!9&EC:6]N87(@86\@8V%TX6QO9V\@9&4@96YD97)EYV]S.@!!
M9&EC:6]N87(@86\@;65U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!!9&EC:6]N
M87(@82!M:6YH82!A9V5N9&$`061I8VEO;F%R('5S=>%R:6\`(B5S(B!A9&EC
M:6]N861O(&-O;6\@=6T@86YE>&\N`"<E<R<@861I8VEO;F%D;R!A;R!S:7-T
M96UA+"!M87,@;N-O('!U9&4@:6YC;'5I<B!I;F9O<FUAY_5E<R!A9&EC:6]N
M86ES(&1O(&-A9&%S=')O.B`E<RX`)7,@861I8VEO;F%D;R!A;R!S:7-T96UA
M+B!6;V/J('!O9&4@<V4@8V]N96-T87(@86=O<F$N`$%D:>?C;R!D92!U<W7A
M<FEO<R!E<W3A(&1E<V%B:6QI=&%D82X`0V%B9>=A;&AO<R!A9&EC:6]N86ES
M('!A<F$@;6]S=')A<B!A;R!V:7-U86QI>F%R.B`\96T^*&]P8VEO;F%L+"!D
M:6=I=&4@8V%D82!C86)EYV%L:&\@96T@=6UA(&YO=F$@;&EN:&$I/"]E;3X`
M26YF;W)M8>?U97,@861I8VEO;F%I<R!P;V1E;2!S97(@=FES=6%L:7IA9&%S
M("5S+@!$971A;&AE<R!A9&EC:6]N86ES(&1A(&EN9F]R;6'GXV\`1&5T86QH
M97,@861I8VEO;F%I<R!D82!M96YS86=E;0!$971A;&AE<R!A9&EC:6]N86ES
M(&1A(&UE;G-A9V5M('!O9&5M('-E<B!V:7-U86QI>F%D;W,@)7,N`$1E=&%L
M:&5S(&%D:6-I;VYA:7,@9&4@97)R;R!D82!M96YS86=E;0!$971A;&AE<R!A
M9&EC:6]N86ES(&1E(&5R<F\@9&$@;65N<V%G96T@<&]D96T@<V5R('9I<W5A
M;&EZ861O<R`E<RX`16YD97)EYV\`0V%TX6QO9V\@9&4@16YD97)EYV]S`$-A
M=.%L;V=O<R!D92!%;F1E<F7G;W,`16YD97)EYV]S(&5M($-C;R!E;2!T;V1A
M<R!A<R!M96YS86=E;G,Z(#QI/BAO<&-I;VYA;"P@<')E96YC:&$@8V%D82!E
M;F1E<F7G;R!E;2!U;6$@;F]V82!L:6YH82D\+VD^`$5N9&5R9>=O<R!E>'!L
M:6-I=&%M96YT92!L:6=A9&]S(&$@97-T82!I9&5N=&ED861E.B`\:3XH;W!C
M:6]N86PL('!R965N8VAA(&-A9&$@96YD97)EYV\@96T@=6UA(&YO=F$@;&EN
M:&$I/"]I/@!!9&UI;FES=')A<B`M(&-O;F9I9W5R82!P97)M:7-S]65S('!A
M<F$@;W5T<F]S('5S=>%R:6]S`$%D;6EN:7-T<F'GXV\`06[Z;F-I;W,`069E
M9V%N:7-TXV\`06QBXFYI80!!<F?I<FEA`$%P96QI9&\`06QI;FAA<@!!;&EN
M:&%M96YT;SH`5&]D;W,`5&]D;W,@57-UX7)I;W,@075T96YT:6-A9&]S`%1O
M9&]S($=R=7!O<P!4;V1A<R!097)M:7-S]65S`%1O9&]S('%U871R;R!L861O
M<P!4;V1A<R!A<R!M96YS86=E;G,@;F$H<RD@<V5G=6EN=&4H<RD@<&%S=&$H
M<RD@<V5RXV\@8F%I>&%D87,@96T@=6T@87)Q=6EV;R!-0D]8.@!4;V1A<R!A
M<R!M96YS86=E;G,@96T@<W5A('!A<W1A("(E<R(@;6%I<R!A;G1I9V%S('%U
M92`E<R!D:6%S('-E<N-O(&5X8VQU[61A<R!P97)M86YE;G1E;65N=&4N`%1O
M9&]S(&]S(&%N97AO<R!L:6=A9&]S(&UA:7,@86YT:6=O<R!Q=64@)7,@;65S
M97,@<V5RXV\@97AC;'7M9&]S+@!4;V1A<R!A<R!P87-T87,@(D5N=FEA9&]S
M(B!M86ES(&%N=&EG87,@<75E("5S(&UE<V5S('-E<N-O(&5X8VQU[61A<RX`
M5&]D;W,@;W,@9&ER96ET;W,@;F$@<&%S=&$@(B5S(B!F;W)A;2!R96UO=FED
M87,@9&\@=7-UX7)I;R`B)7,B(&-O;2!S=6-E<W-O+@!097)M:71I<B!#<FEA
MY^-O(&1E(%!A<W1A<S\`4&5R;6ET:7(@<75E(&%S(')E9W)A<R!D92!F:6QT
M<F\@<V5J86T@87!L:6-A9&%S(&5M('%U86QQ=65R('!A<W1A/P!097)M:71I
M<B!M^FQT:7!L;W,@96YD97)EYV]S`%!E<FUI=&ER(&-O;F9I9W5R87(@;R!T
M:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_`$KA(&5X:7-T90!,;V=I;B!)35-0
M($%L=&5R;F%T:79O`%-E;FAA($E-4U`@06QT97)N871I=F$`57-UX7)I;R!)
M35-0($%L=&5R;F%T:79O`$5N9&5R9>=O(&1E(&4M;6%I;"!A;'1E<FYA=&EV
M;P!-;V1E;&]S(&%L=&5R;F%T:79O<P!497AT;R!A;'1E<FYA=&EV;SH`4&%R
M=&5S(&%L=&5R;F%T:79A<R!P87)A(&5S=&$@<V7GXV\Z`%-E;7!R90!396UP
M<F4@<V%L=F%R(&%N97AO<P!386UO82!!;65R:6-A;F$`3V-O<G)E=2!U;2!E
M<G)O(&%O('1E;G1A<B!R96UO=F5R(&\@86YE>&\N($\@<V5R=FED;W(@24U!
M4"!D:7-S93H@`%5M('9A;&]R(&EL96=A;"!F;VD@97-P96-I9FEC861O+@!/
M8V]R<F5U('5M(&5R<F\@9&5S8V]N:&5C:61O+@!/8V]R<F5U('5M(&5R<F\@
M9&5S8V]N:&5C:61O(&%O(&-R:6%R(&$@;F]V82!N;W1A+@!/8V]R<F5U('5M
M(&5R<F\@9&5S8V]N:&5C:61O(&%O(&-R:6%R(&$@;F]V82!T87)E9F$N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`%!R;WAY(&%N]&YI;6\`4F5S<&]S=&$`
M4F5S<&]N9&ED80!-96YS86=E;G,@<F5S<&]N9&ED87,`06YTX7)T:61A`$%N
M=&EG=6$@92!"87)B861O<P!!<&QI8V'GXV\`3&ES=&$@9&4@07!L:6-AY_5E
M<P!!(&%P;&EC8>?C;R!E<W3A('!R;VYT82X`07!L:6-A<B!&:6QT<F]S`$%P
M;&EC87(@1FEL=')O<R!E;2`E<P!!<&QI8V%R(')E9W)A<R!D92!F:6QT<F\@
M86\@8V]N96-T87(_`$%P;&EC87(@<F5G<F%S(&1E(&9I;'1R;R!S96UP<F4@
M<75E(&$@0V%I>&$@9&4@16YT<F%D82!F;W(@97AI8FED83\`07!L:6-A<B!A
M;W,@0V]M<&%R=&EL:&%M96YT;W,@4W5B;W)D:6YA9&]S`$%P<F]V87(`5&%M
M86YH;R!!<')O>&EM861O`$%B<FEL`$%RX6)I8V\@*%=I;F1O=W,M,3(U-BD`
M5&%M86YH;R!D;R!!<G%U:79O`$YO;64@9&\@07)Q=6EV;P!6;V/J('1E;2!C
M97)T97IA('%U92!Q=65R(&5X8VQU:7(@97-T82!$969I;FGGXV\@9&4@4&%S
M=&$@5FER='5A;#\`5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!E>&-L=6ER
M(&5S=&$@8VAA=F4@</IB;&EC83\`5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E
M<B!E>&-L=6ER('-E=2!P87(@9&4@8VAA=F5S/R`H27-T;R!NXV\@Z2!R96-O
M;65N9&%D;R$I`%9O8^H@=&5M(&-E<G1E>F$@<75E('%U97(@9F%Z97(@:7-T
M;S\`5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(&$@<V]L:6-I
M=&'GXV\@9&4@8V%D87-T<F\@9&4@)7,_`%9O8^H@=&5M(&-E<G1E>F$@<75E
M(&1E<V5J82!E>&-L=6ER(%!%4DU!3D5.5$5-14Y412!E<W1A<R!M96YS86=E
M;G,_`%9O8^H@=&5M(&-E<G1E>F$@<75E(&1E<V5J82!E>&-L=6ER(%!%4DU!
M3D5.5$5-14Y412!E<W1E(&%N97AO/P!6;V/J('1E;2!C97)T97IA('%U92!D
M97-E:F$@97AC;'5I<B`G)7,G(&4@<V5U<R!S=6)G<G5P;W,_`%9O8^H@=&5M
M(&-E<G1E>F$@<75E(&1E<V5J82!E<W9A>FEA<B!E<W1A('!A<W1A/P!6;V/J
M('1E;2!C97)T97IA('%U92!D97-E:F$@97-V87II87(@<W5A('!A<W1A(&1E
M('-P86US/P!6;V/J('1E;2!C97)T97IA('%U92!D97-E:F$@97-V87II87(@
M<W5A($QI>&5I<F$_`%9O8^H@=&5M(&-E<G1E>F$@<75E(&1E<V5J82!E>&-L
M=6ER('!E<FUA;F5N=&5M96YT92!E<W1A<R!M96YS86=E;G,_`%9O8^H@=&5M
M(&-E<G1E>F$@<75E(&1E<V5J82!R97!O<G1A<B!E<W1A(&UE;G-A9V5M(&-O
M;6\@:6YO8V5N=&4_`%9O8^H@=&5M(&-E<G1E>F$@<75E(&1E<V5J82!R97!O
M<G1A<B!E<W1A(&UE;G-A9V5M(&-O;6\@<W!A;3\`07)G96YT:6YA`$%R;>IN
M:6$`07)MZFYI;R`H05)-4T-)22TX*0!(;W)A(&1A($-H96=A9&$`07)T90!!
M<G5B80!!<V-E;F1E;G1E`$EL:&$@07-C96YSXV\`07)T92!!<V-I:0#!<VEA
M+U)E9VGC;R!D;R!086/M9FEC;P!097)G=6YT87(`4V]L:6-I=&%R(&-O;F9I
M<FUAY^-O(&%N=&5S(&1E(&5X96-U=&%R(&%S(&]P97)AY_5E<R!D92!M86YU
M=&5NY^-O/P!#;VQU;F%S(&1E(&1E<VEG;F'GXV\`07)Q=6EV;W,@06YE>&%D
M;W,`06YE>&%R('5M82!C\W!I82!D92!S=6$@8VAA=F4@</IB;&EC82!01U`@
M82!E<W1A(&UE;G-A9V5M/P!!<G%U:79O($%N97AA9&\Z`$\@87)Q=6EV;R!A
M;F5X861O("(E<R(@97AC961E(&\@;&EM:71E(&1E('1A;6%N:&\@9&4@86YE
M>&\N($%R<75I=F\@3L-/(&%N97AA9&\N`%-E(&5N8V]N=')A(&%N97AA9&$@
M82!R97-P;W-T82#@(')E<75I<VGGXV\@9&4@86=E;F1A;65N=&\@<75E('9O
M8^H@96YV:6]U+@!!;F5X;P!!;F5X;R`E<R!E>&-L=>UD;RX`26YF;W)M8>?C
M;R!D;R!!;F5X;P!!;F5X;R!R96UO=FED;SH@5&EP;R!O<FEG:6YA;"!D;R!A
M;F5X;P!!;F5X;W,`5&5N=&]U(&5X8VQU:7(@=6T@9W)U<&\@:6YE>&ES=&5N
M=&4N`%1E;G1O=2!E>&-L=6ER('5M82!P97)M:7-SXV\@;N-O(&5X:7-T96YT
M92X`5&5N=&]U(&5D:71A<B!U;6$@<&5R;6ES<^-O(&[C;R!E>&ES=&5N=&4N
M`%1E;G1O=2!E9&ET87(@=6T@8V]M<&%R=&EL:&%M96YT;R!NXV\@97AI<W1E
M;G1E+@!087)T:6-I<&%N=&5S`$%T96[GXV\`071R:6)U=&]S`$%G;W-T;P!!
M=7-T<N%L:6$`P75S=')I80!!=71H7V-Y<G-Q;#H@3N-O(&9O:2!E;F-O;G1R
M861A(&$@97AT96YSXV\@:6UA<"!N96-E<W/A<FEA+@!!=71H7V-Y<G5S.B!/
M(&-O;F5C=&]R(&[C;R!P;W-S=6D@87,@8V%P86-I9&%D97,@;F5C97-SX7)I
M87,N`$%U=&A?8WER=7,Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O
M(&EM87`@;F5C97-SX7)I82X`075T:%]F='`Z($[C;R!F;VD@96YC;VYT<F%D
M82!A(&5X=&5N<^-O($944"!N96-E<W/A<FEA+B!#;VUP:6QE(&\@4$A0(&-O
M;2!A(&]PY^-O("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!.XV\@9F]I(&5N
M8V]N=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N`$%U=&A?:6UP
M.D5X=&5N<^-O($E-05`@;V)R:6=A=/-R:6$@;N-O(&5N8V]N=')A9&$N`$%U
M=&A?:W)B-3H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:W)B-2!N
M96-E<W/A<FEA+@!!=71H7VQD87`Z($EN8VQU<^-O(&1E('5S=>%R:6]S(&[C
M;R#I('-U<&]R=&%D82!P87)A($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!%>&-L=7/C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@3N-O(&9O:2!E;F-O;G1R861A
M(&$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA+@!!=71H7VQD87`Z($EM<&]S
M<^UV96P@861I8VEO;F%R(&\@=7-UX7)I;R`E<RX@27-T;R!F;VD@;R!Q=64@
M;R!S97)V:61O<B!R97!O<G1O=3H@`$%U=&A?;&1A<#H@26UP;W-S[79E;"!R
M96UO=F5R(&\@=7-UX7)I;R`E<P!!=71H7VQD87`Z($EM<&]S<^UV96P@871U
M86QI>F%R(&\@=7-UX7)I;R`E<P!!=71H7VQD87`Z($%T=6%L:7IAY^-O(&1E
M('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A($%C=&EV92!$:7)E8W1O
M<GDN`$%U=&A?;6-A;#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@
M34-!3"!N96-E<W/A<FEA+@!!=71H7W-M8F%U=&@Z($[C;R!F;VD@96YC;VYT
M<F%D82!A(&5X=&5N<^-O('-M8F%U=&@@;F5C97-SX7)I82X`075T96YT:6-A
MY^-O(&YO('-E<G9I9&]R($E-05`@9F%L:&]U+@!&86QH82!N82!A=71E;G1I
M8V'GXV\`1F%L:&$@;F$@875T96YT:6-AY^-O.B`E<P!!=71E;G1I8V'GXV\@
M<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$2553+@!!(&%U=&5N=&EC8>?C
M;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U+@!!(&%U=&5N=&EC8>?C;R!N;R!S
M97)V:61O<B!334(@9F%L:&]U+@!%>&EB:7(@:6UA9V5N<R!A=71O;6%T:6-A
M;65N=&4@96T@;65N<V%G96YS(&9O<FUA=&\@2%1-3"!Q=6%N9&\@;R!D97-T
M:6YA=.%R:6\@97-T:79E<B!E;2!M974@8V%TX6QO9V\@9&4@96YD97)EYV]S
M/P!#873A;&]G;W,@9&4@16YD97)EYV\@9&ES<&]N[79E:7,Z`$-A;7!O<R!D
M:7-P;V[M=F5I<SH`06=U87)D86YD;R!R97-P;W-T80!!>F5R8F%I:N-O`$1E
M<V-U;'!A<R!D;R!"3T9(`%)E=&]R;F%?<B!P87)A("5S`%)E=&]R;F%R('!A
M<F$@)7,`5F]L=&%R('!A<F$@;R#-;F1I8V4@9&4@5FES=6%L:7IAY^-O(&1E
M($WZ;'1I<&QA<R!-96YS86=E;G,`5F]L=&%R(.`@5FES=6%L:7IAY^-O('!O
M<B!$:7-C=7-SXV\`1G5N9&\`0V]R(&1E($9U;F1O`%-E;FAA(&ME<F)E<F]S
M(&EN8V]R<F5T82X`57-UX7)I;R!K97)B97)O<R!I;F-O<G)E=&\N`$QO9VEN
M(&]U('-E;FAA(&EN=N%L:61O<RX`4V]L:6-I=&'GXV\@:6YVX6QI9&$@;W4@
M9&5F96ET=6]S83H@;R!397)V:61O<B!297-P;VYD974Z("5S`%-O;&EC:71A
MY^-O(&EN=N%L:61A.B`E<RX`0F%H86UA<P!"86AR86EN`$+A;'1I8V\@*$E3
M3RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$[C;R!F;VD@96YC;VYT
M<F%D;R!O(&1I<F5T\W)I;R!B87-E(&1E(&EM86=E;G,@)R5S)RX`3&EN:&$@
M9&4@4&%R=&ED80!#8V\`0F5L;W+Z<W-I80!"Z6QG:6-A`$)E;&EZ90!!8F%I
M>&\@97-TX2!O('1E>'1O(&)R=71O(&1A(&UE;G-A9V5M(&1E(&EN9F]R;6'G
MXV\@9&4@<VET=6'GXV\N`$)E;FEN`$)E<FUU9&%S`$)U=.-O`$%N:79E<G/A
M<FEO`$QI<W1A($YE9W)A`$[C;R!F;VD@96YC;VYT<F%D;R!O(&)L;V-O("(E
M<R(@9&$@87!L:6-AY^-O("(E<R(N`$-O;F9I9W5R8>?U97,@9&\@0FQO8V\`
M5&EP;R!D92!";&]C;P!";&]Q=65A<B!M96YS86=E;G,@96T@2%1-3"!A(&UE
M;F]S('%U92!E;&%S('1E;FAA;2!S:61O(&5X<&QI8VET86UE;G1E('-O;&EC
M:71A9&%S/P!#;W)P;P!.96=R:71O`$)O;.UV:6$`1F%V;W)I=&]S`$)O<F1A
M`$QA<F=U<F$@9&$@8F]R9&$Z`$)O<F1A<P!"\W-N:6$@92!(97)Z96=O=FEN
M80!!;6)O<P!!;6)A<R!,:7-T86=E;2!D;R!#86)EYV%L:&\@92!#;W)P;R!D
M82!-96YS86=E;0!";W1S=6%N80!2;V1A<.D`26QH82!";W5V970`0G)A<VEL
M`%1E<G)I=/-R:6\@9&\@3V-E86YO(,UN9&EC;R!);F=LZG,`0G)U;F5I`$)U
M;&?A<FEA`$QI<W1A(&-O;2!-87)C861O<F5S`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`4&]N=&]S(&1E($1I<W1R:6)U:>?C;R!#4DP`4')O<')I
M961A9&5S(&1A($/I7VQU;&$N+BX`0V]N7VIU;G1O(&1E(&-A<F%C=&5R97,`
M02!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF:6-A9&$N
M`$%G96YD80!#86QM;P!#86UB;V1J80!#86UA<O5E<P!.XV\@8V]N<VEG;R!C
M;VYE8W1A<B!A;R!S97)V:61O<B!D92!C;W)R96EO(')E;6]T;RX`3N-O(&-O
M;G-I9V\@8V]N96-T87(@86\@<V5R=FED;W(@9&4@8V]R<F5I;R!R96UO=&\Z
M(`!.XV\@8V]N<VEG;R!E>&EB:7(@+2!E;F-O;G1R861A<R!S;VUE;G1E("5S
M(&1E("5S('!A<G1E<R!D97-T82!M96YS86=E;2!N82!P87-T82!A='5A;"X`
M3N-O(.D@<&]S<^UV96P@9V5R87(@=6UA(&YO=F$@<V5N:&$@875T;VUA=&EC
M86UE;G1E+"!E;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(N
M`$[C;R!C;VYS:6=O(&=R879A<B!O(&%R<75I=F\@(B5S(@!.XV\@Z2!P;W-S
M[79E;"!A9&UI;FES=')A<B!G97)E;F-I861O<F5S(&5X=&5R;F]S(&1E('-E
M<W/C;RX`3N-O(.D@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@24U!
M4#H@)7,`3N-O(&-O;G-I9V\@86)R:7(@;R!A<G%U:79O("(E<R(N`$-A;F%D
MX0!#86YC96QA<@!#86YC96QA<B!-96YS86=E;0!#86YC96QA<B!296QA=/-R
M:6\@9&4@4')O8FQE;6$`0V%N8V5L87(@97-T82!M96YS86=E;2!D97-C87)T
M87+A('!E<FUA;F5N=&5M96YT92!S974@8V]N=&7Z9&\N`$[C;R#I('!O<W/M
M=F5L(&5X8VQU:7(@;R!A<G%U:79O("(E<R(N`$[C;R#I('!O<W/M=F5L(&5N
M8V]N=')A<B!U;2!D:7)E=/-R:6\@=&5M<&]RX7)I;RX`3N-O(.D@<&]S<^UV
M96P@8V]N=&EN=6%R('-E;2!O('!A<N)M971R;R`G=&%R9V5T1FEL92<N`$[C
M;R#I('!O<W/M=F5L(&5X8VQU:7(@;R!D:7)E=/-R:6\@(B5S(BX`3N-O(.D@
M<&]S<^UV96P@97AC;'5I<BP@)60@<&]S<W5I('-U8F]R9&EN861O<RX`3N-O
M(.D@<&]S<^UV96P@<F5O<F1E;F%R+"!N^FUE<F\@9&4@<F5G:7-T<F]S(&9O
M<FYE8VED;W,@<&%R82!R96]R9&5N87(@;N-O(&-O<G)E<W!O;F1E(&%O(&[Z
M;65R;R!A<FUA>F5N861O+@!.XV\@Z2!P;W-S[79E;"!R;W1E87(@;65N<V%G
M96T@<&%R82!O(&[Z;65R;R!E<W!E8VEF:6-A9&\N`$-A8F\@5F5R9&4`5.UT
M=6QO`$]P97)A9&]R80!#871E9V]R:6%S(&4@3F]M97,`26QH87,@0V%Y;6%N
M`$-C`%1E;&5F;VYE($-E;'5L87(`4')O<')I961A9&5S(&1A($/I;'5L80!-
M87)G96T@9&$@8^EL=6QA.@!0<F]P<FEE9&%D97,@9&$@0^EL=6QA`$5S<&'G
M86UE;G1O(&1A(&/I;'5L83H`5&5L969O;F4@8V5L=6QA<@!#Z6QT:6-O("A)
M4T\M.#@U.2TQ-"D`0V5N=')O`%)E</IB;&EC82!D82#!9G)I8V$@0V5N=')A
M;`!%=7)O<&$@0V5N=')A;"`H25-/+3@X-3DM,BD`1&5T86QH97,@9&\@0V5R
M=&EF:6-A9&\`4')O<')I973A<FEO(&1O($-E<G1I9FEC861O`%!O;.UT:6-A
M<R!D;R!#97)T:69I8V%D;P!);7!O<G1AY^-O(&1E(&-E<G1I9FEC861O<R!N
MXV\@97-TX2!D:7-P;V[M=F5L+B!/(&5N=FEO(&1E(&%R<75I=F]S(&[C;R!E
M<W3A(&AA8FEL:71A9&\@;F5S=&4@<V5R=FED;W(N`%1C:&%D90!-;V1E<F%D
M;W(`06QT97)A<@!!;'1E<F%R(%1O9&%S`$%L=&5R87(@4&%S=&$`06QT97)E
M(%-U82!396YH80!!;'1E<F$@;W#G]65S(&1E(&5X:6)IY^-O('1A:7,@8V]M
M;R!Q=6%N=&%S(&UE;G-A9V5N<R!V;V/J('!O9&4@=F5R(&5M(&-A9&$@<.%G
M:6YA(&4@<75A;G1A<R!M96YS86=E;G,@<^-O(&%R;6%Z96YA9&%S+@!!;'1E
M<F$@<V5R=FED;W(@9&4@8V]R<F5I;R!E(&-O;F9I9W5R8>?U97,@9&4@<&%S
M=&%S+@!!;'1E<F%R(&\@;F]M92!E(&\@96YD97)EYV\@<75E(&%S('!E<W-O
M87,@=NIE;2!Q=6%N9&\@96QA<R!LZF5M(&4@<F5S<&]N9&5M('-U87,@;65N
M<V%G96YS+@!!;'1E<F$@;R!N;VUE+"!E;F1E<F7G;R!E(&%S<VEN871U<F$@
M<75E(&%S('!E<W-O87,@=NIE;2!Q=6%N9&\@96QA<R!LZF5M(&4@<F5S<&]N
M9&5M('-U87,@;65N<V%G96YS+@!!;'1E<F'GXV\@9&4@<V5N:&$@;N-O(.D@
M<W5P;W)T861A(&YA(&-O;F9I9W5R8>?C;R!A='5A;"X@($5N=')E(&5M(&-O
M;G1A=&\@8V]M(&\@861M:6YI<W1R861O<BX`0VAA<@!#87)A8W1E<F5S(&$@
M97AI8FER.@!697)I9FEC87(@3&EN7VLN+BX`5F5R:69I8V%R($YO=F%S($UE
M;G-A9V5N<R!N82AS*2!087-T82AS*0!-87)C87(@5&]D87,O3F5N:'5M80!6
M97)I9FEC87(@=&]D;W,@;W,@<V5R=FED;W)E<R!D92!C;W)R96EO(&1E(&]N
M9&4@=F]CZB!Q=65R('1R87IE<B!M96YS86=E;G,Z`%9E<FEF:6-A<B!O<G1O
M9W)A9FEA(&%N=&5S(&1E(&5N=FEA<B!U;6$@;65N<V%G96T_`$-H:6QE`$-H
M:6YA`$-H:6[J<R!3:6UP;&EF:6-A9&\@*$=",C,Q,BD`0VAI;NIS(%1R861I
M8VEO;F%L("A":6<U*0!%<V-O;&AA(&$@0>?C;SH`17-C;VQH82!A($%P;&EC
M8>?C;SH`17-C;VQH82!U;2!S97)V:61O<B!D92!C;W)R96EO.@!0;W(@9F%V
M;W(@<V5L96-I;VYE(&]U(&5D:71E(&YA(&-A:7AA(.`@9&ER96ET83H`17-C
M;VQH82!U;6$@<V5N:&$`17-C;VQH82!U;2!U<W7A<FEO`$5S8V]L:&$@8V]M
M;R!E>&EB:7(@9&%T87,Z`$5S8V]L:&$@;R!T:7!O(&1E(&5S=&EL;R!D92!L
M:7-T87,@*'!A<F$@;&ES=&%S(&]R9&5N861A<RD`17-C;VQH82!O(&-A=.%L
M;V=O(&1E(&5N9&5R9>=O<R!P87)A('5T:6QI>F%R(&%O(&%D:6-I;VYA<B!E
M;F1E<F7G;W,N`$5S8V]L:&$@82!O<F1E;2!D92!P97-Q=6ES82!D;W,@8V%T
MX6QO9V]S(&1E(&5N9&5R9>=O<R!A;R!E>'!A;F1I<B!E;F1E<F7G;W,N`$EL
M:&%S($-H<FES=&UA<P!.XV\@9F]I(&5N8V]N=')A9&$@82!D969I;FGGXV\@
M9&4@8VQA<W-E(&1E("5S+@!,:6UP87(`3&EM<&%R('1A9W,@35-/9F9I8V4`
M17AC;'5I<B!U<W7A<FEO`$5X8VQU:7(@=7-UX7)I;SH@)7,`17AC;'5I<B!U
M<W7A<FEO`$5X8VQU:7(@9&%D;W,@9&\@=7-UX7)I;P!#Z74@86)E<G1O(&$@
M5&%R9&4`0VQI<75E(&5M("5S('!A<F$@8V]N=F5R=&5R(&\@87)Q=6EV;R!D
M92!I;6%G96T@96T@=6T@9F]R;6%T;R!Q=64@<V5U(&YA=F5G861O<B!P;V1E
M(&5X:6)I<BX`0VQI<75E(&5M("5S('!A<F$@8F%I>&%R(&$@:6UA9V5M+@!#
M;&EQ=64@96T@)7,@<&%R82!I<B!P87)A(&$@<.%G:6YA(&1E(&=E<F5N8VEA
M;65N=&\@9&4@)7,N`$-L:7%U92!E;2`E<R!P87)A('9E<B!O(&-O;G1E^F1O
M($A434P@96T@=6UA(&IA;F5L82!S97!A<F%D82X`0VQI<75E(&5M("5S('!A
M<F$@=F5R('5M82!M:6YI871U<F$@9&5S=&$@:6UA9V5M+@!#;&EQ=64@96T@
M)7,@<&%R82!V97(@;R!A;F5X;R!E;2!U;6$@:F%N96QA(&$@<&%R=&4N`$-L
M:7%U92!E;2`E<R!P87)A('9I<W5A;&EZ87(@97-T82!P87)T92!D;R!T:7!O
M(&UU;'1I<&%R="]R96QA=&5D(&5M('5M82!J86YE;&$@<V5P87)A9&$N`$-L
M:7%U92!A<75I('!A<F$@15A)0DE2(&%S(&EM86=E;G,`0VQI<75E(&5M('5M
M(&1E('-E=7,@0V%TX6QO9V]S(&1E($5N9&5R9>=O<R!S96QE8VEO;F%D;W,@
M92!E;G3C;R!S96QE8VEO;F4@=&]D;W,@;W,@8V%M<&]S(&$@<&5S<75I<V%R
M+@!#;&EQ=64@<&%R82!#;VYT:6YU87(`0VQI<75E('!A<F$@4V%L=F%R(&$@
M0VAA=F4@4/IB;&EC82!01U`@96T@<V5U($-A=.%L;V=O(&1E($5N9&5R9>=O
M<P!#;&EQ=64@<&%R82!386QV87(@;R!C97)T:69I8V%D;R!3+TU)344@9&4@
M)7,@96T@<V5U($-A=.%L;V=O(&1E($5N9&5R9>=O<P!#;&EC:V%T96QL('9I
M82!(5%10`$-L:6-A<B!N;R!E;F1E<F7G;R!I<N$@8V]M<&]R('5M82!N;W9A
M(&UE;G-A9V5M('!A<F$@;R!R96UE=&5N=&4`0VQI8V%R(&YO(&5N9&5R9>=O
M(&%B<FERX2!A(&UE;G-A9V5M('!A<F$@<V5R(&QI9&$`1F5C:&%R`$9E8VAA
M<B!*86YE;&$`1F5C:&%R(&5S=&$@:F%N96QA`$9E8VAA<B!087-T80!.=79E
M;G,`3G5B;&%D;R!P96QA($UA;FCC`$YU8FQA9&\`26QH87,@9&4@0V]C;W,`
M0V]N=')A:7(`0V]N=')A:7(@5&]D87,`0V]N=')A:7(@5&]D87,@4&%S=&%S
M`$-O;G1R86ER(%!A<W1A`$-O;G1R86ER($)A<G)A($QA=&5R86P`0V]N=')A
M:7(@8F]R9&%S`$-O;/1M8FEA`$-O<@!);F1I8V%D;W(@9&4@0V]R.B``4&%L
M:&5T82!D92!#;W)E<P!396QEY^-O(&1E($-O<@!#;VQS.@!4[71U;&]S(&1A
M<R!#;VQU;F%S`%%U861R:6YH;W,`0V]M86YD;P!,:6YH82!D92!#;VUA;F1O
M`$-O;65N=&%R`$YO;64`0V]M;W)O<P!%;7!R97-A`$5N8V5R<F%D80!#;VUP
M;W(@;W5T<F$@;65N<V%G96T`0V]M<&]R(&UE;G-A9V5N<R!E;2!U;6$@:F%N
M96QA('-E<&%R861A/P!#;VUP;W(@;65N<V%G96YS(&5M('5M(&5D:71O<B!(
M5$U,('!O<B!P861RXV\@*'-E(&\@;F%V96=A9&]R('-U<&]R=&%R(&5S=&$@
M8V%R86-T97+M<W1I8V$I/P!#;VUP=71A9&]R97,`0V]N9&GGXV\`0V]N9&GG
M]65S`$1I9F5R96[G87,@9&4@0V]N9FEG=7)AY^-O`$-O;F9I9W5R8>?C;R!D
M92!S:6YC<F]N:7IAY^-O(&-O;2!01$%S+"!3;6%R='!H;VYE<R!E($]U=&QO
M;VLN`$-O;F9I9W5R8>?C;R!N96-E<W-I=&$@9&4@871U86QI>F'GXV\N`$-O
M;F9I9W5R87(@)7,`0V]N9FEG=7)A(&-O;2!A<R!M96YS86=E;G,@<^-O(&5X
M:6)I9&%S+@!#;VYF:6=U<F$@;W#G]65S(&1E('!RZ2UV:7-U86QI>F'GXV\@
M9&4@;65N<V%G96TN`$-O;F9I<FUE(&$@4V5N:&$`0V]N9V\`0V]N9V\L(%)E
M</IB;&EC82!$96UO8W+A=&EC82!D;P!#;VYE>.-O(&1E<V-A<G1A9&$@<&5L
M;R!S97)V:61O<B!)34%0+@!&86QH82!N82!C;VYE>.-O+@!&86QH82!N82!C
M;VYE>.-O.B``0V]N97CC;R!R96-U<V%D82!P96QO('-E<G9I9&]R(&1E(&-H
M879E<R!P^F)L:6-A<RX`0V]N97CC;R!R96-U<V%D82!P96QO('-E<G9I9&]R
M(&1E(&-H879E<R!P^F)L:6-A<RX@36]T:79O.B`E<R`H)7,I`$$@8V]N97CC
M;R!A;R!S97)V:61O<B!&5%`@9F%L:&]U+@!!(&-O;F5XXV\@8V]M(&\@<V5R
M=FED;W(@9F%L:&]U`$-O;G1A=&]S`$]S(&-O;G1A=&]S(&9O<F%M(&%D:6-I
M;VYA9&]S(&-O;2!S=6-E<W-O(&%O('-E=2!C873A;&]G;R!D92!E;F1E<F7G
M;W,N`%1I<&4@9&4@8V]N=&7Z9&\@9&\@87)Q=6EV;R!C;VUP<FEM:61O.B``
M0V]N=&7Z9&\@9&4@)R5S)P!#;VYT:6YU87(`0V]N=')O;&$@;R!S=7!O<G1E
M(%!'4"!P87)A("5S+@!#;VYT<F]L82!O('-U<&]R=&4@4R]-24U%('!A<F$@
M)7,N`$]PY_5E<R!D92!C;VYT<F]L92!R96QA8VEO;F%D87,@82!P97-Q=6ES
M82!D92!M96YS86=E;G,N`$-O;G1R;VQA('%U86YD;R!F87IE<B!A('9E<FEF
M:6-AY^-O('!O<B!N;W9A<R!M96YS86=E;G,@92!S92!D979E(&YO=&EF:6-A
M<B!O=2!NXV\@<75A;F1O(&5L87,@8VAE9V%R96TN`$-O;G9E<G1E<B`G96UO
M=&EC;VYS)R!T97AT=6%I<R!E;2!G<N%F:6-O<S\`26QH87,@0V]O:P!#;V]K
M:64`0V]P:6%R`$9A;&AA(&YA(&/S<&EA.B`E<P!#;W!I87(@<V5L9>?C;P!#
M;W!I87(@<&%R82!A('!A<W1A`$-O<G)I9VER`%1E>'1O($-O<G)I9VED;P!)
M1"!D92!#=7-T;P!#;W-T82!2:6-A`$-O<W1A(&1O($UA<F9I;0!);7!O<W/M
M=F5L(&-R:7!T;V=R869A<B!A(&UE;G-A9V5M(&-O;2!01U`Z(`!);7!O<W/M
M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4$=0.B``3N-O(&9O:2!P;W-S
M[79E;"!C<FEP=&]G<F%F87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.XV\@
M9F]I('!O<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.
MXV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA<B!C;VYT871O+B`E<P!.XV\@9F]I
M('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R($Q$05`N`$[C;R!F;VD@
M<&]S<^UV96P@=F5R:69I8V%R(&\@<V%L9&\N("5S`$EM<&]S<^UV96P@8V]M
M<&QE=&%R(&$@<V]L:6-I=&'GXV\Z(%)A>N-O.B`E<P!);7!O<W/M=F5L(&-O
M;F5C=&%R(&%O('-E<G9I9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@8V]N
M96-T87(@86\@<V5R=FED;W(@)R5S)R!U=&EL:7IA;F1O($944#H@)7,`3N-O
M(&9O:2!P;W-S[79E;"!C<FEA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@
M)7,`3N-O(&-O;G-E9W5I(&-R:6%R('5M(&-O;F5C=&]R(%931CH@)7,`26UP
M;W-S[79E;"!D97-C<FEP=&]G<F%F87(@;W,@9&%D;W,@4$=0.B``3N-O(&9O
M:2!P;W-S[79E;"!D97-C<FEP=&]G<F%F87(@;R!D861O(%,O34E-12X`3N-O
M(&9O:2!P;W-S[79E;"!E>&-L=6ER(&\@8V]N=&%T;RX@)7,`3N-O(&9O:2!P
M;W-S[79E;"!E>&-L=6ER(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.
MXV\@8V]N<V5G=6D@97AC;'5I<B!A<R!M96YS86=E;G,@9&4@)7,N($\@<V5R
M=FED;W(@9&ES<V4Z("5S`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!O('-C
M<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@)R5S)RX`3N-O
M(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&\@96YD97)EYV\@9&4@92UM86EL
M(&1O(&1E<W1I;F%TX7)I;RX`3N-O(&-O;G-E9W5I(&5X96-U=&%R(&%S(&]P
M97)AY_5E<R!D92!M86YU=&5NY^-O+@!.XV\@8V]N<V5G=6D@97AT<F%I<B!O
M(&%R<75I=F\@<V]L:6-I=&%D;R!D;R!A;F5X;R!-4RU43D5&+@!.XV\@8V]N
M<V5G=6D@97AT<F%I<B!O(&%R<75I=F\@<V]L:6-I=&%D;R!D;R!A<G%U:79O
M(%II<"X`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&\@
M8V%TX6QO9V\@9&4@96YD97)EYV]S+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R
M(&-O;7!L971A;65N=&4@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!A(&QI<W1A(&1E(&QI
M<W1A<R!D92!D:7-T<FEB=6GGXV\N`$[C;R!F;VD@<&]S<^UV96P@8V%R<F5G
M87(@82!E<W1R873I9VEA("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@
M;R!D:7)E=/-R:6\@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&-H
M879E('#Z8FQI8V$@82!P87)T:7(@9&\@<V5R=FED;W(@9&4@8VAA=F5S+@!.
MXV\@9F]I('!O<W/M=F5L(&%B<FER("<E<R<@<&%R82!G<F%V8>?C;RX`3N-O
M(&9O:2!P;W-S[79E;"!A8G)I<B`E<RX`3N-O(&9O:2!P;W-S[79E;"!A8G)I
M<B!O(&WS9'5L;R`G36%I;G1E;F%N8V5?5&%S:R<@)7,`3N-O(&9O:2!P;W-S
M[79E;"!A8G)I<B!O(&1I<F5T\W)I;R`G)7,G+@!);7!O<W/M=F5L(&%B<FER
M(&-O;F5XXV\@<V5G=7)A(&YO('-E<G9I9&]R($E-05`Z("5S.B`E<RX`3N-O
M(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@;F\@<V5R=FED;W(@3$1!4"X`3N-O
M(&9O:2!P;W-S[79E;"!L97(@)7,N`$[C;R!F;VD@<&]S<^UV96P@9V5R87(@
M=6UA(&YO=F$@<V5N:&$@<&%R82!O('5S=>%R:6\@<V]L:6-I=&%D;RX@06QG
M=6YS(&]U('1O9&]S(&]S(&1E=&%L:&5S(&[C;R!E<W3C;R!C;W)R971O<RX@
M5&5N=&4@;F]V86UE;G1E(&]U(&5N=')E(&5M(&-O;G1A=&\@8V]M(&\@861M
M:6YI<W1R861O<B!S92!V;V/J(&YE8V5S<VET82!D92!M86ES(&%J=61A+@!.
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@04-,`$[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@;R!C873A;&]G;R!D92!E;F1E<F7G;W,N("5S`$[C;R!F;VD@<&]S
M<^UV96P@;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@87,@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX@
M)7,`26UP;W-S[79E;"!O8G1E<B!I;F9O<FUAY_5E<R!D92!N;VUE<R!D;R!S
M97)V:61O<B!)34%0+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&-A<&%C
M:61A9&5S(&1O('-E<G9I9&]R`$[C;R!F;VD@<&]S<^UV96P@<F5V97)T97(@
M82!C;VYF:6=U<F'GXV\N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&1I
M<F5T\W)I;R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!A(&-O;F9I
M9W5R8>?C;R`E<RX`3N-O(&9O:2!P;W-S[79E;"!S86QV87(@=6T@8F%C:W5P
M(&1A(&-O;F9I9W5R8>?C;RX`3N-O(&9O:2!P;W-S[79E;"!S86QV87(@=6T@
M8F%C:W5P(&1A(&-O;F9I9W5R8>?C;SH@)7,`3N-O(&9O:2!P;W-S[79E;"!S
M86QV87(@;R!S8W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O
M(&5M.B`G)7,G+@!.XV\@8V]N<V5G=6D@<V%L=F%R(&\@8F%C:W5P(&1O(&%R
M<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+@!.XV\@8V]N<V5G=6D@<V%L=F%R
M(&\@87)Q=6EV;R!D92!C;VYF:6=U<F'GXV\@)7,N(%9O8^H@<&]D92!O=2!U
M=&EL:7IA<B!U;6$@9&%S(&]PY_5E<R!P87)A('-A;'9A<B!O(&/S9&EG;R!D
M92!V;VQT82!E;2`E<R!O=2!C;W!I87(@;6%N=6%L;65N=&4@;R!C\V1I9V\@
M86)A:7AO('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV96P@<&5S<75I<V%R(&YO
M('-E<G9I9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&QI
M;FL@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!A='5A;&EZ87(@;R!C;VYT871O
M+B`E<P!.XV\@9F]I('!O<W/M=F5L(&%T=6%L:7IA<B!A(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!G<F%V87(@82!C;VYF
M:6=U<F'GXV\@9&4@)R5S)SH@)7,`3N-O(&9O:2!P;W-S[79E;"!E;F-O;G1R
M87(@82!"87)R82!,871E<F%L(&1O($UO>FEL;&$N($-E<G1I9FEQ=64M<V4@
M<75E(&5L82!E<W3A(&%B97)T82X`3N-O(&9O:2!P;W-S[79E;"!D87(@86\@
M=7-UX7)I;R`E<R!O<R!S96=U:6YT97,@9&ER96ET;W,@<&%R82!A('!A<W1A
M("<E<R<Z("5S`%1E>'1O(&-O;G1A9&\`4&'M<P!#=7)S;W,`0W)I87(`0W)I
M87(@4&%S=&$`0W)I87(@0VAA=F5S`$]U=')A<R!#;VYT87,@9&4@0V]R<F5I
M;P!#<FEA<B!U;2!L:6YK`$-R:6%R('5M82!N;W9A('!A<W1A(&1E('-P86T`
M0W)I87(@=6UA(&YO=F$@<&%S=&$@9&4@<F%S8W5N:&]S`$-R:6%R('5M82!N
M;W9A`$-R:6%R('5M82!N;W9A('!A<W1A(&UE;G-A9V5N<R!E;G9I861A<P!#
M<FEA<B!U;6$@;F]V82!L:7AE:7)A`$-R:6$@<F5G<F%S(&1E(&9I;'1R;R!P
M87)A(&]R9V%N:7IA<B!A<R!N;W9A<R!M96YS86=E;G,L(&]R9&5NX2UL87,@
M96T@<&%S=&%S(&4@97AC;'5I<B!S<&%M+@!#<FEA<B!U;2!N;W9O('!A<&5L
M(&1E(&-A<G1A`$-R:6%R('!A<&5L(&1E(&-A<G1A(&4@9F]R;75LX7)I;R!D
M92!R97-P;W-T87,N`$-R:6%R('-U8B!P87-T87,`4&5R;6ES<_5E<R!D;R!C
M<FEA9&]R`$[Z;65R;R!D;R!C87)TXV\@9&4@8W+I9&ET;P!#<F_A8VEA`$-U
M8F$`-"!&87-E<R!!='5A:7,`4V5S<_5E<R!!='5A:7,`2&]R82!!='5A;`!!
M(%523"!A='5A;"#I`%5S=>%R:6]S(&YO(&UO;65N=&\`0VQI;6$@071U86P`
M06-E<W-O(&%T=6%L(&$@)7,`0V]N9&GGXV\@871U86PZ(`!%<W1I;&\@871U
M86P`0W5S=&]M:7IA(&-O;G1A<R!P87)A('1R87IE<B!M96YS86=E;G,@9&4@
M;W5T<F%S(&-O;G1A<RX`0W5S=&]M:7IA(&-O;6\@=F]CZB!E;G9I82!M96YS
M86=E;G,N`$-U<W1O;6EZ82!T87)E9F%S(&$@<V5R96T@97AE8W5T861A<R!A
M;R!C;VYE8W1A<B!A("5S+@!#;W)T87(`0V]R=&%R('-E;&7GXV\`0VAI<')E
M`$-I<NUL:6-O("A+3TDX+5(I`$-I<NUL:6-O("A7:6YD;W=S+3$R-3$I`$-I
M<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5*0!297#Z8FQI8V$@5&-H96-A`$1$
M`$133B`H=F5J82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1I87)I86UE;G1E`$1A
M=%]A`$YA=F5G861O<B!D92!$871A5')E90!097-Q=6ES82!N;R!"86YC;R!D
M92!$861O<P!$871A`$1A=&$@9&4@4F5C96)I;65N=&\`4V5L9>?C;R!D92!D
M871A`$1I80!%7WAC;'5I<B!#;VQU;F$`1&5Z96UB<F\`3OIM97)O<R!D96-I
M;6%I<P!296-U<V%D;P!296-U<V%D;P!296-U87(@261E;G1AY^-O`$5X8VQU
M:7(`0V]R(%!A9'+C;P!)9&5N=&ED861E(%!A9'+C;P!#86UP;R!D92!097-Q
M=6ES82!0861RXV\`4VAE;&P@4&%D<N-O`$-R:73I<FEO('!A9'+C;R!D92!O
M<F1E;F'GXV\Z`$1I<F7GXV\@9&4@;W)D96YAY^-O('!A9'+C;SH`1&5F:6YI
MY_5E<P!$96QE9V%D;P!%>&-L=6ER`$5X8VQU:7(@0VAA=F4@4/IB;&EC82`E
M<P!%>&-L=6ER(&/I;'5L80!%>&-L=6ER($-H879E<R!!='5A:7,`17AC;'5I
M<B!087-T82AS*0!%>&-L=6ER($=R=7!O`$5X8VQU:7(@3&]G`$5X8VQU:7(@
M4&5R;6ES<^-O`$5X8VQU:7(@4&%S=&%S(%-E;&5C:6]N861A<P!%>&-L=6ER
M(%!A<&5L(&1E($-A<G1A`$5X8VQU:7(@4&%S=&%S(%9I<G1U86ES`$5X8VQU
M:7(@1&5F:6YIY_5E<R!D92!087-T87,@5FER='5A:7,@9&4@)7,`17AC;'5I
M<B!E('!U<F=A<B!M96YS86=E;G,`17AC;'5I<B!CZ6QU;&$`17AC;'5I<B!C
M;VQU;F$`17AC;'5I<B!M;V1E;&\@<W5B<W1I='5T;R!E>&ES=&5N=&4`17AC
M;'5I<B!M96YS86=E;G,@=')A>FED87,@9&\@<V5R=FED;W(@<F5M;W1O/P!%
M>&-L=6ER(&1A(&UI;FAA(&%G96YD80!%>&-L=6ER(&QI;FMS(&1E(&%N97AO
M<R!A;G1I9V]S(&YO(&EN[6-I;R!D;R!MZG,_`$5X8VQU:7(@<&%S=&%S(&%N
M=&EG87,@9&4@;65N<V%G96YS(&5N=FEA9&%S(&YO(&EN[6-I;R!D;R!MZG,_
M`$5X8VQU:7(@<&5R;6ES<_5E<R!P87)A("<E<R<`17AC;'5I<B!P97)M:7-S
M]65S('!A<F$@)R5S)R!E('%U86QQ=65R(&]U=')A('-U8BUP97)M:7-SXV\_
M`$5X8VQU:7(@;&EN:&$`17AC;'5I<B!I9&5N=&ED861E('-E;&5C:6]N861A
M`$5X8VQU:7(@<W!A;7,`17AC;'5I<B!A(&-O;'5N82!A='5A;`!%>&-L=6ER
M(&$@;&EN:&$@871U86P`17AC;'7M9&$`365N<V%G96YS($5X8VQU[61A<P!3
M8W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O("<E<R<@97AC
M;'7M9&\N`$%N97AO("(E<R(@97AC;'7M9&\N`$5X8VQU:6YD;R!E($UO=F5N
M9&\@365N<V%G96YS`$AO<F$@9&4@96YT<F5G80!$:6YA;6%R8V$`3F5G87(@
M<V]L:6-I=&'GXV\`3F5G87(@<V]L:6-I=&'GXV\@9&4@:6YF;W)M8>?C;R!L
M:79R92]O8W5P861O`$1E<V-E;F1E;G1E`$1E<V-R979A(&\@<')O8FQE;6$`
M1&5S8W)IY^-O`$1E=&%L:&5S`$1E=&%L:&5S("AT86UBZ6T@;F\@<F5G:7-T
M<F\@9&4@871I=FED861E<R!D;R!(;W)D92DZ`$]S(&1E=&%L:&5S(&9O<F%M
M(&=R879A9&]S(&5M(&QO9R!P87)A(&\@861M:6YI<W1R861O<BX`1&5S96YV
M;VQV:6UE;G1O`%!O;G1O(&1E($]R=F%L:&\`4&]N=&\@9&4@3W)V86QH;R!P
M87)A(&$@^FQT:6UA(&AO<F$Z(`!0;VYT;R!D92!/<G9A;&AO.B``3N-O(&%N
M97AO=2`B)7,B('!O:7,@;R!A<G%U:79O(&5S=&%V82!V87II;RX`17-M865C
M97(@87-S:6YA='5R87,_`$1I<F7GXV\@9&$@97-Q=65R9&$@<&%R82!D:7)E
M:71A`$1I<F7GXV\@9&$@9&ER96ET82!P87)A(&5S<75E<F1A`$1I<F5T\W)I
M;P!%>&EB:7(`17AI8FER(&5M(&9O<FUA=&\@,C0@:&]R87,_`$]PY_5E<R!D
M92!%>&EB:>?C;P!%>&EB:7(@8V]N9FER;6'GXV\@87#S<R!E;G9I87(@=6UA
M(&UE;G-A9V5M/P!%>&EB:7(@<')E=FESXV\@9&5T86QH861A`$5X:6)I<B!P
M<F5V:7/C;R`H5$%&*0!%>&EB:7(@9F]R;6%T;P!%>&EB:7(@;F\@0V]R<&\@
M9&$@365N<V%G96T`17AI8FER('!O<"UU<"!D92!N;W1I9FEC8>?C;R!D92!N
M;W9A(&UE;G-A9V5M/P!%>&EB:7(@;R#M8V]N92`G07!A9V%R(%-P86US)R!N
M82!B87)R82!D92!M96YU<S\`17AI8FER(&\@[6-O;F4@)T5S=F%Z:6%R($QI
M>&5I<F$G(&YA(&)A<G)A(&1E(&UE;G5S/P!$:7-P;W-IY^-O`$YO=&EF:6-A
MY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.PT\@8V]R<F5S<&]N9&4`3N-O
M(%9E<FEF:6-A($YO=F%S($UE;G-A9V5N<R!N82AS*2!087-T82AS*0!.XV\@
M97AC;'5I<@!.XV\@86-E<W-E(&1I<F5T86UE;G1E(&UA:6YT96YA;F-E+G!H
M<`!.XV\@9V5R87(@=6T@;&EN:R!N82!C;VQU;F$@(D1E.B(`5F]CZB!Q=65R
M(&%B<FER(&5S=&$@<&%S=&$_`$$@<')I;65I<F$@;&EN:&$@8V]N=.EM(&]S
M(&YO;65S(&1O<R!C86UP;W,_(%-E('-I;2P@8VQI<75E(&YE<W1A(&-A:7AA
M.@!$;VUI;FEC86YA`%)E</IB;&EC82!$;VUI;FEC86YA`$[C;R!P;W-S=6D@
M=6UA(&-O;G1A/R!#861A<W1R92US92X`1F5I=&\`0F%I>&%R`$)A:7AA<B`E
M<P!"86EX87(@)7,@;F\@9F]R;6%T;R`N>FEP`$)A:7AA<B!T;V1O<R!A;F5X
M;W,@*&5M(&%R<75I=F\@+GII<"D`0F%I>&%R(%!A<W1A*',I`$)A:7AA<B!0
M87-T82AS*2!;9F]R;6%T;R`N>FEP70!"86EX87(@82!C;VYF:6=U<F'GXV\@
M9V5R861A(&-O;6\@=6T@<V-R:7!T(%!(4"X`0F%I>&%R(&5M(&9O<FUA=&\@
M+GII<`!287-C=6YH;P!087-T82`B4F%S8W5N:&]S(@!087-T82`B4F%S8W5N
M:&]S(CH`3&ES=&$@9&4@<V5L9>?C;P!$<F]G87,`0V]R<F5I;P!%;F1E<F7G
M;R!D92!E+6UA:6P`0V]N96-T;W(@9&\@9V%T97=A>2!%36%I;"UP87)A+5--
M4RP@<&%R82!O<&5R861O<F%S('%U92!D:7-P;VYI8FEL:7IA;2!E<W1E('-E
M<G9IYV\N`$9)30!%4E(`15)23SH@4W5A(&UE;G-A9V5M(&[C;R!P]&1E('-E
M<B!E;G1R96=U92X`17%U861O<@!%9&ET87(`161I=&%R($QI<W1A($YE9W)A
M`$5D:71A<B!";&]C;P!%9&ET87(@1FEL=')O<P!%9&ET87(@1W)U<&\`161I
M=&%R(%!E<FUI<W/C;P!%9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@4&5R;6ES
M<_5E<R!P87)A("5S`$5D:71A<B!396YT96[G82!D92!097-Q=6ES80!%9&ET
M87(@4&%S=&$@5FER='5A;`!%9&ET87(@1&5F:6YIY^-O(&1A(%!A<W1A(%9I
M<G1U86P@<&%R82`E<P!%9&ET87(@3&ES=&$@0G)A;F-A`$5D:71A<B!O<.?U
M97,@9&4Z`$5D:71A<B!P97)M:7-S]65S('!A<F$@)7,`161I=&%R('!E<FUI
M<W/U97,@<&%R82`E<P!%9&ET87(@<W5A(&QI<W1A(&YE9W)A`$5D:71A<B!S
M=6%S(')E9W)A<R!D92!F:6QT<F\`161I=&$@<W5A<R!P<F5F97+J;F-I87,@
M86\@86-E<W-A<B!O=71R87,@8V]N=&%S(&1E(&4M;6%I;"X`161I=&%R('-U
M82!L:7-T82!B<F%N8V$`161U8V'GXV\`16=I=&\`16P@4V%L=F%D;W(`16QE
M;65N=&\N+BX`16T`12UM86EL`$5N9&5R9>=O(&1E($4M36%I;`!/(&5N9&5R
M9>=O(&1E(&4M;6%I;"!D979E(&-O<G)E<W!O;F1E<BX`365N<V%G96T@8V]M
M(&-O;F9I<FUAY^-O`$=A=&5W87D@9&4@14UA:6PM<&%R82U335,`16UO=&EC
M;VYS`%1O9&%S(&UE;G-A9V5N<R!D92`E<R!F;W)A;2!E>&-L=>UD87,N`%1O
M9&%S(&%S(&UE;G-A9V5N<R!D82!,:7AE:7)A(%9I<G1U86P@9F]R86T@97AC
M;'7M9&%S+@!%<W9A>FEA<B!087-T82AS*0!%<W9A>FEA<B!087-T82AS*2!3
M96QE8VEO;F%D82AS*0!%<W9A>FEA<B!,:7AE:7)A`$%P86=A<B!37W!A;0!%
M<W9A>FEA<B!?3&EX96ER80!-96YS86=E;2!E;2!B<F%N8V\N`%)E<W5L=&%D
M;R!E;2!B<F%N8V\N`%1E<FUO<R!D92!P97-Q=6ES82!E;2!B<F%N8V\`2&%B
M:6QI=&%R(&9U;F-I;VYA;&ED861E(%!'4#\`2&%B:6QI=&%R(&9U;F-I;VYA
M;&ED861E(%,O34E-13\`2&%B:6QI=&%R(&EN<V5RY^-O(&1E(&EM86=E;G,@
M82!P87)T:7(@9&$@1V%L97)I82!D92!);6%G96YS(&YO('1E>'1O/P!(86)I
M;&ET87(@<'+I+79I<W5A;&EZ8>?C;R!D92!M96YS86=E;3\`2&%B:6QI=&%R
M(&UE;G4@9&4@8V]N=&5X=&\@8V]M(&\@8F]TXV\@9&ER96ET;S\`3W#G]65S
M(&1E(%]#<FEP=&]G<F%F:6$`0W)I<'1O9W)A9F%D;P!&:6YA;`!&:6YA;"!D
M82!M96YS86=E;2!E;F-A;6EN:&%D80!&:6YA;"!D82!M96YS86=E;0!&:6YA
M;"!D82!M96YS86=E;2!D92`E<P!&:6YA;"!D;R!A;F\`075M96YT87(@161I
M=&]R`$9O<FYEYV$@82!S96YH80!&;W)N9>=A('5M82!P97)G=6YT82!D92!S
M96=U<F%NYV$@82!Q=6%L('9O8^H@<V5RX2!P97)G=6YT861O('-E('9O8^H@
M;F5C97-S:71A<B!G97)A<B!U;6$@;F]V82!S96YH82P@97@N("=Q=6%L(&\@
M;F]M92!D;R!S974@8V%C:&]R<F\_)SH`1F]R;F7G82!A(%523"!D82!I;6%G
M96T@87%U:0!$:6=I=&4@87,@;&5T<F%S(&%B86EX;SH`1F]R;F7G82!O(&YO
M;64@9&4@<W5A(&YO=F$@<&%S=&$@9&4@<W!A;7,`1F]R;F7G82!O(&YO;64@
M9&4@<W5A(&YO=F$@<&%S=&$@9&4@<F%S8W5N:&]S`$9O<FYEYV$@;R!N;VUE
M(&1E('-U82!N;W9A('!A<W1A(&1E(&UE;G-A9V5N<R!E;G9I861A<P!&;W)N
M9>=A(&\@;F]M92!D92!S=6$@;F]V82!L:7AE:7)A`%1O9&$@82!-96YS86=E
M;0!296=I<W1R;R`B)7,B(&9O:2!A9&EC:6]N861O(&%O(&-A=.%L;V=O(&1E
M(&5N9&5R9>=O<R!C;VT@<W5C97-S;P!'=6ENZ2!%<75A=&]R:6%L`$5R:71R
MZ6EA`$5R<F\`17)R;R!C;VYE8W1A;F1O(&%O('-E<G9I9&]R($E-05`Z("5S
M.B`E<RX`17)R;R!A;R!C<FEA<B!B;&]C;SH@)7,`17)R;R!A;R!E>&-L=6ER
M(.)N8V]R82!D92!S:6YC<F]N:7IAY^-O.B`E<P!%<G)O(&%O(&5X8VQU:7(@
M;&]G(&1E('-I;F-R;VYI>F'GXV\Z("5S`$5R<F\@86\@;V)T97(@8V]N=&7Z
M9&\Z("5S`$5R<F\@86\@96YV:6%R(')E<W!O<W1A.B`E<RX`17)R;R!A;R!A
M='5A;&EZ87(@82!S96YH83H@)7,`17)R;R!N82!M96YS86=E;2X`17)R;R!G
M<F%V86YD;R`G)7,G+@!%<W3T;FEA`$5T:?-P:6$`R71N:6-O`$5U<F]P80!%
M=F5N=&\@97AC;'7M9&\@8V]M('-U8V5S<V\N`$-A9&$@,34@;6EN=71O<P!#
M861A(#(@;6EN=71O<P!#861A(#,P('-E9W5N9&]S`$-A9&$@-2!M:6YU=&]S
M`$-A9&$@0V]N97CC;P!#861A(&UE:6$@:&]R80!#861A(&UI;G5T;P!686QO
M<F5S(&1E(&5X96UP;&\Z`$5X96-U=&%R`$5X<&%N9&ER`$5X<&%N9&ER(%1O
M9&%S`$5X<&%N9&ER(%1O9&%S(%!A<W1A<P!%>'!A;F1I<B!087-T80!%>'!A
M;F1I<B!.;VUE<P!%>'!A;F1I<B!"87)R82!,871E<F%L`$5X<&%N9&ER(&YO
M;65S(&YA(&IA;F5L82!D92!C;VUP;W-IY^-O(&%U=&]M871I8V%M96YT92!E
M;2!S96=U;F1O('!L86YO/P!%>'!A;F1I<BP@<&]R('!A9'+C;RP@:6YT96ER
M86UE;G1E(&$@X7)V;W)E(&1E('!A<W1A<R!N82!V:7-U86QI>F'GXV\@9&4@
M<&%S=&%S/P!%>'!A;F1I;F1O`$5S<&5R861O("<I)P!%<W!E<F%D;R!U;6$@
M<&%L879R82!O=2!T97)M;R!D92!P97-Q=6ES82!E;G1R92!A<W!A<P!$871A
M(&1E($5X<&ER8>?C;P!%>'!O96YT90!#;W(@9&\@<')I;65I<F\@<&QA;F\`
M0V]N9FEG=7)AY^-O(&1E(&5N=FEO(&1E(&%R<75I=F]S($944`!4<F%Z97(@
M365N<V%G96YS`$9A;&AA(&]B=&5N9&\@<')E9F5RZFYC:6%S+@!&86QH82!A
M;R!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+@!&86QH82!A;R!C;VYE8W1A
M<B!A;R!S97)V:61O<B!334(N`$9A;&AA(&%O(&-O<&EA<B!D92`B)7,B+@!&
M86QH82!A;R!C;W!I87(@<&%R82`B)7,B+@!&86QH82!A;R!C<FEA<B!U;6$@
M;F]V82!C;VYE>.-O(%-!4TPN`$9A;&AA(&%O(&UO=F5R('!A<F$@(B5S(BX`
M1F%L:&$@86\@;V)T97(Z("5S`$IU<W1O`$EL:&%S($9A;&ML86YD("A-86QV
M:6YA<RD`26QH87,@1F%R;V4`17)R;R!&871A;#H`1F%X`$9A>&5S`$9E=F5R
M96ER;P!396YS8>?C;R!4Z7)M:6-A`%-E;G-AY^-O('3I<FUI8V$Z(`!4<F%Z
M97(@365N<V%G96YS`%1R87IE<B!M96YS86=E;G,@96T@=6UA(&IA;F5L82!S
M97!A<F%D83\`5')A>F5R(&UE;G-A9V5N<R!A;R!C;VYE8W1A<C\`)60@;65N
M<V%G96YS('1R87II9&%S(&1E("5S`#$@;65N<V%G96T@=')A>FED82!D92`E
M<P!4<F%Z97(@365N<V%G96YS.B``5')A>F5R($UE;G-A9V5N<SH@<V5M(&UE
M;G-A9V5N<R!N;W9A<RX`4&%N8V%D87,@9&4@0VAU=F$`3F5V92!&<F%C80!?
M1FEL=')O<P!-871R:7H@9&\@8V%M<&\`1FEG;&5T($-!4%1#2$$`1F]N=&4@
M1FEG;&5T`$9I:FD`07)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@
M87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,`1V5R
M96YC:6%D;W(@9&4@07)Q=6EV;W,`3F]M92!D;R!!<G%U:79O`%-E;&7GXV\@
M9&4@87)Q=6EV;P!%;G9I;R!D92!A<G%U:79O`$5N=FEO(&1E(&%R<75I=F]S
M(&[C;R#I('-U<&]R=&%D;RX`3W#G]65S(&1E($9I;'1R;P!#;VYF:6=U<F'G
M]65S(&1E($9I;'1R;P!&:6QT<F%R(&UE;G-A9V5M(&-O;2!C;VYT9?ID;R!O
M9F5N<VEV;S\`3R!S=7!O<G1E(&$@9FEL=')O<R!E<W3A(&1E<V%B:6QI=&%D
M;R!N97-T92!S:7-T96UA+@!&:6QT<F]S`$9I;'1R;W,@3L-/($%T:79O<P!&
M:6QT<F]S.B!PX6=I;F$@9&4@9V5R96YC:6%M96YT;R!D92`E<P!%;F-O;G1R
M87(`1FEN;.)N9&EA`%!R:6UE:7)A($UE=&%D90!0<FEM96ER82!0X6=I;F$@
M9&$@4&%S=&$`4')I;65I<F$@4.%G:6YA`%!R:6UE:7)O(%%U87)T;P!487AA
M(&9I>&$`1VER87(`1&ES<&]S:>?C;P!%;F-A;6EN7VAA<@!.Z79O80!087-T
M82`E<R!NXV\@97AI<W1E`$'G]65S(&1E(%!A<W1A<R`M($-O;F9I<FUAY^-O
M`$YA=F5G861O<B!D92!087-T87,`4F5S=6UO(&1E(%!A<W1A<P!/(&-O;7!A
M<G1I;&AA;65N=&\@9&4@<&%S=&%S(&[C;R!E<W3A(&AA8FEL:71A9&\N`$$@
M=71I;&EZ8>?C;R!D92!P87-T87,@;N-O(&5S=.$@:&%B:6QI=&%D82X`0V]R
M(&1A($9O;G1E`$-O;6ED80!087)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P
M;W)T86T@:6UA9V5N<P!0<F5V:7/C;R`H5$%&*0!$:6%S(%!R979I<W1O<R`H
M3F]T92!Q=64@82!P<F5V:7/C;R!R971O<FYA9&$@97AI8F4@86UB;W,@9&EA
M(&4@;F]I=&4[('5M(&[Z;65R;R!M=6ET;R!A;'1O(&%Q=6D@<&]D92!R97-U
M;'1A<B!E;2!U;2!B;&]C;R!E>'1E;G-O*0!%<W%U96-E=2!A('-E;FAA/P!&
M;W)M871O(&1A(&1A=&$@9&%S(&UE;G-A9V5N<R!N82!V:7-U86QI>F'GXV\@
M9&$@8V%I>&$@<&]S=&%L('!A<F$@;65N<V%G96YS(&1A=&%D87,@9&4@:&]J
M90!&;W)M=6SA<FEO<P!3;W)T90!4:7!O(&1E(%-O<G1E`%-O<G1E<P!3;W)T
M97,@,@!&\W)U;G,`16YC86UI;FAA<@!%;F-A;6EN:&%R.@!-96YS86=E;2!E
M;F-A;6EN:&%D80!-96YS86=E;2!E;F-A;6EN:&%D82!D92`E<P!2961I<F5C
M:6]N86UE;G1O<P!397@`475A9')O<P!&<F%NYV$`1G)A;N=A($UE=')O<&]L
M:71A;F$`4F5S<&]S=&$@9&$@4V]L:6-I=&'GXV\@9&4@26YF;W)M8>?C;R!,
M:79R92]/8W5P861O`$=U:6%N82!&<F%N8V5S80!0;VQI;NES:6$@1G)A;F-E
M<V$`5&5R<FET\W)I;W,@1G)A;F-E<V5S(&1O(%-U;`!?1&4`1&4`16YD97)E
MYV\@9&\@4F5M971E;G1E`$1O*&$I`$1E<V-R:>?C;R!#;VUP;&5T80!,=6$@
M0VAE:6$`3F]M92!#;VUP;&5T;P!%;F,Z`$5N8SH@`$5N8SH@)74@365N<V%G
M96YS($5N8V%M:6YH861A<P!'86+C;P!'86QE<FEA(&1E(&]N9&4@;V)T97(@
M87,@:6UA9V5N<P!'86QE<FEA.@!'XFUB:6$`3W#G]65S($=E<F%I<P!'97)A
M<B!A($-O;F9I9W5R8>?C;R!D92`E<P!#\V1I9V\@1V5R861O`$=E\W)G:6$`
M06QE;6%N:&$`3V)T97(@<V]M96YT92!N;W9A<R!M96YS86=E;G,_("AS;VUE
M;G1E($E-05`I`$=A;F$`1VEB<F%L=&%R`%!R:6UE:7)O($YO;64`3W#G]65S
M($=L;V)A:7,`27(`27(@<&%R82!A($UE;G-A9V5M`$ER('!A<F$@;R!R96=I
M<W1R;R!D;R!C873A;&]G;R!D92!E;F1E<F7G;W,@9&4@(B5S(@!';V5D96P`
M1V]O9VQE($UA<&%S`%!E<W%U:7-A<B!N;R!';V]G;&4`0V]N8V5D97(@86-E
M<W-O`$5S8V%L82!D92!#:6YZ87,`1W+I8VEA`$=R96=O("A)4T\M.#@U.2TW
M*0!'<F]E;.)N9&EA`$=R86YA9&$`061M:6YI<W1R8>?C;R!D92!'<G5P;W,`
M3F]M97,@9&4@9W)U<&]S(&[C;R!D979E;2!E<W1A<B!E;2!B<F%N8V\`1W)O
M=7!?;&1A<#H@26UP;W-S[79E;"!A9&EC:6]N87(@9W)U<&\@)7,N($ES=&\@
MZ2!O('%U92!O('-E<G9I9&]R(&1I<W-E.B``1W)O=7!?;&1A<#H@26UP;W-S
M[79E;"!E>&-L=6ER(&=R=7!O("5S`$=R;W5P7VQD87`Z($EM<&]S<^UV96P@
M871U86QI>F%R(&=R=7!O("5S`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!'=6%T
M96QA;6$`1W5E<FYS97D`4&5R;6ES<_5E<R!D92!#;VYV:61A9&\`3&EV<F\@
M9&4@5FES:71A<P!'=6ENZ0!'=6ENZ2U":7-S874`1W5I86YA`$%154D`2%1-
M3`!697)SXV\@2%1-3"!D82!-96YS86=E;0!(5$U,07)E82!S92!N96=A(&-O
M=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA
M+@!(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z
M;'1I;6$@8V]L=6YA(&1A('1A8F5L82X`2%1-3$%R96$@<V4@;F5G82!C;W9A
M<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA(&QI;FAA(&1A('1A8F5L82X`
M075T96YT:6-AY^-O($A45%`@;N-O(&5N8V]N=')A9&$N`$AA:71I`$%L9V]R
M:71M;R!(87-H`$YE8FQI;F$`0V%B9>=A;&AO`$-A8F7G86QH;W,`26QH82!(
M96%R9"!E($EL:&%S($UC1&]N86QD`%1E;7!E<W1A9&4@1F]R=&4`2&5B<F5U
M("A)4T\M.#@U.2TX+4DI`$%L='5R80!!:G5D80!!:G5D82!D;R!E9&ET;W(`
M07-S:7-T96YT90!(96UI<V;I<FEO`$%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A
M<G%U:79O.@!!<75I(&5S=.$@82!M96YS86=E;2!Q=64@=F]CZB!E<W1A=F$@
M8V]M<&]N9&\Z`$]C=6QT;P!/8W5L=&\@;F$@5FES=6%L:7IAY^-O('!O<B!$
M:7-C=7-SXV\`3V-U;'1A<B!%>&-L=>UD87,`3V-U;'1A<B!.XV\@26YS8W)I
M=&%S`$%L=&$`4')I;W)I9&%D92!!;'1A`$%L=.US<VEM80!)7V[M8VEO`%-A
M;G1A(%/I("A#:61A9&4M17-T861O(&1O(%9A=&EC86YO*0!);NUC:6\`16YD
M97)EYV\@4F5S:61E;F-I86P`1&ER973S<FEO(%!E<W-O86P`1F]N92!297-I
M9&5N8VEA;`!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M($1A9&\@6$U,("5S(&EN=N%L:61O(&5N8V]N=')A9&\@;F$@;65N<V%G96T@
M)7,`2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G96T@8V]R<F5S<&]N9&4@
M86\@;V)J971O("5S`$AO<F1E+TMO;&%B.B!.96YH=6T@;V)J971O(&1O('1I
M<&\@)7,@9F]I(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,`2&]R9&4O2V]L
M86(Z(%)E;6]V:61O(&-O;2!S=6-E<W-O("5S("(E<R(`2&]R9&4O2V]L86(Z
M($$@96YG:6YE(&1E(&EN=&5G<F'GXV\@<F5Q=65R(&$@97AT96YSXV\@4$A0
M("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L(&-R:6%R('5M82!N
M;W9A(.%R=F]R92!834P@<&%R82!O(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@
M26UP;W-S[79E;"!R96UO=F5R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!)
M;7!O<W/M=F5L(&]B=&5R(&$@:61E;G1I9FEC8>?C;R!-24U%('!A<F$@82!P
M87)T92!D;R!T:7!O("5S`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L('-I;F-R
M;VYI>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L('-I
M;F-R;VYI>F%R(&-O;7!A<G1I;&AA;65N=&]S.B`E<P!(;W)D92]+;VQA8CH@
M0V]M<&%R=&EL:&%M96YT;R!D97-C;VYH96-I9&\@(B5S(@!,:6YH82!(;W)I
M>F]N=&%L`$UA<F=E;2!H;W)I>F]N=&%L`$AO<FEZ;VYT86PZ`$-O;6\@=F]C
MZB!C:&5G;W4@87%U:3\@*%!O<B!F879O<B!C;VUU;FEQ=64A*0!#;VUO('9O
M8^H@9&5S96IA(&5X:6)I<B!A;F5X;W,_`%%U86YT87,@8V]L=6YA<R!V;V/J
M(&=O<W1A<FEA(&1E(&UE<V-L87(_`%%U86YT;W,@8V%M<&]S("AC;VQU;F%S
M*2!E>&ES=&5M/P!1=6%N=&%S(&QI;FAA<R!V;V/J(&=O<W1A<FEA(&1E(&UE
M<V-L87(_`$-O;6\@871R:6)U:7(@;&EN:&%S(&-I=&%D87,@96T@=6UA(')E
M<W!O<W1A`%5M:61A9&4`56UI9&%D93H@`$AU;6]R:7-T87,`2'5N9W+M80!)
M34%0`$E-05`@*$%U=&\@1&5T96-T87(@4')O=&]C;VQO<RD`3R!397)V:61O
M<B!)34%0(&9E8VAO=2!A(&-O;F5XXV\Z(&\@4V5R=FED;W(@4F5S<&]N9&5U
M.B`E<P!&86QH82!A;R!C<FEA<B!C86EX82!P;W-T86P@24U!4#H@)7,`1F%L
M:&$@86\@97AC;'5I<B!C86EX82!P;W-T86P@24U!4#H@)7,`1F%L:&$@86\@
M8W)I87(@<75O=&$@9&$@8V%I>&$@<&]S=&%L($E-05`Z("5S`$E-05`@<V]B
M<F4@4U-,`$E-05`@<V]B<F4@4U-,("AC97)T:69I8V%D;R!A=71O+6%S<VEN
M861O*0!)34%0('-O8G)E(%-33"`H875T;RUA<W-I;F%D;RD`3R!S97)V:61O
M<B!)34%0(&9E8VAO=2!A(&-O;F5XXV\N`$E-05`L('-E;2!43%,`4V5R=FED
M;W)E<R!D92!#;W)R96EO($E-05`O4$]0,P!#86EX82!D92!%;G1R861A`$5N
M9&5R9>=O($E0`$5N9&5R9>=O($E0(&[C;R!D:7-P;V[M=F5L+@!%;F1E<F7G
M;R!)4"!NXV\@97-TX2!N;R!B;&]C;R!P97)M:71I9&\@0TE$4BX`5FEO;&'G
MXV\@9&\@8FQO<75E:6\@25`N`$E?;G-I<F$@3&EN:&$@06YT97,`27-LXFYD
M:6$`4V]M96YT92#-8V]N97,`S6-O;F5S('!A<F$@)7,`S6-O;F5S(&4@=&5X
M=&\`3F]M92!D82!I9&5N=&ED861E.@!392!NXV\@9F]R(&5X:6)I9&\@8V]R
M<F5T86UE;G1E+"`E<R!P87)A(&%B<NTM;&\@96T@=6UA(&YO=F$@:F%N96QA
M+@!392!E<W1I=F5R('5T:6QI>F%N9&\@4U-,(&]U(%1,4RP@82!E>'1E;G/C
M;R!O<&5N<W-L(&1O(%!(4"!D979E(&5S=&%R(&-A<G)E9V%D82X`5&]D87,@
M87,@;65N<V%G96YS(&YA*',I('!A<W1A*',I('-E<N-O('!E<F1I9&%S(0!3
M92!V;V/J(&[C;R!VZB!N96YH=6T@[6-O;F4@86\@=71I;&EZ87(@;R!);G1E
M<FYE="!%>'!L;W)E<BP@=F]CZB!P;V1E(&-H96-A<B!E<W1A(&-A:7AA('!A
M<F$@9&5S86)I;&ET87(@82!T<F%N<W!A<NIN8VEA(%!.1RX`4V4@=F]CZB!V
MZB!E<W1A(&UE;G-A9V5M(&UA<R!NXV\@82!I;6%G96TL(&$@:6UA9V5M('%U
M92!V;V/J('%U97(@96YV:6%R(&[C;R!P;V1E('-E<B!E>&EB:61A('!E;&\@
M<V5U(&YA=F5G861O<BX`26=N;W)A<@!)9VYO<F%R(%1O9&%S`$EM86=E;0!0
M<NDM=FES=6%L:7IAY^-O(&1A($EM86=E;3H`55),(&1A($EM86=E;0!54DP@
M9&$@26UA9V5M.@!);6%G96T@9&$@9V%L97)I80!);6%G96T@9&$@9V%L97)I
M83H`16YV:6\@9&4@26UA9V5M`$EM86=E;G,`26UP;W)T87(`26UP;W)T87(@
M0VAA=F4`26UP;W)T87(@4&%R(&1E($-H879E<P!);7!O<G1A<B!-96YS86=E
M;G,`26UP;W)T87(@0VAA=F4@4$=0`$EM<&]R=&%R($-E<G1I9FEC861O<R!0
M97-S;V%I<P!);7!O<G1A<B!#:&%V92!0<FEV861A(%!'4"!097-S;V%L`$EM
M<&]R=&%R($-H879E(%#Z8FQI8V$@4$=0(%!E<W-O86P`26UP;W)T87(@0V5R
M=&EF:6-A9&]S(%,O34E-12!097-S;V%I<P!);7!O<G1A<B!#:&%V92!0^F)L
M:6-A`$EM<&]R=&%R($-H879E(%#Z8FQI8V$@4$=0`$EM<&]R=&%R($-H879E
M(%#Z8FQI8V$@4R]-24U%`$EM<&]R=&%R($-H879E(%,O34E-10!);7!O<G1A
M<B!!<G%U:79O(&UB;W@`26UP;W)T87(@87)Q=6EV;R!M8F]X("5S('!A<F$@
M82!P87-T82`E<RX`26UP;W)T87(L(%!A<W-O("5D`$EM<&]R=&%N=&4`365N
M<V%G96YS(&EM<&]R=&%N=&5S`"5D(&UE;G-A9V5N<R!I;7!O<G1A9&%S(&1E
M("5S+@!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O<R!I;7!O<G1A9&]S.@!0
M<F]C97-S86YD;P!);E]S97)I<B!,:6YH82!!</-S`$-A:7AA(&1E($5N=')A
M9&$`26YC;'5I<B!U;2!B<F5V92!R97-U;6\@9&\@8V%B9>=A;&AO(&YA(')E
M<W!O<W1A/P!);F-L=6ER(&UE;G-A9V5M(&]R:6=I;F%L(&YA(')E<W!O<W1A
M/P!#\V1I9V\@9&4@8>?C;R!F;W)N96-I9&\@97-TX2!I;F-O<G)E=&\N`%5S
M=>%R:6\@92]O=2!S96YH82!I;F-O<G)E=&]S+@!5<W7A<FEO(&]U(&5N9&5R
M9>=O(&%L=&5R;F%T:79O(&EN8V]R<F5T;W,N(%1E;G1E(&YO=F%M96YT92!O
M=2!E;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(@<V4@=F]C
MZB!N96-E<W-I=&$@9&4@;6%I<R!A:G5D82X`075M96YT87(@261E;G1AY^-O
M`,UN9&EA`%5S=>%R:6]S(&EN9&EV:61U86ES`$EN9&]NZ7-I80!);F9O<FUA
MY^-O`$EN9F]R;6'GXV\`3N-O(&5X:7-T96T@;W#G]65S(&1I<W!O;NUV96ES
M+@!);F9O<FUAY^-O('-O8G)E(&$@0VAA=F4@4/IB;&EC82`E<P!);F9O<FUA
MY^-O('-O8G)E($-H879E(%!R:79A9&$@4&5S<V]A;`!);F9O<FUAY^-O('-O
M8G)E($-H879E(%#Z8FQI8V$@4&5S<V]A;`!);F-O<G!O<F%D;P!);G-E<FER
M($-?;VQU;F$@07#S<P!);G-I<F$@;R!#97)T:69I8V%D;R!!<75I`$EN<V5R
M:7(@26UA9V5M`$EN<VER82!A($-H879E(%!R:79A9&$@4$=0(%!E<W-O86P@
M07%U:0!);G-I<F$@82!#:&%V92!0^F)L:6-A(%!'4"!097-S;V%L($%Q=6D`
M26YS:7)A(&$@0VAA=F4@4/IB;&EC82!01U`@07%U:0!);G-E<FER(%1A8F5L
M80!);G-E<FER($QI;FL@9&$@5V5B`$EN<V5R:7(@7T-O;'5N82!!;G1E<P!)
M;G-E<FER('5M82!N;W9A(&-O;'5N82!A</-S(&$@871U86P`26YS97)I<B!U
M;6$@;F]V82!C;VQU;F$@86YT97,@9&$@871U86P`26YS97)I<B!U;6$@;F]V
M82!L:6YH82!A</-S(&$@871U86P`26YS97)I<B!U;6$@;F]V82!L:6YH82!A
M;G1E<R!D82!A='5A;`!);G-E<FER('5M('!A<N%G<F%F;R!A</-S(&\@871U
M86P`26YS97)I<B!U;2!P87+A9W)A9F\@86YT97,@9&\@871U86P`26YS97)I
M<B!U;2!M;V1E;&\@86QT97)N871I=F\`1F]R;F7G82!U;2!E;F1E<F7G;R!D
M92!E+6UA:6P@;F\@<75A;"!V;V/J('!O9&4@<F5C96)E<B!A(&YO=F$@<V5N
M:&$Z`$EN<V5R:7(@8^EL=6QA(&%P\W,`26YS97)I<B!CZ6QU;&$@86YT97,`
M26YS97)I<B!C;VQU;F$@87#S<P!);G-E<FER(&-O;'5N82!A;G1E<P!);G-E
M<FER(&UE;G-A9V5N<P!);G-E<FER('!A<N%G<F%F;R!A</-S`$EN<V5R:7(@
M<&%RX6=R869O(&%N=&5S`$EN<V5R:7(@;&EN:&$@87#S<P!);G-E<FER(&QI
M;FAA(&%N=&5S`$9O<FYEYV$@82!R97-P;W-T82!O8G)I9V%T\W)I82!P87)A
M(&$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A.@!);G-E<FER+T%L=&5R87(@26UA
M9V5M`$EN<V5R:7(O06QT97)A<B!,:6YK`$-RZ61I=&\@:6YS=69I8VEE;G1E
M('!A<F$@96YV:6%R('!A<F$@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N`$-R
MZ61I=&\@:6YS=69I8VEE;G1E+@!.^FUE<F\@26YT96ER;P!,:7-T82!D92!)
M;G1E:7)O<P!!Y^-O(&EN=N%L:61A('-E;&5C:6]N861A('!A<F$@97-T92!C
M;VUP;VYE;G1E+@!%;F1E<F7G;R!);G;A;&ED;P!#86EX82!0;W-T86P@4F5M
M;W1A(&EN=N%L:61A`$-$52`H0V%B9>=A;&AO(&1E($1A9&]S(&1E(%5S=>%R
M:6\I(&EN=N%L:61O+@!$861O<R!:25`@:6YVX6QI9&]S`$%P;&EC8>?C;R!I
M;G;A;&ED82X`261E;G1I9FEC8>?C;R!D;R!B871C:"!I;G;A;&ED82X`0V%R
M86-T97(@:6YVX6QI9&\@;F\@96YD97)EYV\@9&4@92UM86EL.B`E<RX`1&%D
M;W,@96YV:6%D;W,@<^-O(&EN=N%L:61O<RX`16YD97)EYV\@9&4@9&5S=&EN
M;R#I(&EN=N%L:61O+@!&;W)M871O(&1O(&%R<75I=F\@Z2!I;G;A;&ED;P!#
M:&%V92!I;G;A;&ED80!.^FUE<F\@9&4@;&EC96[G82!I;G;A;&ED;RX`3&]C
M86QI>F'GXV\@9F]R;F5C:61A(.D@:6YVX6QI9&$N`%1I<&\@9&$@;65N<V%G
M96T@Z2!I;G;A;&ED;RX`07!I7VED(.D@:6YVX6QI9&\@;W4@97-TX2!F86QT
M86YD;RX`4&%RXFUE=')O<R!I;G;A;&ED;W,@;W4@9F%L=&%N9&\N`%!E<FUI
M<W/U97,@9&\@<&%I('/C;R!I;G;A;&ED87,N`%!E<FUI<W/U97,@9&\@<&%I
M('/C;R!I;G;A;&ED87,N`$-H879E(%!R:79A9&$@4$=0(%!E<W-O86P@:6YV
MX6QI9&$N`$-H879E(%#Z8FQI8V$@4$=0(%!E<W-O86P@:6YVX6QI9&$N`$/S
M9&EG;R!D;R!P<F]D=71O(.D@:6YVX6QI9&\N`%!R;W1O8V]L;R!I;G;A;&ED
M;RX`1&5S=&EN873A<FEO(&EN=N%L:61O.B`G)7,G`$]B:F5T;R!C;VUP87)T
M:6QH861O(&EN=N%L:61O`$9O;G1E(&1O(&5N9&5R9>=O(&EN=N%L:61A+@!$
M861O<R!U;FEC;V1E(&EN=N%L:61O<RX`26YV96YTX7)I;P!);G9E<G1E<@!)
M;G9E<G1E<B!S96QEY^-O`$ERXRP@4F5P^F)L:6-A($ES;.)M:6-A(&1O`$ER
M87%U90!)<FQA;F1A`$EL:&$@9&\@2&]M96T`5&5M<&5S=&%D97,@27-O;&%D
M87,`27-R865L`$5M:7-S;W(`273A;&EC;P!)=.%L:6$`2F%M86EC80!*86YE
M:7)O`$IA<.-O`$IA<&]NZG,@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9.)N
M:6$`2G5L:&\`2G5N:&\`2G5S=&EF:6-A<@!!;&EN:&%R(&%O($-E;G1R;P!*
M=7-T:69I8V%R`$%L:6YH87(@X"!%<W%U97)D80!!;&EN:&%R(.`@1&ER96ET
M80!+0@!#87IA<75I<W3C;P!-86YT97(@;R!O<FEG:6YA;#\`477J;FEA`%-E
M<G9I9&]R(&ME<F)E<F]S(')E:F5I=&]U(&$@875T96YT:6-AY^-O+@!.;W9A
M=&]S(&1E($ME<FYE;`!#<FEAY^-O(&1E($-H879E`$EM<')E<W/C;R!$:6=I
M=&%L(&1A($-H879E`%1A;6%N:&\@9&$@0VAA=F4`5&EP;R!D82!#:&%V90!5
M<V\@9&$@0VAA=F4`0VAA=F4@:N$@97AI<W1E(&YO('-E<G9I9&]R(&1E(&-H
M879E<R!P^F)L:6-A<RX`02!G97)AY^-O(&1E(&-H879E(&1E=F4@;&5V87(@
M;75I=&\@=&5M<&\@<&%R82!T97)M:6YA<BX@0V]N=&EN=6%R(&-O;2!A(&=E
M<F'GXV\@9&4@8VAA=F4_`$$@:6UP;W)T8>?C;R!NXV\@97-TX2!D:7-P;V[M
M=F5L+B!/(&5N=FEO(&1E(&%R<75I=F]S(&[C;R!E<W3A(&AA8FEL:71A9&\@
M;F5S=&4@<V5R=FED;W(N`$$@:6UP;W)T8>?C;R!NXV\@97-TX2!D:7-P;V[M
M=F5L+B!6;V/J(&[C;R!T96T@=6T@8V%TX6QO9V\@9&4@96YD97)EYV]S(&1E
M9FEN:61O('!A<F$@861I8VEO;F%R('-E=7,@8V]N=&%T;W,N`$-H879E(&5N
M=FEA9&$@8V]M('-U8V5S<V\@<&%R82!O('-E<G9I9&]R(&1E(&-H879E<R!P
M^F)L:6-A<RX`0W)I86[G87,`2VER:6)A=&D`0V]RZ6EA+"!297#Z8FQI8V$@
M4&]P=6QA<B!$96UO8W+A=&EC82!D80!#;W+I:6$L(%)E</IB;&EC82!D80!#
M;W)E86YO("A%54,M2U(I`$MU=V%I=`!1=6ER9W5I<W3C;P!,85]Y;W5T`$ED
M:6]M80!,86\@4F5P^F)L:6-A($1E;6]C<N%T:6-A(%!O<'5L87(`VFQT:6UA
M($UE=&%D90#:;'1I;6$@4.%G:6YA(&1A(%!A<W1A`-IL=&EM82!0X6=I;F$`
M1V5R87(@3F]V82!396YH80#:;'1I;6\@475A<G1O`-IL=&EM82!!='5A;&EZ
M8>?C;SH`VFQT:6UO(&QO9VEN.B`E<P#:;'1I;6\@;&]G:6XZ("5S(.`@<&%R
M=&ER(&1E("5S`-IL=&EM;R!L;V=I;CH@3G5N8V$`3&5T]&YI80!,96D`3&%Y
M;W5T`$1E:7AA('9A>FEO('-E('%U:7-E<B!S96T@8F]R9&$`3.UB86YO`$5S
M<75E<F1A`$-A8F7G86QH;R!E<W%U97)D;P!686QO<F5S(&1A(&5S<75E<F1A
M`$QE<V]T;P!!;6]R`$QI8NER:6$`3.UB:6$@P7)A8F4@2F%M86AI<FEY80!,
M:65C:'1E;G-T96EN`$-H:79I<V-O1G)A8V\`0VAU=F$@1G)A8V$`0VAU=F$@
M1G)A8V$@36%T=71I;F$`0VAU=F$@1G)A8V$@5F5S<&5R=&EN80!,979E<R!0
M86YC861A<R!D92!#:'5V80!#:'5V87,@1G)A8V%S(&-O;2!4<F]V]65S`$YE
M=F4@1G)A8V$`0G)E=F4@3F5V87-C80!0;^IM87,`3&EN:P!#<FEA<B!L:6YK
M<R!P87)A($%N97AO<S\`3&EN:R!A<&]N=&$@<&%R83H`3&EG87(@;R!E;F1E
M<F7G;R!D92!E+6UA:6P@X"!PX6=I;F$@9&4@8V]M<&]S:>?C;R!A;R!E>&EB
M:7(`3&EN:W,@9&4@86YE>&]S(&[C;R!SXV\@<&5R;6ET:61O<RX`3&EN:W,`
M3W,@;&EN:W,@97AP:7)A<N-O(&5M("5S`$-O;VMI92!D;R!,:6YU>`!,:7-T
M87(@+2!U<W7A<FEO('!O9&4@=F5R(&$@<&%S=&$`3&ES=&%R($)A;F-O<R!D
M92!$861O<P!,:7-T87(@5/-P:6-O<R!D92!!:G5D80!,:7-T87(@5&%B96QA
M<P!,:7-T87(@=&]D;W,@8V]N=&%T;W,@<75A;F1O(&-A<G)E9V%R(&$@=&5L
M82!D92!C;VYT871O<S\@*'-E(&1E<V%B:6QI=&%D;RP@=F]CZB!V97+A('-O
M;65N=&4@8V]N=&%T;W,@<75E('9O8^H@97AP;&EC:71A;65N=&4@<&5S<75I
M<V%R*0!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE
M<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,
M:7-T86YD;R!N;R!#86)EYV%L:&\`02!L:7-T86=E;2!D92!S97-S]65S(&9A
M;&AO=3H@)7,`02!L:7-T86=E;2!D92!U<W7A<FEO<R!F86QH;W4Z("5S`$QI
M<W1A9V5M(&1E('5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861A+@!,:71E<F%T
M=7)A`$QI='7B;FEA`$-A<G)E9V%N9&\N+BX`0V%I>&$@4&]S=&%L($QO8V%L
M.@!(;W)A(&QO8V%L.B``3&]C86QI>F'GXV\@92!(;W)A`%)E9VGC;P!#;VYE
M8W1A<@!#;VYE8W1A<B!A("5S`$QO9R!D82!S97-SXV\@9&4@<VEN8W)O;FEZ
M8>?C;R!A;G1E<FEO<@!$97-C;VYE8W1A<@!#;VYE8W1A<@!487)E9F%S(&1E
M($-O;F5XXV\`3R!L;V=I;B!F86QH;W4@<&]R<75E('-E=2!U<W7A<FEO(&]U
M('-E;FAA(&5S=&%V82!I;F-O<G)E=&$N`$9A;&AA(&1E($QO9VEN+@!497AT
M;R!L;VYG;P!!;6]R`$)A:7AA`%!R:6]R:61A9&4@0F%I>&$`06QF86)E=&\@
M9W)E9V\@96T@;6EN^G-C=6QO`$%L9F%B971O(&QA=&EN;R!E;2!M:6[Z<V-U
M;&\`3OIM97)O<R!R;VUA;F]S(&5M(&UI;OIS8W5L;P!"86EX[7-S:6UA`$QU
M>&5M8G5R9V\`34T`34]41`!/(&%N97AO($U3+51.148@;N-O(&-O;G3I;2!D
M861O<RX`35-'`$UA8V%O`$UA8V5D;VYI82P@06YT:6=A(%)E</IB;&EC82!)
M=6=O<VSA=FEA(&1A`$%R<75I=F\@36%C:6YT;W-H`$UA9&%G87-C87(`3>%G
M:6-O`$-O<G)E:6\`061M:6YI<W1R861O<B!D;R!#;W)R96EO`%!RZ2UV:7-U
M86QI>F'GXV\@9&4@365N<V%G96YS`%1I<&\@9&4@<V5R=FED;W(@9&4@8V]R
M<F5I;R!A(&-O;F5C=&%R.@!#86EX82!0;W-T86P`3W#G]65S(&1E(%9I<W5A
M;&EZ8>?C;R!D92!#86EX82!0;W-T86P@92!087-T87,`0W)I87(@;&EN7VLN
M+BX`36%L87=I`$UA;.%S:6$`36%L9&EV87,`36%L:0!-86QT80!'97)E;F-I
M82!A(&QI<W1A(&1E(&-A=&5G;W)I87,@92!A<R!C;W)E<R!A<W-O8VEA9&%S
M(&$@96QA<RX`36%P96%M96YT;R!-87`R-`!-87!E86UE;G1O($UA<%%U97-T
M`$UA<&5A;65N=&]S(&=R879A9&]S+@!-87+G;P!-87)G96T`36%R8V%R(&-O
M;6\@3&ED87,@5&]D87,@87,@365N<V%G96YS(&YA(%!A<W1A`$UA<F-A<B!C
M;VUO($[C;R!,:61A<R!4;V1A<R!A<R!-96YS86=E;G,@;F$@4&%S=&$`36%R
M8V%R(&-O;6\Z`$UA<F-A<B!D:69E<F5N=&5S(&[M=F5I<R!D92!C:71AY^-O
M(&-O;2!D:69E<F5N=&5S(&-O<F5S/P!-87)C87(@;65N<V%G96YS(&-O;6\@
M;&ED87,_("AS;VUE;G1E($E-05`I`%)E<W-A;'1A<B!M87)C861O<B!S:6UP
M;&5S/P!-87)C87(@8V]M(&9L86=S($QI9&$O3N-O($QI9&$`36%R8V%R(&-O
M;2!O=71R;W,@9FQA9W,@*&5X+B!);7!O<G1A;G1E+U)E<W!O;F1I9&$I`$EL
M:&%S($UA<G-H86QL`$UA<G1I;FEC80!#;VEN8VED:7(@=&]D87,`0V]I;F-I
M9&ER('%U86QQ=65R('5M80!#86UP;W,@8V]R<F5S<&]N9&5N=&5S`$UA=7)I
M=.)N:6$`36%U<NUC:6\`0W+I9&ET;R!MX7AI;6\@<&5R;6ET:61O+@!.^FUE
M<F\@;>%X:6UO(&1E('!A<G1E<R!D82!M96YS86=E;2!E>&-E9&5U+@!496UP
M97)A='5R82!MX7AI;6$@;F%S(/IL=&EM87,@,C0@:&]R87,Z(`!496UP97)A
M='5R82!MX7AI;6$@;F%S(/IL=&EM87,@-B!H;W)A<SH@`%1A;6%N:&\@3>%X
M:6UO(&1E($%N97AO`$[Z;65R;R!-X7AI;6\@9&4@4&%S=&%S`$[Z;65R;R!-
MX7AI;6\@9&4@0FQO8V]S(&1E(%!O<G1A;`!486UA;FAO(&WA>&EM;P!.^FUE
M<F\@;>%X:6UO(&1E(&%N97AO<R!A=&EN9VED;RX`5&%M86YH;R!MX7AI;6\@
M9&4@86YE>&]S(&%T:6YG:61O+@!-86EO`$UA>6]T=&4`365D:6-I;F$`365M
M8G)O<P!-96YU(&1E($QI<W1A(&1E(%!A<W1A<P!-;V1O(&1O(&UE;G4Z`$UE
M<V-L87(@8^EL=6QA<P!-96YS86=E;0!#;VUP;W-IY^-O(&1E($UE;G-A9V5M
M`$1A=&$@9&$@365N<V%G96T`3W#G]65S(&1E($UE;G-A9V5M`%!E<W%U:7-A
M<B!-96YS86=E;G,`5&%M86YH;R!D82!-96YS86=E;0!#\V1I9V\@1F]N=&4@
M9&$@365N<V%G96T`365N<V%G96T@5F5R:69I8V%D82!C;VT@4W5C97-S;R!M
M87,@;R!C97)T:69I8V%D;R!D;R!A<W-I;F%N=&4@;N-O('#T9&4@<V5R('9E
M<FEF:6-A9&\N`%9I<W5A;&EZ8>?C;R!D82!-96YS86=E;0!-96YS86=E;2!E
M>'!I<F%D82X`36%R8V%D;W)E<R!D82!M96YS86=E;0!087-T87,@9&4@;65N
M<V%G96T`365N<V%G96T@9&4@)7,`02!M96YS86=E;2!T96T@86YE>&]S`$$@
M;65N<V%G96T@97-TX2!C<FEP=&]G<F%F861A`$$@;65N<V%G96T@97-TX2!A
M<W-I;F%D80!-96YS86=E;2!C;W)R97-P;VYD90!-96YS86=E;2!R961I<F5C
M:6]N861A(&-O;2!S=6-E<W-O+@!-96YS86=E;2!E;G9I861A(&-O;2!S=6-E
M<W-O+"!M87,@;N-O(&9O:2!S86QV82!E;2`E<P!-96YS86=E;2!E;G9I861A
M(&-O;2!S=6-E<W-O+@!4:7!O(&1E(&UE;G-A9V5M`$UE;G-A9V5N<R!P;W(@
M<.%G:6YA(&YA('9I<W5A;&EZ8>?C;R!D82!C86EX82!P;W-T86PN`$UE;G-A
M9V5N<R!P87)A`$-L:6UA($UE=&%R`$)L;V-O($UE=&%R(&[C;R!D:7-P;V[M
M=F5L+@!";&]C;R!-971A<B!NXV\@9&ES<&]N[79E;"X@1&5T86QH97,@9F]R
M86T@9W)A=F%D;W,@96T@;&]G('!A<F$@;R!A9&UI;FES=')A9&]R+@!/($UE
M=&%R1$(@;N-O(&5S=.$@8V]N96-T861O+@!-Z71O9&\`3>ET;V1O("<E<R<@
M;N-O(&5S=.$@9&5F:6YI9&\`3>ET;V1O(&[C;R!D969I;FED;RX@3>ET;V1O
M(&-H86UA9&\Z("5S`$WI=')I8V$`3>EX:6-O`$UI8W)O;NES:6$L($5S=&%D
M;W,@1F5D97)A9&]S(&1A`$UE:6\`5&EP;R!-:6UE`%1E;7!E<F%T=7)A(&WM
M;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E<F%T=7)A(&WM;FEM
M82!N87,@^FQT:6UA<R`V(&AO<F%S.B``261A9&4@;>UN:6UA(&1A('-E;FAA
M(&%I;F1A(&[C;R!E>'!I<F]U`$5S<&5L:&\`1&EV97)S;W,`4&%C;W1E(%!%
M05(@2%144%]297%U97-T(&9A;'1A;F1O+@!#;VYF:6=U<F'GXV\@9F%L=&%N
M9&\N(%9O8^H@=&5M('%U92!G97)A<B!E;&$@86=O<F$@<V4@=F]CZB!Q=65R
M('5T:6QI>F%R(&5S=&$@87!L:6-AY^-O+@!)1"!D82!M96YS86=E;2!F86QT
M86YD;RX`4&%C;W1E(&]B<FEG873S<FEO(%!%05(@36%I;"!F86QT86YD;RX`
M240@9&$@<V5S<^-O(&9A;'1A;F1O+@!396<`0V]R<F5I;R!-\W9E;`!-;V1E
M<F%R`$1A=&$@36]D:69I8V%D80!!;'1E<F%R`$%L=&5R87(@55),`$WS9'5L
M;P!-;VQD;W9A+"!297#Z8FQI8V$@9&$`3?1N86-O`$UO;F?S;&EA`$WJ<R!E
M(&%N;P!-96YS86QM96YT90!-;VYT<V5R<F%T`$9A<V5S(&1A($QU80!-86ES
M(&-A;7!O<R!E;F-O;G1R861O<R!N82!L:6YH82`E9"!Q=64@;R!N^FUE<F\@
M97-P97)A9&\@)60N`$UA:7,@9&4@=6T@96YD97)EYV\@96YC;VYT<F%D;R!N
M;R!C86UP;R`G)7,G+@!-87)R;V-O<P!'<F%N9&4@4&%R=&4@3&EM<&$`1W)A
M;F1E(%!A<G1E($YU8FQA9&\`1W)A;F1E(%!A<G1E($5N<V]L87)A9&\`36]V
M97(`36]V97(@06)A:7AO`$UO=F5R(.`@17-Q=65R9&$`36]V97(@X"!$:7)E
M:71A`$UO=F5R($%C:6UA`$%B86EX;P!-;W9E<B!S<&%M<R!P87)A(&$@<&%S
M=&$@<W!A;2!E(&UE;G-A9V5N<R!I;F]C96YT97,@<&%R82!A($-A:7AA(&1E
M($5N=')A9&$`36]V97(@<&%R82!A('!A<W1A`$%C:6UA`$UOYV%M8FEQ=64`
M3&ES=&%S(&1E('-E;&7GXV\@9&4@;?IL=&EP;&]S(&[M=F5I<P!-87!A<R!)
M;F=L97-E<R!-=6QT:6UA<`!-=6QT:7!A<G0O86QT97)N871I=F4`5FES=6%L
M:7IAY^-O(&1E($WZ;'1I<&QA<R!-96YS86=E;G,`4V5L9>?C;R!M^FQT:7!L
M80!-:6YH82!#;VYT80!3=6%S($EN9F]R;6'G]65S`$UE=2!0;W)T86P`365U
M($QA>6]U="!D92!0;W)T86P`0FER;>)N:6$`3L-/+"!%=2!.PT\@0V]N8V]R
M9&\`3D5.2%5-`$Y/5$$`3F]M90!.;VUE(&4O;W4@92UM86EL(&[C;R!P;V1E
M('-E<B!V87II;P!.86WM8FEA`$YA=7)U`$YE8V5S<VET82!D92!!Y^-O`$YE
M<&%L`$AO;&%N9&$`06YT:6QH87,@2&]L86YD97-A<P!54DP@0F%S92!D;R!.
M971S8V%P90!54DP@9&4@4F5V;V=AY^-O(&1E($-!(&1O($YE='-C87!E`%52
M3"!D92!P;VSM=&EC87,@9&4@0T$@9&\@3F5T<V-A<&4`55),(&1E(%)E;F]V
M8>?C;R!D;R!.971S8V%P90!54DP@9&4@4F5V;V=AY^-O(&1O($YE='-C87!E
M`$YO;64@9&\@<V5R=FED;W(@4U-,(&1O($YE='-C87!E`$-O;65N=.%R:6\@
M9&\@8V5R=&EF:6-A9&\@9&\@3F5T<V-A<&4`5&EP;R!D92!C97)T:69I8V%D
M;R!D;R!.971S8V%P90!2961E`$YU;F-A`$YU;F-A('-A;'9A<B!A;F5X;W,`
M3F]V80!.;W9A($-A;&5D]&YI80!.;W9A($-A=&5G;W)I80!.;W9A(%!A<W1A
M`$YO=F$@365N<V%G96T`3F]V82!-96YS86=E;0!.;W9A($UE;G-A9V5M('!A
M<F$@)7,`3'5A($YO=F$`3F]V;R!5<W7A<FEO("AO<&-I;VYA;"D`3F]V82!:
M96SB;F1I80!.;W9A<R!M96YS86=E;G,`3F]V82!S96YH80!.;W9A('-E;FAA
M(&5X<&ER87+A(&5M("5X+@!!<R!N;W9A<R!S96YH87,@;N-O('/C;R!I9W5A
M:7,N`$YO=F$@:F%N96QA("A?8FQA;FLI`$YO=.UC:6%S`$=R=7!O<R!D92!.
M;W3M8VEA<P!0<O-X:6UA`%!R\WAI;6%S(#0@1F%S97,`4'+S>&EM82!-96YS
M86=E;0!0<O-X:6UA(%#A9VEN80!0<O-X:6UA<R!O<.?U97,`4'+S>&EM83X`
M3FEC87+A9W5A`$YI9V5R`$YI9^ER:6$`3F]I=&4`3FEU90!.XV\`3F5N:'5M
M($-E<G1I9FEC861O(&5N8V]N=')A9&\`4V5M($-R:7!T;V=R869I80!396T@
M0VAA=F5S(&YO($-H879E:7)O`%-E;2!-96YS86=E;G,`3F5N:'5M82!C:&%V
M92!P^F)L:6-A(%!'4"!I;7!O<G1A9&$N`$YE;FAU;2!#97)T:69I8V%D;R!0
M97-S;V%L(%!R97-E;G1E`%-E;2!0<NDM=FES=6%L:7IAY^-O(&1E(%1E>'1O
M`$YE;FAU;6$@0VAA=F4@4/IB;&EC82!%;F-O;G1R861A`$YE;FAU;6$@8VAA
M=F4@</IB;&EC82!3+TU)344@:6UP;W)T861A+@!.96YH=6T@86YE>&\@96YC
M;VYT<F%D;RX`3F5N:'5M(&1A9&\@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV
M96P@<&%R82!E>&EB:7(@87,@9&EF97)E;N=A<RX`3F5N:'5M82!E<W1R873I
M9VEA(&1I<W!O;NUV96P@<&%R82!C<FEA<B!I;6%G96YS($E33RX`3F5N:'5M
M(&UO9&5L;R!D92!B871C:"X`3F5N:'5M(&)L;V-O(&5X:7-T92!N82!P;W-I
MY^-O('-O;&EC:71A9&$`3F5N:'5M(&YO;64@9&4@86=E;F1A(&9O<FYE8VED
M;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN`$YE;FAU;6$@86QT97)AY^-O
M+@!.96YH=6T@<W5B;W)D:6YA9&\@<&]D92!S97(@861I8VEO;F%D;R!A(&5S
M=&$@<&5R;6ES<^-O+@!.96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)A
MY^-O(&5S<&5C:69I8V%D82!P87)A("5S+@!.96YH=6UA(&EN9F]R;6'GXV\@
M9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A($944"!61E,N`$YE
M;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A
M('!A<F$@4U%,(%9&4RX`3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R
M8>?C;R!E<W!E8VEF:6-A9&$@<&%R82!344PM1FEL92!61E,N`$YE;FAU;2!C
M<NED:71O(')E<W1A;G1E+@!.96YH=6T@9&5S=&EN;R!F;W)N96-I9&\N`$YE
M;FAU;2!E+6UA:6P@96YC;VYT<F%D;R!N82!C:&%V92!P^F)L:6-A+@!.96YH
M=6T@87)Q=6EV;R!E;G9I861O`$YE;FAU;6$@<&%S=&$@<V5L96-I;VYA9&$N
M`$YO=F%S(&UE;G-A9V5N<R!NXV\@97-TXV\@<V5N9&\@=F5R:69I8V%D87,@
M96T@;F5N:'5M82!P87-T82X`3F5N:'5M82!P87-T82!F;VD@97-P96-I9FEC
M861A`$YE;FAU;6$@<&%S=&$@8V]M(&YO=F%S(&UE;G-A9V5N<P!.96YH=6UA
M('!A<W1A(&-O;2!M96YS86=E;G,@;N-O(&QI9&%S`$YE;FAU;2#M8V]N92!E
M;F-O;G1R861O+@!.96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+@!.
M96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+@!.96YH=6T@=&5X=&\@
M;F\@8V]R<&\@9&$@;65N<V%G96T`3F5N:'5M82!M96YS86=E;2!R971O<FYA
M9&$N`$YE;FAU;6$@;65N<V%G96T@9F]R;F5C:61A+@!.96YH=6UA(&UE;G-A
M9V5M(&-O<G)E<W!O;F1E=2!A('-U82!P97-Q=6ES82X`3F5N:'5M(&YO;64@
M97-P96-I9FEC861O+@!.96YH=6T@;OIM97)O(&5S<&5C:69I8V%D;RX`4V5M
M('-O<G1E<R!O9F5N<VEV87,`3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R
M82!A(&%U=&5N=&EC8>?C;R!(5%10+@!.96YH=6UA('-E;FAA(&9O<FYE8VED
M82!P87)A(&$@875T96YT:6-AY^-O($E-05`N`$YE;FAU;6$@<V5N:&$@9F]R
M;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@2V5R8F5R;W,N`$YE;FAU;6$@
M<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@3&]G:6XN`$YE
M;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@4$%3
M4U=$+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-A
MY^-O(%--0BX`3F5N:'5M('!A=&@@<&%R82!O(&)I;N%R:6\@9&\@3W!E;E-3
M3"!F;VD@9F]R;F5C:61O+B!/(&)I;N%R:6\@9&\@3W!E;E-33"#I(&YE8V5S
M<^%R:6\@<&%R82!M86YI<'5L87(@;W,@9&%D;W,@4$M#4R`Q,BX`3F5N:'5M
M(&-A9&%S=')O('!E;F1E;G1E+@!.96YH=6UA(&-H879E('!R:79A9&$@4$=0
M('!E<W-O86P@9F]I(&EM<&]R=&%D82X`3F5N:'5M82!C:&%V92!P^F)L:6-A
M(%!'4"!P97-S;V$@9F]I(&EM<&]R=&%D82X`3F5N:'5M(&-E<G1I9FEC861O
M(%,O34E-12!P97-S;V%L(&9O:2!I;7!O<G1A9&\N`$[C;R!E>&ES=&4@=6UA
M(&-H879E('!E<W-O86P@<')I=F%D82P@9&5V:61O(&$@:7-S;R!A(&UE;G-A
M9V5M(&[C;R!P;V1E('-E<B!D97-C<FEP=&]G<F%F861A+@!1=6]T82!NXV\@
M8V]N9FEG=7)A9&$N`%-E;2!L:6YH87,`3F5N:'5M('-E<&%R861O<B!F;VD@
M97-P96-I9FEC861O+@!396T@;&%D;W,`3F5N:'5M('!R;V=R86UA(&1E('9E
M<FEF:6-AY^-O(&1E(&]R=&]G<F%F:6$@9F]I(&-O;F9I9W5R861O+@!.96YH
M=6T@97)R;R!D92!O<G1O9W)A9FEA`$%R<75I=F\@:6YE>&ES=&5N=&4`4V5M
M('-U9V5S=/5E<P!.96YH=6T@<W5P;W)T92!A(&WI=&]D;W,@9&4@875T96YT
M:6-AY^-O($E-05`@9F]I(&5N8V]N=')A9&\N`$YE;FAU;2!D:7)E=/-R:6\@
M=&5M<&]RX7)I;R!D:7-P;V[M=F5L('!A<F$@;R!C86-H92X`3F5N:'5M('5S
M=>%R:6\@97-P96-I9FEC861O+@!.96YH=6T@=7-UX7)I;R!E+V]U('-E;FAA
M(&9O<FYE8VED;W,N`$YE;FAU;2!D861O(%A-3"!VX6QI9&\@<F5T;W)N861O
M`%-E;2!V86QO<F5S`$YE;FAU;2!V97)SXV\@96YC;VYT<F%D82!N82!C;VYF
M:6=U<F'GXV\@;W)I9VEN86PN($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)A
MY^-O+@!.96YH=6UA('9E<G/C;R!E;F-O;G1R861A(&YA('-U82!C;VYF:6=U
M<F'GXV\N($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O+@!396T@4&%R
M=&EC:7!A;G1E<P!.96YH=6UA`$YE;FAU;6$@*'5S;R!I;7!L[6-I=&\I`$[S
M<F1I8V\@*$E33RTX.#4Y+3$P*0!);&AA($YO<F9O;&L`3F]R;6%L`$AE;6ES
M9NER:6\@3F]R=&4`26QH87,@36%R:6%N82!D;R!.;W)T90!.;W)U96=A`$[C
M;R!!</-S`$[C;R!!;G1E<P!.XV\@17AC;'7M9&$`3N-O(%)A<V-U;FAO`$[C
M;R!);7!O<G1A;G1E`$[C;R!097-S;V%L`$[C;R#I('5M(&1I<F5T\W)I;P!.
MXV\@Z2!U;6$@8VAA=F4@</IB;&EC82!VX6QI9&$N`$UE;G-A9V5N<R!NXV\@
M97AC;'7M9&%S`$[C;R!);7!L96UE;G1A9&\N`$UE;G-A9V5N<R!NXV\@:6UP
M;W)T86YT97,`3N-O(&-O;F9I9W5R861O`$[C;R!S=7!O<G1A9&\N`$YO=&4@
M<75E(&ES=&\@<&]D92!L979A<B!A;&=U;2!T96UP;P!!;F]T8>?U97,`3F%D
M80!.861A('!A<F$@97AI8FER+"!V;VQT92X`3F]T:69I8V'GXV\Z($%N97AO
M(&)A:7AA9&\`3F]V96UB<F\`3OIM97)O`$[Z;65R;R!D92!C87)A8W1E<F5S
M`$[Z;65R;R!D92!C;VQU;F%S`$[Z;65R;R!D92!M97-E<R!P87)A(&UA;G1E
M<B!L:6YK<R!D92!A;F5X;W,@86YT:6=O<R!S92!E<W1I=F5R(&5X8VQU:6YD
M;R!M96YS86QM96YT92X`3OIM97)O(&1E('!A<W1A<R!A;G1I9V%S(&1E(&UE
M;G-A9V5N<R!E;G9I861A<R!A(&UA;G1E<B!S92!E<W1I=F5R(&5X8VQU:6YD
M;R!M96YS86QM96YT92X`3OIM97)O(&1E(&QI;FAA<P!.^FUE<F\@;N-O(&5S
M<&5C:69I8V%D;R!P87)A(&%T=6%L:7IAY^-O(&YA(&QI<W1A(&1E(&1I<W1R
M:6)U:>?C;RX`3TL`3U4`3V)J971O`$-R:6%D;W(@9&\@3V)J971O`$]C=&%L
M`$]U='5B<F\`1FEL=')O(&]F96YS:79O`$5S8W)I=/-R:6\`4V5N:&%S(&%N
M=&EG82!E(&YO=F$@9&5V96T@<V5R(&1I9F5R96YT97,N`$UE;G-A9V5N<R!A
M;G1I9V%S`%-E;FAA(&%N=&EG80!396YH82!A;G1I9V$@;N-O(&5S=.$@8V]R
M<F5T82X`07,@<&%S=&%S(&%N=&EG87,@9&4@;65N<V%G96YS(&5N=FEA9&%S
M(&5S=.-O('-E;F1O(&5X8VQU[61A<RX`3VWC`%-O;65N=&4@<V5R=FED;W)E
M<R!)34%0('-U<&]R=&%M('!A<W1A<R!C;VUP87)T:6QH861A<RX`17AI8FER
M('-O;65N=&4@<&%S=&%S(&-O;2!M96YS86=E;G,@;N-O(&QI9&%S/P!3;VUE
M;G1E('-O<G1E<R!O9F5N<VEV87,`4V]M96YT92!U;2!E;F1E<F7G;R!D92!E
M+6UA:6P@<&5R;6ET:61O+@!3;VUE;G1E('5M82!P87-T82!D979E('-E<B!S
M96QE8VEO;F%D82!P87)A(&5S=&$@8>?C;RX`4V]M96YT92!O('!R;W!R:65T
MX7)I;R!O=2!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M82!P;V1E;2!A;'1E
M<F%R(&%S('!E<FUI<W/U97,@9&4@<')O<')I961A9&4@;W4@<')O<')I973A
M<FEO(&1E('5M(&-O;7!A<G1I;&AA;65N=&\`06)R:7(@7U!A<W1A`$%B<FER
M(&5M('5M82!N;W9A(&IA;F5L80!%<G)O(&1O($]P96Y34TPZ($[C;R!P=61E
M(&5X=')A:7(@9&%D;W,@9&$@<&%R=&4@87-S:6YA9&$@4R]-24U%+@!087-T
M82!!8F5R=&$`06)R92!E<W1E(&QI;FL@96T@=6UA(&YO=F$@:F%N96QA`%-I
M<W1E;6$@3W!E<F%C:6]N86P`4&%R=&EC:7!AY^-O($]P8VEO;F%L`$]PY_5E
M<P!/<.?U97,@9&4@)7,`3&ES=&$@3W)D96YA9&$`3W)G86YI>F'GXV\`56YI
M9&%D92!/<F=A;FEZ86-I;VYA;`!/<F=A;FEZ86YD;P!-;V1E;&\@;W)I9VEN
M86P@9&4@87!L:6-AY^-O`$UO9&5L;R!O<FEG:6YA;"!E;2`E<SH`3W5T<F\`
M3W5T<F%S($EN9F]R;6'G]65S`$]U=')A<R!#;VYT87,@9&4@0V]R<F5I;P!/
M=71R87,@3W#G]65S`%-E<G9I9&]R(&1E($5N=FEO`%!E<FUI<W/U97,@9&\@
M4')O<')I973A<FEO`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N
M[79E;"X`0V]N96-T;W(@4$5!4CHZ36%I;`!01U``07-S:6YA='5R82!$:6=I
M=&%L(%!'4`!-96YS86=E;2!#<FEP=&]G<F%F861A(&-O;2!01U``1&%D;W,@
M0W)I<'1O9W)A9F%D;W,@8V]M(%!'4`!%<G)O(&1O(%!'4#H@`$5R<F\@9&\@
M4$=0.B!396YH82!N96-E<W/A<FEA('!A<F$@82!C:&%V92!P<FEV861A('!E
M<W-O86PN`$]PY_5E<R!D92!01U``16YT<F%D82!D82!396YH82!D;R!01U``
M4W5P;W)T92!A(%!A<B!D92!#:&%V97,@4$=0(%!E<W-O86ES(')E<75E<B!U
M;6$@8V]N97CC;R!W96(@<V5G=7)A+@!#:&%V92!0^F)L:6-A(%!'4`!497AT
M;R!D82!#:&%V92!0^F)L:6-A(%!'4`!#:&%V92!0^F)L:6-A(%!'4"!D92`B
M)7,@*"5S*2(@9F]I(&%D:6-I;VYA9&$@8V]M('-U8V5S<V\N`$-H879E(%#Z
M8FQI8V$@4$=0(&1E("(E<R(@9F]I(&5X8VQU[61A(&-O;2!S=6-E<W-O+@!#
M:&%V96ER;R!0^F)L:6-O(%!'4`!-96YS86=E;2!!<W-I;F%D82!C;VT@4$=0
M`$UE;G-A9V5M($%S<VEN861A+T-R:7!T;V=R869A9&$@8V]M(%!'4`!$861O
M<R!!<W-I;F%D;W,O0W)I<'1O9W)A9F%D;W,@8V]M(%!'4`!#:&%V92!P<FEV
M861A(%!'4"!A9&EC:6]N861A(&-O;2!S=6-E<W-O+@!#:&%V92!P^F)L:6-A
M(%!'4"!A9&EC:6]N861A(&-O;2!S=6-E<W-O+@!3=7!O<G1E(&$@4$=0(&5S
M=.$@9&5S86)I;&ET861O(&YE<W1E('-I<W1E;6$N`%-U<&]R=&4@82!01U`@
M;N-O(&5S=.$@871U86QM96YT92!A=&EV;RP@<V5N9&\@87-S:6T@;N-O(.D@
M<&]S<^UV96P@=F5R:69I8V%R(&$@87-S:6YA='5R82!D:6=I=&%L+@!3=7!O
M<G1E(&$@4$=0(&[C;R!E<W3A(&%T=6%L;65N=&4@871I=F\L('-E;F1O(&%S
M<VEM(&[C;R#I('!O<W/M=F5L(&1E<V-R:7!T;V=R869A<B!A(&UE;G-A9V5M
M+@!3=7!O<G1E(&$@4$=0(')E<75E<B!Q=64@:F%N96QA<R!P;W`M=7`@<V5J
M86T@=71I;&EZ861A<RX@(%-E('-E=2!N879E9V%D;W(@97-TX2!A='5A;&UE
M;G1E(&-O;F9I9W5R861O('!A<F$@8FQO<75E87(@<&]P+75P<RP@=F]CZB!D
M979E(&%L=&5R87(@97-T82!C;VYF:6=U<F'GXV\@;W4@87,@9G5NY_5E<R!0
M1U`@;N-O(&9U;F-I;VYA<N-O(&-O<G)E=&%M96YT92X`0_-D:6=O(%!(4`!,
M:6YH82!D92!#;VUA;F1O(%!(4`!#:'5V82!&<F%C82!697-P97)T:6YA`$-H
M=79A(%9E<W!E<G1I;F$`0VAU=F%S(%9E<W!E<G1I;F%S`$YE=F4@5F5S<&5R
M=&EN80!.979A<V-A(%9E<W!E<G1I;F$`3F5V92!697-P97)T:6YA`%1R;W9O
M861A<R!697-P97)T:6YA<P!03U`S`%!/4#,@*$%U=&\@1&5T96-T87(@4')O
M=&]C;VQO<RD`4$]0,R!S;V)R92!34TP`4$]0,R!S;V)R92!34TP@*&-E<G1I
M9FEC861O(&%U=&\M87-S:6YA9&\I`%!/4#,@<V]B<F4@4U-,("AA=71O+6%S
M<VEN861O*0!03U`S+"!S96T@5$Q3`$5S=.$@9F%L=&%N9&\@82!E>'1E;G/C
M;R!03U-)6`!,:6YH82!D92!#;VUA;F1O(%!?2%``36%R9V5M`%#A9VEN82`E
M9"!D92`E9`!0X6=I;F$@8V]M(&%S($UE;G-A9V5N<R!.XV\@3&ED87,@4')I
M;65I<F\`4.%G:6YA(&-O;2!A<R!-96YS86=E;G,@3N-O($QI9&%S('!O<B#:
M;'1I;6\`4&%Q=6ES=.-O`%!A;&%U`%!A;&5S=&EN;RP@5&5R<FET\W)I;R!/
M8W5P861O`%!A;F%MX0!0X7!U82!.;W9A($=U:6[I`%!A<F%G=6%I`%!A<G1E
M*',I`%!A<F-I86QM96YT92!.=6)L861O`%-E;FAA`%-E;FAA("A.;W9A;65N
M=&4I`%-E;FAA(&1E<V-A<G)E9V%D82!C;VT@<W5C97-S;RX`4V5N:&$Z`$%S
M('-E;FAA<R!NXV\@<&]D96T@97-T87(@96T@8G)A;F-O`$%S('-E;FAA<R!N
MXV\@8V]I;F-I9&5M`%-E;FAA`%-E;FAA(&%L=&5R861A(&-O;2!S=6-E<W-O
M+@!396YH82!I;F-O<G)E=&$`4V5N:&$@;V)R:6=A=/-R:6$@<&%R82!A(&%U
M=&5N=&EC8>?C;R!2041)55,N`%-E;FAA(&-O;2!C;VYF:7)M8>?C;P!396YH
M83H`4V5N:&$Z(`!396YH87,@9&5V96T@<V5R(&EG=6%I<RX`0V]L87(`0V]L
M87(@9&$@X7)E82!D92!T<F%N<V9E<NIN8VEA`%!A=&@`0V%D87-T<F]S(%!E
M;F1E;G1E<SH`4&5S<V]A<P!0;W)C96YT86=E;0!%>&5C=71A<B!/<&5R8>?U
M97,@9&4@36%N=71E;N?C;P!%>&5C=71A<B!O<&5R8>?U97,@9&4@;6%N=71E
M;N?C;R!A;R!C;VYE8W1A<C\`4&5R;6ES<^-O`%!E<FUI<W/C;R`B)7,B(&[C
M;R!E>&-L=>UD82X`4&5R;6ES<^-O($YE9V%D80!097)M:7-S]65S`$%D;6EN
M:7-T<F'GXV\@9&4@4&5R;6ES<_5E<P!!<R!P97)M:7-S]65S('!A<F$@97-T
M92!U<W7A<FEO(&[C;R!P;V1E;2!S97(@86QT97)A9&%S+@!097-S;V%L`$EN
M9F]R;6'G]65S(%!E<W-O86ES`%!A<B!D92!#:&%V97,@4$=0(%!E<W-O86P@
M9V5R861A(&-O;2!S=6-E<W-O+@!#:&%V97,@4$=0(%!E<W-O86ES(&5X8VQU
M[61A<R!C;VT@<W5C97-S;RX`0V5R=&EF:6-A9&]S(%,O34E-12!097-S;V%I
M<R!.PT\@9F]R86T@:6UP;W)T861O<SH@`$-H879E<R!3+TU)344@4&5S<V]A
M:7,@97AC;'7M9&%S(&-O;2!S=6-E<W-O+@!097)U`$%N:6UA:7,@9&4@17-T
M:6UAY^-O`$9I;&EP:6YA<P!496QE9F]N90!&;W1O<P!0:71C86ER;@!0:7AE
M;',`26YS97)I<B!S=6$@87-S:6YA='5R82!A;G1E<R!D92!R97-P;W-T87,@
M92!E;F-A;6EN:&%M96YT;W,_`%9E<G/C;R!D82!-96YS86=E;2!E;2!497AT
M;R!0=7)O`$-L:6-HZ0!%;6ET:7(@879I<V\@<V]N;W)O(&%O(')E8V5B97(@
M;F]V82!M96YS86=E;3\@27-T;R!R97%U97(@<75E('-E=2!N879E9V%D;W(@
M<W5P;W)T92!A<G%U:79O<R!D92!S;VYS(&5M8G5T:61O<RX@475A<V4@=&]D
M;W,@<W5P;W)T86T@96T@5VEN9&]W<R!E($UA8RP@;6%S(&]U=')A<R!P;&%T
M869O<FUA<R!N96-E<W-I=&%R86T@9&4@=6T@<&QU9VEN+@!0;W(@9F%V;W(@
M8VQI<75E(&5M(&%L9W5M82!CZ6QU;&$`4&]R(&9A=F]R(&-O;F9I<FUE('%U
M92!V;V/J('%U97(@<F5M;W9E<B!E<W1E(&5L96UE;G1O.@!0;W(@9F%V;W(@
M8V]N9FER;64@<75E('9O8^H@<75E<B!R96UO=F5R(&\@;&EN:R!D97-T92!E
M;&5M96YT;RX`4&]R(&9A=F]R(&9O<FYEYV$@=6T@;>IS(&4@=6T@86YO+@!0
M;W(@9F%V;W(@9F]R;F7G82!U;2!N;VUE('!A<F$@82!N;W9A(&-A=&5G;W)I
M83H`4&]R(&9A=F]R(&9O<FYEYV$@=6T@;F]M92!P87)A(&$@;F]V82!P87-T
M83H`4&]R(&9A=F]R(&9O<FYEYV$@=6T@96YD97)EYV\@25`@=N%L:61O+@!0
M;W(@9F%V;W(@9F]R;F7G82!U;6$@9&%T82!VX6QI9&$L('9E<FEF:7%U92!O
M(&[Z;65R;R!D92!D:6%S(&YO(&WJ<RX`4&]R(&9A=F]R(&9O<FYEYV$@=6UA
M(&AO<F$@=N%L:61A+@!0;W(@9F%V;W(@9F]R;F7G82!O(&YO;64@<&%R82!A
M(&YO=F$@<&%S=&$Z`%!O<B!F879O<B!F;W)N9>=A(&\@;F]V;R!N;VUE.@!0
M;W(@9F%V;W(@9F]R;F7G82!A('-E;FAA('!A<F$@<W5A(&-H879E('!R:79A
M9&$@4$=0+B!6;V/J('-O;65N=&4@<')E8VES87+A(&9O<FYE8V5R(&5S=&$@
M<V5N:&$@=6UA('9E>B!P;W(@<V5S<^-O("5S+@!0;W(@9F%V;W(@9F]R;F7G
M82!A('-E;FAA('!A<F$@<W5A(&-H879E('!R:79A9&$@4R]-24U%+B!6;V/J
M('-O;65N=&4@<')E8VES87+A(&9O<FYE8V5R(&5S=&$@<V5N:&$@=6UA('9E
M>B!P;W(@<V5S<^-O("5S+@!0;W(@9F%V;W(@8V]N96-T92US92!N;W9A;65N
M=&4@<&%R82!C;VYT:6YU87(@8V]M<&]N9&\@<W5A(&UE;G-A9V5M+B!392!V
M;V/J($[#3R!E<W3A('5T:6QI>F%N9&\@8V]O:VEE<R!%('9O8^H@97-TX2!C
M;VUP;VYD;R!M96YS86=E;G,@96T@=6UA(&IA;F5L82!P;W`M=7`L('9O8^H@
M=&5RX2!Q=64@8V]N96-T87(@;F]V86UE;G1E(&YA(&IA;F5L82!P<FEN8VEP
M86P@=&%M8NEM+B!)<W1O(.D@<&%R82!P<F5V96YI<B!Q=64@:&%C:V5R<R!D
M971E;FAA;2!O($E$(&1E('-U82!S97-SXV\N($YO<R!D97-C=6QP86UO<R!P
M;W(@<75A;'%U97(@:6YC;VYV96YIZFYC:6$N`%!O<B!F879O<B!F;W)N9>=A
M('5M(')E<W5M;R!D;R!P<F]B;&5M82X`4&]R(&9A=F]R(&9O<FYEYV$@<W5A
M('-E;FAA+@!0;W(@9F%V;W(@9F]R;F7G82!S974@=7-UX7)I;R!E('-E;FAA
M`%!O<B!F879O<B!F;W)N9>=A('-E=2!U<W7A<FEO+@!0;W(@9F%V;W(@;&5I
M82!O('1E>'1O(&$@<V5G=6ER+B!6;V/J($1%5D4@8V]N8V]R9&%R(&-O;2!O
M<R!T97)M;W,@9&4@=7-O(&1O('-I<W1E;6$N`%!O<B!F879O<B!C;W)R:6IA
M(&5N9&5R9>=O<R!I;G;A;&ED;W,@;W4@86UB[6=U;W,N`%!O<B!F879O<B!S
M96QE8VEO;F4@=6UA('!A<W1A(&%N=&5S(&1E(')E86QI>F%R(&5S=&$@8>?C
M;RX`4&]R(&9A=F]R('-E;&5C:6]N92!P96QO(&UE;F]S('5M82!P87-T82!P
M87)A('!E<W%U:7-A<BX`4&]R(&9A=F]R('-E;&5C:6]N92!S;VUE;G1E('5M
M82!P87-T82!P87)A(&5S=&$@;W!E<F'GXV\N`%!O<B!F879O<B!S96QE8VEO
M;F4@;W4@961I=&4@;F$@8V%I>&$@X"!D:7)E:71A.@!0;W(@9F%V;W(@9&EG
M:71E(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83H`4&]L]&YI80!0;VSM=&EC
M80!%;G%U971E`%!O<G1U9V%L`%!O<VGGXV\@9&5S=&$@:6UA9V5M`%!O<VGG
MXV\@9&5S=&$@=&%B96QA`$5N=FEE('!A<F$@97-T82!P87-T82`H;N-O(.D@
M;V)R:6=A9&\@<&5L;R!)34%0*0!0;W=E<F5D(&)Y($AO<F1E`%!R96-E9&5R
M('-U82!A<W-I;F%T=7)A(&-O;2!T<F'G;W,@*"<M+2<I/P!0<F5C:7!I=&'G
MXV\@<&%R82!A*',I(/IL=&EM82AS*2`E<R!H;W)A*',I.B``4')E8VEP:71A
MY^-O/&)R("\^8VAA;F-E`%!R969E<NIN8VEA<R!A='5A;&EZ861A<R!C;VT@
M<W5C97-S;RX`4')E9G-?;&1A<#H@17AT96YSXV\@3$1!4"!O8G)I9V%T\W)I
M82!NXV\@96YC;VYT<F%D82X`4')E9G-?<V5S<VEO;CH@17AT96YSXV\@9&4@
M<V5S<^-O(&]B<FEG873S<FEA(&[C;R!E;F-O;G1R861A+@!0<F5S<^-O`%!R
M97-SXV\@96T@;NUV96P@9&\@;6%R.B``4')E<W/C;SH@`%!RZ2UV:7-U86QI
M>F'GXV\`4')E=F5R(&$@:6UA9V5M(&5M('5M82!N;W9A(&IA;F5L80!-96YS
M86=E;2!!;G1E<FEO<@!0X6=I;F$@06YT97)I;W(`3W#G]65S(&%N=&5R:6]R
M97,`26UP<FEM:7(`26UP<FEM:7(@9&]C=6UE;G1O`%!R:6]R:61A9&4`0VAA
M=F4@4')I=F%D80!396YH82!D82!#:&%V92!0<FEV861A`%!R;V)L96UA`$1E
M<V-R:>?C;R!D;R!0<F]B;&5M80!0<F]J971O<P!097)G=6YT87(@<V5M<')E
M('%U92!U;2!A;F5X;R#I(&5N=FEA9&\[('!A9'+C;R#I($[#3P!097)G=6YT
M87(@<V5M<')E('%U92!U;2!A;F5X;R#I(&5N=FEA9&\[('!A9'+C;R#I(%-)
M30!497AT;R!B<F5V90!0<F]T;V-O;&\Z`$-H879E(%#Z8FQI8V$`06QG;W)I
M=&UO(&1A($-H879E(%#Z8FQI8V$`0VAA=F4@4/IB;&EC80!3=7!O<G1E(&$@
M<V5R=FED;W)E<R!D92!C:&%V92!P^F)L:6-A(&5S=.$@9&5S86)I;&ET861O
M+@!087(@9&4@8VAA=F5S(%#Z8FQI8V$O4')I=F%D82!NXV\@9F]R86T@9V5R
M861O<R!C;VT@<W5C97-S;RX`4&]R=&\@4FEC;P!%<W9A7WII87(@3&EX96ER
M80!%<W9A>FEA<B!,:7AE:7)A`$5S=F%Z:6%R(%!A<W1A*',I`$9R97'\ZFYC
M:6$@<&%R82!E<W9A>FEA<B!,:7AE:7)A.@!%>&-L=6ER(&UE;G-A9V5N<R!D
M82!,:7AE:7)A(&UA:7,@86YT:6=A<R!Q=64@97-T82!Q=6%N=&ED861E(&1E
M(&1I87,N`$5X8VQU:7(@;65N<V%G96YS(&%N=&EG87,@;F$@3&EX96ER83\`
M17AC;'5I;F1O("5D(&UE;G-A9V5M*&YS*2!D82!,:7AE:7)A+@!%>&-L=6EN
M9&\@,2!M96YS86=E;2!D82!,:7AE:7)A+@!1871A<@!#;VYS=6QT87(`46%T
M87(`4VET=6'GXV\@9&$@475O=&$Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2D`4VET=6'GXV\@9&$@475O=&$Z("4N,F9-0B`O(%-%32!,24U)5$4`4VET
M=6'GXV\@9&$@475O=&$Z(%-%32!,24U)5$4`0VET86YD;R`E9CH`0VAA=F4@
M4/IB;&EC82!24T$@*"5D(&)I="D`0F]T]65S(&1E('-E;&7GXV\`0VAU=F$`
M0VAU=F$@36%T=71I;F$`0VAU=F$@5F5S<&5R=&EN80!086YC861A<R!D92!#
M:'5V80!#:'5V82!E($YE=F4`0VAU=F$@<&%R82!.979E`%-O<G1E($%L96%T
M\W)I80!296QAY^-O`$QE<@!,97(@;65N<V%G96YS`$5X8VQU:7(@<F5A;&UE
M;G1E("5S/R!%<W1A(&]P97)AY^-O(&[C;R!P;V1E('-E<B!D97-F96ET82X`
M4F5M;W9E<B!R96%L;65N=&4@;W,@9&%D;W,@9&\@=7-UX7)I;R`E<S\@17-T
M82!O<&5R8>?C;R!NXV\@<&]D92!S97(@9&5S9F5I=&$N`%)E8V]N<W1R=6ER
M(&$@P7)V;W)E(&1E(%!A<W1A<P!296-E8FED;R!%;0!296-E8FED;R!$97-D
M90!296-E8FED;R!!=.D`4F5D:7)E8U]I;VYA<@!2961I<F5C:6]N87(`4F5D
M:7)E8VEO;F%R($UE;G-A9V5M`%)E9&ER96-I;VYA<B!E<W1A(&UE;G-A9V5M
M`%)E9&ER96-I;VYA;65N=&\@9F%L:&]U+@!2969A>B!S=6$@^FQT:6UA(&'G
MXV\`071U86QI>F%R`$%T=6%L:7IA<B!-96YU(&1E($5L96UE;G1O<R!$:6[B
M;6EC;W,Z`$%T=6%L:7IA<B!6:7-U86QI>F'GXV\@9&4@4&%S=&%S.@!!='5A
M;&EZ87(@17AI8FGGXV\@9&\@4&]R=&%L.@!296=E>`!.879E9V%D;W(@9&4@
M4F5L8>?U97,`071U86QI>F%R`$%T=6%L:7IA<B!6:7-U86QI>F'GXV\`3V)S
M97)V8>?U97,`3&5M8G)A<B!A(&EN9F]R;6'GXV\@;&EV<F4O;V-U<&%D;RX`
M3&5M8G)A<B!A(/IL=&EM82!V:7-U86QI>F'GXV\`0V%I>&$@4&]S=&%L(%)E
M;6]T83H`4V5R=FED;W)E<R!296UO=&]S`%523"!296UO=&$@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F5R`%)E;6]V97(@0FQO8V\`
M4F5M;W9E<B!#86UP;R!D82!097-Q=6ES80!296UO=F5R(&-O;'5N80!296UO
M=F5R(&9O<FUA=&'GXV\`4F5M;W9E<B!P87(`4F5M;W9E<B!S8W)I<'0@9W)A
M=F%D;R!N;R!D:7)E=/-R:6\@=&5M<&]RX7)I;R!D;R!S97)V:61O<BX`4F5M
M;W9E<B!O<FEG96T`4F5M;W9E<B!O`%)E;6]V97(@97-T92!N\R!D;R!D;V-U
M;65N=&\`4F5M;W9E<B!U<W7A<FEO`%)E;6]V97(@=7-UX7)I;SH@)7,`4F5N
M;VUE87(@4&%S=&$H<RD`4F5N;VUE87(@(D5N=FEA9&]S(B!N;R!I;NUC:6\@
M9&\@;>IS/P!&86QH82!A;R!R96YO;65A<B`B)7,B('!A<F$@(B5S(BX@27-T
M;R#I(&\@<75E(&\@<V5R=FED;W(@9&ES<V4`4F5S<&]N9&5R('!A<F$@3&ES
M=&$@9&4@1&ES8U]U<W/C;P!3=6)S=&ET=6ER('!O<CH`4F5S<&]N9&5R`%)E
M<W!O<W1A($5N=FEA9&$N`%)E<W!O;F1E<B!A(%1O9&]S`%)E<W!O;F1E<B!A
M(%1O9&]S.@!297-P;VYD97(@<&%R82!A($QI<W1A(&1E($1I<V-U<W/C;P!2
M97-P;VYD97(@<&%R82!A($QI<W1A(&1E($1I<V-U<W/C;SH`4F5S<&]N9&5R
M(&$@5&]D;W,`4F5S<&]N9&5R(&-O;2!-96YS86=E;2!.XV\@4W5P;W)T861A
M`%)E<W!O;F1E<B!C;VT@:6YF;W)M8>?C;R!L:79R92]O8W5P861O(&1U<F%N
M=&4@,B!M97-E<RX`4F5S<&]N9&5R(&-O;2!S;VQI8VET8>?C;R!D92!I;F9O
M<FUAY^-O(&QI=G)E+V]C=7!A9&\N`%)E<&QY+51O`$5N9&5R9>=O('!A<F$@
M4F5S<&]S=&$@*%)E<&QY+51O*3H@`%)E<W!O;F1E<CH`4F5P;W)T87(@8V]M
M;R!);F]C96YT90!297!O<G1A<B!C;VUO(%-P86T`4V]L:6-I=&%R($-O;F9I
M<FUAY^-O(&1E(%],96ET=7)A`%-O;&EC:71AY^-O(&[C;R!P]&1E('-E<B!R
M97-P;VYD:61A+B!#\V1I9V\@9&4@97)R;R!R971O<FYA9&\Z(`!3;VQI8VET
M87(@8V]N9FER;6'GXV\@9&4@;&5I='5R83\`02!M96YS86=E;2!S;VQI8VET
M861A(&[C;R!F;VD@96YC;VYT<F%D82X`3R!S97)V:>=O(')E<75I<VET861O
M(&[C;R!P;V1E('-E<B!E;F-O;G1R861O+@`G)7,G(&]B<FEG873S<FEO(&[C
M;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R`E<RX`)R5S)R!O
M8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'G
MXV\@5D93+@`G)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O
M(&YA(&-O;F9I9W5R8>?C;RX`0V%M<&\@3V)R:6=A=/-R:6\`4&%R=&EC:7!A
M;G1E($]B<FEG873S<FEO`$QI;7!A<@!'97)A<B!.;W9A(%-E;FAA`$=E<F%R
M($YO=F$@4V5N:&$`4VET=6'GXV\@9&4@4F5S<&]S=&$@071U86QI>F%D82X`
MVFQT:6UO(%%U87)T;P!297-U;'1A9&]S`$-O;G1I;G5A<@!#;VYT:6YU87(@
M<W5A('-E<W/C;P!2971O<FYA<B!P87)A(")#;VUP;W-IY^-O(&1E($UE;G-A
M9V5M(@!2971O<FYA<B!P87)A(%1R87IE<B!-96YS86=E;0!2971O<FYA<B#@
M($]PY_5E<P!2971O<FYA<B#@(&QI<W1A9V5M(&1A(&-A:7AA('!O<W1A;"!A
M</-S(&5X8VQU:7(L(&UO=F5R(&]U(&-O<&EA<B!U;6$@;65N<V%G96T_`$1I
M9VET92!A(&YO=F$@<V5N:&$@;F]V86UE;G1E`%)E=6YIXV\`4F5V97)T97(@
M0V]N9FEG=7)AY^-O`$]PY_5E<R!D;R!%9&ET;W(@4FEC:"!497AT`$-H87)A
M9&%S`$1I<F5I=&$`0V%B9>=A;&AO(&1I<F5I=&\`5F%L;W)E<R!D82!D:7)E
M:71A`%!R;W!R:65D861E<R!D82!?3&EN:&$N+BX`1G5NY^-O`%)O;>IN:6$`
M1VER87(@,3@P(&=R875S`$=I<F%R('!A<F$@82!%<W%U97)D80!':7)A<B!P
M87)A(&$@1&ER96ET80!0<F]P<FEE9&%D97,@9&$@3&EN:&$`4')O<')I961A
M9&5S(&1A(&QI;FAA`$QI;FAA<SH`3&EN:&%S`$QI;FAA<R!A<&%R96-E<N-O
M(&5N=')E('1O9&%S(&%S(&QI;FAA<R!E(&-O;'5N87,`3&EN:&%S(&%P87)E
M8V5RXV\@<V]M96YT92!E;G1R92!C;VQU;F%S`$QI;FAA<R!A<&%R96-E<N-O
M('-O;65N=&4@96YT<F4@;&EN:&%S`$5X96-U=&%R`$9E9&5R8>?C;R!2=7-S
M80!2=6%N9&$`4R]-24U%`$%S<VEN871U<F$@0W)I<'1O9W+A9FEC82!3+TU)
M344`365N<V%G96T@0W)I<'1O9W)A9F%D82!C;VT@4R]-24U%`$UE;G-A9V5M
M($-R:7!T;V=R869A9&$@8V]M(%,O34E-10!%<G)O(&1O(%,O34E-13H@`$5R
M<F\@9&\@4R]-24U%.B!396YH82!N96-E<W/A<FEA('!A<F$@82!C:&%V92!P
M<FEV861A('!E<W-O86PN`$]PY_5E<R!D;R!3+TU)344`16YT<F%D82!D82!3
M96YH82!3+TU)344`4W5P;W)T92!A(%!A<B!D92!#:&%V97,@4R]-24U%(%!E
M<W-O86ES(')E<75E<B!U;6$@8V]N97CC;R!W96(@<V5G=7)A+@!#:&%V92!0
M^F)L:6-A(%,O34E-12!D92`B)7,B(&9O:2!E>&-L=>UD82!C;VT@<W5C97-S
M;RX`0VAA=F4@4/IB;&EC82!3+TU)344@861I8VEO;F%D82!C;VT@<W5C97-S
M;RX`0VAA=F5I<F\@4/IB;&EC;R!3+TU)344`4&%R(&1E($-H879E<R!0^F)L
M:6-A+U!R:79A9&$@4R]-24U%(&%D:6-I;VYA9&\@8V]M('-U8V5S<V\N`$UE
M;G-A9V5M($%S<VEN861A(&-O;2!3+TU)344`365N<V%G96T@07-S:6YA9&$O
M0W)I<'1O9W)A9F%D82!C;VT@4R]-24U%`%-U<&]R=&4@82!3+TU)344@97-T
MX2!D97-A8FEL:71A9&\@;F5S=&4@<VES=&5M82X`4W5P;W)T92!A(%,O34E-
M12!NXV\@97-TX2!A='5A;&UE;G1E(&AA8FEL:71A9&\L('-E;F1O(&%S<VEM
M(&[C;R#I('!O<W/M=F5L(&1E<V-R:7!T;V=R869A<B!A(&UE;G-A9V5M+@!/
M('-U<&]R=&4@4R]-24U%(&[C;R!E<W3A(&AA8FEL:71A9&\@<&]R(&ES<V\@
M;R!C;VYT9?ID;R!D97-T82!M96YS86=E;2!NXV\@<&]D92!S97(@97AI8FED
M82X`4W5P;W)T92!A(%,O34E-12!NXV\@97-TX2!A='5A;&UE;G1E(&AA8FEL
M:71A9&\L('-E;F1O(&%S<VEM(&[C;R#I('!O<W/M=F5L('9E<FEF:6-A<B!A
M(&%S<VEN871U<F$@9&EG:71A;"X`3R!S=7!O<G1E(%,O34E-12!R97%U97(@
M<75E(&IA;F5L87,@<&]P+75P('-E:F$@=71I;&EZ861A<RX@(%-E('-E=2!N
M879E9V%D;W(@97-TX2!A='5A;&UE;G1E(&-O;F9I9W5R861O('!A<F$@9&5S
M86)I;&ET87(@:F%N96QA<R!P;W`M=7`L('9O8^H@9&5V92!A;'1E<F%R(&5S
M=&$@8V]N9FEG=7)AY^-O(&]U(&%S(&9U;N?U97,@4R]-24U%(&[C;R!F=6YC
M:6]N87+C;R!C;W)R971A;65N=&4N`$%U=&5N=&EC8>?C;R!305-,(&[C;R!E
M<W3A(&1I<W!O;NUV96PN`$-O<G)E:6\@4TU3`%--5%``3&EN:&$@9&4@8V]M
M86YD;R!344P`4V5N=&5NYV$@4U%,('!A<F$@<&5S<75I<V%S(&1E('9A;&]R
M97,`4U-(`%-50T534T\`3&EN:&$@9&4@8V]M86YD;R!37U%,`$%?<W-U;G1O
M`%-A8@!386Q?=F%R('5M82!C\W!I82!E;2``4V%L=F%R(&-O;6\`4V%N=&$@
M2&5L96YA`%/C;R!+:71T<R!E($YE=FES`%-A;G1A($QU>FEA`%/C;R!0961R
M;R!E($UI<75E;&]N`%/C;R!6:6-E;G1E(&4@1W)A;F%D:6YA<P!-97-M;R!Q
M=6%D<F\@*%]S96QF*0!386UO80!386X@36%R:6YO`%/C;R!4;VWI(&4@4'+M
M;F-I<&4`4')O=F5D;W(@9&4@4V%TZ6QI=&4`07+A8FEA(%-A=61I=&$`4V%L
M=F%R`%-A;'9A<B`E<P!386QV87(@)7,`4V%L=F%R(&%N97AO<R!C;VT@82!M
M96YS86=E;2!N82!P87-T82!D92!M96YS86=E;G,@96YV:6%D87,_`%-A;'9A
M<B!287-C=6YH;P!386QV87(@8V]M;P!386QV87(@26UA9V5M(&YA($=A;&5R
M:6$`4V%L=F%R($]PY_5E<P!386QV87(@4&%P96P@9&4@0V%R=&$`4V%L=F%R
M(%)A<V-U;E]H;P!386QV87(@8V]M;P!386QV87(@<F%S8W5N:&]S(&-O;6\@
M;N-O(&QI9&]S/P!386QV87(@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M
M('-C<FEP="!02%`@<&%R82!O(&1I<F5T\W)I;R!T96UP;W+A<FEO(&1O('-E
M=2!S97)V:61O<BX`4V%L=F%R(&%U=&]M871I8V%M96YT92!D97-T:6YA=.%R
M:6]S(&YO('-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,@<&%D<N-O/P!386QV
M87(@<&5S<75I<V$@8V]M;R!U;6$@<&%S=&$@=FER='5A;#\`4V%L=F%R(&5N
M=FEA9&]S/P!#;VYF:6=U<F'GXV\@)7,@<V%L=F$N`%-C<FEP="!D92!A='5A
M;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@<V%L=F\@96TZ("<E<R<N`$9A;&AA
M(&%O('-A;'9A<B!R87-C=6YH;RX@27-T;R#I(&\@<75E(&\@<V5R=FED;W(@
M9&ES<V4Z("5S`%1E;7!E<W1A9&5S($ES;VQA9&%S`$-IZFYC:6$`4&5S<75I
M<V%R`%!E<W%U:7-A<B`E<P!%;F=I;F5S(&1E(%!E<W%U:7-A(`!/<.?U97,@
M9&4@4&5S<75I<V$`4F5S=6QT861O<R!D82!097-Q=6ES80!,:61A`%-E;&5C
M:6]N87(`4V5L96-I;VYA<B!/=71R82!#;VYT80!396QE8VEO;F4@;W,@07)Q
M=6EV;W,`4V5L96-I;VYE('5M82!D871A`%-E;&5C:6]N92!U;2!C86UP;P!3
M96QE8VEO;F4@=6T@9W)U<&\@<&%R82!A9&EC:6]N87(`4V5L96-I;VYE('5M
M(&YO=F\@;65M8G)O`%-E;&5C:6]N92!U;2!S97)V:61O<@!396QE8VEO;F4@
M=6T@<&%P96P@9&4@8V%R=&$Z`%-E;&5C:6]N92!U;2!U<W7A<FEO('!A<F$@
M861I8VEO;F%R`%-E;&5C:6]N92!U;2!C873A;&]G;R!D92!E;F1E<F7G;W,@
M<&%R82!A9&EC:6]N87(@92!P97-Q=6ES87(@96YD97)EYV]S+@!396QE8VEO
M;F%R('1O9&%S`%-E;&5C:6]N92!T;V1O<R!O<R!C;VUP;VYE;G1E<R!D92!D
M871A+@!396QE8VEO;F%R('1O9&]S(&]S(&-A;7!O<R!A('!E<W%U:7-A<B!Q
M=6%N9&\@97AP86YD:7(@96YD97)EYV]S+@!396QE8VEO;F%R('5M82!C;VYT
M80!396QE8VEO;F4@=6T@;V)J971O`$[C;R!S96QE8VEO;F%R(&YE;FAU;0!3
M96QE8VEO;F4@;W,@8V%R86-T97)E<R!Q=64@=F]CZB!P<F5C:7-A(&YA(&-A
M:7AA(&%B86EX;RX@5F]CZB!P;V1E(&5N=.-O(&-O<&GA+6QO<R!E(&-O;.$M
M;&]S(&YA(.%R96$@9&4@=&5X=&\N`%-E;&5C:6]N92!U;2!D96QI;6ET861O
M<B!D92!D871A.@!396QE8VEO;F4@;R!F;W)M871O(&1E(&1A=&$Z`%-E;&5C
M:6]N87(@82!G86QE<FEA(&]N9&4@<V%L=F%R(&$@:6UA9V5M+@!396QE8VEO
M;F4@82!I9&5N=&ED861E('%U92!V;V/J('%U97(@86QT97)A<CH`4V5L96-I
M;VYE(&\@=&EP;R!D92!S97)V:61O<B!D92!C;W)R96EO`%-E;&5C:6]N92!U
M;2!D96QI;6ET861O<B!D92!H;W)A.@!396QE8VEO;F4@;R!F;W)M871O(&1E
M(&AO<F$Z`%-E;&5C:6]N92!D;VES(&-A;7!O<R!C;W)R97-P;VYD96YT97,N
M`%-E;&5C:6]N92!S974@97-Q=65M82!D92!C;W)E<RX`4V5L96-I;VYE('-E
M=2!I9&EO;6$@<')E9F5R:61O.@!#873A;&]G;W,@9&4@16YD97)EYV]S(%-E
M;&5C:6]N861O<SH`16YV:6%R(&-H879E('!A<F$@;R!S97)V:61O<B!D92!C
M:&%V97,@</IB;&EC87,`16YV:6%R(-IL=&EM87,@26YF;W)M8>?U97,`16YV
M:6%R($UE;G-A9V5M`$5N=FEA<B!296QA=/-R:6\@9&4@4')O8FQE;6$`16YV
M:6%R(%--4P!%;G9I87(@82!M96YS86=E;2!S96T@=6T@07-S=6YT;S\`16YV
M:6%R($Y$32!Q=6%N9&\@<V]L:6-I=&%D;R!P96QO(')E;65T96YT93\`4V5N
M96=A;`!396YS;W(Z(`!087-T82!%;G9I861O<P!087-T82!%;G9I861O<SH`
M4V5T96UB<F\`4V5R=FEA(&4@36]N=&5N96=R;P!.^FUE<F\@9&4@4^ER:64`
M4V5R=FED;W(`26YF;W)M8>?U97,@9&4@4V5R=FED;W(@92!087-T87,`1&%D
M;W,@9&\@<V5R=FED;W(@97)R861O<R!O=2!NXV\@9&ES<&]N[79E:7,N`%-E
M<G9I9&]R.@!!9&UI;FES=')A9&]R(&1E(%-E<W/C;P!)1"!D82!397-SXV\@
M97AP:7)O=2X`4V5S<_5E<P!!:G5S=&%R`$-O;F9I9W5R82!A<R!O<.?U97,@
M<&%R82!P97)M:71I<B!V;V/J(&=E<F%R('5M82!N;W9A('-E;FAA('-E('9O
M8^H@97-Q=65CZBUL82X`1&5F:6YE('!R969E<NIN8VEA<R!S;V)R92!O('%U
M92!A8V]N=&5C92!Q=6%N9&\@=F]CZB!M;W9E(&4@97AC;'5I(&UE;G-A9V5N
M<RX`26YS97)I<B!O(&-A8F7G86QH;R!8+5!R:6]R:71Y(&%O(&-O;7!O<B!M
M96YS86=E;G,_`$-O;F9I9W5R82!O<R!S97)V:61O<F5S(')E;6]T;W,@<75E
M('9O8^H@<75E<B!A8V5S<V%R(.`@<&%R=&ER(&1O('!O<G1A;"X`0V]N9FEG
M=7)A('-E=2!I9&EO;6$@<')E9F5R:61O+"!F=7-O(&AO<N%R:6\@92!O<.?U
M97,@9&4@9&%T82X`0V]N9FEG=7)A('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@
M97-Q=65M82!D92!C;W)E<RP@871U86QI>F'GXV\@9&4@<.%G:6YA<R!E(&]U
M=')A<R!O<.?U97,@9&4@97AI8FGGXV\N`$-O;F9I9W5R8>?C;P!38W)I<'1S
M(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<P!$
M:79E<G-A<R!L;V-A;&ED861E<R!P;W-S[79E:7,@8V]M(&\@<&%RXFUE=')O
M.B``4V5I8VAE;&5S`%!A<W1A<R!#;VUP87)T:6QH861A<P!#;VUP87)T:6QH
M87(@<&%S=&%S`$-O;7!A<G1I;&AA('-U87,@<&%S=&%S(&1E(&-O<G)E:6\@
M8V]M(&]U=')O<R!U<W7A<FEO<RX`0V]M<')A<P!297-U;6\`5&5C;&%S(&1E
M(&%T86QH;R!D979E<N-O('-E<B!D969I;FED87,@<&%R82!A(&UA:6]R:6$@
M9&]S(&QI;FMS/P!";&]C;W,@9W)A;F1E<R!D92!T97AT;R!C:71A9&\@9&5V
M96T@<V5R(&5X:6)I9&]S(&]U(&]C=6QT861O<R!P;W(@<&%D<N-O/R!)<W1O
M('!O9&4@<V5R(&%L=&5R861O(&9A8VEL;65N=&4@<V5M<')E('%U92!Q=6ES
M97(N`$\@8V]R<&\@9&%S(&UE;G-A9V5N<R!T97AT;R!P=7)O(&1E=F4@<V5R
M(&5X86UI;F%D;R!A('!R;V-U<F$@9&4@9&%D;W,@4$=0/P!!(&IA;F5L82!D
M92!C;VUP;W-IY^-O(&1E=F4@<V5R(&9E8VAA9&$@87#S<R!S86QV87(@=6T@
M<F%S8W5N:&\_`%!O<B!P861RXV\@9&5V92US92!A;F5X87(@<W5A(&-H879E
M('#Z8FQI8V$@4$=0(&5M('-U87,@;65N<V%G96YS/P!%>&EB:7(`17AI8FER
M(%1O9&%S(&%S(%!A<W1A<P!%>&EB:7(@5&]D;W,@;W,@0V%B9>=A;&AO<P!%
M>&EB:7(@17AC;'7M9&%S`$5X:6)I<B!#86)EYV%L:&]S($QI;6ET861O<P!%
M>&EB:7(@26YF;W)M8>?U97,@9&$@3&ES=&$@9&4@1&ES8W5S<^-O`$5X:6)I
M<B!3;VUE;G1E(%!A<W1A<R!);G-C<FET87,`17AI8FER($[C;R!);G-C<FET
M87,`17AI8FER('5M(.UC;VYE('!A<F$@<&5R;6ET:7(@<F5M;W9E<B!A;F5X
M;W,@9&4@;65N<V%G96YS/P!%>&EB:7(@87,@9&EF97)E;N=A<R!E;G1R92!A
M(&-O;F9I9W5R8>?C;R!A='5A;"!E(&$@;F]V82!G97)A9&$N`$5X:6)I<B!D
M871A(&4@:&]R82!D82#Z;'1I;6$@8V]N97CC;R!A;R!S92!C;VYE8W1A<C\`
M17AI8FER(&QE9V5N9&$@;F$@=FES=6%L:7IAY^-O(&1A(&-A:7AA('!O<W1A
M;#\`17AI8FER(&$@;W#GXV\@9&4@;6%N=&5R(&\@;W)I9VEN86P`17AI8FER
M('-E;&5T;W(`17AI8FER('!RZ2UV:7-U86QI>F'GXV\@<V]M96YT92!D92!M
M96YS86=E;G,@;N-O(&QI9&%S/P!%>&EB:7(@<'+I+79I<W5A;&EZ8>?C;R!N
M;W,@8F%L]65S(&1E(&1I8V%S/P!%>&EB:7(@8F%R<F$@9&4@;65N=2!C;VT@
M;W!E<F'G]65S(&1E('1A8F5L83\`17AI8FER(&\@365N=2`E<R#@(&5S<75E
M<F1A/P!%>&EB:7(@;R#M8V]N92!4<F%Z97(@365N<V%G96YS(&YA(&)A<G)A
M(&1E(&UE;G4_`$5X:6)I<B!A<R!);6%G96YS`$5X:6)I<B!D:>%L;V=O(&1E
M(%!R;W!R:65D861E<R!D92!#Z6QU;&%S(&1A(%1A8F5L80!%>&EB:7(@9&GA
M;&]G;R!D92!0<F]P<FEE9&%D97,@9&$@5&%B96QA`$5X:6)I<B!D:>%L;V=O
M(&1E(%!R;W!R:65D861E<R!D92!,:6YH87,@9&$@5&%B96QA`$5X:6)I<B!O
M(.UC;VYE(&1E(&9I;'1R;W,@;F$@8F%R<F$@9&4@;65N=3\`17AI8FER(&1I
MX6QO9V\@9&4@<')O<')I961A9&5S(&1E(&EM86=E;0!%>&EB:7(@;R!N^FUE
M<F\@=&]T86P@9&4@;65N<V%G96YS(&YA('!A<W1A/P!%>&EB:7(@=7!L;V%D
M`$-H=79A<P!#:'5V87,@;6%T:6YA:7,`0VAU=F%S(%9E<W!E<G1I;F%S`$-H
M=79A<R!N87,@<F5D;VYD97IA<P!%>&EB:61A<P!2961U>FER`%!R:6UE:7)A
M;65N=&4@<F5D=7IA(&]U('1I<F4@9&\@8V%M:6YH;R!O*',I(&)L;V-O*',I
M(&%D:F%C96YT92AS*0!485]M86YH;P!397)R82!,96]A`%)E9VES=')A<@!!
M<W-I;F%T=7)A`$%L9V]R:71M;R!D82!!<W-I;F%T=7)A`$%S<VEN861A`$-I
M;F=A<'5R80!486UA;FAO`$EG;F]R87(@36%N=71E;N?C;P!%<VQO=N%Q=6EA
M`$5S;&]V96YI80!.979E`$YE=F%S8V$`3F5V87-C87,`0VAU=F%S(&UA=&EN
M86ES`$YE=F%S8V%S(%9E<W!E<G1I;F%S`%!R;V9U;F1I9&%D92!D82!.979E
M.B``17%U:79A;&5N=&4@9&4@;F5V92!E;2#A9W5A.B``26QH87,@4V%L;VWC
M;P!3;VWA;&EA`$-A;N?U97,@)B!0;V5M87,`3W)D96YA<B!E;2!/<F1E;2!D
M92!#:&5G861A`$]R9&5N87(@<&]R($1A=&$`3W)D96YA<B!P;W(@16YD97)E
MYV\@9&4@4F5M971E;G1E`$]R9&5N87(@<&]R(%1A;6%N:&\@9&$@365N<V%G
M96T`3W)D96YA<B!P;W(@07-S=6YT;P!/<F1E;F%R('!O<B!$:7-C=7-SXV\`
M3W)D96YA<B!P;W(@16YD97)EYV\@9&4@1&5S=&EN873A<FEO`$]R9&5N87(@
M<V5L9>?C;P!%;F1E<F7G;R!D92!O<FEG96T`P69R:6-A(&1O(%-U;`!3=6P@
M175R;W!E=2`H25-/+3@X-3DM,RD`4W5L(&1A($=E;W)G:6$@92!3=6P@9&%S
M($EL:&%S(%-A;F1U[6-H90!(96UI<V;I<FEO(%-U;`!%<W!AYV\@96YT<F4@
M8^EL=6QA<R!A9&IA8V5N=&5S`$5S<&'G;R!E;G1R92!O(&-O;G1E^F1O(&4@
M8F]R9&$@9&$@8^EL=6QA`$5S<&'G861O<@!%<W!AYV%M96YT;P!%<W!AYV%M
M96YT;R!E(&UA<F=E;0!%<W!A;FAA`%-P86T`4&%S=&$@9&4@4W!A;3H`16YT
M<F%D82!D92!#87)A8W1E<F5S($5S<&5C:6%I<P!#87)A8W1E<F5S($5S<&5C
M:6%I<P!087-T87,@17-P96-I86ES(%9I<G1U86ES(&[C;R!P;V1E;2!S97(@
M961I=&%D87,N`%9E<FEF:6-A<B!/<G1O9W)A9FEA`%9E<FEF:6-AY^-O($]R
M=&]G<N%F:6-A`%9E<FEF:6-AY^-O(&]R=&]G<N%F:6-A(&-O;7!L971A`$[Z
M;65R;R!D92!E<G)O<R!D92!O<G1O9W)A9FEA('!O<B!T96QA(&1U<F%N=&4@
M82!V97)I9FEC8>?C;RX`1&EV:61I<B!CZ6QU;&$`1&EV:61I<B!C;VQU;F$`
M1&EV:61I<B!L:6YH80!%<W!O<G1E<P!3<FD@3&%N:V$`4&%D<N-O`%-T87(@
M5')E:P!);FEC:6%R`$%N;R!I;FEC:6%L`$5S=&%D;R!O=2!0<F]V[6YC:6$`
M4&%P96P@9&4@0V%R=&$`3F]M92!D;R!P87!E;"!D92!C87)T83H`5&EP;R!D
M92!P87!E;"!D92!C87)T83H`4&%P96P@9&4@0V%R=&$Z`%-I='5AY^-O`$9O
M<FUA=&\@9&\@87)M87IE;F%M96YT;P!.;VUE(&1A(%)U80!4<F'G861O`$QI
M<W1A(&1E(&-A9&5I87,@9&4@8V%R86-T97)E<P!296UO=F5R($%N97AO`%)E
M=&ER87(@82!P87)T92!D;R!D;VWM;FEO(&1O(&5N9&5R9>=O`%)E;6]V97(@
M<75E8G)A<R!D92!L:6YH83\`17-T:6QO(%M#4U-=`$1O;0!?07-S=6YT;P!3
M=6)D:7)E=/-R:6\@)R5S)R!NXV\@96YC;VYT<F%D;RX`07-S=6YT;P!#86UP
M;R!!<W-U;G1O`$5N=FEA<@!%;G9I861A(&$@<V]L:6-I=&'GXV\@9&4@861I
M8VEO;F%R("(E<R(@86\@<VES=&5M82X@5F]CZB!NXV\@<&]D92!C;VYE8W1A
M<BUS92!A=.D@<75E('-U82!S;VQI8VET8>?C;R!S96IA(&%P<F]V861A+@!)
M;G-C<F5V97(M<V4@X"AS*2!087-T82AS*0!3=6)S8W)E=F5R`%-U8V5S<V\`
M)R5S)R!A9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N`$]S(&1A
M9&]S(&1O('5S=>%R:6\@)R5S)R!F;W)A;2!R96UO=FED;W,@9&\@<VES=&5M
M82!C;VT@<W5C97-S;RX`)R5S)R!E>&-L=>UD;R!C;VT@<W5C97-S;RX`17AC
M;'7M9&\@)R5S)R!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+@!#;VYF:6=U<F'G
MXV\@<F5V97)T:61A(&-O;2!S=6-E<W-O+B!!='5A;&EZ92!P87)A('9E<B!A
M<R!A;'1E<F'G]65S+@!"86-K=7`@9&$@8V]N9FEG=7)AY^-O('-A;'9A(&-O
M;2!S=6-E<W-O+@!/(&)A8VMU<"!D;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C
M;R`E<R!F;VD@<V%L=F\@8V]M('-U8V5S<V\N`"<E<R<@871U86QI>F%D;R!C
M;VT@<W5C97-S;P`E<R!G<F%V861O(&-O;2!S=6-E<W-O`%-U9.-O`%-U9V5S
M=/5E<P!297-U;6\`06UA;FAE8V5R`%#T<BUD;RU3;VP`16YS;VQA<F%D;P!!
M;6%N:&5C97(`06UA;FAE8V5R+U#T<BUD;RU3;VP`06UA;FAE8V5R.B``4/1R
M+61O+5-O;`!0]'(M9&\M4V]L.B``4V]B<F5S8W)E=F5R`%-U<&]R=&4`4W5R
M:6YA;64`4V]B<F5N;VUE`%-V86QB87)D(&4@2F%N($UA>65N`%-U87II;.)N
M9&EA`%-UZ6-I80!4<F]C87(@;R!-Z71O9&\@9&4@0V]M<&]S:>?C;P!4<F]C
M87(@<&%R82!O(&5D:71O<B!(5$U,`%1R;V-A<B!P87)A(&\@961I=&]R(&1E
M('1E>'1O('!U<F\`4W7MYV$`3N-O(&5X8VQU:7(`4WEN8TU,`$5R<F\@9&4@
M<VEN=&%X92!N;W,@=&5R;6]S(&1A('!E<W%U:7-A`%)E</IB;&EC82#!<F%B
M92!D82!3[7)I80!496UP97-T861E`%1E;7!E<W1A9&5S(&4@5F5N=&%N:6$`
M5&5M<&5S=&%D97,`5&5M<&5S=&%D97,@36%T:6YA:7,`07)Q=6EV;R!44U8`
M5&%B96QA`%!R;W!R:65D861E<R!D82!486)E;&$`5&%B96QA`%!R;W!R:65D
M861E<R!D82!T86)E;&$`5&%I=V%N`%1A:7=A;BP@4')O=NUN8VEA(&1A($-H
M:6YA`%1A:FEQ=6ES=.-O`%1A;GKB;FEA+"!297#Z8FQI8V$@9&$`06QV;SH`
M5&%R969A<P!495]X=&\`3OIM97)O(&1E(%1E;&5F;VYE`%1E;7!E<F%T=7)A
M('!A<F$@82#Z;'1I;6$@:&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A
M.B``5&5M<&5R871U<F$\8G(@+SXH)7-!;'1A)7,O)7-"86EX825S*2`F9&5G
M.R5S`$UO9&5L;R`G)7,G(&[C;R!E;F-O;G1R861O+@!!9&UI;FES=')AY^-O
M(&1E($UO9&5L;W,`4')O=FES\W)I;SH@`$%C96ET87(@<V]L:6-I=&'GXV\@
M<')O=FES;W)I86UE;G1E`$%C96ET;R!0<F]V:7-O<FEA;65N=&4`07)Q=6EV
M;R!D92!497)M;W,@9&\@4V5R=FGG;R!NXV\@97-P96-I9FEC861O(&5M(&-O
M;F8N<&AP`%1E7WAT;P!3;VUE;G1E(%1E>'1O`$%L:6YH86UE;G1O(&1E(%1E
M>'1O`$)O<F1A('-U<&5R:6]R(&1O(%1E>'1O`%%U:0!486EL86YDZG,@*%1)
M4RTV,C`I`%1A:6SB;F1I80!!(&5X=&5N<^-O($944"!NXV\@97-TX2!D:7-P
M;V[M=F5L+@!!(&-O;'5N82!$93H@;F$@;65N<V%G96T@9&5V92!S97(@;&EG
M861A(&$Z`$\@:&ES=/-R:6-O(&1O('-I<W1E;6$@97-TX2!D97-A8FEL:71A
M9&\N`$$@96YG:6YE(&1E(&EN=&5G<F'GXV\@2&]R9&4O2V]L86(@;N-O('-U
M<&]R=&$@(B5S(@!/('-E<G9I9&]R($E-05`@<&%R96-E(&[C;R!S=7!O<G1A
M<B!O(&WI=&]D;R!D92!A=71E;G1I8V'GXV\@<V5L96-I;VYA9&\N(%!O<B!F
M879O<B!E;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(@9&\@
M<VES=&5M82X`3R!L;V<@24U34"!NXV\@<&]D92!S97(@:6YI8VEA;&EZ861O
M+@!&;W)K(&1E(')E8W5R<V]S($UA8VEN=&]S:`!&;W)K(&1E(')E8W5R<V]S
M($UA8VEN=&]S:"!P;V1E('-E<B!B86EX861O("5S+@!!(&-L87-S92`B36%I
M;G1E;F%N8V4B(&[C;R!F;VD@8V%R<F5G861A(&-O;2!S=6-E<W-O`$$@:F%N
M96QA(&1E($]PY_5E<R!F;VD@9F5C:&%D82X@4V%I;F1O+@!!(&-O;G1A("(E
M<R(@9F]I(&5X8VQU[61A+@!!(&-O;G1A("(E<R(@9F]I('-A;'9A+@!/(&%D
M;6EN:7-T<F%D;W(@<')E8VES82!C;VYF:6=U<F%R('5M(&-O;F5C=&]R('!E
M<FUA;F5N=&4@9&4@4&5R;6ES<_5E<R!S92!V;V/J('%U97(@=71I;&EZ87(@
M4&5R;6ES<_5E<RX`3R!A;F5X;R!NXV\@9F]I(&5N8V]N=')A9&\N`%-O;65N
M=&4@;R!L861O(&1E(&)A:7AO`$\@9&%D;R!D82!A9V5N9&$@Z2!I;G;A;&ED
M;P!!(&IA;F5L82!D92!C;VUP;W-IY^-O(&[C;R!P;V1E('-E<B!A8F5R=&$N
M(%1A;'9E>B!V;V/J('1E;FAA(&-O;F9I9W5R861O('-E=2!N879E9V%D;W(@
M<&%R82!B;&]Q=65A<B!P;W`M=7!S/P!/(&[Z;65R;R!)1"!D;R!C;VYT871O
M(&[C;R!F;VD@97-P96-I9FEC861O+"!D96EX861O(&5M(&)R86YC;R!O=2!N
MXV\@9F]I(&5N8V]N=')A9&\@;F\@8F%N8V\@9&4@9&%D;W,N`$\@8V]N=&%T
M;R!F;VD@861I8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S974@8V%TX6QO9V\@
M9&4@96YD97)EYV]S+@!/(&-O;G1E^F1O(&1O(&%R<75I=F\@36%C:6YT;W-H
M(&5S=.$@86)A:7AO+@!!*',I('!A<W1A*',I("(E<R(@871U86PH:6%S*2!S
M97+A*.-O*2!R96YO;65A9&$H<RD@<&%R82`B)7,B+@!!(&QI<W1A(&%T=6%L
M(&1E('5S=>%R:6]S(&-O;2!A8V5S<V\@82!E<W1A('!A<W1A(&[C;R!P]&1E
M('-E<B!O8G1I9&$`4&%R82!V97)I9FEC87(@82!M96YS86=E;2!A<W-I;F%D
M82#I(&YE8V5S<^%R:6\@=6T@8FQO8V\@<V5P87)A9&\@9&$@87-S:6YA='5R
M82!01U`N`$\@240@9&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@
M97-P96-I9FEC861O+"!D96EX861O(&5M(&)R86YC;R!O=2!NXV\@9F]I(&5N
M8V]N=')A9&\@;F\@8F%N8V\@9&4@9&%D;W,N`$$@;&ES=&$@9&4@9&ES=')I
M8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861A+@!/(')A<V-U;FAO(&9O:2!S
M86QV;R!N82!P87-T82`B)7,B+@!!<R!F=6[G]65S(&1E(&-R:7!T;V=R869I
M82!R97%U97)E;2!U;6$@8V]N97CC;R!W96(@<V5G=7)A+@!/(&5V96YT;R!F
M;VD@861I8VEO;F%D;R!E;2!S=6$@86=E;F1A+@!/(&-A;7!O("(E<R(@;N-O
M('!O9&4@<V5R(&5X<&%N9&ED;RX`3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N
M=&5R('5M82!C;VYF:6=U<F'GXV\@9&4@)7,N`$\@87)Q=6EV;R`E<R!D979E
M<FEA(&-O;G1E<B!A;&=U;6%S(&-O;F9I9W5R8>?U97,@9&4@)7,N`$\@87)Q
M=6EV;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A(&5L92!M97-M;RX`3R!A
M<G%U:79O(&[C;R!C;VYTZ6T@9&%D;W,N`$$@<&%S=&$@(B5S(B!JX2!E>&ES
M=&4`02!P87-T82`B)7,B(&-O;G1E;2!C87)A8W1E<F5S(&EL96=A:7,@96T@
M<V5U(&YO;64N($ES=&\@<&]D92!C875S87(@<')O8FQE;6%S+B!0;W(@9F%V
M;W(@96YT<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R(&1O('-I
M<W1E;6$N`$$@<&%S=&$@(B5S(B!F;VD@8W)I861A(&UA<R!V;V/J(&[C;R!F
M;VD@:6YS8W)I=&\@;F5L82X`02!P87-T82`B)7,B(&9O:2!E>&-L=>UD82!M
M87,@=F]CZB!NXV\@<V4@9&5S:6YS8W)E=F5U(&1E;&$N`$$@<&%S=&$@(B5S
M(B!F;VD@8W)I861A+B!)<W1O(.D@;R!Q=64@;R!S97)V:61O<B!D:7-S90!!
M('!A<W1A("(E<R(@;N-O(&9O:2!E>&-L=>UD82X@27-T;R#I(&\@<75E(&\@
M<V5R=FED;W(@9&ES<V4`02!P87-T82`B)7,B(&9O:2!C<FEA9&$@8V]M('-U
M8V5S<V\N`$$@<&%S=&$@(B5S(B!F;VD@97AC;'7M9&$@8V]M('-U8V5S<V\N
M`$$@<&%S=&$@(B5S(B!F;VD@<F5N;VUE861A('!A<F$@(B5S(B!C;VT@<W5C
M97-S;RX`4V5G=65M(&]S(&-A8F7G86QH;W,@9&5S=&$@;65N<V%G96TO;65N
M<V%G96T@<F9C.#(R+@!/<R!S96=U:6YT97,@87)Q=6EV;W,@9F]R86T@86YE
M>&%D;W,@82!E<W1A('!A<G1E.@#)('-A8FED;R!Q=64@;R!M;V1O('1E;&$@
M8VAE:6$@8V%U<V$@<')O8FQE;6%S(&-O;2!O($EN=&5R;F5T($5X<&QO<F5R
M+"!E;2!V:7)T=61E(&1E(&)U9W,@9&\@;F%V96=A9&]R('%U92!N\W,@;N-O
M(&5S=&%M;W,@87!T;W,@82!C;VYT;W)N87(N(%9O8^H@<&]D92!O8G-E<G9A
M<B!E<G)O<R!D92!E>&EB:>?C;RP@9F%L=&$@9&4@9G5NY_5E<R!D;R!E9&ET
M;W(@92]O=2!T<F%V86UE;G1O<R!A;&5A=/-R:6]S(&1O(&YA=F5G861O<BX@
M4V4@<V5U('-I<W1E;6$@Z2!7:6YD;W=S(#EX(.D@;75I=&\@<')O=N%V96P@
M<75E('9O8^H@<F5C96)A('5M(&5R<F\@9&4@)T9A;&AA($=E<F%L(&1E(%!R
M;W1EY^-O)R!E('!R96-I<V%RX2!R96EN:6-I87(N(%QN7&X@5F]CZB!F;VD@
M879I<V%D;RX@4&]R(&9A=F]R('!R97-S:6]N92!/2R!S92!V;V/J(&%I;F1A
M('%U97(@=&5N=&%R('5S87(@;R!E9&ET;W(@9&4@=&5L82!C:&5I82X`02!I
M9&5N=&ED861E("(E<R(@9F]I(&5X8VQU[61A+@!!(&IA;F5L82!D92!C;VUP
M;W-IY^-O(&[C;R!P;V1E('-E<B!A8F5R=&$N(%1A;'9E>B!V;V/J('1E;FAA
M(&-O;F9I9W5R861O('-E=2!N879E9V%D;W(@<&%R82!B;&]Q=65A<B!P;W`M
M=7!S/P!!<R!I;6%G96YS('-E<N-O(&5X:6)I9&%S('!O<G%U92!O(')E;65T
M96YT92!E<W3A('!R97-E;G1E(&5M('-E=2!C873A;&]G;R!D92!E;F1E<F7G
M;W,N`%-O;65N=&4@;R!L861O(&5S<75E<F1O`$$@;&]C86QI>F'GXV\@9&\@
M8FENX7)I;R!D;R!';G501R!D979E('-E<B!F;W)N96-I9&$@X"!C;&%S<V4@
M(D-R>7!T7W!G<"(N`$\@<V5R=FED;W(@9&4@8V]R<F5I;R!G97)O=2!A('-E
M9W5I;G1E(&UE;G-A9V5M(&1E(&5R<F\Z`$\@<V5R=FED;W(@9&4@8V]R<F5I
M;R!G97)O=2!A('-E9W5I;G1E(&UE;G-A9V5M(&EN9F]R;6%T:79A.@!/('-E
M<G9I9&]R(&1E(&-O<G)E:6\@9V5R;W4@82!S96=U:6YT92!M96YS86=E;3H`
M02!C86EX82!P;W-T86P@)7,@:N$@97-TX2!V87II82X`02!M96YS86=E;2`B
M)7,B(&1E("(E<R(@*"5D(&)Y=&5S*2!E>&-E9&5U(&\@;&EM:71E(&1E('1A
M;6%N:&\@<&%R82!T<F%Z97(N`$$@;65N<V%G96T@<V5N9&\@8V]M<&]S=&$@
M9F]I(&9E8VAA9&$N(%-A:6YD;RX`02!M96YS86=E;2!NXV\@<&]S<W5I('5M
M($%S<W5N=&\N`$$@;65N<V%G96T@9F]I(&5X8VQU[61A+@!!(&UE;G-A9V5M
M(&9O:2!V97)I9FEC861A+@!!(&UE;G-A9V5M(&9O:2!V97)I9FEC861A+B!2
M96UE=&5N=&4Z("5S+@!!(&UE;G-A9V5M(&5N=FEA9&$@96T@)7,@<&%R82`E
M<R!C;VT@;R!A<W-U;G1O("(E<R(@9F]I(&5X:6)I9&$N"DES=&\@;N-O(&=A
M<F%N=&4@<75E(&$@;65N<V%G96T@9F]I(&QI9&$@;W4@96YT96YD:61A+@!/
M(&YO;64@=71I;&EZ861O(&%O('9I;F-U;&%R(&$@<.%G:6YA(&1E(&-O;7!O
M<VGGXV\`3R!N^FUE<F\@9&4@8V%M<&]S(&1E=F4@<V5R(&YU;>ER:6-O+@!/
M(&WS9'5L;R!O<&5N<W-L(.D@;V)R:6=A=/-R:6\@<&%R82!A(&-L87-S92`B
M2&]R9&5?0W)Y<'1?<VUI;64B+@!!(&IA;F5L82!D92!S96YH82!NXV\@9F]I
M(&%B97)T82X@5&%L=F5Z('9O8^H@=&5N:&$@8V]N9FEG=7)A9&\@<V5U(&YA
M=F5G861O<B!P87)A(&)L;W%U96%R('!O<"UU<',_`$$@<')E9F5RZFYC:6$@
M(B5S(B!NXV\@<&]D92!S97(@<V%L=F$@<&]R<75E('-E=7,@9&%D;W,@97AC
M961E<F%M(&\@=&%M86YH;R!MX7AI;6\@<&5R;6ET:61O`$\@<')O9W)A;6$@
M=71I;&EZ861O('!A<F$@=FES=6%L:7IA<B!E<W1E('1I<&\@9&4@9&%D;R`H
M)7,I(&[C;R!F;VD@96YC;VYT<F%D;R!N;R!S:7-T96UA+@!/(&-A<F%C=&5R
M92!P87)A(&-I=&'GXV\@9&4@<V5R(&%P96YA<R!U;2X`3R!T97AT;R!P=7)O
M(&1A($-H879E(%#Z8FQI8V$@4$=0('!O9&4@<V5R('9I<W5A;&EZ861A("5S
M+@!/(&%R<75I=F\@<V]L:6-I=&%D;R!NXV\@97AI<W1E(&YO(&%N97AO($U3
M+51.148N`$\@87)Q=6EV;R!S;VQI8VET861O(&[C;R!E>&ES=&4@;F\@86YE
M>&\@6FEP+@!3;VUE;G1E(&]S(&QA9&]S(&1I<F5I=&\@92!E<W%U97)D;P!3
M;VUE;G1E(&\@;&%D;R!D:7)E:71O`$\@<F5M971E;G1E(&1E<W1A(&UE;G-A
M9V5M(&5S=.$@<V]L:6-I=&%N9&\@=6UA($YO=&EF:6-AY^-O(&1E($1I<W!O
M<VGGXV\@9&4@365N<V%G96T@9&4@=F]CZB!Q=6%N9&\@=&EV97(@;&ED;R!E
M<W1A(&UE;G-A9V5M+B!0;W(@9F%V;W(@8VQI<75E(&5M("5S('!A<F$@96YV
M:6%R(&$@;65N<V%G96T@9&4@;F]T:69I8V'GXV\N`$\@<V5P87)A9&]R(&1E
M=F4@<V5R('5M(/IN:6-O(&-A<F%C=&5R92X`3R!S97)V:61O<B`B)7,B(&9O
M:2!E>&-L=>UD;RX`3R!S97)V:61O<B`B)7,B(&9O:2!S86QV;RX`3R!S97)V
M:61O<B!NXV\@8V]N<V5G=6EU(&-R:6%R('5M82!M:6YI871U<F$@9&5S=&$@
M:6UA9V5M+@!!(&%S<VEN871U<F$@;N-O('#T9&4@<V5R('-U8G-T:71U[61A
M+@!!(&%S<VEN871U<F$@9F]I('-U8G-T:71U[61A(&-O;2!S=6-E<W-O+@!!
M('-O;&EC:71AY^-O(&1E(&-A9&%S=')O(&1E("5S(&9O:2!E>&-L=>UD82X`
M3R!A<G%U:79O(&5S<&5C:69I8V%D;R!NXV\@97AI<W1E+@!!(&QI;FAA(&5S
M<&5C:69I8V%D82`H)60I(&[C;R!E>&ES=&4N`$\@<&%P96P@9&4@8V%R=&$@
M(B5S(B!F;VD@861I8VEO;F%D;RX`3R!P87!E;"!D92!C87)T82`B)7,B(&9O
M:2!E>&-L=>UD;RX`3R!P87!E;"!D92!C87)T82`B)7,B(&9O:2!A='5A;&EZ
M861O+@!!('1A<F5F82!F;VD@861I8VEO;F%D82!A('-U82!L:7-T82!D92!T
M87)E9F%S+@!/(&%R<75I=F\@=&5M<&]RX7)I;R`B)7,B(&[C;R!E>&ES=&4N
M`$\@=&5X=&\@9&$@;65N<V%G96T`3R!T97AT;R!D82!M96YS86=E;2!P;V1E
M('-E<B!V:7-U86QI>F%D;R`E<RX`3R!T97AT;R!D82!M96YS86=E;2!D92!R
M971O<FYO`$\@=&5X=&\@9&$@;65N<V%G96T@9&4@<F5T;W)N;R!P;V1E('-E
M<B!V:7-U86QI>F%D;R`E<RX`3R!T97AT;R!D82!M96YS86=E;2!E;G9I861A
M`$\@=&5X=&\@9&$@;65N<V%G96T@96YV:6%D82!P;V1E('-E<B!V:7-U86QI
M>F%D;R`E<RX`3R!T97AT;R!Q=64@=F]CZB!D:6=I=&]U(&[C;R!C;W)R97-P
M;VYD92!A;R!T97AT;R!N82!T96QA+@!3;VUE;G1E(&]S(&QA9&]S(&1E(&-I
M;6$@92!D92!B86EX;P!3;VUE;G1E(&\@;&%D;R!D92!C:6UA`$]S(&1A9&]S
M(&5N=FEA9&]S(&9O<F%M('!E<F1I9&]S(&1E<V1E(&\@<&%S<V\@86YT97)I
M;W(N`$\@87)Q=6EV;R!E;G9I861O(&[C;R!P]&1E('-E<B!S86QV;RX`02!I
M;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\@9&\@=7-UX7)I;R!F;VD@87)M87IE
M;F%D82!C;VT@<W5C97-S;RX`3R!B;&]C;R`B=V5A=&AE<BYC;VTB(&[C;R!E
M<W3A(&1I<W!O;NUV96PN`$\@9&ER973S<FEO(&1E('1E;6%S("<E<R<@;N-O
M(&9O:2!E;F-O;G1R861O+@!.XV\@97AI<W1E;2!P87)T97,@86QT97)N871I
M=F%S('%U92!P;V1E;2!S97(@97AI8FED87,@:6YC;W)P;W)A9&%S+@!.XV\@
M97AI<W1E;2!M96YS86=E;G,@;F5S=&$@8V%I>&$@<&]S=&%L+@!.XV\@97AI
M<W1E;2!O<.?U97,@9&ES<&]N[79E:7,N`$[C;R!E>&ES=&5M('!A<G1E<R!Q
M=64@<&]S<V%M('-E<B!E>&EB:61A<R!I;F-O<G!O<F%D87,N`$5X:7-T96T@
M;75I=&]S(&-A<F%C=&5R97,@;F5S=&4@8V%M<&\N(%9O8^H@<')E96YC:&5U
M(&-O;2`E<R!C87)A8W1E<F5S.R!V;V/J(&1E=F4@<')E96YC:&5R(&-O;2`E
M<R!O=2!M96YO<RX`3N-O(&5X:7-T96T@<&%R=&5S(&%L=&5R;F%T:79A<R!Q
M=64@<&]D96T@<V5R(&5X:6)I9&%S(&EN8V]R<&]R861A<RX`2&]U=F4@=6T@
M<')O8FQE;6$@861I8VEO;F%N9&\@)R5S)R!A;R!S:7-T96UA.B`E<P!(;W5V
M92!U;2!P<F]B;&5M82!A;R!E>&-L=6ER(&1O('-I<W1E;6$@;W,@9&%D;W,@
M9&\@=7-UX7)I;R`G)7,G.B``2&]U=F4@=6T@<')O8FQE;6$@86\@97-V87II
M87(@82!C86EX82!P;W-T86PN($\@<V5R=FED;W(@9&ES<V4Z("5S`$AO=79E
M('5M('!R;V)L96UA(&%O(&5X8VQU:7(@)R5S)R!D;R!S:7-T96UA.B``2&]U
M=F4@=6T@<')O8FQE;6$@86\@871U86QI>F%R("<E<R<Z("5S`$AO=79E('5M
M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\Z($YE;FAU;2`E<R!F
M;VD@96YV:6%D;RX`2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@96YV:6\@9&\@
M87)Q=6EV;RX@3R`E<R!E<F$@;6%I;W(@<75E(&\@=&%M86YH;R!MX7AI;6\@
M<&5R;6ET:61O("@E9"!B>71E<RDN`$AO=79E('5M('!R;V)L96UA(&-O;2!O
M(&5N=FEO(&1O(&%R<75I=F\N($\@)7,@9F]I(&5N=FEA9&\@<&%R8VEA;&UE
M;G1E+@!(;W5V92!U;2!E<G)O(&%O(&-O<&EA<B!M96YS86=E;G,@9&4@(B5S
M(B!P87)A("(E<R(N($ES=&\@Z2!O('%U92!O('-E<G9I9&]R(&1I<W-E`$AO
M=79E('5M(&5R<F\@86\@97AC;'5I<B!M96YS86=E;G,@9&$@<&%S=&$@(B5S
M(BX@27-T;R!F;VD@;R!Q=64@;R!S97)V:61O<B!D:7-S90!(;W5V92!U;2!E
M<G)O(&%O(&5X8VQU:7(@;65N<V%G96YS(&YA('!A<W1A("(E<R(N($ES=&\@
MZ2!O('%U92!O('-E<G9I9&]R(&1I<W-E`$AO=79E('5M(&5R<F\@86\@97AC
M;'5I<B!A<R!M96YS86=E;G,N($ES=&\@9F]I(&\@<75E(&\@<V5R=FED;W(@
M9&ES<V4Z("5S`$AO=79E('5M(&5R<F\@86\@97AC;'5I<B!O(&5V96YT;SH@
M)7,N`$AO=79E('5M(&5R<F\@86\@97AI8FER(&5S=&$@<&%R=&4@9&$@;65N
M<V%G96T`2&]U=F4@=6T@97)R;R!A;R!M87)C87(@87,@;65N<V%G96YS(&YE
M<W1A('!A<W1A("(E<R(N($ES=&\@Z2!O('%U92!O('-E<G9I9&]R(&1I<W-E
M`$AO=79E('5M(&5R<F\@86\@:6UP;W)T87(@)7,N`$AO=79E('5M(&5R<F\@
M86\@:6UP;W)T87(@;W,@9&%D;W,@9&\@8V]N=&%T;RX`2&]U=F4@=6T@97)R
M;R!A;R!I;7!O<G1A<B!O(&5V96YT;SH@)7,N`$AO=79E('5M(&5R<F\@86\@
M:6UP;W)T87(@;W,@9&%D;W,@9&\@:4-A;&5N9&%R+@!(;W5V92!U;2!E<G)O
M(&%O(&EM<&]R=&%R(&$@=&%R969A.B`E<RX`2&]U=F4@=6T@97)R;R!A;R!I
M;7!O<G1A<B!A(&EN9F]R;6'GXV\@;&EV<F4O;V-U<&%D;R!D;R!U<W7A<FEO
M.B`E<RX`2&]U=F4@=6T@97)R;R!N;R!F;W)M=6SA<FEO(&1E(&-O;F9I9W5R
M8>?C;RX@5&%L=F5Z('9O8^H@9&5I>&]U('5M(&-A;7!O(&]B<FEG873S<FEO
M(&5M(&)R86YC;RX`2&]U=F4@=6T@97)R;R!A;R!M;W9E<B!M96YS86=E;G,@
M9&4@(B5S(B!P87)A("(E<R(N($ES=&\@Z2!O('%U92!O('-E<G9I9&]R(&1I
M<W-E`$AO=79E('5M(&5R<F\@86\@97AE8W5T87(@82!F=6[GXV\@9&4@8V%T
MX6QO9V\@9&4@96YD97)EYV]S(&5S<&5C:69I8V%D82X@4&]R(&9A=F]R('1E
M;G1E(&YO=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O('-A
M;'9A<B!E<W1A(&UE;G-A9V5M(&-O;6\@<F%S8W5N:&\N`$AO=79E('5M(&5R
M<F\@86\@96YV:6%R(&5S=&$@;65N<V%G96TZ("5S`$AO=79E('5M(&5R<F\@
M86\@871U86QI>F%R(&]S(&1E=&%L:&5S(&1O(&-O;G1A=&\N(%!O<B!F879O
M<B!T96YT92!N;W9A;65N=&4@;6%I<R!T87)D92X`2&]U=F4@=6T@97)R;R!A
M;R!A='5A;&EZ87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N(%!O<B!F879O
M<B!T96YT92!N;W9A;65N=&4@;6%I<R!T87)D92X`2&]U=F4@=6T@97)R;R!A
M;R!A='5A;&EZ87(@;R!E=F5N=&\Z("5S+@!.XV\@:&%V:6$@=&5X=&\@;F5S
M=&$@<&%R=&4@9&$@;65N<V%G96T`17-T82!M96YS86=E;2!(5$U,('1E;2!I
M;6%G96YS(&EN8V]R<&]R861A<R!A(&5L82X`17-T82!M96YS86=E;2!(5$U,
M('1E;2!I;6%G96YS(&EN8V]R<&]R861A<R!A(&5L82X@26UA9V5N<R!B;&]Q
M=65A9&%S(&%P87)E8V5M(&1E<W1A(&9O<FUA.B``17-T92!S97)V:61O<B!)
M34%0(&[C;R!S=7!O<G1A('!A<W1A<R!C;VUP87)T:6QH861A<RX`02!#:&%V
M92!0^F)L:6-A(%!'4"!F;VD@86YE>&%D82!A(&5S=&$@;65N<V%G96TN`$5S
M=&$@8>?C;R!NXV\@Z2!S=7!O<G1A9&$N`$5S=&$@8>?C;R!A:6YD82!NXV\@
M97-TX2!I;7!L96UE;G1A9&$N`$5S=&4@;N-O('!A<F5C92!S97(@=6T@87)Q
M=6EV;R!R87(@=N%L:61O+@!%<W1E(&[C;R!P87)E8V4@<V5R('5M(&%R<75I
M=F\@>FEP(';A;&ED;RX`17-T92!NXV\@<&%R96-E('-E<B!U;2!N^FUE<F\@
M9&4@8V%R=.-O(';A;&ED;RX`17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA
M<B!M96YS86=E;G,@871R87;I<R!D;R!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI+"!U=&EL:7IA;F1O(&$@05!)($A45%``17-T92!C;VYE
M8W1O<B!P97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R87;I<R!D;R!G871E
M=V%Y('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!U=&EL:7IA
M;F1O(&\@05!)($A45%``17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!M
M96YS86=E;G,@871R87;I<R!D;R!G871E=V%Y('-M<S)E;6%I;"`H:'1T<#HO
M+W-M<S)E;6%I;"YC;VTI+"!U=&EL:7IA;F1O(&\@05!)($A45%``17-T92!C
M;VYE8W1O<B!P97)M:71E(&5N=FEA<B!U;6$@;65N<V%G96T@=FEA(%--5%`@
M871R87;I<R!D;R!6;V1A9F]N92!)=&%L:6%N;RP@<V]M96YT92!P87)A(&[Z
M;65R;W,@5F]D869O;F4N(,D@;V)R:6=A=/-R:6\@<&]S<W5I<B!U;6$@8V]N
M=&$@;F\@5F]D869O;F4@271A;&EA;F\@*&AT='`Z+R]W=W<N,3DP+FET*2X`
M17-T92!C86UP;R#I(&]B<FEG873S<FEO+@!%<W1E(&-A;7!O('!O9&4@8V]N
M=&5R(&%P96YA<R!N^FUE<F]S(&EN=&5I<F]S+@!%<W1E(&-A;7!O('!O9&4@
M8V]N=&5R(&%P96YA<R!N^FUE<F]S(&4@=NUR9W5L82X`17-T92!C86UP;R!P
M;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O8W1A:7,N`$5S=&4@8V%M<&\@
M9&5V92!S97(@=6UA(&QI<W1A(&1E(&[Z;65R;W,@:6YT96ER;W,@<V5P87)A
M9&$@<&]R(';M<F=U;&%S(&]U(&5S<&'G;W,`17-T92!C86UP;R!D979E('-E
M<B!U;2!N^FUE<F\@=N%L:61O+@!%<W1E(&-A;7!O(&1E=F4@8V]N=&5R('5M
M(&/S9&EG;R!D92!C;W(@96T@9F]R;6%T;R!21T(@2&5X82P@<&]R(&5X96UP
M;&\@)R,Q,C,T868G+@!%<W1E(&9O<FUU;.%R:6\@:N$@9F]I('!R;V-E<W-A
M9&\N`$ES=&\@Z2`E<RX`17-T92#I('5M(&]B:F5T;R!+;VQA8B!'<F]U<'=A
M<F4N(%!A<F$@=FES=6%L:7IA<B!E<W1E(&]B:F5T;R!V;V/J('!R96-I<V%R
MX2!D92!U;2!C;&EE;G1E(&1E(&-O<G)E:6\@<75E(&5N=&5N9&$@;R!F;W)M
M871O($MO;&%B($=R;W5P=V%R92X@4&%R82!U;6$@;&ES=&$@9&4@8VQI96YT
M97,@9&4@8V]R<F5I;R!C;VT@97-T87,@9G5NY_5E<R!P;W(@9F%V;W(@=FES
M:71E("5S`$ES=&\@<&]D92!L979A<B!A;&=U;2!T96UP;RX@5F]CZB!T96T@
M8V5R=&5Z82!Q=64@<75E<B!P<F]S<V5G=6ER/P!%<W1A(&UE;G-A9V5M(&-O
M;G3I;2!U;2!A<G%U:79O($UA8VEN=&]S:"X`17-T82!M96YS86=E;2!C;VYT
MZ6T@=6T@86YE>&\@<75E(&9O:2!A<W-I;F%D;R!D:6=I=&%L;65N=&4@8V]M
M(%,O34E-12X`17-T82!M96YS86=E;2!C;VYTZ6T@=6T@86YE>&\@<75E(&9O
M:2!C<FEP=&]G<F%F861O(&-O;2!3+TU)344N`$5S=&$@;65N<V%G96T@8V]N
M=.EM(&EN9F]R;6'GXV\@9&4@<VET=6'GXV\@9&4@96YT<F5G82P@;6%S(&\@
M9F]R;6%T;R!D82!M96YS86=E;2#I(&1E<V-O;FAE8VED;RX`17-T82!M96YS
M86=E;2!NXV\@<&%R96-E('-E<B!U;6$@;65N<V%G96T@=N%L:61A(&-R:7!T
M;V=R869A9&$@8V]M(%!'4"X@17)R;SH@`$5S=&$@;65N<V%G96T@;N-O('!A
M<F5C92!E<W1A<B!N;R!F;W)M871O(&-O<G)E=&\@4$=0("AD92!A8V]R9&\@
M8V]M(&$@4D9#(#(P,34I+@!%<W1A(&UE;G-A9V5M(&[C;R!P87)E8V4@97-T
M87(@;F\@9F]R;6%T;R!C;W)R971O(%,O34E-12X`17-T82!M96YS86=E;2!F
M;VD@87-S:6YA9&$@9&EG:71A;&UE;G1E(&-O;2!01U`N`$5S=&$@;65N<V%G
M96T@9F]I(&%S<VEN861A(&1I9VET86QM96YT92!C;VT@4R]-24U%+@!%<W1A
M(&UE;G-A9V5M(&9O:2!C<FEP=&]G<F%F861A(&-O;2!3+TU)344N`$5S=&$@
M;65N<V%G96T@9F]I(&-R:7!T;V=R869A9&$@8V]M(%!'4"X`17-T82!M96YS
M86=E;2!P87)A`$5S=&$@;65N<V%G96T@9F]I(&5S8W)I=&$@96T@=6T@8V]N
M:G5N=&\@9&4@8V%R86-T97)E<R`H)7,I('%U92!NXV\@Z2!O(&UE<VUO('%U
M92!O('-E=2X`17-T92!N^FUE<F\@9&5V92!S97(@<&5L;R!M96YO<R!U;2X`
M17-T92!S97)V:61O<B!NXV\@<&]D92!D97-C;VUP<FEM:7(@87)Q=6EV;W,@
M>FEP(&4@9WII<"X`3R!S97)V:61O<B!NXV\@<W5P;W)T82!P87-T87,@8V]M
M<&%R=&EL:&%D87,N`$5S=&4@<VES=&5M82!E<W3A(&%T=6%L;65N=&4@9&5S
M871I=F%D;RX`17-T92!V86QO<B!D979E('-E<B!U;2!N^FUE<F\N`$5S=&$@
M:F%N96QA(&1E=F4@<V5R(&%B97)T82!A('!A<G1I<B!D82!J86YE;&$@9&4@
M8V]M<&]S:>?C;RX`17-T82!J86YE;&$@9&5V92!S97(@8VAA;6%D82!A('!A
M<G1I<B!D82!J86YE;&$@9&4@3W#G]65S`$5X:6)IY^-O(&1A($1I<V-U<W/C
M;P!6:7-U86QI>F'GXV\@9&4@1&ES8W5S<_5E<P!286EO`$)I;&AE=&5S`$AO
M<F$`06-O;7!A;FAA;65N=&\@9&4@2&]RX7)I;P!&;W)M871O(&1E(&AO<F$`
M4V5L9>?C;R!D92!H;W)A`%1I;6]R($QE<W1E`%3M='5L;P!!<W-U;G1O("AD
M:6-A*3H`4&%R80!%;F1E<F7G;R!D;R!D97-T:6YA=.%R:6\@`%!A<F$@<V5L
M96-I;VYA<B!VX7)I;W,@8V%M<&]S+"!S96=U<F4@0V]N=')O;"`H4$,I(&]U
M($-O;6UA;F0@*$UA8RD@86\@8VQI8V%R+@!087)A('-E;&5C:6]N87(@;?IL
M=&EP;&]S(.UT96YS+"!S96=U<F4@82!T96-L82!#;VYT<F]L("A00RD@;W4@
M0V]M;6%N9"`H36%C*2!A;R!C;&EC87(N`%!A<F$@=71I;&EZ87(@=6UA(&-O
M;F5XXV\@5$Q3+"!V;V/J(&1E=F4@97-T87(@=71I;&EZ86YD;R!02%`@-2XP
M+C8@;W4@<W5P97)I;W(N`$AO:F4`5')O8V%R('!A<F$@8_-D:6=O($A434P`
M5&]G;P!4;VME;&%U`$%M86YHXP!4;VYG80!4;W!O`%%U861R;R!D;R!4;W!O
M("A?=&]P*0!486UA;FAO(%1O=&%L(&1O<R!!;F5X;W,Z`%1R861UY_5E<P!,
M:7AE:7)A`$QI>&5I<F$Z`%1R:6YD861E(&4@5&]B86=O`%9E<F1A9&5I<F\@
M;W4@9F%L<V\`5&5R`%1U;NUS:6$`5'5R<75I80!4=7)C;R`H25-/+3@X-3DM
M.2D`5'5R8V]M96YI<W3C;P!);&AA<R!4=7)K<R!E($-A:6-O<P!4=79A;'4`
M4')E96YC:&$@8V]M('-U82!E<V-O;&AA.B``S6YD:6-E(%4N5BXZ(`!54DP`
M55),(&1O('-E=2!R96QA=/-R:6\@9&4@<VET=6'GXV\@9&4@96YT<F5G80!5
M4DPZ`%5G86YD80!58W+B;FEA`$EM<&]S<^UV96P@86-E<W-A<B!D:7)E=/-R
M:6\@5D93+@!);7!O<W/M=F5L(&%D:6-I;VYA<B!I;F9O<FUAY_5E<R!E>'1R
M87,@9&4@=7-UX7)I;R!A;R!R96=I<W1R87(N`$EM<&]S<^UV96P@86QT97)A
M<B!P97)M:7-SXV\@9&\@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!A
M;'1E<F%R('!E<FUI<W/C;R!D;R!A<G%U:79O(%9&4R`E<R\E<RX`26UP;W-S
M[79E;"!A;'1E<F%R('!A<F$@)7,N`$EM<&]S<^UV96P@=F5R:69I8V%R(&\@
M=&%M86YH;R!D;R!A<G%U:79O(&1E("(E<R(N`$EM<&]S<^UV96P@=F5R:69I
M8V%R(&\@=&%M86YH;R!D;R!A<G%U:79O(&1E("(E<R\E<R(N`$EM<&]S<^UV
M96P@8V]N96-T87(@86\@<V5R=FED;W(@4U%,+@!);7!O<W/M=F5L(&-O;F5C
M=&%R('5T:6QI>F%N9&\@4U-,+@!);7!O<W/M=F5L(&-O<&EA<B!A<G%U:79O
M(%9&4RX`26UP;W-S[79E;"!C<FEA<B!D:7)E=/-R:6\@5D93("(E<R(N`$EM
M<&]S<^UV96P@8W)I87(@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!C<FEA
M<B!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O(%9&
M4R`B)7,B+@!);7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@5D93('9A>FEO+@!)
M;7!O<W/M=F5L(&1E<V-O;7!R:6UI<B!D861O<RX`26UP;W-S[79E;"!E>&-L
M=6ER("(E<R(L(&\@9&ER973S<FEO(&[C;R!E<W3A('9A>FEO+@!);7!O<W/M
M=F5L(&5X8VQU:7(@(B5S(CH@)7,N`$EM<&]S<^UV96P@97AC;'5I<B`E<RP@
M;R!D:7)E=/-R:6\@;N-O(&5S=.$@=F%Z:6\`26UP;W-S[79E;"!E>&-L=6ER
M(')E8W5R<VEV86UE;G1E(&\@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!E
M>&-L=6ER(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@97AC;'5I<B!D:7)E
M=/-R:6\@5D93.B`E<RX`26UP;W-S[79E;"!E>&-L=6ER(&%R<75I=F\@5D93
M("(E<R(N`$EM<&]S<^UV96P@97AC;'5I<B!A<G%U:79O(%9&4RX`26UP;W-S
M[79E;"!E>&-L=6ER(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@97AC
M;'5I<B!61E,@<F5C=7)S:79A;65N=&4Z("5S+@!);7!O<W/M=F5L(&1E=&5R
M;6EN87(@;R!D:7)E=/-R:6\@871U86PN`$EM<&]S<^UV96P@97AT<F%I<B!D
M971A;&AE<R!D;R!C97)T:69I8V%D;P!);7!O<W/M=F5L(&-A<G)E9V%R(&$@
M9&5F:6YIY^-O(&1E("5S+@!);7!O<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!6
M1E,N`$EM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S
M[79E;"!A8G)I<B!A<G%U:79O(%9&4R!P87)A(&=R879AY^-O+@!);7!O<W/M
M=F5L(&%B<FER(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&%B<FER(&%R<75I
M=F\@8V]M<')I;6ED;RX`26UP;W-S[79E;"!L97(@87)Q=6EV;R!61E,@*&9I
M;&5S:7IE*"D@9F%L:&]U*2X`26UP;W-S[79E;"!L97(@87)Q=6EV;R!61E,@
M*&=E=$9I;&53:7IE*"D@9F%L:&]U*2X`26UP;W-S[79E;"!L97(@;R!A<G%U
M:79O.B``26UP;W-S[79E;"!L97(@82!R86EZ(&1O(&1I<F5T\W)I;R!61E,N
M`$EM<&]S<^UV96P@<F5N;VUE87(@)7,@<&%R82`E<SH@82!P87-T82!D92!D
M97-T:6YO(&KA(&5X:7-T90!);7!O<W/M=F5L(')E;F]M96%R(&\@9&ER973S
M<FEO(%9&4RX`26UP;W-S[79E;"!R96YO;65A<B!D:7)E=/-R:6\@5D93.B`E
M<RX`26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O
M<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93("5S+R5S+@!);7!O<W/M=F5L
M(')E;F]M96%R(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&]B=&5R('%U;W1A
M`$EM<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G+@!);7!O<W/M=F5L('1R
M861U>FER(&5S=&4@9&]C=6UE;G1O(%=O<F0`26UP;W-S[79E;"!G<F%V87(@
M87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!G<F%V87(@87)Q=6EV;R!6
M1E,@*&-O<'DH*2!F86QH;W4I+@!);7!O<W/M=F5L(&=R879A<B!D861O<R!D
M;R!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!G<F%V87(@87)Q=6EV;R!61E,L
M('%U;W1A(&5X8V5D97+A+@!.XV\@4F5S<&]N9&ED80!-96YS86=E;G,@;N-O
M(')E<W!O;F1I9&%S`%)E<W1A=7)A<@!3=6)L:6YH861O`$1E<W1I;F%TX7)I
M;W,@3N-O(%)E=F5L861O<P!$97-F87IE<B!!;'1E<F'G]65S`$1E<V9A>B!S
M=6$@^FQT:6UA(&'GXV\`4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O
M<B!D=7)A;G1E(&$@8V]N97CC;SH@`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@
M<V5R=FED;W(@<&%R83H@`%-E;2!C871E9V]R:6$`0V]M<&]N96YT92!NXV\@
M<W5P;W)T861O(&1O('1I<&\Z("5S`%5N:6-O9&4@*%541BTX*0!%;6ER861O
M<R#!<F%B97,@56YI9&]S`%)E:6YO(%5N:61O`$5S=&%D;W,@56YI9&]S`$EL
M:&%S(%!E<FEFZ7)I8V%S($UE;F]R97,@9&]S($5S=&%D;W,@56YI9&]S`%5N
M:61A9&5S`$1E<V-O;FAE8VED;P!$871A($1E<V-O;FAE8VED80!297-P;W-T
M82!D97-C;VYH96-I9&$@9&\@<V5R=FED;W(@24U!4#H@;R!397)V:61O<B!2
M97-P;VYD974Z("5S`%)E=6YIXV\@1&5S8V]N:&5C:61A`$1E<W1I;F%TX7)I
M;R!$97-C;VYH96-I9&\`87!I;7-G:60@9&5S8V]N:&5C:61O("A!4$D@365S
M<V%G92!)1"DN`&-L:6US9VED(&1E<V-O;FAE8VED;R`H0VQI96YT($UE<W-A
M9V4@240I+@!.96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+@!5<W7A
M<FEO(&]U('-E;FAA(&1E<V-O;FAE8VED;W,N`$1E<W9I;F-U;&%R(&\@96QE
M;65N=&\@871U86P`1&5S8V%R<F5G87(@4V5N:&$`4V5M($YO;64`4V-R:7!T
M<R!NXV\@<')I=FEL96=I861O<R!NXV\@<&]D96T@=71I;&EZ87(@0V]R=&%R
M+T-O<&EA<B]#;VQA<B!P;W(@<F%Z]65S(&1E('-E9W5R86[G82X@0VQI<75E
M(&5M($]+('!A<F$@=F5R(&$@;F]T82!TZ6-N:6-A(&5M(&UO>FEL;&$N;W)G
M(&$@<75A;"!E;G-I;F$@8V]M;R!P97)M:71I<B!S8W)I<'1S(&%C97-S87)E
M;2!A(.%R96$@9&4@=')A;G-F97+J;F-I82X`3N-O($QI9&$`1&5S;6%R8V%R
M(&-O<@!$97-I;G-C<F5V97(M<V4@9&$H<RD@4&%S=&$H<RD`17AT96YSXV\@
M3N-O(%-U<&]R=&%D80!!='5A;&EZ87(`)7,@871U86QI>F%D;P!!='5A;&EZ
M87(@<VET=6'GXV\@9&$@<F5S<&]S=&$`071U86QI>F%R('5S=>%R:6\`)R5S
M)R!A='5A;&EZ861O+@!38W)I<'0@9&4@871U86QI>F'GXV\@<F5M;W9I9&\N
M`$5N=FEA<@!4;V1O<R!A<G%U:79O<R!D92`@8V]N9FEG=7)AY_5E<R!D87,@
M87!L:6-AY_5E<R!F;W)A;2!E;G9I861O<R!A;R!S97)V:61O<BX`06QF86)E
M=&\@;&%T:6YO(&5M(&UA:?IS8W5L;P!.^FUE<F]S(')O;6%N;W,@96T@;6%I
M^G-C=6QO`%5R=6=U86D`571I;&EZ87(@071U86PZ("5S`%5T:6QI>F%R(%9A
M;&]R(%!A9'+C;P!5=&EL:7IA<B!I;G-C<FGG]65S(&1E('!A<W1A<R!)34%0
M/P!5=&EL:7IA<B!34TP`571I;&EZ87(@3&EX96ER82!6:7)T=6%L/P!5=&EL
M:7IA<B!S92!O(&YO;64O<V5N:&$@Z2!D:69E<F5N=&4@;F\@<V5R=FED;W(@
M24U34"X`57-UX7)I;P!&;W)A;2!C;VYC961I9&%S(&-O;2!S=6-E<W-O(&%S
M('!E<FUI<W/U97,@<&%R82!O('5S=>%R:6\@)R5S)R!N82!P87-T82`G)7,G
M+@!5<W7A<FEO("5S(&[C;R!E<W3A(&%U=&]R:7IA9&\@<&%R82`E<RX`061M
M:6YI<W1R8>?C;R!D92!5<W7A<FEO<P!/<.?U97,@9&4@57-UX7)I;W,`4F5G
M:7-T<F\@9&4@57-UX7)I;W,`4F5G:7-T<F\@9&4@57-UX7)I;W,@97-TX2!D
M97-A8FEL:71A9&\@;F5S=&4@<VET92X`0V]N=&$@9&4@=7-UX7)I;R!NXV\@
M96YC;VYT<F%D80!5<W7A<FEO`%5S=>%R:6\@)R5S)R!JX2!E>&ES=&4N`%5S
M=>%R:6\Z`%5S=>%R:6\Z(`!5<W7A<FEO<R!N;R!S:7-T96UA.@!5>F)E<75I
M<W3C;P!/(&1I<F5T\W)I;R!61E,@;N-O(&5X:7-T92X`1NER:6%S`$QO8V%L
M:7IAY_5E<R!VX6QI9&%S(&5N8V]N=')A9&%S(&EN8VQU96TZ(`!686QI9&%D
M90!686QO<B!E;2!M:6YU=&]S(&$@<&%R=&ER(&1E(&%G;W)A+@!/('9A;&]R
M(&5S=.$@86-I;6$@9&\@=&%M86YH;R!MX7AI;6\@9&4@)7,N`%9A;&]R97,`
M5F%L;W)E<R!P87)A('-E;&5C:6]N87(`5F%N=6%T=0!687)IX79E;`!696YE
M>G5E;&$`1F%L:&$@;F$@=F5R:69I8V'GXV\@+2!E<W1A(&UE;G-A9V5M('!O
M9&4@=&5R('-I9&\@861U;'1E<F%D82X`5F5R<^-O`$-O;G1R;VQE(&1E(%9E
M<G/C;P!!;&EN:&%M96YT;R!V97)T:6-A;`!-87)G96T@=F5R=&EC86P`5F5R
M=&EC86PZ`$UU:71O($%L=&$`5FEE=&[C`%9I971N86UI=&$@*%9)4T-)22D`
M5F5R`%9E<B`E<P!697(@0VAA=F4@4/IB;&EC82`E<P!697(@8V]N=&7Z9&\@
M2%1-3"!E;2!U;6$@:F%N96QA('-E<&%R861A`%9E<B!-96YS86=E;G,`5F5R
M($-H879E(%!R:79A9&$@4&5S<V]A;`!697(@0VAA=F4@4/IB;&EC82!097-S
M;V%L`%9E<B!$:7-C=7-SXV\`5F5R($UI;FEA='5R80!6:7-U86QI>F%R('5M
M82!PX6=I;F$@=V5B(&5X=&5R;F$`5FES=6%L:7IA<B!C;VUO("5S`%9E<B!A
M;F5X;R!E;2!U;6$@:F%N96QA(&$@<&%R=&4`5FES=6%L:7IA<B!O(&-O;G1E
M^F1O(&5M('5M82!J86YE;&$@<V5P87)A9&$`5F5R(&5V96YT;P!697(@;65N
M<V%G96YS(&5M("5S`%9I<^-O(&]U(&-A:7AA('!O<W1A;"!A(&5X:6)I<B!A
M</-S(&-O;F5C=&%R.@!697(@=&%R969A`%9E<B!A<R!);6%G96YS`$EL:&%S
M(%9I<F=E;G,L($)R:73B;FEC87,`26QH87,@5FER9V5N<RP@12Y5+D$N`%!A
M<W1A(%9I<G1U86P@(B5S(B!C<FEA9&$@8V]M('-U8V5S<V\N`%!A<W1A<R!6
M:7)T=6%I<P!087-T87,@5FER='5A:7,@;F5C97-S:71A;2!D92!U;2!N;VUE
M+@!,:7AE:7)A(%9I<G1U86P`0V%I>&$@9&4@16YT<F%D82!6:7)T=6%L`$QI
M>&5I<F$@5FER='5A;`!,:7AE:7)A(%9I<G1U86P`3F]M92!D82!P87-T82!V
M:7)T=6%L`%9I<VEB:6QI9&%D90!6:7-I8FEL:61A9&4Z(`!6;V1A9F]N92!)
M=&%L:6%N;R!V:6$@4TU44`!!5$5.Q\-/`$%414['PT\A(2$@4D5-3U9!($\@
M4T-225!4($U!3E5!3$U%3E1%($1%("5S+@!724X@=FEA($A45%``5V%L;&ES
M(&4@1G5T=6YA`$%V:7-O`%%U80!0<F5V:7/C;R!D;R!496UP;P!$861O<R!D
M;R!#;&EM82!F;W)N96-I9&\@<&]R`%=E871H97(N8V]M`%=E8@!3:71E(%=E
M8@!396UA;F%L;65N=&4`0F5M+79I;F1O`$)E;2UV:6YD;R!A;R`E<P!"96TM
M=FEN9&\L("5S`$]C:61E;G1A;"`H25-/+3@X-3DM,2D`3V-I9&5N=&%L("A)
M4T\M.#@U.2TQ-2D`4V%H87)A($]C:61E;G1A;`!1=64@87!L:6-AY^-O("5S
M(&1E=F5R:6$@97AI8FER(&%P\W,@82!C;VYE>.-O/P!1=6%L(&\@8V%R86-T
M97)E(&1E;&EM:71A9&]R/P!1=6%L(&\@8V%R86-T97)E(&1E(&-I=&'GXV\_
M`$\@<75E(&9A>F5R(&-O;2!S<&%M<R!A</-S(&5L97,@=&5R96T@<VED;R!R
M97!O<G1A9&]S(&-O;6\@<W!A;2!O=2!I;F]C96YT97,_`$%O(&5X8VQU:7(@
M;65N<V%G96YS+"!M;W;J+6QA<R!P87)A(&$@3&EX96ER82!A;R!I;G;I<R!D
M92!M87)CX2UL87,@8V]M;R!E>&-L=>UD87,_`%%U86YD;R!A8G)I<B!U;6$@
M;F]V82!C86EX82!P;W-T86PL(&5M('%U92!PX6=I;F$@=F]CZB!Q=65R(&EN
M:6-I87(_`$%O('-A;'9A<B!E;G9I861O<RP@9&5V97)E;6]S('-A;'9A<B!O
M<R!A;F5X;W,_`$%O(&5N=FEA<B!M96YS86=E;G,@;W4@97AP86YD:7(@96YD
M97)EYV]S+"!Q=6%L(&1O;>UN:6\@9&5V97+A('-E<B!I;F-L=>UD;R!E;2!U
M;2!E;F1E<F7G;R!NXV\@<75A;&EF:6-A9&\@*&5N9&5R9>=O(&1E(&4M;6%I
M;"!S96T@(D`B*3\`36%P87,@075S=')A;&EA;F]S(%=H97)E:7,`475A:7,@
M9F%S97,`475A:7,@<&QU9VEN<R!H86)I;&ET87(@<&%R82!O(&5D:71O<B!2
M:6-H(%1E>'0N`$QI<W1A($)R86YC80!,87)G=7)A`$QA<F=U<F$@96T@=6YI
M9&%D97,@0U-3`$QA<F=U<F$@9&\@;65N=2`E<R!D;R!L861O(&5S<75E<F1O
M("AT97+A(&5F96ET;R!N82!P<O-X:6UA(&-O;F5XXV\I.@!,87)G=7)A(&1A
M('1A8F5L80!5;FED861E(&1E($QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT
M;P!696YT;W,@<&5L82!M86YHXP!696QO8VED861E(&1O('9E;G1O(&5M(&[S
M<P!696YT;SH`5F5N=&\Z(`!386)E9&]R:6$`3&ES=&$@9&4@<&5D:61O<P!4
M<F%B86QH;P!%;F1E<F7G;R!#;VUE<F-I86P`1F]N92!#;VUE<F-I86P`3OIM
M97)O(&EN8V]R<F5T;R!D92!C86UP;W,@;F$@;&EN:&$@)60N($5S<&5R861O
M<R`E9"P@96YC;VYT<F%D;W,@)60N`$[Z;65R;R!E<G)A9&\@9&4@8V%M<&]S
M+B!%<W!E<F%D;W,@)60L(&5N8V]N=')A9&]S("5D+@!/9F9S970@)60@:6YC
M;W)R971O(&%O(&QE<B!O(&%R<75I=F\@5D93+@!8+5)E9@!297-T<FGG]65S
M($+A<VEC87,@6#4P.78S`%5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A
M(%@U,#EV,P!.;VUE($%L=&5R;F%T:79O(&1E($%S<W5N=&\@6#4P.78S`$ED
M96YT:69I8V%D;W(@9&$@0VAA=F4@9&4@07-S=6YT;R!8-3`Y=C,`17AT96YS
M]65S(%@U,#EV,P!!00!!04%!`$UA<&$@66%H;V\A`$%N=6%L;65N=&4`3.IM
M96X`4VEM`%-I;2P@174@0V]N8V]R9&\`5F]CZB!E<W1A('!R97-T97,@82!T
M<F%Z97(@;65N<V%G96YS(&1A*',I('-E9W5I;G1E*',I(&-O;G1A*',I.@!6
M;V/J(&5S=.$@=&5N=&%N9&\@97AC;'5I<B!T;V1A<R!A<R!M96YS86=E;G,@
M8V]N=&ED87,@;F$H<RD@<V5G=6EN=&4H<RD@<&%S=&$H<RDN`%9O8^H@97-T
MX2!T96YT86YD;R!E>&-L=6ER(&$H<RD@<V5G=6EN=&4H<RD@<&%S=&$H<RDN
M`%9O8^H@97-TX2!C;W!I86YD;R]M;W9E;F1O('!A<F$@=6UA(&YO=F$@<&%S
M=&$N`%9O8^H@97-TX2!C<FEA;F1O('5M82!S=6)P87-T82!E;2``5F]CZB!E
M<W3A(&-R:6%N9&\@=6UA('!A<W1A('!R:6YC:7!A;"X`5F]CZB!E<W3A(&5M
M($U/1$\@5$585$\N("!5=&EL:7IA(&\@8F]TXV\@6SP^72!P87)A('9O;'1A
M<B!P87)A(&\@;6]D;R!765-)5UE'+@!6;V/J(&5S=.$@8W)I86YD;R!U;6$@
M<&%S=&$@<')I;F-I<&%L+@!6;V/J(&[C;R!E<W3A(&%U=&]R:7IA9&\@82!C
M<FEA<B!M86ES(&1E("5D(&)L;V-O<RX`5F]CZB!NXV\@97-TX2!A=71O<FEZ
M861O(&$@8W)I87(@;6%I<R!D92`E9"!P87-T87,N`%9O8^H@;N-O(&5S=.$@
M875T96YT:6-A9&\N`%9O8^H@97-TX2!R96YO;65A;F1O(&$@<&%S=&$Z(`!6
M;V/J('!O9&4@=71I;&EZ87(@;W,@<V5G=6EN=&5S(&1E;&EM:71A9&]R97,@
M;F\@=&5X=&\@9&\@<&%P96P@9&4@8V%R=&$Z("5C('!A<F$@82!M96YS86=E
M;2!A='5A;#L@)7,@<&%R82!A(&%S<VEN871U<F$N`%9O8^H@;N-O('!O9&4@
M=&5R(&\@8V%R86-T97(@7"!N;R!S974@;F]M92X`5F]CZB!NXV\@<&]D92!S
M92!D97-I;G-C<F5V97(@9&4@(B5S(BX`5F]CZB!NXV\@8V]N8V]R9&]U(&-O
M;2!O<R!497)M;W,@9&4@4V5R=FGG;RP@<V5N9&\@87-S:6T@=F]CZB!NXV\@
M9F]I(&%U=&]R:7IA9&\@82!C;VYE8W1A<BX`5F]CZB!NXV\@9F]R;F5C974@
M=6T@96YD97)EYV\@9&4@92UM86EL(';A;&ED;RX`5F]CZB!NXV\@;6%P96]U
M(&YE;FAU;2!C86UP;R!D;R!A<G%U:79O(&EM<&]R=&%D;R!A;W,@8V%M<&]S
M(&-O<G)E<W!O;F1E;G1E<R!E;2`E<RX`5F]CZB!NXV\@=&5M('!E<FUI<W/C
M;R!P87)A(&%L=&5R87(@;R!A8V5S<V\@82!E<W1A('!A<W1A`%9O8^H@96YC
M86UI;FAO=2!E<W1A(&UE;G-A9V5M(&5M("4E<R!P87)A(&]S('-E9W5I;G1E
M<R!D97-T:6YA=.%R:6]S.B`E<RX`5F]CZB!T96T@)7,@;F]V87,@;65N<V%G
M96YS+@!6;V/J('1E;2`Q(&YO=F$@;65N<V%G96TN`%9O8^H@:N$@96YV:6]U
M(&5S=&$@<.%G:6YA+@!6;V/J(&9O:2!D97-C;VYE8W1A9&\N`%9O8^H@=&5M
M(&YO=F%S(&UE;G-A9V5N<R!N82!S96=U:6YT92!P87-T83H`5F]CZB!T96T@
M;F]V87,@;65N<V%G96YS(&YA<R!S96=U:6YT97,@<&%S=&%S.@!6;V/J(&1E
M=F4@<')E96YC:&5R('5M(&[Z;65R;R!D92!T96QE9F]N92!C96QU;&%R(';A
M;&ED;RP@<V]M96YT92!D[6=I=&]S(&-O;2!U;2!O<&-I;VYA;"`G*R<@<&%R
M82!D:7-C86=E;2!D92!P<F5F:7AO(&EN=&5R;F%C:6]N86PN`%9O8^H@9&5V
M92!P<F5E;F-H97(@=6T@=F%L;W(@=N%L:61O+@!6;V/J(&1E=F4@8V]N9FEG
M=7)A<B!U;2!C;VYE8W1O<B!$871A5')E92!P87)A('5T:6QI>F%R($-A9&%S
M=')O<RX`5F]CZB!D979E(&-O;F9I9W5R87(@=6T@8V]N96-T;W(@5D93+@!6
M;V/J(&1E=F4@9&5S8W)E=F5R(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R
M(&\@<F5L873S<FEO(&1E('!R;V)L96UA+@!6;V/J(&1E=F4@9F]R;F5C97(@
M<&5L;R!M96YO<R!U;2!D97-T:6YA=.%R:6\N`%9O8^H@9&5V92!F;W)N96-E
M<B!A(%523"!O;F1E(&\@;&EN:R!A<&]N=&$`5F]CZB!D979E(&9O<FYE8V5R
M(&$@<V5N:&$@<&%R82!S=6$@8VAA=F4@<')I=F%D82!01U`@<&%R82!V:7-U
M86QI>F%R(&5S=&$@;65N<V%G96T`5F]CZB!D979E(&9O<FYE8V5R(&$@<V5N
M:&$@<&%R82!S=6$@8VAA=F4@<')I=F%D82!3+TU)344@<&%R82!V:7-U86QI
M>F%R(&5S=&$@;65N<V%G96T`5F]CZB!D979E('-E;&5C:6]N87(@=6UA(&-A
M:7AA('!O<W1A;"!D92!D97-T:6YO('!R:6UE:7)O+@!6;V/J(&1E=F4@<V5L
M96-I;VYA<B!U;6$@8V]N=&$@<&%R82!E>&-L=6ER+@!6;V/J(&1E=F4@<V5L
M96-I;VYA<B!U;2!E;F1E<F7G;R!P<FEM96ER;RX`5F]CZB!D979E('-E;&5C
M:6]N87(@=6T@<V5R=FED;W(@<&%R82!S97(@97AC;'7M9&\N`%9O8^H@9&5V
M92!S96QE8VEO;F%R('!E;&\@;65N;W,@=6UA(&UE;G-A9V5M('!R:6UE:7)O
M+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@9&5S=&EN873A<FEO+@!6;V/J
M(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(&5X8VQU:7(N`%9O
M8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@<F5M;W9E<BX`
M5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R82!A9&EC:6]N
M87(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@871U
M86QI>F%R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6UA(&'GXV\@<&%R82!E
M>&5C=71A<BX`5F]CZB!D979E('!R965N8VAE<B!U;2!N;VUE('!A<F$@82!N
M;W9A(&-A=&5G;W)I82X`5F]CZB!P<F5C:7-A(&5S=&%R(&-O;2`B)7,B(&AA
M8FEL:71A9&\@;F%S(&]PY_5E<R!D92!M86YU=&5NY^-O+@!6;V/J('!R96-I
M<V$@9F]R;F5C97(@=6T@;OIM97)O(&1E('1E;&5F;VYE(&ET86QI86YO`%9O
M8^H@<F5D:7)E8VEO;F]U(&5S=&$@;65N<V%G96T@<&%R82`E<R!E;2`E)7,N
M`%9O8^H@<F5P;&EC;W4@97-T82!M96YS86=E;2!E;2`E<RX`5F]CZB!NXV\@
M9F]I(&EN<V-R:71O(&5M("(E<R(N($%Q=6D@97-TX2!O('%U92!O('-E<G9I
M9&]R(&1I<W-E`%9O8^H@;N-O(&9O:2!D97-I;G-C<FET;R!D92`B)7,B+B!!
M<75I(&5S=.$@;R!Q=64@;R!S97)V:61O<B!D:7-S90!6;V/J(&9O:2!I;G-C
M<FET;R!E;2`B)7,B(&-O;2!S=6-E<W-O`%9O8^H@9F]I(&1E<VEN<V-R:71O
M(&1E("(E<R(@8V]M('-U8V5S<V\`4W5A('-E<W/C;R`E<R!E>'!I<F]U+B!0
M;W(@9F%V;W(L(&-O;F5C=&4M<V4@;F]V86UE;G1E+@!3974@16YD97)EYV\@
M9&4@12UM86EL`%-E=2!%;F1E<F7G;R!D92!296UE=&5N=&4@*$1E.BDZ`%-U
M87,@26YF;W)M8>?U97,`4V5U($5N9&5R9>=O(&1E($EN=&5R;F5T(&UU9&]U
M(&1E<V1E(&\@:6[M8VEO(&1E('-U82!S97-SXV\@)7,N(%!A<F$@<')O=&5G
M97(@<W5A('-E9W5R86[G82!V;V/J(&1E=F4@8V]N96-T87(M<V4@;F]V86UE
M;G1E+@!3974@3F]M90!3=6%S($-H879E<R!0^F)L:6-A+U!R:79A9&$@4$=0
M`%-U82!#:&%V92!0<FEV861A`%-U82!#:&%V92!0^F)L:6-A`%-E=2!E;F1E
M<F7G;R!297-P;VYD97(M4&%R83H@/&5M/BAO<&-I;VYA;"D\+V5M/@!3975S
M($-E<G1I9FEC861O<R!0^F)L:6-O+U!R:79A9&\@4R]-24U%`%-U87,@8V]N
M=&%S.@!3975S(&5N9&5R9>=O<R!S96-U;F3A<FEO<R`H86QI87,I.B`\:3XH
M;W!C:6]N86PL('!R965N8VAA(&-A9&$@96YD97)EYV\@96T@=6UA(&YO=F$@
M;&EN:&$I/"]I/@!3974@8F%C:V5N9"!D92!A=71E;G1I8V'GXV\@;N-O('-U
M<&]R=&$@861IY^-O(&1E('5S=>%R:6]S+"!O=2!A(&9U;N?C;R!F;VD@9&5S
M86)I;&ET861A('!O<B!A;&=U;6$@;W5T<F$@<F%ZXV\N`%-E=2!B86-K96YD
M(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T82!L:7-T86=E;2!D92!U<W7A
M<FEO<RP@;W4@82!F=6[GXV\@9F]I(&1E<V%B:6QI=&%D82!P;W(@86QG=6UA
M(&]U=')A(')A>N-O+@!3974@;F%V96=A9&]R('!A<F5C92!T97(@86QT97)A
M9&\@9&5S9&4@;R!I;NUC:6\@9&4@<W5A('-E<W/C;R`E<RX@4&%R82!P<F]T
M96=E<B!S=6$@<V5G=7)A;N=A+"!V;V/J(&1E=F4@8V]N96-T87(M<V4@;F]V
M86UE;G1E+@!3974@;F%V96=A9&]R(&[C;R!S=7!O<G1A(&5X:6)IY^-O(&EN
M8V]R<&]R861A(&1E<W1E('1I<&\@9&4@:6UA9V5M+@!3974@;F%V96=A9&]R
M(&[C;R!S=7!O<G1A(&5S=&$@9G5NY^-O+@!3974@;F%V96=A9&]R(&[C;R!S
M=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O+B!0<F5S<VEO;F4@0V]N
M=')O;"]/<'1I;VX@*R!0('!A<F$@:6UP<FEM:7(N`%-E=2!F=7-O(&AO<N%R
M:6\@871U86PZ`%-E=2!C;VYJ=6YT;R!D92!C87)A8W1E<F5S('!A9'+C;R!P
M87)A(&5N=FEA<B!M96YS86=E;G,Z`%-E=2!MZ71O9&\@9&4@8W)I<'1O9W)A
M9FEA('!A9'+C;R!P87)A(&5N=FEA<B!M96YS86=E;G,Z`%-U82!I9&5N=&ED
M861E('!A9'+C;R!F;VD@86QT97)A9&$N`%-U82!I9&5N=&ED861E('!A9'+C
M;SH`4V5U(&YO;64@8V]M<&QE=&\Z`%-E=2!A;F5X;R!F;VD@8F%I>&%D;R!P
M;W(@<&5L;R!M96YO<R!U;2!U<W7A<FEO+@H*3F]M92!D;R!A;F5X;SH@)7,*
M1&%T82!D;R!A;F5X;SH@)7,*"D-L:7%U92!N;R!L:6YK(&$@<V5G=6ER('!A
M<F$@97AC;'5I<B!P97)M86YE;G1E;65N=&4@;R!A;F5X;SH*)7,`4W5A(&-O
M;F5XXV\@97AP:7)O=2X`4W5A(&UE;G-A9V5M(&9O:2!E;G9I861A(&-O;2!S
M=6-E<W-O+@!3=6$@;F]V82!S96YH82!P87)A("5S(.DZ("5S`%-U87,@;W#G
M]65S(&9O<F%M(&%T=6%L:7IA9&%S('!O<B!C875S82!D82!D=7)AY^-O(&1E
M<W1A('-E<W/C;RX`4W5A<R!O<.?U97,@9F]R86T@871U86QI>F%D87,N`%-U
M82!N;W9A('-E;FAA(&9O:2!G97)A9&$`4W5A(&YO=F$@<V5N:&$@9F]I(&=E
M<F%D82P@=F5R:69I<75E('-E=2!E+6UA:6P@92!C;VYE8W1E+7-E(&-O;2!S
M=6$@;F]V82!S96YH82X`4W5A('-E;FAA(&5X<&ER;W4N`%-E=7,@<V5R=FED
M;W)E<R!R96UO=&]S.@!3=6$@87-S:6YA='5R83H`275G;W-LX79I80!:86ER
M90!:XFUB:6$`6FEM8F%B=V4`6FEP<'D`6T]C=6QT87(@16YD97)EYV]S70!;
M3V-U;'1A<B!497AT;R!#:71A9&]=`%M396T@07-S=6YT;UT`6U)E;&%T\W)I
M;R!D92!0<F]B;&5M85T`6T5X:6)I<B!%;F1E<F7G;W,@+0!;17AI8FER(%1E
M>'1O($-I=&%D;R`M`%M%>&EB:7(@5&5X=&\@0VET861O("T@)7,@;&EN:&%S
M70!;17AI8FER(&5N9&5R9>=O<R`M("5S(&1E<W1I;F%TX7)I;W-=`%ML:6YH
M82`E<R!D92`E<UT`7T%D;6EN:7-T<F'GXV\`0V-?;P!,:7-T82!?3F5G<F$`
M7T-,20!?0V,`1&%T85]4<F5E`$5?>&-L=6ER`$5?>&-L=6ER($-O;'5N80!?
M4&%S=&%S`%]'<G5P;W,`05]J=61A`%])9&5N=&ED861E`%!R;W!R:65D861E
M<R!D82!?26UA9V5M+BXN`$-A:7AA(&1E(%]%;G1R861A`%]#;VYE8W1A<@!?
M1&5S8V]N96-T87(`0_-D:5]G;R!&;VYT92!D82!-96YS86=E;0!!7VQT97)A
M<B!,:6YK+BXN`$YO=F$@;65N<V%G96T`7T]PY_5E<P!?4&5R;6ES<_5E<P!)
M7VUP<FEM:7(`4')?:6]R:61A9&4`071U86QI7WIA<B`E<P!?4F5M;W9E<B!,
M:6YK+BXN`%)E7W-P;VYD97(`4&5S7W%U:7-A<@!%;G9I87(@7TUE;G-A9V5M
M`$-O;F9I9W5R85]R`%!R;W!R:65D861E<R!D82!?5&%B96QA+BXN`$1I<V-?
M=7-SXV\`4&%R7V$`7U)E<W1A=7)A<@!?57-UX7)I;W,`7U9E<B!$:7-C=7-S
MXV\`3&ES=&$@7T)R86YC80!C873A;&]G;R!D92!E;F1E<F7G;W,`9&5S=&EN
M873A<FEO(&1E<V-O;FAE8VED;P!A;F5X;P!A;F5X;W,N>FEP`&)Y=&5S`&%G
M96YD80!C86QM;P!I;7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@9&4@9&5S=&EN
M;P!I;7!O<W/M=F5L(&%B<FER(&]R:6=E;0!C;&EQ=64@87%U:0!E<G)O(&1E
M('-I;G1A>&4@;F$@;&EN:&$@9&4@8V]M86YD;P!E<G)O(&1E(&-O;F9I9W5R
M8>?C;P!E<W3A(&9A;'1A;F1O('5M(&%R<75I=F\@8W+M=&EC;R!D;R!S:7-T
M96UA`&5R<F\@;F\@9F]R;6%T;R!D;W,@9&%D;W,`961I=&%R`')E9VES=')O
M(&[C;R!E;F-O;G1R861O`'%U961A`&%R<75I=F\`9&4`82!P87)T:7(@9&4@
M)7,@*"5S*2#@("5S("5S`&)R:7-A`&@Z`&AH`&YO;64@9&\@:&]S="#I(&1E
M<V-O;FAE8VED;P!I;65D:6%T;P!I;F-O<G!O<F%D;P!E<G)O(&1E(&5N=')A
M9&$O<V'M9&$`97)R;R!I;G1E<FYO(&1O('!R;V=R86UA`&-H879E`&QI;FAA
M<UT`87)Q=6EV;R!M86EL8F]X`&/S9&EG;R!D92!E<G)O("5D(&1O(&UK:7-O
M9G,@96YQ=6%N=&\@9V5R879A(&$@25-/+@!M;0!N;VUE`&YE;FAU;6$`;N-O
M(&EM<&QE;65N=&%D;P!NXV\@:6UP;&5M96YT861O(&%I;F1A`&)L;V-O(&1E
M(&YO=&%S`&]U`'!O<F-E;G1A9V5M`'!E<FUI<W/C;R!N96=A9&$`<&EX96QS
M`&1E<W1I;F%TX7)I;W-=`&5R<F\@<F5M;W1O(&YO('!R;W1O8V]L;P!N87-C
M96YT90!S97)V:>=O(&EN9&ES<&]N[79E;`!E>&EB:7(@9&EF97)E;N=A<P!S
M;7,R96UA:6P@=FEA($A45%``97)R;R!D92!O<G1O9W)A9FEA`&5R<F]S(&1E
M(&]R=&]G<F%F:6$`<W,`97-TX79E;`!E<G)O(&1O('-I<W1E;6$`;&ES=&$@
M9&4@=&%R969A<P!F86QH82!T96UP;W+A<FEA`'!R965N8VAA('-U82!S96YH
M82!D=6%S('9E>F5S('!A<F$@8V]N9FER;6%R`'5N:69I8V%D;P!S96T@;F]M
M90!S96QEY^-O(&1E('5S=>%R:6\`=D-A<F0`=SH`=V5A=&AE<BYC;VT`<W5A
M(&QI<W1A(&YE9W)A`'-U82!L:7-T82!B<F%N8V$`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+VQO8V%L92]P=%]"4B]H96QP+GAM;```````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#$T-C$V,P`Q,#0Q-S,V,C<V,P`P,C$Q-#$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,2(_/@H\(2TM
M("1(;W)D93H@:6UP+VQO8V%L92]P=%]"4B]H96QP+GAM;"QV(#$N,3@N-"XT
M(#(P,#8O,#$O,S`@,34Z-3<Z-3<@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\
M96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(@<W1A=&4](G5P=&]D871E(B!M
M9#4](C,R-3EB83`P83$Y.#4U.6,W9F%A-S9E-S@V-S8P,&0Y(CX*("`@(#QT
M:71L93Y#;VUP;W-IY^-O(&1E($UE;G-A9V5M.B!!Y_5E<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!Y_5E<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YV
M:6%R($UE;G-A9V5M(&5N8V%M:6YH82!S=6$@;65N<V%G96T@<&%R82!O*',I
M(&1E<W1I;F%TX7)I;RAS*2!D97-E:F%D;W,N($-E<G1I9FEQ=64M<V4@<75E
M('9O8^H@<F5A;&UE;G1E('%U97(@96YV:6%R(&$@;65N<V%G96T@86YT97,@
M9&4@8VQI8V%R(&%Q=6DL('!O:7,@=6UA('9E>B!E;G9I861O(&[C;R!S92!P
M;V1E('9O;'1A<B!A='+A<RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@
M4V%L=F%R(%)A<V-U;FAO(&=R879A('5M82!M96YS86=E;2!NXV\@9FEN86QI
M>F%D82!E;2!U;6$@<&%S=&$@8VAA;6%D82`G4F%S8W5N:&]S)R!A8V5S<^UV
M96P@871R87;I<R!D82!C86EX82!S96QEY^-O(&%O(&QA9&\@9&ER96ET;R!D
M82!B87)R82!D92!N879E9V'GXV\@86\@=&]P;RX@5F]CZB!P;V1E(&9I;F%L
M:7IA<B!A(&UE;G-A9V5M(&UA:7,@=&%R9&4@<V5L96-I;VYA;F1O(&$@<&%S
M=&$@)U)A<V-U;FAO<R<L(&-L:6-A;F1O(&YA(&UE;G-A9V5M(&=R879A9&$@
M<&%R82!A8G)I+6QA+"!E(&5N=.-O(&-L:6-A;F1O(&5M("=#;VYT:6YU87(G
M+B!#97)T:69I<75E+7-E(&1E(&%T<FEB=6ER('5M('3M='5L;R!P87)A(&$@
M;65N<V%G96T@86YT97,@9&4@9W)A=F%R(&\@<F%S8W5N:&\@<&%R82!F86-I
M;&ET87(@82!I9&5N=&EF:6-AY^-O(&1A(&UE<VUA(&1E;G1R;R!D82!P87-T
M82`G4F%S8W5N:&]S)RX@07#S<R!G<F%V87(@8V]M;R!U;2!R87-C=6YH;RP@
M=F]CZB#I(&5N=FEA9&\@9&4@=F]L=&$@<&%R82!A($-A:7AA(&1E($5N=')A
M9&$@;W4@<&%R82!A(/IL=&EM82!P87-T82!V:7-U86QI>F%D82X*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@0V%N8V5L87(@365N<V%G96T@9&5S8V%R
M=&$@82!C;VUP;W-IY^-O(&1A(&UE;G-A9V5M(&5M('!R;V=R97-S;R!E('-I
M;7!L97-M96YT92!R971O<FYA('!A<F$@82!#86EX82!D92!%;G1R861A(&]U
M('!A<F$@82#Z;'1I;6$@<&%S=&$@=FES=6%L:7IA9&$N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB('-T871E/2)U
M<'1O9&%T92(@;60U/2(X,F-F,C1D,S%A-C8W835B.31E-#@Q8V0U,3<Y8S4R
M.2(^"B`@("`\=&ET;&4^0V]M<&]S:>?C;R!D92!-96YS86=E;3H@1&4\+W1I
M=&QE/@H@("`@/&AE861I;F<^(D1E(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@4')E96YC:&$@8V]R<F5T86UE;G1E('-E=2!E;F1E<F7G;R!D92!E+6UA
M:6PN(%-E=2!E;F1E<F7G;R!D92!E+6UA:6P@Z2!A=71O;6%T:6-A;65N=&4@
M<')E96YC:&ED;R!P87)A('9O8^H@8V]N<W1A;F1O(&1O(&-A;7!O(")&<F]M
M.B(@;F$@;65N<V%G96T@82!S97(@96YV:6%D82X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M=&\B('-T871E/2)U<'1O9&%T
M92(@;60U/2(S,6-B83$W9C$V.34W,F,S-C=A83@P,30X,S%E8CAF."(^"B`@
M("`\=&ET;&4^0V]M<&]S:>?C;R!D92!-96YS86=E;3H@4&%R83PO=&ET;&4^
M"B`@("`\:&5A9&EN9SXB4&%R82(\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%!R965N8VAA(&-O<G)E=&%M96YT92!O*',I(&5N9&5R9>=O*',I(&1O*',I
M(&1E<W1I;F%TX7)I;RAS*2!P87)A('-U82!M96YS86=E;2X@5F]CZB!D979E
M('-E<&%R87(@8V%D82!E;F1E<F7G;R!C;VT@=6UA(';M<F=U;&$N($]U=')O
M('1I<&\@9&4@<&]N='5AY^-O(')E<W5L=&%RX2!E;2!E<G)O+B!/*',I(&5N
M9&5R9>=O*',I('!R965N8VAI9&\H<RD@8V]N<W1A<N$HXV\I(&1O(&-A;7!O
M(")4;SHB(&YA(&UE;G-A9V5M(&$@<V5R(&5N=FEA9&$N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6-C(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB.3<U-S$T,S-A8C`S-V5F.6,T9#$P,6$U-F)F-S1E,C4B
M/@H@("`@/'1I=&QE/D-O;7!O<VGGXV\@9&4@365N<V%G96TZ($-C/"]T:71L
M93X*("`@(#QH96%D:6YG/B)#8R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%!R965N8VAA(&-O<G)E=&%M96YT92!O*',I(&5N9&5R9>=O*',I(&1O*',I
M(&1E<W1I;F%TX7)I;RAS*2!Q=64@<F5C96)E<N-O('5M82!C\W!I82!C87)B
M;VYO(&1E('-U82!M96YS86=E;2X@4V5P87)E(&-A9&$@96YD97)EYV\@8V]M
M('5M82!V[7)G=6QA+B!/*',I(&5N9&5R9>=O*',I('!R965N8VAI9&\H<RD@
M8V]N<W1A<N$HXV\I(&1O(&-A;7!O(")#8SHB(&YA(&UE;G-A9V5M(&$@<V5R
M(&5N=FEA9&$N($/S<&EA<R!#87)B;VYO('/C;R!G97)A;&UE;G1E(&5N=FEA
M9&%S('!A<F$@;W5T<F%S('!E<W-O87,@<75E(&[C;R!A<R!C;VYT871A9&%S
M(&1I<F5T86UE;G1E(&UA<R!T86UBZ6T@<^-O(&EM<&]R=&%N=&5S(&1E<W1I
M;F%TX7)I;W,@<&%R82!A(&UE;G-A9V5M+"!G97)A;&UE;G1E(&%L9W7I;2!I
M;F1I<F5T86UE;G1E(&5N=F]L=FED;R!N;R!A<W-U;G1O(&1A(&UE;G-A9V5M
M+B!!;6)O<R!T:7!O<R!D92!D97-T:6YA=.%R:6]S+"`B4&%R83HB(&4@(D-C
M.B(L('!O9&5M('9E<B!T;V1A(&$@;&ES=&$@9&4@96YD97)EYV]S(&1E(&%M
M8F]S(&]S('1I<&]S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UB8V,B('-T871E/2)U<'1O9&%T92(@;60U/2)A83AF.64R
M9#0T9F1B-S1D968P9F$Q-3(T,&9F-C@W8B(^"B`@("`\=&ET;&4^0V]M<&]S
M:>?C;R!D92!-96YS86=E;3H@0V-O/"]T:71L93X*("`@(#QH96%D:6YG/B)#
M8V\B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!0<F5E;F-H82!C;W)R971A
M;65N=&4@;RAS*2!E;F1E<F7G;RAS*2!D87%U96QE<R!Q=64@<F5C96)E<N-O
M('5M82!C\W!I82!C87)B;VYO(&]C=6QT82!D92!S=6$@;65N<V%G96TN(%9O
M8^H@9&5V92!S97!A<F%R(&-A9&$@96YD97)EYV\@8V]M('5M82!V[7)G=6QA
M+"!O=71R;R!T:7!O(&1E('!O;G1U8>?C;R!R97-U;'1A<N$@96T@97)R;RX@
M3RAS*2!E;F1E<F7G;RAS*2!P<F5E;F-H:61O*',I(&-O;G-T87+A*.-O*2!D
M;R!C86UP;R`B0F-C.B(@;F$@;65N<V%G96T@82!S97(@96YV:6%D82X@0_-P
M:6%S(&-A<F)O;F\@;V-U;'1A<R!SXV\@9V5R86QM96YT92!E;G9I861A<R!P
M87)A('!E<W-O87,@<75E(&[C;R!O<R!D97-T:6YA=.%R:6]S(&1I<F5T;W,@
M92!I;F1I<F5T;W,@*")087)A.B(@92`B0V,Z(BD@<75E('!R96-I<V%M(&QE
M<B!O('%U92!E<W3A('-E;F1O(&5S8W)I=&\@;6%S('-E;2!O(&-O;FAE8VEM
M96YT;R!D;W,@;W5T<F]S(&1E<W1I;F%TX7)I;W,@9&$@;65N<V%G96TN(%-O
M;65N=&4@96QE<R!E('9O8^H@<V%B97+C;R!Q=64@96QE<R!R96-E8F5R86T@
M=6UA(&/S<&EA(&1A(&UE;G-A9V5M+B!6;V/J(&=E<F%L;65N=&4@=7-A(&5S
M=&$@;W#GXV\@<&%R82!I;F9O<FUA<B!U;2!S=7!E<FEO<B!Q=64@=F]CZB!E
M<W3A(&1I>F5N9&\@86QG;R!P87)A('5M82!P97-S;V$L('!O<NEM('-E;2!A
M;&%R;>$M;&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C
M;VUP;W-E+7-U8FIE8W0B('-T871E/2)U<'1O9&%T92(@;60U/2(P-C,Y83@W
M.3!E,S`V86-C.64Q.6(T9#%C93,T,F0U,R(^"B`@("`\=&ET;&4^0V]M<&]S
M:>?C;R!D92!-96YS86=E;3H@5.UT=6QO/"]T:71L93X*("`@(#QH96%D:6YG
M/B)!<W-U;G1O(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4')E96YC:&$@
M;R!A<W-U;G1O(&1E('-U82!M96YS86=E;2X@3R!T97AT;R!P<F5E;F-H:61O
M(&-O;G-T87+A(&1O(&-A;7!O(")3=6)J96-T.B(@;F$@;65N<V%G96T@82!S
M97(@96YV:6%D82X@4V5J82!B<F5V92P@<VEM<&QE<R!E(&1E<V-R:71I=F\N
M($$@;&EN:&$@07-S=6YT;R#I(&$@9F]R;6$@;6%I<R!FX6-I;"!D92!V;V/J
M(&4@<V5U<R!C;W)R97-P;VYD96YT97,@<V4@;&5M8G)A<F5M(&1O('%U92!S
M92!T<F%T879A(&$@;65N<V%G96T@92#I(&UU:71O(&EM<&]R=&%N=&4@<&%R
M82!O<F=A;FEZ87(@<W5A<R!M96YS86=E;G,@92!E;F-O;G1R87(@87,@:6UP
M;W)T86YT97,@;6%I<R!T87)D92X@5&%M8NEM+"!Q=6%N9&\@=F]CZB`G4F5S
M<&]N9&5R)R!O=2`G16YC86UI;FAA<B<@97-T82!M96YS86=E;2P@;R!!<W-U
M;G1O('-E<N$@8V]P:6%D;R!P87)A(&$@;F]V82!M96YS86=E;2!E(&5S=&$@
MZ2!U;6$@9F]R;6$@9&4@9&EZ97(@<75A:7,@;65N<V%G96YS(&9O<FUA;2!A
M(")D:7-C=7-SXV\B(&1E('5M82!C;VYV97)S8>?C;RX@16YT<F5T86YD;RP@
M<V4@<W5A(')E<W!O<W1A(&]U(&5N8V%M:6YH86UE;G1O(&-O;G3I;2!N;W9A
M<R!I9.EI87,L('9O8^H@<&]D92!Q=65R97(@861I8VEO;F%R('!E<75E;F%S
M(&UO9&EF:6-AY_5S(&%O(&%S<W5N=&\L(&%S<VEM(&]S(&1E<W1I;F%TX7)I
M;W,@<&]D96T@<V5G=6ER(&\@<')O9W)E<W-O(&1A(")D:7-C=7-SXV\B+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO<'1I
M;VYS(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-68Q9#4P83<S,V,X8C=E-#9A
M96-E8V4R.#@R,F9F-S`B/@H@("`@/'1I=&QE/D-O;7!O<VGGXV\@9&4@365N
M<V%G96TZ($]PY_5E<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB3W#G]65S(CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17-T87,@3W#G]65S(&%J=61A;2!V
M;V/J(&$@<')E<&%R87(@<W5A(&UE;G-A9V5M+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!#;&EQ=64@96T@(E9E<FEF:6-A<B!/<G1O9W)A9FEA(B!P
M87)A(&-H96-A<B!S=6$@;W)T;V=R869I82X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@0VQI<75E(&5M(")!;F5X;W,B('!A<F$@=F5R+"!N;R!R;V1A
M<.D@9&$@<.%G:6YA+"!A(&QI<W1A(&1E(&%R<75I=F]S(&%N97AA9&]S(&$@
M;65N<V%G96TN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%T:79E(&\@
M8F]TXV\@86\@;&%D;R!D92`B4V%L=F%R('5M82!C\W!I82!E;2(@<&%R82!S
M86QV87(@=6UA(&/S<&EA(&1E<W1A(&UE;G-A9V5M(&YA('-U82!P87-T82`B
M16YV:6%D;W,B+B!386QV92!C\W!I87,@9&4@;65N<V%G96YS(&EM<&]R=&%N
M=&5S('%U92!V;V/J(&5N=FEA('!A<F$@=F]CZB!T97(@<F5F97+J;F-I87,@
M<&]S=&5R:6]R97,@92!P87)A('9O8^H@=&5R('5M(')E9VES=')O('!R96-I
M<V\@9&\@<75E('9O8^H@9&ES<V4N($[S<R!NXV\@<F5C;VUE;F1A;6]S('9O
M8^H@9W)A=F%R('1O9&%S(&%S(&UE;G-A9V5N<RP@<&]I<R!S=6$@8V%I>&$M
M<&]S=&%L(&5N8VAE<N$@<F%P:61A;65N=&4@*&5S<&5C:6%L;65N=&4@<75A
M;F1O('9O8^H@96YV:6$@86YE>&]S*2!O(&1E:7AA;F1O(&EN87!T;R!A(')E
M8V5B97(@;F]V87,@;65N<V%G96YS+B!6;V/J('!O9&4L(&5N=')E=&%N=&\L
M(&1E:7AA<B!E<W1A(&]P8^?C;R!S96UP<F4@;&EG861A('5T:6QI>F%N9&\@
M)T]PY_5E<R<@;F$@;F$@8F%R<F$@9&4@;F%V96=AY^-O(&%O('1O<&\N(%1O
M;64@8W5I9&%D;R!A;R!U=&EL:7IA<B!E<W1A(&]PY^-O+"!P;VES('9O8^H@
M=&5RX2!Q=64@<&5R:6]D:6-A;65N=&4@;&EM<&%R(&$@<&%S=&$@9&4@;65N
M<V%G96YS(&5N=FEA9&%S(&]U(&ES=&\@9&5I>&%RX2!S=6$@8V%I>&$M<&]S
M=&%L(&-H96EA(&4@:6YU=&EL:7KA=F5L+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B('-T871E/2)C:&%N9V5D
M(B!M9#4](CDX9&0S,&8S,F%F,69A.#9A.68P9F5A,S$R-&,T964Q(CX*("`@
M(#QT:71L93Y#;VUP;W-IY^-O(&1E($UE;G-A9V5M.B!!;F5X87(\+W1I=&QE
M/@H@("`@/&AE861I;F<^(D%N97AA<B(\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@("`@("!6;V/J('!O9&4@86YE>&%R(&%R<75I=F]S(&$@<W5A(&UE;G-A
M9V5M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4&%S<V\@,3H@1&EG:71E(&\@
M8V%M:6YH;R!E(&\@;F]M92!D;R!A<G%U:79O('%U92!V;V/J('%U97(@86YE
M>&%R(&$@97-T82!M96YS86=E;2!O=2!C;&EQ=64@;F\@8F]TXV\@(E!R;V-U
M<F%R(B!E('-E;&5C:6]N92!O(&%R<75I=F\@82!S97(@86YE>&%D;RX@3R!C
M86UI;FAO(&4@;R!N;VUE(&1O(&%R<75I=F\@86=O<F$@87!A<F5C97+A(&YO
M('%U861R;R!!;F5X;W,N"B`@("!!9V]R82!S:6=A('!A<F$@;R!087-S;R`R
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4&%S<V\@,CH@8VQI<75E(&YO(&)O
M=.-O(")!;F5X87(B+B!/(&YO;64@9&\@87)Q=6EV;R!E('1A;6%N:&\@<V5R
MXV\@861I8VEO;F%D;W,@82!S=6$@;&ES=&$@9&4@06YE>&]S+B!0;W(@9F%V
M;W(@;F]T92!Q=64@<&%R82!A<G%U:79O<R!G<F%N9&5S(&4O;W4@8V]N97CU
M97,@;&5N=&%S+"!O('!R;V-E<W-O(&1E(&5N=FEO(&4@86YE>&'GXV\@82!M
M96YS86=E;2!P;V1E<N$@9&5M;W)A<B!U;2!P;W5C;RX@4&]R(&9A=F]R('-E
M:F$@<&%C:65N=&4@92!NXV\@8VQI<75E(&5M(&]U=')A<R!C;VES87,@96YQ
M=6%N=&\@97-P97)A+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ
M"CQE;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B/@H@("`@/'1I=&QE/DUE<W-A
M9V4@0V]M<&]S:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M='1A8V@\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=2!M87D@871T86-H
M(&9I;&5S('1O('EO=7(@;65S<V%G92!I9B!Y;W5R(&)R;W=S97(@<W5P<&]R
M=',@=7!L;V%D:6YG(&]F(&9I;&5S+B!-;W)E('1H86X@,2!F:6QE(&-A;B!B
M92!U<&QO861E9"!A="!O;F-E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E
M<"`Q.B!%:71H97(@='EP92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A(&9I;&4@
M=&AA="!Y;W4@=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@;W(@8VQI
M8VL@=&AE(")"<F]W<V4B(&)U='1O;B!A;F0@<V5L96-T('1H92!F:6QE('1O
M(&)E(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD(&YA;64@;V8@=&AA="!F:6QE
M(&YO=R!A<'!E87)S(&EN('1H92!!='1A8VAM96YT(&)O>"X*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@,CH@1&5C:61E('=H971H97(@>6]U('=A;G0@
M=&AE(&9I;&4@=&\@8F4@=FEE=V5D(&%S(&%N(&%T=&%C:&UE;G0@;W(@:6YL
M:6YE('=I=&@@=&AE(')E<W0@;V8@=&AE(&UE<W-A9V4N(%1H92!R96-I<&EE
M;G0G<R!M86EL(')E861I;F<@<V]F='=A<F4@;75S="!B92!A8FQE('1O(&AA
M;F1L92!T:&4@:6YL:6YE(&1I<W!L87D@;V8@=&AE(&9I;&4@='EP92P@;W1H
M97)W:7-E('1H:7,@<&%R="!W:6QL(&)E('9I97=E9"!A<R!A;B!A='1A8VAM
M96YT(&EN<W1E860N"B`@("`\+W!A<F$^"B`@("`\=&EP/@H@("`@4&QE87-E
M(&YO=&4@=&AA="!F;W(@;&%R9V4@9FEL97,@86YD+V]R('-L;W=E<B!);G1E
M<FYE="!C;VYN96-T:6]N<RP@=&AE('!R;V-E<W,@;V8@=7!L;V%D:6YG(&%N
M9"!A='1A8VAI;F<@>6]U<B!F:6QE('1O('1H92!E;6%I;"!M87D@=&%K92!A
M('=H:6QE+B!0;&5A<V4@8F4@<&%T:65N="!A;F0@9&\@;F]T(&-L:6-K(&]T
M:&5R(&QI;FMS(&]R(&)U='1O;G,@=VAI;&4@>6]U(&%R92!W86ET:6YG(&9O
M<B!A(&9I;&4@=&\@=7!L;V%D+@H@("`@/"]T:7`^"CPO96YT<GD^+2T^/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M871T86-H(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8V@\+W1I=&QE
M/@H@("`@/&AE861I;F<^071T86-H/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!9;W4@;6%Y(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4@:68@>6]U
M<B!B<F]W<V5R('-U<'!O<G1S('5P;&]A9&EN9R!O9B!F:6QE<RX@36]R92!T
M:&%N(#$@9FEL92!C86X@8F4@=7!L;V%D960@870@;VYC92X*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@,3H@16ET:&5R('1Y<&4@=&AE('!A=&@@86YD
M(&YA;64@;V8@82!F:6QE('1H870@>6]U('=A;G0@871T86-H960@=&\@=&AI
M<R!M97-S86=E(&]R(&-L:6-K('1H92`B0G)O=W-E(B!B=71T;VX@86YD('-E
M;&5C="!T:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N
M86UE(&]F('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N
M="!B;W@N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($1E8VED92!W
M:&5T:&5R('EO=2!W86YT('1H92!F:6QE('1O(&)E('9I97=E9"!A<R!A;B!A
M='1A8VAM96YT(&]R(&EN;&EN92!W:71H('1H92!R97-T(&]F('1H92!M97-S
M86=E+B!4:&4@<F5C:7!I96YT)W,@;6%I;"!R96%D:6YG('-O9G1W87)E(&UU
M<W0@8F4@86)L92!T;R!H86YD;&4@=&AE(&EN;&EN92!D:7-P;&%Y(&]F('1H
M92!F:6QE('1Y<&4L(&]T:&5R=VES92!T:&ES('!A<G0@=VEL;"!B92!V:65W
M960@87,@86X@871T86-H;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@
M/'1I<#X*("`@(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S(&%N
M9"]O<B!S;&]W97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C97-S
M(&]F('5P;&]A9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T:&4@
M96UA:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@86YD
M(&1O(&YO="!C;&EC:R!O=&AE<B!L:6YK<R!O<B!B=71T;VYS('=H:6QE('EO
M=2!A<F4@=V%I=&EN9R!F;W(@82!F:6QE('1O('5P;&]A9"X*("`@(#PO=&EP
M/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T
M=&%C:&UE;G1S(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB.&%C,#,R8S1A8S$X
M,F8S9C!D-C0T-F,R,&8P,#@Y9&0B/@H@("`@/'1I=&QE/D-O;7!O<VGGXV\@
M9&4@365N<V%G96TZ($%N97AO<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB06YE
M>&]S(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17-T82!S9>?C;R!M;W-T
M<F$@=6UA(&QI<W1A(&1E(&%R<75I=F]S(&KA(&%N97AA9&]S(&$@<W5A(&UE
M;G-A9V5M+B!087)A(')E;6]V97(@=6T@87)Q=6EV;R!A;F5X861O.@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^4&%S<V\@,3H@071I=F4@82!C86EX82!D92!C
M:&5C86=E;2!A;R!L861O(&1O(&YO;64@9&\@87)Q=6EV;R!A;F5X861O('%U
M92!V;V/J('%U97(@<F5M;W9E<BX*("`@(#PO<&%R83X@"B`@("`\<&%R83Y0
M87-S;R`R.B!#;&EQ=64@96T@(D%T=6%L:7IA<B!);F9O<FUAY^-O(&1E($%N
M97AO<R(N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+7!R:6]R:71Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB8C`R,S,V-V,S
M-F1E,V-E,34V-V0R-V-C86$T-38T,&,B/@H@("`@/'1I=&QE/D-O;7!O<VGG
MXV\@9&4@365N<V%G96TZ(%!R:6]R:61A9&4\+W1I=&QE/@H@("`@/&AE861I
M;F<^4')I;W)I9&%D93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@26YS97)I
M(&\@8V%B9>=A;&AO(")8+5!R:6]R:71Y(B!N87,@;65N<V%G96YS(&$@<V5R
M96T@96YV:6%D87,N($\@8V%B9>=A;&AO(")8+5!R:6]R:71Y(B#I('5M('1I
M<&\@9&4@(G!S975D;R!P861RXV\B(&%O('%U86P@;W,@8VQI96YT97,@9&4@
M8V]R<F5I;R!.971S8V%P92P@36]Z:6QL82P@3W!E<F$@92!/=71L;V]K('!A
M<F5C96T@97-T87(@9&4@86-O<F1O+B!1=6%L<75E<B!C;&EE;G1E(&1E(&-O
M<G)E:6\@<75E(&[C;R!L:61A(&-O;2!E<W1E(&-A8F7G86QH;R!S:6UP;&5S
M;65N=&4@;R!I9VYO<F%RX2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F-O;7!O<V4M<V%V92UA='1A8VAM96YT<R(@<W1A=&4](G5P=&]D
M871E(B!M9#4](F1B.#DY-S)C-&5B8C!B-#%A8C8Y,6(V83<W-#1A.#%D(CX*
M("`@(#QT:71L93Y#;VUP;W-IY^-O(&1E($UE;G-A9V5N<SH@4V%L=F%R($%N
M97AO<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R;6EN82!S92!O<R!A
M;F5X;W,@96T@<W5A(&-O;7!O<VGGXV\@<^-O('-A;'9O<R!C;VT@82!M96YS
M86=E;2!Q=6%N9&\@87)M87IE;F%D;W,@;F$@<&%S=&$@(D5N=FEA9&]S(BX@
M4V4@(E-)32(L(&]S(&1A9&]S(&1O(&%N97AO('-E<N-O('-A;'9O<RX@4V4@
M(D[#3R(L(&]S(&1A9&]S(&1O(&%N97AO('-E<N-O(')E;6]V:61O<R!D82!M
M96YS86=E;2!A</-S(&5L82!S97(@96YV:6%D82!P87)A('1O9&]S(&]S(&1E
M<W1I;F%TX7)I;W,N($5S8V]L:&5N9&\@(D[C;R(@86IU9&%RX2`@82!C;VYS
M97)V87(@97-P8>=O(&5M(&1I<V-O(&%O(')E;6]V97(@86YE>&]S("AP;W1E
M;F-I86QM96YT92!G<F%N9&5S*2!D92!S=6%S(&UE;G-A9V5N<RX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;&EN:RUA='1A
M8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@3&EN:R!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@:6X@>6]U
M<B!C;VUP;W-I=&EO;B!A<F4@<V5N="!A<R!A('!A<G0@;V8@=&AE(&UA:6P@
M;65S<V%G92!O<B!W:&5T:&5R('1H;W-E(&%T=&%C:&UE;G1S(&%R92!K97!T
M(&]N(&$@;&]C86P@<V5R=F5R+B`@268@871T86-H;65N=',@87)E(&QI;FME
M9"P@=&AE(')E8VEP:65N="AS*2!O9B!Y;W5R(&UE<W-A9V4@=VEL;"!B92!P
M<F]V:61E9"!A('=E8FQI;FL@=VAE<F4@=&AE>2!C86X@9&]W;FQO860@=&AE
M(&%T=&%C:&UE;G0H<RDN("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA<R!T:&4@
M861V86YT86=E(&]F('1R96UE;F1O=7-L>2!R961U8VEN9R!T:&4@<VEZ92!O
M9B!O=71G;VEN9R!M97-S86=E<RX@($QI;FMI;F<@871T86-H;65N=',@:&%S
M('1H92!D:7-A9'9A;G1A9V4@=&AA="!T:&4@8V]N=&5N="!O9B!T:&4@871T
M86-H;65N=',@8V%N(&YO="!B92!G=6%R86YT965D('1O(&)E(&%V86EL86)L
M92!I;B!T:&4@9G5T=7)E('-I;F-E('1H92!A='1A8VAM96YT(&1A=&$@:7,@
M;F]T(&QO8V%T960@=VET:&EN('1H92!E+6UA:6P@;65S<V%G92X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-E87)C:"(@<W1A=&4](G5P
M=&]D871E(B!M9#4](C@V8C)E9C4W8C$Q.30X.3`X,S-D.61D-#EE8F,Y8C,R
M(CX*("`@(#QT:71L93Y0<F]C=7)A<CPO=&ET;&4^"B`@("`\:&5A9&EN9SY#
M<FETZ7)I;W,@9&$@4')O8W5R83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5F]CZB!P;V1E('!R;V-U<F%R('!O<B!M96YS86=E;G,@96T@<W5A<R!P87-T
M87,@=71I;&EZ86YD;R!D:69E<F5N=&5S(&-R:73I<FEO<R!D92!B=7-C82X*
M("`@(#PO<&%R83X*("`@(#QP87)A/E!A<W-O(#$Z(%!R965N8VAA(&\@=&5X
M=&\@<&%R82!O<R!C86UP;W,@<75E('9O8^H@<75E<B!A9&EC:6]N87(@86\@
M8W)I=.ER:6\@9&4@8G5S8V$N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y087-S
M;R`R.B!%<V-O;&AA(&\H<RD@;6%R8V%D;W(H97,I(&1A*',I(&UE;G-A9V5M
M*&YS*2!Q=64@=F]CZB!Q=65R(&%D:6-I;VYA<B!A;R!C<FETZ7)I;R!D92!B
M=7-C82X*("`@(#PO<&%R83X*("`@(#QP87)A/E!A<W-O(#,Z($5S8V]L:&$@
M82AS*2!P87-T82AS*2!O;F1E('!R;V-U<F%R(&%S(&UE;G-A9V5N<RX*("`@
M(#PO<&%R83X*("`@(#QP87)A/E!A<W-O(#0Z($-L:7%U92!E;2`B16YV:6%R
M(BX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V4@86QG=6UA(&UE;G-A
M9V5M(&9O<B!E;F-O;G1R861A+"!O<R!A<W-U;G1O<R!D97-T87,@;65N<V%G
M96YS('-E<N-O(&5X:6)I9&]S(&5M(")297-U;'1A9&]S(&1A(%!R;V-U<F$B
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]L9&5R+6]P
M=&EO;G,B('-T871E/2)C:&%N9V5D(B!M9#4](C9D86-F83DW-#4T.&(X8S)F
M938X8S8T,C9E9#0Q-3<V(CX*("`@(#QT:71L93Y'97)E;F-I86UE;G1O(&1E
M(%!A<W1A<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY.879E9V%D;W(@9&4@4&%S
M=&%S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%9O8^H@<&]D92!S96QE
M8VEO;F%R('5M82!P87-T82!C;&EC86YD;R!N82!C86EX82!D92!C:&5C86=E
M;2!A;R!L861O(&5S<75E<F1O(&1A(&IA;F5L82X@1F5I=&\@:7-T;RP@<V5L
M96-I;VYE(&$@;W#GXV\@<75E('9O8^H@9&5S96IA(&5X96-U=&%R(&YA('!A
M<W1A('5T:6QI>F%N9&\@82!C86EX82!D92!S96QEY^-O(")%<V-O;&AA(&$@
M0>?C;R(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@5F]CZB!P;V1E
M<N$@<V5R(')E<75I<VET861O(&$@97-C;VQH97(@;W5T<F%S(&]PY_5E<R!C
M;VUP;&5M96YT87)E<RX@5&]M92!C=6ED861O(&-O;2!A(&]PY^-O(")%>&-L
M=6ER(%!A<W1A*',I(BP@<&]I<R!V;V/J('!O9&4@<&5R9&5R('1O9&%S(&%S
M('-U87,@;65N<V%G96YS(&YE<W1A('!A<W1A('-E('9O8^H@97-C;VQH97(@
M97-T82!O<.?C;R!P;W(@96YG86YO(0H@("`@/"]P87)A/@H\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB9F]L9&5R+6]P=&EO;G,B/@H@("`@/'1I
M=&QE/D9O;&1E<B!.879I9V%T;W(Z($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE
M861I;F<^1F]L9&5R($%C=&EO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M("`@66]U(&-A;B!S96QE8W0@82!F;VQD97(@8GD@=7-I;F<@=&AE(')A9&EO
M(&)U='1O;G,@86QO;F<@=&AE(&QE9G0@8V]L=6UN+B!/;F-E('EO=2!H879E
M(&1O;F4@=&AI<RP@<V5L96-T('1H92!A8W1I;VX@>6]U('=I<V@@=&\@<&5R
M9F]R;2!O;B!T:&4@9F]L9&5R('9I82!T:&4@<V5L96-T(&)O>"!T;R!T:&4@
M;&5F="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("!9;W4@;6%Y(&)E
M('!R;VUP=&5D(&9O<B!F=7)T:&5R(&]P=&EO;G,N($)E(&-A<F5F=6P@=VET
M:"!T:&4@9&5L971E(&]P=&EO;BP@87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@
M;65S<V%G97,@:6X@82!F;VQD97(@:68@>6]U(&1E;&5T92!I="!B>2!M:7-T
M86ME(0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^26UP;W)T($UE<W-A9V5S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%1H:7,@;W!T:6]N('=I;&P@
M:6UP;W)T(&UB;W@@9F]R;6%T(&]R("YE;6P@9FEL97,@:6YT;R!T:&4@9F]L
M9&5R(&]F('EO=7(@8VAO:6-E+B!#:&]O<V4@;VYE(&9O;&1E<B!T;R!I;7!O
M<G0@=&AE(&UE<W-A9V5S(&EN=&\@86YD('1H96X@<V5L96-T('1H:7,@;W!T
M:6]N+B!9;W4@=VEL;"!T:&5N(&)E('1A:V5N('1O(&$@<&%G92!T:&%T('=I
M;&P@<')O;7!T(&9O<B!T:&4@;6)O>"!O<B`N96UL(&9I;&4@=&\@:6UP;W)T
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPA+2T@16YG;&ES:"!E;G1R>3H*
M/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(^"B`@("`\=&ET;&4^1F]L9&5R
M($YA=FEG871O<CH@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY&;VQD
M97(@06-T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!9;W4@8V%N
M('-E;&5C="!A(&9O;&1E<B!B>2!U<VEN9R!T:&4@<F%D:6\@8G5T=&]N<R!A
M;&]N9R!T:&4@;&5F="!C;VQU;6XN($]N8V4@>6]U(&AA=F4@9&]N92!T:&ES
M+"!S96QE8W0@=&AE(&%C=&EO;B!Y;W4@=VES:"!T;R!P97)F;W)M(&]N('1H
M92!F;VQD97(@=FEA('1H92!S96QE8W0@8F]X('1O('1H92!L969T+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%EO=2!M87D@8F4@<')O;7!T960@
M9F]R(&9U<G1H97(@;W!T:6]N<RX@0F4@8V%R969U;"!W:71H('1H92!D96QE
M=&4@;W!T:6]N+"!A<R!Y;W4@8V%N(&QO<V4@86QL('1H92!M97-S86=E<R!I
M;B!A(&9O;&1E<B!I9B!Y;W4@9&5L971E(&ET(&)Y(&UI<W1A:V4A"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY);7!O<G0@365S<V%G97,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@5&AI<R!O<'1I;VX@=VEL;"!I;7!O<G0@;6)O
M>"!F;W)M870@;W(@+F5M;"!F:6QE<R!I;G1O('1H92!F;VQD97(@;V8@>6]U
M<B!C:&]I8V4N($-H;V]S92!O;F4@9F]L9&5R('1O(&EM<&]R="!T:&4@;65S
M<V%G97,@:6YT;R!A;F0@=&AE;B!S96QE8W0@=&AI<R!O<'1I;VXN(%EO=2!W
M:6QL('1H96X@8F4@=&%K96X@=&\@82!P86=E('1H870@=VEL;"!P<F]M<'0@
M9F]R('1H92!M8F]X(&]R("YE;6P@9FEL92!T;R!I;7!O<G0N"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60]
M(F9O;&1E<BUO<'1I;VYS(CX*("`@(#QT:71L93Y&;VQD97(@3F%V:6=A=&]R
M.B!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D9O;&1E<B!!8W1I;VYS
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%EO=2!C86X@<V5L96-T(&$@
M9F]L9&5R(&)Y('5S:6YG('1H92!R861I;R!B=71T;VYS(&%L;VYG('1H92!L
M969T(&-O;'5M;BX@3VYC92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C="!T
M:&4@86-T:6]N('EO=2!W:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E<B!V
M:6$@=&AE('-E;&5C="!B;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@("`@66]U(&UA>2!B92!P<F]M<'1E9"!F;W(@9G5R=&AE
M<B!O<'1I;VYS+B!"92!C87)E9G5L('=I=&@@=&AE(&1E;&5T92!O<'1I;VXL
M(&%S('EO=2!C86X@;&]S92!A;&P@=&AE(&UE<W-A9V5S(&EN(&$@9F]L9&5R
M(&EF('EO=2!D96QE=&4@:70@8GD@;6ES=&%K92$*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/DEM<&]R="!-97-S86=E<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@("!4:&ES(&]P=&EO;B!W:6QL(&EM<&]R="!M8F]X(&9O<FUA="!O
M<B`N96UL(&9I;&5S(&EN=&\@=&AE(&9O;&1E<B!O9B!Y;W5R(&-H;VEC92X@
M0VAO;W-E(&]N92!F;VQD97(@=&\@:6UP;W)T('1H92!M97-S86=E<R!I;G1O
M(&%N9"!T:&5N('-E;&5C="!T:&ES(&]P=&EO;BX@66]U('=I;&P@=&AE;B!B
M92!T86ME;B!T;R!A('!A9V4@=&AA="!W:6QL('!R;VUP="!F;W(@=&AE(&UB
M;W@@;W(@+F5M;"!F:6QE('1O(&EM<&]R="X*("`@(#PO<&%R83X*/"]E;G1R
M>3XM+3X\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB9F]L9&5R+6]P
M=&EO;G,B/@H@("`@/'1I=&QE/D9O;&1E<B!.879I9V%T;W(Z($%C=&EO;G,\
M+W1I=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($%C=&EO;G,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@82!F;VQD97(@8GD@
M=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE(&QE9G0@8V]L=6UN
M+B!/;F-E('EO=2!H879E(&1O;F4@=&AI<RP@<V5L96-T('1H92!A8W1I;VX@
M>6]U('=I<V@@=&\@<&5R9F]R;2!O;B!T:&4@9F]L9&5R('9I82!T:&4@<V5L
M96-T(&)O>"!T;R!T:&4@;&5F="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@("!9;W4@;6%Y(&)E('!R;VUP=&5D(&9O<B!F=7)T:&5R(&]P=&EO;G,N
M($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO;BP@87,@>6]U(&-A
M;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD97(@:68@>6]U(&1E
M;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M26UP;W)T($UE<W-A9V5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%1H
M:7,@;W!T:6]N('=I;&P@:6UP;W)T(&UB;W@@9F]R;6%T(&]R("YE;6P@9FEL
M97,@:6YT;R!T:&4@9F]L9&5R(&]F('EO=7(@8VAO:6-E+B!#:&]O<V4@;VYE
M(&9O;&1E<B!T;R!I;7!O<G0@=&AE(&UE<W-A9V5S(&EN=&\@86YD('1H96X@
M<V5L96-T('1H:7,@;W!T:6]N+B!9;W4@=VEL;"!T:&5N(&)E('1A:V5N('1O
M(&$@<&%G92!T:&%T('=I;&P@<')O;7!T(&9O<B!T:&4@;6)O>"!O<B`N96UL
M(&9I;&4@=&\@:6UP;W)T+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPA+2T@
M16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(^"B`@
M("`\=&ET;&4^1F]L9&5R($YA=FEG871O<CH@06-T:6]N<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY&;VQD97(@06-T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@("!9;W4@8V%N('-E;&5C="!A(&9O;&1E<B!B>2!U<VEN9R!T:&4@
M<F%D:6\@8G5T=&]N<R!A;&]N9R!T:&4@;&5F="!C;VQU;6XN($]N8V4@>6]U
M(&AA=F4@9&]N92!T:&ES+"!S96QE8W0@=&AE(&%C=&EO;B!Y;W4@=VES:"!T
M;R!P97)F;W)M(&]N('1H92!F;VQD97(@=FEA('1H92!S96QE8W0@8F]X('1O
M('1H92!L969T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%EO=2!M
M87D@8F4@<')O;7!T960@9F]R(&9U<G1H97(@;W!T:6]N<RX@0F4@8V%R969U
M;"!W:71H('1H92!D96QE=&4@;W!T:6]N+"!A<R!Y;W4@8V%N(&QO<V4@86QL
M('1H92!M97-S86=E<R!I;B!A(&9O;&1E<B!I9B!Y;W4@9&5L971E(&ET(&)Y
M(&UI<W1A:V4A"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY);7!O<G0@365S
M<V%G97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@5&AI<R!O<'1I;VX@
M=VEL;"!I;7!O<G0@;6)O>"!F;W)M870@;W(@+F5M;"!F:6QE<R!I;G1O('1H
M92!F;VQD97(@;V8@>6]U<B!C:&]I8V4N($-H;V]S92!O;F4@9F]L9&5R('1O
M(&EM<&]R="!T:&4@;65S<V%G97,@:6YT;R!A;F0@=&AE;B!S96QE8W0@=&AI
M<R!O<'1I;VXN(%EO=2!W:6QL('1H96X@8F4@=&%K96X@=&\@82!P86=E('1H
M870@=VEL;"!P<F]M<'0@9F]R('1H92!M8F]X(&]R("YE;6P@9FEL92!T;R!I
M;7!O<G0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT
M<GD@:60](F9O;&1E<BUW:61G971S(B!S=&%T93TB8VAA;F=E9"(@;60U/2)D
M,F8U.#`V,S,U,F0P-S)D,#(W,30T.#@Y,31B-3-D9"(^"B`@("`\=&ET;&4^
M1V5R96YC:6%M96YT;R!D92!087-T87,Z($5X:6)IY^-O/"]T:71L93X*("`@
M(#QH96%D:6YG/D5X:6)I<B]/8W5L=&%R($[C;R!);G-C<FET87,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%-E(&5S=&EV97(@=71I;&EZ86YD;R!I;G-C
M<FGGXV\@9&4@<&%S=&%S($E-05`L(&5S=&$@;W#GXV\@97AI8F4O;V-U;'1A
M(&%S('!A<W1A<R!NXV\@:6YS8W)I=&%S+B!087)A('-E(&EN<V-R979E<B]D
M97-I;G-C<F5V97(@=6UA('!A<W1A+"!S96QE8VEO;F4@82!C86EX82!D92!C
M:&5C86=E;2!A;R!L861O(&1O(&YO;64@9&$@<&%S=&$@92!U<V4@82!O<.?C
M;R`B26YS8W)E=F5R+7-E+T1E<VEN<V-R979E<BUS92#@*',I(%!A<W1A*',I
M(B!N;R!M96YU(&1E('-E;&7GXV\@9&4@8>?U97,N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY%>'!A;F1I<B!4;V1A<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@17AP86YD92!T;V1A(&$@:&EE<F%R<75I82!D92!P87-T87,N"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VYT<F%I<B!4;V1A<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@1F5C:&$@=&]D82!A(&AI97)A<G%U:6$@9&4@
M<&%S=&%S+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB9F]L9&5R+7=I9&=E=',B/@H@("`@/'1I=&QE/D9O;&1E<B!.879I
M9V%T;W(Z($1I<W!L87D\+W1I=&QE/@H@("`@/&AE861I;F<^4VAO=R](:61E
M(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=7-I
M;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO=R]H:61E('1H92!U
M;G-U8G-C<FEB960@9F]L9&5R<RX@5&\@<W5B<V-R:6)E+W5N<W5B<V-R:6)E
M('1O(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K8F]X(&YE>'0@=&\@=&AE
M(&9O;&1E<FYA;64@86YD('5S92!T:&4@4W5B<V-R:6)E+U5N<W5B<V-R:6)E
M(&%C=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D<F]P+61O=VX@;65N=2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9"!!;&P\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($5X<&%N9"!A;&P@9F]L9&5R(&5N=')I97,N"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S92!!;&P\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($-O;&QA<'-E(&%L;"!F;VQD97(@96YT<FEE<RX*
M("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB9F]L9&5R+7=I9&=E=',B/@H@("`@/'1I=&QE/D9O;&1E<B!.
M879I9V%T;W(Z($1I<W!L87D\+W1I=&QE/@H@("`@/&AE861I;F<^4VAO=R](
M:61E(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M=7-I;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO=R]H:61E('1H
M92!U;G-U8G-C<FEB960@9F]L9&5R<RX@5&\@<W5B<V-R:6)E+W5N<W5B<V-R
M:6)E('1O(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K8F]X(&YE>'0@=&\@
M=&AE(&9O;&1E<FYA;64@86YD('5S92!T:&4@4W5B<V-R:6)E+U5N<W5B<V-R
M:6)E(&%C=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D<F]P+61O=VX@;65N
M=2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9"!!;&P\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5X<&%N9"!A;&P@9F]L9&5R(&5N=')I97,N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S92!!;&P\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($-O;&QA<'-E(&%L;"!F;VQD97(@96YT<FEE
M<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\(2TM($5N9VQI<V@@96YT<GDZ
M"CQE;G1R>2!I9#TB9F]L9&5R+7=I9&=E=',B/@H@("`@/'1I=&QE/D9O;&1E
M<B!.879I9V%T;W(Z($1I<W!L87D\+W1I=&QE/@H@("`@/&AE861I;F<^4VAO
M=R](:61E(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M268@=7-I;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO=R]H:61E
M('1H92!U;G-U8G-C<FEB960@9F]L9&5R<RX@5&\@<W5B<V-R:6)E+W5N<W5B
M<V-R:6)E('1O(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K8F]X(&YE>'0@
M=&\@=&AE(&9O;&1E<FYA;64@86YD('5S92!T:&4@4W5B<V-R:6)E+U5N<W5B
M<V-R:6)E(&%C=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D<F]P+61O=VX@
M;65N=2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9"!!;&P\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($5X<&%N9"!A;&P@9F]L9&5R(&5N=')I
M97,N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S92!!;&P\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($-O;&QA<'-E(&%L;"!F;VQD97(@96YT
M<FEE<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB9F]L9&5R+7=I9&=E=',B/@H@("`@/'1I=&QE/D9O
M;&1E<B!.879I9V%T;W(Z($1I<W!L87D\+W1I=&QE/@H@("`@/&AE861I;F<^
M4VAO=R](:61E(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@268@=7-I;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO=R]H
M:61E('1H92!U;G-U8G-C<FEB960@9F]L9&5R<RX@5&\@<W5B<V-R:6)E+W5N
M<W5B<V-R:6)E('1O(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K8F]X(&YE
M>'0@=&\@=&AE(&9O;&1E<FYA;64@86YD('5S92!T:&4@4W5B<V-R:6)E+U5N
M<W5B<V-R:6)E(&%C=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D<F]P+61O
M=VX@;65N=2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9"!!;&P\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($5X<&%N9"!A;&P@9F]L9&5R(&5N
M=')I97,N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S92!!;&P\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($-O;&QA<'-E(&%L;"!F;VQD97(@
M96YT<FEE<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\(2TM($5N9VQI<V@@
M96YT<GDZ"CQE;G1R>2!I9#TB9F]L9&5R+7=I9&=E=',B/@H@("`@/'1I=&QE
M/D9O;&1E<B!.879I9V%T;W(Z($1I<W!L87D\+W1I=&QE/@H@("`@/&AE861I
M;F<^4VAO=R](:61E(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@268@=7-I;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO
M=R]H:61E('1H92!U;G-U8G-C<FEB960@9F]L9&5R<RX@5&\@<W5B<V-R:6)E
M+W5N<W5B<V-R:6)E('1O(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K8F]X
M(&YE>'0@=&\@=&AE(&9O;&1E<FYA;64@86YD('5S92!T:&4@4W5B<V-R:6)E
M+U5N<W5B<V-R:6)E(&%C=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D<F]P
M+61O=VX@;65N=2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9"!!
M;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5X<&%N9"!A;&P@9F]L9&5R
M(&5N=')I97,N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S92!!
M;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-O;&QA<'-E(&%L;"!F;VQD
M97(@96YT<FEE<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R<R(@<W1A=&4](G5P=&]D871E(B!M9#4](C5E
M9C8P-S@V-S8W938S.&9B9C5B83AF8S5B9#5D.60R(CX*("`@(#QT:71L93Y&
M:6QT<F]S.B!!<&QI8V%R/"]T:71L93X*("`@(#QH96%D:6YG/D%P;&EC87(@
M1FEL=')O<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI<75E(&YO(.UC
M;VYE(")!<&QI8V%R($9I;'1R;R!E;2(@86\@;&%D;R!D;R!N;VUE(&1A('!A
M<W1A(&YA('9I<W5A;&EZ8>?C;R!D82!C86EX82!P;W-T86P@<&%R82!F:6QT
M<F%R('1O9&%S(&%S(&UE;G-A9V5N<R!NXV\@97AC;'7M9&%S(&1E(&%C;W)D
M;R!C;VT@87,@<F5G<F%S(&5S<&5C:69I8V%D87,N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UR=6QE<R(@<W1A=&4]
M(G5P=&]D871E(B!M9#4](C5B86$U-S`X86,Y-#0Y93<Y-V8Y-C<S,3-A.64Q
M83(W(CX*("`@(#QT:71L93Y&:6QT<F]S.B!%9&ET87(@4F5G<F%S(&1E($9I
M;'1R;SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%9&ET87(@4W5A<R!296=R87,@
M9&4@1FEL=')O<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI<75E(&5M
M(")%9&ET87(@<W5A<R!R96=R87,@9&4@9FEL=')O(B!P87)A(&ER('!A<F$@
M82!PX6=I;F$@;VYD92!V;V/J('!O9&4@861I8VEO;F%R+"!E>&-L=6ER(&4@
M961I=&%R(&\@8V]N:G5N=&\@9&4@<F5G<F%S(&1E(&9I;'1R;R!Q=64@97-T
M96IA;2!A=&EV87,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)F:6QT97(M961I="UB;&%C:VQI<W0B('-T871E/2)U<'1O9&%T92(@;60U
M/2(X,&9F-S@P,V,V-C4Y.6,W,#,U9C=F.#@Q,60R,3AC8R(^"B`@("`\=&ET
M;&4^1FEL=')O<SH@161I=&%R($QI<W1A($YE9W)A/"]T:71L93X*("`@(#QH
M96%D:6YG/D5D:71A<B!3=6$@3&ES=&$@3F5G<F$\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-L:7%U92!E;2`B161I=&%R('-U82!L:7-T82!N96=R82(@
M<&%R82!I<B!P87)A(&$@<.%G:6YA(&]N9&4@=F]CZB!P;V1E(&%D:6-I;VYA
M<BP@97AC;'5I<B!E(&5D:71A<B!A(&QI<W1A(&1E(&5N9&5R9>=O<R!D92!E
M+6UA:6P@9&4@<F5M971E;G1E<R!D92!Q=65M('9O8^H@4T5-4%)%('9A:2!R
M96-U<V%R(&UE;G-A9V5N<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F9I;'1E<BUE9&ET+7=H:71E;&ES="(@<W1A=&4](G5P=&]D871E
M(B!M9#4](C,S,&,S83AF860Q.3AC-V%F93@U-6,Q,#%C-C-C9#!F(CX*("`@
M(#QT:71L93Y&:6QT<F]S.B!%9&ET87(@3&ES=&$@0G)A;F-A/"]T:71L93X*
M("`@(#QH96%D:6YG/D5D:71A<B!3=6$@3&ES=&$@0G)A;F-A/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#;&EQ=64@96T@(D5D:71A<B!S=6$@;&ES=&$@
M8G)A;F-A(B!P87)A('-E<B!E;F-A;6EN:&%D;R!P87)A(&$@<.%G:6YA(&]N
M9&4@=F]CZB!P;V1E(&%D:6-I;VYA<BP@97AC;'5I<B!E(&5D:71A<B!A(&QI
M<W1A(&1E(&5N9&5R9>=O<R!D92!R96UE=&5N=&5S(&1E('%U96T@=F]CZB!3
M14U04D4@=F%I(&%C96ET87(@;65N<V%G96YS+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB,S=D.3(Y-V0Q8V-A-#8T,S5E,S9B-F4S.&4T-61C9&(B
M/@H@("`@/'1I=&QE/D9I;'1R;W,Z($9I;'1R87(@86\@8V]N96-T87(\+W1I
M=&QE/@H@("`@/&AE861I;F<^07!L:6-A<B!296=R87,@9&4@1FEL=')O(&%O
M($-O;F5C=&%R/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@071I=F4@97-T
M82!O<.?C;R!P87)A('-E;7!R92!A<&QI8V%R(&9I;'1R;W,@<75A;F1O(&-O
M;F5C=&%R(&%O($E-4"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](F9I;'1E<BUO;BUD:7-P;&%Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M9C5A9F,S,#4T,#)E9C4R8F%D,3`X.3,S9C-F,S,R.3$B/@H@("`@/'1I=&QE
M/D9I;'1R;W,Z($9I;'1R87(@86\@071U86QI>F%R/"]T:71L93X*("`@(#QH
M96%D:6YG/D%P;&EC87(@<F5G<F%S(&1E(&9I;'1R;R!S96UP<F4@<75E(&$@
M0V%I>&$@9&4@16YT<F%D82!F;W(@97AI8FED83\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($%T:79E(&5S=&$@;W#GXV\@<&%R82!S96UP<F4@87!L:6-A
M<B!F:6QT<F]S(&%O(&5X:6)I<B!A($-A:7AA(&1E($5N=')A9&$N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M86YY+6UA:6QB
M;W@B('-T871E/2)U<'1O9&%T92(@;60U/2(W,6,U,64X,SDP.68Y9#!B9#0T
M,&0R,C`W-S)E93-C-B(^"B`@("`\=&ET;&4^1FEL=')O<SH@1FEL=')A<B!Q
M=6%L<75E<B!#86EX82!0;W-T86P\+W1I=&QE/@H@("`@/&AE861I;F<^07!L
M:6-A<B!R96=R87,@9&4@9FEL=')O(&5M('%U86QQ=65R(&-A:7AA('!O<W1A
M;#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($%T:79E(&5S=&$@;W#GXV\@
M<V4@=F]CZB!D97-E:F$@<&5R;6ET:7(@87!L:6-A<B!R96=R87,@9&4@9FEL
M=')O(&5M('%U86QQ=65R(&-A:7AA('!O<W1A;"X@3F]R;6%L;65N=&4L(')E
M9W)A<R!D92!F:6QT<F\@<V4@87!L:6-A;2!S;VUE;G1E(&$@;F]V87,@;65N
M<V%G96YS('%U92!SXV\@96YT<F5G=65S(&5M('-U82!#86EX82!D92!%;G1R
M861A+B!392!E<W1A(&]PY^-O(&5S=&EV97(@871I=F$L('5M(.UC;VYE(&%P
M87)E8V5RX2!E;2!T;V1A<R!A<R!PX6=I;F%S(&1A(&-A:7AA('!O<W1A;"!P
M97)M:71I;F1O('9O8^H@87!L:6-A<B!R96=R87,@9&4@9FEL=')O(&5M('1O
M9&%S(&%S(&UE;G-A9V5N<R!N82!C86EX82!P;W-T86P@871U86PN($Y/5$$Z
M($9I;'1R87(@96T@;W5T<F%S(&-A:7AA<R!P;W-T86ES('%U92!NXV\@82!#
M86EX82!D92!%;G1R861A('!O9&4@<')O9'5Z:7(@<F5S=6QT861O<R!E<W1R
M86YH;W,@*&5X+CH@;R!F:6QT<F\@<&]D92!F87IE<B!C;VT@<75E('5M82!C
M\W!I82!D82!M96YS86=E;2!S96IA(&5N=')E9W5E('!A<F$@82!M97-M82!C
M86EX82!P;W-T86PI(&4O;W4@:6YD97-E:F%D;W,@*&5X+CH@:7-T;R!P;V1E
M(&9A>F5R(&-O;2!Q=64@;65N<V%G96YS('-E:F%M(&UO=FED87,O97AC;'7M
M9&%S('-E('5M82!N;W9A(')E9W)A(&1E(&9I;'1R;R!F;VD@:6UP;&5M96YT
M861A(&1E<V1E(&$@;65N<V%G96T@=&5R('-I9&\@96YT<F5G=64@;F$@8V%I
M>&$@<&]S=&%L(&%T=6%L*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C:"UP=6)K97DB('-T871E/2)U<'1O
M9&%T92(@;60U/2(Y-S0T-F1B8F(R-S8Q-F(T9F$S.6)E.#`Q93$P9&8R9"(^
M"B`@("`\=&ET;&4^4$=0.B!!;F5X87(@0VAA=F4@4/IB;&EC83PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY!;F5X87(@0VAA=F4@4/IB;&EC83PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@4V4@<V5L96-I;VYA9&\L('5M82!C\W!I82!D92!S
M=6$@8VAA=F4@<'5B;&EC82!01U`L('-E(&5X:7-T:7(L('-E<N$@86YE>&%D
M82!N87,@;65N<V%G96YS('%U92!V;V/J(&5N=FEA<BX@5F]CZB!P;V1E(&-O
M;F9I9W5R87(@=6T@8V]M<&]R=&%M96YT;R!P861RXV\@;F$@=&5L82!D92!/
M<.?U97,@9&4@4$=0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+6]P=&EO;BUS8V%N+6)O9'DB('-T871E/2)U<'1O9&%T92(@;60U
M/2(V8F%A861A,&0T-F1C,6%B,#DT,3`X-V8R,S5F,S4Y8B(^"B`@("`\=&ET
M;&4^4$=0.B!%>&%M:6YA<B!#;W)P;R!D87,@365N<V%G96YS/"]T:71L93X*
M("`@(#QH96%D:6YG/D5X86UI;F%R($-O<G!O(&1A<R!-96YS86=E;G,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%-E('-E;&5C:6]N861O+"!)35`@97AA
M;6EN87+A(&\@8V]R<&\@9&4@=&]D87,@87,@;65N<V%G96YS('1E>'1O('!R
M;V-U<F%N9&\@<&]R(&EN9F]R;6'G]65S(%!'4"P@92!M;W-T<F%RX2!O<R!R
M97-U;'1A9&]S(&-A<V\@<V5J82!E;F-O;G1R861O+B!.;W1E('%U92!I<W1O
M('!O9&4@9&5G<F%D87(@;R!S:7-T96UA(&KA('%U92!T;V1A(&UE;G-A9V5M
M('-E<N$@97AA;6EN861A('!O<B!C;VUP;&5T;R!A('!R;V-U<F$@9&4@:6YF
M;W)M8>?U97,@4$=0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UO<'1I;VYS+65N8W)Y<'0B('-T871E/2)U<'1O9&%T92(@
M;60U/2(Q,#$R,30T9C<T.68Q.68U83(T8V5F,S@V,#%D86$W,2(^"B`@("`\
M=&ET;&4^0V]M<&]S:>?C;R!D92!-96YS86=E;3H@3W#G]65S(&1E($-R:7!T
M;V=R869I83PO=&ET;&4^"B`@("`\:&5A9&EN9SY396T@0W)I<'1O9W)A9FEA
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G9I82!A(&UE;G-A9V5M('-E
M;2!C<FEP=&]G<F%F87(@*'1E>'1O('!U<F\I+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^365N<V%G96T@0W)I<'1O9W)A9F%D82!C;VT@4$=0/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!%<W1A(&]PY^-O('9A:2!C<FEP=&]G<F%F
M87(@82!M96YS86=E;2!A='5A;"P@=71I;&EZ86YD;R!01U`@92!A(&-H879E
M('#Z8FQI8V$@9&\@9&5S=&EN873A<FEO+"!E(&5N=.-O(&5N=FGA+6QA+B!6
M;V/J('!O9&4@<V]M96YT92!E;G9I87(@;65N<V%G96YS('!A<F$@=6T@^FYI
M8V\@9&5S=&ENX71A<FEO('5T:6QI>F%N9&\@97-T82!O<.?C;RX@5F]CZB!$
M159%('1E<B!A(&-H879E('!U8FQI8V$@9&\@9&5S=&EN873A<FEO(&%R;6%Z
M96YA9&$@;F\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!O=2!E<W1A(&]P
MY^-O(&9A;&AA<N$N(%-E('9O8^H@=&5M(&$@8VAA=F4@</IB;&EC82!D;R!D
M97-T:6YA=.%R:6\@96T@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!E('9O
M8^H@;65S;6\@87-S:6T@8V]N=&EN=6%R(')E8V5B96YD;R!M96YS86=E;G,@
M9&4@97)R;RP@=F5R:69I<75E('-E(&\@96YD97)EYV\@9&4@92UM86EL(&YO
M(&-A;7!O(")087)A.B(@8V]R<F5S<&]N9&4@86\@96YD97)EYV\@9&4@92UM
M86EL(&]N9&4@82!C:&%V92!P^F)L:6-A(&5S=.$@87)M87IE;F%D82X@3W,@
M9&%D;W,@8W)I<'1O9W)A9F%D;W,@<V5RXV\@86YE>&%D;W,@82!M96YS86=E
M;2!A('-E<B!E;G9I861A+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^365N
M<V%G96T@07-S:6YA9&$@8V]M(%!'4#PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@17-T82!O<.?C;R!A<W-I;F%RX2!D:6=I=&%L;65N=&4@82!M96YS86=E
M;2!A='5A;"!U=&EL:7IA;F1O(%!'4"!E('-U82!C:&%V92!P<FEV861A('!E
M<W-O86PN(%-E('9O8^H@86EN9&$@;N-O(&9O<FYE8V5U(&$@<V5N:&$@<&%R
M82!S=6$@8VAA=F4@<')I=F%D82!N97-T82!S97-SXV\@=F]CZB!S97+A('-O
M;&EC:71A9&\@82!F;W)N96/J+6QA+B!/(&1E<W1I;F%TX7)I;R!D979E('1E
M<B!U;6$@8_-P:6$@9&4@<W5A(&-H879E('#Z8FQI8V$@<&%R82!V97)I9FEC
M87(@9&EG:71A;&UE;G1E('-U82!A<W-I;F%T=7)A+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^365N<V%G96T@07-S:6YA9&$@92!#<FEP=&]G<F%F861A
M(&-O;2!01U`\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5S=&$@;W#GXV\@
M<')I;65I<F%M96YT92!A<W-I;F%RX2!D:6=I=&%L;65N=&4@<W5A(&UE;G-A
M9V5M(&4@96YTXV\@8W)I<'1O9W)A9F%RX2!O(')E<W5L=&%D;RX@5F5J82!A
M<R!S97-S]65S(")-96YS86=E;2!#<FEP=&]G<F%F861A(&-O;2!01U`B(&4@
M(DUE;G-A9V5M($%S<VEN861A(&-O;2!01U`B('!A<F$@;6%I;W)E<R!I;F9O
M<FUAY_5E<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DUE;G-A9V5M($-R
M:7!T;V=R869A9&$@8V]M(%,O34E-13PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@P"!C;VYC;'5I<BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DUE;G-A
M9V5M($%S<VEN861A(&-O;2!3+TU)344\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(,`@8V]N8VQU:7(N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY-96YS
M86=E;2!!<W-I;F%D82!E($-R:7!T;V=R869A9&$@8V]M(%,O34E-13PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@P"!C;VYC;'5I<BX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R=FEE=R(@<W1A=&4](G5P
M=&]D871E(B!M9#4](C(T8C4Q,SAB-&(U,V8W,V(U9C)F,C<S.64T8S$X-3AD
M(CX*("`@(#QT:71L93Y01U`Z(%9I<^-O($=E<F%L/"]T:71L93X*("`@(#QH
M96%D:6YG/D\@<75E(.D@4$=0/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M4$=0(.D@=6UA(&9E<G)A;65N=&$@<&%R82!C;VUU;FEC8>?C;R!E(&%R;6%N
M97IA;65N=&\@9&4@9&%D;W,@<V5G=7)O<RP@97-P96-I86QM96YT92!P87)A
M('5S87(@8V]M(&4M;6%I;"X@16QE('!O9&4@<V5R('5T:6QI>F%D;R!P87)A
M(&-R:7!T;V=R869A<B!D861O<R!E(&-R:6%R(&%S<VEN871U<F%S(&1I9VET
M86ES+B!/($E-4"!U=&EL:7IA($=N=5!'("A'3E4@4')I=F%C>2!'=6%R9"D@
M<&%R82!O9F5R96-E<B!E<W1A(&9U;F-I;VYA;&ED861E+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^2&%B:6QI=&%R($9U;F-I;VYA;&ED861E(%!'4#\\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E(&5S=&$@;W#GXV\@97-T:79E
M<B!S96QE8VEO;F%D82P@=F]CZB!S97+A(&%P=&\@82!C<FEA<B]V:7-U86QI
M>F%R('-U87,@8VAA=F5S('!E<W-O86ES(%!'4"P@861I8VEO;F%R+V5X8VQU
M:7(@8VAA=F5S('#Z8FQI8V%S(&1E(&]U=')A<R!P97-S;V%S+"!L97(@;65N
M<V%G96YS(&-R:7!T;V=R869A9&%S+"!V97)I9FEC87(@;65N<V%G96YS(&%S
M<VEN861A<R!D:6=I=&%L;65N=&4@92!C<FEP=&]G<F%F87(O87-S:6YA<B!S
M=6%S(&UE;G-A9V5N<R!A;R!E;G9I87(N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C:"UP=6)K97DB('-T871E
M/2)U<'1O9&%T92(@;60U/2(U-C%C930S,S<P86,T869B8V,S9CDX,3AC.&9B
M8S)F-B(^"B`@("`\=&ET;&4^4$=0.B!/<.?U97,@+2!!;F5X87(@0VAA=F4@
M4/IB;&EC83PO=&ET;&4^"B`@("`\:&5A9&EN9SY/<.?U97,@+2!!;F5X87(@
M0VAA=F4@4/IB;&EC83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V4@<V5L
M96-I;VYA9&\L('5M82!C\W!I82!D92!S=6$@8VAA=F4@<'5B;&EC82!01U`L
M('-E(&5X:7-T:7(L('-E<N$@<&]R('!A9'+C;R!A;F5X861A(&$@=&]D87,@
M87,@;65N<V%G96YS(&5N=FEA9&%S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<&=P+6UA;F%G92UP=6)K97DB('-T871E/2)U<'1O9&%T
M92(@;60U/2)B,C@Y96$U.#(T8C=F-CEF,S5C,#<U,30Y-V8T93%C,R(^"B`@
M("`\=&ET;&4^4$=0.B!'97)E;F-I86YD;R!#:&%V97,@4/IB;&EC87,\+W1I
M=&QE/@H@("`@/&AE861I;F<^5FESXV\@1V5R86P\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($5S=&$@=&5L82!L:7-T82!T;V1O<R!O<R!U<W7A<FEO<R!A
M='5A;&UE;G1E(&5M('-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,@<75E('3J
M;2!C:&%V97,@</IB;&EC87,@4$=0+B!%<W1E<R!SXV\@;W,@VDY)0T]3('5S
M=>%R:6]S('!A<F$@<75E;2!V;V/J('!O9&4@,2D@96YV:6%R('5M82!M96YS
M86=E;2!E;F-R:7!T861A("U/52T@,BD@=F5R:69I8V%R('5M82!A<W-I;F%T
M=7)A(&1I9VET86PN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY697(\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($%B<F4@=6UA(&IA;F5L82!P87)A(&5X
M:6)I<B!A(&-H879E('#Z8FQI8V$@4$=0+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^1&5T86QH97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($UO<W1R
M82!A;&=U;G,@9&5T86QH97,@<V]B<F4@82!C:&%V92!P^F)L:6-A(%!'4"X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5X8VQU:7(\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($5X8VQU:2!A(&-H879E('#Z8FQI8V$@9&4@<V5U(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UI;7!O<G0M<'5B:V5Y(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB-F5E,3$S,&(T-F4Y9F8Q8V$Y860S83-A-#=E-V(S.#(B/@H@("`@
M/'1I=&QE/E!'4#H@1V5R96YC:6%N9&\@0VAA=F5S(%#Z8FQI8V%S("T@26UP
M;W)T87(\+W1I=&QE/@H@("`@/&AE861I;F<^26UP;W)T87(@0VAA=F4@4/IB
M;&EC83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17-T92!B;W3C;R!A8G)I
M<N$@=6UA(&IA;F5L82!O;F1E('9O8^H@<&]D92!M86YU86QM96YT92!I;7!O
M<G1A<B!U;6$@8VAA=F4@</IB;&EC82!01U`N($$@8VAA=F4@<&]D92!S97(@
M8V]L861A(&1E;G1R;R!D;R!C86UP;R!T97AT;R!O=2P@<V4@82!C:&%V92!P
M^F)L:6-A(&5S=&EV97(@96T@=6T@87)Q=6EV;R!N;R!S974@8V]M<'5T861O
M<BP@=F]CZB!P;V1E(&EM<&]R=.$M;&$N(%-E(&$@8VAA=F4@</IB;&EC82!F
M;W(@=N%L:61A(&5L82!S97+A(&EN<V5R:61A(&5M('-E=2!C873A;&]G;R!D
M92!E;F1E<F7G;W,@92!A(&IA;F5L82!F96-H87+A.R!S92!NXV\@9F]R(';A
M;&ED82P@=6UA(&UE;G-A9V5M(&1E(&5R<F\@<V5RX2!R971O<FYA9&$@97AP
M;&EC86YD;R!O('!O<G%UZBX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UO=F5R=FEE=RUP97)S;VYA;&ME>2(@<W1A=&4](G5P=&]D
M871E(B!M9#4](C(R,&%F,F(W-&$U.&8T,S!E9F0W,F0V9#9B,68Y.3-F(CX*
M("`@(#QT:71L93Y01U`Z($=E<F5N8VEA;F1O($-H879E<R!097-S;V%I<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY6:7/C;R!'97)A;#PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@4V4@=F]CZB!Q=65R(&%S<VEN87(@9&EG:71A;&UE;G1E
M(&UE;G-A9V5N<R!O=2!P97)M:71I<B!Q=64@;W5T<F]S(&QH97,@96YV:65M
M(&UE;G-A9V5N<R!C<FEP=&]G<F%F861A<RP@=F]CZB!D979E('!O<W-U:7(@
M<V5U('!R\W!R:6\@<&%R(&1E(&-H879E<R!P^F)L:6-A+W!R:79A9&$@4$=0
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4W5A($-H879E(%#Z8FQI8V$\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-U82!C:&%V92!P^F)L:6-A(&1E
M=F4@97-T87(@9&ES<&]N[79E;"!P87)A('%U86QQ=65R('!E<W-O82!Q=64@
M=F]CZB!Q=65R('%U92!S96IA(&%P=&\@82!E;G9IX2UL;R!M96YS86=E;G,@
M8W)I<'1O9W)A9F%D87,@<75E('-O;65N=&4@5D]#RB!P;V1E(&1E<V-R:7!T
M;V=R869A<B`H=7-A;F1O('-U82!C:&%V92!P<FEV861A*2X@061I8VEO;F%L
M;65N=&4L('-U82!C:&%V92!P^F)L:6-A('!R96-I<V$@97-T87(@9&ES<&]N
M[79E;"!P87)A('%U86QQ=65R('5M('%U92!V;V/J('1E;FAA(&5N=FEA9&\@
M=6UA(&UE;G-A9V5M(&%S<VEN861A(&1I9VET86QM96YT92`M(&$@8VAA=F4@
M</IB;&EC82#I(&YE8V5S<^%R:6$@<&%R82!V97)I9FEC87(@82!A<W-I;F%T
M=7)A(&1I9VET86PN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3=6$@0VAA
M=F4@4')I=F%D83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4W5A(&-H879E
M('!R:79A9&$@Z2!N96-E<W/A<FEA('!A<F$@9&5S8W)I<'1O9W)A9F%R('5M
M82!M96YS86=E;2!C<FEP=&]G<F%F861A('5T:6QI>F%N9&\@<W5A(&-H879E
M('#Z8FQI8V$N($%D:6-I;VYA;&UE;G1E+"!S=6$@8VAA=F4@<')I=F%D82#I
M(&YE8V5S<^%R:6$@<V4@=F]CZB!D97-E:F$@87-S:6YA<B!D:6=I=&%L;65N
M=&4@=6UA(&UE;G-A9V5M+B!3=6$@8VAA=F4@<')I=F%D82!S97+A('!R;W1E
M9VED82!P;W(@=6UA('-E;FAA(&-R:6%D82!Q=6%N9&\@82!C:&%V92!F;VD@
M9V5R861A+B!!<W-I;2P@<&%R82!E>&5C=71A<B!Q=6%L<75E<B!A=&EV:61A
M9&4@<75E(')E<75E:7)A('-U82!C:&%V92!P<FEV861A+"!O($E-4"!L:&4@
M<V]L:6-I=&%RX2!S=6$@<V5N:&$N(%9O8^H@;F5C97-S:71A(&EN<V5R:7(@
M<W5A('-E;FAA('-O;65N=&4@=6UA('9E>B!P;W(@<V5S<^-O("T@;R!)35`@
M87)M87IE;F%RX2!S=6$@<V5N:&$@873I('9O8^H@9&5S8V]N96-T87(@*$-E
M<G1I9FEQ=64M<V4@9&4@9&5S8V]N96-T87(A*2X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP=6)L:6,B('-T
M871E/2)U<'1O9&%T92(@;60U/2(S8S@T-&0T9F8X9F1D83-E,&0T-#9B-#=A
M-C,Q,3=E,"(^"B`@("`\=&ET;&4^4$=0.B!'97)E;F-I86YD;R!#:&%V97,@
M4')I=F%D87,@+2!#:&%V97,@4/IB;&EC87,\+W1I=&QE/@H@("`@/&AE861I
M;F<^5F5R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!8G)E('5M82!J86YE
M;&$@<&%R82!E>&EB:7(@82!C:&%V92!P^F)L:6-A(%!'4"X*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/D1E=&%L:&5S/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%>&EB92!A;&=U;G,@9&5T86QH97,@<V]B<F4@<W5A(&-H879E('#Z
M8FQI8V$@4$=0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<&=P+7!E<G-O;F%L:V5Y+7!R:79A=&4B('-T871E/2)U<'1O9&%T92(@;60U
M/2(Q.#4Q8C8W83%A965F,3(T,F9C,V$R8CDT868W-6,P,R(^"B`@("`\=&ET
M;&4^4$=0.B!'97)E;F-I86YD;R!#:&%V97,@4&5S<V]A:7,@+2!#:&%V97,@
M4')I=F%D87,\+W1I=&QE/@H@("`@/&AE861I;F<^1F]R;F7G82!A(%-E;FAA
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!8G)E('5M82!J86YE;&$@9&4@
M9&GA;&]G;R!P87)A(&$@<V5N:&$N($$@<V5N:&$@9F]R;F5C:61A+"!S92!C
M;W)R971A+"!S97+A(&%R;6%Z96YA9&$@<&5L;R!)35`@873I('-U82!S97-S
MXV\@9FEN86QI>F%R+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5S8V%R
M<F5G87(@4V5N:&$\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%)E;6]V92!A
M('-E;FAA(&%R;6%Z96YA9&$@;F\@24U0("T@<75A;'%U97(@=7-O('!O<W1E
M<FEO<B!D92!S=6$@8VAA=F4@<')I=F%D82!N96-E<W-I=&%RX2!Q=64@=F]C
MZB!F;W)N9>=A(&YO=F%M96YT92!A('-E;FAA+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^5F5R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!8G)E('5M
M82!J86YE;&$@<&%R82!E>&EB:7(@82!C:&%V92!P<FEV861A(%!'4"X@3L-/
M($5.5DE%($535$$@0TA!5D4@02!.24Y'5<E-("T@97-T82!O<.?C;R#I(&5S
M=')I=&%M96YT92!P87)A('!E<FUI=&ER('%U92!V;V/J('!O<W-A(&5X<&]R
M=&%R('-U82!C:&%V92!P<FEV861A('!A<F$@=7-A<B!E;2!O=71R;R!P<F]G
M<F%M82X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%L:&5S/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!%>&EB92!A;&=U;G,@9&5T86QH97,@<V]B
M<F4@82!C:&%V92!P<FEV861A(%!'4"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UD96QE=&4B('-T871E/2)U
M<'1O9&%T92(@;60U/2)D8F0X8V)E-F)C93<Q8S1F8C4Y,F1D,6(S8C(W8C=C
M92(^"B`@("`\=&ET;&4^4$=0.B!'97)E;F-I86YD;R!#:&%V97,@4&5S<V]A
M:7,@+2!%>&-L=6ER/"]T:71L93X*("`@(#QH96%D:6YG/D5X8VQU:7(@0VAA
M=F5S($%T=6%I<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17-T92!B;W3C
M;R!E>&-L=6ERX2!S974@<&%R('!E<W-O86P@9&4@8VAA=F5S('#Z8FQI8V$O
M<')I=F%D82!D87,@<')E9F5RZFYC:6%S(&1O($E-4"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M
M;F%M92(@<W1A=&4](G5P=&]D871E(B!M9#4](C<T.&-B,3(T8C=F9C4R.#(P
M-SDR93(W.#`S-V$X8S(W(CX*("`@(#QT:71L93Y01U`Z($-R:6%R($-H879E
M(%!E<W-O86P@+2!.;VUE/"]T:71L93X*("`@(#QH96%D:6YG/DYO;64\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($\@;F]M92!Q=64@=F]CZB!Q=65R(&%S
M<V]C:6%R(.!S('-U87,@8VAA=F5S('!E<W-O86ES+B!#86UP;R!O8G)I9V%T
M\W)I;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP
M97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N="(@<W1A=&4](G5P=&]D871E(B!M
M9#4](F4V-C9E8CEF,&5E-&(T.69E,#1F-S1F8S$X9&(X-C0P(CX*("`@(#QT
M:71L93Y01U`Z($-R:6%R($-H879E(%!E<W-O86P@+2!#;VUE;G3A<FEO/"]T
M:71L93X*("`@(#QH96%D:6YG/D-O;65N=.%R:6\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%5M(&-O;65N=.%R:6\@82!S97(@87-S;V-I861O(.!S('-U
M87,@8VAA=F5S('!R:79A9&%S+B!#86UP;R!O<&-I;VYA;"X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A
M=&4M96UA:6PB('-T871E/2)U<'1O9&%T92(@;60U/2)C-S(Y9C<P9F1B,V$W
M,V-B8C=B835E9C4X.#AE,S`Y,B(^"B`@("`\=&ET;&4^4$=0.B!#<FEA<B!#
M:&%V92!097-S;V%L("T@16YD97)EYV\@9&4@12UM86EL/"]T:71L93X*("`@
M(#QH96%D:6YG/D5N9&5R9>=O(&1E($4M;6%I;#PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@3R!E;F1E<F7G;R!D92!E+6UA:6P@<75E('9O8^H@<75E<B!A
M<W-O8VEA<B!A('-U87,@8VAA=F5S('!E<W-O86ES+B!#86UP;R!O8G)I9V%T
M\W)I;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP
M97)S;VYA;&ME>2UC<F5A=&4M:V5Y;&5N9W1H(B!S=&%T93TB8VAA;F=E9"(@
M;60U/2(U-#9A,#@W-C4P8V%D83)D,60T83`Q8C0W.#,Q,6)B.2(^"B`@("`\
M=&ET;&4^4$=0.B!#<FEA<B!#:&%V92!097-S;V%L("T@5&%M86YH;R!D82!#
M:&%V93PO=&ET;&4^"B`@("`\:&5A9&EN9SY486UA;FAO(&1A($-H879E/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!/('1A;6%N:&\@9&$@8VAA=F4L(&5M
M(&)Y=&5S+"!D92!S=6$@8VAA=F4@9V5R861A+B!1=6%N=&\@;6%I;W(@;R!V
M86QO<BP@;6%I;W(@82!P<F]T9>?C;R`H92!T86UBZ6T@;6%I;W(@;R!T96UP
M;R!D92!G97)AY^-O(&4@8W)I<'1O9W)A9FEA*2X@,3`R-"!B>71E<R#I(&\@
M<&%D<N-O("T@97-T92!V86QO<B!O9F5R96-E('5M82!E>&-E;&5N=&4@<')O
M=&7GXV\N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"(^"B`@("`\
M=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@2V5Y;&5N9W1H/"]T
M:71L93X*("`@(#QH96%D:6YG/DME>6QE;F=T:#PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&AE(&ME>6QE;F=T:"P@:6X@8FET+"!O9B!Y;W5R(&=E;F5R
M871E9"!K97DN(%1H92!G<F5A=&5R('1H92!V86QU92P@=&AE(&=R96%T97(@
M=&AE('!R;W1E8W1I;VX@*&%N9"!A;'-O(&=R96%T97(@9V5N97)A=&EO;B!T
M:6UE(&%N9"!E;F-R>7!T:6]N('1I;64I+B`Q,#(T(&)I="!I<R!T:&4@9&5F
M875L="`M('1H:7,@=F%L=64@<')O=FED97,@97AC96QL96YT('!R;W1E8W1I
M;VXN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"$M+2!%;F=L:7-H(&5N=')Y
M.@H\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M:V5Y;&5N9W1H
M(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!+97EL
M96YG=&@\+W1I=&QE/@H@("`@/&AE861I;F<^2V5Y;&5N9W1H/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&4@:V5Y;&5N9W1H+"!I;B!B:70L(&]F('EO
M=7(@9V5N97)A=&5D(&ME>2X@5&AE(&=R96%T97(@=&AE('9A;'5E+"!T:&4@
M9W)E871E<B!T:&4@<')O=&5C=&EO;B`H86YD(&%L<V\@9W)E871E<B!G96YE
M<F%T:6]N('1I;64@86YD(&5N8W)Y<'1I;VX@=&EM92DN(#$P,C0@8FET(&ES
M('1H92!D969A=6QT("T@=&AI<R!V86QU92!P<F]V:61E<R!E>&-E;&QE;G0@
M<')O=&5C=&EO;BX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\(2TM($5N9VQI
M<V@@96YT<GDZ"CQE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UK
M97EL96YG=&@B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME
M>2`M($ME>6QE;F=T:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY+97EL96YG=&@\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H92!K97EL96YG=&@L(&EN(&)I
M="P@;V8@>6]U<B!G96YE<F%T960@:V5Y+B!4:&4@9W)E871E<B!T:&4@=F%L
M=64L('1H92!G<F5A=&5R('1H92!P<F]T96-T:6]N("AA;F0@86QS;R!G<F5A
M=&5R(&=E;F5R871I;VX@=&EM92!A;F0@96YC<GEP=&EO;B!T:6UE*2X@,3`R
M-"!B:70@:7,@=&AE(&1E9F%U;'0@+2!T:&ES('9A;'5E('!R;W9I9&5S(&5X
M8V5L;&5N="!P<F]T96-T:6]N+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM
M8W)E871E+6ME>6QE;F=T:"(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R
M<V]N86P@2V5Y("T@2V5Y;&5N9W1H/"]T:71L93X*("`@(#QH96%D:6YG/DME
M>6QE;F=T:#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&ME>6QE;F=T
M:"P@:6X@8FET+"!O9B!Y;W5R(&=E;F5R871E9"!K97DN(%1H92!G<F5A=&5R
M('1H92!V86QU92P@=&AE(&=R96%T97(@=&AE('!R;W1E8W1I;VX@*&%N9"!A
M;'-O(&=R96%T97(@9V5N97)A=&EO;B!T:6UE(&%N9"!E;F-R>7!T:6]N('1I
M;64I+B`Q,#(T(&)I="!I<R!T:&4@9&5F875L="`M('1H:7,@=F%L=64@<')O
M=FED97,@97AC96QL96YT('!R;W1E8W1I;VXN"B`@("`\+W!A<F$^"CPO96YT
M<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC
M<F5A=&4M<&%S<W!H<F%S92(@<W1A=&4](G5P=&]D871E(B!M9#4](C)F8CDS
M-S(Y-S!B9C,S9C4Q93DX.&)A,SED8F0W,3DS(CX*("`@(#QT:71L93Y01U`Z
M($-R:6%R($-H879E(%!E<W-O86P@+2!396YH83PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY316YH83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@02!S96YH82!U
M<V%D82!P87)A('!R;W1E9V5R+V-R:7!T;V=R869A<B!S=6$@8VAA=F4@<&5S
M<V]A;"!P<FEV861A+B!%;&$@9&5V92!C;VYT97(@4$5,3R!-14Y/4R`V(&-A
M<F%C=&5R97,L($[#3R!D979E('-E<B!I9W5A;"!A('-E;FAA(&1E(&QO9VEN
M+"!.PT\@9&5V90H@("`@<V5R(&)A<V5A9&$@96T@=6UA('!A;&%V<F$@9&\@
M9&EC:6]NX7)I;R!E(&1E=F4@:6YC;'5I<B!A;6)O<R!N^FUE<F]S(&4@;&5T
M<F%S+B!6;V/J(&1E=F4@9F]R;F5C97(@97-T82!S96YH82!D=6%S('9E>F5S
M('!A<F$@<')O</-S:71O<R!D92!V97)I9FEC8>?C;RX@0V%M<&\@;V)R:6=A
M=/-R:6\N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M
M<&5R<V]N86QK97DM8W)E871E+6%C=&EO;G,B('-T871E/2)U<'1O9&%T92(@
M;60U/2(P9C@R,S0Y,S5B.38T8S@S-3,S8C1E8S1C,35E8C<Q,B(^"B`@("`\
M=&ET;&4^4$=0.B!#<FEA<B!#:&%V92!097-S;V%L("T@0>?U97,\+W1I=&QE
M/@H@("`@/&AE861I;F<^0W)I87(@0VAA=F4\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($-R:6$@92!A<FUA>F5N82!S974@<&%R('!E<W-O86P@9&4@8VAA
M=F5S('#Z8FQI8V$O<')I=F%D82X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/DEM<&]R=&%R($-H879E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!);7!O
M<G1A('5M('!A<B!D92!C:&%V97,@</IB;&EC82]P<FEV861A+B!%<W1E(&)O
M=.-O(&%B<F4@=6UA(&IA;F5L82!O;F1E('9O8^H@<&]D92!M86YU86QM96YT
M92!I;7!O<G1A<B!S974@<&%R(&5X:7-T96YT92!D92!C:&%V97,@</IB;&EC
M82]P<FEV861A+B!!<R!C:&%V97,@<&]D96T@<V5R(&-O;&%D87,@;F\@8V%M
M<&\@=&5X=&\@;W4L('-E(&$@8VAA=F4@97-T:79E<B!E;2!U;2!A<G%U:79O
M(&5M('-E=2!C;VUP=71A9&]R+"!V;V/J('!O9&4@:6UP;W)TX2UL;RX@4V4@
M87,@8VAA=F5S(&9O<F5M(';A;&ED87,@96QA<R!S97+C;R!I;G-E<FED87,@
M96T@<W5A<R!P<F5F97+J;F-I87,@92!A(&IA;F5L82!F96-H87+A.R!S92!N
MXV\@9F]R96T@=N%L:61A<RP@=6UA(&UE;G-A9V5M(&1E(&5R<F\@<V5RX2!R
M971O<FYA9&$@97AP;&EC86YD;R!O('!O<G%UZBX*("`@(#PO<&%R83X*/"$M
M+3QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UA8W1I;VYS(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+
M97D@+2!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D-R96%T92!+97ES
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#<F5A=&4@86YD('-T;W)E('EO
M=7(@<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<BX*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/DEM<&]R="!+97EP86ER/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!);7!O<G0@82!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N
M(%1H:7,@8G5T=&]N(&]P96YS(&$@=VEN9&]W('=H97)E('EO=2!C86X@;6%N
M=6%L;'D@:6UP;W)T('EO=7(@97AI<W1I;F<@4$=0('!E<G-O;F%L('!U8FQI
M8R]P<FEV871E(&ME>7!A:7(N(%1H92!K97ES(&-A;B!E:71H97(@8F4@<&%S
M=&5D(&EN=&\@82!T97AT9FEE;&0@;W(L(&EF('1H92!K97ES(')E<VED92!I
M;B!A(&9I;&4@;VX@>6]U<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O
M<G0@=&AE;2X@268@=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I
M;G-E<G1E9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@
M=VEL;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I
M;&P@8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W
M(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB9#-C-S4R8C$S-#5F8C)E8V-F934W
M-6,P-S0V,3DV,V8B/@H@("`@/'1I=&QE/E,O34E-13H@5FESXV\@1V5R86P\
M+W1I=&QE/@H@("`@/&AE861I;F<^3R!Q=64@Z2!3+TU)344_/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!3+TU)344@Z2!U;2!S:7-T96UA(&1E(&-H879E
M<R!P<FEV861A+W#Z8FQI8V$@<75E(&]F97)E8V4@87-S:6YA='5R87,@9&EG
M:71A:7,L('!R:79A8VED861E(&5M(&UE;G-A9V5N<RP@92!D971E8^?C;R!D
M92!A;'1E<F'G]65S(&[C;R!A=71O<FEZ861A<R!D92!F;W)M82!A8F5R=&$@
M92!I;G1E<F]P97+A=F5L+B!3+TU)344@<&]D92!O9F5R96-E<B!P<FEV86-I
M9&%D92!D92!M96YS86=E;G,@8W)I<'1O9W)A9F%N9&\M87,@9&4@9F]R;6$@
M<75E('-O;65N=&4@;R!R96UE=&5N=&4@92!O<R!D97-T:6YA=.%R:6]S(&QE
M9^UT:6UO<R!P;W-S86T@9&5C;V1I9FECX2UL87,N($5L92!P97)M:71E('9O
M8^H@:61E;G1I9FEC87(@;R!R96UE=&5N=&4@9&4@=6UA(&UE;G-A9V5M(&%T
M<F%VZ7,@9&4@<W5A(&%S<VEN871U<F$@9&EG:71A;"X@2G5N=&%S+"!A(&-R
M:7!T;V=R869I82!E(&$@87-S:6YA='5R82!D:6=I=&%L(&%J=61A;2!A(&]F
M97)E8V5R(&1E=&5C8^?C;R!D92!A;'1E<F'G]65S(&[C;R!A=71O<FEZ861A
M<RP@<&5R;6ET:6YD;R!O<R!D97-T:6YA=.%R:6]S(&1E=&5R;6EN87)E;2!S
M92!A(&UE;G-A9V5M(&9O:2!A;'1E<F%D82!A</-S('-E<B!E;G9I861A+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^2&%B:6QI=&%R(%,O34E-13\\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%-E(&5S=&$@;W#GXV\@9F]R('-E;&5C
M:6]N861A+"!V;V/J(&5S=&%RX2!A<'1O(&$@:6UP;W)T87(@<V5U('!A<B!P
M97-S;V%L(&1E(&-H879E<R!3+TU)344L(&QE<B!M96YS86=E;G,@8W)I<'1O
M9W)A9F%D87,L('9E<FEF:6-A<B!M96YS86=E;G,@87-S:6YA9&%S(&1I9VET
M86QM96YT92P@92!C<FEP=&]G<F%F87(O87-S:6YA<B!A<R!M96YS86=E;G,@
M<75E(&5N=FEA<BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G-M:6UE+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB.68T9C,V864W,F-B-&%B8S<S,3`V-V0S,SAB93-B.3@B/@H@("`@
M/'1I=&QE/E,O34E-13H@0VAA=F5S(%!E<W-O86ES/"]T:71L93X*("`@(#QH
M96%D:6YG/E9I<^-O($=E<F%L/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3
M92!V;V/J('%U:7-E<B!A<W-I;F%R(&1I9VET86QM96YT92!O=2!C<FEP=&]G
M<F%F87(@;65N<V%G96YS('9O8^H@9&5V92!P;W-S=6ER('-E=2!P<O-P<FEO
M('!A<B!D92!C:&%V97,@</IB;&EC82]P<FEV861A(%,O34E-12X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6EM<&]R="UP97)S
M;VYA;"UC97)T<R(@<W1A=&4](G5P=&]D871E(B!M9#4](F-F,&5D,F4S93(T
M9#,P9&5D9CAC9F5F,F,R-C0U-S4Y(CX*("`@(#QT:71L93Y3+TU)344Z($EM
M<&]R=&%R($-E<G1I9FEC861O<R!097-S;V%I<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY);7!O<G1A<B!#97)T:69I8V%D;W,@4&5S<V]A:7,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EM<&]R=&$@8V5R=&EF:6-A9&]S('!E<W-O86ES
M(&1E('5M(&%R<75I=F\@96T@9F]R;6%T;R!02T-3(",Q,BX@4$M#4R`C,3(@
MZ2!U;2!A<G%U:79O(&=E<F%L;65N=&4@9V5R861O('%U86YD;R!S92!E>'!O
M<G1A('5M82!C:&%V92!A('!A<G1I<B!D92!U;2!N879E9V%D;W(@*&5X+CH@
M26YT97)N970@17AP;&]R97(L($9I<F5F;W@I(&]U(&$@<&%R=&ER(&1E('5M
M(&-E<G1I9FEC861O(&%R;6%Z96YA9&\@92!M86YT:61O('!E;&\@4VES=&5M
M82!/<&5R86-I;VYA;"`H97@N.B!7:6YD;W=S(%A0*2X@4V4@<W5A<R!C:&%V
M97,@9F]R96T@=N%L:61A<R!E;&%S('-E<N-O(&EN<V5R:61A<R!E;2!S=6%S
M('!R969E<NIN8VEA<R!E(&$@:F%N96QA('-E(&9E8VAA<N$[('-E(&[C;R!F
M;W)E;2!VX6QI9&%S+"!U;6$@;65N<V%G96T@9&4@97)R;R!S97+A(')E=&]R
M;F%D82!E>'!L:6-A;F1O(&\@<&]R<77J+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<VUI;64M9&5L971E+7!E<G-O;F%L+6-E<G1S(B!S
M=&%T93TB=7!T;V1A=&4B(&UD-3TB,#$X8F(V8C8Q83=E-#$V.#DR9&4R.#AA
M9#%C.#@P9C0B/@H@("`@/'1I=&QE/E,O34E-13H@17AC;'5I<B!#97)T:69I
M8V%D;W,@4&5S<V]A:7,\+W1I=&QE/@H@("`@/&AE861I;F<^17AC;'5I<B!#
M97)T:69I8V%D;W,@4&5S<V]A:7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($5X8VQU:2!S975S(&-E<G1I9FEC861O<R!P97-S;V%I<R!D92!S=6%S('!R
M969E<NIN8VEA<RX@5F]CZB!NXV\@<V5RX2!M86ES(&%P=&\@82!A<W-I;F%R
M(&UE;G-A9V5N<R!C;VT@4R]-24U%(&]U('9I<W5A;&EZ87(@<75A;'%U97(@
M;65N<V%G96T@8W)I<'1O9W)A9F%D82!C;VT@4R]-24U%(&5N=FEA9&$@82!V
M;V/J+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M
M;6%N86=E+7!U8FME>2(@<W1A=&4](G5P=&]D871E(B!M9#4](CAB-F,V,S8X
M-&0S9#<S8C-D,#@T,#(U83<X9F4W93@X(CX*("`@(#QT:71L93Y3+TU)344Z
M($=E<F5N8VEA<B!#:&%V97,@4/IB;&EC87,\+W1I=&QE/@H@("`@/&AE861I
M;F<^4R]-24U%.B!'97)E;F-I87(@0VAA=F5S(%#Z8FQI8V%S/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!'97)E;F-I82!S=6$@;&ES=&$@9&4@8VAA=F5S
M('#Z8FQI8V%S(&1O('1I<&\@4R]-24U%+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^5F5R/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:7-U86QI>F$@
M<W5A(&-H879E('#Z8FQI8V$@96T@=&5X=&\@<'5R;RX*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/D1E=&%L:&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!6:7-U86QI>F$@;W,@9&5T86QH97,@=.EC;FEC;W,@9&4@<W5A(&-H879E
M('#Z8FQI8V$N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%>&-L=6ER/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!%>&-L=6D@9&\@<F5P;W-I=/-R:6\@
M82!C:&%V92!P^F)L:6-A('-E;&5C:6]N861A+B!%>&-L=6ER('5M82!C:&%V
M92!P^F)L:6-A('!R979I;FERX2!V;V/J(&1E(&-R:7!T;V=R869A<B!U;6$@
M;65N<V%G96T@<&%R82!O('5S=>%R:6\@96T@<75E<W3C;RX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R:6YT:6YG(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB9C(S,V,Q,6(V8C1A-F)E9&5B-CAF,60U83)A.3<V9&(B
M/@H@("`@/'1I=&QE/DEM<')I;6EN9&\\+W1I=&QE/@H@("`@/&AE861I;F<^
M26UP<FEM:7(@82!-96YS86=E;3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M4&%R82!I;7!R:6UI<B!U;6$@;65N<V%G96T@<75E('9O8^H@97-T:79E<B!V
M:7-U86QI>F%N9&\L(&-L:7%U92!N;R!L:6YK("));7!R:6UI<B(@;F\@=&]P
M;R!O=2!N;R!R;V1A<.D@9&$@;65N<V%G96TN($$@;65N<V%G96T@<V5RX2!A
M8F5R=&$@96T@=6UA(&YO=F$@:F%N96QA(&9O<FUA=&%D82!P87)A(&EM<')E
M<W/C;RX@1&5P96YD96YD;R!D;R!S974@;F%V96=A9&]R(&4@<VES=&5M82!O
M<&5R86-I;VYA;"P@=6UA(&-A:7AA(&1E(&1IX6QO9V\@<V4@86)R:7+A('!A
M<F$@=F]CZBX@4V4@96QA(&[C;R!S92!A8G)I<BP@96YTXV\@<V5L96-I;VYE
M(&\@;65N=2`B07)Q=6EV;R(@9&4@<V5U(&YA=F5G861O<B!E(&5S8V]L:&$@
M(DEM<')I;6ER(B!P87)A(&%B<FER(&$@8V%I>&$@9&4@9&GA;&]G;R!D92!I
M;7!R97-SXV\N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S
M;W)T:6YG(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,3AC9&5A8S,X,#(W9F4U
M8S0R8F%B-CDS9C)A-#(V,&$B/@H@("`@/'1I=&QE/D]R9&5N86YD;R!E($%G
M<G5P86YD;R!P;W(@1&ES8W5S<^-O/"]T:71L93X*("`@(#QH96%D:6YG/D]R
M9&5N87(@4F5G:7-T<F]S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!!;R!V
M:7-U86QI>F%R('5M82!L:7-T82!D92!M96YS86=E;G,L('9O8^H@<&]D92!O
M<F1E;F%R(&%S(&UE;G-A9V5N<R!C;&EC86YD;R!N;R!C86)EYV%L:&\@87!R
M;W!R:6%D;R!D82!C;VQU;F$N(%!A<F$@:6YV97)T97(@87,@8V]L=6YA<R!E
M;G1R92!O<F1E;2!A<V-E;F1E;G1E(&]U(&1E<V-E;F1E;G1E(&-L:7%U92!N
M;R#M8V]N92!E;2!F;W)M82!D92!F;&5C:&$@;F\@8V%B9>=A;&AO(&1A(&-O
M;'5N82X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D%G<G5P87(@<&]R($1I
M<V-U<W/C;SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@06=R=7!A(&UE;G-A
M9V5N<R!P;W(@9&ES8W5S<^-O("AA<W-U;G1O*2P@8V]M(&ES=&\@=&]D87,@
M87,@;65N<V%G96YS('-E<N-O(&%G<G5P861A<R!C;VT@<W5A<R!R97-P;W-T
M87,L(&-L:6-A;F1O(&YO(&QI;FL@6T1I<V-U<W/C;UT@;F\@8V%B9>=A;&AO
M(&1A(&-O;'5N82!A<W-U;G1O+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB86QT97)N871I=F4M;7-G(B!S=&%T93TB=7!T;V1A=&4B(&UD
M-3TB-#DW.#`W,V8W-CDW-V(V868V8C8Y.#$P931D,C)A-C4B/@H@("`@/'1I
M=&QE/DUE;G-A9V5N<R!D;R!T:7!O($UU;'1I<&%R="]!;'1E<FYA=&EV93PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($%L9W5M82!M96YS86=E;2!F;VD@96YV
M:6%D82!C;VUO('-E;F1O(&1O('1I<&\@(FUU;'1I<&%R="]A;'1E<FYA=&EV
M92(N($5S=&%S(&UE;G-A9V5N<R!P;W-S=65M(&1I=F5R<V%S('!A<G1E<RP@
M=&]D87,@;6]S=')A;F1O(&\@345334\@0T].5$7:1$\@;6%S(&5M($1)1D52
M14Y415,@1D]234%43U,N($\@8VQI96YT92!D92!C;W)R96EO(&UO<W1R87+A
M(&$@^FQT:6UA('!A<G1E(&1A(&QI<W1A('%U92!P;W-S82!S97(@=FES=6%L
M:7IA9&$@8V]R<F5T86UE;G1E(&YO(&YA=F5G861O<BP@8V%S;R!H86IA(&%L
M9W5M82X@5&]D;W,@;W,@;W5T<F]S(&9O<FUA=&]S(&%P87)E8V5RXV\@86)A
M:7AO(&1O('3M='5L;R`B4&%R=&5S(&%L=&5R;F%T:79A<R!P87)A(&5S=&$@
M<V7GXV\B(&4@<&]D96T@<V5R('9I<W5A;&EZ861O<R!E(&)A:7AA9&]S('-E
M<&%R861A;65N=&4N(,D@:6UP;W)T86YT92!N;W1A<B!Q=64@97-T87,@<&%R
M=&5S(&%L=&5R;F%T:79A<R!P;W-S=65M(&\@345334\@0T].5$7:1$\@<75E
M(&$@<&%R=&4@<75E(&5S=.$@<V5N9&\@;6]S=')A9&$@+2!E;&5S(&5S=.-O
M('-I;7!L97-M96YT92!E;2!O=71R;W,@9F]R;6%T;W,@*&5X+CH@=&5X=&\@
M=G,N($A434PI+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DB('-T871E/2)U<'1O9&%T
M92(@;60U/2(U,S!F83(P93!A9F)C,C5F9F0T,#@W-SDT.#@S,C@Y.2(^"B`@
M("`\=&ET;&4^4')E9F5RZFYC:6%S.B!-86YU=&5NY^-O.B!296YO;65A<B`B
M16YV:6%D;W,B(&UE;G-A;&UE;G1E/"]T:71L93X*("`@(#QP87)A/@H@("`@
M071I=F4@97-T82!O<.?C;R!S92!V;V/J(&=O<W1A<FEA(&1E(')E;F]M96%R
M('-U82!P87-T82`B16YV:6%D;W,B(&%O(&EN[6-I;R!D92!C861A(&WJ<RX@
M02!P87-T82!S97+A(')E;F]M96%D82`H<&%R82!U;2!N;VUE('%U92!C;VYT
M96YH82!MZG,@92!A;F\I(&4@=6UA(&YO=F$@<&%S=&$@(D5N=FEA9&]S(B!S
M97+A(&-R:6%D82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY(B!S=&%T93TB=7!T;V1A
M=&4B(&UD-3TB,&)E960Q-F1F9#8X93)F,C5E,&,V-C@W,69D-30V9&8B/@H@
M("`@/'1I=&QE/E!R969E<NIN8VEA<SH@36%N=71E;N?C;SH@17AC;'5I<B!M
M96YS86QM96YT92!P87-T87,@(D5N=FEA9&]S(B!A;G1I9V%S/"]T:71L93X*
M("`@(#QP87)A/@H@("`@071I=F4@97-T82!O<.?C;R!Q=64@<V4@=F]CZB!G
M;W-T87)I82!D92!E>&-L=6ER('!A<W1A<R`B16YV:6%D;W,B(&%N=&EG87,@
M86\@:6[M8VEO(&1E(&-A9&$@;>IS+B!)<W1O('!O9&4@<V5R(/IT:6P@<V4@
M=F]CZB!P;W-S=6D@<75O=&$L('!O<B!E>&5M<&QO+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7W-E;G1M86EL7VUO
M;G1H;'E?:V5E<"(@<W1A=&4](G5P=&]D871E(B!M9#4](C<Q960Q8S)E86(T
M.&(Y,6$R-6(U8F-D-&(Q-&-C96$Y(CX*("`@(#QT:71L93Y0<F5F97+J;F-I
M87,Z($UA;G5T96[GXV\Z($5X8VQU:7(@4&%S=&$@(D5N=FEA9&]S(B!-96YS
M86QM96YT92`M($[Z;65R;R!D92!087-T87,@82!-86YT97(\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!392!V;V/J(&5S=&EV97(@97AC;'5I;F1O('!A<W1A
M<R`B16YV:6%D;W,B('1O9&\@;>IS+"!Q=6%N=&]S(&UE<V5S(&1E('!A<W1A
M<R!A;G1I9V%S('9O8^H@9V]S=&%R:6$@9&4@;6%N=&5R/R!1=6%L<75E<B!P
M87-T82!M86ES(&%N=&EG82!Q=64@;R!N^FUE<F\@9&4@;65S97,@97-P96-I
M9FEC861O<R!S97+A(&5X8VQU[61A+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DB
M('-T871E/2)U<'1O9&%T92(@;60U/2(S-S-E83`R961E-F1F-69C,S0U8V%F
M-C,R93$Y83<U9B(^"B`@("`\=&ET;&4^4')E9F5RZFYC:6%S.B!-86YU=&5N
MY^-O.B!%>&-L=6ER($UE;G-A;&UE;G1E($%N97AO<R!,:6=A9&]S/"]T:71L
M93X*("`@(#QP87)A/@H@("`@071I=F4@97-T82!O<.?C;R!S92!V;V/J(&=O
M<W1A<FEA(&1E(&5X8VQU:7(@86YT:6=O<R!A;F5X;W,@;&EG861O<R!A;R!I
M;NUC:6\@9&4@8V%D82!MZG,N($ES=&\@<&]D92!S97(@^G1I;"!S92!V;V/J
M('!O<W-U:2!Q=6]T82P@<&]R(&5X96UP;&\N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N
M=&AL>5]K965P(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,6(S-#!A-C`R,31D
M9F9D,#1A96,P,F-C,3$R-V1F-60B/@H@("`@/'1I=&QE/E!R969E<NIN8VEA
M<SH@36%N=71E;N?C;SH@17AC;'5I<B!-96YS86QM96YT92!!;F5X;W,@3&EG
M861O<R`M($[Z;65R;R!D92!-97-E<R!A($UA;G1E<CPO=&ET;&4^"B`@("`\
M<&%R83X*("`@(%-E('9O8^H@97-TX2!E>&-L=6EN9&\@86YT:6=O<R!A;F5X
M;W,@;&EG861O('1O9&\@;>IS+"!Q=6%N=&]S(&UE<V5S(&1E(&1E(&%N=&EG
M;W,@86YE>&]S('9O8^H@9V]S=&%R:6$@9&4@;6%N=&5R/R!1=6%L<75E<B!A
M;F5X;R!M86ES(&%N=&EG;R!Q=64@;R!N^FUE<F\@9&4@;65S97,@97-P96-I
M9FEC861O<R!S97+A(&5X8VQU[61O+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<V@B('-T871E/2)U<'1O9&%T
M92(@;60U/2)D8S<Q.#<Q,30V8F4S930V861E,#`X-V$X8V8Q.#(W,R(^"B`@
M("`\=&ET;&4^4')E9F5RZFYC:6%S.B!-86YU=&5NY^-O.B!%<W9A>FEA<B!,
M:7AE:7)A/"]T:71L93X*("`@(#QP87)A/@H@("`@5F]CZB!G;W-T87)I82!D
M92!E<W9A>FEA<B!S=6$@<&%S=&$@3&EX96ER82!F<F5Q_&5N=&5M96YT93\*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E
M7W1R87-H7VEN=&5R=F%L(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-V)E.3%F
M8F5B,#5B,F0X-S(X.60T8S4V,#)D-6$S,F8B/@H@("`@/'1I=&QE/E!R969E
M<NIN8VEA<SH@36%N=71E;N?C;SH@1G)E<?SJ;F-I82!P87)A($5S=F%Z:6%R
M($QI>&5I<F$\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!392!V;V/J(&5S=.$@
M97-V87II86YD;R!S=6$@<&%S=&$@3&EX96ER82P@96T@<75E(&9R97'\ZFYC
M:6$@96QA(&1E=F5R:6$@<V5R(&5S=F%Z:6%D83\*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H7VME97`B('-T
M871E/2)U<'1O9&%T92(@;60U/2(S8V(U83)B-6(X,&(W86,Q,3<Y864P,#5F
M.3@S.3<P92(^"B`@("`\=&ET;&4^4')E9F5RZFYC:6%S.B!-86YU=&5NY^-O
M.B!-96YS86=E;G,@36%N=&ED87,@86\@17-V87II87(@3&EX96ER83PO=&ET
M;&4^"B`@("`\<&%R83X*("`@(%-E('9O8^H@97-TX2!E<W9A>FEA;F1O('-U
M82!P87-T82!,:7AE:7)A+"!M96YS86=E;G,@;6%I<R!V96QH87,@<75E('%U
M86YT;W,@9&EA<R!D979E<N-O('-E<B!A<&%G861A<S\*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6%T=')I8E]T97AT(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB-S(Q83`Y9#=C83`R.&,Y-V4S8F0R8C,X8S4Y
M-V9F9C<B/@H@("`@(#QT:71L93Y0<F5F97+J;F-I87,Z($-O;7!O<VGGXV\@
M9&4@365N<V%G96TZ(%1E>'1O(&1E($%T<FEB=6GGXV\\+W1I=&QE/@H@("`@
M(#QP87)A/@H@("`@($%Q=6D@=F]CZB!P;V1E(&9O<FYE8V5R(&$@9G)A<V4@
M<75E('9O8^H@9&5S96IA('%U92!A<&%R9>=A(&%N=&5S(&1E('%U86QQ=65R
M(&-I=&'GXV\@9&4@=&5X=&\@96T@=6UA(')E<W!O<W1A('%U92!V;V/J(&5N
M=FEO=2X*("`@("`\+W!A<F$^"B`@("`@/'!A<F$^"B`@("`@5F]CZB!P;V1E
M(&EN8VQU:7(@=6UA(&]U(&UA:7,@=F%R:>%V96ES('!A<F$@:6YS97)I<B!I
M;F9O<FUAY_5E<R!S;V)R92!A(&UE;G-A9V5M('%U92!V;V/J(&5S=.$@<F5S
M<&]N9&5N9&\N(%9A<FGA=F5I<R!C;VYS:7-T96T@96T@=6T@<VEN86P@)R4G
M('-E9W5I9&\@9&4@=6UA(&QE=')A+B!!<R!S96=U:6YT97,@=F%R:>%V96ES
M(&5S=.-O(&1I<W!O;NUV96ES.@H@("`@(#PO<&%R83X*"B`@("`@/'!A<F$^
M("5F(#H@3R!N;VUE(&1O(')E;65T96YT92!E(&5N9&5R9>=O(&1E(&4M;6%I
M;#PO<&%R83X*("`@("`\<&%R83X@)6$@.B!/(&5N9&5R9>=O(&1E(&4M;6%I
M;"!D;R!R96UE=&5N=&4\+W!A<F$^"B`@("`@/'!A<F$^("5P(#H@3R!N;VUE
M(&1O(')E;65T96YT93PO<&%R83X*("`@("`\<&%R83X@)7(@.B!!(&1A=&$@
M92!F=7-O(&AO<N%R:6\@96T@9F]R;6%T;R!C;VYC;W)D86YT92!A(%)&0R`R
M.#(R/"]P87)A/@H@("`@(#QP87)A/B`E9"`Z($$@9&%T82!E;2!F;W)M871O
M('-S<RP@9&0@;6UM(%E965D\+W!A<F$^"B`@("`@/'!A<F$^("5X(#H@02!D
M871A(&YO('!A9'+C;R!L;V-A;#PO<&%R83X*("`@("`\<&%R83X@)6,@.B!!
M(&1A=&$@92!H;W)A(&YO('!A9'+C;R!L;V-A;#PO<&%R83X*("`@("`\<&%R
M83X@)6T@.B!!(&ED96YT:69I8V'GXV\@9&$@;65N<V%G96X@*$UE<W-A9V4M
M240I/"]P87)A/@H@("`@(#QP87)A/B`E<R`Z($\@=.UT=6QO/"]P87)A/@H@
M("`@(#QP87)A/B`E;B`Z(%5M82!N;W9A(&QI;FAA/"]P87)A/@H@("`@(#QP
M87)A/B`E)2`Z($\@<VEN86P@)R4G/"]P87)A/@H*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?<F5A9"(@<W1A=&4]
M(G5P=&]D871E(B!M9#4](C@Y93DR8S1D-C@R,C1B,C,T-6(U.3DU.3@W.&$W
M,3<T(CX*("`@(#QT:71L93Y0<F5F97+J;F-I87,Z(%-O;&EC:71A<B!#;VYF
M:7)M8>?C;R!D92!,96ET=7)A/"]T:71L93X*("`@(#QP87)A/@H@("`@(E-O
M;&EC:71A<B!#;VYF:7)M8>?C;R!D92!,96ET=7)A(B!E;G9I82!U;6$@<V]L
M:6-I=&'GXV\@86]S(&1E<W1I;F%TX7)I;W,@9&5S=&$@;65N<V%G96T@<&%R
M82!N;W1I9FEC87(@=F]CZB!Q=6%N9&\@97-T82!M96YS86=E;2!F;W(@86)E
M<G1A('!O<B!E;&5S+B!.96T@=&]D;W,@;W,@8VQI96YT97,@9&4@8V]R<F5I
M;R!S=7!O<G1A;2]H;VYR86T@:7-T;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W-E;F1?;61N(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB,69E,#1E-61C,V1E-CAD,3<R9&$R.#0X.34Y
M-S-E83DB/@H@("`@/'1I=&QE/E!R969E<NIN8VEA<SH@16YV:6%R($Y$33PO
M=&ET;&4^"B`@("`\<&%R83X*("`@(")%;G9I87(@3D1-(B!E;G9I82!U;6$@
M3F]T:69I8V'GXV\@9&4@1&ES<&]S:>?C;R!D82!-96YS86=E;2`H=&%M8NEM
M(&-O;FAE8VED82!C;VUO($-O;F9I<FUAY^-O(&1E($QE:71U<F$I('%U86YD
M;R!V;V/J('9I<W5A;&EZ87(@=6UA(&UE;G-A9V5M(&YA('%U86P@;R!U<W7A
M<FEO('-O;&EC:71O=2!Q=64@96QE(')E8V5B82!U;6$@;F]T:69I8V'GXV\@
M<75E('9O8^H@;&5U(&$@;65N<V%G96TN($5M(&UU:71O<R!C87-O<RP@:7-T
M;R!A8V]N=&5C97+A(&%U=&]M871I8V%M96YT92!S96T@<&5R9W5N=&%R(&$@
M=F]CZBX@16T@8V5R=&]S(&-A<V]S(&ES;VQA9&]S+"!V;V/J('!O9&4@=&5R
M('%U92!M86YU86QM96YT92!D96-I9&ER(&5M(&5N=FEA<B!A(&YO=&EF:6-A
MY^-O(&%O(&-L:6-A<B!E;2!U;2!L:6YK+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]D96QI
M=F5R>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C(V-3DX93(Y868P-6$P-V1E
M-64Q,S8T-#8V.6)E-S$R(CX*("`@(#QT:71L93Y0<F5F97+J;F-I87,Z(%-O
M;&EC:71A<B!#;VYF:7)M8>?C;R!D92!%;G1R96=A/"]T:71L93X*("`@(#QP
M87)A/@H@("`@(E-O;&EC:71A<B!#;VYF:7)M8>?C;R!D92!%;G1R96=A(B!E
M;G9I82!A;R!S97)V:61O<B!D92!E+6UA:6P@9&\@9&5S=&EN873A<FEO('5M
M82!S;VQI8VET8>?C;R!D92!N;W1I9FEC8>?C;R!Q=6%N9&\@82!M96YS86=E
M;2!F;W(@96YT<F5G=64@;F$@8V%I>&$@<&]S=&%L(&1O(&1E<W1I;F%TX7)I
M;RX@27-T;R!NXV\@<VEG;FEF:6-A('%U92!A(&UE;G-A9V5M(&9O:2!L:61A
M+"!S:6UP;&5S;65N=&4@96QA(&5S=.$@96T@=6UA(&-A:7AA('!O<W1A;"!E
M;2!A;&=U;2!L=6=A<BX@3F5M('1O9&]S(&]S('-E<G9I9&]R97,@9&4@92UM
M86EL('-U<&]R=&%M(&ES=&\N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD96QE=&5?<W!A;5]A9G1E<E]R97!O<G0B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!$96QE=&4@4W!A;2!!
M9G1E<B!297!O<G1I;F<\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y
M(&5L96-T('1O(&1O(&]N92!O9B!T:')E92!I=&5M<R!A9G1E<B!R97!O<G1I
M;F<@82!M97-S86=E(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C96YT+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("!&:7)S="P@>6]U(&-A;B!D96-I9&4@
M=&\@9&\@;F]T:&EN9R`M('1H92!M97-S86=E('=I;&P@8F4@<F5P;W)T960@
M87,@96ET:&5R('-P86T@;W(@:6YN;V-E;G0@8G5T('=I;&P@;W1H97)W:7-E
M(')E;6%I;B!U;F-H86YG960@:6X@>6]U<B!M86EL8F]X+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("!396-O;F0L(&EF(')E<&]R=&EN9R!A(&UE<W-A
M9V4@87,@<W!A;2P@>6]U(&-A;B!I;G-T96%D(&AA=F4@=&AE(&UE<W-A9V4@
M8F4@:6UM961I871E;'D@9&5L971E9"X@(%1H:7,@<V5T=&EN9R!H87,@;F\@
M969F96-T(&]N(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN;V-E;G0N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%1H:7)D+"!A9G1E<B!R97!O<G1I
M;F<@82!M97-S86=E(&%S('-P86T@=&AE(&UE<W-A9V4@=VEL;"!B92!D96QE
M=&5D(&9R;VT@=&AE(&-U<G)E;G0@;6%I;&)O>"!A;F0@;6]V960@=&\@>6]U
M<B!S<&%M(&9O;&1E<BX@($%L=&5R;F%T:79E;'DL(&EF(')E<&]R=&EN9R!A
M(&UE<W-A9V4@87,@:6YN;V-E;G0@=&AE(&UE<W-A9V4@=VEL;"!B92!D96QE
M=&5D(&9R;VT@=&AE(&-U<G)E;G0@;6%I;&)O>"!A;F0@;6]V960@=&\@>6]U
M<B!)3D)/6"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+6AT;6Q?:6UA9V5?<F5P;&%C96UE;G0B('-T871E/2)U<'1O9&%T92(@
M;60U/2(R.&4Q8V8P.&4S,C@S-#5A.&4W,C<T8S@U,S0Y,F0T9B(^"B`@("`\
M=&ET;&4^4')E9F5RZFYC:6%S.B!3=6)S=&ET=6GGXV\@9&4@26UA9V5M($A4
M34P\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!087)A(&UE;G-A9V5N<R!(5$U,
M(&5X:6)I9&%S(&EN8V]R<&]R861A<RP@9&5V97+C;R!T;V1A<R!A<R!I;6%G
M96YS('-E<F5M(&)L;W%U96%D87,@873I('9O8^H@97-P96-I9FEC86UE;G1E
M(&1E8VED:7(@96T@=F5R(&5S=&%S(&EM86=E;G,_($YO=&4@<75E(&%O('9I
M<W5A;&EZ87(@=6T@86YE>&\@2%1-3"P@87,@:6UA9V5N<R!S96UP<F4@<V5R
MXV\@;6]S=')A9&%S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M:'1M;%]I;6%G95]A9&1R8F]O:R(@<W1A=&4](G5P=&]D871E
M(B!M9#4](C<U.69A,V1F,C1E,&$S8V0X.68S,C`Q,#(R-3)F.3%A(CX*("`@
M(#QT:71L93Y0<F5F97+J;F-I87,Z(%-U8G-T:71U:>?C;R!D92!);6%G96T@
M2%1-3"]%>&EB:7(@0V%TX6QO9V\@9&4@16YD97)EYV]S/"]T:71L93X*("`@
M(#QP87)A/@H@("`@06\@8FQO<75E87(@:6UA9V5N<R!(5$U,+"!D979E<NUA
M;6]S(&UO<W1RX2UL87,@875T;VUA=&EC86UE;G1E('-E(&\@<F5M971E;G1E
M(&5S=&EV97(@96T@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<S\*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A
M<G0B('-T871E/2)U<'1O9&%T92(@;60U/2(S9#$Q.39F,C8U9#AB-V-C-#8U
M96)F,C$U,3)A8V,P-2(^"B`@("`\=&ET;&4^4')E9F5RZFYC:6%S.B!0X6=I
M;F$@26YI8VEA;"!D82!#86EX82!0;W-T86P\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!$971E<FUI;F$@<75A;"!PX6=I;F$@;F$@8V%I>&$@<&]S=&%L('-E
M<N$@;6]S=')A9&$@<75A;F1O('9O8^H@86-E<W-A<B!A(&-A:7AA('!O<W1A
M;"!P96QA('!R:6UE:7)A('9E>BX@3F]T92!Q=64@87,@;W#G]65S(&1E(&UE
M;G-A9V5N<R`B3N-O($QI9&%S(B!NXV\@9G5N8VEO;F%RXV\@8V]M(&$@;W#G
MXV\@9&4@;W)D96YA<B!P;W(@(D1I<V-U<W/C;R(@+2!A;R!I;G;I<R!D:7-T
M;RP@=F]CZB!S97+A(&5N=FEA9&\@<&%R82!A(/IL=&EM82!PX6=I;F$@=FES
M=&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS
M879E7V%T=&%C:&UE;G1S(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,S5B-#8S
M,S1C9&-C-V9A-#$V8CEF.69C834X-S1E.#`B/@H@("`@/'1I=&QE/E!R969E
M<NIN8VEA<SH@4V%L=F%R(&%N97AO<R!N87,@365N<V%G96YS($5N=FEA9&%S
M/"]T:71L93X*("`@(#QP87)A/@H@("`@06\@<V%L=F%R(&UE;G-A9V5M(&YA
M('!A<W1A(")%;G9I861O<R(L(&1E=&5R;6EN82!S92!T;V1O<R!O<R!D861O
M<R!S97+C;R!S86QV;W,N($%S('-E9W5I;G1E<R!O<.?U97,@97-TXV\@9&ES
M<&]N[79E:7,Z"B`@("`\+W!A<F$^"@H@("`@/'!A<F$^*B`B4V5M<')E('-A
M;'9A<B!A;F5X;W,B("T@3E5.0T$@<&5R9W5N=&%R('!A<F$@<V%L=F%R(&%N
M97AO<R!N82!T96QA(&1E(&-O;7!O<VGGXV\[(&]S(&%N97AO<R!S97+C;R!3
M14U04D4@<V%L=F]S(&-O;2!A(&UE;G-A9V5M+CPO<&%R83X*("`@("`\<&%R
M83XJ(")097)G=6YT87(@<V5M<')E('%U92!U;2!A;F5X;R!F;W(@96YV:6%D
M;SL@<&%D<N-O(%-)32(@+2!314U04D4@<&5R9W5N=&$@<V4@<V%L=F%RX2!A
M;F5X;W,@;F$@:F%N96QA(&1E(&-O;7!O<VGGXV\[(&\@<&%D<N-O(.D@<V%L
M=F%R(&]S(&%N97AO<RX\+W!A<F$^"B`@("`@/'!A<F$^*B`B4&5R9W5N=&%R
M('-E;7!R92!Q=64@=6T@86YE>&\@9F]R(&5N=FEA9&\[('!A9'+C;R!.PT\B
M("T@4T5-4%)%('!E<F=U;G1A('-E('-A;'9A<N$@86YE>&]S(&YA(&IA;F5L
M82!D92!C;VUP;W-IY^-O.R!O('!A9'+C;R#I(&[C;R!S86QV87(@;W,@86YE
M>&]S+CPO<&%R83X*("`@("`\<&%R83XJ(").=6YC82!S86QV87(@86YE>&]S
M(B`M($Y53D-!('!E<F=U;G1A<BP@;F$@=&5L82!D92!C;VUP;W-IY^-O(&1E
M(&UE;G-A9V5M+"!S92!S86QV87+A(&%N97AO<SL@;W,@86YE>&]S($Y53D-!
M('/C;R!S86QV;W,@8V]M(&$@;65N<V%G96TN/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB=FER='5A;%]I;F)O>"(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L($EN8F]X/"]T:71L93X*
M("`@(#QP87)A/@H@("`@5FER=71A;"!);F)O>"!I<R!A('-A=F5D('-E87)C
M:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D('1O('-E87)C:"!E=F5R
M>2!M86EL8F]X(&9O<B!M97-S86=E<R!M87)K960@87,@;F5W+B`@26YS=&5A
M9"P@86QL(&-U<G)E;G1L>2!S=6)S8W)I8F5D(&UA:6QB;WAE<R!A<F4@<V5A
M<F-H960@9F]R(&YE=R!M97-S86=E<R!A;F0@=&AE(')E<W5L=',@87)E(&1I
M<W!L87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T<F%S:"(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L(%1R87-H/"]T
M:71L93X*("`@(#QP87)A/@H@("`@5FER='5A;"!4<F%S:"!I<R!A('-A=F5D
M('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D(&9O<B!A('-E
M<&%R871E(%1R87-H(&9O;&1E<BX@($EN<W1E860@;V8@;6]V:6YG(&UE<W-A
M9V5S('1O(&$@8V5N=')A;&EZ960@=')A<V@@9F]L9&5R+"!M97-S86=E<R!A
M<F4@<VEM<&QY(&UA<FME9"!A<R!D96QE=&5D(&EN('1H92!C=7)R96YT(&9O
M;&1E<B!T:&5Y(&QI=F4@:6XN("!7:&5N("=S:&]W(&1E;&5T960@;65S<V%G
M97,G(&ES('1U<FYE9"!O9F8L('1H:7,@<F5S=6QT<R!I;B!T:&5S92!M97-S
M86=E<R!N;W0@87!P96%R:6YG(&EN(&$@;6%I;&)O>"!V:65W+B`@5VAE;B!A
M('5S97(@8VQI8VMS(&]N(%9I<G1U86P@5')A<V@L("IA;&PJ(&UA:6QB;WAE
M<R!A;&P@<V5A<F-H960@9F]R(&UE<W-A9V5S('1H870@87)E(&9L86=G960@
M9&5L971E9"!A;F0@=&AE<V4@;65S<V%G97,@87)E(&1I<W!L87EE9"!I;B!A
M('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O<'1?4%0O````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-C,`,#$W-#<W`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L
M92]P=%]05"],0U]-15-304=%4R\`````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,C$R-C0`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O;&]C86QE+W!T7U!4+TQ#7TU%4U-!1T53+VEM<"YM;P``
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S`Q-C(R`#$P-#$W,S8R-S8S`#`R,C0Q
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````#\+```<````%%H```</```,M````````"CP```*````*?````H`
M```T\```"@```#_P``!-````2O```+\```"8\```9````%CQ``"^````O?$`
M`)````!\\@``0P````WS```\````4?,``"L```".\P``+@```+KS```I````
MZ?,``"@````3]```10```#ST``!'````@O0``$H```#*]```1P```!7U``!%
M````7?4``$@```"C]0``.0```.SU``!&````)O8``$@```!M]@``,````+;V
M``!%````Y_8``$8````M]P``3````'3W```T````P?<``#(```#V]P``:0``
M`"GX```P````D_@``"4```#$^```B````.KX``!`````<_D``/8```"T^0``
M2@```*OZ```L````]OH``(4````C^P``2````*G[```.````\OL```\````!
M_```#0```!'\```(````'_P```L````H_```#````#3\```*````0?P```0`
M``!,_```!````%'\```;````5OP``"T```!R_```'0```*#\```D````OOP`
M`"D```#C_```&0````W]```!````)_T``!D````I_0``#````$/]```1````
M4/T``!X```!B_0``2````(']```K````ROT``$0```#V_0``)P```#O^```E
M````8_X``!<```")_@``#P```*'^```+````L?X``!$```"]_@``#@```,_^
M```%````WOX``"@```#D_@``%0````W_```8````(_\```@````\_P``"@``
M`$7_```5````4/\``!(```!F_P``,@```'G_```+````K/\``"D```"X_P``
M,@```.+_```0````%0`!`!0````F``$`$````#L``0`F````3``!`"<```!S
M``$`)@```)L``0`<````P@`!`!,```#?``$`#@```/,``0`*`````@$!``T`
M```-`0$`+@```!L!`0`G````2@$!`"````!R`0$`#@```),!`0`@````H@$!
M`!<```##`0$`(@```-L!`0`U````_@$!`!$````T`@$`#0```$8"`0`,````
M5`(!``T```!A`@$`!@```&\"`0`;````=@(!`"X```"2`@$`-P```,$"`0!\
M````^0(!`&P```!V`P$`'````.,#`0`=``````0!``H````>!`$`#P```"D$
M`0`8````.00!``P```!2!`$`&P```%\$`0`;````>P0!`$4```"7!`$`*```
M`-T$`0!!````!@4!`"0```!(!0$`#@```&T%`0`/````?`4!``X```",!0$`
M#@```)L%`0`(````J@4!``X```"S!0$`#@```,(%`0`)````T04!`$(```#;
M!0$`+@```!X&`0`:````308!`#,```!H!@$`40```)P&`0`R````[@8!`#@`
M```A!P$`5````%H'`0!1````KP<!`%H````!"`$`5P```%P(`0`T````M`@!
M``D```#I"`$`#0```/,(`0`'`````0D!``H````)"0$`#P```!0)`0`%````
M)`D!``,````J"0$`!@```"X)`0`1````-0D!``@```!'"0$`"0```%`)`0`)
M````6@D!``X```!D"0$`*````',)`0`(````G`D!``H```"E"0$`)0```+`)
M`0`@````U@D!`!````#W"0$`#P````@*`0`/````&`H!``H````H"@$`!P``
M`#,*`0`#````.PH!``\````_"@$`%````$\*`0`)````9`H!``T```!N"@$`
M$@```'P*`0`9````CPH!`!X```"I"@$`#P```,@*`0`*````V`H!``\```#C
M"@$`"````/,*`0`*````_`H!`"0````'"P$`%P```"P+`0`8````1`L!`!0`
M``!="P$`%@```'(+`0`(````B0L!`!P```"2"P$`3@```*\+`0`M````_@L!
M`!\````L#`$`&0```$P,`0!>````9@P!`"@```#%#`$`'@```.X,`0`:````
M#0T!`"P````H#0$`(````%4-`0`R````=@T!``<```"I#0$`#````+$-`0`-
M````O@T!`%(```#,#0$`80```!\.`0`L````@0X!``X```"N#@$``P```+T.
M`0`+````P0X!``<```#-#@$`!P```-4.`0`%````W0X!``4```#C#@$`"@``
M`.D.`0`#````]`X!`!<```#X#@$`"@```!`/`0`/````&P\!``X````K#P$`
M3@```#H/`0!0````B0\!`$,```#:#P$`0@```!X0`0`]````81`!`#````"?
M$`$`&````-`0`0`C````Z1`!``X````-$0$`%````!P1`0`7````,1$!`!<`
M``!)$0$`%P```&$1`0`3````>1$!``\```"-$0$`(P```)T1`0`&````P1$!
M`!<```#($0$`#@```.`1`0!1````[Q$!`!\```!!$@$`'0```&$2`0`U````
M?Q(!``<```"U$@$`!@```+T2`0`(````Q!(!``\```#-$@$`!@```-T2`0`(
M````Y!(!`!$```#M$@$`"@```/\2`0`3````"A,!``L````>$P$`%0```"H3
M`0`-````0!,!`!,```!.$P$`(P```&(3`0`O````AA,!`!4```"V$P$`!P``
M`,P3`0`0````U!,!``4```#E$P$`%0```.L3`0`1`````10!``P````3%`$`
M,````"`4`0!(````410!`"$```":%`$`.P```+P4`0`[````^!0!`#P````T
M%0$`.````'$5`0`K````JA4!`#$```#6%0$`.P````@6`0`Y````1!8!`#4`
M``!^%@$`"0```+06`0`'````OA8!`!0```#&%@$`#````-L6`0`#````Z!8!
M``4```#L%@$`"0```/(6`0`0````_!8!``D````-%P$`$P```!<7`0`#````
M*Q<!`#D````O%P$`$@```&D7`0`&````?!<!``P```"#%P$`-0```)`7`0`.
M````QA<!`$D```#5%P$`,P```!\8`0`*````4Q@!`"T```!>&`$`"P```(P8
M`0`G````F!@!`"P```#`&`$`*@```.T8`0`E````&!D!``D````^&0$`"0``
M`$@9`0`*````4AD!``8```!=&0$`"0```&09`0`'````;AD!`"\```!V&0$`
M-P```*89`0`N````WAD!`%4````-&@$`+0```&,:`0`L````D1H!`"T```"^
M&@$`+0```.P:`0!`````&AL!`",```!;&P$`(P```'\;`0`M````HQL!`#,`
M``#1&P$`%0````4<`0`9````&QP!`"D````U'`$`)````%\<`0!0````A!P!
M`!@```#5'`$`$0```.X<`0`1`````!T!``H````2'0$`#````!T=`0`+````
M*AT!``H````V'0$`"@```$$=`0`0````3!T!`!8```!='0$`%@```'0=`0`'
M````BQT!``<```"3'0$`%````)L=`0`*````L!T!``@```"['0$`"````,0=
M`0`#````S1T!``<```#1'0$`!P```-D=`0`&````X1T!`#@```#H'0$`!0``
M`"$>`0`'````)QX!``8````O'@$`"````#8>`0`)````/QX!`"D```!)'@$`
M#@```',>`0`*````@AX!`$4```"-'@$`!````-,>`0`$````V!X!``<```#=
M'@$`"0```.4>`0`&````[QX!`!$```#V'@$`!P````@?`0`6````$!\!``0`
M```G'P$`)P```"P?`0`(````5!\!``8```!='P$`#0```&0?`0`&````<A\!
M`!X```!Y'P$`$0```)@?`0`B````JA\!`!8```#-'P$`"````.0?`0`-````
M[1\!``P```#['P$`!P````@@`0`#````$"`!``,````4(`$`%P```!@@`0`3
M````,"`!``@```!$(`$`'0```$T@`0`(````:R`!``0```!T(`$`"````'D@
M`0`(````@B`!`"H```"+(`$`*P```+8@`0!3````XB`!`$$````V(0$`(```
M`'@A`0`&````F2$!``8```"@(0$`#@```*<A`0`5````MB$!`#X```#,(0$`
M&`````LB`0`B````)"(!`"X```!'(@$`'0```'8B`0`A````E"(!`%0```"V
M(@$`*0````LC`0`*````-2,!``<```!`(P$`%0```$@C`0`.````7B,!``(`
M``!M(P$`"@```'`C`0`/````>R,!``T```"+(P$`#P```)DC`0`-````J2,!
M``D```"W(P$`%````,$C`0`&````UB,!`!@```#=(P$`'0```/8C`0`3````
M%"0!`!$````H)`$`%````#HD`0`$````3R0!``P```!4)`$`!@```&$D`0`*
M````:"0!``T```!S)`$`8@```($D`0`G````Y"0!`%0````,)0$`7P```&$E
M`0`$````P24!`!8```#&)0$`#@```-TE`0`<````["4!``\````))@$`,P``
M`!DF`0`H````328!`$0```!V)@$`!0```+LF`0`%````P28!`!L```#')@$`
M&@```.,F`0`.````_B8!`!4````-)P$`,````",G`0`1````5"<!`!$```!F
M)P$`$0```'@G`0`<````BB<!`"H```"G)P$`-0```-(G`0!%````""@!`!``
M``!.*`$`(0```%\H`0`E````@2@!`!D```"G*`$`!0```,$H`0`3````QR@!
M`!(```#;*`$`"@```.XH`0`/````^2@!``T````)*0$`1P```!<I`0`?````
M7RD!`"4```!_*0$`,P```*4I`0`K````V2D!`#4````%*@$`0@```#LJ`0`=
M````?BH!`!T```"<*@$`40```+HJ`0`1````#"L!`#$````>*P$`.P```%`K
M`0`3````C"L!`$````"@*P$`.````.$K`0`%````&BP!``P````@+`$`$0``
M`"TL`0`-````/RP!``8```!-+`$`#````%0L`0`&````82P!`!<```!H+`$`
M"````(`L`0`,````B2P!`!0```"6+`$`#P```*LL`0`0````NRP!`!$```#,
M+`$`"````-XL`0`%````YRP!`!$```#M+`$`#````/\L`0`0````#"T!``4`
M```=+0$`#0```",M`0`&````,2T!``<````X+0$`#0```$`M`0`0````3BT!
M``D```!?+0$`!P```&DM`0`+````<2T!``L```!]+0$`!P```(DM`0`'````
MD2T!``D```"9+0$`!P```*,M`0`4````JRT!`!<```#`+0$`)@```-@M`0!/
M````_RT!``D```!/+@$`"0```%DN`0`*````8RX!`!D```!N+@$`'0```(@N
M`0`,````IBX!`"4```"S+@$`'P```-DN`0`0````^2X!``4````*+P$`)0``
M`!`O`0`2````-B\!`!,```!)+P$`*P```%TO`0`[````B2\!`"````#%+P$`
M&P```.8O`0`V`````C`!`"$````Y,`$`$````%LP`0`(````;#`!`!L```!U
M,`$`'@```)$P`0!<````L#`!`"X````-,0$`#````#PQ`0`&````23$!``0`
M``!0,0$`#@```%4Q`0`.````9#$!`!````!S,0$`!P```(0Q`0`.````C#$!
M``H```";,0$`#0```*8Q`0`>````M#$!`!L```#3,0$`(0```.\Q`0`>````
M$3(!`!D````P,@$`'@```$HR`0`;````:3(!`"X```"%,@$`%P```+0R`0`F
M````S#(!`#````#S,@$`)````"0S`0`;````23,!`!X```!E,P$`'````(0S
M`0`F````H3,!`#8```#(,P$`*P```/\S`0`S````*S0!`"D```!?-`$`00``
M`(DT`0`Z````RS0!`"8````&-0$`*P```"TU`0`X````634!`!T```"2-0$`
M%0```+`U`0`O````QC4!`"````#V-0$`$@```!<V`0`I````*C8!`!X```!4
M-@$`$@```',V`0"B````AC8!`!8````I-P$`(P```$`W`0`H````9#<!`"D`
M``"--P$`*````+<W`0`?````X#<!`!4`````.`$`(````!8X`0`E````-S@!
M`"@```!=.`$`+0```(8X`0`P````M#@!`)(```#E.`$`(0```'@Y`0`6````
MFCD!`!P```"Q.0$`)@```,XY`0`J````]3D!`$$````@.@$`1````&(Z`0`,
M````ISH!``<```"T.@$`!P```+PZ`0`&````Q#H!``T```#+.@$`"P```-DZ
M`0`5````Y3H!`!0```#[.@$`#0```!`[`0`8````'CL!`!H````W.P$`$```
M`%([`0`=````8SL!`!D```"!.P$`70```)L[`0`2````^3L!`!,````,/`$`
M$@```"`\`0`'````,SP!``0````[/`$`$````$`\`0`,````43P!``X```!>
M/`$`#P```&T\`0`4````?3P!`!,```"2/`$`#0```*8\`0`Y````M#P!`!P`
M``#N/`$`*`````L]`0`#````-#T!``T````X/0$`!@```$8]`0`1````33T!
M`!<```!?/0$`&P```'<]`0`.````DST!``(```"B/0$`!0```*4]`0`%````
MJST!`!````"Q/0$`!````,(]`0`-````QST!``X```#5/0$``P```.0]`0`.
M````Z#T!``@```#W/0$`#P`````^`0`(````$#X!``H````9/@$`#P```"0^
M`0`'````-#X!``T````\/@$`$````$H^`0`3````6SX!`!,```!O/@$`&0``
M`(,^`0`:````G3X!``L```"X/@$`"0```,0^`0`&````SCX!`!0```#5/@$`
M$P```.H^`0`0````_CX!``P````//P$`$0```!P_`0`7````+C\!`!4```!&
M/P$`&0```%P_`0`+````=C\!``T```""/P$`(@```)`_`0`K````LS\!`!<`
M``#?/P$`-````/<_`0`S````+$`!`!L```!@0`$`-````'Q``0`*````L4`!
M`!@```"\0`$`.P```-5``0`9````$4$!`!8````K00$`+P```$)!`0`'````
M<D$!`!````!Z00$`(@```(M!`0`<````KD$!`!P```#+00$`#0```.A!`0`'
M````]D$!``P```#^00$`)@````M"`0`*````,D(!`!0````]0@$`"P```%)"
M`0`'````7D(!`"(```!F0@$`+P```(E"`0`+````N4(!``D```#%0@$`&0``
M`,]"`0`+````Z4(!``\```#U0@$`%P````5#`0`7````'4,!``D````U0P$`
M!P```#]#`0`6````1T,!``\```!>0P$`+0```&Y#`0`9````G$,!`!8```"V
M0P$`#@```,U#`0`:````W$,!`"@```#W0P$`+@```"!$`0`+````3T0!`!@`
M``!;1`$`"````'1$`0`,````?40!`",```"*1`$`#0```*Y$`0`F````O$0!
M`"H```#C1`$`(`````Y%`0!#````+T4!``@```!S10$`$@```'Q%`0`$````
MCT4!``@```"410$`"P```)U%`0`:````J44!`"<```#$10$`$@```.Q%`0`@
M````_T4!`"\````@1@$`%P```%!&`0`%````:$8!``P```!N1@$`#@```'M&
M`0`.````BD8!``4```"91@$`!@```)]&`0`.````ID8!``,```"U1@$``P``
M`+E&`0`K````O48!``<```#I1@$`!````/%&`0`.````]D8!``H````%1P$`
M#````!!'`0`*````'4<!``\````H1P$`$````#A'`0`7````24<!`!,```!A
M1P$`)0```'5'`0`.````FT<!`!$```"J1P$`&0```+Q'`0`7````UD<!`!,`
M``#N1P$`%@````)(`0`X````&4@!`!,```!22`$`"0```&9(`0`%````<$@!
M``L```!V2`$`"@```()(`0`"````C4@!``4```"02`$`#0```)9(`0`;````
MI$@!`!<```#`2`$`"0```-A(`0`=````XD@!``\`````20$`%@```!!)`0`2
M````)TD!``P````Z20$`#@```$=)`0`-````5DD!`!(```!D20$`&0```'=)
M`0`<````D4D!`#@```"N20$`&````.=)`0`@`````$H!`!,````A2@$``P``
M`#5*`0`5````.4H!``L```!/2@$`$P```%M*`0`(````;TH!``X```!X2@$`
M$````(=*`0![````F$H!`!@````42P$`)P```"U+`0`I````54L!`"P```!_
M2P$`*````*Q+`0`.````U4L!`$````#D2P$`-0```"5,`0`1````6TP!``<`
M``!M3`$`!0```'5,`0`8````>TP!`!D```"43`$`$P```*Y,`0`'````PDP!
M``<```#*3`$`"````-),`0`&````VTP!``8```#B3`$`&P```.E,`0`0````
M!4T!``\````630$`$````"9-`0`/````-TT!``L```!'30$`#P```%--`0`,
M````8TT!``\```!P30$`!P```(!-`0`*````B$T!``8```"330$`"@```)I-
M`0`2````I4T!``T```"X30$`#````,9-`0`.````TTT!`$,```#B30$`/0``
M`"9.`0`)````9$X!``P```!N3@$`*````'M.`0`/````I$X!``@```"T3@$`
M%@```+U.`0`(````U$X!`!,```#=3@$`"P```/%.`0`>````_4X!`"$````<
M3P$`(````#Y/`0`9````7T\!`!<```!Y3P$`)0```)%/`0`7````MT\!``0`
M``#/3P$`&P```-1/`0`-````\$\!``P```#^3P$``P````M0`0`(````#U`!
M``H````84`$`#````"-0`0`*````,%`!`"`````[4`$`'P```%Q0`0`;````
M?%`!`!D```"84`$`"P```+)0`0`;````OE`!``L```#:4`$`$````.90`0`(
M````]U`!``P`````40$`!`````U1`0`$````$E$!`!,````740$`%````"M1
M`0`,````0%$!``D```!-40$`#@```%=1`0`+````9E$!`!L```!R40$`#@``
M`(Y1`0`/````G5$!`"4```"M40$`*@```--1`0`'````_E$!`!(````&4@$`
M&P```!E2`0`$````-5(!``<````Z4@$`"@```$)2`0`2````35(!``H```!@
M4@$`#0```&M2`0`)````>5(!``0```"#4@$`!0```(A2`0`(````CE(!``,`
M``"74@$`&````)M2`0`=````M%(!`!````#24@$`#0```.-2`0`.````\5(!
M`!X`````4P$`&@```!]3`0`*````.E,!``0```!%4P$`)@```$I3`0`.````
M<5,!`'P```"`4P$`%0```/U3`0!$````$U0!``4```!85`$`!P```%Y4`0`,
M````9E0!``@```!S5`$`"@```'Q4`0`&````AU0!``<```".5`$`"````)94
M`0`1````GU0!`!D```"Q5`$`"````,M4`0`6````U%0!`!(```#K5`$``@``
M`/Y4`0`&`````54!``8````(50$`%`````]5`0`5````)%4!``\````Z50$`
M$0```$I5`0`:````7%4!``T```!W50$`$````(55`0`;````EE4!``4```"R
M50$`!````+A5`0`,````O54!``D```#*50$`$````-15`0`)````Y54!``D`
M``#O50$`!0```/E5`0`$````_U4!``4````$5@$`&@````I6`0`%````)58!
M`!H````K5@$`"````$96`0`&````3U8!``\```!65@$`&0```&96`0`.````
M@%8!`"(```"/5@$`!P```+)6`0`'````NE8!`"(```#"5@$`#@```.56`0`%
M````]%8!``D```#Z5@$`"@````17`0`"````#U<!``T````25P$`(````"!7
M`0`&````05<!``T```!(5P$`#````%97`0`)````8U<!``8```!M5P$`$@``
M`'17`0`)````AU<!``<```"15P$`%````)E7`0`=````KE<!`!$```#,5P$`
M!@```-Y7`0`*````Y5<!``0```#P5P$`"0```/57`0`(````_U<!`!$````(
M6`$`$0```!I8`0`)````+%@!``8````V6`$`#0```#U8`0`&````2U@!``0`
M``!26`$`!````%=8`0`7````7%@!`#D```!T6`$`/0```*Y8`0`Z````[%@!
M`!X````G60$`!0```$99`0`.````3%D!``0```!;60$`!@```&!9`0`'````
M9UD!`"$```!O60$`#0```)%9`0`5````GUD!``8```"U60$`!````+Q9`0`1
M````P5D!``8```#360$`H````-I9`0`*````>UH!`"(```"&6@$`)P```*E:
M`0`&````T5H!`!4```#86@$`#````.Y:`0`1````^UH!``\````-6P$`!```
M`!U;`0`-````(EL!``<````P6P$`)0```#A;`0`%````7EL!`!T```!D6P$`
M!````();`0`,````AUL!``H```"46P$`"````)];`0`)````J%L!``4```"R
M6P$`&P```+A;`0`Z````U%L!`#`````/7`$`-0```$!<`0`I````=EP!`"X`
M``"@7`$`1P```,]<`0`X````%UT!`"D```!070$`/P```'I=`0`N````NET!
M`"T```#I70$`'P```!=>`0`/````-UX!`!(```!'7@$`"P```%I>`0`F````
M9EX!`"<```"-7@$`*0```+5>`0`D````WUX!`"8````$7P$`*````"M?`0`(
M````5%\!``H```!=7P$`"0```&A?`0`'````<E\!``0```!Z7P$`'````']?
M`0`@````G%\!`"````"]7P$`)@```-Y?`0`-````!6`!`"<````38`$`&P``
M`#M@`0`,````5V`!`!8```!D8`$`!0```'M@`0`*````@6`!`!D```",8`$`
M*0```*9@`0`6````T&`!`!(```#G8`$`!P```/I@`0`*`````F$!``\````-
M80$`$````!UA`0!`````+F$!`#P```!O80$`<````*QA`0!F````'6(!``8`
M``"$8@$`"@```(MB`0`.````EF(!``D```"E8@$`"@```*]B`0`2````NF(!
M`!,```#-8@$`#````.%B`0`&````[F(!``8```#U8@$`"@```/QB`0`.````
M!V,!``\````68P$`#@```"9C`0`<````-6,!`!\```!28P$`'@```')C`0`C
M````D6,!`!$```"U8P$`%0```,=C`0`8````W6,!`!$```#V8P$`$`````AD
M`0`C````&60!``\````]9`$`"0```$UD`0`2````5V0!`!T```!J9`$`$@``
M`(AD`0`0````FV0!``H```"L9`$`$0```+=D`0`%````R60!`#$```#/9`$`
M)`````%E`0`<````)F4!`",```!#90$`:@```&=E`0`/````TF4!``4```#B
M90$`$````.AE`0`)````^64!``0````#9@$`"P````AF`0`@````%&8!`!P`
M```U9@$`(P```%)F`0`B````=F8!`!H```"99@$`!@```+1F`0`4````NV8!
M`!<```#09@$`#````.AF`0`D````]68!`",````:9P$`&@```#YG`0`,````
M66<!``\```!F9P$`%0```'9G`0`I````C&<!`"H```"V9P$`)@```.%G`0`G
M````"&@!`"D````P:`$`*@```%IH`0`9````A6@!`$(```"?:`$`$0```.)H
M`0`2````]&@!`!,````':0$`%````!MI`0`/````,&D!`!8```!`:0$`%P``
M`%=I`0`0````;VD!`!$```"`:0$`-````))I`0`3````QVD!`!(```#;:0$`
M-0```.YI`0`4````)&H!``<````Y:@$`#````$%J`0`K````3FH!``\```!Z
M:@$`%@```(IJ`0`@````H6H!`!````#":@$`%````--J`0`1````Z&H!`"@`
M``#Z:@$`%P```"-K`0`<````.VL!`!,```!8:P$`"P```&QK`0`4````>&L!
M`!H```"-:P$`$0```*AK`0`:````NFL!`!X```#5:P$`&@```/1K`0`3````
M#VP!`"$````C;`$`(````$5L`0`5````9FP!`!$```!\;`$`%P```(YL`0`4
M````IFP!`!<```"[;`$`%0```--L`0`)````Z6P!``8```#S;`$`&0```/IL
M`0`$````%&T!``<````9;0$`"P```"%M`0`1````+6T!``8````_;0$`!@``
M`$9M`0`&````36T!``4```!4;0$`!P```%IM`0`'````8FT!``4```!J;0$`
M%@```'!M`0`&````AVT!``8```".;0$`!````)5M`0`$````FFT!``<```"?
M;0$`#@```*=M`0`,````MFT!``P```##;0$`#0```-!M`0`"````WFT!``H`
M``#A;0$`#@```.QM`0`%````^VT!`"@````!;@$`#@```"IN`0`,````.6X!
M``\```!&;@$`"@```%9N`0`(````86X!``D```!J;@$`*P```'1N`0!/````
MH&X!`"X```#P;@$`!````!]O`0`(````)&\!`"8````M;P$`$@```%1O`0`/
M````9V\!``8```!W;P$`"@```'YO`0`'````B6\!``@```"1;P$`(````)IO
M`0`)````NV\!`!$```#%;P$`"0```-=O`0`,````X6\!``T```#N;P$`#@``
M`/QO`0`6````"W`!`!$````B<`$`!@```#1P`0`#````.W`!``8````_<`$`
M&0```$9P`0`'````8'`!``0```!H<`$`"P```&UP`0`+````>7`!``<```"%
M<`$`$0```(UP`0`'````GW`!`!8```"G<`$`#0```+YP`0`-````S'`!``H`
M``#:<`$`$````.5P`0`/````]G`!`!$````&<0$`%P```!AQ`0`*````,'$!
M`!$````[<0$`"````$UQ`0`$````5G$!``\```!;<0$`.@```&MQ`0`A````
MIG$!``4```#(<0$`%P```,YQ`0`,````YG$!`!X```#S<0$`#@```!)R`0`0
M````(7(!``L````R<@$`?````#YR`0`,````NW(!``D```#(<@$`!P```-)R
M`0`*````VG(!``D```#E<@$`#@```.]R`0`0````_G(!`!4````/<P$`&@``
M`"5S`0`*````0',!``D```!+<P$`%````%5S`0`*````:G,!``X```!U<P$`
M#````(1S`0`/````D7,!``@```"A<P$`!@```*IS`0`,````L7,!``<```"^
M<P$`!0```,9S`0`+````S',!`$<```#8<P$`#0```"!T`0`)````+G0!``0`
M```X=`$``P```#UT`0`,````070!`!,```!.=`$`$P```&)T`0`3````=G0!
M``8```"*=`$`"@```)%T`0`"````G'0!``0```"?=`$`)0```*1T`0`#````
MRG0!``4```#.=`$`*@```-1T`0`.````_W0!``H````.=0$`!0```!EU`0`$
M````'W4!``H````D=0$`#0```"]U`0`?````/74!``<```!==0$`(@```&5U
M`0`-````B'4!`$````"6=0$`$P```-=U`0`&````ZW4!``@```#R=0$`"```
M`/MU`0`$````!'8!``4````)=@$`:`````]V`0`)````>'8!``P```""=@$`
M!0```(]V`0`&````E78!`",```"<=@$`)0```,!V`0`(````YG8!`#<```#O
M=@$`(@```"=W`0`3````2G<!`!L```!>=P$`+P```'IW`0`0````JG<!``H`
M``"[=P$`$0```,9W`0`/````V'<!``\```#H=P$`"@```/AW`0`)`````W@!
M`!,````->`$`&P```"%X`0`8````/7@!`!<```!6>`$`%P```&YX`0`.````
MAG@!`"8```"5>`$`)@```+QX`0`#````XW@!``<```#G>`$`"````.]X`0`4
M````^'@!`!,````->0$`$````"%Y`0`-````,GD!``X```!`>0$`%@```$]Y
M`0`'````9GD!`!````!N>0$`"@```']Y`0`+````BGD!`"T```"6>0$`%0``
M`,1Y`0`P````VGD!`"0````+>@$`!P```#!Z`0`3````.'H!``P```!,>@$`
M#P```%EZ`0`.````:7H!``P```!X>@$`#@```(5Z`0!1````E'H!``\```#F
M>@$`$````/9Z`0`.````!WL!``T````6>P$`#P```"1[`0`/````-'L!`!<`
M``!$>P$`%````%Q[`0`1````<7L!``\```"#>P$`(````)-[`0`N````M'L!
M`!H```#C>P$`#````/Y[`0`F````"WP!``L````R?`$`#0```#Y\`0`:````
M3'P!`$H```!G?`$`&0```+)\`0`&````S'P!`!H```#3?`$`!@```.Y\`0`&
M````]7P!`!\```#\?`$`!@```!Q]`0`)````(WT!`!@````M?0$`%P```$9]
M`0`&````7GT!``T```!E?0$`(@```'-]`0!7````EGT!`!,```#N?0$`(P``
M``)^`0`3````)GX!``(````Z?@$`"P```#U^`0`(````27X!``T```!2?@$`
M!@```&!^`0`*````9WX!``8```!R?@$`!P```'E^`0`4````@7X!``8```"6
M?@$`"````)U^`0`.````IGX!``<```"U?@$`"@```+U^`0`+````R'X!`"L`
M``#4?@$`!P````!_`0`,````"'\!``T````5?P$`#````"-_`0`$````,'\!
M``D````U?P$`"0```#]_`0`*````27\!``<```!4?P$`"0```%Q_`0`.````
M9G\!``<```!U?P$`"@```'U_`0`;````B'\!`!4```"D?P$`$@```+I_`0`*
M````S7\!``D```#8?P$`$````.)_`0`'````\W\!`!(```#[?P$`!`````Z`
M`0`$````$X`!`"(````8@`$`!P```#N``0`%````0X`!``P```!)@`$`!0``
M`%:``0`+````7(`!`!0```!H@`$`$0```'V``0`:````CX`!`!8```"J@`$`
M%````,&``0`7````UH`!`!@```#N@`$`'`````>!`0`9````)($!``<````^
M@0$`!0```$:!`0`6````3($!``,```!C@0$`#0```&>!`0`,````=8$!``H`
M``""@0$`"````(V!`0`(````EH$!`!<```"?@0$`"P```+>!`0`,````PX$!
M`!,```#0@0$`!````.2!`0`*````Z8$!``0```#T@0$`#0```/F!`0`,````
M!X(!``D````4@@$`#````!Z"`0`%````*X(!``D````Q@@$`!0```#N"`0`'
M````08(!``4```!)@@$`!````$^"`0`"````5((!`!0```!7@@$`#0```&R"
M`0`2````>H(!``L```"-@@$`&P```)F"`0`?````M8(!``\```#5@@$`%```
M`.6"`0`>````^H(!`!4````9@P$`.````"^#`0`L````:(,!`!(```"5@P$`
M*0```*B#`0`R````TH,!``H````%A`$`-@```!"$`0`L````1X0!`!4```!T
MA`$`+@```(J$`0`S````N80!`#,```#MA`$`.````"&%`0`/````6H4!`!@`
M``!JA0$`+P```(.%`0`[````LX4!`!````#OA0$`$P````"&`0`J````%(8!
M`!D````_A@$`'````%F&`0`?````=H8!`!0```"6A@$`$P```*N&`0`5````
MOX8!`!0```#5A@$`%````.J&`0`@````_X8!`!(````@AP$`%````#.'`0`5
M````2(<!`"T```!>AP$`+0```(R'`0`Q````NH<!`"T```#LAP$`+@```!J(
M`0`O````28@!`"P```!YB`$`8@```*:(`0`3````"8D!`"4````=B0$`)```
M`$.)`0`I````:(D!``@```"2B0$`"````)N)`0`D````I(D!`!(```#)B0$`
M#@```-R)`0`K````ZXD!`!(````7B@$`(0```"J*`0`:````3(H!``D```!G
MB@$`10```'&*`0!!````MXH!``\```#YB@$`!`````F+`0`3````#HL!`!0`
M```BBP$`#@```#>+`0`&````1HL!`!,```!-BP$`&````&&+`0`&````>HL!
M``D```"!BP$`"@```(N+`0`+````EHL!``D```"BBP$`#0```*R+`0`,````
MNHL!``\```#'BP$`%P```->+`0`4````[XL!`!`````$C`$`%@```!6,`0`'
M````+(P!``X````TC`$`(0```$.,`0`%````98P!`!L```!KC`$`!@```(>,
M`0`(````CHP!``8```"7C`$`%````)Z,`0`1````LXP!`$0```#%C`$`/```
M``J-`0`.````1XT!`#@```!6C0$``@```(^-`0`"````DHT!``8```"5C0$`
M#@```)R-`0`:````JXT!``4```#&C0$`!P```,R-`0`.````U(T!``8```#C
MC0$`#````.J-`0`C````]XT!``0````;C@$`*0```"".`0`R````2HX!`!<`
M``!]C@$`'P```)6.`0`S````M8X!`%P```#IC@$`#````$:/`0`+````4X\!
M`!0```!?CP$`/@```'2/`0`-````LX\!`!\```#!CP$`$````.&/`0`4````
M\H\!``<````'D`$`#@````^0`0`(````'I`!``P````GD`$`#````#20`0`3
M````09`!``H```!5D`$`'0```&"0`0`9````?I`!``4```"8D`$`$0```)Z0
M`0`3````L)`!``T```#$D`$`$0```-*0`0`D````Y)`!``,````)D0$`%0``
M``V1`0`3````(Y$!`!(````WD0$`"P```$J1`0`T````5I$!``X```"+D0$`
M"P```)J1`0`4````II$!`#X```"[D0$`#@```/J1`0`3````"9(!`#0````=
MD@$`,0```%*2`0`2````A)(!`!````"7D@$`&````*B2`0`9````P9(!`",`
M``#;D@$`(@```/^2`0`G````(I,!`%8```!*DP$`30```*&3`0"X````[Y,!
M``@```"HE`$`"0```+&4`0`-````NY0!``H```#)E`$`!P```-24`0`/````
MW)0!``8```#LE`$`"P```/.4`0`$````_Y0!`!P````$E0$`#0```"&5`0`G
M````+Y4!`!L```!7E0$`#````'.5`0`*````@)4!``<```"+E0$`#0```).5
M`0`B````H94!`"$```#$E0$`"````.:5`0`%````[Y4!`!\```#UE0$`!@``
M`!66`0`0````')8!``@````ME@$`!P```#:6`0`-````/I8!``H```!,E@$`
M$@```%>6`0`A````:I8!``L```",E@$`'````)B6`0`8````M98!``@```#.
ME@$`$@```->6`0`L````ZI8!`!H````7EP$`"0```#*7`0`*````/)<!`!4`
M``!'EP$`!0```%V7`0`4````8Y<!``0```!XEP$`$````'V7`0`&````CI<!
M``<```"5EP$`'@```)V7`0`H````O)<!``H```#EEP$`'````/"7`0`:````
M#9@!``\````HF`$`+0```#B8`0`(````9I@!`!0```!OF`$`+````(28`0`G
M````L9@!`"L```#9F`$`*@````69`0`$````,)D!``0````UF0$`"P```#J9
M`0`%````1ID!``8```!,F0$`"````%.9`0`&````7)D!`#$```!CF0$`'```
M`)69`0`*````LID!`!L```"]F0$`-````-F9`0`T````#IH!`"````!#F@$`
M*0```&2:`0`G````CIH!`"````"VF@$`00```->:`0`:````&9L!`"@````T
MFP$`&@```%V;`0!V````>)L!`'D```#OFP$`'`$``&F<`0`H````AIT!`!T`
M``"OG0$`*0```,V=`0`=````]YT!`%$````5G@$`+P```&>>`0`N````EYX!
M`%<```#&G@$`-@```!Z?`0`L````59\!`"P```""GP$`,0```*^?`0`N````
MX9\!`"(````0H`$`!@```#.@`0`(````.J`!``4```!#H`$`"````$F@`0`9
M````4J`!`!D```!LH`$`*@```(:@`0`0````L:`!`"L```#"H`$`(P```.Z@
M`0`9````$J$!`"$````LH0$`+@```$ZA`0`T````?:$!``@```"RH0$`%P``
M`+NA`0`*````TZ$!``<```#>H0$`(0```.:A`0`0````"*(!``T````9H@$`
M$````">B`0`%````.*(!``X````^H@$`"````$VB`0`+````5J(!`!0```!B
MH@$`!P```'>B`0`3````?Z(!``@```"3H@$`-@```)RB`0`W````TZ(!``L`
M```+HP$`"0```!>C`0`*````(:,!`!0````LHP$`#P```$&C`0`O````4:,!
M`#(```"!HP$`"P```+2C`0`.````P*,!``T```#/HP$`#P```-VC`0`6````
M[:,!`#X````$I`$`)P```$.D`0`F````:Z0!`"0```"2I`$`!0```+>D`0`%
M````O:0!`"<```##I`$`'P```.ND`0`6````"Z4!``L````BI0$`%P```"ZE
M`0`/````1J4!``0```!6I0$`"@```%NE`0`)````9J4!``L```!PI0$`#0``
M`'RE`0`,````BJ4!``X```"7I0$`!0```*:E`0`>````K*4!``0```#+I0$`
M#0```-"E`0`R````WJ4!`$4````1I@$`"P```%>F`0`.````8Z8!``X```!R
MI@$`"0```(&F`0`(````BZ8!`!````"4I@$`%0```*6F`0`3````NZ8!`!<`
M``#/I@$`!P```.>F`0`>````[Z8!`!4````.IP$`%````"2G`0`%````.:<!
M`!0````_IP$`!@```%2G`0`+````6Z<!``<```!GIP$`(P```&^G`0`6````
MDZ<!``\```"JIP$`#@```+JG`0`J````R:<!``8```#TIP$`#````/NG`0`8
M````"*@!``T````AJ`$`$0```"^H`0`+````0:@!`#8```!-J`$`#0```(2H
M`0`*````DJ@!`"(```"=J`$`"P```,"H`0`/````S*@!`!````#<J`$`+@``
M`.VH`0`Z````'*D!``X```!7J0$`#0```&:I`0`%````=*D!``L```!ZJ0$`
M#````(:I`0`-````DZD!``T```"AJ0$`#@```*^I`0`-````OJD!`"````#,
MJ0$`)P```.VI`0`K````%:H!``@```!!J@$`"@```$JJ`0`&````5:H!`!(`
M``!<J@$`#@```&^J`0`7````?JH!`#(```"6J@$`'@```,FJ`0`6````Z*H!
M`!P```#_J@$`)0```!RK`0`P````0JL!`#$```!SJP$`+0```*6K`0`.````
MTZL!`!0```#BJP$`!0```/>K`0`.````_:L!`!,````,K`$`&@```""L`0`'
M````.ZP!`!H```!#K`$`"````%ZL`0`&````9ZP!`!,```!NK`$`%````(*L
M`0`1````EZP!`$L```"IK`$`!P```/6L`0`4````_:P!`!@````2K0$`!P``
M`"NM`0`%````,ZT!``P````YK0$`#````$:M`0`2````4ZT!``0```!FK0$`
M!P```&NM`0`*````<ZT!``L```!^K0$`#````(JM`0`.````EZT!``X```"F
MK0$`!0```+6M`0`%````NZT!`"X```#!K0$`)@```/"M`0`C````%ZX!``,`
M```[K@$`$@```#^N`0`&````4JX!``8```!9K@$`'@```&"N`0`6````?ZX!
M`!@```"6K@$`#@```*^N`0`W````OJX!`!$```#VK@$`#@````BO`0`7````
M%Z\!`$$````OKP$`-````'&O`0`E````IJ\!`!4```#,KP$`,0```.*O`0`3
M````%+`!`!L````HL`$`*@```$2P`0!1````;[`!`%H```#!L`$`4````!RQ
M`0"^````;;$!`"4````LL@$`#0```%*R`0`)````8+(!``,```!JL@$`!P``
M`&ZR`0`*````=K(!``@```"!L@$``@```(JR`0`0````C;(!``@```">L@$`
M#````*>R`0`5````M+(!``L```#*L@$`&0```-:R`0`@````\+(!`!(````1
MLP$`!0```"2S`0`*````*K,!`!4````ULP$`$@```$NS`0`,````7K,!``0`
M``!KLP$`!P```'"S`0`)````>+,!`#(```""LP$`"@```+6S`0`,````P+,!
M``L```#-LP$`!P```-FS`0`6````X;,!`%(```#XLP$`.@```$NT`0`@````
MAK0!``\```"GM`$`%P```+>T`0`D````S[0!`#D```#TM`$`$@```"ZU`0`'
M````0;4!``8```!)M0$`"0```%"U`0`.````6K4!``X```!IM0$`(@```'BU
M`0`=````F[4!``0```"YM0$`!@```+ZU`0`6````Q;4!``P```#<M0$`#0``
M`.FU`0`.````][4!`!4````&M@$`$@```!RV`0`/````+[8!`!0````_M@$`
M0P```%2V`0`*````F+8!`!L```"CM@$`-0```+^V`0`1````];8!`!`````'
MMP$`"P```!BW`0!I````)+<!`!H```".MP$`%P```*FW`0`G````P;<!`!L`
M``#IMP$`&@````6X`0`7````(+@!`!L````XN`$`&0```%2X`0`?````;K@!
M`!<```".N`$`'````*:X`0`7````P[@!``P```#;N`$`$P```.BX`0`(````
M_+@!`"\````%N0$`!P```#6Y`0`(````/;D!`!````!&N0$`$0```%>Y`0`)
M````:;D!`!4```!SN0$`#0```(FY`0`&````E[D!`!T```">N0$`(P```+RY
M`0`'````X+D!`!,```#HN0$``P```/RY`0!&`````+H!`$,```!'N@$`,@``
M`(NZ`0`_````OKH!`#<```#^N@$`5P```#:[`0`%````CKL!`!\```"4NP$`
M+P```+2[`0`*````Y+L!``T```#ONP$`$@```/V[`0`I````$+P!``@````Z
MO`$`#0```$.\`0`M````4;P!`'````!_O`$`/P```/"\`0`Y````,+T!`$8`
M``!JO0$`!````+&]`0`0````MKT!`!````#'O0$`#````-B]`0`4````Y;T!
M`!T```#ZO0$`'````!B^`0`1````-;X!`#T```!'O@$`3P```(6^`0`E````
MU;X!`"````#[O@$`'````!R_`0`+````.;\!`"<```!%OP$`&@```&V_`0`?
M````B+\!`!T```"HOP$`*````,:_`0`/````[[\!`"4```#_OP$`(````"7`
M`0`D````1L`!`"0```!KP`$`(````)#``0`E````L<`!``L```#7P`$`!P``
M`./``0`-````Z\`!``P```#YP`$`%P````;!`0`%````'L$!``8````DP0$`
M.0```"O!`0`%````9<$!``P```!KP0$`!P```'C!`0`9````@,$!``D```":
MP0$`$P```*3!`0`&````N,$!``D```"_P0$`!````,G!`0`0````SL$!``H`
M``#?P0$`"````.K!`0`(````\\$!``0```#\P0$`"P````'"`0`,````#<(!
M`!(````:P@$`$0```"W"`0`,````/\(!`!H```!,P@$`#P```&?"`0`'````
M=\(!``T```!_P@$`#@```(W"`0`/````G,(!``P```"LP@$`%````+G"`0`4
M````SL(!``\```#CP@$`#@```//"`0`2`````L,!`!0````5PP$`#@```"K#
M`0`,````.<,!`!L```!&PP$`+````&+#`0`3````C\,!`!P```"CPP$`*```
M`,##`0`&````Z<,!``<```#PPP$`$P```/C#`0`%````#,0!``0````2Q`$`
M#````!?$`0`7````),0!`!(````\Q`$`"P```$_$`0`-````6\0!`!0```!I
MQ`$`+P```'[$`0`*````KL0!``P```"YQ`$`"0```,;$`0`&````T,0!``D`
M``#7Q`$`"````.'$`0`)````ZL0!``4```#TQ`$`"@```/K$`0`1````!<4!
M``8````7Q0$`&````![%`0`.````-\4!``X```!&Q0$`#0```%7%`0`+````
M8\4!`!````!OQ0$`'0```(#%`0`1````GL4!``L```"PQ0$``@```+S%`0`(
M````O\4!``<```#(Q0$`#0```-#%`0`&````WL4!`&4```#EQ0$`%@```$O&
M`0`)````8L8!``<```!LQ@$`)@```'3&`0`X````F\8!`!H```#4Q@$`*@``
M`._&`0`[````&L<!`"@```!6QP$`-````'_'`0`9````M,<!`!4```#.QP$`
M!0```.3'`0`+````ZL<!``<```#VQP$`"````/['`0`'````!\@!``4````/
MR`$`!P```!7(`0`.````'<@!``D````LR`$`!@```#;(`0`(````/<@!``L`
M``!&R`$`!P```%+(`0`(````6L@!``<```!CR`$`%@```&O(`0`)````@L@!
M``8```",R`$`&0```)/(`0`:````K<@!`"````#(R`$`"P```.G(`0`<````
M]<@!`!0````2R0$`!P```"?)`0`1````+\D!``@```!!R0$`#@```$K)`0`(
M````6<D!``4```!BR0$`$````&C)`0`0````><D!``8```"*R0$`&0```)')
M`0`*````J\D!`!P```"VR0$`!P```-/)`0`%````V\D!``4```#AR0$`$```
M`.?)`0`4````^,D!``L````-R@$`#0```!G*`0`H````)\H!`!@```!0R@$`
M%P```&G*`0`+````@<H!`!H```"-R@$`%````*C*`0`O````O<H!``0```#M
MR@$`"0```/+*`0`*````_,H!``<````'RP$``@````_+`0`.````$LL!``@`
M```ARP$`'P```"K+`0`^````2LL!`",```")RP$`,0```*W+`0`X````W\L!
M`"8````8S`$`&P```#_,`0`Q````6\P!`#$```"-S`$`)P```+_,`0`B````
MY\P!`"`````*S0$`)@```"O-`0!D````4LT!`!T```"WS0$`%````-7-`0`<
M````ZLT!`%T````'S@$`50```&7.`0`X````N\X!`"T```#TS@$`,P```"+/
M`0!+````5L\!`$H```"BSP$`6P```.W/`0`H````2=`!`"P```!RT`$`.```
M`)_0`0`E````V-`!`"$```#^T`$`*````"#1`0`L````2=$!`"<```!VT0$`
M&P```)[1`0`>````NM$!`'4```#9T0$`/@```$_2`0!"````CM(!`#T```#1
MT@$`/0````_3`0`I````3=,!`"D```!WTP$`,0```*'3`0`^````T],!`"\`
M```2U`$`J0$``$+4`0`H````[-4!`",````5U@$`3P```#G6`0`7````B=8!
M`$@```"AU@$`-@```.K6`0`^````(=<!`#````!@UP$`(````)'7`0`_````
MLM<!`#0```#RUP$`'0```"?8`0`>````1=@!`"H```!DV`$`A0```(_8`0`P
M````%=D!`$$```!&V0$`8````(C9`0!;````Z=D!`$D```!%V@$`-````(_:
M`0`\````Q-H!`#@````!VP$`'0```#K;`0`8````6-L!`*<```!QVP$`(0``
M`!G<`0`?````.]P!`#P```!;W`$`)````)C<`0`H````O=P!`"L```#FW`$`
M(@```!+=`0`A````-=T!`"D```!7W0$`)P```('=`0`7````J=T!`"D```#!
MW0$`(````.O=`0`R````#-X!`!P````_W@$`+@```%S>`0`=````B]X!`!$`
M``"IW@$`,P```+O>`0`E````[]X!`#@````5WP$`)P```$[?`0`\````=M\!
M`"8```"SWP$`'P```-K?`0`P````^M\!`&D````KX`$`*P```)7@`0`N````
MP>`!`#$```#PX`$`00```"+A`0`^````9.$!`#X```"CX0$`1P```.+A`0`S
M````*N(!`"4```!>X@$`/0```(3B`0!E````PN(!`$T````HXP$`4P```';C
M`0!7````RN,!`%4````BY`$`1@```'CD`0`J````O^0!`"\```#JY`$`50``
M`!KE`0`@````<.4!`"X```"1Y0$`*P```,#E`0`P````[.4!`"H````=Y@$`
M/@```$CF`0!4````A^8!`%(```#<Y@$`@P```"_G`0!:````L^<!`#(````.
MZ`$`*P```$'H`0!(````;>@!`$H```"VZ`$`*@````'I`0`F````+.D!`"P`
M``!3Z0$`3@```(#I`0`R````S^D!`#`````"Z@$`'0```#/J`0`C````4>H!
M`"\```!UZ@$`+````*7J`0`M````TNH!`'$`````ZP$`;P```'+K`0"S````
MXNL!`!<```"6[`$`)0```*[L`0`R````U.P!`"D````'[0$`/@```#'M`0`B
M````<.T!`%(```"3[0$`)0```.;M`0`+````#.X!`+$````8[@$`.P```,KN
M`0`G````!N\!`$X````N[P$`1P```'WO`0!B````Q>\!`$D````H\`$`50``
M`'+P`0!`````R/`!`"\````)\0$`,@```#GQ`0`K````;/$!`"D```"8\0$`
M#P```,+Q`0!%````TO$!`"$````8\@$`+@```#KR`0`P````:?(!`"T```":
M\@$`)0```,CR`0`<````[O(!`#$````+\P$`,0```#WS`0`+````;_,!``<`
M``![\P$`!P```(/S`0`$````B_,!``T```"0\P$`"P```)[S`0`.````JO,!
M``L```"Y\P$`!0```,7S`0`0````R_,!``(```#<\P$`"@```-_S`0!6````
MZO,!`%D```!!]`$`!0```)OT`0`2````H?0!``0```"T]`$`!P```+GT`0`(
M````P?0!``4```#*]`$``P```-#T`0`0````U/0!`!<```#E]`$`"@```/WT
M`0`,````"/4!``P````5]0$`#0```"+U`0`3````,/4!``T```!$]0$``@``
M`%+U`0`'````5?4!``8```!=]0$`%````&3U`0`,````>?4!`!@```"&]0$`
M!@```)_U`0`2````IO4!``P```"Y]0$``P```,;U`0`J````RO4!``0```#U
M]0$`!@```/KU`0`'`````?8!`!\````)]@$`-0```"GV`0`N````7_8!`"\`
M``".]@$`%P```+[V`0`@````UO8!`!L```#W]@$`&````!/W`0`D````+/<!
M`!\```!1]P$`&@```''W`0`@````C/<!`!H```"M]P$`,@```,CW`0`:````
M^_<!`"\````6^`$`*P```$;X`0`?````<O@!`",```"2^`$`'P```+;X`0`:
M````UO@!`"4```#Q^`$`)@```!?Y`0`E````/OD!`"0```!D^0$`&````(GY
M`0`=````HOD!`"0```#`^0$`&````.7Y`0`B````_OD!`!4````A^@$`)0``
M`#?Z`0`\````7?H!`!\```":^@$`(P```+KZ`0`?````WOH!`"````#^^@$`
M&@```!_[`0`8````.OL!`!@```!3^P$`)@```&S[`0`>````D_L!`"D```"R
M^P$`'@```-S[`0`*````^_L!`!,````&_`$`"````!K\`0`)````(_P!`!8`
M```M_`$`#````$3\`0`7````4?P!`"\```!I_`$`)````)G\`0`'````OOP!
M`!\```#&_`$`#P```.;\`0`4````]OP!``X````+_0$`#0```!K]`0`D````
M*/T!``4```!-_0$`!P```%/]`0`,````6_T!``\```!H_0$`$0```'C]`0`B
M````BOT!`"4```"M_0$`$P```-/]`0`:````Y_T!`!T````"_@$`&@```"#^
M`0`1````._X!``<```!-_@$`QP```%7^`0`&````'?\!``L````D_P$`&@``
M`##_`0`5````2_\!``P```!A_P$`!@```&[_`0`)````=?\!`!T```!__P$`
M&````)W_`0`+````MO\!``T```#"_P$`'0```-#_`0`7````[O\!``8````&
M``(`,P````T``@`3````00`"`!,```!5``(`!P```&D``@`&````<0`"``\`
M``!X``(`$0```(@``@`>````F@`"``<```"Y``(`,@```,$``@`$````]``"
M`$8```#Y``(`(0```$`!`@`3````8@$"``P```!V`0(`$0```(,!`@`R````
ME0$"`!````#(`0(`"````-D!`@`=````X@$"``D``````@(`"@````H"`@`%
M````%0("`!0````;`@(`"@```#`"`@`=````.P("``@```!9`@(`'P```&("
M`@`(````@@("`!H```"+`@(`)P```*8"`@`&````S@("`!4```#5`@(`!P``
M`.L"`@`(````\P("``D```#\`@(`/P````8#`@`'````1@,"``\```!.`P(`
M#@```%X#`@`0````;0,"``D```!^`P(`"0```(@#`@`(````D@,"`!,```";
M`P(`!````*\#`@`'````M`,"`!(```"\`P(`)@```,\#`@`9````]@,"`!@`
M```0!`(`"P```"D$`@`.````-00"`!D```!$!`(`"@```%X$`@`D````:00"
M`"$```".!`(`"@```+`$`@`3````NP0"`"<```#/!`(`"0```/<$`@`/````
M`04"`!<````1!0(`%````"D%`@`H````/@4"``\```!G!0(`(````'<%`@`4
M````F`4"``H```"M!0(`#````+@%`@`7````Q04"``0```#=!0(`*@```.(%
M`@`1````#08"``<````?!@(`"0```"<&`@`"````,08"`!`````T!@(`&```
M`$4&`@`+````7@8"``,```!J!@(`"````&X&`@`&````=P8"``<```!^!@(`
M#0```(8&`@`+````E`8"`!0```"@!@(`%0```+4&`@`.````RP8"`"\```#:
M!@(`(`````H'`@`<````*P<"`%H```!(!P(`/P```*,'`@`V````XP<"`'X`
M```:"`(`#````)D(`@`Q````I@@"``D```#8"`(`!0```.((`@`2````Z`@"
M`#\```#["`(`$@```#L)`@`*````3@D"``8```!9"0(`!````&`)`@`$````
M90D"``H```!J"0(`$P```'4)`@`%````B0D"``8```"/"0(`!@```)8)`@`)
M````G0D"``0```"G"0(`#````*P)`@`*````N0D"`"(```#$"0(`(````.<)
M`@`%````"`H"`!@````."@(`&0```"<*`@`?````00H"`!T```!A"@(`$0``
M`'\*`@`"````D0H"``0```"4"@(`"@```)D*`@`&````I`H"``4```"K"@(`
M`P```+$*`@`,````M0H"`#L```#""@(`3P```/X*`@`U````3@L"`"<```"$
M"P(`(0```*P+`@`D````S@L"`$4```#S"P(`&@```#D,`@`=````5`P"`#4`
M``!R#`(`(@```*@,`@!6````RPP"`"@````B#0(`4P```$L-`@`Z````GPT"
M`$(```#:#0(`&0```!T.`@`7````-PX"`(L```!/#@(`&0```-L.`@`J````
M]0X"`"L````@#P(`<@```$P/`@`@````OP\"`#4```#@#P(`(0```!80`@!%
M````.!`"`"8```!^$`(`,````*40`@!+````UA`"`$X````B$0(`)P```'$1
M`@`I````F1$"`"$```##$0(`*````.41`@`K````#A("`!T````Z$@(`*0``
M`%@2`@`F````@A("`"T```"I$@(`)0```-<2`@`H````_1("`"@````F$P(`
M(@```$\3`@`Z````<A,"`"L```"M$P(`*0```-D3`@`B`````Q0"`#T````F
M%`(`00```&04`@`H````IA0"`"P```#/%`(`,````/P4`@`2````+14"`!,`
M``!`%0(`$````%05`@!Y````914"``D```#?%0(`'````.D5`@`0````!A8"
M``\````7%@(`*0```"<6`@`G````418"``X```!Y%@(`20```(@6`@!R````
MTA8"`',```!%%P(`?````+D7`@!`````-A@"`"L```!W&`(`5````*,8`@`7
M````^!@"`"H````0&0(`-````#L9`@`6````<!D"``\```"'&0(`90```)<9
M`@`H````_1D"`!\````F&@(`0````$8:`@`?````AQH"`!P```"G&@(`40``
M`,0:`@`4````%AL"``\````K&P(`"@```#L;`@`%````1AL"``8```!,&P(`
M"````%,;`@`%````7!L"`!(```!B&P(`#````'4;`@`0````@AL"`!,```"3
M&P(`'0```*<;`@`/````Q1L"``\```#5&P(`!````.4;`@`*````ZAL"``0`
M``#U&P(``P```/H;`@`(````_AL"``D````''`(`!P```!$<`@`+````&1P"
M``@````E'`(`!P```"X<`@`%````-AP"``D````\'`(`%````$8<`@`&````
M6QP"``<```!B'`(`"````&H<`@`/````<QP"``\```"#'`(`"````),<`@`,
M````G!P"``8```"I'`(`"0```+`<`@`+````NAP"``\```#&'`(`!@```-8<
M`@`'````W1P"``T```#E'`(`!@```/,<`@`4````^AP"``<````/'0(``P``
M`!<=`@`)````&QT"``8````E'0(`#````"P=`@`*````.1T"``P```!$'0(`
M%0```%$=`@`*````9QT"``\```!R'0(`!0```((=`@`(````B!T"``0```"1
M'0(`"@```)8=`@`$````H1T"``8```"F'0(`!P```*T=`@`$````M1T"``<`
M``"Z'0(`!````,(=`@`9````QQT"``<```#A'0(``@```.D=`@`"````[!T"
M``D```#O'0(`!@```/D=`@`#`````!X"``8````$'@(`#`````L>`@`G````
M&!X"``(```!`'@(`!````$,>`@`$````2!X"``L```!-'@(`"0```%D>`@`/
M````8QX"`!,```!S'@(`!P```(<>`@`"````CQX"``<```"2'@(`!@```)H>
M`@`&````H1X"`!````"H'@(`$@```+D>`@`.````S!X"``\```#;'@(``@``
M`.L>`@`&````[AX"``D```#U'@(`,P```/\>`@`B````,Q\"``<```!6'P(`
M!P```%X?`@`'````9A\"``L```!N'P(`!0```'H?`@`"````@!\"``L```"#
M'P(`#@```(\?`@`.````GA\"`&,!``"M'P(`"@```!$A`@`*````'"$"``H`
M```G(0(`<P```#(A`@"X````IB$"`$(```!?(@(`P````*(B`@"0````8R,"
M`$8```#T(P(`-P```#LD`@`S````<R0"`#8```"G)`(`+P```-XD`@`N````
M#B4"`&@````])0(`90```*8E`@!G````#"8"`&4```!T)@(`9P```-HF`@!O
M````0B<"`#\```"R)P(`9````/(G`@!#````5R@"`"\```";*`(`30```,LH
M`@!$````&2D"`$H```!>*0(`,P```*DI`@`X````W2D"`&X````6*@(`+@``
M`(4J`@`M````M"H"`(@```#B*@(`8@```&LK`@`/`0``SBL"`$X```#>+`(`
M-````"TM`@"+````8BT"`%````#N+0(`$````#\N`@`5````4"X"`!0```!F
M+@(`!P```'LN`@`)````@RX"``@```"-+@(`"@```)8N`@`%````H2X"``4`
M``"G+@(`'@```*TN`@`N````S"X"`"P```#[+@(`*0```"@O`@`N````4B\"
M`!@```"!+P(``0```)HO`@`9````G"\"``H```"V+P(`$0```,$O`@`=````
MTR\"`$T```#Q+P(`+````#\P`@!)````;#`"`"@```"V,`(`*P```-\P`@`7
M````"S$"`!,````C,0(`$````#<Q`@`0````2#$"`!0```!9,0(`!0```&XQ
M`@`H````=#$"`!P```"=,0(`'P```+HQ`@`-````VC$"``T```#H,0(`$P``
M`/8Q`@`-````"C("`"L````8,@(`"P```$0R`@`J````4#("`"L```![,@(`
M"P```*<R`@`/````LS("``P```##,@(`)P```-`R`@`@````^#("`"<````9
M,P(`&@```$$S`@`;````7#,"`!````!X,P(`"@```(DS`@`6````E#,"`#\`
M``"K,P(`+P```.LS`@`=````&S0"``T````Y-`(`(P```$<T`@`6````:S0"
M`!T```""-`(`.0```*`T`@`/````VC0"`!````#J-`(`"P```/LT`@`-````
M!S4"``8````5-0(`&P```!PU`@`V````.#4"`$H```!O-0(`C````+HU`@"#
M````1S8"`!L```#+-@(`)````.<V`@`-````##<"`!,````:-P(`%0```"XW
M`@`-````1#<"`!L```!2-P(`&````&XW`@!-````AS<"`"T```#5-P(`0P``
M``,X`@`C````1S@"``X```!K.`(`#P```'HX`@`;````BC@"`!,```"F.`(`
M"````+HX`@`.````PS@"``X```#2.`(`"0```.$X`@!8````ZS@"`#0```!$
M.0(`%0```'DY`@`T````CSD"`%$```#$.0(`/0```!8Z`@!.````5#H"`&H`
M``"C.@(`:0````X[`@!P````>#L"`&\```#I.P(`0@```%D\`@`/````G#P"
M`!(```"L/`(`#@```+\\`@`3````SCP"``\```#B/`(`!0```/(\`@`!````
M^#P"``8```#Z/`(`$P````$]`@`)````%3T"``\````?/0(`$0```"\]`@`.
M````03T"`"X```!0/0(`!@```'\]`@`'````ACT"`"$```"./0(`(P```+`]
M`@`6````U#T"`!````#K/0(`#@```/P]`@`-````"SX"``8````9/@(`"0``
M`"`^`@`5````*CX"`!D```!`/@(`$0```%H^`@`5````;#X"`!@```""/@(`
M'P```)L^`@`D````NSX"`!H```#@/@(`$````/L^`@`7````##\"`!(````D
M/P(`#P```#<_`@`N````1S\"`"````!V/P(`)````)<_`@`8````O#\"`!P`
M``#5/P(`%````/(_`@`9````!T`"`%D````A0`(`*@```'M``@`J````ID`"
M`"H```#10`(`8P```/Q``@`G````8$$"`",```"(00(`(0```*Q!`@`V````
MSD$"`"D````%0@(`/@```"]"`@`(````;D("`!(```!W0@(`$P```(I"`@!E
M````GD("`&$````$0P(`-P```&9#`@`-````GD,"``@```"L0P(`"P```+5#
M`@`'````P4,"``<```#)0P(`!P```-%#`@`'````V4,"``P```#A0P(`!```
M`.Y#`@`B````\T,"``\````61`(`$P```"9$`@`7````.D0"`%@```!21`(`
M60```*M$`@!"````!44"`$\```!(10(`6````)A%`@!$````\44"`!P````V
M1@(`,````%-&`@`)````A$8"`!@```".1@(`'@```*=&`@`C````QD8"`!$`
M``#J1@(`%````/Q&`@`2````$4<"`"4````D1P(`!@```$I'`@`8````44<"
M``\```!J1P(`1````'I'`@`C````OT<"`!T```#C1P(`-@````%(`@`'````
M.$@"``8```!`2`(`!P```$=(`@`:````3T@"``@```!J2`(`"@```'-(`@`5
M````?D@"``H```"42`(`$0```)](`@`)````L4@"`!$```"[2`(`#P```,U(
M`@`4````W4@"`#(```#R2`(`/0```"5)`@`:````8TD"``<```!^20(`$@``
M`(9)`@`%````F4D"`!8```"?20(`'@```+9)`@`/````U4D"`#0```#E20(`
M2P```!I*`@`D````9DH"`#\```"+2@(`00```,M*`@`\````#4L"`#L```!*
M2P(`+````(9+`@`R````LTL"`$$```#F2P(`10```"A,`@!!````;DP"``D`
M``"P3`(`!P```+I,`@`3````PDP"``\```#63`(`!````.9,`@`%````ZTP"
M``D```#Q3`(`$````/M,`@`*````#$T"`!0````730(`"0```"Q-`@`\````
M-DT"`!4```!S30(`!@```(E-`@`/````D$T"`#P```"@30(`$````-U-`@!#
M````[DT"`$,````R3@(`!0```'9.`@`H````?$X"``8```"E3@(`+0```*Q.
M`@`R````VDX"`#$````-3P(`,````#]/`@`-````<$\"``<```!^3P(`"0``
M`(9/`@`&````D$\"``D```"73P(`!P```*%/`@`[````J4\"`#L```#E3P(`
M.@```"%0`@!?````7%`"`#D```"\4`(`-@```/90`@`Y````+5$"`#D```!G
M40(`2P```*%1`@`M````[5$"`#`````;4@(`.0```$Q2`@`_````AE("`!4`
M``#&4@(`&0```-Q2`@`R````]E("`"8````I4P(`=P```%!3`@`@````R%,"
M`!,```#I4P(`$@```/U3`@`*````$%0"`!`````;5`(`#P```"Q4`@`.````
M/%0"``4```!+5`(`#````%%4`@`>````7E0"`",```!]5`(`!@```*%4`@`%
M````J%0"`!4```"N5`(`"P```,14`@`(````T%0"``H```#95`(``P```.14
M`@`,````Z%0"``<```#U5`(`!@```/U4`@!#````!%4"``4```!(50(`!P``
M`$Y5`@`%````5E4"``L```!<50(`"P```&A5`@`R````=%4"`!<```"G50(`
M#0```+]5`@!(````S54"``4````65@(`!P```!Q6`@`'````)%8"``H````L
M5@(`!0```#=6`@`3````/58"``8```!15@(`$@```%A6`@`%````:U8"`"D`
M``!Q5@(`"````)M6`@`$````I%8"``L```"I5@(`!@```+56`@`E````O%8"
M`!$```#B5@(`*P```/16`@`>````(%<"``@````_5P(`#@```$A7`@`-````
M5U<"``<```!E5P(``P```&U7`@`#````<5<"`!H```!U5P(`(````)!7`@`'
M````L5<"`"L```"Y5P(`"@```.57`@`%````\%<"``@```#V5P(`"````/]7
M`@`^````"%@"`#\```!'6`(`80```(=8`@!>````Z5@"`"@```!(60(`!@``
M`'%9`@`(````>%D"`!$```"!60(`'P```)-9`@!)````LUD"`"0```#]60(`
M+P```"):`@`R````4EH"`"8```"%6@(`)@```*Q:`@!=````TUH"`#X````Q
M6P(`%P```'!;`@`'````B%L"`!(```"06P(`#````*-;`@`"````L%L"`!``
M``"S6P(`&````,1;`@`7````W5L"`!@```#U6P(`&`````Y<`@`)````)UP"
M`!4````Q7`(`!P```$=<`@`9````3UP"`!L```!I7`(`&0```(5<`@`3````
MGUP"`!@```"S7`(`$@```,Q<`@`)````WUP"``<```#I7`(`#````/%<`@`-
M````_EP"`&@````,70(`/@```'5=`@!;````M%T"`&(````07@(`"0```'->
M`@`5````?5X"`!4```"37@(`+0```*E>`@`1````UUX"`$,```#I7@(`,@``
M`"U?`@`V````8%\"`!(```"77P(`&@```*I?`@`=````Q5\"`!D```#C7P(`
M!@```/U?`@`L````!&`"`#\````Q8`(`%P```'%@`@`=````B6`"`!(```"G
M8`(`'@```+I@`@`R````V6`"`$(````,80(`3P```$]A`@`-````GV$"`"P`
M``"M80(`)P```-IA`@`=`````F("``8````@8@(`'````"=B`@`>````1&("
M`!H```!C8@(`&@```'YB`@`+````F6("`&````"E8@(`*0````9C`@`S````
M,&,"`#P```!D8P(`+P```*%C`@`T````T6,"`$D````&9`(`)@```%!D`@`A
M````=V0"`%X```"99`(`%0```/AD`@!!````#F4"`$@```!090(`$P```)EE
M`@`_````K64"`#,```#M90(`!@```"%F`@`-````*&8"`!(````V9@(`#0``
M`$EF`@`&````5V8"``\```!>9@(`"````&YF`@`5````=V8"``@```"-9@(`
M#````)9F`@`3````HV8"``P```"W9@(`%@```,1F`@`1````VV8"`!4```#M
M9@(`!0````-G`@`3````"6<"``8````=9P(`$0```"1G`@`(````-F<"`!,`
M```_9P(``@```%-G`@`'````5F<"`!,```!>9P(`$@```')G`@`)````A6<"
M``H```"/9P(`"0```)IG`@`*````I&<"``<```"O9P(`!P```+=G`@`(````
MOV<"``@```#(9P(`#0```-%G`@`;````WV<"`"@```#[9P(`30```"1H`@`,
M````<F@"``@```!_:`(`"0```(AH`@`:````DF@"`"(```"M:`(`#0```-!H
M`@`M````WF@"`$0````,:0(`&````%%I`@`>````:FD"`!X```"):0(`#P``
M`*AI`@`0````N&D"`#````#):0(`/P```/II`@`A````.FH"`!X```!<:@(`
M/````'MJ`@`H````N&H"``X```#A:@(`"0```/!J`@`C````^FH"`"8````>
M:P(`1````$5K`@`R````BFL"``H```"]:P(`#@```,AK`@`&````UVL"``\`
M``#>:P(`$0```.YK`@`6`````&P"``@````7;`(`#P```"!L`@`7````,&P"
M`!P```!(;`(`+@```&5L`@`L````E&P"`#````#!;`(`+P```/)L`@`I````
M(FT"`"D```!,;0(`)@```'9M`@`Y````G6T"`"(```#7;0(`,````/IM`@!"
M````*VX"`"0```!N;@(`,0```)-N`@`R````Q6X"`"4```#X;@(`,@```!YO
M`@`^````46\"`#D```"0;P(`3@```,IO`@`U````&7`"`#T```!/<`(`-0``
M`(UP`@`U````PW`"`#@```#Y<`(`0P```#)Q`@`D````=G$"`!8```";<0(`
M3P```+)Q`@`I`````G("`!H````L<@(`.P```$=R`@`B````@W("`!@```"F
M<@(`U0```+]R`@`:````E7,"`"T```"P<P(`,````-YS`@`Q````#W0"`#(`
M``!!=`(`*0```'1T`@`6````GG0"`"X```"U=`(`-P```.1T`@`Z````''4"
M`#T```!7=0(`.@```)5U`@":````T'4"`"L```!K=@(`'P```)=V`@`H````
MMW8"`#<```#@=@(`-@```!AW`@!6````3W<"`%D```"F=P(`#0````!X`@`$
M````#G@"``8````3>`(`!0```!IX`@`+````('@"``P````L>`(`$P```#EX
M`@`0````37@"`!$```!>>`(`'````'!X`@`A````C7@"``X```"O>`(`*@``
M`+YX`@`<````Z7@"`'<````&>0(`$````'YY`@`5````CWD"`!L```"E>0(`
M%````,%Y`@`1````UGD"`!8```#H>0(`"0```/]Y`@`.````"7H"``\````8
M>@(`%````"AZ`@`1````/7H"``T```!/>@(`/@```%UZ`@`G````G'H"`"\`
M``#$>@(`!@```/1Z`@`1````^WH"`!,````->P(`$0```"%[`@`7````,WL"
M`!L```!+>P(`#P```&=[`@`"````=WL"``L```!Z>P(`!0```(9[`@`<````
MC'L"``0```"I>P(`$````*Y[`@`0````OWL"``,```#0>P(`#P```-1[`@`(
M````Y'L"`!````#M>P(`"0```/Y[`@`*````"'P"`!(````3?`(`"P```"9\
M`@`/````,GP"`!$```!"?`(`%@```%1\`@`6````:WP"`!T```""?`(`$0``
M`*!\`@`*````LGP"``D```"]?`(`!P```,=\`@`8````SWP"`!@```#H?`(`
M$`````%]`@`-````$GT"`!$````@?0(`'````#)]`@`5````3WT"`!H```!E
M?0(`#@```(!]`@`.````CWT"`"0```">?0(`-@```,-]`@`9````^GT"`#4`
M```4?@(`.0```$I^`@`:````A'X"`#@```"??@(`#0```-A^`@`?````YGX"
M`#L````&?P(`&0```$)_`@`8````7'\"`#8```!U?P(`"````*Q_`@`3````
MM7\"`"<```#)?P(`%````/%_`@`=````!H`"`!(````D@`(`"0```#>``@`.
M````08`"`"H```!0@`(`"P```'N``@`3````AX`"``D```";@`(`"````*6`
M`@`P````KH`"`#L```#?@`(`#P```!N!`@`0````*X$"`"$````\@0(`$@``
M`%Z!`@`0````<8$"`",```""@0(`(P```*:!`@`*````RH$"``P```#5@0(`
M'````.*!`@`6````_X$"`"T````6@@(`'@```$2"`@`6````8X("`!<```!Z
M@@(`'````)*"`@!`````KX("`#````#P@@(`"@```"&#`@`9````+(,"``<`
M``!&@P(`#P```$Z#`@`R````7H,"``L```"1@P(`*@```)V#`@`C````R(,"
M`!@```#L@P(`2@````6$`@`(````4(0"`!0```!9A`(`!0```&Z$`@`'````
M=(0"``H```!\A`(`'@```(>$`@`O````IH0"`!````#6A`(`'@```.>$`@`W
M````!H4"`!L````^A0(`"````%J%`@`2````8X4"`!,```!VA0(`$P```(J%
M`@`&````GH4"`!,```"EA0(`'P```+F%`@`#````V84"``,```#=A0(`*P``
M`.&%`@`4````#88"``8````BA@(`$@```"F&`@`,````/(8"``X```!)A@(`
M#````%B&`@`1````988"`!$```!WA@(`%P```(F&`@`4````H88"`"<```"V
MA@(`$P```-Z&`@`1````\H8"`!D````$AP(`%P```!Z'`@`8````-H<"`"(`
M``!/AP(`3@```'*'`@`9````P8<"``@```#;AP(`!@```.2'`@`8````ZX<"
M``L````$B`(``@```!"(`@`3````$X@"`!$````GB`(`'P```#F(`@`8````
M68@"`!(```!RB`(`*0```(6(`@`2````KX@"`!T```#"B`(`&````."(`@`.
M````^8@"``\````(B0(`#P```!B)`@`5````*(D"`!\````^B0(`(@```%Z)
M`@`^````@8D"`!\```#`B0(`,@```.")`@`6````$XH"``,````JB@(`'```
M`"Z*`@`/````2XH"`!4```!;B@(`"@```'&*`@`/````?(H"`!<```",B@(`
MH@```*2*`@`>````1XL"`"<```!FBP(`+P```(Z+`@`X````OHL"`"H```#W
MBP(`$0```"*,`@!-````-(P"`#\```""C`(`$````,*,`@`2````TXP"``0`
M``#FC`(`'````.N,`@`H````"(T"`!8````QC0(`!@```$B-`@`4````3XT"
M`"@```!DC0(`!0```(V-`@`&````DXT"`!P```":C0(`#P```+>-`@`.````
MQXT"`!````#6C0(`#@```.>-`@`,````]HT"``X````#C@(`"P```!*.`@`0
M````'HX"``@````OC@(`"P```#B.`@`(````1(X"``T```!-C@(`&````%N.
M`@`.````=(X"``X```"#C@(`%0```)*.`@!(````J(X"`$8```#QC@(`"@``
M`#B/`@`,````0X\"`#\```!0CP(`$0```)"/`@`(````HH\"`!,```"KCP(`
M%0```+^/`@`K````U8\"``P````!D`(`)P````Z0`@`B````-I`"`"$```!9
MD`(`&````'N0`@`:````E)`"`"4```"OD`(`&0```-60`@`#````[Y`"`!D`
M``#SD`(`"P````V1`@`+````&9$"``,````ED0(`"0```"F1`@`(````,Y$"
M``H````\D0(`"P```$>1`@`A````4Y$"`"````!UD0(`(````):1`@`=````
MMY$"`!$```#5D0(`)@```.>1`@`1````#I("``T````@D@(`"````"Z2`@`0
M````-Y("``0```!(D@(`!P```$V2`@`@````59("`"$```!VD@(`$P```)B2
M`@`/````K)("`!,```"\D@(`%P```-"2`@`N````Z)("`!,````7DP(`&@``
M`"N3`@`F````1I,"`#0```!MDP(`!P```**3`@`1````JI,"`!T```"\DP(`
M"````-J3`@`)````XY,"`!````#MDP(`'P```/Z3`@`/````'I0"`!`````N
ME`(`"P```#^4`@`(````2Y0"``D```!4E`(`"P```%Z4`@`(````:I0"`!8`
M``!SE`(`'0```(J4`@`/````J)0"`!````"XE`(`$````,F4`@`<````VI0"
M`!X```#WE`(`#````!:5`@`&````(Y4"`"D````JE0(`#@```%25`@")````
M8Y4"`!T```#ME0(`)P````N6`@`'````,Y8"``4````[E@(`#0```$&6`@`%
M````3Y8"``<```!5E@(`!@```%V6`@`*````9)8"``P```!OE@(`%````'R6
M`@`:````D98"``@```"LE@(`)````+66`@`3````VI8"``(```#NE@(`"```
M`/&6`@`2````^I8"`!4````-EP(`'@```".7`@`6````0I<"`!0```!9EP(`
M'P```&Z7`@`/````CI<"`!(```">EP(`)P```+&7`@`#````V9<"``(```#=
MEP(`"P```."7`@`#````[)<"`!(```#PEP(`"0````.8`@`-````#9@"``<`
M```;F`(`!````".8`@`%````*)@"`!X````NF`(`$@```$V8`@`@````8)@"
M``@```"!F`(`$P```(J8`@`-````GI@"`!4```"LF`(`#0```,*8`@`@````
MT)@"``<```#QF`(`'0```/F8`@`Q````%YD"``\```!)F0(`$0```%F9`@`)
M````:YD"``P```!UF0(``@```(*9`@`0````A9D"`#T```"6F0(`!0```-29
M`@`/````VID"`!````#JF0(`$@```/N9`@`&````#IH"`!(````5F@(`"P``
M`"B:`@`'````-)H"`!<````\F@(`)@```%2:`@`3````>YH"``8```"/F@(`
M"0```)::`@`$````H)H"`!8```"EF@(`"````+R:`@`6````Q9H"`!8```#<
MF@(`$````/.:`@`%````!)L"``P````*FP(`(````!>;`@`$````.)L"``0`
M```]FP(`%P```$*;`@!%````6IL"`$8```"@FP(`10```.>;`@`E````+9P"
M`!(```!3G`(`$P```&:<`@`'````>IP"``D```""G`(`"@```(R<`@`6````
MEYP"`!````"NG`(`%0```+^<`@`&````U9P"``4```#<G`(`%````.*<`@`%
M````]YP"`)P```#]G`(`"@```)J=`@`>````I9T"`",```#$G0(`"0```.B=
M`@`E````\IT"`!(````8G@(`%P```"N>`@`3````0YX"``0```!7G@(`#P``
M`%R>`@`+````;)X"`#,```!XG@(`!0```*R>`@`<````LIX"``0```#/G@(`
M$````-2>`@`0````Y9X"`!8```#VG@(`#`````V?`@`%````&I\"`!H````@
MGP(`,@```#N?`@`W````;I\"`$````"FGP(`+````.>?`@`R````%*`"`$$`
M``!'H`(`2@```(F@`@`Q````U*`"`$4````&H0(`-0```$RA`@`W````@J$"
M`"<```"ZH0(`$````.*A`@`5````\Z$"``L````)H@(`*````!6B`@`<````
M/J("`"````!;H@(`(0```'RB`@`?````GJ("`"T```"^H@(`"````.RB`@`*
M````]:("``H`````HP(`%`````NC`@`$````(*,"`",````EHP(`*0```$FC
M`@`G````<Z,"`#````";HP(`#@```,RC`@`J````VZ,"`!X````&I`(`#0``
M`"6D`@`K````,Z0"``<```!?I`(`"P```&>D`@`9````<Z0"`"D```"-I`(`
M&@```+>D`@`4````TJ0"`!0```#GI`(`#0```/RD`@`0````"J4"`!,````;
MI0(`1````"^E`@`]````=*4"`'T```"RI0(`@@```#"F`@`'````LZ8"``P`
M``"[I@(`$P```,BF`@`-````W*8"``X```#JI@(`$0```/FF`@`2````"Z<"
M`!8````>IP(`!P```#6G`@`(````/:<"``X```!&IP(`%@```%6G`@`2````
M;*<"`!(```!_IP(`'@```)*G`@`B````L:<"`"(```#4IP(`)0```/>G`@`6
M````':@"`!H````TJ`(`'0```$^H`@`5````;:@"`!4```"#J`(`*0```)FH
M`@`2````PZ@"``H```#6J`(`%0```.&H`@`>````]Z@"`!,````6J0(`$@``
M`"JI`@`0````/:D"`!4```!.J0(`!P```&2I`@`T````;*D"`"@```"AJ0(`
M+````,JI`@`L````]ZD"`&T````DJ@(`%0```)*J`@`2````J*H"`!@```"[
MJ@(`%@```-2J`@`*````ZZH"``H```#VJ@(`(0````&K`@`C````(ZL"`"@`
M``!'JP(`*````'"K`@`=````F:L"``@```"WJP(`%@```,"K`@`9````UZL"
M``X```#QJP(`)P````"L`@`G````**P"`!\```!0K`(`#@```'"L`@`5````
M?ZP"`!4```"5K`(`*@```*NL`@`I````UJP"`"D`````K0(`*````"JM`@`G
M````4ZT"`"D```![K0(`&@```*6M`@!5````P*T"`!,````6K@(`%0```"JN
M`@`5````0*X"`!0```!6K@(`$0```&NN`@`7````?:X"`!<```"5K@(`%```
M`*VN`@`3````PJX"`#H```#6K@(`&````!&O`@`9````*J\"`#X```!$KP(`
M%0```(.O`@`'````F:\"`!$```"AKP(`,0```+.O`@`1````Y:\"`!P```#W
MKP(`(````!2P`@`3````-;`"`!,```!)L`(`'@```%VP`@`Z````?+`"`"(`
M``"WL`(`'0```-JP`@`;````^+`"``X````4L0(`&@```".Q`@`B````/K$"
M`!(```!AL0(`'````'2Q`@`A````D;$"`!P```"SL0(`&````-"Q`@`C````
MZ;$"`",````-L@(`&P```#&R`@`3````3;("`!L```!AL@(`'````'VR`@`<
M````FK("`!@```"WL@(`"@```-"R`@`(````V[("`!H```#DL@(`$P```/^R
M`@`4````$[,"``L````HLP(`%````#2S`@`0````2;,"``<```!:LP(`!P``
M`&*S`@`2````:K,"``<```!]LP(`!P```(6S`@`%````C;,"`!4```"3LP(`
M!@```*FS`@`;````L+,"``4```#,LP(`!0```-*S`@`*````V+,"``<```#C
MLP(`"@```.NS`@`5````]K,"`!0````,M`(``@```"&T`@`8````)+0"`!4`
M```]M`(`$P```%.T`@`L````9[0"`!,```"4M`(`$````*BT`@`:````N;0"
M`!0```#4M`(`#0```.FT`@`3````][0"`#$````+M0(`.@```#VU`@`T````
M>+4"``8```"MM0(`"0```+2U`@`G````OK4"`!,```#FM0(`$````/JU`@`&
M````"[8"`!,````2M@(`"P```":V`@`&````,K8"`"$````YM@(`$@```%NV
M`@`=````;K8"``T```",M@(`$@```)JV`@`4````K;8"`!(```#"M@(`&```
M`-6V`@`5````[K8"`!0````$MP(``P```!FW`@`*````';<"`"$````HMP(`
M!@```$JW`@`(````4;<"`!4```!:MP(`$@```'"W`@`&````@[<"`!,```"*
MMP(`!P```)ZW`@`S````IK<"``P```#:MP(`$P```.>W`@`)````^[<"`!(`
M```%N`(`%0```!BX`@`1````+K@"`!4```!`N`(`#0```%:X`@`$````9+@"
M``H```!IN`(`!P```'2X`@`4````?+@"`$D```"1N`(`(@```-NX`@`(````
M_K@"`!@````'N0(`#P```""Y`@`E````,+D"`!4```!6N0(`&````&RY`@`.
M````A;D"`)$```"4N0(`$````":Z`@`.````-[H"``L```!&N@(`#0```%*Z
M`@`3````8+H"`!,```!TN@(`%P```(BZ`@`5````H+H"`"P```"VN@(`"P``
M`..Z`@`5````[[H"`!D````%NP(`#0```!^[`@`3````+;L"``P```!!NP(`
M&@```$Z[`@`%````:;L"``8```!ONP(`#````':[`@`$````@[L"``8```"(
MNP(`$@```(^[`@!6````HKL"`!8```#YNP(`"P```!"\`@`$````'+P"``4`
M```AO`(`$````">\`@`8````.+P"`!D```!1O`(`&@```&N\`@`*````AKP"
M``H```"1O`(``@```)R\`@`$````G[P"`",```"DO`(``P```,B\`@`%````
MS+P"`"@```#2O`(`$0```/N\`@`*````#;T"``4````8O0(`!P```!Z]`@`8
M````)KT"`!,````_O0(`.0```%.]`@`,````C;T"`!\```":O0(`$0```+J]
M`@!1````S+T"`!(````>O@(`!@```#&^`@`'````.+X"``@```!`O@(`!```
M`$F^`@`%````3KX"`&0```!4O@(`"@```+F^`@`-````Q+X"``4```#2O@(`
M!@```-B^`@`M````W[X"`"\````-OP(`#````#V_`@`\````2K\"`"@```"'
MOP(`&@```+"_`@`9````R[\"`#@```#EOP(`#@```![``@`)````+<`"`!8`
M```WP`(`%@```$[``@`7````9<`"``H```!]P`(`"````(C``@`9````D<`"
M`"\```"KP`(`*0```-O``@`H````!<$"`!D````NP0(`$@```$C!`@`A````
M6\$"`"@```!]P0(`!````*;!`@`'````J\$"``@```"SP0(`%P```+S!`@`8
M````U,$"`!,```#MP0(`$@````'"`@`7````%,("`"$````LP@(`!P```$["
M`@`7````5L("``T```!NP@(`#````'S"`@`V````B<("`!\```#`P@(`,0``
M`.#"`@`E````$L,"``@````XPP(`$P```$'#`@`0````5<,"`!,```!FPP(`
M$0```'K#`@`3````C,,"`!@```"@PP(`60```+G#`@`8````$\0"`!$````L
MQ`(`$@```#[$`@`5````4<0"`!,```!GQ`(`#@```'O$`@`3````BL0"`!H`
M``">Q`(`&````+G$`@`/````TL0"`"H```#BQ`(`,P````W%`@`=````0<4"
M`!````!?Q0(`-0```'#%`@`.````IL4"`!(```"UQ0(`&0```,C%`@!.````
MXL4"`!T````QQ@(`!@```$_&`@`?````5L8"``<```!VQ@(`!@```'[&`@`@
M````A<8"``8```"FQ@(`"0```*W&`@`G````M\8"`"8```#?Q@(`!P````;'
M`@`*````#L<"`"4````9QP(`2P```#_'`@`8````B\<"`!T```"DQP(`%@``
M`,+'`@`"````V<<"``T```#<QP(`"````.K'`@`3````\\<"``D````'R`(`
M#0```!'(`@`&````'\@"``8````FR`(`%````"W(`@`4````0L@"``@```!7
MR`(`"0```&#(`@`+````:L@"``H```!VR`(`"P```('(`@`T````C<@"`!$`
M``#"R`(`#P```-3(`@`2````Y,@"`!,```#WR`(`!0````O)`@`&````$<D"
M`!4````8R0(`%````"[)`@`%````0\D"``8```!)R0(`$````%#)`@`%````
M8<D"`!<```!GR0(`(````'_)`@`6````H,D"`!$```"WR0(`#0```,G)`@`,
M````U\D"`!0```#DR0(`$````/G)`@`1````"LH"``0````<R@(`!````"'*
M`@`H````)LH"`!0```!/R@(`!0```&3*`@`0````:LH"``4```![R@(`%P``
M`('*`@`3````F<H"`!0```"MR@(`'````,+*`@`A````W\H"`!D````!RP(`
M&0```!O+`@`=````-<L"`"(```!3RP(`'````';+`@`$````D\L"``4```"8
MRP(`%````)[+`@`$````L\L"``X```"XRP(`#@```,?+`@`*````ULL"``T`
M``#ARP(`"````._+`@`B````^,L"``T````;S`(`#P```"G,`@`4````.<P"
M``@```!.S`(`$@```%?,`@`'````:LP"`!````!RS`(`$````(/,`@`.````
ME,P"``\```"CS`(`"````+/,`@`6````O,P"`!(```#3S`(`'````.;,`@`%
M`````\T"``0````)S0(``P````[-`@`>````$LT"``\````QS0(`&````$'-
M`@`0````6LT"`"8```!KS0(`(````)+-`@`5````L\T"`"4```#)S0(`+P``
M`._-`@`8````'\X"`%$````XS@(`/P```(K.`@`>````RLX"`"0```#IS@(`
M00````[/`@`1````4,\"`#X```!BSP(`+@```*'/`@`<````T,\"`#H```#M
MSP(`2@```"C0`@!7````<]`"`%P```#+T`(`$````"C1`@`B````.=$"`#H`
M``!<T0(`1P```)?1`@`5````W]$"`",```#UT0(`+P```!G2`@`>````2=("
M`"$```!HT@(`(P```(K2`@`A````KM("`!X```#0T@(`(P```._2`@`;````
M$],"`!\````OTP(`*P```$_3`@`9````>],"`!L```"5TP(`$P```+'3`@`Y
M````Q=,"`#D```#_TP(`/0```#G4`@`Y````=]0"`#H```"QU`(`.P```.S4
M`@`X````*-4"`'$```!AU0(`'0```-/5`@`T````\=4"`#0````FU@(`-```
M`%O6`@`*````D-8"``D```";U@(`-@```*76`@`9````W-8"``T```#VU@(`
M,`````37`@`>````-=<"`#L```!4UP(`*0```)#7`@`+````NM<"`$L```#&
MUP(`1@```!+8`@`0````6=@"``<```!JV`(`%P```'+8`@`5````BM@"``\`
M``"@V`(`!@```+#8`@`0````M]@"`!<```#(V`(`$````.#8`@`/````\=@"
M``X````!V0(`#````!#9`@`,````'=D"``X````JV0(`"P```#G9`@`3````
M1=D"`!<```!9V0(`%P```''9`@`1````B=D"`!T```";V0(`#````+G9`@`.
M````QMD"`"8```#5V0(`!0```/S9`@`C`````MH"``0````FV@(`"````"O:
M`@`&````--H"`!0````[V@(`$0```%#:`@!L````8MH"`&````#/V@(`$```
M`##;`@!2````0=L"``(```"4VP(``@```)?;`@`'````FML"`!(```"BVP(`
M(````+7;`@`%````UML"``<```#<VP(`&P```.3;`@`(`````-P"`!$````)
MW`(`/0```!O<`@`0````6=P"`#(```!JW`(`+````)W<`@`6````RMP"`#(`
M``#AW`(`.````!3=`@!V````3=T"``P```#$W0(`"P```-'=`@`5````W=T"
M`$X```#SW0(`#````$+>`@`B````3]X"`!$```!RW@(`%0```(3>`@`&````
MFMX"``P```"AW@(`!P```*[>`@`.````MMX"``L```#%W@(`%@```-'>`@`+
M````Z-X"`!P```#TW@(`&````!'?`@`%````*M\"`!(````PWP(`&````$/?
M`@`-````7-\"`!(```!JWP(`)0```'W?`@`#````H]\"`!8```"GWP(`&@``
M`+[?`@`5````V=\"``T```#OWP(`10```/W?`@`.````0^`"``T```!2X`(`
M'0```&#@`@!!````?N`"`!$```#`X`(`&@```-+@`@`^````[>`"`#<````L
MX0(`&P```&3A`@`8````@.$"`"(```"9X0(`(P```+SA`@`J````X.$"`#``
M```+X@(`,````#SB`@!D````;>("`%T```#2X@(`T@```##C`@`*`````^0"
M``P````.Y`(`%````!OD`@`3````,.0"``P```!$Y`(`#@```%'D`@`+````
M8.0"`!,```!LY`(`!````(#D`@`C````A>0"``X```"IY`(`*@```+CD`@`>
M````X^0"``T````"Y0(`#0```!#E`@`*````'N4"``\````IY0(`)@```#GE
M`@`D````8.4"`!\```"%Y0(`$@```*7E`@`7````N.4"``8```#0Y0(`$```
M`-?E`@`5````Z.4"``@```#^Y0(`%@````?F`@`+````'N8"`!<````JY@(`
M*P```$+F`@`,````;N8"`"````![Y@(`'0```)SF`@`-````NN8"`!@```#(
MY@(`,0```.'F`@`=````$^<"``X````QYP(`#P```$#G`@`D````4.<"``4`
M``!UYP(`$0```'OG`@`'````C><"`!8```"5YP(`!P```*SG`@`+````M.<"
M`"````#`YP(`-P```.'G`@`)````&>@"`"(````CZ`(`&P```$;H`@`-````
M8N@"`#<```!PZ`(`!P```*CH`@`4````L.@"`"X```#%Z`(`*@```/3H`@`K
M````'^D"`"T```!+Z0(`!````'GI`@`4````?ND"``D```"3Z0(`"````)WI
M`@`+````IND"``X```"RZ0(`!@```,'I`@!!````R.D"`",````*Z@(`"@``
M`"[J`@`A````.>H"`#\```!;Z@(`0````)OJ`@`D````W.H"`"T````!ZP(`
M*@```"_K`@`J````6NL"`$<```"%ZP(`)````,WK`@`J````\NL"`"$````=
M[`(`AP```#_L`@"*````Q^P"`#(!``!2[0(`,P```(7N`@`H````N>X"`$,`
M``#B[@(`+0```";O`@!A````5.\"`#0```"V[P(`-0```.OO`@!8````(?`"
M`$0```!Z\`(`+@```+_P`@!$````[O`"`$,````S\0(`,````'?Q`@`M````
MJ/$"``<```#6\0(`"````-[Q`@`)````Y_$"`!0```#Q\0(`&P````;R`@`;
M````(O("`#`````^\@(`$````&_R`@`R````@/("`"4```"S\@(`(@```-GR
M`@`L````_/("`#H````I\P(`0@```&3S`@`'````I_,"`!D```"O\P(`"0``
M`,GS`@`(````T_,"`"````#<\P(`$0```/WS`@`/````#_0"`!$````?]`(`
M"````#'T`@`4````.O0"``H```!/]`(`#0```%KT`@`>````:/0"``@```"'
M]`(`%0```)#T`@`)````IO0"`$0```"P]`(`1````/7T`@`/````.O4"``H`
M``!*]0(`#0```%7U`@`:````8_4"`!@```!^]0(`00```)?U`@`[````V?4"
M``H````5]@(`$P```"#V`@`2````-/8"`!````!']@(`)P```%CV`@!&````
M@/8"`"H```#']@(`*@```/+V`@`E````'?<"``\```!#]P(`!@```%/W`@`J
M````6O<"`"0```"%]P(`&P```*KW`@`+````QO<"`!H```#2]P(`$````.WW
M`@`%````_O<"``T````$^`(`$````!+X`@`)````(_@"``P````M^`(`#```
M`#KX`@`.````1_@"``<```!6^`(`&````%[X`@`#````=_@"``T```![^`(`
M-@```(GX`@!(````P/@"``L````)^0(`#@```!7Y`@`,````)/D"``X````Q
M^0(`#0```$#Y`@`6````3OD"`!L```!E^0(`&0```('Y`@`8````F_D"``D`
M``"T^0(`)0```+[Y`@`B````Y/D"`"$````'^@(`$0```"GZ`@`5````._H"
M``H```!1^@(`%P```%SZ`@`+````=/H"`",```"`^@(`'0```*3Z`@`4````
MPOH"`!(```#7^@(`*0```.KZ`@`'````%/L"``T````<^P(`&````"K[`@`.
M````0_L"`!(```!2^P(`"P```&7[`@`\````<?L"``T```"N^P(`"0```+S[
M`@`<````QOL"`!(```#C^P(`%@```/;[`@`1````#?P"`#T````?_`(`-P``
M`%W\`@`7````E?P"``\```"M_`(`"0```+W\`@`1````Q_P"`!(```#9_`(`
M$@```.S\`@`6````__P"`!<````6_0(`$@```"[]`@`D````0?T"`#4```!F
M_0(`+P```)S]`@`.````S/T"`!````#;_0(`"@```.S]`@`6````]_T"`!(`
M```._@(`%P```"'^`@!`````.?X"`!T```!Z_@(`'0```)C^`@`?````MOX"
M`"0```#6_@(`/````/O^`@`Z````./\"`#8```!S_P(`$0```*K_`@`:````
MO/\"``8```#7_P(`%P```-[_`@`<````]O\"`"$````3``,`"@```#4``P`=
M````0``#``L```!>``,`"0```&H``P`2````=``#`"0```"'``,`$````*P`
M`P!4````O0`#``<````2`0,`%0```!H!`P`5````,`$#``D```!&`0,`!P``
M`%`!`P`4````6`$#`!$```!M`0,`&0```'\!`P`%````F0$#``<```"?`0,`
M"0```*<!`P`0````L0$#``\```#"`0,`%0```-(!`P`5````Z`$#``<```#^
M`0,`!@````8"`P`Q````#0(#`"D````_`@,`)0```&D"`P`(````CP(#``\`
M``"8`@,`$P```*@"`P`&````O`(#`!\```##`@,`'0```.,"`P`>`````0,#
M`!`````@`P,`1````#$#`P`1````=@,#`!````"(`P,`(````)D#`P!%````
MN@,#`#@`````!`,`+````#D$`P`>````9@0#`#P```"%!`,`&P```,($`P`E
M````W@0#`#,````$!0,`8````#@%`P!H````F04#`%P````"!@,`U0```%\&
M`P`?````-0<#``T```!5!P,`#````&,'`P`#````<`<#``<```!T!P,`#0``
M`'P'`P`(````B@<#``(```"3!P,`%0```)8'`P`-````K`<#``P```"Z!P,`
M$0```,<'`P`+````V0<#`!0```#E!P,`&````/H'`P`5````$P@#`!P````I
M"`,`(P```$8(`P`3````:@@#`!8```!^"`,`#@```)4(`P`&````I`@#``H`
M``"K"`,`#````+8(`P`]````PP@#`!`````!"0,`#@```!()`P`1````(0D#
M``P````S"0,`'P```$`)`P!:````8`D#`$@```"["0,`(P````0*`P`;````
M*`H#`!@```!$"@,`+````%T*`P`P````B@H#`!4```"["@,`!P```-$*`P`(
M````V0H#``L```#B"@,`$@```.X*`P`5`````0L#`"L````7"P,`)````$,+
M`P`$````:`L#``L```!M"P,`%@```'D+`P`4````D`L#`!,```"E"P,`$P``
M`+D+`P`A````S0L#`!@```#O"P,`%@````@,`P`D````'PP#`$X```!$#`,`
M$````),,`P`H````I`P#`$(```#-#`,`%````!`-`P`5````)0T#`!,````[
M#0,`7P```$\-`P`A````KPT#`!T```#1#0,`+0```.\-`P`=````'0X#`",`
M```[#@,`'0```%\.`P`D````?0X#`"````"B#@,`(@```,,.`P`B````Y@X#
M`"\````)#P,`&````#D/`P`/````4@\#`!T```!B#P,`"@```(`/`P`M````
MBP\#`!0```"Y#P,`"0```,X/`P`;````V`\#`!P```#T#P,`"````!$0`P`3
M````&A`#``\````N$`,`"````#X0`P`D````1Q`#`"L```!L$`,`"0```)@0
M`P`5````HA`#``@```"X$`,`8````,$0`P!,````(A$#`#@```!O$0,`/P``
M`*@1`P!0````Z!$#`'`````Y$@,`"@```*H2`P`E````M1(#`"\```#;$@,`
M"0````L3`P`0````%1,#`"<````F$P,`0````$X3`P`'````CQ,#``T```"7
M$P,`/@```*43`P!X````Y!,#`$X```!=%`,`E0```*P4`P!,````0A4#``<`
M``"/%0,`%P```)<5`P`;````KQ4#`!$```#+%0,`'````-T5`P`G````^A4#
M`"`````B%@,`%@```$,6`P!"````6A8#`$D```"=%@,`+0```.<6`P`P````
M%1<#`"<```!&%P,`#@```&X7`P`O````?1<#`"X```"M%P,`-P```-P7`P`=
M````%!@#`"\````R&`,`$@```&(8`P!!````=1@#`#8```"W&`,`/P```.X8
M`P`N````+AD#`#4```!=&0,`*P```),9`P`4````OQD#``H```#4&0,`$P``
M`-\9`P`6````\QD#`!@````*&@,`"````",:`P`(````+!H#`#$````U&@,`
M"````&<:`P`*````<!H#``H```![&@,`)@```(8:`P`*````K1H#`!<```"X
M&@,`"````-`:`P`6````V1H#``<```#P&@,`$0```/@:`P`1````"AL#``H`
M```<&P,`%@```"<;`P`$````/AL#``4```!#&P,`!@```$D;`P`/````4!L#
M`!(```!@&P,`$````',;`P`=````A!L#``T```"B&P,`!P```+`;`P`0````
MN!L#`!4```#)&P,`$P```-\;`P`2````\QL#`!X````&'`,`(````"4<`P`3
M````1AP#`!0```!:'`,`&0```&\<`P`@````B1P#`!(```"J'`,`#0```+T<
M`P`:````RQP#`"8```#F'`,`#@````T=`P`?````'!T#`"\````\'0,`"0``
M`&P=`P`+````=AT#`!@```""'0,`$````)L=`P`6````K!T#`!````##'0,`
M&0```-0=`P`4````[AT#`!0````#'@,`%0```!@>`P`@````+AX#`#````!/
M'@,`#@```(`>`P`0````CQX#``T```"@'@,`"0```*X>`P`M````N!X#``8`
M``#F'@,`"0```.T>`P`'````]QX#``T```#_'@,`$P````T?`P`&````(1\#
M`!P````H'P,`&````$4?`P`/````7A\#``@```!N'P,`'@```'<?`P`/````
MEA\#`!L```"F'P,`%P```,(?`P`,````VA\#``(```#G'P,`"````.H?`P`'
M````\Q\#`!````#['P,`"`````P@`P!N````%2`#`!,```"$(`,`$````)@@
M`P`'````J2`#`"<```"Q(`,`1@```-D@`P`<````("$#`"<````](0,`1```
M`&4A`P`Q````JB$#`$````#<(0,`'````!TB`P`6````.B(#`!(```!1(@,`
M"0```&0B`P`'````;B(#``T```!V(@,`"@```(0B`P`)````CR(#``T```"9
M(@,`$0```*<B`P`/````N2(#``H```#)(@,`#````-0B`P`0````X2(#``<`
M``#R(@,`"````/HB`P`'`````R,#`!0````+(P,`%````"`C`P`/````-2,#
M`!L```!%(P,`&P```&$C`P`?````?2,#``4```"=(P,`)0```*,C`P`5````
MR2,#``H```#?(P,`%````.HC`P`+````_R,#`!0````+)`,`"P```"`D`P`&
M````+"0#`!8````S)`,`%@```$HD`P`'````820#``<```!I)`,`&0```'$D
M`P`(````BR0#``4```"4)`,`!P```)HD`P`&````HB0#`!(```"I)`,`&P``
M`+PD`P`+````V"0#``T```#D)`,`+0```/(D`P`A````("4#`!@```!")0,`
M"P```%LE`P`=````9R4#`!4```"%)0,`0````)LE`P`%````W"4#``P```#B
M)0,`%````.\E`P`-````!"8#``(````2)@,`$P```!4F`P`2````*28#`!\`
M```\)@,`0````%PF`P`C````G28#`"````#!)@,`-````.(F`P`Q````%R<#
M`!L```!))P,`-0```&4G`P`T````FR<#`"(```#0)P,`&@```/,G`P`:````
M#B@#`"0````I*`,`8@```$XH`P`;````L2@#`!8```#-*`,`)````.0H`P!V
M````"2D#`&X```"`*0,`.P```.\I`P`S````*RH#`#\```!?*@,`40```)\J
M`P!6````\2H#`'$```!(*P,`+0```+HK`P`F````Z"L#`#P````/+`,`*@``
M`$PL`P`D````=RP#`"L```"<+`,`,````,@L`P`P````^2P#`!P````J+0,`
M%@```$<M`P![````7BT#`$````#:+0,`0@```!LN`P`M````7BX#`#D```",
M+@,`)0```,8N`P`F````["X#`#$````3+P,`.@```$4O`P`R````@"\#`+\!
M``"S+P,`*P```',Q`P`?````GS$#`$X```"_,0,`%@````XR`P!6````)3(#
M`$0```!\,@,`2````,$R`P`\````"C,#`"````!',P,`30```&@S`P`M````
MMC,#`!@```#D,P,`&@```/TS`P`I````&#0#`(P```!"-`,`,P```,\T`P!`
M`````S4#`'D```!$-0,`6@```+XU`P!0````&38#`#,```!J-@,`+0```)XV
M`P`I````S#8#`"(```#V-@,`%0```!DW`P"D````+S<#`!T```#4-P,`'0``
M`/(W`P`S````$#@#`"8```!$.`,`*0```&LX`P`J````E3@#`"(```#`.`,`
M'````.,X`P`O`````#D#`"4````P.0,`$P```%8Y`P`F````:CD#`!T```"1
M.0,`,````*\Y`P`;````X#D#`"X```#\.0,`(P```"LZ`P`6````3SH#`#<`
M``!F.@,`*@```)XZ`P!#````R3H#`"@````-.P,`/0```#8[`P`D````=#L#
M`!H```"9.P,`,````+0[`P!B````Y3L#`"T```!(/`,`-@```'8\`P`T````
MK3P#`$4```#B/`,`,@```"@]`P!"````6ST#`#X```">/0,`,@```-T]`P`K
M````$#X#`$<````\/@,`90```(0^`P!:````ZCX#`$8```!%/P,`3@```(P_
M`P!.````VS\#`$0````J0`,`*````&]``P`Q````F$`#`%````#*0`,`'P``
M`!M!`P`N````.T$#`"D```!J00,`+````)1!`P`I````P4$#`$D```#K00,`
M60```#5"`P!3````CT(#`)4```#C0@,`;````'E#`P`Z````YD,#`"P````A
M1`,`7````$Y$`P!:````JT0#`"L````&10,`)P```#)%`P`I````6D4#`%@`
M``"$10,`,@```-U%`P`N````$$8#`!L````_1@,`)P```%M&`P`E````@T8#
M`"4```"I1@,`*P```,]&`P!N````^T8#`&L```!J1P,`P````-9'`P`9````
MET@#`"<```"Q2`,`/@```-E(`P`M````&$D#`%$```!&20,`)P```)A)`P!<
M````P$D#`!X````=2@,`"@```#Q*`P#>````1TH#`#X````F2P,`*P```&5+
M`P!'````D4L#`$D```#92P,`8@```"-,`P!$````ADP#`%````#+3`,`/@``
M`!Q-`P`P````6TT#`#,```",30,`*````,!-`P`E````Z4T#`!(````/3@,`
M.P```").`P`I````7DX#`$(```"(3@,`/0```,M.`P`M````"4\#`"4````W
M3P,`(````%U/`P!(````?D\#`#\```#'3P,`%@````=0`P`(````'E`#``@`
M```G4`,`"0```#!0`P`3````.E`#`!````!.4`,`$@```%]0`P`+````<E`#
M``8```!^4`,`#@```(50`P`$````E%`#``\```"94`,`6@```*E0`P!<````
M!%$#``0```!A40,`$0```&91`P`2````>%$#``@```"+40,`!@```)11`P`.
M````FU$#``0```"J40,`%@```*]1`P`9````QE$#``H```#@40,`"0```.M1
M`P`-````]5$#``X````#4@,`$0```!)2`P`3````)%(#``(````X4@,`%```
M`#M2`P`4````4%(#`!(```!E4@,`#@```'A2`P`5````AU(#``8```"=4@,`
M%@```*12`P`-````NU(#``,```#)4@,`-````,U2`P`$`````E,#`!,````'
M4P,`!P```!M3`P`D````(U,#`%````!(4P,`.0```)E3`P`Z````TU,#`!\`
M```.5`,`)P```"Y4`P`B````5E0#`"8```!Y5`,`*````*!4`P`C````R50#
M`"4```#M5`,`+````!-5`P`G````0%4#`#L```!H50,`(@```*15`P`X````
MQU4#`#0`````5@,`)0```#56`P`I````6U8#`"P```"%5@,`)P```+)6`P`L
M````VE8#`"T````'5P,`-0```#57`P`A````:U<#`"4```"-5P,`*@```+-7
M`P`R````WE<#`"4````16`,`+````#=8`P`;````9%@#`"4```"`6`,`0@``
M`*98`P`F````Z5@#`"H````060,`+0```#M9`P`N````:5D#`"8```"860,`
M'@```+]9`P`D````WED#`"X````#6@,`*P```#):`P`X````7EH#`!T```"7
M6@,`#@```+5:`P`9````Q%H#``D```#>6@,`"@```.A:`P`;````\UH#`!,`
M```/6P,`&0```"-;`P`L````/5L#`",```!J6P,`#0```(Y;`P`D````G%L#
M``\```#!6P,`%@```-%;`P`+````Z%L#`!D```#T6P,`*@````Y<`P`(````
M.5P#``P```!"7`,`$0```$]<`P`4````85P#`!D```!V7`,`(0```)!<`P`R
M````LEP#`!@```#E7`,`*P```/Y<`P`K````*ET#`"0```!670,`%P```'M=
M`P`(````DUT#`.8```"<70,`!P```(->`P`1````BUX#`!\```"=7@,`%@``
M`+U>`P`,````U%X#``D```#A7@,`#0```.M>`P`B````^5X#`"(````<7P,`
M%0```#]?`P`1````55\#`"D```!G7P,`(@```)%?`P`&````M%\#`$4```"[
M7P,`'`````%@`P`=````'F`#`!T````\8`,`"P```%I@`P`3````9F`#`!,`
M``!Z8`,`'P```(Y@`P`)````KF`#`%(```"X8`,`"@````MA`P!3````%F$#
M`"H```!J80,`'0```)5A`P`4````LV$#`!<```#(80,`*````.!A`P`8````
M"6(#``H````B8@,`)````"UB`P`)````4F(#`!0```!<8@,`#````'%B`P`8
M````?F(#`!@```"78@,`%P```+!B`P`(````R&(#`"P```#18@,`"0```/YB
M`P`I````"&,#`"@````R8P,`!P```%MC`P`;````8V,#``<```!_8P,`"```
M`(=C`P`)````D&,#`#P```":8P,`!@```-=C`P`3````WF,#`!0```#R8P,`
M#@````=D`P`)````%F0#``H````@9`,`(````"MD`P`3````3&0#``H```!@
M9`,`#0```&MD`P`6````>60#`"<```"09`,`&P```+AD`P`;````U&0#``P`
M``#P9`,`#0```/UD`P`6````"V4#`!(````B90,`'P```#5E`P`B````564#
M``H```!X90,`$P```(-E`P`R````EV4#``H```#*90,`#@```-5E`P`8````
MY&4#`!@```#]90,`+````!9F`P`/````0V8#`"D```!39@,`&0```'UF`P`,
M````EV8#``X```"D9@,`&````+-F`P`$````S&8#`"\```#19@,`#P````%G
M`P`%````$6<#``<````79P,``@```!]G`P`1````(F<#`",````T9P,`"P``
M`%AG`P`#````9&<#``8```!H9P,`#````&]G`P`,````?&<#``\```")9P,`
M$````)EG`P`6````JF<#`!<```#!9P,`!0```-EG`P`O````WV<#`!\````/
M:`,`'@```"]H`P!;````3F@#`$$```"J:`,`1````.QH`P">````,6D#``D`
M``#0:0,`*0```-II`P`,````!&H#``<````1:@,`%P```!EJ`P`^````,6H#
M`!$```!P:@,`$@```()J`P`(````E6H#``0```">:@,`!0```*-J`P`-````
MJ6H#`!H```"W:@,`!@```-)J`P`'````V6H#``D```#A:@,`$0```.MJ`P`(
M````_6H#`!(````&:P,`$@```!EK`P`V````+&L#`#````!C:P,`%````)1K
M`P`9````J6L#`"0```##:P,`(@```.AK`P`E````"VP#`!`````Q;`,``@``
M`$)L`P`$````16P#``L```!*;`,`"@```%9L`P`%````86P#``,```!G;`,`
M#0```&ML`P`]````>6P#`$P```"W;`,`,`````1M`P`H````-6T#`!X```!>
M;0,`*````'UM`P!'````IFT#`!4```#N;0,`&0````1N`P`R````'FX#`"4`
M``!1;@,`1@```'=N`P`Y````OFX#`%(```#X;@,`-````$MO`P!"````@&\#
M`!<```##;P,`%````-MO`P!S````\&\#``\```!D<`,`)@```'1P`P`I````
MFW`#`'8```#%<`,`(@```#QQ`P!.````7W$#`"\```"N<0,`-@```-YQ`P`M
M````%7(#`#T```!#<@,`3P```(%R`P!2````T7(#`"T````D<P,`+P```%)S
M`P`H````@G,#`"D```"K<P,`-````-5S`P`B````"G0#`"<````M=`,`,```
M`%5T`P`R````AG0#`#0```"Y=`,`+0```.YT`P`I````''4#`"P```!&=0,`
M.P```'-U`P`N````KW4#`"L```#>=0,`(`````IV`P!5````*W8#`%L```"!
M=@,`00```-UV`P!!````'W<#`#$```!A=P,`)@```)-W`P`4````NG<#`!``
M``#/=P,`>P```.!W`P`*````7'@#`"0```!G>`,`$P```(QX`P`3````H'@#
M`"T```"T>`,`+0```.)X`P`/````$'D#`%<````@>0,`>````'AY`P!Z````
M\7D#`'D```!L>@,`20```.9Z`P`P````,'L#`&$```!A>P,`%````,-[`P`[
M````V'L#`#P````4?`,`$@```%%\`P`-````9'P#`(,```!R?`,`)P```/9\
M`P`F````'GT#`#D```!%?0,`(@```']]`P`@````HGT#`&L```##?0,`&P``
M`"]^`P`1````2WX#``H```!=?@,`!0```&A^`P`&````;GX#``@```!U?@,`
M!0```'Y^`P`7````A'X#``T```"<?@,`&0```*I^`P`7````Q'X#`"(```#<
M?@,`$````/]^`P`.````$'\#``0````??P,`#````"1_`P`(````,7\#``,`
M```Z?P,`"0```#Y_`P`'````2'\#``@```!0?P,`#@```%E_`P`'````:'\#
M``<```!P?P,`!@```'A_`P`+````?W\#`!<```"+?P,`"````*-_`P`'````
MK'\#``4```"T?P,`&````+I_`P`2````TW\#``<```#F?P,`"P```.Y_`P`)
M````^G\#``H````$@`,`#0````^``P`3````'8`#``H````Q@`,`"0```#R`
M`P`0````1H`#``T```!7@`,`%P```&6``P`)````?8`#``4```"'@`,`"@``
M`(V``P`-````F(`#``T```"F@`,`#0```+2``P`)````PH`#`!````#,@`,`
M!0```-V``P`*````XX`#``4```#N@`,`"@```/2``P`%````_X`#``L````%
M@0,`!0```!&!`P`&````%X$#``H````>@0,`"````"F!`P`,````,H$#``(`
M```_@0,`$P```$*!`P`'````5H$#``(```!>@0,``@```&&!`P`(````9($#
M``@```!M@0,`!0```':!`P`'````?($#`!@```"$@0,`+````)V!`P`"````
MRH$#``0```#-@0,`!@```-*!`P`.````V8$#``X```#H@0,`$````/>!`P`5
M````"((#`!`````>@@,``@```"^"`P`+````,H(#``8````^@@,`!P```$6"
M`P`2````38(#`!(```!@@@,`$@```'."`P`3````AH(#``(```":@@,`!P``
M`)V"`P`0````I8(#`"H```"V@@,`-@```.&"`P`)````&(,#``@````B@P,`
M"P```"N#`P`<````-X,#``4```!4@P,`!@```%J#`P`+````88,#`!$```!M
M@P,`$@```'^#`P`!````B08``)0'``#="```>PD``$<(``!]`P``F0,``!@)
M````````V`$````````X!`````````````!*"@``8P```$@!``#K`P``J@``
M``````#T!0```````#H'``#)`````````"8)``#]"```G`H``(8```!V!0``
MR0H``'X(``!;"```$@@``#@`````````:`$``)L'``!L````-`<``(@$```^
M`0``JP<````````T`0``<0<```````":!P``8`@``!@"``!W`0``CP```$,)
M````````Y`<```\)``!&`````````&T#````````7`8```````#N"```70``
M`#````"F"0````````@```!/!0``SP$``'8*```.`0``3@H``',$````````
M]0D````````\"P``CP4``)$%`````````````!(!````````LP4``.X```#K
M!0```````.L*```E"0```````/P!``#?`P``7`0``$$'``!&!```>P,``),!
M``#M"@``6@<````````+!0``/P4``)T$``!"`@``_P(``(8%````````````
M`!4&``!Y!P```````#`)``"L"0``&@D```````"9"@``D`$``+X#``!B!@``
M%`@``'L$```2!P``A````),'``!O````M00```<!````````WP4``/@&``!<
M`0``E0@````````````````````````L"```J`<```````#*"````````!`"
M``!I`@```````($&````````.0L```````!M!P``%@H``,X(``!,`@``T@4`
M`/`'````````*`4```````"7"@``G@``````````````9P$``&,#``#V````
MV`<``+,$````````Q`$```````#K`@``"`(``!X'````````/@4``-H)```1
M`@``OP```*`'``#?````O`8``+8)````````A`<``+L%``#+`P```````#D$
M``#K`````````!<'````````2@8``-8)``````````````````#G`P``]08`
M`#((``#Z!P``O@$``$('``"L"```W`,````````J"````````",+````````
MZ@4``,,)``#+`````````",(```%`@``A08``,0$``!""@```````.H(```A
M`@``G`D```````#8````-@L``&X'``!#!```=`8``$4)````````#P<``$@(
M``!8`P``FPD``)<```#T`@``H`$``+<*``!!!@```````.0*``"V!P``````
M`&\(``#R!@``Z0@``-\*``!4!```*P```"\#```\`P```````.D&```>"```
M`````/`(`````````````-@&``!:```````````````?!``````````````0
M````C04``$8%``"1`@``S`D`````````````_PH```````!7"0```````(H$
M``!D!```&@<``!X#``!4"@``Q`D``&X&``"I"```V`(``*H&``"&"```'`,`
M``````"5!````````$T'``"`"@``H0```-`$``!Z"0``=`4``"0(``#J`@``
M``````````"(!@``(0$``.8'`````````````)0#``#$!@``E`D`````````
M`````````#\!``!X"```@`<``+8&````````T04``+('````````\@@``/4%
M`````````````+<`````````I`0```````!!"@``VP@``+`*``!Z"```>`,`
M`$,%``!A"```````````````````9P<``.<"```G"@```````,$%``#"`P``
MZ0<``'@&``"`````4@```#8'``"@!@``V`D``-<'```U`@``X`0``!,)``!>
M`P``"@@``#L)``"W"```C0(`````````````Y@0``%X````2"0``U`4``$P(
M``"Q`0``G`4```````!U!@``,00``'8!````````50H``"8'````````=`D`
M``````!$"@``MP,``/X!```1"````````)`'``".`0``OP4``'4*``!'`0``
MV@0``%8#```A!P``V@(``.$!```+`P``)00```````"!"0``@@H``#H!``"8
M"0``M`H``-8#```<!```9PH``&,!```7`````````-8'``!G`@``@`0``*@&
M```/"````````'@*`````````````/<!`````````````!0#````````````
M`*<#``!W!P``0`4```````#-`P``:`0```````!+"```Z`D``#D#````````
M!P(`````````````)@```/L(````````AP8``#`(````````20D``*D#``!A
M`P``Q`@``"X&````````_@H``!$*`````````````.@$```]!@``````````
M``#2"@``9P8``$,'``#W`P``!P<```\$````````(`,`````````````Z`(`
M``H"``!I`P``40(``*@$``#,!0```PH``"X(``!P"@``^P,```````!Z`P``
M`````%X"`````````````&H(```_!P`````````````X!0``!@8``-("````
M`````````'`'``!+`````````*H(```O!@``%@L``(X'````````60,``"$`
M````````70<``#X&``"/"```/@@``````````````````+P'```.````9`$`
M`(($```I!```CPH```````!E`0``3`D``!4'````````40$``*P%```9!@``
MQ@H```````!\"``````````````U!P``500````%```6"0```````/L"``#@
M!0``=`0``",$````````7@<```$)``!;`0``8@```.X'`````````````+0&
M```\````K@0```,"`````````````!4(````````30,``/,"``#.`0``;P4`
M`+L'```=````5P````````"'`P``IP@``%P"``!*!```N`````````#R!```
M.0H````````]"@``0`D``,4!``!W"````````(X#````````W0<``)0$``"6
M!0``9`H``',%``#L!0```````(D'``"K!@``^`H`````````````UPH``*T`
M``!M"0``'`<````````N!P```````-T#``!0!@``)`L``&8%````````````
M`(H(```3`P``K`(``-@*``!-"@``Z`8``+`!`````````````(,%``!A!0``
M`````(L`````````(@0``"P"`````````````"()``!-"0``)0@``'8'```^
M!```!00``$H"``"["@``NP0``"\!````````8@H``/@```"-"0```````',*
M`````````````+0$``#D"0``WP(``#T+```0!0``:P$``"8#``"P"```\PD`
M``````#'!@``7P<``,8(``"[`0``*P(``*L)``"O"0``3PD```$#``#%"```
MDP0````(````````1@H``'@'```-!@``Z````#X+``!5````.@``````````
M````=@0````````M`P```````.\&```\"@``HP<``#`$````````/@D``*8"
M``!]!```1@$```````!Q!@``)0$``*L%``"G!P``H````,4*````````L`8`
M```````5`````0<```````#&`0````````````"D!0```````"D+``"2"@``
MA`,``%8"``#@`@``M`,```````!)"```=`(```````"U`@```````(X&````
M````Q00````````H!````````````````0``B@````<#``!#````3P$``"(%
M```Z"0``+08``'<%```A`P``A`8``#,#``"(````8P4`````````````@@8`
M```````Q"```X`@``-$'``!V````IP8``,0'````````NP```"8&``#D`P``
M1`4``#0)```````````````````K!P``6@@``)H&``#S`P``Q0,````````O
M!0``KPH``*4)````````8@$``(4$``#0`0``M`D``%T)````````````````
M``!.!P``-`0````````/`@``R00``/,'``#/!0```````$0"``#=!0``T@0`
M`!4)`````P``D0H``+<&```M"0``!@````````"X!P```````$($``!U!```
M`````/X```#F!@```````````````````````)`"```6"```H0(``&4```"_
M`@``N@(``"H)```7!0``K@H```````"S!@``SP,``*,"``#G`0``'@4``%$$
M```>"@``\0D``,T'``#Z!@``2@```*8%````!```)08```````#9`P``(P(`
M`-X)```[!0``704``*P&``#R`@``[`@```````#:"@``BP<``/8#````````
MD@$``````````````````$<``````````````!\"``#W!0```````(4"````
M````"@0``*$'``!Z!@``;P<```````"]"@``T@@```D"````````=0<``/X#
M``"M!@``%P,``$T"```)"@```````"D(``"+!0``!PD`````````````40``
M`-8(```C!P``%@0``"L+```W"```7P(``,("``!"!@`````````````(!P``
M^0,``#$&````````9@D``(D$```#!P``0@4````````]````I00``-H'``#G
M!```YP@``"8%``#D`@``G@@``(D*```?!@``4PH``$D$````````7`D``"\`
M````````^@```'`$``"\`0````````@)``!L`0``U@8``(X"````````````
M`(D#````````4P(``(`#``!("0``40@``"8$``!0!0``O`@``"<#``"+"0``
M`````#L#```W!0``S`(``-<#````````UP8``#$%``"!`0``S0$``+@$```#
M"P``:@```&4"``#Q!P``XP8``!D'``#+`@``004```````#_"0```````$P$
M``"Y"@``-`,```H```#N`0``\`8``'<"````````_@(``#@*``#,"@``QPH`
M`/(!``!#"```!`(``%T(``#T"```2`4``'X``````````````)P(````````
M@P,```````!Q`P``K`H``&D!``#Z`0``-`H```````#3!```P@@``(H*``"D
M````W`<``&<(````````$P$```````#\!P``60$``$8&````````-`8``*X"
M``"/!P``4`<```````#H"```/P,``/,%````````L0@``'<$``"Y!P``````
M``````"^!0```@```$T%````````\0@``"4#``!*!0``/PH```````!>"0``
MC@D```````!R!0``7P,``*4'``"R"```#`8``/<$``#?`0```````"\*``#C
M"```K`$``(P'``"``0``KP4```````!U````#@D```````#P`@``108`````
M``"Z"0``C0$``%H%``#,!P````````H%``!."0``&04```````#]````````
M``````!D!P``0`,``#<``````````````-T$``#Q!```G@0```4*``!;````
M``````````#B````I@@``'X%``#(`@``:P4``/\$``#A!0``F0D``,,!````
M````000``((%``"0"0``9@<``/\'``!_!```"0@``,8```!R!@```````"P!
M```_!@``*````#$)````````I@H```````#O`P````````````!E`P``OP,`
M`.L(````````G0<```L!``#'!```4P$``,\$````````F00``(,&````````
M.@(``)@`````````J`D```````#+!@```````$L%````````&@@``#@+```L
M`P```````,,*````````$0```,T&````````D0$``(@)```Y`@``A@0``-<%
M``"'"@``GPH```````";`````````#8%``#8!```PP@`````````````````
M`/L$````````P0D``'("``"K"```(```````````````H0H``%H$````````
M@@(``(4(``````````````````"6"@``3P````\&``!3"```]0H``#P"``"%
M`P``$@H``&D`````````F`$```````!\!@``TP$``($%``#A"```5P0``'D)
M``"B`0``I`$``-T"``#^!0``:`<``%`"```````````````&````````&`,`
M`"0"``!$"0```````"(```!V`@``P@4``*8`````````>`````````!X`0``
MGP4``/`%``!""0``VP0````````````````````````D!@``=`<```````!]
M`0``"`,``)$#``#@"@``<P,``.,*````````/0(``.\(`````````````$L'
M``#+"0``#0@``+L)``#B"@``!PH``(<$``#K!@```````.T$``"9"```HP,`
M`,`*``!^`@``R04``!0$``!6"```TP<``,H!```^"@``6@D```````"<!P``
MMP0``,@#``#R"@``D`4``"(&```%````LP@``)0!```&!0```````&,$````
M`````````%T*```````````````````\!```70$``'H*``#!!```]@@``"4'
M```J`0``4`@``$`&``!M"```DPH``)L%``!-!@````````````!2`0``F@0`
M``````":"0``]0`````````-``````````$+```-"P``[P$``+P```#^!```
M'`L``````````````````,4"``!8`@``+`4``*\&``"2"```!0D```````!]
M!0``#`$````````2````Z`,``!T+``"X`P``^`,``#(```!8!@``2P,``-,"
M``"2````4PD``!\)``"/!@``F@H``&L(``"<!@``&@L`````````````OP<`
M`,H"``!U`0``(0L``(L*``!R"```M0H```````"-"```-04``-D)``"_!@``
M```````````-`@``F@```*H)``!9`@``,P0``)0%```3`@``408``)("``"0
M`````````%<#``#$`@```````$D"``#Y"@```````&D'``!)`P``````````
M``#D!0``;PD``'L`````````H@(```````!A!@````````````"E!@``F`<`
M````````````U0H`````````````"04``%('``"1!P``?@,``&P#``#H!0``
MU@H``!L*``#X`@``?P,``"4*``"V"@``:P```#8*``"Z!````````)T(``!;
M`@``4@8``.\*``!2`@``NP,```````!?`0``&P@`````````````]@0``(L#
M``"&`@``]@<``````````````````*4"`````````````&`&````````5P4`
M`)X*``!<`P`````````````&`0```````+$$``"@`@``+@H````````1!```
M`````#L```#Q"@``X@(```````!.!@``HP4``(0*``!G!````````!X&``!_
M!0``N`8``'X$````````5`D``!T#``!/`P``J@0``"\'``#G!0```````'@%
M``#H!P``.@L```($````````Y`8```````">!0``UPD```````#R````0```
M`-X'``"R`@``[@H``(P)``#_!@``3@@``"@"``#Z`@``10$`````````````
M$`H``$\'``!C"@``N`4``"H'````````M`<```````!N!0``\0$``,\'``#[
M!P``G@(``.4'`````````````!4#```<"0```````$L!``!H`````````#D&
M```3"P``*08``+@"````````600``'0(``!,!0```````,,$``"Q````````
M`%@'``#@`P``VP$``+D%``!'!0``,P8`````````````J@4````````I`P``
M``````@*````````.PL`````````````B`4``.$)``"S`@``H`0``/T#``#.
M!P``*PD``+H(```%`0``JP(``'<#````````XP$``*$$``#<!@``,`H`````
M````````Y0(``,,"````````UP(``+(*````````AP<````````Z"@``J`,`
M`-(#``!`!```A0<``,4&```G!```=`$``&$`````````D`,``&$$``#,!```
M30```%P*``"/`P``&P<``%()```1!0``K@<````````I`0``5`<``,0````P
M!P``@PH````````D!P``!@L```````";`P``%@4``*8$``#9!@``&`0``,8&
M```)`0````````@+``#Z"@``[0<````````V!````````"`"````````````
M``4'``!O`@````````````!5!P``>`D``.L$``"'"0```````"@)``#<!0``
M`````+0`````````;P0````````A"```_0<``!L#```'!0``4`H```````!S
M!@``8`$``'$"```C`P``E04```````"]"```50@``*X&````````SP8``-\$
M```7!```9`,```````#L"@```````'@$``#J!P``)P<```````![!@``Y@4`
M`($*````````S`,````````H"@``R@<``)H#```N!````````,T(````````
M`````,T*``````````````$%``#/"@``K@4```@!``!]!@```````#\+```)
M`P``N`H```$&```+!P``'`8``,<"``!Y!@``R0<``',(``!!`P``?0@`````
M``#U`@``D`8```````")"0``S`8``%<'``"3````Z@8``/D&``#)"0``8PD`
M`.4)````````'P```%,$```1`P``+@D`````````````Y0$````````5"P``
M)`H`````````````M@(``.D!``"%"0``O04``#@#`````````````&@&````
M````=PD``%8&`````````````!0"````````T`<``#L!````````V0<``%H"
M```]!``````````````*"P``:0H```````"A"0``-0D``(X$``!8````````
M``````````````````````#(!@``_P4``*H'``#'!P``#`,``%H#``#E!```
M`````,(!```,`@```````#P'``#."0``-PD````````N`@``&`@````````Y
M`0``!`<``(0!````````A0$````````K"@```P,```@(````````+`<``*@`
M``!.````-P$``#P!````````&PL``-0!``#="0``KP<``"P&``"D!@``]00`
M`(D%``![!P``I`(```````##````SPD``"L&```7`@``(`$``'0#``"I"0``
M[`$``($$``!Y"@``)@@``-4#````````V0@``%P%````````10(``,$&``"<
M!```0`@``.X&```*`P``^PD``%0!````````S@(``*$#````````S`$``*X)
M``"2!```JP,``-L&````````;@(``"<&``"?!@``(04``.\'```R!@``IP$`
M`%8%```X!@```````$$(````````=0D``'$!``#X!P``R`@``%P(``!E!@``
M`````"T$```Q!P```````.T)``!F````:P,`````````````C`H``($(````
M`````````.0```#`````F@@``+X"``#P!```8P8`````````````^@4``/$`
M``"B`P``(`0``+$'```<"`````````````#3!0``````````````````A@$`
M`/4!``"U`0`````````````X"0``;0$``/`!``!^!@```````.D"``!F!@``
M@P`````````P!0``CP0````````."@``2`0``%`!``!T````?P``````````
M`````````-X*```J"P``B0@``.($``!)`0``4@,```````#3````````````
M``!Y````XP0``.@*``#``@``N@```+,````3!@``:@8```````!2!```"P@`
M`(@"``!N"@``6`D````````R"0``2P0``&4$`````````````.$"``#J"0``
M`````.T```#T!```_````%\%``#8"```!`8``#H$````````-0@``-`)````
M````X@8```````#'````3@(``)$```!4````Y0H``!,%``#F"```GP@`````
M````````+@,``)4#``#+`0``Q0D```````#!````F@$``&````"8"```"00`
M`#(+````````AP````T#```S"@``]@(``!`'``"P`P``'P<```````!B`P``
MT0,````````D````&0$``+X&``"R!@``*P4``%$*```V````+PD`````````
M```````````````$!0```````*\```#;"@```````(T``````````````/,&
M``!_!@`````````````(!@```````&0`````````%0$``$T$``"R````;`H`
M``````#3`P``:@<``!P"``!5`P```````(4%``":`@``!08``#<$``"-`P``
ME0<``+L"``"Y````+`L`````````````,0`````````8`0``*@8``-0$````
M````?@<``*('```#!```(@(``"@!``"T"```O`(``$L&``!P`0``````````
M```J`@``8`,``/4(``"\"0``[0@``+T!``#X`0``R0$``/<&````````````
M`'L%```_!`````````("``"I`0``L04````````""```CP(``,0%````````
M``````````#"!@``!`D````*``"$!```X08``!H#``!H!0```````"<"``"C
M`0```````"8"``"O!```\P0``!H&``!%"```@`4``"H$````````-0H``)D%
M``"C"@``]P(```````"Z`P``4@@``+\*```=!@``3`,``/`)``#;!P``````
M``````!P`P``7P````````"6`@`````````````["@``T@<``+<)``"_!```
M`````*X```!*"```;`D``+4%``#&!P``1@<```````#7"```K`<``+4#```L
M````-PH``"$&``"7!0```00```````!:"@```@4```````#-`@``)PD``*((
M``"P`@``2@D``$8"``"^`````````/P*````````Q@D``',!``"!````#@8`
M``````!P`@``^`D```<&```9"0``*0H``'8(````````(@,``&0&``#C````
M[@0``/\(``"=`````````$D%``!P"````````&("``"^!````@8``'('``"A
M!0``F@4``&$*````````4`0``!(+````````_@D``)\"``"9`@``00```+L(
M```4`````````"P$``#:`0``,0L``"T(```````````````````;"0``_`8`
M``````"7"0``3P8``/$"``"4"@```````$P!``!>!0```````,$*````````
M'P$``/(#``#?"```90D``"D%``"]!P``````````````````'@L```````!J
M`P``Z@0``"`)``#I````W@8``(L!``!_"@``X`D````'````````E08``!<(
M``#G"0````````````!R`0``?P<``(X````?`P````````````"5`0``%`L`
M`)P!``!#`P```````%\*````````?`4``-,&``"W`0```````.H!``#M!0``
MX00``+$"````````L@4``*L*````````)@L``+D$``!A"0`````````````C
M`0``^`4``'`&````````W@(``"T```"R"0``,PL``/X'``#(`0``Y`$``&()
M````````N`$``+H*``"6"0```````&H$```^`@``7@0``&4*``"G"0``?`D`
M`.(#``!0`P``T`,```````#A!P``0P8``+`%``!S!P``"P0``%8)```+"P``
M-@(```L)``!,"@``M@@``&H*`````````````)(%```3"```7P@``-<````4
M"0``#@<``.P&```S!P```````#8)```Y"```8P@```X(``!I"0``5`,``(X%
M````````/@<```D'``#\"```Y`0``&`)```@!0``````````````````HPD`
M``4%```"!P``[@4```````")`````````+4````R`P``\04``*(%```8"P``
MP@<``/X&``"3`P``*@,``'4"``#&!```'P@``-T*````````KP,``"L$```\
M"```A@<``"4%```1`0``8P<```````!N!```M`4```T)```Y"0```````*D'
M```I`@``X0,```````!9````T`H``/8*``!G````5`4```````"E`0``]`$`
M`````````````````#H#```?!0``?`(```(!``!$!```:P8``-L#```0"0``
M?`$``)@$``"?````RP4``+4&``##`P``:04``(8)``"C````$PH``/D'```1
M"P``"0L``&H%``"'`0``UP0``!\+```"`P``2@,``#4$``#!`0``&P(``$@&
M````````;@@``$$)``#L!```]@D``%L)``!E!P``^`@``(P&```/`P``YP<`
M```````Z!0``P0<``$D*``#J"@```````#@"``````````````````"#"0``
M``````````#\!```#`<``/,*````````=@8```````"K`0``6`H``),"```)
M!@``^0```*(&``!6`````````-T``````````````%T"````````H`,`````
M``````````````````!W"@``ZPD``)8!``!/!```C@H``/\!``!=!@``````
M`%L#``#M`0``]P@`````````````1`8````````5`@```````%,'``!6"@``
M100``)(#```[`@```````!0'``"L````V@,``,T%```#"0``\````*H!```W
M!P``GP0``+,'```:`@``O@<```````"1!```9`4``%<(```M`@``5`8``+8`
M``!]!P```````!T)``"4`````````-0&``#W"0```````#\)``#.````````
M``````!&`P``I0@`````````````G04``'H"```="@``608```````#!`@``
MB@,``.P#``"=`P``O@D``'X*``"M!```\P@``"4"````````L@0```````#2
M!@`````````+``!+"@``Q@(``/T!```=!0```````*\(``!.!```,`$``#4+
M``!Z!P``H`@````````Q"@```````&`*````````,@4``/0&````````:0@`
M`#H(``#`!P``%0H``-4&``"Y"```8`4```````#C`@``6`4```````##!P``
M`````$<)``##!0``LP,``'D$```!"`````````````",`P```````'$$``"'
M!0``P`$``!P*``#(!P```````!@&``"6````````````````````904`````
M````````?P@````````$"```3`<```````````````````````!\`P``/`4`
M`-X!``"5"0``7@$``/T)``!:`0``I`D``.X#``#4`P``````````````````
M`````'(````O!```W@0``!8"``#<!```;P8``(('``#9`0``O`4``)\!````
M````TPD``"H````O"```9P,`````````````QP,````````T"```/P(``#T%
M```D!0``=P```)P#``"N`P``H@H```````#``P``R08``"(*```M`0``Y04`
M`!L```#*!@``1P8`````````````$@8``)`(``#Y"```K0,``'4#``"E"@``
MU`@``*8!``"M"@``QP@``,<)``#`!```7P0``!@`````````<`4```````!"
M"```FP8``.$*``"5"@``KP$``!4$``"S"0```````",%````````]@$``*8'
M````````[P4``/H(````````T0H``-@%````````P`D``-T&````````````
M`/<'```9"@``?P$``#L'``!)!@``&0(``"T+```R!P``2PD```````";"@``
M[P`````````>````O0D``"@(``#M!@``1@@``%T#```_"```V0(``'8#``#Y
M"0```````,\(```M!0````````````";`0``U0<````````8!0````````0+
M`````````````&T"``#O"0```````$X#````````5P(``-$&```;!@``!0,`
M`&`'```K`P``4@H````````9`````````,,&``"G!```.@8``,L*``"Y`@``
MKP(```````#5````T0D``#\`````````<`D`````````````0`H``&T```"*
M`@``Q`H```````"V!0``!@@``'<&``"-"@``.0````````"9`````````-$$
M``!C`@``700``(@!``"(!P``T0@``*D*````````,P@``+`'````````$08`
M`-`%```T````(`H``#0"``#;`@``@0<``+,!``!B"```````````````````
M`````+T```#-!```WP<``"<(``#@!P``,@(``!4%``#3"```T0$``)4"````
M````[````/0#``!K!P``Z@,``-$```#V!@``^0$``!8&````````"@H``&$"
M``#G````#0<```P(````````BP@``+L&````````1`,``+D)````````K@@`
M`.(!``#,"```9P4``&@#````````9@H``/D$````````9@(``$$!``!,!@``
M+0H``"@#``!;!````````````````````````/`#``#<"0``>P$```````!3
M````H`4``.8)``!@`@```````&0)```["```G`````@$``"``@``/`D``!`+
M```.!```V0H``#8#```!"@``XP4``!T"``"7!@``F`8``.D#``#+!```QP$`
M`+H'``#>"```F`4``!$'```G````^`0``%X(``"L!```U0@``"@'```]"0``
MS0D``),(``!8`0```````"8!``!("@```````)8#``!'"@```````"8*```,
M!0``G@8```H)``#K!P``D0D```````#2````J04``%0"``"B"0``GP,``&('
M``!Y`@``N`@``(,(````````E`@```H!```Y!P```````,L(```4"@``,@0`
M`($"````````-PL``*$!`````````````*@%`````````````#<"```N````
MB@D``!8```"J`P``H`H``,@%``#!"```"0```)T!```9"P````````````"D
M!P``G0D``+4(``!3!@``C08``%P```!/"````````)()``",!0``5@<```,`
M``"1"```F08``-4$``!>!@``F0$``#,!```W!@``#PH```````"Y`0``)`,`
M``````!-`0``]````'P'``"A"```'@D```````"G`````````*4%```:"@``
MZP$``#P&``"F!@``H08```````!``0```````)0"````````CP$``)@"``#-
M`````````-0*``">`P``6`@```\`````````%@,```````!M!0``!@D``+,*
M```S!0``_P```#T#``"V`0`````````````,"0``Y@$``$\*````````0@,`
M`!P```#W"@``*`L``%D(``#5`@````````````"5`````````#$!```J"@``
MB@4`````````````R@,``)(&``!.!0``Y@(``````````````````-`&``#6
M````#@L```````#M`@```````*@*````````B`@```H'``"6!P``&P$``"$*
M``#G!@```P@``(D!``"+!```9@,```$"``!``@```````-`(```'````````
M`"D)````````$`@``-P(``#F`P``C````$0```"#!```>@0``/4'````````
M`````+$&```Q`P``L0,``&P"``"(`P``6@8``#4#````````^0(```````#4
M`@```````#@!```>!```7`<``/P"``!$!P```````#8&``"Z`0``W`H``'()
M```:!```_04``/<```"Z!@``M@0``-X%````````V@```/X(````````>0$`
M``````"=`@``S@H``!<)``!Z!0``R0,```T$````````U``````````N"P``
MG`(```````#"!```DP8``,H$````````Y08```P+````````IP(````````L
M"@``:P0``)<"``!T"@``6PH``$8)``"C"````````'T*``!#`@``=@D``#$"
M``"6!````@D``+@)```%"P``D`0``````````````````%$#``!X`@``)0L`
M````````````R`D``-@#`````````````&0"```O"P``5P$``/P#``!)````
M-`4``+0"``"D"`````````````";"```C00``'H!``"!`P``W`$``)8&``#4
M"0``G0H``+D#``#M`P```````.P'```T"P``00(``(P$``#U`P```````*T%
M```K"```:00```````#L`@``T@$``(L&```<!0``$`0````````G`0``@P(`
M`/L```#_`P```````)L$``!7!@```````"0!``!N"0``!PL``!(#``"-!P``
MB@8``$`'```C"0``(00``*0*````````#04```````"Y!@```````%4!```6
M`0``````````````````HP0```````"""```'`$```````#\"0```````/H#
M``"("@``^PH``!T(````````L@$``)@#````````K0$``#4```#L"0``````
M`-D```!B!```'00`````````````%@<``'T"``"'"```*@4``'X)````````
M:@(``-0'````````$`,``((!``"'`@``!`H``-4%``"$`@``K`,``)<!````
M`````````)$&``#&`P``?````#4&````````"P(``%L'``!H"0``````````
M``````````````L`````````&0@``'4(``!\"@``,PD``.D)``"@"0````D`
M`!H%````````&00``"`+```W`P``EP0````````]`0``)`0```````"_"```
M[P0``/L&```P!@``X`8````````3!```&P4``&H!```V"```IP4``&P'```;
M!```#@(```L*``"4!@``OP$``&0(````````%`4``*T)`````````````!D#
M````````^04`````````````^@D``(L"``!5`@``;`4````````""P``(P8`
M`((```"P"0``\0,``"((``!5!@```````(H'``!9!0``J0(``#T'```P"P``
MV@4```````",`@``,P(```<(```[!@``5`@``%D)```X"```]`H````````]
M"```SP(``'L(``!R`P``:@D``````````````````-\&```[!```Q`,``"0)
M``#]"@``*0<`````````````M0<``.,#``#3"@``;P,``$<'``"]!```````
M```````8!P``"`4``&`$``!'`@````````\+``!M"@``````````````````
M2````&8!``!\!`````````````"\"@``104``+$*````````9@0```````"W
M!0``3P(`````````````,@$``'D%``!(`P```````*X!``"I`````````.4(
M``!5!0``I@,``(\)``#Q!@``M@,``%,%``#>`P``S@8``$0!``!^`0``5PH`
M`-\)``#9!```SP````````","```)PL``)\'`````````````)X!````````
M`````(()``"P````O`,``%4)``#<`````````*T'``!(`@``0PH``+<'```P
M`P``5@0``.,)```-`0``P`8```````"K!```Z@````````"=!@``X@4``-H(
M``#0``````````````!9"@``OPD``-4!```^`P``1`@``-H&``!%!P``#```
M`(0)```7"P``9PD``-8!```/!0``R0(`````````````X0````````#"````
M'@(````````""@``%PH``"`(``!E"````````'$(``!B!0``<@H```````!P
M````)0````8'````````80$``+4)```N!0````````D)```.!0``A@8``&$'
M````````J00```<$``"B!```E@@`````````````U@4``)`*````````S@0`
M`'4%```A"0```````````````````````'L*``#C!P```````',```"]`@``
M10```-8$``#`!0``4`D``+$)```I````'0<``````````````````!`&``#F
M````20<``!<!`````````````&\*````````'0$``*H*````````[@D`````
M```-"@```````#D%````````"P8``/0)``!;!0``7PD``%D'````````:`@`
M``````#S`0``;08``+(#``"%"@``*`8`````````````@`@``"(!``#\!0``
M`````,X#````````Y0,``,H*``!Q````VP````````"7!P```````%,#````
M`````````"`&``"^"`````````````",`0``!@H``$@'````````EP@`````
M``"]!@```````$X!``"D`P``(@L``!("``!-"````````&@"``#,````````
M`#,````$`0```````'\)``!K`@``%`$```````#B!P``:PD``+X*```K`0``
M````````````````J`$``/,```"#!P``[@(``"`'``""`P```````/(%```#
M!@``?P(```````#@````;@```,H%```.`P``K0(``,()``#I"@``'@$``!\*
M``!Y"````````%\&`````````````,@*``#[`0````(``)X)````````I0``
M`,X%``"."```UP$``,@$```4!@```````(`)`````````````$L"``"&"@``
M;00``!$)````````>@```"('``````````````````````````````````"8
M"@````````````#[!0``G@<```````!"````````````````````\@D``),)
M```%"```&`H```,%````````:PH```````!Q"0``4@4``*L`````````Y0``
M`#(*``![`@````````````#+!P``[P(``,8%``!%"@```````/T"``#)"```
M<PD``*4#```M!P``:08````````*!@``QP4``(H!````````+`D```````!;
M!@```````!H```!'!```K0@``$(!``")`@```P$``!,```"H`@``VPD``!,'
M````````VP4``+<"```,"@````````````!N`0```````*D&``"7`P``````
M``8"``#B"```Q0<`````````````]`<```0$````````R@D```````!1"0``
M`````-X```!>"@``HP8``#4!``!]````J`@``*(``````````````.`!``#2
M"0``P@H``.0(``!S`@``]@4```8#``!Q!0``D@<``+`$``#P"@``P`@``)\)
M```V`0``%P8``&P$``!Y`P``Z00``!`!``!L"```!````,@`````````M`$`
M`(4````&!```:`H``$H!``!8!````````&8(````````)P4``.<*``!R!```
MW`(``/T&``#0`@````````$!``#1`@``.`<`````````````3````%$'``"J
M`@``U0D``/T$``"]`P```````+H%`````````````%````#=`0``#`0``(8#
M``"G"@````````````"9!P```````,H`````````+P(``,4%``#6`@``````
M`$H'````````DP4``(0(```P`@```````'T)```N`0``/@```!H!````````
M`````-D%``#I!0``O`0``.8*``!#`0``Z`$``&P&````````10,``%8!``!N
M`P``(PH``(0%````````1P,``!(%``!Q"@``FP(``/('``#%````@`8`````
M`````````````&\!``#!`P``!`,``%$%```C````X@D``/H$````````@P$`
M``\!```2!````"`@("`@(%1O.B``("`@($1A=&4Z(``@("`@1G)O;3H@`"`@
M+4TL("TM;65S<V%G93U-15-304=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G
M92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N97,N`"`@+6$L("TM861D/49)
M3$4@("`@("`@($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN
M(%5S969U;"!T;PH@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E(&$@
M8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T;PH@("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@9V5N97)A=&5D(&-O;7!E;F1I=6TN`"`@
M+6(L("TM8F%S93TO4$%42"`@1G5L;"!P871H('1O('1H92`H2&]R9&4I(&)A
M<V4@9&ER96-T;W)Y('1H870@<VAO=6QD(&)E"B`@("`@("`@("`@("`@("`@
M("`@=7-E9"X`("`M8RP@+2UC;VUP96YD:75M/49)3$4@($UE<F=E(&YE=R!T
M<F%N<VQA=&EO;G,@=&\@=&AI<R!C;VUP96YD:75M(&9I;&4*("`@("`@("`@
M("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE("AC
M;VUP96YD:75M+G!O(&EN('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@
M:&]R9&4O<&\@9&ER96-T;W)Y+@`@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@
M57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0*("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M<&5N9&EU;2YP
M;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2X`("`M9"P@+2UD96)U9R`@
M("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE(&5X96-U=&5D(&)I
M;F%R:65S+@`@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M<&5N
M9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2X`("`M:"P@+2UH96QP("`@("`@("!3
M:&]W('1H:7,@:&5L<"!M97-S86=E+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@
M("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C86QE/6QL7T-#
M("`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@
M(%5S92!T:&ES(&QO8V%L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($)U
M:6QD($U/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@
M+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P(%!/(&9I;&5S(&]N;'D@
M9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,
M12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E
M*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#<F5A=&4@82!0
M3R!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F:6QE<R!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D
M871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`
M("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!O;FQY('1H:7,@*$AO
M<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@1V5N97)A=&4@
M4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;BP@
M+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T<F%N<VQA=&EO
M;G,@=&\@=&AE(&-O;7!E;F1I=6TN`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@
M("!$;VXG="!U<V4@82!C;VUP96YD:75M+@`@("US+"`M+7-T871I<W1I8W,@
M("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@
M9FEL92X`("`M="P@+2UT97-T("`@("`@("!3:&]W('1H92!E>&5C=71E9"!C
M;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+@`@(&-L96%N=7`@("`@
M($-L96%N<R!T:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS;&%T960@86YD
M(&]B<V]L971E(&5N=')I97,N`"`@8V]M;6ET("`@("`@0V]M;6ET('1R86YS
M;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BX`("!C;VUM:70M:&5L<"!#;VUM
M:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E<BX`("!C;VUP96YD:75M
M("!296)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@
M;W9E<G=R:71E<R!T:&4*("`@("`@("`@("`@("!C=7)R96YT(&-O;7!E;F1I
M=6TN`"`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA=&4@*"YP;W0I
M(&9I;&5S+@`@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N
M`"`@:6YI="`@("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/(&9I;&5S(&9O
M<B!A(&YE=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7,*("`@("`@("`@("`@("!O
M=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T:&ES(&QO8V%L
M92X`("!M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@9FEL97,@9G)O;2!T
M:&4@<W!E8VEF:65D(%!/(&9I;&5S+@`@(&UA:V4M:&5L<"`@($UA<FL@86QL
M(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@=7`M=&\M9&%T
M92!A;F0*("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE(&9O<B!T:&4@
M;F5X="!E>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=0H@("`@("`@("`@
M("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@049415(@=7!D871E+6AE
M;'`@86YD(')E=FES:6YG('1H90H@("`@("`@("`@("`@(&AE;'`@9FEL92X`
M("!M97)G92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F:6QE('=I=&@@
M=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL92X`("!U<&1A=&4@("`@("!2
M=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N="X`("!U<&1A=&4M:&5L<"!%
M>'1R86-T(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M('1H92!%
M;F=L:7-H(%A-3"!H96QP"B`@("`@("`@("`@("`@9FEL92!A;F0@;65R9V4@
M=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+@`@)B,Q-3$[("5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H
M:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI
M`"!3=6)J96-T.B``(&%T(``@:6X@`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO
M:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I
M<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@
M861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D
M.B`E<RX`(P`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`"5D("5S(&%N9"`E
M<P`E9"!B>71E<R!W<FET=&5N+@`E9"!M97-S86=E<R!H879E(&)E96X@9&5L
M971E9"X`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S
M<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`"5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2X`)60@;65S<V%G97,@
M:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S
M('-P86TN`"5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4`
M)60@=&\@)60@;V8@)60@365S<V%G97,`)60M9&%Y(&9O<F5C87-T`"5S("T@
M3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S($9I;F=E<G!R:6YT`"5S($M"
M`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@
M4$=0($%D;6EN:7-T<F%T:6]N`"5S(%,O34E-12!!9&UI;FES=')A=&EO;@`E
M<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A
M;')E861Y(&5X:7-T<RX`)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L
M9&5R('=A<R!N;W0@<F5N86UE9"X`)7,@870@)7,@)7,`)7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R(&)E:6YG
M(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"X`)7,@:&%S(&%C
M8V5P=&5D+@`E<R!H87,@8V%N8V5L;&5D("5S+@`E<R!H87,@9&5C;&EN960N
M`"5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA
M<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N
M="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!H87,@=&5N=&%T:79E
M;'D@86-C97!T960N`"5S(&ES(&YO="!W<FET86)L92X`)7,@:7,@<F5Q=6ER
M960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(&YO="!F;W5N9"X@4G5N
M("=T<F%N<VQA=&EO;B!E>'1R86-T)R!F:7)S="X`)7,@<F5Q=65S=',@>6]U
M<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(')E<75E<W1S('EO=7(@<')E
M<V5N8V4@870@)7,N`"5S('1O("5S(&]F("5S`"5S('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@)7,N`"5S('=I<VAE<R!T;R!A;6UE;F0@)7,N`"5S('=I
M<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E
M8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!
M9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!4
M87-K;&ES=``E<SH@)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!
M<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`
M*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S
M92!S8W)E96XN*0`H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E
M<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E
M<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI
M`"A396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D
M92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I
M;&P@3D]4(&)E(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/
M2R`J`"H@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN9R``
M+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S
M96QE8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`#$@;65S<V%G
M92!H87,@8F5E;B!D96QE=&5D+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`
M,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`Q(&UE
M<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@
M87,@<W!A;2X`,3`P(&-H87)A8W1E<G,`,3`P,"!C:&%R86-T97)S`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#(U,"!C:&%R86-T
M97)S`#4P,"!C:&%R86-T97)S`#Q0<F5V:6]U<P`\9V5T=&5X=#X@=&%G(&YO
M="!C;&]S960@:6X@9FEL92`E<RX*3W!E;FEN9R!T86<@9F]U;F0@:6X@;&EN
M92`E9"X`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES
M(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!(&QA<F=E(&EM
M86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92X`02!M
M97-S86=E('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N
M(&YO=&EF:6-A=&EO;B!F<F]M('1H92!R96-I<&EE;G0N`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!
M32!3;F]W(%-H;W=E<G,`04TO4$T`04Y$`$%022!)1`!!8F]U="!T:&ES(&5D
M:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P="!R97%U
M97-T`$%C8V5P="!R97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(`
M06-C97!T960`06-C97!T960Z(`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G0G<R!N
M86UE.@!!8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"!#:&EL9"!'<F]U<`!!
M9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!
M9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!
M9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z
M`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!S;W5R
M8V4`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T
M:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;R!!9&1R97-S(&)O;VL@*"5S*0!!
M9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D
M9"!U<V5R`$%D9&5D("(E<R(@87,@86X@871T86-H;65N="X`061D960@(B5S
M(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L
M('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@;F5W(&9I;&5S('1O
M(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D:71I
M;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\:3XH;W!T
M:6]N86PL(&5N=&5R(&5A8V@@:&5A9&5R(&]N(&$@;F5W(&QI;F4I/"]I/@!!
M9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N`$%D9&ET
M:6]N86P@:6YF;W)M871I;VX@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@
M9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE
M=V5D("5S+@!!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<P!!9&1I
M=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S
M+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&1R97-S($)O;VMS`$%D9')E<W-E
M<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\:3XH;W!T:6]N86PL(&5N=&5R(&5A
M8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO:3X`061D<F5S<V5S('1O(&5X
M<&QI8VET;'D@=&EE('1O('1H:7,@:61E;G1I='DZ(#QI/BAO<'1I;VYA;"P@
M96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]I/@!!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES
M=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S
M`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S
M`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L
M;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E
M(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE.@!!;&P@;65S<V%G97,@
M:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B
M92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD(&QI;FME9"!A='1A8VAM
M96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N
M`$%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H
M<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&P@<FEG:'1S(&]N(&9O;&1E<B`B
M)7,B('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U<V5R("(E<R(N`$%L;&]W
M(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/P!!
M;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@
M3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@
M57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E
M;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06QT97)N871I=F4@<&%R=',@9F]R
M('1H:7,@<V5C=&EO;CH`06QW87ES`$%L=V%Y<R!S879E(&%T=&%C:&UE;G1S
M`$%M97)I8V%N(%-A;6]A`$%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP
M=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE($E-05`@<V5R=F5R
M('-A:60Z(`!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N('5N:VYO=VX@97)R;W(@;V-C
M=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS=V5R960`
M06YS=V5R960@;65S<V%G97,`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B
M=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!&
M:6QT97)S`$%P<&QY($9I;'1E<G,@=&\@)7,`07!P;'D@9FEL=&5R(')U;&5S
M('5P;VX@;&]G9VEN9R!O;C\`07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R
M($E.0D]8(&ES(&1I<W!L87EE9#\`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P
M<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M
M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/P!!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H
M:7,@:7,@3D]4(')E8V]M;65N9&5D(2D`07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI
M<R!A='1A8VAM96YT/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@96UP='D@=&AI<R!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@
M87,@:6YN;V-E;G0_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@
M=&AI<R!M97-S86=E(&%S('-P86T_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N
M:6%N("A!4DU30TE)+3@I`$%R<FEV86P@5&EM90!!<G0`07)U8F$`07-C96YD
M:6YG`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!2
M96=I;VX`07-K`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M
M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T
M86-H`$%T=&%C:"!&:6QE<P!!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U
M8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/P!!='1A8VAE9"!&:6QE.@!!='1A
M8VAE9"!F:6QE("(E<R(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI
M;6ET<RX@1FEL92!.3U0@871T86-H960N`$%T=&%C:&5D(&ES(&$@<F5P;'D@
M=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+@!!='1A8VAM96YT`$%T
M=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP90!!
M='1A8VAM96YT<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T
M96YD965S`$%T=&5N=&EO;@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`
M075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@
M<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($94
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M
M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]I;7`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A
M9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U
M=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@
M34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I
M<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I
M;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&]M871I8V%L;'D@<VAO=R!I
M;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@
M;7D@861D<F5S<V)O;VL_`$%V86EL86)L92!!9&1R97-S(&)O;VMS.@!!=F%I
M;&%B;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!!>F5R8F%I:F%N`$)/
M1D@@17AC=7-E<P!"86-?:R!T;R`E<P!"86-K('1O("5S`$)A8VMG<F]U;F0`
M0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K
M97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/
M+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F-C`$)E
M;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F
M('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S<V%G92X`0F5N:6X`0F5R;75D
M80!":'5T86X`0FER=&AD87D`0FQA8VML:7-T`$)L;V-K("(E<R(@;V8@87!P
M;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K
M(%1Y<&4`0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H
M97D@87)E('-P96-I9FEC86QL>2!R97%U97-T960_`$)O9'D`0F]L9`!";VQI
M=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T:"!(96%D97(@3&ES
M=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E`$)O='-W86YA`$)O='1O;0!";W5V
M970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GD`0G)U;F5I($1A<G5S<V%L86T`0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO
M9'5L92`E<RXN+@!"=6EL9&EN9R!L;V-A;&4@)7,N+BX@`$)U;&=A<FEA`$)U
M;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-?:&%R
M<V5T`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A
M;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!C;VYN96-T('1O('1H92!R
M96UO=&4@;6%I;"!S97)V97(N`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M
M;W1E(&UA:6P@<V5R=F5R.B``0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL
M>2`E<R!O9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E
M;G0@;6%I;&)O>"X`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A
M;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@365S
M<V%G90!#86YC96P@4')O8FQE;2!297!O<G0`0V%N8V5L;&EN9R!T:&ES(&UE
M<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RX`
M0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B
M+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO
M;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V,`0V5L
M;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R
M;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M
M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT
M<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS
M`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`
M0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@06QL`$-H86YG92!&;VQD97(`
M0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A
M9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@87)E
M('-O<G1E9"X`0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN
M9W,N`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#
M:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M
M86EL+@!#:&%R`$-H87)A8W1E<G,@=&\@9&ES<&QA>3H`0VAE8U]K($QI;FLN
M+BX`0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!#:&5C:R!?06QL+TYO
M;F4`0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M
M86EL(&9R;VTZ`$-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S
M<V%G93\`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I`$-H;V]S92!!8W1I;VXZ`$-H;V]S92!A(&UA:6P@<V5R=F5R.@!#
M:&]O<V4@82!M871C:"!O<B!E9&ET('1H92!A9&1R97-S('1O('1H92!R:6=H
M=#H`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E
M(&%N(&%C=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E
M('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E<W-E
M<RX`0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C
M:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`$-H<FES=&UA<R!)<VQA;F0`
M0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%N:6YG('5P
M(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`0VQE86YI;F<@=7`@;&]C86QE
M("5S+BXN(`!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U
M<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,
M871E`$-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A
M(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N`$-L:6-K("5S('1O(&1O
M=VYL;V%D('1H92!I;6%G92X`0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E
M;65N="!P86=E+@!#;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A
M('-E<&%R871E('=I;F1O=RX`0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I
M;"!O9B!T:&ES(&EM86=E+@!#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM
M96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W('1H
M:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O
M=RX`0VQI8VL@:&5R92!T;R!(241%('1H92!);6%G97,`0VQI8VL@:&5R92!T
M;R!32$]7('1H92!);6%G97,`0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T
M960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T
M;R!S96%R8V@N`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K('1O(%-A=F4@4$=0
M(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VL`0VQI8VL@=&\@4V%V
M92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O
M;VL`0VQI8VMA=&5L;"!V:6$@2%144`!#;&EC:VEN9R!O;B!T:&4@861D<F5S
M<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R`$-L
M:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T
M;R!B92!R96%D`$-L;W-E`$-L;W-E(%=I;F1O=P!#;&]S92!T:&ES('=I;F1O
M=P!#;&]S960@1F]L9&5R`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E`$-O;&QA<'-E($%L;`!#
M;VQL87!S92!!;&P@1F]L9&5R<P!#;VQL87!S92!&;VQD97(`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO
M<B!);F1I8V%T;W(Z(`!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE
M;&P`0V]M;6%N9"!O<'1I;VYS.@!#;VUM86YD<SH`0V]M;65N=`!#;VUM:71T
M:6YG.@!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&QE=&5D`$-O
M;7!O<V4`0V]M<&]S92!-97-S86=E("@E<RD`0V]M<&]S92!A;F]T:&5R(&UE
M<W-A9V4`0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\`
M0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@
M*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE(&9E871U<F4I/P!#;VUP=71E<G,`
M0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`
M0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+@!#;VYF:6=U
M<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N`$-O;F9I<FT@4&%S<W=O<F0`0V]N
M9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN
M96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;FYE8W1I
M;VX@=&\@<V5R=F5R(&9A:6QE9`!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F
M(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`
M0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@4R]-24U%('-U
M<'!O<G0@9F]R("5S+@!#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C
M:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@
M=VAE;B!I="!A<G)I=F5S+@!#;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN
M=&\@9W)A<&AI8V%L(&]N97,_`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#
M;W!Y('-E;&5C=&EO;@!#;W!Y('1O(&9O;&1E<@!#;W!Y:6YG("5S('1O("5S
M`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]S=&$@4FEC80!#;W1E(&0G279O
M:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N
M;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@
M8V]P>2`E<R!T;R`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R
M(&QO8V%L92`E<SH`0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z
M("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I
M9#H@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B
M)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RX`0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<RX`0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE
M(&9R;VT@=&AE($U3+51.148@871T86-H;65N="X`0V]U;&0@;F]T(&5X=')A
M8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H:79E+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M
M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG
M+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E
M<R(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L
M9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L
M9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@
M=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`
M0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E($9O
M;&1E<@!#<F5A=&4@2V5Y<P!#<F5A=&4@5FER='5A;"!&;VQD97(`0W)E871E
M(&$@3F5W($%C8V]U;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@4W!A
M;2!F;VQD97(`0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E871E(&$@
M;F5W(&]N90!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@
M82!N97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@
M;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L
M9&5R<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E
M871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#
M=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),
M(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&%C8V5S<R!T;R`E<P!#=7)R
M96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE(&%C8V]U
M;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N`$-U
M<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"X`0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R
M=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$
M`$1A:6QY`$1A=%]E`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I
M=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E
M<@!$96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C;&EN960Z(`!$96-R96%S
M92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I
M='D`1&5F875L="!097)M:7-S:6]N<P!$969A=6QT('!E<FUI<W-I;VYS`$1E
M9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C
M=&EO;CH`1&5F:6YI=&EO;G,`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@)7,@
M4'5B;&EC($ME>0!$96QE=&4@0W5R<F5N="!+97ES`$1E;&5T92!&;VQD97(H
M<RD`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!396QE
M8W1E9"!&;VQD97)S`$1E;&5T92!6:7)T=6%L($9O;&1E<@!$96QE=&4@86YD
M('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@9F5T8VAE
M9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_`$1E;&5T92!F<F]M(&UY
M(&-A;&5N9&%R`$1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T(&)E
M9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y`$1E;&5T92!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B
M965N(')E<&]R=&5D(&%S('-P86T_`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU
M;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!P97)M:7-S
M:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&5D`$1E;&5T960@
M;65S<V%G97,`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$
M96QE=&5D('1H92!A='1A8VAM96YT("(E<R(N`$1E;&5T:6YG(&%N9"!-;W9I
M;F<@365S<V%G97,`1&5L:79E<GD@=&EM90!$96YM87)K`$1E;GD@<F5Q=65S
M=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;@!$97-C
M96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I
M;',`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E
M;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$
M97<@<&]I;G0Z(`!$:6T@<VEG;F%T=7)E<S\`1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L
M87D`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_`$1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G90!$
M:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_`$1I<W!L
M87D@=&AE("=%;7!T>2!4<F%S:"<@;&EN:R!I;B!T:&4@;65N=6)A<C\`1&ES
M<&]S:71I;VX`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O
M($Y/5"!M871C:`!$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I
M;`!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ
M(&-O;'5M;@!$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/P!$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI
M8P!$;VYE`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D("5S(&EN("YZ
M:7`@1F]R;6%T`$1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F
M:6QE*0!$;W=N;&]A9"!&;VQD97(H<RD`1&]W;FQO860@1F]L9&5R*',I(%LN
M>FEP(&9O<FUA=%T`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1&]W;FQO860@:6X@+GII<"!&;W)M870`1')A9G0`
M1')A9G0@9F]L9&5R`$1R869T<R!F;VQD97(Z`$1R;W`@9&]W;B!L:7-T`$1R
M=6=S`$4M36%I;`!%+6UA:6P@061D<F5S<P!%3D0`15)2`$524D]2.B!9;W5R
M(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`16-U861O<@!%9&ET
M`$5D:70@0FQA8VML:7-T`$5D:70@0FQO8VL`161I="!&:6QT97)S`$5D:70@
M1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!6:7)T=6%L($9O;&1E<@!%9&ET(%9I
M<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$5D:70@5VAI=&5L:7-T
M`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`
M161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!Y;W5R(&)L86-K;&ES=`!%
M9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D:70@>6]U<B!P<F5F97)E;F-E<R!F
M;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N`$5D:70@>6]U<B!W
M:&ET96QI<W0`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N
M+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M
M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N`$5M<'1Y($9O;&1E<BAS*0!%
M;7!T>2!396QE8W1E9"!&;VQD97)S`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T
M>2!?5')A<V@`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S
M96%R8V@@=&5R;7,`16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/P!%;F%B;&4@
M4R]-24U%(&9U;F-T:6]N86QI='D_`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!M97-S
M86=E('!R979I97=S/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/P!%;F-R7WEP=&EO;B!/<'1I;VYS`$5N9`!%;F0@9F]R=V%R9&5D(&UE<W-A
M9V4`16YD(&UE<W-A9V4`16YD(&UE<W-A9V4@9G)O;2`E<P!%;F0@>65A<@!%
M;FQA<F=E($5D:71O<@!%;G1E<B!087-S<&AR87-E`$5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`
M16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R`$5N=&5R
M('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H
M92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H
M92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(`16YT:7)E($UE<W-A
M9V4`16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@
M)60@8VAA;F=E9"P@)60@=6YK;F]W;@!%;G1R>2`B)7,B('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:P!%<75A=&]R:6%L($=U
M:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+@!%
M<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`
M17)R;W(Z(`!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E;G0@
M<W5C8V5S<V9U;&QY(&1E;&5T960N`$5V97)Y(#$U(&UI;G5T97,`179E<GD@
M,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V
M97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L
M92!V86QU97,Z`$5X96-U=&4`17AE8W5T:6YG.@!%>'!A;F0`17AP86YD($%L
M;`!%>'!A;F0@06QL($9O;&1E<G,`17AP86YD($9O;&1E<@!%>'!A;F0@3F%M
M97,`17AP86YD(%-I9&5B87(`17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E
M('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H92!B86-K9W)O=6YD/P!%>'!A
M;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN('1H92!F
M;VQD97)S('9I97<_`$5X<&%N9&EN9P!%>'!E8W1E9"`G*2<`17AP96-T960@
M8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A
M=&4`17AP;VYE;G0`17AT<F%C=&EN9R!F<F]M("5S+BXN(`!&1R!#;VQO<@!&
M5%`@=7!L;V%D(&]F('-E='5P`$9?971C:"!-86EL`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&
M965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&971C:"!-86EL`$9E=&-H($UA:6P@
M:6X@82!S97!A<F%T92!W:6YD;W<_`$9E=&-H(&UE<W-A9V5S('5P;VX@;&]G
M9VEN9R!O;C\`1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S`$9E=&-H960@
M,2!M97-S86=E(&9R;VT@)7,`1F5T8VAM86EL.B``1F5T8VAM86EL.B!N;R!N
M97<@;65S<V%G97,N`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FE?
M;'1E<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA
M;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N`$9I;'1E<B!/<'1I;VYS`$9I;'1E<B!3971T:6YG<P!&
M:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_`$9I;'1E<B!S
M=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!&:6QT97)S`$9I
M;'1E<G,@3D]4($%C=&EV90!&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4`
M1FEN9`!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@36%I;&)O>"!086=E`$9I
M<G-T(%!A9V4`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&
M;U]R=V%R9`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;&1E<B!!
M8W1I;VYS("T@0V]N9FER;6%T:6]N`$9O;&1E<B!.879I9V%T;W(`1F]L9&5R
M(%!R969I>`!&;VQD97(@4W5M;6%R>0!&;VQD97(@<VAA<FEN9R!I<R!N;W0@
M96YA8FQE9"X`1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"X`1F]N="!#;VQO
M<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@
M<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[
M(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B
M;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUA="!O9B!M97-S86=E
M(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D
M('1O9&%Y`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O
M<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE
M<W-A9V4`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&;W)W87)D<P!&;W5N
M9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C=&]R:65S.@!&<@!&<F%M
M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R964O0G5S>2!);F9O
M<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`1G)E
M92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&<F5N8V@@
M4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]?;0!&
M<F]M`$9R;VT@061D<F5S<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$9U>GIY`$9W9#H`1G=D.B``1G=D.B`E=2!&
M;W)W87)D960@365S<V%G97,`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@3W!T:6]N<P!'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;F5R871I;F<@
M<W1A='5S(&9O<B!M;V1U;&4@)7,N+BX`1V5O<F=I80!'97)M86YY`$=E="!O
M;FQY(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2D`1V5T;W!T($5R<F]R.B``
M1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V\@=&\@365S<V%G90!'
M;R!T;R!A9&1R97-S(&)O;VL@96YT<GD@;V8@(B5S(@!';V5D96P`1V]O9VQE
M(%-E87)C:`!'<F%N="!A8V-E<W,`1W)A>7-C86QE`$=R965C90!'<F5E:R`H
M25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R
M871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R
M;6ES<VEO;G,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E
M<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W0@<&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(15)%`$A434P`
M2%1-3"!697)S:6]N(&]F($UE<W-A9V4`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A
M9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@
M5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;'!E<B!A<'!L:6-A=&EO;B!T;R!C
M<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E
M"F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RX*1F]R(&%N(&EN=')O
M9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R
M>2X`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z`$AE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.@!(
M:61D96X`2&ED9&5N(&EN(%1H<F5A9"!6:65W`$AI9&4@1&5L971E9`!(:61E
M(%5N<W5B<V-R:6)E9`!(:61E('1H92!);6%G97,`2&EG:`!(:6=H(%!R:6]R
M:71Y`$AI9VAE<W0`2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>0!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE
M`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(
M;W)D90!(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(`2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O
M;FES960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D
M:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I`$AO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE
M;G1S/P!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W('1O(&%T=')I
M8G5T92!Q=6]T960@;&EN97,@:6X@82!R97!L>0!(=6UI9&ET>0!(=6UI9&ET
M>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05``24U!4"`H075T;R!$971E8W0@
M4')O=&]C;VQS*0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&]V97(@4U-,`$E-05`@
M;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*0!)34%0(&]V97(@
M4U-,("AS96QF+7-I9VYE9"D`24U!4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL
M(%-E<G9E<G,`24Y"3U@`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO
M8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E
M`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG
M<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!C;VYT:6YU92P@
M86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(0!)
M9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L
M;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!)9VYO<F4`26=N
M;W)E($%L;`!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!)
M;6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U
M<&QO860`26UA9V5S`$EM<&]R=`!);7!O<G0@2V5Y`$EM<&]R="!+97EP86ER
M`$EM<&]R="!-97-S86=E<P!);7!O<G0@4$=0($ME>0!);7!O<G0@4&5R<V]N
M86P@0V5R=&EF:6-A=&5S`$EM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+
M97D`26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y`$EM<&]R="!097)S
M;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S`$EM<&]R="!0=6)L:6,@2V5Y`$EM
M<&]R="!0=6)L:6,@4$=0($ME>0!);7!O<G0@4'5B;&EC(%,O34E-12!+97D`
M26UP;W)T(%,O34E-12!+97D`26UP;W)T(&UB;W@@1FEL90!);7!O<G0@;6)O
M>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+@!);7!O<G0L(%-T97`@)60`26UP
M;W)T86YT`$EM<&]R=&%N="!M97-S86=E<P!);7!O<G1E9"`E9"!M97-S86=E
M<R!F<F]M("5S+@!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8F]X`$EN8VQU9&4@
M82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\`26YC
M;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_`$EN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD
M:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO
M;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);F9O<FUA=&EO
M;B!O;B`E<R!0=6)L:6,@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R
M:79A=&4@2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97D`
M26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN+B``26YL:6YE`$EN<V5R="!#7V]L
M=6UN($%F=&5R`$EN<V5R="!#97)T:69I8V%T92!(97)E`$EN<V5R="!);6%G
M90!);G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4`26YS97)T
M(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS97)T(%!U8FQI8R!0
M1U`@2V5Y($AE<F4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E
M<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S
M<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`
M26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C
M;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A
M9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B
M969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L
M:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N
M="X`26YV86QI9"!!9&1R97-S`$EN=F%L:60@4F5M;W1E($UA:6QB;W@`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T
M80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A
M;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N`$EN=F%L:60@
M9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`
M26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&ME>0!);G9A;&ED(&QI8V5N
M<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US
M9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R
M(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO
M;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P
M<FEV871E(&ME>2X`26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`
M26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L
M:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L
M:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E
M;G1O<GD`26YV97)T`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)
M<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)
M<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A
M;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU
M<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F
M=`!*=7-T:69Y(%)I9VAT`$M"`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`
M2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT
M`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2V5Y(&=E;F5R871I;VX@
M;6%Y('1A:V4@82!L;VYG('1I;64@=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W
M:71H(&ME>2!G96YE<F%T:6]N/P!+97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E
M;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC
M(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T
M`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA
M<W0@2&%L9@!,87-T($UA:6QB;W@@4&%G90!,87-T(%!A9V4`3&%S="!1=6%R
M=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U
M=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T
M(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI7VYK($%T=&%C:&UE;G1S
M`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN
M`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI
M9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I
M=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R
M:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:V5D
M(&%T=&%C:&UE;G1S(&%R92!F;W)B:61D96XN`$QI;FMS`$QI;FMS('=I;&P@
M97AP:7)E(&]N("5S`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E
M('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,
M:7-T(%1A8FQE<P!,:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@=&AE
M(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"!O;FQY
M('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI
M`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI
M<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I
M;F<@:6X@=&AE($AE861E<@!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,
M:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG(&QI8G)A<FEE<RXN+@!,;V%D
M:6YG+BXN`$QO8V%L($UA:6QB;W@Z`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD
M(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!I;B!T;R`E<P!,;V<@;W5T`$QO
M9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=R!0<FEO<FET>0!,
M;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@
M<F]M86X@;G5M8F5R<P!,;W=E<W0`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-86-I
M;G1O<V@@1FEL90!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-
M86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SH`
M36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS`$UA
M:V4@;&EN7VLN+BX`36%K92!S=7)E('1H870@>6]U(&AA=F4@4$5!4B!I;G-T
M86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P871H+@!-86MI;F<@9&ER96-T
M;W)Y("5S`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`36%R
M9VEN`$UA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N`$UA<FL@
M06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96X`36%R:R!A<SH`36%R
M:R!D:69F97)E;G0@;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@
M8V]L;W)S/P!-87)K(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI`$UA
M<FL@<VEM<&QE(&UA<FMU<#\`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:"!!;&P@475E
M<FEE<P!-871C:"!!;GD@475E<GD`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N
M:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($%T=&%C:&UE;G0@4VEZ90!-
M87AI;75M(&QE;F=T:`!-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R
M96%C:&5D+@!-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D
M+@!-87D`36%Y;W1T90!-961I8VEN90!-965T:6YG($-A;F-E;&QA=&EO;@!-
M965T:6YG($EN9F]R;6%T:6]N`$UE971I;F<@4')O<&]S86P`365E=&EN9R!2
M97!L>0!-965T:6YG(%5P9&%T90!-965T:6YG(%5P9&%T92!297%U97-T`$UE
M;6)E<G,`365N=2!&;VQD97(@3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS
M`$UE<F=I;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN
M(`!-97)G:6YG(&QO8V%L92`E<RXN+B``365R9VEN9R!T:&4@4$\@9FEL92!F
M;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@`$UE<F=I;F<@=')A;G-L871I
M;VX@9F]R(&UO9'5L92`E<RXN+@!-97-S86=E`$UE<W-A9V4@0V]M<&]S:71I
M;VX`365S<V%G92!$871E`$UE<W-A9V4@3W!T:6]N<P!-97-S86=E(%-E87)C
M:`!-97-S86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@5FEE=VEN9P!-97-S86=E
M(&5X<&ER960N`$UE<W-A9V4@9FEE;&1S`$UE<W-A9V4@9FQA9W,`365S<V%G
M92!F;VQD97)S`$UE<W-A9V4@9G)O;2`E<P!-97-S86=E(&AA<R!A='1A8VAM
M96YT<P!-97-S86=E(&ES(&5N8W)Y<'1E9`!-97-S86=E(&ES('-I9VYE9`!-
M97-S86=E(&UA=&-H97,`365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL
M>2X`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T
M;R`E<P!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+@!-97-S86=E('1Y<&4`
M365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G
M97,@=&\`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO
M="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE
M9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-
M:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y`$UO9&EF>2!54DP`36]D=6QE`$UO9'5L=7,`
M36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N
M9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E('1H
M86X@;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I96QD("(E<R(N`$UO<F]C8V\`
M36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4`
M36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D
M;W=N`$UO=F4@=&\@9F]L9&5R`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP87)T+V%L=&5R;F%T:79E`$UU
M;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T
M86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$Y/5$4`3F%M
M90!.86UE(&%N9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y`$YA;6EB:6$`
M3F%U<G4`3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA
M;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E
M=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@
M4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=F5R
M('-A=F4@871T86-H;65N=',`3F5W`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G
M;W)Y`$YE=R!&;VQD97(`3F5W($UA:6P`3F5W($UO;VX`3F5W(%5S97)N86UE
M("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W(&UE<W-A9V5S`$YE=R!W:6YD
M;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E
M<P!.97AT($UE<W-A9V4`3F5X="!086=E`$YE>'0@;W!T:6]N<P!.97AT/@!.
M:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO($-E<G1I
M9FEC871E(&9O=6YD`$YO($5N8W)Y<'1I;VX`3F\@2V5Y<R!I;B!+97ER:6YG
M`$YO($UE<W-A9V5S`$YO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!0
M97)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT`$YO(%!R979I97<@5&5X=`!.
M;R!0=6)L:6,@2V5Y<R!&;W5N9`!.;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O
M<G1E9"X`3F\@871T86-H;65N=',@9F]U;F0N`$YO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A
M=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD('!E<FUI<W-I
M;VYS(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+@!.;R!C:&EL
M9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VUM
M86YD('-P96-I9FEE9"X`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO
M(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@96UA
M:6P@:6YF;W)M871I;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2X`3F\@
M96YT<GD@=VET:"!T:&4@:60@(B5S(B!E>&ES=',@:6X@=&AE(&]R:6=I;F%L
M(&AE;'`@9FEL92X`3F\@9FEL92!U<&QO861E9`!.;R!F;VQD97(@<V5L96-T
M960N`$YO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M86EL
M+@!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&9O;&1E<G,@=VET:"!N
M97<@;65S<V%G97,`3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<P!.
M;R!L;V-A;&4@<W!E8VEF:65D+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO
M8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E(&)O9'D@=&5X=`!.;R!M97-S
M86=E('-U<'!L:65D+@!.;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H
M+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@
M;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(
M5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P
M96YD:6YG('-I9VYU<',N`$YO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I
M;7!O<G1E9"X`3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N
M`$YO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP;W)T960N`$YO
M(')U;&5S`$YO('-I9&5S`$YO('-P96QL8VAE8VMI;F<@<')O9W)A;2!C;VYF
M:6=U<F5D+@!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S=&EO;G,`3F\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U
M<V5R('-P96-I9FEE9"X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N
M(%!A<G1I8VEP86YT`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@
M*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)M86P`3F]R=&AE<FX@
M2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO
M="!!9G1E<@!.;W0@0F5F;W)E`$YO="!$96QE=&5D`$YO="!$<F%F=`!.;W0@
M26UP;W)T86YT`$YO="!097)S;VYA;`!.;W0@82!D:7)E8W1O<GD`3F]T(&$@
M=F%L:60@<'5B;&EC(&ME>2X`3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM
M<&QE;65N=&5D+@!.;W0@:6UP;W)T86YT(&UE<W-A9V5S`$YO="!S970`3F]T
M('-U<'!O<G1E9"X`3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE
M`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I8V4`3F]V
M96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C
M;VQU;6YS`$YU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T
M=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E<B!O9B!O;&0@
M<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY
M+@!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/4@!/8FIE8W0`3V)J
M96-T($-R96%T;W(`3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,`3V-T86P`
M3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&UE<W-A9V5S`$]L
M9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]M86X`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!D:7-P
M;&%Y(&9O;&1E<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\`3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+@!/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O
M<B!T:&ES(&%C=&EO;BX`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4`3W!E7VX@1F]L9&5R`$]P96X@1F]L9&5R`$]P
M96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YE9"!&
M;VQD97(`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I
M;F<@4WES=&5M`$]P=&EO;F%L(%!A<G1I8VEP86YT`$]P=&EO;G,`3W!T:6]N
M<R!F;W(@)7,`3W!T:6]N<SH`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!-86EL($%C8V]U;G1S`$]T:&5R
M($]P=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%!'4`!01U`@1&EG:71A;"!3:6=N871U<F4`
M4$=0($5N8W)Y<'0@365S<V%G90!01U`@16YC<GEP=&5D($1A=&$`4$=0($5R
M<F]R.B``4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L
M('!R:79A=&4@:V5Y+@!01U`@3D]4($%C=&EV90!01U`@3W!T:6]N<P!01U`@
M4&%S<W!H<F%S92!);G!U=`!01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T
M(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!01U`@4'5B;&EC
M($ME>0!01U`@4'5B;&EC($ME>2!497AT`%!'4"!0=6)L:6,@2V5Y(&9O<B`B
M)7,@*"5S*2(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0(%!U8FQI8R!+
M97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!01U`@4'5B
M;&EC($ME>7)I;F<`4$=0(%-I9VX@365S<V%G90!01U`@4VEG;B]%;F-R>7!T
M($UE<W-A9V4`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!01U`@<')I=F%T
M92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@<'5B;&EC(&ME>2!S=6-C
M97-S9G5L;'D@861D960N`%!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H
M:7,@<WES=&5M+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV
M92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E('9E
M<FEF:65D+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S
M;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+@!01U`@
M<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)
M9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O
M<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@
M96QS92!T:&4@4$=0(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY
M`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`
M4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/
M4#,`4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*0!03U`S(&]V97(@4U-,
M`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*0!03U`S
M(&]V97(@4U-,("AS96QF+7-I9VYE9"D`4$]0,RP@;F\@5$Q3`%!?2%`@4VAE
M;&P`4&%D9&EN9P!086=E("5D(&]F("5D`%!A9V4@=VET:"!T:&4@1FER<W0@
M56YS965N($UE<W-A9V4`4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S
M86=E`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R="AS
M*0!087)T;'D@0VQO=61Y`%!A<W-P:')A<V4`4&%S<W!H<F%S92`H06=A:6XI
M`%!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+@!087-S<&AR87-E
M.@!087-S<&AR87-E<R!C86X@;F]T(&)E(&5M<'1Y`%!A<W-P:')A<V5S(&1O
M(&YO="!M871C:`!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D
M`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S
M(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R
M;6ES<VEO;G,@9F]R`%!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N(&YO
M="!B92!C:&%N9V5D+@!097)S;VYA;`!097)S;VYA;"!);F9O<FUA=&EO;@!0
M97)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0
M97)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2X`4&5R<V]N
M86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z(`!097)S;VYA
M;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2X`4&5R=0!0971S
M`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA
M8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S
M/P!0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E`%!L871I='5D97,`4&QE
M87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92X`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@
M9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.@!0;&5A<V4@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9
M;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N
M8V4@<&5R("5S('-E<W-I;VXN`%!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S
M92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@
M;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S
M<VEO;BX`4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG
M('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@8V]O:VEE<R!!
M3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W
M<RP@>6]U('=I;&P@:&%V92!T;R!L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN
M('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R
M;VT@:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O
M<B!A;GD@:6YC;VYV96YI96YC92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D
M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE+@!0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M
M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E<&]R="!A;GD@8G5G<R!T
M;R!I,3AN0&QI<W1S+FAO<F1E+F]R9RX`4&QE87-E(')E<V]L=F4@86UB:6=U
M;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+@!0;&5A<V4@<F5V:65W('1H92!F
M;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I
M;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('-E;&5C="!A(&9O;&1E
M<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N`%!L96%S92!S96QE
M8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE
M8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N`%!L96%S92!S96QE
M8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BX`4&QE87-E
M('-E;&5C="!O<B!E9&ET(&EN('1H92!B;W@@=&\@=&AE(')I9VAT.@!0;&5A
M<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC
M<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O
M<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H
M;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!O=V5R960@8GD@2&]R9&4`4')E8V5D
M92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/P!0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R
M("\^8VAA;F-E`%!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E
M<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=P!0<F5V:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')E=FEO=7,@
M;W!T:6]N<P!0<FEN=`!0<FEN="!D;V-U;65N=`!0<FEO<FET>0!0<FEV871E
M($ME>0!0<FEV871E($ME>2!087-S=V]R9`!0<F]B;&5M`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O:F5C=',`4')O;7!T(&5V97)Y('1I;64@86X@871T86-H
M;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/`%!R;VUP="!E=F5R>2!T:6UE
M(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,`4')O;7!T
M('1E>'0`4')O=&]C;VPZ`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O
M<G0@:&%S(&)E96X@9&ES86)L960N`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<E]G
M92!$96QE=&5D`%!U<F=E($1E;&5T960`4'5R9V4@1F]L9&5R*',I`%!U<F=E
M(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L
M9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RX`4'5R9V4@;VQD
M(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_`%!U<F=I;F<@)60@;65S
M<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N`%!U<F=I;F<@,2!M97-S86=E(&9R
M;VT@5')A<V@@9F]L9&5R+@!1871A<@!1=65R>0!1=6]T82!S=&%T=7,Z("4N
M,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`475O=&$@<W1A='5S.B`E+C)F34(@
M+R!.3R!,24U)5`!1=6]T82!S=&%T=7,Z($Y/($Q)34E4`%%U;W1I;F<@)68Z
M`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN
M`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N
M;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E7W%U97-T
M($1E;&EV97)Y($-O;F9I<FUA=&EO;@!296%D`%)E860@;65S<V%G97,`4F5A
M;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E8V5I=F5D($]N`%)E8V5I
M=F5D(%-I;F-E`%)E8V5I=F5D(%5N=&EL`%)E9&ER96-?=`!2961I<F5C=`!2
M961I<F5C="!-97-S86=E`%)E9&ER96-T('1H:7,@;65S<V%G90!2961I<F5C
M=&EN9R!F86EL960N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@1F]L9&5R
M(%9I97=S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H
M:7`@0G)O=W-E<@!296QO860`4F5L;V%D(%9I97<`4F5M87)K<P!296UE;6)E
M<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!296UE;6)E<B!T:&4@;&%S
M="!V:65W`%)E;6]T92!-86EL8F]X.@!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@1FEE;&0@1G)O;2!396%R8V@`4F5M;W9E(&-O
M;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4F5M;W9E('-O=7)C90!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E
M;F%M92!&;VQD97(H<RD`4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G
M:6YN:6YG(&]F(&UO;G1H/P!296YA;6EN9R`B)7,B('1O("(E<R(@9F%I;&5D
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%)E<&Q?>2!T;R!,:7-T
M`%)E<&QA8V4@=VET:#H`4F5P;'D`4F5P;'D@4V5N="X`4F5P;'D@=&\@06QL
M`%)E<&QY('1O($%L;#H`4F5P;'D@=&\@3&ES=`!297!L>2!T;R!,:7-T.@!2
M97!L>2!T;R!?06QL`%)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E
M`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+@!297!L
M>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E<&QY
M+51O`%)E<&QY+51O.B``4F5P;'DZ`%)E<&]R="!A<R!);FYO8V5N=`!297!O
M<G0@87,@4W!A;0!297%U97-T(&$@7U)E860@4F5C96EP=`!297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U
M97-T(&1E;&EV97)Y(&-O;F9I<FUA=&EO;C\`4F5Q=65S="!R96%D(')E8V5I
M<'1S/P!297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N`%)E<75E<W1E9"!S
M97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M($9I96QD`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W
M;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S<&]N9&5N="!3=&%T=7,@57!D
M871E9"X`4F5S=6QT<P!297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.@!297-U
M;'1S.@!297-U;64`4F5S=6UE('EO=7(@<V5S<VEO;@!2971U<FX@=&\@1F5T
M8V@@36%I;`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@=&AE(&UA:6QB
M;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG
M(&$@;65S<V%G93\`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D
M97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N
M:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R
M;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N
M`%)W86YD80!3+TU)344`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M`%,O34E-12!%;F-R>7!T($UE<W-A9V4`4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E`%,O34E-12!%<G)O<CH@`%,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR
M87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4R]-24U%($Y/5"!!8W1I
M=F4`4R]-24U%($]P=&EO;G,`4R]-24U%(%!A<W-P:')A<V4@26YP=70`4R]-
M24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`4R]-24U%(%!U8FQI8R!+97D@9F]R("(E<R(@
M=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!3+TU)344@4'5B;&EC($ME>2!S
M=6-C97-S9G5L;'D@861D960N`%,O34E-12!0=6)L:6,@2V5Y<FEN9P!3+TU)
M344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N
M`%,O34E-12!3:6=N($UE<W-A9V4`4R]-24U%(%-I9VXO16YC<GEP="!-97-S
M86=E`%,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M
M+@!3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@
M=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`4R]-24U%
M('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H
M:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO="!B92!D:7-P;&%Y960N`%,O34E-
M12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA
M='5R92!I<R!U;F%B;&4@=&\@8F4@=F5R:69I960N`%,O34E-12!S=7!P;W)T
M(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@
M8G)O=W-E<B!I<R!C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN
M9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H
M92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'D`4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G
M:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-?=6)J96-T
M`%-A`%-A7W9E(&$@8V]P>2!I;B``4V%?=F4@87,`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA
M`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!!='1A8VAM96YT<R!W:71H
M(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\`4V%V92!$<F%F=`!3879E
M($]P=&EO;G,`4V%V92!?1')A9G0`4V%V92!A<P!3879E(&1R869T<R!A<R!U
M;G-E96X_`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4V%V92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@
M861D<F5S<R!B;V]K/P!3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R
M/P!3879E('-E;G0@;6%I;#\`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-A=FEN9R!T:&4@
M9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E
M<P!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H("5S
M`%-E87)C:"!%;F=I;F5S`%-E87)C:"!297-U;'1S`%-E87)C:&EN9R!(;W)D
M92!A<'!L:6-A=&EO;G,@:6X@)7,`4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I
M97,N+BX`4V5E;@!396QE8W0`4V5L96-T($%N;W1H97(@06-C;W5N=`!396QE
M8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!F:65L9`!396QE8W0@
M82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E
M<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@861D<F5S<R!B;V]K
M('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S
M97,N`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E
M;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R
M97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!A;B!O8FIE8W0`4V5L
M96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@
M=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE(&UA:6P@<V5R
M=F5R('1Y<&4`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396QE8W1E9"!!9&1R97-S(&)O;VMS.@!396YD($ME>2!T
M;R!0=6)L:6,@2V5Y<V5R=F5R`%-E;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E
M;F0@365S<V%G90!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F0@
M<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD97(_`%-E
M;F5G86P`4V5N<V]R.B``4V5N="!M86EL(&9O;&1E<@!396YT(&UA:6P@9F]L
M9&5R.@!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.
M=6UB97(`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N`%-E
M<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<G9E<CH`4V5S
M<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+@!3970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M
M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N`%-E="!T:&4@6"U0<FEO<FET>2!H
M96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_`%-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES
M<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F4@1F]L9&5R<P!3:&%R92!M86EL
M(&9O;&1E<G,`4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U
M<V5R<RX`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=6QD(&QA<F=E(&)L
M;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F
M875L=#\@270@8V%N(&)E('1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@
M8VAO;W-E+@!3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E
M<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\`4VAO=6QD('1H92!C;VUP;W-E
M('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W5L
M9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@
M;65S<V%G97,@8GD@9&5F875L=#\`4VAO=P!3:&]W($%L;"!&;VQD97)S`%-H
M;W<@06QL($AE861E<G,`4VAO=R!$96QE=&5D`%-H;W<@3&EM:71E9"!(96%D
M97)S`%-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N`%-H;W<@3VYL>2!3
M=6)S8W)I8F5D($9O;&1E<G,`4VAO=R!5;G-U8G-C<FEB960`4VAO=R!A;B!I
M8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE
M<W-A9V5S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E
M;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('!R979I97=S(&9O<B!U;G)E860@
M;65S<V%G97,@;VYL>3\`4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\`4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/P!3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE
M(&UE;G5B87(_`%-H;W<@=&AE($EM86=E<P!3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@
M:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T;W1A;"!N=6UB97(@;V8@
M;6%I;',@:6X@9F]L9&5R/P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@
M16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H
M;W=N`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VE?>F4`4VEE<G)A($QE;VYE`%-I
M9VX@=7``4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6=N960`4VEN9V%P;W)E`%-I>F4`4VMI<"!-
M86EN=&5N86YC90!3:VEP<&5D+BXN`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`
M4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3
M;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0
M;V5M<P!3;W)T($1I<F5C=&EO;@!3;W)T(&)Y($%R<FEV86P`4V]R="!B>2!$
M871E`%-O<G0@8GD@1G)O;2!!9&1R97-S`%-O<G0@8GD@365S<V%G92!3:7IE
M`%-O<G0@8GD@4W5B:F5C=`!3;W)T(&)Y(%1H<F5A9`!3;W)T(&)Y(%1O($%D
M9')E<W,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U
M=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R
M;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`
M4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!A;2!F
M;VQD97(Z`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P96-I86P@0VAA<F%C
M=&5R<P!3<&5L;"!#:&5C:P!3<&5L;"!#:&5C:V5R`%-P96QL(&-H96-K(&-O
M;7!L971E`%-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@
M8VAE8VMI;F<N`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3
M<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R
M="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&%T=7,@9F]R(&QO
M8V%L92`E<RXN+B``4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R
M:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!!='1A8VAM96YT`%-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T<FEP(&QI;F5B<F5A:W,_`%-T
M>6QE(%M#4U-=`%-U`%-U8E]J96-T`%-U8FIE8W0`4W5B:F5C="!&:65L9`!3
M=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:6)E('1O($9O;&1E<BAS*0!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B
M+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`
M4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U9V=E<W1I;VYS`%-U;6UA
M<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N
M<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P
M<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`
M4W=A>FEL86YD`%-W961E;@!3=VET8V@@0V]M<&]S:71I;VX@365T:&]D`%-W
M:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N`%-W:71C:"!T;R!P;&%I;B!T97AT
M(&-O;7!O<VET:6]N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M
M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!4
M86)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N
M`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5?>'0`5&5L
M97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R
M90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO
M)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E
M($%D;6EN:7-T<F%T:6]N`%1E;G1A=&EV93H@`%1E;G1A=&EV96QY($%C8V5P
M="!R97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E<FUS(&]F(%-E<G9I
M8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP`%1E>'0`5&5X="!/
M;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I
M;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H
M96QP(&9I;&4@9F]R("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A
M(&YE=R!O;F4N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%1H92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI
M;FME9#H`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I
M;FET:6%L:7IE9"X`5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K`%1H92!-
M86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RX`
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`
M5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@86-C;W5N
M="`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@861D<F5S<R`B)7,B(&AA<R!B
M965N(&%D9&5D('1O("5S+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!A='1A8VAM96YT('=A
M<R!N;W0@9F]U;F0N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C86QE;F1A
M<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E
M(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O
M(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!C;VYT86-T($E$(&YU;6)E<B!W
M87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD
M(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&-O;G1E;G1S(&]F
M('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N`%1H92!C=7)R96YT(&9O
M;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N86UE9"!T;R`B)7,B+@!4:&4@8W5R
M<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R
M(&-O=6QD(&YO="!B92!R971R:65V960`5&AE(&1E=&%C:&5D(%!'4"!S:6=N
M871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@
M;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C
M:69I960N`%1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@(B5S(B!F
M;VQD97(N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E=F5N="!W87,@861D960@=&\@>6]U
M<B!C86QE;F1A<BX`5&AE(&9I96QD("(E<R(@8V%N)W0@8F4@97AP86YD960N
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE
M(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L9&5R("(E<R(@86QR96%D>2!E
M>&ES=',`5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL;&5G86P@8VAA<F%C
M=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E('!R;V)L96US+B!0;&5A
M<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!F;VQD97(@
M(B5S(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@
M=&\@:70N`%1H92!F;VQD97(@(B5S(B!W87,@9&5L971E9"!B=70@>6]U('=E
M<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@9F]L9&5R("(E<R(@
M=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S
M9G5L;'D@8W)E871E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L
M;'D@9&5L971E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@
M<F5N86UE9"!T;R`B)7,B+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R
M<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9F]L;&]W
M:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@=&AI<R!P87)T.@!4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+@!4:&4@:&5L<"!F:6QE("5S(&1I9&XG="!S=&%R="!W
M:71H(#P_>&UL`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N
M`%1H92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N
M9&5R(&ES('!R97-E;G0@:6X@>6]U<B!A9&1R97-S8F]O:RX`5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H
M92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M
M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I
M;F<@:6YF;W)M871I;VYA;"!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N
M97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93H`5&AE(&UA:6QB;W@@)7,@
M:7,@86QR96%D>2!E;7!T>2X`5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@
M*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@;&EM:70N`%1H92!M97-S
M86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RX`
M5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"X`5&AE(&UE<W-A9V4@:&%S
M(&)E96X@=F5R:69I960N`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D
M+B!396YD97(Z("5S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER
M960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<&%S
M<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H
M879E('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\`
M5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S
M92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R87<@=&5X="!O
M9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E<RX`5&AE(')E
M<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T
M=&%C:&UE;G0N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I
M;B!T:&4@6FEP(&%T=&%C:&UE;G0N`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5N9&5R(&]F
M('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VX@9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D
M('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE(&YO
M=&EF:6-A=&EO;B!M97-S86=E+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@
M<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@
M=&AI<R!I;6%G92X`5&AE('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C
M960N`%1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"X`
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4
M:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI<W0N`%1H92!S<&5C:69I
M960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E
M9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D
M;V5S(&YO="!E>&ES="X`5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4`5&AE('1E
M>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RX`5&AE('1E>'0@
M;V8@=&AE(')E='5R;F5D(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE(')E='5R
M;F5D(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RX`5&AE('1E>'0@;V8@=&AE
M('-E;G0@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A
M;B!B92!V:65W960@)7,N`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T
M('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N`%1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N`%1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@86QT97)N
M871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE
M<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY
M(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E
M<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H
M97)E(&1O97-N)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RX`5&AE
M<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ
M("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H
M97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@
M<V5R=F5R('-A:60Z("5S`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG
M('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T
M96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S
M<V%G97,@9G)O;2`B)7,B('1O("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S
M(&9R;VT@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!I
M;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<P!4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R
M<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE('1A<VLZ("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+@!4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@;W!E
M;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP
M('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F
M<F]M('1H92!X;6P@<&%R<V5R+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R
M;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE
M87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN
M9R!T:&ES(&UE<W-A9V4@87,@82!D<F%F="X`5&AE<F4@=V%S(&%N(&5R<F]R
M('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<P!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A
M<R!N;R!T97AT(&EN('1H:7,@;65S<V%G92!P87)T`%1H:7,@2%1-3"!M97-S
M86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N`%1H:7,@2%1-3"!M97-S
M86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N($)L;V-K960@:6UA9V5S
M(&%P<&5A<B!L:6ME('1H:7,Z(`!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(%!'4"!0=6)L:6,@2V5Y
M('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92X`5&AI<R!A8W1I;VX@:7,@
M;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE
M;G1E9"X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R
M9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E
M=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N
M(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@
M82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T
M('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N
M9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@
M<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UA>2!T
M86ME('-O;64@=&EM92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O;G1I
M;G5E/P!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92X`
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N`%1H:7,@;65S<V%G
M92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC<GEP
M=&5D('9I82!3+TU)344N`%1H:7,@;65S<V%G92!C;VYT86EN<R!M86EL(&1E
M;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M870@;V8@
M=&AI<R!M97-S86=E(&ES('5N:VYO=VXN`%1H:7,@;65S<V%G92!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N
M($5R<F]R.B``5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I
M;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T("AA8V-O<F1I;F<@=&\@4D9#(#(P
M,34I+@!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H
M92!C;W)R96-T(%,O34E-12!F;W)M870N`%1H:7,@;65S<V%G92!H87,@8F5E
M;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N`%1H:7,@;65S<V%G92!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N`%1H:7,@;65S<V%G
M92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E
M(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"X`5&AI<R!M97-S86=E('1O
M`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O;2!T
M:&4@8V]M;6%N9"!L:6YE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD
M;W<N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N
M<R!W:6YD;W<`5&AR96%D(%9I97<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM
M92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,
M97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O($%D9')E<W,`5&\@
M<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92!C;&EC:VEN9RX`5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`
M5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG
M80!4;W``5&]P(&9R86UE("A?=&]P*0!4;W1A;"!!='1A8VAM96YT<R!3:7IE
M.@!4<F%N<VQA=&5D`%1R86YS;&%T:6]N<P!4<F%S:"!F;VQD97(`5')A<V@@
M9F]L9&5R.@!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`
M5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R
M(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP
M="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')E=')I979E('%U
M;W1A`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I
M;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86YS=V5R
M960`56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T90!5;F1E<FQI;F4`56YD
M:7-C;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`56YD;V5S('EO=7(@
M;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O
M;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!T;SH@`%5N9FEL960`56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E
M<P!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D
M($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N($1A=&4`56YK
M;F]W;B!-965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+@!5;FMN;W=N(&-O;6UA;F0Z("5S`%5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;&]A9"!087-S<&AR87-E
M`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E96X`56YS970@8V]L
M;W(`56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RD`56YS=7!P;W)T960@17AT
M96YS:6]N`%5N=')A;G-L871E9`!5<&1A=&4`57!D871E("5S`%5P9&%T92!!
M='1A8VAM96YT($EN9F]R;6%T:6]N`%5P9&%T92!R97-P;VYD96YT('-T871U
M<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9&%T:6YG("5S(&AE;'`@
M9FEL92!F;W(@)7,N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S
M`%5R=6=U87D`57-A9V4Z`%5S92!#=7)R96YT.B`E<P!5<V4@1&5F875L="!6
M86QU90!5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\`57-E(%-33`!5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+@!5<V5R`%5S97(@(B5S(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE('-P
M96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(BX`57-E<B`E<R!I
M<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`
M57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T
M:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@<&5R
M;6ES<VEO;G,`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T
M<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,`57-E<G,@:6X@=&AE('-Y
M<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A
M;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V
M97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O
M('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF
M:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T
M86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A
M;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`
M5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W`%9I97<@)7,`5FEE
M=R`E<R!0=6)L:6,@2V5Y`%9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W`%9I97<@4&5R<V]N86P@4')I=F%T92!+97D`5FEE=R!097)S
M;VYA;"!0=6)L:6,@2V5Y`%9I97<@5&AR96%D`%9I97<@5&AU;6)N86EL`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W(&%T=&%C
M:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!C;VYT96YT(&EN(&$@
M<V5P87)A=&4@=VEN9&]W`%9I97<@979E;G0`5FEE=R!M97-S86=E<R!I;B`E
M<P!6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CH`5FEE
M=R!T87-K`%9I97<@=&AE($EM86=E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7)T=6%L($9O;&1E<B`B)7,B(&-R
M96%T960@<W5C8V5S9G5L;'DN`%9I<G1U86P@1F]L9&5R<P!6:7)T=6%L($9O
M;&1E<G,@<F5Q=6ER92!A(&QA8F5L+@!6:7)T=6%L(&9O;&1E<B!L86)E;`!6
M:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=A<FYI;F<Z(`!790!7
M96%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T
M:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T
M;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N
M("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@
M9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C
M=&5R/P!7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U
M<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@87,@9&5L
M971E9#\`5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@
M9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E;G0M;6%I
M;"P@<VAO=6QD('=E('-A=F4@871T86-H;65N="!D871A/P!7:&5N('-E;F1I
M;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S
M:&]U;&0@=V4@87!P96YD('1O('5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA
M:6P@861D<F5S<V5S('=I=&AO=70@(D`B*3\`5VAI8V@@<&AA<V5S`%=H:6-H
M('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`
M5VAI=&5L:7-T`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z
M`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!7<F%P('1E>'0@870@=&AI<R!M86YY(&-H87)A8W1E<G,N
M`%=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@)7,N`%@M4F5F`%@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E
M`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE
M8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!9
M86AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A
M<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C
M8V]U;G0H<RDZ`%EO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE
M<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`
M66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O
M;&1E<BAS*2X`66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD
M97(N`%EO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O(`!9;W4@87)E
M(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BX`66]U(&%R92!I;B!415A4
M($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O
M(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!A<F4@
M<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!C86X@;F]T('5N
M<W5B<V-R:6)E(&9R;VT@(B5S(BX`66]U(&1I9"!N;W0@86=R964@=&\@=&AE
M(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@=V5R92!N;W0@
M86QL;W=E9"!T;R!L;V=I;BX`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E
M;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@
M=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S
M(&EN("5S+@!9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@
M86-C97-S('1O('1H:7,@9F]L9&5R`%EO=2!F;W)W87)D960@=&AI<R!M97-S
M86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+@!9
M;W4@:&%V92`E<R!N97<@;65S<V%G97,N`%EO=2!H879E(#$@;F5W(&UE<W-A
M9V4N`%EO=2!H879E(&%T(&QE87-T(&]N92!A='1A8VAM96YT('-E;&5C=&5D
M('1H870@>6]U(&1I9&XG="!U<&QO860@>65T+B!!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<V5N9"!T:&ES(&UE<W-A9V4@=VET:&]U="!T:&5S92!A='1A
M8VAM96YT<S\`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!N
M97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CH`66]U(&AA=F4@;F5W
M(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.@!9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I
M=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!A="!L96%S
M="!O;F4@<F5C:7!I96YT+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@96YT97(@=&AE('!A<W-P
M:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M
M97-S86=E`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9;W4@
M;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="X`66]U(&UU<W0@
M<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L
M96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!S97)V
M97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N
M92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT
M+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S
M="!S<&5C:69Y(&%T(&QE87-T(&]N92!F:6QE('1O(&%T=&%C:"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!H879E("(E<R(@96YA8FQE9"!I
M;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N`%EO=2!N965D('1O('!R;W9I
M9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U(')E9&ER96-T960@=&AI
M<R!M97-S86=E('1O("5S(&]N("4E<RX`66]U(')E<&QI960@=&\@=&AI<R!M
M97-S86=E(&]N("5S+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B
M+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U
M;G-U8G-C<FEB960@9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%EO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E
M<R(`66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E
M<R(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@
M86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z
M`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+@!9;W5R($YA;64`66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<P!9
M;W5R(%!R:79A=&4@2V5Y`%EO=7(@4'5B;&EC($ME>0!9;W5R(%)E<&QY+71O
M.B!A9&1R97-S.B`\:3XH;W!T:6]N86PI/"]I/@!9;W5R(%,O34E-12!0=6)L
M:6,O4')I=F%T92!#97)T:69I8V%T97,`66]U<B!A8V-O=6YT<SH`66]U<B!A
M;&EA<R!A9&1R97-S97,Z(#QI/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R
M97-S(&]N(&$@;F5W(&QI;F4I/"]I/@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92X`66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT
M('1I;64@>F]N93H`66]U<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@
M;65S<V%G97,Z`%EO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@
M<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R
M(&9U;&P@;F%M93H`66]U<B!G971T97AT('9E<G-I;VX@:7,@=&]O(&]L9"!A
M;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN"DYO="!A;&P@<W1R
M:6YG<R!W:6QL(&)E(&5X=')A8W1E9"X`66]U<B!M97-S86=E('=A<R!S=6-C
M97-S9G5L;'D@9&5L:79E<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@
M:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE
M(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T
M92!S97)V97)S.@!9;W5R('-I9VYA='5R93H`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M.;R!3
M=6)J96-T70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`
M6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=
M`%]!9&UI;FES=')A=&EO;@!?0F-C`%]";&%C:VQI<W0`7T-,20!?0V,`7T-O
M;7!O<V4`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2;W<`7T9O;&1E<G,`
M7T=R;W5P<P!?2&5L<`!?261E;G1I='D`7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TEN8F]X`%],;V<@:6X`7TQO9R!O=70`7TUE<W-A9V4@4V]U<F-E`%]-;V1I
M9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U!R:6YT`%]0<FEO
M<FET>0!?4F5F<F5S:"`E<P!?4F5M;W9E($QI;FLN+BX`7U)E<&QY`%]396%R
M8V@`7U-E;F0@365S<V%G90!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`
M7U1H<F5A9`!?5&\`7U5N9&5L971E`%]5<V5R<P!?5FEE=R!4:')E860`7U=H
M:71E;&ES=`!A9&1R97-S(&)O;VL`86X@97)R;W(@:&%S(&]C8W5R960Z`&%T
M=&%C:&UE;G0`871T86-H;65N=',N>FEP`&)Y=&5S`&-A;&5N9&%R`&-A;&T`
M8VQI8VL@:&5R90!D;VYE`&9A:6QE9`!F86QL:6YG`&9I;&4`9F]U;F0Z(`!F
M<F]M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!I
M;6UE9&EA=&4`:6YL:6YE`&ME>0!L:6YE<UT`;6%I;&)O>"!F:6QE`&UK:7-O
M9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO
M;F4`;F]T(&-H86YG960`;F]T(&9O=6YD`&YO="!I;7!L96UE;G1E9`!N;W0@
M>65T(&EM<&QE;65N=&5D`&YO=&5P860`;W(`<&5R8V5N=`!P:7AE;',`<FES
M:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-P96QL
M:6YG(&5R<F]R`'-P96QL:6YG(&5R<F]R<P!S<P!S=&5A9'D`=&%S:R!L:7-T
M`'1H92!(;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T
M(&5X:7-T.@!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N
M:69I960`=6YN86UE9`!U<&1A=&5D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E
M871H97(N8V]M`'EO=7(@8FQA8VML:7-T`'EO=7(@=VAI=&5L:7-T`%!R;VIE
M8W0M260M5F5R<VEO;CH@24U0(#0N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3,@,3<Z,3,K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`Q
M+3`W(#$X.C(U("LP,C`P"DQA<W0M5')A;G-L871O<CH@3G5N;R!,;W5R96ER
M;R`\;G5N;T!E=&@N<'0^"DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T
M=6=U97-E(#QD979`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`("`@(%!A<F$Z
M(``@("`@1&%T83H@`"`@("`@($1E.B``("`M32P@+2UM97-S86=E/4U%3E-!
M1T5-(%5S87(@97-T82!M96YS86=E;2!D92!C;VUE=&EM96YT;R!E;2!V97H@
M9&$*("`@("`@("`@("`@("`@("`@("`@("`@(&UE;G-A9V5M('!O<B!O;6ES
M<^-O+@`@("UA+"`M+6%D9#U!4E%5259/("`@("!!9&EC:6]N87(@97-T92!A
M<G%U:79O(%!/(&%O(&-O;7#J;F1I;RX@571I;"!P87)A"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU:7(@=6T@8V]M<.IN9&EO(&1E('5M(')A;6\@
M9&EF97)E;G1E(&YO"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;7#J;F1I
M;R!G97)A9&\N`"`@+6(L("TM8F%S93TO0T%-22`@0V%M:6YH;R!P87)A(&\@
M9&ER96-T\W)I;R!B87-E("A(;W)D92D@82!U<V%R+@`@("UC+"`M+6-O;7!E
M;F1I=6T]05)152`@26YT96=R87(@;F]V87,@=')A9'7G]65S(&$@97-T92!A
M<G%U:79O(&1E(&-O;7#J;F1I;PH@("`@("`@("`@("`@("`@("`@("`@("`@
M92!NXV\@86\@8V]M<.IN9&EO('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O
M(&YA"B`@("`@("`@("`@("`@("`@("`@("`@("!P87-T82!H;W)D92]P;RX`
M("`M8RP@+2UC;VUP96YD:75M/4%2454@(%5S87(@97-T92!A<G%U:79O(&1E
M(&-O;7#J;F1I;R!E;2!V97H@9&\@87)Q=6EV;PH@("`@("`@("`@("`@("`@
M("`@("`@("`@<&]R(&]M:7-SXV\@*&-O;7!E;F1I=6TN<&\@;F$@<&%S=&$@
M:&]R9&4O<&\N`"`@+60L("TM9&5B=6<@("`@("`@36]S=')A<B!M96YS86=E
M;G,@9&4@97)R;R!D;W,@8FENX7)I;W,@97AE8W5T861O<RX`("`M9"P@+2UD
M:7)E8W1O<GD]4$%35$$@0W)I87(@=6T@8V]M<.IN9&EO(&YE<W1A('!A<W1A
M+@`@("UH+"`M+6AE;'`@("`@("`@($UO<W1R87(@97-T82!M96YS86=E;2!D
M92!A:G5D82X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S87(@87!E;F%S
M(&5S=&$@;&]C86QI>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5
M<V%R(&5S=&$@;&]C86QI>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@
M(%5S87(@97-T82!L;V-A;&EZ8>?C;RX`("`M;2P@+2UM;V1U;&4]3=-$54Q/
M("`@($-O;G-T<G5I<B!A<G%U:79O<R!-3R!A<&5N87,@<&%R82!E<W1E(&WS
M9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@
M+2UM;V1U;&4]3=-$54Q/("`@($QI;7!A<B!A<G%U:79O<R!03R!A<&5N87,@
M<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO
M<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-O;65T97(@87,@=')A
M9'7G]65S(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@
M("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@
M0W)I87(@;R!A<G%U:79O(%!/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO"B`@
M("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO9'5L
M93U-TT153$\@("`@26YT96=R87(@87)Q=6EV;W,@4$\@87!E;F%S('!A<F$@
M97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN
M`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!!8W1U86QI>F%R(&%R<75I=F]S
M(&1E(&%J=61A(&%P96YA<R!P87)A(&5S=&4*("`@("`@("`@("`@("`@("`@
M("`@("`@(&WS9'5L;R`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@06-T=6%L:7IA<B!A<&5N87,@97-T92!M\V1U;&\@*$AO<F1E*2X`("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($=E<F%R(&%R8VAI=F\@4$]4(&%P96YA
M<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H
M2&]R9&4I+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@3N-O(&EN=&5G<F%R
M(&YO=F%S('1R861UY_5E<R!N;R!C;VUPZFYD:6\N`"`@+6XL("TM;F\M8V]M
M<&5N9&EU;2`@("!.XV\@=7-A<B!U;2!C;VUPZFYD:6\N`"`@+7,L("TM<W1A
M=&ES=&EC<R`@("`@("!'=6%R9&%R(&5S=&%T[7-T:6-A<R!D92!T<F%D=>?C
M;R!N=6T@9FEC:&5I<F\@;&]C86PN`"`@+70L("TM=&5S="`@("`@("`@36]S
M=')A<B!O<R!P<F]G<F%M87,@82!E>&5C=71A<B!M87,@;N-O(&\@9F%Z97(N
M`"`@8VQE86YU<"`@("`@3&EM<&%R(&]F(&%R<75I=F]S(%!/(&1E(&5N=')A
M9&%S('!O<B!T<F%D=7II<B!O=2!O8G-O;&5T87,N`"`@8V]M;6ET("`@("`@
M0V]M971E<B!A<R!T<F%D=>?U97,@;F\@<V5R=FED;W(@0U93+@`@(&-O;6UI
M="UH96QP($-O;65T97(@87)Q=6EV;W,@9&4@86IU9&$@;F\@<V5R=FED;W(@
M0U93+@`@(&-O;7!E;F1I=6T@(%)E8V]N<W1R=6ER(&\@87)Q=6EV;R!D92!C
M;VUPZFYD:6\N($%T96[GXV\Z($\@;F]V;R!A<G%U:79O"B`@("`@("`@("`@
M("`@<V]B<F5P]64M<V4@86\@86YT:6=O+@`@(&5X=')A8W0@("`@($=E<F%R
M(&%R<75I=F]S(&UO9&5L;R!03R`H+G!O="DN`"`@:&5L<"`@("`@("`@36]S
M=')A<B!E<W1A(&UE;G-A9V5M(&1E(&%J=61A+@`@(&EN:70@("`@("`@($-R
M:6%R('5M(&]U(&UA:7,@87)Q=6EV;W,@4$\@<&%R82!U;6$@;F]V82!L;V-A
M;&EZ8>?C;RX*("`@("`@("`@("`@("!!=&5NY^-O.B!/<R!N;W9O<R!A<G%U
M:79O<R!S;W!R97#U96TM<V4@86]S(&%N=&EG;W,N`"`@;6%K92`@("`@("`@
M0V]N<W1R=6ER(&%R<75I=F]S(&)I;N%R:6]S($U/(&$@<&%R=&ER(&1O<R!A
M<G%U:79O<PH@("`@("`@("`@("`@(%!/(&5S<&5C:69I8V%D;W,N`"`@;6%K
M92UH96QP("`@36%R8V%R('1O9&%S(&%S(&5N=')A9&%S(&YO(&%R<75I=F\@
M6$U,(&1E(&%J=61A(&-O;6\@97-T86YD;PH@("`@("`@("`@("`@(&%C='5A
M;&EZ861A<R!E('!R97!A<F%R(&\@87)Q=6EV;R!P87)A(&$@<'+S>&EM82!E
M>&5C=>?C;PH@("`@("`@("`@("`@(&1E('5P9&%T92UH96QP+B!$979E+7-E
M(&5X96-U=&%R(&UA:V4M:&5L<"!$15!/25,@9&4*("`@("`@("`@("`@("!U
M<&1A=&4M:&5L<"!E(&1E(')E=F5R(&\@87)Q=6EV;R!D92!A:G5D82X`("!M
M97)G92`@("`@("!);G1E9W)A<B!O(&%R<75I=F\@4$\@8V]R<F5N=&4@8V]M
M(&\@87)Q=6EV;R!M;V1E;&\@4$\@8V]R<F5N=&4N`"`@=7!D871E("`@("`@
M17AE8W5T87(@97AT<F%C="!E(&UE<F=E(&5M('-E<77J;F-I82X`("!U<&1A
M=&4M:&5L<"!%>'1R86ER('1O9&%S(&%S(&5N=')A9&%S(&YO=F%S(&4@;6]D
M:69I8V%D87,@9&\@87)Q=6EV;R!D90H@("`@("`@("`@("`@(&%J=61A(%A-
M3"!E;2!I;F=LZG,@92!I;G1E9W+A+6QA<R!C;VT@87,@97AI<W1E;G1E+@`@
M)B,Q-3$[("5S(&5S=.$@<')O;G1O('!A<F$@969E8W1U87(@87,@;W!E<F'G
M]65S(&1E(&UA;G5T96[GXV\@;6%R8V%D87,@86)A:7AO+@`@*"5S(&1I87,@
M871RX7,I`"`H0VAA=F4@9&4@86-E<W-O("5S*0`@*&1E;G1R;R!D92`E<R!D
M:6%S*0`@*&AO:F4I`"`H86UA;FCC*0`@*&]N=&5M*0`@07-S=6YT;SH@`"!C
M;VT@`"!E;2`@`"(E<R(@;N-O(.D@=6UA(&5S8V]L:&$@=N%L:61A+@`B)7,B
M(&[C;R!E<W3A(&-O;F9I9W5R861O(&YO(%)E9VES=&\@9&\@2&]R9&4N`"(E
M<R(@<F5P<F5S96YT861O<B!D92#A<G9O<F4@;N-O(&5N8V]N=')A9&\N`"(E
M<R(@9F]I(&%D:6-I;VYA9&\@86\@<VES=&5M82!D92!G<G5P;W,N`"(E<R(G
M(&9O:2!A9&EC:6]N861O(&%O('-I<W1E;6$@9&4@<&5R;6ES<_5E<RX`(B5S
M(B!NXV\@9F]I(&-R:6%D;SH@)7,N`",`)2XR9DU"("\@)2XR9DU"("`H)2XR
M9B4E*0`E9"`E<R!E("5S`"5D(&)Y=&5S(&5S8W)I=&]S`"5D(&UE;G-A9V5N
M<R!F;W)A;2!R96UO=FED87,N`"5D(&UE;G-A9V5N<R!F;W)A;2!R97!O<G1A
M9&%S(&-O;6\@;N-O('-P86T@86\@<V5U(&%D;6EN:7-T<F%D;W(@9&4@<VES
M=&5M87,N`"5D(&UE;G-A9V5N<R!F;W)A;2!R97!O<G1A9&%S(&-O;6\@;N-O
M('-P86TN`"5D(&UE;G-A9V5N<R!F;W)A;2!R97!O<G1A9&%S(&-O;6\@<W!A
M;2!A;R!S974@861M:6YI<W1R861O<B!D92!S:7-T96UA<RX`)60@;65N<V%G
M96YS(&9O<F%M(')E<&]R=&%D87,@8V]M;R!S<&%M+@`E9"!D92`E9"!E;G1R
M861A(&UA<F-A9&%S(&-O;6\@86-T=6%L:7IA9&%S`"5D(&$@)60@9&4@)60@
M365N<V%G96YS`'!R979I<^-O(&1E("5D(&1I87,`)7,@+2!.;W1I9FEC8>?C
M;P`E<R!!9&UI;FES=')AY^-O`"5S($EM<')E<W/C;R!$:6=I=&%L`"5S($M"
M`"5S($]P97)AY_5E<R!D92!-86YU=&5NY^-O("T@0V]N9FER;6'GXV\`061M
M:6YI<W1R8>?C;R!D;R!01U`@<&%R82`E<P!!9&UI;FES=')AY^-O(&1O(%,O
M34E-12!P87)A("5S`$-O;F9I9W5R87(@)7,`)7,@4W5B<V-R979E<@`E<R!4
M97)M;W,@9&\@06-O<F1O`"5S(&KA(&5X:7-T92X`)7,@:N$@97AI<W1E+B!!
M('!A<W1A("5S(&[C;R!F;VD@<F5N;VUE861A+@`E<R!E;2`E<R`E<P`E<R!N
MXV\@<&%R96-E('-E<B!U;6$@8V%I>&$@<&]S=&%L(';A;&ED82X`02!P87-T
M82`E<R!S97+A(')E;F]M96%D82!N;R!I;NUC:6\@9&\@;>IS+@`E<R!A8V5I
M=&]U+@`E<R!C86YC96QO=2`E<RX`)7,@9&5C;&EN;W4N`"5S(')E<W!O;F1E
M=2!A('5M('!E9&ED;R!L:79R92]O8W5P861O+@`E<R!R97-P;VYD974@86\@
M8V]N=FET92!P87)A("5S+@`E<R!E;G9I;W4M;&AE(&EN9F]R;6'GXV\@;&EV
M<F4O;V-U<&%D;RX`)7,@86-E:71O=2!T96YT871I=F%M96YT92X`;N-O('-E
M('!O9&4@97-C<F5V97(@96T@)7,N`"5S(.D@;V)R:6=A=/-R:6\`)7,@;6EN
M=71O<P`E<R!NXV\@9F]I(&5N8V]N=')A9&\N`"5S(&[C;R!F;VD@96YC;VYT
M<F%D;RX@17AE8W5T87(@)W1R86YS;&%T:6]N(&5X=')A8W0G('!R:6UE:7)O
M+@`E<R!S;VQI8VET82UL:&4@82!S=6$@:6YF;W)M8>?C;R!L:79R92]O8W5P
M861O+@`E<R!P961E(&$@<W5A('!R97-E;N=A(&5M("5S+@`E<R!A("5S(&1E
M("5S`"5S(&9O:2!A9&EC:6]N861A(&-O;2!S=6-E<W-O(&$@)7,N`"5S(&1E
M<V5J82!C;W)R:6=I<B`E<RX`)7,@9&5S96IA(&%V:7/A+6QO(&1E('%U92`E
M<RX`)7,@9&5S96IA(')E8V5B97(@82!I;F9O<FUAY^-O(&UA:7,@86-T=6%L
M:7IA9&$@<V]B<F4@)7,N`$-O;G1A8W1O<R!D92`E<P!#86QE;F3A<FEO(&1E
M("5S`$YO=&%S(&1E("5S`%1A<F5F87,@9&4@)7,`)7,Z("5S`"5S.B`E<R`H
M)60F;F)S<#MD929N8G-P.R5D*0`H169E8W1U87(@86QT97)AY_5E<R!E(&%V
M86[G87(@<&%R82!A('!R\WAI;6$@<.%G:6YA+BD`*$-A;F-E;&%R('1O9&%S
M(&%S(&%L=&5R8>?U97,@92!R971O<FYA<B#@(&IA;F5L82!D92!E<V-R:71A
M(&1E(&UE;G-A9V5M+BD`*%9O;'1A<B#@(&IA;F5L82!D92!C;VUP;W-IY^-O
M(&1E<&]I<R!D92!E9F5C='5A<B!A<R!A;'1E<F'G]65S(&9E:71A<R!A=.D@
M86\@;6]M96YT;RX@07,@86QT97)AY_5E<R!N82!J86YE;&$@86-T=6%L($[#
M3R!S97+C;R!E9F5C='5A9&%S+BD`*$5N=FEA<B!M96YS86=E;2!D97!O:7,@
M9&4@87!L:6-A<B!T;V1A<R!A<R!A;'1E<F'G]65S(&9E:71A<R!A=.D@86\@
M;6]M96YT;RX@07,@86QT97)AY_5E<R!N82!J86YE;&$@86-T=6%L($[#3R!S
M97+C;R!E9F5C='5A9&%S+BD`*B!!9&EC:6]N92!C;&EC86YD;R!E;2!/2R`J
M`"H@4&]R(&9A=F]R('-E;&5C8VEO;F4@96YD97)EYV\H<RD@*@`L(&-O;2!R
M86IA9&%S`"P@8V]M(')A:F%D87,@)7,@)7,`+"!V87)IX79E;"!D92`E<R!A
M("5S`"TM(&5S8V]L:&$@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M`#$@;65N<V%G96T@9F]I(')E;6]V:61A+@`Q(&UE;G-A9V5M(&9O:2!R97!O
M<G1A9&$@8V]M;R!NXV\@<V5N9&\@<W!A;2!A;R!S974@861M:6YI<W1R861O
M<B!D92!S:7-T96UA+@`Q(&UE;G-A9V5M(&9O:2!R97!O<G1A9&$@8V]M;R!N
MXV\@<V5N9&\@<W!A;2X`,2!M96YS86=E;2!F;VD@<F5P;W)T861A(&-O;6\@
M<W!A;2!A;R!S974@861M:6YI<W1R861O<B!D92!S:7-T96UA+@`Q(&UE;G-A
M9V5M(&9O:2!R97!O<G1A9&$@8V]M;R!S<&%M+@`Q,#`@8V%R86-T97)E<P`Q
M,#`P(&-A<F%C=&5R97,`1F]R;6%T;R!D92`Q,B!H;W)A<R`H04TO4$TI`$9O
M<FUA=&\@9&4@,C0@:&]R87,`,C0@:&]R87,`,C4P(&-A<F%C=&5R97,`-3`P
M(&-A<F%C=&5R97,`/$%N=&5R:6]R`&5T:7%U971A(#QG971T97AT/B!P;W(@
M9F5C:&%R(&YO(&9I8VAE:7)O("5S+@I!8G)I;F1O(&$@971I<75E=&$@96YC
M;VYT<F%D82!N82!L:6YH82`E9"X`17-T92!B;&]C;R!E>&EG92!U;2!M96-A
M;FES;6\@=7-A;F1O(&)A<V5S(&1E(&1A9&]S+@!/8V]R<F5U('5M(&5R<F\@
M9F%T86P`56UA(&=R86YD92!I;6%G96T@8VAA;6%D82`E<R#I(&%N97AO(&1E
M<W1A(&UE;G-A9V5M+@!5;6$@;65N<V%G96T@<&]R('-I(&5N=FEA9&$@<F5S
M=6QT;W4@;G5M82!N;W1I9FEC8>?C;R!D92!R971O<FYO(&1O(&1E<W1I;F%T
MX7)I;RX`R2!N96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%!'4"!P87)A
M(&5N8W)I<'1A<B!A(&UE;G-A9V5M+@#)(&YE8V5S<^%R:6$@=6UA(&-H879E
M('#Z8FQI8V$@4$=0('!A<F$@=F5R:69I8V%R(&$@87-S:6YA='5R82!D92!U
M;6$@;65N<V%G96T`4&%R82!D96-I9G)A<B!U;6$@;65N<V%G96T@<^-O(&YE
M8V5S<^%R:6%S('5M82!C:&%V92!P^F)L:6-A(%!'4"P@=6UA(&-H879E('!R
M:79A9&$@4$=0(&4@=6UA(&9R87-E+7!A<W-E+@!087)A(&%S<VEN87(@=6UA
M(&UE;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!0
M1U`L('5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!F<F%S92UP87-S92X`
M4&%R82!D96-I9G)A<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M
M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-
M24U%(&4@=6UA(&9R87-E+7!A<W-E+@!087)A(&%S<VEN87(@=6UA(&UE;G-A
M9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!3+TU)344L
M('5M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M82!F<F%S92UP87-S92X`
MR2!N96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%,O34E-12!P87)A(&5N
M8W)I<'1A<B!U;6$@;65N<V%G96TN`$[Z=F5N<R!D92!M86YHXP!#:'5V:7-C
M;W,@9&4@36%N:.,`0VAU=F$@9&4@;6%N:.,`06=U86-E:7)O<R!D92!M86YH
MXP!.97;U97,@9&4@;6%N:.,`04TO4$T`10!!4$D@240`06-E<F-A(&1E<W1E
M(&5D:71O<@!!8V5R8V$N+BX`0F%S97,@86QI;FAA9&%S`$-E;G1R;W,@86QI
M;FAA9&]S`$%C96ET87(@<&5D:61O`$%C96ET87(@<&5D:61O(&4@861I8VEO
M;N$M;&\@86\@;65U(&-A;&5N9.%R:6\`06-E:71E`$%C96ET93H`06-E<W-O
M(&YE9V%D;R!A;R!C<FEA<B!P87-T82!61E,N`$%C97-S;R!N96=A9&\@86\@
M8W)I87(@87)Q=6EV;R!61E,N`%!A;&%V<F$M4&%S<V4@9&$@0V]N=&$`0V]N
M=&$@8V]N9V5L861A+@!.;VUE(&1A(&-O;G1A.@!#;VYT86)I;&ED861E`$%C
MY_5E<P!!9&EC:6]N87(`061I8VEO;F%R($=R=7!O($9I;&AO`$%D:6-I;VYA
M<B!097)M:7-SXV\@1FEL:&$`06-R97-C96YT87(@07%U:3H`061D:6-I;VYA
M<B!.;W9O($=R=7!O`$%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C;P!!9&EC:6]N
M87(@=6T@9W)U<&\@9FEL:&\@82`B)7,B`$%D:6-I;VYA<B!U;6$@<&5R;6ES
M<^-O(&9I;&AA(&$@(B5S(@!!9&EC:6]N87(@;F]V;R!U=&EL:7IA9&]R.@!!
M9&EC:6]N87(@8V]L=6YA`$%D:6-I;VYA<B!N;W9O<R!M96UB<F]S`$%D:6-I
M;VYA<B!P87)C96ER;P!!9&EC:6]N87(@9F]N=&4`061I8VEO;F%R(&\@365N
M=2`E<R!C;VUO($)A<G)A($QA=&5R86P@36]Z:6QL80!!9&EC:6]N87(@:7-T
M;R!A;R!M974@8V%L96YDX7)I;P!!9&EC:6]N87(@86\@3&EV<F\@9&4@16YD
M97)EYV]S("@E<RD`061I8VEO;F%R(&%O<R!#;VYT86-T;W,Z`$%D:6-I;VYA
M<B!A;W,@;65U<R!C;VYT86-T;W,`061I8VEO;F%R('5T:6QI>F%D;W(`(B5S
M(B!I;F-L=>UD;R!C;VUO(&%N97AO+@!!9&EC:6]N96D@(B5S(B!A;R!S:7-T
M96UA+"!M87,@;N-O('!U9&4@861I8VEO;F%R(&EN9F]R;6'GXV\@9&4@<W5B
M<V-R:>?C;R!A9&EC:6]N86PZ("5S+@!!9&EC:6]N96D@(B5S(B!A;R!S:7-T
M96UA+B!*X2!P;V1E(&5N=')A<BX`061I8VEO;F%N9&\@;F]V;W,@87)Q=6EV
M;W,@86\@<F5P;W-I=/-R:6\Z`$$@861IY^-O(&1E('5T:6QI>F%D;W)E<R!E
M<W3A(&1E<V%C=&EV861A+@!#86)EYV%L:&]S(&%D:6-I;VYA:7,@82!M;W-T
M<F%R('%U86YD;R!V:7-U86QI>F%N9&\Z(#QI/BAO<&-I;VYA;"P@8V%D82!C
M86)EYV%L:&\@96T@<W5A(&QI;FAA*3PO:3X`26YF;W)M8>?C;R!A9&EC:6]N
M86P@<&]D92!S97(@=FES=&$@)7,N`%!O<FUE;F]R97,@861I8VEO;F%I<R!D
M82!I;F9O<FUAY^-O`%!O<FUE;F]R97,@861I8VEO;F%I<R!D82!M96YS86=E
M;0!0;W)M96YO<F5S(&%D:6-I;VYA:7,@9&$@;65N<V%G96T@<&]D96T@<V5R
M('9I<W1O<R`E<RX`4&]R;65N;W)E<R!A9&EC:6]N86ES(&1A(&UE;G-A9V5M
M(&1E(&5R<F\`4&]R;65N;W)E<R!D92!E<G)O(&%D:6-I;VYA:7,@9&$@;65N
M<V%G96T@<&]D96T@<V5R('9I<W1O<R`E<RX`16YD97)EYV\`3&EV<F\@9&4@
M16YD97)EYV]S`$QI<W1A<R!D92!#;VYT86-T;W,`16YD97)EYV]S(&%O<R!Q
M=6%I<R!E;G9I87(@8V]M;R!#8V\@=&]D87,@87,@;65N<V%G96YS.B`\:3XH
M;W!C:6]N86PL(&-A9&$@96YD97)EYV\@96T@<W5A(&QI;FAA*3PO:3X`16YD
M97)EYV]S(&$@;&EG87(@97AP;&EC:71A;65N=&4@82!E<W1A(&ED96YT:61A
M9&4Z(#QI/BAO<&-I;VYA;"P@8V%D82!E;F1E<F7G;R!E;2!S=6$@;&EN:&$I
M/"]I/@!!9&UI;FES=')A<B`M(&%T<FEB=6ER('!E<FUI<W/U97,@82!O=71R
M;W,@=71I;&EZ861O<F5S`$%D;6EN:7-T<F'GXV\`06[Z;F-I;W,`069E9V%N
M:7-TXV\`06QBXFYI80!!<F?I;&EA`$%L8W5N:&$`06QI;FAA<@!!;&EN:&%M
M96YT;SH`5'5D;P!4;V1O<R!O<R!5=&EL:7IA9&]R97,@075T96YT:6-A9&]S
M`%1O9&]S(&]S($=R=7!O<P!4;V1A<R!A<R!097)M:7-S]65S`%1O9&]S(&]S
M("AQ=6%T<F\I(&QA9&]S`%1O9&%S(&%S(&UE;G-A9V5N<R!D82AS*2!S96=U
M:6YT92AS*2!P87-T87,H<RD@<V5RXV\@<'5X861A<R!P87)A('5M(/IN:6-O
M(&%R<75I=F\@34)/6"``5&]D87,@87,@;65N<V%G96YS(&1A('!A<W1A("(E
M<R(@8V]M(&UA:7,@9&\@<75E("5S(&1I87,@<V5RXV\@<&5R;6%N96YT96UE
M;G1E(')E;6]V:61A<RX`5&]D;W,@;W,@86YE>&]S(&-O;2!L:6=AY_5E<R!C
M;VT@;6%I<R!D92`E<R!M97-E<R!S97+C;R!R96UO=FED;W,N`%1O9&%S(&%S
M('!A<W1A<R!D92!M96YS86=E;G,@96YV:6%D87,@8V]M(&UA:7,@9&\@<75E
M("5S(&UE<V5S('-E<N-O(')E;6]V:61A<RX`5&]D;W,@;W,@9&ER96ET;W,@
M<V]B<F4@82!P87-T82`B)7,B(&9O<F%M(')E;6]V:61O<R!C;VT@<W5C97-S
M;R!P87)A(&\@=71I;&EZ861O<B`B)7,B+@!097)M:71I<B!A(&%P;&EC8>?C
M;R!D92!R96=R87,@9&4@9FEL=')A9V5M(&$@<75A;'%U97(@8V%I>&$@<&]S
M=&%L/P!097)M:71I<B!M^FQT:7!L;W,@96YD97)EYV]S`%!E<FUI=&ER(&%T
M<FEB=6GGXV\@9&\@=&EP;R!D92!L:7-T87,@;W)D96YA9&%S/P!*X2!E>&ES
M=&4`16YT<F%D82!)35-0($%L=&5R;F%T:79A`%!A;&%V<F$M4&%S<V4@24U3
M4"!!;'1E<FYA=&EV80!.;VUE(&1E(%5T:6QI>F%D;W(@24U34"!!;'1E<FYA
M=&EV;P!%;F1E<F7G;R!I;G;A;&ED;P!-;V1E;&]S(&%L=&5R;F%T:79O<P!4
M97AT;R!A;'1E<FYA=&EV;SH`4&%R=&5S(&%L=&5R;F%T:79A<R!P87)A(&5S
M=&$@<V5CY^-O.@!396UP<F4`1W5A<F1A<B!S96UP<F4@;W,@86YE>&]S`%-A
M;6]A($%M97)I8V%N80!/8V]R<F5U('5M(&5R<F\@86\@=&5N=&%R(&1E<V-A
M<G1A<B!O(&%N97AO+B!/('-E<G9I9&]R($E-05`@9&ES<V4Z(`!&;VD@97-P
M96-I9FEC861O('5M('9A;&]R(&EN=N%L:61O+@!/8V]R<F5U('5M(&5R<F\@
M9&5S8V]N:&5C:61O+@!/8V]R<F5U('5M(&5R<F\@9&5S8V]N:&5C:61O(&%O
M(&-R:6%R('5M82!N;W9A('1A<F5F82X`06YD;W)R80!!;F=O;&$`06YG=6EL
M80!%;G1R97!O<W1O("AP<F]X>2D@06[S;FEM;P!297-P;W-T80!297-P;VYD
M:61A`$UE;G-A9V5N<R!R97-P;VYD:61A<P!!;G3A<F-T:6-O`$%N=.UG=6$@
M92!"87)B=61A`$%P;&EC8>?C;P!!<&QI8V'GXV\@<')O;G1A+@!!<&QI8V%R
M($9I;'1R;W,`07!L:6-A<B!&:6QT<F]S(&$@)7,`07!L:6-A<B!A<R!R96=R
M87,@9&4@9FEL=')A9V5M(&%Q=6%N9&\@9&$@96YT<F%D83\`07!L:6-A<B!A
M<R!R96=R87,@9&4@9FEL=')A9V5M('%U86YD;R!A($5N=')A9&$@9F]R(&UO
M<W1R861A/P!!<&QI8V%R(&$@4&%R=&EL:&%S($9I;&AA<P!!<')O=F%R`%1A
M;6%N:&\@07!R;WAI;6%D;P!!8G)I;`!!<N%B:6-O("A7:6YD;W=S+3$R-38I
M`%1A;6%N:&\@9&\@1FEC:&5I<F\@9&4@07)Q=6EV;P!.;VUE(&1O($%R<75I
M=F\`5&5M(&$@8V5R=&5Z82!Q=64@9&5S96IA(')E;6]V97(@97-T82!C:&%V
M92!P^F)L:6-A/P!496T@82!C97)T97IA(&1E('%U92!Q=65R(')E;6]V97(@
M;R!S974@<&%R(&1E(&-H879E<S\@*$[#3R#I(')E8V]M96YD861O(2D`5&5M
M(&$@8V5R=&5Z82!Q=64@9&5S96IA(&9A>F5R(&ES=&\_`%1E;2!A(&-E<G1E
M>F$@<75E('%U97(@<F5M;W9E<B!O('!E9&ED;R!D92!S=6)S8W)IY^-O('!A
M<F$@)7,@/P!496T@82!C97)T97IA('%U92!D97-E:F$@<F5M;W9E<B!015)-
M04Y%3E1%345.5$4@97-T87,@;65N<V%G96YS/P!496T@82!C97)T97IA('%U
M92!D97-E:F$@<F5M;W9E<B!015)-04Y%3E1%345.5$4@97-T92!A;F5X;S\`
M5&5M(&$@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R("(E<R(@92!Q=6%I<W%U
M97(@<W5B+6=R=7!O<S\`5&5M(&$@8V5R=&5Z82!Q=64@9&5S96IA(')E;6]V
M97(@97-T82!P87-T83\`5&5M(&$@8V5R=&5Z82!Q=64@9&5S96IA(&5S=F%Z
M:6%R(&$@<&%S=&$@9&4@;&EX;S\`5&5M(&$@8V5R=&5Z82!Q=64@9&5S96IA
M(')E;6]V97(@<&5R;6%N96YT96UE;G1E(&5S=&%S(&UE;G-A9V5N<S\`5&5M
M(&$@8V5R=&5Z82!D92!Q=64@<75E<B!R97!O<G1A<B!E<W1A(&UE;G-A9V5M
M(&-O;6\@<V5N9&\@:6YO8V5N=&4_`%1E;2!A(&-E<G1E>F$@9&4@<75E('%U
M97(@<F5P;W)T87(@97-T82!M96YS86=E;2!C;VUO('-E;F1O('-P86T_`$%R
M9V5N=&EN80!!<FWI;FEA`$%R;>EN:6\@*$%235-#24DM."D`1&%T82!D92!#
M:&5G861A`$%R=&4`07)U8F$`0W)E<V-E;G1E`$EL:&$@9&4@07-C96YSXV\`
M07)T92!!4T-)20!296=IXV\@P7-I82]086/M9FEC;P!097)G=6YT87(`4&5D
M:7(@8V]N9FER;6'GXV\@86YT97,@9&4@<F5A;&EZ87(@;W!E<F'G]65S(&1E
M(&UA;G5T96[GXV\_`$-O;'5N87,@9&4@871R:6)U:>?C;P!!;F5X87(`06YE
M>&%R($%R<75I=F]S`$%N97AA<B!U;6$@8_-P:6$@9&$@<W5A(&-H879E('#Z
M8FQI8V$@9&4@4$=0(.`@<W5A(&UE;G-A9V5M/P!!<G%U:79O($%N97AA9&\Z
M`$\@87)Q=6EV;R`B)7,B(&5X8V5D92!A(&1I;65N<^-O(&QI;6ET92X@3R!A
M<G%U:79O($[#3R!F;VD@86YE>&%D;RX`16T@86YE>&\@97-TX2!A(')E<W!O
M<W1A(&$@=6T@<&5D:61O(&1E(&-A;&5N9.%R:6\@<75E('9O8^H@96YV:6]U
M+@!!;F5X;P!!;F5X;R!D97-C87)T861O.B!4:7!O(&1E(&%N97AO(&]R:6=I
M;F%L`$%N97AO<P!496YT871I=F$@9&4@<F5M;^?C;R!D92!U;2!G<G5P;R!I
M;F5X:7-T96YT92X`5&5N=&%T:79A(&1E(')E;6_GXV\@9&4@=6UA('!E<FUI
M<W/C;R!I;F5X:7-T96YT92X`5&5N=&%T:79A(&1E(&5D:>?C;R!D92!U;6$@
M<&5R;6ES<^-O(&EN97AI<W1E;G1E+@!496YT871I=F$@9&4@961IY^-O(&1E
M('5M82!P87)T:6QH82!I;F5X:7-T96YT92X`4&%R=&EC:7!A;G1E<P!!=&5N
MY^-O`$%T<FEB=71O<P!!9V]S=&\`075S='+A;&EA`,%U<W1R:6$`075T:%]C
M>7)S<6PZ($$@97AT96YSXV\@:6UA<"!N96-E<W/A<FEA(&[C;R!F;VD@96YC
M;VYT<F%D82X`075T:%]C>7)U<SH@3R!M96-A;FES;6\@;N-O('1E;2!A<R!C
M87!A8VED861E<R!N96-E<W/A<FEA<RX`075T:%]C>7)U<SH@02!E>'1E;G/C
M;R!I;6%P(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!=71H7V9T
M<#H@02!E>'1E;G/C;R!&5%`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A
M9&$N($-O;7!I;&4@;R!02%`@8V]M(&$@;W#GXV\@+2UE;F%B;&4M9G1P+@!!
M=71H7VEM87`Z($$@97AT96YSXV\@24U!4"!N96-E<W/A<FEA(&[C;R!F;VD@
M96YC;VYT<F%D82X`075T:%]I;7`Z($5X=&5N<^-O($E-05`@;F5C97-SX7)I
M82!M87,@;N-O(&5N8V]N=')A9&$N`$%U=&A?:W)B-3H@02!E>'1E;G/C;R!K
M<F(U(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!=71H7VQD87`Z
M($$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D
M82X`075T:%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!U=&EL:7IA9&]R
M("5S+B!%:7,@;R!Q=64@;R!S97)V:61O<B!D:7-S93H@`$%U=&A?;&1A<#H@
M26UP;W-S[79E;"!R96UO=F5R(&\@=71I;&EZ861O<B`E<P!!=71H7VQD87`Z
M($EM<&]S<^UV96P@86-T=6%L:7IA<B!O('5T:6QI>F%D;W(@)7,`075T:%]M
M8V%L.B!!(&5X=&5N<^-O($U#04P@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N
M=')A9&$N`$%U=&A?<VUB875T:#H@02!E>'1E;G/C;R!S;6)A=71H(&YE8V5S
M<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!(&%U=&5N=&EC8>?C;R!F86QH
M;W4`02!A=71E;G1I8V'GXV\@9F%L:&]U+B`E<P!!(&%U=&5N=&EC8>?C;R!F
M;VD@<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$2553+@!!(&%U=&5N=&EC
M8>?C;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U+@!-;W-T<F%R(&%U=&]M871I
M8V%M96YT92!I;6%G96YS(&5M(&UE;G-A9V5N<R!(5$U,('%U86YD;R!E;G9I
M861A<R!P;W(@8V]R<F5S<&]N9&5N=&4@;&ES=&%D;R!N;R!M974@;&EV<F\@
M9&4@96YD97)EYV]S/P!,:79R;W,@9&4@16YD97)EYV]S(&1I<W!O;NUV96ES
M.@!#86UP;W,@9&ES<&]N[79E:7,Z`$5S<&5R86YD;R!297-P;W-T80!!>F5R
M8F%I:N-O`$1E<V-U;'!A<R`B0D]&2"(`5F]L7W1A<B!P87)A("5S`%9O;'1A
M<B!P87)A("5S`$9U;F1O`$-O<B!D;R!&=6YD;P!086QA=G)A+5!A<W-E(&ME
M<F)E<F]S(&5R<F%D82X`3F]M92!D92!5=&EL:7IA9&]R(&ME<F)E<F]S(&5R
M<F%D;RX`0F%A;6%S`$)A<NEM`$+A;'1I8V\@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D96-H90!"87)B861O<P!,:6YH82!B87-E`$)C8P!":65L;W)R^G-S:6$`
M0NEL9VEC80!"96QI>F4`06)A:7AO(&5N8V]N=')A+7-E(&\@=&5X=&\@8W)U
M(&1A(&UE;G-A9V5M(&1E(&EN9F]R;6'GXV\@9&4@97-T861O+@!"96YI;0!"
M97)M=61A`$)U=.-O`$%N:79E<G/A<FEO`$QI<W1A($YE9W)A`$\@8FQO8V\@
M(B5S(B!D82!A<&QI8V'GXV\@(B5S(B!NXV\@9F]I(&5N8V]N=')A9&\N`$-O
M;F9I9W5R8>?U97,@9&4@0FQO8V]S`%1I<&\@9&4@0FQO8V\`0FQO<75E<B!I
M;6%G96YS(&5M(&UE;G-A9V5N<R!(5$U,(&5X8V5P=&\@<75A;F1O(&5X<&QI
M8VET86UE;G1E('!E9&ED87,_`$-O<G!O`$YE9W)I=&\`0F]L[79I80!-87)C
M861O<F5S`$)O<F1A`$5S<&5S<W5R82!D82!B;W)D83H`0F]R9&%S`$+S<VYI
M82U(97)Z96=O=FEN80!!;6)A<P!,:7-T86=E;2!N;R!#86)EYV%L:&\@92!#
M;W)P;R!D82!-96YS86=E;0!";W1S=6%N80!"87-E`$EL:&$@0F]U=F5T`$)R
M87-I;`!497)R:73S<FEO($)R:73B;FEC;R!D;R!/8V5A;F\@S6YD:6-O`$)R
M=6YE:2!$87)U<W-A;&%M`$-O;G-T<G5I;F1O(&%R<75I=F]S($U/('!A<F$@
M;R!M\V1U;&\@)7,N+BX`0V]N<W1R=6EN9&\@;&]C86QI>F'GXV\@)7,N+BX@
M`$)U;&?A<FEA`$QI<W0@271E;6EZ861A`$)U<G%U:6YA($9A<V\`0G5R^FYD
M:0!#35,`0U)#`%!O;G1O<R!D92!$:7-T<FEB=6GGXV\@0U),`%!R;W!R:65D
M861E<R!D82AS*2!#Z5]L=6QA*',I+BXN`$/S7V1I9V\`26YI8VEA;&EZ8>?C
M;R!D82`B8V%C:&4B(&[C;R!F;VD@8V]N8VQU[61A+@!#86QE;F3A<FEO`$-A
M;&UO`$-A;6)O9&IA`$-A;6%R]65S`$EM<&]S<^UV96P@8V]N96-T87(@86\@
M<V5R=FED;W(@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!R96UO=&\N`$EM<&]S
M<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@9&4@8V]R<F5I;R!E;&5C='+S
M;FEC;R!R96UO=&\Z(`!.XV\@<V4@<&]D92!M;W-T<F%R("T@96YC;VYT<F%D
M87,@87!E;F%S("5S(&1E("5S('!A<G1E<R!D97-T82!M96YS86=E;2!N82!C
M86EX82!P;W-T86P@8V]R<F5N=&4N`$[C;R!P;W-S;R!R96EN:6-I87(@82!P
M86QA=G)A+7!A<W-E(&%U=&]M871I8V%M96YT92P@8V]N=&%C=&4@;R!S974@
M861M:6YI<W1R861O<B!D92!S:7-T96UA<RX`26UP;W-S[79E;"!C;VYE8W1A
M<B!A;R!S97)V:61O<B!)34%0.B`E<P!#86YA9.$`0V%N8V5L87(`0V%N8V5L
M87(@365N<V%G96T`0V%N8V5L87(@4F5L873S<FEO(&1E(%!R;V)L96UA<P!!
M;R!C86YC96QA<B!E<W1A(&UE;G-A9V5M(&ERX2!P97)D97(@=&]D;R!O('-E
M=2!C;VYT9?ID;R!P97)M86YE;G1E;65N=&4N`$[C;R!C;VYS:6=O(')E;6]V
M97(@;R!F:6-H96ER;R`B)7,B+@!.XV\@8V]N<VEG;R!E;F-O;G1R87(@=6T@
M9&ER96-T\W)I;R!T96UP;W+A<FEO+@!);7!O<W/M=F5L(&-O;G1I;G5A<B!S
M96T@;R!P87+B;65T<F\@)W1A<F=E=$9I;&4G+@!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@82!P87-T82`B)7,B+@!);7!O<W/M=F5L(')E;6]V97(L(&5X
M:7-T96T@)60@9FEL:&]S+@!.XV\@Z2!P;W-S[79E;"!R96]R9&5N87(Z(&\@
M;OIM97)O(&1E(&5N=')A9&%S(&9O<FYE8VED87,@;N-O(&-O<G)E<W!O;F1E
M(&%O(&[Z;65R;R!G=6%R9&%D;RX`3N-O(&9O:2!P;W-S[79E;"!E;F-A;6EN
M:&%R(&$@;65N<V%G96T@<&%R82!O(&[Z;65R;R!I;F1I8V%D;RX`4F5P^F)L
M:6-A(&1E($-A8F\@5F5R9&4`3&5G96YD80!#871E9V]R:6%S(&4@0V]R97,`
M26QH87,@0V%I;>-O`$-C`%1E;&5F;VYE($-E;'5L87(`4')O<')I961A9&5S
M(&1A<R!#Z6QU;&%S`$5N8VAI;65N=&\@9&%S($/I;'5L87,Z`%!R;W!R:65D
M861E<R!D87,@8^EL=6QA<P!%<W!AYV%M96YT;R!D87,@8^EL=6QA<SH`5&5L
M96WS=F5L`$/I;'1I8V\@*$E33RTX.#4Y+3$T*0!#96YT<F%R`%)E</IB;&EC
M82!#96YT<F\@069R:6-A;F$`175R;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I
M`%!O<FUE;F]R97,@9&\@0V5R=&EF:6-A9&\`1&]N;R!D;R!#97)T:69I8V%D
M;P!0;VSM=&EC87,@9&4@0V5R=&EF:6-A9&\`4F5P^F)L:6-A(&1O($-H861E
M`$UO9&5R861O<@!!;'1E<F%R`$%L=&5R87(@5'5D;P!!;'1E<F%R(%!A<W1A
M`$%L=&5R87(@;W#G]65S(&1E('9I<W5A;&EZ8>?C;R!T86ES(&-O;6\@<75A
M;G1A<R!M96YS86=E;G,@<75E<B!V97(@<&]R('#A9VEN82!E(&$@<F5S<&5C
M=&EV82!O<F1E;F'GXV\N`$%L=&5R87(@9&%D;W,@9&\@<V5R=FED;W(@9&4@
M8V]R<F5I;R!E;&5C='+S;FEC;R!E(&1A<R!P87-T87,N`$%L=&5R92!O(&YO
M;64@92!E;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!V97+C;R!Q=6%N9&\@;&5R
M96T@92!R97-P;VYD97)E;2#@<R!S=6%S(&UE;G-A9V5N<RX`06QT97)A<B!O
M(&YO;64L(&5M86EL(&4@87-S:6YA='5R82!Q=64@87,@<&5S<V]A<R!V97+C
M;R!Q=6%N9&\@;&5R96T@92!R97-P;VYD97)E;2#@('-U82!M96YS86=E;2X`
M0V%R86-T97)E`$-A<F%C=&5R97,@82!M;W-T<F%R.@!697)I7V9I8V%R($QI
M9V'GXV\N+BX`5F5R:69I8V$@<V4@:.$@365N<V%G96YS($YO=F%S(&YA*',I
M(%!A<W1A*',I`$UA<F-A<B!?5'5D;R].861A`%9E<FEF:6-A<B!T;V1O<R!O
M<R!S97)V:61O<F5S(&1E(&]N9&4@<')E=&5N9&4@9&5S8V%R<F5G87(@8V]R
M<F5I;SH`5F5R:69I8V%R(&$@;W)T;V=R869I82!A;G1E<R!D92!E;G9I87(@
M82!M96YS86=E;3\`36%R<75E(&%S(&]P97)AY_5E<R!Q=64@9&5S96IA(&5X
M96-U=&%R(&YE<W1E(&UO;65N=&\N`%)E</IB;&EC82!D;R!#:&EL90!297#Z
M8FQI8V$@4&]P=6QA<B!D82!#:&EN80!#:&ENZG,@4VEM<&QI9FEC861O<R`H
M1T(R,S$R*0!#:&ENZG,@5')A9&EC:6]N86P@*$)I9S4I`$%CY^-O.@!%<V-O
M;&AE<B!U;2!S97)V:61O<B!D92!C;W)R96EO(&5L96-T<O-N:6-O.@!%<V-O
M;&AA('5M82!D87,@8V]R<F5S<&]N9.IN8VEA<R!O=2!E9&ET92!O(&5N9&5R
M9>=O(.`@9&ER96ET83H`17-C;VQH82!A('!A;&%V<F$M<&%S<V4`17-C;VQH
M82!U;2!.;VUE(&1E(%5T:6QI>F%D;W(`17-C;VQH82!U;6$@86/GXV\Z`$5S
M8V]L:&$@8V]M;R!M;W-T<F%R(&%S(&1A=&%S.@!%<V-O;&AA(&\@97-T:6QO
M(&1A<R!L:7-T82`H<&%R82!L:7-T87,@;W)D96YA9&%S*0!%<V-O;&AA(&\@
M;&EV<F\@9&4@96YD97)EYV]S(&$@=7-A<B!Q=6%N9&\@<V4@861I8VEO;F%R
M(&5N9&5R9>=O<RX`17-C;VQH82!A(&]R9&5M(&1O<R!L:79R;W,@9&4@96YD
M97)EYV]S(&$@<')O8W5R87(@<75A;F1O(&5X<&%N9&EN9&\@96YD97)EYV]S
M+@!);&AA(&1O($YA=&%L`$[C;R!F;VD@96YC;VYT<F%D82!A(&1E9FEN:>?C
M;R!D82!C;&%S<V4@)7,N`$QI;7!A;F1O(&]S(&%R<75I=F]S(%!/(&1O(&WS
M9'5L;R`E<RXN+@!,:6UP86YD;R!A(&QO8V%L:7IAY^-O("5S+BXN(`!,:6UP
M87(`3&EM<&%R(&5T:7%U971A<R!D;R!-4T]F9FEC90!,:6UP87(@9&%D;W,@
M9&\@=71I;&EZ861O<CH@)7,`3&EM<&%R(&1A9&]S(&1O('5T:6QI>F%D;W(`
M3&EM<&%R(&1A9&]S(&1O('5T:6QI>F%D;W(`3&EM<&$@5&%R9&4`0V%R<F5G
M=64@96T@)7,@<&%R82!C;VYV97)T97(@;R!A<G%U:79O(&1E(&EM86=E;2!P
M87)A('5M(&9O<FUA=&\@<75E(&\@;F%V96=A9&]R('!O<W-A(&UO<W1R87(N
M`$-A<G)E9W5E(&5M("5S('!A<F$@9&5S8V%R<F5G87(@82!I;6%G96TN`$-A
M<G)E9W5E(&5M("5S('!A<F$@:7(@<&%R82!PX6=I;F$@9&4@9V5S=.-O(&1O
M("5S+@!#87)R96=U92!E;2`E<R!P87)A('9E<B!O(&-O;G1E^F1O($A434P@
M;G5M82!J86YE;&$@X"!P87)T92X`0V%R<F5G=64@96T@)7,@<&%R82!V97(@
M;6EN:6%T=7)A(&1E<W1A(&EM86=E;2X`0V%R<F5G=64@96T@)7,@<&%R82!V
M97(@;R!A;F5X;R!N=6UA(&IA;F5L82#@('!A<G1E+@!#87)R96=U92!E;2`E
M<R!P87)A('9E<B!M=6QT:7!A<G1E+W!A<G1E(')E;&%C:6]N861A(&YU;6$@
M:F%N96QA(.`@<&%R=&4N`$-A<G)E9W5E(&%Q=6D@<&%R82!%4T-/3D1%4B!A
M<R!);6%G96YS`$-A<G)E9W5E(&%Q=6D@<&%R82!615(@87,@26UA9V5N<P!#
M87)R96=U92!N=6T@9&]S('-E=7,@;&EV<F]S(&1E(&5N9&5R9>=O<R!S96QE
M8V-I;VYA9&]S(&4@9&5P;VES(&5S8V]L:&$@;W,@8V%M<&]S(&$@<')O8W5R
M87(N`$-L:7%U92!P87)A($-O;G1I;G5A<@!#;&EQ=64@<&%R82!'=6%R9&%R
M(&$@0VAA=F4@4/IB;&EC82!01U`@;F\@<V5U($QI=G)O(&1E($5N9&5R9>=O
M<P!#;&EQ=64@<&%R82!'=6%R9&%R(&\@0V5R=&EF:6-A9&\@4R]-24U%(&1E
M("5S(&YO('-E=2!,:79R;R!D92!%;F1E<F7G;W,`0VQI8VMA=&5L;"!V:6$@
M2%144`!#87)R96=A<B!N;R!E;F1E<F7G;R!C;VUP;W+A('5M82!N;W9A(&UE
M;G-A9V5M('!A<F$@;R!R96UE=&5N=&4`0V%R<F5G87(@;F\@96YD97)EYV\@
M86)R:7+A(&$@;65N<V%G96T@<&%R82!L96ET=7)A`$9E8VAA<@!&96-H87(@
M:F%N96QA`$9E8VAA<B!E<W1A($IA;F5L80!087-T82!&96-H861A`$[Z=F5N
M<P!.^G9E;G,@36%T:6YA:7,`16YE=F]A9&\`26QH87,@0V]C;W,@*$ME96QI
M;F<I`$-O;&%P<V%R`$9E8VAA<B!4;V1A<P!&96-H87(@5&]D87,@4&%S=&%S
M`$9E8VAA<B!087-T80!#;VQA<'-A<B!"87)R82!,871E<F%L`$)O<F1A<R!#
M;VQA<'-A9&%S`%)E</IB;&EC82!D82!#;VST;6)I80!#;W)E<P!);F1I8V%D
M;W(@0V]L;W)I9&\Z`%!A;&5T90!396QE8^?C;R!D92!C;W)E<@!#;VQU;F%S
M.@!4[71U;&]S(&1A<R!C;VQU;F%S`$)$`$-O;6%N9&\`0V]N<V]L82!D92!#
M;VUA;F1O<P!/<.?U97,@9&\@8V]M86YD;SH`0V]M86YD;W,Z`$-O;65N=.%R
M:6\`0V]M971E;F1O`$YO;64@0V]M=6T`0V]M;W)O<P!%;7!R97-A`$-O;7!L
M971O`$5S8W)E=F5R`$5S8W)E=F5R("@E<RD`17-C<F5V97(@=6UA(&]U=')A
M(&UE;G-A9V5M`$5S8W)E=F5R(&UE;G-A9V5N<R!N=6UA(&IA;F5L82!S97!A
M<F%D83\`0V]M<&]R(&UE;G-A9V5N<R!C;VT@;R!A;6)I96YT92!(5$U,('!O
M<B!O;6ES<^-O("AS92!O(&YA=F5G861O<B!O('-U<&]R=&%R*3\`0V]M<'5T
M861O<F5S`$-O;F1IY^-O`$-O;F1IY_5E<P!$:69E<F5NYV%S(&1E($-O;F9I
M9W5R8>?C;P!!(&-O;F9I9W5R8>?C;R!E<W3A(&1E<V%C='5A;&EZ861A`$-O
M;F9I9W5R87(@)7,`0V]N9FEG=7)A<B!M;V1O(&1E('9I<W5A;&EZ8>?C;R!D
M92!M96YS86=E;G,N`$-O;F9I9W5R92!A<R!O<.?U97,@9&4@<')E=FESXV\@
M9&4@;65N<V%G96YS(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\N`$-O;F9I<FUE
M(&$@4&%L879R82U087-S90!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\@0V]N
M9V\`4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1O($-O;F=O`$-O;F5XXV\@9F%L
M:&]U+@!#;VYE>.-O(&9A;&AO=3H@`$-O;F5XXV\@86\@<V5R=FED;W(@9&4@
M8VAA=F5S('#Z8FQI8V%S(')E8W5S861A+@!#;VYE>.-O(&%O('-E<G9I9&]R
M(&1E(&-H879E<R!P^F)L:6-A<R!R96-U<V%D82X@4F%ZXV\Z("5S("@E<RD`
M0V]N97CC;R!A;R!S97)V:61O<B!&5%`@<F5C=7-A9&$N`$$@8V]N;F5CY^-O
M(&%O('-E<G9I9&]R(&9A;&AO=0!#;VYT86-T;W,@861I8VEO;F%D;W,@8V]M
M('-U8V5S<V\@86\@<V5U(&QI=G)O(&1E(&5N9&5R9>=O<RX`5&EP;R!D92!C
M;VYT9?ID;R!D;R!A<G%U:79O(&-O;7!R:6UI9&\Z(`!#;VYT9?ID;R!D92`E
M<P!#;VYT:6YU87(`0V]N=')O;&%R('-U<&]R=&4@9&4@4$=0('!A<F$@;R`E
M<RX`0V]N=')O;&%R('-U<&]R=&4@9&4@4R]-24U%('!A<F$@;R`E<RX`0V]N
M=')O;&%R(&$@=F5R:69I8V'GXV\@9&4@;F]V87,@;65N<V%G96YS(&4@<F5S
M<&5C=&EV82!N;W1I9FEC8>?C;RX`0V]N=F5R=&5R(.UC;VYE<R!D92!E;6_G
MXV\@9&4@=&5X=&\@<&%R82!G<N%F:6-O<S\`26QH87,@0V]O:P!";VQI;FAO
M(&-H:6[J<P!#;W!I87(`0V]P:6%R('-E;&5CY^-O`$-O<&EA<B!P87)A('!A
M<W1A`$-O<&EA;F1O(&1E("5S('!A<F$@)7,`0V]R<FEG:7(`5&5X=&\@0V]R
M<FEG:61O`%)E</IB;&EC82!D82!#;W-T82!2:6-A`%)E</IB;&EC82!D82!#
M;W-T82!D;R!-87)F:6T`3N-O(&9O:2!P;W-S[79E;"!E;F-R:7!T87(@82!M
M96YS86=E;2!C;VT@4$=0+@!.XV\@9F]I('!O<W/M=F5L(&%S<VEN87(@82!M
M96YS86=E;2!C;VT@4$=0+@!.XV\@9F]I('!O<W/M=F5L(&5N8W)I<&%R(&$@
M;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A<W-I;F%R
M(&$@;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A9&EC
M:6]N87(@;R!C;VYT86-T;RX@)7,`1F%L:&$@;F$@;&EG8>?C;R`H8FEN9"D@
M86\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!V97)I9FEC87(@
M;R!S86QD;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V
M:61O<B`B)7,B('5S86YD;R!&5%`Z("5S`$[C;R!F;VD@<&]S<^UV96P@8V]P
M:6%R("5S('!A<F$@)7,`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!L:7-T82!D
M92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@<&%S
M=&$@9&4@;&]C86QI>F'GXV\@<&%R82!A(&QO8V%L:7IAY^-O("5S.@!);7!O
M<W/M=F5L(&-R:6%R(&\@;65C86YI<VUO(%9&4SH@)7,`3N-O(&9O:2!P;W-S
M[79E;"!D97-E;F-R:7!T87(@;W,@9&%D;W,@8V]M(&\@4$=0+@!.XV\@9F]I
M('!O<W/M=F5L(&1E<V5N8W)I<'1A<B!O<R!D861O<R!C;VT@4R]-24U%+@!.
MXV\@9F]I('!O<W/M=F5L(')E;6]V97(@8V]N=&%C=&\N("5S`$[C;R!F;VD@
M<&]S<^UV96P@<F5M;W9E<B!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$[C
M;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!M96YS86=E;G,@9&4@)7,N($\@<V5R
M=FED;W(@9&ES<V4Z("5S`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(")S
M8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L
M(&1E=&5R;6EN87(@;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O
M(&1O(&1E<W1I;F%TX7)I;RX`3N-O(&9O:2!P;W-S[79E;"!E>&5C=71A<B!A
M<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;RX`3N-O(&9O:2!P;W-S[79E;"!E
M>'1R86ER(&\@87)Q=6EV;R!D97-E:F%D;R!D;R!A;F5X;R!-4RU43D5&+@!)
M;7!O<W/M=F5L(&5X=')A:7(@;R!A<G%U:79O(&1E<V5J861O(&1O(&%R<75I
M=F\@6FEP+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@;&EV<F\@9&4@96YD
M97)EYV]S(&-O;7!L971O+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O(&-O;7!L971A+@!.XV\@9F]I('!O<W/M=F5L
M(&]B=&5R(&$@;&ES=&$@8V]M<&QE=&$@9&%S(&QI<W1A<R!D92!D:7-T<FEB
M=6GGXV\N`$EM<&]S<^UV96P@8V%R<F5G87(@97-T<F%TZ6=I82`B)7,B+@!)
M;7!O<W/M=F5L(&UK9&ER("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@
M82!C:&%V92!P^F)L:6-A(&$@<&%R=&ER(&1O('-E<G9I9&]R(&1E(&-H879E
M<R!P^F)L:6-A<RX`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B`B)7,B('!A<F$@
M97-C<FET82X`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B`E<RX`3N-O(&9O:2!P
M;W-S[79E;"!A8G)I<B!O(&WS9'5L;R!D92!-86YU=&5NY^-O(&1E(%1A<F5F
M87,@)7,`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!P87-T82`B)7,B+@!.XV\@
M9F]I('!O<W/M=F5L(&QE<B`E<RX`3N-O(&9O:2!P;W-S[79E;"!R96EN:6-I
M87(@82!P86QA=G)A+7!A<W-E(&1O('5T:6QI>F%D;W(@:6YD:6-A9&\N($%L
M9W5M(&]U('1O9&]S(&]S('!O<FUE;F]R97,@;N-O(&5S=&%V86T@8V]R<F5C
M=&]S+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!O=2!C;VYT86-T92!O('-E
M=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('-E('!R96-I<V%R(&1E(&UA
M:7,@86IU9&$N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@04-,`$[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@;&EV<F\@9&4@96YD97)EYV]S+B`E<P!.XV\@9F]I
M('!O<W/M=F5L(&]B=&5R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O
M(&9O:2!P;W-S[79E;"!O8G1E<B!L:7-T87,@9&4@9&ES=')I8G5IY^-O+B`E
M<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&-O;7!E=.IN8VEA<R!D;R!S
M97)V:61O<@!.XV\@9F]I('!O<W/M=F5L(')E=F5R=&5R(&$@8V]N9FEG=7)A
MY^-O+@!);7!O<W/M=F5L(')M9&ER("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@
M9W5A<F1A<B!A(&-O;F9I9W5R8>?C;R!D92`E<RX`3N-O(&9O:2!P;W-S[79E
M;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A+@!.XV\@
M9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G
M=6%R9&$Z("5S`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!O(")S8W)I<'0B
M(&1E(&%C='5A;&EZ8>?C;R!E;3H@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!G
M=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A("5S+@!.XV\@
M9F]I('!O<W/M=F5L(&=U87)D87(@;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C
M;R`E<RX@4&]D92!U<V%R('5M82!D87,@;W#G]65S('!A<F$@9W5A<F1A<B!O
M(&/S9&EG;R!E;2`E<R!O=2!C;W!I87(@;6%N=6%L;65N=&4@;R!C\V1I9V\@
M86)A:7AO('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV96P@<')O8W5R87(@;F\@
M<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!D97-L:6=A<B`B)7,B
M+@!.XV\@9F]I('!O<W/M=F5L(&%C='5A;&EZ87(@8V]N=&%C=&\N("5S`$[C
M;R!F;VD@<&]S<^UV96P@86-T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U
M:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!A(&-O;F9I9W5R
M8>?C;R!P87)A("(E<R(Z("5S`$[C;R!E;F-O;G1R96D@82!"87)R82!,871E
M<F%L(&1O($UO>FEL;&$N($%S<V5G=7)E+7-E('%U92!A(&)A<G)A(&QA=&5R
M86P@97-TX2!A8F5R=&$N`$[C;R!F;VD@<&]S<^UV96P@871R:6)U:7(@86\@
M=71I;&EZ861O<B`B)7,B(&]S('-E9W5I;G1E<R!D:7)E:71O<R!S;V)R92!A
M('!A<W1A("(E<R(Z("5S`%1E>'1O($-O;G1A9&\`4&'M<P!#=7)S;W,`0W)I
M87(`0W)I87(@4&%S=&$`0W)I87(@8VAA=F5S`$-R:6%R(%!A<W1A(%9I<G1U
M86P`0W)I87(@3F]V82!#;VYT80!#<FEA<B!U;6$@;&EG8>?C;P!#<FEA<B!U
M;6$@;F]V82!P87-T82!D92!3<&%M`$-R:6%R('5M82!P87-T82!D92!R87-C
M=6YH;W,@;F]V80!#<FEA<B!U;6$@;F]V80!#<FEA<B!U;6$@<&%S=&$@9&4@
M;65N<V%G96YS(&5N=FEA9&%S(&YO=F$`0W)I87(@=6UA(&YO=F$@<&%S=&$@
M9&4@;&EX;P!#<FEA<B!R96=R87,@9&4@9FEL=')A9V5M('!A<F$@;W)G86YI
M>F%R(&%S(&UE;G-A9V5N<R!R96-E8FED87,L(&1I<W1R:6)U[2UL87,@<&5L
M87,@<F5S<&5C=&EV87,@<&%S=&%S(&4@<F5M;W9E<B!S<&%M+@!#<FEA<B!S
M=6(M<&%S=&%S`%!E<FUI<W/U97,@9&\@0W)I861O<@!.^FUE<F\@9&\@8V%R
M=.-O(&1E(&-RZ61I=&\`4F5P^F)L:6-A(&1A($-R;^%C:6$`4F5P^F)L:6-A
M(&1E($-U8F$`475A=')O(&9A<V5S(&-O<G)E;G1E<P!$871A+TAO<F$`55),
M(&-O<G)E;G1E(.D`17-T861O(&1O(%1E;7!O`$%C97-S;R!C;W)R96YT92!A
M("5S`%-I='5AY^-O(&%C='5A;#H@`$5S=&EL;R!A8W1U86P`4&5R<V]N86QI
M>F%R(&-O;G1A<R!P87)A(&1E<V-A<G)E9V%R(&-O<G)E:6\@9&4@;W5T<F%S
M(&-O;G1A<RX`4&5R<V]N86QI>F%R(&9O<FUA(&1E(&5N=FEO(&1E(&-O<G)E
M:6\N`%!E<G-O;F%L:7IA<B!T87)E9F%S(&5X96-U=&%D87,@86\@86-E9&5R
M(&$@)7,N`$-O<G1A<@!#;W)T87(@82!S96QE8^?C;P!297#Z8FQI8V$@9&4@
M0VAI<')E`$-I<NUL:6-O("A+3TDX+5(I`$-I<NUL:6-O("A7:6YD;W=S+3$R
M-38I`$-I<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5*0!297#Z8FQI8V$@0VAE
M8V$`1$0`1&EA<FEA;65N=&4`7T1A=&$`3F%V96=A9&]R(&1E(,%R=F]R92!D
M92!$861O<P!$871A`$1A=&$@9&4@4F5C97#GXV\`4V5L96/GXV\@9&4@9&%T
M80!$:6$`4F5M;W9E<B!#;U]L=6YA`$1E>F5M8G)O`$[Z;65R;W,@9&5C:6UA
M:7,`1&5C;&EN861A`$1E8VQI;F%D83H`4F5D=7II<B!I;F1E;G1AY^-O`%!O
M<B!/;6ES<^-O`$-O<B!0;W(@3VUI<W/C;P!)9&5N=&ED861E(%!A9'+C;P!0
M97)M:7-S]65S(%!O<B!/;6ES<^-O`%!E<FUI<W/U97,@<&]R(&]M:7-SXV\`
M0W)I=.ER:6\@9&4@;W)D96YAY^-O('!A9'+C;SH`3W)D96YAY^-O('!A9'+C
M;SH`1&5F:6YIY_5E<P!$96QE9V%D83H`4F5M;W9E<@!296UO=F5R($-H879E
M(%#Z8FQI8V$@)7,`4F5M;W9E<B!#:&%V97,@0V]R<F5N=&5S`%)E;6]V97(@
M4&%S=&$H<RD`4F5M;W9E<B!'<G5P;P!296UO=F5R(%!E<FUI<W/C;P!296UO
M=F5R(%!A<W1A<R!396QE8V-I;VYA9&%S`%)E;6]V97(@4&%S=&$@5FER='5A
M;`!296UO=F5R(&4@<'5R9V%R(&UE;G-A9V5N<P!296UO=F5R(&/I;'5L80!2
M96UO=F5R(&-O;'5N80!296UO=F5R(&UO9&5L;R!A;'1E<FYA=&EV;R!E>&ES
M=&5N=&4`4F5M;W9E<B!D;R!S97)V:61O<B!R96UO=&\@87,@;65N<V%G96YS
M(&1E<V-A<G)E9V%D87,_`%)E;6]V97(@9&\@;65U(&-A;&5N9.%R:6\`4F5M
M;W9E<B!A;F5X;W,@;&EG861O<R!A;G1I9V]S(&YO(&EN[6-I;R!D92!C861A
M(&WJ<S\`4F5M;W9E<B!P87-T87,@86YT:6=A<R!D92!E;G9I861O<R!N;R!I
M;NUC:6\@9&4@8V%D82!MZG,_`%)E;6]V97(@<&5R;6ES<_5E<R!D92`B)7,B
M`%)E;6]V97(@<&5R;6ES<_5E<R!P87)A("<E<R<@92!Q=6%I<W%U97(@<W5B
M+7!E<FUI<W/U97,_`%)E;6]V97(@;&EN:&$`4F5M;W9E<B!I9&5N=&ED861E
M('-E;&5C8VEO;F%D80!296UO=F5R(&UE;G-A9V5N<R!D92!S<&%M('%U86YD
M;R!C;VUO('1A;"!F;W)E;2!R97!O<G1A9&%S/P!296UO=F5R(&$@8V]L=6YA
M(&-O<G)E;G1E`%)E;6]V97(@82!L:6YH82!C;W)R96YT90!296UO=F5R(&5S
M=&$@<&5R;6ES<^-O(&4@=&]D87,@87,@<W5A<R!S=6(M<&5R;6ES<_5E<S\`
M4F5M;W9I9&$`365N<V%G96YS(')E;6]V:61A<P`B4V-R:7!T(B!D92!A8W1U
M86QI>F'GXV\@(B5S(B!R96UO=FED;RX`06YE>&\@(B5S(B!R96UO=FED;RX`
M4F5M;W9E;F1O(&4@36]V96YD;R!-96YS86=E;G,`36]M96YT;R!D92!E;G1R
M96=A`$1I;F%M87)C80!296-U<V%R('!E9&ED;P!296-U<V%R('!E9&ED;R!D
M92!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\`1&5C<F5S8V5N=&4`1&5S8W)E
M=F$@;R!0<F]B;&5M80!$97-C<FGGXV\`1&5T86QH97,`4&]R;65N;W)E<R`H
M=&%M8NEM(&YO(')E9VES=&\L(")L;V<B+"!D;R!(;W)D92DZ`$]S(&1E=&%L
M:&5S(&9O<F%M(&5N=FEA9&]S('!A<F$@;R!A9&UI;FES=')A9&]R(&1O('-I
M<W1E;6$N`$1E<V5N=F]L=FEM96YT;P!0;VYT;R!D92!/<G9A;&AO`%!O;G1O
M(&1E($]R=F%L:&\@;F$@^FQT:6UA(&AO<F$Z(`!0;VYT;R!D92!O<G9A;&AO
M.B``07-S:6YA='5R87,@1$E-/P!$:7)E8^?C;R!D82!E<W%U97)D82!P87)A
M(&$@9&ER96ET80!$:7)E8^?C;R!D82!D:7)E:71A('!A<F$@82!E<W%U97)D
M80!$:7)E8W3S<FEO`%9I<W5A;&EZ8>?C;P!-;W-T<F%R('1E;7!O<R!C;VT@
M,C0@:&]R87,_`$]PY_5E<R!D92!6:7-U86QI>F'GXV\`36]S=')A<B!C;VYF
M:7)M8>?C;R!A</-S(&5N=FEA<B!U;6$@;65N<V%G96T_`$UO<W1R87(@<')E
M=FESXV\@<&]R;65N;W)I>F%D80!-;W-T<F%R('!R979I<^-O("A4048I`$9O
M<FUA=&\@9&4@=FES=6%L:7IAY^-O`$UO<W1R87(@;F\@0V]R<&\@9&$@365N
M<V%G96T`36]S=')A<B!U;6$@;F]T:69I8V'GXV\@(G!O<'5P(B!Q=6%N9&\@
M8VAE9V%R96T@;F]V87,@;65N<V%G96YS/P!-;W-T<F%R(&\@;&EN:R`G17-V
M87II87(@;&EX;R<@;F$@8F%R<F$@9&\@;65N=3\`1&ES<&]S:>?C;P!.;W1I
M9FEC8>?C;R!D92!$:7-P;W-IY^-O`$1J:6)U=&D`3L-/(&-O<G)E<W!O;F1E
M`$[C;R!697)I9FEC87(@<V4@2.$@365N<V%G96YS($YO=F%S(&YA*',I(%!A
M<W1A*',I`$[C;R!R96UO=F5R`$[C;R!U=&EL:7IE(&\@;6%I;G1E;F%N8V4N
M<&AP(&1I<F5C=&%M96YT90!.XV\@9V5R87(@=6UA(&QI9V'GXV\@;F$@8V]L
M=6YA($1E.@!$97-E:F$@86)R:7(@97-S82!P87-T83\`02!P<FEM96ER82!L
M:6YH82!C;VYTZ6T@;W,@;F]M97,@9&]S(&-A;7!O<S\@4V4@<VEM+"!A<W-I
M;F%L87(@97-T82!C86EX83H`1&]M:6YI8V$`4F5P^F)L:6-A($1O;6EN:6-A
M;F$`1F5I=&\`4F5C96)E<@!296-E8F5R("5S`$1E<V-A<G)E9V%R("5S(&5M
M(&9O<FUA=&\@+GII<`!$97-C87)R96=A<B!4;V1O<R!O<R!!;F5X;W,@*&YU
M;2!F:6-H96ER;R`N>FEP*0!296-E8F5R(%!A<W1A*',I`%)E8V5B97(@4&%S
M=&$H<RD@6RYZ:7`@9F]R;6%T70!$97-C87)R96=A<B!A(&-O;F9I9W5R8>?C
M;R!G97)A9&$@8V]M;R!U;2`B<V-R:7!T(B!02%`N`$1E<V-A<G)E9V%R(&YO
M($9O<FUA=&\@+GII<`!287-C=6YH;P!087-T82!D92!R87-C=6YH;W,`4&%S
M=&$@9&4@<F%S8W5N:&]S.@!,:7-T82!D92!D97-E;G)O;&%R`$1R;V=A<P!#
M;W)R96EO(&5L96-T<O-N:6-O`$5N9&5R9>=O(&1E($-O<G)E:6\@16QE8W1R
M\VYI8V\`1DE-`$524@!%4E)/.B!!('-U82!M96YS86=E;2!NXV\@</1D92!S
M97(@96YT<F5G=64N`%)E</IB;&EC82!D;R!%<75A9&]R`$5D:71A<@!%9&ET
M87(@3&ES=&$@3F5G<F$`161I=&%R($)L;V-O`$5D:71A<B!&:6QT<F]S`$5D
M:71A<B!'<G5P;P!%9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@4&5R;6ES<_5E
M<P!%9&ET87(@<&5R;6ES<_5E<R!D92`E<P!%9&ET87(@4&%S=&$@5FER='5A
M;`!%9&ET87(@1&5F:6YIY^-O(&1E(%!A<W1A(%9I<G1U86P@9&4@)7,`161I
M=&%R($QI<W1A($)R86YC80!%9&ET87(@;W#G]65S(&1E.@!%9&ET87(@<&5R
M;6ES<_5E<R!D92`B)7,B`$5D:71A<B!P97)M:7-S]65S(&1E("5S`$5D:71A
M<B!A('-U82!L:7-T82!N96=R80!%9&ET87(@87,@<W5A<R!R96=R87,@9&4@
M9FEL=')A9V5M`$5D:71A<B!A<R!S=6$@<')E9F5RZFYC:6%S('!A<F$@86-E
M9&5R(&$@;W5T<F%S(&-O;G1A<R!D92!C;W)R96EO(&5L96-T<O-N:6-O+@!%
M9&ET87(@82!S=6$@;&ES=&$@8G)A;F-A`$5D=6-AY^-O`$5G:7!T;P!297#Z
M8FQI8V$@9&4@16P@4V%L=F%D;W(`16QE;65N=&\N+BX`16T`0V]R<F5I;R!%
M;&5C='+S;FEC;P!%;F1E<F7G;R!D92!%;6%I;`!/<R!E;F1E<F7G;W,@=.IM
M('%U92!C;VEN8VED:7(N`$UE;G-A9V5M(&-O;2!C;VYF:7)M8>?C;P!3[6UB
M;VQO<R!D92!%;6_GXV\`5&]D87,@87,@;65N<V%G96T@9&4@)7,@9F]R86T@
M97-V87II861A<RX`17-V87II87(@('!A<W1A*',I`$5S=F%Z:6%R(%!A<W1A
M<R!396QE8V-I;VYA9&%S`$5S=F%Z:6%R(&$@4&%S=&$@9&4@3&EX;P!%<W9A
M>FEA<B!,:5]X;P!-96YS86=E;2!V87II82X`4V5M(')E<W5L=&%D;W,N`%-E
M;2!T97)M;W,@9&4@<')O8W5R80!!8W1I=F%R(&9U;F-I;VYA;&ED861E<R!D
M;R!01U`_`$%C=&EV87(@9G5N8VEO;F%L:61A9&5S(&1O(%,O34E-13\`06-T
M:79A<B!I;G-E<N?C;R!D92!I;6%G96YS(&1E($=A;&5R:6%S($9O=&]G<N%F
M:6-A<R!N;R!T97AT;S\`06-T:79A<B!P<F5V:7/U97,@9&4@;65N<V%G96YS
M/P!!8W1I=F%R(&UE;G4@9&4@8V]N=&5X=&\@;F\@8F]TXV\@9&ER96ET;R!D
M;R!R871O/P!/<.?U97,@9&4@16YC<FEP7W1AY^-O`$9I;0!&:6YA;&EZ87(@
M;65N<V%G96T@<F5E;G9I861A`$9I;2!D82!M96YS86=E;0!&:6T@9&$@;65N
M<V%G96T@9&4@)7,`06YO(&1E(&9I;0!!=6UE;G1A<B!%9&ET;W(`26YT<F]D
M=7IA(&$@1G)A<V4M0VAA=F4`26YT<F]D=7IA('5M82!P97)G=6YT82!D92!S
M96=U<F%NYV$@<75E('-E<N$@8V]N=FED861O(&$@<F5S<&]N9&5R('-E('!R
M96-I<V%R(&1E(')E:6YI8VEA<B!A('-U82!P86QA=G)A+7!A<W-E+"!E+F<N
M+"`G8V]M;R!S92!C:&%M82!O('-E=2!A;FEM86P@9&4@97-T:6UAY^-O/R<Z
M`$EN=')O9'5Z82!O(%523"!D82!I;6%G96T@87%U:0!);G1R;V1U>F$@;R!N
M;VUE(&1A('-U82!N;W9A('!A<W1A(%-P86T`26YT<F]D=7IA(&\@;F]M92!D
M82!S=6$@;F]V82!P87-T82!D92!R87-C=6YH;W,`26YT<F]D=7IA(&\@;F]M
M92!D82!S=6$@;F]V82!P87-T82!D92!M96YS86=E;G,@96YV:6%D87,`26YT
M<F]D=7IA(&\@;F]M92!D82!S=6$@;F]V82!P87-T82!D92!L:7AO`$UE;G-A
M9V5M($-O;7!L971A`$5N=')A9&%S.B`E9"!T;W1A;"P@)60@86-T=6%L:7IA
M9&%S+"`E9"!N;W9A<RP@)60@86QT97)A9&%S+"`E9"!D97-C;VYH96-I9&%S
M`$$@96YT<F%D82`B)7,B(&9O:2!A9&EC:6]N861A(&%O(&QI=G)O(&1E(&5N
M9&5R9>=O<R!C;VT@<W5C97-S;P!'=6ENZ2!%<75A=&]R:6%L`$5S=&%D;R!D
M82!%<FET<F5I80!%<G)O`$5R<F\@86\@96YV:6%R(')E<W!O<W1A.B`E<RX`
M17)R;R!N82!M96YS86=E;2!D92!C;W)R96EO(&5L96-T<O-N:6-O+@!%<G)O
M(&%O(&5S8W)E=F5R("(E<R(N`$5R<F\Z(`!297#Z8FQI8V$@9&$@17-T\VYI
M80!297#Z8FQI8V$@1&5M;V-RX71I8V$@1F5D97)A;"!D82!%=&GS<&EA`,ET
M:6-O`$5U<F]P80!%=F5N=&\@<F5M;W9I9&\@8V]M('-U8V5S<V\N`$-A9&$@
M,34@;6EN=71O<P!#861A(#(@;6EN=71O<P!#861A(#,P('-E9W5N9&]S`$-A
M9&$@-2!M:6YU=&]S`$-A9&$@16YT<F%D80!#861A(&UE:6$M:&]R80!#861A
M(&UI;G5T;P!686QO<F5S(&5X96UP;&\Z`$5X96-U=&%R`$5X96-U=&%N9&\Z
M`$5X<&%N9&ER`$5X<&%N9&ER(%1U9&\`17AP86YD:7(@5&]D87,@87,@4&%S
M=&%S`$5X<&%N9&ER(%!A<W1A`$5X<&%N9&ER($YO;65S`$UO<W1R87(@0F%R
M<F$@3&%T97)A;`!%>'!A;F1I<B!N;VUE<R!N82!J86YE;&$@9&4@8V]M<&]S
M:>?C;R!A=71O;6%T:6-A;65N=&4@92!N;W,@8F%S=&ED;W)E<S\`36]S=')A
M<B!P;W(@;VUI<W/C;R!T;V1A(&$@X7)V;W)E(&1E('!A<W1A<R!N82!V:7-U
M86QI>F'GXV\@9&4@<&%S=&%S/P!%>'!A;F1I;F1O`"<I)R!E<W!E<F%D;P!%
M<W!E<F%V82!U;6$@<VEM<&QE<R!P86QA=G)A(&]U('5M('1E<FUO(&1E('!R
M;V-U<F$@96YT<F4@87-P87,`1&%T82!D92!%>'!I<F'GXV\`17AP;V5N=&4`
M17AT<F%I;F1O(&1E("5S+BXN(`!#;W(@9&\@4')I;65I<F\@4&QA;F\`0V%R
M<F5G87(@8V]N9FEG=7)AY^-O(&1E(&EN<W1A;&'GXV\@<&]R($944`!?1&5S
M8V%R<F5G87(`3N-O(&9O:2!P;W-S[79E;"!P=7AA<B!A<R!P<F5F97+J;F-I
M87,N`$9A;&AA(&YA(&QI9V'GXV\@86\@<V5R=FED;W(@3$1!4"X`1F%L:&$@
M;F$@;&EG8>?C;R!A;R!S97)V:61O<B!334(N`$9A;&AA(&%O(&-O<&EA<B!D
M92`B)7,B+@!&86QH82!A;R!C;W!I87(@<&%R82`B)7,B+@!&86QH82!A;R!C
M<FEA<B!U;6$@;F]V82!C;VYE>.-O(%-!4TPN`$9A;&AA(&%O(&UO=F5R('!A
M<F$@(B5S(BX`0F]M`$EL:&%S($9A;&ML86YD("A-86QV:6YA<RD`26QH87,@
M1F%R;V4`17)R;R!&871A;#H`1F%X`$9E=F5R96ER;P!!<&%R96YT80!!<&%R
M96YT83H@`$1E<V-A<G)E9V%R`$1E<V-A<G)E9V%R(&YU;6$@:F%N96QA('-E
M<&%R861A/P!$97-C87)R96=A<B!M96YS86=E;G,@86\@96YT<F%R/P`E9"!M
M96YS86=E;G,@9&5S8V%R<F5G861A<R!D92`E<P`Q(&UE;G-A9V5M(&1E<V-A
M<G)E9V%D82!D92`E<P!$97-C87)R96=A;65N=&]S.@!$97-C87)R96=A;65N
M=&]S.B!S96T@;65N<V%G96YS(&YO=F%S+@!!;&=U;G,@06=U86-E:7)O<P!!
M;&=U;G,@3F5V]65S`$9I7VQT<F]S`$UA=')I>B!D92!C86UP;W,`1FEJ:0!!
M<G%U:79O`$-O;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O`$-O;G1A
M9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O<P!'97-TXV\@9&4@1FEC:&5I
M<F]S`$YO;64@9&\@07)Q=6EV;P!396QE8^?C;R!D;R!A<G%U:79O`$-A<G)E
M9V%M96YT;R!D92!A<G%U:79O`$-A<G)E9V%M96YT;W,@9&4@9FEC:&5I<F]S
M(&[C;R!SXV\@<W5P;W)T861O<RX`3W#G]65S(&1E($9I;'1R86=E;0!#;VYF
M:6=U<F'G]65S(&1A($9I;'1R86=E;0!&:6QT<F%R(&-O;G1E^F1O('!R;V9A
M;F\@9&4@;65N<V%G96YS/P!/('-U<&]R=&4@9&4@9FEL=')O<R!E<W3A(&1E
M<V%C=&EV861O(&YE<W1E('-I<W1E;6$N`$9I;'1R;W,`1FEL=')O<R!);F%C
M=&EV;W,`1FEL=')O<SH@)7,@<.%G:6YA<R!D92!G97-TXV\`4')O8W5R87(`
M1FEN;.)N9&EA`%%U87)T;R!#<F5S8V5N=&4`4')I;65I<F$@4.%G:6YA(&1A
M($-A:7AA(%!O<W1A;`!0<FEM96ER82!0X6=I;F$`475A<G1O($-R97-C96YT
M90!&:7AA<B!RX6-I;P!);G9E<G1E<@!&;'5T=6%N=&4`7T5N8V%M:6YH87(`
M3F5V;V5I<F\`02!P87-T82`E<R!NXV\@97AI<W1E+@!!8^?U97,@9&4@4&%S
M=&$@+2!#;VYF:7)M8>?C;P!,:7-T82!D92!087-T87,`4')E9FEX;R!D92!0
M87-T80!3=6WA<FEO(&1A(%!A<W1A`%!A<G1I;&AA(&1E('!A<W1A<R!I;F%C
M=&EV82X`571I;&EZ8>?C;R!D92!P87-T87,@:6YA8W1I=F$N`$-O<B!D;R!4
M97AT;P!#;VUI9&$`4&%R82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R=&%M
M(&EM86=E;G,`4')E=FESXV\@*%1!1BD`1&EA<R!D92!0<F5V:7/C;R`H;F]T
M92US92!Q=64@87,@<')E=FES]65S(&EN8VQU96T@=&%N=&\@9&EA<R!C;VUO
M(&YO:71E<SL@=6T@=F%L;W(@9&5M87-I861O(&=R86YD92!P;V1E(')E<W5L
M=&%R(&YU;2!B;&]C;R!M=6ET;R!L87)G;RD`17-Q=65C974M<V4@9&$@<&%L
M879R82UP87-S93\`1F]R;6%T;R!D87,@9&%T87,@9&%S(&UE;G-A9V5N<R!D
M92!H;VIE`$UO9&5L;W,`1&ET;W,`5&EP;R!D92!D:71O<P!$:71O<P!$:71O
M<R`R`$;S<G5N<P!%;F-A;6EN:&%R`$5N8V%M:6YH861A.@!-96YS86=E;2!E
M;F-A;6EN:&%D80!-96YS86=E;2!E;F-A;6EN:&%D82!D92`E<P!2965N=FEO
M<P!!<&QI8V'G]65S("AM\V1U;&]S*2!E;F-O;G1R861A<SH@)7,`4&%S=&%S
M(&5N8V]N=')A9&%S.@`VJ@!-;VQD=7)A<P!297#Z8FQI8V$@1G)A;F-E<V$`
M1G)A;N=A+"!-971R;W!O;&ET86YA`$EN9F]R;6'GXV\@9&4@1&ES<&]N:6)I
M;&ED861E<P!297-P;W-T82!,:79R92]/8W5P861O`%!E9&ED;R!,:79R92]/
M8W5P861O`%)E<W!O<W1A(&$@4&5D:61O($QI=G)E+T]C=7!A9&\`1W5I86YA
M($9R86YC97-A`%!O;&ENZ7-I82!&<F%N8V5S80!497)R87,@075S=')A:7,@
M92!!;G3A<F-T:6-A<R!&<F%N8V5S87,`7T1E`$1E`$1O($5N9&5R9>=O`$1E
M(`!$97-C<FGGXV\@0V]M<&QE=&$`3'5A($-H96EA`$YO;64@0V]M<&QE=&\`
M1&EF=7-A<P!%;F,Z`$5N8SH@`$5N8SH@)74@365N<V%G96YS($5N8V%M:6YH
M861A<P!297#Z8FQI8V$@1V%B;VYE<V$`1V%L97)I82!D92!O;F1E(')E=&ER
M87(@82!I;6%G96T`1V%L97)I83H`4F5P^F)L:6-A(&1A($?B;6)I80!/<.?U
M97,@1V5R86ES`$=E<F%R($-O;F9I9W5R8>?C;R`E<P!#\V1I9V\@1V5R861O
M`$=E<F%N9&\@;R!E<W1A9&\@9&\@;?-D=6QO("5S+BXN`$=E\W)G:6$`4F5P
M^F)L:6-A($9E9&5R86P@9&$@06QE;6%N:&$`1&5S8V%R<F5G87(@87!E;F%S
M(&UE;G-A9V5N<R!N;W9A<S\@*&%P96YA<R!)34%0*0!%<G)O(&5M(&=E=&]P
M=#H`4F5P^F)L:6-A(&1O($=A;F$`1VEB<F%L=&%R`$YO;64@4'+S<')I;P!)
M<@!)<B!P87)A($UE;G-A9V5M`$ER('!A<F$@82!E;G1R861A(&1O(&QI=G)O
M(&1E(&5N9&5R9>=O<R!C;W)R97-P;VYD96YT92!A("(E<R(`1_9D96P`4&5S
M<75I<V$@1V]O9VQE`$%U=&]R:7IA<B!A8V5S<V\`3NUV96ES(&1E(&-I;GIE
M;G1O`$=RZ6-I80!'<F5G;R`H25-/+3@X-3DM-RD`1W)O;F5LXFYD:6$`1W)A
M;F%D80!!9&UI;FES=')AY^-O(&1E($=R=7!O<P!.;VUE<R!D92!G<G5P;W,@
M;N-O('!O9&5M(&5S=&%R('9A>FEO<P!097)M:7-S]65S(&1E(&=R=7!O`$=R
M=7!O<P!'=6%D86QU<&4`1W5A;0!297#Z8FQI8V$@9&$@1W5A=&5M86QA`$=U
M97)N<V5Y`%!E<FUI<W/U97,@9&%S(%9I<VET87,`4&5R;6ES<_5E<R!D87,@
M5FES:71A<P!,:79R;R!D92!6:7-I=&%S`$=U:6[I`$=U:6[I+4)I<W-A=0!2
M97#Z8FQI8V$@0V\M;W!E<F%T:79A(&1A($=U:6%N80!!455)`$A434P`5F5R
M<^-O($A434P@9&$@365N<V%G96T`3R!(5$U,07)E82!R96-U<V$M<V4@8V]B
M87)D96UE;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!CZ6QU;&$@9&$@;&EN:&$N
M`$\@2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@
M82#Z;'1I;6$@8V]L=6YA(&1A('1A8F5L82X`3R!(5$U,07)E82!R96-U<V$M
M<V4@8V]B87)D96UE;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!L:6YH82!D82!T
M86)E;&$N`$%U=&5N=&EC8>?C;R!(5%!0(&[C;R!F;VD@96YC;VYT<F%D82X`
M4F5P^F)L:6-A(&1O($AA:71I`$%L9V]R:71M;R!D92`B2&%S:"(`3F5B;&EN
M80!#86)EYV%L:&\`0V%B9>=A;&AO<P!);&AA<R!(96%R9"!E($UC1&]N86QD
M`%1E;7!O<F%L+50@1F]R=&4`2&5B<F5U("A)4T\M.#@U.2TX+4DI`$%L='5R
M80!!:G5D80!!:G5D82!S;V)R92!O(&5D:71O<@!!:G5D80!!<&QI8V'GXV\@
M875X:6QI87(@<&%R82!C<FEA<B!E(&UA;G1E<B!T<F%D=>?U97,@9&$@<&QA
M=&%F;W)M80I(;W)D92!E(&1A<R!S=6%S(&%P;&EC8>?U97,@*&WS9'5L;W,I
M+@I087)A('5M82!I;G1R;V1UY^-O(&QE<B!O(&9I8VAE:7)O(%)%041-12!N
M97-T82!P87-T82X`2&5M:7-FZ7)I;P!!<75I(&5S=.$@;R!I;NUC:6\@9&\@
M87)Q=6EV;SH`07%U:2!E<W3A(&$@;65N<V%G96T@96T@8V]M<&]S:>?C;SH`
M17-C;VYD:61O`$5S8V]N9&ED;R!E;2!6:7-U86QI>F'GXV\@9&4@0V]N=F5R
M<V$`17-C;VYD97(@4F5M;W9I9&%S`$5S8V]N9&5R($[C;RU3=6)S8W)I=&%S
M`$5S8V]N9&5R(&%S($EM86=E;G,`06QT80!!;'1A(%!R:6]R:61A9&4`02!-
M86ES($%L=&$`3F]M97,@9&%S(&5N=')A9&%S(&AI<W3S<FEA<R!NXV\@<&]D
M96T@97-T87(@=F%Z:6]S`$-A7W-A`$5S=&%D;R!D82!#:61A9&4@9&\@5F%T
M:6-A;F\`0V%S80!%;F1E<F7G;R!D92!#87-A`%1E;&5F;VYE(&1E($-A<V$`
M4F5P^F)L:6-A(&1A<R!(;VYD=7)A<P!(;VYG=65C;VYG=64`2&]R9&4`1V5R
M861O<B!D92!T<F%D=>?U97,@2&]R9&4`2&]R9&4O2V]L86(Z($1A9&]S(%A-
M3"`E<R!I;G;A;&ED;W,@;F$@;65N<V%G96T@)7,`2&]R9&4O2V]L86(Z($YE
M;FAU;6$@;65N<V%G96T@8V]R<F5S<&]N9&4@86\@;V)J96-T;R`E<P!(;W)D
M92]+;VQA8CH@3F5N:'5M(&]B:F5C=&\@9&\@=&EP;R`E<R!E;F-O;G1R861O
M(&YA(&UE;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!296UOY^-O(&1E("5S("(E
M<R(@=&5V92!S=6-E<W-O`$AO<F1E+TMO;&%B.B!3:6YC<F]N:7IAY^-O(&1E
M("5S("(E<R(@=&5V92!S=6-E<W-O`$AO<F1E+TMO;&%B.B!/(&UO=&]R(&1E
M(&EN=&5G<F'GXV\@<F5Q=65R(&$@97AT96YSXV\@4$A0("=D;VUX;6PG`$AO
M<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L(&-R:6%R('5M82!N;W9A(.%R
M=F]R97,@6$U,('!A<F$@;R!O8FIE8W1O("5S`$AO<F1E+TMO;&%B.B!.XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M($[C;R!F;VD@<&]S<^UV96P@;V)T97(@;R!)1"!-24U%('!A<F$@82!P87)T
M92!D92!T:7!O("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L('-I
M;F-R;VYI>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O
M<W/M=F5L('-I;F-R;VYI>F%R('!A<G1I;&AA<SH@)7,`2&]R9&4O2V]L86(Z
M(%!A<G1I;&AA("(E<R(@9&5S8V]N:&5C:61A`%1R8>=O($AO<FEZ;VYT86P`
M16YC:&EM96YT;R!H;W)I>F]N=&%L`$AO<FEZ;VYT86PZ`$-O;6\@8VAE9V]U
M(&%Q=6D_("A0;W(@9F%V;W(@<F5P;W)T92UO(2D`0V]M;R!Q=65R(&UO<W1R
M87(@;W,@86YE>&]S/P!1=6%N=&%S(&-O;'5N87,@<')E=&5N9&4@:G5N=&%R
M/P!1=6%N=&]S(&-A;7!O<R`H8V]L=6YA<RD@97AI<W1E;3\`475A;G1A<R!L
M:6YH87,@<')E=&5N9&4@:G5N=&%R/P!#;VUO(&%T<FEB=6ER(&%S(&QI;FAA
M<R!C:71A9&%S(&YU;6$@<F5S<&]S=&$`2'5M:61A9&4`2'5M:61A9&4Z(`!(
M=6UO<FES=&%S`%)E</IB;&EC82!D82!(=6YG<FEA`$E-05``24U!4"`H4')O
M=&]C;VQO<R!C;VT@075T;RUD971E8^?C;RD`02!C<FEAY^-O(&1A(&-A:7AA
M('!O<W1A;"!)34%0(&9A;&AO=3H@)7,`4F5M;^?C;R!D82!C86EX82!P;W-T
M86P@24U!4"!F86QH;W4Z("5S`$-R:6'GXV\@9&4@<75O=&$@9&4@8V%I>&$@
M<&]S=&%L($E-05`@9F%L:&]U.B`E<P!)34%0('-O8G)E(%-33`!)34%0('-O
M8G)E(%-33"`H8V5R=&EF:6-A9&\@875T;RUA<W-I;F%D;RD`24U!4"!S;V)R
M92!34TP@*&%U=&\M87-S:6YA9&\I`$E-05`L('-E;2!43%,`4V5R=FED;W)E
M<R!D92!#;W)R96EO($5L96-T<O-N:6-O($E-05`O4$]0,P!%;G1R861A`$5N
M9&5R9>=O($E0`$5N9&5R9>=O($E0(&EN9&ES<&]N[79E;"X`16YD97)EYV\@
M25`@9F]R82!D;R!B;&]C;R!#2412('!E<FUI=&ED;RX`5FEO;&'GXV\@9&4@
M8FQO<75E:6\@9&4@25``25]N<V5R:7(@3&EN:&$@06YT97,`4F5P^F)L:6-A
M(&1A($ES;.)N9&D`07!E;F%S(,UC;VYE<P#-8V]N97,@8V]M(%1E>'1O`$YO
M;64@9&$@:61E;G1I9&%D93H`4V4@;N-O(&9O<B!M;W-T<F%D;R!C;W)R96-T
M86UE;G1E+"`E<R!P87)A(&\@86)R:7(@;G5M82!N;W9A(&IA;F5L82X`4V4@
M8V]N=&EN=6%R+"!T;V1A<R!A<R!M96YS86=E;G,@9&$H<RD@<&%S=&%S*',I
M('-E('!E<F1E<N-O(0!392!NXV\@=FER('%U86QQ=65R(.UC;VYE(&%O('5S
M87(@;R!);G1E<FYE="!%>'!L;W)E<BP@<&]D92!P<F5C:7-A<B!D92!S96QE
M8V-I;VYA<B!E<W1A(&-A:7AA('!A<F$@9&5S;&EG87(@82!T<F%N<W!A<NIN
M8VEA+@!392!V:7(@97-T82!M96YS86=E;2!N;6%S(&[C;R!A(&EM86=E;2!P
M<F]P<FEA;65N=&4@9&ET82P@82!I;6%G96T@<75E('!R971E;F1E(&-A<G)E
M9V%R(&[C;R!P;V1E('-E<B!M;W-T<F%D82!P96QO('-E=2!N879E9V%D;W(N
M`$EG;F]R87(`26=N;W)A<B!4=61O`%!R979I<^-O(&1A($EM86=E;3H`55),
M(&1A(&EM86=E;0!54DP@9&$@:6UA9V5M.@!);6%G96T@9&4@9V%L97)I80!)
M;6%G96T@9&4@9V%L97)I83H`0V%R<F5G86UE;G1O(&1A(&EM86=E;0!);6%G
M96YS`$EM<&]R=&%R`$EM<&]R=&%R($-H879E`$EM<&]R=&%R(%!A<B!D92!#
M:&%V97,`26UP;W)T87(@365N<V%G96YS`$EM<&]R=&%R($-H879E(%!'4`!)
M;7!O<G1A<B!#97)T:69I8V%D;W,@4&5S<V]A:7,`26UP;W)T87(@8VAA=F4@
M<&5S<V]A;"!P<FEV861A(%!'4`!);7!O<G1A<B!C:&%V92!P97-S;V%L('#Z
M8FQI8V$@4$=0`$EM<&]R=&%R($-E<G1I9FEC861O<R!097-S;V%I<R!3+TU)
M344`26UP;W)T87(@8VAA=F4@</IB;&EC80!);7!O<G1A<B!C:&%V92!P^F)L
M:6-A(%!'4`!);7!O<G1A<B!#:&%V92!0^F)L:6-A(%,O34E-10!);7!O<G1A
M<B!#:&%V92!3+TU)344`26UP;W)T87(@07)Q=6EV;R!-0D]8`$EM<&]R=&%R
M(&%R<75I=F\@34)/6"`E<R!P87)A(&$@<&%S=&$@)7,N`$EM<&]R=&%R+"!0
M87-S;R`E9`!);7!O<G1A;G1E`$UE;G-A9V5N<R!I;7!O<G1A;G1E<P`E9"!M
M96YS86=E;G,@:6UP;W)T861A<R!D92`E<RX`0V%M<&\@:6UP;W)T861O.B`E
M<P!#86UP;W,@:6UP;W)T861O<SH`16T@4')O8V5S<V%M96YT;P!);E]S97)I
M<B!,:6YH82!$97!O:7,`16YT<F%D80!);F-L=6ER('5M(&)R979E('-U;>%R
M:6\@9&\@8V%B9>=A;&AO(&YU;6$@<F5S<&]S=&$_`$EN8VQU:7(@82!M96YS
M86=E;2!O<FEG:6YA;"!N82!R97-P;W-T83\`0_-D:6=O(&1E(&%CY^-O(&EN
M=')O9'5Z:61O(&5S=.$@:6YC;W)R96-T;RX`3F]M92!D92!U=&EL:7IA9&]R
M(&]U('!A;&%V<F$M<&%S<V4@97)R861O<RX`3F]M92!D92!U=&EL:7IA9&]R
M(&]U(&5N9&5R9>=O(&%L=&5R;F%T:79O(&5R<F%D;W,N($-O;G1A8W1E(&\@
M<V5U(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M82!P87)A(&]B=&5R(&%J=61A
M+@!!=6UE;G1A<B!A($EN9&5N=&'GXV\`4F5P^F)L:6-A(&1A(,UN9&EA`%5T
M:6QI>F%D;W)E<R!);F1I=FED=6%I<P!297#Z8FQI8V$@9&$@26YD;V[I<VEA
M`$EN9F]R;6'GXV\`26YF;W)M8>?C;P!);F9O<FUAY^-O(&KA(&[C;R!E<W3A
M(&1I<W!O;NUV96P`26YF;W)M8>?C;R!S;V)R92!A(&-H879E('#Z8FQI8V$@
M)7,`26YF;W)M8>?C;R!S;V)R92!A(&-H879E('!E<W-O86P@<')I=F%D80!)
M;F9O<FUAY^-O('-O8G)E(&$@8VAA=F4@<&5S<V]A;"!P^F)L:6-A`$EN:6-I
M86QI>F%N9&\@;R!M\V1U;&\@)7,N+BX@`$5M+6QI;FAA`$EN<V5R:7(@0U]O
M;'5N82!$97!O:7,`26YS:7)A(&\@0V5R=&EF:6-A9&\@07%U:0!);G-E<FER
M($EM86=E;0!);G-I<F$@82!#:&%V92!097-S;V%L(%!R:79A9&$@4$=0($%Q
M=6D`26YS:7)A(&$@0VAA=F4@4&5S<V]A;"!0^F)L:6-A(%!'4"!!<75I`$EN
M<VER82!A($-H879E(%#Z8FQI8V$@4$=0($%Q=6D`26YS97)I<B!486)E;&$`
M26YS97)I<B!,:6=AY^-O(.`@5V5B`$EN<V5R:7(@7T-O;'5N82!!;G1E<P!)
M;G-I<FER('5M82!N;W9A(&-O;'5N82!D97!O:7,@9&$@8V]R<F5N=&4`26YS
M:7)I<B!U;6$@;F]V82!C;VQU;F$@86YT97,@9&$@8V]R<F5N=&4`26YS:7)I
M<B!U;6$@;F]V82!L:6YH82!D97!O:7,@9&$@8V]R<F5N=&4`26YS:7)I<B!U
M;6$@;F]V82!L:6YH82!A;G1E<R!D82!C;W)R96YT90!);G-E<FER('5M('!A
M<N%G<F%F;R!A</-S(&\@;O,@8V]R<F5N=&4`26YS97)I<B!U;2!P87+A9W)A
M9F\@86YT97,@9&\@;O,@8V]R<F5N=&4`26YS:7)I<B!M;V1E;&\@86QT97)N
M871I=F\`26YT<F]D=7IA('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R
M\VYI8V\@;VYD92!P;W-S82!R96-E8F5R(&$@;F]V82!P86QA=G)A+7!A<W-E
M.@!);G-I<FER(&/I;'5L82!A</-S`$EN<V5R:7(@8^EL=6QA<R!A;G1E<P!)
M;G-E<FER(&/I;'5L82!D97!O:7,`26YS97)I<B!C;VQU;F$@86YT97,`26YS
M97)I<B!M96YS86=E;G,`26YS97)I<B!P87+A9W)A9F\@86YT97,`26YS97)I
M<B!P87+A9W)A9F\@86YT97,`26YS97)I<B!L:6YH82!D97!O:7,`26YS97)I
M<B!L:6YH82!A;G1E<P!);G1R;V1U>F$@82!R97-P;W-T82!E>&EG:61A('!A
M<F$@82!P97)G=6YT82!D92!S96=U<F%NYV$Z`$EN<V5R:7(O36]D:69I8V%R
M($EM86=E;0!);G-E<FER+TUO9&EF:6-A<B!,:6=AY^-O`$-RZ61I=&\@:6YS
M=69I8VEE;G1E('!A<F$@96YV:6%R('!A<F$@82!L:7-T82!D92!D:7-T<FEB
M=6GGXV\N`$-RZ61I=&\@:6YS=69I8VEE;G1E+@!);G1E:7)O`$QI<W1A(&1E
M(&EN=&5I<F]S`$%CY^-O('-E;&5C8VEO;F%D82!I;G;A;&ED82!P87)A(&5S
M=&4@8V]M<&]N96YT92X`16YD97)EYV\@26YVX6QI9&\`0V%I>&$@4&]S=&%L
M(%)E;6]T82!);G;A;&ED80!51$@@*%5S97(@1&%T82!(96%D97(I(&EN=N%L
M:61O+@!$861O<R!:25`@:6YVX6QI9&]S`$%P;&EC8>?C;R!I;G;A;&ED82X`
M240@9&4@;&]T92`H(F)A=&-H(BD@:6YVX6QI9&\N`$-A<F%C=&5R92!I;G;A
M;&ED;R!N;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O.B`E<RX`
M3W,@9&%D;W,@<W5B;65T:61O<R!SXV\@:6YVX6QI9&]S+@!%;F1E<F7G;R!D
M92!D97-T:6YO(&EN=N%L:61O+@!&;W)M871O(&1O(&%R<75I=F\@:6YVX6QI
M9&\`0VAA=F4@:6YVX6QI9&$`0VAA=F4@9&$@;&EC96[G82!I;G;A;&ED82X`
M3&]C86QI>F'GXV\@:6YVX6QI9&$@97-P96-I9FEC861A+@!M<V=?='EP92!I
M;G;A;&ED;RX`87!I7VED(&EN=N%L:61O(&]U(&5M(&9A;'1A+@!087+B;65T
M<F]S(&EN=N%L:61O<R!O=2!E;2!F86QT82X`4&5R;6ES<^-O('!A<F5N=&%L
M(&EN=N%L:61A+@!)1"!D92!P87)C96ER;R!I;G;A;&ED;RX`0VAA=F4@<&5S
M<V]A;"!P<FEV861A(%!'4"!I;G;A;&ED82X`0VAA=F4@</IB;&EC82!P97-S
M;V%L(%!'4"!I;G;A;&ED82X`0_-D:6=O(&1E('!R;V1U=&\@:6YVX6QI9&\N
M`%!R;W1O8V]L;R!I;G;A;&ED;RX`1&5S=&EN873A<FEO(&EN=N%L:61O.B`B
M)7,B`$]B:F5C=&\@9&4@<&%R=&EL:&$@:6YVX6QI9&\`16YD97)EYV\@9&$@
M;W)I9V5M(&EN=N%L:61O+@!$861O<R!U;FEC;V1E(&EN=N%L:61O<RX`26YV
M96YTX7)I;P!);G9E<G1E<@!297#Z8FQI8V$@27-LXFUI8V$@9&\@27+C;P!2
M97#Z8FQI8V$@9&\@27)A<75E`%)E</IB;&EC82!D82!)<FQA;F1A`$EL:&$@
M9&4@36%N`%1E;7!O<F%I<RU4($ES;VQA9&]S`$5S=&%D;R!D92!)<W)A96P`
M16UI<W-O<@!)=.%L:6-O`%)E</IB;&EC82!)=&%L:6%N80!*86UA:6-A`$IA
M;F5I<F\`2F%PXV\`2F%P;V[J<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!296EN
M;R!(87-H96UI=&$@9&$@2F]R9.)N:6$`2G5L:&\`2G5N:&\`2G5S=&EF:6-A
M<@!#96YT<F%R`$IU<W1I9FEC87(`2G5S=&EF:6-A<B#@($5S<75E<F1A`$IU
M<W1I9FEC87(@X"!$:7)E:71A`$M"`%)E</IB;&EC82!D;R!#87IA<75I<W3C
M;P!0<F5S97)V87(@;R!O<FEG:6YA;#\`4F5P^F)L:6-A(&1O(%%UZ6YI80!/
M('-E<G9I9&]R($ME<F)E<F]S(')E:F5I=&]U(&$@875T96YT:6-AY^-O+@!.
M;W9A=&]S(&YO(")+97)N96PB`$-R:6'GXV\@9&$@0VAA=F4`26UP<F5S<^-O
M(&1I9VET86P@9&$@8VAA=F4`0V]M<')I;65N=&\@9&$@8VAA=F4`5&EP;R!D
M82!#:&%V90!5=&EL:7IAY^-O(&1A($-H879E`$$@8VAA=F4@:N$@97AI<W1E
M(&YO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RX`02!G97)AY^-O(&1A
M<R!C:&%V97,@<&]D92!D96UO<F%R(&UU:71O('1E;7!O+B`@0V]N=&EN=6%R
M/P!#:&%V92!E;G9I861A(&-O;2!S=6-E<W-O('!A<F$@;R!S97)V:61O<B!D
M92!C:&%V97,N`$UI^F1O<P!1=6ER:6)A=&D`4F5P^F)L:6-A(%!O<'5L87(@
M1&5M;V-RX71I8V$@9&$@0V]R96EA`%)E</IB;&EC82!D82!#;W)E:6$`0V]R
M96%N;R`H155#+4M2*0!+=7=A:70`4F5P^F)L:6-A(%%U:7)G=6EZ90!?1&ES
M<&]S:>?C;P!)9&EO;6$`4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@
M3&%O`%%U87)T;R!$96-R97-C96YT90#:;'1I;6$@4.%G:6YA(&1A($-A:7AA
M(%!O<W1A;`#:;'1I;6$@4.%G:6YA`%%U87)T;R!$96-R97-C96YT90#:;'1I
M;6$@06-T=6%L:7IAY^-O.@#:;'1I;6$@96YT<F%D83H@)7,`VFQT:6UA(&5N
M=')A9&$Z("5S(&1E("5S`-IL=&EM82!E;G1R861A.B!.=6YC80!297#Z8FQI
M8V$@9&$@3&5T\VYI80!,96D`1&ES<&]S:>?C;P!$96EX87(@=F%Z:6\@<&%R
M82!F:6-A<B!S96T@8F]R9&$`3.UB86YO`$5S<75E<F1A`$-A8F7G86QH;R!D
M82!E<W%U97)D80!686QO<F5S(.`@97-Q=65R9&$`3&5S;W1O`$%N97AO<R!C
M;VT@3&EG8>?U97,`3&EBZ7)I80!'<F%N9&4@2F%M86AI<FEY82!3;V-I86QI
M<W1A(%!O<'5L87(@P7)A8F4@9&$@3.UB:6$`3&ES=&5N<W1A:6YE`$-H=79A
M(")-;VQH82U4;VQO<R(`0VAU=FES8V]S`$-H=79I<V-O<R!-871I;F%I<P!#
M:'5V:7-C;W,@5F5S<&5R=&EN;W,`4&5Q=65N;R!!9W5A8V5I<F\`0VAU=FES
M8V\@8V]M(%1R;W9O861A`%%U961A(&1E($YE=F4`3F5V90`B3&EM97)I8VLB
M`$QI9V'GXV\`3&EG8>?C;R!A<&]N=&$@<&%R83H`3&EG87(@;R!E;F1E<F7G
M;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(.`@<.%G:6YA(&1E(&-O;7!O<VGG
MXV\@86\@;6]S=')A<@!!;F5X;W,@8V]M(&QI9V'G]65S('/C;R!P<F]I8FED
M;W,N`$QI9V'G]65S`$QI9V'G]65S(&5X<&ER87+C;R!E;2`E<P!";VQI;FAO
M(&QI;G5XZG,`3&ES=&$@+2!O('5T:6QI>F%D;W(@<&]D92!V97(@82!P87-T
M80!,:7-T87(@0F%S97,@9&4@1&%D;W,`36]S=')A<B!4\W!I8V]S(&1E($%J
M=61A`$QI<W1A<B!486)E;&%S`$QI<W1A<R!T;V1O<R!O<R!C;VYT86-T;W,@
M<75A;F1O(&-A<G)E9V%N9&\@82!J86YE;&$@9&4@8V]N=&%C=&]S/R`H<V4@
M9&5S86-T:79A9&\L('9E<N$@87!E;F%S(&]S(&-O;G1A8W1O<R!P96QO<R!Q
M=6%I<R!P<F]C=7)A<B!E>'!L:6-I=&%M96YT92D`3&ES=&%G96TM07)Q=6EV
M;P!,:7-T86=E;2U!:G5D80!)1"!D82!,:7-T80!,:7-T86=E;2U$;VYO`$QI
M<W1A9V5M+5-U8FUI<W/U97,`3&ES=&%G96TM4W5B<V-R:71A<P!,:7-T86=E
M;2U.XV\@<W5B<V-R:71A<P!,:7-T86=E;2!N;R!#86)EYV%L:&\`02!L:7-T
M86=E;2!D92!U=&EL:7IA9&]R97,@97-TX2!D97-A8W1I=F%D82X`3&ET97)A
M='5R83H`4F5P^F)L:6-A(&1A($QI='7B;FEA`$-A<G)E9V%N9&\@8FEB;&EO
M=&5C87,N+BX`0V%R<F5G86YD;RXN+@!#86EX82!0;W-T86P@3&]C86PZ`%1E
M;7!O(&QO8V%L.@!,;V-A;&EZ8>?C;R!E($9U<V\@2&]RX7)I;P!,;V-A;`!%
M;G1R87(`16YT<F%R(&5M("5S`%-A:7(`16YT<F%R`%1A<F5F87,@9&4@16YT
M<F%D80!!(&%U=&5N=&EC8>?C;R!F86QH;W4@<&]R(&\@3F]M92!D92!5=&EL
M:7IA9&]R(&]U(&$@4&%L879R82U087-S92!E<W1A<F5M(&EN8V]R<F5C=&]S
M+@!!(&%U=&5N=&EC8>?C;R!F86QH;W4N`%1E>'1O(&QO;F=O`$%M;W(`0F%I
M>&\`0F%I>&$@4')I;W)I9&%D90!,971R87,@9W)E9V%S(&UI;OIS8W5L87,`
M3&5T<F%S(&QA=&EN87,@;6EN^G-C=6QA<P!.^FUE<F]S(')O;6%N;W,@;6EN
M^G-C=6QO<P!-86ES($)A:7AO`$QU>&5M8G5R9V\`34T`34]41`!/(&%N97AO
M($U3+51.148@;N-O(&-O;G1I;FAA(&1A9&]S+@!-4T<`36%C874`36%C963S
M;FEA+"!!;G1I9V$@4F5P^F)L:6-A($IU9V]S;&%V82!D80!!<G%U:79O($UA
M8VEN=&]S:`!-861A9^%S8V%R`$UA9VEA`$-O<G)E:6\`061M:6YI<W1R8>?C
M;R!D92!#;W)R96EO`%!R979I<^-O(&1O($-O<G)E:6\`5&EP;R!D;R!S97)V
M:61O<B!D92!C;W)R96EO(&5L96-T<O-N:6-O(&%O('%U86P@8V]N96-T87(Z
M`$-A:7AA(%!O<W1A;`!/<.?U97,@9&4@4&%S=&%S(&4@5FES=6%L:7IAY^-O
M`$9A>F5R(&QI7V=AY^-O+BXN`$%S<V5G=7)E+7-E(&1E('%U92!T96T@;R!0
M14%2(&EN<W1A;&%D;R!E(&YO(&-A;6EN:&\@9&4@:6YC;'5S]65S("AI;F-L
M=61E('!A=&@I+@!#<FEA;F1O(&$@<&%S=&$@)7,`36%L875I`$UA;.%S:6$`
M36%L9&EV87,`36%L:0!-86QT80!':7)A(&$@;&ES=&$@9&4@8V%T96=O<FEA
M<R!Q=64@<&]D92!A=')I8G5I<B!A;W,@:71E;G,L(&)E;2!C;VUO(&%S(&-O
M<F5S('%U92!L:&5S(&5S=.-O(&%S<V]C:6%D87,N`$UA<&$@36%P,C0`36%P
M82!-87!1=65S=`!-87+G;P!-87)G96T`36%R8V%R(%1O9&%S(&%S($UE;G-A
M9V5N<R!N82!087-T82!#;VUO($QI9&%S`$UA<F-A<B!4;V1A<R!A<R!-96YS
M86=E;G,@;F$@4&%S=&$@0V]M;R!0;W(@3&5R`$UA<F-A<B!C;VUO.@!-87)C
M87(@;W,@9&EF97)E;G1E<R!N[79E:7,@9&4@8VET8>?C;R!C;VT@8V]R97,@
M9&EF97)E;G1E<S\`36%R8V%R(&EM86=E;G,@8V]M;R!L:61A<S\@*&%P96YA
M<R!)34%0*0!-;W-T<F%R(&UA<F-AY_5E<R!S:6UP;&5S/P!-87)C87(@8V]M
M;R!,:61A+T[C;R!L:61A`$UA<F-A<B!D92!O=71R87,@9F]R;6%S("AE+F<N
M+"!);7!O<G1A;G1E+U!O<B!R97-P;VYD97(I`$EL:&%S($UA<G-H86QL`$UA
M<G1I;FEC80!0<F]C=7)A(%1O9&]S(&]S($-A<V]S`%!R;V-U<F$@475A;'%U
M97(@0V%S;W,`0V%M<&]S('%U92!C;W)R97-P;VYD96T`36%U<FETXFYI80!-
M875R[6-I;P!-X7AI;6\@8W+I9&ET;R!P97)M:71I9&\N`$WA>&EM;R!N^FUE
M<F\@9&4@<&%R=&5S(&YU;6$@;65N<V%G96T@97AC961I9&\N`%1E;7!E<F%T
M=7)A(&WA>&EM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E<F%T=7)A
M(&WA>&EM82!N87,@^FQT:6UA<R`V(&AO<F%S.B``5&%M86YH;R!-X7AI;6\@
M9&]S($%N97AO<P!#;VUP<FEM96YT;R!MX7AI;6\`3OIM97)O(&WA>&EM;R!D
M92!A;F5X;W,@871I;F=I9&\N`%1A;6%N:&\@=&]T86P@;>%X:6UO(&1E(&%N
M97AO<R!A=&EN9VED;RX`36%I;P!-87EO='1E`$UE9&EC:6YA`$-A;F-E;&%M
M96YT;R!D92!2975N:>-O`$EN9F]R;6'GXV\@<V]B<F4@4F5U;FGC;P!0<F]P
M;W-T82!D92!2975N:>-O`%)E<W!O<W1A(&$@4F5U;FGC;P!!8W1U86QI>F'G
MXV\@9&4@4F5U;FGC;P!0961I9&\@9&4@06-T=6%L:7IAY^-O(&1E(%)E=6YI
MXV\`365M8G)O<P!,:7-T82!D92!-96YU<R!D92!087-T80!-;V1O(&1O(&UE
M;G4Z`%5N:7(@8^EL=6QA<P!);G1E9W)A;F1O('1O9&]S(&]S(&9I8VAE:7)O
M<R`E<RYP;R!C;VT@;R!C;VUPZFYD:6\N+BX`26YT96=R86YD;R!A(&QO8V%L
M:7IAY^-O("5S+BXN(`!);G1E9W)A;F1O(&\@87)Q=6EV;R!03R!D92`E<R!C
M;VT@;R!C;VUPZFYD:6\N+BX@`$EN=&5G<F%N9&\@82!T<F%D=>?C;R!D;R!M
M\V1U;&\@)7,N+BX`365N<V%G96T`17-C<FET82!D92!-96YS86=E;0!$871A
M(&1A($UE;G-A9V5M`$]PY_5E<R!D92!-96YS86=E;G,`4')O8W5R87(@365N
M<V%G96T`5&%M86YH;R!D82!-96YS86=E;0!#\V1I9V\M9F]N=&4@9&$@365N
M<V%G96T`365N<V%G96X@5F5R:69I8V%D82!C;VT@4W5C97-S;RP@;6%S(&\@
M8V5R=&EF:6-A9&\@9&\@<W5B<V-R:71O<B!NXV\@</1D92!S97(@=F5R:69I
M8V%D;RX`5FES=6%L:7IAY^-O(&1A($UE;G-A9V5M`$UE;G-A9V5M(&5X<&ER
M;W4N`$-A;7!O<R!D82!M96YS86=E;0!!=')I8G5T;W,@9&$@;65N<V%G96T`
M4&%S=&%S(&1E(&UE;G-A9V5N<P!-96YS86=E;2!D92`E<P!-96YS86=E;2!C
M;VT@86YE>&]S`$$@;65N<V%G96T@97-TX2!E;F-R:7!T861A`$$@;65N<V%G
M96T@97-TX2!A<W-I;F%D80!4:7!O(&1E('!R;V-U<F$`02!M96YS86=E;2!F
M;VD@<F5D:7)E8V-I;VYA9&$@8V]M('-U8V5S<V\N`$UE;G-A9V5M(&5N=FEA
M9&$@8V]M('-U8V5S<V\@;6%S(&[C;R!G=6%R9&%D82!E;2`E<P!-96YS86=E
M;2!E;G9I861A(&-O;2!S=6-E<W-O+@!4:7!O(&1E(&UE;G-A9V5M`$UE;G-A
M9V5N<R!P;W(@<.%G:6YA(&YA('9I<W5A;&EZ8>?C;R!D82!C86EX82!P;W-T
M86PN`$UE;G-A9V5N<R!P87)A`$UE=&5O<F]L;V=I82!-151!4@!";&]C;R!-
M151!4B!I;F1I<W!O;NUV96PN`$)L;V-O($U%5$%2(&EN9&ES<&]N[79E;"X@
M3W,@<&]R;65N;W)E<R!F;W)A;2!R96=I<W1A9&]S('!A<F$@;R!A9&UI;FES
M=')A9&]R+@!!($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861A+@!-Z71O9&\`
M3R!MZ71O9&\@(B5S(B!NXV\@97-TX2!D969I;FED;P!-Z71R:6-O`$WI>&EC
M;P!-:6-R;V[I<VEA+"!%<W1A9&]S($9E9&5R861O<R!D80!#96YT<F\`5&EP
M;R!-24U%`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A
M<P!496UP97)A='5R82!M[6YI;6$@;F%S(/IL=&EM87,@-B!H;W)A<P!%<W!E
M;&AO`$UI<V-E;.)N96$`4&%C;W1E($A45%!?4F5Q=65S="!D;R!014%2(&5M
M(&9A;'1A+@!#;VYF:6=U<F'GXV\@96T@9F%L=&$N(%1E<N$@9&4@82!G97)A
M<B!A9V]R82!S92!Q=6ES97(@=7-A<B!E<W1A(&%P;&EC8>?C;RX`240@9&$@
M;65N<V%G96T@96T@9F%L=&$N`%!A8V]T92!-86EL(&1O(%!%05(@96T@9F%L
M=&$N`$E$(&1A('-E<W/C;R!E;2!F86QT82X`,JH`0V]R<F5I;R!-\W9E;`!-
M;V1E<F%D;P!$871A(&1E($UO9&EF:6-AY^-O`$UO9&EF:6-A<@!-;V1I9FEC
M87(@55),`$WS9'5L;P!-\V1U;&\`4F5P^F)L:6-A(&1A($UO;&1O=F$`4')I
M;F-I<&%D;R!D;R!-\VYA8V\`36]N9_-L:6$`3>IS(&4@86YO`$UE;G-A;&UE
M;G1E`$UO;G1S97)R870`1F%S92!D82!,=6$`36%I<R!D;R!Q=64@=6T@96YD
M97)EYV\@96YC;VYT<F%D;R!C;VT@;R!C86UP;R`B)7,B+@!296EN;R!D92!-
M87)R;V-O<P!3;V)R971U9&\@3&EM<&\`4V]B<F5T=61O($5N979O861O`%-O
M8G)E='5D;R!3;VQA<F5N9V\`36]V97(`1&5S8V5R`$UO=F5R('!A<F$@82!%
M<W%U97)D80!-;W9E<B!P87)A(&$@1&ER96ET80!3=6)I<@!$97-C97(`36]V
M97(@<&%R82!P87-T80!3=6)I<@!297#Z8FQI8V$@9&4@36_G86UB:7%U90!,
M:7-T87,@9&4@9&5S96YR;VQA<B!M=6QT:2UN[79E;`!-=6QT:7!A<G1E+V%L
M=&5R;F%T:79A`%-E;&5CY^-O(&WZ;'1I<&QA`$$@36EN:&$@0V]N=&$`3R!-
M974@4&]R=&%L`$1I<W!O<VGGXV\@9&\@4&]R=&%L`%5N:>-O(&1E($UY86YM
M87(`3N-O+"!NXV\@8V]N8V]R9&\`3D]400!.;VUE`$\@3F]M92!E+V]U(&\@
M96UA:6P@;N-O('!O9&5M('-E<B!V87II;W,`4F5P^F)L:6-A(&1A($YA;>UB
M:6$`3F%U<G4`06/GXV\@3F5C97-SX7)I80!.97!A;`!296EN;R!D;W,@4&'M
M<V5S($)A:7AO<P!!;G1I;&AA<R!(;VQA;F1E<V%S`%523"!D92!"87-E($YE
M='-C87!E`%523"!D92!2979O9V'GXV\@0T$@3F5T<V-A<&4`55),(&-O;2!A
M('!O;.UT:6-A(&1E($-!($YE='-C87!E`%523"!D92!296YO=F'GXV\@3F5T
M<V-A<&4`55),(&1E(%)E=F]G8>?C;R!.971S8V%P90!.;VUE(&1O('-E<G9I
M9&]R(%-33"!.971S8V%P90!#;VUE;G3A<FEO(&1E(&-E<G1I9FEC861O($YE
M='-C87!E`%1I<&\@9&4@8V5R=&EF:6-A9&\@3F5T<V-A<&4`4F5D90!.=6YC
M80!.=6YC82!G=6%R9&%R(&%N97AO<P!.;W9A`$YO=F$@0V%L963S;FEA`$YO
M=F$@0V%T96=O<FEA`$YO=F$@4&%S=&$`3F]V82!-96YS86=E;0!,=6$@3F]V
M80!.;W9O($YO;64@9&4@571I;&EZ861O<B`H;W!C:6]N86PI`$YO=F$@6F5L
MXFYD:6$`365N<V%G96YS(&YO=F%S`$YO=F$@:F%N96QA("A?8FQA;FLI`$YO
M=.UC:6%S`$=R=7!O<R!D92!.;W3M8VEA<P!0<O-X:6UA`%!R\WAI;6%S(#0@
M1F%S97,`4'+S>&EM82!-96YS86=E;0!0<O-X:6UA(%#A9VEN80!0<O-X:6UA
M<R!O<.?U97,`4'+S>&EM83X`4F5P^F)L:6-A(&1A($YI8V%RX6=U80!297#Z
M8FQI8V$@9&\@3NUG97(`4F5P^F)L:6-A($9E9&5R86P@9&$@3FEG97)I80!.
M;VET90!.:75E`$[C;P!#97)T:69I8V%D;R!NXV\@9F]I(&5N8V]N=')A9&\`
M4V5M($5N8W)I<'1AY^-O`$[C;R!E>&ES=&4@;F5N:'5M82!C:&%V90!.XV\@
M2.$@365N<V%G96YS`$[C;R!F;VD@:6UP;W)T861A(&$@8VAA=F4@</IB;&EC
M82!01U`N`%-E;2!#97)T:69I8V%D;R!097-S;V%L(%!R97-E;G1E`%-E;2!4
M97AT;R!D92!0<F5V:7/C;P!.XV\@1F]R86T@16YC;VYT<F%D87,@0VAA=F5S
M(%#Z8FQI8V%S`$[C;R!F;VD@:6UP;W)T861A(&YE;FAU;6$@8VAA=F4@</IB
M;&EC82!3+TU)344N`$[C;R!S92!E;F-O;G1R;W4@86YE>&]S+@!.XV\@:.$@
M9&%D;W,@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV96ES(&5M(')E;&'GXV\@
M86]S('%U86ES(&UO<W1R87(@9&EF97)E;N=A<RX`3N-O(&CA(&YE;FAU;6$@
M97-T<F%TZ6=I82!D:7-P;V[M=F5L('!A<F$@<F5A;&EZ87(@:6UA9V5N<R!)
M4T\N`$[C;R!HX2!M;V1E;&\@9&4@;&]T92`B8F%T8V@B+@!.XV\@97AI<W1E
M(&)L;V-O(&YA('!O<VGGXV\@:6YD:6-A9&$`3N-O(&9O:2!F;W)N96-I9&\@
M=6T@;F]M92!D92!C86QE;F3A<FEO('!A<F$@82!A=71E;G1I8V'GXV\@34-!
M3"X`4V5M(&UO9&EF:6-AY_5E<RX`3N-O('-E('!O9&4@861I8VEO;F%R('!E
M<FUI<W/U97,@9&4@9FEL:&]S(&%B86EX;R!D97-T92!N[79E;"X`3N-O('-E
M('!O9&4@861I8VEO;F%R(&9I;&AO<R!A(&5S=&$@<&5R;6ES<^-O+@!.96YH
M=6T@8V]M86YD;R!E<W!E8VEF:6-A9&\N`$[C;R!F;VD@97-P96-I9FEC861A
M(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@<&%R82`E<RX`3N-O(&9O
M:2!E<W!E8VEF:6-A9&$@82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!P
M87)A(%9&4R!B87-E861O(&5M($944"X`3N-O(&9O:2!E<W!E8VEF:6-A9&$@
M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!N96-E<W/A<FEA('!A<F$@
M;R!61E,@8F%S96%D;R!E;2!344PN`$[C;R!F;VD@97-P96-I9FEC861A(&$@
M:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@;F5C97-SX7)I82!P87)A(&\@
M5D93(&)A<V5A9&\@96T@4U%,+49I;&4N`$-RZ61I=&\@97-G;W1O=2X`3F5N
M:'5M(&1E<W1I;F%TX7)I;R!F;VD@9F]R;F5C:61O+@!.XV\@:.$@:6YF;W)M
M8>?C;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(&YA(&-H879E('#Z8FQI8V$N
M`$[C;R!E>&ES=&4@<75A;'%U97(@96YT<F%D82!C;VT@;R!I9"`B)7,B(&YO
M(&%R<75I=F\@9&4@86IU9&$@;W)I9VEN86PN`$[C;R!S92!C87)R96=O=2!N
M861A+@!.XV\@9F]I('-E;&5C8VEO;F%D82!N96YH=6UA('!A<W1A+@!.96YH
M=6UA('!A<W1A(&5S=.$@82!V97)I9FEC87(@;F]V87,@;65N<V%G96YS+@!.
M96YH=6UA('!A<W1A(&9O:2!E<W!E8VEF:6-A9&$`3N-O(&CA('!A<W1A<R!C
M;VT@;F]V87,@;65N<V%G96YS`$[C;R!HX2!P87-T87,@8V]M(&UE;G-A9V5N
M<R!P;W(@;&5R`$YE;FAU;6$@;&]C86QI>F'GXV\@97-P96-I9FEC861A+@!&
M86QT82!I;F1I8V%R('5M82!L;V-A;&EZ8>?C;RX`02!L;V-A;&EZ8>?C;R!N
MXV\@9F]I(&5S<&5C:69I8V%D82X`365N<V%G96T@<V5M('1E>'1O(&YO(&-O
M<G!O`$YE;FAU;6$@;65N<V%G96T@9F]I(&9O<FYE8VED82X`3F5N:'5M82!M
M96YS86=E;2!C;W)R97-P;VYD92#@('-U82!P<F]C=7)A+@!.96YH=6T@;F]M
M92!E<W!E8VEF:6-A9&\N`$YE;FAU;2!N^FUE<F\@97-P96-I9FEC861O+@!3
M96T@9&ET;W,@;V9E;G-I=F]S`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M
M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!(5%10+@!.XV\@9F]I(&9O<FYE
M8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@24U!4"X`
M3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT
M:6-AY^-O($ME<F)E<F]S+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A
M<W-E('!A<F$@82!A=71E;G1I8V'GXV\@3$1!4"X`3N-O(&9O:2!F;W)N96-I
M9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($QO9VEN+@!.
MXV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I
M8V'GXV\@4$%34U=$+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E
M('!A<F$@82!A=71E;G1I8V'GXV\@4TU"+@!.XV\@9F]I(&EN9&EC861O(&-A
M;6EN:&\@<&%R82!O(&)I;N%R:6\@3W!E;E-33"X@3R!B:6[A<FEO($]P96Y3
M4TP@Z2!N96-E<W/A<FEO('!A<F$@=')A8F%L:&%R(&-O;2!D861O<R!02T-3
M(#$R+@!.XV\@:.$@<W5B<V-R:>?U97,@<&5N9&5N=&5S+@!.XV\@9F]I(&EM
M<&]R=&%D82!N96YH=6UA(&-H879E('!E<W-O86P@<')I=F%D82!01U`N`$[C
M;R!F;VD@:6UP;W)T861A(&YE;FAU;6$@8VAA=F4@<&5S<V]A;"!P^F)L:6-A
M(%!'4"X`3N-O(&9O:2!I;7!O<G1A9&\@;F5N:'5M(&-E<G1I9FEC861O('!E
M<W-O86P@4R]-24U%+@!396T@=')AYV]S`%-E;2!L861O<P!0<F]G<F%M82!D
M92!C;W)R96/GXV\@;W)T;V=RX69I8V$@;N-O(&9O:2!C;VYF:6=U<F%D;RX`
M3F5N:'5M(&5R<F\@9&4@;W)T;V=R869I80!396T@<W5G97-T]65S`$[C;R!H
MX2!P87-T82!T96UP;W+A<FEA(&1I<W!O;NUV96P@<&%R82`B8V%C:&4B+@!.
M96YH=6T@=71I;&EZ861O<B!E<W!E8VEF:6-A9&\`3N-O(&9O<F%M(&5N=FEA
M9&]S(&\@;F]M92!D;R!U=&EL:7IA9&]R(&]U(&$@<&%L879R82UP87-S92X`
M3N-O(&9O<F%M(')E=&]R;F%D;W,@9&%D;W,@96T@6$U,(';A;&ED;W,`4V5M
M('9A;&]R97,`3N-O(&9O:2!E;F-O;G1R861A('9E<G/C;R!N82!C;VYF:6=U
M<F'GXV\@;W)I9VEN86PN(%)E9V5N97)A<B!C;VYF:6=U<F'GXV\N`$[C;R!F
M;VD@96YC;VYT<F%D82!V97)SXV\@;F$@<W5A(&-O;F9I9W5R8>?C;RX@4F5G
M96YE<F%R(&-O;F9I9W5R8>?C;RX`3N-O+5!A<G1I8VEP86YT90!.96YH=6UA
M`$YE;FAU;2`H=7-A<B!I;7!L[6-I=&\I`$[S<F1I8V\@*$E33RTX.#4Y+3$P
M*0!);&AA(&1E($YO<F9O;&L`3F]R;6%L`$AE;6ES9NER:6\@3F]R=&4`26QH
M87,@36%R:6%N87,@9&\@3F]R=&4`4F5I;F\@9&$@3F]R=65G80!.=6YC82!$
M97!O:7,@9&4`3G5N8V$@06YT97,@9&4`3N-O(%)E;6]V:61A`$[C;R!287-C
M=6YH;P!.XV\@26UP;W)T86YT90!.XV\@4&5S<V]A;`!.XV\@Z2!U;2!D:7)E
M8W3S<FEO`$-H879E('#Z8FQI8V$@26YVX6QI9&$N`$UE;G-A9V5N<R!NXV\@
M<F5M;W9I9&%S`$[C;R!I;7!L96UE;G1A9&$N`$[C;R!SXV\@;65N<V%G96YS
M(&EM<&]R=&%N=&5S`%!O<B!A=')I8G5I<@!.XV\@<W5P;W)T861O+@!.;W1E
M('%U92!I<W1O('!O9&4@9&5M;W)A<B!A;&=U;2!T96UP;P!.;W1A<P!.861A
M('!A<F$@;F%V96=A<BP@=F]L=&4@<&%R82!T<N%S+@!.;W1A`$YO=F5M8G)O
M`$[Z;65R;P!.^FUE<F\@9&4@8V%R86-T97)E<P!.^FUE<F\@9&4@8V]L=6YA
M<P!.^FUE<F\@9&4@;65S97,@9'5R86YT92!O<R!Q=6%I<R!A;F5X;W,@;&EG
M861O<R!V96QH;W,@<^-O(&UA;G1I9&]S+"!S92!S92!E<W1I=F5R(&$@<F5M
M;W;J+6QO<R!M96YS86QM96YT92X`3OIM97)O(&1E('!A<W1A<R!A;G1I9V%S
M(&1E(&UE;G-A9V5N<R!E;G9I861A<R!A(&UA;G1E<BP@<V4@<V4@97-T:79E
M<B!A(')E;6]VZBUL87,@;65N<V%L;65N=&4N`$[Z;65R;R!D92!L:6YH87,`
M3F$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&CA(&[Z;65R;W,@<75E(&[C;R!F
M;W)A;2!E<W!E8VEF:6-A9&]S('!A<F$@86-T=6%L:7IAY^-O+@!/2P!/50!/
M8FIE8W1O`$-R:6%D;W(@9&\@3V)J96-T;P!097)M:7-S]65S(&1O(&-R:6%D
M;W(@9&\@;V)J96-T;P!/8W1A;`!/=71U8G)O`$9I;'1R;R!D92!M871E<FEA
M;"!O9F5N<VEV;P!'86)I;F5T90!-96YS86=E;G,@86YT:6=A<P!!<R!P87-T
M87,@86YT:6=A<R!D92!M96YS86=E;G,@96YV:6%D87,@97-TXV\@82!S97(@
M<'5R9V%D87,N`%-U;'1A;F%T;R!D;R!/;>,`4_,@;W,@<V5R=FED;W)E<R!)
M34%0('-U<&]R=&%M('!A<W1A<R!P87)T:6QH861A<RX`36]S=')A<B!A<&5N
M87,@<&%S=&%S(&-O;2!M96YS86=E;G,@<&]R(&QE<C\`07!E;F%S(&1I=&]S
M(&]F96YS:79O<P!3\R#I('!E<FUI=&ED;R!U;2!E;F1E<F7G;R!D92!C;W)R
M96EO(&5L96-T<O-N:6-O+@!!<&5N87,@<V4@9&5V92!S96QE8V-I;VYA<B!U
M;6$@<&%S=&$@<&%R82!E<W1A(&]P97)AY^-O+@!!<&5N87,@;R!D;VYO(&]U
M('5M(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<&]D92!A;'1E<F%R(&$@
M=&ET=6QA<FED861E(&1E('5M82!P87)T:6QH82!O=2!A<R!P97)M:7-S]65S
M(&1O('-E=2!D;VYO`$%B<FE?<B!087-T80!!8G)I<B!087-T80!!8G)E(&YU
M;6$@;F]V82!J86YE;&$`17)R;R!/<&5N4U-,.B!.XV\@9F]I('!O<W/M=F5L
M(&5X=')A:7(@9&%D;W,@9&4@=6UA('!A<G1E(&%S<VEN861A(&-O;2!3+TU)
M344N`%!A<W1A($%B97)T80!!8G)E(&5S=&$@;&EG8>?C;R!N=6UA(&YO=F$@
M:F%N96QA`%-I<W1E;6$@3W!E<F%T:79O`%!A<G1I8VEP86YT92!/<&-I;VYA
M;`!/<.?U97,`3W#G]65S(&1O("5S`$]PY_5E<SH`3&ES=&$@3W)D96YA9&$`
M3W)G86YI>F'GXV\`56YI9&%D92!/<F=A;FEZ86-I;VYA;`!/<F=A;FEZ8>?C
M;P!-;V1E;&\@;W)I9VEN86P@9&$@87!L:6-AY^-O`$UO9&5L;W,@;W)I9VEN
M86ES(&5M("5S.@!/=71R;P!/=71R87,@26YF;W)M8>?U97,`3W5T<F%S($-O
M;G1A<R!D92!#;W)R96EO`$]U=')A<R!/<.?U97,`4&5R;6ES<_5E<R!D;R!$
M;VYO`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E;"X`4$=0
M`$%S<VEN871U<F$@1&EG:71A;"!01U``16YC<FEP=&%R($UE;G-A9V5M(&-O
M;2!01U``1&%D;W,@96YC<FEP=&%D;W,@4$=0`$5R<F\@9&\@4$=0.B``17)R
M;R!D;R!01U`Z(,D@;F5C97-SX7)I;R!A(&9R87-E(&-H879E('!A<F$@82!C
M:&%V92!P97-S;V%L('!R:79A9&$N`%!'4"!NXV\@86-T:79O`$]PY_5E<R!D
M92!01U``26YT<F]D=>?C;R!D82!F<F%S92!C:&%V92!01U``3R!P87(@9&4@
M8VAA=F5S('!E<W-O86ES(%!'4"!N96-E<W-I=&$@9&4@=6UA(&QI9V'GXV\@
M=V5B('-E9W5R82X`0VAA=F4@4/IB;&EC82!01U``5&5X=&\@9&$@0VAA=F4@
M4/IB;&EC82!01U``02!#:&%V92!0^F)L:6-A(%!'4"!P87)A("(E<R(@*"5S
M*2!F;VD@861I8VEO;F%D82!C;VT@<W5C97-S;RX`02!C:&%V92!P^F)L:6-A
M(%!'4"!P87)A("(E<R(@9F]I(')E;6]V:61A(&-O;2!S=6-E<W-O+@!!;F5L
M(&1E($-H879E<R!0^F)L:6-A<R!01U``07-S:6YA<B!-96YS86=E;2!C;VT@
M4$=0`$%S<VEN87(O16YC<FEP=&%R($UE;G-A9V5M(&-O;2!01U``1&%D;W,@
M07-S:6YA9&]S+T5N8W)I<'1A9&]S(&-O;2!01U``0VAA=F5S('!R:79A9&$@
M4$=0(&%D:6-I;VYA9&$@8V]M('-U8V5S<V\N`$$@8VAA=F5S('#Z8FQI8V$@
M4$=0(&9O:2!A9&EC:6]N861A(&-O;2!S=6-E<W-O+@!/('-U<&]R=&4@9&4@
M4$=0(&5S=.$@9&5S86-T:79A9&\@;F5S=&4@<VES=&5M82X`3R!S=7!O<G1E
M(&1E(%!'4"!NXV\@97-TX2!A8W1I=F\@9&4@;6]M96YT;RP@<&]R(&ES<V\@
M;N-O(.D@<&]S<^UV96P@=F5R:69I8V%R(&$@87-S:6YA='5R82!D:6=I=&%L
M+@!/('-U<&]R=&4@9&4@4$=0(&[C;R!E<W3A(&%C=&EV;R!D92!M;VUE;G1O
M+"!P;W(@:7-S;R!NXV\@Z2!P;W-S[79E;"!D97-E;F-R:7!T87(@82!M96YS
M86=E;2X`3R!S=7!O<G1E(&1E(%!'4"!E>&EG92!A('5T:6QI>F'GXV\@9&4@
M:F%N96QA<R`B<&]P=7`B+B`@4V4@;R!S974@;F%V96=A9&]R(&%S(&5S=&EV
M97(@82!B;&]Q=65A<BP@9&5V97+A(&%L=&5R87(@97-S82!C;VYF:6=U<F'G
MXV\L('!O:7,@9&4@;W5T<F\@;6]D;R!A<R!F=6YC:6]N86QI9&%D97,@9&\@
M4$=0(&[C;R!S92!C;VUP;W)T87+C;R!C;VUO(&1E<V5J861O`$/S9&EG;R!0
M2%``0V]M86YD;W,@4$A0`$-H=79I<V-O<R!P96QA(%1A<F1E`$%G=6%C96ER
M;W,@9&4@5&%R9&4`3F5V92#@(%1A<F1E`$YE=O5E<R#@(%1A<F1E`%-O;"#@
M(%1A<F1E`%1E;7!O<F%I<RU4(.`@5&%R9&4`4$]0,P!03U`S("A0<F]T;V-O
M;&]S(&-O;2!!=71O+61E=&5CY^-O*0!03U`S('-O8G)E(%-33`!03U`S('-O
M8G)E(%-33"`H8V5R=&EF:6-A9&\@875T;RUA<W-I;F%D;RD`4$]0,R!S;V)R
M92!34TP@*&%U=&\M87-S:6YA9&\I`%!/4#,L('-E;2!43%,`0V]M86YD;W,@
M4%](4`!%;F-H:6UE;G1O`%#A9VEN82`E9"!D92`E9`!0X6=I;F$@8V]M(&$@
M4')I;65I<F$@365N<V%G96T@4&]R(&QE<@!0X6=I;F$@8V]M(&$@VFQT:6UA
M($UE;G-A9V5M('!O<B!,97(`4F5P^F)L:6-A($ES;.)M:6-A(&1O(%!A<75I
M<W3C;P!297#Z8FQI8V$@9&4@4&%L874`5&5R<FET\W)I;R!086QE<W1I;FEA
M;F\`4&%N86WA`%!A<'5A($YO=F$@1W5I;ND`4F5P^F)L:6-A(&1O(%!A<F%G
M=6%I`%!A<G1E*',I`%!A<F-I86QM96YT92!%;F-O8F5R=&\`1G)A<V4@8VAA
M=F4`1G)A<V4@8VAA=F4@*&YO=F%M96YT92D`02!F<F%S92!C:&%V92!F;VD@
M9&5S8V%R<F5G861A(&-O;2!S=6-E<W-O+@!&<F%S92!C:&%V93H`02!F<F%S
M92!C:&%V92!NXV\@<&]D92!S97(@=F%Z:6$`07,@9G)A<V5S(&-H879E(&[C
M;R!C;VEN8VED96T`4&%L879R82UP87-S90!086QA=G)A+5!A<W-E(&EN8V]R
M<F5C=&$`4&%L879R82U087-S92!N96-E<W/A<FEA('!A<F$@875T96YT:6-A
MY^-O(%)!1$E54P!086QA=G)A+5!A<W-E(&-O;2!C;VYF:7)M8>?C;P!086QA
M=G)A+5!A<W-E.@!086QA=G)A+5!A<W-E.B``07,@<&%L879R87,M<&%S<V4@
M=.IM(&1E('-E<B!I9W5A:7,N`$-O;&%R`$-O;&%R(&1E(')E8V]R=&5S`$-A
M;6EN:&\`4W5B<V-R:>?U97,@4&5N9&5N=&5S.@!097-S;V%S`%!E<F-E;G1A
M9V5M`$5X96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O`$5X96-U=&%R
M(&%S(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%Q=6%N9&\@9&$@96YT<F%D
M83\`4&5R;6ES<^-O`$$@<&5R;6ES<^-O("(E<R(@;N-O(&9O:2!R96UO=FED
M82X`061M:6YI<W1R8>?C;R!D92!097)M:7-S]65S`%!E<FUI<W/U97,@9&4`
M07,@<&5R;6ES<_5E<R!D97-T92!U=&EL:7IA9&]R(&[C;R!P;V1E;2!S97(@
M86QT97)A9&%S+@!097-S;V%L`$EN9F]R;6'G]65S(%!E<W-O86ES`%!A<B!D
M92!C:&%V97,@<&5S<V]A:7,@4$=0(&=E<F%D87,@8V]M('-U8V5S<V\`0VAA
M=F5S('!E<W-O86ES(%!'4"!R96UO=FED87,@8V]M('-U8V5S<V\N`$-E<G1I
M9FEC861O<R!3+TU)344@<&5S<V]A:7,@3L-/(&EM<&]R=&%D;W,`0VAA=F5S
M('!E<W-O86ES(%,O34E-12!R96UO=FED87,@8V]M('-U8V5S<V\N`%!E<OH`
M06YI;6%I<R!D92!%<W1I;6'GXV\`1FEL:7!I;F%S`%1E;&5F;VYE`$9O=&]G
M<F%F:6%S`$EL:&%S(%!I=&-A:7)N`%#M>&5I<P!#;VQO8V%R(&$@<W5A(&%S
M<VEN871U<F$@86YT97,@9&4@<F5S<&]S=&%S(&]U(')E96YC86UI;FAA;65N
M=&]S/P!697)SXV\@9&$@365N<V%G96T@96T@5&5X=&\@4VEM<&QE<P!0;&%T
M:71U9&5S`%!O<B!F879O<B!C;&EQ=64@<V]B<F4@=6UA(&/I;'5L80!0;W(@
M9F%V;W(@8V]N9FER;64@<V4@<F5A;&UE;G1E('!R971E;F1E(')E;6]V97(@
M97-T92!E;&5M96YT;SH`4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E86QM96YT
M92!P<F5T96YD92!D97-L:6=A<B!E<W1E(&5L96UE;G1O+@!0;W(@9F%V;W(@
M:6YT<F]D=7IA('5M(&WJ<R!E('5M(&%N;RX`4&]R(&9A=F]R(&EN=')O9'5Z
M82!O(&YO;64@9&$@;F]V82!C871E9V]R:6$Z`%!O<B!F879O<BP@:6YT<F]D
M=7IA(&\@;F]M92!D82!N;W9A('!A<W1A.@!0;W(@9F%V;W(@:6YT<F]D=7IA
M('5M(&5N9&5R9>=O($E0(';A;&ED;RX`4&]R(&9A=F]R(&EN=')O9'5Z82!U
M;6$@9&%T82!VX6QI9&$[('9E<FEF:7%U92!O(&[Z;65R;R!D92!D:6%S(&1O
M(&WJ<RX`4&]R(&9A=F]R(&EN=')O9'5Z82!U;6$@:&]R82!VX6QI9&$N`%!O
M<B!F879O<BP@:6YT<F]D=7IA(&\@;F]M92!D82!N;W9A('!A<W1A.@!0;W(@
M9F%V;W(L(&EN=')O9'5Z82!O(&YO=F\@;F]M93H`4&]R(&9A=F]R(&EN=')O
M9'5Z82!A(&9R87-E+6-H879E(&1A('-U82!C:&%V92!P<FEV861A(%!'4"X@
M07!E;F%S('!R96-I<V$@9&4@:6YT<F]D=7II<B!E<W1A(&9R87-E(&-H879E
M('5M82!V97H@<&]R('-E<W/C;R`E<R!N;R!)35`N`%!O<B!F879O<B!I;G1R
M;V1U>F$@82!F<F%S92UC:&%V92!D82!S=6$@8VAA=F4@<')I=F%D82!3+TU)
M344N($%P96YA<R!P<F5C:7-A(&1E(&EN=')O9'5Z:7(@97-T82!F<F%S92!C
M:&%V92!U;6$@=F5Z('!O<B!S97-SXV\@)7,@;F\@24U0+@!0;W(@9F%V;W(@
M96YT<F4@9&4@;F]V;R!P87)A(')E8V]M9>=A<B!A(&-O;7!O<VGGXV\@9&$@
M<W5A(&UE;G-A9V5M+B!392!.PT\@97-T:79E<B!A('5S87(@(F-O;VMI97,B
M(&4@97-T:79E<B!A(&-O;7!O<B!E;2!J86YE;&%S(&1E(")P;W!U<"(L('1E
M<N$@=&%M8NEM(&1E(&5N=')A<B!D92!N;W9O(&YA(&IA;F5L82!P<FEN8VEP
M86PN($ES=&\@<V5R=F4@<&%R82!I;7!E9&ER(&%T86-A;G1E<R!D92!S97%U
M97-T<F%R(&\@240@9&$@<W5A('-E<W/C;RX@4&5D:6UO<R!D97-C=6QP82!P
M;W(@<75A;'%U97(@:6YC;VYV96YI96YT92X`4&]R(&9A=F]R+"!F;W)N9>=A
M('5M82!B<F5V92!D97-C<FGGXV\@9&\@<')O8FQE;6$N`%!O<B!F879O<B!I
M;G1R;V1U>F$@82!S=6$@<&%L879R82UP87-S92X`4&]R(&9A=F]R+"!I;G1R
M;V1U>F$@;R!S974@3F]M92!D92!5=&EL:7IA9&]R(&4@82!S=6$@4&%L879R
M82U087-S90!0;W(@9F%V;W(@:6YT<F]D=7IA(&\@<V5U(&YO;64@9&4@=71I
M;&EZ861O<BX`4&]R(&9A=F]R(&QE:6$@;R!T97AT;R!S96=U:6YT92X@5&5M
M(&1E($-/3D-/4D1!4B!C;VT@;W,@=&5R;6]S(&1E<W1E(&%C;W)D;R!P87)A
M('5S87(@;R!S:7-T96UA+@!0;W(@9F%V;W(@<F5P;W)T92!O<R!E<G)O<R!P
M87)A(&DQ.&Y`;&ES=',N:&]R9&4N;W)G`%!O<B!F879O<B!R97-O;'9A(&]S
M(&5N9&5R9>=O<R!A;6+M9W5O<R!O=2!I;G;A;&ED;W,N`%!O<B!F879O<B!R
M979E:F$@82!I;F9O<FUAY^-O('%U92!S92!S96=U92!E(&1E<&]I<R!D96QE
M8V-I;VYE('5M82!A8^?C;R!D;R!M96YU(&%B86EX;RX`4&]R(&9A=F]R+"!S
M96QE8V-I;VYE('5M82!P87-T82!A;G1E<R!D92!E9F5C='5A<B!Q=6%L<75E
M<B!O<&5R8>?C;RX`4&]R(&9A=F]R('-E;&5C8VEO;F4@=6UA(&%CY^-O(&1O
M(&UE;G4@86)A:7AO+@!0;W(@9F%V;W(L('-E;&5C8VEO;F4@<&5L;R!M96YO
M<R!U;6$@<&%S=&$@<&%R82!E9F5C='5A<B!A('!E<W%U:7-A+@!0;W(@9F%V
M;W(L('-E;&5C8VEO;F4@87!E;F%S('5M82!P87-T82!P87)A(&5F96-T=6%R
M(&5S=&$@;W!E<F'GXV\N`%!O<B!F879O<B!S96QE8V-I;VYE(&]U(&5D:71E
M(&$@8V%I>&$@X"!P<O-X:6UA.@!0;W(@9F%V;W(@:6YT<F]D=7IA(&\@;F]M
M92!D82!N;W9A(&-A=&5G;W)I83H`4&]L\VYI80!0;VSM=&EC80!3;VYD86=E
M;G,`4F5P^F)L:6-A(%!O<G1U9W5E<V$`4&]S:6-I;VYA;65N=&\@9&5S=&$@
M:6UA9V5M`%!O<VEC:6]N86UE;G1O(&1E<W1A('1A8F5L80`B4&]S="(@<&%R
M82!E<W1A('!A<W1A("ANXV\@Z2!R97%U:7-I=&\@9&\@24U!4"D`0F%S96%D
M;R!E;2!(;W)D90!0<F5C961E<B!A('-U82!A<W-I;F%T=7)A(&-O;2!D;VES
M(&CM9F5N<R`H)RTM("<I/P!0<F5C:7!I=&'GXV\@;F%S(/IL=&EM87,@)7,@
M:&]R82AS*3H@`%!R;V)A8FEL:61A9&4@9&4\8G(@+SY0<F5C:7!I=&'GXV\`
M07,@<')E9F5RZFYC:6%S(&9O<F%M(&%L=&5R861A<R!C;VT@<W5C97-S;RX`
M4')E9G-?;&1A<#H@02!E>'1E;G/C;R!,1$%0(&YE8V5S<^%R:6$@;N-O(&9O
M:2!E;F-O;G1R861A+@!0<F5F<U]S97-S:6]N.B!!(&5X=&5N<^-O(&1E('-E
M<W/C;R!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`4')E<W/C;P!0
M<F5S<^-O(&%O(&[M=F5L(&1O(&UA<CH@`%!R97-SXV\Z(`!0<F5V:7/C;P!0
M<F5V97(@82!I;6%G96T@;G5M82!N;W9A(&IA;F5L80!-96YS86=E;2!!;G1E
M<FEO<@!0X6=I;F$@06YT97)I;W(`3W#G]65S(&%N=&5R:6]R97,`26UP<FEM
M:7(`26UP<FEM:7(@;R!D;V-U;65N=&\`4')I;W)I9&%D90!#:&%V92!0<FEV
M861A`%!A;&%V<F$M<&%S<V4@9&$@0VAA=F4@4')I=F%D80!0<F]B;&5M80!$
M97-C<FGGXV\@9&\@4')O8FQE;6$`4')O:F5C=&]S`%!E<F=U;G1A<B!S96UP
M<F4@<75E('5M(&%N97AO(&9O<B!E;G9I861O.R!O('9A;&]R('!O<B!O;6ES
M<^-O(.D@3L-/`%!E<F=U;G1A<B!S96UP<F4@<75E('5M(&%N97AO(&9O<B!E
M;G9I861O.R!O('9A;&]R('!O<B!O;6ES<^-O(.D@4TE-`$UE;G-A9V5M+7!R
M;VYT;P!0<F]T;V-O;&\Z`$-H879E(%#Z8FQI8V$`06QG;W)I=&UO(&1E($-H
M879E(%#Z8FQI8V$`26YF;W)M8>?C;R!3;V)R92!A($-H879E`$\@<W5P;W)T
M92!P87)A('-E<G9I9&]R97,@9&4@8VAA=F5S(%!'4"!P^F)L:6-A<R!F;VD@
M9&5S86-T:79A9&\N`$\@<&%R(&1E(&-H879E<R!0=6)L:6-A+U!R:79A9&$@
M;N-O(&9O:2!G97)A9&$@8V]M('-U8V5S<V\N`%!O<G1O(%)I8V\`16QI;6EN
M87(@4F5M;U]V:61A<P!%;&EM:6YA<B!296UO=FED87,`4F5M;W9E<B!087-T
M82AS*0!&<F5Q=>IN8VEA(&1A<R!P=7)G87,@9&$@<&%S=&$@9&4@3&EX;SH`
M4'5R9V%R(&UE;G-A9V5N<R!D82!P87-T82!D92!,:7AO(&-O;2!M86ES(&1O
M('%U92!E<W1E(&[Z;65R;R!D92!D:6%S+@!0=7)G87(@;65N<V%G96YS(&%N
M=&EG87,@9&$@<&%S=&$@9&4@3&EX;S\`4'5R9V%N9&\@)60@;65N<V%G96TH
M;G,I(&1A('!A<W1A(&1E($QI>&\N`%!U<F=A;F1O(#$@;65N<V%G96T@9&$@
M<&%S=&$@9&4@3&EX;RX`17-T861O(&1O(%%A=&%R`%!E9&ED;P!%<W1A9&\@
M9&$@<75O=&$Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`17-T861O(&1A
M('%U;W1A.B`E+C)F34(@+R!314T@3$E-251%`$5S=&%D;R!D82!Q=6]T83H@
M4T5-($Q)34E410!#:71A;F1O("5F.@!#:&%V92!0^F)L:6-A(%)302`H)60@
M8FET*0!396QE8^?C;R`B<N%D:6\B`$-H=79A`$-H=79A($UA=&EN86P`0VAU
M=F$@5F5S<&5R=&EN80!!9W5A8V5I<F\`0VAU=F$@92!.979E`$-H=79A(&$@
M3F5V90!$:71O($%L96%T\W)I;P!296QAY^-O`%!E7V1I<B!!=FES;R!D92!2
M96-E<.?C;P!,97(`3&5R(&UE;G-A9V5N<P!1=65R(&UE<VUO(')E;6]V97(@
M)7,_($5S=&$@;W!E<F'GXV\@;N-O('1E;2!R96=R97-S;RX`4F5M;W9E<B!M
M97-M;R!O<R!D861O<R!D;R!U=&EL:7IA9&]R("5S/R!%<W1A(&]P97)AY^-O
M(&[C;R!T96T@<F5G<F5S<V\N`%)E8V5B:61A($5M`%)E8V5B:61A($1E<V1E
M`%)E8V5B:61A($%TZ0!2961I<F5?8V-I;VYA<@!2961I<F5C8VEO;F%R`%)E
M9&ER96-C:6]N87(@365N<V%G96T`4F5D:7)E8V-I;VYA<B!E<W1A(&UE;G-A
M9V5M`%)E9&ER96-C:6]N86UE;G1O(&9A;&AO=2X`4F5F87H@82!S=6$@^FQT
M:6UA(&%CY^-O`%)E9G)E<V-A<@!2969R97-C87(@16QE;65N=&]S(&1E($UE
M;G4@1&ENXFUI8V\Z`$%C='5A;&EZ87(@5FES=6%L:7IAY^-O(&1E(%!A<W1A
M<SH`4F5F<F5S8V%R(%9I<W5A;&EZ8>?C;R!D;R!0;W)T86PZ`$5X<')E<W/C
M;R!296=U;&%R`$YA=F5G861O<B!D92!296QAY_5E<P!296-A<G)E9V%R`%)E
M8V%R<F5G87(@5FES=6%L:7IAY^-O`$]B<V5R=F'G]65S`$QE;6)R87(@82!I
M;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\N`$QE;6)R87(@82#Z;'1I;6$@=FES
M=6%L:7IAY^-O`$-A:7AA(%!O<W1A;"!296UO=&$Z`%-E<G9I9&]R97,@4F5M
M;W1O<P!54DP@4F5M;W1O("AH='1P.B\O=W=W+F5X96UP;&\N<'0O:&]R9&4I
M.@!296UO=F5R`%)E;6]V97(@0FQO8V\`4F5M;W9E<B!#86UP;R!D82!0<F]C
M=7)A`%)E;6]V97(@8V]L=6YA`%)E;6]V97(@9F]R;6%T8>?C;P!296UO=F5R
M('!A<@!296UO=F5R(&\@(G-C<FEP="(@9W5A<F1A9&\@9&$@<&%S=&$@=&5M
M<&]RX7)I82!D;R!S97)V:61O<BX`4F5M;W9E<B!F;VYT90!296UO=F5R(&\`
M4F5M;W9E<B!E<W1E(&[S(&1O(&1O8W5M96YT;P!296UO=F5R(%5T:6QI>F%D
M;W(`4F5M;W9E<B!U=&EL:7IA9&]R.B`E<P!296YO;65A<B!087-T82AS*0!2
M96YO;65A<B!A('!A<W1A(&1E(&UE;G-A9V5N<R!E;G9I861A<R!N;R!I;NUC
M:6\@9&4@8V%D82!MZG,_`$$@<F5N;VUE8>?C;R!D92`B)7,B('!A<F$@(B5S
M(B!F86QH;W4N($\@<V5R=FED;W(@9&ES<V4`4F5S7W!O;F1E<B!P87)A(&$@
M3&ES=&$`4W5B<W1I='5I<B!P;W(Z`%)E<W!O;F1E<@!297-P;W-T82!%;G9I
M861A+@!297-P;VYD97(@7V$@5&]D;W,`4F5S<&]N9&5R(&$@5&]D;W,Z`%)E
M<W!O;F1E<B!P87)A(&$@3&ES=&$`4F5S<&]N9&5R('!A<F$@82!,:7-T83H`
M4F5S<&]N9&5R(&$@7U1O9&]S`%)E<W!O;F1E<B!C;VT@365N<V%G96T@3N-O
M(%-U<&]R=&%D80!297-P;VYD97(@8V]M(&QI=G)E+V]C=7!A9&\@<&%R82!O
M<R!P<O-X:6UO<R`R(&UE<V5S+@!297-P;VYD97(@8V]M(&$@:6YF;W)M8>?C
M;R!L:79R92]O8W5P861O(&QI=G)E+@!297-P;VYD97(@4&%R80!297-P;VYD
M97(@4&%R83H@`%)E<W!O;F1E<CH`4F5P;W)T87(@8V]M;R!.XV\@4W!A;0!2
M97!O<G1A<B!C;VUO(%-P86T`4&5D:7(@079I<V\@9&4@7TQE:71U<F$`3N-O
M(&9O:2!P;W-S[79E;"!R97-P;VYD97(@86\@<&5D:61O+B!#\V1I9V\@9&4@
M97)R;R!D979O;'9I9&\Z(`!0961I<B!C;VYF:7)M8>?C;R!D92!E;G1R96=A
M/P!3;VQI8VET87(@<F5C:6)O<R!D92!L96ET=7)A/P!-96YS86=E;2!P961I
M9&$@;N-O(&5N8V]N=')A9&$N`$\@<V5R=FGG;R!P961I9&\@;N-O(&9O:2!E
M;F-O;G1R861A+@`B)7,B(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC
M861O(&YA(&-O;F9I9W5R8>?C;R!D92`E<RX`(B5S(B!O8G)I9V%T\W)I;R!N
MXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@5D93+@`B)7,B
M(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R
M8>?C;RX`0V%M<&\@3V)R:6=A=/-R:6\`4&%R=&EC:7!A;G1E($EN9&ES<&5N
M<^%V96P`3&EM<&%R`%)E:6YI8VEA<B!086QA=G)A+5!A<W-E`%)E:6YI8VEE
M(&$@4W5A(%!A;&%V<F$M4&%S<V4`17-T861O(&1O(%)E<W!O;F1E;G1E($%C
M='5A;&EZ861O`%)E<W5L=&%D;W,`4F5S=6QT861O<R`H:6YC;'5I;F1O($AO
M<F1E*3H`4F5S=6QT861O<SH`0V]N=&EN=6%R`%)E8V]M9>=A<B!A('-E<W/C
M;P!6;VQT87(@86\@1&5S8V%R<F5G86UE;G1O(&1E($-O<G)E:6\`5F]L=&%R
M(.!S($]PY_5E<P!6;VQT87(@X"!L:7-T86=E;2!D92!C86EX87,@<&]S=&%I
M<R!D97!O:7,@9&4@<F5M;W9E<BP@;6]V97(@;W4@8V]P:6%R('5M82!M96YS
M86=E;3\`4F5U;FGC;P!2179E<G1E<B!#;VYF:6=U<F'GXV\`3W#G]65S(&1E
M($5D:>?C;R!2:6-A`$%D:79I;FAA<P!$:7)E:71A`$-A8F7G86QH;R!D82!D
M:7)E:71A`%9A;&]R97,@X"!D:7)E:71A`%!R;W!R:65D861E<R!D82!,:6Y?
M:&$N+BX`4F5G<F$`4F]MZ6YI80!2;V1A<B`Q.#``4F]D87(@X"!%<W%U97)D
M80!2;V1A<B#@(&1I<F5I=&$`4')O<')I961A9&5S(&1A($QI;FAA`%!R;W!R
M:65D861E<R!D82!L:6YH80!,:6YH87,Z`%1R8>=O<P!4<F'G;W,@87!A<F5C
M97+C;R!E;G1R92!T;V1A<R!A<R!L:6YH87,@92!C;VQU;F%S`%1R8>=O<R!A
M<&%R96-E<N-O(&%P96YA<R!E;G1R92!A<R!C;VQU;F%S`%1R8>=O<R!A<&%R
M96-E<N-O(&%P96YA<R!E;G1R92!L:6YH87,`17AE8W5T87(`1F5D97)AY^-O
M(%)U<W-A`%)E</IB;&EC82!D;R!2=6%N9&$`4R]-24U%`$%S<VEN871U<F$@
M0W)I<'1O9W+A9FEC82!3+TU)344`16YC<FEP=&%R($UE;G-A9V5M(&-O;2!3
M+TU)344`365N<V%G96T@16YC<FEP=&%D82!C;VT@4R]-24U%`$5R<F\@9&\@
M4R]-24U%.B``17)R;R!D;R!3+TU)344Z($YE8V5S<^%R:6$@9G)A<V4M8VAA
M=F4@<&%R82!A(&-H879E('!E<W-O86P@<')I=F%D82X`4R]-24U%($[#3R!!
M8W1I=F\`3W#G]65S(&1E(%,O34E-10!);G1R;V1UY^-O(&1A(&9R87-E+6-H
M879E(%,O34E-10!/('-U<&]R=&4@82!087)E<R!D92!#:&%V97,@4&5S<V]A
M:7,@4R]-24U%(&5X:6IE('5M82!L:6=AY^-O('-E9W5R82X`02!#:&%V92!0
M^F)L:6-A(%,O34E-12!D92`B)7,B(&9O:2!R96UO=FED82!C;VT@<W5C97-S
M;RX`0VAA=F4@4/IB;&EC82!3+TU)344@861I8VEO;F%D82!C;VT@<W5C97-S
M;RX`06YE;"!D92!#:&%V97,@4/IB;&EC87,@4R]-24U%`%!A<B!D92!#:&%V
M97,@4/IB;&EC82]0<FEV861A(%,O34E-12!A9&EC:6]N861O(&-O;2!S=6-E
M<W-O+@!!<W-I;F%R($UE;G-A9V5M(&-O;2!3+TU)344`07-S:6YA<B]%;F-R
M:7!T87(@365N<V%G96T@8V]M(%,O34E-10!/('-U<&]R=&4@9&4@4R]-24U%
M(&5S=.$@9&5S86-T:79A9&\@;F5S=&4@<VES=&5M82X`3R!S=7!O<G1E(&1E
M(%,O34E-12!NXV\@97-TX2!A8W1I=F\@9&4@;6]M96YT;RP@<&]R(&ES<V\@
M;N-O(.D@<&]S<^UV96P@9&5S96YC<FEP=&%R(&$@;65N<V%G96TN`$\@<W5P
M;W)T92!D92!3+TU)344@;N-O(&5S=.$@86-T:79O+"!P;W(@:7-S;R!NXV\@
MZ2!P;W-S[79E;"!M;W-T<F%R(&\@8V]N=&7Z9&\@9&5S=&$@;65N<V%G96T@
M87-S:6YA9&$N`$\@<W5P;W)T92!D92!3+TU)344@;N-O(&5S=.$@86-T:79O
M+"!P;W(@:7-S;R!NXV\@Z2!P;W-S[79E;"!V97)I9FEC87(@82!A<W-I;F%T
M=7)A(&1I9VET86PN`$\@<W5P;W)T92!D92!3+TU)344@97AI9V4@82!U=&EL
M:7IAY^-O(&1E(&IA;F5L87,@(G!O<'5P(BX@(%-E(&\@<V5U(&YA=F5G861O
M<B!A<R!E<W1I=F5R(&$@8FQO<75E87(L(&1E=F5RX2!A;'1E<F%R(&5S<V$@
M8V]N9FEG=7)AY^-O+"!P;VES(&1E(&]U=')O(&UO9&\@87,@9G5N8VEO;F%L
M:61A9&5S(&1O(%!'4"!NXV\@<V4@8V]M<&]R=&%RXV\@8V]M;R!D97-E:F%D
M;P!!=71E;G1I8V'GXV\@4T%33"!I;F1I<W!O;NUV96PN`$UE;G-A9V5N<R!3
M35,`0V]M86YD;W,@4U%,`%-32`!354-%4U-/`$-O;6%N9&]S(%-?44P`05]S
M<W5N=&\`<^$`1W5A<F1A<B!U;6$@0_-P:6$@96T@`$=U87)?9&%R(&-O;6\`
M4V%N=&$@2&5L96YA`%/C;R!+:71T<R!E($YE=FES`%-A;G1A($SZ8VEA`%/C
M;R!0961R;R!E($UI<75E;&]N`%/C;R!6:6-E;G1E(&4@1W)E;F%D:6YE<P!-
M97-M82!M;VQD=7)A("A?<V5L9BD`17-T861O($EN9&5P96YD96YT92!D82!3
M86UO80!297#Z8FQI8V$@4V5R96[M<W-I;6$@9&4@4^-O($UA<FEN;P!3XV\@
M5&]MZ2!E(%!R[6YC:7!E`$9O<FYE8V5D;W(@9&\@4V%TZ6QI=&4`07+A8FEA
M(%-A=61I=&$`1W)A=F%R`$=U87)D87(@)7,`1W5A<F1A<B`G)7,G`$=U87)D
M87(@06YE>&]S(&-O;2!A(&UE;G-A9V5M(&YA('!A<W1A(&1E(&UE;G-A9V5N
M<R!E;G9I861A<S\`1W5A<F1A<B!287-C=6YH;P!'=6%R9&%R($]PY_5E<P!'
M=6%R9&%R(%]287-C=6YH;P!'=6%R9&%R(&-O;6\`1W5A<F1A<B!R87-C=6YH
M;W,@8V]M;R!P;W(@;&5R/P!'=6%R9&%R(&-O;F9I9W5R8>?C;R!G97)A9&$@
M8V]M;R!U;2`B<V-R:7!T(B!02%`@;F\@9&ER96-T\W)I;R!T96UP;W+A<FEO
M(&1O('-E=2!S97)V:61O<BX`1W5A<F1A<B!D97-T:6YA=.%R:6]S(&%U=&]M
M871I8V%M96YT92!N;R!L:79R;R!D92!E;F1E<F7G;W,@<&]R(&]M:7-SXV\_
M`$=U87)D87(@<')O8W5R82!C;VUO('!A<W1A('9I<G1U86P_`$=U87)D87(@
M;65N<V%G96YS(&5N=FEA9&%S/P!'=6%R9&5I(&-O;F9I9W5R8>?C;R`E<RX`
M1W5A<F1E:2!O(")S8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R!E;3H@(B5S(BX`
M3R!R87-C=6YH;R!NXV\@9F]I(&=R879A9&\N($\@<V5R=FED;W(@9&ES<V4Z
M("5S`%1E;7!O<F%I<RU4($1I<W!E<G-O<P!#:>IN8VEA`%!R;V-U<F%R`%!R
M;V-U<F%R("5S`$UO=&]R97,@9&4@4')O8W5R80!297-U;'1A9&]S(&1A(%!R
M;V-U<F$`4')O8W5R86YD;R!A<&QI8V'G]65S("AM\V1U;&]S*2!(;W)D92!E
M;2`E<P!0<F]C=7)A;F1O(&]S(&)I;N%R:6]S(&1E(&=E='1E>'0N+BX`3&ED
M80!396QE8V-I;VYA<@!396QE8V-I;VYE($]U=')A($-O;G1A`%-E;&5C8VEO
M;F%R($%R<75I=F]S`%-E;&5C8VEO;F4@=6UA(&1A=&$`4V5L96-C:6]N92!U
M;2!C86UP;P!396QE8V-I;VYE('5M(&=R=7!O(&$@86-R97-C96YT87(`4V5L
M96-C:6]N87(@=6T@;F]V;R!D;VYO`%-E;&5C8VEO;F4@=6T@<V5R=FED;W(`
M4V5L96-C:6]N92!U;2!U=&EL:7IA9&]R(&$@861I8VEO;F%R`%-E;&5C8VEO
M;F%R(&]S(&QI=G)O<R!D92!E;F1E<F7G;W,@;VYD92!S92!A9&EC:6]N87+C
M;R!E('!R;V-U<F%RXV\@96YD97)EYV]S+@!396QE8V-I;VYA<B!T=61O`%-E
M;&5C8VEO;F4@=&]D;W,@;W,@8V]M<&]N96YT97,@9&$@9&%T82X`4V5L96-C
M:6]N92!T;V1O<R!O<R!C86UP;W,@82!P<F]C=7)A<B!Q=6%N9&\@97AP86YD
M:6YD;R!E;F1E<F7G;W,N`%-E;&5C8VEO;F4@=6UA(&-O;G1A`%-E;&5C8VEO
M;F4@=6T@;V)J96-T;P!396QE8V-I;VYA<B!N96YH=6UA`%-E;&5C8VEO;F4@
M;W,@8V%R86-T97)E<R!N87,@8V%I>&%S(&%B86EX;RX@4&]D97+A(&5N=.-O
M(&-O<&GA+6QO<R!E(&-O;.$M;&]S(&YA(.%R96$@9&4@=&5X=&\N`%-E;&5C
M8VEO;F4@;R!D96QI;6ET861O<B!D82!D871A.@!396QE8V-I;VYE(&\@9F]R
M;6%T;R!D82!D871A.@!396QE8V-I;VYE(&$@:61E;G1I9&%D92!Q=64@<')E
M=&5N9&4@86QT97)A<CH`4V5L96-C:6]N92!O('1I<&\@9&\@<V5R=FED;W(`
M4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A<R!H;W)A<SH`4V5L96-C:6]N
M92!O(&9O<FUA=&\@9&$@:&]R83H`4V5L96-C:6]N92!D;VES(&-A;7!O<R!R
M96QA8VEO;F%D;W,N`$5S8V]L:&$@;R!S974@8V]N:G5N=&\@9&4@8V]R97,N
M`%-E;&5C8VEO;F4@;R!S974@:61I;VUA('!R969E<FED;SH`3&EV<F]S(&1E
M($5N9&5R9>=O<R!S96QE8V-I;VYA9&]S.@!%;G9I87(@0VAA=F4@<&%R82!O
M(%-E<G9I9&]R(&1E($-H879E<R!0^F)L:6-A<P!%;G9I87(@VFQT:6UA($EN
M9F]R;6'GXV\`16YV:6%R($UE;G-A9V5M`$5N=FEA<B!296QA=/-R:6\@9&4@
M4')O8FQE;6%S`$5N=FEA<B!335,`16YV:6%R(&%V:7-O(&1E(&QE:71U<F$@
M<75A;F1O(&9O<B!R97%U97)I9&\_`%)E</IB;&EC82!D;R!396YE9V%L`"!3
M96YS;W(Z(`!087-T82!D92!M96YS86=E;G,@96YV:6%D87,`4&%S=&$@9&4@
M;65N<V%G96YS(&5N=FEA9&%S.@!3971E;6)R;P!3Z7)V:6$@92!-;VYT96YE
M9W)O`$[Z;65R;R!D92!3Z7)I90!397)V:61O<@!);F9O<FUAY^-O('-O8G)E
M(%-E<G9I9&]R97,@92!087-T87,`1&%D;W,@9&\@<V5R=FED;W(@97)R861O
M<R!O=2!I;F1I<W!O;NUV96ES+@!397)V:61O<CH`240@9&4@<V5S<^-O(&5X
M<&ER;W4N`$%T<FEB=6ER`$5S=&%B96QEYV$@;W#G]65S('%U92!L:&4@<&5R
M;6ET86T@<F5I;FEC:6%R(&$@<W5A('!A;&%V<F$M<&%S<V4@<V4@86QG=6UA
M('9E>B!D96QA('-E(&5S<75E8V5R+@!!:G5S=&%R('!R969E<NIN8VEA<R!A
M8V5R8V$@9&\@<75E(&%C;VYT96-E('%U86YD;R!M;W9E(&]U(')E;6]V92!M
M96YS86=E;G,N`$-O;&]C87(@;R!C86)EYV%L:&\@6"U0<FEO<FED861E(&%O
M(&-O;7!O<B!A<R!M96YS86=E;G,_`$5S<&5C:69I8V%R('-E<G9I9&]R97,@
M<F5M;W1O<R!Q=64@9&5S96IA(&%C961E<B!N;R!S974@<&]R=&%L+@!396QE
M8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F97)I9&\L(&\@<V5U(&9U<V\@:&]R
MX7)I;R!E(&%S('-U87,@;W#G]65S(&1E(&1A=&%S+@!%<V-O;&AA(&$@<W5A
M(&%P;&EC8>?C;R!I;FEC:6%L+"!O(&5S<75E;6$@9&4@8V]R97,L(&\@<F5F
M<F5S8V%M96YT;R!D92!PX6=I;F%S(&4@;W5T<F%S(&]PY_5E<R!D92!V:7-U
M86QI>F'GXV\N`$-O;F9I9W5R87(`(E-C<FEP=',B(&1E(&%C='5A;&EZ8>?C
M;R!D:7-P;V[M=F5I<P!6X7)I87,@;&]C86QI>F'G]65S('!O<W/M=F5I<R!C
M;VT@;R!P87+B;65T<F\Z(`!396EC:&5L97,`4&%R=&EL:&%R(%!A<W1A<P!0
M87)T:6QH87(@<&%S=&%S(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\`4&%R=&EL
M:&%R('!A<W1A<R!D92!C;W)R96EO(&5L96-T<O-N:6-O(&-O;2!O=71R;W,@
M=71I;&EZ861O<F5S+@!#;VUP<F%S`$)R979E(%-U;>%R:6\`1&5V96TM<V4@
M9&5F:6YI<B!T96-L87,@9&4@86-E<W-O('!A<F$@82!M86EO<FEA(&1A<R!L
M:6=AY_5E<S\`1W)E;F1E<R!B;&]C;W,@9&4@=&5X=&\@8VET861O(&1E=F5M
M('-E<B!M;W-T<F%D;W,@;W4@;V-U;'1A9&]S('!O<B!O;6ES<^-O/R!!('-U
M82!E<V-O;&AA('!O9&4@<V5R(&%L=&5R861A(&9A8VEL;65N=&4N`$\@8V]R
M<&\@9&4@;65N<V%G96YS(&1E(")T97AT+W!L86EN(B!D979E('-E<B!P97)C
M;W)R:61O('!R;V-U<F%N9&\@9&%D;W,@4$=0/P!!(&IA;F5L82!D92!C;VUP
M;W-IY^-O(&1E=F4@<V5R(&9E8VAA9&$@9&5P;VES(&1E(&=U87)D87(@=6T@
M<F%S8W5N:&\_02!J86YE;&$@9&4@97-C<FET82!D92!M96YS86=E;2!D979E
M<N$@<V5R(&9E8VAA9&$@87#S<R!A(&=R879AY^-O(&1O(')A<V-U;FAO/P!1
M=65R('%U92!A('-U82!C:&%V92!P^F)L:6-A(%!'4"!S96IA(&%N97AA9&$@
MX7,@<W5A<R!M96YS86=E;G,@<&]R(&]M:7-SXV\_`$UO<W1R87(`36]S=')A
M<B!4;V1A<R!A<R!087-T87,`36]S=')A<B!4;V1O<R!O<R!#86)EYV%L:&]S
M`$UO<W1R87(@4F5M;W9I9&%S`$UO<W1R87(@0V%B9>=A;&AO<R!,:6UI=&%D
M;W,`36]S=')A<B!);F9O<FUAY_5E<R!D92!,:7-T82!D92!#;W)R96EO`$UO
M<W1R87(@07!E;F%S(%!A<W1A<R!3=6)S8W)I=&%S`$UO<W1R87(@3N-O(%-U
M8G-C<FET87,`36]S=')A<B!U;2#M8V]N92!P87)A('!E<FUI=&ER(&QI8F5R
M=&%R(&UE;G-A9V5N<R!D;W,@<V5U<R!A;F5X;W,_`$UO<W1R87(@9&EF97)E
M;N=A<R!E;G1R92!A(&-O;F9I9W5R8>?C;R!G=6%R9&%D82!E(&%Q=64@9F]I
M(&%G;W)A(&=E<F%D82X`36]S=')A<B!M;VUE;G1O(&1A(/IL=&EM82!E;G1R
M861A(&YO('-I<W1E;6$_`$UO<W1R87(@;&5G96YD82!N82!V:7-U86QI>F'G
MXV\@9&$@8V%I>&$@<&]S=&%L/P!-;W-T<F%R(&]PY^-O('!A<F$@<')E<V5R
M=F%R(&\@;W)I9VEN86P`36]S=')A<B!P86QE=&4`36]S=')A<B!P<F5V:7/U
M97,@87!E;F%S(&1A<R!M96YS86=E;G,@<&]R(&QE<C\`36]S=')A<B!P<F5V
M:7/U97,@8V]M;R!A;F]T8>?U97,@*")T;V]L=&EP<R(I/P!-;W-T<F%R(&$@
M8F%R<F$@9&4@;65N=2!C;VT@87,@;W!E<F'G]65S('-O8G)E('1A8F5L87,_
M`$UO<W1R87(@;R!-96YU("5S(.`@97-Q=65R9&$_`$UO<W1R87(@;R#M8V]N
M92`G1&5S8V%R<F5G87(G(&YA(&)A<G)A(&1O(&UE;G4_`$UO<W1R87(@87,@
M26UA9V5N<P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I
M961A9&5S(&1E($/I;'5L87,@9&4@5&%B96QA/P!-;W-T<F%R(&$@8V%I>&$@
M9&4@9&GA;&]G;R!D87,@4')O<')I961A9&5S(&1E(%1A8F5L87,`36]S=')A
M<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!,:6YH
M87,@9&4@5&%B96QA`$UO<W1R87(@;R#M8V]N92!D92!F:6QT<F%G96T@;F$@
M8F%R<F$@9&\@;65N=3\`36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S
M(%!R;W!R:65D861E<R!D92!);6%G96T`36]S=')A<B!N^FUE<F\@=&]T86P@
M9&4@;65N<V%G96YS(&YA('!A<W1A/P!-;W-T<F%R(&-A<G)E9V%M96YT;P!!
M9W5A8V5I<F]S`$%G=6%C96ER;W,@36%T:6YA:7,`06=U86-E:7)O<R!697-P
M97)T:6YO<P!!9W5A8V5I<F]S(&YA(%9I>FEN:&%NYV$`36]S=')A9&$`16YC
M;VQH97(`16YC;VQH82!O=2!M;W9A(&\H<RD@8FQO8V\H<RD@=FEZ:6YH;RAS
M*2!P<FEM96ER;P!?5&%M86YH;P!397)R82!,9>-O`%-U8G-C<F5V97(`4W5B
M<V-R979A+"!S92!A:6YD82!NXV\@97-TX2!R96=I<W1A9&\`07-S:6YA='5R
M80!!;&=O<FET;6\@9&4@07-S:6YA='5R80!!<W-I;F%D80!297#Z8FQI8V$@
M9&4@4VEN9V%P=7)A`%1A;6%N:&\`4V%L=&%R($UA;G5T96[GXV\`3N-O('!R
M;V-E<W-A9&\N+BX`17-L;W;A<75I80!297#Z8FQI8V$@9&$@17-L;W;I;FEA
M`$YE=F4`3F5VXV\`3F5V]65S`$YE=O5E<R!-871I;F%I<P!.97;U97,@5F5S
M<&5R=&EN;W,`06QT=7)A(&1E(&YE=F4Z(`!-;W-T<F%R(&5Q=6EV86QE;G1E
M(&YA(.%G=6$Z(`!);&AA<R!386QO;>-O`%-O;>%L:6$`0V%NY_5E<R!E(%!O
M96UA<P!$:7)E8^?C;R!D92!/<F1E;F'GXV\`3W)D96YA<B!P;W(@0VAE9V%D
M80!/<F1E;F'GXV\@<&]R($1A=&$`3W)D96YA<B!P;W(@16YD97)EYV\@9&4@
M3W)I9V5M`$]R9&5N87(@<&5L;R!486UA;FAO(&1A($UE;G-A9V5M`$]R9&5N
M87(@<&]R($%S<W5N=&\`3W)D96YA<B!P;W(@0V]N=F5R<V$`3W)D96YA<B!P
M96QO($1E<W1I;F%TX7)I;P!396QE8^?C;R!D;R!S96YT:61O(&1A(&]R9&5N
M8>?C;P!%;F1E<F7G;R!D92!O<FEG96T`P69R:6-A(&1O(%-U;`!%=7)O<&$@
M9&\@4W5L("A)4T\M.#@U.2TS*0!'9?-R9VEA(&1O(%-U;"!E($EL:&%S(%-A
M;F1W:6-H(&1O(%-U;`!(96UI<V;I<FEO(%-U;`!%<W!AYV\@96YT<F4@8^EL
M=6QA<R!A9&IA8V5N=&5S`$5S<&'G;R!E;G1R92!O(&-O;G1E^F1O(&4@82!B
M;W)D82!D92!U;6$@8^EL=6QA`$5S<&'G861O<@!%<W!AYV%M96YT;P!%<W!A
MYV%M96YT;R!E(&5N8VAI;65N=&\`4F5I;F\@9&4@17-P86YH80!#;W)R96EO
M(&[C;R!S;VQI8VET861O`%!A<W1A(&1E(")3<&%M(CH`26YS97)I<B!#87)A
M8W1E<B!%<W!E8VEA;`!#87)A8W1E<F5S($5S<&5C:6%I<P!697)I9FEC87(@
M3W)T;V=R869I80!#;W)R96-T;W(@3W)T;V=RX69I8V\`5F5R:69I8V'GXV\@
M;W)T;V=RX69I8V$@8V]M<&QE=&$`17)R;W,@9&4@;W)T;V=R869I82!P;W(@
M96-RXR!Q=6%N=&\@=F5R:69I8V%N9&\N`$1I=FED:7(@8^EL=6QA`$%D:6-I
M;VYA<B!C;VQU;F$`1&EV:61I<B!L:6YH80!$97-P;W)T;W,`4F5P^F)L:6-A
M($1E;6]C<N%T:6-A(%-O8VEA;&ES=&$@9&\@4W)I($QA;FMA`%!A9'+C;P!3
M=&%R(%1R96L`0V]M9>=A<@!!;F\@9&4@:6[M8VEO`$5S=&%D;R!O=2!0<F]V
M[6YC:6$`17-T861O`$5S=&%D;R!D82!L;V-A;&EZ8>?C;R`E<RXN+B``1F]R
M;6%T;R!D92!A<FUA>F5N86UE;G1O`$5N9&5R9>=O(&1E(%)U80!287-U<F%D
M;P!,:7-T82!D92!C861E:6%S(&1E(&-A<F%C=&5R97,`1&5S8V%R=&%R($%N
M97AO`%)E=&ER87(@9&]M[6YI;R!D;R!E;F1E<F7G;P!%;&EM:6YA<B!F:6YS
M+61E+6QI;FAA/P!%<W1I;&\@6T-34UT`9&\`05]S<W5N=&\`07-S=6YT;P!#
M86UP;R!D92!!<W-U;G1O`%-U8FUE=&5R`$9O:2!S=6)M971I9&\@<&5D:61O
M('!A<F$@861I8VEO;F%R("(E<R(@86\@<VES=&5M82X@3N-O('!O9&5RX2!E
M;G1R87(@96YQ=6%N=&\@;R!S974@<&5D:61O(&[C;R!F;W(@87!R;W9A9&\N
M`%-U8G-C<F5V97(@4&%S=&$H<RD`26YF97)I;W(@X"!L:6YH80!3=6-E<W-O
M`"(E<R(@861I8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S:7-T96UA+@!,:6UP
M97IA(&1O('-I<W1E;6$@9&]S(&1A9&]S(&1O('5T:6QI>F%D;W(@(B5S(B!R
M96%L:7IA9&$@8V]M('-U8V5S<V\N`%)E;6_GXV\@9&4@(B5S(B!C;VT@<W5C
M97-S;RX`4F5M;^?C;R!D92`B)7,B(&1O('-I<W1E;6$@8V]M('-U8V5S<V\N
M`$-O;F9I9W5R8>?C;R!R979E<G1I9&$@8V]M('-U8V5S<V\N(%)E8V%R<F5G
M=64@<&%R82!V97(@87,@;75D86[G87,N`$-O;F9I9W5R8>?C;R!D92!S86QV
M86=U87)D82!G=6%R9&%D82!C;VT@<W5C97-S;RX`1FEC:&5I<F\@9&4@8V]N
M9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A("5S(&=U87)D861O(&-O;2!S=6-E
M<W-O+@`B)7,B(&%C='5A;&EZ861O(&-O;2!S=6-E<W-O`"5S(&5S8W)I=&\@
M8V]M('-U8V5S<V\`4F5P^F)L:6-A(&1O(%-U9.-O`%-U9V5S=/5E<P!3=6WA
M<FEO`$YA<V-E<B!D;R!3;VP`4/1R(&1O(%-O;`!3;VQA<F5N9V\`3F%S8V5R
M(&1O(%-O;`!.87-C97(O4/1R(&1O(%-O;`!.87-C97(@9&\@4V]L.B``4/1R
M(&1O(%-O;`!0]'(@9&\@4V]L.B``4W5P97)I;W(@X"!L:6YH80!3=7!O<G1E
M`%-U<FEN86UE`$%P96QI9&\`4W9A;&)A<F0@92!*86X@36%Y96X`4F5I;F\@
M9&$@4W5A>FELXFYD:6$`4F5I;F\@9&$@4W7I8VEA`%1R;V-A<B!-Z71O9&\@
M9&4@0V]M<&]S:>?C;P!4<F]C87(@<&%R82!#;VUP;W-IY^-O($A434P`5')O
M8V%R('!A<F$@0V]M<&]S:>?C;R!E;2!497AT;P!3=>WG80!%<G)O(&1E('-I
M;G1A>&4@;F]S('1E<FUO<R!D92!P<F]C=7)A`%)E</IB;&EC82#!<F%B92!3
M[7)I80!496UP;W)A;"U4`%1E;7!O<F%L+50@92!696YT;W-O`%1E;7!O<F%I
M<RU4`%1E;7!O<F%I<RU4($UA=&EN86ES`$%R<75I=F\@5%-6`%1A8F5L80!0
M<F]P<FEE9&%D97,@9&$@5&%B96QA`%!R;W!R:65D861E<R!D82!T86)E;&$`
M1F]R;6]S80!&;W)M;W-A`%)E</IB;&EC82!D;R!4861J:7%U:7-TXV\`5&%N
M>N)N:6$`06QV;SH`5&%R969A<P!495]X=&\`3OIM97)O(&1E(%1E;&5F;VYE
M`%1E;7!E<F%T=7)A(&1A(/IL=&EM82!H;W)A.@!496UP97)A='5R80!496UP
M97)A='5R83H@`%1E;7!E<F%T=7)A/&)R("\^*"5S06QT825S+R5S0F%I>&$E
M<RD@)F1E9SLE<P!/(&UO9&5L;R`B)7,B(&[C;R!F;VD@96YC;VYT<F%D;RX`
M061M:6YI<W1R8>?C;R!D92!-;V1E;&]S`%1E;G1A=&EV83H@`$%C96ET87(@
M<&5D:61O('1E;G1A=&EV86UE;G1E`$%C96ET92!496YT871I=F%M96YT90!/
M(&9I8VAE:7)O(&1E(%1E<FUO<R!D;R!397)V:>=O(&[C;R!F;VD@97-P96-I
M9FEC861O(&5M(&-O;F8N<&AP`%1E>'1O`$%P96YA<R!497AT;P!!;&EN:&%M
M96YT;R!D;R!T97AT;P!4;W!O(&1O('1E>'1O`#6J`%1A:6QA;F3J<R`H5$E3
M+38R,"D`4F5I;F\@9&$@5&%I;.)N9&EA`$]B<FEG861O('!O<B!U<V%R(&5S
M=&4@<VES=&5M82X`3R!A<G%U:79O(&1E(&%J=61A("5S('!A<F$@)7,@;N-O
M(&5X:7-T92!A:6YD82X@0W)I86YD;R!U;2!N;W9O+@!!(&5X=&5N<^-O($94
M4"!NXV\@97-TX2!D:7-P;V[M=F5L+@!!(&-O;'5N82!$93H@9&5V97)I82!S
M97(@;&EG861A.@!/(&5N9V5N:&\@9&4@:6YT96=R8>?C;R!(;W)D92]+;VQA
M8B!NXV\@<W5P;W)T82`B)7,B`$\@<F5G:7-T;R`H(FQO9R(I($E-4U`@;N-O
M('#T9&4@<V5R(&EN:6-I86QI>F%D;RX`3R`B36%C:6YT;W-H(')E<V]U<F-E
M(&9O<FLB`$\@(DUA8VEN=&]S:"!R97-O=7)C92!F;W)K(B!P;V1E('-E<B!D
M97-C87)R96=A9&\@)7,N`$$@8VQA<W-E($UA:6YT96YA;F-E.CH@;N-O(&9O
M:2!C87)R96=A9&$@8V]M('-U8V5S<V\`02!J86YE;&$@9&4@3W#G]65S(&9E
M8VAO=2X@4V'M;F1O+@!!(&-O;G1A("(E<R(@9F]I(')E;6]V:61A+@!!(&-O
M;G1A("(E<R(@9F]I(&=U87)D861A+@!/(&5N9&5R9>=O("(E<R(@9F]I(&%D
M:6-I;VYA9&\@82`E<RX`3R!A9&UI;FES=')A9&]R('1E;2!D92!C;VYF:6=U
M<F%R('5M(&UE8V%N:7-M;R!D92!P97)M:7-S]65S('!E<FUA;F5N=&4@<V4@
M<75I<V5R('5S87(@4&5R;6ES<_5E<RX`3R!A;F5X;R!NXV\@9F]I(&5N8V]N
M=')A9&\N`$%P96YA<R!O(&QA9&\@:6YF97)I;W(`3W,@9&%D;W,@9&4@8V%L
M96YDX7)I;R!SXV\@:6YVX6QI9&]S`$$@:F%N96QA(&1E(&-O;7!O<VGGXV\@
M;N-O('#T9&4@<V5R(&%B97)T82X@5&%L=F5Z('1E;FAA(&-O;F9I9W5R861O
M(&\@<V5U(&YA=F5G861O<B!P87)A(&)L;W%U96%R(&IA;F5L87,@9&4@(G!O
M<'5P(C\`3R!N^FUE<F\@9&4@240@9&\@8V]N=&%C=&\@;N-O(&9O:2!E<W!E
M8VEF:6-A9&\L(&9O:2!D96EX861O(&5M(&)R86YC;R!O=2!NXV\@9F]I(&5N
M8V]N=')A9&\@;F$@8F%S92!D92!D861O<RX`3R!C;VYT86-T;R!F;VD@861I
M8VEO;F%D;R#@(&QI<W1A(&1E(&-O;G1A8W1O<R!C;VT@<W5C97-S;RX`3R!C
M;VYT9?ID;R!D;R!A<G%U:79O($UA8VEN=&]S:"!E;F-O;G1R82US92!A8F%I
M>&\N`$$H<RD@<&%S=&$H<RD@8V]R<F5N=&4H<RD@(B5S(B!S97+A*.-O*2!R
M96YO;65A9&$H<RD@<&%R82`B)7,B+@!!(&QI<W1A(&-O<G)E;G1E(&1E('5T
M:6QI>F%D;W)E<R!C;VT@86-E<W-O(&$@97-T82!P87-T82!NXV\@</1D92!S
M97(@96YC;VYT<F%D82X`3R!B;&]C;R!D92!A<W-I;F%T=7)A(%!'4"!D97-T
M86-A9&\@Z2!N96-E<W/A<FEO('!A<F$@=F5R:69I8V%R('5M82!M96YS86=E
M;2!A<W-I;F%D82X`3R!)1"!D82!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O
M(&9O:2!E<W!E8VEF:6-A9&\L(&9O:2!D96EX861O(&5M(&)R86YC;R!O=2!N
MXV\@9F]I(&5N8V]N=')A9&\@;F$@8F%S92!D92!D861O<RX`02!L:7-T82!D
M92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF:6-A9&$N`$\@<F%S8W5N
M:&\@9F]I(&=U87)D861O(&YA('!A<W1A("(E<R(N`$%S(&9U;F-I;VYA;&ED
M861E<R!D92!E;F-R:7!T8>?C;R!E>&EG96T@=6UA(&QI9V'GXV\@<V5G=7)A
M+@!/(&5V96YT;R!F;VD@861I8VEO;F%D;R!A;R!S974@8V%L96YDX7)I;RX`
M3R!C86UP;R`B)7,B(&[C;R!P;V1E('-E<B!E>'!A;F1I9&\N`$\@87)Q=6EV
M;R`E<R!D979E<FEA(&-O;G1E<B!U;2!A=')I8G5T;R`E<RX`3R!A<G%U:79O
M("5S(&1E=F5R:6$@8V]N=&5R(&%L9W5N<R!A=')I8G5T;W,@)7,N`$\@9FEC
M:&5I<F\@;N-O('!O9&4@<V5R(&-O<&EA9&\@<&%R82!S:2!P<O-P<FEO+@!/
M(&9I8VAE:7)O(&[C;R!C;VYTZ6T@9&%D;W,N`$$@<&%S=&$@(B5S(B!JX2!E
M>&ES=&4`3R!N;VUE(&1A('!A<W1A("(E<R(@8V]N=.EM(&-A<F%C=&5R97,@
M:6YVX6QI9&]S(&4@<&]D92!C875S87(@<')O8FQE;6%S+B!%;G1R92!E;2!C
M;VYT86-T;R!C;VT@;R!A9&UI;FES=')A9&]R(&1O('-I<W1E;6$N`$$@<&%S
M=&$@(B5S(B!F;VD@8W)I861A(&UA<R!NXV\@97-TX2!N82!S=6$@;&ES=&$@
M9&4@<W5B<V-R:71A<RX`02!P87-T82`B)7,B(&9O:2!R96UO=FED82!M87,@
M8V]N=&EN=6$@;F$@<W5A(&QI<W1A(&1E('-U8G-C<FET87,N`$$@<&%S=&$@
M(B5S(B!NXV\@9F]I(&-R:6%D82X@3R!S97)V:61O<B!D:7-S90!!('!A<W1A
M("(E<R(@;N-O(&9O:2!R96UO=FED82X@16ES(&\@<75E(&\@<V5R=FED;W(@
M9&ES<V4`02!P87-T82`@(B5S(B!F;VD@8W)I861A(&-O;2!S=6-E<W-O+@!!
M('!A<W1A("(E<R(@9F]I(')E;6]V:61A(&-O;2!S=6-E<W-O+@!!('!A<W1A
M("(E<R(@9F]I(')E;F]M96%D82!P87)A("(E<R(@8V]M('-U8V5S<V\N`$%B
M86EX;R!E<W3C;R!O<R!C86)EYV%L:&]S(&1E<W1A(&UE;G-A9V5M+VUE;G-A
M9V5M(')F8S@R,BX`3W,@<V5G=6EN=&5S(&%R<75I=F]S(&9O<F%M(&%N97AA
M9&]S(&$@97-T82!P87)T93H`3R!M;V1O(&1E(&5C<N,@:6YT96ER;R!C875S
M82!P<F]B;&5M87,@;F\@26YT97)N970@17AP;&]R97(L(&1E=FED;R!A(&5R
M<F]S(&YO(&YA=F5G861O<B!Q=64@;N-O(&-O;G-E9W5I;6]S('5L=')A<&%S
M<V%R+B`@4&]D92!S=7)G:7(@;&EX;RP@<&]D96T@9&5S87!A<F5C97(@9G5N
M8VEO;F%L:61A9&5S(&1O(&5D:71O<B!E+V]U(&\@<V5U(&YA=F5G861O<B!P
M;V1E(&%B;W)T87(N(%-E(&\@<V5U('-I<W1E;6$@Z2!U;2!7:6YD;W=S(#EX
M+"#I(&UU:71O('!R;W;A=F5L('%U92!O8G1E;FAA('5M("='96YE<F%L(%!R
M;W1E8W1I;VX@1F%U;'0G(&4@<')E8VES92!D92!R96EN:6-I87(@;R!S:7-T
M96UA+EQN7&Y&;VD@879I<V%D;RX@(%!O<B!F879O<B!P<F5S<VEO;F4@3TL@
M<V4@86EN9&$@87-S:6T@<75I<V5R(&5X<&5R:6UE;G1A<B!O(&5D:71O<B!D
M92!E8W+C(&EN=&5I<F\N`$\@9FEC:&5I<F\@9&4@86IU9&$@)7,@;N-O(&-O
M;67G82!C;VT@/#]X;6P`02!I9&5N=&ED861E("(E<R(@9F]I(')E;6]V:61A
M+@!!<R!I;6%G96YS('-E<N-O(&UO<W1R861A<RP@<&]I<R!O(')E;65T96YT
M92!C;VYS=&$@;F\@<V5U(&QI=G)O(&1E(&5N9&5R9>=O<RX`07!E;F%S(&\@
M;&%D;R!E<W%U97)D;P!!(&QO8V%L:7IAY^-O(&1O(&%R<75I=F\@97AE8W5T
MX79E;"!D92!';G501R!T96T@9&4@<V5R(&EN9&EC861A(.`@8VQA<W-E($-R
M>7!T7W!G<#HZ+@!/('-E<G9I9&]R(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@
M9V5R;W4@82!S96=U:6YT92!M96YS86=E;2!D92!E<G)O.@!/('-E<G9I9&]R
M(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@9V5R;W4@82!S96=U:6YT92!M96YS
M86=E;2!I;F9O<FUA=&EV83H`3R!S97)V:61O<B!D92!C;W)R96EO(&5L96-T
M<O-N:6-O(&=E<F]U(&$@<V5G=6EN=&4@;65N<V%G96TZ`$$@8V%I>&$@<&]S
M=&%L("5S(&5S=.$@:N$@=F%Z:6$N`$$@;65N<V%G96T@(B5S(B!D92`B)7,B
M("@E9"!B>71E*2!E>&-E9&4@;R!T86UA;FAO(&WA>&EM;R!D92!D97-C87)R
M96=A;65N=&\N`$$@;65N<V%G96T@96T@8V]M<&]S:>?C;R!F;VD@9F5C:&%D
M82X@4V'M;F1O+@!!(&UE;G-A9V5M(&9O:2!R96UO=FED82X`02!M96YS86=E
M;2!F;VD@=F5R:69I8V%D82X`02!M96YS86=E;2!F;VD@=F5R:69I8V%D82X@
M4F5M971E;G1E.B`E<RX`02!M96YS86=E;2!E;G9I861A(&5M("5S('!A<F$@
M)7,@8V]M(&%S<W5N=&\@(B5S(B!F;VD@;6]S=')A9&$N"D[C;R!HX2!G87)A
M;G1I82!D92!Q=64@82!M96YS86=E;2!T96YH82!S:61O(')E86QM96YT92!L
M:61A(&]U(&-O;7!R965N9&ED82X`3R!N;VUE(&$@=7-A<B!Q=6%N9&\@;&EG
M86YD;R#@('#A9VEN82!D92!C;VUP;W-IY^-O`$\@;?-D=6QO(&]P96YS<VP@
MZ2!N96-E<W/A<FEO('!A<F$@82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.BX`02!J86YE;&$@9&$@<&%L879R82UP87-S92!NXV\@</1D92!S97(@86)E
M<G1A+B!486QV97H@=&5N:&$@8V]N9FEG=7)A9&\@;R!S974@;F%V96=A9&]R
M('!A<F$@8FQO<75E87(@:F%N96QA<R!D92`B<&]P=7`B/P!!(&]PY^-O("(E
M<R(@;N-O('#T9&4@<V5R(&=U87)D861A+"!P;VES(&]S('-E=7,@9&%D;W,@
M97AC961E;2!A(&1I;65N<^-O(&WA>&EM82!P97)M:71I9&$`3R!P<F]G<F%M
M82!U<V%D;R!P87)A('9E<B!E<W1E('1I<&\@9&4@9&%D;W,@*"5S*2!NXV\@
M9F]I(&5N8V]N=')A9&\@;F\@<VES=&5M82X`3R!T97AT;R!C<G4@9&$@0VAA
M=F4@4/IB;&EC82!01U`@<&]D92!S97(@=FES=&\@)7,N`$\@87)Q=6EV;R!P
M961I9&\@;N-O(&5X:7-T92!N;R!A;F5X;R!-4RU43D5&+@!/(&%R<75I=F\@
M<&5D:61O(&[C;R!E>&ES=&4@;F\@86YE>&\@6FEP+@!!<&5N87,@;W,@;&%D
M;W,@97-Q=65R9&\@92!D:7)E:71O`$%P96YA<R!O(&QA9&\@9&ER96ET;P!/
M(')E;65N=&5N=&4@9&5S=&$@;65N<V%G96T@<&5D92!U;6$@3F]T:69I8V'G
MXV\@9&4@1&ES<&]S:>?C;R!D92!-96YS86=E;2!Q=6%N9&\@;&5R(&5S=&$@
M;65N<V%G96TN(%!O<B!F879O<B!C87)R96=U92!E;2`E<R!P87)A(&5N=FEA
M<B!A(&UE;G-A9V5M(&1E(&YO=&EF:6-AY^-O+@!/('-E<G9I9&]R("(E<R(@
M9F]I(')E;6]V:61O+@!/('-E<G9I9&]R("(E<R(@9F]I(&=U87)D861O+@!/
M('-E<G9I9&]R(&[C;R!P]&1E(&-R:6%R(&$@;6EN:6%T=7)A(&1E<W1A(&EM
M86=E;2X`02!A<W-I;F%T=7)A(&[C;R!P]&1E('-E<B!S=6)S=&ET=>UD82X`
M02!A<W-I;F%T=7)A(&9O:2!S=6)S=&ET=>UD82!C;VT@<W5C97-S;RX`3R!P
M961I9&\@9&4@<W5B<V-R:>?C;R!D92`E<R!F;VD@<F5M;W9I9&\N`$\@87)Q
M=6EV;R!E<W!E8VEF:6-A9&\@;N-O(&5X:7-T92X`02!L:6YH82!I;F1I8V%D
M82!NXV\@97AI<W1E+@!!('1A<F5F82!F;VD@861I8VEO;F%D82#@('-U82!L
M:7-T82!D92!T87)E9F%S+@!/(&%R<75I=F\@=&5M<&]RX7)I;R`B)7,B(&[C
M;R!E>&ES=&4N`$\@=&5X=&\@9&$@;65N<V%G96T`3R!T97AT;R!D82!M96YS
M86=E;2!P;V1E('-E<B!V:7-T;R`E<RX`3R!T97AT;R!D82!M96YS86=E;2!D
M979O;'9I9&$`3R!T97AT;R!D82!M96YS86=E;2!D979O;'9I9&$@<&]D92!S
M97(@=FES=&\@)7,N`$\@=&5X=&\@9&$@;65N<V%G96T@96YV:6%D80!/('1E
M>'1O(&1A(&UE;G-A9V5M(&5N=FEA9&$@<&]D92!S97(@=FES=&\@)7,N`$%P
M96YA<R!O<R!L861O<R!S=7!E<FEO<B!E(&EN9F5R:6]R`$%P96YA<R!O(&QA
M9&\@<W5P97)I;W(`3W,@9&%D;W,@8V%R<F5G861O<R!P97)D97)A;2US92!D
M97-D92!O('!A<W-O(&%N=&5R:6]R+@!/(&%R<75I=F\@8V%R<F5G861O(&[C
M;R!P]&1E('-E<B!G=6%R9&%D;RX`02!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A
M9&\@9&\@=71I;&EZ861O<B!F;VD@87)Q=6EV861A(&-O;2!S=6-E<W-O+@!/
M(&)L;V-O('=E871H97(N8V]M(&[C;R!E<W3A(&1I<W!O;NUV96PN`$[C;R!H
MX2!P87)T97,@86QT97)N871I=F%S('%U92!P;W-S86T@<V5R(&UO<W1R861A
M<R!E;2UL:6YH82X`3N-O(&CA(&UE;G-A9V5N<R!N97-T82!C86EX82!P;W-T
M86PN`$[C;R!HX2!O<.?U97,@9&ES<&]N[79E:7,N`$[C;R!HX2!P87)T97,@
M<75E('!O<W-A;2!S97(@;6]S=')A9&%S(&5M(&QI;FAA+@!(X2!D96UA<VEA
M9&]S(&-A<F%C=&5R97,@;F5S=&4@8V%M<&\N($EN=')O9'5Z:74@)7,@8V%R
M86-T97)E<SL@=&5M(&1E(&EN=')O9'5Z:7(@;65N;W,@9&\@<75E("5S+@!.
MXV\@97AI<W1E(&%I;F1A('5M(&%R<75I=F\@9&4@86IU9&$@<&%R82`E<RX`
M3N-O(&CA('%U86QQ=65R('1E>'1O('%U92!P;W-S82!S97(@;6]S=')A9&\@
M96TM;&EN:&$N`$]C;W)R974@=6T@<')O8FQE;6$@;F$@861IY^-O(&1E("(E
M<R(@86\@<VES=&5M83H@)7,`3V-O<G)E=2!U;2!P<F]B;&5M82!A;R!L:6UP
M87(@;W,@9&%D;W,@9&\@=71I;&EZ861O<B`B)7,B(&1O('-I<W1E;6$N`$]C
M;W)R974@=6T@<')O8FQE;6$@<F5M;W9E;F1O("5S+B!/('-E<G9I9&]R(&1I
M<W-E`$]C;W)R974@=6T@<')O8FQE;6$@<F5M;W9E;F1O(&$@8V%I>&$@<&]S
M=&%L+B!/('-E<G9I9&]R(&1I<W-E.B`E<P!/8V]R<F5U('5M('!R;V)L96UA
M(')E;6]V96YD;R!A(&-A:7AA('!O<W1A;"X@3R!S97)V:61O<B!D:7-S90!/
M8V]R<F5U('5M('!R;V)L96UA(&YA(')E;6_GXV\@9&4@(B5S(B!D;R!S:7-T
M96UA+@!/8V]R<F5U('5M('!R;V)L96UA(&%O(&%C='5A;&EZ87(@(B5S(CH@
M)7,N`$AO=79E('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M96YT;R!D;R!F
M:6-H96ER;SH@)7,@;N-O(&9O:2!C87)R96=A9&\N`$]C;W)R974@=6T@<')O
M8FQE;6$@8V]M(&\@8V%R<F5G86UE;G1O(&1O(&%R<75I=F\Z($\@)7,@97AC
M961E(&\@=&%M86YH;R!MX7AI;6\@<&5R;6ET:61O("@E9"!B>71E<RDN`$]C
M;W)R974@=6T@<')O8FQE;6$@8V]M(&\@8V%R<F5G86UE;G1O(&1O(&%R<75I
M=F\Z($\@)7,@9F]I(&%P96YA<R!P87)C:6%L;65N=&4@8V%R<F5G861O+@!/
M8V]R<F5U('5M(&5R<F\@8V]P:6%N9&\@;65N<V%G96YS(&1E("(E<R(@<&%R
M82`B)7,B+B!/('-E<G9I9&]R(&1I<W-E`$]C;W)R974@=6T@97)R;R!A;R!R
M96UO=F5R(&UE;G-A9V5N<R!D82!P87-T82`B)7,B+B!%:7,@;R!Q=64@;R!S
M97)V:61O<B!D:7-S90!/8V]R<F5U('5M(&5R<F\@86\@<F5M;W9E<B!M96YS
M86=E;G,@9&$@<&%S=&$@(B5S(BX@16ES(&\@<75E(&\@<V5R=FED;W(@9&ES
M<V4`3V-O<G)E=2!U;2!E<G)O(&%O(')E;6]V97(@;65N<V%G96YS+B!%:7,@
M;R!Q=64@;R!S97)V:61O<B!D:7-S93H@)7,`3V-O<G)E=2!U;2!E<G)O(&%O
M(')E;6]V97(@;R!E=F5N=&\Z("5S+@!/8V]R<F5U('5M(&5R<F\@86\@;6]S
M=')A<B!E<W1A('!A<G1E(&1A(&UE;G-A9V5M`$]C;W)R974@=6T@97)R;R!A
M;R!M87)C87(@87,@;65N<V%G96YS(&1A('!A<W1A("(E<R(N($5I<R!O('%U
M92!O('-E<G9I9&]R(&1I<W-E`$]C;W)R974@=6T@97)R;R!A;R!I;7!O<G1A
M<B`E<RX`3V-O<G)E=2!U;2!E<G)O(&%O(&EM<&]R=&%R(&1A9&]S(&1E(&-O
M;G1A8W1O+@!/8V]R<F5U('5M(&5R<F\@86\@:6UP;W)T87(@;R!E=F5N=&\Z
M("5S+@!/8V]R<F5U('5M(&5R<F\@86\@:6UP;W)T87(@9&%D;W,@:4-A;&5N
M9&%R+@!/8V]R<F5U('5M(&5R<F\@86\@:6UP;W)T87(@82!T87)E9F$Z("5S
M+@!/8V]R<F5U('5M(&5R<F\@86\@:6UP;W)T87(@82!I;F9O<FUAY^-O(&QI
M=G)E+V]C=7!A9&\@9&\@=71I;&EZ861O<CH@)7,N`$]C;W)R974@=6T@97)R
M;R!N;R!F;W)M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('1E;FAA
M(&]M:71I9&\@=6T@8V%M<&\@;V)R:6=A=/-R:6\N`$]C;W)R974@=6T@97)R
M;R!A;R!M;W9E<B!A<R!M96YS86=E;G,@9&4@(B5S(B!P87)A("(E<R(N($5I
M<R!O('%U92!O('-E<G9I9&]R(&1I<W-E`$]C;W)R974@=6T@97)R;R!A;R!A
M8G)I<B!O(&%R<75I=F\@)7,N($5X<&5R:6UE;G1E(&5X96-U=&%R('1R86YS
M;&%T:6]N+G!H<"!C;VT@82!O<.?C;R`M9"!P87)A(&-O;G-E9W5I<B!V97(@
M87,@;65N<V%G96YS(&1E(&5R<F\@9&\@86YA;&ES861O<B!834PN`$]C;W)R
M974@=6T@97)R;R!A;R!R96%L:7IA<B!A(&9U;N?C;R!D92!L:79R;R!D92!E
M;F1E<F7G;W,@97-P96-I9FEC861A+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V
M;R!M86ES('1A<F1E+@!/8V]R<F5U('5M(&5R<F\@86\@9W5A<F1A<B!E<W1A
M(&UE;G-A9V5M(&-O;6\@=6T@<F%S8W5N:&\N`$]C;W)R974@=6T@97)R;R!A
M;R!E;G9I87(@82!S=6$@;65N<V%G96TZ("5S`$]C;W)R974@=6T@97)R;R!A
M;R!A8W1U86QI>F%R(&]S('!O<FUE;F]R97,@9&\@8V]N=&%C=&\N(%!O<B!F
M879O<B!T96YT92!D92!N;W9O(&UA:7,@=&%R9&4N`$]C;W)R974@=6T@97)R
M;R!A;R!A8W1U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B!0;W(@
M9F%V;W(@=&5N=&4@9&4@;F]V;R!M86ES('1A<F1E+@!/8V]R<F5U('5M(&5R
M<F\@86\@86-T=6%L:7IA<B!O(&5V96YT;SH@)7,N`$[C;R!H879I82!T97AT
M;R!N97-T82!P87)T92!D82!M96YS86=E;0!%<W1A(&UE;G-A9V5M($A434P@
M=&5M(&EM86=E;G,@96UB96)I9&%S+@!%<W1A(&UE;G-A9V5M($A434P@=&5M
M(&EM86=E;G,@96UB96)I9&%S+B!);6%G96YS(&)L;W%U96%D87,@87!A<F5C
M96T@8V]M(&5S=&4@87-P96-T;SH@`$5S=&4@<V5R=FED;W(@24U!4"!NXV\@
M<W5P;W)T82!P87)T:6QH82!D92!P87-T87,N`$5S=&$@8VAA=F4@</IB;&EC
M82!01U`@9F]I(&%N97AA9&$@X"!M96YS86=E;2X`17-T82!A8^?C;R!NXV\@
MZ2!S=7!O<G1A9&$N`$5S=&$@86/GXV\@86EN9&$@;N-O(&5S=.$@:6UP;&5M
M96YT861A+@!.XV\@<&%R96-E('-E<B!U;2!A<G%U:79O(')A<B!VX6QI9&\N
M`$[C;R!P87)E8V4@<V5R('5M(&%R<75I=F\@>FEP(';A;&ED;RX`3N-O('!A
M<F5C92!S97(@=6UA(&[Z;65R;R!D92!C87)TXV\@=N%L:61O+@!%<W1E(&-O
M;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@871R87;I
M<R!D;R!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI+"!U<V%N
M9&\@82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I
M;R!D92!M96YS86=E;G,@871R87;I<R!D;R!S;7,R;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"YC;VTI+"!U<V%N9&\@82!!4$D@2%144`!%<W1E(&-O;G1R;VQA
M9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@=FEA(%--5%`@871R
M87;I<R!D82!6;V1A9F]N92!)=.%L:6$@92!A<&5N87,@<&%R82!N^FUE<F]S
M(%9O9&%F;VYE+B!%>&EG92!U;6$@8V]N=&$@9&4@8V]R<F5I;R!E;&5C='+S
M;FEC;R!N82!6;V1A9F]N92!)=.%L:6$@*&AT='`Z+R]W=W<N,3DP+FET*2X`
M17-T92!C86UP;R#I(&]B<FEG873S<FEO+@!%<W1E(&-A;7!O('!O9&4@8V]N
M=&5R(&%P96YA<R!I;G1E:7)O<RX`17-T92!C86UP;R!P;V1E(&%P96YA<R!C
M;VYT97(@;OIM97)O<R!E(&\@<^UM8F]L;R!D;VES+7!O;G1O<RX`17-T92!C
M86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O8W1A:7,N`$5S=&4@
M8V%M<&\@=&5M(&1E(&-O;G1E<B!U;6$@;&ES=&$@9&4@:6YT96ER;W,@<V5P
M87)A9&]S('!O<B!E<W!AYV]S(&]U(';M<F=U;&%S+@!%<W1E(&-A;7!O('1E
M;2!D92!S97(@=6T@;OIM97)O(';A;&ED;RX`17-T92!C86UP;R!T96T@9&4@
M8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@;F\@9F]R;6%T;R!21T(@:&5X861E
M8VEM86PL('!O<B!E>&5M<&QO("<C,3(S-&%F)RX`17-T92!M;V1E;&\@:N$@
M9F]I('!R;V-E<W-A9&\N`$ES=&\@Z2`E<RX`17-T92#I('5M(&]B:F5C=&\@
M2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!E<W1E(&]B:F5C=&\@<')E8VES
M82!D92!U;2!C;&EE;G1E(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@<75E(&-O
M;FAEYV$@;R!F;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R82!U;6$@;&ES
M=&$@9&4@8VQI96YT97,@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!N97-S87,@
M8VER8W5N<W3B;F-I87,@=FES:71E("5S`$ES=&\@<&]D92!L979A<B!A;&=U
M;2!T96UP;RX@5&5M(&-E<G1E>F$@<75E(&1E<V5J82!C;VYT:6YU87(_`$5S
M=&$@;65N<V%G96T@8V]N=.EM('5M(&9I8VAE:7)O($UA8VEN=&]S:"X`17-T
M82!M96YS86=E;2!C;VYTZ6T@=6T@86YE>&\@<75E(&9O:2!A<W-I;F%D;R!D
M:6=I=&%L;65N=&4@=FEA(%,O34E-12X`17-T82!M96YS86=E;2!C;VYTZ6T@
M=6T@86YE>&\@<75E(&9O:2!E;F-R:7!T861O(&1I9VET86QM96YT92!V:6$@
M4R]-24U%+@!%<W1A(&UE;G-A9V5M(&-O;G3I;2!I;F9O<FUAY^-O(&1E(&5S
M=&%D;R!D92!E;G1R96=A(&1O(&-O<G)E:6\L(&UA<R!O('-E=2!F;W)M871O
M(.D@9&5S8V]N:&5C:61O+@!%<W1A(&UE;G-A9V5M(&[C;R!P87)E8V4@<V5R
M('5M82!M96YS86=E;2!E;F-R:7!T861A(&-O;2!01U`N($5R<F\Z(`!%<W1A
M(&UE;G-A9V5M(&[C;R!P87)E8V4@97-T87(@9&4@86-O<F1O(&-O;2!O(&9O
M<FUA=&\@4$=0("AS96=U;F1O(&\@4D9#(#(P,34I+@!%<W1A(&UE;G-A9V5M
M(&[C;R!P87)E8V4@97-T87(@9&4@86-O<F1O(&-O;2!O(&9O<FUA=&\@4R]-
M24U%+@!%<W1A(&UE;G-A9V5M(&9O:2!A<W-I;F%D82!D:6=I=&%L;65N=&4@
M=FEA(%!'4"X`17-T82!M96YS86=E;2!F;VD@87-S:6YA9&$@9&EG:71A;&UE
M;G1E('9I82!3+TU)344N`$5S=&$@;65N<V%G96T@9F]I(&5N8W)I<'1A9&$@
M=FEA(%,O34E-12X`17-T82!M96YS86=E;2!F;VD@96YC<FEP=&%D82!C;VT@
M4$=0+@!%<W1A(&UE;G-A9V5M('!A<F$`17-T82!M96YS86=E;2!F;VD@97-C
M<FET82!N=6T@8_-D:6=O("@E<RD@9&EF97)E;G1E(&1O('-E=2X`17-T92!N
M^FUE<F\@<')E8VES82!D92!S97(@<&5L;R!M96YO<R!U;2X`17-T92`B<V-R
M:7!T(B!T96T@<V5R(&5X96-U=&%D;R!A('!A<G1I<B!D92!U;6$@;&EN:&$@
M9&4@8V]M86YD;W,N`$5S=&4@<V5R=FED;W(@;N-O(&-O;G-E9W5E(&1E<V-O
M;7!R:6UI<B!A<G%U:79O<R!Z:7`@;W4@9WII<"X`17-T92!S97)V:61O<B!N
MXV\@<W5P;W)T82!P87)T:6QH82!D92!P87-T87,N`$5S=&4@<VES=&5M82!E
M;F-O;G1R82US92!D97-A8W1I=F%D;RX`17-T82!V86QO<B!T96T@9&4@<V5R
M('5M(&[Z;65R;RX`17-T82!J86YE;&$@=&5M(&1E('-E<B!C:&%M861A(&$@
M<&%R=&ER(&1A(&IA;F5L82!D92!E<V-R:71A(&1E(&UE;G-A9V5M`$5S=&$@
M:F%N96QA('1E;2!D92!S97(@8VAA;6%D82!A('!A<G1I<B!D92!U;6$@:F%N
M96QA(&1E($]PY_5E<P!6:7-U86QI>F'GXV\@9&\@5&AR96%D`%1R;W9O861A
M`$)I;&AE=&5S`$1A=&$O2&]R80!396=U:6UE;G1O(%1E;7!O<F%L`$9O<FUA
M=&\@9&\@=&5M<&\`4V5L96/GXV\@9&%T82]H;W)A`%1I;6]R+4QE<W1E`%3M
M='5L;P!4[71U;&\@*&1I8V$I.@!087)A`%!A<F$@;R!%;F1E<F7G;P!087)A
M('-E;&5C8VEO;F%R(&WZ;'1I<&QO<R!C86UP;W,L('!R97-S:6]N92!#;VYT
M<F]L;R`H4$,I(&]U($-O;6%N9&\@*$UA8RD@<75A;F1O(&-L:6-A<BX`4&%R
M82!S96QE8V-I;VYA<B!M^FQT:7!L;W,@:71E;G,L(&-A<G)E9W5E(&5M($-O
M;G1R;VP@*%!#*2!O=2!#;VUM86YD("A-86,I(&5N<75A;G1O(&-L:6-A<BX`
M2&]J90!4<F]C87(@1F]N=&4@2%1-3`!297#Z8FQI8V$@5&]G;VQE<V$`5&]Q
M=65L874`06UA;FCC`%)E:6YO(&1O(%1O;F=A`%1O<&\`36]L9'5R82!D92!T
M;W!O("A?=&]P*0!486UA;FAO(%1O=&%L(&1O<R!!;F5X;W,Z`%1R861U>FED
M87,`5')A9'7G]65S`%!A<W1A(&1E(&QI>&\`4&%S=&$@9&4@;&EX;SH`5')I
M;F1A9&4@92!4;V)A9V\`5F5R9&%D96ER;R!O=2!F86QS;P`SJ@!297#Z8FQI
M8V$@9&$@5'5N[7-I80!297#Z8FQI8V$@9&$@5'5R<75I80!4=7)C;R`H25-/
M+3@X-3DM.2D`5'5R<75E;65N:7-TXV\`26QH87,@5'5R8V%S(&4@0V%I8V]S
M`%1U=F%L=0!%<V-R979A(&$@<W5A(&5S8V]L:&$Z`,UN9&EC92!5+E8N.B``
M55),`%523"!D;R!S974@<F5L873S<FEO(&1E(&5S=&%D;R!D;R!E;G9I;R!D
M92`B<V-R:7!T<R(`55),.@!297#Z8FQI8V$@9&\@56=A;F1A`%5C<N)N:6$`
M3N-O(&9O:2!P;W-S[79E;"!A8V5D97(@X"!P87-T82!61E,N`$[C;R!F;VD@
M<&]S<^UV96P@861I8VEO;F%R(&EN9F]R;6'GXV\@9&4@=71I;&EZ861O<B!E
M>'1R82!A<75A;F1O(&1A('-U8G-C<FGGXV\N`$[C;R!F;VD@<&]S<^UV96P@
M;75D87(@87,@<&5R;6ES<_5E<R!D;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@
M9F]I('!O<W/M=F5L(&UU9&%R(&%S('!E<FUI<W/U97,@9&\@87)Q=6EV;R!6
M1E,@)7,O)7,N`$[C;R!F;VD@<&]S<^UV96P@;75D87(@<&%R82`E<RX`3N-O
M(&9O:2!P;W-S[79E;"!L:6=A<B!A;R!S97)V:61O<B!344PN`$[C;R!F;VD@
M<&]S<^UV96P@;&EG87(@=7-A;F1O(%-33"X`3N-O(&9O:2!P;W-S[79E;"!C
M;W!I87(@;R!A<G%U:79O(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A
M('!A<W1A(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@<&%S
M=&$@5D93+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&\@87)Q=6EV;R!61E,N
M`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@=6T@87)Q=6EV;R!61E,@=F%Z:6\N
M`$[C;R!F;VD@<&]S<^UV96P@9&5S8V]M<')I;6ER(&]S(&1A9&]S+@!.XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@(B5S(BP@<&]I<R!A('!A<W1A(&[C;R!E
M<W3A('9A>FEA+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@(B5S(CH@)7,N
M`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B`E<RP@<&]I<R!A('!A<W1A(&[C
M;R!E<W3A('9A>FEA`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A
M(%9&4R!R96-U<G-I=F%M96YT92X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R
M(&$@<&%S=&$@5D93+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T
M82!61E,Z("5S+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O
M(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O
M(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(')E8W5R<VEV86UE;G1E
M.B`E<RX`3N-O(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&$@<&%S=&$@8V]R
M<F5N=&4N`$[C;R!F;VD@<&]S<^UV96P@97AT<F%I<B!O<R!P;W)M96YO<F5S
M(&1O(&-E<G1I9FEC861O`$EM<&]S<^UV96P@;&5R(&$@9&5F:6YIY^-O(&1E
M("5S+@!.XV\@9F]I('!O<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!61E,N`$[C
M;R!F;VD@<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@
M9F]I('!O<W/M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,@<&%R82!E<V-R:71A
M+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,N`$[C;R!F
M;VD@<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(&-O;7!R:6UI9&\N`$[C;R!C
M;VYS:6=O(&QE<B!O(&%R<75I=F\Z(`!.XV\@9F]I('!O<W/M=F5L(&QE<B!A
M('!A<W1A('9F<W)O;W0N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@)7,@
M8V]M;R`E<SH@82!P87-T82!D92!D97-T:6YO(&KA(&5X:7-T90!.XV\@9F]I
M('!O<W/M=F5L(')E;F]M96%R(&$@<&%S=&$@5D93+@!.XV\@9F]I('!O<W/M
M=F5L(')E;F]M96%R(&$@<&%S=&$@5D93.B`E<RX`3N-O(&9O:2!P;W-S[79E
M;"!R96YO;65A<B!O(&%R<75I=F\@5D93("(E<R(N`$[C;R!F;VD@<&]S<^UV
M96P@<F5N;VUE87(@;R!A<G%U:79O(%9&4R`E<R\E<RX`3N-O(&9O:2!P;W-S
M[79E;"!R96YO;65A<B!A<G%U:79O(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!O
M8G1E<B!A('%U;W1A`$[C;R!F;VD@<&]S<^UV96P@97AE8W5T87(@)VUK:7-O
M9G,G+@!.XV\@9F]I('!O<W/M=F5L(&-O;G9E<G1E<B!E<W1E(&1O8W5M96YT
M;R!7;W)D`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@87)Q=6EV;R!61E,@
M(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!O(&%R<75I=F\@5D93
M("AC;W!Y*"D@9F%L:&]U*2X`3N-O(&-O;G-I9V\@<F5M;W9E<B`G)7,G.B`E
M<RX`3N-O(')E<W!O;F1I9&$`365N<V%G96YS(&[C;R!R97-P;VYD:61A<P!2
M96-U<&5R87(`4W5B;&EN:&%D;P!$97-T:6YA=.%R:6]S(&[C;R!R979E;&%D
M;W,`1&5S9F%Z97(@06QT97)AY_5E<P!$97-F87H@82!S=6$@^FQT:6UA(&%C
MY^-O`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@;F$@8V]N97CC
M;SH@`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@83H@`%-E;2!C
M871E9V]R:6$`0V]M<&]N96YT92!D92!T:7!O(&[C;R!S=7!O<G1A9&\Z("5S
M`%5N:6-O9&4@*%541BTX*0!%;6ER861O<R#!<F%B97,@56YI9&]S`%)E:6YO
M(%5N:61O`$5S=&%D;W,@56YI9&]S(&1A($%MZ7)I8V$`26QH87,@365N;W)E
M<R!$:7-T86YT97,@9&]S($5S=&%D;W,@56YI9&]S`%5N:61A9&5S`$1E<V-O
M;FAE8VED;P!$871A($1E<V-O;FAE8VED80!2975N:>-O($1E<V-O;FAE8VED
M80!$97-T:6YA=.%R:6\@1&5S8V]N:&5C:61O`&%P:6US9VED("A)1"!D92!-
M96YS86=E;2!D92!!4$DI+@!C;&EM<V=I9"!D97-C;VYH96-I9&\@*$E$(&1E
M($UE;G-A9V5M(&1E($-L:65N=&4I+@!#;VUA;F1O(&1E<V-O;FAE8VED;SH@
M)7,`1F]I(&9O<FYE8VED82!U;6$@;&]C86QI>F'GXV\@9&5S8V]N:&5C:61A
M+@!.;VUE(&1E('5T:6QI>F%D;W(@;W4@<&%L879R82UP87-S92!E<G)A9&]S
M`%)E;6]V97(@;&EG8>?C;R!D;R!E;&5M96YT;R!C;W)R96YT90!$97-C87)R
M96=A<B!F<F%S92UC:&%V90!396T@;F]M90!0;W(@<F%Z]65S(&1E('-E9W5R
M86[G82P@(G-C<FEP=',B('-E;2!P<FEV:6SI9VEO(&[C;R!P;V1E;2!A8V5D
M97(@82!#;W)T87(O0V]P:6%R+T-O;&%R('!R;V=R86UA=&EC86UE;G1E+B!#
M87)R96=U92!E;2!/2R!P87)A('9E<B!U;6$@;F]T82!TZ6-N:6-A(&5M(&UO
M>FEL;&$N;W)G('%U92!L:&4@;6]S=')A<N$@8V]M;R!A=71O<FEZ87(@=6T@
M(G-C<FEP="(@82!A8V5D97(@86]S(')E8V]R=&5S+@!0;W(@;&5R`%)E;6]V
M97(@8V]L;W)AY^-O`$-A;F-E;&%R(%-U8G-C<FGGXV\@9&4@4&%S=&$H<RD`
M17AT96YSXV\@;N-O(%-U<&]R=&%D80!0;W(@=')A9'5Z:7(`36]D:69I8V%R
M`$%C='5A;&EZ87(@)7,`06-T=6%L:7IA<B!);F9O<FUAY^-O('-O8G)E($%N
M97AO<P!!8W1U86QI>F%R(&\@97-T861O(&1O(')E<W!O;F1E;G1E`$%C='5A
M;&EZ87(@=71I;&EZ861O<@`B)7,B(&%C='5A;&EZ861O+@!!8W1U86QI>F%N
M9&\@87)Q=6EV;R!D92!A:G5D82`E<R!P87)A("5S+@`B4V-R:7!T(B!D92!A
M8W1U86QI>F'GXV\@<F5M;W9I9&\N`%5P;&]A9`!#87)R96=A9&]S(&YO('-E
M<G9I9&]R('1O9&]S(&]S(&%R<75I=F]S(&1E(&EN<W1A;&'GXV\@9&4@87!L
M:6-AY_5E<RX`3&5T<F%S(&QA=&EN87,@96T@;6%I^G-C=6QA<P!.^FUE<F]S
M(')O;6%N;W,@96T@;6%I^G-C=6QA<P!297#Z8FQI8V$@3W)I96YT86P@9&\@
M57)U9W5A:0!5=&EL:7IAY^-O.@!5<V%R(&\@0V]R<F5N=&4Z("5S`%5S87(@
M;R!V86QO<B!P861RXV\`57-A<B!S=6)S8W)IY^-O(&1E('!A<W1A<R!)34%0
M/P!5<V%R(%-33"X`57-A<B!S92!O(&YO;64@9&4@=71I;&EZ861O<B!O=2!A
M('!A;&%V<F$M<&%S<V4@9F]R96T@9&EF97)E;G1E<R!N;R!S97)V:61O<B!)
M35-0+@!5=&EL:7IA9&]R`$\@=71I;&EZ861O<B`B)7,B(&%T<FEB=6EU(&-O
M;2!S=6-E<W-O(&]S(&1I<F5I=&]S(&5S<&5C:69I8V%D;W,@<&%R82!A('!A
M<W1A("(E<R(N`%5T:6QI>F%D;W(@)7,@;N-O(&5S=.$@875T;W)I<V%D;R!P
M87)A("5S+@!!9&UI;FES=')AY^-O(&1E(%5T:6QI>F%D;W)E<P!/<.?U97,@
M9&\@571I;&EZ861O<@!296=I<W1O(&1E(%5T:6QI>F%D;W)E<P!/(%)E9VES
M=&\@9&4@571I;&EZ861O<F5S(&5S=.$@:6YA8W1I=F\N`%!E<FUI<W/U97,@
M9&\@=71I;&EZ861O<@!5=&EL:7IA9&]R`$\@3F]M92!D92!5=&EL:7IA9&]R
M("(E<R(@:N$@97AI<W1E+@!5<V5R;F%M93H`3F]M92!D92!5=&EL:7IA9&]R
M.B``571I;&EZ861O<F5S`%5T:6QI>F%D;W)E<R!D;R!S:7-T96UA.@!297#Z
M8FQI8V$@9&\@57IB97%U:7-TXV\`02!P87-T82!61E,@;N-O(&5X:7-T92X`
M075SZFYC:6$`07,@;&]C86QI>F'G]65S(';A;&ED87,@96YC;VYT<F%D87,@
M:6YC;'5E;3H`5F%L:61A9&4N`%9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@
M9&5S=&4@:6YS=&%N=&4N`%9A;&]R(&5X8V5D92!O(&-O;7!R:6UE;G1O(&WA
M>&EM;R!D92`E<RX`5F%L;W)E<P!0;W-S[79E;"!V86QO<F5S(&$@97-C;VQH
M97(`5F%N=6%T=0!687)IX79E;`!696YE>G5E;&$`5F5R:69I8V'GXV\@9F%L
M:&]U("T@97-T82!M96YS86=E;2!P;V1E('1E<B!S:61O(&%D=6QT97)A9&$N
M`%9E<G/C;P!#;VYT<F]L;R!D92!697)S]65S`$%L:6YH86UE;G1O(%9E<G1I
M8V%L`$-A;.=O(%9E<G1I8V%L`%9E<G1I8V%L.@!-=6ET;R!!;'1O`%)E</IB
M;&EC82!3;V-I86QI<W1A(&1O(%9I971N86UE`%9I971N86UI=&$@*%9)4T-)
M22D`5FES=6%L:7IA<@!6:7-U86QI>F%R("5S`%9E<B!A(&-H879E('#Z8FQI
M8V$@)7,`5F5R(&-O;G1E^F1O($A434P@;G5M82!J86YE;&$@<V5P87)A9&$N
M`%9E<B!A(&-H879E('!E<W-O86P@<')I=F%D80!697(@82!C:&%V92!P97-S
M;V%L('#Z8FQI8V$`5F5R($-O;G9E<G-A`%9E<B!-:6YI871U<F$`5F5R('5M
M82!PX6=I;F$@97AT97)N80!6:7-U86QI>F%R(&-O;6\@)7,`5F5R(&%N97AO
M(&YU;6$@:F%N96QA('-E<&%R861A+@!697(@8V]N=&7Z9&\@;G5M82!J86YE
M;&$@<V5P87)A9&$N`%9E<B!E=F5N=&\`5F5R(&UE;G-A9V5N<R!E;2`E<P!#
M86EX82!P;W-T86P@;W4@=FES=&$@82!M;W-T<F%R(&1E<&]I<R!D82!E;G1R
M861A.@!697(@=&%R969A`%9E<B!A<R!);6%G96YS`$EL:&%S(%9I<F=E;G,@
M0G)I=.)N:6-A<P!);&AA<R!6:7)G96YS($%M97)I8V%N87,`02!087-T82!6
M:7)T=6%L("(E<R(@9F]I(&-R:6%D82!C;VT@<W5C97-S;RX`4&%S=&%S(%9I
M<G1U86ES`%!A<W1A<R!6:7)T=6%I<R!P<F5C:7-A;2!D92!U;6$@971I<75E
M=&$N`$5T:7%U971A(&1A('!A<W1A('9I<G1U86P`5FES:6)I;&ED861E`%9I
M<VEB:6QI9&%D93H@`%9O9&%F;VYE($ETX6QI82!V:6$@4TU44`!!5DE3`$%4
M14['PT\A(2$@4D5-3U9!($\@(E-#4DE05"(@34%.54%,345.5$4@1$4@)7,N
M`%=A;&QI<R!E($9U='5N80!!=FES;P!!=FES;SH@`#2J`%!R979I<^-O(&1O
M(%1E;7!O`$1A9&]S(&UE=&5O<F]L\V=I8V]S(&9O<FYE8VED;W,@<&]R`%=E
M871H97(N8V]M`%=E8@!0X6=I;F$`4V5M86YA;&UE;G1E`$)E;2UV:6YD82AO
M*0!"96TM=FEN9&\@86\@)7,`0F5M+79I;F1A*&\I+"`E<P!/8VED96YT86P@
M*$E33RTX.#4Y+3$I`$]C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A87)A`%%U
M92!A<&QI8V'GXV\@9&5V92!O("5S(&UO<W1R87(@87#S<R!A(&5N=')A9&$_
M`%%U86P@Z2!O(&-A<F%C=&5R92!D96QI;6ET861O<C\`475A;"#I(&\@8V%R
M86-T97)E(&1E(&-I=&'GXV\_`%%U86YD;R!R96UO=F5R(&UE;G-A9V5N<RP@
M;6]VZBUL87,@<&%R82!A('!A<W1A(&1E($QI>&\@96T@=F5Z(&1E(&UA<F/A
M+6QA<R!C;VUO(')E;6]V:61A<S\`475A;F1O(&%B<FEN9&\@=6UA(&YO=F$@
M8V%I>&$@<&]S=&%L+"!E;2!Q=64@<.%G:6YA('%U97(@8V]M9>=A<C\`475A
M;F1O(&=U87)D86YD;R!M96YS86=E;G,@96YV:6%D87,L(&=U87)D87(@=&%M
M8NEM(&]S(&1A9&]S(&%N97AO<S\`06\@96YV:6%R(&UE;G-A9V5N<R!O=2!A
M;R!E>'!A;F1I<B!E;F1E<F7G;W,L('%U92!D;VWM;FEO(&1E=F4@<V5R(&%D
M:6-I;VYA9&\@86]S(&5N9&5R9>=O<R!NXV\@<75A;&EF:6-A9&]S("AI+F4N
M+"!E;F1E<F7G;W,@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!S96T@(D`B*3\`
M475E(&9A<V5S`%%U92`B<&QU9VEN<R(@86-T:79A<B!P87)A(&$@161IY^-O
M(%)I8V$N`$QI<W1A($)R86YC80!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D
M97,@0U-3`$QA<F=U<F$@9&\@365N=2`E<R#@(&5S<75E<F1A("AT96T@969E
M:71O(&YA('!R\WAI;6$@96YT<F%D82DZ`$QA<F=U<F$@9&$@=&%B96QA`%5N
M:61A9&4@9&4@;&%R9W5R80!,87)G=7)A.@!7:6MI`%9E;G1O`%9E;G1O($UA
M=&EN86P`5F5L;V-I9&%D92!D;R!V96YT;R!E;2!N\W,`5F5N=&\Z`%9E;G1O
M.B``4V%B961O<FEA`$QI<W1A<R!D92!$97-E:F]S`%1R86)A;&AO`$5N9&5R
M9>=O("A%;7!R96=O*0!496QE9F]N92`H16UP<F5G;RD`475E8G)A<B!A(&QI
M;FAA(&1E<&]I<R!D97-T82!Q=6%N=&ED861E(&1E(&-A<F%C=&5R97,N`$5S
M8W)E=F5N9&\@87)Q=6EV;R!D92!A:G5D82!A8W1U86QI>F%D;R!P87)A("5S
M+@!2969E<NIN8VEA<R!C<G5Z861A<P!297-T<FGG]65S($+A<VEC87,@6#4P
M.78S`%5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U,#EV,P!.;VUE
M($%L=&5R;F%T:79O(&1E(%-U:F5I=&\@6#4P.78S`$ED96YT:69I8V%D;W(@
M0VAA=F4@9&4@4W5J96ET;R!8-3`Y=C,`17AT96YS]65S(%@U,#EV,P!!00!!
M04%!`$UA<&$@66%H;V\A`$%N=6%L;65N=&4`2>EM96X`4VEM`%-I;2P@0V]N
M8V]R9&\`17-TX2!A('1E;G1A<B!D97-C87)R96=A<B!C;W)R96EO(&1A*',I
M('-E9W5I;G1E*',I(&-O;G-T*',I.@!%<W3A(&$@=&5N=&%R(')E;6]V97(@
M=&]D87,@87,@;65N<V%G96YS(&-O;G1I9&%S(&YA*',I('-E9W5I;G1E*',I
M('!A<W1A*',I`$5S=.$@82!T96YT87(@<F5M;W9E<B!A*',I('-E9W5I;G1E
M*',I('!A<W1A*',I+@!%<W3A(&$@8V]P:6%R+VUO=F5R('!A<F$@=6UA(&YO
M=F$@<&%S=&$N`$5S=.$@82!C<FEA<B!U;6$@<W5B+7!A<W1A(&5M(`!%<W3A
M(&$@8W)I87(@=6UA('!A<W1A(&YO(&[M=F5L(&1E('1O<&\N`$5S=.$@96T@
M34]$3R!D92!415A4+B`@57-E(&\@8F]TXV\@6SP^72!P87)A('1R;V-A<B!P
M87)A(&\@;6]D;R!625-504PN`$[C;R!E<W3A(&%U=&5N=&EC861O+@!%<W3A
M(&$@<F5N;VUE87(@82!P87-T83H@`$[C;R!P;V1E('1E<B!O(&-A<F%C=&5R
M92`G7"<@;F\@<V5U(&YO;64@8V]M<&QE=&\N`$[C;R!P;V1E(&-E<W-A<B!A
M('-U8G-C<FGGXV\@9&4@(B5S(BX`3N-O(&1E=2!O('-E=2!A8V]R9&\@86]S
M(%1E<FUO<R!D92!397)V:>=O<RP@<&]R(&ES<V\@;N-O('!O9&4@96YT<F%R
M+@!.XV\@:6YT<F]D=7II=2!U;2!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T
M<O-N:6-O(';A;&ED;RX`3N-O(&UA<&5O=2!N96YH=6T@8V%M<&\@9&\@87)Q
M=6EV;R!I;7!O<G1A9&\@<&%R82!O<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S
M(&5M("5S+@!.XV\@=&5M('!E<FUI<W/C;R!P87)A(&%L=&5R87(@;R!A8V5S
M<V\@82!E<W1A('!A<W1A`%)E96YV:6]U(&5S=&$@;65N<V%G96T@96T@)25S
M('!A<F$@;W,@<V5G=6EN=&5S(&1E<W1I;F%TX7)I;W,Z("5S+@!496T@)7,@
M;65N<V%G96YS(&YO=F%S+@!496T@,2!M96YS86=E;2!N;W9A+@!496T@<&5L
M;R!M96YO<R!U;2!A;F5X;R!S96QE8V-I;VYA9&\@<75E(&%I;F1A(&[C;R!C
M87)R96=O=2X@475E<B!M97-M;R!Q=64@96YV:65M;W,@97-T82!M96YS86=E
M;2!S92!E<W-E<R!A;F5X;W,_`$%C86)O=2!D92!S86ER+@!496T@;F]V87,@
M;65N<V%G96YS(&YA('-E9W5I;G1E('!A<W1A.@!496T@;F]V87,@;65N<V%G
M96YS(&YA<R!S96=U:6YT97,@<&%S=&%S.@!496T@9&4@:6YT<F]D=7II<B!U
M;2!N^FUE<F\@9&4@=&5L96WS=F5L(';A;&ED;RP@<_,@8V]M(&3M9VET;W,L
M(&UA<R!C;VT@=6T@)RLG(&]P8VEO;F%L('!A<F$@;R!P<F5F:7AO(&EN=&5R
M;F%C:6]N86PN`%1E;2!D92!I;G1R;V1U>FER('5M('9A;&]R(';A;&ED;RX`
M5&5M(&1E(&-O;F9I9W5R87(@=6T@;65C86YI<VUO(&+A<VEC;R!P87)A($1A
M=&%4<F5E('-E('%U:7-E<B!U<V%R(%-U8G-C<FGG]65S`%1E;2!D92!C;VYF
M:6=U<F%R('5M(&UE8V%N:7-M;R!B87-E('!A<F$@;R!61E,N`$1E=F4@9&5S
M8W)E=F5R(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@<F5L873S<FEO
M+@!496T@9&4@:6YT<F]D=7II<B!P96QO(&UE;F]S('5M(&1E<W1I;F%TX7)I
M;RX`5&5M(&1E(&EN=')O9'5Z:7(@;R!54DP@9&\@<F5C=7)S;R!Q=64@97-T
M82!L:6=AY^-O('-E(')E9F5R90!496T@9&4@:6YT<F]D=7II<B!A(&9R87-E
M+6-H879E(&1A('-U82!C:&%V92!P<FEV861A(%!'4"!P87)A('9E<B!E<W1A
M(&UE;G-A9V5M`%1E;2!D92!I;G1R;V1U>FER(&$@9G)A<V4M8VAA=F4@9&$@
M<W5A(&-H879E('!R:79A9&$@4R]-24U%('!A<F$@=F5R(&5S=&$@;65N<V%G
M96T`5&5M(&1E('-E;&5C8VEO;F%R('!R:6UE:7)O('5M82!C86EX82!P;W-T
M86PN`%1E;2!D92!S96QE8V-I;VYA<B!U;6$@8V]N=&$@<&%R82!S97(@<F5M
M;W9I9&$N`%1E;2!D92!S96QE8V-I;VYA<B!P<FEM96ER;R!U;2!E;F1E<F7G
M;RX`5&5M(&1E('-E;&5C8VEO;F%R('5M('-E<G9I9&]R(&$@<F5M;W9E<BX`
M5&5M(&1E('-E;&5C8VEO;F%R('!R:6UE:7)O('!E;&\@;65N;W,@=6UA(&UE
M;G-A9V5M+@!496T@9&4@:6YT<F]D=7II<B!U;2!D97-T:6YA=.%R:6\N`$1E
M=F4@97-P96-I9FEC87(@;R!U=&EL:7IA9&]R(&$@;&EM<&%R+@!$979E(&5S
M<&5C:69I8V%R(&\@;F]M92!D;R!U=&EL:7IA9&]R(&$@<F5M;W9E<BX`5&5M
M(&1E(&5S<&5C:69I8V%R('!E;&\@;65N;W,@=6T@87)Q=6EV;R!A(&%N97AA
M<BX`5&5M(&1E(&5S<&5C:69I8V%R(&\@;F]M92!D;R!U=&EL:7IA9&]R(&$@
M861I8VEO;F%R+@!496T@9&4@97-P96-I9FEC87(@;R!U=&EL:7IA9&]R(&$@
M86-T=6%L:7IA<BX`5&5M(&1E(&5S<&5C:69I8V%R(&$@86/GXV\@82!D97-E
M;7!E;FAA<BX`5&5M(&1E(&EN=')O9'5Z:7(@=6T@;F]V;R!N;VUE(&1E(&-A
M=&5G;W)I82X`4')E8VES82!D92!T97(@(B5S(B!A8W1I=F%D;R!N87,@<W5A
M<R!O<.?U97,@9&4@;6%N=71E;N?C;RX`5&5M(&1E(&9O<FYE8V5R('5M(&[Z
M;65R;R!D92!T96QE9F]N92!I=&%L:6%N;P!2961I<F5C8VEO;F]U(&5S=&$@
M;65N<V%G96T@<&%R82`E<R!E;2`E)7,N`%)E<W!O;F1E=2!A(&5S=&$@;65N
M<V%G96T@96T@)7,N`$$@<&%S=&$@(B5S(B!NXV\@97-T879A(&YA('-U82!L
M:7-T82!D92!S=6)S8W)IY_5E<RX@07%U:2!E<W3A(&\@<75E(&\@<V5R=FED
M;W(@9&ES<V4`02!P87-T82`B)7,B(&[C;R!F;VD@<F5T:7)A9&$@9&$@<W5A
M(&QI<W1A(&1E('-U8G-C<FGG]65S+B!!<75I(&5S=.$@;R!Q=64@;R!S97)V
M:61O<B!D:7-S90!!('!A<W1A("(E<R(@9F]I(&EN8VQU[61A(&-O;2!S=6-E
M<W-O(&YA('-U82!L:7-T82!D92!S=6)S8W)IY_5E<P!!('!A<W1A("(E<R(@
M9F]I(&5X8VQU[61A(&-O;2!S=6-E<W-O(&1A('-U82!L:7-T82!D92!S=6)S
M8W)IY_5E<P!!('-U82!S97-SXV\@)7,@97AP:7)O=2X@4&]R(&9A=F]R(&5N
M=')E(&1E(&YO=F\N`$\@<V5U($5N9&5R9>=O(&1E($-O<G)E:6\@16QE8W1R
M\VYI8V\Z`$\@<V5U(&5N9&5R9>=O(")$93HB`$$@<W5A($EN9F]R;6'GXV\`
M3R!S974@96YD97)EYV\@25`@<&%R96-E('1E<B!M=61A9&\@9&5S9&4@;R!I
M;NUC:6\@9&$@<V5S<^-O("5S+B!087)A(&=A<F%N=&ER(&$@<W5A('-E9W5R
M86[G82P@9&5V92!A=71E;G1I8V%R+7-E(&1E(&YO=F\N`$\@4V5U($YO;64`
M07,@4W5A<R!#:&%V97,@4'5B;&EC87,O4')I=F%D87,@4$=0`$$@4W5A($-H
M879E(%!R:79A9&$`02!3=6$@0VAA=F4@4/IB;&EC80!/(%-E=2!%;F1E<F7G
M;R!D92!297-P;W-T82`\:3XH;W!C:6]N86PI/"]I/CH`3W,@4V5U<R!#97)T
M:69I8V%D;W,@4'5B;&EC;W,O4')I=F%D;W,@4R]-24U%`$%S('-U87,@8V]N
M=&%S.@!/<R!S975S(&5N9&5R9>=O<R!E<75I=F%L96YT97,Z(#QI/BAO<&-I
M;VYA;"P@:6YT<F]D=7IA(&-A9&$@96YD97)EYV\@96T@<W5A(&QI;FAA*3PO
M:3X`3R!S974@;65C86YI<VUO(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T
M82!A9&GGXV\@9&4@=71I;&EZ861O<F5S(&]U(&5S=&$@;W#GXV\@9F]I(&1E
M<V%C=&EV861A('!O<B!A;&=U;2!O=71R;R!M;W1I=F\N`$\@<V5U(&UE8V%N
M:7-M;R!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@;&ES=&%G96T@9&4@
M=71I;&EZ861O<F5S(&]U(&5S=&$@;W#GXV\@9F]I(&1E<V%C=&EV861A('!O
M<B!A;&=U;2!O=71R;R!M;W1I=F\N`$\@<V5U(&YA=F5G861O<B!P87)E8V4@
M=&5R(&UU9&%D;R!D97-D92!O(&EN[6-I;R!D82!S97-SXV\@)7,N(%!A<F$@
M9V%R86YT:7(@82!S=6$@<V5G=7)A;N=A+"!D979E(&%U=&5N=&EC87(M<V4@
M9&4@;F]V;RX`3R!S974@;F%V96=A9&]R(&[C;R!S=7!O<G1A(&$@=FES=6%L
M:7IAY^-O(&5M+6QI;FAA(&1E<W1E('1I<&\@9&4@:6UA9V5M+@!/('-E=2!N
M879E9V%D;W(@;N-O('-U<&]R=&$@97-T82!F=6YC:6]N86QI9&%D92X`3R!S
M974@;F%V96=A9&]R(&[C;R!S=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S
M<^-O+B!0<F5S<VEO;F4@0V]N=')O;"]#;VUM86YD("L@4"!P87)A(&EM<')I
M;6ER+@!&=7-O(&AO<N%R:6\@86-T=6%L.@!/('-E=2!C\V1I9V\@9&4@8V%R
M86-T97)E<R!P;W(@96UI<W/C;R!A;R!E;G9I87(@;65N<V%G96YS.@!/('-E
M=2!MZ71O9&\@9&4@96YC<FEP=&'GXV\@<&]R(&]M:7-SXV\@86\@96YV:6%R
M(&UE;G-A9V5N<SH`261E;G1I9&%D92!P861RXV\Z`$YO;64@8V]M<&QE=&\`
M02!S=6$@=F5R<^-O(&1O(&=E='1E>'0@Z2!D96UA<VEA9&\@86YT:6=A+"!N
MXV\@<W5P;W)T86YD;R!02%`@9&4@9F]R;6$@;F%T:79A+B!.96T@=&]D87,@
M87,@8V%D96EA<R!D92!C87)A8W1E<F5S('-E<N-O(&5X=')A[61A<RX`02!S
M=6$@;65N<V%G96T@9F]I(&5N=FEA9&$@8V]M('-U8V5S<V\N`$$@<W5A(&YO
M=F$@<&%L879R82UP87-S92!P87)A("5S(.DZ("5S`$%S('-U87,@;W#G]65S
M(&9O<F%M(&%L=&5R861A<R!A=.D@86\@9FEN86P@9&5S=&$@<V5S<^-O+@!!
M<R!S=6%S(&]PY_5E<R!F;W)A;2!A8W1U86QI>F%D87,N`$$@<W5A('!A;&%V
M<F$M<&%S<V4@9F]I(')E8W)I861A`$$@<W5A('!A;&%V<F$M<&%S<V4@9F]I
M(')E8W)I861A+"!V97)I9FEQ=64@;R!S974@8V]R<F5I;R!E;&5C='+S;FEC
M;R!E(&5N=')E(&-O;2!A('-U82!N;W9A('!A;&%V<F$M<&%S<V4N`$]S('-E
M=7,@<V5R=FED;W)E<R!R96UO=&]S.@!!(%-U82!!<W-I;F%T=7)A.@!*=6=O
M<VSA=FEA`%IA:7)E`%KB;6)I80!::6UB86)UZ0!::7!P>0!;17-C;VYD97(@
M5&5X=&\@0VET861O70!;4V5M($%S<W5N=&]=`%M296QA=/-R:6\@9&4@4')O
M8FQE;6%S72``6TUO<W1R87(@5&5X=&\@0VET861O("T`6TUO<W1R87(@5&5X
M=&\@0VET861O("T@)7,@;&EN:&%S70!;;&EN:&$@)7,@9&4@)7-=`%]!9&UI
M;FES=')AY^-O`%]"8V,`3&ES=&$@3E]E9W)A`%]#;VYS;VQA`%]#8P!%<V-R
M979E7W(`P7)?=F]R90!296UO7W9E<@!?4F5M;W9E<B!,:6YH80!?4&%S=&%S
M`%]'<G5P;W,`05]J=61A`%])9&5N=&ED861E`%!R;W!R:65D861E<R!D82!?
M26UA9V5M`%]%;G1R861A`%]%;G1R87(`7U-A:7(`0_-D:6=O+69O;G1E(&1A
M($UE;G-A9V5M`%]-;V1I9FEC87(@3&EG8>?C;P!?3W#G]65S`%]097)M:7-S
M]65S`%]);7!R:6UI<@!0<FEO<FED861E`%]2969R97-C87(@)7,`7U)E;6]V
M97(@3&EG8>?C;RXN+@!297-P7V]N9&5R`%!R;V-?=7)A<@!?16YV:6%R($UE
M;G-A9V5M`%]#;VYF:6=U<F'GXV\`4')O<')I961A9&5S(&1A(%]486)E;&$`
M7T-O;G9E<G-A`%]087)A`%]296-U<&5R87(`7U5T:6QI>F%D;W)E<P!?5F5R
M($-O;G9E<G-A`$QI<W1A($)?<F%N8V$`8V]N=&%C=&]S`&]C;W)R974@=6T@
M97)R;SH`86YE>&\`86YE>&]S+GII<`!B>71E<P!C86QE;F3A<FEO`&-A;&UO
M`&-L:7%U92!A<75I`&9E:71O`&9A;&AO=0!D:6UI;G5I;F1O`&9I8VAE:7)O
M`&5N8V]N=')A9&\Z(`!D90!D;R`E<R`H)7,I(.!S("5S("5S`')A:F%D87,`
M:#H`:&@`:6UE9&EA=&\`96T@;&EN:&$`8VAA=F4`;&EN:&%S70!F:6-H96ER
M;R!D92!C86EX82!P;W-T86P`17)R;R!M:VES;V9S(&-O;2!C\V1I9V\@)60@
M86\@8V]N<W1R=6ER($E33RX`;6T`3F]M90!N96YH=6T`<V5M(&%L=&5R8>?U
M97,`;N-O(&5N8V]N=')A9&\`;N-O(&EM<&QE;65N=&%D80!A:6YD82!P;W(@
M:6UP;&5M96YT87(`8V%D97)N;R!D92!N;W1A<P!O=0!P97)C96YT86=E;0!P
M[7AE:7,`<W5B:6YD;P!M;W-T<F%R(&1I9F5R96[G87,`<VUS,F5M86EL('9I
M82!(5%10`&5R<F\@9&4@;W)T;V=R869I80!E<G)O<R!D92!O<G1O9W)A9FEA
M`'-S`&5S=.%V96P`;&ES=&$@9&4@=&%R969A<P!/(&9I8VAE:7)O(%!/('!A
M<F$@;R!L;V-A;&4@)7,@;N-O(&5X:7-T92X`:6YT<F]D=7IA(&$@<&%L879R
M82UP87-S92!D=6%S('9E>F5S+"!P87)A(&-O;F9I<FUAY^-O`'5N:69I8V%D
M;P!S96T@;F]M90!A8W1U86QI>F%D;P!S96QE8V-I;VYA9&$@<&5L;R!U=&EL
M:7IA9&]R`'9#87)D`%)E96YC.@!W96%T:&5R+F-O;0!A('-U82!L:7-T82!N
M96=R80!A('-U82!L:7-T82!B<F%N8V$`````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O<'1?4%0O:&5L
M<"YX;6P`````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,C8U,38`
M,3`T,3<S-C(W-C,`,#(Q,38Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(
M;W)D93H@:6UP+VQO8V%L92]P=%]05"]H96QP+GAM;"QV(#$N,38N-BXT(#(P
M,#8O,#$O,S`@,34Z-3<Z-38@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](F-O;7!O<V4M8G5T=&]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@
M/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%C=&EO;G,\+W1I=&QE/@H@
M("`@/&AE861I;F<^06-T:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M4V5N9"!-97-S86=E(&QA=6YC:&5S('EO=7(@96UA:6P@=&\@=&AE(&EN=&5N
M9&5D(')E8VEP:65N="AS*2X@0F4@<W5R92!Y;W4@=V%N="!T;R!S96YD(&)E
M9F]R92!C;&EC:VEN9R!H97)E(&%S(&]N8V4@<V5N="!I="!C86YN;W0@8F4@
M=&%K96X@8F%C:RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V%V92!$
M<F%F="!P;&%C97,@86X@=6YF:6YI<VAE9"!M97-S86=E(&EN(&$@9F]L9&5R
M(&-A;&QE9"`G1')A9G1S)PIA8V-E<W-I8FQE(&)Y('1H92!P;W`M9&]W;B!B
M;W@@;VX@=&AE(')I9VAT('-I9&4@;V8@=&AE(&)L=64@;F%V:6=A=&EO;B!B
M87(@870@=&]P+B!9;W4@8V%N('1H96X@9FEN:7-H('1H92!M97-S86=E(&QA
M=&5R(&)Y('-W:71C:&EN9R!T;R!T:&4@)T1R869T<R<@9F]L9&5R+"!C;&EC
M:VEN9R!O;B!T:&4@<V%V960@;65S<V%G92!T;R!O<&5N(&ET+"!A;F0@=&AE
M;B!C;&EC:VEN9R!O;B`G4F5S=6UE)RX@0F4@<W5R92!T;R!P=70@82!S=6)J
M96-T(&]N('1H92!E;6%I;"!B969O<F4@>6]U('-A=F4@=&AE(&1R869T('-O
M('1H870@>6]U(&-A;B!E87-I;'D@:61E;G1I9GD@=VAI8V@@;65S<V%G92!Y
M;W4@=V%N="!W:71H:6X@=&AE($1R869T<R!F;VQD97(N($%F=&5R('-A=FEN
M9R!A<R!A($1R869T+"!Y;W4@87)E(')E='5R;F5D('1O('EO=7(@24Y"3U@@
M;W(@=VAA=&5V97(@9F]L9&5R('EO=2!W97)E('9I97=I;F<@;&%S="X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@0V%N8V5L($UE<W-A9V4@9')O<',@
M=&AE(&UE<W-A9V4@:6X@<')O9W)E<W,@86YD('-I;7!L>2!R971U<FYS('EO
M=2!T;R!T:&4@24Y"3U@@;W(@=VAA=&5V97(@9F]L9&5R('EO=2!W97)E('9I
M97=I;F<@;&%S="X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\
M96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD($UE<W-A9V4@
M;&%U;F-H97,@>6]U<B!E;6%I;"!T;R!T:&4@:6YT96YD960@<F5C:7!I96YT
M*',I+B!"92!S=7)E('EO=2!W86YT('1O('-E;F0@8F5F;W)E(&-L:6-K:6YG
M(&AE<F4@87,@;VYC92!S96YT(&ET(&-A;FYO="!B92!T86ME;B!B86-K+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3879E($1R869T('!L86-E<R!A
M;B!U;F9I;FES:&5D(&UE<W-A9V4@:6X@82!F;VQD97(@8V%L;&5D("=$<F%F
M=',G"F%C8V5S<VEB;&4@8GD@=&AE('!O<"UD;W=N(&)O>"!O;B!T:&4@<FEG
M:'0@<VED92!O9B!T:&4@8FQU92!N879I9V%T:6]N(&)A<B!A="!T;W`N(%EO
M=2!C86X@=&AE;B!F:6YI<V@@=&AE(&UE<W-A9V4@;&%T97(@8GD@<W=I=&-H
M:6YG('1O('1H92`G1')A9G1S)R!F;VQD97(L(&-L:6-K:6YG(&]N('1H92!S
M879E9"!M97-S86=E('1O(&]P96X@:70L(&%N9"!T:&5N(&-L:6-K:6YG(&]N
M("=297-U;64G+B!"92!S=7)E('1O('!U="!A('-U8FIE8W0@;VX@=&AE(&5M
M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A9G0@<V\@=&AA="!Y;W4@8V%N
M(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S86=E('EO=2!W86YT('=I=&AI
M;B!T:&4@1')A9G1S(&9O;&1E<BX@069T97(@<V%V:6YG(&%S(&$@1')A9G0L
M('EO=2!A<F4@<F5T=7)N960@=&\@>6]U<B!)3D)/6"!O<B!W:&%T979E<B!F
M;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!#86YC96P@365S<V%G92!D<F]P<R!T:&4@;65S<V%G92!I
M;B!P<F]G<F5S<R!A;F0@<VEM<&QY(')E='5R;G,@>6]U('1O('1H92!)3D)/
M6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@
M("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C
M;VUP;W-E+69R;VTB('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S
M86=E($-O;7!O<VET:6]N.B!&<F]M/"]T:71L93X*("`@(#QH96%D:6YG/B)&
M<F]M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@>6]U<B!C;W)R
M96-T(&5M86EL(&%D9')E<W,N(%EO=7(@96UA:6P@861D<F5S<R!I<R!A=71O
M;6%T:6-A;&QY(&5N=&5R960@9F]R('EO=2!F;VQL;W=I;F<@(D9R;VTZ(B!I
M;B!O=71G;VEN9R!E;6%I;"X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N
M=')Y.@H\96YT<GD@:60](F-O;7!O<V4M9G)O;2(^"B`@("`\=&ET;&4^365S
M<V%G92!#;VUP;W-I=&EO;CH@1G)O;3PO=&ET;&4^"B`@("`\:&5A9&EN9SXF
M<75O=#M&<F]M)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E
M<B!Y;W5R(&-O<G)E8W0@96UA:6P@861D<F5S<RX@66]U<B!E;6%I;"!A9&1R
M97-S(&ES(&%U=&]M871I8V%L;'D@96YT97)E9"!F;W(@>6]U(&9O;&QO=VEN
M9R`F<75O=#M&<F]M.B9Q=6]T.R!I;B!O=71G;VEN9R!E;6%I;"X*("`@(#PO
M<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UT;R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ(%1O/"]T:71L93X*("`@(#QH96%D:6YG/B)4;R(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D
M9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@>6]U<B!M97-S86=E+B!9
M;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O
M=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U
M<B!E;G1R>2!F;VQL;W=S(")4;SHB(&EN(&]U=&=O:6YG(&UA:6PN("`*("`@
M(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O
M<V4M=&\B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%1O/"]T
M:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.U1O)G%U;W0[/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S
M*&5S*2!O9B!T:&]S92!T;R!R96-E:79E('EO=7(@;65S<V%G92X@66]U(&UU
M<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@
M<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT
M<GD@9F]L;&]W<R`F<75O=#M4;SHF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@
M(`H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)C;VUP;W-E+6-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S
M<V%G92!#;VUP;W-I=&EO;CH@0V,\+W1I=&QE/@H@("`@/&AE861I;F<^(D-C
M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@
M96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&-A<F)O
M;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@4V5P87)A=&4@96%C:"!A9&1R97-S
M('=I=&@@82!C;VUM82X@66]U<B!E;G1R>2!F;VQL;W=S(")#8SHB(&EN(&]U
M=&=O:6YG(&UA:6PN($-A<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T
M;R!P96]P;&4@;W1H97(@=&AA;B!T:&4@;VYE*',I(&)E:6YG('=R:71T96X@
M=&\@9&ER96-T;'D@8G5T(&%R92!I;7!O<G1A;G0@<F5C:7!I96YT<R!O9B!T
M:&4@96UA:6P@87,@=V5L;"P@=7-U86QL>2!S;VUE;VYE(&EN9&ER96-T;'D@
M8V]N8V5R;F5D(&%B;W5T('1H92!S=6)J96-T(&]F('1H92!E;6%I;"X@($%L
M;"`G5&\Z)R!R96-I<&EE;G1S(&%N9"`G0V,Z)R!R96-I<&EE;G1S(&-A;B!S
M964@=&AE(&5N=&ER92!L:7-T(&]F(&)O=&@@:VEN9',@;V8@<F5C:7!I96YT
M<RX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60]
M(F-O;7!O<V4M8V,B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ
M($-C/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T-C)G%U;W0[/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A
M9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@8V%R8F]N(&-O<'D@
M;V8@>6]U<B!M97-S86=E+B!397!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A
M(&-O;6UA+B!9;W5R(&5N=')Y(&9O;&QO=W,@)G%U;W0[0V,Z)G%U;W0[(&EN
M(&]U=&=O:6YG(&UA:6PN($-A<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N
M="!T;R!P96]P;&4@;W1H97(@=&AA;B!T:&4@;VYE*',I(&)E:6YG('=R:71T
M96X@=&\@9&ER96-T;'D@8G5T(&%R92!I;7!O<G1A;G0@<F5C:7!I96YT<R!O
M9B!T:&4@96UA:6P@87,@=V5L;"P@=7-U86QL>2!S;VUE;VYE(&EN9&ER96-T
M;'D@8V]N8V5R;F5D(&%B;W5T('1H92!S=6)J96-T(&]F('1H92!E;6%I;"X@
M($%L;"`G5&\Z)R!R96-I<&EE;G1S(&%N9"`G0V,Z)R!R96-I<&EE;G1S(&-A
M;B!S964@=&AE(&5N=&ER92!L:7-T(&]F(&)O=&@@:VEN9',@;V8@<F5C:7!I
M96YT<RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UB8V,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@/&AE861I
M;F<^(D)C8R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C
M;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@
M82!B;&EN9"!C87)B;VX@8V]P>2!O9B!Y;W5R(&UE<W-A9V4N(%EO=2!M=7-T
M('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R('!U
M;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N=')Y
M(&9O;&QO=W,@(D)C8SHB(&EN(&]U=&=O:6YG(&UA:6PN($)L:6YD(&-A<F)O
M;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA
M;B!D:7)E8W0@86YD(&EN9&ER96-T(')E8VEP:65N=',@*")4;SHB(&%N9"`B
M0V,Z(B!R96-I<&EE;G1S*2!W:&\@;F5E9"!T;R!R96%D('=H870@:7,@8F5I
M;F<@=W)I='1E;B!A<R!W96QL(%=)5$A/550@=&AE(&]T:&5R(')E8VEP:65N
M=',@:VYO=VEN9R!T:&%T('1H97D@87)E(')E8V5I=FEN9R!T:&4@96UA:6PN
M(%1H=7,@)V)L:6YD)R!M96%N<R!T:&%T('1H92!I9&5N=&ET>2!O9B!T:&5S
M92!R96-I<&EE;G1S(&ES(&AI9&1E;B!F<F]M(&%L;"!O=&AE<B!R96-I<&EE
M;G1S(&]F('1H92!E;6%I;"P@86YD(&]N;'D@>6]U(&%N9"!T:&5Y(&MN;W<@
M=&AE>2!G;W0@82!C;W!Y+B!9;W4@='EP:6-A;&QY('5S92!T:&ES('1O('1E
M;&P@86X@875T:&]R:71Y(&9I9W5R92!T:&%T('EO=2!A<F4@=&5L;&EN9R!S
M;VUE;VYE('-O;65T:&EN9R!W:71H;W5T(&%L87)M:6YG('1H92!P97)S;VX@
M>6]U(&%R92!S96YD:6YG('1H92!A8W1U86P@96UA:6P@=&\N"B`@("`\+W!A
M<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6)C
M8R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@0F-C/"]T:71L
M93X*("`@(#QH96%D:6YG/B9Q=6]T.T)C8R9Q=6]T.SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE
M<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&)L:6YD(&-A<F)O;B!C;W!Y(&]F
M('EO=7(@;65S<V%G92X@66]U(&UU<W0@<V5P87)A=&4@96%C:"!A9&1R97-S
M('=I=&@@82!C;VUM83L@;W1H97(@<'5N8W1U871I;VX@=VEL;"!R97-U;'0@
M:6X@86X@97)R;W(N(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O=#M"8V,Z)G%U
M;W0[(&EN(&]U=&=O:6YG(&UA:6PN($)L:6YD(&-A<F)O;B!C;W!I97,@87)E
M('5S=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!D:7)E8W0@86YD
M(&EN9&ER96-T(')E8VEP:65N=',@*"9Q=6]T.U1O.B9Q=6]T.R!A;F0@)G%U
M;W0[0V,Z)G%U;W0[(')E8VEP:65N=',I('=H;R!N965D('1O(')E860@=VAA
M="!I<R!B96EN9R!W<FET=&5N(&%S('=E;&P@5TE42$]55"!T:&4@;W1H97(@
M<F5C:7!I96YT<R!K;F]W:6YG('1H870@=&AE>2!A<F4@<F5C96EV:6YG('1H
M92!E;6%I;"X@5&AU<R`G8FQI;F0G(&UE86YS('1H870@=&AE(&ED96YT:71Y
M(&]F('1H97-E(')E8VEP:65N=',@:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R
M(')E8VEP:65N=',@;V8@=&AE(&5M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H
M97D@:VYO=R!T:&5Y(&=O="!A(&-O<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H
M:7,@=&\@=&5L;"!A;B!A=71H;W)I='D@9FEG=7)E('1H870@>6]U(&%R92!T
M96QL:6YG('-O;65O;F4@<V]M971H:6YG('=I=&AO=70@86QA<FUI;F<@=&AE
M('!E<G-O;B!Y;W4@87)E('-E;F1I;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*
M("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M8V]M<&]S92US=6)J96-T(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
M365S<V%G92!#;VUP;W-I=&EO;CH@4W5B:F5C=#PO=&ET;&4^"B`@("`\:&5A
M9&EN9SXB4W5B:F5C="(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R
M('1H92!S=6)J96-T(&]F('EO=7(@;65S<V%G92X@66]U<B!E;G1R>2!F;VQL
M;W=S(")3=6)J96-T.B(@:6X@;W5T9V]I;F<@;6%I;"X@2V5E<"!I="!S:&]R
M="P@<VEM<&QE(&%N9"!D97-C<FEP=&EV92X@(%1H92!S=6)J96-T(&QI;F4@
M:7,@=&AE(&5A<VEE<W0@=V%Y(&9O<B!Y;W4@86YD('EO=7(@8V]R<F5S<&]N
M9&5N=',@=&\@<F5M96UB97(@=VAA="!W87,@:6X@=&AE(&5M86EL(&%N9"!T
M:'5S(&ES('9E<GD@:6UP;W)T86YT(&EN(&]R9V%N:7II;F<@>6]U<B!E;6%I
M;"!A;F0@9FEN9&EN9R!I;7!O<G1A;G0@;VYE<R!L871E<BX@($%L<V\L('=H
M96X@>6]U("=297!L>2<@;W(@)T9O<G=A<F0G(&%N9"!E;6%I;"!T:&ES('-U
M8FIE8W0@;&EN92!I<R!C;W!I960@;W9E<B!I;G1O('1H92!N97<@;65S<V%G
M92!A;F0@<V\@:7,@82!V86QU86)L92!W87D@;V8@=&5L;&EN9R!W:&%T(&UE
M<W-A9V5S(&=O('1O9V5T:&5R('1O(&9O<FT@82`B=&AR96%D(B!O9B!A(&-O
M;G9E<G-A=&EO;BX@($AO=V5V97(L(&EF('1H92`G4F5P;'DG(&]R("=&;W)W
M87)D)R!C;VYT86EN<R!N97<@:61E87,L('EO=2!M87D@=V%N="!T;R!A9&0@
M<VEM<&QE(&UO9&EF:6-A=&EO;G,@=&\@=&AE("=3=6)J96-T)R!L:6YE('-O
M('1H92!R96-I<&EE;G0H<RD@8V%N(&9O;&QO=R!T:&4@<')O9W)E<W-I;VX@
M;V8@=&AE(")T:')E860N(@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT
M<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T(CX*("`@(#QT:71L93Y-
M97-S86=E($-O;7!O<VET:6]N.B!3=6)J96-T/"]T:71L93X*("`@(#QH96%D
M:6YG/B9Q=6]T.U-U8FIE8W0F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($5N=&5R('1H92!S=6)J96-T(&]F('EO=7(@;65S<V%G92X@66]U<B!E
M;G1R>2!F;VQL;W=S("9Q=6]T.U-U8FIE8W0Z)G%U;W0[(&EN(&]U=&=O:6YG
M(&UA:6PN($ME97`@:70@<VAO<G0L('-I;7!L92!A;F0@9&5S8W)I<'1I=F4N
M("!4:&4@<W5B:F5C="!L:6YE(&ES('1H92!E87-I97-T('=A>2!F;W(@>6]U
M(&%N9"!Y;W5R(&-O<G)E<W!O;F1E;G1S('1O(')E;65M8F5R('=H870@=V%S
M(&EN('1H92!E;6%I;"!A;F0@=&AU<R!I<R!V97)Y(&EM<&]R=&%N="!I;B!O
M<F=A;FEZ:6YG('EO=7(@96UA:6P@86YD(&9I;F1I;F<@:6UP;W)T86YT(&]N
M97,@;&%T97(N("!!;'-O+"!W:&5N('EO=2`G4F5P;'DG(&]R("=&;W)W87)D
M)R!A;F0@96UA:6P@=&AI<R!S=6)J96-T(&QI;F4@:7,@8V]P:65D(&]V97(@
M:6YT;R!T:&4@;F5W(&UE<W-A9V4@86YD('-O(&ES(&$@=F%L=6%B;&4@=V%Y
M(&]F('1E;&QI;F<@=VAA="!M97-S86=E<R!G;R!T;V=E=&AE<B!T;R!F;W)M
M(&$@)G%U;W0[=&AR96%D)G%U;W0[(&]F(&$@8V]N=F5R<V%T:6]N+B`@2&]W
M979E<BP@:68@=&AE("=297!L>2<@;W(@)T9O<G=A<F0G(&-O;G1A:6YS(&YE
M=R!I9&5A<RP@>6]U(&UA>2!W86YT('1O(&%D9"!S:6UP;&4@;6]D:69I8V%T
M:6]N<R!T;R!T:&4@)U-U8FIE8W0G(&QI;F4@<V\@=&AE(')E8VEP:65N="AS
M*2!C86X@9F]L;&]W('1H92!P<F]G<F5S<VEO;B!O9B!T:&4@)G%U;W0[=&AR
M96%D+B9Q=6]T.PH@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B('-T871E/2)U;FMN;W=N(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!/<'1I;VYS/"]T:71L
M93X*("`@(#QH96%D:6YG/B)/<'1I;VYS(CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AE<V4@3W!T:6]N<R!H96QP('EO=2!P<F5P87)E('EO=7(@;65S
M<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI8VL@(E-P96QL
M($-H96-K(B!T;R!C:&5C:R!Y;W5R('-P96QL:6YG+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!#;&EC:R`B071T86-H;65N=',B('1O('9I97<@870@
M=&AE(&)O='1O;2!O9B!T:&4@<&%G92!A(&QI<W0@;V8@9FEL97,@871T86-H
M960@=&\@=&AI<R!M97-S86=E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@(E-A=F4@8V]P
M>2(@=&\@<V%V92!A(&-O<'D@;V8@=&AI<R!M97-S86=E(&EN('EO=7(@(E-E
M;G0@36%I;"(@9F]L9&5R+B!3879E(&-O<&EE<R!O9B!I;7!O<G1A;G0@96UA
M:6QS('EO=2!S96YD('-O('1H870@>6]U(&AA=F4@<V]M971H:6YG('1O(')E
M9F5R(&)A8VL@=&\@;&%T97(@86YD('1O(&ME97`@86X@86-C=7)A=&4@<F5C
M;W)D(&]F('=H870@=V%S('-A:60N(%=E(&1O(&YO="!R96-O;6UE;F0@>6]U
M('-A=F4@979E<GD@96UA:6P@<VEN8V4@=&AE;B!Y;W5R(&1I<VL@<W1O<F%G
M92!Q=6]T82!W:6QL(&)E('5S960@=7`@<75I8VML>2`H97-P96-I86QL>2!W
M:&5N('EO=2!S96YD(&%T=&%C:&UE;G1S*2!A;F0@>6]U<B!M86EL8F]X('=I
M;&P@8F4@9G5L;"!A;F0@=6YA8FQE('1O(')E8V5I=F4@;F5W(&EN8V]M:6YG
M(&5M86EL+B!9;W4@8V%N+"!H;W=E=F5R+"!T=7)N('1H:7,@9F5A='5R92`G
M;VXG(&%S('EO=7(@9&5F875L="!W:71H:6X@>6]U<B!)9&5N=&ET>2P@8GD@
M9V]I;F<@=&\@3W!T:6]N<RTF9W0[4&5R<V]N86P@26YF;W)M871I;VXM)F=T
M.T5D:70@>6]U<B!I9&5N=&ET:65S+B!"92!C87)E9G5L('=H96X@=7-I;F<@
M=&AI<R!M;V1I9FEE9"!D969A=6QT(&%S('EO=2!W:6QL(&YE960@=&\@<&5R
M:6]D:6-A;&QY('!U<F=E('EO=7(@(E-E;G0@36%I;"(@9F]L9&5R(&]R(&ET
M('=I;&P@979E;G1U86QL>2!M86ME('EO=7(@;6%I;&)O>"!F=6QL(&%N9"!U
M;G5S96%B;&4N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N
M=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U
M;W0[3W!T:6]N<R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE
M<V4@3W!T:6]N<R!H96QP('EO=2!P<F5P87)E('EO=7(@;65S<V%G92X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@0VQI8VL@)G%U;W0[4W!E;&P@0VAE
M8VLF<75O=#L@=&\@8VAE8VL@>6]U<B!S<&5L;&EN9RX*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@0VQI8VL@)G%U;W0[071T86-H;65N=',F<75O=#L@
M=&\@=FEE=R!A="!T:&4@8F]T=&]M(&]F('1H92!P86=E(&$@;&ES="!O9B!F
M:6QE<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T
M;R`F<75O=#M3879E(&-O<'DF<75O=#L@=&\@<V%V92!A(&-O<'D@;V8@=&AI
M<R!M97-S86=E(&EN('EO=7(@)G%U;W0[4V5N="!-86EL)G%U;W0[(&9O;&1E
M<BX@4V%V92!C;W!I97,@;V8@:6UP;W)T86YT(&5M86EL<R!Y;W4@<V5N9"!S
M;R!T:&%T('EO=2!H879E('-O;65T:&EN9R!T;R!R969E<B!B86-K('1O(&QA
M=&5R(&%N9"!T;R!K965P(&%N(&%C8W5R871E(')E8V]R9"!O9B!W:&%T('=A
M<R!S86ED+B!792!D;R!N;W0@<F5C;VUM96YD('EO=2!S879E(&5V97)Y(&5M
M86EL('-I;F-E('1H96X@>6]U<B!D:7-K('-T;W)A9V4@<75O=&$@=VEL;"!B
M92!U<V5D('5P('%U:6-K;'D@*&5S<&5C:6%L;'D@=VAE;B!Y;W4@<V5N9"!A
M='1A8VAM96YT<RD@86YD('EO=7(@;6%I;&)O>"!W:6QL(&)E(&9U;&P@86YD
M('5N86)L92!T;R!R96-E:79E(&YE=R!I;F-O;6EN9R!E;6%I;"X@66]U(&-A
M;BP@:&]W979E<BP@='5R;B!T:&ES(&9E871U<F4@)V]N)R!A<R!Y;W5R(&1E
M9F%U;'0@=VET:&EN('EO=7(@261E;G1I='DL(&)Y(&=O:6YG('1O($]P=&EO
M;G,M)F=T.U!E<G-O;F%L($EN9F]R;6%T:6]N+29G=#M%9&ET('EO=7(@:61E
M;G1I=&EE<RX@0F4@8V%R969U;"!W:&5N('5S:6YG('1H:7,@;6]D:69I960@
M9&5F875L="!A<R!Y;W4@=VEL;"!N965D('1O('!E<FEO9&EC86QL>2!P=7)G
M92!Y;W5R("9Q=6]T.U-E;G0@36%I;"9Q=6]T.R!F;VQD97(@;W(@:70@=VEL
M;"!E=F5N='5A;&QY(&UA:V4@>6]U<B!M86EL8F]X(&9U;&P@86YD('5N=7-E
M86)L92X*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UA='1A8V@B('-T871E/2)U;FMN;W=N(CX*("`@(#QT
M:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8V@\+W1I=&QE/@H@("`@
M/&AE861I;F<^(D%T=&%C:"(\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@
M("!9;W4@;6%Y(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5I=&AE<BP@='EP92!T:&4@<&%T
M:"!A;F0@;F%M92!O9B!A(&9I;&4@=&AA="!Y;W4@=V%N="!A='1A8VAE9"!T
M;R!T:&ES(&UE<W-A9V4@;W(@8VQI8VL@(D)R;W=S92(@8G5T=&]N(&%N9"!S
M96QE8W0@=&AE(&9I;&4@=&\@8F4@871T871C:&5D+B!4:&4@<&%T:"!A;F0@
M;F%M92!O9B!T:&%T(&9I;&4@;F]W(&%P<&5A<G,@:6X@=&AE($%T=&%C:&UE
M;G0@8F]X+B!.;W<@<')O8V5E9"!T;PI3=&5P(#(N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#(Z($-L:6-K(")!='1A8V@B(&)U='1O;BX@5&AE(&9I
M;&4@;F%M92!A;F0@<VEZ92!W:6QL(&)E(&%D9&5D('1O('EO=7(@;&ES="!O
M9B!!='1A8VAM96YT<RX@4&QE87-E(&YO=&4@=&AA="!F;W(@;&%R9V4@9FEL
M97,@86YD+V]R('-L;W=E<B!);G1E<FYE="!C;VYN96-T:6]N<RP@=&AE('!R
M;V-E<W,@;V8@=7!L;V%D:6YG(&%N9"!A='1A8VAI;F<@>6]U<B!F:6QE('1O
M('1H92!E;6%I;"!M87D@=&%K92!A('=H:6QE+B!0;&5A<V4@8F4@<&%T:65N
M="!A;F0@9&\@;F]T(&-L:6-K(&]N(&]T:&5R('1H:6YG<R!W:&EL92!Y;W4@
M87)E('=A:71I;F<N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*
M/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:"(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@071T86-H/"]T:71L93X*("`@(#QH96%D:6YG/B9Q
M=6]T.T%T=&%C:"9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U
M(&UA>2!A='1A8V@@9FEL97,@=&\@>6]U<B!M97-S86=E.R!O;FQY(&]N92!F
M:6QE(&UA>2!B92!A='1A8VAE9"!A="!A('1I;64N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#$Z($5I=&AE<BP@='EP92!T:&4@<&%T:"!A;F0@;F%M
M92!O9B!A(&9I;&4@=&AA="!Y;W4@=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE
M<W-A9V4@;W(@8VQI8VL@)G%U;W0[0G)O=W-E)G%U;W0[(&)U='1O;B!A;F0@
M<V5L96-T('1H92!F:6QE('1O(&)E(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD
M(&YA;64@;V8@=&AA="!F:6QE(&YO=R!A<'!E87)S(&EN('1H92!!='1A8VAM
M96YT(&)O>"X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,CH@1&5C:61E
M('=H971H97(@>6]U('=A;G0@=&AE(&9I;&4@=&\@8F4@=FEE=V5D(&%S(&%N
M(&%T=&%C:&UE;G0@;W(@:6YL:6YE9"!W:71H('1H92!R97-T(&]F('1H92!M
M97-S86=E+B!4:&4@<F5C96EV:6YG('!E<G-O;BAS*2!M86EL(')E861I;F<@
M<V]F='=A<F4@;75S="!B92!A8FQE('1O(&AA;F1L92!T:&4@9FEL92!T>7!E
M(&EN;&EN93L@:68@;F]T+"!T:&ES('!A<G0@=VEL;"!B92!V:65W960@87,@
M86X@871T86-H;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M4W1E<"`S.B!#;&EC:R`F<75O=#M!='1A8V@F<75O=#L@8G5T=&]N+B!4:&4@
M9FEL92!N86UE(&%N9"!S:7IE('=I;&P@8F4@861D960@=&\@>6]U<B!L:7-T
M(&]F($%T=&%C:&UE;G1S+B!0;&5A<V4@;F]T92!T:&%T(&9O<B!L87)G92!F
M:6QE<R!A;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O;FYE8W1I;VYS+"!T:&4@
M<')O8V5S<R!O9B!U<&QO861I;F<@86YD(&%T=&%C:&EN9R!Y;W5R(&9I;&4@
M=&\@=&AE(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N(%!L96%S92!B92!P871I
M96YT(&%N9"!D;R!N;W0@8VQI8VL@;W1H97(@=&AI;F=S('=H:6QE('EO=2!A
M<F4@=V%I=&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:&UE
M;G1S/"]T:71L93X*("`@(#QH96%D:6YG/B)!='1A8VAM96YT<R(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H:7,@<V5C=&EO;B!D:7-P;&%Y<R!A(&QI
M<W0@;V8@9FEL97,@86QR96%D>2!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V4N
M(%1O($1E;&5T92!A;B!A='1A8VAE9"!F:6QE.@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^4W1E<"`Q.B!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@
M=&\@=&AE(&%T=&%C:&5D(&9I;&5N86UE('EO=2!W86YT('1O($1E;&5T92X*
M("`@(#PO<&%R83X@"B`@("`\<&%R83Y3=&5P(#(Z($-L:6-K(")$96QE=&4@
M071T86-H;65N="AS*2(N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R
M>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8VAM96YT<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SXF<75O=#M!='1A8VAM96YT<R9Q=6]T.SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AI<R!S96-T:6]N(&1I<W!L87ES(&$@;&ES="!O
M9B!F:6QE<R!A;')E861Y(&%T=&%C:&5D('1O('EO=7(@;65S<V%G92X@5&\@
M1&5L971E(&%N(&%T=&%C:&5D(&9I;&4Z"B`@("`\+W!A<F$^"B`@("`\<&%R
M83Y3=&5P(#$Z($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R!T
M:&4@871T86-H960@9FEL96YA;64@>6]U('=A;G0@=&\@1&5L971E+@H@("`@
M/"]P87)A/B`*("`@(#QP87)A/E-T97`@,CH@0VQI8VL@)G%U;W0[1&5L971E
M($%T=&%C:&UE;G0H<RDF<75O=#LN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^
M/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<')I;W)I='DB('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%!R:6]R
M:71Y/"]T:71L93X*("`@(#QH96%D:6YG/B)0<FEO<FET>2(\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1H:7,@<V5T<R!T:&4@(E@M4')I;W)I='DB(&AE
M861E<B!O;B!Y;W5R(&]U=&=O:6YG(&UE<W-A9V4N(%1H92`B6"U0<FEO<FET
M>2(@=&%G(&ES(&$@<V]R="!O9B`B<'-E=61O('-T86YD87)D(B!T:&%T($YE
M='-C87!E+"!-;WII;&QA+"!/<&5R82P@86YD($]U=&QO;VL@;6%I;"!C;&EE
M;G1S(&%P<&5A<B!T;R!A9W)E92!O;BX@06YY(&UA:6P@8VQI96YT<R!T:&%T
M(&1O(&YO="!H86YD;&4@=&AI<R!H96%D97(@=VEL;"!S:6UP;'D@:6=N;W)E
M(&ET+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92US879E+6%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-
M97-S86=E($-O;7!O<VET:6]N.B!3879E($%T=&%C:&UE;G1S/"]T:71L93X*
M("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM
M96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N(&%R92!S879E9"!W:71H('1H92!M
M97-S86=E('=H96X@<W1O<F5D(&EN('1H92!S96YT+6UA:6P@9F]L9&5R+B`@
M268@(EEE<R(L('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S879E9"X@
M($EF(").;R(L('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S=')I<'!E
M9"!F<F]M('1H92!M97-S86=E(&%F=&5R(&ET(&ES('-E;G0@=&\@86QL(')E
M8VEP:65N=',N("!#:&]O<VEN9R`B3F\B('=I;&P@:&5L<"!C;VYS97)V92!D
M:7-K('-P86-E(&)Y(')E;6]V:6YG("AP;W1E;G1I86QL>2!L87)G92D@871T
M86-H;65N="!I;F9O<FUA=&EO;B!F<F]M('1H92!S879E9"!M97-S86=E<RX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;&EN
M:RUA='1A8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@3&EN:R!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\
M<&%R83X*("`@($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@
M:6X@>6]U<B!C;VUP;W-I=&EO;B!A<F4@<V5N="!A<R!A('!A<G0@;V8@=&AE
M(&UA:6P@;65S<V%G92!O<B!W:&5T:&5R('1H;W-E(&%T=&%C:&UE;G1S(&%R
M92!K97!T(&]N(&$@;&]C86P@<V5R=F5R+B`@268@871T86-H;65N=',@87)E
M(&QI;FME9"P@=&AE(')E8VEP:65N="AS*2!O9B!Y;W5R(&UE<W-A9V4@=VEL
M;"!B92!P<F]V:61E9"!A('=E8FQI;FL@=VAE<F4@=&AE>2!C86X@9&]W;FQO
M860@=&AE(&%T=&%C:&UE;G0H<RDN("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA
M<R!T:&4@861V86YT86=E(&]F('1R96UE;F1O=7-L>2!R961U8VEN9R!T:&4@
M<VEZ92!O9B!O=71G;VEN9R!M97-S86=E<RX@($QI;FMI;F<@871T86-H;65N
M=',@:&%S('1H92!D:7-A9'9A;G1A9V4@=&AA="!T:&4@8V]N=&5N="!O9B!T
M:&4@871T86-H;65N=',@8V%N(&YO="!B92!G=6%R86YT965D('1O(&)E(&%V
M86EL86)L92!I;B!T:&4@9G5T=7)E('-I;F-E('1H92!A='1A8VAM96YT(&1A
M=&$@:7,@;F]T(&QO8V%T960@=VET:&EN('1H92!E+6UA:6P@;65S<V%G92X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-E87)C:"(@<W1A
M=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@4V5A<F-H/"]T:71L
M93X*("`@(#QH96%D:6YG/E-E87)C:"!#<FET97)I83PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@("`@($AE;'`@=&5X="!T;R!B92!W<FET=&5N+@H@("`@
M/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<V5A<F-H
M(CX*("`@(#QT:71L93Y-97-S86=E(%-E87)C:#PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY396%R8V@@0W)I=&5R:6$\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%EO=2!M87D@<V5A<F-H(&9O<B!M97-S86=E<R!F<F]M('EO=7(@9F]L9&5R
M<R!U<VEN9R!D:69F97)E;G0@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^4W1E<"`Q.B!%;G1E<B!T97AT('1O('1H92!F:65L9',@
M>6]U('=A;G0@=&\@861D('1O('EO=7(@<V5A<F-H(&-R:71E<FEA+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^4W1E<"`R.B!#:&]O<V4@=&AE(&UE<W-A9V4@
M9FQA9RAS*2!T;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83Y3=&5P(#,Z($-H;V]S92!T:&4@9F]L9&5R*',I
M(&9R;VT@=VAI8V@@=&\@<V5A<F-H(&9O<B!T:&4@;65S<V%G97,N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83Y3=&5P(#0Z($-L:6-K("9Q=6]T.U-E87)C:"9Q
M=6]T.RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@268@86YY(&UE<W-A
M9V5S(&UA=&-H960@>6]U<B!S96%R8V@@8W)I=&5R:6$L('1H96X@=&AE('-U
M8FIE8W1S(&]F('1H97-E(&UE<W-A9V5S('=I;&P@8F4@<VAO=VX@:6X@=&AE
M("9Q=6]T.U-E87)C:"!297-U;'1S)G%U;W0[('9I97<N"B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUO<'1I
M;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^1F]L9&5R($UA;F%G
M96UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($]P=&EO;G,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@82!F;VQD
M97(@8GD@=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE(&QE9G0@
M8V]L=6UN+B`@3VYC92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C="!T:&4@
M;W!T:6]N('EO=2!W:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E<B!V:6$@
M=&AE('-E;&5C="!B;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83X*("`@("`@66]U('=I;&P@8F4@<')O;7!T960@9F]R(&9U<G1H97(@
M;W!T:6]N<RX@($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO;BP@
M87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD97(@
M:68@>6]U(&1E;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB9F]L9&5R+6]P=&EO;G,B/@H@
M("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M96YT/"]T:71L93X*("`@(#QH96%D
M:6YG/D9O;&1E<B!/<'1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@
M(%EO=2!C86X@<V5L96-T(&$@9F]L9&5R(&)Y('5S:6YG('1H92!R861I;R!B
M=71T;VYS(&%L;VYG('1H92!L969T(&-O;'5M;BX@($]N8V4@>6]U(&AA=F4@
M9&]N92!T:&ES+"!S96QE8W0@=&AE(&]P=&EO;B!Y;W4@=VES:"!T;R!P97)F
M;W)M(&]N('1H92!F;VQD97(@=FEA('1H92!S96QE8W0@8F]X('1O('1H92!L
M969T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%EO=2!W:6QL(&)E
M('!R;VUP=&5D(&9O<B!F=7)T:&5R(&]P=&EO;G,N("!"92!C87)E9G5L('=I
M=&@@=&AE(&1E;&5T92!O<'1I;VXL(&%S('EO=2!C86X@;&]S92!A;&P@=&AE
M(&UE<W-A9V5S(&EN(&$@9F]L9&5R(&EF('EO=2!D96QE=&4@:70@8GD@;6ES
M=&%K92$*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/DEM<&]R="!M8F]X($9I
M;&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@5&AI<R!O<'1I;VX@=VEL
M;"!I;7!O<G0@82!M8F]X(&9O<FUA="!F:6QE(&EN=&\@=&AE(&9O;&1E<B!O
M9B!Y;W5R(&-H;VEC92X@0VAO;W-E(#$@*&]N92D@9F]L9&5R('1O(&EM<&]R
M="!T:&4@;65S<V%G97,@:6YT;R!A;F0@=&AE;B!S96QE8W0@=&AI<R!O<'1I
M;VXN(%EO=2!W:6QL('1H96X@8F4@=&%K96X@=&\@82!P86=E('1H870@=VEL
M;"!P<F]M<'0@9F]R('1H92!M8F]X(&9I;&4@=&\@:6UP;W)T+@H@("`@/"]P
M87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M
M=VED9V5T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1F]L9&5R($UA;F%G
M96UE;G0Z($1I<W!L87D\+W1I=&QE/@H@("`@/&AE861I;F<^4VAO=R](:61E
M(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=7-I
M;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO=R]H:61E('1H92!U
M;G-U8G-C<FEB960@9F]L9&5R<RX@(%1O('-U8G-C<FEB92]U;G-U8G-C<FEB
M92!T;R!A(&9O;&1E<BP@<V5L96-T('1H92!C:&5C:V)O>"!N97AT('1O('1H
M92!F;VQD97)N86UE(&%N9"!U<V4@=&AE(%-U8G-C<FEB92]5;G-U8G-C<FEB
M92!O<'1I;VX@:6X@=&AE($9O;&1E<B!!8W1I;VX@9')O<"UD;W=N(&UE;G4N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%>'!A;F0@06QL/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!%>'!A;F0@86QL(&9O;&1E<B!E;G1R:65S+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^0V]L;&%P<V4@06QL/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#;VQL87!S92!A;&P@9F]L9&5R(&5N=')I97,N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97)S(B!S
M=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^1FEL=&5R<SH@07!P;'D\+W1I
M=&QE/@H@("`@/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B!T:&4@(D%P<&QY($9I;'1E<B(@
M:6-O;B!N97AT('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X('9I
M97<@=&\@9FEL=&5R(&%L;"!U;F1E;&5T960@;65S<V%G97,@86-C;W)D:6YG
M('1O('1H92!S<&5C:69I960@<G5L97,N("!/<BP@86QT97)N871E=FQY+"!C
M;&EC:R!O;B`B07!P;'D@06QL(%)U;&5S(B!I;B!T:&4@9FEL=&5R(&UE;G4N
M("!.;W1E('1H870@9FEL=&5R:6YG(&ES(&YO="!D;VYE(&%U=&]M871I8V%L
M;'DN"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)F:6QT97)S(CX*("`@(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-L:6-K(&]N('1H92`F<75O=#M!<'!L>2!&:6QT97(F
M<75O=#L@:6-O;B!N97AT('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL
M8F]X('9I97<@=&\@9FEL=&5R(&%L;"!U;F1E;&5T960@;65S<V%G97,@86-C
M;W)D:6YG('1O('1H92!S<&5C:69I960@<G5L97,N("!/<BP@86QT97)N871E
M=FQY+"!C;&EC:R!O;B`F<75O=#M!<'!L>2!!;&P@4G5L97,F<75O=#L@:6X@
M=&AE(&9I;'1E<B!M96YU+B`@3F]T92!T:&%T(&9I;'1E<FEN9R!I<R!N;W0@
M9&]N92!A=71O;6%T:6-A;&QY+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UR=6QE<R(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!&:6QT97(@4G5L97,\
M+W1I=&QE/@H@("`@/&AE861I;F<^161I="!9;W5R($9I;'1E<B!2=6QE<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!F
M:6QT97(@<G5L97,B('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U
M(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@=&AE(&-U<G)E;G1L>2!A8W1I
M=F4@<V5T(&]F(&9I;'1E<B!R=6QE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](F9I;'1E<BUE9&ET+6)L86-K;&ES="(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!";&%C:VQI<W0\+W1I=&QE
M/@H@("`@/&AE861I;F<^161I="!9;W5R($)L86-K;&ES=#PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!B;&%C:VQI<W0B
M('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E
M;&5T92P@86YD(&5D:70@=&AE(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y
M;W4@04Q705E3(')E9G5S92!M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UW:&ET96QI<W0B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@5VAI=&5L:7-T/"]T
M:71L93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!7:&ET96QI<W0\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@=VAI=&5L
M:7-T(B!T;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D
M+"!D96QE=&4L(&%N9"!E9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S
M97,@>6]U($%,5T%94R!A8V-E<'0@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!&:6QT97(@;VX@3&]G:6X\+W1I
M=&QE/@H@("`@/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S(%5P;VX@3&]G
M;VX_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO
M;B!T;R!A;'=A>7,@87!P;'D@9FEL=&5R<R!W:&5N(&9I<G-T(&QO9V=I;F<@
M;VYT;R!)35`N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F
M:6QT97(M;VXM9&ES<&QA>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL
M=&5R<SH@1FEL=&5R(&]N(%)E9G)E<V@\+W1I=&QE/@H@("`@/&AE861I;F<^
M07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE
M9#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N
M('1O(&%L=V%Y<R!A<'!L>2!F:6QT97)S('=H96YE=F5R('EO=7(@=FEE=R!T
M:&4@24Y"3U@_"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F
M:6QT97(M86YY+6UA:6QB;W@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I
M;'1E<G,Z($9I;'1E<B!A;GD@36%I;&)O>#PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY!<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA:6QB;W@_/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!I9B!Y;W4@=V%N
M="!T;R!B92!A;&QO=V5D('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@
M;6%I;&)O>"X@3F]R;6%L;'DL(&9I;'1E<FEN9R!R=6QE<R!A<F4@;VYL>2!A
M<'!L:65D('1O(&YE=R!M86EL('1H870@:7,@9&5L:79E<F5D('1O('EO=7(@
M24Y"3U@N("!)9B!T:&ES(&]P=&EO;B!I<R!C:&5C:V5D+"!A;B!I8V]N('=I
M;&P@87!P96%R(&]N(&%L;"!M86EL8F]X('!A9V=E<R!T:&%T('=I;&P@86QL
M;W<@>6]U('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!T:&4@;65S<V%G97,@
M:6X@=&AE(&-U<G)E;G0@;6%I;&)O>"X@($Y/5$4Z($9I;'1E<FEN9R!I;B!M
M86EL8F]X97,@;W1H97(@=&AA;B!)3D)/6"!M87D@<')O9'5C92!S=')A;F=E
M("AE+F<N('1H92!F:6QT97(@;6%Y(&-A=7-E(&$@8V]P>2!O9B!M97-S86=E
M<R!T;R!B92!D96QI=F5R960@=&\@=&AE('-A;64@;6%I;&)O>"D@86YD+V]R
M('5N9&5S:7)E9"!R97-U;'1S("AE+F<N(&ET(&UA>2!C875S92!M97-S86=E
M<R!T;R!B92!M;W9E9"]D96QE=&5D(&EF(&YE=R!F:6QT97)I;F<@<G5L97,@
M:&%V92!B965N(&EM<&QE;65N=&5D('-I;F-E('1H92!M97-S86=E(&AA<R!B
M965N(&1E;&EV97)E9"!T;R!T:&4@8W5R<F5N="!M86EL8F]X*2X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C
M:"UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@071T86-H
M(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^071T86-H(%!U8FQI
M8R!+97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H
M96X@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T
M<RP@=VEL;"!B92!A='1A8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X@
M(%EO=2!C86X@<V5T('1H92!D969A=6QT(&)E:&%V:6]R('9I82!T:&4@4$=0
M($]P=&EO;G,@<V-R965N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+6]P=&EO;BUS8V%N+6)O9'DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@4V-A;B!497AT($)O9&EE<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY38V%N(%1E>'0@0F]D:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!)9B!S96QE8W1E9"!T:&5N($E-4"!W:6QL('-C86X@=&AE(&)O9'D@;V8@
M86QL('1E>'0@;65S<V%G97,@9F]R(%!'4"!D871A+"!A;F0@9&ES<&QA>2!T
M:&4@<F5S=6QT<R!I9B!A;GD@9&%T82!I<R!F;W5N9"X@($YO=&4@=&AA="!T
M:&ES(&UA>2!S;&]W(&1O=VX@=&AE('-Y<W1E;2!A<R!E=F5R>2!T97AT(&UE
M<W-A9V4@;75S="!B92!S8V%N;F5D(&EN(&ET<R!E;G1I<F5T>2!F;W(@4$=0
M(&1A=&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6]P=&EO;G,M96YC<GEP="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M0V]M<&]S93H@16YC<GEP=&EO;B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D
M:6YG/DYO($5N8W)Y<'1I;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E
M;F0@=&AE(&UE<W-A9V4@=VET:"!N;R!E;F-R>7!T:6]N("AC;&5A<G1E>'0I
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0($5N8W)Y<'0@365S<V%G
M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!E
M;F-R>7!T('1H92!C=7)R96YT(&UE<W-A9V4L('5S:6YG(%!'4"!A;F0@=&AE
M(')E8VEP:65N=',@<&5R<V]N86P@<'5B;&EC(&ME>2P@86YD('1H96X@<V5N
M9"!I="X@66]U(&-A;B!O;FQY('-E;F0@82!M97-S86=E('1O(&$@<VEN9VQE
M('!E<G-O;B!U<VEN9R!T:&ES(&]P=&EO;BX@66]U($U54U0@:&%V92!T:&4@
M<'5B;&EC(&ME>2!O9B!T:&4@<F5C:7!I96YT('-T;W)E9"!I;B!Y;W5R(&%D
M9')E<W-B;V]K(&]R(&5L<V4@=&AI<R!O<'1I;VX@=VEL;"!F86EL+B!)9B!Y
M;W4@:&%V92!T:&4@<'5B;&EC(&ME>2!F;W(@=&AE(')E8VEP:65N="!I;B!Y
M;W5R(&%D9')E<W-B;V]K(&%N9"!A<F4@<W1I;&P@<F5C96EV:6YG(&5R<F]R
M<RP@=F5R:69Y('1H870@=&AE(&4M;6%I;"!A9&1R97-S(&EN('1H92!R96-I
M<&EE;G0@9FEE;&0@;6%T8VAE<R!T:&4@92UM86EL(&%D9')E<W,@=VAE<F4@
M=&AE('!U8FQI8R!K97D@:7,@<W1O<F5D+B!4:&4@96YC<GEP=&5D(&1A=&$@
M=VEL;"!B92!A='1A8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!3:6=N($UE<W-A9V4\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@9&EG:71A;&QY
M('-I9VX@=&AE(&-U<G)E;G0@;65S<V%G92!U<VEN9R!01U`@86YD('EO=7(@
M<&5R<V]N86P@<')I=F%T92!K97DN($EF('EO=2!H879E(&YO="!A;')E861Y
M(&5N=&5R960@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@<')I=F%T92!K97D@
M9'5R:6YG('1H:7,@<V5S<VEO;B!Y;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@
M:70N("!4:&4@<F5C96EP:65N="!M=7-T(&AA=F4@82!C;W!Y(&]F('EO=7(@
M<'5B;&EC(&ME>2!T;R!D:6=I=&%L;'D@=F5R:69Y('EO=7(*("`@('-I9VYA
M='5R92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!3:6=N+T5N8W)Y
M<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I
M;VX@=VEL;"!F:7)S="!D:6=I=&%L;'D@<VEG;B!Y;W5R(&UE<W-A9V4@86YD
M('1H96X@=VEL;"!E;F-R>7!T('1H92!R97-U;'1I;F<@;W5T<'5T+B!3964@
M=&AE("=01U`@16YC<GEP="!-97-S86=E)R!A;F0@)U!'4"!3:6=N($UE<W-A
M9V4G(&5N=')I97,@9F]R(&9U<G1H97(@:6YF;W)M871I;VXN"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY3+TU)344@16YC<GEP="!-97-S86=E/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY3+TU)344@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG
M;B]%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/
M1$\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R
M=FEE=R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!/=F5R=FEE=SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY7:&%T(&ES(%!'4#\\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%!'4"!I<R!A('1O;VP@9F]R('-E8W5R92!C;VUM=6YI
M8V%T:6]N(&%N9"!D871A('-T;W)A9V4L(&5S<&5C:6%L;'D@9F]R('5S92!W
M:71H(&4M;6%I;"X@270@8V%N(&)E('5S960@=&\@96YC<GEP="!D871A(&%N
M9"!T;R!C<F5A=&4@9&EG:71A;"!S:6=N871U<F5S+B!)35`@=7-E<R!';G50
M1R`H1TY5(%!R:79A8WD@1W5A<F0I('1O('!R;W9I9&4@=&AI<R!F=6YC=&EO
M;F%L:71Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16YA8FQE(%!'4"!F
M=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=&AI
M<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@8W)E
M871E+W9I97<@>6]U<B!P97)S;VYA;"!01U`@:V5Y<RP@861D+V1E;&5T92!P
M=6)L:6,@:V5Y<R!F<F]M(&]T:&5R(&EN9&EV:61U86QS+"!R96%D(&5N8W)Y
M<'1E9"!M86EL+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@
M96YC<GEP="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I;VXM871T86-H+7!U8FME
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!/<'1I;VYS("T@071T
M86-H(%!U8FQI8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^3W!T:6]N<R`M
M($%T=&%C:"!0=6)L:6,@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)
M9B!S96QE8W1E9"!T:&5N(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y
M+"!I9B!I="!E>&ES=',L('=I;&P@8GD@9&5F875L="!B92!A='1A8VAE9"!T
M;R!A;&P@;W5T9V]I;F<@;65S<V%G97,N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@
M("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1H:7,@<V-R965N(&QI<W1S(&%L;"!O9B!T:&4@8W5R<F5N="!U<V5R<R!I
M;B!Y;W5R(&%D9')E<W-B;V]K('1H870@:&%V92!01U`@<'5B;&EC(&ME>7,N
M(%1H97-E('5S97)S(&%R92!T:&4@3TY,62!U<V5R<R!T:&%T('EO=2!C86X@
M96ET:&5R(#$I('-E;F0@86X@96YC<GEP=&5D(&UE<W-A9V4@=&\@+4]2+2`R
M*2!V97)I9GD@82!D:6=I=&%L('-I9VYA='5R92X*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS
M(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<'5B
M;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T:&4@<'5B;&EC(&ME>2!F
M<F]M('EO=7(@861D<F5S<V)O;VLN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M:6UP;W)T+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME>7,@+2!);7!O<G0\+W1I
M=&QE/@H@("`@/&AE861I;F<^26UP;W)T(%!U8FQI8R!+97ES/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&ES(&)U='1O;B!W:6QL(&]P96X@82!W:6YD
M;W<@=VAE<F4@>6]U(&-A;B!M86YU86QL>2!I;7!O<G0@82!01U`@<'5B;&EC
M(&ME>2X@(%1H92!K97D@8V%N(&5I=&AE<B!B92!P87-T960@:6YT;R!A('1E
M>'1F:65L9"!O<BP@:68@=&AE(&ME>2!R97-I9&5S(&EN(&$@9FEL92!O;B!Y
M;W5R(&QO8V%L(&-O;7!U=&5R+"!Y;W4@8V%N(&EM<&]R="!I="X@($EF('1H
M92!K97D@:7,@=F%L:60@:70@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@
M861D<F5S<V)O;VL@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T
M('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP
M;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M;W9E<G9I97<M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,\+W1I=&QE/@H@("`@
M/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF
M('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&UE<W-A9V5S(&]R(&5N86)L
M92!O=&AE<G,@=&\@<V5N9"!Y;W4@96YC<GEP=&5D(&UE<W-A9V5S+"!Y;W4@
M;75S="!H879E('EO=7(@;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%!'
M4"!K97EP86ER+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0=6)L
M:6,@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!U8FQI8R!K
M97D@<VAO=6QD(&)E(&UA9&4@879A:6QA8FQE('1O(&%N>2!P97)S;VX@=&AA
M="!Y;W4@=V%N="!T;R!B92!A8FQE('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M
M97-S86=E<R!T:&%T(&]N;'D@64]5(&-A;B!D96-R>7!T("AU<VEN9R!Y;W5R
M('!R:79A=&4@:V5Y*2X@061D:71I;VYA;&QY+"!Y;W5R('!U8FQI8R!K97D@
M;F5E9',@=&\@8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY8F]D>2!Y;W4@<V5N
M9"!A(&1D:6=I=&%L;'D@<VEG;F5D(&UE<W-A9V4@=&\@+2!T:&4@<'5B;&EC
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE(&1I9VET86P@<VEG;F%T
M=7)E+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0<FEV871E($ME
M>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U<B!P<FEV871E(&ME>2!I
M<R!N96-E<W-A<GD@=&\@9&5C<GEP="!A;GD@;65S<V%G92!E;F-R>7!T960@
M=7-I;F<@>6]U<B!P=6)L:6,@:V5Y+B!!9&1I=&EO;F%L;'DL('EO=7(@<')I
M=F%T92!K97D@:7,@;F5E9&5D(&EF('EO=2!W86YT('1O(&1I9VET86QL>2!S
M:6=N(&$@;65S<V%G92X@66]U<B!P<FEV871E(&ME>2!W:6QL(&)E('!R;W1E
M8W1E9"!V:6$@82!P87-S<&AR87-E(&-R96%T960@=VAE;B!T:&4@:V5Y<R!A
M<F4@9V5N97)A=&5D+B!4:'5S+"!T;R!P97)F;W)M(&%N>2!A8W1I=FET>2!T
M:&%T(')E<75I<F5S('EO=7(@<')I=F%T92!K97DL($E-4"!W:6QL('!R;VUP
M="!Y;W4@9F]R('EO=7(@<&%S<W!H<F%S92X@66]U(&]N;'D@;F5E9"!T;R!I
M;G-E<G0@>6]U<B!P87-S<&AR87-E(&]N8V4@<&5R('-E<W-I;VX@+2!)35`@
M=VEL;"!S=&]R92!Y;W5R('!A<W-P:')A<V4@=6YT:6P@>6]U(&QO9V]U="`H
M4V\@8F4@<W5R92!T;R!L;V=O=70A*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP=6)L:6,B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!0
M=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'
M4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A
M:6QS(&%B;W5T('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP<FEV871E(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+
M97ES("T@4')I=F%T92!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^16YT97(@
M4&%S<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@=&AE
M('!A<W-P:')A<V4@9&EA;&]G('=I;F1O=RX@5&AE('!A<W-P:')A<V4@96YT
M97)E9"P@:68@8V]R<F5C="P@=VEL;"!B92!S=&]R960@8GD@24U0('5N=&EL
M('EO=7(@<V5S<VEO;B!E;F1S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M56YL;V%D(%!A<W-P:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%)E
M;6]V97,@=&AE('-T;W)E9"!P87-S<&AR87-E(&9R;VT@24U0("T@86YY(&%D
M9&ET:6]N86P@=7-A9V4@;V8@=&AE('!R:79A=&4@:V5Y('=I;&P@<F5Q=6ER
M92!Y;W4@=&\@<F5E;G1E<B!T:&4@<&%S<W!H96%S92X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P
M96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P<FEV871E(&ME>2X@1$\@
M3D]4(%-%3D0@5$A)4R!+15D@5$\@04Y93TY%("T@=&AI<R!O<'1I;VX@:7,@
M<W1R:6-T;'D@<V\@=&AA="!Y;W4@8V%N(&5X<&]R="!Y;W5R($E-4"!P97)S
M;VYA;"!P<FEV871E(&ME>2!F;W(@=7-E(&EN(&%N;W1H97(@<')O9W)A;2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@
M4$=0('!R:79A=&4@:V5Y+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+61E;&5T92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M($1E;&5T93PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@2V5Y<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!D96QE=&4@
M>6]U<B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER(&9R;VT@24U0
M)W,@<')E9F5R96YC97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6YA;64B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($YA;64\
M+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AE(&YA;64@>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S
M;VYA;"!K97ES+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UC;VUM
M96YT(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S
M;VYA;"!+97D@+2!#;VUM96YT/"]T:71L93X*("`@(#QH96%D:6YG/D-O;6UE
M;G0\+VAE861I;F<^"B`@("`\<&%R83X*("`@($$@8V]M;65N="!S=')I;F<@
M>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!;B!O
M<'1I;VYA;"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M96UA:6PB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($4M;6%I
M;"!!9&1R97-S/"]T:71L93X*("`@(#QH96%D:6YG/D4M;6%I;"!!9&1R97-S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@92UM86EL(&%D9')E<W,@
M>6]U('=A;G0@87-S;V-I871E9"!W:71H('EO=7(@<&5R<V]N86P@:V5Y<RX@
M02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M:V5Y;&5N9W1H(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@
M+2!+97EL96YG=&@\+W1I=&QE/@H@("`@/&AE861I;F<^2V5Y;&5N9W1H/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@:V5Y;&5N9W1H+"!I;B!B>71E
M<RP@;V8@>6]U<B!G96YE<F%T960@:V5Y+B!4:&4@9W)E871E<B!T:&4@=F%L
M=64L('1H92!G<F5A=&5R('1H92!P<F]T96-T:6]N("AA;F0@86QS;R!G<F5A
M=&5R(&=E;F5R871I;VX@=&EM92!A;F0@96YC<GEP=&EO;B!T:6UE*2X@,3`R
M-"!B>71E<R!I<R!T:&4@9&5F875L="`M('1H:7,@=F%L=64@<')O=FED97,@
M97AC96QL96YT('!R;W1E8W1I;VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+7!A<W-P:')A<V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L
M($ME>2`M(%!A<W-P:')A<V4\+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE('!A<W-P:')A<V4@=7-E9"!T
M;R!P<F]T96-T+V5N8W)Y<'0@>6]U<B!P97)S;VYA;"!P<FEV871E(&ME>2X@
M5&AI<R!S:&]U;&0@8F4@050@3$5!4U0@-B!C:&%R86-T97)S+"!S:&]U;&0@
M3D]4(&)E('1H92!S86UE(&%S('EO=7(@;&]G:6X@<&%S<W=O<F0L('-H;W5L
M9"!.3U0@8F4@8F%S960@;VX@82!D:6-T:6]N87)Y('=O<F0L(&%N9"!S:&]U
M;&0@:6YC;'5D92!B;W1H(&YU;6)E<G,@86YD(&QE='1E<G,N(%EO=2!M=7-T
M(&5N=&5R('1H:7,@<&%S<W!H<F%S92!T=VEC92!F;W(@=F5R:69I8V%T:6]N
M('!U<G!O<V5S+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UA8W1I
M;VYS(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S
M;VYA;"!+97D@+2!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D-R96%T
M92!+97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#<F5A=&4@86YD('-T
M;W)E('EO=7(@<&5R<V]N86PO<')I=F%T92!K97EP86ER+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^26UP;W)T($ME>7!A:7(\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($EM<&]R="!A('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX@
M5&AI<R!B=71T;VX@;W!E;G,@82!W:6YD;W<@=VAE<F4@>6]U(&-A;B!M86YU
M86QL>2!I;7!O<G0@>6]U<B!E>&ES=&EN9R!01U`@<&5R<V]N86P@<'5B;&EC
M+W!R:79A=&4@:V5Y<&%I<BX@(%1H92!K97ES(&-A;B!E:71H97(@8F4@<&%S
M=&5D(&EN=&\@82!T97AT9FEE;&0@;W(L(&EF('1H92!K97ES(')E<VED92!I
M;B!A(&9I;&4@;VX@>6]U<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O
M<G0@=&AE;2X@($EF('1H92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@
M:6YS97)T960@:6YT;R!Y;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W
M('=I;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W
M:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E,O34E-13H@3W9E<G9I97<\+W1I=&QE/@H@("`@
M/&AE861I;F<^5VAA="!I<R!3+TU)344_/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!3+TU)344@:7,@82!P<FEV871E+W!U8FQI8R!K97D@<&%I<B!S>7-T
M96T@=VAI8V@@<')O=FED97,@9&EG:71A;"!S:6=N871U<F5S+"!M97-S86=E
M('!R:79A8WDL(&%N9"!T86UP97(@9&5T96-T:6]N(&EN(&$@;W!E;BP@:6YT
M97)O<&5R86)L92!W87DN("!3+TU)344@8V%N('!R;W9I9&4@;65S<V%G92!P
M<FEV86-Y(&)Y(&5N8W)Y<'1I;F<@;65S<V%G97,@=&AA="!O;FQY('1H92!S
M96YD97(@86YD('1H92!I;G1E;F1E9"!R96-I<&EE;G1S(&-A;B!D96-O9&4N
M("!)="!A;&QO=W,@>6]U('1O(&ED96YT:69Y('1H92!S96YD97(@;V8@82!M
M97-S86=E('9I82!A(&1I9VET86P@<VEG;F%T=7)E+B`@5&]G971H97(L('1H
M:7,@96YC<GEP=&EO;B!A;F0@9&EG:71A;"!S:6=N:6YG(&AE;'`@<')O=FED
M92!T86UP97(@9&5T96-T:6]N+"!A;&QO=VEN9R!R96-I<&EE;G1S('1O(&1E
M=&5R;6EN92!W:&5T:&5R(&$@;65S<V%G92!W87,@86QT97)E9"!A9G1E<B!I
M="!W87,@<V5N="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!3
M+TU)344@9G5N8W1I;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($EF('1H:7,@;W!T:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE
M('1O(&EM<&]R="!Y;W5R('!E<G-O;F%L(%,O34E-12!K97ES+"!R96%D(&5N
M8W)Y<'1E9"!M86EL+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A
M;F0@96YC<GEP="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W+7!E<G-O
M;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z(%!E<G-O
M;F%L($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($EF('EO=2!W86YT('1O(&1I9VET86QL>2!S
M:6=N(&]R(&5N8W)Y<'0@;65S<V%G97,@>6]U(&UU<W0@:&%V92!Y;W5R(&]W
M;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!3+TU)344@:V5Y<&%I<BX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6EM<&]R="UP
M97)S;VYA;"UC97)T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%
M.B!);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH
M96%D:6YG/DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EM<&]R="!P97)S;VYA;"!C97)T:69I8V%T97,@
M9G)O;2!A(%!+0U,@(S$R(&9O<FUA="!F:6QE+B!02T-3(",Q,B!F:6QE<R!I
M<R!T:&4@9FEL92!U<W5A;&QY(&=E;F5R871E9"!W:&5N(&5X<&]R=&EN9R!A
M(&ME>2!F<F]M(&$@8G)O=W-E<B`H92YG+B!);G1E<FYE="!%>'!L;W)E<BP@
M1FER969O>"D@;W(@9G)O;2!A(&-E<G1I9FEC871E('-T;W)E(&UA:6YT86EN
M960@8GD@86X@3W!E<F%T:6YG(%-Y<W1E;2`H92YG+B!7:6YD;W=S(%A0*2X@
M268@=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E9"!I
M;G1O('EO=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S
M93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T
M=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)S;6EM92UD96QE=&4M<&5R<V]N86PM8V5R=',B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@1&5L971E(%!E<G-O;F%L($-E
M<G1I9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N
M86P@0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE
M=&4@>6]U<B!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!Y;W5R('!R969E
M<F5N8V5S+B`@66]U('=I;&P@;F\@;&]N9V5R(&)E(&%B;&4@=&\@<VEG;B!3
M+TU)344@;65S<V%G97,@;W(@=FEE=R!A;GD@4R]-24U%(&5N8W)Y<'1E9"!M
M97-S86=E<R!A9&1R97-S960@=&\@>6]U+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<VUI;64M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I
M=&QE/@H@("`@/&AE861I;F<^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($UA;F%G92!Y;W5R(%,O34E-12!P
M=6)L:6,@:V5Y(&QI<W0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W('1H92!R87<@=&5X="!O
M9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E
M=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&5C:&YI8V%L
M(&1E=&%I;',@;V8@=&AE('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY$96QE=&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T
M97,@=&AE('-E;&5C=&5D('!U8FQI8R!K97D@9G)O;2!S=&]R86=E+B`@1&5L
M971I;F<@82!P=6)L:6,@:V5Y(&9O<B!A('5S97(@=VEL;"!P<F5V96YT('EO
M=7(@9G)O;2!E;F-R>7!T:6YG(&$@;65S<V%G92!T;R!T:&%T('5S97(N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<FEN=&EN9R(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')I;G1I;F<\+W1I=&QE/@H@("`@/&AE
M861I;F<^4')I;G0@82!M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4;R!P<FEN="!A(&UE<W-A9V4@>6]U(&%R92!V:65W:6YG+"!C;&EC:R!O
M;B!T:&4@(E!R:6YT(B!L:6YK(&%T(&5I=&AE<B!T:&4@=&]P(&]R(&)O='1O
M;2!O9B!T:&4@;65S<V%G92X@5&AE(&UE<W-A9V4@=VEL;"!O<&5N(&EN(&$@
M;F5W('=I;F1O=R!F;W)M871E9"!F;W(@<')I;G1I;F<N("!$97!E;F1I;F<@
M;VX@>6]U<B!W96(@8G)O=W-E<B!A;F0@;W!E<F%T:6YG('-Y<W1E;2P@=&AE
M('!R:6YT(&1I86QO9R!B;W@@;6%Y(&]P96X@9F]R('EO=2X@($EF(&ET(&1O
M97,@;F]T(&]P96XL('1H96X@<'5L;"!D;W=N('1H92!W96(@8G)O=W-E<B=S
M(")&:6QE(B!M96YU(&%N9"!C:&]O<V4@(E!R:6YT(B!T;R!O<&5N('1H92!P
M<FEN="!D:6%L;V<@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<V]R=&EN9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4V]R=&EN
M9R!A;F0@5&AR96%D:6YG/"]T:71L93X*("`@(#QH96%D:6YG/E-O<G1I;F<@
M16YT<FEE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5VAE;B!V:65W:6YG
M(&$@;&ES="!O9B!M97-S86=E<RP@>6]U(&-A;B!S;W)T('1H92!M97-S86=E
M<R!B>2!A;GD@8V]L=6UN(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T
M92!C;VQU;6X@:&5A9&EN9RX@(%1O('-W:71C:"!C;VQU;6YS(&)E='=E96X@
M87-C96YD:6YG(&%N9"!D97-C96YD:6YG(&]R9&5R+"!C;&EC:R!O;B!T:&4@
M87)R;W<@:6-O;B!I;B!T:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY4:')E861I;F<\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1O(&=R;W5P(&UE<W-A9V5S(&)Y('1H<F5A9',@*'-U8FIE8W0I+"!S
M;R!E86-H(&UE<W-A9V4@:7,@9W)O=7!E9"!W:71H(&%L;"!I=',@<F5P;&EE
M<RP@8VQI8VL@=&AE(%M4:')E861=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L
M=6UN(&AE861I;F<N("!4;R!R971U<FX@=&\@;F]R;6%L('-U8FIE8W0@<V]R
M=&EN9RP@8VQI8VL@;VX@=&AE(%M3=6)J96-T72!L:6YK(&EN('1H92!S=6)J
M96-T(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB86QT97)N871I=F4M;7-G(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y-=6QT:7!A<G0O06QT97)N871I=F4@365S<V%G97,\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!3;VUE(&UE<W-A9V4@:&%V92!B965N('-E;G0@87,@
M82`B;75L=&EP87)T+V%L=&5R;F%T:79E(B!T>7!E(&)Y('1H92!S96YD97(N
M(%1H97-E(&UE<W-A9V5S(&AA=F4@<V5V97)A;"!P87)T<RP@86QL(&1I<W!L
M87EI;F<@=&AE(%-!344@0T].5$5.5"!B=70@:6X@1$E&1D5214Y4($9/4DU!
M5%,N(%1H92!M86EL(&%G96YT('=I;&P@9&ES<&QA>2!T:&4@;&%S="!P87)T
M(&EN('1H92!L:7-T('1H870@8V%N(&)E('-U8V-E<W-F=6QL>2!D:7-P;&%Y
M960@:6YL:6YE(&EN('1H92!B<F]W<V5R+"!I9B!A;GDN($%L;"!O=&AE<B!F
M;W)M871S('=I;&P@87!P96%R('5N9&5R('1H92!H96%D:6YG(")!;'1E<FYA
M=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N(B!A;F0@8V%N(&)E('9I97=E
M9"!O<B!D;W=N;&]A9&5D('-E<&%R871E;'DN($ET(&ES(&EM<&]R=&%N="!T
M;R!N;W1E('1H870@=&AE<V4@86QT97)N871I=F4@<&%R=',@8V]N=&%I;B!T
M:&4@4T%-12!#3TY414Y44R!A<R!T:&4@<&%R="!T:&%T(&ES('-H;W=N("T@
M=&AE>2!A<F4@<VEM<&QY(&EN(&$@9&EF9F5R96YT(&UE9&EA(&9O<FUA="`H
M92YG+B!T97AT('9S+B!(5$U,(&]U='!U="DN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUR96YA;65?<V5N=&UA:6Q?;6]N=&AL
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!296YA;64@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L
M93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@
M=V]U;&0@;&EK92!T;R!R96YA;64@>6]U<B!S96YT+6UA:6P@9F]L9&5R(&%T
M('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&4@9F]L9&5R('=I
M;&P@8F4@<F5N86UE9"`H=&\@82!N86UE('1H870@8V]N=&%I;G,@=&AE(&UO
M;G1H(&%N9"!Y96%R*2!A;F0@82!N97<@<V5N="UM86EL(&9O;&1E<B!W:6QL
M(&)E(&-R96%T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@
M4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@
M("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!D
M96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T('1H92!B96=I;FYI;F<@
M;V8@979E<GD@;6]N=&@N("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA
M=F4@82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K
M965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($1E;&5T92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D@+2`C
M(&]F($9O;&1E<G,@=&\@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF
M('EO=2!A<F4@9&5L971I;F<@;VQD('-E;G0M;6%I;"!F;VQD97)S(&5V97)Y
M(&UO;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@;VQD(&9O;&1E<G,@9&\@>6]U
M("!W86YT('1O(&ME97`_("!!;GD@9F]L9&5R<R!O;&1E<B!T:&%N('1H:7,@
M;6%N>2!M;VYT:',@=VEL;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO
M;G1H;'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-
M86EN=&5N86YC93H@1&5L971E($QI;FME9"!!='1A8VAM96YT<R!-;VYT:&QY
M/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I
M9B!Y;W4@=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD(&QI;FME9"!A='1A8VAM
M96YT<R!A="!T:&4@8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AI<R!M
M87D@8F4@=7-E9G5L(&EF('EO=2!H879E(&$@<75O=&$L(&9O<B!E>&%M<&QE
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L
M971E7V%T=&%C:&UE;G1S7VUO;G1H;'E?:V5E<"(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN
M:V5D($%T=&%C:&UE;G1S($UO;G1H;'D@+2`C(&]F($UO;G1H<R!T;R!+965P
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O
M;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&5V97)Y(&UO;G1H+"!H;W<@;6%N>2!M
M;VYT:',@;V8@;VQD(&%T=&%C:&UE;G1S(&1O('EO=2`@=V%N="!T;R!K965P
M/R`@06YY(&%T=&%C:&UE;G1S(&]L9&5R('1H86X@=&AI<R!M86YY(&UO;G1H
M<R!W:6QL(&)E(&1E;&5T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:"(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:#PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($1O('EO=2!W86YT('1O('!U<F=E('EO
M=7(@=')A<V@@9F]L9&5R(&5V97)Y('-O(&]F=&5N+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:6YT97)V
M86PB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN
M=&5N86YC93H@4'5R9V4@5')A<V@@26YT97)V86P\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!)9B!Y;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L
M(&AO=R!O9G1E;B!S:&]U;&0@:70@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:V5E<"(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!0=7)G92!4<F%S:"!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@
M268@>6]U(&%R92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R+"!M97-S86=E
M(&]L9&5R('1H86X@:&]W(&UA;GD@9&%Y<R!S:&]U;&0@8F4@<'5R9V5D/PH@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB
M7W1E>'0B('-T871E/2)N97<B/@H@("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M365S<V%G92!#;VUP;W-I=&EO;CH@071T<FEB=71I;VX@5&5X=#PO=&ET;&4^
M"B`@("`@/'!A<F$^"B`@("`@2&5R92!Y;W4@8V%N(&5N=&5R('1H92!P:')A
M<V4@=&AA="!Y;W4@=VES:"!T;R!A<'!E87(@8F5F;W)E(&%N>2!Q=6]T960@
M=&5X="!I;B!A(')E<&QY('1H870@>6]U('-E;F0N"B`@("`@/"]P87)A/@H@
M("`@(#QP87)A/@H@("`@(%EO=2!C86X@:6YC;'5D92!O;F4@;W(@;6]R92!S
M<&5C:6%L('!L86-E:&]L9&5R<R!T;R!I;G-E<G0@:6YF;W)M871I;VX@86)O
M=70@=&AE(&UE<W-A9V4@=&\@=VAI8V@@>6]U(&%R92!R97!L>6EN9RX@4&QA
M8V5H;VQD97)S(&-O;G-I<W0@;V8@82`G)2<@9F]L;&]W960@8GD@82!S:6YG
M;&4@;&5T=&5R+B!4:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!A<F4@879A
M:6QA8FQE.@H@("`@(#PO<&%R83X*"B`@("`@/'!A<F$^("5F(#H@5&AE('-E
M;F1E<B=S(&YA;64@86YD(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A
M<F$^("5A(#H@5&AE('-E;F1E<B=S(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@
M("`@/'!A<F$^("5P(#H@5&AE('-E;F1E<B=S(&YA;64\+W!A<F$^"B`@("`@
M/'!A<F$^("5R(#H@5&AE(&9U;&P@4D9#(#(X,C(@<W1Y;&4@9&%T92!A;F0@
M=&EM92!Z;VYE/"]P87)A/@H@("`@(#QP87)A/B`E9"`Z(%1H92!D871E(&%S
M('=W=RP@9&0@;6UM(%E965D\+W!A<F$^"B`@("`@/'!A<F$^("5X(#H@5&AE
M(&1A=&4@:6X@=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A
M<F$^("5C(#H@5&AE(&1A=&4@86YD('1I;64@:6X@=&AE(&QO8V%L92=S(&1E
M9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^("5M(#H@5&AE($UE<W-A9V4M240\
M+W!A<F$^"B`@("`@/'!A<F$^("5S(#H@5&AE('-U8FIE8W0\+W!A<F$^"B`@
M("`@/'!A<F$^("5N(#H@02!N97<@;&EN93PO<&%R83X*("`@("`\<&%R83X@
M)24@.B!4:&4@)R4G(&-H87)A8W1E<CPO<&%R83X*"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7W)E860B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!297%U97-T(%)E860@
M4F5C96EP=',\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!A(%)E
M860@4F5C96EP="(@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G1S
M(&]F('1H:7,@;65S<V%G92!T;R!N;W1I9GD@>6]U('=H96X@=&AI<R!M97-S
M86=E(&ES(&]P96YE9"!B>2!T:&4@<F5C:7!I96YT<RX@3F]T(&%L;"!C;&EE
M;G1S('-U<'!O<G0@+R!H;VYO<B!T:&ES+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<V5N9%]M9&XB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!396YD($U$3CPO
M=&ET;&4^"B`@("`\<&%R83X*("`@(")396YD(&$@341.(B!S96YD<R!A($UE
M<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("AA;'-O(&MN;W=N(&%S
M(&$@<F5A9"!R96-E:7!T*2!W:&5N('EO=2!V:65W(&$@;65S<V%G92!I;B!W
M:&EC:"!T:&4@=7-E<B!H87,@<F5Q=65S=&5D('1H870@=&AE>2!R96-E:79E
M(&YO=&EF:6-A=&EO;B!T:&%T('EO=2!H879E(')E860@=&AE(&UE<W-A9V4N
M($EN(&UO<W0@8V%S97,L('1H:7,@=VEL;"!H87!P96X@875T;VUA=&EC86QL
M>2!W:71H;W5T('!R;VUP=&EN9R!Y;W4N($EN(&-E<G1A:6X@:7-O;&%T960@
M8V%S97,L('EO=2!M87D@:&%V92!T;R!M86YU86QL>2!D96-I9&4@=&\@<V5N
M9"!T:&4@;F]T:69I8V%T:6]N(&)Y(&-L:6-K:6YG(&]N(&$@;&EN:RX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET
M:6]N7W)E<75E<W1?9&5L:79E<GDB('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!297%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;CPO
M=&ET;&4^"B`@("`\<&%R83X*("`@(")297%U97-T($1E;&EV97)Y($-O;F9I
M<FUA=&EO;B(@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@<V5R=F5R('1O(&YO=&EF>2!Y;W4@=VAE;B!I="!H87,@9&5L:79E
M<F5D('1H92!M97-S86=E('1O('1H92!R96-I<&EE;G0G<R!M86EL8F]X+B!)
M="!D;V5S;B=T(&UE86X@=&AE(&UE<W-A9V4@:&%S(&)E96X@<V5E;BP@:G5S
M="!T:&%T(&ET)W,@<VET=&EN9R!I;B!A(&UA:6QB;W@@<V]M97=H97)E+B!.
M;W0@86QL(&UA:6P@<V5R=F5R<R!S=7!P;W)T('1H:7,N(`H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7W-P86U?869T
M97)?<F5P;W)T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@1&5L971E(%-P86T@069T97(@4F5P;W)T:6YG/"]T:71L93X*("`@(#QP
M87)A/@H@("`@66]U(&UA>2!E;&5C="!T;R!D;R!O;F4@;V8@=&AR964@:71E
M;7,@869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!E:71H97(@<W!A;2!O
M<B!I;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@1FER<W0L
M('EO=2!C86X@9&5C:61E('1O(&1O(&YO=&AI;F<@+2!T:&4@;65S<V%G92!W
M:6QL(&)E(')E<&]R=&5D(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C96YT(&)U
M="!W:6QL(&]T:&5R=VES92!R96UA:6X@=6YC:&%N9V5D(&EN('EO=7(@;6%I
M;&)O>"X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V5C;VYD+"!I9B!R
M97!O<G1I;F<@82!M97-S86=E(&%S('-P86TL('EO=2!C86X@:6YS=&5A9"!H
M879E('1H92!M97-S86=E(&)E(&EM;65D:6%T96QY(&1E;&5T960N("!4:&ES
M('-E='1I;F<@:&%S(&YO(&5F9F5C="!O;B!R97!O<G1I;F<@82!M97-S86=E
M(&%S(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!4:&ER
M9"P@869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!S<&%M('1H92!M97-S
M86=E('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@
M86YD(&UO=F5D('1O('EO=7(@<W!A;2!F;VQD97(N("!!;'1E<FYA=&EV96QY
M+"!I9B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT('1H92!M97-S
M86=E('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@
M86YD(&UO=F5D('1O('EO=7(@24Y"3U@N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUH=&UL7VEM86=E7W)E<&QA8V5M96YT(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G
M92!297!L86-E;65N=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($9O<B!(5$U,
M(&UE<W-A9V5S(&1I<W!L87EE9"!I;FQI;F4L('-H;W5L9"!A;&P@:6UA9V4@
M=&%G<R!B92!B;&]C:V5D('5N=&EL('EO=2!S<&5C:69I8V%L;'D@9&5C:61E
M('1O('9I97<@=&AO<V4@:6UA9V5S/R!.;W1E('1H870L(&EF('9I97=I;F<@
M86X@2%1-3"!A='1A8VAM96YT+"!T:&4@:6UA9V5S('=I;&P@86QW87ES(&)E
M(&1I<W!L87EE9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+6AT;6Q?:6UA9V5?861D<F)O;VLB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!(5$U,($EM86=E(%)E<&QA8V5M96YT+T%D
M9')E<W-B;V]K(%-H;W<\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!B;&]C
M:VEN9R!I;6%G97,@9F]R(&EN;&EN92!(5$U,(&UE<W-A9V5S+"!S:&]U;&0@
M=V4@875T;VUA=&EC86QL>2!D:7-P;&%Y('1H96T@:6YS=&5A9"!I9B!T:&4@
M<V5N9&5R(&%P<&5A<G,@:6X@>6]U<B!A9&1R97-S8F]O:S\*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A<G0B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EL8F]X
M(%-T87)T(%!A9V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S
M('=H:6-H('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=R!W:6QL(&)E(&1I<W!L
M87EE9"!W:&5N('EO=2!A8V-E<W,@82!M86EL8F]X(&9O<B!T:&4@9FER<W0@
M=&EM92X@3F]T92!T:&%T('1H92`G=6YS965N)R!M97-S86=E(&]P=&EO;G,@
M9&\@;F]T('=O<FL@=VET:"!T:&4@)U1H<F5A9"<@<V]R=&EN9R!O<'1I;VX@
M+2!I;G-T96%D+"!Y;W4@=VEL;"!B92!S96YT('1O('1H92!L87-T('!A9V4N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E
M7V%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@4V%V92!!='1A8VAM96YT<R!O;B!396YT($UE<W-A9V5S/"]T:71L
M93X*("`@(#QP87)A/@H@("`@268@<V%V:6YG(&$@8V]M<&]S960@;65S<V%G
M92!I;B!A('-E;G0M;6%I;"!F;VQD97(L(&1E=&5R;6EN92!I9B!A;&P@871T
M86-H;65N="!D871A(&ES('-A=F5D+B!4:&4@9F]L;&]W:6YG(&]P=&EO;G,@
M87)E(&%V86EL86)L93H*("`@(#PO<&%R83X*"B`@("`\<&%R83XJ(")!;'=A
M>7,@<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A
M='1A8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S
M(&%R92!!3%=!65,@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"B`@
M("`@/'!A<F$^*B`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I
M<R!S96YT.R!D969A=6QT('1O(%E%4R(@+2!!3%=!65,@<')O;7!T('1O('-A
M=F4@871T86-H;65N=',@:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F
M875L="!I<R!T;R!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R
M83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[
M(&1E9F%U;'0@=&\@3D\B("T@04Q705E3('!R;VUP="!T;R!S879E(&%T=&%C
M:&UE;G1S(&EN('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@:7,@
M=&\@;F]T('-A=F4@871T86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@
M(DYE=F5R('-A=F4@871T86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A
M=F4@871T86-H;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM
M96YT<R!A<F4@3D5615(@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7VEN8F]X(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@26YB
M;W@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)U=&%L($EN8F]X(&ES(&$@
M<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@=&\@
M<V5A<F-H(&5V97)Y(&UA:6QB;W@@9F]R(&UE<W-A9V5S(&UA<FME9"!A<R!N
M97<N("!);G-T96%D+"!A;&P@8W5R<F5N=&QY('-U8G-C<FEB960@;6%I;&)O
M>&5S(&%R92!S96%R8VAE9"!F;W(@;F5W(&UE<W-A9V5S(&%N9"!T:&4@<F5S
M=6QT<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7W1R87-H(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U
M86P@5')A<V@\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)T=6%L(%1R87-H
M(&ES(&$@<V%V960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE
M960@9F]R(&$@<V5P87)A=&4@5')A<V@@9F]L9&5R+B`@26YS=&5A9"!O9B!M
M;W9I;F<@;65S<V%G97,@=&\@82!C96YT<F%L:7IE9"!T<F%S:"!F;VQD97(L
M(&UE<W-A9V5S(&%R92!S:6UP;'D@;6%R:V5D(&%S(&1E;&5T960@:6X@=&AE
M(&-U<G)E;G0@9F]L9&5R('1H97D@;&EV92!I;BX@(%=H96X@)W-H;W<@9&5L
M971E9"!M97-S86=E<R<@:7,@='5R;F5D(&]F9BP@=&AI<R!R97-U;'1S(&EN
M('1H97-E(&UE<W-A9V5S(&YO="!A<'!E87)I;F<@:6X@82!M86EL8F]X('9I
M97<N("!7:&5N(&$@=7-E<B!C;&EC:W,@;VX@5FER='5A;"!4<F%S:"P@*F%L
M;"H@;6%I;&)O>&5S(&%L;"!S96%R8VAE9"!F;W(@;65S<V%G97,@=&AA="!A
M<F4@9FQA9V=E9"!D96QE=&5D(&%N9"!T:&5S92!M97-S86=E<R!A<F4@9&ES
M<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"CPO:&5L<#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L
M92]R;U]23R\`````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,3<T-S$`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O;&]C86QE+W)O7U)/+TQ#7TU%4U-!1T53+P``````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S`#`R,3(U
M-@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O<F]?4D\O3$-?
M34534T%'15,O:6UP+FUO````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3(Q,S0`
M,3`T,3<S-C(W-C,`,#(R-#`R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````/P$``!P````4"@``KP$```P4````
M````R!H```H```#)&@``"@```-0:```*````WQH```H```#J&@``!````/4:
M```7````^AH``"@````2&P``,@```#L;```I````;AL``#(```"8&P``+@``
M`,L;```W````^AL``'P````R'```'````*\<```=````S!P```@```#J'```
M!0```/,<```(````^1P```<````"'0``#`````H=```%````%QT```,````=
M'0``3@```"$=``!0````<!T``$(```#!'0``'P````0>```(````)!X``!$`
M```M'@``(0```#\>```[````81X``"L```"='@``,0```,D>```,````^QX`
M``D````('P``!@```!(?```*````&1\```L````D'P``$0```#`?```*````
M0A\```,```!-'P``"````%$?```)````6A\```0```!D'P``!````&D?```&
M````;A\```X```!U'P``%0```(0?```^````FA\```(```#9'P``"@```-P?
M```&````YQ\```H```#N'P``8@```/D?``!?````7"```!P```"\(```#@``
M`-D@```,````Z"````T```#U(```#`````,A```4````$"$```\````E(0``
M!P```#4A``!<````/2$```0```":(0``!P```)\A```.````IR$``"D```"V
M(0``!@```.`A```-````YR$``!H```#U(0``'0```!`B```9````+B(``%T`
M``!((@``*````*8B```"````SR(```4```#2(@``!````-@B```0````W2(`
M`!D```#N(@``&@````@C```&````(R,``!`````J(P``!P```#LC```0````
M0R,``!P```!4(P``"@```'$C```4````?",``"\```"1(P``#P```,$C```'
M````T2,```\```#9(P``(P```.DC```F````#20``"`````T)```!````%4D
M```2````6B0```4```!M)```#@```',D```6````@B0```4```"9)```#0``
M`)\D```/````K20``!(```"])```#0```-`D```I````WB0``"P````()0``
M*````#4E```%````7B4``!````!D)0``$````'4E```/````AB4```L```"6
M)0``#P```*(E```,````LB4```\```"_)0``"@```,\E```2````VB4```T`
M``#M)0``#````/LE```>````""8``"$````G)@```P```$DF```'````328`
M``0```!5)@``"@```%HF```0````928```<```!V)@``"````'XF```9````
MAR8```0```"A)@``#````*8F```$````LR8```P```"X)@``#````,4F```*
M````TB8```4```#=)@``!@```.,F```*````ZB8```D```#U)@``$@```/\F
M```2````$B<``!`````E)P``)````#8G```(````6R<```D```!D)P``$```
M`&XG```&````?R<```P```"&)P``!P```),G```+````FR<```(```"G)P``
M!P```*HG```(````LB<``#<```"[)P``#P```/,G```'`````R@``!,````+
M*```#````!\H```.````+"@```P````[*```#@```$@H```/````5R@```T`
M``!G*```#P```'4H```F````A2@```L```"L*```!@```+@H```'````OR@`
M``0```#'*```!````,PH```%````T2@```,```#7*```"````-LH```,````
MY"@```0```#Q*```#````/8H```)`````RD```(````-*0``&0```!`I```2
M````*BD```X````]*0``!````$PI```+````42D```D```!=*0``#0```&<I
M```,````=2D``!0```""*0``%@```)<I```%````KBD```P```"T*0``(P``
M`,$I```'````Y2D``!$```#M*0``#0```/\I```-````#2H```<````;*@``
M"````",J```>````+"H``!0```!+*@``!0```&`J```Q````9BH``"@```"8
M*@``&@```,$J```H````W"H``"D````%*P``+@```"\K```V````7BL``"P`
M``"5*P``,0```,(K```0````]"L```T````%+```!0```!,L```3````&2P`
M``T````M+```%@```#LL```(````4BP``!````!;+```%0```&PL```3````
M@BP```<```"6+```%0```)XL```+````M"P``!8```#`+```"P```-<L```Z
M````XRP```T````>+0``!0```"PM```,````,BT```T````_+0``"@```$TM
M```&````6"T```X```!?+0``!0```&XM``!+````="T```H```#`+0``!P``
M`,LM```Y````TRT```8````-+@``#@```!0N```$````(RX```8````H+@``
M"@```"\N```+````.BX``!H```!&+@``%P```&$N```7````>2X``!L```"1
M+@``'P```*TN```,````S2X``!,```#:+@``$0```.XN``!#`````"\``#D`
M``!$+P``#````'XO```$````BR\``!````"0+P``%P```*$O```2````N2\`
M`"\```#,+P``!P```/PO```-````!#```!8````2,```"P```"DP```%````
M-3````0````[,```,P```$`P```>````=#```'4```"3,```/@````DQ``!"
M````2#$``#T```"+,0``/0```,DQ```I````!S(``"D````Q,@``,0```%LR
M```F````C3(``#L```"T,@``#P```/`R```A`````#,``!P````B,P``!0``
M`#\S```"````13,```T```!(,P```P```%8S```@````6C,``"8```![,P``
M"@```*(S```3````K3,```@```#!,P``#````,HS```&````US,``!$```#>
M,P``'@```/`S```,````#S0```@````<-```)P```"4T```'````330```8`
M``!5-```#0```%PT```+````:C0```P```!V-```"@```(,T```"````CC0`
M``8```"1-````P```)@T```A````G#0``"0```"^-```'0```.,T``!%````
M`34``#````!'-0``$````'@U```?````B34```\```"I-0``#````+DU```0
M````QC4```\```#7-0``!````.<U```%````[#4``%H!``#R-0``#0```$TW
M```*````6S<```L```!F-P``"@```'(W```$````?3<``!4```""-P``*```
M`)@W```Q````P3<``"H```#S-P``+P```!XX```K````3C@``#H```!Z.```
M?0```+4X```;````,SD``!T```!/.0``"0```&TY```%````=SD```\```!]
M.0``!@```(TY```&````E#D```4```";.0``!0```*$Y``!7````ISD``%``
M``#_.0``2````%`Z```C````F3H```H```"].@``$0```,@Z```:````VCH`
M`"X```#U.@``)@```"0[```?````2SL```L```!K.P``"0```'<[```(````
M@3L```D```"*.P``"@```)0[```4````GSL```P```"T.P``"````,$[```/
M````RCL```P```#:.P``"@```.<[```(````\CL```<```#[.P``$`````,\
M```1````%#P``#L````F/```!0```&(\```-````:#P```<```!V/```"P``
M`'X\``!&````BCP``$4```#1/```+P```!<]```/````1ST``!$```!7/0``
M#P```&D]```-````>3T``!T```"'/0``%````*4]```(````NCT``%\```##
M/0``!P```",^```&````*SX```T````R/@``*````$`^```&````:3X```\`
M``!P/@``(0```(`^```I````HCX``"````#,/@``:P```.T^```Q````63\`
M``(```"+/P``!@```(X_```$````E3\``!0```":/P``'0```*\_```>````
MS3\```8```#L/P``&0```/,_```&````#4````T````40```*0```")````,
M````3$```!````!90```,0```&I````<````G$````@```"Y0```$@```,)`
M```R````U4```"<````(00``(````#!!```$````44$``!L```!600``!@``
M`')!```3````>4$``!P```"-00``!0```*I!```/````L$$``!H```#`00``
M#P```-M!```9````ZT$``"@````%0@``,````"Y"```E````7T(```8```"%
M0@``#````(Q"```-````F4(```L```"G0@``%````+-"```*````R$(``!``
M``#30@``$@```.1"```.````]T(``!T````&0P``%0```"1#```=````.D,`
M`!D```!80P``)@```')#```#````F4,```8```"=0P``!P```*1#```,````
MK$,```H```"Y0P``#0```,1#```-````TD,``!D```#@0P``!0```/I#```)
M`````$0```0````*1```%0````]$```/````)40``!(````U1```!0```$A$
M```&````3D0```H```!51```"@```&!$```1````:T0``!$```!]1```$@``
M`(]$```D````HD0```4```#'1```#0```,U$```:````VT0```D```#V1```
M#P````!%```+````$$4``!0````<10```@```#%%```0````-$4```H```!%
M10``-P```%!%```=````B$4```4```"F10``$0```*Q%```,````OD4```T`
M``#+10``#````-E%```/````YD4``!$```#V10``"@````A&```/````$T8`
M`!,````C1@``$````#=&```(````2$8```4```!11@``!````%=&```$````
M7$8```D```!A1@```P```&M&```*````;T8```H```!Z1@``"0```(5&```/
M````CT8``!````"?1@```@```+!&```<````LT8``!P```#01@``$@```.U&
M```(`````$<```@````)1P``!@```!)'```,````&4<```L````F1P``#P``
M`#)'```3````0D<```0```!61P``#````%M'```P````:$<```<```"91P``
M#P```*%'```,````L4<``!````"^1P``#````,]'```&````W$<``"(```#C
M1P``#@````9(```'````%4@``"H````=2```'P```$A(```9````:$@``"<`
M``""2```,````*I(```_````VT@``#D````;20``+@```%5)```W````A$D`
M`!$```"\20``$0```,Y)```)````X$D``!0```#J20``#0```/])```/````
M#4H```P````=2@``#````"I*```8````-TH``!4```!02@``#P```&9*```H
M````=DH``!,```"?2@``#````+-*```/````P$H``#T```#02@``#P````Y+
M```(````'DL``!`````G2P``$0```#A+```.````2DL```D```!92P``%0``
M`&-+```*````>4L``$\```"$2P``#P```-1+```+````Y$L``#4```#P2P``
M!P```"9,```1````+DP```8```!`3```"@```$=,```.````4DP``!````!A
M3```%````'),```<````ATP``!L```"D3```(@```,!,```;````XTP```<`
M``#_3```&`````=-```8````($T``$$````Y30``/@```'M-```3````NDT`
M``8```#.30``%0```-5-```6````ZTT``!(````"3@``(````!5.```'````
M-DX```D````^3@``&@```$A.```(````8TX```<```!L3@``!@```'1.```\
M````>TX``!P```"X3@``<0```-5.```Y````1T\``$,```"!3P``.0```,5/
M```Y````_T\``"<````Y4```)P```&%0```S````B5```"L```"]4```0P``
M`.E0```*````+5$``!8````X40``*````$]1```%````>%$```4```!^40``
M!@```(11```#````BU$``"(```"/40``+@```+)1```,````X5$``!,```#N
M40``"P````)2```4````#E(```@````C4@``'````"Q2```<````25(``!(`
M``!F4@``"@```'E2```6````A%(```<```";4@``"@```*-2```<````KE(`
M`!$```#+4@``$@```-U2```3````\%(```(````$4P``!0````=3```"````
M#5,``!8````04P``'````"=3```8````1%,``#H```!=4P``.P```)A3```6
M````U%,``!H```#K4P``"@````94```.````$50``!$````@5```$0```#)4
M```%````1%0``!$```!*5````0````<```#:````B`````````"=````.P``
M`````````````````-8```"9````SP``````````````#P```)@```#O````
M.@$``-P`````````10```!(!```````````````````'`0```````,D```!0
M````0````+T````8`0``JP````````#G````*`````L!``!Y````=````%P`
M```1````)@$``+P```!!````]0```"D`````````Q0```'(````E````A@``
M`!L!``#^````X````+<````6`0```````*````!\````GP```+0````P`0``
ME@```*<````]`0``+````.D`````````6@```#@!``">````9P```.P````R
M`0````````````"!````E0```%(```#=````2@````````#Y`````````)(`
M```<````"@$```````#'````D0`````````L`0```````)L````S`0``M@``
M`*8````.````%@```.0``````````````#D!```H`0``<````"$!``".````
M`````.,```#K````(`$```@!``!3````?0```#X`````````&````,,````O
M`0``$````"X````-`0``-@```#<!``#7`````````%$```"L`````````(H`
M```)`0``)````&P```#0````J@```&L````G````'P```+,````7`0``````
M`&,````%`````````&T`````````,P````8!```;````1P````````"[````
MK0```"$`````````(@``````````````&@$``(T```#\````30```,X````G
M`0``R`````````"X````N@```$X````3`0````````$!````````)0$``+4`
M``",`````````.X```"A````+0$```````""````G```````````````````
M`````````````````(\`````````,@```/\`````````$@````````![````
M1@```+\```````````````````"P````Q@````````#T``````````````!@
M`````````$(`````````K@```'4`````````3P```#4!``#V````1````",`
M``"%````90```"H!```+````9````*4`````````*0$`````````````7P``
M```````P````6P```````````````````#D```")`````````,(`````````
M20````@````B`0``U0`````````F``````````````"H````9@```,T````]
M````BP```,````!J`````````*\``````````````',```!=`````````),`
M```,`0``'0$``#8!```[`0``@P```#X!``#[````HP````8```"0````,0$`
M````````````T0```/,````Z````-0```",!````````WP```!H````9`0``
M'P$``%D````_`0``\````-D````X````3````,L````"`0```````#\`````
M````[0````4!```T````=P`````````M``````````````#X````"@``````
M``````````````````"B````?P````(```#2````>@````````#B````%0$`
M`"X!``#E````)`$``!$!```Q`````P$````````K`0``\@```/H`````````
M``````T````4`0```````!`!``#Q````!`$``.H```#4````L@```/<`````
M````I````#P!``#;`````````'X```!(````W@````\!``!H````*@```!4`
M`````0``'`$```````"I````'@$``&\```!V````O@```)H```#H````````
M``````!B````2P```+D````>````5P`````````7`````````-,```!I````
M_0```)<```#A````Y@```````````````````&$```!#``````````````!4
M````-P``````````````E````'$```"`````7@```%@`````````50``````
M```9````5@``````````````R@```+$````@````Q````!,````$````+P``
M`(<`````````"0```#0!````````A````,$````.`0```P````P```#8````
M/````"L```!X````S````!0```!N`````````!T`````("`@("`@5&\Z(``@
M("`@1&%T93H@`"`@("!&<F]M.B``(%-U8FIE8W0Z(``@:6X@`"5D('1O("5D
M(&]F("5D($UE<W-A9V5S`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R
M('=A<R!N;W0@<F5N86UE9"X`)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@=&AE
M('-T87)T(&]F('1H92!M;VYT:"X`*$%P<&QY('1H97-E(&-H86YG97,@86YD
M(&UO=F4@=&\@;F5X="!S8W)E96XN*0`H1&ES8V%R9"!A;&P@8VAA;F=E<R!A
M;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI`"A2971U<FX@=&\@
M=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S
M(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E
M;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI
M;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`R-"!H;W5R
M<P!!32]030!!9&0@<&%I<@!!9&1R97-S`$%D9')E<W,@0F]O:P!!;&EA<P!!
M;&P`06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I
M;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z`$%L;"!M97-S
M86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W
M:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@<V5N="UM86EL
M(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE
M=&5D+@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N<W=E<F5D
M`$%N<W=E<F5D(&UE<W-A9V5S`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D
M;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@
M9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@96UP='D@=&AI<R!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\`07)R:79A;"!4:6UE`$%S8V5N
M9&EN9P!!='1A8V@`071T86-H;65N=`!!='1A8VAM96YT<P!!=F%I;&%B;&4@
M9FEE;&1S.@!"86-K('1O("5S`$)C8P!":7)T:&1A>0!";&%C:VQI<W0`0F]D
M>0!";W1H`$-A;F-E;`!#86YC96P@365S<V%G90!#86YC96P@4')O8FQE;2!2
M97!O<G0`0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L
M>2!D:7-C87)D(&ET<R!C;VYT96YT<RX`0V,`0V5L;"!0:&]N90!#:&%N9V4`
M0VAA;F=E($%L;`!#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W
M(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD(&AO=R!M
M97-S86=E<R!A<F4@<V]R=&5D+@!#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L
M(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&5C:R!&;VQD97(H<RD@9F]R
M($YE=R!-86EL`$-H;V]S92!!8W1I;VXZ`$-L;W-E(%=I;F1O=P!#;&]S960@
M1F]L9&5R`$-O;&QA<'-E($%L;`!#;VQL87!S92!!;&P@1F]L9&5R<P!#;VQL
M87!S92!&;VQD97(`0V]M<&%N>0!#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL
M;"!B92!C:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF
M>2!Y;W4@=VAE;B!I="!A<G)I=F5S+@!#;W!Y`$-O<G)E8W0`0V]R<F5C=&5D
M(%1E>'0`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,`0W)E871E`$-R96%T92!&;VQD97(`0W)E871E(&$@;F5W(&1R869T<R!F
M;VQD97(`0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(`0W)E871E(&$@
M;F5W('1R87-H(&9O;&1E<@!#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R
M9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E
M<G,L(&%N9"!D96QE=&4@<W!A;2X`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+@!$1`!$86EL>0!$871E`$1E9F%U;'0@261E;G1I
M='D`1&5F875L="!S;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@
M9&ER96-T:6]N.@!$96QE=&4`1&5L971E($9O;&1E<BAS*0!$96QE=&5D`$1E
M;&5T960@;65S<V%G97,`1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$
M97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I;2!S:6=N871U
M<F5S/P!$:7-P;&%Y`$1I<W!L87D@3W!T:6]N<P!$;R!.;W0@0VAE8VL@1F]L
M9&5R*',I(&9O<B!.97<@36%I;`!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<`!$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R
M/P!$;VYE`$1O=VYL;V%D($9O;&1E<BAS*0!$<F%F=`!$<F%F=',@9F]L9&5R
M.@!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5M86EL`$5M86EL($%D9')E<W,`
M16UP='D@1F]L9&5R*',I`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T>2!R97-U
M;'0N`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R
M`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R
M`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(`17)R
M;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!%>'!A;F0@06QL`$5X<&%N9"!!;&P@1F]L
M9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.86UE<P!&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A>`!&:6QT97)S`$9I;F0`1FER<W0@4&%G90!&;VQD97(@3F%V
M:6=A=&]R`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4@9G)O
M;2`E<P!&<F]M`$9R;VT@061D<F5S<P!(96QP`$AI9&4@1&5L971E9`!(;VUE
M($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)9VYO<F4`26=N;W)E($%L;`!)
M;7!O<G1A;G0`26UP;W)T86YT(&UE<W-A9V5S`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I
M;B!A(')E<&QY/P!,86YG=6%G90!,87-T(%!A9V4`3&ES="!(96QP(%1O<&EC
M<P!,;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G:6X@5&%S:W,`34T`
M36%I;&)O>`!-87)K(&%S.@!-87)K(&1I9F9E<F5N="!L979E;',@;V8@<75O
M=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA=&-H:6YG(&9I96QD<P!-
M97-S86=E`$UE<W-A9V4@0V]M<&]S:71I;VX`365S<V%G92!$871E`$UE<W-A
M9V4@4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E
M(%9I97=I;F<`365S<V%G92!F;&%G<P!-97-S86=E(&9O;&1E<G,`365S<V%G
M97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`
M36]D:69Y`$UO;G1H;'D`36]V90!.86UE`$YE=F5R`$YE=P!.97<@36%I;`!.
M97<@;65S<V%G97,`3F5X=`!.97AT($UE<W-A9V4`3F5X="!086=E`$YO`$YO
M(&9O;&1E<G,@=V5R92!S<&5C:69I960`3F\@<W!E;&QI;F<@97)R;W)S`$YO
M('-U9V=E<W1I;VYS`$YO;F4`3F]T($1E;&5T960`3F]T($1R869T`$YO="!)
M;7!O<G1A;G0`3F]T(%!E<G-O;F%L`$YO="!D96QE=&5D(&UE<W-A9V5S`$YO
M="!I;7!O<G1A;G0@;65S<V%G97,`3F]T97,`3VQD(&UE<W-A9V5S`$]L9"!S
M96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N`$]P=&EO;G,`3W1H97(@
M26YF;W)M871I;VX`3W1H97(@3W!T:6]N<P!086=E("5D(&]F("5D`%!A<G0H
M<RD`4&%S<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!L86-E('EO=7(@<VEG;F%T=7)E
M(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\`4&QE87-E(&5N=&5R('1H
M92!N86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE
M=R!N86UE.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E
M<RX`4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@
M86YY(&%C=&EO;G,N`%!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E
M<B!T;R!S96%R8V@N`%!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O
M<B!T:&ES(&]P97)A=&EO;BX`4')E=FEO=7,@365S<V%G90!0<F5V:6]U<R!0
M86=E`%!R:6YT`%!R;V)L96T@1&5S8W)I<'1I;VX`4'5R9V4@1&5L971E9`!0
M=7)G92!4<F%S:"!H;W<@;V9T96XZ`%)E9&ER96-T`%)E9&ER96-T($UE<W-A
M9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG(&9A:6QE9"X`
M4F5F<F5S:`!2969R97-H($9O;&1E<B!6:65W<SH`4F5L;V%D(%9I97<`4F5M
M96UB97(@=&AE(&QA<W0@=FEE=P!296UO=F4@<&%I<@!296YA;6EN9R`B)7,B
M('1O("(E<R(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%)E<&QA8V4@=VET:#H`4F5P;'D`4F5P;'D@=&\@06QL`%)E<&QY('1O($%L
M;#H`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S(%-P86T`4F5S970`4F5T
M=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO
M=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%-A=F4@1')A9G0`4V%V92!A
M<P!3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@)7,`4V5A<F-H`%-E87)C:"!297-U;'1S`%-E96X`4V5L
M96-T`%-E;&5C="!A;&P`4V5L96-T(&YO;F4`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!-97-S86=E`%-E;F0@
M4')O8FQE;2!297!O<G0`4V5N="!M86EL(&9O;&1E<CH`4V5T('!R969E<F5N
M8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E
M(&UE<W-A9V5S+@!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E
M9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=R!$96QE=&5D`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&5C:6%L
M($-H87)A8W1E<G,`4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S
M<&5L;"!C:&5C:VEN9RX`4W5B:F5C=`!3=6)J96-T($9I96QD`%-U8G-C<FEB
M92!T;R!&;VQD97(H<RD`4W5G9V5S=&EO;G,`5&%S:W,`5&5X=`!4:&4@8W5R
M<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M960@=&\@(B5S(BX`
M5&AE(&9O;&1E<B`B)7,B(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD97(@(B5S
M(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET
M(&UA>2!C875S92!P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+@!4:&4@9F]L9&5R("(E<R(@=V%S(&-R96%T960@8G5T
M('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E
M<R(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@
M9G)O;2!I="X`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@8W)E871E9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S
M(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H
M92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N`%1H92!F
M;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%1H92!F;VQD
M97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@(B5S(BX`5&AE
M<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AI<R!M87D@
M=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT
M:6YU93\`5&AI<R!M97-S86=E('1O`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE
M`%1O`%1R87-H(&9O;&1E<CH`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M
M96YT`%5N86YS=V5R960`56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T90!5
M;F1O($-H86YG97,`56YS965N`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0
M(&9O;&1E<B!S=6)S8W)I<'1I;VYS/P!5<V5R($]P=&EO;G,`57-E<FYA;64`
M5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ`%=A<FYI
M;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R
M97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EE<P!9;W4@87)E(&-R96%T:6YG
M(&$@<W5B+69O;&1E<B!T;R``66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E
M;"!F;VQD97(N`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<VEG;F%T=7)E.@!;
M3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`
M9G)O;0!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($E-4"`S+C$*4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$
M871E.B`R,#`R+3`X+3`Q(#$R.C4V.BLP,CHP,`I,87-T+51R86YS;&%T;W(Z
M($-O<FYE;&EU($U54T%4(#QC;75S871`:V5Y<WES+G)O/@I,86YG=6%G92U4
M96%M.B!2;VUA;FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R
M<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)
M4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`@
M("`@($-A=')E.B``("`@($1A=&$Z(``@("`@1&4@;&$Z(``@4W5B:65C=#H@
M`"!I;B``)60@+2`E9"!D:6X@)60@365S86IE`"5S($]P97)A=&EU;FD@9&4@
M;65N=&5N86YT82`M($-O;F9I<FUA<F4`)7,@97AI<W1A+B!$:7)E8W1O<G5L
M("5S(&YU(&$@<'5T=70@9FD@<F5D96YU;6ET+@`E<R!N=2!P87)E('-A(&9I
M92!O(&-A<W5T82!P;W-T86QA('9A;&ED82X`1&ER96-T;W)U;"`E<R!V82!F
M:2!R961E;G5M:70N($EN8V5P=70@9&4@;'5N82X`*$%P;&EC82!M;V1I9FEC
M87)I;&4@<VD@;65R9VD@;6%I(&1E<&%R=&4N*0`H4F5N=6YT82!L82!M;V1I
M9FEC87)I+B!);F%P;VD@;&$@9F5R96%S=')A(&1E($UE<V%J($YO=2XI`$%P
M;&EC82!S8VAI;6)A<FEL92!D92!P:6YA(&%C=6T@<VD@:6YT;V%R8V4M=&4@
M;&$@9F5R96%S=')A(&1E($UE<V%J($YO=2Y38VAI;6)A<FEL92!D92!P92!P
M86=I;F$@8W5R96YT82!.52!V;W(@9FD@87!L:6-A=&4N`"H@061A=6=A(&%S
M=&5A(&%P87-I;F0@3TL@*@`J(%1E(')O9R!A;&5G92!A9')E<RAA+V5L92D@
M*@`R-"!D92!O<F4`04TO4$T`061A=6=A('!E<F5C:&5A`$%D<F5S80!!9V5N
M9&$`06QI87,`5&]A=&4`5&]A=&4@;65S86IE;&4@9&EN(&1I<F5C=&\H<G5L
M+V%R96QE*2!U<FUA=&\H<B]A<F4I('9O<B!F:2!S86QV871E(&EN='(M=6X@
M9FES:65R($U"3U@Z`%1O871E(&UE<V%J96QE(&1I;B!D:7)E8W1O<G5L("(E
M<R(L(&UA:2!V96-H:2!D92`E<R!Z:6QE('9O<B!F:2!S=&5R<V5D969I;FET
M:78N`%1O871E(&1I<F5C=&]A<F5L92!C=2!M97-A:F4M=')I;6ES92!M86D@
M=F5C:&D@9&4@)7,@;'5N:2!V;W(@9FD@<W1E<G-E+@!3+6$@<W!E8VEF:6-A
M="!O('9A;&]A<F4@:6YC;W)E8W1A+@!#=2!287-P=6YS`$UE<V%J92!C=2!2
M87-P=6YS`%-I9W5R('9R96D@<V$@9F%C:6$@87-T82`_`%-I9W5R('9R96D@
M<V$@<W1E<F=I(&1E9FEN:71I=B!A8V5S=&4@;65S86IE(#\`4VEG=7(@=G)E
M:2!S82!G;VQE<W1I(&%C97-T(&1I<F5C=&]R(#\`4VEG=7(@=G)E:2!S82!G
M;VQE<W1I($=U;F]I=6P@/P!/<F$@<V]S:7)I:0!#<F5S8V%T;W(`071A<V5A
M>F$`071A<V%M96YT`$%T87-A;65N=&4`0VEM<'5R:2!D:7-P;VYI8FEL93H`
M26YA<&]I(&QA("5S`$-O<&EE(",R`%II=6$@9&4@;F%S=&5R90!,:7-T82!.
M96%G<F$`0V]R<"!-97-A:@!!;6EN9&]U80!296YU;G1A`%)E;G5N=&$@3&$@
M365S86H`4F5N=6YT82!L82!287!O<G0`1&%C82!R96YU;G1I(&QA(&%C97-T
M(%)A<W!U;G,L(&-O;G1I;G5T=6P@;'5I('-E('9A('!I97)D92X`0V]P:64`
M5&5L969O;B!-;V)I;`!38VAI;6)A`%-C:&EM8F$@5&]T`$]P=&EU;FD@9&4@
M9V5N=6P@8VET92!M97-A:F4@=F5Z:2!P92!O('!A9VEN82!S:2!C=6T@<VEN
M="!E;&4@<V]R=&%T92X`4W!E8VEF:6-A(&YU;65L92P@861R97-A('-I('-E
M;6YA='5R82!C87)E('9O<B!A<&%R96$@:6X@365S86IU;"!T874N`%9E<FEF
M:6-A(&1A8V$@<VEN="!M97-A:F4@;F]I(&EN($1I<F5C=&\H<B]A<F4I`$%L
M96=E($%C=&EU;F5A.@!);F-H:61E(&9E<F5A<W1R80!$:7)E8W1O<B!);F-H
M:7,`4F5S=')I;F=E('1O=`!297-T<FEN9V4@=&]A=&4@9&ER96-T;V%R96QE
M+@!297-T<FEN9V4@9&ER96-T;W)U;`!#;VUP86YI80!#;VYT<F]L96%Z82!C
M:6YD('-E('9E<FEF:6-A(&1A8V$@<VEN="!M97-A:F4@;F]I('-I(&1A8V$@
M=F5I(&9I('-A=2!N=2!A;G5N=&%T(&QA('-O<VER96$@;&]R+@!#;W!I87IA
M`$-O<F5C=`!497AT($-O<F5C=&%T`$YU('!O="!D97-C:&ED92!M;V1U;'5L
M(&1E($UE;G1E;F%N=&$@)7,`0W)E87IA`$-R96%Z82!$:7)E8W1O<@!#<F5A
M>F$@9&ER96-T;W(@;F]U('!E;G1R=2!#:6]R;F4`0W)E87IA(&1I<F5C=&]R
M(&YO=2!P96YT<G4@365S86IE+51R:6UI<V4`0W)E87IA(&1I<F5C=&]R(&YO
M=2!P96YT<G4@1W5N;VD`0W)E87IA(&9I;'1R92!P96YT<G4@;W)G86YI>F%R
M96$@;65S86IE;&]R('!R:6UI=&4L('-O<G1A<F5A(&QO<B!I;B!D:7)E8W1O
M87)E('-I('-T97)G97)E82!C96QO<B!N961O<FET92X`06QE9V4@;W!E<F%T
M:75N:6QE(&5X96-U=&%T92!L82!C;VYE8W1A<F5A(&QA("5S+@!:6@!::6QN
M:6,`1&%T80!)9&5N=&ET871E($EM<&QI8VET80!#<FET97)I=2!I;7!L:6-I
M="!D92!S;W)T87)E.@!$:7)E8W1I92!I;7!L:6-I=&$@9&4@<V]R=&%R93H`
M4W1E<F=E`%-T97)G92!$:7)E8W1O*')U;"]A<F5L92D`4W1E<G-E`$UE<V%J
M92!3=&5R<V4`3W!T:75N:2!-=71A<F4L($-O<&EE<F4L(%-T97)G97)E(&UE
M<V%J92X`1&5S8W)E<V-A=&]R`$1E<V-R:64@<')O8FQE;6$`1&5T86QI:2!I
M;G)E9VES=')A=&4@:6X@3$]'('!E;G1R=2!A9&UI;FES=')A=&]R+@!$:6T@
M<VEG;F%T=7)E<R`M(&1E('1R861U<R`_`$%F:7-E87IA`$]P=&EU;FD@9&4@
M069I<V%R90!.=2!V97)I9FEC82!D86-A('-I;G0@;65S86IE(&YO:2!I;B!$
M:7)E8W1O*'(O87)E*0!492!R;V<@;G4@86-C97-A(&1I<F5C="!M86EN=&5N
M86YC92YP:'``5G)E:2!S82!D97-C:&EZ:2!A8V5L($1I<F5C=&]R(#\`1V%T
M80!386QV96%Z82!$:7)E8W1O*')U;"]A<F5L92D`0VEO<FYE`$1I<F5C=&]R
M(&-U($-I;W)N93H`4V-H:6UB82!296=U;&EL92!D92!&:6QT<F%R90!%;6%I
M;`!!9')E<V$@9&4@16UA:6P`1V]L97-T92!$:7)E8W1O*')U;"]A<F5L92D`
M1V]L97-T92!'=6YO:75L`$5M<'1Y(')E<W5L="X@+2!D92!T<F%D=7,`26YT
M<F]D=2!N=6UE;&4@;F]U;'5I(&1I<F5C=&]R(&-U($-I;W)N90!);G1R;V1U
M(&YU;65L92!N;W5L=6D@9&ER96-T;W(@8W4@365S86IE+51R:6UI<V4`26YT
M<F]D=2!N=6UE;&4@;F]U;'5I($1I<F5C=&]R($=U;F]I(`!%<F]A<F4`3&$@
M,34@;6EN=71E`$QA(#,P('-E8W5N9&4`3&$@-2!M:6YU=&4`3&$@9FEE8V%R
M92!#;VYE8W1A<F4`3&$@,2\R(&]R90!);B!F:65C87)E(&UI;G5T`$5X96UP
M;&4@9&4@=F%L;W)I.@!$97-F87-O87)A(%1O=`!$97-F87-O87)A(%1O871E
M($1I<F5C=&]A<F5L90!$97-F87-O87)A($1I<F5C=&]R=6P`0V]M<&QE=&5A
M>F$@861R97-A(&1I;B!!9V5N9&$`3G4@<&]T(&-I=&D@<')E9F5R:6YT96QE
M+@!.=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0+@!&87@`
M1FEL=')E`$=A<V5S=&4`4')I;6$@4&%G:6YA`$1I<F5C=&]A<F4`5')I;6ET
M92!#;W!I90!4<FEM:71E($-O<&EE`$-O<&EE($UE<V%J('1R:6UI<V$@9&4@
M)7,`1&4@;&$`17AP961I=&]R`$AE;'``07-C=6YD92!-97-A:F4M4W1E<G-E
M`$%D<F5S82!D92!A8V%S80!496QE9F]N=6P@9&4@86-A<V$`2&]R9&4`26=N
M;W)A`$EG;F]R82!T;W0`26UP;W)T86YT90!-97-A:F4@26UP;W)T86YT90!#
M:6UP(&EM<&]R=&%T.B`E<P!#:6UP=7)I(&EM<&]R=&%T93H`26YC;'5D92!M
M97-A:G5L(&]R:6=I;F%L(&EN(')A<W!U;G,N`$QI;6)A`%5L=&EM82!086=I
M;F$`3&ES=&$@<W5B:65C=&5L;W(@9&EN($AE;'``0V]N96-T87)E`$-O;F5C
M=&%R92!L82`E<P!$96-O;F5C=&%R90!!8W1I=6YI(&QA($-O;F5C=&%R90!,
M3`!#87-U=&$@9&4@365S86IE`$UA<F-H96%Z83H`36%R8VAE87IA(&1I9F5R
M:71E(&YI=F5L92!D92!C:71A<F4@8W4@9&EF97)I=&4@8W5L;W)I+@!#:6UP
M=7)I('!O=')I=FET92`M(&1E('1R861U<P!-97-A:@!#;VUP=6YE($UE<V%J
M($YO=0!$871A(%-O<VER:6D`0V%U=&$@365S86IU;`!-87)I;64@365S86H`
M4W5R<V$@365S86IU;'5I`$9I;'1R87)E($-O;G1I;G5T`$UA<F-A=&4@8V$`
M26X@1&ER96-T;V%R96QE`&UE<V%J92!P92!O('!A9VEN82X`365S86HH=6PO
M96QE*2!I;@!-;V1I9FEC80!,=6YA<@!-=71A`$YU;64`3FEC:6]D871A`$YO
M:0!-97-A:F4@3F]I`$UE<V%J92!.;VD`57)M871O<G5L`$UE<V%J=6P@57)M
M871O<@!086=I;F$@57)M871O87)E`$YU`$YU(',M82!S<&5C:69I8V%T(&1I
M<F5C=&]R=6P`3G4@97AI<W1A(&=R97-E;&D@9&4@<V-R:65R90!.=2!E>&ES
M=&$@<W5G97-T:6D`3FEC:2!5;F$`3F5S=&5R<V4`0W5R871E`$YE:6UP;W)T
M86YT90!.92!097)S;VYA;`!-97-A:F4@3F5S=&5R<V4`365S86IE($YE:6UP
M;W)T86YT90!.;W1E`$UE<V%J92!696-H:0!$:7)E8W1O<G5L(&1E($UE<V%J
M92U4<FEM:7-E('9E8VAI(&$@9F]S="!G;VQI="X`3W!T:75N:0!!;'1E(&EN
M9F]R;6%T:6D`06QT92!/<'1I=6YI`%!A9VEN82`E9"!D:6X@)60`071A<V%M
M96YT*&4I`%!A<F]L80!%>&5C=71A($]P97)A=&EU;FEL92!D92!-96YT96YA
M;G1A`$1A=&4@4&5R<V]N86QE`%1E;&5F;VX`4&QA<V5A>F$@<V5M;F%T=7)A
M(&EN86EN=&5A(')A<W!U;G-U<FEL;W(N`$EN=')O9'4@;G5M96QE(&YO=6QU
M:2!D:7)E8W1O<CH`5&4@<F]G(&EN=')O9'4@;F]U;"!N=6UE.@!492!R;V<@
M<W!E8VEF:6-A('5N('-U;6%R(&%L('!R;V)L96UE:2X`5&4@<F]G(&EN=')O
M9'4@=6X@;G5M92!D92!U=&EL:7IA=&]R('-I(&\@<&%R;VQA`%9A(')O9R!S
M82!V97)I9FEC871I(&%D<F5S96QE(&EN=')O9'5S92X@3G4@<&%R('-A(&9I
M92!C;W)E8W1E+@!492!R;V<@86QE9V4@=6X@9&ER96-T;W(@:6YA:6YT92!D
M92!A('-P96-I9FEC82!A8W1I=6YE82X`5&4@<F]G(&%L96=E(&-E;"!P=71I
M;B!U;B!D:7)E8W1O<B!D92!C875T87)E+@!492!R;V<@86QE9V4@=6X@<VEN
M9W5R(&1I<F5C=&]R('!E;G1R=2!A8V5A<W1A(&%C=&EU;F4N`$UE<V%J=6P@
M4')E8V5D96YT`%!A9VEN82!0<F5C961E;G1A`%1I<&%R97-T90!$97-C<FEE
M<F5A('!R;V)L96UE:0!3=&5R9V4@9&4@5&]T`$=O;&5S=&4@1W5N;VEU;`!2
M961I<F5C=&5A>F$`4F5D:7)E8W1E87IA`%)E9&ER96-T96%Z82!A8V5S="!M
M97-A:@!2961I<F5C=&%R96$@82!E<W5A="X`4F5I;7!R;W-P871E87IA`%)E
M:6UP<F]S<&%T96%Z82!F97)E87-T<F$@8W4@9&ER96-T;V%R93H`4F5I;F-A
M<F-A(&9E<F5A<W1R80!5;'1I;6$@<W1A<F4`4W1E<F=E('!E<F5C:&5A`%)E
M9&5N=6UI<F5A(&QU:2`B)7,B(&EN("(E<R(@82!E<W5A="X@26%T82!C92!A
M('II<R!S97)V97)U;#H`26YL;V-U:65S=&4@8W4Z`%)A<W!U;F1E`%)A<W!U
M;F1E(&QA(%1O=&D`4F%S<'5N9&4@;&$@5&]T:3H`4F%S<'5N<RU#871R93H`
M4F%S<'5N9&4Z`%)A<&]R=&5A>F$@8V$@3F5D;W)I=`!3=&5R9V4@5&]T`$EN
M=&]A<F-E+71E(&QA(&QI<W1A(&1E(&UE<V%J92!D=7!A('-T97)G97)E82P@
M;75T87)E82!S874@8V]P:65R96$@=6YU:2!M97-A:BX`4V%L=F5A>F$@0VEO
M<FYA`%-A;'9E87IA(&-A`%-A;'9A<F5A($-I;W)N96D@82!E<W5A="X@26%T
M82!C92!A('-P=7,@<V5R=F5R=6PZ("5S`$-A=71A<F4`4F5Z=6QT871E($-A
M=71A<F4`0VET:71E`%-E;&5C=&5A>F$`4V5L96-T96%Z82!4;W0`4V5L96-T
M96%Z82!.:6UI8P!$96QI;6ET871O<B!D92!D871A.@!&;W)M871U;"!D92!A
M9FES87)E(&$@9&%T96DZ`$9O<FUA='5L(&1E(&%F:7-A<F4@82!O<F5I.@!3
M96QE8W1E87IA(&1O=6$@8VEM<'5R:2!P;W1R:79I=&4N`%-E;&5C=&5A>F$@
M;&EM8F$@<')E9F5R871A.@!4<FEM:71E`%1R:6UI=&4@4F%P;W)T(&1E($5R
M;V%R90!$:7)E8W1O<B!-97-A:F4M5')I;6ES93H`06QE9V4@8V4@<V4@:6YT
M:6UP;&$@871U;F-I(&-I;F0@;75T:2P@8V]P:65Z:2!S874@<W1E<F=I(&UE
M<V%J92X`26YC:&ED96T@9F5R96%S=')A(&1E(&-O;7!U;F5R92!-97-A:B!.
M;W4@;&$@<V%L=F%R96$@8VEO<FYE:2X`07)A=&$@365S86IE(%-T97)S90!-
M87)I;64`4V%R:2!P97-T92!-96YT96YA;G1A`$-A<F%C=&5R92!3<&5C:6%L
M92`N+BX`0V%R86-T97)E(%-P96-I86QE`&=R97-E;&D@9&4@;W)T;V=R869I
M92!P92!P86=I;F$N`%-U8FEE8W0`4W5B:65C='5L`%-U8G-C<FEE(&QA($1I
M<F5C=&\H<B]A<F4I`%-U9V5S=&EI`%-A<F-I;FD`5&5X='5L`$1I<F5C=&\H
M<G5L+V%R96QE*2!C=7)E;G0H92D@(B5S(B!V;W(@9FD@<F5D96YU;6ET92!C
M82`B)7,B+@!$:7)E8W1O<G5L("(E<R(@97AI<W1A(&1E:F$N`$1I<F5C=&]R
M=6P@(B5S(B!C;VYT:6YE(&-A<F%C=&5R92!N97!E<FUI<V4@:6X@;G5M96QE
M('-A=2X@07(@<'5T96$@8W)E82!P<F]B;&5M92X@0V]N=&%C=&5A>F$M;"!P
M92!!9&UI;FES=')A=&]R`$1I<F5C=&]R=6P@(B5S(B!A(&9O<W0@8W)E870@
M9&%R('1U(&YU(&%I('-U8G-C<FES(&QA(&5L+@!$:7)E8W1O<G5L("(E<R(@
M82!F;W-T('-T97)S(&1A<B!T=2!N=2!A:2!A;G5L870@<W5B<V-R:65R96$@
M;&$@96PN`$1I<F5C=&]R=6P@(B5S(B!N=2!A(&9O<W0@8W)E870N($EA=&$@
M8V4@82!S<'5S('-E<G9E<G5L.@!$:7)E8W1O<G5L("(E<R(@;G4@82!F;W-T
M('-T97)S+B!)871A(&-E(&$@<W!U<R!S97)V97)U;#H`1&ER96-T;W)U;"`B
M)7,B(&$@9F]S="!C<F5A="!C=2!S=6-C97,N`$1I<F5C=&]R=6P@(B5S(B!A
M(&9O<W0@<W1E<G,@8W4@<W5C8V5S+@!$:7)E8W1O<G5L("(E<R(@82!F;W-T
M(')E9&5N=6UI="!C=2!S=6-C97,@8V$@(B5S(BX`3G4@97AI<W1A($UE<V%J
M92!I;B!A8V5A<W1A(&-A<W5T82!P;W-T86QA+@!!8V5A<W1A(&]P97)A=&EU
M;F4@97-T92!D92!D=7)A=&$N($5S=&D@<VEG=7(@8V$@=G)E:2!S82!C;VYT
M:6YU:2`_`$UE<V%J=6P@:6X`5F%L;V%R96$@;6EN:6UA(&5S=&4@,0!!8V5A
M<W1A('9A;&]A<F4@=')E8G5I92!S82!F:64@;G5M97)I8V$N`%1I=&QU`$-A
M=')E`$=U;F]I.@!54DP`3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@
M4U%,+@!.=2!P;W0@=')A9'5C92!A8V5S="!D;V-U;65N="!7;W)D("T@9&4@
M=')A9'5S`$9A<F$@4F%S<'5N<P!-97-A:F4@9F%R82!287-P=6YS`%)E8W5P
M97)E87IA`$%N=6QE87IA(%-C:&EM8F%R:6QE`$YE8VET:71E`$9O;&]S97-T
M92!686QO87)E82!);7!L:6-I=&$`4W5B<V-R:64@;&$@9&ER96-T;V%R92!)
M34%0+@!/<'1I=6YI(%5T:6QI>F%T;W(`571I;&EZ871O<@!,82!C;VYE8W1A
M<F4@869I<V5A>F$Z`$%T96YT:64`4V%P=&%M:6YA;`!":6YE(&%I('9E;FET
M(&EN('-I<W1E;75L("5S`$)I;F4@86D@=F5N:70L("5S`$%D<F5S82!L82!3
M97)V:6-I=0!496QE9F]N(&QA(%-E<G9I8VEU`$%!`$%N=6%L`$1A`$-R96%R
M92!S=6)D:7)E8W1O<B!L82``0W)E87)E(&1I<F5C=&]R(&EN(')A9&%C:6YA
M+@!2961E;G5M97-T92!D:7)E8W1O<G5L.B``5')E8G5I92!S82!D97-C<FEI
M('!R;V)L96UA(&EN86EN=&4@9&4@82!T<FEM:71E(')A<&]R='5L+@!397-I
M=6YE82!T82!D92`E<R!A(&5X<&ER870N(%1E(')O9R!S82!F86-I($QO9R!)
M;B!D:6X@;F]U+@!);F9O<FUA=&EI(&1E<W!R92!T:6YE`$]P=&EU;FEL92!A
M=2!F;W-T('-A;'9A=&4N`%-E;6YA='5R83H`6T9A<F$@4W5B:65C=%T`6U)A
M<&]R="!0<F]B;&5M85T`6VQI;FEA("5S(&1I;B`E<UT`9&4@;&$`=D-A<F0@
M+2!D92!T<F%D=7,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O;&]C86QE+W)U7U)5+P``````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S`#`Q-S4P
M-0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O<G5?4E4O3$-?
M34534T%'15,O````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-C,`,#(Q,C<R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+VQO8V%L92]R=5]252],0U]-15-304=%4R]I;7`N;6\`````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$W-3,T,@`Q,#0Q-S,V,C<V,P`P,C(T,C4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````WA($E0````!D`P``
M'````#P;``"+!```7#8```````"(2```"@```(E(```*````E$@```H```"?
M2```"@```*I(```$````M4@```L```"Z2```%P```,9(```H````WD@``#(`
M```'20``,@```#I)```;````;4D``"X```")20``-P```+A)``!\````\$D`
M`!P```!M2@``'0```(I*```.````J$H```X```"W2@``"````,9*```%````
MSTH```,```#52@``$P```-E*```/````[4H```,```#]2@``"0````%+```(
M````"TL``"0````42P``'````#E+``!@````5DL``"````"W2P``,@```-A+
M```'````"TP```P````33```#0```"!,``!4````+DP``&,```"#3```+```
M`.=,```.````%$T```4````C30```P```"E-```7````+4T```H```!%30``
M#P```%!-``!.````8$T``%````"O30``0@````!.```C````0TX``!0```!G
M3@``%P```'Q.```7````E$X``",```"L3@``%P```-!.```?````Z$X```@`
M```(3P``$0```!%/```+````(T\``!4````O3P``#0```$5/```3````4T\`
M`",```!G3P``+P```(M/```_````NT\``"$```#[3P``.P```!U0```\````
M65```"L```"64```,0```,)0```[````]%````P````P40``"0```#U1```#
M````1U$``#D```!+40``#````(51```U````DE$```X```#(40``"@```-=1
M```6````XE$``"T```#Y40``"P```"=2```L````,U(``"H```!@4@``4```
M`(M2```1````W%(```L```#N4@``"@```/I2```C````!5,```,````I4P``
M"````"U3```)````-E,```X```!`4P``"@```$]3``!%````6E,```0```"@
M4P``!````*53```G````JE,```@```#24P``"````-M3```&````Y%,```X`
M``#K4P``%0```/I3```^````$%0``!4```!/5````@```&54```*````:%0`
M``8```!S5```"@```'I4```-````A50``&(```"35```)P```/94``!4````
M'E4``%\```!S50``'````--5```/````\%4``#,`````5@``*````#16``!$
M````758```X```"B5@``$P```+%6```<````Q58``#4```#B5@``'0```!A7
M```Q````-E<``$````!H5P``.````*E7```%````XE<```P```#H5P``#0``
M`/57```,`````U@``!0````06```#P```"58```0````-5@``!$```!&6```
M!P```%A8```'````8%@``"8```!H6```3P```(]8```=````WU@``"4```#]
M6```&P```"-9```>````/UD``"\```!>60``7````(Y9```N````ZUD```0`
M```:6@``!P```!]:```.````)UH``"D````V6@``!@```&!:```-````9UH`
M``L```!U6@``%````(%:```8````EEH``!H```"O6@``$````,I:```=````
MVUH``!D```#Y6@``70```!-;```5````<5L``"4```"'6P``$P```*U;```,
M````P5L``#D```#.6P``'`````A<```"````)5P```4````H7```!0```"Y<
M```$````-%P```T````Y7```$````$=<```4````6%P``!D```!M7```&@``
M`(=<```&````HEP``!,```"I7```$````+U<```7````SEP``!$```#F7```
M%0```/A<```K````#ET``#0````Z70``,P```&]=```8````HUT``!0```"\
M70``!P```-%=```0````V5T``!P```#J70``"@````=>```4````$EX```L`
M```G7@``!P```#->```O````.UX```\```!K7@``"0```'M>```'````A5X`
M`!8```"-7@``#P```*1>```M````M%X``!H```#B7@``*````/U>```M````
M)E\``"X```!47P``"P```(-?```,````CU\``",```"<7P``)@```,!?```J
M````YU\``"`````28```0P```#-@```$````=V````@```!\8```"P```(5@
M```:````D6```"<```"L8```$@```-1@```@````YV```!<````(80``!0``
M`"!A```.````)F$```X````U80``*P```$1A```$````<&$```H```!U80``
M#````(!A```7````C6$``!,```"E80``$0```+EA```6````RV$``#@```#B
M80``!0```!MB```=````(6(```\````_8@``%@```$]B```2````9F(```P`
M``!Y8@``#0```(9B```9````E&(``!P```"N8@``(````,MB```3````[&(`
M``D`````8P``%0````IC```0````(&,``"D````Q8P``+````%MC```H````
MB&,```X```"Q8P``-0```,!C```%````]F,``!````#\8P``#P````UD```0
M````'60```\````N9```"P```#YD```/````2F0```P```!:9```#P```&=D
M```*````=V0``!(```""9```#0```)5D```,````HV0``$,```"P9```/0``
M`/1D```+````,F4``!X````^90``(0```%UE```#````?V4```H```"#90``
M(````(YE```?````KV4``!L```#/90``&0```.ME```+````!68``!L````1
M9@``"````"UF```$````-F8```P````[9@``)0```$AF```J````;F8```<`
M``"99@``$@```*%F```$````M&8``!(```"Y9@``"@```,QF```(````UV8`
M`!T```#@9@``$````/YF```.````#V<``$0````>9P``!P```&-G```(````
M:V<``!D```!T9P``!0```(YG```$````E&<```P```"99P``$````*9G```$
M````MV<```\```"\9P``(@```,QG```.````[V<```(```#^9P``#0````%H
M```-````#V@```8````=:```$0```"1H```$````-F@```<````[:```!```
M`$-H```*````2&@``"(```!3:```!@```'9H```5````?6@```P```"3:```
M$0```*!H```%````LF@```0```"X:```#````+UH```*````RF@```4```#5
M:```)P```-MH```H`````VD``!8````L:0``"@```$-I```/````3FD``!``
M``!>:0``/````&]I```&````K&D```H```"S:0``!@```+YI```&````Q6D`
M``H```#,:0``#@```-=I```/````YFD``!L```#V:0``$0```!)J```5````
M)&H``!@````Z:@``$0```%-J```0````96H``",```!V:@``#P```)IJ```)
M````JFH``!(```"T:@``$@```,=J```0````VFH```4```#K:@``,0```/%J
M```D````(VL``!````!(:P``!@```%EK```:````8&L```8```![:P``"@``
M`()K``!/````C6L``"X```#=:P``!P````QL```(````%&P``!$````=;```
M"0```"]L```.````.6P``!8```!(;```$0```%]L```&````<6P``!$```!X
M;```$````(IL``!\````FVP``!4````8;0``#@```"YM```/````/6T```8`
M``!-;0``#````%1M```'````86T```L```!I;0```@```'5M```$````>&T`
M`!\```!];0``!P```)UM```B````I6T``&@```#(;0``(P```#%N```E````
M56X```@```![;@``-P```(1N```B````O&X``!,```#?;@``$0```/-N```/
M````!6\```\````5;P``%P```"5O```*````/6\```<```!(;P``$P```%!O
M```,````9&\```\```!Q;P``#@```(%O```,````D&\```X```"=;P``#P``
M`*QO```-````O&\```\```#*;P``#P```-IO```N````ZF\``!H````9<```
M)@```#1P```+````6W````8```!G<```!P```&YP```+````=G````0```""
M<```"0```(=P```)````D7````H```";<```!P```*9P``!`````KG```!4`
M``#O<```"@````5Q```6````$'$```0````G<0``!````"QQ```$````,7$`
M``4````V<0``%@```#QQ```#````4W$```P```!7<0``"@```&1Q```(````
M;W$```L```!X<0``#````(1Q```$````D7$```0```"6<0``#````)MQ```)
M````J'$```P```"R<0```@```+]Q```-````PG$``!(```#0<0``"P```.-Q
M```?````[W$``!0````/<@``&0```"1R```@````/G(``!(```!?<@``#@``
M`')R```)````@7(```0```"+<@``$P```)!R```+````I'(```D```"P<@``
M#0```+IR```,````R'(``!0```#5<@``%@```.IR```%`````7,```<````'
M<P``1`````]S```\````5',```(```"1<P```@```)1S```,````EW,``",`
M``"D<P``,@```,AS```,````^W,```<````(=```#@```!!T```*````'W0`
M`!$````J=```$P```#QT```-````4'0``!,```!>=```"P```')T```T````
M?G0```L```"S=```%````+]T```^````U'0``!,````3=0``-````"=U```2
M````7'4``!````!O=0``&````(!U```C````F74``"(```"]=0``)P```.!U
M``!6````"'8``$T```!?=@``N0```*UV```-````9W<``"(```!U=P``(0``
M`)AW```'````NG<```H```#"=P``$@```,UW```+````X'<``!L```#L=P``
M&`````AX```(````(7@```D````J>```"@```#1X```>````/W@``"@```!>
M>```"@```(=X```+````DG@```@```">>```%````*=X```L````O'@```4`
M``#I>```,0```.]X``"B````(7D``"D```#$>0``)P```.YY```H````%GH`
M`!H````_>@``=@```%IZ```H````T7H``"D```#Z>@``+@```"1[```V````
M4WL``"P```"*>P``,0```+=[```K````Z7L``!`````5?```#0```"9\```0
M````-'P```4```!%?```!P```$M\```3````4WP``#8```!G?```-P```)Y\
M```)````UGP```X```#@?```#0```.]\```/````_7P``!8````-?0``/@``
M`"1]```G````8WT``"<```"+?0``"P```+-]```$````OWT``!,```#$?0``
M"P```-A]```.````Y'T```X```#S?0``"0````)^```(````#'X``!`````5
M?@``%0```"9^```3````/'X```<```!0?@``'@```%A^```5````=WX``!0`
M``"-?@``"P```*)^```6````KGX```\```#%?@``#@```-5^```J````Y'X`
M``8````/?P``#````!9_```+````(W\``!`````O?P``+@```$!_```Z````
M;W\```X```"J?P``#0```+E_```%````QW\```P```#-?P``#0```-I_```-
M````Z'\```@```#V?P``"@```/]_```&````"H````X````1@```%P```""`
M```6````.(````4```!/@```!@```%6````?````7(```!0```!\@```$0``
M`)&```!+````HX```!@```#O@```!`````B!```.````#8$``!4````<@0``
MOP```#*!```(````\H$``!````#[@0``"`````R"```$````%8(``#(````:
M@@``"@```$V"```,````6((```\```!E@@``"P```'6"```'````@8(``!8`
M``")@@``.@```*""```@````VX(```\```#\@@``.0````R#```&````1H,`
M``D```!-@P``#@```%>#```.````9H,```0```!U@P``!@```'J#```6````
M@8,```X```"8@P``#P```*>#```4````MX,``$,```#,@P``"@```!"$```U
M````&X0``!$```!1A```"P```&.$```:````;X0``!<```"*A```)P```**$
M```;````RH0``!<```#FA```&P```/Z$```9````&H4``!\````TA0``%P``
M`%2%```<````;(4```P```")A0``$P```):%```O````JH4``!$```#:A0``
M!@```.R%```=````\X4```<````1A@``0P```!F&```R````788``#\```"0
MA@``-P```-"&``!7````"(<```4```!@AP``#0```&:'```M````=(<``'``
M``"BAP``/P```!.(```Y````4X@``$8```"-B```!````-2(```0````V8@`
M``P```#JB```%````/>(```=````#(D``!$````JB0``/0```#R)```E````
M>HD``"````"@B0``'P```,&)```=````X8D``"@```#_B0``)0```"B*```%
M````3HH```8```!4B@``!0```%N*```&````88H```0```!HB@``$````&V*
M```3````?HH```P```"2B@``%P```)^*```2````MXH```L```#*B@``#0``
M`-:*```4````Y(H``"\```#YB@``"@```"F+```0````-(L``!````!%BP``
M"P```%:+```0````8HL```<```!SBP``#0```'N+```&````B8L``!8```"0
MBP``!P```*>+```T````KXL``!4```#DBP``"P```/J+```.````!HP``!H`
M```5C```(````#",```%````48P```4```!7C```!````%V,```)````8HP`
M`#$```!LC```(@```)Z,```@````P8P``#,```#BC```'@```!:-``!U````
M-8T``#X```"KC0``0@```.J-```]````+8X``#T```!KC@``*0```*F.```I
M````TXX``#$```#]C@``-@```"^/```@````9H\``#0```"'CP``(0```+R/
M```?````WH\``"@```#^CP``,@```">0```F````6I```!\```"!D```,```
M`*&0``!7````TI```%4````JD0``+P```("1``!5````L)$``"L````&D@``
M)@```#*2```L````69(``$X```"&D@``,````-62```[````!I,``"\```!"
MDP``*0```'*3```/````G),``"$```"LDP``'````,Z3```+````ZY,```<`
M``#WDP``"P```/^3```%````"Y0```(````1E```"@```!24``!6````'Y0`
M`%D```!VE```%P```-"4```-````Z)0```,```#VE```(````/J4```D````
M&Y4``"8```!`E0``"@```&>5```3````<I4```@```"&E0``%@```(^5```,
M````II4```<```"SE0``!P```+N5```&````PY4``!H```#*E0``!@```.65
M```&````[)4``!$```#SE0``'@````66```9````))8``#(````^E@``#```
M`'&6```(````?I8```D```"'E@``"@```)&6```$````G)8```<```"AE@``
M#0```*F6```+````MY8``!D```##E@``$P```-V6```G````\98```\````9
MEP``#0```"F7```4````-Y<```T```!,EP``%````%J7```4````;Y<```,`
M``"$EP``!@```(B7```-````CY<```L```"=EP``+P```*F7``!7````V9<`
M`%H````QF```/P```(R8```V````S)@``'X````#F0``#````(*9```Q````
MCYD``#\```#!F0``#`````&:```*````#IH```(````9F@``!@```!R:```#
M````(YH``$\````GF@``-0```'>:```A````K9H``"0```#/F@``'0```/2:
M```9````$IL``!<````LFP``&0```$2;```J````7IL``"L```")FP``10``
M`+6;``!+````^YL``"<```!'G```(0```&^<```K````D9P``!T```"]G```
M.@```-N<```B````%IT``#T````YG0``00```'>=```H````N9T``"P```#B
MG0``,`````^>```2````0)X``!,```!3G@``$````&>>```)````>)X``!P`
M``""G@``$````)^>```/````L)X``"L```#`G@``)P```.R>```.````%)\`
M`$L````CGP``%P```&^?```J````AY\``#0```"RGP``%@```.>?```/````
M_I\``!\````.H```%````"Z@```/````0Z````P```!3H```$````&"@```/
M````<:````\```"!H````P```)&@```'````E:````@```"=H```!P```*:@
M```%````KJ````D```"TH```!@```+Z@```(````Q:````\```#.H```#```
M`-Z@```(````ZZ````P```#TH```!@````&A```&````"*$```<````/H0``
M!@```!>A```'````'J$```,````FH0``"0```"JA```&````-*$```P````[
MH0``!0```$BA```$````3J$```0```!3H0``!````%BA```"````7:$```X`
M``!@H0``#P```&^A```'````?Z$```4```"'H0``6P$``(VA```+````Z:(`
M``D```#UH@``#````/^B```'````#*,```,````4HP``#````!BC```8````
M):,``"4````^HP``-@```&2C```M````FZ,``!L```#)HP``)0```.6C```S
M````"Z0``#4````_I```'0```'6D```@````DZ0```H```"TI```"@```+^D
M```'````RJ0```4```#2I````0```-BD```.````VJ0```@```#II```"```
M`/*D```)````^Z0```T````%I0``&````!.E```=````+*4``%\```!*I0``
M(P```*JE```^````SJ4```4````-I@``#@```!.F```.````(J8``&,````Q
MI@``6````)6F```S````[J8```H````BIP``"0```"VG```#````-Z<```P`
M```[IP``"@```$BG```)````4Z<``$$```!=IP``2````)^G``!!````Z*<`
M`!X````JJ```$P```$FH```'````7:@``!8```!EJ```(P```'RH```9````
MH*@``",```"ZJ```"@```-ZH```4````Z:@```H```#^J```"0````FI```3
M````$ZD``!H````GJ0``,````$*I```\````<ZD``",```"PJ0``(P```-2I
M```Z````^*D``#D````SJ@``*@```&VJ```H````F*H``#H```#!J@``#P``
M`/RJ```.````#*L```H````;JP``0@```":K```*````::L``"X```!TJP``
M#@```*.K```(````LJL``!,```"[JP``'````,^K```(````[*L``"0```#U
MJP``*@```!JL``!%````1:P```\```"+K```#@```)NL```.````JJP```8`
M``"YK````P```,"L```-````Q*P```T```#2K```"@```."L```*````ZZP`
M`"@```#VK```#P```!^M```&````+ZT``!X````VK0``"0```%6M```,````
M7ZT```8```!LK0``$0```'.M```8````A:T``$4```">K0``$0```.2M```"
M````]JT``!0```#YK0``"`````ZN```,````%ZX```X````DK@``5@```#.N
M```B````BJX``"$```"MK@``(0```,^N```;````\:X```P````-KP``+```
M`!JO```D````1Z\``#X```!LKP``"0```*NO```4````M:\``!@```#*KP``
M-0```..O```H````&;```#P```!"L```+@```'^P```9````KK````<```#(
ML```#````-"P```.````W;````P```#LL```$@```/FP```.````#+$```L`
M```;L0``$P```">Q```+````.[$```@```!'L0``)P```%"Q```I````>+$`
M`!4```"BL0``)P```+BQ```<````X+$``!\```#]L0``,P```!VR```S````
M4;(``"X```"%L@``"@```+2R```&````O[(``!$```#&L@``*@```-BR```'
M`````[,```T````+LP``#0```!FS```-````)[,``!T````ULP``(@```%.S
M```5````=K,``"X```",LP``%0```+NS``!0````T;,``!0````BM```#P``
M`#>T```)````1[0```T```!1M```6P```%^T``!$````N[0```(`````M0``
M"0````.U```$````#;4```0````2M0``$0```!>U```4````*;4``!@````^
MM0``&````%>U```2````<+4```<```"#M0``%0```(NU```0````H;4``!<`
M``"RM0``#@```,JU```9````V;4``#````#SM0``*````"2V```U````3;8`
M`!D```"#M@``#````)VV```)````JK8``!,```"TM@``$P```,BV```+````
MW+8``!````#HM@``"````/FV```*`````K<``#8````-MP``$0```$2W```'
M````5K<```@```!>MP``)@```&>W```0````CK<``#$```"?MP``$````-&W
M```S````XK<``#$````6N```-````$BX```,````?;@```P```"*N```)```
M`)>X```L````O+@``!$```#IN```'````/NX``!!````&+D```D```!:N0``
M"0```&2Y```,````;KD``!0```![N0``'@```)"Y```2````K[D``!H```#"
MN0``$0```-VY```)````[[D``!$```#YN0``#`````NZ```T````&+H```X`
M``!-N@``#0```%RZ```5````:KH``!4```"`N@``'P```):Z```)````MKH`
M`"8```#`N@``-0```.>Z```%````';L``!L````CNP``$0```#^[```8````
M4;L```\```!JNP``#P```'J[```2````BKL``!<```"=NP``#P```+6[```N
M````Q;L```H```#TNP``"P```/^[```=````"[P```T````IO```)@```#>\
M```R````7KP``"D```"1O```$0```+N\```K````S;P```8```#YO```#P``
M``"]```/````$+T``!`````@O0``#@```#&]```4````0+T```X```!5O0``
M#0```&2]```0````<KT```X```"#O0``%````)*]```0````I[T``!````"X
MO0``(0```,F]```E````Z[T```0````1O@``(P```!:^```E````.KX```0`
M``!@O@``!````&6^```@````:KX``"4```"+O@``%@```+&^```9````R+X`
M``P```#BO@``'````.^^```'````#+\```0````4OP``"0```!F_```A````
M([\``#````!%OP``!P```':_```4````?K\```4```"3OP``#P```)F_```/
M````J;\```D```"YOP``'P```,._```/````X[\```H```#SOP``.````/Z_
M```)````-\````H```!!P```'0```$S````'````:L````<```!RP```$0``
M`'K````9````C,````0```"FP```#P```*O````J````N\````8```#FP```
M!P```.W````0````]<````X````&P0``!@```!7!```%````',$```4````B
MP0``"0```"C!```)````,L$```D````\P0``-````$;!```(````>\$``!@`
M``"$P0``$````)W!```4````KL$```8```##P0``!@```,K!```.````T<$`
M`!````#@P0``!@```/'!```B````^,$``#X````;P@``$````%K"```-````
M:\(``!````!YP@``#````(K"```X````E\(```P```#0P@``$````-W"```(
M````[L(```T```#WP@``$@````7#```2````&,,``!<````KPP``)0```$/#
M```<````:<,``"````"&PP``(P```*?#```9````R\,``!L```#EPP``'P``
M``'$```.````(<0```8````PQ```$````#?$```6````2,0``!,```!?Q```
M"````'/$```J````?,0``#$```"GQ```#````-G$```'````YL0``!\```#N
MQ```#0````[%```+````',4``$8````HQ0``)P```&_%```)````E\4```0`
M``"AQ0``$@```*;%```2````N<4``!<```#,Q0``)P```.3%```?````#,8`
M``4````LQ@``'@```#+&```9````4<8``"D```!KQ@``%0```)7&```;````
MJ\8```L```#'Q@``!````-/&```*````V,8```4```#CQ@``!````.G&```"
M````[L8```4```#QQ@``(0```/?&```%````&<<``!L````?QP``,@```#O'
M```F````;L<``"@```"5QP``#0```+['```J````S,<``"T```#WQP``&@``
M`"7(```1````0,@``!(```!2R```$````&7(```<````=L@```L```"3R```
M"0```)_(```5````J<@```X```"_R```$P```,[(```/````XL@``!````#R
MR```"`````/)```2````#,D``!$````?R0``#P```#')```+````0<D``#(`
M``!-R0``'0```(#)```H````GLD```L```#'R0``#0```-/)```*````X<D`
M``D```#LR0``"P```/;)```0`````LH``!$````3R@``$@```"7*```1````
M.,H``#H```!*R@``$@```(7*```.````F,H```\```"GR@``!P```+?*```$
M````O\H```,```#$R@``!P```,C*```=````T,H```4```#NR@``#P```/3*
M```+````!,L```L````0RP``"````!S+```/````)<L```<````URP``!0``
M`#W+```3````0\L``!(```!7RP``$@```&K+```#````?<L```X```"!RP``
M$P```)#+```-````I,L``!T```"RRP``&P```-#+```3````[,L``#<`````
MS```'````#C,```3````5<P```T```!IS````P```'?,```2````>\P```P`
M``".S```#````)O,```)````J,P```D```"RS```%@```+S,```3````T\P`
M``<```#GS```!@```._,```J````]LP``#X````AS0```@```&#-```#````
M8\T``!````!GS0``,0```'C-```N````JLT```T```#9S0``"0```.?-```1
M````\<T```H````#S@``$0````[.```F````(,X``!````!'S@``#P```%C.
M```*````:,X``#$```!SS@``#0```*7.```*````L\X``"P```"^S@``&@``
M`.O.```S````!L\``!L````ZSP``"P```%;/```8````8L\``!\```![SP``
M'P```)O/```I````N\\``%L```#ESP``8````$'0``#(````HM```!$```!K
MT0``'@```'W1```A````G-$```@```"^T0``!@```,?1```2````SM$```<`
M``#AT0``&P```.G1```3````!=(```8````9T@``!@```"#2```&````)](`
M`"`````NT@``,P```$_2```%````@](```T```")T@``!@```)?2```&````
MGM(``#@```"ET@``!P```-[2```O````YM(``&P````6TP``(0```(/3```8
M````I=,``!@```"^TP``'0```-?3``!L````]=,``",```!BU```,@```(;4
M```Y````N=0``#D```#SU```,P```"W5```Y````8=4``"H```";U0``%```
M`,;5```3````V]4``!,```#OU0``!@````/6```)````"M8``!$````4U@``
M-````";6```S````6]8```D```"/U@``$````)G6```0````JM8``!$```"[
MU@``$````,W6```^````WM8``"0````=UP``)P```$+7```+````:M<```8`
M``!VUP``$@```'W7```*````D-<```P```";UP``#0```*C7```-````MM<`
M``T```#$UP``%P```-+7```;````ZM<``!<````&V```"````![8```C````
M)]@``!L```!+V```%0```&?8```4````?=@``!T```"2V```&P```+#8```0
M````S-@``"<```#=V```!P````79```,````#=D```P````:V0``$P```"?9
M```]````.]D``#,```!YV0``$P```*W9```,````P=D```@```#.V0``#0``
M`-?9```.````Y=D```T```#TV0``#@````+:```(````$=H```D````:V@``
M&P```"3:```A````0-H``"(```!BV@``"````(7:```*````CMH``!8```"9
MV@``%@```+#:```6````Q]H``$$```#>V@``'P```"#;```(````0-L``!``
M``!)VP``'@```%K;``#,````>=L```0```!&W```$0```$O<```-````7=P`
M``T```!KW```/P```'G<```6````N=P``!(```#0W```"0```./<```6````
M[=P```T````$W0``)````!+=```T````-]T``"X```!LW0``(0```)O=```K
M````O=T```4```#IW0``"0```._=```%````^=T``!$```#_W0``"P```!'>
M```'````'=X``!<````EW@``#0```#W>```/````2]X```\```!;W@``-0``
M`&O>```+````H=X``#$```"MW@``$````-_>```.````\-X``"````#_W@``
M%0```"#?```?````-M\``!X```!6WP``)````'7?```>````FM\``!,```"Y
MWP``$````,W?```9````WM\``"````#XWP``$P```!G@```<````+>```#D`
M``!*X```'0```(3@```&````HN````4```"IX```!@```*_@``!`````MN``
M`"@```#WX```30```"#A``!%````;N$``$P```"TX0``"@````'B```2````
M#.(``"8````?X@``.````$;B```M````?^(``#\```"MX@``1P```.WB```(
M````->,``!8````^XP``$@```%7C```0````:.,``!L```!YXP``%@```)7C
M```W````K.,``"D```#DXP``)P````[D```B````-N0``!D```!9Y```+0``
M`'/D```L````H>0```H```#.Y```!@```-GD```&````X.0```D```#GY```
M!@```/'D```4````^.0```\````-Y0``%P```!WE```3````->4``!,```!)
MY0``$P```%WE```3````<>4``!T```"%Y0``*0```*/E```'````S>4```D`
M``#5Y0``!````-_E```'````Y.4``!````#LY0``!````/WE```.`````N8`
M``(````1Y@``%P```!3F```)````+.8``"@````VY@``(@```%_F```+````
M@N8``!0```".Y@``$P```*/F```S````M^8```8```#KY@``!0```/+F```%
M````^.8```P```#^Y@``-0````OG```8````0><``!H```!:YP``,0```'7G
M```9````I^<``'<```#!YP``.````#GH```_````<N@``"H```"RZ```*@``
M`-WH```@````".D``"`````IZ0``+0```$KI```V````>.D``!4```"OZ0``
M(@```,7I```4````Z.D``!0```#]Z0``&0```!+J```S````+.H``!<```!@
MZ@``%P```'CJ```W````D.H``#<```#(Z@``-P````#K```K````..L``#8`
M``!DZP``&@```)OK```=````MNL``"X```#4ZP``6`````/L```H````7.P`
M`#P```"%[```+P```,+L```?````\NP```\````2[0``)P```"+M```@````
M2NT``!$```!K[0``!P```'WM```2````A>T```D```"8[0``!````*+M```0
M````I^T``#````"X[0``0P```.GM```6````+>X``!$```!$[@```P```%;N
M```F````6NX``"0```"![@``*P```*;N```-````TNX``!<```#@[@``#```
M`/CN```6````!>\``!(````<[P``!@```"_O```+````-N\```4```!"[P``
M'0```$CO```)````9N\```D```!P[P``(@```'KO```D````G>\``"$```#"
M[P``2````.3O```6````+?```!````!$\```$````%7P```0````9O````@`
M``!W\```"P```(#P```5````C/```!0```"B\```%0```+?P```7````S?``
M`"4```#E\```$0````OQ```4````'?$``!0````R\0``$P```$?Q```3````
M6_$``!H```!O\0```P```(KQ```+````CO$``!4```":\0``%````+#Q```E
M````Q?$``$\```#K\0``3P```#OR```\````B_(``"H```#(\@``$P```//R
M```$````!_,``#$````,\P``.@```#[S```-````>?,```\```"'\P```@``
M`)?S```(````FO,```(```"C\P``-0```*;S```E````W/,``!X````"]```
M(@```"'T```;````1/0``"````!@]```(@```('T```4````I/0``"4```"Y
M]```)@```-_T``!(````!O4``%0```!/]0``*````*3U```@````S?4``#D`
M``#N]0``'0```"CV``!$````1O8``!\```"+]@``+````*OV```Z````V/8`
M`!X````3]P``*0```#+W``!!````7/<```H```">]P``%@```*GW```/````
MP/<```D```#0]P``(@```-KW```3````_?<``!,````1^```*P```"7X```K
M````4?@```T```!]^```1P```(OX```,````T_@``"\```#@^```)0```!#Y
M```9````-OD```D```!0^0``'@```%KY```1````>?D```T```"+^0``"@``
M`)GY```6````I/D``!$```"[^0``"@```,WY```%````V/D```<```#>^0``
M!0```.;Y```&````[/D```8```#S^0``!P```/KY```(`````OH```4````+
M^@``"0```!'Z```(````&_H```D````D^@``!0```"[Z```&````-/H```@`
M```[^@``!0```$3Z```*````2OH```@```!5^@``!````%[Z```,````8_H`
M``P```!P^@``"````'WZ```$````AOH```<```"+^@```@```)/Z```#````
MEOH```,```":^@``%@```)[Z```6````M?H```\```#,^@``!0```-SZ```!
M`````````#P```"=`0``6`$``/X"``!T`````````&@```#P````?@$``#``
M````````,`(``&$"``!R`@```````#\"``"C`@``X@$``/0```#4````````
M``("``#Z````"0$``)H````.````.P,``*0```"0`@``50,``(`!````````
M`````'X"``"[````[P```````````````````.@!``!<`@```````-4"``#.
M````!@$``"`````>`P``"0,`````````````AP(````````4`P``D0```%`"
M``#9````]P$``(8!````````0`$``*L`````````X`(``/$"````````'0,`
M`'@!```-`````````"<!``````````````$#``"M````[````&$````K`@``
M`````"(!```_````%P(``#D!```M`0``\0````````"T````,0$``!@"``"P
M````IP(``$P"``"I`0``FP````````"6``````````````#=`0``8````(<`
M``!P`@```P(``%4`````````NP(````````,`0``8@```#,```!3`@``+0,`
M`/H!```A`P``#`,````````1`P``SP(``!<``````````````.@"``#S`0``
M5@$```````````````````````#V`0``5P$``/,`````````0`(``%,#``#W
M`````````%T#``"Z`0``5`$```0!```M`@```````)4!`````````````'8!
M``!\`@``'0(`````````````9@$``(,!``#0````.`$`````````````B0$`
M`($!````````,@,``-$"```?`P``XP$``,D`````````40$``%8"```M````
MF````-,```#!`0``6P,``/(```!L````10(``,D!````````C@```-H"``!^
M````=0```+<"``"(````<0$``!$"``#I`0``+````)<"``!8`P``BP````8#
M``#6`0```````&T```"4`@``_P```)@!``""`@``70(``"X#``!J`@``````
M`/(!``")````OP$`````````````O@(```````#2`@``E@(``#H"```V````
M`````*8```"^````5P(``#X"```@`@``9`,```(```#\``````````````!(
M`@``1````!@#``````````````\"``##`@``"P,``+$"``!D`@```````&D!
M```=````H0(`````````````-@$``!0"``#4`0``V@```+`!``!-````9@(`
M``,!``#<`````````%$"``"U`0``S0$`````````````%`$``*X"``"\`0``
M`````%H!```:`@``,0(```4```![`@``-@(``&4!``"$`@``OP````````"'
M`0``YP$``````````````````)`!````````"@```*P"``!4`@````````L"
M``!*`@``5P,``%H````.`0``=@(``!H!``!B`@``+P,``$4```#9`0``[0$`
M`+D!``!<`P``#P$``*`!``#J````M@(```P````7`P``$@```$T!```C`P``
MLP$``)X"```T`0``/`(``)\`````````@0(```````#_`0```````)0!```D
M`P````````````#[`0``30,``*\```!H`0``#`(``)$!```]`@```````",`
M````````[P$``(L"``#8`0``10$``+4```````````````````!A`P``````
M`)T```!'`@``N`(```````!+`0``1P```````````P``J@```,X"``!@`@``
M,0```!8#``#?````>P$``,P"```X````V0(``.````!9`0``$P,``.L`````
M```````````````(`@``)0$``%8#``"C`0```````#L"``#*`0``?0```$`#
M``#%`0```````#<"````````00,``-0"````````-P,`````````````SP$`
M``````"O`0``PP$``)D!`````````````)X!```;````K`$```````#B````
M`````+(!````````C0(``'P```!/`0``FP$``!P#``"]````R@```+4"``"Z
M`````````$<!``"W````:0(``(P```".`@``IP$```8``````````````'`!
M``":`0```````%X```"[`0```````$\#``!#`P`````````````)````````
M``````#!`@``Y@````````"4````6@(``.4"``""`0``1@(``.<"```2`@``
MW`(``,<```#Y`0``'0$````````N`@``(`,`````````````]`$``&(!````
M````Z````!X!``"Y`@````````@`````````:P`````````L`0```````!``
M``"&`````````.H"``#]````H````/P!```B`@``>P```*X```!Y`0``````
M``````!V````*0$``,0!``"G````/0$``%T```#!`````````"0```"@`@``
M'@(``$X#``"*````;@```$("`````````````+,"``"8`@``]0$``/D```#&
M````#0,````````V`P``E0(``,L!````````UP$`````````````R`$``!D#
M``!9`````````'T"``#N`@``%@```$\"````````LP````````!*`````P``
M`#4#```?`0``DP````````"?`0``X0```!D"``!Q````$`$``!P`````````
M@P```#X!````````M`(``*,```"<`````````"(#```<`0````(```````"-
M````$`,``````````````````$0#``#Q`0````````````",`0```````(@"
M````````.0,``%L!``#``@``20`````````(`P``!0(``%\!```7`0``*@(`
M```````O`0````````````"2`0``U0```%@"``#Z`@``V`(`````````````
MD``````````X`P``2`,``)P!``"V`0``&P(``"D#``#1````4P````(#```K
M`0``%0```-T"``#2````"0(``$P!``"``@````````H!````````T`$``%D#
M``!M`@`````````````E````;`$``*\"````````>`(``/@"```F`P``.P``
M``````#1`0``R````*@```#>`@``L@(``/X!``":`@```````.P"````````
M4`$``)P"``#E`0``3````!4#``!Y`@```````*H"``"/`@``I0$```T"``#B
M`@``]@`````````3`@```````,`!``#"````)P,```T!```K`P``2@$``$X`
M``!2`@``P`````````!S`0``20,``,L"```J`0``:0```-\!````````1`(`
M`#("````````D0(``&,"````````7P```%X#``#R`@```````-X`````````
M```````````%`0`````````````````````````````P`0``!`,```````#O
M`@``G@```/T!```N`0``P@$``&@"`````````````)("```]`````````.,`
M```I`@```````#H!``#L`0```````.4```#)`@``DP(````````\`0``G0(`
M`$8!```6`@````````<#``!?`P``80$``'\```"`````7@$```````"K`@``
M=P````````!+`@``2`$``!@!``!&````J`$```````"F`@``T@$`````````
M````^P```%4"````````5P```,T```!;`@``8`,``(8"```H`0```````$T"
M``#P`@``Z@$``$4#`````````0$``%L```"I`````````(H!``"M`@``W0``
M`&4"``#&`@```````*8!``"#`@```````.X```#D````W`$````````E`@``
MI`$``-L```!'`P``0P(``)D```!K`@``+P````@!`````````````%(#````
M`````0(``$,!```E`P``=P$``"0!``#$`@``/0,``-L!```A````4@$``%`#
M``#8````$`(```````"H`@````````X"```;`0```````,,`````````````
M`'````!$`0``Q0(```H"````````X0(``!D!```$`@``;0$``&<````W````
M=`(```````#I`@``OP(``#L!```2`0``;@$``*X!````````,`,``%0```#M
M`@``!P(``+X!````````A```````````````]P(```````"\````[@$``*(!
M```%`P```````.D```!W`@``3`,```````!!`@```````$,````4````$@,`
M`&8````H````?`$``),!``"2````/P,``-8````````````````````T`@``
M70$``"8```#,`0``M`$``#4!```J`P``RP```!H```!:`P``=0$``,T"````
M`````````&,!```L`@``TP(``($```!Y`````P,``#4"````````O0$```L`
M``#3`0``"@,``"H```#F`0``/P$``#,"````````=`$``,@"``!!````]@(`
M`.T````G````#P,``)D"``#7````WP(`````````````_`(``.0"``"7````
M$0$````````C`@```````"(```"*`@``&0``````````````O`(``$$!```;
M`P````````````!C`P``````````````````0@```$D!``"%`````````&\`
M```A`0``^````#P#``#7`@``_@``````````````QP(``&,```"/````````
M`#,#````````Q@$```````!S`````````+<!``!*`P``A0(``$8#``#[`@``
M>@```+$!``"X`0```````.8"```'````9````(D"````````I`(``,0`````
M````9`$``````````````````,\```"5````#P````````!Q`@``<@```&\"
M``!+`P``N0```*$```!?`@``!@(```X#``".`0``4P$`````````````8`$`
M````````````EP$``"<"``#Y`@``JP$``(L!``#:`0``X0$``*("```'`0``
M>````!X```"V````\P(``+`"```+`0```````%$````1````9P(``,H"````
M`````````',"````````S``````````Z`P``9P$``.L!``#;`@```````*(`
M``#_`@```````*4"````````&``````````N````*`,``$X"``!`````FP(`
M`+@```"M`0````````0```!<````<@$``%````!/````,P$```````"Z`@``
M`````"\"``!)`@``,0,``%D"``"Q`````````"D````5`@``A`$```````!"
M`0``$P`````````:`P```````#X````K````(P$``%(````X`@``````````
M``"?`@```````%$#``"L````XP(``&H``````````````#X#``!E````(0(`
M`/4"``!+`````````(@!````````````````````````0@,```````!K`0``
M$P$```````"-`0``ZP(`````````````YP````````!_`0``Q0``````````
M````]0```#4`````````'P(```````!5`0``^`$```````"6`0```````&\!
M``#0`@``L@```'\"``!6````+`,``-4!``"A`0``>@$``#(````Z````)@(`
M```````H`@``=0(``,<!``!N`@```````,X!```R`0``3@$``(4!```5`0``
MC`(``&(#```@`0``-`,``.0!```"`0```````'T!`````````````%0#``"]
M`@```````"8!```Y`@``P@(``/T"``!Z`@``J0(``&H!``!8`````````#0`
M``#6`@```````(\!`````0``.0```$@```!>`@``'`(``&P"``""````````
M`.`!``"J`0``)`(``-X!``#T`@```````%P!```6`0``I0```!\```#P`0``
M````````````````-P$````@("`@("!4;SH@`"`@("!$871E.B``("`@($9R
M;VTZ(``@4W5B:F5C=#H@`"!I;B``)60@365S<V%G97,`)60@=&\@)60@;V8@
M)60@365S<V%G97,`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;@`E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S
M(&YO="!R96YA;65D+@`E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@
M<W1A<G0@;V8@=&AE(&UO;G1H+@`E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE
M9"D`*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E
M96XN*0`H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C
M;VUP;W-E('-C<F5E;BXI`"A2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N
M(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#
M:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L
M:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S
M96QE8W0@861D<F5S<RAE<RD@*@`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O
M<FUA=``R-"!H;W5R<P!!32]030!!3D0`06-C;W5N="!);F9O<FUA=&EO;@!!
M8V-O=6YT)W,@;F%M93H`061D`$%D9"!(97)E.@!!9&0@<&%I<@!!9&0@=&AE
M("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D960@(B5S(B!A<R!A
M;B!A='1A8VAM96YT+@!!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES<&QA>2!W
M:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@:&5A9&5R
M(&]N(&$@;F5W(&QI;F4I/"]E;3X`061D:71I;VYA;"!M97-S86=E(&5R<F]R
M(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N
M(&)E('9I97=E9"`E<RX`061D<F5S<P!!9&1R97-S($)O;VL`061D<F5S<R!"
M;V]K<P!!9&1R97-S97,@=&\@0D-#(&%L;"!M97-S86=E<SH@/&5M/BAO<'1I
M;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3X`
M061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H:7,@:61E;G1I='DZ
M(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L
M:6YE*3PO96T^`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%L;`!!;&P@075T:&5N
M=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@
M;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D
M;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@9FEL93H`06QL(&UE<W-A9V5S(&EN
M('EO=7(@(B5S(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@
M<&5R;6%N96YT;'D@9&5L971E9"X`06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N`$%L
M;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L=&5R;F%T92!)
M35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)
M35-0(%5S97)N86UE`$%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I
M;VXZ`$%L=V%Y<R!S879E(&%T=&%C:&UE;G1S`$%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"X`06YS=V5R960`06YS=V5R960@;65S<V%G97,`07!P
M;&EC871I;VX`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY($9I;'1E<G,`
M07!P;'D@1FEL=&5R<R!T;R`E<P!!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L
M;V=G:6YG(&]N/P!!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@
M:7,@9&ES<&QA>65D/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E
M('1H:7,@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;C\`07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A
M8VAM96YT/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F
M;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R
M87-H(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N
M=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)R:79A;"!4:6UE`$%S8V5N
M9&EN9P!!<VL`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&%C:"!&:6QE<P!!='1A8V@@82!C
M;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/P!!
M='1A8VAE9"!&:6QE.@!!='1A8VAM96YT`$%T=&%C:&UE;G0@)7,@9&5L971E
M9"X`071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N="!T
M>7!E`$%T=&%C:&UE;G1S`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A4
M34P@;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY(&%D9')E<W-B
M;V]K/P!!=F%I;&%B;&4@9FEE;&1S.@!"86-?:R!T;R`E<P!"86-K('1O("5S
M`$)A8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN9&5X`$)C8P!":7)T
M:&1A>0!";&%C:VQI<W0`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";&]C
M:R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E
M8VEF:6-A;&QY(')E<75E<W1E9#\`0F]D>0!";W1H`$)O=&@@2&5A9&5R($QI
M<W1I;F<@86YD($)O9'D@;V8@365S<V%G90!#7VAA<G-E=`!#86QE;F1A<@!#
M86YC96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A
M;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R
M9"!I=',@8V]N=&5N=',N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#8P!#96QL
M(%!H;VYE`$-H86YG90!#:&%N9V4@06QL`$-H86YG92!&;VQD97(`0VAA;F=E
M(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO
M=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@87)E('-O<G1E
M9"X`0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N`$-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V4@
M=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#
M:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$-H96-K(%]!;&PO3F]N90!#
M:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@
M9G)O;3H`0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M97-S86=E
M/P!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT
M('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&]O<V4@06-T:6]N.@!#:&]O
M<V4@07!P;&EC871I;VXZ`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`
M0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D
M9')E<W-E<RX`0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,`0VQI8VL@
M=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:P!#
M;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S
M<V%G92!T;R!T:&4@<V5N9&5R`$-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I
M;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D`$-L;W-E`$-L;W-E(%=I
M;F1O=P!#;&]S960@1F]L9&5R`$-O;&QA<'-E($%L;`!#;VQL87!S92!!;&P@
M1F]L9&5R<P!#;VQL87!S92!&;VQD97(`0V]L;&%P<V4@4VED96)A<@!#;VQO
M<B!);F1I8V%T;W(Z(`!#;VUM96YT`$-O;7!A;GD`0V]M<&]S92!M97-S86=E
M<R!I;B!A('-E<&%R871E('=I;F1O=S\`0V]M<&]S92!M97-S86=E<R!W:71H
M(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@
M=&AE(&9E871U<F4I/P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#
M;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N`$-O;G1R;VP@
M4$=0('-U<'!O<G0@9F]R("5S+@!#;VYT<F]L(%,O34E-12!S=7!P;W)T(&9O
M<B`E<RX`0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E
M87)C:&EN9RX`0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME
M9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U('=H96X@
M:70@87)R:79E<RX`0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R
M87!H:6-A;"!O;F5S/P!#;W!Y`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0W)E871E
M`$-R96%T92!&;VQD97(`0W)E871E($ME>7,`0W)E871E(&$@3F5W($%C8V]U
M;G0`0W)E871E(&$@;F5W(%-P86T@9F]L9&5R`$-R96%T92!A(&YE=R!D<F%F
M=',@9F]L9&5R`$-R96%T92!A(&YE=R!O;F4`0W)E871E(&$@;F5W('-E;G0@
M;6%I;"!F;VQD97(`0W)E871E(&$@;F5W('1R87-H(&9O;&1E<@!#<F5A=&4@
M9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I
M;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L(&%N9"!D96QE=&4@<W!A;2X`0W)E
M871E(&YE=R!S=&%T:6]N97)Y`$-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M
M(')E<W!O;G-E<RX`0W)E871O<B!097)M:7-S:6]N<P!#=7)R96YT(%1I;64`
M0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@;W1H
M97(@86-C;W5N=',N`$-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"X`1$0`
M1&%I;'D`1&%T7V4`1&%T90!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I
M='D`1&5F875L="!396%R8V@@1FEE;&0`1&5F875L="!S;W)T:6YG(&-R:71E
M<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$96QE=&4`1&5L971E
M($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E;&5T92!396QE8W1E
M9"!&;VQD97)S`$1E;&5T92!3=&%T:6]N97)Y`$1E;&5T92!6:7)T=6%L($9O
M;&1E<@!$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V
M97(_`$1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN
M9R!O9B!M;VYT:#\`1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B
M96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$
M96QE=&4@<W!A;2!M97-S86=E<P!$96QE=&5D`$1E;&5T960@;65S<V%G97,`
M1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$97-C96YD:6YG`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',`1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&EM('-I
M9VYA='5R97,_`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@8V]N9FER;6%T:6]N(&%F
M=&5R('-E;F1I;F<@82!M97-S86=E/P!$:7-P;&%Y(&EN($)O9'D@;V8@365S
M<V%G90!$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_
M`$1I<W!L87D@=&AE(")%;7!T>2!3<&%M(B!L:6YK(&EN('1H92!M96YU8F%R
M/P!$:7-P;&%Y('1H92`B16UP='D@5')A<V@B(&QI;FL@:6X@=&AE(&UE;G5B
M87(_`$1I<W!O<VET:6]N`$1O($Y/5"!M871C:`!$;R!.;W0@0VAE8VL@1F]L
M9&5R*',I(&9O<B!.97<@36%I;`!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<`!$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&
M<F]M.B!C;VQU;6X`1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\`
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VYE`$1O=VYL;V%D`$1O=VYL;V%D
M("5S`$1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T`$1O=VYL;V%D($%L;"!!
M='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*0!$;W=N;&]A9"!&;VQD97(H<RD`
M1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%T`1&]W;FQO860@:6X@
M+GII<"!&;W)M870`1')A9G0`1')A9G1S(&9O;&1E<CH`12UM86EL($%D9')E
M<W,`15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D
M+@!%9&ET`$5D:70@0FQO8VL`161I="!&:6QT97)S`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@5FER='5A;"!&;VQD97(`161I="!O<'1I;VYS(&9O
M<CH`161I="!Y;W5R(&9I;'1E<B!R=6QE<P!%9&ET('EO=7(@<')E9F5R96YC
M97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+@!%;6%I;`!%
M;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+@!%;7!T>2!&;VQD97(H<RD`
M16UP='D@4V5L96-T960@1F]L9&5R<P!%;7!T>2!4<F%S:"!F;VQD97(`16UP
M='D@7U1R87-H`$5M<'1Y(')E<W5L="X`16YA8FQE(%!'4"!F=6YC=&EO;F%L
M:71Y/P!%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_`$5N86)L92!R:6=H
M="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N8W)?>7!T:6]N($]P=&EO;G,`16YC
M<GEP=&5D`$5N9"!F;W)W87)D960@;65S<V%G90!%;G1E<B!087-S<&AR87-E
M`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R`$5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R`$5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(`16YT:7)E
M($UE<W-A9V4`16YT<GD@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('1H92!A9&1R97-S(&)O;VL`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`
M179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M
M<&QE('9A;'5E<SH`17AP86YD($%L;`!%>'!A;F0@06QL($9O;&1E<G,`17AP
M86YD($9O;&1E<@!%>'!A;F0@3F%M97,`17AP86YD(&YA;65S(&EN('1H92!C
M;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H92!B86-K9W)O=6YD
M/P!%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN
M('1H92!F;VQD97)S('9I97<_`$9?971C:"!-86EL`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%X`$9E=&-H($UA:6P`1F5T8V@@36%I;"!I;B!A('-E<&%R871E
M('=I;F1O=S\`1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N/P!&971C
M:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,`1F5T8VAE9"`Q(&UE<W-A9V4@9G)O
M;2`E<P!&971C:&UA:6PZ(`!&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RX`
M1FE?;'1E<G,`1FEL90!&:6QE($UA;F%G97(`1FEL=&5R(&UE<W-A9V4@8V]N
M=&5N="!F;W(@<')O9F%N:71Y/P!&:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE
M9"!O;B!T:&ES('-Y<W1E;2X`1FEL=&5R<P!&:6QT97)S($Y/5"!!8W1I=F4`
M1FEN9`!&:7)S="!-86EL8F]X(%!A9V4`1FER<W0@4&%G90!&;U]R=V%R9`!&
M;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;@!&;VQD97(@3F%V:6=A=&]R
M`$9O;&1E<B!3=6UM87)Y`$9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H
M92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y`$9O<G=A
M<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&<F]?;0!&
M<F]M`$9R;VT@061D<F5S<P!&=6QL($1E<V-R:7!T:6]N`$9W9#H`1V5N97)A
M;"!/<'1I;VYS`$=E="!O;FQY(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2D`
M1VQO8F%L($]P=&EO;G,`1V\`1V\@=&\@365S<V%G90!';V]G;&4@4V5A<F-H
M`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!(15)%`$AE861E<G,`2&5L<`!(
M96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`
M2&ED9&5N`$AI9&1E;B!I;B!4:')E860@5FEE=P!(:61E($1E;&5T960`2&ED
M92!5;G-U8G-C<FEB960`2&]?;64`2&]M90!(;VUE($%D9')E<W,`2&]M92!0
M:&]N90!(;W)D90!(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM
M96YT<S\`2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R97!L
M>0!)34%0+U!/4#,@36%I;"!397)V97)S`$EC;VYS($]N;'D`26-O;G,@=VET
M:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@>6]U(&-O;G1I;G5E+"!A;&P@
M;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E(&QO<W0A`$EG;F]R
M90!)9VYO<F4@06QL`$EM86=E<P!);7!O<G0`26UP;W)T($ME>0!);7!O<G0@
M2V5Y<&%I<@!);7!O<G0@365S<V%G97,`26UP;W)T(%!E<G-O;F%L($-E<G1I
M9FEC871E`$EM<&]R="!0=6)L:6,@2V5Y`$EM<&]R="!0=6)L:6,@4$=0($ME
M>0!);7!O<G0@4'5B;&EC(%,O34E-12!+97D`26UP;W)T(%,O34E-12!+97D`
M26UP;W)T(&UB;W@@1FEL90!);7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L
M9&5R("5S+@!);7!O<G0L(%-T97`@)60`26UP;W)T86YT`$EM<&]R=&%N="!M
M97-S86=E<P!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!)
M;F)O>`!);F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN
M(&$@<F5P;'D_`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY
M/P!);F1I=FED=6%L(%5S97)S`$EN;&EN90!);G-E<G0@4'5B;&EC(%!'4"!+
M97D@2&5R90!);G9E<G0`2V5Y($QE;F=T:`!+97D@9V5N97)A=&EO;B!M87D@
M=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@
M:V5Y(&=E;F5R871I;VX_`$ME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`3&%?>6]U=`!,86YG=6%G90!,87-T($UA:6QB
M;W@@4&%G90!,87-T(%!A9V4`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87EO=70`3&EN:R!!='1A
M8VAM96YT<S\`3&ES="!(96QP(%1O<&EC<P!,:7-T(&%L;"!C;VYT86-T<R!W
M:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D
M+"!Y;W4@=VEL;"!O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@
M9F]R(&5X<&QI8VET;'DI`$QI<W1I;F<@:6X@=&AE($AE861E<@!,;V-A;"!-
M86EL8F]X.@!,;V-A;&4@86YD(%1I;64`3&]G(&EN`$QO9R!I;B!T;R`E<P!,
M;V<@;W5T`$QO9VEN(%1A<VMS`$U-`$UA:6P`36%I;"!S97)V97(@='EP92!T
M;R!C;VYN96-T('1O.@!-86EL8F]X`$UA:6QB;W@@86YD($9O;&1E<B!$:7-P
M;&%Y($]P=&EO;G,`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%R:R!!;&P@365S<V%G97,@
M:6X@1F]L9&5R(&%S(%-E96X`36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R
M(&%S(%5N<V5E;@!-87)K(&%S.@!-87)K(&1I9F9E<F5N="!L979E;',@;V8@
M<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA<FL@;65S<V%G97,@
M87,@<V5E;C\@*$E-05`@;VYL>2D`36%R:R!S:6UP;&4@;6%R:W5P/P!-871C
M:"!!;&P@475E<FEE<P!-871C:"!!;GD@475E<GD`36%T8VAI;F<@9FEE;&1S
M`$UA>&EM=6T@071T86-H;65N="!3:7IE`$UE;G4@;6]D93H`365S<V%G90!-
M97-S86=E($-O;7!O<VET:6]N`$UE<W-A9V4@1&%T90!-97-S86=E($]P=&EO
M;G,`365S<V%G92!396%R8V@`365S<V%G92!3:7IE`$UE<W-A9V4@4V]U<F-E
M`$UE<W-A9V4@5FEE=VEN9P!-97-S86=E(&9L86=S`$UE<W-A9V4@9F]L9&5R
M<P!-97-S86=E(&UA=&-H97,`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@
M8G5T(&YO="!S879E9"!T;R`E<P!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY
M+@!-97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W+@!-97-S
M86=E<R!T;P!-;V1I9GD`36]N=&AL>0!-;V]N(%!H87-E<P!-;W9E`$UO=F4@
M1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@<W!A;2!M
M97-S86=E<R!T;R!S<&%M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G97,@
M=&\@24Y"3U@`375L=&EP;&4@365S<V%G92!6:65W`$UY($%C8V]U;G0`37D@
M06-C;W5N="!);F9O<FUA=&EO;@!.3TY%`$Y/5$4`3F%M90!.979E<@!.979E
M<B!S879E(&%T=&%C:&UE;G1S`$YE=P!.97<@0V%T96=O<GD`3F5W($9O;&1E
M<@!.97<@36%I;`!.97<@365S<V%G90!.97<@;65S<V%G97,`3F5W<P!.97AT
M`$YE>'0@365S<V%G90!.97AT(%!A9V4`3F5X="!O<'1I;VYS`$YO`$YO($5N
M8W)Y<'1I;VX`3F\@2V5Y<R!I;B!+97ER:6YG`$YO($UE<W-A9V5S`$YO(%!E
M<G-O;F%L($-E<G1I9FEC871E(%!R97-E;G0`3F\@4'5B;&EC($ME>7,@1F]U
M;F0`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!M97-S86=E<R!M871C
M:&5D('EO=7(@<V5A<F-H+@!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@<W5G9V5S
M=&EO;G,`3F\@=F%L=65S`$YO;F4`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W0@
M1&5L971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`
M3F]T(&1E;&5T960@;65S<V%G97,`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.
M;W1E<P!.;W1H:6YG`$YU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E<B!O
M9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M
M;VYT:&QY+@!/2P!/4@!/;&0@;65S<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD
M97)S(&)E:6YG('!U<F=E9"X`3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U
M;G)E860@;65S<V%G97,@:6X@=&AE;3\`3W!E;B!&;U]L9&5R`$]P=&EO;G,`
M3W!T:6]N<R!F;W(@)7,`3W)G86YI>FEN9P!/=&AE<B!);F9O<FUA=&EO;@!/
M=&AE<B!-86EL($%C8V]U;G1S`$]T:&5R($]P=&EO;G,`4$=0($5N8W)Y<'0@
M365S<V%G90!01U`@17)R;W(Z(`!01U`@17)R;W(Z($YE960@<&%S<W!H<F%S
M92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN`%!'4"!/<'1I;VYS`%!'4"!0
M87-S<&AR87-E($EN<'5T`%!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@
M<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%!'4"!0=6)L:6,@
M2V5Y(%1E>'0`4$=0(%!U8FQI8R!+97D@9F]R("(E<R`H)7,I(B!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D+@!01U`@4'5B;&EC($ME>7)I;F<`4$=0(%-I9VX@
M365S<V%G90!01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4`4$=0('!R:79A=&4@
M:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`4$=0('!U8FQI8R!K97D@<W5C8V5S
M<V9U;&QY(&%D9&5D+@!01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES
M('-Y<W1E;2X`4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@
M<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I
M9FEE9"X`4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@
M=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`4$=0('-U
M<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@
M>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U
M<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L
M<V4@=&AE(%!'4"!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`
M4&%G92`E9"!O9B`E9`!086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S
M86=E`%!A9V4@=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G90!087)T*',I
M`%!A<W-P:')A<V4`4&%S<W!H<F%S92`H06=A:6XI`%!A<W-P:')A<V4Z`%!A
M<W-P:')A<V5S(&-A;FYO="!B92!E;7!T>0!087-S<&AR87-E<R!D;R!N;W0@
M;6%T8V@`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<P!097)S
M;VYA;`!097)S;VYA;"!);F9O<FUA=&EO;@!097)S;VYA;"!01U`@:V5Y<&%I
M<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0:&]N90!0;&%C92!Y;W5R('-I
M9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_`%!L87D@<V]U
M;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T
M;R!S=7!P;W)T(&5M8F5D9&5D('-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D
M;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL
M;"!R97%U:7)E(&$@<&QU9VEN+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@
M9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.@!0;&5A<V4@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9
M;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N
M8V4@<&5R("5S('-E<W-I;VXN`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O
M9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0`4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L
M:60@861D<F5S<V5S+@!0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y
M;W4@<&5R9F]R;2!A;GD@86-T:6]N<RX`4&QE87-E('-E;&5C="!A="!L96%S
M="!O;F4@9F]L9&5R('1O('-E87)C:"X`4&QE87-E('-E;&5C="!O;FQY(&]N
M92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+@!0<F5C961E('EO=7(@<VEG
M;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_`%!R979I;W5S($UE<W-A9V4`
M4')E=FEO=7,@4&%G90!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT`%!R;V)L96T`
M4')O8FQE;2!$97-C<FEP=&EO;@!0<F]M<'0@979E<GD@=&EM92!A;B!A='1A
M8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\`4')O;7!T(&5V97)Y('1I
M;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4P!0<F]T
M;V-O;#H`4'5R7V=E($1E;&5T960`4'5R9V4@1&5L971E9`!0=7)G92!&;VQD
M97(H<RD`4'5R9V4@5')A<V@@:&]W(&]F=&5N.@!0=7)G92!M97-S86=E<R!I
M;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES
M+@!0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\`475O
M=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I`%%U;W1I;F<@
M)68Z`%)E860`4F5B=6EL9"!&;VQD97(@5')E90!296-E:79E9"!/;@!296-E
M:79E9"!3:6YC90!296-E:79E9"!5;G1I;`!2961I<F5C7W0`4F5D:7)E8W0`
M4F5D:7)E8W0@365S<V%G90!2961I<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E
M8W1I;F<@9F%I;&5D+@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.@!2969R97-H($9O;&1E<B!6:65W<SH`4F5F<F5S:"!0;W)T86P@
M5FEE=SH`4F5L;V%D(%9I97<`4F5M96UB97(@=&AE(&QA<W0@=FEE=P!296UO
M=&4@36%I;&)O>#H`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`
M4F5M;W9E('!A:7(`4F5N86UE($9O;&1E<BAS*0!296YA;64@<V5N="UM86EL
M(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_`%)E;F%M:6YG("(E<R(@
M=&\@(B5S(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M4F5P;%]Y('1O($QI<W0`4F5P;&%C92!W:71H.@!297!L>0!297!L>2!T;R!!
M;&P`4F5P;'D@=&\@06QL.@!297!L>2!T;R!?06QL`%)E<&QY+51O`%)E<&QY
M+51O.B``4F5P;'DZ`%)E<&]R="!A<R!3<&%M`%)E<75E<W0@82!?4F5A9"!2
M96-E:7!T`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`4F5S970`4F5S=6UE`%)E
M='5R;B!T;R`B365S<V%G92!#;VUP;W-I=&EO;B(`4F5T=7)N('1O($9E=&-H
M($UA:6P`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O('1H92!M86EL8F]X
M(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A
M(&UE<W-A9V4_`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2;VQE`%,O34E-
M12!/<'1I;VYS`%,O34E-12!0=6)L:6,@2V5Y<FEN9P!3+TU)344@<W5P<&]R
M="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R
M(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I
M;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T
M:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+@!3
M7W5B:F5C=`!385]V92!A(&-O<'D@:6X@`%-A7W9E(&%S`%-A=F4`4V%V92!!
M='1A8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\`
M4V%V92!$<F%F=`!3879E($]P=&EO;G,`4V%V92!3=&%T:6]N97)Y`%-A=F4@
M7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@87,@=6YS965N/P!3879E(')E
M8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S
M(&)O;VL_`%-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_`%-A=F4@
M<V5N="!M86EL/P!3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@)7,`4V5A<F-H`%-E87)C:"`E<P!396%R
M8V@@3W!T:6]N<P!396%R8V@@4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@
M06YO=&AE<B!!8V-O=6YT`%-E;&5C="!A(&9I96QD`%-E;&5C="!A('-E<G9E
M<@!396QE8W0@82!S=&%T:6]N97)Y.@!396QE8W0@861D<F5S<R!B;V]K('-O
M=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N
M`%-E;&5C="!A;&P`4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@
M97AP86YD:6YG(&%D9')E<W-E<RX`4V5L96-T(&%N(&%C8V]U;G0`4V5L96-T
M(&YO;F4`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D
M871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C
M:&%N9V4Z`%-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP90!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;&5C=&5D($%D9')E<W,@8F]O:W,Z`%-E;F0@2V5Y('1O
M(%!U8FQI8R!+97ES97)V97(`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE;2!2
M97!O<G0`4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE
M('-E;F1E<C\`4V5N="!M86EL(&9O;&1E<CH`4V5R=F5R`%-E<G9E<B!A;F0@
M1F]L9&5R($EN9F]R;6%T:6]N`%-E<G9E<CH`4V5T('!R969E<F5N8V5S(&9O
M<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A
M9V5S+@!3970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@8V]M<&]S:6YG
M(&UE<W-A9V5S/P!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@
M>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@
M<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``
M4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\`4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@
M=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E
M('1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+@!3:&]U;&0@
M=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O
M<B!01U`@9&%T83\`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S
M960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W5L9"!Y;W5R(%!'4"!P=6)L
M:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F
M875L=#\`4VAO=P!3:&]W($%L;"!(96%D97)S`%-H;W<@1&5L971E9`!3:&]W
M($QI;6ET960@2&5A9&5R<P!3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO
M;@!3:&]W(%5N<W5B<V-R:6)E9`!3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R
M:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_`%-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E;F0@:6X@
M=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@
M8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!&
M971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&]T86P@;G5M
M8F5R(&]F(&UA:6QS(&EN(&9O;&1E<C\`4VAO=VX`4VAR:6YK`%-I7WIE`%-I
M9VYE9`!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4V]U=&AE<FX@2&5M:7-P:&5R
M90!3<&%M(&9O;&1E<CH`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!E8VEA
M;"!#:&%R86-T97)S`%-P96QL($-H96-K`%-P96QL($-H96-K97(`4W!E;&P@
M8VAE8VL@8V]M<&QE=&4`4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE
M;B!S<&5L;"!C:&5C:VEN9RX`4W1A=&EO;F5R>0!3=&%T:6]N97)Y(&YA;64Z
M`%-T871I;VYE<GD@='EP93H`4W1A=&EO;F5R>3H`4W1R:7`@071T86-H;65N
M=`!3=6)J96-T`%-U8FIE8W0@1FEE;&0`4W5B;6ET`%-U8G-C<FEB92!T;R!&
M;VQD97(H<RD`4W5C8V5S<P!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E
M<P!3=6=G97-T:6]N<P!3=6YR:7-E+U-U;G-E=`!3=VET8V@@=&\@2%1-3"!C
M;VUP;W-I=&EO;@!3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;@!4
M87-K<P!495]X=`!497AT`%1E>'0@3VYL>0!4:&4@1G)O;3H@8V]L=6UN(&]F
M('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z`%1H92!A8V-O=6YT("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E
M;B!S879E9"X`5&AE(&-U<G)E;G0@9F]L9&5R*',I("(E<R(@=VEL;"!B92!R
M96YA;65D('1O("(E<R(N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T
M<P!4:&4@9F]L9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S
M(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S
M964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B
M('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I
M="X`5&AE(&9O;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N
M;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@
M;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE
M(&9O;&1E<B`B)7,B('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL
M>2!C<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA
M;65D('1O("(E<R(N`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O
M;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@;6%I;&)O>"`E<R!I<R!A;')E
M861Y(&5M<'1Y+@!4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y
M(&-A;B!B92!V:65W960@)7,N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S
M:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"X`5&AE('1E>'0@
M;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RX`5&AE
M<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B`B)7,B+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&9L
M86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN
M9R!Y;W5R(&UE<W-A9V4Z("5S`%1H97)E('=A<R!N;R!T97AT(&EN('1H:7,@
M;65S<V%G92!P87)T`%1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB
M961D960@:6X@:70N`%1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB
M961D960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L:6ME('1H:7,Z
M(`!4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S
M<V%G92X`5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!C;VYT:6YU93\`5&AI<R!M97-S86=E(&AA<R!B965N(&1I
M9VET86QL>2!S:6=N960@=FEA(%!'4"X`5&AI<R!M97-S86=E(&AA<R!B965N
M(&5N8W)Y<'1E9"!W:71H(%!'4"X`5&AI<R!M97-S86=E('1O`%1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N`%1H<F5A9"!6:65W`%1I8VME=',`5&EM92!F;W)M870`5&ET
M;&4`5&\`5&\@061D<F5S<P!4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H
M:6QE(&-L:6-K:6YG+@!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H
M:6QE(&-L:6-K:6YG+@!4;W1A;"!!='1A8VAM96YT<R!3:7IE.@!4<F%S:"!F
M;VQD97(Z`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA;G-W97)E9`!5;F%N
M<W=E<F5D(&UE<W-A9V5S`%5N9&5L971E`%5N9&ES8VQO<V5D(%)E8VEP:65N
M=',`56YD;R!#:&%N9V5S`%5N9FEL960`56YN86UE9`!5;G-E96X`56YS=6)S
M8W)I8F4@9G)O;2!&;VQD97(H<RD`57!D871E`%5P;&]A9`!5<V4@1&5F875L
M="!686QU90!5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\`57-E(%9I
M<G1U86P@5')A<V@@1F]L9&5R/P!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R($]P=&EO;G,`57-E<FYA
M;64`57-E<FYA;64Z`%5S97)N86UE.B``5FEE=P!6:65W("5S`%9I97<@365S
M<V%G97,`5FEE=R!4:')E860`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&UE<W-A9V5S(&EN("5S`%9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN.@!6:7)T=6%L($9O;&1E<G,`5FER='5A;"!)3D)/6`!6
M:7)T=6%L($E.0D]8($9O;&1E<@!6:7)T=6%L(%1R87-H`%9I<G1U86P@5')A
M<V@@1F]L9&5R`%9I<G1U86P@9F]L9&5R(&QA8F5L`%=E8@!7965K;'D`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T('-H;W5L9"!W92!D;R!W
M:71H('-P86T@;65S<V%G97,@869T97(@=&AE>2!H879E(&)E96X@<F5P;W)T
M960@87,@<W!A;2!O<B!I;FYO8V5N=#\`5VAE;B!D96QE=&EN9R!M97-S86=E
M<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E860@;V8@
M;6%R:VEN9R!T:&5M(&%S(&1E;&5T960_`%=H96X@;W!E;FEN9R!A(&YE=R!M
M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N/P!7
M:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE
M;G0@9&%T83\`5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D9')E
M<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R!U;G%U86QI
M9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T(")`(BD_
M`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!A<F4@871T96UP
M=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@
M9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!A='1E;7!T:6YG('1O(&1E
M;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!C<F5A=&EN
M9R!A('-U8BUF;VQD97(@=&\@`%EO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V
M96P@9F]L9&5R+@!9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z(`!9;W4@
M:&%V92`E<R!N97<@;65S<V%G97,N`%EO=2!H879E(#$@;F5W(&UE<W-A9V4N
M`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@;F5W(&UA:6P@
M:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN
M('1H92!F;VQL;W=I;F<@9F]L9&5R<SH`66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'
M4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9;W4@;75S="!S
M96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="X`66]U(&UU<W0@<V5L96-T
M(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O
M;F4@;65S<V%G92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N
M="X`66]U(&YE960@=&\@:&%V92`B)7,B(&5N86)L960@:6X@>6]U<B!M86EN
M=&5N86YC92!O<'1I;VYS+@!9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@
M;VX@)7,N`%EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O("(E<R(N($AE<F4@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@;F]T('5N<W5B<V-R
M:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@(B5S(@!9;W4@
M=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(@!9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`
M66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!)
M;F9O<FUA=&EO;@!9;W5R($YA;64`66]U<B!01U`@4'5B;&EC+U!R:79A=&4@
M2V5Y<P!9;W5R(%!R:79A=&4@2V5Y`%EO=7(@4'5B;&EC($ME>0!9;W5R(%)E
M<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^`%EO=7(@4R]-
M24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<P!9;W5R(&%C8V]U;G1S
M.@!9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@
M96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3X`66]U<B!C=7)R96YT
M('1I;64@>F]N93H`66]U<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@
M;65S<V%G97,Z`%EO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@
M<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R
M(&9U;&P@;F%M93H`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9
M;W5R(')E;6]T92!S97)V97)S.@!9;W5R('-I9VYA='5R93H`6TYO(%-U8FIE
M8W1=`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES
M=')A=&EO;@!?0V,`7T1E;&5T90!?1F]L9&5R<P!?1W)O=7!S`%](96QP`%])
M9&5N=&ET>0!?26YB;W@`7TQO9R!O=70`7TUE<W-A9V4@4V]U<F-E`%].97<@
M365S<V%G90!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U!R:6YT`%]297!L>0!?
M4V5A<F-H`%]3971U<`!?5&AR96%D`%]4;P!?56YD96QE=&4`7U5S97)S`%]6
M:65W(%1H<F5A9`!B>71E<P!E9&ET`&9R;VT`;F]N90!O<@!S<&5L;&EN9R!E
M<G)O<@!S<&5L;&EN9R!E<G)O<G,`=6YN86UE9`!V0V%R9`!0<F]J96-T+4ED
M+59E<G-I;VXZ($E-4"!(,R!V-"XQ+5)#,PI297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-BTP,BTQ-R`Q-SHP,RLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M
M,3<@,3<Z,S`K,#(P,`I,87-T+51R86YS;&%T;W(Z($%L97AE>2!:86MH87)O
M=B`\8F%B97)`;6]S9V$N;F5T/@I,86YG=6%G92U496%M.B!2=7-S:6%N(#QI
M,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U,0I#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET"@`@("`@("#*[NSS.@`@("`@Q.#RX#H`
M("`@(,[R(.KNX^XZ`"#2Y>S@.B``(.(@`"5D(/'N[N'YY>WHZ0`E9"#O[B`E
M9"#HYR`E9"#Q[N[A^>7MZ.D`SN_E\.#VZ/\@[^[DY.7PYNKH("5S("T@S^[D
M\N+E\.;DY>WHY0`E<R#SYN4@\?/YY?+B\^7R+B#"X/C@("5S(._@[^K@(.WE
M(.'[Z^`@[^7PY>CLY>WNXN#MX"X`)7,@[^#OZN`@X?/DY?(@[^7PY>CLY>WN
MXN#MX"#B(.W@]^#KY2#LY?'_]N`N`"5S.B`E<R`H)60F;F)S<#OHYR9N8G-P
M.R5D*0`HT>[U\.#MZ/+\(.CG[.7MY>WH_R#H(._E\.7I\N@@Y.#KY>4I`"C.
M\NSE[>CR_"#B\>4@Z.?LY>WE[>C_(.@@[^7PY>GRZ"#J(/#EY.#J\NCP[N+@
M[>C^*0`HPN7P[?/R_/'_(.(@\.7DX.KR[O`L(/'N]?#@[>CB(.+MY?'E[>W[
MY2#HY^SE[>7MZ/\N*0`J(,3K_R#D[N'@XNOE[>C_(.W@YNSH\N4@3TL@*@`J
M(,_NYN#K\^GQ\N`@XOOAY?#H\N4@X.3PY?$HX"D@*@`Q,BWWX/'NXN[I`#(T
M+??@\>[B[ND`,C0@]^#QX`!!32]030#(`-/WY?+MX/\@Y^#OZ/'\`,_P[O3H
MZ_PZ`,3NX>#BZ/+\`,3NX>#BZ/+\.@#$[N'@XNCR_"#OX/#S`,3NX>#BZ/+\
M($UO>FEL;&$@4VED96)A<@#4X.GK("(E<R(@[_#HZO#E[^OE[2#J(._H\?SL
M\P#$[N_NZ^WH\N7K_.WN(.[R[N'PX.;@\OP@\>OEY//^^>CE(.?@X^[K[N+J
MZ#H@(#QE;3XH[>4@[N'_Y^#RY>O\[?LL(.K@YN3[Z2#Q(.WNXN[I(/'R\.[J
MZ"D\+V5M/@#$[N_NZ^WH\N7K_.W@_R#H[?3N\.S@]NC_(.[A(.[XZ.'JY0#$
M[N_NZ^WH\N7K_.W@_R#H[?3N\.S@]NC_(.[A(.[XZ.'JY2#L[N;E\B#A^_+\
M(._P[O'L[O+PY>W@("5S+@#`Y/#E\0#`Y/#E\>W@_R#J[>CCX`#`Y/#E\>W[
MY2#J[>CCZ`#-X._PX.+K__+\(.KN[^CH(.+QY?4@\>[NX?GE[>CI(.3@[>W[
M["#@Y/#E\>#RX.PZ("`\96T^*.WE(.[A_^?@\N7K_.W[+"#JX.;D^^D@\2#M
M[N+NZ2#Q\O#NZN@I/"]E;3X`P.3PY?'@+"#N\NWN\?_YZ.7Q_R#J(.3@[>WN
M[/,@[_#N].CK_CH@(#QE;3XH[>4@[N'_Y^#RY>O\[?LL(.K@YN3[Z2#Q(.WN
MXN[I(/'R\.[JZ"D\+V5M/@#-X/'R\.[IZN@@+2#S\?+@[>[BZN`@[_#@XB#D
MZ_\@Y/#SX^CU(._NZ_SG[N+@\N7KY>D`T^_PX.+KY>WHY0#/\>7BY.[MZ.P`
MPO'E`,+QY2#B[OCEY/CHY0#"\>4@X_#S[^_[`,+QY2#O\.#BX`#"\>4@\>[N
MX?GE[>C_(.(@\^K@Y^#M[>[I(._@[^KE*.#U*2#A\^3S\B#OY?#E[.7YY>W[
M(.(@].#IZR!-0D]8.@#"\>4@\>[NX?GE[>C_(.(@(,+@^.7I(._@[^KE("(E
M<R(@\?+@\/CE("5S(.3M_RCD[>7I*2#A\^3S\B#S[>CW\N[FY>WM^RX`PO'E
M(._@[^KH(.[R[_#@XNOE[>W[]2#Q[N[A^>7MZ.D@\?+@\/CE("5S(.SE\?_V
MY>(@X?/D\_(@\^3@Z^7M^RX`T.#G\.7XZ/+\(.[OY?#@]NCH(/'N(/'OZ/'J
MX.SH`,#K_/+E\.W@\NCB[?OI($E335``S^#P[NO\.@#([/\@[^[K_.?NXN#R
MY>O_($E335`Z`,#K_/+E\.W@\NCB[?OI(.+HY"#]\N[C[B#Q[N[A^>7MZ/\Z
M`,+QY>/DX"#Q[O7PX.W_\OP@XNONYN7MZ/\`P?OK[B#SZN#GX.WN(.WEZN[P
M\.7J\NWNY2#G[>#WY>WHY2X`SO+BY??E[>W[Y0#.\N+E]^7M[?OE(/'N[N'Y
MY>WH_P#/\.CK[N;E[>CE`,W@\?+P[N7M[@#"ZNO^]^CR_"#TZ.O\\O#@]NC^
M`,+JZ_[WZ/+\(/3HZ_SR\.#VZ/X@Y.O_("5S`,_PZ.SE[>CR_"#O\.#BZ.O@
M(/3HZ_SR\.#VZ.@@[_#H(.+U[N3E(.(@\>CQ\N7L\P#/\.CLY>WH\OP@[_#@
MXNCKX"#TZ.O\\O#@]NCH(._PZ"#NX>WNXNOE[>CH(._N]_+NXN[C[B#_^>CJ
MX"X`POL@\^+E\.7M^RP@]_+N(/7N\NCRY2#QY.7KX/+\(/WR[C\`POL@\^+E
M\.7M^RP@]_+N(/7N\NCRY2#QY.7KX/+\(/WR[C\`POL@\^+E\.7M^RP@]_+N
M(/7N\NCRY2#.RL[-U\#2Q<O<S<X@\^3@Z^CR_"#]\N@@\>[NX?GE[>C_/P#"
M^R#SXN7PY>W[+"#W\NX@]>[RZ/+E(,[*SLW7P-+%R]S-SB#SY.#KZ/+\(/WR
MZ"#BZ^[FY>WH_S\`POL@\^+E\.7M^RP@]_+N(/7N\NCRY2#N]^CQ\NCR_"#]
M\O,@[^#OZO,_`,+[(//BY?#E[?LL(/?R[B#U[O+H\N4@[O?H\?+H\OP@ZN[P
MY^CM\S\`POL@\^+E\.7M^RP@]_+N(/7N\NCRY2#.RL[-U\#2Q<O<S<X@\^3@
MZ^CR_"#]\N@@\>[NX?GE[>C_/P#"\.7L_R#O[NOS]^7MZ/\`S^X@XN[G\.#Q
M\N#MZ/X`T>_PX/CHXN#R_`#'X._PX/CHXN#R_"#O[N3RXN7PYN3E[>CE(._E
M\.7D(.+[[^[K[>7MZ.7L(.[OY?#@]NCI(.[A\>OSYNCBX.WH_S\`S_#HZO#E
M[^CR_`#/\.CK[N;H\OP@ZB#OZ/'\[/,@ZN[OZ/X@[_/AZ^CW[>[C[B!01U`@
MZNO^]^`_`,_PZ.KPY>_KY>WM^^4Z`,+K[N;E[>CE`,+K[N;E[>CE("5S(//D
MX.OE[>X`PNONYN7MZ.4@[>4@\>[U\.#M_^ON\?PL(/+H[P#"Z^[FY>WH_P#/
M[N_[\NK@(//DX.OH\OP@[>7Q\_GE\?+B\_[YZ.4@[_#@XN``S^[O^_+JX"#P
MY>3@ZO+H\.[BX/+\(.WE\?/YY?'RXO/^^>CE(._PX.+@`,[R[N'PX.;@\OP@
MZN#P\NCMZN@@XB!(5$U,(/'N[N'YY>WH__4@Y.O_(.#D\.7QX/+NXB#HYR#@
MY/#E\>WNZ2#J[>CCZ`#$[O'R\^_M^^4@[^[K_SH`PN7P[?/R_/'_(.(@)7,`
MPN7P[?/R_/'_(.(@)7,`R.WDY>KQ`$)C8P#$Y>W\(/#NYN3E[>C_`-?E\.W[
MZ2#Q[^CQ[NH`S>#Q\O#NZ>K@.@#0X/'XZ/#E[>CE`,WE(.[R[N'PX.;@\OP@
MZN#P\NCMZN@@XB!(5$U,(/'N[N'YY>WH__4`TN7J\?(@\>[NX?GE[>C_`,+L
MY?'RY0#"(.?@X^[K[N+JY2#H(.(@\N7KY2#Q[N[A^>7MZ/\`RN[DZ/#NXNK@
M`,7FY>WEY.7K_.WHZ@#.\NSE[>``SO+LY>WH\OP@[O+O\.#BZO,`SO+LY>W@
M(.[R]^7RX"#N(._P[N'KY>SE`,_PZ"#N\NSE[>4@[O+O\.#BZN@@_?+NX^X@
M\>[NX?GE[>C_(.+QY2#EX^X@\>[DY?#FX.WHY2#A\^3E\B#S\N7P_^WN+@#*
MX/+EX^[PZ.@@Z"#LY?+JZ`!#8P#*Z^7R[O?MX/\@\.#DZ.[QXO_G_`#(Y^SE
M[>CR_`#(Y^SE[>CR_"#"\>4`R.?LY>WH\OP@[^#OZO,`S>#Q\O#NZ>KH(._P
M[O'L[O+PX"#Q[N[A^>7MZ.DN("C*[NOH]^7Q\N+N(/'N[N'YY>WHZ2#MX"#Q
M\O#@[>CVY2P@[^[P_^3NZB#Q[O#RZ/#NXNKH+BD`S>#Q\O#NZ/+\(._@[^KH
M(.3K_R#PX.?KZ/?M^_4@[?/FY`#-X/'R\.[IZN@@Z.SE[>@L(.#D\.7QX"P@
M[^[D[^CQZ"X`S>#Q\O#NZ>KH(.CLY>WH+"#@Y/#E\>`L(._NY._H\>@N`,_P
M[N+E\.CR_"#O[O?R\R#B(._@[^KE*.#U*0#"^^3EZ^CR_"#B\>4`Q^#A\.#R
M_"#O[O?R\R#Q(//JX.?@[>W[]2#O[O?R[N+[]2#QY?#BY?#NXCH`S_#NXN7P
M__+\(.[P].[C\.#TZ/X@[^7PY>0@[O+O\.#BZN[I`,[R[.7R_/+E(/3KX.;J
MX.SH(.[OY?#@]NC^*.CH*2P@ZN[R[O#[Y2#"^R#U[O+H\N4@[O'S^>7Q\N+H
M\OPN`,3EZ?'RXNCE.@#"^^'E\.CRY2#O\.CK[N;E[>CE.@#4[O#LX/(@[O+N
MX?#@YN7MZ/\@Y.#R^SH`POOAY?#H\N4@X.3PY?'M\_X@ZNWHX_,@Y.O_(.3N
MX>#BZ^7MZ/\@XB#MY>4@X.3PY?'NXBX`S>#FYNCRY2#GY.7Q_"#W\N[A^R#3
MPLC$Q=+<(.CG[N'PX.;E[>C_+@#-X.;LZ/+E(.?DY?'\(/?R[N'[(.?@[^CQ
MX/+\(._SX>OH]^W[Z2#JZ_[W(.(@X.3PY?'M\_X@ZNWHX_,`T>[GY.#MZ.4@
M[>[B[N/N(/'N[N'YY>WH_R#DZ_\@Y.#M[>[C[B#@Y/#E\>#RX`#.\NKP^_+H
MY2#B]>[D__GEX^X@[^CQ_.S@`,?@ZO#[\OP`Q^#J\/OR_"#NZNWN`,?@ZO#[
M\N#_(._@[^K@`-'BY?#M\_+\(.+QY0#1XN7P[?/R_"#B\>4@[^#OZN@`T>+E
M\.WS\OP@[^#OZO,`T^'PX/+\(.SE[?X`UN+E\N[B[ND@Z.WDZ.K@\N[P.@#*
M[NSLY>WRX/#HZ0#*[NSOX.WH_P#1[N?DX.+@\OP@[>[B[N4@[^CQ_.SN(.(@
M[O+DY>O\[>[L(.[J[>4`PNKK_O?H\OP@XNCG\^#K_.W[Z2#PY>3@ZO+N\"#O
M[B#S[.[K]^#MZ/X`RN[M].CC\_#@]NC_(//Q\N#PY>O@`,W@\?+P[NGJX"#P
MY>;H[.[B(.[R[N'PX.;E[>C_(/'N[N'YY>WHZ0#/[N3DY?#FZN`@]//MZO;H
MZ2!01U`@Y.O_("5S`,_NY.3E\.;JX"#T\^WJ]NCI(%,O34E-12#DZ_\@)7,`
MS>#Q\O#NZ>K@(._@\.#LY?+P[N(L(/'B_^?@[>W[]2#Q(._NZ/'J[NP@\>[N
MX?GE[>CI`,W@\?+P[NGJZ"#O\.[BY?#JZ"#O[O?R^R#H(.CGXN7YY>WHZ2#N
M(.WNXN[I(._N]_+E+@#*[NWBY?#RZ/#NXN#R_"#RY>KQ\N[B^^4@_>SN]NCH
M(.(@X_#@].CWY?'JZ.4_`,KN[^CP[N+@\OP`SOCHX>K@`,_P[N+E\.7M[?OI
M(/+EZO'R`,WE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S
M:R`E<P#1[N?DX/+\`-'NY^3@\OP@[^#OZO,`T>[GY.#R_"#JZ_[WZ`#1[N?D
MX/+\(.WNXOOI`-'NY^3@\OP@[>[B\_X@[^#OZO,@Y.O_(/'OX.S@`-'NY^3@
M\OP@[>[B\_X@[^#OZO,@Y.O_(/?E\.WNXNCJ[N(`T>[GY.#R_"#M[N+[Z2#O
M\.[TZ.O\`-'NY^3@\OP@[>[B\_X@[^#OZO,@Y.O_(.[R[_#@XNOE[>W[]2#Q
M[N[A^>7MZ.D`T>[GY.#R_"#M[N+S_B#J[O#GZ.WS`-'NY^3@[>CE(/3HZ_SR
M\.[B(.3K_R#B]>[D__GEZ2#O[O?R^RP@\>[P\NCP[N+JX"#O[O?R^R#B(._@
M[^K@]2P@\^3@Z^7MZ.4@\>_@[.`N`-'NY^3@\OP@[>[B^^D@^.#AZ^[M`-'N
MY^3@\OP@^.#AZ^[M^P#1[N?DX/+EZ_P`TN7J\_GEY2#B\.7L_P#-X/'R\.[I
MZN`@XN[G[.[F[>[Q\N@@\>'N\.`@[^[W\OL@\2#BX/CH]2#O[O?R[N+[]2#_
M^>CJ[N(L(/#@\>_NZ^[FY>WM^_4@[>`@Y/#SX^CU(/'E\.+E\.#U`,W@\?+P
M[NGJX"#PY>;H[.[B(/'N\?+@XNOE[>C_(.WNXOOU(/'N[N'YY>WHZ2P@\>[U
M\.#MY>WH_R#WY?#M[N+HZN[B`,3$`,7FY>3MY>+M[@#$X/+@`,3@\N``UN+E
M\B#O[B#S[.[K]^#MZ/X`S_#N].CK_"#O[B#S[.[K]^#MZ/X`S^[KY2#O[NCQ
MZN`@[^X@\^SNZ_?@[>C^`-'N\/+H\.[BZN`@[^X@\^SNZ_?@[>C^.@#/[O#_
MY.[J(/'N\/+H\.[BZN@`T^3@Z^CR_`#3Y.#KZ/+\(/+EZO/YZ.4@ZNO^]^@`
MT^3@Z^CR_"#OX._J\RCH*0#3Y.#KZ/+\(.+[X?#@[>W[Y2#OX._JZ`#3Y.#K
MZ/+\(/C@X>ON[0#3Y.#KZ/+\(.+H\/+SX.O\[?/^(._@[^KS`-/DX.OH\OP@
M[_#H[?_R^^4@\>[NX?GE[>C_(/'N(/'R[O#N[>WEX^X@\>7PXN7PX`#3Y.#K
M__+\(/'RX/#[Y2#BZ^[FY>WH_R#B(.W@]^#KY2#LY?'_]N`_`-/DX.O_\OP@
M[^#OZO,@[O+O\.#BZ^7M[?OU(/'N[N'YY>WHZ2#B(.W@]^#KY2#LY?'_]N`_
M`-/DX.OH\OP@XOOA\.#M[?OI(._P[O3HZ_P`T^3@Z__R_"#Q[^#L`-/DX.OE
M[>W[Y0#3Y.#KY>WM^^4@\>[NX?GE[>C_`-/DX.OE[>W[Y2#Q[N[A^>7MZ/\`
MS^X@\^'[XN#MZ/X`SN_H^.CRY2#O\.[AZ^7L\P#.[^CQX.WHY0#([?3N\.S@
M]NC_`,_NY/#NX>WN\?+H(.'[Z^@@Y^#OZ/'@[?L@XB#F\_#MX.L@Y.O_(.#D
M[.CMZ/'R\.#R[O#@+@#.\O+E[?_R_"#O[N3OZ/'H/P#*X/+@Z^[C`,[A[NON
M]^K@`,[R[N'PX.;@\OP@XO#E[/\@XB`R-"WWX/'NXN[L(/3N\.S@\N4_`,3P
M\^/HY2#MX/'R\.[IZN@`SO+NX?#@YN#R_"#O[N3RXN7PYN3E[>CE(._N\>OE
M(.[R[_#@XNKH(/'N[N'YY>WH_P#"(/+EZ^4@\>[NX?GE[>C_`,[R[N'PX.;@
M\OP@XO'OZ_OBX/[YY>4@\>[NX?GE[>CE(._PZ"#O\.CU[N3E(._N]_+[/P#.
M\N[A\.#FX/+\(.KM[N_J\R`GSO?H\?+H\OP@T>_@["<@XB#BY?#U[>7L(.SE
M[?X_`,[R[N'PX.;@\OP@ZNWN[^KS("?.]^CQ\NCR_"#J[O#GZ.WS)R#B(.+E
M\/7MY>P@[.7M_C\`TNCO(.+K[N;E[>C_`,W%(/'NXN_@Y.#E\@#-Y2#O\.[B
MY?#_\OP@[^#OZO,HZ"D@[>`@[>[B\_X@[^[W\O,`S>4@XOOG^^+@Z?+E(&UA
M:6YT96YA;F-E+G!H<"#MY>_N\?#EY/'RXN7M[>X`S>CJX.KNX^X@Y.7I\?+B
MZ/\`POL@]>[RZ/+E(.[RZO#[\OP@_?+S(._@[^KS/P#"(._E\.+NZ2#Q\O#N
MZN4@\^K@Y^#M^R#H[.7MX"#O[NOEZ3\@Q?'KZ"#DX"P@[^[Q\N#B_/+E(./@
MZ^[WZO,Z(`#"^^_NZ^WE[>X`Q^#C\//GZ/+\`,?@X_#SY^CR_"`E<P#'X./P
M\^?H\OP@)7,@XB#@\/7HX@#'X./P\^?H\OP@XO'E(.+K[N;E[>C_(.(@X/#U
MZ.(`Q^#C\//GZ/+\(._@[^KS*.@I`,?@X_#SY^CR_"#OX._J\RCH*2#B(.#P
M]>CB`,?@X_#SY^CR_"#B(.#P]>CB`-?E\.WNXNCJZ`#/X._JX"#WY?#M[N+H
MZN[B.@#`Y/#E\2!%+6UA:6P`SMC(P<K`.B#"X/CE(/'N[N'YY>WHY2#MY2#A
M^^ON(.3N\?+@XNOE[>X@[^[K\_?@\N7K_@#0Y>3@ZO+H\.[BX.WHY0#0Y>3@
MZO+H\.[BX/+\`-#EY.#J\NCP[N+@\OP@].CK_/+P^P#3\?+@[>[BZN`@[_#@
MXB#DZ_\@)7,`T.7DX.KRZ/#NXN#R_"#BZ/#R\^#K_.WS_B#OX._J\P#-X/'R
M\.[IZN@`T.7DX.KRZ/#NXN#MZ.4@PN#XZ/4@[_#@XNCK(/3HZ_SR\.#VZ.@`
MT.7DX.KRZ/#NXN#R_"#MX/'R\.[IZN@@\>'N\.`@[^[W\OL@\2#D\//CZ/4@
M\>7PXN7P[N(`16UA:6P`SO?H^>7M^R#B\>4@\>[NX?GE[>C_(.CG("5S`,[W
MZ/'RZ/+\(._@[^KS*.@I`,[WZ/'RZ/+\(.+[X?#@[>W[Y2#OX._JZ`#.]^CR
MZ/+\(.KN\.?H[?,`SO?H\NCR_"#J[O#GZ.WS`,WSZ^7B[ND@\.7G\^O\\N#R
M+@#"ZNO^]^CR_"#O[N3DY?#FZO,@4$=0/P#"ZNO^]^CR_"!3+TU)344`RN[M
M\N7J\?+M[N4@[.7M_B#O[B#MX.;@\NCH(._PX.+NZ2#J[>[OZN@@[/OXZ`#8
MZ/3P[N+@[>CE`,?@^.CT\.[BX.WN`,KN[>7V(._E\.7Q^^O@Y>SNX^X@\>[N
MX?GE[>C_`,+BY?'RZ"#OX/#NZ_P`PN+EY.CRY2#H[/\@[>[B[ND@[^#OZN@@
MY.O_(/?E\.WNXNCJ[N(`PN+EY.CRY2#H[/\@[>[B[ND@[^#OZN@@Y.O_(.[R
M[_#@XNOE[>W[]2#Q[N[A^>7MZ.D`PN+EY.CRY2#H[/\@[^#OZN@@Y.O_(,+@
M^.7I(.WNXN[I(.KN\.?H[?L`T>[NX?GE[>CE(/;EZ^CJ[NP`Q^#OZ/'\("(E
M<R(@X?OKX"#D[N'@XNOE[>`@XB#@Y/#E\>WS_B#J[>CC\P#.^.CAZN``RN#F
MY/OE(#$U(.SH[?/R`,K@YN3[Y2`R(.SH[?/R^P#*X.;D^^4@,S`@\>7J\^WD
M`,K@YN3[Y2`U(.SH[?/R`,K@YN3[Z2#PX.<@[_#H(.+U[N3E`,K@YN3[Y2#O
M[NOWX/'@`,K@YN3S_B#LZ.WS\O,`S_#H[.7P(.?MX/?E[>CI.@#0X.?BY?#M
M\_+\(.+QY0#0X.?BY?#M\_+\(.+QY2#OX._JZ`#0X.?BY?#M\_+\(._@[^KS
M`-#@Y^+E\.WS\OP@Z.SE[>``T.#GXN[PX/?HXN#R_"#H[.7MX"#@XO+N[.#R
MZ/?E\>KH`-#@Y^+E\.WS\OP@Y.7PY>+N(._@[^[J(._N(//L[NOWX.WH_C\`
MT>'N\`#"[O'Q\N#M[N+KY>WHY2#MX/'R\.[EZB#MY2#SY.#K[O'\+@#-Y?/D
MX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N`-3@ZO$`T>'N\`#1
M[N'H\.#R_"#O[O?R\R#B(.[RY.7K_.WN["#NZNWE+@#/\.CM__+\(/'N[N'Y
MY>WH_R#O\.@@XO7NY.4@XB#QZ/'RY>SS`,_PZ.W_\NX@)60@[^CQY>P@Z.<@
M)7,`S_#H[?_R[B`Q(/'N[N'YY>WHY2#N\B`E<P#1X>[P(._N]_+[.B``Q.O_
M(,+@\2#MY?(@[>[B^_4@\>[NX?GE[>CI+@#4Z.O\\O#[`-3@Z>L`U?#@[>CK
MZ/G@`-3HZ_SR\.[BX/+\(/'NY.7PYNCL[N4@\>[NX?GE[>CI/P#/[N3DY?#F
MZN`@].CK_/+PX/;HZ"#B(.+@^.7I(/'H\?+E[.4@[>4@XNKK_O?E[>``U.CK
M_/+P^P#4Z.O\\O#@]NC_(,[2RLO>U\7-P`#-X.GRZ`#/Y?#BX/\@\?+PX.WH
M]N``S^7PXN#_(/'R\.#MZ/;@`,_E\.7QZ^#R_`#/[N3RXN7PYN3E[>CE(.3E
MZ?'RXNC_(/$@[^#OZN[I`,W@XNCCX/+N\"#OX._NZ@#1\N#RZ/'RZ.K@`-3N
M\.S@\B#N\N[A\.#FY>WH_R#DX/+[(.3K_R#Q[N[A^>7MZ.DL(._PZ/CEY/CH
M]2#QY>/NY.W_`,_E\.7QZ^#R_`#/Y?#E\>O@\OPZ`,_E\.7O\.#BZ^7M[N4@
M\>[NX?GE[>CE(.[R("5S`,[R(.KNX^X`SO(@ZN[C[@#`Y/#E\2#N\N_PX.+H
M\N7K_P#/[NOM[N4@[N_H\>#MZ.4@[_#NX>OE[/LZ`$9W9#H`SN'YZ.4@[>#Q
M\O#NZ>KH`,_NZ_/WZ/+\(/+NZ_SJ[B#M[N+[Y2#Q[N[A^>7MZ/\@*.3K_R!)
M34%0*0#/[O#RX.L`S^7PY>GRZ`#/Y?#EZ?+H(.H@[^CQ_.SS`,_NZ/'J(.(@
M1V]O9VQE`,/P\^_O^P##[O'R_`#'Q,71W`#'X./NZ^[BZN@`S^[D\>K@Y^K@
M`,_NZ_/XX/#HY0#-Z.;E(._PY>3Q\N#BZ^7MX"#H[?3N\.S@]NC_(.CG(/'@
M[.[C[B#MX/?@Z^`@].#IZ^`Z`-'J\/OBX/+\`-'J\/OBX/+\(._PZ"#C\//O
M[^CP[N+JY0#1ZO#[\OP@\^3@Z^7M[?OE`-'J\/OR_"#MY>_NY._H\>#M[?OE
M`,_N\/+@ZP#/[O#RX.L`Q.[LX/CMZ.D@X.3PY?$`Q.[LX/CMZ.D@\N7KY?3N
M[0#/[O#RX.L`RN#JZ.P@[N'PX.?N["#N\N[A\.#FX/+\(.+K[N;E[>C_/P#*
MX.KH["#NX?#@Y^[L(._N[.7WX/+\(.+Q\N#BZ^7M[?OI(.(@[O+BY?(@[O#H
MX^CMX.O\[?OI(/+EZO'R.@#1Y?#BY?`@4$]0,R])34%0`-+NZ_SJ[B#HZN[M
MZN@`R.KN[>KH(/$@\N7J\?+N[`#([/\@[_#N].CK_SH`Q?'KZ"#B^R#O\.[D
M[NOFZ/+E+"#B\>4@\>[NX?GE[>C_(.(@[^#OZN4@X?/D\_(@\_+E\/_M^R$`
MR./M[O#H\.[BX/+\`,CC[>[PZ/#NXN#R_"#B\>4`RN#P\NCMZN@`R.SO[O#R
MZ/#NXN#R_`#([._N\/+H\.[BX/+\(.KK_O<`R.SO[O#RZ/#NXN#R_"#OX/#S
M`,CL[^[P\NCP[N+@\OP@\>[NX?GE[>C_`,CL[^[P\NCP[N+@\OP@[^7P\>[M
MX.O\[?OI(/'E\/+H].CJX/(`R.SO[O#RZ/#NXN#R_"#O\^'KZ/?M^^D@ZNO^
M]P#([._N\/+H\.[BX/+\(._SX>OH]^W[Z2#JZ_[W(%!'4`#([._N\/+H\.[B
MX/+\(._SX>OH]^W[Z2#JZ_[W(%,O34E-10#([._N\/+H\.[BX/+\(.KK_O<@
M4R]-24U%`,CL[^[P\NCP[N+@\OP@[^[W\N[B^^D@__GHZ@#([._N\/+H\.[B
MX/+\(/3@Z>L@)7,@XB#_^>CJ("5S`,CL[^[P\BP@^.#C("5D`,+@YNW[Y0#"
MX.;M^^4@\>[NX?GE[>C_`,CL[^[P\NCP[N+@[>X@[^[KY3H@)7,`R.SO[O#R
MZ/#NXN#M^R#O[NO_.@#"]>[D__GHY0#"ZNO^]^#R_"#WX/'R_"#GX./NZ^[B
MZN`@[^CQ_.S@(._PZ"#N\N+E\N4`PNKK_O?@\OP@\N7J\?(@[O#HX^CMX.O\
M[>[C[B#Q[N[A^>7MZ/\@[_#H(.[RXN7RY0#/[NO\Y^[BX/+EZ^@`XB#RY>KQ
M\@#"\?+@XOSRY2#O\^'KZ/?M^^D@4$=0(.KK_O<@\O/R`,CMXN7P\NCP[N+@
M\OP`Q.OH[>`@ZNO^]^``P^7MY?#@]NC_(.KK_O?EZ2#L[N;E\B#GX.W_\OP@
M[N_PY>3EZ^7M[>[E(.+PY>S_+B#1X^7MY?#H\.[BX/+\(.KK_O?H/P#*Z_[W
M(//Q[^7X[>X@[^[QZ^#M(.W@(._SX>OH]^W[Z2#QY?#BY?``T.#QZNO@Y.K@
M`-_G^^H`S^[QZ^7D[?__(/'R\.#MZ/;@`,_N\>OEY.W__R#Q\O#@[>CVX`#/
M\.7D^^3S^>CI(.+U[N0@X?OK.B`E<P#/\.7D^^3S^>CI(.+U[N0@X?OK.B`E
M<R#Q(.KN[._\_O+E\.`@)7,`S_#EY/OD\_GHZ2#B]>[D(.WE(.?@].CJ\>CP
M[N+@[0#"^_7NY`#.\N_PX.+K__+\(.+K[N;E[>C_(.K@ZB#Q\?OKZN@`T>_H
M\>[J(/#@Y^3EZ^[B(._NY/'JX.?JZ`#.\N[A\.#FX/+\(.(@X.3PY?'M[ND@
MZNWHX^4@XO'E(.KN[?+@ZO+[/P#"(.?@X^[K[N+JY2#Q[N[A^>7MZ/\`S^#O
MZN`@[>`@Z^[JX.O\[>[L(/'E\.+E\.4Z`,ONZN#KZ.?@]NC_`,+U[N0`PN[I
M\N@@XB`E<P#"^_7NY`#"]>[D`,S,`,_N]_+@`-+H[R#Q\N[P[NWMY>/N(._N
M]_+NXN[C[B#QY?#BY?#@.@#?^>CJZ`#/X/#@[.7R\/L@[O+NX?#@YN7MZ/\@
M[^#O[NH`S>#Q\O#NZ>K@(/'OZ/'JX"#JX/+EX^[PZ.D@Z"#VXN7R[N(@Z/4@
M[O+NX?#@YN7MZ/\`S^[LY?+H\OP@XO'E(/'N[N'YY>WH_R#JX.H@[_#N]^CR
MX.WM^^4`S^[LY?+H\OP@XO'E(/'N[N'YY>WH_R#JX.H@[>7O\.[WZ/+@[>W[
MY0#.\NSE\NCR_"#JX.HZ`,+[Y.7K__+\(/;BY?+@[.@@\.#G[?OE(//P[N+M
MZ"#VZ/+H\.[BX.WH_P#/[NSE\NCR_"#Q[N[A^>7MZ/\@ZN#J(._P[O?H\N#M
M[?OE("CDZ_\@24U!4"D`S^[LY??@\OP@[_#N\?+S_B#PX.?LY?+J\S\`S^X@
MPM'%S"#J\.CRY?#H_^P`S^X@R][!SLS3(.KPZ/+E\.C^`-'NXN_@Y.#^^>CE
M(._NZ_\`S.#J\>CLX.O\[?OI(/#@Y^SE\"#BZ^[FY>WHZ0#0Y>;H["#LY>W^
M.@#1[N[A^>7MZ.4`T>[Q\N#BZ^7MZ.4@\>[NX?GE[>C_`,+PY>S_(.[R[_#@
MXNKH`,W@\?+P[NGJZ"#Q[N[A^>7MZ.D`S^[H\>H@\>[NX?GE[>C_`-#@Y^SE
M\"#Q[N[A^>7MZ/\`R/'U[N3MZ.H`S_#N\>SN\O`@\>[NX?GE[>C_`,_N[.7R
MZN@@\>[NX?GE[>C_`,_@[^KH(/'N[N'YY>WHZ0#1[N+OX.3E[>CE.@#1[N[A
M^>7MZ.4@\_'OY?CM[B#N\N_PX.+KY>WN+"#M[B#MY2#Q[O7PX.WE[>X@XB`E
M<P#1[N[A^>7MZ.4@\_'OY?CM[B#N\N_PX.+KY>WN+@#1ZN[K_.KN(/'N[N'Y
MY>WHZ2#N\N[A\.#FX/+\(.W@(/'R\.#MZ/;E`-'N[N'YY>WH_R#B`-#EY.#J
M\NCP[N+@\OP`Q>;E[.7Q__?M[@#4X.?[(,OS[?L`S^7PY>SE\?+H\OP`[^7P
MY>SE\?+H\OP@XNWHYP#OY?#E[.7Q\NCR_"#BZ^7B[@#OY?#E[.7Q\NCR_"#B
M[_#@XNX`[^7PY>SE\?+H\OP@XN+E\/4`S^7PY>SE^>#R_"#Q[^#L(.(@\>_E
M]NC@Z_SM\_X@[^#OZO,L(.`@[>4@\>_@["#B[B#"]>[D__GHY0#/\.[Q[.[R
M\"#Q[N[A^>7MZ.D`T_?E\NW@_R#GX._H\?P`PN#XX"#H[?3N\.S@]NC_`"T@
M[>7R("T`UB[3+@#([/\`S>CJ[N/DX`#-Z.KNX^3@(.WE(/'N]?#@[?_R_"#B
MZ^[FY>WH_P#-[N+[Y0#-[N+@_R#JX/+EX^[PZ/\`S>[BX/\@[^#OZN``S>[B
MX/\@[^[W\N``S>#OZ/'@\OP`S>[B^^4@\>[NX?GE[>C_`,WNXN[Q\N@`Q.#K
MY>4`T>OEY//^^>7E(/'N[N'XY>WHY0#1Z^7D\_[YY?\@\?+PX.WH]N``T>OE
MY//^^>#_(/'R\.#MZ/;@`,WE\@#!Y><@^.CT\.[BX.WH_P#-Y?(@ZNO^]^7I
M(.(@\>+_Y^KE`,WE\B#Q[N[A^>7MZ.D`S>7R(._E\/'N[>#K_.W[]2#QY?#R
MZ/3HZN#R[N(`S_/AZ^CW[?OU(.KK_O?EZ2#MY2#MX.GDY>WN`,+[(.WE(//J
MX.?@Z^@@[^#OZN@`T>[NX?GE[>CI+"#SY.[BZ^7RXN[P__[YZ/4@ZO#H\N7P
MZ/_L(._NZ/'JX"P@[>4@[>#IY.7M[@#.^.CA[NH@[O#T[N/PX/3HZ"#MY2#M
MX.GDY>WN`,WHZN#JZ/4@[_#EY.ONYN7MZ.D`S>4@[N_PY>3EZ^7M[@#-Y?(`
MT>7BY?#M[N4@[^[K\_C@\.CE`,WE(//DX.OE[>W[Y0#-Y2#WY?#M[N+HZN@`
MS>4@XN#F[?OE`,WE(.OH]^WNY0#-Y2#SY.#KY>WM^^4@\>[NX?GE[>C_`,WE
M(.+@YNW[Y2#Q[N[A^>7MZ/\`Q^#LY?+JZ`#-Z/?EX^X`Q^`@\>KNZ_SJ[B#L
MY?'_]N7B(/7PX.WH\OP@\?+@\/OE(.+K[N;E[>C_`,?@(/'J[NO\ZNX@[.7Q
M__;EXB#U\.#MZ/+\(/'RX/#[Y2#OX._JZ"#N\N_PX.+KY>WM^_4@\>[NX?GE
M[>CI`$]+`,C+R`#1\N#P^^4@\>[NX?GE[>C_`-'RX/#@_R#OX._JX"#DZ_\@
M[O+O\.#BZ^7M[?OU(/'N[N'YY>WHZ2#N]^CYY>WMX"X`TN[K_.KN(._N(._@
M[^K@["#Q(.WE[_#N]^CRX.WM^^SH(/'N[N'YY>WH_^SH/P#.\NKP^_+\(._@
M[^KS`,W@\?+P[NGJZ`#-X/'R\.[IZN@@Y.O_.B`E<P#.\./@[>#IY^7P`,_P
M[O?@_R#H[?3N\.S@]NC_`,+@^.@@[^[W\N[B^^4@__GHZN@@[>`@Y/#SX^CU
M(/'E\.+E\.#U`,3P\^/HY2#MX/'R\.[IZN@`V.CT\.[BX.WMZ.4@4$=0`,[X
MZ.'JX"!01U``SOCHX>K@.B#-Y>[A]>[DZ.P@[^#P[NO\(.3K_R#OY?#Q[NW@
MZ_SM[N/N(.KK_O?@+@#-X/'R\.[IZN@@4$=0`%!'4"#/X/#NZ_P`S^[DY.7P
MYNK@(%!'4"#R\.7A\^7R(.?@^>CYY>WM[N/N(/'NY>3H[>7MZ/\`TN7J\?(@
M[_/AZ^CW[>[C[B#JZ_[WX"!01U``S_/AZ^CW[?OI(.KK_O<@4$=0(.3K_R`E
M<R`H)7,I(.'[ZR#S\>_E^.WN(.3NX>#BZ^7M`-'B_^?JX"#O\^'KZ/?M^_4@
MZNO^]^7I(%!'4`#/[N3OZ/'\(%!'4`#/[N3OZ/'\(.@@^.CT\.[BX.WHY2!0
M1U``T>7J\.7R[?OI(.KK_O<@\_'OY?CM[B#D[N'@XNOE[0#/\^'KZ/?M^^D@
MZNO^]R#S\>_E^.WN(.3NX>#BZ^7M`,_NY.3E\.;JX"!01U`@XB#BX/CEZ2#Q
MZ/'RY>SE(.WE(.+JZ_[WY>W@`,_NY.3E\.;JX"#RY?7M[NONX^CH(%!'4"#B
M(.3@[>W[Z2#L[NSE[?(@[O+JZ_[WY>W@+"#O[OWR[NSS(._NY._H\?P@[>4@
M[.[FY?(@X?OR_"#O\.[BY?#E[>``S^[DY.7PYNK@(/+E]>WNZ^[CZ.@@4$=0
M(.(@Y.#M[?OI(.SN[.7M\B#N\NKK_O?E[>`L(._N_?+N[/,@\>[NX?GE[>CE
M(.WE(.SNYN7R(.'[\OP@\.#Q^.CT\.[BX.WN`,_NY.3E\.;JX"!01U`@Z/'O
M[NO\Y_/E\B#DZ_\@\.#A[O+[(.+Q[^O[XN#^^>CE(.[J[>`N(,7QZ^@@XN#X
M(.'PX//GY?`@[>#Q\O#NY>T@[>`@[^[DX.+KY>WHY2#B\>_K^^+@_OGH]2#N
MZN[M+"#BX.P@[>7NX?7NY.CL[B#HY^SE[>CR_"#]\N@@[>#Q\O#NZ>KH+"#H
M[>#WY2#O[N3DY?#FZN`@4$=0(.WE(/'L[N;E\B#PX.'N\N#R_"#O\.#BZ.O\
M[>XN`-'R\.#MZ/;@("5D(.CG("5D`,_E\.+NY2#MY>_P[O?H\N#M[>[E(/'N
M[N'YY>WHY0#/[O'KY>3MY>4@[>7O\.[WZ/+@[>WNY2#Q[N[A^>7MZ.4`PNON
MYN7MZ/\`S^#P[NO\`,_@\.[K_"`H[^[B\N[PZ/+\*0#/X/#NZ_PZ`,_@\.[K
M_"#MY2#L[N;E\B#A^_+\(._S\?+[[`#/X/#NZ^@@[>4@\>[B[^#DX/[R`,_@
M\.[K_`#/X/#NZ_P`S^#P[NO\`,[Q\_GE\?+BZ^7MZ.4@[N_E\.#VZ.D@[^[D
MY.7PYNKH`,+[[^[K[>CR_"#N[^7PX/;HZ"#NX?'K\^;HXN#MZ/\@[_#H(.+U
M[N3E(.(@\>CQ\N7L\P#/\.#BX`#/\.#BX"#D[O'R\^_@`,OH]^W[Y0#+Z/?M
M^^4`S^7P\>[MX.O\[>#_(._@\.`@4$=0(.KK_O?EZ2#A^^O@(//Q[^7X[>X@
M\>/E[>7PZ/#NXN#MX"X`TN7KY?3N[0#0X.?LY?G@\OP@[^[D[^CQ_"#OY?#E
MY"#N\N+E\N#LZ"#H(._E\.7Q^^OJX.SH/P#(\>_NZ_SG[N+@\OP@Y^+SZN[B
M[N4@\^+EY.[LZ^7MZ.4_(-WR[B#R\.7A\^7R(._NY.3E\.;JZ"#B(.'PX//G
MY?#E+"#B[N?NYNWN(/$@[^[L[OG\_B#Q[^7VZ.#K_.W[]2#OZ^#CZ.WNXBX`
MPN+EY.CRY2#MX.?BX.WHY2#M[N+NZ2#JX/+EX^[PZ.@Z`,+BY>3H\N4@Z.S_
M(.WNXN[I(._@[^KH.@#"XN7DZ/+E(.CL_R#M[N+NZ2#OX._JZ#H`S^[FX.OS
MZ?'RX"#BXN7DZ/+E(.WNXN[E(.CL_SH`PN+EY.CRY2#OX/#NZ_P@Y.O_(.+@
M^.7C[B#QY>KPY?+M[N/N(%!'4"#JZ_[WX"X@PN#L(.WE[N'U[N3H[.X@XN+N
MY.CR_"#OX/#NZ_P@[N3H[2#PX.<@Y^`@\>7Q\>C^(/#@X>[R^R#Q("5S`,_N
MYN#K\^GQ\N`L(/'N[N'YZ/+E(/'S\OP@[_#NX>OE[/LN`,_NYN#K\^GQ\N`L
M(.+BY>3H\N4@PN#XZ"#H[/\@[^[K_.?NXN#RY>O_(.@@[^#P[NO\`,_NYN#K
M\^GQ\N`L(//DX.OH\N4@\>[L[>CRY>O\[?OE(.CKZ"#MY>_PX.+HZ_SM^^4@
MX.3PY?'@+@#/[N;@Z_/I\?+@+"#B^^'E\.CRY2#OX._J\R#OY?#EY"#N\?/Y
MY?'RXNOE[>CE["#DY>GQ\N+H_RX`S^[FX.OSZ?'RX"P@XOOAY?#H\N4@]>[R
M_R#A^R#NY.WS(._@[^KS(.3K_R#O[NCQZN`N`,_NYN#K\^GQ\N`L(.+[X>7P
MZ/+E(/+NZ_SJ[B#NY.WS(._@[^KS(.3K_R#]\N[I(.[OY?#@]NCH+@#.\N3E
MZ^CR_"#BX/CS(._NY._H\?P@[O(@\>[NX?GE[>C_(/?E\/+NZ3\`S_#EY/OD
M\_GEY2#Q[N[A^>7MZ.4`S_#EY/OD\_G@_R#Q\O#@[>CVX`#/\.7D^^3S^>#_
M(/'R\.#MZ/;@`,_E]^#R_`#/\.[AZ^7LX#\`SN_H\>#MZ.4@[_#NX>OE[/L`
MT>_PX/CHXN#R_"#JX.;D^^D@\.#G(._PZ"#BZ^[FY>WHZ"P@[^X@\^SNZ_?@
M[>C^(,W%T@#1[_#@^.CBX/+\(.K@YN3[Z2#PX.<@[_#H(.+K[N;E[>CH+"#O
M[B#S[.[K]^#MZ/X@Q,``S_#N\N[J[NLZ`,[WZ/'RZ/+\(,KN\.?H[?,`SO?H
M\?+H\OP@RN[PY^CM\P#.]^CQ\NCR_"#OX._J\RCH*0#.]^CYX/+\(.KN\.?H
M[?,Z`-/DX.O_\OP@Z.<@ZN[PY^CM^R#Q[N[A^>7MZ/\@\?+@\/CE(//JX.?@
M[>WNX^X@ZN[KZ/?E\?+BX"#D[>7I`-/DX.O_\OP@\?+@\/OE(/'N[N'YY>WH
M_R#HYR#*[O#GZ.W[/P#(\>_NZ_SG[N+@[>XZ("4N,F;,X2#HYR`E+C)FS.$@
M*"4N,F8E)2D`UNCRZ/#S_B`E9CH`U^CRX/+\`,_E\.7Q\O#NZ/+\(.3E\.7B
M[@#/[NOS]^7M[>XZ`,_NZ_/WY>WM[B!C.@#/[NOS]^7M[>X@Y.XZ`,_E\.7M
MX._PX.+H\OP`S^7PY>W@[_#@XNCR_`#/Y?#E[>#O\.#BZ/+\(/'N[N'YY>WH
MY0#/Y?#E[>#O\.#BZ/+\(/WR[B#Q[N[A^>7MZ.4`SOCHX>K@(._E\.7MX._P
MX.+KY>WH_RX`SN'M[N+H\OP`SN'M[N+K__+\(.3H[>#LZ/?E\>KHY2#O\^WJ
M\OL@[.7M_CH`S_#NXN7P__+\(._N]_+S(.W@(/'E\.+E\.4Z`,[A[>[BZ__R
M_"#H[?3N\.S@]NC^.@#/Y?#EX_#SY^CR_"#O\.[Q[.[R\`#'X._N[.WH\OP@
M[^[QZ^7D[>7E(/'N\?+N_^WHY0#/X._JX"#MX"#Q\N[P[NWMY>P@\>7PXN7P
MY3H`S^[W\N[B^^4@\>7PXN7PX`#`Y/#E\2#QY?#BY?#@("CMX._PZ.SE\"!H
M='1P.B\O;6%I;"YR=2D`T^3@Z^CR_`#3Y.#KZ/+\(.'K[NH`T^3@Z^CR_"#O
MX/#S`,_E\.7H[.7M[N+@\OP@[^#OZO,`S^7PY>CLY>WNXOOBX/+\(._@[^KS
M(.[R[_#@XNOE[>W[]2#Q[N[A^>7MZ.D@XB#MX/?@Z^4@[.7Q__;@/P#/Y?#E
MZ.SE[>[BX.WHY2`B)7,B(.(@(B5S(B#MY2#SY.#K[O'\+B#1Y?#BY?`@[^CX
MY?(`SO+BY?+H\OP@XB#PX/'Q^^OJ\P#'X.SE[>CR_"#MX#H`SO+BY?+H\OP`
MSO+BY?+H\OP@XO'E[`#.\N+E\NCR_"#B\>7L.@#.\N+E\NCR_"#B\>7L`,KN
M[/,@[O+BY?+H\OPZ`,[RXN7RZ/+\`,[RXN7RZ/+\.@#.\N_PX.+H\OP@\>[N
MX?GE[>CE(.X@\>_@[.4`Q^#O\.[QZ/+\(._NY/+BY?#FY.7MZ.4@[^[K\_?E
M[>C_`,?@[_#N\>CR_"#O[N3RXN7PYN3E[>CE(._NZ_/WY>WH_S\`T>'P[O'H
M\OP`S_#NY.[KYNCR_`#"Y?#M\_+\\?\@ZB#MX/'R\.[IZN#L`,+E\.WS\OSQ
M_R#J(.W@\?+P[NGJX.P`PN7P[?/R_/'_(.H@[>#Q\O#NZ>K@[`#.\N[A\.#G
MZ/+\(._N]_+NXOOI(/_YZ.H@[^[QZ^4@\^3@Z^7MZ/\@Z.OH(._E\.7LY?GE
M[>C_(/'N[N'YY>WH_P#-X/'R\.[IZN@@XNCG\^#K_.WNX^X@\.7DX.KR[O#@
M`-'VY>W@\.CI`,W@\?+P[NGJZ"!3+TU)344`T>+_Y^K@(._SX>OH]^W[]2#J
MZ_[WY>D@4R]-24U%`,_NY.3E\.;JX"!3+TU)344@Z/'O[NO\Y_/E\B#DZ_\@
M\.#A[O+[(.+Q[^O[XN#^^>CE(.[J[>`N(,7QZ^@@XN#X(.'PX//GY?`@[>#Q
M\O#NY>WMX"#O[N3@XNOE[>CE(.+Q[^O[XN#^^>CU(.[J[NTL(.+@["#MY>[A
M]>[DZ.SN(.CG[.7MZ/+\(/WRZ"#MX/'R\.[IZN@L(.CMX/?E[^[DY.7PYNK@
M(%,O34E-12#MY2#Q[.[FY?(@\.#A[O+@\OP@[_#@XNCK_.WN+@#2Y>S@`-'N
M]?#@[>CR_"#J[N_H_B#B`-'N]?#@[>CR_"#JX.H`T>[U\.#MZ/+\(.K@Z@#1
M[O7PX.WH\OP@XNONYN7MZ/\@XNWS\O#H(/'N[N'YY>WHZ2#B(._@[^KE(.[R
M[_#@XNOE[>WNZ2#O[O?R^S\`T>[U\.#MZ/+\(.K@ZB#WY?#M[N+HZ@#'X._H
M\>#R_"#MX/'R\.[IZN@`T>[U\.#MZ/+\`-'N]?#@[>CR_"#JX.H@]^7P[>[B
MZ.H`T>[U\.#MZ/+\(.K@Z@#/[NSE]^#R_"#WY?#M[N+HZN@@ZN#J(.WE[_#N
M]^CRX.WM^^4`P.+R[NS@\NCWY?'JZ"#GX._H\?OBX/+\(._NZ_/WX/+EZ_\@
MXB#@Y/#E\>WS_B#J[>CC\P#'X._H\>#R_"#PY>?SZ_SRX/(@[^[H\>K@(.(@
MXNCP\O/@Z_SM\_X@[^#OZO,_`-'N]?#@[?_R_"#N\N_PX.+KY>WM^^4@\>[N
MX?GE[>C_/P#.^.CAZN`@Y^#OZ/'H(/?E\.WNXNCJX"X@T>7PXN7P(.[RXN7R
MZ.LZ("5S`,_NZ/'J`,CQZN#R_"`E<P#/[NCQZ@#0Y>?SZ_SRX/+[(._NZ/'J
MX`#/\.[WZ/+@[>W[Y0#"^^'PX/+\`,+[X?#@\OP@Y/#SX^[I(._P[O3HZ_PZ
M`,+[X>7PZ/+E(._NZ^4`POOAY?#H\N4@\>7PXN7P`,+[X>7PZ/+E(/C@X>ON
M[0#"^^'E\.CRY2#@Y/#E\>WS_B#J[>CC\R#DZ_\@Y.[AX.+KY>WH_R#B(.WE
MY2#@Y/#E\>[B+@#"^^'PX/+\(.+QY0#"^^'E\.CRY2#O[NO_(.3K_R#O[NCQ
MZN`@[_#H(/#@Y^+N\.#WZ.+@[>CH(.CLY>TN`,+[X>7PZ/+E(._P[O3HZ_P`
MSO+LY>WH\OP@XOOA[O``POOAY?#H\N4@\.#GY.7KZ/+EZ_P@[^[KY>D@Y.#R
M^SH`POOAY?#H\N4@].[P[.#R(.3@\OLZ`,+[X>7PZ/+E(._P[O3HZ_P@Y.O_
M(.W@\?+P[NGJZ#H`POOAY?#H\N4@\NCO(._N]_+NXN[C[B#QY?#BY?#@`,+[
MX>7PZ/+E(.[R[N'PX.;E[>C_(/3N\.S@\B#B\.7LY>WH.@#"^^'E\.CRY2#D
MXN`@\>[B[^#DX/[YZ/4@[^[K_RX`PN#XX"#VXN7R[N+@_R#Q]>7LX`#?Y_OJ
M(.[R[N'PX.;E[>C_`,+[X?#@[>W[Y2#@Y/#E\>W[Y2#J[>CCZ#H`S^[QZ^#R
M_"#JZ_[W(.W@(._SX>OH]^W[Z2#QY?#BY?``SO+O\.#BZ/+\(/'N[N'YY>WH
MY0#/[O'KX/+\(/'N[N'YY>WHY2#N(._P[N'KY>SE`,[R\?OKX/+\(.?@[_#N
M^.7M[>[E(.#D\.7QX/+N["#O[N3RXN7PYN3E[>CE(.X@[_#N]_+E[>CH/P#/
MX._JX"#N\N_PX.+KY>WM^_4@\>[NX?GE[>CI.@#1Y?#BY?``S^#OZN@`T>7P
MXN7P`,W@\?+P[NGJX"#LX.WH[_/K__;HZ2#Q(//DX.OE[>W[[.@@Z.OH(._E
M\.7LY?GE[>W[[.@@\>[NX?GE[>C_[.@`T_'RX.WNXNCR_"#O\.CN\.CRY?(@
M[^CQ_.S@(._PZ"#N\N_PX.+JY0#$[N_NZ^WH\N7K_.W[Y2#O[O?R[N+[Y2#Q
MY?#BY?#@+"#J(.KN\N[P^^P@XOL@]>[RZ/+E(.CLY?+\(.3N\?+S[R#HYR#/
M[O#RX.O@+@#3\?+@[>[BZN`@_^?[ZN`@XOOB[N3@+"#B\.7LY>WM[ND@Y^[M
M^R#H(/3N\.S@\N`@[O+NX?#@YN7MZ/\@XO#E[.7MZ"X`T_'RX.WNXNK@(._P
MZ.ONYN7MZ/\@[^X@\^SNZ_?@[>C^+"#VXN7R[N+NZ2#Q]>7L^R#H(._P[O?H
M]2#N[_;HZ2#N\N[A\.#FY>WH_P#/\.CK[N;E[>C_`,KPX/+J[N4@[N'NX?GE
M[>CE.@#.[_#EY.7KZ/+\(.'[\?+P^^4@ZNO@XNCXZ"#DZ_\@\?'[Z^[J/P#/
M[B#S[.[K]^#MZ/XL(/'J\/OBX/+\(.'NZ_SXZ.4@X>ONZN@@]NCRZ/#SY>SN
MX^X@\N7J\?+@/P#(\>K@\OP@XB#RY>OE(/+EZO'R[N+[]2#Q[N[A^>7MZ.D@
MY.#M[?OE(%!'4#\`Q^#J\/OBX/+\(.[J[>X@\>[Q\N#BZ^7MZ/\@\>[NX?GE
M[>C_+"#O\.@@\>[U\.#MY>WHZ"#WY?#M[N+HZN`_`,3NX>#BZ__R_"#BX/@@
M[_/AZ^CW[?OI(.KK_O<@ZNX@XO'E["#H\?7NY/_YZ.P@\>[NX?GE[>C_["#O
M[B#S[.[K]^#MZ/X_`,_NZN#GX/+\`,_NZN#GX/+\(.+QY2#GX./NZ^[BZN@`
MS^[JX.?@\OP@\^3@Z^7M[?OE`-'J\/OR_"#GX./NZ^[BZN@`S^[JX.?@\OP@
MY^#C[NONXNKH(/#@\?'[Z^KH`,_NZN#GX/+\(.WE[^[D[^CQX.WM^^4`S^[G
MXN[K__+\(//DX.O_\OP@XNONYN7MZ/\@Z.<@[^CQY>PL(.W@YN#RZ.7L(.W@
M(.CJ[NWJ\P#/[NK@Y_OBX/+\(.CM].[P[.#VZ/X@[B#O\.7D^^3S^>7L(.+U
M[N3E/P#/[NK@Y_OBX/+\(.OEX^7MY/,@[_#H(._P[O'L[O+PY2#_^>CJX#\`
MS^[JX.?@\OP@[.7M_B#N[^7PX/;HZ2#Q(/+@X>OH]N#LZ`#.\N[A\.#FX/+\
M(.SE[?X@)7,@\>OEXN`_`,[R[N'PX.?H\OP@Z.KN[>KS(/'A[O#@(._N]_+[
M(.(@XN7P]>WE["#LY>W^/P#/[NK@Y^#R_"#Q\^SLX/#M[N4@ZN[KZ/?E\?+B
M[B#OZ/'E["#B(._@[^KE/P#.\N[A\.#FX/+\`-'SY^CR_`#0X.?LY?``S^[D
M[^CQX.WN`-#@Y^SE\`#/\.[O\_'RZ/+\(._NY.3E\.;J\P#>YNWNY2#O[NOS
M^.#PZ.4`S>7FY>O@\N7K_.W[Y2#PX/'Q^^OJZ#H`T>_E]NC@Z_SM^^4@\>CL
MXN[K^P#1[^7VZ.#K_.W[Y2#QZ.SB[NO[`,_P[N+E\.K@(.[P].[C\.#TZ.@`
MS_#NXN7PZN`@[O#T[N/PX/3HZ`#/\.[BY?#JX"#N\/3NX_#@].CH(.?@XN7P
M^.7MX`#*[NOH]^7Q\N+N(.[R[N'PX.;@Y>S[]2#N^.CA[NH@[O#T[N/PX/3H
MZ`#8X.'K[NW[`,W@Y^+@[>CE.@#2Z.\Z`-C@X>ON[3H`T^3@Z^CR_"#BZ^[F
MY>WHY0#2Y>S@`-+E[.`@\>[NX?GE[>C_`,[J`,_NY._H\>#R_/'_(.W@(._@
M[^KS*.@I`,+[[^[K[>7M[@#1\N#PX/\@ZN[M].CC\_#@]NC_(/'N]?#@[>7M
MX"#B(/3@Z>LZ("5S`,WNXN#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE[>`@XCH@
M)7,`Q^#LY>WH\OP@[>``PO#E[/\@XN[Q]>[DX"_GX.K@\N``PNCG\^#K_.W[
MZ2#PY>3@ZO+N\`#/Y?#EZNO^]^CR_/'_(.(@[N'[]^W[Z2#PY>;H["#Q[O'R
MX.+KY>WH_R#Q[N[A^>7MZ/\`Q^#DX/?H`-+EZO'R`-+EZO'R`-+NZ_SJ[B#R
MY>KQ\@#*X.KNY2#DY>GQ\N+HY2#B^^?[XN#E\B#YY>OW[NH@[^X@X.3PY?'S
M(.[R[_#@XNCRY>O_.@#/\.[TZ.O\("(E<R(@X?OK(//DX.OE[2X`S_#N].CK
M_"`B)7,B(.'[ZR#Q[O7PX.WE[2X`TN7J\_G@_R#OX._JX"CH*2`B)7,B(.'S
MY.7R(._E\.7H[.7M[N+@[>`@XB`B)7,B+@#/X._JX"`B)7,B(//FY2#Q\_GE
M\?+B\^7R`,_@[^K@("(E<R(@\>[DY?#FZ/(@Y^#O\.7YY>WM^^4@\>CLXN[K
M^R#B(.CLY>WH+B#=\NX@[.[FY?(@XOOG^^+@\OP@[_#NX>OE[/LN(,_NYN#K
M\^GQ\N`L(/'B_^;H\N7Q_"#Q(,+@^.CL(/'H\>#D[.CM[NPN`,_@[^K@("(E
M<R(@X?OKX"#Q[N?DX.W@+"#M[B#"^R#MY2#A^^OH(.W@(.WEY2#O[N3OZ/'@
M[?LN`,_@[^K@("(E<R(@X?OKX"#SY.#KY>W@+"#M[B#"^R#MY2#@[>WSZ^CP
M[N+@Z^@@[^[D[^CQZO,@[>`@[>7E+@#/X._JX"`B)7,B(.WE(.'[Z^`@\>[G
MY.#MX"X@T>7PXN7P(.[RXN7RZ.L`S^#OZN`@(B5S(B#MY2#A^^O@(//DX.OE
M[>`N(-'E\.+E\"#N\N+E\NCK`,_@[^K@("(E<R(@X?OKX"#S\>_E^.WN(/'N
MY^3@[>`N`,_@[^K@("(E<R(@X?OKX"#S\>_E^.WN(//DX.OE[>`N`,_@[^K@
M("(E<R(@X?OKX"#S\>_E^.WN(._E\.7H[.7M[N+@[>`@XB`B)7,B+@#/[O?R
M[N+[Z2#QY?#BY?`@[_#H\>O@ZR#QZ^7D\_[YY>4@\>[NX?GE[>CE(.[A(.[X
MZ.'JY3H`S^#OZN`@(B5S(B#SYN4@[_/Q\N#_`-'@["#JZ_[W(._P[O'L[O+P
MY?+\(.+[(/'L[N;E\N4@)7,`T>7PXN7P("5S(.'[ZR#SY.#KY>T`T>7PXN7P
M("5S(.'[ZR#Q[N?DX.T`S^[D[^CQ_"#S\>_E^.WN(.?@[.7MY>W@+@#2Y>KQ
M\B#BY?#M\^+XY>/N\?\@[^CQ_.S@(.SNYN7R(.'[\OP@[_#N\>SN\O#E[2`E
M<RX`PB#]\N[L(/_YZ.KE(.WE\B#OZ/'E["X`S>7R(.3N\?+S[^W[]2#MX/'R
M\.[EZBX`T>[NX?GE[>CE(.(@[>7BY?#M[NP@].[P[.#RY2#H(.WE(.SNYN7R
M(.'[\OP@[O+NX?#@YN7M[@#.^.CAZN`@[_#H(//DX.OE[>CH(._H\>7L(.CG
M(._@[^KH("(E<R(N(-'E\.+E\"#N\N+E\NCK`,[XZ.'JX"#O\.@@\^3@Z^7M
MZ.@@[^CQY>P@Z.<@[^#OZN@@(B5S(BX@T>7PXN7P(.[RXN7RZ.L`SOCHX>K@
M(._PZ"#N\N[A\.#FY>WHZ"#]\N[I(/?@\?+H(/'N[N'YY>WH_P#.^.CAZN`@
M[_#H(._N[.7RZN4@[^CQY>P@XB#OX._JY2`B)7,B+B#1Y?#BY?`@[O+BY?+H
MZR``SOCHX>K@(.[R[_#@XNKH(._H\?SLX#H@)7,`W?+N(._H\?SL[B#MY2#Q
M[N3E\.;H\B#RY>KQ\N``W?+N(/'N[N'YY>WHY2#Q[N3E\.;H\B#B\?+P[N7M
M[?OE(.CG[N'PX.;E[>C_+@#=\NX@\>[NX?GE[>CE(/'NY.7PYNCR(.+Q\O#N
MY>WM^^4@Z.?NX?#@YN7MZ/\N(,?@X>ONZNCP[N+@[>W[Y2#HY^[A\.#FY>WH
M_R#B^^/K_^3_\B#RX.HZ`,H@\>[NX?GE[>C^(._PZ.ONYN7M(._SX>OH]^W[
MZ2!01U`@ZNO^]RX`W?+N(.SNYN7R(.?@[?_R_"#JX.KNY2WR[B#B\.7L_RX@
MPOL@\N[W[>X@]>[RZ/+E(._P[N3NZ^;H\OP_`-WR[B#OZ/'\[.X@X?OK[B#O
M[N3OZ/'@[>X@]NCT\.[B[ND@[^[D[^CQ_/X@4$=0`-WR[B#OZ/'\[.X@X?OK
M[B#GX/CH]/#NXN#M[B!01U``W?+N(/'N[N'YY>WHY2#B`-WR[B#WZ/'K[B#M
MY2#L[N;E\B#A^_+\(.SE[?SXY2#EY.CMZ/;[+@#=\NX@Y^W@]^7MZ.4@Y.[K
MYNWN(.'[\OP@]^CQZ^[L+@#/\.[Q[.[P\B#O[B#RY>S@[`#'X._P[O'[`-3N
M\.S@\B#N\N[A\.#FY>WH_P#'X./NZ^[B[NH`RN[L\P#`Y/#E\2#O[NOS]^#R
MY>O_`,3K_R#B^^'N\.`@[>7QZN[K_.KH]2#O[NOEZ2#DY?#FZ/+E(.KKX.+H
M^/,@0W1R;`#7\N[A^R#B^^'PX/+\(.WE\>KNZ_SJ[B#]Z^7LY>WR[N(L(//D
MY?#FZ.+@Z?+E(.W@YN#R[ND@ZNO@XNCF\R!#=')L`,[A^>CI(/#@Y^SE\"#B
MZ^[FY>WHZ3H`S//Q[O#MX/\@ZN[PY^CMX#H`55),`,WEXN[G[.[F[>X@\>[E
MY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN`,WEXN[G[.[F[>X@Y^#C\//GZ/+\
M(.[O\.7DY>OE[>CE("5S+@#=\N[R(.3NZO/LY>WR(%=O<F0@[>4@[.[FY?(@
MX?OR_"#OY?#EXN7DY>TN`,WE(.[RXN7WY>WM^^4`S>4@[O+BY??E[>W[Y2#Q
M[N[A^>7MZ/\`PN[Q\?+@[>[BZ/+\`,WE\.#QZO#[\OOE(._NZ_/WX/+EZ^@`
MSO+LY>WH\OP@Z.?LY>WE[>C_`,_S\?+NZ0#-Y>W@Y^+@[>W[Y0#-[N+[Y0#.
M\NSE[>CR_"#O[N3OZ/'J\R#MX"#/X._J\RCH*0#/\.CLY>WH\OP`Q^#C\//G
MZ/+\`,CQ[^[K_.?NXN#R_"#G[>#WY>WH_R#O[B#S[.[K]^#MZ/X`R/'O[NO\
MY^[BX/+\(._NY._H\>KS(.W@(._@[^KH($E-05`_`,CQ[^[K_.?NXN#R_"#"
MZ/#R\^#K_.WS_B#*[O#GZ.WS/P#(\>_NZ_SG\^7R\?\@Y?'KZ"#BX/CH(.CL
M_R_OX/#NZ_P@Y.O_($E-4U`@\>7PXN7PX"#N\NOH]^#^\O'_(.[R(/+EZO/Y
MZ/4`S>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_P#([/\@[^[K_.?NXN#RY>O_`,CL
M_R#O[NO\Y^[BX/+EZ_\`R.S_(._NZ_SG[N+@\N7K_P#/\.[Q[.[R\`#/\.[Q
M[.[R\"`E<P#/\.[Q[.[R\.7R_"#Q[N[A^>7MZ/\`S_#N\>SN\O#E\OP@[^X@
M\N7LX.P`S^[JX.?@\OP@XN7A+?'R\.#MZ/;S`,_P[O'L[O+P(/'N[N'YY>WH
MZ2#B("5S`,_P[O'L[O+P(/_YZ.K@(._N\>OE(.+U[N3@(.(@\>CQ\N7L\SH`
MPNCP\O/@Z_SM^^4@[^#OZN@`PNCP\O/@Z_SM^^4@PO7NY/_YZ.4`PNCP\O/@
MZ_SM^^4@PO7NY/_YZ.4`PNCP\O/@Z_SMX/\@ZN[PY^CMX`#"Z/#R\^#K_.W@
M_R#J[O#GZ.W@`,W@Y^+@[>CE(.+H\/+SX.O\[>[I(._@[^KH`,+EX0#%YN7M
MY>3EZ_SM[@#$[N'P[B#O[N;@Z^[BX/+\(.(@)7,`Q.[A\.X@[^[FX.ONXN#R
M_"P@)7,`U_+N(.[R[N'PX.;@\OP@[^[QZ^4@XO7NY.`@XB#QZ/'RY>SS.@#7
M\NX@Y.7KX/+\(/$@\>[NX?GE[>CE["P@[^[QZ^4@\N[C[B#JX.H@[NWN(.'[
MZ^X@[^[LY??E[>X@ZN#J(/'OX.P@Z.OH(.WE(/'OX.P_`,_PZ"#SY.#KY>WH
MZ"#Q[N[A^>7MZ/\L(._E\.7LY?'RZ/+\(.7C[B#B(,KN\.?H[?,L(.`@[>4@
M[^[LY??@\OP@ZN#J(//DX.OE[>WNY3\`S_#H(.[RZO#[\NCH(.WNXN[C[B#_
M^>CJX"P@ZN#JZ.4@\>[NX?GE[>C_(.[R[N'PX.?H\OP@\?#@Y_,_`-'N]?#@
M[?_R_"#BZ^[FY>WH_R#B(.CQ]>[D__GH]2#Q[N[A^>7MZ/_U/P#$[NSE[2#O
M[B#S[.[K]^#MZ/XZ`-3@Y^``RN#JZ.4@[N_VZ.@@X?/D\_(@Y.[Q\O/O[?L@
MXB#BZ.?SX.O\[>[L(/#EY.#J\N[PY0#8Z/#H[>`@[.7M_B`E<R#QZ^7BX"`H
MX?/DY?(@[_#H[.7MY>W@(._PZ"#QZ^7D\_[YY>P@XO7NY.4I`-#@X>[WZ.D@
MX.3PY?$`T.#A[O?HZ2#RY>OE].[M`,/#`,7FY>/NY.WN`,3@`,+[(._[\N#E
M\N7Q_"#SY.#KZ/+\(.+QY2#Q[N[A^>7MZ/\@XB#QZ^7D\_[YY>D@[^#OZN4Z
M`,+[(._[\N#E\N7Q_"#SY.#KZ/+\(/'KY>3S_OGHY2#OX._JZ#H`POL@\>[G
MY.#E\N4@XNONYN7M[?/^(._@[^KS(.(@`,+[(/'NY^3@Y?+E(._@[^KS(.+E
M\/7MY>/N(//P[N+M_RX`POL@[^7PY>CLY>WNXOOBX.7RY2#OX._J\SH@`,3K
M_R#"X/$@Y?'R_"`E<R#M[N+[]2#Q[N[A^>7MZ.DN`,3K_R#"X/$@Y?'R_"#N
MY.WN(.WNXN[E(/'N[N'YY>WHY2X`POL@XOOXZ^@@Z.<@\>CQ\N7L^RX`Q.O_
M(,+@\2#E\?+\(._N]_+@(.(@\>OEY//^^>7I(._@[^KE.@#$Z_\@PN#Q(.7Q
M\OP@[^[W\N`@XB#QZ^7D\_[YZ/4@[^#OZN#U.@#"^R#D[NOF[?L@[N_H\>#R
M_"#O\.[AZ^7L^RP@[_#EYN3E(/?E["#Q[.[FY?+E(.[R[O'KX/+\(/'N[N'Y
MY>WHY2#N(.WEZ2X`POL@Y.[KYNW[(.+BY?'RZ"#OX/#NZ_P@\>+NY>/N(/'E
MZO#E\NWNX^X@ZNO^]^`@Y.O_(/+NX^X@]_+NX?L@[_#N\>SN\O#E\OP@\>[N
MX?GE[>CE`,+[(.3NZ^;M^R#SZN#GX/+\(/'MX/?@Z^`@XB#JX.KS_B#OX._J
M\RX`POL@Y.[KYNW[(/'MX/?@Z^`@XOOA\.#R_"#@Y/#E\2X`POL@Y.[KYNW[
M(/'MX/?@Z^`@XOOA\.#R_"#O[B#J\.#I[>7I(.SE\.4@[N3M[B#Q[N[A^>7M
MZ.4N`,+[(.3NZ^;M^R#SZN#GX/+\(._NZ_/WX/+EZ_\N`,+@["#MY>[A]>[D
MZ.SN(.CLY?+\(.+JZ_[WY>WM[ND@[N_VZ/X@)R5S)R#B(.[OY?#@]NC_]2#N
MX?'K\^;HXN#MZ/\@`,+[(.[RXN7RZ.OH(.W@(/WR[B#Q[N[A^>7MZ.4@)7,`
MPOL@[>4@X?OKZ"#O[N3OZ/'@[?L@[>`@(B5S(BX@T>7PXN7P(.[RXN7RZ.L`
MPOL@[>4@\>SNX^OH(.[JX.?@\OSQ_R#N\B#O[N3OZ/'JZ"#MX"`B)7,B+B#1
MY?#BY?`@[O+BY?+HZP#"^R#S\>_E^.WN(._NY._H\>#KZ/'\(.W@("(E<R(`
MPOL@\_'OY?CM[B#N\NK@Y^#KZ/'\(.[R(._NY._H\>KH(.W@("(E<R(`PN#X
MX"`E<R#QY?'QZ/\@Y^#J[NWWZ.O@\?PN(,_NYN#K\^GQ\N`L(.+NZ>3H\N4@
MXB#QZ/'RY>SS(.?@[>[B[BX`PN#X($5M86EL.@#"X/@@X.3PY?$@[O+O\.#B
MZ/+EZ_\Z`,+@^.`@Z.WT[O#LX/;H_P#"X/CE(.CL_SH`PN#XZ"#O\^'KZ/?M
M^^4O\>7J\.7R[?OE(.KK_O?H(%!'4`#"X/@@\>7J\.7R[?OI(.KK_O<Z`,+@
M^"#O\^'KZ/?M^^D@ZNO^]SH`PN#X(.#D\.7Q(.3K_R#N\N+E\N`@/&D^*.WE
M(.[A_^?@\N7KY>TI/"]I/@#"X/CH(._SX>OH]^W[Y2_QY>KPY?+M^^4@\>7P
M\NCTZ.K@\OL@4R]-24U%`,+@^.@@[_#N].CKZ#H`PN#XZ"#@Y/#E\>`M[_'E
MXN3N[>CL^R`\96T^*.WE(.[A_^?@\N7K_.W[+"#JX.;D^^D@\2#M[N+NZ2#Q
M\O#NZN@I/"]E;3X`U^#Q[N+NZ2#O[O_Q`,KNY.CP[N+JX"#O[B#S[.[K]^#M
MZ/X@Y.O_(.CQ]>[D__GH]2#Q[N[A^>7MZ.DZ`,SE\N[D(/CH]/#NXN#MZ/\@
MZ/'U[N3_^>CU(/'N[N'YY>WHZ3H`PN#X(._P[O3HZ_P@[^X@\^SNZ_?@[>C^
M.@#"X/CE(.CL_SH`PN#XZ"#MX/'R\.[IZN@@X?OKZ"#NX>WNXNOE[?LN`-'R
M[O#N[>WHZ2#QY?#BY?`Z`,+@^.`@[^[D[^CQ_#H`6\'EYR#RY>S[70!;T>[N
MX?GE[>CE(.X@[_#NX>OE[.5=`%OQ\O#NZN`@)7,@Z.<@)7-=`-/O\.#BZ^7M
MZ.4`RN[OZ.@`T^3@Z^CR_`#/X._JZ`##\//O[_L`S^[L[OG\`,_P[O3HZ_P`
MPO7NY/_YZ.4`POOU[N0`R/'U[N3MZ.H@`,W@[^CQX/+\`,W@\?+P[NGJZ`#/
M\.#BX`#/Y??@\OP`SO+BY?+H\OP`S^[H\>H`S_#HZ^[FY>WH_P#O[B#RY>S@
M[`#*[NSS`,+N\?'RX.WNXNCR_`#/[NO\Y^[BX/+EZ^@`S^X@\N7LX.P`X>#I
M\@#/\.#BZ/+\`.[R`.WE\@#HZ^@`[O#T[N/PX/3H]^7QZN#_(.[XZ.'JX`#N
M\/3NX_#@].CWY?'JZ.4@[OCHX>KH`/+EZO'R(/'N[N'YY>WH_P!V0V%R9```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M;&]C86QE+W)U7U)5+VAE;'`N>&UL````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,3(V,#4S`#$P-#$W,S8R-S8S`#`R,3$V,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B(&5N8V]D:6YG/2)W:6YD;W=S+3$R-3$B/SX*/"$M+2`D2&]R9&4Z
M(&EM<"]L;V-A;&4O<G5?4E4O:&5L<"YX;6PL=B`Q+C$X+C8N-"`R,#`V+S`Q
M+S,P(#$U.C4W.C4V(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED
M/2)C;VUP;W-E+6)U='1O;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L
M93[1[O'RX.+KY>WHY2#OZ/'\[.`Z(,3EZ?'RXNC_/"]T:71L93X*("`@(#QH
M96%D:6YG/L3EZ?'RXNC_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("#*[>[O
MZN`@)\[R[_#@XNCR_"#Q[N[A^>7MZ.4G(.[R[_#@XNO_Y?(@PN#X\R#O[O?R
M\R#SZN#GX.WM[NSS(.#D\.7QX/+S*.#L*2X@S^7PY>0@[O+O\.#BZ^7MZ.7L
M(._H\?SLX"#"^R#D[NOF[?L@X?OR_"#RXN7PY.X@\^+E\.7M^R#B(/+N["P@
M]_+N(/7N\NCRY2#EX^X@[O+O\.#BZ/+\+B#"Y?#M\_+\(._H\?SL[B#MX.?@
MY"#MY>+NY^SNYNWN+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("#*[>[O
MZN`@)]'N]?#@[>CR_"#JX.H@]^7P[>[BZ.HG(._N[.7YX.7R(.WEY^#J[NWW
MY>WM[N4@[^CQ_.SN(.(@[^#OZO,@)T1R869T<R<@+2#WY?#M[N+HZN@L(.3N
M\?+S[^W[Y2#HYPH@("`@XOOJZ.3[XN#^^>7C[O'_(.SE[?X@XB#O\.#B[ND@
M]^#Q\N@@XN7P]>WEX^X@[>#BZ./@]NCN[>WNX^X@[.7M_BX@S^[R[NP@POL@
M\>SNYN7RY2#GX.KN[??H\OP@[^CQ_.SN+"#OY?#EZ>3_(.(@[^#OZO,@]^7P
M[>[BZ.KNXBP@^>7KZNWSXB#L^_CJ[ND@[>`@[^CQ_.SE+"#DZ_\@\N[C[BP@
M]_+NX?L@[O+J\/OR_"#EX^XL(.`@Y^#RY>P@^>7KZNWSXB#MX"#Q\?OKZN4@
M)\_P[N3NZ^;H\OPG+@H@("`@T^'EY.CRY?'\+"#W\NX@POL@\^K@Y^#KZ"#R
MY>SS(/'N[N'YY>WH_RP@[_#EYN3E(/?E["#OY?#E[.7Q\NCR_"#EX^X@XB#W
MY?#M[N+HZN@L(/+NX^3@(,+[(.OEX^KN(/'L[N;E\N4@[^[R[NP@Y>/N(.W@
MZ?+H+B#/[O'KY2#Q[O7PX.WE[>C_(/'N[N'YY>WH_R#B(.K@]^7Q\N+E(/?E
M\.WNXNCJX"#"^R#B[N?B\.#YX.7RY?'\(.(@\O,@[^#OZO,L(/$@ZN[R[O#N
MZ2#"^R#PX.'N\N#KZ"#MY>_N\?#EY/'RXN7M[>X@[^7PY>0@\>[Q\N#BZ^7M
MZ.7L(/'N[N'YY>WH_RX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@RNWN
M[^K@("?.\NSE[>CR_"#N\N_PX.+J\R<@[_#E\/OBX.7R(/'N\?+@XNOE[>CE
M(._N\>O@[>C_(.@@[_#N\?+N(.+NY^+PX/G@Y?(@PN#Q(.(@\O,@[^#OZO,L
M(/$@ZN[R[O#NZ2#"^R#PX.'N\N#KZ"#MY>_N\?#EY/'RXN7M[>X@[^7PY>0@
M\>[Q\N#BZ^7MZ.7L(/'N[N'YY>WH_RX*("`@(#PO<&%R83X*/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8G5T=&]N<R(^"B`@("`\
M=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@06-T:6]N<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3
M96YD($UE<W-A9V4@;&%U;F-H97,@>6]U<B!E;6%I;"!T;R!T:&4@:6YT96YD
M960@<F5C:7!I96YT*',I+B!"92!S=7)E('EO=2!W86YT('1O('-E;F0@8F5F
M;W)E(&-L:6-K:6YG(&AE<F4@87,@;VYC92!S96YT(&ET(&-A;FYO="!B92!T
M86ME;B!B86-K+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3879E($1R
M869T('!L86-E<R!A;B!U;F9I;FES:&5D(&UE<W-A9V4@:6X@82!F;VQD97(@
M8V%L;&5D("=$<F%F=',G"F%C8V5S<VEB;&4@8GD@=&AE('!O<"UD;W=N(&)O
M>"!O;B!T:&4@<FEG:'0@<VED92!O9B!T:&4@8FQU92!N879I9V%T:6]N(&)A
M<B!A="!T;W`N(%EO=2!C86X@=&AE;B!F:6YI<V@@=&AE(&UE<W-A9V4@;&%T
M97(@8GD@<W=I=&-H:6YG('1O('1H92`G1')A9G1S)R!F;VQD97(L(&-L:6-K
M:6YG(&]N('1H92!S879E9"!M97-S86=E('1O(&]P96X@:70L(&%N9"!T:&5N
M(&-L:6-K:6YG(&]N("=297-U;64G+B!"92!S=7)E('1O('!U="!A('-U8FIE
M8W0@;VX@=&AE(&5M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A9G0@<V\@
M=&AA="!Y;W4@8V%N(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S86=E('EO
M=2!W86YT('=I=&AI;B!T:&4@1')A9G1S(&9O;&1E<BX@069T97(@<V%V:6YG
M(&%S(&$@1')A9G0L('EO=2!A<F4@<F5T=7)N960@=&\@>6]U<B!)3D)/6"!O
M<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("!#86YC96P@365S<V%G92!D<F]P<R!T
M:&4@;65S<V%G92!I;B!P<F]G<F5S<R!A;F0@<VEM<&QY(')E='5R;G,@>6]U
M('1O('1H92!)3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE
M=VEN9R!L87-T+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($9R;VT\+W1I=&QE/@H@("`@/&AE
M861I;F<^(D9R;VTB/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!Y
M;W5R(&-O<G)E8W0@96UA:6P@861D<F5S<RX@66]U<B!E;6%I;"!A9&1R97-S
M(&ES(&%U=&]M871I8V%L;'D@96YT97)E9"!F;W(@>6]U(&9O;&QO=VEN9R`B
M1G)O;3HB(&EN(&]U=&=O:6YG(&5M86EL+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UT;R(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/M'N\?+@XNOE[>CE(._H\?SLX#H@RN[L\SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SXBRN[L\SHB/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("#"
MXN7DZ/+E(._PX.+HZ_SM^^D@X.3PY?$@96UA:6P@[^[K\_?@\N#K_RCEZ2D@
MPN#XY>/N(._H\?SLX"X@Q?'KZ"#O[NOS]^#RY>OEZ2#MY?'J[NO\ZNXL(/#@
MY^3EZ__I\N4@Z/4@Y^#O__+[[.@@Z.OH(._P[N'EZ^#LZ"X@S.[F[>X@\^K@
MY^#R_"#H[/\@[^[K\_?@\N7K_R#B[.7Q\N4@\2#EX^X@X.3PY?'N["P*("`@
M(.?@ZNO^]^CB(.7C[B#B(.K@XOOWZN@@*"))=F%N($DN($EV86YO=B(@+"`B
M4&5T<B!0+B!0971R;W8B("DN(,3P\^/HY2#BX/#HX.WR^R#GX._H\>@@Z.OH
M(.3P\^/HY2#PX.?DY>OH\N7KZ"#O[NOEZ2#A\^3S\B#B[O'O\.CM__+[(.K@
MZB#N^.CAZN`L(.@@ZN[L\R#B(.CR[N/E(.'SY.7R(.[R[O'KX.WN(,+@^.4@
M[^CQ_.SN+"#O\.7D\>K@Y^#R_"#MY>O\Y_\N"B`@("#1[^CQ[NH@X.3PY?'N
MXB#O[NOS]^#RY>OEZ2#N\O'[Z^#E\O'_(.+LY?'RY2#Q(/+EZO'R[NP@[^CQ
M_.S@+B#%\>OH(,+[(.WE(/7N\NCRY2P@]_+NX?L@[^[K\_?@\N7KZ"#G[>#K
MZ"#D\//C(.X@Y/#SX^4L(.CQ[^[K_.?SZ?+E(._NZ^4@)T)#0R<N"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E
M+71O(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!4;SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SXF<75O=#M4;R9Q=6]T.SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE
M<RD@;V8@=&AO<V4@=&\@<F5C96EV92!Y;W5R(&UE<W-A9V4N(%EO=2!M=7-T
M('-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R('!U
M;F-T=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N=')Y
M(&9O;&QO=W,@)G%U;W0[5&\Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN("`*
M("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M8V]M<&]S92UC8R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/M'N\?+@
MXNOE[>CE(._H\?SLX#H@0V,\+W1I=&QE/@H@("`@/&AE861I;F<^(D-C(CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@PN+EY.CRY2#O\.#BZ.O\[?OI(&5M
M86EL(._NZ_/WX/+EZ_\HY>DI(/+N]^WNZ2#J[N_HZ"#"X/CEX^X@[^CQ_.S@
M+B#.\N3EZ__I\N4@X.3PY?'@(.3P\^,@[O(@Y/#SX^`@[_#H(._N[.[YZ"#G
MX.__\OOU(.CKZ"#O\.[AY>ONXBX@PN+EY.7M[?OE(,+@[.@@Y.#M[?OE(.'S
MY//R(.[R[O'KX.W[(.+LY?'RY2#Q(/+EZO'R[NP@[^[QZ^#MZ/\N(-+N]^W[
MY2#J[N_HZ"#NX?OW[>X@[O+O\.#BZ__^\O'_(.WE(.WE[^[Q\.7D\?+BY>WM
M^^P@[^[K\_?@\N7K_^P@[^CQ_.S@+"#@(.O^Y/_L+"#J[O+N\/OE(.SNX_/R
M(.'[\OP@Y^#H[?+E\.7Q[N+@[?L@\N7L[ND@[^[QZ^#MZ/\N("#"\>4@[^[K
M\_?@\N7KZ"P@\^K@Y^#M[?OE(.(@[^[KY2`GRN[L\SHG(.@@)T-C.B<@[.[C
M\_(@XNCDY?+\(.[AX"#Q[^CQZN`@[^[K\_?@\N7KY>DN"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6-C(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!#8SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SXF<75O=#M#8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@
M=&AO<V4@=&\@<F5C96EV92!A(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G
M92X@4V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM82X@66]U<B!E
M;G1R>2!F;VQL;W=S("9Q=6]T.T-C.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL
M+B!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O<&QE(&]T
M:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET=&5N('1O(&1I<F5C=&QY
M(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@;V8@=&AE(&5M86EL(&%S
M('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C=&QY(&-O;F-E<FYE9"!A
M8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN("!!;&P@)U1O.B<@<F5C
M:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C86X@<V5E('1H92!E;G1I
M<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP:65N=',N"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M8F-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^T>[Q\N#BZ^7MZ.4@
M[^CQ_.S@.B!"8V,\+W1I=&QE/@H@("`@/&AE861I;F<^(D)C8R(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(,+BY>3H\N4@[_#@XNCK_.W[Z2!E;6%I;"#O
M[NOS]^#RY>O_*.7I*2#R[O?M[ND@)_'KY>_NZ2<@ZN[OZ.@@PN#XY>/N(._H
M\?SLX"X@SO+DY>O_Z?+E(.#D\.7QX"#D\//C(.[R(.3P\^/@(._PZ"#O[NSN
M^>@@Y^#O__+[]2#HZ^@@[_#NX>7K[N(L(.O^X>#_(.3P\^/@_R#O\^WJ\O/@
M]NC_(.'SY.7R(.+N\>_PZ.W_\N`L(.K@ZB#N^.CAZN`N(,+BY>3E[>W[Y2#"
MX.SH(.3@[>W[Y2#A\^3S\B#N\N[QZ^#M^R#B[.7Q\N4@\2#RY>KQ\N[L(._N
M\>O@[>C_+B`GT>OE[_OE)R#R[O?M^^4@ZN[OZ.@@[N'[]^WN(.[R[_#@XNO_
M_O+Q_R#MY2#MY>_N\?#EY/'RXN7M[?OL(._NZ_/WX/+EZ__L(._H\?SLX"#H
M(.WE(._NZ_/WX/+EZ__L(/+N]^W[]2#J[N_HZ2`HS^[K_R`GRN[L\SHG(.@@
M)T-C.B<I+"#@(/+E["P@[B#J[NP@[>4@Y.[KYNW[(.?MX/+\+"#JX.H@[B#O
M[NOS]^#RY>O_]2#OZ/'\[.`N(-+@ZNCL(.[A\.#G[NPL("?QZ^7OX/\G(.KN
M[^C_(.[G[>#WX.7R+"#W\NX@Z.WT[O#LX/;H_R#N(.7E(._NZ_/WX/+EZ__U
M(/'O\/_RX.W@(.[R(.3P\^/H]2#O[NOS]^#RY>OEZ2P@Z"#R[NO\ZNX@POL@
MZ"#O[NOS]^#RY>O\(/+@ZN[I(.KN[^CH(.?MX.7RY2#N(/'S^>7Q\N+NXN#M
MZ.@@\N#J[ND@ZN[OZ.@N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R
M>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6)C8R(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@0F-C/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T
M.T)C8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE
M(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV
M92!A(&)L:6YD(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@66]U(&UU
M<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@
M<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT
M<GD@9F]L;&]W<R`F<75O=#M"8V,Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN
M($)L:6YD(&-A<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T;R!P96]P
M;&4@;W1H97(@=&AA;B!D:7)E8W0@86YD(&EN9&ER96-T(')E8VEP:65N=',@
M*"9Q=6]T.U1O.B9Q=6]T.R!A;F0@)G%U;W0[0V,Z)G%U;W0[(')E8VEP:65N
M=',I('=H;R!N965D('1O(')E860@=VAA="!I<R!B96EN9R!W<FET=&5N(&%S
M('=E;&P@5TE42$]55"!T:&4@;W1H97(@<F5C:7!I96YT<R!K;F]W:6YG('1H
M870@=&AE>2!A<F4@<F5C96EV:6YG('1H92!E;6%I;"X@5&AU<R`G8FQI;F0G
M(&UE86YS('1H870@=&AE(&ED96YT:71Y(&]F('1H97-E(')E8VEP:65N=',@
M:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R(')E8VEP:65N=',@;V8@=&AE(&5M
M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H97D@:VYO=R!T:&5Y(&=O="!A(&-O
M<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H:7,@=&\@=&5L;"!A;B!A=71H;W)I
M='D@9FEG=7)E('1H870@>6]U(&%R92!T96QL:6YG('-O;65O;F4@<V]M971H
M:6YG('=I=&AO=70@86QA<FUI;F<@=&AE('!E<G-O;B!Y;W4@87)E('-E;F1I
M;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*("`@(#PO<&%R83X*/"]E;G1R>3XM
M+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T(B!S=&%T
M93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^T>[Q\N#BZ^7MZ.4@[^CQ_.S@.B#2
MY>S@/"]T:71L93X*("`@(#QH96%D:6YG/B+2Y>S@(CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@PN+EY.CRY2#RY>SS(,+@^.7C[B#OZ/'\[.`N(,+BY>3E
M[>W@_R#"X.SH(.CM].[P[.#VZ/\@X?/DY?(@[O+N\>O@[>`@XNSE\?+E(/$@
M[^CQ_.SN["X@QN7KX/+EZ_SM[BP@]_+NX?L@\N7LX"#A^^O@(._P[O'R[NDL
M(._N[?_R[>[I(.@@[O+PX.;@Z^`@\?/R_"#OZ/'\[.`N(,_NZ^4@\N7L^R`M
M(._P[O'RY>GXZ.D@\>_N\>[A(.K@ZB#DZ_\@PN#Q+"#RX.H@Z"#DZ_\@[^[K
M\_?@\N7K_R#"X/CEX^X@[^CQ_.S@+"#B\>_N[.WH\OP@[B#WY>PL(/'NX?'R
MXN7M[>XL(/CKX"#PY??\(.(@[^CQ_.SE+B#/[OWR[NSS(/WR[B#O[NOE(/_B
MZ__E\O'_(.[WY>W\(.+@YNW[["#B(.3EZ^4@[_#@XNCK_.WNZ2#H(//D[N'M
M[ND@[O#CX.WHY^#VZ.@@PN#XY>D@[^[W\N[B[ND@ZN[P\.7Q[^[MY.7M]NCH
M+B#2X.KFY2P@ZN[CY.`@POL@[O+BY??@Y?+E(.CKZ"#OY?#E\?OKX.7RY2!E
M;6%I;"P@_?+@(/+E[.`@X?/DY?(@\>KN[^CP[N+@[>`@XB#M[N+NY2#OZ/'\
M[.XL(/+@ZB#W\NX@\2#H\>_NZ_SG[N+@[>CE["#RY>P@[^[QZ^#MZ.D@[.[F
M[>X@\>[GY.#R_"#R+NTN("?BY?+B_"#Q[N[A^>7MZ.DG+B#"[_#N]^7L+"#E
M\>OH(._E\.7Q^^O@Y>SNY2#OZ/'\[.X@Z.OH(.[RXN7R(/'NY.7PYN#R(.K@
MZNCE+>OHX>X@[>[B^^4@Z.3EZ"P@\NX@POL@[.[FY?+E(._P[NCGXN7Q\N@@
MXB#O[NOE("?2Y>S@)R#MY>KN\N[P^^4@[_#N\?+[Y2#HY^SE[>7MZ/\L(/?R
M[N'[(._NZ_/WX/+EZ^@@[.[CZ^@@\?#@Y_,@\^+HY.7R_"#PX.?BZ/+HY2#H
MY.7I+"#GX.ONYN7M[?OU(.(@[^7PXN[E(._N\>O@[>CE+@H@("`@/"]P87)A
M/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92US=6)J
M96-T(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!3=6)J96-T
M/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.U-U8FIE8W0F<75O=#L\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!S=6)J96-T(&]F('EO
M=7(@;65S<V%G92X@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.U-U8FIE8W0Z
M)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN($ME97`@:70@<VAO<G0L('-I;7!L
M92!A;F0@9&5S8W)I<'1I=F4N("!4:&4@<W5B:F5C="!L:6YE(&ES('1H92!E
M87-I97-T('=A>2!F;W(@>6]U(&%N9"!Y;W5R(&-O<G)E<W!O;F1E;G1S('1O
M(')E;65M8F5R('=H870@=V%S(&EN('1H92!E;6%I;"!A;F0@=&AU<R!I<R!V
M97)Y(&EM<&]R=&%N="!I;B!O<F=A;FEZ:6YG('EO=7(@96UA:6P@86YD(&9I
M;F1I;F<@:6UP;W)T86YT(&]N97,@;&%T97(N("!!;'-O+"!W:&5N('EO=2`G
M4F5P;'DG(&]R("=&;W)W87)D)R!A;F0@96UA:6P@=&AI<R!S=6)J96-T(&QI
M;F4@:7,@8V]P:65D(&]V97(@:6YT;R!T:&4@;F5W(&UE<W-A9V4@86YD('-O
M(&ES(&$@=F%L=6%B;&4@=V%Y(&]F('1E;&QI;F<@=VAA="!M97-S86=E<R!G
M;R!T;V=E=&AE<B!T;R!F;W)M(&$@)G%U;W0[=&AR96%D)G%U;W0[(&]F(&$@
M8V]N=F5R<V%T:6]N+B`@2&]W979E<BP@:68@=&AE("=297!L>2<@;W(@)T9O
M<G=A<F0G(&-O;G1A:6YS(&YE=R!I9&5A<RP@>6]U(&UA>2!W86YT('1O(&%D
M9"!S:6UP;&4@;6]D:69I8V%T:6]N<R!T;R!T:&4@)U-U8FIE8W0G(&QI;F4@
M<V\@=&AE(')E8VEP:65N="AS*2!C86X@9F]L;&]W('1H92!P<F]G<F5S<VEO
M;B!O9B!T:&4@)G%U;W0[=&AR96%D+B9Q=6]T.PH@("`@/"]P87)A/@H\+V5N
M=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B
M('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93[1[O'RX.+KY>WHY2#OZ/'\
M[.`Z(,W@\?+P[NGJZ#PO=&ET;&4^"B`@("`\:&5A9&EN9SXBS>#Q\O#NZ>KH
M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@W?+H(.W@\?+P[NGJZ"#O[NSN
MX^#^\B#Q[O'RX.+H\OP@PN#XY2#O[O'KX.WHY2X*("`@(#PO<&%R83X*("`@
M(#QP87)A/@H@("`@S>#F[.CRY2`BS_#NXN7PZN`@[O#T[N/PX/3HZ"(@Y.O_
M(._P[N+E\.KH(.[P].[C\.#TZ.@@XB#"X/CE["#OZ/'\[.4N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@(,W@YNSH\N4@(L_PZ.KPY>_KY>WM^^4B(.3K
M_R#O\.[Q[.[R\.`@\>_H\>K@(._PZ.KPY>_KY>WM^_4@].#IZ^[B(.(@[>CF
M[>7I(/?@\?+H(.[J[>`N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(,[R
M[.7R_/+E(/3KX.;J[NP@(M'N]?#@[>CR_"#J[N_H_B#B('-E;G0M;6%I;"(@
MY.O_(/'N]?#@[>7MZ/\@ZN[OZ.@@[^CQ_.S@(.(@PN#XY>D@[^#OZN4@(E-E
M;G0@36%I;"(N(-'N]?#@[?_I\N4@ZN[OZ.@@XN#F[?OU(._H\>7L+"#]\NX@
M[^[L[N;E\B#"X.P@XN_N\>OEY/'RXNCH(/'N\>O@\OSQ_R#MX"#Q[N3E\.;@
M^?/^\?\@XB#MZ/4@Z.WT[O#LX/;H_B#H(/+BY?#D[B#G[>#R_"P@]_+N(.@@
MZN[CY.`@X?OK[B#MX._H\>#M[BX@S/L@[>4@\.7J[NSE[>3SY>P@PN#L(/'N
M]?#@[?_R_"#B\>4@PN#XZ"#OZ/'\[.`L(/(NZBX@XB#]\N[L(/'K\_?@Y2#"
MX/C@(.KB[O+@(.W@(.CQ[^[K_.?NXN#MZ.4@YN7Q\NKNX^X@Y.CQZN`@X?/D
M\_(@Y.[B[NO\[>X@X?OQ\O#N(.CQ]^7P[^#MX"`H[O'NX>7M[>XL(.7QZ^@@
MPOL@[O+Q^^O@Y?+E(.+LY?'RY2#Q(._H\?SL[NP@].#IZ_LI(.@@PN#X(._N
M]_+NXOOI(/_YZ.H@X?/DY?(@Y^#AZ/(L(/+E["#QX.S[["#QY.7KX.(@[>7B
M[N?L[N;M^^P@[_#HY>P@[>[B^_4@[^CQY>PN(,+[+"#B[_#N]^7L+"#L[N;E
M\N4@XNKK_O?H\OP@_?+S(.[O]NC^(._N(//L[NOWX.WH_BP@Z/'O[NO\Y_/_
M(._S[>KR("?-X/'R\.[IZN@G(.W@(.+E\/7MY>D@[>#BZ./@]NCN[>WNZ2#O
MX.WEZ^@N(,'SY/SRY2#N\?+N\.[F[?L@\2#]\N[I(.[O]NCEZ2P@\B[J+B#B
M(/'K\_?@Y2#EY2#BZNO^]^7MZ/\@PN#L(._E\.7NY.CWY?'JZ"#MX.3N(.'S
MY.7R(/?H\?+H\OP@PN#X\R#OX._J\R`B4V5N="!-86EL(B#B[B#HY^'EYN#M
MZ.4@[N_H\>#M[?OU(.+[^.4@[>7O\.C_\NWN\?+EZ2X*("`@(#PO<&%R83X*
M/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M;W!T:6]N
M<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@3W!T:6]N<SPO
M=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M/<'1I;VYS)G%U;W0[/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!4:&5S92!/<'1I;VYS(&AE;'`@>6]U('!R
M97!A<F4@>6]U<B!M97-S86=E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!#;&EC:R`F<75O=#M3<&5L;"!#:&5C:R9Q=6]T.R!T;R!C:&5C:R!Y;W5R
M('-P96QL:6YG+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`F
M<75O=#M!='1A8VAM96YT<R9Q=6]T.R!T;R!V:65W(&%T('1H92!B;W1T;VT@
M;V8@=&AE('!A9V4@82!L:7-T(&]F(&9I;&5S(&%T=&%C:&5D('1O('1H:7,@
M;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@06-T:79A=&4@
M=&AE(&-H96-K+6)U='1O;B!N97AT('1O("9Q=6]T.U-A=F4@8V]P>29Q=6]T
M.R!T;R!S879E(&$@8V]P>2!O9B!T:&ES(&UE<W-A9V4@:6X@>6]U<B`F<75O
M=#M396YT($UA:6PF<75O=#L@9F]L9&5R+B!3879E(&-O<&EE<R!O9B!I;7!O
M<G1A;G0@96UA:6QS('EO=2!S96YD('-O('1H870@>6]U(&AA=F4@<V]M971H
M:6YG('1O(')E9F5R(&)A8VL@=&\@;&%T97(@86YD('1O(&ME97`@86X@86-C
M=7)A=&4@<F5C;W)D(&]F('=H870@=V%S('-A:60N(%=E(&1O(&YO="!R96-O
M;6UE;F0@>6]U('-A=F4@979E<GD@96UA:6P@<VEN8V4@=&AE;B!Y;W5R(&1I
M<VL@<W1O<F%G92!Q=6]T82!W:6QL(&)E('5S960@=7`@<75I8VML>2`H97-P
M96-I86QL>2!W:&5N('EO=2!S96YD(&%T=&%C:&UE;G1S*2!A;F0@>6]U<B!M
M86EL8F]X('=I;&P@8F4@9G5L;"!A;F0@=6YA8FQE('1O(')E8V5I=F4@;F5W
M(&EN8V]M:6YG(&5M86EL+B!9;W4@8V%N+"!H;W=E=F5R+"!T=7)N('1H:7,@
M9F5A='5R92`G;VXG(&%S('EO=7(@9&5F875L="!W:71H:6X@>6]U<B!)9&5N
M=&ET>2P@8GD@9V]I;F<@=&\@3W!T:6]N<RTF9W0[4&5R<V]N86P@26YF;W)M
M871I;VXM)F=T.T5D:70@>6]U<B!I9&5N=&ET:65S+B!"92!C87)E9G5L('=H
M96X@=7-I;F<@=&AI<R!M;V1I9FEE9"!D969A=6QT(&%S('EO=2!W:6QL(&YE
M960@=&\@<&5R:6]D:6-A;&QY('!U<F=E('EO=7(@)G%U;W0[4V5N="!-86EL
M)G%U;W0[(&9O;&1E<B!O<B!I="!W:6QL(&5V96YT=6%L;'D@;6%K92!Y;W5R
M(&UA:6QB;W@@9G5L;"!A;F0@=6YU<V5A8FQE+@H@("`@/"]P87)A/@H\+V5N
M=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C:"(@
M<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/M'N\?+@XNOE[>CE(._H\?SL
MX#H@S_#HZO#E[^CR_#PO=&ET;&4^"B`@("`\:&5A9&EN9SXB071T86-H(CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("`@(,+[(.SNYN7RY2#O\.CJ\.7O
MZ/+\(.H@PN#XY>SS(._H\?SL\R#TX.GK^RX*("`@(#PO<&%R83X*("`@(#QP
M87)A/MC@XR`Q.B#+Z.'N(.+BY>3H\N4@[_/R_"#H(.CL_R#O\.CJ\.7OZ__E
M[.[C[B#TX.GKX"P@Z^CA[B#B^^'E\.CRY2#]\N[R(/3@Z>LL(.CQ[^[K_.?S
M_R#J[>[OZO,@)T)R;W=S92<N(,_N\>OE(/WR[N/N(.(@[^[KY2`GS_#HZO#E
M[^O_Y>SNY2<@[^[_XNCR\?\@[_/R_"#H(.CL_R#O\.CJ\.7OZ__E[.[C[B#T
MX.GKX"X@TN7OY?#\(._E\.7U[N3H["#J"MC@X_,@,BX*("`@(#PO<&%R83X*
M("`@(#QP87)A/MC@XR`R.B#-X.;LZ/+E(.W@(.KM[N_J\R`BS_#HZO#E[^CR
M_"(N(,CL_R#TX.GKX"#H(.7C[B#PX.?LY?`@X?/D\_(@Y.[AX.+KY>W[(.(@
M\>_H\>[J(._PZ.KPY>_KY>WM^_4N(-/W\NCRY2P@]_+N(.3K_R#A[NO\^.CU
M(/3@Z>ONXB#H+^CKZ"#LY>3KY>WM^_4@R.WRY?#MY?(M\>[EY.CMY>WHZ2P@
M[_#N]N7Q\2#GX./P\^?JZ"#H(._PZ.KPY>_KY>WH_R#"X/CH]2#TX.GK[N(@
MZB#OZ/'\[/,@[.[FY?(@Y^#M__+\(.WEZN[R[O#NY2#B\.7L_RX@S_#N_^+H
M\N4@\N7P[^7MZ.4@Z"#MY2#MX.;H[.#I\N4@[>`@Y/#SX^CE(/'Q^^OJZ"#B
M(.[J[>4@\>[GY.#MZ/\@[>[B[N/N(._H\?SLX"P@[^[JX"#FY.7RY2X*("`@
M(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O
M<V4M871T86-H(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!
M='1A8V@\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[071T86-H)G%U;W0[
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y(&%T=&%C:"!F:6QE
M<R!T;R!Y;W5R(&UE<W-A9V4[(&]N;'D@;VYE(&9I;&4@;6%Y(&)E(&%T=&%C
M:&5D(&%T(&$@=&EM92X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,3H@
M16ET:&5R+"!T>7!E('1H92!P871H(&%N9"!N86UE(&]F(&$@9FEL92!T:&%T
M('EO=2!W86YT(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92!O<B!C;&EC:R`F
M<75O=#M"<F]W<V4F<75O=#L@8G5T=&]N(&%N9"!S96QE8W0@=&AE(&9I;&4@
M=&\@8F4@871T871C:&5D+B!4:&4@<&%T:"!A;F0@;F%M92!O9B!T:&%T(&9I
M;&4@;F]W(&%P<&5A<G,@:6X@=&AE($%T=&%C:&UE;G0@8F]X+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^4W1E<"`R.B!$96-I9&4@=VAE=&AE<B!Y;W4@=V%N
M="!T:&4@9FEL92!T;R!B92!V:65W960@87,@86X@871T86-H;65N="!O<B!I
M;FQI;F5D('=I=&@@=&AE(')E<W0@;V8@=&AE(&UE<W-A9V4N(%1H92!R96-E
M:79I;F<@<&5R<V]N*',I(&UA:6P@<F5A9&EN9R!S;V9T=V%R92!M=7-T(&)E
M(&%B;&4@=&\@:&%N9&QE('1H92!F:6QE('1Y<&4@:6YL:6YE.R!I9B!N;W0L
M('1H:7,@<&%R="!W:6QL(&)E('9I97=E9"!A<R!A;B!A='1A8VAM96YT(&EN
M<W1E860N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#,Z($-L:6-K("9Q
M=6]T.T%T=&%C:"9Q=6]T.R!B=71T;VXN(%1H92!F:6QE(&YA;64@86YD('-I
M>F4@=VEL;"!B92!A9&1E9"!T;R!Y;W5R(&QI<W0@;V8@071T86-H;65N=',N
M(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S(&%N9"]O<B!S;&]W
M97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C97-S(&]F('5P;&]A
M9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T:&4@96UA:6P@;6%Y
M('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@86YD(&1O(&YO="!C
M;&EC:R!O=&AE<B!T:&EN9W,@=VAI;&4@>6]U(&%R92!W86ET:6YG+@H@("`@
M/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6%T=&%C:&UE;G1S(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^
MT>[Q\N#BZ^7MZ.4@[^CQ_.S@.B#/\.CJ\.7OZ^7M[?OE/"]T:71L93X*("`@
M(#QH96%D:6YG/B+/\.CJ\.7OZ^7M[?OE(CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@W?+@(/'EZO;H_R#N\N[A\.#FX.7R(/'OZ/'NZB#TX.GK[N(L(//F
MY2#O\.CJ\.7OZ^7M[?OU(.H@PN#XY>SS(._H\?SL\RX@Q.O_(//DX.OE[>C_
M(._PZ.KPY>_KY>WM^_4@].#IZ^[B.@H@("`@/"]P87)A/@H@("`@/'!A<F$^
MV.#C(#$Z(,[R[.7R_/+E(/3KX.;J[NP@Z.S_(._PZ.KPY>_KY>WM[N/N(/3@
MZ>O@+"#J[O+N\/OI(,+[(/7N\NCRY2#SY.#KZ/+\+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^V.#C(#(Z(,W@YNSH\N4@(M/DX.OH\OP@[O+LY??E[>W[Y2(N
M"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C
M;VUP;W-E+6%T=&%C:&UE;G1S(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O
M=#M!='1A8VAM96YT<R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5&AI<R!S96-T:6]N(&1I<W!L87ES(&$@;&ES="!O9B!F:6QE<R!A;')E861Y
M(&%T=&%C:&5D('1O('EO=7(@;65S<V%G92X@5&\@1&5L971E(&%N(&%T=&%C
M:&5D(&9I;&4Z"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($%C=&EV
M871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R!T:&4@871T86-H960@9FEL
M96YA;64@>6]U('=A;G0@=&\@1&5L971E+@H@("`@/"]P87)A/B`*("`@(#QP
M87)A/E-T97`@,CH@0VQI8VL@)G%U;W0[1&5L971E($%T=&%C:&UE;G0H<RDF
M<75O=#LN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT
M<GD@:60](F-O;7!O<V4M<')I;W)I='DB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%!R:6]R:71Y/"]T:71L93X*("`@
M(#QH96%D:6YG/B)0<FEO<FET>2(\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1H:7,@<V5T<R!T:&4@(E@M4')I;W)I='DB(&AE861E<B!O;B!Y;W5R(&]U
M=&=O:6YG(&UE<W-A9V4N(%1H92`B6"U0<FEO<FET>2(@=&%G(&ES(&$@<V]R
M="!O9B`B<'-E=61O('-T86YD87)D(B!T:&%T($YE='-C87!E+"!-;WII;&QA
M+"!/<&5R82P@86YD($]U=&QO;VL@;6%I;"!C;&EE;G1S(&%P<&5A<B!T;R!A
M9W)E92!O;BX@06YY(&UA:6P@8VQI96YT<R!T:&%T(&1O(&YO="!H86YD;&4@
M=&AI<R!H96%D97(@=VEL;"!S:6UP;'D@:6=N;W)E(&ET+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US879E+6%T=&%C:&UE
M;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET
M:6]N.B!3879E($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A/@H@("`@
M1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y;W5R(&-O
M;7!O<VET:6]N(&%R92!S879E9"!W:71H('1H92!M97-S86=E('=H96X@<W1O
M<F5D(&EN('1H92!S96YT+6UA:6P@9F]L9&5R+B`@268@(EEE<R(L('1H92!A
M='1A8VAM96YT(&1A=&$@=VEL;"!B92!S879E9"X@($EF(").;R(L('1H92!A
M='1A8VAM96YT(&1A=&$@=VEL;"!B92!S=')I<'!E9"!F<F]M('1H92!M97-S
M86=E(&%F=&5R(&ET(&ES('-E;G0@=&\@86QL(')E8VEP:65N=',N("!#:&]O
M<VEN9R`B3F\B('=I;&P@:&5L<"!C;VYS97)V92!D:7-K('-P86-E(&)Y(')E
M;6]V:6YG("AP;W1E;G1I86QL>2!L87)G92D@871T86-H;65N="!I;F9O<FUA
M=&EO;B!F<F]M('1H92!S879E9"!M97-S86=E<RX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;&EN:RUA='1A8VAM96YT<R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@
M3&EN:R!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R
M;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@:6X@>6]U<B!C;VUP;W-I
M=&EO;B!A<F4@<V5N="!A<R!A('!A<G0@;V8@=&AE(&UA:6P@;65S<V%G92!O
M<B!W:&5T:&5R('1H;W-E(&%T=&%C:&UE;G1S(&%R92!K97!T(&]N(&$@;&]C
M86P@<V5R=F5R+B`@268@871T86-H;65N=',@87)E(&QI;FME9"P@=&AE(')E
M8VEP:65N="AS*2!O9B!Y;W5R(&UE<W-A9V4@=VEL;"!B92!P<F]V:61E9"!A
M('=E8FQI;FL@=VAE<F4@=&AE>2!C86X@9&]W;FQO860@=&AE(&%T=&%C:&UE
M;G0H<RDN("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA<R!T:&4@861V86YT86=E
M(&]F('1R96UE;F1O=7-L>2!R961U8VEN9R!T:&4@<VEZ92!O9B!O=71G;VEN
M9R!M97-S86=E<RX@($QI;FMI;F<@871T86-H;65N=',@:&%S('1H92!D:7-A
M9'9A;G1A9V4@=&AA="!T:&4@8V]N=&5N="!O9B!T:&4@871T86-H;65N=',@
M8V%N(&YO="!B92!G=6%R86YT965D('1O(&)E(&%V86EL86)L92!I;B!T:&4@
M9G5T=7)E('-I;F-E('1H92!A='1A8VAM96YT(&1A=&$@:7,@;F]T(&QO8V%T
M960@=VET:&EN('1H92!E+6UA:6P@;65S<V%G92X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G-E87)C:"(@<W1A=&4](G5N:VYO=VXB/@H@
M("`@/'1I=&QE/L_NZ/'J/"]T:71L93X*("`@(#QH96%D:6YG/LKPZ/+E\.CI
M(._NZ/'JX#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("`@(,_NY/'JX.?J
MX"#E^>4@[>4@[>#OZ/'@[>`N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E
M;G1R>3H*/&5N=')Y(&ED/2)S96%R8V@B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG/E-E87)C:"!#<FET97)I83PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA>2!S96%R8V@@9F]R(&UE
M<W-A9V5S(&9R;VT@>6]U<B!F;VQD97)S('5S:6YG(&1I9F9E<F5N="!S96%R
M8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z($5N
M=&5R('1E>'0@=&\@=&AE(&9I96QD<R!Y;W4@=V%N="!T;R!A9&0@=&\@>6]U
M<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P
M(#(Z($-H;V]S92!T:&4@;65S<V%G92!F;&%G*',I('1O(&%D9"!T;R!Y;W5R
M('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@
M,SH@0VAO;W-E('1H92!F;VQD97(H<RD@9G)O;2!W:&EC:"!T;R!S96%R8V@@
M9F]R('1H92!M97-S86=E<RX*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@
M-#H@0VQI8VL@)G%U;W0[4V5A<F-H)G%U;W0[+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!)9B!A;GD@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C
M:"!C<FET97)I82P@=&AE;B!T:&4@<W5B:F5C=',@;V8@=&AE<V4@;65S<V%G
M97,@=VEL;"!B92!S:&]W;B!I;B!T:&4@)G%U;W0[4V5A<F-H(%)E<W5L=',F
M<75O=#L@=FEE=RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9F]L9&5R+6]P=&EO;G,B('-T871E/2)U;FMN;W=N(CX*
M("`@(#QT:71L93[3[_#@XNOE[>CE(._@[^K@[.@\+W1I=&QE/@H@("`@/&AE
M861I;F<^S>#Q\O#NZ>KH(._@[^[J/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("`@(,+[(.SNYN7RY2#B^^'PX/+\(._@[^KS(.CQ[^[K_.?S_R#PX.3H[BWJ
M[>[OZN@@XN3NZ_P@Z^7B[ND@ZN[K[NWJZ"X@T>3EZ^#B(/WR[BP@XOOAY?#H
M\N4@Y.7I\?+BZ.4L(.KN\N[P[N4@POL@]>[RZ/+E(._P[NCGXN7Q\N@@\2#B
M^^'PX.WM[ND@[^#OZN[I+"#H\>_NZ_SG\_\@XOOOX.3@_OGEY2#LY>W^(/'K
MY>+@+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(,+[(.'SY.7RY2#O
M\.7D\^_PY>;DY>W[(.X@Y.#K_.WEZ?CH]2#DY>GQ\N+H__4N(,'SY/SRY2#N
M\?+N\.[F[?L@\2#DY>GQ\N+HY>P@\^3@Z^7MZ/\L(,+[(.SNYN7RY2#O[O+E
M\/_R_"#B\>4@\>[NX?GE[>C_(.(@[^#OZN4L(.7QZ^@@\^3@Z^CRY2#EY2#O
M[B#N^.CAZN4A"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N
M=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(^"B`@("`\=&ET;&4^1F]L9&5R($UA
M;F%G96UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($]P=&EO;G,\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@82!F
M;VQD97(@8GD@=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE(&QE
M9G0@8V]L=6UN+B`@3VYC92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C="!T
M:&4@;W!T:6]N('EO=2!W:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E<B!V
M:6$@=&AE('-E;&5C="!B;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@("`@66]U('=I;&P@8F4@<')O;7!T960@9F]R(&9U<G1H
M97(@;W!T:6]N<RX@($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO
M;BP@87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD
M97(@:68@>6]U(&1E;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^26UP;W)T(&UB;W@@1FEL93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@("!4:&ES(&]P=&EO;B!W:6QL(&EM<&]R="!A(&UB;W@@9F]R
M;6%T(&9I;&4@:6YT;R!T:&4@9F]L9&5R(&]F('EO=7(@8VAO:6-E+B!#:&]O
M<V4@,2`H;VYE*2!F;VQD97(@=&\@:6UP;W)T('1H92!M97-S86=E<R!I;G1O
M(&%N9"!T:&5N('-E;&5C="!T:&ES(&]P=&EO;BX@66]U('=I;&P@=&AE;B!B
M92!T86ME;B!T;R!A('!A9V4@=&AA="!W:6QL('!R;VUP="!F;W(@=&AE(&UB
M;W@@9FEL92!T;R!I;7!O<G0N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E
M;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUW:61G971S(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E;65N=#H@1&ES<&QA>3PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY3:&]W+TAI9&4@56YS=6)S8W)I8F5D/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!)9B!U<VEN9R!)34%0(&9O;&1E<B!S=6)S
M8W)I<'1I;VYS+"!S:&]W+VAI9&4@=&AE('5N<W5B<V-R:6)E9"!F;VQD97)S
M+B`@5&\@<W5B<V-R:6)E+W5N<W5B<V-R:6)E('1O(&$@9F]L9&5R+"!S96QE
M8W0@=&AE(&-H96-K8F]X(&YE>'0@=&\@=&AE(&9O;&1E<FYA;64@86YD('5S
M92!T:&4@4W5B<V-R:6)E+U5N<W5B<V-R:6)E(&]P=&EO;B!I;B!T:&4@1F]L
M9&5R($%C=&EO;B!D<F]P+61O=VX@;65N=2X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/D5X<&%N9"!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5X
M<&%N9"!A;&P@9F]L9&5R(&5N=')I97,N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY#;VQL87!S92!!;&P\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-O
M;&QA<'-E(&%L;"!F;VQD97(@96YT<FEE<RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](F9I;'1E<G,B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/D9I;'1E<G,Z($%P<&QY/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY
M($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VQI8VL@
M;VX@=&AE(")!<'!L>2!&:6QT97(B(&EC;VX@;F5X="!T;R!T:&4@24Y"3U@@
M;F%M92!I;B!T:&4@;6%I;&)O>"!V:65W('1O(&9I;'1E<B!A;&P@=6YD96QE
M=&5D(&UE<W-A9V5S(&%C8V]R9&EN9R!T;R!T:&4@<W!E8VEF:65D(')U;&5S
M+B`@3W(L(&%L=&5R;F%T979L>2P@8VQI8VL@;VX@(D%P<&QY($%L;"!2=6QE
M<R(@:6X@=&AE(&9I;'1E<B!M96YU+B`@3F]T92!T:&%T(&9I;'1E<FEN9R!I
M<R!N;W0@9&]N92!A=71O;6%T:6-A;&QY+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M<G5L97,B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@1FEL=&5R(%)U;&5S/"]T:71L
M93X*("`@(#QH96%D:6YG/D5D:70@66]U<B!&:6QT97(@4G5L97,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@9FEL=&5R
M(')U;&5S(B!T;R!P<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@
M861D+"!D96QE=&4L(&%N9"!E9&ET('1H92!C=7)R96YT;'D@86-T:79E('-E
M="!O9B!F:6QT97(@<G5L97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)F:6QT97(M961I="UB;&%C:VQI<W0B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@0FQA8VML:7-T/"]T:71L93X*("`@
M(#QH96%D:6YG/D5D:70@66]U<B!";&%C:VQI<W0\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@8FQA8VML:7-T(B!T;R!P
M<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L
M(&%N9"!E9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U($%,
M5T%94R!R969U<V4@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R+65D:70M=VAI=&5L:7-T(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET(%=H:71E;&ES=#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@5VAI=&5L:7-T/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R('=H:71E;&ES="(@
M=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L
M971E+"!A;F0@961I="!T:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S('EO
M=2!!3%=!65,@86-C97!T(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](F9I;'1E<BUO;BUL;V=I;B(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&]N($QO9VEN/"]T:71L93X*
M("`@(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<R!5<&]N($QO9V]N/SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@=&\@
M86QW87ES(&%P<&QY(&9I;'1E<G,@=VAE;B!F:7)S="!L;V=G:6YG(&]N=&\@
M24U0+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R
M+6]N+61I<W!L87DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z
M($9I;'1E<B!O;B!2969R97-H/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY
M(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T;R!A
M;'=A>7,@87!P;'D@9FEL=&5R<R!W:&5N979E<B!Y;W5R('9I97<@=&AE($E.
M0D]8/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9FEL=&5R
M+6%N>2UM86EL8F]X(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S
M.B!&:6QT97(@86YY($UA:6QB;W@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P
M;'D@9FEL=&5R(')U;&5S('1O(&%N>2!M86EL8F]X/SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@:68@>6]U('=A;G0@=&\@
M8F4@86QL;W=E9"!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@86YY(&UA:6QB
M;W@N($YO<FUA;&QY+"!F:6QT97)I;F<@<G5L97,@87)E(&]N;'D@87!P;&EE
M9"!T;R!N97<@;6%I;"!T:&%T(&ES(&1E;&EV97)E9"!T;R!Y;W5R($E.0D]8
M+B`@268@=&AI<R!O<'1I;VX@:7,@8VAE8VME9"P@86X@:6-O;B!W:6QL(&%P
M<&5A<B!O;B!A;&P@;6%I;&)O>"!P86=G97,@=&AA="!W:6QL(&%L;&]W('EO
M=2!T;R!A<'!L>2!F:6QT97(@<G5L97,@=&\@=&AE(&UE<W-A9V5S(&EN('1H
M92!C=7)R96YT(&UA:6QB;W@N("!.3U1%.B!&:6QT97)I;F<@:6X@;6%I;&)O
M>&5S(&]T:&5R('1H86X@24Y"3U@@;6%Y('!R;V1U8V4@<W1R86YG92`H92YG
M+B!T:&4@9FEL=&5R(&UA>2!C875S92!A(&-O<'D@;V8@;65S<V%G97,@=&\@
M8F4@9&5L:79E<F5D('1O('1H92!S86UE(&UA:6QB;W@I(&%N9"]O<B!U;F1E
M<VER960@<F5S=6QT<R`H92YG+B!I="!M87D@8V%U<V4@;65S<V%G97,@=&\@
M8F4@;6]V960O9&5L971E9"!I9B!N97<@9FEL=&5R:6YG(')U;&5S(&AA=F4@
M8F5E;B!I;7!L96UE;G1E9"!S:6YC92!T:&4@;65S<V%G92!H87,@8F5E;B!D
M96QI=F5R960@=&\@=&AE(&-U<G)E;G0@;6%I;&)O>"DN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M<'5B
M:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($%T=&%C:"!0=6)L
M:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D%T=&%C:"!0=6)L:6,@2V5Y
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N(&$@
M8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L('=I
M;&P@8F4@871T86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N("!9;W4@
M8V%N('-E="!T:&4@9&5F875L="!B96AA=FEO<B!V:6$@=&AE(%!'4"!/<'1I
M;VYS('-C<F5E;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UO<'1I;VXM<V-A;BUB;V1Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y01U`Z(%-C86X@5&5X="!";V1I97,\+W1I=&QE/@H@("`@/&AE861I;F<^
M4V-A;B!497AT($)O9&EE<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M<V5L96-T960@=&AE;B!)35`@=VEL;"!S8V%N('1H92!B;V1Y(&]F(&%L;"!T
M97AT(&UE<W-A9V5S(&9O<B!01U`@9&%T82P@86YD(&1I<W!L87D@=&AE(')E
M<W5L=',@:68@86YY(&1A=&$@:7,@9F]U;F0N("!.;W1E('1H870@=&AI<R!M
M87D@<VQO=R!D;W=N('1H92!S>7-T96T@87,@979E<GD@=&5X="!M97-S86=E
M(&UU<W0@8F4@<V-A;FYE9"!I;B!I=',@96YT:7)E='D@9F]R(%!'4"!D871A
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UO
M<'1I;VYS+65N8W)Y<'0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D-O;7!O
M<V4Z($5N8W)Y<'1I;VX@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY.
M;R!%;F-R>7!T:6]N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD('1H
M92!M97-S86=E('=I=&@@;F\@96YC<GEP=&EO;B`H8VQE87)T97AT*2X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!%;F-R>7!T($UE<W-A9V4\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@96YC<GEP
M="!T:&4@8W5R<F5N="!M97-S86=E+"!U<VEN9R!01U`@86YD('1H92!R96-I
M<&EE;G1S('!E<G-O;F%L('!U8FQI8R!K97DL(&%N9"!T:&5N('-E;F0@:70N
M(%EO=2!C86X@;VYL>2!S96YD(&$@;65S<V%G92!T;R!A('-I;F=L92!P97)S
M;VX@=7-I;F<@=&AI<R!O<'1I;VXN(%EO=2!-55-4(&AA=F4@=&AE('!U8FQI
M8R!K97D@;V8@=&AE(')E8VEP:65N="!S=&]R960@:6X@>6]U<B!A9&1R97-S
M8F]O:R!O<B!E;'-E('1H:7,@;W!T:6]N('=I;&P@9F%I;"X@268@>6]U(&AA
M=F4@=&AE('!U8FQI8R!K97D@9F]R('1H92!R96-I<&EE;G0@:6X@>6]U<B!A
M9&1R97-S8F]O:R!A;F0@87)E('-T:6QL(')E8V5I=FEN9R!E<G)O<G,L('9E
M<FEF>2!T:&%T('1H92!E+6UA:6P@861D<F5S<R!I;B!T:&4@<F5C:7!I96YT
M(&9I96QD(&UA=&-H97,@=&AE(&4M;6%I;"!A9&1R97-S('=H97)E('1H92!P
M=6)L:6,@:V5Y(&ES('-T;W)E9"X@5&AE(&5N8W)Y<'1E9"!D871A('=I;&P@
M8F4@871T86-H960@=&\@=&AE(&]U=&=O:6YG(&UE<W-A9V4N"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL(&1I9VET86QL>2!S:6=N
M('1H92!C=7)R96YT(&UE<W-A9V4@=7-I;F<@4$=0(&%N9"!Y;W5R('!E<G-O
M;F%L('!R:79A=&4@:V5Y+B!)9B!Y;W4@:&%V92!N;W0@86QR96%D>2!E;G1E
M<F5D('1H92!P87-S<&AR87-E(&9O<B!Y;W5R('!R:79A=&4@:V5Y(&1U<FEN
M9R!T:&ES('-E<W-I;VX@>6]U('=I;&P@8F4@<')O;7!T960@9F]R(&ET+B`@
M5&AE(')E8V5I<&EE;G0@;75S="!H879E(&$@8V]P>2!O9B!Y;W5R('!U8FQI
M8R!K97D@=&\@9&EG:71A;&QY('9E<FEF>2!Y;W5R"B`@("!S:6=N871U<F4N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@4VEG;B]%;F-R>7!T($UE
M<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@;W!T:6]N('=I
M;&P@9FER<W0@9&EG:71A;&QY('-I9VX@>6]U<B!M97-S86=E(&%N9"!T:&5N
M('=I;&P@96YC<GEP="!T:&4@<F5S=6QT:6YG(&]U='!U="X@4V5E('1H92`G
M4$=0($5N8W)Y<'0@365S<V%G92<@86YD("=01U`@4VEG;B!-97-S86=E)R!E
M;G1R:65S(&9O<B!F=7)T:&5R(&EN9F]R;6%T:6]N+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^4R]-24U%($5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M4R]-24U%(%-I9VX@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^4R]-24U%(%-I9VXO16YC
M<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@3W9E<G9I97<\+W1I=&QE
M/@H@("`@/&AE861I;F<^5VAA="!I<R!01U`_/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!01U`@:7,@82!T;V]L(&9O<B!S96-U<F4@8V]M;75N:6-A=&EO
M;B!A;F0@9&%T82!S=&]R86=E+"!E<W!E8VEA;&QY(&9O<B!U<V4@=VET:"!E
M+6UA:6PN($ET(&-A;B!B92!U<V5D('1O(&5N8W)Y<'0@9&%T82!A;F0@=&\@
M8W)E871E(&1I9VET86P@<VEG;F%T=7)E<RX@24U0('5S97,@1VYU4$<@*$=.
M52!0<FEV86-Y($=U87)D*2!T;R!P<F]V:61E('1H:7,@9G5N8W1I;VYA;&ET
M>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!01U`@9G5N8W1I
M;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@;W!T
M:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&-R96%T92]V
M:65W('EO=7(@<&5R<V]N86P@4$=0(&ME>7,L(&%D9"]D96QE=&4@<'5B;&EC
M(&ME>7,@9G)O;2!O=&AE<B!I;F1I=FED=6%L<RP@<F5A9"!E;F-R>7!T960@
M;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N8W)Y
M<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C:"UP=6)K97DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@3W!T:6]N<R`M($%T=&%C:"!0
M=6)L:6,@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D]P=&EO;G,@+2!!='1A
M8V@@4'5B;&EC($ME>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@<V5L
M96-T960@=&AE;B!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@:68@
M:70@97AI<W1S+"!W:6QL(&)Y(&1E9F%U;'0@8F4@871T86-H960@=&\@86QL
M(&]U=&=O:6YG(&UE<W-A9V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*("`@(#QH
M96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES
M('-C<F5E;B!L:7-T<R!A;&P@;V8@=&AE(&-U<G)E;G0@=7-E<G,@:6X@>6]U
M<B!A9&1R97-S8F]O:R!T:&%T(&AA=F4@4$=0('!U8FQI8R!K97ES+B!4:&5S
M92!U<V5R<R!A<F4@=&AE($].3%D@=7-E<G,@=&AA="!Y;W4@8V%N(&5I=&AE
M<B`Q*2!S96YD(&%N(&5N8W)Y<'1E9"!M97-S86=E('1O("U/4BT@,BD@=F5R
M:69Y(&$@9&EG:71A;"!S:6=N871U<F4N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A('=I
M;F1O=R!T;R!V:65W('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!U8FQI8R!K
M97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($1E;&5T97,@=&AE('!U8FQI8R!K97D@9G)O;2!Y
M;W5R(&%D9')E<W-B;V]K+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+6EM<&]R="UP=6)K97DB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@36%N86=E(%!U8FQI8R!+97ES("T@26UP;W)T/"]T:71L93X*
M("`@(#QH96%D:6YG/DEM<&]R="!0=6)L:6,@2V5Y<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!O<&5N(&$@=VEN9&]W('=H
M97)E('EO=2!C86X@;6%N=6%L;'D@:6UP;W)T(&$@4$=0('!U8FQI8R!K97DN
M("!4:&4@:V5Y(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT9FEE
M;&0@;W(L(&EF('1H92!K97D@<F5S:61E<R!I;B!A(&9I;&4@;VX@>6]U<B!L
M;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@:70N("!)9B!T:&4@:V5Y
M(&ES('9A;&ED(&ET('=I;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R(&%D9')E
M<W-B;V]K(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V86QI
M9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI
M;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P
M+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES/"]T:71L93X*("`@(#QH96%D
M:6YG/D]V97)V:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!M97-S86=E<R!O<B!E;F%B;&4@;W1H
M97)S('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M97-S86=E<RP@>6]U(&UU<W0@
M:&%V92!Y;W5R(&]W;B!P97)S;VYA;"!P=6)L:6,O<')I=F%T92!01U`@:V5Y
M<&%I<BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4'5B;&EC($ME
M>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U<B!P=6)L:6,@:V5Y('-H
M;W5L9"!B92!M861E(&%V86EL86)L92!T;R!A;GD@<&5R<V]N('1H870@>6]U
M('=A;G0@=&\@8F4@86)L92!T;R!S96YD('EO=2!E;F-R>7!T960@;65S<V%G
M97,@=&AA="!O;FQY(%E/52!C86X@9&5C<GEP="`H=7-I;F<@>6]U<B!P<FEV
M871E(&ME>2DN($%D9&ET:6]N86QL>2P@>6]U<B!P=6)L:6,@:V5Y(&YE961S
M('1O(&)E(&UA9&4@879A:6QA8FQE('1O(&%N>6)O9'D@>6]U('-E;F0@82!D
M9&EG:71A;&QY('-I9VYE9"!M97-S86=E('1O("T@=&AE('!U8FQI8R!K97D@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!D:6=I=&%L('-I9VYA='5R92X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/EEO=7(@4')I=F%T92!+97D\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%EO=7(@<')I=F%T92!K97D@:7,@;F5C
M97-S87)Y('1O(&1E8W)Y<'0@86YY(&UE<W-A9V4@96YC<GEP=&5D('5S:6YG
M('EO=7(@<'5B;&EC(&ME>2X@061D:71I;VYA;&QY+"!Y;W5R('!R:79A=&4@
M:V5Y(&ES(&YE961E9"!I9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!A
M(&UE<W-A9V4N(%EO=7(@<')I=F%T92!K97D@=VEL;"!B92!P<F]T96-T960@
M=FEA(&$@<&%S<W!H<F%S92!C<F5A=&5D('=H96X@=&AE(&ME>7,@87)E(&=E
M;F5R871E9"X@5&AU<RP@=&\@<&5R9F]R;2!A;GD@86-T:79I='D@=&AA="!R
M97%U:7)E<R!Y;W5R('!R:79A=&4@:V5Y+"!)35`@=VEL;"!P<F]M<'0@>6]U
M(&9O<B!Y;W5R('!A<W-P:')A<V4N(%EO=2!O;FQY(&YE960@=&\@:6YS97)T
M('EO=7(@<&%S<W!H<F%S92!O;F-E('!E<B!S97-S:6]N("T@24U0('=I;&P@
M<W1O<F4@>6]U<B!P87-S<&AR87-E('5N=&EL('EO=2!L;V=O=70@*%-O(&)E
M('-U<F4@=&\@;&]G;W5T(2DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<'5B;&EC(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@4'5B;&EC
M($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!/<&5N<R!A('=I;F1O=R!T;R!V:65W('1H92!01U`@<'5B
M;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A
M8F]U="!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<')I=F%T92(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M
M(%!R:79A=&4@2V5Y/"]T:71L93X*("`@(#QH96%D:6YG/D5N=&5R(%!A<W-P
M:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS('1H92!P87-S
M<&AR87-E(&1I86QO9R!W:6YD;W<N(%1H92!P87-S<&AR87-E(&5N=&5R960L
M(&EF(&-O<G)E8W0L('=I;&P@8F4@<W1O<F5D(&)Y($E-4"!U;G1I;"!Y;W5R
M('-E<W-I;VX@96YD<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E5N;&]A
M9"!087-S<&AR87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!296UO=F5S
M('1H92!S=&]R960@<&%S<W!H<F%S92!F<F]M($E-4"`M(&%N>2!A9&1I=&EO
M;F%L('5S86=E(&]F('1H92!P<FEV871E(&ME>2!W:6QL(')E<75I<F4@>6]U
M('1O(')E96YT97(@=&AE('!A<W-P:&5A<V4N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!A
M('=I;F1O=R!T;R!V:65W('1H92!01U`@<')I=F%T92!K97DN($1/($Y/5"!3
M14Y$(%1(25,@2T59(%1/($%.64].12`M('1H:7,@;W!T:6]N(&ES('-T<FEC
M=&QY('-O('1H870@>6]U(&-A;B!E>'!O<G0@>6]U<B!)35`@<&5R<V]N86P@
M<')I=F%T92!K97D@9F]R('5S92!I;B!A;F]T:&5R('!R;V=R86TN"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P
M<FEV871E(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UP97)S;VYA;&ME>2UD96QE=&4B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!$96QE=&4\+W1I=&QE
M/@H@("`@/&AE861I;F<^1&5L971E(%!E<G-O;F%L($ME>7,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1H:7,@8G5T=&]N('=I;&P@9&5L971E('EO=7(@
M<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<B!F<F]M($E-4"=S('!R
M969E<F5N8V5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UN86UE(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!.86UE/"]T:71L
M93X*("`@(#QH96%D:6YG/DYA;64\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1H92!N86UE('EO=2!W86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@
M:V5Y<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M8V]M;65N="(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@
M2V5Y("T@0V]M;65N=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY#;VUM96YT/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!!(&-O;6UE;G0@<W1R:6YG('EO=2!W
M86YT(&5M8F5D9&5D(&EN('EO=7(@<&5R<V]N86P@:V5Y<RX@06X@;W!T:6]N
M86P@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M<&5R<V]N86QK97DM8W)E871E+65M86EL(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!%+6UA:6P@061D
M<F5S<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY%+6UA:6P@061D<F5S<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&4M;6%I;"!A9&1R97-S('EO=2!W
M86YT(&%S<V]C:6%T960@=VET:"!Y;W5R('!E<G-O;F%L(&ME>7,N($$@<F5Q
M=6ER960@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@2V5Y
M;&5N9W1H/"]T:71L93X*("`@(#QH96%D:6YG/DME>6QE;F=T:#PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5&AE(&ME>6QE;F=T:"P@:6X@8GET97,L(&]F
M('EO=7(@9V5N97)A=&5D(&ME>2X@5&AE(&=R96%T97(@=&AE('9A;'5E+"!T
M:&4@9W)E871E<B!T:&4@<')O=&5C=&EO;B`H86YD(&%L<V\@9W)E871E<B!G
M96YE<F%T:6]N('1I;64@86YD(&5N8W)Y<'1I;VX@=&EM92DN(#$P,C0@8GET
M97,@:7,@=&AE(&1E9F%U;'0@+2!T:&ES('9A;'5E('!R;W9I9&5S(&5X8V5L
M;&5N="!P<F]T96-T:6]N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UP87-S<&AR87-E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@
M+2!087-S<&AR87-E/"]T:71L93X*("`@(#QH96%D:6YG/DYA;64\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H92!P87-S<&AR87-E('5S960@=&\@<')O
M=&5C="]E;F-R>7!T('EO=7(@<&5R<V]N86P@<')I=F%T92!K97DN(%1H:7,@
M<VAO=6QD(&)E($%4($Q%05-4(#8@8VAA<F%C=&5R<RP@<VAO=6QD($Y/5"!B
M92!T:&4@<V%M92!A<R!Y;W5R(&QO9VEN('!A<W-W;W)D+"!S:&]U;&0@3D]4
M(&)E(&)A<V5D(&]N(&$@9&EC=&EO;F%R>2!W;W)D+"!A;F0@<VAO=6QD(&EN
M8VQU9&4@8F]T:"!N=6UB97)S(&%N9"!L971T97)S+B!9;W4@;75S="!E;G1E
M<B!T:&ES('!A<W-P:')A<V4@='=I8V4@9F]R('9E<FEF:6-A=&EO;B!P=7)P
M;W-E<RX@02!R97%U:7)E9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M86-T:6]N<R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@
M2V5Y("T@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY#<F5A=&4@2V5Y
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0W)E871E(&%N9"!S=&]R92!Y
M;W5R('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/DEM<&]R="!+97EP86ER/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!);7!O<G0@82!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N(%1H:7,@
M8G5T=&]N(&]P96YS(&$@=VEN9&]W('=H97)E('EO=2!C86X@;6%N=6%L;'D@
M:6UP;W)T('EO=7(@97AI<W1I;F<@4$=0('!E<G-O;F%L('!U8FQI8R]P<FEV
M871E(&ME>7!A:7(N("!4:&4@:V5Y<R!C86X@96ET:&5R(&)E('!A<W1E9"!I
M;G1O(&$@=&5X=&9I96QD(&]R+"!I9B!T:&4@:V5Y<R!R97-I9&4@:6X@82!F
M:6QE(&]N('EO=7(@;&]C86P@8V]M<'5T97(L('EO=2!C86X@:6UP;W)T('1H
M96TN("!)9B!T:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E(&EN<V5R
M=&5D(&EN=&\@>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O=R!W:6QL
M(&-L;W-E.R!I9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B
M92!R971U<FYE9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y3+TU)344Z($]V97)V:65W/"]T:71L93X*("`@(#QH96%D
M:6YG/E=H870@:7,@4R]-24U%/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M4R]-24U%(&ES(&$@<')I=F%T92]P=6)L:6,@:V5Y('!A:7(@<WES=&5M('=H
M:6-H('!R;W9I9&5S(&1I9VET86P@<VEG;F%T=7)E<RP@;65S<V%G92!P<FEV
M86-Y+"!A;F0@=&%M<&5R(&1E=&5C=&EO;B!I;B!A(&]P96XL(&EN=&5R;W!E
M<F%B;&4@=V%Y+B`@4R]-24U%(&-A;B!P<F]V:61E(&UE<W-A9V4@<')I=F%C
M>2!B>2!E;F-R>7!T:6YG(&UE<W-A9V5S('1H870@;VYL>2!T:&4@<V5N9&5R
M(&%N9"!T:&4@:6YT96YD960@<F5C:7!I96YT<R!C86X@9&5C;V1E+B`@270@
M86QL;W=S('EO=2!T;R!I9&5N=&EF>2!T:&4@<V5N9&5R(&]F(&$@;65S<V%G
M92!V:6$@82!D:6=I=&%L('-I9VYA='5R92X@(%1O9V5T:&5R+"!T:&ES(&5N
M8W)Y<'1I;VX@86YD(&1I9VET86P@<VEG;FEN9R!H96QP('!R;W9I9&4@=&%M
M<&5R(&1E=&5C=&EO;BP@86QL;W=I;F<@<F5C:7!I96YT<R!T;R!D971E<FUI
M;F4@=VAE=&AE<B!A(&UE<W-A9V4@=V%S(&%L=&5R960@869T97(@:70@=V%S
M('-E;G0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;F%B;&4@4R]-24U%
M(&9U;F-T:6]N86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!T
M:&ES(&]P=&EO;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@86)L92!T;R!I
M;7!O<G0@>6]U<B!P97)S;VYA;"!3+TU)344@:V5Y<RP@<F5A9"!E;F-R>7!T
M960@;6%I;"P@=F5R:69Y(&1I9VET86QL>2!S:6=N960@;6%I;"P@86YD(&5N
M8W)Y<'0O<VEG;B!Y;W5R(&]U=&=O:6YG(&UA:6PN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=RUP97)S;VYA;&ME
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!097)S;VYA;"!+
M97ES/"]T:71L93X*("`@(#QH96%D:6YG/D]V97)V:65W/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!)9B!Y;W4@=V%N="!T;R!D:6=I=&%L;'D@<VEG;B!O
M<B!E;F-R>7!T(&UE<W-A9V5S('EO=2!M=7-T(&AA=F4@>6]U<B!O=VX@<&5R
M<V]N86P@<'5B;&EC+W!R:79A=&4@4R]-24U%(&ME>7!A:7(N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UI;7!O<G0M<&5R<V]N
M86PM8V5R=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@26UP
M;W)T(%!E<G-O;F%L($-E<G1I9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY);7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!);7!O<G0@<&5R<V]N86P@8V5R=&EF:6-A=&5S(&9R;VT@
M82!02T-3(",Q,B!F;W)M870@9FEL92X@4$M#4R`C,3(@9FEL97,@:7,@=&AE
M(&9I;&4@=7-U86QL>2!G96YE<F%T960@=VAE;B!E>'!O<G1I;F<@82!K97D@
M9G)O;2!A(&)R;W=S97(@*&4N9RX@26YT97)N970@17AP;&]R97(L($9I<F5F
M;W@I(&]R(&9R;VT@82!C97)T:69I8V%T92!S=&]R92!M86EN=&%I;F5D(&)Y
M(&%N($]P97)A=&EN9R!3>7-T96T@*&4N9RX@5VEN9&]W<R!84"DN($EF('1H
M92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS97)T960@:6YT;R!Y
M;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF
M(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D
M(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<VUI;64M9&5L971E+7!E<G-O;F%L+6-E<G1S(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y3+TU)344Z($1E;&5T92!097)S;VYA;"!#97)T:69I
M8V%T97,\+W1I=&QE/@H@("`@/&AE861I;F<^1&5L971E(%!E<G-O;F%L($-E
M<G1I9FEC871E<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E('EO
M=7(@<&5R<V]N86P@8V5R=&EF:6-A=&5S(&9R;VT@>6]U<B!P<F5F97)E;F-E
M<RX@(%EO=2!W:6QL(&YO(&QO;F=E<B!B92!A8FQE('1O('-I9VX@4R]-24U%
M(&UE<W-A9V5S(&]R('9I97<@86YY(%,O34E-12!E;F-R>7!T960@;65S<V%G
M97,@861D<F5S<V5D('1O('EO=2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G-M:6UE+6UA;F%G92UP=6)K97DB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*
M("`@(#QH96%D:6YG/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!-86YA9V4@>6]U<B!3+TU)344@<'5B;&EC
M(&ME>2!L:7-T+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5FEE=R!T:&4@<F%W('1E>'0@;V8@=&AE
M('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W('1E8VAN:6-A;"!D971A
M:6QS(&]F('1H92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^1&5L971E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&5S('1H
M92!S96QE8W1E9"!P=6)L:6,@:V5Y(&9R;VT@<W1O<F%G92X@($1E;&5T:6YG
M(&$@<'5B;&EC(&ME>2!F;W(@82!U<V5R('=I;&P@<')E=F5N="!Y;W5R(&9R
M;VT@96YC<GEP=&EN9R!A(&UE<W-A9V4@=&\@=&AA="!U<V5R+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')I;G1I;F<B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R:6YT:6YG/"]T:71L93X*("`@(#QH96%D:6YG
M/E!R:6YT(&$@;65S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&\@
M<')I;G0@82!M97-S86=E('EO=2!A<F4@=FEE=VEN9RP@8VQI8VL@;VX@=&AE
M(")0<FEN="(@;&EN:R!A="!E:71H97(@=&AE('1O<"!O<B!B;W1T;VT@;V8@
M=&AE(&UE<W-A9V4N(%1H92!M97-S86=E('=I;&P@;W!E;B!I;B!A(&YE=R!W
M:6YD;W<@9F]R;6%T960@9F]R('!R:6YT:6YG+B`@1&5P96YD:6YG(&]N('EO
M=7(@=V5B(&)R;W=S97(@86YD(&]P97)A=&EN9R!S>7-T96TL('1H92!P<FEN
M="!D:6%L;V<@8F]X(&UA>2!O<&5N(&9O<B!Y;W4N("!)9B!I="!D;V5S(&YO
M="!O<&5N+"!T:&5N('!U;&P@9&]W;B!T:&4@=V5B(&)R;W=S97(G<R`B1FEL
M92(@;65N=2!A;F0@8VAO;W-E(")0<FEN="(@=&\@;W!E;B!T:&4@<')I;G0@
M9&EA;&]G(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G-O<G1I;F<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E-O<G1I;F<@86YD
M(%1H<F5A9&EN9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY3;W)T:6YG($5N=')I
M97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%=H96X@=FEE=VEN9R!A(&QI
M<W0@;V8@;65S<V%G97,L('EO=2!C86X@<V]R="!T:&4@;65S<V%G97,@8GD@
M86YY(&-O;'5M;B!B>2!C;&EC:VEN9R!O;B!T:&4@87!P<F]P<FEA=&4@8V]L
M=6UN(&AE861I;F<N("!4;R!S=VET8V@@8V]L=6UN<R!B971W965N(&%S8V5N
M9&EN9R!A;F0@9&5S8V5N9&EN9R!O<F1E<BP@8VQI8VL@;VX@=&AE(&%R<F]W
M(&EC;VX@:6X@=&AE(&-O;'5M;B!H96%D:6YG+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^5&AR96%D:6YG/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M;R!G<F]U<"!M97-S86=E<R!B>2!T:')E861S("AS=6)J96-T*2P@<V\@96%C
M:"!M97-S86=E(&ES(&=R;W5P960@=VET:"!A;&P@:71S(')E<&QI97,L(&-L
M:6-K('1H92!;5&AR96%D72!L:6YK(&EN('1H92!S=6)J96-T(&-O;'5M;B!H
M96%D:6YG+B`@5&\@<F5T=7)N('1O(&YO<FUA;"!S=6)J96-T('-O<G1I;F<L
M(&-L:6-K(&]N('1H92!;4W5B:F5C=%T@;&EN:R!I;B!T:&4@<W5B:F5C="!C
M;VQU;6X@:&5A9&EN9RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](F%L=&5R;F%T:79E+6US9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M375L=&EP87)T+T%L=&5R;F%T:79E($UE<W-A9V5S/"]T:71L93X*("`@(#QP
M87)A/@H@("`@4V]M92!M97-S86=E(&AA=F4@8F5E;B!S96YT(&%S(&$@(FUU
M;'1I<&%R="]A;'1E<FYA=&EV92(@='EP92!B>2!T:&4@<V5N9&5R+B!4:&5S
M92!M97-S86=E<R!H879E('-E=F5R86P@<&%R=',L(&%L;"!D:7-P;&%Y:6YG
M('1H92!304U%($-/3E1%3E0@8G5T(&EN($1)1D9%4D5.5"!&3U)-0513+B!4
M:&4@;6%I;"!A9V5N="!W:6QL(&1I<W!L87D@=&AE(&QA<W0@<&%R="!I;B!T
M:&4@;&ES="!T:&%T(&-A;B!B92!S=6-C97-S9G5L;'D@9&ES<&QA>65D(&EN
M;&EN92!I;B!T:&4@8G)O=W-E<BP@:68@86YY+B!!;&P@;W1H97(@9F]R;6%T
M<R!W:6QL(&%P<&5A<B!U;F1E<B!T:&4@:&5A9&EN9R`B06QT97)N871I=F4@
M<&%R=',@9F]R('1H:7,@<V5C=&EO;B(@86YD(&-A;B!B92!V:65W960@;W(@
M9&]W;FQO861E9"!S97!A<F%T96QY+B!)="!I<R!I;7!O<G1A;G0@=&\@;F]T
M92!T:&%T('1H97-E(&%L=&5R;F%T:79E('!A<G1S(&-O;G1A:6X@=&AE(%-!
M344@0T].5$5.5%,@87,@=&AE('!A<G0@=&AA="!I<R!S:&]W;B`M('1H97D@
M87)E('-I;7!L>2!I;B!A(&1I9F9E<F5N="!M961I82!F;W)M870@*&4N9RX@
M=&5X="!V<RX@2%1-3"!O=71P=70I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@4F5N86UE(%-E;G0M;6%I;"!&;VQD97(@36]N=&AL>3PO=&ET;&4^"B`@
M("`\<&%R83X*("`@(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U('=O=6QD
M(&QI:V4@=&\@<F5N86UE('EO=7(@<V5N="UM86EL(&9O;&1E<B!A="!T:&4@
M8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AE(&9O;&1E<B!W:6QL(&)E
M(')E;F%M960@*'1O(&$@;F%M92!T:&%T(&-O;G1A:6YS('1H92!M;VYT:"!A
M;F0@>65A<BD@86YD(&$@;F5W('-E;G0M;6%I;"!F;VQD97(@=VEL;"!B92!C
M<F5A=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&5L971E7W-E;G1M86EL7VUO;G1H;'DB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E(%-E;G0M
M;6%I;"!&;VQD97(@36]N=&AL>3PO=&ET;&4^"B`@("`\<&%R83X*("`@(%1U
M<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U('=O=6QD(&QI:V4@=&\@9&5L971E
M(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!T:&4@8F5G:6YN:6YG(&]F(&5V
M97)Y(&UO;G1H+B`@5&AI<R!M87D@8F4@=7-E9G5L(&EF('EO=2!H879E(&$@
M<75O=&$L(&9O<B!E>&%M<&QE+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&5L971E7W-E;G1M86EL7VUO;G1H;'E?:V5E<"(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!$96QE=&4@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY("T@(R!O9B!&
M;VQD97)S('1O($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M87)E(&1E;&5T:6YG(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!E=F5R>2!M;VYT
M:"P@:&]W(&UA;GD@;6]N=&AS(&]F(&]L9"!F;VQD97)S(&1O('EO=2`@=V%N
M="!T;R!K965P/R`@06YY(&9O;&1E<G,@;VQD97(@=&AA;B!T:&ES(&UA;GD@
M;6]N=&AS('=I;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E
M;F%N8V4Z($1E;&5T92!,:6YK960@071T86-H;65N=',@36]N=&AL>3PO=&ET
M;&4^"B`@("`\<&%R83X*("`@(%1U<FX@=&AI<R!O<'1I;VX@;VX@:68@>6]U
M('=O=6QD(&QI:V4@=&\@9&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@
M870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H:7,@;6%Y(&)E
M('5S969U;"!I9B!Y;W4@:&%V92!A('%U;W1A+"!F;W(@97AA;7!L92X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]A
M='1A8VAM96YT<U]M;VYT:&QY7VME97`B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L971E($QI;FME9"!!
M='1A8VAM96YT<R!-;VYT:&QY("T@(R!O9B!-;VYT:',@=&\@2V5E<#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@9&5L971I;F<@;VQD(&QI
M;FME9"!A='1A8VAM96YT<R!E=F5R>2!M;VYT:"P@:&]W(&UA;GD@;6]N=&AS
M(&]F(&]L9"!A='1A8VAM96YT<R!D;R!Y;W4@('=A;G0@=&\@:V5E<#\@($%N
M>2!A='1A8VAM96YT<R!O;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT:',@=VEL
M;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M<'5R9V5?=')A<V@B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@4'5R9V4@5')A<V@\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!$;R!Y;W4@=V%N="!T;R!P=7)G92!Y;W5R('1R
M87-H(&9O;&1E<B!E=F5R>2!S;R!O9G1E;BX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H7VEN=&5R=F%L(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z(%!U<F=E(%1R87-H($EN=&5R=F%L/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@>6]U(&%R92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R+"!H;W<@
M;V9T96X@<VAO=6QD(&ET(&)E('!U<F=E9#\*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H7VME97`B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@
M4'5R9V4@5')A<V@@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO
M=2!A<F4@<'5R9VEN9R!Y;W5R('1R87-H(&9O;&1E<BP@;65S<V%G92!O;&1E
M<B!T:&%N(&AO=R!M86YY(&1A>7,@<VAO=6QD(&)E('!U<F=E9#\*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6%T=')I8E]T97AT
M(B!S=&%T93TB;F5W(CX*("`@("`\=&ET;&4^4')E9F5R96YC97,Z($UE<W-A
M9V4@0V]M<&]S:71I;VXZ($%T=')I8G5T:6]N(%1E>'0\+W1I=&QE/@H@("`@
M(#QP87)A/@H@("`@($AE<F4@>6]U(&-A;B!E;G1E<B!T:&4@<&AR87-E('1H
M870@>6]U('=I<V@@=&\@87!P96%R(&)E9F]R92!A;GD@<75O=&5D('1E>'0@
M:6X@82!R97!L>2!T:&%T('EO=2!S96YD+@H@("`@(#PO<&%R83X*("`@("`\
M<&%R83X*("`@("!9;W4@8V%N(&EN8VQU9&4@;VYE(&]R(&UO<F4@<W!E8VEA
M;"!P;&%C96AO;&1E<G,@=&\@:6YS97)T(&EN9F]R;6%T:6]N(&%B;W5T('1H
M92!M97-S86=E('1O('=H:6-H('EO=2!A<F4@<F5P;'EI;F<N(%!L86-E:&]L
M9&5R<R!C;VYS:7-T(&]F(&$@)R4G(&9O;&QO=V5D(&)Y(&$@<VEN9VQE(&QE
M='1E<BX@5&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@87)E(&%V86EL86)L
M93H*("`@("`\+W!A<F$^"@H@("`@(#QP87)A/B`E9B`Z(%1H92!S96YD97(G
M<R!N86UE(&%N9"!E;6%I;"!A9&1R97-S/"]P87)A/@H@("`@(#QP87)A/B`E
M82`Z(%1H92!S96YD97(G<R!E;6%I;"!A9&1R97-S/"]P87)A/@H@("`@(#QP
M87)A/B`E<"`Z(%1H92!S96YD97(G<R!N86UE/"]P87)A/@H@("`@(#QP87)A
M/B`E<B`Z(%1H92!F=6QL(%)&0R`R.#(R('-T>6QE(&1A=&4@86YD('1I;64@
M>F]N93PO<&%R83X*("`@("`\<&%R83X@)60@.B!4:&4@9&%T92!A<R!W=W<L
M(&1D(&UM;2!965E9/"]P87)A/@H@("`@(#QP87)A/B`E>"`Z(%1H92!D871E
M(&EN('1H92!L;V-A;&4G<R!D969A=6QT/"]P87)A/@H@("`@(#QP87)A/B`E
M8R`Z(%1H92!D871E(&%N9"!T:6UE(&EN('1H92!L;V-A;&4G<R!D969A=6QT
M/"]P87)A/@H@("`@(#QP87)A/B`E;2`Z(%1H92!-97-S86=E+4E$/"]P87)A
M/@H@("`@(#QP87)A/B`E<R`Z(%1H92!S=6)J96-T/"]P87)A/@H@("`@(#QP
M87)A/B`E;B`Z($$@;F5W(&QI;F4\+W!A<F$^"B`@("`@/'!A<F$^("4E(#H@
M5&AE("<E)R!C:&%R86-T97(\+W!A<F$^"@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]R96%D(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4F5Q=65S="!296%D(%)E8V5I
M<'1S/"]T:71L93X*("`@(#QP87)A/@H@("`@(E)E<75E<W0@82!296%D(%)E
M8V5I<'0B('-E;F1S(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT<R!O9B!T
M:&ES(&UE<W-A9V4@=&\@;F]T:69Y('EO=2!W:&5N('1H:7,@;65S<V%G92!I
M<R!O<&5N960@8GD@=&AE(')E8VEP:65N=',N($YO="!A;&P@8VQI96YT<R!S
M=7!P;W)T("\@:&]N;W(@=&AI<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W-E;F1?;61N(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4V5N9"!-1$X\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("`B4V5N9"!A($U$3B(@<V5N9',@82!-97-S86=E
M($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`H86QS;R!K;F]W;B!A<R!A(')E
M860@<F5C96EP="D@=VAE;B!Y;W4@=FEE=R!A(&UE<W-A9V4@:6X@=VAI8V@@
M=&AE('5S97(@:&%S(')E<75E<W1E9"!T:&%T('1H97D@<F5C96EV92!N;W1I
M9FEC871I;VX@=&AA="!Y;W4@:&%V92!R96%D('1H92!M97-S86=E+B!);B!M
M;W-T(&-A<V5S+"!T:&ES('=I;&P@:&%P<&5N(&%U=&]M871I8V%L;'D@=VET
M:&]U="!P<F]M<'1I;F<@>6]U+B!);B!C97)T86EN(&ES;VQA=&5D(&-A<V5S
M+"!Y;W4@;6%Y(&AA=F4@=&\@;6%N=6%L;'D@9&5C:61E('1O('-E;F0@=&AE
M(&YO=&EF:6-A=&EO;B!B>2!C;&EC:VEN9R!O;B!A(&QI;FLN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R
M97%U97-T7V1E;&EV97)Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F
M97)E;F-E<SH@4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VX\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I
M;VXB('-E;F1S(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT)W,@92UM86EL
M('-E<G9E<B!T;R!N;W1I9GD@>6]U('=H96X@:70@:&%S(&1E;&EV97)E9"!T
M:&4@;65S<V%G92!T;R!T:&4@<F5C:7!I96YT)W,@;6%I;&)O>"X@270@9&]E
M<VXG="!M96%N('1H92!M97-S86=E(&AA<R!B965N('-E96XL(&IU<W0@=&AA
M="!I="=S('-I='1I;F<@:6X@82!M86EL8F]X('-O;65W:&5R92X@3F]T(&%L
M;"!M86EL('-E<G9E<G,@<W5P<&]R="!T:&ES+B`*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61E;&5T95]S<&%M7V%F=&5R7W)E
M<&]R="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($1E
M;&5T92!3<&%M($%F=&5R(%)E<&]R=&EN9SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@(%EO=2!M87D@96QE8W0@=&\@9&\@;VYE(&]F('1H<F5E(&ET96US(&%F
M=&5R(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@96ET:&5R('-P86T@;W(@:6YN
M;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($9I<G-T+"!Y;W4@
M8V%N(&1E8VED92!T;R!D;R!N;W1H:6YG("T@=&AE(&UE<W-A9V4@=VEL;"!B
M92!R97!O<G1E9"!A<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="!B=70@=VEL
M;"!O=&AE<G=I<V4@<F5M86EN('5N8VAA;F=E9"!I;B!Y;W5R(&UA:6QB;W@N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%-E8V]N9"P@:68@<F5P;W)T
M:6YG(&$@;65S<V%G92!A<R!S<&%M+"!Y;W4@8V%N(&EN<W1E860@:&%V92!T
M:&4@;65S<V%G92!B92!I;6UE9&EA=&5L>2!D96QE=&5D+B`@5&AI<R!S971T
M:6YG(&AA<R!N;R!E9F9E8W0@;VX@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I
M;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@5&AI<F0L(&%F
M=&5R(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@<W!A;2!T:&4@;65S<V%G92!W
M:6QL(&)E(&1E;&5T960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M
M;W9E9"!T;R!Y;W5R('-P86T@9F]L9&5R+B`@06QT97)N871I=F5L>2P@:68@
M<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I;FYO8V5N="!T:&4@;65S<V%G92!W
M:6QL(&)E(&1E;&5T960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M
M;W9E9"!T;R!Y;W5R($E.0D]8+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]R97!L86-E;65N="(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P
M;&%C96UE;G0\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!&;W(@2%1-3"!M97-S
M86=E<R!D:7-P;&%Y960@:6YL:6YE+"!S:&]U;&0@86QL(&EM86=E('1A9W,@
M8F4@8FQO8VME9"!U;G1I;"!Y;W4@<W!E8VEF:6-A;&QY(&1E8VED92!T;R!V
M:65W('1H;W-E(&EM86=E<S\@3F]T92!T:&%T+"!I9B!V:65W:6YG(&%N($A4
M34P@871T86-H;65N="P@=&AE(&EM86=E<R!W:6QL(&%L=V%Y<R!B92!D:7-P
M;&%Y960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUH=&UL7VEM86=E7V%D9')B;V]K(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G92!297!L86-E;65N="]!9&1R97-S
M8F]O:R!3:&]W/"]T:71L93X*("`@(#QP87)A/@H@("`@268@8FQO8VMI;F<@
M:6UA9V5S(&9O<B!I;FQI;F4@2%1-3"!M97-S86=E<RP@<VAO=6QD('=E(&%U
M=&]M871I8V%L;'D@9&ES<&QA>2!T:&5M(&EN<W1E860@:68@=&AE('-E;F1E
M<B!A<'!E87)S(&EN('EO=7(@861D<F5S<V)O;VL_"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUM86EL8F]X7W-T87)T(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;&)O>"!3=&%R
M="!086=E/"]T:71L93X*("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&EC
M:"!P86=E(&EN('1H92!M86EL8F]X('9I97<@=VEL;"!B92!D:7-P;&%Y960@
M=VAE;B!Y;W4@86-C97-S(&$@;6%I;&)O>"!F;W(@=&AE(&9I<G-T('1I;64N
M($YO=&4@=&AA="!T:&4@)W5N<V5E;B<@;65S<V%G92!O<'1I;VYS(&1O(&YO
M="!W;W)K('=I=&@@=&AE("=4:')E860G('-O<G1I;F<@;W!T:6]N("T@:6YS
M=&5A9"P@>6]U('=I;&P@8F4@<V5N="!T;R!T:&4@;&%S="!P86=E+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<V%V95]A='1A
M8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M(%-A=F4@071T86-H;65N=',@;VX@4V5N="!-97-S86=E<SPO=&ET;&4^"B`@
M("`\<&%R83X*("`@($EF('-A=FEN9R!A(&-O;7!O<V5D(&UE<W-A9V4@:6X@
M82!S96YT+6UA:6P@9F]L9&5R+"!D971E<FUI;F4@:68@86QL(&%T=&%C:&UE
M;G0@9&%T82!I<R!S879E9"X@5&AE(&9O;&QO=VEN9R!O<'1I;VYS(&%R92!A
M=F%I;&%B;&4Z"B`@("`\+W!A<F$^"@H@("`@/'!A<F$^*B`B06QW87ES('-A
M=F4@871T86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A=F4@871T86-H
M;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT<R!A<F4@
M04Q705E3('-A=F5D('=I=&@@=&AE(&UE<W-A9V4N/"]P87)A/@H@("`@(#QP
M87)A/BH@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N
M=#L@9&5F875L="!T;R!915,B("T@04Q705E3('!R;VUP="!T;R!S879E(&%T
M=&%C:&UE;G1S(&EN('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@
M:7,@=&\@<V%V92!A='1A8VAM96YT<RX\+W!A<F$^"B`@("`@/'!A<F$^*B`B
M4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A
M=6QT('1O($Y/(B`M($%,5T%94R!P<F]M<'0@=&\@<V%V92!A='1A8VAM96YT
M<R!I;B!T:&4@8V]M<&]S92!S8W)E96X[('1H92!D969A=6QT(&ES('1O(&YO
M="!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R83XJ(").979E
M<B!S879E(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP="!T;R!S879E(&%T
M=&%C:&UE;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@871T86-H;65N=',@
M87)E($Y%5D52('-A=F5D('=I=&@@=&AE(&UE<W-A9V4N/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]I;F)O>"(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L($EN8F]X/"]T
M:71L93X*("`@(#QP87)A/@H@("`@5FER=71A;"!);F)O>"!I<R!A('-A=F5D
M('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D('1O('-E87)C
M:"!E=F5R>2!M86EL8F]X(&9O<B!M97-S86=E<R!M87)K960@87,@;F5W+B`@
M26YS=&5A9"P@86QL(&-U<G)E;G1L>2!S=6)S8W)I8F5D(&UA:6QB;WAE<R!A
M<F4@<V5A<F-H960@9F]R(&YE=R!M97-S86=E<R!A;F0@=&AE(')E<W5L=',@
M87)E(&1I<W!L87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T<F%S:"(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L(%1R
M87-H/"]T:71L93X*("`@(#QP87)A/@H@("`@5FER='5A;"!4<F%S:"!I<R!A
M('-A=F5D('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D(&9O
M<B!A('-E<&%R871E(%1R87-H(&9O;&1E<BX@($EN<W1E860@;V8@;6]V:6YG
M(&UE<W-A9V5S('1O(&$@8V5N=')A;&EZ960@=')A<V@@9F]L9&5R+"!M97-S
M86=E<R!A<F4@<VEM<&QY(&UA<FME9"!A<R!D96QE=&5D(&EN('1H92!C=7)R
M96YT(&9O;&1E<B!T:&5Y(&QI=F4@:6XN("!7:&5N("=S:&]W(&1E;&5T960@
M;65S<V%G97,G(&ES('1U<FYE9"!O9F8L('1H:7,@<F5S=6QT<R!I;B!T:&5S
M92!M97-S86=E<R!N;W0@87!P96%R:6YG(&EN(&$@;6%I;&)O>"!V:65W+B`@
M5VAE;B!A('5S97(@8VQI8VMS(&]N(%9I<G1U86P@5')A<V@L("IA;&PJ(&UA
M:6QB;WAE<R!A;&P@<V5A<F-H960@9F]R(&UE<W-A9V5S('1H870@87)E(&9L
M86=G960@9&5L971E9"!A;F0@=&AE<V4@;65S<V%G97,@87)E(&1I<W!L87EE
M9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\
M+VAE;'`^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]L;V-A;&4O<VM?4TLO````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#$W-#8S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]S:U]32R],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<V,P`P,C$R-3``(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M;&]C86QE+W-K7U-++TQ#7TU%4U-!1T53+VEM<"YM;P``````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P-C8S,S$P`#$P-#$W,S8R-S8S`#`R,C0P,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#>$@25`````%@+```<
M````W%H``"4/``"<M0```````##R```*````,?(```H````\\@``"@```$?R
M```*````4O(```X```!=\@``#P```&SR```-````?/(```@```"*\@``"P``
M`)/R```,````G_(```H```"L\@``!````+?R```$````O/(``!@```#!\@``
M&P```-KR```M````]O(``!T````D\P``)````$+S```I````9_,``!D```"1
M\P```0```*OS```9````K?,``"8```#'\P``#````.[S```+````^_,``"0`
M```']```'@```"ST``!(````2_0``"L```"4]```1````,#T```G````!?4`
M`!<````M]0``#P```$7U```+````5?4```X```!A]0``!0```'#U```H````
M=O4```@```"?]0``"@```*CU```5````L_4``!(```#)]0``,@```-SU```+
M````#_8``"D````;]@``,@```$7V```0````>/8``!8```")]@``$````*#V
M```F````L?8``"D```#8]@``)@````+W```<````*?<``(4```!&]P``#@``
M`,SW```*````V_<```T```#F]P``)P```/3W```B````'/@```X````_^```
M(@```$[X```9````<?@``"0```"+^```-P```+#X```1````Z/@```T```#Z
M^```#`````CY```-````%?D```8````C^0``&P```"KY``"4````1OD``"X`
M``#;^0``-P````KZ```&````0OH```P```!)^@``?````%;Z``!L````T_H`
M`!P```!`^P``'0```%W[```*````>_L```\```"&^P``&````);[```,````
MK_L``!L```"\^P``10```-C[```H````'OP``$$```!'_```)````(G\```.
M````KOP```\```"]_```#@```,W\```.````W/P```@```#K_```#@```/3\
M```.`````_T```D````2_0``+@```!S]```:````2_T``#,```!F_0``40``
M`)K]```R````[/T``#@````?_@``5````%C^``!1````K?X``%H```#__@``
M5P```%K_```T````LO\```D```#G_P``#0```/'_```'````__\```H````'
M``$`#P```!(``0`%````(@`!``,````H``$`!@```"P``0`1````,P`!``@`
M``!%``$`"0```$X``0`)````6``!`!T```!B``$`#@```(```0`(````CP`!
M``H```"8``$`)0```*,``0`@````R0`!`!,```#J``$`$````/X``0`/````
M#P$!``\````?`0$`"@```"\!`0`'````.@$!``,```!"`0$`&0```$8!`0`/
M````8`$!`!0```!P`0$`"0```(4!`0`-````CP$!`!(```"=`0$`&0```+`!
M`0`>````R@$!``\```#I`0$`"@```/D!`0`/````!`(!``@````4`@$`"@``
M`!T"`0`D````*`(!`!<```!-`@$`%````&4"`0`6````>@(!`!(```"1`@$`
M"````*0"`0`<````K0(!`$X```#*`@$`+0```!D#`0`9````1P,!`&````!A
M`P$`*````,(#`0`>````ZP,!`!H````*!`$`+````"4$`0`@````4@0!`#(`
M``!S!`$`!P```*8$`0`,````K@0!``T```"[!`$`5````,D$`0!C````'@4!
M`"P```""!0$`#@```*\%`0`#````O@4!``L```#"!0$`!P```,X%`0`'````
MU@4!``4```#>!0$`!0```.0%`0`*````Z@4!``,```#U!0$`%P```/D%`0`*
M````$08!``\````<!@$`#@```"P&`0!.````.P8!`%````"*!@$`0P```-L&
M`0!"````'P<!`#T```!B!P$`%@```*`'`0`P````MP<!`!@```#H!P$`(P``
M``$(`0`.````)0@!`!0````T"`$`%P```$D(`0`7````80@!`!<```!Y"`$`
M$P```)$(`0`/````I0@!`",```"U"`$`!@```-D(`0`7````X`@!``X```#X
M"`$`40````<)`0`?````60D!`!T```!Y"0$`-0```)<)`0`U````S0D!``<`
M```#"@$`!@````L*`0`(````$@H!``\````;"@$`!@```"L*`0`(````,@H!
M`!$````["@$`"@```$T*`0`3````6`H!``L```!L"@$`$````'@*`0`5````
MB0H!``T```"?"@$`$P```*T*`0`C````P0H!`"\```#E"@$`%0```!4+`0`'
M````*PL!`!`````S"P$`!0```$0+`0`1````2@L!``P```!<"P$`/P```&D+
M`0`P````J0L!`$@```#:"P$`(0```",,`0`[````10P!`#L```"!#`$`/```
M`+T,`0`X````^@P!`"L````S#0$`,````%\-`0`Q````D`T!`#L```#"#0$`
M.0```/X-`0`U````.`X!``D```!N#@$`!P```'@.`0`,````@`X!``,```"-
M#@$`!0```)$.`0`)````EPX!`!````"A#@$`"0```+(.`0`3````O`X!``,`
M``#0#@$`.0```-0.`0`,````#@\!`#4````;#P$`#@```%$/`0!)````8`\!
M`#,```"J#P$`"@```-X/`0`6````Z0\!`"T`````$`$`"P```"X0`0`G````
M.A`!`"P```!B$`$`*@```(\0`0`E````NA`!``D```#@$`$`"0```.H0`0`*
M````]!`!``8```#_$`$`"0````81`0`'````$!$!`"\````8$0$`-P```$@1
M`0`N````@!$!`%4```"O$0$`+0````42`0`L````,Q(!`"T```!@$@$`/0``
M`(X2`0`_````S!(!`"T````,$P$`0````#H3`0`C````>Q,!`",```"?$P$`
M0````,,3`0`M````!!0!`#,````R%`$`)0```&84`0`5````C!0!`!D```"B
M%`$`*0```+P4`0`D````YA0!`"@````+%0$`4````#05`0`8````A14!`!$`
M``">%0$`$0```+`5`0`*````PA4!``P```#-%0$`"P```-H5`0`*````YA4!
M`",```#Q%0$`"@```!46`0`0````(!8!`!8````Q%@$`%@```$@6`0`N````
M7Q8!``<```".%@$`!P```)86`0`*````GA8!``@```"I%@$`)P```+(6`0`(
M````VA8!``,```#C%@$`!P```.<6`0`'````[Q8!``8```#W%@$`.````/X6
M`0`%````-Q<!``<````]%P$`!@```$47`0`(````3!<!``D```!5%P$`*0``
M`%\7`0`.````B1<!``H```"8%P$`10```*,7`0`$````Z1<!``0```#N%P$`
M!P```/,7`0`)````^Q<!``8````%&`$`$0````P8`0`'````'A@!`!8````F
M&`$`!````#T8`0`G````0A@!``@```!J&`$`!@```',8`0`-````>A@!``8`
M``"(&`$`'@```(\8`0`1````KA@!``@```#`&`$`#0```,D8`0`,````UQ@!
M``<```#D&`$``P```.P8`0`#````\!@!`!<```#T&`$`$P````P9`0`(````
M(!D!`!T````I&0$`"````$<9`0`$````4!D!``@```!5&0$`"````%X9`0`J
M````9QD!`"L```"2&0$`4P```+X9`0!!````$AH!`!H```!4&@$`*P```&\:
M`0`@````FQH!`!4```"\&@$`!@```-(:`0`&````V1H!``X```#@&@$`%0``
M`.\:`0`^````!1L!`!@```!$&P$`(@```%T;`0`N````@!L!`!T```"O&P$`
M(0```,T;`0!4````[QL!`"D```!$'`$`"@```&X<`0`'````>1P!`!4```"!
M'`$`#@```)<<`0`"````IAP!``H```"I'`$`#P```+0<`0`-````Q!P!``\`
M``#2'`$`#0```.(<`0`)````\!P!``8```#Z'`$`&`````$=`0`3````&AT!
M`!$````N'0$`%````$`=`0!/````51T!``0```"E'0$`#````*H=`0`&````
MMQT!``H```"^'0$`#0```,D=`0`4````UQT!`&(```#L'0$`)P```$\>`0!4
M````=QX!`%\```#,'@$`9````"P?`0`$````D1\!`!8```"6'P$`#@```*T?
M`0`<````O!\!``\```#9'P$`,P```.D?`0`H````'2`!``4```!&(`$`!0``
M`$P@`0`.````4B`!`!,```!A(`$`%0```'4@`0`P````BR`!`!$```"\(`$`
M$0```,X@`0`<````X"`!`"H```#](`$`-0```"@A`0!%````7B$!`!````"D
M(0$`(0```+4A`0`%````UR$!`!,```#=(0$`"P```/$A`0`2````_2$!``H`
M```0(@$`#P```!LB`0`-````*R(!`$<````Y(@$`'P```($B`0`E````H2(!
M`#,```#'(@$`*P```/LB`0`U````)R,!`$(```!=(P$`'0```*`C`0!1````
MOB,!`!$````0)`$`,0```"(D`0`[````5"0!`!,```"0)`$`0````*0D`0`X
M````Y20!``4````>)0$`#````"0E`0`1````,24!``T```!#)0$`!@```%$E
M`0`,````6"4!``8```!E)0$`%P```&PE`0`(````A"4!``P```"-)0$`%```
M`)HE`0`/````KR4!`!````"_)0$`$0```-`E`0`(````XB4!``4```#K)0$`
M$0```/$E`0`,`````R8!`!`````0)@$`!0```"$F`0`-````)R8!``8````U
M)@$`!P```#PF`0`-````1"8!``<```!2)@$`"P```%HF`0`'````9B8!``<`
M``!N)@$`"0```'8F`0`7````@"8!`"8```"8)@$`3P```+\F`0`)````#R<!
M``D````9)P$`"@```",G`0`9````+B<!`#T```!()P$`'0```(8G`0`,````
MI"<!`"4```"Q)P$`'P```-<G`0`0````]R<!``4````(*`$`)0````XH`0`B
M````-"@!`!(```!7*`$`$P```&HH`0`K````?B@!`#L```"J*`$`(````.8H
M`0`;````!RD!``@````C*0$`-@```"PI`0`A````8RD!`!````"%*0$`"```
M`)8I`0`;````GRD!`!X```"[*0$`+P```-HI`0!<````"BH!`"X```!G*@$`
M#````)8J`0`&````HRH!``0```"J*@$`#P```*\J`0`.````ORH!``X```#.
M*@$`!P```-TJ`0`.````Y2H!``H```#T*@$`#0```/\J`0`?````#2L!`!P`
M```M*P$`(0```$HK`0`>````;"L!`!D```"+*P$`'@```*4K`0`=````Q"L!
M`!L```#B*P$`+````/XK`0`@````*RP!`"X```!,+`$`)@```'LL`0`D````
MHBP!`!P```#'+`$`'@```.0L`0`<`````RT!`"8````@+0$`-@```$<M`0`K
M````?BT!`#,```"J+0$`*0```-XM`0!!````""X!`#H```!*+@$`)@```(4N
M`0`K````K"X!`#@```#8+@$`'0```!$O`0`5````+R\!`"\```!%+P$`(```
M`'4O`0`2````EB\!`"D```"I+P$`'@```-,O`0`]````\B\!`"`````P,`$`
M$@```%$P`0"B````9#`!`!8````',0$`(P```!XQ`0`H````0C$!`"D```!K
M,0$`.@```)4Q`0`H````T#$!`!\```#Y,0$`%0```!DR`0`@````+S(!`"4`
M``!0,@$`*````'8R`0`M````GS(!`#````#-,@$`D@```/XR`0`A````D3,!
M`!8```"S,P$`'````,HS`0`F````YS,!`"H````.-`$`00```#DT`0!$````
M>S0!``P```#`-`$`!P```,TT`0`'````U30!``8```#=-`$`#0```.0T`0`+
M````\C0!`!4```#^-`$`%````!0U`0`-````*34!`!@````W-0$`&@```%`U
M`0`0````:S4!`!T```!\-0$`&0```)HU`0!=````M#4!`!4````2-@$`)0``
M`"@V`0`2````3C8!`!,```!A-@$`$@```'4V`0`'````B#8!``0```"0-@$`
M$````)4V`0`0````IC8!``P```"W-@$`#@```,0V`0`-````TS8!``\```#A
M-@$`%````/$V`0`3````!C<!``T````:-P$`.0```"@W`0`<````8C<!`"@`
M``!_-P$``P```*@W`0`-````K#<!``8```"Z-P$`#@```,$W`0`"````T#<!
M`$D```#3-P$`!0```!TX`0`%````(S@!`!`````I.`$`#P```#HX`0`$````
M2C@!``T```!/.`$`#@```%TX`0`#````;#@!``X```!P.`$`"````'\X`0`/
M````B#@!``@```"8.`$`"@```*$X`0`/````K#@!``<```"\.`$`#0```,0X
M`0`0````TC@!`!0```#C.`$`#0```/@X`0`9````!CD!`!H````@.0$`"P``
M`#LY`0`)````1SD!``8```!1.0$`%````%@Y`0`+````;3D!`!,```!Y.0$`
M$````(TY`0`,````GCD!``H```"K.0$`$0```+8Y`0`7````R#D!`!$```#@
M.0$`%0```/(Y`0`G````"#H!`!D````P.@$`"P```$HZ`0`-````5CH!`"(`
M``!D.@$`*P```(<Z`0`7````LSH!`#0```#+.@$`,P`````[`0`;````-#L!
M`#0```!0.P$`"@```(4[`0`8````D#L!`!0```"I.P$`&0```+X[`0`6````
MV#L!``<```#O.P$`$````/<[`0`B````"#P!`!P````K/`$`'````$@\`0`-
M````93P!``<```!S/`$`#````'L\`0`F````B#P!``H```"O/`$`%````+H\
M`0`+````SSP!``<```#;/`$`(@```.,\`0`O````!CT!``L````V/0$`"0``
M`$(]`0`9````3#T!``L```!F/0$`*@```'(]`0`/````G3T!`!<```"M/0$`
M%P```,4]`0`)````W3T!``<```#G/0$`%@```.\]`0`/````!CX!`"T````6
M/@$`&0```$0^`0`6````7CX!``X```!U/@$`&@```(0^`0`H````GSX!`"T`
M``#(/@$`+@```/8^`0`+````)3\!`!@````Q/P$`"````$H_`0`,````4S\!
M`",```!@/P$`#0```(0_`0`F````DC\!`"H```"Y/P$`(````.0_`0!#````
M!4`!``@```!)0`$`$@```%)``0`?````94`!``0```"%0`$`"````(I``0`+
M````DT`!`!H```"?0`$`)P```+I``0`2````XD`!`"````#U0`$`+P```!9!
M`0`7````1D$!``4```!>00$`#````&1!`0`.````<4$!``X```"`00$`!0``
M`(]!`0`&````E4$!``X```"<00$``P```*M!`0`#````KT$!`"L```"S00$`
M!P```-]!`0`$````YT$!``X```#L00$`"@```/M!`0`,````!D(!``H````3
M0@$`#P```!Y"`0`0````+D(!`!<````_0@$`$P```%="`0`E````:T(!``X`
M``"10@$`$0```*!"`0`9````LD(!`!<```#,0@$`$P```.1"`0`6````^$(!
M`#@````/0P$`$P```$A#`0`)````7$,!``4```!F0P$`"P```&Q#`0`*````
M>$,!``(```"#0P$`!0```(9#`0`-````C$,!`!L```":0P$`%P```+9#`0`4
M````SD,!``D```#C0P$`'0```.U#`0`/````"T0!`!8````;1`$`$@```#)$
M`0`+````140!``P```!11`$`#@```%Y$`0`-````;40!`!(```![1`$`&0``
M`(Y$`0`<````J$0!`#@```#%1`$`&````/Y$`0`@````%T4!`!,````X10$`
M"0```$Q%`0`#````5D4!`!4```!:10$`"P```'!%`0`3````?$4!``@```"0
M10$`#@```)E%`0`0````J$4!`'L```"Y10$`&````#5&`0`8````3D8!`"<`
M``!G1@$`*0```(]&`0`L````N48!`"@```#F1@$`#@````]'`0`U````'D<!
M`!$```!41P$`!P```&9'`0`%````;D<!`"D```!T1P$`&````)Y'`0`>````
MMT<!`!L```#61P$`&0```/)'`0`8````#$@!`!L````E2`$`&0```$%(`0`3
M````6T@!``<```!O2`$`"````'=(`0`&````@$@!``8```"'2`$`&P```(Y(
M`0`0````JD@!``\```"[2`$`$````,M(`0`/````W$@!``L```#L2`$`#P``
M`/A(`0`,````"$D!``\````520$`!P```"5)`0`&````+4D!``H````T20$`
M$@```#])`0`-````4DD!``P```!@20$`#@```&U)`0!#````?$D!`#T```#`
M20$`"0```/Y)`0`,````"$H!`"@````52@$`#P```#Y*`0`(````3DH!``@`
M``!72@$`$P```&!*`0`+````=$H!`!X```"`2@$`(0```)]*`0`@````P4H!
M`!D```#B2@$`%P```/Q*`0`E````%$L!`!<````Z2P$`%@```%)+`0`$````
M:4L!`!L```!N2P$`#0```(I+`0`,````F$L!``,```"E2P$`!0```*E+`0`(
M````KTL!``H```"X2P$`#````,-+`0`*````T$L!`"````#;2P$`'P```/Q+
M`0`;````'$P!`!D````X3`$`"P```%),`0`;````7DP!``L```!Z3`$`$```
M`(9,`0`(````ETP!``P```"@3`$`!````*U,`0`$````LDP!`!,```"W3`$`
M%````,M,`0`,````X$P!``D```#M3`$`#@```/=,`0`+````!DT!`!L````2
M30$`#@```"Y-`0`/````/4T!`"4```!-30$`*@```'--`0`'````GDT!`!(`
M``"F30$`&P```+E-`0`$````U4T!``<```#:30$`"@```.)-`0`2````[4T!
M``H`````3@$`#0````M.`0`)````&4X!``0````C3@$`!0```"A.`0`(````
M+DX!``,````W3@$`&````#M.`0`=````5$X!`!````!R3@$`#@```(-.`0`>
M````DDX!`!H```"Q3@$`"@```,Q.`0`$````UTX!`"8```#<3@$`#@````-/
M`0!\````$D\!`!4```"/3P$`1````*5/`0`%````ZD\!``<```#P3P$`#```
M`/A/`0`(````!5`!``H````.4`$`!@```!E0`0`'````(%`!``@````H4`$`
M$0```#%0`0`9````0U`!``@```!=4`$``@```&90`0`&````:5`!``8```!P
M4`$`%````'=0`0`:````C%`!``T```"G4`$`$````+50`0`;````QE`!``4`
M``#B4`$`!````.A0`0`,````[5`!``D```#Z4`$`$`````11`0`)````%5$!
M``D````?40$`!````"E1`0`%````+E$!`!H````T40$`!0```$]1`0`:````
M55$!``@```!P40$`!@```'E1`0`/````@%$!`!D```"040$`#@```*I1`0`'
M````N5$!``<```#!40$`(@```,E1`0`%````[%$!``D```#R40$`"@```/Q1
M`0`"````!U(!``T````*4@$`(````!A2`0`&````.5(!``L```!`4@$`#0``
M`$Q2`0`,````6E(!``D```!G4@$`!@```'%2`0`)````>%(!``<```""4@$`
M%````(I2`0`=````GU(!`$(```"]4@$`)0````!3`0`E````)E,!``8```!,
M4P$`"@```%-3`0`$````7E,!``D```!C4P$`"````&U3`0`1````=E,!``D`
M``"(4P$`!@```))3`0`-````F5,!``8```"G4P$`!````*Y3`0`$````LU,!
M`!<```"X4P$`.0```-!3`0`]````"E0!`#H```!(5`$`'@```(-4`0`%````
MHE0!``X```"H5`$`!````+=4`0`&````O%0!``<```##5`$`(0```,M4`0`-
M````[50!``8```#[5`$`!`````)5`0`1````!U4!``8````950$`"@```"!5
M`0`B````*U4!`"<```!.50$`!@```'95`0`5````?54!``P```"350$`$0``
M`*!5`0`$````LE4!``T```"W50$`!P```,55`0`%````S54!`!T```#350$`
M!````/%5`0`,````]E4!``X````#5@$`"@```!)6`0`(````'58!``D````F
M5@$`!0```#!6`0`Z````-E8!`#````!Q5@$`-0```*)6`0`I````V%8!`$<`
M```"5P$`.````$I7`0`I````@U<!`#\```"M5P$`+@```.U7`0`M````'%@!
M`!\```!*6`$`#P```&I8`0`2````>E@!``L```"-6`$`)@```)E8`0`G````
MP%@!`"D```#H6`$`)````!)9`0`F````-UD!`"@```!>60$`"````(=9`0`*
M````D%D!``D```";60$`!P```*59`0`$````K5D!`!P```"R60$`-P```,]9
M`0`@````!UH!`"`````H6@$`)@```$E:`0`-````<%H!`"<```!^6@$`&P``
M`*9:`0`B````PEH!``P```#E6@$`%@```/):`0`%````"5L!``H````/6P$`
M&0```!I;`0`I````-%L!`!8```!>6P$`$@```'5;`0`'````B%L!``H```"0
M6P$`#````)M;`0`/````J%L!`!````"X6P$`0````,E;`0!$````"EP!`#P`
M``!/7`$`<````(Q<`0!F````_5P!``8```!D70$`"@```&M=`0`%````=ET!
M``X```!\70$`"0```(M=`0`*````E5T!`!(```"@70$`$P```+-=`0`,````
MQUT!``8```#470$`!@```-M=`0`*````XET!``X```#M70$`#P```/Q=`0`.
M````#%X!`!L````;7@$`'P```#=>`0`>````5UX!`",```!V7@$`$0```)I>
M`0`5````K%X!`!@```#"7@$`$0```-M>`0`0````[5X!`",```#^7@$`#P``
M`")?`0`)````,E\!`!(````\7P$`'0```$]?`0`2````;5\!`!````"`7P$`
M"@```)%?`0`1````G%\!``4```"N7P$`,0```+1?`0`D````YE\!`!P````+
M8`$`(P```"A@`0!J````3&`!``\```"W8`$`!0```,=@`0`0````S6`!``D`
M``#>8`$`!````.A@`0`+````[6`!`"````#Y8`$`'````!IA`0`C````-V$!
M`"(```!;80$`!@```'YA`0`4````A6$!`!<```":80$`#````+)A`0`D````
MOV$!`",```#D80$`&@````AB`0`,````(V(!``\````P8@$`%0```$!B`0`I
M````5F(!`"H```"`8@$`)@```*MB`0`G````TF(!`"D```#Z8@$`*@```"1C
M`0`9````3V,!`$(```!I8P$`$0```*QC`0`2````OF,!`!,```#18P$`%```
M`.5C`0`/````^F,!`!8````*9`$`%P```"%D`0`0````.60!`!$```!*9`$`
M-````%QD`0`3````D60!`!(```"E9`$`-0```+AD`0`4````[F0!``<````#
M90$`#`````ME`0`K````&&4!``\```!$90$`%@```%1E`0`@````:V4!`!``
M``",90$`%````)UE`0`1````LF4!`"@```#$90$`%P```.UE`0`<````!68!
M`!,````B9@$`"P```#9F`0`4````0F8!`!H```!79@$`$0```')F`0`:````
MA&8!`!X```"?9@$`&@```+YF`0`3````V68!`"$```#M9@$`(`````]G`0`5
M````,&<!`!$```!&9P$`%P```%AG`0`4````<&<!`!<```"%9P$`%0```)UG
M`0`)````LV<!``8```"]9P$`$````,1G`0`9````U6<!``0```#O9P$`!P``
M`/1G`0`+````_&<!`!$````(:`$`!@```!IH`0`&````(6@!``8````H:`$`
M!0```"]H`0`'````-6@!``<````]:`$`!0```$5H`0`&````2V@!``8```!2
M:`$`!````%EH`0`$````7F@!``<```!C:`$`#@```&MH`0`,````>F@!``P`
M``"':`$`#0```)1H`0`"````HF@!``H```"E:`$`#@```+!H`0`%````OV@!
M`"@```#%:`$`#@```.YH`0`,````_6@!``\````*:0$`"@```!II`0`(````
M)6D!``D````N:0$`*P```#AI`0!/````9&D!`$<```"T:0$`4P```/QI`0`N
M````4&H!``0```!_:@$`"````(1J`0`F````C6H!`!(```"T:@$`!@```,=J
M`0`*````SFH!``<```#9:@$`"````.%J`0`@````ZFH!``D````+:P$`$0``
M`!5K`0`)````)VL!`!0````Q:P$`#````$9K`0`-````4VL!``X```!A:P$`
M%@```'!K`0`1````AVL!``8```"9:P$``P```*!K`0`&````I&L!`!D```"K
M:P$`!P```,5K`0`$````S6L!``L```#2:P$`"P```-YK`0`'````ZFL!``4`
M``#R:P$`!P```/AK`0`6`````&P!``T````7;`$`#0```"5L`0`*````,VP!
M`!`````^;`$`#P```$]L`0`1````7VP!`!<```!Q;`$`"@```(EL`0`1````
ME&P!``@```"F;`$`!````*]L`0`1````M&P!``\```#&;`$`.@```-9L`0`A
M````$6T!``4````S;0$`%P```#EM`0`,````46T!`!X```!>;0$`#@```'UM
M`0`0````C&T!``L```"=;0$`?````*EM`0`,````)FX!``D````S;@$`!P``
M`#UN`0`*````16X!``D```!0;@$`#@```%IN`0`0````:6X!`!4```!Z;@$`
M&P```)!N`0`8````K&X!`!H```#%;@$`"@```.!N`0`)````ZVX!``H```#U
M;@$`#@````!O`0`,````#V\!``\````<;P$`"````"QO`0`&````-6\!``P`
M```\;P$`'````$EO`0`'````9F\!``4```!N;P$`"P```'1O`0!'````@&\!
M``T```#(;P$`"0```-9O`0`$````X&\!``,```#E;P$`#````.EO`0`3````
M]F\!`!,````*<`$`$P```!YP`0`&````,G`!``H````Y<`$``@```$1P`0`$
M````1W`!`"4```!,<`$``P```')P`0`%````=G`!`"H```!\<`$`#@```*=P
M`0`*````MG`!``4```#!<`$`!````,=P`0`*````S'`!``T```#7<`$`'P``
M`.5P`0`'````!7$!`"(````-<0$`#0```#!Q`0`&````/G$!``@```!%<0$`
M"````$YQ`0`$````5W$!``4```!<<0$`:````&)Q`0`)````RW$!``P```#5
M<0$`$````.)Q`0`%````\W$!``8```#Y<0$`(P````!R`0`E````)'(!``@`
M``!*<@$`-P```%-R`0`B````BW(!`!,```"N<@$`&P```,)R`0`O````WG(!
M`!`````.<P$`"@```!]S`0`1````*G,!``\````\<P$`#P```$QS`0`*````
M7',!``D```!G<P$`$P```'%S`0`;````A7,!`!@```"A<P$`%P```+IS`0`7
M````TG,!`!D```#J<P$`'P````1T`0`.````)'0!`"8````S=`$`)@```%IT
M`0`#````@70!``<```"%=`$`"````(UT`0`'````EG0!`!````">=`$`"@``
M`*]T`0`+````NG0!``<```#&=`$`$P```,YT`0`,````XG0!``\```#O=`$`
M#@```/]T`0`,````#G4!``X````;=0$`40```"IU`0`/````?'4!`!````",
M=0$`#0```)UU`0`/````JW4!``\```"[=0$`%P```,MU`0`4````XW4!`!$`
M``#X=0$`#P````IV`0`@````&G8!`"X````[=@$`&@```&IV`0`,````A78!
M`"8```"2=@$`"P```+EV`0`-````Q78!`!H```#3=@$`2@```.YV`0`9````
M.7<!``8```!3=P$`&@```%IW`0`E````=7<!``8```";=P$`!@```*)W`0`?
M````J7<!``8```#)=P$`"0```-!W`0`8````VG<!`!<```#S=P$`*`````MX
M`0`&````-'@!``T````[>`$`(@```$EX`0!7````;'@!`!,```#$>`$`(P``
M`-AX`0`3````_'@!``(````0>0$`"P```!-Y`0`(````'WD!``T````H>0$`
M!@```#9Y`0`*````/7D!``<```!(>0$`%````%!Y`0`&````97D!``@```!L
M>0$`#@```'5Y`0`'````A'D!``H```",>0$`"P```)=Y`0`R````HWD!`"L`
M``#6>0$`!P````)Z`0`,````"GH!``T````7>@$`#````"5Z`0`$````,GH!
M``D````W>@$`"0```$%Z`0`*````2WH!``<```!6>@$`"0```%YZ`0!`````
M:'H!``X```"I>@$`!P```+AZ`0`*````P'H!`!L```#+>@$`%0```.=Z`0`5
M````_7H!`!(````3>P$`"@```"9[`0`6````,7L!``D```!(>P$`$````%)[
M`0`'````8WL!`!(```!K>P$`!````'Y[`0`$````@WL!``0```"(>P$`(0``
M`(U[`0`'````KWL!``4```"W>P$`#````+U[`0`%````RGL!``L```#0>P$`
M%````-Q[`0`1````\7L!`!H````#?`$`%@```!Y\`0`4````-7P!`!<```!*
M?`$`&````&)\`0`<````>WP!`!D```"8?`$`!P```+)\`0`%````NGP!`!8`
M``#`?`$``P```-=\`0`-````VWP!``P```#I?`$`"@```/9\`0`(`````7T!
M``L````*?0$`$0```!9]`0`(````*'T!`!<````Q?0$`"P```$E]`0`,````
M57T!``P```!B?0$`'P```&]]`0`:````CWT!`!,```"J?0$`!````+Y]`0`*
M````PWT!``0```#.?0$`#0```--]`0`,````X7T!``D```#N?0$`#````/A]
M`0`%````!7X!``D````+?@$`!0```!5^`0`'````&WX!``4````C?@$`!```
M`"E^`0`"````+GX!`!0````Q?@$`#0```$9^`0`2````5'X!``L```!G?@$`
M&P```'-^`0`?````CWX!``\```"O?@$`%````+]^`0`>````U'X!`!4```#S
M?@$`.`````E_`0`L````0G\!`!(```!O?P$`*0```()_`0`R````K'\!``H`
M``#??P$`+````.I_`0`N````%X`!`#,```!&@`$`,P```'J``0`X````KH`!
M``\```#G@`$`&````/>``0`O````$($!`!````!`@0$`$P```%&!`0`J````
M98$!`!D```"0@0$`'````*J!`0`?````QX$!``\```#G@0$`$P```/>!`0`5
M````"X(!`!0````A@@$`%````#:"`0`@````2X(!`!(```!L@@$`%````'^"
M`0`5````E((!`"T```"J@@$`+0```-B"`0`Q````!H,!`"X````X@P$`+P``
M`&>#`0`L````EX,!`&(```#$@P$`$P```">$`0`E````.X0!`"0```!AA`$`
M*0```(:$`0!(````L(0!``T```#YA`$`"`````>%`0`7````$(4!``@````H
MA0$`)````#&%`0`2````5H4!``P```!IA0$`#@```':%`0`W````A84!`"L`
M``"]A0$`$@```.F%`0`A````_(4!`!H````>A@$`"0```#F&`0!%````0X8!
M`$$```")A@$`#P```,N&`0`$````VX8!`!,```#@A@$`#@```/2&`0`&````
M`X<!`!,````*AP$`&````!Z'`0`&````-X<!``D````^AP$`"@```$B'`0`+
M````4X<!``D```!?AP$`#0```&F'`0`,````=X<!``\```"$AP$`%P```)2'
M`0`4````K(<!`!````#!AP$`%@```-*'`0`'````Z8<!``X```#QAP$`(0``
M``"(`0`%````(H@!``<````HB`$`&P```#"(`0`J````3(@!``@```!WB`$`
M!@```("(`0`4````AX@!`!$```"<B`$`1````*Z(`0`\````\X@!``X````P
MB0$`.````#^)`0`"````>(D!``(```![B0$`!@```'Z)`0`.````A8D!``4`
M``"4B0$`!P```)J)`0`.````HHD!``8```"QB0$`*````+B)`0`,````X8D!
M``P```#NB0$`'````/N)`0`C````&(H!``0````\B@$`*0```$&*`0`R````
M:XH!`!<```">B@$`'P```+:*`0`S````UHH!`%P````*BP$`#````&>+`0`4
M````=(L!`#X```")BP$`#0```,B+`0`?````UHL!`!````#VBP$`%`````>,
M`0`'````'(P!``X````DC`$`#````#.,`0`,````0(P!`!,```!-C`$`"@``
M`&&,`0`=````;(P!`!D```"*C`$`!0```*2,`0`1````JHP!`!,```"\C`$`
M#0```-",`0`1````WHP!`"0```#PC`$`$@```!6-`0`#````*(T!`!4````L
MC0$`$P```$*-`0`2````5HT!``L```!IC0$`-````'6-`0`+````JHT!`!0`
M``"VC0$`/@```,N-`0`.````"HX!`!,````9C@$`-````"V.`0`Q````8HX!
M`!(```"4C@$`$````*>.`0`8````N(X!`!D```#1C@$`(P```.N.`0`B````
M#X\!`"<````RCP$`5@```%J/`0!-````L8\!`+D```#_CP$`"````+F0`0`)
M````PI`!``T```#,D`$`"@```-J0`0`'````Y9`!``\```#MD`$`!@```/V0
M`0`+````!)$!``0````0D0$`'````!61`0`-````,I$!`"<```!`D0$`&P``
M`&B1`0`,````A)$!`!H```"1D0$`"@```*R1`0`'````MY$!``T```"_D0$`
M(@```,V1`0`A````\)$!``@````2D@$`!0```!N2`0`?````(9(!``8```!!
MD@$`$````$B2`0`(````69(!``<```!BD@$`#0```&J2`0`*````>)(!`!(`
M``"#D@$`(0```):2`0`+````N)(!`!L```#$D@$`&````."2`0`(````^9(!
M`!X````"DP$`$@```"&3`0`L````-),!`!H```!ADP$`"0```'R3`0`*````
MAI,!`!4```"1DP$`!0```*>3`0`4````K9,!``0```#"DP$`$````,>3`0`&
M````V),!``<```#?DP$`'@```.>3`0`H````!I0!``H````OE`$`'````#J4
M`0`1````5Y0!``L```!IE`$`&@```'64`0`L````D)0!``@```"]E`$`%```
M`,:4`0`L````VY0!`"<````(E0$`*P```#"5`0`J````7)4!``0```"'E0$`
M!````(R5`0`+````D94!``4```"=E0$`!@```*.5`0`(````JI4!``8```"S
ME0$`,0```+J5`0`<````[)4!`*(````)E@$`&P```*R6`0`T````R)8!`#0`
M``#]E@$`(````#*7`0`I````4Y<!`"<```!]EP$`(````*67`0!!````QI<!
M`!H````(F`$`*````".8`0`:````3)@!`'8```!GF`$`>0```-Z8`0`<`0``
M6)D!`"@```!UF@$`'0```)Z:`0`I````O)H!`!T```#FF@$`4`````2;`0`N
M````59L!`#8```"$FP$`+````+N;`0`Q````Z)L!`"X````:G`$`(@```$F<
M`0`&````;)P!``@```!SG`$`!0```'R<`0`(````@IP!`!D```"+G`$`&0``
M`*6<`0`J````OYP!`!````#JG`$`*P```/N<`0`C````)YT!`!D```!+G0$`
M(0```&6=`0`N````AYT!`#0```"VG0$`"````.N=`0`7````])T!``H````,
MG@$`!P```!>>`0`A````'YX!`!````!!G@$`#0```%*>`0`0````8)X!``4`
M``!QG@$`#@```'>>`0`(````AIX!``L```"/G@$`%````)N>`0`'````L)X!
M`!,```"XG@$`"````,R>`0`V````U9X!`#<````,GP$`"P```$2?`0`)````
M4)\!``H```!:GP$`%````&6?`0`/````>I\!`"\```"*GP$`,@```+J?`0`+
M````[9\!``X```#YGP$`#0````B@`0`/````%J`!`!8````FH`$`/@```#V@
M`0`G````?*`!`"8```"DH`$`)````,N@`0`%````\*`!``4```#VH`$`!0``
M`/R@`0`G`````J$!`!\````JH0$`%@```$JA`0`+````8:$!`!<```!MH0$`
M#P```(6A`0`$````E:$!``H```":H0$`"0```*6A`0`+````KZ$!``T```"[
MH0$`#````,FA`0`.````UJ$!``4```#EH0$`!````.NA`0`-````\*$!`#(`
M``#^H0$`10```#&B`0`+````=Z(!``X```"#H@$`#@```)*B`0`)````H:(!
M``@```"KH@$`$````+2B`0`5````Q:(!`!,```#;H@$`%P```.^B`0`'````
M!Z,!`!X````/HP$`%0```"ZC`0`4````1*,!``4```!9HP$`%````%^C`0`&
M````=*,!``L```![HP$`!P```(>C`0`C````CZ,!`!8```"SHP$`#P```,JC
M`0`.````VJ,!`"H```#IHP$`!@```!2D`0`,````&Z0!`!@````HI`$`#0``
M`$&D`0`1````3Z0!``L```!AI`$`-@```&VD`0`-````I*0!``H```"RI`$`
M(@```+VD`0`+````X*0!``\```#LI`$`$````/RD`0`N````#:4!`#H````\
MI0$`#@```'>E`0`-````AJ4!``4```"4I0$`"P```)JE`0`,````IJ4!``T`
M``"SI0$`#0```,&E`0`.````SZ4!``T```#>I0$`(````.RE`0`G````#:8!
M`"L````UI@$`"````&&F`0`*````:J8!``8```!UI@$`$@```'RF`0`.````
MCZ8!`!<```">I@$`,@```+:F`0`6````Z:8!`!P`````IP$`)0```!VG`0`P
M````0Z<!`#$```!TIP$`+0```*:G`0`.````U*<!`!0```#CIP$`!0```/BG
M`0`.````_J<!`!,````-J`$`&@```"&H`0`2````/*@!``<```!/J`$`!@``
M`%>H`0`3````7J@!`!\```!RJ`$`%````)*H`0`1````IZ@!`$L```"YJ`$`
M$P````6I`0`'````&:D!`!0````AJ0$`&````#:I`0`'````3ZD!``4```!7
MJ0$`#````%VI`0`,````:JD!`!(```!WJ0$`!````(JI`0`'````CZD!``H`
M``"7J0$`"P```**I`0`,````KJD!``X```"[J0$`#@```,JI`0`%````V:D!
M``4```#?J0$`+@```.6I`0`F````%*H!`",````[J@$``P```%^J`0`2````
M8ZH!``8```!VJ@$`!@```'VJ`0`>````A*H!`!8```"CJ@$`&````+JJ`0`.
M````TZH!`#<```#BJ@$`#@```!JK`0`7````*:L!`$$```!!JP$`-````(.K
M`0`E````N*L!`!4```#>JP$`,0```/2K`0`3````)JP!`!L````ZK`$`*@``
M`%:L`0!1````@:P!`%D```#3K`$`4````"VM`0"_````?JT!`"4````^K@$`
M#0```&2N`0`$````<JX!``D```!WK@$`'P```(&N`0`#````H:X!``<```"E
MK@$`"@```*VN`0`(````N*X!``(```#!K@$`$````,2N`0`(````U:X!``P`
M``#>K@$`%0```.NN`0`+`````:\!`!D````-KP$`(````">O`0`2````2*\!
M``4```!;KP$`"@```&&O`0`5````;*\!`!(```""KP$`#````)6O`0`$````
MHJ\!``D```"GKP$`!P```+&O`0`R````N:\!``H```#LKP$`"@```/>O`0`5
M`````K`!``P````8L`$`#P```"6P`0`+````-;`!``<```!!L`$`%@```$FP
M`0!2````8+`!`#H```"SL`$`(````.ZP`0`/````#[$!`!<````?L0$`)```
M`#>Q`0`Y````7+$!`!(```"6L0$`!P```*FQ`0`&````L;$!``D```"XL0$`
M#@```,*Q`0`.````T;$!``X```#@L0$`!````.^Q`0`&````]+$!`!8```#[
ML0$`#````!*R`0`-````'[(!``X````ML@$`%0```#RR`0`2````4K(!``\`
M``!EL@$`%````'6R`0`4````BK(!`$,```"?L@$`"@```..R`0`;````[K(!
M`#4````*LP$`$0```$"S`0`0````4K,!``L```!CLP$`:0```&^S`0`:````
MV;,!`!<```#TLP$`*`````RT`0`G````-;0!`!L```!=M`$`&@```'FT`0`7
M````E+0!`!L```"LM`$`&0```,BT`0`?````XK0!`!<````"M0$`'````!JU
M`0`7````-[4!``P```!/M0$`$P```%RU`0`(````<+4!`"\```!YM0$`!P``
M`*FU`0`(````L;4!`!````"ZM0$`$0```,NU`0`)````W;4!`!4```#GM0$`
M#0```/VU`0`&````"[8!`!T````2M@$`(P```#"V`0`'````5+8!``T```!<
MM@$`$P```&JV`0`(````?K8!``,```"'M@$`1@```(NV`0!#````TK8!`#(`
M```6MP$`/P```$FW`0`W````B;<!`%<```#!MP$`!0```!FX`0`?````'[@!
M`"\````_N`$`"@```&^X`0`-````>K@!`!(```"(N`$`*0```)NX`0`(````
MQ;@!``T```#.N`$`+0```-RX`0!P````"KD!`#\```![N0$`.0```+NY`0!&
M````];D!``0````\N@$`$````$&Z`0`0````4KH!``P```!CN@$`%````'"Z
M`0`=````A;H!`!P```"CN@$`$0```,"Z`0`]````TKH!`$\````0NP$`)0``
M`&"[`0`@````AKL!`!P```"GNP$`"P```,2[`0`G````T+L!`!H```#XNP$`
M'P```!.\`0`=````,[P!`"@```!1O`$`#P```'J\`0`E````BKP!`"````"P
MO`$`)````-&\`0`D````]KP!`"`````;O0$`)0```#R]`0`+````8KT!``<`
M``!NO0$`#0```':]`0`,````A+T!`!<```"1O0$`!0```*F]`0`&````K[T!
M`#D```"VO0$`!0```/"]`0`,````]KT!``<````#O@$`"0````N^`0`3````
M%;X!``8````IO@$`"0```#"^`0`$````.KX!`!`````_O@$`"````%"^`0`(
M````6;X!``0```!BO@$`"P```&>^`0`,````<[X!`!(```"`O@$`$0```).^
M`0`,````I;X!`!H```"RO@$`#P```,V^`0`'````W;X!``T```#EO@$`#P``
M`/.^`0`,`````[\!`!0````0OP$`%````"6_`0`/````.K\!``X```!*OP$`
M$@```%F_`0`4````;+\!``X```"!OP$`#````)"_`0`L````G;\!`!,```#*
MOP$`'````-Z_`0`H````^[\!``8````DP`$`!P```"O``0`3````,\`!``4`
M``!'P`$`!````$W``0`,````4L`!`!<```!?P`$`$@```'?``0`I````BL`!
M``L```"TP`$`#0```,#``0`4````SL`!`"\```#CP`$`"@```!/!`0`,````
M'L$!``D````KP0$`!@```#7!`0`)````/,$!``@```!&P0$`"0```$_!`0`%
M````6<$!``H```!?P0$`$0```&K!`0`*````?,$!`!````"'P0$`$````)C!
M`0`+````J<$!``8```"UP0$`#@```+S!`0`.````R\$!``T```#:P0$`"P``
M`.C!`0`0````],$!`!T````%P@$`$0```"/"`0`+````-<(!``(```!!P@$`
M"````$3"`0`<````3<(!``<```!JP@$`#0```'+"`0`&````@,(!`&0```"'
MP@$`%@```.S"`0`)`````\,!``<````-PP$`)@```!7#`0`X````/,,!`!H`
M``!UPP$`*@```)##`0`[````N\,!`"@```#WPP$`-````"#$`0`9````5<0!
M`!4```!OQ`$`!0```(7$`0`+````B\0!``<```"7Q`$`"````)_$`0`'````
MJ,0!``4```"PQ`$`!P```+;$`0`.````OL0!``D```#-Q`$`!@```-?$`0`(
M````WL0!``L```#GQ`$`!P```//$`0`(````^\0!``<````$Q0$`%@````S%
M`0`)````(\4!``8````MQ0$`&0```#3%`0`:````3L4!`"````!IQ0$`"P``
M`(K%`0`0````EL4!``8```"GQ0$`'````*[%`0`4````R\4!``<```#@Q0$`
M$0```.C%`0`(````^L4!``X````#Q@$`"````!+&`0`%````&\8!`!`````A
MQ@$`$````#+&`0`&````0\8!`!D```!*Q@$`"@```&3&`0`<````;\8!``<`
M``",Q@$`!0```)3&`0`%````FL8!`!````"@Q@$`%````+'&`0`+````QL8!
M``T```#2Q@$`*````.#&`0`8````"<<!`!<````BQP$`"P```#K'`0`:````
M1L<!`!0```!AQP$`+P```';'`0`$````IL<!``D```"KQP$`"@```+7'`0`'
M````P,<!``(```#(QP$`"````,O'`0`C````U,<!`#$```#XQP$`.````"K(
M`0!X````8\@!`"8```#<R`$`&P````/)`0`Q````'\D!`#$```!1R0$`)P``
M`(/)`0`B````J\D!`"````#.R0$`9````._)`0`=````5,H!`!0```!RR@$`
M'````(?*`0!=````I,H!`%4````"RP$`.````%C+`0`M````D<L!`#,```"_
MRP$`2P```//+`0!*````/\P!`%L```"*S`$`*````.;,`0`L````#\T!`#@`
M```\S0$`)0```'7-`0`A````F\T!`"@```"]S0$`+````.;-`0`F````$\X!
M`!L````ZS@$`'@```%;.`0!U````=<X!`#X```#KS@$`0@```"K/`0`]````
M;<\!`#T```"KSP$`*0```.G/`0`I````$]`!`#$````]T`$`/@```&_0`0`O
M````KM`!`*D!``#>T`$`(P```(C2`0!B````K-(!`$\````/TP$`%P```%_3
M`0!(````=],!`#8```#`TP$`/@```/?3`0`P````-M0!`"````!GU`$`/P``
M`(C4`0`T````R-0!`!T```#]U`$`'@```!O5`0`J````.M4!`(4```!EU0$`
M,````.O5`0`E````'-8!`$$```!"U@$`8````(36`0!;````Y=8!`$D```!!
MUP$`,0```(O7`0`T````O=<!`#P```#RUP$`.````"_8`0`=````:-@!`!@`
M``"&V`$`IP```)_8`0`K````1]D!`"$```!SV0$`'P```)79`0`\````M=D!
M`"0```#RV0$`*````!?:`0`K````0-H!`"(```!LV@$`(0```(_:`0`C````
ML=H!`"4```#5V@$`)0```/O:`0`I````(=L!`"<```!+VP$`%P```'/;`0`I
M````B]L!`"````"UVP$`,@```-;;`0`<````"=P!`"X````FW`$`.@```%7<
M`0`=````D-P!`!$```"NW`$`,P```,#<`0`E````]-P!`#@````:W0$`)P``
M`%/=`0`@````>]T!`#P```"<W0$`)@```-G=`0`?`````-X!`#`````@W@$`
M:0```%'>`0`N````N]X!`#$```#JW@$`00```!S?`0`^````7M\!`#,```"=
MWP$`)0```-'?`0`]````]]\!`&4````UX`$`30```)O@`0!3````Z>`!`%<`
M```]X0$`50```)7A`0!&````Z^$!`"H````RX@$`+P```%WB`0!5````C>(!
M`"````#CX@$`+@````3C`0`K````,^,!`#````!?XP$`*@```)#C`0`^````
MN^,!`%0```#ZXP$`4@```$_D`0!:````HN0!`#(```#]Y`$`*P```##E`0!(
M````7.4!`$H```"EY0$`*@```/#E`0`F````&^8!`"P```!"Y@$`3@```&_F
M`0`R````ON8!`#````#QY@$`'0```"+G`0`C````0.<!`"\```!DYP$`+```
M`)3G`0`M````P><!`'$```#OYP$`9@```&'H`0!O````R.@!`+,````XZ0$`
M%P```.SI`0`E````!.H!`#(````JZ@$`*0```%WJ`0`^````A^H!`"(```#&
MZ@$`4@```.GJ`0`E````/.L!``L```!BZP$`L0```&[K`0`[````(.P!`"<`
M``!<[`$`3@```(3L`0!'````T^P!`&(````;[0$`20```'[M`0!5````R.T!
M`$`````>[@$`+P```%_N`0`R````C^X!`"L```#"[@$`*0```.[N`0`/````
M&.\!`$4````H[P$`(0```&[O`0`P````D.\!`"T```#![P$`)0```._O`0`<
M````%?`!`#$````R\`$`,0```&3P`0`+````EO`!``<```"B\`$`!P```*KP
M`0`$````LO`!``T```"W\`$`"P```,7P`0`.````T?`!``L```#@\`$`!0``
M`.SP`0`0````\O`!``(````#\0$`"@````;Q`0!6````$?$!`%D```!H\0$`
M3@```,+Q`0`%````$?(!`!(````7\@$`!````"KR`0`'````+_(!``@````W
M\@$`!0```$#R`0`#````1O(!`!````!*\@$`%P```%OR`0`,````<_(!``P`
M``"`\@$`#0```(WR`0`3````F_(!``T```"O\@$``@```+WR`0`'````P/(!
M``8```#(\@$`#````,_R`0`8````W/(!``8```#U\@$`$@```/SR`0`,````
M#_,!``,````<\P$`*@```"#S`0`$````2_,!``8```!0\P$`!P```%?S`0`?
M````7_,!`#4```!_\P$`+@```+7S`0`O````Y/,!`!<````4]`$`(@```"ST
M`0`E````3_0!`"````!U]`$`&P```);T`0`8````LO0!`"0```#+]`$`'P``
M`/#T`0`:````$/4!`"$````K]0$`(````$WU`0`:````;O4!`#(```")]0$`
M&@```+SU`0`O````U_4!`"L````']@$`'P```#/V`0`C````4_8!`!\```!W
M]@$`&@```)?V`0`A````LO8!`"4```#4]@$`)@```/KV`0`E````(?<!`"0`
M``!']P$`&````&SW`0`=````A?<!`"0```"C]P$`&````,CW`0`B````X?<!
M`"P````$^`$`+P```#'X`0`5````8?@!`"4```!W^`$`/````)WX`0`?````
MVO@!`",```#Z^`$`'P```![Y`0`@````/OD!`!H```!?^0$`&````'KY`0`8
M````D_D!`"8```"L^0$`'@```-/Y`0`I````\OD!`!X````<^@$`,0```#OZ
M`0`*````;?H!`!,```!X^@$`"````(SZ`0`)````E?H!`!8```"?^@$`#```
M`+;Z`0`7````P_H!`"\```#;^@$`)`````O[`0`'````,/L!`!\````X^P$`
M%````%C[`0`.````;?L!``T```!\^P$`!0```(K[`0`'````D/L!``P```"8
M^P$`.P```*7[`0`/````X?L!`!$```#Q^P$`(@````/\`0`E````)OP!`!H`
M``!,_`$`'0```&?\`0`:````A?P!`!$```"@_`$`!P```++\`0#'````NOP!
M``8```""_0$`"P```(G]`0`:````E?T!`!4```"P_0$`!@```,;]`0`)````
MS?T!`!@```#7_0$`"P```/#]`0`-````_/T!`!<````*_@$`!@```"+^`0`S
M````*?X!`!,```!=_@$`$P```''^`0`'````A?X!``\```"-_@$`$0```)W^
M`0`>````K_X!``<```#._@$`&0```-;^`0`R````\/X!``0````C_P$`1@``
M`"C_`0`A````;_\!`!,```"1_P$`#````*7_`0`1````LO\!`#(```#$_P$`
M%@```/?_`0`(````#@`"`!T````7``(`"0```#4``@`*````/P`"`!0```!*
M``(`"@```%\``@`=````:@`"``@```"(``(`'P```)$``@`(````L0`"`!H`
M``"Z``(`)P```-4``@`&````_0`"`!4````$`0(`!P```!H!`@`(````(@$"
M``D````K`0(`/P```#4!`@`'````=0$"``\```!]`0(`#@```(T!`@`0````
MG`$"``D```"M`0(`"0```+<!`@`(````P0$"``0```#*`0(`!P```,\!`@`2
M````UP$"`"8```#J`0(`#0```!$"`@`9````'P("`!@````Y`@(`"P```%("
M`@`.````7@("`!D```!M`@(`"@```(<"`@`D````D@("`"$```"W`@(`"@``
M`-D"`@`3````Y`("`"<```#X`@(`"0```"`#`@`/````*@,"`!<````Z`P(`
M%````%(#`@`H````9P,"`!X```"0`P(`#P```*\#`@`@````OP,"``T```#@
M`P(`%````.X#`@`-`````P0"`!0````1!`(`)````"8$`@`4````2P0"``H`
M``!@!`(`#````&L$`@`7````>`0"``0```"0!`(`*@```)4$`@`,````P`0"
M`!$```#-!`(`!P```-\$`@`"````YP0"`!````#J!`(`&````/L$`@`+````
M%`4"``,````@!0(`"````"0%`@`&````+04"``<````T!0(`#0```#P%`@`+
M````2@4"``X```!6!0(`+P```&4%`@`@````E04"`!P```"V!0(`5P```-,%
M`@!:````*P8"`#\```"&!@(`-@```,8&`@!^````_08"`!4```!\!P(`#```
M`)('`@`Q````GP<"``D```#1!P(`!0```-L'`@`2````X0<"`#\```#T!P(`
M$@```#0(`@`*````1P@"``8```!2"`(`!````%D(`@`$````7@@"``H```!C
M"`(`$P```&X(`@`%````@@@"``8```"("`(`!@```(\(`@`(````E@@"``0`
M``"?"`(`#````*0(`@`*````L0@"`#D```"\"`(`+@```/8(`@`I````)0D"
M``4```!/"0(`&````%4)`@`9````;@D"`!\```"("0(`'0```*@)`@`1````
MQ@D"``(```#8"0(`!````-L)`@`*````X`D"``8```#K"0(`!0```/()`@`#
M````^`D"``P```#\"0(`.P````D*`@!/````10H"`#4```"5"@(`)P```,L*
M`@`A````\PH"`"0````5"P(`10```#H+`@`F````@`L"`#(```"G"P(`,P``
M`-H+`@`:````#@P"`!T````I#`(`>````$<,`@`T````P`P"`"$```#U#`(`
M5@```!<-`@`H````;@T"`%,```"7#0(`.@```.L-`@!"````)@X"`!D```!I
M#@(`%P```(,.`@`E````FPX"`!D```#!#@(`*@```-L.`@`K````!@\"`'(`
M```R#P(`(````*4/`@`U````Q@\"`"$```#\#P(`10```!X0`@`F````9!`"
M`#````"+$`(`2P```+P0`@!.````"!$"`"<```!7$0(`*0```'\1`@`A````
MJ1$"`"@```#+$0(`*P```/01`@`=````(!("`"D````^$@(`)@```&@2`@`E
M````CQ("`"@```"U$@(`*````-X2`@`B````!Q,"`#H````J$P(`*P```&43
M`@`I````D1,"`"(```"[$P(`/0```-X3`@!!````'!0"`"@```!>%`(`+```
M`(<4`@`P````M!0"`!(```#E%`(`$P```/@4`@`0````#!4"`'D````=%0(`
M"0```)<5`@`<````H14"`!````"^%0(`#P```,\5`@`K````WQ4"`"<````+
M%@(`#@```#,6`@!+````0A8"`*$```".%@(`<P```#`7`@!\````I!<"`$``
M```A&`(`*P```&(8`@!4````CA@"`!<```#C&`(`*@```/L8`@`T````)AD"
M`"<```!;&0(`%@```(,9`@`/````FAD"`*\```"J&0(`%P```%H:`@`H````
M<AH"`!\```";&@(`0````+L:`@`?````_!H"`!P````<&P(`40```#D;`@`:
M````BQL"`!0```"F&P(`#P```+L;`@`*````RQL"``4```#6&P(`!@```-P;
M`@`(````XQL"``4```#L&P(`$````/(;`@`2`````QP"``P````6'`(`$```
M`",<`@`1````-!P"`!,```!&'`(`'0```%H<`@`@````>!P"``\```"9'`(`
M#P```*D<`@`$````N1P"``H```"^'`(`!````,D<`@`#````SAP"``D```#2
M'`(`!P```-P<`@`+````Y!P"``@```#P'`(`!P```/D<`@`%`````1T"``D`
M```''0(`%````!$=`@`&````)AT"``<````M'0(`"````#4=`@`/````/AT"
M``\```!.'0(`#````%X=`@`(````:QT"``P```!T'0(`!@```($=`@`)````
MB!T"``L```"2'0(`#P```)X=`@`&````KAT"``<```"U'0(`#0```+T=`@`&
M````RQT"`!0```#2'0(`!P```.<=`@`#````[QT"``D```#S'0(`!@```/T=
M`@`,````!!X"``H````1'@(`#````!P>`@`1````*1X"``H````['@(`#P``
M`$8>`@`%````5AX"``@```!<'@(`!````&4>`@`9````:AX"`!$```"$'@(`
M"@```)8>`@`8````H1X"`!,```"Z'@(`'````,X>`@`1````ZQX"``\```#]
M'@(`!P````T?`@`$````%1\"``0````:'P(`&0```!\?`@`'````.1\"``(`
M``!!'P(``@```$0?`@`1````1Q\"``D```!9'P(`!@```&,?`@`2````:A\"
M`!<```!]'P(``P```)4?`@`&````F1\"``P```"@'P(`)P```*T?`@`"````
MU1\"``0```#8'P(`!````-T?`@`/````XA\"`!,```#R'P(`!P````8@`@`"
M````#B`"``<````1(`(`$0```!D@`@`&````*R`"``L````R(`(`&````#X@
M`@`&````5R`"`!,```!>(`(`$````'(@`@`2````@R`"``X```"6(`(`#P``
M`*4@`@`"````M2`"``8```"X(`(`#````+\@`@`)````S"`"`!$```#6(`(`
M(@```.@@`@`'````"R$"``<````3(0(`"P```!LA`@`%````)R$"``(````M
M(0(`"P```#`A`@`.````/"$"``X```!+(0(`2`$``%HA`@`*````HR("``P`
M``"N(@(`#````+LB`@`,````R"("`!````#5(@(`%P```.8B`@`+````_B("
M``8````*(P(`"0```!$C`@`(````&R,"``P````D(P(`"@```#$C`@`#````
M/","`!0```!`(P(`&0```%4C`@`M````;R,"`"4```"=(P(`)0```,,C`@`C
M````Z2,"`!\````-)`(``0```"TD`@`9````+R0"`"T```!))`(`"@```'<D
M`@`(````@B0"`"H```"+)`(`&@```+8D`@!,````T20"`#P````>)0(`4```
M`%LE`@`V````K"4"`!H```#C)0(`$P```/XE`@`-````$B8"``L````@)@(`
M!0```"PF`@`M````,B8"``T```!@)@(`'0```&XF`@`5````C"8"``\```"B
M)@(`,P```+(F`@`1````YB8"`"@```#X)@(`,@```"$G`@`.````5"<"``\`
M``!C)P(`#````',G`@`Z````@"<"`"$```"[)P(`+````-TG`@`8````"B@"
M`'0````C*`(`#@```)@H`@`(````IR@"`!$```"P*`(`,````,(H`@`D````
M\R@"``T````8*0(`(0```"8I`@`7````2"D"`"````!@*0(`+0```($I`@`6
M````KRD"`!<```#&*0(`%P```-XI`@`:````]BD"``8````1*@(`&@```!@J
M`@"_````,RH"`#P```#S*@(`,P```#`K`@`&````9"L"``H```!K*P(`<P``
M`'8K`@!J````ZBL"`!P```!5+`(`'````'(L`@`+````CRP"`!(```";+`(`
M'0```*XL`@`0````S"P"`!<```#=+`(`6````/4L`@`Y````3BT"`%$```"(
M+0(`-P```-HM`@`*````$BX"``L````=+@(`$@```"DN`@`2````/"X"``@`
M``!/+@(`"@```%@N`@`*````8RX"``\```!N+@(`,````'XN`@`9````KRX"
M`#@```#)+@(`10````(O`@`V````2"\"`#T```!_+P(`4````+TO`@!/````
M#C`"`%@```!>,`(`5@```+<P`@`X````#C$"`!0```!',0(`%P```%PQ`@`1
M````=#$"`!4```"&,0(`'0```)PQ`@`(````NC$"``D```##,0(`!@```,TQ
M`@`/````U#$"``0```#D,0(`$````.DQ`@`/````^C$"`"(````*,@(`$0``
M`"TR`@`'````/S("``D```!',@(`,@```%$R`@`P````A#("`!$```"U,@(`
M#@```,<R`@`1````UC("``L```#H,@(`"0```/0R`@`%````_C("``8````$
M,P(`&P````LS`@`9````)S,"`!<```!!,P(`!P```%DS`@`.````83,"`!$`
M``!P,P(`'@```((S`@`<````H3,"`!,```"^,P(`#0```-(S`@`-````X#,"
M``H```#N,P(`#````/DS`@`F````!C0"`!D````M-`(`$P```$<T`@`8````
M6S0"`!D```!T-`(`$@```(XT`@`;````H30"`%0```"]-`(`-P```!(U`@`D
M````2C4"`&<```!O-0(`*````-<U`@`2`````#8"`!4````3-@(`+````"DV
M`@`>````5C8"`#4```!U-@(`!@```*LV`@`'````LC8"``@```"Z-@(`?P``
M`,,V`@!V````0S<"`#8```"Z-P(`#0```/$W`@`'````_S<"``H````'.`(`
M"````!(X`@`(````&S@"``4````D.`(`"````"HX`@`+````,S@"``8````_
M.`(`(P```$8X`@`.````:C@"``P```!Y.`(`$P```(8X`@!,````FC@"`$X`
M``#G.`(`1P```#8Y`@!'````?CD"`%0```#&.0(`'@```!LZ`@!!````.CH"
M`!8```!\.@(`*P```),Z`@`+````OSH"`"0```#+.@(`%P```/`Z`@`D````
M"#L"`!T````M.P(`%````$L[`@`2````8#L"`",```!S.P(`!````)<[`@`4
M````G#L"``X```"Q.P(`/````,`[`@`<````_3L"`!8````:/`(`-P```#$\
M`@`T````:3P"``<```">/`(`!@```*8\`@`(````K3P"``X```"V/`(`!P``
M`,4\`@`+````S3P"`!(```#9/`(`"@```.P\`@`1````]SP"``D````)/0(`
M$````!,]`@`8````)#T"`!`````]/0(`%@```$X]`@`N````93T"`%````"4
M/0(`*@```.4]`@`(````$#X"`!$````9/@(`!0```"L^`@`/````,3X"``P`
M``!!/@(`.P```$X^`@`I````BCX"`#P```"T/@(`&````/$^`@`Q````"C\"
M`"P````\/P(`+````&D_`@`O````EC\"`"D```#&/P(`+0```/`_`@`A````
M'D`"`"0```!`0`(`+P```&5``@`_````E4`"``D```#50`(`"````-]``@`-
M````Z$`"``8```#V0`(`!0```/U``@`)`````T$"`!`````-00(`#````!Y!
M`@`5````*T$"``D```!!00(`-````$M!`@`/````@$$"`"(```"000(`$```
M`+-!`@!0````Q$$"`#0````50@(`!P```$I"`@`9````4D("`"P```!L0@(`
M!P```)E"`@`H````H4("`"<```#*0@(`)````/)"`@`Q````%T,"``D```!)
M0P(`!0```%-#`@`(````64,"``8```!B0P(`"0```&E#`@`'````<T,"`#<`
M``![0P(`+P```+-#`@`V````XT,"`%X````:1`(`-0```'E$`@`T````KT0"
M`#4```#D1`(`2@```!I%`@!+````944"`#4```"Q10(`0@```.=%`@`Q````
M*D8"`#0```!<1@(`3````)%&`@`U````WD8"`#L````41P(`+````%!'`@`6
M````?4<"`!H```"41P(`)@```*]'`@`K````UD<"`"L````"2`(`10```"Y(
M`@`2````=$@"`!$```"'2`(`$@```)E(`@`+````K$@"``P```"X2`(`"P``
M`,5(`@`*````T4@"`"(```#<2`(`!P```/](`@`-````!TD"`!<````520(`
M)````"U)`@`Z````4DD"``8```"-20(`!P```)1)`@`)````G$D"``@```"F
M20(`*````*])`@`/````V$D"``,```#H20(`"@```.Q)`@`(````]TD"``8`
M````2@(`)@````=*`@`%````+DH"``<````T2@(`!0```#Q*`@`*````0DH"
M``X```!-2@(`)P```%Q*`@`0````A$H"``D```"52@(`00```)]*`@`$````
MX4H"``4```#F2@(`!P```.Q*`@`'````]$H"``4```#\2@(`#0````)+`@`&
M````$$L"`!,````72P(``P```"M+`@`6````+TL"``@```!&2P(`!@```$]+
M`@`-````5DL"``@```!D2P(`(````&U+`@`1````CDL"``D```"@2P(`$@``
M`*I+`@`,````O4L"``<```#*2P(``P```-)+`@`#````UDL"`!0```#:2P(`
M%````.]+`@`-````!$P"`#(````23`(`"````$5,`@`)````3DP"``@```!8
M3`(`!P```&%,`@`U````:4P"`#8```"?3`(`1P```-9,`@!+````'DT"`"0`
M``!J30(`+0```(]-`@`H````O4T"`"$```#F30(`!@````A.`@`&````#TX"
M``T````63@(`&````"1.`@`K````/4X"`"$```!I3@(`)````(M.`@`N````
ML$X"`"4```#?3@(`+0````5/`@!@````,T\"`"X```"43P(`$@```,-/`@`'
M````UD\"`!,```#>3P(`$0```/)/`@`"````!%`"``\````'4`(`$````!=0
M`@`0````*%`"`!`````Y4`(`$````$I0`@`/````6U`"``D```!K4`(`%P``
M`'50`@`A````C5`"`!0```"O4`(`&````,10`@!9````W5`"``,````W40(`
M!@```#M1`@`&````0E$"``T```!)40(`$````%=1`@`1````:%$"`%,```!Z
M40(`-0```,Y1`@!5````!%("`%0```!:4@(`7````*]2`@`$````#%,"`!L`
M```14P(`%@```"U3`@`B````1%,"`!@```!G4P(`0P```(!3`@`L````Q%,"
M``4```#Q4P(`!````/=3`@`.````_%,"`!(````+5`(`%P```!Y4`@`W````
M-E0"``\```!N5`(`'````'Y4`@`D````FU0"`#````#`5`(`/@```/%4`@!)
M````,%4"``\```!Z50(`(P```(I5`@`%````KE4"`!H```"T50(`#0```,]5
M`@`9````W54"`!4```#W50(`&P````U6`@`1````*58"`$T````[5@(`(P``
M`(E6`@`I````K58"`#H```#75@(`,P```!)7`@`V````1E<"`$8```!]5P(`
M)````,17`@!?````Z5<"`!D```!)6`(`.P```&-8`@`]````GU@"`!,```#=
M6`(`/````/%8`@`D````+ED"``@```!360(`#0```%Q9`@`-````:ED"`!,`
M``!X60(`!@```(Q9`@`,````DUD"``<```"@60(`%P```*A9`@`&````P%D"
M``T```#'60(`%P```-59`@`0````[5D"`!(```#^60(`#@```!%:`@`(````
M(%H"``4````I6@(`#0```"]:`@`+````/5H"``L```!)6@(`!P```%5:`@`/
M````75H"``8```!M6@(`!@```'1:`@`5````>UH"``@```"16@(`"@```)I:
M`@`&````I5H"``H```"L6@(`!@```+=:`@`3````OEH"`!H```#26@(`3```
M`.U:`@`(````.EL"``0```!#6P(`!````$A;`@`7````35L"`$P```!E6P(`
M)````+);`@`/````UUL"`",```#G6P(`(P````M<`@`.````+UP"``4````^
M7`(`'````$1<`@`=````85P"`!$```!_7`(`$@```)%<`@`N````I%P"`#T`
M``#37`(`(````!%=`@`<````,ET"``@```!/70(`,````%A=`@`:````B5T"
M``H```"D70(`"@```*]=`@`H````NET"`"L```#C70(`)0````]>`@!R````
M-5X"`"L```"H7@(`#P```-1>`@`&````Y%X"``H```#K7@(`%P```/9>`@`/
M````#E\"`!<````>7P(`!P```#9?`@`-````/E\"``D```!,7P(`$@```%9?
M`@`M````:5\"`"L```"77P(`+P```,-?`@`M````\U\"`"$````A8`(`)@``
M`$-@`@`E````:F`"`"D```"08`(`+````+I@`@`I````YV`"`#4````180(`
M*P```$=A`@`F````<V$"`"0```":80(`)@```+]A`@`A````YF$"`"H````(
M8@(`'P```#-B`@`Z````4V("`"X```".8@(`(````+UB`@`R````WF("`"\`
M```18P(`)````$%C`@`P````9F,"`#D```"78P(`)0```-%C`@`A````]V,"
M`#0````99`(`)0```$YD`@`9````=&0"`"\```".9`(`(P```+YD`@!"````
MXF0"`"8````E90(`&@```$QE`@"Q````9V4"`!(````99@(`(````"QF`@`I
M````368"`"D```!W9@(`1````*%F`@`Q````YF8"`"(````89P(`(0```#MG
M`@`E````76<"`"D```"#9P(`+````*UG`@`Z````VF<"`"P````5:`(`DP``
M`$)H`@`E````UF@"`!L```#\:`(`)@```!AI`@`O````/VD"`"\```!O:0(`
M1@```)]I`@!$````YFD"``T````K:@(`!P```#EJ`@`%````06H"``@```!'
M:@(`$@```%!J`@`.````8VH"`!P```!R:@(`$@```(]J`@`.````HFH"`!T`
M``"Q:@(`(0```,]J`@`-````\6H"`"<```#_:@(`&P```"=K`@!Z````0VL"
M`!4```"^:P(`'````-1K`@`5````\6L"``P````';`(`%0```!1L`@`*````
M*FP"``0````U;`(`#P```#IL`@`0````2FP"``P```!;;`(`#P```&AL`@`5
M````>&P"`!````".;`(`%@```)]L`@`4````MFP"``T```#+;`(`-````-EL
M`@`=````#FT"`$(````L;0(`"@```&]M`@`0````>FT"``8```"+;0(`#P``
M`))M`@`"````HFT"`$L```"E;0(`!0```/%M`@`&````]VT"`",```#^;0(`
M%P```")N`@`%````.FX"``X```!`;@(`#````$]N`@`#````7&X"`!$```!@
M;@(`"````')N`@`0````>VX"``H```",;@(`#````)=N`@`1````I&X"``T`
M``"V;@(`$P```,1N`@`;````V&X"`!L```#T;@(`(P```!!O`@`B````-&\"
M`!T```!7;P(`"0```'5O`@`(````?V\"``<```"(;P(`%P```)!O`@`-````
MJ&\"`!4```"V;P(`'0```,QO`@`/````ZF\"``X```#Z;P(`#0````EP`@`9
M````%W`"``\````Q<`(`&P```$%P`@`N````77`"`!H```",<`(`#0```*=P
M`@`.````M7`"`"<```#$<`(`,````.QP`@`;````'7$"`#8````Y<0(`/```
M`'!Q`@`6````K7$"`"L```#$<0(`#@```/!Q`@`8````_W$"`!@````8<@(`
M%P```#%R`@`7````27("``@```!A<@(`#P```&IR`@`Q````>G("`!L```"L
M<@(`'@```,AR`@`-````YW("``8```#U<@(`%````/QR`@`Q````$7,"``@`
M``!#<P(`#P```$QS`@`%````7',"``L```!B<P(`*P```&YS`@`L````FG,"
M``4```#'<P(`"0```,US`@`>````UW,"``L```#V<P(`+0````)T`@`C````
M,'0"`!(```!4=`(`$@```&=T`@`'````>G0"`!4```""=`(`)@```)AT`@`5
M````OW0"`"<```#5=`(`&P```/UT`@`8````&74"`!$````R=0(`%@```$1U
M`@`J````6W4"`"<```"&=0(`,0```*YU`@`(````X'4"`!4```#I=0(`"0``
M`/]U`@`*````"78"`"4````4=@(`"0```#IV`@`C````1'8"`!X```!H=@(`
M'0```(=V`@`]````I78"``@```#C=@(`%@```.QV`@`C`````W<"``8````G
M=P(`"````"YW`@`+````-W<"`!L```!#=P(`)0```%]W`@`>````A7<"`"P`
M``"D=P(`,@```-%W`@`8````!'@"``<````=>`(`$P```"5X`@`4````.7@"
M`!````!.>`(`!0```%]X`@`&````97@"`!````!L>`(`!@```'UX`@`#````
MA'@"`"<```"(>`(`!P```+!X`@`'````N'@"`!8```#`>`(`#````-=X`@`6
M````Y'@"``\```#[>`(`#0````MY`@`-````&7D"`!0````G>0(`&P```#QY
M`@`N````6'D"`!4```"'>0(`%P```)UY`@`6````M7D"`!0```#,>0(`%@``
M`.%Y`@`<````^'D"`#<````5>@(`%0```$UZ`@`+````8WH"``4```!O>@(`
M"````'5Z`@`*````?GH"``(```")>@(`!0```(QZ`@`0````DGH"`",```"C
M>@(`$P```,=Z`@`2````VWH"``D```#N>@(`'````/AZ`@`@````%7L"`!P`
M```V>P(`&````%-[`@`/````;'L"`!D```!\>P(`#P```)9[`@`1````IGL"
M`!H```"X>P(`%````--[`@`7````Z'L"`"T`````?`(`(@```"Y\`@`K````
M47P"`!8```!]?`(`"P```)1\`@`&````H'P"`!D```"G?`(`#0```,%\`@`3
M````SWP"``L```#C?`(`#@```.]\`@`6````_GP"`'8````5?0(`$P```(Q]
M`@`?````H'T"`"T```#`?0(`+0```.Y]`@`S````''X"`"<```!0?@(`"P``
M`'A^`@`M````A'X"`!````"R?@(`!P```,-^`@`%````RWX"`"\```#1?@(`
M'0````%_`@`Q````'W\"`"\```!1?P(`'@```(%_`@`B````H'\"`"````##
M?P(`&@```.1_`@`:````_W\"``@````:@`(`!P```".``@`'````*X`"``8`
M```S@`(`'@```#J``@`0````68`"``X```!J@`(`$0```'F``@`/````BX`"
M`!4```";@`(`$````+&``@`,````PH`"``H```#/@`(`!P```-J``@`(````
MXH`"``\```#K@`(`&0```/N``@`2````%8$"`!,````H@0(`%````#R!`@`\
M````48$"`#\```".@0(`#````,Z!`@`.````VX$"`#<```#J@0(`#P```"*"
M`@`(````,H("``L````[@@(`&@```$>"`@`/````8H("`"````!R@@(`*@``
M`)."`@`I````OH("`!\```#H@@(`(`````B#`@`J````*8,"`!\```!4@P(`
M&````'2#`@`%````C8,"`!T```"3@P(`#P```+&#`@`.````P8,"``,```#0
M@P(`!````-2#`@`'````V8,"``T```#A@P(`#P```.^#`@`.````_X,"`!P`
M```.A`(`'P```"N$`@`9````2X0"`!<```!EA`(`"@```'V$`@`>````B(0"
M``L```"GA`(`%0```+.$`@`'````R80"``L```#1A`(`!0```-V$`@`%````
MXX0"`!<```#IA`(`&0````&%`@`/````&X4"``L````KA0(`#````#>%`@`/
M````1(4"`"8```!4A0(`$@```'N%`@`2````CH4"`"X```"AA0(`+0```-"%
M`@`&````_H4"`!@````%A@(`'````!Z&`@`&````.X8"``8```!"A@(`#0``
M`$F&`@`5````5X8"``P```!MA@(`"@```'J&`@`+````A88"``8```"1A@(`
M#@```)B&`@`*````IX8"``0```"RA@(`%P```+>&`@`@````SX8"`!$```#P
MA@(`%@````*'`@`E````&8<"`"0````_AP(`"P```&2'`@`'````<(<"`"H`
M``!XAP(`#P```*.'`@"#````LX<"`!(````WB`(`.````$J(`@`)````@X@"
M``<```"-B`(`"P```)6(`@`'````H8@"``D```"IB`(`!````+.(`@`)````
MN(@"``H```#"B`(`$0```,V(`@`7````WX@"``T```#WB`(``P````6)`@`%
M````"8D"``H````/B0(`$P```!J)`@`T````+HD"`!(```!CB0(`%````':)
M`@`:````BXD"``,```"FB0(``@```*J)`@`0````K8D"``D```"^B0(`"P``
M`,B)`@`$````U(D"``H```#9B0(`!````.2)`@`$````Z8D"`!H```#NB0(`
M!0````F*`@`F````#XH"``@````VB@(`!@```#^*`@`4````1HH"`"<```!;
MB@(`#@```(.*`@`'````DHH"``<```":B@(`(P```***`@`%````QHH"``D`
M``#,B@(`"P```-:*`@`'````XHH"`!````#JB@(`(@```/N*`@`&````'HL"
M``L````EBP(`$````#&+`@`/````0HL"``T```!2BP(`!@```&"+`@`'````
M9XL"``<```!OBP(`%````'>+`@`=````C(L"`#\```"JBP(`+````.J+`@`Q
M````%XP"``<```!)C`(`"@```%&,`@`$````7(P"``D```!AC`(`"````&N,
M`@`=````=(P"``D```"2C`(`!@```)R,`@`-````HXP"``8```"QC`(``@``
M`+B,`@`$````NXP"`!(```#`C`(`,@```-.,`@`T````!HT"`#0````[C0(`
M(P```'"-`@`%````E(T"`!T```":C0(`!````+B-`@`(````O8T"``@```#&
MC0(`)````,^-`@`+````](T"``4`````C@(`"`````:.`@`?````#XX"``@`
M```OC@(`"````#B.`@`6````08X"`!\```!8C@(`!@```'B.`@`:````?XX"
M``X```":C@(`$@```*F.`@`&````O(X"``\```##C@(`"0```-..`@`&````
MW8X"``<```#DC@(`!0```.R.`@`-````\HX"`!``````CP(`#0```!&/`@`(
M````'X\"``D````HCP(`!0```#*/`@`[````.(\"`#@```!TCP(`/````*V/
M`@`G````ZH\"`#@````2D`(`0````$N0`@`P````C)`"`#H```"]D`(`-0``
M`/B0`@`^````+I$"`"D```!MD0(`$@```)>1`@`6````JI$"``T```#!D0(`
M*@```,^1`@`=````^I$"`!P````8D@(`'0```#62`@`<````4Y("`"8```!P
MD@(`!P```)>2`@`)````GY("``D```"ID@(`"````+.2`@`$````O)("`"8`
M``#!D@(`,@```.B2`@`H````&Y,"`"<```!$DP(`)0```&R3`@`,````DI,"
M`"\```"?DP(`+P```,^3`@`=````_Y,"``T````=E`(`&P```"N4`@`.````
M1Y0"``D```!6E`(`&@```&"4`@`O````>Y0"`"8```"KE`(`$0```-*4`@`&
M````Y)0"``D```#KE`(`#````/64`@`,`````I4"``\````/E0(`-@```!^5
M`@!!````5I4"`$L```"8E0(`@@```.25`@!V````9Y8"``D```#>E@(`$```
M`.B6`@`'````^98"``\````!EP(`"P```!&7`@`,````'9<"`!$````JEP(`
M$@```#R7`@`0````3Y<"``<```!@EP(`!@```&B7`@`/````;Y<"`!8```!_
MEP(`$0```):7`@`3````J)<"`!P```"\EP(`(P```-F7`@`B````_9<"`"0`
M```@F`(`%P```$68`@`;````79@"`!X```!YF`(`%@```)B8`@`5````KY@"
M`"D```#%F`(`#P```.^8`@`(````_Y@"``\````(F0(`'````!B9`@`4````
M-9D"`!(```!*F0(`"P```%V9`@`/````:9D"``X```!YF0(`/````(B9`@`B
M````Q9D"`!\```#HF0(`*@````B:`@"&````,YH"`!$```"ZF@(`!0```,R:
M`@`7````TIH"``D```#JF@(`!````/2:`@`*````^9H"`!X````$FP(`'@``
M`".;`@`D````0IL"`",```!GFP(`#0```(N;`@`1````F9L"`!4```"KFP(`
M#@```,&;`@`B````T)L"`"$```#SFP(`&@```!6<`@`.````,)P"``P````_
MG`(`$P```$R<`@`>````8)P"`"````!_G`(`'@```*"<`@`@````OYP"`!\`
M``#@G`(`(0````"=`@`;````(IT"`#@````^G0(`#P```'>=`@`1````AYT"
M`!````"9G0(`$@```*J=`@`-````O9T"`!(```#+G0(`%````-Z=`@`0````
M\YT"`!(````$G@(`,@```!>>`@`6````2IX"`!0```!AG@(`/0```':>`@`4
M````M)X"``H```#)G@(`$P```-2>`@`P````Z)X"``\````9GP(`'````"F?
M`@!!````1I\"`!L```"(GP(`$P```*2?`@`2````N)\"`"8```#+GP(`'0``
M`/*?`@`8````$*`"`!8````IH`(`#0```$"@`@`7````3J`"`!X```!FH`(`
M&@```(6@`@`H````H*`"`",```#)H`(`&@```.V@`@`5````"*$"`"(````>
MH0(`(0```$&A`@`6````8Z$"`!$```!ZH0(`%P```(RA`@`9````I*$"`!D`
M``"^H0(`%P```-BA`@`(````\*$"``H```#YH0(`$`````2B`@`$````%:("
M``0````:H@(`!0```!^B`@`+````):("``\````QH@(`!@```$&B`@`)````
M2*("``<```!2H@(`"0```%JB`@`'````9*("``8```!LH@(`"````'.B`@`&
M````?*("``8```"#H@(``P```(JB`@`#````CJ("``@```"2H@(`$@```)NB
M`@`1````KJ("``X```#`H@(`#P```,^B`@`"````WZ("``H```#BH@(`$@``
M`.VB`@`$`````*,"`"@````%HP(`$@```"ZC`@`0````0:,"`!@```!2HP(`
M"P```&NC`@`)````=Z,"``X```"!HP(`+0```)"C`@!"````OJ,"`%,````!
MI`(`40```%6D`@`U````IZ0"``0```#=I`(`"````.*D`@`B````ZZ0"`!(`
M```.I0(`!@```"&E`@`)````**4"``<````RI0(`!0```#JE`@`$````0*4"
M`!$```!%I0(`&0```%>E`@`0````<:4"`!0```""I0(`#@```)>E`@`6````
MIJ4"`!@```"]I0(`'0```-:E`@`;````]*4"``@````0I@(`!0```!FF`@`&
M````'Z8"`"$````FI@(`!P```$BF`@`%````4*8"``X```!6I@(`#0```&6F
M`@`'````<Z8"``8```![I@(`!P```(*F`@`%````BJ8"``\```"0I@(`#P``
M`*"F`@`*````L*8"``\```"[I@(`$0```,NF`@`6````W:8"`!0```#TI@(`
M#@````FG`@`6````&*<"``@````OIP(`!0```#BG`@`3````/J<"`!$```!2
MIP(`-@```&2G`@`@````FZ<"``4```"\IP(`&0```,*G`@`,````W*<"`",`
M``#IIP(`%@````VH`@`4````)*@"`!<````YJ`(`A@```%&H`@`,````V*@"
M``D```#EJ`(`!P```.^H`@`*````]Z@"``D````"J0(`#@````RI`@`0````
M&ZD"`!$````LJ0(`'0```#ZI`@`C````7*D"`"X```"`J0(`"@```*^I`@`%
M````NJD"``X```#`J0(`$0```,^I`@`-````X:D"`!$```#OJ0(`"P````&J
M`@`+````#:H"`!(````9J@(`)@```"RJ`@`(````4ZH"``L```!<J@(`%```
M`&BJ`@!1````?:H"`!0```#/J@(`"0```.2J`@`%````[JH"``4```#TJ@(`
M#@```/JJ`@`3````":L"`!4````=JP(`$P```#.K`@`)````1ZL"``L```!1
MJP(``@```%VK`@`*````8*L"`"H```!KJP(``P```):K`@`%````FJL"``H`
M``"@JP(`#P```*NK`@`*````NZL"``4```#&JP(`!0```,RK`@`>````TJL"
M``P```#QJP(`)````/ZK`@`(````(ZP"`"L````LK`(`$@```%BL`@`&````
M:ZP"``@```!RK`(`"````'NL`@`$````A*P"``4```")K`(`80```(^L`@`*
M````\:P"``T```#\K`(`$@````JM`@`%````':T"``4````CK0(`+P```"FM
M`@`Q````6:T"``P```"+K0(`*@```)BM`@`H````PZT"`"````#LK0(`)P``
M``VN`@`T````-:X"`!,```!JK@(`"````'ZN`@`<````AZX"`!X```"DK@(`
M#````,.N`@`*````T*X"``D```#;K@(`&@```.6N`@`L`````*\"`"H````M
MKP(`*0```%BO`@`9````@J\"`!H```"<KP(`'@```+>O`@`/````UJ\"`"8`
M``#FKP(`,0````VP`@`#````/[`"``<```!#L`(`"````$NP`@`(````5+`"
M`!8```!=L`(`$````'2P`@`,````A;`"``8```"2L`(`#@```)FP`@`,````
MJ+`"`!````"UL`(`$0```,:P`@`.````V+`"`!0```#GL`(`20```/RP`@`1
M````1K$"`!D```!8L0(`#P```'*Q`@`/````@K$"``P```"2L0(`$0```)^Q
M`@`5````L;$"`!,```#'L0(`#P```-NQ`@`@````Z[$"`#,````,L@(`'0``
M`$"R`@`*````7K("`"````!IL@(`"0```(JR`@`-````E+("`!P```"BL@(`
M30```+^R`@`@````#;,"``8````NLP(`'0```#6S`@`H````4[,"``@```!\
MLP(`!@```(6S`@`=````C+,"``4```"JLP(`"````+"S`@`J````N;,"`"D`
M``#DLP(`+@````ZT`@`1````/;0"``4```!/M`(`'@```%6T`@!=````=+0"
M`!````#2M`(`(0```..T`@`1````!;4"``,````7M0(`#````!NU`@`&````
M*+4"`!4````OM0(`!P```$6U`@`+````3;4"``<```!9M0(`"0```&&U`@`&
M````:[4"``D```!RM0(`#````'RU`@`'````B;4"``H```"1M0(`#````)RU
M`@`Y````J;4"`"8```#CM0(`!@````JV`@`.````$;8"`!`````@M@(`$```
M`#&V`@`(````0K8"``T```!+M@(`#@```%FV`@`/````:+8"``T```!XM@(`
M#P```(:V`@!%````EK8"`!4```#<M@(`#P```/*V`@`(`````K<"`!X````+
MMP(`&0```"JW`@`:````1+<"`!$```!?MP(`"@```'&W`@`7````?+<"``H`
M``"4MP(`%````)^W`@`'````M+<"`!````"\MP(`!@```,VW`@`(````U+<"
M``0```#=MP(`,````.*W`@`'````$[@"``4````;N`(`#@```"&X`@`%````
M,+@"``D````VN`(`$````$"X`@`5````4;@"`"T```!GN`(`'````)6X`@`Q
M````LK@"`"H```#DN`(`&0````^Y`@`=````*;D"`!@```!'N0(`!````&"Y
M`@`%````9;D"`!<```!KN0(`!````(.Y`@`.````B+D"``X```"7N0(`#@``
M`*:Y`@`*````M;D"``L```#`N0(`$@```,RY`@`#````W[D"`",```#CN0(`
M"P````>Z`@`+````$[H"``H````?N@(`(````"JZ`@`:````2[H"`!(```!F
MN@(`!````'FZ`@`0````?KH"``4```"/N@(`$@```)6Z`@`-````J+H"``T`
M``"VN@(`$0```,2Z`@`,````UKH"``D```#CN@(`!0```.VZ`@`'````\[H"
M``,```#[N@(`!````/^Z`@`#````!+L"`!\````(NP(`#@```"B[`@`:````
M-[L"``T```!2NP(`*@```&"[`@`H````B[L"``H```"TNP(`(P```+^[`@`M
M````X[L"`!X````1O`(`4@```#"\`@!`````@[P"`!T```#$O`(`+@```.*\
M`@`U````$;T"``T```!'O0(`-@```%6]`@`B````C+T"`"<```"OO0(`)P``
M`->]`@`L````_[T"``X````LO@(`)````#N^`@`_````8+X"`!0```"@O@(`
M(0```+6^`@`W````U[X"`!X````/OP(`)@```"Z_`@`M````5;\"`!P```"#
MOP(`&@```*"_`@`7````N[\"`!D```#3OP(`'````.V_`@`G````"L`"`"$`
M```RP`(`&P```%3``@`7````<,`"`"P```"(P`(`+````+7``@`P````XL`"
M`"T````3P0(`+@```$'!`@`K````<,$"`%X```"<P0(`(````/O!`@`K````
M',("`"H```!(P@(`-````'/"`@!!````J,("`!<```#JP@(`"`````+#`@`>
M````"\,"``D````JPP(`-0```#3#`@`6````:L,"``\```"!PP(`#0```)'#
M`@!"````G\,"`$````#BPP(`'P```"/$`@`Q````0\0"`!\```!UQ`(`#@``
M`)7$`@!5````I,0"`$P```#ZQ`(`#P```$?%`@`&````5\4"`"(```!>Q0(`
M#@```('%`@`(````D,4"`!````"9Q0(`&0```*K%`@`&````Q,4"``H```#+
MQ0(`#````-;%`@`*````X\4"``X```#NQ0(`"@```/W%`@`-````",8"``X`
M```6Q@(`%@```"7&`@`1````/,8"`!8```!.Q@(`$0```&7&`@`+````=\8"
M`!,```"#Q@(`%0```)?&`@`(````K<8"``,```"VQ@(`(@```+K&`@`O````
MW<8"``@````-QP(`!0```!;'`@`,````',<"``T````IQP(`70```#?'`@!5
M````E<<"``T```#KQP(`/@```/G'`@`"````.,@"``4````[R`(`!@```$'(
M`@`-````2,@"``D```!6R`(`!P```&#(`@`1````:,@"``H```!ZR`(`)0``
M`(7(`@`,````J\@"``L```"XR`(`(@```,3(`@`O````Y\@"``0````7R0(`
M+@```!S)`@`P````2\D"`!0```!\R0(`*````)')`@`V````NLD"`&H```#Q
MR0(`$@```%S*`@`4````;\H"`$0```"$R@(`$@```,G*`@`?````W,H"``\`
M``#\R@(`$@````S+`@`*````'\L"``T````JRP(`#P```#C+`@`+````2,L"
M`!0```!4RP(`#0```&G+`@`9````=\L"`!4```"1RP(``P```*?+`@`1````
MJ\L"`!````"]RP(`#@```,[+`@`/````W<L"`",```#MRP(`$0```!',`@`#
M````(\P"`!0````GS`(`'0```#S,`@`=````6LP"``L```!XS`(`-@```(3,
M`@`.````N\P"`!<```#*S`(`3P```.+,`@`0````,LT"`!@```!#S0(`,P``
M`%S-`@`O````D,T"`!T```#`S0(`&P```-[-`@`F````^LT"`"<````AS@(`
M)@```$G.`@`E````<,X"`"D```"6S@(`4````,#.`@!*````$<\"`*L```!<
MSP(`!P````C0`@`)````$-`"`!0````:T`(`$@```"_0`@`2````0M`"`!H`
M``!5T`(`$@```'#0`@`/````@]`"``0```"3T`(`)@```)C0`@`,````O]`"
M`"\```#,T`(`+P```/S0`@`-````+-$"`!8````ZT0(`"@```%'1`@`)````
M7-$"``X```!FT0(`)````'71`@`H````FM$"``@```##T0(`$````,S1`@`2
M````W=$"``8```#PT0(`$0```/?1`@`(````"=("``<````2T@(`$0```!K2
M`@`.````+-("`!8````[T@(`)P```%+2`@`/````>M("`"(```"*T@(`%```
M`*W2`@`%````PM("`!L```#(T@(`#P```.32`@`N````]-("`!(````CTP(`
M!@```#;3`@`'````/=,"`!@```!%TP(`!@```%[3`@`2````9=,"``4```!X
MTP(`&0```'[3`@`%````F-,"``<```">TP(`%P```*;3`@`G````OM,"``4`
M``#FTP(`&P```.S3`@`2````"-0"``4````;U`(`$@```"'4`@`K````--0"
M``8```!@U`(`$0```&?4`@`P````>=0"`"<```"JU`(`+@```-+4`@`J````
M`=4"``0````LU0(`#P```#'5`@`(````0=4"``<```!*U0(`"@```%+5`@`(
M````7=4"``4```!FU0(`.````&S5`@`>````I=4"`,T```#$U0(`(````)+6
M`@`S````L]8"`#P```#GU@(`'````"37`@`G````0=<"`"<```!IUP(`(```
M`)'7`@`^````LM<"`!H```#QUP(`)P````S8`@`9````--@"`&H```!.V`(`
M;0```+G8`@`I`0``)]D"`"````!1V@(`&@```'+:`@`O````C=H"`"<```"]
MV@(`6````.7:`@`Q````/ML"`"X```!PVP(`,0```)_;`@`U````T=L"`#``
M```'W`(`)P```#C<`@`&````8-P"``@```!GW`(`!@```'#<`@`+````=]P"
M`!D```"#W`(`&0```)W<`@`L````M]P"`!````#DW`(`+@```/7<`@`?````
M)-T"`!L```!$W0(`)@```&#=`@`V````A]T"`#P```"^W0(`!````/O=`@`5
M`````-X"``8````6W@(`!@```!W>`@`D````)-X"`!4```!)W@(`%@```%_>
M`@`9````=MX"``8```"0W@(`$0```)?>`@`(````J=X"``T```"RW@(`&```
M`,#>`@`'````V=X"``X```#AW@(`"````/#>`@`W````^=X"`#<````QWP(`
M%@```&G?`@`)````@-\"``P```"*WP(`&@```)??`@`;````LM\"`"T```#.
MWP(`.````/S?`@`)````->`"`!,````_X`(`$@```%/@`@`@````9N`"`!D`
M``"'X`(`-````*'@`@`>````UN`"`!P```#UX`(`'````!+A`@`%````+^$"
M``4````UX0(`!0```#OA`@`E````0>$"`",```!GX0(`&@```(OA`@`)````
MIN$"`!L```"PX0(`$@```,SA`@`$````W^$"``D```#DX0(`"P```.[A`@`0
M````^N$"``X````+X@(`'0```!KB`@`/````..("``4```!(X@(`!0```$[B
M`@`,````5.("`#4```!AX@(`60```)?B`@`+````\>("``H```#]X@(`"@``
M``CC`@`,````$^,"``L````@XP(`$@```"SC`@`7````/^,"`!8```!7XP(`
M'@```&[C`@`'````C>,"`"(```"5XP(`'@```+CC`@`;````U^,"``\```#S
MXP(`$@````/D`@`'````%N0"`!(````>Y`(`"````#'D`@`I````.N0"`!X`
M``!DY`(`$P```(/D`@`1````E^0"`"T```"IY`(`"0```-?D`@`.````X>0"
M`!X```#PY`(`$`````_E`@`6````(.4"``T````WY0(`.@```$7E`@`-````
M@.4"``D```".Y0(`'P```)CE`@`5````N.4"`!D```#.Y0(`'P```.CE`@`Y
M````".8"`",```!"Y@(`)````&;F`@`,````B^8"``D```"8Y@(`%@```*+F
M`@`1````N>8"`!(```#+Y@(`(P```-[F`@`D`````N<"`!(````GYP(`(P``
M`#KG`@`^````7N<"`#\```"=YP(`"0```-WG`@`+````Y^<"``H```#SYP(`
M&@```/[G`@`=````&>@"`!\````WZ`(`.P```%?H`@`=````D^@"`"$```"Q
MZ`(`)@```-/H`@`^````^N@"`#\````YZ0(`.P```'GI`@`,````M>D"`!,`
M``#"Z0(`$````-;I`@`-````Y^D"`!(```#UZ0(`(0````CJ`@`6````*NH"
M``@```!!Z@(`!P```$KJ`@`4````4NH"`!\```!GZ@(`&0```(?J`@`4````
MH>H"`$<```"VZ@(`$@```/[J`@`'````$>L"`!,````9ZP(`*````"WK`@`'
M````5NL"``8```!>ZP(`#P```&7K`@`.````=>L"`!4```"$ZP(`!````)KK
M`@`(````G^L"``P```"HZP(`#````+7K`@`-````PNL"`!$```#0ZP(`$0``
M`.+K`@`'````].L"``4```#\ZP(`-`````+L`@`D````-^P"`"0```!<[`(`
M!P```('L`@`/````B>P"``8```"9[`(`!@```*#L`@`<````I^P"`"````#$
M[`(`(0```.7L`@`.````!^T"`#D````6[0(`$0```%#M`@`:````8NT"`%(`
M``!][0(`,@```-#M`@`H`````^X"`"`````L[@(`)P```$WN`@`>````=>X"
M`"D```"4[@(`+P```+[N`@!-````[NX"`%P````\[P(`4P```)GO`@"R````
M[>\"`"0```"@\`(`#@```,7P`@`$````U/`"``D```#9\`(`'@```./P`@`#
M`````O$"``8````&\0(`"@````WQ`@`(````&/$"``(````A\0(`$0```"3Q
M`@`+````-O$"``P```!"\0(`$P```$_Q`@`+````8_$"`!4```!O\0(`&0``
M`(7Q`@`6````G_$"``4```"V\0(`"@```+SQ`@`3````Q_$"`!8```#;\0(`
M#@```/+Q`@`&`````?("``L````(\@(`"0```!3R`@`W````'O("``X```!6
M\@(`#@```&7R`@`9````=/("`!$```".\@(`#@```*#R`@`/````K_("``H`
M``"_\@(`(````,KR`@!5````Z_("`$$```!!\P(`+````(/S`@`6````L/,"
M`!T```#'\P(`,0```.7S`@`E````%_0"``\````]]`(`!````$WT`@`+````
M4O0"``X```!>]`(`"P```&WT`@`3````>?0"`!$```"-]`(`"0```)_T`@`&
M````J?0"`!````"P]`(`#@```,'T`@`-````T/0"``P```#>]`(`&P```.OT
M`@`8````!_4"``X````@]0(`$````"_U`@`?````0/4"`#H```!@]0(`#@``
M`)OU`@`@````JO4"`$$```#+]0(`#`````WV`@`.````&O8"`!`````I]@(`
M:@```#KV`@`D````I?8"`!8```#*]@(`,````.'V`@`F````$O<"`!\````Y
M]P(`(@```%GW`@`4````?/<"`!D```"1]P(`&0```*OW`@`.````Q?<"`!$`
M``#4]P(`)P```.;W`@`<````#O@"``X````K^`(`&````#KX`@`*````4_@"
M`#H```!>^`(`!P```)GX`@`(````H?@"`!D```"J^`(`&@```,3X`@`)````
MW_@"`!0```#I^`(`#0```/[X`@`&````#/D"`"(````3^0(`-````#;Y`@`'
M````:_D"`!0```!S^0(`'0```(CY`@`'````IOD"``X```"N^0(`.P```+WY
M`@`F````^?D"`"\````@^@(`3@```%#Z`@`O````G_H"`'@```#/^@(`"@``
M`$C[`@`H````4_L"`#<```!\^P(`"````+3[`@`1````O?L"`!<```#/^P(`
M,@```.?[`@`(````&OP"``P````C_`(`-@```##\`@!\````9_P"`#H```#D
M_`(`.P```!_]`@`N````6_T"``@```"*_0(`&0```)/]`@`8````K?T"``\`
M``#&_0(`&P```-;]`@`M````\OT"`"$````@_@(`$P```$+^`@`N````5OX"
M`$D```"%_@(`.0```,_^`@`E````"?\"`"@````O_P(`(````%C_`@`M````
M>?\"`!X```"G_P(`)P```,;_`@`A````[O\"`"H````0``,`$````#L``P`L
M````3``#`"8```!Y``,`+0```*```P`>````S@`#`"8```#M``,`*0```!0!
M`P`0````/@$#``@```!/`0,`#0```%@!`P`/````9@$#``X```!V`0,`"0``
M`(4!`P`'````CP$#`#0```"7`0,`"````,P!`P`,````U0$#`!````#B`0,`
M!@```/,!`P`2````^@$#``D````-`@,`"````!<"`P`'````(`(#`!`````H
M`@,`"0```#D"`P`)````0P(#``@```!-`@,`$````%8"`P`0````9P(#`!4`
M``!X`@,`%P```(X"`P`-````I@(#`"(```"T`@,`$@```-<"`P`(````Z@(#
M``X```#S`@,`&P````(#`P`4````'@,#`"$````S`P,`%@```%4#`P`6````
M;`,#`!0```"#`P,`'0```)@#`P`5````M@,#``\```#,`P,`#````-P#`P`F
M````Z0,#``X````0!`,`'P```!\$`P`E````/P0#``D```!E!`,`!@```&\$
M`P`2````=@0#``H```")!`,`!````)0$`P`3````F00#`!L```"M!`,`#P``
M`,D$`P`N````V00#`!(````(!0,`$@```!L%`P`;````+@4#`"T```!*!0,`
M#@```'@%`P`/````AP4#``\```"7!0,`!@```*<%`P`)````K@4#``H```"X
M!0,`"0```,,%`P`%````S04#``X```#3!0,`%````.(%`P`'````]P4#``T`
M``#_!0,`#`````T&`P`(````&@8#``0````C!@,`#P```"@&`P`(````.`8#
M``L```!!!@,`#P```$T&`P`1````708#`!D```!O!@,`&````(D&`P`*````
MH@8#``(```"M!@,`"````+`&`P`@````N08#``<```#:!@,`#0```.(&`P`'
M````\`8#`'(```#X!@,`)@```&L'`P`+````D@<#``8```">!P,`)@```*4'
M`P`^````S`<#`!P````+"`,`)P```"@(`P!1````4`@#`"$```"B"`,`,@``
M`,0(`P`?````]P@#`!0````7"0,`!0```"P)`P`&````,@D#``@````Y"0,`
M#````$()`P`+````3PD#``<```!;"0,`#````&,)`P`2````<`D#``X```"#
M"0,`"P```)()`P`-````G@D#``L```"L"0,`!P```+@)`P`'````P`D#``H`
M``#("0,`%````-,)`P`)````Z`D#``<```#R"0,`'````/H)`P`?````%PH#
M`"T````W"@,`"P```&4*`P`A````<0H#``8```"3"@,`*````)H*`P`%````
MPPH#``4```#)"@,`#P```,\*`P`%````WPH#``H```#E"@,`"0```/`*`P`'
M````^@H#`!(````""P,`$@```!4+`P`&````*`L#`!8````O"P,`"P```$8+
M`P`(````4@L#``4```!;"P,`!0```&$+`P`%````9PL#``\```!M"P,`'```
M`'T+`P`'````F@L#``D```"B"P,`)@```*P+`P`<````TPL#``T```#P"P,`
M%P```/X+`P`?````%@P#`!4````V#`,`,@```$P,`P`$````?PP#``@```"$
M#`,`$````(T,`P`)````G@P#``(```"H#`,`!P```*L,`P`?````LPP#`"@`
M``#3#`,`)P```/P,`P!N````)`T#`"$```"3#0,`%P```+4-`P`J````S0T#
M`"H```#X#0,`*0```",.`P`7````30X#`!8```!E#@,`6@```'P.`P`7````
MUPX#`!$```#O#@,`&P````$/`P!L````'0\#`%\```"*#P,`+@```.H/`P`I
M````&1`#`#T```!#$`,`00```($0`P!)````PQ`#`&P````-$0,`'@```'H1
M`P`F````F1$#`#````#`$0,`*````/$1`P`@````&A(#`"@````[$@,`,0``
M`&02`P`K````EA(#`!\```#"$@,`&@```.(2`P!V````_1(#`#P```!T$P,`
M/0```+$3`P`@````[Q,#`"\````0%`,`)0```$`4`P`D````9A0#`"\```"+
M%`,`.@```+L4`P`P````]A0#`,L!```G%0,`'````/,6`P!N````$!<#`#X`
M``!_%P,`#P```+X7`P`_````SA<#`#@````.&`,`.P```$<8`P`O````@Q@#
M`!H```"S&`,`2````,X8`P`X````%QD#`!4```!0&0,`%````&89`P`E````
M>QD#`'P```"A&0,`0P```!X:`P`:````8AH#`#(```!]&@,`:P```+`:`P!>
M````'!L#`$@```![&P,`(0```,0;`P`U````YAL#`"X````<'`,`*@```$L<
M`P`7````=AP#`!````".'`,`>P```)\<`P`>````&QT#`!D````Z'0,`&```
M`%0=`P`U````;1T#`"$```"C'0,`(0```,4=`P`G````YQT#`!\````/'@,`
M(````"\>`P`:````4!X#`!L```!K'@,`(````(<>`P`I````J!X#`!X```#2
M'@,`"P```/$>`P`B````_1X#`!0````@'P,`*P```#4?`P`5````81\#`"P`
M``!W'P,`,0```*0?`P`9````UA\#`!````#P'P,`-`````$@`P`C````-B`#
M`#\```!:(`,`(0```)H@`P`A````O"`#`#D```#>(`,`&0```!@A`P`B````
M,B$#`#D```!5(0,`5````(\A`P`K````Y"$#`"\````0(@,`1P```$`B`P`O
M````B"(#`#````"X(@,`)P```.DB`P!!````$2,#`%X```!3(P,`10```+(C
M`P`Y````^",#`#4````R)`,`-0```&@D`P`F````GB0#`"H```#%)`,`,```
M`/`D`P!%````(24#`!T```!G)0,`+````(4E`P`G````LB4#`"L```#:)0,`
M)`````8F`P!(````*R8#`%8```!T)@,`,@```,LF`P!/````_B8#`"0```!.
M)P,`'@```',G`P!*````DB<#`$D```#=)P,`*@```"<H`P`B````4B@#`"(`
M``!U*`,`2````)@H`P`S````X2@#`"X````5*0,`'@```$0I`P`F````8RD#
M`"P```"**0,`+````+<I`P`M````Y"D#`&4````2*@,`6@```'@J`P!C````
MTRH#`)T````W*P,`%0```-4K`P`C````ZRL#`"\````/+`,`+P```#\L`P!!
M````;RP#`"````"Q+`,`5````-(L`P`A````)RT#``L```!)+0,`M0```%4M
M`P`Q````"RX#`"4````]+@,`2P```&,N`P!$````KRX#`%@```#T+@,`.0``
M`$TO`P!)````AR\#`#L```#1+P,`,0````TP`P`T````/S`#`"P```!T,`,`
M*0```*$P`P`.````RS`#`$@```#:,`,`'P```",Q`P`V````0S$#`"X```!Z
M,0,`(@```*DQ`P`>````S#$#`#(```#K,0,`+````!XR`P`/````2S(#``<`
M``!;,@,`!P```&,R`P`#````:S(#``T```!O,@,`"P```'TR`P`*````B3(#
M``L```"4,@,`!P```*`R`P`9````J#(#``,```#",@,`#P```,8R`P!/````
MUC(#`%L````F,P,`2@```((S`P`$````S3,#`"<```#2,P,`!````/HS`P`'
M````_S,#``8````'-`,`!0````XT`P`$````%#0#`!,````9-`,`%P```"TT
M`P`(````130#``T```!.-`,`#@```%PT`P`1````:S0#`!4```!]-`,``@``
M`),T`P`'````EC0#``<```">-`,`#````*8T`P`.````LS0#``8```#"-`,`
M%````,DT`P`,````WC0#``,```#K-`,`)P```.\T`P`$````%S4#``8````<
M-0,`"````",U`P`P````+#4#`$<```!=-0,`+@```*4U`P`O````U#4#`!L`
M```$-@,`+P```"`V`P`R````4#8#`"0```"#-@,`(0```*@V`P`C````RC8#
M`"@```#N-@,`(P```!<W`P`A````.S<#`"H```!=-P,`*0```(@W`P`B````
MLC<#`#,```#5-P,`'P````DX`P`P````*3@#`"T```!:.`,`(@```(@X`P`F
M````JS@#`"4```#2.`,`(````/@X`P`I````&3D#`"D```!#.0,`)0```&TY
M`P`O````DSD#`!P```##.0,`(0```.`Y`P`E`````CH#`"D````H.@,`(```
M`%(Z`P`J````<SH#`#X```">.@,`00```-TZ`P`=````'SL#`"0````].P,`
M0````&([`P`E````HSL#`"D```#).P,`*````/,[`P`I````'#P#`",```!&
M/`,`(0```&H\`P`@````C#P#`"H```"M/`,`)0```-@\`P`Y````_CP#`"<`
M```X/0,`-0```&`]`P`-````ECT#`!0```"D/0,`!P```+D]`P`,````P3T#
M`!@```#./0,`#````.<]`P`4````]#T#`"\````)/@,`(P```#D^`P`+````
M73X#`!T```!I/@,`%P```(<^`P`.````GSX#`!8```"N/@,`"````,4^`P`'
M````SCX#``T```#6/@,`-0```.0^`P`2````&C\#`!`````M/P,`(@```#X_
M`P`E````83\#`!X```"'/P,`)P```*8_`P`E````SC\#`!@```#T/P,`#```
M``U``P#K````&D`#``L````&00,`#P```!)!`P`D````(D$#`!@```!'00,`
M#````&!!`P`/````;4$#`!L```!]00,`&````)E!`P`?````LD$#`!\```#2
M00,`!@```/)!`P`U````^4$#`!8````O0@,`%````$9"`P`'````6T(#`!,`
M``!C0@,`'````'="`P`F````E$(#``H```"[0@,`(@```,9"`P`\````Z4(#
M``H````F0P,`0P```#%#`P`H````=4,#`!,```">0P,`&````+)#`P`7````
MRT,#`#@```#C0P,`(````!Q$`P`2````/40#`"0```!01`,`$P```'5$`P`4
M````B40#`!4```">1`,`"@```+1$`P`7````OT0#``D```#71`,`'0```.%$
M`P`(````_T0#`!P````(10,`)@```"5%`P`'````3$4#`",```!410,`!P``
M`'A%`P`(````@$4#``D```")10,`-````)-%`P`&````R$4#`!````#/10,`
M%0```.!%`P`4````]D4#``L````+1@,`#````!=&`P`'````)$8#``@````L
M1@,`"P```#5&`P`8````048#`"````!:1@,`#P```'M&`P`=````BT8#`!P`
M``"I1@,`#P```,9&`P`.````UD8#`!P```#E1@,`#P````)'`P`=````$D<#
M`!L````P1P,`$````$Q'`P`4````74<#`!<```!R1P,`#@```(I'`P`0````
MF4<#`!@```"J1P,`&0```,-'`P`O````W4<#`!\````-2`,`$P```"U(`P`F
M````04@#`"(```!H2`,`(P```(M(`P`-````KT@#`!H```"]2`,`)@```-A(
M`P`=````_T@#``L````=20,`#0```"E)`P`7````-TD#``D```!/20,`*P``
M`%E)`P`,````A4D#``\```"220,`"0```*))`P`"````K$D#`!$```"O20,`
M&````,%)`P`+````VDD#``,```#F20,`"P```.I)`P`(````]DD#``<```#_
M20,`"P````=*`P`+````$TH#``X````?2@,`+0```"Y*`P`:````7$H#`!H`
M``!W2@,`5````))*`P!0````YTH#`$L````X2P,`-````(1+`P!Q````N4L#
M`"$````K3`,`"@```$U,`P`Z````6$P#``T```"33`,`!0```*%,`P`6````
MITP#`#<```"^3`,`#0```/9,`P`.````!$T#``8````330,`!````!I-`P`&
M````'TT#``L````F30,`%P```#)-`P`'````2DT#``@```!230,`!P```%M-
M`P`(````8TT#``4```!L30,`#P```')-`P`0````@DT#`#X```"330,`,0``
M`-)-`P`D````!$X#``4````I3@,`&@```"].`P`A````2DX#`"$```!L3@,`
M(P```(Y.`P`1````LDX#``(```#$3@,`!````,=.`P`*````S$X#``4```#7
M3@,`!0```-U.`P`#````XTX#``D```#G3@,`,0```/%.`P!)````(T\#`#8`
M``!M3P,`*0```*1/`P`6````SD\#`"4```#E3P,`3`````M0`P`K````6%`#
M`"4```"$4`,`,@```*I0`P`8````W5`#`!<```#V4`,`:P````Y1`P`M````
M>E$#`!P```"H40,`1````,51`P`E````"E(#`%\````P4@,`,````)!2`P`Y
M````P5(#`!4```#[4@,`$P```!%3`P`=````)5,#`!,```!#4P,`*0```%=3
M`P`L````@5,#`'D```"N4P,`'````"A4`P!3````150#`"(```"95`,`/P``
M`+Q4`P`H````_%0#`#0````E50,`3@```%I5`P!1````J54#`"8```#[50,`
M*P```")6`P`<````3E8#`"P```!K5@,`*````)A6`P`6````P58#`#8```#8
M5@,`-@````]7`P`U````1E<#`#,```!\5P,`*````+!7`P`B````V5<#`"\`
M``#\5P,`)@```"Q8`P`D````4U@#`"$```!X6`,`'P```)I8`P`=````NE@#
M`"0```#86`,`(@```/U8`P!,````(%D#`!0```!M60,`-````()9`P`/````
MMUD#`&\```#'60,`#@```#=:`P`.````1EH#`!$```!56@,`$````&=:`P`W
M````>%H#`"@```"P6@,`"@```-E:`P!'````Y%H#`*(````L6P,`>P```,];
M`P!P````2UP#`$$```"\7`,`*````/Y<`P!4````)UT#`!H```!\70,`-0``
M`)==`P`Y````S5T#`"D````'7@,`%P```#%>`P`*````25X#`*,```!47@,`
M'0```/A>`P`=````%E\#`!T````T7P,`-````%)?`P`C````AU\#`!@```"K
M7P,`5````,1?`P`>````&6`#`!<````X8`,`#P```%!@`P`*````8&`#``0`
M``!K8`,`!@```'!@`P`(````=V`#``4```"`8`,`#@```(9@`P`5````E6`#
M`!<```"K8`,`$P```,-@`P`2````UV`#`!D```#J8`,`)0````1A`P`@````
M*F$#`!````!+80,`#@```%QA`P`$````:V$#``\```!P80,`!````(!A`P`#
M````A6$#``D```")80,`"````)-A`P`/````G&$#``H```"L80,`"````+=A
M`P`)````P&$#``D```#*80,`%@```-1A`P`/````ZV$#``T```#[80,`"0``
M``EB`P`5````$V(#`!$````I8@,`#````#MB`P`+````2&(#``8```!48@,`
M!P```%MB`P`)````8V(#``L```!M8@,`$P```'EB`P`*````C6(#``P```"8
M8@,`#@```*5B`P`+````M&(#`!8```#`8@,`!P```-=B`P`$````WV(#``@`
M``#D8@,`#0```.UB`P`0````^V(#``X````,8P,`!P```!MC`P`/````(V,#
M``<````S8P,`#P```#MC`P`&````2V,#``@```!28P,`"0```%MC`P`<````
M96,#`!L```""8P,`#````)YC`P`B````JV,#`!(```#.8P,`)P```.%C`P`6
M````"60#`!$````@9`,`!0```#)D`P`%````.&0#``(````^9`,`(0```$%D
M`P`(````8V0#``(```!L9`,``@```&]D`P`6````<F0#``@```")9`,`"```
M`))D`P`4````FV0#`!<```"P9`,`!````,AD`P`(````S60#``X```#69`,`
M+0```.5D`P`"````$V4#``0````690,`!@```!ME`P`0````(F4#`!<````S
M90,`#P```$ME`P`%````6V4#``<```!A90,`$@```&EE`P`%````?&4#``H`
M``""90,`&0```(UE`P`%````IV4#`!$```"M90,`$0```+]E`P`2````T64#
M``\```#D90,`#P```/1E`P`"````!&8#``@````'9@,`#P```!!F`P`+````
M(&8#``T````L9@,`)````#IF`P`+````7V8#``P```!K9@,`$P```'AF`P`%
M````C&8#``(```"29@,`"P```)5F`P`3````H68#`!(```"U9@,``0````T"
M``!H"0``K@<``$H$``".!@``KP,``+T#``#K!@``30```#4$```("0``````
M`.<&````````-@```.0)```'"```D@H``%P$```U!P``A@8```````#X!```
ME@D``.0%```A`@``0P<``%T%``!D````K`D```````!'`P```````$L+```6
M````&PH`````````````%P@```````#U````W@<``+X%``#0`0````````@'
M```1````50L``+D%``!O"@```````"8```#."0```````)D#``"3`@``;`(`
M`"T!``#>!@``7`H```````"G`@``0`@`````````````K`4``-L%```4`@``
M_`,``(D$``!["0``008``),$````````_@0``/$*``#.````\`4``(X```"0
M!@``KP8```````#>`0````````````!%"0``@04```L#```S````OP4``%`*
M```5````&`8``/\%``"N!0``LP4``+T!``"L`P``+`H```````!O`P``0@,`
M`.0#``#F`@``IPH``,H"``#Z!@``W`$``&,'`````````@`````````B!@``
M%P(``)(#```P``````````````#;`0```04``+\!``"/!````````/H"``!;
M!```1`$``-L)```&"```,P$``)L#``!1"```E0(``-,%````````````````
M```'`0````````X#````````F0<``!@$``#5````&P4`````````````VP<`
M`"X)````````)@4``/0*```#`P````````````!'"P``]0D``",)```P!P``
M;@,``!\"``!$`@``QPD``(0%````````9P$``&$'````````ZPD```````"W
M!@```````!8(``!.`P``$`L``/8!```6`0```````"H%``#9`P```````*T%
M``#H`P``6`````````#L`@``G@(`````````````608``&$)``#C!0``````
M```````G"````````%`$``#5!@``UPD``'(*``#H"0``+`4```````"&!P``
MC@$```````";!@``5`,```````#S"```1`D``'L*```%````7P$```````!)
M"P``=`(``-@$``"J!```;`@``#8$```\!P``,@H```8*`````````````'L$
M``!4````2PD``)$*``",`@``)P,``%H%```&````[`8````````/````````
M``````#B``````````````!<`@``7`4``!`#``!`!@``.`L``#L%```M!0``
M`````&<#````````,@<``*X"````````````````````````CPH``'4)````
M`````````$4#```A````)08``!,&``!D!```PPD``*,)``"I"```:````!@!
M````````P@<``(L%``!7`````@8``*L!``#J!@```````"\```!7"P``````
M`!('```<````]@H``!D(````````5P0`````````````(0D``!X'``!G````
M`````-`*``!C!```#0@```````#*`0``EP(``-H"``",`0```````$,```"'
M!@``MPH```@#``"9`0``G`,``!H$````````0`$``!@(``#$!@``/@,``)<!
M````````!PL```````!#`@````````````!D"0``!@4``#8(```Z!```J`4`
M`+`'``"]!0``F0````P'``"["```!0D```````#=!@``B@,``"T(``#-`P``
M`````-T'````````Y@,``$L&``!A`P``0@```'L&``#6````D0(``-0%``!2
M!```;@0``/P%``#_"`````````````#L`P``G@D``/`#``#\!P``I0$`````
M``"`!@``O@$``(\'````````.@L``'<!```J"````````$(!``!-`@``QP<`
M```````L"0``^0@`````````````IP@``,<%``#J!0``]0@``&("```'!P``
MM0@``#T$```N!0``%04``"L#`````````@@``%$#``!-"@``.00`````````
M`````````)((````````$P```,P&```5"0````````0$``!(!```K@0``(P%
M``!(!0``Z0```/H!``!8!P``X0D``%D(``#P`@``?@,``#(%``"5"0``L0(`
M``````#`!````````#P$``#&````4@H`````````````)P<``#`(``"7!P``
MH`````T&``"["0```````$\*``!"!0``-08``($#``#Q`P``C@4```````#%
M"0``CP8````````J"0``(@$``%4#``!$!@```````,4(``#6!0``,PH``.4`
M``!D!P``\@@``-\!``#Z`P``#P<``+H)``!F!P``@`H`````````````%P,`
M`!H'`````````````#L'``"F!P``:`H```<&````````)0@``#$#```_`@``
M1@```$T(``!^"0``>@,``$````"Z`@``_0$```````!M!```I@8``-L(``"P
M`P``100``'P#``#R!0``?@(``"4%````````IP0``*\*````````````````
M```O"0```````*@&```@`0``VP0``%8!``"`!````````#L*```J"@``G0H`
M`)T)``"A!```C0,``#<+````````8`H``&D```#K"@``W`4``'P*````````
M#`$``/X"```V!P``I`(```H$``"A`P``#P4```````#*!0``_P0``*(#``#6
M"@```````.$!```C!P``%P0````````,`P``:@$``+X*```O`P``20<`````
M``#R````H`<```````!6````XP@``"L%``!0`@``5P8````````6`@``N0<`
M`((%```,!0```````.,#``#U`@``$0,``/4*````````W@D````````,"```
M`````$\```#(!```2`$``!,'````````*0(```````"-``````````````"@
M`0``]`<``.<#````````E@@``&(#``#3`0``<0D``$$#``#=!0```````#\(
M``!O!```M0D``*0(```-!0``K@@``&@$````````$0D``.L`````````@PD`
M```````R`P``0`(``,T&````````HP4``.X(````````D0@````````]`0``
M*`H``(0'``!V`0``?@0```````#W"@``C0H```````!4!0``X`8``+@(``#V
M!@``4P```"\(```S!@``2P(``.H#``!3"0``/@D``$,&````````=`0``"<%
M````````2PH```````!T"0``[08``-0&``#(`P```````!H!``#="```*08`
M`````````````````-H%``#(````OP@`````````````V@`````````L`@``
M*0<```L"``#L"@``-`0``,\#``#E"0```````)H$``#G"0``2@H``%@)```6
M"P``````````````````!`H``(@```"?"```E0H``-,(``#S`@``N@<``*,&
M``#$`````````&('```O`@```````#`&``````````````````"5!```G`0`
M```````.`@``J@(``-`)`````````````$`+``#I!0``G@0```````"8!0``
MW`````````!?!0````$``.T```!U!0``V04````````?`0``&@,``+`)```2
M`0``I@(```````"E!```'@@``'\*``"Q`P``1@@``/L'``"I!P```````'4*
M``#H!P``J`,``/T(````````4P,```````##`P``V@H``%(&``#Z````-PD`
M`/P(````````7`,``,T)``!F`@``40H``'<(``#!"0```````"T```#%!```
MDP4``/("```"!0``3@8```````!2"0``'P0```````"S!P``(0L``(8)``">
M"@```````+('``#Z!P``/P4```$$``"L`@``````````````````[`4``+<#
M```3!``````````````)"0````````0!```V!@```````(L&``"M"@``````
M``````!/"P``:`(``(("````````T0D```(#``"S!@````````X`````````
M"0,``#$&``"Q!@``7@@```P```!W"@``FP0``%T$``!2````J0$``"L"````
M`````````+(&````````N0D``%4'``"V`@``.0```!T'``#'````````````
M```'!```1`4``$H%``"N````P00``-\#``!("@```````,D)``!4!P``D0,`
M``````#F`0``WPH``,$#``#/"0``30$``#H```#J"@```````&`&``#%!P``
M=@,``%D%```@!0``*`L```````!>!0``(00`````````````QP0``(@%``"+
M`0``H`0``)L*```C`@``*`<``+D#````````8@$``'D*``!S!```,`,`````
M```*!0```````,P$```F!@`````````````L`P``\P,``'8'``!:`P``````
M``````"X`0```````%$&``!I`P``_`0``*4&``!7`0``E`(``+P*```Y"0``
MO0@``"<"```5!```?`D```````!O"0``H0$``,X*``"=!0``$0$``*,*``#I
M"```V`@````````D`@``Z`$`````````````30L````````P"P```````+(#
M``";"````````*T$``#,"```KP```"0$``#S````]`$``.`*```K"@``F`H`
M`/(*````````TP0``%@!``""!P``J`0``/('```#"@``:@````````!_"0``
MY0(``.\%````````"04``*8#``"X!P``$P4``,8)````````6P<``!0)````
M````UP8``,L"```>"@``.`4```X'```K"0``_`H``#$'``"/"0``N@,``,D%
M``#+"```A08``/L*``#)!```;@```#$(````````;P<``!T"```0"0``````
M`+T)``!A"@``8@D`````````````20````````",!@```````-\%``!,!@``
M)0(``#X!``!I"```%PL``"T)``!1!0``-0(``%$$````!0``VP`````````;
M"0``>0$````````K"````````+H```!)`@``-P$``,0*```W`P```0(`````
M`````````````'`(``!N"```P@@``&X*``!H`P`````````````,"P``````
M`$<'``!*"```2@<``%$```#4`0``D`<``!0%``!M"0````````4'```U"```
M<@,``+P'````````QPH```P$``"$!```?@```)P%`````````````#,)```.
M!```0`H``$D&```\````808``($"````````]P8``!\*````````E0$`````
M``!#`P``L@0``(0#``!T!@```````*D)````````V0D``!P!````````````
M`%`!``````````````````#/!@``S@0````````(`0````````````":"@``
MA0(``*T&````````[`D```````#^"```L`(```@+```$!P``^0$```````#F
M!P```````*\'``!@`@``$@H``#`!``#&!````````",(``!A````1@$``+("
M```````````````````4`P``*PL``/H%``!5!0``PP```-$```"H````````
M`````````````````.\"````````]`4````````U"0``K@8``(4)```["P``
M/P<``*0'`````````08``!@)`````````````(D#``"I!0````````````#G
M`0```````.X%``!T``````````````!X"```/P0``*T(````````XPH``#@"
M```F`@``"00``(8"```'`````````-(!``!B!0``X0<``+$*``!P!0``````
M```````8`P``"P```(<*``"``````````#<`````````"`4``+$)``")"0``
MJP4`````````````!`````````#K!```B`0``&D"````````U@@``'H'``"O
M"```:0<``/L!``!E!P``F00``"`#```R"P``MP(``'<#````````E````'\!
M``!W!P``3@D``',)```("@```````,`)````````G@8``-H&``"_!@``$```
M`#H)``"Y!`````````````"("0``'@8```````!_````I0`````&```="```
ML@$``/,&```"`0``(0$```````#T`P``\08```````"-!@``Y@@``)4'``#,
M`0``<04``)@```"1!P``TP<```````":`0``F`@``/<"````````````````
M``!5!@````````````#:`0``$`<```````!Y"0``L`0``.T#``#O````````
M```````P!```Q`<```````"/````300``)<#`````````````&D$```*"P``
M%`0```````!C"0``\`D```````#F!@```````/$(``#Q`0``MP4``#P%``"2
M!```D@8``'````!W!```9`@``$4+````````!0H``'8*`````````````#@!
M``!C"@``Q0````````"\!```KP0``"\&``!H!0``<PH``"()````````>@H`
M`%`)``"]````2`@``*$)````````C0D```````"^"0``XPD```H)``!+`P``
M'P4``)X````E"P````````````"$!@```````"X+``!4"P``M04``)$!````
M````Z@D``*(`````````500````````W!P```````*L&`````````````.T*
M``"6`0```````#D!``!K`@``Y`$``*H!````````9P4``"8*``#@!0``````
M`($$``!L`P``G@,``$D#``#W`````````.('``````````````````"A````
MA@H``-\'``#-"@``WP8``-8!``"'`0``<`,```````#"`P``XP(````#````
M````T`8``#@'``!V!0``_P$````````9`0``*P```-T```"*!0``]P$`````
M```L!```<@<````````*`@``%0@``,D*``!#"P``V`4``+8*```M"P``JPD`
M``````!D`P``&````%,"```C"P``[P@``*$%```."P``D00``.P$```B`P``
M``````````!P"@``(@<``/````#9!`````````````"B`0``S@(``,\'```N
M`@``$@4``(D&``````````````<*````````90,``%<)````````%`$`````
M``````````````````#("```U`@````````7"@``*P8``/H(````````O@@`
M`/@%```O`0``ZP<``/<$``#H"@``O@0```4(````````GP4``*@"``"%"```
M``````,$``"O"0``$`@``'0#``"Q`0``1`0``%P(````````/PH``&`%````
M``````````````#[!`````````````!,"P``B@@``(0)``#U!@```````(0(
M``!N!P``EP@``)0%``!_"````````%@&``#*"```````````````````````
M``````"9!@``FP<``!@*```E````.@<``,0!````````7`D```````!Q!P``
M#@@``+((``!F!@```````(,'````````EP```$@&``#<!```)0,`````````
M````/`$```````#(!0``4P$``(X"``"X````W@H``,,"``!,`@```````'T%
M````````Y@0``!L+``"^!P```````/@"```7!P``&`<``*D$``"!"0``````
M`*P$``#!!0``%P```&<'````````60$``,L'```^"P``]`@``*`(``"6`P``
MS0@``-4%``!J!@``]@D``)@'``"""@``H0(``#8*``#X`0``3@````````!=
M!P``GPD``#@$``",!P``X0,```````"%!0``2``````````_`P```````,X%
M``#M"0``\@8````````)"```M0$``)`$````````R08```````!S!@``3`0`
M`#0#```Z"````````````````````````*L*````````-@$``'8"``!Q!@``
M?0D``!$$``"3````7@```)@#````````I@H``'@"``"@"@``G@@``#,(```E
M!P``1`L``)8'```K!P```````!H+```]!P``_@,``#0!``!4"0```````.X)
M``#P!@``'`<``'<`````````F0@```````"V!````````+\"````````J@@`
M`!X```#I"0`````````````)`````````*($````````E0```*T)``"[!@``
MPP4``,0"``#_`P``2@8``,(*````````P`$``-L"```9!0``'P,`````````
M````0@L``"`"````````]@(``%,+``#K"```90H``'T"```*!P``````````
M``!.!```.P8```````#N`````````!0+``#Q!````````+D"``#3````:P0`
M`(<````H````N@@``&P!``"9"0``"P8``)`*``!4`0``B@```.4&``#X`P``
M`````,4#``#&`P```````)`"```3`0``'`D``(8$``#8!@``+P<``)X%````
M````S`H``&L&``!R!```$@,```````!6!0``WP0``.\&````````D````.,`
M``"+!P``BP@```````"%`0``?0H``$T#``"[!0```````+<'``#2`````P$`
M`+4*``![!P``,P(``.L"`````````````+,```"I````F@4``'\#``"3"```
MT`@``$()```?"0```````"D#```Z"@``O0H```````!/`@``^08``(`!```%
M"P``N@4``-D"``#N"@``;0@``#H#```(`@```````$,(``!I"0``UP(``'@'
M``````````````8!`````````````-$!``"=`@```````%D#```:"0``AP,`
M`(<(``!:`0``U0$``!H%``":!@``HP````````````````````,&``"-!0``
M(@@``-$'``!]!P``Z0(```````!"!P``C@,``#8"``"#`0``DP8``,4&``#)
M"```E08```````#7!P```````#(```!P!@``\`0``#@#``!%`@``10@``!L#
M`````````````!8)````````T0@``,D"`````````````.`````1!0``RP0`
M`$L`````````K0(``)`(``#R!```:@@``*L"```'"0```````$$(``"<!P``
M<0$```0&````````3`@``"X!``#I!```U0<``.<$````````;`0``'L!````
M`````````&8%```)`@``P`4``#\+``!)!````0D``#H&```&!@``;0,``%L(
M````````X@,```````!V!@``#@D``,`#``!C"```"````(8!```9````O```
M`+0```!5"@```````$<$``")!0``+@H``/T&````````$@``````````````
ML0@``+P&```4"```'`@``$H)```L"P``?0,``+@*``!O"```1`H``+P"````
M`````````#H%````````@@,``-\```"/!0``'00``,`*``!X`P```````'$(
M````````?`8``%H)```!`P``'08```````"R````Y0$``(H'``"7"@``````
M`(X$```````````````*````````QP,``&`#```U`P```````'P"````````
M/`L```````!(`P``60```.D!``!1`@``\P$``*X*`````````````,(!````
M````*04``/,*`````````````$((``#"!0``\@D```````"#`@``_04``+D&
M```Q`0```````-$$``#&!P``.08``#@)``"H!P``=@@```````#K`P``````
M```````Y"@``>@8```````!I`0``)`````\)``#H!@``5@<`````````````
MT`(``#L$``"7!@``#PH``+L!``!7`P``E0,``!L```!0"```W0D`````````
M````#00``&,#``!6`P``````````````````!@D``!D'```)!P``I0,``%\`
M````````M`4``/$"````````V@D``,,&````````20$``-X```"*"0``````
M`!L(``#:!P``A@````````"C`@``40D``/D```"J"0``X0H```````#B!```
M+````$T%````````B0<```````!M!P```````!`%```F"```[PD``.@```#R
M`P``70(`````````````Z@@```````#P!P```````$X*``#)`P```````,H$
M``#2!P```````$8"``"%````7P@``!X+`````````````#4+``#V`P``````
M`,@*```T````%0<``+D!``"H"@```````(L$``!+!0``G08`````````````
M$P,````````0!@```````````````````````"0*```D!0``B@8``(L#``"7
M"0``6P8``,@"`````````0$```````#,````_`(``(@!````````-`<``+<)
M`````````````.0'````````*@L``+`(`````````````&`````X"@``9PD`
M`!X)``"_"@``!0,``"4)````!```)@0``-4#``#J!```1`,``($&``!9"0``
M`````",*``!*`0``5P(````````*"```@@$``-0#`````````````',"``";
M`0``*`(``%@(``"X!```>00``+<(``!S`0````````````",!```?0@``!L&
M``""!@```````"@)```^`@````````````!7!P``0PH`````````````YP``
M`.H"````````2@,```````"_"0``"@$```````#D!@``S@8``"T&``"C"```
M-@D``,X!``!F`P``3P4``.P!``"B!0``P0(```````!H!P``C`,``+````"4
M!@``-0$``#()````````@P```,P'``"G"0``Y0@``&0"````````<`0``*X)
M```T!@```````,<!````````^`@``!(+``![`P``:P```/8%``"^`P``]`D`
M```````%!0``<0```$@)``!'"0``+0<``%@$```?!P````````````!`"0``
MN@$``.("``!%````B@$``&8)``"4"@``^0,```````"[!````````*((````
M````VPH``!P*```#````-P4``%4)``"T!@``H`D``'\'```B!0``:08``%P&
M```B"@```````,D'```@!@``4````,L)``!?!```6@0```````#A!0``,00`
M``('``"D!0```````($'````````#`8``)P&`````````````"<```!1`0``
MW`H``-P#```Y"P``G```````````````5P@````````J````!`D``!4!``#I
M!P``>@(``/,)``!9"@`````````````6!P``X@D``&L'``"4`0``?`<``*<`
M``!F!````````!\(``````````````````#O`P``A0,``$(*``#N`0``````
M`!T*````````N`(````````C!0```````+8&````````T@,``-D'``"D"@``
M!P,```````"""```FPD``(,*```J`0``4P4``(8#``","@```````(`)``!6
M"P``6`,``````````````````&`$``#9!@``GP```"`)```;!```I````#@&
M``!J`P``$P(```,)`````````````"0!``"P!@``6@(``"H"````````00H`
M`,L*````````_P8``/4#````````1P8``!P%``#W!0``Q`D``)0#```E"@``
M*@,````````,"@``&P(``!<!``#``@``&@```,(&``!O`0``V0$``,P%````
M````L0<``&<"``"3`P````````8+``!B````U0H`````````````X@4``$\(
M````````KP$``!D+``!O!@``R@```)8"``"``@``JP```%8&````````````
M`!,(``#/!```RP4``&@&``"!"```(`H``)H'``#W"```7@8``.\!``"\!0``
MP0$``&X)```N!@``Y0H``)0(``#+`0```````!<&``#-!0```````+8(``!?
M!@``E`D````````N````7@H``#P*``#J````?`4``*H&```I`0``)`@``,`(
M``#@!````````%,$````````#P8```````"E"@``J0,```````"U!P``"PH`
M``````#7!```M@````````#F!0``6PH```````#^"0````````````!'`0``
MD@D``/L)``#@`P```P4``)P)``!#!0``X@H``(P)````````OP0```````"U
M!@``.PD``%L#``!;"0```````+`!``#+`P``E@8```````"E"```D08``,D`
M``"4!```@P8``)8*````````M`D``!8#``!9`@``&@H``#0"````````````
M````````````/@H``-(%```J!@``_0D``&X"```T!0``````````````````
M,0(``(\!``"$"@``O@```.T'````````````````````````E04```X*````
M`````````.@$```<"P````````````!="@```````(@'``!``P``)PL``$("
M``!O!0``V0@```````!X!```K`@```````!C!@``8P```(L*``#:!```````
M`-T*``"H`0``QP@```````!:````<@`````````9!```90D``!X"````````
M]P<``$P*````````\04``(X(``"(`@```````*D*``!>"0``\`$``'P$``#A
M````A00``!D"``"F````PP@``.\*```=`0``00$``%T#``#Y`@``OP,`````
M``"+`@``'`0``.`)``!@"```7P<``-T#````````@@D`````````````"@``
M`($!```@"P``W@,```````#5"0```````#L"``"V`P``)@$```````!Y!0``
M`````*0!````````8P(``&D*``!.!0``<P,`````````````B@H```,(````
M`````````/D'``#(!P``P`````````#X!@``2P$````````1"````````)T$
M``#-`@```````%`&````````I@@`````````````WP(``%T)````````2@``
M``H*``#V!```K@,``-T$``#Y"@``GP8```````!K"0``>P(```````"("@``
M``````````"#`P``P0```/X*``!'!0``;04``+0'```=`P``<`(``!\&```4
M!@``U@D``$X+``#/`0``6`L``-0'`````````````*8%````````]`(`````
M``!G"@``R@D````````<`@```````&0!``!I!0```PL```````#'!@``````
M`-$%````````AP0``%,*````````<`D``````````````````,8&```U!0``
M$@0``'D(```I"@``N@H```\"````````P08``&P*```,`@``)@<``*8!``"S
M`0```````"X(``#%"@``*`@``"$%``!U`0``)`<```@$```T"@``IP8```8"
M``!A`@``.P```)P!````````>@$``-@)``"'`@``%P4``*@)``","```/@4`
M`$<"```N!P``:@D```````````````````````!S"````````&<$````````
M]P,``,P#``#R`0```````/\)````````?P(``#D#``!C!0``>`D``%P'``!.
M"```Z08``+L#````````O`D``)$)``!,`0``=`H``#,%``"T"@``D@(``%`#
M``#("0``$0H``"($``"C!P``%@8``%@*``!7"@``:P4```````"+````````
M`.,&``!-!P``O08``*P&``#W"0```````#T#```2`@``>`H``&X!````````
M/@8`````````````D@4``!0'````````;0(``-0```!_!0```````$D*``#2
M"0``)`L``+4"```_!@``^P,``"`$``"E`@```````#<*``!&!@``O@8``),'
M````````P@0``#,#``!Z`````````"T$````````-`D```````!<````#0``
M`!T+``!)!0``3`D```````":````-`@``$P```"=`P```````#P#````"```
M/0L```````!0"P``=0```'T&```!!P```````)$````!"P````````````#Y
M!```?@8````````'!0```````*L#``"A!@````````8'``#H`@``H0H`````
M``!!````108``%8"``#3`P``>`8```D!`````````````"D(````````````
M`#4````@!P``Z0H```<"````````YP4``$`%``!E`0```````&`!``#7`0``
MC0(``-8#``"[````N0@```````!T!0``2`(`````````````5`0```````"0
M`0``O`,``'4"````````N0H``)T!````````904``*4'``#,"0``60<``)P(
M````````4@,``"P&``#G`@``LP@```````#X"@````````````"9!0``B`@`
M``0#``!$`````````-8'````````Q@(``!D&``",````Q0(``&H"````````
M?0```.P(```0`0````````0"```A!P```````'`!``"N`0``5`(``'$*``#]
M````E`<``'8```#V!P``M`@``%$'``"``P``A`````8$``!B"@``.P@``/H*
M``!`!P````````````#/````%0(``#T)``!,!0``30D``/,%``#^````J@``
M`*$'``#"````#@$``*<'``!N!0```````"@#````````TPD``!4*``#Q````
M+PL`````````````;08``-<*`````````````-X(``#J`0``X@@````````2
M!@```````),!``##!P```````-@#``!/`0``#P,``$D(``#8`@``O`$`````
M``"*`@``J@,``&$%````````B`,```````!0!P``A`(````````R`0``(@(`
M`/\'``#*!@``/`8``&$(``#M"```K0$``!$'````````<00``"$*```:`@``
MYP@```T)```E!```-P8``/`(````````$0(``&\"````````4@$````````1
M"P``MP0``)@&``"V"0``XP$``-8"``"L`0``;P```*D"```^"````````"D+
M``!L!P``T@@``/,$``"2````X`(```````!"!```````````````````N0``
M`/,'``!K`P```````"D$``````````````D&``!1"P``3@<```````#2!@``
M``````(+``!B!@``A0H``#$*``!6!```/@<```````!\````Y0,``%T!``#K
M`0```````/4%``"X`P``PPH``$4*`````````````+$```!K"```````````
M``#<"0``:@4``-$&```D`P````````````#U!P``,`H``&8*````````````
M````````````:@0```````!J!P``;`4```\(``#/!0``?@$``'0'```H`0``
MWPD``#X$``!9!```+P0`````````````!`4```@&````````%PD``/P&``#A
M"```N`8``,<"```*!@``,0D``&<(``#4!````````/0`````````1@4`````
M````````Y`(``````````````````,H*``!>`0```````$$'````````PP$`
M`*<!``"."@``L@D``'()``"0"0````````````!@"0```````(<)```Y"```
M'0```-P'``#8`0``[P<```````!L!@``H0@``"8+``!R!0``$PD``%H&```M
M`P``P0@``,X#``!L"0```````.8*```3"@``^0D``%\*``#H!0``I`D`````
M``#Q"0``)PD```4$`````````````*,$`````````````!8%```[`0``]@``
M`$0'```)"P``=P4``*`&``!;`@``3`,``/P````R`@``^P(```````"-!P``
MW@4``,0#``#,`@``=0<``*0#```P!0``V0H```````#N!```U`H`````````
M````10$``%,(``!("P``^04````````B"P`````````````^````````````
M``!!"0``&`L``',`````````X@$``&T!``!5"```&0H``/T'````````.0<`
M`-0"``"8"0``"P<``(,$``"?"@``*0```-($````````*P$``#\!``#]!```
M`````#\``````````````(D```````````````````":"````````%\"```Q
M````/0````````#M!```@0H``)8````\"0``F@(``.H'``#!"@```````(T!
M````````2P<```H#```3"P``E@0``'@!```X"```ZP4``'D'````````M`(`
M`/@)```L`0``T`4``&$$``""!```1`@``"\*``"W`0``Q@4``,X'```%`0``
M'`8``)4(````````]`0``-$*`````````````)H#``!;`0```````!T)``#F
M````FP```/\"``"-"````````$8$``#8!P``JP<``!X!``!X!0``[0$``",!
M``#5!```'`,````````@````%@0``$\'``"#!0```````#T"``"Q!```C00`
M`*("```6"@``908``)`%``!8!0``CP@````````T"P``SP(``#,$````````
M?@4``!X%````````#@4``,$'``#_"@``OP<``+4#``"2`0``2@(`````````
M````O0(``)X!````````"PD``````````````````)@!```5`P``````````
M````````00(`````````````-P@```````"W````IP,``.`'````````&0,`
M`+L'````````X`$``#`"````````>0,``#$+``"?`0``Y`0``#$%```%`@``
M(@```!H(``")`0``@0```/4$````````_0(``'`'``!U!````````-\(``"#
M"```M@$``%X'```>!```.`````````!E"```EP0```````#E!P``20D``",`
M``"'!0``UP4``(D(``"8`@```````)\#``!=!@``2P@``.\$``"2!P``TPH`
M```````]"@``(P0``,0(```5!@````````````!5``````<``-("``"F!```
M^````)\$```\`@``AP<```````"7!0``Q04``&P`````````0PD``/T*``!K
M`0``=08````````-"P```````````````````````%<%``!Z!````````'0!
M``!_!```K`H``!\+````````T0(``"<!``#<!@``^P8``%P!```F"0``````
M`,L&``#-`0``*`4``*T#`````````````.8)```-!P````````````!&!P``
M5`@```````#G!P``LPD``)T```#H"````````*L(``#8"@``G`H``$`$```W
M!```"P$``%4"```R!```7@0`````````````Q`0``+,"``!-!@``&0D``"<&
M``#6!```"PL````````R!@``O00``.X#``"X!0``6@<``$\)``!#!```P@D`
M`",#``#-!```L@H``+H&``"J"@``H@H`````````````1P@``&T*```G"@``
M!`@``*L$```D!@``/0@```````"_````M`0``*P```!?`P``Y`H```,"````
M````^@D``!`*``!F"```F`0``*D&````````<0(``%L%``"S"@``A0<``-4"
M```4`````````!$&``"D!@``PP0``(8(```]!0``4@L``-H(````````L04`
M`.$&```;`0``R`8``&8!````````:`@``&,!``#E!0``K0````````#L!P``
M`````+@)``!3!P``#PL``"<$````````]0$`````````````R@,``*4)```(
M"`````````````"J!P``4@<``(X'``#&"```7@,``!()``!Y`@``B0H``!`$
M````````G0<``(`%``#Q!P``5`8``-T"``"T`0`````````````""@``^`<`
M```````+!0``(08``&<&```A`P```````(X)``"$`0``-@4```````#M!0``
M<P<``)$%````````5@D``"T"``#\"0``D`,``!H&``#^!0``7@(```````!6
M"```#P$``-L&``#N!P``6@H``$X"``!/!````````!@%``#$!0``9`4``$,!
M``#5"```0@8``-P"``![!0``4@@``/X!``#_````XP0``"0)````````<P4`
M`'P(``"F"0```````-@````""0`````````)```.!@``P`<```````!N!@``
M^P@``((```#&`0``?@@``(D"```Z`0``2`<```````#(`0``]@@``"D)``#:
M`P``F@D``&($``!!"P```````-X"``!="```````````````````````````
M``#7````P@(`````````````#`D``+H$``#N`@``+P4``(H$````````````
M``T*``#%`0``M@<``$L$``!A`0``<@(``.X&``"P"@``J@4``)X'````````
M=@0```````#^!P``&P<``#P(``!=`````````+T'``!Z"0```````'<&````
M````5`H``#T&``````````````$(``!^!P``LP,````````_"0``(`@``+,$
M``"6!0```````/`*``"B!P``'@,``````````````````-,&``!F````````
M`+(%``"E!0``````````````````1PH``'((``!Y`````````"H$``!&"0``
M^@0```````!^"@``J`@``),*``````````````````!E`@``4`4``#8#``"/
M`@``.04````````H!@````````````#C!P``8@@``%@"``"(!@``M@4``!\`
M``"+"0``F0H``#((``!Q`P``#0,`````````````#P0``&L*````````1P``
M`*\%``#@"```104````````#!P``*`0```$*``!@!P``O`@``*,!```-`0``
M.@(```````#M`@``)0$``.D#````````5@H``+L*``![````UP@``.(&``#/
M"@```````$\#``!W"0``3P8``,T```"<`@``T0,``!4+````````=@D``'T$
M``!3!@``,`D```````"@`@``!@,```````!;`````````-D```"U!```````
M`-(*```L!P``U`D````+``"O`@``:@H``.0(````````G0@```L(````````
M^P```&4```!&"@```````(`(``#=`0```````&4$``!H`0``R@<```````#[
M!0``GP(``'H(`````````````"8#``"`!P``.0(``/0&````````````````
M``#A`@``_0,``-8&``#3`@```````"X$````````O@(``,\(````````"P0`
M`.0```!?"0``10<```````"@`P```````````````````````,8*````````
M`````*<%``"M!P```````#L#``!D"@```````"$(`````````````.4$``#+
M`````````#,+```8`@``4@(``$8#``!M```````````````M"@``L`4```D*
M````````2@L``,X(``"C`P``S0<``'P!````````H`4``),)``!&"P``I`0`
M`.P```#0````?P8```````#0`P``=0,```0+`````@``+@,````````J!P``
M-P(``",&```0`@``GP<```````"B!@``T`<```````#)`0``_`$``'@````4
M"@```````%(%``!5`0``3`<```````!W`@``H@D````````=!0``6@@``)L%
M``!]`0``P`8``$$%``#A!````````*P'``#^!@``F0(```````#G"@``<@$`
M`"L$```V"P``3@$```````";`@``UP,``&0&``#0!````````"P(```"!```
M000``+4```#<"`````````4&``!Z!0``CP,``-L#````````$@@``'4(````
M`````````'D&`````````````'0(``!["```W@0``#,'````````NP(``'(&
M`````````@(``#4*``"T`P``A@4````@("`@("!#8SH@`"`@("`@(%1O.B``
M("`@($1A=&4Z(``@("`@1G)O;3H@`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S
M:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H
M>65S=&5R9&%Y*0`@4W5B:F5C=#H@`"!A="``(&EN(``B)7,B(&ES(&YO="!A
M(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@
M:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B
M('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`C`"4N
M,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D($UE<W-A9V5S`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"!M97-S86=E
M<R!H879E(&)E96X@9&5L971E9"X`)60@;65S<V%G97,@:&%V92!B965N(')E
M<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A
M;2X`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@
M>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S('-P86TN`"5D('1O("5D(&]F("5D($UE<W-A9V5S
M`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E
M<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S
M(&%L<F5A9'D@97AI<W1S+@`E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F
M;VQD97(@=V%S(&YO="!R96YA;65D+@`E<R!A="`E<R`E<P`E<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!M86EL8F]X+@`E<R!F;VQD97(@8F5I
M;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+@`E<R!H87,@
M86-C97!T960N`"5S(&AA<R!C86YC96QL960@(B5S(BX`)7,@:&%S(&1E8VQI
M;F5D+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E
M<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`B)7,B+@`E<R!H
M87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!H87,@=&5N
M=&%T:79E;'D@86-C97!T960N`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E
M<R!N;W0@9F]U;F0N`"5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("(E<R(N`"5S
M('1O("5S(&]F("5S`"5S('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@(B5S
M(BX`)7,@=VES:&5S('1O(&%M;65N9"`B)7,B+@`E<R!W:7-H97,@=&\@;6%K
M92!Y;W4@87=A<F4@;V8@(B5S(BX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE
M(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`B)7,B+@`E<R=S($%D9')E<W,@
M0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T
M`"5S.B`E<P`E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"D`)7,Z(%1H:7,@
M;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N
M($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R
M;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T
M:6]N+@`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C
M<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE
M(&-O;7!O<V4@<V-R965N+BD`*$A434PI`"A0;&%I;B!497AT*0`H4F5T=7)N
M('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA
M;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S
M8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"A396YD(&UE<W-A9V4@869T
M97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG
M97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N
M*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J`"H@4&QE87-E('-E;&5C
M="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,2!M97-S86=E
M(&AA<R!B965N(&1E;&5T960N`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`Q
M(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN`#$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M+@`Q,#`@8VAA<F%C=&5R<P`Q,#`P(&-H87)A8W1E<G,`,3(@2&]U
M<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`,C4P(&-H87)A8W1E
M<G,`-3`P(&-H87)A8W1E<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960`02!L87)G92!I;6%G92!N86UE9"`E<R!I<R!A='1A8VAE
M9"!T;R!T:&ES(&UE<W-A9V4N`$$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA
M<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@
M<F5C:7!I96YT+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I
M;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%.
M1`!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M
M`$%B<VUI9&1L90!!8V-E<'0@86YD(&%D9"!T;R!M>2!C86QE;F1A<@!!8V-E
M<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E<'1E9#H@`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W
M;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT)W,@;F%M93H`06-C;W5N=&EN
M9P!!8W1I;VYS`$%D9`!!9&0@)7,@=&\@;7D@061D<F5S<R!";V]K`$%D9"!#
M:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D
M($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O
M=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D
M(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P
M86ER`$%D9"!S;W5R8V4`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3
M:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;R!A9&1R97-S
M(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('1O(&UY(&-A;&5N
M9&%R`$%D9"!U<V5R`$%D9&5D("(E<R(@87,@86X@871T86-H;65N="X`061D
M960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I
M=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H
M96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@
M;VX@82!N97<@;&EN92D\+V5M/@!!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A
M;B!B92!V:65W960@)7,N`$%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL
M<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A
M9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&UE<W-A
M9V4@97)R;W(@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T
M86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!
M9&1R97-S($)O;VMS`$%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\
M96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN
M92D\+V5M/@!!9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I
M9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N
M(&$@;F5W(&QI;F4I/"]E;3X`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES
M=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L
M;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M
M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&P@;65S<V%G97,@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE
M($U"3U@@9FEL93H`06QL(&UE<W-A9V5S(&EN('EO=7(@(B5S(B!F;VQD97(@
M;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E
M9"X`06QL(&]L9"!L:6YK960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO
M;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&P@;VQD('-E;G0M;6%I;"!F
M;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E
M9"X`06QL(')I9VAT<R!O;B!F;VQD97(@(B5S(B!S=6-C97-S9G5L;'D@<F5M
M;W9E9"!F;W(@=7-E<B`B)7,B+@!!;&QO=R!&;VQD97(@0W)E871I;VX_`$%L
M;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M86EL8F]X
M/P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-
M4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-
M4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E
M('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06QT97)N871I=F4@<&%R=',@
M9F]R('1H:7,@<V5C=&EO;CH`06QW87ES`$%L=V%Y<R!S879E(&%T=&%C:&UE
M;G1S`$%M97)I8V%N(%-A;6]A`$%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T
M96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE($E-05`@<V5R
M=F5R('-A:60Z(`!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N('5N:VYO=VX@97)R;W(@
M;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W(&YO=&4N`$%N('5N:VYO
M=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN
M`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W
M97(`06YS=V5R960`06YS=V5R960@;65S<V%G97,`06YT87)C=&EC80!!;G1I
M9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`
M07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY($9I;'1E<G,`07!P;'D@1FEL
M=&5R<R!T;R`E<P!!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N
M/P!!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA
M>65D/P!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T
M92!3:7IE`$%P<FEL`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@5FER='5A;"!&
M;VQD97(@1&5F:6YI=&EO;C\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E
M;&5T92!T:&ES('!U8FQI8R!K97D_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD
M960A*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\`07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9
M(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG
M<F]U<',_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O
M;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@<W!A
M;2!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R
M('1R87-H(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA
M;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_`$%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S
M('-P86T_`$%R9V5N=&EN80!!<FUE;FEA`$%R<FEV86P@5&EM90!!<G0`07)U
M8F$`07-C96YD:6YG`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O
M4&%C:69I8R!296=I;VX`07-K`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1A8V@@1FEL97,`
M071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@
M;65S<V%G93\`071T86-H960@1FEL93H`071T86-H960@9FEL92`B)7,B(&5X
M8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T
M=&%C:&5D+@!!='1A8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q
M=65S="!Y;W4@<V5N="X`071T86-H;65N=`!!='1A8VAM96YT("5S(&1E;&5T
M960N`$%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@
M='EP90!!='1A8VAM96YT<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92X`071T96YD965S`$%T=&5N=&EO;@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T
M<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I
M<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H
M('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]I;7`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S
M`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A
M=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%U=&]M871I8V%L;'D@
M<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@
M:7,@:6X@;7D@861D<F5S<V)O;VL_`$%V86EL86)L92!!9&1R97-S(&)O;VMS
M.@!!=F%I;&%B;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!!>F5R8F%I
M:F%N`$)/1D@@17AC=7-E<P!"86-?:R!T;R`E<P!"86-K('1O("5S`$)A8VL@
M=&\@375L=&EP;&4@365S<V%G92!6:65W($EN9&5X`$)A8VMG<F]U;F0`0F%C
M:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B
M97)O<R!U<V5R;F%M92X`0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V
M97(@4F5S<&]N9&5D.B`E<P!"86AA;6%S`$)A:')A:6X`0F%N9VQA9&5S:`!"
M87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`0F%S96QI;F4`0F-C`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5L;W<@
M:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S
M<V%G92X`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQA8VML:7-T
M`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L
M;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQO8VL@:6UA9V5S(&EN($A434P@
M;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I9FEC86QL>2!R97%U97-T
M960_`$)O9'D`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R
M('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O
M=&@`0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E`$)O
M='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN
M9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R
M:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#
M`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`
M0U]H87)S970`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD
M87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(&-O;FYE8W0@=&\@
M=&AE(')E;6]T92!M86EL('-E<G9E<BX`0V%N(&YO="!C;VYN96-T('1O('1H
M92!R96UO=&4@;6%I;"!S97)V97(Z(`!#86X@;F]T(&1I<W!L87D@+2!F;W5N
M9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S<V%G92!I;B!T:&4@
M8W5R<F5N="!M86EL8F]X+@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T
M('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A
M;F-E;"!-97-S86=E`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YC96QL:6YG
M('1H:7,@;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O
M;G1E;G1S+@!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@
M82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D
M90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD
M<P!#8P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z
M`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96YT
M97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E<G1I9FEC871E($1E=&%I
M;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0V5R
M=&EF:6-A=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D
M(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+@!#:&%D`$-H86ER(%!E
M<G-O;@!#:&%N9V4`0VAA;F=E($%L;`!#:&%N9V4@1F]L9&5R`$-H86YG92!9
M;W5R(%!A<W-W;W)D`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H
M;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W
M(&UE<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!M86EL('-E<G9E<B!A;F0@
M9F]L9&5R('-E='1I;F=S+@!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG
M;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;"X`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N
M;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@
M($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H87)A8W1E<G,@
M=&\@9&ES<&QA>3H`0VAE8U]K($QI;FLN+BX`0VAE8VL@1F]L9&5R*',I(&9O
M<B!.97<@36%I;`!#:&5C:R!?06QL+TYO;F4`0VAE8VL@86QL(&UA:6P@<V5R
M=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ`$-H96-K('-P96QL
M:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\`0VAI;&4`0VAI;F$`0VAO
M;W-E($%C=&EO;CH`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!M86EL
M('-E<G9E<CH`0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T
M;R!T:&4@<FEG:'0Z`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N
M86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D
M<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N`$-H;V]S
M92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E
M>'!A;F1I;F<@861D<F5S<V5S+@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC
M92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U
M<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K("5S('1O
M(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R
M;W=S97(@8V%N('9I97<N`$-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G
M92X`0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+@!#;&EC
M:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O
M=RX`0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E
M+@!#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E
M;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@:&5R92!T
M;R!32$]7('1H92!);6%G97,`0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T
M960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T
M;R!S96%R8V@N`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K('1O(%-A=F4@4$=0
M(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VL`0VQI8VL@=&\@4V%V
M92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O
M;VL`0VQI8VMA=&5L;"!V:6$@2%144`!#;&EC:VEN9R!O;B!T:&4@861D<F5S
M<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R`$-L
M:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T
M;R!B92!R96%D`$-L;W-E`$-L;W-E(%=I;F1O=P!#;&]S92!T:&ES('=I;F1O
M=P!#;&]S960@1F]L9&5R`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E`$-O;&QA<'-E($%L;`!#
M;VQL87!S92!!;&P@1F]L9&5R<P!#;VQL87!S92!&;VQD97(`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO
M<B!);F1I8V%T;W(Z(`!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE
M;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&QE
M=&5D`$-O;7!O<V4@86YO=&AE<B!M97-S86=E`$-O;7!O<V4@;65S<V%G97,@
M:6X@82!S97!A<F%T92!W:6YD;W<_`$-O;7!O<V4@;65S<V%G97,@=VET:"!A
M;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H
M92!F96%T=7)E*3\`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN
M8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FEG
M=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+@!#;VYF:6=U<F4@;6%I
M;"!P<F5V:65W(&]P=&EO;G,N`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N
M9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N
M(&1R;W!P960@8GD@24U!4"!S97)V97(N`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I
M;&5D`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E
M<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;VYT<F]L
M(%!'4"!S=7!P;W)T(&9O<B`E<RX`0V]N=')O;"!3+TU)344@<W5P<&]R="!F
M;W(@)7,N`$-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S
M96%R8VAI;F<N`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K
M960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N
M(&ET(&%R<FEV97,N`$-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G
M<F%P:&EC86P@;VYE<S\`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@
M9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W!Y('1O(&9O;&1E<@!#;W)R
M96-T`$-O<G)E8W1E9"!497AT`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E
M87-O;B!':79E;CH@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V
M97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@8W)E871E('1H92!61E,@8F%C:V5N9#H@)7,`0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E
M(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,`0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`
M0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RX`0V]U
M;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3
M+51.148@871T86-H;65N="X`0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E
M<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H:79E+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@
M8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@
M;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO
M="!O<&5N('-E8W5R92!C;VYN96-T:6]N('1O('1H92!)34%0('-E<G9E<BX@
M)7,@.B`E<RX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO
M;B!F<F]M($E-05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R
M)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S
M(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E
M<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E
M<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E
M<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R
M96%T92!&;VQD97(`0W)E871E($ME>7,`0W)E871E(%9I<G1U86P@1F]L9&5R
M`$-R96%T92!A($YE=R!!8V-O=6YT`$-R96%T92!A(&QI;FL`0W)E871E(&$@
M;F5W(%-P86T@9F]L9&5R`$-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R`$-R
M96%T92!A(&YE=R!O;F4`0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(`
M0W)E871E(&$@;F5W('1R87-H(&9O;&1E<@!#<F5A=&4@9FEL=&5R:6YG(')U
M;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I
M;G1O(&9O;&1E<G,L(&%N9"!D96QE=&4@<W!A;2X`0W)E871E(&YE=R!S=&%T
M:6]N97)Y`$-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RX`
M0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET
M(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U
M<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U
M<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@86-C97-S('1O
M("5S`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI
M>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O
M=6YT<RX`0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+@!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<')U<P!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I`$1A:6QY`$1A=%]E`$1A=&%4<F5E($)R;W=S97(`1&%T
M86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO
M;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S
M`$1E8VQI;F5D`$1E8VQI;F5D.B``1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`
M1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4V5A<F-H
M($9I96QD`$1E9F%U;'0@4VAE;&P`1&5F875L="!S;W)T:6YG(&-R:71E<FEA
M.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$969I;FET:6]N<P!$96QE
M9V%T960`1&5L971E`$1E;&5T92`E<R!0=6)L:6,@2V5Y`$1E;&5T92!#96QL
M`$1E;&5T92!#=7)R96YT($ME>7,`1&5L971E($9O;&1E<BAS*0!$96QE=&4@
M1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@4V5L
M96-T960@1F]L9&5R<P!$96QE=&4@4W1A=&EO;F5R>0!$96QE=&4@5FER='5A
M;"!&;VQD97(`1&5L971E(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R
M("5S`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L
M971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M`$1E;&5T92!F971C:&5D(&UE<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\`
M1&5L971E(&9R;VT@;7D@8V%L96YD87(`1&5L971E(&]L9"!L:6YK960@871T
M86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H/P!$96QE=&4@;VQD('-E
M;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-P86T@;65S<V%G97,`1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M`$1E;&5T960`1&5L971E9"!M97-S86=E<P!$96QE=&5D('-E='5P('5P9W)A
M9&4@<V-R:7!T("(E<R(N`$1E;&5T960@=&AE(&%T=&%C:&UE;G0@(B5S(BX`
M1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$96QI=F5R>2!T:6UE`$1E
M;FUA<FL`1&5N>2!R97%U97-T`$1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5T86EL<P!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@
M;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@
M9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I9"!N;W0@871T86-H("(E
M<R(@87,@=&AE(&9I;&4@=V%S(&5M<'1Y+@!$:6T@<VEG;F%T=7)E<S\`1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`
M1&ER96-T;W)Y`$1I<W!L87D`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P
M;&%Y($]P=&EO;G,`1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN
M9R!A(&UE<W-A9V4_`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA
M>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;&%Y(&EN($)O
M9'D@;V8@365S<V%G90!$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@
M;F5W(&UA:6P_`$1I<W!L87D@=&AE(")%;7!T>2!3<&%M(B!L:6YK(&EN('1H
M92!M96YU8F%R/P!$:7-P;&%Y('1H92`B16UP='D@5')A<V@B(&QI;FL@:6X@
M=&AE(&UE;G5B87(_`$1I<W!O<VET:6]N`$1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;@!$:FEB;W5T:0!$;R!.3U0@;6%T8V@`1&\@3F]T($-H96-K($9O;&1E
M<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!N;W0@9V5N97)A=&4@82!L
M:6YK(&EN('1H92!&<F]M.B!C;VQU;6X`1&\@>6]U('=A;G0@=&\@;W!E;B!T
M:&%T(&9O;&1E<C\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$
M;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+@!$;VYE`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D("5S(&EN
M("YZ:7`@1F]R;6%T`$1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII
M<"!F:6QE*0!$;W=N;&]A9"!&;VQD97(H<RD`1&]W;FQO860@1F]L9&5R*',I
M(%LN>FEP(&9O<FUA=%T`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@4$A0('-C<FEP="X`1&]W;FQO860@:6X@+GII<"!&;W)M870`1')A
M9G0`1')A9G0@9F]L9&5R`$1R869T<R!F;VQD97(Z`$1R;W`@9&]W;B!L:7-T
M`$1R=6=S`$4M36%I;`!%+6UA:6P@061D<F5S<P!%3D0`15)2`$524D]2.B!9
M;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"X`16-U861O<@!%
M9&ET`$5D:70@0FQA8VML:7-T`$5D:70@0FQO8VL`161I="!&:6QT97)S`$5D
M:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!6:7)T=6%L($9O;&1E<@!%9&ET
M(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S`$5D:70@5VAI=&5L
M:7-T`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E
M<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!Y;W5R(&)L86-K;&ES
M=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D:70@>6]U<B!P<F5F97)E;F-E
M<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N`$5D:70@>6]U
M<B!W:&ET96QI<W0`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE
M;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M
M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1I960@86QL(&UE<W-A9V5S(&9R
M;VT@)7,N`$5M<'1Y($9O;&1E<BAS*0!%;7!T>2!396QE8W1E9"!&;VQD97)S
M`$5M<'1Y(%1R87-H(&9O;&1E<@!%;7!T>2!?4W!A;0!%;7!T>2!?5')A<V@`
M16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R
M;7,`16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/P!%;F%B;&4@4R]-24U%(&9U
M;F-T:6]N86QI='D_`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@
M4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!M97-S86=E('!R979I
M97=S/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F-R7WEP
M=&EO;B!/<'1I;VYS`$5N8W)Y<'1E9`!%;F0`16YD(&9O<G=A<F1E9"!M97-S
M86=E`$5N9"!M97-S86=E`$5N9"!M97-S86=E(&9R;VT@)7,`16YD('EE87(`
M16YL87)G92!%9&ET;W(`16YT97(@4&%S<W!H<F%S90!%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E
M`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%;G1E<B!T:&4@;F%M92!F;W(@
M>6]U<B!N97<@4W!A;2!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@
M;F5W(&1R869T<R!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W
M('-E;G0@;6%I;"!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W
M('1R87-H(&9O;&1E<@!%;G1I<F4@365S<V%G90!%;G1R>2`B)7,B('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:P!%<75A=&]R
M:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-O;FYE8W1I;F<@=&\@
M24U!4"!S97)V97(N("5S(#H@)7,N`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E
M<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I
M;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R
M;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D
M.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@
M(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V96YT('-U
M8V-E<W-F=6QL>2!D96QE=&5D+@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@06QL`$5X<&%N9"!!;&P@
M1F]L9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.86UE<P!%>'!A;F0@4VED
M96)A<@!%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M
M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_`$5X<&%N9"!T:&4@96YT:7)E
M(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\`
M17AP86YD:6YG`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&
M1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9?971C:"!-86EL`$9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T
M;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@
M)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L
M86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI
M:V4`1F5E;',@;&EK93H@`$9E=&-H($UA:6P`1F5T8V@@36%I;"!I;B!A('-E
M<&%R871E('=I;F1O=S\`1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N
M/P!&971C:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,`1F5T8VAE9"`Q(&UE<W-A
M9V4@9G)O;2`E<P!&971C:&UA:6PZ(`!&971C:&UA:6PZ(&YO(&YE=R!M97-S
M86=E<RX`1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:5]L=&5R<P!&
M:65L9"!M871R:7@`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%-E='1I;F=S`$9I;'1E<B!M
M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\`1FEL=&5R('-U<'!O<G0@
M:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`$9I;'1E<G,`1FEL=&5R<R!.
M3U0@06-T:79E`$9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G90!&:6YD`$9I
M;FQA;F0`1FER<W0@2&%L9@!&:7)S="!-86EL8F]X(%!A9V4`1FER<W0@4&%G
M90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O7W)W87)D
M`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]L9&5R($%C=&EO;G,@
M+2!#;VYF:7)M871I;VX`1F]L9&5R($YA=FEG871O<@!&;VQD97(@4W5M;6%R
M>0!&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"X`1F]L9&5R('5S92!I
M<R!N;W0@96YA8FQE9"X`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X
M('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y`$9O<FUS`$9O<G1U;F4`
M1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A
M<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A
M9V4@9G)O;2`E<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@
M365T<F]P;VQI=&%N`$9R964O0G5S>2!297%U97-T(%)E<W!O;G-E`$9R96YC
M:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,`1G)O7VT`1G)O;0!&<F]M($%D9')E<W,`1G)O;2!T:&4@`$9U
M;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=V0Z`$9W9#H@
M`$9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S`$=A8F]N`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%L($]P=&EO
M;G,`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'
M96]R9VEA`$=E<FUA;GD`1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O
M;FQY*0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';R!T;R!-97-S
M86=E`$=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B`B)7,B`$=O961E;`!'
M;V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R86YT(&%C8V5S<P!'<F%Y<V-A
M;&4`1W)E96-E`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T
M:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z
M(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P
M("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O
M=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@
M4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U
M>6%N80!(15)%`$A434P`2%1-3"!697)S:6]N(&]F($UE<W-A9V4`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`
M2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96EG:'0`2&5L<`!(96QP('5S:6YG
M(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI
M;F<@;V8@=&AE(&9I;&4Z`$AE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@
M8V]M<&]S:6YG.@!(:61D96X`2&ED9&5N(&EN(%1H<F5A9"!6:65W`$AI9&4@
M1&5L971E9`!(:61E(%5N<W5B<V-R:6)E9`!(:6=H`$AI9V@@4')I;W)I='D`
M2&EG:&5S=`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(
M;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO
M;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E
M<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S
M(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E
M<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T
M(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S
M(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT
M86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO
M=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/P!(;W<@;6%N
M>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F
M:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W('1O(&%T=')I8G5T92!Q=6]T960@
M;&EN97,@:6X@82!R97!L>0!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T
M<P!(=6YG87)Y`$E-05``24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*0!)
M34%0(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P
M;VYD960Z("5S`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;W9E<B!34TP`24U!4"!O
M=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I`$E-05`@;W9E<B!3
M4TP@*'-E;&8M<VEG;F5D*0!)34%0('-E<G9E<B!C;&]S960@=&AE(&-O;FYE
M8W1I;VXN`$E-05`L(&YO(%1,4P!)34%0+U!/4#,@36%I;"!397)V97)S`$E.
M0D]8`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!
M9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K
M9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC
M;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET
M>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@=7-I;F<@4U-,(&]R
M(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N
M(&QO861E9"X`268@>6]U(&-O;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE
M(&9O;&1E<BAS*2!W:6QL(&)E(&QO<W0A`$EF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N`$EG;F]R90!)9VYO<F4@06QL`$EM86=E`$EM86=E
M(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L
M;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`
M26UP;W)T`$EM<&]R="!+97D`26UP;W)T($ME>7!A:7(`26UP;W)T($UE<W-A
M9V5S`$EM<&]R="!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!#97)T:69I8V%T
M90!);7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y`$EM<&]R="!097)S
M;VYA;"!0=6)L:6,@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4R]-24U%($-E
M<G1I9FEC871E<P!);7!O<G0@4'5B;&EC($ME>0!);7!O<G0@4'5B;&EC(%!'
M4"!+97D`26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y`$EM<&]R="!3+TU)344@
M2V5Y`$EM<&]R="!M8F]X($9I;&4`26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O
M(&9O;&1E<B`E<RX`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O<G1A
M;G0@;65S<V%G97,`26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E<RX`26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26X@4')O8V5S<P!)
M;E]S97)T(%)O=R!!9G1E<@!);F)O>`!);F-L=61E(&$@8G)I968@<W5M;6%R
M>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_`$EN8VQU9&4@;W)I9VEN86P@
M;65S<V%G92!I;B!A(')E<&QY/P!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R
M<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@
M57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@
M;F\@;&]N9V5R(&%V86EL86)L92X`26YF;W)M871I;VX@;VX@)7,@4'5B;&EC
M($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA;"!0<FEV871E($ME>0!);F9O
M<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y`$EN;&EN90!);G-E<G0@
M0U]O;'5M;B!!9G1E<@!);G-E<G0@0V5R=&EF:6-A=&4@2&5R90!);G-E<G0@
M26UA9V4`26YS97)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>2!(97)E`$EN
M<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2!(97)E`$EN<V5R="!0=6)L
M:6,@4$=0($ME>2!(97)E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`
M26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T
M97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D
M9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O
M<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E
M<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M
M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A
M<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN
M:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G
M97(@;&ES=`!);G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP
M;VYE;G0N`$EN=F%L:60@061D<F5S<P!);G9A;&ED(%)E;6]T92!-86EL8F]X
M`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0
M(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`
M26YV86QI9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+@!);G9A
M;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!K97D`26YV86QI9"!L
M:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI
M9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI
M9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI
M<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P97)S;VYA;"!0
M1U`@<')I=F%T92!K97DN`$EN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K
M97DN`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!)
M;G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!)
M;G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`
M26YV96YT;W)Y`$EN=F5R=`!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA
M=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I
M8V$`2F%N=6%R>0!*87!A;@!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T
M:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`
M2G5S=&EF>2!2:6=H=`!+0@!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME
M;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`
M2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+
M97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$ME>2!G96YE<F%T:6]N(&UA
M>2!T86ME(&$@;&]N9R!T:6UE('1O(&-O;7!L971E+B`@0V]N=&EN=64@=VET
M:"!K97D@9V5N97)A=&EO;C\`2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE
M+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BX`
M2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R
M97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B!C;VYT86-T<RX`2V5Y('-U
M8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S
M`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC
M(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+=7=A:70`2WER9WEZ<W1A;@!,85]Y
M;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M`$QA<W0@2&%L9@!,87-T($UA:6QB;W@@4&%G90!,87-T(%!A9V4`3&%S="!0
M87-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@
M8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,
M97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,
M:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!2
M86EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,
M:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@
M4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!!='1A8VAM96YT<S\`3&EN:R!P
M;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:V5D(&%T=&%C:&UE;G1S(&%R
M92!F;W)B:61D96XN`$QI;FMS`$QI;FMS('=I;&P@97AP:7)E(&]N("5S`$QI
M;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES
M="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T
M(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E
M;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"!O;FQY('-E92!C;VYT86-T<R!T
M:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI`$QI<W0M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@:6X@=&AE($AE861E
M<@!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F
M86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U
M<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@36%I;&)O>#H`3&]C86P@
M=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&EN
M('1O("5S`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,
M;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,
M;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W<@4')I;W)I='D`
M3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R
M(')O;6%N(&YU;6)E<G,`3&]W97-T`$QU>&5M8F]U<F<`34T`34]41`!-4RU4
M3D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-
M86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%C
M:6YT;W-H($9I;&4`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`
M36%I;"!0<F5V:65W<P!-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z
M`$UA:6QB;W@`36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T:6]N<P!-
M86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA
M;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P
M<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!!;&P@365S<V%G97,@
M:6X@1F]L9&5R(&%S(%-E96X`36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R
M(&%S(%5N<V5E;@!-87)K(&%S.@!-87)K(&1I9F9E<F5N="!L979E;',@;V8@
M<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA<FL@;65S<V%G97,@
M87,@<V5E;C\@*$E-05`@;VYL>2D`36%R:R!S:6UP;&4@;6%R:W5P/P!-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-
M87)T:6YI<75E`$UA=&-H($%L;"!1=65R:65S`$UA=&-H($%N>2!1=65R>0!-
M871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W
M960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA
M>&EM=6T@071T86-H;65N="!3:7IE`$UA>&EM=6T@3G5M8F5R(&]F($9O;&1E
M<G,`36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE
M;F=T:`!-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D+@!-
M87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+@!-87D`36%Y
M;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@1F]L9&5R($QI<W0`365N=2!M
M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@0V]M<&]S:71I;VX`
M365S<V%G92!$871E`$UE<W-A9V4@3W!T:6]N<P!-97-S86=E(%-E87)C:`!-
M97-S86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@5FEE=VEN9P!-97-S86=E(&5X
M<&ER960N`$UE<W-A9V4@9FQA9W,`365S<V%G92!F;VQD97)S`$UE<W-A9V4@
M9G)O;2`E<P!-97-S86=E(&AA<R!A='1A8VAM96YT<P!-97-S86=E(&ES(&5N
M8W)Y<'1E9`!-97-S86=E(&ES('-I9VYE9`!-97-S86=E(&UA=&-H97,`365S
M<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2X`365S<V%G92!S96YT('-U
M8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<P!-97-S86=E('-E;G0@
M<W5C8V5S<V9U;&QY+@!-97-S86=E('1Y<&4`365S<V%G97,@<&5R('!A9V4@
M:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`365T87(@5V5A=&AE
M<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO
M9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN
M960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I
M82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O
M<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE
M<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I
M;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2
M('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@
M36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>0!-;V1I9GD@55),
M`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA
M`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E
M<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C
M=&5D("5D+@!-;W)E('1H86X@;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I96QD
M("(E<R(N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S
M=&QY(%-U;FYY`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@<W!A;2!M97-S86=E<R!T;R!S<&%M
M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@24Y"3U@`36]V92!T
M;R!F;VQD97(`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<P!-=6QT:7!A<G0O86QT97)N871I=F4`375L=&EP;&4@365S
M<V%G92!6:65W`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C
M8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`
M37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3D].10!.3U1%`$YA;64`3F%M
M92!A;F0O;W(@96UA:6P@8V%N;F]T(&)E(&5M<'1Y`$YA;6EB:6$`3F%U<G4`
M3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N
M=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I
M;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A
M;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=F5R('-A=F4@
M871T86-H;65N=',`3F5W`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE
M=R!&;VQD97(`3F5W($UA:6P`3F5W($UE<W-A9V4`3F5W($UE<W-A9V4@=&\@
M)7,`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA
M;F0`3F5W(&UE<W-A9V5S`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE
M=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T
M(%!H87-E<P!.97AT($UE<W-A9V4`3F5X="!086=E`$YE>'0@;W!T:6]N<P!.
M97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO
M($-E<G1I9FEC871E(&9O=6YD`$YO($5N8W)Y<'1I;VX`3F\@2V5Y<R!I;B!+
M97ER:6YG`$YO($UE<W-A9V5S`$YO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D
M+@!.;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT`$YO(%!R979I97<@
M5&5X=`!.;R!0=6)L:6,@2V5Y<R!&;W5N9`!.;R!3+TU)344@<'5B;&EC(&ME
M>2!I;7!O<G1E9"X`3F\@871T86-H;65N=',@9F]U;F0N`$YO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N
M`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I
M;VX@<W5P<&QI960N`$YO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@
M=&AE('!U8FQI8R!K97DN`$YO(&9I;&4@=7!L;V%D960`3F\@9F]L9&5R('-E
M;&5C=&5D+@!.;R!F;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@
M;6%I;"X`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!F;VQD97)S('=I
M=&@@;F5W(&UE<W-A9V5S`$YO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G
M97,`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C
M871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@8F]D>2!T97AT`$YO(&UE<W-A
M9V4@<W5P<&QI960N`$YO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N
M`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O
M9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A4
M5%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)
M34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@
M3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I
M<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N
M9&EN9R!S:6=N=7!S+@!.;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP
M;W)T960N`$YO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.
M;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+@!.;R!P
M97)S;VYA;"!P<FEV871E(&ME>2!E>&ES=',@<V\@=&AE(&UE<W-A9V4@:7,@
M=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`3F\@<75O=&$@<V5T+@!.;R!R=6QE
M<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S<&5L;&-H
M96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"X`3F\@<W!E;&QI;F<@97)R;W)S
M`$YO('-U8V@@9FEL90!.;R!S=6=G97-T:6]N<P!.;R!S=7!P;W)T960@24U!
M4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N`$YO('1E
M;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E
M<B!S<&5C:69I960N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!0
M87)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9F]L:R!)
M<VQA;F0`3F]R;6%L`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@
M1&5L971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`
M3F]T(&$@9&ER96-T;W)Y`$YO="!A('9A;&ED('!U8FQI8R!K97DN`$YO="!D
M96QE=&5D(&UE<W-A9V5S`$YO="!I;7!L96UE;G1E9"X`3F]T(&EM<&]R=&%N
M="!M97-S86=E<P!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&4@=&AA="!T
M:&ES(&-A;B!T86ME('-O;64@=&EM90!.;W1E<P!.;W1H:6YG`$YO=&AI;F<@
M=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I9FEC871I;VXZ($QI;FME9"!A='1A
M8VAM96YT(&1O=VYL;V%D960`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C
M:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!M;VYT:',@
M=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO
M;G1H;'DN`$YU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E
M<"!I9B!D96QE=&EN9R!M;VYT:&QY+@!.=6UB97(@;V8@<F]W<P!.=6UB97)S
M(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L
M:7-T+@!/2P!/4@!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E
M<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@;65S<V%G97,`3VQD('!A<W-W;W)D
M`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VQD('-E;G0M;6%I;"!F
M;VQD97)S(&)E:6YG('!U<F=E9"X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S
M=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&1I<W!L87D@9F]L9&5R<R!W
M:71H('5N<F5A9"!M97-S86=E<R!I;B!T:&5M/P!/;FQY(&]F9F5N<VEV92!F
M;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@
M;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N
M+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S
M:&%R90!/<&5N($9O7VQD97(`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="X`3W!E;F5D($9O;&1E<@!/<&5N<R!T:&ES(&QI;FL@:6X@
M82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC
M:7!A;G0`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C
M;W5N=',`3W1H97(@3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N<P!004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K
M96YD`%!'4`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'0@365S
M<V%G90!01U`@16YC<GEP=&5D($1A=&$`4$=0($5R<F]R.B``4$=0($5R<F]R
M.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+@!0
M1U`@3W!T:6]N<P!01U`@4&%S<W!H<F%S92!);G!U=`!01U`@4&5R<V]N86P@
M2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T
M:6]N+@!01U`@4'5B;&EC($ME>0!01U`@4'5B;&EC($ME>2!497AT`%!'4"!0
M=6)L:6,@2V5Y(&9O<B`B)7,@*"5S*2(@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"X`4$=0(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+@!01U`@4'5B;&EC($ME>7)I;F<`4$=0(%-I9VX@365S<V%G90!0
M1U`@4VEG;B]%;F-R>7!T($UE<W-A9V4`4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T80!01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@
M<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N`%!'4"!S=7!P;W)T(&ES
M(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!01U`@<W5P<&]R="!I<R!N;W0@
M8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@
M=6YA8FQE('1O(&)E('9E<FEF:65D+@!01U`@<W5P<&]R="!I<R!N;W0@8W5R
M<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@
M9&5C<GEP=&5D+@!01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S
M('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E
M="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T
M:&ES('-E='1I;F<@;W(@96QS92!T:&4@4$=0(&9E871U<F5S('=I;&P@;F]T
M('=O<FL@8V]R<F5C=&QY+@!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@
M4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U
M;@!032!4+5-T;W)M<P!03U`S`%!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L
M<RD`4$]0,R!O=F5R(%-33`!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C
M97)T:69I8V%T92D`4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I`%!/4#,L
M(&YO(%1,4P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL
M`%!A9&1I;F<`4&%G92`E9"!O9B`E9`!086=E('=I=&@@=&AE($9I<G-T(%5N
M<V5E;B!-97-S86=E`%!A9V4@=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G
M90!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P
M:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G0H<RD`
M4&%R=&QY($-L;W5D>0!087-S<&AR87-E`%!A<W-P:')A<V4@*$%G86EN*0!0
M87-S<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"X`4&%S<W!H<F%S93H`
M4&%S<W!H<F%S97,@8V%N;F]T(&)E(&5M<'1Y`%!A<W-P:')A<V5S(&1O(&YO
M="!M871C:`!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL
M>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H
M+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG
M;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E
M<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N;F]T(&)E
M(&-H86YG960N`%!E<G-O;F%L`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G-O
M;F%L(%!'4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!E<G-O
M;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)S;VYA;"!3
M+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@`%!E<G-O;F%L(%,O
M34E-12!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)U`%!E=',`4&AI
M;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%C92!Y
M;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_`%!L
M86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4`4&QA>2!S;W5N9"!O;B!N97<@
M;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O<G0@
M96UB961D960@<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I;F1O
M=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL(')E<75I<F4@
M82!P;'5G:6XN`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A
M=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!E;G1E<B!T:&4@;F%M
M92!O9B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H92!N97<@;F%M
M93H`4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P
M<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N=&5R('1H:7,@
M<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A<V4@96YT97(@
M=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9
M;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N
M8V4@<&5R("5S('-E<W-I;VXN`%!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S
M=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S
M:6YG(&-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN
M('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@;&]G(&EN(&%G86EN
M(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P
M(&%T=&%C:V5R<R!F<F]M(&AI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E
M(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!P87-S=V]R9"X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92X`4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E<V]L
M=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+@!0;&5A<V4@<V5L
M96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RX`
M4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"X`
M4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H:7,@;W!E<F%T
M:6]N+@!0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@
M<FEG:'0Z`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L
M86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4&]W97)E9"!B>2!(
M;W)D90!0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@
M)RD_`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I
M<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9F5R96YC97,@<W5C8V5S<V9U;&QY
M('5P9&%T960N`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@
M;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W`%!R979I;W5S($UE<W-A9V4`4')E=FEO=7,@4&%G
M90!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT`%!R:6YT(&1O8W5M96YT`%!R:6]R
M:71Y`%!R:79A=&4@2V5Y`%!R:79A=&4@2V5Y(%!A<W-W;W)D`%!R;V)L96T`
M4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@979E<GD@=&EM
M92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\`4')O;7!T
M(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O
M(%E%4P!0<F]M<'0@=&5X=`!0<F]T;V-O;#H`4'5B;&EC($ME>0!0=6)L:6,@
M2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC(%!'4"!K97ES
M97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"X`4'5B;&EC+U!R:79A
M=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O
M(%)I8V\`4'5R7V=E($1E;&5T960`4'5R9V4@1&5L971E9`!0=7)G92!&;VQD
M97(H<RD`4'5R9V4@5')A<V@@:&]W(&]F=&5N.@!0=7)G92!M97-S86=E<R!I
M;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES
M+@!0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\`4'5R
M9VEN9R`E9"!M97-S86=E<R!F<F]M(%1R87-H(&9O;&1E<BX`4'5R9VEN9R`Q
M(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N`%%A=&%R`%%U97)Y`%%U;W1A
M`%%U;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0!1=6]T
M82!S=&%T=7,Z("4N,F9-0B`O($Y/($Q)34E4`%%U;W1A('-T871U<SH@3D\@
M3$E-250`475O=&EN9R`E9CH`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D
M:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3
M:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U
M;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!296-E:79E9"!/;@!296-E:79E9"!3:6YC90!296-E
M:79E9"!5;G1I;`!2961I<F5C7W0`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G
M90!2961I<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2
M961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.@!2969R97-H($9O;&1E<B!6:65W<SH`4F5F<F5S
M:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L
M;V%D`%)E;&]A9"!6:65W`%)E;6%R:W,`4F5M96UB97(@=&AE(&9R964O8G5S
M>2!I;F9O<FUA=&EO;BX`4F5M96UB97(@=&AE(&QA<W0@=FEE=P!296UO=&4@
M36%I;&)O>#H`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M
M;W9E($9I96QD($9R;VT@4V5A<F-H`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!S;W5R8V4`
M4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!296YA;64@1F]L9&5R*',I
M`%)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT
M:#\`4F5N86UI;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9`!297!L7WD@=&\@3&ES=`!297!L86-E('=I=&@Z
M`%)E<&QY`%)E<&QY(%-E;G0N`%)E<&QY('1O($%L;`!297!L>2!T;R!!;&PZ
M`%)E<&QY('1O($QI<W0`4F5P;'D@=&\@3&ES=#H`4F5P;'D@=&\@7T%L;`!2
M97!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G90!297!L>2!W:71H(&9R
M964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P;'D@=VET:"!R97%U97-T
M960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L>2U4;P!297!L>2U4;SH@
M`%)E<&QY.@!297!O<G0@87,@26YN;V-E;G0`4F5P;W)T(&%S(%-P86T`4F5Q
M=65S="!A(%]296%D(%)E8V5I<'0`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S="!R96%D(')E8V5I
M<'1S/P!297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N`%)E<75E<W1E9"!S
M97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M($9I96QD`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W
M;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S<&]N9&5N="!3=&%T=7,@57!D
M871E9"X`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5S=6UE`%)E<W5M
M92!Y;W5R('-E<W-I;VX`4F5T=7)N('1O(")-97-S86=E($-O;7!O<VET:6]N
M(@!2971U<FX@=&\@1F5T8V@@36%I;`!2971U<FX@=&\@3W!T:6]N<P!2971U
M<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V
M:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\`4F5T>7!E(&YE=R!P87-S=V]R
M9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V
M86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@
M,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2
M;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O
M34E-10!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N
M8W)Y<'0@365S<V%G90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4R]-24U%
M($5R<F]R.B``4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E
M<G-O;F%L('!R:79A=&4@:V5Y+@!3+TU)344@3W!T:6]N<P!3+TU)344@4&%S
M<W!H<F%S92!);G!U=`!3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T
M(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!3+TU)344@4'5B
M;&EC($ME>2!F;W(@(B5S(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N`%,O
M34E-12!0=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`4R]-24U%(%!U
M8FQI8R!+97ER:6YG`%,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U
M8V-E<W-F=6QL>2!A9&1E9"X`4R]-24U%(%-I9VX@365S<V%G90!3+TU)344@
M4VEG;B]%;F-R>7!T($UE<W-A9V4`4R]-24U%('-U<'!O<G0@:7,@9&ES86)L
M960@;VX@=&AI<R!S>7-T96TN`%,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R
M96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@
M9&5C<GEP=&5D+@!3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T
M:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S<V%G92!C86YN;W0@8F4@
M9&ES<&QA>65D+@!3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T
M:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E('9E<FEF:65D
M+@!3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E
M('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T;R!D
M:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E
M='1I;F<@;W(@96QS92!T:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O
M<FL@8V]R<F5C=&QY+@!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%--4R!-97-S86=I;F<`4TU44`!344P@4VAE;&P`4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL
M`%-?=6)J96-T`%-A`%-A7W9E(&$@8V]P>2!I;B``4V%?=F4@87,`4V%I;G0@
M2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN
M="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'
M<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U
M9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!!='1A8VAM
M96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\`4V%V92!$
M<F%F=`!3879E($EM86=E`%-A=F4@26UA9V4@:6X@1V%L;&5R>0!3879E($]P
M=&EO;G,`4V%V92!3=&%T:6]N97)Y`%-A=F4@7T1R869T`%-A=F4@87,`4V%V
M92!D<F%F=',@87,@=6YS965N/P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O
M('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\`4V%V92!S96%R8V@@87,@82!V
M:7)T=6%L(&9O;&1E<C\`4V%V92!S96YT(&UA:6P_`%-A=F5D("5S(&-O;F9I
M9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B
M+@!3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@)7,`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A
M<F-H`%-E87)C:"`E<P!396%R8V@@16YG:6YE<P!396%R8V@@3W!T:6]N<P!3
M96%R8V@@4F5S=6QT<P!3965N`%-E;&5C=`!396QE8W0@06YO=&AE<B!!8V-O
M=6YT`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD
M`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L
M96-T(&$@<V5R=F5R`%-E;&5C="!A('-T871I;VYE<GDZ`%-E;&5C="!A('5S
M97(@=&\@861D`%-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D
M:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RX`4V5L96-T(&%L;`!3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%L;"!F:65L9',@
M=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RX`4V5L96-T(&%N
M(&%C8V]U;G0`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!G86QL97)Y('1O('-A=F4@=&AE
M(&EM86=E(&EN+@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E`%-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@
M061D<F5S<R!B;V]K<SH`4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<@!3
M96YD($QA=&5S="!);F9O<FUA=&EO;@!396YD($UE<W-A9V4`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!396YD(%--4P!396YD(')E860@<F5C96EP="!W:&5N(')E
M<75E<W1E9"!B>2!T:&4@<V5N9&5R/P!396YE9V%L`%-E;G-O<CH@`%-E;G0@
M;6%I;"!F;VQD97(`4V5N="!M86EL(&9O;&1E<CH`4V5P=&5M8F5R`%-E<F)I
M82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<@!397)V97(@
M86YD($9O;&1E<B!);F9O<FUA=&EO;@!397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+@!397)V97(Z`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)
M1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@
M>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T
M(&ET+@!3970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO
M=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N`%-E="!T:&4@6"U0<FEO<FET
M>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_`%-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I
M;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAA<F4@1F]L9&5R<P!3:&%R92!M
M86EL(&9O;&1E<G,`4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE
M<B!U<V5R<RX`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=6QD(&QA<F=E
M(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@
M9&5F875L=#\@270@8V%N(&)E('1O9V=L960@96%S:6QY('=H:6-H979E<B!Y
M;W4@8VAO;W-E+@!3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S
M86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\`4VAO=6QD('1H92!C;VUP
M;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H
M;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO
M=7(@;65S<V%G97,@8GD@9&5F875L=#\`4VAO=P!3:&]W($%L;"!&;VQD97)S
M`%-H;W<@06QL($AE861E<G,`4VAO=R!$96QE=&5D`%-H;W<@3&EM:71E9"!(
M96%D97)S`%-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N`%-H;W<@3VYL
M>2!3=6)S8W)I8F5D($9O;&1E<G,`4VAO=R!5;G-U8G-C<FEB960`4VAO=R!A
M;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M
M(&UE<W-A9V5S/P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY
M('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN
M`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L
M96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\`4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('!R979I97=S(&9O<B!U;G)E
M860@;65S<V%G97,@;VYL>3\`4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\`
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/P!3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@
M=&AE(&UE;G5B87(_`%-H;W<@=&AE($EM86=E<P!3:&]W('1H92!486)L92!#
M96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T;W1A;"!N=6UB97(@
M;V8@;6%I;',@:6X@9F]L9&5R/P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E
M<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y
M`%-H;W=N`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VE?>F4`4VEE<G)A($QE;VYE
M`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEG;F5D
M`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO
M=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W
M97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W
M(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI
M80!3;VYG<R`F(%!O96US`%-O<G0@8GD@07)R:79A;`!3;W)T(&)Y($1A=&4`
M4V]R="!B>2!&<F]M($%D9')E<W,`4V]R="!B>2!-97-S86=E(%-I>F4`4V]R
M="!B>2!3=6)J96-T`%-O<G0@8GD@5&AR96%D`%-O<G0@8GD@5&\@061D<F5S
M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!
M9G)I8V$`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN
M(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I
M;@!3<&%M`%-P86T@9F]L9&5R.@!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M<&5C:6%L($-H87)A8W1E<G,`4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N
M;F]T(&)E(&5D:71E9"X`4W!E;&P@0VAE8VL`4W!E;&P@0VAE8VME<@!3<&5L
M;"!C:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W
M:&5N('-P96QL(&-H96-K:6YG+@!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`
M4W1A<G0`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T:6]N97)Y
M`%-T871I;VYE<GD@;F%M93H`4W1A=&EO;F5R>2!T>7!E.@!3=&%T:6]N97)Y
M.@!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME
M=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!!='1A8VAM96YT`%-T<FEP(&1O
M;6%I;B!F<F]M('1H92!A9&1R97-S`%-T<FEP(&QI;F5B<F5A:W,_`%-T>6QE
M(%M#4U-=`%-U`%-U8E]J96-T`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`4W5B:F5C=`!3=6)J96-T($9I96QD`%-U8FUI=`!3=6)M:71T960@<F5Q
M=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO
M9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U
M8G-C<FEB92!T;R!&;VQD97(H<RD`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S
M<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V
M960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3
M=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E
M<P!3=61A;@!3=6=G97-T:6]N<P!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`
M4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T
M`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M
M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I
M=&-H($-O;7!O<VET:6]N($UE=&AO9`!3=VET8V@@=&\@2%1-3"!C;VUP;W-I
M=&EO;@!3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;@!3=VET>F5R
M;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3
M=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I
M;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A
M:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N
M>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E7WAT
M`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R
M871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O
M)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP
M;&%T92!!9&UI;FES=')A=&EO;@!496YT871I=F4Z(`!496YT871I=F5L>2!!
M8V-E<'0@<F5Q=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497)M<R!O9B!3
M97)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<`!497AT`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:6QA;F0`5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($9R;VTZ(&-O;'5M
M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.@!4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S
M(@!4:&4@24U!4"!S97)V97(@9&]E<R!N;W0@87!P96%R('1O('-U<'!O<G0@
M=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!S96QE8W1E9"X@4&QE87-E(&-O
M;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE($E-4U`@;&]G
M(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA8VEN=&]S:"!R97-O
M=7)C92!F;W)K`%1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@
M9&]W;FQO861E9"`E<RX`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L
M;W-E9"X@17AI=&EN9RX`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@86-C;W5N="`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N`%1H92!A='1A8VAM96YT('=A<R!N;W0@9F]U;F0N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O
M;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V
M92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@
M8F5L;W<N`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N
M86UE9"!T;R`B)7,B+@!4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@
M86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!D<F%F="!H87,@8F5E
M;B!S879E9"!T;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E
M=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BX`5&AE(&9I96QD("(E
M<R(@8V%N)W0@8F4@97AP86YD960N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O
M;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F
M;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L9&5R("(E<R(@8V]N
M=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@
M8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A=&5D(&)U="!Y;W4@
M=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O;&1E<B`B)7,B('=A
M<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@
M:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!N;W0@
M9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&4@9F]L
M9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+@!4:&4@9F]L9&5R
M("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4:&4@9F]L9&5R("(E
M<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E<R(N`%1H92!F;VQL
M;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R
M(&UE<W-A9V4N`%1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T
M;R!T:&ES('!A<G0Z`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O
M(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S
M('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E
M8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@
M8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A
M;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET
M>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!I;6%G92!S879E('=I;F1O
M=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U
M<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!I;6%G97,@
M=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES('!R97-E
M;G0@:6X@>6]U<B!A9&1R97-S8F]O:RX`5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M86EL('-E<G9E
M<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@
M;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I
M;VYA;"!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F
M;VQL;W=I;F<@;65S<V%G93H`5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E
M;7!T>2X`5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@*"5D(&)Y=&5S*2!E
M>&-E961S(&9E=&-H('-I>F4@;&EM:70N`%1H92!M97-S86=E(&)E:6YG(&-O
M;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A9V4@
M:&%S(&)E96X@9&5L971E9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I
M960N`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S
M+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B
M)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P87-S<&AR87-E('=I;F1O=R!C86XG
M="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E
M<B!T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/P!4:&4@<')E9F5R96YC92`B)7,B
M(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D
M('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+@!4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L
M:6,@2V5Y(&-A;B!B92!V:65W960@)7,N`%1H92!R97%U97-T960@9FEL92!D
M;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!4:&4@
M<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A
M8VAM96YT+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@
M:7,@<F5Q=65S=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N(&9R;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N
M(%!L96%S92!C;&EC:R`E<R!T;R!S96YD('1H92!N;W1I9FEC871I;VX@;65S
M<V%G92X`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<V5R=F5R('=A<R!N;W0@
M86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92X`5&AE
M('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N`%1H92!S:6=N871U
M<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"X`5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(&9I
M;&4@9&]E<R!N;W0@97AI<W0N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+@!4:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B965N(&%D9&5D+@!4
M:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S=&%T
M:6]N97)Y("(E<R(@:&%S(&)E96X@=7!D871E9"X`5&AE('1A<VL@:&%S(&)E
M96X@861D960@=&\@>6]U<B!T87-K;&ES="X`5&AE('1E;7!O<F%R>2!F:6QE
M("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT(&]F('1H92!M97-S86=E
M`%1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H
M92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E`%1H92!T97AT(&]F('1H
M92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT
M(&]F('1H92!S96YT(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE('-E;G0@;65S
M<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!U
M<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S
M=&]R960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@
M;F\@86QT97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92X`5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@
M<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N`%1H97)E(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D
M(&EN;&EN92X`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T
M:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A
M=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@
M82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S
M86ED.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O
M;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B
M)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!C
M;W!Y:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S
M86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E
M('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R
M("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN
M(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E
M('=A<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O;2`B)7,B('1O("(E
M<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N`%1H97)E
M('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z
M("5S+@!4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R=`!4
M:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+@!4
M:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!"
M;&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92!T:&ES.B``5&AI<R!)34%0('-E
M<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!0
M1U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N`%1H
M:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO
M="!Y970@:6UP;&5M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P
M.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M
M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U
M9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE
M;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I
M;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C
M=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A
M8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T
M(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E
M<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O
M8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E
M;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W
M87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@
M<&QE87-E('9I<VET("5S`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G92!C
M;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+@!4:&ES(&UE<W-A9V4@8V]N=&%I
M;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N
M960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C
M:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI
M<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R
M;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B!T:&ES(&UE<W-A9V4@:7,@=6YK
M;F]W;BX`5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z(`!4:&ES(&UE<W-A
M9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F
M;W)M870@*&%C8V]R9&EN9R!T;R!21D,@,C`Q-2DN`%1H:7,@;65S<V%G92!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O
M<FUA="X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@
M=FEA(%!'4"X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N
M960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E
M9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D
M('=I=&@@4$=0+@!4:&ES(&UE<W-A9V4@=&\`5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`
M5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N`%1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AR96%D(%9I97<`
M5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O
M;'1I<"DZ`%1O`%1O($%D9')E<W,`5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!W:&EL92!C;&EC:VEN9RX`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2!W:&EL92!C;&EC:VEN9RX`5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO
M=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C`N-B!O<B!H
M:6=H97(N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`
M5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5&]T86P@071T
M86-H;65N=',@4VEZ93H`5')A;G-L871I;VYS`%1R87-H(&9O;&1E<@!4<F%S
M:"!F;VQD97(Z`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4
M=0!4=6YI<VEA`%1U<FME>0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O
M<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E
M>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R
M97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T
M;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L
M92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O
M;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@
M)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D
M*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@
M9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$`56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F%N<W=E<F5D`%5N
M86YS=V5R960@;65S<V%G97,`56YD96QE=&4`56YD97)L:6YE`%5N9&ES8VQO
M<V5D(%)E8VEP:65N=',`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M(`!5;F9I;&5D`%5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI
M=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E
M<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@1&%T90!5;FMN;W=N($E-05`@<F5S
M<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B!397)V97(@4F5S<&]N9&5D.B`E<P!5
M;FMN;W=N($UE971I;F<`56YK;F]W;B!296-I<&EE;G0`56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N
M:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT`%5N;&]A9"!087-S<&AR87-E`%5N;F%M960`56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+@!5;G-E96X`56YS970@8V]L;W(`56YS=6)S8W)I8F4@9G)O
M;2!&;VQD97(H<RD`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E(')E<W!O;F1E;G0@<W1A='5S`%5P9&%T92!U<V5R`%5P
M9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`
M57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E($1E9F%U;'0@5F%L=64`57-E
M($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_`%5S92!34TP`57-E(%9I<G1U
M86P@5')A<V@@1F]L9&5R/P!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@(B5S(B!S=6-C97-S
M9G5L;'D@9VEV96X@=&AE('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD
M97(@(B5S(BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S
M97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T
M:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E
M<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE
M.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T
M;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B
M;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I
M;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E
M<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=P!6:65W("5S`%9I97<@
M)7,@4'5B;&EC($ME>0!6:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E
M('=I;F1O=P!6:65W($UE<W-A9V5S`%9I97<@4&5R<V]N86P@4')I=F%T92!+
M97D`5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y`%9I97<@5&AR96%D`%9I97<@
M5&AU;6)N86EL`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E
M<P!6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!C
M;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I97<@979E;G0`5FEE=R!M
M97-S86=E<R!I;B`E<P!6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E
M<B!L;V=I;CH`5FEE=R!T87-K`%9I97<@=&AE($EM86=E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7)T=6%L($9O
M;&1E<B`B)7,B(&-R96%T960@<W5C8V5S9G5L;'DN`%9I<G1U86P@1F]L9&5R
M(&1O97,@;F]T(&5X:7-T+@!6:7)T=6%L($9O;&1E<G,`5FER='5A;"!&;VQD
M97)S(')E<75I<F4@82!L86)E;"X`5FER='5A;"!)3D)/6`!6:7)T=6%L($E.
M0D]8($9O;&1E<@!6:7)T=6%L(%1R87-H`%9I<G1U86P@5')A<V@@1F]L9&5R
M`%9I<G1U86P@5')A<V@@1F]L9&5R(&1O97,@;F]T(&5X:7-T+@!6:7)T=6%L
M(&9O;&1E<B!L86)E;`!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&
M=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T
M82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY
M`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N(%-A
M:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R
M(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H870@<VAO=6QD('=E(&1O('=I
M=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M(&]R(&EN;F]C96YT/P!7:&5N(&1E;&5T:6YG(&UE<W-A9V5S
M+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M
M87)K:6YG('1H96T@87,@9&5L971E9#\`5VAE;B!O<&5N:6YG(&$@;F5W(&UA
M:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_`%=H
M96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD('=E('-A=F4@871T86-H;65N
M="!D871A/P!7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S
M<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD('1O('5N<75A;&EF
M:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@(D`B*3\`
M5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E
M;&ES=`!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI
M`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0
M:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP
M96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A
M9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`
M665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&%B;W5T('1O(&9E=&-H
M(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O=6YT*',I.@!9;W4@87)E
M(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@
M:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN`%EO=2!A<F4@871T96UP=&EN
M9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN`%EO=2!A<F4@
M8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+@!9;W4@87)E(&-R96%T
M:6YG(&$@<W5B+69O;&1E<B!T;R``66]U(&%R92!C<F5A=&EN9R!A('1O<"UL
M979E;"!F;VQD97(N`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!F;VQD97)S+@!9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L9&5R<RX`
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&%R92!R96YA;6EN9R!T
M:&4@9F]L9&5R.B``66]U(&-A;B!U<V4@=&AE(&9O;&QO=VEN9R!P;&%C96AO
M;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X=#H@)6,@9F]R('1H92!C=7)R
M96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R('1H92!S:6=N871U<F4N`%EO
M=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@
M;F%M92X`66]U(&-A;FYO="!U;G-U8G-C<FEB92!F<F]M("(E<R(N`%EO=2!D
M:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N
M="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@=&\@;&]G:6XN`%EO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E
M<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<@!9;W4@
M9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN
M9R!R96-I<&EE;G1S.B`E<RX`66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+@!9
M;W4@:&%V92`Q(&YE=R!M97-S86=E+@!9;W4@:&%V92!A;')E861Y('-U8FUI
M='1E9"!T:&ES('!A9V4N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z`%EO=2!H
M879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SH`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@
M870@;&5A<W0@;VYE(')E8VEP:65N="X`66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T(&5N=&5R('1H
M92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W
M('1H:7,@;65S<V%G90!9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F
M;W(@>6]U<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A
M9V4`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO
M=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N`%EO=2!M
M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE8W0@
M86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A="!L
M96%S="!O;F4@;65S<V%G92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E
M8VEP:65N="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R
M(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P
M96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A
M(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!H879E("(E<R(@96YA
M8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N`%EO=2!N965D('1O
M('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U(')E9&ER96-T
M960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RX`66]U(')E<&QI960@=&\@
M=&AI<R!M97-S86=E(&]N("5S+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T
M;R`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E
M(&YO="!U;G-U8G-C<FEB960@9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%EO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D
M('1O("(E<R(`66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F
M<F]M("(E<R(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!01U`@4'5B;&EC+U!R:79A=&4@
M2V5Y<P!9;W5R(%!R:79A=&4@2V5Y`%EO=7(@4'5B;&EC($ME>0!9;W5R(%)E
M<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^`%EO=7(@4R]-
M24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<P!9;W5R(&%C8V]U;G1S
M.@!9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@
M96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3X`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC
M871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@
M='EP92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT
M(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`
M66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&-H87)S970@
M9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO=7(@9&5F875L="!E;F-R>7!T:6]N
M(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&ED
M96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET
M>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&EN:V5D(&%T=&%C:&UE;G0@:&%S
M(&)E96X@9&]W;FQO861E9"!B>2!A="!L96%S="!O;F4@=7-E<BX*"D%T=&%C
M:&UE;G0@;F%M93H@)7,*071T86-H;65N="!D871E.B`E<PH*0VQI8VL@;VX@
M=&AE(&9O;&QO=VEN9R!L:6YK('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&4@
M871T86-H;65N=#H*)7,`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!M
M97-S86=E('=A<R!S=6-C97-S9G5L;'D@9&5L:79E<F5D+@!9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W
M;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S
M97)V97)S.@!9;W5R('-I9VYA='5R93H`675G;W-L879I80!:86ER90!:86UB
M:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@061D<F5S<V5S70!;2&ED92!1=6]T
M960@5&5X=%T`6TYO(%-U8FIE8W1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M061D<F5S<V5S("T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S70!;4VAO=R!A9&1R97-S97,@+2`E<R!R96-I<&EE
M;G1S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]"8V,`7T)L
M86-K;&ES=`!?0TQ)`%]#8P!?1&%T851R964`7T1E;&5T90!?1&5L971E(%)O
M=P!?1F]L9&5R<P!?1W)O=7!S`%](96QP`%])9&5N=&ET>0!?26UA9V4@4')O
M<&5R=&EE<RXN+@!?26YB;W@`7TQO9R!I;@!?3&]G(&]U=`!?365S<V%G92!3
M;W5R8V4`7TUO9&EF>2!,:6YK+BXN`%].97<@365S<V%G90!?3W!T:6]N<P!?
M4&5R;6ES<VEO;G,`7U!R:6YT`%]0<FEO<FET>0!?4F5F<F5S:"`E<P!?4F5M
M;W9E($QI;FLN+BX`7U)E<&QY`%]396%R8V@`7U-E;F0@365S<V%G90!?4V5T
M=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U1H<F5A9`!?5&\`7U5N9&5L971E
M`%]5<V5R<P!?5FEE=R!4:')E860`7U=H:71E;&ES=`!A9&1R97-S(&)O;VL`
M861D<F5S<V5E('5N:VYO=VX`871T86-H;65N=`!A='1A8VAM96YT<RYZ:7``
M8GET97,`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE
M`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S
M86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M
M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E;G1R>2!N;W0@9F]U
M;F0`9F%L;&EN9P!F:6QE`&9R;VT`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I
M;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R
M<F]R`&ME>0!L:6YE<UT`;6%I;&)O>"!F:6QE`&UK:7-O9G,@97)R;W(@8V]D
M92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO;F4`;F]T(&EM<&QE
M;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT
M`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96-I<&EE;G1S70!R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`
M<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W!E;&QI;F<@
M97)R;W(`<W!E;&QI;F<@97)R;W)S`'-S`'-T96%D>0!S>7-T96T@97)R;W(`
M=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D
M('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T
M`'9#87)D`'<Z`'=E871H97(N8V]M`'EO=7(@8FQA8VML:7-T`'EO=7(@=VAI
M=&5L:7-T`%!R;VIE8W0M260M5F5R<VEO;CH@24U0(#0N,0I297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM
M1&%T93H@,C`P-BTP,2TP-B`R,CHP,"LP,3`P"E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#8M,#$M,S`@,C$Z,C8K,#$P,`I,87-T+51R86YS;&%T;W(Z($EV86X@
M3F]R:7,@/'9I>$!V87IK82YS:SX*3&%N9W5A9V4M5&5A;3H@4VQO=F%K(#QV
M:7A`=F%Z:V$N<VL^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z("`X+6)I=`H`("`@2_-P:6$Z(``@("`@("`@4')E.B``
M("`@("!$X71U;3H@`"`@("`@("`@3V0Z(``@*'!R960@)7,@9/)A;6DI`"`H
M2VSA=F5S;W;A('-K<F%T:V$@)7,I`"`H;R`E<R!D;NTI`"AD;F5S*0`@*'IA
M:G1R82D`("AVZ&5R82D`("`@4')E9&UE=#H@`"!R_6-H;&]SNR``('8@`"(E
M<R(@;FEE(&IE(&%D<F5SX7(N`"(E<R(@;FEE(&IE('!L871NX2!V;[5B82X`
M(B5S(B!N:64@:F4@;F%K;VYF:6=U<F]V86[I('8@<F5G:7-T<FD@2&]R9&4N
M`'IO8G)A>F]V8>@@<W1R;VUU("(E<R(@;F5B;VP@;N%J9&5N_2X`4VMU<&EN
M82`B)7,B(&)O;&$@<')I9&%NX2!D;R!S>7-TZ6UU+@!0<N%V;R`B)7,B(&)O
M;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+@`B)7,B(&YE8F]L;R!M;[YNZ2!V>71V
M;W)INSH@)7,N`",`)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0!0;W6^:73]
M8V@@)2XR9DU"('H@9&]V;VQE;OUC:"`E+C)F34(@*"4N,F8E)2D`)60@)7,@
M82`E<P`E9"!S<'+A=@`E9"!D;NT@9&\@=GEP<KEA;FEA('!L871N;W-T:2!6
MX;EH;R!H97-L82X`4W!RX79Y("@E9"D@8F]L:2!V>6UA>F%NZ2X`4W!RX79Y
M("@E9"D@8F]L:2!O:&SA<V5NZ2!6X;EM=2!S<'+A=F-O=FD@86MO(&)EOF[A
M("AN:64@;F5V>;YI861A;N$I('!ON71A+@!3<'+A=GD@*"5D*2!B;VQI(&]H
M;.%S96[I(&%K;R!B9;YNX2`H;FEE(&YE=GF^:6%D86[A*2!P;[ET82X`4W!R
MX79Y("@E9"D@8F]L:2!O>FYAZ&5NZ2!Z82!N979YOFEA9&%N^B!P;[ET=2`H
M4U!!32D@82!Z87-L86[I(%;AN6UU('-P<N%V8V]V:2X`4W!RX79Y("@E9"D@
M8F]L:2!O>FYAZ&5NZ2!Z82!N979YOFEA9&%N^B!P;[ET=2`H4U!!32DN`%-P
M<N%V>2`E9"!AOB`E9"!Z("5D('-P<N%V`'!R961P;W9E[R!N82`E9"!D;NT`
M)7,@+2!0;WINX6UK80!/9'1L8>AO:R`E<P`E<R!+0@!/<&5RX6-I92#Z9'*^
M8GD@<')E(&%P;&EKX6-I=2`E<R`M(%!O='9R9&5N:64`3F%S=&%V96YI92`E
M<P!296=I<W1R;W9A;FEE(&1O(&%P;&EKX6-I92`E<P!0;V1M:65N:WD@<&]U
MOFET:6$@)7,`)7,@=;X@97AI<W1U:F4N`"5S('6^(&5X:7-T=6IE+B!6X;D@
M<')I9>AI;F]K("5S(&YE8F]L('!R96UE;F]V86[]+@`E<R!V;R!V_;EK92`E
M<R`E<P`E<R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;N$@<V-H<N%N:V$N
M`%!R:67H:6YO:R`E<R!B=61E('!R96UE;F]V86[](&YA('IAZ&EA=&MU(&UE
M<VEA8V$N`"5S(&%K8V5P=&]V86PN`"5S('IR=;EI;"`B)7,B+@`E<R!O9&UI
M971O;"X`)7,@;V1P;W9E9&%L*&$I(&YA('!OOFEA9&%V:W4@>FESNV]V86YI
M82!Z86YE<'+A>F1N96YO<W1I+@`E<R!O9'!O=F5D86P@;F$@<&]Z=F%N:64@
M;F$@(B5S(BX`)7,@5N%M('!O<VQA;"!I;F9O<FWA8VEU(&\@>F%N97!RX7ID
M;F5N;W-T:2X`)7,@<')E9&)EOFYE(&%K8V5P=&]V86PN`$%P;&EKX6-I82`E
M<R!J92!P<FEP<F%V96[A(&YA('9Y:V]N86YI92!O<&5RX6-I[2#Z9'*^8GDN
M3WIN8>AT92"Y='9O<NAE:R!P<FD@;W!E<N%C:>%C:"P@:W1O<ND@8VAC971E
M('9Y:V]N8;L@=&5R87HN`%!OOF%D=6IE('-A("5S`"5S(&UI;OIT`"5S(&YE
M8F]L(&[A:F1E;OTN`"5S('!OOF%D=6IE(&EN9F]R;>%C:74@;R!68;EE:B!Z
M86YE<'+A>F1N96YO<W1I+@`E<R!V>;YA9'5J92!68;EU('!R[71O;6YO<[L@
M;F$@(B5S(BX`)7,@8;X@)7,@>B`E<P!0<FED86YI92`E<R!D;R`B)7,B(&)O
M;&\@^G-P9;ENZ2X`)7,@8GD@<N%D('5P<F%V:6P@(B5S(BX`)7,@8GD@5N%S
M('+A9"!U<&]Z;W)N:6P@;F$@(B5S(BX`)7,@8GD@<N%D(&1O<W1A;"!N86IN
M;W:Y:64@:6YF;W)MX6-I92!O("(E<R(N`$%D<F5SX7(@<&]UONUV871EM6$@
M)7,`2V%L96YDX7(@<&]UONUV871EM6$@)7,`4&]Z;N%M:WD@<&]UONUV871E
MM6$@)7,`6F]Z;F%M(/IL;V@@<&]UONUV871EM6$@)7,`)7,Z("5S`"5S.B`E
M<R`H)60F;F)S<#MZ)FYB<W`[)60I`"5S.B!4X71O('-P<N%V82!N96UU<^T@
M8GF[(&]D(&]D;W-I96QA=&6U82P@:W1O<OT@<V$@>F]B<F%Z=6IE(&%K;R!O
M9&]S:65L871EM2!S<'+A=GDN(%IA8VAO=F%J=&4@;W!A=')N;W.[('!R:2!K
M;&EK86[M(&YA(&QI;FMY('8@<W!RX79E(&%L96)O('!O<VMY=&]V86[M(&]S
M;V)N_6-H(&EN9F]R;>%C:>T@;V1O<VEE;&%T9;5O=FDN`"A0;W1V<F1INR!T
M:65T;R!Z;65N>2!A('!O:W)AZ&]V8;L@;F%S;&5D=6KZ8V]U(&]B<F%Z;W9K
M;W4N*0`H6G)UN6F[(':Y971K>2!Z;65N>2!A('9RX71INR!S82!K('#M<V%N
M:74@<W!RX79Y+BD`*$A434PI`"A)8F$@=&5X="D`*$[A=G)A="!K('#M<V%N
M:74@<W!RX79Y('!O(&%P;&EK;W9A;NT@=KEE=&O]8V@@9&]T97)A:KGM8V@@
M>FUI96XN(%IM96YY(&YA(&%K='7A;&YE:B!O8G)A>F]V:V4@3D5"543:(&%P
M;&EK;W9A;NDN*0`H3V1O<VQANR!S<'+A=G4@<&\@87!L:6MO=F%N[2!VN65T
M:_UC:"!D;W1E<F%JN>UC:"!Z;6EE;BX@6FUE;GD@;F$@86MT=>%L;F5J(&]B
M<F%Z;W9K92!.14)51-H@87!L:6MO=F%NZ2XI`"H@4')I9&%J=&4@:VQI:VYU
M=.UM(&YA($]+("H`*B!0<F]S[6T@=GEB97)T92!A9')E<W4H>2D@*@`L(&[A
M<F%Z;W;](``L('8@;N%R87IO8V@@)7,@)7,`+"!P<F5M96YNX2!V(')O>G-A
M:'4@)7,@8;X@)7,`+2T@=GEB97)T92!S:2`M+0`Q('-P<N%V82!B;VQA('9Y
M;6%Z86[A+@`Q('-P<N%V82!B;VQA(&]H;.%S96[A(%;AN6UU('-Y<W3I;6]V
MZ6UU('-P<N%V8V]V:2!A:V\@;F]R;>%L;F$@*&YI92!N979YOFEA9&%NX2D@
M<&^Y=&$N`#$@<W!RX79A(&)O;&$@;VALX7-E;N$@86MO(&)EOF[A("AN:64@
M;F5V>;YI861A;N$I('!ON71A+@!*961N82!S<'+A=F$@8F]L82!O>FYAZ&5N
MX2!Z82!N979YOFEA9&%N^B!P;[ET=2`H4U!!32D@82!Z87-L86[A(%;AN6UU
M('-P<N%V8V]V:2X`2F5D;F$@<W!RX79A(&)O;&$@;WIN8>AE;N$@>F$@;F5V
M>;YI861A;OH@<&^Y='4@*%-004TI+@`Q,#`@>FYA:V]V`#$P,#`@>FYA:V]V
M`#$R+6AO9&EN;W;](&9O<FWA=``R-"UH;V1I;F]V_2!F;W)MX70`,C0@:&]D
M[6X`,C4P('IN86MO=@`U,#`@>FYA:V]V`#Q0<F5D8VCA9'IA:OIC80!0<F4@
M=&5N=&\@8FQO:R!J92!P;[YA9&]V86[](&1A=&%BX7IO=OT@8F%C:V5N9"X`
M5GES:WET;&$@<V$@>N%V8;YNX2!C:'EB80!+('1E:G1O('-P<N%V92!J92!P
M<FEP;VIE;OT@=F6U:_T@;V)RX7IO:R!P;VUE;F]V86[]("5S+@!3<'+A=F$L
M(&MT;W+Z('-T92!P;W-L86QI+"!S</1S;V)I;&$@>F%S;&%N:64@<&]T=G)D
M96YI82!O9"!P<NUJ96UC=2X`3F$@>F&Y:69R;W9A;FEE('-P<N%V>2!J92!P
M;[YA9&]V86[]('9E<F5J;OT@4$A0(&NU^N@N`$YA(&]V97)E;FEE('!O9'#M
M<V%N96H@<W!RX79Y(&IE('!OOF%D;W9A;OT@=F5R96IN_2!01U`@:[7ZZ"X`
M3F$@9&6Y:69R;W9A;FEE('-P<N%V>2!S^B!P;W1R96)NZ3H@=F5R96IN_2!0
M1U`@:[7ZZ"P@<')I=N%T;GD@4$=0(&NU^N@@82!H97-L;RX`3F$@<&]D<.US
M86YI92!S<'+A=GD@<_H@<&^^861O=F%NZ3H@=G)E:F[](%!'4"!KM?KH+"!P
M<FEVX71N>2!01U`@:[7ZZ"!A(&AE<VQO+@!.82!D9;EI9G)O=F%N:64@<W!R
MX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU^N@L('!R:7;A
M=&YY(%,O34E-12!KM?KH(&$@:&5S;&\N`$YA('!O9'#M<V%N:64@<W!RX79Y
M('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU^N@L('!R:7;A=&YY
M(%,O34E-12!KM?KH(&$@:&5S;&\N`$YA('IAN6EF<F]V86YI92!S<'+A=GD@
M:F4@<&^^861O=F%N_2!V97)E:F[](%--24U%(&NU^N@N`%!R961P;VQU9&[M
M;2!O8FQAZ&YO`%!R961P;VQU9&[M;2"U86AK_2!DX;[O`%!R961P;VQU9&[M
M;2!DX;[O`%!R961P;VQU9&[M;2!P<F5HX6YK>0!0<F5D<&]L=61N[6T@<VYE
M:&]VZ2!P<F5HX6YK>0`Q,B!H;V3M;@!!(%K!4D]61=(`05!)($E$`$\@=&]M
M=&\@961I=&]R90!/+BXN`$%B<V]L^G1N>2!S<&]D;VL`06)S;VSZ=&YY('-T
M<F5D`%!R:6IANR!A('!R:61ANR!D;R!M]&IH;R!K86QE;F3A<F$`4')I:F&[
M('!OOFEA9&%V:W4`4')I:F%TX0!0<FEJ873A.B``4')I('9Y=';A<F%N[2!6
M1E,@861R97/A<F$@8F]L('IA;6EE=&YU=/T@<'+M<W1U<"X`4')I('9Y=';A
M<F%N[2!61E,@<_IB;W)U(&)O;"!Z86UI971N=73]('!R[7-T=7`N`$EN9F]R
M;>%C:64@;R#ZZ'1E`$AE<VQO('!R92#ZZ&5T`-KH970@>F%B;&]K;W9A;OTN
M`$[A>F]V(/KH='4Z`-KH=&]V86YI90!!:V-I90!0<FED8;L`4')I9&&[("5S
M(&1O(&WT:FAO(&%D<F5SX7)A`%!R:61ANR!P;V1R:6%D96[Z('-K=7!I;G4`
M4')I9&&[('!O9')I861E;ND@<'+A=F\`4')I9&&[.@!0<FED8;L@<VMU<&EN
M=0!0<FED8;L@;F]VZ2!P<N%V;P!0<FED8;L@9&/I<G-K=2!S:W5P:6YU(&1O
M("(E<R(`4')I9&&[(&1CZ7)S:V4@<'+A=F\@9&\@(B5S(@!0<FED8;L@<&]U
MONUV871EM6$Z`%!R:61ANR!S=.5P96,`4')I9&&[(.AL96YO=@!0<FED8;L@
M<.%R`%!R:61ANR!Z9')O:@!0<FED8;L@;65N=2`E<R!A:V\@0F_H;OT@<&%N
M96P@36]Z:6QL>0!0<FED8;L@9&\@;?1J:&\@:V%L96YDX7)A`%!R:61ANR!D
M;R!A9')E<^%R83H`4')I9&&[(&1O(&WT:FAO(&%D<F5SX7)A`%!R:61ANR!D
M;R!M]&IH;R!K86QE;F3A<F$`4')I9&&[('!O=;[M=F%T9;5A`%!R[6QO:&$@
M(B5S(B!B;VQA('!R:7!O:F5NX0`B)7,B(&)O;"!P<FED86[](&1O('-Y<W3I
M;74L(&%L92!N96UOOFYO('!R:61ANR#O86RY:64@<')I:&QA<V]V86-I92!I
M;F9O<FWA8VEE.B`E<RX`(B5S(B!B;VP@<')I9&%N_2!D;R!S>7-TZ6UU+B!4
M97)A>B!S82!M]+YE=&4@<')I:&SA<VF[+@!0<FEDX79A;FEE('!O=;[M=F%T
M9;5O=B!J92!Z86OA>F%NZ2X`SV%LN6EE(&AL879IZ&MY('IO8G)A>F]V86[I
M('!R:2!P<F5Z97)A;NTZ(#QE;3XH=F]L:71EM6[I+"!Z861A:G1E(&MAOF3Z
M(&AL879IZ&MU(&YA(&YO=F]M(')I861K=2D\+V5M/@#/86RY:64@:6YF;W)M
MX6-I92!M]+YU(&)YNR!Z;V)R87IE;ND@)7,N`,]A;+EI92!P;V1R;V)N;W-T
M:0#/86RY:64@9&5T86EL>2!S<'+A=GD`SV%LN6EE(&1E=&%I;'D@<W!RX79Y
M(&WTOG4@8GF[('IO8G)A>F5NZ2`E<RX`SV%LN6EE(&1E=&%I;'D@8VAY8F]V
M96H@<W!RX79Y`,]A;+EI92!D971A:6QY(&-H>6)O=F5J('-P<N%V>2!M]+YU
M(&)YNR!Z;V)R87IE;ND@)7,N`$%D<F5S80!!9')E<^%R`$%D<F5SX7)E`$%D
M<F5S>2P@;F$@:W1O<ND@<V$@;6%J^B!P;W-I96QANR!S:W)Y=.D@:_-P:64@
M*$)#0RD@=KEE=&O]8V@@<W!RX78Z(#QE;3XH=F]L:71EM6[I+"!Z861A:G1E
M(&MAOF3Z(&%D<F5S=2!N82!N;W9O;2!R:6%D:W4I/"]E;3X`061R97-Y+"!K
M=&]RZ2!S82!M86KZ(&5X<&QI8VET;F4@>G9I87IANR!S('1O=71O(&ED96YT
M:71O=3H@/&5M/BAV;VQI=&6U;NDL('IA9&%J=&4@:V&^9/H@861R97-U(&YA
M(&YO=F]M(')I861K=2D\+V5M/@!!9&UI;FES='+A8VEA("T@;F%S=&%V96YI
M92!P<N%V('!R92!I;OUC:"!P;W6^[79A=&6U;W8`061M:6YI<W1RX6-I80!2
M96ML86UY`$%F9V%N:7-T86X`06QBX6YS:V\`06R^[7)S:V\`06QI87,`6F%R
M;W9N8;L`6F%R;W9N86YI93H`5KEE=&MY`%:Y971C:2!A=71E;G1I9FEK;W9A
M;NT@<&]UONUV871E;&EA`%:Y971K>2!S:W5P:6YY`%:Y971K>2!P<N%V80!6
MN65T:WD@N71Y<FD@<W1R86YY`%:Y971K>2!S<'+A=GD@=B!N87-L961U:OIC
M:6-H('!R:67H:6YK;V-H('-A('-T:6%H;G4@9&\@:F5D;NEH;R!S^F)O<G4@
M34)/6#H`5KEE=&MY('-P<N%V>2!V;R!68;EO;2!P<FEEZ&EN:W4@(B5S(B!S
M=&%RN6EE(&%K;R`E<R!D;NT@8G5D^B!T<G9A;&4@=GEM87IA;NDN`%:Y971K
M>2!S=&%RZ2!N86QI;FMO=F%NZ2!P<NUL;VAY('-T87*Y:64@86MO("5S(&UE
M<VEA8V]V(&)U9/H@=GEM87IA;NDN`%:Y971K>2!P<FEEZ&EN:WD@;V1O<VQA
M;F5J('!ON71Y('-T87*Y:64@86MO("5S(&UE<VEA8V]V(&)U9/H@=GEM87IA
M;NDN`%:Y971K>2!P<N%V82!P<F4@<')I9>AI;F]K("(E<R(@<&QA=&[I('!R
M92!P;W6^[79A=&6U82`B)7,B(&)O;&D@^G-P9;EN92!O9'-T<N%N96[I+@!0
M;W9O;&F[('9Y=';A<F%N:64@<')I9>AI;FMO=C\`4&]V;VQINR!A<&QI:V]V
M86YI92!F:6QT<F]V86/M8V@@<')A=FED:65L(&YA(+5U8F]V;[5N^B!S8VAR
MX6YK=3\`4&]V;VQINR!V:6%C97+I(&%D<F5S>0!0;W9O;&F[(&YA<W1A=F5N
M:64@='EP=2!Z;W)A9&5NZ6AO('IO>FYA;74_`%6^(&5X:7-T=6IE`$%L=&5R
M;F%T[79N92!P<FEH;&%S;W9A8VEE(&UE;F\@24U34`!!;'1E<FYA=.UV;F4@
M:&5S;&\@24U34`!!;'1E<FYA=.UV;F4@<&]UONUV871EM7-KZ2!M96YO($E-
M4U``06QT97)N873M=FYA(&4M;6%I;&]VX2!A9')E<V$`06QT97)N873M=FYE
M(+EA8FSS;GD`06QT97)N873M=FYY('1E>'0Z`$%L=&5R;F%T[79N92#H87-T
M:2!P<F4@=/IT;R!S96MC:74Z`%:^9'D`5KYD>2!U:VQA9&&[('!R[6QO:'D`
M06UE<FEC:^$@4V%M;V$`4')I('!O:W5S92!O(&]D<W1RX6YE;FEE('!R[6QO
M:'D@;F%S=&%L82!C:'EB82X@24U!4"!S97)V97(Z`$)O;&$@>F%D86[A(&YE
M<&QA=&[A(&AO9&YO=&$`3F%S=&%L82!N97INX6UA(&-H>6)A+@!0<FD@=GET
M=N%R86[M(&YO=F5J('!O>F[A;6MY('-A('9Y<VMY=&QA(&YE>F[A;6$@8VAY
M8F$N`%!R:2!V>71VX7)A;NT@;F]V96H@^FQO:'D@<V$@=GES:WET;&$@;F5Z
M;N%M82!C:'EB82X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;ND@
M<')O>'D`3V1P;W9E[P!:;V1P;W9E9&%NZ0!:;V1P;W9E9&%NZ2!S<'+A=GD`
M06YT87)K=&EK80!!;G1I9W5A(&$@0F%R8G5D80!!<&QI:^%C:6$`6F]Z;F%M
M(&%P;&EKX6-I[0!!<&QI:^%C:6$@:F4@<')I<')A=F5NX2X`07!L:6MO=F&[
M(&9I;'1R90!!<&QI:V]V8;L@9FEL=')E(&YA("5S`$%P;&EK;W9ANR!F:6QT
M<F]V86-I92!P<F%V:61LX2!P<FD@<')I:&SA<V5N[3\`07!L:6MO=F&[(&9I
M;'1R;W9A8VEE('!R879I9&SA('!R:2!O8FYO=F5N[2!Z;V)R87IE;FEA('-C
M:'+A;FMY('!R:6IA=/UC:"!S<'+A=C\`07!L:6MO=F&[(&YA('!O9')I861E
M;ND@>F1I9;5A;ND@<')I9>AI;FMY`%-C:';A;&F[`%!R:6)L:;YNX2!V9;5K
M;W.[`$%P<NUL`%9EM6MO<[L@87)C:.UV=0!-96YO(&%R8VCM=G4`3F%O>F%J
M(&-H8V5T92!V>6UA>F&[('3Z=&\@9&5F:6[M8VEU('9I<G1UX6QN96AO('!R
M:67H:6YK83\`3F%O>F%J(&-H8V5T92!V>6UA>F&[('1E;G1O('9E<F5J;OT@
M:[7ZZ#\`3F%O>F%J(&-H8V5T92!V>6UA>F&[('1E;G1O(%;AN2!KM?KH;W;]
M('#A<C\@*$YE;V1P;W+ZZ&%M92$I`$YA;WIA:B!T;R!C:&-E=&4@=7)O8FF[
M/P!.86]Z86H@8VAC971E('9Y;6%Z8;L@OFEA9&]SNR!O('!R:6ALX7-E;FEE
M("<E<R<_`%5RZ&ET92!C:&-E=&4@3D%44E9!3$\@=GEM87IANR!T:65T;R!S
M<'+A=GD_`%5RZ&ET92!C:&-E=&4@3D%44E9!3$\@=GEM87IANR!T^G1O('!R
M[6QO:'4_`$YA;WIA:B!C:&-E=&4@=GEM87IANR`B)7,B(&$@=KEE=&MY('!O
M9'-K=7!I;GD_`%5RZ&ET92!C:&-E=&4@=GEP<N%Z9&YINR!T96YT;R!P<FEE
MZ&EN;VL_`%5RZ&ET92!C:&-E=&4@=GEP<N%Z9&YINR!P<FEEZ&EN;VL@<V\@
M<W!A;6]M/P!5<NAI=&4@8VAC971E('9Y<'+A>F1N:;L@5N&Y($OTN3\`57+H
M:71E(&-H8V5T92!V>6UA>F&[('1I971O('-P<N%V>2`_`%5RZ&ET92!C:&-E
M=&4@;VALX7-INR!T^G1O('-P<N%V=2!A:V\@;F6Y:V]D;OH_`%5RZ&ET92!C
M:&-E=&4@;VALX7-INR!T^G1O('-P<N%V=2!A:V\@;F5V>;YI861A;OH@<&^Y
M='4@*'-P86TI/P!!<F=E;G3M;F$`07)MZ6YS:V\`R&%S(&1O<G7H96YI80!5
M;65N:64`07)U8F$`5GIO<W1U<&YE`$]S=')O=B!!<V-E;G-I;VX`07-C:6D@
M=6UE;FEE`,%Z:6$O4&%C:69I8VO](')E9VGS;@!3</UT8;L@<V$`5GF^861O
M=F&[('!O='9R9&5N:64@<')E9"!V>6MO;F%N[6T@;W!E<N%C:>T@^F1ROF)Y
M/P!0<FEP;VIINR!S^F)O<GD`5FQOOFF[(%;AN2!V97)E:F[](&NU^N@@9&\@
M<W!RX79Y/P!0<FEP;VIE;OT@<_IB;W(Z`%!R:7!O:F5N_2!S^F)O<B`B)7,B
M('!R96MR8>AU:F4@;&EM:70@;F$@=F6U:V]SNR!P<NUL;VAY+B!3^F)O<B!.
M14)/3"!P<FEP;VIE;OTN`%8@<'+M;&]H92!J92!O9'!O=F7O(&YA(%9AN74@
M:V%L96YDX7)O=OH@<&^^:6%D879K=2X`4'+M;&]H80!0<NUL;VAA("5S(&)O
M;&$@=GEM87IA;N$N`%!R[6QO:&$@8F]L82!O9'-T<N%N96[A.B!P]'9O9&[]
M('1Y<"!P<NUL;VAY`%!R[6QO:'D`4&]K=7,@;R!V>6UA>F%N:64@;F5E>&ES
M='5J^F-E:B!S:W5P:6YY+@!0;VMU<R!O('9Y;6%Z86YI92!N965X:7-T=6KZ
M8V5H;R!P<N%V82X`4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J^F-E:&\@<'+A
M=F$N`%!O:W5S(&\@^G!R879U(&YE97AI<W1U:OIC96AO('ID:66U86[I:&\@
M;V)J96MT=2X`VNAA<W1N[6-I`%!O>F]R`$%T<FEB^G1Y`$%U9W5S=`!!=7-T
M<N%L:6$`4F%K^G-K;P!!=71H7V-Y<G-Q;#H@4&^^861O=F%NZ2!R;WJY[7)E
M;FEE(&EM87`@;F5B;VQO(&[A:F1E;NDN`$%U=&A?8WER=7,Z(&)A8VME;F0@
M;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN`$%U=&A?8WER=7,Z('!OOF%D
M;W9A;ND@<F]ZN>UR96YI92!I;6%P(&YE8F]L;R!NX6ID96[I+@!!=71H7V9T
M<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($944"!N96)O;&\@;N%J9&5NZ2X@
M4VMO;7!I;'5J=&4@4$A0(',@<')E<.UN8>AO;2`M+65N86)L92UF='`N`$%U
M=&A?:6UA<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($E-05`@;F5B;VQO(&[A
M:F1E;NDN`$%U=&A?:6UP.B!P;[YA9&]V86[I(')O>KGM<F5N:64@24U!4"!N
M96)O;&\@;N%J9&5NZ2X`075T:%]K<F(U.B!P;[YA9&]V86[I(')O>KGM<F5N
M:64@:W)B-2!N96)O;&\@;N%J9&5NZ2X`075T:%]L9&%P.B!P<FEDX79A;FEE
M('!O=;[M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;ND@<')E($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!V>6UA>N%V86YI92!P;W6^[79A=&6U;W8@
M;FEE(&IE('!O9'!O<F]V86[I('!R92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($Q$05`@;F5B;VQO(&[A:F1E
M;NDN`$%U=&A?;&1A<#H@3F5P;V1A<FEL;R!S82!P<FED8;L@<&]UONUV871E
MM6$@)7,N(%-E<G9E<B!O9'!O=F5D86PZ(`!!=71H7VQD87`Z(&YE<&]D87)I
M;&\@<V$@;V1S='+A;FF[('!O=;[M=F%T9;5A("5S`$%U=&A?;&1A<#H@;F5P
M;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@<&]UONUV871EM6$@)7,`075T:%]L
M9&%P.B!A:W1U86QI>N%C:6$@<&]UONUV871EM6]V(&YI92!J92!P;V1P;W)O
M=F%NX2!P<F4@06-T:79E($1I<F5C=&]R>0!!=71H7VUC86PZ('!OOF%D;W9A
M;ND@<F]ZN>UR96YI92!-0T%,(&YE8F]L;R!NX6ID96[I+@!!=71H7W-M8F%U
M=&@Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!S;6)A=71H(&YE8F]L;R!NX6ID
M96[I+@!!=71E;G1I9FEKX6-I82!P;VUO8V]U($E-05`@<V5R=F5R82!Z;'EH
M86QA+@!!=71E;G1I9FEKX6-I82!Z;'EH86QA`$%U=&5N=&EF:6OA8VEA('IL
M>6AA;&$N("5S`%-E<G9E<B!2041)55,@>F%M:65T;VP@875T96YT:69I:^%C
M:74N`$%U=&5N=&EF:6OA8VEA('!O;6]C;W4@1E10('-E<G9E<F$@>FQY:&%L
M82X`075T96YT:69I:^%C:6$@<&]M;V-O=2!334(@<V5R=F5R82!Z;'EH86QA
M+@!:;V)R87IINR!O8G+A>FMY('8@2%1-3"!S<'+A=F%C:"P@86L@:F4@;V1O
M<VEE;&%T9;4@=B!M;VIO;2!A9')E<^%R:3\`1&]S='5P;ND@861R97/A<F4Z
M`$1O<W1U<&[I('!O;&^^:WDZ`,AA:^$@<V$@;F$@;V1P;W9E[P!!>F5R8F%J
M9+YA;@!"3T9(($5X8W5S97,`7U-PY+L@;F$@)7,`4W#DNR!N82`E<P!3<.2[
M(&YA('IO8G)A>F5N:64@=FEA8V5R_6-H('-P<N%V`%!O>F%D:64`1F%R8F$@
M<&]Z861I80!:;.D@:&5S;&\@<')E(&ME<F)E<F]S+@!:;.D@<&]UONUV871E
MM7-KZ2!M96YO('!R92!K97)B97)O<RX`6FSA(&%L96)O('IL92!F;W)M=6QO
M=F%NX2!P;[YI861A=FMA+B!397)V97(@;V1P;W9E9&%L.B`E<P!"86AA;7D`
M0F%H<F%J;@!"86YG;&%DZ;D`0F%R8F%D;W,`4')I9>AI;F]K(',@9W)A9FEK
M;W4@(B5S(B!N96)O;"!NX6ID96[]+@!:X6ML861N_2!R:6%D;VL`0F-C`$)I
M96QO<G5S:V\`0F5L9VEC:V\`0F5L:7IE`$YIOKEI92!J92!P]'9O9&[]('1E
M>'0@<W!RX79Y(&\@<W1A=F4N`$)E;FEN`$)E<FUU9'D`0G5TX6X`3F%R;V1E
M;FEN>0#(:65R;F$@;&ES=&EN80!";&]K("(E<R(@87!L:6OA8VEE("(E<R(@
M;F5B;VP@;N%J9&5N_2X`3F%S=&%V96YI82!B;&]K=0!4>7`@8FQO:W4`6F%B
M;&]K;W9ANR!O8G+A>FMY('8@2%1-3"!S<'+A=F%C:"!AOB!D;R!E>'!L:6-I
M=&[I:&\@=GF^:6%D86YI83\`5&5L;P!4=>ANZ0!";VSM=FEA`%KA;&^^:WD`
M3VMR86H`J>UR:V$@;VMR86IA.@!/:W)A:F4`0F]S;F$@82!(97)C96=O=FEN
M80!/8F4`2&QA=FGH:WD@82!T96QO('-P<N%V>0!";W1S=V%N80!";W1T;VT`
M0F]U=F5T($ES;&%N9`!"<F%Z[6QI80!"<FET<VOI(/IZ96UI92!V($EN9&EC
M:V]M(&]C9>%N90!"<G5N96D@1&%R=7-S86QA;0!"=6QH87)S:V\`6F]Z;F%M
M(',@;V1RX;YK86UI`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`1&ES
M=')I8G7H;ND@8F]D>2!#4DP`5FQA<W1N;W-T:2!?8G5N:WDN+BX`6E]N86MO
M=N$@<V%D80!);F-I86QI>N%C:6$@=GER;W9NX79A8V5J('!A;>1T:2!N96)O
M;&$@9&]K;V[H96[A+@!+86QE;F3A<@!"97IV971R:64`2V%M8F]DOF$`2V%M
M97)U;@!.97!O9&%R:6QO('-A('-P;VIINR!S;R!V>F1I86QE;OUM(&UA:6QO
M=OUM('-E<G9E<F]M+@!.97!O9&%R:6QO('-A('-P;VIINR!S;R!V>F1I86QE
M;OUM(&UA:6QO=OUM('-E<G9E<F]M.B``3F5M;[YN;R!Z;V)R87IINR`M('8@
M=&5J=&\@<V-H<N%N:V4@:F4@:6)A('!R=OUC:"`E<R!Z("5S(.AA<W3M('-P
M<N%V>2X`3F5P;V1A<FEL;R!S82!A=71O;6%T:6-K>2!O8FYO=FF[(&AE<VQO
M+"!K;VYT86MT=6IT92!S=F]J:&\@861M:6YI<W1RX71O<F$N`$YE<&]D87)I
M;&\@<V$@>F%P[7-ANR!D;R!S^F)O<G4@(B5S(@!.96UOOFYO(&%D;6EI<W1R
M;W9ANR!E>'1E<F[I(&]V;.%D8>AE('-E9&5N[2X`3F5P;V1A<FEL;R!S82!S
M<&]J:;L@<R!)34%0('-E<G9E<F]M.B`E<P!.97!O9&%R:6QO('-A(&]T=F]R
M:;L@<_IB;W(@(B5S(BX`2V%N861A`%IR=;EINP!:<G6Y:;L@<W!RX79U`%IR
M=;EINR!S<'+A=G4@;R!P<F]B;.EM90!:<G6Y96[M;2!S<'+A=GD@;F%T<G9A
M;&\@>G)UN>UT92!J96H@;V)S86@N`$YE<&]D87)I;&\@<V$@=GEM87IANR!S
M^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A(&[A:G.[(&1OZ&%S;OT@861R97/A
M<BX`3F5M;[YN;R!P;VMR8>AO=F&[(&)E>B!P87)A;65T<F$@)W1A<F=E=$9I
M;&4G+@!.97!O9&%R:6QO('-A(&]D<W1RX6YINR!A9')E<^%R("(E<R(N`$YE
M;6^^;F\@;V1S='+A;FF[+"!E>&ES='5J92`E9"!N87-L961O=F[M:V]V+@!.
M96UOOFYO('!R975S<&]R:6%D8;LL('!OZ&5T('!O;&^^:65K('!R92!P<F5U
M<W!O<FEA9&%N:64@;F5S^FAL87/M(',@<&_H=&]M('5L;[YE;OUC:"!P;VQO
MOFEE:RX`3F5P;V1A<FEL;R!S82!S;65R;W9ANR!S<'+A=G4@;F$@=7+H96[I
M(.CM<VQO+@!+87!V97)D<VOI(&]S=')O=GD`5&ET=6QO:P!+871E9_-R:64@
M82!P;W!I<VMY`$MA:FUA;G-KZ2!O<W1R;W9Y`$-C`$UO8FEL;OT@=&5L96;S
M;@!6;&%S=&YO<W1I(&)U;FMY`%9Y<&QN96YI92!B=6YK>3H`5FQA<W1N;W-T
M:2!B=6YK>0!2;WIO<W1U<"!B=6YI96LZ`$UO8FEL;OT@=&5L96;S;@!$;R!S
M=')E9'4`4W1R961O869R:6-KX2!R97!U8FQI:V$`4&]D<F]B;ND@:6YF;W)M
MX6-I92!O(&-E<G1I9FEKX71E`%9L87-T;NUK(&-E<G1I9FEKX71U`%!O;&ET
M:6MY('!R92!C97)T:69I:^%T>0!);7!O<G0@8V5R=&EF:6OA=&]V(&YI92!J
M92!D;W-T=7!N_2X@3F%H<N%V86YI92!S^F)O<F]V(&YI92!J92!N82!T;VUT
M;R!S97)V97)I('!O=F]L96[I+@#(860`5F5D^F-I`%IM96YINP!:;65N:;L@
M=KEE=&MY`%IM96YINR!P<FEEZ&EN;VL`6FUE;FF[(%9AN64@:&5S;&\`6FUE
M;F$@;F%S=&%V96[M('IO8G)A>F5N:6$L('!OZ&5T('-P<N%V("!N82!K8;YD
M96H@<W1R86YE(&$@<W#T<V]B('1R:65D96YI82!S<'+A=BX`6FUE;F$@;F%S
M=&%V96[M(%;AN6AO(&UA:6QO=NEH;R!S97)V97)A(&$@<')I9>AI;FMO=BX`
M3F%S=&%V96YI92!M96YA(&$@861R:65S+"!K=&]RZ2!V:61I82"U=61I82P@
M:V7O(.CM=&%J^B!A(&]D<&]V961A:OH@;F$@5F&Y92!E+6UA:6QY+@!.87-T
M879E;FEE(&UE;F$L(&%D<F5S>2!A('-I9VYA=/IR>2P@:W1O<ND@<V$@>F]B
M<F%Z=6KZ('9O(%9A;6D@;F%P[7-A;OUC:"!S<'+A=F%C:"X`6FUE;F$@:&5S
M;&$@;FEE(&IE('8@86MT=>%L;F5J(&MO;F9I9W5RX6-I:2!P;V1P;W)O=F%N
MX2X@($MO;G1A:W1U:G1E('-V;VIH;R!A9&UI;FES='+A=&]R82X`6FYA:P!0
M;^AE="!Z;F%K;W8@;F$@>F]B<F%Z96YI93H`4U]K;VYT<F]L;W9ANR!L:6YK
M=2XN+@!+;VYT<F]L82!N;W9E:B!P;[ET>2!V('!R:67H:6YK;V-H`%IAN6MR
M=&[ZNR!?=KEE=&MY+[YI861N90!:8;EK<G1N:71E(':Y971K>2!M86EL;W;I
M('-E<G9E<GDL('H@:W1O<OUC:"!C:&-E=&4@<[MA:&]V8;L@<&^Y='4Z`%-K
M;VYT<F]L;W9ANR!P<F%V;W!I<R!P<F5D(&]D;W-L86[M;2!S<'+A=GD_`$-H
M:6QE`,CM;F$`5GEB97)T92!A:V-I=3H`5GEB97)T92!A<&QI:^%C:74Z`%9Y
M8F5R=&4@;6%I;&]V_2!S97)V97(Z`%!R;W/M;2!V>6)E<G1E(&%L96)O('5P
M<F%V=&4@861R97-U('8@<')I97-T;W)E('9P<F%V;SH`6G9OM71E('-I(&AE
M<VQO`%IV;[5T92!S:2!P;W6^[79A=&6U<VOI(&UE;F\`5GEB97)T92!S</1S
M;V(@>F]B<F%Z;W9A;FEA(&3A='5M;W8Z`%9Y8F5R=&4@='EP(+ET_6QU('IO
M>FYA;74@*'!R92!Z;W)A9&5NZ2!Z;WIN86UY*0!6>6)E<G1E(&%D<F5SX7(L
M(&MT;W+]('-A('!O=;YI:F4@<')I('!R:63A=F%N[2!N;W;]8V@@861R:65S
M+@!6>6)E<G1E('!O<F%D:64L('8@86MO;2!S82!B=63Z('!R96BU863A=F&[
M(&%D<F5SX7)E('!R:2!D;W#E\F%N[2!A9')I97,N`%9I86YOZ&[](&]S=')O
M=@!$969I;NUC:6$@=')I961Y("5S(&YE8F]L82!NX6ID96[A+@!*87-N;P!/
M9'-T<N%N:;L@<'+M:V%Z>2!-4T]F9FEC90!6>6UA>F&[(&1O=&%Z`$]D<W1R
MX6YINR!P;W6^[79A=&6U83H@)7,`3V1S='+A;FF[('!O=;[M=F%T9;5A`%9Y
M;6%Z8;L@<&]UONUV871EM7-KZ2#Z9&%J90!.97-K]'(@=GEJ87-N96YI90!+
M;&EK;FET92`E<R!P<F4@:V]N=F5R>FEU(&]B<N%Z:W4@9&\@9F]R;>%T=2P@
M:W1O<OT@<&]D<&]R=6IE(%;AN2!P<F5H;&EA9&'H+@!+;&EK;FET92`E<R!P
M<F4@<W1I86AN=71I92!O8G+A>FMU+@!+;&EK;FET92`E<R!P<F4@<W1RX6YK
M=2!A9&UI;FES='+A8VEE("5S+@!+;&EK;FET92`E<R!P<F4@>F]B<F%Z96YI
M92!(5$U,(&]B<V%H=2!V('-A;6]S=&%T;F]M(&]K;F4N`$ML:6MN:71E("5S
M('!R92!Z;V)R87IE;FEE('IM96ZY96YE:B!K\W!I92!O8G+A>FMU+@!+;&EK
M;FET92`E<R!P<F4@>F]B<F%Z96YI92!P<NUL;VAY('8@<V%M;W-T871N;VT@
M;VMN92X`2VQI:VYI=&4@)7,@<')E('IO8G)A>F5N:64@;75L=&EP87)T+W)E
M;&%T960@Z&%S=&D@=B!S86UO<W1A=&YO;2!O:VYE+@!+;&EK;FET92!S96T@
M<')E(%I/0E)!6D5.244@;V)RX7IK;W8`2VQI:VYI=&4@;F$@:F5D96X@>B!6
M8;EI8V@@=GEB<F%N_6-H(&%D<F5SX7)O=B!A('!O=&]M(&]Z;F'H=&4@<&]L
M:6$L(&MT;W+I(&-H8V5T92!P<F5HM6%DX79ANRX`2VQI:VYI=&4@<')E('!O
M:W)AZ&]V86YI90!+;&EK;FET92!P<F4@=6QOOF5N:64@=F5R96INZ6AO(%!'
M4"!KM?KH82!D;R!6X7-H;R!A9')E<^%R80!+;&EK;FET92!P<F4@=6QOOF5N
M:64@4R]-24U%(&-E<G1I9FEKX71U("5S(&1O(%;AN6AO(&%D<F5SX7)A`$-L
M:6-K871E;&P@8V5Z($A45%``2VQI:VYU=.UM(&YA(&%D<F5S=2!Z8>AN971E
M('#M<V&[(&YO=OH@<W!RX79U(&]D;W-I96QA=&6U;W9I`$ML:6MN=73M;2!N
M82!A9')E<W4@<V$@;W1V;W+M('-P<N%V80!:871V;W)INP!:871V;W)INR!O
M:VYO`%IA='9O<FF[(&]K;F\`6F%T=F]R96[]('!R:67H:6YO:P!/8FQA:WD`
M4N%N;R!O8FQAZ&YO`$]B;&'H;F\`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`
M6F)A;&F[`%IB86QINR!VN65T:V\`6F)A;&F[(':Y971K>2!P<FEEZ&EN:WD`
M6F)A;&F[('!R:67H:6YO:P!:8F%L:;L@0F_H;OT@<&%N96P`6F)A;&5NZ2!O
M:W)A:F4`2V]L=6UB:6$`1F%R8F$`56OAOFMA(&9A<F)Y.@!6_6)E<B!F87)B
M>0!6_6)E<B!F87)B>0!3=.5P8V4Z`$YA9'!I<WD@<W3E<&-O=@!+;VUI:W,`
M4'+M:V%Z`%!R[6MA>F]V_2!I;G1E<G!R971E<@!+;VUE;G3A<@!"9;YNZ2!M
M96YO`$MO;6]R>0!3<&]L;^AN;W.[`$AO=&]V;P!0[7-ANR#O86RY:74@<W!R
MX79U`%#M<V&[('-P<N%V>2!V(&YO=F]M(&]K;F4_`%#M<V&[('-P<N%V>2"Y
M=&%N9&%R9&YE('8@2%1-3"!'54D@*&%K('!R96AL:6%D8>@@<&]D<&]R=6IE
M('3Z=&\@=FQA<W1N;W.[*3\`4&_H[71AZ&4`4W1A=@!3=&%V`%)O>F1I96QY
M('8@:V]N9FEG=7+A8VEI`$MO;F9I9W5RX6-I82!P<F4@<WEN8VAR;VYI>N%C
M:74@<R!01$$L(&EN=&5L:6=E;G1N_6UI('1E;&5F\VYM:2!A($]U=&QO;VMO
M;2X`2V]N9FEG=7+A8VEA('!O=')E8G5J92!A:W1U86QI>N%C:74N`$MO;F9I
M9W5R;W9ANR`E<P!.87-T879E;FEE('-P]'-O8B!Z;V)R87IE;FEA('-P<N%V
M+@!.87-T879E;FEE('IO8G)A>F5N:6$@=6OAOF]K('-P<N%V+@!0;W1V<N]T
M92!H97-L;P!+;VYG;P!$96UO:W)A=&EC:^$@<F5P=6)L:6MA($MO;F=O`$E-
M05`@<V5R=F5R('5K;V[H:6P@<W!O:F5N:64N`%-P;VIE;FEE('IL>6AA;&\N
M`%-P;VIE;FEE('IL>6AA;&\Z(`!+M?KH(&)O;"!Z86UI971N=73]('-E<G9E
M<F]M('9E<F5J;OUC:"!KM?KH;W8N`$NU^N@@8F]L('IA;6EE=&YU=/T@<V5R
M=F5R;VT@=F5R96IN_6-H(&NU^NAO=BX@1/1V;V0Z("5S("@E<RD`4W!O:F5N
M:64@<R!&5%`@<V5R=F5R;VT@>FQY:&%L;RX`4W!O:F5N:64@<V\@<V5R=F5R
M;VT@>FQY:&%L;P!+;VYT86MT>0!+;VYT86MT>2!B;VQI(/IS<&6Y;F4@=FQO
MOF5NX2!D;R!6X;EH;R!A9')E<^%R82X`5'EP(&MO;7!R:6UO=F%NZ6AO('/Z
M8F]R=3H`3V)S86@@(B5S(@!0;VMR8>AO=F&[`$YA<W1A=F5N:64@<&]D<&]R
M>2!01U`@<')E(&%P;&EKX6-I=2`E<RX`3F%S=&%V96YI92!P;V1P;W)Y(%,O
M34E-12!P<F4@87!L:6OA8VEU("5S+@!.87-T879INR!M;[YN;W-T:2!P<F4@
M:+5A9&%N:64@<W!RX78N`$YA<W1A=F5N:6$L(&MT;W+I('5RZ'5J^BP@:V5D
M>2!S82!B=63Z(&MO;G1R;VQO=F&[(&YO=ND@<W!RX79Y(&$@Z&D@<V$@>F]B
M<F%Z[2!I;F9O<FWA8VEA(&\@<'+M8VAO9&4@;F]V96H@<W!RX79Y+@!3:V]N
M=F5R=&]V8;L@=&5X=&]VZ2!E;6]T:6MO;GD@;F$@9W)A9FEC:^D_`$-O;VMO
M=F4@;W-T<F]V>0!#;V]K:64`4VMO<.UR;W9ANP!+;W#M<F]V86YI92!Z;'EH
M86QO.B`E<P!+;W#M<F]V8;L@=OUB97(`4VMO<.UR;W9ANR!D;R!P<FEEZ&EN
M:V$`3W!R879INP!/<')A=F5N_2!T97AT`$MO<W1A<FEK80!0;V)R9;YI92!S
M;&]N;W9I;GD`3F5P;V1A<FEL;R!S82!Z8;EI9G)O=F&[('-P<N%V=2!P;VUO
M8V]U(%!'4#H@`$YE<&]D87)I;&\@<V$@<&]D<.US8;L@<W!RX79U('!O;6]C
M;W4@4$=0.B``3F5P;V1A<FEL;R!S82!Z8;EI9G)O=F&[('-P<N%V=2!P;VUO
M8V]U(%,O34E-12X`3F5P;V1A<FEL;R!S82!P;V1P[7-ANR!S<'+A=G4@<&]M
M;V-O=2!3+TU)344N`$YE<&]D87)I;&\@<V$@<')I9&&[(&MO;G1A:W0N("5S
M+@!.97!O9&%R:6QO('-A('!R:7!O:FF[(&L@3$1!4"!S97)V97)U+@!.97!O
M9&%R:6QO('-A('!R:7!O:FF[(&L@3$1!4"!S97)V97)U`$YE<&]D87)I;&\@
M<V$@;W9E<FF[('IO<W1A=&]K(&YA(/KH=&4N("5S`$YE<&]D87)I;&\@<V$@
M9&]K;V[H:;L@<&^^:6%D879K=2X@1/1V;V0Z("5S`$YA<W1A;&$@8VAY8F$@
M<')I('!R[7-T=7!E(&L@3$1!4"!S97)V97)U`$YE<&]D87)I;&\@<V$@<')I
M<&]J:;L@:R!S97)V97)U("(E<R(@<&]M;V-O=2!&5%`Z("5S`$YE<&]D87)I
M;&\@<V$@=GET=F]R:;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,`3F5P;V1A<FEL
M;R!S82!V>71V;W)INR!61E,@8F%C:V5N9#H@)7,`3F5P;V1A<FEL;R!S82!D
M9;EI9G)O=F&[(%!'4"#Z9&%J93H@`$YE<&]D87)I;&\@<V$@9&6Y:69R;W9A
MNR!3+TU)344@^F1A:F4N`$YE<&]D87)I;&\@<V$@=GEM87IANR!K;VYT86MT
M+B`E<P!.97!O9&%R:6QO('-A('9Y;6%Z8;L@>F]Z;F%M('!R[6IE;6-O=BX@
M)7,`3F5M;[YN;R!V>6UA>F&[('-P<N%V>2!Z("5S.B`E<P!.97!O9&%R:6QO
M('-A('9Y;6%Z8;L@<VMR:7!T(&YA('5P9W)A9&4@:V]N9FEG=7+A8VEE("(E
M<R(N`$YE<&]D87)I;&\@<V$@=7+H:;L@92UM86EL;W;Z(&%D<F5S=2!P<NUJ
M96UC=2X`3F5M;[YN;R!V>6MO;F&[(&]P97+A8VEE(/ID<KYB>2X`3F5M;[YN
M;R!V>6)R8;L@<&^^861O=F%N_2!S^F)O<B!Z('!R[6QO:'D@35,M5$Y%1BX`
M3F5M;[YN;R!V>6)R8;L@<&^^861O=F%N_2!S^F)O<B!Z;R!::7`@87)C:.UV
M=2X`3F5P;V1A<FEL;R!S82!S=&EA:&YUNR!C96S](&%D<F5SX7(N`$YE<&]D
M87)I;&\@<V$@>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@<'+M:F5M8V]V+@!.
M97!O9&%R:6QO('-A('KM<VMANR!K;VUP;&5T;OT@>F]Z;F%M('IO>FYA;6]V
M('!R[6IE;6-O=BX`3F5P;V1A<FEL;R!S82!N8>CM=&&[('-T<F%TZ6=I=2`B
M)7,B+@!.97!O9&%R:6QO('-A('-P=7-T:;L@;6MD:7(@(B5S(BX`3F5P;V1A
M<FEL;R!S82!Z[7-K8;L@=F5R96IN_2!KM?KH('IO('-E<G9E<F$@:[7ZZ&]V
M+@!.97!O9&%R:6QO('-A(&]T=F]R:;L@(B5S(B!P<F4@>N%P:7,N`$YE<&]D
M87)I;&\@<V$@;W1V;W)INR`E<RX`3F5P;V1A<FEL;R!S82!O='9O<FF[(&UO
M9'5L($UA:6YT96YA;F-E7U1A<VL@)7,`3F5P;V1A<FEL;R!S82!O='9O<FF[
M(&%D<F5SX7(@(B5S(BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!B97IP9>AN
MZ2!S<&]J96YI92!S($E-05`@<V5R=F5R;VTN("5S(#H@)7,N`$YE<&]D87)I
M;&\@<V$@<')I<&]J:;L@;F$@3$1!4"!S97)V97(N`$YE<&]D87)I;&\@<V$@
M<')EZ.UT8;L@)7,N`$YE<&]D87)I;&\@<V$@;V)N;W9INR!H97-L;R!Z861A
M;NEH;R!P;W6^[79A=&6U82X@3FEE:W1O<ND@86QE8F\@=KEE=&MY('!O9')O
M8FYO<W1I(&YI92!S^B!S<'+A=FYE+B!3:_IS=&4@=&\@>FYO=G4@86QE8F\@
M:V]N=&%K='5J=&4@5N&Y:&\@861M:6YI<W1RX71O<F$L(&%K('!O=')E8G5J
M971E('!O;6]C+@!.96UOOFYO('KM<VMANR!!0TP`3F5P;V1A<FEL;R!S82!Z
M[7-K8;L@861R97/A<BX@)7,`3F5P;V1A<FEL;R!S82!Z[7-K8;L@>F]Z;F%M
M('!R[6IE;6-O=BX@)7,`3F5P;V1A<FEL;R!S82!Z[7-K8;L@>F]Z;F%M>2!P
M<NUJ96UC;W8@)7,`3F5P;V1A<FEL;R!S82!Z[7-K8;L@:6YF;W)MX6-I=2!O
M(&UE;F[]8V@@;V)L87-T:6%C:"!Z($E-05`@<V5R=F5R82X`3F5M;[YN;R!Z
M[7-K8;L@:6YF;W)MX6-I92!O('9L87-T;F]S=&EA8V@@<V5R=F5R80!.97!O
M9&%R:6QO('-A('9RX71INR!K;VYF:6=U<N%C:74N`$YE<&]D87)I;&\@<V$@
M<W!U<W1INR!R;61I<B`B)7,B+@!.97!O9&%R:6QO('-A('5L;[YINR!K;VYF
M:6=U<N%C:74@)7,N`$YE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K;VYF
M:6=U<N%C:64N`$YE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K;VYF:6=U
M<N%C:64Z("5S`$YE<&]D87)I;&\@<V$@=6QOOFF[('-K<FEP="!N82!U<&=R
M861E(&YA<W1A=F5N[2!D;SH@(B5S(BX`3F5P;V1A<FEL;R!S82!U;&^^:;L@
M>N%L;VAU(&MO;F9I9W5RX6-I92`E<RX`3F5P;V1A<FEL;R!S82!Z87#M<V&[
M(&MO;F9I9W5R8>AN_2!S^F)O<B`E<RX@3?2^971E('!O=;YINR!N:65K=&]R
M^B!Z(&UOOFYO<W3M(&YA('KA<&ES(&OS9'4@;F$@)7,@86QE8F\@<VMO<.UR
M;W9ANR!R=>AN92!K\V0@=79E9&5N_2!N:;ZY:64@9&\@)7,N`$YE<&]D87)I
M;&\@<V$@:+5A9&&[(&YA($Q$05`@<V5R=F5R:2X`3F5P;V1A<FEL;R!S82!V
M>6UA>F&[("(E<R(N`$YE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[(&MO;G1A
M:W0N("5S`$YE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('IO>FYA;2!P<NUJ
M96UC;W8N("5S`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!K;VYF:6=U<N%C:74@
M<')E("(E<R(Z("5S`$YE;6^^;F\@;N%J<[L@0F_H;OT@<&%N96P@36]Z:6QL
M>2X@4VMO;G1R;VQU:G1E+""^92!J92!P86YE;"!O='9O<F5N_2X`4&]UONUV
M871EM6]V:2`B)7,B('-A(&YE<&]D87)I;&\@<')I9&&[('!RX79A('!R92!P
M<FEEZ&EN;VL@(B5S(CH@)7,`4&_H[71A;OT@=&5X=`!+<F%J:6YA`$MU<GIY
M`%9Y='9O<FF[`%9Y='9O<FF[('!R:67H:6YO:P!6>71V;W)INR!KM?KH90!6
M>71V;W)INR!V:7)T=>%L;GD@<')I9>AI;F]K`%9Y='9O<FF[(&YO=OT@^NAE
M=`!6>71V;W)INR!L:6YK=0!6>71V;W)INR!N;W;]('!R:67H:6YO:R!S<&%M
M=0!6>71V;W)INR!N;W;]('!R:67H:6YO:R!K;VYC97!T;W8`5GET=F]R:;L@
M;F]V_0!6>71V;W)INR!N;W;]('!R:67H:6YO:R!O9&]S;&%N96H@<&^Y='D`
M5GET=F]R:;L@;F]V_2!O9'!A9&MO=OT@:_2Y`%9Y=';A<F%N:64@<')A=FED
M:65L(&YA('5S<&]R:6%D86YI92!68;EE:B!P<FEC:.%D>F%J^F-E:B!P;[ET
M>2P@:F5J('1R:65D96YI92!D;R!P<FEEZ&EN:V]V(&$@;6%Z86YI92!N979Y
MOFEA9&%N96H@<&^Y='DN`%9Y='9O<FF[(&YO=OH@N6%B;/-N=0!6>71V;W)I
MNR"Y86)L\VYU(&$@;V1P;W9E9&4N`%9Y='9O<FF[('!O9'!R:67H:6YO:P!0
M<N%V82!T=F]R8W4`R.US;&\@:W)E9&ET;F5J(&MA<G1Y`$-H;W)VX71S:V\`
M2W5B80!!:W1UX6QN92`T(&;A>GD`06MT=>%L;F4@<V5D96YI80!!:W1UX6QN
M>2#H87,`06MT=>%L;F$@55),(&IE`$%K='7A;&YI('!O=;[M=F%T96QI80!!
M:W1UX6QN92!P;^AA<VEE`$%K='7A;&YY('!R[7-T=7`@9&\@)7,`06MT=>%L
M;F4@<&]D;6EE;FMY.B``06MT=>%L;GD@N73];`!.87-T879E;FEE(/KH=&]V
M('!R92!SNV%H;W9A;FEE('!ON71Y('H@:6[]8V@@^NAT;W8N`$YA<W1A=F5N
M:64@;V1O<VEE;&%N:6$@<&^Y='DN`$YA<W1A=F5N:64@^FQO:"P@:W1O<ND@
M<V$@<W#ZN;MA:OH@<')I('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S+@!6
M>7-T<FEH;OJ[`%9Y<W1R:6AN^KL@=OUB97(`0WEP<G5S`,AE<VOA(')E<'5B
M;&EK80!$1`!$4TX@*'!O>G)I(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&5N;F4`
M1.%T7W5M`%!R97IE<F'H(&3A=&]VZ6AO('-T<F]M=2`H1&%T851R964I`%9Y
M:+5A9.%V86YI92!V(&1A=&%BX7IE`$3A='5M`$3A='5M('!R:6IA=&EA`%;]
M8F5R(&3A='5M=0!$9?(`3U]D<W1RX6YINR!S=.5P96,`1&5C96UB97(`1&5S
M:6%T:V]VZ2#H[7-L80!/9&UI971N=73I`$]D;6EE=&YU=.DZ(`!:;65NN6F[
M(&]D<V%D96YI90!0<F5D;F%S=&%V96[I`%!R961N87-T879E;N$@9F%R8F$`
M5F&Y82!P<F5D;F%S=&%V96[A(&ED96YT:71A`%!R961N87-T879E;ND@<&]L
M92!HM6%D86YI80!0<F5D;F%S=&%V96[]('!R[6MA>F]V_2!I;G1E<G!R971E
M<@!0<F5D;F%S=&%V96[I(&MR:73I<FEU;2!T<FEE9&5N:6$Z`%!R961N87-T
M879E;OT@<VUE<B!T<FEE9&5N:6$Z`$1E9FEN[6-I90!0<FED96QINP!6>6UA
M>F&[`%9Y;6%Z8;L@)7,@=F5R96IN_2!KM?KH`%9Y;6%Z8;L@8G5N:W4`6FUA
M>F&[(&%K='7A;&YE(&NU^NAE`%9Y;6%Z8;L@<')I9>AI;F]K("AP<FEEZ&EN
M:WDI`%9Y;6%Z8;L@<VMU<&EN=0!6>6UA>F&[('KA>FYA;0!6>6UA>F&[('!R
MX79O`%9Y;6%Z8;L@=GEB<F%NZ2!P<FEEZ&EN:WD`5GEM87IANR"Y86)L\VYU
M`%9Y;6%Z8;L@=FER='7A;&YY('!R:67H:6YO:P!6>6UA>F&[(&1E9FEN[6-I
M=2!V:7)T=>%L;F5H;R!P<FEEZ&EN:W4@<')E("5S`%9Y;6%Z8;L@82!O9'-T
M<N%N:;L@<W!RX79Y`%9Y;6%Z8;L@8G5N:W4`5GEM87IANR!S=.5P96,`5GEM
M87IANR!E>&ES='5J^F-U(&%L=&5R;F%T[79N=2"Y86)L\VYU`%9Y;6%Z8;L@
M<W1I86AN=73I('-P<N%V>2!Z;R!V>F1I86QE;NEH;R!S97)V97)A/P!/9'-T
M<N%N:;L@>B!M]&IH;R!K86QE;F3A<F$`5GEM87IANR!S=&%RZ2!N86QI;FMO
M=F%NZ2!P<NUL;VAY(&YA('IAZ&EA=&MU(&UE<VEA8V$_`%9Y;6%Z8;L@<W1A
M<ND@<')I9>AI;FMY(&]D;W-L86YE:B!P;[ET>2!N82!Z8>AI871K=2!M97-I
M86-A/P!6>6UA>F&[('!RX79A('!R92`B)7,B`$-H8V5T92!V>6UA>F&[("(E
M<R(@82!VN65T:WD@:F5H;R!P;V1P<N%V83\`5GEM87IANR!R:6%D;VL`5GEM
M87IANR!V>6)R86[Z(&ED96YT:71U`%9Y;6%Z8;L@<W!RX79Y('-O('-P86UO
M;0!6>6UA>F&[(&%K='7A;&YY('-TY7!E8P!6>6UA>F&[(&%K='7A;&YY(')I
M861O:P!6>6UA>F%NZ0!6>6UA>F%NZ2!S<'+A=GD`4VMR:7!T(&YA('5P9W)A
M9&4@:V]N9FEG=7+A8VEE("(E<R(@8F]L('9Y;6%Z86[]+@!0<NUL;VAA("(E
M<R(@8F]L82!V>6UA>F%NX2X`5GEM87KA=F%N:64@82!P<F5S^G9A;FEE('-P
M<N%V`,AA<R!D;W)UZ&5N:6$`1.%N<VMO`%IA;6EE=&YUNR!P;[YI861A=FMU
M`%IA;6EE=&YUNR!P;[YI861A=FMU(&YA('II<W1E;FEE('IA;F5P<N%Z9&YE
M;F]S=&D`6F]S='5P;F4`4&]P[;ET92!P<F]B;.EM`%!O<&ES`%!O9')O8FYO
M<W1I`%!O9')O8FYO<W1I("AT:66^('8@;&]G;W9A8V]M('/Z8F]R92!(;W)D
M92D`1&5T86EL>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R
M82X`5OUV;VH`4F]S;OT@8F]D`%)O<V[](&)O9"!Z82!P;W-L961N^B!H;V1I
M;G4Z(`!2;W-N_2!B;V0Z(`!3^F)O<B`B)7,B(&YE8F]L('!R:7!O:F5N_2P@
M;&5B;R!B;VP@<'+A>F1N>2X`6F]B<F%Z;W9ANR!S:6=N873Z<GD@;65N96H@
M=OUR87IN93\`4VUE<B!ZM6%V82!D;W!R879A`%-M97(@<W!R879A(&1OM6%V
M80!!9')E<^%R`$YA<W1A=F5N:64@>F]B<F%Z96YI80!:;V)R87IO=F&[(.AA
M<R!V(#(T+6AO9&EN;W9O;2!F;W)MX71E/P!.87-T879E;FEE('IO8G)A>F5N
M:6$`6F]B<F%Z:;L@<&]T=G)D96YI92!P;R!O9&]S;&%N[2!S<'+A=GD_`%IO
M8G)A>FF[('!O9')O8F[Z('!R961P;W9E[P!:;V)R87IINR!P<F5D<&]V9>\@
M*%1!1BD`1F]R;>%T('IO8G)A>F5N:6$`6F]B<F%Z:;L@=B!T96QE('-P<N%V
M>0!:;V)R87IINR!O>F[A;65N:64@;R!P<FEJ873M(&YO=F5J('-P<N%V>3\`
M6F]B<F%Z:;L@;&EN:W4@(D]D<W1RX6YINR!S<&%M(B!V(&UE;G4_`%IO8G)A
M>FF[(&QI;FMU(")6>7!RX7ID;FF[($]D<&%D:V]V_2!K]+DB('8@;65N=3\`
M4&]UOFET:64`4&]T=G)D96YI92!O(&1O<G7H96[M`$2^:6)U='-K;P!.979Y
M:&]V=6IE`$YE:V]N=')O;&]V8;L@<')I9>AI;FMY(&YA(&YO=OH@<&^Y='4`
M3F5V>6UA>F&[`$YE<&]UONUV86IT92!P<FEA;6\@;6%I;G1E;F%N8V4N<&AP
M`$YE=GET=N%R8;L@;&EN:W4@>F\@<W3E<&-A($]D.@!#:&-E=&4@;W1V;W)I
MNR!T96X@<')I9>AI;F]K/P!/8G-A:'5J92!P<G;](')I861O:R!NX7IV>2!P
M;VSM/R!!:R#A;F\L('IAN6MR=&YI=&4@<&]L[>AK;SH@`$1O;6EN:6-A`$1O
M;6EN:6OA;G-K82!R97!U8FQI:V$`3F5MX71E(&6Y=&4@^NAE=#\@6F%R96=I
M<W1R=6IT92!S82X`2&]T;W9O`%-T:6%H;G6[`%-T:6%H;G6[("5S`%-T:6%H
M;G6[("5S('9O(&9O<FWA=&4@+GII<`!3=&EA:&YUNR!VN65T:WD@<'+M;&]H
M>2`H9F]R;>%T("YZ:7`I`%-T:6%H;G6[('!R:67H:6YO:R`H<')I9>AI;FMY
M*0!3=&EA:&YUNR!P<FEEZ&EN;VL@*'!R:67H:6YK>2D@6V9O<FWA="`N>FEP
M70!3=&EA:&YUNR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A8VEU(&%K;R!02%`@
M<VMR:7!T+@!3=&EA:&YUNR!V;R!F;W)MX71E("YZ:7``2V]N8V5P=`!0<FEE
MZ&EN;VL@:V]N8V5P=&]V`%!R:67H:6YO:R!K;VYC97!T;W8Z`%IO>FYA;2!S
M(';]8F5R;VT`1')O9WD`12UM86EL`$4M;6%I;&]VX2!A9')E<V$`2T].245#
M`$524@!#2%E"03H@5F&Y=2!S<'+A=G4@;F5B;VQO(&UOOF[I(&1O<G7H:;L`
M16MVX61O<@!5<')A=FF[`%5P<F%V:;L@Z&EE<FYU(&QI<W1I;G4`57!R879I
MNR!B;&]K`%5P<F%V:;L@<&^Y=&]VZ2!F:6QT<F4`57!R879INR!S:W5P:6YU
M`%5P<F%V:;L@<'+A=F\`57!R879INR!P<N%V80!5<')A=FF[('!RX79A('!R
M92`E<P!5<')A=FF[('9I<G1UX6QN>2!P<FEEZ&EN;VL`57!R879INR!D969I
M;NUC:74@=FER='7A;&YE:&\@<')I9>AI;FMU('!R92`E<P!5<')A=FF[(&)I
M96QU(&QI<W1I;G4`57!R879INR!N87-T879E;FEA('!R93H`57!R879INR!P
M<N%V82!P<F4@(B5S(@!5<')A=FF[('!RX79A('!R92`E<P!5<')A=FF[(.AI
M97)N=2!L:7-T:6YU`%5P<F%V:;L@9FEL=')O=F%C:64@<')A=FED;.$`57!R
M879INR!N87-T879E;FEA('!R92!P<NUS='5P(&L@:6[];2!E+6UA:6QO=OUM
M(/KH=&]M+@!5<')A=FF[(&)I96QU(&QI<W1I;G4`5GID96SA=F%N:64`16=Y
M<'0`4V%L=N%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%+6UA:6QO=N$@861R
M97-A`$4M;6%I;&]VZ2!A9')E<WD@;75S:6$@8GF[(')O=FYA:^DN`$4M;6%I
M;"!S('!O='9R9&5N[6T`0G+A;F$@16UA:6PM;F$M4TU3`$5M;W1I:V]N>0!6
M>6UA>F%NZ2!VN65T:WD@<W!RX79Y('H@)7,N`%9Y<'+A>F1N:;L@<')I9>AI
M;F]K("AP<FEEZ&EN:WDI`%9Y<'+A>F1N:;L@=GEB<F%NZ2!P<FEEZ&EN:WD`
M5GEP<N%Z9&YINR!/9'!A9&MO=OT@:_2Y`$]D<W1RX6YINR!?<W!A;0!6>7!R
MX7ID;FF[($]D<&%D:V]V_2!?:_2Y`%!RX7ID;F$@<W!RX79A+@!0<N%Z9&YY
M(';]<VQE9&]K+@!0<N%Z9&YE('!O9&UI96YK>2!HM6%D86YI80!0;W9O;&F[
M('!RX6-U(',@4$=0/P!0;W9O;&F[('!RX6-U(',@4R]-24U%/P!0;W9O;&F[
M('9L;[YE;FEE(&]B<N%Z:V]V('H@1V%LZ7)I[2!D;R!T97AT=3\`4&]V;VQI
MNR!Z;V)R87IO=F%N:64@=6OAOF]K('-P<N%V/P!0;W9O;&F[(&MO;G1E>'1O
M=ND@;65N=2!P<F4@<')A=ND@=&QAZ&ED;&\_`$YA<W1A=F5N:6$@N6E?9G)O
M=F%N:6$`6F&Y:69R;W9A;ND`2V]N:65C`$MO;FEE8R!P<F5P;W-L86YE:B!S
M<'+A=GD`2V]N:65C('-P<N%V>0!+;VYI96,@<W!RX79Y(&]D("5S`$MO;FEE
M8R!R;VMA`%IVY.BY:;L@961I=&]R`%IA9&%J=&4@:&5S;&\@<')E(&NU^N@`
M6F%D86IT92!B97IP9>AN;W-T;OH@;W3A>FMU+"!N82!K=&]R^B!B=61E=&4@
M;75S:66[(&]D<&]V961ANR!A:R!Z86)U9&YE=&4@:&5S;&\L(&YA<'(N("=A
M:V\@<V$@=F]LX2!M;VIE('IV:65R871K;S\G.@!:861A:G1E(%523"!O8G+A
M>FMA`%IA9&%J=&4@<.US;65NX2!U=F5D96[I(&YIOKEI93H`6F%D86IT92!M
M96YO('!R92!6X;D@;F]V_2!P<FEEZ&EN;VL@<V\@<W!A;6]M`%IA9&%J=&4@
M;65N;R!P<F4@5N&Y(&YO=OT@<')I9>AI;F]K(&MO;F-E<'1O=@!:861A:G1E
M(&UE;F\@<')E(%;AN2!N;W;]('!R:67H:6YO:R!O9&]S;&%N96H@<&^Y='D`
M6F%D86IT92!M96YO('!R92!6X;D@;F]V_2!O9'!A9&MO=OT@:_2Y`$-E;.$@
M<W!RX79A`%!O;&^^:V$@(B5S(B!B;VQA(/IS<&6Y;F4@=FQOOF5NX2!D;R!A
M9')E<^%R80!2;W9N[6MO=N$@1W5I;F5A`$5R:71R96$`0VAY8F$`0VAY8F$@
M<')I('!R:7#A:F%N:2!S82!K($E-05`@<V5R=F5R=2X@)7,@.B`E<RX`0VAY
M8F$@<')I('9Y=';A<F%N[2!B;&]K=3H@)7,`0VAY8F$@<')I('9Y;6%ZX79A
M;NT@=6MO='9E;FEA('-Y;F-H<F]N:7KA8VEE.B`E<P!#:'EB82!P<FD@=GEM
M87KA=F%N[2!ZX7IN86UU('-Y;F-H<F]N:7KA8VEE.B`E<P!#:'EB82!P<FD@
M>NUS:V%V86[M(&]B<V%H=3H@)7,`0VAY8F$@<')I(&]D;W-I96QA;NT@;V1P
M;W9E9&4Z("5S+@!#:'EB82!P<FD@86MT=6%L:7KA8VEI(&AE<VQA.B`E<P!#
M:'EB82!V(&4M;6%I;&]V96H@<W!RX79E+@!#:'EB82!P<FD@>F%P:7-O=F%N
M[2`B)7,B+@!%<W3S;G-K;P!%=&GS<&EA`$5T;FEC:^D`175R\W!A`%5D86QO
M<[L@8F]L82#Z<W!EN6YE('9Y;6%Z86[A+@!+8;YD_6-H(#$U(&UI;OIT`$MA
MOF3I(#(@;6EN^G1Y`$MAOF3]8V@@,S`@<V5K^FYD`$MAOF3]8V@@-2!M:6[Z
M=`!0<FD@:V&^9&]M('!R:6ALX7-E;NT`2V&^9/H@<&]L(&AO9&EN=0!+8;YD
M^B!M:6[Z='4`3F%P<NUK;&%D.@!3<'5S=&F[`%)O>F)A;&F[`%)O>F)A;&F[
M(':Y971K;P!2;WIB86QINR!VN65T:WD@<')I9>AI;FMY`%)O>F)A;&F[('!R
M:67H:6YO:P!$;W!L;FF[(&UE;N$O861R97-Y`%)O>F)A;&F[($)OZ&[]('!A
M;F5L`$1O<&QN:;L@;65NX2!V(&]K;F4@;F$@<.US86YI92!S<'+A=GD@875T
M;VUA=&EC:WD@;F$@<&]Z863M/P!);7!L:6-I=&YE(')O>F)A;&F[(&-E;/T@
M<W1R;VT@<')I9>AI;FMO=B!V('IO>FYA;64@<')I9>AI;FMO=C\`4F]B>F&U
M=6IE('-A`$_H86OA=F$@<V$@)RDG`$_H86OA=F$@<V$@<VQO=F\@86QE8F\@
M<&]D;6EE;FMA(&BU861A;FEA('8@^G9O9'IO=FOA8V@`1.%T=6T@97AP:7+A
M8VEE`$5X<&]N96YT`$9A<F)A('1E>'1U`$YA:')ANR!K;VYF:6=U<N%C:74@
M;F$@1E10`%-?=&EA:&YUNR!P;[ET=0!.97!O9&%R:6QO('-A('KM<VMANR!N
M87-T879E;FEA+@!.87-T86QA(&-H>6)A('!R:2!S<&]J96[M(',@3$1!4"!S
M97)V97)O;2X`3F%S=&%L82!C:'EB82!P<FD@<'+M<W1U<&4@:R!334(@<V5R
M=F5R=2X`3F5P;V1A<FEL;R!S82!K;W#M<F]V8;L@>B`B)7,B+@!.97!O9&%R
M:6QO('-A(&MO<.UR;W9ANR!D;R`B)7,B+@!.97!O9&%R:6QO('-A('9Y='9O
M<FF[(&YO=ND@4T%33"!S<&]J96YI92X`3F5P;V1A<FEL;R!S82!P<F5S=6[Z
MNR!D;R`B)7,B+@!.97!O9&%R:6QO('-A('KM<VMANSH@)7,`1&]B<ND`1F%L
M:VQA;F1S:^D@;W-T<F]V>2`H36%L=NUN>2D`1F%E<G-KZ2!O<W1R;W9Y`%KA
M=F&^;N$@8VAY8F$Z`$9A>`!&87AY`$9E8G)UX7(`4&]C:70@=&5P;&]T>0!0
M;V-I="!T97!L;W1Y.B``4W1I86AN=;L@<&^Y='4`4W1I86AN=;L@<&^Y='4@
M=B!N;W9O;2!O:VYE/P!3=&EA:&YUNR!S<'+A=GD@<')I('!R:6ALX7-E;NT_
M`%-T:6%H;G5T_6-H("5D('-P<N%V('H@)7,`4W1I86AN=73A(#$@<W!RX79A
M('H@)7,`1F5T8VAM86EL.@!&971C:&UA:6PZ(+YI861N92!N;W;I('-P<N%V
M>2X`36%LZ2!Z<N&^:WD`36%LZ2!S;F5H;W;I('!R96CA;FMY`$9I7VQT<F4`
M36%T:6-A('!O;.T`1FEDOFD`4_IB;W(`4&_H970@<_IB;W)O=CH@)7,@<_IB
M;W(`4&_H970@<_IB;W)O=CH@)7,@<_IB;W)O=@!3<'+A=F-A('/Z8F]R;W8`
M365N;R!S^F)O<G4`5OUB97(@<_IB;W)U`$YA:')A=&EE('/Z8F]R=0!.86AR
MX79A;FEE('/Z8F]R;W8@;FEE(&IE('!O9'!O<F]V86[I+@!.87-T879E;FEA
M(&9I;'1R;W8`3F%S=&%V96YI82!F:6QT<F]V`$]D<W1RX6YINR!Z;R!S<'+A
M=GD@;F%DX79K>2!A(&YE<VQUN6[I(';]<F%Z>3\`3F$@=&]M=&\@<WES=.EM
M92!J92!P;V1P;W)A(&9I;'1R;W8@>F%KX7IA;N$N`$9I;'1R90!&:6QT<F4@
M;FEE('/Z(&%K=&EV;W9A;ND`1FEL=')E.B!S='+A;FMA(&YA('-P<N%V=2`E
M<P!(M6%D8;L`1NUN<VMO`%!R=N$@<&]L;W9I8V$`4')VX2!S='+A;FMA('-C
M:'+A;FMY`%!R=N$@<W1RX6YK80!0<G;A(+ET=G*[`%!E=F[]('!O;65R`$]T
M;^AINP!0;.%V86KZ8VD@=&5X=`!07W)E<&]S;&&[`$AM;&$`4')I9>AI;F]K
M("5S(&YE97AI<W1U:F4`06MC:64@<R!P<FEEZ&EN:V%M:2`M('!O='9R9&5N
M:64`4W!RX79A('!R:67H:6YK;W8`26YF;W)MX6-I92!O('!R:67H:6YK=0!:
M9&EEM6%N:64@<')I9>AI;FMO=B!N:64@:F4@<&]V;VQE;NDN`%!O=;YI=&EE
M('!R:67H:6YK;W8@;FEE(&IE('!O=F]L96[I+@!&87)B82!P[7-M80!0;W1R
M879A`%!R92!P<F5H;&EA9&'H92P@:W1O<ND@;F5P;V1P;W)U:OH@;V)RX7IK
M>0!0<F5D<&]V9>\@*%1!1BD`4')E9'!O=F7O(&YA('5V961E;OT@<&_H970@
M9&[M("AP86WD=&%J=&4@;F$@=&\L(+YE('!R961P;W9E[R!J92!P<F4@9&YI
M(&%J(&YO8VD@82!T86L@;?2^92!V9;5KZ2#H[7-L;R!V>71V;W)INR!V9;5M
M:2"Y:7)O:_T@8FQO:RD`6F%B=61L:2!S=&4@:&5S;&\_`$9O<FWA="!DX71U
M;74@>F]B<F%Z96[]8V@@<W!RX78@<')E('-P<N%V>2!D871O=F%NZ2!D;F5S
M`$9O<FUU;.%R90!&;W)T=6YA`%1Y<"!F;W)T=6YY`$9O<G1U;GD`1F]R='5N
M>2`R`$;S<F$`4')E<&]S;&&[`%!R97!O<VQANSH`4')E<&]S;&%NX2!S<'+A
M=F$`4')E<&]S;&%NX2!S<'+A=F$@;V0@)7,`4')E<VUE<F]V86YI80!0:6$`
M4N%M8V4`1G)A;F/Z>G-K;P!&<F%N8_IZ<VMO("A%=7+S<&$I`$]D<&]V9>\@
M;F$@OFEA9&]SNR!O('II<W1E;FEE('IA;F5P<N%Z9&YE;F]S=&D@*%A86"D`
M1G)A;F/Z>G-K82!'=6%Y86YA`$9R86YC^GIS:V$@4&]L>6[I>FEA`$9R86YC
M^GIS:V4@:G6^;ND@=&5R:73S<FGA`%]/9`!/9`!3<&EA=&_H;N$@861R97-A
M`%IO('-M97)U(`#:<&QN_2!P;W!I<P!3<&QN`$-E;.D@;65N;SH`1G=D.@!&
M=V0Z`$9W9#H@)74@<')E<&]S;&%N_6-H('-P<N%V`$=A8G5N`$=A;.ER:6$L
M('H@:W1O<F5J(&-H8V5T92!V>FEANR!O8G+A>F]K`$=A;.ER:6$Z`$=A;6)I
M80!6N65O8F5C;ND@;F%S=&%V96YI80!'96YE<F]V8;L@:V]N9FEG=7+A8VEU
M('!R92!A<&QI:^%C:74@)7,`1V5N97)O=F%N_2!K\V0`1V5O<F=I80!.96UE
M8VMO`%-T:6%H;G6[(&EB82!N;W;I('-P<N%V>2`H:6)A($E-05`I`$=H86YA
M`$=I8G)A;'3A<@!+<G-T;ND@;65N;P!/9&]S;&&[`%!R96ISNR!N82!S<'+A
M=G4`4')E:G.[(&1O(&%D<F5SX7)A(&YA('!O;&^^:W4@(B5S(@!';V5D96P`
M1V]O9VQE($UA<',`2+5A9&&[(&YA($=O;V=L90!5;6^^;FF[('!R[7-T=7``
M3V1T:65N92"Y961E:@!'<NEC:V\`1W+S;G-K;P!'<F5N861A`$%D;6EN:7-T
M<N%C:6$@<VMU<.UN`$UE;N$@<VMU<.UN(&YE<VWZ(&)YNR!P<N%Z9&YE`$=R
M;W5P7VQD87`Z($YE<&]D87)I;&\@<V$@<')I9&&[('-K=7!I;G4@)7,N(%-E
M<G9E<B!O9'!O=F5D86PZ(`!'<F]U<%]L9&%P.B!N97!O9&%R:6QO('-A('9Y
M;6%Z8;L@<VMU<&EN=2`E<P!'<F]U<%]L9&%P.B!N97!O9&%R:6QO('-A(&%K
M='5A;&EZ;W9ANR!S:W5P:6YU("5S`%-K=7!I;GD`1W5A9&5L;W5P90!'=6%M
M`$=U871E;6%L80!'=65R;G-E>0!0<N%V82!A;F]N>6UN_6-H('!O=;[M=F%T
M9;5O=@!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`%15
M`$A434P`2%1-3"!V97)Z:6$@<W!RX79Y`$A434Q!<F5A(&YE9&]V;VSM('9Y
M;6%Z8;L@<&]S;&5D;OH@8G5N:W4@=B!R:6%D:W4N`$A434Q!<F5A(&YE9&]V
M;VSM('9Y;6%Z8;L@<&]S;&5D;OT@<W3E<&5C('8@=&%B=;5K92X`2%1-3$%R
M96$@;F5D;W9O;.T@=GEM87IANR!P;W-L961N_2!R:6%D;VL@=B!T86)UM6ME
M+@!(5%10(&%U=&5N=&EF:6OA8VEA(&YE8F]L82!NX6ID96[A+@!(86ET:0!!
M;&=O<FET;75S(&AA<VAO=F%C96H@9G5N:V-I90!/<&%R`$AL879IZ&MA`$AL
M879IZ&MY`$AE87)D;W8@;W-T<F]V(&$@36-$;VYA;&1O=F4@;W-T<F]V>0!3
M:6QNX2!B^G)K80!6_;EK80!0;VUO8V[M:P!0;VUO8V[M:R!P<F4@<&]UONUV
M86YI92!E9&ET;W)A`%!O;6]C;NUK`%!O;&]G=;5A`%1U(&IE('IAZ&EA=&]K
M('/Z8F]R=3H`5'4@:F4@<W!RX79A+"!K=&]R^B!S=&4@<.US86QI.@!3:W)Y
M=.D`4VMR>73I('8@>F]B<F%Z96[M('9LX6MI96X`4VMR>;L@=GEM87IA;ND`
M4VMR>;L@;F5P<FEH;.%S96[I`%9Y<V]KX0!6>7-O:^$@<')I;W)I=&$`3F%J
M=GFYN6EA`$1O7VUO=@!6871I:^%N`$1O;6]V`$1O;>%C82!A9')E<V$`1&]M
MX6-I('!R:67H:6YO:P!496QE9O-N(&1O;6]V`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92]+;VQA8CH@=B!S<'+A=F4@)7,@8F]L:2!NX6ID96[I
M(&YE<&QA=&[I("5S(%A-3"#Z9&%J90!(;W)D92]+;VQA8CH@<R!O8FIE:W1O
M;2`E<R!N96MO<F6Y<&]N9'5J92"^:6%D;F$@<W!RX79A+@!(;W)D92]+;VQA
M8CH@=B!S<'+A=F4@)7,@;F5B;VP@;N%J9&5N_2"^:6%D96X@;V)J96MT('1Y
M<'4@)7,`2&]R9&4O2V]L86(Z(/IS<&6Y;F4@;V1S='+A;F5NZ2`E<R`B)7,B
M`$AO<F1E+TMO;&%B.B!I;G1E9W+A8VEA('9YOF%D=6IE(%!(4"!R;WJY[7)E
M;FEE("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A('9Y='9O
M<FF[(&YO=OT@6$U,('-T<F]M('!R92!O8FIE:W0@)7,`2&]R9&4O2V]L86(Z
M(&YE<&]D87)I;&\@<V$@;V1S='+A;FF[("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!N97!O9&%R:6QO('-A('KM<VMANR!-24U%($E$('!R92#H87.[('1Y
M<'4@)7,`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@<WEN8VAR;VYI>F]V
M8;L@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@<WEN
M8VAR;VYI>F]V8;L@>F1I9;5A;ND@;V)J96MT>3H@)7,`2&]R9&4O2V]L86(Z
M(&YE>F[A;7D@>F1I9;5A;OT@;V)J96MT("(E<R(`2&]R:7IO;G3A;&YA(.AI
M87)A`$AO<FEZ;VYTX6QN92!V>7!L;F5N:64`2&]R:7IO;G3A;&YE.@!!:V\@
M<W1E('-A('-E;2!D;W-T86QI/R`H4')O<^UM(&YA:&SA<W1E(2D`06MO('-A
M(&UA:OH@>F]B<F%Z:;L@<'+M;&]H>3\`2V^U:V\@<W3E<&-O=B!C:&-E=&4@
M>FSZZ&F[/P!:861A:G1E('!OZ&5T('!O;.T@*'-TY7!C;W8I/P!+;[5K;R!R
M:6%D:V]V(&-H8V5T92!Z;/KH:;L_`$%K;R!O>FYAZ&F[(&-I=&]V86[I(')I
M861K>2!V(&]D<&]V961I`%9L:&MO<[L`5FQH:V]SNSH@`$AU;6]R:7-T:0!-
M8>]A<G-K;P!)34%0`$E-05`@*$%U=&]M871I8VMY(&1E=&5K;W9ANR!P<F]T
M;VMO;'DI`$E-05`@<V5R=F5R('5K;V[H:6P@<W!O:F5N:64N(%-E<G9E<B!O
M9'!O=F5D86PZ("5S`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@24U!4"!S8VAR
MX6YK=3H@)7,`3F5P;V1A<FEL;R!S82!V>6UA>F&[($E-05`@<V-H<N%N:W4Z
M("5S`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@24U!4"!K=O-T=3H@)7,`24U!
M4"!C97H@4U-,`$E-05`@8V5Z(%-33"`H8V5R=&EF:6OA="!P;V1P[7-A;OT@
M<V%M_6T@<V5B;W4I`$E-05`@8V5Z(%-33"`H8V5R=&EF:6OA="!P;V1P[7-A
M;OT@<V%M_6T@<V5B;W4I`$E-05`@<V5R=F5R('5K;V[H:6P@<W!O:F5N:64N
M`$E-05`L(&)E>B!43%,`24U!4"]03U`S(&4M;6%I;&]VZ2!S97)V97)Y`%!R
M:6IA=.D@<W!RX79Y`$E0(&%D<F5S80!)4"!A9')E<V$@;FEE(&IE(&1O<W1U
M<&[A+@!)4"!A9')E<V$@;FEE(&IE('8@<N%M8VD@9&]V;VQE;NEH;R!#2412
M(&)L;VMU+@!0;W)UN65N:64@<')A=FED;&$@;R!P979N96H@25`@861R97-E
M+@!6;&^^:;L@:[7ZZ"!?<')E9`!)<VQA;F0`26)A(&EK;VYY`$EK;VYY('!R
M92`E<P!):V]N>2!A('1E>'0`3N%Z;W8@:61E;G1I='DZ`$%K('-A(&YE>F]B
M<F%Z[2!K;W)E:W1N92P@)7,@82!O='9O<NT@<V$@=B!N;W9O;2!O:VYE+@!!
M:R!P;W6^[79A=&4@4U-,(&%L96)O(%1,4RP@;75S[71E(&YA:')ANR!02%`@
M<F]ZN>UR96YI92!O<&5N<W-L+@!!:R!B=61E=&4@<&]K<F'H;W9ANRP@=KEE
M=&MY('-P<N%V>2!V('!R:67H:6YK=2AP<FEEZ&EN:V]C:"D@8G5D^B!S=')A
M=&5NZ2$`06L@;F5V:63M=&4@<')I('!O=;YI=.T@26YT97)N970@17AP;&]R
M97)A(+YI861N92!I:V]N>2P@<&]T<F5B=6IE=&4@>F&Y:W)T;OJ[('3Z=&\@
M=F^U8G4@<')E('9Y<&YU=&EE('!R:65S=FET;F]S=&D@4$Y'(&]B<N%Z:V]V
M+@!!:R!V:63M=&4@=/IT;R!S<'+A=G4@82!N979I9.UT92!O8G+A>F]K+"!O
M8G+A>F]K+"!K=&]R_2!S=&4@8VAC96QI(&YA:')ANRP@;F5M]+YE(&)YNR!Z
M;V)R87IE;OT@=F\@5F&Y;VT@<')E:&QI861AZ&DN`&EG;F]R;W9ANP!)9VYO
M<F]V8;L@=KEE=&MY`$]B<N%Z;VL`56OAOFMA(&]B<N%Z:V$Z`%523"!O8G+A
M>FMA`%523"!O8G+A>FMA.@!/8G+A>F]K('H@9V%LZ7)I90!/8G+A>F]K('H@
M9V%LZ7)I93H`3F%H<F%T:64@;V)RX7IK=0!/8G+A>FMY`$EM<&]R=`!);7!O
M<G1O=F&[(&NU^N@`26UP;W)T;W9ANR!KM?KH;W;]('#A<@!);7!O<G1O=F&[
M('-P<N%V>0!);7!O<G1O=F&[(%!'4"!KM?KH`$EM<&]R=&]V8;L@;W-O8F[]
M(&-E<G1I9FEKX70`26UP;W)T;W9ANR!O<V]B;OT@<')I=N%T;GD@4$=0(&NU
M^N@`26UP;W)T;W9ANR!O<V]B;OT@=F5R96IN_2!01U`@:[7ZZ`!);7!O<G1O
M=F&[(&]S;V)NZ2!3+TU)344@8V5R=&EF:6OA='D`26UP;W)T;W9ANR!V97)E
M:F[](&NU^N@`26UP;W)T;W9ANR!V97)E:F[](%!'4"!KM?KH`$EM<&]R=&]V
M8;L@=F5R96IN_2!3+TU)344@:[7ZZ`!);7!O<G1O=F&[(%,O34E-12!KM?KH
M`$EM<&]R=&]V8;L@<_IB;W(@;6)O>`!);7!O<G1O=F&[('/Z8F]R(&UB;W@@
M)7,@9&\@<')I9>AI;FMA("5S+@!);7!O<G0L(&MR;VL@)60`1/1L9;YI=.D`
M1/1L9;YI=.D@<W!RX79Y`$EM<&]R=&]V86[]8V@@)60@<W!RX78@>B`E<RX`
M26UP;W)T;W9A;ND@<&]L93H@)7,`26UP;W)T;W9A;ND@<&]L:6$Z`%-P<F%C
M^G9A('-A`%9L;[YINR!KM?KH(%]Z80!0<FEJ873I('-P<N%V>0!6;&^^:;L@
M9&\@;V1P;W9E9&4@;F%J9/1L9;YI=&5JN6EE(&AL879IZ&MY('#T=F]D;F5J
M('-P<N%V>3\`5FQOOFF[('#T=F]D;OH@<W!RX79U(&1O(&]D<&]V961E/P!"
M;VP@>F%D86[](&YE<W!RX79N>2!K\V0@86MC:64N`$YE<W!RX79N92!P;W6^
M[79A=&6U<VOI(&UE;F\@82]A;&5B;R!H97-L;P!.97-P<N%V;F4@<&]UONUV
M871EM7-KZ2!M96YO(&%L96)O(&%L=&5R;F%T[79N82!A9')E<V$N(%-K^G-T
M92!T;R!Z;F]V=2!A;&5B;R!K;VYT86MT=6IT92!S<'+A=F-U(%;AN6AO('-Y
M<W3I;74L(&%K('!O=')E8G5J971E('!O;6]C+@!:=N3HN6F[(&]D<V%D96YI
M90!);F1I80!*961N;W1L:7;M('!O=;[M=F%T96QI80!);F1O;NEZ:6$`26YF
M;P!);F9O<FWA8VEE`$EN9F]R;>%C:64@=;X@;FEE('/Z(&1O<W1U<&[I+@!)
M;F9O<FWA8VEE(&\@)7,@=F5R96IN;VT@:[7ZZ&D`26YF;W)MX6-I92!O(&]S
M;V)N;VT@<')I=N%T;F]M(&NU^NAI`$EN9F]R;>%C:64@;R!O<V]B;F]M('9E
M<F5J;F]M(&NU^NAI`%8@=&5L92!S<'+A=GD`5FQOOFF[(%]S=.5P96,@>F$`
M4V5M('9L;[YT92!C97)T:69I:^%T`%9L;[YINR!O8G+A>F]K`%1U('9L;[YT
M92!O<V]B;OT@<')I=N%T;GD@4$=0(&NU^N@`5'4@=FQOOG1E(&]S;V)N_2!V
M97)E:F[](%!'4"!KM?KH`%1U('9L;[YT92!V97)E:F[](%!'4"!KM?KH`%9L
M;[YINR!T86)UM6MU`%9L;[YINR!L:6YK=0!6;&^^:;L@7W-TY7!E8R!P<F5D
M`%9L;[YINR!N;W;]('-TY7!E8R!Z82!A:W1UX6QN>0!6;&^^:;L@;F]V_2!S
M=.5P96,@<')E9"!A:W1UX6QN>0!6;&^^:;L@;F]V_2!R:6%D;VL@>F$@86MT
M=>%L;GD`5FQOOFF[(&YO=OT@<FEA9&]K('!R960@86MT=>%L;GD`5FQOOFF[
M(&]D<W1A=F5C('IA(&%K='7A;&YY(&)O9`!6;&^^:;L@;V1S=&%V96,@<')E
M9"!A:W1UX6QN>2!B;V0`5FQOOFF[(&%L=&5R;F%T[79N=2"Y86)L\VYU`%IA
M9&%J=&4@92UM86EL;W;Z(&%D<F5S=2P@;F$@:W1O<OH@9&]S=&%N971E(&YO
M=ND@:&5S;&\Z`%9L;[YINR!B=6YK=2!Z80!6;&^^:;L@8G5N:W4@<')E9`!6
M;&^^:;L@<W3E<&5C('IA`%9L;[YINR!S=.5P96,@<')E9`!6;&^^=&4@<W!R
MX79Y`%9L;[YINR!O9'-T879E8R!Z80!6;&^^:;L@;V1S=&%V96,@<')E9`!6
M;&^^:;L@<FEA9&]K('IA`%9L;[YINR!R:6%D;VL@<')E9`!:861A:G1E('!O
MOF%D;W9A;OH@;V1P;W9E[R!N82!B97IP9>AN;W-T;OH@;W3A>FMU.@!6;&^^
M:;LO=7!R879INR!O8G+A>F]K`%9L;[YINR]U<')A=FF[(&QI;FMU`$YA(&]D
M;W-I96QA;FEE('!R92!Z;WIN86T@<'+M:F5M8V]V(&YE;>%T92!D;W-T871O
MZ&[](&MR961I="X`3F5D;W-T871OZ&[](&MR961I="X`0V5LZ2#H[7-L;P!:
M;WIN86T@8V5L_6-H(.AI<V5L`%!R92!T96YT;R!K;VUP;VYE;G0@8F]L82!V
M>6)R86[A(&YE<&QA=&[A(&%K8VEA+@!.97!L871NX2!A9')E<V$`3F5P;&%T
M;N$@=GID:6%L96[A('-C:'+A;FMA+@!.97!L861NZ2!51$@@*%5S97(@1&%T
M82!(96%D97(L($AL879IZ&MA('!O=;[M=F%T9;5S:_UC:"#Z9&%J;W8I+@!.
M97!L871NZ2#Z9&%J92!F;W)MX71U(%I)4"X`3F5P;&%T;N$@87!L:6OA8VEA
M+@!.97!L871NZ2!)1"!DX79K>2X`3F5P;&%T;OT@>FYA:R!V(&4M;6%I;&]V
M96H@861R97-E.B`E<RX`0F]L:2!O9&]S;&%NZ2!N97!L871NZ2#Z9&%J92X`
M3F5P;&%T;N$@8VEEM6]VX2!A9')E<V$N`$YE<&QA=&[](&9O<FWA="!S^F)O
M<G4`3F5P;&%T;OT@:[7ZZ`!.97!L871N_2!L:6-E;NAN_2!KM?KH+@!";VQA
M('IA9&%NX2!N97!L871NX2!L;VMA;&ET82X`3F5P;&%T;N$@:&]D;F]T82!M
M<V=?='EP92X`3F5P;&%T;N$@86QE8F\@8VC]8F%J^F-A(&AO9&YO=&$@87!I
M7VED+@!.97!L871NZ2!A;&5B;R!C:/UB86KZ8V4@<&%R86UE=')E+@!.97!L
M871NZ2!R;V1IZ&]V<VOI('!RX79O+@!.97!L871NZ2!I9"!P87)T;F5R82X`
M3F5P;&%T;OT@;W-O8F[](%!'4"!P<FEVX71N>2!KM?KH+@!.97!L871N_2!O
M<V]B;OT@4$=0('9E<F5J;OT@:[7ZZ"X`3F5P;&%T;OT@:_-D('!R;V1U:W1U
M+@!.97!L871N_2!P<F]T;VMO;`!.97!L871N_2!P<NUJ96UC83H@(B5S(@!.
M97!L871N_2!O8FIE:W0@>F1I9;5A;FEA`$YE<&QA=&[A('ID<F]J;W;A(&%D
M<F5S82X`3F5P;&%T;ND@^F1A:F4@=6YI8V]D92X`26YV96YTX7(`26YV97)T
M;W9ANP!);G9E<G1O=F&[(';]8F5R`$ERX6X`27)A:P#-<G-K;P!)<VQE(&]F
M($UA;@!/:F5D:6YE;.D@8OIR:WD`27IR865L`%9Y9&%V871EM0!+=7)Z[79A
M`%1A;&EA;G-K;P!*86UA:FMA`$IA;G7A<@!*87!O;G-K;P!*97)S97D`2F]R
M9.%N`$KZ;`!*^FX`6F%R;W9N8;L`6F%R;W9N8;L@9&\@<W1R961U`%IA<F]V
M;F&[(&1O(&)L;VMU`%IA<F]V;F&[(':U879O`%IA<F]V;F&[('9P<F%V;P!+
M0@!+87IA8VAS=&%N`%!O;F5C:&&[(&]R:6=I;N%L/P!+9?)A`$ME<F)E<F]S
M('-E<G9E<B!Z86UI971O;"!A=71E;G1I9FEKX6-I=2X`2V5R;F5L+6YO=N'H
M:6MO=FEA`%9Y='9O<F5N:64@:[7ZZ&$`1&EG:73A;&YY(&]D=&QAZ&]K(&NU
M^NAA`$3EOFMA(&NU^NAA`%1Y<"!KM?KH80!0;W6^:71I92!KM?KH80!+M?KH
M('6^(&5X:7-T=6IE(&YA('-E<G9E<FD@=F5R96IN_6-H(&NU^NAO=BX`1V5N
M97)O=F%N:64@:[7ZZ&$@;?2^92!T<G9ANR!D;&AO+B`@4&]K<F'H;W9ANR!V
M(&=E;F5R;W9A;NT@:[7ZZ&$_`$EM<&]R="!KM?KH;W8@;FEE(&IE(&1O<W1U
M<&[]+B!.86ARX79A;FEE('/Z8F]R;W8@;FEE(&IE(&YA('1O;71O('-E<G9E
M<FD@<&]V;VQE;NDN`$EM<&]R="!KM?KH;W8@;FEE(&IE(&1O<W1U<&[]+B!.
M96WA=&4@9&5F:6YO=F%N_2!A9')E<^%R(&YA('!R:63A=F%N:64@:V]N=&%K
M=&]V+@!+M?KH(&)O;"#Z<W!EN6YE(&]D;W-L86[](&YA('-E<G9E<B!V97)E
M:F[]8V@@:[7ZZ&]V+@!$971I`$MI<FEB871I`*5U9&]V;V1E;6]K<F%T:6-K
MX2!R97!U8FQI:V$@2_-R96$`2_-R96IS:^$@<F5P=6)L:6MA`$MU=F%J=`!+
M:7)G:;ES:V\`5GI?:+5A9`!*87IY:P!,86]S`%!O<VQE9&[A('!O;&]V:6-A
M`%!O<VQE9&[A('-T<N%N:V$@<V-H<N%N:WD`4&]S;&5D;N$@<W1RX6YK80!0
M;W-L961NX2!Z;65N82!H97-L80!0;W-L961NX2"Y='9RNP!0;W-L961NX2!A
M:W1U86QI>N%C:6$Z`%!O<VQE9&[I('!R:6ALX7-E;FEE.B`E<P!0;W-L961N
MZ2!P<FEH;.%S96YI93H@)7,@>B`E<P!0;W-L961NZ2!P<FEH;.%S96YI93H@
M;FEK9'D`3&]T>;ES:V\`4'+A=F\`5GIHM6%D`$YE8VAA:G1E('!RX7ID;F4@
M<')E(+YI861E;B!O:W)A:@!,:6)A;F]N`%:U879O`$AL879IZ&MA(':U879O
M`$AO9&YO='D@=K5A=F\`3&5S;W1H;P#:<F]V9?(`3&EBZ7)I80!,[6)Y80!,
M:6-H=&5NN71A:FYS:V\`I6%H:^D@;7)H;VQE;FEE`*5A:&O](&3AON\`4N%N
M;R"U86AK_2!DX;[O`$YE<VOT<B"U86AK_2!DX;[O`*5A:&OI(&1AON]O=ND@
M<')E:.%N:WD`I6%H:_T@9.&^[R!S(&AR;65N[6T`I6%H:^D@<VYEOF5N:64`
MI6%H:^D@<VYE:&]VZ2!P<F5HX6YK>0!,:6UE<FEC:P!,:6YK80!.86QI;FMO
M=F&[('!R[6QO:'D_`$QI;FMA('5K87IU:F4@;F$Z`%!R97!O:FF[(&4M;6%I
M;&]V^B!A9')E<W4@<V\@<W1RX6YK;W4@;F$@<.US86YI92!P;[ET>0!.86QI
M;FMO=F%NZ2!P<NUL;VAY('/Z('IA:^%Z86[I+@!,:6YK>0!0;&%T;F]SNR!L
M:6YI96L@=GEP<KGM("5S`$QI;G5X($-O;VMI90!:;WIN86T@+2!P;W6^[79A
M=&6U('5V:63M('!R:67H:6YO:P!6>7#M<V&[('IO>FYA;2!D871A8N%Z`%IO
M>FYA;2!TZ6T@4&]M;V-N[6MA`%9Y<.US8;L@>F]Z;F%M('1A8G5L:65K`%IO
M8G)A>FF[(':Y971K>2!K;VYT86MT>2!P<FD@;F%H<N%V86[M(&]B<F%Z;W9K
M>2!S(&MO;G1A:W1M:3\@*$%K(&IE('IA:^%Z86[I('5V:63M=&4@:6)A(&MO
M;G1A:W1Y+"!K=&]RZ2!S=&4@97AP;&EC:71N92!V>6BU863A=F%L:2DN`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`%IO>FYA;2!V
M(&AL879IZ&ME`%IO8G)A>F5N:64@<V5D96[M('IL>6AA;&\Z("5S`%IO8G)A
M>F5N:64@<&]UONUV871EM6]V('IL>6AA;&\Z("5S`%IO8G)A>F]V86YI92!Z
M;WIN86UU('!O=;[M=F%T9;5O=B!J92!Z86OA>F%NZ2X`3&ET97)A=/IR80!,
M:71V80!.8>CM=&%V82!S82XN+@!,;VOA;&YA('-C:'+A;FMA.@!-:65S=&YY
M(.AA<SH@`$QO:V%L:7KA8VEA(&$@Z&%S`%5M:65S=&YE;FEE`%!R:6ALX7-E
M;FEE`%!R:6ALX7-INR!S82!N82`E<P!:X7IN86UY('!R961C:.%D>F%J^F-E
M:B!S>6YC:')O;FEZX6-I90!/9&ALX7-INP!0<FEH;.%S96YI90#:;&]H>2!P
M<FD@<')I:&SA<V5N[0!0<FEH;.%S96YI92!Z;'EH86QO+"!P<F5T;[YE('-T
M92!Z861A;&D@;F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!H
M97-L;RX`4')I:&SA<V5N:64@>FQY:&%L;RX`1&QH_2!T97AT`$SA<VMA`$[M
M>FMA`$[M>FMA('!R:6]R:71A`$UA;.D@9W+I8VME('#M<VUE;N$`36%LZ2!L
M871I;G-KZ2!P[7-M96[A`$UA;.D@<NUM<VME(.CM<VQI8V4`3F%J;FF^N6EA
M`$QU>&5M8G5R<VMO`$U-`%-P<N%V82!D\F$`4'+M;&]H82!-4RU43D5&(&YE
M;V)S86AO=F%L82"^:6%D;F4@^F1A:F4N`$U31P!-86-A;P!-86-E9/-N<VMO
M`%/Z8F]R($UA8VEN=&]S:`!-861A9V%S:V%R`$WA9VEA`%!ON71A`%!O<VQA
MNR!E+6UA:6P@861M:6YI<W1RX71O<F]V:0!5:^&^:WD@<W!RX78`5'EP(&UA
M:6QO=NEH;R!S97)V97)A(&YA('!R:7!O:F5N:64Z`%-C:'+A;FMA`$YA<W1A
M=F5N:64@>F]B<F%Z96YI82!S8VARX6YO:R!A('!R:67H:6YK;W8`5GET=F]R
M:;L@;&EN7VMU+BXN`$UA;&%W:0!-86QA:GII80!-86QE9&EV>0!-86QI`$UA
M;'1A`%-P<F%V;W9ANR!Z;WIN86T@:V%T96?S<FGM+"!S(&MT;W+];6D@;WIN
M8>AU:F5T92!P;VQOOFMY(&$@9F%R8GD@87-O8VEO=F%NZ2!S('3];6ET;R!K
M871E9_-R:6%M:2X`36%P82!-87`R-`!-87!A($UA<%%U97-T`$UA<&]V86YI
M82!U;&^^96[I+@!-87)E8P!/:W)A:@!/>FYAZ&F[(':Y971K>2!S<'+A=GD@
M=B!P<FEEZ&EN:W4@86MO('!R9>CM=&%NZ0!/>FYAZ&F[(':Y971K>2!S<'+A
M=GD@=B!P<FEEZ&EN:W4@86MO(&YE<')EZ.UT86[I`$]Z;F'H:;L@86MO.@!2
M;WIL:;EO=F&[('9N;W)E;ND@8VETX71Y('+T>FYY;6D@9F%R8F%M:3\`3WIN
M8>AINR!S<'+A=GD@86MO('!R9>CM=&%NZ3\@*&EB82!)34%0*0!/>FYAZ&F[
M(&IE9&YO9'5C:.D@9F]R;>%T;W9A;FEE/P!/>FYAZ&F[('!R[7IN86MM:2!0
M<F7H[71A;NDO3F5P<F7H[71A;ND`3WIN8>AINR!I;OUM:2!P<NUZ;F%K;6D@
M*&YA<'(N($3T;&6^:73I+UIO9'!O=F5D86[I*0!-87)S:&%L;&]V92!O<W1R
M;W9Y`$UA<G1I;FEK`%9Y:&]V=6IE(':Y971K_6T@<&^^:6%D879KX6T`5GEH
M;W9U:F4@M75B;W9OM6YE:B!P;[YI861A=FME`%IH;V1NZ2!P;VQI80!-875R
M973A;FEA`$UA=7+M=&EU<P!-87AI;>%L;GD@<&]V;VQE;OT@:W)E9&ET+@!"
M;VP@<')E:W)OZ&5N_2!M87AI;>%L;GD@<&_H970@Z&%S=.T@<W!RX79Y+@!.
M86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#(T(&AO9.UN.B``3F%J
M=GFYN6EA('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`V(&AO9.UN.B``36%X:6WA
M;&YA('9EM6MO<[L@<'+M;&]H>0!-87AI;>%L;GD@<&_H970@<')I9>AI;FMO
M=@!-87AI;>%L;GD@<&_H970@8FQO:V]V('!O<G3A;'4`36%X:6WA;&YA(&3E
MOFMA`$)O;"!D;W-I86AN=73](&UA>&EMX6QN>2!P;^AE="!P<NUL;V@N`$)O
M;&$@9&]S:6%H;G5TX2!M87AI;>%L;F$@8V5L:V]VX2!V9;5K;W.[('!R[6QO
M:"X`3>%J`$UA>6]T=&4`365D:6/M;F$`R&QE;F]V:6$`6F]Z;F%M('!R:67H
M:6YK;W8@;65N=0!:;V)R87IE;FEE(&UE;G4Z`%IL^NAINR!B=6YK>0!3<'+A
M=F$`4.US86YI92!S<'+A=GD`1.%T=6T@<W!RX79Y`$YA<W1A=F5N:6$@<W!R
MX78`5GEHM6%D86YI92!S<'+A=GD`5F6U:V]SNR!S<'+A=GD`6F1R;VIO=OT@
M=&5X="!S<'+A=GD`4W!RX79A(&)O;&$@^G-P9;EN92!O=F5R96[A+"!A;&4@
M8V5R=&EF:6OA="!P;V1P:7-U('-A(&YE<&]D87)I;&\@;W9E<FF[+@!:;V)R
M87IE;FEE('-P<N%V>0!0;&%T;F]SNR!S<'+A=GD@=GEP<KEA;&$N`%!R[7IN
M86MY('-P<N%V>0!0<FEEZ&EN:WD@<W!RX78`4W!RX79A(&]D("5S`%-P<N%V
M82!MX2!P<NUL;VAY`%-P<N%V82!J92!Z8;EI9G)O=F%NX0!3<'+A=F$@:F4@
M<&]D<.US86[A`%-P<N%V82!V>6AO=G5J90!3<'+A=F$@8F]L82#Z<W!EN6YE
M('!R97-M97)O=F%NX0!3<'+A=F$@8F]L82#Z<W!EN6YE(&]D;W-L86[A+"!A
M;&4@;FEE('5L;[YE;N$@9&\@)7,`4W!RX79A(&)O;&$@^G-P9;EN92!O9&]S
M;&%NX2X`5'EP('-P<N%V>0!3<'+A=B!N82!S='+A;FMU('8@>F]Z;F%M92!S
M<'+A=@!3<'+A=GD@9&\`4&_H87-I92!-971A<@#:9&%J92!-971A<B!N:64@
M<_H@9&]S='5P;NDN`-ID86IE($UE=&%R(&YI92!S^B!K(&1I<W!O>NUC:6DN
M($1E=&%I;'D@8F]L:2!Z87IN86UE;F%NZ2!P<F4@861M:6YI<W1RX71O<F$N
M`%-Y<W3I;2!-971A<D1"(&YI92!J92!P<FEP;VIE;OTN`$UE=/-D80!-973S
M9&$@(B5S(B!N:64@:F4@9&5F:6YO=F%NX0!.961E9FEN;W9A;N$@;65T\V1A
M+B!6;VQA;ND@>B!M973S9'DZ("5S`$UE=')I8VOI`$UE>&EC;P!-:6MR;V[I
M>G-K92!F961E<F%T[79N92"Y=.%T>0!3=')E9`!4>7`@36EM90!.86IN:;ZY
M:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#(T(&AO9.UN.B``3F%J;FF^N6EA
M('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`V(&AO9.UN.B``36EN:6WA;&YA(&1O
M8F$@<&QA=&YO<W1I(&AE<VQA(&6Y=&4@;F5V>7!RN6%L80!:<FMA9&QO=F\@
M;V)RX71INP!2]'IN90!#:/UB82!B86SM:R!014%2($A45%!?4F5Q=65S="X`
M0VC]8F$@:V]N9FEG=7+A8VEA+B!!:R!C:&-E=&4@<&]UONUV8;L@=/IT;R!A
M<&QI:^%C:74L(&UU<^UT92!T97)A>B!V>6=E;F5R;W9ANR!K;VYF:6=U<N%C
M:74N`$-H_6)A($E$('-P<N%V>2X`0VC]8F$@<&^^861O=F%N_2!014%2(&)A
M;.UK($UA:6PN`$-H_6)A($E$(')E;.%C:64N`%!O;@!-;V)I;&[](&UA:6P`
M36EE<FYY`$3A='5M('!O<VQE9&YE:B!Z;65N>0!5<')A=FF[`%5P<F%V:;L@
M55),`$UO9'5L=7,`36]L9&%V<VMO`$UO;F%K;P!-;VYG;VQS:V\`365S:6%C
M(&$@<F]K`$UE<V'H;F4`36]N='-E<G)A=`!-97-AZ&[I(&;A>GD`3F$@<FEA
M9&MU("5D(&)O;&\@;N%J9&5N_6-H('9I86,@<&]L[2!A:V\@;^AA:^%V86[]
M8V@@)60N`%!R92!P;VQE("(E<R(@<V$@;F&Y;&D@=FEA8V5RZ2!A9')E<WDN
M`$UA<F]K;P!0<F5V8;YN92!J87-N;P!0<F5V8;YN92!O8FQAZ&YO`%!R979A
MOFYE('-L;F7H;F\`4')E<W5N^KL`4')E<W5N^KL@9&]L=0!0<F5S=6[ZNR!V
MM6%V;P!0<F5S=6[ZNR!V<')A=F\`4')E<W5N^KL@:&]R90!0<F5S=6[ZNR!N
M:;ZY:64`4')E<W5N^KL@<W!A;2!D;R!P<FEEZ&EN:V$@<W!A;6]V(&$@;F6Y
M:V]D;ND@<W!RX79Y(&1O('!R:6IA=&5J('!ON71Y`%!R97-U;OJ[(&1O('!R
M:67H:6YK80!0<F5S=6[ZNR!V>;FY:64`36]Z86)M:6L`5FEA8_IR;W;R;W;I
M('9Y8F5R86-I92!Z;WIN86UY`%9I86-E<F\@Z&%S=.TO86QT97)N873M=GD`
M6F]B<F%Z96YI92!V:6%C97+]8V@@<W!RX78`5FEA8V[A<V]B;OT@=OUB97(`
M36]J92!K;VYT;P!);F9O<FWA8VEE(&\@;6]J;VT@^NAT90!-]&H@<&]R=.%L
M`%9Z:+5A9"!M]&IH;R!P;W)TX6QU`$UY86YM87(`3FEE+"!.15/:2$Q!4\U-
M+@"N24%$3D4`4$]:3L%-2T$`365N;P!-96YO(&$O86QE8F\@92UM86EL;W;A
M(&%D<F5S82!N96WTOG4@8GF[('!RX7ID;F4`3F%M[6)I80!.875R=0!6>;YA
M9'5J92!A:V-I=0!.97#A;`!(;VQA;F1S:V\`2&]L86YD<VOI($%N=&EL>0!:
MX6ML861NX2!54DP@3F5T<V-A<&4`55),('!R92!Z;F5P;&%T;F5N:64@8V5R
M=&EF:6OA=&]V($-!($YE='-C87!E`%523"!P<F4@<&]L:71I:W4@0T$@3F5T
M<V-A<&4`55),('!R92!O8FYO=F5N:64@<&QA=&YO<W1I(&-E<G1I9FEKX71O
M=B!.971S8V%P90!54DP@<')E('IN97!L871N96YI92!C97)T:69I:^%T;W8@
M3F5T<V-A<&4`365N;R!34TP@<V5R=F5R82!.971S8V%P90!+;VUE;G3A<B!C
M97)T:69I:^%T=2!.971S8V%P90!4>7`@8V5R=&EF:6OA='4@3F5T<V-A<&4`
M4VEENP!.:6MD>0!.:6MD>2!N975K;&%D8;L@<'+M;&]H>0!.;W;I`$YO=N$@
M2V%L963S;FEA`$YO=N$@:V%T96?S<FEA`$YO=OT@<')I9>AI;F]K`$YO=N$@
M<&^Y=&$`3F]VX2!S<'+A=F$`3F]VX2!S<'+A=F$@<')E("5S`$YO=@!.;W;I
M('!O=;[M=F%T9;5S:^D@;65N;R`H;F5P;W9I;F[I*0!.;W;](%KI;&%N9`!.
M;W;I('-P<N%V>0!.;W;I(&AE<VQO`%!L871N;W.[(&YO=NEH;R!H97-L82!V
M>7!RN>T@)7@N`$YO=ND@:&5S;.$@;FEE('/Z(')O=FYA:^DN`$YO=ND@;VMN
M;R`H7V)L86YK*0!.97=S`$1I<VMU<V[I('-K=7!I;GD`SV%L96H`3F%S;&5D
M=6KZ8V4@-"!FX7IY`,]A;+EI82!S<'+A=F$`SV%LN6EA('-T<F%N80#/86RY
M:64@;F%S=&%V96YI80!.87-L961U:OIC83X`3FEK87)A9W5A`$YI9V5R`$YI
M9^ER:6$`3F]C`$YI=64`3FEE`*YI861E;B!C97)T:69I:^%T(&YE8F]L(&[A
M:F1E;OT`0F5Z(+EI9G)O=F%N:6$`1&%T86+A>F$@:[7ZZ&]V(&IE('!RX7ID
M;F$`KFEA9&YE('-P<N%V>0!.96)O;"!I;7!O<G1O=F%N_2"^:6%D96X@=F5R
M96IN_2!01U`@:[7ZZ"X`3FEE(&IE('!R[71O;6[](+YI861E;B!O<V]B;OT@
M8V5R=&EF:6OA=`!"97H@=6OAOFMY`$YE8F]L:2!NX6ID96[I(+YI861N92!V
M97)E:F[I(&NU^NAE`$YE8F]L(&EM<&]R=&]V86[](+YI861E;B!V97)E:F[]
M(%,O34E-12!KM?KH+@!.96)O;&D@;N%J9&5NZ2"^:6%D;F4@<'+M;&]H>2X`
M3FEE('/Z(&1O<W1U<&[I(+YI861N92!K;VYF:6=U<F'H;ND@^F1A:F4L('!R
M92!K=&]RZ2!B>2!S82!D86QI('IO8G)A>FF[(')O>F1I96QY+@!0<F4@=GET
M=N%R86YI92!)4T\@;V)R87IO=B!N:64@:F4@:R!D:7-P;WKM8VEI(+YI861N
M82!S=')A=.EG:6$N`$YE97AI<W1U:F4@N6%B;/-N82!P<F4@9.%V:W4N`$YA
M('!OOF%D;W9A;F5J('!O>NUC:6D@;F5E>&ES='5J92"^:6%D96X@8FQO:RX`
M4')E($U#04P@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!M96YO(&MA
M;&5N9.%R82X`KFEA9&YA('IM96YA+@!+('1O;75T;R!P<N%V=2!N96UOOFYO
M('!R:61ANR"^:6%D;F4@<&]D<FEA9&5NZ2!P<N%V82X`4')E("5S(&YE8F]L
M82!U<NAE;N$@:V]N9FEG=7+A8VEA+@!0<F4@1E10(%9&4R!N96)O;&$@=7+H
M96[A(&MO;F9I9W5RX6-I82X`4')E(%-13"!61E,@;F5B;VQA('5RZ&5NX2!K
M;VYF:6=U<N%C:6$N`%!R92!344PM1FEL92!61E,@;F5B;VQA('5RZ&5NX2!K
M;VYF:6=U<N%C:6$N`*YI861E;B!K<F5D:70N`$YE8F]L;R"Y<&5C:69I:V]V
M86[I(&UI97-T;R!U<NAE;FEA+@!6;R!V97)E:FYO;2!KM?KH:2!N:64@:F4@
MOFEA9&YA(&EN9F]R;>%C:6$@;R!E+6UA:6QO=F5J(&%D<F5S92X`4_IB;W(@
M;F5B;VP@;F%H<F%N_2X`KFEA9&5N('!R:67H:6YO:R!N:64@:F4@;WIN8>AE
M;OTN`*YI861N92!P<FEEZ&EN:WD@<V$@;F5K;VYT<F]L=6KZ(&YA(';]<VMY
M="!N;W9E:B!P;[ET>2X`3F5B;VQI(+EP96-I9FEK;W9A;ND@<')I9>AI;FMY
M`%8@OFEA9&YO;2!P<FEEZ&EN:W4@;FEE('/Z(&YO=ND@<W!RX79Y`%8@OFEA
M9&YO;2!P<FEEZ&EN:W4@;FEE('/Z(&YE<')EZ.UT86[I('-P<N%V>0!.96)O
M;&D@;N%J9&5NZ2"^:6%D;F4@:6MO;GDN`$YI92!J92!N87-T879E;N$@;&]K
M86QI=&$N`$YE8F]L82!Z861A;N$@;&]K86QI=&$N`*YI861E;B!T97AT('8@
M=&5L92!S<'+A=GD`3F5B;VQA('IA9&%NX2"^:6%D;F$@<W!RX79A+@"N:6%D
M;F$@<W!RX79A(&YE=GEH;W9U:F4@5N&Y;74@>F%D86YI=2X`3F5B;VQO(+EP
M96-I9FEK;W9A;ND@OFEA9&YE(&UE;F\N`$YE8F]L;R"Y<&5C:69I:V]V86[I
M(.CM<VQO+@"N:6%D;F4@=7+AOFQI=ND@9F]R='5N>0!0<F4@2%144"!A=71E
M;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@24U!4"!A=71E
M;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@2V5R8F5R;W,@
M875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($QO9VEN
M(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!005-3
M5T0@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E(%--
M0B!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!.96)O;&$@
M>F%D86[A(&-E<W1A(&L@<')O9W)A;74@3W!E;E-33"X@4')O9W)A;2!/<&5N
M4U-,(&IE('!O=')E8F[](&YA('!RX6-U(',@^F1A:FUI(%!+0U,@,3(N`*YI
M861N92!P<F5B:65H86KZ8V4@<')I:&SA<V5N:6$N`$YE8F]L(&EM<&]R=&]V
M86[](+YI861E;B!P<FEVX71N>2!01U`@:[7ZZ"X`3F5B;VP@:6UP;W)T;W9A
M;OT@OFEA9&5N('9E<F5J;OT@4$=0(&NU^N@N`$YE8F]L:2!I;7!O<G1O=F%N
MZ2"^:6%D;F4@;W-O8F[I(%,O34E-12!C97)T:69I:^%T>2X`3F5E>&ES='5J
M92"^:6%D96X@<')I=N%T;GD@:[7ZZ"P@=&%KOF4@<W!RX79U(&YE;6^^;F\@
M9&6Y:69R;W9ANRX`2W;S=&$@;FEE(&IE(&YA<W1A=F5NX2X`0F5Z(.AI87(`
M3F5B;VP@N7!E8VEF:6MO=F%N_2!O9&1EM6]V8>@N`$)E>B!S='+A;@!.96)O
M;"!N87-T879E;OT@OFEA9&5N('!R;V=R86T@;F$@:V]N=')O;'4@<')A=F]P
M:7-U+@"N:6%D;F4@8VAY8GD@<')A=F]P:7-U`%/Z8F]R(&YE;N%J9&5N_0"N
M:6%D;F4@;N%V<FAY`$YE<&]D87)I;&\@<V$@;N%J<[L@OFEA9&YU('!O9'!O
M<F]V86[Z(&UE=/-D=2!)34%0(&%U=&5N=&EF:6OA8VEE+@!0<F4@=GER;W9N
MX79A8VEU('!A;>2[(&YI92!J92!D;W-T=7!N_2"^:6%D96X@9&_H87-N_2!P
M<FEEZ&EN;VLN`$YE8F]L(+EP96-I9FEK;W9A;OT@<&]UONUV871EM2X`3F5B
M;VQO(&]D;W-L86[I('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L96)O(&AE<VQO
M+@!.96)O;&D@=G+A=&5NZ2!P;&%T;ND@6$U,(/ID86IE`*YI861N92!H;V1N
M;W1Y`%8@</1V;V1N96H@:V]N9FEG=7+A8VEI(&YE8F]L82!NX6ID96[A(+YI
M861N82!V97)Z:6$N(%9Y9V5N97)U:G1E('IN;W9U(&MO;F9I9W5RX6-I=2X`
M5B!K;VYF:6=U<N%C:6D@;F5B;VQA(&[A:F1E;N$@OFEA9&YA('9E<GII82X@
M5GEG96YE<G5J=&4@>FYO=G4@:V]N9FEG=7+A8VEU+@!.:64@:F4@^NAA<W1N
M[6L`KFEA9&YE`*YI861N92`H<&]UOFF[(&EM<&QI8VET;OH@:&]D;F]T=2D`
M3W-T<F]V($YO<F9O;&L`3F]R;>%L;F$`4V5V97)NX2!P;VQO9W6U80!3979E
M<F[I($UA<FGA;G-K92!O<W1R;W9Y`$[S<G-K;P!.97!L873M('!O`$YE<&QA
M=.T@<')E9`!.979Y;6%Z86[I`$YI92!J92!K;VYC97!T`$YE9/1L9;YI=.D`
M3FEE(&IE(&]S;V)NZ0!.:64@:F4@861R97/A<@!.97!L871N_2!V97)E:F[]
M(&NU^N@N`$YE=GEM87IA;ND@<W!RX79Y`$YI92!J92!I;7!L96UE;G1O=F%N
MZ2X`3F5D]&QEOFETZ2!S<'+A=GD`3F5N87-T879E;ND`3FEE(&IE('!O9'!O
M<F]V86[I+@!-]+YE('1O(&-H=NVU=2!T<G9ANRX`4&]Z;N%M:WD`3FGH`$YI
MZ"!N82!P<F5Z97)A;FEE+"!V<N&[=&4@<V$@<W#DNRX`57!O>F]R;F5N:64Z
M(&YA;&EN:V]V86[A('!R[6QO:&$@8F]L82!S=&EA:&YU=.$`3F]V96UB97(`
MR.US;&\`4&_H970@>FYA:V]V`%!OZ&5T('-TY7!C;W8`4&_H970@;65S:6%C
M;W8L('!OZ&%S(&MT;W+]8V@@<V$@;6%J^B!P;VYE8VAANR!S=&%RZ2!N86QI
M;FMO=F%NZ2!P<NUL;VAY('!R:2!M97-AZ&YO;2!M87IA;NTN`%!OZ&5T('-T
M87+]8V@@<')I9>AI;FMO=B!O9&]S;&%N96H@<&^Y='DL(&MT;W+I('-A(&UA
M:OH@<&]N96-H8;L@<')I(&UE<V'H;F]M(&UA>F%N[2X`4&_H970@<FEA9&MO
M=@!0<F4@86MT=6%L:7KA8VEU('IO>FYA;74@<'+M:F5M8V]V(&YE8F]L:2"Y
M<&5C:69I:V]V86[I(.CM<VQA+@!/2P!!3$5"3P!/8FIE:W0`075T;W(@;V)J
M96MT=0!/<VUIZ&MO=OT`3VMT\V)E<@!&:6QT97(@;F$@;F%DX79K>0!0<F%C
M;W9I<VMO`%-T87+I(&$@;F]VZ2!H97-L;R!M=7-I82!B>;L@;V1L:;ENZ2X`
M4W1A<ND@<W!RX79Y`%-T87+I(&AE<VQO`%-T87+I(&AE<VQO(&YE8F]L;R!Z
M861A;ND@<W!RX79N92X`4W1A<ND@<')I9>AI;FMY(&]D;W-L86[]8V@@<W!R
MX78@<V$@=GEM87KA=F%J^BX`3VWA;@!)8F$@24U!4"!S97)V97)Y('!O9'!O
M<G5J^B!Z9&EEM6%NZ2!P<FEEZ&EN:WDN`%IO8G)A>FF[(&QE;B!P<FEEZ&EN
M:WD@<R!N97!R9>CM=&%N_6UI('-P<N%V86UI/P!)8F$@=7+AOFQI=ND@9F]R
M='5N>0!*92!P<NUP=7-T;N$@:6)A(&IE9&YA(&4M;6%I;&]VX2!A9')E<V$N
M`%!R92!T^G1O(&%K8VEU(&)Y(&UA;"!B>;L@=GEB<F%T_2!I8F$@:F5D96X@
M<')I9>AI;F]K+@!6;&%S=&[M:V$@86QE8F\@<'+A=F$@=FQA<W1N[6MA('!R
M92!Z9&EEM6%N_2!O8FIE:W0@;?2^92!Z;65N:;L@:6)A('9L87-T;NUK(&%L
M96)O('-Y<W3I;6]V_2!A9&UI;FES='+A=&]R`$]T=F]R:;L@7W!R:67H:6YO
M:P!/='9O<FF[('8@;F]V;VT@;VMN90!#:'EB82!/<&5N4U-,.B!N97!O9&%R
M:6QO('-A('KM<VMANR#Z9&%J92!Z('!O9'#M<V%N96H@Z&%S=&D@4R]-24U%
M+@!/='9O<F5N_2!P<FEEZ&EN;VL`3W1V;W)INR!T^G1O(&QI;FMU('8@;F]V
M;VT@;VMN90!/<&5R8>AN_2!S>7-TZ6T`3F5P;W9I;F[](/KH87-T;NUK`$YA
M<W1A=F5N:6$`3F%S=&%V96YI82`E<P!:;W)A9&5N_2!Z;WIN86T`3W)G86YI
M>N%C:6$`3W)G86YI>F'H;N$@:F5D;F]T:V$`3W)G86YI>F]V86YI90!0]'9O
M9&[A(+EA8FSS;F$@87!L:6OA8VEE`%#T=F]D;ND@N6%B;/-N>2!V("5S.@!)
M;ND`SV%LN6EE(&EN9F]R;>%C:64`26[I('!ON71O=ND@^NAT>0!);ND@;F%S
M=&%V96YI80!0<N%V82!V;&%S=&[M:V$`4$%-(&%U=&5N=&EF:6OA8VEA(&YI
M92!J92!D;W-T=7!NX2X`4$5!4CI-86EL(&)A8VME;F0`4$=0`$1I9VETX6QN
M>2!P;V1P:7,@4$=0`%IAN6EF<F]V8;L@<W!RX79U('!O;6]C;W4@4$=0`-ID
M86IE('IAN6EF<F]V86[I('!O;6]C;W4@4$=0`$-H>6)A(%!'4#H@`$-H>6)A
M(%!'4#H@<')E(&]S;V)N_2!P<FEVX71N>2!KM?KH('1R96)A('IA9&&[(&AE
M<VQO+@!.87-T879E;FEA(%!'4`!:863A=F%N:64@:&5S;&$@<')E(%!'4`!0
M<F4@<&]D<&]R=2!O<V]B;NEH;R!KM?KH;W;I:&\@<.%R=2!01U`@;75S[71E
M(&UANR!B97IP9>ANZ2!P<FEP;VIE;FEE("AH='1P<RDN`%!'4"!V97)E:F[]
M(&NU^N@`5&5X="!01U`@=F5R96INZ6AO(&NU^NAA`%9E<F5J;OT@4$=0(&NU
M^N@@<')E("(E<R`H)7,I(B!B;VP@^G-P9;EN92!P<FED86[]+@!697)E:F[]
M(%!'4"!KM?KH('!R92`B)7,B(&)O;"#Z<W!EN6YE('9Y;6%Z86[]+@!$871A
M8N%Z82!V97)E:F[]8V@@4$=0(&NU^NAO=@!0;V1P[7-ANR!S<'+A=G4@<&]M
M;V-O=2!01U``4&]D<.US8;LO>F&Y:69R;W9ANR!S<'+A=G4@<&]M;V-O=2!0
M1U``VF1A:F4@<&]D<.US86[I+WIAN6EF<F]V86[I('!O;6]C;W4@4$=0`%!R
M:7;A=&YY(%!'4"!KM?KH(&)O;"#Z<W!EN6YE('!R:61A;OTN`%9E<F5J;OT@
M4$=0(&NU^N@@8F]L(/IS<&6Y;F4@<')I9&%N_2X`3F$@=&]M=&\@<WES=.EM
M92!J92!P;V1P;W)A(%!'4"!Z86OA>F%NX2X`4&]D<&]R82!01U`@;FEE(&IE
M(&UO;65N=.%L;F4@86MT:79O=F%NX2P@=&%KOF4@;F5M;[YN;R!O=F5R:;L@
M9&EG:73A;&YY('!O9'!I<RX`4&]D<&]R82!01U`@;FEE(&IE(&UO;65N=.%L
M;F4@86MT:79O=F%NX2P@=&%KOF4@;F5M;[YN;R!D9;EI9G)O=F&[('-P<N%V
M=2X`4&]D<&]R82!01U`@=GF^861U:F4@<&]UOFET:64@=GES:V%K;W9A8^UC
M:"!O:VEE;BX@06L@5N&Y('!R96AL:6%D8>@@;6]M96YTX6QN92!B;&]K=6IE
M('9Y<VMA:V]V86-I92!O:V[A+"!M=7/M=&4@=&]T;R!N87-T879E;FEE('IM
M96YINRP@:6YA:R!N96)U9&4@4$=0(&9U;F=O=F&[('-P<N%V;F4N`%!(4"!K
M\V0`4$A0(%-H96QL`%!O<&]L=61N[2"U86AK_2!DX;[O`%!O<&]L=61N[2!P
M<F5HX6YK>0!0;W!O;'5D;NT@<VYEOF5N:64`4&]P;VQU9&[M('-N96AO=ND@
M<')E:.%N:WD`4&]P;VQU9&[M('-N9;YE;FEE`%!O<&]L=61N[2!B^G)K>0!0
M3U`S`%!/4#,@*$%U=&]M871I8VMY(&1E=&5K;W9ANR!P<F]T;VMO;'DI`%!/
M4#,@8V5Z(%-33`!03U`S(&-E>B!34TP@*&-E<G1I9FEKX70@<&]D<.US86[]
M('-A;?UM('-E8F]U*0!03U`S(&-E>B!34TP@*&-E<G1I9FEKX70@<&]D<.US
M86[]('-A;?UM('-E8F]U*0!03U`S+"!B97H@5$Q3`$-H_6)A(')O>KGM<F5N
M:64@4$]325@`4%](4"!3:&5L;`!6>7!L;F5N:64`4W1R86YA("5D('H@)60`
M4W1RX6YK82!S('!R=F]U(&YE<')EZ.UT86YO=2!S<'+A=F]U`%-T<N%N:V$@
M<R!P;W-L961N;W4@;F5P<F7H[71A;F]U('-P<N%V;W4`4&%K:7-T86X`4&%L
M875S:^D@;W-T<F]V>0!086QE<W3M;G-K92#Z>F5M:64`4&%N86UA`%!A<'5A
M($YO=N$@1W5I;F5A`%!A<F%G=6%Y`,AA<[LH:2D`R&EA<W1OZ&YE(&]B;&'H
M;F\`2&5S;&\@<')E(&NU^N@`2&5S;&\@<')E(&NU^N@@*'IN;W9U*0!(97-L
M;R!B;VQO(/IS<&6Y;F4@;V1S='+A;F5NZ2!Z('!A;>1T:2X`2&5S;&\@<')E
M(&NU^N@Z`$AE<VSA('!R92!KM?KH92!N96WTOG4@8GF[('!RX7ID;F4`2&5S
M;.$@;FEE('/Z(')O=FYA:^D`2&5S;&\`2&5S;&\@8F]L;R#Z<W!EN6YE('IM
M96YE;NDN`$YE<W!RX79N92!H97-L;P!0<F4@875T96YT:69I:^%C:74@4D%$
M2553(&IE('9YOF%D;W9A;ND@:&5S;&\N`$AE<VQO(',@<&]T=G)D96[M;0!(
M97-L;SH`2&5S;&\Z(`!(97-LX2!M=7-I82!B>;L@<F]V;F%KZ2X`5FQOOFF[
M`%9L;[YINR!Z;R!S8VARX6YK>0!#97-T80!0<F5B:65H86KZ8V4@<F5G:7-T
M<N%C:64Z`*5U9&EA`%!E<F-E;G0`5GEK;VYANR!O<&5RX6-I92#Z9'*^8GD`
M5GEK;VYANR!O<&5RX6-I92#Z9'*^8GD@<')I('!R:6ALX7-E;NT_`%!RX79O
M`%!RX79O("(E<R(@;F5B;VQO('9Y;6%Z86[I+@!0<NUS='5P('IA;6EE=&YU
M=/T`4'+A=F$`061M:6YI<W1RX6-I82!P<N%V`%!RX79A('!R92!T;VAT;R!P
M;W6^[79A=&6U82!N96UOOFYO('IM96YINRX`3W-O8F[I`$]S;V)NZ2!I;F9O
M<FWA8VEE`$]S;V)N_2!01U`@:[7ZZ&]V_2!PX7(@8F]L(/IS<&6Y;F4@=GEG
M96YE<F]V86[]+@!/<V]B;ND@4$=0(&NU^NAE(&)O;&D@^G-P9;EN92!V>6UA
M>F%NZ2X`3W-O8F[I(%,O34E-12!C97)T:69I:^%T>2!.14)/3$D@:6UP;W)T
M;W9A;NDZ(`!/<V]B;ND@4R]-24U%(&NU^NAE(&)O;&D@^G-P9;EN92!V>6UA
M>F%NZ2X`4&5R=0!$;VWA8V4@>G9I97)A=.$`1FEL:7#M;GD`5&5L96;S;@!&
M;W1O9W)A9FEE`%!I=&-A:7)N`$)O9&]V`%9K;&%D8;L@5F&Y=2!S:6=N873Z
M<G4@<')E9"!O9'!O=F5D92!A('!R97!O<VQA;OH@<&^Y='4_`%IO8G)A>FF[
M('1E>'1O=OH@=F5R>FEU('-P<N%V>0!0<F5H<F&[('IV=6L@<')I('!R[6-H
M;V1E(&YO=F5J('!ON71Y/R`@5&]T;R!V>;YA9'5J92!P;V1P;W)U(%;AN6AO
M('!R96AL:6%D8>AA('!R92!V;&^^96[I('IV=6MO=ND@<_IB;W)Y+B`@3F$@
M<&QA=&9O<FWA8V@@5VEN9&]W<R!A($UA8R!S^B!T;R!T86MM97(@=KEE=&MY
M+"!N82!I;OUC:"!P;&%T9F]R;>%C:"!B=61E=&4@<&]T<F5B;W9ANR!P;'5G
M:6XN`$ML:6MN:71E('!R;W/M;2!D;R!N96IA:V5J(&)U;FMY`%!O='9R[W1E
M('!R;W/M;2P@OF4@8VAC971E(&]D<W1RX6YINR!T96YT;R!E;&5M96YT.@!0
M;W1V<N]T92!P<F]S[6TL(+YE(&-H8V5T92!O9'-T<N%N:;L@;&EN:W4@>B!T
M;VAT;R!E;&5M96YT=2X`6F%D86IT92!P<F]S[6T@;65S:6%C(&$@<F]K+@!:
M861A:G1E('!R;W/M;2!M96YO('!R92!N;W;Z(&MA=&5G\W)I=3H`6F%D86IT
M92!P<F]S[6T@;65N;R!P<F4@;F]V_2!P<FEEZ&EN;VLZ`%IA9&%J=&4@<')O
M<^UM('!L871N^B!)4"!A9')E<W4N`%IA9&%J=&4@<')O<^UM('!L871N_2!D
MX71U;2P@<VMO;G1R;VQU:G1E('!OZ&5T(&1N[2!V(&UE<VEA8VDN`%IA9&%J
M=&4@<')O<^UM('!L871N_2#H87,N`%IA9&%J=&4@<')O<^UM(&UE;F\@<')E
M(&YO=OT@<')I9>AI;F]K.@!:861A:G1E('!R;W/M;2!N;W;I(&UE;F\Z`%IA
M9&%J=&4@<')O<^UM(&AE<VQO('!R92!6X;D@<')I=N%T;GD@4$=0(&NU^N@N
M($AE<VQO(&UU<^UT92!Z861ANR!I8F$@<F%Z(&$@<&QA=.T@<&_H87,@8V5L
M96H@<F5LX6-I92`E<RX`6F%D86IT92!P<F]S[6T@:&5S;&\@<')E(%;AN2!P
M<FEVX71N>2!3+TU)344@:[7ZZ"X@2&5S;&\@;75S[71E('IA9&&[(&EB82!R
M87H@82!P;&%T[2!P;^AA<R!C96QE:B!R96SA8VEE("5S+@!0<F]S[6T@<')I
M:&SA<W1E('-A('IN;W9U+"!A:R!C:&-E=&4@<&]K<F'H;W9ANR!V('#M<V%N
M[2!S<'+A=GDN($%K($Y%4$]5KLU6051%(&-O;VMI97,@02!P[;EE=&4@<W!R
MX79Y('9O('9Y<VMA:V]V86/M8V@@;VMNX6-H+"!B=61E=&4@<V$@;75S:66[
M('IN;W9U('!R:6ALX7-INR!A:B!D;R!H;&%V;NEH;R!O:VYA+B!4;W1O('-L
M^KYI(&YA(&]C:')A;G4@<')E9"#Z=&_H;NUK;6DL(&MT;W+M(&)Y('IN976^
M:6QI(&ED96YT:69I:V'H;ND@Z.US;&\@5F&Y96H@<F5LX6-I92X@SV%K=6IE
M;64@>F$@<&]C:&]P96YI92X`4')O<^UM('5V9>]T92!Z:')N=71I92!P<F]B
M;.EM=2X`4')O<^UM('IA9&%J=&4@<W9O:F4@:&5S;&\`4')O<^UM('IA9&%J
M=&4@<W9O:F4@<&]UONUV871EM7-KZ2!M96YO(&$@:&5S;&\`4')O<^UM('IA
M9&%J=&4@<W9O:F4@<&]UONUV871EM7-KZ2!M96YO`%!R9>CM=&%J=&4@<VD@
M<')O<^UM(&YA<VQE9'5J^F-I('1E>'0N($U54\U412!S^FAL87-INR!S('!O
M9&UI96YK86UI('!O=;[M=F%N:6$@<WES=.EM=2X`4')O<^UM(')O>FSZN71I
MNR!N96IE9&YO>FYAZ&[I(&$@;F5P;&%T;ND@861R97-Y+@!0<F5D('9Y:V]N
M86[M;2!A:V-I92!V>6)E<G1E('!R;W/M;2!P<FEEZ&EN;VLN`%!R;W/M;2!V
M>6)E<G1E(&%S<&_R(&IE9&5N('!R:67H:6YO:R!N82!HM6%D86YI92X`4')O
M<^UM('9Y8F5R=&4@:6)A(&IE9&5N('!R:67H:6YO:R!P<F4@=/IT;R!O<&5R
MX6-I=2X`4')O<^UM(&]Z;F'H=&4@86QE8F\@=7!R879T92!V('!R:65S=&]R
M92!V<')A=F\Z`%IA9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S
M<FEU.@!0;[5S:V\`4&]L:71I:V$`06YK971Y`%!O<G1U9V%L<VMO`%5M:65S
M=&YE;FEE('1O:'1O(&]B<N%Z:W4`56UI97-T;F5N:64@=&5J=&\@=&%B=;5K
M>0!/9&]S;&&[(&1O('1O:'1O('!R:67H:6YK82`H;F5V>6YU8W5J92!)34%0
M*0!0;W=E<F5D(&)Y($AO<F1E`$]D9&5L:;L@<VEG;F%T^G)U(&]D('-P<N%V
M>2!P;VULZ&MA;6D@*"<M+2`G*3\`6G+AOFMY('IA('!O<VQE9&[]8V@@)7,@
M:&]D[6XZ(`!0<F%V9&5P;V1O8FYO<[L\8G(@+SYZ<N&^;VL`3F%S=&%V96YI
M82!B;VQI(/IS<&6Y;F4@86MT=6%L:7IO=F%NZ2X`4')E9G-?;&1A<#H@<&^^
M861O=F%NZ2!R;WJY[7)E;FEE($Q$05`@;F5B;VQO(&[A:F1E;NDN`%!R969S
M7W-E<W-I;VXZ('!OOF%D;W9A;ND@<F]ZN>UR96YI92!S97-S:6]N(&YE8F]L
M;R!NX6ID96[I+@!4;&%K`%1L86L@;F$@^G)O=FYI(&UO<F$Z(`!4;&%K.B``
M56OAOFMA`%IO8G)A>FF[('5KX;YK=2!O8G+A>FMU('8@;F]V;VT@;VMN90!0
M<F5D8VCA9'IA:OIC82!S<'+A=F$`4')E9&-HX61Z86KZ8V$@<W1RX6YK80!0
M<F5D8VCA9'IA:OIC92!N87-T879E;FEA`%1L8>AINP!6>71L8>AINR!D;VMU
M;65N=`!0<FEO<FET80!0<FEVX71N>2!KM?KH`$AE<VQO(&L@<')I=N%T;F5M
M=2!KM?KH=0!0<F]B;.EM`%!O<&ES('!R;V)LZ6UU`%!R;VIE:W1Y`%#]=&&[
M('-A('IA:V&^9/UM('!R:2!P;W-I96QA;NT@<'+M;&]H>3L@N71A;F1A<F1N
M92!.244`4/UT8;L@<V$@>F%K8;YD_6T@<')I('!O<VEE;&%N[2!P<NUL;VAY
M.R"Y=&%N9&%R9&YE(,%.3P!6_7IV82!N82!Z861A;FEE('1E>'1U`%!R;W1O
M:V]L.@!697)E:F[](&NU^N@`06QG;W)I=&UU<R!V97)E:F[I:&\@:[7ZZ&$`
M26YF;W)MX6-I92!O('9E<F5J;F]M(&NU^NAI`%!O9'!O<F$@4$=0(&NU^NAO
M=OUC:"!S97)V97)O=B!B;VQA('IA:^%Z86[A+@!697)E:F[]+W!R:7;A=&YY
M(&NU^NAO=OT@<.%R(&YE8F]L(/IS<&6Y;F4@=GEG96YE<F]V86[]+@!0;W)T
M;W)I:V\`3U]D<W1RX6YINR!V>6UA>F%NZ0!/9'-T<N%N:;L@=GEM87IA;ND`
M5GEP<N%Z9&YINR!P<FEEZ&EN;VL@*'!R:67H:6YK>2D`06MO(.AA<W1O('9Y
M<'+A>F1N:;L@2_2Y.@!/9'-T<N%N:;L@>B!+;[EA('-P<N%V>2!S=&%RN6EE
M(&%K;R!T96YT;R!P;^AE="!D;NTN`$]D<W1RX6YINR!S=&%RZ2!S<'+A=GD@
M>B!+;[EA/P!/9'-T<F'R=6IE;2`E9"!S<'+A=B!Z($MON6$N`$]D<W1R8?)U
M:F5M(#$@<W!RX79U('H@2V^Y82X`2V%T87(`1&]T87H`2W;S=&$`4W1A=B!K
M=O-T>3H@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*0!3=&%V(&MV\W1Y.B`E
M+C)F34(@+R!"15H@3T)-141:14Y)00!3=&%V(&MV\W1Y.B!"15H@3T)-141:
M14Y)00!#:73A="`E9CH`4E-!('9E<F5J;OT@:[7ZZ"`H)60@8FET;W8I`%!R
M97#M;F'H(',@=OUB97)O;0!$X;[O`%+A;F\@9.&^[P!.97-K]'(@9.&^[P!$
M8;[O;W;I('!R96CA;FMY`$3AON\@<V\@<VYE:&]M`$3AON\@<')E8VCA9'IA
M:OIC:2!V('-N9;YE;FEE`$[A:&]D;N$@9F]R='5N80!0;VUE<@#([71ANP#(
M[71ANR!S<'+A=GD`3F%O>F%J('9Y;6%Z8;L@)7,_(%3Z=&\@;W!E<N%C:74@
M;F5M;[YN;R!V<N%T:;L@<W#DNRX`3F%O>F%J('9Y;6%Z8;L@<&]UONUV871E
MM7-KZ2#Z9&%J92!P<F4@<&]UONUV871EM6$@)7,_(%3Z=&\@;W!E<N%C:74@
M;F5M;[YN;R!V<N%T:;L@<W#DNRX`4')I:F%TZ2!D\F$`4')I:F%TZ2!O9`!0
M<FEJ873I(&1O`%!R95]S;65R;W9ANP!0<F5S;65R;W9ANP!0<F5S;65R;W9A
MNR!S<'+A=G4`4')E<VUE<F]V8;L@=/IT;R!S<'+A=G4`4')E<VUE<F]V86YI
M92!Z;'EH86QO+@!6<N%T:2!S<.2[(%9AN74@<&]S;&5D;OH@86MC:74`3V)N
M;W9INP!/8FYO=FF[(&5L96UE;G1Y(&1Y;F%M:6-KZ6AO(&UE;G4Z`$]B;F]V
M:;L@>F]B<F%Z96YI92!P<FEEZ&EN:V]V.@!/8FYO=FF[('IO8G)A>F5N:64@
M<&]R=.%L=3H`4F5G=6SA<FYY(';]<F%Z`%!R96AL:6%D8>@@=GJ[86AO=@!/
M8FYO=FF[`$]B;F]V:;L@>F]B<F%Z96YI90!0;W-T<F5H>0!P86WD=&&[('-I
M(&EN9F]R;>%C:64@;R!Z86YE<'+A>F1N96YO<W1I+@!086WD=&&[('-I('!O
M<VQE9&[I('IO8G)A>F5N:64`5GID:6%L96[A('-C:'+A;FMA.@!6>F1I86QE
M;ND@<V5R=F5R>0!6>F1I86QE;N$@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`3V1S='+A;FF[`$]D<W1RX6YINR!B;&]K`$]D<W1RX6YI
MNR!P;VQE('H@<')E:+5A9.%V86YI80!/9'-T<N%N:;L@<W3E<&5C`$]D<W1R
MX6YINR!F;W)MX71O=F%N:64`3V1S='+A;FF[('#A<@!/9'-T<N%N:;L@=6QO
MOF5N_2!S:W)I<'0@>B!D;^AA<V[I:&\@<')I9>AI;FMA(&YA('-E<G9E<FDN
M`$]D;V)R8;L@>F1R;VH`3V1S='+A;FF[`$]D<W1RX6YINR!T96YT;R!B;V0@
M>B!D;VMU;65N='4`3V1S='+A;FF[('!O=;[M=F%T9;5A`$]D<W1RX6YINR!P
M;W6^[79A=&6U83H@)7,`4')E;65N;W9ANR!P<FEEZ&EN;VLH<')I9>AI;FMY
M*0!0<F5M96YO=F&[('!R:67H:6YO:R!O9&]S;&%N96H@<&^Y='D@;F$@>F'H
M:6%T:W4@;65S:6%C83\`4')E;65N;W9A;FEE("(E<R(@;F$@(B5S(B!Z;'EH
M86QO+B``3V1P;W9E9&&[(&1O(&4M;6%I;&]V96H@7VMO;F9E<F5N8VEE`%!R
M97#M<V&[(&YA.@!/9'!O=F5D8;L`3V1P;W9E[R!B;VQA(&]D;W-L86[A+@!/
M9'!O=F5D8;L@=KEE=&O];0!/9'!O=F5D8;L@=KEE=&O];3H`3V1P;W9E9&&[
M(&1O(&4M;6%I;&]V96H@:V]N9F5R96YC:64`3V1P;W9E9&&[(&1O(&4M;6%I
M;&]V96H@:V]N9F5R96YC:64Z`$]D<&]V961ANR!?=KEE=&O];0!/9'!O=F5D
M8;L@<V\@<W!RX79O=3H@3F5P;V1P;W)O=F%NZ0!/9'!O=F5D8;L@<W!RX79O
M=2!O('IA;F5P<N%Z9&YE;F]S=&D@;F$@;F%S;&5D=6KZ8V4@,B!M97-I86-E
M+@!/9'!O=F5D8;L@<W!RX79O=2!S('!OOF%D;W9A;F]U(&EN9F]R;>%C:6]U
M(&\@>F%N97!RX7ID;F5N;W-T:2X`3V1P;W9E9&&[`$]D<&]V961ANSH@`$]D
M<&]V961ANSH`3VALX7-INR!A:V\@;F6Y:V]D;OH@<&^Y='4`3VALX7-INR!A
M:V\@;F5V>;YI861A;OH@<&^Y='4`5GF^:6%D8;L@<VD@<W!RX79U(&\@<%]R
M9>CM=&%N[0!.82!P;[YI861A=FMU(&YE8F]L;R!M;[YNZ2!O9'!O=F5D8;LN
M($[A=G)A=&]V_2!K\V0@8VAY8GDZ(`!6>;YA9&]V8;L@<W!RX79U(&\@<')E
MZ.UT86[M/P!0;[YA9&]V86[A('-P<N%V82!N96)O;&$@;N%J9&5NX2X`4&^^
M861O=F%N^B!S;'6^8G4@<V$@;F5P;V1A<FEL;R!NX6ISNRX`5B!K;VYF:6=U
M<N%C:6D@)7,@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQO
MOFMA("(E<R(`5B!K;VYF:6=U<N%C:6D@5D93(&YI92!J92"Y<&5C:69I:V]V
M86[A('!OOF%D;W9A;N$@<&]L;[YK82`B)7,B`%8@:V]N9FEG=7+A8VEI(&YI
M92!J92"Y<&5C:69I:V]V86[A('!OOF%D;W9A;N$@<&]L;[YK82`B)7,B`%!O
M=FEN;ND@<&]L90!0;[YA9&]V86[](/KH87-T;NUK`%9Y;6%Z8;L@9F]R;75L
MX7(`3V)N;W9INR!H97-L;P!/8FYO=FF[(%9AN64@:&5S;&\`4W1A=B#ZZ&%S
M=&[M:V$@8F]L(&%K='5A;&EZ;W9A;OTN`$]B;F]V:;L@<&]S;&5D;OT@9&]T
M87H`5OUS;&5D:WD`3V)N;W9INP!0;VMR8>AO=F&[('8@<F5LX6-I:0!.X79R
M870@9&\@;65N=2`B4.US86YI92!S<'+A=GDB`$[A=G)A="!K('.[86AO=F%N
M:74@<&^Y='D`3N%V<F%T(&YA(&YA<W1A=F5N:6$`5G+A=&F[('-A(&YA('IO
M>FYA;2!S<'+A=B!P;R!V>6UA>F%N[2P@<')E<W5N92!A;&5B;R!K;W#M<F]V
M86[M('-P<N%V>3\`6F%D86IT92!N;W;I(&AE<VQO`%)E=6YI;VX`5G+A=&F[
M(&MO;F9I9W5RX6-I=0!.87-T879E;FEA(')O>KGM<F5NZ6AO('1E>'1O=NEH
M;R!E9&ET;W)U`$CA9&%N:WD`5G!R879O`$AL879IZ&MA('9P<F%V;P!(;V1N
M;W1Y('9P<F%V;P!6;&%S=&YO<W1I(%]R:6%D:V$N+BX`4F]L80!2=6UU;G-K
M;P!/=&_H:;L@;R`Q.#``3W1OZ&F[(':U879O`$]T;^AINR!V<')A=F\`5FQA
M<W1N;W-T:2!R:6%D:V$`5FQA<W1N;W-T:2!R:6%D:V$`4FEA9&MY.@#(:6%R
M>0#(:6%R>2!S82!Z;V)R87II82!M961Z:2!VN65T:_UM:2!R:6%D:V%M:2!A
M('-TY7!C86UI`,AI87)Y('-A('IO8G)A>FEA(&EB82!M961Z:2!S=.5P8V%M
M:0#(:6%R>2!S82!Z;V)R87II82!I8F$@;65D>FD@<FEA9&MA;6D`4W!U<W1I
MNP!2=7-KX2!F961E<N%C:6$`4G=A;F1A`%,O34E-10!3+TU)344@:W)Y<'1O
M9W)A9FEC:_T@<&]D<&ES`%IAN6EF<F]V8;L@<W!RX79U('!O;6]C;W4@4R]-
M24U%`%-P<N%V82!Z8;EI9G)O=F%NX2!P;VUO8V]U(%,O34E-10!#:'EB82!3
M+TU)344Z(`!#:'EB82!3+TU)344Z('!R92!O<V]B;OT@<')I=N%T;GD@:[7Z
MZ"!T<F5B82!Z861ANR!H97-L;RX`3F%S=&%V96YI82!3+TU)344`6F%DX79A
M;FEE(&AE<VQA('!R92!3+TU)344`4')E('!O9'!O<G4@;W-O8F[I:&\@:[7Z
MZ&]VZ6AO('#A<G4@4R]-24U%(&UU<^UT92!M8;L@8F5Z<&7H;ND@<')I<&]J
M96YI92`H:'1T<',I+@!697)E:F[](%,O34E-12!KM?KH('!R92`B)7,B(&)O
M;"#Z<W!EN6YE('9Y;6%Z86[]+@!697)E:F[](%,O34E-12!KM?KH(&)O;"#Z
M<W!EN6YE('!R:61A;OTN`$1A=&%BX7IA('9E<F5J;OUC:"!3+TU)344@:[7Z
MZ&]V`$NU^NAO=OT@<.%R(%,O34E-12!B;VP@^G-P9;EN92!P<FED86[]+@!0
M;V1P[7-ANR!S<'+A=G4@<&]M;V-O=2!3+TU)344`4&]D<.US8;LO>F&Y:69R
M;W9ANR!S<'+A=G4@<&]M;V-O=2!3+TU)344`3F$@=&]M=&\@<WES=.EM92!J
M92!P;V1P;W)A(%,O34E-12!J92!Z86OA>F%NX2X`4&]D<&]R82!3+TU)344@
M;FEE(&IE(&UO;65N=.%L;F4@86MT:79O=F%NX2P@=&%KOF4@;F5M;[YN;R!D
M9;EI9G)O=F&[('-P<N%V=2X`4&]D<&]R82!3+TU)344@;FEE(&IE(&UO;65N
M=.%L;F4@86MT:79O=F%NX2P@=&%KOF4@;V)S86@@<&]D<.US86YE:B!S<'+A
M=GD@;F5M;[YN;R!Z;V)R87IINRX`4&]D<&]R82!3+TU)344@;FEE(&IE(&UO
M;65N=.%L;F4@86MT:79O=F%NX2P@=&%KOF4@;F5M;[YN;R!O=F5R:;L@9&EG
M:73A;&YY('!O9'!I<RX`4&]D<&]R82!3+TU)344@=GF^861U:F4@<&]UOFET
M:64@=GES:V%K;W9A8^UC:"!O:VEE;BX@($%K(%;AN2!P<F5H;&EA9&'H(&UO
M;65N=.%L;F4@8FQO:W5J92!V>7-K86MO=F%C:64@;VMNX2P@;75S[71E('1O
M=&\@;F%S=&%V96YI92!Z;65N:;LL(&EN86L@;F5B=61E(%,O34E-12!F=6YG
M;W9ANR!S<'+A=FYE+@!305-,(&%U=&5N=&EF:6OA8VEA(&YI92!J92!D;W-T
M=7!NX2X`4&]S:65L86YI92!335,`4TU44`!344P@4VAE;&P`4U%,('!R[6MA
M>B!P<F4@:+5A9&%N:64@:&]D;O1T`%-32`#:4U!%0T@`4U]13"!3:&5L;`!0
M7W)E9&UE=`!3;P!57VQOOFF[(&OS<&EU(&1O(`!5;&^^:;L@7V%K;P!3=N1T
MX2!(96QE;F$`4W;D=/T@2VET=',@82!.979I<P!3=N1TX2!,=6-I80!3=BX@
M4&EE<G)E(&$@36EQ=65L;VX`4W;D=/T@5FEN8V5N="!A($=R96YA9&EN>0!4
M96X@:7-T_2!RX6UE8R`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O
M;64@82!0<FEN8VEP90!3871E;&ET;OT@<&]S:WET;W9A=&6U`%-A=61S:^$@
M07+A8FEA`%5L;[YINP!5;&^^:;L@(B5S(@!5;&^^:;L@)7,`56QOOFF[('!R
M[6QO:'D@<V\@<W!RX79O=2!D;R!P<FEEZ&EN:V$@;V1O<VQA;F5J('!ON71Y
M/P!5;&^^:;L@:V]N8V5P=`!5;&^^:;L@;V)RX7IO:P!5;&^^:;L@;V)RX7IO
M:R!D;R!G86SI<FEE`%5L;[YINR!N87-T879E;FEA`%5L;[YINR"Y86)L\VYU
M`%5L;[YINR!?:V]N8V5P=`!5;&^^:;L@86MO`%5L;[YINR!K;VYC97!T>2!A
M:V\@;F5P<F7H[71A;ND_`%5L;[YINR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A
M8VEU(&%K;R!02%`@<VMR:7!T(&1O(&1OZ&%S;NEH;R!P<FEEZ&EN:V$@5N&Y
M:&\@<V5R=F5R82X`56ML861ANR!P<NUJ96UC;W8@875T;VUA=&EC:WD@9&\@
MN71A;F1A<F1NZ6AO(&%D<F5SX7)A(&MO;G1A:W1O=C\`56QOOFF[('9Y:+5A
M9.%V86YI92!A:V\@=FER='7A;&YY('!R:67H:6YO:S\`56QOOFF[(&]D;W-L
M86[Z('!ON71U/P!+;VYF:6=U<N%C:6$@)7,@8F]L82!U;&^^96[A+@!3:W)I
M<'0@;F$@=7!G<F%D92!N87-T879E;NT@8F]L('5L;[YE;OT@9&\Z("(E<R(N
M`%5K;&%D86YI92!K;VYC97!T=2!Z;'EH86QO+B!#:'EB83H@)7,`3VIE9&EN
M96SI(&+Z<FMY`%9E9&$`4')E:+5A9.%V8;L`4')E:+5A9.%V8;L@)7,`5GEH
MM6%DX79AZ&4`3F%S=&%V96YI82!HM6%D86YI80!6_7-L961O:R!HM6%D86YI
M80!0<F7H[71A;ND`5GEB<F&[`%9Y8F5R=&4@:6[](/KH970`5GEB97)T92!S
M^F)O<GD`5GEB97)T92!DX71U;0!6>6)E<G1E('!O;&4`5GEB97)T92!S:W5P
M:6YU(&YA('!R:61A;FEE`%9Y8F5R=&4@;F]VZ6AO('9L87-T;NUK80!6>6)E
M<G1E('-E<G9E<@!6>6)E<G1E(+EA8FSS;G4Z`%9Y8F5R=&4@<&]UONUV871E
MM6$@;F$@<')I9&%N:64`3F%S=&%V96YI92!A9')E<^%R;W8@<')E('!R:63A
M=F%N:64@82!V>6BU863A=F%N:64@861R:65S+@!/>FYAZ&F[(':Y971K;P!6
M>6)E<G1E(':Y971K>2!K;VUP;VYE;G1Y(&3A='5M=0!6>6)E<G1E(':Y971K
M>2!P;VQI82P@=B!K=&]R_6-H('-A(&WA(&BU861ANR!P<FD@9&]PY?)A;NT@
M861R:65S+@!6>6)E<G1E(/KH970`5GEB97)T92!O8FIE:W0`6G)UN6F[(&]Z
M;F'H96YI90!6>6)E<G1E('IN86MY+"!K=&]RZ2!P;W1R96)U:F5T92P@>B!O
M:VEE;F]K(&YIOKEI92X@4&]T;VT@:6-H(&WTOF5T92!S:V]P[7)O=F&[(&$@
M=FQOOFF[('H@=&5X=&]VZ6AO('!OM6$N`%9Y8F5R=&4@;V1D9;5O=F'H('9O
M(&9O<FWA=&4@9.%T=6UU.@!6>6)E<G1E(&9O<FWA="!DX71U;74Z`%9Y8F5R
M=&4@9V%LZ7)I=2P@9&\@:W1O<F5J('-A(&WA('5L;[YINR!O8G+A>F]K+@!6
M>6)E<G1E(&ED96YT:71U+"!K=&]R^B!C:&-E=&4@>FUE;FF[.@!6>6)E<G1E
M('1Y<"!E+6UA:6QO=NEH;R!S97)V97)A`%9Y8F5R=&4@;V1D9;5O=F'H('9O
M(&9O<FWA=&4@Z&%S=3H`5GEB97)T92!F;W)MX70@Z&%S=3H`5GEB97)T92!D
M=F4@>FAO9&[I('!O;&EA+@!6>6)E<G1E('-I(&9A<F5B;OH@<V-HZ6UU`%9Y
M8F5R=&4@:F%Z>6LZ`%9Y8G)A;ND@861R97/A<F4Z`$]D;W-L8;L@:[7ZZ"!N
M82!S97)V97(@=F5R96IN_6-H(&NU^NAO=@!/9&]S;&&[(&YA:FYO=KEI92!I
M;F9O<FWA8VEE`$]D;W-L8;L@<W!RX79U`%!O<VQANR!S<'+A=G4@;R!P<F]B
M;.EM90!0;W-L8;L@4TU3`$]D;W-L8;L@;WINX6UE;FEE(&\@<')EZ.UT86[M
M+"!A:R!H;R!V>;YA9'5J92!O9&]S:65L871EM3\`4V5N96=A;`!396YZ;W(Z
M(`!0<FEEZ&EN;VL@;V1O<VQA;F5J('!ON71Y`%!R:67H:6YO:R!O9&]S;&%N
M96H@<&^Y='DZ`%-E<'1E;6)E<@!3<F)S:V\@82#(:65R;F$@:&]R80!3Z7)I
M;W;I(.CM<VQO`%-E<G9E<@!);F9O<FWA8VEE(&\@<V5R=F5R:2!A('!R:67H
M:6YK;V-H`-ID86IE('IO('-E<G9E<F$@<_H@;F5S<'+A=FYE(&%L96)O(&YI
M92!S^B!D;W-T=7!NZ2X`4V5R=F5R.@!!9&UI;FES='+A8VEA('-E9&5N[0!0
M;&%T;F]SNR!)1"!S961E;FEA('9Y<'*Y86QA+@!3961E;FEA`$UN;[YI;F$@
M:&]D;O1T`$YA<W1A=G1E(&UOOFYO<W1I(&YA(&]B;F]V96YI92!6X;EH;R!H
M97-L82!A:R!H;R!Z86)U9&YE=&4N`$YA<W1A=F5N:6$@<')E<_IV86YI82!A
M(&UA>F%N:6$@<W!RX78N`$YA<W1A=FF[(&AL879IZ&MU(%@M4')I;W)I='D@
M<')I('#M<V%N[2!S<'+A=GD_`$YA<W1A=F5N:64@=GID:6%L96[]8V@@<V5R
M=F5R;W8L(&MU(&MT;W+];2!C:&-E=&4@<')I<W1U<&]V8;L@>B!6X;EH;R!P
M;W)TX6QU+@!6>6)E<G1E(&IA>GEK+"#H87-O=OH@>O-N=2!A(&YA<W1A=F5N
M:6$@9.%T=6UU+@!.87-T879E;FEE(&%P;&EKX6-I92!S</JYNV%N96H@<')I
M(+ET87)T92P@9F%R96)N96H@<V-HZ6UY+"!I;G1E<G9A;'4@;V)N;W9O=F%N
M:6$@<W1RX6YK>2!A(&EN_6-H('9L87-T;F]S=.T@>F]B<F%Z96YI82X`3F%S
M=&%V96YI90!3^B!D;W-T=7!NZ2!S:W)I<'1Y(&YA('5P9W)A9&4@;F%S=&%V
M96[M`$1O(/IV86AY('!R:6-HX61Z82!N:65K;[5K;R!L;VMA;.UT('!O;6]C
M;W4@<&%R86UE=')A.B``4V5Y8VAE;'D`6F1I9;5ANR!P<FEEZ&EN:WD`6F1I
M9;5ANR!P<FEEZ&EN:WD@<&^Y='D`6F1I9;5ANR!68;EE('!R:67H:6YK>2!P
M;[ET>2!S(&EN_6UI('!O=;[M=F%T9;5M:2X`4VAO<'!I;F<`2W+A=&MY('/Z
M:')N`$UA:OH@<V$@<')E(';DZ+EI;G4@;&EN:65K('9Y='9O<FF[('-K<F%T
M:V]VZ2!K;.%V97-Y/P!-86KZ(&)YNR!V9;5KZ2!B;&]K>2!C:71O=F%NZ6AO
M('1E>'1U(+ET86YD87)D;F4@>F]B<F%Z96[I(&%L96)O('-K<GETZ3\@3F%S
M=&%V96YI92!M]+YE(&)YNR!K961Y:V^U=F5K(&IE9&YO9'5C:&\@<')E<&YU
M=.DN`$UA:OH@<V$@=B!T96QE('-P<N%V('1Y<'4@=&5X="]P;&%I;B!HM6%D
M8;L@^F1A:F4@<')E(%!'4#\`3>$@<V$@;VMN;R!N82!P[7-A;FEE('-P<N%V
M>2!Z871V;W)INR!P;R!U;&^^96[M(&MO;F-E<'1U(#\`3>$@<V$@5N&Y('9E
M<F5J;OT@4$=0(&NU^N@@<')I<&]J:;L@:R!S<'+A=F%M/P!:;V)R87IINP!:
M;V)R87IINR!VN65T:WD@<')I9>AI;FMY`%IO8G)A>FF[(':Y971K>2!H;&%V
M:>AK>0!5:^%Z8;L@=GEM87IA;ND`6F]B<F%Z:;L@:6)A(&)EOF[I(&AL879I
MZ&MY`%IO8G)A>FF[(&EN9F]R;>%C:64@;R!E+6UA:6QO=F5J(&MO;F9E<F5N
M8VEI+@!:;V)R87IINR!I8F$@<')I:&SA<V5NZ2!P<FEEZ&EN:WD`56OA>F&[
M(&YE<')I:&SA<V5NZ0!:;V)R87IINR!I:V]N=2!N82!O9'-T<N%N96YI92!P
M<NUL;V@@>F\@<W!RX78_`%IO8G)A>FF[(')O>F1I96QY(&UE9'II('!RX79E
M('5L;[YE;F]U(&$@;F]V;W9Y9V5N97)O=F%N;W4@:V]N9FEG=7+A8VEO=2X`
M3>$@<V$@<')I('!R:6ALX7-E;NT@>F]B<F%Z:;L@Z&%S('!O<VQE9&[I:&\@
M<')I:&SA<V5N:6$_`%IO8G)A>FF[('9Y<W9E=&QI=FMY('8@>F]Z;F%M92!S
M<'+A=C\`6F]B<F%Z:;L@;6^^;F]SNR!N82!P;VYE8VAA;FEE(&]R:6=I;N%L
M=0!:;V)R87IINR!NX7-T<F]J(&YA(';]8F5R(&9A<FEE8@!:;V)R87IO=F&[
M('5KX;YK>2!I8F$@<')E(&YE<')EZ.UT86[I('-P<N%V>3\`6F]B<F%Z;W9A
MNR!U:^&^:WD@86MO('!O<&ES:WD_`%IO8G)A>FF[(&UE;G4@<')E(&]P97+A
M8VEE(',@=&%B=;5K86UI/P!:;V)R87IINR!M96YU("5S(&YA(+5A=F5J('-T
M<F%N93\`6F]B<F%Z:;L@:6MO;G4@;F$@<[MA:&]V86YI92!P;[ET>2!V(&UE
M;G4_`%IO8G)A>FF[(&]B<N%Z:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N
M;W.[86UI(&)U;FMY('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N
M;W.[86UI('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI
M(')I861K=2!T86)UM6MY`%IO8G)A>FF[(&EK;VYU(&9I;'1R;W8@=B!M96YU
M/P!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@;V)RX7IK=0!:;V)R
M87IINR!C96QK;W;]('!OZ&5T('-P<N%V('8@<')I9>AI;FMU/P!:;V)R87II
MNR!N86AR86[I`%!R96CA;FMY`%+A;F\@<')E:.%N:WD`3F5S:_1R('!R96CA
M;FMY`%IRX;YK>2!V(&]K;VSM`%IO8G)A>F5NZ0!:;65NN6F[`$YA:G!R=B!M
M=7/M=&4@>FUE;KEINR!A;&5B;R!P<F5S=6[ZNR!S=7-E9&[](&)L;VLH>2D`
M5F6U:V]?<[L`4VEE<G)A($QE;VYE`%IA<F5G:7-T<F]V8;L@<V$`4&]D<&ES
M`$%L9V]R:71M=7,@<&]D<&ES=0!0;V1P[7-A;ND`4VEN9V%P=7(`5F6U:V]S
MNP!0<F5S:V_H:;L@^F1ROF)U`%-L;W9E;G-K;P!3;&]V:6YS:V\`4VYEOF5N
M:64`4VYE:&]VX2!P<F5HX6YK80!3;F5H;W;I('!R96CA;FMY`%+A;F\@<VYE
M:&]VZ2!P<F5HX6YK>0!.97-K]'(@<VYE:&]VZ2!P<F5HX6YK>0!(Y6)K82!S
M;F5H=3H@`$UN;[YS='9O('9O9'D@96MV:79A;&5N=&[I('-N96AU.B``J6%L
M86WZ;F]V92!O<W1R;W9Y`%-O;>%L<VMO`%!I97-N92!A(&+A<VYE`%1R:65D
M:;L@<&]DM6$@Z&%S=2!P<NUC:&]D=0!4<FEE9&F[('!O9+5A(&3A='5M=0!4
M<FEE9&F[('!O9+5A(&%D<F5S>2!O9&]S:65L871EM6$`5')I961INR!P;V2U
M82!V9;5K;W-T:0!4<FEE9&F[('!O9+5A('!R961M971U`%1R:65D:;L@<&]D
MM6$@=FSA:VYA`%1R:65D:;L@<&]DM6$@861R97-Y('!R[6IE;6-U`%;]8F5R
M('-M97)U('1R:65D96YI80!:9')O:F]VX2!A9')E<V$`2G6^;N$@069R:6MA
M`$IUOF[A($=E;W)G:6$@82!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$IUOF[A
M('!O;&]G=;5A`$UE9'IE<F$@;65D>FD@<W5S961N_6UI(&)U;FMA;6D`365D
M>F5R82!M961Z:2!O8G-A:&]M(&$@;VMR86IO;2!B=6YK>0!/9&1EM6]V8>@`
M3V1S='5P`$]D<W1U<"!A('9Y<&QN96YI90"I<&%N:65L<VMO`%-P86T`4')I
M9>AI;F]K('!R92!S<&%M.@!6;&^^96YI92"Y<&5C:>%L;GEC:"!Z;F%K;W8`
MJ7!E8VGA;&YE('IN86MY`*EP96-IX6QN92!V:7)T=>%L;F4@<')I9>AI;FMY
M(&YE;6^^;F\@=7!R879INRX`2V]N=')O;&$@<')A=F]P:7-U`$MO;G1R;VQA
M('!R879O<&ES=0!+;VYT<F]L82!P<F%V;W!I<W4@=6MO;NAE;N$`4&_H970@
M8VC]8B!N82!S='+A;FMU('!R:2!K;VYT<F]L92!P<F%V;W!I<W4N`%)O>F1E
M;&F[(&)U;FMU`%)O>F1E;&F[('-TY7!E8P!2;WID96QINR!R:6%D;VL`J7!O
M<G1Y`%-R[2!,86YK80"I=&%N9&%R9&[I`%-T87(@5')E:P"I=&%R=`!0;^AI
M871OZ&[](')O:P"I=.%T(&%L96)O('!R;W9I;F-I80"I86)L\VYA`$UE;F\@
MN6%B;/-N>3H`5'EP(+EA8FSS;GDZ`*EA8FSS;F$Z`%-T878`1F]R;>%T('5L
M;[YE;FEA`$)Y9&QI<VMO`%!R9;EK<G1N=73I`%IO>FYA;2!R9;MA>F-O=@!/
M9'-T<N%N:;L@<'+M;&]H=0!/9'-T<N%N:;L@9&]MZ6YU('H@861R97-Y`$]D
M<W1RX6YINR!K;VYC92!R:6%D:V]V/P"I=/UL(%M#4U-=`$YE`%!?<F5D;65T
M`%!O9'!R:67H:6YO:R`B)7,B(&YE8F]L(&[A:F1E;OTN`%!R961M970`4&]L
M92!P<F5D;65T=0!/9&]S;&&[`%!OOFEA9&%V:V$@;F$@<')I9&%N:64@(B5S
M(B!D;R!S>7-TZ6UU(&)O;&$@;V1O<VQA;N$N($YE;?2^971E('-A('!R:6AL
MX7-INRP@:_UM(&YE8G5D92!68;EA('!OOFEA9&%V:V$@<V-H=N%L96[A+@!0
M<FEH;.%S:;L@<V$@9&\@<')I9>AI;FMA("AP<FEEZ&EN:V]V*0!$;VQN_2!I
M;F1E>`#:<W!E8V@`4')I9&%N:64@(B5S(B!D;R!S>7-TZ6UU(&)O;&\@^G-P
M9;ENZ2X`5GEM87IA;FEE(/ID86IO=B!Z;R!S>7-TZ6UU('!R92!P;W6^[79A
M=&6U82`B)7,B(&)O;&\@^G-P9;ENZ2X`5GEM87IA;FEE("(E<R(@8F]L;R#Z
M<W!EN6[I+@!6>6UA>F%N:64@(B5S(B!Z;R!S>7-TZ6UU(&)O;&\@^G-P9;EN
MZ2X`3N%V<F%T(&MU(&MO;F9I9W5RX6-I:2!B;VP@^G-P9;EN_2X@4')E('IO
M8G)A>F5N:64@>FUI96X@>FYO=G4@;F'H[71A:G1E('-T<N%N:W4N`%KA;&]H
M82!K;VYF:6=U<N%C:64@8F]L82!U;&^^96[A+@!:X6QOOF[](&MO;F9I9W5R
M8>AN_2!S^F)O<B`E<R!B;VP@^G-P9;EN92!U;&^^96[]+@!!:W1U86QI>N%C
M:6$@(B5S(B!B;VQA(/IS<&6Y;N$N`%KA<&ES("5S(&)O;"#Z<W!EN6[]`%-U
M9.%N`$[A=G)H>0!::')N=71I90!6_6-H;V0@<VQN:V$`6N%P860@<VQN:V$`
M4VQN9>AN;P!6_6-H;V0@<VQN:V$`5OUC:&]D+WKA<&%D('-L;FMA`%;]8VAO
M9"!S;&YK83H@`%KA<&%D('-L;FMA`%KA<&%D('-L;FMA.B``2&]R;OT@:6YD
M97@`4&]D<&]R80!3=7)I;F%M`%!R:65Z=FES:V\`4W9A;&)A<F0@82!*86X@
M36%Y96X`4W9A>FEJ<VMO`*EVZ61S:V\`4')E<&[ZNR!S</1S;V(@<.US86YI
M82!S<'+A=@!0<F5P;OJ[(&YA('#M<V%N:64@<W!RX78@=B!(5$U,`%!R97!N
M^KL@;F$@<.US86YI92!O8GGH86IN_6-H('1E>'1O=OUC:"!S<'+A=@"I=F%J
MZ&EA<G-K;P!:X7IN86UY(&\@<WEN8VAR;VYI>N%C:6D@=GEM87IA;ND`4WEN
M8TU,`%-Y;G1A:W1I8VOA(&-H>6)A('8@<&]D;6EE;FMA8V@@:+5A9&%N:6$`
M4_UR:6$`0OIR:V$`0OIR:V$@82!V971E<FYO`$+Z<FMY`%+A;F\@8OIR:WD`
M5%-6('/Z8F]R`%1A8G6U:V$`5FQA<W1N;W-T:2!T86)UM6MY`%9L87-T;F]S
M=&D@=&%B=;5K>0!486EW86X`5&%I=V%N+"!P<F]V:6YC:6$@R.UN>0!4862^
M:6MI<W1A;@!486YZX6YI80!#:66U.@#:;&]H>0!495]X=`!496QE9O-N;F4@
MZ.US;&\`5&5P;&]T82!Z82!P;W-L961N^B!H;V1I;G4Z(`!497!L;W1A`%1E
M<&QO=&$Z(`!497!L;W1A/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE
M<P"I86)L\VYA("(E<R(@;F5B;VQA(&[A:F1E;N$N`%-P<N%V82"Y86)L\VX`
M4')E9&)EOFYE(&%K8V5P=&]V86[A.B``4')E9&)EOFYE(&%K8V5P=&]V8;L@
M<&^^:6%D879K=0!0<F5D8F6^;F4@86MC97!T;W9A;N$`4&]D;6EE;FMY('!O
M=;YI=&EA(&YI92!S^B"Y<&5C:69I:V]V86[I('8@8V]N9BYP:'``5&5X=`!)
M8F$@=&5X=`!:87)O=FYA;FEE('1E>'1U`%1E>'0@:&]R90"I=`!4:&%J<VMO
M`%)O>KGM<F5N:64@1E10(&YI92!J92!D;W-T=7!NZ2X`4&]L92!/9#H@=B!S
M<'+A=F4@8GD@;>$@8GF[('!R97!O:F5NZ2!S.@!);G1E9W+A8VEA($AO<F1E
M+TMO;&%B(&YE<&]D<&]R=6IE("(E<R(`24U!4"!S97)V97(@<')A=F1E<&]D
M;V)N92!N97!O9'!O<G5J92!V>6)R86[Z(&%U=&5N=&EF:6MAZ&[Z(&UE=/-D
M=2X@2V]N=&%K='5J=&4@<')O<^UM('-V;VIH;R!A9&UI;FES='+A=&]R82X`
M24U34"!ZX7IN86T@<V$@;F5P;V1A<FEL;R!U;&^^:;LN`$UA8VEN=&]S:"!R
M97-O=7)C92!F;W)K`$UA8VEN=&]S:"!R97-O=7)C92!F;W)K('-A(&3A('-T
M:6%H;G6[("5S+@!4<FEE9&$@36%I;G1E;F%N8V4Z.B!S82!N96YAZ.UT86QA
M(/IS<&6Y;F4`3VMN;R!S(&YA<W1A=F5N:6%M:2!S82!Z871V;W)I;&\N($MO
M;FEE8RX`VNAE="`B)7,B(&)O;"!V>6UA>F%N_2X`VNAE="`B)7,B(&)O;"!U
M;&^^96[]+@!!9&UI;FES='+A=&]R(&UU<^T@;F%K;VYF:6=U<F]V8;L@<&5R
M;6%N96YT;OT@8F%C:V5N9"!P<F4@4'+A=F$L(&%K(&-H8V5T92!P;W6^[79A
MNR!0<N%V82X`4'+M;&]H82!N96)O;&$@;N%J9&5NX2X`26)A('-P;V1NX2!S
M=')A;F$`VF1A:F4@:V%L96YDX7)A('/Z(&YE<&QA=&[I`$]K;F\@;F$@<.US
M86YI92!S<'+A=GD@<V$@;F5P;V1A<FEL;R!O='9O<FF[+B!.96WA=&4@;F%S
M=&%V96[]('!R96AL:6%D8>@@;F$@8FQO:V]V86YI92!V>7-K86MO=F%C[6-H
M(&]K:65N/P!)1"#H[7-L;R!K;VYT86MT=2!N96)O;&\@N7!E8VEF:6MO=F%N
MZ2P@8F]L;R!P;VYE8VAA;ND@<'+A>F1N92!A;&5B;R!N96)O;&\@;N%J9&5N
MZ2!V(&1A=&%BX7IE+@!+;VYT86MT(&)O;"#Z<W!EN6YE('9L;[YE;OT@9&\@
M5N&Y:&\@861R97/A<F$N`$]B<V%H('/Z8F]R=2!-86-I;G1O<V@@:F4@=79E
M9&5N_2!N:;ZY:64N`$%K='7A;&YY('!R:67H:6YO:R`H<')I9>AI;FMY*2`B
M)7,B(&)U9&4@<')E;65N;W9A;OT@;F$@(B5S(BX`3F5M;[YN;R!Z[7-K8;L@
M>F]Z;F%M('!O=;[M=F%T9;5O=B!S('!R[7-T=7!O;2!K('1O;75T;R!P<FEE
MZ&EN:W4`3F$@;W9E<F5N:64@<&]D<.US86YE:B!S<'+A=GD@:F4@<&^^861O
M=F%N_2!O9&1E;&5N_2!B;&]K(',@4$=0('!O9'!I<V]M+@!)1"!Z;WIN86UU
M('!R[6IE;6-O=B!B=>\@;F5B;VQO(+EP96-I9FEK;W9A;NDL(&%L96)O(&)O
M;&\@<&]N96-H86[I('!RX7ID;F4@86QE8F\@;F5B;VQO(&[A:F1E;ND@=B!D
M871A8N%Z92X`3F5B;VP@=7+H96[]('IO>FYA;2!P<NUJ96UC;W8N`$MO;F-E
M<'0@8F]L('5L;[YE;OT@9&\@<')I9>AI;FMA("(E<R(N`*EI9G)O=F%N:64@
M=GF^861U:F4@8F5Z<&7H;ND@<')I<&]J96YI92`H:'1T<',I+@!59&%L;W.[
M(&)O;&$@<')I9&%NX2!D;R!6X;EH;R!K86QE;F3A<F$N`%!O;&4@(B5S(B!S
M82!N97!O9&%R:6QO(&1O<&QN:;LN`%/Z8F]R("5S(&)Y(&UA;"!O8G-A:&]V
M8;L@;F%S=&%V96YI92`E<RX`4_IB;W(@)7,@8GD@;6%L(&]B<V%H;W9ANR!N
M:65K=&]RZ2!N87-T879E;FEA("5S+@!:9')O:F]V_2!A(&-I9;5O=OT@<_IB
M;W(@;75S:6$@8GF[(&]D;&FY;NDN`%/Z8F]R(&YE;V)S86AO=F%L(+YI861N
M92#Z9&%J92X`4')I9>AI;F]K("(E<R(@=;X@97AI<W1U:F4`4')I9>AI;F]K
M("(E<R(@;V)S86AU:F4@=B!M96YE(&YE<'+M<'5S=&[I('IN86MY+"#H;R!M
M]+YE('-P]'-O8FF[('!R;V)LZ6UY+B!0<F]S[6T@:V]N=&%K='5J=&4@<W!R
MX79C=2!6X;EH;R!S>7-TZ6UU+@!0<FEEZ&EN;VL@(B5S(B!B;VP@=GET=F]R
M96[]+"!A;&4@;F5B;VQI('-T92!D;_(@<')I:&SA<V5N_2X`4')I9>AI;F]K
M("(E<R(@8F]L('9Y;6%Z86[]+"!A;&4@;F5B;VQI('-T92!Z(&YE:&\@;V1H
M;.%S96[]+@!0<FEEZ&EN;VL@(B5S(B!N96)O;"!V>71V;W)E;OTN(`!0<FEE
MZ&EN;VL@(B5S(B!N96)O;"!V>6UA>F%N_2X@4V5R=F5R(&]D<&]V961A;`!0
M<FEEZ&EN;VL@(B5S(B!B;VP@^G-P9;EN92!V>71V;W)E;OTN`%!R:67H:6YO
M:R`B)7,B(&)O;"#Z<W!EN6YE('9Y;6%Z86[]+@!0<FEEZ&EN;VL@(B5S(B!B
M;VP@^G-P9;EN92!P<F5M96YO=F%N_2!N82`B)7,B+@!.87-L961U:OH@:&QA
M=FGH:WD@=&5J=&\@<W!RX79Y('9O(&9O<FWA=&4@;65S<V%G92]R9F,X,C(N
M`$L@=&5J=&\@Z&%S=&D@8F]L:2!P<FEP;VIE;ND@;F%S;&5D=6KZ8V4@<_IB
M;W)Y.@!#96QO;V)R87IO=FMO=OT@<F6^:6T@<W#T<V]B=6IE('!R;V)LZ6UY
M('8@26YT97)N970@17AP;&]R97)I(&MV]&QI(&-H>6+A;2!P<F5H;&EA9&'H
M82P@:W1O<ND@<V$@;N%M(&YE<&]D87)I;&\@;V+M<[LN($WTOG4@<V$@<')E
M:F%V:;L@;F5S<'+A=FYY;2!Z;V)R87IE;NUM+"!C:/UB86KZ8VEM:2!F=6YK
M8VEA;6D@961I=&]R82!A+V%L96)O(&[A:&]D;OUM:2!PX61M:2!P<F5H;&EA
M9&'H82X@06L@:F4@5N&Y('-Y<W3I;2!7:6YD;W=S(#EX+"!J92!V9;5M:2!P
M<F%V9&5P;V1O8F[I+""^92!S82!Z;V)R87KM(&-H>6)A("='96YE<F%L(%!R
M;W1E8W1I;VX@1F%U;'0G(&$@8G5D971E(&UU<VEENR!R9;ET87)T;W9ANR!P
M;^CM=&'H+EQN7&Y687)O=F%L:2!S;64@5N%S+B!3=&QAZ'1E('!R;W/M;2!/
M2R!A:R!N86]Z86H@8VAC971E('!O=;YINR!E9&ET;W(@=B!C96QO;V)R87IO
M=FMO=F]M(')EOFEM92X`261E;G1I=&$@(B5S(B!B;VQA('9Y;6%Z86[A+@!/
M:VYO(&YA('5L;[YE;FEE(&]B<N%Z:V$@<V$@;F5P;V1A<FEL;R!O='9O<FF[
M+B!.96WA=&4@;F%S=&%V96[]('!R96AL:6%D8>@@;F$@8FQO:V]V86YI92!V
M>7-K86MO=F%C[6-H(&]K:65N/P!/8G+A>FMY('-A('IO8G)A>FEA+"!P<F5T
M;[YE(&]D;W-I96QA=&6U(&IE('9O(%9AN6]M(&%D<F5SX7)I+@!)8F$@M6%V
MX2!S=')A;F$`5')I961A($-R>7!T7W!G<#HZ('!O=')E8G5J92!P;WIN8;L@
M=6UI97-T;F5N:64@<')O9W)A;74@1VYU4$<N`$UA:6QO=OT@<V5R=F5R('9Y
M9V5N97)O=F%L(&YA<VQE9'5J^F-E(&-H>6)O=ND@:&SA<V5N:64Z`$UA:6QO
M=OT@<V5R=F5R('9Y9V5N97)O=F%L(&YA<VQE9'5J^F-E(&EN9F]R;6'H;ND@
M:&SA<V5N:64Z`$UA:6QO=OT@<V5R=F5R('9Y9V5N97)O=F%L(&YA<VQE9&]V
M;ND@:&SA<V5N:64Z`%-C:'+A;FMA("5S(&IE('6^('!RX7ID;F$N`%-P<N%V
M82`B)7,B(&]D("(E<R(@*"5D(&)A:G1O=BD@<')E:W)OZ&EL82!L:6UI="!V
M9;5K;W-T:2!N82!SNV%H;W9A;FEE+@!3<'+A=F$L(&YA(&MT;W)E:B!S=&4@
M<')A8V]V86QI+"!B;VQA('IA='9O<F5NX2X@2V]N:65C+@!3<'+A=F$@8F]L
M82!V>6UA>F%NX2X`4W!RX79A(&)O;&$@;W9E<F5NX2X`4W!RX79A(&)O;&$@
M;W9E<F5NX2X@3V1O<VEE;&%T9;4Z("5S+@!3<'+A=F$@;V1O<VQA;N$@)7,@
M<')E("5S(',@<')E9&UE=&]M("(E<R(@8F]L82!Z;V)R87IE;N$N"DYE97AI
M<W1U:F4@=KEA:R!ZX7)U:V$L(+YE('-P<N%V82!B;VQA('!R9>CM=&%NX2!A
M;&5B;R!P;V-H;W!E;N$N`$UE;F\L(&MT;W+I('-A(&WA('!O=;YINR!P<FD@
M;&EN:V]V86[M(&YA('-T<N%N:W4@;F$@<.US86YI92!S<'+A=B``4&_H970@
M<&]L[2!M=7/M(&)YNR#H[7-L;RX`5')I961A($AO<F1E7T-R>7!T7W-M:6UE
M.CH@=GF^861U:F4@;6]D=6P@;W!E;G-S;"X`3VMN;R!N82!Z861A;FEE(&AE
M<VQA('-A(&YE<&]D87)I;&\@;W1V;W)INRX@3F5MX71E(&YA<W1A=F5N_2!P
M<F5H;&EA9&'H(&YA(&)L;VMO=F%N:64@=GES:V%K;W9A8^UC:"!O:VEE;C\`
M3F%S=&%V96YI92`B)7,B('-A(&YE<&]D87)I;&\@=6QOOFF[+"!P<F5T;[YE
M(&IE:&\@^F1A:F4@<')E:W)AZ'5J^B!M87AI;>%L;G4@<&]V;VQE;OH@=F6U
M:V]SNP!0<F]G<F%M('!O=;[M=F%N_2!N82!Z;V)R87IE;FEE('1O:'1O(/ID
M86IO=NEH;R!T>7!U("@E<RD@;F5B;VP@;N%J9&5N_2X`6FYA:R!C:73A8VEE
M(&UU<^T@8GF[(&IE9&5N('IN86LN`%1E>'0@=&]H=&\@=F5R96INZ6AO(%!'
M4"!KM?KH82!M]+YE(&)YNR!Z;V)R87IE;OT@)7,N`%!OOF%D;W9A;OT@<_IB
M;W(@;F5E>&ES='5J92!V('!R[6QO:&4@35,M5$Y%1BX`4&^^861O=F%N_2!S
M^F)O<B!N965X:7-T=6IE('8@<'+M;&]H92!::7`N`$EB82!P<F%VX2!A(+5A
M=N$@<W1R86YA`$EB82!P<F%VX2!S=')A;F$`3V1O<VEE;&%T9;4@=&5J=&\@
M<W!RX79Y('9YOF%D=6IE(&]D(%;A<R!O>F[A;65N:64@;R!P<F7H[71A;NT@
M<W!RX79Y+B!+;&EK;FET92!P<F]S[6T@)7,@<')E(&]D;W-L86YI92!S<'+A
M=GD@<R!O>F[A;65N[6TN`$]D9&6U;W9AZ"!M=7/M(&)YNR!J961E;B!Z;F%K
M+@!397)V97(@(B5S(B!B;VP@=GEM87IA;OTN`%-E<G9E<B`B)7,B(&)O;"!U
M;&^^96[]+@!397)V97(@;F5M;VAO;"!V>71V;W)INR!Z;65NN65N^B!K\W!I
M=2!T;VAT;R!O8G+A>FMU+@!3:6=N873Z<G4@<V$@;F5P;V1A<FEL;R!N86AR
M861INRX`4VEG;F%T^G)A(&)O;&$@^G-P9;EN92!N86AR861E;N$N`*YI861O
M<[L@;R!P<FEH;.%S96YI92`E<R!B;VQA('9Y;6%Z86[A+@"I<&5C:69I:V]V
M86[]('/Z8F]R(&YE97AI<W1U:F4N`*EP96-I9FEK;W9A;OT@<FEA9&]K(&YE
M97AI<W1U:F4N`*EA8FSS;F$@(B5S(B!B;VQA('5L;[YE;N$N`*EA8FSS;F$@
M(B5S(B!B;VQA('9Y;6%Z86[A+@"I86)L\VYA("(E<R(@8F]L82!A:W1U86QI
M>F]V86[A+@#:;&]H82!B;VQA('!R:61A;N$@9&\@5N&Y:&\@>F]Z;F%M=2#Z
M;&]H+@!$;^AA<V[]('/Z8F]R("(E<R(@;F5E>&ES='5J92X`5&5X="!S<'+A
M=GD`5&5X="!S<'+A=GD@;?2^92!B>;L@>F]B<F%Z96[]("5S+@!497AT('9R
MX71E;F5J('-P<N%V>0!497AT('9RX71E;F5J('-P<N%V>2!M]+YE(&)YNR!Z
M;V)R87IE;OT@)7,N`%1E>'0@;V1O<VQA;F5J('-P<N%V>0!497AT(&]D;W-L
M86YE:B!S<'+A=GD@;?2^92!B>;L@>F]B<F%Z96[]("5S+@!:861A;OT@=&5X
M="!N:64@:F4@<F]V;F%K_2!A:V\@=&5X="!N82!O8G)A>F]V:V4N`$EB82!H
M;W)NX2!A('-P;V1NX2!S=')A;F$`26)A(&AO<F[A('-T<F%N80!.86AR86[I
M(/ID86IE('-A(&]D('!R961C:.%D>F%J^F-E:&\@:W)O:W4@<W1R871I;&DN
M`$YA:')A;OT@<_IB;W(@<V$@;F5P;V1A<FEL;R!U;&^^:;LN`$EN9F]R;>%C
M:6$@;R!Z86YE<'+A>F1N96YO<W1I('!O=;[M=F%T9;5A(&)O;&$@^G-P9;EN
M92!U;&^^96[A+@!";&]K('=E871H97(N8V]M(&YI92!J92!D;W-T=7!N_2X`
M4')I9>AI;F]K('3I;2`B)7,B(&YE8F]L(&[A:F1E;OTN`*YI861N92!A;'1E
M<FYA=.UV;F4@Z&%S=&D@;F5M;[YN;R!Z;V)R87IINR!V('1E;&4@<W!RX79Y
M+@!4X71O('-C:'+A;FMA(&IE('!RX7ID;F$N`*YI861N92!N87-T879E;FEA
M(&YI92!S^B!D;W-T=7!NZ2X`KFEA9&YE(&%L=&5R;F%T[79N92#H87-T:2!N
M96UOOFYO('IO8G)A>FF[('8@=&5L92!S<'+A=GDN`%8@=&]M=&\@<&]L:2!J
M92!P<NUL:;D@=F6U82!Z;F%K;W8N(%IA9&%L:2!S=&4@)7,@>FYA:V]V.R!M
M=7/M=&4@>F%D8;L@;65N96H@86MO("5S+@"N:6%D96X@=&5X="!N96UOOFYO
M('IO8G)A>FF[('8@=&5L92!S<'+A=GDN`$YA<W1A;&$@8VAY8F$@<')I('!R
M:63A=F%N[2`B)7,B(&1O('-Y<W3I;74Z("5S`$YA<W1A;&$@8VAY8F$@<')I
M(&]D<W1R8?)O=F%N[2!P;W6^[79A=&6U<VO]8V@@^F1A:F]V("(E<R(@>F\@
M<WES=.EM=3H@`%9Y<VMY=&]L('-A('!R;V)LZ6T@<')I('9Y;6%ZX79A;NT@
M<V-H<N%N:WDZ("5S`$YA<W1A;&$@8VAY8F$@<')I(&]D<W1R8?)O=F%N[2`B
M)7,B('IO('-Y<W3I;74Z(`!.87-T86QA(&-H>6)A('!R:2!A:W1U86QI>N%C
M:6D@(B5S(CH@)7,`5GES:WET;VP@<V$@<')O8FSI;2!S(&YA:'+A=F%N[6T@
M<_IB;W)U.B"N:6%D96X@)7,@;F5B;VP@;F%H<F%N_2X`5GES:WET;VP@<V$@
M<')O8FSI;2!S(&YA:'+A=F%N[6T@<_IB;W)U.B`E<R!B;VP@=N3HN>T@86MO
M(&YA:G;DZ+GM('!O=F]L96[](&QI;6ET("@E9"!B86IT;W8I+@!6>7-K>71O
M;"!S82!P<F]B;.EM(',@=6ML861A;NUM('/Z8F]R=3H@)7,@8F]L(&YA:')A
M;OT@;&5N(.AI87-T;^AN92X`5GES:WET;VP@<V$@<')O8FSI;2!P<FD@:V]P
M[7)O=F%N[2!S<'+A=B!Z("(E<R(@9&\@(B5S(CH@`%9Y<VMY=&QA('-A(&-H
M>6)A('!R:2!M87IA;NT@<W!RX78@>B!P<FEEZ&EN:V$@(B5S(BX@`%9Y<VMY
M=&QA('-A(&-H>6)A('!R:2!M87IA;NT@<W!RX78@=B!P<FEEZ&EN:W4@(B5S
M(BX@`%9Y<VMY=&QA('-A(&-H>6)A('!R:2!M87IA;NT@<W!RX78Z("5S`$YA
M<W1A;&$@8VAY8F$@<')I('9Y;6%ZX79A;NT@=61A;&]S=&DZ("5S+@!.87-T
M86QA(&-H>6)A('!R:2!Z;V)R87IO=F%N[2!T96IT;R#H87-T:2!S<'+A=GD`
M5GES:WET;&$@<V$@8VAY8F$@<')I(&YA<W1A=F]V86[M('!R[7IN86MO=B!S
M<'+A=GD@=B!P<FEEZ&EN:W4@(B5S(BX@`$YA<W1A;&$@8VAY8F$@<')I(&EM
M<&]R=&4@)7,N`$YA<W1A;&$@8VAY8F$@<')I(&EM<&]R=&4@^F1A:F]V(&\@
M:V]N=&%K=&4N`$YA<W1A;&$@8VAY8F$@<')I(&EM<&]R=&4@=61A;&]S=&DZ
M("5S+@!.87-T86QA(&-H>6)A('!R:2!I;7!O<G1E(/ID86IO=B!I0V%L96YD
M87(N`$YA<W1A;&$@8VAY8F$@<')I(&EM<&]R=&4@^FQO:'DZ("5S+@!.87-T
M86QA(&-H>6)A('!R:2!I;7!O<G1E(&EN9F]R;>%C:>T@;R!Z86YE<'+A>F1N
M96YO<W1I('!O=;[M=F%T9;5A.B`E<RX`3F%S=&%L82!C:'EB82!V(&MO;F9I
M9W5R8>AN;VT@9F]R;75LX7)I+B!0<F%V9&5P;V1O8FYE('-T92!N979Y<&QN
M:6QI('!OOF%D;W9A;ND@<&]L92X`3F%S=&%L82!C:'EB82!P<FD@<')E<_IV
M86[M('-P<N%V('H@(B5S(B!D;R`B)7,B+B``3F%S=&%L82!C:'EB82!P<FD@
M=GEK;V[A=F%N[2!U<NAE;F5J(&9U;FMC:64@861R97/A<F$N(%!R;W/M;2!S
M:_IS=&4@=&\@;F5S:_1R+@!.87-T86QA(&-H>6)A('!R:2!U:VQA9&%N[2!K
M;VYC97!T=2X`0VAY8F$@<')I('!O<VEE;&%N[2!S<'+A=GDZ("5S`$YA<W1A
M;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2!D971A:6QO=B!K;VYT86MT=2X@
M4')O<^UM('-K^G-T92!T;R!N97-K]'(N`$YA<W1A;&$@8VAY8F$@<')I(&%K
M='5A;&EZX6-I:2!Z;WIN86UU('!R[6IE;6-O=BX@4')O<^UM('-K^G-T92!T
M;R!Z;F]V=2X`3F%S=&%L82!C:'EB82!P<FD@86MT=6%L:7KA8VEI(&]B:F5K
M='4Z("5S`%3A=&\@Z&%SNR!S<'+A=GD@;F5O8G-A:&]V86QA('1E>'0`5.%T
M;R!(5$U,('-P<N%V82!O8G-A:'5J92!O8G+A>FMY+@!4X71O($A434P@<W!R
MX79A(&]B<V%H=6IE(&]B<N%Z:WDN($)L;VMO=F%NZ2!O8G+A>FMY('-A('IO
M8G)A>FEA('1A:W1O.B``5&5N=&\@24U!4"!S97)V97(@;F5P;V1P;W)U:F4@
M>F1I9;5A;FEE('!R:67H:6YK;W8N`%1E;G1O('9E<F5J;OT@4$=0(&NU^N@@
M8F]L('!R:7!O:F5N_2!K('-P<N%V92X`5.%T;R!A:V-I82!N:64@:F4@<&]D
M<&]R;W9A;N$N`%3A=&\@86MC:6$@9;ET92!N:64@:F4@:6UP;&5M96YT;W9A
M;N$N`%1O=&\@<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!R
M87(N`%1O=&\@<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!Z
M:7`N`%1O=&\@<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[I(.CM<VQO(&MA
M<G1Y+@!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@
M8V5Z(&)RX6YU($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M<&]M;V-O=2!(5%10($%020!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE
M;&%N:64@<W!RX78@8V5Z(&)RX6YU(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M('!O;6]C;W4@2%144"!!4$D`5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I
M96QA;FEE('-P<N%V(&-E>B!B<N%N=2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R
M96UA:6PN8V]M*2!P;VUO8V]U($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UO
MOO)U:F4@<&]S:65L8;L@<W!RX79Y(&-E>B!33510(&-E>B!B<N%N=2!6;V1A
M9F]N92!)=&%L>2`H:6)A(&YA(.CM<VQA(%9O9&%F;VYE*2X@5GF^861U:F4@
M92UM86EL;W;](/KH970@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP
M+FET*2X`5&]T;R!P;VQE(&IE('!O=FEN;NDN`%1O=&\@<&]L92!M]+YE(&]B
M<V%H;W9ANR!I8F$@Z.US;&$N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I
M8F$@Z.US;&$@82!D=F]J8F]D:W4N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9A
MNR!I8F$@;W-M:>AK;W;I(&AO9&YO='DN`%1O=&\@<&]L92!M=7/M(&)YNR!Z
M;WIN86T@Z.US96P@;V1D96QE;OUC:"#H:6%R:V]U(&%L96)O(&UE9'IE<F]U
M`%1O=&\@<&]L92!M=7/M(&)YNR!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M
M=7/M(&]B<V%H;W9ANR!K\V0@9F%R8GD@=B"Y97-T;N%S=&MO=F]M(&9O<FWA
M=&4@4D="+"!N87!R[6ML860@)R,Q,C,T868G+@!496YT;R!F;W)M=6SA<B!U
MOB!B;VP@<W!R86-O=F%N_2X`5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE:W0@
M2V]L86(@1W)O=7!W87)E+B!0<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE:W1U
M('!O=')E8G5J971E(&4M;6%I;&]VZ6AO(&ML:65N=&$L(&MT;W+](')O>G5M
M:64@9F]R;>%T=2!+;VQA8B!'<F]U<'=A<F4N(%!R92!Z;WIN86T@=&%K_6-H
M=&\@:VQI96YT;W8@;F%VN73M=G1E('!R;W/M;2`E<P!4;W1O(&WTOF4@8VAV
M[;5U('1R=F&[+B!.86]Z86H@8VAC971E('!O:W)AZ&]V8;L_`%3A=&\@<W!R
MX79A(&]B<V%H=6IE('/Z8F]R($UA8VEN=&]S:"X`5.%T;R!S<'+A=F$@;V)S
M86AU:F4@<'+M;&]H=2P@:W1RX2!B;VQA(&1I9VETX6QN92!P;V1P[7-A;N$@
M<&]M;V-O=2!3+TU)344N`%3A=&\@<W!RX79A(&]B<V%H=6IE('!R[6QO:'4L
M(&MT;W+A(&)O;&$@>F&Y:69R;W9A;N$@<&]M;V-O=2!3+TU)344N`%3A=&\@
M<W!RX79A(&]B<V%H=6IE(&EN9F]R;>%C:74@;R!S=&%V92!D;W)UZ&5N:6$@
M<&^Y='DL(&%L92!F;W)MX70@<W!RX79Y(&YI92!J92!Z;N%M>2X`5.%T;R!S
M<'+A=F$@<')A=F1E<&]D;V)N92!N:64@:F4@>F&Y:69R;W9A;N$@4$=0+B!#
M:'EB83H@`%3A=&\@<W!RX79A('!R879D97!O9&]B;F4@;FEE(&IE('8@<W!R
MX79N;VT@4$=0(&9O<FWA=&4@*'!O9+5A(%)&0R`R,#$U*2X`5.%T;R!S<'+A
M=F$@<')A=F1E<&]D;V)N92!N:64@:F4@=B!S<'+A=FYO;2!3+TU)344@9F]R
M;>%T92X`5.%T;R!S<'+A=F$@8F]L82!D:6=I=.%L;F4@<&]D<.US86[A('!O
M;6]C;W4@4$=0+@!4X71O('-P<N%V82!B;VQA(&1I9VETX6QN92!P;V1P[7-A
M;N$@<&]M;V-O=2!3+TU)344N`%3A=&\@<W!RX79A(&)O;&$@>F&Y:69R;W9A
M;N$@<&]M;V-O=2!3+TU)344N`%3A=&\@<W!RX79A(&)O;&$@>F&Y:69R;W9A
M;N$@<&]M;V-O=2!01U`N`%3Z=&\@<W!RX79U(&1O`%3A=&\@<W!RX79A(&)O
M;&$@;F%P[7-A;N$@=B!I;F5J(&%K;R!686UI('!O=;[M=F%N96H@>FYA:V]V
M96H@<V%D92`H)7,I+@!4;W1O(.CM<VQO(&UU<^T@8GF[(&YA:FUE;F5J(#$N
M`%1E;G1O('-E<G9E<B!N961O:^&^92!D96MO;7!R:6UO=F&[('/Z8F]R>2!Z
M:7`@82!G>FEP+@!496YT;R!S97)V97(@;F5P;V1P;W)U:F4@>F1I9;5A;FEE
M('!R:67H:6YK;W8N`%-Y<W3I;2!J92!M;VUE;G3A;&YE(&1E86MT:79O=F%N
M_2X`5.%T;R!H;V1N;W1A(&UU<^T@8GF[(.CM<V5L;N$N`%1O=&\@;VMN;R!S
M82!M=7/M('9O;&&[('H@;VMN82!P<F4@<.US86YI92!S<'+A=GDN`%1O=&\@
M;VMN;R!M=7/M(&)YNR!Z879O;&%NZ2!Z(&]K;F$@3F%S=&%V96[M`%IO8G)A
M>FF[('9LX6MN80!(<FUE;FEE`%1I8VME=',`R&%S`%1I;64@5')A8VMI;F<`
M1F]R;>%T(.AA<W4`5OUB97(@Z&%S=0!4:6UO<BU,97-T90!4:71U;&]K`$YA
M9'!I<R`H8G5B;&EN;W;](';]<&ES*3H`4')E`$%D<F5S82!P<NUJ96UC=0!0
M<F4@=OUB97(@=FEA8V5R_6-H('!O;.T@9'*^=&4@0V]N=')L;"`H4$,I(&%L
M96)O($-O;6UA;F0@*$UA8RD@<&_H87,@:VQI:V%N:6$N`%!R92!V_6)E<B!V
M:6%C97+]8V@@<&]L;[YI96L@9'*^=&4@<&_H87,@:VQI:V%N:6$@:VSA=F5S
M=2!#;VYT<F]L("A00RD@86QE8F\@0V]M;6%N9"`H36%C*2X`06)Y('-T92!M
M;VAL:2!P;W6^:;L@5$Q3('-P;VIE;FEE+"!M=7/M=&4@<&]UONUV8;L@4$A0
M(#4N,"XV(&%L96)O('9YN;EI92X`1&YE<P!0<F5P;OJ[('IO8G)A>F5N:64@
M>F1R;VIO=NEH;R!K\V1U($A434P`5&]G;P!4;VME;&%U`%IA:G1R80!4;VYG
M80!6<F-H`%9R8VAN_2!RX6UE8R`H7W1O<"D`0V5L:V]VX2!V9;5K;W.[('!R
M[6QO:#H`4')E:VQA9'D`3V1P861K;W;](&OTN0!/9'!A9&MO=OT@:_2Y.@!4
M<FEN:61A9"!A(%1O8F%G;P!0<F%V9&$@86QE8F\@;F5P<F%V9&$`570`5'5N
M:7-K;P!4=7)E8VMO`%1U<FMM96YI<W1A;@!4=7)K<R!A($-A:6-O<P!4=79A
M;'4`6F%D86IT92!68;EU('9OM6)U.B``52Y6+B!I;F1E>#H@`%523`!54DP@
M5N&Y:&\@<VMR:7!T=2!P<F4@<W!RX79U(&\@9&]R=>AE;NT`55),.@!59V%N
M9&$`56MR86II;F$`3F5P;V1A<FEL;R!S82!U<VMU=&_H;FF[('!R[7-T=7`@
M:R!61E,@861R97/A<G4N`$YE<&]D87)I;&\@<V$@<')I9&&[(.]A;+EI92!I
M;F9O<FWA8VEE(&\@<&]UONUV871EM6]V:2!P<FD@<F5G:7-T<N%C:6DN`$YE
M<&]D87)I;&\@<V$@>FUE;FF[('!RX79O('!R92!61E,@<_IB;W(@(B5S(BX`
M3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@<')E(%9&4R!S^F)O<B`E<R\E
M<RX`3F5P;V1A<FEL;R!S82!Z;65N:;L@;F$@)7,N`$YE<&]D87)I;&\@<V$@
M<VMO;G1R;VQO=F&[('9EM6MO<[L@<_IB;W)U("(E<R(N`$YE<&]D87)I;&\@
M<V$@<VMO;G1R;VQO=F&[('9EM6MO<[L@<_IB;W)U("(E<R\E<R(N`$YE<&]D
M87)I;&\@<V$@<W!O:FF[(',@4U%,('-E<G9E<F]M+@!.97!O9&%R:6QO('-A
M('-P;VIINR!P;VUO8V]U(%-33"X`3F5P;V1A<FEL;R!S82!S:V]P[7)O=F&[
M(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@861R97/A
M<B`B)7,B+@!.97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!A9')E<^%R+@!.
M97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S
M82!V>71V;W)INR!61E,@<')I9>AI;F]K("(E<R(N`$YE<&]D87)I;&\@<V$@
M=GET=F]R:;L@<'+A>F1N>2!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@9&5K
M;VUP<FEM;W9ANR#Z9&%J92X`3F5P;V1A<FEL;R!S82!V>6UA>F&[("(E<R(L
M(&%D<F5SX7(@;FEE(&IE('!RX7ID;GDN`$YE<&]D87)I;&\@<V$@=GEM87IA
MNR`B)7,B.B`E<RX`3F5P;V1A<FEL;R!S82!V>6UA>F&[("5S+"!A9')E<^%R
M(&YI92!J92!P<N%Z9&YY`$YE<&]D87)I;&\@<V$@<F5K=7)Z[79N92!V>6UA
M>F&[(%9&4R!A9')E<^%R+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93(&%D
M<F5SX7(N`$YE<&]D87)I;&\@<V$@=GEM87IANR!61E,@861R97/A<CH@)7,N
M`$YE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<_IB;W(@(B5S(BX`3F5P;V1A
M<FEL;R!S82!V>6UA>F&[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S82!V>6UA
M>F&[(%9&4R!P<FEEZ&EN;VL@(B5S(BX`3F5P;V1A<FEL;R!S82!R96MU<GKM
M=FYE('9Y;6%Z8;L@5D93.B`E<RX`3F5P;V1A<FEL;R!S82!U<NAINR!A:W1U
MX6QN>2!A9')E<^%R+@!.97!O9&%R:6QO('-A('II<W1INR!P;V1R;V)N;W-T
M:2!O(&-E<G1I9FEKX71E+@!.96UOOF[I(&YA:')ANR!D969I;NUC:74@)7,N
M`$YE<&]D87)I;&\@<V$@<')E<W5N^KL@5D93('/Z8F]R+@!.97!O9&%R:6QO
M('-A(&]T=F]R:;L@5D93('/Z8F]R("(E<R(N`$YE<&]D87)I;&\@<V$@;W1V
M;W)INR!61E,@<_IB;W(@;F$@>N%P:7,N`$YE<&]D87)I;&\@<V$@;W1V;W)I
MNR!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@;W1V;W)INR!K;VUP<FEM;W9A
M;OT@87)C:.UV+@!.97!O9&%R:6QO('-A('!R9>CM=&&[(%9&4R!S^F)O<B`H
M9G5N:V-I82!F:6QE<VEZ92@I('IL>6AA;&$I+@!.97!O9&%R:6QO('-A('!R
M9>CM=&&[(%9&4R!S^F)O<B`H9G5N:V-I82!G971&:6QE4VEZ92@I('IL>6AA
M;&$I+@!.97!O9&%R:6QO('-A('!R9>CM=&&[('/Z8F]R.@!.97!O9&%R:6QO
M('-A(.CM=&&[(&%D<F5SX7(@=F9S<F]O="X`3F5P;V1A<FEL;R!S82!P<F5M
M96YO=F&[("5S(&YA("5S.B!C:66U;W;]('!R:67H:6YO:R!UOB!E>&ES='5J
M90!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93(&%D<F5SX7(N`$YE<&]D
M87)I;&\@<V$@<')E;65N;W9ANR!61E,@861R97/A<CH@)7,N`$YE<&]D87)I
M;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(@(B5S(BX`3F5P;V1A<FEL;R!S
M82!P<F5M96YO=F&[(%9&4R!S^F)O<B`E<R\E<RX`3F5P;V1A<FEL;R!S82!P
M<F5M96YO=F&[(%9&4R!S^F)O<BX`3F5M;[YN;R!Z[7-K8;L@:6YF;W)MX6-I
M=2!O(&MV\W1E`$YE<&]D87)I;&\@<V$@<W!U<W1INR`G;6MI<V]F<R<N`$YE
M<&]D87)I;&\@<V$@<')E;&^^:;L@=&5N=&\@9&]K=6UE;G0@5V]R9`!.97!O
M9&%R:6QO('-A('IA<.US8;L@5D93('/Z8F]R("(E<R(N`$YE<&]D87)I;&\@
M<V$@>F%P[7-ANR!61E,@<_IB;W(@*&9U;FMC:6$@8V]P>2@I('IL>6AA;&$I
M+@!.97!O9&%R:6QO('-A('IA<.US8;L@^F1A:F4@5D93('/Z8F]R=2X`3F5P
M;V1A<FEL;R!S82!Z87#M<V&[(%9&4R!S^F)O<BP@:W;S=&$@:F4@<')E:W)O
MZ&5NX2X`3F5Z;V1P;W9E9&%NZ0!.97IO9'!O=F5D86[I('-P<N%V>0!/8FYO
M=FF[`%!O9.AI87)K;G5TZ0!.97IV97)E:FYE;NT@<'+M:F5M8V]V:6$`6G)U
MN6F[('IM96YY`%IR=;GM('!O<VQE9&[Z(&%K8VEU`$YE;^AA:^%V86[A(&]D
M<&]V9>\@;V0@<V5R=F5R82!P;^AA<R!S<&]J96YI83H@`$YE;^AA:^%V86[A
M(&]D<&]V9>\@;V0@<V5R=F5R82!N83H@`$YE;F%S=&%V96[A`$YE;[EE=')E
M;OT@:V]M<&]N96YT('1Y<'4Z("5S`%-P;VIE;ND@87)A8G-KZ2!E;6ERX71Y
M`%9EM6OA($)R:73A;FEA`%-P;VIE;ND@N73A='D@06UE<FEC:^D`2F5D;F]T
M:WD`3F5Z;N%M90!.97INX6UY(&3A='5M`$YE>F[A;6$@24U!4"!O9'!O=F7O
M(&]D('-E<G9E<F$N(%-E<G9E<B!O9'!O=F5D86PZ("5S`$YE>F[A;64@<W1R
M971N=71I90!.97INX6UY('!R[6IE;6-A`$YE>F[A;64@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2X`3F5Z;N%M92!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+@!";VQA('IA9&%NX2!N97!L871NX2!L;VMA;&ET82X`3F5Z;N%M
M92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S;&\N`$]D<W1RX6YINR!L
M:6YK=2!Z(&%K='7A;&YE:&\@96QE;65N='4`3V1S='+A;FF[(&AE<VQO('H@
M<&%MY'1I`$YE<&]M96YO=F%NX0!.97!R:79I;&5G;W9A;ND@<VMR:7!T>2!N
M96UA:OH@>B!B97IP9>AN;W-T;OUC:"!D]'9O9&]V('!R[7-T=7`@:R!V;[5B
MX6T@5GES=')I:&[ZNR]+;W#M<F]V8;LO5FQOOFF[+B!+;&EK;FET92!N82!/
M2R!A('IO8G)A>NT@<V$@=&5C:&YI8VOA(&EN9F]R;>%C:6$@;F$@<W1RX6YK
M92!M;WII;&QA+F]R9RP@:W1O<N$@5N%S(&EN9F]R;75J92P@86MO('5M;[YN
M:;L@<VMR:7!T=2!P<NUS='5P(&L@<V-H<N%N:V4N`$YE<')EZ.UT86[I`$]D
M<W1RX6YINR!F87)B=0!/9&ALX7-INR!S82!Z('!R:67H:6YK82`H<')I9>AI
M;FMO=BD`3F5P;V1P;W)O=F%NZ2!R;WJY[7)E;FEE`$%K='5A;&EZX6-I80!!
M:W1U86QI>F]V8;L@)7,`06MT=6%L:7IO=F&[('-T878@^NAA<W1N[6MA`$%K
M='5A;&EZ;W9ANR!P;W6^[79A=&6U80!!:W1U86QI>N%C:6$@(B5S(B!B;VQA
M(/IS<&6Y;N$N`%-K<FEP="!N82!U<&=R861E(&)O;"!V>6UA>F%N_2X`3F%H
M<F&[`%:Y971K>2!S^F)O<GD@<R!K;VYF:6=U<N%C:6]U(&)O;&D@;F%H<F%N
MZ2!N82!S97)V97(N`%9EM6OI(&QA=&EN<VOI('#M<VUE;N$`5F6U:^D@<NUM
M<VME(.CM<VQI8V4`57)U9W5A>0!0;W6^:;L@86MT=>%L;F4Z("5S`%!O=;YI
MNR!P<F5D;F%S=&%V96[Z(&AO9&YO='4`4&]UOFF[('!R:6ALX7-E;FEE(&1O
M('!R:67H:6YK;W8@24U!4#\`4&]UOFF[(%-33`!0;W6^:;L@<')I9>AI;F]K
M('9I<G1UX6QN96AO($MON6$_`%!O=;YI=&4@=B!P<NUP861E+""^92!J92!M
M96YO+VAE<VQO(&]D;&FY;ND@<')E($E-4U`@<V5R=F5R+@!0;W6^[79A=&6U
M`%!O=;[M=F%T9;5O=FD@(B5S(B!B;VQI(/IS<&6Y;F4@<')I9&5L96[I('!R
MX79A('!R92!P<FEEZ&EN;VL@(B5S(BX`4&]UONUV871EM2`E<R!N:64@:F4@
M875T;W)I>F]V86[](&YA("5S+@!3<'+A=F$@<&]UONUV871EM6]V`%!O=;[M
M=F%T9;5S:^D@;F%S=&%V96YI80!296=I<W1RX6-I82!P;W6^[79A=&6U80!2
M96=I<W1RX6-I82!P;W6^[79A=&6U;W8@8F]L82!P<F4@=&5N=&\@<WES=.EM
M('IA:^%Z86[A+@!0;W6^[79A=&6U<VO](/KH970@;F5B;VP@;N%J9&5N_0!0
M<FEH;&%S;W9A8VEE(&UE;F\`4&]UONUV871EM7-KZ2!M96YO("(E<R(@=;X@
M97AI<W1U:F4N`%!R:6AL87-O=F%C:64@;65N;SH`4&]UONUV871EM7-KZ2!M
M96YO.B``4&]UONUV871E;&EA('-Y<W3I;74Z`%5Z8F5K:7-T86X`5D93(&%D
M<F5SX7(@;F5E>&ES='5J92X`1&]V;VQE;FMA`%!L871NZ2!U;6EE<W1N96YI
M82!Z86C@\F%J^CH@`%!L871N;W.[`%!L871N;W.[('8@;6EN^G1A8V@@;V1T
M97)A>BX`2&]D;F]T82!P<F5K<F_H:6QA(&UA>&EMX6QN=2!DY;YK=2`E<RX`
M2&]D;F]T>0!(;V1N;W1Y+"!Z(&MT;W+]8V@@<VD@;?2^971E('9Y8G)ANP!6
M86YU871U`%!R96UE;F[A`%9E;F5Z=65L80!/=F5R96YI92!Z;'EH86QO("T@
M=.%T;R!S<'+A=F$@;6]H;&$@8GF[('-F86RY;W9A;N$N`%9E<GII80!-86YA
MOFUE;G0@=F5R>FGM`%9E<G1I:^%L;F4@>F%R;W9N86YI90!697)T:6OA;&YE
M('9Y<&QN96YI90!697)T:6OA;&YE.@!69;5M:2!V>7-O:^$`5FEE=&YA;0!:
M;V)R87IINP!:;V)R87IINR`E<P!:;V)R87IINR`E<R!V97)E:F[](&NU^N@`
M6F]B<F%Z:;L@2%1-3"!O8G-A:"!V(&YO=F]M(&]K;F4`6F]B<F%Z:;L@<W!R
MX79Y`%IO8G)A>FF[(&]S;V)N_2!P<FEVX71N>2!KM?KH`%IO8G)A>FF[(&]S
M;V)N_2!V97)E:F[](&NU^N@`6F]B<F%Z:;L@=FSA:VYO`%IO8G)A>FF[(&EK
M;VYU`%IO8G)A>FF[(&5X=&5R;OH@=W=W('-T<N%N:W4`6F]B<F%Z:;L@86MO
M("5S`%IO8G)A>FF[('!R[6QO:'4@=B!N;W9O;2!O:VYE`%IO8G)A>FF[(&]B
M<V%H('8@;F]V;VT@;VMN90!:;V)R87IINR!U9&%L;W.[`%IO8G)A>FF[('-P
M<N%V>2!V("5S`%!O('!R:6ALX7-E;NT@>F]B<F%Z:;LZ`%IO8G)A>FF[(/IL
M;VAU`%IO8G)A>FF[(&]B<N%Z:WD`0G)I='-KZ2!086YE;G-KZ2!O<W1R;W9Y
M`$%M97)I8VOI(%!A;F5N<VOI(&]S=')O=GD`5FER='7A;&YY('!R:67H:6YO
M:R`B)7,B(&)O;"#Z<W!EN6YE('9Y='9O<F5N_2X`5FER='7A;&YY('!R:67H
M:6YO:R!N965X:7-T=6IE+@!6:7)T=>%L;F4@<')I9>AI;FMY`%9I<G1UX6QN
M>2!P<FEEZ&EN;VL@<&]T<F5B=6IE('!O<&ES;VLN`%9I<G1UX6QN82!S8VAR
MX6YK82!P<FEJ873]8V@@<W!RX78`5FER='7A;&YY('!R:67H:6YO:R!P<FEJ
M873]8V@@<W!RX78`5FER='7A;&YY($OTN0!0<FEEZ&EN;VL@=FER='7A;&YE
M:&\@:V^Y80!0<FEEZ&EN;VL@=FER='7A;&YE:&\@:V^Y82!N965X:7-T=6IE
M+@!0;W!I<V]K('9I<G1UX6QN96AO('!R:67H:6YK=0!6:61I=&6U;F]SNP!6
M:61I=&6U;F]SNSH@`%9O9&%F;VYE($ET86QY(&-E>B!33510`%9!4D]604Y)
M10!54$]:3U).14Y)12$A(2!/1%-44L'25$4@4TM225!4(%H@)7,@4E7(3D4N
M`%=)3B!C97H@2%144`!786QL:7,@82!&=71U;F$`5F%R;W9A;FEE`%-T`%!R
M961P;W9E[R!P;^AA<VEA`-ID86IE(&\@<&_H87/M('!O<VMY='5J90!796%T
M:&5R+F-O;0!796(`5U=7('-T<N%N:V$`5/V^9&5N;F4`5FET86IT90!6[71A
M(%;A<R`E<P!6:71A:G1E+"`E<P!:X7!A9&[A(%-A:&%R80!+=&]R^B!A<&QI
M:^%C:74@;>$@)7,@>F]B<F%Z:;L@<&\@<')I:&SA<V5N[3\`06O](&IE('IN
M86L@<')E(&]D9&6U;W9AZ#\`06O](&IE('IN86L@<')E(/IV;V1Z;W9K=3\`
MR&\@<V$@;>$@=7)O8FF[(',@;F5V>;YI861A;F]U('!ON71O=2!P;R!J96H@
M;VALX7-E;NT@86MO('-P86T@86QE8F\@;F6Y:V]D;OH@<&^Y='4_`%!R97-U
M;OJ[('9Y;6%Z86[I('-P<N%V>2!D;R!/9'!A9&MO=NEH;R!K;[EA(&YA;6EE
M<W1O(&EC:"!O>FYAZ&5N:6$@>F$@=GEM87IA;ND_`$YA(&MT;W)E:B!S=')A
M;F4@8VAC971E('IAZ&&[('!R97IE<F%N:64@<W!RX78@<')I(&]T=F]R96[M
M(&YO=F5J('-C:'+A;FMY/P!-86KZ('-A('5L;[YINR!P<NUL;VAY('!R:2!U
M:VQA9&%N[2!O9&]S;&%N96H@<&^Y='D_`%!R:2!P;W-I96QA;NT@<&^Y='D@
M86QE8F\@9&]PY?)A;NT@861R:65S+"!A:^$@9&]MZ6YA('-A(&WA(&1O<&QN
M:;L@>F$@;F7Z<&QNZ2!A9')E<WD@*&4M;6%I;&]VZ2!A9')E<WD@8F5Z(")`
M(BD_`$UA<&$@075S='+A;&EE('!R92!S;'6^8G4@5VAE<F5I<P!+=&]RZ2!F
MX7IY`$MT;W+I('KA<W5V;ND@;6]D=6QY('!O=F]L:;L@<')E(')O>KGM<F5N
M_2!T97AT;W;](&5D:71O<BX`0FEE;&$@;&ES=&EN80"I[7)K80"I[7)K82!V
M(&IE9&YO=&OA8V@@0U-3`*GM<FMA(&UE;G4@)7,@=K5A=F\@*'!R96IA=NT@
M<V$@<')I(.]A;+EO;2!P<FEH;.%S96[M*3H`J>UR:V$@=&%B=;5K>0!*961N
M;W1K82"Y[7)K>0"I[7)K83H`5VEK:0!6:65T;W(`4N%N;R!V:65T;W(`4OUC
M:&QO<[L@=F5T<F$@=B!U>FQO8V@`5FEE=&]R.@!6:65T;W(Z(`!-^F1R;W.[
M`%=I<VAL:7-T`%!RX6-A`$%D<F5S82!D;R!P<N%C90!496QE9O-N(&1O('!R
MX6-E`$YE<W!RX79N>2!P;^AE="!P;VSM(&YA(')I861K=2`E9"X@3^AA:^%V
M82!S82`E9"P@;F&Y;&\@<V$@)60N`$YE<W!RX79N>2!P;^AE="!P;VSM+B!/
MZ&%KX79A('-A("5D+"!N8;EL;R!S82`E9"X`6FS](&]F9G-E="`E9"!P<FD@
MZ.UT86[M(%9&4R!S^F)O<G4N`%@M4F5F`%KA:VQA9&[I(&]B;65D>F5N:6$@
M6#4P.78S`%!O=;YI=&EE(')O>KGM<F5NZ6AO(&NU^NAA(%@U,#EV,P!!;'1E
M<FYA=.UV;F4@;65N;R!S=6)J96MT=2!8-3`Y=C,`261E;G1I9FEKX71O<B!K
MM?KH82!S=6)J96MT=2!8-3`Y=C,`6#4P.78S(')O>KGM<F5N:6$`65D`65E9
M60!986AO;R$@;6%P`%)OZ&YE`$IE;65N`,%N;P!3^FAL87/M;2X`0VAY<W3A
M=&4@<V$@<W1I86AN=;L@<&^Y='4@>B!N87-L961U:OIC:6-H(/KH=&]V.@!#
M:'ES=.%T92!S82!V>6UA>F&[(':Y971K>2!S<'+A=GD@=B!N87-L961U:OIC
M;VT@<')I9>AI;FMU("AP<FEEZ&EN:V]C:"DN`$-H>7-TX71E('-A('9Y;6%Z
M8;L@;F%S;&5D=6KZ8VD@<')I9>AI;F]K("AP<FEEZ&EN:WDI+@!+;W#M<G5J
M971E+W!R97/Z=F%T92!D;R!N;W;I:&\@<')I9>AI;FMA+@!6>71VX7)A=&4@
M<')I9>AI;F]K('8@`%9Y=';A<F%T92!P<FEEZ&EN;VL@;F%J=GFYN65J(/IR
M;W9N92X`4W1E('8@5$585$]63TT@4D6N24U%+B!0;W6^:71E('1L8>AI9&QO
M(%L\/ET@;F$@<')E<&YU=&EE(&YA<W#DNR!D;R!765-)5UE'+@!.96WA=&4@
M;W!RX79N96YI92!N82!V>71VX7)A;FEE('!R:67H:6YK;W8N`$YE;?2^971E
M('9Y='9O<FF[('9I86,@86MO("5D(&)L;VMO=BX`3F5MX71E(&]P<N%V;F5N
M:64@=GET=F]R:;L@=FEA8R!A:V\@)60@<')I9>AI;FMO=BX`3FEE('-T92!A
M=71E;G1I9FEK;W9A;OTN`%!R96UE;OIV871E('!R:67H:6YO:SH@`%8@=&5X
M=&4@N6%B;/-N>2!M]+YE=&4@<&]UOFF[(&YA<VQE9'5J^F-E(+EP96-IX6QN
M92!Z;F%K>3H@)6,@<')E(&]B<V%H(&%K='7A;&YE:B!S<'+A=GD[("5S('!R
M92!S:6=N873Z<G4N`%9O(%9AN6]M('!L;F]M(&UE;F4@;F5M]+YE=&4@<&]U
MOFF[('IN86L@)UPG+@!.96WTOF5T92!S82!O9&ALX7-INR!Z("(E<R(N`$YE
M<_IH;&%S:6QI('-T92!S('!O9&UI96YK86UI('!O=;YI=&EA+"!T86N^92!S
M82!N96WTOF5T92!P<FEH;.%S:;LN`$YE>F%D86QI('-T92!P;&%T;OH@92UM
M86EL;W;Z(&%D<F5S=2X`3F5U<NAI;&D@<W1E('9ZNV%H(&UE9'II(+YI861N
M>6UI('!O;&EA;6D@>B!I;7!O<G1O=F%NZ6AO('/Z8F]R=2!A('IO9'!O=F5D
M86KZ8VEM:2!P;[5A;6D@=B`E<RX`3F5MX71E('!RX79O(&YA<W1A=FF[('!R
M[7-T=7`@:R!T;VUU=&\@<')I9>AI;FMU`%!R97!O<VQA;&D@<W1E('3Z=&\@
M<W!RX79U("4E<R!N87-L961O=F[];2!P<NUJ96UC;VTZ("5S+@!-X71E("5S
M(&YO=OUC:"!S<'+A=BX`3>%T92`Q(&YO=OH@<W!RX79U+@!4^G1O('-T<N%N
M:W4@<W1E('6^(&]D;W-L86QI+@!";VQI('-T92!O9&ALX7-E;OTN`$WA=&4@
M;F]V^B!P;[ET=2!V(&YA<VQE9'5J^F-O;2!P<FEEZ&EN:W4Z`$WA=&4@;F]V
M^B!P;[ET=2!V(&YA<VQE9'5J^F-I8V@@<')I9>AI;FMO8V@Z`$UU<^UT92!Z
M861ANR!P;&%T;ND@Z.US;&\@;6]B:6QNZ6AO('1E;&5F\VYU+"!K=&]RZ2!O
M8G-A:'5J92!I8F$@Z.US;&$@<R!V;VQI=&6U;OUM('!R969I>&]M("<K)R!P
M<F4@;65D>FENX7)O9&[](&9O<FWA="X`375S[71E('IA9&&[('!L871N^B!H
M;V1N;W1U+@!!8GD@<W1E(&UO:&QI('!O=;[M=F&[(%)E9VES='+A8VEE+"!M
M=7/M=&4@;F%J<VOT<B!N86MO;F9I9W5R;W9ANR!$871A5')E92!B86-K96YD
M+@!-=7/M=&4@;F%K;VYF:6=U<F]V8;L@5D93(&)A8VME;F0N`$UU<^UT92!P
M;W#M<V&[('!R;V)LZ6T@<')E9'3];2P@86MO(&]D;[EL971E('-P<N%V=2!O
M('!R;V)LZ6UE+@!-=7/M=&4@>F%D8;L@;6&[(&%S<&_R(&IE9&[I:&\@<'+M
M:F5M8W4N`$UU<^UT92!Z861ANR!54DP@861R97-U+"!N82!K=&]R^B!TX71O
M(&QI;FMA('5K87IU:F4`3F$@>F]B<F%Z96YI92!T96IT;R!S<'+A=GD@;75S
M[71E('IA9&&[(&AE<VQO('!R92!6X;D@;W-O8F[]('!R:7;A=&YY(%!'4"!K
MM?KH`$YA('IO8G)A>F5N:64@=&5J=&\@<W!RX79Y(&UU<^UT92!Z861ANR!H
M97-L;R!P<F4@5N&Y(&]S;V)N_2!P<FEVX71N>2!3+TU)344@:[7ZZ`!-=7/M
M=&4@;F%J<')V('9Y8G)ANR!C:66U;W;Z('-C:'+A;FMU+@!-=7/M=&4@;WIN
M8>AINR#ZZ&5T+"!K=&]R_2!MX2!B>;L@=GEM87IA;OTN`$UU<^UT92!N86IP
M<G8@=GEB<F&[(&%D<F5S=2X`375S[71E('9Y8G)ANR!S97)V97(L(&MT;W+]
M(&WA(&)YNR!V>6UA>F%N_2X`375S[71E(&YA:G!R=B!V>6)R8;L@87-P;_(@
M:F5D;G4@<W!RX79U+@!-=7/M=&4@=7+H:;L@<'+M:F5M8W4N`$UU<^UT92!U
M<NAINR!M96YO('!O=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!V>6UA>F&[
M+@!-=7/M=&4@=7+H:;L@;65N;R!P;W6^[79A=&6U82P@:W1O<NEH;R!C:&-E
M=&4@=GEM87IANRX`375S[71E('5RZ&F[(&UE;F\@<&]UONUV871EM6$L(&MT
M;W+I:&\@8VAC971E('!R:61ANRX`375S[71E('5RZ&F[('!O=;[M=F%T9;5A
M+"!K=&]R_2!S82!MX2!A:W1U86QI>F]V8;LN`$UU<^UT92!U<NAINR!A:V-I
M=2P@:W1O<N$@<V$@;>$@=GEK;VYANRX`375S[71E('IA9&&[(&UE;F\@;F]V
M96H@:V%T96?S<FEE+@!6(&YA<W1A=F5N:6%C:"#Z9'*^8GD@;75S[71E(&UA
MNR!P;W9O;&5NZ2`B)7,B+@!-=7/M=&4@>F%D8;L@=&%L:6%N<VME('1E;&5F
M\VYN92#H[7-L;P!0<F5S;65R;W9A;&D@<W1E('3Z=&\@<W!RX79U("5S("4E
M<RX`3V1P;W9E9&%L:2!S=&4@;F$@=/IT;R!S<'+A=G4@)7,N`$YE8F]L:2!S
M=&4@<')I:&SA<V5N_2!D;R`B)7,B+B``3F5B;VQI('-T92!O9&ALX7-E;OT@
M>B`B)7,B+B``0F]L:2!S=&4@^G-P9;EN92!P<FEH;.%S96[](&1O("(E<R(N
M`$)O;&D@<W1E(/IS<&6Y;F4@;V1H;.%S96[]('H@(B5S(BX`4&QA=&YO<[L@
M5F&Y96H@<F5LX6-I92!P<F4@87!L:6OA8VEU("5S('9Y<'*Y86QA+B!0<F]S
M[6T@<')I:&SA<W1E('-A('IN;W9U+@!68;EA($5M86EL;W;A(&%D<F5S80!6
M8;EA($5M86EL;W;A(&%D<F5S82!P;W6^:73A('!R92!O9&-HX61Z86KZ8W4@
M<&^Y='4Z`%9AN64@:6YF;W)MX6-I90!68;EA(&EN=&5R;F5T;W;A(&%D<F5S
M82!S82!Z;65N:6QA(&]D('IAZ&EA=&MU(%9AN65J(')E;.%C:64@)7,N(%!R
M92!68;EU(&)E>G!EZ&YO<[L@<V$@;75S[71E('IN;W9U('!R:6ALX7-INRX`
M5F&Y92!C96SI(&UE;F\`5F&Y92!01U`@:[7ZZ&4`5N&Y('!R:7;A=&YY(&NU
M^N@`5N&Y('9E<F5J;OT@:[7ZZ`!68;EA(&%D<F5S82!P<F4@;V1P;W9E[R`H
M4F5P;'DM=&\I.B`\96T^;F5P;W9I;F[I*3PO96T^`%9AN64@4R]-24U%('9E
M<F5J;NDO<')I=N%T;F4@8V5R=&EF:6OA='D`5F&Y92#ZZ'1Y.@!68;EE(&%L
M:6%S>3H@/&5M/BAV;VQI=&6U;NDL('IA9&%J=&4@:V&^9/H@861R97-U(&YA
M(&YO=F]M(')I861K=2D\+V5M/@!6X;D@875T96YT:69I:V'H;OT@;6]D=6P@
M;F5P;V1P;W)U:F4@<')I9.%V86YI92!P;W6^[79A=&6U;W8N($%K('-I(+YE
M;.%T92!P;W6^:;L@2&]R9&4@;F$@<W!RX79U('!O=;[M=F%T9;5S:_UC:"#Z
MZ'1O=BP@;75S[71E('!O=;YINR!I;OT@875T96YT:69I:V'H;OT@8F%C:V5N
M9"X`5N&Y(&%U=&5N=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('IO8G)A
M>F]V86YI92!Z;WIN86UU('!O=;[M=F%T9;5O=BP@86QE8F\@8F]L82!TX71O
M(&UOOFYO<[L@>B!N96IA:^EH;R!D]'9O9'4@>F%KX7IA;N$N`%IDX2!S82P@
MOF4@5N&Y('!R96AL:6%D8>@@<V$@>FUE;FEL(&]D('IAZ&EA=&MU(%9AN65J
M(')E;.%C:64@)7,N(%!R92!68;EU(&)E>G!EZ&YO<[L@<V$@;75S[71E('IN
M;W9U('!R:6ALX7-INRX`5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@<')I
M86UE('IO8G)A>F5N:64@=&]H=&\@='EP=2!O8G+A>FMO=BX`5N&Y('!R96AL
M:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU+@!6X;D@<')E:&QI861A
MZ"!N97!O9'!O<G5J92!T^G1O(&9U;FMC:74@=&QAZ&4N(%-T;&'H=&4@0V]N
M=')O;"]#;VUM86YD("L@4"!P<F4@=&QAZ"X`5F&Y82!A:W1UX6QN82#H87-O
M=N$@>O-N83H`5F&Y82!P<F5D;F%S=&%V96[A('IN86MO=N$@<V%D82!P<F4@
M<&]S:65L86YI92!S<'+A=CH`5N&Y('!R961N87-T879E;OT@<W#T<V]B(+EI
M9G)O=F%N:6$@<')E('!O<VEE;&%N:64@<W!RX78Z`%9AN6$@<')E9&YA<W1A
M=F5NX2!I9&5N=&ET82!B;VQA('IM96YE;N$N`%!R961N87-T879E;N$@:61E
M;G1I=&$Z`%9AN64@;65N;SH`5F&Y82!N86QI;FMO=F%NX2!P<NUL;VAA(&)O
M;&$@<W1I86AN=73A(&YA:FUE;F5J(&IE9&[];2!P;W6^[79A=&6U;VTN"@I-
M96YO('!R[6QO:'DZ("5S"D3A='5M('!R[6QO:'DZ("5S"@I+;&EK;FET92!N
M82!N87-L961U:OIC=2!L:6YK=2!N82!O9'-T<N%N96YI92!P<NUL;VAY.@HE
M<P!0;&%T;F]SNR!6X;EH;R#ZZ'1U('9Y<'*Y86QA+@!3<'+A=F$@8F]L82#Z
M<W!EN6YE(&1O<G7H96[A+@!68;EE(&YO=ND@:&5S;&\@<')E("5S(&IE.B`E
M<P!68;EE(&YA<W1A=F5N:6$@8F]L:2!A:W1U86QI>F]V86[I('!R92!T;W1O
M('-E9&5N:64N`%9AN64@;F%S=&%V96YI82!B;VQI(&%K='5A;&EZ;W9A;NDN
M`%9AN64@:&5S;&\@8F]L;R!O8FYO=F5NZ0!68;EE(&AE<VQO(&)O;&\@;V)N
M;W9E;NDL('-K;VYT<F]L=6IT92!S:2!P;[ET=2!A('!R:6ALX7-T92!S82!S
M(%9AN>UM(&YO=OUM(&AE<VQO;2X`4&QA=&YO<[L@5N&Y:&\@:&5S;&$@=GEP
M<KEA;&$N`%9AN64@=GID:6%L96[I('-E<G9E<GDZ`%9AN6$@<VEG;F%T^G)A
M.@!*=6AO<VSA=FEA`%IA:7(`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M3:W)Y
MNR!A9')E<WE=`%M3:W)YNR!C:71O=F%N_2!T97AT70!;KFEA9&YY('!R961M
M970@<W!RX79Y70!;4W!RX79A(&\@<')O8FSI;65=`%M:;V)R87IINR!A9')E
M<WD@+0!;6F]B<F%Z:;L@8VET;W9A;OT@=&5X="`M`%M:;V)R87IINR!C:71O
M=F%N_2!T97AT("T@)7,@<FEA9&MO=ET`6UIO8G)A>FF[(&%D<F5S>2`M("5S
M('!R[6IE;6-O=ET`6W)I861O:R`E<R!Z("5S70!?061M:6YI<W1RX6-I80!?
M0F-C`,AI97)N82!?;&ES=&EN80!?0TQ)`%]#8P!?1&%T851R964`7U9Y;6%Z
M8;L`7U9Y;6%Z8;L@<FEA9&]K`%]0<FEEZ&EN:WD`7U-K=7!I;GD`7U!O;6]C
M;NUK`%])9&5N=&ET80!6;&%S=&YO<W1I(%]O8G+A>FMU+BXN`%]0<FEJ873I
M('-P<N%V>0!?4')I:&SA<VF[('-A`%]/9&ALX7-INP!?6F1R;VIO=OT@=&5X
M="!S<'+A=GD`7U5P<F%V:;L@;&EN:W4N+BX`7TYO=N$@<W!RX79A`%].87-T
M879E;FEA`%]0<N%V80!?5&QAZ&F[`%]0<FEO<FET80!?3V)N;W9INR`E<P!/
M9'-T7W+A;FF[(&QI;FMU+BXN`%]/9'!O=F5D8;L`7U!R96BU863A=F&[`%]0
M;W-L8;L@<W!RX79U`$YA7W-T879E;FEE`%9L87-T;F]S=&D@7W1A8G6U:WDN
M+BX`7U9LX6MN;P!?4')E`$]B;F]?=FF[`%!O7W6^[79A=&5L:6$`7UIO8G)A
M>FF[('9LX6MN;P!?0FEE;&$@;&ES=&EN80!A9')E<^%R`&YE>F[A;7D@861R
M97/A=`!P<NUL;VAA`&%T=&%C:&UE;G1S+GII<`!B86IT;W8`:V%L96YDX7(`
M8F5Z=F5T<FEE`&YE<&]D87)I;&\@<V$@=GET=F]R:;L@<_IB;W(`;F5P;V1A
M<FEL;R!S82!O='9O<FF[('9S='5P`&ML:6MN:71E('-E;0!C:'EB;ND@<&]U
MOFET:64@<'+M:V%Z;W;I:&\@<FEA9&MU`&-H>6)A(&MO;F9I9W5RX6-I90!C
M:/UB82!K<FET:6-K>2!D]&MEOFET_2!S>7-TZ6UO=OT@<_IB;W(`8VAY8F$@
M9.%T;W;I:&\@9F]R;>%T=0!P;VQOOFMA(&YE;N%J9&5NX0!K;&5SX0!S^F)O
M<@!O9`!Z;R!S;65R=2`E<R`H)7,I('+]8VAL;W.[;W4@)7,@)7,`;N%R87IO
M=OT`=CH`:&@`;F5N>N%M92!M96YO(&AO<W1I=&6U80!O:V%MOFET90!V('-P
M<N%V90!C:'EB82!V<W1U<'4O=OUS='5P=0!V;OIT;W)NX2!C:'EB82!S;V9T
M=NER=0!KM?KH`')I861K;W9=`'/Z8F]R(',@<&^Y=&]U`'!OZ&%S('9Y=';A
M<F%N:6$@25-/(&YA<W1A;&$@8VAY8F$@;6MI<V]F<R`E9`!M;0!M96YO`+YI
M861N90!N96EM<&QE;65N=&]V86[I`'IA=&EAM2!N96EM<&QE;65N=&]V86[I
M`'!O>F[A;6MO=OT@8FQO:P!A;&5B;P!P97)C96YT`'!R[7-T=7`@>F%M:65T
M;G5T_0!B;V1O=@!P<NUJ96UC;W9=`'9Z9&EA;&5NX2!C:'EB82!P<F]T;VMO
M;'4`<W3Z<&$`<VQUOF)A(&YE9&]S='5P;N$`>F]B<F%Z:;L@<F]Z9&EE;'D`
M<VUS,F5M86EL(&-E>B!(5%10`&-H>6)A('!R879O<&ES=0!C:'EB>2!P<F%V
M;W!I<W4`<W,`=7-TX6QE;OT`<WES=.EM;W;A(&-H>6)A`'IO>FYA;2#Z;&]H
M`&1OZ&%S;N$@8VAY8F$`<')E('!O='9R9&5N:64@>F%D86IT92!H97-L;R!D
M=F%K<N%T`'5N:69I:V]V86[I`&YE<&]M96YO=F%NX0!D969I;G5J92!P;W6^
M[79A=&6U`'9#87)D`+DZ`'=E871H97(N8V]M`%9AN6$@Z&EE<FYA(&QI<W1I
M;F$`5F&Y82!B:65L82!L:7-T:6YA````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+VQO8V%L92]S:U]32R]H96QP+GAM;```````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#$R-#<R-``Q,#0Q-S,V,C<V,P`P,C$Q-#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]X;6P@=F5R
M<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,B(_/@H\(2TM("1(;W)D
M93H@:6UP+VQO8V%L92]S:U]32R]H96QP+GAM;"QV(#$N,3<N-BXT(#(P,#8O
M,#$O,S`@,34Z-3<Z-34@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@
M:60](F-O;7!O<V4M8G5T=&]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I
M=&QE/E#M<V%N:64@<W!RX79Y.B!!:V-I93PO=&ET;&4^"B`@("`\:&5A9&EN
M9SY!:V-I93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@2VQI:VYU=.UM(&YA
M('1L8>AI9&QO(")0;W-L8;L@<W!RX79U(B!P;[EL971E(%;AN2!E+6UA:6PN
M(%!R960@:VQI:VYU=.UM"G-I+"!P<F]S[6TL('5V961O;71E+""^92!O9&]S
M;&%N:64@;6%I;'4@=;X@;F5M;[YN;R!V<N%T:;L@<W#DNRX*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@(E5L;[YINR!K;VYC97!T(B!U;&^^[2!S<'+A
M=G4@=B!A:W1UX6QN;VT@<W1A=F4@86MO(&MO;F-E<'0@9&\@<')I9>AI;FMA
M"B)$<F%F=',B+"!K=&]R_2!S:2!M]+YE=&4@>F]B<F%Z:;L@<&]M;V-O=2!V
M_6)E<F]VZ6AO('1L8>AI9&QA('!R92!P<FEEZ&EN:WD@=@IP<F%V96H@:&]R
M;F5J(.AA<W1I(&YA=FEG8>ANZ6AO('!A;F5L=2X@3F5S:_1R('-A(&WTOF5T
M92!K('#M<V%N:74@<W!RX79Y"G9RX71INR!O='9O<F5N[6T@<')I9>AI;FMA
M(")$<F%F=',B+"!K;&EK;G5T[6T@;F$@=6QOOF5N^B!S<'+A=G4@82!P;W1O
M;2!N80IT;&'H:61L;R`B3V)N;W9INR(N(%!R960@=6QOOF5N[6T@:V]N8V5P
M='4@;F%S=&%V=&4@<')E9&UE="P@86)Y('-T92!H;PIN97-K]'(@;6]H;&D@
M:F5D;F]D=6-H;R!R;WIL[;EINR!O9"!O<W1A=&[]8V@@:V]N8V5P=&]V+B!0
M;R!U;&^^96[M(&MO;F-E<'1U"G-A(&%U=&]M871I8VMY(&1O<W1A;F5T92!D
M;R!P<FEEZ&EN:W4L(&MT;W+]('-T92!P<F5Z97)A;&D@86MO('!O<VQE9&[]
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("`B6G)UN6F[('-P<N%V=2(@
M>G)UN>T@<.US86YI92!S<'+A=GD@82!A=71O;6%T:6-K>2!6X7,@=G+A=&D@
M9&\*<')I9>AI;FMU+"!K=&]R_2!S=&4@<')E>F5R86QI(&%K;R!P;W-L961N
M_2X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60]
M(F-O;7!O<V4M8G5T=&]N<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY!8W1I;VYS/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD($UE<W-A9V4@;&%U;F-H97,@
M>6]U<B!E;6%I;"!T;R!T:&4@:6YT96YD960@<F5C:7!I96YT*',I+B!"92!S
M=7)E('EO=2!W86YT('1O('-E;F0@8F5F;W)E(&-L:6-K:6YG(&AE<F4@87,@
M;VYC92!S96YT(&ET(&-A;FYO="!B92!T86ME;B!B86-K+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("!3879E($1R869T('!L86-E<R!A;B!U;F9I;FES
M:&5D(&UE<W-A9V4@:6X@82!F;VQD97(@8V%L;&5D("=$<F%F=',G"F%C8V5S
M<VEB;&4@8GD@=&AE('!O<"UD;W=N(&)O>"!O;B!T:&4@<FEG:'0@<VED92!O
M9B!T:&4@8FQU92!N879I9V%T:6]N(&)A<B!A="!T;W`N(%EO=2!C86X@=&AE
M;B!F:6YI<V@@=&AE(&UE<W-A9V4@;&%T97(@8GD@<W=I=&-H:6YG('1O('1H
M92`G1')A9G1S)R!F;VQD97(L(&-L:6-K:6YG(&]N('1H92!S879E9"!M97-S
M86=E('1O(&]P96X@:70L(&%N9"!T:&5N(&-L:6-K:6YG(&]N("=297-U;64G
M+B!"92!S=7)E('1O('!U="!A('-U8FIE8W0@;VX@=&AE(&5M86EL(&)E9F]R
M92!Y;W4@<V%V92!T:&4@9')A9G0@<V\@=&AA="!Y;W4@8V%N(&5A<VEL>2!I
M9&5N=&EF>2!W:&EC:"!M97-S86=E('EO=2!W86YT('=I=&AI;B!T:&4@1')A
M9G1S(&9O;&1E<BX@069T97(@<V%V:6YG(&%S(&$@1')A9G0L('EO=2!A<F4@
M<F5T=7)N960@=&\@>6]U<B!)3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U
M('=E<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!#86YC96P@365S<V%G92!D<F]P<R!T:&4@;65S<V%G92!I;B!P<F]G<F5S
M<R!A;F0@<VEM<&QY(')E='5R;G,@>6]U('1O('1H92!)3D)/6"!O<B!W:&%T
M979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A
M/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+69R
M;VTB('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y0[7-A;FEE('-P<N%V
M>3H@3V0\+W1I=&QE/@H@("`@/&AE861I;F<^(D]D(CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@6F%D86IT92!68;EU(&4M;6%I;&]V^B!A9')E<W4L(&MT
M;W+A('-A(&)U9&4@875T;VUA=&EC:WD@>F]B<F%Z;W9ANR!V"F]D8VCA9'IA
M:OIC:6-H(&4M;6%I;&]C:"!V(&AL879IZ&ME(")/9#HB+@H@("`@/"]P87)A
M/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UF<F]M
M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!&<F]M/"]T:71L
M93X*("`@(#QH96%D:6YG/B9Q=6]T.T9R;VTF<75O=#L\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($5N=&5R('EO=7(@8V]R<F5C="!E;6%I;"!A9&1R97-S
M+B!9;W5R(&5M86EL(&%D9')E<W,@:7,@875T;VUA=&EC86QL>2!E;G1E<F5D
M(&9O<B!Y;W4@9F]L;&]W:6YG("9Q=6]T.T9R;VTZ)G%U;W0[(&EN(&]U=&=O
M:6YG(&5M86EL+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)C;VUP;W-E+71O(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\
M=&ET;&4^4.US86YI92!S<'+A=GDZ(%!R93PO=&ET;&4^"B`@("`\:&5A9&EN
M9SXB4')E(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@6F%D86IT92!E+6UA
M:6QO=OH@861R97-U('!R[6IE;6-U*&]V*2X@3V1D9;5U:G1E(&%D<F5S>2#H
M:6%R:V]U+"!P;W6^:71I90II;NEH;R!Z;F%K=2!S</1S;V+M(&-H>6)U+B!:
M861A;N$@:&]D;F]T82!S82!Z;V)R87IU:F4@=B!E+6UA:6QO=F5J(&AL879I
MZ&ME"B)0<F4Z(BX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\
M96YT<GD@:60](F-O;7!O<V4M=&\B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ(%1O/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.U1O)G%U
M;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C
M="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E('EO=7(@
M;65S<V%G92X@66]U(&UU<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@
M82!C;VUM83L@;W1H97(@<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@
M97)R;W(N(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O=#M4;SHF<75O=#L@:6X@
M;W5T9V]I;F<@;6%I;"X@(`H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6-C(B!S=&%T93TB=6YK;F]W;B(^
M"B`@("`\=&ET;&4^4.US86YI92!S<'+A=GDZ($-C/"]T:71L93X*("`@(#QH
M96%D:6YG/B)#8R(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%IA9&%J=&4@
M92UM86EL;W;Z(&%D<F5S=2!P<NUJ96UC=2AO=BD@:_-P:64@<W!RX79Y+B!/
M9&1EM75J=&4@861R97-Y"NAI87)K;W4L('!O=;YI=&EE(&ENZ6AO('IN86MU
M('-P]'-O8NT@8VAY8G4N(%IA9&%NX2!H;V1N;W1A('-A('IO8G)A>G5J92!V
M"F4M;6%I;&]V96H@:&QA=FGH:V4@(D-C.B(N($OS<&EE(&4M;6%I;&]V('-A
M(&]B>>AA:FYE('!O<VEE;&%J^B"U=>]O;2P@:W1O<NT*<_IV:7-I82!S(&1A
M;F]U('-P<N%V;W4L(&D@:V7O(&YI92!S^B!J96H@<')I86UY;6D@<'+M:F5M
M8V%M:2`H;F%P<NUK;&%D(&ME[PIDX79A=&4@;FEE:V]M=2!N:67H;R!N82!V
M961O;6EE*2X@5KEE=&-I('!R[6IE;6-O=FEA('5V961E;NT@=B`B4')E.B(@
M80HB0V,Z(B!V:61I82!O8F$@>F]Z;F%M>2!A9')I97,N"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6-C(CX*
M("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!#8SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SXF<75O=#M#8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@
M=&AO<V4@=&\@<F5C96EV92!A(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G
M92X@4V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM82X@66]U<B!E
M;G1R>2!F;VQL;W=S("9Q=6]T.T-C.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL
M+B!#87)B;VX@8V]P:65S(&%R92!U<W5A;&QY('-E;G0@=&\@<&5O<&QE(&]T
M:&5R('1H86X@=&AE(&]N92AS*2!B96EN9R!W<FET=&5N('1O(&1I<F5C=&QY
M(&)U="!A<F4@:6UP;W)T86YT(')E8VEP:65N=',@;V8@=&AE(&5M86EL(&%S
M('=E;&PL('5S=6%L;'D@<V]M96]N92!I;F1I<F5C=&QY(&-O;F-E<FYE9"!A
M8F]U="!T:&4@<W5B:F5C="!O9B!T:&4@96UA:6PN("!!;&P@)U1O.B<@<F5C
M:7!I96YT<R!A;F0@)T-C.B<@<F5C:7!I96YT<R!C86X@<V5E('1H92!E;G1I
M<F4@;&ES="!O9B!B;W1H(&MI;F1S(&]F(')E8VEP:65N=',N"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M8F-C(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^4.US86YI92!S<'+A
M=GDZ($)C8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB0F-C(CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@6F%D86IT92!E+6UA:6QO=OH@861R97-U('!R[6IE
M;6-U*&]V*2!S:W)Y=&5J(&OS<&EE('-P<N%V>2X@3V1D9;5U:G1E"F%D<F5S
M>2#H:6%R:V]U+"!P;W6^:71I92!I;NEH;R!Z;F%K=2!S</1S;V+M(&-H>6)U
M+B!:861A;N$@:&]D;F]T82!S80IZ;V)R87IU:F4@=B!E+6UA:6QO=F5J(&AL
M879IZ&ME(")"8V,Z(BX@4VMR>73I(&OS<&EE('-A(&]B>>AA:FYE('!O<VEE
M;&%J^@JU=>]O;2P@:W1O<NT@<&]T<F5B=6KZ(.CM=&&[('-P<N%V=2!"15H@
M5$](3RP@86)Y(&\@=&]M('!R:6%M:2`H(E!R93HB*2!A;&5B;PIN97!R:6%M
M:2`H(D-C.B(I('!R[6IE;6-O=FEA('9E9&5L:2X*("`@(#PO<&%R83X*/"$M
M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8F-C(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@
M/&AE861I;F<^)G%U;W0[0F-C)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T
M:&]S92!T;R!R96-E:79E(&$@8FQI;F0@8V%R8F]N(&-O<'D@;V8@>6]U<B!M
M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A
M(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E
M<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T)C8SHF<75O=#L@:6X@
M;W5T9V]I;F<@;6%I;"X@0FQI;F0@8V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL
M>2!S96YT('1O('!E;W!L92!O=&AE<B!T:&%N(&1I<F5C="!A;F0@:6YD:7)E
M8W0@<F5C:7!I96YT<R`H)G%U;W0[5&\Z)G%U;W0[(&%N9"`F<75O=#M#8SHF
M<75O=#L@<F5C:7!I96YT<RD@=VAO(&YE960@=&\@<F5A9"!W:&%T(&ES(&)E
M:6YG('=R:71T96X@87,@=V5L;"!7251(3U54('1H92!O=&AE<B!R96-I<&EE
M;G1S(&MN;W=I;F<@=&AA="!T:&5Y(&%R92!R96-E:79I;F<@=&AE(&5M86EL
M+B!4:'5S("=B;&EN9"<@;65A;G,@=&AA="!T:&4@:61E;G1I='D@;V8@=&AE
M<V4@<F5C:7!I96YT<R!I<R!H:61D96X@9G)O;2!A;&P@;W1H97(@<F5C:7!I
M96YT<R!O9B!T:&4@96UA:6PL(&%N9"!O;FQY('EO=2!A;F0@=&AE>2!K;F]W
M('1H97D@9V]T(&$@8V]P>2X@66]U('1Y<&EC86QL>2!U<V4@=&AI<R!T;R!T
M96QL(&%N(&%U=&AO<FET>2!F:6=U<F4@=&AA="!Y;W4@87)E('1E;&QI;F<@
M<V]M96]N92!S;VUE=&AI;F<@=VET:&]U="!A;&%R;6EN9R!T:&4@<&5R<V]N
M('EO=2!A<F4@<V5N9&EN9R!T:&4@86-T=6%L(&5M86EL('1O+@H@("`@/"]P
M87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E
M+7-U8FIE8W0B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y0[7-A;FEE
M('-P<N%V>3H@4')E9&UE=#PO=&ET;&4^"B`@("`\:&5A9&EN9SXB4')E9&UE
M="(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%IA9&%J=&4@<')E9&UE="!S
M<'+A=GDN(%IA9&%NX2!H;V1N;W1A('-A('IO8G)A>G5J92!V(&4M;6%I;&]V
M96H@:&QA=FGH:V4*(E!R961M970Z(BX@4')E9&UE="!S<'+A=GD@8GD@;6%L
M(&)YNR#H;R!N86IK<F%TN>T@=&5X="!V>7-T:6AU:OIC:2!P;V1S=&%T=0IE
M+6UA:6QU+"!K=&]R_2!6X6T@82!P<NUJ96UC;VT@5N&Y:&\@92UM86EL=2!P
M;VWTOF4@=B!O<F=A;FEZ;W9A;NT@82!T<FEE9&5N[0IP;[ET>2X@06L@;V1P
M;W9I971E(&YA(&4M;6%I;"P@86QE8F\@:&\@<&^Y;&5T92#O86QE:BP@<')E
M9&UE="!S<'+A=GD@<V$*<VMO<.UR=6IE(&1O('!R961M971U(&YO=F5J('-P
M<N%V>2!A('-P<N%V>2!V>71VX7)A:OH@(G9LX6MN;R(@*'1H<F5A9"D*9&ES
M:W5S:64N($%K(':Y86L@92UM86EL+"!K=&]R_6T@;V1P;W9E9.%T92P@86QE
M8F\@:W1O<OT@<')E<&]S:65L871E+`IO8G-A:'5J92!N;W;I(&UYN6QI96YK
M>2P@;?2^971E('!R961M970@<W!RX79Y(+5U8F]V;[5N92!M96YINRP@86)Y
M('!R[6IE;6-A"G9I9&5L(';]=F]J(")V;.%K;F$B+@H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T
M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!3=6)J96-T/"]T
M:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.U-U8FIE8W0F<75O=#L\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!S=6)J96-T(&]F('EO=7(@
M;65S<V%G92X@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.U-U8FIE8W0Z)G%U
M;W0[(&EN(&]U=&=O:6YG(&UA:6PN($ME97`@:70@<VAO<G0L('-I;7!L92!A
M;F0@9&5S8W)I<'1I=F4N("!4:&4@<W5B:F5C="!L:6YE(&ES('1H92!E87-I
M97-T('=A>2!F;W(@>6]U(&%N9"!Y;W5R(&-O<G)E<W!O;F1E;G1S('1O(')E
M;65M8F5R('=H870@=V%S(&EN('1H92!E;6%I;"!A;F0@=&AU<R!I<R!V97)Y
M(&EM<&]R=&%N="!I;B!O<F=A;FEZ:6YG('EO=7(@96UA:6P@86YD(&9I;F1I
M;F<@:6UP;W)T86YT(&]N97,@;&%T97(N("!!;'-O+"!W:&5N('EO=2`G4F5P
M;'DG(&]R("=&;W)W87)D)R!A;F0@96UA:6P@=&AI<R!S=6)J96-T(&QI;F4@
M:7,@8V]P:65D(&]V97(@:6YT;R!T:&4@;F5W(&UE<W-A9V4@86YD('-O(&ES
M(&$@=F%L=6%B;&4@=V%Y(&]F('1E;&QI;F<@=VAA="!M97-S86=E<R!G;R!T
M;V=E=&AE<B!T;R!F;W)M(&$@)G%U;W0[=&AR96%D)G%U;W0[(&]F(&$@8V]N
M=F5R<V%T:6]N+B`@2&]W979E<BP@:68@=&AE("=297!L>2<@;W(@)T9O<G=A
M<F0G(&-O;G1A:6YS(&YE=R!I9&5A<RP@>6]U(&UA>2!W86YT('1O(&%D9"!S
M:6UP;&4@;6]D:69I8V%T:6]N<R!T;R!T:&4@)U-U8FIE8W0G(&QI;F4@<V\@
M=&AE(')E8VEP:65N="AS*2!C86X@9F]L;&]W('1H92!P<F]G<F5S<VEO;B!O
M9B!T:&4@)G%U;W0[=&AR96%D+B9Q=6]T.PH@("`@/"]P87)A/@H\+V5N=')Y
M/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B('-T
M871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y0[7-A;FEE('-P<N%V>3H@36^^
M;F]S=&D\+W1I=&QE/@H@("`@/&AE861I;F<^(DUOOFYO<W1I(CPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5&EE=&\@;F%S=&%V96YI82!6X6T@<&]M]+YU
M('!R:2!P[7-A;NT@<W!RX79Y+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@
M("!+;&EK;G5T[6T@;F$@(DMO;G1R;VQA('!R879O<&ES=2(@86MT:79U:F5T
M92!K;VYT<F]L=2!P<F%V;W!I<W4@=B!A:W1UX6QN;VT*:F%Z>6MU+B`H4&]Z
M;N%M:V$Z(&MO;G1R;VQU:F4@<V$@<')A=F]P:7,L(&YI92!G<F%M871I:V$N
M*0H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!+;&EK;G5T[6T@;F$@(EIO
M8G)A>FF[('!R[6QO:'DB('-A('8@9&]L;F5J(.AA<W1I('-T<N%N:WD@>F]B
M<F%Z[2!Z;WIN86T*<_IB;W)O=B`H<'+M;&]H*2!P<FEP;VIE;OUC:"!K('1O
M;75T;R!E+6UA:6QU+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!:8;EK
M<G1N:71E('!O;.WH:V\@=F5DM6$@=&5X='4@(E5L;[YINR!O9&]S;&%N^B!P
M;[ET=2(L(&%K(&-H8V5T92!U;&^^:;L*:_-P:74@=&5J=&\@<W!RX79Y('8@
M<')I9>AI;FMU(',@;V1O<VQA;F]U('!ON71O=2X@56QOOF5N[6T@9/1L9;YI
M=/UC:`IE+6UA:6QO=B!S82!VOF1Y(&WTOF5T92!D;WIV961I9;LL(.AO('-T
M92!N87#M<V%L:2X@3F5O9'!O<OKH86UE(%;A;2!U:VQA9&&["FMAOF3](&4M
M;6%I;"P@<')E=&^^92!6X;D@;&EM:70@*&MV\W1A*2!N82!S^F)O<GD@<V$@
M<OUC:&QO('9YZ&5R<.$@*'IV;.&YNPIP<FD@<&]S:65L86[M(&4M;6%I;&]V
M(',@<'+M;&]H86UI*2!A(&WTOF5T92!M8;L@<')O8FSI;7D@<R!P<FEJ[6UA
M;NUM('!ON71Y+@I.82!D<G5H96H@<W1R86YE(&WTOF5T92!Z87!N^KL@=/IT
M;R!M;[YN;W.[(&%K;R!P<F5D;F%S=&%V96[Z('8@<N%M8VD@<W9O:F5J"DED
M96YT:71Y.B!-;[YN;W-T:2TF9W0[3W-O8F[I(&EN9F]R;>%C:64M)F=T.U5P
M<F%V:;L@5F&Y92!I9&5N=&ET>2X@5B!T86MO;2!P<NUP861E"G:Y86L@<')A
M=FED96QN92!V>7!RX7ID\G5J=&4@<')I9>AI;F]K(',@;V1O<VQA;F]U('!O
MN71O=2$*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@
M:60](F-O;7!O<V4M;W!T:6]N<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M/
M<'1I;VYS)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&5S92!/
M<'1I;VYS(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M97-S86=E+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`F<75O=#M3<&5L;"!#:&5C:R9Q
M=6]T.R!T;R!C:&5C:R!Y;W5R('-P96QL:6YG+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!#;&EC:R`F<75O=#M!='1A8VAM96YT<R9Q=6]T.R!T;R!V
M:65W(&%T('1H92!B;W1T;VT@;V8@=&AE('!A9V4@82!L:7-T(&]F(&9I;&5S
M(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O("9Q
M=6]T.U-A=F4@8V]P>29Q=6]T.R!T;R!S879E(&$@8V]P>2!O9B!T:&ES(&UE
M<W-A9V4@:6X@>6]U<B`F<75O=#M396YT($UA:6PF<75O=#L@9F]L9&5R+B!3
M879E(&-O<&EE<R!O9B!I;7!O<G1A;G0@96UA:6QS('EO=2!S96YD('-O('1H
M870@>6]U(&AA=F4@<V]M971H:6YG('1O(')E9F5R(&)A8VL@=&\@;&%T97(@
M86YD('1O(&ME97`@86X@86-C=7)A=&4@<F5C;W)D(&]F('=H870@=V%S('-A
M:60N(%=E(&1O(&YO="!R96-O;6UE;F0@>6]U('-A=F4@979E<GD@96UA:6P@
M<VEN8V4@=&AE;B!Y;W5R(&1I<VL@<W1O<F%G92!Q=6]T82!W:6QL(&)E('5S
M960@=7`@<75I8VML>2`H97-P96-I86QL>2!W:&5N('EO=2!S96YD(&%T=&%C
M:&UE;G1S*2!A;F0@>6]U<B!M86EL8F]X('=I;&P@8F4@9G5L;"!A;F0@=6YA
M8FQE('1O(')E8V5I=F4@;F5W(&EN8V]M:6YG(&5M86EL+B!9;W4@8V%N+"!H
M;W=E=F5R+"!T=7)N('1H:7,@9F5A='5R92`G;VXG(&%S('EO=7(@9&5F875L
M="!W:71H:6X@>6]U<B!)9&5N=&ET>2P@8GD@9V]I;F<@=&\@3W!T:6]N<RTF
M9W0[4&5R<V]N86P@26YF;W)M871I;VXM)F=T.T5D:70@>6]U<B!I9&5N=&ET
M:65S+B!"92!C87)E9G5L('=H96X@=7-I;F<@=&AI<R!M;V1I9FEE9"!D969A
M=6QT(&%S('EO=2!W:6QL(&YE960@=&\@<&5R:6]D:6-A;&QY('!U<F=E('EO
M=7(@)G%U;W0[4V5N="!-86EL)G%U;W0[(&9O;&1E<B!O<B!I="!W:6QL(&5V
M96YT=6%L;'D@;6%K92!Y;W5R(&UA:6QB;W@@9G5L;"!A;F0@=6YU<V5A8FQE
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)C;VUP;W-E+6%T=&%C:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/E#M<V%N:64@<W!RX79Y.B!0<FEP;VIINSPO=&ET;&4^"B`@("`\:&5A9&EN
M9SXB4')I<&]J:;LB/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@("`@4')I
M<&]J96YI92!S^F)O<G4H;W8I(&L@5F&Y96H@<W!RX79E.@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("!+<F]K(#$Z($YA<.VY=&4@;65N;R!S^F)O<G4L
M(&MT;W+](&-H8V5T92!P<FEP;VIINRP@86QE8F\@:&\@=GEB97)T90IP;VUO
M8V]U('1L8>AI9&QA(")"<F]W<V4B(&$@:VQI:VYU=.UM(&YA('!OOF%D;W9A
M;OT@<_IB;W(H>2DN($-E<W1A(&$@;65N;PIS^F)O<G4@<V$@;V)J87;M('8@
M=&5X=&]V;VT@<&]L:2`B4'+M;&]H82(N(%!R96ID:71E(&YA(&)O9"`R+@I3
M=&5P(#(N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($MR;VL@,CH@2VQI
M:VYI=&4@;F$@=&QAZ&ED;&\@(E!R:7!O:FF[(BX@365N;R!S^F)O<G4@82!J
M96AO('9EM6MO<[L@<V$*>F]B<F%Z:6$@=B!Z;WIN86UE(%!R[6QO:"X@4')I
M9.%V86YI92!VY.BY[6-H('/Z8F]R;W8@82]A;&5B;R!P;VUA;.D*<')I<&]J
M96YI92!K($EN=&5R;F5T=2!M]+YU(';]<F%Z;F4@<W!O;6%L:;L@<')O8V5S
M('!R:7#A:F%N:6$@<'+M;&]H+@I0;^AK86IT92!N82!Z;V)R87IE;FEE('IO
M>FYA;74@82!N96ML:6MA:G1E('!OZ&%S(.AA:V%N:6$@;F$@:6[I('1L8>AI
M9&SA+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I
M9#TB8V]M<&]S92UA='1A8V@B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M!='1A
M8V@F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=2!M87D@871T
M86-H(&9I;&5S('1O('EO=7(@;65S<V%G93L@;VYL>2!O;F4@9FEL92!M87D@
M8F4@871T86-H960@870@82!T:6UE+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M4W1E<"`Q.B!%:71H97(L('1Y<&4@=&AE('!A=&@@86YD(&YA;64@;V8@82!F
M:6QE('1H870@>6]U('=A;G0@871T86-H960@=&\@=&AI<R!M97-S86=E(&]R
M(&-L:6-K("9Q=6]T.T)R;W=S929Q=6]T.R!B=71T;VX@86YD('-E;&5C="!T
M:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N86UE(&]F
M('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N="!B;W@N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($1E8VED92!W:&5T:&5R
M('EO=2!W86YT('1H92!F:6QE('1O(&)E('9I97=E9"!A<R!A;B!A='1A8VAM
M96YT(&]R(&EN;&EN960@=VET:"!T:&4@<F5S="!O9B!T:&4@;65S<V%G92X@
M5&AE(')E8V5I=FEN9R!P97)S;VXH<RD@;6%I;"!R96%D:6YG('-O9G1W87)E
M(&UU<W0@8F4@86)L92!T;R!H86YD;&4@=&AE(&9I;&4@='EP92!I;FQI;F4[
M(&EF(&YO="P@=&AI<R!P87)T('=I;&P@8F4@=FEE=V5D(&%S(&%N(&%T=&%C
M:&UE;G0@:6YS=&5A9"X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,SH@
M0VQI8VL@)G%U;W0[071T86-H)G%U;W0[(&)U='1O;BX@5&AE(&9I;&4@;F%M
M92!A;F0@<VEZ92!W:6QL(&)E(&%D9&5D('1O('EO=7(@;&ES="!O9B!!='1A
M8VAM96YT<RX@4&QE87-E(&YO=&4@=&AA="!F;W(@;&%R9V4@9FEL97,@86YD
M+V]R('-L;W=E<B!);G1E<FYE="!C;VYN96-T:6]N<RP@=&AE('!R;V-E<W,@
M;V8@=7!L;V%D:6YG(&%N9"!A='1A8VAI;F<@>6]U<B!F:6QE('1O('1H92!E
M;6%I;"!M87D@=&%K92!A('=H:6QE+B!0;&5A<V4@8F4@<&%T:65N="!A;F0@
M9&\@;F]T(&-L:6-K(&]T:&5R('1H:6YG<R!W:&EL92!Y;W4@87)E('=A:71I
M;F<N"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@
M:60](F-O;7!O<V4M871T86-H;65N=',B('-T871E/2)U;FMN;W=N(CX*("`@
M(#QT:71L93Y0[7-A;FEE('-P<N%V>3H@4'+M;&]H>3PO=&ET;&4^"B`@("`\
M:&5A9&EN9SXB071T86-H;65N=',B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4=2!S82!Z;V)R87IU:F4@>F]Z;F%M('/Z8F]R;W8L(&MT;W+I('6^('/Z
M('!R:7!O:F5N[2!K(%9AN65J('-P<N%V92X@3F$*=GEM87IA;FEE('!R[6QO
M:'DZ"B`@("`\+W!A<F$^"B`@("`\<&%R83Y+<F]K(#$Z(%IAN6MR=&YI=&4@
M<&]L[>AK;R!V962U82!P<NUL;VAY+"!K=&]R^B!C:&-E=&4@;V1S='+A;FF[
M+@H@("`@/"]P87)A/B`*("`@(#QP87)A/DMR;VL@,CH@2VQI:VYI=&4@;F$@
M(E9Y;6%Z8;LB+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB8V]M<&]S92UA='1A8VAM96YT<R(^"B`@("`\=&ET;&4^365S
M<V%G92!#;VUP;W-I=&EO;CH@071T86-H;65N=',\+W1I=&QE/@H@("`@/&AE
M861I;F<^)G%U;W0[071T86-H;65N=',F<75O=#L\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H:7,@<V5C=&EO;B!D:7-P;&%Y<R!A(&QI<W0@;V8@9FEL
M97,@86QR96%D>2!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V4N(%1O($1E;&5T
M92!A;B!A='1A8VAE9"!F:6QE.@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E
M<"`Q.B!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@=&AE(&%T
M=&%C:&5D(&9I;&5N86UE('EO=2!W86YT('1O($1E;&5T92X*("`@(#PO<&%R
M83X@"B`@("`\<&%R83Y3=&5P(#(Z($-L:6-K("9Q=6]T.T1E;&5T92!!='1A
M8VAM96YT*',I)G%U;W0[+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7!R:6]R:71Y(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!0<FEO<FET>3PO
M=&ET;&4^"B`@("`\:&5A9&EN9SXB4')I;W)I='DB/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!4:&ES('-E=',@=&AE(")8+5!R:6]R:71Y(B!H96%D97(@
M;VX@>6]U<B!O=71G;VEN9R!M97-S86=E+B!4:&4@(E@M4')I;W)I='DB('1A
M9R!I<R!A('-O<G0@;V8@(G!S975D;R!S=&%N9&%R9"(@=&AA="!.971S8V%P
M92P@36]Z:6QL82P@3W!E<F$L(&%N9"!/=71L;V]K(&UA:6P@8VQI96YT<R!A
M<'!E87(@=&\@86=R964@;VXN($%N>2!M86EL(&-L:65N=',@=&AA="!D;R!N
M;W0@:&%N9&QE('1H:7,@:&5A9&5R('=I;&P@<VEM<&QY(&EG;F]R92!I="X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<V%V
M92UA='1A8VAM96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@4V%V92!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\
M<&%R83X*("`@($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@
M:6X@>6]U<B!C;VUP;W-I=&EO;B!A<F4@<V%V960@=VET:"!T:&4@;65S<V%G
M92!W:&5N('-T;W)E9"!I;B!T:&4@<V5N="UM86EL(&9O;&1E<BX@($EF(")9
M97,B+"!T:&4@871T86-H;65N="!D871A('=I;&P@8F4@<V%V960N("!)9B`B
M3F\B+"!T:&4@871T86-H;65N="!D871A('=I;&P@8F4@<W1R:7!P960@9G)O
M;2!T:&4@;65S<V%G92!A9G1E<B!I="!I<R!S96YT('1O(&%L;"!R96-I<&EE
M;G1S+B`@0VAO;W-I;F<@(DYO(B!W:6QL(&AE;'`@8V]N<V5R=F4@9&ES:R!S
M<&%C92!B>2!R96UO=FEN9R`H<&]T96YT:6%L;'D@;&%R9V4I(&%T=&%C:&UE
M;G0@:6YF;W)M871I;VX@9G)O;2!T:&4@<V%V960@;65S<V%G97,N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6QI;FLM871T
M86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ($QI;FL@071T86-H;65N=',\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!$971E<FUI;F5S('=H971H97(@=&AE(&%T=&%C:&UE;G1S(&EN('EO
M=7(@8V]M<&]S:71I;VX@87)E('-E;G0@87,@82!P87)T(&]F('1H92!M86EL
M(&UE<W-A9V4@;W(@=VAE=&AE<B!T:&]S92!A='1A8VAM96YT<R!A<F4@:V5P
M="!O;B!A(&QO8V%L('-E<G9E<BX@($EF(&%T=&%C:&UE;G1S(&%R92!L:6YK
M960L('1H92!R96-I<&EE;G0H<RD@;V8@>6]U<B!M97-S86=E('=I;&P@8F4@
M<')O=FED960@82!W96)L:6YK('=H97)E('1H97D@8V%N(&1O=VYL;V%D('1H
M92!A='1A8VAM96YT*',I+B`@3&EN:VEN9R!A='1A8VAM96YT<R!H87,@=&AE
M(&%D=F%N=&%G92!O9B!T<F5M96YD;W5S;'D@<F5D=6-I;F<@=&AE('-I>F4@
M;V8@;W5T9V]I;F<@;65S<V%G97,N("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA
M<R!T:&4@9&ES861V86YT86=E('1H870@=&AE(&-O;G1E;G0@;V8@=&AE(&%T
M=&%C:&UE;G1S(&-A;B!N;W0@8F4@9W5A<F%N=&5E9"!T;R!B92!A=F%I;&%B
M;&4@:6X@=&AE(&9U='5R92!S:6YC92!T:&4@871T86-H;65N="!D871A(&ES
M(&YO="!L;V-A=&5D('=I=&AI;B!T:&4@92UM86EL(&UE<W-A9V4N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S96%R8V@B('-T871E/2)U
M;FMN;W=N(CX*("`@(#QT:71L93Y6>6BU863A=F%N:64@<W!RX79Y/"]T:71L
M93X*("`@(#QH96%D:6YG/DMR:73I<FEU;2!HM6%D86YI83PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@("`@(%IA9&%J=&4@<&QA=&[I(&MR:73I<FEU;2!H
MM6%D86YI82X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT
M<GD@:60](G-E87)C:"(^"B`@("`\=&ET;&4^365S<V%G92!396%R8V@\+W1I
M=&QE/@H@("`@/&AE861I;F<^4V5A<F-H($-R:71E<FEA/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!9;W4@;6%Y('-E87)C:"!F;W(@;65S<V%G97,@9G)O
M;2!Y;W5R(&9O;&1E<G,@=7-I;F<@9&EF9F5R96YT('-E87)C:"!C<FET97)I
M82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,3H@16YT97(@=&5X="!T
M;R!T:&4@9FEE;&1S('EO=2!W86YT('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C
M<FET97)I82X*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,CH@0VAO;W-E
M('1H92!M97-S86=E(&9L86<H<RD@=&\@861D('1O('EO=7(@<V5A<F-H(&-R
M:71E<FEA+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`S.B!#:&]O<V4@
M=&AE(&9O;&1E<BAS*2!F<F]M('=H:6-H('1O('-E87)C:"!F;W(@=&AE(&UE
M<W-A9V5S+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`T.B!#;&EC:R`F
M<75O=#M396%R8V@F<75O=#LN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M($EF(&%N>2!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H(&-R:71E<FEA
M+"!T:&5N('1H92!S=6)J96-T<R!O9B!T:&5S92!M97-S86=E<R!W:6QL(&)E
M('-H;W=N(&EN('1H92`F<75O=#M396%R8V@@4F5S=6QT<R9Q=6]T.R!V:65W
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)F;VQD97(M;W!T:6]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/E-P<N%V82!P<FEEZ&EN:V]V/"]T:71L93X*("`@(#QH96%D:6YG/DUOOFYO
M<W1I('!R:67H:6YK83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!0;VUO
M8V]U('!R97#M;F'H82!P;[5A('8@M6%V;VT@<W3E<&-I(&WTOF5T92!V>6)R
M8;L@<')I9>AI;F]K+B!0;W1O;0IS:2!M]+YE=&4@=GEB<F&[(&]P97+A8VEU
M+"!K=&]R^B!C:&-E=&4@<R!P<FEEZ&EN:V]M('9Y:V]N8;LN('!O;6]C;W4*
M=OUB97)O=NEH;R!P;[5A('8@M6%V96H@Z&%S=&DN"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@("`@4WES=.EM('-A(%;A<R!S</UT82!N82#O86RY:64@
M;6^^;F]S=&DN($)U[W1E(&]P871R;NT@<')I('!O=;[M=F%N[0IO<&5RX6-I
M92!V>6UA>N%V86YI82P@<')E=&^^92!V>6UA>F%N:64@<')I9>AI;FMU('-P
M]'-O8NT@=GEM87IA;FEE(':Y971K_6-H"G-P<N%V('8@=&]M=&\@<')I9>AI
M;FMU(0H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I
M9#TB9F]L9&5R+6]P=&EO;G,B/@H@("`@/'1I=&QE/D9O;&1E<B!-86YA9V5M
M96YT/"]T:71L93X*("`@(#QH96%D:6YG/D9O;&1E<B!/<'1I;VYS/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("`@(%EO=2!C86X@<V5L96-T(&$@9F]L9&5R
M(&)Y('5S:6YG('1H92!R861I;R!B=71T;VYS(&%L;VYG('1H92!L969T(&-O
M;'5M;BX@($]N8V4@>6]U(&AA=F4@9&]N92!T:&ES+"!S96QE8W0@=&AE(&]P
M=&EO;B!Y;W4@=VES:"!T;R!P97)F;W)M(&]N('1H92!F;VQD97(@=FEA('1H
M92!S96QE8W0@8F]X('1O('1H92!L969T+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("`@(%EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!F=7)T:&5R(&]P
M=&EO;G,N("!"92!C87)E9G5L('=I=&@@=&AE(&1E;&5T92!O<'1I;VXL(&%S
M('EO=2!C86X@;&]S92!A;&P@=&AE(&UE<W-A9V5S(&EN(&$@9F]L9&5R(&EF
M('EO=2!D96QE=&4@:70@8GD@;6ES=&%K92$*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/DEM<&]R="!M8F]X($9I;&4\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@("`@5&AI<R!O<'1I;VX@=VEL;"!I;7!O<G0@82!M8F]X(&9O<FUA="!F
M:6QE(&EN=&\@=&AE(&9O;&1E<B!O9B!Y;W5R(&-H;VEC92X@0VAO;W-E(#$@
M*&]N92D@9F]L9&5R('1O(&EM<&]R="!T:&4@;65S<V%G97,@:6YT;R!A;F0@
M=&AE;B!S96QE8W0@=&AI<R!O<'1I;VXN(%EO=2!W:6QL('1H96X@8F4@=&%K
M96X@=&\@82!P86=E('1H870@=VEL;"!P<F]M<'0@9F]R('1H92!M8F]X(&9I
M;&4@=&\@:6UP;W)T+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)F;VQD97(M=VED9V5T<R(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^1F]L9&5R($UA;F%G96UE;G0Z($1I<W!L87D\+W1I=&QE/@H@
M("`@/&AE861I;F<^4VAO=R](:61E(%5N<W5B<V-R:6)E9#PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@268@=7-I;F<@24U!4"!F;VQD97(@<W5B<V-R:7!T
M:6]N<RP@<VAO=R]H:61E('1H92!U;G-U8G-C<FEB960@9F]L9&5R<RX@(%1O
M('-U8G-C<FEB92]U;G-U8G-C<FEB92!T;R!A(&9O;&1E<BP@<V5L96-T('1H
M92!C:&5C:V)O>"!N97AT('1O('1H92!F;VQD97)N86UE(&%N9"!U<V4@=&AE
M(%-U8G-C<FEB92]5;G-U8G-C<FEB92!O<'1I;VX@:6X@=&AE($9O;&1E<B!!
M8W1I;VX@9')O<"UD;W=N(&UE;G4N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY%>'!A;F0@06QL/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%>'!A;F0@
M86QL(&9O;&1E<B!E;G1R:65S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M0V]L;&%P<V4@06QL/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!#;VQL87!S
M92!A;&P@9F]L9&5R(&5N=')I97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)F:6QT97)S(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET
M;&4^1FEL=')E.B!!<&QI:V]V8;L\+W1I=&QE/@H@("`@/&AE861I;F<^07!L
M:6MO=F&[(&9I;'1R;W9A8VEE('!R879I9&SA/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!+;&EK;G5T[6T@;F$@:6MO;G4@(D%P;&EK;W9ANR!F:6QT97(B
M('9E9+5A(&UE;F$@24Y"3U@@=B!Z;V)R87IE;NT*<')I9>AI;FMA+"!A;&5B
M;R!T;&'H:61L82`B07!L:6MO=F&[(':Y971K>2!P<F%V:61LX2(@=B!M96YU
M('!R92!N87-T879E;FEE"F9I;'1R;W8L('-A(&%P;&EK=6KZ(&9I;'1R;W9A
M8VEE('!R879I9&SA(&YA(':Y971K>2!N979Y;6%Z86[I('-P<N%V>2X*1FEL
M=')O=F%N:64@<V$@;F5S</JYNV$@875T;VUA=&EC:WDN"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F:6QT97)S(CX*("`@
M(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-L
M:6-K(&]N('1H92`F<75O=#M!<'!L>2!&:6QT97(F<75O=#L@:6-O;B!N97AT
M('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X('9I97<@=&\@9FEL
M=&5R(&%L;"!U;F1E;&5T960@;65S<V%G97,@86-C;W)D:6YG('1O('1H92!S
M<&5C:69I960@<G5L97,N("!/<BP@86QT97)N871E=FQY+"!C;&EC:R!O;B`F
M<75O=#M!<'!L>2!!;&P@4G5L97,F<75O=#L@:6X@=&AE(&9I;'1E<B!M96YU
M+B`@3F]T92!T:&%T(&9I;'1E<FEN9R!I<R!N;W0@9&]N92!A=71O;6%T:6-A
M;&QY+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)F:6QT97(M961I="UR=6QE<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^1FEL=&5R<SH@161I="!&:6QT97(@4G5L97,\+W1I=&QE/@H@("`@/&AE
M861I;F<^161I="!9;W5R($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!F:6QT97(@<G5L97,B('1O
M('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T
M92P@86YD(&5D:70@=&AE(&-U<G)E;G1L>2!A8W1I=F4@<V5T(&]F(&9I;'1E
M<B!R=6QE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I
M;'1E<BUE9&ET+6)L86-K;&ES="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M1FEL=&5R<SH@161I="!";&%C:VQI<W0\+W1I=&QE/@H@("`@/&AE861I;F<^
M161I="!9;W5R($)L86-K;&ES=#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M0VQI8VL@;VX@(D5D:70@>6]U<B!B;&%C:VQI<W0B('1O('!R;V-E960@=&\@
M=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T92P@86YD(&5D:70@
M=&AE(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y;W4@04Q705E3(')E9G5S
M92!M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)F:6QT97(M961I="UW:&ET96QI<W0B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/D9I;'1E<G,Z($5D:70@5VAI=&5L:7-T/"]T:71L93X*("`@(#QH96%D
M:6YG/D5D:70@66]U<B!7:&ET96QI<W0\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($-L:6-K(&]N(")%9&ET('EO=7(@=VAI=&5L:7-T(B!T;R!P<F]C965D
M('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L(&%N9"!E
M9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U($%,5T%94R!A
M8V-E<'0@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y&:6QT97)S.B!&:6QT97(@;VX@3&]G:6X\+W1I=&QE/@H@("`@/&AE861I
M;F<^07!P;'D@1FEL=&5R(%)U;&5S(%5P;VX@3&]G;VX_/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T;R!A;'=A>7,@87!P
M;'D@9FEL=&5R<R!W:&5N(&9I<G-T(&QO9V=I;F<@;VYT;R!)35`N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM9&ES<&QA
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL=&5R(&]N
M(%)E9G)E<V@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@9FEL=&5R(')U
M;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N('1O(&%L=V%Y<R!A<'!L
M>2!F:6QT97)S('=H96YE=F5R('EO=7(@=FEE=R!T:&4@24Y"3U@_"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M86YY+6UA:6QB
M;W@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!A
M;GD@36%I;&)O>#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!F:6QT97(@
M<G5L97,@=&\@86YY(&UA:6QB;W@_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!#:&5C:R!T:&ES(&]P=&EO;B!I9B!Y;W4@=V%N="!T;R!B92!A;&QO=V5D
M('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@;6%I;&)O>"X@3F]R;6%L
M;'DL(&9I;'1E<FEN9R!R=6QE<R!A<F4@;VYL>2!A<'!L:65D('1O(&YE=R!M
M86EL('1H870@:7,@9&5L:79E<F5D('1O('EO=7(@24Y"3U@N("!)9B!T:&ES
M(&]P=&EO;B!I<R!C:&5C:V5D+"!A;B!I8V]N('=I;&P@87!P96%R(&]N(&%L
M;"!M86EL8F]X('!A9V=E<R!T:&%T('=I;&P@86QL;W<@>6]U('1O(&%P<&QY
M(&9I;'1E<B!R=6QE<R!T;R!T:&4@;65S<V%G97,@:6X@=&AE(&-U<G)E;G0@
M;6%I;&)O>"X@($Y/5$4Z($9I;'1E<FEN9R!I;B!M86EL8F]X97,@;W1H97(@
M=&AA;B!)3D)/6"!M87D@<')O9'5C92!S=')A;F=E("AE+F<N('1H92!F:6QT
M97(@;6%Y(&-A=7-E(&$@8V]P>2!O9B!M97-S86=E<R!T;R!B92!D96QI=F5R
M960@=&\@=&AE('-A;64@;6%I;&)O>"D@86YD+V]R('5N9&5S:7)E9"!R97-U
M;'1S("AE+F<N(&ET(&UA>2!C875S92!M97-S86=E<R!T;R!B92!M;W9E9"]D
M96QE=&5D(&EF(&YE=R!F:6QT97)I;F<@<G5L97,@:&%V92!B965N(&EM<&QE
M;65N=&5D('-I;F-E('1H92!M97-S86=E(&AA<R!B965N(&1E;&EV97)E9"!T
M;R!T:&4@8W5R<F5N="!M86EL8F]X*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C:"UP=6)K97DB('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@071T86-H(%!U8FQI8R!+97D\+W1I
M=&QE/@H@("`@/&AE861I;F<^071T86-H(%!U8FQI8R!+97D\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@82!C;W!Y(&]F('EO
M=7(@4$=0('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T<RP@=VEL;"!B92!A='1A
M8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X@(%EO=2!C86X@<V5T('1H
M92!D969A=6QT(&)E:&%V:6]R('9I82!T:&4@4$=0($]P=&EO;G,@<V-R965N
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO
M;BUS8V%N+6)O9'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@4V-A
M;B!497AT($)O9&EE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY38V%N(%1E>'0@
M0F]D:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T
M:&5N($E-4"!W:6QL('-C86X@=&AE(&)O9'D@;V8@86QL('1E>'0@;65S<V%G
M97,@9F]R(%!'4"!D871A+"!A;F0@9&ES<&QA>2!T:&4@<F5S=6QT<R!I9B!A
M;GD@9&%T82!I<R!F;W5N9"X@($YO=&4@=&AA="!T:&ES(&UA>2!S;&]W(&1O
M=VX@=&AE('-Y<W1E;2!A<R!E=F5R>2!T97AT(&UE<W-A9V4@;75S="!B92!S
M8V%N;F5D(&EN(&ET<R!E;G1I<F5T>2!F;W(@4$=0(&1A=&$N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,M96YC
M<GEP="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^0V]M<&]S93H@16YC<GEP
M=&EO;B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/DYO($5N8W)Y<'1I
M;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@=&AE(&UE<W-A9V4@
M=VET:"!N;R!E;F-R>7!T:6]N("AC;&5A<G1E>'0I+@H@("`@/"]P87)A/@H@
M("`@/&AE861I;F<^4$=0($5N8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!E;F-R>7!T('1H92!C=7)R
M96YT(&UE<W-A9V4L('5S:6YG(%!'4"!A;F0@=&AE(')E8VEP:65N=',@<&5R
M<V]N86P@<'5B;&EC(&ME>2P@86YD('1H96X@<V5N9"!I="X@66]U(&-A;B!O
M;FQY('-E;F0@82!M97-S86=E('1O(&$@<VEN9VQE('!E<G-O;B!U<VEN9R!T
M:&ES(&]P=&EO;BX@66]U($U54U0@:&%V92!T:&4@<'5B;&EC(&ME>2!O9B!T
M:&4@<F5C:7!I96YT('-T;W)E9"!I;B!Y;W5R(&%D9')E<W-B;V]K(&]R(&5L
M<V4@=&AI<R!O<'1I;VX@=VEL;"!F86EL+B!)9B!Y;W4@:&%V92!T:&4@<'5B
M;&EC(&ME>2!F;W(@=&AE(')E8VEP:65N="!I;B!Y;W5R(&%D9')E<W-B;V]K
M(&%N9"!A<F4@<W1I;&P@<F5C96EV:6YG(&5R<F]R<RP@=F5R:69Y('1H870@
M=&AE(&4M;6%I;"!A9&1R97-S(&EN('1H92!R96-I<&EE;G0@9FEE;&0@;6%T
M8VAE<R!T:&4@92UM86EL(&%D9')E<W,@=VAE<F4@=&AE('!U8FQI8R!K97D@
M:7,@<W1O<F5D+B!4:&4@96YC<GEP=&5D(&1A=&$@=VEL;"!B92!A='1A8VAE
M9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E!'4"!3:6=N($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%1H:7,@;W!T:6]N('=I;&P@9&EG:71A;&QY('-I9VX@=&AE(&-U<G)E
M;G0@;65S<V%G92!U<VEN9R!01U`@86YD('EO=7(@<&5R<V]N86P@<')I=F%T
M92!K97DN($EF('EO=2!H879E(&YO="!A;')E861Y(&5N=&5R960@=&AE('!A
M<W-P:')A<V4@9F]R('EO=7(@<')I=F%T92!K97D@9'5R:6YG('1H:7,@<V5S
M<VEO;B!Y;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@:70N("!4:&4@<F5C96EP
M:65N="!M=7-T(&AA=F4@82!C;W!Y(&]F('EO=7(@<'5B;&EC(&ME>2!T;R!D
M:6=I=&%L;'D@=F5R:69Y('EO=7(*("`@('-I9VYA='5R92X*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!F:7)S="!D
M:6=I=&%L;'D@<VEG;B!Y;W5R(&UE<W-A9V4@86YD('1H96X@=VEL;"!E;F-R
M>7!T('1H92!R97-U;'1I;F<@;W5T<'5T+B!3964@=&AE("=01U`@16YC<GEP
M="!-97-S86=E)R!A;F0@)U!'4"!3:6=N($UE<W-A9V4G(&5N=')I97,@9F]R
M(&9U<G1H97(@:6YF;W)M871I;VXN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN
M9SY3+TU)344@16YC<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG
M;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A
M9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R=FEE=R(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4$=0.B!/=F5R=FEE=SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY7:&%T(&ES(%!'4#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%!'
M4"!I<R!A('1O;VP@9F]R('-E8W5R92!C;VUM=6YI8V%T:6]N(&%N9"!D871A
M('-T;W)A9V4L(&5S<&5C:6%L;'D@9F]R('5S92!W:71H(&4M;6%I;"X@270@
M8V%N(&)E('5S960@=&\@96YC<GEP="!D871A(&%N9"!T;R!C<F5A=&4@9&EG
M:71A;"!S:6=N871U<F5S+B!)35`@=7-E<R!';G501R`H1TY5(%!R:79A8WD@
M1W5A<F0I('1O('!R;W9I9&4@=&AI<R!F=6YC=&EO;F%L:71Y+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=&AI<R!O<'1I;VX@:7,@<V5L
M96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@8W)E871E+W9I97<@>6]U<B!P
M97)S;VYA;"!01U`@:V5Y<RP@861D+V1E;&5T92!P=6)L:6,@:V5Y<R!F<F]M
M(&]T:&5R(&EN9&EV:61U86QS+"!R96%D(&5N8W)Y<'1E9"!M86EL+"!V97)I
M9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@96YC<GEP="]S:6=N('EO
M=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UO<'1I;VXM871T86-H+7!U8FME>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4$=0.B!/<'1I;VYS("T@071T86-H(%!U8FQI8R!+97D\
M+W1I=&QE/@H@("`@/&AE861I;F<^3W!T:6]N<R`M($%T=&%C:"!0=6)L:6,@
M2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E9"!T:&5N
M(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E>&ES=',L
M('=I;&P@8GD@9&5F875L="!B92!A='1A8VAE9"!T;R!A;&P@;W5T9V]I;F<@
M;65S<V%G97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0
M.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E
M<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@<V-R965N(&QI
M<W1S(&%L;"!O9B!T:&4@8W5R<F5N="!U<V5R<R!I;B!Y;W5R(&%D9')E<W-B
M;V]K('1H870@:&%V92!01U`@<'5B;&EC(&ME>7,N(%1H97-E('5S97)S(&%R
M92!T:&4@3TY,62!U<V5R<R!T:&%T('EO=2!C86X@96ET:&5R(#$I('-E;F0@
M86X@96YC<GEP=&5D(&UE<W-A9V4@=&\@+4]2+2`R*2!V97)I9GD@82!D:6=I
M=&%L('-I9VYA='5R92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I97<\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O('9I
M97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@
M<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@1&5L971E<R!T:&4@<'5B;&EC(&ME>2!F<F]M('EO=7(@861D<F5S
M<V)O;VLN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M
M:6UP;W)T+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-
M86YA9V4@4'5B;&EC($ME>7,@+2!);7!O<G0\+W1I=&QE/@H@("`@/&AE861I
M;F<^26UP;W)T(%!U8FQI8R!+97ES/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4:&ES(&)U='1O;B!W:6QL(&]P96X@82!W:6YD;W<@=VAE<F4@>6]U(&-A
M;B!M86YU86QL>2!I;7!O<G0@82!01U`@<'5B;&EC(&ME>2X@(%1H92!K97D@
M8V%N(&5I=&AE<B!B92!P87-T960@:6YT;R!A('1E>'1F:65L9"!O<BP@:68@
M=&AE(&ME>2!R97-I9&5S(&EN(&$@9FEL92!O;B!Y;W5R(&QO8V%L(&-O;7!U
M=&5R+"!Y;W4@8V%N(&EM<&]R="!I="X@($EF('1H92!K97D@:7,@=F%L:60@
M:70@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@861D<F5S<V)O;VL@86YD
M('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O
M<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<M
M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N
M86=E(%!E<G-O;F%L($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I
M97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('EO=2!W86YT('1O(&1I
M9VET86QL>2!S:6=N(&UE<W-A9V5S(&]R(&5N86)L92!O=&AE<G,@=&\@<V5N
M9"!Y;W4@96YC<GEP=&5D(&UE<W-A9V5S+"!Y;W4@;75S="!H879E('EO=7(@
M;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%!'4"!K97EP86ER+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0=6)L:6,@2V5Y/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!9;W5R('!U8FQI8R!K97D@<VAO=6QD(&)E(&UA
M9&4@879A:6QA8FQE('1O(&%N>2!P97)S;VX@=&AA="!Y;W4@=V%N="!T;R!B
M92!A8FQE('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M97-S86=E<R!T:&%T(&]N
M;'D@64]5(&-A;B!D96-R>7!T("AU<VEN9R!Y;W5R('!R:79A=&4@:V5Y*2X@
M061D:71I;VYA;&QY+"!Y;W5R('!U8FQI8R!K97D@;F5E9',@=&\@8F4@;6%D
M92!A=F%I;&%B;&4@=&\@86YY8F]D>2!Y;W4@<V5N9"!A(&1D:6=I=&%L;'D@
M<VEG;F5D(&UE<W-A9V4@=&\@+2!T:&4@<'5B;&EC(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE(&1I9VET86P@<VEG;F%T=7)E+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^66]U<B!0<FEV871E($ME>3PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@66]U<B!P<FEV871E(&ME>2!I<R!N96-E<W-A<GD@=&\@
M9&5C<GEP="!A;GD@;65S<V%G92!E;F-R>7!T960@=7-I;F<@>6]U<B!P=6)L
M:6,@:V5Y+B!!9&1I=&EO;F%L;'DL('EO=7(@<')I=F%T92!K97D@:7,@;F5E
M9&5D(&EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&$@;65S<V%G92X@
M66]U<B!P<FEV871E(&ME>2!W:6QL(&)E('!R;W1E8W1E9"!V:6$@82!P87-S
M<&AR87-E(&-R96%T960@=VAE;B!T:&4@:V5Y<R!A<F4@9V5N97)A=&5D+B!4
M:'5S+"!T;R!P97)F;W)M(&%N>2!A8W1I=FET>2!T:&%T(')E<75I<F5S('EO
M=7(@<')I=F%T92!K97DL($E-4"!W:6QL('!R;VUP="!Y;W4@9F]R('EO=7(@
M<&%S<W!H<F%S92X@66]U(&]N;'D@;F5E9"!T;R!I;G-E<G0@>6]U<B!P87-S
M<&AR87-E(&]N8V4@<&5R('-E<W-I;VX@+2!)35`@=VEL;"!S=&]R92!Y;W5R
M('!A<W-P:')A<V4@=6YT:6P@>6]U(&QO9V]U="`H4V\@8F4@<W5R92!T;R!L
M;V=O=70A*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UP97)S;VYA;&ME>2UP=6)L:6,B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!0=6)L:6,@2V5Y/"]T:71L
M93X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!0
M1U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UP<FEV871E(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@4')I=F%T92!+
M97D\+W1I=&QE/@H@("`@/&AE861I;F<^16YT97(@4&%S<W!H<F%S93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@=&AE('!A<W-P:')A<V4@9&EA
M;&]G('=I;F1O=RX@5&AE('!A<W-P:')A<V4@96YT97)E9"P@:68@8V]R<F5C
M="P@=VEL;"!B92!S=&]R960@8GD@24U0('5N=&EL('EO=7(@<V5S<VEO;B!E
M;F1S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^56YL;V%D(%!A<W-P:')A
M<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%)E;6]V97,@=&AE('-T;W)E
M9"!P87-S<&AR87-E(&9R;VT@24U0("T@86YY(&%D9&ET:6]N86P@=7-A9V4@
M;V8@=&AE('!R:79A=&4@:V5Y('=I;&P@<F5Q=6ER92!Y;W4@=&\@<F5E;G1E
M<B!T:&4@<&%S<W!H96%S92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I
M97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W('1O
M('9I97<@=&AE(%!'4"!P<FEV871E(&ME>2X@1$\@3D]4(%-%3D0@5$A)4R!+
M15D@5$\@04Y93TY%("T@=&AI<R!O<'1I;VX@:7,@<W1R:6-T;'D@<V\@=&AA
M="!Y;W4@8V%N(&5X<&]R="!Y;W5R($E-4"!P97)S;VYA;"!P<FEV871E(&ME
M>2!F;W(@=7-E(&EN(&%N;W1H97(@<')O9W)A;2X*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1I
M<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!R:79A=&4@:V5Y
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O
M;F%L:V5Y+61E;&5T92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!-
M86YA9V4@4&5R<V]N86P@2V5Y<R`M($1E;&5T93PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY$96QE=&4@4&5R<V]N86P@2V5Y<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AI<R!B=71T;VX@=VEL;"!D96QE=&4@>6]U<B!P97)S;VYA;"!P
M=6)L:6,O<')I=F%T92!K97EP86ER(&9R;VT@24U0)W,@<')E9F5R96YC97,N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N
M86QK97DM8W)E871E+6YA;64B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'
M4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($YA;64\+W1I=&QE/@H@("`@/&AE
M861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE(&YA;64@
M>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!(')E
M<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UC;VUM96YT(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!#;VUM
M96YT/"]T:71L93X*("`@(#QH96%D:6YG/D-O;6UE;G0\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($$@8V]M;65N="!S=')I;F<@>6]U('=A;G0@96UB961D
M960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!;B!O<'1I;VYA;"!F:65L9"X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA
M;&ME>2UC<F5A=&4M96UA:6PB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'
M4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($4M;6%I;"!!9&1R97-S/"]T:71L
M93X*("`@(#QH96%D:6YG/D4M;6%I;"!!9&1R97-S/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!4:&4@92UM86EL(&%D9')E<W,@>6]U('=A;G0@87-S;V-I
M871E9"!W:71H('EO=7(@<&5R<V]N86P@:V5Y<RX@02!R97%U:7)E9"!F:65L
M9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S
M;VYA;&ME>2UC<F5A=&4M:V5Y;&5N9W1H(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!+97EL96YG=&@\+W1I
M=&QE/@H@("`@/&AE861I;F<^2V5Y;&5N9W1H/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4:&4@:V5Y;&5N9W1H+"!I;B!B>71E<RP@;V8@>6]U<B!G96YE
M<F%T960@:V5Y+B!4:&4@9W)E871E<B!T:&4@=F%L=64L('1H92!G<F5A=&5R
M('1H92!P<F]T96-T:6]N("AA;F0@86QS;R!G<F5A=&5R(&=E;F5R871I;VX@
M=&EM92!A;F0@96YC<GEP=&EO;B!T:6UE*2X@,3`R-"!B>71E<R!I<R!T:&4@
M9&5F875L="`M('1H:7,@=F%L=64@<')O=FED97,@97AC96QL96YT('!R;W1E
M8W1I;VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M
M<&5R<V]N86QK97DM8W)E871E+7!A<W-P:')A<V4B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M(%!A<W-P:')A
M<V4\+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&AE('!A<W-P:')A<V4@=7-E9"!T;R!P<F]T96-T+V5N8W)Y
M<'0@>6]U<B!P97)S;VYA;"!P<FEV871E(&ME>2X@5&AI<R!S:&]U;&0@8F4@
M050@3$5!4U0@-B!C:&%R86-T97)S+"!S:&]U;&0@3D]4(&)E('1H92!S86UE
M(&%S('EO=7(@;&]G:6X@<&%S<W=O<F0L('-H;W5L9"!.3U0@8F4@8F%S960@
M;VX@82!D:6-T:6]N87)Y('=O<F0L(&%N9"!S:&]U;&0@:6YC;'5D92!B;W1H
M(&YU;6)E<G,@86YD(&QE='1E<G,N(%EO=2!M=7-T(&5N=&5R('1H:7,@<&%S
M<W!H<F%S92!T=VEC92!F;W(@=F5R:69I8V%T:6]N('!U<G!O<V5S+B!!(')E
M<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UA8W1I;VYS(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!!8W1I
M;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D-R96%T92!+97ES/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#<F5A=&4@86YD('-T;W)E('EO=7(@<&5R<V]N
M86PO<')I=F%T92!K97EP86ER+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M26UP;W)T($ME>7!A:7(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EM<&]R
M="!A('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX@5&AI<R!B=71T;VX@;W!E
M;G,@82!W:6YD;W<@=VAE<F4@>6]U(&-A;B!M86YU86QL>2!I;7!O<G0@>6]U
M<B!E>&ES=&EN9R!01U`@<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@:V5Y<&%I
M<BX@(%1H92!K97ES(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@82!T97AT
M9FEE;&0@;W(L(&EF('1H92!K97ES(')E<VED92!I;B!A(&9I;&4@;VX@>6]U
M<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@=&AE;2X@($EF('1H
M92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS97)T960@:6YT;R!Y
M;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF
M(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D
M(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<VUI;64M;W9E<G9I97<B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E,O34E-13H@3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE861I;F<^5VAA="!I
M<R!3+TU)344_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3+TU)344@:7,@
M82!P<FEV871E+W!U8FQI8R!K97D@<&%I<B!S>7-T96T@=VAI8V@@<')O=FED
M97,@9&EG:71A;"!S:6=N871U<F5S+"!M97-S86=E('!R:79A8WDL(&%N9"!T
M86UP97(@9&5T96-T:6]N(&EN(&$@;W!E;BP@:6YT97)O<&5R86)L92!W87DN
M("!3+TU)344@8V%N('!R;W9I9&4@;65S<V%G92!P<FEV86-Y(&)Y(&5N8W)Y
M<'1I;F<@;65S<V%G97,@=&AA="!O;FQY('1H92!S96YD97(@86YD('1H92!I
M;G1E;F1E9"!R96-I<&EE;G1S(&-A;B!D96-O9&4N("!)="!A;&QO=W,@>6]U
M('1O(&ED96YT:69Y('1H92!S96YD97(@;V8@82!M97-S86=E('9I82!A(&1I
M9VET86P@<VEG;F%T=7)E+B`@5&]G971H97(L('1H:7,@96YC<GEP=&EO;B!A
M;F0@9&EG:71A;"!S:6=N:6YG(&AE;'`@<')O=FED92!T86UP97(@9&5T96-T
M:6]N+"!A;&QO=VEN9R!R96-I<&EE;G1S('1O(&1E=&5R;6EN92!W:&5T:&5R
M(&$@;65S<V%G92!W87,@86QT97)E9"!A9G1E<B!I="!W87,@<V5N="X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!3+TU)344@9G5N8W1I;VYA
M;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@;W!T:6]N
M(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&EM<&]R="!Y;W5R
M('!E<G-O;F%L(%,O34E-12!K97ES+"!R96%D(&5N8W)Y<'1E9"!M86EL+"!V
M97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@96YC<GEP="]S:6=N
M('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G-M:6UE+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y3+TU)344Z(%!E<G-O;F%L($ME>7,\+W1I=&QE
M/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&]R(&5N8W)Y<'0@
M;65S<V%G97,@>6]U(&UU<W0@:&%V92!Y;W5R(&]W;B!P97)S;VYA;"!P=6)L
M:6,O<')I=F%T92!3+TU)344@:V5Y<&%I<BX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G-M:6UE+6EM<&]R="UP97)S;VYA;"UC97)T<R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!);7!O<G0@4&5R<V]N
M86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH96%D:6YG/DEM<&]R="!0
M97)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($EM<&]R="!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!A(%!+0U,@(S$R
M(&9O<FUA="!F:6QE+B!02T-3(",Q,B!F:6QE<R!I<R!T:&4@9FEL92!U<W5A
M;&QY(&=E;F5R871E9"!W:&5N(&5X<&]R=&EN9R!A(&ME>2!F<F]M(&$@8G)O
M=W-E<B`H92YG+B!);G1E<FYE="!%>'!L;W)E<BP@1FER969O>"D@;W(@9G)O
M;2!A(&-E<G1I9FEC871E('-T;W)E(&UA:6YT86EN960@8GD@86X@3W!E<F%T
M:6YG(%-Y<W1E;2`H92YG+B!7:6YD;W=S(%A0*2X@268@=&AE(&ME>7,@87)E
M('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@<')E9F5R
M96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED
M+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN
M9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM
M92UD96QE=&4M<&5R<V]N86PM8V5R=',B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E,O34E-13H@1&5L971E(%!E<G-O;F%L($-E<G1I9FEC871E<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@0V5R=&EF:6-A=&5S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&4@>6]U<B!P97)S;VYA
M;"!C97)T:69I8V%T97,@9G)O;2!Y;W5R('!R969E<F5N8V5S+B`@66]U('=I
M;&P@;F\@;&]N9V5R(&)E(&%B;&4@=&\@<VEG;B!3+TU)344@;65S<V%G97,@
M;W(@=FEE=R!A;GD@4R]-24U%(&5N8W)Y<'1E9"!M97-S86=E<R!A9&1R97-S
M960@=&\@>6]U+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<VUI;64M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@("`@/&AE861I
M;F<^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($UA;F%G92!Y;W5R(%,O34E-12!P=6)L:6,@:V5Y(&QI<W0N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!6:65W('1H92!R87<@=&5X="!O9B!T:&4@<'5B;&EC(&ME
M>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%9I97<@=&5C:&YI8V%L(&1E=&%I;',@;V8@=&AE
M('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$96QE=&4\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T97,@=&AE('-E;&5C=&5D
M('!U8FQI8R!K97D@9G)O;2!S=&]R86=E+B`@1&5L971I;F<@82!P=6)L:6,@
M:V5Y(&9O<B!A('5S97(@=VEL;"!P<F5V96YT('EO=7(@9G)O;2!E;F-R>7!T
M:6YG(&$@;65S<V%G92!T;R!T:&%T('5S97(N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<FEN=&EN9R(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')I;G1I;F<\+W1I=&QE/@H@("`@/&AE861I;F<^4')I;G0@82!M
M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4;R!P<FEN="!A(&UE
M<W-A9V4@>6]U(&%R92!V:65W:6YG+"!C;&EC:R!O;B!T:&4@(E!R:6YT(B!L
M:6YK(&%T(&5I=&AE<B!T:&4@=&]P(&]R(&)O='1O;2!O9B!T:&4@;65S<V%G
M92X@5&AE(&UE<W-A9V4@=VEL;"!O<&5N(&EN(&$@;F5W('=I;F1O=R!F;W)M
M871E9"!F;W(@<')I;G1I;F<N("!$97!E;F1I;F<@;VX@>6]U<B!W96(@8G)O
M=W-E<B!A;F0@;W!E<F%T:6YG('-Y<W1E;2P@=&AE('!R:6YT(&1I86QO9R!B
M;W@@;6%Y(&]P96X@9F]R('EO=2X@($EF(&ET(&1O97,@;F]T(&]P96XL('1H
M96X@<'5L;"!D;W=N('1H92!W96(@8G)O=W-E<B=S(")&:6QE(B!M96YU(&%N
M9"!C:&]O<V4@(E!R:6YT(B!T;R!O<&5N('1H92!P<FEN="!D:6%L;V<@8F]X
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V]R=&EN9R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4V]R=&EN9R!A;F0@5&AR96%D:6YG
M/"]T:71L93X*("`@(#QH96%D:6YG/E-O<G1I;F<@16YT<FEE<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5VAE;B!V:65W:6YG(&$@;&ES="!O9B!M97-S
M86=E<RP@>6]U(&-A;B!S;W)T('1H92!M97-S86=E<R!B>2!A;GD@8V]L=6UN
M(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T92!C;VQU;6X@:&5A9&EN
M9RX@(%1O('-W:71C:"!C;VQU;6YS(&)E='=E96X@87-C96YD:6YG(&%N9"!D
M97-C96YD:6YG(&]R9&5R+"!C;&EC:R!O;B!T:&4@87)R;W<@:6-O;B!I;B!T
M:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY4
M:')E861I;F<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1O(&=R;W5P(&UE
M<W-A9V5S(&)Y('1H<F5A9',@*'-U8FIE8W0I+"!S;R!E86-H(&UE<W-A9V4@
M:7,@9W)O=7!E9"!W:71H(&%L;"!I=',@<F5P;&EE<RP@8VQI8VL@=&AE(%M4
M:')E861=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L=6UN(&AE861I;F<N("!4
M;R!R971U<FX@=&\@;F]R;6%L('-U8FIE8W0@<V]R=&EN9RP@8VQI8VL@;VX@
M=&AE(%M3=6)J96-T72!L:6YK(&EN('1H92!S=6)J96-T(&-O;'5M;B!H96%D
M:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB86QT97)N
M871I=F4M;7-G(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-=6QT:7!A<G0O
M06QT97)N871I=F4@365S<V%G97,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3
M;VUE(&UE<W-A9V4@:&%V92!B965N('-E;G0@87,@82`B;75L=&EP87)T+V%L
M=&5R;F%T:79E(B!T>7!E(&)Y('1H92!S96YD97(N(%1H97-E(&UE<W-A9V5S
M(&AA=F4@<V5V97)A;"!P87)T<RP@86QL(&1I<W!L87EI;F<@=&AE(%-!344@
M0T].5$5.5"!B=70@:6X@1$E&1D5214Y4($9/4DU!5%,N(%1H92!M86EL(&%G
M96YT('=I;&P@9&ES<&QA>2!T:&4@;&%S="!P87)T(&EN('1H92!L:7-T('1H
M870@8V%N(&)E('-U8V-E<W-F=6QL>2!D:7-P;&%Y960@:6YL:6YE(&EN('1H
M92!B<F]W<V5R+"!I9B!A;GDN($%L;"!O=&AE<B!F;W)M871S('=I;&P@87!P
M96%R('5N9&5R('1H92!H96%D:6YG(")!;'1E<FYA=&EV92!P87)T<R!F;W(@
M=&AI<R!S96-T:6]N(B!A;F0@8V%N(&)E('9I97=E9"!O<B!D;W=N;&]A9&5D
M('-E<&%R871E;'DN($ET(&ES(&EM<&]R=&%N="!T;R!N;W1E('1H870@=&AE
M<V4@86QT97)N871I=F4@<&%R=',@8V]N=&%I;B!T:&4@4T%-12!#3TY414Y4
M4R!A<R!T:&4@<&%R="!T:&%T(&ES('-H;W=N("T@=&AE>2!A<F4@<VEM<&QY
M(&EN(&$@9&EF9F5R96YT(&UE9&EA(&9O<FUA="`H92YG+B!T97AT('9S+B!(
M5$U,(&]U='!U="DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUR96YA;65?<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!296YA;64@
M4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@
M("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!R
M96YA;64@>6]U<B!S96YT+6UA:6P@9F]L9&5R(&%T('1H92!B96=I;FYI;F<@
M;V8@979E<GD@;6]N=&@N("!4:&4@9F]L9&5R('=I;&P@8F4@<F5N86UE9"`H
M=&\@82!N86UE('1H870@8V]N=&%I;G,@=&AE(&UO;G1H(&%N9"!Y96%R*2!A
M;F0@82!N97<@<V5N="UM86EL(&9O;&1E<B!W:6QL(&)E(&-R96%T960N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?
M<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@4V5N="UM86EL($9O;&1E
M<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P
M=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD('-E;G0M
M;6%I;"!F;VQD97)S(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N
M("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@9F]R
M(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K965P(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T
M92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D@+2`C(&]F($9O;&1E<G,@=&\@
M2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@9&5L971I
M;F<@;VQD('-E;G0M;6%I;"!F;VQD97)S(&5V97)Y(&UO;G1H+"!H;W<@;6%N
M>2!M;VYT:',@;V8@;VQD(&9O;&1E<G,@9&\@>6]U("!W86YT('1O(&ME97`_
M("!!;GD@9F]L9&5R<R!O;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT:',@=VEL
M;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DB('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&5L
M971E($QI;FME9"!!='1A8VAM96YT<R!-;VYT:&QY/"]T:71L93X*("`@(#QP
M87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK
M92!T;R!D96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!T:&4@8F5G
M:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AI<R!M87D@8F4@=7-E9G5L(&EF
M('EO=2!H879E(&$@<75O=&$L(&9O<B!E>&%M<&QE+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S
M7VUO;G1H;'E?:V5E<"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE;G1S
M($UO;G1H;'D@+2`C(&]F($UO;G1H<R!T;R!+965P/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O;&0@;&EN:V5D(&%T=&%C
M:&UE;G1S(&5V97)Y(&UO;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@;VQD(&%T
M=&%C:&UE;G1S(&1O('EO=2`@=V%N="!T;R!K965P/R`@06YY(&%T=&%C:&UE
M;G1S(&]L9&5R('1H86X@=&AI<R!M86YY(&UO;G1H<R!W:6QL(&)E(&1E;&5T
M960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP
M=7)G95]T<F%S:"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:#PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($1O('EO=2!W86YT('1O('!U<F=E('EO=7(@=')A<V@@9F]L9&5R
M(&5V97)Y('-O(&]F=&5N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:6YT97)V86PB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@4'5R9V4@
M5')A<V@@26YT97)V86P\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L(&AO=R!O9G1E;B!S:&]U
M;&0@:70@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:V5E<"(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S
M:"!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R92!P=7)G
M:6YG('EO=7(@=')A<V@@9F]L9&5R+"!M97-S86=E(&]L9&5R('1H86X@:&]W
M(&UA;GD@9&%Y<R!S:&]U;&0@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB7W1E>'0B('-T871E/2)N
M97<B/@H@("`@(#QT:71L93Y0<F5F97)E;F-E<SH@365S<V%G92!#;VUP;W-I
M=&EO;CH@071T<FEB=71I;VX@5&5X=#PO=&ET;&4^"B`@("`@/'!A<F$^"B`@
M("`@2&5R92!Y;W4@8V%N(&5N=&5R('1H92!P:')A<V4@=&AA="!Y;W4@=VES
M:"!T;R!A<'!E87(@8F5F;W)E(&%N>2!Q=6]T960@=&5X="!I;B!A(')E<&QY
M('1H870@>6]U('-E;F0N"B`@("`@/"]P87)A/@H@("`@(#QP87)A/@H@("`@
M(%EO=2!C86X@:6YC;'5D92!O;F4@;W(@;6]R92!S<&5C:6%L('!L86-E:&]L
M9&5R<R!T;R!I;G-E<G0@:6YF;W)M871I;VX@86)O=70@=&AE(&UE<W-A9V4@
M=&\@=VAI8V@@>6]U(&%R92!R97!L>6EN9RX@4&QA8V5H;VQD97)S(&-O;G-I
M<W0@;V8@82`G)2<@9F]L;&]W960@8GD@82!S:6YG;&4@;&5T=&5R+B!4:&4@
M9F]L;&]W:6YG('!L86-E:&]L9&5R<R!A<F4@879A:6QA8FQE.@H@("`@(#PO
M<&%R83X*"B`@("`@/'!A<F$^("5F(#H@5&AE('-E;F1E<B=S(&YA;64@86YD
M(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^("5A(#H@5&AE('-E
M;F1E<B=S(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^("5P(#H@
M5&AE('-E;F1E<B=S(&YA;64\+W!A<F$^"B`@("`@/'!A<F$^("5R(#H@5&AE
M(&9U;&P@4D9#(#(X,C(@<W1Y;&4@9&%T92!A;F0@=&EM92!Z;VYE/"]P87)A
M/@H@("`@(#QP87)A/B`E9"`Z(%1H92!D871E(&%S('=W=RP@9&0@;6UM(%E9
M65D\+W!A<F$^"B`@("`@/'!A<F$^("5X(#H@5&AE(&1A=&4@:6X@=&AE(&QO
M8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^("5C(#H@5&AE(&1A
M=&4@86YD('1I;64@:6X@=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@
M("`@/'!A<F$^("5M(#H@5&AE($UE<W-A9V4M240\+W!A<F$^"B`@("`@/'!A
M<F$^("5S(#H@5&AE('-U8FIE8W0\+W!A<F$^"B`@("`@/'!A<F$^("5N(#H@
M02!N97<@;&EN93PO<&%R83X*("`@("`\<&%R83X@)24@.B!4:&4@)R4G(&-H
M87)A8W1E<CPO<&%R83X*"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD
M:7-P;W-I=&EO;E]R97%U97-T7W)E860B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!297%U97-T(%)E860@4F5C96EP=',\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!A(%)E860@4F5C96EP="(@<V5N
M9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G1S(&]F('1H:7,@;65S<V%G
M92!T;R!N;W1I9GD@>6]U('=H96X@=&AI<R!M97-S86=E(&ES(&]P96YE9"!B
M>2!T:&4@<F5C:7!I96YT<RX@3F]T(&%L;"!C;&EE;G1S('-U<'!O<G0@+R!H
M;VYO<B!T:&ES+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&ES<&]S:71I;VY?<V5N9%]M9&XB('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!396YD($U$3CPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(")396YD(&$@341.(B!S96YD<R!A($UE<W-A9V4@1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N("AA;'-O(&MN;W=N(&%S(&$@<F5A9"!R96-E:7!T
M*2!W:&5N('EO=2!V:65W(&$@;65S<V%G92!I;B!W:&EC:"!T:&4@=7-E<B!H
M87,@<F5Q=65S=&5D('1H870@=&AE>2!R96-E:79E(&YO=&EF:6-A=&EO;B!T
M:&%T('EO=2!H879E(')E860@=&AE(&UE<W-A9V4N($EN(&UO<W0@8V%S97,L
M('1H:7,@=VEL;"!H87!P96X@875T;VUA=&EC86QL>2!W:71H;W5T('!R;VUP
M=&EN9R!Y;W4N($EN(&-E<G1A:6X@:7-O;&%T960@8V%S97,L('EO=2!M87D@
M:&%V92!T;R!M86YU86QL>2!D96-I9&4@=&\@<V5N9"!T:&4@;F]T:69I8V%T
M:6]N(&)Y(&-L:6-K:6YG(&]N(&$@;&EN:RX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?9&5L
M:79E<GDB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!2
M97%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;CPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(")297%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(@<V5N9',@
M82!R97%U97-T('1O('1H92!R96-I<&EE;G0G<R!E+6UA:6P@<V5R=F5R('1O
M(&YO=&EF>2!Y;W4@=VAE;B!I="!H87,@9&5L:79E<F5D('1H92!M97-S86=E
M('1O('1H92!R96-I<&EE;G0G<R!M86EL8F]X+B!)="!D;V5S;B=T(&UE86X@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<V5E;BP@:G5S="!T:&%T(&ET)W,@<VET
M=&EN9R!I;B!A(&UA:6QB;W@@<V]M97=H97)E+B!.;W0@86QL(&UA:6P@<V5R
M=F5R<R!S=7!P;W)T('1H:7,N(`H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&5L971E7W-P86U?869T97)?<F5P;W)T(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@1&5L971E(%-P86T@
M069T97(@4F5P;W)T:6YG/"]T:71L93X*("`@(#QP87)A/@H@("`@66]U(&UA
M>2!E;&5C="!T;R!D;R!O;F4@;V8@=&AR964@:71E;7,@869T97(@<F5P;W)T
M:6YG(&$@;65S<V%G92!A<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@1FER<W0L('EO=2!C86X@9&5C:61E
M('1O(&1O(&YO=&AI;F<@+2!T:&4@;65S<V%G92!W:6QL(&)E(')E<&]R=&5D
M(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C96YT(&)U="!W:6QL(&]T:&5R=VES
M92!R96UA:6X@=6YC:&%N9V5D(&EN('EO=7(@;6%I;&)O>"X*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@4V5C;VYD+"!I9B!R97!O<G1I;F<@82!M97-S
M86=E(&%S('-P86TL('EO=2!C86X@:6YS=&5A9"!H879E('1H92!M97-S86=E
M(&)E(&EM;65D:6%T96QY(&1E;&5T960N("!4:&ES('-E='1I;F<@:&%S(&YO
M(&5F9F5C="!O;B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!4:&ER9"P@869T97(@<F5P;W)T
M:6YG(&$@;65S<V%G92!A<R!S<&%M('1H92!M97-S86=E('=I;&P@8F4@9&5L
M971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D('1O('EO
M=7(@<W!A;2!F;VQD97(N("!!;'1E<FYA=&EV96QY+"!I9B!R97!O<G1I;F<@
M82!M97-S86=E(&%S(&EN;F]C96YT('1H92!M97-S86=E('=I;&P@8F4@9&5L
M971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D('1O('EO
M=7(@24Y"3U@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUH=&UL7VEM86=E7W)E<&QA8V5M96YT(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G92!297!L86-E;65N=#PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($9O<B!(5$U,(&UE<W-A9V5S(&1I<W!L
M87EE9"!I;FQI;F4L('-H;W5L9"!A;&P@:6UA9V4@=&%G<R!B92!B;&]C:V5D
M('5N=&EL('EO=2!S<&5C:69I8V%L;'D@9&5C:61E('1O('9I97<@=&AO<V4@
M:6UA9V5S/R!.;W1E('1H870L(&EF('9I97=I;F<@86X@2%1-3"!A='1A8VAM
M96YT+"!T:&4@:6UA9V5S('=I;&P@86QW87ES(&)E(&1I<W!L87EE9"X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6AT;6Q?:6UA
M9V5?861D<F)O;VLB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N
M8V5S.B!(5$U,($EM86=E(%)E<&QA8V5M96YT+T%D9')E<W-B;V]K(%-H;W<\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!B;&]C:VEN9R!I;6%G97,@9F]R
M(&EN;&EN92!(5$U,(&UE<W-A9V5S+"!S:&]U;&0@=V4@875T;VUA=&EC86QL
M>2!D:7-P;&%Y('1H96T@:6YS=&5A9"!I9B!T:&4@<V5N9&5R(&%P<&5A<G,@
M:6X@>6]U<B!A9&1R97-S8F]O:S\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A<G0B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EL8F]X(%-T87)T(%!A9V4\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H:6-H('!A9V4@:6X@
M=&AE(&UA:6QB;W@@=FEE=R!W:6QL(&)E(&1I<W!L87EE9"!W:&5N('EO=2!A
M8V-E<W,@82!M86EL8F]X(&9O<B!T:&4@9FER<W0@=&EM92X@3F]T92!T:&%T
M('1H92`G=6YS965N)R!M97-S86=E(&]P=&EO;G,@9&\@;F]T('=O<FL@=VET
M:"!T:&4@)U1H<F5A9"<@<V]R=&EN9R!O<'1I;VX@+2!I;G-T96%D+"!Y;W4@
M=VEL;"!B92!S96YT('1O('1H92!L87-T('!A9V4N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E7V%T=&%C:&UE;G1S(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4V%V92!!='1A
M8VAM96YT<R!O;B!396YT($UE<W-A9V5S/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@<V%V:6YG(&$@8V]M<&]S960@;65S<V%G92!I;B!A('-E;G0M;6%I
M;"!F;VQD97(L(&1E=&5R;6EN92!I9B!A;&P@871T86-H;65N="!D871A(&ES
M('-A=F5D+B!4:&4@9F]L;&]W:6YG(&]P=&EO;G,@87)E(&%V86EL86)L93H*
M("`@(#PO<&%R83X*"B`@("`\<&%R83XJ(")!;'=A>7,@<V%V92!A='1A8VAM
M96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A='1A8VAM96YT<R!I;B!C
M;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S(&%R92!!3%=!65,@<V%V
M960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"B`@("`@/'!A<F$^*B`B4')O
M;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT
M('1O(%E%4R(@+2!!3%=!65,@<')O;7!T('1O('-A=F4@871T86-H;65N=',@
M:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F875L="!I<R!T;R!S879E
M(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R83XJ(")0<F]M<'0@979E
M<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B
M("T@04Q705E3('!R;VUP="!T;R!S879E(&%T=&%C:&UE;G1S(&EN('1H92!C
M;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@:7,@=&\@;F]T('-A=F4@871T
M86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@(DYE=F5R('-A=F4@871T
M86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A=F4@871T86-H;65N=',@
M:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT<R!A<F4@3D5615(@
M<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)V:7)T=6%L7VEN8F]X(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@26YB;W@\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!6:7)U=&%L($EN8F]X(&ES(&$@<V%V960@<V5A<F-H('1H
M870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@=&\@<V5A<F-H(&5V97)Y(&UA
M:6QB;W@@9F]R(&UE<W-A9V5S(&UA<FME9"!A<R!N97<N("!);G-T96%D+"!A
M;&P@8W5R<F5N=&QY('-U8G-C<FEB960@;6%I;&)O>&5S(&%R92!S96%R8VAE
M9"!F;W(@;F5W(&UE<W-A9V5S(&%N9"!T:&4@<F5S=6QT<R!A<F4@9&ES<&QA
M>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)V:7)T=6%L7W1R87-H(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@5')A<V@\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!6:7)T=6%L(%1R87-H(&ES(&$@<V%V960@<V5A
M<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@9F]R(&$@<V5P87)A
M=&4@5')A<V@@9F]L9&5R+B`@26YS=&5A9"!O9B!M;W9I;F<@;65S<V%G97,@
M=&\@82!C96YT<F%L:7IE9"!T<F%S:"!F;VQD97(L(&UE<W-A9V5S(&%R92!S
M:6UP;'D@;6%R:V5D(&%S(&1E;&5T960@:6X@=&AE(&-U<G)E;G0@9F]L9&5R
M('1H97D@;&EV92!I;BX@(%=H96X@)W-H;W<@9&5L971E9"!M97-S86=E<R<@
M:7,@='5R;F5D(&]F9BP@=&AI<R!R97-U;'1S(&EN('1H97-E(&UE<W-A9V5S
M(&YO="!A<'!E87)I;F<@:6X@82!M86EL8F]X('9I97<N("!7:&5N(&$@=7-E
M<B!C;&EC:W,@;VX@5FER='5A;"!4<F%S:"P@*F%L;"H@;6%I;&)O>&5S(&%L
M;"!S96%R8VAE9"!F;W(@;65S<V%G97,@=&AA="!A<F4@9FQA9V=E9"!D96QE
M=&5D(&%N9"!T:&5S92!M97-S86=E<R!A<F4@9&ES<&QA>65D(&EN(&$@<VEN
M9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O<VQ?4TDO````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-C,`,#$W-#8R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO
M8V%L92]S;%]322],0U]-15-304=%4R\`````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,C$R-#<`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O;&]C86QE+W-L7U-)+TQ#7TU%4U-!1T53+VEM<"YM
M;P```````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-34V-S(P`#$P-#$W,S8R-S8S`#`R
M,C0P-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25``````(*```<````+%```&D-```\H````````.#5```*````X=4`
M``H```#LU0``"@```/?5```.`````M8```\````1U@``#0```"'6```(````
M+]8```L````XU@``#````$36```*````4=8```0```!<U@``!````&'6```!
M````9M8``!D```!HU@``#````(+6``!(````C]8``"L```#8U@``1`````37
M```G````2=<``!<```!QUP``#P```(G7```+````F=<```X```"EUP``!0``
M`+37```H````NM<```H```#CUP``%0```.[7```2````!-@``#(````7V```
M"P```$K8```I````5M@``#(```"`V```$````+/8```4````Q-@``!````#9
MV```)@```.K8```G````$=D``"8````YV0``'````&#9```.````?=D```H`
M``",V0``#0```)?9```G````I=D``"````#-V0``#@```.[9```7````_=D`
M`"(````5V@``-0```#C:```1````;MH```T```"`V@``#````([:```-````
MF]H```8```"IV@``&P```+#:```N````S-H``#<```#[V@``?````#/;``!L
M````L-L``!P````=W```'0```#K<```/````6-P``!@```!HW```#````('<
M``!%````CMP``"@```#4W```00```/W<```D````/]T```X```!DW0``#P``
M`'/=```.````@]T```X```"2W0``"````*'=```.````JMT```X```"YW0``
M+@```,C=```:````]]T``#,````2W@``40```$;>```R````F-X``#@```#+
MW@``5`````3?``!1````6=\``%H```"KWP``5P````;@```T````7N````H`
M``"3X```!0```)[@```#````I.````8```"HX```$0```*_@```(````P>``
M``D```#*X```"0```-3@```.````WN````@```#MX```)0```/;@```@````
M'.$``!`````]X0``#P```$[A```/````7N$```H```!NX0``!P```'GA```#
M````@>$```\```"%X0``%````)7A```)````JN$```T```"TX0``$@```,+A
M```/````U>$```H```#EX0``#P```/#A```(`````.(```H````)X@``)```
M`!3B```7````.>(``!0```!1X@``%@```&;B```(````?>(``!P```"&X@``
M&0```*/B```H````O>(``!X```#FX@``&@````7C```L````(.,``"````!-
MXP``,@```&[C```'````H>,```P```"IXP``#0```+;C```L````Q.,```X`
M``#QXP```P````#D```+````!.0```<````0Y```!P```!CD```%````(.0`
M``4````FY```"@```"SD```#````-^0``!<````[Y```"@```%/D```/````
M7N0```X```!NY```3@```'WD``!0````S.0``$,````=Y0``0@```&'E```P
M````I.4``!@```#5Y0``(P```.[E```.````$N8``!0````AY@``%P```#;F
M```7````3N8``!<```!FY@``$P```'[F```/````DN8``",```"BY@``!@``
M`,;F```7````S>8```X```#EY@``40```/3F```?````1N<``#4```!FYP``
M!P```)SG```&````I.<```@```"KYP``#P```+3G```&````Q.<```@```#+
MYP``$0```-3G```*````YN<``!,```#QYP``"P````7H```0````$>@``!4`
M```BZ```#0```#CH```3````1N@``",```!:Z```+P```'[H```5````KN@`
M``<```#$Z```!0```,SH```5````TN@``!$```#HZ```#````/KH```P````
M!^D``$@````XZ0``(0```('I```[````H^D``#L```#?Z0``/````!OJ```K
M````6.H``#$```"$Z@``.P```+;J```Y````\NH``#4````LZP``"0```&+K
M```'````;.L``!0```!TZP``#````(GK```#````ENL```4```":ZP``"0``
M`*#K```0````JNL```D```"[ZP``$P```,7K```#````V>L``#D```#=ZP``
M$@```!?L```&````*NP```P````Q[```-0```#[L```.````=.P``$D```"#
M[```,P```,WL```*`````>T``"T````,[0``"P```#KM```G````1NT``"P`
M``!N[0``*@```)OM```E````QNT```D```#L[0``"0```/;M```*`````.X`
M``8````+[@``"0```!+N```'````'.X``"\````D[@``-P```%3N```N````
MC.X``%4```"[[@``+0```!'O```L````/^\``"T```!L[P``+0```)KO``!`
M````R.\``",````)\```(P```"WP```M````4?```#,```!_\```%0```+/P
M```9````R?```"D```#C\```)`````WQ``!0````,O$``!@```"#\0``$0``
M`)SQ```1````KO$```H```#`\0``#````,OQ```+````V/$```H```#D\0``
M"@```._Q```0````^O$``!8````+\@``%@```"+R```'````.?(```<```!!
M\@``%````$GR```*````7O(```@```!I\@``"````'+R```#````>_(```<`
M``!_\@``!P```(?R```&````C_(``#@```"6\@``!0```,_R```'````U?(`
M``8```#=\@``"````.3R```)````[?(``"D```#W\@``#@```"'S```*````
M,/,``$4````[\P``!````('S```$````AO,```<```"+\P``"0```)/S```&
M````G?,``!$```"D\P``!P```+;S```6````OO,```0```#5\P``)P```-KS
M```(`````O0```8````+]```#0```!+T```&````(/0``!X````G]```$0``
M`$;T```(````6/0```T```!A]```#````&_T```'````?/0```,```"$]```
M`P```(CT```7````C/0``!,```"D]```"````+CT```(````P?0```0```#*
M]```"````,_T```(````V/0``"H```#A]```*P````SU``!3````./4``$$`
M``",]0``(````,[U```&````[_4```8```#V]0``#@```/WU```5````#/8`
M`#X````B]@``&````&'V```B````>O8``"X```"=]@``'0```,SV```A````
MZO8``%0````,]P``*0```&'W```*````B_<```<```"6]P``%0```)[W```.
M````M/<```(```##]P``"@```,;W```/````T?<```T```#A]P``#P```._W
M```-````__<```D````-^```%````!?X```&````+/@``!@````S^```'0``
M`$SX```3````:O@``!0```!^^```!````)/X```,````F/@```8```"E^```
M"@```*SX```-````M_@``&(```#%^```)P```"CY``!4````4/D``%\```"E
M^0``!`````7Z```6````"OH```X````A^@``'````##Z```/````3?H``#,`
M``!=^@``*````)'Z```%````NOH```4```#`^@``&P```,;Z```:````XOH`
M``X```#]^@``%0````S[```1````(OL``!$````T^P``$0```$;[```<````
M6/L``"H```!U^P``-0```*#[``!%````UOL``!`````<_```(0```"W\```%
M````3_P``!,```!5_```$@```&G\```*````?/P```\```"'_```1P```)?\
M```?````W_P``"4```#__```,P```"7]```K````6?T``#4```"%_0``'0``
M`+O]``!1````V?T``!$````K_@``,0```#W^```[````;_X``!,```"K_@``
M0````+_^```X`````/\```4````Y_P``#````#__```1````3/\```T```!>
M_P``!@```&S_```&````<_\``!<```!Z_P``"````)+_```,````F_\``!0`
M``"H_P``#P```+W_```0````S?\``!$```#>_P``"````/#_```%````^?\`
M`!$```#__P``#````!$``0`0````'@`!``4````O``$`#0```#4``0`&````
M0P`!``<```!*``$`#0```%(``0`'````8``!``L```!H``$`!P```'0``0`'
M````?``!``D```"$``$`%P```(X``0`F````I@`!`$\```#-``$`"0```!T!
M`0`*````)P$!`!D````R`0$`#````$P!`0`E````60$!`!\```!_`0$`$```
M`)\!`0`%````L`$!`"4```"V`0$`$@```-P!`0`3````[P$!`"L````#`@$`
M.P```"\"`0`@````:P(!`!L```",`@$`-@```*@"`0`(````WP(!`!L```#H
M`@$`'@````0#`0!<````(P,!`"X```"``P$`#````*\#`0`&````O`,!``0`
M``##`P$`#@```,@#`0`.````UP,!``<```#F`P$`#@```.X#`0`*````_0,!
M``T````(!`$`'@```!8$`0`;````-00!`"$```!1!`$`'@```',$`0`9````
MD@0!`!X```"L!`$`&P```,L$`0`F````YP0!`"0````.!0$`&P```#,%`0`>
M````3P4!`!P```!N!0$`)@```(L%`0`V````L@4!`#,```#I!0$`*0```!T&
M`0!!````1P8!`#H```")!@$`)@```,0&`0`K````ZP8!`#@````7!P$`+P``
M`%`'`0`2````@`<!`"D```"3!P$`$@```+T'`0"B````T`<!`!8```!S"`$`
M(P```(H(`0`H````K@@!`"D```#7"`$`*`````$)`0`?````*@D!`"````!*
M"0$`)0```&L)`0`H````D0D!`"$```"Z"0$`'````-P)`0`F````^0D!`$$`
M```@"@$`#````&(*`0`'````;PH!``<```!W"@$`!@```'\*`0`-````A@H!
M``L```"4"@$`%0```*`*`0`-````M@H!`!H```#$"@$`$````-\*`0`=````
M\`H!`!D````."P$`70```"@+`0`2````A@L!`!,```"9"P$`$@```*T+`0`'
M````P`L!``0```#("P$`#````,T+`0`.````V@L!``\```#I"P$`%````/D+
M`0`3````#@P!``T````B#`$`.0```#`,`0`<````:@P!`"@```"'#`$``P``
M`+`,`0`-````M`P!``8```#"#`$`$0```,D,`0`7````VPP!`!L```#S#`$`
M#@````\-`0`"````'@T!``4````A#0$`!0```"<-`0`0````+0T!``0````^
M#0$`#0```$,-`0`.````40T!``,```!@#0$`#@```&0-`0`(````<PT!``\`
M``!\#0$`"````(P-`0`/````E0T!``T```"E#0$`$````+,-`0`9````Q`T!
M`!H```#>#0$`"P```/D-`0`)````!0X!``8````/#@$`%````!8.`0`3````
M*PX!`!`````_#@$`#````%`.`0`1````70X!`!4```!O#@$`&0```(4.`0`+
M````GPX!``T```"K#@$`(@```+D.`0`K````W`X!`!<````(#P$`-````"`/
M`0`S````50\!``H```")#P$`&````)0/`0`9````K0\!`!8```#'#P$`!P``
M`-X/`0`0````Y@\!`!P```#W#P$`'````!00`0`-````,1`!``<````_$`$`
M#````$<0`0`F````5!`!``H```![$`$`%````(80`0`+````FQ`!``<```"G
M$`$`(@```*\0`0`O````TA`!``L````"$0$`"0````X1`0`9````&!$!``L`
M```R$0$`#P```#X1`0`7````3A$!`!<```!F$0$`"0```'X1`0`'````B!$!
M`!8```"0$0$`#P```*<1`0`M````MQ$!`!8```#E$0$`#@```/P1`0`:````
M"Q(!`"@````F$@$`"P```$\2`0`8````6Q(!``@```!T$@$`#````'T2`0`C
M````BA(!``T```"N$@$`)@```+P2`0`J````XQ(!`"`````.$P$`0P```"\3
M`0`(````<Q,!`!(```!\$P$`!````(\3`0`(````E!,!``L```"=$P$`&@``
M`*D3`0`G````Q!,!`!(```#L$P$`(````/\3`0`O````(!0!`!<```!0%`$`
M!0```&@4`0`,````;A0!``X```![%`$`#@```(H4`0`%````F10!``8```"?
M%`$`#@```*84`0`#````M10!`"L```"Y%`$`!P```.44`0`$````[10!``X`
M``#R%`$`"@````$5`0`,````#!4!``H````9%0$`#P```"05`0`0````-!4!
M`!<```!%%0$`$P```%T5`0`E````<14!``X```"7%0$`$0```*85`0`7````
MN!4!`!,```#0%0$`%@```.05`0`X````^Q4!`!,````T%@$`"0```$@6`0`%
M````4A8!``L```!8%@$`"@```&06`0`"````;Q8!``4```!R%@$`#0```'@6
M`0`;````AA8!`!<```"B%@$`"0```+H6`0`=````Q!8!``\```#B%@$`$@``
M`/(6`0`,````!1<!``X````2%P$`#0```"$7`0`2````+Q<!`!D```!"%P$`
M'````%P7`0`X````>1<!`!@```"R%P$`(````,L7`0`3````[!<!``,`````
M&`$`%0````08`0`+````&A@!`!,````F&`$`"````#H8`0`.````0Q@!`!``
M``!2&`$`>P```&,8`0`8````WQ@!`"D```#X&`$`+````"(9`0`H````3QD!
M`#4```!X&0$`$0```*X9`0`'````P!D!``4```#(&0$`&````,X9`0`9````
MYQD!``<````!&@$`"`````D:`0`&````$AH!``8````9&@$`&P```"`:`0`0
M````/!H!``\```!-&@$`$````%T:`0`/````;AH!``L```!^&@$`#P```(H:
M`0`,````FAH!``\```"G&@$`!P```+<:`0`&````OQH!``H```#&&@$`$@``
M`-$:`0`-````Y!H!``P```#R&@$`#@```/\:`0!#````#AL!`#T```!2&P$`
M"0```)`;`0`,````FAL!`"@```"G&P$`#P```-`;`0`(````X!L!``@```#I
M&P$`$P```/(;`0`>````!AP!`"$````E'`$`(````$<<`0`9````:!P!`!<`
M``""'`$`)0```)H<`0`7````P!P!``0```#8'`$`&P```-T<`0`-````^1P!
M``,````''0$`"`````L=`0`*````%!T!``P````?'0$`"@```"P=`0`@````
M-QT!`!\```!8'0$`"P```'@=`0`;````A!T!``L```"@'0$`"````*P=`0`$
M````M1T!``0```"Z'0$`$P```+\=`0`4````TQT!``P```#H'0$`"0```/4=
M`0`.````_QT!``L````.'@$`&P```!H>`0`.````-AX!``\```!%'@$`)0``
M`%4>`0`J````>QX!``<```"F'@$`$@```*X>`0`;````P1X!``0```#='@$`
M!P```.(>`0`*````ZAX!`!(```#U'@$`"@````@?`0`-````$Q\!``D````A
M'P$`!````"L?`0`%````,!\!``@````V'P$``P```#\?`0`8````0Q\!`!``
M``!<'P$`#@```&T?`0`>````?!\!`!H```";'P$`"@```+8?`0`$````P1\!
M`"8```#&'P$`#@```.T?`0!\````_!\!`!4```!Y(`$`1````(\@`0`%````
MU"`!``<```#:(`$`#````.(@`0`(````[R`!``H```#X(`$`!@````,A`0`'
M````"B$!``@````2(0$`$0```!LA`0`9````+2$!``@```!'(0$``@```%`A
M`0`&````4R$!``8```!:(0$`%````&$A`0`5````=B$!``\```",(0$`$0``
M`)PA`0`:````KB$!``T```#)(0$`$````-<A`0`;````Z"$!``4````$(@$`
M!`````HB`0`,````#R(!``D````<(@$`$````"8B`0`)````-R(!``D```!!
M(@$`!````$LB`0`%````4"(!`!H```!6(@$`!0```'$B`0`:````=R(!``@`
M``"2(@$`!@```)LB`0`/````HB(!`!D```"R(@$`#@```,PB`0`'````VR(!
M``<```#C(@$`(@```.LB`0`%````#B,!``D````4(P$`"@```!XC`0`-````
M*2,!``8````W(P$`#0```#XC`0`,````3",!``D```!9(P$`!@```&,C`0`2
M````:B,!``D```!](P$`!P```(<C`0`4````CR,!`!T```"D(P$`!@```,(C
M`0`*````R2,!``0```#4(P$`"0```-DC`0`(````XR,!`!$```#L(P$`"0``
M`/XC`0`&````""0!``T````/)`$`!@```!TD`0`$````)"0!``0````I)`$`
M%P```"XD`0`Y````1B0!`#T```"`)`$`.@```+XD`0`>````^20!``4````8
M)0$`#@```!XE`0`$````+24!``8````R)0$`!P```#DE`0`A````024!`!4`
M``!C)0$`!@```'DE`0`$````@"4!`!$```"%)0$`!@```)<E`0`*````GB4!
M`"(```"I)0$`)P```,PE`0`&````]"4!`!4```#[)0$`#````!$F`0`1````
M'B8!``0````P)@$`#0```#4F`0`'````0R8!``4```!+)@$`'0```%$F`0`$
M````;R8!``P```!T)@$`"@```($F`0`(````C"8!``D```"5)@$`!0```)\F
M`0`Z````I28!`#````#@)@$`-0```!$G`0`I````1R<!`$<```!Q)P$`.```
M`+DG`0`I````\B<!`#\````<*`$`+@```%PH`0`M````BR@!`!\```"Y*`$`
M#P```-DH`0`2````Z2@!``L```#\*`$`)@````@I`0`G````+RD!`"D```!7
M*0$`)````($I`0`F````IBD!`"@```#-*0$`"````/8I`0`*````_RD!``D`
M```**@$`!P```!0J`0`$````'"H!`!P````A*@$`(````#XJ`0`@````7RH!
M`"8```"`*@$`#0```*<J`0`G````M2H!`!L```#=*@$`#````/DJ`0`6````
M!BL!``4````=*P$`"@```",K`0`9````+BL!`"D```!(*P$`%@```'(K`0`2
M````B2L!``<```"<*P$`"@```*0K`0`,````KRL!``\```"\*P$`$````,PK
M`0!`````W2L!`'`````>+`$`9@```(\L`0`&````]BP!``H```#]+`$`#@``
M``@M`0`)````%RT!``H````A+0$`$@```"PM`0`3````/RT!``P```!3+0$`
M!@```&`M`0`&````9RT!``H```!N+0$`#@```'DM`0`.````B"T!`!\```"7
M+0$`'@```+<M`0`C````UBT!`!$```#Z+0$`%0````PN`0`8````(BX!`!$`
M```[+@$`$````$TN`0`C````7BX!``\```""+@$`"0```)(N`0`2````G"X!
M`!T```"O+@$`$@```,TN`0`0````X"X!``H```#Q+@$`$0```/PN`0`%````
M#B\!`#$````4+P$`)````$8O`0`<````:R\!`",```"(+P$`:@```*PO`0`/
M````%S`!``4````G,`$`$````"TP`0`)````/C`!``0```!(,`$`"P```$TP
M`0`<````63`!`",```!V,`$`(@```)HP`0`&````O3`!`!0```#$,`$`%P``
M`-DP`0`,````\3`!`"0```#^,`$`(P```",Q`0`:````1S$!``P```!B,0$`
M#P```&\Q`0`5````?S$!`"D```"5,0$`*@```+\Q`0`F````ZC$!`"<````1
M,@$`*0```#DR`0`J````8S(!`!D```".,@$`0@```*@R`0`1````ZS(!`!(`
M``#],@$`$P```!`S`0`4````)#,!``\````Y,P$`%@```$DS`0`7````8#,!
M`!````!X,P$`$0```(DS`0`T````FS,!`!,```#0,P$`$@```.0S`0`U````
M]S,!`!0````M-`$`!P```$(T`0`,````2C0!`"L```!7-`$`#P```(,T`0`6
M````DS0!`"````"J-`$`%````,LT`0`1````X#0!`"@```#R-`$`%P```!LU
M`0`<````,S4!`!,```!0-0$`"P```&0U`0`1````<#4!`!H```""-0$`'@``
M`)TU`0`:````O#4!`"$```#7-0$`(````/DU`0`1````&C8!`!0````L-@$`
M%P```$$V`0`5````638!``D```!O-@$`!@```'DV`0`9````@#8!``0```":
M-@$`!P```)\V`0`+````IS8!`!$```"S-@$`!@```,4V`0`&````S#8!``8`
M``#3-@$`!0```-HV`0`'````X#8!``<```#H-@$`!0```/`V`0`6````]C8!
M``8````--P$`!@```!0W`0`$````&S<!``0````@-P$`!P```"4W`0`.````
M+3<!``P````\-P$`#````$DW`0`-````5C<!``(```!D-P$`"@```&<W`0`.
M````<C<!``4```"!-P$`*````(<W`0`.````L#<!``P```"_-P$`#P```,PW
M`0`*````W#<!``@```#G-P$`"0```/`W`0`K````^C<!`"X````F.`$`!```
M`%4X`0`(````6C@!`"8```!C.`$`$@```(HX`0`/````G3@!``8```"M.`$`
M"@```+0X`0`'````OS@!``@```#'.`$`(````-`X`0`)````\3@!`!$```#[
M.`$`"0````TY`0`,````%SD!``T````D.0$`#@```#(Y`0`6````03D!`!$`
M``!8.0$`!@```&HY`0`#````<3D!``8```!U.0$`&0```'PY`0`'````ECD!
M``0```">.0$`"P```*,Y`0`+````KSD!``<```"[.0$`$0```,,Y`0`'````
MU3D!`!8```#=.0$`#0```/0Y`0`-`````CH!``H````0.@$`$````!LZ`0`/
M````+#H!`!$````\.@$`%P```$XZ`0`*````9CH!`!$```!Q.@$`"````(,Z
M`0`$````C#H!``\```"1.@$`.@```*$Z`0`A````W#H!``4```#^.@$`#```
M``0[`0`>````$3L!``X````P.P$`$````#\[`0`+````4#L!`'P```!<.P$`
M#````-D[`0`)````YCL!``<```#P.P$`"@```/@[`0`)`````SP!``X````-
M/`$`$````!P\`0`5````+3P!`!H```!#/`$`"@```%X\`0`)````:3P!``H`
M``!S/`$`#@```'X\`0`,````C3P!``\```":/`$`"````*H\`0`&````LSP!
M``P```"Z/`$`!P```,<\`0`%````SSP!``L```#5/`$`1P```.$\`0`-````
M*3T!``D````W/0$`!````$$]`0`#````1CT!``P```!*/0$`$P```%<]`0`3
M````:ST!`!,```!_/0$`!@```),]`0`*````FCT!``(```"E/0$`!````*@]
M`0`E````K3T!``,```#3/0$`!0```-<]`0`J````W3T!``X````(/@$`"@``
M`!<^`0`%````(CX!``0````H/@$`"@```"T^`0`-````.#X!`!\```!&/@$`
M!P```&8^`0`B````;CX!``T```"1/@$`!@```)\^`0`(````ICX!``@```"O
M/@$`!````+@^`0`%````O3X!`&@```##/@$`"0```"P_`0`,````-C\!``4`
M``!#/P$`!@```$D_`0`C````4#\!`"4```!T/P$`"````)H_`0`W````HS\!
M`"(```#;/P$`$P```/X_`0`;````$D`!`"\````N0`$`$````%Y``0`*````
M;T`!`!$```!Z0`$`#P```(Q``0`/````G$`!``H```"L0`$`"0```+=``0`3
M````P4`!`!L```#50`$`&````/%``0`7````"D$!`!<````B00$`#@```#I!
M`0`F````24$!`"8```!P00$``P```)=!`0`'````FT$!``@```"C00$`%```
M`*Q!`0`3````P4$!`!````#500$`#0```.9!`0`.````]$$!`!8````#0@$`
M!P```!I"`0`0````(D(!``H````S0@$`"P```#Y"`0`'````2D(!`!,```!2
M0@$`#````&9"`0`/````<T(!``X```"#0@$`#````))"`0`.````GT(!`%$`
M``"N0@$`#P````!#`0`0````$$,!``T````A0P$`#P```"]#`0`/````/T,!
M``\```!/0P$`(````%]#`0`N````@$,!`!H```"O0P$`#````,I#`0`F````
MUT,!``L```#^0P$`#0````I$`0`:````&$0!`$H````S1`$`!@```'Y$`0`&
M````A40!``8```",1`$`'P```)-$`0`&````LT0!``D```"Z1`$`&````,1$
M`0`7````W40!``8```#U1`$`#0```/Q$`0`B````"D4!`%<````M10$`$P``
M`(5%`0`C````F44!`!,```"]10$``@```-%%`0`+````U$4!``@```#@10$`
M#0```.E%`0`&````]T4!``H```#^10$`!P````E&`0`4````$48!``8````F
M1@$`"````"U&`0`.````-D8!``<```!%1@$`"@```$U&`0`+````6$8!``<`
M``!D1@$`#````&Q&`0`-````>48!``P```"'1@$`!````)1&`0`)````F48!
M``D```"C1@$`"@```*U&`0`'````N$8!``D```#`1@$`#@```,I&`0`'````
MV48!``H```#A1@$`&P```.Q&`0`5````"$<!`!(````>1P$`"@```#%'`0`)
M````/$<!`!````!&1P$`!P```%='`0`2````7T<!``0```!R1P$`!````'='
M`0`B````?$<!``<```"?1P$`!0```*='`0`,````K4<!``4```"Z1P$`"P``
M`,!'`0`4````S$<!`!$```#A1P$`&@```/-'`0`6````#D@!`!0````E2`$`
M%P```#I(`0`8````4D@!`!P```!K2`$`&0```(A(`0`'````HD@!``4```"J
M2`$`%@```+!(`0`#````QT@!``T```#+2`$`#````-E(`0`*````YD@!``@`
M``#Q2`$`"````/I(`0`7`````TD!``L````;20$`#````"=)`0`3````-$D!
M``0```!(20$`"@```$U)`0`$````6$D!``P```!=20$`"0```&I)`0`,````
M=$D!``D```"!20$`!0```(M)`0`'````D4D!``4```"920$`!````)])`0`"
M````I$D!`!0```"G20$`#0```+Q)`0`2````RDD!``L```#=20$`&P```.E)
M`0`?````!4H!`!0````E2@$`'@```#I*`0`5````64H!`#@```!O2@$`+```
M`*A*`0`2````U4H!`"D```#H2@$`,@```!)+`0`*````14L!`"P```!02P$`
M+@```'U+`0`S````K$L!`#,```#@2P$`.````!1,`0`/````34P!`!@```!=
M3`$`$````'9,`0`3````ATP!`"H```";3`$`&0```,9,`0`<````X$P!`!\`
M``#]3`$`#P```!U-`0`3````+4T!`!0```!!30$`%````%9-`0`@````:TT!
M`!(```",30$`%````)]-`0`5````M$T!`"T```#*30$`+0```/A-`0`Q````
M)DX!`"X```!83@$`+P```(=.`0`L````MTX!`&(```#D3@$`$P```$=/`0`E
M````6T\!`"0```"!3P$`*0```*9/`0`(````T$\!``@```#93P$`)````.)/
M`0`2````!U`!``X````:4`$`*P```"E0`0`2````55`!`"$```!H4`$`&@``
M`(I0`0`)````I5`!`$4```"O4`$`00```/50`0`/````-U$!``0```!'40$`
M$P```$Q1`0`4````8%$!``X```!U40$`!@```(11`0`3````BU$!`!@```"?
M40$`!@```+A1`0`)````OU$!``H```#)40$`"P```-11`0`)````X%$!``T`
M``#J40$`#````/A1`0`/````!5(!`!<````54@$`%````"U2`0`0````0E(!
M`!8```!34@$`!P```&I2`0`.````<E(!`"$```"!4@$`!0```*-2`0`;````
MJ5(!``@```#%4@$`!@```,Y2`0`4````U5(!`!$```#J4@$`1````/Q2`0`\
M````05,!``X```!^4P$`.````(U3`0`"````QE,!``(```#)4P$`!@```,Q3
M`0`.````TU,!``4```#B4P$`!P```.A3`0`.````\%,!``8```#_4P$`#```
M``94`0`C````$U0!``0````W5`$`*0```#Q4`0`R````9E0!`!<```"95`$`
M'P```+%4`0`S````T50!`%P````%50$`%````&)5`0`^````=U4!``T```"V
M50$`'P```,15`0`0````Y%4!`!0```#U50$`!P````I6`0`.````$E8!``P`
M```A5@$`#````"Y6`0`3````.U8!``H```!/5@$`'0```%I6`0`9````>%8!
M``4```"25@$`$0```)A6`0`3````JE8!``T```"^5@$`$0```,Q6`0`D````
MWE8!``,````#5P$`%0````=7`0`3````'5<!`!(````Q5P$`"P```$17`0`T
M````4%<!``L```"%5P$`%````)%7`0`^````IE<!``X```#E5P$`$P```/17
M`0`T````"%@!`#$````]6`$`$@```&]8`0`0````@E@!`!@```"36`$`&0``
M`*Q8`0`C````QE@!`"(```#J6`$`)P````U9`0!6````-5D!`$T```",60$`
M"````-I9`0`)````XUD!``T```#M60$`"@```/M9`0`+````!EH!``0````2
M6@$`'````!=:`0`-````-%H!`"<```!"6@$`&P```&I:`0`,````AEH!``H`
M``"36@$`!P```)Y:`0`-````IEH!`"(```"T6@$`(0```-=:`0`(````^5H!
M``4````"6P$`'P````A;`0`&````*%L!`!`````O6P$`"````$!;`0`'````
M25L!``T```!16P$`"@```%];`0`2````:EL!`"$```!]6P$`"P```)];`0`<
M````JUL!`!@```#(6P$`"````.%;`0`2````ZEL!`"P```#]6P$`&@```"I<
M`0`)````15P!``H```!/7`$`%0```%I<`0`%````<%P!`!0```!V7`$`!```
M`(M<`0`0````D%P!``8```"A7`$`!P```*A<`0`>````L%P!`"@```#/7`$`
M"@```/A<`0`:`````UT!`"T````>70$`"````$Q=`0`4````55T!`"P```!J
M70$`)P```)==`0`K````OUT!`"H```#K70$`!````!9>`0`$````&UX!``L`
M```@7@$`!0```"Q>`0`&````,EX!``@````Y7@$`!@```$)>`0`Q````25X!
M`!P```![7@$`"@```)A>`0`;````HUX!`#0```"_7@$`-````/1>`0`@````
M*5\!`"D```!*7P$`)P```'1?`0`@````G%\!`$$```"]7P$`&@```/]?`0`H
M````&F`!`!H```!#8`$`=@```%Y@`0!Y````U6`!`!P!``!/80$`*````&QB
M`0`=````E6(!`"D```"S8@$`'0```-UB`0`N````^V(!`%<````J8P$`-@``
M`()C`0`L````N6,!`"P```#F8P$`,0```!-D`0`N````160!`"(```!T9`$`
M!@```)=D`0`(````GF0!``4```"G9`$`"````*UD`0`9````MF0!`!D```#0
M9`$`*@```.ID`0`0````%64!`"L````F90$`(P```%)E`0`A````=F4!`"X`
M``"890$`-````,=E`0`(````_&4!`!<````%9@$`"@```!UF`0`'````*&8!
M`"$````P9@$`$````%)F`0`-````8V8!`!````!Q9@$`!0```()F`0`.````
MB&8!``@```"79@$`"P```*!F`0`4````K&8!``<```#!9@$`$P```,EF`0`(
M````W68!`#8```#F9@$`-P```!UG`0`+````56<!``D```!A9P$`"@```&MG
M`0`4````=F<!`"\```"+9P$`,@```+MG`0`+````[F<!``X```#Z9P$`#0``
M``EH`0`/````%V@!`!8````G:`$`/@```#YH`0`G````?6@!``4```"E:`$`
M!0```*MH`0`G````L6@!`!\```#9:`$`%@```/EH`0`7````$&D!``\````H
M:0$`!````#AI`0`*````/6D!``D```!(:0$`"P```%)I`0`.````7FD!``4`
M``!M:0$`'@```'-I`0`$````DFD!``T```"7:0$`,@```*5I`0!%````V&D!
M``L````>:@$`#@```"IJ`0`.````.6H!``D```!(:@$`"````%)J`0`0````
M6VH!`!4```!L:@$`$P```()J`0`7````EFH!``<```"N:@$`'@```+9J`0`5
M````U6H!`!0```#K:@$`!0````!K`0`4````!FL!``8````;:P$`"P```")K
M`0`'````+FL!`",````V:P$`%@```%IK`0`/````<6L!``X```"!:P$`*@``
M`)!K`0`&````NVL!``P```#":P$`&````,]K`0`-````Z&L!`!$```#V:P$`
M"P````AL`0`V````%&P!``T```!+;`$`"@```%EL`0`B````9&P!``L```"'
M;`$`#P```)-L`0`0````HVP!`"X```"T;`$`.@```.-L`0`.````'FT!``T`
M```M;0$`!0```#MM`0`+````06T!``P```!-;0$`#0```%IM`0`-````:&T!
M``X```!V;0$`#0```(5M`0`@````DVT!`"<```"T;0$`*P```-QM`0`(````
M"&X!``H````1;@$`!@```!QN`0`2````(VX!``X````V;@$`%P```$5N`0`R
M````76X!`!X```"0;@$`%@```*]N`0`<````QFX!`!0```#C;@$`!0```/AN
M`0`.````_FX!`!,````-;P$`&@```"%O`0`'````/&\!``8```!$;P$`$P``
M`$MO`0`4````7V\!`!$```!T;P$`2P```(9O`0`'````TF\!`!0```#:;P$`
M&````.]O`0`'````"'`!``4````0<`$`#````!9P`0`,````(W`!`!(````P
M<`$`!````$-P`0`'````2'`!``H```!0<`$`"P```%MP`0`,````9W`!``X`
M``!T<`$`#@```(-P`0`%````DG`!``4```"8<`$`+@```)YP`0`F````S7`!
M`",```#T<`$``P```!AQ`0`2````''$!``8````O<0$`!@```#9Q`0`>````
M/7$!`!8```!<<0$`&````'-Q`0`.````C'$!`#<```";<0$`#@```--Q`0`7
M````XG$!`$$```#Z<0$`-````#QR`0`E````<7(!`!4```"7<@$`,0```*UR
M`0`3````WW(!`!L```#S<@$`*@````]S`0!1````.G,!`%H```",<P$`4```
M`.=S`0`E````.'0!``T```!>=`$`"0```&QT`0`#````=G0!``<```!Z=`$`
M"@```()T`0`(````C70!``(```"6=`$`$````)ET`0`(````JG0!``P```"S
M=`$`%0```,!T`0`+````UG0!`!D```#B=`$`(````/QT`0`2````'74!``4`
M```P=0$`"@```#9U`0`5````074!`!(```!7=0$`#````&IU`0`$````=W4!
M``<```!\=0$`,@```(1U`0`*````MW4!``P```#"=0$`"P```,]U`0`'````
MVW4!`!8```#C=0$`4@```/IU`0`Z````378!`"````"(=@$`#P```*EV`0`7
M````N78!`#D```#1=@$`!P````MW`0`&````$W<!``D````:=P$`#@```"1W
M`0`.````,W<!``0```!"=P$`!@```$=W`0`6````3G<!``P```!E=P$`#0``
M`')W`0`.````@'<!`!4```"/=P$`$@```*5W`0`/````N'<!`!0```#(=P$`
M0P```-UW`0`*````(7@!`!L````L>`$`-0```$AX`0`1````?G@!`!````"0
M>`$`"P```*%X`0!I````K7@!`!H````7>0$`%P```#)Y`0`G````2GD!`!L`
M``!R>0$`&@```(YY`0`7````J7D!`!L```#!>0$`&0```-UY`0`?````]WD!
M`!<````7>@$`'````"]Z`0`7````3'H!``P```!D>@$`$P```'%Z`0`(````
MA7H!``<```".>@$`"````)9Z`0`0````GWH!`!$```"P>@$`"0```,)Z`0`5
M````S'H!``T```#B>@$`!@```/!Z`0`=````]WH!``<````5>P$`$P```!U[
M`0`#````,7L!`$8````U>P$`0P```'Q[`0`R````P'L!`#\```#S>P$`-P``
M`#-\`0!7````:WP!`!\```##?`$`+P```.-\`0`*````$WT!``T````>?0$`
M$@```"Q]`0`I````/WT!``@```!I?0$`#0```')]`0`M````@'T!`'````"N
M?0$`/P```!]^`0`Y````7WX!`$8```"9?@$`!````.!^`0`0````Y7X!`!``
M``#V?@$`#`````=_`0`4````%'\!`!T````I?P$`'````$=_`0`1````9'\!
M`#T```!V?P$`3P```+1_`0`E````!(`!`"`````J@`$`'````$N``0`+````
M:(`!`"<```!T@`$`&@```)R``0`?````MX`!`!T```#7@`$`*````/6``0`/
M````'H$!`"4````N@0$`(````%2!`0`D````=8$!`"0```":@0$`(````+^!
M`0`E````X($!``L````&@@$`!P```!*"`0`-````&H(!``P````H@@$`!0``
M`#6"`0`&````.X(!`#D```!"@@$`!0```'R"`0`,````@H(!``<```"/@@$`
M"0```)>"`0`3````H8(!``8```"U@@$`"0```+R"`0`$````QH(!`!````#+
M@@$`"````-R"`0`(````Y8(!``0```#N@@$`"P```/."`0`,````_X(!`!$`
M```,@P$`#````!Z#`0`:````*X,!``\```!&@P$`!P```%:#`0`-````7H,!
M``\```!L@P$`#````'R#`0`4````B8,!`!0```">@P$`#P```+.#`0`.````
MPX,!`!(```#2@P$`%````.6#`0`.````^H,!``P````)A`$`&P```!:$`0`L
M````,H0!`!,```!?A`$`'````'.$`0`H````D(0!``8```"YA`$`!P```,"$
M`0`3````R(0!``4```#<A`$`!````.*$`0`,````YX0!`!<```#TA`$`$@``
M``R%`0`+````'X4!``T````KA0$`%````#F%`0`O````3H4!``H```!^A0$`
M#````(F%`0`)````EH4!``8```"@A0$`"0```*>%`0`(````L84!``D```"Z
MA0$`!0```,2%`0`*````RH4!`!$```#5A0$`!@```.>%`0`.````[H4!``X`
M``#]A0$`#0````R&`0`+````&H8!`!`````FA@$`'0```#>&`0`1````588!
M``L```!GA@$``@```'.&`0`(````=H8!``<```!_A@$`#0```(>&`0`&````
ME88!`!8```"<A@$`"0```+.&`0`'````O88!`#L```#%A@$`*`````&'`0`5
M````*H<!``4```!`AP$`"P```$:'`0`'````4H<!``@```!:AP$`!P```&.'
M`0`%````:X<!``<```!QAP$`#@```'F'`0`)````B(<!``8```"2AP$`"```
M`)F'`0`+````HH<!``<```"NAP$`"````+:'`0`'````OX<!`!8```#'AP$`
M"0```-Z'`0`&````Z(<!`!D```#OAP$`&@````F(`0`@````)(@!``L```!%
MB`$`'````%&(`0`4````;H@!``<```"#B`$`"````(N(`0`(````E(@!``4`
M``"=B`$`$````*.(`0`0````M(@!``8```#%B`$`&0```,R(`0`*````YH@!
M`!P```#QB`$`!P````Z)`0`%````%HD!``4````<B0$`$````"*)`0`4````
M,XD!``L```!(B0$`#0```%2)`0`7````8HD!`!H```!ZB0$`%````)6)`0`O
M````JHD!``D```#:B0$`"@```.2)`0`'````[XD!``(```#WB0$`#@```/J)
M`0`(````"8H!`!\````2B@$`(P```#**`0`Q````5HH!`#@```"(B@$`&P``
M`,&*`0`Q````W8H!`#$````/BP$`)P```$&+`0`B````:8L!`"````",BP$`
M9````*V+`0`=````$HP!`!0````PC`$`70```$6,`0!5````HXP!`#@```#Y
MC`$`+0```#*-`0`S````8(T!`$L```"4C0$`2@```."-`0!;````*XX!`"@`
M``"'C@$`+````+".`0`X````W8X!`"4````6CP$`*````#R/`0`L````98\!
M`"<```"2CP$`&P```+J/`0`>````UH\!`'4```#UCP$`/@```&N0`0!"````
MJI`!`#T```#MD`$`*0```"N1`0`I````59$!`#$```!_D0$`/@```+&1`0`O
M````\)$!`*D!```@D@$`(P```,J3`0!/````[I,!`!<````^E`$`2````%:4
M`0`V````GY0!`#X```#6E`$`,````!65`0`@````1I4!`#\```!GE0$`-```
M`*>5`0`=````W)4!`!X```#ZE0$`*@```!F6`0"%````1)8!`#````#*E@$`
M00```/N6`0!@````/9<!`%L```">EP$`20```/J7`0`T````1)@!`#P```!Y
MF`$`.````+:8`0`=````[Y@!`!@````-F0$`IP```":9`0`A````SID!`!\`
M``#PF0$`)````!":`0`H````-9H!`"L```!>F@$`(@```(J:`0`A````K9H!
M`"D```#/F@$`%P```/F:`0`I````$9L!`"`````[FP$`,@```%R;`0`<````
MCYL!`"X```"LFP$`'0```-N;`0`1````^9L!`#,````+G`$`)0```#^<`0`X
M````99P!`"<```">G`$`/````,:<`0`F`````YT!`!\````JG0$`,````$J=
M`0!I````>YT!`#X```#EG0$`/@```"2>`0!'````8YX!`#T```"KG@$`90``
M`.F>`0!-````3Y\!`%,```"=GP$`5P```/&?`0!5````2:`!`$8```"?H`$`
M*@```.:@`0`O````$:$!`%4```!!H0$`(````)>A`0`N````N*$!`"L```#G
MH0$`,````!.B`0`J````1*(!`#X```!OH@$`5````*ZB`0!2`````Z,!`%H`
M``!6HP$`,@```+&C`0`K````Y*,!`$@````0I`$`2@```%FD`0`J````I*0!
M`"8```#/I`$`+````/:D`0!.````(Z4!`#(```!RI0$`,````*6E`0`=````
MUJ4!`",```#TI0$`+P```!BF`0`L````2*8!`"T```!UI@$`<0```*.F`0!O
M````%:<!`+,```"%IP$`%P```#FH`0`E````4:@!`#(```!WJ`$`*0```*JH
M`0`^````U*@!`"(````3J0$`4@```#:I`0`E````B:D!``L```"OJ0$`L0``
M`+NI`0`[````;:H!`"<```"IJ@$`3@```-&J`0!'````(*L!`&(```!HJP$`
M20```,NK`0!5````%:P!`$````!KK`$`+P```*RL`0`R````W*P!`"L````/
MK0$`*0```#NM`0`/````9:T!`$4```!UK0$`(0```+NM`0`P````W:T!`"T`
M```.K@$`)0```#RN`0`<````8JX!`#$```!_K@$`,0```+&N`0`+````XZX!
M``<```#OK@$`!P```/>N`0`$````_ZX!``T````$KP$`"P```!*O`0`.````
M'J\!``L````MKP$`!0```#FO`0`0````/Z\!``(```!0KP$`"@```%.O`0!6
M````7J\!`%D```"UKP$`!0````^P`0`2````%;`!``0````HL`$`!P```"VP
M`0`(````-;`!``4````^L`$``P```$2P`0`0````2+`!`!<```!9L`$`#```
M`'&P`0`,````?K`!``T```"+L`$`$P```)FP`0`-````K;`!``(```"[L`$`
M!P```+ZP`0`&````QK`!`!0```#-L`$`#````.*P`0`8````[[`!``8````(
ML0$`$@````^Q`0`,````(K$!``,````OL0$`*@```#.Q`0`$````7K$!``8`
M``!CL0$`!P```&JQ`0`?````<K$!`#4```"2L0$`+@```,BQ`0`O````][$!
M`!<````GL@$`(````#^R`0`;````8+(!`!@```!\L@$`)````)6R`0`?````
MNK(!`!H```#:L@$`(````/6R`0`:````%K,!`#(````QLP$`+P```&2S`0`K
M````E+,!`!\```#`LP$`(P```."S`0`?````!+0!`!H````DM`$`)0```#^T
M`0`F````9;0!`"4```",M`$`)````+*T`0`8````U[0!`!T```#PM`$`)```
M``ZU`0`8````,[4!`"(```!,M0$`)0```&^U`0`\````E;4!`!\```#2M0$`
M(P```/*U`0`?````%K8!`"`````VM@$`&@```%>V`0`8````<K8!`!@```"+
MM@$`)@```*2V`0`>````R[8!`"D```#JM@$`'@```!2W`0`*````,[<!`!,`
M```^MP$`"````%*W`0`)````6[<!`!8```!EMP$`#````'RW`0`7````B;<!
M`"\```"AMP$`)````-&W`0`'````]K<!`!\```#^MP$`#P```!ZX`0`4````
M+K@!``X```!#N`$`#0```%*X`0`D````8+@!``4```"%N`$`!P```(NX`0`,
M````D[@!``\```"@N`$`$0```+"X`0`B````PK@!`"4```#EN`$`'0````NY
M`0`:````*;D!`!$```!$N0$`!P```%:Y`0#'````7KD!``8````FN@$`"P``
M`"VZ`0`:````.;H!`!4```!4N@$`!@```&JZ`0`)````<;H!`!T```![N@$`
M&````)FZ`0`+````LKH!`!<```"^N@$`!@```-:Z`0`S````W;H!`!,````1
MNP$`$P```"6[`0`'````.;L!``\```!!NP$`$0```%&[`0`>````8[L!``<`
M``""NP$`,@```(J[`0`$````O;L!`"$```#"NP$`$P```.2[`0`,````^+L!
M`!$````%O`$`,@```!>\`0`(````2KP!``D```!3O`$`"@```%V\`0`4````
M:+P!``H```!]O`$`'0```(B\`0`(````IKP!`!\```"OO`$`"````,^\`0`:
M````V+P!``8```#SO`$`%0```/J\`0`'````$+T!``@````8O0$`"0```"&]
M`0`_````*[T!``<```!KO0$`#P```'.]`0`.````@[T!`!````"2O0$`"0``
M`*.]`0`)````K;T!``@```"WO0$`$P```,"]`0`$````U+T!``<```#9O0$`
M$@```.&]`0`F````]+T!`!D````;O@$`&````#6^`0`+````3KX!``X```!:
MO@$`&0```&F^`0`*````@[X!`"0```".O@$`"@```+.^`0`3````OKX!`"<`
M``#2O@$`"0```/J^`0`/````!+\!`!<````4OP$`%````"R_`0`H````0;\!
M``\```!JOP$`%````'J_`0`*````C[\!``P```":OP$`%P```*>_`0`$````
MO[\!`"H```#$OP$`$0```.^_`0`"`````<`!`!`````$P`$`&````!7``0`+
M````+L`!``,````ZP`$`"````#[``0`&````1\`!``<```!.P`$`#0```%;`
M`0`+````9,`!`!0```!PP`$`%0```(7``0`.````F\`!`"\```"JP`$`(```
M`-K``0`<````^\`!`%H````8P0$`/P```'/!`0`V````L\$!``P```#JP0$`
M,0```/?!`0`)````*<(!``4````SP@$`$@```#G"`0`_````3,(!`!(```",
MP@$`"@```)_"`0`&````JL(!``0```"QP@$`!````+;"`0`3````N\(!``4`
M``#/P@$`!@```-7"`0`&````W,(!``0```#CP@$`#````.C"`0`*````]<(!
M``4`````PP$`&`````;#`0`9````'\,!`!\````YPP$`'0```%G#`0`1````
M=\,!``(```")PP$`!````(S#`0`*````D<,!``8```"<PP$`!0```*/#`0`#
M````J<,!``P```"MPP$`.P```+K#`0`G````]L,!`"$````>Q`$`)````$#$
M`0!%````9<0!`!H```"KQ`$`'0```,;$`0`U````Y,0!`%8````:Q0$`*```
M`''%`0!3````FL4!`#H```#NQ0$`0@```"G&`0`9````;,8!`!<```"&Q@$`
MBP```)[&`0`9````*L<!`"H```!$QP$`*P```&_'`0!R````F\<!`"`````.
MR`$`-0```"_(`0`A````9<@!`$4```"'R`$`)@```,W(`0`P````],@!`$L`
M```ER0$`3@```'')`0`G````P,D!`"D```#HR0$`(0```!+*`0`H````-,H!
M`"L```!=R@$`'0```(G*`0`I````I\H!`"8```#1R@$`+0```/C*`0`E````
M)LL!`"@```!,RP$`*````'7+`0`B````GLL!`"D```#!RP$`(@```.O+`0`]
M````#LP!`$$```!,S`$`*````([,`0`L````M\P!`#````#DS`$`$@```!7-
M`0`3````*,T!`!`````\S0$`>0```$W-`0`)````Q\T!`!P```#1S0$`$```
M`.[-`0`/````_\T!`"<````/S@$`#@```#?.`0!S````1LX!`'P```"ZS@$`
M0````#?/`0`K````>,\!`!<```"DSP$`*@```+S/`0`T````Y\\!`!8````<
MT`$`#P```#/0`0`H````0]`!`!\```!LT`$`'P```(S0`0`<````K-`!`%$`
M``#)T`$`%````!O1`0`/````,-$!``H```!`T0$`!0```$O1`0`&````4=$!
M``@```!8T0$`!0```&'1`0`2````9]$!``P```!ZT0$`$````(?1`0`3````
MF-$!`!T```"LT0$`#P```,K1`0`/````VM$!``0```#JT0$`"@```._1`0`$
M````^M$!``,```#_T0$`"0````/2`0`'````#=(!``L````5T@$`"````"'2
M`0`'````*M(!``4````RT@$`"0```#C2`0`4````0M(!``8```!7T@$`!P``
M`%[2`0`(````9M(!``\```!OT@$`#P```'_2`0`(````C](!``P```"8T@$`
M!@```*72`0`)````K-(!``L```"VT@$`#P```,+2`0`&````TM(!``<```#9
MT@$`#0```.'2`0`&````[](!`!0```#VT@$`!P````O3`0`#````$],!``D`
M```7TP$`!@```"'3`0`,````*-,!``H````UTP$`#````$#3`0`*````3=,!
M``\```!8TP$`!0```&C3`0`(````;M,!``0```!WTP$`"@```'S3`0`'````
MA],!``0```"/TP$`!````)33`0`9````F=,!``(```"STP$`"0```+;3`0`&
M````P-,!``,```#'TP$`!@```,O3`0`,````TM,!`"<```#?TP$`!`````?4
M`0`$````#-0!``\````1U`$`$P```"'4`0`'````-=0!``(````]U`$`!P``
M`$#4`0`&````2-0!``8```!/U`$`$````%;4`0`2````9]0!``X```!ZU`$`
M#P```(G4`0`&````F=0!``D```"@U`$`(@```*K4`0`'````S=0!``<```#5
MU`$`"P```-W4`0`%````Z=0!``(```#OU`$`"P```/+4`0`.````_M0!``X`
M```-U0$`20$``!S5`0`*````9M8!``H```!QU@$`"@```'S6`0`/````A]8!
M``\```"7U@$`#````*?6`0`(````M-8!``@```"]U@$`"0```,;6`0`*````
MT-8!``4```#;U@$``P```.'6`0`!````Y=8!`!D```#GU@$`"P````'7`0!&
M````#=<!`#8```!4UP$`2````(O7`0`X````U-<!`!<````-V`$`$0```"78
M`0`.````-]@!``\```!&V`$`!0```%;8`0`:````7-@!``H```!WV`$`$0``
M`(+8`0`.````E-@!`#$```"CV`$`#````-78`0`:````XM@!`"H```#]V`$`
M#@```"C9`0`3````-]D!``\```!+V0$`*0```%O9`0`B````A=D!`"L```"H
MV0$`&0```-39`0`.````[MD!``@```#]V0$`$P````;:`0`N````&MH!`"(`
M``!)V@$`#0```&S:`0`5````>MH!`!P```"0V@$`+````*W:`0`-````VMH!
M``T```#HV@$`$````/;:`0`4````!]L!``8````<VP$`&P```"/;`0`C````
M/]L!`#L```!CVP$`?0```)_;`0!J````'=P!`!P```"(W`$`'0```*7<`0`/
M````P]P!`!H```#3W`$`#````.[<`0!%````^]P!`#4```!!W0$`1P```'?=
M`0`W````O]T!``H```#WW0$`"P````+>`0`.````#MX!``X````=W@$`!0``
M`"S>`0`*````,MX!``H````]W@$`+@```$C>`0`:````=]X!`#,```"2W@$`
M5@```,;>`0`T````'=\!`#X```!2WP$`4@```)'?`0!,````Y-\!`%@````Q
MX`$`4@```(K@`0`W````W>`!``@````5X0$`!0```![A`0`"````).$!``8`
M```GX0$`$@```"[A`0`$````0>$!``D```!&X0$`"0```%#A`0`/````6N$!
M``@```!JX0$`*0```'/A`0`M````G>$!``P```#+X0$`$````-CA`0`+````
MZ>$!``T```#UX0$`!P````/B`0`%````"^(!`!`````1X@$`&````"+B`0`,
M````.^(!`!(```!(X@$`%0```%OB`0`8````<>(!``T```"*X@$`$````)CB
M`0`)````J>(!``D```"SX@$`(0```+WB`0`3````W^(!`!````#SX@$`$P``
M``3C`0`0````&.,!`!@````IXP$`)0```$+C`0`C````:.,!`!,```",XP$`
M'P```*#C`0`O````P.,!`!P```#PXP$`+`````WD`0`'````.N0!``<```!"
MY`$`"0```$KD`0`T````5.0!``X```")Y`$`!P```)CD`0`*````H.0!``@`
M``"KY`$`"````+3D`0`)````O>0!``@```#'Y`$`"@```-#D`0`#````V^0!
M`!<```#?Y`$`"P```/?D`0`.`````^4!`!`````2Y0$`1````"/E`0!0````
M:.4!`#0```"YY0$`/P```.[E`0!%````+N8!`!,```!TY@$`*0```(CF`0`*
M````LN8!`!D```"]Y@$`%P```-?F`0`A````[^8!`!P````1YP$`%0```"[G
M`0`6````1.<!`!X```!;YP$`!0```'KG`0`5````@.<!``X```"6YP$`4@``
M`*7G`0`A````^.<!`#H````:Z`$`!@```%7H`0`&````7.@!``<```!CZ`$`
M#@```&OH`0`'````>N@!``L```""Z`$`%0```([H`0`*````I.@!`!(```"O
MZ`$`"@```,+H`0`0````S>@!`!L```#>Z`$`#@```/KH`0`4````">D!`"@`
M```>Z0$`+@```$?I`0`J````=ND!``8```"AZ0$`!0```*CI`0`6````KND!
M`!H```#%Z0$`"@```.#I`0`W````Z^D!`$L````CZ@$`*P```&_J`0!`````
MF^H!`#<```#<Z@$`-@```!3K`0`M````2^L!`#D```!YZP$`.````+/K`0`^
M````[.L!`$`````K[`$`"0```&SL`0`(````=NP!`!8```!_[`$`"P```);L
M`0`(````HNP!``4```"K[`$`"0```+'L`0`.````N^P!``L```#*[`$`&```
M`-;L`0`'````[^P!`#<```#W[`$`%````"_M`0`&````1.T!``\```!+[0$`
M-````%OM`0`)````D.T!`$\```":[0$`+P```.KM`0`(````&NX!`"0````C
M[@$`"````$CN`0`D````4>X!`"D```!V[@$`*0```*#N`0`H````RNX!``H`
M``#S[@$`!0```/[N`0`(````!.\!``8````-[P$`"@```!3O`0`(````'^\!
M`#4````H[P$`.````%[O`0`T````E^\!`%H```#,[P$`,P```"?P`0`N````
M6_`!`#,```"*\`$`,P```+[P`0`]````\O`!`"T````P\0$`+0```%[Q`0`S
M````C/$!`#D```#`\0$`$P```/KQ`0`7````#O(!`"@````F\@$`)0```$_R
M`0!5````=?(!`!H```#+\@$`%0```.;R`0`-````_/(!``L````*\P$`#0``
M`!;S`0`,````)/,!``L````Q\P$`!@```#WS`0`,````1/,!`!H```!1\P$`
M)````&SS`0`&````D?,!``<```"8\P$`%@```*#S`0`)````M_,!``@```#!
M\P$`!@```,KS`0`#````T?,!``H```#5\P$`!P```.#S`0`&````Z/,!`"T`
M``#O\P$`!0```!WT`0`'````(_0!``4````K]`$`"P```#'T`0`)````/?0!
M`"L```!']`$`$````'/T`0`+````A/0!`$$```"0]`$`!````-+T`0`&````
MU_0!``@```#>]`$`#````.?T`0`#````]/0!``X```#X]`$`!@````?U`0`4
M````#O4!``4````C]0$`)@```"GU`0`'````4/4!``8```!8]0$`"P```%_U
M`0`)````:_4!`",```!U]0$`$0```)GU`0`)````J_4!``\```"U]0$`#```
M`,7U`0`'````TO4!``,```#:]0$``P```-[U`0`6````XO4!`!0```#Y]0$`
M#0````[V`0`'````'/8!``4````D]@$`"````"KV`0`'````,_8!`"\````[
M]@$`,````&OV`0!>````G/8!`$\```#[]@$`-````$OW`0`&````@/<!``@`
M``"']P$`$@```)#W`0`7````H_<!`#$```"[]P$`(@```.WW`0`=````$/@!
M`#(````N^`$`'P```&'X`0`U````@?@!`',```"W^`$`+P```"OY`0`*````
M6_D!``8```!F^0$`%````&WY`0`/````@OD!``(```"2^0$`#P```)7Y`0`0
M````I?D!`!@```"V^0$`$````,_Y`0`<````X/D!``\```#]^0$`%0````WZ
M`0`'````(_H!`!@````K^@$`'````$3Z`0`4````8?H!`!$```!V^@$``P``
M`(CZ`0`2````C/H!``@```"?^@$`#````*CZ`0`-````M?H!`&4```##^@$`
M*0```"G[`0!4````4_L!`&H```"H^P$`!````!/\`0`.````&/P!`!0````G
M_`$`&````#S\`0`4````5?P!`#H```!J_`$`+````*7\`0`$````TOP!``@`
M``#7_`$`(````.#\`0`=`````?T!`!$````?_0$`&0```#']`0`.````2_T!
M`!@```!:_0$`$0```'/]`0`?````A?T!`"P```"E_0$`-P```-+]`0!`````
M"OX!`!````!+_@$`)@```%S^`0`%````@_X!`!@```")_@$`%@```*+^`0`2
M````N?X!`!P```#,_@$`2@```.G^`0`B````-/\!`"<```!7_P$`,@```'__
M`0`G````LO\!`"X```#:_P$`%P````D``@!9````(0`"`!8```![``(`-@``
M`)(``@`W````R0`"`!4````!`0(`0@```!<!`@`K````6@$"``4```"&`0(`
M"@```(P!`@`-````EP$"``H```"E`0(`!@```+`!`@`'````MP$"`!````"_
M`0(`!0```-`!`@`)````U@$"``X```#@`0(`"@```.\!`@`3````^@$"``P`
M```.`@(`"0```!L"`@`%````)0("`!(````K`@(`#0```#X"`@`,````3`("
M``@```!9`@(`$````&("`@`&````<P("``0```!Z`@(`#0```'\"`@`(````
MC0("``,```"6`@(`!@```)H"`@`(````H0("``<```"J`@(`&````+("`@`D
M````RP("`%X```#P`@(`"P```$\#`@`&````6P,"`!4```!B`P(`"@```'@#
M`@`8````@P,"`!L```"<`P(`#````+@#`@`%````Q0,"`!L```#+`P(`$P``
M`.<#`@`3````^P,"`"X````/!`(`/@```#X$`@`C````?00"`!\```"A!`(`
M)P```,$$`@`&````Z00"`"````#P!`(`(P```!$%`@!0````-04"`"8```"&
M!0(`#0```*T%`@`(````NP4"``<```#$!0(`#P```,P%`@`.````W`4"``<`
M``#K!0(`%````/,%`@`)````"`8"`!(````2!@(`)P```"4&`@`G````308"
M`"P```!U!@(`+````*(&`@`?````SP8"`"D```#O!@(`(P```!D'`@`N````
M/0<"`"D```!L!P(`*````)8'`@`K````OP<"`"(```#K!P(`+P````X(`@`T
M````/@@"`#L```!S"`(`(P```*\(`@`\````TP@"`#@````0"0(`)P```$D)
M`@`P````<0D"`#D```"B"0(`.@```-P)`@`5````%PH"`"P````M"@(`%@``
M`%H*`@"[````<0H"`!L````M"P(`(````$D+`@`I````:@L"`"H```"4"P(`
M+````+\+`@`R````[`L"`"8````?#`(`-````$8,`@`W````>PP"`"$```"S
M#`(`(P```-4,`@`P````^0P"`$D````J#0(`$P```'0-`@`&````B`T"``8`
M``"/#0(`!P```)8-`@`,````G@T"``X```"K#0(`%@```+H-`@`0````T0T"
M`!P```#B#0(`#````/\-`@`B````#`X"`!H````O#@(`>@```$H.`@`/````
MQ0X"`!````#5#@(`&0```.8.`@`'``````\"``0````(#P(`#`````T/`@`/
M````&@\"``X````J#P(`%0```#D/`@`0````3P\"``T```!@#P(`,@```&X/
M`@`E````H0\"`#$```#'#P(`!@```/D/`@`.`````!`"``4````/$`(`$0``
M`!40`@`7````)Q`"`!H````_$`(`!0```%H0`@`"````8!`"``8```!C$`(`
M!@```&H0`@`2````<1`"``4```"$$`(`#0```(H0`@`-````F!`"``,```"F
M$`(`#P```*H0`@`(````NA`"``D```##$`(`"0```,T0`@`.````UQ`"``X`
M``#F$`(`$P```/40`@`5````"1$"`!H````?$0(`"@```#H1`@`*````11$"
M``<```!0$0(`%@```%@1`@`7````;Q$"``\```"'$0(`#P```)<1`@`/````
MIQ$"`!8```"W$0(`'````,X1`@`.````ZQ$"``\```#Z$0(`)P````H2`@`S
M````,A("`!L```!F$@(`*@```((2`@`X````K1("``\```#F$@(`&@```/82
M`@`8````$1,"`!@````J$P(`"0```$,3`@`3````31,"`!8```!A$P(`'P``
M`'@3`@`+````F!,"``8```"D$P(`#@```*L3`@`K````NA,"``<```#F$P(`
M#0```.X3`@`$````_!,"``L````!%`(`*`````T4`@`I````-A0"``8```!@
M%`(`!````&<4`@`2````;!0"``8```!_%`(`$0```(84`@`8````F!0"`!@`
M``"Q%`(`!@```,H4`@`&````T10"`!P```#8%`(`$````/44`@`H````!A4"
M`!4````O%0(`#@```$45`@`:````5!4"`"H```!O%0(`"P```)H5`@`7````
MIA4"``<```"^%0(`"P```,85`@`C````TA4"``H```#V%0(`,0````$6`@`A
M````,Q8"`!L```!5%@(`.````'$6`@`(````JA8"`!8```"S%@(`!P```,H6
M`@`'````TA8"``H```#:%@(`&````.46`@`G````_A8"`!`````F%P(`'@``
M`#<7`@`Q````5A<"`!8```"(%P(`!P```)\7`@`.````IQ<"``\```"V%P(`
M#P```,87`@`%````UA<"``<```#<%P(`#P```.07`@`#````]!<"`#(```#X
M%P(`!P```"L8`@`%````,Q@"``\````Y&`(`"@```$D8`@`,````5!@"``T`
M``!A&`(`#0```&\8`@`-````?1@"`!,```"+&`(`%````)\8`@`E````M!@"
M``\```#:&`(`$@```.H8`@`3````_1@"`!8````1&0(`(0```"@9`@`^````
M2AD"`!8```")&0(`"0```*`9`@`%````JAD"``@```"P&0(`"@```+D9`@`"
M````Q!D"``<```#'&0(`#P```,\9`@`C````WQD"`!4````#&@(`!@```!D:
M`@`=````(!H"`!`````^&@(`%@```$\:`@`/````9AH"`!$```!V&@(`$```
M`(@:`@`4````F1H"``T```"N&@(`$````+P:`@`U````S1H"`!H````#&P(`
M&@```!X;`@`4````.1L"``4```!.&P(`'0```%0;`@`/````<AL"`!4```""
M&P(`"@```)@;`@`3````HQL"`!<```"W&P(`>@```,\;`@`5````2AP"`"0`
M``!@'`(`*@```(4<`@`C````L!P"`"@```#4'`(`%````/T<`@`(````$AT"
M``8````;'0(`(P```"(=`@`>````1AT"``@```!E'0(`"````&X=`@`$````
M=QT"``8```!\'0(`&0```(,=`@`/````G1T"``X```"M'0(`$````+P=`@`.
M````S1T"`!````#<'0(`#0```.T=`@`,````^QT"``@````('@(`!@```!$>
M`@`'````&!X"``L````@'@(`$````"P>`@`,````/1X"``T```!*'@(`%0``
M`%@>`@`[````;AX"`"<```"J'@(`"@```-(>`@`.````W1X"`#X```#L'@(`
M$0```"L?`@`)````/1\"``X```!''P(`%0```%8?`@`;````;!\"`"0```"(
M'P(`(P```*T?`@`<````T1\"`!L```#N'P(`+`````H@`@`<````-R`"``0`
M``!4(`(`$0```%D@`@`+````:R`"``0```!W(`(`!P```'P@`@`)````A"`"
M``L```".(`(`"@```)H@`@`:````I2`"`!X```#`(`(`"P```-\@`@`=````
MZR`"``H````)(0(`!P```!0A`@`%````'"$"``@````B(0(`'````"LA`@`;
M````2"$"`!(```!D(0(`#````'<A`@`/````A"$"`!L```"4(0(`*0```+`A
M`@`0````VB$"`!(```#K(0(`+@```/XA`@`N````+2("``8```!<(@(`$P``
M`&,B`@`?````=R("``4```"7(@(`!@```)TB`@`-````I"("`!8```"R(@(`
M"@```,DB`@`-````U"("``\```#B(@(`"0```/(B`@`&````_"("``<````#
M(P(`!0````LC`@`2````$2,"`!,````D(P(`"0```#@C`@`B````0B,"`!D`
M``!E(P(`#@```'\C`@`%````CB,"`",```"4(P(`#0```+@C`@!B````QB,"
M`!,````I)`(`.@```#TD`@`'````>"0"``<```"`)`(`#@```(@D`@`'````
MER0"``D```"?)`(`!P```*DD`@`(````L20"``D```"Z)`(`%0```,0D`@`;
M````VB0"``P```#V)`(``@````,E`@`'````!B4"``@````.)0(`#P```!<E
M`@`9````)R4"`!4```!!)0(`%0```%<E`@`@````;24"`!````".)0(`%```
M`)\E`@`7````M"4"``,```#,)0(``@```-`E`@`)````TR4"``,```#=)0(`
M"@```.$E`@`*````["4"``D```#W)0(`!`````$F`@`$````!B8"`!T````+
M)@(`!0```"DF`@`7````+R8"``D```!')@(`!P```%$F`@`0````628"`!H`
M``!J)@(`%P```(4F`@`'````G28"``<```"E)@(`*0```*TF`@`$````UR8"
M``D```#<)@(`"@```.8F`@`2````\28"``8````$)P(`#@````LG`@`-````
M&B<"`!$````H)P(`!@```#HG`@`2````02<"``P```!4)P(`!P```&$G`@`5
M````:2<"`"$```!_)P(`!P```*$G`@`*````J2<"``0```"T)P(`"0```+DG
M`@`(````PR<"``T```#,)P(`#0```-HG`@`'````Z"<"``X```#P)P(`!P``
M`/\G`@`%````!R@"``0````-*`(`&````!(H`@`\````*R@"`#X```!H*`(`
M/````*<H`@`?````Y"@"``4````$*0(`#@````HI`@`&````&2D"``4````@
M*0(`#0```"8I`@`=````-"D"`!@```!2*0(`!@```&LI`@`%````<BD"`!X`
M``!X*0(`"````)<I`@`'````H"D"`!<```"H*0(`*@```,`I`@`&````ZRD"
M`!D```#R*0(`#P````PJ`@`0````'"H"``8````M*@(`$0```#0J`@`(````
M1BH"``8```!/*@(`)@```%8J`@`%````?2H"``T```"#*@(`#@```)$J`@`(
M````H"H"``D```"I*@(`!0```+,J`@`Z````N2H"`#0```#T*@(`.````"DK
M`@`F````8BL"`#<```")*P(`/P```,$K`@`M`````2P"`#<````O+`(`,0``
M`&<L`@`U````F2P"`"<```#/+`(`#@```/<L`@`/````!BT"``H````6+0(`
M*P```"$M`@`?````32T"`!\```!M+0(`'P```(TM`@`=````K2T"`"H```#+
M+0(`"````/8M`@`)````_RT"``D````)+@(`"0```!,N`@`$````'2X"`!8`
M```B+@(`*@```#DN`@`G````9"X"`"T```",+@(`#@```+HN`@`H````R2X"
M`!X```#R+@(`#@```!$O`@`:````("\"``4````[+P(`"0```$$O`@`6````
M2R\"`",```!B+P(`'@```(8O`@`4````I2\"``D```"Z+P(`"@```,0O`@`+
M````SR\"``\```#;+P(`#P```.LO`@`R````^R\"`&\````N,`(`:P```)XP
M`@`&````"C$"``H````1,0(`$````!PQ`@`)````+3$"``H````W,0(`$0``
M`$(Q`@`2````5#$"`!@```!G,0(`!0```(`Q`@`%````AC$"``L```",,0(`
M$0```)@Q`@`/````JC$"`!X```"Z,0(`'````-DQ`@`<````]C$"`!$````3
M,@(`%0```"4R`@`8````.S("`!(```!4,@(`$P```&<R`@`A````>S("``X`
M``"=,@(`"````*PR`@`2````M3("`!D```#(,@(`$0```.(R`@`.````]#("
M``8````#,P(`%0````HS`@`%````(#,"`"D````F,P(`)0```%`S`@`?````
M=C,"`"@```"6,P(`>P```+\S`@`-````.S0"``8```!)-`(`%````%`T`@`*
M````930"``0```!P-`(`"P```'4T`@`>````@30"`"4```"@-`(`(P```,8T
M`@`'````ZC0"`!4```#R-`(`%0````@U`@`,````'C4"`"4````K-0(`(P``
M`%$U`@`<````=34"``T```"2-0(`%P```*`U`@`7````N#4"`!\```#0-0(`
M(0```/`U`@`>````$C8"`"$````Q-@(`)@```%,V`@`H````>C8"`!P```"C
M-@(`.````,`V`@`3````^38"`!4````--P(`%````",W`@`6````.#<"`!``
M``!/-P(`%P```&`W`@`5````>#<"`!0```".-P(`%@```*,W`@`Q````NC<"
M`!(```#L-P(`%0```/\W`@`Y````%3@"`!(```!/.`(`!P```&(X`@`-````
M:C@"`#,```!X.`(`$0```*PX`@`>````OC@"`"````#=.`(`$P```/XX`@`2
M````$CD"`"<````E.0(`%P```$TY`@`<````93D"`!<```"".0(`$````)HY
M`@`1````JSD"`!P```"].0(`(````-HY`@`G````^SD"`"0````C.@(`(@``
M`$@Z`@`1````:SH"`!\```!].@(`&@```)TZ`@`8````N#H"``D```#1.@(`
M"P```-LZ`@`$````YSH"``0```#L.@(`!0```/$Z`@`*````]SH"`!$````"
M.P(`!@```!0[`@`*````&SL"``<````F.P(`!P```"X[`@`'````-CL"``8`
M```^.P(`"````$4[`@`6````3CL"``8```!E.P(`!@```&P[`@`%````<SL"
M``4```!Y.P(`"0```'\[`@`3````B3L"`!<```"=.P(`#@```+4[`@`/````
MQ#L"``(```#4.P(`"0```-<[`@`1````X3L"``8```#S.P(`)@```/H[`@`/
M````(3P"``\````Q/`(`$P```$$\`@`.````53P"``P```!D/`(`#@```'$\
M`@`N````@#P"`#````"O/`(`!@```.`\`@`(````YSP"`"8```#P/`(`$0``
M`!<]`@`1````*3T"``8````[/0(`"P```$(]`@`+````3CT"``4```!:/0(`
M!````&`]`@`/````93T"`!@```!U/0(`#````(X]`@`/````FST"`!4```"K
M/0(`$@```,$]`@`7````U#T"`!8```#L/0(`!P````,^`@`%````"SX"``H`
M```1/@(`&P```!P^`@`'````.#X"``0```!`/@(`"@```$4^`@`.````4#X"
M``8```!?/@(`$````&8^`@`(````=SX"``8```"`/@(`"P```(<^`@`-````
MDSX"``D```"A/@(`$````*L^`@`/````O#X"`!,```#,/@(`%````.`^`@`.
M````]3X"`!(````$/P(`"````!<_`@`(````(#\"`!$````I/P(`.````#L_
M`@`A````=#\"``@```"6/P(`#@```)\_`@`B````KC\"`!4```#1/P(`$P``
M`.<_`@`.````^S\"`'T````*0`(`#````(A``@`,````E4`"``D```"B0`(`
M#@```*Q``@`,````NT`"``T```#(0`(`#@```-9``@`.````Y4`"`"@```#T
M0`(`"@```!U!`@`%````*$$"``H````N00(`$P```#E!`@`-````34$"``P`
M``!;00(`"````&A!`@`'````<4$"``P```!Y00(`!@```(9!`@`'````C4$"
M`!,```"500(`20```*E!`@`2````\T$"``X````&0@(`"````!5"`@`%````
M'D("`!`````D0@(`#P```#5"`@`2````14("`!0```!80@(`"````&U"`@`*
M````=D("``(```"!0@(`!````(1"`@`G````B4("``,```"Q0@(`!0```+5"
M`@`*````NT("`!(```#&0@(`"@```-E"`@`&````Y$("``4```#K0@(`$```
M`/%"`@`/`````D,"`!H````20P(`"@```"U#`@`D````.$,"`!$```!=0P(`
M!@```&]#`@`(````=D,"``<```!_0P(`!````(=#`@`%````C$,"`&,```"2
M0P(`#P```/9#`@`2````!D0"``4````91`(`!0```!]$`@`F````)40"`"D`
M``!,1`(`"P```'9$`@`W````@D0"`"D```"Z1`(`'@```.1$`@`@`````T4"
M`#4````D10(`$0```%I%`@`*````;$4"`!4```!W10(`'````(U%`@`/````
MJD4"``L```"Z10(`"0```,9%`@`;````T$4"`"\```#L10(`)````!Q&`@`C
M````048"`!H```!E1@(`$@```(!&`@`B````DT8"`"H```"V1@(``P```.%&
M`@`'````Y48"``D```#M1@(`$````/=&`@`6````"$<"`!,````?1P(`$@``
M`#-'`@`;````1D<"`"@```!B1P(`!0```(M'`@`0````D4<"``T```"B1P(`
M#````+!'`@`)````O4<"`!4```#'1P(`#P```-U'`@`2````[4<"`!$`````
M2`(`$@```!)(`@`6````)4@"`%@````\2`(`$0```)5(`@`6````IT@"`!``
M``"^2`(`#0```,](`@`/````W4@"`!(```#M2`(`'P````!)`@`X````($D"
M`!H```!920(`#P```'1)`@`H````A$D"``P```"M20(`"P```+I)`@`7````
MQDD"`$@```#>20(`!@```"=*`@`.````+DH"``<````]2@(`"P```$5*`@`'
M````44H"``@```!92@(`)````&)*`@`C````ATH"``8```"K2@(`!0```+)*
M`@`?````N$H"`%4```#82@(`%````"Y+`@`@````0TL"``\```!D2P(``@``
M`'1+`@`-````=TL"``8```"%2P(`#P```(Q+`@`(````G$L"``P```"E2P(`
M!@```+)+`@`)````N4L"``8```##2P(`"0```,I+`@`-````U$L"``<```#B
M2P(`"````.I+`@`+````\TL"``8```#_2P(`#@````9,`@`0````%4P"``\`
M```F3`(`"````#9,`@`,````/TP"``T```!,3`(`#@```%I,`@`,````:4P"
M``P```!V3`(`#P```(-,`@`,````DTP"``@```"@3`(`'0```*E,`@`5````
MQTP"`!````#=3`(`"0```.Y,`@`*````^$P"`!4````#30(`!P```!E-`@`2
M````(4T"``<````T30(``P```#Q-`@`G````0$T"``<```!H30(`!0```'!-
M`@`/````=DT"``4```"&30(`"@```(Q-`@`1````ETT"`!0```"I30(`(P``
M`+Y-`@`8````XDT"`!\```#[30(`(````!M.`@`:````/$X"`!H```!73@(`
M%P```').`@`'````BDX"``8```"23@(`&````)E.`@`#````LDX"``\```"V
M3@(`#P```,9.`@`)````UDX"``P```#@3@(`!````.U.`@`?````\DX"``X`
M```23P(`#@```"%/`@`2````,$\"``8```!#3P(`$P```$I/`@`&````7D\"
M`!,```!E3P(`#P```'E/`@`2````B4\"``D```"<3P(`!0```*9/`@`(````
MK$\"``,```"U3P(`!````+E/`@`"````OD\"``H```#!3P(`#P```,Q/`@`*
M````W$\"``L```#G3P(`)````/-/`@`2````&%`"`!$````K4`(`)P```#U0
M`@`+````95`"`#\```!Q4`(`-@```+%0`@`;````Z%`"`"0````$40(`-```
M`"E1`@`/````7E$"`"X```!N40(`,P```)U1`@`X````T5$"`#@````*4@(`
M/0```$-2`@`/````@5("`!L```"14@(`(````*U2`@`7````SE("`"D```#F
M4@(`&@```!!3`@`E````*U,"`"D```!14P(`%0```'M3`@`8````D5,"`"(`
M``"J4P(`&0```,U3`@`O````YU,"`!,````75`(`&````"M4`@`?````1%0"
M`"L```!D5`(`*P```)!4`@`O````O%0"`"P```#L5`(`+0```!E5`@`J````
M1U4"`%X```!R50(`$P```-%5`@`M````Y54"`"L````35@(`+@```#]6`@`(
M````;E8"``P```!W5@(`.P```(16`@`3````P%8"``P```#45@(`(@```.%6
M`@`7````!%<"`"T````<5P(`)@```$I7`@`.````<5<"`$0```"`5P(`/@``
M`,57`@`-````!%@"``@````26`(`&0```!M8`@`7````-5@"``X```!-6`(`
M!P```%Q8`@`/````9%@"`!4```!T6`(`"````(I8`@`%````DU@"``<```"9
M6`(`#````*%8`@`*````KE@"``H```"Y6`(`"0```,18`@`'````SE@"`!@`
M``#66`(`&````.]8`@`2````"%D"`!<````;60(`#0```#-9`@`+````05D"
M`!T```!-60(`!P```&M9`@`?````<UD"``@```"360(`!P```)Q9`@`.````
MI%D"`!````"S60(`10```,19`@!+````"EH"``X```!66@(`-P```&5:`@`&
M````G5H"``,```"D6@(`!@```*A:`@`.````KUH"``<```"^6@(`!P```,9:
M`@`.````SEH"``<```#=6@(`#P```.5:`@`F````]5H"``0````<6P(`,0``
M`"%;`@`L````4UL"`!8```"`6P(`)````)=;`@`M````O%L"`%H```#J6P(`
M$@```$5<`@!&````6%P"``L```"?7`(`'@```*M<`@`2````REP"`!(```#=
M7`(`"````/!<`@`.````^5P"``T````(70(`#````!9=`@`2````(UT"``P`
M```V70(`'@```$-=`@`9````8ET"``4```!\70(`$0```()=`@`7````E%T"
M``X```"L70(`$````+M=`@`>````S%T"``,```#K70(`%````.]=`@`6````
M!%X"`!4````;7@(`#````#%>`@`U````/EX"``P```!T7@(`#@```(%>`@!!
M````D%X"``\```#27@(`&P```.)>`@`R````_EX"`#`````Q7P(`&P```&)?
M`@`5````?E\"`!X```"47P(`'P```+-?`@`@````TU\"`!X```#T7P(`*@``
M`!-@`@!3````/F`"`$T```"28`(`"````.!@`@`1````Z6`"`!(```#[8`(`
M$0````YA`@`3````(&$"``0````T80(`%P```#EA`@`.````46$"`"@```!@
M80(`'@```(EA`@`.````J&$"`!(```"W80(`!@```,IA`@`.````T6$"`",`
M``#@80(`)0````1B`@`(````*F("``4````S8@(`$P```#EB`@`&````36("
M`!(```!48@(`"````&=B`@`&````<&("``T```!W8@(`!0```(5B`@`/````
MBV("`!H```";8@(`!@```+9B`@`8````O6("`!,```#68@(`!0```.IB`@`0
M````\&("`"<````!8P(`$0```"EC`@`&````.V,"``<```!"8P(`&````$IC
M`@`'````8V,"`!,```!K8P(``P```']C`@`/````@V,"``8```"38P(`"```
M`)IC`@`<````HV,"`!\```#`8P(`!P```.!C`@`5````Z&,"`#````#^8P(`
M!@```"]D`@`2````-F0"`"D```!)9`(`*````'-D`@`H````G&0"`"<```#%
M9`(`!````.UD`@`-````\F0"``@`````90(`!P````EE`@`+````$64"``@`
M```=90(`!@```"9E`@`]````+64"`!T```!K90(`"0```(EE`@`8````DV4"
M`"H```"L90(`+0```-=E`@`=````!68"`"8````C9@(`(````$IF`@`B````
M:V8"`#X```".9@(`'````,UF`@`=````ZF8"`!@````(9P(`:0```"%G`@!L
M````BV<"`#$!``#X9P(`(0```"II`@`;````3&D"`"P```!H:0(`)0```)5I
M`@`P````NVD"`$X```#L:0(`+@```#MJ`@`L````:FH"`"(```"7:@(`+@``
M`+IJ`@`O````Z6H"`",````9:P(`!P```#UK`@`(````16L"``8```!.:P(`
M"P```%5K`@`0````86L"`!$```!R:P(`)P```(1K`@`0````K&L"`"H```"]
M:P(`)````.AK`@`@````#6P"`"P````N;`(`,@```%ML`@`'````CFP"`!H`
M``"6;`(`"0```+%L`@`)````NVP"`!P```#%;`(`$@```.)L`@`.````]6P"
M`!$````$;0(`!P```!9M`@`0````'FT"``H````O;0(`#0```#IM`@`6````
M2&T"``<```!?;0(`#0```&=M`@`(````=6T"`#4```!^;0(`-0```+1M`@`2
M````ZFT"``D```#];0(`"P````=N`@`8````$VX"`#(````L;@(`+P```%]N
M`@`)````CVX"`!(```"9;@(`$0```*QN`@`B````OFX"`!P```#A;@(`+P``
M`/YN`@`B````+F\"``4```!1;P(`"0```%=O`@`G````86\"`"(```");P(`
M&0```*QO`@`9````QF\"``8```#@;P(``P```.=O`@`*````ZV\"``D```#V
M;P(`#0````!P`@`1````#G`"``@````@<`(`&P```"EP`@`'````17`"`!$`
M``!-<`(`,@```%]P`@!+````DG`"``H```#><`(`"@```.EP`@`*````]'`"
M``H```#_<`(`"0````IQ`@`3````%'$"`!8````H<0(`&````#]Q`@`=````
M6'$"``8```!V<0(`(0```'UQ`@`2````GW$"`!8```"R<0(`!0```,EQ`@`1
M````SW$"``X```#A<0(`#0```/!Q`@`(````_G$"`"4````'<@(`&````"UR
M`@`4````1G("`!,```!;<@(`+````&]R`@`(````G'("``T```"E<@(`&0``
M`+-R`@`0````S7("`!0```#><@(`#````/-R`@`W`````',"`!4````X<P(`
M"````$YS`@`A````5W,"`!,```!Y<P(`%P```(US`@`1````I7,"`#,```"W
M<P(`-@```.MS`@`2````(G0"``L````U=`(`"````$%T`@`/````2G0"``T`
M``!:=`(`#@```&AT`@`1````=W0"`!(```")=`(`#@```)QT`@`@````JW0"
M`#L```#,=`(`+P````AU`@`+````.'4"``P```!$=0(`"0```%%U`@`4````
M6W4"`!8```!P=0(`'````(=U`@`N````I'4"`!P```#3=0(`'````/!U`@`D
M````#78"`!,````R=@(`"0```$9V`@`/````4'8"`!8```!@=@(`'@```'=V
M`@`)````EG8"``@```"@=@(`#0```*EV`@`5````MW8"`!$```#-=@(`3P``
M`-]V`@`'````+W<"`!H````W=P(`*@```%)W`@`&````?7<"``4```"$=P(`
M"P```(IW`@`/````EG<"`!(```"F=P(`!0```+EW`@`(````OW<"``T```#(
M=P(`"P```-9W`@`,````XG<"`!$```#O=P(`$0````%X`@`(````$W@"``0`
M```<>`(`,@```"%X`@`D````5'@"`"8```!Y>`(`!@```*!X`@`&````IW@"
M``8```"N>`(`!@```+5X`@`;````O'@"`!L```#8>`(`&@```/1X`@`/````
M#WD"`#D````?>0(`#P```%EY`@`1````:7D"`#H```![>0(`+````+9Y`@`A
M````XWD"`!T````%>@(`+P```"-Z`@`:````4WH"`",```!N>@(`+0```))Z
M`@!0````P'H"`%D````1>P(`30```&M[`@`;````N7L"``X```#5>P(`"@``
M`.1[`@`#````[WL"``8```#S>P(`"P```/I[`@`'````!GP"``(````.?`(`
M$````!%\`@`+````(GP"``H````N?`(`%````#E\`@`+````3GP"`!@```!:
M?`(`&@```'-\`@`2````CGP"``4```"A?`(`"@```*=\`@`4````LGP"`!T`
M``#'?`(`#P```.5\`@`&````]7P"``D```#\?`(`-P````9]`@`.````/GT"
M``\```!-?0(`#P```%U]`@`*````;7T"`!T```!X?0(`4@```)9]`@`Q````
MZ7T"`",````;?@(`%@```#]^`@`;````5GX"`#8```!R?@(`!P```*E^`@`$
M````L7X"``<```"V?@(`#@```+Y^`@`1````S7X"``8```#??@(`!@```.9^
M`@`1````[7X"`!$```#_?@(`#````!%_`@`,````'G\"`"0````K?P(`&```
M`%!_`@`1````:7\"`"<```![?P(`,P```*-_`@`*````UW\"`!\```#B?P(`
M,0````*``@`,````-(`"``T```!!@`(`$````$^``@!E````8(`"`!L```#&
M@`(`'````.*``@`M````_X`"`"$````M@0(`&P```$^!`@`>````:X$"`!T`
M``"*@0(`'````*B!`@`6````Q8$"`!(```#<@0(`)P```.^!`@`=````%X("
M`!`````U@@(`&````$:"`@`*````7X("``<```!J@@(`"````'*"`@`4````
M>X("`!4```"0@@(`"0```*:"`@`3````L(("`!$```#$@@(`"````-:"`@`A
M````WX("``D````!@P(`$P````N#`@`'````'X,"`$$````G@P(`.0```&F#
M`@`[````HX,"`$,```#?@P(`,P```".$`@!9````5X0"`"P```"QA`(`*```
M`-Z$`@`'````!X4"``\````/A0(`#P```!^%`@`I````+X4"``L```!9A0(`
M#P```&6%`@`E````=84"`'8```";A0(`,P```!*&`@!(````1H8"`#8```"/
MA@(`!P```,:&`@`0````SH8"`!D```#?A@(`$0```/F&`@`<````"X<"`!\`
M```HAP(`&@```$B'`@`2````8X<"`#H```!VAP(`2````+&'`@`L````^H<"
M`"<````GB`(`)@```$^(`@`7````=H@"`#````".B`(`)0```+^(`@`A````
MY8@"`!D````'B0(`&@```"&)`@`,````/(D"`"X```!)B0(`)P```'B)`@`O
M````H(D"`!8```#0B0(`)@```.>)`@`H````#HH"`"`````WB@(`!0```%B*
M`@`,````7HH"``L```!KB@(`"0```'>*`@`%````@8H"`"@```"'B@(`"0``
M`+"*`@`,````NHH"``<```#'B@(`!@```,^*`@`1````UHH"``D```#HB@(`
M"````/**`@`(````^XH"`!0````$BP(`"````!F+`@`)````(HL"``0````L
MBP(`#````#&+`@`,````/HL"`!(```!+BP(`%P```%Z+`@`5````=HL"`!``
M``",BP(`"````)V+`@`/````IHL"`!,```"VBP(`$@```,J+`@`6````W8L"
M`!\```#TBP(`$@```!2,`@`4````)XP"`!8````\C`(`$````%.,`@`.````
M9(P"``P```!SC`(`&P```(",`@`E````G(P"``T```#"C`(`'P```-",`@`C
M````\(P"``H````4C0(`!@```!^-`@`1````)HT"``<````XC0(`!````$"-
M`@`8````18T"`!0```!>C0(`#0```'.-`@`1````@8T"``D```"3C0(`'0``
M`)V-`@`W````NXT"``X```#SC0(`#P````*.`@`/````$HX"``4````BC@(`
M"````"B.`@`(````,8X"``T````ZC@(`!0```$B.`@`,````3HX"`!,```!;
MC@(`!@```&^.`@`3````=HX"``8```"*C@(`"0```)&.`@`/````FXX"`!$`
M``"KC@(`&@```+V.`@`9````V(X"``H```#RC@(``@```/V.`@`'`````(\"
M``8````(CP(`#@````^/`@`&````'H\"`!0````ECP(`"0```#J/`@`&````
M1(\"`#,```!+CP(`+P```'^/`@`2````KX\"``4```#"CP(`"````,B/`@`(
M````T8\"``P```#:CP(`#````.>/`@`&````](\"``P```#[CP(`$@````B0
M`@`.````&Y`"``P````JD`(`#0```#>0`@`)````19`"``<```!/D`(`!P``
M`%>0`@`'````7Y`"`!4```!GD`(`!0```'V0`@`'````@Y`"`"````"+D`(`
M(@```*R0`@`G````SY`"``4```#WD`(`'P```/V0`@`:````'9$"``<````X
MD0(`!P```$"1`@`,````2)$"``8```!5D0(`$````%R1`@`0````;9$"``8`
M``!^D0(`&0```(61`@`+````GY$"``D```"KD0(`!0```+61`@`(````NY$"
M``D```#$D0(`$P```,Z1`@`7````XI$"``L```#ZD0(`#0````:2`@`3````
M%)("`!H````HD@(`$P```$.2`@`N````5Y("``P```"&D@(`$@```).2`@`,
M````II("``(```"SD@(`$````+:2`@`&````QY("`!D```#.D@(`&````.B2
M`@`C`````9,"`"<````EDP(`$0```$V3`@`D````7Y,"`"H```"$DP(`)```
M`*^3`@`;````U),"`!L```#PDP(`7@````R4`@`9````:Y0"`!(```"%E`(`
M8@```)B4`@!5````^Y0"`"@```!1E0(`+P```'J5`@`J````JI4"`$<```#5
ME0(`3@```!V6`@!B````;)8"`!\```#/E@(`)````.^6`@`U````%)<"`"0`
M``!*EP(`+@```&^7`@`N````GI<"`"8```#-EP(`'0```/27`@`4````$I@"
M`'L````GF`(`.@```*.8`@`]````WI@"`#4````<F0(`)0```%*9`@`D````
M>)D"`"X```"=F0(`+````,R9`@`L````^9D"`,D!```FF@(`(@```/";`@!$
M````$YP"``\```!8G`(`10```&B<`@`J````KIP"`"\```#9G`(`&0````F=
M`@`;````(YT"`#,````_G0(`+@```'.=`@`<````HIT"`!L```"_G0(`+```
M`-N=`@![````")X"`#D```"$G@(`,0```+Z>`@!D````\)X"`%(```!5GP(`
M2````*B?`@`W````\9\"`#$````IH`(`+0```%N@`@`9````B:`"`!````"C
MH`(`D````+2@`@`>````1:$"`!X```!DH0(`(0```(.A`@`?````I:$"`"H`
M``#%H0(`'0```/"A`@`=````#J("`"X````LH@(`$@```%NB`@`G````;J("
M`!P```"6H@(`,0```+.B`@`<````Y:("`#$````"HP(`(````#2C`@`5````
M5:,"`$````!KHP(`*0```*RC`@!!````UJ,"`!T````8I`(`3````#:D`@`>
M````@Z0"`!T```"BI`(`/@```,"D`@!1````_Z0"`#<```!1I0(`1````(FE
M`@!`````SJ4"`$8````/I@(`;@```%:F`@!/````Q:8"`$P````5IP(`20``
M`&*G`@!/````K*<"`$````#\IP(`+0```#VH`@`Y````:Z@"`%$```"EJ`(`
M)````/>H`@`R````'*D"`"T```!/J0(`-````'VI`@`M````LJD"`$P```#@
MJ0(`6@```"VJ`@!4````B*H"`&$```#=J@(`.P```#^K`@`W````>ZL"`$L`
M``"SJP(`2@```/^K`@`P````2JP"`"4```![K`(`)@```*&L`@!*````R*P"
M`#4````3K0(`*P```$FM`@`6````=:T"`"````",K0(`*````*VM`@`H````
MUJT"`#<```#_K0(`:P```#>N`@!I````HZX"`+(````-KP(`%````,"O`@`E
M````U:\"`#$```#[KP(`+@```"VP`@!$````7+`"`"H```"AL`(`2````,RP
M`@`=````%;$"``D````SL0(`F````#VQ`@!'````UK$"`"@````>L@(`2```
M`$>R`@!!````D+("`%8```#2L@(`.@```"FS`@!!````9+,"`#````"FLP(`
M,P```->S`@`V````"[0"`"P```!"M`(`*0```&^T`@`.````F;0"`$0```"H
MM`(`'@```.VT`@`W````#+4"`"0```!$M0(`'P```&FU`@`>````B;4"`#D`
M``"HM0(`+````.*U`@`/````#[8"``8````?M@(`"0```":V`@`#````,+8"
M``T````TM@(`$@```$*V`@`+````5;8"``L```!AM@(`!@```&VV`@`2````
M=+8"``(```"'M@(`"0```(JV`@!=````E+8"`&@```#RM@(`!0```%NW`@`9
M````8;<"``0```![MP(`!P```("W`@`%````B+<"``4```".MP(`!@```)2W
M`@`4````F[<"`!@```"PMP(`!P```,FW`@`-````T;<"``T```#?MP(`$@``
M`.VW`@`0`````+@"``(````1N`(`"````!2X`@`'````';@"`!,````EN`(`
M#````#FX`@`5````1K@"``8```!<N`(`$````&.X`@`-````=+@"``,```""
MN`(`'@```(:X`@`$````I;@"``8```"JN`(`"````+&X`@`<````NK@"`$,`
M``#7N`(`,0```!NY`@`R````3;D"`!@```"`N0(`(P```)FY`@`9````O;D"
M`"$```#7N0(`(0```/FY`@`<````&[H"`"`````XN@(`)P```%FZ`@`B````
M@;H"`"D```"DN@(`)@```,ZZ`@`H````];H"`!T````>NP(`(0```#R[`@`F
M````7KL"`"$```"%NP(`)P```*>[`@`G````S[L"`"X```#WNP(`(0```":\
M`@`B````2+P"`"0```!KO`(`*0```)"\`@`?````NKP"`"@```#:O`(`(```
M``.]`@`O````)+T"`"````!4O0(`)````'6]`@`I````FKT"`"H```#$O0(`
M)````.^]`@`=````%+X"`"(````RO@(`)````%6^`@`E````>KX"`#L```"@
MO@(`*P```-R^`@`-````"+\"`!<````6OP(`"@```"Z_`@`)````.;\"`!$`
M``!#OP(`%````%6_`@`9````:K\"`"H```"$OP(`(0```*^_`@`,````T;\"
M`"$```#>OP(`#P````#``@`8````$,`"`!,````IP`(`#P```#W``@`K````
M3<`"``4```!YP`(`!@```'_``@`,````AL`"``\```"3P`(`$````*/``@`C
M````M,`"`"T```#8P`(`(@````;!`@`E````*<$"``X```!/P0(`"@```%[!
M`@#(````:<$"``@````RP@(`$P```#O"`@`3````3\("`!````!CP@(`"```
M`'3"`@`+````?<("`!T```")P@(`%P```*?"`@`3````O\("`"````#3P@(`
M$P```/3"`@`P````",,"`!0````YPP(`%@```$[#`@`'````9<,"`!0```!M
MPP(`&0```(+#`@`B````G,,"``L```"_PP(`-0```,O#`@`)`````<0"`"$`
M```+Q`(`&@```"W$`@`4````2,0"`!@```!=Q`(`/````';$`@`/````L\0"
M`!````##Q`(`$0```-3$`@`5````YL0"``H```#\Q`(`%`````?%`@`&````
M',4"`"<````CQ0(`"@```$O%`@`D````5L4"``D```![Q0(`$P```(7%`@`'
M````F<4"``P```"AQ0(`"0```*[%`@`U````N,4"``<```#NQ0(`#0```/;%
M`@`2````!,8"``X````7Q@(`"0```";&`@`+````,,8"``<````\Q@(`$P``
M`$3&`@`'````6,8"``H```!@Q@(`%@```&O&`@`C````@L8"`!P```"FQ@(`
M&@```,/&`@`/````WL8"``\```#NQ@(`'0```/[&`@`.````',<"`!\````K
MQP(`#P```$O'`@`6````6\<"`#$```!RQP(`$````*3'`@`-````M<<"`!<`
M``##QP(`%@```-O'`@`G````\L<"``X````:R`(`%0```"G(`@`*````/\@"
M``P```!*R`(`&P```%?(`@`'````<\@"`"P```![R`(`$````*C(`@`"````
MN<@"`!$```"\R`(`&P```,[(`@`+````ZL@"``4```#VR`(`#0```/S(`@`(
M````"LD"``H````3R0(`#P```![)`@`.````+LD"`!0````]R0(`%0```%+)
M`@`.````:,D"`"P```!WR0(`'````*3)`@`G````P<D"`%8```#IR0(`.@``
M`$#*`@`T````>\H"``L```"PR@(`1P```+S*`@`)````!,L"``8````.RP(`
M$P```!7+`@`V````*<L"``T```!@RP(`#````&[+`@`'````>\L"``0```"#
MRP(`!0```(C+`@`6````CLL"``8```"ERP(`!P```*S+`@`'````M,L"``0`
M``"\RP(`#P```,'+`@`0````T<L"``4```#BRP(`%P```.C+`@`@`````,P"
M`"`````AS`(`)0```$+,`@`.````:,P"``(```!WS`(`!````'K,`@`0````
M?\P"``4```"0S`(`!0```);,`@`"````G,P"``\```"?S`(`+P```*_,`@`?
M````W\P"`!<```#_S`(`$````!?-`@!(````*,T"`!0```!QS0(`&0```(;-
M`@`J````H,T"`$D```#+S0(`*0```!7.`@!*````/\X"`#,```"*S@(`+0``
M`+[.`@`8````[,X"`!<````%SP(`@P```!W/`@`0````H<\"`"@```"RSP(`
M*````-O/`@!K````!-`"`"$```!PT`(`,0```)+0`@`9````Q-`"`#D```#>
MT`(`)0```!C1`@`M````/M$"`$H```!LT0(`30```+?1`@`I````!=("`"T`
M```OT@(`'@```%W2`@`P````?-("`"H```"MT@(`&P```-C2`@`W````]-("
M`#@````LTP(`-P```&73`@`T````G=,"`#@```#2TP(`*0````O4`@`C````
M-=0"`"8```!9U`(`'P```(#4`@`N````H-0"`"\```#/U`(`'P```/_4`@`?
M````']4"`"X````_U0(`%````&[5`@`/````@]4"``P```"3U0(`;0```*#5
M`@`(````#M8"`!T````7U@(`$0```#76`@`/````1]8"`"(```!7U@(`#```
M`'K6`@!Y````A]8"`&H````!UP(`.````&S7`@`E````I=<"`!D```#+UP(`
M,@```.77`@`T````&-@"`!D```!-V`(`#P```&?8`@`K````=]@"`!P```"C
MV`(`)0```,#8`@`@````YM@"`%<````'V0(`&0```%_9`@`+````>=D"``L`
M``"%V0(`!0```)'9`@`'````E]D"``@```"?V0(`!0```*C9`@`9````KMD"
M``T```#(V0(`$P```-;9`@`<````ZMD"`"<````'V@(`$@```"_:`@`/````
M0MH"``0```!2V@(`"@```%?:`@`$````8MH"``,```!GV@(`"0```&O:`@`(
M````==H"`!````!^V@(`!0```(_:`@`(````E=H"``8```">V@(`"P```*7:
M`@`3````L=H"``8```#%V@(`"````,S:`@`'````U=H"`!<```#=V@(`%0``
M`/7:`@`)````"]L"``@````5VP(`"````![;`@`+````)]L"``H````SVP(`
M%0```#[;`@`)````5-L"``4```!>VP(`$0```&3;`@`+````=ML"`!0```""
MVP(`"````)?;`@`#````H-L"``L```"DVP(`"P```+#;`@`/````O-L"``H`
M``#,VP(`!P```-?;`@`(````W]L"``P```#HVP(`!0```/7;`@`'````^]L"
M``4````#W`(`#`````G<`@`'````%MP"``@````>W`(``@```"?<`@`4````
M*MP"``(````_W`(`"````$+<`@`(````2]P"``4```!4W`(`"````%K<`@`*
M````8]P"`#4```!NW`(``P```*3<`@`%````J-P"`!````"NW`(`$P```+_<
M`@`)````T]P"``,```#=W`(`"````.'<`@`&````ZMP"``8```#QW`(`#@``
M`/C<`@`4````!]T"`!`````<W0(`$````"W=`@`%````/MT"``X```!$W0(`
M(@```%/=`@`'````=MT"``H```!^W0(`$0```(G=`@`%````F]T"``(```"A
MW0(`"P```*3=`@`/````L-T"``\```#`W0(``0`````"``"2!0````````X#
M`````````````&L$``#*!@``:@@``%T$``"G!0``P0$``.,#``"0"```J`8`
M`!4&````````2`D``)X(```7!@```````'@!````````L@<``*H$``">!P``
MN`0```$&````````&`(``'\)````````1`$```T#```.````%@$``/`(```4
M````F0```/8$```-!0``7P`````````O````OP```#0)````````Z@8``)L&
M``!I"0```````"L%``"(`@``3P,``&P#``"_!0`````````````E`@``'`$`
M`-$)``#U`0``-0(``#H(````````(P,```````"7!P``Y0@``"L(```&`P``
M`````/<!``"@!@``>`@``#0%``!G"```/0(``/0!``#@"0``B0```/4#````
M````%`0``%H&``#A````*`$`````````````900`````````````,00`````
M````````L0D```````!B`P``"@<```$(``!E!@``[@@``/P!``"L!0``````
M``````"G!P``?0,``"\&``!W````+0(``&X(````````.P```&<%``"L"```
M````````````````9@(````````#`P``C`D``%T)````````I`$``-@#````
M````V00``/L'``!Q`@``/@(``'@)```W`P``$@D```,&````````````````
M``!=`@``=`,```````!0"```L@0``'X'``"_`@``C`,```````!_`0``````
M``(%```-!@```````!X```#4"0``+P4``$X!``">"0``AP,``-,!``!G!P``
M_`D``,H!`````````````%8```!;"```$`<`````````````7@@``(H```#(
M`0``A0(``(,'```:!```Q08``,$&```A!P``6@4```````!E"```'P$``!D(
M```+`0``G`8``(D"```L`````````'P$``#3!```5P@```````!#!@``T@$`
M`'H(````````8`0``/\#```A!@``+08``-4`````````\`$```````"S`0``
M`````$0$``"L!@``20@``)P```!A!P``Y`,``(@'````````&`0``*8&````
M````\`8```8'````````````````````````/P(````````8"````````(4!
M``"0!0``OP,``(P&``"6!@```````"D````;`P``C@D`````````````````
M`$(%``!_!P``9P8``+8&````````EP$``!@)``#H`0``_@D``&0&``#2!P``
M#`<``/<```#`````8P<``"\(````````:P,``.H```"+!P``1P(``&,&``#,
M````(0$``````````````````/,$```"!@``=`@``(('````````Y`4`````
M``"2!@``80```-L%````````P`<````````J!P``\@<``#$"``"A`0``=@0`
M`),!``"T`P``%0$``&\#```N````$0<```````!<"```<0,``!P(````````
M`````*L)````````B`@``)P)```7````S`8``%H#``#?!```"P`````````P
M!@``A@4```H"````````@`4``"X(``"%!@```````/<"``"``P``Q`4``.D#
M```````````````````&"0``9P(```````!D!`````````````#?!@``.`4`
M`-T"``!/`0``E@```*H```"F`@````````<`````````RP@``*<#``"V!P``
MM0(````````R!```*PD``!@!```$"```F`@``!8'```J"0``<@@```````#=
M!P``````````````````8`D``$4'````````7`8``/@%````````B@,``$`"
M```3!0```````((%``!H!0``=@8```````#5"````````,L'``#L"```1@(`
M`!$)``!]!````````.L)``"F`P``I00``)@#``#6`@``308``)D$``!;!@``
M@@```)H(```(!```W`,````!````````.04``($(``!J"0``_P````@!````
M````H@4``%8!````````M@4```````#M````````````````````VPD``)H%
M````````4`$``#$!```T`@``-P``````````````U@```'H'``"+`@``\0D`
M``<'``"D`@``K@````````#[!0``>P````(*``#.`P``````````````````
M`````)D%``#T`P``\@$``)@&``"I!P``G`0```````"]!@``&P0``"T$```7
M`@````````````"7!0``````````````````>@(``'L)``"\!@``````````
M``!S!P``)P,``(X"``"N!@```````'4)``!/"```N0<``(8````Z!0``?`,`
M`)0"``#C"```7P<``'\#``!%"0``]`(``#0(````````Q@D``*D$``"@"0``
MF0,``&@&````````C`<``&<````!!````````%\)``!2!0```````!H"``!!
M````\`(``*````#-!0``_PD``)P!``#Q`0``)@$``'<$``#I"````````-((
M`````````````&H"`````````0(```````!>"0```````$H)````````Z@,`
M``$)``#^`0``>@0``!($``""!````````*0)``#:!0```````*\(````````
MQ@0``+P#``!'!0``.P8``.0&``#7`0``\0```'T!``"H!0``LP8``+@!````
M````*P$``%0"```>!@``H08``.@'````````4@<````````Y`P``H0D``+((
M````````_@@``$4&````````A0@```````!,!```^0@``$$%``#^````X@4`
M`$(&`````````````$H#``!-`P``>0D```````#T"0``"P,``"`'``">````
MD@<``(\)```.!0``$`0``(,#`````````````/(&```0"0````````````"B
M"0``!@8````````@`P``%`,```````"6`P``#P$```````#$"0``.P,``"P)
M``"_!@``Y0D```````!^!```$00``#8"``!,"0``3P8``)X#````````50(`
M`+$$``!U!P```````%<!```/!P``>`````````![`@```````-0```"?`@``
MV04```,'`````````````!4$``!H"```8`$``!0&``!`!@```````*<&``!5
M"```<`$``&(%```G````KP$``$P%````````<0```"4```#!!```````````
M````````Q00``!H(``"C`0``800```@%``"S`@```````*D!````````U`$`
M`!T#```>!0``RP4``'L#```=!P``6`4``$0`````````#@8`````````````
M5`D``#H!``#>!````````*P'``!^`P``@````"8&``#)`````````%D)``#:
M`0``\0<````````I`P``,`4``#$#``"@`@``;`0``#D````1!0````````L'
M````````JP````````"Z````.0@``,$````H`@```````*,(``#S"```0`0`
M`.8#````````1`<```0"````````4P0``$8```#Z!0`````````````("0``
M=`(``(T```"J`@```````$(#``"W`@``$`$``'P%``"N!0``M`(``$H%``"=
M"0``O@@``&$!``")`P``40```/L&```X"0``Y0$``(4#```)`P```````*<`
M```?!@``T@0``',)``"T"````````+T#``#R!0``K0<``),"````````````
M`&L&``"%!P```````!D"```:`0```````/P#``!X!@```````/($````````
M2P4``'0'````````_`8```````#X`0``<`0``*T)``"9`@````````````"Y
M"````````,D#````````<@```!`"```<"0`````````````N`P``_P@``$P#
M```;!0```@0``-T)``".!P``=@@``+,#````````/@0``#,"``"U!0``````
M`/D$``#2`@``/0,``!D&````````J@,``*@$````````#`0``#P%``!9````
M.@8``%((```=!0``"P@``-L```"$!@```````)4%```&!`````````````!\
M!@``%0D```````":!```V0`````````N!0``.P@``)\#``#(````M@(``.@#
M``"?`````````*H(``!T!@``WP`````````7"0``1@$````````@`0``F`0`
M`-T(``"^!@``9P0``"\$``!``````````-4$``#U`@``=0@``+`'``!,!@``
M``````````#[`P````````````#L`0```````+(#``#Z!P```````)L(```?
M"0``_08``-<$````````]0<````````,"```*0@``*\%````````+P,`````
M``!&!0```````.("`````````````'D#``!X`P``)@D``+@%``#Z!```&@,`
M`#<&````````Y@4``+T)```A``````````````"T!0``!0<``!X'``!)`@``
M.`@``(@&``"V````RP(```````",`0``&@<``#P'```U````)08``&D%````
M````]@8``,@#````````````````````````!P8`````````````K`$``*(!
M```_!0``<`<``-0'````````(P0```````"M````H0````(#````````!@``
M`/0'````````"@8````````]`0``M08``"4'````````<P$``($"````````
M)`8``.4%``#]"```"P(``.H%`````````````%0(``""`@``Z@$``*,)``"W
M````3P4``!P$``"2"````````)@```#]!0```````!$!``#X!@``@`8`````
M``!$!0``!P@``*L#````````O`(``),$``"I`@```````.<%``!Q`0``````
M`"D$```T`P``R0$``%T#``#4`@``9`D``+("``#M`P``00(``$\'```;!P``
ME`@``'4$```E"`````H``!(&``#\`@``/0````````#0````9@4``"L$``"+
M!````````(0#````````Z`8``+P$``!2!```S`(```````"[`0``=P,`````
M`````````````#D&````````C0@``"`(``".````@P(``.8```"[!P``Z0<`
M`#8$``"]````>P8``#<%```#"0``]0D``!D```!?!@```````%D!```=`@``
MY@<``"X&````````!@4``/@)``"'!```HP<```````"@!P``:`<``#`)``![
M"```Z0$```````!'!````````/H#``#$`@``B0<```$*```7!P``@0$``)$#
M``!)"0``7@,``(8!````````_0,``"$)``#G`@``P@$``+H&````````<@(`
M`)4$````````3P0```````"[`````````'H&``!E!P``NP4```````#[`@``
M`````'D``````````````"@%``#H!```]P8``*X!``#``0``-P0``!H&```8
M````S@8```````!="```*0$``*@)``"H`@``L`,````````U!0``CP$``,@&
M``".`P``)@,``(H(``#I!```C08``)4!```*!`````````````#)"0``````
M````````````)P$```````!_"```-08````````Z!P``T@,``"@```#M"```
M`````%H)`````````````*P`````````RP$``+,'````````&`8``$<'``!T
M!```$`@```````#D````DPD`````````````X`(``"()````````*@,``-D)
M````````70$``/D)``!I!P``K`,``+D&``#<!```U`8``!X"````````,@,`
M`&()``"E`0``WP$``*,$``!P"0```````,\)`````````````.`'````````
M&P(``&$&````````0@@```\"``#:"0```````$`)```]!0``I@0``%$(``#V
M`0``ZP,``#,%````````/0D``.8$````````208``$H!``#;`@``I````%L%
M``!H````_P(``%`&```+"0``!0```%L'``#?!0````````````!L````9`<`
M```````\`@``;0,````````C````;@4`````````````80D``#````#L!@``
M.P$```````#7!@`````````````S!P``4P<``,P)``#5!0``(P(``)8"``#/
M`0```````"P"``!^````9@@``(<"``"_!```B````$@"``"5`@``&04``+P%
M```\`P``]P<``)$'```X`@````8``'\"``#)!0```````(\(````````J@4`
M`#$%``#>!0``\P$``!`#``!C"0``)P<```````#C!P``<0<``&`'``#U"```
M!`4``%`)````````*@4``#,#````````*04``(@%`````````````.L&```J
M`@``KP0```<%`````````````-D"```F`@``L0<``&T)``!E````H0(`````
M``#N`P``=P$``)0'``!F`0``>0<``'0)``````````````````"3!@``!@@`
M`+\'``"4"0``+`<``$L(````````3@(`````````````#P8``&("``!&"```
M`````&P"``#R"```$`4```````!<"0```````"D&``!6!P``0P4```````#F
M"0``@`$`````````````+`$``#,`````````[`<``.P```!Y`0```````/\!
M```6`P``C````(4$```_"0``/@D`````````````6P(``,0&```P"```````
M`,T````/"0```````$L!``!S"````````#<!``!_!0``G0@``.<'``#3`P``
M<@4``%@&```D`@``E@@``#H"`````````````(0%``"7`P``D`<```````#;
M!````````&L'``"%!0``-`0``"T%``#2!@`````````````7!0```````.T%
M````````N`(`````````````]@,``*('``````````````@(````````````
M`"T!```"````6`@``(0(```_!P``?`(``/X"```D`0``;0$``&D"````````
M"@```"$$``#'`0```````-@%``!`!0``6`0``(<(``!X!```-@<``+`````S
M!```/08``)T%``#Y````*@8``%,%```X!```-0D``$4(``"(`0``/@,``)0`
M``#Y`P```````-@'````````C0D``(8'``#4!````````(8&```)!@``PP(`
M`)T$``!K"0````````H!``#+````D@$```````!B!@``7`,``*0#``"A!P``
MT0```"T(````````O@$``!T)````````7P@``!$&``"Q`P``D0````````!]
M`@``W@,``.\)``"A!0``;@,``-H'```K`P``_0D``.T&``!K`@``;0```!0(
M``"3!P``#0<```````#.!P``'P(``"$#````````?`<``-X'``!%````Q0<`
M`#<'``"Q"```4P,``$H(``"D!0``#0$``#4#``!D`P``QP0````````>!```
MGP<``-H&``"R"0``I08```````"M!````````-$#```V````U`@``,4!```I
M!P``8@$``%$'````````3@8`````````````;@$``)D&``!Y!```^@$``#$)
M``#Y`0``J08``+X'``!S!````````-,(``!'"0``'@,``!$#``"P"0``K0,`
M`-P)`````````````&H````Q!P``BP,``'<)``"O!@``10(``"@&``#8"```
M`P4``-$"``````````````````!(!P``2P```$T%````````LPD``)4)``"Z
M`P``I04``````````````````(H%``#%````@@,``/,````Q````;`D``%(`
M````````(0(``$T"``!<`@``JP8``"H(``"3````K04``&P&````````>P0`
M`!P``````````````.,"``"!!P````````````"K"```1P,```````#-!@``
M@P8``(<)``!.!```0@$````````H!P``^P0``',#````````````````````
M`````````#P&``"+"```!PD``*<$```4!0``L0$``"`&``"K!```NPD``+0`
M````````V@,``+H$``"!!0``@@D``-<'```C"0``=0```/8)``"U"0``<@$`
M`)<"``"%"0```````+\(````````_`<``,`$``#;!P``FP`````````^`0``
M`````+@&``!:`0```````(`'``"8`0``)@4``$X```#Q`P``$`8``$T(````
M````7@8```````!#"```<@<```````#``P```````"4$```=!```:08`````
M````````T`4```('``!X!0``G@(``($&``!1`P``D`(```````")"```T0$`
M`!P"``!]"```3`(``%4!``!<!P```````&<!````````HP8```````#-`P``
M:@0``(P"``#.!```,@```````````````````/H`````````#0(``"($``";
M`P```````(@#``#Q!@``K08```D"``#6"0``7@4``/8'``#&!0``8P@``,`%
M``!H`0``2`8``/,)``#C!```ZP<``,,)``#Y!@````4``"$%```'`0``NP0`
M`(8#``"X"0``,`0``&X`````````CP4```````#^!@``LP4```````"<"```
M```````````/"```U0D```````!8`P``-@,``(\````?!P``T`@``,P!````
M````LP```,('``#0`0``<@,``!(#````````)04``&,```!-!```TP```/,&
M``"]`@``40(``,P(``!7`P```````%D$``!!`0``:00````````*"0``N```
M````````````.````/T!``#0!@``N`<```0!``#:!````@@``.0)``!1`0``
M`````#,!```)````#@$``%P!``"2"0``JP<``+D%``!F`P``7P4``!4#``!*
M!@```````,@'````````L`0````````N`@``P@4``&,!````````:@<``,D"
M``#""0``:P4``'T)```[!P``[`D``$4%``#9!@``S@$`````````````U@8`
M````````````Y0```+L"``#:``````````````#'"```V``````````/!```
ME@0``+X#``!5!0``]0```!D#``#F!@``(P<`````````````S`4``,((````
M````!`D``"`$```L!0``P`D``.(````Z`````````'D(``#&````WP,``.$&
M`````````````(P(``##"````````+@#``#N````"`,``)P'```P`P``````
M```````"`0``IP@``/T```!W!@``L04``%L#````````]@@``%X'```-````
M`````/L!``!(!`````````````#X````#`D``&\$``"?!@``#P`````````G
M!```@@8```````#\````.@D``)8%``#*"```A@@``"$(``"0`0``````````
M````````8P,```T$``"E`@``200```````"\"```P`@```````#A`@``+P<`
M`/`'````````1`D``",&`````````````'X(``"=!@``>@$```````!&!```
MZ08``&`#```F!````````,X(````````]04```````#@`P``B@(``$T'``#8
M!````````!T(``!I"```)`@``$@#``!F"0``U0<``,\'``#X"```BP$``+D"
M``"H`0``VP8``#H#``#H````XP4``.H)``"8"0```````*X)``"$`0``````
M`%<'``!5!```]@4``!D!``#@!```X@@``%$&```````````````````6`@``
M`````/$"``"E!P``2P8``,<#```)!0````````````#O!```;0<``)$%``!@
M!0``X0@`````````````.0D```````#(`@``Q@,``'H#```4`0```````"4)
M````````B04```T)``#W"```+`@```````"I"0``5@@```H(````````.@0`
M``0#``!3"0``'`,``)<&``!4`P``\@```-4"````````:0,``$`'```?````
MTPD```````#S`@``,@D``$`!``#B!@``3`@``!$(``"O`````````#X```#&
M`@``[P8```@"``!6!0``N@(``(\&``!@`@``30D```P!``!8"0``ZP````0&
M``"N`P``20```*L"``"#!```%@D```,!```R"```W````)\(````````````
M`-()```]"```HP(``'H)````````````````````````[0D``$$#```2"```
M80(``!8(``"D!P``508``)````!9!P```````!\%``";!```W00```````#_
M!@``X````%D"``````````<``,H)``!1!0```P0``,X)``"2!```[P$``$@!
M````````I0````````"5``````````````#H"```@0```.('```,`P``\`4`
M`#P```````````````````!#!````````*H!```_````5P0``,L&``!;"0``
MT08```````"'!0``;`4``-D#```(!P``OP$``&4)````````G@$``'T&```M
M!P``J`<``$<```"D"````````$T!``#0`@``8@```'`&````````````````
M``#$!P```````)X$```$!P````````````"]`0```````"0`````````M00`
M`+L&``````````````````#F"```S@(``,4"``#O!0``CP,``),%````````
M4P```%$$``"U````E@$``'H%``````````````````#O!P```@(``(,!````
M````Q@8```````!.`P```````-<"`````````````!(!``"N`@``E@D`````
M``````````````X'````````ZP4```````#%"`````D`````````````E@<`
M````````````6```````````````:`,``!L)``#)!`````````````"R!0``
MJP4``.D"``#6"```@`0``$0(``#'!P````````````#P!```I@<``#P!```\
M"0``ZP@```````#E!P``Z@0``!X!````````V`(``!L&`````````````*X(
M````````000``((!``#W!```D0D``.@"``!K`0``(`(``+$&``#=!0``````
M`&H!``!W"```4`<```4$````````5`4``````````````````)H!````````
M`````,<```"4`0``B@0``'($````````60,``.P$````````]P4``/<#```$
M`````````,$"``"B!````````%$)```C`0```````)$"`````````````*D%
M``#W"0``T`0``&,$````````VP$``)L'``!G`P``CP(``!X)``!]````"```
M`"P&```4!P``$@4```````"V`0``$@(``!<!``!>`@```````+@(````````
M`````-T&````````0P,```````"8!0``UPD``$,)````````=0,``,\(```Q
M"````````"X!``!:````?P0``,H%```1````W`$```\%``!<!0``M@@``(\$
M````````BPD``"<(```D"0``J0@``/X%``#X`P``DP,``*T!```8!0``XP$`
M``````!O`0``;P(``*<"```W`@``C`4``"4!```D`P``'@@``*(#``#["0``
M,P8``!,'``#M!P``4`4``$<!``"9"0``WP@```8!``!#!P````````````#*
M`@``OPD``,4)``#G`0``-````.<(```9!P``K@<``!P%```B"```G@8``$T`
M``#8`0``F`<``-X!````````5@(``)`)``"'!P``V0$``+`!``",!```M0<`
M`/0(````````_@<```````!U!0``N0,```````":````#`8``&$#``!S````
MLP0`````````````D@(``'4!``#I"0``5````-$(`````````0<``'$)``#N
M!0``]````-H"````````=````%H$``"$`@``8@0```````"O`P``UP4``"X'
M``#)!@```````+$"```B!P``R@<```````"#!0`````````````T`0``S`0`
M`%D(``#$`P```````)H"````````;08```````#0"0``10,```````"@!```
M&P@`````````````-P@``$@```"4!0``K`0``,H```"T!@``L@8```````#!
M"`````````````"W!P``'`<``%D%``"/!P``4@(``"X$``#6`P```0$````#
M``!\"```A0```+8$``!8`@``Q````.@%``#9!P``>P$``&$%``#<"```M@D`
M``P"``#Z!@```````&L(``"+!@``5`0````````6!0``@PD```````"T`0``
M2@0```````"."```+`0``-<```#=`P```````'D"``#J!P```````!\(``!0
M`@``S`,```````#K`@``TP(``,\%``"J"0``,@$``*\'``#Q"```1P@``/X#
M``"E"0``G`4```````````````````````#*!```\`D``&H#``!V`@``%@0`
M`&4%``"U`0``B@8```````!#`@```````+H)``!:!P``*P<``.0'````````
M\P4``,<)``!O!0```````'<'````````I@$```D!````````.P0``+D)````
M````%`(```````!E`P``````````````````,08``$,```"$!```(P@`````
M```5"```]08``*@(````````3PD``-8$``#+`P``?04``"8'``!F````Q@$`
M`$L'``!7`@```````,T$``#!`P``A`D``.T$``#_!```F@8`````````````
MHP``````````````*`0```4&````````NP,``(D!````````;P8``'`````%
M"````````.$!`````````````#('````````S0$```````##`0``MP@`````
M````````^@@``+H%``!0`P``=08```````#("````````!<$``#"!```>`(`
M````````````/@@```````"D!```Y@$````````%`@``2P0```````#\!```
MU@<````````3````EP@`````````````4P$`````````````W`(``(X&```)
M!```X`8``*\"````````O04`````````````K0@``-4&``#]`@``F0<``$@%
M``!!!P``X0D``&T(```)"```-@D``%\!``"-`@``"P0``)H#``#3!P``````
M`!4'````````4P@``+T'``"^````8@<``$0&``#'!0``&@``````````````
M`````$$&````````$PD``$\"``#P`P``BP```````````````````"<&````
M`````````+<)```.!````````#(%`````````````/P%``!$`P``VP,``"8(
M``#``@`````````````T!@``3``````````6````90$``'\`````````````
M````````````@00``)X%`````````````+0'````````^`(``.4$````````
M```````````M"0``2P,``(T#````````A`<```````"B"```E`,``.P"```.
M"```(P4``%@!```B!0``HP4``)L%````````(@```,,$``!I````[`4```()
M````````?0<``#L)``"A`P```````$4!````"```?P8``+4#``"*!P``F@<`
M`,<"``"G"0``6@(````````9!````````+4(```%`P``J@<```````!=!P``
MQ04``)`&```;````_0<````````I"0``:`D`````````````;P```#X&``!2
M!@````````````#7"```P`8``-X(``"F````R0<```````!E`@``'0``````
M``!>!```[`,``/(#``#0!P``?@(``&H%```2!P```````&H&```U!P``_@0`
M`"L&``"\!P``/`0``"<%``!V"0````````````"R````[P,``*8(````````
M_P4``-T!``#7`P``.P(``$($````````W`4``(8)````````PP````````!3
M`@``[@D```````!F!@``@0,``,$%````````D00``-X"````````+P$`````
M``#A`P``GP0``-T````H"```]`4``%T&````````3@@``%P$```5`@``````
M`.4#``#-"```=@4``"(#````````]`0``%8$``#"!@``%P@``,\#``!N"0``
MO00``&8'``#&"```R`D``,,#``#_!P``0`@``*D#``````````````````##
M!@``P0<`````````````=@<```````![!0``G0```#("``!Y!0```````"0$
M````````J@8``````````````````.H"``````````````````".!```"`8`
M`-\'``!5`P``!@(``)D!``!\````;@0``)\!``!.!0``\@(``"(&``!:"```
M/P0``.<```"<`@``W`<``*P)``#B`0```````.D`````````X@D``)4&``#@
M!0``+0,``#,(``#-!P```````#`!`````````````%L````#````=P4`````
M``#N!P``I`8``.0!```_!@``#@(``'X%``!P`@``9PD``%X!``"9"```K@0`
M`,\&````````0@<```````#Y`@``5P8``+,(````````G0<``(<`````````
MPP4`````````````50```(0```"F!0``5P4``)@"``#"```````````````]
M!```R@,`````````````L`(```````!."0```````&\(``!)!0```````)`$
M``#G`P``3@<``'`(```P`@``O@0``+L(``"A!```O`$``/,#````````````
M````````````S@```.$'``"G`0```````#X'```#`@``````````````````
MJ`,```````!P!0``8`8``%T%```)"0``@@@``-X)``!3!@``AP8````````Y
M`@``R0@``,L$```@"0```````$H"``#-`@```````.<$``#$!```D@,``$\`
M```/`P``4`0``````````````````)0$``#6`0``5`8``)T!``!S!0``?@8`
M`!4````H`P```````#T'``#Z`@``H@8`````````````^`0``*,#``#M`0``
M-0@``'`#``!L"```B0D``/,'````````WPD```````#U!```7````-4!``!D
M`0``2`@```,(``````````````$%```B`0``>`<``,4#``!,`0``C0<`````
M````````H`,`````````````X@,``*8)``!&"0```````$D'``".!0``?`D`
M`)$!```O"0``&`<`````````````*`D``(T!`````````````!,(``"#"```
MMP8``/L````^!0``00@``*T"``!@`````````$8'````````'P,``)L)``"5
M`P``6P0``&,"``"E`P```````-@&``"@!0```0,`````````````*@$``&@"
M``"3"```,@8``%0!````````6P$```````#?`@``#`4``%T```#1!```^P@`
M`"T```!D!0``%P,```````#;"```%@8```````#(!0``FP(``'$(``!'!@``
M`````.,&```_`0```````+P`````````?`$``(@)````````G0(```````#I
M!0```````!L!```X!P``[@(``&\'```F````!0$`````````````Q@<`````
M``#(!```I0@``%X```!V`P```````'L'``!$`@```````.<&````````B08`
M``````#Q!0`````````````?!```J0```'X)```V`0```````&D!````````
MXPD``)T#``#]!```^0<``(`(``!T`0``.0$````````V"```MP4``"0%``!R
M"0``<08``-X```"@`0``^04```````"Y`0``Q`$```4)``!V`0``^`<``)\%
M``!Y!@``K`(``(8"```I`@``Z@@`````````````(````+`%````````-@4`
M``````#$"```P0D``#\(``"Z!P````````````!7"0``)PD```````"2````
M`````$D#``!H!```SP0``&8$``!N!P``L0```+(!```D!P``.P4``/$$````
M`````````&0(``"P"`````0```````#3!@``@`(``"L"````````H@(`````
M``"*"0``!P0``-$%``#D"````````#\#``#4`P```````/8"``#2````QP8`
M``L&``"'`0````````````!&`P```````#@!``!+`@``[P@``"`%````````
M)P(``$$)``!L!P``P@,```L%```Y!P``U@4``#D$``!M!`````````````!@
M"```N0```!P&``!,!P```````!````"5"```Z`D``$,!```'`@``&@4``%\#
M````````C00``$("``"Y!```EPD``&T"````````,`<``+H!``#B!```5`<`
M````````````$P(``&0"````````+`,``%8&``!"`````````#<)``#0`P``
M$P$``'0%```'`P``L`8```````!A"``````````````8`P````````````#3
M!0``Y08``'8````%!0``MP$````````2````X00``!0)`````````````'H`
M``!5"0``'0$``-D(```3`P``S`<``+P)```5!0``$P0``+0$``!""0``;04`
M`(8$``#4!0``"0<````````*`P``:P```(D$``!2`P``G`,``,("````````
M[@8``%\"``!5!P``PP<`````````````&0D``,L)````````2@``````````
M````MP0``-(%```=!@``V`D``$8&```\"```5@D``'$%``#\"```8P4``+8#
M```V!@``\````$H'``!``P``#@D``.`(````````C@$``+<#``#-"0``````
M`*L!``````````````````#@`0``T0<```P```#D`@``.`,``'<"``#Z"0``
M<P(``-4#``"5!P``SP(``'$$````````E`8``&P!``"O"0``100``+X%``#<
M!@``,PD`````````````H0@``.8"```J````?@$``!,&``"?"0``;PD`````
M``"+!0``[@0```````":"0``5@,````````K````SP````````!+"0``[0(`
M`)<```#G"0``9````)L!````````$0(``!H)`````````````%@'``#D!```
M`````%(!``"Z"```W@8``.L!``"(!```(@(``*@```"-!0``D`,````````E
M`P``]`8```T(``!0````D0@```````"#````[P(```````"B````;@8`````
M``"*`0``M`D``+X"``#K!```20$```````"`"0``]@```.$%``"]"```````
M`%<````*!0``608`````````````<@8``"X)````````\@D``#4!``#C````
M``````0$```J!````````#4$``#N`0``H`@``-H(``"!"0``.`8`````````
M````7P0``.\`````````<P8``)$&``!B"```;@(``%()````````=0(`````
M``#.!0``-`<``)<$`````````````"\"``#E`@``O@D````@("`@("!4;SH@
M`"`@("!$871E.B``("`@($9R;VTZ(``@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@
M*'EE<W1E<F1A>2D`(%-U8FIE8W0Z(``@870@`"!I;B``(P`E+C)F34(@+R`E
M+C)F34(@("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!M97-S86=E<R!H879E
M(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@
M<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S86=E
M<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2X`)60@=&\@)60@;V8@)60@
M365S<V%G97,`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E
M<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@
M86QR96%D>2!E>&ES=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O
M;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&%T("5S("5S`"5S(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN
M9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S(&AA<R!A
M8V-E<'1E9"X`)7,@:&%S(&-A;F-E;&QE9"`E<RX`)7,@:&%S(&1E8VQI;F5D
M+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E<R!H
M87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S('-E
M;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S('1E;G1A=&EV
M96QY(&%C8V5P=&5D+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO
M="!F;W5N9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('1O("5S
M(&]F("5S`"5S('=I<VAE<R!T;R!A;6UE;F0@)7,N`"5S('=I<VAE<R!T;R!M
M86ME('EO=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE
M(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S($)O
M;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E
M<SH@)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!<'!L>2!T:&5S
M92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A<F0@
M86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN
M*0`H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN
M9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@
M8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"A396YD(&UE
M<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A
M<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E
M(&%P<&QI960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J`"H@4&QE
M87-E('-E;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN9R`E<R`E<P`L('9A
M<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@;65S<V%G92!H
M87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@
M;F]T('-P86TN`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M+@`Q,#`@8VAA<F%C=&5R<P`Q,#`P(&-H
M87)A8W1E<G,`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U
M<G,`,C4P(&-H87)A8W1E<G,`-3`P(&-H87)A8W1E<G,`02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R
M<F]R(&AA<R!O8V-U<G)E9`!!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T
M=&%C:&5D('1O('1H:7,@;65S<V%G92X`02!M97-S86=E('EO=2!H879E('-E
M;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M
M('1H92!R96-I<&EE;G0N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-(%-H;W=E<G,`04TO4$T`
M04Y$`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T
M;VT`06)S;6ED9&QE`$%C8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R
M;WIE;BX`06-C;W5N="=S(&YA;64Z`$%C8V]U;G1I;F<`06-T:6]N<P!!9&0`
M061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E
M.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@
M=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D
M('-O=7)C90!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`
M061D('1H:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`
M061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B(&%S
M(&%N(&%T=&%C:&UE;G0N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M:71I;VYA;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO
M;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E(&1E
M=&%I;',`061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E
M9"`E<RX`061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',`061D:71I
M;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`
M061D<F5S<P!!9&1R97-S($)O;VL`061D<F5S<R!";V]K<P!!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A
M=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L
M:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;"!M
M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O
M=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE.@!!;&P@;65S<V%G97,@:6X@
M>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P
M97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N`$%L
M;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O
M;&0@=VEL;"!B92!D96QE=&5D+@!!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@
M87!P;&EE9"!I;B!A;GD@;6%I;&)O>#\`06QL;W<@;75L=&EP;&4@861D<F5S
M<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A
M9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E
M;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E
M>'0Z`$%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ`$%L=V%Y
M<P!!;'=A>7,@<V%V92!A='1A8VAM96YT<P!!;65R:6-A;B!386UO80!!;B!E
M<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T
M=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B!S86ED.B``06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@
M=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+@!!;F1O<G)A`$%N9V]L80!!
M;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N<W=E<F5D`$%N<W=E
M<F5D(&UE<W-A9V5S`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!
M<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E
M861Y+@!!<'!L>2!&:6QT97)S`$%P<&QY($9I;'1E<G,@=&\@)7,`07!P;'D@
M9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\`07!P;'D@9FEL=&5R(')U
M;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\`07!P;'D@=&\@0VAI
M;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I
M`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\`07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES
M($Y/5"!R96-O;6UE;F1E9"$I`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D
M;R!T:&ES/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@4$5234%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T
M86-H;65N=#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@
M9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T
M<F%S:"!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE
M;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/P!!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S
M<&%M/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!
M<G)I=F%L(%1I;64`07)T`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I;VX@27-L
M86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:P!!<VL@9F]R
M(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&%C:`!!='1A8V@@1FEL97,`
M071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@
M;65S<V%G93\`071T86-H960@1FEL93H`071T86-H960@9FEL92`B)7,B(&5X
M8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T
M=&%C:&5D+@!!='1A8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q
M=65S="!Y;W4@<V5N="X`071T86-H;65N=`!!='1A8VAM96YT('-T<FEP<&5D
M.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4`071T86-H;65N=',`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1E;G1I;VX`
M071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C
M:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT
M:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+@!!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A434P@;65S
M<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY(&%D9')E<W-B;V]K/P!!
M=F%I;&%B;&4@061D<F5S<R!B;V]K<SH`079A:6QA8FQE(&9I96QD<SH`07=A
M:71I;F<@4F5S<&]N<V4`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C7VL@
M=&\@)7,`0F%C:R!T;R`E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N
M`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&]S`$)A<V5L:6YE`$)C8P!"96QA<G5S`$)E;&=I=6T`0F5L
M:7IE`$)E;&]W(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R
M;6%T:6]N(&UE<W-A9V4N`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y
M`$)L86-K;&ES=`!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T
M(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)L;V-K(&EM86=E
M<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L
M;'D@<F5Q=65S=&5D/P!";V1Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R
M9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z
M96=O=FEN80!";W1H`$)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@
M365S<V%G90!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-?:&%R<V5T`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M
M97)O;VX`0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V
M97(N`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R
M.B``0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T
M<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@;6%I;&)O>"X`0V%N
M(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@365S<V%G90!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M
M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RX`0V%N;F]T(&1E;&5T92!F
M:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R
M+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E
M+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O
M9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H
M(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N
M9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V,`0V5L;"!0:&]N90!#96QL(%!R
M;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S
M<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@06QL`$-H
M86YG92!&;VQD97(`0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO
M=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@
M;65S<V%G97,@87)E('-O<G1E9"X`0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F
M;VQD97(@<V5T=&EN9W,N`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@96UA:6QS+@!#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N
M871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L
M>2!T;R!Y;W5R(&5M86EL+@!#:&%R`$-H87)A8W1E<G,@=&\@9&ES<&QA>3H`
M0VAE8U]K($QI;FLN+BX`0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!#
M:&5C:R!?06QL+TYO;F4`0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N
M="!T;R!F971C:"!M86EL(&9R;VTZ`$-H96-K('-P96QL:6YG(&)E9F]R92!S
M96YD:6YG(&$@;65S<V%G93\`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF
M:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S
M92!!8W1I;VXZ`$-H;V]S92!A(&UA:6P@<V5R=F5R.@!#:&]O<V4@82!P87-S
M=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@86-T:6]N.@!#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y
M<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=&AE(&%D9')E<W,@8F]O
M:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+@!#:&]O<V4@=&AE(&]R
M9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD:6YG
M(&%D9')E<W-E<RX`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#
M;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`
M0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R
M;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RX`0VQI8VL@)7,@=&\@9&]W;FQO
M860@=&AE(&EM86=E+@!#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M96YT
M('!A9V4N`$-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W(&$@=&AU;6)N86EL(&]F
M('1H:7,@:6UA9V4N`$-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<N`$-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@
M26UA9V5S`$-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@
M8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H+@!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:R!T;R!3879E(%!'4"!0=6)L:6,@2V5Y
M(&EN('EO=7(@061D<F5S<R!B;V]K`$-L:6-K('1O(%-A=F4@4R]-24U%(&-E
M<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K`$-L:6-K871E
M;&P@=FEA($A45%``0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP
M;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<@!#;&EC:VEN9R!O;B!T
M:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9`!#
M;&]S90!#;&]S92!7:6YD;W<`0VQO<V4@=&AI<R!W:6YD;W<`0VQO<V5D($9O
M;&1E<@!#;&]U9',`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O
M;&QA<'-E`$-O;&QA<'-E($%L;`!#;VQL87!S92!!;&P@1F]L9&5R<P!#;VQL
M87!S92!&;VQD97(`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R
M<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!);F1I8V%T;W(Z(`!#;VQO<B!0:6-K
M97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC
M<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#
M;VUO<F]S`$-O;7!A;GD`0V]M<&QE=&5D`$-O;7!O<V4@86YO=&AE<B!M97-S
M86=E`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_`$-O
M;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI
M9B!B<F]W<V5R('-U<'!O<G1S('1H92!F96%T=7)E*3\`0V]M<'5T97)S`$-O
M;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@
M)7,`0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+@!#;VYF
M:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N`$-O;F9I<FT@4&%S<W=O<F0`
M0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#
M;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;FYE
M8W1I;VX@=&\@<V5R=F5R(&9A:6QE9`!#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&EN=64`0V]N
M=')O;"!01U`@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@4R]-24U%('-U<'!O
M<G0@9F]R("5S+@!#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C:&5C
M:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@=VAE
M;B!I="!A<G)I=F5S+@!#;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN=&\@
M9W)A<&AI8V%L(&]N97,_`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y
M('-E;&5C=&EO;@!#;W!Y('1O(&9O;&1E<@!#;W)R96-T`$-O<G)E8W1E9"!4
M97AT`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K
M(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!M97-S86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S
M`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+@!#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I
M;VYS+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O
M;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!#;W5L9"!N;W0@97AT<F%C="!T
M:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N`$-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E
M=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N
M;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N
M(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#
M;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V
M92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U
M<G-E<P!#<F5A=&4`0W)E871E($9O;&1E<@!#<F5A=&4@2V5Y<P!#<F5A=&4@
M5FER='5A;"!&;VQD97(`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@9')A
M9G1S(&9O;&1E<@!#<F5A=&4@82!N97<@;VYE`$-R96%T92!A(&YE=R!S96YT
M(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(`0W)E871E
M(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA
M:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"!A;F0@9&5L971E('-P86TN`$-R
M96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C
M87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@
M55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&%C8V5S<R!T;R`E<P!#
M=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE(&%C
M8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N
M`$-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"X`0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#
M>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC
M`$1$`$1A:6QY`$1A=%]E`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E
M8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT
M`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT('-O<G1I
M;F<@8W)I=&5R:6$Z`$1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ`$1E9FEN
M:71I;VYS`$1E;&5G871E9`!$96QE=&4`1&5L971E("5S(%!U8FQI8R!+97D`
M1&5L971E($-U<G)E;G0@2V5Y<P!$96QE=&4@1F]L9&5R*',I`$1E;&5T92!'
M<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@5FER='5A;"!&;VQD97(`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/P!$96QE
M=&4@9G)O;2!M>2!C86QE;F1A<@!$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM
M96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/P!$96QE=&4@<F]W
M`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9`!$96QE=&5D
M(&UE<W-A9V5S`$1E;&5T960@=&AE(&%T=&%C:&UE;G0@(B5S(BX`1&5L971I
M;F<@86YD($UO=FEN9R!-97-S86=E<P!$96QI=F5R>2!T:6UE`$1E;FUA<FL`
M1&5N>2!R97%U97-T`$1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N`$1E<V-E;F1I;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I
M<'1I;VX`1&5T86EL<P!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL
M92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA
M<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I;2!S:6=N871U<F5S/P!$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E
M8W1O<GD`1&ES<&QA>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@
M3W!T:6]N<P!$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@
M;65S<V%G93\`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA
M=`!$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G90!$:7-P;&%Y('!O<"UU<"!N
M;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_`$1I<W!O<VET:6]N`$1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!.3U0@;6%T8V@`1&\@3F]T
M($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`1&\@;F]T(&1E;&5T90!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;R!N;W0@
M9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6X`1&\@>6]U('=A
M;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\`1&]E<R!T:&4@9FER<W0@<F]W(&-O
M;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X
M.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N90!$;W=N;&]A9`!$
M;W=N;&]A9"`E<P!$;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA=`!$;W=N;&]A
M9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92D`1&]W;FQO860@1F]L
M9&5R*',I`$1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1O
M=VYL;V%D(&EN("YZ:7`@1F]R;6%T`$1R869T`$1R869T(&9O;&1E<@!$<F%F
M=',@9F]L9&5R.@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`12UM86EL
M($%D9')E<W,`15)2`$524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E
M(&1E;&EV97)E9"X`16-U861O<@!%9&ET`$5D:70@0FQA8VML:7-T`$5D:70@
M0FQO8VL`161I="!&:6QT97)S`$5D:70@1W)O=7``161I="!097)M:7-S:6]N
M`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I
M="!6:7)T=6%L($9O;&1E<@!%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I
M;VX@9F]R("5S`$5D:70@5VAI=&5L:7-T`$5D:70@;W!T:6]N<R!F;W(Z`$5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@>6]U<B!B;&%C:VQI<W0`161I
M="!Y;W5R(&9I;'1E<B!R=6QE<P!%9&ET('EO=7(@<')E9F5R96YC97,@9F]R
M(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+@!%9&ET('EO=7(@=VAI
M=&5L:7-T`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T
M:65D(&%L;"!M97-S86=E<R!F<F]M("5S+@!%;7!T>2!&;VQD97(H<RD`16UP
M='D@5')A<V@@9F]L9&5R`$5M<'1Y(%]4<F%S:`!%;7!T>2!M97-S86=E+@!%
M;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@4$=0(&9U
M;F-T:6]N86QI='D_`$5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\`16YA
M8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@
M:6X@=&5X=#\`16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_`$5N86)L92!R:6=H
M="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N8W)?>7!T:6]N($]P=&EO;G,`16YD
M`$5N9"!F;W)W87)D960@;65S<V%G90!%;F0@;65S<V%G90!%;F0@;65S<V%G
M92!F<F]M("5S`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(%!A<W-P
M:')A<V4`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL
M;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D
M+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R
M('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M<V5N="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M=')A<V@@9F]L9&5R`$5N=')Y("(E<R(@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!T:&4@861D<F5S<R!B;V]K`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R
M96$`17)R;W(`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('=I=&@@
M96UA:6P@;65S<V%G92X`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E
M`$5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+@!%=F5R>2`Q-2!M:6YU=&5S
M`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN
M=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E
M`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@06QL`$5X
M<&%N9"!!;&P@1F]L9&5R<P!%>'!A;F0@1F]L9&5R`$5X<&%N9"!.86UE<P!%
M>'!A;F0@4VED96)A<@!%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN
M9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_`$5X<&%N9"!T
M:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E
M<G,@=FEE=S\`17AP86YD:6YG`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E
M('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%
M>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`
M1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B
M)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A
M:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H
M36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y`$9E96QS($QI
M:V4`1F5E;',@;&EK93H@`$9E=&-H($UA:6P`1F5T8V@@36%I;"!I;B!A('-E
M<&%R871E('=I;F1O=S\`1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N
M/P!&971C:&UA:6PZ(`!&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RX`1F5W
M(%-H;W=E<G,`1FE?;'1E<G,`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I
M;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M
M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"X`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%-E='1I;F=S`$9I
M;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\`1FEL=&5R('-U
M<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`$9I;'1E<G,`1FEL
M=&5R<R!.3U0@06-T:79E`$9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G90!&
M:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!-86EL8F]X(%!A9V4`1FER
M<W0@4&%G90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O
M7W)W87)D`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]L9&5R($YA
M=FEG871O<@!&;VQD97(@4W5M;6%R>0!&;VQD97(@<VAA<FEN9R!I<R!N;W0@
M96YA8FQE9"X`1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"X`1F]N="!#;VQO
M<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@
M<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[
M(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B
M;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUA="!O9B!M97-S86=E
M(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D
M('1O9&%Y`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O
M<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D(&UE
M<W-A9V4`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&;W)W87)D<P!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R964O0G5S>2!)
M;F9O<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`
M1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&<F5N
M8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]?
M;0!&<F]M`$9R;VT@061D<F5S<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO
M;@!&=6QL($UO;VX`1G5L;"!.86UE`$9W9#H`1G=D.B``1G=D.B`E=2!&;W)W
M87)D960@365S<V%G97,`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@3W!T:6]N<P!'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N
M>0!'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI`$=H86YA`$=I
M8G)A;'1A<@!':79E;B!.86UE`$=O('1O($UE<W-A9V4`1V]E9&5L`$=O;V=L
M92!396%R8V@`1W)A;G0@86-C97-S`$=R87ES8V%L90!'<F5E8V4`1W)E96L@
M*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T
M<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'
M=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI
M<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`
M2$5210!(5$U,`$A434P@5F5R<VEO;B!O9B!-97-S86=E`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W
M+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`
M2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S
M:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z`$AE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E
M<F4@8V]M<&]S:6YG.@!(:61D96X`2&ED9&5N(&EN(%1H<F5A9"!6:65W`$AI
M9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E9`!(:6=H`$AI9V@@4')I;W)I
M='D`2&EG:&5S=`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S
M86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@
M;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L
M(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!D;R!Y;W4@=V%N
M="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/P!(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R
M97!L>0!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-
M05``24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*0!)34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<P!)34%0(&]V97(@4U-,`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E
M<G1I9FEC871E*0!)34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"D`24U!4"P@
M;F\@5$Q3`$E-05`O4$]0,R!-86EL(%-E<G9E<G,`24Y"3U@`25`@061D<F5S
M<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO
M;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N
M<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U
M<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K
M('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B
M<F]W<V5R+@!)9VYO<F4`26=N;W)E($%L;`!);6%G92!0<F5V:65W.@!);6%G
M92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O
M;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R=`!);7!O<G0@
M2V5Y`$EM<&]R="!+97EP86ER`$EM<&]R="!01U`@2V5Y`$EM<&]R="!097)S
M;VYA;"!0<FEV871E(%!'4"!+97D`26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!0
M1U`@2V5Y`$EM<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S`$EM
M<&]R="!0=6)L:6,@2V5Y`$EM<&]R="!0=6)L:6,@4$=0($ME>0!);7!O<G0@
M4'5B;&EC(%,O34E-12!+97D`26UP;W)T(%,O34E-12!+97D`26UP;W)T(&UB
M;W@@1FEL90!);7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+@!)
M;7!O<G0L(%-T97`@)60`26UP;W)T86YT`$EM<&]R=&%N="!M97-S86=E<P!)
M;7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+@!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F
M=&5R`$EN8F]X`$EN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D
M97(@:6X@82!R97!L>3\`26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@
M<F5P;'D_`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!)
M;F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S
M:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@
M2V5Y`$EN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y`$EN9F]R
M;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97D`26YL:6YE`$EN<V5R="!#
M7V]L=6UN($%F=&5R`$EN<V5R="!#97)T:69I8V%T92!(97)E`$EN<V5R="!)
M;6%G90!);G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4`26YS
M97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4`26YS97)T(%!U8FQI
M8R!01U`@2V5Y($AE<F4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!)
M;G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R
M="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE
M<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P
M:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!)
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK
M`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E
M<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O
M;F5N="X`26YV86QI9"!!9&1R97-S`$EN=F%L:60@4F5M;W1E($UA:6QB;W@`
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!C:&%R86-T97(@
M:6X@92UM86EL(&%D9')E<W,Z("5S+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D
M+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F
M;W)M870`26YV86QI9"!K97D`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O
M<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&5R<V]N
M86P@4$=0('!R:79A=&4@:V5Y+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L
M:6,@:V5Y+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED('-H87)E(&]B:F5C
M=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T
M82X`26YV96YT;W)Y`$EN=F5R=`!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)
M<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P
M86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`
M2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T
M:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+0@!+87IA:VAS=&%N`$ME97`@;W)I
M9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG
M97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$ME>2!S=6-C
M97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+
M:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+
M>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@36%I;&)O>"!086=E`$QA
M<W0@4&%G90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`
M3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`
M3&E?;FL@071T86-H;65N=',`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER
M:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI
M9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO
M=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@
M4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN
M:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@
M9&ES<&QA>6EN9P!,:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BX`
M3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B
M;&5S`$QI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C
M=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL(&]N;'D@<V5E(&-O
M;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2D`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!I;B!T
M:&4@2&5A9&5R`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U
M<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@36%I;&)O>#H`3&]C86P@
M=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&EN
M('1O("5S`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,
M;W<`3&]W(%!R:6]R:71Y`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T
M:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QO=V5S=`!,=7AE;6)O
M=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V
M(%)E<'5B;&EC(&]F`$UA8VEN=&]S:"!&:6QE`$UA9&%G87-C87(`36%G:6,`
M36%I;`!-86EL($%D;6EN`$UA:6P@4')E=FEE=W,`36%I;"!S97)V97(@='EP
M92!T;R!C;VYN96-T('1O.@!-86EL8F]X`$UA:6QB;W@@86YD($9O;&1E<B!$
M:7-P;&%Y($]P=&EO;G,`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`
M36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O
M<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S
M(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``
M36%P475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-87)K($%L;"!-97-S86=E<R!I
M;B!&;VQD97(@87,@4V5E;@!-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@
M87,@56YS965N`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q
M=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`36%R:R!M97-S86=E<R!A
M<R!S965N/R`H24U!4"!O;FQY*0!-87)K('-I;7!L92!M87)K=7`_`$UA<FL@
M=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA
M<G1I;FEQ=64`36%T8V@@06QL(%%U97)I97,`36%T8V@@06YY(%%U97)Y`$UA
M=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E
M9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X
M:6UU;2!!='1A8VAM96YT(%-I>F4`36%X:6UU;2!L96YG=&@`36%X:6UU;2!N
M=6UB97(@;V8@871T86-H;65N=',@<F5A8VAE9"X`36%X:6UU;2!T;W1A;"!A
M='1A8VAM96YT('-I>F4@<F5A8VAE9"X`36%Y`$UA>6]T=&4`365D:6-I;F4`
M365E=&EN9R!#86YC96QL871I;VX`365E=&EN9R!);F9O<FUA=&EO;@!-965T
M:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P;'D`365E=&EN9R!5<&1A=&4`365E
M=&EN9R!5<&1A=&4@4F5Q=65S=`!-96UB97)S`$UE;G4@1F]L9&5R($QI<W0`
M365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@0V]M<&]S
M:71I;VX`365S<V%G92!$871E`$UE<W-A9V4@3W!T:6]N<P!-97-S86=E(%-E
M87)C:`!-97-S86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!697)I
M9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T
M92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@5FEE=VEN9P!-97-S
M86=E(&5X<&ER960N`$UE<W-A9V4@9FQA9W,`365S<V%G92!F;VQD97)S`$UE
M<W-A9V4@9G)O;2`E<P!-97-S86=E(&UA=&-H97,`365S<V%G92!R961I<F5C
M=&5D('-U8V-E<W-F=6QL>2X`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@
M8G5T(&YO="!S879E9"!T;R`E<P!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY
M+@!-97-S86=E('1Y<&4`365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB
M;W@@=FEE=RX`365S<V%G97,@=&\`365T87(@5V5A=&AE<@!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!-971H;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL
M86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES
M<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N
M;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I
M;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@
M36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E
M<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>0!-;V1I9GD@55),`$UO9'5L=7,`
M36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N
M9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O
M`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@
M9&]W;@!-;W9E('1O(&9O;&1E<@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I<&%R="]A;'1E<FYA=&EV90!-
M=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R
M=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.3U1%`$YA
M;64`3F%M92!A;F0O;W(@96UA:6P@8V%N(&YO="!B92!E;7!T>0!.86UI8FEA
M`$YA=7)U`$YE961S($%C=&EO;@!.97!A;`!.971H97)L86YD<P!.971H97)L
M86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2
M979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E
M(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E
M(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.979E
M<B!S879E(&%T=&%C:&UE;G1S`$YE=P!.97<@0V%L961O;FEA`$YE=R!#871E
M9V]R>0!.97<@1F]L9&5R`$YE=R!-86EL`$YE=R!-;V]N`$YE=R!5<V5R;F%M
M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!M97-S86=E<P!.97<@=VEN
M9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@365S<V%G
M90!.97AT(%!A9V4`3F5X="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`$YI9VAT`$YI=64`3F\`3F\@0V5R=&EF:6-A=&4@9F]U;F0`3F\@16YC
M<GEP=&EO;@!.;R!+97ES(&EN($ME>7)I;F<`3F\@365S<V%G97,`3F\@4$=0
M('!U8FQI8R!K97D@:6UP;W)T960N`$YO(%!E<G-O;F%L($-E<G1I9FEC871E
M(%!R97-E;G0`3F\@4'5B;&EC($ME>7,@1F]U;F0`3F\@4R]-24U%('!U8FQI
M8R!K97D@:6UP;W)T960N`$YO(&%T=&%C:&UE;G1S(&9O=6YD+@!.;R!A=F%I
M;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@
M9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA
M9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H
M92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E
M9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL
M9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I
M;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&9O;&1E<B!S
M96QE8W1E9"X`3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W
M(&UA:6PN`$YO(&9O;&1E<G,@=V5R92!S<&5C:69I960`3F\@9F]L9&5R<R!W
M:71H(&YE=R!M97-S86=E<P!.;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A
M9V5S`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&UE
M<W-A9V4@8F]D>2!T97AT`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&UE<W-A
M9V5S(&UA=&-H960@>6]U<B!S96%R8V@N`$YO(&YA;64@<W!E8VEF:65D+@!.
M;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W
M:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!P97)S
M;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N`$YO('!E<G-O;F%L(%!'
M4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!3+TU)344@8V5R
M=&EF:6-A=&5S(&EM<&]R=&5D+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!S<&5L
M;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"X`3F\@<W!E;&QI;F<@97)R
M;W)S`$YO('-U9V=E<W1I;VYS`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A
M:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<B!S<&5C:69I960N`$YO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R
M971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO;B!087)T:6-I<&%N=`!.;VYE`$YO;F4@
M*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)
M<VQA;F0`3F]R;6%L`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@
M1&5L971E9`!.;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`
M3F]T(&$@9&ER96-T;W)Y`$YO="!A('9A;&ED('!U8FQI8R!K97DN`$YO="!D
M96QE=&5D(&UE<W-A9V5S`$YO="!I;7!L96UE;G1E9"X`3F]T(&EM<&]R=&%N
M="!M97-S86=E<P!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&4@=&AA="!T
M:&ES(&-A;B!T86ME('-O;64@=&EM90!.;W1E<P!.;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T
M97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!M;VYT:',@=&\@:V5E
M<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN
M`$YU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D
M96QE=&EN9R!M;VYT:&QY+@!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S
M<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/
M2P!/4@!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E
M;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&UE<W-A9V5S`$]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!B96EN9R!P=7)G960N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@
M<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!D:7-P;&%Y(&9O;&1E<G,@
M=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\`3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY
M(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO
M;BX`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U
M;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`
M3W!E;F5D($9O;&1E<@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N
M<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R
M9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A
M=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R
M`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C;W5N=',`3W1H97(@
M3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4$=0`%!'4"!$:6=I=&%L(%-I9VYA='5R90!0
M1U`@16YC<GEP="!-97-S86=E`%!'4"!%;F-R>7!T960@1&%T80!01U`@17)R
M;W(Z(`!01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@
M<')I=F%T92!K97DN`%!'4"!/<'1I;VYS`%!'4"!087-S<&AR87-E($EN<'5T
M`%!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN`%!'4"!0=6)L:6,@2V5Y`%!'4"!0=6)L:6,@
M2V5Y(%1E>'0`4$=0(%!U8FQI8R!+97D@9F]R("(E<R`H)7,I(B!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D+@!01U`@4'5B;&EC($ME>2!F;W(@(B5S(B!W87,@
M<W5C8V5S<V9U;&QY(&1E;&5T960N`%!'4"!0=6)L:6,@2V5Y<FEN9P!01U`@
M4VEG;B!-97-S86=E`%!'4"!3:6=N+T5N8W)Y<'0@365S<V%G90!01U`@4VEG
M;F5D+T5N8W)Y<'1E9"!$871A`%!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L
M;'D@861D960N`%!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"X`
M4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`%!'4"!S
M=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L
M('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@=F5R:69I960N`%!'4"!S=7!P
M;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!M97-S86=E(&ES
M('5N86)L92!T;R!B92!D96-R>7!T960N`%!(4"!#;V1E`%!(4"!3:&5L;`!0
M32!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@5"U3=&]R;7,`4$]0,P!03U`S
M("A!=71O($1E=&5C="!0<F]T;V-O;',I`%!/4#,@;W9E<B!34TP`4$]0,R!O
M=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I`%!/4#,@;W9E<B!3
M4TP@*'-E;&8M<VEG;F5D*0!03U`S+"!N;R!43%,`4%](4"!3:&5L;`!0861D
M:6YG`%!A9V4@)60@;V8@)60`4&%G92!W:71H('1H92!&:7)S="!5;G-E96X@
M365S<V%G90!086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4`4&%K
M:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!0
M86YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T*',I`%!A<G1L
M>2!#;&]U9'D`4&%S<W!H<F%S90!087-S<&AR87-E("A!9V%I;BD`4&%S<W!H
M<F%S92!S=6-C97-S9G5L;'D@=6YL;V%D960N`%!A<W-P:')A<V4Z`%!A<W-P
M:')A<V5S(&-A;B!N;W0@8F4@96UP='D`4&%S<W!H<F%S97,@9&\@;F]T(&UA
M=&-H`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U
M:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@
M;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0
M96YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VX`4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C86X@;F]T(&)E(&-H
M86YG960N`%!E<G-O;F%L`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G-O;F%L
M(%!'4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!E<G-O;F%L
M(%!'4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)S;VYA;"!3+TU)
M344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@`%!E<G-O;F%L(%,O34E-
M12!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+@!097)U`%!E=',`4&AI;&EP
M<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%C92!Y;W5R
M('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_`%!L86EN
M=&5X="!697)S:6]N(&]F($UE<W-A9V4`4&QA=&ET=61E<P!0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E
M<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R
M('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S
M+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R
M(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T
M:6UE+@!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z
M`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!E;G1E<B!T:&4@
M<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL
M(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@
M)7,@<V5S<VEO;BX`4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y
M;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O
M(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0
M;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M
M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R!C;V]K:65S($%.1"!Y;W4@
M87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@
M=VEL;"!H879E('1O(&QO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W
M(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2!H:6IA
M8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I
M;F-O;G9E;FEE;F-E+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64N`%!L96%S92!R97-O;'9E(&%M8FEG=6]U
M<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`4&QE87-E(')E=FEE=R!T:&4@9F]L
M;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N
M(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@82!F;VQD97(@
M8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS+@!0;&5A<V4@<V5L96-T
M(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T
M(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+@!0;&5A<V4@<V5L96-T
M(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN`%!L96%S92!S
M96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#H`4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`
M4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*0!0;W=E<F5D(&)Y($AO<F1E`%!R96-E9&4@
M>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\`4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9F5R96YC97,@<W5C8V5S
M<V9U;&QY('5P9&%T960N`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S($UE<W-A9V4`4')E=FEO
M=7,@4&%G90!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT`%!R:6YT(&1O8W5M96YT
M`%!R:6]R:71Y`%!R:79A=&4@2V5Y`%!R:79A=&4@2V5Y(%!A<W-W;W)D`%!R
M;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@979E
M<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\`
M4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A
M=6QT('1O(%E%4P!0<F]M<'0@=&5X=`!0<F]T;V-O;#H`4'5B;&EC($ME>0!0
M=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P
M;W)T(&AA<R!B965N(&1I<V%B;&5D+@!0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)?
M9V4@1&5L971E9`!0=7)G92!$96QE=&5D`%!U<F=E($9O;&1E<BAS*0!0=7)G
M92!4<F%S:"!H;W<@;V9T96XZ`%!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O
M;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N`%!U<F=E(&]L
M9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/P!1871A<@!1=65R>0!1
M=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`475O=&$@
M<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5`!1=6]T82!S=&%T=7,Z($Y/($Q)
M34E4`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A;F1O;2!&
M;W)T=6YE`%)A=&EO`%)E7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;@!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E8V5I=F5D($]N`%)E8V5I=F5D(%-I;F-E`%)E8V5I=F5D(%5N=&EL
M`%)E9&ER96-?=`!2961I<F5C=`!2961I<F5C="!-97-S86=E`%)E9&ER96-T
M('1H:7,@;65S<V%G90!2961I<F5C=&EN9R!F86EL960N`%)E9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE
M;65N=',Z`%)E9G)E<V@@1F]L9&5R(%9I97=S.@!2969R97-H(%!O<G1A;"!6
M:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5L;V%D
M(%9I97<`4F5M87)K<P!296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+@!296UE;6)E<B!T:&4@;&%S="!V:65W`%)E;6]T92!-86EL8F]X.@!2
M96UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@1FEE;&0@
M1G)O;2!396%R8V@`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!2
M96UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('-O=7)C90!296UO=F4@=&AE
M`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S
M97(`4F5M;W9E('5S97(Z("5S`%)E;F%M92!&;VQD97(H<RD`4F5N86UE('-E
M;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/P!296YA;6EN
M9R`B)7,B('1O("(E<R(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%)E<&Q?>2!T;R!,:7-T`%)E<&QA8V4@=VET:#H`4F5P;'D`4F5P
M;'D@4V5N="X`4F5P;'D@=&\@06QL`%)E<&QY('1O($%L;#H`4F5P;'D@=&\@
M3&ES=`!297!L>2!T;R!,:7-T.@!297!L>2!T;R!?06QL`%)E<&QY('=I=&@@
M3F]T(%-U<'!O<G1E9"!-97-S86=E`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O
M<B!N97AT(#(@;6]N=&AS+@!297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U
M<WD@:6YF;W)M871I;VXN`%)E<&QY+51O`%)E<&QY+51O.B``4F5P;'DZ`%)E
M<&]R="!A<R!);FYO8V5N=`!297!O<G0@87,@4W!A;0!297%U97-T(&$@7U)E
M860@4F5C96EP=`!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T(&1E;&EV97)Y(&-O;F9I<FUA=&EO
M;C\`4F5Q=65S="!R96%D(')E8V5I<'1S/P!297%U97-T960@;65S<V%G92!N
M;W0@9F]U;F0N`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A
M<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S<&]N9&5N="!3=&%T=7,@
M57!D871E9"X`4F5S=6QT<P!297-U;64`4F5S=6UE('EO=7(@<V5S<VEO;@!2
M971U<FX@=&\@1F5T8V@@36%I;`!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@
M=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG
M+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\`4F5U;FEO;@!2979E<G0@0V]N9FEG
M=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H
M=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN
M+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@
M4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L
M97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA
M;B!&961E<F%T:6]N`%)W86YD80!3+TU)344`4R]-24U%($-R>7!T;V=R87!H
M:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T($UE<W-A9V4`4R]-24U%($5N
M8W)Y<'1E9"!-97-S86=E`%,O34E-12!%<G)O<CH@`%,O34E-12!%<G)O<CH@
M3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4R]-
M24U%($]P=&EO;G,`4R]-24U%(%!A<W-P:')A<V4@26YP=70`4R]-24U%(%!E
M<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BX`4R]-24U%(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U
M8V-E<W-F=6QL>2!D96QE=&5D+@!3+TU)344@4'5B;&EC($ME>2!S=6-C97-S
M9G5L;'D@861D960N`%,O34E-12!0=6)L:6,@2V5Y<FEN9P!3+TU)344@4'5B
M;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N`%,O34E-
M12!3:6=N($UE<W-A9V4`4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E`%,O
M34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!3+TU)
M344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE
M<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`4R]-24U%('-U<'!O
M<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG
M;F5D(&UE<W-A9V4@8V%N(&YO="!B92!D:7-P;&%Y960N`%,O34E-12!S=7!P
M;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I
M<R!U;F%B;&4@=&\@8F4@=F5R:69I960N`%-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(
M`%-50T-%4U,`4U]13"!3:&5L;`!37W5B:F5C=`!380!385]V92!A(&-O<'D@
M:6X@`%-A7W9E(&%S`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V
M:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L
M9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T
M96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@)7,`4V%V
M92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E
M<C\`4V%V92!$<F%F=`!3879E($]P=&EO;G,`4V%V92!?1')A9G0`4V%V92!A
M<P!3879E(&1R869T<R!A<R!U;G-E96X_`%-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4V%V92!R96-I<&EE;G1S(&%U=&]M871I8V%L
M;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K/P!3879E('-E87)C:"!A
M<R!A('9I<G1U86P@9F]L9&5R/P!3879E('-E;G0@;6%I;#\`4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BX`4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S`%-C:65N8V4`4V5A<F-H`%-E
M87)C:"`E<P!396%R8V@@16YG:6YE<P!396%R8V@@4F5S=6QT<P!3965N`%-E
M;&5C=`!396QE8W0@06YO=&AE<B!!8V-O=6YT`%-E;&5C="!&:6QE<P!396QE
M8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A(&=R;W5P('1O(&%D
M9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A
M('5S97(@=&\@861D`%-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@
M861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RX`4V5L96-T(&%L
M;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%L;"!F:65L
M9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RX`4V5L96-T
M(&%N(&%C8V]U;G0`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE
M8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L
M;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP90!396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;&5C=&5D($%D9')E<W,@8F]O:W,Z`%-E;F0@2V5Y('1O(%!U8FQI8R!+97ES
M97)V97(`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N9"!-97-S86=E`%-E
M;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!3
M96YT(&UA:6P@9F]L9&5R`%-E;G0@;6%I;"!F;VQD97(Z`%-E<'1E;6)E<@!3
M97)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(`4V5R
M=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VX`4V5R=F5R.@!397-S:6]N($E$
M(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!P
M<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD
M(&1E;&5T92!M97-S86=E<RX`4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W
M:&5N(&-O;7!O<VEN9R!M97-S86=E<S\`4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@
M;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P
M=&EO;G,N`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y
M8VAE;&QE<P!3:&%R92!&;VQD97)S`%-H87)E(&UA:6P@9F]L9&5R<P!3:&%R
M92!Y;W5R(&UA:6P@9F]L9&5R<R!W:71H(&]T:&5R('5S97)S+@!3:&]P<&EN
M9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D
M(&9O<B!M;W-T(&QI;FMS/P!3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E
M9"!T97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@
M8F4@=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N`%-H;W5L
M9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@
M9F]R(%!'4"!D871A/P!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L
M;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=6QD('EO=7(@4$=0('!U
M8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D
M969A=6QT/P!3:&]W`%-H;W<@06QL($9O;&1E<G,`4VAO=R!!;&P@2&5A9&5R
M<P!3:&]W($1E;&5T960`4VAO=R!,:6UI=&5D($AE861E<G,`4VAO=R!-86EL
M:6YG($QI<W0@26YF;W)M871I;VX`4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L
M9&5R<P!3:&]W(%5N<W5B<V-R:6)E9`!3:&]W(&%N(&EC;VX@=&\@86QL;W<@
M<W1R:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_`%-H;W<@
M9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N
M97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN
M('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&QE9V5N9"!I;B!T:&4@;6%I
M;&)O>"!V:65W/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@
M<&EC:V5R`%-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY
M/P!3:&]W('!R979I97=S(&EN('1O;VQT:7!S/P!3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M`%-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO
M=R!T:&4@26UA9V5S`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&9I;'1E
M<B!I8V]N(&]N('1H92!M96YU8F%R/P!3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9P!3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD
M97(_`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S
M($QA=&4`4VAO=VX`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:5]Z90!3:65R<F$@
M3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3
M:6=N960`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI
M80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W
M(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN
M('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M
M<P!3;W)T(&)Y($%R<FEV86P`4V]R="!B>2!$871E`%-O<G0@8GD@1G)O;2!!
M9&1R97-S`%-O<G0@8GD@365S<V%G92!3:7IE`%-O<G0@8GD@4W5B:F5C=`!3
M;W)T(&)Y(%1H<F5A9`!3;W)T(&)Y(%1O($%D9')E<W,`4V]R="!O<F1E<B!S
M96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E
M(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT
M(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N
M9"!P861D:6YG`%-P86EN`%-P86T`4W!A;2!F;VQD97(Z`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P96-I86P@0VAA<F%C=&5R<P!3<&5L;"!#:&5C:P!3
M<&5L;"!#:&5C:V5R`%-P96QL(&-H96-K(&-O;7!L971E`%-P96QL:6YG(&5R
M<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N`%-P;&ET(&-E
M;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R="!Y96%R`%-T871E(&]R(%!R
M;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3
M=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP($%T=&%C:&UE;G0`4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1R:7`@;&EN96)R96%K<S\`
M4W1Y;&4@6T-34UT`4W4`4W5B7VIE8W0`4W5B:F5C=`!3=6)J96-T($9I96QD
M`%-U8FUI=`!3=6)S8W)I8F4@=&\@1F]L9&5R*',I`%-U8G-C<FEP=`!3=6-C
M97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U
M9V=E<W1I;VYS`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR
M:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``
M4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D
M(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET8V@@0V]M<&]S
M:71I;VX@365T:&]D`%-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N`%-W:71C
M:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N`%-W:71Z97)L86YD`%-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`
M5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F`%1A<F=E=#H`5&%S:W,`5&5?>'0`5&5L97!H;VYE($YU;6)E<@!496UP
M(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E
M;7!L871E($%D;6EN:7-T<F%T:6]N`%1E;G1A=&EV96QY($%C8V5P="!R97%U
M97-T`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E<FUS(&]F(%-E<G9I8V4@9FEL
M92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP`%1E>'0@3VYL>0!497AT(&%L
M:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@
M>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I
M<R!N;W0@879A:6QA8FQE+@!4:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M97-S
M86=E('-H;W5L9"!B92!L:6YK960Z`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A
M=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86-I;G1O
M<V@@<F5S;W5R8V4@9F]R:P!4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@
M8V%N(&)E(&1O=VYL;V%D960@)7,N`%1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W
M(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A8V-O=6YT("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+@!4:&4@871T86-H;65N="!W87,@;F]T(&9O=6YD+@!4:&4@
M8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@
M;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@
M8FQO8VL@<&]P=7`@=VEN9&]W<S\`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@8V]N=&5N=',@;V8@
M=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RX`5&AE(&-U<G)E;G0@9F]L
M9&5R*',I("(E<R(@=VEL;"!B92!R96YA;65D('1O("(E<R(N`%1H92!C=7)R
M96YT(&QI<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@
M8V]U;&0@;F]T(&)E(')E=')I979E9`!4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"X`5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92`B)7,B(&9O
M;&1E<BX`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R
M(&-A;&5N9&%R+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF
M+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&1E<B`B)7,B
M(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!C;VYT86EN<R!I;&QE
M9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S92!P<F]B
M;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4
M:&4@9F]L9&5R("(E<R(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S
M=6)S8W)I8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S(&1E;&5T960@
M8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="X`5&AE(&9O
M;&1E<B`B)7,B('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C
M<F5A=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE
M=&5D+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D
M('1O("(E<R(N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F;VQL;W=I;F<@9FEL
M97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z`%1H92!F=6QL('-C<F5E
M;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N
M970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E
M;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E
M(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N
M9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@
M:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E
M="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@
M3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E
M9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R
M(&ES('!R97-E;G0@:6X@>6]U<B!A9&1R97-S8F]O:RX`5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@
M;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M
M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S
M86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@
M:6YF;W)M871I;VYA;"!M97-S86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A
M=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93H`5&AE(&UA:6QB;W@@)7,@:7,@
M86QR96%D>2!E;7!T>2X`5&AE(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@*"5D
M(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@;&EM:70N`%1H92!M97-S86=E
M(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RX`5&AE
M(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"X`5&AE(&UE<W-A9V4@:&%S(&)E
M96X@=F5R:69I960N`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!3
M96YD97(Z("5S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@
M9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<&%S<W!H
M<F%S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E
M('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\`5&AE
M('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R87<@=&5X="!O9B!T
M:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E<RX`5&AE(')E<75E
M<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C
M:&UE;G0N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T
M:&4@6FEP(&%T=&%C:&UE;G0N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5N9&5R(&]F('1H
M:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VX@9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H
M:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE(&YO=&EF
M:6-A=&EO;B!M97-S86=E+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG
M;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"X`5&AE('-I9VYA='5R92!W
M87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+@!4:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@9FEL92!D
M;V5S(&YO="!E>&ES="X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI
M<W0N`%1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N
M`%1H92!T97AT(&]F('1H92!M97-S86=E`%1H92!T97AT(&]F('1H92!M97-S
M86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT(&]F('1H92!R971U<FYE
M9"!M97-S86=E`%1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(&-A
M;B!B92!V:65W960@)7,N`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4`
M5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92!C86X@8F4@=FEE=V5D("5S
M+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@
M;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A
M=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C
M97-S9G5L;'D@<W1O<F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!N;R!M97-S
M86=E<R!I;B!T:&ES(&UA:6QB;W@N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN
M('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B
M;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9`!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@
M5&AE('-E<G9E<B!S86ED.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N
M9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9`!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA
M>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P
M87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG
M(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S
M86=E<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G
M97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A
M;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O;2`B)7,B('1O("(E<R(N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N`%1H97)E('=A<R!A
M;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S+@!4
M:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES($A4
M34P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+@!4:&ES($A4
M34P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D
M(&EM86=E<R!A<'!E87(@;&EK92!T:&ES.B``5&AI<R!)34%0('-E<G9E<B!D
M;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!01U`@4'5B
M;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N`%1H:7,@86-T
M:6]N(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@
M:6UP;&5M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT
M='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI
M<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!C;VYT:6YU93\`5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@36%C:6YT;W-H
M(&9I;&4N`%1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H
M870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-24U%+@!4:&ES
M(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N
M(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@
M;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M871I;VXL(&)U="!T:&4@9F]R
M;6%T(&]F('1H:7,@;65S<V%G92!I<R!U;FMN;W=N+@!4:&ES(&UE<W-A9V4@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M
M97-S86=E+B!%<G)O<CH@`%1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D:6YG('1O
M(%)&0R`R,#$U*2X`5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R;6%T+@!4:&ES(&UE<W-A9V4@
M:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+@!4:&ES(&UE<W-A
M9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-24U%+@!4:&ES
M(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N`%1H:7,@
M;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N`%1H:7,@;65S
M<V%G92!T;P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T
M97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E
M('=I;F1O=RX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/
M<'1I;VYS('=I;F1O=P!4:')E860@5FEE=P!4:'5N9&5R`%1I8VME=',`5&EM
M90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I
M;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@061D<F5S
M<P!4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE(&-L:6-K:6YG+@!4
M;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4
M;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W
M`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1O=&%L($%T=&%C:&UE;G1S
M(%-I>F4Z`%1R86YS;&%T:6]N<P!4<F%S:"!F;VQD97(`5')A<V@@9F]L9&5R
M.@!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I
M80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U
M<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC
M93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI
M=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE
M('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O
M(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA
M8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N
M(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@
M9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$`56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA;G-W97)E9`!5;F%N<W=E
M<F5D(&UE<W-A9V5S`%5N9&5L971E`%5N9&5R;&EN90!5;F1I<V-L;W-E9"!2
M96-I<&EE;G1S`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I
M;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF
M:6QE9`!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S`%5N:6-O9&4@
M*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5
M;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@1&%T90!5;FMN;W=N($UE971I
M;F<`56YK;F]W;B!296-I<&EE;G0`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT`%5N;&]A9"!087-S<&AR87-E`%5N;F%M960`56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+@!5;G-E96X`56YS970@8V]L;W(`56YS=6)S8W)I
M8F4@9G)O;2!&;VQD97(H<RD`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T
M90!5<&1A=&4@)7,`57!D871E($%T=&%C:&UE;G0@26YF;W)M871I;VX`57!D
M871E(')E<W!O;F1E;G0@<W1A='5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@
M<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R
M<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S
M`%5S92!$969A=6QT(%9A;'5E`%5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I
M;VYS/P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS
M`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5
M<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A
M;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!6
M97)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A
M;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA
M;65S92`H5DE30TE)*0!6:65W`%9I97<@)7,`5FEE=R`E<R!0=6)L:6,@2V5Y
M`%9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I97<@
M4&5R<V]N86P@4')I=F%T92!+97D`5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y
M`%9I97<@5&AR96%D`%9I97<@5&AU;6)N86EL`%9I97<@86X@97AT97)N86P@
M=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A
M<F%T92!W:6YD;W<`5FEE=R!E=F5N=`!6:65W(&UE<W-A9V5S(&EN("5S`%9I
M97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.@!6:65W('1A
M<VL`5FEE=R!T:&4@26UA9V5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I
M<F=I;B!)<VQA;F1S+"!5+E,N`%9I<G1U86P@1F]L9&5R("(E<R(@8W)E871E
M9"!S=6-C97-F=6QL>2X`5FER='5A;"!&;VQD97)S`%9I<G1U86P@9F]L9&5R
M(&QA8F5L`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY
M('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!
M3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E
M8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H96X@
M9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O
M;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@=&AE;2!A<R!D96QE=&5D/P!7:&5N
M(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N
M="!T;R!S=&%R="!O;C\`5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@
M=V4@<V%V92!A='1A8VAM96YT(&1A=&$_`%=H:6-H('!H87-E<P!7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H
M:71E;&ES=`!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7
M:6MI`%=I;F0`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES
M9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`6"U2968`6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA
M:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R
M92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C
M;W5N="AS*3H`66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD
M97(N`%EO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O(`!9;W4@87)E
M(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BX`66]U(&%R92!I;B!415A4
M($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O
M(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!A<F4@
M<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&%G
M<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U
M('=E<F4@;F]T(&%L;&]W960@=&\@;&]G:6XN`%EO=2!D:60@;F]T(&5N=&5R
M(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I
M96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD
M:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@
M=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<@!9;W4@9F]R=V%R9&5D
M('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE
M;G1S.B`E<RX`66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+@!9;W4@:&%V92`Q
M(&YE=R!M97-S86=E+@!9;W4@:&%V92!A="!L96%S="!O;F4@871T86-H;65N
M="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@=7!L;V%D('EE="X@07)E('EO
M=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI<R!M97-S86=E('=I=&AO=70@
M=&AE<V4@871T86-H;65N=',_`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z`%EO
M=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SH`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I
M=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME
M;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B
M86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT
M97(@870@;&5A<W0@;VYE(')E8VEP:65N="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T(&5N=&5R
M('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V
M:65W('1H:7,@;65S<V%G90!9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S
M92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE
M<W-A9V4`66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N
M`%EO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N`%EO
M=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+@!9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A
M="!L96%S="!O;F4@;65S<V%G92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A
M(')E8VEP:65N="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L
M96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92X`66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@9FEL92!T;R!A='1A
M8V@N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(')E9&ER96-T960@=&AI<R!M
M97-S86=E('1O("5S(&]N("4E<RX`66]U(')E<&QI960@=&\@=&AI<R!M97-S
M86=E(&]N("5S+@!9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(
M97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U
M8G-C<FEB960@9G)O;2`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%EO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`
M66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO
M=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R($YA;64`66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<P!9;W5R
M(%!R:79A=&4@2V5Y`%EO=7(@4'5B;&EC($ME>0!9;W5R(%,O34E-12!0=6)L
M:6,O4')I=F%T92!#97)T:69I8V%T97,`66]U<B!A8V-O=6YT<SH`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN
M92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92X`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.@!9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S
M86=E<SH`66]U<B!D969A=6QT(&5N8W)Y<'1I;VX@;65T:&]D(&9O<B!S96YD
M:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L
M;"!N86UE.@!9;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R
M960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO
M=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9
M;W5R(')E;6]T92!S97)V97)S.@!9;W5R('-I9VYA='5R93H`675G;W-L879I
M80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E
M>'1=`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E
M9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@
M)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0F-C`%]";&%C:VQI<W0`7T-,
M20!?0V,`7T1A=&%4<F5E`%]$96QE=&4`7T1E;&5T92!2;W<`7T9O;&1E<G,`
M7T=R;W5P<P!?2&5L<`!?261E;G1I='D`7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TEN8F]X`%],;V<@:6X`7TQO9R!O=70`7TUE<W-A9V4@4V]U<F-E`%]-;V1I
M9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U!R:6YT`%]0<FEO
M<FET>0!?4F5F<F5S:"`E<P!?4F5M;W9E($QI;FLN+BX`7U)E<&QY`%]396%R
M8V@`7U-E;F0@365S<V%G90!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`
M7U1H<F5A9`!?5&\`7U5N9&5L971E`%]5<V5R<P!?5FEE=R!4:')E860`7U=H
M:71E;&ES=`!A9&1R97-S(&)O;VL`871T86-H;65N=`!A='1A8VAM96YT<RYZ
M:7``8GET97,`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E`&9A;&QI;F<`9FEL
M90!F<F]M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`:6UM961I871E
M`&EN;&EN90!K97D`;&EN97-=`&UA:6QB;W@@9FEL90!M:VES;V9S(&5R<F]R
M(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M90!N;VYE`&YO="!I;7!L
M96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`;W(`<&5R8V5N
M=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I
M82!(5%10`'-P96QL:6YG(&5R<F]R`'-P96QL:6YG(&5R<F]R<P!S=&5A9'D`
M=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N
M8V]M`'EO=7(@8FQA8VML:7-T`'EO=7(@=VAI=&5L:7-T`%!R;VIE8W0M260M
M5F5R<VEO;CH@($EM<"!(,R`H-"XP+C$I"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP,BTR
M,2`Q-3HR-2LP,3`P"DQA<W0M5')A;G-L871O<CH@36%T:6,@1&]L87(@/'-M
M97-N:4!M961I=6TN<VD^"DQA;F=U86=E+51E86TZ(%-L;W9E;KGH:6YA"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#UI<V\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*`"`@("`@(%IA.B``("`@1&%T=6TZ(``@("`@("!/9#H@`"`H)7,@9&YI
M(&YA>F%J*0`@*$)L:;YN:FEC82`E<RD`("AV("5S(&1N96@I`"`H9&%N97,I
M`"`H:G5T<FDI`"`H=NAE<F%J*0`@(%IA9&5V83H@`"!P<FD@`"!V(``C`"4N
M,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`)60@)7,@:6X@)7,`)60@<W!O<F_H
M:6P@:F4@8FEL;R!V8;EE;74@<VMR8FYI:W4@<')I:F%V;&IE;FEH(&MO="!Z
M8;YE;&5N82!E+7!ON71A+@`E9"!S<&]R;^AI;"!J92!B:6QO('!R:6IA=FQJ
M96YI:"!K;W0@>F&^96QE;F$@92UP;[ET82X`)60@<W!O<F_H:6P@:F4@8FEL
M;R!V8;EE;74@<VMR8FYI:W4@<')I:F%V;&IE;FEH(&MO="!N97IAOF5L96YA
M(&4M<&^Y=&$N`"5D('-P;W)OZ&EL(&IE(&)I;&\@<')I:F%V;&IE;FEH(&MO
M="!N97IAOF5L96YA(&4M<&^Y=&$N`"5D(&1O("5D(&]D("5D('-P;W)OZ&EL
M`"5D+61N979N82!N87!O=F5D`"5S("T@3V)V97-T:6QO`"5S(%!R<W1N:2!O
M9'1I<P`E<R!+0@`E<R!6>F1ROF5V86YJ92`M(%!O=')D:71E=@`E<R!0<FEJ
M879A`"5S(%!O9V]J:2!U<&]R86)E`"5S(+YE(&]B<W1A:F$N`"5S(+YE(&]B
M<W1A:F$N(%9AN6$@;6%P82`E<R!N:2!B:6QA('!R96EM96YO=F%N82X`)7,@
M<')I("5S("5S`"5S(&YI('9E;&IA=F5N(&YA8FER86QN:6LN`$UA<&$@)7,@
M8F\@<')E:6UE;F]V86YA(&YA('IAZ&5T:W4@;65S96-A+@`E<R!J92!S<')E
M:F5L+@`E<R!J92!P<F5K;&EC86P@)7,N`"5S(&IE(&]D:VQO;FEL+@`E<R!J
M92!O9&=O=F]R:6P@;F$@>F%H=&5V;R!P<F]S="]Z87-E9&5N+@`E<R!J92!O
M9&=O=F]R:6P@;F$@<&]V86)I;&\@;F$@)7,N`"5S('9A;2!J92!P;W-L86P@
M:6YF;W)M86-I:F\@<')O<W0O>F%S961E;BX`)7,@:F4@;VML979A:F_H92!S
M<')E:F5L+@`E<R!J92!Z86AT979A;@`E<R!M:6YU=``E<R!N:2!M;V=OZ&4@
M;F%J=&DN`"5S(&IE('IA:'1E=F%L('9AN6\@:6YF;W)M86-I:F\@<')O<W0O
M>F%S961E;BX`)7,@>F%H=&5V82!V8;EO('!R:7-O=&YO<W0@<')I("5S+@`E
M<R!K("5S(&]D("5S`"5S(+YE;&D@<&]P<F%V:71I("5S+@`E<R!V87,@OF5L
M:2!O<&]Z;W)I=&D@;F$@)7,N`"5S(+YE;&D@<')E:F5T:2!N86IN;W9E:KEE
M(&EN9F]R;6%C:6IE(&\@)7,N`"5S+6]V($%D<F5S87(`)7,M;W8@2V]L961A
M<@`E<RUO=F$@0F5L9;YN:6-A`"5S+6]V(%-E>FYA;2!O<')A=FEL`"5S.B`E
M<P`E<SH@)7,@*"5D)FYB<W`[;V0F;F)S<#LE9"D`*%5P;W)A8FD@=&4@<W!R
M96UE;6)E(&EN(&YA9&%L:G5J+BD`*$]V<KYI('9S92!S<')E;65M8F4@:6X@
M<V4@=G)N:2!N82!S97-T879L:F%N:F4@<W!O<F_H:6QA+BD`*%5P;W)A8FD@
M=G-E(&1O<V5D86YJ92!S<')E;65M8F5M8F4@:6X@<V4@=G)N:2!N82!S97-T
M879L:F%N92!S<&]R;^AI;&$N(%-P<F5M96UB92!N82!T<F5N=71N96T@>F%S
M;&]N=2!.12!"3T1/('5P;W)A8FQJ96YE+BD`*%5P;W)A8FD@=G-E(&1O<V5D
M86YJ92!S<')E;65M8F4@:6X@<&^Y;&II('-P;W)OZ&EL;RX@4W!R96UE;6)E
M(&YA('1R96YU=&YE;2!Z87-L;VYU($Y%($)/1$\@=7!O<F%B;&IE;F4N*0`J
M($1O9&%J(',@:VQI:V]M(&YA(%8@<F5D=2`J`"H@4')O<VEM(&EZ8F5R:71E
M(&YA<VQO=BAE*2`J`"P@<&EH86IOZ"`E<R`E<P`L('-P<F5M96YL:FEV;R!O
M9"`E<R!D;R`E<P`M+2!I>F)E<FD@+2T`,2!S<&]R;^AI;&\@:F4@8FEL;R!V
M8;EE;74@<VMR8FYI:W4@<')I:F%V;&IE;F\@:V]T('IAOF5L96YA(&4M<&^Y
M=&$N`#$@<W!O<F_H:6QO(&IE(&)I;&\@<')I:F%V;&IE;F\@:V]T('IAOF5L
M96YA(&4M<&^Y=&$N`#$@<W!O<F_H:6QO(&IE(&)I;&\@=F&Y96UU('-K<F)N
M:6MU('!R:6IA=FQJ96YO(&MO="!N97IAOF5L96YA(&4M<&^Y=&$N`#$@<W!O
M<F_H:6QO(&IE(&)I;&\@<')I:F%V;&IE;F\@:V]T(&YE>F&^96QE;F$@92UP
M;[ET82X`,3`P('IN86MO=@`Q,#`P('IN86MO=@`Q,B!5<FYA(&]B;&EK80`R
M-"!5<FYA(&]B;&EK80`R-"!U<@`R-3`@>FYA:V]V`#4P,"!Z;F%K;W8`6F$@
M=&$@8FQO:R!J92!Z86AT979A;F$@=7!O<F%B82!B87IE('!O9&%T:V]V+@!0
M<FFY;&\@:F4@9&\@=7-O9&YE(&YA<&%K90!496UU('-P;W)OZ&EL=2!J92!P
M<FEP971A('9E;&EK82!S;&EK82!Z(&EM96YO;2`E<RX`4W!O<F_H:6QO+"!K
M:2!S=&4@9V$@<&]S;&%L:2P@:F4@8FEL;R!V>G)O:R!Z82!O8G9E<W1I;&\L
M('9R;FIE;F\@<R!S=')A;FD@<')E:F5M;FEK82X`6F$@N6EF<FER86YJ92!S
M<&]R;^AI;&$@:F4@<&]T<F5B96X@:F%V;FD@4$=0(&ML:G7H+@!:82!O=F5R
M:71E=B!P;V1P:7-A;F5G82!S<&]R;^AI;&$@:F4@>F%H=&5V86X@:F%V;FD@
M4$=0(&ML:G7H+@!:82!D9;EI9G)I<F%N:F4@<W!O<F_H:6QA('-O('!O=')E
M8FYI(&IA=FYI(%!'4"!K;&IUZ"P@>F%S96)N:2!01U`@:VQJ=>@@:6X@9V5S
M;&\N`%IA('!O9'!I<R!S<&]R;^AI;&$@<V\@<&]T<F5B;FD@:F%V;FD@4$=0
M(&ML:G7H+"!Z87-E8FYI(%!'4"!K;&IUZ"!I;B!G97-L;RX`6F$@9&6Y:69R
M:7)A;FIE('-P;W)OZ&EL82!S;R!P;W1R96)N:2!J879N:2!3+TU)344@:VQJ
M=>@L('IA<V5B;FD@4R]-24U%(&ML:G7H(&EN(&=E<VQO+@!:82!P;V1P:7,@
M<W!O<F_H:6QA('-O('!O=')E8FYI(&IA=FYI(%,O34E-12!K;&IUZ"P@>F%S
M96)N:2!3+TU)344@:VQJ=>@@:6X@9V5S;&\N`%IA(+EI9G)I<F%N:F4@<W!O
M<F_H:6QA(&IE('!O=')E8F5N(&IA=FYI(%,O34E-12!K;&IUZ"X`04T@4&QO
M:&4`04TO4$T`24X`05!)($E$`$\@=&5M('5R96IE=F%L;FEK=0!/+BXN`$%B
M<V)O='1O;0!!8G-M:61D;&4`4W!R96IM:2!Z86AT979O`%-P<F5J971O`$1O
M<W1O<"!P<FD@:7ID96QO=F%N:G4@5D93(&UA<&4@>F%V<FYJ96XN`$1O<W1O
M<"!P<FD@:7ID96QO=F%N:G4@5D93(&1A=&]T96ME('IA=G)N:F5N+@!'97-L
M;R!R8>AU;F$`4F'H=6X@>F%M<GIN:F5N+@!);64@<F'H=6YA.@!28>AU;F]V
M;V1S='9O`$1E:F%N:F$`1&]D86H`1&]D86H@<&]D<VMU<&EN;P!$;V1A:B!P
M<F%V:6-E('!O9'-K=7!I;F4`1&]D86H@='5K86HZ`$1O9&%J(&YO=F\@<VMU
M<&EN;P!$;V1A:B!N;W9O(&1O=F]L:F5N:F4`1&]D86H@;F]V96=A('5P;W)A
M8FYI:V$Z`$1O9&%J('-T;VQP96,`1&]D86H@;F]V92#H;&%N90!$;V1A:B!P
M87(`1&]D86H@=FER`$1O9&%J("5S(&UE;G4@:V]T($UO>FEL;&$@4VED96)A
M<@!$;V1A:B!V(&UO:B!K;VQE9&%R`$1O9&%J('8@861R97-A<CH`1&]D86H@
M=B!M;VH@861R97-A<@!$;V1A:B!U<&]R86)N:6MA`$1O9&%L("(E<R(@:V]T
M('!R:7!O;FMO+@!$;V1A:F%N:F4@=7!O<F%B;FEK;W8@:F4@;VYE;6]G;^AE
M;F\N`$1O9&%T;F4@:6YF;W)M86-I:F4@<V\@;F$@=F]L:F\@)7,N`$1O9&%T
M;F4@<&]D<F]B;F]S=&D`1&]D871N92!P;V1R;V)N;W-T:2!O('-P;W)OZ&EL
M=0!$;V1A=&YE('!O9')O8FYO<W1I(&\@<W!O<F_H:6QU('-O(&YA('9O;&IO
M("5S+@!$;V1A=&YE('!O9')O8FYO<W1I(&\@;F%P86MI`$1O9&%T;F4@<&]D
M<F]B;F]S=&D@;R!N87!A:VD@<V\@;F$@=F]L:F\@)7,N`$YA<VQO=FD`061R
M97-A<@!!9')E<V%R:FD`061M:6YI<W1R86-I:F$@+2!N87-T879I('!R879I
M8V4@;W-T86QI:"!U<&]R86)N:6MO=@!!9&UI;FES=')A8VEJ80!296ML86UE
M`$%F9V%N:7-T86X`06QB86YI:F$`06R^:7)I:F$`4'-E=F1O;FEM`%!O<F%V
M;F%J`%!O<F%V;F%V83H`5G-A`%9S:2!/=F5R:F5N:2!U<&]R86)N:6MI`%9S
M92!3:W5P:6YE`%9S82!$;W9O;&IE;FIA`%9S92"Y=&ER:2!S=')A;FD`5G-A
M('-P;W)OZ&EL82!V(&YA<VQE9&YJ:6@@;6%P86@@8F]D;R!S=')N:F5N82!V
M(&5N($U"3U@@;F%B:7)A;&YI:SH`5G-A('-P;W)OZ&EL82!V('9AN6D@;6%P
M:2`B)7,B+"!K:2!S;R!S=&%R96JY82!O9"`E<R!D;FD@8F]D;R!T<F%J;F\@
M('!O8G)I<V%N82X`5G-E('!R:7!O;FME+"!S=&%R96JY92!O9"`E<R!M97-E
M8V5V(&)O9&\@<&]B<FES86YE+@!6<V4@;6%P92!S('!O<VQA;F\@<&^Y=&\@
M<W1A<F5JN64@;V0@)7,@;65S96-E=B!B;V1O('!O8G)I<V%N92X`4V4@;&%H
M:V\@<')A=FEL82!Z82!F:6QT<FER86YJ92!U<&]R86)I:F\@;F$@:V%T97)E
M;6MO;&D@;F%B:7)A;&YI:W4_`$1O=F]L:2!V9>@@;F%S;&]V;W8`1&]V;VQI
M(&YA<W1A=FET978@=7)E:F5N96=A('1I<&$@<V5Z;F%M83\`KF4@;V)S=&%J
M80!!;'1E<FYA=&EV;F$@24U34"!P<FEJ879A`$%L=&5R;F%T:79N;R!)35-0
M(&=E<VQO`$%L=&5R;F%T:79N;R!)35-0('5P;W)A8FYIN6MO(&EM90!!;'1E
M<FYA=&EV96X@92UP;[ET;FD@;F%S;&]V`$%L=&5R;F%T:79N92!P<F5D;&]G
M90!!;'1E<FYA=&EV;F\@8F5S961I;&\Z`$%L=&5R;F%T:79N:2!D96QI('IA
M('1A(&]D<V5K.@!6961N;P!6961N;R!S:')A;FD@<')I<&]N:V4`06UE<FFY
M:V$@4V%M;V$`4')I(&]D<W1R86YJ979A;FIU('!R:7!O;FME('-P;W)OZ&EL
M(&IE('!R:;EL;R!D;R!N87!A:V4N($E-05`@<W1R9;YN:6L@:F4@:F%V:6PZ
M(`!6;F6Y96YA(&IE(&)I;&$@;F%P8>AN82!V<F5D;F]S="X`4')I(&1O9&%J
M86YJ=2!N;W9E9V$@;W!R879I;&$@:F4@<')IN6QO(&1O(&YE>FYA;F4@;F%P
M86ME+@!!;F1O<F$`06YG;VQA`$%N9W5I;&$`06YO;FEM96X@<')O>'D`3V1G
M;W9O<@!/9&=O=F]R:F5N;P!/9&=O=F]R:F5N82!S<&]R;^AI;&$`06YK=&%R
M=&EK80!!;G1I9W9A(&EN($)A<F)U9&$`07!L:6MA8VEJ80!397IN86T@87!L
M:6MA8VEJ`$%P;&EK86-I:F$@:F4@<')I<')A=FQJ96YA+@!5<&]R86)I(&9I
M;'1R90!5<&]R86)I(&9I;'1R92!N82`E<P!5<&]R86)I;2!P<F%V:6QA(&9I
M;'1R:7)A;FIA(&]B('!R:6IA=FD_`%5P;W)A8FEM('!R879I;&$@9FEL=')I
M<F%N:F$@;V(@<')I:V%Z=2!)3D)/6#\`57!O<F%B:2!Z82!P;V1R96IE;F4@
M;V)J96MT92!V('-K=7!N:2!R86)I`$]D;V)R:0!!<')I;`!!<F%B<VMO("A7
M:6YD;W=S+3$R-38I`%9E;&EK;W-T(&%R:&EV<VME(&1A=&]T96ME`$EM92!A
M<FAI=F$`06QI('-T92!P<F5P<FGH86YI+"!D82"^96QI=&4@<&]B<FES871I
M('1A(&IA=FYI(&ML:G7H/P!!;&D@<W1E('!R97!R:>AA;FDL(&1A(+YE;&ET
M92!P;V)R:7-A=&D@<W9O:B!P87(@:VQJ=>AE=C\@*$Y)('!R:7!O<F_H96YO
M(2D`4W1E('!R97!R:>AA;FDL(&1A(+YE;&ET92!I>G9RN6ET:2!D96IA;FIE
M/P!!;&D@<W1E('!R97!R:>AA;FD@9&$@OF5L:71E(&]D<W1R86YI=&D@<')I
M:F%V;F\@>F%H=&5V;R!Z82`E<R`_`%-T92!P<F5P<FGH86YI+"!D82"^96QI
M=&4@5%)!2DY/('IB<FES871I('1A('-P;W)OZ&EL83\`4W1E('!R97!R:>AA
M;FDL(&1A(+YE;&ET92!44D%*3D\@>F)R:7-A=&D@=&\@<')I<&]N:V\_`%-T
M92!P<F5P<FGH86YI+"!D82"^96QI=&4@:7IP<F%Z;FET:2!T;R!M87!O/P!3
M=&4@<')E<')IZ&%N:2P@9&$@OF5L:71E(&EZ<')A>FYI=&D@<W9O:F\@;6%P
M;R!S('-M971M:3\`4W1E('!R97!R:>AA;FDL(&1A(+YE;&ET92!T<F%J;F\@
M<&]B<FES871I('1A('-P;W)OZ&EL83\`4W1E('!R97!R:>AA;FDL(&1A(+YE
M;&ET92!P<FEJ879I=&D@=&\@<W!O<F_H:6QO(&MO="!Z8;YE;&5N;S\`4W1E
M('!R97!R:>AA;FDL(&1A(+YE;&ET92!P<FEJ879I=&D@=&\@<W!O<F_H:6QO
M(&MO="!N97IAOF5L96YO/P!!<F=E;G1I;F$`07)M96YI:F$`07)M96YI:G-K
M;R`H05)-4T-)22TX*0#(87,@<')I:&]D80!5;65T;F]S=`!!<G5B80!.87)A
MN75J;^@`3W1O:R!!<V-E;G-I;VX`07-C:6D@<VQI:V4`07II:G-K82]086-I
M9FFY:V$@<F5G:6IA`%9P<F&Y86H`5G!R8;EA;2!Z82!P;W1R9&ET978@<')E
M9"!I>G9E9&)O(&]P97)A8VEJ('9Z9'*^979A;FIA/P!3=&]L<&-I('IA(&1O
M;&_H:71E=@!0<FEP;FD`4')I<&YI(&1A=&]T96ME`%!R:7!N96T@:7IV;V0@
M=F&Y96=A(&IA=FYE9V$@4$=0(&ML:G7H82!K('-P;W)OZ&EL=3\`4')I<&]N
M:V$Z`%!R:7!O;FMA("(E<R(@<')E<V5G82!O;65J:71E=B!V96QI:V]S=&D@
M>F$@<')I<&]N:V4N($1A=&]T96MA($Y)($))3$$@<')I<&5T82X`4')I<&5T
M(&IE(&]D9V]V;W(@;F$@<&]S;&%N;R!Z86AT979O(&MO;&5D87)J82X`4')I
M<&]N:V$`4')I<&]N:V$@;V1S=')A;FIE;F$Z(%9R<W1A('!R:7!O;FME`%!R
M:7!O;FME`%!O<VMU<R!B<FES86YJ82!N96]B<W1O:F7H92!S:W5P:6YE+@!0
M;W-K=7,@8G)I<V%N:F$@;F5O8G-T;VIEZ&5G82!D;W9O;&IE;FIA+@!0;W-K
M=7,@=7)E:F%N:F$@;F5O8G-T;VIEZ&5G82!D;W9O;&IE;FIA+@!0;W-K=7,@
M=7)E:F%N:F$@;F5O8G-T;VIEZ&4@<VMU<&YE(')A8F4N`%5D96QEOF5N8VD`
M4&]Z;W(`071R:6)U=&D`079G=7-T`$%V<W1R86QI:F$`079S=')I:F$`075T
M:%]C>7)S<6PZ(%!O=')E8FYE9V$@24U!4"!D;V1A=&MA(&YI(&UO9V_H92!N
M86IT:2X`075T:%]C>7)U<SH@2')B=&5N:6-A('!R;V=R86UA(&YI;6$@<&]T
M<F5B;FEH('IM;[YN;W-T:2X`075T:%]C>7)U<SH@4&]T<F5B;F5G82!)34%0
M(&1O9&%T:V$@;FD@;6]G;^AE(&YA:G1I+@!!=71H7V9T<#H@4&]T<F5B;F5G
M82!&5%`@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN($-O;7!I;&%J=&4@4$A0
M('H@;6^^;F]S=&IO("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!0;W1R96)N
M96=A($E-05`@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN`$%U=&A?:6UP.B!:
M86AT979A;B!)34%0(&1O9&%T96L@;FD@8FEL(&YA:F1E;BX`075T:%]K<F(U
M.B!0;W1R96)N96=A(&MR8C4@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN`$%U
M=&A?;&1A<#H@4&]T<F5B;F5G82!,1$%0(&1O9&%T:V$@;FD@;6]G;^AE(&YA
M:G1I+@!!=71H7VQD87`Z(%5P;W)A8FYI:V$@)7,@;FD@;6]G;^AE(&1O9&%T
M:2X@4W1R9;YN:6L@:F4@:F%V:6PZ`$%U=&A?;&1A<#H@57!O<F%B;FEK82`E
M<R!N:2!M;V=OZ&4@;V1S=')A;FET:0!!=71H7VQD87`Z(%5P;W)A8FYI:V$@
M)7,@;FD@;6]G;^AE('!O<V]D;V)I=&D`075T:%]M8V%L.B!0;W1R96)N96=A
M($U#04P@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN`$%U=&A?<VUB875T:#H@
M4&]T<F5B;F5G82!S;6)A=71H(&1O9&%T:V$@;FD@;6]G;^AE(&YA:G1I+@!/
M=F5R:F%N:F4@;FD@=7-P96QO`$]V97)J86YJ92!N:2!U<W!E;&\N("5S`$]V
M97)J86YJ92!Z879R;FIE;F\@;F$@4D%$2553('-T<F6^;FEK=2X`3W9E<FIA
M;FIE(&YA($944"!S=')EOFYI:W4@;FD@=7-P96QO+@!!=G1O;6%T:>AN;R!P
M<FEK8;YE;2!S;&EK92!V($A434P@<W!O<F_H:6QI:"P@:V%D87(@:F4@<&^Y
M:6QJ871E;&H@=B!M;VIE;2!A9')E<V%R:G4_`$%D<F5S87)J:2P@:VD@<V\@
M;F$@=F]L:F\Z`%!O;&IA(&MI('-O(&YA('9O;&IO.@#(86MA:F_H(&]D>FEV
M`$%Z97)B86IDOF%N`$)/1D@@27IG;W9O<FD`3F%Z86H@7VYA("5S`$YA>F%J
M(&YA("5S`$]Z861J90!"87)V82!O>F%D:F$`3F5P<F%V:6QN;R!K97)B97)O
M<R!G97-L;RX`3F5P<F%V:6QN;R!K97)B97)O<R!U<&]R86)N:;EK;R!I;64N
M`$)A:&%M:0!"86AR86IN`$)A;'1IN6MO("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&6Y`$)A<F)A9&]S`$]S;F]V80!":VL`0F5L;W)U<VEJ80!"96QG:6IA`$)E
M;&EZ90!3<&]D86H@:F4@<W5R;W9O(&)E<V5D:6QO('!O<F_H:6QA(&\@<W1A
M='5S=2X`0F5N:6X`0F5R;75D80!"=71A;@!2;VIS=&YI(&1A;@!";&%C:VQI
M<W0`0FQO:V$@(B5S(B!A<&QI:V%C:6IE("(E<R(@;FD@;6]G;^AE(&YA:G1I
M+@!.87-T879I='9E(&)L;VMA`%9R<W1A(&)L;VMA`$YE('!R:6MAOF5M('-L
M:6L@=B!(5$U,('-P;W)OZ&EL:6@@<F%Z96X@Z&4@<V\@:7IR96-N;R!Z86AT
M979A;F4_`%1E;&\`2W)E<&MO`$)O;&EV:6IA`%!R:6QJ=6)L:F5N90!2;V(`
M1&5B96QI;F$@<F]B=3H`4F]B;W9I`$)O<VYA(&EN($AE<F-E9V]V:6YA`$]B
M;VIE`$]B;VIE("T@<V5Z;F%M(&=L879E(&EN('1E;&\@<W!O<F_H:6QA`$)O
M8W9A;F$`4W!O9&%J`$]T;VL@0F]U=F5T`$)R87II;&EJ80!"<FET86YS:V\@
M;WIE;6QJ92!);F1I:G-K96=A(&]C96%N80!"<G5N96H@1&%R=7-S86QA;0!"
M=6QG87)I:F$`3WIN8>AE;FD@<V5Z;F%M`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`$--4P!#4D,`5&_H:V4@9&ES=')I8G5C:6IE($-23`!,87-T;F]S=&D@8U]E
M;&EC92XN+@!+;U]D;F$@=&%B96QA`$MO;&5D87(`36ER;F\`2V%M8F]DOF$`
M2V%M97)U;@!0;W9E>F%V82!N82!O9&1A;&IE;B!P;[ET;FD@<W1R9;YN:6L@
M;FD@=7-P96QA+@!0;W9E>F%V82!N82!O9&1A;&IE;B!P;[ET;FD@<W1R9;YN
M:6L@;FD@=7-P96QA.B``4')I:V%Z(&YI(&UO9V_H("T@=B!T<F5N=71N96T@
M;F%B:7)A;&YI:W4@:F4@8FEL;R!N86ID96YI:"!S86UO("5S(&]D("5S(&1E
M;&]V('1E9V$@<W!O<F_H:6QA+@!'97-L82!N:2!M;V=OZ&4@<&]N87-T879I
M=&D@879T;VUA=&GH;F\L(&MO;G1A:W1I<F%J=&4@<W9O:F5G82!A9&UI;FES
M=')A=&]R:F$N`%!O=F5Z879E('H@24U!4"!S=')EOFYI:V]M(&YI(&UO9V_H
M92!V>G!O<W1A=FET:3H@)7,`2V%N861A`%!R96ML:>AI`%!R96ML:>AI('-P
M;W)OZ&EL;P!0<F5K;&GH:2!P<FEJ879O(&YA<&%K90!0<F5K;&EC('1E9V$@
M<W!O<F_H:6QA(&)O('1R86IN;R!Z879R9V5L('9S96)I;F\N`$1A=&]T96ME
M("(E<R(@;FD@;6]G;^AE(&EZ8G)I<V%T:2X`6F'H87-N92!M87!E(&YI(&UO
M9V_H92!N86IT:2X`0G)E>B`G=&%R9V5T1FEL92<@<&%R86UE=')A(&YI(&UO
M9V_H92!N861A;&IE=F%T:2X`36%P92`B)7,B(&YI(&UO9V_H92!O9'-T<F%N
M:71I+@!/8FIE:W1A(&YI(&UO9V_H92!O9'-T<F%N:71I+"!O8G-T86IA("5D
M('!O9&]B:F5K=&]V+@!0;VYO=FYA(')A>G9R<W1I=&5V(&YI(&UO9V_H82P@
MN71E=FEL;R!P;V1A;FEH('9P:7-O=B!N92!U<W1R97IA('-H<F%N:F5N96UU
M(+ET979I;'4@=G!I<V]V('IA('!O;F]V;F\@<F%Z=G)S=&ET978N`%-P;W)O
MZ&EL82!N:2!M;V=OZ&4@=7-M97)I=&D@;F$@<&]D86YO(+ET979I;&\N`$-A
M<&4@5F5R9&4`3F%S;&]V`$MA=&5G;W)I:F4@:6X@;WIN86ME`$MA:FUA;G-K
M:2!O=&]K:0!+:P!-;V)I;&YI('1E;&5F;VX`3&%S=&YO<W1I(&-E;&EC90!0
M<F%Z96X@<')O<W1O<B!V(&-E;&EC:3H`3&%S=&YO<W1I(&-E;&EC90!0<F%Z
M96X@<')O<W1O<B!M960@8V5L:6-A;6DZ`$UO8FEL;FD@=&5L969O;@!+96QT
M<VMO("A)4T\M.#@U.2TQ-"D`4W)E9&EN80!3<F5D;FIE869R:;EK82!297!U
M8FQI:V$`4W)E9&YJ965V<F]P<VMO("A)4T\M.#@U.2TR*0!0;V1R;V)N;W-T
M:2!P;W1R9&EL80!0;VQI=&EK82!P;W1R9&EL80#(860`4')E9'-E9'5J;^AA
M(&]S96)A`%-P<F5M96YI`%-P<F5M96YI('9S90!3<')E;65N:2!M87!O`$YA
M<W1A=FD@;6^^;F]S=&D@<')I:V%Z82P@N71E=FEL;R!S<&]R;^AI;"!P<FEK
M87IA;FEH(&YA(&5N:2!S=')A;FD@:6X@;6^^;F]S=&D@<F%Z=G*YZ&%N:F$@
M<W!O<F_H:6PN`$YA<W1A=FD@<&^Y=&YI('-T<F6^;FEK(&EN(&UOOFYO<W1I
M(&UA<&4N`$YA<W1A=FD@:6UE(&EN(&YA<VQO=BP@:VD@9V$@;W-E8F4@=FED
M:6IO+"!K;R!B97)E:F\@:6X@;V1G;W9A<FIA:F\@;F$@=F&Y;R!E+7!ON71O
M+@!.87-T879I(&EM92P@;F%S;&]V(&EN('!O9'!I<RP@:VD@9V$@<')E:F5M
M;FEK:2!S<&]R;^AI;"!V:61I:F\L(&MO(&)E<F5J;R!I;B!O9&=O=F%R:F%J
M;R!N82!V8;EO(&4M<&^Y=&\N`%IN86L`4')I:V%Z('IN86MO=CH`4')E=E]E
M<FD@<&]V97IA=F\N+BX`4&]G;&5J('IA($YO=F$@<W!O<F_H:6QA`$]Z;F'H
M:2!?5G-E+TYO8F5N96=A`$]Z;F'H:71E('9S92!S=')EOFYI:V4L(',@:V%T
M97)I:""^96QI=&4@<')E;F5S=&D@92UP;[ET;SH`4')E=F5R:6T@Z')K;W9A
M;FIE('!R961E;B!P;[EL:F5M('-P;W)OZ&EL;S\`R&EL90!+:71A:G-K80!0
M;V5N;W-T879L:F5N;R!+:71A:G-K;R`H1T(R,S$R*0!4<F%D:6-I;VYA;&YO
M($MI=&%J<VMO("A":6<U*0!)>F)E<FET92!D96IA;FIE.@!)>F)E<FET92!P
M;[ET;FD@<W1R9;YN:6LZ`$EZ8F5R:71E(&=E<VQO`$EZ8F5R:71E('5P;W)A
M8FYIN6MO(&EM90!)>F)E<FET92!D96IA;FIE.@!)>F)E<FET92!N8>AI;B!P
M<FEK87IA(&1A='5M;W8Z`$EZ8F5R:71E(&EZ9VQE9"!S97IN86UA("AZ82!U
M<F5J96YE('-E>FYA;64I`$EZ8F5R:71E(&%D<F5S87(L(&MI(&=A('5P;W)A
M8FEM('IA(&1O9&%J86YJ92!N87-L;W9O=BX`27IB97)I=&4@=G)S=&YI(')E
M9"!I<VMA;FIA('!O(&%D<F5S87)J:6@L(&MO(')A>KEI<FIA;2!N87-L;W9E
M+@!696QI:V]N;^AN:2!O=&]K`$1E9FEN:6-I:F4@<F%Z<F5D82`E<R!N:2!M
M;V=OZ&4@;F%J=&DN`$IA<VYO`%!OZ&ES=&D@35-/9F9I8V4@;WIN8>AB90!0
M;^AI<W1I('5P;W)A8FYI:V$Z("5S`%!OZ&ES=&D@=7!O<F%B;FEK80!0;^AI
M<W1I('!O9&%T:V4@;R!U<&]R86)N:6MU`$ML:6MN:71E("5S('IA('!R971V
M;W)B;R!S;&EK92!V(&]B;&EK;R!K:2!J;R!V8;D@8G)S:V%L;FEK('IN82!P
M<FEK87IA=&DN`$ML:6MN:71E("5S(&1A('-I('!R96YE<V5T92!S;&EK;RX`
M2VQI:VYI=&4@)7,@>F$@<W1R86X@>F$@=7!R879L:F%N:F4@)7,N`$ML:6MN
M:71E("5S('IA('!R:6MA>B!(5$U,('9S96)I;F4@=B!L;^AE;F5M(&]K;G4N
M`$ML:6MN:71E("5S('IA('!R:6MA>B!S;&GH:6-E('1E('-L:6ME+@!+;&EK
M;FET92`E<R!Z82!P<FEK87H@<')I<&]N:V4@=B!L;^AE;F5M(&]K;G4N`$ML
M:6MN:71E('IA(%!224M!6B!S;&EK`$ML:6MN:71E(&YA(&EZ8G)A;F4@861R
M97-A<FIE+"!N871O('!A(&EZ8F5R:71E('9S82!P;VQJ82P@<&\@:V%T97)I
M:"!N86H@<&]T96MA(&ES:V%N:F4N`$ML:6MN:2!Z82!N861A;&IE=F%N:F4`
M2VQI:VYI=&4@>F$@<VAR86YI=&5V(&IA=FYE9V$@4$A0(&ML:G7H82!V('9A
MN2!!9')E<V%R`$ML:6MN:71E('IA('-H<F%N:71E=B`E<R!3+TU)344@<&]T
M<F1I;&$@=B!V8;D@061R97-A<BX`0VQI8VMA=&5L;"!P<F5K;R!(5%10`$ML
M:6L@;F$@;F%S;&]V(&)O(&]D<')L('-E<W1A=FQJ86YJ92!N;W9E9V$@<W!O
M<F_H:6QA('!ON6EL:F%T96QJ=0!+;&EK(&YA(&YA<VQO=B!B;R!O9'!R;"!S
M<&]R;^AI;&\@>F$@8G)A;FIE`%IA<')I`%IA<')I(&]K;F\`6F%P<FD@=&\@
M;VMN;P!:87!R:2!M87!O`$]B;&%K:0!/8FQAZ&YO`$ME96QI;F=O=FD@;W1O
M:VD`4VMRZ&D`4VMRZ&D@=G-E`%-K<NAI('9S92!M87!E`%-K<NAI(&UA<&\`
M4VMR:6H@<W1R86YS:VD@;65N=0!3:W)I:B!R;V)O=F4`2V]L=6UB:6IA`$)A
M<G9A`%!O:V%Z871E;&H@8F%R=F4Z(`!"87)V;F$@=&%B96QA`$EZ8FER82!B
M87)V90!3=&]L<&-I.@!.87-L;W9I('-T;VQP8V5V`%-T<FEP:0!5:V%Z`%5K
M87IN82!L=7!I;F$`2V]M96YT87(`26UE`$MO;6]R:0!0;V1J971J90!+;V[H
M86YO`%-E<W1A=FD@N64@96YO('-P;W)OZ&EL;P!397-T879L:F%J('-P;W)O
MZ&EL82!V(&QOZ&5N96T@;VMN=3\`4')I=GIE=&\@<V5S=&%V;&IA:B!S<&]R
M;^AI;&$@<R!(5$U,('5P;W)A8FYIN6MI;2!V;65S;FEK;VT@*.AE(&)R<VMA
M;&YI:R!P;V1P:7)A('1O(&UOOFYO<W0I/P!28>AU;F%L;FEK:0!0;V=O:FD`
M4F%Z;&EK92!V(&YA<W1A=FET=F%H`$YA<W1A=FD@)7,`3F%S=&%V:2!P<FEK
M87H@<W!O<F_H:6PN`$YA<W1A=FD@<')E9&]G;&5D('-P;W)OZ&EL+@!0;W1R
M9&D@9V5S;&\`2V]N9V\`1&5M;VMR871S:V$@4F5P=6)L:6MA($MO;F=O`%!O
M=F5Z879A(&YI('5S<&5L82X`4&]V97IA=F$@;FD@=7-P96QA.@!0;W9E>F%V
M82!N82!J879N:2!S=')EOFYI:R!S(&ML:G7H:2!Z879R;FIE;F$N`%!O=F5Z
M879A(&YA(&IA=FYI('-T<F6^;FEK(',@:VQJ=>AI('IA=G)N:F5N82X@4F%Z
M;&]G.B`E<R`H)7,I`%!O=F5Z879A(&YA($944"!S=')EOFYI:R!N:2!U<W!E
M;&$N`%!O=F5Z879A(',@<W1R9;YN:6MO;2!N:2!U<W!E;&$`4W1I:VD@<V\@
M8FEL:2!U<W!EN6YO(&1O9&%N:2!V(&%D<F5S87(N`$YA<')E:@!5<')A=FQJ
M86YJ92!S(%!'4"!P;V1P;W)O('IA("5S+@!5<')A=FQJ86YJ92!S(%,O34E-
M12!P;V1P;W)O('IA("5S+@!.87-T879I('!R979E<FIA;FIE(&YO=F4@<&^Y
M=&4@:6X@;F'H:6X@;V)V9;GH86YJ82P@:V%D87(@<')I<W!E(&YO=F\@<W!O
M<F_H:6QO+@!0<F5T=F]R:6T@=&5K<W1O=FYE('-M9;EK92!V(&=R869IZ&YE
M/P!#;V]K;W9I(&]T;VMI`%!IN6MO=&5K`$MO<&ER86H`2V]P:7)A:B!I>F)R
M86YO`$MO<&ER86H@=B!M87!O`%!O<')A=FD`4&]P<F%V;&IE;F\@8F5S961I
M;&\`2V]S=&%R:6MA`%-L;VYO:V^YZ&5N82!O8F%L80!01U`@<W!O<F_H:6QA
M(&YI(&)I;&\@;6]G;^AE(+EI9G)I<F%T:2X`4$=0('-P;W)OZ&EL82!N:2!B
M:6QO(&UO9V_H92!P;V1P:7-A=&DN`%-P;W)OZ&EL82!N:2!B:6QO(&UO9V_H
M92"Y:69R:7)A=&D@<R!3+TU)344N`%-P;W)OZ&EL82!N:2!B:6QO(&UO9V_H
M92!P;V1P:7-A=&D@<R!3+TU)344N`%-T:6MA(&YI(&)I;&\@;6]G;^AE(&1O
M9&%T:2X@)7,`4&]V97IA=F$@;F$@3$1!4"!S=')EOFYI:R!N:2!B:6QA(&UO
M9V_H82X`4W1A;FIA(&YI(&)I;&\@;6]G;^AE('!R979E<FET:2X@)7,`4V5Z
M;F%M82!R87ID96QI='9E(&YI(&)I;&\@;6]G;^AE(&EZ9&5L871I+B`E<P!6
M1E,@:')B=&5N:6-E(&YI(&)I;&\@;6]G;^AE(&EZ9&5L871I.B`E<P!01U`@
M<&]D871K;W8@;FD@8FEL;R!M;V=OZ&4@9&6Y:69R:7)A=&DN`%,O34E-12!P
M;V1A=&MO=B!N:2!B:6QO(&UO9V_H92!D9;EI9G)I<F%T:2X`4W1I:V$@;FD@
M8FEL;R!M;V=OZ&4@<&]B<FES871I+B`E<P!397IN86UA(')A>F1E;&ET=F4@
M;FD@8FEL;R!M;V=OZ&4@<&]B<FES871I+B`E<P!3<&]R;^AI;&$@;FD@8FEL
M;R!M;V=OZ&4@<&]B<FES871I(&EZ("5S+B!.87!A:V$Z("5S`%!R96IE;6YI
M:V]V96=A(&4M<&^Y=&YE9V$@;F%S;&]V82!N:2!B:6QO(&UO9V_H92!U9V]T
M;W9I=&DN`%9Z9'*^979A;FIA(&YI(&)I;&\@;6]G;^AE('IA9VYA=&DN`*YE
M;&IE;F4@9&%T;W1E:V4@;FD@8FEL;R!M;V=OZ&4@:7IV;&7H:2!I>B!-4RU4
M3D5&('!R:7!O;FME+@"N96QJ96YE(&1A=&]T96ME(&YI(&)I;&\@;6]G;^AE
M(&EZ=FQEZ&D@:7H@6FEP('!R:7!O;FME+@!#96QO=&YE9V$@861R97-A<FIA
M(&YI(&UO9V_H92!P<F5B<F%T:2X`0V5L;W1N96=A('-E>FYA;6$@<F%Z9&5L
M:71V92!N:2!M;V=OZ&4@<')E8G)A=&DN`$-E;&]T;F5G82!S97IN86UA('-E
M>FYA;6]V(')A>F1E;&ET=F4@;FD@;6]G;^AE('!R96)R871I+@!3('-T<F6^
M;FEK82!S(&ML:G7H:2!N:2!B:6QO(&UO9V_H92!D;V)I=&D@:F%V;F5G82!K
M;&IUZ&$N`"5S(&YI(&UO9V_H92!O9'!R971I+@!-;V1U;&$@36%I;G1E;F%N
M8V5?5&%S:R!N:2!M;V=OZ&4@;V1P<F5T:2`E<P`E<R!N:2!M;V=OZ&4@<')E
M8G)A=&DN`%IA('IA:'1E=F%N96=A('5P;W)A8FYI:V$@;FD@8FEL;R!M;V=O
MZ&4@<&]N87-T879I=&D@9V5S;&$N($YE:V%T97)I(&%L:2!V<VD@<&]D871K
M:2!N:7-O('!R879I;&YI+B!0;W-K=7-I=&4@<&]N;W9N;RP@86QI('!A('-E
M(&]B<FYI=&4@;F$@<W9O:F5G82!S:W)B;FEK82#H92!P;W1R96)U:F5T92!N
M861A;&IN;R!P;VUOZ"X`04-,(&YI(&)I;&\@;6]G;^AE('!R96)R871I`$%D
M<F5S87)J82!N:2!M;V=OZ&4@<')E8G)A=&DN("5S`%-E>FYA;6$@<F%Z9&5L
M:71V92!N:2!M;V=OZ&4@<')E8G)A=&DN("5S`%-E>FYA;6]V(')A>F1E;&ET
M=F4@;FD@;6]G;^AE('!R96)R871I+B`E<P!:;6^^;F]S=&D@<W1R9;YN:6MA
M(&YI(&)I;&\@;6]G;^AE('5G;W1O=FET:0!.87-T879I=&5V(&YI(&)I;&\@
M;6]G;^AE('9R;FET:2!N82!P<G9O=&YO('-T86YJ90!.87-T879I=&5V("5S
M(&YI(&)I;&\@;6]G;^AE('-H<F%N:71I+@!687)N;W-T;F4@:V]P:6IE(&YA
M<W1A=FET978@;FD@8FEL;R!M;V=OZ&4@<VAR86YI=&DN`%9A<FYO<W1N92!K
M;W!I:F4@;F%S=&%V:71E=B!N:2!B:6QO(&UO9V_H92!S:')A;FET:3H@)7,`
M27-K86YJ92!,1$%0('-T<F6^;FEK82!N:2!U<W!E;&\N`%-T:6MA(&YI(&)I
M;&\@;6]G;^AE('!O<V]D;V)I=&DN("5S`%-E>FYA;6$@<F%Z9&5L:71V92!N
M:2!B:6QO(&UO9V_H92!P;W-O9&]B:71I+B`E<P!-96YU:F$@36]Z:6QL82!3
M:61E8F%R(&YI(&)I;&\@;6]G;^AE(&YA:G1I+B!0<F5P<FGH86IT92!S92P@
M9&$@:F4@;V1P<G0N`%5P;[ET979A;F\@8F5S961I;&\`1'*^879A`%1EZ&%J
M:0!5<W1V87)I`%5S='9A<FD@;6%P;P!5<W1V87)I(&ML:G7H90!5<W1V87)I
M(&YA=FED97IN;R!M87!O`%5S='9A<FD@<&]V97IA=F\`57-T=F%R:2!N;W9O
M(&UA<&\@>F$@;W-N=71K90!5<W1V87)I(&YO=F\`57-T=F%R:2!N;W9O(&UA
M<&\@>F$@<&]S;&%N;R!P;[ET;P!5<W1V87)I(&YO=F\@;6%P;R!Z82!S;65T
M:0!.87-T879I=&5V('!R879I;"!F:6QT<FER86YJ82!Z82!O<F=A;FEZ:7)A
M;FIE('9AN64@<')I:&%J86IOZ&4@92UP;[ET92P@<V]R=&ER86YJ92!V(&UA
M<&4@:6X@8G)I<V%N:F4@;F5Z8;YE;&5N92!E+7!ON71E+@!5<W1V87)I('!O
M9&UA<&\`4')A=FEC92!L87-T;FEK80"I=&5V:6QK82!K<F5D:71N92!K87)T
M:6-E`$AR=F&Y:V$`2W5B80!4<F5N=71E;B#H87,`5')E;G5T96X@55),(&IE
M`%1R96YU=&YO('9R96UE`%1R96YU=&5N(&1O<W1O<"!D;R`E<P!4<F5N=71N
M;R!S=&%N:F4Z`%1R96YU=&5N('-T:6P`3F%S=&%V:2!R8>AU;F4@>F$@<VYE
M;6%N:F4@<&^Y=&4@>B!D<G5G:6@@<F'H=6YO=BX`3F%S=&%V:71V92!N8>AI
M;F$@<&^Y:6QJ86YJ82!E+7!ON71E+@!.87-T879I(&]P<F%V:6QA+"!K:2!S
M92!Z8;YE;F5J;R!O8B!P<FEJ879I('8@)7,N`$EZ<F6^:0!)>G)EOFD@:7IB
M<F%N;P!#:7!E<@!#:7)I;&EC82`H2T])."U2*0!#:7)I;&EC82`H5VEN9&]W
M<RTQ,C4Q*0!#:7)I;&EC82]5:W)A:FEN82`H2T])."U5*0#(9;EK80!$1`!$
M;F5V;F\`1&%T=5]M`$)R<VMA;&YI:R!$871A5')E90!$871U;0!$871U;2!P
M<F5J96UA`$EZ8FER82!D871U;6$`1&%N`$EZ8G)IN6D@<W1O;'!E8P!$96-E
M;6)E<@!$96-I;6%L:V4`6F%V<FYJ96YO`%IM86YJN6%J('IA;6EK`%!R:79Z
M971A(&)A<G9A`%!R:79Z971A(&ED96YT:71E=&$`4')I=GIE=&$@<F%Z=G)S
M=&ET978Z`%!R:79Z971A('-M97(@<F%Z=G)S=&ET=F4Z`$1E9FEN:6-I:F4`
M1&5L96=I<F%N;P!)>F)R:;EI`$EZ8G)IN6D@)7,@:F%V;FD@:VQJ=>@`27IB
M<FFY:2!T<F5N=71N92!K;&IUZ&4`27IB<FFY:2!M87!O*&4I`$EZ8G)IN6D@
M<VMU<&EN;P!)>F)R:;EI('!R879I8V\`27IB<FFY:2!N879I9&5Z;F\@;6%P
M;P!)>F)R:;EI(&EN('!OZ&ES=&D@<W!O<F_H:6QA`$EZ8G)IN6D@8V5L:6-O
M`$EZ8G)IN6D@<W1O;'!E8P!)>F)R:;EI(&]B<W1O:F7H;R!A;'1E<FYA=&EV
M;F\@<')E9&QO9V\`27IB<FFY96T@<&]S;F5T82!S<&]R;^AI;&$@>B!O9&1A
M;&IE;F5G82!S=')EOFYI:V$_`$EZ8G)IN6D@:7H@;6]J96=A(&MO;&5D87)J
M80!0;V)R:;EE;2!S=&%R92!P<FEP;VYK92!N82!Z8>AE=&MU(&UE<V5C83\`
M4&]B<FFY96T@<W1A<F4@;6%P92!S('!O<VQA;F\@92UP;[ET;R!N82!Z8>AE
M=&MU(&UE<V5C83\`27IB<FFY:2!V<G-T:6-O`$EZ8G)IN6D@:7IB<F%N;R!I
M9&5N=&ET971O`$EZ8G)IN6D@=')E;G5T96X@<W1O;'!E8P!)>F)R:;EI('1R
M96YU=&YO('9R<W1I8V\`4&]B<FES86YO`%!O8G)I<V%N82!S<&]R;^AI;&$`
M4&]B<FFY:2!P<FEP;VYK;R`B)7,B+@!"<FES86YJ92!I;B!P<F5M:6MA;FIE
M('-P;W)OZ&EL`,AA<R!D;W-T879E`$1A;G-K80!:879R;FD@>F%H=&5V;P!:
M879R;FD@>F%H=&5V;R!Z82!I;F9O<FUA8VEJ;R!P<F]S="]Z87-E9&5N`%!A
M9&%J;^@`3W!IN6D@<')O8FQE;0!/<&ES`%!O9')O8FYO<W1I`%!O9')O8FYO
M<W1I("AT=61I('8@2&]R9&4@;&]G(&1A=&]T96MI*3H`4&]D<F]B;F]S=&D@
M<V\@8FEL92!Z87!I<V%N92!Z82!S:W)B;FEK82X`4F%Z=F]J`%)O<V$`4F]S
M82!V('IA9&YJ:2!U<FDZ`%)O<V$Z(`!:86UE9VQI;2!P;V1P:7-E/P!3;65R
M(&]D(&QE=F4@<')O=&D@9&5S;FD`4VUE<B!O9"!D97-N92!P<F]T:2!L979I
M`$EM96YI:P!0<FEK87H`4')I:V&^96T@Z&%S('8@;V)L:6MI(#(T('5R/P!-
M;[YN;W-T:2!P<FEK87IA`%!R:6MAOF5M('!O=')D:71E=B!O('!O<VQA;F5M
M('-P;W)OZ&EL=3\`4')I:V&^:2!N87!O=F5D("A4048I`$]B;&EK82!P<FEK
M87IA`%!R:6MAOFD@=B!T96QE<W4@<W!O<F_H:6QA`%!R:6MAOF5M(&]K96YC
M92!Z(&]B=F5S=&EL;VT@;R!N;W9I('!ON71I/P!$:7-P;WII8VEJ80!/8G9E
M<W1I;&\@;R!D:7-P;WII8VEJ:0!$OFEB=71I`%-E($Y%('5J96UA`$YE('!R
M979E<FIA:B!M87`H92D@>F$@;F]V;R!E+7!ON71O`$YE('!O8G)IN6D`3F4@
M9&]S=&]P86IT92!D871O=&5K92!M86EN=&5N86YC92YP:'`@;F5P;W-R961N
M;P!.92!U<W1V87)I('!O=F5Z879E('H@3V0Z('-T;VQP8V$`06QI(+YE;&ET
M92!O9'!R971I('1O(&UA<&\_`$%L:2!P<G9A('9R<W1I8V$@=G-E8G5J92!I
M;65N82!P;VQJ/R#(92!D82P@;V1K;&IU:V%J=&4Z`$1O;6EN:6-A`$1O;6EN
M:6MA;G-K82!R97!U8FQI:V$`2V]NZ&%N;P!0<F5N97-I`%!R96YE<VD@)7,`
M4')E;F5S:2`E<R!V("YZ:7`@;V)L:6MI`%!R97-N96UI('9S92!0<FEP;VYK
M92`H=B`N>FEP(&1A=&]T96MI*0!0<F5S;F5M:2!-87!O*&4I`%!R97-N96UI
M($UA<&\H92D@6RYZ:7`@;V)L:6MA70!0<F5N97-I(&=E;F5R:7)A;F\@:V]N
M9FEG=7)A8VEJ;R!K;W0@4$A0('-K<FEP=&\N`%!R97-N96UI('8@+GII<"!O
M8FQI:VD`3W-N=71E:P!-87!A('H@;W-N=71K:0!-87!A('H@;W-N=71K:3H`
M4V5Z;F%M('H@:7IB:7)O`$1R;V=E`$4M<&^Y=&$`12UP;[ET;FD@;F%S;&]V
M`$524@!.05!!2T$Z(%9AN65G82!S<&]R;^AI;&$@;FD@8FEL;R!M;V=OZ&4@
M9&]S=&%V:71I+@!%:W9A9&]R`%5R961I`%5R961I($)L86-K;&ES=`!5<F5D
M:2!B;&]K`%5R961I($9I;'1R90!5<F5D:2!S:W5P:6YO`%5R961I('!R879I
M8V\`57)E9&D@<')A=FEC90!5<F5D:2!P<F%V:6-E('IA("5S`%5R961I($YA
M=FED97IN92!M87!E`%5R961I(&1E9FEN:6-I:F\@;F%V:61E>FYI:"!M87`@
M>F$@)7,`57)E9&D@5VAI=&5L:7-T`%5R961I(&UOOFYO<W1I('IA.@!5<F5D
M:2!P<F%V:6-E('IA("5S`%5R961I=&4@<W9O:B!B;&%C:VQI<W0`57)E9&ET
M92!S=F]J82!P<F%V:6QA(&9I;'1R:7)A;FIA`%5R961I=&4@<W9O:F4@;F%S
M=&%V:71V92!Z82!D;W-T;W`@9&\@9')U9VEH('!ON71N:6@@;F%S;&]V;W8N
M`%5R961I=&4@<W9O:B!W:&ET96QI<W0`27IO8G)A>F)A`$5G:7!T`%-A;'9A
M9&]R`$5L96UE;G0N+BX`16T`12UP;[ET80!%+7!ON71N:2!N87-L;W8`12UP
M;[ET;FD@;F%S;&]V:2!S92!M;W)A:F\@=6IE;6%T:2X`12UP;[ET82!S('!O
M=')D:71V:6IO`%-M9;EK:0!)>G!R87IN:6P@=G-A('-P;W)OZ&EL82!I>B`E
M<P!)>G!R87IN:2!M87!O*&4I`$EZ<')A>FYI(&UA<&\@<R!S;65T;6D`27IP
M<F%Z;FD@7U-M971I`%!R87IN;R!S<&]R;^AI;&\N`%!R87IE;B!R97IU;'1A
M="X`4')A>FYA(&ES:V%L;F$@<&]L:F$`3VUO9V_H:6T@4$=0/P!/;6]G;^AI
M;2!3+TU)344_`$]M;V=OZ&D@=G-T879L:F%N:F4@<VQI:R!I>B!&;W1O(&=A
M;&5R:6IE('8@8F5S961I;&\_`$]M;V=OZ&D@<')E9&]G;&5D('-P;W)OZ&EL
M`$]M;V=OZ&D@9&5S;FD@:VQI:R!Z82!M96YU`$UOOFYO<W1I(*EI9G)I<F%N
M7VIA`$MO;F5C`$MO;F5C('!O<W)E9&]V86YE9V$@<W!O<F_H:6QA`$MO;F5C
M('-P;W)OZ&EL80!+;VYE8R!S<&]R;^AI;&$@;V0@)7,`3&5T;R!K;VYC80!0
M;W9EZ&%J('5R96IE=F%L;FEK`%9P:;EI=&4@<W1A=F5K('IA(&=E<VQO`%9N
M97-I=&4@=G!R8;EA;FIE+"!K:2!V86T@8F\@>F%S=&%V;&IE;F\L(.AE(&)O
M<W1E(+YE;&5L:2!P;VYA<W1A=FET:2!S=F]J92!G97-L;RP@;G!R+B`G2V%K
M;R!J92!I;64@=F&Y:2!D;VUAZ&D@OFEV86QI/R<Z`%1U:V%J('9P:;EI(%52
M3"!S;&EK90!6<&FY:71E(&EM92!V8;EE(&YO=F4@;6%P92!Z(&]S;G5T:VD`
M5G!IN6ET92!I;64@=F&Y92!N;W9E(&UA<&4@<R!P;W-L86YO('!ON71O`%9P
M:;EI=&4@:6UE('9AN64@;F]V92!M87!E('IA('-M971I`%9P:7,@(B5S(B!J
M92!B:6P@=7-P9;EN;R!D;V1A;B!V($%D<F5S87(`16MV871O<FEA;&YA($=V
M:6YE:F$`17)I=')E:F$`3F%P86MA`$YA<&%K82!P<FD@<&^Y:6QJ86YJ=2!O
M9&=O=F]R83H@)7,N`$YA<&%K82!Z(&4M<&^Y=&YI;2!S<&]R;^AI;&]M+@!%
M<W1O;FEJ80!%=&EO<&EJ80!%=&YO`$5V<F]P80!$;V=O9&5K('5S<&6Y;F\@
M:7IB<FES86XN`%9S86MI:"`Q-2!M:6YU=`!6<V%K:2`R(&UI;G5T:0!6<V%K
M:6@@,S`@<V5K=6YD`%9S86MI:"`U(&UI;G5T`$]B('9S86MI('!R:6IA=FD`
M5G-A:V4@<&]L('5R90!6<V%K;R!M:6YU=&\`4')I;65R:3H`27IV961I`%)A
M>KEI<FD`4F%ZN6ER:2!V<V4`4F%ZN6ER:2!V<V4@;6%P90!287JY:7)I(&UA
M<&\`4F%ZN6ER:2!I;65N80!287JY:7)I('-T<F%N<VMI(&UE;G4`4')I(&]K
M;G4@>F$@<V5S=&%V;&IA;F4@879T;VUA=&GH;F\@<F%ZN6ER:2!I;65N82!V
M(&]Z861J=2X`4F%ZN6ER:6T@8V5L;W1N;R!D<F5V;R!P<FD@<&]G;&5D=2!M
M87`_`%)A>KEI<F%N:F4`4')IZ&%K;W9A;"`G*2<`4')IZ&%K;W9A;F$@:F4@
M8FEL82!B97-E9&$@86QI('-T879E:R!Z82!I<VMA;FIE('8@;F%R96MO=F%J
M:6@`1&%T=6T@=F5L:F%V;F]S=&D`16MS<&]N96YT`$)A<G9A(&]S<')E9&IA
M`$944"!P<F5N;W,@;F%M97-T:71V90!0<F5N;W,@;F%S=&%V:71E=B!N:2!U
M<W!E;"X`4&]V97IA=F$@;F$@3$1!4"!S=')EOFYI:R!N:2!U<W!E;&$N`%!O
M=F5Z879A(&YA(%--0B!S=')EOFYI:R!N:2!U<W!E;&$N`$MO<&ER86YJ92!I
M>B`B)7,B(&YI('5S<&5L;RX`2V]P:7)A;FIE('8@(B5S(B!N:2!U<W!E;&\N
M`%9Z<&]S=&%V;&IA;FIE(&YO=F4@4T%33"!P;W9E>F%V92!N:2!U<W!E;&\N
M`%!R96UI:V%N:F4@=B`B)7,B(&YI('5S<&5L;RX`3&5P;P!&86QK;&%N9'-K
M:2!O=&]K:0!&87)O92!O=&]K:0!&86MS`$9E8G)U87(`R'5T:71I(&IE`,AU
M=&ET:2!J93H@`$9E=&-H($UA:6P`1F5T8V@@36%I;"!V(&QOZ&5N96T@;VMN
M=3\`4')E;F5S96T@<W!O<F_H:6QA(&]B('!R:6IA=FD_`$9E=&-H;6%I;#H@
M`$9E=&-H;6%I;#H@;FD@;F]V:6@@<W!O<F_H:6PN`$YE:V%J('!L;V@`1FE?
M;'1R:0!&:62^:0!$871O=&5K80"I=&5V:6QO(&1A=&]T96LZ("5S(&1A=&]T
M96MA`*ET979I;&\@9&%T;W1E:SH@)7,@9&%T;W1E:P!5<')A=FET96QJ(&1A
M=&]T96L`26UE(&1A=&]T96ME`$EZ8FER82!D871O=&5K90!0<F5N;W,@9&%T
M;W1E:V4@;F$@<W1R9;YN:6L`4')E;F]S:2!D871O=&5K(&YA('-T<F6^;FEK
M(&YI<V\@<&]D<')T:2X`36^^;F]S=&D@1FEL=')O=@!.87-T879I='9E($9I
M;'1R;W8`1FEL=')I<F%M('9S96)I;F\@<W!O<F_H:6P@>F$@=G5L9V%R;F4@
M8F5S961E/P!0;V1P;W)A(&9I;'1R;VT@:F4@;F$@=&5M('-I<W1E;74@;VYE
M;6]G;^AE;F$N`$9I;'1R:0!&:6QT<FD@3DE33R!A:W1I=FYI`$9I;'1R:3H@
M)7,@<W1R86X@>F$@=7!R879L:F%N:F4`3F%J9&D`1FEN<VMA`%!R=F$@<&]L
M;W9I8V$`4')V82!S=')A;B!N86)I<F%L;FEK80!0<G9A('-T<F%N`%!R=F$@
MZ&5T<G1I;F$`1FEK<VYO(')A>FUE<FIE`%!R97IR8V%L:0!,96)D9>@`3F%P
M7W)E:@!-96=L80!-87!A("5S(&YE(&]B<W1A:F$`4')E;6EK86YJ92!P;R!-
M87!A:`!/<&ES($UA<&4`36%P92!V('-K=7!N:2!R86)I(&YI<V\@;VUO9V_H
M96YE+@!5<&]R86)A(&UA<"!N:2!O;6]G;^AE;F$N`$)A<G9A(&)E<V5D:6QA
M`$AR86YA`%IA(&)R<VMA;&YI:V4L(&MI(&YE('!O9'!I<F%J;R!S;&EK`$YA
M<&]V960@*%1!1BD`1&YE=FD@;F%P;W9E9&D@*&YA<&]V960@8F\@=G)N:F5N
M82!Z82!O8F]J92!D86X@:6X@;F_H.R!V:7-O:V$@N71E=FEL:V$@;&%H:V\@
M<&]V>G)OZ&D@N6ER;VL@8FQO:RD`4W1E('!O>F%B:6QI(&=E<VQO/P!/8FQI
M:V$@9&%T=6UO=B!Z82!D86YAN6YJ82!S<&]R;^AI;&$@=B!P;V=L961U(&YA
M8FER86QN:6MA`$]B<F%Z8VD`1F]R='5N:0!6<G-T82!&;W)T=6YO=@!&;W)T
M=6YI`$9O<G1U;FD@,@!/8G)A>F-I`%!O<W)E9'5J`%!O<W)E9'5J.@!0;W-R
M961O=F%N;R!S<&]R;^AI;&\`4&]S<F5D;W9A;F\@<W!O<F_H:6QO(&]D("5S
M`%!O<W)E9&]V86YJ80!090!/:W9I<FII`$9R86YC:6IA`$9R86YC:6IA+"!-
M97-T;P!);F9O<FUA8VEJ82!0<F]S="]:87-E9&5N`$]D9V]V;W(@4')O<W0O
M6F%S961E;@!:86AT979A(%!R;W-T+UIA<V5D96X`3V1G;W9O<B!N82!Z86AT
M979O(%!R;W-T+UIA<V5D96X`1G)A;F-O<VMA($=U:6%N80!&<F%N8V]S:V$@
M4&]L:6YE>FEJ80!*=;YN82!&<F%N8V]S:V$@;WIE;6QJ80!/7V0`3V0`3V0@
M;F%S;&]V`$]D(`!0;VQN:2!O<&ES`%!O;&YA(&QU;F$`4&]L;F\@:6UE`$9W
M9#H`1G=D.@!&=V0Z("5U(%!O<W)E9&]V86YI:"!S<&]R;^AI;`!'86)O;0!6
M>F5M:2!S;&EK;R!I>B!G86QE<FEJ90!'86QE<FEJ83H`1V%M8FEJ80!3<&QO
MN6YE($UOOFYO<W1I`$=E;F5R:7)A:B`E<R!K;VYF:6=U<F%C:6IO`$=E;F5R
M:7)A;F$@:7IV;W)N82!K;V1A`$=E;W)G:6$`3F5MZ&EJ80!0<F5N97-E;2!S
M86UO(&YO=F$@<W!O<F_H:6QA/R`H<V%M;R!)34%0*0!'86YA`$=I8G)A;'1A
M<@!,87-T;F\@:6UE`%!O:F1I(&YA('-P;W)OZ&EL;P!';V5D96P`1V]O9VQE
M(&ES:V%N:F4`3V1O8G)I(&1O<W1O<`!3:79I;G-K82!L97-T=FEC80!'<NAI
M:F$`1W*Y:V\@*$E33RTX.#4Y+3<I`$=R965N;&%N9&EJ80!'<F5N861A`$%D
M;6EN:7-T<F%C:6IA('-K=7!I;@!);65N82!S:W5P:6X@;F4@<VUE:F\@8FET
M:2!P<F%Z;F$`4VMU<&EN90!'=6%D96QO=7!E`$=U86T`1W9A=&5M86QA`$=U
M97)N<V5Y`%!R879I8V4@1V]S=&$`2VYJ:6=A(&=O<W1O=@!'=FEN96IA`$=V
M:6YE:F$@0FES<V%U`$=V86IA;F$`5%5+04H`2%1-3`!(5$U,(')A>FQIZ&EC
M82!S<&]R;^AI;&$`2%1-3$%R96$@<W1R86AO<&5T;F\@;F_H92!P;V)R:7-A
M=&D@>F%D;FIE(&-E;&EC92!V('9R<W1I8VDN`$A434Q!<F5A('-T<F%H;W!E
M=&YO(&YOZ&4@<&]B<FES871I('IA9&YJ96=A('-T;VQP8V$@=B!T86)E;&DN
M`$A434Q!<F5A('-T<F%H;W!E=&YO(&YOZ&4@<&]B<FES871I('IA9&YJ92!V
M<G-T:6-E('8@=&%B96QI+@!(5%10(&]V97)J86YJ92!N:2!B:6QO(&YA:F1E
M;F\N`$AA:71I`$AA<V@M06QG;W)I=&5M`%-O<&%R80!';&%V80!6<G-T:6-E
M(&=L879E`$AE87)D(&]T;VMI(&EN($UC1&]N86QD(&]T;VMI`$AE8G)E=G-K
M;R`H25-/+3@X-3DM."U)*0!6:;EI;F$`4&]M;^@`4&]M;^@@<')I('5P;W)A
M8FD@=7)E:F5V86QN:6MA`%!O;6_H;FEK`%!O;&]B;&$`4VQE9&D@>F'H971E
M:R!D871O=&5K93H`5'5K86H@:F4@<W!O<F_H:6QO+"!K:2!S=&4@9V$@<V5S
M=&%V;&IA;&DZ`%-K<FET;P!3:W)I=&\@=B!P;V=L961U(%!O9V]V;W)A`%-K
M<FEJ($EZ8G)I<V%N80!3:W)I:B!.96YA<F_H96YE`%9I<V]K80!6:7-O:V$@
M<')I;W)I=&ET80!.86IV:;EJ80!$;U]M;W8`4W9E=&D@<V5D9;X@*%9A=&EK
M86YS:V$@;65S=&YA(&1ROF%V82D`1&]M;W8`1&]M8>AI(&YA<VQO=@!$;VUA
MZ&D@=&5L969O;@!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z($YA<&'H;FD@)7,@6$U,('!O9&%T:VD@;F%J9&5N:2!V('-P;W)OZ&EL
M=2`E<P!(;W)D92]+;VQA8CH@3F]B96YO('-P;W)OZ&EL;R!N92!U<W1R97IA
M(&]B:F5K='4@)7,@`$AO<F1E+TMO;&%B.B!/8FIE:W0@=&EP82`E<R!N:2!B
M:6P@;F%J9&5N('8@<W!O<F_H:6QU("5S`$AO<F1E+TMO;&%B.B!5<W!EN6YO
M(&]D<W1R86YI;"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!);G1E9W)A8VEJ82!P
M;W1R96)U:F4@4$A0(&1O9&%T96L@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($YI
M(&UO9V_H92!I>F1E;&%T:2!N;W9E9V$@6$U,(&1R979E<V$@>F$@;V)J96MT
M("5S`$AO<F1E+TMO;&%B.B!.:2!M;V=OZ&4@;V1S=')A;FET:2`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@3FD@;6]G;^AE('!R:61O8FET:2!-24U%($E$
M('IA(&1E;"!T:7!A("5S`$AO<F1E+TMO;&%B.B!.:2!M;V=OZ&4@<VEN:')O
M;FEZ:7)A=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YI(&UO9V_H92!S
M:6YH<F]N:7II<F%T:2!S:W5P;F4@<F%B93H@)7,`2&]R9&4O2V]L86(Z($YE
M<&]Z;F%N82!S:W5P;F$@<F%B82`B)7,B`%9O9&]R879N82#H<G1A`%9O9&]R
M879N:2!O9&UI:P!6;V1O<F%V;F\Z`$MA:V\@<W1E('!R:;EL:2!D;R!S96T_
M("A0<F]S:6T@;V)V97-T:71E(2D`2V%K;R"^96QI=&4@<')I:V%Z871I('!R
M:7!O;FME/P!+;VQI:V\@<W1O;'!C978@OF5L:71E('-P;VII=&D_`$MO;&EK
M;R!P;VQJ("AS=&]L<&-E=BD@;V)S=&%J83\`2V]L:6MO('9R<W1I8R"^96QI
M=&4@<W!O:FET:3\`2V%K;R!P;VYA>F]R:6T@8VET:7)A;F4@=G)S=&EC92!V
M(&]D9V]V;W)U`%9L8;YN;W-T`%9L8;YN;W-T.@!(=6UO<FES=&D`36%DOF%R
M<VMA`$E-05``24U!4"`H>F%Z;F%J('!R;W1O:V]L*0!5<W1V87)J86YJ92!)
M34%0(&YA8FER86QN:6MA(&YI('5S<&5L;SH@)7,`0G)I<V%N:F4@24U!4"!N
M86)I<F%L;FEK82!N:2!U<W!E;&\Z("5S`$EZ9&5L879A(&MV;W1E($E-05`@
M;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<P!)34%0('!R96MO(%-33`!)34%0
M('!R96MO(%-33"`H<V%M;RUP;V1P:7-A;F\@<&]T<F1I;&\I`$E-05`@<')E
M:V\@4U-,("AS86UO+7!O9'!I<V%N*0!)34%0+"!B<F5Z(%1,4P!)34%0+U!/
M4#,@4&^Y=&YI(%-T<F6^;FEK:0!)3D)/6`!)4"!N87-L;W8`25`@;F%S;&]V
M(&YI(&YA('9O;&IO+@!)4"!N87-L;W8@;FD@9&]V;VQJ96X@=B!#2412(&)L
M;VMU+@!+<KEI=&5V('IA:VQE;FET=F4@25`@;F%S;&]V82X`5E]S=&%V:2!V
M<G-T:6-E('!R960`27-L86YD:6IA`%-A;6\@:6MO;F4`26MO;F4@>F$@)7,`
M26MO;F4@<R!T96MS=&]M`$EM92!I9&5N=&ET971E.@#(92!P<FEK87H@;FD@
M<')A=FEL96XL("5S('IA(&]D<')T:F4@=B!N;W9E;2!O:VYU+@#(92!P<FD@
M=7!O<F%B:2!);G1E<FYE="!%>'!L;W)E<FIA(&YE('9I9&ET92!I:V]N+"!O
M9&ML:G5K86IT92!T;R!M;[YN;W-T('IA(&]N96UO9V_H96YJ92!P<F]Z;W)N
M;W-T:2!S;&EK(%!.1RX`R&4@=FED:71E('1O('-P;W)OZ&EL;RP@<VQI:V4@
M<&$@;F4L('-L:6MA(&MI(&IO(+YE;&ET92!P<F5N97-T:2!N92!M;W)E(&)I
M=&D@<')I:V%Z86YA('8@=F&Y96T@8G)S:V%L;FEK=2X`4')E>G)I`%!R97IR
M:2!V<V4`4')E9&]G;&5D('-L:6ME.@!54DP@<VQI:V4`55),('-L:6ME.@!3
M;&EK82!I>B!G86QE<FEJ90!3;&EK82!I>B!G86QE<FEJ93H`4')E;F]S('-L
M:6ME(&YA('-T<F6^;FEK`%-L:6ME`%5V;WII`%5V;WII(&ML:G7H`%5V;WII
M('!A<B!K;&IUZ&5V`%5V;WII(%!'4"!K;&IUZ`!5=F]Z:2!O<V5B;FD@6F%S
M96)N:2!01U`@:VQJ=>@`579O>FD@;W-E8FYI($IA=FYI(%!'4"!K;&IUZ`!5
M=F]Z:2!O<V5B;F\@4R]-24U%('!O=')D:6QO`%5V;WII($IA=FYI(&ML:G7H
M`%5V;WII($IA=FYI(%!'4"!K;&IUZ`!5=F]Z:2!*879N:2!3+TU)344@:VQJ
M=>@`579O>FD@4R]-24U%(&ML:G7H`%5V;WII(&UB;W@@9&%T;W1E:V\`579O
M>FD@;6)O>"!D871O=&5K;R`E<R!V(&UA<&\@)7,N`%5V;WHL(&MO<F%K("5D
M`%!O;65M8FYO`%!O;65M8FYA('-P;W)OZ&EL80!5=F]Z:6P@)60@<W!O<F_H
M:6P@:7H@)7,N`%5V;[YE;F\@<&]L:F4Z("5S`%5V;[YE;F$@<&]L:F$Z`%8@
M=&5K=0!67W-T879I('9R<W1I8V4@>F%D86H`26YB;W@`5FML:G7H:6T@:W)A
M=&5K('!O=GIE=&5K(&=L879E('8@;V1G;W9O<C\`5FML:G7H:6T@:7IV;W)N
M;R!S<&]R;^AI;&\@=B!O9&=O=F]R/P!0;V1A;F$@;F5P<F%V:6QN82!K;V1A
M(&1E:F%N:F$N`$YE<')A=FEL;F\@=7!O<F%B;FFY:V\@:6UE(&EN+V%L:2!G
M97-L;RX`3F5P<F%V:6QN;R!U<&]R86)N:;EK;R!I;64@86QI(&YA<VQO=BX@
M4&]S:W5S:71E('!O;F]V;F\@86QI(&MO;G1A:W1I<F%J=&4@<W9O:F5G82!S
M:W)B;FEK82P@Z&4@<&]T<F5B=6IE=&4@;F%D86QJ;F\@<&]M;^@N`%!O=F7H
M86H@>F%M:6L`26YD:6IA`%!O<V%M97IN:2!U<&]R86)N:6MI`$EN9&]N97II
M:F$`26YF;P!);F9O<FUA8VEJ90!);F9O<FUA8VEJ92!O("5S($IA=FYE;2!K
M;&IUZ'4`26YF;W)M86-I:F4@;R!O<V5B;F5M(%IA<V5B;F5M(&ML:G7H=0!)
M;F9O<FUA8VEJ92!O(&]S96)N96T@2F%V;F5M(&ML:G7H=0!:;F]T<F%J`%9S
M=&%V:2!S=%]O;'!E8R!Z861A:@!4=6MA:B!V<W1A=FD@4&]T<F1I;&\`5G-T
M879I('-L:6MO`%1U:V%J('9S=&%V:2!O<V5B;FD@6F%S96)E;B!01U`@:VQJ
M=>@`5'5K86H@=G-T879I(&]S96)N:2!*879N:2!01U`@:VQJ=>@`5'5K86H@
M=G-T879I($IA=FYI(%!'4"!K;&IUZ`!6<W1A=FD@=&%B96QO`%9S=&%V:2!S
M<&QE=&YO('!O=F5Z879O`%9S=&%V:2!S=&]?;'!E8R!S<')E9&%J`%9S=&%V
M:2!N;W8@<W1O;'!E8R!Z82!T<F5N=71N:6T`5G-T879I(&YO=B!S=&]L<&5C
M('!R960@=')E;G5T;FEM`%9S879I(&YO=F\@=G)S=&EC;R!Z82!T<F5N=71N
M;P!6<W1A=FD@;F]V;R!V<G-T:6-O('!R960@=')E;G5T;F\`5G-T879I(&]D
M<W1A=F5K('IA('1R96YU=&YI;2!V;WIL:;GH96T`5G-T879I(&]D<W1A=F5K
M('!R960@=')E;G5T;FEM('9O>FQIN>AE;0!6<W1A=FD@86QT97)N871I=FYO
M('!R961L;V=O`%9P:;EI=&4@92UP;[ET;FD@;F%S;&]V(&MA;6]R(+YE;&ET
M92!P<F5J971I(&YO=F\@9V5S;&\Z`%9S=&%V:2!C96QI8V\@>F%D86H`5G-T
M879I(&-E;&EC;R!S<')E9&%J`%9S=&%V:2!S=&]L<&5C('IA9&%J`%9S=&%V
M:2!S=&]L<&5C('-P<F5D86H`5G-T879I('-P;W)OZ&EL80!6<W1A=FD@;V1S
M=&%V96L@<W!R961A:@!6<W1A=FD@;V1S=&%V96L@>F%D86H`5G-T879I('9R
M<W1I8V\@>F%D86H`5G-T879I('9R<W1I8V\@<W!R961A:@!6<&FY:71E(&]D
M9V]V;W(@;F$@>F%H=&5V86YO('9A<FYO<W1N;R!V<')AN6%N:F4Z`%9S=&%V
M:2]5<F5D:2!S;&EK;P!6<W1A=FDO57)E9&D@<&]V97IA=F\`3F5Z861O<W1E
M;B!K<F5D:70@>F$@<&^Y:6QJ86YJ92!N82!S97IN86UA(')A>G!ON6EL:F%N
M:F$N`$YE>F%D;W-T96X@:W)E9&ET+@"I=&5V:6QO`%-E>FYA;2"Y=&5V:6P`
M6F$@=&\@:V]M<&]N96YT;R!J92!B:6QO(&EZ8G)A;F\@;F5P<F%V:6QN;R!D
M96IA;FIE`$YE<')A=FEL96X@3F%S;&]V`$YE<')A=FEL96X@;V1D86QJ96X@
M;F%B:7)A;&YI:P!.87!AZ&5N(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!.
M87!AZ&YA(&%P;&EK86-I:F$N`$YA<&'H96X@240@<&%K971A+@!.979E;&IA
M=F5N('IN86L@=B!E+7!ON71N96T@;F%S;&]V=3H@)7,`3V1D86YI(&YA<&'H
M;FD@<&]D871K:2X`3F%P8>AN96X@;F%S;&]V(&1E<W1I;F%C:6IE+@!.87!A
MZ&YA(&]B;&EK82!D871O=&5K90!.979E;&IA=F5N(&ML:G7H`$YA<&'H96X@
M;7-G7W1Y<&4N`$YA<&'H96X@86QI(&UA;FMA:F_H(&%P:5]I9"X`3F%P8>AN
M:2!A;&D@;6%N:V%J;^AI('!A<F%M971R:2X`3F%P8>AN82!D;W9O;&IE;FIA
M(&YA9')E:F5N96=A(&]B:F5K=&$N`$YE=F5L:F%V96X@;W-E8FYI(%!'4"!Z
M87-E8FYI(&ML:G7H+@!.979E;&IA=F5N(&]S96)N:2!01U`@:F%V;FD@:VQJ
M=>@N`$YA<&'H96X@<')O=&]K;VPN`$YE=F5L:F%V96X@;V)J96MT('8@<VMU
M<&YI(')A8FD`3F5V96QJ879E;B!I>G9O<FYI(&YA<VQO=BX`3F%P8>AN:2!U
M;FEC;V1E('!O9&%T:VDN`$EN=F5N='5R80!/8G)N:2!I>F)O<@!)<F%N`$ER
M86L`27)S:V$`36%N;W8@;W1O:P!)>F]L:7)A;F4@;F5V:6AT90!)>G)A96P`
M27ID86IA=&5L:@!0;[EE=FYO`$ET86QI:F$`2F%M86IK80!*86YU87(`2F%P
M;VYS:V$`2F%P;VYS:V\@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU
M;&EJ`$IU;FEJ`%!O<F%V;F%V80!3<F5D:6YS:V$@<&]R879N879A`$]B;VIE
M<W1R86YS:V$@<&]R879N879A`$QE=F$@<&]R879N879A`$1E<VYA('!O<F%V
M;F%V80!+0@!+87IA:'-T86X`3V)D<KYI;2!O<FEG:6YA;#\`2V5N:6IA`$ME
M<F)E<F]S('-T<F6^;FEK(&IE('IA=G)N:6P@;W9E<FET978N`$YO=FEN8VD@
M:V5R;F5L80!)>F1E;&%V82!K;&IUZ&$`4')S=&YI(&]D=&ES(&ML:G7H80!$
M;VR^:6YA(&ML:G7H80!6<G-T82!K;&IUZ&$`57!O<F%B82!K;&IUZ&$`2VQJ
M=>@@OF4@;V)S=&%J82!N82!J879N96T@<W1R9;YN:6MU(',@:VQJ=>AI+@!+
M;&IUZ"!U<W!EN6YO('!O<VQA;B!N82!J879N:2!S=')EOFYI:R!S(&ML:G7H
M:2X`3W1R;V-I`$MI<FEB871I`$MO<F5J82P@3&IU9'-K82!D96UO:W)A=&GH
M;F$@<F5P=6)L:6MA`$MO<F5J82P@<F5P=6)L:6MA`$MO<F5J<VMO("A%54,M
M2U(I`$MU=F%J=`!+:7)G:7II<W1A;@!0;W-T7V%V:71E=@!*97II:P!,86]S
M`%IA9&YJ82!P;VQO=FEC80!:861N:F$@<W1R86X@;F%B:7)A;&YI:V$`6F%D
M;FIA('-T<F%N`%IA9&YJ82#H971R=&EN80!:861N:FGH('!O<V]D;V)L:F5N
M;SH`6F%D;FIA('!R:6IA=F$Z("5S`%IA9&YJ82!P<FEJ879A.B`E<R!Z("5S
M`%IA9&YJ82!P<FEJ879A.B!.:6MO;&D`3&%T=FEJ80!:86MO;@!0;W-T879I
M=&5V`%!U<W1I=&4@<')A>FYO('IA(&)R97H@<F]B=0!,:6)A;F]N`$QE=F\`
M3&5V82!G;&%V80!,979E('9R961N;W-T:0!,97-O=&\`4&]V9;YI(%!R:7!O
M7VYK90!,:6)E<FEJ80!,:6)I:F$`3&EH=&5NN71A:FX`4F%H;&\@<F]S96YJ
M90!286AE;"!D9;X`4F%H96P@9&6^('IG;V1A:@!286AE;"!D9;X@<&]Z;F\`
M4F%H;&$@9&6^979N82!P;&]H80!286AE;"!D9;X@<R!S=')E;&%M:0!286AL
M;R!S;F6^96YJ90!286AL82!S;F6^;F$@<&QO:&$`3&EM97)I8VL`4&]V97IA
M=F$`4&]V97IA=F$@:V&^92!N83H`4&]V9;YI(&4M<&^Y=&YI(&YA<VQO=B!N
M82!S=')A;B!Z82!S97-T879L:F%N:F4@<W!O<F_H:6P`4&]V97IA;F4@<')I
M<&]N:V4@;FES;R!D;W9O;&IE;F4N`%!O=F5Z879E`$QI;G5X('!IN6MO=&5K
M`%-E>FYA;2`M('5P;W)A8FYI:R!L86AK;R!V:61I(&UA<&\`4')I:V&^:2!B
M87IE('!O9&%T:V]V`%!R:6MAOFD@=&5M92!P;VUOZ&D`4')I:V&^:2!T86)E
M;&4`4')I:V&^96T@=G-E('-T:6ME+"!K;R!N86QA9V%M('IA<VQO;B!S('-T
M:6MI/R`HZ&4@:F4@;6^^;F]S="!O;F5M;V=OZ&5N82!B;W-T979I9&5L:2!S
M86UO('-T:6ME+"!K:2!J:6@@<V%M:2!I>G)E8VYO(&FYZ&5T92D`4V5Z;F%M
M+4%R:&EV`%-E>FYA;2U0;VUOZ`!397IN86TM260`4V5Z;F%M+4QA<W1N:6L`
M4V5Z;F%M+4UE<W1O`%-E>FYA;2U.87)OZ&D`4V5Z;F%M+4]D<&]V96H`4V5Z
M;F%M('8@9VQA=FD`4')I:V%Z;W9A;FIE('5P;W)A8FYI:V]V(&IE(&]N96UO
M9V_H96YO+@!,:71E<F%T=7)A`$QI='9A`$YA;&%G86TN+BX`3&]K86QN:2!.
M86)I<F%L;FEK.@!,;VMA;&5N(.AA<SH@`$IE>FEK(&EN(.AA<P!,;VMA8VEJ
M80!0<FEJ879A`%!R:6IA=F$@=B`E<P!/9&IA=F$`4')I:F%V80!/<')A=FEL
M82!O8B!P<FEJ879I`%!R:6IA=F$@;FD@=7-P96QA('IA<F%D:2!N87!AZ&YO
M('9P:7-A;F5G82!U<&]R86)N:;EK96=A(&EM96YA(&%L:2!G97-L82X`4')I
M:F%V82!N:2!U<W!E;&$N`$1O;&=O(&)E<V5D:6QO`$QJ=6)E>F5N`$YI>FMA
M`$YI>FMA(%!R:6]R:71E=&$`36%L92!G<KEK92#H<FME`$UA;&4@;&%T:6YS
M:V4@Z')K90!-86QE(')I;7-K92"Y=&5V:6QK90!.86IN:;YJ80!,=6MS96UB
M=7)G`$U-`$U/5$0`35,M5$Y%1B!P<FEP;VYK82!N:2!V<V5B;W9A;&$@<&]D
M871K;W8N`$U31P!-86MA;P!-86ME9&]N:6IA`$UA8VEN=&]S:"!$871O=&5K
M80!-861A9V%S:V%R`$UA9VEJ80!0;[ET80!5<')A=FET96QJ('!ON71E`%!R
M961O9VQE9"!0;[ET90!4:7`@<W1R9;YN:6MA('IA('!O=F5Z879O.@!.86)I
M<F%L;FEK`$UOOFYO<W1I('!R:6MA>F$@3F%B:7)A;&YI:V]V(&EN($UA<`!5
M<W1V87)I('!O=F5?>F%V;P!-86QA=FD`36%L97II:F$`36%L9&EV:0!-86QI
M`$UA;'1A`%5R961I=&4@<V5Z;F%M(&MA=&5G;W)I:BP@<R!K871E<FEM:2"^
M96QI=&4@;WIN8>AI=&D@;V)J96MT92!I;B!B87)V92!P;W9E>F%N92!S('1E
M;6D@:V%T96=O<FEJ86UI+@!:96UL:F5V:60@36%P,C0`6F5M;&IE=FED($UA
M<%%U97-T`$UA<F5C`$]D;6EK`$]Z;F'H:2!V<V$@<W!O<F_H:6QA('8@;6%P
M:2!K;W0@5FED96YA`$]Z;F'H:2!V<V$@<W!O<F_H:6QA('8@;6%P:2!K;W0@
M3F4M=FED96YA`$]Z;F'H:2!K;W0Z`$]Z;F'H:6T@<F%Z;&GH;F4@;FEV;VIE
M(&-I=&ER86YJ82!Z(')A>FQIZ&YI;6D@8F%R=F%M:3\`3WIN8>AI;2!S<&]R
M;^AI;&$@:V]T('9I9&5N83\@*'-A;6\@24U!4"D`3WIN8>AI;2!P<F5P<F]S
M=&\@;V)L:6MO=F%N:F4_`$]Z;F'H:2!Z(&]Z;F%K;R!6:61E;F\O3F4@=FED
M96YO`$]Z;F'H:2!Z(&1R=6=I;6D@;WIN86MA;6D@*&YP<BX@4&]M96UB;F\O
M3V1G;W9O<FIE;F\I`$UA<G-H86QL;W9I(&]T;VMI`$UA<G1I;FEQ=64`4')I
M:V&^:2!V<V4@<&]I>G9E9&)E`%!R:6MAOFD@:V%T97)O:V]L:2!P;VEZ=F5D
M8F\`56IE;6%J;^AA('!O;&IA`$UA=G)E=&%N:6IA`$UA=7)I=&EU<P!-86MS
M:6UA;&YI(&1O=F]L:F5N(&MR961I="X`36%K<VEM86QN;R"Y=&5V:6QO(&1E
M;&]V('-P;W)OZ&EL82!P<F5K;W)AZ&5N;RX`3F%J=FFY:F$@=&5M<&5R871U
M<F$@>F%D;FII:"`R-"!U<CH@`$YA:G9IN6IA('1E;7!E<F%T=7)A('IA9&YJ
M:6@@-B!U<CH@`$YA:G9EZ&IA('9E;&EK;W-T('!R:7!O;FME`$UA:W-I;6%L
M;F$@9&]LOFEN80!.86IV9>AJ92"Y=&5V:6QO('!R:7!O;FL@9&]S9;YE;F\N
M`$YA:G9EZ&IA('-K=7!N82!V96QI:V]S="!P<FEP;VYK(&1O<V6^96YA+@!-
M86H`36%Y;W1T90!:9')A=G-T=F\`3V1P;W9E9"!S97-T86YK80!);F9O<FUA
M8VEJ92!O('-E<W1A;FMU`%!R961L;V<@>F$@<V5S=&%N96L`3V1G;W9O<B!O
M('-E<W1A;FMU`$YO=F4@:6YF;W)M86-I:F4@;R!S97-T86YK=0!:86AT979A
M('!O(&YO=FEH(&EN9F]R;6%C:6IA:"!O('-E<W1A;FMU`,AL86YI`$UE;G4@
M<V5Z;F%M82!-87``5G)S=&$@;65N=6IA.@!3<&]J:2!C96QI8V4`4W!O<F_H
M:6QO`%-E=&%V;&IA;FIE(%-P;W)OZ&EL80!$871U;2!3<&]R;^AI;&$`36^^
M;F]S=&D@4W!O<F_H:6QA`$ES:V%N:F4@4W!O<F_H:6QA`%9E;&EK;W-T(%-P
M;W)OZ&EL80!)>G9O<FYA(&MO9&$@4W!O<F_H:6QA`%-P;W)OZ&EL;R!J92!B
M:6QO('5S<&6Y;F\@<')E=F5R:F5N;RP@<&]D<&ES;FEK;W9E9V$@<&]T<F1I
M;&$@<&$@;FD@8FEL;R!M;V=OZ&4@;W9E<FET:2X`4')E9VQE9"!3<&]R;^AI
M;&$`4W!O<F_H:6QO(&IE('!R971E:VQO+@!/>FYA:V4@4W!O<F_H:6QA`$UA
M<&4@<W!O<F_H:6P`4W!O<F_H:6QO(&]D("5S`%5J96UA;FIE('-P;W)OZ&EL
M80!3<&]R;^AI;&\@=7-P9;EN;R!P<F5U<VUE<FIE;F\N`%-P;W)OZ&EL;R!U
M<W!EN6YO('!O<VQA;F\L('9E;F1A<B!N:2!B:6QO('-H<F%N:F5N;R!V("5S
M`%-P;W)OZ&EL;R!U<W!EN6YO('!O<VQA;F\N`%9R<W1A('-P;W)OZ&EL80!3
M<&]R;^AI;"!N82!S=')A;B!V('!O9VQE9'4@;F%B:7)A;&YI:V$N`%-P;W)O
MZ&EL82!Z80!-971A<B!6<F5M90!-971A<B!B;&]K(&YI(&YA('9O;&IO+@!-
M971A<B!B;&]K(&YI(&YA('9O;&IO+B!0;V1R;V)N;W-T:2!S;R!B:6QE(&QO
M9VER86YE('IA(&%D;6EN:7-T<F%T;W)J82X`365T;V1A`$UE=')IZ&YA('-K
M86QA`$UE:W-I:V$`36EK<F]N97II:F$`4W)E9&EN80!4:7`@36EM90!.86IN
M:;YJ82!T96UP97)A='5R82!Z861N:FEH(#(T('5R.B``3F%J;FF^:F$@=&5M
M<&5R871U<F$@>F%D;FII:"`V('5R.B``6G)C86QI`%)A>FYO`$UA;FIK82!0
M14%2('!A:V5T($A45%!?4F5Q=65S="X`2V]N9FEG=7)A8VEJ82!M86YJ:V$N
M(,AE(+YE;&ET92!U<&]R86)L:F%T:2!T;R!A<&QI:V%C:6IO+"!J;R!M;W)A
M=&4@>F1A:B!G96YE<FER871I+@!-86YJ:V$@240@<W!O<F_H:6QA+@!-86YJ
M:V$@>F%H=&5V86X@4$5!4B!P86ME="!-86EL+@!-86YJ:V$@240@<V5J92X`
M4&\`36]B:6QN82!P;[ET80!:;65R;F\`1&%T=6T@<W!R96UE;6)E`%-P<F5M
M96YI`%-P<F5M96YI(%523`!-;V1U;&D`36]L9&%V:6IA`$UO;F%K;P!-;VYG
M;VQI:F$`365S96,@:6X@;&5T;P!-97-EZ&YO`$UO;G-E<F%T`$QU;FEN92!M
M96YE`$UA<F]K;P!0<F5T9;YN;R!J87-N;P!0<F5T9;YN;R!O8FQAZ&YO`%!R
M971EOFYO('-O;NAN;P!0<F5M86MN:0!0<F5M86MN:2!D;VP`4')E;6%K;FD@
M;&5V;P!0<F5M86MN:2!D97-N;P!0<F5M86MN:2!G;W(`4')E;6%K;FD@9&]L
M`%!R96UA:VYI('8@;6%P;P!0<F5M86MN:2!G;W(`36]Z86UB:6L`5F7H+6YI
M=F]J<VMI('-E>FYA;6D@>B!I>F)I<F\`5F7H9&5L;F\O86QT97)N871I=FYO
M`%9EZ&MR871N82!I>F)I<F$`36]J(')AZ'5N`$UO:B!P;W)T86P`3V)L:6MA
M(&UO:F5G82!P;W)T86QA`$UA:FYM87(`3D4L(&YE('-T<FEN:F%M('-E`$)%
M3$6N2T$`26UE`$EM92!I;B]A;&D@92UP;[ET82!N92!S;65T82!B:71I('!R
M87IN80!.86UB:6IA`$YA=7)U`%!O=')E8G5J92!U:W)E<`!.97!A;`!.:7IO
M>F5M<VMA`$YI>F]Z96US:VD@06YT:6QI`$]S;F]V;FD@3F5T<V-A<&4@55),
M`%523"!Z82!P<F5K;&EC('!O=')D:6QA($YE='-C87!E($-!`%523"!P;VQI
M=&EK92!.971S8V%P92!#00!54DP@>F$@;V)N;W9O('!O=')D:6QA($YE='-C
M87!E`%523"!Z82!P<F5K;&EC('!O=')D:6QA($YE='-C87!E`$EM92!S=')E
MOFYI:V$@3F5T<V-A<&4@4U-,`$MO;65N=&%R('!O=')D:6QA($YE='-C87!E
M`%9R<W1A('!O=')D:6QA($YE='-C87!E`$]M<F6^:F4`3FEK;VQI`$YI:V]L
M:2!N92!S:')A;FD@<')I<&]N:P!.;W8`3F]V82!+86QE9&]N:6IA`$YO=F$@
M:V%T96=O<FEJ80!.;W9A(&UA<&$`3F]V82!%+7!ON71A`$UL86H`3F]V;R!U
M<&]R86)N:;EK;R!I;64@*&]P8VEJ<VMO*0!.;W9A(%IE;&%N9&EJ80!.;W9A
M('-P;W)OZ&EL80!.;W9O(&]K;F\@*%]B;&%N:RD`3F]V:6-E`$YO=FGH:V%R
M<VME('-K=7!I;F4`3F%P<F5J`$YA<VQE9&YJ92!S<&]R;^AI;&\`3F%S;&5D
M;FIA('-T<F%N`$YA<VQE9&YJ92!M;[YN;W-T:0!.:6MA<F%G=F$`3FEG97(`
M3FEG97)I:F$`3F_H`$YI=64`3F4`3FD@<&]T<F1I;`!"<F5Z(+EI9G)I<F%N
M:F$`3FD@:VQJ=>AE=@!.:2!S<&]R;^AI;`!.;V)E;B!J879N:2!01U`@:VQJ
M=>@@;FD@8FEL('5V;[YE;BX`3FD@;W-E8FYI:"!P;W1R9&EL`$YI(&IA=FYI
M:"!K;&IUZ&5V`$YO8F5N(&IA=FYI(%,O34E-12!K;&IUZ"!N:2!B:6P@=79O
MOF5N+@!.:2!P<FEP;VYK+@!0;V1A=&MI(&MO;F9I9W5R86-I:F4@;FES;R!N
M82!V;VQJ;RP@<F%Z;&EK(&YI(&UO9V_H92!P;VMA>F%T:2X`3F$@=F]L:F\@
M;FD@;F]B96YE9V$@;F'H:6YA('IA(&EZ9&5L879O($E33R!P;W-N971K;W8N
M`%!R961L;V=A('!A:V5T82!N92!O8G-T86IA+@!.82"^96QJ96YE;2!P;VQO
MOF%J=2!B;&]K(&YE(&]B<W1A:F$`6F$@34-!3"!A=G1E;G1I:V%C:6IO(&YI
M(&)I;&\@<&]D871N;R!I;64@:V]L961A<FIA+@!"<F5Z('-P<F5M96UB92X`
M4&]D<F5J96YE('!R879I8V4@<V4@=&5J('!R879I8VD@;&%H:V\@9&]D86IO
M+@!);F9O<FUA8VEJ92!O(&MO;F9I9W5R86-I:FD@>F$@)7,@;FES;R!B:6QE
M('!O9&%N92X`26YF;W)M86-I:F4@;R!K;VYF:6=U<F%C:6II('IA($944"!6
M1E,@;FES;R!B:6QE('!O9&%N92X`26YF;W)M86-I:F4@;R!K;VYF:6=U<F%C
M:6II('IA(%-13"!61E,@;FES;R!B:6QE('!O9&%N92X`26YF;W)M86-I:F4@
M;R!K;VYF:6=U<F%C:6II('IA(%-13"U&:6QE(%9&4R!N:7-O(&)I;&4@<&]D
M86YE+@!+<F5D:71A(&YI('9EZ"X`1&5S=&EN86-I:F$@;FD@8FEL82!P;V1A
M;F$N`$1A=&]T96MA(&YI('!R96YEN65N86YA('-T<F6^;FEK`$YO8F5N82!M
M87!A(&YI(&EZ8G)A;F$N`$YO8F5N92!M87!E('-E(&YE('!R979E<FIA('IA
M(&YO=F\@<&^Y=&\N`$YO8F5N82!M87!A(&YI(&)I;&$@<&]D86YA`$YO8F5N
M82!M87!A(&YE('9S96)U:F4@;F]V:6@@<W!O<F_H:6P`3F]B96YA(&UA<&$@
M;F4@=G-E8G5J92!N979I9&5N:6@@<W!O<F_H:6P`26MO;B!N:2!M;V=OZ&4@
M;F%J=&DN`$QO:V%C:6IA(&YI(&YA<W1A=FQJ96YA+@!496QO('-P;W)OZ&EL
M82!N92!V<V5B=6IE(&)E<V5D:6QA`%-P;W)OZ&EL;R!N:2!B:6QO('!O9&%N
M;RX`3F]B96YO('-P;W)OZ&EL;R!S92!N92!U:F5M82!Z(&ES:V%N:6UI('!O
M9V]J:2X`26UE(&YI(&)I;&\@<&]D86YO+@"I=&5V:6QK82!N:2!B:6QA('!O
M9&%N82X`3F4@<')I:V%Z=6H@OF%L:FEV:6@@9F]R='5N92UO=@!'97-L;R!Z
M82!(5%10(&%V=&5N=&EK86-I:F\@;FD@8FEL;R!P;V1A;F\N`$=E<VQO('IA
M($E-05`@879T96YT:6MA8VEJ;R!N:2!B:6QO('!O9&%N;RX`1V5S;&\@>F$@
M2V5R8F5R;W,@879T96YT:6MA8VEJ;R!N:2!B:6QO('!O9&%N;RX`1V5S;&\@
M>F$@3&]G:6X@879T96YT:6MA8VEJ;R!N:2!B:6QO('!O9&%N;RX`1V5S;&\@
M>F$@4$%34U=$(&%V=&5N=&EK86-I:F\@;FD@8FEL;R!P;V1A;F\N`$=E<VQO
M('IA(%--0B!A=G1E;G1I:V%C:6IO(&YI(&)I;&\@<&]D86YO+@!0;W0@9&\@
M3W!E;E-33"!I>G9RN6EL;F4@9&%T;W1E:V4@;FD@8FEL82!P;V1A;F$N($QE
M+71A(&IE('!O=')E8FYA('IA(&1E;&\@<R!P;V1A=&MI(%!+0U,@,3(N`$YO
M8F5N('9P:7,@;F4@Z&%K82X`3F]B96X@;W-E8FYI(%IA<V5B;FD@4$=0(&ML
M:G7H(&YI(&)I;"!U=F^^96XN`$YO8F5N(&]S96)N:2!*879N:2!01U`@:VQJ
M=>@@;FD@8FEL('5V;[YE;BX`3F]B96YO(&]S96)N;R!3+TU)344@<&]T<F1I
M;&\@;FD@8FEL;R!U=F^^96YO+@!"<F5Z(.AR=`!"<F5Z('-T<F%N:6,`3F]B
M96X@<')O9W)A;2!Z82!P<F5V97)J86YJ92#H<FMO=F%N:F$@;FD@8FEL(&MO
M;F9I9W5R:7)A;BX`3FD@Z')K;W9A;&YI:"!N87!A:P!.:2!P<F5D;&]G;W8`
M3F$@=F]L:F\@;FD@>F'H87-N92!M87!E('IA(&-A8VAE+@!5<&]R86)N:6L@
M;FD@8FEL('!O9&%N+@!5<&]R86)N:;EK;R!I;64@:6XO86QI(&=E<VQO(&YI
M(&)I;&\@<&]S;&%N;RX`3FES;R!B:6QI('9R;FIE;FD@=F5L:F%V;FD@6$U,
M('!O9&%T:VD`0G)E>B!V<F5D;F]S=&D`5B!O<FEG:6YA;&YI(&MO;F9I9W5R
M86-I:FD@=F5R>FEJ82!N:2!N86ID96YA+B!:;F]V82!J;R!G96YE<FER86IT
M92X`5B!V8;EI(&MO;F9I9W5R86-I:FD@=F5R>FEJ82!N:2!N86ID96YA+B!:
M;F]V82!J;R!G96YE<FER86IT92X`3FD@=61E;&6^96YE8P!.;V)E;F5G80!"
M<F5Z("AU<&]R86)I(&EM<&QI8VET;F\I`$YO<F1I:G-K;R`H25-/+3@X-3DM
M,3`I`$YO<F9O;+EK:2!O=&]K`$YA=F%D;F$`4V5V97)N82!P;VQO8FQA`%-E
M=F5R;FD@36%R:6%N82!O=&]K:0!.;W)V9;EK80!.92!P;P!.92!P<F5D`$YI
M('!O8G)I<V%N;P!.:2!/<VYU=&5K`$YE<&]M96UB;F\`3FD@3W-E8FYO`$YI
M(&UA<&$`3FD@=F5L:F%V96X@:F%V;FD@:VQJ=>@N`$YI<V\@:7IB<FES86YA
M('-P;W)OZ&EL80!.:2!I;7!L96UE;G1I<F%N;RX`3FES;R!P;VUE;6)N82!S
M<&]R;^AI;&$`3FD@;F%S=&%V;&IE;@!.:2!P;V1P<G1O+@!$96IA;FIE(&QA
M:&MO('1R86IA(&1A;&H@Z&%S80!:87!I<VMI`$YIZ&5S87(@>F$@<')E8G)S
M:V%T:2P@=G)N:2!S92X`3F]V96UB97(`J71E=FEL;P"I=&5V:6QO('IN86MO
M=@"I=&5V:6QO('-T;VQP8V5V`*ET979I;"!M97-E8V5V('!R961E;B!P;V)R
M:;EE;2!S=&%R92!P<FEP;VYK92P@Z&4@:FEH(&)R:;EE;2!M97-EZ&YO+@"I
M=&5V:6P@;65S96-E=B!P<F5D96X@<&]B<FFY96T@;6%P92!S('!O<VQA;F\@
M<&^Y=&\L(.AE(&II:"!B<FFY96T@;65S9>AN;RX`J71E=FEL;R!V<G-T:6,`
MJ71E=FEL:V4@>F$@<&]S;V1O8FET978@<V5Z;F%M82!R87ID96QI='9E(&YI
M<V\@<&]D86YE+@!6(')E9'4`04Q)`$]B:F5K=`!4=F]R96,@;V)J96MT80!/
M:W1A;&YO`$]K=&]B97(`1FEL=&5R(+YA;&II=FL`4&ES87)N80!3=&%R82!S
M<&]R;^AI;&$`4W1A<F4@;6%P92!S('!O<VQA;F\@<&^Y=&\@<V4@8G)IN65J
M;RX`3VUA;@!386UO($E-05`@<W1R9;YN:6MI('!O9'!I<F%J;R!M87!E('8@
M<VMU<&YI(')A8FDN`%!R:6MAOF5M('-A;6\@;6%P92!Z(&YE<')E8G)A;FEM
M:2!S<&]R;^AI;&D_`%-A;6\@OF%L:FEV:2!F;W)T=6YE+6D`1&]V;VQJ96X@
M:F4@<V%M;R!E;B!E+7!ON71N:2!N87-L;W8N`%IA('1O(&1E:F%N:F4@:F4@
M;&%H:V\@:7IB<F%N82!S86UO(&5N82!M87!A+@!386UO(&QA<W1N:6L@86QI
M('-K<F)N:6L@<VES=&5M82!L86AK;R!S<')E;65N:2!L87-T;FFY='9O(&%L
M:2!L87-T;FEK82!P<F%V:6,@<VMU<&YE(')A8F4`3V1P<FD@=B!N;W9E;2!O
M:VYU`$]P96Y34TP@;F%P86MA.B!0;V1A=&MO=B!I>B!3+TU)344@<&]D<&ES
M86YE9V$@9&5L82!N:2!M;V=OZ&4@:7IV;&7H:2X`3V1P<G1A($UA<&$`3V1P
M<F4@=&\@<&]V97IA=F\@=B!N;W9E;2!O:VYU`$]P97)A8VEJ<VMI('-I<W1E
M;0!0;V=O:FYI('5D96QEOF5N96,`36^^;F]S=&D`36^^;F]S=&D@>F$@)7,`
M57)E:F5N('-E>FYA;0!/<F=A;FEZ86-I:F$`16YO=&$@;W)G86YI>F%C:6IE
M`$]R9V%N:7IA8VEJ80!/<FEG:6YA;&YA('!R961L;V=A(&%P;&EK86-I:F4`
M3W)I9VEN86QN92!P<F5D;&]G92!V("5S.@!$<G5G;P!$<G5G92!I;F9O<FUA
M8VEJ90!$<G5G:2!R8>AU;FD@>F$@12UP;[ET;P!$<G5G92!M;[YN;W-T:0!0
M<F%V:6-E(&QA<W1N:6MA`%!!32!A=G1E;G1I:V%C:6IA(&YI(&YA('9O;&IO
M+@!01U``4$=0(&1I9VET86QN:2!P;V1P:7,`4$=0(+EI9G)I<F%J('-P;W)O
MZ&EL;P!01U`@N6EF<FER86YI('!O9&%T:VD`4$=0($YA<&%K83H@`%!'4"!.
M87!A:V$Z(%!O=')E8G5J96T@9V5S;&\@>F$@;W-E8FYI('IA<V5B;FD@:VQJ
M=>@N`%!'4"!-;[YN;W-T:0!6<&ES(%!'4"!G97-L80!0;V1P;W)A(&]S96)N
M96UU('!A<G4@4$=0(&ML:G7H978@>F%H=&5V82!V87)N;R!S<&QE=&YO('!O
M=F5Z879O+@!01U`@:F%V;FD@:VQJ=>@`0F5S961I;&\@2F%V;F5G82!01U`@
M:VQJ=>AA`$IA=FYI(%!'4"!K;&IUZ"!Z82`B)7,@*"5S*2(@:F4@8FEL('5S
M<&6Y;F\@9&]D86XN`$IA=FYI(%!'4"!K;&IUZ"!Z82`B)7,B(&IE(&)I;"!U
M<W!EN6YO(&EZ8G)I<V%N+@!/8F5S96L@>B!J879N:6UI(%!'4"!K;&IUZ&D`
M4$=0(%!O9'!IN6D@<W!O<F_H:6QO`%!'4"!0;V1P:;EI+ZEI9G)I<F%J('-P
M;W)OZ&EL;P!01U`@<&]D<&ES86YI+[EI<F9I<F%N:2!P;V1A=&MI`%!'4"!Z
M87-E8FYI(&ML:G7H('5S<&6Y;F\@9&]D86XN`%!'4"!J879N:2!K;&IUZ"!U
M<W!EN6YO(&1O9&%N+@!0;V1P;W)A(%!'4"!J92!N82!T96T@<VES=&5M=2!O
M;F5M;V=OZ&5N82X`4$=0('!O9'!O<F$@=')E;G5T;F\@;FD@;VUO9V_H96YA
M+"!Z871O(&1I9VET86QN96=A('!O9'!I<V$@;FD@8FEL;R!M;V=OZ&4@;W9E
M<FET:2X`4$=0('!O9'!O<F$@=')E;G5T;F\@;FD@;VUO9V_H96YA+"!Z871O
M('-P;W)OZ&EL82!N:2!B:6QO(&UO9V_H92!D9;EI9G)I<F%T:2X`4$A0(&MO
M9&$`4$A0('5K87IN82!L=7!I;F$`4&]P;VQD86X@<F%H96P@9&6^`%!O<&]L
M9&%N<VME('!L;VAE`%!O<&]L9&%N<VME(&YE=FEH=&4`4$]0,P!03U`S("AS
M86UO9&5J;F\@>F%Z;F%J*0!03U`S('!R96MO(%-33`!03U`S('!R96MO(%-3
M3"`H<V%M;RUP;V1P:7-A;F\@<&]T<F1I;&\I`%!/4#,@<')E:V\@4U-,("AS
M86UO+7!O9'!I<V%N*0!03U`S+"!B<F5Z(%1,4P!07TA0('5K87IN82!L=7!I
M;F$`3V)R;V)A`%-T<F%N("5D(&]D("5D`%-T<F%N(',@<')V:6T@3F4M=FED
M96YI;2!S<&]R;^AI;&]M`%-T<F%N('H@>F%D;FII;2!.92UV:61E;FEM('-P
M;W)OZ&EL;VT`4&%K:7-T86X`4&%L874`4&%L97-T:6YS:V\@;WIE;6QJ90!0
M86YA;6$`4&%P=6$@3F]V82!'=FEN96IA`%!A<F%G=F%J`$1E;"AI*0!$96QN
M;R!O8FQAZ&YO`$=E<VQO`$=E<VQO("AP;VYO=FYO*0!'97-L;R!U<W!EN6YO
M(&]D<W1R86YJ96YO+@!'97-L;SH`1V5S;&\@;F4@<VUE(&)I=&D@<')A>FYO
M`$=E<VQI('-E(&YE('5J96UA=&$`1V5S;&\`3F5P<F%V:6QN;R!G97-L;P!'
M97-L;R!P;W1R96)N;R!Z82!2041)55,@879T96YT:6MA8VEJ;RX`1V5S;&\@
M<R!P;W1R9&EL;VT`1V5S;&\Z`$=E<VQO.B``1V5S;&D@<V4@;6]R871A('5J
M96UA=&DN`%!R:6QE<&D`4')I;&5P:2!Z(&]D;&^^:;GH80!0;W0`R&%K86IO
MZ&D@=G!I<VDZ`$QJ=61J90!/9'-T;W1E:P!)>G9E9&D@;W!E<F%C:6IE('9Z
M9'*^979A;FIA`$EZ=F5D96T@=GID<KYE=F%N:F4@;V(@<')I:F%V:3\`4')A
M=FEC80!!9&UI;FES=')A8VEJ82!P<F%V:6,`4')A=FEC('IA('1E9V$@=7!O
M<F%B;FEK82!N:2!M;V=OZ&4@<W!R96UI;FIA=&DN`$]S96)N;P!/<V5B;F4@
M26YF;W)M86-I:F4`3W-E8F5N('!A<B!01U`@:VQJ=>AE=B!U<W!EN6YO(&=E
M;F5R:7)A;BX`3W-E8F5N('!A<B!01U`@:VQJ=>AE=B!U<W!EN6YO(&EZ8G)I
M<V%N+@!/<V5B;F\@4R]-24U%('!O=')D:6QO($Y)($))3$\@=79OOF5N;SH@
M`$]S96)N:2!3+TU)344@:VQJ=>AI('5S<&6Y;F\@:7IB<FES86YI+@!097)U
M`$1O;6'H92"^:79A;&D`1FEL:7!I;FD`5&5L969O;@!&;W1O9W)A9FEJ90!0
M:71C86ER;@!0:6MS;&D`4')I:V&^96T@=F&Y('!O9'!I<R!P<F5D('!O<W)E
M9&]V86YI;6D@<W!O<F_H:6QI(&EN(&]D9V]V;W)I/P!3<&]R;^AI;&\@=B!N
M879A9&YE;2!B97-E9&EL=0!0;&%T:71U9&4`4')O<VEM(&ML:6MN:71E('8@
M8V5L:6-O`%!R;W-I;2!P;W1R9&ET92!O9'-T<F%N:71E=B!T96=A(&5L96UE
M;G1A.@!0<F]S:6T@<&]T<F1I=&4@;V1S=&%N:71E=B!P;W9E>F%V92!E;&5M
M96YT83H`4')O<VEM('9P:;EI=&4@;65S96,@:6X@;&5T;RX`4')O<VEM('9P
M:;EI=&4@:6UE('IA(&YO=F\@:V%T96=O<FEJ;SH`4')O<VEM('9P:;EI=&4@
M:6UE('IA(&YO=F\@;6%P;SH`4')O<VEM('9P:;EI=&4@=F5L:F%V96X@25`@
M;F%S;&]V+@!0<F]S:6T@=G!IN6ET92!V96QJ879E;B!D871U;2P@<')E=F5R
M:71E(+ET979I;&\@9&YI('8@;65S96-U+@!0<F]S:6T@=G!IN6ET92!V96QJ
M879E;B#H87,N`%!R;W-I;2!V<&FY:71E(&EM92!N;W9E(&UA<&4Z`%!R;W-I
M;2!V<&FY:71E(&YO=F\@:6UE.@!0<F]S:6T@=G!IN6ET92!G97-L;R!Z82!V
M8;D@>F%S96)N:2!01U`@:VQJ=>@N(%1O(&=E<VQO(&)O<W1E(&UO<F%L:2!V
M<&ES871I('-A;6\@96YK<F%T('8@=G-A:VD@)7,@<V5J:2X`4')O<VEM('9P
M:;EI=&4@9V5S;&\@>F$@=F&Y(%,O34E-12!Z87-E8FYI(&ML:G7H+B!4;R!G
M97-L;R!B;W-T92!M;W)A;&D@=G!I<V%T:2!S86UO(&5N:W)A="!V('9S86MI
M("5S('-E:FDN`%IA(&YA9&%L:F5V86YJ92!S97-T879L:F%N:F$@=F&Y96=A
M('-P;W)OZ&EL82!S92!P<F]S:6T@<&]N;W9N;R!P<FEJ879I=&4N(,AE(&YE
M('5P;W)A8FQJ871E('!IN6MO=&MO=B!)3B#H92!S97-T879L:F%T92!S<&]R
M;^AI;&$@=B!P;W!U<"!O:VYI:"P@<V4@8F]S=&4@;6]R86QI('!O;F]V;F\@
M<')I:F%V:71I('1U9&D@=B!V8;EE;2!G;&%V;F5M(&]K;G4N(%1I('5K<F5P
M:2!S;R!Z871O+"!D82!B:2!N87!A9&%L8V5M('!R97!R9>AI;&D@=6=R86)I
M=&5V($E$('-E:F4N($]P<F%V:>AU:F5M;R!S92!Z82!N97!R:6IE=&YO<W0N
M`%!R;W-I;2!V<&FY:71E('!O=GIE=&5K('!R;V)L96UA+@!0<F]S:6T@=G!I
MN6ET92!S=F]J92!G97-L;RX`4')O<VEM('9P:;EI=&4@=F&Y92!U<&]R86)N
M:;EK;R!I;64@:6X@9V5S;&\`4')O<VEM('9P:;EI=&4@<W9O:F4@=7!O<F%B
M;FFY:V\@:6UE+@!0<F]S:6T@<&]P<F%V:71E(&1V;W5M;F4@86QI(&YE=F5L
M:F%V;F4@;F%S;&]V92X`4')O<VEM('!O9VQE:G1E(&YA<VQE9&YJ92!I;F9O
M<FUA8VEJ92!I;B!I>F)E<FET92!D96IA;FIE(&EZ('-P;V1N:F5G82!M96YU
M:F$N`%!R;W-I;2!I>F)E<FET92!M87!O+"!P<F5D96X@:7IB97)I=&4@9&5J
M86YJ92X`4')O<VEM(&EZ8F5R:71E(&1E:F%N:F4@:7H@<W!O9&YJ96=A(&UE
M;G5J82X`6F$@:7-K86YJ92!I>F)E<FET92!V<V%J(&5N;R!M87!O+@!:82!T
M;R!O<')E86-I:F\@<')O<VEM(&EZ8F5R:71E('-M86\@96YO(&UA<&\N`%!R
M;W-I;2!I>F)E<FET92!A;&D@=7)E9&ET92!V(&]B<F%Z8W4@;F$@9&5S;FDZ
M`%!R;W-I;2!V<&FY:71E(&EM92!N;W9E(&MA=&5G;W)I:F4Z`%!O;&IS:V$`
M4&]L:71I:V$`06YK971E`%!O<G1U9V%L<VMA`%!O<W1A=FET978@<VQI:V4`
M4&]S=&%V:71E=B!T86)E;&4`4VAR86YI('8@=&\@;6%P;R`H24U!4"!T96=A
M(&YE('IA:'1E=F$I`%!O=V5R960@8GD@2&]R9&4`4')E9'!IN65M('9AN2!P
M;V1P:7,@<R!P;VUIN6QJ86II("@G+2T@)RD_`$MO;&GH:6YA('!A9&%V:6X@
M=B!Z861N:FEH("5S('5R86@Z(`!.87-T879I='9E('5S<&6Y;F\@<&]S;V1O
M8FQJ96YE+@!0<F5F<U]L9&%P.B!0;W1R96)E;B!,1$%0(&1O9&%T96L@;FD@
M;F%J9&5N+@!0<F5F<U]S97-S:6]N.B!0;W1R96)E;B!S97-S:6]N(&1O9&%T
M96L@;FD@;F%J9&5N+@!0<FET:7-K`%!R:71I<VL@;F$@;6]R<VMI('9IN6EN
M:3H@`%!R:71I<VLZ(`!0<F5D;V=L960`4')E9&]G;&5D('-L:6ME('8@;F]V
M96T@;VMN=0!0<F5JN6YJ92!S<&]R;^AI;&\`4')E:KEN:F$@<W1R86X`4')E
M:KEN:F4@;6^^;F]S=&D`3F%T:7-N:0!.871I<VYI(&1O:W5M96YT`%!R:6]R
M:71E=&$`6F%S96)N:2!K;&IUZ`!'97-L;R!Z87-E8FYE9V$@:VQJ=>AA`%!R
M;V)L96T`3W!I<R!P<F]B;&5M80!0<F]J96MT:0!6<')AN6%M('9S86MIZ"!K
M;R!J92!P;W-L86YA('!R:7!O;FMA.R!P<FEV>F5T;R!J92!.10!6<')AN6%M
M('9S86MIZ"!K;R!J92!P;W-L86YA('!R:7!O;FMA.R!P<FEV>F5T;R!J92!$
M00!"97-E9&EL;R!P;WII=FYI:V$`4')O=&]K;VPZ`$IA=FYI(&ML:G7H`$%L
M9V]R:71E;2!J879N96=A(&ML:G7H80!0;V1P;W)A(&IA=FYE;74@4$=0('-T
M<F6^;FEK=2!J92!B:6QA(&]N96UO9V_H96YA+@!'96YE<FER86YJ92!P87)A
M($IA=FYI+UIA<V5B;FD@:VQJ=>@@;FD@=7-P96QO+@!0;W)T;W)I:V\`27IB
M7W)IN6D@27IB<FES86YA`$EZ8G)IN6D@27IB<FES86YA`$EZ8G)IN6D@:7IB
M<FES86YA('-P;W)OZ&EL82!I>B!M87``2V%K;R!P;V=O<W1O(&EZ8G)IN65M
M(%-M971I.@!0;V)R:;EE;2!S<&]R;^AI;&$@:7H@4VUE=&DL(&MI('-O('-T
M87)E:KEA(&]D.@!0;V)R:;EE;2!S=&%R82!S<&]R;^AI;&$@:7H@4VUE=&D_
M`%%A=&%R`%!O:7IV961B80!3=&%N:F4@:W9O=&4Z("4N,F9-0B`O("4N,F9-
M0B`@*"4N,F8E)2D`4W1A;FIE(&MV;W1E.B`E+C)F34(@+R!.22!/345*2516
M10!3=&%N:F4@:W9O=&4Z($Y)($]-14I)5%9%`%)302!J879N:2!K;&IUZ"`H
M)2!B:71E;BD`27IB:7)A`$1EO@!$9;X@>F=O9&%J`$1EOB!P;WIN;P!$9;YE
M=FYA('!L;VAA`$YA:VQJ=>AE;B!F;W)T=6YE`%)A>FUE<FIE`%IA:'1E7W9A
M;2!P;W1R9&ET978@9&]S=&%V90!0<F5B97)I`%!R96)E<FD@<W!O<F_H:6QA
M`%)E<R!P;V)R:;EE;2`E<S\@3W!E<F%C:6IE(&YI(&UO9V_H92!R87IV96QJ
M879I=&DN`%)E<R!O9'-T<F%N:6T@=7!O<F%B;FEK;W9E('!O9&%T:V4@>F$@
M)7,_($]P97)A8VEJ92!N:2!M;V=OZ&4@<F%Z=F5L:F%V:71I+@!0<F5J971O
M(&YA`%!R96IE=&\@;V0`4')E:F5T;R!D;P!0<F5?=7-M97)I`%!R975S;65R
M:0!0<F5U<VUE<FD@<W!O<F_H:6QO`%!R975S;65R:2!T;R!S<&]R;^AI;&\`
M4')E=7-M97)I=&5V('-P;V1L971E;&$N`%!O;F]V;F\@:7IV961I('IA9&YJ
M92!D96IA;FIE`$]S=F6^:0!/<W9EOFD@9&EN86UIZ&YE(&5L96UE;G1E(&UE
M;G5J83H`3W-V9;YI('!O9VQE9"!M87`Z`$]S=F6^:2!P;V=L960@<&]R=&%L
M83H`4F5G97@`0G)S:V%L;FEK(&]D;F]S;W8`4&]N;W9N;R!N86QOOFD`3W-V
M9;YI('!O9VQE9`!0<FEP;VUB90!:87!O;6YI('-I(&EN9F]R;6%C:6IO('!R
M;W-T+WIA<V5D96XN`%IA<&]M;FD@<VD@>F%D;FII('!O9VQE9`!/9&1A;&IE
M;B!.86)I<F%L;FEK.@!/9&1A;&IE;FD@<W1R9;YN:6MI`$]D9&%L:F5N(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$]D<W1R86YI`$]D
M<W1R86YI(&)L;VL`3V1S=')A;FD@<&]L:F4@:7H@:7-K86YJ80!/9'-T<F%N
M:2!S=&]L<&5C`$]D<W1R86YI(&]B;&EK;W9A;FIE`$]D<W1R86YI('!A<@!/
M9'-T<F%N:2!S:')A;FIE;F\@<VMR:7!T;R!I>B!S=')EOFYI:V]V92!Z8>AA
M<VYE(&UA<&4N`$]D<W1R86YI(&EZ=F]R;F\@:V]D;P!/9'-T<F%N:0!/9'-T
M<F%N:2!T;R!V;WIL:;GH92!I>B!D;VMU;65N=&$`3V1S=')A;FD@=7!O<F%B
M;FEK80!/9'-T<F%N:2!U<&]R86)N:6MA.B`E<P!0<F5I;65N=6H@;6%P;RAE
M*0!0<F5I;65N=6IE;2!M87!O(',@<&]S;&%N;R!P;[ET;R!N82!Z8>AE=&MU
M(&UE<V5C83\`4')E:6UE;F]V86YJ92`B)7,B('8@(B5S(B!N:2!U<W!E;&\N
M(%-T<F6^;FEK(&IE(&IA=FEL`$]?9&=O=F]R:2!N82!,:7-T;P!:86UE;FIA
M:B!Z.@!/9&=O=F]R:0!/9&=O=F]R('!O<VQA;BX`3V1G;W9O<FD@=G-E;0!/
M9&=O=F]R:2!V<V5M.@!/9&=O=F]R:2!N82!,:7-T;P!/9&=O=F]R:2!N82!,
M:7-T;SH`3V1G;W9O<FD@=E]S96T`3V1G;W9O<FD@<R!S<&]R;^AI;&]M($YI
M('!O9'!R=&\`3V1G;W9O<FD@>B!I;F9O<FUA8VEJ;R!P<F]S="]Z87-E9&5N
M('IA(&YA<VQE9&YJ92`R(&UE<V5C82X`3V1G;W9O<FD@>B!Z86AT979A;F\@
M:6YF;W)M86-I:F\@<')O<W0O>F%S961E;BX`3V1G;W9O<FDM3F$`3V1G;W9O
M<FDM3F$Z`$]D9V]V;W)I.@!0<FEJ879I(&MO="!:8;YE;&5N;P!0<FEJ879I
M(&MO="!.97IAOF5L96YO`%IA:'1E=F%J('!O=')D:6QO(&\@7U!R96IE;74`
M3F$@>F%H=&5V;R!N:2!B:6QO(&UO9V_H92!O9&=O=F]R:71I+B!.87!A:V$Z
M(`!:86AT979A;2!P;W1R9&EL;R!O(&1O<W1A=FD_`%IA:'1E=F%M('!O=')D
M:6QA(&\@<')E:F5M=3\`6F%H=&5V86YO('-P;W)OZ&EL;R!N:2!B:6QO(&YA
M:F1E;F\N`%!O=')E8F5N('5D96QEOF5N96,`4&]N87-T879I`%!O;F%S=&%V
M:2!G97-L;P!0;VYA<W1A=FET92!V8;EE(&=E<VQO`%-T86YJ92!D;W!I<VYI
M:V$@<&]S;V1O8FQJ96YO+@!297IU;'1A=&D`3F%D86QJ=6H`3F%D86QJ=6H@
M<V5J;P!6<FYI('-E(&YA($9E=&-H($UA:6P`3F%Z86H@;F$@;6^^;F]S=&D`
M4V4@=G)N96T@;F$@<V5Z;F%M(&YA8FER86QN:6MA('!O(&)R:7-A;FIU+"!P
M<F5M:6MA;FIU(&%L:2!K;W!I<F%N:G4@<W!O<F_H:6QA/P!2975N:6]N`$]B
M;F]V:2!P<F5JN6YJ92!N87-T879I='9E`$UOOFYO<W1I('5R96IE=F%L;FEK
M82!O8F]G871E;F5G82!B97-E9&EL80!59V%N:V4`1&5S;F\`1&5S;F$@9VQA
M=F$`1&5S;F4@=G)E9&YO<W1I`$QA<U]T;F]S=&D@=G)S=&EC90!6;&]G80!2
M;VUU;FEJ80!:87-UZ&D@>F$@,3@P`%IA<W7H:2!L979O`%IA<W7H:2!D97-N
M;P!,87-T;F]S=&D@=G)S=&EC90!,87-T;F]S=&D@=G)S=&EC90!6<G-T:6-E
M.@#(<G1E`,AR=&4@8F]D;R!P<FEK87IA;F4@;65D('9S96UI('9R<W1I8V%M
M:2!I;B!S=&]L<&-I`,AR=&4@8F]D;R!P<FEK87IA;F4@<V%M;R!M960@<W1O
M;'!C:0#(<G1E(&)O9&\@<')I:V%Z86YE('-A;6\@;65D('9R<W1I8V%M:0!0
M;[YE;FD`4G5S:6IA`%)U86YD80!3+TU)344`4R]-24U%(&MR:7!T;V=R869S
M:VD@<&]D<&ES`*EI9G)I<F%J('-P;W)OZ&EL;R!S(%,O34E-10!3+TU)344@
MN6EF<FER86YO('-P;W)OZ&EL;P!3+TU)344@3F%P86MA.B``4R]-24U%($YA
M<&%K83H@6F$@;W-E8FYI('IA<V5B;FD@:VQJ=>@@:F4@<&]T<F5B;F\@9V5S
M;&\N`%,O34E-12!-;[YN;W-T:0!6;F]S(%,O34E-12!G97-L80!3+TU)344@
M>F%S96)N:2!P87(@:VQJ=>AE=B!Z86AT979A('9A<FYO('-P;&5T;F\@<&]V
M97IA=F\N`%,O34E-12!J879N:2!K;&IUZ"!Z82`B)7,B('5S<&6Y;F\@:7IB
M<FES86XN`%,O34E-12!J879N:2!K;&IUZ"!U<W!EN6YO(&1O9&%N+@!3+TU)
M344@;V)E<V5K('IA(&IA=FYE(&ML:G7H90!3+TU)344@2F%V;FDO6F%S96)N
M:2!P87(@:VQJ=>AE=B!U<W!EN6YO(&1O9&%N+@!0;V1P:;EI('-P;W)OZ&EL
M;R!S(%,O34E-10!0;V1P:;EI+ZEI9G)I<F%J('-P;W)OZ&EL;R!S(%,O34E-
M10!0;V1P;W)A(%,O34E-12!J92!N82!T96T@<VES=&5M=2!O;F5M;V=OZ&5N
M82X`4&]D<&]R82!3+TU)344@=')E;G5T;F\@;FD@;VUO9V_H96YA+"!Z871O
M('-P;W)OZ&EL82!N:2!B:6QO(&UO9V_H92!D9;EI9G)I<F%T:2X`4&]D<&]R
M82!3+TU)344@;FD@;VUO9V_H96YA+"!Z871O('9S96)I;F4@=&5G82!P;V1P
M:7-A;F5G82!S<&]R;^AI;&$@;FD@;6]G;^AE('!R:6MA>F%T:2X`4&]D<&]R
M82!3+TU)344@;FD@;VUO9V_H96YA+"!Z871O('1E9V$@9&EG:71A;&YE9V$@
M<&]D<&ES82!N:2!M;V=OZ&4@;W9E<FET:2X`4T%33"!O=F5R:F%N:F4@;FD@
M;F$@=F]L:F\N`%--4R!S<&]R;^AA;FIE`%-13"!L=7!I;F$`4U-(`%534$5,
M3P!37U%,(&QU<&EN80!:861E7W9A`%-O`%-H<F%?;FD@:V]P:6IO('8`4VAR
M85]N:2!K;W0`4W8N($AE;&5N80!386EN="!+:71T<R!I;B!.979I<P!386EN
M="!,=6-I80!386EN="!0:65R<F4@:6X@36EQ=65L;VX`4V%I;G0@5FEN8V5N
M="!I;B!'<F5N861I;F4`27-T:2!O:W9I<B`H7W-E;&8I`%-A;6]A`%-A;B!-
M87)I;F\`4V%O(%1O;64@:6X@4')I;F-I<&4`4&]N=61N:6L@<V%T96QI='-K
M96=A(&1O<W1O<&$`4V%U9&]V82!!<F%B:6IA`%-H<F%N:0!3:')A;FD@)7,`
M4VAR86YI;2!0<FEP;VYK92!S:W5P86H@<R!S<&]R;^AI;&]M(&UE9"!P;W-L
M86YO('!ON71O/P!3:')A;FD@3W-N=71E:P!3:')A;FD@36^^;F]S=&D`4VAR
M86YI(%]/<VYU=&5K`%-H<F%N:2!K;W0`4VAR86YI;2!O<VYU=&ME(&MO="!N
M979I9&5N93\`4VAR86YI(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;R!K;W0@
M4$A0('-K<FEP=&\@=B!Z8>AA<VYO(&UA<&\@;F$@=F&Y96T@<W1R9;YN:6MU
M+@!!=G1O;6%T:>AN;R!S:')A;FEM('!R96IE;6YI:V4@=B!P<FEV>F5T(&%D
M<F5S87(_`%-H<F%N:6T@:7-K86YJ92!K;W0@;F%V:61E>FYO(&UA<&\_`%-H
M<F%N:6T@<&]S;&%N;R!P;[ET;S\`2V]N9FEG=7)A8VEJ82`E<R!S:')A;FIE
M;F$N`%-H<F%N:F5V86YJ92!O<VYU=&MA('-P;V1L971E;&\N(%-T<F6^;FEK
M(&IE(&IA=FEL.B`E<P!:;F%N;W-T`$FYZ&D`2;GH:2`E<P!)<VMA;&YA(&]R
M;V1J80!297IU;'1A=&D@27-K86YJ80!6:61E;F$`27IB97)I`$EZ8F5R:2!D
M<G5G(')AZ'5N`$EZ8F5R:71E(&1A=&]T96ME`$EZ8F5R:2!D871U;0!)>F)E
M<FD@<&]L:F4`27IB97)I=&4@<VMU<&EN;R!K:2!J;R"^96QI=&4@9&]D871I
M`$EZ8F5R:71E(&YO=F5G82!L87-T;FEK80!)>F)E<FET92!S=')EOFYI:P!)
M>F)E<FET92!U<&]R86)N:6MA(&MI(&=A(+YE;&ET92!D;V1A=&D`27IB97)I
M=&4@061R97-A<FIE('IA(&1O9&%J86YJ92!I;B!I<VMA;FIE(&YA<VQO=F]V
M`$EZ8F5R:2!V<V4`27IB97)I('9S92!D871U;7-K92!K;VUP;VYE;G1E+@!)
M>F)E<FD@=G-A('!O;&IA('IA(&ES:V%N:F4L(&MO(')A>KEI<FIAN2!N87-L
M;W9E`$EZ8F5R:2!R8>AU;@!)>F)E<FD@;V)J96MT`$YE(&EZ8F5R:2!N;V)E
M;F4`27IB97)I=&4@>FYA:V4L(&MI(&II:"!P;W1R96)U:F5T92!I>B!S<&]D
M;FII:"!P;VQJ+B!.871O(&II:"!L86AK;R!K;W!I<F%T92!I;B!P<FEL97!I
M=&4@:7H@;V)R87IC82X`27IB97)I(')A>FUE:FET978@>F$@9&%T=6TZ`$EZ
M8F5R:2!O8FQI:V\@>F%P:7-A(&1A='5M83H`27IB97)I=&4@:61E;G1I=&5T
M;RP@:VD@:F\@OF5L:71E('-P<F5M96YI=&DZ`$EZ8F5R:71E('9R<W1O('!O
MN71N96=A('-T<F6^;FEK80!)>F)E<FET92!R87IM96II=&5V('IA(.AA<SH`
M27IB97)I=&4@;V)L:6MO('IA<&ES82!Z82#H87,Z`$EZ8F5R:71E(&1V92!U
M:F5M86IAZ&D@<&]L:FDN`$EZ8F5R:71E('-V;VIO(&)A<G9N;R!S:&5M;RX`
M27IB97)I=&4@OF5L:F5N(&IE>FEK.@!)>F)R86YI($%D<F5S87)J:3H`4&^Y
M;&II($ML:G7H(&YA(&IA=FYI('-T<F6^;FEK(',@:VQJ=>AI`%!ON6QJ:2!N
M86IN;W9E:KEE(&EN9F]R;6%C:6IE`%!ON6QJ:2!S<&]R;^AI;&\`4&^Y;&II
M('!O<F_H:6QO(&\@;F%P86MI`%!ON6QJ:2!335,`4V5N96=A;`!396YZ;W(Z
M(`!-87!A(',@<&]S;&%N;R!P;[ET;P!-87!A(',@<&]S;&%N;R!P;[ET;SH`
M4V5P=&5M8F5R`%-R8FEJ82!I;B#(<FYA($=O<F$`4V5R:6IS:V$@N71E=FEL
M:V$`4W1R9;YN:6L`26YF;W)M86-I:F4@;R!3=')EOFYI:VEH(&EN($UA<&%H
M`%-T<F6^;FEK.@!)1"!S96IE(&IE('!O=&5K;&$N`$YA<W1A=FD`3F%S=&%V
M:2!M;[YN;W-T:2!Z82!P;VYA<W1A=FET978@9V5S;&$L('8@<')I;65R=2!D
M82!G82!P;WIA8FET92X`3F%S=&%V:2!K86H@<V4@>F=O9&DL(&MO('!R96UI
M:V%T92!A;&D@8G)IN65T92!S<&]R;^AI;&$N`$YA<W1A=FD@=G)S=&EC;R!G
M;&%V92!8+5!R:6]R:71Y('!R:2!S97-T879L:F%N:G4@<W!O<F_H:6P_`$YA
M<W1A=FD@;V1D86QJ96YE('-T<F6^;FEK92P@9&\@:V%T97)I:""^96QI=&4@
M9&]S=&]P871I(',@<&]R=&%L82X`3F%S=&%V:2"^96QJ96X@:F5Z:6LL(.AA
M<V]V;FD@<&%S(&EN('!R:6MA>B!D871U;6$N`$YA<W1A=FD@>F'H971N;R!A
M<&QI:V%C:6IO+"!B87)V;F\@<VAE;6\L(&]S=F6^979A;FIE('-T<F%N:2P@
M:6X@;W-T86QE(&UOOFYO<W1I('!R:6MA>F$N`$YA;65S=&ET978@<VMR:7!T
M('IA('!O<V]D;V)I=&5V(&IE(&YA('9O;&IO`%!O9&%N:6T@<&%R86UE=')O
M;2!U<W1R97IA('9EZ"!L;VMA8VEJ.B``4V5JN65L:0!3:W5P;F$@<F%B82!-
M87``4VMU<&YA(')A8F$@;6%P`$]M;V=OZ&ET92!S:W5P;F\@<F%B;R!S=F]J
M:6@@<&^Y=&YI:"!M87`N`$YA:W5P;W9A;FIE`$MR871E:R!P;W9Z971E:P!.
M87-T879I;2!B;&F^;FII8V4@>F$@=F7H:6YO('!O=F5Z878_`$YA:B!B;V1O
M('9E;&EK:2!O9'-E:VD@8VET:7)A;F5G82!B97-E9&EL82!P<FEV>F5T;R!P
M<FEK87IA;FD@86QI('-K<FET:3\@3F%S=&%V:71E=B!J92!M;V=OZ&4@<')E
M<')O<W1O('!R96ML87!L:F%T:2X`3F%J('8@=&5L97-U('1E>'0O<&QA:6X@
M<W!O<F_H:6P@:;GH96T@4$=0('!O9&%T:V4_`$YA:B!S92!P;R!S:')A;FIE
M=F%N:G4@<W!O<F_H:6QA(&UE9"!O<VYU=&ME(&]K;F\@>F$@<V5S=&%V;&IA
M;FIE('IA<')E/P!.86H@<V4@=F&Y(&IA=FYI(%!'4"!K;&IUZ"!P<FEV>F5T
M;R!P<FEP;F4@<W!O<F_H:6QO;3\`4')I:V&^:0!0<FEK8;YI('9S92!M87!E
M`%!R:6MAOFD@=G-E('9R<W1I8V4@9VQA=F4`4')I:V&^:2!P;V)R:7-A;F4`
M4VMR86JY86X@<')I:V%Z('9R<W1I8R!G;&%V90!0<FEK8;YI('!O9&%T:V4@
M;R!M86EL:6YG+6QI<W1I`%!R:6MAOFD@<V%M;R!N87)OZ&5N92!M87!E`%!R
M:6MAOFD@3F5N87)OZ&5N90!0<FEK8;YE;2!I:V]N;RP@:VD@9&]V;VQJ=6IE
M(&)R:7-A;FIE('!R:7!O;FL@:7H@<W!O<F_H:6P_`%!R:6MAOFD@<F%Z;&EK
M92!M960@=')E;G5T;F\@<VAR86YJ96YO(&EN(&YO=F\@9V5N97)I<F%N;R!K
M;VYF:6=U<F%C:6IO+@!0<FEK8;YE;2#H87,@>F%D;FIE('!R:6IA=F4@;V(@
M<')I:F%V;&IA;FIU/P!0<FEK8;YE;2!L96=E;F1O('8@<&]G;&5D=2!N86)I
M<F%L;FEK83\`4')I:V&^:2!M;[YN;W-T('IA(&]H<F%N:71E=B!O<FEG:6YA
M;&$`4&]K8;YI(&]R;V1J92!Z82!I>F)I<F\`4')I:V&^96T@<')E9&]G;&5D
M('-A;6\@>F$@;F5P<F5B<F%N82!S<&]R;^AI;&$_`%!R:6MAOF5M('!R961O
M9VQE9&4@;V(@<')E:&]D=2!M:;EK93\`4')I:V&^96T@;65N=2!Z82!U<F5J
M86YJ92!T86)E;&4_`%!R:6MAOF5M("5S($UE;G4@;F$@;&5V:3\`4')I:V&^
M96T@:6MO;F\@1F5T8V@@36%I;#\`4&]K8;YI(%-L:6ME`%!R:6MAOFD@<&]G
M;W9O<FYO(&]K;F\@3&%S=&YO<W1I(&-E;&EC92!T86)E;&4`4')I:V&^:2!P
M;V=O=F]R;F\@;VMN;R!,87-T;F]S=&D@=&%B96QE`%!R:6MAOFD@<&]G;W9O
M<FYO(&]K;F\@3&%S=&YO<W1I('9R<W1I8V4@=&%B96QE`%!R:6MAOF5M(&EK
M;VYO($9I;'1E<C\`4')I:V&^:2!P;V=O=F]R;F\@;VMN;R!,87-T;F]S=&D@
M<VQI:V4`4')I:V&^96T@<VMU<&YO(+ET979I;&\@<W!O<F_H:6P@=B!M87!I
M/P!0<FEK8;YI('-H<F%N:F5V86YJ92!N82!S=')EOFYI:P!0;&]H90!0;&]H
M92!Z9V]D86H`4&QO:&4@<&]Z;F\`4')I:V%Z86YO`%-K<NAI`$YA:G!R96H@
M<VMRZ&D@86QI(&]D;6%K;FD@<V]S961N:F4@8FQO:V4`5F5L:6MO7W-T`%-I
M97)R82!,96]N90!0<FEJ879A`%!O9'!I<P!!;&=O<FET96T@<&]D<&ES80!0
M;V1P:7-A;F\`4VEN9V%P=7(`5F5L:6MO<W0`4')E<VMOZ&D@=GID<KYE=F%N
M:F4`4VQO=F&Y:V$`4VQO=F5N:6IA`%-N96<`4VYEOFYA('!L;VAA`%-N9;YN
M92!P;&]H90!3;F6^;F4@<&QO:&4@<&]Z;F\`1&5B96QI;F$@<VYEOFYE(&]D
M96IE.B``16YA:V$@:V]L:>AI;F$@=F]D93H@`%-A;&]M;VYO=FD@;W1O:VD`
M4V]M86QI:F$`4&5S;6D@)B!0;V5Z:6IA`%)A>G9R<W1I('!O(%!R:6AO9'4`
M4F%Z=G)S=&D@<&\@1&%T=6UU`%)A>G9R<W1I('!O($]D(&YA<VQO=G4`4F%Z
M=G)S=&D@<&\@5F5L:6MO<W1I('-P;W)OZ&EL80!287IV<G-T:2!P;R!:861E
M=FD`4F%Z=G)S=&D@<&\@4&]G;W9O<G4`4F%Z=G)S=&D@<&\@6F$@;F%S;&]V
M=0!287IV<G-T:2!I>F)R86YO`$EZ=F]R;FD@;F%S;&]V`$IUOFYA($%F<FEK
M80!*=;YN;R!%=G)O<'-K;R`H25-/+3@X-3DM,RD`2G6^;F$@1V5O<F=I82!I
M;B!*=;YN:2!386YD=VEC:"!O=&]K:0!*=;YN82!P;VQO8FQA`%!R;W-T;W(@
M;65D('-O<V5D;FII;6$@8V5L:6-A;6$`4')O<W1O<B!M960@=G-E8FEN;R!I
M;B!R;V)O;2!C96QI8V4`4')E<VQE9&YI:P!287IM86L`4F%Z;6%K:2!I;B!O
M9&UI:VD`J7!A;FEJ80!3<&%M`$UA<&$@>B!N97IAOF5L96YO('!ON71O.@!6
M;F]S('!O<V5B;FEH('IN86MO=@!0;W-E8FYI('IN86MI`%!R979E<FD@Z')K
M;W9A;FIE`,AR:V]V86YJ90!0<F5V97)J86YJ92#H<FMO=F%N:F$@:V]NZ&%N
M;P#(<FMO=F%L;FEH(&YA<&%K(&YA('IA<VQO;B!P<FD@<')E9VQE9&]V86YJ
M=2#H<FMO=F%N:F$N`%)A>F1E;&D@8V5L:6-O`%)A>F1E;&D@<W1O;'!E8P!2
M87ID96QI('9R<W1I8V\`J7!O<G0`J7)I;&%N:V$`4W1A;F1A<F0`6G9E>F1N
M92!S=&5Z90!:8>AN:0!,971O('IAZ&5T:V$`1'*^879A(&%L:2!P<F]V:6YC
M80!3=&%N:F4`3V)L:6MA('-H<F%N:F5V86YJ80!.87-L;W8`4')EZ')T86YO
M`%-E>FYA;2!B97-E9&EL80!/9'-T<F%N:2!0<FEP;VYK;P!/9'-T<F%N:2!D
M;VUE;F\@:7H@;F%S;&]V80!/9'-T<F%N:6T@<')E;&]M92!V<G-T:6,_`%-T
M:6P@6T-34UT`3F4`6F%D95]V80!:861E=F$`4&]L:F4@>B!:861E=F\`4&^Y
M;&II`$YA<F_H:2!S92!N82!-87!O*&4I`%!O9'!I<V%N;P!5<W!E;&\`57-P
M9;EN;R!P;W9R;FEL(&YA<W1A=FET=F4N(%!O;F]V;F\@;F%L;[YI=&4@<W1R
M86XN`%5S<&6Y;F\@<VAR86YI;"!V87)N;W-T;F\@:V]P:6IO(&MO;F9I9W5R
M86-I:F4N`%5S<&6Y;F\@>F%P:7-A;"`E<P!3=61A;@!0<F5D;&]G:0!0;W9Z
M971E:P!3;V[H;FD@=GIH;V0`4V]NZ&YI('IA:&]D`%-O;NAN;P!3;V[H;FD@
M=GIH;V0`4V]NZ&YI('9Z:&]D+WIA:&]D`%-O;NAN:2!V>FAO9#H@`%-O;NAN
M:2!Z86AO9`!3;V[H;FD@>F%H;V0Z`$YA9'!I<V%N;P!0;V1P;W)A`%-U<FEN
M86T`4')I:6UE:P!3=F%L8F%R9"!I;B!*86X@36%Y96X`4W9A>FD`J79E9'-K
M80!0<F5K;&]P(&UE9"!N8>AI;F]M('-E<W1A=FQJ86YJ80!0<F5K;&]P:2!V
M($A434P@;F'H:6X@<V5S=&%V;&IA;FIA`%!R96ML;W!I('8@=&5K<W1O=FYI
M(&YAZ&EN('-E<W1A=FQJ86YJ80"I=FEC80!.87!AZ&YA('-I;G1A:W-A(&ES
M:V%N:6@@<&]J;6]V`%-I<FEJ<VMA($%R86)S:V$@4F5P=6)L:6MA`$YE=FEH
M=&$`3F5V:6AT90!44U8@9&%T;W1E:V$`5&%B96QA`$QA<W1N;W-T:2!T86)E
M;&4`3&%S=&YO<W1I('1A8F5L90!486IV86X`5&%J=F%N+"!+:71A:G-K82!P
M<F]V:6YC80!4862^:6MI<W1A;@!486YZ86YI:F$`0VEL:CH`3W!R879I;&$`
M0F5S95]D:6QO`%1E;&5F;VYS:V$@N71E=FEL:V$`5&5M97)A='5R82!Z861N
M:F\@=7)O.B``5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!5<')A=FQJ86YJ
M92!P<F5D;&]G`$]K;&5V86IOZ&4@4W!R96IM:2!Z86AT979O`$]K;&5V86IO
MZ&4@4W!R96IE=&\`1&%T;W1E:V$@<R!0;V=O:FD@=7!O<F%B92!N:2!P;V1A
M;F$@=B!C;VYF+G!H<`!386UO(&)E<V5D:6\`4&]R879N879A(&)E<V5D:6QA
M`%9R:"!B97-E9&EL80#(90!486IS:V\@*%1)4RTV,C`I`%1A:G-K80!(=F%L
M82!Z82!U<&]R86)O('-I<W1E;6$N`$944"!D;V1A=&5K(&YI(&YA('9O;&IO
M+@!0;W9E>F%V82!V('-T;VQP8W4@3V0Z(&YA:B!K8;YE(&YA.@!(;W)D92]+
M;VQA8B!I;G1E9W)A8VEJ82!N92!P;V1P:7)A("(E<R(`36%C:6YT;W-H(')E
M<W5R<VD`36%C:6YT;W-H(')E<W5R<V4@;&%H:V\@9&]B:71E('H@)7,N`%)A
M>G)E9"!-86EN=&5N86YC93HZ('-E(&YI('5S<&6Y;F\@;F%L;[YI;`!/:VYO
M(&UOOFYO<W1I('-E(&IE('IA<')L;RX@6F%P:7)A;2X`4F'H=6X@(B5S(B!J
M92!B:6P@<&]B<FES86XN`%)AZ'5N("(E<R(@:F4@8FEL('-H<F%N:F5N+@!3
M:W)B;FEK(&UO<F$@;F%M97-T:71I('-T86QN;R!H<F)T96YI8V\@>F$@9&]D
M96QJ979A;FIE('!R879I8RP@Z&4@OF5L:71E('5P;W)A8FQJ871I(%!R879I
M8V4N`%!R:7!O;FME(&YI(&UO9V_H92!N86IT:2X`4V%M;R!S<&]D;FIA('-T
M<F%N`$]K;F$@>F$@<V5S=&%V;&IA;FIE('-P;W)OZ&EL(&YI(&UO9V_H92!O
M9'!R971I+B!-;V=OZ&4@:6UA=&4@=B!B<G-K86QN:6MU(&]N96UO9V_H96YA
M('!O<'5P(&]K;F$_`$E$(+ET979I;&MA('-T:6MA(&YI(&)I;&$@<&]D86YA
M+"!P=;GH96YA('!R87IN82!A;&D@;FD@8FEL82!N86ID96YA('8@8F%Z:2!P
M;V1A=&MO=BX`4W1I:R!J92!B:6P@=7-P9;EN;R!D;V1A;B!V('9AN2!A9')E
M<V%R+@!6<V5B:6YA($UA8VEN=&]S:"!D871O=&5K92!J92!P<FEK87IA;F$@
M<W!O9&%J+@!4<F5N=71N82!M87!A("(E<R(@8F\@<')E:6UE;F]V86YA('8@
M(B5S(BX`5')E;G5T;F5G82!S97IN86UA('5P;W)A8FYI:V]V('H@9&]S=&]P
M;VT@9&\@=&4@;6%P92!N:2!M;V=OZ&4@<')E8G)A=&D`3V1D=F]J96X@4$=0
M('!O9'!I<VYI(&)L;VL@:F4@<&]T<F5B96X@>F$@879T96YT:6MA8VEJ;R!P
M;V1P:7-A;F5G82!S<&]R;^AI;&$N`$E$(+ET979I;&MA('-E>FYA;6$@<F%Z
M9&5L:71V92!N:2!B:6QA('!O9&%N82P@<'6YZ&5N82!P<F%Z;F$@86QI(&YI
M(&)I;&$@;F%J9&5N82!V(&)A>FD@<&]D871K;W8N`%-E>FYA;2!R87ID96QI
M='9E(&YI(&)I;"!P;V1A;BX`3W-N=71E:R!J92!B:6P@<VAR86YJ96X@=B!M
M87!O("(E<R(N`$UOOFYO<W1I(+EI9G)I<F%N:F$@>F%H=&5V86IO('9A<FYO
M('-P;&5T;F\@<&]V97IA=F\N`$1O9V]D96L@:F4@8FEL(&1O9&%N(&YA('9A
MN2!K;VQE9&%R+@!$871O=&5K82`E<R!B:2!M;W)A;&$@=G-E8F]V871I(&YA
M<W1A=FET978@)7,N`$1A=&]T96MA("5S(&)I(&UO<F%L82!V<V5B;W9A=&D@
M;F%S=&%V:71V92`E<RX`1&%T;W1E:V4@;FD@;6]G;^AE('!R97-N971I('-A
M;64@=F%S92X`1&%T;W1E:V$@;F4@=G-E8G5J92!P;V1A=&MO=BX`36%P82`B
M)7,B(+YE(&]B<W1A:F$`36%P82`B)7,B('9S96)U:F4@=B!S=F]J96T@:6UE
M;G4@;F5V96QJ879N92!Z;F%K92X@5&\@;&%H:V\@<&]V>G)OZ&D@=&6^879E
M+B!0<F]S:6T@:V]N=&%K=&ER86IT92!S=F]J96=A('-K<F)N:6MA('-I<W1E
M;6$N`$UA<&$@(B5S(B!J92!B:6QA('5S='9A<FIE;F$L('9E;F1A<B!N86YJ
M;R!N:7-T92!N87)OZ&5N:2X`36%P82`B)7,B(&IE(&)I;&$@:7IB<FES86YA
M+"!V96YD87(@<V4@;V0@;FIE(&YI<W1E(&]D:F%V:6QI+@!-87!E("(E<R(@
M;FD@8FEL;R!M;V=OZ&4@=7-T=F%R:71I+B!3=')EOFYI:R!J92!J879I;`!-
M87!A("(E<R(@:F4@8FEL82!U<W!EN6YO('5S='9A<FIE;F$N`$UA<&$@(B5S
M(B!J92!B:6QA('5S<&6Y;F\@:7IB<FES86YA+@!-87!A("(E<R(@:F4@8FEL
M82!U<W!EN6YO('!R96EM96YO=F%N82!V("(E<R(N`%-L961I(&=L879A('IA
M('1O('-P;W)OZ&EL;R]R9F,X,C(@<W!O<F_H:6QO`$YA<VQE9&YJ92!D871O
M=&5K92!S;R!B:6QE('!R:7!E=&4@=&5M(&1E;'4Z`$YAZ&EN(&1E;&]V86YJ
M82#H97H@8V5L('IA<VQO;B!L86AK;R!P;W9Z<F_H:2!P<F]B;&5M92!V(&1E
M;&]V86YJ=2!);G1E<FYE="!%>'!L;W)E<FIA('IA<F%D:2!H<F^YZ&5V(&)R
M<VMA;&YI:V$L(&MI('-E(&II;2!N:7-M;R!U<W!E;&D@;V=N:71I+B!/<&%Z
M:71E(&QA:&MO(.AU9&5N('!R:6MA>BP@;6%N:FMA:F_H92!M;[YN;W-T:2!U
M<F5J979A;&YI:V$@:6XO86QI(&YA:VQJ=>AN82!S97-U=&IA(&)R<VMA;&YI
M:V$N(,AE('5P;W)A8FQJ871E(%=I;F1O=W,@.7@L(&)O(&YA<&%K82!V97)J
M971N;R`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!K:2!B;R!Z86AT979A
M;&$@<&]N;W9N:2!Z86=O;BY<;EQN0FEL:2!S=&4@;W!O>F]R:F5N:2X@4')O
M<VEM(&EZ8F5R:71E($]+(.AE(+EE('9E9&YO(+YE;&ET92!P;W-K=7-I=&D@
M=7!O<F%B;&IA=&D@8V5L;WIA<VQO;G-K:2!U<F5J979A;&YI:RX`261E;G1I
M=&5T82`B)7,B(&IE(&)I;&$@:7IB<FES86YA+@!3;&EK92!B;V1O('!R:6MA
M>F%N92P@:V5R(&IE('!ON6EL:F%T96QJ('!R:7-O=&5N('8@=F&Y96T@861R
M97-A<FIU+@!386UO(&QE=F$@<W1R86X`4F%Z<F5D=2!#<GEP=%]P9W`Z.B!M
M;W)A(&)I=&D@<&]D86YA('!O="!D;R!';G501R!I>G9RN6EL;F4@9&%T;W1E
M:V4N`%!ON71N:2!S=')EOFYI:R!J92!J879I;"!N87-L961N:F\@;F%P86MO
M.@!0;[ET;FD@<W1R9;YN:6L@:F4@:F%V:6P@;F%S;&5D;FIO(&EN9F]R;6%C
M:6IO.@!0;[ET;FD@<W1R9;YN:6L@:F4@:F%V:6PZ`$YA8FER86QN:6L@)7,@
M:F4@OF4@<')A>F5N+@!3<&]R;^AI;&\@(B5S(B!I>B`B)7,B("@E9"!B>71O
M=BD@<')E<V5G82!O;65J:71E=BX`4W!O<F_H:6QO+"!K:2!S=&4@9V$@<V5S
M=&%V;&IA;&D@<V4@:F4@>F%P<FQO+@!3<&]R;^AI;&\@:F4@8FEL;R!P;V)R
M:7-A;F\N`%-P;W)OZ&EL;R!J92!B:6QO(&]V97)J96YO+@!3<&]R;^AI;&\@
M:F4@8FEL;R!O=F5R:F5N;RX@4&^Y:6QJ871E;&HZ("5S+@!3<&]R;^AI;&\@
M<&]S;&%N;R`E<R!Z82`E<R!Z('IA9&5V;R`B)7,B(&IE(&)I;&\@<')I:V%Z
M86YO+@I4;R!N:2!Z86=O=&]V:6QO+"!D82!J92!B:6QO('-P;W)OZ&EL;R!P
M<F5B<F%N;R!A;&D@<F%Z=6UL:F5N;RX`26UE+"!U<&]R86)L:F5N;R!P<FD@
M<&]V97IO=F%N:G4@;F$@<W1R86X@>F$@<V5S=&%V;&IA;FIE`%)A>G)E9"!(
M;W)D95]#<GEP=%]S;6EM93HZ('IA:'1E=F$@;6]D=6P@;W!E;G-S;"X`3VMN
M82!Z82!G97-L;R!N:2!M;V=OZ&4@;V1P<F5T:2X@36]R9&$@:F4@=F&Y(&)R
M<VMA;&YI:R!N87-T879L:F5N('1A:V\L(&1A(&YE(&1O=F]L:G5J92!P;W!U
M<"!O:V5N/P!.87-T879I='9E("(E<R(@;FD@8FEL;R!M;V=OZ&4@<VAR86YI
M=&DL(&ME<B!P<F5S96=A(&UA:W-I;6%L;F\@9&]V;VQJ96YO('9E;&EK;W-T
M`%!R;V=R86TL(&MI('-E('5P;W)A8FQJ82!Z82!P<FEK87H@=&4@=G)S=&4@
M<&]D871K;W8@*"5S*2!N:2!B:6P@;F%J9&5N+@!3=7)O=F\@8F5S961I;&\@
M2F%V;F5G82!01U`@:VQJ=>AA(&IE(&UO9V_H92!V:61E=&D@)7,N`%IA:'1E
M=F%N82!D871O=&5K82!N92!O8G-T86IA('8@35,M5$Y%1B!P<FEP;VYK:2X`
M6F%H=&5V86YA(&1A=&]T96MA(&YE(&]B<W1A:F$@=B!::7`@<')I<&]N:VDN
M`%-A;6\@9&5S;F4@:6X@;&5V92!S=')A;FD`4V%M;R!D97-N82!S=')A;@!0
M;[EI;&IA=&5L:B!S<&]R;^AI;&$@:F4@>F%H=&5V86P@3V)V97-T:6QO(&\@
M9&ES<&]Z:6-I:FD@<W!O<F_H:6QA+"!K;R!B;W-T92!P<F5B<F%L:2!T;R!S
M<&]R;^AI;&\N(%!R;W-I;2!K;&EK;FET92`E<R!Z82!P;[EI;&IA;FIE($]B
M=F5S=&EL82X`4W1R9;YN:6L@(B5S(B!J92!B:6P@:7IB<FES86XN`%-T<F6^
M;FEK("(E<R(@:F4@8FEL('-H<F%N:F5N+@!0;V1P:7-A(&YI(&)I;&\@;6]G
M;^AE('IA;65N:F%T:2X`4&]D<&ES(&IE(&)I;"!U<W!EN6YO('IA;65N:F%N
M+@!:86AT979A('IA('!R:6IA=F\@)7,@:F4@8FEL82!O9'-T<F%N:F5N82X`
M3F%V961E;F$@9&%T;W1E:V$@;F4@;V)S=&%J82X`26UE;F]V86YA('9R<W1I
M8V$@;F4@;V)S=&%J82X`3W!R879I;&\@:F4@8FEL;R!D;V1A;F\@;F$@=F&Y
M('-E>FYA;2!O<')A=FEL+@!"97-E9&EL;R!S<&]R;^AI;&$`0F5S961I;&\@
M<W!O<F_H:6QA(&IE(&UO9V_H92!V:61E=&D@)7,N`$)E<V5D:6QO('9R;FIE
M;F5G82!S<&]R;^AI;&$`0F5S961I;&\@=G)N:F5N96=A('-P;W)OZ&EL82!J
M92!M;V=OZ&4@=FED971I("5S+@!"97-E9&EL;R!P;W-L86YE9V$@<W!O<F_H
M:6QA`$)E<V5D:6QO('!O<VQA;F5G82!S<&]R;^AI;&$@:F4@;6]G;^AE('9I
M9&5T:2`E<RX`4V%M;R!Z9V]R;FIA(&EN('-P;V1N:F$@<W1R86YI8V$`4V%M
M;R!Z9V]R;FIA('-T<F%N:6-A`%!O9&%T:VD@<&]S;F5T:2!N82!S=')EOFYI
M:R!S;R!S92!O9"!P<F5JN6YJ96=A(&MO<F%K82!I>F=U8FEL:2X`4&]S;F5T
M92!D871O=&5K92!N:2!B:6QO(&UO9V_H92!S:')A;FET:2X`57!O<F%B;FEK
M;W9A(&EN9F]R;6%C:6IA('!R;W-T+WIA<V5D96X@:F4@8FEL82!U<W!EN6YO
M('-H<F%N:F5N82X`0FQO:R!W96%T:&5R+F-O;2!N:2!N82!V;VQJ;RX`3FD@
M86QT97)N871I=FYI:"!D96QO=B!S<&]R;^AI;&$L(&MI(&)I(&II:"!B:6QO
M(&UO9V_H92!P<FEK87IA=&D@=B!O:W9I<FIU+@!6('1E;2!N86)I<F%L;FEK
M=2!N:2!S<&]R;^AI;"X`3F]B96YA(&UOOFYO<W0@;FES;R!N82!V;VQJ;RX`
M3F]B96YE9V$@9&5L82!S<&]R;^AI;&$@;FD@;6]G;^AE('!R:6MA>F%T:2!Z
M;F]T<F%J('1E9V$@;VMN82X`4&]L:F4@=G-E8G5J92!P<F5V9>@@>FYA:V]V
M+B!6;F5S;&D@<W1E("5S('IN86MO=CL@=FYE<W1I(&II:"!M;W)A=&4@;6%N
M:B!K;W0@)7,N`%!R:2!P<F%Z;F5N:G4@)7,@:F4@<')IN6QO(&1O(&YA<&%K
M92X@4W1R9;YN:6L@:F4@:F%V:6P`4')I('!R87IN96YJ=2!N86)I<F%L;FEK
M82!J92!P<FFY;&\@9&\@;F%P86ME+B!3=')EOFYI:R!J92!J879I;#H@)7,`
M4')I('!R87IN96YJ=2!N86)I<F%L;FEK82!J92!P<FFY;&\@9&\@;F%P86ME
M+B!3=')EOFYI:R!J92!J879I;`!0<FD@<VYE;6%N:G4@9&%T;W1E:V4@;F$@
M<W1R9;YN:6L@:F4@<')IN6QO(&1O(&YA<&%K93H@)7,@;FD@<VAR86YJ96XN
M`%!R:2!S;F5M86YJ=2!D871O=&5K92!N82!S=')EOFYI:R!J92!P<FFY;&\@
M9&\@;F%P86ME.B`E<R!J92!V9>AJ82!O9"!N86IV9>AJ92!D;W9O;&IE;F4@
M=F5L:6MO<W1I("@E9"!B>71O=BDN`%!R:2!S;F5M86YJ=2!D871O=&5K92!N
M82!S=')EOFYI:R!J92!P<FFY;&\@9&\@;F%P86ME.B`E<R!J92!P;W-N970@
M<V%M;R!D96QN;RX`4')I(&MO<&ER86YJ=2!S<&]R;^AI;"!I>B`B)7,B('8@
M(B5S(B!J92!P<FFY;&\@9&\@;F%P86ME+B!3=')EOFYI:R!J92!J879L:0!0
M<FD@8G)I<V%N:G4@<W!O<F_H:6P@:7H@;6%P92`B)7,B(&IE('!R:;EL;R!D
M;R!N87!A:V4N(%-T<F6^;FEK(&IE(&IA=FEL`%!R:2!B<FES86YJ=2!S<&]R
M;^AI;"!V(&UA<&D@(B5S(B!J92!P<FFY;&\@9&\@;F%P86ME+B!3=')EOFYI
M:R!J92!J879I;"!N87!A:V\`4')I(&)R:7-A;FIU('-P;W)OZ&EL(&IE('!R
M:;EL;R!D;R!N87!A:V4N(%-T<F6^;FEK(&IE(&IA=FEL.B`E<P!0<FD@8G)I
M<V%N:G4@9&]G;V1K82!J92!P<FFY;&\@9&\@;F%P86ME.B`E<RX`4')I('!R
M:6MA>F]V86YJ=2!T96=A(&1E;&$@<W!O<F_H:6QA(&IE('!R:;EL;R!D;R!N
M87!A:V4N`%!R:2!O>FYAZ&5V86YJ=2!S<&]R;^AI;"!V(&UA<&D@(B5S(B!J
M92!P<FFY;&\@9&\@;F%P86ME+B!3=')EOFYI:R!J92!J879I;&YA<&%K;P!0
M<FD@=79AOF%N:G4@)7,@:F4@<')IN6QO(&1O(&YA<&%K92X`4')I('5V8;YA
M;FIU('!O9&%T:V]V(&\@<W1I:W4@:F4@<')IN6QO(&1O(&YA<&%K92X`4')I
M('5V8;YA;FIU(&1O9V]D:V$@:F4@<')IN6QO(&1O(&YA<&%K93H@)7,N`%!R
M:2!U=F&^86YJ=2!P;V1A=&MO=B!I0V%L96YD87(@:F4@<')IN6QO(&1O(&YA
M<&%K92X`4')I('5V8;YA;FIU(&]P<F%V:6QA(&IE('!R:;EL;R!D;R!N87!A
M:V4Z("5S`%!R:2!U=F&^86YJ=2!U<&]R86)N:6MO=F4@:6YF;W)M86-I:F4@
M<')O<W0O>F%S961E;B!J92!P<FFY;&\@9&\@;F%P86ME.B`E<RX`1&\@;F%P
M86ME(&IE('!R:;EL;R!V(&]B<F%Z8W4@>F$@:V]N9FEG=7)A8VEJ;RX@36]G
M;^AE('-T92!P=7-T:6QI('!R87IN;R!Z86AT979A;F\@<&]L:F4N`%!R:2!P
M<F5M:6MA;FIU('-P;W)OZ&EL(&EZ("(E<R(@=B`B)7,B(&IE('!R:;EL;R!D
M;R!N87!A:V4N(%-T<F6^;FEK(&IE(&IA=FEL(&YA<&%K;P!0<FFY;&\@:F4@
M9&\@;F%P86ME('!R:2!I>G9A:F%N:G4@>F%H=&5V86YE(&9U;FMC:6IE(&%D
M<F5S87)J82X@4')O<VEM('!O<VMU<VET92!P;VYO=FYO(&MA<VYE:F4N`%!R
M:2!S:')A;FIE=F%N:G4@<W!O<F_H:6QA(&MO="!O<VYU=&5K(&IE('!R:;EL
M;R!D;R!N87!A:V4N`%!R:2!P;[EI;&IA;FIU('9AN65G82!S<&]R;^AI;&$@
M:F4@<')IN6QO(&1O(&YA<&%K93H@)7,`4')IN6QO(&IE(&1O(&YA<&%K92!P
M<FD@;W-V9;YE=F%N:G4@<&]D<F]B;F]S=&D@;R!S=&EK=2X@4&]S:W5S:71E
M(&MA<VYE:F4N`%!R:;EL;R!J92!D;R!N87!A:V4@<')I(&]S=F6^979A;FIU
M('-E>FYA;6$@<F%Z9&5L:71V92X@4&]S:W5S:71E(&MA<VYE:F4N`%!R:2!O
M<W9EOF5V86YJ=2!D;V=O9&MA(&IE('!R:;EL;R!D;R!N87!A:V4Z("5S+@!6
M('1E;2!D96QU('-P;W)OZ&EL82!N:2!B:6QO(&)E<V5D:6QA`%1O($A434P@
M<W!O<F_H:6QO(&EM82!V9VYE>F1E;F4@<VQI:V4N`%1O($A434P@<W!O<F_H
M:6QO(&EM82!V9VYE>F1E;F4@<VQI:V4N($)L;VMI<F%N92!S;&EK92!S;R!P
M<FEK87IA;F4@=&%K;SH@`%1A($E-05`@<W1R9;YN:6L@;F4@<&]D<&ER82!S
M:W5P;F4@<F%B92!N86)I<F%L;FEK;W8N`%1A($IA=FYI(%!'4"!K;&IUZ"!J
M92!B:6P@<')I<&5T('-P;W)OZ&EL=2X`5&\@9&5J86YJ92!N:2!P;V1P<G1O
M+@!4;R!D96IA;FIE(+EE(&YI(&EM<&QE;65N=&ER86YO+@!$871O=&5K82!V
M97)J971N;R!N:2!V96QJ879E;B!R87(@87)H:78N`$1A=&]T96MA('9E<FIE
M=&YO(&YI('9E;&IA=F5N('II<"!A<FAI=BX`5G!I<V%N82"Y=&5V:6QK82!N
M:2!V96QJ879N82"Y=&5V:6QK82!K<F5D:71N92!K87)T:6-E+@!482!G;VYI
M;&YI:R!O;6]G;^AA('!ON6EL:F%N:F4@<W!O<F_H:6P@<')E:V\@0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!P<F5H;V1A('H@=7!O<F%B
M;R!(5%10($%020!482!G;VYI;&YI:R!O;6]G;^AA('!ON6EL:F%N:F4@<W!O
M<F_H:6P@<')E:V\@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@
M<')E:&]D82!Z('5P;W)A8F\@2%144"!!4$D`5&$@9V]N:6QN:6L@;VUO9V_H
M82!P;[EI;&IA;FIE('-P;W)OZ&EL('!R96MO(%--5%`@<')E:&]D82!6;V1A
M9F]N92!)=&%L:6IA<V%M;R!6;V1A9F]N92"Y=&5V:6QK86TN(%IA:'1E=F%N
M(&IE(&]B<W1O:F7H(&4M<&^Y=&YI(&YA<VQO=B!P<FD@5F]D869O;F4@271A
M;&EJ82`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4;R!P;VQJ92!J92!O8G9E>FYO
M+@!4;R!P;VQJ92!L86AK;R!V<V5B=6IE('-A;6\@N71E=FEL:V4N`%1O('!O
M;&IE(&QA:&MO('9S96)U:F4@<V%M;R"Y=&5V:6QK92!I;B!D=F]P:>AJ92X`
M5&\@<&]L:F4@;&%H:V\@=G-E8G5J92!S86UO(&]K=&%L;F4@=G)E9&YO<W1I
M+@!4;R!P;VQJ92!M;W)A('9S96)O=F%T:2!S97IN86T@N71E=FEL(&QOZ&5N
M('H@9'9O<&GH:FD@86QI('!R97-L961K:0!4;R!P;VQJ92!M;W)A('9S96)O
M=F%T:2!V96QJ879N;R"Y=&5V:6QK;RX`5&\@<&]L:F4@;6]R82!V<V5B;W9A
M=&D@:V]D;R!B87)V92!V(&]B;&EK:2!21T(@2&5X+"!N87!R:6UE<B`G(S$R
M,S1A9B<N`%1A(&]B<F%Z96,@:F4@8FEL(+YE(&]B9&5L86XN`%1O(&IE("5S
M+@!482!O8FIE:W0@:F4@:7H@2V]L86(@1W)O=7!W87)E+B#(92!G82"^96QI
M=&4@<')I:V%Z871I+"!P;W1R96)U:F5T92!P<F]G<F%M>F$@92UP;[ET;RP@
M:VD@<&]Z;F$@9F]R;6%T($MO;&%B($=R;W5P=V%R92X@6F$@<V5Z;F%M('!R
M;V=R86UO=B!O8FFYZ&ET92`E<P!4;R!D96IA;FIE(&QA:&MO('1R86IA(&1A
M;&H@Z&%S82X@4W1E('!R97!R:>AA;FD@9&$@OF5L:71E(&YA9&%L:F5V871I
M/P!4;R!S<&]R;^AI;&\@=G-E8G5J92!-86-I;G1O<V@@9&%T;W1E:V\N`%-P
M;W)OZ&EL;R!V<V5B=6IE('!R:7!O;FMO+"!K:2!J92!B:6QA(&1I9VET86QN
M;R!P;V1P:7-A;F$@<')E:V\@4R]-24U%+@!4;R!S<&]R;^AI;&\@=G-E8G5J
M92!P<FEP;VYK;RP@:VD@:F4@8FEL82"Y:69R:7)A;F$@<')E:V\@4R]-24U%
M+@!4;R!S<&]R;^AI;&\@=G-E8G5J92!P;W)OZ&EL;R!O(&1O<W1A=FD@<W!O
M<F_H:6QA+"!F;W)M870@=&5G82!S<&]R;^AI;&$@<&$@:F4@;F5Z;F%N+@!4
M;R!S<&]R;^AI;&\@;FD@=F5L:F%V;F\@4$=0(+EI9G)I<F%N;R!S<&]R;^AI
M;&\N($YA<&%K83H@`%1O('-P;W)OZ&EL;R!OZ&ET;F\@;FD@=B!P<F%V:6QN
M:2!01U`@;V)L:6MI("AG;&5D92!N82!21D,@,C`Q-2DN`%1O('-P;W)OZ&EL
M;R!OZ&ET;F\@;FD@=B!P<F%V:6QN:2!3+TU)344@;V)L:6MI+@!4;R!S<&]R
M;^AI;&\@:F4@8FEL;R!D:6=I=&%L;F\@<&]D<&ES86YO('!R96MO(%!'4"X`
M5&\@<W!O<F_H:6QO(&IE(&)I;&\@9&EG:71A;&YO('!O9'!I<V%N;R!P<F5K
M;R!3+TU)344N`%1O('-P;W)OZ&EL;R!J92!B:6QO(+EI9G)I<F%N;R!P<F5K
M;R!3+TU)344N`%1O('-P;W)OZ&EL;R!J92!B:6QO(+EI9G)I<F%N;R!P<F5K
M;R!01U`N`%1O('-P;W)OZ&EL;R!K`%1O('-P;W)OZ&EL;R!J92!B:6QO(&YA
M<&ES86YO('8@9')U9VD@:V]D;FD@=&%B96QI("@E<RD@:V]T(&IE('9AN6$N
M`%1O(+ET979I;&\@;6]R82!B:71I('9S86H@96YA+@!482!S=')EOFYI:R!N
M92!M;W)E(&]D:V]M<')E<VER871I('II<"!I;B!G>FEP(&1A=&]T96LN`%-T
M<F6^;FEK(&YE('!O9'!I<F$@<VMU<&YE(')A8F4@;6%P+@!3:7-T96T@:F4@
M=')E;G5T;F\@9&5A:W1I=FER86XN`%1A('9R961N;W-T(&UO<F$@8FET:2"Y
M=&5V:6QO+@!4;R!O:VYO(&UO<F%T92!O9'!R971I(&EZ(&]K;F$@>F$@<V5S
M=&%V;&IA;FIE('-P;W)OZ&EL82X`5&\@;VMN;R!J92!P;W1R96)N;R!O9'!R
M971I(&EZ(&]K;F$@36^^;F]S=&D`4&]G;&5D('!O9V]V;W)A`%-T<F5L80!6
M<W1O<&YI8V4`R&%S`%-L961E;FIE(.AA<V$`3V)L:6MA('IA<&ES82#H87-A
M`$EZ8FER82#H87-A`%1I;6]R+4QE<W1E`$YA<VQO=@!.87-L;W8@*&]K=FER
MZ&5K*3H`6F$`6F$@3F%S;&]V`%IA(&EZ8FER;R!V9>AI:"!P;VQJ+"!D<KYI
M=&4@=&EP:V\@0V]N=')O;"`H4$,I(&%L:2!#;VUM86YD("A-86,I(&UE9'1E
M;2!K;R!K;&EK871E(&YA('!O;&IA+@!:82!I>F)I<F\@=F7H:6@@;6^^;F]S
M=&DL(&1ROFET92!T:7!K;R!#;VYT<F]L("A00RD@86QI($-O;6UA;F0@*$UA
M8RD@;65D(&ML:6MA;FIE;2!N82"^96QJ96YE(&UOOFYO<W1I+@!$86YE<P!0
M<FEK8;YI($A434P@:7IV;W)N;R!K;V1O`%1O9V\`5&]K96QA=0!*=71R:0!4
M;VYG80!:9V]R86H`6F=O<FYJ:2!O:W9I<B`H7W1O<"D`4VMU<&YA('9E;&EK
M;W-T(%!R:7!O;FLZ`%!R979O9&D`36%P82!S('-M971M:0!-87!A(',@<VUE
M=&UI`%1R:6YI9&%D(&EN(%1O8F%G;P!$<KYI(&%L:2!N92!D<KYI`%1O`%1U
M;FEZ:6IA`%1U<NAI:F$`5'5RN6MO("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T
M86X`5'5R:W,@:6X@0V%I8V]S(&]T;VMI`%1U=F%L:0!6<&FY:71E(&EZ8FER
M;SH@`%4N5BX@:6YD96MS.B``55),`%523"!Z82!D;W-T879O('-T871U<V$@
M<VMR:7!T90!54DPZ`%5G86YD80!5:W)A:FEN80!$;W-T;W`@9&\@5D93(&UA
M<&4@;FD@;6]G;^@N`%!R:2!P<FEJ879L:F%N:G4@;FD@;6]G;^AE(&1O9&%T
M:2!D;V1A=&YI:"!I;F9O<FUA8VEJ(&\@=7!O<F%B;FEK=2X`3FD@;6]G;^AE
M('-P<F5M96YI=&D@<')A=FEC('IA(%9&4R!D871O=&5K;R`B)7,B+@!.:2!M
M;V=OZ&4@<W!R96UE;FET:2!P<F%V:6,@>F$@5D93(&1A=&]T96MO("5S+R5S
M+@`E<R!N:2!M;V=OZ&4@<W!R96UE;FET:2X`4&]V97IA=F$@;F$@4U%,('-T
M<F6^;FEK(&YI(&UO9V_H82X`4&]V97IA=F$@<R!34TP@;FD@;6]G;^AA+@!+
M;W!I<F%N:F4@5D93(&1A=&]T96ME(&YI(&UO9V_H92X`27ID96QA=F$@5D93
M(&UA<&4@(B5S(B!N:2!M;V=OZ&$N`$EZ9&5L879A(%9&4R!M87!E(&YI(&UO
M9V_H82X`27ID96QA=F$@5D93(&1A=&]T96ME(&YI(&UO9V_H82X`27ID96QA
M=F$@<')A>FYE(%9&4R!D871O=&5K92!N:2!M;V=OZ&$N`%!O9&%T:V]V(&YI
M(&UO9V_H92!O9&MO;7!R97-I<F%T:2X`(B5S(B!N:2!M;V=OZ&4@<&]B<FES
M871I+"!M87!A(&YI('!R87IN82X`)7,@;FD@;6]G;^AE('!O8G)I<V%T:2P@
M;6%P82!N:2!P<F%Z;F$`5D93(&UA<&4@;FD@;6]G;^AE(')E:W5R>FEV;F\@
M<&]B<FES871I+@!61E,@;6%P92!N:2!M;V=OZ&4@<&]B<FES871I+@!61E,@
M;6%P92!N:2!M;V=OZ&4@<&]B<FES871I.B`E<RX`5D93(&1A=&]T96ME(&YI
M(&UO9V_H92!P;V)R:7-A=&D@(B5S(BX`5D93(&1A=&]T96ME(&YI(&UO9V_H
M92!P;V)R:7-A=&DN`%9&4R!N:2!M;V=OZ&4@<F5K=7)Z:79N;R!P;V)R:7-A
M=&DZ("5S+@!4<F5N=71N92!M87!E(&YI(&)I;&\@;6]G;^AE('5G;W1O=FET
M:2X`4&]D<F]B;F]S=&D@;R!P;W1R9&EL=2!N:2!B:6QO(&UO9V_H92!I>G9L
M9>AI+@!$969I;FEC:6IE("5S(&YI(&UO9V_H92!N86QOOFET:2X`5D93(&1A
M=&]T96ME(&YI(&UO9V_H92!P<F5M86MN:71I+@!61E,@9&%T;W1E:V4@(B5S
M(B!N:2!M;V=OZ&4@;V1P<F5T:2X`5D93(&1A=&]T96ME(&YI(&UO9V_H92!O
M9'!R971I('IA(&)R86YJ92X`5D93(&1A=&]T96ME(&YI(&UO9V_H92!O9'!R
M971I+@!+;VUP<F5S:7)A;F5G82!A<FAI=F$@;FD@;6]G;^AE(&]D<')E=&DN
M`'9F<W)O;W0@;6%P92!N:2!M;V=OZ&4@<')E8G)A=&DN`"5S(&YI(&UO9V_H
M92!P<F5I;65N;W9A=&D@=B`E<SH@;6%P82"^92!O8G-T86IA`%9&4R!M87!E
M(&YI(&UO9V_H92!P<F5I;65N;W9A=&DN`%9&4R!M87!E(&YI(&UO9V_H92!P
M<F5I;65N;W9A=&DZ("5S+@!61E,@9&%T;W1E:V4@(B5S(B!N:2!M;V=OZ&4@
M<')E:6UE;F]V871I+@!61E,@9&%T;W1E:V4@)7,O)7,@;F\@;6]G;^AE('!R
M96EM96YO=F%T:2X`5D93(&1A=&]T96ME(&YI(&UO9V_H92!P<F5I;65N;W9A
M=&DN`$YI(&)I;&\@;6]G;^AE('!R96)R871I(&MV;W1E`%5K87IA("=M:VES
M;V9S)R!N:2!M;V=OZ&4@>F%G;F%T:2X`5V]R9&]V92!D871O=&5K92!N:2!M
M;V=OZ&4@<')E=F5S=&DN`%9&4R!D871O=&5K92`B)7,B(&YI(&UO9V_H92!Z
M87!I<V%T:2X`5D93(&1A=&]T96ME(&YI(&UO9V_H92!Z87!I<V%T:2`H=6MA
M>B!C;W!Y*"D@:F4@<W!O9&QE=&5L*2X`4&]D871K;W8@;R!61E,@9&%T;W1E
M:VD@;FD@;6]G;^AE('IA<&ES871I+@!.96]D9V]V;W)J96YO`$YE;V1G;W9O
M<FIE;F$@<W!O<F_H:6QA`$YE(&EZ8G)IN6D`4&]DZ')T86YO`%-K<FET:2!0
M<F5J96UN:6MI`%)A>G9E;&IA=FD@<W!R96UE;6)E`%)A>G9E;&IA=FD@>F%D
M;FIE(&1E:F%N:F4`3F5P<FGH86MO=F%N(&]D>FEV('-T<F6^;FEK82!O8B!P
M;W9E>F%V:3H@`$YE<')IZ&%K;W9A;B!O9'II=B!S=')EOFYI:V$@;F$Z(`!.
M96YA<&]L;FIE;F\`3F5O8G)A=FYA=F%N82!K;VUP;VYE;G1A('1I<&$Z("5S
M`%5N:6-O9&4@*%541BTX*0!:9')UOF5N:2!!<F%B<VMI($5M:7)A=&D`6F1R
M=;YE;F\@:W)A;&IE<W1V;P!:9')UOF5N92!D<KYA=F4`6F1R=;YE;F4@9'*^
M879E("T@;6%N:KEI(&EZ=F5N+6QEOF7H:2!O=&]K:0!%;F]T90!.97IN86X`
M3F5Z;F%N(&1A='5M`$YE>FYA;B!S97-T86YE:P!.97IN86X@4')E:F5M;FEK
M`$YE>FYA;B!A<&EM<V=I9"`H240@05!)('-P;W)OZ&EL82DN`$YE>FYA;B!C
M;&EM<V=I9"`H240@;V1J96UA;.AE=F5G82!S<&]R;^AI;&$I+@!.97IN86YO
M('5P;W)A8FYIN6MO(&EM92!A;&D@9V5S;&\N`$]D<W1R86YI('!O=F5Z879O
M('1R96YU=&YE9V$@96QE;65N=&$`3V1N86QOOFD@9V5S;&\`3F5I;65N;W9A
M;@!3:W)I<'1E(&)R97H@<')A=FEC(&YE(&UO<F%J;R!U<&]R86)L:F%T:2!U
M:V%Z;W8@27IR9;YI+TMO<&ER86HO4')I;&5P:2!I>B!V87)N;W-T;FEH(')A
M>FQO9V]V+B!+;&EK;FET92!/2R!Z82!T96AN:>AN;R!R87IL86=O(&YA(&UO
M>FEL;&$N;W)G(&MI('!O;F%Z87)J82P@:V%K;R!O;6]G;^AI=&D@<VMR:7!T
M:2!D;W-T;W`@9&\@;V1L;[YIN>AA+@!.979I9&5N;P!.96YA<W1A=FQJ96YA
M(&)A<G9A`$]D:F%V:2!S92!O9"!-87`H92D`3F5P;V1P<G0@9&]D871E:P!0
M;W-O9&]B:0!0;W-O9&]B:2`E<P!/<W9EOFD@:6YF;W)M86-I:F4@;R!P<FEP
M;VYK:0!/<W9EOFD@<W1A;FIE(&1O<&ES;FEK80!0;W-O9&]B:2!U<&]R86)N
M:6MA`%-K<FEP=&$@>F$@;F%D9W)A9&YJ;R!P;V)R:7-A;F$N`%!O<VYE;6D@
M;F$@<W1R9;YN:6L`5G-E(&YA;65S=&ET=F5N92!D871O=&5K92!S:')A;FIE
M;F4@;F$@<W1R9;YN:6LN`%9E;&EK92!L871I;G-K92#H<FME`%9E;&EK92!R
M:6US:V4@N71E=FEL:V4`57)A9W9A:@!5<&]R86)I('1R96YU=&YO.B`E<P!5
M<&]R86)I('!R:79Z971O('9R961N;W-T`%5P;W)A8FQJ86T@;F%R;^AA;FIE
M(&YA($E-05`@;6%P93\`57!O<F%B:2!34TP`57!O<F%B:2#H92!S92!I;64O
M9V5S;&\@<F%Z;&EK=6IE=&$@>F$@24U34"!S=')EOFYI:RX`57!O<F%B;FEK
M`%5P;W)A8FYI:R`E<R!N:2!P;V]B;&&YZ&5N('IA("5S+@!!9&UI;FES=')A
M8VEJ82!U<&]R86)N:6MO=@!-;[YN;W-T:2!U<&]R86)N:6MO=@!296=I<W1R
M86-I:F$@=7!O<F%B;FEK;W8`4F5G:7-T<F%C:6IA('5P;W)A8FYI:V]V(&IE
M('IA('1O('-P;&5T;F\@;65S=&\@;VYE;6]G;^AE;F$N`%5P;W)A8FYIN6MO
M(&EM90!5<&]R86)N:;EK;R!I;64Z`%5P;W)A8FYIN6MO(&EM93H@`%5P;W)A
M8FYI:VD@=B!S:7-T96UU.@!5>F)E:VES=&%N`%9&4R!M87!A(&YE(&]B<W1A
M:F$N`$1O<'5S=`!5<W1R97IN92!N86ID96YE(&QO:V%C:6IE('9K;&IUZ'5J
M96IO.B``5F5L:F%V;F]S=`!6<F5D;F]S="!V(&UI;G5T86@@;V0@=&5G82!T
M<F5N=71K82X`5G)E9&YO<W1I`%9R961N;W-T:2!Z82!I>F)I<F\`5F%N=6%T
M=0!3<')E;65N;&II=F\`5F5N97IU96QA`$]V97)J86YJ92!S<&]D;&5T96QO
M("T@<W!O<F_H:6QO(&IE(&)I;&\@<W!R96UE;FIE;F\N`%9E<GII:F$`3F%D
M>F]R('9E<GII:@!.879P:>AN82!P;W)A=FYA=F$`3F%V<&GH96X@;V1M:6L`
M3F%V<&GH;F\Z`%IE;&\@=FES;VMO`%9I971N86T`5FEE=&YA;7-K;R`H5DE3
M0TE)*0!0<FEK8;YI`%!R:6MAOFD@)7,`4')I:V&^:2`E<R!*879N:2!K;&IU
MZ`!0<FEK8;YI($A434P@=G-E8FEN;R!V(&QOZ&5N96T@;VMN=0!0<FEK8;YI
M(&]S96)N:2!:87-E8FYI(&ML:G7H`%!R:6MAOFD@;W-E8FYI($IA=FYI(&ML
M:G7H`%!R:6MAOFD@<&]G;W9O<@!0<FEK8;YI('-L:>AI8V\`4')I:V&^:2!Z
M=6YA;FIO('-P;&5T;F\@<W1R86X`4')I:V&^:2!K;W0@)7,`4')I:V&^:2!P
M<FEP;VYK;R!V(&QOZ&5N96T@;VMN=0!0<FEK8;YI(&1O9V]D96L`4')I:V&^
M:2!S<&]R;^AI;&$@=B`E<P!0;V=L960@86QI(&YA8FER86QN:6LL(&MI(&=A
M('!R:6MAOF5M('!O('!R:6IA=FDZ`%!R:6MAOFD@;W!R879I;&\`4')I:V&^
M:2!S;&EK90!"<FET86YS:VD@1&5V:;EK:2!O=&]K:0!!;65R:;EK:2!$979I
MN6MI(&]T;VMI`$YA=FED97IN82!M87!A("(E<R(@=7-P9;EN;R!U<W1V87)J
M96YA+@!.879I9&5Z;F4@36%P90!/>FYA:V$@;F%V:61E>FYE(&UA<&4`5FED
M;&II=F]S=`!6:61L:FEV;W-T.B``5F]D869O;F4@271A;&EJ82!P<F5K;R!3
M3510`$]03UI/4DD`3U!/6D]224Q/(2$A(%)/R$Y/($]$4U1204Y)5$4@4TM2
M25!43R!)6B`E<RX`5V%L;&ES(&EN($9U='5N80!3<@!6<F5M96YS:V$@;F%P
M;W9E9`!6<F5M96YS:V\@;F%P;W9E9"!P<FES:W)B96P`5V5A=&AE<BYC;VT`
M4W!L970`4W!L971N;R!M97-T;P!4961E;G-K;P!$;V)R;V1ON6QI`$1O8G)O
M9&^Y;&D@=B`E<P!$;V)R;V1ON65L+"`E<P!:86AO9&YO("A)4T\M.#@U.2TQ
M*0!:86AO9&YO("A)4T\M.#@U.2TQ-2D`6F%H;V1N82!386AA<F$`2V%T97)O
M(&%P;&EK86-I:F\@;F%J("5S('!R:6MAOF4@<&\@<')I:F%V:3\`2V%T97)I
M('IN86L@<F%Z;65J=6IE('!O;&IA/P!+871E<FD@>FYA:R!J92!U<&]R86)L
M:F5N('IA(&-I=&ER86YJ93\`2V\@8G)IN65M('-P;W)OZ&EL82P@:FEH('!R
M96UA:VYE;2!V(&UA<&\@4VUE=&DL(&YA;65S=&\@9&$@:FEH(&]Z;F'H:6T@
M:V]T('!O8G)I<V%N93\`2V\@<')I:V%Z=6IE;2!N;W8@;F%B:7)A;&YI:RP@
M;F$@:V%T97)I('-T<F%N:2!N86H@>F'H;F5M/P!+;R!S:')A;FIU:F5M('!O
M<VQA;F\@92UP;[ET;RP@;F%J('-H<F%N:6T@<')I<&]N:V4_`$MA=&5R92!M
M96YE`$MA=&5R:2!P;'5G:6YI+2!N86H@8F]D;R!O;6]G;^AE;FD@>F$@=7)E
M:F5V86QN:6L@;V)O9V%T96YE9V$@8F5S961I;&$N`%=H:71E;&ES=`"I:7)I
M;F$`J6ER:6YA('8@0U-3(&5N;W1A:`"I:7)I;F$@)7,@;65N=6IA(&YA(&QE
M=FD@*'9E;&IA(&]B(&YA<VQE9&YJ:2!P<FEJ879I*3H`J6ER:6YA('1A8F5L
M90!%;F]T82"Y:7)I;F4`J6ER:6YA.@!7:6MI`%9E=&5R`$AI=')O<W0@=F5T
M<F$@=B!V;WIL:6@`5F5T97(Z`%9E=&5R.B``36]D<F]S=`!$96QO`%-L=;YB
M96YI(&YA<VQO=@!3;'6^8F5N:2!T96QE9F]N`%@M4F5F`%@U,#EV,R!/<VYO
M=FYE(&]M96II='9E`%@U,#EV,R!0;V1A;&JY86YA('5P;W)A8F$@:VQJ=>AA
M`%@U,#EV,R!!;'1E<FYA=&EV;F\@:6UE('-U8FIE:W1A`%@U,#EV,R!)9&5N
M=&EF:6MA8VEJ82!K;&IUZ&$@<W5B:F5K=&$`6#4P.78S(&1O9&%T:VD`3$P`
M3$Q,3`!986AO;R$@>F5M;&IE=FED`$QE=&YO`$IE;65N`$1A`$1A+"!S=')I
M;FIA;2!S90!0<F5S;F5L:2!S:2!B;W-T92!E+7!ON71O('H@;F%S;&5D;FII
M:"!R8>AU;F]V.@!+;W!I<F%T92]P<F5M:6MA=&4@=B!N;W9O(&UA<&\N`%5S
M='9A<FIA=&4@<&]D+6UA<&\@>F$@`%5S='9A<FIA=&4@;6%P;RX`4W1E('8@
M0D53141)3$Y%32!.0<A)3E4N(%5P;W)A8FET92!;/#Y=(&=U;6(@>F$@<')E
M:VQO<"!N87IA:B!V(%=94TE764<N`$YI<W1E(&)I;&D@;W9E<FIE;FDN`%!R
M96EM96YO=F%L:2!B;W-T92!M87!O.B``5F&Y92!P;VQN;R!I;64@;F4@<VUE
M('9S96)O=F%T:2!Z;F%K82`G7"<N`$YI<W1E('-E('-T<FEN:F%L:2!S(%!R
M879I;&D@57!O<F%B92P@>F%T;R!V86T@<')I:F%V82!N:2!B:6QA(&1O=F]L
M:F5N82X`3FES=&4@=G!I<V%L:2!V96QJ879N96=A(&YA<VQO=F$@92UP;[ET
M92X`3FES=&4@<&]V97IA;&D@;F]B96YE9V$@<&]L:F$@:7H@=79OOF5N92!D
M871O=&5K92!Z('5S=')E>FYI;6D@<&]L:FD@=B`E<RX`3FEM871E(&1O=F]L
M:F5N:F$@>F$@<W!R96UI;FIA;F4@9&]S=&]P82!D;R!T92!M87!E`"4E<R!S
M=&4@<&]S<F5D;W9A;&D@<W!O<F_H:6QO('!R96IE;6YI:V]M.B`E<P!);6%T
M92`E<R!N;W9I:"!S<&]R;^AI;"X`26UA=&4@,2!N;W9O('-P;W)OZ&EL;RX`
M27IB<F%N;R!I;6%T;R!V<V%J(&5N;R!P<FEP;VYK;RP@:VD@:F4@N64@;FES
M=&4@<')E<VYE;&D@;F$@<W1R9;YN:6LN(%-T92!P<F5P<FGH86YI+"!D82"^
M96QI=&4@<&]S;&%T:2!S<&]R;^AI;&\@8G)E>B!T92!P<FEP;VYK93\`3V1J
M879I;&D@<W1E('-E+@!.;W9A('-P;W)OZ&EL82!I;6%T92!V(&YA<VQE9&YJ
M:6@@;6%P86@Z`$YO=F$@<W!O<F_H:6QA(&EM871E('8@;F%S;&5D;FII:"!M
M87!A:#H`5G!I<V%T:2!M;W)A=&4@=F5L:F%V;F\@N71E=FEL:V\@;6]B:6QN
M96=A('1E;&5F;VYA("T@<V%M;R"Y=&5V:6QK92!Z(&]P8VEJ<VMI;2`G*R<@
M>F$@;65D;F%R;V1N;R!P<F5D<&]N;RX`5G!I<V%T:2!M;W)A=&4@=F5L:F%V
M;F\@=G)E9&YO<W0N`$1A=&%T<F5E(&UO<F%T92!K;VYF:6=U<FER871I('IA
M('5P;W)A8F\@4VEG;G5P<RX`5D93(&UO<F%T92!K;VYF:6=U<FER871I+@!0
M<F5D96X@<&^Y;&IE=&4@<&]R;^AI;&\@;R!N87!A:VDL(&UO<F%T92!N87!A
M:V\@;W!I<V%T:2X`5G!I<V%T:2!M;W)A=&4@=G-A:B!E;F5G82!P<F5J96UN
M:6MA+@!6<&ES871I(&UO<F%T92!54DP@:V%M;W(@;F%J('1A('!O=F5Z879A
M(&MAOF4`R&4@OF5L:71E('9I9&5T:2!S<&]R;^AI;&\L(&UO<F%T92!V<&ES
M871I(&=E<VQO('IA('-V;VH@>F%S96)N:2!01U`@:VQJ=>@`R&4@OF5L:71E
M('9I9&5T:2!S<&]R;^AI;&\L(&UO<F%T92!V<&ES871I(&=E<VQO('IA('-V
M;VH@>F%S96)N:2!3+TU)344@:VQJ=>@`3F%J<')E:B!M;W)A=&4@:7IB<F%T
M:2!C:6QJ;FD@;F%B:7)A;&YI:RX`27IB<F%T:2!M;W)A=&4@<F'H=6XL(&MI
M(&=A(+YE;&ET92!I>F)R:7-A=&DN`$YA:G!R96H@;6]R871E(&EZ8G)A=&D@
M;F%S;&]V+@!)>F)R871I(&UO<F%T92!S=')EOFYI:RP@:VD@9V$@OF5L:71E
M(&EZ8G)I<V%T:2X`3F%J<')E:B!M;W)A=&4@:7IB<F%T:2!V<V%J(&5N;R!S
M<&]R;^AI;&\N`$1O;&_H:71I(&UO<F%T92!P<F5J96UN:6MA+@!.879E<W1I
M(&UO<F%T92!U<&]R86)N:;EK;R!I;64L(&MI(&=A(+YE;&ET92!P;^AI<W1I
M=&DN`$YA=F5S=&D@;6]R871E('5P;W)A8FYIN6MO(&EM92P@:VD@9V$@OF5L
M:71E(&]D<W1R86YI=&DN`$EZ8G)A=&D@;6]R871E('9S86H@96YO(&1A=&]T
M96MO+"!K:2!J;R"^96QI=&4@<')I<&5T:2X`3F%V97-T:2!M;W)A=&4@=7!O
M<F%B;FFY:V\@:6UE+"!K:2!G82"^96QI=&4@9&]D871I+@!.879E<W1I(&UO
M<F%T92!U<&]R86)N:;EK;R!I;64L(&MI(&=A(+YE;&ET92!P;W-O9&]B:71I
M+@!.879E<W1I(&UO<F%T92!D96IA;FIE+"!K:2!N86H@<V4@:7IV961E+@!6
M<&ES871I(&UO<F%T92!I;64@;F]V92!K871E9V]R:6IE+@!3<&]R;^AI;&\@
M<W1E('!R975S;65R:6QI(',@)7,@;F$@)25S+@!.82!S<&]R;^AI;&\@<W1E
M(&]D9V]V;W)I;&D@)7,N`$YA("(E<R(@;FES=&4@8FEL:2!N87)OZ&5N:2X@
M4W1R9;YN:6L@:F4@:F%V:6P`3V0@(B5S(B!S92"Y92!N:7-T92!O9&IA=FEL
M:2X@4W1R9;YN:6L@:F4@:F%V:6P`57-P9;EN;R!S=&4@<V4@;F%R;^AI;&D@
M;F$@(B5S(@!5<W!EN6YO('-T92!S92!O9&IA=FEL:2!O9"`B)7,B`%9AN6$@
M)7,@<V5J82!J92!P;W1E:VQA+B!0;VYO=FYO('-E('!R:6IA=FET92X`5F&Y
M82!E+7!ON71N:2!N87-L;W8`5F&Y($]D.B!N87-L;W8Z`%9AN6D@<&]D871K
M:0!68;D@:6YT97)N971N:2!N87-L;W8@<V4@:F4@<W!R96UE;FEL(&]D('IA
MZ&5T:V$@)7,@<V5J92X@27H@=F%R;F]S=&YI:"!R87IL;V=O=B!S92!M;W)A
M=&4@<&]N;W9N;R!P<FEJ879I=&DN`%9AN64@:6UE`%9AN6D@2F%V;FDO6F%S
M96)N:2!01U`@:VQJ=>AI`%9AN2!Z87-E8FYI(&ML:G7H`%9AN2!J879N:2!K
M;&IUZ`!68;EA($IA=FYA+UIA<V5B;F$@4R]-24U%('!O=')D:6QA`%9AN6D@
M<F'H=6YI.@!68;EA(&AR8G1E;FEC82!Z82!O=F5R:F%N:F4@;F4@<&]D<&ER
M82!P<FEK87IO=F%N:F$@=7!O<F%B;FEK;W8L(&%L:2!P82!J92!B:6QA('1A
M(&UOOFYO<W0@:7H@;F5K96=A(')A>FQO9V$@;VYE;6]G;^AE;F$N`%9AN2!B
M<G-K86QN:6L@<V4@:F4@<W!R96UE;FEL(&]D('IAZ&5T:V$@=F&Y92`E<R!S
M96IE+B!)>B!V87)N;W-T;FEH(')A>FQO9V]V('-E(&UO<F%T92!P;VYO=FYO
M('!R:6IA=FET:2X`5F&Y(&)R<VMA;&YI:R!N92!P;V1P:7)A('!R:6MA>B!T
M92!V<G-T92!S;&EK('8@;VMV:7)J=2X`5F&Y(&)R<VMA;&YI:R!N92!P;V1P
M:7)A('1E(&UOOFYO<W1I+@!68;D@=')E;G5T96X@Z&%S;W9N:2!P87,Z`%9A
MN6$@<')I=GIE=&$@:V]D;F$@=&%B96QA('IA('!ON6EL:F%N:F4@<W!O<F_H
M:6PZ`%9AN2!P<FEV>F5T(&YAZ&EN(+EI9G)I<F%N:F$@>F$@<&^Y:6QJ86YJ
M92!S<&]R;^AI;#H`5F&Y82!P<FEV>F5T82!I9&5N=&ET971A.@!68;EE('!O
M;&YO(&EM93H`5F&Y92!S<&]R;^AI;&\@:F4@8FEL;R!U<W!EN6YO(&1O<W1A
M=FQJ96YO+@!68;EE(&YO=F\@9V5S;&\@>F$@)7,@:F4Z("5S`%9AN64@;F%S
M=&%V:71V92!S;R!B:6QE('!O<V]D;V)L:F5N92X`5F&Y92!G97-L;R!J92!B
M:6QO('!O;F%S=&%V;&IE;F\`5F&Y92!G97-L;R!J92!B:6QO('!O;F%S=&%V
M;&IE;F\N(%!O9VQE:G1E('9AN6\@92UP;[ET;R!I;B!S92!P<FEJ879I=&4@
M>B!N;W9I;2!G97-L;VTN`%9AN6D@;V1D86QJ96YI('-T<F6^;FEK:3H`5F&Y
M('!O9'!I<SH`2G5G;W-L879I:F$`6F%I<F4`6F%M8FEJ80!::6UB86)V90!:
M:7!P:0!;4VMR:6H@8VET:7)A;F\@8F5S961I;&]=`%M"<F5Z(%IA9&5V95T`
M6U!O<F_H:6QO(&\@;F%P86MI70!;4')I:V&^:2!C:71I<F%N;R!B97-E9&EL
M;R`M`%M0<FEK8;YI(&-I=&ER86YO(&)E<V5D:6QO("T@)7,@=G)S=&EC70!;
M=G)S=&EC82`E<R!O9"`E<UT`7T%D;6EN:7-T<F%C:6IA`%]":VL`7T)L86-K
M;&ES=`!?0TQ)`%]+:P!?1&%T851R964`7TEZ8G)IN6D`7TEZ8G)IN6D@=G)S
M=&EC;P!?36%P90!?4VMU<&EN90!?4&]M;^@`7TED96YT:71E=&$`7TQA<W1N
M;W-T:2!S;&EK92XN+@!?26YB;W@`7U!R:6IA=F$`7T]D:F%V80!?27IV;W)N
M82!K;V1A('-P;W)OZ&EL80!?4W!R96UE;FD@<&]V97IA=F\N+BX`7TUOOFYO
M<W1I`%]0<F%V:6-E`%].871I<VYI`%]0<FEO<FET971A`%]/<W9EOFD@)7,`
M7T]D<W1R86YI('!O=F5Z879O+BXN`%]/9&=O=F]R:0!?2;GH:0!?4&^Y;&II
M(%-P;W)OZ&EL;P!?3F%M97-T:71E=@!?3&%S=&YO<W1I('1A8F5L92XN+@!?
M4&]G;W9O<@!?6F$`7TYE(&EZ8G)IN6D`7U5P;W)A8FYI:VD`7U!O9VQE:B!0
M;V=O=F]R`%]7:&ET96QI<W0`861R97-A<@!P<FEP;VYK80!P<FEP;VYK92YZ
M:7``8GET;W8`:V]L961A<@!M:7)N;P!K;&EK;FET92!S96T`<&%D86IOZ`!D
M871O=&5K80!O9`!O9"`E<R`H)7,I('!R:2`E<R`E<P!V.@!T86MO:KEN:0!N
M;W1R86YJ:0!K;&IUZ`!V<G-T:6-E70!N86)I<F%L;FEK`&UK:7-O9G,@;F%P
M86MA(+ET979I;&MA("5D(&UE9"!I>F1E;&%V;R!)4T\@<&]S;F5T:V$N`&EM
M90!N;V)E;@!N:2!I;7!L96UE;G1I<F%N`+EE(&YI(&EM<&QE;65N=&ER86X`
M8F5L9;YN:6-A`&%L:0!O9'-T;W1E:P!P:7AL;W8`<F%S=&_H`'!O:V&^:2!R
M87IL:6ME`'-M<S)E;6%I;"!P<F5K;R!(5%10`.AR:V]V86QN82!N87!A:V$`
MZ')K;W9A;&YE(&YA<&%K90!M:7)N;P!S97IN86T@;W!R879I;`!V<&FY:71E
M(&=E<VQO(&1V86MR870@>F$@<&]T<F1I=&5V`'ID<G6^96X`;F5I;65N;W9A
M;@!I>F)I<F$@=7!O<F%B;FEK80!V0V%R9`"Y.@!W96%T:&5R+F-O;0!V8;EA
M(&)L86-K;&ES=&$`=F&Y82!W:&ET96QI<W1A````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]T:%]42"\`````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P
M,3<T-3<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+W1H7U1(
M+TQ#7TU%4U-!1T53+P``````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S8S`#`R,3(T-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]L;V-A;&4O=&A?5$@O3$-?34534T%'15,O:6UP+FUO````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,S<W,S,`,3`T,3<S-C(W-C,`,#(R-#`P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
M]````!P```"\!P``2P$``%P/````````B!0```H```")%```"@```)04```*
M````GQ0```H```"J%```!````+44```!````NA0``!<```"\%```,@```-04
M```R````!Q4``!L````Z%0``+@```%85```W````A14``'P```"]%0``'```
M`#H6```=````5Q8```P```!U%@```P```((6``!0````AA8``$(```#7%@``
M"````!H7```1````(Q<``#L````U%P``,0```'$7```,````HQ<```D```"P
M%P``"@```+H7```+````Q1<```H```#1%P```P```-P7```)````X!<```0`
M``#J%P``!````.\7```"````]!<```8```#W%P``"@```/X7``!B````"1@`
M`%\```!L&```'````,P8```.````Z1@```T```#X&```#`````89```4````
M$QD```\````H&0``7````#@9```$````E1D```<```":&0``#@```*(9```-
M````L1D``!H```"_&0``'0```-H9```9````^!D``%T````2&@``*````'`:
M```$````F1H``!D```">&@``&@```+@:```&````TQH``!````#:&@``!P``
M`.L:```0````\QH``!P````$&P``"@```"$;```/````+!L```<````\&P``
M(P```$0;```2````:!L```4```![&P``#@```($;```6````D!L```T```"G
M&P``#P```+4;```2````Q1L``!4```#8&P``!0```.X;```0````]!L``!``
M```%'```#P```!8<```/````)AP```P````V'```"@```$,<```2````3AP`
M``T```!A'```#````&\<```'````?!P```0```"$'```"@```(D<```0````
ME!P```<```"E'```"````*T<```9````MAP```0```#0'```#````-4<```$
M````XAP```P```#G'```$0```/0<```%````!AT```8````,'0``"@```!,=
M```)````'AT``!(````H'0``)````#L=```(````8!T```D```!I'0``#```
M`',=```+````@!T```<```",'0``"````)0=```W````G1T```<```#5'0``
M$P```-T=```,````\1T```X```#^'0``#`````T>```.````&AX```\````I
M'@``#0```#D>```/````1QX``"8```!7'@``"P```'X>```$````BAX```0`
M``"/'@``!0```)0>```#````FAX```@```">'@``#````*<>```,````M!X`
M``D```#!'@```@```,L>```9````SAX``!(```#H'@``#@```/L>```$````
M"A\```L````/'P``"0```!L?```-````)1\```P````S'P``%````$`?```6
M````51\```P```!L'P``(P```'D?```-````G1\```T```"K'P``!P```+D?
M```(````P1\```@```#*'P``%````-,?```Q````Z!\``"X````:(```$```
M`$D@```-````6B````4```!H(```#0```&X@```6````?"````@```"3(```
M%0```)P@```3````LB````<```#&(```%0```,X@```+````Y"```!8```#P
M(```.@````<A```-````0B$```4```!0(0``#````%8A```-````8R$```H`
M``!Q(0``!@```'PA```.````@R$```8```"2(0``2P```)DA```'````Y2$`
M`#D```#M(0``!@```"<B```.````+B(```0````](@``!@```$(B```*````
M22(```L```!4(@``$0```&`B```&````<B(``$,```!Y(@``.0```+TB```,
M````]R(``!$````$(P``!````!8C```2````&R,```L````N(P``#0```#HC
M```4````2",``"\```!=(P``!P```(TC```-````E2,``!8```"C(P``!P``
M`+HC```+````PB,```0```#.(P``,P```-,C```>````!R0``'4````F)```
M/@```)PD``!"````VR0``#T````>)0``/0```%PE```I````FB4``"D```#$
M)0``,0```.XE```F````("8``#X```!')@``1P```(8F``!7````SB8``%4`
M```F)P``+P```'PG``!5````K"<``"L````"*```#P```"XH```+````/B@`
M``(```!**```#0```$TH```*````6R@``!,```!F*```"````'HH```6````
M@R@```<```":*```!@```*(H```:````J2@``!$```#$*```"````-8H```'
M````WR@``"<```#G*```!P````\I```-````%RD```,````E*0``/0```"DI
M``!!````9RD``"@```"I*0``+````-(I```/````_RD```P````/*@``!```
M`!PJ```$````(2H```(````F*@``#@```"DJ```/````."H``$X!``!(*@``
M"P```)<K```,````HRL```D```"P*P``"0```+HK```$````Q"L```$```#)
M*P``&````,LK```N````Y"L``"D````3+```'````#TL```I````6BP``#<`
M``"$+```=P```+PL```F````-"T``!P```!;+0``"0```'@M```'````@BT`
M`$````"*+0``+@```,LM```'````^BT``!4````"+@``+````!@N```R````
M12X```T```!X+@``$@```(8N```)````F2X```D```"C+@``#````*TN```,
M````NBX```<```#'+@``!P```,\N```-````URX```@```#E+@``"P```.XN
M```2````^BX``$8````-+P``-````%0O```/````B2\```X```"9+P``"P``
M`*@O```*````M"\``!(```"_+P``"P```-(O```V````WB\```4````5,```
M!P```!LP```3````(S````T````W,```%````$4P```=````6C```!,```!X
M,```10```(PP```M````TC````8`````,0``'0````<Q```;````)3$```(`
M``!!,0``"@```$0Q```&````3S$```\```!6,0``&0```&8Q```2````@#$`
M`!8```"3,0``!@```*HQ```;````L3$``!$```#-,0``!P```-\Q```/````
MYS$```P```#W,0``#`````0R```,````$3(``!(````>,@``$@```#$R```'
M````1#(```L```!,,@``#0```%@R```*````9C(```\```!Q,@``!P```($R
M```+````B3(``!,```"5,@``#````*DR```(````MC(```<```"_,@``!0``
M`,<R```'````S3(``!````#5,@``!@```.8R```'````[3(``!@```#U,@``
M`P````XS```-````$C,```<````@,P``#0```"@S```4````-C,```D```!+
M,P``!@```%4S```-````7#,```4```!J,P``#````'`S```H````?3,```0`
M``"F,P``"P```*LS```/````MS,``!(```#',P``"P```-HS```,````YC,`
M`#@```#S,P``!P```"PT```0````-#0``!````!%-```#````%8T```.````
M8S0```X```!R-```#@```($T```0````D#0```@```"A-```)@```*HT```,
M````T30```0```#>-```!````.,T```(````Z#0```0```#Q-```"@```/8T
M```+`````34```P````--0``"0```!HU```#````)#4``!L````H-0``$0``
M`$0U```,````5C4```@```!C-0``"````&PU```-````=34``!(```"#-0``
M%````)8U```5````JS4``!(```#!-0``"P```-0U```J````X#4```P````+
M-@``$0```!@V```*````*C8```@````U-@``!P```#XV```-````1C8``"<`
M``!4-@``(@```'PV```.````GS8```L```"N-@``!0```+HV```)````P#8`
M`!<```#*-@``#@```.(V```8````\38``!<````*-P``!@```"(W```4````
M*3<```P````^-P``$````$LW```_````7#<```L```"<-P``!P```*@W```.
M````L#<```\```"_-P``#0```,\W```'````W3<```T```#E-P``!0```/,W
M``!,````^3<```H```!&.```,@```%$X```%````A#@```H```"*.```"```
M`)4X```%````GC@```P```"D.```"P```+$X```3````O3@```T```#1.```
M*@```-\X```\````"CD```P```!'.0``%````%0Y```$````:3D```L```!N
M.0``"@```'HY```-````A3D``!<```"3.0``-@```*LY```*````XCD``!0`
M``#M.0``$P````(Z```&````%CH```<````=.@``!P```"4Z```O````+3H`
M`!@```!=.@``9@```'8Z```V````W3H``#8````4.P``-@```$L[```S````
M@CL``"H```"V.P``(P```.$[```V````!3P``!P````\/```+P```%D\```W
M````B3P``$,```#!/```0@````4]```H````2#T``$8```!Q/0``)P```+@]
M```/````X#T```H```#P/0```P```/L]```/````_ST```T````//@``%P``
M`!T^```&````-3X``!,````\/@``"0```%`^```-````6CX```\```!H/@``
M#P```'@^```*````B#X```<```"3/@``.````)L^```'````U#X``!(```#<
M/@```P```.\^```P````\SX``"\````D/P``(0```%0_```@````=C\```X`
M``"7/P``$0```*8_```#````N#\```4```"\/P``!````,(_```)````QS\`
M``D```#1/P```0````````!B````P0```+D```#0`````````#``````````
M`````!@`````````!0```"@```":````B@```'$```!6````U`````````#C
M````$````*D```"W````Z@```+$`````````.`````````!<````+P```#X`
M``#N````F``````````'````:@```(,```!5````"P```.@`````````````
M`!X```"L`````````$\```````````````````!_````%0```&,`````````
M``````````!+`````````!\```")``````````````!0````\0````,`````
M````QP````````"\````Y`````````#)````Q`````````!U````AP```%L`
M``"X````:0```($```#8````C````#$```##````````````````````W```
M`&T```!>`````````+T```!.````+0```,``````````C@```+4```#,````
MQ0```#H```````````````P```#L````````````````````/````!<````)
M````V0````````#M````0@```&P````I````YP```*X`````````#@```',`
M``"^`````````*T```"?````=@```+L`````````JP````````!@````:```
M``````!D````#P```-,```!1``````````````"P````-P````````#-````
MSP``````````````LP```-<`````````\@``````````````M````&L`````
M````.0```````````````````#L`````````*P`````````A`````````!0`
M``"Z`````````.$````<````U@```"<```#O````-@```)(```#(````U0``
M`"(```"@````30```%T```"D````,@```#\```#T````6@```.8```!\````
MWP````````"F````FP```$H```"A````E0```",````*````1````!,```#I
M````+`````8````=````J````.L```!4````1@````````"/````````````
M``"G````20````@`````````X@```$P```!8````)````-H```!^````````
M``````#P````9@```-L```#"````5P```'L```"`````T0```$$```!'````
MX`````0```"O````W0````(`````````7P```"X```!%````B````,H`````
M````4P```,X```"-````````````````````>0```-(```"0````<@```"``
M``!]`````````*H```"_````W@``````````````BP```%(```!(````/0``
M`#4```#E````>@```!(```"6````G````)T`````````=P```*4```"C````
M9P```"H```"4````D0```&$`````````$0```,8````;````G@```$````!T
M````<````#0``````````````&\`````````DP```)<```"V````60```"4`
M````````90````T````S````>````(4```#+`````````*(```#S````0P``
M`!D```!N``````````````"&`````````!8```"R````)@```(0````:````
M`````)D``````````````((````````````````@("`@("!4;SH@`"`@("!$
M871E.B``("`@($9R;VTZ(``@4W5B:F5C=#H@`"!I;B``(P`E9"!T;R`E9"!O
M9B`E9"!-97-S86=E<P`E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD
M97(@=V%S(&YO="!R96YA;65D+@`E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A
M="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+@`E<SH@)7,@*"5D)FYB<W`[;V8F
M;F)S<#LE9"D`*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X
M="!S8W)E96XN*0`H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O
M('1H92!C;VUP;W-E('-C<F5E;BXI`"A2971U<FX@=&\@=&AE(&-O;7!O<V4@
M<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F
M87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B
M92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*@`J(%!L
M96%S92!S96QE8W0@861D<F5S<RAE<RD@*@!!9&1R97-S($)O;VL`06QL`$%L
M;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@
M9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@<V5N
M="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B
M92!D96QE=&5D+@!!;G-W97)E9`!!;G-W97)E9"!M97-S86=E<P!!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H97-E(&UE
M<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T
M<F%S:"!F;VQD97(_`$%R<FEV86P@5&EM90!!<V-E;F1I;F<`071T86-H;65N
M=`!!='1A8VAM96YT<P!"86-K('1O("5S`$)C8P!";&%C:VQI<W0`0F]D>0!"
M;W1H`$-C`$-H86YG90!#:&%N9V4@06QL`$-H86YG92!D:7-P;&%Y(&]P=&EO
M;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@
M<&%G92!A;F0@:&]W(&UE<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!T:&4@
M;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6PN`$-H96-K
M($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAO;W-E($%C=&EO;CH`0VQO<V5D
M($9O;&1E<@!#;VQL87!S92!!;&P`0V]L;&%P<V4@06QL($9O;&1E<G,`0V]L
M;&%P<V4@1F]L9&5R`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H
M96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W
M:&5N(&ET(&%R<FEV97,N`$-O<'D`0V]R<F5C=`!#;W)R96-T960@5&5X=`!#
M<F5A=&4@1F]L9&5R`$-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R`$-R96%T
M92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R`$-R96%T92!A(&YE=R!T<F%S:"!F
M;VQD97(`0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R
M(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"!A;F0@9&5L
M971E('-P86TN`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RX`1&%T90!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@
M<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T90!$96QE=&4@1F]L9&5R*',I`$1E
M;&5T960`1&5L971E9"!M97-S86=E<P!$96QE=&EN9R!A;F0@36]V:6YG($UE
M<W-A9V5S`$1E<V-E;F1I;F<`1&EM('-I9VYA='5R97,_`$1I<W!L87D`1&\@
M3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`1&]W;FQO860@1F]L
M9&5R*',I`$1R869T`$1R869T<R!F;VQD97(Z`$5D:70@>6]U<B!F:6QT97(@
M<G5L97,`16UA:6P@061D<F5S<P!%;7!T>2!&;VQD97(H<RD`16UP='D@5')A
M<V@@9F]L9&5R`$5N9"!F;W)W87)D960@;65S<V%G90!%<G)O<@!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AP86YD($%L;`!%>'!A;F0@
M06QL($9O;&1E<G,`17AP86YD($9O;&1E<@!%>'!A;F0@3F%M97,`1FEL=&5R
M<P!&:6YD`$9I<G-T(%!A9V4`1F]L9&5R($YA=FEG871O<@!&;W)W87)D`$9O
M<G=A<F0Z`$9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,`1G)O;0!&<F]M($%D
M9')E<W,`1G=D.@!(:61E($1E;&5T960`2&ED92!5;G-U8G-C<FEB960`24Y"
M3U@`26=N;W)E`$EG;F]R92!!;&P`26UP;W)T86YT`$EM<&]R=&%N="!M97-S
M86=E<P!);F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\`3&%N
M9W5A9V4`3&%S="!086=E`$QO9R!I;B!T;R`E<P!,;V=I;B!487-K<P!-86EL
M8F]X`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG
M('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`365S<V%G90!-97-S86=E($-O;7!O
M<VET:6]N`$UE<W-A9V4@1&%T90!-97-S86=E(%-E87)C:`!-97-S86=E(%-I
M>F4`365S<V%G92!3;W5R8V4`365S<V%G92!6:65W:6YG`$UE<W-A9V4@9FQA
M9W,`365S<V%G92!F;VQD97)S`$UE<W-A9V5S('!E<B!P86=E(&EN('1H92!M
M86EL8F]X('9I97<N`$UE<W-A9V5S('1O`$UO=F4`3F%M90!.979E<@!.97<`
M3F5W($UA:6P`3F5W(&UE<W-A9V5S`$YE>'0@365S<V%G90!.97AT(%!A9V4`
M3F\`3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9`!.;R!S<&5L;&EN9R!E<G)O
M<G,`3F\@<W5G9V5S=&EO;G,`3F]N90!.;W0@1&5L971E9`!.;W0@1')A9G0`
M3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&1E;&5T960@;65S<V%G
M97,`3F]T(&EM<&]R=&%N="!M97-S86=E<P!/;&0@;65S<V%G97,`3VQD('-E
M;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"X`3W1H97(@3W!T:6]N<P!0
M86=E("5D(&]F("5D`%!A<G0H<RD`4&%S<W=O<F0`4&5R<V]N86P`4&5R<V]N
M86P@26YF;W)M871I;VX`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E
M<&QI97,@86YD(&9O<G=A<F1S/P!0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@
M;W(@:6YV86QI9"!A9&1R97-S97,N`%!R979I;W5S($UE<W-A9V4`4')E=FEO
M=7,@4&%G90!0<FEN=`!0=7)G92!$96QE=&5D`%!U<F=E(%1R87-H(&AO=R!O
M9G1E;CH`4F5D:7)E8W0`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T
M:6YG(&9A:6QE9"X`4F5F<F5S:`!2969R97-H($9O;&1E<B!6:65W<SH`4F5L
M;V%D(%9I97<`4F5M96UB97(@=&AE(&QA<W0@=FEE=P!296YA;6EN9R`B)7,B
M('1O("(E<R(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%)E<&QA8V4@=VET:#H`4F5P;'D`4F5P;'D@=&\@06QL`%)E<&QY('1O($%L
M;#H`4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S(%-P86T`4F5S=6UE`%)E
M='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M
M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/P!3879E(&%S`%-A=FEN9R!T
M:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`E<P!396%R8V@`4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`4V5L96-T
M(&%L;`!396QE8W0@;F]N90!396YT(&UA:6P@9F]L9&5R.@!397)V97(`4V5T
M('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A
M;F0@9&5L971E(&UE<W-A9V5S+@!3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W
M(&)E(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\`4VAO=R!$96QE=&5D
M`%-H;W<@56YS=6)S8W)I8F5D`%-I>F4`4W!E8VEA;"!#:&%R86-T97)S`%-P
M96QL($-H96-K`%-P96QL($-H96-K97(`4W!E;&P@8VAE8VL@8V]M<&QE=&4`
M4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN
M9RX`4W5B:F5C=`!3=6)J96-T($9I96QD`%-U8G-C<FEB92!T;R!&;VQD97(H
M<RD`4W5C8V5S<P!3=6=G97-T:6]N<P!497AT`%1H92!C=7)R96YT(&9O;&1E
M<BAS*2`B)7,B('=I;&P@8F4@<F5N86UE9"!T;R`B)7,B+@!4:&4@9F]L9&5R
M("(E<R(@86QR96%D>2!E>&ES=',`5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS
M(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E
M('!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(N`%1H92!F;VQD97(@(B5S(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@
M;F]T('-U8G-C<FEB960@=&\@:70N`%1H92!F;VQD97(@(B5S(B!W87,@9&5L
M971E9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4
M:&4@9F]L9&5R("(E<R(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&1E;&5T
M960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B
M)7,B('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"X`5&AE(&9O;&1E<B`B)7,B
M('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"X`5&AE(&9O;&1E<B`B)7,B('=A
M<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R`B)7,B+@!4:&5R92!A<F4@;F\@
M;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+@!4:&5R92!W87,@82!P<F]B;&5M
M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4
M:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E<R(N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA
M9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG
M('EO=7(@;65S<V%G93H@)7,`5&AI<R!M97-S86=E('1O`%1H<F5A9"!6:65W
M`%1O`%1R87-H(&9O;&1E<CH`56YA;G-W97)E9`!5;F%N<W=E<F5D(&UE<W-A
M9V5S`%5N9&5L971E`%5N9&ES8VQO<V5D(%)E8VEP:65N=',`56YN86UE9`!5
M;G-E96X`56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RD`57-E($1E9F%U;'0@
M5F%L=64`57-E<FYA;64`5FEE=R`E<P!6:65W(&]R(&UA:6QB;W@@=&\@9&ES
M<&QA>2!A9G1E<B!L;V=I;CH`5V%R;FEN9P!796QC;VUE('1O("5S`%EE<P!9
M;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(97)E(&ES('=H870@
M=&AE('-E<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O
M;2`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E
M('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`66]U('=E<F4@<W5C
M8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`66]U<B!S:6=N871U
M<F4Z`%M.;R!3=6)J96-T70!F<F]M`&YO;F4`;W(`<W!E;&QI;F<@97)R;W(`
M<W!E;&QI;F<@97)R;W)S`%!R;VIE8W0M260M5F5R<VEO;CH@26UP(#,N,0I2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#,M,#(M,#@@,34Z-#4K,#<P,`I,87-T+51R86YS;&%T
M;W(Z(%-U<F%S86L@4W)I<V%W86X@/'-U<F%S86M`<FER8RYA8RYT:#X*3&%N
M9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/51)4RTV
M,C`*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("`@("`@MM:G
M.B``("`@(,?1N;?5Z#H@`"`@(""HTJ$Z(``@X,/7Z,VG.B``(..Y(``C`"5D
M(+;6IR`E9""HTJ$@)60@HNG-I,?2P0`E<R#!U<W"V>CAQ>G'(.*_Q>"TS</L
M("5S(*C6I^3!Z+;9H>"[Q=7HPKFJU^C-`.*_Q>"TS</L("5S(*C0MMFAX+O%
MU>C"N:K7Z,VWV*'F(+7IN>"TU\VY`"5S.B`E<R`H)60F;F)S<#NHTJ$F;F)S
M<#LE9"D`*+K1N;?6H:3'TL'@N\75Z,*YX;O%I^'%Z<?DN\+1I\NYZ=*UZ,WD
MNRD`*,*AX,74H:'2P^"[Q=7HPKGAN\6GM]'II\O!M.'%T*'%T;K*V>C+N>G2
MJ,W@HM7"N:BTR\'2P@`HNM&YM]:AX*F^TM"ATL/@N\75Z,*YX;O%I[?5Z+SH
MTKG!TN'%Z<?AQ="AQ=&ZRMGHR[GITJC-X*+5PKFHM,O!TL(@I,?2P>"[Q=7H
MPKGAN\6GM]7HX*'4M*+6Z;GCN<NYZ=*HS;G5Z:C0Y,'HMMFANM&YM]:A*0`J
M(."^U.C!JM?HS;7HS>2[N=7IXK3"I,74H;?5Z+O8Z,$@3TL@*@`J(*'#V+/2
MX,77S:&JU^C-M]7HM>G-IZ'2PR`J`+?5Z+74M+7HS0"WT>FGR\&T`*BTR\'2
MPK?5Z*3ITJ?-PMGHX[GBO\7@M,W#["`B)7,B(+G2N:''Z-(@)7,@Q]&Y(*C0
MMMFAQ;K-PNC2I[;2Q\,`Q;KBO\7@M,W#[*BTR\'2PJ+2S<VAM]7HP=7-TL+8
MN=*YH<?HTB`E<R#@M-?-N0"US;KAQ>G'`*+IS:3'TL&WU>BUS;JAQ=&ZX<7I
MQP"DV+.UZ<VGH=+#Q;JBZ<VDQ]+!X,O%Z-*YU>G-PNC2I[;2Q\/+P]?-Y,'H
M/P"DV+.UZ<VGH=+#Q;JBZ<VDQ]+!M]'II\O!M..YXK_%X+3-P^RVT:>BPM#+
MP]?-Y,'H/P#@Q\72M]7HY+3IP]&Z`.##U<*GJ-*AR[GITN2[R\71IP#@S:'*
MTL/AN;H`X,VARM+#X;FZ`*'%T;KDN\K9Z"`E<P#*T^"YTJOHS;FVUJ<`NM&M
MJM6TTP#@N=?IS<O2`+?1Z:?*S:>[P]#@P+<`RM/@N=*VUJ<`X+O%U>C"N>&[
MQ:<`X+O%U>C"N>&[Q:>WT>FGR\&T`."[Q=7HPKFUT<?@Q=?-H>.YH=+#X<JT
MI[S%(."JZ+D@J-.YQ[FHM,O!TL*UZ,W+N>G2X<70H=+#J-&TX,/5PJ>HM,O!
MTL(`X+O%U>C"N:K7Z,TL(+?5Z,W"V>@@X<70Q=+"X*OGN;?5Z,KHI^2[OL/I
MS<&AT;K-U>#!Q0#*T\/'J*BTR\'2PN/+P>@`X,77S:&ATL.AP]"WTSH`N]2T
MXK_%X+3-P^P`PMBZM]'II\O!M`#"V+KBO\7@M,W#[+?1Z:?+P;0`PMBZXK_%
MX+3-P^P`I,>ZI-C!H=+#M</'J,K-NJBTR\'2PN/+P>CAQ="ATL/@M=?-N>#!
MU^C-P=6HM,O!TL+CR\'H`,K3X+G2`+;9H;7IS:<`HNG-I,?2P;?5Z.&AZ>2B
MX<7IQP#*P^G2I^*_Q>"TS</L`,K#Z=*GXK_%X+3-P^SANKK#Z-*G`,K#Z=*G
MXK_%X+3-P^RHM,O!TL*WU>C*Z*?AQ>G'`,K#Z=*GXK_%X+3-P^RVT:>BPM``
MRL/ITJ>UT<>AP\VGX+[7Z,VHT;2ATL.HM,O!TL*BTN"BZ=(L(*C1M."AY[K%
MI^*_Q>"TS</L(.'%T,6ZJ+3+P=+"HL+0`*'3R[FTI]*YM]7HM>G-IZ'2P^/+
MZ</1N>#!U^C-Q:>JU^C-X*+ITLK9Z"`E<P#'T;FWU>@`X*?7Z,VYY**ATL.H
MT;3@P]7"I^*TPKO#U,+2PCH`M]3(M]*GH=+#J-&TX,/5PJ?BM,*[P]3"TL(Z
M`,6Z`,6ZXK_%X+3-P^P`Q;KAQ>G'`*+IS:3'TL&WU>BVV:'%N@"ATL/%NN'%
MT."DQ=?HS;G"Z=+"J+3+P=+"`.##U<*GJ-*AR\71I^2[R[GIT@#ARK2GQ=+"
MX*OGN;3IQ\+*U<WHS;D_`.'*M*>\Q0#DP>BUZ<VGH=+#M</'J,K-NJBTR\'2
MPN/+P>@`M-+'N>SBR\6TXK_%X+3-P^P`X;JZP^C2IP#BO\7@M,W#[.&ZNL/H
MTJ<`X:'IY**UT<>AP\VG`+?5Z,W"V>C-U>#!Q0#%Z=*GXK_%X+3-P^P`Q>G2
MI^*_Q>"TS</LMM&GHL+0`*BZH=+#RNBGM>C-HNG-I,?2P0"\U+2^Q=*T`+?8
MH2`Q-2"YTK?5`+?8H2`S,"#'U+G2M]4`M]BA(#4@N=*WU0"WV*&DP];HIZK1
MZ,?BP:<`M]BAN=*WU0"BPM+"M]'II\O!M`"BPM+"XK_%X+3-P^RWT>FGR\&T
M`*+"TL+BO\7@M,W#[`#@M=3!JM?HS0"UT<>AP\VG`*3IN<O2`,NYZ=+APZ$`
MM=''N=.WTJ?BO\7@M,W#[`#*Z*>UZ,T`RNBGM>C-.@"BZ<VDQ]+!M]7HRNBG
MM>C-P=*HTJ$@)7,`J-*A`+?5Z,W"V>B\V>G*Z*<`RNBGM>C-.@"KZ,VYM]7H
MQ;KAQ>G'`*OHS;FWU>C@Q=2AXZKIY+OAQ>G'`+79Z:+2X*+IT@#%T.#'Z;D`
MQ=#@Q^FYM]'II\O!M`#*TZ31K0"BZ<VDQ]+!RM.DT:T`X;FZHNG-I,?2P;7I
MN:FZT;KDNZ'1NJ'2P[7-NJ'%T;K+P]?-Y,'H/P#`TLG2`,NYZ=+*V+2WZ=+"
M`,6GNM&YM]:AX*+ITB`E<P"GTKGCN:*ST,6GJM?HS>"BZ=(`M=GIY+O#R;/5
MPNP`H=/+N;3CR^G@N^>Y`*'3R[FTRM7CR^GAM:&UZ-*GH=&YRM/+P]&ZX;7H
MQ=##T+31NJ+-IZ'2P\WITJ?-U*?+P]?-Y,'H`*+IS:3'TL$`X*+5PKFBZ<VD
MQ]+!X\O!Z`#'T;FWU>BBS:>BZ<VDQ]+!`*3IN<O2HNG-I,?2P0"BN=*THLVG
MHNG-I,?2P0"UZ;FINM&ZHNG-I,?2P0"ATL/ARK2GHNG-I,?2P0"UT<>ZZ*>J
MU>FBZ<VDQ]+!`.*_Q>"TS</L`*C3N<>YHNG-I,?2P;7HS<NYZ=+CN<'8P<'-
MI[79Z>2[P\FSU<+L`*+IS:3'TL'DN\+1IP#"Z=+"`*K7Z,T`Y,'HX,77S:$`
MX\O!Z`"HM,O!TL+CR\'H`*+IS:3'TL'CR\'H`*+IS:3'TL&UZ,WDNP#+N>G2
MM>C-Y+L`Y,'H`*'#V+/2P]"ZV.*_Q>"TS</LM]7HM>G-IZ'2PP#DP>B^NJ33
MM]7HRM"AM+S4M`#DP>C!U:33X;G0N=,`Y,'HX,77S:$`Y,'HMMFAQ;H`Y,'H
MXZKHX;JZP^C2IP#DP>CCJNBBZ<VDQ]+!RM.DT:T`Y,'HXZKHHNG-I,?2P<KH
MQ[FUT<<`Y,'HXZKHHNG-I,?2P;?5Z+;9H<6Z`.3!Z..JZ*+IS:3'TL'*TZ31
MK0"BZ<VDQ]+!X*'HT@"AT\71IZ'3J-&TXK_%X+3-P^RHM,O!TL*BTLW-H:+-
MI^"TU\VYH>C-N>8`M=''X,77S:'-U^BY`,NYZ=*WU>@@)60@J-*A("5D`,KH
MQ[F[P]"AS;H`P\O1RKSHTKD`RNC'N;71QP"BZ<W!V<7*Z,>YM=''`."UU,'%
MTL+@J^>YHLVGI-BSX[FATL.US;JAQ=&ZX<70RNBGM>C-/P"AP]BSTK7#QZC*
MS;JWU>C-PMGHJ^G3R\/7S;[4P;[LO-2T`*+IS:3'TL&WU>CAQ>G'`,NYZ=*W
MU>CAQ>G'`+[4P;[L`,6ZXK3"MM+'PP"DQ]+!MM7HX[FATL.ATZC1M+;1IZ+"
MT`#@N\75Z,*YX,KIN;?2IP#@N\75Z,*YX,KIN;?2IZ+IS:3'TL&YU>D`H=+#
MX+O5Z,*YX,KIN;?2I\7IP>#+Q<<`P]7@O\.J`,/5X+_#JL'8P<'-I^*_Q>"T
MS</L`,/5XLO%M,'8P<'-IP"HM*C3P=C!P<VGQ>C2RMBT`*'2P^"[Q=7HPKFJ
MU^C-J-*A("(E<R(@X+OGN2`B)7,B(,7IP>#+Q<<@X*3#U^C-I[K#U*'2P\/2
MPJ?2N<?HT@#AM[FWU>BTZ<?".@"US;JAQ=&Z`+7-NJ'%T;JWT>FGR\&T`+7-
MNJ'%T;JWT>FGR\&T.@"US;JAQ=&ZY+O"T:<Z`+7-NJ'%T;H`P]+"I]*YQ^C2
MX+OGN0"WT[7HS0"UZ<VGH=+#H<71NLK9Z,/2PJ'2P[79Z>2[P\FSU<+LR\71
MIZC2H;?3H=+#Q;HL(,+ITL(@R\/7S<K3X+G2HNG-I,?2P<O#U\WDP>@_`+K1
MN;?6H>"[Y[D`H=+#NM&YM]:AX;JZP^C2I\7IP>#+Q<<@X*3#U^C-I[K#U*'2
MP\/2PJ?2N<?HTCH@)7,`I.FYR](`O,6ATL.DZ;G+T@#-Z-*YX<7IQP#@Q=?-
MH0#@Q=?-H;?1Z:?+P;0`Y,'HX,77S:'@Q<(`XK_%X+3-P^RHM,O!TL*BTLW-
MH0#@I,/7Z,VGNL/4H=+#`*'3R[FTI.C2H=+#H</0M]/@P=?HS;?3H=+#PNG2
MPN'%T,6ZHNG-I,?2P0"UZ<VGH=+#X\OIN]2TR[GITK7HTJ?@HM7"N:BTR\'2
MPLO%T:>HTJ&ZT;FWUJ'ANKK#Z-*GR\/7S>3!Z#\`X<JTI[?5Z+;9H<6Z`.'*
MM*>WU>C@Q=2AXZKIY+OAQ>G'`**YTK0`S=&AHL/0OM3@R,D`M</'J*33RM"A
MM`"UT<>UP\>HI-/*T*&T`+7#QZBDT\K0H;3@P]7"NL/IS<+AQ>G'`*C3N<>Y
MI,?2P;S4M+[%TK2WU>CARK2GX[G+N=;HI\NYZ=*HS:*ST+?3H=+#M</'J*33
MRM"AM`"JU^C-X,/7Z,VG`."BM:+IS:3'TL&JU^C-X,/7Z,VG`.#%U\VAXZKI
MI]*YXK_%X+3-P^P`RM/@P^>H`*33X;G0N=,`P=6DT\?HT@#BO\7@M,W#[+O1
MJ*C8NM&Y("(E<R(@J-"VV:'@N\75Z,*YJM?HS>"[Y[D@(B5S(@#BO\7@M,W#
M["`B)7,B(,'5S<+9Z.'%Z<<`XK_%X+3-P^P@(B5S(B#!U;71Q\W1H<G#M]7H
MY,'HMMFAM>G-I\W"V>CCN:K7Z,T@J];HI\W2J+?3X\OIX*'4M+O1K<O2Y+3I
M(*'#V+/2M=2TM>C-O-GIM-GAQ=##T+JZHLVGI-BS`.*_Q>"TS</L("(E<R(@
MY+3IMMFARL/ITJ>BUNFYX<7IQR#AM>C"T:?DP>CDM.G@P]7"H>.JZ0#BO\7@
MM,W#["`B)7,B(.2TZ;;9H<6ZY+O-S:'AQ>G'(.&UZ*38L\+1I^3!Z.2TZ>#%
MU*'CJND`Y,'HRM+!TL.VRL/ITJ?BO\7@M,W#["`B)7,B(.2TZ2#@I,/7Z,VG
MNL/4H=+#P]+"I]*YQ^C2`.3!Z,K2P=+#ML6ZXK_%X+3-P^P@(B5S(B#DM.D@
MX*3#U^C-I[K#U*'2P\/2PJ?2N<?HT@#BO\7@M,W#["`B)7,B(.2TZ;;9H<K#
MZ=*GHM;IN>##U<*ZP^G-PN'%Z<<`XK_%X+3-P^P@(B5S(B#DM.FVV:'%NN##
MU<*ZP^G-PN'%Z<<`XK_%X+3-P^P@(B5S(B#DM.FVV:'@N\75Z,*YJM?HS>"[
MY[D@(B5S(B#@P]7"NL/IS<+AQ>G'`.3!Z,'5HNG-I,?2P>.YM=GIY+O#R;/5
MPNRYU>D`X*'4M*+IS;S4M+[%TK3CN:'2P\6Z("5S(."DP]?HS:>ZP]2ATL/#
MTL*GTKG'Z-(`X*'4M*+IS;S4M+[%TK3CN:'2P\6ZM=GIY+O#R;/5PNP@X*3#
MU^C-I[K#U*'2P\/2PJ?2N<?HT@#@H=2THNG-O-2TOL72M..YH=+#Q;JBZ<VD
MQ]+!J-*AXK_%X+3-P^P@(B5S(B#@I,/7Z,VGNL/4H=+#P]+"I]*YQ^C2`."A
MU+2BZ<V\U+2^Q=*TX[FATL/%NJ+IS:3'TL'CN>*_Q>"TS</L("(E<R(@X*3#
MU^C-I[K#U*'2P\/2PJ?2N<?HT@#@H=2THNG-O-2TOL72M..YH=+#X<JTI\KH
MQ[FYU>FBS:>BZ<VDQ]+!`."AU+2BZ<V\U+2^Q=*TX[FATL.ZZ*>JU>FBZ<VD
MQ]+!X[GBO\7@M,W#["`B)7,B(."DP]?HS:>ZP]2ATL/#TL*GTKG'Z-(`X*'4
MM*+IS;S4M+[%TK3CN:'2P\KHIZ+IS:3'TL&BS:>DV+,Z("5S`*+IS:3'TL&Y
MU>GDN\+1IP#!V,'!S:?@M\.T`+;6IP#BO\7@M,W#[+;1IZ+"T#H`Y,'HY+3I
MM<VZH<71N@"BZ<VDQ]+!M]7HY,'HY+3IM<VZH<71N@"AV>FDU[D`O-GIP]&Z
MM]7HY,'HX+O4M."\P@#DP>C!U:K7Z,T`PM&GY,'HY+3IX+O4M`#@Q=2AXZKI
MXK_%X+3-P^P`XZKII.C2XK3"N\/4PM+"`*K7Z,V\V>GCJND`X<JTIR`E<P#!
MV,'!S:?+P]?-M=GIY+O#R;/5PNRWU>BUZ<VGH=+#X\OIX<JTI\O%T:>HTJ'%
MIZK7Z,W@HNG2.@"DT^"UU\VY`,+4N;35M>G-N</1NLK9Z"`E<P#CJN@`I-BS
MPM&GY,'HY+3IX,/5PJ'CJND@(B5S(B#@I,/7Z,VGNL/4H=+#P]+"I]*YQ^C2
M`*38L\+1I^3!Z.2TZ>#%U*'CJND@(B5S(B#@I,/7Z,VGNL/4H=+#P]+"I]*Y
MQ^C2`*38L^2TZ>##U<*AXZKI("(E<R(@X,/5PKK#Z<W"X<7IQP"DV+/DM.G@
MQ=2AXZKI("(E<R(@X,/5PKK#Z<W"X<7IQP#%TL+@J^>YHLVGI-BS.@!;Y,'H
MP=6JU^C-X,/7Z,VG70"HTJ$`Y,'HP=4`R\/7S0#*T*&TI-.\U+0`RM"AM*33
MO-2T```````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L;V-A;&4O<W9?4T4O````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-C,`,#$W-#<P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO
M8V%L92]S=E]312],0U]-15-304=%4R\`````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V,P`P,C$R-34`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O;&]C86QE+W-V7U-%+TQ#7TU%4U-!1T53+VEM<"YM
M;P```````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C8S-3<R`#$P-#$W,S8R-S8S`#`R
M,C0Q-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25`````+\+```<````%%X``*T/```,O````````,#Z```*````P?H`
M``H```#,^@``"@```-?Z```*````XOH``$@```#M^@``#@```#;[```/````
M1?L```P```!5^P``#0```&+[```(````</L```L```!Y^P``#````(7[```*
M````DOL```0```"=^P``!````*+[```8````I_L``!L```#`^P``+0```-S[
M```=````"OP``"0````H_```*0```$W\```9````=_P```$```"1_```&0``
M`)/\```F````K?P```P```#4_```"P```.'\```D````[?P``!X````2_0``
M2````#']```K````>OT``$0```"F_0``)P```.O]```7````$_X```\````K
M_@``"P```#O^```.````1_X```4```!6_@``*````%S^```(````A?X```H`
M``"._@``%0```)G^```2````K_X``#(```#"_@``"P```/7^```I`````?\`
M`#(````K_P``$````%[_```6````;_\``!0```"&_P``$````)O_```F````
MK/\``"D```#3_P``)P```/W_```F````)0`!`!P```!,``$`A0```&D``0`.
M````[P`!``H```#^``$`#0````D!`0`G````%P$!`"(````_`0$`(````&(!
M`0`.````@P$!`"(```"2`0$`%P```+4!`0`9````S0$!`"0```#G`0$`(@``
M``P"`0`W````+P(!`#4```!G`@$`$0```)T"`0`-````KP(!``P```"]`@$`
M#0```,H"`0`&````V`(!`!L```#?`@$`E````/L"`0`N````D`,!`#<```"_
M`P$`!@```/<#`0`,````_@,!`'P````+!`$`;````(@$`0`<````]00!`!T`
M```2!0$`"@```#`%`0`/````.P4!`!@```!+!0$`#````&0%`0`;````<04!
M`$4```"-!0$`*````-,%`0!!````_`4!`"0````^!@$`#@```&,&`0`/````
M<@8!``X```""!@$`#@```)$&`0`(````H`8!``X```"I!@$`#@```+@&`0`)
M````QP8!`"X```#1!@$`&@`````'`0`S````&P<!`%$```!/!P$`,@```*$'
M`0`X````U`<!`%0````-"`$`40```&((`0!:````M`@!`%<````/"0$`-```
M`&<)`0`)````G`D!``T```"F"0$`!P```+0)`0`*````O`D!``\```#'"0$`
M!0```-<)`0`#````W0D!``8```#A"0$`$0```.@)`0`(````^@D!``D````#
M"@$`"0````T*`0`=````%PH!``X````U"@$`"````$0*`0`*````30H!`"4`
M``!8"@$`(````'X*`0`)````GPH!`!,```"I"@$`$````+T*`0`/````S@H!
M``\```#>"@$`"@```.X*`0`'````^0H!``,````!"P$`!@````4+`0`9````
M#`L!``\````F"P$`%````#8+`0`)````2PL!``T```!5"P$`$@```&,+`0`9
M````=@L!`!X```"0"P$`#P```*\+`0`*````OPL!``\```#*"P$`"````-H+
M`0`*````XPL!`"0```#N"P$`%P```!,,`0`4````*PP!`!8```!`#`$`$@``
M`%<,`0`(````:@P!`!P```!S#`$`3@```)`,`0`M````WPP!`!D````-#0$`
M8````"<-`0`H````B`T!`!X```"Q#0$`&@```-`-`0`L````ZPT!`"`````8
M#@$`,@```#D.`0`'````;`X!``P```!T#@$`#0```($.`0!4````CPX!`&,`
M``#D#@$`+````$@/`0`.````=0\!``,```"$#P$`"P```(@/`0`'````E`\!
M``<```"<#P$`!0```*0/`0`%````J@\!``H```"P#P$``P```+L/`0`7````
MOP\!``H```#7#P$`#P```.(/`0`.````\@\!`$X````!$`$`4````%`0`0!#
M````H1`!`$(```#E$`$`/0```"@1`0`6````9A$!`#````!]$0$`&````*X1
M`0`C````QQ$!``X```#K$0$`%````/H1`0`7````#Q(!`!<````G$@$`%P``
M`#\2`0`3````5Q(!``\```!K$@$`(P```'L2`0`&````GQ(!`!<```"F$@$`
M#@```+X2`0!1````S1(!`"D````?$P$`'P```$D3`0`=````:1,!`#4```"'
M$P$`-0```+T3`0`'````\Q,!``8```#[$P$`"`````(4`0`/````"Q0!``8`
M```;%`$`"````"(4`0`1````*Q0!``H````]%`$`$P```$@4`0`+````7!0!
M`!````!H%`$`%0```'D4`0`-````CQ0!`!,```"=%`$`(P```+$4`0`O````
MU10!`!4````%%0$`!P```!L5`0`0````(Q4!``4````T%0$`%0```#H5`0`1
M````4!4!``P```!B%0$`/P```&\5`0`P````KQ4!`$@```#@%0$`(0```"D6
M`0`[````2Q8!`#L```"'%@$`/````,,6`0`X`````!<!`"L````Y%P$`,```
M`&47`0`Q````EA<!`#L```#(%P$`.0````08`0`U````/A@!``D```!T&`$`
M!P```'X8`0`4````AA@!``P```";&`$``P```*@8`0`%````K!@!``D```"R
M&`$`$````+P8`0`)````S1@!`!,```#7&`$``P```.L8`0`Y````[Q@!`!(`
M```I&0$`#````#P9`0`U````21D!``X```!_&0$`20```(X9`0`S````V!D!
M`#D````,&@$`"@```$8:`0`6````41H!`!8```!H&@$`+0```'\:`0`+````
MK1H!`"<```"Y&@$`+````.$:`0`J````#AL!`"4````Y&P$`"0```%\;`0`)
M````:1L!``H```!S&P$`!@```'X;`0`)````A1L!``<```"/&P$`+P```)<;
M`0`W````QQL!`"X```#_&P$`50```"X<`0`M````A!P!`"P```"R'`$`+0``
M`-\<`0`]````#1T!`#\```!+'0$`+0```(L=`0!`````N1T!`",```#Z'0$`
M(P```!X>`0!`````0AX!`"T```"#'@$`,P```+$>`0`E````Y1X!`!4````+
M'P$`&0```"$?`0`I````.Q\!`"0```!E'P$`*````(H?`0!0````LQ\!`!@`
M```$(`$`$0```!T@`0`1````+R`!``H```!!(`$`!````$P@`0`,````42`!
M``L```!>(`$`"@```&H@`0`C````=2`!`!8```"9(`$`"@```+`@`0`0````
MNR`!`!8```#,(`$`%@```.,@`0`;````^B`!`"X````6(0$`$````$4A`0`'
M````5B$!``<```!>(0$`%````&8A`0`*````>R$!``@```"&(0$`"````(\A
M`0`(````F"$!``8```"A(0$`)P```*@A`0`(````T"$!``,```#9(0$`!P``
M`-TA`0`'````Y2$!``8```#M(0$`.````/0A`0`%````+2(!``<````S(@$`
M!@```#LB`0`(````0B(!``D```!+(@$`*0```%4B`0`.````?R(!``H```".
M(@$`10```)DB`0`)````WR(!``X```#I(@$`!````/@B`0`$````_2(!``<`
M```"(P$`"0````HC`0`&````%",!`!$````;(P$`!P```"TC`0`6````-2,!
M``0```!,(P$`)P```%$C`0`(````>2,!``8```""(P$`#0```(DC`0`&````
MER,!`!X```">(P$`!0```+TC`0`1````PR,!``@```#5(P$`#0```-XC`0`,
M````[",!``P```#Y(P$`!P````8D`0`#````#B0!``,````2)`$`%P```!8D
M`0`3````+B0!``@```!")`$`'0```$LD`0`(````:20!``0```!R)`$`"```
M`'<D`0`(````@"0!``H```"))`$`*@```)0D`0`K````OR0!`%,```#K)`$`
M00```#\E`0`:````@24!`"L```"<)0$`(````,@E`0`5````Z24!``8```#_
M)0$`!@````8F`0`.````#28!`!4````<)@$`/@```#(F`0`8````<28!`"(`
M``"*)@$`+@```*TF`0`=````W"8!`"$```#Z)@$`*0```!PG`0`*````1B<!
M``<```!1)P$`!P```%DG`0`5````82<!``X```!W)P$``@```(8G`0`*````
MB2<!``\```"4)P$`#0```*0G`0`/````LB<!``T```#")P$`"0```-`G`0`4
M````VB<!``8```#O)P$`&````/8G`0`=````#R@!`!,````M*`$`$0```$$H
M`0`4````4R@!`$\```!H*`$`!````+@H`0`,````O2@!``8```#**`$`"@``
M`-$H`0`-````W"@!`!0```#J*`$`%P```/\H`0!B````%RD!`"<```!Z*0$`
M5````*(I`0!?````]RD!`&0```!7*@$`!````+PJ`0`6````P2H!``X```#8
M*@$`'````.<J`0`/````!"L!`#,````4*P$`*````$@K`0!$````<2L!``4`
M``"V*P$`!0```+PK`0`;````PBL!`!H```#>*P$`#@```/DK`0`3````""P!
M`!4````<+`$`,````#(L`0`1````8RP!`!$```!U+`$`$0```(<L`0`<````
MF2P!`"H```"V+`$`-0```.$L`0!%````%RT!`!````!=+0$`(0```&XM`0`%
M````D"T!`!,```"6+0$`"P```*HM`0`2````MBT!``H```#)+0$`#P```-0M
M`0`-````Y"T!`$<```#R+0$`'P```#HN`0`E````6BX!`#,```"`+@$`*P``
M`+0N`0`U````X"X!`$(````6+P$`'0```%DO`0!1````=R\!`!$```#)+P$`
M,0```-LO`0`[````#3`!`!,```!),`$`0````%TP`0`X````GC`!``4```#7
M,`$`#````-TP`0`1````ZC`!``T```#\,`$`!@````HQ`0`,````$3$!``8`
M```>,0$`%P```"4Q`0`(````/3$!``P```!&,0$`%````%,Q`0`/````:#$!
M`!````!X,0$`$0```(DQ`0`(````FS$!``4```"D,0$`$0```*HQ`0`,````
MO#$!`!````#),0$`!0```-HQ`0`-````X#$!``8```#N,0$`!P```/4Q`0`-
M````_3$!``<````+,@$`"P```!,R`0`'````'S(!``<````G,@$`"0```"\R
M`0`4````.3(!`!<```!.,@$`)@```&8R`0!/````C3(!``D```#=,@$`"0``
M`.<R`0`*````\3(!`!D```#\,@$`/0```!8S`0`=````5#,!``P```!R,P$`
M)0```'\S`0`?````I3,!`!````#%,P$`!0```-8S`0`E````W#,!`"(````"
M-`$`$@```"4T`0`3````.#0!`"L```!,-`$`.P```'@T`0`@````M#0!`!L`
M``#5-`$`"````/$T`0`V````^C0!`"$````Q-0$`$````%,U`0`(````9#4!
M`!L```!M-0$`'@```(DU`0`O````J#4!`%P```#8-0$`+@```#4V`0`,````
M9#8!``8```!Q-@$`!````'@V`0`/````?38!``X```"--@$`#@```)PV`0`*
M````JS8!``<```"V-@$`#@```+XV`0`'````S38!``H```#5-@$`#0```.`V
M`0`>````[C8!`!\````--P$`&P```"TW`0`<````23<!`"$```!F-P$`'@``
M`(@W`0`9````IS<!`!X```#!-P$`&P```.`W`0`L````_#<!`"$````I.`$`
M+@```$LX`0`F````>C@!`"0```"A.`$`&P```,8X`0`<````XC@!`!X```#_
M.`$`'````!XY`0`F````.SD!`#8```!B.0$`*P```)DY`0`S````Q3D!`"D`
M``#Y.0$`00```",Z`0`Z````93H!`"8```"@.@$`*P```,<Z`0`X````\SH!
M`!T````L.P$`'0```$H[`0`5````:#L!`!4```!^.P$`+P```)0[`0`@````
MQ#L!`!(```#E.P$`(````/@[`0`I````&3P!`!X```!#/`$`'@```&(\`0`]
M````@3P!`"````"_/`$`$@```.`\`0"B````\SP!`!8```"6/0$`(P```*T]
M`0`H````T3T!`"D```#Z/0$`.@```"0^`0`H````7SX!`!\```"(/@$`%0``
M`*@^`0`5````OCX!`"````#4/@$`)0```/4^`0`H````&S\!`"T```!$/P$`
M,````'(_`0"2````HS\!`"$````V0`$`%@```%A``0`6````;T`!`!P```"&
M0`$`)@```*-``0`J````RD`!`$$```#U0`$`1````#=!`0`,````?$$!``<`
M``")00$`!P```)%!`0`&````F4$!``T```"@00$`"P```*Y!`0`5````ND$!
M`!0```#000$`#0```.5!`0`8````\T$!`!H````,0@$`$````"="`0`=````
M.$(!`!D```!60@$`70```'!"`0`5````SD(!`"4```#D0@$`$@````I#`0`3
M````'4,!`!(````Q0P$`!P```$1#`0`$````3$,!`!````!10P$`$````&)#
M`0`,````<T,!``X```"`0P$`#0```(]#`0`/````G4,!`!0```"M0P$`$P``
M`,)#`0`-````UD,!`#D```#D0P$`'````!Y$`0`H````.T0!``,```!D1`$`
M#0```&A$`0`&````=D0!`!$```!]1`$`%P```(]$`0`;````IT0!``X```##
M1`$``@```-)$`0`%````U40!``4```#;1`$`$````.%$`0`/````\D0!``0`
M```"10$`#0````=%`0`.````%44!``,````D10$`#@```"A%`0`(````-T4!
M``\```!`10$`"````%!%`0`*````644!``\```!D10$`!P```'1%`0`-````
M?$4!`!````"*10$`%````)M%`0`-````L$4!`!D```"^10$`&@```-A%`0`+
M````\T4!`!$```#_10$`"0```!%&`0`&````&T8!`!0````B1@$`"P```#=&
M`0`3````0T8!`!````!71@$`#````&A&`0`*````=48!`!$```"`1@$`%P``
M`))&`0`1````JD8!`!4```"\1@$`)P```-)&`0`9````^D8!``L````41P$`
M#0```"!'`0`B````+D<!`"L```!11P$`%P```'U'`0`/````E4<!`#0```"E
M1P$`,P```-I'`0`;````#D@!`#0````J2`$`"@```%](`0`8````:D@!`!0`
M``"#2`$`$@```)A(`0`9````JT@!`!8```#%2`$`$````-Q(`0`'````[4@!
M`!````#U2`$`(@````9)`0`<````*4D!`!P```!&20$`#0```&-)`0`'````
M<4D!``P```!Y20$`)@```(9)`0`*````K4D!`!0```"X20$`"P```,U)`0`'
M````V4D!`"(```#A20$`+P````1*`0`+````-$H!``D```!`2@$`&0```$I*
M`0`+````9$H!`"H```!P2@$`#P```)M*`0`7````JTH!`!<```##2@$`"0``
M`-M*`0`'````Y4H!`!8```#M2@$`#P````1+`0`M````%$L!`!D```!"2P$`
M%@```%Q+`0`.````<TL!`!H```""2P$`*````)U+`0`M````QDL!`"X```#T
M2P$`"P```"-,`0`'````+TP!``@````W3`$`#````$!,`0`C````34P!``T`
M``!Q3`$`)@```'],`0`J````IDP!`"````#13`$`0P```/),`0`2````-DT!
M`!\```!)30$`!````&E-`0`(````;DT!``L```!W30$`&@```(--`0`G````
MGDT!`!(```#&30$`(````-E-`0`O````^DT!`!<````J3@$`!0```$).`0`,
M````2$X!``X```!53@$`#@```&1.`0`%````<TX!``8```!Y3@$`#@```(!.
M`0!%````CTX!``,```#53@$``P```-E.`0`K````W4X!``<````)3P$`!```
M`!%/`0`.````%D\!``H````E3P$`#````#!/`0`*````/4\!``\```!(3P$`
M$````%A/`0`7````:4\!`!$```"!3P$`$P```)-/`0`E````IT\!``X```#-
M3P$`$0```-Q/`0`9````[D\!`!<````(4`$`$P```"!0`0`6````-%`!`#@`
M``!+4`$`$P```(10`0`)````F%`!``4```"B4`$`"P```*A0`0`*````M%`!
M``(```"_4`$`!0```,)0`0`-````R%`!`!L```#64`$`%P```/)0`0`4````
M"E$!``D````?40$`'0```"E1`0`O````1U$!``\```!W40$`%@```(=1`0`2
M````GE$!``L```"Q40$`#````+U1`0`.````RE$!``T```#940$`$@```.=1
M`0`9````^E$!`!P````44@$`&````#%2`0`3````2E(!``D```!>4@$``P``
M`&A2`0`5````;%(!``L```""4@$`$P```(Y2`0`(````HE(!``X```"K4@$`
M$````+I2`0`8````RU(!`!@```#D4@$`)P```/U2`0`I````)5,!`"P```!/
M4P$`*````'Q3`0`.````I5,!`#4```"T4P$`!0```.I3`0`A````\%,!`"(`
M```25`$`*0```#54`0`8````7U0!`!X```!X5`$`&P```)=4`0`9````LU0!
M`!@```#-5`$`&P```.94`0`3`````E4!`!,````650$`7````"I5`0`Q````
MAU4!`!H```"Y50$`.0```-15`0`'````#E8!``@````65@$`!@```!]6`0`&
M````)E8!`!L````M5@$`$````$E6`0`/````6E8!`!````!J5@$`#P```'M6
M`0`+````BU8!``\```"75@$`#````*=6`0`/````M%8!``<```#$5@$`!@``
M`,Q6`0`*````TU8!`!(```#>5@$`#0```/%6`0`,````_U8!``X````,5P$`
M0P```!M7`0`]````7U<!``D```"=5P$`#````*=7`0`H````M%<!``\```#=
M5P$`"````.U7`0`(````]E<!`!,```#_5P$`"P```!-8`0`>````'U@!`"$`
M```^6`$`(````&!8`0`9````@5@!`!<```";6`$`)0```+-8`0`7````V5@!
M`!8```#Q6`$`!`````A9`0`;````#5D!``T````I60$`#````#=9`0`#````
M1%D!``4```!(60$`"````$Y9`0`*````5UD!``P```!B60$`"@```&]9`0`@
M````>ED!`!\```";60$`&P```+M9`0`9````UUD!``L```#Q60$`&P```/U9
M`0`+````&5H!`!`````E6@$`"````#9:`0`,````/UH!``X```!,6@$`"P``
M`%M:`0`$````9UH!``0```!L6@$`$P```'%:`0`4````A5H!``P```":6@$`
M"0```*=:`0`.````L5H!``L```#`6@$`&P```,Q:`0`.````Z%H!``\```#W
M6@$`)0````=;`0`J````+5L!``<```!86P$`$@```&!;`0`;````<UL!``0`
M``"/6P$`!P```)1;`0`*````G%L!`!(```"G6P$`"@```+I;`0`-````Q5L!
M``@```#36P$`&````-Q;`0`=````]5L!`!`````37`$`#@```"1<`0`>````
M,UP!`!H```!27`$`"@```&U<`0`$````>%P!`"8```!]7`$`#@```*1<`0!\
M````LUP!`!4````P70$`1````$9=`0`%````BUT!``<```"170$`#````)E=
M`0`(````IET!``H```"O70$`!@```+I=`0`'````P5T!``@```#)70$`$0``
M`-)=`0`9````Y%T!``@```#^70$``@````=>`0`&````"EX!``8````17@$`
M%````!A>`0`5````+5X!``\```!#7@$`$0```%->`0`:````95X!``T```"`
M7@$`$````(Y>`0`;````GUX!``4```"[7@$`!````,%>`0`,````QEX!``D`
M``#37@$`$````-U>`0`)````[EX!``D```#X7@$`!`````)?`0`%````!U\!
M`!H````-7P$`!0```"A?`0`:````+E\!``@```!)7P$`!@```%)?`0`/````
M65\!`!D```!I7P$`#@```(-?`0`'````DE\!``<```":7P$`(@```*)?`0`%
M````Q5\!``D```#+7P$`"@```-5?`0`.````X%\!``(```#O7P$`#0```/)?
M`0`@`````&`!``8````A8`$`"P```"A@`0`-````-&`!``P```!"8`$`"0``
M`$]@`0`&````66`!``4```!@8`$`"0```&9@`0`'````<&`!``0```!X8`$`
M%````'U@`0!"````DF`!`"4```#58`$`)0```/M@`0`&````(6$!``0````H
M80$`"0```"UA`0`(````-V$!`!$```!`80$`#@```%)A`0`)````86$!``8`
M``!K80$`#0```')A`0`&````@&$!``0```"'80$`!````(QA`0`7````D6$!
M`#D```"I80$`/0```.-A`0`Z````(6(!`!X```!<8@$`!0```'MB`0`.````
M@6(!``0```"08@$`!@```)5B`0`'````G&(!`"$```"D8@$`#0```,9B`0`5
M````U&(!``8```#J8@$`$@```/%B`0`$````!&,!`!$````)8P$`!@```!MC
M`0`*````(F,!`"(````M8P$`)P```%!C`0`&````>&,!`!4```!_8P$`#```
M`)5C`0`1````HF,!``0```"T8P$`#0```+EC`0`'````QV,!``4```#/8P$`
M!````-5C`0`,````VF,!``X```#G8P$`"@```/9C`0`(`````60!``D````*
M9`$`!0```!1D`0`Z````&F0!`#````!59`$`-0```(9D`0`I````O&0!`$<`
M``#F9`$`.````"YE`0`I````9V4!`#\```"190$`+@```-%E`0`M`````&8!
M`!\````N9@$`#P```$YF`0`2````7F8!``L```!Q9@$`$````'UF`0`F````
MCF8!`"<```"U9@$`*0```-UF`0`D````!V<!`"8````L9P$`*````%-G`0`(
M````?&<!``H```"%9P$`"0```)!G`0`'````FF<!``0```"B9P$`'````*=G
M`0`W````Q&<!`"````#\9P$`(````!UH`0`F````/F@!``T```!E:`$`)P``
M`'-H`0`;````FV@!`"(```"W:`$`#````-IH`0`6````YV@!``H```#^:`$`
M&0````EI`0`I````(VD!`!8```!-:0$`$@```&1I`0`'````=VD!``H```!_
M:0$`#````(II`0`/````EVD!`!````"G:0$`0````+AI`0!$````^6D!`#P`
M```^:@$`<````'MJ`0!F````[&H!``8```!3:P$`"@```%IK`0`%````96L!
M``X```!K:P$`"0```'IK`0`*````A&L!`!(```"/:P$`$P```*)K`0`,````
MMFL!``8```##:P$`!@```,IK`0`*````T6L!``X```#<:P$`#P```.MK`0`.
M````^VL!`!L````*;`$`'P```"9L`0`>````1FP!`",```!E;`$`$0```(EL
M`0`5````FVP!`!@```"Q;`$`$0```,IL`0`0````W&P!`",```#M;`$`#P``
M`!%M`0`)````(6T!`!(````K;0$`'0```#YM`0`2````7&T!`!````!O;0$`
M"@```(!M`0`1````BVT!``4```"=;0$`,0```*-M`0`D````U6T!`!P```#Z
M;0$`(P```!=N`0!J````.VX!``\```"F;@$`!0```+9N`0`0````O&X!``D`
M``#-;@$`!````-=N`0`+````W&X!`"````#H;@$`'`````EO`0`C````)F\!
M`"(```!*;P$`!@```&UO`0`4````=&\!`!<```");P$`#````*%O`0`D````
MKF\!`",```#3;P$`&@```/=O`0`,````$G`!``\````?<`$`%0```"]P`0`I
M````17`!`"H```!O<`$`)@```)IP`0`G````P7`!`"D```#I<`$`*@```!-Q
M`0`9````/G$!`!$```!8<0$`$@```&IQ`0`3````?7$!`!0```"1<0$`#P``
M`*9Q`0`6````MG$!`!<```#-<0$`$````.5Q`0`1````]G$!`#0````(<@$`
M$P```#UR`0`2````47(!`#4```!D<@$`%````)IR`0`'````KW(!``P```"W
M<@$`*P```,1R`0`/````\'(!`!8`````<P$`(````!=S`0`0````.',!`!0`
M``!)<P$`$0```%YS`0`H````<',!`!<```"9<P$`'````+%S`0`3````SG,!
M``L```#B<P$`%````.YS`0`:`````W0!`!$````>=`$`&@```#!T`0`>````
M2W0!`!H```!J=`$`$P```(5T`0`A````F70!`"````"[=`$`%0```-QT`0`1
M````\G0!`!<````$=0$`%````!QU`0`7````,74!`!4```!)=0$`"0```%]U
M`0`&````:74!`!````!P=0$`&0```(%U`0`$````FW4!``<```"@=0$`"P``
M`*AU`0`1````M'4!``8```#&=0$`!@```,UU`0`&````U'4!``4```#;=0$`
M!P```.%U`0`'````Z74!``4```#Q=0$`%@```/=U`0`&````#G8!``8````5
M=@$`!````!QV`0`$````(78!``<````F=@$`#@```"YV`0`,````/78!``P`
M``!*=@$`#0```%=V`0`"````978!``4```!H=@$`*````&YV`0`,````EW8!
M``\```"D=@$`"@```+1V`0`(````OW8!``D```#(=@$`*P```-)V`0`N````
M_G8!``0````M=P$`"````#)W`0`%````.W<!`"8```!!=P$`$@```&AW`0`/
M````>W<!``8```"+=P$`"@```))W`0`'````G7<!``@```"E=P$`(````*YW
M`0`)````SW<!`!$```#9=P$`"0```.MW`0`4````]7<!``P````*>`$`#0``
M`!=X`0`.````)7@!`!8````T>`$`$0```$MX`0`&````77@!``@```!D>`$`
M`P```&UX`0`&````<7@!`!D```!X>`$`!P```))X`0`$````FG@!``L```"?
M>`$`"P```*MX`0`'````MW@!``4```"_>`$`!P```,5X`0`6````S7@!``T`
M``#D>`$`"@```/)X`0`-````_7@!``H````+>0$`$````!9Y`0`/````)WD!
M`!$````W>0$`%P```$EY`0`*````87D!`!$```!L>0$`"````'YY`0`$````
MAWD!`!$```",>0$`#P```)YY`0`Z````KGD!`"$```#I>0$`!0````MZ`0`7
M````$7H!``P````I>@$`'@```#9Z`0`.````57H!`!````!D>@$`"P```'5Z
M`0!\````@7H!``P```#^>@$`"0````M[`0`'````%7L!``H````=>P$`"0``
M`"A[`0`.````,GL!`!````!!>P$`%0```%)[`0`;````:'L!`!@```"$>P$`
M&@```)U[`0`*````N'L!``D```##>P$`"@```,U[`0`.````V'L!``P```#G
M>P$`#P```/1[`0`(````!'P!``8````-?`$`#````!1\`0`'````(7P!``4`
M```I?`$`"P```"]\`0!'````.WP!``T```"#?`$`"0```)%\`0`$````FWP!
M``,```"@?`$`#````*1\`0`3````L7P!`!,```#%?`$`$P```-E\`0`&````
M[7P!``8```#T?`$`"P```/M\`0`*````!WT!``(````2?0$`!````!5]`0`E
M````&GT!``,```!`?0$`!0```$1]`0`J````2GT!``X```!U?0$`"@```(1]
M`0`%````CWT!``0```"5?0$`"@```)I]`0`-````I7T!`!\```"S?0$`!P``
M`--]`0`B````VWT!``T```#^?0$`!@````Q^`0`(````$WX!``@````<?@$`
M!````"5^`0`%````*GX!`&@````P?@$`"0```)E^`0`,````HWX!`!````"P
M?@$`!0```,%^`0`&````QWX!`",```#.?@$`)0```/)^`0`(````&'\!`#<`
M```A?P$`(@```%E_`0`3````?'\!`!L```"0?P$`+P```*Q_`0`0````W'\!
M``H```#M?P$`$0```/A_`0`/````"H`!``\````:@`$`"@```"J``0`)````
M-8`!`!,````_@`$`&P```%.``0`8````;X`!`!<```"(@`$`%P```*"``0`9
M````N(`!`!\```#2@`$`#@```/*``0`F`````8$!`"8````H@0$``P```$^!
M`0`'````4X$!``@```!;@0$`%````&2!`0`3````>8$!`!````"-@0$`#0``
M`)Z!`0`.````K($!`!8```"[@0$`!P```-*!`0`0````VH$!``H```#K@0$`
M"P```/:!`0`'`````H(!`!,````*@@$`#````!Z"`0`/````*X(!``X````[
M@@$`#````$J"`0`.````5X(!`%$```!F@@$`#P```+B"`0`0````R((!``T`
M``#9@@$`#P```.>"`0`/````]X(!`!<````'@P$`%````!^#`0`1````-(,!
M``\```!&@P$`(````%:#`0`N````=X,!`!H```"F@P$`#````,&#`0`F````
MSH,!``L```#U@P$`#0````&$`0`:````#X0!`$H````JA`$`&0```'6$`0`&
M````CX0!`!H```"6A`$`)0```+&$`0`&````UX0!``8```#>A`$`'P```.6$
M`0`&````!84!``D````,A0$`&````!:%`0`7````+X4!`"@```!'A0$`!@``
M`'"%`0`-````=X4!`"(```"%A0$`5P```*B%`0`3`````(8!`",````4A@$`
M$P```#B&`0`"````3(8!``L```!/A@$`"````%N&`0`-````9(8!``8```!R
MA@$`"@```'F&`0`'````A(8!`!0```",A@$`!@```*&&`0`(````J(8!``X`
M``"QA@$`!P```,"&`0`*````R(8!``L```#3A@$`,@```-^&`0`K````$H<!
M``<````^AP$`#````$:'`0`-````4X<!``P```!AAP$`!````&Z'`0`)````
M<X<!``D```!]AP$`"@```(>'`0`'````DH<!``D```":AP$`#@```*2'`0`'
M````LX<!``H```"[AP$`!P```,:'`0`;````SH<!``\```#JAP$`%0```/J'
M`0`5````$(@!`!(````FB`$`"@```#F(`0`6````1(@!``D```!;B`$`$```
M`&6(`0`'````=H@!`!(```!^B`$`!````)&(`0`$````EH@!``0```";B`$`
M(0```*"(`0`'````PH@!``4```#*B`$`!````-"(`0`,````U8@!``4```#B
MB`$`"P```.B(`0`4````](@!`!$````)B0$`%````!N)`0`7````,(D!`!@`
M``!(B0$`'````&&)`0`9````?HD!``<```"8B0$`!0```*")`0`6````IHD!
M``,```"]B0$`#0```,&)`0`,````SXD!``H```#<B0$`"````.>)`0`+````
M\(D!`!$```#\B0$`"`````Z*`0`7````%XH!``L````OB@$`#````#N*`0`,
M````2(H!`!\```!5B@$`&@```'6*`0`3````D(H!``0```"DB@$`"@```*F*
M`0`$````M(H!``T```"YB@$`#````,>*`0`)````U(H!``P```#>B@$`!0``
M`.N*`0`)````\8H!``4```#[B@$`!P````&+`0`%````"8L!``0````/BP$`
M`@```!2+`0`4````%XL!``T````LBP$`$@```#J+`0`+````38L!`!L```!9
MBP$`'P```'6+`0`/````E8L!`!0```"EBP$`'@```+J+`0`5````V8L!`#@`
M``#OBP$`+````"B,`0`2````58P!`"D```!HC`$`,@```)*,`0`*````Q8P!
M`"P```#0C`$`+@```/V,`0`S````+(T!`#,```!@C0$`.````)2-`0`/````
MS8T!`!0```#=C0$`&````/*-`0`O````"XX!`!`````[C@$`$P```$R.`0`J
M````8(X!`!D```"+C@$`'````*6.`0`?````PHX!``\```#BC@$`$P```/*.
M`0`5````!H\!`!0````<CP$`%````#&/`0`4````1H\!`"````!;CP$`$@``
M`'R/`0`4````CX\!`!4```"DCP$`+0```+J/`0`M````Z(\!`#$````6D`$`
M+@```$B0`0`O````=Y`!`"P```"GD`$`$P```-20`0`E````Z)`!`"0````.
MD0$`*0```#.1`0!(````79$!``P```"FD0$`#0```+.1`0`(````P9$!`!<`
M``#*D0$`"````.*1`0`D````ZY$!`!(````0D@$`#````".2`0`.````,)(!
M`"L````_D@$`$@```&N2`0`A````?I(!`!H```"@D@$`"0```+N2`0!%````
MQ9(!`$$````+DP$`#P```$V3`0`$````79,!`!,```!BDP$`#@```':3`0`&
M````A9,!`!,```",DP$`&````*"3`0`&````N9,!``D```#`DP$`"@```,J3
M`0`+````U9,!``D```#ADP$`#0```.N3`0`,````^9,!``\````&E`$`%P``
M`!:4`0`4````+I0!`!````!#E`$`%@```%24`0`'````:Y0!``X```!SE`$`
M(0```(*4`0`%````I)0!``<```"JE`$`&P```+*4`0`&````SI0!`"H```#5
ME`$`"`````"5`0`&````"94!`!0````0E0$`$0```"65`0!$````-Y4!`#P`
M``!\E0$`#@```+F5`0`X````R)4!``(````!E@$``@````26`0`&````!Y8!
M``X````.E@$`!0```!V6`0`'````(Y8!``X````KE@$`!@```#J6`0`H````
M098!``P```!JE@$`#````'>6`0`<````A)8!`",```"AE@$`!````,66`0`I
M````RI8!`#(```#TE@$`%P```">7`0`?````/Y<!`#,```!?EP$`7````).7
M`0`,````\)<!``P```#]EP$`"P````J8`0`4````%I@!`#X````KF`$`#0``
M`&J8`0`?````>)@!`!````"8F`$`%````*F8`0`'````OI@!``X```#&F`$`
M#````-68`0`,````XI@!`!,```#OF`$`"@````.9`0`=````#ID!`!D````L
MF0$`!0```$:9`0`1````3)D!`!,```!>F0$`#0```'*9`0`1````@)D!`"0`
M``"2F0$`$@```+>9`0`#````RID!`!4```#.F0$`$P```.29`0`2````^)D!
M``L````+F@$`-````!>:`0`+````3)H!`!0```!8F@$`/@```&V:`0`.````
MK)H!`!,```"[F@$`-````,^:`0`Q````!)L!`!(````VFP$`$````$F;`0`8
M````6IL!`!D```!SFP$`(P```(V;`0`B````L9L!`"<```#4FP$`5@```/R;
M`0!-````4YP!`+D```"AG`$`"````%N=`0`)````9)T!``T```!NG0$`!P``
M`'R=`0`*````A)T!``<```"/G0$`#P```)>=`0`&````IYT!``L```"NG0$`
M!````+J=`0`<````OYT!``T```#<G0$`)P```.J=`0`;````$IX!``P````N
MG@$`&@```#N>`0`*````5IX!``<```!AG@$`#0```&F>`0`B````=YX!`"$`
M``":G@$`"````+R>`0`%````Q9X!`!\```#+G@$`!@```.N>`0`0````\IX!
M``@````#GP$`!P````R?`0`-````%)\!``H````BGP$`$@```"V?`0`A````
M0)\!``L```!BGP$`&P```&Z?`0`8````BI\!``@```"CGP$`'@```*R?`0`2
M````RY\!`"P```#>GP$`&@````N@`0`)````)J`!``H````PH`$`%0```#N@
M`0`%````4:`!`!0```!7H`$`!````&R@`0`0````<:`!``8```""H`$`!P``
M`(F@`0`>````D:`!`"@```"PH`$`"@```-F@`0`<````Y*`!`!$````!H0$`
M"P```!.A`0`:````'Z$!`"P````ZH0$`"````&>A`0`4````<*$!`"P```"%
MH0$`)P```+*A`0`K````VJ$!`"H````&H@$`!````#&B`0`$````-J(!``L`
M```[H@$`!0```$>B`0`&````3:(!``@```!4H@$`!@```%VB`0`Q````9*(!
M`!P```"6H@$`"@```+.B`0"B````OJ(!`!L```!AHP$`-````'VC`0`T````
MLJ,!`"````#GHP$`*0````BD`0`G````,J0!`"````!:I`$`00```'ND`0`:
M````O:0!`"@```#8I`$`&@````&E`0!V````'*4!`'D```"3I0$`'`$```VF
M`0`H````*J<!`!T```!3IP$`*0```'&G`0`=````FZ<!`%$```"YIP$`4```
M``NH`0`N````7*@!`%<```"+J`$`-@```..H`0`V````&JD!`"P```!1J0$`
M+````'ZI`0`Q````JZD!`"X```#=J0$`(@````RJ`0`&````+ZH!``@````V
MJ@$`!0```#^J`0`(````1:H!`!D```!.J@$`&0```&BJ`0`J````@JH!``@`
M``"MJ@$`$````+:J`0`K````QZH!`",```#SJ@$`&0```!>K`0`A````,:L!
M`"X```!3JP$`-````(*K`0`(````MZL!`!<```#`JP$`"@```-BK`0`'````
MXZL!`"$```#KJP$`$`````VL`0`-````'JP!`!`````LK`$`!0```#VL`0`.
M````0ZP!``@```!2K`$`"P```%NL`0`4````9ZP!``<```!\K`$`$P```(2L
M`0`(````F*P!`#8```"AK`$`-P```-BL`0`+````$*T!``D````<K0$`"@``
M`":M`0`4````,:T!``\```!&K0$`+P```%:M`0`R````AJT!``L```"YK0$`
M#@```,6M`0`-````U*T!``\```#BK0$`%@```/*M`0`.````":X!`#X````8
MK@$`)P```%>N`0`F````?ZX!`"0```"FK@$`!0```,NN`0`%````T:X!``4`
M``#7K@$`)P```-VN`0`?````!:\!`!8````EKP$`"P```#RO`0`7````2*\!
M``\```!@KP$`!````'"O`0`*````=:\!``D```"`KP$`"P```(JO`0`-````
MEJ\!``P```"DKP$`#@```+&O`0`%````P*\!``0```#&KP$`#0```,NO`0`R
M````V:\!`$4````,L`$`$P```%*P`0`+````9K`!``X```!RL`$`#@```(&P
M`0`)````D+`!``@```":L`$`$````*.P`0`5````M+`!`!,```#*L`$`%P``
M`-ZP`0`'````]K`!`!X```#^L`$`%0```!VQ`0`4````,[$!``4```!(L0$`
M%````$ZQ`0`&````8[$!``L```!JL0$`!P```':Q`0`C````?K$!`!8```"B
ML0$`#P```+FQ`0`.````R;$!`"H```#8L0$`!@````.R`0`,````"K(!`!@`
M```7L@$`#0```#"R`0`1````/K(!`!<```!0L@$`"P```&BR`0`V````=+(!
M``T```"KL@$`"@```+FR`0`B````Q+(!``L```#GL@$`#P```/.R`0`0````
M`[,!`!4````4LP$`+@```"JS`0`Z````6;,!``X```"4LP$`#0```*.S`0`%
M````L;,!``L```"WLP$`#````,.S`0`-````T+,!``T```#>LP$`#@```.RS
M`0`-````^[,!`"`````)M`$`)P```"JT`0`K````4K0!``@```!^M`$`"@``
M`(>T`0`&````DK0!``D```"9M`$`$@```*.T`0`.````MK0!`!<```#%M`$`
M,@```-VT`0`6````$+4!`!P````GM0$`)0```$2U`0`P````:K4!`#$```";
MM0$`+0```,VU`0`.````^[4!`!0````*M@$`!0```!^V`0`.````);8!`!,`
M```TM@$`&@```$BV`0`2````8[8!``<```!VM@$`!@```'ZV`0`3````A;8!
M`!\```"9M@$`%````+FV`0`1````SK8!`$L```#@M@$`$P```"RW`0`'````
M0+<!`!0```!(MP$`&````%VW`0`'````=K<!``4```!^MP$`#````(2W`0`,
M````D;<!`!(```">MP$`!````+&W`0`'````MK<!``H```"^MP$`"P```,FW
M`0`,````U;<!``X```#BMP$`#@```/&W`0`%`````+@!``4````&N`$`+@``
M``RX`0`F````.[@!`",```!BN`$``P```(:X`0`2````BK@!``8```"=N`$`
M!@```*2X`0`>````J[@!`!8```#*N`$`&````.&X`0`.````^K@!`#<````)
MN0$`#@```$&Y`0`7````4+D!`$$```!HN0$`-````*JY`0`E````W[D!`!4`
M```%N@$`,0```!NZ`0`3````3;H!`!L```!AN@$`*@```'VZ`0!1````J+H!
M`%D```#ZN@$`4````%2[`0"_````I;L!`"4```!EO`$`#0```(N\`0`)````
MF;P!`!\```"CO`$``P```,.\`0`'````Q[P!``H```#/O`$`"````-J\`0`"
M````X[P!`!````#FO`$`"````/>\`0`,`````+T!`!4````-O0$`"P```".]
M`0`9````+[T!`"````!)O0$`$@```&J]`0`%````?;T!``H```"#O0$`%0``
M`(Z]`0`2````I+T!``P```"WO0$`!````,2]`0`)````R;T!``<```#3O0$`
M,@```-N]`0`*````#KX!``H````9O@$`%0```"2^`0`,````.KX!``\```!'
MO@$`"P```%>^`0`'````8[X!`!8```!KO@$`4@```(*^`0`Z````U;X!`"``
M```0OP$`#P```#&_`0`7````0;\!`"0```!9OP$`.0```'Z_`0`2````N+\!
M``<```#+OP$`!@```-._`0`)````VK\!``X```#DOP$`#@```/._`0`.````
M`L`!``0````1P`$`!@```!;``0`6````'<`!``P````TP`$`#0```$'``0`.
M````3\`!`!4```!>P`$`$@```'3``0`/````A\`!`!0```"7P`$`%````*S`
M`0!#````P<`!``H````%P0$`&P```!#!`0`U````+,$!`!$```!BP0$`$```
M`'3!`0`+````A<$!`&D```"1P0$`&@```/O!`0`7````%L(!`"@````NP@$`
M)P```%?"`0`;````?\(!`!H```";P@$`%P```+;"`0`;````SL(!`!D```#J
MP@$`'P````3#`0`7````),,!`!P````\PP$`%P```%G#`0`,````<<,!`!,`
M``!^PP$`"````)+#`0`O````F\,!``<```#+PP$`"````-/#`0`0````W,,!
M`!$```#MPP$`"0```/_#`0`5````"<0!``T````?Q`$`!@```"W$`0`=````
M-,0!`",```!2Q`$`!P```';$`0`-````?L0!`!,```",Q`$`"````*#$`0`#
M````J<0!`$8```"MQ`$`0P```/3$`0`R````.,4!`#\```!KQ0$`-P```*O%
M`0!7````X\4!``4````[Q@$`'P```$'&`0`O````8<8!``H```"1Q@$`#0``
M`)S&`0`2````JL8!`"D```"]Q@$`"````.?&`0`-````\,8!`"T```#^Q@$`
M<````"S'`0`_````G<<!`#D```#=QP$`1@```!?(`0`$````7L@!`!````!C
MR`$`$````'3(`0`,````A<@!`!0```"2R`$`'0```*?(`0`<````Q<@!`!$`
M``#BR`$`/0```/3(`0!/````,LD!`"4```""R0$`(````*C)`0`<````R<D!
M``L```#FR0$`)P```/+)`0`:````&LH!`!\````UR@$`'0```%7*`0`H````
M<\H!``\```"<R@$`)0```*S*`0`@````TLH!`"0```#SR@$`)````!C+`0`@
M````/<L!`"4```!>RP$`"P```(3+`0`'````D,L!``T```"8RP$`#````*;+
M`0`7````L\L!``4```#+RP$`!@```-'+`0`Y````V,L!``4````2S`$`#```
M`!C,`0`'````)<P!``D````MS`$`$P```#?,`0`&````2\P!``<```!2S`$`
M"0```%K,`0`$````9,P!`!````!IS`$`"````'K,`0`(````@\P!``0```",
MS`$`"P```)',`0`,````G<P!`!(```"JS`$`$0```+W,`0`,````S\P!`!H`
M``#<S`$`#P```/?,`0`'````!\T!``T````/S0$`#P```!W-`0`,````+<T!
M`!0````ZS0$`%````$_-`0`/````9,T!``X```!TS0$`$@```(/-`0`4````
MELT!``X```"KS0$`#````+K-`0`L````Q\T!`!,```#TS0$`'`````C.`0`H
M````)<X!``8```!.S@$`!P```%7.`0`3````7<X!``4```!QS@$`!````'?.
M`0`,````?,X!`!<```")S@$`$@```*'.`0`I````M,X!``L```#>S@$`#0``
M`.K.`0`4````^,X!`"\````-SP$`"@```#W/`0`,````2,\!``D```!5SP$`
M!@```%_/`0`)````9L\!``@```!PSP$`"0```'G/`0`%````@\\!``H```")
MSP$`$0```)3/`0`*````IL\!`!````"QSP$`$````,+/`0`+````T\\!``8`
M``#?SP$`#@```.;/`0`.````]<\!``T````$T`$`"P```!+0`0`0````'M`!
M`!T````OT`$`$0```$W0`0`+````7]`!``(```!KT`$`"````&[0`0`<````
M=]`!``<```"4T`$`#0```)S0`0`&````JM`!`&0```"QT`$`%@```!;1`0`)
M````+=$!``<````WT0$`)@```#_1`0`X````9M$!`!H```"?T0$`*@```+K1
M`0`[````Y=$!`"@````AT@$`-````$K2`0`9````?](!`!4```"9T@$`!0``
M`*_2`0`+````M=(!``<```#!T@$`"````,G2`0`'````TM(!``4```#:T@$`
M!P```.#2`0`.````Z-(!``D```#WT@$`!@````'3`0`(````"-,!``L````1
MTP$`!P```!W3`0`(````)=,!``<````NTP$`%@```#;3`0`)````3=,!``8`
M``!7TP$`&0```%[3`0`:````>-,!`"````"3TP$`"P```+33`0`0````P-,!
M``8```#1TP$`'````-C3`0`4````]=,!``<````*U`$`$0```!+4`0`(````
M)-0!``X````MU`$`"````#S4`0`%````1=0!`!````!+U`$`"0```%S4`0`0
M````9M0!``8```!WU`$`&0```'[4`0`*````F-0!`!P```"CU`$`!P```,#4
M`0`%````R-0!``4```#.U`$`!````-34`0`0````V=0!`!0```#JU`$`"P``
M`/_4`0`-````"]4!`"@````9U0$`&````$+5`0`7````6]4!``L```!SU0$`
M&@```'_5`0`4````FM4!`"\```"OU0$`!````-_5`0`)````Y-4!``H```#N
MU0$`!P```/G5`0`"`````=8!``X````$U@$`"````!/6`0`?````'-8!`",`
M```\U@$`(P```&#6`0`Q````A-8!`!\```"VU@$`.````-;6`0!X````#]<!
M`"8```"(UP$`&P```*_7`0`Q````R]<!`#$```#]UP$`)P```"_8`0`B````
M5]@!`"````!ZV`$`9````)O8`0`=`````-D!`!0````>V0$`'````#/9`0!=
M````4-D!`%4```"NV0$`.`````3:`0`M````/=H!`#,```!KV@$`2P```)_:
M`0!*````Z]H!`%L````VVP$`*````)+;`0`L````N]L!`#@```#HVP$`*@``
M`"'<`0`E````3-P!`"$```!RW`$`*````)3<`0`L````O=P!`"<```#JW`$`
M)@```!+=`0`;````.=T!`!X```!5W0$`=0```'3=`0`^````ZMT!`$(````I
MW@$`/0```&S>`0`]````JMX!`"D```#HW@$`*0```!+?`0`Q````/-\!`#X`
M``!NWP$`+P```*W?`0`C````W=\!`&(````!X`$`3P```&3@`0`7````M.`!
M`!D```#,X`$`2````.;@`0`V````+^$!`#X```!FX0$`,````*7A`0`@````
MUN$!`#\```#WX0$`-````#?B`0`L````;.(!`!T```"9X@$`'@```+?B`0`J
M````UN(!`(4````!XP$`,````(?C`0`E````N.,!`$$```#>XP$`8````"#D
M`0!;````@>0!`$D```#=Y`$`,0```"?E`0`T````6>4!`#P```".Y0$`.```
M`,OE`0`=````!.8!`!@````BY@$`IP```#OF`0`K````X^8!`"$````/YP$`
M'P```#'G`0`\````4><!`"0```".YP$`*````+/G`0`K````W.<!`"(````(
MZ`$`)@```"OH`0`A````4N@!`",```!TZ`$`)0```)CH`0`E````ON@!`"D`
M``#DZ`$`)P````[I`0`7````-ND!`"D```!.Z0$`(````'CI`0`R````F>D!
M`!P```#,Z0$`+@```.GI`0`Z````&.H!`!T```!3Z@$`$0```''J`0`S````
M@^H!`"4```"WZ@$`.````-WJ`0`G````%NL!`"`````^ZP$`/````%_K`0`F
M````G.L!`!\```##ZP$`,````./K`0!I````%.P!`"X```!^[`$`,0```*WL
M`0!!````W^P!`#X````A[0$`,P```&#M`0`E````E.T!`#T```"Z[0$`90``
M`/CM`0!-````7NX!`%,```"L[@$`5P````#O`0!5````6.\!`$8```"N[P$`
M*@```/7O`0`O````(/`!`%4```!0\`$`(````*;P`0`N````Q_`!`"L```#V
M\`$`,````"+Q`0`J````4_$!`#X```!^\0$`5````+WQ`0!2````$O(!`%H`
M``!E\@$`,@```,#R`0`K````\_(!`$@````?\P$`2@```&CS`0`J````L_,!
M`"8```#>\P$`+`````7T`0!.````,O0!`#(```"!]`$`,````+3T`0`=````
MY?0!`",````#]0$`+P```"?U`0`L````5_4!`"T```"$]0$`<0```++U`0!F
M````)/8!`&\```"+]@$`LP```/OV`0`7````K_<!`"4```#']P$`,@```.WW
M`0`I````(/@!`#X```!*^`$`(@```(GX`0!2````K/@!`"4```#_^`$`"P``
M`"7Y`0`[````,?D!`"<```!M^0$`3@```)7Y`0!'````Y/D!`&(````L^@$`
M20```(_Z`0!5````V?H!`$`````O^P$`+P```'#[`0`R````H/L!`"L```#3
M^P$`*0```/_[`0`/````*?P!`$4````Y_`$`(0```'_\`0`P````H?P!`"T`
M``#2_`$`)0````#]`0`<````)OT!`#$```!#_0$`,0```'7]`0`.````I_T!
M``L```"V_0$`!P```,+]`0`'````ROT!``0```#2_0$`#0```-?]`0`+````
MY?T!``X```#Q_0$`"P````#^`0`%````#/X!`!`````2_@$``@```"/^`0`*
M````)OX!`%8````Q_@$`60```(C^`0!.````XOX!``4````Q_P$`$@```#?_
M`0`$````2O\!``<```!/_P$`"````%?_`0`%````8/\!``,```!F_P$`$```
M`&K_`0`7````>_\!``P```"3_P$`#````*#_`0`-````K?\!`!,```"[_P$`
M#0```,__`0`"````W?\!``<```#@_P$`!@```.C_`0`4````[_\!``P````$
M``(`&````!$``@`&````*@`"`!(````Q``(`#````$0``@`#````40`"`"H`
M``!5``(`!````(```@`&````A0`"``<```",``(`'P```)0``@`U````M``"
M`"X```#J``(`+P```!D!`@`7````20$"`!\```!A`0(`(@```($!`@`E````
MI`$"`"````#*`0(`&P```.L!`@`8````!P("`"0````@`@(`'P```$4"`@`:
M````90("`"$```"``@(`(````*("`@`:````PP("`#(```#>`@(`&@```!$#
M`@`O````+`,"`"L```!<`P(`'P```(@#`@`C````J`,"`!\```#,`P(`&@``
M`.P#`@`A````!P0"`"4````I!`(`)@```$\$`@`E````=@0"`"0```"<!`(`
M&````,$$`@`=````V@0"`"0```#X!`(`&````!T%`@`B````-@4"`"P```!9
M!0(`+P```(8%`@`5````M@4"`"4```#,!0(`/````/(%`@`?````+P8"`",`
M``!/!@(`'P```',&`@`@````DP8"`!H```"T!@(`&````,\&`@`8````Z`8"
M`"8````!!P(`'@```"@'`@`I````1P<"`!X```!Q!P(`,0```)`'`@`*````
MP@<"`!,```#-!P(`"````.$'`@`)````Z@<"`!8```#T!P(`#`````L(`@`7
M````&`@"`"\````P"`(`.````&`(`@`W````F0@"`#$```#1"`(`)`````,)
M`@`'````*`D"`!\````P"0(`#P```%`)`@`4````8`D"``X```!U"0(`#0``
M`(0)`@`D````D@D"``4```"W"0(`!P```+T)`@`,````Q0D"`#L```#2"0(`
M#P````X*`@`1````'@H"`"(````P"@(`)0```%,*`@`:````>0H"`!T```"4
M"@(`&@```+(*`@`1````S0H"``<```#?"@(`QP```.<*`@`&````KPL"``L`
M``"V"P(`&@```,(+`@`5````W0L"``8```#S"P(`"0```/H+`@`8````!`P"
M``L````=#`(`#0```"D,`@`7````-PP"``8```!/#`(`,P```%8,`@`3````
MB@P"`!,```">#`(`!P```+(,`@`/````N@P"`!$```#*#`(`'@```-P,`@`'
M````^PP"`!D````##0(`,@```!T-`@`$````4`T"`$8```!5#0(`(0```)P-
M`@`3````O@T"``P```#2#0(`$0```-\-`@`R````\0T"`!8````D#@(`"```
M`#L.`@`=````1`X"``D```!B#@(`"@```&P.`@`4````=PX"``H```",#@(`
M'0```)<.`@`(````M0X"`!\```"^#@(`"````-X.`@`:````YPX"`"<````"
M#P(`!@```"H/`@`5````,0\"``<```!'#P(`"````$\/`@`)````6`\"`#\`
M``!B#P(`!P```*(/`@`/````J@\"``X```"Z#P(`$````,D/`@`)````V@\"
M``D```#D#P(`"````.X/`@`3````]P\"``0````+$`(`!P```!`0`@`2````
M&!`"`"8````K$`(`#0```%(0`@`9````8!`"`!@```!Z$`(`"P```),0`@`.
M````GQ`"`!D```"N$`(`"@```,@0`@`D````TQ`"`"$```#X$`(`"@```!H1
M`@`3````)1$"`"<````Y$0(`"0```&$1`@`/````:Q$"`!<```![$0(`%```
M`),1`@`H````J!$"``\```#1$0(`(````.$1`@`-`````A("`!0````0$@(`
M#0```"42`@`4````,Q("`!0```!($@(`"@```%T2`@`,````:!("`!<```!U
M$@(`!````(T2`@`J````DA("``P```"]$@(`$0```,H2`@`'````W!("``(`
M``#D$@(`$````.<2`@`8````^!("``L````1$P(``P```!T3`@`(````(1,"
M`!,````J$P(`%P```#X3`@`&````5A,"``<```!=$P(`#0```&43`@`+````
M<Q,"`!0```!_$P(`%0```)03`@`.````JA,"`"\```"Y$P(`(````.D3`@`<
M````"A0"`%<````G%`(`6@```'\4`@`_````VA0"`#8````:%0(`?@```%$5
M`@`5````T!4"``P```#F%0(`,0```/,5`@`)````)18"``4````O%@(`$@``
M`#46`@`_````2!8"`!(```"(%@(`"@```)L6`@`&````IA8"``0```"M%@(`
M!````+(6`@`*````MQ8"`!,```#"%@(`!0```-86`@`&````W!8"``8```#C
M%@(`"````.H6`@`$````\Q8"``P```#X%@(`"@````47`@`Y````$!<"`"X`
M``!*%P(`*0```'D7`@`%````HQ<"`!D```"I%P(`$0```,,7`@`"````U1<"
M``0```#8%P(`"@```-T7`@`&````Z!<"``4```#O%P(``P```/47`@`,````
M^1<"`#L````&&`(`3P```$(8`@`U````DA@"`"<```#(&`(`(0```/`8`@`D
M````$AD"`$4````W&0(`)@```'T9`@`R````I!D"`#,```#7&0(`&@````L:
M`@`=````)AH"`#4```!$&@(`>````'H:`@`T````\QH"`"$````H&P(`5@``
M`$H;`@`H````H1L"`#H```#*&P(`0@````4<`@`9````2!P"`!<```!B'`(`
M)0```'H<`@`9````H!P"`"H```"Z'`(`*P```.4<`@!R````$1T"`"````"$
M'0(`)0```*4=`@`U````RQT"`"$````!'@(`10```",>`@`F````:1X"`#``
M``"0'@(`2P```,$>`@!.````#1\"`"<```!<'P(`*0```(0?`@`A````KA\"
M`"@```#0'P(`*P```/D?`@`=````)2`"`"D```!#(`(`)@```&T@`@`E````
ME"`"`"@```"Z(`(`*````.,@`@`B````#"$"`#H````O(0(`*P```&HA`@`I
M````EB$"`"(```#`(0(`/0```.,A`@!!````(2("`"@```!C(@(`+````(PB
M`@`P````N2("`!(```#J(@(`$P```/TB`@`0````$2,"`'D````B(P(`"0``
M`)PC`@`<````IB,"`!````##(P(`#P```-0C`@`K````Y","`"<````0)`(`
M#@```#@D`@!+````1R0"`*$```"3)`(`<P```#4E`@!\````J24"`$`````F
M)@(`*P```&<F`@!4````DR8"`%,```#H)@(`%P```#PG`@`J````5"<"`#0`
M``!_)P(`)P```+0G`@`6````W"<"``\```#S)P(`KP````,H`@`7````LR@"
M`"@```#+*`(`'P```/0H`@!`````%"D"`!\```!5*0(`'````'4I`@!1````
MDBD"`!H```#D*0(`%````/\I`@`/````%"H"``H````D*@(`!0```"\J`@`&
M````-2H"``@````\*@(`!0```$4J`@`0````2RH"`!(```!<*@(`#````&\J
M`@`0````?"H"`!$```"-*@(`$P```)\J`@`=````LRH"`"````#1*@(`#P``
M`/(J`@`/`````BL"``0````2*P(`"@```!<K`@`$````(BL"``,````G*P(`
M"````"LK`@`)````-"L"``<````^*P(`"P```$8K`@`(````4BL"``<```!;
M*P(`!0```&,K`@`)````:2L"`!0```!S*P(`!@```(@K`@`'````CRL"``@`
M``"7*P(`#P```*`K`@`/````L"L"``P```#`*P(`"````,TK`@`,````UBL"
M``8```#C*P(`"0```.HK`@`+````]"L"``\`````+`(`!@```!`L`@`'````
M%RP"``T````?+`(`!@```"TL`@`4````-"P"``<```!)+`(``P```%$L`@`)
M````52P"``8```!?+`(`#````&8L`@`*````<RP"``P```!^+`(`$0```(LL
M`@`*````G2P"``\```"H+`(`!0```+@L`@`(````OBP"``0```#'+`(`&0``
M`,PL`@`1````YBP"``H```#X+`(`!0````,M`@`8````"2T"`!,````B+0(`
M'````#8M`@`1````4RT"``0```!E+0(`#P```&HM`@`'````>BT"``0```""
M+0(`!````(<M`@`9````C"T"``<```"F+0(``@```*XM`@`"````L2T"`!$`
M``"T+0(`"0```,8M`@`&````T"T"`!(```#7+0(`%P```.HM`@`#`````BX"
M``8````&+@(`#`````TN`@`G````&BX"``(```!"+@(`!````$4N`@`$````
M2BX"``\```!/+@(`$P```%\N`@`'````<RX"``(```![+@(`!P```'XN`@`1
M````ABX"``8```"8+@(`"P```)\N`@`8````JRX"``8```#$+@(`$P```,LN
M`@`0````WRX"`!(```#P+@(`#@````,O`@`/````$B\"``(````B+P(`!@``
M`"4O`@`,````+"\"``D````Y+P(`$0```$,O`@`B````52\"``<```!X+P(`
M!P```(`O`@`+````B"\"``4```"4+P(``@```)HO`@`+````G2\"``X```"I
M+P(`#@```+@O`@"+`0``QR\"``H```!3,0(`"@```%XQ`@`*````:3$"``H`
M``!T,0(`3````'\Q`@`1````S#$"`!(```#>,0(`#P```/$Q`@`.`````3("
M``<````0,@(`"@```!@R`@`'````(S("``H````K,@(`!````#8R`@`#````
M.S("`!@````_,@(`'0```%@R`@`L````=C("`!T```"C,@(`(````,$R`@`F
M````XC("`!<````),P(``0```"$S`@`8````(S,"`"@````\,P(`#````&4S
M`@`.````<C,"`"L```"!,P(`'@```*TS`@!.````S#,"`#$````;-`(`20``
M`$TT`@`N````ES0"`!P```#&-`(`#@```.,T`@`1````\C0"`!(````$-0(`
M!0```!<U`@`C````'34"``@```!!-0(`"@```$HU`@`3````534"``\```!I
M-0(`,@```'DU`@`+````K#4"`"0```"X-0(`+````-TU`@`2````"C8"`!<`
M```=-@(`%0```#4V`@`.````2S8"`$,```!:-@(`(@```)XV`@`B````P38"
M`#$```#D-@(`'@```!8W`@!O````-3<"``@```"E-P(`"@```*XW`@`*````
MN3<"`#<```#$-P(`'@```/PW`@`B````&S@"`!`````^.`(`$0```$\X`@`;
M````83@"`!$```!].`(`(````(\X`@`@````L#@"`#````#1.`(`,`````(Y
M`@`0````,SD"``\```!$.0(`$P```%0Y`@`0````:#D"``8```!Y.0(`&P``
M`(`Y`@")````G#D"`#8````F.@(`-@```%TZ`@`&````E#H"``8```";.@(`
M?@```*(Z`@!W````(3L"`"D```"9.P(`$P```,,[`@`+````USL"`!$```#C
M.P(`'0```/4[`@`*````$SP"`!D````>/`(`3````#@\`@`O````A3P"`$D`
M``"U/`(`+````/\\`@`*````+#T"``L````W/0(`$````$,]`@`0````5#T"
M``D```!E/0(`"@```&\]`@`*````>CT"``L```"%/0(`+````)$]`@`<````
MOCT"`"X```#;/0(`/0````H^`@`[````2#X"`$4```"$/@(`5@```,H^`@!3
M````(3\"`%D```!U/P(`5@```,\_`@`^````)D`"``X```!E0`(`$P```'1`
M`@`.````B$`"`!````"70`(`&````*A``@`%````P4`"``,```#'0`(`!@``
M`,M``@`*````TD`"``4```#=0`(`!@```.-``@`&````ZD`"`"0```#Q0`(`
M$0```!9!`@`*````*$$"``P````S00(`)0```$!!`@`D````9D$"``<```"+
M00(`$````)-!`@`2````I$$"``P```"W00(`#0```,1!`@`&````TD$"``@`
M``#900(`"0```.)!`@`,````[$$"`!P```#Y00(`%````!9"`@`9````*T("
M``X```!%0@(`$@```%1"`@`7````9T("`!X```!_0@(`(P```)Y"`@`:````
MPD("`!````#=0@(`%P```.Y"`@`-````!D,"``\````40P(`*@```"1#`@`8
M````3T,"`!8```!H0P(`&0```']#`@`8````F4,"`!,```"R0P(`&P```,9#
M`@!/````XD,"`#$````R1`(`)````&1$`@!@````B40"`"$```#J1`(`#0``
M``Q%`@`<````&D4"`"8````W10(`&P```%Y%`@`E````>D4"``8```"@10(`
M"0```*=%`@`,````L44"`'4```"^10(`:````#1&`@`T````G48"``X```#2
M1@(`!@```.%&`@`*````Z$8"``@```#S1@(`"````/Q&`@`%````!4<"``<`
M```+1P(`"@```!-'`@`$````'D<"`!P````C1P(`#````$!'`@`1````34<"
M``\```!?1P(`00```&]'`@!1````L4<"`#P````#2`(`30```$!(`@`[````
MCD@"`!D```#*2`(`-````.1(`@`5````&4D"`"8````O20(`"P```%9)`@`:
M````8DD"`!T```!]20(`(0```)M)`@`8````O4D"``\```#620(`$````.9)
M`@`D````]TD"``8````<2@(`%````"-*`@`1````.$H"`$,```!*2@(`+P``
M`(Y*`@`;````ODH"`!L```#:2@(`-0```/9*`@`U````+$L"``<```!B2P(`
M!@```&I+`@`(````<4L"``P```!Z2P(`!````(=+`@`(````C$L"`!4```"5
M2P(`"0```*M+`@`3````M4L"``L```#)2P(`$0```-5+`@`6````YTL"`!``
M``#^2P(`%@````],`@`F````)DP"`"H```!-3`(`'P```'A,`@`'````F$P"
M`!(```"@3`(`!0```+-,`@`6````N4P"``\```#03`(`#````.!,`@`U````
M[4P"`#,````C30(`00```%=-`@`,````F4T"`#$```"F30(`/@```-A-`@`T
M````%TX"`$(```!,3@(`*````(].`@`X````N$X"`#$```#Q3@(`/@```"-/
M`@!`````8D\"`$````"C3P(`"0```.1/`@`(````[D\"`!0```#W3P(`"@``
M``Q0`@`%````%U`"``4````=4`(`"````"-0`@`0````+%`"``L````]4`(`
M&0```$E0`@`%````8U`"`#L```!I4`(`$@```*50`@`,````N%`"`#L```#%
M4`(`#`````%1`@!+````#E$"`"\```!:40(`1@```(I1`@`&````T5$"`!P`
M``#840(`$0```/51`@`I````!U("``<````Q4@(`+P```#E2`@`T````:5("
M`"X```">4@(`+0```,U2`@`)````^U("``D````%4P(`"`````]3`@`'````
M&%,"``H````@4P(`"0```"M3`@`C````-5,"`#0```!94P(`(@```(Y3`@!&
M````L5,"`"$```#X4P(`.````!I4`@`A````4U0"`$,```!U5`(`0@```+E4
M`@`?````_%0"`$`````<50(`)P```%U5`@`J````A54"`$,```"P50(`(0``
M`/15`@`G````%E8"`"P````^5@(`&@```&M6`@`>````AE8"`"H```"E5@(`
M*P```-!6`@`K````_%8"`$X````H5P(`&@```'=7`@`2````DE<"``X```"E
M5P(`"@```+17`@`'````OU<"``T```#'5P(`$0```-57`@`0````YU<"`"$`
M``#X5P(`&0```!I8`@`(````-%@"``T````]6`(`'P```$M8`@`C````:U@"
M`"4```"/6`(`)@```+58`@`5````W%@"``<```#R6`(`!P```/I8`@`5````
M`ED"``H````860(`!@```"-9`@`&````*ED"``@````Q60(`!@```#I9`@`I
M````05D"``@```!K60(``P```'19`@`+````>%D"``<```"$60(`!@```(Q9
M`@`S````DUD"``4```#'60(`!P```,U9`@`&````U5D"``H```#<60(`#0``
M`.=9`@`G````]5D"`!(````=6@(`"````#!:`@!#````.5H"``@```!]6@(`
M#@```(9:`@`.````E5H"``,```"D6@(`!P```*A:`@`)````L%H"``,```"Z
M6@(`"0```+Y:`@`%````R%H"`!<```#.6@(`!````.9:`@`@````ZUH"``@`
M```,6P(`!@```!5;`@`-````'%L"``D````J6P(`)P```#1;`@`$````7%L"
M``8```!A6P(`"0```&A;`@`*````<EL"``P```!]6P(`#````(I;`@`'````
MEUL"``,```"?6P(``P```*-;`@`7````IUL"`!8```"_6P(`#@```-9;`@`D
M````Y5L"``@````*7`(`!0```!-<`@`(````&5P"``<````B7`(`"@```"I<
M`@`?````-5P"`"$```!57`(`3@```'=<`@!%````QEP"`!T````,70(`.```
M`"I=`@`B````8UT"`!<```"&70(`!@```)Y=`@`&````I5T"``8```"L70(`
M%0```+-=`@`M````R5T"`!4```#W70(`'P````U>`@`K````+5X"`!H```!9
M7@(`(P```'1>`@`Q````F%X"``D```#*7@(`!@```-1>`@`(````VUX"`!<`
M``#D7@(`#@```/Q>`@`"````"U\"``P````.7P(`$0```!M?`@`.````+5\"
M`!$````\7P(`#@```$Y?`@`,````75\"`!4```!J7P(`"0```(!?`@`<````
MBE\"`!T```"G7P(`$@```,5?`@`/````V%\"`!(```#H7P(`60```/M?`@`%
M````56`"``H```!;8`(`!0```&9@`@`*````;&`"``H```!W8`(`$P```()@
M`@`7````EF`"`$,```"N8`(`,````/)@`@!5````(V$"`%X```!Y80(`8@``
M`-AA`@`#````.V("`!8````_8@(`$P```%9B`@`H````:F("`!,```"38@(`
M-@```*=B`@`N````WF("`"D````-8P(`!0```#=C`@`$````/6,"`!P```!"
M8P(`'@```%]C`@`,````?F,"`!$```"+8P(`%0```)UC`@`M````LV,"``T`
M``#A8P(`$0```.]C`@`,`````60"`!L````.9`(`)````"ID`@`K````3V0"
M`$(```![9`(`!0```+YD`@`>````Q&0"``4```#C9`(`%0```.ED`@`+````
M_V0"`!,````+90(`#P```!]E`@`2````+V4"`!,```!"90(`3````%9E`@`C
M````HV4"`"T```#'90(`.````/5E`@`U````+F8"`#(```!D9@(`/````)=F
M`@`@````U&8"`%$```#U9@(`&````$=G`@`W````8&<"`#X```"89P(`$P``
M`-=G`@!+````ZV<"`#@````W:`(`!0```'!H`@`-````=F@"``X```"$:`(`
M#@```)-H`@`$````HF@"``L```"G:`(`"````+-H`@`7````O&@"``4```#4
M:`(`"@```-IH`@`1````Y6@"``H```#W:`(`%0````)I`@`2````&&D"``@`
M```K:0(`!````#1I`@`/````.6D"``T```!):0(`!P```%=I`@`)````7VD"
M``\```!I:0(`"P```'EI`@`(````A6D"``\```".:0(`"0```)YI`@`$````
MJ&D"``<```"M:0(`!P```+5I`@`(````O6D"`!4```#&:0(`&@```-QI`@`H
M````]VD"`$T````@:@(`!P```&YJ`@`%````=FH"``4```!\:@(`&````()J
M`@!0````FVH"`"$```#L:@(`#@````YK`@`D````'6L"`"<```!":P(`$0``
M`&IK`@`%````?&L"``4```"":P(`*````(AK`@`9````L6L"`!H```#+:P(`
M+````.9K`@`T````$VP"`"@```!(;`(`)0```'%L`@`)````EVP"`"4```"A
M;`(`(@```,=L`@`/````ZFP"``@```#Z;`(`%@````-M`@`9````&FT"`"<`
M```T;0(`6P```%QM`@`Q````N&T"``P```#J;0(`!@```/=M`@`'````_FT"
M`!H````&;@(`$0```"%N`@`1````,VX"``H```!%;@(`!P```%!N`@`/````
M6&X"``L```!H;@(`"@```'1N`@`/````?VX"`"$```"/;@(`(@```+%N`@`@
M````U&X"`"$```#U;@(`)````!=O`@`C````/&\"`!\```!@;P(`)@```(!O
M`@`A````IV\"`"H```#);P(`)````/1O`@`I````&7`"`"4```!#<`(`(P``
M`&EP`@`=````C7`"`!X```"K<`(`(````,IP`@`;````ZW`"`"8````'<0(`
M.@```"YQ`@`M````:7$"`"L```"7<0(`)P```,-Q`@`U````ZW$"`#$````A
M<@(`(@```%-R`@`K````=G("`#<```"B<@(`'0```-IR`@`=````^'("`!D`
M```6<P(`&0```#!S`@`P````2G,"`"$```![<P(`$@```)US`@`A````L',"
M`"@```#2<P(`&@```/MS`@`8````%G0"`#X````O=`(`'@```&YT`@`1````
MC70"`+8```"?=`(`$@```%9U`@`<````:74"`"4```"&=0(`)@```*QU`@`O
M````TW4"`"`````#=@(`)````"1V`@`:````278"`!H```!D=@(`)````']V
M`@`D````I'8"`"L```#)=@(`+````/5V`@`G````(G<"`(P```!*=P(`'P``
M`-=W`@`5````]W<"`!4````->`(`'@```"-X`@`I````0G@"`"D```!L>`(`
M1````)9X`@!$````VW@"``L````@>0(`!````"QY`@`&````,7D"``4````X
M>0(`"@```#YY`@`-````27D"`!,```!7>0(`$````&MY`@`*````?'D"`!L`
M``"'>0(`&````*-Y`@`(````O'D"`"8```#%>0(`'0```.QY`@!L````"GH"
M``T```!W>@(`'@```(5Z`@`/````I'H"`!8```"T>@(`$0```,MZ`@`(````
MW7H"``0```#F>@(`$````.MZ`@`/````_'H"``L````,>P(`#@```!A[`@`0
M````)WL"``X````X>P(`'````$=[`@`2````9'L"``P```!W>P(`0````(1[
M`@`F````Q7L"`#8```#L>P(`"````"-\`@`+````+'P"``8````X?`(`$@``
M`#]\`@`8````4GP"`!L```!K?`(`"````(=\`@`"````D'P"``8```"3?`(`
M!@```)I\`@`2````H7P"``X```"T?`(`!0```,-\`@`.````R7P"``@```#8
M?`(``P```.%\`@`.````Y7P"``@```#T?`(`"0```/U\`@`&````!WT"``@`
M```.?0(`#0```!=]`@`(````)7T"``P````N?0(`$0```#M]`@`/````37T"
M``P```!=?0(`&@```&I]`@`;````A7T"``P```"A?0(`$0```*Y]`@`)````
MP'T"``8```#*?0(`&P```-%]`@`+````[7T"`!<```#Y?0(`#P```!%^`@`,
M````(7X"``L````N?@(`$0```#I^`@`5````3'X"``L```!B?@(`%````&Y^
M`@`N````@WX"`!P```"R?@(`"P```,]^`@`-````VWX"`!\```#I?@(`)P``
M``E_`@`9````,7\"`!0```!+?P(`*P```&!_`@`_````C'\"`!H```#,?P(`
M,0```.=_`@`*````&8`"`!4````D@`(`$````#J``@`2````2X`"`!4```!>
M@`(`$@```'2``@`5````AX`"``<```"=@`(`%````*6``@`D````NH`"`!0`
M``#?@`(`'0```/2``@`+````$H$"``<````>@0(`#0```":!`@`K````-($"
M``@```!@@0(`$0```&F!`@`+````>X$"``@```"'@0(`(@```)"!`@`O````
MLX$"``H```#C@0(`"0```.Z!`@`>````^($"``L````7@@(`*````"."`@`4
M````3(("`!L```!A@@(`&P```'V"`@`'````F8("``0```"A@@(`%P```*:"
M`@`5````OH("`#,```#4@@(`'`````B#`@`7````)8,"``X````]@P(`$@``
M`$R#`@`K````7X,"`!T```"+@P(`'@```*F#`@`)````R(,"``H```#2@P(`
M"````-V#`@`1````YH,"`"T```#X@P(`"P```":$`@`B````,H0"`"$```!5
MA`(`%0```'>$`@`Y````C80"`!<```#'A`(`(P```-^$`@`$`````X4"``4`
M```(A0(`"`````Z%`@`8````%X4"`"0````PA0(`#@```%6%`@`@````9(4"
M`"T```"%A0(`$P```+.%`@`&````QX4"``L```#.A0(`#````-J%`@`*````
MYX4"``8```#RA0(`!@```/F%`@`,`````(8"`%8````-A@(`!````&2&`@`#
M````:88"`"H```!MA@(`!P```)B&`@`%````H(8"`!<```"FA@(`"P```+Z&
M`@`,````RH8"``L```#7A@(`$````..&`@`2````](8"`!D````'AP(`$0``
M`"&'`@`3````,X<"`"X```!'AP(`%P```':'`@`8````CH<"`!L```"GAP(`
M&P```,.'`@`7````WX<"`!(```#WAP(`-@````J(`@`7````08@"``H```!9
MB`(`!P```&2(`@`+````;(@"``H```!XB`(``@```(.(`@`&````AH@"``P`
M``"-B`(`)0```)J(`@`@````P(@"`!8```#AB`(`#````/B(`@`A````!8D"
M`#8````GB0(`#````%Z)`@`4````:XD"``\```"`B0(`#@```)")`@`0````
MGXD"`!````"PB0(`#@```,&)`@`0````T(D"`!P```#AB0(`'P```/Z)`@`K
M````'HH"`!D```!*B@(`"0```&2*`@`$````;HH"`"(```!SB@(`$P```):*
M`@`:````JHH"``<```#%B@(`#P```,V*`@`-````W8H"`"$```#KB@(`&```
M``V+`@`B````)HL"`!\```!)BP(`+0```&F+`@`;````EXL"`!````"SBP(`
M'@```,2+`@`#````XXL"`!X```#GBP(`'P````:,`@`F````)HP"`!T```!-
MC`(`+````&N,`@`K````F(P"`!P```#$C`(`*0```.&,`@`C````"XT"`!<`
M```OC0(`&@```$>-`@!@````8HT"`!L```##C0(`'@```-^-`@`W````_HT"
M``<````VC@(`"````#Z.`@`&````1XX"``8```!.C@(`$0```%6.`@`.````
M9XX"``X```!VC@(`#P```(6.`@`-````E8X"`!````"CC@(`#P```+2.`@`+
M````Q(X"`!(```#0C@(``P```...`@`)````YXX"``X```#QC@(`%0````"/
M`@`.````%H\"``X````ECP(`$@```#2/`@!!````1X\"`#@```")CP(`"@``
M`,*/`@`.````S8\"`"\```#<CP(`#0````R0`@`(````&I`"``T````CD`(`
M(````#&0`@`-````4I`"`"4```!@D`(`)@```(:0`@`E````K9`"`",```#3
MD`(`(P```/>0`@`K````&Y$"`"(```!'D0(`&@```&J1`@`#````A9$"``X`
M``")D0(`"````)B1`@`+````H9$"``,```"MD0(`!0```+&1`@`(````MY$"
M``D```#`D0(`"P```,J1`@`,````UI$"`",```#CD0(`(0````>2`@`?````
M*9("`!T```!)D@(`"P```&>2`@`@````<Y("``\```"4D@(`$@```*22`@`'
M````MY("``H```"_D@(`#@```,J2`@`.````V9("``0```#HD@(``P```.V2
M`@`3````\9("`!4````%DP(`#````!N3`@`'````*),"``8````PDP(`#@``
M`#>3`@`:````1I,"`!,```!ADP(`$P```'63`@`A````B9,"`"4```"KDP(`
M!@```-&3`@`5````V),"`!<```#NDP(``P````:4`@`'````"I0"``T````2
ME`(`%````""4`@`,````-90"``X```!"E`(`#P```%&4`@`7````890"`"$`
M``!YE`(`#0```)N4`@`3````J90"`"$```"]E`(`)````-^4`@`(````!)4"
M``,````-E0(`)0```!&5`@`-````-Y4"`$X```!%E0(`%````)25`@`W````
MJ94"``@```#AE0(`"@```.J5`@`1````]94"``H````'E@(`#````!*6`@`%
M````'Y8"``X````EE@(`#P```#26`@`:````1)8"`"(```!?E@(`#@```(*6
M`@`"````D98"``4```"4E@(`"0```)J6`@`3````I)8"`!H```"XE@(`$P``
M`-.6`@`8````YY8"`"``````EP(`#@```"&7`@`2````,)<"`!D```!#EP(`
M!0```%V7`@`$````8Y<"``L```!HEP(`"0```'27`@`7````?I<"``@```"6
MEP(`$0```)^7`@`#````L9<"``0```"UEP(`(````+J7`@`%````VY<"`!@`
M``#AEP(`"````/J7`@`&`````Y@"`!8````*F`(`'0```"&8`@`-````/Y@"
M``@```!-F`(`"````%:8`@`D````7Y@"``4```"$F`(`"0```(J8`@`'````
ME)@"`!4```"<F`(``@```+*8`@`2````M9@"`!\```#(F`(`!@```.B8`@`,
M````[Y@"``T```#\F`(`#@````J9`@`(````&9D"`!0````BF0(`!````#>9
M`@`(````/)D"``<```!%F0(``P```$V9`@`3````49D"`#T```!EF0(`)@``
M`*.9`@`I````RID"``<```#TF0(`!````/R9`@`)`````9H"``@````+F@(`
M$````!2:`@`3````)9H"``<````YF@(`!@```$&:`@`-````2)H"``8```!6
MF@(``P```%V:`@`$````89H"`!L```!FF@(`,0```(*:`@`V````M)H"`#,`
M``#KF@(`&@```!^;`@`%````.IL"``P```!`FP(`!0```$V;`@`&````4YL"
M``@```!:FP(`&````&.;`@`2````?)L"`!<```"/FP(`!````*>;`@`-````
MK)L"``4```"ZFP(`$0```,";`@`-````TIL"``@```#@FP(`%P```.F;`@`?
M`````9P"``0````AG`(`#0```":<`@`-````-)P"`!````!"G`(``P```%.<
M`@`-````5YP"``4```!EG`(`!````&N<`@`#````<)P"``L```!TG`(`"@``
M`("<`@`,````BYP"``@```"8G`(`"0```*&<`@`%````JYP"`#T```"QG`(`
M,0```.^<`@`_````(9T"`!T```!AG0(`00```'^=`@`W````P9T"`"@```#Y
MG0(`.0```"*>`@`N````7)X"`#(```"+G@(`(0```+Z>`@`1````X)X"`!4`
M``#RG@(`#`````B?`@`.````%9\"`"\````DGP(`&0```%2?`@`D````;I\"
M`"0```"3GP(`(P```+B?`@`C````W)\"``D`````H`(`"@````J@`@`*````
M%:`"``8````@H`(`!````">@`@`D````+*`"`#,```!1H`(`)0```(6@`@`F
M````JZ`"`#````#2H`(`#0````.A`@`H````$:$"`!T````ZH0(`'P```%BA
M`@`/````>*$"`!<```"(H0(`"0```*"A`@`>````JJ$"`"H```#)H0(`&@``
M`/2A`@`0````#Z("``8````@H@(`#0```">B`@`-````-:("``\```!#H@(`
M$@```%.B`@`[````9J("`$X```"BH@(`5@```/&B`@"1````2*,"`&0```#:
MHP(`"````#^D`@`-````2*0"``0```!6I`(`%0```%ND`@`*````<:0"``L`
M``!\I`(`$0```(BD`@`2````FJ0"``X```"MI`(`!@```+RD`@`)````PZ0"
M`!````#-I`(`$P```-ZD`@`5````\J0"`!0````(I0(`'P```!VE`@`E````
M/:4"`"4```!CI0(`)@```(FE`@`7````L*4"`!@```#(I0(`'@```.&E`@`7
M`````*8"`!(````8I@(`)0```"NF`@`2````4:8"``<```!DI@(`$P```&RF
M`@`C````@*8"`!0```"DI@(`$0```+FF`@`(````RZ8"`!$```#4I@(`!@``
M`.:F`@`W````[:8"`",````EIP(`)````$FG`@`J````;J<"`&X```"9IP(`
M"@````BH`@`&````$Z@"`!8````:J`(`"@```#&H`@`$````/*@"``L```!!
MJ`(`)P```$VH`@`C````=:@"`"8```"9J`(`)@```,"H`@`&````YZ@"`!0`
M``#NJ`(`%0````.I`@`+````&:D"`"8````EJ0(`*0```$RI`@`<````=JD"
M``T```"3J0(`#P```*&I`@`3````L:D"`"4```#%J0(`)````.NI`@`<````
M$*H"`!X````MJ@(`(0```$RJ`@`@````;JH"`!8```"/J@(`$0```*:J`@`0
M````N*H"`!,```#)J@(`$@```-VJ`@`2````\*H"`!4````#JP(`%````!FK
M`@`0````+JL"``\````_JP(`*0```$^K`@`1````>:L"`!$```"+JP(`.P``
M`)VK`@`4````V:L"``8```#NJP(`#````/6K`@`L`````JP"``\````OK`(`
M%@```#^L`@`A````5JP"`!8```!XK`(`%0```(^L`@`2````I:P"`",```"X
MK`(`%@```-RL`@`<````\ZP"`!,````0K0(`#P```"2M`@`5````-*T"`!H`
M``!*K0(`&````&6M`@`=````?JT"`"$```"<K0(`(0```+ZM`@`5````X*T"
M`"4```#VK0(`)0```!RN`@`4````0JX"`!0```!7K@(`&````&RN`@`:````
MA:X"`!@```"@K@(`%@```+FN`@`+````T*X"``\```#<K@(`#P```.RN`@`$
M````_*X"``0````!KP(`!@````:O`@`+````#:\"`!$````9KP(`!@```"NO
M`@`+````,J\"``8````^KP(`!P```$6O`@`'````3:\"``<```!5KP(`!0``
M`%VO`@`5````8Z\"``8```!YKP(`"0```("O`@`$````BJ\"``0```"/KP(`
M!P```)2O`@`-````G*\"``P```"JKP(`#@```+>O`@`,````QJ\"``(```#3
MKP(`!0```-:O`@`I````W*\"``T````&L`(`"P```!2P`@`+````(+`"``D`
M```LL`(`$````#:P`@`P````1[`"`#````!XL`(`!````*FP`@`(````KK`"
M``4```"WL`(`"0```+VP`@`(````Q[`"`!$```#0L`(`!@```.*P`@`)````
MZ;`"``<```#SL`(`!0```/NP`@`$`````;$"``P````&L0(`$P```!.Q`@`+
M````)[$"`!$````SL0(`#P```$6Q`@`2````5;$"`!8```!HL0(`'@```'^Q
M`@`:````GK$"``@```"YL0(`"````,*Q`@`#````R[$"``8```#/L0(`)0``
M`-:Q`@`'````_+$"``<````$L@(`#0````RR`@`-````&K("``<````HL@(`
M!````#"R`@`'````-;("``8````]L@(`#0```$2R`@`'````4K("``@```!:
ML@(`"0```&.R`@`3````;;("`!4```"!L@(`#0```)>R`@`2````I;("``@`
M``"XL@(`#````,&R`@`(````SK("``0```#7L@(`#P```-RR`@`0````[+("
M`$(```#]L@(`'P```$"S`@`&````8+,"`!P```!GLP(`!````(2S`@`?````
MB;,"``X```"ILP(`#P```+BS`@`.````R+,"`&X```#7LP(`#````$:T`@`)
M````4[0"``<```!=M`(`"@```&6T`@`)````<+0"``X```!ZM`(`$````(FT
M`@`.````FK0"`"4```"IM`(`)0```,^T`@`B````];0"``H````8M0(`!P``
M`".U`@`)````*[4"``L````UM0(`"P```$&U`@`)````3;4"``4```!7M0(`
M"````%VU`@`0````9K4"``@```!WM0(`!0```("U`@`0````AK4"`$X```"7
MM0(`&````.:U`@`)````_[4"``8````)M@(``P```!"V`@`-````%+8"`!``
M```BM@(`$````#.V`@`4````1+8"``4```!9M@(`!@```%^V`@`*````9K8"
M``D```!QM@(``@```'NV`@`$````?K8"`",```"#M@(``P```*>V`@`%````
MJ[8"``H```"QM@(`#````+RV`@`*````R;8"``8```#4M@(`!@```-NV`@`+
M````XK8"`!(```#NM@(`)@````&W`@`(````*+<"`"T````QMP(`#0```%^W
M`@`&````;;<"``@```!TMP(`"@```'VW`@`$````B+<"``4```"-MP(`=@``
M`).W`@`+````"K@"``X````6N`(`%P```"6X`@`$````/;@"``@```!"N`(`
M*P```$NX`@`L````=[@"``P```"DN`(`+P```+&X`@`L````X;@"`!X````.
MN0(`%0```"VY`@`O````0[D"``T```!SN0(`"@```(&Y`@`(````C+D"``@`
M``"5N0(`#@```)ZY`@`+````K;D"``D```"YN0(`%````,.Y`@`S````V+D"
M`"@````,N@(`)P```#6Z`@`5````7;H"`!````!SN@(`&@```(2Z`@`-````
MG[H"`!H```"MN@(`*````,BZ`@`#````\;H"``<```#UN@(`!P```/VZ`@`+
M````!;L"`!`````1NP(`#@```"*[`@`)````,;L"`!`````[NP(`&P```$R[
M`@`)````:+L"``X```!RNP(`"0```(&[`@`/````B[L"``H```";NP(`$```
M`*:[`@`/````M[L"`!<```#'NP(`$0```-^[`@`1````\;L"``\````#O`(`
M30```!.\`@`1````8;P"`!X```!SO`(`$0```)*\`@`1````I+P"`!(```"V
MO`(`%P```,F\`@`8````X;P"`!<```#ZO`(`$@```!*]`@`5````);T"`#,`
M```[O0(`%0```&^]`@`-````A;T"`!X```"3O0(`#P```+*]`@`*````PKT"
M`"$```#-O0(`3````.^]`@`9````/+X"``4```!6O@(`'P```%R^`@`N````
M?+X"``<```"KO@(`!@```+.^`@`+````NKX"``8```#&O@(`!P```,V^`@`G
M````U;X"`"8```#]O@(`*@```"2_`@`&````3[\"``<```!6OP(`+P```%Z_
M`@!5````CK\"`!4```#DOP(`)P```/J_`@`3````(L`"``(````VP`(`#```
M`#G``@`(````1L`"``P```!/P`(`!0```%S``@`*````8L`"``<```!MP`(`
M"0```'7``@`&````?\`"``D```"&P`(`#````)#``@`(````G<`"``D```"F
MP`(`"````+#``@`R````N<`"`"@```#LP`(`!P```!7!`@`/````'<$"`!$`
M```MP0(`$````#_!`@`&````4,$"``H```!7P0(`#@```&+!`@`,````<<$"
M``H```!^P0(`"@```(G!`@`0````E,$"``H```"EP0(`"@```+#!`@`'````
MN\$"``X```##P0(`'````-+!`@`5````[\$"`!4````%P@(`!P```!O"`@`*
M````(\("`!0````NP@(`"@```$/"`@`0````3L("``<```!?P@(`&````&?"
M`@`%````@,("``@```"&P@(`!````(_"`@`G````E,("``<```"\P@(`!0``
M`,3"`@`$````RL("``X```#/P@(`!0```-["`@`-````Y,("`!<```#RP@(`
M#P````K#`@`6````&L,"`!D````QPP(`%P```$O#`@`<````8\,"`!8```"`
MPP(`!P```)?#`@`&````G\,"`!0```"FPP(``@```+O#`@`.````OL,"``L`
M``#-PP(`!P```-G#`@`/````X<,"``\```#QPP(`%P````'$`@`&````&<0"
M`!P````@Q`(`"P```#W$`@`/````2<0"``T```!9Q`(`(@```&?$`@`:````
MBL0"`!4```"EQ`(`!P```+O$`@`-````P\0"``4```#1Q`(`$````-?$`@`0
M````Z,0"``H```#YQ`(`$P````3%`@`&````&,4"``D````?Q0(`!0```"G%
M`@`'````+\4"``0````WQ0(`!````#S%`@`#````0<4"`!<```!%Q0(`$```
M`%W%`@`;````;L4"`!````"*Q0(`)0```)O%`@`H````P<4"`!4```#JQ0(`
M'0````#&`@`H````'L8"``\```!'Q@(`.P```%?&`@`S````D\8"`!(```#'
MQ@(`+P```-K&`@`R````"L<"``X````]QP(`/````$S'`@`O````B<<"`#0`
M``"YQP(`-````.['`@`X````(\@"`!(```!<R`(`$P```&_(`@`8````@\@"
M`#<```"<R`(`$P```-3(`@`0````Z,@"`"<```#YR`(`%````"')`@`?````
M-LD"`"(```!6R0(`%0```'G)`@`2````C\D"`!(```"BR0(`%````+7)`@`8
M````RLD"`!L```#CR0(`*````/_)`@`3````*,H"`!4````\R@(`&@```%+*
M`@`N````;<H"`"X```"<R@(`,@```,O*`@`O````_LH"`#`````NRP(`+0``
M`%_+`@`=````C<L"`"\```"KRP(`+P```-O+`@`P````"\P"`$`````\S`(`
M$P```'W,`@`4````D<P"``L```"FS`(`&0```++,`@`*````S,P"`#````#7
MS`(`#`````C-`@`/````%<T"``P````ES0(`+````#+-`@`8````7\T"`"X`
M``!XS0(`(@```*?-`@`+````RLT"`%4```#6S0(`1@```"S.`@`.````<\X"
M``4```""S@(`'````(C.`@`,````I<X"``8```"RS@(`$````+G.`@`2````
MRLX"``4```#=S@(`"@```./.`@`)````[LX"``H```#XS@(`"0````//`@`*
M````#<\"``T````8SP(`#P```";/`@`;````-L\"`!<```!2SP(`$0```&K/
M`@`6````?,\"``H```"3SP(`"P```)[/`@`4````JL\"``P```"_SP(`"0``
M`,S/`@`@````UL\"``,```#WSP(`'P```/O/`@`(````&]`"``8````DT`(`
M#````"O0`@`.````.-`"`$8```!'T`(`30```([0`@`+````W-`"`$(```#H
MT`(``@```"O1`@`%````+M$"``8````TT0(`#0```#O1`@`%````2=$"``<`
M``!/T0(`&0```%?1`@`&````<=$"`"X```!XT0(`$0```*?1`@`0````N=$"
M`!T```#*T0(`)0```.C1`@`$````#M("`"H````3T@(`*````#[2`@`<````
M9]("`"````"$T@(`,@```*72`@!9````V-("``L````RTP(`"@```#[3`@`*
M````2=,"`!0```!4TP(`1P```&G3`@`,````L=,"`!D```"^TP(`#@```-C3
M`@`<````Y],"``T````$U`(`%````!+4`@`.````)]0"``P````VU`(`$@``
M`$/4`@`*````5M0"`!P```!AU`(`&0```'[4`@`%````F-0"`!,```">U`(`
M$@```++4`@`3````Q=0"`!````#9U`(`)@```.K4`@`3````$=4"``,````E
MU0(`%0```"G5`@`,````/]4"`!(```!,U0(`"0```%_5`@`V````:=4"`!$`
M``"@U0(`&0```++5`@`Z````S-4"`!$````'U@(`$0```!G6`@`K````*]8"
M`"4```!7U@(`&0```'W6`@`'````E]8"`!````"?U@(`&0```+#6`@`=````
MRM8"`!T```#HU@(`(P````;7`@!2````*M<"`$<```!]UP(`I@```,77`@`'
M````;-@"``@```!TV`(`$P```'W8`@`.````D=@"`!(```"@V`(`#P```+/8
M`@`:````P]@"``\```#>V`(`&@```.[8`@`$````"=D"`"0````.V0(`#0``
M`#/9`@`H````0=D"`!T```!JV0(`#P```(C9`@`4````F-D"``D```"MV0(`
M"@```+?9`@`-````PMD"`",```#0V0(`)@```/39`@`(````&]H"``4````D
MV@(`"0```"K:`@`&````--H"`!`````[V@(`"````$S:`@`'````5=H"``X`
M``!=V@(`"````&S:`@`/````==H"`!(```"%V@(`"0```)C:`@`<````HMH"
M`!X```"_V@(`"````-[:`@`2````Y]H"`!(```#ZV@(`*`````W;`@`8````
M-ML"``D```!/VP(`"@```%G;`@`9````9-L"``H```!^VP(`(@```(G;`@`&
M````K-L"`!@```"SVP(`"0```,S;`@`'````UML"`!H```#>VP(`*P```/G;
M`@`*````)=P"`!\````PW`(`#0```%#<`@`,````7MP"`!D```!KW`(`+P``
M`(7<`@`)````M=P"`!4```"_W`(`)@```-7<`@`G````_-P"`#`````DW0(`
M*@```%7=`@`$````@-T"``<```"%W0(`#````(W=`@`'````FMT"``4```"B
MW0(`"````*C=`@`&````L=T"`"X```"XW0(`%@```.?=`@`(````_MT"`*,`
M```'W@(`&````*O>`@`F````Q-X"`"T```#KW@(`&@```!G?`@`@````--\"
M`"(```!5WP(`'P```'C?`@!$````F-\"`!P```#=WP(`%0```/K?`@`8````
M$.`"`&<````IX`(`:@```)'@`@`T`0``_.`"`!T````QX@(`$P```$_B`@`D
M````8^("`!<```"(X@(`6P```*#B`@!;````_.("`"D```!8XP(`2@```(+C
M`@`G````S>,"`"P```#UXP(`(@```"+D`@`C````1>0"`"H```!IY`(`)```
M`)3D`@`7````N>0"``4```#1Y`(`!P```-?D`@`.````W^0"``@```#NY`(`
M%P```/?D`@`9````#^4"`"X````IY0(`"````%CE`@`/````8>4"`"(```!Q
MY0(`(@```)3E`@`8````M^4"`!H```#0Y0(`'P```.OE`@`[````"^8"``4`
M``!'Y@(`%0```$WF`@`+````8^8"``\```!OY@(`(P```'_F`@`5````H^8"
M``\```"YY@(`&````,GF`@`(````XN8"`!$```#KY@(`"0```/WF`@`.````
M!^<"`!H````6YP(`!P```#'G`@`2````.><"``<```!,YP(`/@```%3G`@`]
M````D^<"``0```#1YP(`"@```-;G`@`-````X><"`!4```#OYP(`&`````7H
M`@`L````'N@"`"\```!+Z`(`"P```'OH`@`/````A^@"``X```"7Z`(`#```
M`*;H`@`=````L^@"`!$```#1Z`(`/0```./H`@`G````(>D"`"H```!)Z0(`
M)@```'3I`@`%````F^D"``4```"AZ0(`!0```*?I`@`F````K>D"`"@```#4
MZ0(`'P```/WI`@`+````'>H"`!P````IZ@(`"P```$;J`@`$````4NH"``L`
M``!7Z@(`"0```&/J`@`*````;>H"``P```!XZ@(`#0```(7J`@`7````D^H"
M``L```"KZ@(``P```+?J`@`/````N^H"`#D```#+Z@(`2@````7K`@`@````
M4.L"``D```!QZP(`"P```'OK`@`/````A^L"``H```"7ZP(`"0```*+K`@`4
M````K.L"`!T```#!ZP(`&P```-_K`@`<````^^L"``D````8[`(`(````"+L
M`@`3````0^P"`!,```!7[`(`!0```&OL`@`1````<>P"``@```"#[`(`"P``
M`(SL`@`+````F.P"`"<```"D[`(`%````,SL`@`.````X>P"``P```#P[`(`
M(P```/WL`@`'````(>T"``T````I[0(`&P```#?M`@`.````4^T"`!,```!B
M[0(`&0```';M`@`+````D.T"`#,```"<[0(`#0```-#M`@`'````WNT"`"``
M``#F[0(`$0````?N`@`5````&>X"`!0````O[@(`$P```$3N`@`^````6.X"
M`#H```"7[@(`$0```-+N`@`+````Y.X"``4```#P[@(`#0```/;N`@`*````
M!.\"``L````/[P(`$````!OO`@`1````+.\"``L````^[P(`'````$KO`@!!
M````9^\"`#,```"I[P(`"0```-WO`@`+````Y^\"``8```#S[P(`"````/KO
M`@`8`````_`"`!@````<\`(`$````#7P`@`P````1O`"`!````!W\`(`'```
M`(CP`@`L````I?`"`#8```#2\`(`-P````GQ`@`P````0?$"`!,```!R\0(`
M%@```(;Q`@`)````G?$"`!(```"G\0(`$@```+KQ`@`7````S?$"`!@```#E
M\0(`"````/[Q`@`&````!_("`!$````.\@(`(P```"#R`@`8````1/("`!L`
M``!=\@(`3P```'GR`@`2````R?("``<```#<\@(`%P```.3R`@`B````_/("
M``4````?\P(`!0```"7S`@`+````*_,"``L````W\P(`%````$/S`@`$````
M6/,"``@```!=\P(`"@```&;S`@`.````<?,"``P```"`\P(`$````(WS`@`0
M````GO,"``8```"O\P(`!@```+;S`@`K````O?,"`",```#I\P(`(`````WT
M`@`#````+O0"``@````R]`(`!@```#OT`@`&````0O0"``\```!)]`(`#P``
M`%GT`@`;````:?0"``L```"%]`(`.0```)'T`@`4````R_0"`!P```#@]`(`
M/0```/WT`@`H````._4"`"````!D]0(`'````(7U`@`O````HO4"``X```#2
M]0(`%P```.'U`@`F````^?4"`$L````@]@(`90```&SV`@!6````TO8"`*$`
M```I]P(`)P```,OW`@`/````\_<"``@````#^`(`(0````SX`@`#````+O@"
M``8````R^`(`"0```#GX`@`'````0_@"``(```!+^`(`#P```$[X`@`*````
M7O@"``P```!I^`(`%0```';X`@`+````C/@"`!D```"8^`(`'@```++X`@`1
M````T?@"``4```#C^`(`"@```.GX`@`5````]/@"`!(````*^0(`#````!WY
M`@`%````*OD"``H````P^0(`"````#OY`@`Q````1/D"``P```!V^0(`"@``
M`(/Y`@`4````COD"`!,```"C^0(`"@```+?Y`@`-````POD"``D```#0^0(`
M&````-KY`@!,````\_D"`#8```!`^@(`)0```'?Z`@`;````G?H"`!T```"Y
M^@(`)0```-?Z`@`R````_?H"`!$````P^P(`"0```$+[`@`#````3/L"``8`
M``!0^P(`"@```%?[`@`9````8OL"``L```!\^P(`!````(C[`@`$````C?L"
M`!0```"2^P(`"@```*?[`@`.````LOL"``T```#!^P(`&0```,_[`@`-````
MZ?L"``L```#W^P(`#0````/\`@`=````$?P"`#,````O_`(`"0```&/\`@`6
M````;?P"`#(```"$_`(`#@```+?\`@`/````QOP"``H```#6_`(`8````.'\
M`@`:````0OT"`!$```!=_0(`(````&_]`@`=````D/T"`!0```"N_0(`&```
M`,/]`@`0````W/T"`!@```#M_0(`%0````;^`@`9````'/X"`!,````V_@(`
M)@```$K^`@`<````<?X"``8```"._@(`%0```)7^`@`*````J_X"`"T```"V
M_@(`!P```.3^`@`(````[/X"`!T```#U_@(`'@```!/_`@`)````,O\"`!8`
M```\_P(`"P```%/_`@`&````7_\"`!L```!F_P(`,P```(+_`@`'````MO\"
M`!8```"^_P(`&````-7_`@`)````[O\"``0```#X_P(`20```/W_`@!,````
M1P`#`#$```"4``,`/@```,8``P`Y````!0$#`%L````_`0,`!0```)L!`P`T
M````H0$#`"4```#6`0,`#````/P!`P`+````"0(#`!$````5`@,`)@```"<"
M`P`&````3@(#``X```!5`@,`-@```&0"`P!O````FP(#`#4````+`P,`1P``
M`$$#`P!&````B0,#``0```#0`P,`$````-4#`P`2````Y@,#``T```#Y`P,`
M&`````<$`P`=````(`0#`"0````^!`,`$0```&,$`P`V````=00#`$P```"L
M!`,`*P```/D$`P`:````)04#`"D```!`!0,`"P```&H%`P`V````=@4#`"@`
M``"M!0,`(0```-8%`P`>````^`4#`"$````7!@,`$````#D&`P`7````2@8#
M`!,```!B!@,`$P```'8&`P`8````B@8#`"(```"C!@,`'@```,8&`P`0````
MY08#``8```#V!@,`#0```/T&`P`+````"P<#`!$````7!P,`!@```"D'`P`)
M````,`<#`"\````Z!P,`"````&H'`P`,````<P<#``H```"`!P,`"````(L'
M`P`0````E`<#``@```"E!P,`!P```*X'`P`)````M@<#``<```#`!P,`$```
M`,@'`P`)````V0<#``D```#C!P,``P```.T'`P`'````\0<#``D```#Y!P,`
M$`````,(`P`.````%`@#``D````C"`,`&@```"T(`P`,````2`@#``<```!5
M"`,`$0```%T(`P`2````;P@#`!````"""`,`$0```),(`P`2````I0@#`!$`
M``"X"`,`#P```,H(`P`1````V@@#`!8```#L"`,`"@````,)`P`)````#@D#
M`"(````8"0,`$````#L)`P`C````3`D#`"L```!P"0,`"0```)P)`P`)````
MI@D#`!<```"P"0,`!P```,@)`P`$````T`D#`!,```#5"0,`'0```.D)`P`-
M````!PH#`#$````5"@,`$0```$<*`P`1````60H#`!8```!K"@,`+@```((*
M`P`)````L0H#``L```"["@,`"````,<*`P`'````T`H#``D```#8"@,`"```
M`.(*`P`)````ZPH#``4```#U"@,`!P```/L*`P`1`````PL#``0````5"P,`
M#0```!H+`P`(````*`L#``4````Q"P,`!@```#<+`P`.````/@L#``H```!-
M"P,`#````%@+`P`+````90L#``X```!Q"P,`&P```(`+`P`6````G`L#``H`
M``"S"P,``@```+X+`P`'````P0L#`"$```#)"P,`!@```.L+`P`*````\@L#
M``8```#]"P,`<P````0,`P`7````>`P#``@```"0#`,`!@```)D,`P`;````
MH`P#`"<```"\#`,`#P```.0,`P`=````]`P#`$@````2#0,`'````%L-`P`?
M````>`T#`!(```"8#0,`"````*L-`P`%````M`T#``<```"Z#0,`#P```,(-
M`P`*````T@T#``H```#=#0,`!@```.@-`P`*````[PT#`!(```#Z#0,`#```
M``T.`P`*````&@X#``P````E#@,`!P```#(.`P`'````.@X#``@```!"#@,`
M"0```$L.`P`6````50X#``D```!L#@,`!P```'8.`P`-````?@X#`!(```",
M#@,`$0```)\.`P`'````L0X#`!H```"Y#@,`!@```-0.`P`7````VPX#``8`
M``#S#@,`!P```/H.`P`5`````@\#``D````8#P,`$````"(/`P`'````,P\#
M``8````[#P,`$P```$(/`P`1````5@\#`!,```!H#P,`!@```'P/`P`&````
M@P\#``H```"*#P,`"````)4/`P`$````G@\#``D```"C#P,`!0```*T/`P`$
M````LP\#``T```"X#P,`(@```,8/`P`*````Z0\#``P```#T#P,`*0````$0
M`P`7````*Q`#`!8```!#$`,`#0```%H0`P`;````:!`#`!8```"$$`,`,```
M`)L0`P`%````S!`#``L```#2$`,`#0```-X0`P`'````[!`#``(```#T$`,`
M#@```/<0`P`(````!A$#`"(````/$0,`'P```#(1`P`C````4A$#`#0```!V
M$0,`(````*L1`P`U````S!$#`&@````"$@,`(0```&L2`P`9````C1(#`"P`
M``"G$@,`)P```-02`P`K````_!(#`!8````H$P,`%0```#\3`P!D````51,#
M``\```"Z$P,`$@```,H3`P`A````W1,#`'0```#_$P,`/@```'04`P`C````
MLQ0#`"T```#7%`,`/0````45`P!!````0Q4#`$\```"%%0,`2````-45`P`F
M````'A8#`",```!%%@,`/P```&D6`P`A````J18#`"@```#+%@,`(````/06
M`P`O````%1<#`"X```!%%P,`)P```'07`P`G````G!<#`"$```#$%P,`%P``
M`.87`P!T````_A<#`#P```!S&`,`10```+`8`P`J````]A@#`"L````A&0,`
M%0```$T9`P`6````8QD#`"@```!Z&0,`-@```*,9`P`J````VAD#`!L````%
M&@,`;@```"$:`P`Q````D!H#`!$```#"&@,`%@```-0:`P!+````ZQH#`"D`
M```W&P,`,@```&$;`P`F````E!L#`!D```"[&P,`7P```-4;`P`M````-1P#
M`"X```!C'`,`&0```)(<`P`<````K!P#`"H```#)'`,`<````/0<`P`X````
M91T#`"H```">'0,`-0```,D=`P!Y````_QT#`&(```!Y'@,`5````-P>`P`K
M````,1\#`"(```!='P,`+P```(`?`P`L````L!\#`!P```#='P,`#P```/H?
M`P!W````"B`#`"$```""(`,`%@```*0@`P`5````NR`#`#0```#1(`,`'@``
M``8A`P`7````)2$#`"T````](0,`%P```&LA`P`<````@R$#`!L```"@(0,`
M%P```+PA`P`6````U"$#`!P```#K(0,`+0````@B`P`=````-B(#`!8```!4
M(@,`)````&LB`P`G````D"(#`#0```"X(@,`)````.TB`P`Q````$B,#`#T`
M``!$(P,`&0```((C`P`-````G",#`"X```"J(P,`)P```-DC`P`V`````20#
M`"D````X)`,`'````&(D`P`V````?R0#`"P```"V)`,`(````.,D`P`V````
M!"4#`%`````[)0,`*@```(PE`P`Q````MR4#`$,```#I)0,`0````"TF`P`L
M````;B8#`",```";)@,`-P```+\F`P!C````]R8#`$P```!;)P,`50```*@G
M`P!1````_B<#`%$```!0*`,`0P```*(H`P`P````YB@#`#,````7*0,`3@``
M`$LI`P`B````FBD#`!X```"]*0,`(````-PI`P`A````_2D#`"`````?*@,`
M-````$`J`P!?````=2H#`%$```#5*@,`40```"<K`P`\````>2L#`#4```"V
M*P,`/````.PK`P`_````*2P#`#4```!I+`,`)````)\L`P`F````Q"P#`$L`
M``#K+`,`*@```#<M`P`Y````8BT#`!H```"<+0,`)@```+<M`P`M````WBT#
M`"T````,+@,`%0```#HN`P"#````4"X#`'<```#4+@,`@````$PO`P#(````
MS2\#`!D```"6,`,`(P```+`P`P`N````U#`#`"<````#,0,`1P```"LQ`P`B
M````<S$#`%````"6,0,`)````.<Q`P`.````##(#`#H````;,@,`+0```%8R
M`P`^````A#(#`#\```##,@,`8`````,S`P`_````9#,#`$P```"D,P,`/```
M`/$S`P`B````+C0#`"4```!1-`,`)@```'<T`P`C````GC0#`!````#"-`,`
M00```-,T`P`D````%34#`"X````Z-0,`)P```&DU`P`G````D34#`"0```"Y
M-0,`2@```-XU`P`Z````*38#``L```!D-@,`!@```'`V`P`$````=S8#``<`
M``!\-@,``P```(0V`P`/````B#8#``H```"8-@,`!P```*,V`P`(````JS8#
M``8```"T-@,`$0```+LV`P`$````S38#``L```#2-@,`5@```-XV`P!;````
M-3<#`$L```"1-P,`!````-TW`P`/````XC<#``0```#R-P,`!P```/<W`P`'
M````_S<#``4````'.`,``P````TX`P`0````$3@#`!,````B.`,`#@```#8X
M`P`+````13@#``L```!1.`,`$P```%TX`P`1````<3@#``(```"#.`,`"```
M`(8X`P`'````CS@#`!0```"7.`,`#````*PX`P`6````N3@#``8```#0.`,`
M#P```-<X`P`*````YS@#``,```#R.`,`*````/8X`P`$````'SD#``8````D
M.0,`!P```"LY`P`7````,SD#`$@```!+.0,`*0```)0Y`P`L````OCD#`!<`
M``#K.0,`)0````,Z`P`F````*3H#`"D```!0.@,`'0```'HZ`P`:````F#H#
M`!D```"S.@,`&P```,TZ`P`8````Z3H#`!<````".P,`'0```!H[`P`;````
M.#L#`!@```!4.P,`)P```&T[`P`8````E3L#`"<```"N.P,`(P```-8[`P`9
M````^CL#`!T````4/`,`&P```#(\`P`8````3CP#`!X```!G/`,`(@```(8\
M`P`=````J3P#`"8```#'/`,`(@```.X\`P`8````$3T#`!H````J/0,`)0``
M`$4]`P`7````:ST#`"$```"#/0,`,````*4]`P`S````UCT#`!,````*/@,`
M)@```!X^`P`^````13X#`!\```"$/@,`(P```*0^`P`A````R#X#`"0```#J
M/@,`'@````\_`P`5````+C\#`!@```!$/P,`(0```%T_`P`@````?S\#`#,`
M``"@/P,`(@```-0_`P`W````]S\#``D````O0`,`%@```#E``P`&````4$`#
M``P```!70`,`#P```&1``P`/````=$`#`!D```"$0`,`*0```)Y``P`T````
MR$`#`"D```#]0`,`+0```"=!`P`?````54$#`!````!U00,`(@```(9!`P`/
M````J4$#`!4```"Y00,`#@```,]!`P`0````WD$#`!L```#O00,`!P````M"
M`P`%````$T(#``L````90@,`,````"5"`P`*````5D(#``\```!A0@,`*0``
M`'%"`P`D````FT(#`!<```#`0@,`(@```-A"`P`D````^T(#``\````@0P,`
M!P```#!#`P#4````.$,#``4````-1`,`#````!-$`P`A````($0#`!0```!"
M1`,`"0```%=$`P`,````840#`!P```!N1`,`$P```(M$`P`1````GT0#`!L`
M``"Q1`,`"0```,U$`P`R````UT0#``@````*10,`$````!-%`P`'````)$4#
M`!(````L10,`%````#]%`P`A````5$4#``H```!V10,`'````(%%`P`V````
MGD4#``D```#510,`.0```-]%`P`D````&48#`!8````^1@,`%0```%5&`P`4
M````:T8#`"8```"`1@,`'````*=&`P`,````Q$8#`!P```#11@,`#0```.Y&
M`P`.````_$8#`!4````+1P,`"@```"%'`P`8````+$<#``@```!%1P,`*0``
M`$Y'`P`)````>$<#``\```""1P,`*@```))'`P`&````O4<#`!4```#$1P,`
M!P```-I'`P`(````XD<#``D```#K1P,`.P```/5'`P`'````,4@#`!`````Y
M2`,`$@```$I(`P`2````74@#``D```!P2`,`"P```'I(`P`'````AD@#`!4`
M``".2`,`!````*1(`P`'````J4@#`!D```"Q2`,`*````,M(`P`0````]$@#
M`!T````%20,`'0```"-)`P`)````04D#`!$```!+20,`%P```%U)`P`+````
M=4D#`"(```"!20,`(P```*1)`P`-````R$D#`!4```#620,`*````.Q)`P`,
M````%4H#``L````B2@,`%P```"Y*`P`9````1DH#`!P```!@2@,`$````'U*
M`P`B````CDH#``\```"Q2@,`#P```,%*`P`4````T4H#`!0```#F2@,`%0``
M`/M*`P`$````$4L#``4````62P,`&0```!Q+`P`$````-DL#`"P````[2P,`
M#````&A+`P`1````=4L#``<```"'2P,``@```(]+`P`,````DDL#``X```"?
M2P,`"P```*Y+`P`$````NDL#``D```"_2P,`$P```,E+`P`6````W4L#``@`
M``#T2P,`"0```/U+`P`1````!TP#``T````93`,`&0```"=,`P`:````04P#
M``T```!<3`,`,@```&I,`P`>````G4P#`",```"\3`,`7@```.!,`P!A````
M/TT#`#<```"A30,`-````-E-`P"#````#DX#`!<```"23@,`"P```*I.`P`S
M````MDX#`!$```#J3@,`!0```/Q.`P`1`````D\#`$(````43P,`"P```%=/
M`P`*````8T\#``8```!N3P,`!````'5/`P`$````>D\#``H```!_3P,`%```
M`(I/`P`%````GT\#``8```"E3P,`!@```*Q/`P`*````LT\#``8```"^3P,`
M#@```,5/`P`/````U$\#`#0```#D3P,`*@```!E0`P`G````1%`#``4```!L
M4`,`'@```')0`P`.````D5`#``(```"@4`,`!````*-0`P`*````J%`#``4`
M``"S4`,`!0```+E0`P`"````OU`#`!$```#"4`,`-@```-10`P`Y````"U$#
M`"8```!%40,`)````&Q1`P`<````D5$#`!\```"N40,`0P```,Y1`P`9````
M$E(#`"X````L4@,`)0```%M2`P`8````@5(#`!0```":4@,`(P```*]2`P!<
M````TU(#`",````P4P,`+@```%13`P!#````@U,#`"8```#'4P,`-0```.Y3
M`P`_````)%0#`!H```!D5`,`&0```']4`P`F````F50#``\```#`5`,`'@``
M`-!4`P`I````[U0#`%X````950,`(````'A5`P`G````F54#`$<```#!50,`
M)`````E6`P!!````+E8#`!@```!P5@,`*````(E6`P!9````LE8#`%P````,
M5P,`%@```&E7`P`>````@%<#`!X```"?5P,`*@```+Y7`P`@````Z5<#`!(`
M```*6`,`,````!U8`P`Q````3E@#`#4```"`6`,`-````+98`P`J````ZU@#
M`"0````660,`,0```#M9`P`J````;5D#`"H```"860,`'0```,-9`P`Q````
MX5D#`#H````36@,`(````$Y:`P`E````;UH#`#(```"56@,`$````,A:`P`1
M````V5H#``\```#K6@,`;````/M:`P`)````:%L#`"(```!R6P,`$@```)5;
M`P`2````J%L#`"<```"[6P,`*@```.-;`P`,````#EP#`%`````;7`,`J0``
M`&Q<`P!?````%ET#`'<```!V70,`/P```.Y=`P`N````+EX#`%@```!=7@,`
M6P```+9>`P`5````$E\#`"\````H7P,`.````%A?`P`C````D5\#`!<```"U
M7P,`%P```,U?`P":````Y5\#`!L```"`8`,`&````)Q@`P`?````M6`#`#D`
M``#58`,`(P````]A`P`C````,V$#`%@```!780,`&@```+!A`P`2````RV$#
M``T```#>80,`"P```.QA`P`%````^&$#``8```#^80,`"`````5B`P`%````
M#F(#``X````48@,`$@```"-B`P`.````-F(#``P```!%8@,`$````%)B`P`4
M````8V(#`!X```!X8@,`'@```)=B`P`.````MF(#``\```#%8@,`!````-5B
M`P`.````VF(#``0```#I8@,``P```.YB`P`1````\F(#``D````$8P,`!P``
M``YC`P`+````%F,#``<````B8P,`"````"IC`P`&````,V,#``H````Z8P,`
M%0```$5C`P`'````6V,#``D```!C8P,`"0```&UC`P`0````=V,#``X```"(
M8P,`$````)=C`P`.````J&,#``T```"W8P,`"0```,5C`P`*````SV,#``H`
M``#:8P,`$````.5C`P`&````]F,#``0```#]8P,`!P````)D`P`&````"F0#
M`!<````19`,`!0```"ED`P`%````+V0#``8````U9`,`"@```#QD`P`*````
M1V0#`!(```!29`,`"0```&5D`P`/````;V0#``8```!_9`,`"P```(9D`P`&
M````DF0#``@```"99`,`!0```*)D`P`4````J&0#`!4```"]9`,`"@```--D
M`P`&````WF0#``\```#E9`,`$0```/5D`P`8````!V4#``D````@90,`!0``
M`"IE`P`,````,&4#``@````]90,``P```$9E`P`$````2F4#`!D```!/90,`
M"0```&EE`P`"````<V4#``(```!V90,`#P```'EE`P`&````B64#``8```"0
M90,`#P```)=E`P`3````IV4#``8```"[90,`!@```,)E`P`+````R64#`!8`
M``#590,``@```.QE`P`$````[V4#``4```#T90,`$@```/IE`P`2````#68#
M`!`````@9@,`!0```#%F`P`'````-V8#``T````_9@,`!@```$UF`P`*````
M5&8#``P```!?9@,`"````&QF`P`6````=68#``\```",9@,`$@```)QF`P`'
M````KV8#``<```"W9@,``@```+]F`P`'````PF8#``D```#*9@,`#0```-1F
M`P`/````XF8#`"L```#R9@,`!````!YG`P`'````(V<#``L````K9P,`!0``
M`#=G`P`"````/6<#``L```!`9P,`%@```$QG`P`6````8V<#``$```#?"@``
MB`<``!\#````````A@L``(X&```G!0``_0$``)`#``";!@``W@,``*@'```V
M"@``]0```,0(````````A08``"\"```F`0``U@(``*<#````````,0@``$T)
M``"#!P``[`<``,X!``!7!P``V`H``&8&```""0``````````````````&```
M``````"S"@``V`,``"X"```O!```#00```````"?"```5@4`````````````
M`````!<'`````````````%D)````````5```````````````@`8``&\)````
M``````````L#``#3"@``%`L``%$%``"K!0``K`8```````#:"```B0<``&`$
M``"N"```]`$````````O"@``9`<``$0+``"7"@``4````'`#```2!```?0<`
M``$$``!-!````````#8+``!E`0``Z@<``',$```+"P``K@0``,(#``#T````
MD`L``%4&`````````````$4````="````````%$$```0!P```````-L*``!6
M!```S08``+H"```5`0``X04``(H```#(`@``7@<``/P&``#S`@``E0```(L%
M````````D0H``'8(``"L````90L``"H$``!."@``"P(``&(&```0"@``````
M`(`!``#%"```A`<``$H"``!F"@``%P0``,D$```J"0``XP(``)$```"]!@``
M$P8`````````````=`0``$()```T!@``9P0``#X"````````/`<```,(``"S
M`P```````.(!`````````````.P*``!K````%@@```T%``"E````,0<``)\'
M``!0"0``%@H``!,!```R"```]P(``!@"``#Y"0``V`0``*L(``"["@``'@L`
M`)L```!.````'PL```````"Y!0```````$@$``#7`@```````+`)``#K!P``
M``````````"<"P``Z@(``````````````0$``-`'``"\"@``5P0``-<!````
M````-@(``%,+````````)0(``*<)``"]`0``E`````````"J!@``-`H`````
M```<"0``_P@```T*``"["```,`$``"\+``#J!0``,P0``$H#``!'"P``X`0`
M`!X```"F`@``O`````````"9!P```````-\'````````(P8``%`&```^`0``
M]`0```````#E`P``J`4``(D!````````PP,``-("``!R!`````H`````````
M````-PL``!$&```E"0```````(<```!\`````````#4$``#1````NP0``.`!
M```D`@```````!`"````````$@H``&P!``"@````+@,``*(*``#"````Z`0`
M`)\$``#(!`````````````!5`P``L@8```````#?!@``$`$``!`+````````
M`````)X%````````$P<``.X'``!C!@``>0L```````"""P``ZP$``!$#``"_
M!```6@````````"-!````````&P*```U!0```0D````````P"@``````````
M``#P"````````'L!``"]"```80<``*@)```F!@``DPL``.T#``!D"```7`@`
M`+P'``","````````($(``!F"P```````.8%``#X"```4`@``.T%``"X`@``
MXP8``'P*```Z`````````,H"```H"```*`$``*4(``!1"0```````#P#```L
M!P``H`(``+8(``#+"@``B`,``&H!``"."0``QP4``,0#``#"!@```````/,%
M```4"```+P8``(T'``````````````````!A"```7`<``*()``"M!```10,`
M`.D'``#+!P``5P$``-\!```'"```XP,``*D*``!R"```-PD``%D!```C!```
MF08``.0&``"I`@`````````````2`@``_@$``!P&``"U`0``908``+`'```D
M"@``I`8``(8```#G!```4`4````````#"P``.0````````#D!P```````*`)
M``!Z`@``0P```````````````````(L!``#"`0``T`,``'L(``#O`P``N@8`
M`&0)``#Q`0``;@8``,L&````````U0<``'L&```("```SP8```````!S"```
M$0$```````#F`P``60,``'D'````````]@H``&D"``!W!0````````````!!
M"```6P@```````!:"P````````H"````````)0@``-@%``!:`0``````````
M```B"@``/PL``'<&``!6`@``700``.$*``"*"0``[0H``(H&``!1!P``6`0`
M`*(!``"K"@``304``*,&``"Z"````````+8!````````%`,``/,&``#<!@``
M(0L``",%````````JP0``$`!``!X!@``.P(```````!L"```8P4``-P'````
M````;`0``)0$``"3"0``LP8``(<*``"1"````````,($``"-!0``D@8``,X&
M``".`0``+0<```````"H`0``FP<`````````````L`$``!<*``#:"0``)0``
M``````"5!@```````&<&``!:!````````$@``````````````!<(``"8"0``
MB@,``$<(`````````````+$&``#O"0``/P@``+`&```:`@```````%8!````
M````3@D``````````````````+D(```>"`````````````#Y"@```````*`!
M```["@``KP<``)D#```A!```M08``+\*```>!P``_PH``.@*``"U!0``````
M`(P)``"M`P``20D``'T%``!-!@``A0@``+($``"$!```=0H```````!N"0``
M(0(`````````````00$``,$&``")"0````````````#3`P```````"\(``!?
M!0````````````````````````````!4"P```````*0(```#"0``1P4``+@(
M```N!0```````'\(````````P@D``#X)``!;`@``L00``"4'``#W!0``````
M`)@```#X````,P,```$&``"3`0````````````"C"@``MP0``$D```!B!```
MRP(``&X'``"$"P```````&X#``#("````````(0(```)````\0(```````!1
M`0``7`D```````"-!@``U@0``+<#```:"```MP@```````!;`0``(@```(P"
M`````````````.@`````````EPL``'(#``"F!0``F@8``(<+````````N00`
M`&P#``#9!0``(P,``*@#````````D0(``/`)```Z"0``A@0``-,(````````
MM@L``$4$``!?!@```````"H#``#<`P`````````````9!0``````````````
M````"0H``!$'``""````^0@```L*``"(`0``#`8``&4```!*!@``<@$``,8!
M````````D0<`````````````20@````````%`0``;0L``#@`````````````
M`)`"```V!@``(@4``$(%``!(`0``:P0```````#L````L0$``(4%``"4"@``
MV@4``#,%``#4!0``X`````8'``!5!```2P``````````````A`,````````Z
M!P````````````#*!```VP@````````'"P``;`4``*<%``#\`P```````%X*
M``"="P``DPH``*0#``"X!````````*$$```8"P``R@<``*H!``"R````````
M`)@*``!D````&PD``$<"````````J0@``#$&```Y"0```````+D)````````
M'04``-@'``!K!0``U`0``-<'```@"P``JP<``'8%`````````@L``!<#````
M````PPH``/L*``![`P``^08``,T*``#.````A00``#P`````````````````
M``#X"0``%00``',+````````_`@``)<`````````;04``$P#``"_!P``.`4`
M``````#@`@``,04``%<"````````7`(``-D#``"O`P``00,``)8)````````
M/`0``/X#````````<@8``-`)``#,"0```````,\(``#?!0``8````)4$``"9
M"0``=0(``)0%````````2P<``,L!``#>"@````````````!B`@``$P4``,4&
M``!V"P``_P(``+,'``#]`@``#PL``%8&``!^!P``E@<```('```E`P``````
M`&X*``#N"@`````````````V`P```````"L'```H`P``=P0```````!0`@``
M`````!X#```"`0```````+L'`````````````+X+``"3!@``Y@<``!8'``!F
M!P``W00``!T&````````E`@```````"H"P``608``-(```"V!P``W@(`````
M`````````````'0&``">"0``VP0``/H)``"A!P```````(('``"("```9PL`
M`((#``#N"```3@0````````<``````````D+``#,`P``ZP8``!H)``#Y!0``
M4@$```P(`````````````*@*```T`0``-@@``/X)``")`@```````(0&``#N
M`0``2`L``%\"``!4!```!@0```T+``#R"```'`$`````````````"@@``#@"
M````````L`````<&``#N!0``1`0```````"/!@``UP,```````!I"0``3P4`
M`'\'``!'`````````#(&``!D!0``(`8``.(#``!5"```GP8``-8'``"S`@``
M<0````````#4"``````````````=`P``2P8``'4$```H`@``IP```%8'``"B
M!0``CP@``(`'````````R0,``)X#``!:"@``VP```-`&````````````````
M``#6````+@@``%<&````````R@D``$`(``````````````````"U!P``_00`
M`$`*``#3````VP4``"0%``!#!P``MPD````````+!```4`<``$<#``#-"0``
M```````````M`0```````-$!``!E!0```````$$'``#`!@````````````!+
M"@``%`8````````?!@``6PL``'H)````````,0,```````"3````_@0``)T$
M``#8!@``FP$``'0%````````?P```.,'`````````````,4%``##!0``$04`
M`,D```!C"@``D@```"\!````````G@0``#H$``#<!```3@$````````B`@``
M_@```,<`````````6`L```````!A"P``,P(``)H*````````O@(``"P"````
M````Q`$```````"E!P``/@H``'@+``!7"0``-````'H*``"7"````````"$#
M```````````````````-!@``%@,````````$"@``$P(``/@"``"B`@``````
M`$`+``#\!```$`4```(#``#L"0``"`L``'T)``"-`P``(`D````````'````
MJP(``&H(``!\!P``3@(``+D!``#Z````P0H``',"``!<"P``504``.L%``#`
M!```G`@``"0#```:!P``'00``-<`````````N08``.\*````````>@<``-`!
M```(!```AP(``',`````````;@```.P%``!&"@``.@$``)@+``#R!```````
M`",````Z`P``]04``"X*``!7`P````````````">`````````/(*``#!"```
MZPH``.\$``!E!P``K@```(@&`````````````%L&`````````````.0#````
M````N@D``*,(````````1PH``%@*```/!````````'\!``#0"@``9@$``/`%
M``"P"``````````````/"```@PL``#L!``"("0``;`<```````"\`@``[@D`
M`'\+``!<!```GPL```````"@"````````-D$````````D@(``&@*``"D`0``
M>P0``````````````````,H%````````"`8``#@&``!-"@``YP4``#X+``!@
M"```_`4``"$&``!\`P```````&((``#&!@``50$``"@*``#P!@``````````
M```````````````````D"P``W`H``)4+``";`@```````-,$``"J!0``,@D`
M`'P+````````Q@0``$L%``".!0``EP$``,@&``!%"P``>0,``"H%``"<`0``
M`````/P"``!W"0``/@<```````":"```<04```````#)"0```````!,+``"]
M!0``>@4``````````````````+,```#;`@```````"$!``#4`P``[`,`````
M````````_@<```````!.!@``S@0``-H```"I!P``,P$``,P"```G"0``/`D`
M``````#Q"```>`H``(`$````````Y0`````````M`P``^@8``#(*``"V!0``
M`````.T'```("@``[P8``#`'```2!@```````!H&````````````````````
M````E@H```,*``!``P``;PH```````!>`0``]0@``!L+````````%P(``,$)
M``!*"@```````(H*``"W!0``7@(```````")!0``S@(```````#H!P``````
M`$@(``#N!```*08``$@*``#G````G0(```````#P````60@``*H)```1!```
M>P(```````"4!@``.0@``.L$````````#`,``+,$````````5@D``,@%``"6
M!`````````4%```Y"P``)@D``*4!``#X"@``U08``'8`````````````````
M```/````204```````!Y"@``/`4``$(!``#(!P``A@(```4$``!G`@``0P0`
M`)X+```R````]`(``$8+``!^!@``+0```"0&``"C!`````````4&``!M`@``
M]PH``$T"``!2!0``$`,```````````````````````````````````````#\
M!P``8P@``#4"``#]"0``X`4``%,$``!1`````````$P+``"2"```\08`````
M````````OPL``'D)````````K@D``!L&``!Q`P```````+,!``"!!@``````
M`"X'``"K`P``,@4``-4*``"]!```W`4```````!^!```4P8``!4'``#$````
M`````/X*``"2!0``<@(```H%`````````````!D&```*````(````&0#``!(
M!0``7`4``$,*``"J`@````````````"7!```J`@```````"W"P``!`0`````
M``"""0``T`4``'X```!2!@``<P$``````````````````+P(````````^P<`
M`.`*````````\0H```($````````%@L``-0"``"L"```I00```````#N`@``
M/`L````````8!0``Q`<```````"T!0``````````````````<`8`````````
M````#`$``)````!V!````````',&``"L!P``<@<```````#%!P``S`H``.0!
M``!O"```^`8``),"```$!@```````/<'``!H"P``````````````````N`$`
M`%D'``#_````9P$``"$)``#+`P````````````!A!@``K@8``,T$```6`0``
M`````*4"``"8`0``T`@``$("``!!"P``H@,``!H+``!`````H0@``/`!```@
M`0``3PH``)$$``#W!@```````!8"``!Q`@``$0L``&8"``#.!P``OP8``.($
M````````O0<``!P'````````*````&L(```T"P``7P@```````!!"0``+`@`
M`-L!``````````````D&``#D````2PD``&L+``!O!0``(0```*D%``!P`@``
MJ@L``)8%``#A!P``"@8````````V`0``&`<```````#H"```[00``,\$```;
M````2P@``*$```"$````M`0``$L"```O!0``J0```*8)`````````````)T#
M``!V`0``<`L``!<)```_`P``EP(```````!M!@```````%P!``!2!P``````
M`$,(````````.@L``%\$```W"````````"L#``!-````6@D``-D'``";!```
M3@@```````#*`0```````$`$``"^!0``,00``)T'``!/!@```````(H+``#G
M`0```````%((````````M`@``+0#```1"0``CP(``/L)```8"0``#`0``)X&
M``"Z````ZPD```````!N!0``N`8``*`'``"G!@``%@8``&H%``!X````````
M`)@#``#=`0``9@,````````J`0``A0<````````G!P``6````',#```]"```
MI04``%@!``"="```O@0```````!]`0```````+$)```B!@``;````,`'``"D
M`@``\`<``&D!``!%"0``;P,```````#""@```````/H*```C`@``6`(`````
M``!%`@````````@)``!Y"```RP```-D(``"T!P``*PH````````I"P``````
M````````````Q0````````!D"@`````````````.`@``!`@```````#1!```
M.P,``-P)```<"P```````*L```!&"```K@<``&T#```N`0``K08```````!\
M`@``S@4````````7````A@H``/T%```;`P``Y`4```````#_!```,`(``"4+
M``#[!0```````/X&``#-`0``@04``.H#``"7"0```````"8`````````````
M``````!P`0``5@L```L(`````````````#$)``!P!````````-H*``!\`0``
MK0D```````#W!```X0````````"F"````````*\(``#8````+@8``*H#``#,
M````HPD``.<(`````````````&L#```A!P```````$H!``!R"0```````"`'
M``"A`@``Z0$``!D)``"R`@``_@(```````"#"@``>@L````````""@``````
M`-L)``!4!0````````````"G!```@`(``&$)````````'P4``/H(```\"@``
M00(``#0(```>!@``B@<``+<````/`0``;0$```````!="0``[P(``/0*````
M`````````'@$``"-"P```````*0+``!W`P``O@<````````U`P``JP$``.P$
M``!U!0```````(D$``#%"0```````.@&``#!!0``NP4``)\"````````>`<`
M`+8```"W`0``,@,``&L&``#S"@```````%4)````````H`4``,8'``#T!@``
M1`$```````"/````90@```````!Y`````````+D*```*"@``/`(``-`````-
M`P``900```,%``!#"0``UP8`````````````:`0`````````````E0(`````
M`````````````"<&``"O"@``200``+P%``"5!P```````*<+``!M````3PD`
M`+P)````````=`$``(\)``#Y!```KP4``"4*``"2!P```````"X$````````
M``````````!B!P```````%@(``"-`@``#P4``"H```#L"```6@8``-P```!)
M!P``/P<``)$#```R`@``1`,``!4`````````6PH`````````````$P```(X"
M``!9````Y`0``'<+````````````````````````(@D``.,```#&!0``Y00`
M`,("``"#````'@0```\#``"_"0``1`4``$<$``#'"0``KP(``,H`````````
MF`0``/<```"Q`@``W0@```<*``"&!@``H`L``+(+``#2`0```````$,%``#I
M`@```````"H+``"Y!P```````(\*``"M"```U@4``*\!```\"````````&`!
M```S!@``SP$``*P!``"Y"P``?PH```````">`0``^P8``'<*```%"P``#@H`
M``P*``"F`P``)@L``.L(````````>P<```````"Z!```1@,``'\#```:`0``
M;P0``-X(````````.`0``/8#``````````````X(````````3`H```@'``"P
M!```>@```"<+``!A`````@8```````"+!@``O`8``),(``#!`````````+\!
M``!,"0``FPL``&<#````````+00``.L"````"P```````)4*````````8PD`
M`,L%``"Q````D04``-T%``"(!```S@D``-D"``!N`0``U0@`````````````
MR08``#,*```>`@```````%H#``#``0``M@(```````!^"@``````````````
M````(PH``(D+````````.`$``/4#````````3````)`*``!$`@``,`L``,X(
M``!>"0``+`,``+P+```["P``.`<```````"#!```8@$```````!G!0``9P``
M``````#4!@``M00```````!P"```Q`D``"4$``!9"P``U04```````!O!P``
MQ`8``-D&``!]!```>P````````````````````````!8!@``N`H``-(%``"5
M!0``O0,```X$````````BP@`````````````T08``"4%````````&0<``/@!
M``#H`0`````````````@"@```````-X$````````OP```"X)````````````
M`'0#````````@00``(L#````````````````````````(@$``+4#``"["P``
MZ0D````````B`P``XPH``#T*``!^"0``#0@``&D*``#T`P``5`H``"\'````
M`````````$X+```&`P``+`4````````2!P``)`````````!/!````````!4*
M``!%!P``S`<``!\'`````````````%4`````````#PH``.8````'`0```P8`
M`)\%`````````````,,'````````5`8``+T```!$"@``J@0``-(&``!J"@``
M`````.`'``!=`P``3P@``````````````````)4)``#G`@``G`0``+P$````
M````00H```````"I!```6`<``$<)````````Z@0``)D+``"^!@``-@4``$D+
M``"Z"P```````#$+``##`@```````/8%`````````````#`#``#C"0``GP,`
M`#D#``"C````<`H`````````````````````````````6PD```````!X`0``
M``````````#+"```YP8``$X%```L"0```````.<*````````50H``!8````+
M````0`8``)X'``!\"```Z@@```````#=!P``"P4```````!I!0``#`(``$P(
M``#3"0```````%<*``"<!P``F@0``)(!`````````````!`(``"M!P``````
M```````-`@````````````"<"@``M@,``!L!``#H!0``T04``/0'``!K!P``
M-0D``+4)````````_````(X````&`0````````````"%`P``*`<``-H!``"7
M!P``#0```&H+``!X"0````````````"E"0``!@(``$8"````````A0D``'0)
M``#M``````````````#'`0``Y@D`````````````T@H``#T#```""````@``
M`+$%``!F!````````,$#`````````````!0"``!P!P``4@H``'L+```K`0``
M_0H``%\#````````Z@```.T)``!,!0``V@0```````#>!P``BPH````````+
M!@``GPH``+`#``#1"```,@$```````#"!0``"0,``/L`````````*P8``.<#
M````````T@0``/`$````````QP(``.T&````!@``?0,`````````````G04`
M```````C"P``_`D```````!*!0``E0@``#\*``!="P``XP$``/,#```G`0``
M`````&,"```!"````````"D%``#>`0```````&(+```J!@````````X&``#T
M"0``1`D``'4`````````U0D``-T"``"2`P``BP0```````"A"0``M@D`````
M```3"```?`4```````"+`@```````-8&```L````-0$``-((```G"```.04`
M`)H%``"<"0``C0```#4(````````-08``!P(``!;````*`D``"X`````````
M>`,``-P"```7"P``1`8``)X(```*"0``M````,\"``"_!0``@@H```````#_
M"0``2@```*\)``!^"P``L`(``%T````#!```"`4``!\*````````````````
M```>!0``=`L```8%``"[!@``,`@``(,%```K"```F@,```````"M!0``.P8`
M`%(```!/`@```P```.8"``"'"0```````&@"``!^"```#`4``%<%````````
M"@,`````````````-P,``$T!``!!````9`8``*X*`````````````$(```"[
M"0``50L```````"C!P```````&8`````````@`H``,,&```M"@``!`<``/("
M``"L`@``2`(``!\(``!@"@``O@,``,4!``#"!P``L0L``"`"````````;00`
M`"P+``"M````*0(``)X*``#;!P``J@```+<*````````7@````````#W`P``
M5@`````````+"0``<0H```X``````@``F0@``'0*````````[P@``#,'``#)
M`@``M0(``$X'``#/!0``QP8``&X$```(`0``Z0```,L)``"W`@``<@H`````
M``"0"0``5@,``#,+``#_!@```````'D!````````\P$``#,)````````IP@`
M``````!R"P``K0L``+L````L!```/P0``(`%`````````````(4!````````
M_@4```````#B"0``Y@@`````````````^`,``*8&``"'`P``)PH``*0*``#*
M"@``IP$``%`!``"N`P``FPD``'<(````````20(``&\"``"E!@```````&(#
M`````````````$8!``"*!`````````````!@`@``,`D``%@%````````````
M`!D*````````O`$``.(````$`P`````````````?`@``CP,``($!``#D`@``
M@@4``!8$``!Z`0``:08``'P)``#:`@``A0(``*`*``#("0``&0@````````9
M"P``R````)P%``!F"0``R@@```````#="@``\`,``#P!``"S"````````!(`
M``#]"```2@D``*X%``!A`0``)@0```X'``#8"```-@0```````"0`0``600`
M````````````70<``*T!``"1!@``]0H``)@"``#$!```6`,``*0```!3`@``
M`````#X%````````!P4``/`*``!3`0```P$````````?````?@$```````"Q
M"@``FP4```D!``!E"@```````!T!``!C"P```````'$(````````M`(`````
M```'`@``#`<```````#$!0``````````````````4@L``,P!```_"0``^P0`
M`"D*``#A"0``L`H``'H$``!@!@```````($#````````7`````````"8!@``
ME`,``)`'````````WPD``)@%``#U"0``>@@``*X!``"%"@```````$(&```)
M!```8`L``,P%```3"0``>08``/,'``#9`0``R0H``#D&``"W!@```````(`+
M```K"P``:P(``$P'```4!````````$`"``````````````P)``"G!P``````
M`.T!``#3`@```````-X&``!Z!@```````%X(````````)P0``.4(``#M"```
M-P0```````","P````````````"7!@``QP0``/('``#'`P``KP0``'````#R
M````'@D``*8$````````5`,```(%`````````````!T+``!1`P``````````
M```[!0``C@<``````````````````,4"```H"P``,P@``'$+```?!```%P$`
M`$P"``":````CP4``,````"Z!P``A@4``"T"```[!P``:`<```````"6"```
M$@$```````"3!0``O@H````````'!P``:`D``*$&``"``````````"P*``!2
M"0``;`L``'4)``!@`P````````````"2"P``90D``````````````````!L"
M``!4"0``G`(``/4"```V!P```````.D*``#Y`@``P`4``$\'````````^0<`
M`(\'``!4`0``@@8```````!1"P````````````#-!P``O0L``-4$```>"@``
MQ@,``-,!``!$````=@D``.$(``#/!P``]0<```````!A!```^@<``*,+``#6
M"```O@D``.\```#U!```N@4``/H"````````Z@$``*@`````````````````
M``!_!```[`$``(4```!M"```XP@````````<`P``X@(``",(```?"0``6@<`
M`+$(```%`P``Y`H``"T+``!:!0``\00``$`'`````````````+@#```;!P``
M9P@```````!]````X@4``,L$``":"0``*P```#$*``!Q!P``OP,```````#(
M"@```````#\"```%````C`8``&H```#`"0``E`L``.((```F"@``?@4``(<$
M``"+"0``R0<``/$)````````%@4``$@&````````%`D``&@%```;"@``Z0@`
M`(<'``"%"P``.P0``&P)````````#0$```````"X!0``.`,````````;!0``
M`````,H&````````@0````````"J!P``1P<``$<&````````W08``)D*``#C
M!````````-$)``#4!P``=`(```````````````````````"M`@``2@0`````
M```D!````````/H!``!'`0``>0(``+(*``#6"0```````+0)````````````
M`,`"``#R`P```````-D````:````IPH`````````````!@8```````"(`@``
MU0(```````#-`@```````+<'```#`@``#PD``#`%``"Z`P``[@,``-<)````
M`````````'0'````````&@H``(($```I"0``X`@``-`$``!%"```\P0``(T)
M``!]"@``/0$``*8*````````[`(```4*``````````````D'````````>`4`
M`.L`````!P``]08```````!L!@``GP$``#D!``"="0``!@@```````#A`P``
MG0H``,@!``#&````M`L``+\"``!=!@```````&(```#3!P``]`4```````!B
M!0``\@$``%H(```L`0``'0D``)T````5!0```````+@)``!_"0```````-$#
M````````````````````````L@4```````#E"0``P0<`````````````40@`
M`/D#``#)!0``+08``"T(``!I````P0$``#<*``#J!@``YP<``-@)````````
M:0@``!(#````````(@L``,((``"K"P``%0L`````````````,0$``&0"``#D
M"```000``+H!`````````````````````````````*,%``"<!@``(P<``-<%
M````````(04`````````````0PL``"D!``",`0```````*8`````````8`4`
M``````"("P``=@(`````````````I@<``&@&``!O`````````&,```!U!P``
MW0D``````````````````($"``"L!0``)P,```````"#`0``#`````````"D
M"0````````````!W`@``M@H``*0'``"B````30,``,<*``"+!P``A`(``/0(
M``!="```!`$``+@'````````"P<``,D!````````Y`D``!H#``#."@``&00`
M`!,#```."0````````````"#"````````)($``"T"@``CPL```X+``"I`P``
MS@,``!D#`````````````$D&```8"`````````````!G"@``KPL``'\%``!`
M!0``HP(``&,'```K"0``\P```'<'``!Q!```O@$``+D"````````X`,``/T&
M```X"@``?P(``%L#``#G"0``=````&0+``"K!@``.@(``-0!``#5`P``A@$`
M`'P&``!U"```FP,``!P"``#F!```Q`H```````#-````704``+4*```Z"```
ME@L``%L%```9````#@,`````````````F0$``,,)``#L!@````````````"I
M`0``@0<``$L$``!J`P``5@H``,,$```F"```K@L```````!&!0```0H`````
M``#_`0``2PL``#X```"4`@``20H``%\*``!=`0``R0@`````````````^@4`
M```````````````````````$"P```````(D(``!?"P``+04``)@'``#<"```
M7@,``#0$````````7`,``&$*``#O!P``A@<``'L)``#5`0``Y@H``"4&``"B
M!```$@L``/P*``!N`@``)`<``(,&````````_0<``/\#```1````````````
M```T"0``CP0````````<!0``TP8```````!%"@``[@````D)```5`@``;0D`
M`",!`````````````'$)``#*`P```````*0$```_````4P@``*L)``!Y!0``
M#@$``-H&```1"```-0H``(P$``!B"0``8P0`````````````"@L`````````
M````$0H``(8(`````````````&X(```?`0``-P(``-<(``!Z`P``````````
M``!,!````````(,#````````>P4``%\'``"`"0``Y0H``+$'``!.`P``+@L`
M```````W`0``)@4````````:!0``B````.`&``!Q!@``ZP,``%H"````````
M1`<``.`)```(`@``.@4``!0%``!S"@``Y0$```````"P"P``&`0```T'````
M````F@(``%4"````"0```````(X(``#?!```*0<``!8)```*!```!0D``+('
M```A"@``FPH``-8!```8!@``T@,``'8*```F`P``SP,```<)``"*"```:@8`
M`)H+``!8"0```````%0'``!$"```-P<``!````!Q`0```````(8#````````
MJ0L``#L)````````A`$```8*````````,0```&X+````````AP4```("````
M````@PD``&(*```.!0``X08``$(*``#%"@````````````!X"```````````
M``#9"@``L@D``'\&``"B"```,0(``/L"```^!```=`@``,\```"""```*`4`
M`*`#````````5@@``+(!``#Z!```J0D``(D#`````````````#`$```T!0``
MH0,``(@*``#S"```/P4``(T(``!2`@``+P,```````#?"```\0```!P$````
M````%`<``,$"````````'`H``+T"``!F"```1@D````````A"```]@```.4%
M````````D0$``$\+``#5`````````)P#``!I!```M`8````````!!P``X00`
M`-8*``#Q!P```````/4!``#X!P``!0(``*<"``!>!@``V0D``-$*``"?````
M^0$`````````````````````````````=0$``,0"```#!P``_`$```````!(
M!P```````%<+```$!0``:@(``!H$````````,P```/8"``!)`0``2`,``&\+
M``"+"P``:@D``#L`````````W`$``$T'``#A`0``*P(``(D*````````````
M`,8)````````Q@H``%X+``!=`@``=0,````````K!```/00``/\'```U````
M60H``)\)``!2!````````%0(```@`P``)@<``"H*``#-"`````````````"!
M"P``L0,```````#V"```]@$``(X*````````!0@``,4#``"2"0```````#X(
M``!S!P```````%X$``#E`@``8`D``"\)```M"0``A`H``*T*``!E`@``(@0`
M`*$+```R!P``K`0``````````````````.4'```I`P```````$4!``!C`P``
M\PD``#($``!D!````0L``%,*`````````````#T+``##````H@L``.T"``!7
M````I0,``%,```#'!P``C@L``!()``!+`0``0@@``+@```"'`0``*0````H'
M``#;`P``B`4```````#V!@```````/L!``#?````KP````````#``P``````
M``<#```D"0``-P8``#T)````````^`0``&H'````````^`4``($*``!F!0``
M&`H``%D"``")````;P8``!`&``!#`P``108``)(*``"*`@``-@```*,#``"<
M````*@<``/(&``"E"@``;P$``!<%``!]!@```````!`$``#V!P``*`0``%<(
M``"V!```/P$```8)``#]`P``(@@``(T!``#V!````````+,%````````````
M`',)``"L"@``?0@````````)!0``F04`````````````#0D``/(%``!C`0``
MU@,``%`+````````B08``(("``"9````B@$``)8"````````O0D``$$&```0
M"0``%`$```````#I`P``EP,``*4+```T`@``!@L``%\!``"Y````@0D``!T`
M````````K`D``'<!``#J"@```````(P#````````*@@``-$'``#W"```X@8`
M`,,!``"D!0``H0$``#P&``````````````````"0!0```````$`)``#7!```
M^@,```````"=!@``/P8``,P(``"@!@``7@4``'D$``!S!0``0P8``"0!``#4
M"@``J08``.H)````!```9P<``,8"`````````````/T```"3!P``"`,``,@#
M````````80(``,<(``##"`````@``%,#````````O@@``&@(``"L"P``>`(`
M`#T```"9!```W@D````````]`@``(`4``+H*`````````````)<%``!/`0``
M=0L``.D$``!J!```/04```````"[`@``X0(``.\%`````````0(````````)
M`@```````&L*````````T@<``&0!````````D0L`````````````6P<``'X"
M````````?0(``-X%````````F@<```8``````````````#X&````````X@H`
M`"`$``#E!@``F@$``)4!``#R"0``@`@``#4+````````W0```!4(``"R"```
M:PD``%$&``!0"@``\04````````P!@``40(``#D*````!0``S`8``+4+``"V
M!@``\`(`````````````C`<```````"4`0``A@D``"P&``#4"0``H@<``"@&
M``"0!@``.`D``%P&``#`"```^0```&D'``!&!@``604``.@)```]!P``9PD`
M`/X(`````````````'8#```#`P```````+T*``"@!```&0$``+L!```8`P``
M20,``,\)``!#`0``I@$``(T*``#F!@```````"D(````````Z`,``)8!``";
M"```S0,``!$"````````Q00```````#Q`P```````%0"``!*"```0@L``(X$
M``!@!P``!0<```````"0"`````$``%L$```8`0```````+`%``!A`P``.P@`
M`$$%````````H04``*@$``"1"0```````'(%```*`0`````````````I!```
M@P(````````)"````````+X```#?`@``&P@``,8(``!"`P``:0,`````````
M````DP,``&L!```W!0``4@,``,$$```$"0``[P$````````E`0``J@@``,P$
M``!V!P```````,\*````````2@<``#0#```V"0``1@```/<!``!W````.0(`
M`(`#``">`@``K`,``$L#```X"P```````%P*``"+``````````````"F"P``
M?0L```P+``!("0```04``"8"`````````````-\#``````````````````!P
M!0``A`4````````3"@``LPD``)8&``"S"P``.`@``&$%````````_P4``'P$
M``#[`P``UPH`````````````1@0``(0)````````M0@```<$```U!P``104`
M`'`)```!`P``T@D``.X&````````V`$```````!#`@``DP0````````(````
M`````((!`````````````+4```"6`````````(X#````````?@,`````````
M`````````-L&```Z"@``:0L``+(#``"9`@```````"L%````````40H``!T'
M``````````,```````"H`@`````````````Y!P``'@$``+L#``"N`@``:`,`
M`%T*``!,!@```````````````````````&T*``"0!```W@````````!/`P``
MB@4``#0'`````````````%`#``!,`0``````````````````#P<``$T+```B
M!P`````````````4````7P```%\)```P````90,```\"`````````````.8!
M```3!```CP$``!T*```````````````````;!`````````````"H!@``````
M`-H#```+`0``$@@```````"5`P``F`@``*$*``#I!@``50<``$H+``","@``
M)`@``+D#``#["```X@<``#T&``!U!@```````-`"```$`@```````"<"``!H
M`0```````/<)```G`````````!4#````````%0D```````#I!0``:````%,'
M``#8`@``30@``)8#``````````````0```"J"@``#P8``+0!``!3!0``0@0`
M`#D$```C"0``&0(``.@"```5!@``*@(``````````````````!T"```4"@``
M4`0``#<````O````4PD``&T'``#V"0``3P```(<&``#C!0``P`H`````````
M````<@```#X#``#3!0``OP@``)0)```@"````````)0'``",````=@8``*(&
M```R"P``KP8``&P"````````W0,``-$"````````U```````````````C`4`
M`#H&``!["@``O`,``,T%```2!0``N`L```````!"!P``G0$``!<&``"C`0``
M``````````"'"```V@<```````!&!P```"`@("`@($-C.B``("`@("`@5&\Z
M(``@("`@1&%T93H@`"`@("!&<F]M.B``("8C,34Q.R`E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*%)E860@
M;VYL>2D`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE
M<W1E<F1A>2D`(%-U8FIE8W0Z(``@870@`"!I;B``(B5S(B!I<R!N;W0@82!D
M:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE
M(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S
M:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`(P`E+C)F
M34(@+R`E+C)F34(@("@E+C)F)24I`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!-97-S86=E<P`E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60@;65S<V%G97,@
M:&%V92!B965N(&1E;&5T960N`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O
M<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN
M`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`"5D(&UE<W-A9V5S(&AA=F4@8F5E
M;B!R97!O<G1E9"!A<R!S<&%M+@`E9"!T;R`E9"!O9B`E9"!-97-S86=E<P`E
M9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@
M2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E
M<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A
M;')E861Y(&5X:7-T<RX`)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L
M9&5R('=A<R!N;W0@<F5N86UE9"X`)7,@870@)7,@)7,`)7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"X`)7,@9F]L9&5R(&)E:6YG
M(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"X`)7,@:&%S(&%C
M8V5P=&5D+@`E<R!H87,@8V%N8V5L;&5D("(E<R(N`"5S(&AA<R!C86YC96QL
M960@)7,N`"5S(&AA<R!D96-L:6YE9"X`)7,@:&%S(')E<&QI960@=&\@82!F
M<F5E+V)U<WD@<F5Q=65S="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET
M871I;VX@=&\@(B5S(BX`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I
M;VX@=&\@)7,N`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN`"5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"X`)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E
M9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@<F5Q=65S=',@>6]U<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N
M8V4@870@(B5S(BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RX`
M)7,@=&\@)7,@;V8@)7,`)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R`B
M)7,B+@`E<R!W:7-H97,@=&\@861D('1O("5S+@`E<R!W:7-H97,@=&\@86UM
M96YD("(E<R(N`"5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`B)7,B
M+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N`"5S('=I<VAE
M<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@(B5S
M(BX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO
M;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E
M<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z("5S("@E9"9N
M8G-P.V]F)FYB<W`[)60I`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F
M<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG
M(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W
M:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`*$%P<&QY('1H97-E(&-H
M86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*0`H1&ES8V%R9"!A;&P@
M8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI`"A(
M5$U,*0`H4&QA:6X@5&5X="D`*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E
M96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@
M($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P
M<&QI960N*0`H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N
M9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C
M<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI
M8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`L(&=U
M<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,`+2T@<V5L96-T("TM`#$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+@`Q
M(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U
M<B!S>7-T96T@861M:6YI<W1R871O<BX`,2!M97-S86=E(&AA<R!B965N(')E
M<&]R=&5D(&%S(&YO="!S<&%M+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`Q(&UE
M<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2X`,3`P(&-H87)A8W1E
M<G,`,3`P,"!C:&%R86-T97)S`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R
M;6%T`#(T(&AO=7)S`#(U,"!C:&%R86-T97)S`#4P,"!C:&%R86-T97)S`#Q0
M<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@;&%R9V4@
M:6UA9V4@;F%M960@)7,@:7,@871T86-H960@=&\@=&AI<R!M97-S86=E+@!!
M(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@82!R971U
M<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE(')E8VEP:65N="X`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S
M`$%-(%-N;W<@4VAO=V5R<P!!32]030!!3D0`05!)($E$`$%B;W5T('1H:7,@
M961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97!T(&%N
M9"!A9&0@=&\@;7D@8V%L96YD87(`06-C97!T(')E<75E<W0`06-C97!T960`
M06-C97!T960Z(`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O
M<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]?=6YT
M<P!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N
M="!F<F]Z96XN`$%C8V]U;G0G<R!N86UE.@!!8V-O=6YT:6YG`$%C=&EO;G,`
M061D`$%D9"`E<P!!9&0@)7,@=&\@;7D@061D<F5S<R!";V]K`$%D9"!#:&EL
M9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE
M=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@
M=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@
M;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER
M`$%D9"!S;W5R8V4`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;R!A9&1R97-S(&)O
M;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('1O(&UY(&-A;&5N9&%R
M`$%D9"!U<V5R`$%D9&5D("(E<R(@87,@86X@871T86-H;65N="X`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@
M=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@;VX@
M82!N97<@;&EN92D\+V5M/@!!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B
M92!V:65W960@)7,N`$%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<P!!
M9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@
M9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&UE<W-A9V4@
M97)R;W(@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL
M<R!C86X@8F4@=FEE=V5D("5S+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&1R
M97-S($)O;VMS`$%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^
M*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\
M+V5M/@!!9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N
M=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@
M;F5W(&QI;F4I/"]E;3X`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F
M;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N
M`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!
M;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S
M:6]N<P!!;&P@9F]U<B!S:61E<P!!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO
M=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"
M3U@@9FEL93H`06QL(&UE<W-A9V5S(&EN('EO=7(@(B5S(B!F;VQD97(@;VQD
M97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@9&5L971E9"X`
M06QL(&]L9"!L:6YK960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H
M<R!O;&0@=VEL;"!B92!D96QE=&5D+@!!;&P@;VQD('-E;G0M;6%I;"!F;VQD
M97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`
M06QL(')I9VAT<R!O;B!F;VQD97(@(B5S(B!S=6-C97-S9G5L;'D@<F5M;W9E
M9"!F;W(@=7-E<B`B)7,B+@!!;&QO=R!&;VQD97(@0W)E871I;VX_`$%L;&]W
M(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/P!!
M;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@
M3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@
M57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E
M;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06QT97)N871I=F4@<&%R=',@9F]R
M('1H:7,@<V5C=&EO;CH`06QW87ES`$%L=V%Y<R!S879E(&%T=&%C:&UE;G1S
M`$%M97)I8V%N(%-A;6]A`$%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP
M=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE($E-05`@<V5R=F5R
M('-A:60Z(`!!;B!E<G)O<B!O8V-U<G)E9"!F;VQL;W=I;F<@=&AI<R!L:6YK
M.B`E<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO
M=VX@97)R;W(@:&%S(&]C8W5R960N`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E
M9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W(&YO=&4N`$%N('5N:VYO=VX@97)R
M;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN`$%N9&]R
M<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YS
M=V5R960`06YS=V5R960@;65S<V%G97,`06YT87)C=&EC80!!;G1I9W5A(&%N
M9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%P<&QY($9I;'1E<G,`07!P;'D@1FEL=&5R<R!T
M;R`E<P!!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/P!!<'!L
M>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/P!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE
M`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T
M92!T:&ES(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX_`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/P!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@
M:7,@3D]4(')E8V]M;65N9&5D(2D`07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A
M='1A8VAM96YT/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E
M<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@96UP='D@=&AI<R!F;VQD97(_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!E;7!T>2!Y;W5R('-P86T@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_
M`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E
M(&%S(&EN;F]C96YT/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T
M('1H:7,@;65S<V%G92!A<R!S<&%M/P!!<F=E;G1I;F$`07)M96YI80!!<FUE
M;FEA;B`H05)-4T-)22TX*0!!<G)I=F%L(%1I;64`07)T`$%R=6)A`$%S8V5N
M9&EN9P!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@
M4F5G:6]N`$%S:P!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T
M=&%C:"!&:6QE<P!!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K
M97D@=&\@>6]U<B!M97-S86=E/P!!='1A8VAE9"!&:6QE.@!!='1A8VAE9"!F
M:6QE("(E<R(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@
M1FEL92!.3U0@871T86-H960N`$%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C
M86QE;F1A<B!R97%U97-T('EO=2!S96YT+@!!='1A8VAE9"!I<R!A;B!I0V%L
M96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0`071T86-H
M;65N=`!!='1A8VAM96YT("5S(&1E;&5T960N`$%T=&%C:&UE;G0@26YF;W)M
M871I;VX`071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N
M="!T>7!E`$%T=&%C:&UE;G1S`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+@!!='1E;F1E97,`071T96YT:6]N`$%T=')I8G5T97,`075G=7-T`$%U
M<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q
M=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I
M=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VEM<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I
M<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D
M9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`
M075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I
M8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`075T;VUA=&EC86QL
M>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E
M<B!I<R!I;B!M>2!A9&1R97-S8F]O:S\`079A:6QA8FQE($%D9')E<W,@8F]O
M:W,Z`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B
M86EJ86X`07IU<@!"3T9(($5X8W5S97,`0F%C7VL@=&\@)7,`0F%C:R!T;R`E
M<P!"86-K('1O($UU;'1I<&QE($UE<W-A9V4@5FEE=R!);F1E>`!"86-K('1O
M(%1H<F5A9"!$:7-P;&%Y`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"
M860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`
M0F%D(&QO9VEN(&YA;64@;W(@<&%S<W=O<F0N`$)A9"!O<B!M86QF;W)M960@
M<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,`0F%D(')E<75E<W0Z("5S
M+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87(@5&EM90!"87(@=&EM90!"87)B861O<P!"87)B:64`0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)C
M8P!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;&]W(&ES('1H92!R87<@=&5X
M="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N`$)E;FEN`$)E
M<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L86-K;&ES=`!";&]C:R`B)7,B(&]F
M(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!"
M;&]C:R!4>7!E`$)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S
M<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/P!";'5E($UO;VX`
M0FQU92!A;F0@5VAI=&4`0F]D>0!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O
M<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$`0F]T:`!";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F
M($UE<W-A9V4`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL
M`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<F]W;@!"<G5N96D@
M1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S
M;P!"=7)N="!/<F%N9V4`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0U]H87)S970`0V%C:&4@
M:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I
M80!#86UE<F]O;@!#86UO=69L86=E`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@
M<F5M;W1E(&UA:6P@<V5R=F5R+@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E
M;6]T92!M86EL('-E<G9E<CH@`$-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N
M;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R
M96YT(&UA:6QB;W@N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I
M=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L
M($UE<W-A9V4`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;F-E;&QI;F<@=&AI
M<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N
M=',N`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R
M9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM
M86X@27-L86YD<P!#8P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL
M('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP
M:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E
M<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A
M=&4@4&]L:6-I97,`0V5R=&EF:6-A=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B
M;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R
M+@!#:&%D`$-H86ER(%!E<G-O;@!#:&%N9V4`0VAA;F=E($%L;`!#:&%N9V4@
M1F]L9&5R`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!D969A=6QT(&ED
M96YT:71Y`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N
M>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W(&UE<W-A
M9V5S(&%R92!S;W)T960N`$-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R
M('-E='1I;F=S+@!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M
M86EL<RX`0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B!E;6%I;"X`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P
M<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H87)A8W1E<G,@=&\@9&ES
M<&QA>3H`0VAE8U]K($QI;FLN+BX`0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@
M36%I;`!#:&5C:R!?06QL+TYO;F4`0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y
M;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ`$-H96-K('-P96QL:6YG(&)E
M9F]R92!S96YD:6YG(&$@;65S<V%G93\`0VAE8VL@=&AE(&)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92X`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H
M:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!8W1I;VXZ`$-H;V]S
M92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@;6%I;"!S97)V97(Z`$-H;V]S92!A
M(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.@!#:&]O
M<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@86-T
M:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T
M('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:&]O<V4@=&AE(&%D
M9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+@!#:&]O
M<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@
M97AP86YD:6YG(&%D9')E<W-E<RX`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I
M8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@
M=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R`E<R!T
M;R!C;VYV97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B
M<F]W<V5R(&-A;B!V:65W+@!#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@:6UA
M9V4N`$-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G92X`0VQI
M8VL@)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD
M;W<N`$-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G
M92X`0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R
M871E('=I;F1O=RX`0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R
M96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N`$-L:6-K(&AE<F4@
M=&\@4TA/5R!T:&4@26UA9V5S`$-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C
M=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@
M=&\@<V5A<F-H+@!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:R!T;R!3879E(%!'
M4"!0=6)L:6,@2V5Y(&EN('EO=7(@061D<F5S<R!B;V]K`$-L:6-K('1O(%-A
M=F4@4R]-24U%(&-E<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S<R!"
M;V]K`$-L:6-K871E;&P@=FEA($A45%``0VQI8VMI;F<@;VX@=&AE(&%D9')E
M<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<@!#
M;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@
M=&\@8F4@<F5A9`!#;&]S90!#;&]S92!7:6YD;W<`0VQO<V4@=&AI<R!W:6YD
M;W<`0VQO<V5D($9O;&1E<@!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#
M;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S90!#;VQL87!S92!!;&P`
M0V]L;&%P<V4@06QL($9O;&1E<G,`0V]L;&%P<V4@1F]L9&5R`$-O;&QA<'-E
M(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L
M;W(@26YD:6-A=&]R.B``0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H
M96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!L
M971E9`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP;W-E(&%N;W1H97(@;65S
M<V%G90!#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/P!#
M;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H
M:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@9F5A='5R92D_`$-O;7!U=&5R<P!#
M;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92X`0V]N9FEG=7)E("5S`$-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I
M<W!L87EE9"X`0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+@!#;VYF
M:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R
M+@!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O
M;FYE8W1I;VX@=&\@<V5R=F5R(&9A:6QE9`!#;VYT86-T<P!#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F
M("(E<R(`0V]N=&EN=64`0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N`$-O
M;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+@!#;VYT<F]L(&]P=&EO;G,@
M<F5L871I;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG+@!#;VYT<F]L('=H96X@
M;F5W(&UA:6P@=VEL;"!B92!C:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@
M;F]T('1O(&YO=&EF>2!Y;W4@=VAE;B!I="!A<G)I=F5S+@!#;VYV97)T('1E
M>'1U86P@96UO=&EC;VYS(&EN=&\@9W)A<&AI8V%L(&]N97,_`$-O;VL@27-L
M86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I
M;VX`0V]P>2!T;R!F;VQD97(`0V]R;F9L;W=E<@!#;W)R96-T`$-O<G)E8W1E
M9"!497AT`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD
M(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S`$-O=6QD
M(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!C<F5A=&4@=&AE
M(%9&4R!B86-K96YD.B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@
M)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B
M+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RX`0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<RX`0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R
M;VT@=&AE($U3+51.148@871T86-H;65N="X`0V]U;&0@;F]T(&5X=')A8W0@
M=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H:79E+@!#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F
M971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N
M`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y("<E<R<N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N
M;W0@;6MD:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I
M=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@
M9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(&]P96X@<V5C
M=7)E(&-O;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R+B`E<R`Z("5S+@!#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R;VT@24U!
M4"!S97)V97(N`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T(')M9&ER("<E<R<N`$-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O
M=6QD(&YO="!U;FQI;FL@)R5S)RX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U
M;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E($9O;&1E
M<@!#<F5A=&4@2V5Y<P!#<F5A=&4@5FER='5A;"!&;VQD97(`0W)E871E(&$@
M3F5W($%C8V]U;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@4W!A;2!F
M;VQD97(`0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E871E(&$@;F5W
M(&]N90!#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@82!N
M97<@=')A<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G
M86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R
M<RP@86YD(&1E;&5T92!S<&%M+@!#<F5A=&4@;F5W('-T871I;VYE<GD`0W)E
M871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+@!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S
M:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R
M<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!A8V-E<W,@=&\@)7,`0W5R<F5N
M="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!A8V-O=6YT
M<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+@!#=7-T
M;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN`$-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S
M`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y
M<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$
M86EL>0!$871?90!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$
M871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@
M0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L:6YE9`!$96-L
M:6YE9#H@`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`
M1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-E87)C:"!&:65L9`!$969A=6QT
M(%-H96QL`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T
M:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L96=A=&4@<&]S:71I;VX`
M1&5L96=A=&5D`$1E;&5T90!$96QE=&4@)7,@4'5B;&EC($ME>0!$96QE=&4@
M0V5L;`!$96QE=&4@0W5R<F5N="!+97ES`$1E;&5T92!&;VQD97(H<RD`1&5L
M971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E
M(%-E;&5C=&5D($9O;&1E<G,`1&5L971E(%-T871I;VYE<GD`1&5L971E(%9I
M<G1U86P@1F]L9&5R`$1E;&5T92!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N
M(&9O<B`E<P!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL
M`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP
M;&%T90!$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V
M97(_`$1E;&5T92!F<F]M(&UY(&-A;&5N9&%R`$1E;&5T92!M97-S86=E<P!$
M96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@
M;6]N=&@_`$1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN
M:6YG(&]F(&UO;G1H/P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE
M=&4@<W!A;2!M97-S86=E<P!$96QE=&4@<W5B(&9O;&1E<G,`1&5L971E('1H
M92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T
M92!T:&ES(&QI;FL`1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L971E9"!T:&4@871T86-H
M;65N="`B)7,B+@!$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E;&EV
M97)Y('1I;64`1&5N;6%R:P!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O
M<B!F<F5E+V)U<WD@:6YF;W)M871I;VX`1&5S8V5N9&EN9P!$97-C<FEB92!T
M:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS`$1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT
M`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ED(&YO
M="!A='1A8V@@(B5S(B!A<R!T:&4@9FEL92!W87,@96UP='DN`$1I;2!S:6=N
M871U<F5S/P!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>0!$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A
M9G1E<B!S96YD:6YG(&$@;65S<V%G93\`1&ES<&QA>2!D971A:6QE9"!F;W)E
M8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I
M<W!L87D@:6X@0F]D>2!O9B!-97-S86=E`$1I<W!L87D@<&]P+75P(&YO=&EF
M:6-A=&EO;B!O9B!N97<@;6%I;#\`1&ES<&QA>2!T:&4@(D5M<'1Y(%-P86TB
M(&QI;FL@:6X@=&AE(&UE;G5B87(_`$1I<W!L87D@=&AE(")%;7!T>2!4<F%S
M:"(@;&EN:R!I;B!T:&4@;65N=6)A<C\`1&ES<&]S:71I;VX`1&EV:61E<@!$
M:FEB;W5T:0!$;R!.3U0@;6%T8V@`1&\@3F]T($-H96-K($9O;&1E<BAS*2!F
M;W(@3F5W($UA:6P`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<`!$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN
M('1H92!&<F]M.B!C;VQU;6X`1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O
M;&1E<C\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC86X@4F5P=6)L
M:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;VYE`$1O=VYL
M;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T`$1O
M=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*0!$;W=N;&]A
M9"!&;VQD97(H<RD`1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%T`
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="X`1&]W;FQO860@:6X@+GII<"!&;W)M870`1')A9G0`1')A9G0@9F]L9&5R
M`$1R869T<R!F;VQD97(Z`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%
M+6UA:6P@061D<F5S<P!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O
M<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`14Y$`$52
M4@!%4E)/4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N
M`$5C=6%D;W(`161I=`!%9&ET($)L86-K;&ES=`!%9&ET($)L;V-K`$5D:70@
M1FEL=&5R<P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI
M<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@4V5A<F-H(%%U
M97)Y`$5D:70@5FER='5A;"!&;VQD97(`161I="!6:7)T=6%L($9O;&1E<B!$
M969I;FET:6]N(&9O<B`E<P!%9&ET(%=H:71E;&ES=`!%9&ET(&]P=&EO;G,@
M9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@>6]U<B!B;&%C:VQI<W0`161I="!Y;W5R(&9I;'1E
M<B!R=6QE<P!%9&ET('EO=7(@<')E9F5R96YC97,@9F]R(&%C8V5S<VEN9R!O
M=&AE<B!M86EL(&%C8V]U;G1S+@!%9&ET('EO=7(@=VAI=&5L:7-T`$5D=6-A
M=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I
M8V]N<P!%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+@!%;7!T:65D(&%L
M;"!M97-S86=E<R!F<F]M(%9I<G1U86P@5')A<V@@1F]L9&5R+@!%;7!T>2!&
M;VQD97(H<RD`16UP='D@4V5L96-T960@1F]L9&5R<P!%;7!T>2!4<F%S:"!F
M;VQD97(`16UP='D@7U-P86T`16UP='D@7U1R87-H`$5M<'1Y(&UE<W-A9V4N
M`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!01U`@
M9G5N8W1I;VYA;&ET>3\`16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/P!%
M;F%B;&4@;65S<V%G92!P<F5V:65W<S\`16YC<E]Y<'1I;VX@3W!T:6]N<P!%
M;F-R>7!T960`16YD`$5N9"!F;W)W87)D960@;65S<V%G90!%;F0@;65S<V%G
M90!%;F0@;65S<V%G92!F<F]M("5S`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R
M`$5N=&5R(%!A<W-P:')A<V4`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N
M=&5R('1H92!L971T97)S(&)E;&]W.@!%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@4W!A;2!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W
M(&1R869T<R!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E
M;G0@;6%I;"!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R
M87-H(&9O;&1E<@!%;G1I<F4@365S<V%G90!%;G1R>2`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:P!%<G)O<@!%<G)O
M<B`T,#,Z(%)E<75E<W0@=V%S(&9O<F)I9&1E;BX`17)R;W(@-3`S.B!397)V
M:6-E(&ES('5N879A:6QA8FQE+@!%<G)O<B!C;VYN96-T:6YG('1O($E-05`@
M<V5R=F5R+B`E<R`Z("5S+@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('-E
M;F1I;F<@<F5P;'DZ("5S+@!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`
M17)R;W(@=W)I=&EN9R`B)7,B+@!%<G)O<B!W<FET:6YG("<E<R<N`$5R<F]R
M.B!(860@=&\@;6%K92`E9"!R97%U97-T<RP@8VAE8VL@=7-E<FYA;64@86YD
M('!A<W-W;W)D(&]R(&EN8W)E87-E(')E<75E<W0@8V]U;G0@;&EM:70N`$5R
M<F]R.B!5;G)E8V]G;FEZ960@2%144"!S=&%T=7,@=V%S(')E8VEE=F5D.B`E
M<RX`17)R;W(Z(&9S;V-K;W!E;B@I(&9A:6QE9"X`17)R;W(Z(&9S;V-K;W!E
M;B@I(&9A:6QE9"X@17)R;W(@;F\Z("5S+B!%<G)O<B!S=')I;F<@)7,N`$5S
M=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5N="!S=6-C97-S9G5L
M;'D@9&5L971E9"X`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`
M179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`
M17AE8W5T90!%>'!A;F0`17AP86YD($%L;`!%>'!A;F0@06QL($9O;&1E<G,`
M17AP86YD($9O;&1E<@!%>'!A;F0@3F%M97,`17AP86YD(%-I9&5B87(`17AP
M86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY
M(&EN('1H92!B86-K9W)O=6YD/P!%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@
M=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_`$5X<&%N9&EN
M9P!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`
M1E10('5P;&]A9"!O9B!S971U<`!&7V5T8V@@36%I;`!&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE
M9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`
M1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@
M=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T
M86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS
M(&QI:V4Z(`!&971C:"!-86EL`$9E=&-H($UA:6P@:6X@82!S97!A<F%T92!W
M:6YD;W<_`$9E=&-H(&UE<W-A9V5S('5P;VX@;&]G9VEN9R!O;C\`1F5T8VAE
M9"`E9"!M97-S86=E<R!F<F]M("5S`$9E=&-H960@,2!M97-S86=E(&9R;VT@
M)7,`1F5T8VAM86EL.B``1F5T8VAM86EL.B!N;R!N97<@;65S<V%G97,N`$9E
M=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FE?;'1E<G,`1FEE;&0@;6%T
M<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE
M($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N
M86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<B!/<'1I;VYS`$9I;'1E
M<B!3971T:6YG<P!&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI
M='D_`$9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M
M+@!&:6QT97)S`$9I;'1E<G,@3D]4($%C=&EV90!&:6QT97)S.B`E<R!M86YA
M9V5M96YT('!A9V4`1FEN9`!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@36%I
M;&)O>"!086=E`$9I<G-T(%!A9V4`1FER<W0@475A<G1E<@!&;U]R=V%R9`!&
M;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]L9&5R($%C=&EO;G,@+2!#;VYF
M:7)M871I;VX`1F]L9&5R($YA=FEG871O<@!&;VQD97(@4W5M;6%R>0!&;VQD
M97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"X`1F]L9&5R('5S92!I<R!N;W0@
M96YA8FQE9"X`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_
M`$9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@
M9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y`$9O<FUS`$9O<G1U;F4`1F]R='5N
M92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R
M=V%R9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A9V4@9G)O
M;2`E<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P
M;VQI=&%N`$9R964O0G5S>2!);F9O<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`
M1G)E92]"=7-Y(%)E<75E<W0`1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`
M1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R
M;B!497)R:71O<FEE<P!&<F]?;0!&<F]M`$9R;VT@061D<F5S<P!&<F]M('1H
M92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9W9#H`
M1G=D.B``1G=D.B`E=2!&;W)W87)D960@365S<V%G97,`1V%B;VX`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@
M3W!T:6]N<P!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#
M;V1E`$=E;W)G:6$`1V5R;6%N>0!'970@;VYL>2!N97<@;65S<V%G97,_("A)
M34%0(&]N;'DI`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/
M<'1I;VYS`$=O`$=O('1O($UE<W-A9V4`1V\@=&\@861D<F5S<R!B;V]K(&5N
M=')Y(&]F("(E<R(`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`
M1W)A;G0@86-C97-S`$=R87ES8V%L90!'<F5E8V4`1W)E96X`1W)E96YL86YD
M`$=R96YA9&$`1W)E>0!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U
M<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R
M;W5P<P!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N
M<P!'=65S="!397)V:6-E<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S
M874`1W5Y86YA`$A%4D4`2%1-3`!(5$U,(%9E<G-I;VX@;V8@365S<V%G90!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R
M:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96EG:'0`2&5I9VAT("AI;B!P:7AE;',I`$AE;'``2&5L<"!U<VEN
M9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN
M:6YG(&]F('1H92!F:6QE.@!(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E
M(&-O;7!O<VEN9SH`2&ED9&5N`$AI9&1E;B!I;B!4:')E860@5FEE=P!(:61E
M($1E;&5T960`2&ED92!5;G-U8G-C<FEB960`2&EG:`!(:6=H(%!R:6]R:71Y
M`$AI9VAE<W0`2&]?;64`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O
M<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O
M2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S
M<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S
M(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%
M($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5
M;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@
M<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W1M86EL($%C8V]U;G1S`$AO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!D;R!Y;W4@=V%N
M="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/P!(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R
M97!L>0!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-
M05``24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*0!)34%0(%-E<G9E<B!C
M;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S`$E-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S`$E-05`@;W9E<B!34TP`24U!4"!O=F5R(%-33"`H<V5L
M9BUS:6=N960@8V5R=&EF:6-A=&4I`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG
M;F5D*0!)34%0('-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN`$E-05`L
M(&YO(%1,4P!)34%0+U!/4#,@36%I;"!397)V97)S`$E0($%D9')E<W,`25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?
M;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V
M92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"X`268@>6]U(&-O
M;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E
M(&QO<W0A`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EG
M;F]R90!)9VYO<F4@06QL`$EM86=E`$EM86=E(%!R979I97<Z`$EM86=E(%52
M3`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A
M;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T`$EM<&]R="!+97D`
M26UP;W)T($ME>7!A:7(`26UP;W)T($UE<W-A9V5S`$EM<&]R="!01U`@2V5Y
M`$EM<&]R="!097)S;VYA;"!#97)T:69I8V%T90!);7!O<G0@4&5R<V]N86P@
M4')I=F%T92!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME
M>0!);7!O<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<P!);7!O<G0@
M4'5B;&EC($ME>0!);7!O<G0@4'5B;&EC(%!'4"!+97D`26UP;W)T(%!U8FQI
M8R!3+TU)344@2V5Y`$EM<&]R="!3+TU)344@2V5Y`$EM<&]R="!M8F]X($9I
M;&4`26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RX`26UP;W)T
M+"!3=&5P("5D`$EM<&]R=&%N=`!);7!O<G1A;G0@;65S<V%G97,`26UP;W)T
M960@)60@;65S<V%G97,@9G)O;2`E<RX`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26X@4')O8V5S<P!);E]S97)T(%)O=R!!9G1E<@!)
M;F)O>`!);F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN
M(&$@<F5P;'D_`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY
M/P!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A
M<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN
M9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92X`26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>0!);F9O<FUA=&EO;B!O
M;B!097)S;VYA;"!0<FEV871E($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA
M;"!0=6)L:6,@2V5Y`$EN;&EN90!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E
M<G0@0V5R=&EF:6-A=&4@2&5R90!);G-E<G0@26UA9V4`26YS97)T(%!E<G-O
M;F%L(%!R:79A=&4@4$=0($ME>2!(97)E`$EN<V5R="!097)S;VYA;"!0=6)L
M:6,@4$=0($ME>2!(97)E`$EN<V5R="!0=6)L:6,@4$=0($ME>2!(97)E`$EN
M<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F
M;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E
M`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS
M97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A
M<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E
M9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF
M>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`
M26YT96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES
M(&-O;7!O;F5N="X`26YV86QI9"!!9&1R97-S`$EN=F%L:60@4F5M;W1E($UA
M:6QB;W@`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI
M9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H
M($E$+@!);G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N
M`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&ME>0!);G9A
M;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!)
M;G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@
M<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!E<G-O
M;F%L(%!'4"!P<FEV871E(&ME>2X`26YV86QI9"!P97)S;VYA;"!01U`@<'5B
M;&EC(&ME>2X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C
M;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J
M96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D
M871A+@!);G9E;G1O<GD`26YV97)T`$EN=F5R="!S96QE8W1I;VX`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`
M27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`
M2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E
M<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2T(`
M2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+@!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y
M(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO;&%B`$MO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI
M8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U
M=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,
M87-T($AA;&8`3&%S="!-86EL8F]X(%!A9V4`3&%S="!086=E`$QA<W0@4&%S
M<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@
M;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@
M3F5V97(`3&%T=FEA`$QA=F5N9&5R`$QA=P!,87EO=70`3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V
M86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H
M:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!";'5E`$QI9VAT($1R:7IZ;&4`
M3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,
M:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H
M="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!!
M='1A8VAM96YT<S\`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN
M:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B:61D96XN`$QI;FMS`$QI;FMS('=I
M;&P@97AP:7)E(&]N("5S`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@
M=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"!O
M;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET
M;'DI`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R
M`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI
M<W1I;F<@:6X@=&AE($AE861E<@!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C
M86P@36%I;&)O>#H`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A
M=&EO;@!,;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G:6X`3&]G:6X@
M5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D
M+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W(%!R:6]R:71Y`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QO=V5S=`!,;WEO;&$`3&]Y;VQA($)L=64`3'5X96UB;W5R9P!-30!-
M3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'
M`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9@!-86-I;G1O<V@@1FEL90!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I
M;"!!9&UI;@!-86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y<&4@=&\@8V]N
M;F5C="!T;SH`36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/
M<'1I;VYS`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S
M`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T
M(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K($%L;"!-
M97-S86=E<R!I;B!&;VQD97(@87,@4V5E;@!-87)K($%L;"!-97-S86=E<R!I
M;B!&;VQD97(@87,@56YS965N`$UA<FL@87,Z`$UA<FL@9&EF9F5R96YT(&QE
M=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\`36%R:R!M
M97-S86=E<R!A<R!S965N/R`H24U!4"!O;FQY*0!-87)K('-I;7!L92!M87)K
M=7`_`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H
M97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)
M<VQA;F1S`$UA<G1I;FEQ=64`36%T8V@@06QL(%%U97)I97,`36%T8V@@06YY
M(%%U97)Y`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-
M87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D
M+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO
M=7)S.B``36%X:6UU;2!!='1A8VAM96YT(%-I>F4`36%X:6UU;2!.=6UB97(@
M;V8@1F]L9&5R<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA
M>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E
M86-H960N`$UA>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE(')E86-H960N
M`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE971I;F<@0V%N8V5L;&%T:6]N`$UE
M971I;F<@26YF;W)M871I;VX`365E=&EN9R!0<F]P;W-A;`!-965T:6YG(%)E
M<&QY`$UE971I;F<@57!D871E`$UE971I;F<@57!D871E(%)E<75E<W0`365M
M8F5R<P!-96YU($9O;&1E<B!,:7-T`$UE;G4@;6]D93H`365R9V4@8V5L;',`
M365S<V%G90!-97-S86=E($-O;7!O<VET:6]N`$UE<W-A9V4@1&%T90!-97-S
M86=E($]P=&EO;G,`365S<V%G92!396%R8V@`365S<V%G92!3:7IE`$UE<W-A
M9V4@4V]U<F-E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D
M+@!-97-S86=E(%9I97=I;F<`365S<V%G92!E>'!I<F5D+@!-97-S86=E(&9L
M86=S`$UE<W-A9V4@9F]L9&5R<P!-97-S86=E(&9R;VT@)7,`365S<V%G92!H
M87,@871T86-H;65N=',`365S<V%G92!I<R!E;F-R>7!T960`365S<V%G92!I
M<R!S:6=N960`365S<V%G92!M871C:&5S`$UE<W-A9V4@<F5D:7)E8W1E9"!S
M=6-C97-S9G5L;'DN`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N
M;W0@<V%V960@=&\@)7,`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2X`365S
M<V%G92!T>7!E`$UE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I
M97<N`$UE<W-A9V5S('1O`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@
M;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A
M9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A
M9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI
M<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D
M:69I960@1&%T90!-;V1I9GD`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L
M(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-
M;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R92!T:&%N
M(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"`B)7,B+@!-;W)O8V-O`$UO
M<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E`$UO
M=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W
M;@!-;W9E('1O(&9O;&1E<@!-;W9E('5P`$UO>F%M8FEQ=64`36]Z:6QL80!-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU
M;'1I<&%R="]A;'1E<FYA=&EV90!-=6QT:7!L92!-97-S86=E(%9I97<`375L
M=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA
M=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)
M($1O($Y/5"!!9W)E90!.3TY%`$Y/5$4`3F%M90!.86UE(&%N9"]O<B!E;6%I
M;"!C86YN;W0@8F4@96UP='D`3F%M:6)I80!.875R=0!.95A4`$YE961S($%C
M=&EO;@!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.
M971S8V%P92!"87-E(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P
M92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T
M92!T>7!E`$YE='=O<FL`3F5V97(`3F5V97(@<V%V92!A='1A8VAM96YT<P!.
M97<`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($9O;&1E<@!.97<@
M36%I;`!.97<@365S<V%G90!.97<@365S<V%G92!T;R`E<P!.97<@36]O;@!.
M97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@;65S<V%G
M97,`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E
M>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L
M86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@
M365S<V%G90!.97AT(%!A9V4`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U
M80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@0V5R=&EF:6-A=&4@
M9F]U;F0`3F\@16YC<GEP=&EO;@!.;R!+97ES(&EN($ME>7)I;F<`3F\@365S
M<V%G97,`3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N`$YO(%!E<G-O;F%L
M($-E<G1I9FEC871E(%!R97-E;G0`3F\@4')E=FEE=R!497AT`$YO(%!U8FQI
M8R!+97ES($9O=6YD`$YO(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D+@!.
M;R!A='1A8VAM96YT<R!F;W5N9"X`3F\@879A:6QA8FQE(&-O;F9I9W5R871I
M;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE
M('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M
M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET
M:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N
M=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!6
M1E,N`$YO(&-R961I="!L969T+@!.;R!D97-C<FEP=&EO;B!F;W5N9`!.;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@96UA:6P@:6YF;W)M871I;VX@;&]C
M871E9"!I;B!T:&4@<'5B;&EC(&ME>2X`3F\@9FEL92!U<&QO861E9`!.;R!F
M;VQD97(@<V5L96-T960N`$YO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@
M9F]R(&YE=R!M86EL+@!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&9O
M;&1E<G,@=VET:"!N97<@;65S<V%G97,`3F\@9F]L9&5R<R!W:71H('5N<V5E
M;B!M97-S86=E<P!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T
M+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!B;V1Y('1E>'0`
M3F\@;65S<V%G92!R971U<FYE9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@
M;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"X`3F\@;F%M92!S<&5C:69I
M960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE
M<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('!E<G-O;F%L
M(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"X`3F\@<&5R<V]N86P@4$=0('!U
M8FQI8R!K97D@:6UP;W)T960N`$YO('!E<G-O;F%L(%,O34E-12!C97)T:69I
M8V%T97,@:6UP;W)T960N`$YO('!E<G-O;F%L('!R:79A=&4@:V5Y(&5X:7-T
M<R!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+@!.
M;R!Q=6]T82!S970`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T
M;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S<&5L;&-H96-K:6YG('!R;V=R
M86T@8V]N9FEG=7)E9"X`3F\@<W!E;&QI;F<@97)R;W)S`$YO('-U8V@@9FEL
M90!.;R!S=6=G97-T:6]N<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N`$YO('5S97(@<W!E8VEF:65D+@!.;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V
M97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`3F]N90!.;VYE("AU
M<V4@:6UP;&EC:70I`$YO<F9O;&L@27-L86YD`$YO<FUA;`!.;W)T:&5R;B!(
M96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T
M($%F=&5R`$YO="!"969O<F4`3F]T($1E;&5T960`3F]T($1R869T`$YO="!)
M;7!O<G1A;G0`3F]T(%!E<G-O;F%L`$YO="!A(&1I<F5C=&]R>0!.;W0@82!V
M86QI9"!P=6)L:6,@:V5Y+@!.;W0@9&5L971E9"!M97-S86=E<P!.;W0@:6UP
M;&5M96YT960N`$YO="!I;7!O<G1A;G0@;65S<V%G97,`3F]T('-E=`!.;W0@
M<W5P<&]R=&5D+@!.;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I;64`
M3F]T97,`3F]T:&EN9P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T
M:6-E`$YO=&EF:6-A=&EO;CH@3&EN:V5D(&%T=&%C:&UE;G0@9&]W;FQO861E
M9`!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK
M960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F
M(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO
M;G1H;'DN`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]2`$]B:F5C
M=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R
M`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E
M;G0N`$]L9"!M97-S86=E<P!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES
M(&YO="!C;W)R96-T+@!/;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R
M9V5D+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N`$]N;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A
M9V5S(&EN('1H96T_`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE
M(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!O;F4@9F]L9&5R('-H;W5L
M9"!B92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I;VXN`$]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P95]N($9O;&1E
M<@!/<&5N($9O7VQD97(`3W!E;B!&;VQD97(`3W!E;B!I;B!A(&YE=R!W:6YD
M;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M
M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;F5D($9O;&1E<@!/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N
M86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D
M($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI
M>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R
M($UA:6P@06-C;W5N=',`3W1H97(@3W!T:6]N<P!/=VYE<B!097)M:7-S:6]N
M<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ
M36%I;"!B86-K96YD`%!'4`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N
M8W)Y<'0@365S<V%G90!01U`@16YC<GEP=&5D($1A=&$`4$=0($5R<F]R.B``
M4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A
M=&4@:V5Y+@!01U`@3W!T:6]N<P!01U`@4&%S<W!H<F%S92!);G!U=`!01U`@
M4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+@!01U`@4'5B;&EC($ME>0!01U`@4'5B;&EC($ME>2!4
M97AT`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,@*"5S*2(@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"X`4$=0(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E
M<W-F=6QL>2!D96QE=&5D+@!01U`@4'5B;&EC($ME>7)I;F<`4$=0(%-I9VX@
M365S<V%G90!01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4`4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T80!01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D
M9&5D+@!01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N`%!'4"!S
M=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!01U`@<W5P<&]R
M="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N
M871U<F4@:7,@=6YA8FQE('1O(&)E('9E<FEF:65D+@!01U`@<W5P<&]R="!I
M<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B
M;&4@=&\@8F4@9&5C<GEP=&5D+@!01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U
M<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R
M<F5N=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T
M(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@4$=0(&9E871U<F5S
M('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+@!02%`@0V]D90!02%`@4VAE;&P`
M4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3
M;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4#,`4$]0,R`H075T
M;R!$971E8W0@4')O=&]C;VQS*0!03U`S(&]V97(@4U-,`%!/4#,@;W9E<B!3
M4TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*0!03U`S(&]V97(@4U-,("AS
M96QF+7-I9VYE9"D`4$]0,RP@;F\@5$Q3`%!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086=E("5D(&]F("5D`%!A9V4@
M=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4`4&%G92!W:71H('1H92!,
M87-T(%5N<V5E;B!-97-S86=E`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`
M4&%R86=U87D`4&%R="AS*0!087)T;'D@0VQO=61Y`%!A<W-P:')A<V4`4&%S
M<W!H<F%S92`H06=A:6XI`%!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A
M9&5D+@!087-S<&AR87-E.@!087-S<&AR87-E<R!C86YN;W0@8F4@96UP='D`
M4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H`%!A<W-W;W)D`%!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D
M`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S
M(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`
M4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R;6ES<VEO;G,@9F]R('1H
M:7,@=7-E<B!C86YN;W0@8F4@8VAA;F=E9"X`4&5R<V]N86P`4&5R<V]N86P@
M26YF;W)M871I;VX`4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2X`4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C97-S
M9G5L;'DN`%!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R
M=&5D.B``4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S9G5L
M;'DN`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I
M<FX`4&EX96QS`%!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S
M(&%N9"!F;W)W87)D<S\`4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G90!0
M;&%T:71U9&5S`%!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I
M<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D('-O=6YD(&9I
M;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O
M=&AE<B!P;&%T9F]R;7,@=VEL;"!R97%U:7)E(&$@<&QU9VEN+@!0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A(&YA;64@9F]R
M('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+@!0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD
M97(Z`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!E;G1E<B!T
M:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W
M:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P
M97(@)7,@<V5S<VEO;BX`4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O
M<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D
M('1O(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N
M+@!0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U
M<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R!C;V]K:65S($%.1"!Y
M;W4@87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y
M;W4@=VEL;"!H879E('1O(&QO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN
M9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2!H
M:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N
M>2!I;F-O;G9E;FEE;F-E+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64N`%!L96%S92!R96%D('1H92!F;VQL
M;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O
M('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@
M<WES=&5M+@!0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A
M9&1R97-S97,N`%!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA
M=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU
M(&)E;&]W+@!0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R
M9F]R;2!A;GD@86-T:6]N<RX`4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O
M<F4@>6]U('!E<F9O<FT@=&AI<R!A8W1I;VXN`%!L96%S92!S96QE8W0@86X@
M86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@870@
M;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N`%!L96%S92!S96QE8W0@;VYL
M>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BX`4&QE87-E('-E;&5C
M="!O<B!E9&ET(&EN('1H92!B;W@@=&\@=&AE(')I9VAT.@!0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL
M<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I`%!O<W1N=6ME`%!O=V5R960@8GD@2&]R9&4`4')E
M8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/P!0<F5C
M:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N
M/&)R("\^8VAA;F-E`%!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D
M+@!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``
M4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=P!0<F5V:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')E=FEO
M=7,@;W!T:6]N<P!0<FEN=`!0<FEN="!D;V-U;65N=`!0<FEO<FET>0!0<FEV
M871E($ME>0!0<FEV871E($ME>2!087-S=V]R9`!0<F]B;&5M`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T(&5V97)Y('1I;64@86X@871T
M86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/`%!R;VUP="!E=F5R>2!T
M:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,`4')O
M;7!T('1E>'0`4')O=&]C;VPZ`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O
M<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R!01U`@:V5Y<V5R=F5R('-U
M<'!O<G0@:&%S(&)E96X@9&ES86)L960N`%!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U
M<E]G92!$96QE=&5D`%!U<F=E($1E;&5T960`4'5R9V4@1F]L9&5R*',I`%!U
M<F=E(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@;65S<V%G97,`4'5R9V4@;65S
M<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@
M;V8@9&%Y<RX`4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD
M97(_`%!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N`%!U
M<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+@!1871A<@!1=65R
M>0!1=6]T80!1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2D`475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5`!1=6]T82!S=&%T
M=7,Z($Y/($Q)34E4`%%U;W1I;F<@)68Z`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E
M`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O
M;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5B=6EL9"!&;VQD97(@5')E90!296-E
M:79E9"!/;@!296-E:79E9"!3:6YC90!296-E:79E9"!5;G1I;`!2961I<F5C
M7W0`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I<F5C="!T:&ES(&UE
M<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2961O97,@>6]U<B!L87-T(&%C
M=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2
M969R97-H($9O;&1E<B!6:65W<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G
M97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;&]A9"!6:65W`%)E
M;6%R:W,`4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M
M96UB97(@=&AE(&QA<W0@=FEE=P!296UO=&4@36%I;&)O>#H`4F5M;W1E(%-E
M<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E($9I96QD($9R;VT@4V5A
M<F-H`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E(&9R
M;VT@;7D@8V%L96YD87(`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!S
M;W5R8V4`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!296YA;64@1F]L
M9&5R*',I`%)E;F%M92!6:7)T=6%L($9O;&1E<@!296YA;64@<V5N="UM86EL
M(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_`%)E;F%M:6YG("(E<R(@
M=&\@(B5S(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M4F5P;%]Y('1O($QI<W0`4F5P;&%C92!W:71H.@!297!L>0!297!L>2!396YT
M+@!297!L>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!L>2!T;R!,:7-T`%)E
M<&QY('1O($QI<W0Z`%)E<&QY('1O(%]!;&P`4F5P;'D@=VET:"!.;W0@4W5P
M<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@
M,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BX`4F5P;'DM5&\`4F5P;'DM5&\Z(`!297!L>3H`4F5P;'DZ("5S
M`%)E<&]R="!A<R!);FYO8V5N=`!297!O<G0@87,@4W!A;0!297%U97-T(&$@
M7U)E860@4F5C96EP=`!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2
M971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T(')E860@<F5C96EP=',_`%)E
M<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"X`4F5Q=65S=&5D('-E<G9I8V4@
M8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`
M4F5Q=6ER960@4&%R=&EC:7!A;G0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S
M970@66]U<B!087-S=V]R9`!297-P;VYD96YT(%-T871U<R!5<&1A=&5D+@!2
M97-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!297-U;64`4F5S=6UE('EO=7(@
M<V5S<VEO;@!2971U<FX@=&\@(DUE<W-A9V4@0V]M<&]S:71I;VXB`%)E='5R
M;B!T;R!&971C:"!-86EL`%)E='5R;B!T;R!/<'1I;VYS`%)E='5R;B!T;R!T
M:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R
M(&-O<'EI;F<@82!M97-S86=E/P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI
M;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2
M;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T
M871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P
M97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%`%,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP="!-
M97-S86=E`%,O34E-12!%;F-R>7!T960@365S<V%G90!3+TU)344@17)R;W(Z
M(`!3+TU)344@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@
M<')I=F%T92!K97DN`%,O34E-12!/<'1I;VYS`%,O34E-12!087-S<&AR87-E
M($EN<'5T`%,O34E-12!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER
M97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%,O34E-12!0=6)L:6,@2V5Y
M(&9O<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"X`4R]-24U%(%!U
M8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!3+TU)344@4'5B;&EC($ME
M>7)I;F<`4R]-24U%(%!U8FQI8R]0<FEV871E($ME>7!A:7(@<W5C8V5S<V9U
M;&QY(&%D9&5D+@!3+TU)344@4VEG;B!-97-S86=E`%,O34E-12!3:6=N+T5N
M8W)Y<'0@365S<V%G90!3+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T
M:&ES('-Y<W1E;2X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E
M;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T
M960N`%,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT
M96YT<R!O9B!T:&ES('-I9VYE9"!M97-S86=E(&-A;FYO="!B92!D:7-P;&%Y
M960N`%,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I
M=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@=F5R:69I960N`%,O34E-
M12!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@
M($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@
M<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O
M<B!E;'-E('1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R
M96-T;'DN`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`
M4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L
M=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-?=6)J96-T`%-A
M`%-A7W9E(&$@8V]P>2!I;B``4V%?=F4@87,`4V%I;G0@2&5L96YA`%-A:6YT
M($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD
M($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A
M;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N
M9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A
M=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!!='1A8VAM96YT<R!W:71H(&UE
M<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\`4V%V92!$<F%F=`!3879E($EM
M86=E`%-A=F4@26UA9V4@:6X@1V%L;&5R>0!3879E($]P=&EO;G,`4V%V92!3
M=&%T:6]N97)Y`%-A=F4@7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@87,@
M=6YS965N/P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT
M(&%D9')E<W,@8F]O:S\`4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E
M<C\`4V%V92!S96YT(&UA:6P_`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A
M=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!3879I;F<@=&AE
M(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M)7,`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"`E
M<P!396%R8V@@16YG:6YE<P!396%R8V@@3W!T:6]N<P!396%R8V@@4F5S=6QT
M<P!3965N`%-E;&5C=`!396QE8W0@06YO=&AE<B!!8V-O=6YT`%-E;&5C="!&
M:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A(&=R
M;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R
M`%-E;&5C="!A('-T871I;VYE<GDZ`%-E;&5C="!A('5S97(@=&\@861D`%-E
M;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R
M8VAI;F<@9F]R(&%D9')E<W-E<RX`4V5L96-T(&%L;`!396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RX`4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H
M96X@97AP86YD:6YG(&%D9')E<W-E<RX`4V5L96-T(&%N(&%C8V]U;G0`4V5L
M96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+@!3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T
M('1H92!M86EL('-E<G9E<B!T>7!E`%-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5L96-T960@061D<F5S<R!B;V]K
M<SH`4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<@!396YD($QA=&5S="!)
M;F9O<FUA=&EO;@!396YD($UE<W-A9V4`4V5N9"!0<F]B;&5M(%)E<&]R=`!3
M96YD(%--4P!396YD(')E860@<F5C96EP="!W:&5N(')E<75E<W1E9"!B>2!T
M:&4@<V5N9&5R/P!396YE9V%L`%-E;G-O<CH@`%-E;G0@;6%I;"!F;VQD97(`
M4V5N="!M86EL(&9O;&1E<CH`4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N
M96=R;P!397)I86P@3G5M8F5R`%-E<G9E<@!397)V97(@86YD($9O;&1E<B!)
M;F9O<FUA=&EO;@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE
M+@!397)V97(Z`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!3
M97-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@<')E
M9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D
M96QE=&4@;65S<V%G97,N`%-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE
M;B!C;VUP;W-I;F<@;65S<V%G97,_`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I
M;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M`%-E>6-H96QL97,`4VAA<F4@1F]L9&5R<P!3:&%R92!M86EL(&9O;&1E<G,`
M4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RX`4VAO
M<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q
M=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@
M8V%N(&)E('1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+@!3
M:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N
M;F5D(&9O<B!01U`@9&%T83\`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B
M92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W5L9"!Y;W5R(%!'
M4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@
M8GD@9&5F875L=#\`4VAO=P!3:&]W($%L;"!&;VQD97)S`%-H;W<@06QL($AE
M861E<G,`4VAO=R!$96QE=&5D`%-H;W<@3&EM:71E9"!(96%D97)S`%-H;W<@
M36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N`%-H;W<@3VYL>2!3=6)S8W)I8F5D
M($9O;&1E<G,`4VAO=R!5;G-U8G-C<FEB960`4VAO=R!A;B!I8V]N('1O(&%L
M;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/P!3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E;F0@:6X@=&AE
M(&UA:6QB;W@@=FEE=S\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3
M:&]W('!I8VME<@!3:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@
M;VYL>3\`4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\`4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/P!3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_
M`%-H;W<@=&AE($EM86=E<P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!F
M:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@
M9F]L9&5R/P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO
M=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H;W=N`%-H<FEN
M:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0`4VE?>F4`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG
M;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEG;F5D`%-I;7!L97@`4VEN
M9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI
M80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@
M16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U
M:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O
M;F=S("8@4&]E;7,`4V]R="!B>2!!<G)I=F%L`%-O<G0@8GD@1&%T90!3;W)T
M(&)Y($9R;VT@061D<F5S<P!3;W)T(&)Y($UE<W-A9V4@4VEZ90!3;W)T(&)Y
M(%-U8FIE8W0`4V]R="!B>2!4:')E860`4V]R="!B>2!4;R!!9&1R97-S`%-O
M<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC
M80!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD
M<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P
M86T`4W!A;2!F;VQD97(Z`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P96-I
M86P@0VAA<F%C=&5R<P!3<&5C:6%L(%9I<G1U86P@1F]L9&5R<R!C86YN;W0@
M8F4@961I=&5D+@!3<&5L;"!#:&5C:P!3<&5L;"!#:&5C:V5R`%-P96QL(&-H
M96-K(&-O;7!L971E`%-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@
M<W!E;&P@8VAE8VMI;F<N`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET
M(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R
M=`!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871I;VYE<GD`4W1A
M=&EO;F5R>2!N86UE.@!3=&%T:6]N97)Y('1Y<&4Z`%-T871I;VYE<GDZ`%-T
M871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O
M=6=H`%-T<FEN9R!L:7-T`%-T<FEP($%T=&%C:&UE;G0`4W1R:7`@9&]M86EN
M(&9R;VT@=&AE(&%D9')E<W,`4W1R:7`@;&EN96)R96%K<S\`4W1Y;&4@6T-3
M4UT`4W4`4W5B7VIE8W0`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3
M=6)J96-T`%-U8FIE8W0@1FEE;&0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN
M('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R
M:6)E('1O($9O;&1E<BAS*0!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M9&%N`%-U9V=E<W1I;VYS`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN
M>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N
M<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V
M86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET8V@@
M0V]M<&]S:71I;VX@365T:&]D`%-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N
M`%-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N`%-W:71Z97)L86YD
M`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M
M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!4
M86)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T
M:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T
M86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS
M`%1E7WAT`%1E86P`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO
M=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R
M("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@
M9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E;G1A=&EV93H@`%1E
M;G1A=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D
M`%1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N
M<&AP`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I
M("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S
M>7-T96TN`%1H92`E<R!L:6YK('1O("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!&<F]M.B!C
M;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#H`5&AE($AI
M<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U!
M4"!S97)V97(@9&]E<R!N;W0@87!P96%R('1O('-U<'!O<G0@=&AE(&%U=&AE
M;G1I8V%T:6]N(&UE=&AO9"!S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@>6]U
M<B!S>7-T96T@861M:6YI<W1R871O<BX`5&AE($E-4U`@;&]G(&-O=6QD(&YO
M="!B92!I;FET:6%L:7IE9"X`5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K
M`%1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E
M9"`E<RX`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U
M8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI
M=&EN9RX`5&AE(&%C8V]U;G0@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M86-C;W5N="`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!A
M='1A8VAM96YT('=A<R!N;W0@9F]U;F0N`%1H92!B;W1T;VT@<VED92!O;FQY
M`%1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;7!O<V4@=VEN
M9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U
M<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE
M(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N`%1H
M92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I;&P@8F4@<F5N86UE9"!T;R`B
M)7,B+@!4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O
M('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960`5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N`%1H92!D<F%F="!H87,@8F5E;B!S879E9"!T
M;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E=F5N="!H87,@
M8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+@!4:&4@979E;G0@=V%S(&%D
M9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F:65L9"`B)7,B(&-A;B=T(&)E
M(&5X<&%N9&5D+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF
M+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&1E<B`B)7,B(&%L<F5A
M9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!C;VYT86EN<R!I;&QE9V%L(&-H
M87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S92!P<F]B;&5M<RX@
M4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4:&4@9F]L
M9&5R("(E<R(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I
M8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S(&1E;&5T960@8G5T('EO
M=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="X`5&AE(&9O;&1E<B`B
M)7,B('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED`%1H92!F;VQD97(@(B5S(B!W87,@<W5C
M8V5S<V9U;&QY(&-R96%T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S
M<V9U;&QY(&1E;&5T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U
M;&QY(')E;F%M960@=&\@(B5S(BX`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9O
M;&QO=VEN9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R=#H`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&EM86=E('-A
M=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E
M('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\`5&AE
M(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@
M:7,@<')E<V5N="!I;B!Y;W5R(&%D9')E<W-B;V]K+@!4:&4@;&5F="UH86YD
M('-I9&4@;VYL>0!4:&4@;&EN:R!H87,@8F5E;B!R96UO=F5D`%1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D
M('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93H`5&AE(&UA:6P@<V5R=F5R
M(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S<V%G
M93H`5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE
M<W-A9V4Z`%1H92!M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN`%1H92!M
M97-S86=E("(E<R(@9G)O;2`B)7,B("@E9"!B>71E<RD@97AC965D<R!F971C
M:"!S:7IE(&QI;6ET+@!4:&4@;65S<V%G92!B96EN9R!C;VUP;W-E9"!H87,@
M8F5E;B!C;&]S960N($5X:71I;F<N`%1H92!M97-S86=E(&1O97,@;F]T(&AA
M=F4@82!3=6)J96-T(&5N=&5R960N`%1H92!M97-S86=E(&AA<R!B965N(&1E
M;&5T960N`%1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+@!4:&4@;65S
M<V%G92!H87,@8F5E;B!V97)I9FEE9"X@4V5N9&5R.B`E<RX`5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E
M;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+@!4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D
M+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@
M<&]P=7`@=VEN9&]W<S\`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE(')A=R!T97AT(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@
M8F4@=FEE=V5D("5S+@!4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI
M<W0@:6X@=&AE($U3+51.148@871T86-H;65N="X`5&AE(')E<75E<W1E9"!F
M:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H;65N="X`5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY`%1H92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I
M;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B!F<F]M('EO
M=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI
M8VL@)7,@=&\@<V5N9"!T:&4@;F]T:69I8V%T:6]N(&UE<W-A9V4N`%1H92!S
M97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!S879E9"X`5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E
M871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N`%1H92!S:6=N871U<F4@
M8V]U;&0@;F]T(&)E(')E<&QA8V5D+@!4:&4@<VEG;F%T=7)E('=A<R!S=6-C
M97-S9G5L;'D@<F5P;&%C960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T
M(&5X:7-T+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T
M+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('-T871I
M;VYE<GD@(B5S(B!H87,@8F5E;B!A9&1E9"X`5&AE('-T871I;VYE<GD@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B
M965N('5P9&%T960N`%1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@
M=&%S:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@
M;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T:&4@<F5T
M=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G
M92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S
M86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E
M9"`E<RX`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@
M=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!N
M;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N`%1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T
M97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C
M=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!I<R!N
M;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E('=A
M<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@
M9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I
M;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W
M960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@8V]P>6EN9R!M97-S86=E<R!F
M<F]M("(E<R(@=&\@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@9G)O;2!T
M:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F
M;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA
M9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E
M;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M=&%S:SH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S
M(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@;6]V
M:6YG(&UE<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG
M('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H
M:7,@;65S<V%G92!A<R!A(&1R869T+@!4:&5R92!W87,@86X@97)R;W(@<V5N
M9&EN9R!Y;W5R(&UE<W-A9V4Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&YO
M('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0`5&AI<R!(5$U,(&UE<W-A9V4@
M:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X`5&AI<R!(5$U,(&UE<W-A9V4@
M:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P
M96%R(&QI:V4@=&AI<SH@`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@4$=0(%!U8FQI8R!+97D@=V%S
M(&%T=&%C:&5D('1O('1H92!M97-S86=E+@!4:&ES(&%C=&EO;B!I<R!N;W0@
M<W5P<&]R=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F
M:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N
M`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN
M=&]S:"!F:6QE+@!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N
M="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@
M8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A
M:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE
M(&9O<FUA="!O9B!T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BX`5&AI<R!M97-S
M86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T
M960@;65S<V%G92X@17)R;W(Z(`!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN
M9R!T;R!21D,@,C`Q-2DN`%1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="X`5&AI<R!M97-S
M86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"X`5&AI<R!M
M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12X`
M5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+@!4
M:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+@!4:&ES
M(&UE<W-A9V4@=&\`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA
M<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U
M;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@<WES=&5M(&ES
M(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M
M<&]S92!W:6YD;W<N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<`5&AR96%D($1I<W!L87D`5&AR96%D(%9I97<`
M5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O
M;'1I<"DZ`%1O`%1O($%D9')E<W,`5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!W:&EL92!C;&EC:VEN9RX`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2!W:&EL92!C;&EC:VEN9RX`5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO
M=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C$N,"!O<B!H
M:6=H97(N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`
M5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5&]T86P@071T
M86-H;65N=',@4VEZ93H`5')A;G-L871I;VYS`%1R87-H(&9O;&1E<@!4<F%S
M:"!F;VQD97(Z`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4
M=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO
M=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN
M90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A
M9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92`E<R\E<P!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E
M<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE
M8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O
M(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A
M<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F
M86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E
M860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R971R:65V92!Q=6]T
M80!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N86YS
M=V5R960`56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T90!5;F1E<FQI;F4`
M56YD:7-C;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`56YD;V5S('EO
M=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;R!!551(14Y424-!5$4@8V]M;6%N9"X`56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;R!$:6=E<W0M340U(')E<W!O;G-E+@!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($Q/1TE.(&-O;6UA;F0N
M`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D
M`%5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&
M+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E
M9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M`%5N:71S`%5N:VYO=VX`56YK;F]W;B!$871E`%5N:VYO=VX@24U!4"!R97-P
M;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S`%5N
M:VYO=VX@365E=&EN9P!5;FMN;W=N(%)E8VEP:65N=`!5;FMN;W=N(&%P:6US
M9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N
M="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK
M;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0`56YL;V%D(%!A<W-P:')A<V4`56YN86UE9`!5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O
M('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N`%5N<V5E;@!5;G-E="!C;VQO<@!5;G-U8G-C<FEB92!F<F]M
M($9O;&1E<BAS*0!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T
M92`E<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D
M871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L
M;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V
M97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5
M<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@
M24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\`57-E(%-33`!5<V4@5FER='5A
M;"!4<F%S:"!&;VQD97(_`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E
M<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`B)7,B('-U8V-E<W-F
M=6QL>2!G:79E;B!T:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E
M<B`B)7,B+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E
M<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I
M;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R
M;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L
M90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO
M;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R
M=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI
M`%9I97<`5FEE=R`E<P!6:65W("5S(%!U8FQI8R!+97D`5FEE=R!(5$U,(&-O
M;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<`5FEE=R!-97-S86=E<P!6:65W
M(%!E<G-O;F%L(%!R:79A=&4@2V5Y`%9I97<@4&5R<V]N86P@4'5B;&EC($ME
M>0!6:65W(%1H<F5A9`!6:65W(%1H=6UB;F%I;`!6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W`%9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O
M=P!6:65W(&5V96YT`%9I97<@;65S<V%G97,@:6X@)7,`5FEE=R!O<B!M86EL
M8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ`%9I97<@=&%S:P!6:65W('1H
M92!);6%G97,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N
M9',L(%4N4RX`5FER='5A;"!&;VQD97(@(B5S(B!C<F5A=&5D('-U8V-E<V9U
M;&QY+@!6:7)T=6%L($9O;&1E<G,`5FER='5A;"!&;VQD97)S(')E<75I<F4@
M82!L86)E;"X`5FER='5A;"!)3D)/6`!6:7)T=6%L($E.0D]8($9O;&1E<@!6
M:7)T=6%L(%1R87-H`%9I<G1U86P@5')A<V@@1F]L9&5R`%9I<G1U86P@9F]L
M9&5R(&QA8F5L`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N
M80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!796)B<&QA='-E
M;B`M(%-O8F5R`%=E8F)P;&%T<V5N("T@4V]B97(@3D57`%=E96ML>0!796QC
M;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X
M-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\`5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M
M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P
M86T@;W(@:6YN;V-E;G0_`%=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@
M=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@
M=&AE;2!A<R!D96QE=&5D/P!7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@
M=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\`5VAE;B!S879I
M;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_
M`%=H96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N9&EN9R!A9&1R97-S97,L('=H
M870@9&]M86EN('-H;W5L9"!W92!A<'!E;F0@=&\@=6YQ=6%L:69I960@861D
M<F5S<V5S("AE;6%I;"!A9&1R97-S97,@=VET:&]U="`B0"(I/P!7:&5R96ES
M($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VAI=&5L:7-T`%=I
M9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED
M=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7
M:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I
M<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@
M5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P
M.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE
M;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA
M:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ`%EO=2!A<F4@871T
M96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T
M:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!A='1E;7!T:6YG('1O
M(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!C;W!Y
M:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E871I;F<@
M82!S=6(M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L
M(&9O;&1E<BX`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+@!9;W4@
M87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@87)E(')E;F%M:6YG('1H92!F
M;VQD97(Z(`!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+@!9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L
M86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE
M(&-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R
M92X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+@!9;W4@8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@(B5S(BX`
M66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R
M965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"!T;R!L;V=I;BX`66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@
M9F]L9&5R`%EO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T
M:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+@!9;W4@:&%V92`E<R!N97<@
M;65S<V%G97,N`%EO=2!H879E(#$@;F5W(&UE<W-A9V4N`%EO=2!H879E(&%L
M<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92X`66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<CH`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD
M97)S.@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92X`66]U(&UA>2!O;FQY(&5D:70@,2!F;VQD97(@
M870@82!T:6UE+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K
M96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@
M8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N
M=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N`%EO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!E;G1E
M<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@
M=FEE=R!T:&ES(&UE<W-A9V4`66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A
M<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M
M97-S86=E`%EO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T
M+@!9;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+@!9
M;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="X`66]U(&UU<W0@<V5L
M96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S96QE8W0@
M870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N`%EO=2!M=7-T('-P96-I9GD@
M82!R96-I<&EE;G0N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C
M;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO
M=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@:&%V92`B)7,B
M(&5N86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+@!9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=2!R961I
M<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N`%EO=2!R97!L:65D
M('1O('1H:7,@;65S<V%G92!O;B`E<RX`66]U('=E<F4@;F]T('-U8G-C<FEB
M960@=&\@(B5S(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9`!9;W4@
M=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@(B5S(BX@2&5R92!I<R!W:&%T
M('1H92!S97)V97(@<V%I9`!9;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R
M:6)E9"!T;R`B)7,B`%EO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB
M960@9G)O;2`B)7,B`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@4$=0(%!U8FQI8R]0<FEV
M871E($ME>7,`66]U<B!0<FEV871E($ME>0!9;W5R(%!U8FQI8R!+97D`66]U
M<B!297!L>2UT;SH@861D<F5S<SH@/&5M/BAO<'1I;VYA;"D\+V5M/@!9;W5R
M(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,`66]U<B!A8V-O
M=6YT<SH`66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N
M=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U
M<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@
M=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`
M66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM
M86=E('1Y<&4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I
M;G0N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO;B`K(%`@=&\@<')I;G0N`%EO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!C:&%R<V5T(&9O
M<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M
M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z`%EO=7(@9&5F875L="!I9&5N
M=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QI;FME9"!A='1A8VAM96YT(&AA<R!B
M965N(&1O=VYL;V%D960@8GD@870@;&5A<W0@;VYE('5S97(N"@I!='1A8VAM
M96YT(&YA;64Z("5S"D%T=&%C:&UE;G0@9&%T93H@)7,*"D-L:6-K(&]N('1H
M92!F;VQL;W=I;F<@;&EN:R!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE(&%T
M=&%C:&UE;G0Z"B5S`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;65S
M<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"X`66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C
M:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R
M9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R
M=F5R<SH`66]U<B!S:6=N871U<F4Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA
M`%II;6)A8G=E`%II<'!Y`%M(:61E($%D9')E<W-E<UT`6TAI9&4@475O=&5D
M(%1E>'1=`%M.;R!3=6)J96-T70!;4')O8FQE;2!297!O<G1=`%M3:&]W($%D
M9')E<W-E<R`M`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UT`6U-H;W<@861D<F5S<V5S("T@)7,@<F5C:7!I96YT
M<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0F-C`%]";&%C
M:VQI<W0`7T-,20!?0V,`7T-O;7!O<V4`7T1A=&%4<F5E`%]$96QE=&4`7T1E
M;&5T92!2;W<`7T9O;&1E<G,`7T=R;W5P<P!?2&5L<`!?261E;G1I='D`7TEM
M86=E(%!R;W!E<G1I97,N+BX`7TEN8F]X`%],;V<@:6X`7TQO9R!O=70`7TUE
M<W-A9V4@4V]U<F-E`%]-;V1I9GD@3&EN:RXN+@!?3F5W($UE<W-A9V4`7T]P
M=&EO;G,`7U!E<FUI<W-I;VYS`%]0<FEN=`!?4')I;W)I='D`7U)E9G)E<V@@
M)7,`7U)E;6]V92!,:6YK+BXN`%]297!L>0!?4V5A<F-H`%]396YD($UE<W-A
M9V4`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]4:')E860`7U1O`%]5
M;F1E;&5T90!?57-E<G,`7U9I97<@5&AR96%D`%]7:&ET96QI<W0`861D<F5S
M<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&%T=&%C:&UE;G0`871T86-H;65N
M=',N>FEP`&)Y=&5S`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-L;V-K`&-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`
M961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U
M;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN
M=&5R;F%L('-O9G1W87)E(&5R<F]R`&ME>0!L:6YE<UT`;6%I;&)O>"!F:6QE
M`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N
M86UE`&YO;F4`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`
M;F]T97!A9`!O<@!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R
M96-I<&EE;G1S70!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E
M<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@
M=FEA($A45%``<W!E;&QI;F<@97)R;W(`<W!E;&QI;F<@97)R;W)S`'-S`'-T
M96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U
M;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`'EO=7(@
M8FQA8VML:7-T`'EO=7(@=VAI=&5L:7-T`%!R;VIE8W0M260M5F5R<VEO;CH@
M26UP(#0N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ-"`Q-3HS,"LP,3`P
M"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,30@,38Z,#`K,#$P,`I,87-T
M+51R86YS;&%T;W(Z($IO87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P
M;&%T<V5N+G-E/@I,86YG=6%G92U496%M.B!3=V5D:7-H(#QI,3AN0&QI<W1S
M+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L
M=7)A;#TH;B`A/2`Q*3L*`"`@("`@($-C.B``("`@(%1I;&PZ(``@("!$871U
M;3H@`"`@("!&<N5N.B``("8C,34Q.R`E<R!K;VUM97(@871T('5T9O9R82!D
M92!U;F1E<FCE;&QS86MT:79I=&5T97)N82!S;VT@;6%R:V5R871S(&YE9&%N
M+@`@*"5S(&1A9V%R('-E9&%N*0`@*'-N86)B=&%N9V5N="`E<RD`("A3:W)I
M=G-K>61D860I`"`H;VT@)7,@9&%G87(I`"`H:61A9RD`("AI;6]R9V]N*0`@
M*&EGY7(I`"`@Q')E;F1E.B``(&ML(``@:2``)R5S)R#D<B!I;G1E(&5N(&MA
M=&%L;V<N`"<E<R<@Y'(@:6YT92!E='0@9V]D:^1N="!V86PN`"<E<R<@Y'(@
M:6YT92!K;VYF:6=U<F5R870@:2!(;W)D97)E9VES=')E<G0N`%1RY&1H86YT
M97)A<F5N(&;V<B`E<R!S86MN87,N`"<E<R<@;&%D97,@=&EL;"!I(&=R=7!P
M<WES=&5M970N`"<E<R<@;&%D97,@=&EL;"!I(&)E:/9R:6=H971S<WES=&5M
M970N`"<E<R<@<VMA<&%D97,@:6YT93H@)7,N`",`)2XR9DU"("\@)2XR9DU"
M("`H)3)F)24I`"4N,F9-0B!A;G;D;G0@878@)2XR9DU"('1I;&SE=&5T("@E
M,F8E)2D`)60@)7,@;V-H("5S`"5D(&UE9&1E;&%N9&5N`$1I='0@;/9S96YO
M<F0@=7!P:/9R(&%T="!GY&QL82!O;2`E9"!D86=A<BX`)60@;65D9&5L86YD
M92AN*2!H87(@<F%D97)A=',N`"5D(&UE9&1E;&%N9&5N(&AA<B!R87!P;W)T
M97)A=',@<V]M($5*+7-K<N1P<&]S="!T:6QL(&1I;B!S>7-T96UA9&UI;FES
M=')A=/9R+@`E9"!M961D96QA;F1E;B!H87(@<F%P<&]R=&5R871S('-O;2!%
M2BUS:W+D<'!O<W0N`"5D(&UE9&1E;&%N9&5N(&AA<B!R87!P;W)T97)A=',@
M<V]M('-K<N1P<&]S="!T:6QL('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BX`)60@
M;65D9&5L86YD96X@:&%R(')A<'!O<G1E<F%T<R!S;VT@<VMRY'!P;W-T+@`E
M9"!T:6QL("5D(&%V("5D(&UE9&1E;&%N9&5N`"5D+61A9W-P<F]G;F]S`"5S
M("T@1O9R(&OD;FYE9&]M`$9I;F=E<G!R:6YT(&;V<B`E<P`E<R!+8@`E<R!5
M;F1E<FCE;&QS9G5N:W1I;VX@+2!"96MRY&9T96QS90`E<R!3971U<``E<R!A
M;FWD;&%N`%1JY&YS=&5A=G1A;"!F]G(@)7,`)7,@9FEN;G,@<F5D86XN`"5S
M(&9I;FYS(')E9&%N+B!.86UN970@<.4@;6%P<&5N("5S(.1N9')A9&5S(&EN
M=&4N`"5S(&ML("5S("5S`"5S('9E<FMA<B!I;G1E('9A<F$@96X@:V]R<F5K
M="!M87!P+@!-87!P96X@)7,@9N5R(&YY='0@;F%M;B!I(&+V<FIA;B!A=B!M
MY6YA9&5N+@`E<R!H87(@86-C97!T97)A="X`)7,@:&%R(&%N;G5L;&5R870@
M(B5S(BX`)7,@:&%R(&%N;G5L;&5R870@)7,N`"5S(&AA<B!A=F+V:G0N`"5S
M(&AA<B!S=F%R870@<.4@96X@8F5GY')A;B!O;2!I;F9O<FUA=&EO;B!A;F?E
M96YD92!L961I9R]U<'!T86=E;BX`)7,@:&%R('-V87)A="!PY2!I;F)J=61A
M;B!T:6QL("5S+@`E<R!H87(@<W9A<F%T('#E(&EN8FIU9&%N('1I;&P@)7,N
M`"5S(&AA<B!S:VEC:V%T(&1I9R!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T
M86=E;BX`)7,@:&%R(&%C8V5P=&5R870@<')E;&EM:6[D<G0N`"5S(&MO;6UE
M<B!A='0@=71F]G)A(&1E('5N9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M
M87)K97)A=',@;F5D86XN($UA<FME<F$@9&4@86MT:79I=&5T97(@<V]M(&1U
M('9I;&P@=71F]G)A+@`E<R!K<N1V<P`E<R!M:6YU=&5R`"5S('-A:VYA<RX`
M)7,@969T97)F<N5G87(@:6YF;W)M871I;VX@;VT@;N1R(&1U(.1R(&QE9&EG
M+W5P<'1A9V5N+@`E<R!E9G1E<F9RY6=A<B!D:6X@;N1R=F%R;R`E<RX`)7,@
M969T97)F<N5G87(@9&EN(&[D<G9A<F\@=FED("5S+@`E<R!T:6QL("5S(&%V
M("5S`"5S(&QA9&5S('1I;&P@)7,N`"5S('9I;&P@;.1G9V$@=&EL;"!T:6QL
M("5S+@`E<R!V:6QL(.1N9')A("5S+@`E<R!V:6QL(&?V<F$@9&EG(&UE9'9E
M=&5N(&]M("5S+@`E<R!V:6QL(&?V<F$@9&EG(&UE9'9E=&5N(&]M("5S+@`E
M<R!V:6QL(&5R:.5L;&$@9&5N('-E;F%S=&4@:6YF;W)M871I;VYE;B!O;2`E
M<RX`)7,@=FEL;"!E<FCE;&QA(&1E;B!S96YA<W1E(&EN9F]R;6%T:6]N96X@
M;VT@)7,N`$%D<F5S<V)O:R!F]G(@)7,`2V%L96YD97(@9O9R("5S`$%N=&5C
M:VYI;F=A<B!F]G(@)7,`57!P9VEF=&5R(&;V<B`E<P`E<SH@)7,`)7,Z("5S
M("@E9"9N8G-P.V%V)FYB<W`[)60I`"5S.B!-961D96QA;F1E="!K86YS:V4@
M:6YT92#D<B!F<N5N(&1E;B!S;VT@9&5T('9E<FMA<BX@5F%R(&;V<G-I:W1I
M9R!M960@871T(&;V;&IA(&SD;FMA<B!E;&QE<B!S:VEC:V$@879SY&YD87)E
M;B!P97)S;VYL:6<@:6YF;W)M871I;VXN`"A697)K<W3D;&P@Y&YD<FEN9V%R
M;F$@;V-H(&9O<G1SY'1T('1I;&P@;N1S=&$@<VOD<FTN*0`H5&$@8F]R="!A
M;&QA(.1N9')I;F=A<B!O8V@@Y71E<G;D;F0@=&EL;"!M961D96QA;F1E+BD`
M*$A434PI`"A497AT*0`HQ71E<G;D;F0@=&EL;"!M961D96QA;F1E(&5F=&5R
M('9E<FMS=.1L;&%N9&4@878@:&ET=&EL;',@9VIO<F1A(.1N9')I;F=A<BX@
MQ&YD<FEN9V%R('#E(&%K=&EV('-KY')M(&MO;6UE<B!)3E1%('9E<FMS=.1L
M;&%S+BD`*%-K:6-K82!M961D96QA;F1E(&5F=&5R('9E<FMS=.1L;&%N9&4@
M878@:&ET=&EL;',@9VIO<F1A(.1N9')I;F=A<BX@Q&YD<FEN9V%R('#E(&%K
M=&EV('-KY')M(&MO;6UE<B!)3E1%('9E<FMS=.1L;&%S+BD`*B!,Y&=G('1I
M;&P@9&5M(&CD<B!G96YO;2!A='0@:VQI8VMA($]+("H`*B!6Y&QJ(&%D<F5S
M<RAE<BD@*@`L('-T;W)M8GEA<@`L('-T;W)M8GEA<B`E<R`E<P`L('9A<FEE
M<F%N9&4@;65L;&%N("5S(&]C:"`E<P`M+2!VY&QJ("TM`$UE9&1E;&%N9&5T
M(&AA<B!R861E<F%T<RX`,2!M961D96QA;F1E(&AA<B!R87!P;W)T97)A=',@
M<V]M($5*+7-K<N1P<&]S="!T:6QL(&1I;B!S>7-T96UA9&UI;FES=')A=/9R
M+@`Q(&UE9&1E;&%N9&4@:&%R(')A<'!O<G1E<F%T<R!S;VT@14HM<VMRY'!P
M;W-T+@`Q(&UE9&1E;&%N9&4@:&%R(')A<'!O<G1E<F%T<R!S;VT@<VMRY'!P
M;W-T('1I;&P@9&EN('-Y<W1E;6%D;6EN:7-T<F%T]G(N`#$@;65D9&5L86YD
M92!H87(@<F%P<&]R=&5R871S('-O;2!S:W+D<'!O<W0N`#$P,"!T96-K96X`
M,3`P,"!T96-K96X`,3(M=&EM;6%R<V9O<FUA=``R-"UT:6UM87)S9F]R;6%T
M`#(T('1I;6UA<@`R-3`@=&5C:V5N`#4P,"!T96-K96X`/$;V<F5GY65N9&4`
M16X@9&%T86)A<VMO<'!L:6YG(&MRY'9S(&;V<B!A:W1U96QL="!B;&]C:RX`
M171T(&9A=&%L="!F96P@:&%R(&EN='+D9F9A=`!%;B!S=&]R(&)I;&0@*"5S
M*2#D<B!B:69O9V%D('1I;&P@;65D9&5L86YD970N`$1U(&AA<B!FY71T(&QE
M=F5R86YS8F5K<N1F=&5L<V4@<.4@971T(&UE9&1E;&%N9&4@9'4@<VMI8VMA
M="X`16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D=G,@9O9R(&%T="!K<GEP=&5R
M82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D=G,@
M9O9R(&%T="!V97)I9FEE<F$@971T('-I9VYE<F%T(&UE9&1E;&%N9&4N`$5N
M('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E;F]R9"!K
M<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N`$5N('!U
M8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E;F]R9"!K<N1V
M<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N9&4N`$5N('!U8FQI:R!O
M8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M="!L]G-E;F]R9"!K<N1V<R!F
M]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N`$5N('!U8FQI:R!O
M8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M="!L]G-E;F]R9"!K<N1V<R!F
M]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N9&4N`$5N('!U8FQI:R!3+TU)
M344M;GEC:V5L(&MRY'9S(&;V<B!A='0@:W)Y<'1E<F$@971T(&UE9&1E;&%N
M9&4N`$;V<FUI9&1A9W-M;VQN`$SD='0@9O9R;6ED9&%G<W)E9VX`1O9R;6ED
M9&%G<W)E9VX`1O9R;6ED9&%G<W-K=7)A<@!&]G)M:61D86=S<VMU<F%R(&UE
M9"!S;O8`04TO4$T`3T-(`$%022!)1`!/;2!E9&ET;W)N`$]M+BXN`$)O='1E
M;@!-:71T96X`06-C97!T97)A(&]C:"!LY&=G('1I;&P@;6EN(&MA;&5N9&5R
M`$%C8V5P=&5R82!B96?D<F%N`$%C8V5P=&5R860`06-C97!T97)A9#H@`$)E
M:/9R:6=H970@<V%K;F%S(&%T="!S:V%P82!61E,M;6%P<"X`0F5H]G)I9VAE
M="!S86MN87,@871T('-K87!A(%9&4RUF:6PN`$MO;E]T;VX`2V]N=&]I;F9O
M<FUA=&EO;@!,]G-E;F]R9"!F]G(@:V]N=&\`2V]N=&]T(&9R>7-T`$MO;G1O
M=',@;F%M;CH`0G5D9V5T`,5T9^1R9&5R`$SD9V<@=&EL;`!,Y&=G('1I;&P@
M)7,`3.1G9R!T:6QL("5S(&D@;6EN(&%D<F5S<V)O:P!,Y&=G('1I;&P@=6YD
M97)G<G5P<`!LY&=G('1I;&P@=6YD97)B96CV<FEG:&5T`$SD9V<@=&EL;"!H
MY'(Z`$SD9V<@=&EL;"!N>2!G<G5P<`!,Y&=G('1I;&P@;GD@8F5H]G)I9VAE
M=`!,Y&=G('1I;&P@=6YD97)G<G5P<"!T:6QL("<E<R<`3.1G9R!T:6QL('5N
M9&5R8F5H]G)I9VAE="!T:6QL("<E<R<`3.1G9R!T:6QL(&5N(&YY(&%N=N1N
M9&%R93H`3.1G9R!T:6QL(&MO;'5M;@!,Y&=G('1I;&P@;GEA(&UE9&QE;6UA
M<@!,Y&=G('1I;&P@<&%R`$SD9V<@=&EL;"!KY&QL80!,Y&=G('1I;&P@;65N
M>6X@9O9R("5S('-O;2!-;WII;&QA(%-I9&5B87(`3.1G9R!T:6QL(&D@;6EN
M(&MA;&5N9&5R`$SD9V<@=&EL;"!I(&%D<F5S<V)O:SH`3.1G9R!T:6QL(&D@
M;6EN(&%D<F5S<V)O:P!,Y&=G('1I;&P@:2!M:6X@:V%L96YD97(`3.1G9R!T
M:6QL(&%N=N1N9&%R90!,861E('1I;&P@)7,@<V]M(&5N(&)I;&%G82X`3&%D
M92!T:6QL("<E<R<@=&EL;"!S>7-T96UE="P@;65N(&MU;F1E(&EN=&4@;.1G
M9V$@=&EL;"!E>'1R82`@:6YF;W)M871I;VXZ("5S+@!,861E('1I;&P@)R5S
M)R!T:6QL('-Y<W1E;65T+B!$=2!K86X@;&]G9V$@:6X@;G4N`%5P<&SD9V<@
M878@86YVY&YD87)E(.1R(&EN86MT:79E<F%T+@!9='1E<FQI9V%R92!H=79U
M9')A9&5R(&%T="!V:7-A.B`\96T^*&5J(&]B;&EG871O<FES:W0L(&%N9V4@
M=F%R:F4@:'5V=61R860@<.4@96X@96=E;B!R860I/"]E;3X`671T97)L:6=A
M<F4@:6YF;W)M871I;VX@=FES87,@)7,N`$9L97(@9&5T86QJ97(`1FQE<B!D
M971A;&IE<B!O;2!M961D96QA;F1E=`!&;&5R(&1E=&%L:F5R(&]M(&UE9&1E
M;&%N9&5T('9I<V%S("5S+@!&;&5R(&9E;&UE9&1E;&%N9&4M9&5T86QJ97(`
M1FQE<B!F96QM961D96QA;F1E+61E=&%L:F5R('9I<V%S("5S+@!!9')E<W,`
M061R97-S8F]K`$%D<F5S<V+V8VME<@!!9')E<W-E<B!A='0@;.1G9V$@=&EL
M;"!S;VT@0D-#('1I;&P@86QL82!M961D96QA;F1E;CH@/&5M/BAE:B!O8FQI
M9V%T;W)I<VMT+"!S:W)I=B!V87)J92!A9')E<W,@<.4@96X@96=E;B!R860I
M/"]E;3X`061R97-S97(@:V]P<&QA9&4@=&EL;"!D96X@:.1R(&ED96YT:71E
M;CH@/&5M/BAE:B!O8FQI9V%T;W)I<VMT+"!S:W)I=B!V87)J92!A9')E<W,@
M<.4@96X@96=E;B!R860I/"]E;3X`061M:6YI<W1R871I;VX@+2!A;F=E(&)E
M:/9R:6=H970@9O9R(&%N9')A(&%N=N1N9&%R90!!9&UI;FES=')A=&EO;@!2
M96ML86T`069G86YI<W1A;@!!;&)A;FEE;@!!;&=E<FEE=`!!;&EA<P!*=7-T
M97)A`$IU<W1E<FEN9SH`06QL80!!;&QA(&%U=&5N=&ES97)A9&4@86YVY&YD
M87)E`$%L;&$@9W)U<'!E<@!!;&QA(&)E:/9R:6=H971E<@!!;&QA(&9Y<F$@
M<VED;W(`06QL82!M961D96QA;F1E;B!I(&;V;&IA;F1E(&UA<'`H87(I(&QA
M9&1A<R!N97(@=&EL;"!E;B!-0D]8+69I;#H`06QL82!M961D96QA;F1E;B!I
M(&1I;B`G)7,G+6UA<'`L(.1L9')E(.1N("5S(&1A9V%R(&MO;6UE<B!A='0@
M<F%D97)A<R!P97)M86YE;G0N`$%L;&$@;.1N:V%D92!B:6QA9V]R(.1L9')E
M(.1N("5S(&WE;F%D97(@:V]M;65R(&%T="!R861E<F%S+@!!;&QA(&UA<'!A
M<B!F]G(@<VMI8VMA9&4@;65D9&5L86YD96XL(.1L9')E(.1N("5S(&WE;F%D
M97(@:V]M;65R(&%T="!R861E<F%S+@!"96CV<FEG:&5T97(@=&EL;"!M87!P
M96X@)R5S)R!R861E<F%D97,@9O9R(&%N=N1N9&%R92`G)7,G+@!4:6QLY70@
M871T(&UA<'!A<B!S:V%P87,_`%1I;&SE="!A='0@9FEL=&5R+7)E9VQE<B!T
M:6QLY&UP87,@:2!A;&QA(&)R979LY61O<C\`5&EL;.5T(&9L97)A(&%D<F5S
M<V5R`%1I;&SE="!I;G-TY&QL;FEN9R!F]G(@<V]R=&5R860@;&ES=&$_`$9I
M;FYS(')E9&%N`$%L=&5R;F%T:78@24U34"UI;FQO9V=N:6YG`$%L=&5R;F%T
M:79T(&SV<V5N;W)D(&;V<B!)35-0`$%L=&5R;F%T:79T(&%N=N1N9&%R;F%M
M;B!F]G(@24U34`!!;'1E<FYA=&EV(&4M<&]S="!A9')E<W,`06QT97)N871I
M=B!M86QL`$%L=&5R;F%T:78@=&5X=#H`06QT97)N871I=F$@9&5L87(@9O9R
M(&1E;B!HY'(@9&5L96XZ`$%L;'1I9`!3<&%R82!A;&QT:60@8FEL86=O<@!!
M;65R:6MA;G-K82!386UO80!%='0@9F5L('5P<'-T;V0@;N1R(&)I;&%G86X@
M<VMU;&QE('1A<R!B;W)T.B!)34%0+7-E<G9E<FX@<W9A<F%D93H@`$5T="!F
M96P@=7!P<W1O9"!NY'(@;.1N:V5N("@E<RD@<VMU;&QE(&%N=N1N9&%S`$5T
M="!F96QA:W1I9W0@=N1R9&4@86YG879S+@!%='0@;VOD;G0@9F5L(&AA<B!I
M;G1RY&9F870`171T(&]KY&YT(&9E;"!U<'!S=&]D('9I9"!U<'!LY&=G;FEN
M9V5N(&%V('5P<&=I9G1E;BX`171T(&]KY&YT(&9E;"!U<'!S=&]D('9I9"!U
M<'!LY&=G;FEN9V5N(&%V('5P<&=I9G1E;BX`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM('!R;WAY`%-V87(`0F5S=F%R870`0F5S=F%R861E(&UE
M9&1E;&%N9&5N`$%N=&%R:W1I<P!!;G1I9W5A(&]C:"!"87)B=61A`$%P<&QI
M:V%T:6]N`$%P<&QI:V%T:6]N<VQI<W1A`$%P<&QI:V%T:6]N96X@Y'(@:VQA
M<BX`5F5R:W-TY&QL(&9I;'1E<@!697)K<W3D;&P@9FEL=&5R('#E("5S`%9E
M<FMS=.1L;"!F:6QT97)R96=L97(@=FED(&EN;&]G9VYI;F<_`%9E<FMS=.1L
M;"!F:6QT97)R96=L97(@;N1R(&EN:V]R9V5N('9I<V%S/P!697)K<W3D;&P@
M=&EL;"!U;F1E<G5T9&5L;FEN9V%R`$=O9&OD;FX`56YG96;D<FQI9R!S=&]R
M;&5K`&%P<FEL`$%R86)I<VL@*%=I;F1O=W,M,3(U-BD`07)K:79F:6QS=&]R
M;&5K`$%R:VEV9FEL;F%M;@#$<B!D=2!SY&ME<B!A='0@9'4@=FEL;"!R861E
M<F$@86MT=65L;"!V:7)T=65L;"!M87!P/P#$<B!D=2!SY&ME<B!A='0@9'4@
M=FEL;"!R861E<F$@9&5N('!U8FQI:V$@;GEC:V5L;C\`Q'(@9'4@<^1K97(@
M871T(&1U('9I;&P@<F%D97)A(&YY8VME;'!A<F5T/R`H4F5K;VUM96YD97)A
M<R!)3E1%(2D`Q'(@9'4@<^1K97(_`,1R(&1E="!SY&ME<G0@871T(&1U('9I
M;&P@=&$@8F]R="!B96?D<F%N(&;V<B`E<S\`Q'(@9'4@<^1K97(@<.4@871T
M(&1U('9I;&P@<F%D97)A(&1E<W-A(&UE9&1E;&%N9&5N(%!%4DU!3D5.5#\`
MQ'(@9'4@<^1K97(@<.4@871T(&1U('9I;&P@<F%D97)A(&)I;&%G86X@4$52
M34%.14Y4/P#$<B!D970@<^1K97)T(&%T="!D=2!V:6QL(')A9&5R82`G)7,G
M(&]C:"!E=F5N='5E;&QA('5N9&5R9W)U<'!E<C\`Q'(@9'4@<^1K97(@<.4@
M871T(&1U('9I;&P@=/9M;6$@;6%P<&5N/P#$<B!D=2!SY&ME<B!PY2!A='0@
M9'4@=FEL;"!T]FUM82!D:6X@;6%P<"!F]G(@<VMRY'!P;W-T/P#$<B!D=2!S
MY&ME<B!PY2!A='0@9'4@=FEL;"!T]FUM82!D:6X@<&%P<&5R<VMO<F<_`,1R
M(&1U('/D:V5R('#E(&%T="!D=2!V:6QL(')A9&5R82!D97-S82!M961D96QA
M;F1E;B!015)-04Y%3E0_`,1R(&1U('/D:V5R('#E(&%T="!D=2!V:6QL(')A
M<'!O<G1E<F$@;65D9&5L86YD970@<V]M(&]S:WEL9&EG=#\`Q'(@9'4@<^1K
M97(@<.4@871T(&1U('9I;&P@<F%P<&]R=&5R82!M961D96QA;F1E="!S;VT@
M<VMRY'!P;W-T/P!!<F=E;G1I;F$`07)M86YI96X`07)M96YI<VL@*$%235-#
M24DM."D`06YK;VUS='1I9`!+;VYS=`!!<G5B80!3=&EG86YD90!!<V-E;G-I
M;VX@27-L86YD`$%S8VEI(&MO;G-T`$%S:65N+U-T:6QL82!H879S<F5G:6]N
M96X`1G+E9V$`1G+E9V$@969T97(@8F5K<N1F=&5L<V4@:6YN86X@=6YD97)H
MY6QL<V%K=&EV:71E=&5R('5T9O9R<S\`5&EL;&1E;&YI;F=S:V]L=6UN`$)I
M9F]G82!F:6QE<@!":69O9V$@96X@:V]P:6$@878@9&EN('!U8FQI:V$@4$=0
M+6YY8VME;"!T:6QL(&UE9&1E;&%N9&5T/P!":69O9V%D(&9I;#H`0FEF;V=A
M9"!F:6P@(B5S(B#V=F5R<VMR:61E<B!M87AS=&]R;&5K(&;V<B!B:6QA9V]R
M+B!&:6QE;B!H87(@96H@8FEF;V=A=',N`$)I9F]G87(@<W9A<B!PY2!K86QE
M;F1E<BUF]G)F<N5G86X@9'4@<VMI8VMA9&4N`$)I9F]G860@Y'(@96X@:4-A
M;&5N9&5R(&9I;"!M960@971T('-V87(@<.4@96X@8F5GY')A;B!S;VT@9'4@
M<VMI8VMA="P`0FEL86=A`$)I9F]G861E(&9I;&5N("5S(')A9&5R861E<RX`
M0FEL86=E:6YF;W)M871I;VX`0FEL86=A(&)O<G1T86=E;CH@5'EP('#E('5R
M<W!R=6YG<V)I;&%G86X`0FEL86=O<@!&]G)S]FL@=&EL;"!A='0@<F%D97)A
M(&5N(&=R=7!P('-O;2!I;G1E(&9I;FYS+@!&]G)S]FL@=&EL;"!A='0@<F%D
M97)A(&5N(&)E:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N`$;V<G/V:R!A='0@
MY&YD<F$@96X@8F5H]G)I9VAE="!S;VT@:6YT92!F:6YN<RX`1O9R<_9K(&%T
M="#D;F1R82!E;B!U=&1E;&YI;F<@<V]M(&EN=&4@9FEN;G,N`$1E;'1A9V%R
M90!/8G-E<G9E<F$`071T<FEB=70`875G=7-T:0!!=7-T<F%L:65N`-9S=&5R
M<FEK90!!=71H7V-Y<G-Q;#H@24U!4"UE>'1E;G-I;VX@<V%K;F%S+@!!=71H
M7V-Y<G-Q;#H@2V]P<&QI;F=E;B!S86MN87(@9G5N:W1I;VYE<B!S;VT@:W+D
M=G,N`$%U=&A?8WER=7,Z($E-05`M97AT96YS:6]N('-A:VYA<RX`075T:%]F
M='`Z($944"UT:6QLY&=G('-A:VYA<RX@2V]M<&EL97)A(%!(4"!M960@<W=I
M=&-H96X@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z($E-05`M97AT96YS:6]N
M('-A:VYA<RX`075T:%]I;7`Z($MA;B!I;G1E(&AI='1A(&1E;B!N]F1VY&YD
M:6=A($E-05`M=73V:VYI;F=E;BX`075T:%]K<F(U.B!K<F(U+65X=&5N<VEO
M;B!S86MN87,N`$%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!LY&=G82!T
M:6QL(&%N=N1N9&%R92!I($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!$
M970@9^5R(&EN=&4@871T(')A9&5R82!A;G;D;F1A<F4@9G+E;B!!8W1I=F4@
M1&ER96-T;W)Y`$%U=&A?;&1A<#H@3$1!4"UT:6QLY&=G('-A:VYA<RX`075T
M:%]L9&%P.B!+86X@:6YT92!LY&=G82!T:6QL(&%N=N1N9&%R92`G)7,G+B!3
M97)V97)N('-V87)A9&4Z(`!!=71H7VQD87`Z($MA;B!I;G1E(')A9&5R82!A
M;G;D;F1A<F4@)7,`075T:%]L9&%P.B!+86X@:6YT92!U<'!D871E<F$@86YV
MY&YD87)E("5S`$%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!U<'!D871E
M<F$@86YVY&YD87)E(&D@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!-
M0T%,+65X=&5N<VEO;B!S86MN87,N`$%U=&A?<VUB875T:#H@<VUB875T:"UE
M>'1E;G-I;VX@<V%K;F%S+@!!=71E;G1I<V5R:6YG('1I;&P@24U!4"US97)V
M97(@;6ES<VQY8VMA9&5S+@!!=71E;G1I<V5R:6YG(&UI<W-L>6-K861E<P!!
M=71E;G1I<V5R:6YG(&UI<W-L>6-K861E<RX@)7,`075T96YT:7-E<FEN9R!A
M=G9I<V%D97,@878@4D%$2553+7-E<G9E<FXN`$%U=&5N=&ES97)I;F<@=&EL
M;"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RX`075T96YT:7-E<FEN9R!T:6QL
M(%--0BUS97)V97(@;6ES<VQY8VMA9&5S+@!6:7-A(&)I;&1E<B!I($A434PM
M;65D9&5L86YD96X@875T;VUA=&ES:W0@;N1R(&%V<^1N9&%R96X@9FEN;G,@
M:0IA9')E<W-B;VME;C\`5&EL;&?D;F=L:6=A(&%D<F5S<V+V8VME<CH`5&EL
M;&?D;F=L:6=A(&;D;'0Z`%;D;G1A<B!PY2!S=F%R`$%Z97)B86EJ86X`07IU
M<F)LY0!"3T9(+75R<^1K=&5R`%1I;&QB85]K82!T:6QL("5S`%1I;&QB86MA
M('1I;&P@)7,`Q71E<G;D;F0@=&EL;"!M961D96QA;F1E=FES;FEN9V5N`%1I
M;&QB86MA('1I;&P@='+E9'9I<VYI;F<`0F%K9W)U;F0`0F%K9W)U;F1S9N1R
M9P!&96QA:W1I9W0@;/9S96YO<F0@9O9R($ME<F)E<F]S`$9E;&%K=&EG="!A
M;G;D;F1A<FYA;6X@9O9R($ME<F)E<F]S`$]G:6QT:6=T(&%N=N1N9&%R;F%M
M;B!E;&QE<B!L]G-E;F]R9"X`3V=I;'1I9R!F]G)F<N5G86XN(%-E<G9E<FX@
M<W9A<F%D93H@)7,`1F5L86MT:6<@8F5GY')A;CH@)7,N`$)A:&%M87,`0F%H
M<F%I;@!"86QT:7-K("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)T:60`
M4F%D=&ED`$)A<F)A9&]S`$)A<F)I90!"87-K871A;&]G("<E<R<@9O9R(&)I
M;&1E<B!H:71T861E<R!I;G1E+@!"87-L:6YJ90!"8V,`5FET<GES<VQA;F0`
M0F5L9VEE;@!"96QI>F4`3F5D86X@9FEN;G,@=7)S<')U;F=S=&5X=&5N(&9R
MY6X@<W1A='5S;65D9&5L86YD970N`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$;V
M9&5L<V5D86<`4W#D<G)A(&%D<F5S<P!";&]C:R`G)7,G(&;V<B!A<'!L:6MA
M=&EO;B`G)7,G('-A:VYA<RX`0FQO8VMI;G-TY&QL;FEN9V%R`$)L;V-K='EP
M`$)L;V-K97)A(&)I;&1E<B!I($A434PM;65D9&5L86YD96X@;VT@9&4@:6YT
M92!SY')S:VEL="!E9G1E<F9RY6=A<S\`0FSE(&WE;F4`0FSE='0@;V-H('9I
M='0`365D9&5L86YD971E>'0`1F5T`$)O;&EV:6$`0F]K;>1R:V5N`%)A;0!2
M86UB<F5D9#H`4F%M87(`0F]S;FEE;B!O8V@@2&5R>F5G;W9I;F$`0N5D80!"
MY61E(&D@:'5V=61E="!O8V@@:2!M961D96QA;F1E=`!";W1S=V%N80!";W1T
M96X`0F]U=F5T($ES;&%N9`!"<F%S:6QI96X`0G)I='1I<VMA('1E<G)I=&]R
M:65T(&D@26YD:7-K82!O8V5A;F5N`$)R=6X`0G)U;F5I`$)U;&=A<FEE;@!0
M=6YK=&QI<W1A`$)U<FMI;F$@1F%S;P!"<N1N9"!/<F%N9V4`0G5R=6YD:0!#
M35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(&EN<W3D;&QN
M:6YG87(N+BX`5%]E8VME;FMO9&YI;F<`0V%C:&5I;FET:65R:6YG(.1R(&EN
M=&4@9G5L;'-TY&YD:6<N`$MA;&5N9&5R`$QU9VYT`$MA;6)O9&IA`$MA;65R
M=6X`2V%M;W5F;&%G90!+86X@:6YT92!K;VYT86MT82!E+7!O<W1S97)V97)N
M`$MA;B!I;G1E(&MO;G1A:W1A(&4M<&]S='-E<G9E<FXZ(`!+86X@:6YT92!V
M:7-A("T@:&ET=&%D92!B87)A("5S(&%V("5S(&1E;&%R(&%V(&UE9&1E;&%N
M9&5T(&D@86MT=65L;"!B<F5V;.5D82X`2V%N(&EN=&4@;F]L;'-TY&QL82!L
M]G-E;F]R9"!A=71O;6%T:7-K="P@:V]N=&%K=&$@9&EN(&%D;6EN:7-T<F%T
M]G(N`$MA;B!I;G1E('-K<FEV82!T:6QL(&9I;"`G)7,G`$1E="!GY7(@:6YT
M92!A='0@861M:6YI<W1R97)A(&5X=&5R;F$@<V5S<VEO;G-H86YT97)A<F4N
M`$MA;B!I;G1E(&MO;G1A:W1A($E-05`M<V5R=F5R;CH@)7,`2V%N(&EN=&4@
M]G!P;F$@9FEL("<E<R<`2V%N861A`$%V8G)Y=`!!=F)R>70`079B<GET('!R
M;V)L96UR87!P;W)T`$]M(&1U(&%V8G)Y=&5R(&;V<G-V:6YN97(@86QL="!I
M(&UE9&1E;&%N9&5T+@!+86X@:6YT92!R861E<F$@)R5S)RX`2V%N(&EN=&4@
M:&ET=&$@96X@=&5M<'+D<B!M87!P+@!+86X@:6YT92!F;W)T<^1T=&$@=71A
M;B`G;>5L9FEL)RUP87)A;65T97(N`$MA;B!I;G1E(')A9&5R82!M87!P("<E
M<R<N`$MA;B!I;G1E(')A9&5R83L@)60@8F%R;B!E>&ES=&5R87(N`$MA;B!I
M;G1E(&1I<FEG97)A(&UE9&1E;&%N9&4@=&EL;"!A;F=I=F5T(&YU;6UE<BX`
M2V%P(%9E<F1E`%)U8G)I:P!/<&5R873V<@!+871E9V]R:65R(&]C:"!R=6)R
M:6ME<@!#87EM86X@27-L86YD<P!#8P!-;V)I;'1E;&5F;VX`0V5L;&EN<W3D
M;&QN:6YG87(`0V5L;'5T9GEL;&YA9#H`0V5L;&EN<W3D;&QN:6YG87(`0V5L
M;&UE;&QA;G)U;3H`36]B:6QT96QE9F]N`$-E;'1I<VL@*$E33RTX.#4Y+3$T
M*0!#96YT<F5R860`0V5N=')A;&%F<FEK86YS:V$@<F5P=6)L:6ME;@!#96YT
M<F%L975R;W!E:7-K("A)4T\M.#@U.2TR*0!#97)T:69I:V%T9&5T86QJ97(`
M0V5R=&EF:6MA=.1G87)E`$-E<G1I9FEK871P;VQI8VEE<P!#97)T:69I:V%T
M:6UP;W)T(.1R(&EN=&4@=&EL;&?D;F=L:6=T+B!5<'!L861D;FEN9R!A=B!F
M:6QE<B#D<B!I;G1E(&%K=&EV97)A="!PY2!S97)V97)N+@!48VAA9`!/<F1F
M]G)A;F1E`,1N9')A`,1N9')A(&%L;&$`Q&YD<F$@;6%P<`#$;F1R82!D:71T
M(&SV<V5N;W)D`,1N9')A(&;V<G9A;&0@:61E;G1I=&5T`,1N9')A(&EN<W3D
M;&QN:6YG87(@9O9R('9I<VYI;F<@878@86YT86P@;65D9&5L86YD96X@;V-H
M('-O<G1E<FEN9RX`Q&YD<F$@:6YS=.1L;&YI;F=A<B!F]G(@92UP;W-T<V5R
M=F5R(&]C:"!M87!P87(N`,1N9')A(&YA;6X@;V-H(&%D<F5S<R!S;VT@;6]T
M=&%G87)N82!S97(@;N1R(&1E(&SD<V5R(&]C:"!S=F%R87(@<.4@9&EN82!M
M961D96QA;F1E;BX`Q&YD<F$@;F%M;BP@861R97-S(&]C:"!S:6=N871U<B!S
M;VT@;6]T=&%G87)N82!S97(@;N1R(&1E(&SD<V5R(&]C:"!S=F%R87(@<.4@
M9&EN(&UE9&1E;&%N9&5N+@!!='0@8GET82!L]G-E;F]R9"!S=/9D<R!I;G1E
M(&UE9"!D96X@;G5V87)A;F1E(&MO;F9I9W5R871I;VYE;BX@(%9A<B!G;V0@
M:V]N=&%K=&$@861M:6YI<W1R873V<F5N+@!4:VX`06YT86P@=&5C:V5N(&%T
M="!V:7-A.@!+;VYT<F]L;&5R82!LY&YK+BXN`$MO;G1R;VQL97)A(&UA<'`H
M87(I(&;V<B!N>6$@;65D9&5L86YD96X`36%R:V5R82!?06QL82]);F=E;@!+
M<GES<V$@9O9R(&%L;&$@92UP;W-T<V5R=G)A<B!D=2!V:6QL(&CD;71A('!O
M<W0@9G+E;CH`2V]N=')O;&QE<F$@<W1A=FYI;F<@:6YN86X@;65D9&5L86YD
M92!S:VEC:V%S/P!-87)K97)A(&1E(&%K=&EV:71E=&5R(&1U('9I;&P@=71F
M]G)A(&YU+@!#:&EL90!+:6YA`$MI;F5S:7-K="!F]G)E;FML870@*$=",C,Q
M,BD`2VEN97-I<VMT('1R861I=&EO;F5L;'0@*$)I9S4I`%;D;&H@Y71GY')D
M.@!6Y&QJ(&%P<&QI:V%T:6]N.@!6Y&QJ(&5N(&4M<&]S='-E<G9E<CH`5N1L
M:B!E;&QE<B#D;F1R82!A9')E<W-E;B!I(')U=&%N('1I;&P@:/9G97(Z`%;D
M;&H@;/9S96YO<F0`5N1L:B!A;G;D;F1A<FYA;6X`5N1L:B#E=&?D<F0Z`%;D
M;&H@:'5R(&1A='5M('-K86QL('9I<V%S.@!6Y&QJ(&QI<W1S=&EL("AF]G(@
M<V]R=&5R861E(&QI<W1O<BD`5N1L:B!A9')E<W-B;VL@9.1R(&YY82!A9')E
M<W-E<B!LY&=G<R!T:6QL+@!6Y&QJ(&]R9&YI;F<@<V]M(&%D<F5S<V+V8VME
M<B!G96YO;7/V:W,@=FED(&5X<&%N<VEO;B!A=B!A9')E<W-E<BX`2G5L]FX`
M2VQA<W-D969I;FET:6]N(&;V<B`E<R!S86MN87,N`%)E;G-A`%)E;G-A($U3
M3V9F:6-E+71A9V=A<@!296YS82!F<N5G80!296YS82!A;G;D;F1A<F4Z("5S
M`%)E;G-A(&%N=N1D;F%R90!296YS82!A;G;D;F1A<F1A=&$`4V5N87)E('5P
M<&ML87)N86YD90!+;&EC:V$@)7,@9O9R(&%T="!K;VYV97)T97)A(&)I;&1E
M;B!T:6QL(&5T="!F;W)M870@9&EN('=E8F)LY'-A<F4@:V%N"G9I<V$N`$ML
M:6-K82`E<R!F]G(@871T(&QA9&1A(&YE<B!B:6QD96XN`$ML:6-K82`E<R!F
M]G(@871T(&?E('1I;&P@)7,M:&%N=&5R:6YG<W-I9&%N+@!+;&EC:V$@)7,@
M9O9R(&%T="!V:7-A($A434PM:6YN96CE;&P@:2!E='0@96=E="!F]FYS=&5R
M+@!+;&EC:V$@)7,@9O9R(&%T="!V:7-A(&5N(&UI;FEA='ER(&%V(&1E;B!H
MY'(@8FEL9&5N+@!+;&EC:V$@)7,@9O9R(&%T="!V:7-A(&)I;&%G86X@:2!E
M='0@96=E="!F]FYS=&5R+@!+;&EC:V$@)7,@9O9R(&%T="!V:7-A(&UU;'1I
M<&%R="]R96QA=&5D(&D@971T(&5G970@9O9N<W1E<BX`2VQI8VMA(&CD<B!F
M]G(@871T(%9)4T$@8FEL9&5R;F$`2VQI8VMA('#E(&5N(&%V(&1I;F$@861R
M97-S8O9C:V5R(&]C:"!A;F=E('-E9&%N('9I;&MA(&;D;'0@<V]M('-K86QL
M(&=E;F]M<_9K87,N`$ML:6-K82!F]G(@871T(&9O<G1SY'1T80!+;&EC:V$@
M9O9R82!A='0@<W!A<F$@<'5B;&EK(%!'4"UN>6-K96P@:2!D:6X@861R97-S
M8F]K`$ML:6-K82!F]G)A(&%T="!S<&%R82!3+TU)344@8V5R=&EF:6MA="!F
M]G(@)7,@:2!D:6X@861R97-S8F]K`$-L:6-K871E;&P@=FEA($A45%``3VT@
M9'4@:VQI8VMA<B!PY2!A9')E<W-E;B!FY7(@9'4@<VMR:79A(&5T="!N>71T
M(&UE9&1E;&%N9&4@=&EL;`IA=G/D;F1A<F5N`$]M(&1U(&ML:6-K87(@<.4@
M861R97-S96X@]G!P;F%S(&UE9&1E;&%N9&5T(&;V<B!V:7-N:6YG`%-TY&YG
M`%-TY&YG(&;V;G-T97(`4W3D;F<@9O9N<W1R970`4W3D;F=D82!M87!P87(`
M36]L;@!4:61I9V$@;6]L;@!-;VQN:6YG=`!#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<P!3=.1N9P!3=.1N9R!A;&QA`%-TY&YG(&%L;&$@;6%P<&%R`%-TY&YG
M(&UA<'``2V]M<')I;65R82!S:61O9N1L=&5T`$MO;7!R:6UE<F%D92!R86UA
M<@!+;VQO;6)I80!&Y')G`$;D<F=I;F1I:V%T;W(Z(`!&Y')G:&%N=&5R87)E
M`$;D<F=V86P`2V]L=6UN97(Z`$MO;'5M;B!R=6)R:6ME<@!,=7-T:6=H971E
M<@!+;VUM86YD;P!+;VUM86YD;V;V;G-T97(`2V]M;65N=&%R`$YA;6X`0V]M
M;W)O<P!&]G)E=&%G`%-L=71F]G)D`%-K<FEV(&UE9&1E;&%N9&4@*"5S*0!3
M:W)I=B!E='0@86YN870@;65D9&5L86YD90!3:W)I=B!M961D96QA;F1E;B!I
M(&5T="!S97!A<F%T(&;V;G-T97(_`%-K<FEV(&UE9&1E;&%N9&5N(&UE9"!E
M='0@2%1-3"UG<N1N<W-N:71T("AO;2!W96)LY'-A<F5N('-T]F1J97(@9G5N
M:W1I;VYE;BD_`$1A=&]R97(`5N1D97(`5N1D97(`2V]N9FEG=7)A=&EO;G-S
M:VEL;&YA9&5R`$EN<W3D;&QN:6YG87(@9O9R(&%T="!S>6YK<F]N:7-E<F$@
M;65D(&AA;F1D871O<F5R+"!S;6%R=&$@=&5L969O;F5R(&]C:"!/=71L;V]K
M`$MO;F9I9W5R871I;VX@8F5H]G9E<B!U<'!D871E<F%S+@!+;VYF:6=U<F5R
M82`E<P!);G-TY&QL;FEN9V%R(&;V<B!M961D96QA;F1E=FES;FEN9RX`Q&YD
M<F$@:6YS=.1L;&YI;F=A<B!F]G)H86YD<V=R86YS:VYI;F<N`$)E:W+D9G1A
M(&SV<V5N;W)D`$MO;F=O`$MO;F=O`$;V<F)I;F1E;'-E;B!N961K;W!P;&%D
M(&%V($E-05`M<V5R=F5R;BX`1O9R8FEN9&5L<V4@;6ES<VQY8VMA9&5S+@!&
M]G)B:6YD96QS92!M:7-S;'EC:V%D97,Z(`!&]G)B:6YD96QS92!M960@<'5B
M;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S+@!&]G)B:6YD96QS92!M960@<'5B
M;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S.B`E<R`H)7,I`$;V<F)I;F1E;'-E
M(&UE9"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RX`06YS;'5T;FEN9R!T:6QL
M('-E<G9E<FX@;6ES<VQY8VMA9&5S+@!+;VYT86MT97(`2V]N=&%K=&5R(&QA
M9&5S('1I;&P@:2!D:6X@861R97-S8F]K+@!);FYE:.5L;'-T>7`@9O9R(&MO
M;7!R:6UE<F%D(&9I;#H@`$EN;F5HY6QL(&D@)R5S)P!&;W)T<^1T=`!(86YT
M97)I;F<@878@4$=0(&D@)7,N`$AA;G1E<FEN9R!A=B!3+TU)344@:2`E<RX`
M26YS=.1L;&YI;F=A<B!F]G(@<_9K;FEN9R!I(&UE9&1E;&%N9&5N`$MO;G1R
M;VQL97)A(&[D<B!N>6$@;65D9&5L86YD96X@86YLY&YD97(@;V-H(&%N9V4@
M;VT@;F]T:69I97)I;F<@<VMA;&P@<VME(&[D<B!D92!A;FSD;F1E<BX`2V]N
M=F5R=&5R82!KY&YS;&]I:V]N97(@:2!T97AT9F]R;2!T:6QL(&=R869I<VMA
M/P!#;V]K($ES;&%N9',`0V]O:VEE`$MO<&EE<F$`2V]P:65R:6YG(&UI<W-L
M>6-K861E<SH@)7,`2V]P:65R82!M87)K97)I;F<`2V]P:65R82!T:6QL(&UA
M<'``36%J<V)L;VUM80!+;W)R96MT`$MO<G)I9V5R860@=&5X=`!+;W-T;F%D
M<RU)1`!#;W-T82!2:6-A`$5L9F5N8F5N<VMU<W1E;@!+86X@:6YT92!01U`M
M:W)Y<'1E<F$@;65D9&5L86YD92X`2V%N(&EN=&4@4$=0+6MR>7!T97)A(&UE
M9&1E;&%N9&4Z(`!+86X@:6YT92!01U`M<VEG;F5R82!M961D96QA;F1E+@!+
M86X@:6YT92!01U`M<VEG;F5R82!M961D96QA;F1E.B``2V%N(&EN=&4@4R]-
M24U%+6MR>7!T97)A(&UE9&1E;&%N9&4N`$MA;B!I;G1E(%,O34E-12US:6=N
M97)A(&UE9&1E;&%N9&4N`$MA;B!I;G1E(&SD9V=A('1I;&P@:V]N=&%K="X@
M)7,`36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!,1$%0('-E<G9E<BX`2V%N
M(&EN=&4@=F5R:69I97)A(&MO;G1O<V%L9&\N("5S`$MU;F1E(&EN=&4@<VQU
M=&;V<F$@8F5GY')A;BX@06YL961N:6YG.B`E<P!+=6YD92!I;G1E(&%N<VQU
M=&$@=&EL;"!,1$%0+7-E<G9E<BX`2V%N(&EN=&4@:V]N=&%K=&$@<V5R=F5R
M("<E<R<@=FEA($944#H@)7,`2V%N(&EN=&4@<VMA<&$@9&ES=')I8G5T:6]N
M<VQI<W1A+B`E<P!+=6YD92!I;G1E('-K87!A(%9&4RUK;W!P;&EN9V5N.B`E
M<P!+86X@:6YT92!D96MR>7!T97)A(%!'4"UD871A+@!+86X@:6YT92!D96MR
M>7!T97)A(%!'4"UD871A.B``2V%N(&EN=&4@9&5K<GEP=&5R82!3+TU)344M
M9&%T82X`2V%N(&EN=&4@<F%D97)A(&MO;G1A:W0N("5S`$MA;B!I;G1E(')A
M9&5R82!D:7-T<FEB=71I;VYS;&ES=&$N("5S`$MU;F1E(&EN=&4@<F%D97)A
M(&UE9&1E;&%N9&5N(&9RY6X@)7,N(%-E<G9E<FX@<W9A<F%D93H@)7,`2V%N
M(&EN=&4@<F%D97)A('5P<&=R861E<FEN9W-S8W)I<'0@=&EL;#H@)7,N`$MA
M;B!I;G1E(&)E<W3D;6UA(&UO='1A9V%R96YS(&50;W-T+6%D<F5S<RX`2W5N
M9&4@:6YT92!U=&;V<F$@=6YD97)HY6QL<V%K=&EV:71E=&5R`$MU;F1E(&EN
M=&4@97AT<F%H97)A(&)E9^1R9"!F:6P@9G+E;B!-4RU43D5&(&)I;&%G86XN
M`$MU;F1E(&EN=&4@97AT<F%H97)A(&)E9^1R9"!F:6P@9G+E;B!:25`M87)K
M:79E="X`2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@861R97-S8F]K+@!+86X@
M:6YT92!HY&UT82!K;VUP;&5T="!D:7-T<FEB=71I;VYS;&ES=&$N`$MA;B!I
M;G1E(&CD;71A(&MO;7!L971T(&QI<W1A(/9V97(@9&ES=')I8G5T:6]N<VQI
M<W1O<BX`2V%N(&EN=&4@;&%D9&$@<W1R871E9VD@)R5S)RX`2V%N(&EN=&4@
M;&%D9&$@<W1R871E9VD@)R5S)RX`2V%N(&EN=&4@<VMA<&$@;6%P<"`G)7,G
M+@!+86X@:6YT92!S:V%P82!M87!P("<E<R<N`$MA;B!I;G1E(&CD;71A('!U
M8FQI:R!N>6-K96P@9G+E;B!N>6-K96QS97)V97)N+@!+86X@:6YT92#V<'!N
M82`G)7,G(&;V<B!S:W)I=FEN9RX`2V%N(&EN=&4@]G!P;F$@)7,N`$MA;B!I
M;G1E(/9P<&YA("<E<R<@9O9R('-K<FEV:6YG+@!+86X@:6YT92#V<'!N82!-
M86EN=&5N86YC95]487-K(&UO9'5L("5S`$MA;B!I;G1E(/9P<&YA(&UA<'!E
M;B`G)7,G`$MA;B!I;G1E(/9P<&YA(&UA<'`@)R5S)P!+86X@:6YT92!S:V%P
M82!E;B!SY&ME<B!A;G-L=71N:6YG('1I;&P@24U!4"US97)V97)N+B`E<R`Z
M("5S+@!+86X@:6YT92!K;VYT86MT82!,1$%0('-E<G9E<BX`2V%N(&EN=&4@
M;.1S82`E<RX`1&5T(&=I8VL@:6YT92!A='0@Y71E<G-TY&QL82!L]G-E;F]R
M9&5T(&;V<B!D96X@86YG:79N82!A;G;D;F1A<F5N+B!.Y6=O;B!E;&QE<B!N
MY6=R82!A=B!U<'!G:69T97)N82#D<B!I;G1E(&MO<G)E:W1A+B!&]G)S]FL@
M:6=E;B!E;&QE<B!K;VYT86MT82!A9&UI;FES=')A=/9R96X@;VT@9'4@8F5H
M]G9E<B!H:N1L<"X`2V%N(&EN=&4@:.1M=&$@04-,`$MA;B!I;G1E(&CD;71A
M(&%D<F5S<V)O:RX@)7,`2V%N(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI
M<W1A+B`E<P!+86X@:6YT92!HY&UT82!D:7-T<FEB=71I;VYS;&ES=&]R+B`E
M<P!+86X@:6YT92!HY&UT82!N86UN9&5F:6YI=&EO;B!F<N5N($E-05`M<V5R
M=F5R+@!+86X@:6YT92!HY&UT82!D<V5R=F5R9G5N:W1I;VYE<@!+86X@:6YT
M92#E=&5R<W3D;&QA(&MO;F9I9W5R871I;VYE;BX`2V%N(&EN=&4@<F%D97)A
M(&UA<'`@)R5S)RX`2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RX`2V%N(&EN
M=&4@<W!A<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,N`$MA;B!I;G1E('-P87)A
M(&)A8VMU<"UK;VYF:6=U<F%T:6]N+@!+86X@:6YT92!S<&%R82!E;B!B86-K
M=7`M:V]N9FEG=7)A=&EO;CH@)7,N`$MA;B!I;G1E('-P87)A('5P<&=R861E
M<FEN9W-S8W)I<'0@=&EL;#H@)7,N`$MA;B!I;G1E('-P87)A(&)A8VMU<"UK
M;VYF:6=U<F%T:6]N("5S+@!+86X@:6YT92!S<&%R82!K;VYF:6=U<F%T:6]N
M<V9I;&5N("5S+B!$=2!K86X@86YT:6YG96X@86YVY&YD82!E;B!A=B!A;'1E
M<FYA=&EV96X@871T('-P87)A(&MO9&5N('1I;&P@)7,@96QL97(@:V]P:65R
M82!K;V1E;B!N961A;B!T:6QL("5S+@!+86X@:6YT92!S]FMA(&D@3$1!4"UK
M871A;&]G96XN`$MA;B!I;G1E(')A9&5R82`G)7,G+@!+86X@:6YT92!R861E
M<F$@)R5S)RX`2V%N(&EN=&4@=7!P9&%T97)A(&MO;G1A:W0N("5S`$MA;B!I
M;G1E('5P<&1A=&5R82!D:7-T<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I;G1A
M('-P87)A(&MO;F9I9W5R871I;VX@9O9R("<E<R<Z("5S`$MA;B!I;G1E(&AI
M='1A($UO>FEL;&%S('-I9&]FY&QT+B!697)I9FEE<F$@871T('-I9&]FY&QT
M970@Y'(@]G!P970N`$MA;B!I;G1E(&=E(&%N=N1N9&%R96X@)R5S)R!A;F=I
M=FYA('+D='1I9VAE=&5R('1I;&P@;6%P<&5N("<E<R<Z("5S`%+D:VYA9"!T
M97AT`$QA;F0`2W5R<V5R`%-K87!A`%-K87!A(&UA<'``4VMA<&$@;GEC:VQA
M<@!3:V%P82!V:7)T=65L;"!M87!P`%-K87!A(&YY='0@:V]N=&\`4VMA<&$@
M;.1N:P!3:V%P82!N>2!M87!P(&;V<B!S:W+D<'!O<W0`4VMA<&$@;GD@;6%P
M<"!F]G(@=71K87-T`%-K87!A(&YY`%-K87!A(&YY(&UA<'`@9O9R('-K:6-K
M861E(&UE9&1E;&%N9&5N`%-K87!A(&YY(&UA<'`@9O9R('!A<'!E<G-K;W)G
M`%-K87!A(&9I;'1R97)I;F=S<F5G;&5R(&;V<B!A='0@;W)G86YI<V5R82!I
M;FMO;6UA;F1E(&UE9&1E;&%N9&5N+"!S;W)T97)A(&EN(&D@;6%P<&%R(&]C
M:"!R861E<F$@<VMRY'!P;W-T+@!3:V%P82!N>2!M86QL`%-K87!A(&UA;&QA
M<B!O8V@@9F]R;75LY')S=F%R+@!3:V%P82!U;F1E<FUA<'``0F5H]G)I9VAE
M=&5R(&;V<B#D9V%R80!+<F5D:71K;W)T<VYU;6UE<@!+<F]A=&EE;@!+=6)A
M`$%K='5E;&QA(#0@9F%S97(`06MT=65L;"!S97-S:6]N`$%K='5E;&P@=&ED
M`$%K='5E;&P@55),(.1R`$%K=&EV82!A;G;D;F1A<F4`06MT=65L;'0@=N1D
M97(`3G5V87)A;F1E('+D='1I9VAE=&5R(&;V<B`E<P!!:W1U96QL82!V:6QL
M:V]R.B``06MT=65L;"!S=&EL`%-K<N1D9&%R<WD@:V]N=&]N(&;V<B!HY&UT
M;FEN9R!A=B!M961D96QA;F1E;B!F<N5N(&%N9')A(&MO;G1O;BX`4VMRY&1D
M87)S>2!H=7(@9'4@<VMI8VMA<B!M961D96QA;F1E;BX`4VMRY&1D87)S>2!A
M:W1I=FET971E<B!S;VT@:_9R<R!V:60@:6YL;V=N:6YG('1I;&P@)7,N`$ML
M:7!P('5T`$ML:7!P('5R=F%L`$-Y<&5R;@!+>7)I;&QI<VL@*$M/23@M4BD`
M2WER:6QL:7-K("A7:6YD;W=S+3$R-3$I`$MY<FEL;&ES:R]5:W)A:6YS:R`H
M2T])."U5*0!4:F5C:VEE;@!$1`!$86=L:6<`1&%T7W5M`$1A=&%4<F5E(&)L
MY&1D<F%R90!$871A8F%S=7!P<VQA9P!$871U;0!$871U;2!M;W1T86=E=`!$
M871U;79A;`!$86<`7U)A9&5R82!K;VQU;6X`9&5C96UB97(`1&5C:6UA;&5R
M`$%V8O9J=`!!=F+V:G0Z(`!-:6YS:V$@:6YD<F%G`%-T86YD87)D`$;V<G9A
M;&0@9N1R9P!&]G)V86QD(&ED96YT:71E=`!&]G)V86QT('/V:V;D;'0`1O9R
M=F%L="!S:V%L`$;V<G9A;&0@<V]R=&5R:6YG<V]R9&YI;F<Z`$;V<G9A;&0@
M<V]R=&5R:6YG<W)I:W1N:6YG.@!$969I;FET:6]N97(`1&5L96=E<F$@<&]S
M:71I;VX`1&5L96=E<F%D`%)A9&5R80!2861E<F$@<'5B;&EK(&YY8VME;"!F
M]G(@)7,`4F%D97)A(&-E;&P`4F%D97)A(&%K='5E;&QA(&YY8VML87(`4F%D
M97)A(&UA<'`H87(I`%)A9&5R82!G<G5P<`!2861E<F$@;&]G9P!2861E<F$@
M8F5H]G)I9VAE=`!2861E<F$@=F%L9&$@;6%P<"AA<BD`4F%D97)A(&UA;&P`
M4F%D97)A('9I<G1U96QL(&UA<'``Q&YD<F$@9&5F:6YI=&EO;F5N(&;V<B!D
M96X@=FER='5E;&QA(&UA<'!E;B`E<P!2861E<F$@;V-H(')E;G-A(&UE9&1E
M;&%N9&5N`%)A9&5R82!C96QL`%)A9&5R82!K;VQU;6X`4F%D97)A(&)E9FEN
M=&QI9R!A;'1E<FYA=&EV;6%L;`!2861E<F$@:.1M=&%D92!M961D96QA;F1E
M;B!F<N5N('-E<G9E<C\`5&$@8F]R="!F<N5N(&UI;B!K86QE;F1E<@!2861E
M<F%D92!M961D96QA;F1E;@!2861E<F$@;.1N:V%D92!B:6QA9V]R(&D@8O9R
M:F%N(&%V(&WE;F%D96X_`%)A9&5R82!M87!P*&%R*2!F]G(@<VMI8VMA9&4@
M;65D9&5L86YD96X@=FED(&+V<FIA;B!A=B!MY6YA9&5N/P!2861E<F$@8F5H
M]G)I9VAE="!F]G(@)R5S)P!2861E<F$@8F5H]G)I9VAE="!F]G(@)R5S)R!O
M8V@@=6YD97)B96CV<FEG:&5T97(_`%)A9&5R82!R860`4F%D97)A('9A;&0@
M:61E;G1I=&5T`%)A9&5R82!S:W+D<'!O<W0`4F%D97)A('5N9&5R;6%P<&%R
M`%)A9&5R82!A:W1U96QL(&MO;'5M;@!2861E<F$@86MT=65L;"!R860`4F%D
M97)A(&1E;B!HY'(@;.1N:V5N`%)A9&5R860`4F%D97)A9&4@;65D9&5L86YD
M96X`4F%D97)A9&4@=7!P9W)A9&5R:6YG<W-C<FEP=&5T("<E<R<N`%)A9&5R
M861E(&)I;&%G86X@)7,N`%)A9&5R82!O8V@@9FQY='1A(&UE9&1E;&%N9&5N
M`$QE=F5R86YS=&ED`$1A;FUA<FL`079S;.4@8F5GY')A;@!!=G-LY2!B96?D
M<F%N(&]M(&QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N`$9A;&QA;F1E`$)E
M<VMR:78@<')O8FQE;65T`$)E<VMR:79N:6YG`$1E=&%L:F5R`$1E=&%L:F5R
M("AO8VMSY2!I($AO<F1E<R!L;V=G9FEL*3H`1&5T86QJ97(@:&%R(&QO9V=A
M=',@9O9R('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BX`571V96-K;&EN9P!$86=G
M<'5N:W0`1&%G9W!U;FMT(&;V<B!S96YA<W1E('1I;6UE;CH@`$1A9V=P=6YK
M=#H@`"(E<R(@8FEF;V=A9&5S(&EN=&4@969T97)S;VT@9&5N(.1R('1O;2X`
M1W+E;6%R:V5R82!S:6=N871U<C\`4FEK=&YI;F<@=N1N<W1E<B!T:6QL(&CV
M9V5R`%)I:W1N:6YG(&CV9V5R('1I;&P@=N1N<W1E<@!+871A;&]G`%9I<V$`
M5FES82`R-"UT:6UM87)S(&ML;V-K83\`5FES;FEN9W-I;G-TY&QL;FEN9V%R
M`%9I<V$@8F5K<N1F=&5L<V4@969T97(@871T(&UE9&1E;&%N9&4@:&%R('-K
M:6-K871S/P!6:7-A(&1E=&%L:F5R860@9O9R=71SY&=E;'-E`%9I<V$@9O9R
M=71SY&=E;'-E("A4048I`%9I<VYI;F=S9F]R;6%T`%9I<V$@:2!M961D96QA
M;F1E=`!6:7-A('!O<'5P(&YO=&EF:65R:6YG('9I9"!N>6$@;65D9&5L86YD
M96X_`%9I<V$@(E3V;2!S:W+D<'!O<W0B(&D@;65N>6X_`%9I<V$@(E3V;2!P
M87!P97)K;W)G(B!I(&UE;GEN/P!0;&%C97)I;F<`079S:VEL:F%R90!$:FEB
M;W5T:0!3:V%L;"!)3E1%(&UA=&-H80!+;VYT<F]L;&5R82!I;G1E(&UA<'`H
M87(I(&;V<B!N>6$@;65D9&5L86YD96X`4F%D97)A(&EN=&4`06YVY&YD(&EN
M=&4@;6%I;G1E;F%N8V4N<&AP(&1I<F5K=`!3:V%P82!I;F=E;B!LY&YK(&%V
M($9RY6XM:V]L=6UN96X`5FEL;"!D=2#V<'!N82!M87!P96X_`$EN;F5HY6QL
M97(@9O9R<W1A(')A9&5N(&;D;'1N86UN96X_($]M("=J82<L(&UA<FME<F$@
M:.1R.@!$;VUI;FEK86YS:V$@<F5P=6)L:6ME;@!(87(@9'4@:6YG970@:V]N
M=&\_(%)E9VES=')E<F$@9&EG+@!+;&%R`$CD;71A`$CD;71A("5S`$CD;71A
M("5S('-O;2!E;B`N>FEP+69I;`!(Y&UT82!A;&QA(&)I;&%G;W(@*'-O;2!E
M;B`N>FEP+69I;"D`2.1M=&$@;6%P<"AA<BD`2.1M=&$@;6%P<"AA<BD@*'-O
M;2!E;B`N>FEP+69I;"D`2.1M=&$@9V5N97)E<F%D(&MO;F9I9W5R871I;VX@
M<V]M(%!(4"US:W)I<'0N`$CD;71A(&D@+GII<"UF;W)M870`571K87-T`%5T
M:V%S="UM87!P`%5T:V%S="UM87!P.@!$<F]P<&QI<W1A`$1R;V=E<@!%+7!O
M<W0`12UP;W-T861R97-S`$1R:79R=71I;B!F]G(@12UP;W-T('1I;&P@4TU3
M+6)R>6=G83L@9O9R(&]P97)A=/9R97(@<V]M('1I;&QH86YD86CE;&QE<B!D
M96YN82!T:N1N<W0N`%-,550`1D5,`$9%3#H@1&ET="!M961D96QA;F1E(&MU
M;F1E(&EN=&4@;&5V97)E<F%S+@!%:W5A9&]R`,1N9')A`,1N9')A('-PY')R
M861E(&%D<F5S<V5R`,1N9')A(&)L;V-K`,1N9')A(&9I;'1E<@#$;F1R82!G
M<G5P<`#$;F1R82!B96CV<FEG:&5T`,1N9')A(&)E:/9R:6=H971E<@#$;F1R
M82!B96CV<FEG:&5T97(@9O9R("5S`%)E9&EG97)A('/V:V9RY6=A`,1N9')A
M('9I<G1U96QL(&UA<'``Q&YD<F$@9&5F:6YI=&EO;F5N(&;V<B!D96X@=FER
M='5E;&QA(&UA<'!E;B`E<P#$;F1R82!B971R;V1D82!A9')E<W-E<@#$;F1R
M82!I;G-TY&QL;FEN9V%R(&;V<CH`Q&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`G
M)7,G`,1N9')A(&)E:/9R:6=H971E<B!F]G(@)R5S)P#$;F1R82!S<.1R<F%D
M92!A9')E<W-E<@#$;F1R82!F:6QT97)R96=L97(`Q&YD<F$@:6YS=.1L;&YI
M;F=A<B!F]G(@Y71K;VUS="!A=B!A;F1R82!E+7!O<W1K;VYT;VXN`,1N9')A
M(&)E=')O9&1A(&%D<F5S<V5R`%5T8FEL9&YI;F<`16=Y<'1E;@!%;"!386QV
M861O<@!%;&5M96YT+BXN`$5M`$4M<&]S=`!%+7!O<W1A9')E<W,`12UP;W-T
M861R97-S97(@;>5S=&4@<W3D;6UA(/9V97)R96YS+@!%+7!O<W1M961D96QA
M;F1E(&UE9"!B96MRY&9T96QS90!%+7!O<W0@=&EL;"!335,M8G)Y9V=A`$OD
M;G-L;VEK;VYE<@!296YS861E(&%L;&$@;65D9&5L86YD96X@9G+E;B`E<RX`
M4F5N<V%D92!A;&QA(&UE9&1E;&%N9&5N(&9RY6X@=FER='5E;&QA('!A<'!E
M<G-K;W)G96XN`%3V;2!M87!P*&%R*0!4]FT@;6%R:V5R861E(&UA<'!A<@!4
M]FT@4&%P<&5R<VMO<F<`5/9M(%]S:W+D<'!O<W0`5/9M(%]P87!P97)S:V]R
M9P!4;VUT(&UE9&1E;&%N9&4N`%1O;70@<F5S=6QT870N`%1O;70@<_9K:W)I
M=&5R:6$`06MT:79E<F$@4$=0+69U;FMT:6]N86QI=&5T/P!!:W1I=F5R82!3
M+TU)344M9G5N:W1I;VYA;&ET970_`$%K=&EV97)A(&;V<FAA;F1S9W)A;G-K
M;FEN9R!A=B!M961D96QA;F1E;C\`2W)?>7!T97)I;F=S:6YS=.1L;&YI;F=A
M<@!+<GEP=&5R870`4VQU=`!3;'5T('#E('9I9&%R96)E9F]R9')A="!M961D
M96QA;F1E`%-L=70@<.4@;65D9&5L86YD96X`4VQU="!PY2!M961D96QA;F1E
M(&9RY6X@)7,`4VQU="#E<@!&]G)S=&]R82!E9&ET;W(`06YG92!L]G-E;F]R
M9`!!;F=E('/V:W;D9R`H55),*2!T:6QL(&)I;&1E;B!HY'(`4TMR:78@8F]K
M<W3D=F5R;F$@;F5D86XZ`$%N9V4@;F%M;B!PY2!N>2!M87!P(&;V<B!S:W+D
M<'!O<W0`06YG92!N86UN('#E(&YY(&UA<'`@9O9R('5T:V%S=`!!;F=E(&YA
M;6X@<.4@;GD@;6%P<"!F]G(@<VMI8VMA9&4@;65D9&5L86YD96X`06YG92!N
M86UN('#E(&YY('!A<'!E<G-K;W)G`$AE;&$@;65D9&5L86YD970`)R5S)R!L
M861E<R!T:6QL(&D@861R97-S8F]K96XN`$9E;`!&96P@-#`S.B!"96?D<F%N
M('1I;&SE=',@:6YT92X`1F5L(#4P,SH@4V5R=FEC92!E:B!T:6QL9^1N9VQI
M9P!+86X@:6YT92!K;VYT86MT82!M86EL<V5R=F5R;BX@)7,@.B`E<P!&96P@
M=FED('-K87!A;F1E(&%V(&)L;V-K.B`E<P!&96P@=FED(')A9&5R:6YG(&%V
M('-Y;FMR;VYI<V5R:6YG<VWD<FME.B`E<P!&96P@=FED(')A9&5R:6YG(&%V
M('-Y;FMR;VYI<V5R:6YG<VQO9V<Z("5S`$9E;"!NY'(@:6YN96CE;"!HY&UT
M861E<SH@)7,`1F5L('5N9&5R('/D;F1N:6YG(&%V('-V87)S;65D9&5L86YD
M93H@)7,`1F5L('9I9"!U<'!D871E<FEN9R!A=B!L]G-E;F]R9#H@)7,`1F5L
M('9I9"!S:W)I=FYI;F<@)R5S)RX`1F5L('9I9"!S:W)I=FYI;F<@878@)R5S
M)RX`1F5L.B!':F]R9&4@)60@9O9R<_9K+"!V87(@9V]D(&MO;G1R;VQL97(@
M86YVY&YD87)N86UN(&]C:"!L]G-E;F]R9"P@96QL97(@]FMA(&UA>"!A;G1A
M;"!F]G)S]FLN`$9E;#H@3VOD;F0@2%144"US=&%T=7,Z("5S+@!&96PZ(&9S
M;V-K;W!E;B@I(&UI<W-L>6-K861E<RX`1F5L.B!F<V]C:V]P96XH*2!M:7-S
M;'EC:V%D97,N($9E;"!N<CH@)7,N($9E;'1E>'0Z("5S+@!%<W1L86YD`$5T
M:6]P:65N`$5T;FES:P!%=7)O<&$`2.1N9&5L<V4@<F%D97)A9"X`5F%R(#$U
M.F4@;6EN=70`5F%R86YN86X@;6EN=70`5F%R(#,P.F4@<V5K=6YD`%9A<B`U
M.F4@;6EN=70`5F%R:F4@:6YL;V=G;FEN9P!687)J92!H86QV=&EM;64`5F%R
M:F4@;6EN=70`17AE;7!E;"!PY2!VY')D96XZ`$OV<@!%>'!A;F1E<F$`17AP
M86YD97)A(&%L;&$`17AP86YD97)A(&%L;&$@;6%P<&%R`$5X<&%N9&5R82!M
M87!P`$5X<&%N9&5R82!N86UN`$5X<&%N9&5R82!S:61O9N1L=`!!=71O;6%T
M:7-K(&)A:V=R=6YD<V5X<&%N<VEO;B!A=B!A9')E<W-E<B!NY'(@9'4@86YG
M97(@;6]T=&%G87)E/P!%>'!A;F1E<F$@86QL82!M87!P87(@<V]M(&;V<G9A
M;&0@:6YS=.1L;&YI;F<@:2!M87!P=GEN/P!%>'!A;F1E<F%R`$;V<G;D;G1A
M9&4@)RDG`$;V<G;D;G1A9&4@96YS:VEL="!O<F0@96QL97(@8VET97)A="!S
M]FMB96=R97!P`$;V<F9A;&QO9&%T=6T`17AP;VYE;G0`1O9R9W)U;F1S9N1R
M9P!,861D82!U<'`@:V]N9FEG=7)A=&EO;B!V:6$@1E10+@!(Y&U?=&$@92UP
M;W-T`$UI<W-L>6-K861E<R!A='0@:.1M=&$@:6YS=.1L;&YI;F=A<BX`36ES
M<VQY8VMA9&5S(&%T="!K;VYT86MT82!,1$%0('-E<G9E<BX`36ES<VQY8VMA
M9&5S(&%T="!K;VYT86MT82!334(@<V5R=F5R+@!-:7-S;'EC:V%D97,@871T
M(&MO<&EE<F$@9G+E;B`G)7,G+@!-:7-S;'EC:V%D97,@871T(&MO<&EE<F$@
M=&EL;"`G)7,G+@!-:7-S;'EC:V%D97,@871T('-K87!A(&YY(%-!4TPM9O9R
M8FEN9&5L<V4N`$UI<W-L>6-K861E<R!A='0@9FQY='1A('1I;&P@)R5S)RX`
M36ES<VQY8VMA9&5S(&%T="!HY&UT83H@)7,`0G)A`$9A;&ML86YD<_9A<FYA
M`$;D<O9A<FYA`$9A=&%L="!F96PZ`$9A>`!&87AA<@!F96)R=6%R:0!+Y&YN
M<R!S;VT`2^1N;G,@<V]M.B``2.1M=&$@92UP;W-T`$CD;71A(&4M<&]S="!I
M(&5T="!S97!A<F%T(&;V;G-T97(N`$CD;71A(&UE9&1E;&%N9&5N('9I9"!I
M;FQO9V=N:6YG/P!(Y&UT861E("5D(&UE9&1E;&%N9&5N(&9RY6X@)7,N`$CD
M;71A9&4@,2!M961D96QA;F1E(&9RY6X@)7,N`$9E=&-H;6%I;#H@`$9E=&-H
M;6%I;#H@:6YG82!N>6$@;65D9&5L86YD96XN`$;E=&%L:6=A('-K=7)A<@!&
MY71A;&EG82!S;O9S:W5R87(`1FE?;'1E<@!&Y&QT;6%T<FES`$9I9VQE="!#
M05!40TA!`$9I9VQE='1Y<'-N:71T`$9I:FD`1FEL`$%N=&%L(&9I;&5R.B`E
M<R!F:6P`06YT86P@9FEL97(Z("5S(&9I;&5R`$9I;&AA;G1E<F%R90!&:6QN
M86UN`$9I;'9A;`!&:6QU<'!L861D;FEN9P!&:6QU<'!L861D;FEN9R!S=/9D
M<R!I;G1E+@!&:6QT97)I;G-TY&QL;FEN9V%R`$9I;'1E<FEN<W3D;&QN:6YG
M87(`1FEL=')E<F$@;65D9&5L86YD92!PY2!S=F]R9&]M87(_`$9I;'1E<G-U
M<'!O<G0@Y'(@879S=.1N9W0@:2!S>7-T96UE="X`1FEL=&5R`$9I;'1E<B#D
M<B!)3E1%(&%K=&EV=``E<RUF:6QT97)H86YT97)I;F=S<VED80!3]FL`1FEN
M;&%N9`!&]G)S=&$@:&%L=F%N`$;V<G-T82!B<F5V;.5D97-I9&%N`$;V<G-T
M82!S:61A;@!&]G)S=&$@:W9A<G1E;@!6:61A7W)E8F5F;W)D<F$`36%P<"`E
M<R!E>&ES=&5R87(@:6YT92X`0F5K<N1F=&5L<V4@9O9R(.5T9^1R9&5R(&D@
M;6%P<&%R`$UA<'!N879I9V%T;W(`36%P<'-A;6UA;G-TY&QL;FEN9P!-87!P
M9&5L;FEN9R#D<B!I;G1E('1I;&QGY&YG;&EG="X`36%P<&%N=N1N9&YI;F<@
MY'(@:6YT92!T:6QL9^5N9VQI9W0N`$9O;G1FY')G`$UA=`!&]G(@=V5B8FSD
M<V%R92!S;VT@:6YT92!S=/9D97(@8FEL9&5R`%!R;V=N;W,@*%1!1BD`06YT
M86P@9&%G87(@9O9R('!R;V=N;W,@*'9A<FIE(&1A9R!B971Y9&5R(&5N('!R
M;V=N;W,@9O9R(&1A9R!O8V@@96X@9O9R(&YA='0I`$=L]FUT(&1I='0@;/9S
M96YO<F0_`$1A='5M9F]R;6%T(&D@8G)E=FSE9&5V>6X@9O9R(&UE9&1E;&%N
M9&5N(&1A=&5R861E(&ED86<`1F]R;75LY'(`5FES:&5T<V]R9`!4>7`@878@
M=FES:&5T<V]R9`!6:7-H971S;W)D`%9I<VAE='-O<F0@,@!&;W)U;0!6:61A
M<F5B969O<F1R80!6:61A<F5B969O<F1R83H`5FED87)E8F5F;W)D<F%T(&UE
M9&1E;&%N9&4`5FED87)E8F5F;W)D<F%T(&UE9&1E;&%N9&4@9G+E;B`E<P!6
M:61A<F)E9F]R9')A<@!&<@!286UA<@!&<F%N:W)I:V4`1G)A;FMR:6ME+"!-
M971R;W!O;`!,961I9R]5<'!T86=E;B!I;F9O<FUA=&EO;@!,961I9R]5<'!T
M86=E;B!S=F%R`$QE9&EG+W5P<'1A9V5N+6;V<F9RY6=A;@!3=F%R('#E(&QE
M9&EG+W5P<'1A9V5N+6;V<F9RY6=A;@!&<F%N<VMA($=U:6%N80!&<F%N<VMA
M(%!O;'EN97-I96X`1G)A;G-K82!S]F1R82!T97)R:71O<FEE<@!&<N5?;@!&
M<N5N`$9RY6XM861R97-S`$9RY6X@9&5N(`!&=6QL<W3D;F1I9R!B97-K<FEV
M;FEN9P!&=6QL;>5N90!&=6QL<W3D;F1I9W0@;F%M;@!60CH`5D(Z(`!60CH@
M)74@=FED87)B969O<F1R870@;65D9&5L86YD90!'86)O;@!'86QL97)I(&%T
M="!T82!B:6QD(&9RY6X`1V%L;&5R:3H`1V%M8FEA`$%L;&WD;FYA(&EN<W3D
M;&QN:6YG87(`1V5N97)E<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,`1V5N97)E
M<F%D(&MO9`!'96]R9VEE;@!4>7-K;&%N9`!(Y&UT82!E;F)A<G0@;GEA(&UE
M9&1E;&%N9&5N/R`H24U!4"D`1VAA;F$`1VEB<F%L=&%R`$;V<FYA;6X`1VQO
M8F%L82!I;G-TY&QL;FEN9V%R`$]+`$?E('1I;&P@;65D9&5L86YD90!'Y2!T
M:6QL(&%D<F5S<V)O:W-P;W-T(&;V<B`B)7,B`$=O961E;`!';V]G;&5K87)T
M;W(`1V]O9VQE<_9K;FEN9P!4:6QLY70@Y71K;VUS=`!'<N5S:V%L80!'<F5K
M:7-K("A)4T\M.#@U.2TW*0!'<O9N`$=R]FYL86YD`$=R86YA9&$`1W+E`$=R
M=7!P861M:6YI<W1R871I;VX`1W)O=7!?;&1A<#H@2V%N(&EN=&4@;.1G9V$@
M=&EL;"!G<G5P<"`G)7,G+B!397)V97)N('-V87)A9&4Z(`!'<F]U<%]L9&%P
M.B!+86X@:6YT92!R861E<F$@9W)U<'`@)R5S)P!'<F]U<%]L9&%P.B!+86X@
M:6YT92!U<'!D871E<F$@9W)U<'`@)R5S)P!'<G5P<&5R`$=U86T`1W5A=&5M
M86QA`$=U97)N<V5Y`$?D<W1B96CV<FEG:&5T97(`5&KD;G-T97(@9O9R(&?D
M<W1E<@!'Y'-T8F]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U:6YE80!(Q%(`
M2%1-3`!(5$U,+79E<G-I;VX@878@;65D9&5L86YD970`2%1-3$%R96$@=N1G
M<F%R(&%T="!R861E<F$@<VES=&$@8V5L;&5N(&D@96X@<F%D+@!(5$U,07)E
M82!VY&=R87(@871T(')A9&5R82!S:7-T82!K;VQU;6YE;B!I(&5N('1A8F5L
M;"X`2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@<VES=&$@<F%D96X@:2!E
M;B!T86)E;&PN`$A45%`@075T96YT:7-E<FEN9R!S86MN87,N`$AA:71I`$AA
M<VAA;&=O<FET;0!$:6UM80!2=6)R:6L`4G5B<FEK97(`2&5A<F0M(&]C:"!-
M8T1O;F%L9/9A<FYA`$MR869T:6=A(.5S:W-K=7)A<@!(96)R96ES:R`H25-/
M+3@X-3DM."U)*0!(]FID`$CV:F0@*'!I>&QA<BD`2&KD;'``2&KD;'`@;65D
M(&5D:71O<FX`2&KD;'!F=6YK=&EO;@!(96UI<V;D<@!(Y'(@Y'(@8O9R:F%N
M(&%V(&9I;&5N.@!(Y'(@Y'(@;65D9&5L86YD970@9'4@<VMR978@<.4Z`$?V
M;60`1_9M9"!I('1RY61V>0!$]FQJ(')A9&5R861E`$?V;2!U;G-U8G-C<FEB
M960`2/9G`$CV9R!P<FEO<FET970`2/9G<W0`2&5?;0!(96T`061R97-S+"!H
M96T`2&5M:V%T86QO9P!496QE9F]N+"!H96T`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<F1E+TMO;&%B.B!/9VEL=&EG="`E<R!834PM9&%T82!PY71R
MY&9F861E<R!I(&UE9&1E;&%N9&4@)7,`2&]R9&4O2V]L86(Z($EN9V5T(&UE
M9&1E;&%N9&4@;6%T8VAA<B!O8FIE:W1E="`E<P!(;W)D92]+;VQA;CH@26YG
M970@;V)J96MT(&%V('1Y<&5N("5S(&AI='1A9&5S(&D@;65D9&5L86YD970@
M)7,`2&]R9&4O2V]L86(Z(%)A9&5R861E("5S("<E<R<`2&]R9&4O2V]L86(Z
M($EN=&5G<F%T:6]N<VUO=&]R;B!K<N1V97(@)V1O;7AM;"<M=&EL;.1G9V5T
M(&;V<B!02%``2&]R9&4O2V]L86(Z($MA;B!I;G1E('-K87!A(&YY='0@6$U,
M+71RY&0@9O9R(&]B:F5K="`E<P!(;W)D92]+;VQA8CH@2V%N(&EN=&4@<F%D
M97)A("5S("<E<R<Z("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!HY&UT82!-
M24U$12U)1"!F]G(@9&5L96X@;65D('1Y<"`E<P!(;W)D92]+;VQA8CH@2V%N
M(&EN=&4@<WEN:W)O;FES97)A("5S("<E<R<Z("5S`$AO<F1E+TMO;&%B.B!+
M86X@:6YT92!S>6YK<F]N:7-E<F$@=71D96QN:6YG87(Z("5S`$AO<F1E+TMO
M;&%B.B!/:^1N9"!U=&1E;&YI;F<@)R5S)P!(;W)I<V]N=&5L;"!L:6YJ90!(
M;W)I<V]N=&5L;"!U=&9Y;&QN860`2&]R:7-O;G1E;&PZ`$AO=&UA:6PM:V]N
M=&]N`$AU<B!H86UN861E(&1U(&CD<C\@*%9A<B!G;V0@<F%P<&]R=&5R82!D
M971T82$I`$AU<B!V:6QL(&1U('9I<V$@8FEL86=O<C\`2'5R(&WE;F=A(&MO
M;'5M;F5R('9I;&P@9'4@<VSE(&EH;W`_`$AU<B!MY6YG82!FY&QT("AK;VQU
M;6YE<BD@9FEN;G,@9&5T/P!(=7(@;>5N9V$@<F%D97(@=FEL;"!D=2!S;.4@
M<V%M;6%N/P!(=7(@8VET97)A9&4@<F%D97(@=FES87,@:2!E='0@<W9A<@!&
M=6MT:6=H970`1G5K=&EG:&5T.@!(=6UO<FES=&5R`%5N9V5R;@!)34%0`$E-
M05`@*'5P<'3D8VL@<')O=&]K;VQL(&%U=&]M871I<VMT*0!)34%0+7-E<G9E
M<FX@8G+V="!F]G)B:6YD96QS96XN(%-E<G9E<FX@<W9A<F%D93H@)7,`4VMA
M<&%N9&4@878@24U!4"UM87!P(&UI<W-L>6-K861E.B`E<P!2861E<FEN9R!A
M=B!)34%0+6UA<'`@;6ES<VQY8VMA9&5S.B`E<P!3:V%P86YD92!A=B!Q=6]T
M82!F]G(@24U!4"UM87!P(&UI<W-L>6-K861E<SH@)7,`24U!4"#V=F5R(%-3
M3`!)34%0(/9V97(@4U-,("AS:N1L=G-I9VYE<F%T(&-E<G1I9FEK870I`$E-
M05`@]G9E<B!34TP@*'-JY&QV<VEG;F5R860I`$E-05`M<V5R=F5R;B!B<O9T
M(&;V<F)I;F1E;'-E;BX`24U!4"P@:6YG96X@5$Q3`$E-05`O4$]0,R!E+7!O
M<W1S97)V<F%R`$E0+6%D<F5S<P!)4"UA9')E<W,@Y'(@:6YT92!T:6QL9^1N
M9VQI9RX`25`M861R97-S(.1R(&EN=&4@:6YO;2!G;V1KY&YT($-)1%(M8FQO
M8VLN`$;V<G/V:R!A='0@:W)I;F=GY2!)4"ULY7,N`$E?;F9O9V$@<F%D(&;V
M<F4`27-L86YD`$5N8F%R="!I:V]N97(`26MO;F5R(&;V<B`E<P!):V]N97(@
M;65D('1E>'0`261E;G1I=&5T96YS(&YA;6XZ`$]M(&1E="!I;G1E('9I<V%S
M(&MO<G)E:W0L("5S(&;V<B!A='0@]G!P;F$@:2!N>71T(&;V;G-T97(N`$]M
M(&1U(&%N=N1N9&5R(%-33"!E;&QE<B!43%,@<^4@;>5S=&4@9'4@:&$@3U!%
M3E-33"UT:6QLY&=G970@=&EL;"!02%`@;&%D9&%T+@!/;2!D=2!VY&QJ97(@
M871T(&9O<G1SY'1T82!SY2!K;VUM97(@86QL82!M961D96QA;F1E;B!I(&UA
M<'!E;B]M87!P87)N82!A='0@9O9R<W9I;FYA(0!/;2!D=2!I;G1E('-E<B!N
MY6=R82!I:V]N97(@;N1R(&1U(&%N=N1N9&5R($EN=&5R;F5T($5X<&QO<F5R
M+"!SY2!K86X@9'4@8F5H]G9A(&UA<FME<F$@9&5N;F$@<G5T82!F]G(@871T
M('-TY&YG82!A=B!G96YO;7-K:6YL:6=A(%!.1RUB:6QD9FEL97(N`$]M(&1U
M('-E<B!D96YN82!T97AT(&UE;B!I;F=E;B!B:6QD+"!SY2!K86X@:6YT92!D
M:6X@=V5B8FSD<V%R92!V:7-A(&1E;B!B:6QD(&1U(&;V<G/V:V5R(&QA9&1A
M('5P<"X`26=N;W)E<F$`26=N;W)E<F$@86QL80!":6QD`$;V<FAA;F1S9W)A
M;G-K82!B:6QD.@!":6QD861R97-S`$)I;&1A9')E<W,Z`$)I;&0@9G+E;B!G
M86QL97)I`$)I;&0@9G+E;B!G86QL97)I.@!,861D82!U<'`@8FEL9`!":6QD
M97(`26UP;W)T97)A`$EM<&]R=&5R82!N>6-K96P`26UP;W)T97)A(&YY8VME
M;'!A<@!);7!O<G1E<F$@;65D9&5L86YD96X`26UP;W)T97)A(%!'4"UN>6-K
M96P`26UP;W)T97)A('!E<G-O;FQI9W0@8V5R=&EF:6MA=`!);7!O<G1E<F$@
M<&5R<V]N;&EG('!R:79A="!01U`M;GEC:V5L`$EM<&]R=&5R82!P97)S;VYL
M:6<@<'5B;&EK(%!'4"UN>6-K96P`26UP;W)T97)A('!E<G-O;FQI9W0@4R]-
M24U%+6-E<G1I9FEK870`26UP;W)T97)A('!U8FQI:R!N>6-K96P`26UP;W)T
M('!U8FQI:R!01U`M;GEC:V5L`$EM<&]R=&5R82!P=6)L:6L@4R]-24U%+6YY
M8VME;`!);7!O<G1E<F$@4R]-24U%+6YY8VME;`!);7!O<G1E<F$@;6)O>"UF
M:6P`26UP;W)T97)A(&UB;W@M9FEL("5S('1I;&P@;6%P<&5N("5S+@!);7!O
M<G1E<F$L('-T96<@)60`5FEK=&EG=`!6:6MT:6=A(&UE9&1E;&%N9&5N`$EM
M<&]R=&5R861E("5D(&UE9&1E;&%N9&5N(&9RY6X@)7,N`$EM<&]R=&5R861E
M(&;D;'0Z("5S`$EM<&]R=&5R861E(&;D;'0Z`%#E9^5E;F1E`$EN7V9O9V$@
M<F%D(&5F=&5R`$EN:V]R9P!);FML=61E<F$@96X@:V]R="!S86UM86YS=.1L
M;&YI;F<@878@<G5B<FEK97)N82!I('-V87(_`$EN:VQU9&5R82!O<F=I;F%L
M;65D9&5L86YD92!I('-V87(_`$9E;&%K=&EV(&%K=&EV:71E='-K;V0@<W!E
M8VEF:6-E<F%D+@!&96QA:W1I9W0@86YVY&YD87)N86UN(&]C:"]E;&QE<B!L
M]G-E;F]R9"X`3V=I;'1I9W0@86YVY&YD87)N86UN(&5L;&5R(&%L=&5R;F%T
M:78@861R97-S+B!&]G)S]FL@:6=E;B!E;&QE<B!K;VYT86MT82!A9&UI;FES
M=')A=/9R96X@;VT@9'4@8F5H]G9E<B!H:N1L<"X`UFMA(&EN9')A9P!);F1I
M96X`26YD:79I9'5E;&QA(&%N=N1N9&%R90!);F1O;F5S:65N`$EN9F\`26YF
M;W)M871I;VX`26YF;W)M871I;VX@Y'(@:6YT92!T:6QL9^1N9VQI9R!LY&YG
M<F4N`$EN9F]R;6%T:6]N(&]M('!U8FQI:R!N>6-K96P@9O9R("5S`$EN9F]R
M;6%T:6]N(&]M('!E<G-O;FQI9R!P<FEV870@;GEC:V5L`$EN9F]R;6%T:6]N
M(&]M('!E<G-O;FQI9R!P=6)L:6L@;GEC:V5L`$EN;&EN90!);F9O9V$@:U]O
M;'5M;B!E9G1E<@!);F9O9V$@8V5R=&EF:6MA="!HY'(`26YF;V=A(&)I;&0`
M26YF;V=A('!E<G-O;FQI9R!P<FEV870@4$=0+6YY8VME;"!HY'(`26YF;V=A
M('!E<G-O;FQI9R!P=6)L:6L@4$=0+6YY8VME;"!N>6-K96P`26YF;V=A('!U
M8FQI:R!01U`M;GEC:V5L(&CD<@!);F9O9V$@=&%B96QL`$EN9F]G82!W96)B
M;.1N:P!);F9O9V$@7VMO;'5M;B!F]G)E`$EN9F]G82!N>2!K;VQU;6X@969T
M97(@86MT=65L;"!K;VQU;6X`26YF;V=A(&YY(&MO;'5M;B!F]G)E(&%K='5E
M;&P@:V]L=6UN`$EN9F]G82!R860@969T97(@86MT=65L;"!R860`26YF;V=A
M(&YY(')A9"!F]G)E(&5K='5E;&P@<F%D`$EN9F]G82!P87)A9W)A9B!E9G1E
M<B!A:W1U96QL(&YO9`!);F9O9V$@<&%R86=R868@9O9R92!A:W1U96QL(&YO
M9`!);F9O9V$@86QT97)N871I=B!M86QL`$EN9F]G82!C96QL(&5F=&5R`$EN
M9F]G82!C96QL(&;V<F4`26YF;V=A(&MO;'5M;B!E9G1E<@!);F9O9V$@:V]L
M=6UN(&;V<F4`26YF;V=A(&UE9&1E;&%N9&5N`$EN9F]G82!P87)A9W)A9B!E
M9G1E<@!);F9O9V$@<&%R86=R868@9O9R90!);F9O9V$@<F%D(&5F=&5R`$EN
M9F]G82!R860@9O9R90!!;F=E(&5R9F]R9')A="!S=F%R('1I;&P@<^1K97)H
M971S9G+E9V%N.@!);F9O9V$OQ&YD<F$@8FEL9`!);F9O9V$OQ&YD<F$@;.1N
M:P!/=&EL;'+D8VML:6<@:W)E9&ET(&;V<B!A='0@<VMI8VMA('1I;&P@9&ES
M=')I8G5T:6]N<VQI<W1A+@!/=&EL;'+D8VML:6<@:W)E9&ET+@!(96QT86P`
M2&5L=&%L<VQI<W1A`$AA;F1L:6YG(.1R(&]G:6QT:6<@9O9R(&1E;B!HY'(@
M:V]M<&]N96YT96XN`$9E;&%K=&EG(&%D<F5S<P!&96QA:W1I9R!F:N1R<F)R
M979LY61A`$]G:6QT:6<@541(("@G=7-E<B!D871A(&AE861E<B<I+@!/9VEL
M=&EG="!:25`M87)K:79D871A`$9E;&%K=&EG(&%P<&QI:V%T:6]N+@!&96QA
M:W1I9W0@8F%T8V@M240`3V=I;'1I9W0@=&5C:V5N(&D@92UP;W-T861R97-S
M.B`E<RX`1F5L86MT:6<@9&%T82!S:VEC:V%D+@!&96QA:W1I9R!D97-T:6YA
M=&EO;G-A9')E<W,N`$9E;&%K=&EG="!F:6QF;W)M870`1F5L86MT:6<@;GEC
M:V5L`$]G:6QT:6<@;&EC96YS;GEC:V5L+@!&96QA:W1I9R!O<G0@<W!E8VEF
M:6-E<F%D+@!&96QA:W1I9R!M961D96QA;F1E7W1Y<"X`1F5L86MT:6<@96QL
M97(@<V%K;F%D(&%P:5]I9"X`1F5L86MT:6=T(&5L;&5R('-A:VYA9"!P87)A
M;65T97(N`$9E;&%K=&EG(/9V97)L:6=G86YD92!B96CV<FEG:&5T+@!&96QA
M:W1I9W0@<&%R=&YE<BUI9"X`1F5L86MT:6<@<&5R<V]N;&EG('!R:79A="!0
M1U`M;GEC:V5L+@!&96QA:W1I9R!P97)S;VYL:6<@<'5B;&EK(%!'4"UN>6-K
M96PN`$9E;&%K=&EG('!R;V1U:W1K;V0N`$9E;&%K=&EG="!P<F]T;VMO;&PN
M`$9E;&%K=&EG(&UO='1A9V%R93H@)R5S)P!&96QA:W1I9W0@=71D96QN:6YG
M<V]B:F5K=`!&96QA:W1I9R!A=G/D;F1A<F%D<F5S<RX`1F5L86MT:6=T('5N
M:6-O9&4M9&%T80!);G9E;G1A<FEE<@!);G9E<G1E<F$@=7)V86P`26YV97)T
M97)A('5R=F%L`$ER86X`27)A:P!)<FQA;F0`27-L92!O9B!-86X`16YS=&%K
M82#E<VMS:W5R87(`27-R865L`%5T9N1R9&%T(&%V`$MU<G-I=@!)=&%L:65N
M`$IA;6%I8V$`:F%N=6%R:0!*87!A;@!*87!A;G-K("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;FEE;@!J=6QI`&IU;FD`2G5S=&5R80!#96YT97)J=7-T
M97)A`$IU<W1E<F$@:N1M=`!6Y&YS=&5R:G5S=&5R80!(]F=E<FIU<W1E<F$`
M2T(`2V5N>6$`2V5R8F5R;W-S97)V97)N(&%V=FES861E(&%U=&5N=&ES97)I
M;F=E;BX`3GEC:V5L('-K87!A9`!&:6YG97)P<FEN=`!.>6-K96QLY&YG9`!.
M>6-K96QT>7``3GEC:V5L86YVY&YD86YD90!.>6-K96P@9FEN;G,@<F5D86X@
M<.4@9&5N('!U8FQI:V$@;GEC:V5L<V5R=F5R;BX`3GEC:V5L('-K:6-K861E
M<R!T:6QL(&1E;B!P=6)L:6MA(&YY8VME;'-E<G9E<FXN`$)A<FX`2VER:6)A
M=&D`2V]L86(`3F]R9&MO<F5A`%-Y9&MO<F5A`$MO<F5A;G-K("A%54,M2U(I
M`$MU=V%I=`!+:7)G:7-T86X`3&%?>6]U=`!3<'+E:P!,86]S`%-I<W1A(&AA
M;'9A;@!3:7-T82!B<F5V;.5D97-I9&%N`%-I<W1A('-I9&%N`$SV<V5N;W)D
M(.1N9')A9&5S`%-I<W1A(&MV87)T86QE=`!396YA<W0@=7!P9&%T97)A9#H`
M4V5N87-T92!I;FQO9V=N:6YG.B`E<P!396YA<W1E(&EN;&]G9VYI;F<Z("5S
M(&9RY6X@)7,`4V5N87-T92!I;FQO9V=N:6YG.B!!;&1R:6<`3&5T=&QA;F0`
M3&%V96YD97(`3&%G`$QA>6]U=`!,Y&UN82!T;VT@9O9R(&%T="!S=.1N9V$@
M878@:V%N=&QI;FIE`$QI8F%N;VX`5N1N<W1E<@!6Y&YS=&5R<G5B<FEK`%;D
M;G-T97)VY')D96X`3&5S;W1H;P!.:7;E`$QI8F5R:6$`3&EB>65N`$QI96-H
M=&5N<W1E:6X`3&IU<V)LY0!$=6=G<F5G;@!,Y'1T(')E9VX`3.1T="!F]G)M
M:61D86=S<F5G;@!,Y'1T(&5F=&5R;6ED9&%G<W)E9VX`3.1T="!R96=N<VMU
M<@!,Y'1T(')E9VX@;65D(.5S:V$`3.1T="!S;O8`3.1T="!S;O9S:W5R`$QI
M;65R:6-K`$SD;FL`3.1?;FMA(&)I;&%G;W(_`$SD;FME;B!P96MA<B!PY3H`
M3.1N:V$@92UP;W-T861R97-S96X@=&EL;"!F=6YK=&EO;F5N(&;V<B!A='0@
M<VMA<&$@;GET="!M961D96QA;F1E`$SD;FMA(&)I;&%G;W(@Y'(@:6YT92!T
M:6QLY71E="X`3.1N:V%R`$SD;FMA<B!K;VUM97(@871T(&SV<&$@=70@)7,`
M2V%K80!,:7-T82`M(&%N=N1N9&%R92!K86X@<V4@;6%P<&5N`%9I<V$@9&%T
M86)A<V5R`%9I<V$@:&KD;'#D;6YE;@!,:7-T82!T86)E;&QE<@!6:7-A(&%L
M;&$@:V]N=&%K=&5R(&[D<B!D=2!T87(@9G)A;2!K;VYT86MT=GEN/R`H06YN
M87)S('-E<B!D=2!B87)A"FMO;G1A:W1E<B!NY'(@9'4@97AP;&EC:70@<_9K
M97(@969T97(@9&5M*0!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!6:7-A(&D@:'5V=61E=`!$970@9VEC:R!I;G1E(&%T="!L:7-T
M82!S97-S:6]N97(Z("5S`$1E="!G:6-K(&EN=&4@871T(&QI<W1A(&%N=N1N
M9&%R93H@)7,`3&ES=&YI;F<@878@86YVY&YD87)E(&%V86MT:79E<F%D+@!,
M:71T97)A='5R`$QI=&%U96X`3&%D9&%R+BXN`$QO:V%L(&UA<'`Z`$QO:V%L
M('1I9#H@`%)E9VEO;F%L=`!0;&%T<P!,;V=G82!I;@!,;V=G82!I;B!T:6QL
M("5S`$QO9V=A('5T`$QO9VEN`$QO9VEN86MT:79I=&5T97(`26YL;V=G;FEN
M9R!M:7-S;'EC:V%D97,N(%1R;VQI9W1V:7,@=F%R(&%N=N1N9&%R;F%M;B!E
M;&QE<B!L]G-E;F]R9"!F96QA:W1I9W0N`$EN;&]G9VYI;F<@;6ES<VQY8VMA
M9&5S+@!,Y6YG('1E>'0`2^1R;&5K`$SE9P!,Y6<@<')I;W)I=&5T`$=R96MI
M<VMA(&=E;65N97(`3&%T:6YS:V$@9V5M96YE<@!3;>4@<F]M97)S:V$@<VEF
M9G)O<@!,Y&=S=`!,;WEO;&$`3&]Y;VQA($)LY0!,=7AE;6)U<F<`34T`34]4
M1`!-4RU43D5&(&)I;&%G82!I;FYE:/9L;"!I;F=E;B!D871A+@!-4T<`36%C
M86\`36%C961O;FEE;@!-86-I;G1O8VAF:6P`36%G86=A<VMA<@!-86=I<VL`
M12UP;W-T`$4M<&]S=&%D;6EN`$;V<FAA;F1S9W)A;G-K;FEN9P!4>7`@878@
M92UP;W-T('-E<G9E<B!A='0@86YS;'5T82!T:6QL.@!"<F5V;.5D80!6:7-N
M:6YG<VEN<W3D;&QN:6YG87(@9O9R(&)R979LY61A(&]C:"!M87!P87(`4VMA
M<&$@;.1N:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97)N80!-86QI`$UA
M;'1A`%5N9&5R:.5L;"!L:7-T86X@;65D(&MA=&5G;W)I97(@9'4@86YVY&YD
M97(@9O9R(&%T="!K871E9V]R:7-E<F$@<&]S=&5R(&UE9"!O8V@@9N1R9V5R
M;F$@<V]M('1I;&QH]G(@9&5S<V$@:V%T96=O<FEE<BX`36%P,C0M:V%R=&$`
M36%P475E<W0M:V%R=&$`UG9E<G/D='1N:6YG87(@<W!A<F%D92X`;6%R<P!-
M87)G:6YA;`!-87)K97)A(&%L;&$@;65D9&5L86YD96X@:2!M87!P96X@<V]M
M(&SD<W1A`$UA<FME<F$@86QL82!M961D96QA;F1E;B!I(&UA<'!E;B!S;VT@
M;VSD<W1A`$UA<FME<F$@<V]M.@!-87)K97)A(&]L:6MA(&YI=N5E<B!A=B!C
M:71A="!M960@;VQI:V$@9N1R9V5R/P!-87)K97)A(&UE9&1E;&%N9&5N('-O
M;2!LY'-T83\@*&5N9&%S="!)34%0*0!(86YT97)A(&5N:V5L('1E>'1U<'!M
MY')K;FEN9S\`1FQA9V=A('-O;2!LY'-T+V]LY'-T`$9L86=G82!M960@86YN
M86X@<W1A='5S("AT(&5X('9I:W1I9W0O8F5S=F%R870I`$UA<G-H86QL]F%R
M;F$`36%R=&EN:7%U90!386UT;&EG80!-:6YS="!E;@!-871C:&%N9&4@9N1L
M=`!-875R:71A;FEE;@!-875R:71I=7,`36%X('1I;&SE=&5N(&MR961I="X`
M1W+D;G,@9O9R(&UA>"!A;G1A;"!D96QA<B!I(&UE9&1E;&%N9&4@]G9E<G-K
M<FED96XN`$CV9W-T82!T96UP97)A='5R92!S96YA<W1E(#(T('1I;6UA<FYA
M.B``2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S=&4@-B!T:6UM87)N83H@`$UA
M>&EM86P@8FEL86=E<W1O<FQE:P!-87@@86YT86P@;6%P<&%R`$UA>&EM86QT
M(&%N=&%L('!O<G1A;&)L;V-K`$UA>&EM86P@;.1N9V0`36%X(&%N=&%L(&)I
M;&%G;W(@=7!P;N5T="X`36%X<W1O<FQE:R!F]G(@<V%M=&QI9V$@8FEL86=O
M<B!U<'!NY61D+@!M86H`36%Y;W1T90!-961I8VEN`$%V8F]K82!M]G1E`$WV
M=&5S:6YF;W)M871I;VX`3?9T97-F]G)F<N5G86X`3?9T97-S=F%R`$WV=&5S
M=7!P9&%T97)I;F<`57!P9&%T97)I;F=S8F5GY')A;B!O;2!M]G1E`$UE9&QE
M;6UA<@!-96YY(&UA<'!L:7-T80!-96YY;.1G93H`4VSE(&EH;W`@8V5L;&5R
M`$UE9&1E;&%N9&4`4VMR:78@;65D9&5L86YD90!-961D96QA;F1E9&%T=6T`
M365D9&5L86YD96EN<W3D;&QN:6YG87(`365D9&5L86YD97/V:VYI;F<`365D
M9&5L86YD97-T;W)L96L`365D9&5L86YD96OD;&QA`$UE9&1E;&%N9&5T('9E
M<FEF:65R861E<R!M96X@9&5N('-I9VYE<F%D97,@8V5R=&EF:6MA="!K=6YD
M92!I;G1E('9E<FEF:65R87,N`$UE9&1E;&%N9&5V:7-N:6YG`$UE9&1E;&%N
M9&4@9^1L;&5R(&EN=&4@;.1N9W)E+@!-961D96QA;F1E9FQA9V=O<@!-961D
M96QA;F1E(&UA<'!A<@!-961D96QA;F1E(&9RY6X@)7,`365D9&5L86YD970@
M:&%R(&)I;&%G;W(`365D9&5L86YD970@Y'(@:W)Y<'1E<F%T`$UE9&1E;&%N
M9&5T(.1R('-I9VYE<F%T`$UE9&1E;&%N9&4@;6%T8VAA<@!-961D96QA;F1E
M(&5F=&5R<^1N="X`365D9&5L86YD92!S:VEC:V%D97,L(&UE;B!K=6YD92!I
M;G1E('-P87)A<R!T:6QL("5S`$UE9&1E;&%N9&4@<VMI8VMA9&5S+@!-961D
M96QA;F1E='EP`$UE9&1E;&%N9&4@<&5R('-I9&$@:2!M87!P=GEN+@!-961D
M96QA;F1E('1I;&P`365T87)VY&1E<@!-971A<F)L;V-K970@Y'(@:6YT92!T
M:6QL9^1N9VQI="X`365T87(M8FQO8VL@96H@=&EL;&?D;F=L:6=T+B!$971A
M;&IE<B!H87(@;&]G9V%T<R!F]G(@<WES=&5M861M:6YI<W1R873V<F5N+@!-
M971A<D1"(.1R(&EN=&4@86YS;'5T96XN`$UE=&]D`$UE=&]D96X@)R5S)R#D
M<B!I;G1E(&1E9FEN:65R860`365T;V1E;B!H87(@:6YT92!D969I;F5R871S
M+B!!;G)O<&%D(&UE=&]D.B`E<P!-971R:7-K`$UE>&EK;P!-:6MR;VYE<VEE
M;@!-:71T96X`36EM971Y<`!,Y&=S=&$@=&5M<&5R871U<B!S96YA<W1E(#(T
M('1I;6UA<FYA.B``3.1G<W1A('1E;7!E<F%T=7(@<V5N87-T92`V('1I;6UA
M<FYA.B``36EN<W1A(&SV<V5N;W)D<^5L9&5R(&AA<B!I;G1E('5P<&[E='1S
M(.1N`%-P96=L80!$:79E<G-E`$]B;&EG871O<FES:W0@<&%K970@<V%K;F%S
M("A014%2($A45%!?4F5Q=65S="DN`$MO;F9I9W5R871I;VX@<V%K;F%S+B!$
M=2!MY7-T92!S:V%P82!D96X@;G4@;VT@9'4@=FEL;"!A;G;D;F1A(&1E;B!H
MY'(@87!P;&EK871I;VYE;BX`4V%K;F%R(&UE9&1E;&%N9&4M240N`$]B;&EG
M871O<FES:W0@<&%K970@<V%K;F%S("A014%2($UA:6PI+@!386MN87(@<V5S
M<VEO;G,M240N`$WE`$UO8FEL(&4M<&]S=`!-;V1E<F5R80#$;F1R860@9&%T
M=6T`Q&YD<F$`Q&YD<F$@;.1N:P!-;V1U;'5S`$UO;&1A=FEE;@!-;VYA8V\`
M36]N9V]L:65T`$WE;F%D(&]C:"#E<@!-Y6YA=&QI9P!-;W1S97)R870`3>5N
M9F%S97(`1FQE<B!FY&QT(&AI='1A9&5S('#E(')A9"`E9"#D;B!D970@9O9R
M=N1N=&%D92`E9"X`365R(.1N(&5N(&%D<F5S<R!H:71T870@9O9R(&;D;'1E
M="`G)7,G+@!-87)O8VMO`$UE<W1A9&5L<R!K;&%R=`!-97-T861E;',@;6]L
M;FEG=`!-97-T861E;',@<V]L:6=T`$9L>71T80!&;'ET=&$@;F5D`$9L>71T
M82!VY&YS=&5R`$9L>71T82!H]F=E<@!&;'ET=&$@=7!P`$9L>71T82!N97(`
M1FQY='1A('1I;&P@;6%P<`!&;'ET=&$@=7!P`$UOYV%M8FEQ=64`36]Z:6QL
M80!&;&5R;FEVY7-L:7-T80!-=6QT:6UA<"!3=&]R8G)I=&%N;FEE;FMA<G1A
M`$UU;'1I<&%R="]A;'1E<FYA=&EV90!&;&5R;65D9&5L86YD979I<VYI;F<`
M1FQE<G9A;`!-:71T(&MO;G1O`$UI;B!K;VYT;VEN9F]R;6%T:6]N`$UI;B!P
M;W)T86P`36EN('!O<G1A;&QA>6]U=`!->6%N;6%R`$Y%2BP@2F%G(&%C8V5P
M=&5R87(@:6YT90!)3D=%5`!.;W1E<FEN9P!.86UN`$YA;6X@;V-H+V5L;&5R
M(&4M<&]S="!FY7(@:6YT92!V87)A('1O;0!.86UI8FEA`$YA=7)U`$YE6%0`
M0F5H]G9E<B#E=&?D<F0`3F5P86P`3F5D97)LY&YD97)N80!.961E<FSD;F1S
M:V$@06YT:6QL97)N80!.97-C87!E(&)A<RU54DP`3F5T<V-A<&4@9O9R;GEE
M;'-E+5523`!.971S8V%P92#E=&5R:V%L;&5L<V4M55),`$YE='-C87!E(%-3
M3"US97)V97)N86UN`$YE='-A<&4@8V5R=&EF:6MA='-K;VUM96YT87(`3F5T
M<V%P92!C97)T:69I:V%T<W1Y<`!.Y'1V97)K`$%L9')I9P!3<&%R82!A;&1R
M:6<@8FEL86=O<@!.>0!.>6$@2V%L961O;FEE;@!.>2!K871E9V]R:0!.>2!M
M87!P`$YY82!M961D96QA;F1E;@!.>71T(&UE9&1E;&%N9&4`3GET="!M961D
M96QA;F1E('1I;&P@)7,`3GEMY6YE`$YY='0@86YVY&YD87)N86UN("AV86QF
M<FET="D`3GEA(%IE96QA;F0`3GEA(&UE9&1E;&%N9&5N`$YY='0@;/9S96YO
M<F0`3GET="!L]G-E;F]R9"!K;VUM97(@871T(&?E('5T("5X+@!,]G-E;F]R
M9"!MY7-T92!V87)A('-A;6UA+@!.>71T(&;V;G-T97(@*%]B;&%N:RD`3GEH
M971E<@!.>6AE='-G<G5P<&5R`$[D<W1A`$MO;6UA;F1E(#0@9F%S97(`3N1S
M=&$@;65D9&5L86YD90!.Y'-T82!S:61A`$[D<W1A(&EN<W3D;&QN:6YG87(`
M3N1S=&$^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YA='0`3FEU90!.96H`
M26YG970@8V5R=&EF:6MA="!H:71T870`26YG96X@:W)Y<'1E<FEN9P!);F=A
M(&YY8VML87(@:2!N>6-K96QR:6YG96X`26YG82!M961D96QA;F1E;@!);F=E
M;B!P=6)L:6L@4$=0+6YY8VME;"!I;7!O<G1E<F%D97,N`$EN9V5T('!E<G-O
M;FQI9W0@8V5R=&EF:6MA="!T:6QL9^1N9VQI9W0`26YG96X@9O9R:&%N9'-V
M:7-N:6YG`$EN9V$@<'5B;&EK82!N>6-K;&%R(&AI='1A9&5S`$EN9V5N('!U
M8FQI:R!3+TU)344M;GEC:V5L(&EM<&]R=&5R861E<RX`0FEL86=O<B!S86MN
M87,N`$1E="!F:6YN<R!I;F=E="!K;VYF:6=U<F%T:6]N<V1A=&$@871T('9I
M<V$@<VMI;&QN861E<B!F]G(N`$EN9V5N('1I;&QGY&YG;&EG('-T<F%T96=I
M(&;V<B!A='0@<VMA<&$@25-/+6EM86=E+@!);G1E(&5N(&)A=&-H;6%L;"X`
M1&5T(&9I;FYS(&EN9V5T(&)L;V-K('#E(&1E;B!B96?D<F1A('!O<VET:6]N
M96X`26YG970@:V%L96YD97)N86UN(&;V<B!-0T%,(&%U=&5N=&ES97)I;F<@
M86YG:79E="X`26YG96X@Y&YD<FEN9RX`26YG82!U;F1E<F)E:/9R:6=H971E
M<B!K86X@;.1G9V%S('1I;&P@9&5N(&CD<B!B96CV<FEG:&5T96XN`$EN9V5N
M(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@)7,N`$EN
M9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@1E10
M(%9&4RX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N
M(&;V<B!344P@5D93+@!);F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N
M(&%N9VEV96X@9O9R(%-13"UF:6P@5D93+@!);F=E;B!K<F5D:70@:W9A<BX`
M0F5S:W)I=FYI;F<@<V%K;F%S+@!);F=E;B!M;W1T86=A<F4@86YG:79E;BX`
M26YG96X@92UP;W-T:6YF;W)M871I;VX@Y71E<F9A;FYS(&D@9&5N('!U;&EK
M82!N>6-K96QN+@!);F=E;B!F:6P@=7!P;&%D9&%D`$EN9V5N(&UA<'`@=F%L
M9"X`26YG82!M87!P87(@:V]N=')O;&QE<F%S(&;V<B!N>2!E+7!O<W0N`$EN
M9V$@;6%P<&%R(.1R('9A;&1A`$EN9V$@;6%P<&%R(&UE9"!N>6$@;65D9&5L
M86YD96X`26YG82!M87!P87(@;65D(&]LY'-T82!M961D96QA;F1E;@!);F=A
M(&EK;VYE<B!H:71T861E<RX`26YG96X@;W)T(&%N9VEV96XN`$EN9V5N(&]R
M="!A;F=I=F5N+@!);F=E;B!M961D96QA;F1E=&5X=`!);F=E="!M961D96QA
M;F1E(&CD;71A="X`26YG970@;65D9&5L86YD92!B:69O9V%D97,N`$EN9V$@
M;65D9&5L86YD96X@;6]T<W9A<F%D92!D:6X@<_9K;FEN9RX`26YG970@;F%M
M;B!A;F=I=F5T+@!);F=E;B!N=6UM97(@86YG:79E="X`26YG82!O9O9R<VOD
M;61A('9I<VAE='-O<F0`26YG970@;/9S96YO<F0@9O9R($A45%`M875T96YT
M:7-E<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@24U!4"UA=71E
M;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!+97)B97)O
M<RUA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!,
M;V=I;BUA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V
M<B!005-35T0M875T96YT:7-E<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R
M9"!F]G(@4TU"+6%U=&5N=&ES97)I;F<@86YG:79E="X`26YG82!VY&YT86YD
M92!R96=I<W1R97)I;F=A<BX`26YG96X@<&5R<V]N;&EG('!R:79A="!01U`M
M;GEC:V5L(&EM<&]R=&5R861E<RX`26YG96X@<&5R<V]N;&EG('!U8FQI:R!0
M1U`M;GEC:V5L(&EM<&]R=&5R861E<RX`26YG96YT('!E<G-O;FQI9R!3+TU)
M344M8V5R=&EF:6MA="!I;7!O<G1E<F%D97,N`$UE9&1E;&%N9&5T(&MA;B!I
M;G1E(&1E:W)Y<'1E<F%S+"!D970@9FEN;G,@:6YG96X@<')I=F%T(&YY8VME
M;"X`26YG96X@:W9O=&$@86YG:79E;@!);F=E;B!K=F]T82!A;F=I=F5N+@!)
M;F=A(')E9VQE<@!);F=E;B!A=F=RY&YS87)E(&%N9VEV96XN`$EN9V$@<VED
M;W(`2&ET=&%D92!I;F=E="!P<F]G<F%M(&;V<B!RY'1T<W1A=FYI;F=S:V]N
M=')O;&PN`$EN9V$@<W1A=F9E;`!);F=E;B!SY61A;B!F:6P`26YG82!F]G)S
M;&%G`$EN9V5N('1E;7!O<N1R:V%T86QO9R!T:6QL9^1N9VQI9R!F]G(@8V%C
M:&4N`$EN9V5N(&%N=N1N9&%R92!A;F=I=F5N+@!);F=E="!A;G;D;F1A<FYA
M;6X@;V-H+V5L;&5R(&SV<V5N;W)D('-K:6-K870N`$EN9V5T(&=I;'1I9R!8
M34PM9&%T82!R971U<FYE<F%D97,`26YG82!VY')D96X`26YG96X@=F5R<VEO
M;B!H:71T861E<R!I(&1E;B!U<G-P<G5N9VQI9V$@:V]N9FEG=7)A=&EO;F5N
M+B#%=&5R<VMA<&$@:V]N9FEG=7)A=&EO;F5N+@!);F=E;B!V97)S:6]N(&AI
M='1A9&5S(&D@9&EN(&MO;F9I9W5R871I;VXN(,5T97)S:V%P82!K;VYF:6=U
M<F%T:6]N96XN`$EC:V4M9&5L=&%G87)E`$EN9V5N`$EN9V5N("AA;G;D;F0@
M=6YD97)F]G)S=.5D9"D`3F]R9F]L:_9A<FYA`$YO<FUA;`!.;W)R82!H96UI
M<V;D<F5N`$YO<G)A($UA<FEA;F'V87)N80!.;W)G90!);G1E(&5F=&5R`$EN
M=&4@9O9R90!%:B!R861E<F%D`$5J('5T:V%S=`!%:B!V:6MT:6=T`$5J('!E
M<G-O;FQI9W0`26YT92!E;B!K871A;&]G`$9E;&%K=&EG('!U8FQI:R!01U`M
M;GEC:V5L+@!%:B!R861E<F%D92!M961D96QA;F1E;@!%:B!I;7!L96UE;G1E
M<F%D+@!%:B!V:6MT:6=A(&UE9&1E;&%N9&5N`$5J(&%N9VEV96X`4W3V9',@
M:6YT92X`1&5T(&MA;B!T82!E;B!S='5N9"X`06YT96-K;FEN9V%R`$EN9V5N
M=&EN9P!);F=E;G1I;F<@871T('9I<V$L(&?E('1I;&QB86MA+@!/0E,`3V)S
M.B!,Y&YK861E(&)I;&%G;W(@;F5D;&%D9&%D90!N;W9E;6)E<@!.=6UM97(`
M06YT86P@=&5C:V5N`$%N=&%L(&MO;'5M;F5R`$%N=&%L(&WE;F%D97(@<V]M
M(&SD;FMA9&4@8FEL86=O<B!S:V%L;"!S<&%R87,L(&]M(&WE;F%D<W9I<R!R
M861E<FEN9RX`06YT86P@;6%P<&%R(&;V<B!S:VEC:V%D92!M961D96QA;F1E
M;B!S;VT@<VMA;&P@<W!A<F%S('9I9"!MY6YA=&QI9R!R861E<FEN9RX`06YT
M86P@<F%D97(`3G5M;65R(&EN=&4@<W!E8VEF:6-E<F%D92!F]G(@871T('5P
M<&1A=&5R82!I(&1I<W1R:6)U=&EO;G-L:7-T86XN`$]+`&5L;&5R`$]B:F5K
M=`!/8FIE:W1S:V%P87)E`$]K=&%L`&]K=&]B97(`1FEL=&5R(&;V<B!O9O9R
M<VOD;61H971E<@!+;VYT;W(`1V%M;6%L="!O8V@@;GET="!L]G-E;F]R9"!F
MY7(@:6YT92!V87)A('-A;6UA+@!'86UL82!M961D96QA;F1E;@!'86UM86QT
M(&SV<V5N;W)D`$=A;6UA;'0@;/9S96YO<F0@Y'(@9F5L86MT:6=T`$UA<'`@
M9O9R('-K:6-K861E(&UE9&1E;&%N9&5N(')E;G-A<RX`3VUA;@!$96QA9&4@
M;6%P<&%R('-T]F1S(&5N8F%R="!A=B!)34%0+7-E<G9R87(`5FES82!B87)A
M(&UA<'!A<B!M960@;VSD<W1A(&UE9&1E;&%N9&5N/P!%;F)A<G0@;V;V<G-K
MY&UD82!V:7-H971S;W)D`$5N9&%S="!E;B!E+7!O<W1A9')E<W,@=&EL;.5T
M96XN`$)A<F$@96X@;6%P<"!K86X@=F%R82!V86QD(&;V<B!D96X@:.1R(&AA
M;F1L:6YG96XN`$5N9&%S="#D9V%R92!E;&QE<B!S>7-T96UA9&UI;FES=')A
M=/9R(&MA;B#D;F1R82#D9V%R92!E;&QE<B!B96CV<FEG:&5T97(@<.4@96X@
M=71D96QN:6YG`-9P<%]N82!M87!P`-9P<&YA(&UA<'``UG!P;F$@;6%P<`#6
M<'!N82!I(&YY='0@9O9N<W1E<@!/<&5N4U-,+69E;#H@1&5T(&=I8VL@:6YT
M92!A='0@97AT<F%H97)A(&1A=&$@9G+E;B!S:6=N97)A9"!3+TU)344M9&5L
M+@#6<'!N861E(&UA<'``UG!P;F$@;.1N:R!I(&YY='0@9O9N<W1E<@!/<&5R
M871I=G-Y<W1E;0!)8VME(&]B;&EG871O<FES:V$@9&5L=&%G87)E`$EN<W3D
M;&QN:6YG87(`26YS=.1L;&YI;F=A<B!F]G(@)7,`4V]R=&5R860@;&ES=&$`
M3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;G-E;FAE=`!/<F=A;FES97)A`%5R
M<W!R=6YG;&EG(&%P<&QI:V%T:6]N<VUA;&P`57)S<')U;F=L:6=A(&UA;&QA
M<B!I("5S.@!!;FYA;@!!;F1R82!I;G-TY&QL;FEN9V%R`$%N9')A(&4M<&]S
M=&MO;G1O;@!!;F1R82!I;G-TY&QL;FEN9V%R`,1G87)B96CV<FEG:&5T97(`
M4$%-+4%U=&5N=&ES97)I;F<@Y'(@:6YT92!T:6QL9^1N9VQI9RX`4$5!4CHZ
M36%I;"UK;W!P;&EN9P!01U``4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"UK
M<GEP=&5R80!01U`@16YC<GEP=&5D($1A=&$`4$=0+69E;#H@`%!'4"UF96PZ
M($)E:/9V97(@;/9S96YO<F0@9O9R('!E<G-O;FQI9R!P<FEV870@;GEC:V5L
M+@!01U`M:6YS=.1L;&YI;F=A<@!);FUA=&YI;F<@878@4$=0+6SV<V5N;W)D
M`%!'4"!P97)S;VYL:6=T(&YY8VME;'!A<B!K<N1V97(@<^1K97(@9O9R8FEN
M9&5L<V4@*$A45%!3*2X`4'5B;&EK(%!'4"UN>6-K96P`4'5B;&EK(%!'4"UN
M>6-K96P`4'5B;&EK(%!'4"UN>6-K96P@9O9R("<E<R`H)7,I)R!L861E<R!T
M:6QL+@!0=6)L:6L@4$=0+6YY8VME;"!F]G(@)R5S)R!R861E<F%D97,N`%!U
M8FQI:R!N>6-K96QR:6YG(&;V<B!01U``4VEG;F5R80!3:6=N97)A+TMR>7!T
M97)A`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4')I=F%T(%!'4"UN>6-K
M96P@;&%D97,@=&EL;"X`4'5B;&EK(%!'4"UN>6-K96P@;&%D97,@=&EL;"X`
M4$=0+7-U<'!O<G0@Y'(@879S=.1N9W0@:2!S>7-T96UE="X`1&5N(&1I9VET
M86QA('-I9VYA='5R96X@:V%N(&EN=&4@=F5R:69I97)A<R!P9V$@871T(%!'
M4"US=7!P;W)T(&EN=&4@Y'(@86MT:79E<F%T+@!-961D96QA;F1E="!K86X@
M:6YT92!D96MR>7!T97)A<R!P9V$@871T(%!'4"US=7!P;W)T(&EN=&4@Y'(@
M86MT:79E<F%T+@!01U`M<W3V9&5T(&MRY'9E<B!A='0@<&]P=7`M9O9N<W1E
M<B!F=6YG97)A<BX@3VT@9&EN('=E8F)LY'-A<F4@Y'(@:6YS=.1L;&0@871T
M(&)L;V-K97)A('!O<'5P+6;V;G-T97(@;>5S=&4@9'4@Y&YD<F$@9&5N(&EN
M<W3D;&QN:6YG96X@9O9R(&%T="!01U`M<W3V9&5T('-K82!F=6YG97)A`%!(
M4"UK;V0`4$A0+7-K86P`3.1T="!F]G)M:61D86=S<F5G;@!&]G)M:61D86=S
M<F5G;@!%9G1E<FUI9&1A9W-S:W5R87(`169T97)M:61D86=S<V[V`$5F=&5R
M;6ED9&%G<W-K=7)A<B!M960@<V[V`$5F=&5R;6ED9&%G<W-O;`#%<VMS:W5R
M87(@<.4@969T97)M:61D86=E;@!03U`S`%!/4#,@*'5P<'3D8VL@<')O=&]K
M;VQL(&%U=&]M871I<VMT*0!03U`S(/9V97(@4U-,`%!/4#,@]G9E<B!34TP@
M*'-JY&QV<VEG;F5R870@8V5R=&EF:6MA="D`4$]0,R#V=F5R(%-33"`H<VKD
M;'9S:6=N97)A9"D`4$]0,RP@:6YG96X@5$Q3`%!/4TE8+71I;&SD9V<@<V%K
M;F%S`%!?2%`M<VMA;`!5=&9Y;&QN860Z`%-I9&$@)60@878@)60`4VED86X@
M;65D(&;V<G-T82!O;.1S=&$@;65D9&5L86YD970`4VED86X@;65D(&1E="!S
M:7-T82!O;.1S=&$@;65D9&5L86YD970`4&%K:7-T86X`4&%L874`4&%L97-T
M:6YA`%!A;F%M80!087!U82U.>6$@1W5I;F5A`%!A<F%G=6%Y`$1E;"AA<BD`
M1&5L=FES(&UO;&YI9W0`3/9S96YO<F0`3/9S96YO<F0@*&EG96XI`$SV<V5N
M;W)D(&9R:6=J;W)T+@!,]G-E;F]R9#H`3/9S96YO<F0@:V%N(&EN=&4@=F%R
M82!T;VUM80!,]G-E;F]R9"!S=.1M;65R(&EN=&4@]G9E<G)E;G,`3/9S96YO
M<F0`3/9S96YO<F0@Y&YD<F%D97,N`$SV<V5N;W)D(&9E;&%K=&EG=`!,]G-E
M;F]R9"!K<N1V<R!F]G(@4D%$2553(&%U=&5N=&ES97)I;F<N`$SV<V5N;W)D
M(&UE9"!B96MRY&9T96QS90!,]G-E;F]R9#H`3/9S96YO<F0Z(`!,]G-E;F]R
M9"!MY7-T92!V87)A(&QI:V$N`$ML:7-T<F$@:6X`2VQI<W1R82!I;B!F<N5N
M('5R:VQI<'!S:&%N=&5R87)E;@!3]FMVY&<`5N1N=&%N9&4@<F5G:7-T<F5R
M:6YG87(Z`$WD;FYI<VMO<@!0<F]C96YT`%5T9O9R('5N9&5R:.5L;'-F=6YK
M=&EO;F5R`%5T9O9R('5N9&5R:.5L;'-A:W1I=FET971E<B!V:60@:6YL;V=G
M;FEN9S\`0F5H]G)I9VAE=`!"96CV<FEG:&5T("<E<R<@<F%D97)A9&5S(&EN
M=&4N`,5T:V]M<W0@;F5K860`8F5H]G)I9VAE=&5R`$)E:/9R:6=H971S861M
M:6YI<W1R871I;VX`2V%N(&EN=&4@Y&YD<F$@<N1T=&EG:&5T97(@9O9R(&1E
M;FYA(&%N=N1N9&%R92X`4&5R<V]N;&EG`%!E<G-O;FQI9R!I;F9O<FUA=&EO
M;@!097)S;VYL:6=T(&YY8VME;'!A<B!F]G(@4$=0('-K87!A9&5S+@!097)S
M;VYL:6=T(&YY8VME;'!A<B!F]G(@4$=0(')A9&5R861E<RX`26YG970@<&5R
M<V]N;&EG="!3+TU)344M8V5R=&EF:6MA="!I;7!O<G1E<F%D97,N`%!E<G-O
M;FQI9W0@;GEC:V5L<&%R(&;V<B!3+TU)344@<F%D97)A9&5S+@!097)U`$AU
M<V1J=7(`1FEL:7!P:6YE<FYA`%1E;&5F;VX`1F]T;VX`4&ET8V%I<FX`4&EX
M;&%R`$EN9F]G82!S:6=N871U<B!F]G)E('-V87(@;V-H('9I9&%R8F5F;W)D
M<FEN9S\`365D9&5L86YD92!I('!L86EN=&5X=`!+;&EC:.EE<@!3<&5L82!L
M:G5D(&[D<B!N>2!E+7!O<W0@=&%S(&5M;W0_($1E='1A(&MRY'9E<B!A='0@
M9&EN('=E8F)LY'-A<F4@:&%R('-T]F0@9O9R(&EN<&%C:V%D92!L:G5D9FEL
M97(N($[D<W1A;B!A;&QA('=E8F)LY'-A<F4@9O9R($UA8R!O8V@@5VEN9&]W
M<R!H87(@<W3V9"!F]G(@9&5T=&$N`%9A<B!G;V0@:VQI8VMA(&D@96X@8V5L
M;`!"96MRY&9T82!A='0@9'4@=FEL;"!R861E<F$@=F%L9"!P;W-T/P!"96MR
MY&9T82!A='0@9'4@=FEL;"!R861E<F$@86MT=65L;'0@96QE;65N="X`5F%R
M(&=O9"!A;F=E(&WE;F%D(&]C:"#E<BX`5F%R(&=O9"!A;F=E(&YA;6X@9O9R
M(&MA=&5G;W)I;CH`4VMR:78@971T(&YA;6X@9O9R(&1E;B!N>6$@;6%P<&5N
M.@!687(@9V]D(&%N9V4@9V]D:^1N9"!)4"UA9')E<W,N`%9A<B!G;V0@86YG
M92!E='0@9VEL=&EG="!D871U;3L@:V]N=')O;&QE<F$@86YT86QE="!D86=A
M<B!I(&WE;F%D96XN`%9A<B!G;V0@86YG92!E;B!G;V1KY&YD('1I9"X`06YG
M92!N86UN('#E(&YY(&UA<'`Z`%-K<FEV(&EN(&1E="!N>6$@;F%M;F5T.@!6
M87(@9V]D(&%N9V4@;/9S96YO<F0@9O9R(&1I;B!P<FEV871A(%!'4"UN>6-K
M96PN($SV<V5N;W)D970@8F5H]G9E<B!B87)A(&%N9V5S(&5N(&?E;F<@<&5R
M("5S+7-E<W-I;VXN`%9A<B!G;V0@86YG92!L]G-E;F]R9"!F]G(@9&EN('!R
M:79A=&$@4R]-24U%+6YY8VME;"X@3/9S96YO<F1E="!B96CV=F5R(&)A<F$@
M86YG97,@96X@9^5N9R!P97(@)7,M<V5S<VEO;BX`3&]G9V$@:6X@:6=E;B!F
M]G(@871T(.5T97)U<'!T82!A<F)E=&5T(&UE9"!A='0@<VMR:79A('#E(&1I
M='0*;65D9&5L86YD92X@3VT@9'4@24Y412!A8V-E<'1E<F%R(&MA:V]R($]#
M2"!S:W)I=F5R(&)R978@:0IP;W!U<"UF]FYS=&5R(&WE<W1E(&1U(&]C:W/E
M(&QO9V=A(&EN(&D@:'5V=61F]FYS=')E="!I9V5N+B!$971T82#D<@IE;B!S
MY&ME<FAE='/E=&?D<F0@9O9R(&%T="!H:6YD<F$@871T(&1I;B!S97-S:6]N
M(/9V97)T87,N(%9I(&)E<B!O;0IU<G/D:W0@9O9R(&5V96YT=65L;&$@;VSD
M9V5N:&5T97(@9&5T=&$@;W)S86MA<BX`5F%R(&=O9"!S=6UM97)A(&1I='0@
M<')O8FQE;2X`06YG92!D:71T(&SV<V5N;W)D+@!!;F=E(&1I='0@86YVY&YD
M87)N86UN(&]C:"!L]G-E;F]R9"X`06YG92!D:71T(&%N=N1N9&%R;F%M;BX`
M5F%R(&=O9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E>'0N($1U($W%4U1%('-A
M;71Y8VMA(&UE9"!V:6QL:V]R96X@9O9R(&%T="!A;G;D;F1A('-Y<W1E;65T
M+@!687(@9V]D(&SD<R!I9V5N;VT@9O9L:F%N9&4@=&5X="X@1'4@3<535$4@
M<V%M='EC:V$@;65D('9I;&QK;W)E;B!F]G(@871T(&%N=N1N9&$@<WES=&5M
M970N`%+D='1A(&9E;&%K=&EG82!E;&QE<B!T=F5T>61I9V$@861R97-S97(N
M`$MO;G1R;VQL97)A(&;V;&IA;F1E(&EN9F]R;6%T:6]N(&]C:"!VY&QJ('-E
M9&%N(&5N(&AA;F1L:6YG(&D@;65N>6X*;F5D86XN`%;D;&H@96X@;6%P<"!I
M;FYA;B!D=2!U=&;V<B!H86YD;&EN9V%R+@!6Y&QJ(&5N(&UA<'`@:6YN86X@
M9'4@=71F]G(@9&5N;F$@86MT:79I=&5T+@!6Y&QJ(&5N(&AA;F1L:6YG(&9R
MY6X@;65N>6X@;F5D86XN`%;D;&H@Y71M:6YS=&]N92!E;B!M87!P(&%T="!S
M]FMA(&DN`%;D;&H@8F%R82!E;B!M87!P(&;V<B!D96X@:.1R(&]P97)A=&EO
M;F5N+@!6Y&QJ(&5L;&5R(.1N9')A(&D@<G5T86X@=&EL;"!H]F=E<CH`06YG
M92!N>71T(&MA=&5G;W)I;F%M;CH`4&]L96X`4&]L:71I:P!5;F1E<G/V:VYI
M;F=A<@!0;W)T=6=A;`!0;W-I=&EO;F5R:6YG(&%V(&)I;&1E;@!0;W-I=&EO
M;F5R:6YG(&%V('1A8F5L;&5N`%-K<FEV('1I;&P@9&5N(&CD<B!M87!P96X@
M*&5J('1V:6YG870@878@24U!4"D`4&]S=&YU:V4`1')I=G,@;65D($AO<F1E
M`$;V<F5GY2!S:6=N871U<B!M960@<W1R96-K("@G+2TG*3\`3F5D97)B]G)D
M(&1E('-E;F%S=&4@)7,@=&EM;6%R;F$Z(`!#:&%N<R!T:6QL/&)R+SYN961E
M<F+V<F0`26YS=.1L;&YI;F=A<B!U<'!D871E<F%D92X`075T:%]L9&%P.B!,
M1$%0+71I;&SD9V<@<V%K;F%S+@!0<F5F<U]S97-S:6]N.B!/8FQI9V%T;W)I
M<VMT('-E<W-I;VYS=&EL;.1G9R!H:71T861E<R!I;G1E+@!4<GEC:P!,=69T
M=')Y8VL@=FED(&AA=F5T.B``3'5F='1R>6-K.B``1O9R:&%N9'-V:7-N:6YG
M`$;V<FAA;F1S9W)A;G-K82!B:6QD(&D@;GET="!F]FYS=&5R`$;V<F5GY65N
M9&4@;65D9&5L86YD90!&]G)E9^5E;F1E('-I9&$`1O9R96?E96YD92!I;G-T
MY&QL;FEN9V%R`%-K<FEV('5T`%-K<FEV('5T(&1O:W5M96YT`%!R:6]R:71E
M=`!0<FEV871A(&YY8VME;`!,]G-E;F]R9"!F]G(@<')I=F%T(&YY8VME;`!0
M<F]B;&5M`%!R;V)L96UB97-K<FEV;FEN9P!0<F]J96MT`$)E:W+D9G1A('9A
M<FIE(&?E;F<@96X@8FEL86=A('-K:6-K87,L(&AA($Y%2B!S;VT@<W1A;F1A
M<F1S=F%R`$)E:W+D9G1A('9A<FIE(&?E;F<@96X@8FEL86=A('-K:6-K87,L
M(&AA($I!('-O;2!S=&%N9&%R9'-V87(`5&5X=`!0<F]T;VMO;&PZ`%!U8FQI
M:R!N>6-K96P`4'5B;&EK(&YY8VME;&%L9V]R:71M`%!U8FQI:R!N>6-K96QI
M;F9O<FUA=&EO;@!3=7!P;W)T(&;V<B!01U`M;GEC:V5L<V5R=F5R(.1R(&EN
M=&4@86MT:79T+@!&96P@=FED(&=E;F5R97)I;F<@878@<'5B;&EK="]P<FEV
M870@;GEC:V5L<&%R+@!0=65R=&\@4FEC;P!296Y?<V$@<F%D97)A9&4`4F5N
M<V$@<F%D97)A9&4`5/9M(&UA<'`H87(I`$AU<B!O9G1A(')E;G-A<R!P87!P
M97)K;W)G96XZ`%)E;G-A(&UE9&1E;&%N9&5N`%)E;G-A(&UE9&1E;&%N9&5N
M(&D@<&%P<&5R:V]R9V5N(.1L9')E(.1N('/E(&CD<B!MY6YG82!D86=A<BX`
M4F5N<V$@9V%M;&$@;65D9&5L86YD96X@:2!P87!P97)K;W)G96X_`%)E;G-A
M<B`E9"!M961D96QA;F1E*&XI(&9RY6X@<&%P<&5R:V]R9V5N+@!296YS87(@
M,2!M961D96QA;F1E(&9RY6X@<&%P<&5R:V]R9V5N+@!1871A<@!&<N5G80!+
M=F]T80!1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4R9B4E*0!1
M=6]T82!S=&%T=7,Z("4N,F9-0B`O($E.1T5.($)%1U+$3E-.24Y'`%%U;W1A
M('-T871U<SH@24Y'14X@0D5'4L1.4TY)3D<`0VET97)A<B`E9CH`4'5B;&EK
M(%)302UN>6-K96P@*"5D(&)I=&%R*0!%;G-K:6QT('9A;`!296=N`%1I9&EG
M="!R96=N`%-E;G0@<F5G;@!296=N<VMU<F%R`%)E9VX@;V-H('-N]@!296=N
M('1I;&P@<V[V`%-L=6UP;>1S<VEG="!V:7-H971S;W)D`$;V<FCE;&QA;F1E
M`$SD<P!,Y',@;65D9&5L86YD96X`4^1K97)T(&%T="!D=2!V:6QL(')A9&5R
M82`E<S\@4F%D97)I;F=E;B!K86X@:6YT92#E;F=R87,N`%/D:V5R="!A='0@
M9'4@=FEL;"!R861E<F$@86YVY&YD87)D871A(&;V<B`E<S\@4F%D97)I;F=E
M;B!K86X@:6YT92#E;F=R87,N`,5T97)S:V%P82!I;F9O<FUA=&EO;B!F]G(@
M;6%P<'9Y`$%N:V]M(&1E;@!!;FMO;2!E9G1E<@!!;FMO;2!F<F%M('1I;&P`
M169T97)SY&Y?9`!%9G1E<G/D;F0`169T97)SY&YD(&UE9&1E;&%N9&4`169T
M97)SY&YD(&1E="!HY'(@;65D9&5L86YD970`169T97)SY&YD;FEN9R!M:7-S
M;'EC:V%D97,N`$?V<B!O;2!D:6X@<V5N87-T92!I;FUA=&YI;F<`57!P9&%T
M97)A`%5P<&1A=&5R82!D>6YA;6ES:V$@;65N>65L96UE;G0Z`%5P<&1A=&5R
M82!M87!P=GEE<CH`57!P9&%T97)A('!O<G1A;'9Y.@!296=E>`!6:7-A(&;V
M<FCE;&QA;F1E;@!,861D82!O;0!,861D82!O;2!V>0!+;VUM96YT87)E<@!+
M;VT@:6CE9R!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;BX`2V]M(&EH
MY6<@<V5N87-T92!V>6X`1FKD<G)B<F5V;.5D83H`1FKD<G)S97)V<F%R`%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%1A(&)O<G0`5&$@
M8F]R="!B;&]C:P!482!B;W)T(&;D;'0@9G+E;B!S]FMN:6YG96X`5&$@8F]R
M="!K;VQU;6X`5&$@8F]R="!F;W)M871E<FEN9P!482!B;W)T(&9RY6X@;6EN
M(&MA;&5N9&5R`%1A(&)O<G0@<&%R`%)A9&5R82!S<&%R870@<VMR:7!T(&9R
MY6X@<V5R=F5R;G,@=&5M<&]RY')K871A;&]G+@!482!B;W)T(&OD;&QA`%1A
M(&)O<G0`4F%D97)A(&1E;FYA(&YO9"!F<N5N(&1O:W5M96YT970`5&$@8F]R
M="!A;G;D;F1A<F4`5&$@8F]R="!A;G;D;F1A<F4Z("5S`$)Y="!N86UN('#E
M(&UA<'`H87(I`%-K87!A('9I<G1U96QL(&UA<'``0GET(&YA;6X@<.4@;6%P
M<"!F]G(@<VMI8VMA9&4@;65D9&5L86YD96X@:2!B]G)J86X@878@;>5N861E
M;C\`3F%M;F)Y=&4@9G+E;B`G)7,G('1I;&P@)R5S)R!M:7-S;'EC:V%D97,N
M(%-E<G9E<FX@<W9A<F%D90!3=F%?<F$@=&EL;"!L:7-T80!%<G/D='0@;65D
M.@!3=F%R80!3=F%R('-K:6-K870N`%-V87)A(&%L;&$`4W9A<F$@86QL83H`
M4W9A<F$@=&EL;"!L:7-T80!3=F%R82!T:6QL(&QI<W1A.@!3=F%R82!?86QL
M80!3=F%R82!A='0@8F5GY')A;B!I;G1E('-T]F1S`%-V87)A(&UE9"!I;F9O
M<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;B!F]G(@:V]M;6%N9&4@=';E(&WE
M;F%D97(N`%-V87)A(&UE9"!D96X@8F5GY')D82!L961I9R]U<'!T86=E;BUI
M;F9O<FUA=&EO;F5N+@!3=F%R('1I;&P`4W9A<B!T:6QL.B``4W9A<F$Z`%-V
M87(Z("5S`%)A<'!O<G1E<F$@<V]M(&]S:WEL9&EG=`!287!P;W)T97)A('-O
M;2!S:W+D<'!O<W0`0F5GY'(@7VSD<VMV:71T;P!"96?D<F%N(&MU;F1E(&EN
M=&4@8F5S=F%R87,N(%)E='5R;F5R860@9F5L:V]D.B``0F5GY'(@;.1S:W9I
M='1O/P!"96?D<G0@;65D9&5L86YD92!E:B!F=6YN970N`$1E;B!E9G1E<F9R
MY6=A9&4@=&KD;G-T96X@:W5N9&4@:6YT92!H:71T87,N`$5R9F]D<F%D("<E
M<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)A=&EO;F5N(&%V("5S+@!%
M<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R97)I;F=E
M;B!A=B!61E,N`$5R9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N
M9FEG=7)E<FEN9V5N+@!/8FQI9V%T;W)I<VMT="!FY&QT`$]B;&EG871O<FES
M:R!D96QT86=A<F4`Q71E<G-TY&QL`,5T97)S=.1L;"!L]G-E;F]R9`#%=&5R
M<W3D;&P@;/9S96YO<F0`4W9A<G-S=&%T=7,@=7!P9&%T97)A9"X`Q7-T97)T
MY&QL('-E;F%S=&4@9G+E9V%N`%)E<W5L=&%T`,5T97)T80#%=&5R=7!P=&$@
M<V5S<VEO;@#%=&5R=N1N9"!T:6QL(&%T="!S:W)I=F$@;65D9&5L86YD90#%
M=&5R=N1N="!T:6QL($9E=&-H($UA:6P`Q71E<G;D;F0@=&EL;"!I;G-TY&QL
M;FEN9V%R`,5T97)VY&YD82!T:6QL(&UA<'!V>6X@969T97(@<F%D97)I;F<L
M(&9L>71T;FEN9R!E;&QE<B!K;W!I97)I;F<@878@;65D9&5L86YD93\`06YG
M92!N>71T(&SV<V5N;W)D`%+I=6YI;VX`Q71E<G-TY&QL(&MO;F9I9W5R871I
M;VX`26YS=.1L;&YI;F=A<B!F]G(@4FEC:"!497AT($5D:71O<@!'Y71O<@!(
M]F=E<@!(]F=E<G)U8G)I:P!(]F=E<G;D<F1E;@!285]D:6YS=.1L;&YI;F=A
M<BXN+@!2;VQL`%)U;>1N:65N`%)O=&5R82`Q.#``4F]T97)A(';D;G-T97(`
M4F]T97)A(&CV9V5R`%)A9&EN<W3D;&QN:6YG87(`4F%D:6YS=.1L;&YI;F=A
M<@!2861E<CH`3&EN:F5R`$QI;FIE<B!V:7-A<R!M96QL86X@86QL82!R861E
M<B!O8V@@:V]L=6UN97(`3&EN:F5R('9I<V%S(&5N8F%R="!M96QL86X@:V]L
M=6UN97(`3&EN:F5R('9I<V%S(&5N8F%R="!M96QL86X@<F%D97(`2_9R`%)Y
M<W-L86YD`%)W86YD80!3+TU)344`4R]-24U%('-I9VYA='5R`%,O34E-12!K
M<GEP=&5R80!3+TU)344M:W)Y<'1E<F%T(&UE9&1E;&%N9&4`4R]-24U%+69E
M;#H`4R]-24U%+69E;#H@0F5H]G9E<B!L]G-E;F]R9"!F]G(@<&5R<V]N;&EG
M('!R:79A="!N>6-K96PN`%,O34E-12!I;G-TY&QL;FEN9V%R`$EN;6%T;FEN
M9R!A=B!3+TU)344M;/9S96YO<F0`4R]-24U%('!E<G-O;FQI9W0@;GEC:V5L
M<&%R(&MRY'9E<B!SY&ME<B!F]G)B:6YD96QS92`H2%144%,I+@!0=6)L:6L@
M4R]-24U%+6YY8VME;"!F]G(@)R5S)R!R861E<F%D97,N`%!U8FQI:R!3+TU)
M344M;GEC:V5L(&QA9&5S('1I;&PN`%!U8FQI:R!N>6-K96QR:6YG(&;V<B!3
M+TU)344`4'5B;&EK="]P<FEV870@;GEC:V5L<&%R(&;V<B!3+TU)344@;&%D
M97,@=&EL;"X`4R]-24U%('-I9VYE<F$`4R]-24U%(%-I9VYE<F$O2W)Y<'1E
M<F$`4R]-24U%+7-U<'!O<G0@Y'(@879S=.1N9W0@:2!S>7-T96UE="X`365D
M9&5L86YD970@:V%N(&EN=&4@9&5K<GEP=&5R87,@<&=A(&%T="!S=/9D(&;V
M<B!3+TU)344@:6YT92#D<B!A:W1I=F5R870N`$EN;F5HY6QL970@:2!D970@
M<VEG;F5R861E(&UE9&1E;&%N9&5T(&MA;B!I;G1E('9E<FEF:65R87,@<&=A
M(&%T="!S=/9D(&;V<B!3+TU)344@:6YT92#D<B!A:W1I=F5R870N`$1E;B!D
M:6=I=&%L82!S:6=N871U<F5N(&MA;B!I;G1E('9E<FEF:65R87,@<&=A(&%T
M="!S=/9D(&;V<B!3+TU)344@:6YT92#D<B!A:W1I=F5R870N`%,O34E-12US
M=/9D970@86YVY&YD97(@<&]P=7`M9O9N<W1E<BX@3VT@9&EN('=E8F)LY'-A
M<F4@Y'(@:6YS=.1L;&0*871T(&)L;V-K97)A('!O<'5P+6;V;G-T97(@;>5S
M=&4@9'4@Y&YD<F$@9&5N(&EN<W3D;&QN:6YG96X@9O9R(&%T=`I3+TU)344M
M<W3V9&5T('-K82!F=6YG97)A`%-!4TPM875T96YT:7-E<FEN9R#D<B!I;G1E
M('1I;&QGY&YG;&EG+@!335,@;65D9&5L86YD96X`4U%,+7-K86P`4U%,+7-E
M:W9E;G,@9O9R('5P<'-L86<@878@=N1R9&5N`%-32`!,64-+050`4U]13"US
M:V%L`,1?<F5N9&4`3/8`4W!A7W)A(&MO<&EA(&D@`%-P85]R82!S;VT`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&]C:"!.979I<P!386EN="!,=6-I80!3
M86EN="U0:65R<F4@;V-H($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@;V-H($=R
M96YA9&EN97)N80!386UM82!R86T@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE(&]C:"!0<FEN8VEP90!3871T96QI=&QE=F5R86YT]G(`4V%U
M9&EA<F%B:65N`%-P87)A`%-P87)A("<E<R<`4W!A<F$@)7,`4W!A<F$@8FEL
M86=O<B!M960@;65D9&5L86YD970@:2!S96YT+6UA:6P@;6%P<&5N/P!3<&%R
M82!U=&MA<W0`4W!A<F$@8FEL9`!3<&%R82!B:6QD(&D@9V%L;&5R:0!3<&%R
M82!I;G-TY&QL;FEN9V%R`%-P87)A(&UA;&P`4W!A<F$@7W5T:V%S=`!3<&%R
M82!S;VT`4W!A<F$@=71K87-T('-O;2!O;.1S=&$_`%-P87)A(&=E;F5R97)A
M9"!K;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T('1I;&P@9&EN('-E<G9E
M<G,@('1E;7`M:V%T86QO9RX`3.1G9R!T:6QL(&UO='1A9V%R92!T:6QL(&AU
M=G5D861R97-S8F]K96X@875T;VUA=&ES:W0_`%-P87)A('/V:VYI;F<@<V]M
M(&5N('9I<G1U96QL(&9O;&1E<C\`4W!A<F$@<VMI8VMA9&4@;65D9&5L86YD
M96X_`%-P87)A9&4@:V]N9FEG=7)A=&EO;B!F]G(@)7,N`%-P87)A9&4@=7!P
M9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RX`36ES<VQY8VMA9&5S(&%T="!S
M<&%R82!U=&MA<W0N(%-E<G9E<FX@<W9A<F%D93H@)7,`4W!R:61D82#E<VMS
M:W5R87(`5F5T96YS:V%P`%/V:P!3]FL@)7,`4_9K;6]T;W)E<@!);G-TY&QL
M;FEN9V%R(&;V<B!S]FMN:6YG`%/V:W)E<W5L=&%T`%-E9&0`5N1L:@!6Y&QJ
M(&5T="!A;FYA="!K;VYT;P!6Y&QJ(&9I;&5R`%;D;&H@971T(&1A='5M`%;D
M;&H@971T(&;D;'0`5N1L:B!G<G5P<"!A='0@;.1G9V$@=&EL;`!6Y&QJ(&YY
M(.1G87)E`%;D;&H@<V5R=F5R`%;D;&H@96X@;6%L;#H`5N1L:B!A;G;D;F1A
M<F4@871T(&SD9V=A('1I;&P`5N1L:B!A9')E<W-B;VL@9O9R('1I;&SD9V<@
M;V-H('/V:VYI;F<@878@861R97-S97(N`%;D;&H@86QL80!6Y&QJ(&1A='5M
M:V]M<&]N96YT97(N`%;D;&H@9N1L="!S;VT@9V5N;VUS]FMS('9I9"!E>'!A
M;G-I;VX@878@861R97-S97(N`%;D;&H@971T(&MO;G1O`%;D;&H@971T(&]B
M:F5K=`!6Y&QJ(&EN9V5N`$%N9V4@9&4@=&5C:V5N(&1U(&)E:/9V97(@:2!R
M=71O<FYA(&YE9&%N+B!$=2!K86X@<V5D86X@:V]P:65R82!O8V@@:VQI<W1R
M82!I;B!D96T@:2!T97AT87)U=&%N+@!6Y&QJ(&%V9W+D;G-A<F4@9O9R(&1A
M='5M.@!6Y&QJ(&1A='5M9F]R;6%T.@!6Y&QJ(&=A;&QE<FD@871T('-P87)A
M(&)I;&1E;B!I+@!6Y&QJ(&ED96YT:71E="!D=2!V:6QL(.1N9')A.@!6Y&QJ
M(&4M<&]S='-E<G9E<G1Y<`!6Y&QJ(&%V9W+D;G-A<F4@9O9R('1I9#H`5N1L
M:B!T:61S9F]R;6%T.@!6Y&QJ('1VY2!M871C:&%N9&4@9N1L=#H`5N1L:B!D
M:71T(&;D<F=S8VAE;6$N`$%N9V4@9&ET="!F]G)V86QD82!S<'+E:SH`5F%L
M9&$@861R97-S8O9C:V5R.@!3:VEC:V$@;GEC:V5L('1I;&P@<'5B;&EK(&YY
M8VME;'-E<G9E<@!3:VEC:V$@<V5N87-T92!I;F9O<FUA=&EO;F5N`%-K:6-K
M80!3:VEC:V$@<')O8FQE;7)A<'!O<G0`4VMI8VMA(%--4P!3:VEC:V$@;.1S
M8F5K<N1F=&5L<V4@;N1R('/D;F1A<F5N(&)E9^1R(&1E=#\`4V5N96=A;`!3
M96YS;W(Z(`!-87!P(&;V<B!S:VEC:V%D92!M961D96QA;F1E;@!-87!P(&;V
M<B!S:VEC:V%D92!M961D96QA;F1E;CH`<V5P=&5M8F5R`%-E<F)I96X@;V-H
M($UO;G1E;F5G<F\`4V5R:65N=6UM97(`4V5R=F5R`%-E<G9E<BT@;V-H(&UA
M<'!I;F9O<FUA=&EO;@!397)V97)I;G-TY&QL;FEN9V%R(&9E;&%K=&EG82!E
M;&QE<B!I;F%K=&EV('-E<G9E<BX`4V5R=F5R.@!397-S:6]N<V%D;6EN:7-T
M<F%T:6]N`%-E<W-I;VYS+4E$(&AA<B!GY71T('5T+@!397-S:6]N97(`4^1T
M=`!+;VYF:6=U<F5R82!A;'1E<FYA=&EV('-O;2!M]FIL:6=G]G(@Y71E<G-T
MY&QL;FEN9R!A=B!B;W)T9VSV;70@;/9S96YO<F0N`$%N9V4@:6YS=.1L;&YI
M;F=A<B!F]G(@=F%D('-O;2!HY&YD97(@=FED(&9L>71T(&]C:"!R861E<FEN
M9R!A=B!M961D96QA;F1E;BX`06YG92`G6"U0<FEO<FET>2<@<G5B<FEK(&[D
M<B!M961D96QA;F1E;B!S:VEC:V%S/P!+;VYF:6=U<F5R82!F:N1R<G-E<G9R
M87(@<V]M(&1U('9I;&P@:V]M;6$@Y70@9G+E;B!D:6X@<&]R=&%L+@!!;F=E
M(&1I='0@9O9R=F%L9&$@<W!RY6LL('1I9'-Z;VX@8V]H(&1A='5M:6YS=.1L
M;&YI;F=A<BX`4^1T="!D:71T(&EN:71I86QA(&%P<&QI:V%T:6]N+"!FY')G
M<V-H96UA+"!S:61U<'!D871E<FEN9R!O8V@@86YD<F$@=FES;FEN9W-I;G-T
MY&QL;FEN9V%R+@!3971U<`!+;VYF:6=U<F%T:6]N<W5P<&=R861E<FEN9W-S
M:W)I<'0@9FEN;G,@=&EL;&?D;F=L:6=A`$1E="!F:6YN<R!F;&5R82!O<G1E
M<B!M960@<&%R86UE=&5R;CH`4V5Y8VAE;&QE<FYA`$1E;&$@;6%P<&%R`$1E
M;&$@92UP;W-T;6%P<&%R`$1E;&$@92UP;W-T;6%P<&%R(&UE9"!A;F1R82!A
M;G;D;F1A<F4N`$AA;F1E;`!+;W)T('-U;6UE<FEN9P!3:V%L;"!G96YVY&=S
M=&%N9V5N=&5R(&1E9FEN97)A<R!F]G(@9&4@9FQE<W1A(&SD;FMA<C\`4VMA
M('-T;W)A('-J;VL@878@8VET97)A9"!T97AT('9I<V%S(&5L;&5R(&?V;6UA
M<R!S;VT@<W1A;F1A<F0_"D]A=G-E='0@=FEL:V5T(&1U(';D;&IE<B#D<B!D
M970@;.1T="!A='0@Y&YD<F$N`%9I;&P@9'4@<_9K82!E9G1E<B!01U`@9&%T
M82!I('1E>'0O<&QA:6XM;65D9&5L86YD96X_`%-K86QL(&;V;G-T<F5T("=S
M:W)I=B!M961D96QA;F1E)R!S=.1N9V%S(&5F=&5R(&%T="!U=&MA<W0@:&%R
M('-P87)A=',_`%9I;&P@9'4L('-O;2!S=&%N9&%R9"P@8FEF;V=A(&1I;B!P
M=6)L:6MA(%!'4"UN>6-K96P@=&EL;"!M961D96QA;F1E;C\`5FES80!6:7-A
M(&%L;&$@;6%P<&%R`%9I<V$@86QL82!R=6)R:6ME<@!6:7-A(')A9&5R861E
M`%9I<V$@8F5G<N1N<V%D92!R=6)R:6ME<@!6:7-A(&EN9F]R;6%T:6]N(&]M
M(&UA:6QL:7-T80!6:7-A(&)A<F$@;6%P<&%R(&UE9"!P<F5N=6UE<F%T:6]N
M97(`5FES82!U;G-U8G-C<FEB960`5FES82!E;B!I:V]N(&;V<B!A='0@=&$@
M8F]R="!B:6QA9V]R(&9RY6X@;65D9&5L86YD96X_`%9I<V$@<VMI;&QN861E
M<B!M96QL86X@9&5N(&%K='5E;&QA(&]C:"!D96X@;GEL:6=E;B!S:V%P861E
M(&MO;F9I9W5R871I;VYE;BX`5FES82!S96YA<W1E(&EN;&]G9VYI;F=S=&ED
M('9I9"!I;FQO9V=N:6YG/P!6:7-A(&;V<FML87)I;F<@:2!M87!P=GEN/P!6
M:7-A(&EN<W3D;&QN:6YG(&;V<B!A='0@8F5HY6QL82!O<FEG:6YA;`!6:7-A
M('!A;&5T=`!6:7-A(&;V<FAA;F1S9W)A;G-K;FEN9V%R(&)A<F$@9O9R(&]L
MY'-T82!M961D96QA;F1E;C\`5FES82!F]G)H86YD<V=R86YS:VYI;F=A<B!I
M('9E<FMT>6=T:7!S/P!6:7-A("=T86)E;&QA:W1I=FET971E<B<@:2!M96YY
M;C\`5FES82!M96YY(&;V<B`E<R!T:6QL(';D;G-T97(_`%9I<V$@)VCD;71A
M(&UE9&1E;&%N9&5N)R!I(&UE;GEN/P!6:7-A(&%L;&$@8FEL9&5R`%1A8F5L
M;&-E;&QI;G-TY&QL;FEN9V%R`%1A8F5L;&EN<W3D;&QN:6YG87(`5&%B96QL
M:6YS=.1L;&YI;F=A<@!6:7-A(&9I;'1E<FEK;VX@:2!M96YY;C\`5FES82!D
M:6%L;V=R=71A(&;V<B!B:6QD96=E;G-K87!E<@!6:7-A(&%N=&%L(&UE9&1E
M;&%N9&5N(&D@;6%P<#\`5FES82!U<'!L861D;FEN9P!3:W5R87(`5&ED:6=A
M('-K=7)A<@!396YA('-K=7)A<@!3:W5R87(@:2!NY')H971E;@!6:7-A9&4`
M1O9R;6EN<VMA`$MR>6UP(&5L;&5R(&9L>71T82!B;W)T(&[D<FQI9V=A;F1E
M(&)L;V-K(&;V<G-T`%-T;U]R;&5K`%-I97)R82!,96]N90!296=I<W1R97)A
M`%-I9VYA='5R`%-I9VYA='5R86QG;W)I=&T`4VEG;F5R870`4VEM<&QE>`!3
M:6YG87!O<F4`4W1O<FQE:P!!=F)R>70@=6YD97)HY6QL`%-L;W9A:VEE;@!3
M;&]V96YI96X`4V[V`%-N]G-K=7(`4V[V<VMU<F%R`%1I9&EG82!S;O9S:W5R
M87(`4V5N82!S;O9S:W5R87(`4V[V9&IU<#H@`$UO='-V87)A;F1E('-N]B!I
M('9A='1E;CH@`%-A;&]M;V[V87)N80!3;VUA;&EA`%/E;F=E<B!O8V@@9&EK
M=&5R`%-O<G1E<F$@<.4@86YK;VUS=`!3;W)T97)A('#E(&1A='5M`%-O<G1E
M<F$@<.4@861R97-S`%-O<G1E<F$@<.4@<W1O<FQE:P!3;W)T97)A('#E(.1R
M96YD90!3;W)T97)A('#E('1RY60`4V]R=&5R82!PY2!A9')E<W,`4V]R=&5R
M:6YG<VEO<F1N:6YG<W9A;`!KY&QL861R97-S`%-Y9&%F<FEK80!3]F1R82!'
M96]R9VEA(&]C:"!3>7-S86YD=VEC:/9A<FYA`%/D9')A(&AE;6ES9N1R96X`
M571R>6UM92!M96QL86X@:6YT:6QL:6=G86YD92!C96QL97(`571R>6UM92!M
M96QL86X@:6YN96CE;&P@;V-H(&MA;G1E;B!I(&-E;&QE;@!-96QL86YR=6T`
M365L;&%N<G5M`$UE;&QA;G)U;2!O8V@@=71JY&UN:6YG`%-P86YI96X`4W!A
M;0!-87!P(&;V<B!S:W+D<'!O<W0Z`$EN;6%T;FEN9R!A=B!S<&5C:65L;&$@
M=&5C:V5N`%-P96-I86QT96-K96X`5FER='5E;&QA(&UA<'!A<B!S;VT@Y'(@
M<W!C:65L;&$@:V%N(&EN=&4@Y&YD<F%S+@!3=&%V;FEN9W-K;VYT<F]L;`!3
M=&%V;FEN9W-K;VYT<F]L;`!3=&%V;FEN9W-K;VYT<F]L;"!K;&%R`$%N=&%L
M('-T879F96P@<&5R('-KY')M('9I9"!S=&%V;FEN9W-K;VYT<F]L;"X`1&5L
M82!C96QL`$1E;&$@:V]L=6UN`$1E;&$@<F%D`%-P;W)T97(`4W)I($QA;FMA
M`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R=.5R`%-T870@96QL97(@
M<F5G:6]N`$UA;&P`36%L;&5N<R!N86UN.@!-86QL='EP.@!-86QL.@!3=&%T
M=7,`3&%G<FEN9W-F;W)M870`1V%T=6%D<F5S<P!'96YO;7-T<G5K96X`4W1R
MY&YG;&ES=&$`5&$@8F]R="!B:6QA9V$`5&$@8F]R="!D;VWD;B!F<N5N(&%D
M<F5S<V5N`%1A(&)O<G0@<F%D8G)Y=&YI;F=A<C\`4W1I;"!;0U-370!3]@#$
M7W)E;F1E`$MA;B!I;G1E(&AI='1A('5N9&5R:V%T86QO9R`G)7,G+@#$<F5N
M9&4`Q')E;F1E9N1L=`!3:VEC:V$`1&EN(&)E9^1R86X@871T(&SD9V=A('1I
M;&P@(B5S(B!T:6QL('-Y<W1E;65T(&AA<B!S:VEC:V%T<RX@1'4@:V%N(&EN
M=&4@;&]G9V$@:6X@:6YN86X@9&EN(&)E9^1R86X@:&%R(&%C8V5P=&5R871S
M+@!0<F5N=6UE<F5R82!PY2!M87!P*&%R*0!.961SY&YK=`!,>6-K870`)R5S
M)R!L861E<R!T:6QL(&D@<WES=&5M970N`%)A9&5R861E(&EN9F]R;6%T:6]N
M(&]M(&%N=N1N9&%R92`G)7,G+@`G)7,G(')A9&5R861E<RX`)R5S)R!T;V=S
M(&)O<G0@9G+E;B!S>7-T96UE="X`2V]N9FEG=7)A=&EO;F5N(&AA<B#E=&5R
M<W3D;&QT<RX@3&%D9&$@;VT@<VED86X@9O9R(&%T="!S92!F]G+D;F1R:6YG
M87(N`%-P87)A9&4@8F%C:W5P:V]N9FEG=7)A=&EO;BX`4W!A<F%D92!B86-K
M=7!K;VYF:6=U<F%T:6]N("5S+@`G)7,G('5P<&1A=&5R861E<RX`4VMR978@
M)7,`4W5D86X`1O9R<VQA9P!386UM86YS=.1L;&YI;F<`4V]L=7!P9^5N9P!3
M;VQN961GY6YG`%-O;&EG=`!3;VQU<'!GY6YG`%-O;'5P<&?E;F<O;F5D9^5N
M9P!3;VQU<'!GY6YG.B``4V]L;F5D9^5N9P!3;VQN961GY6YG.B``57!P:/9J
M9`!3=7!P;W)T`%-U<FEN86UE`$5F=&5R;F%M;@!3=F%L8F%R9"!O8V@@2F%N
M($UA>65N`%-W87II;&%N9`!3=F5R:6=E`$)Y="!S:W)I=FSD9V4`0GET('1I
M;&P@2%1-3"ULY&=E`$)Y="!T:6QL('1E>'1LY&=E`%-C:'=E:7H`4WEK<F]N
M:7-E<FEN9W-L;V=G(')A9&5R860`4WEN8TU,`%-Y;G1A>&9E;"!I('/V:VMR
M:71E<FEA`%-Y<FEE;@#%<VMS:W5R`,5S:W-K=7)A<B!O8V@@8FSE<VEG=`#%
M<VMS:W5R87(`5&ED:6=A(.5S:W-K=7)A<@!44U8M9FEL`%1A8F5L;`!486)E
M;&QI;G-TY&QL;FEN9V%R`%1A8F5L;'5P<'/D='1N:6YG`%1A8F5L;&EN<W3D
M;&QN:6YG87(`5&%I=V%N`%1A:7=A;@!486II:VES=&%N`%1A;GIA;FEA`$WE
M;#H`57!P9VEF=&5R`%1E7WAT`%1E86P`5&5L969O;FYU;6UE<@!(]F=S=&$@
M=&5M<&5R871U<B!S96YA<W1E('1I;6UE;CH@`%1E;7!E<F%T=7(`5&5M<&5R
M871U<CH@`%1E;7!E<F%T=7(\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G
M.R5S`$MA;B!I;G1E(&AI='1A(&UA;&P@)7,N`$%N=N1N9&%R861M:6YI<W1R
M871I;VX`4')E;&EM:6[D<G0Z(`!';V1KY&YN(&)E9^1R86X@<')E;&EM:6[D
M<G0`4')E;&EM:6[D<G0@86-C97!T97)A=`!&:6P@;65D(&%V=&%L<W9I;&QK
M;W(@Y'(@:6YT92!A;F=I=F5N(&D@8V]N9BYP:'``5&5?>'0`16YB87)T('1E
M>'0`5&5X=&IU<W1E<FEN9P!497AT=&]P`%1O`%1H86D@*%1)4RTV,C`I`%1H
M86EL86YD`%1A8VL@9O9R(&%T="!D=2!A;G;D;F1E<B!S>7-T96UE="X`3.1N
M:V5N("5S('1I;&P@)7,@:&%R(')A9&5R871S+@!&5%`M=&EL;.1G9V5T(.1R
M(&EN=&4@=&EL;&?D;F=L:6=T+@!6860@<VMA;&P@(D9RY6XB+6MO;'5M;F5N
M(&%V(&UE9&1E;&%N9&5T(&SD;FMA('1I;&PZ`$AI<W1O<FEK<WES=&5M970@
MY'(@879A:W1I=F5R870N`$AO<F1E+TMO;&%B+6EN=&5G<F%T:6]N<V=RY&YS
M<VYI='1E="!S=/9D97(@:6YT92`B)7,B`$E-05`M<V5R=F5R;B!V97)K87(@
M:6YT92!S=/9J9&$@9&5N('9A;&1A(&%U=&5N=&ES97)I;F=S;65T;V1E;BX@
M5F%R(&=O9"!K;VYT86MT82!S>7-T96UA9&UI;FES=')A=/9R96XN`$E-4U`M
M;&]G9V5N(&MU;F1E(&EN=&4@:6YI=&EE<F%S+@!-86-I;G1O<V@@<F5S=7)S
M+7-T<O9M;65N`$UA8VEN=&]S:"!R97-U<G,M<W1R]FUM96X@:V%N(&QA9&1A
M<R!N97(@)7,N`$ML87-S96X@36%I;G1E;F%N8V4Z.B!K=6YD92!I;G1E(&QA
M9&1A<P!);G-TY&QL;FEN9W-F]FYS=')E="!H87(@<W3D;F=T<RX@079S;'5T
M87(N`$MO;G1O="`G)7,G(')A9&5R861E<RX`2V]N=&]T("<E<R<@<W!A<F%D
M97,N`$%D;6EN:7-T<F%T]G)E;B!MY7-T92!K;VYF:6=U<F5R82!E;B!P97)M
M86YE;G0@0F5H]G)I9VAE=',M:V]P<&QI;F<@;VT@9'4@=FEL;"!A;G;D;F1A
M($)E:/9R:6=H971E<BX`0FEL86=O<B!S86MN87,N`$5N8F%R="!N961R92!S
M:61A;@!+86QE;F1E<FEN9F]R;6%T:6]N96X@Y'(@9F5L86MT:6<`2V%N(&EN
M=&4@]G!P;F$@9O9N<W1R970@871T('-K<FEV82!M961D96QA;F1E;B!I+"!K
M86YS:V4@:&%R(&1U('-TY&QL="!I;B!D:6X@=V5B8FSD<V%R92!A='0@8FQO
M8VME<F$@<&]P=7`M9O9N<W1E<C\`2V]N=&%K=&5N<R!)1"!A;F=A=G,@:6YT
M92!E;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I(&1A=&%B87-E;BX`2V]N=&%K
M=&5N(&QA9&5S('1I;&P@:2!A9')E<W-B;VME;BX`26YN96CE;&QE="!I($UA
M8VEN=&]S:"UF:6QE;B#E=&5R9FEN;G,@;F5D86XN`$YA;6YE="!PY2!N=79A
M<F%N9&4@;6%P<"AA<BD@)R5S)R!K;VUM97(@871T(&)Y=&%S('1I;&P@)R5S
M)RX`2W5N9&4@:6YT92!HY&UT82!L:7-T86X@<.4@86YVY&YD87)E(&UE9"!T
M:6QL9^5N9R!T:6QL(&1E;FYA(&UA<'``1&5N(&SV<V=J;W)D82!01U`M<VEG
M;F%T=7)E;B!K<N1V<R!F]G(@871T('9E<FEF:65R82!D970@<VEG;F5R861E
M(&UE9&1E;&%N9&5T+@!$:7-T<FEB=71I;VYS;&ES=&%N<R!)1"!A;F=A=G,@
M:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I(&1A=&%B87-E;BX`1&ES
M=')I8G5T:6]N<VQI<W1A;B!H87(@:6YT92!A;F=I=FET<RX`571K87-T970@
M:&%R('-P87)A=',@:2!M87!P96X@(B5S(BX`2W)Y<'1E<FEN9W-F=6YK=&EO
M;F5R;F$@:W+D=F5R(&5N('/D:V5R('=E8F;V<F)I;F1E;'-E("A(5%104RDN
M`$CD;F1E;'-E;B!L861E<R!T:6QL(&D@:V%L96YD97)N+@!(Y&YD96QS96X@
M:&%R(&QA9W1S('1I;&P@:2!D:6X@:V%L96YD97(N`$;D;'1E="`G)7,G(&MA
M;B!I;G1E(&5X<&%N9&5R87,N`$9I;&5N("5S('-K86QL(&EN;F5HY6QL82!E
M;B!I;G-TY&QL;FEN9R!F]G(@)7,N`$9I;&5N("5S('-K86QL(&EN;F5HY6QL
M82!I;G-TY&QL;FEN9V%R(&;V<B`E<RX`1FEL96X@:V%N(&EN=&4@:V]P:65R
M87,@=&EL;"!S:6<@<VKD;'8N`$9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I
M;&P@<VEG('-JY&QV+@!&:6QE;B!I;FYE:/9L;"!I;F=E;B!I;F9O<FUA=&EO
M;BX`36%P<&5N("<E<R<@9FEN;G,@<F5D86X`3F%M;F5T('#E(&UA<'!E;B`G
M)7,G(&EN;F5HY6QL97(@9F5L86MT:6=A('1E8VME;B!S;VT@:V%N(&UE9&;V
M<F$@<')O8FQE;2X@5F%R(&=O9"!K;VYT86MT82!D:6X@<WES=&5M861M:6YI
M<W1R873V<BX`36%P<&5N("<E<R<@<VMA<&%D97,@;65N(&1U(&+V<FIA9&4@
M:6YT92!P<F5N=6UE<F5R82!PY2!D96XN`$UA<'!E;B`G)7,G(')A9&5R861E
M<R!M96X@9&EN('!R96YU;65R871I;VX@<.4@;6%P<&5N('1O9W,@:6YT92!B
M;W)T+@!-87!P96X@)R5S)R!S:V%P861E<R!I;G1E+B!397)V97)N('-V87)A
M9&4`36%P<&5N("<E<R<@<F%D97)A9&5S(&EN=&4N(%-E<G9E<FX@<W9A<F%D
M90!-87!P96X@)R5S)R!S:V%P861E<RX`36%P<&5N("<E<R<@<F%D97)A9&5S
M+@!.86UN970@<.4@;6%P<&5N("<E<R<@Y&YD<F%D97,@=&EL;"`G)7,G`$AU
M=G5D9N1L="!F]G(@9&5T=&$@;65D9&5L86YD92]R9F,X,C)M961D96QA;F1E
M(&;V;&IE<@!&]FQJ86YD92!F:6QE<B!V87(@8FEF;V=A9&4@9&5N(&CD<B!D
M96QE;CH`261E;G1I=&5T96X@)R5S)R!R861E<F%D97,N`$MA;B!I;G1E(/9P
M<&YA(&;V;G-T<F5T(&%T="!S<&%R82!B:6QD97(@:2P@:V%N<VME(&AA<B!D
M=2!S=.1L;'0@:6X@9&EN('=E8F)LY'-A<F4@871T(&)L;V-K97)A('!O<'5P
M+6;V;G-T97(_`%9I<V%R(&)I;&1E<B!DY2!A=G/D;F1A<F5N(&9I;FYS(&D@
M9&EN(&%D<F5S<V)O:RX`0F%R82!VY&YS=&5R('-I9&$`3.1N:V5N(&AA<B!T
M86=I=',@8F]R=`!3]FMVY&=E;B!T:6QL($=N=5!'+7!R;V=R86UM970@;>5S
M=&4@=F%R82!A;F=I=F5N('1I;&P@:VQA<W-E;B!#<GEP=%]P9W`Z.BX`12UP
M;W-T<V5R=F5R;B!G878@9O9L:F%N9&4@9F5L;65D9&5L86YD93H`12UP;W-T
M<V5R=F5R;B!G878@9O9L:F%N9&4@:6YF;W)M871I;VYS;65D9&5L86YD93H`
M12UP;W-T<V5R=F5R;B!G878@9O9L:F%N9&4@;65D9&5L86YD93H`36%P<&5N
M("<E<R<@Y'(@<F5D86X@=&]M+@!-961D96QA;F1E="!F<N5N("(E<R(@=&EL
M;"`B)7,B("@E9"!B>71E<RD@]G9E<G-K<FED97(@;6%X<W1O<FQE:V5N"F;V
M<B!M961D96QA;F1E;B!S;VT@:.1M=&%S+@!-961D96QA;F1E="!S;VT@<VMR
M:79S(&AA<B!S=.1N9W1S+B!!=G-L=71A<BX`365D9&5L86YD970@:&%R('-A
M:VYA<B!I;FYE:.5L;"!I(.1R96YD97)A9&5N+@!-961D96QA;F1E="!H87(@
M<F%D97)A=',N`$UE9&1E;&%N9&5T(&AA<B!V97)I9FEE<F%T<RX`365D9&5L
M86YD970@:&%R('9E<FEF:65R871S+B!!=G/D;F1A<F4Z("5S`$UE9&1E;&%N
M9&5T('-K:6-K870@)7,@=&EL;"`E<R!M960@Y')E;F1E("(E<R(@:&%R('9I
M<V%T<RX*1&5T=&$@Y'(@:6YG96X@9V%R86YT:2!F]G(@871T(&UE9&1E;&%N
M9&5T(&AA<B!LY'-T<RX`3F%M;F5T('-O;2!S:V%L;"!A;G;D;F1A<R!F]G(@
M871T(&SD;FMA('1I;&P@<VMA<&$M<VED86X`06YT86P@9N1L="!MY7-T92!V
M87)A(&5T="!N=6UE<FES:W0@=N1R9&4N`$UO9'5L96X@;W!E;G-S;"!K<N1V
M<R!A=B!K;&%S<V5N($AO<F1E7T-R>7!T7W-M:6UE.CHN`$MA;B!I;G1E(/9P
M<&YA(&;V;G-T<F5T(&;V<B!A='0@9G+E9V$@969T97(@;/9S96YF<F%S+B!+
M86YS:V4@:&%R(&1U('-TY&QL=`II;B!D:6X@=V5B8FSD<V%R92!A='0@8FQO
M8VME<F$@<&]P=7`M9O9N<W1E<C\`26YS=.1L;&YI;F=E;B`B)7,B(&MU;F1E
M(&EN=&4@<W!A<F%S('#E(&=R=6YD(&%V(&%T="!D871A;>1N9V1E;B#V=F5R
M<VMR:79E<B!D96X@;6%X:6UA;'0@=&EL;.5T;F$`4')O9W)A;6UE="!S;VT@
M86YVY&YD<R!F]G(@871T('9I<V$@9&5N(&CD<B!M961D96QA;F1E='EP96X@
M*"5S*2!S86MN87,@<.4@<WES=&5M970N`%1E8VMN970@9O9R(&-I=&5R:6YG
M(&WE<W1E('9A<F$@971T('1E8VME;BX`4N5T97AT96X@9O9R(%!'4"UN>6-K
M96QN('9I<V%S("5S+@!$96X@8F5GY')D82!F:6QE;B!F:6YN<R!I;G1E(&D@
M35,M5$Y%1BUB:6QA9V%N+@!$96X@8F5GY')D82!F:6QE;B!F:6YN<R!I;G1E
M(&D@+GII<"UB:6QA9V%N+@!"87)A(&CV9V5R(&]C:"!VY&YS=&5R('-I9&]R
M`$)A<F$@:/9G97(@<VED80!!=G/D;F1A<F5N(&)E9^1R(&QE=F5R86YS8F5K
M<N1F=&5L<V4@878@9&EG(&[D<B!D=2!LY'-T(&1E='1A"FUE9&1E;&%N9&4N
M($ML:6-K82`E<R!F]G(@871T('-K:6-K82!L979E<F%N<V)E:W+D9G1E;'-E
M+@!397!A<F%T;W)N(&WE<W1E('9A<F$@971T('1E8VME;BX`4V5R=F5R("<E
M<R<@<F%D97)A9&5S+@!397)V97(@)R5S)R!S<&%R861E<RX`4V5R=F5R;B!K
M=6YD92!I;G1A('-K87!A(&5N(&UI;FEA='ER8FEL9"!F]G(@8FEL9&5N+@!+
M=6YD92!I;G1E(&)Y=&$@=70@<VEG;F%T=7)E;BX`4VEG;F%T=7)E;B!H87(@
M97)S871T<RX`4')E;G5M97)A=&EO;G-B96?D<F%N(&;V<B`E<R!H87(@=&%G
M:71S(&)O<G0N`$%N9VEV96X@9FEL(&9I;FYS(&EN=&4N`$%N9VEV96X@<F%D
M("@E9"D@9FEN;G,@:6YT92X`06YG:79E;B!R860@97AI<W1E<F%R(&EN=&4N
M`$UA;&QE;B`G)7,G(&QA9&5S('1I;&PN`$UA;&QE;B`G)7,G(')A9&5R861E
M<RX`36%L;&5N("<E<R<@:&%R('5P<&1A=&5R871S+@!5<'!G:69T96X@:&%R
M(&QA9W1S('1I;&P@:2!D:6X@=7!P9VEF='-L:7-T82X`5&5M<&]RY'(@9FEL
M("<E<R<@9FEN;G,@:6YT92X`5&5X=&5N(&;V<B!M961D96QA;F1E=`!497AT
M96X@9O9R(&UE9&1E;&%N9&5T(&MA;B!V:7-A<R`E<RX`5&5X=&5N(&;V<B!D
M970@<F5T=7)N97)A9&4@;65D9&5L86YD970N`%1E>'1E;B!F]G(@9&5T(')E
M='5R;F5R861E(&UE9&1E;&%N9&5T(&MA;B!V:7-A<R`E<RX`5&5X=&5N(&;V
M<B!D970@<VMI8VMA9&4@;65D9&5L86YD970N`%1E>'1E;B!F]G(@9&5T('-K
M:6-K861E(&UE9&1E;&%N9&5T(&MA;B!V:7-A<R`E<RX`5&5X=&5N(&1U(&UA
M=&%T(&EN('-TY&UM97(@:6YT92#V=F5R96YS(&UE9"!T97AT96X@<.4@<VOD
M<FUE;@!"87)A('1O<'`@;V-H(&)O='1E;B!S:61A`$)A<F$@=&]P<'-I9&$`
M57!P;&%D9&%T(&1A=&$@9O9R<W9A;FX@<V5D86X@9O9R96?E96YD92!S=&5G
M+@!$96X@=7!P;&%D9&%D92!F:6QE;B!K=6YD92!I;G1E('-P87)A<RX`3&5D
M:6<O=7!P=&%G96XM:6YF;W)M871I;VX@9O9R(&%N=N1N9&%R96X@:&%R('-P
M87)A=',N`%=E871H97(N8V]M+6)L;V-K970@Y'(@:6YT92!T:6QL9^1N9VQI
M9W0N`%1E;6%K871A;&]G("<E<R<@9FEN;G,@:6YT92X`1&5T(&9I;FYS(&EN
M9V$@86QT97)N871I=F$@9&5L87,@<V]M(&MA;B!V:7-A<R!I;FQI;F4N`$1E
M="!F:6YN<R!I;F=A(&UE9&1E;&%N9&5N(&D@9&5N(&CD<B!M87!P96XN`$EN
M9V$@:6YS=.1L;&YI;F=A<B!T:6QL9^1N9VQI9V$N`$1E="!F:6YN<R!I;F=A
M(&%L=&5R;F%T:79A(&1E;&%R('-O;2!K86X@=FES87,@:6YL:6YE+@!&]G(@
M;>5N9V$@=&5C:V5N(&D@9N1L=&5T+B!$=2!H87(@86YG971T("5S('1E8VME
M;CL@;6%X:6UA;'0@86YT86P@=&5C:V5N(.1R("5S+@!$970@9FEN;G,@:6YG
M96X@=&5X="!S;VT@:V%N('9I<V%S(&EN;&EN92X`4')O8FQE;2!M960@871T
M(&SD9V=A('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T.B`E<P!0<F]B;&5M(&UE
M9"!A='0@<F5N<V$@:6YF;W)M871I;VX@;VT@86YVY&YD87)E("<E<R<@9G+E
M;B!S>7-T96UE=#H@`%!R;V)L96T@=FED(')A9&5R:6YG(&%V(&EN;F5HY6QL
M970@:2!M87!P96XN(%-E<G9E<FX@<W9A<F%D93H@)7,`4')O8FQE;2!M960@
M871T('1A(&)O<G0@)R5S)R!F<N5N('-Y<W1E;65T.B``4')O8FQE;2!V:60@
M=7!P9&%T97)I;F<@878@)R5S)SH@)7,`4')O8FQE;2!V:60@=7!P;&%D9&YI
M;F<@878@9FEL96XN($EN9V$@)7,@;&%D9&%D97,@=7!P+@!$970@=7!P<W1O
M9"!P<F]B;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;CH@)7,@Y'(@<W3V
M<G)E(.1N(&UA>&EM86QT('1I;&SE=&5N('-T;W)L96L@*"5D(&)Y=&5S*2X`
M1&5T('5P<'-T;V0@<')O8FQE;2!V:60@=7!P;&%D9&YI;F<@878@9FEL96XZ
M("5S(&QA9&1A9&5S(&5N8F%R="!U<'`@9&5L=FES+@!$970@=7!P<W1O9"!P
M<F]B;&5M('9I9"!K;W!I97)I;F<@878@;65D9&5L86YD96X@=&EL;"`G)7,G
M('1I;&P@)R5S)RX@4V5R=F5R;B!S=F%R861E`$1E="!U<'!S=&]D('!R;V)L
M96T@=FED(')A9&5R:6YG(&%V(&UE9&1E;&%N9&5N(&9RY6X@;6%P<&5N("<E
M<R<N(%-E<G9E<FX@<W9A<F%D90!$970@=7!P<W1O9"!P<F]B;&5M('9I9"!R
M861E<FEN9R!A=B!M961D96QA;F1E;B!F<N5N(&UA<'!E;B`G)7,G+B!397)V
M97)N('-V87)A9&4`1&5T('5P<'-T;V0@<')O8FQE;2!V:60@<F%D97)I;F<@
M878@;65D9&5L86YD96XN(%-E<G9E<FX@<W9A<F%D92`E<P!$970@=7!P<W1O
M9"!E='0@9F5L('9I9"!R861E<FEN9R!A=B!HY&YD96QS93H@)7,`1&5T('5P
M<'-T;V0@971T(&9E;"!V:60@=FES;FEN9R!A=B!M961D96QA;F1E9&5L96XN
M`$1E="!U<'!S=&]D('!R;V)L96T@=FED(&WD<FMN:6YG(&%V(&UE9&1E;&%N
M9&5N(&D@;6%P<&5N("<E<R<N(%-E<G9E<FX@<W9A<F%D90!$970@=7!P<W1O
M9"!E='0@9F5L('9I9"!I;7!O<G0Z("5S`$9E;"!V:60@:6UP;W)T(&%V(&MO
M;G1A:W1D871A+@!&96P@=FED(&EM<&]R="!A=B!HY&YD96QS96XZ("5S+@!&
M96P@=FED(&EM<&]R="!A=B!I0V%L96YD87(@9&%T82X`1F5L('9I9"!I;7!O
M<G0@878@=7!P9VEF=&5N.B`E<RX`1F5L('9I9"!I;7!O<G0@878@:6YF;W)M
M871I;VX@;VT@;&5D:6<O=7!P=&%G96XZ("5S+@!%='0@9F5L('#E='+D9F9A
M9&5S(&D@9F]R;75LY')E="X@2V]N=')O;&QE<F$@871T(&1U(&EN=&4@9VSV
M;70@9GEL;&$@:2!E='0@;V)L:6=A=&]R:7-K="!FY&QT+@!$970@=7!P<W1O
M9"!P<F]B;&5M('9I9"!F;'ET="!A=B!M961D96QA;F1E;B!T:6QL("<E<R<@
M=&EL;"`G)7,G+B!397)V97)N('-V87)A9&4`1&5T(&=I8VL@:6YT92!A='0@
M=71F]G)A(&1E;B!B96?D<F1A(&%D<F5S<V)O:W-F=6YK=&EO;F5N+B!687(@
M9V]D(&;V<G/V:R!S96YA<F4N`$1E="!U<'!S=&]D(&5T="!F96P@;N1R(&UE
M9&1E;&%D970@<VMU;&QE('-P87)A<R!S;VT@=71K87-T+@!$970@=7!P<W1O
M9"!E='0@9F5L(&[D<B!D:71T(&UE9&1E;&%N9&4@<VMI8VMA9&5S.B`E<P!&
M96P@=FED('5P<&1A=&5R:6YG(&%V(&MO;G1A:W1U<'!G:69T97(N($;V<G/V
M:R!I9V5N('-E;F%R92X`1F5L('9I9"!U<'!D871E<FEN9R!A=B!D:7-T<FEB
M=71I;VYS;&ES=&%N+B!&]G)S]FL@:6=E;B!S96YA<F4N`$1E="!U<'!S=&]D
M(&5T="!F96P@=FED(#-U<'!D871E<FEN9R!A=B!HY&YD96QS96XZ("5S`$EN
M9V5N('1E>'0@:2!D96X@:.1R(&UE9&1E;&%N9&5D96QE;@!(5$U,+6UE9&1E
M;&%N9&5T(&AA<B!I;F+D9&1A9&4@8FEL9&5R+@!$971T82!(5$U,+6UE9&1E
M;&%N9&4@:&%R(&EN8N1D9&%D92!B:6QD97(N($)L;V-K97)A9&4@8FEL9&5R
M('9I<V%S('/E(&CD<CH`1&EN($E-05`M<V5R=F5R('-T]F1E<B!I;G1E(&1E
M;&%D92!M87!P87(N`$1E;B!HY'(@<'5B;&EK82!01U`M;GEC:V5L;B!V87(@
M8FEF;V=A="!T:6QL(&UE9&1E;&%N9&5T+@!$96YN82!H86YD;&EN9R!S=/9D
M<R!I;G1E+@!(86YD;&EN9V5N(.1R(&EN=&4@:6UP;&5M96YT97)A9"#D;FYU
M+@!&:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%)!4BUA<FMI
M=BX`1FEL96X@=F5R:V%R(&EN=&4@=F%R82!E='0@9VEL=&EG="!:25`M87)K
M:78N`$9E;&%K=&EG="!K;W)T;G5M;65R+@!$96YN82!D<FEV<G5T:6X@9_9R
M(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA($-L:6-K
M871E;&PM8G)Y9V=A;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G96YO;2!A
M='0@86YVY&YD82!(5%10($%023IT+@!$96YN82!D<FEV<G5T:6X@9_9R(&1E
M="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA(%=)3BUB<GEG
M9V%N("AH='1P.B\O=VEN<&QC+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%14
M4"!!4$DZ=`!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S
M:VEC:V$@;65D9&5L86YD96X@=FEA('-M<S)E;6%I;"UB<GEG9V%N("AH='1P
M.B\O<VUS,F5M86EL+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%144"!!4$DZ
M=`!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@
M;65D9&5L86YD96X@=FEA(%--5%`@9V5N;VT@5F]D869O;F4@271A;&EE;BUB
M<GEG9V%N("AE;F)A<G0@=&EL;"!6;V1A9F]N;G5M;65R*2X@1')I=G)U=&EN
M96X@:W+D=F5R(&5T="!E+7!O<W1K;VYT;R!H;W,@5F]D869O;F4@271A;&EE
M;B`H:'1T<#HO+W=W=RXQ.3`N:70I+@!&Y&QT970@;>5S=&4@=F%R82!I9GEL
M;'0N`$;D;'1E="!FY7(@96YB87)T(&EN;F5HY6QL82!H96QT86PN`$;D;'1E
M="!FY7(@96YB87)T(&EN;F5HY6QL82!S:69F<F]R(&]C:"!K;VQO;BX`1N1L
M=&5T(&;E<B!E;F)A<G0@:6YN96CE;&QA(&]K=&%L82!T86PN`$;D;'1E="!S
M:V%L;"!V87)A(&5N(&MO;6UA+2!E;&QE<B!M96QL86YS;&%G<W-E<&%R87)A
M9"!L:7-T82!M960@:&5L=&%L`$;D;'1E="!MY7-T92!V87)A(&5T="!G;V1K
MY&YT('1A;"X`1&5T=&$@9N1L="!MY7-T92!I;FYE:.5L;&$@96X@4D="+6;D
M<F=K;V0@:2!H97AA9&5C:6UA;'0@9F]R;6%T+"!T(&5X("<C,3(S-&%F)RX`
M1&5T=&$@9F]R;75LY'(@:&%R(')E9&%N(&)E87)B971A=',N`$1E="!HY'(@
MY'(@)7,N`$1E="!K86X@=&$@;&ET92!T:60L(.1R(&1U('/D:V5R('#E(&%T
M="!D=2!V:6QL(&9O<G1SY'1T83\`1&5T=&$@;65D9&5L86YD92!I;FYE:.5L
M;&5R(&5N($UA8VEN=&]S:"UF:6PN`$UE9&1E;&%N9&5T(&EN;F5HY6QL97(@
M96X@8FEL86=A('-O;2!H87(@<VEG;F5R871S('9I82!3+TU)344N`$UE9&1E
M;&%N9&5T(&EN;F5HY6QL97(@96X@8FEL86=A('-O;2!H87(@:W)Y<'1E<F%T
M<R!V:6$@4R]-24U%+@!$971T82!M961D96QA;F1E(&EN;F5HY6QL97(@;&5V
M97)A;G-I;F9O<FUA=&EO;B!O;2!E+7!O<W0L(&UE;@IF;W)M871E="!PY2!M
M961D96QA;F1E="#D<B!O:^1N="X`1&5T(&CD<B!M961D96QA;F1E="!V97)K
M87(@:6YT92!H82!E='0@<FEK=&EG="!01U`M9F]M870N($9E;#H@`$1E="!H
MY'(@;65D9&5L86YD970@=F5R:V%R(&EN=&4@:&$@971T(')I:W1I9W0@4$=0
M+69O<FUA="`H96YL:6=T(%)&0R`R,#$U*2X`1&5T(&CD<B!M961D96QA;F1E
M="!V97)K87(@:6YT92!H82!E='0@<FEK=&EG="!3+TU)344M9F]M870N`$UE
M9&1E;&%N9&5T(&AA<B!S:6=N97)A=',@=FEA(%!'4"X`365D9&5L86YD970@
M:&%R('-I9VYE<F%T<R!V:6$@4R]-24U%+@!-961D96QA;F1E="!H87(@:W)Y
M<'1E<F%T<R!V:6$@4R]-24U%+@!-961D96QA;F1E="!H87(@:W)Y<'1E<F%T
M<R!V:6$@4$=0+@!-961D96QA;F1E="!T:6QL`$UE9&1E;&%N9&5T('-K<F5V
M<R!I(&5N(&%N;F%N('1E8VME;G5P<'/D='1N:6YG("@E<RD@Y&X@9&EN(&5G
M96XN`$1E="!HY'(@;G5M<F5T(&WE<W1E('9A<F$@;6EN<W0@971T+@!397)V
M97)N(&MA;B!I;G1E('!A8VMA('5P<"!Z:7`@;V-H(&=Z:7`@9FEL97(N`$1E
M;FYA('-E<G9E<B!S=/9D97(@:6YT92!D96QA9&4@;6%P<&%R+@!3>7-T96UE
M="#D<B!F]G(@=&EL;&;D;&QE="!A=F%K=&EV97)A="X`1&5T(&CD<B!VY')D
M970@;>5S=&4@=F%R82!N=6UE<FES:W0N`$1E='1A(&;V;G-T97(@:V%N(&)A
M<F$@]G!P;F%S(&9RY6X@971T(&;V;G-T97(@9O9R(&%T="!S:W)I=F$@;65D
M9&5L86YD96XN`$1E='1A(&;V;G-T97(@;>5S=&4@86YR;W!A<R!F<N5N(&5T
M="!K;VYF:6=U<F%T:6]N<V;V;G-T97(`5'+E9'9I<VYI;F<`5'+E9'9Y`,5S
M:V$`Q')E;F1E;@!4:60`5&ED<W)E9&]V:7-N:6YG`%1I9'-F;W)M870`5&ED
M<W9A;`#6<W1T:6UO<@!2=6)R:6L`4G5B<FEK("AT;V]L=&EP*3H`5&EL;`!4
M:6QL(&%D<F5S<P!&]G(@871T(';D;&IA(&9L97)A(&;D;'0L(&CE;&P@;F5R
M92!#;VYT<F]L("APY2!00RD@96QL97(@0V]M;6%N9"`H<.4*36%C*2!O8V@@
M:VQI8VMA+@!&]G(@871T(&UA<FME<F$@9FQE<F$@=F%L+"!HY6QL(&YE9"!#
M=')L("A00RD@96QL97(@0V]M;6%N9"`H36%C*2!T86YG96YT96X@;N1R(&1U
M(&ML:6-K87(N`$;V<B!A='0@86YVY&YD82!43%,M86YS;'5T;FEN9RP@<^4@
M;>5S=&4@9'4@86YVY&YD82!02%`@-2XQ+C`@96QL97(@<V5N87)E+@!)9&%G
M`%9I<V$@2%1-3"UKY&QL80!4;V=O`%1O:V5L874`26UO<F=O;@!4;VYG80!4
M;W``5&]P(&9R86UE("A?=&]P*0!3=&]R;&5K('#E(&)I;&%G;W(Z`-9V97)S
MY'1T;FEN9V%R`%!A<'!E<G-K;W)G`%!A<'!E<G-K;W)G`%1R:6YI9&%D(&]C
M:"!4;V)A9V\`4V%N="!E;&QE<B!F86QS:W0`5&D`5'5N:7-I96X`5'5R:VEE
M=`!4=7)K:7-K("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,M(&]C
M:"!#86EC;W/V87)N80!4=79A;'4`06YG92!D:71T('9A;#H@`%56+6EN9&5X
M.B``55),`%523"!F]G(@9&ET="!L979E<F%N<W)A<'!O<G1E<FEN9W-S:W)I
M<'0`55),.@!59V%N9&$`56MR86EN80!+86X@:6YT92!LY'-A(%9&4RUM87!P
M+@!$970@9VEC:R!I;G1E(&%T="!LY&=G82!T:6QL('5T]FMA9"!A;G;D;F1A
M<FEN9F]R;6%T:6]N('9I9"!R96=I<W1E<FEN9RX`2V%N(&EN=&4@Y&YD<F$@
M8F5H]G)I9VAE="!F]G(@5D93+69I;"`E<RX`2V%N(&EN=&4@Y&YD<F$@8F5H
M]G)I9VAE="!F]G(@5D93+69I;"`E<R\E<RX`2V%N(&EN=&4@Y&YD<F$@=&EL
M;"`E<RX`2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL<W1O<FQE:R`E<R\E<P!+
M86X@:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R;&5K('#E("5S+@!+86X@:6YT
M92!K;VYT<F]L;&5R82!F:6QS=&]R;&5K('#E("5S+R5S+@!+86X@:6YT92!K
M;VYT86MT82!344PM<V5R=F5R+@!+86X@:6YT92!K;VYT86MT82!V:6$@4U-,
M+@!+86X@:6YT92!K;W!I97)A(%9&4RUF:6PN`$MA;B!I;G1E('-K87!A(%9&
M4RUM87!P("5S+@!+86X@:6YT92!S:V%P82!61E,M;6%P<"X`2V%N(&EN=&4@
M<VMA<&$@5D93+69I;"X`2V%N(&EN=&4@<VMA<&$@5D93+6UA<'`@)R5S)RX`
M2V%N(&EN=&4@<VMA<&$@=&]M(%9&4RUF:6PN`$MA;B!I;G1E('!A8VMA('5P
M<"!D871A+@!+86X@:6YT92!R861E<F$@)7,L(&UA<'!E;B#D<B!I;G1E('1O
M;2X`2V%N(&EN=&4@<F%D97)A("<E<R<Z("5S`$MA;B!I;G1E(')A9&5R82`E
M<RP@;6%P<&5N(.1R(&EN=&4@=&]M+@!+86X@:6YT92!R861E<F$@5D93+6UA
M<'`@<F5K=7)S:79T+@!+86X@:6YT92!R861E<F$@5D93+6UA<'`N`$MA;B!I
M;G1E(')A9&5R82!61E,M;6%P<#H@)7,N`$MA;B!I;G1E(')A9&5R82!61E,M
M9FEL("5S+@!+86X@:6YT92!R861E<F$@5D93+69I;"X`2V%N(&EN=&4@<F%D
M97)A(%9&4RUM87!P("<E<R<N`$MA;B!I;G1E(')A9&5R82!61E,@<F5K=7)S
M:79T.B`E<RX`2V%N(&EN=&4@879G]G)A(&%K='5E;&P@;6%P<"X`2V%N(&EN
M=&4@97AT<F%H97)A($-E<G1I9FEK871S9&5T86QJ97(`2V%N(&EN=&4@;&%D
M9&$@9&5F:6YI=&EO;F5N(&%V("5S+@!+86X@:6YT92!F;'ET=&$@5D93+69I
M;"X`2V%N(&EN=&4@]G!P;F$@5D93+69I;"`E<RX`2V%N(&EN=&4@]G!P;F$@
M5D93+69I;"!F]G(@<VMR:79N:6YG+@!+86X@:6YT92#V<'!N82!61E,M9FEL
M+@!+86X@:6YT92#V<'!N82!K;VUP<FEM97)A="!A<FMI=BX`2V%N(&EN=&4@
M;.1S82!61E,M9FEL("AF:6QE<VEZ92@I(&UI<W-L>6-K861E<RDN`$MA;B!I
M;G1E(&SD<V$@5D93+69I;"`H9V5T1FEL95-I>F4H*2!M:7-S;'EC:V%D97,I
M+@!+86X@:6YT92!LY'-A(&9I;#H@`$MA;B!I;G1E(&SD<V$@:V%T86QO9V5N
M(&;V<B`G=F9S<F]O="<N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2`E<R!T:6QL
M("5S.B!D97-T:6YA=&EO;G-M87!P(&9I;FYS(')E9&%N`$MA;B!I;G1E(&)Y
M=&$@;F%M;B!PY2!61E,M;6%P<"X`2V%N(&EN=&4@8GET82!N86UN('#E(%9&
M4RUM87!P.B`E<RX`2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUF:6P@)7,N
M`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+R5S+@!+86X@:6YT
M92!B>71A(&YA;6X@<.4@5D93+69I;"X`2W5N9&4@:6YT92!LY'-A(&MV;W1A
M`$MA;B!I;G1E(&OV<F$@)VUK:7-O9G,G+@!+86X@:6YT92#V=F5R<^1T=&$@
M5V]R9&1O:W5M96YT970`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`E
M<RX`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`H8V]P>2@I(&UI<W-L
M>6-K861E<RDN`$MA;B!I;G1E('-K<FEV82!D871A('1I;&P@5D93+69I;"X`
M2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"P@:W9O=&$@<VMU;&QE(/9V
M97)S:W)I9&%S+@!/8F5S=F%R870`3V)E<W9A<F%D92!M961D96QA;F1E;@#%
M=&5R=&$`56YD97)S=')U:V5N`$1O;&1A(&UO='1A9V%R90#%;F=R82#D;F1R
M:6YG87(`Q6YG<F%R(&1I;B!S96YA<W1E(.5T9^1R9`!/=N1N=&%T('-V87(@
M9G+E;B!S97)V97(@<.4@9O9R8FEN9&5L<V4Z(`!/=N1N=&%T('-V87(@9G+E
M;B!S97)V97(@9O9R($%55$A%3E1)0T%412UK;VUM86YD;SH@`$]VY&YT870@
M<W9A<B!F<N5N('-E<G9E<B!F]G(@1&EG97-T+4U$-3H@`$]VY&YT870@<W9A
M<B!F<N5N('-E<G9E<B!F]G(@3$]'24XM:V]M;6%N9&\Z(`!/=N1N=&%T('-V
M87(@9G+E;B!S97)V97(@=&EL;#H@`$5J(&MA=&5G;W)I<V5R860`26-K92!H
M86YT97)A9"!K;VUP;VYE;G0@878@='EP.B`E<P!5;FEC;V1E("A55$8M."D`
M1O9R96YA9&4@07)A8F5M:7)A=&5N`%-T;W)B<FET86YN:65N`$;V<F5N=&$@
M4W1A=&5R;F$`06UE<FEK86YS:V$@4W1I;&QA:&%V<_9A<FYA`$5N:&5T97(`
M3VOD;F0`3VOD;G0@9&%T=6T`3VOD;G0@<W9A<B!F<N5N($E-05`M<V5R=F5R
M+B!397)V97)N('-V87)A9&4Z("5S`$]KY&YT(&WV=&4`3VOD;F0@;6]T=&%G
M87)E`$]KY&YT(&=RY&YS<VYI='1S;65D9&5L86YD96ED("AA<&EM<V=I9"DN
M`$]KY&YT(&ML:65N=&UE9&1E;&%N9&5I9"`H8VQI;7-G:60I+@!/:^1N9"!O
M<G0@<W!E8VEF:6-E<F%D+@!/:^1N="!A;G;D;F1A<FYA;6X@96QL97(@;/9S
M96YO<F0N`%1A(&)O<G0@;.1N:V5N(&9RY6X@;G5V<F%N9&4@96QE;65N=`!&
M<FEG]G(@;/9S96YO<F0`3F%M;FSV<P!)8VME+7!R:79I;&EG97)A9&4@<VMR
M:7!T(&MA;B!I;G1E(&MO;6UA(.5T($ML:7!P('5T+TMO<&EE<F$O2VQI<W1R
M82UF=6YK=&EO;F5R;F$@878@<^1K97)H971S<VOD;"X@2VQI8VMA($]+(&;V
M<B!A='0@<V4@96X@=&5K;FES:R!B97-K<FEV;FEN9R!F<N5N(&UO>FEL;&$N
M;W)G(&]M(&AU<B!D=2!K86X@=&EL;.5T82!A='0@<VMR:7!T(&MO;6UE<B#E
M="!U<FML:7!P+@!/;.1S=`!482!B;W)T(&;D<F<`079S;'5T82!P<F5N=6UE
M<F%T:6]N('#E(&UA<'`H87(I`%1I;&SD9V=E="!S=/9D<R!I;G1E`%5P<&1A
M=&5R80!5<'!D871E<F$@)7,`57!P9&%T97)A('-T871U<R!PY2!S=F%R86YD
M90!5<'!D871E<F$@86YVY&YD87)E`%5P<&1A=&5R861E("<E<R<N`%5P<&1A
M=&5R:6YG<W-C<FEP="!R861E<F%T+@!,861D82!U<'``3&%D9&%D92!U<'`@
M86QL82!K;VYF:6=U<F%T:6]N<V9I;&5R('1I;&P@<V5R=F5R;BX`5F5R<V%L
M97(`4F]M97)S:V$@<VEF9G)O<@!5<G5G=6%Y`$%N=N1N9"!A:W1U96QL.B`E
M<P!!;G;D;F0@9O9R=F%L="!VY')D90!!;G;D;F0@24U!4',@;6%P<'!R96YU
M;65R871I;VYE<C\`06YVY&YD(%-33`!!;G;D;F0@=FER='5E;&P@<&%P<&5R
M<VMO<F<_`$%N=N1N9"!O;2!N86UN+VSV<V5N;W)D(.1R(&%N;F]R;'5N9&$@
M9O9R($E-4U`M<V5R=F5R+@!!;G;D;F1A<F4`1V%V(&%N=N1N9&%R96X@(B5S
M(B!A;F=I=FYA('+D='1I9VAE=&5R('1I;&P@;6%P<&5N("(E<R(N`$%N=N1N
M9&%R92`E<R#D<B!I;G1E(&)E:/9R:6<@9O9R("5S+@!!;G;D;F1A<F%D;6EN
M:7-T<F%T:6]N`$%N=N1N9&%R:6YS=.1L;&YI;F=A<@!!;G;D;F1A<G)E9VES
M=')E<FEN9P!!;G;D;F1A<G)E9VES=')E<FEN9R!H87(@879A:W1I=F5R871S
M+@!!;G;D;F1A<FMO;G1O="!H:71T861E<R!I;G1E`$%N=N1N9&%R;F%M;@!!
M;G;D;F1A<FYA;6X@)7,@9FEN;G,@<F5D86XN`$%N=N1N9&%R;F%M;CH`06YV
MY&YD87)N86UN.B``06YVY&YD87)E(&D@<WES=&5M970Z`%5Z8F5K:7-T86X`
M5D93+6UA<'`@97AI<W1E<F%R(&EN=&4N`%-E;65S=&5R`$=I;'1I9V$@<&QA
M='-E<B!S;VT@:&ET=&%D97,@:6YK;'5D97)A<CH@`$=I;'1I9VAE=`!-:6YU
M=&5R(&9RY6X@;G4`5N1R9&5T(/9V97)S=&EG97(@9&5T(&CV9W-T82!T:6QL
MY71N82`H)7,I`%;D<F1E;@!6Y')D96X@871T(';D;&IA(&9RY6X`5F%N=71A
M=0!687)I86)E;`!696YE>G5E;&$`5F5R:69I97)I;F<@;6ES<VQY8VMA9&5S
M("T@;65D9&5L86YD970@:V%N(&AA(&UA;FEP=6QE<F%T<RX`5F5R<VEO;@!6
M97)S:6]N:&%N=&5R:6YG`%9E<G1I:V%L(&IU<W1E<FEN9P!697)T:6MA;"!U
M=&9Y;&QN860`5F5R=&EK86PZ`%;D;&1I9W0@:/9G`%9I971N86T`5FEE=&YA
M;65S:7-K("A625-#24DI`%9I<V$`5FES82`E<P!6:7-A('!U8FQI:R!N>6-K
M96P@9O9R("5S`%9I<V$@2%1-3"UI;FYE:.5L;"!I(&5T="!S97!A<F%T(&;V
M;G-T97(`5FES82!M961D96QA;F1E;@!6:7-A('!E<G-O;FQI9RP@<')I=F%T
M(&YY8VME;`!6:7-A('!E<G-O;FQI9RP@<'5B;&EK(&YY8VME;`!6:7-A('1R
MY60`5FES82!M:6YI871Y<F)I;&0`5FES82!E;B!E>'1E<FX@=V5B8G-I9&$`
M5FES82!S;VT@)7,`5FES82!B:6QA9V]R(&D@971T('-E<&%R870@9O9N<W1E
M<@!6:7-A(&EN;F5HY6QL(&D@971T('-E<&%R870@9O9N<W1E<@!6:7-A(&CD
M;F1E;'-E`%9I<V$@;65D9&5L86YD96X@:2`E<P!6>2!E;&QE<B!M87!P(&%T
M="!V:7-A(&5F=&5R(&EN;&]G9VYI;F<Z`%9I<V$@=7!P9VEF=`!6:7-A(&)I
M;&1E<@!*=6YG9G)U]F%R;F$L($)R:71T:7-K80!*=6YG9G)U]F%R;F$L($%M
M97)I:V%N<VMA`%9I<G1U96QL(&UA<'`@(B5S(B!S:V%P861E<RX`5FER='5E
M;&QA(&UA<'!A<@!6:7)T=65L;&$@;6%P<&%R(&WE<W1E(&AA(&5T="!N86UN
M`%9I<G1U96QL(&EN:V]R9P!6:7)T=65L;"!I;FMO<F<`5FER='5E;&P@<&%P
M<&5R<VMO<F<`5FER='5E;&P@<&%P<&5R<VMO<F<`3F%M;B!PY2!V:7)T=65L
M;"!M87!P`%-I:W0`4VEK=#H`5F]D869O;F4@271A;&EE;B!V:6$@4TU44`!6
M05).`%9!4DY)3D<A(2$@4D%$15)!(%-+4DE05$54($U!3E5%3$Q4($92Q4X@
M)7,N`%=)3B!V:6$@2%144`!786QL:7,@;V-H($9U='5N80!687)N:6YG`$]N
M`%;D9&5R<')O9VYO<P!6Y&1E<F1A=&$@9G+E;@!W96%T:&5R+F-O;0!796)B
M`%=E8F)P;&%T<P!796)B<&QA='-E;B`M(%-O8F5R`%=E8F)P;&%T<V5N("T@
M4V]B97(@3ED`5F5C:V]V:7,`5N1L:V]M;65N`%;D;&MO;6UE;B!T:6QL("5S
M`%;D;&MO;6UE;BP@)7,`5N1S=&5R;.1N9'-K("A)4T\M.#@U.2TQ*0!6Y'-T
M97)LY&YD<VL@*$E33RTX.#4Y+3$U*0!6Y'-T<F$@4V%H87)A`%9I;&ME;B!A
M<'!L:6MA=&EO;B!S:V%L;"`E<R!V:7-A(&5F=&5R(&EN;&]G9VYI;F<_`%9I
M;&ME;B#D<B!A=F=RY&YS;FEN9W-T96-K;F5T/P!6:6QK970@Y'(@=&5C:VYE
M="!F]G(@8VET97)A9"!T97AT/P!(=7(@<VMA;&P@;65D9&5L86YD96X@:&%N
M=&5R87,@969T97(@9&4@:&%R(')A<'!O<G1E<F%T<R!S;VT@<VMRY'!P;W-T
M(&5L;&5R('-O;2!%2BUS:W+D<'!O<W0_`$[D<B!M961D96QA;F1E;B!R861E
M<F%S+"!F;'ET=&$@9&5M('1I;&P@<&%P<&5R<VMO<F=E;B!I<W3D;&QE="!F
M]G(@871T(&UA<FME<F$@9&5M('-O;2!R861E<F%D93\`3N1R(&1U(/9P<&YA
M<B!E;B!N>2!M87!P+"!V:6QK96X@<VED82!V:6QL(&1U(&+V<FIA('#E/P!.
MY'(@<VMI8VMA9"!P;W-T('-P87)A<RP@<VMA;&P@8FEL86=O<B!O8VMSY2!S
M<&%R87,_`$[D<B!V:2!S:VEC:V%R(&4M<&]S="!E;&QE<B!E>'!A;F1E<F%R
M(&%D<F5S<V5R+"!V:6QK96X@9&]MY&X@<VMA;&P@=FD@;.1G9V$@=&EL;"!O
M9G5L;'-TY&YD:6=A(&4M<&]S=&%D<F5S<V5R("AA9')E<W-E<B!U=&%N(")`
M(BD_`%=H97)E:7,@075S=')A;&EE;FMA<G1A`%9I;&MA(&9A<V5R`%9I;&MA
M('!L=6=I;B!S:V%L;"!A:W1I=F5R87,@9O9R(%)I8V@@5&5X="!E9&ET;W)N
M+@!"971R;V1D82!A9')E<W-E<@!"<F5D9`!"<F5D9"!I($-34RUU;FET<P!"
M<F5D9"!PY2!M96YY;B!F]G(@)R5S)R!T:6QL(';D;G-T97(@*&?D;&QE<B!F
M<N5N(&[D<W1A(&EN;&]G9VYI;F<`5&%B96QL8G)E9&0`0G)E9&1E;FAE=`!"
M<F5D9#H`5VEK:0!6:6YD`%1I9&EG('9I;F0`5FEN9&AA<W1I9VAE="!I(&MN
M;W``5FEN9#H`5FEN9#H@`%9I<V1O;0#6;G-K96QI<W1A`$%R8F5T90!!9')E
M<W,L(&%R8F5T90!496QE9F]N+"!A<F)E=&4`1F5L(&%N=&%L(&;D;'0@<.4@
M<F%D("5D+B!&]G)VY&YT861E("5D+"!H:71T861E("5D+@!&96P@86YT86P@
M9N1L="X@1O9R=N1N=&%D92`E9"P@:&ET=&%D92`E9"X`1F5L('!O<VET:6]N
M("5D('9I9"!LY'-N:6YG(&%V(%9&4RUF:6PN`%@M4F5F`%@U,#E6,R!5=/9K
M860@;GEC:V5L86YVY&YD;FEN9P!8-3`Y5C,M=&EL;.1G9P!960!965E9`%EA
M:&]O(2!M87``Q7)L:6<`665M96X`2F$`2F$L(&IA9R!S86UT>6-K97(`1'4@
M:V]M;65R(&%T="!HY&UE(&UE9&1E;&%N9&5N(&9RY6X@9O9L:F%N9&4@:V]N
M=&\H;BDZ`$1U(&;V<G/V:V5R('1A(&)O<G0@86QL82!M961D96QA;F1E;B!I
M(&;V;&IA;F1E(&UA<'`H87(I.@!$=2!F]G)S]FME<B!T82!B;W)T(&;V;&IA
M;F1E(&UA<'`H87(I.@!$=2!F;'ET=&%R+VMO<&EE<F%R('1I;&P@96X@;GD@
M;6%P<"X`1'4@<VMA<&%R(&5N('5N9&5R;6%P<"!T:6QL(`!$=2!S:V%P87(@
M96X@;6%P<"!PY2!T;W!P;FEVY6XN`$1U(&AA<B!A:W1I=F5R870@=&5X=&SD
M9V4N($%N=N1N9"!;/#Y=(&;V<B!A='0@Y71E<F?E('1I;&P@5UE325=91RX`
M1'4@9N5R(&EN=&4@<VMA<&$@;6%P<&%R+@!$=2!H87(@:6YT92!B96CV<FEG
M:&5T('-K87!A(&9L97(@Y&X@)60@8FQO8VLN`$1U(&;E<B!I;G1E('-K87!A
M(&UE<B#D;B`E9"!M87!P*&%R*2X`1'4@Y'(@:6YT92!A=71E;G1I<V5R860N
M`$1U(&3V<&5R(&]M(&UA<'!E;CH@`$1U(&MA;B!I;G1E(&%N=N1N9&$@)UPG
M(&D@9&ET="!N86UN`$1U(&MA;B!A;G;D;F1A(&;V;&IA;F1E(&UA:W)O;B!I
M(&UA;&QT97AT96XZ("5C(&;V<B!M961D96QA;F1E:6YN96CE;&QE=#L@)7,@
M9O9R('-I9VYA='5R96XN`$1U(&MA;B!I;G1E(&%N=N1N9&$@)UPG(&D@9&ET
M="!N86UN`$1U(&MA;B!I;G1E(&%V<VQU=&$@9&EN('!R96YU;65R871I;VX@
M<.4@(B5S(BX`169T97)S;VT@9'4@:6YT92!G;V1KY&YT(&%N=N1N9&YI;F=S
M=FEL;&MO<F5N(&;E<B!D=2!I;G1E(&QO9V=A(&EN+@!$=2!A;F=A=B!I;G1E
M(&5N(&=O9&OD;F0@92UP;W-T861R97-S+@!$=2!H87(@:6YT92!RY'1T(&%T
M="#D;F1R82!RY'1T:6=H971E<B!F]G(@9&5N;F$@;6%P<`!$=2!V:61A<F)E
M9F]R9')A9&4@;65D9&5L86YD970@)25S('1I;&P@9O9L:F%N9&4@;6]T=&%G
M87)E.B`E<RX`1'4@:&%R("5S(&YY82!M961D96QA;F1E;BX`1'4@:&%R(#$@
M;GET="!M961D96QA;F1E+@!$=2!H87(@<V5D86X@<VMI8VMA="!S:61A;B]F
M;W)M=6SD<F5T+@!$=2#D<B!U=&QO9V=A9"X`1'4@:&%R(&YY82!M961D96QA
M;F1E;B!M87!P96XZ`$1U(&AA<B!N>6$@;65D9&5L86YD96X@:2!F]FQJ86YD
M92!M87!P87(Z`$1U(&WE<W1E(&%N9V4@971T(&=I;'1I9W0@;6]B:6QN=6UM
M97([(&5N8F%R="!S:69F<F]R(&]C:"!E='0@)RLG(&;V<F4@:6YT97)N871I
M;VYE;&QT('!R969I>"X`1'4@86YG878@:6YT92!E='0@9V]D:^1N="!VY')D
M92X`1'4@:V%N(&)A<F$@<F5D:6=E<F$@96X@;6%P<"#E="!GY6YG96XN`$1U
M(&WE<W1E(&MO;F9I9W5R97)A(&5N($1A=&%4<N1D<RUK;W!P;&EN9R!F]G(@
M871T(&%N=N1N9&$@<F5G:7-T<F5R:6YG`$1U(&WE<W1E(&MO;F9I9W5R97)A
M(&5N(%9&4RUK;W!P;&EN9P!$=2!MY7-T92!B97-K<FEV82!P<F]B;&5M96XL
M(&EN;F%N(&1U(&MA;B!R87!P;W)T97)A(&5T="!P<F]B;&5M+@!6Y&QJ(&UI
M;G-T(&5N(&UO='1A9V%R92X`1'4@;>5S=&4@86YG92!E;B!54DP@<V]M(&SD
M;FME;B!P96MA<B!PY0!$=2!MY7-T92!A;F=E(&SV<V5N;W)D(&;V<B!D:6X@
M<')I=F%T82!01U`M;GEC:V5L(&;V<B!A='0@:W5N;F$@=FES82!D970@:.1R
M(&UE9&1E;&%N9&5T+@!$=2!MY7-T92!A;F=E(&SV<V5N;W)D(&;V<B!D:6X@
M<')I=F%T82!3+TU)344M;GEC:V5L(&;V<B!A='0@:W5N;F$@=FES82!D970@
M:.1R(&UE9&1E;&%N9&5T+@!6Y&QJ(&5N(&WE;&UA<'`@9O9R<W0N`$%N9V4@
M:V]N=&]T('-O;2!S:V%L;"!R861E<F%S+@!$=2!MY7-T92!A;F=E(&5N(&%D
M<F5S<R!F]G)S="X`1'4@;>5S=&4@86YG92!E;B!S97)V97(@<V]M('-K86QL
M(')A9&5R87,N`%;D;&H@;6EN<W0@971T(&UE9&1E;&%N9&4@9O9R<W0N`%;D
M;&H@96X@;6]T=&%G87)E+@!$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA
M;6X@<V]M('-K86QL(')E;G-A<RX`1'4@;>5S=&4@86YG92!E='0@86YVY&YD
M87)N86UN('-O;2!S:V%L;"!R861E<F%S+@!$=2!MY7-T92!A;F=E(&5T="!A
M;G;D;F1A<FYA;6X@<V]M('-K86QL(&SD9V=A<R!T:6QL+@!$=2!MY7-T92!A
M;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL('5P<&1A=&5R87,N`$1U
M(&WE<W1E(&%N9V4@96X@Y71GY')D('-O;2!S:V%L;"!U=&;V<F%S+@!$=2!M
MY7-T92!A;F=E(&5T="!N>71T(&MA=&5G;W)I;F%M;BX`1'4@;>5S=&4@86MT
M:79E<F$@(B5S(B!I('5N9&5R:.5L;'-I;G-TY&QL;FEN9V%R+@!$=2!MY7-T
M92!A;F=E(&5T="!I=&%L:65N<VMT('1E;&5F;VYN=6UM97(`1'4@969T97)S
MY&YD92!M961D96QA;F1E="!T:6QL("5S(&1E;B`E)7,N`$1U('-V87)A9&4@
M<.4@;65D9&5L86YD970@)7,N`$1U(&)L978@:6YT92!P<F5N=6UE<F%N="!P
MY2`B)7,B+B!397)V97)N('-V87)A9&4`1&EN('!R96YU;65R871I;VX@<.4@
M(B5S(B!A=G-L=71A9&5S(&EN=&4N(%-E<G9E<FX@<W9A<F%D90!0<F5N=6UE
M<F%T:6]N('#E("(E<R(@<W1A<G1A9&5S+@!$:6X@<')E;G5M97)A=&EO;B!P
MY2`B)7,B(&%V<VQU=&%D97,N`$1I;B`E<R!S97-S:6]N(&AA<B!U<'!H]G)T
M+B!687(@9V]D(&QO9V=A(&EN(&EG96XN`$1I;B!E+7!O<W1A9')E<W,`1&EN
M($9RY6XZ(&%D<F5S<SH`1&EN(&EN9F]R;6%T:6]N`$1I;B!I;G1E<FYE=&%D
M<F5S<R!H87(@Y&YD<F%T<R!E9G1E<B!A='0@9'4@;&]G9V%T(&EN('1I;&P@
M)R5S)RX@1O9R(&%T="!S:WED9&$@9&EG+"!MY7-T92!D=2!L;V=G82!I;B!I
M9V5N+@!$:71T(&YA;6X`1&EN('!U8FQI:V$O<')I=F%T82!N>6-K96P@9O9R
M(%!'4`!$:6X@<')I=F%T82!N>6-K96P`1&EN('!U8FQI:V$@;GEC:V5L`$1I
M;B!297!L>2UT;SH@861R97-S.B`\96T^*'9A;&9R:2D\+V5M/@!$:71T('!U
M8FQI:V$O<')I=F%T82!C97)T:69I:V%T(&;V<B!3+TU)344`1&EN82!K;VYT
M;VXZ`$1I;F$@86QI87-A9')E<W-E<CH@/&5M/BAE:B!O8FQI9V%T;W)I<VMT
M+"!S:W)I=B!V87)J92!A9')E<W,@<.4@96X@;GD*<F%D*3PO96T^`$1I;B!A
M=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E<B!I;G1E('5P<&SD9V<@878@
M86YVY&YD87)E+B!/;2!D=2!V:6QL(&%N=N1N9&$@2&]R9&4@9O9R(&%T="!A
M9&UI;FES=')E<F$@86YVY&YD87)E('/E(&WE<W1E(&1U(&%N=N1N9&$@96X@
M86YN86X@875T96YT:7-E<FEN9W-K;W!P;&EN9RX`1&ET="!A=71E;G1I<V5R
M:6YG<VMO<'!L:6YG('-T]F1E<B!I;G1E(&QI<W1N:6YG(&%V(&%N=N1N9&%R
M92P@96QL97(@<^4@Y'(@9G5N:W1I;VYE;B!A=G-TY&YG9"X`1&EN('=E8F)L
MY'-A<F4O:6YT97)N971A9')E<W,@:&%R(.1N9')A=',@969T97(@871T(&1U
M(&QO9V=A="!I;B!T:6QL("<E<R<N($;V<B!A='0@<VMY9&1A(&1I9RP@;>5S
M=&4@9'4@;&]G9V$@:6X@:6=E;BX`1&EN('=E8FSD<V%R92!S=/9D:F5R(&EN
M=&4@:6YL:6YE+79I<VYI;F<@878@9&5N(&CD<B!B:6QD='EP96XN`$1I;B!W
M96)B;.1S87)E('-T]F1E<B!I;G1E(&1E;B!HY'(@9G5N:W1I;VYE;BX`1&EN
M('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@=71S:W)I9G1S9G5N:W1I;VYE;BX@
M5')Y8VL@0W1R;"]/<'1I;VX@*R!0(&;V<B!A='0@<VMR:79A('5T+@!$:6X@
M=V5B;.1S87)E('-T]F1J97(@:6YT92!U='-K<FEF='-F=6YK=&EO;F5N+B!4
M<GEC:R!C;VYT<F]L+V]P=&EO;B`K(%`@9O9R(&%T="!S:W)I=F$@=70N`$1I
M;B!A:W1U96QL82!T:61S>F]N.@!3=&%N9&%R9'1E>'1K;V1N:6YG(&[D<B!D
M=2!S:VEC:V%R(&UE9&1E;&%N9&5N.@!3=&%N9&%R9&UE=&]D(&;V<B!K<GEP
M=&5R:6YG(&[D<B!D=2!S:VEC:V%R(&UE9&1E;&%N9&5N.@!$:6X@9O9R=F%L
M9&$@:61E;G1I=&5T(&AA<B#D;F1R871S+@!$:6X@9O9R=F%L9&$@:61E;G1I
M=&5T.@!$:71T(&9U;&QS=.1N9&EG82!N86UN.@!$92!LY&YK861E(&)I9F]G
M861E(&1O:W5M96YT96X@:&%R(&QA9&1A=',@;F5D(&%V(.5T;6EN<W1O;F4@
M96X@86YVY&YD87)E+@H*3F%M;CH@)7,*1&%T=6TZ("5S"@I+;&EC:V$@<.4@
M;.1N:V5N(&;V<B!A='0@<F%D97)A(&1E(&)I9F]G861E(&1O:W5M96YT96XZ
M"B5S`$1I;B!I;FQO9V=N:6YG(&AA<B!GY71T('5T+@!-961D96QA;F1E="!L
M979E<F5R861E<RX`1&ET="!N>6$@;/9S96YO<F0@9O9R("5S(.1R.B`E<P!$
M:6YA(&EN<W3D;&QN:6YG87(@:&%R('5P<&1A=&5R871S(&;V<B!D96X@:.1R
M('-E<W-I;VYE;BX`1&EN82!I;G-TY&QL;FEN9V%R(&AA<B!U<'!D871E<F%T
M<RX`1&ET="!L]G-E;F]R9"!H87(@8FQI=FET(.5T97)S=.1L;'0`1&ET="!L
M]G-N;W)D(&AA<B#E=&5R<W3D;&QT<RP@:V]N=')O;&QE<F$@9&EN(&4M<&]S
M="!O8V@@;&]G9V$@:6X@;65D(&1I='0@;GEA(&SV<V5N;W)D+@!$:71T(&SV
M<V5N;W)D(&AA<B!GY71T('5T+@!$:6YA(&9JY')R<V5R=G)A<CH`1&EN('-I
M9VYA='5R.@!*=6=O<VQA=FEE;@!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6T?V;2!A9')E<W-E<ET`6T?V;2!C:71E<F%D('1E>'1=`%M);F=E="#D
M<F5N9&5=`%M&96QR87!P;W)T70!;5FES82!A9')E<W-E<B`M`%M6:7-A(&-I
M=&5R860@=&5X="`M`%M6:7-A(&-I=&5R860@=&5X="`M("5S(')A9&5R70!;
M5FES82!A9')E<W-E<B`M("5S(&UO='1A9V%R95T`6W)A9"`E<R!A=B`E<UT`
M7T%D;6EN:7-T<F%T:6]N`%]"8V,`7U-PY')R82!A9')E<W,`7T-,20!?0V,`
M7U-K<FEV(&UE9&1E;&%N9&4`7T1A=&%4<N1D`%]2861E<F$`7U)A9&5R82!R
M860`7TUA<'!A<@!?1W)U<'!E<@!?2&KD;'``7TED96YT:71E=`!?0FEL9&EN
M<W3D;&QN:6YG87(N+BX`7TEN:V]R9P!?3&]G9V$@:6X`7TQO9V=A('5T`%]-
M961D96QA;F1E:^1L;&$`Q%]N9')A(&SD;FLN+BX`7TYY='0@;65D9&5L86YD
M90!?26YS=.1L;&YI;F=A<@!?0F5H]G)I9VAE=&5R`%]5='-K<FEF=`!?4')I
M;W)I=&5T`%]&]G)N>6$@)7,`7U1A(&)O<G0@;.1N:RXN+@!?4W9A<F$`7U/V
M:P!?4VMI8VMA`%]3971U<`!?5&%B96QL:6YS=.1L;&YI;F=A<BXN+@!?5'+E
M9`!?5&EL;`#%=&5R=&$`7T%N=N1N9&%R90!?5FES82!T<N5D`%]"971R;V1D
M82!A9')E<W-E<@!A9')E<W-B;VL`;VOD;F0@;6]T=&%G87)E`&)I;&%G80!B
M:6QA9V]R+GII<`!T96-K96X`:V%L96YD97(`;'5G;G0`2V%N(&EN=&4@<VMA
M<&$@=71F:6P`:V%N(&EN=&4@]G!P;F$@:6YD871A`&ML:6-K82!HY'(`:VQO
M8VMA`&MO;6UA;F1O<F%D<V9E;`!K;VYF:6=U<F%T:6]N<V9E;`!K<FET:7-K
M('-Y<W1E;69I;"!S86MN87,`9F]R;6%T9F5L`.1N9')A`'!O<W0@<V%K;F%S
M+@!F86QL86YD90!F:6P`9G+E;@!F<N5N(&1E;B`E<R`H)7,I(&ML("5S("5S
M`'-T;W)M8GEA<@!H.@!H:`!O:^1N9"!VY')D9&%T;W(`9V5N87-T`&EN;&EN
M90!B96%R8F5T;FEN9W-F96P`26YT97)N="!M:G5K=F%R=69E;`!N>6-K96P`
M<F%D97)=`&)R979LY61E9FEL`&9E;&MO9"`E9"!F<N5N(&UK:7-O9G,`;6T`
M;F%M;@!I;F=E;@!I;G1E(&EM<&QE;65N=&5R860`:6YT92!I;7!L96UE;G1E
M<F%D`&%N=&5C:VYI;F=S8FQO8VL`96QL97(`<')O8V5N=`#E=&MO;7-T(&YE
M:V%D`'!I>&QA<@!M;W1T86=A<F5=`'!R;W1O:V]L;&9E;`!S=&EG86YD90!S
M97)V:6-E(&5J('1I;&QGY&YG;&EG`'9I<V$@<VMI;&QN861E<@!S;7,R96UA
M:6P@=FEA($A45%``<W1A=F9E;`!S=&%V9F5L`'-S`'-T861I9W0`<WES=&5M
M9F5L`'5P<&=I9G1S;&ES=&$`=&EL;&;D;&QI9W0@9F5L`&%N9V4@;/9S96YO
M<F1E="!T=N4@9^5N9V5R(&;V<B!A='0@8F5K<N1F=&$`96YA9`!N86UN;/9S
M`&%N=N1N9&%R=F%L`'9#87)D`'<Z`'=E871H97(N8V]M`&1I;F$@<W#D<G)A
M9&4@861R97-S97(`9&EN82!B971R;V1D82!A9')E<W-E<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]S=E]312]H96QP+GAM;```````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R-C0T-P`Q,#0Q-S,V,C<V
M,P`P,C$Q-34`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!I;7`O
M;&]C86QE+W-V7U-%+VAE;'`N>&UL+'8@,2XQ-BXV+C0@,C`P-B\P,2\S,"`Q
M-3HU-SHU,B!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB8V]M
M<&]S92UB=71T;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S
M<V%G92!#;VUP;W-I=&EO;CH@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY!8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD($UE<W-A
M9V4@;&%U;F-H97,@>6]U<B!E;6%I;"!T;R!T:&4@:6YT96YD960@<F5C:7!I
M96YT*',I+B!"92!S=7)E('EO=2!W86YT('1O('-E;F0@8F5F;W)E(&-L:6-K
M:6YG(&AE<F4@87,@;VYC92!S96YT(&ET(&-A;FYO="!B92!T86ME;B!B86-K
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3879E($1R869T('!L86-E
M<R!A;B!U;F9I;FES:&5D(&UE<W-A9V4@:6X@82!F;VQD97(@8V%L;&5D("=$
M<F%F=',G"F%C8V5S<VEB;&4@8GD@=&AE('!O<"UD;W=N(&)O>"!O;B!T:&4@
M<FEG:'0@<VED92!O9B!T:&4@8FQU92!N879I9V%T:6]N(&)A<B!A="!T;W`N
M(%EO=2!C86X@=&AE;B!F:6YI<V@@=&AE(&UE<W-A9V4@;&%T97(@8GD@<W=I
M=&-H:6YG('1O('1H92`G1')A9G1S)R!F;VQD97(L(&-L:6-K:6YG(&]N('1H
M92!S879E9"!M97-S86=E('1O(&]P96X@:70L(&%N9"!T:&5N(&-L:6-K:6YG
M(&]N("=297-U;64G+B!"92!S=7)E('1O('!U="!A('-U8FIE8W0@;VX@=&AE
M(&5M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A9G0@<V\@=&AA="!Y;W4@
M8V%N(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S86=E('EO=2!W86YT('=I
M=&AI;B!T:&4@1')A9G1S(&9O;&1E<BX@069T97(@<V%V:6YG(&%S(&$@1')A
M9G0L('EO=2!A<F4@<F5T=7)N960@=&\@>6]U<B!)3D)/6"!O<B!W:&%T979E
M<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^"B`@("!#86YC96P@365S<V%G92!D<F]P<R!T:&4@;65S<V%G
M92!I;B!P<F]G<F5S<R!A;F0@<VEM<&QY(')E='5R;G,@>6]U('1O('1H92!)
M3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T
M+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB
M8V]M<&]S92UB=71T;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET
M:6]N.B!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D%C=&EO;G,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@365S<V%G92!L875N8VAE<R!Y
M;W5R(&5M86EL('1O('1H92!I;G1E;F1E9"!R96-I<&EE;G0H<RDN($)E('-U
M<F4@>6]U('=A;G0@=&\@<V5N9"!B969O<F4@8VQI8VMI;F<@:&5R92!A<R!O
M;F-E('-E;G0@:70@8V%N;F]T(&)E('1A:V5N(&)A8VLN"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@(%-A=F4@1')A9G0@<&QA8V5S(&%N('5N9FEN:7-H
M960@;65S<V%G92!I;B!A(&9O;&1E<B!C86QL960@)T1R869T<R<*86-C97-S
M:6)L92!B>2!T:&4@<&]P+61O=VX@8F]X(&]N('1H92!R:6=H="!S:61E(&]F
M('1H92!B;'5E(&YA=FEG871I;VX@8F%R(&%T('1O<"X@66]U(&-A;B!T:&5N
M(&9I;FES:"!T:&4@;65S<V%G92!L871E<B!B>2!S=VET8VAI;F<@=&\@=&AE
M("=$<F%F=',G(&9O;&1E<BP@8VQI8VMI;F<@;VX@=&AE('-A=F5D(&UE<W-A
M9V4@=&\@;W!E;B!I="P@86YD('1H96X@8VQI8VMI;F<@;VX@)U)E<W5M92<N
M($)E('-U<F4@=&\@<'5T(&$@<W5B:F5C="!O;B!T:&4@96UA:6P@8F5F;W)E
M('EO=2!S879E('1H92!D<F%F="!S;R!T:&%T('EO=2!C86X@96%S:6QY(&ED
M96YT:69Y('=H:6-H(&UE<W-A9V4@>6]U('=A;G0@=VET:&EN('1H92!$<F%F
M=',@9F]L9&5R+B!!9G1E<B!S879I;F<@87,@82!$<F%F="P@>6]U(&%R92!R
M971U<FYE9"!T;R!Y;W5R($E.0D]8(&]R('=H871E=F5R(&9O;&1E<B!Y;W4@
M=V5R92!V:65W:6YG(&QA<W0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M($-A;F-E;"!-97-S86=E(&1R;W!S('1H92!M97-S86=E(&EN('!R;V=R97-S
M(&%N9"!S:6UP;'D@<F5T=7)N<R!Y;W4@=&\@=&AE($E.0D]8(&]R('=H871E
M=F5R(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M9G)O
M;2(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ($9R;VT\+W1I=&QE/@H@("`@/&AE861I;F<^(D9R;VTB/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!Y;W5R(&-O<G)E8W0@96UA:6P@
M861D<F5S<RX@66]U<B!E;6%I;"!A9&1R97-S(&ES(&%U=&]M871I8V%L;'D@
M96YT97)E9"!F;W(@>6]U(&9O;&QO=VEN9R`B1G)O;3HB(&EN(&]U=&=O:6YG
M(&5M86EL+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R
M>2!I9#TB8V]M<&]S92UF<F]M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!&<F]M/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T9R;VTF
M<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('EO=7(@8V]R
M<F5C="!E;6%I;"!A9&1R97-S+B!9;W5R(&5M86EL(&%D9')E<W,@:7,@875T
M;VUA=&EC86QL>2!E;G1E<F5D(&9O<B!Y;W4@9F]L;&]W:6YG("9Q=6]T.T9R
M;VTZ)G%U;W0[(&EN(&]U=&=O:6YG(&5M86EL+@H@("`@/"]P87)A/@H\+V5N
M=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+71O(B!S=&%T
M93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@
M5&\\+W1I=&QE/@H@("`@/&AE861I;F<^(E1O(CPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@
M;V8@=&AO<V4@=&\@<F5C96EV92!Y;W5R(&UE<W-A9V4N(%EO=2!M=7-T('-E
M<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R('!U;F-T
M=6%T:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N=')Y(&9O
M;&QO=W,@(E1O.B(@:6X@;W5T9V]I;F<@;6%I;"X@(`H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UT;R(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@5&\\+W1I=&QE/@H@("`@
M/&AE861I;F<^)G%U;W0[5&\F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H
M;W-E('1O(')E8V5I=F4@>6]U<B!M97-S86=E+B!9;W4@;75S="!S97!A<F%T
M92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO
M;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S
M("9Q=6]T.U1O.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL+B`@"B`@("`\+W!A
M<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M8V,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!#8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB0V,B/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R
M97-S*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@8V%R8F]N(&-O<'D@;V8@
M>6]U<B!M97-S86=E+B!397!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O
M;6UA+B!9;W5R(&5N=')Y(&9O;&QO=W,@(D-C.B(@:6X@;W5T9V]I;F<@;6%I
M;"X@0V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S96YT('1O('!E;W!L92!O
M=&AE<B!T:&%N('1H92!O;F4H<RD@8F5I;F<@=W)I='1E;B!T;R!D:7)E8W1L
M>2!B=70@87)E(&EM<&]R=&%N="!R96-I<&EE;G1S(&]F('1H92!E;6%I;"!A
M<R!W96QL+"!U<W5A;&QY('-O;65O;F4@:6YD:7)E8W1L>2!C;VYC97)N960@
M86)O=70@=&AE('-U8FIE8W0@;V8@=&AE(&5M86EL+B`@06QL("=4;SHG(')E
M8VEP:65N=',@86YD("=#8SHG(')E8VEP:65N=',@8V%N('-E92!T:&4@96YT
M:7)E(&QI<W0@;V8@8F]T:"!K:6YD<R!O9B!R96-I<&EE;G1S+@H@("`@/"]P
M87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UC
M8R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@0V,\+W1I=&QE
M/@H@("`@/&AE861I;F<^)G%U;W0[0V,F<75O=#L\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I
M(&]F('1H;W-E('1O(')E8V5I=F4@82!C87)B;VX@8V]P>2!O9B!Y;W5R(&UE
M<W-A9V4N(%-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$N(%EO
M=7(@96YT<GD@9F]L;&]W<R`F<75O=#M#8SHF<75O=#L@:6X@;W5T9V]I;F<@
M;6%I;"X@0V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S96YT('1O('!E;W!L
M92!O=&AE<B!T:&%N('1H92!O;F4H<RD@8F5I;F<@=W)I='1E;B!T;R!D:7)E
M8W1L>2!B=70@87)E(&EM<&]R=&%N="!R96-I<&EE;G1S(&]F('1H92!E;6%I
M;"!A<R!W96QL+"!U<W5A;&QY('-O;65O;F4@:6YD:7)E8W1L>2!C;VYC97)N
M960@86)O=70@=&AE('-U8FIE8W0@;V8@=&AE(&5M86EL+B`@06QL("=4;SHG
M(')E8VEP:65N=',@86YD("=#8SHG(')E8VEP:65N=',@8V%N('-E92!T:&4@
M96YT:7)E(&QI<W0@;V8@8F]T:"!K:6YD<R!O9B!R96-I<&EE;G1S+@H@("`@
M/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6)C8R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($)C8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB0F-C(CPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA
M:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&)L:6YD(&-A
M<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@66]U(&UU<W0@<V5P87)A=&4@
M96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@<'5N8W1U871I;VX@
M=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT<GD@9F]L;&]W<R`B
M0F-C.B(@:6X@;W5T9V]I;F<@;6%I;"X@0FQI;F0@8V%R8F]N(&-O<&EE<R!A
M<F4@=7-U86QL>2!S96YT('1O('!E;W!L92!O=&AE<B!T:&%N(&1I<F5C="!A
M;F0@:6YD:7)E8W0@<F5C:7!I96YT<R`H(E1O.B(@86YD(")#8SHB(')E8VEP
M:65N=',I('=H;R!N965D('1O(')E860@=VAA="!I<R!B96EN9R!W<FET=&5N
M(&%S('=E;&P@5TE42$]55"!T:&4@;W1H97(@<F5C:7!I96YT<R!K;F]W:6YG
M('1H870@=&AE>2!A<F4@<F5C96EV:6YG('1H92!E;6%I;"X@5&AU<R`G8FQI
M;F0G(&UE86YS('1H870@=&AE(&ED96YT:71Y(&]F('1H97-E(')E8VEP:65N
M=',@:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R(')E8VEP:65N=',@;V8@=&AE
M(&5M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H97D@:VYO=R!T:&5Y(&=O="!A
M(&-O<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H:7,@=&\@=&5L;"!A;B!A=71H
M;W)I='D@9FEG=7)E('1H870@>6]U(&%R92!T96QL:6YG('-O;65O;F4@<V]M
M971H:6YG('=I=&AO=70@86QA<FUI;F<@=&AE('!E<G-O;B!Y;W4@87)E('-E
M;F1I;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8F-C(CX*("`@(#QT
M:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@/&AE
M861I;F<^)G%U;W0[0F-C)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S
M92!T;R!R96-E:79E(&$@8FQI;F0@8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S
M86=E+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O
M;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O
M<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T)C8SHF<75O=#L@:6X@;W5T
M9V]I;F<@;6%I;"X@0FQI;F0@8V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S
M96YT('1O('!E;W!L92!O=&AE<B!T:&%N(&1I<F5C="!A;F0@:6YD:7)E8W0@
M<F5C:7!I96YT<R`H)G%U;W0[5&\Z)G%U;W0[(&%N9"`F<75O=#M#8SHF<75O
M=#L@<F5C:7!I96YT<RD@=VAO(&YE960@=&\@<F5A9"!W:&%T(&ES(&)E:6YG
M('=R:71T96X@87,@=V5L;"!7251(3U54('1H92!O=&AE<B!R96-I<&EE;G1S
M(&MN;W=I;F<@=&AA="!T:&5Y(&%R92!R96-E:79I;F<@=&AE(&5M86EL+B!4
M:'5S("=B;&EN9"<@;65A;G,@=&AA="!T:&4@:61E;G1I='D@;V8@=&AE<V4@
M<F5C:7!I96YT<R!I<R!H:61D96X@9G)O;2!A;&P@;W1H97(@<F5C:7!I96YT
M<R!O9B!T:&4@96UA:6PL(&%N9"!O;FQY('EO=2!A;F0@=&AE>2!K;F]W('1H
M97D@9V]T(&$@8V]P>2X@66]U('1Y<&EC86QL>2!U<V4@=&AI<R!T;R!T96QL
M(&%N(&%U=&AO<FET>2!F:6=U<F4@=&AA="!Y;W4@87)E('1E;&QI;F<@<V]M
M96]N92!S;VUE=&AI;F<@=VET:&]U="!A;&%R;6EN9R!T:&4@<&5R<V]N('EO
M=2!A<F4@<V5N9&EN9R!T:&4@86-T=6%L(&5M86EL('1O+@H@("`@/"]P87)A
M/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7-U
M8FIE8W0B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!3=6)J96-T/"]T:71L93X*("`@(#QH96%D:6YG/B)3=6)J
M96-T(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE('-U8FIE
M8W0@;V8@>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y(&9O;&QO=W,@(E-U8FIE
M8W0Z(B!I;B!O=71G;VEN9R!M86EL+B!+965P(&ET('-H;W)T+"!S:6UP;&4@
M86YD(&1E<V-R:7!T:79E+B`@5&AE('-U8FIE8W0@;&EN92!I<R!T:&4@96%S
M:65S="!W87D@9F]R('EO=2!A;F0@>6]U<B!C;W)R97-P;VYD96YT<R!T;R!R
M96UE;6)E<B!W:&%T('=A<R!I;B!T:&4@96UA:6P@86YD('1H=7,@:7,@=F5R
M>2!I;7!O<G1A;G0@:6X@;W)G86YI>FEN9R!Y;W5R(&5M86EL(&%N9"!F:6YD
M:6YG(&EM<&]R=&%N="!O;F5S(&QA=&5R+B`@06QS;RP@=VAE;B!Y;W4@)U)E
M<&QY)R!O<B`G1F]R=V%R9"<@86YD(&5M86EL('1H:7,@<W5B:F5C="!L:6YE
M(&ES(&-O<&EE9"!O=F5R(&EN=&\@=&AE(&YE=R!M97-S86=E(&%N9"!S;R!I
M<R!A('9A;'5A8FQE('=A>2!O9B!T96QL:6YG('=H870@;65S<V%G97,@9V\@
M=&]G971H97(@=&\@9F]R;2!A(")T:')E860B(&]F(&$@8V]N=F5R<V%T:6]N
M+B`@2&]W979E<BP@:68@=&AE("=297!L>2<@;W(@)T9O<G=A<F0G(&-O;G1A
M:6YS(&YE=R!I9&5A<RP@>6]U(&UA>2!W86YT('1O(&%D9"!S:6UP;&4@;6]D
M:69I8V%T:6]N<R!T;R!T:&4@)U-U8FIE8W0G(&QI;F4@<V\@=&AE(')E8VEP
M:65N="AS*2!C86X@9F]L;&]W('1H92!P<F]G<F5S<VEO;B!O9B!T:&4@(G1H
M<F5A9"XB"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+7-U8FIE8W0B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ(%-U8FIE8W0\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[
M4W5B:F5C="9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@
M=&AE('-U8FIE8W0@;V8@>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y(&9O;&QO
M=W,@)G%U;W0[4W5B:F5C=#HF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@2V5E
M<"!I="!S:&]R="P@<VEM<&QE(&%N9"!D97-C<FEP=&EV92X@(%1H92!S=6)J
M96-T(&QI;F4@:7,@=&AE(&5A<VEE<W0@=V%Y(&9O<B!Y;W4@86YD('EO=7(@
M8V]R<F5S<&]N9&5N=',@=&\@<F5M96UB97(@=VAA="!W87,@:6X@=&AE(&5M
M86EL(&%N9"!T:'5S(&ES('9E<GD@:6UP;W)T86YT(&EN(&]R9V%N:7II;F<@
M>6]U<B!E;6%I;"!A;F0@9FEN9&EN9R!I;7!O<G1A;G0@;VYE<R!L871E<BX@
M($%L<V\L('=H96X@>6]U("=297!L>2<@;W(@)T9O<G=A<F0G(&%N9"!E;6%I
M;"!T:&ES('-U8FIE8W0@;&EN92!I<R!C;W!I960@;W9E<B!I;G1O('1H92!N
M97<@;65S<V%G92!A;F0@<V\@:7,@82!V86QU86)L92!W87D@;V8@=&5L;&EN
M9R!W:&%T(&UE<W-A9V5S(&=O('1O9V5T:&5R('1O(&9O<FT@82`F<75O=#MT
M:')E860F<75O=#L@;V8@82!C;VYV97)S871I;VXN("!(;W=E=F5R+"!I9B!T
M:&4@)U)E<&QY)R!O<B`G1F]R=V%R9"<@8V]N=&%I;G,@;F5W(&ED96%S+"!Y
M;W4@;6%Y('=A;G0@=&\@861D('-I;7!L92!M;V1I9FEC871I;VYS('1O('1H
M92`G4W5B:F5C="<@;&EN92!S;R!T:&4@<F5C:7!I96YT*',I(&-A;B!F;VQL
M;W<@=&AE('!R;V=R97-S:6]N(&]F('1H92`F<75O=#MT:')E860N)G%U;W0[
M"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60]
M(F-O;7!O<V4M;W!T:6]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/DUE<W-A9V4@0V]M<&]S:71I;VXZ($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE
M861I;F<^(D]P=&EO;G,B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&5S
M92!/<'1I;VYS(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M97-S86=E+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`B4W!E;&P@0VAE8VLB('1O
M(&-H96-K('EO=7(@<W!E;&QI;F<N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@($-L:6-K(")!='1A8VAM96YT<R(@=&\@=FEE=R!A="!T:&4@8F]T=&]M
M(&]F('1H92!P86=E(&$@;&ES="!O9B!F:6QE<R!A='1A8VAE9"!T;R!T:&ES
M(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%C=&EV871E
M('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R`B4V%V92!C;W!Y(B!T;R!S879E
M(&$@8V]P>2!O9B!T:&ES(&UE<W-A9V4@:6X@>6]U<B`B4V5N="!-86EL(B!F
M;VQD97(N(%-A=F4@8V]P:65S(&]F(&EM<&]R=&%N="!E;6%I;',@>6]U('-E
M;F0@<V\@=&AA="!Y;W4@:&%V92!S;VUE=&AI;F<@=&\@<F5F97(@8F%C:R!T
M;R!L871E<B!A;F0@=&\@:V5E<"!A;B!A8V-U<F%T92!R96-O<F0@;V8@=VAA
M="!W87,@<V%I9"X@5V4@9&\@;F]T(')E8V]M;65N9"!Y;W4@<V%V92!E=F5R
M>2!E;6%I;"!S:6YC92!T:&5N('EO=7(@9&ES:R!S=&]R86=E('%U;W1A('=I
M;&P@8F4@=7-E9"!U<"!Q=6EC:VQY("AE<W!E8VEA;&QY('=H96X@>6]U('-E
M;F0@871T86-H;65N=',I(&%N9"!Y;W5R(&UA:6QB;W@@=VEL;"!B92!F=6QL
M(&%N9"!U;F%B;&4@=&\@<F5C96EV92!N97<@:6YC;VUI;F<@96UA:6PN(%EO
M=2!C86XL(&AO=V5V97(L('1U<FX@=&AI<R!F96%T=7)E("=O;B<@87,@>6]U
M<B!D969A=6QT('=I=&@@)U!R969E<F5N8V5S)R!O;B!T:&4@8FQU92!N879I
M9V%T:6]N(&)A<B!A="!T;W`N($)E(&-A<F5F=6P@=VAE;B!U<VEN9R!T:&ES
M(&UO9&EF:65D(&1E9F%U;'0@87,@>6]U('=I;&P@;F5E9"!T;R!P97)I;V1I
M8V%L;'D@<'5R9V4@>6]U<B`B4V5N="!-86EL(B!F;VQD97(@;W(@:70@=VEL
M;"!E=F5N='5A;&QY(&UA:V4@>6]U<B!M86EL8F]X(&9U;&P@86YD('5N=7-E
M86)L92X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@
M:60](F-O;7!O<V4M;W!T:6]N<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP
M;W-I=&EO;CH@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M/
M<'1I;VYS)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&5S92!/
M<'1I;VYS(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M97-S86=E+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`F<75O=#M3<&5L;"!#:&5C:R9Q
M=6]T.R!T;R!C:&5C:R!Y;W5R('-P96QL:6YG+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!#;&EC:R`F<75O=#M!='1A8VAM96YT<R9Q=6]T.R!T;R!V
M:65W(&%T('1H92!B;W1T;VT@;V8@=&AE('!A9V4@82!L:7-T(&]F(&9I;&5S
M(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O("9Q
M=6]T.U-A=F4@8V]P>29Q=6]T.R!T;R!S879E(&$@8V]P>2!O9B!T:&ES(&UE
M<W-A9V4@:6X@>6]U<B`F<75O=#M396YT($UA:6PF<75O=#L@9F]L9&5R+B!3
M879E(&-O<&EE<R!O9B!I;7!O<G1A;G0@96UA:6QS('EO=2!S96YD('-O('1H
M870@>6]U(&AA=F4@<V]M971H:6YG('1O(')E9F5R(&)A8VL@=&\@;&%T97(@
M86YD('1O(&ME97`@86X@86-C=7)A=&4@<F5C;W)D(&]F('=H870@=V%S('-A
M:60N(%=E(&1O(&YO="!R96-O;6UE;F0@>6]U('-A=F4@979E<GD@96UA:6P@
M<VEN8V4@=&AE;B!Y;W5R(&1I<VL@<W1O<F%G92!Q=6]T82!W:6QL(&)E('5S
M960@=7`@<75I8VML>2`H97-P96-I86QL>2!W:&5N('EO=2!S96YD(&%T=&%C
M:&UE;G1S*2!A;F0@>6]U<B!M86EL8F]X('=I;&P@8F4@9G5L;"!A;F0@=6YA
M8FQE('1O(')E8V5I=F4@;F5W(&EN8V]M:6YG(&5M86EL+B!9;W4@8V%N+"!H
M;W=E=F5R+"!T=7)N('1H:7,@9F5A='5R92`G;VXG(&%S('EO=7(@9&5F875L
M="!W:71H:6X@>6]U<B!)9&5N=&ET>2P@8GD@9V]I;F<@=&\@3W!T:6]N<RTF
M9W0[4&5R<V]N86P@26YF;W)M871I;VXM)F=T.T5D:70@>6]U<B!I9&5N=&ET
M:65S+B!"92!C87)E9G5L('=H96X@=7-I;F<@=&AI<R!M;V1I9FEE9"!D969A
M=6QT(&%S('EO=2!W:6QL(&YE960@=&\@<&5R:6]D:6-A;&QY('!U<F=E('EO
M=7(@)G%U;W0[4V5N="!-86EL)G%U;W0[(&9O;&1E<B!O<B!I="!W:6QL(&5V
M96YT=6%L;'D@;6%K92!Y;W5R(&UA:6QB;W@@9G5L;"!A;F0@=6YU<V5A8FQE
M+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)C;VUP;W-E+6%T=&%C:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE
M/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@("`\:&5A
M9&EN9SXB071T86-H(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("`@(%EO
M=2!M87D@871T86-H(&9I;&5S('1O('EO=7(@;65S<V%G92X*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@,3H@16ET:&5R+"!T>7!E('1H92!P871H(&%N
M9"!N86UE(&]F(&$@9FEL92!T:&%T('EO=2!W86YT(&%T=&%C:&5D('1O('1H
M:7,@;65S<V%G92!O<B!C;&EC:R`B0G)O=W-E(B!B=71T;VX@86YD('-E;&5C
M="!T:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N86UE
M(&]F('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N="!B
M;W@N($YO=R!P<F]C965D('1O"E-T97`@,BX*("`@(#PO<&%R83X*("`@(#QP
M87)A/E-T97`@,CH@0VQI8VL@(D%T=&%C:"(@8G5T=&]N+B!4:&4@9FEL92!N
M86UE(&%N9"!S:7IE('=I;&P@8F4@861D960@=&\@>6]U<B!L:7-T(&]F($%T
M=&%C:&UE;G1S+B!0;&5A<V4@;F]T92!T:&%T(&9O<B!L87)G92!F:6QE<R!A
M;F0O;W(@<VQO=V5R($EN=&5R;F5T(&-O;FYE8W1I;VYS+"!T:&4@<')O8V5S
M<R!O9B!U<&QO861I;F<@86YD(&%T=&%C:&EN9R!Y;W5R(&9I;&4@=&\@=&AE
M(&5M86EL(&UA>2!T86ME(&$@=VAI;&4N(%!L96%S92!B92!P871I96YT(&%N
M9"!D;R!N;W0@8VQI8VL@;VX@;W1H97(@=&AI;F=S('=H:6QE('EO=2!A<F4@
M=V%I=&EN9RX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT
M<GD@:60](F-O;7!O<V4M871T86-H(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!!='1A8V@\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[
M071T86-H)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y
M(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4[(&]N;'D@;VYE(&9I;&4@
M;6%Y(&)E(&%T=&%C:&5D(&%T(&$@=&EM92X*("`@(#PO<&%R83X*("`@(#QP
M87)A/E-T97`@,3H@16ET:&5R+"!T>7!E('1H92!P871H(&%N9"!N86UE(&]F
M(&$@9FEL92!T:&%T('EO=2!W86YT(&%T=&%C:&5D('1O('1H:7,@;65S<V%G
M92!O<B!C;&EC:R`F<75O=#M"<F]W<V4F<75O=#L@8G5T=&]N(&%N9"!S96QE
M8W0@=&AE(&9I;&4@=&\@8F4@871T871C:&5D+B!4:&4@<&%T:"!A;F0@;F%M
M92!O9B!T:&%T(&9I;&4@;F]W(&%P<&5A<G,@:6X@=&AE($%T=&%C:&UE;G0@
M8F]X+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`R.B!$96-I9&4@=VAE
M=&AE<B!Y;W4@=V%N="!T:&4@9FEL92!T;R!B92!V:65W960@87,@86X@871T
M86-H;65N="!O<B!I;FQI;F5D('=I=&@@=&AE(')E<W0@;V8@=&AE(&UE<W-A
M9V4N(%1H92!R96-E:79I;F<@<&5R<V]N*',I(&UA:6P@<F5A9&EN9R!S;V9T
M=V%R92!M=7-T(&)E(&%B;&4@=&\@:&%N9&QE('1H92!F:6QE('1Y<&4@:6YL
M:6YE.R!I9B!N;W0L('1H:7,@<&%R="!W:6QL(&)E('9I97=E9"!A<R!A;B!A
M='1A8VAM96YT(&EN<W1E860N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P
M(#,Z($-L:6-K("9Q=6]T.T%T=&%C:"9Q=6]T.R!B=71T;VXN(%1H92!F:6QE
M(&YA;64@86YD('-I>F4@=VEL;"!B92!A9&1E9"!T;R!Y;W5R(&QI<W0@;V8@
M071T86-H;65N=',N(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S
M(&%N9"]O<B!S;&]W97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C
M97-S(&]F('5P;&]A9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T
M:&4@96UA:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@
M86YD(&1O(&YO="!C;&EC:R!O=&AE<B!T:&EN9W,@=VAI;&4@>6]U(&%R92!W
M86ET:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(B!S=&%T93TB=6YK;F]W;B(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H;65N=',\
M+W1I=&QE/@H@("`@/&AE861I;F<^(D%T=&%C:&UE;G1S(CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AI<R!S96-T:6]N(&1I<W!L87ES(&$@;&ES="!O
M9B!F:6QE<R!A;')E861Y(&%T=&%C:&5D('1O('EO=7(@;65S<V%G92X@5&\@
M1&5L971E(&%N(&%T=&%C:&5D(&9I;&4Z"B`@("`\+W!A<F$^"B`@("`\<&%R
M83Y3=&5P(#$Z($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R!T
M:&4@871T86-H960@9FEL96YA;64@>6]U('=A;G0@=&\@1&5L971E+@H@("`@
M/"]P87)A/B`*("`@(#QP87)A/E-T97`@,CH@0VQI8VL@(D1E;&5T92!!='1A
M8VAM96YT*',I(BX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\
M96YT<GD@:60](F-O;7!O<V4M871T86-H;65N=',B/@H@("`@/'1I=&QE/DUE
M<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QH
M96%D:6YG/B9Q=6]T.T%T=&%C:&UE;G1S)G%U;W0[/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!4:&ES('-E8W1I;VX@9&ES<&QA>7,@82!L:7-T(&]F(&9I
M;&5S(&%L<F5A9'D@871T86-H960@=&\@>6]U<B!M97-S86=E+B!4;R!$96QE
M=&4@86X@871T86-H960@9FEL93H*("`@(#PO<&%R83X*("`@(#QP87)A/E-T
M97`@,3H@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O('1H92!A
M='1A8VAE9"!F:6QE;F%M92!Y;W4@=V%N="!T;R!$96QE=&4N"B`@("`\+W!A
M<F$^(`H@("`@/'!A<F$^4W1E<"`R.B!#;&EC:R`F<75O=#M$96QE=&4@071T
M86-H;65N="AS*29Q=6]T.RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UP<FEO<FET>2(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@4')I;W)I='D\
M+W1I=&QE/@H@("`@/&AE861I;F<^(E!R:6]R:71Y(CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!S971S('1H92`B6"U0<FEO<FET>2(@:&5A9&5R
M(&]N('EO=7(@;W5T9V]I;F<@;65S<V%G92X@5&AE(")8+5!R:6]R:71Y(B!T
M86<@:7,@82!S;W)T(&]F(")P<V5U9&\@<W1A;F1A<F0B('1H870@3F5T<V-A
M<&4L($UO>FEL;&$L($]P97)A+"!A;F0@3W5T;&]O:R!M86EL(&-L:65N=',@
M87!P96%R('1O(&%G<F5E(&]N+B!!;GD@;6%I;"!C;&EE;G1S('1H870@9&\@
M;F]T(&AA;F1L92!T:&ES(&AE861E<B!W:6QL('-I;7!L>2!I9VYO<F4@:70N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7-A
M=F4M871T86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A
M9V4@0V]M<&]S:71I;VXZ(%-A=F4@071T86-H;65N=',\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!$971E<FUI;F5S('=H971H97(@=&AE(&%T=&%C:&UE;G1S
M(&EN('EO=7(@8V]M<&]S:71I;VX@87)E('-A=F5D('=I=&@@=&AE(&UE<W-A
M9V4@=VAE;B!S=&]R960@:6X@=&AE('-E;G0M;6%I;"!F;VQD97(N("!)9B`B
M665S(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W:6QL(&)E('-A=F5D+B`@268@
M(DYO(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W:6QL(&)E('-T<FEP<&5D(&9R
M;VT@=&AE(&UE<W-A9V4@869T97(@:70@:7,@<V5N="!T;R!A;&P@<F5C:7!I
M96YT<RX@($-H;V]S:6YG(").;R(@=VEL;"!H96QP(&-O;G-E<G9E(&1I<VL@
M<W!A8V4@8GD@<F5M;W9I;F<@*'!O=&5N=&EA;&QY(&QA<F=E*2!A='1A8VAM
M96YT(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-A=F5D(&UE<W-A9V5S+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UL:6YK+6%T
M=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!,:6YK($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A
M/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y
M;W5R(&-O;7!O<VET:6]N(&%R92!S96YT(&%S(&$@<&%R="!O9B!T:&4@;6%I
M;"!M97-S86=E(&]R('=H971H97(@=&AO<V4@871T86-H;65N=',@87)E(&ME
M<'0@;VX@82!L;V-A;"!S97)V97(N("!)9B!A='1A8VAM96YT<R!A<F4@;&EN
M:V5D+"!T:&4@<F5C:7!I96YT*',I(&]F('EO=7(@;65S<V%G92!W:6QL(&)E
M('!R;W9I9&5D(&$@=V5B;&EN:R!W:&5R92!T:&5Y(&-A;B!D;W=N;&]A9"!T
M:&4@871T86-H;65N="AS*2X@($QI;FMI;F<@871T86-H;65N=',@:&%S('1H
M92!A9'9A;G1A9V4@;V8@=')E;65N9&]U<VQY(')E9'5C:6YG('1H92!S:7IE
M(&]F(&]U=&=O:6YG(&UE<W-A9V5S+B`@3&EN:VEN9R!A='1A8VAM96YT<R!H
M87,@=&AE(&1I<V%D=F%N=&%G92!T:&%T('1H92!C;VYT96YT(&]F('1H92!A
M='1A8VAM96YT<R!C86X@;F]T(&)E(&=U87)A;G1E960@=&\@8F4@879A:6QA
M8FQE(&EN('1H92!F=71U<F4@<VEN8V4@=&AE(&%T=&%C:&UE;G0@9&%T82!I
M<R!N;W0@;&]C871E9"!W:71H:6X@=&AE(&4M;6%I;"!M97-S86=E+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V5A<F-H(B!S=&%T93TB
M=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!396%R8V@\+W1I=&QE/@H@
M("`@/&AE861I;F<^4V5A<F-H($-R:71E<FEA/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("`@("`@2&5L<"!T97AT('1O(&)E('=R:71T96XN"B`@("`\+W!A
M<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)S96%R8V@B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG
M/E-E87)C:"!#<FET97)I83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U
M(&UA>2!S96%R8V@@9F]R(&UE<W-A9V5S(&9R;VT@>6]U<B!F;VQD97)S('5S
M:6YG(&1I9F9E<F5N="!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#$Z($5N=&5R('1E>'0@=&\@=&AE(&9I96QD<R!Y;W4@
M=V%N="!T;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A
M<F$^"B`@("`\<&%R83Y3=&5P(#(Z($-H;V]S92!T:&4@;65S<V%G92!F;&%G
M*',I('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@,SH@0VAO;W-E('1H92!F;VQD97(H<RD@9G)O
M;2!W:&EC:"!T;R!S96%R8V@@9F]R('1H92!M97-S86=E<RX*("`@(#PO<&%R
M83X*("`@(#QP87)A/E-T97`@-#H@0VQI8VL@)G%U;W0[4V5A<F-H)G%U;W0[
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!)9B!A;GD@;65S<V%G97,@
M;6%T8VAE9"!Y;W5R('-E87)C:"!C<FET97)I82P@=&AE;B!T:&4@<W5B:F5C
M=',@;V8@=&AE<V4@;65S<V%G97,@=VEL;"!B92!S:&]W;B!I;B!T:&4@)G%U
M;W0[4V5A<F-H(%)E<W5L=',F<75O=#L@=FEE=RX*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]L9&5R+6]P=&EO;G,B
M('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E;65N
M=#PO=&ET;&4^"B`@("`\:&5A9&EN9SY&;VQD97(@3W!T:6]N<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@("!9;W4@8V%N('-E;&5C="!A(&9O;&1E<B!B
M>2!U<VEN9R!T:&4@<F%D:6\@8G5T=&]N<R!A;&]N9R!T:&4@;&5F="!C;VQU
M;6XN("!/;F-E('EO=2!H879E(&1O;F4@=&AI<RP@<V5L96-T('1H92!O<'1I
M;VX@>6]U('=I<V@@=&\@<&5R9F]R;2!O;B!T:&4@9F]L9&5R('9I82!T:&4@
M<V5L96-T(&)O>"!T;R!T:&4@;&5F="X*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@("!9;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@9G5R=&AE<B!O<'1I
M;VYS+B`@0F4@8V%R969U;"!W:71H('1H92!D96QE=&4@;W!T:6]N+"!A<R!Y
M;W4@8V%N(&QO<V4@86QL('1H92!M97-S86=E<R!I;B!A(&9O;&1E<B!I9B!Y
M;W4@9&5L971E(&ET(&)Y(&UI<W1A:V4A"B`@("`\+W!A<F$^"CPA+2T@16YG
M;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(^"B`@("`\
M=&ET;&4^1F]L9&5R($UA;F%G96UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^
M1F]L9&5R($]P=&EO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@66]U
M(&-A;B!S96QE8W0@82!F;VQD97(@8GD@=7-I;F<@=&AE(')A9&EO(&)U='1O
M;G,@86QO;F<@=&AE(&QE9G0@8V]L=6UN+B`@3VYC92!Y;W4@:&%V92!D;VYE
M('1H:7,L('-E;&5C="!T:&4@;W!T:6]N('EO=2!W:7-H('1O('!E<F9O<FT@
M;VX@=&AE(&9O;&1E<B!V:6$@=&AE('-E;&5C="!B;W@@=&\@=&AE(&QE9G0N
M"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@66]U('=I;&P@8F4@<')O
M;7!T960@9F]R(&9U<G1H97(@;W!T:6]N<RX@($)E(&-A<F5F=6P@=VET:"!T
M:&4@9&5L971E(&]P=&EO;BP@87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@;65S
M<V%G97,@:6X@82!F;VQD97(@:68@>6]U(&1E;&5T92!I="!B>2!M:7-T86ME
M(0H@("`@/"]P87)A/@H@("`@/&AE861I;F<^26UP;W)T(&UB;W@@1FEL93PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("!4:&ES(&]P=&EO;B!W:6QL(&EM
M<&]R="!A(&UB;W@@9F]R;6%T(&9I;&4@:6YT;R!T:&4@9F]L9&5R(&]F('EO
M=7(@8VAO:6-E+B!#:&]O<V4@,2`H;VYE*2!F;VQD97(@=&\@:6UP;W)T('1H
M92!M97-S86=E<R!I;G1O(&%N9"!T:&5N('-E;&5C="!T:&ES(&]P=&EO;BX@
M66]U('=I;&P@=&AE;B!B92!T86ME;B!T;R!A('!A9V4@=&AA="!W:6QL('!R
M;VUP="!F;W(@=&AE(&UB;W@@9FEL92!T;R!I;7!O<G0N"B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUW:61G
M971S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E;65N
M=#H@1&ES<&QA>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY3:&]W+TAI9&4@56YS
M=6)S8W)I8F5D/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!U<VEN9R!)
M34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS+"!S:&]W+VAI9&4@=&AE('5N<W5B
M<V-R:6)E9"!F;VQD97)S+B`@5&\@<W5B<V-R:6)E+W5N<W5B<V-R:6)E('1O
M(&$@9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K8F]X(&YE>'0@=&\@=&AE(&9O
M;&1E<FYA;64@86YD('5S92!T:&4@4W5B<V-R:6)E+U5N<W5B<V-R:6)E(&]P
M=&EO;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D<F]P+61O=VX@;65N=2X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9"!!;&P\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($5X<&%N9"!A;&P@9F]L9&5R(&5N=')I97,N"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S92!!;&P\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-O;&QA<'-E(&%L;"!F;VQD97(@96YT<FEE<RX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<G,B('-T871E
M/2)U;FMN;W=N(CX*("`@(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-L:6-K(&]N('1H92`B07!P;'D@1FEL=&5R(B!I8V]N
M(&YE>'0@=&\@=&AE($E.0D]8(&YA;64@:6X@=&AE(&UA:6QB;W@@=FEE=R!T
M;R!F:6QT97(@86QL('5N9&5L971E9"!M97-S86=E<R!A8V-O<F1I;F<@=&\@
M=&AE('-P96-I9FEE9"!R=6QE<RX@($]R+"!A;'1E<FYA=&5V;'DL(&-L:6-K
M(&]N(")!<'!L>2!!;&P@4G5L97,B(&EN('1H92!F:6QT97(@;65N=2X@($YO
M=&4@=&AA="!F:6QT97)I;F<@:7,@;F]T(&1O;F4@875T;VUA=&EC86QL>2X*
M("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F9I
M;'1E<G,B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($%P<&QY/"]T:71L93X*("`@
M(#QH96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@0VQI8VL@;VX@=&AE("9Q=6]T.T%P<&QY($9I;'1E<B9Q=6]T
M.R!I8V]N(&YE>'0@=&\@=&AE($E.0D]8(&YA;64@:6X@=&AE(&UA:6QB;W@@
M=FEE=R!T;R!F:6QT97(@86QL('5N9&5L971E9"!M97-S86=E<R!A8V-O<F1I
M;F<@=&\@=&AE('-P96-I9FEE9"!R=6QE<RX@($]R+"!A;'1E<FYA=&5V;'DL
M(&-L:6-K(&]N("9Q=6]T.T%P<&QY($%L;"!2=6QE<R9Q=6]T.R!I;B!T:&4@
M9FEL=&5R(&UE;G4N("!.;W1E('1H870@9FEL=&5R:6YG(&ES(&YO="!D;VYE
M(&%U=&]M871I8V%L;'DN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R
M>3X*("`\96YT<GD@:60](F9I;'1E<BUE9&ET+7)U;&5S(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y&:6QT97)S.B!%9&ET($9I;'1E<B!2=6QE<SPO=&ET
M;&4^"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@1FEL=&5R(%)U;&5S/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R(&9I;'1E
M<B!R=6QE<R(@=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N
M(&%D9"P@9&5L971E+"!A;F0@961I="!T:&4@8W5R<F5N=&QY(&%C=&EV92!S
M970@;V8@9FEL=&5R(')U;&5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB9FEL=&5R+65D:70M8FQA8VML:7-T(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y&:6QT97)S.B!%9&ET($)L86-K;&ES=#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY%9&ET(%EO=7(@0FQA8VML:7-T/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R(&)L86-K;&ES="(@=&\@
M<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E
M+"!A;F0@961I="!T:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S('EO=2!!
M3%=!65,@<F5F=7-E(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](F9I;'1E<BUE9&ET+7=H:71E;&ES="(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!7:&ET96QI<W0\+W1I=&QE
M/@H@("`@/&AE861I;F<^161I="!9;W5R(%=H:71E;&ES=#PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!W:&ET96QI<W0B
M('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E
M;&5T92P@86YD(&5D:70@=&AE(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y
M;W4@04Q705E3(&%C8V5P="!M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM;&]G:6XB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!O;B!,;V=I;CPO=&ET;&4^
M"B`@("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L97,@57!O;B!,;V=O;C\\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N('1O
M(&%L=V%Y<R!A<'!L>2!F:6QT97)S('=H96X@9FER<W0@;&]G9VEN9R!O;G1O
M($E-4"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E
M<BUO;BUD:7-P;&%Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S
M.B!&:6QT97(@;VX@4F5F<F5S:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L
M>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@=&\@
M86QW87ES(&%P<&QY(&9I;'1E<G,@=VAE;F5V97(@>6]U<B!V:65W('1H92!)
M3D)/6#\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E
M<BUA;GDM;6%I;&)O>"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R
M<SH@1FEL=&5R(&%N>2!-86EL8F]X/"]T:71L93X*("`@(#QH96%D:6YG/D%P
M<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@;6%I;&)O>#\\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N(&EF('EO=2!W86YT('1O
M(&)E(&%L;&]W960@=&\@87!P;'D@9FEL=&5R(')U;&5S('1O(&%N>2!M86EL
M8F]X+B!.;W)M86QL>2P@9FEL=&5R:6YG(')U;&5S(&%R92!O;FQY(&%P<&QI
M960@=&\@;F5W(&UA:6P@=&AA="!I<R!D96QI=F5R960@=&\@>6]U<B!)3D)/
M6"X@($EF('1H:7,@;W!T:6]N(&ES(&-H96-K960L(&%N(&EC;VX@=VEL;"!A
M<'!E87(@;VX@86QL(&UA:6QB;W@@<&%G9V5S('1H870@=VEL;"!A;&QO=R!Y
M;W4@=&\@87!P;'D@9FEL=&5R(')U;&5S('1O('1H92!M97-S86=E<R!I;B!T
M:&4@8W5R<F5N="!M86EL8F]X+B`@3D]413H@1FEL=&5R:6YG(&EN(&UA:6QB
M;WAE<R!O=&AE<B!T:&%N($E.0D]8(&UA>2!P<F]D=6-E('-T<F%N9V4@*&4N
M9RX@=&AE(&9I;'1E<B!M87D@8V%U<V4@82!C;W!Y(&]F(&UE<W-A9V5S('1O
M(&)E(&1E;&EV97)E9"!T;R!T:&4@<V%M92!M86EL8F]X*2!A;F0O;W(@=6YD
M97-I<F5D(')E<W5L=',@*&4N9RX@:70@;6%Y(&-A=7-E(&UE<W-A9V5S('1O
M(&)E(&UO=F5D+V1E;&5T960@:68@;F5W(&9I;'1E<FEN9R!R=6QE<R!H879E
M(&)E96X@:6UP;&5M96YT960@<VEN8V4@=&AE(&UE<W-A9V4@:&%S(&)E96X@
M9&5L:79E<F5D('1O('1H92!C=7)R96YT(&UA:6QB;W@I+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6-O;7!O<V4M871T86-H+7!U
M8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!!='1A8V@@4'5B
M;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!='1A8V@@4'5B;&EC($ME
M>3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@<V5L96-T960@=&AE;B!A
M(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@:68@:70@97AI<W1S+"!W
M:6QL(&)E(&%T=&%C:&5D('1O('1H92!O=71G;VEN9R!M97-S86=E+B`@66]U
M(&-A;B!S970@=&AE(&1E9F%U;'0@8F5H879I;W(@=FEA('1H92!01U`@3W!T
M:6]N<R!S8W)E96XN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M;W!T:6]N+7-C86XM8F]D>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4$=0.B!38V%N(%1E>'0@0F]D:65S/"]T:71L93X*("`@(#QH96%D:6YG
M/E-C86X@5&5X="!";V1I97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF
M('-E;&5C=&5D('1H96X@24U0('=I;&P@<V-A;B!T:&4@8F]D>2!O9B!A;&P@
M=&5X="!M97-S86=E<R!F;W(@4$=0(&1A=&$L(&%N9"!D:7-P;&%Y('1H92!R
M97-U;'1S(&EF(&%N>2!D871A(&ES(&9O=6YD+B`@3F]T92!T:&%T('1H:7,@
M;6%Y('-L;W<@9&]W;B!T:&4@<WES=&5M(&%S(&5V97)Y('1E>'0@;65S<V%G
M92!M=7-T(&)E('-C86YN960@:6X@:71S(&5N=&ER971Y(&9O<B!01U`@9&%T
M82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M
M;W!T:6]N<RUE;F-R>7!T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y#;VUP
M;W-E.B!%;F-R>7!T:6]N($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^
M3F\@16YC<GEP=&EO;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5N9"!T
M:&4@;65S<V%G92!W:71H(&YO(&5N8W)Y<'1I;VX@*&-L96%R=&5X="DN"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@16YC<GEP="!-97-S86=E/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL(&5N8W)Y
M<'0@=&AE(&-U<G)E;G0@;65S<V%G92P@=7-I;F<@4$=0(&%N9"!T:&4@<F5C
M:7!I96YT<R!P97)S;VYA;"!P=6)L:6,@:V5Y+"!A;F0@=&AE;B!S96YD(&ET
M+B!9;W4@8V%N(&]N;'D@<V5N9"!A(&UE<W-A9V4@=&\@82!S:6YG;&4@<&5R
M<V]N('5S:6YG('1H:7,@;W!T:6]N+B!9;W4@35535"!H879E('1H92!P=6)L
M:6,@:V5Y(&]F('1H92!R96-I<&EE;G0@<W1O<F5D(&EN('EO=7(@861D<F5S
M<V)O;VL@;W(@96QS92!T:&ES(&]P=&EO;B!W:6QL(&9A:6PN($EF('EO=2!H
M879E('1H92!P=6)L:6,@:V5Y(&9O<B!T:&4@<F5C:7!I96YT(&EN('EO=7(@
M861D<F5S<V)O;VL@86YD(&%R92!S=&EL;"!R96-E:79I;F<@97)R;W)S+"!V
M97)I9GD@=&AA="!T:&4@92UM86EL(&%D9')E<W,@:6X@=&AE(')E8VEP:65N
M="!F:65L9"!M871C:&5S('1H92!E+6UA:6P@861D<F5S<R!W:&5R92!T:&4@
M<'5B;&EC(&ME>2!I<R!S=&]R960N(%1H92!E;F-R>7!T960@9&%T82!W:6QL
M(&)E(&%T=&%C:&5D('1O('1H92!O=71G;VEN9R!M97-S86=E+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^4$=0(%-I9VX@365S<V%G93PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!D:6=I=&%L;'D@<VEG
M;B!T:&4@8W5R<F5N="!M97-S86=E('5S:6YG(%!'4"!A;F0@>6]U<B!P97)S
M;VYA;"!P<FEV871E(&ME>2X@268@>6]U(&AA=F4@;F]T(&%L<F5A9'D@96YT
M97)E9"!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!P<FEV871E(&ME>2!D=7)I
M;F<@=&AI<R!S97-S:6]N('EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!I="X@
M(%1H92!R96-E:7!I96YT(&UU<W0@:&%V92!A(&-O<'D@;V8@>6]U<B!P=6)L
M:6,@:V5Y('1O(&1I9VET86QL>2!V97)I9GD@>6]U<@H@("`@<VEG;F%T=7)E
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0(%-I9VXO16YC<GEP="!-
M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W
M:6QL(&9I<G-T(&1I9VET86QL>2!S:6=N('EO=7(@;65S<V%G92!A;F0@=&AE
M;B!W:6QL(&5N8W)Y<'0@=&AE(')E<W5L=&EN9R!O=71P=70N(%-E92!T:&4@
M)U!'4"!%;F-R>7!T($UE<W-A9V4G(&%N9"`G4$=0(%-I9VX@365S<V%G92<@
M96YT<FEE<R!F;W(@9G5R=&AE<B!I;F9O<FUA=&EO;BX*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/E,O34E-12!%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/E,O34E-12!3:6=N($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%1/1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-12!3:6=N+T5N
M8W)Y<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5$]$3PH@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]V97)V:65W
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($]V97)V:65W/"]T:71L
M93X*("`@(#QH96%D:6YG/E=H870@:7,@4$=0/SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@4$=0(&ES(&$@=&]O;"!F;W(@<V5C=7)E(&-O;6UU;FEC871I
M;VX@86YD(&1A=&$@<W1O<F%G92P@97-P96-I86QL>2!F;W(@=7-E('=I=&@@
M92UM86EL+B!)="!C86X@8F4@=7-E9"!T;R!E;F-R>7!T(&1A=&$@86YD('1O
M(&-R96%T92!D:6=I=&%L('-I9VYA='5R97,N($E-4"!U<V5S($=N=5!'("A'
M3E4@4')I=F%C>2!'=6%R9"D@=&\@<')O=FED92!T:&ES(&9U;F-T:6]N86QI
M='DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;F%B;&4@4$=0(&9U;F-T
M:6]N86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!T:&ES(&]P
M=&EO;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@86)L92!T;R!C<F5A=&4O
M=FEE=R!Y;W5R('!E<G-O;F%L(%!'4"!K97ES+"!A9&0O9&5L971E('!U8FQI
M8R!K97ES(&9R;VT@;W1H97(@:6YD:79I9'5A;',L(')E860@96YC<GEP=&5D
M(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG;F5D(&UA:6PL(&%N9"!E;F-R
M>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO;BUA='1A8V@M<'5B:V5Y(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($]P=&EO;G,@+2!!='1A8V@@
M4'5B;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY/<'1I;VYS("T@071T
M86-H(%!U8FQI8R!+97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('-E
M;&5C=&5D('1H96X@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97DL(&EF
M(&ET(&5X:7-T<RP@=VEL;"!B>2!D969A=6QT(&)E(&%T=&%C:&5D('1O(&%L
M;"!O=71G;VEN9R!M97-S86=E<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UM86YA9V4M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI
M<R!S8W)E96X@;&ES=',@86QL(&]F('1H92!C=7)R96YT('5S97)S(&EN('EO
M=7(@861D<F5S<V)O;VL@=&AA="!H879E(%!'4"!P=6)L:6,@:V5Y<RX@5&AE
M<V4@=7-E<G,@87)E('1H92!/3DQ9('5S97)S('1H870@>6]U(&-A;B!E:71H
M97(@,2D@<V5N9"!A;B!E;F-R>7!T960@;65S<V%G92!T;R`M3U(M(#(I('9E
M<FEF>2!A(&1I9VET86P@<VEG;F%T=7)E+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@82!W
M:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^
M"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P=6)L:6,@
M:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5L971E/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!$96QE=&5S('1H92!P=6)L:6,@:V5Y(&9R;VT@
M>6]U<B!A9&1R97-S8F]O:RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UI;7!O<G0M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y<R`M($EM<&]R=#PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY);7!O<G0@4'5B;&EC($ME>7,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1H:7,@8G5T=&]N('=I;&P@;W!E;B!A('=I;F1O=R!W
M:&5R92!Y;W4@8V%N(&UA;G5A;&QY(&EM<&]R="!A(%!'4"!P=6)L:6,@:V5Y
M+B`@5&AE(&ME>2!C86X@96ET:&5R(&)E('!A<W1E9"!I;G1O(&$@=&5X=&9I
M96QD(&]R+"!I9B!T:&4@:V5Y(')E<VED97,@:6X@82!F:6QE(&]N('EO=7(@
M;&]C86P@8V]M<'5T97(L('EO=2!C86X@:6UP;W)T(&ET+B`@268@=&AE(&ME
M>2!I<R!V86QI9"!I="!W:6QL(&)E(&EN<V5R=&5D(&EN=&\@>6]U<B!A9&1R
M97-S8F]O:R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L;W-E.R!I9B!N;W0@=F%L
M:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R971U<FYE9"!E>'!L86EN
M:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UO=F5R=FEE=RUP97)S;VYA;&ME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@>6]U
M('=A;G0@=&\@9&EG:71A;&QY('-I9VX@;65S<V%G97,@;W(@96YA8FQE(&]T
M:&5R<R!T;R!S96YD('EO=2!E;F-R>7!T960@;65S<V%G97,L('EO=2!M=7-T
M(&AA=F4@>6]U<B!O=VX@<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@4$=0(&ME
M>7!A:7(N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY9;W5R(%!U8FQI8R!+
M97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=7(@<'5B;&EC(&ME>2!S
M:&]U;&0@8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY('!E<G-O;B!T:&%T('EO
M=2!W86YT('1O(&)E(&%B;&4@=&\@<V5N9"!Y;W4@96YC<GEP=&5D(&UE<W-A
M9V5S('1H870@;VYL>2!93U4@8V%N(&1E8W)Y<'0@*'5S:6YG('EO=7(@<')I
M=F%T92!K97DI+B!!9&1I=&EO;F%L;'DL('EO=7(@<'5B;&EC(&ME>2!N965D
M<R!T;R!B92!M861E(&%V86EL86)L92!T;R!A;GEB;V1Y('EO=2!S96YD(&$@
M9&1I9VET86QL>2!S:6=N960@;65S<V%G92!T;R`M('1H92!P=6)L:6,@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@9&EG:71A;"!S:6=N871U<F4N
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY9;W5R(%!R:79A=&4@2V5Y/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!R:79A=&4@:V5Y(&ES(&YE
M8V5S<V%R>2!T;R!D96-R>7!T(&%N>2!M97-S86=E(&5N8W)Y<'1E9"!U<VEN
M9R!Y;W5R('!U8FQI8R!K97DN($%D9&ET:6]N86QL>2P@>6]U<B!P<FEV871E
M(&ME>2!I<R!N965D960@:68@>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@
M82!M97-S86=E+B!9;W5R('!R:79A=&4@:V5Y('=I;&P@8F4@<')O=&5C=&5D
M('9I82!A('!A<W-P:')A<V4@8W)E871E9"!W:&5N('1H92!K97ES(&%R92!G
M96YE<F%T960N(%1H=7,L('1O('!E<F9O<FT@86YY(&%C=&EV:71Y('1H870@
M<F5Q=6ER97,@>6]U<B!P<FEV871E(&ME>2P@24U0('=I;&P@<')O;7!T('EO
M=2!F;W(@>6]U<B!P87-S<&AR87-E+B!9;W4@;VYL>2!N965D('1O(&EN<V5R
M="!Y;W5R('!A<W-P:')A<V4@;VYC92!P97(@<V5S<VEO;B`M($E-4"!W:6QL
M('-T;W)E('EO=7(@<&%S<W!H<F%S92!U;G1I;"!Y;W4@;&]G;W5T("A3;R!B
M92!S=7)E('1O(&QO9V]U="$I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!U8FQI8R(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M(%!U8FQI
M8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!U
M8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@
M86)O=70@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!R:79A=&4B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@
M+2!0<FEV871E($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY%;G1E<B!087-S
M<&AR87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!T:&4@<&%S
M<W!H<F%S92!D:6%L;V<@=VEN9&]W+B!4:&4@<&%S<W!H<F%S92!E;G1E<F5D
M+"!I9B!C;W)R96-T+"!W:6QL(&)E('-T;W)E9"!B>2!)35`@=6YT:6P@>6]U
M<B!S97-S:6]N(&5N9',N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY5;FQO
M860@4&%S<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4F5M;W9E
M<R!T:&4@<W1O<F5D('!A<W-P:')A<V4@9G)O;2!)35`@+2!A;GD@861D:71I
M;VYA;"!U<V%G92!O9B!T:&4@<')I=F%T92!K97D@=VEL;"!R97%U:7)E('EO
M=2!T;R!R965N=&5R('1H92!P87-S<&AE87-E+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@
M82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!R:79A=&4@:V5Y+B!$3R!.3U0@
M4T5.1"!42$E3($M%62!43R!!3EE/3D4@+2!T:&ES(&]P=&EO;B!I<R!S=')I
M8W1L>2!S;R!T:&%T('EO=2!C86X@97AP;W)T('EO=7(@24U0('!E<G-O;F%L
M('!R:79A=&4@:V5Y(&9O<B!U<V4@:6X@86YO=&AE<B!P<F]G<F%M+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@
M<')I=F%T92!K97DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM9&5L971E(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@1&5L971E/"]T:71L
M93X*("`@(#QH96%D:6YG/D1E;&5T92!097)S;VYA;"!+97ES/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&ES(&)U='1O;B!W:6QL(&1E;&5T92!Y;W5R
M('!E<G-O;F%L('!U8FQI8R]P<FEV871E(&ME>7!A:7(@9G)O;2!)35`G<R!P
M<F5F97)E;F-E<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M;F%M92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@3F%M93PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY.86UE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4:&4@;F%M92!Y;W4@=V%N="!E;6)E9&1E9"!I;B!Y;W5R('!E<G-O;F%L
M(&ME>7,N($$@<F5Q=6ER960@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6-O;6UE;G0B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L
M($ME>2`M($-O;6UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^0V]M;65N=#PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@02!C;VUM96YT('-T<FEN9R!Y;W4@
M=V%N="!E;6)E9&1E9"!I;B!Y;W5R('!E<G-O;F%L(&ME>7,N($%N(&]P=&EO
M;F%L(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UE;6%I;"(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@12UM86EL($%D
M9')E<W,\+W1I=&QE/@H@("`@/&AE861I;F<^12UM86EL($%D9')E<W,\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%1H92!E+6UA:6P@861D<F5S<R!Y;W4@
M=V%N="!A<W-O8VEA=&5D('=I=&@@>6]U<B!P97)S;VYA;"!K97ES+B!!(')E
M<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UK97EL96YG=&@B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($ME
M>6QE;F=T:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY+97EL96YG=&@\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H92!K97EL96YG=&@L(&EN(&)Y=&5S+"!O
M9B!Y;W5R(&=E;F5R871E9"!K97DN(%1H92!G<F5A=&5R('1H92!V86QU92P@
M=&AE(&=R96%T97(@=&AE('!R;W1E8W1I;VX@*&%N9"!A;'-O(&=R96%T97(@
M9V5N97)A=&EO;B!T:6UE(&%N9"!E;F-R>7!T:6]N('1I;64I+B`Q,#(T(&)Y
M=&5S(&ES('1H92!D969A=6QT("T@=&AI<R!V86QU92!P<F]V:61E<R!E>&-E
M;&QE;G0@<')O=&5C=&EO;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M<&%S<W!H<F%S92(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y
M("T@4&%S<W!H<F%S93PO=&ET;&4^"B`@("`\:&5A9&EN9SY.86UE/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!4:&4@<&%S<W!H<F%S92!U<V5D('1O('!R
M;W1E8W0O96YC<GEP="!Y;W5R('!E<G-O;F%L('!R:79A=&4@:V5Y+B!4:&ES
M('-H;W5L9"!B92!!5"!,14%35"`V(&-H87)A8W1E<G,L('-H;W5L9"!.3U0@
M8F4@=&AE('-A;64@87,@>6]U<B!L;V=I;B!P87-S=V]R9"P@<VAO=6QD($Y/
M5"!B92!B87-E9"!O;B!A(&1I8W1I;VYA<GD@=V]R9"P@86YD('-H;W5L9"!I
M;F-L=61E(&)O=&@@;G5M8F5R<R!A;F0@;&5T=&5R<RX@66]U(&UU<W0@96YT
M97(@=&AI<R!P87-S<&AR87-E('1W:6-E(&9O<B!V97)I9FEC871I;VX@<'5R
M<&]S97,N($$@<F5Q=6ER960@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6%C=&EO;G,B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L
M($ME>2`M($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^0W)E871E($ME
M>7,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($-R96%T92!A;F0@<W1O<F4@
M>6]U<B!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY);7!O<G0@2V5Y<&%I<CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@26UP;W)T(&$@<&5R<V]N86PO<')I=F%T92!K97EP86ER+B!4:&ES
M(&)U='1O;B!O<&5N<R!A('=I;F1O=R!W:&5R92!Y;W4@8V%N(&UA;G5A;&QY
M(&EM<&]R="!Y;W5R(&5X:7-T:6YG(%!'4"!P97)S;VYA;"!P=6)L:6,O<')I
M=F%T92!K97EP86ER+B`@5&AE(&ME>7,@8V%N(&5I=&AE<B!B92!P87-T960@
M:6YT;R!A('1E>'1F:65L9"!O<BP@:68@=&AE(&ME>7,@<F5S:61E(&EN(&$@
M9FEL92!O;B!Y;W5R(&QO8V%L(&-O;7!U=&5R+"!Y;W4@8V%N(&EM<&]R="!T
M:&5M+B`@268@=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E
M<G1E9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL
M;"!C;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@
M8F4@<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=R(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4R]-24U%.B!/=F5R=FEE=SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY7:&%T(&ES(%,O34E-13\\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%,O34E-12!I<R!A('!R:79A=&4O<'5B;&EC(&ME>2!P86ER('-Y<W1E;2!W
M:&EC:"!P<F]V:61E<R!D:6=I=&%L('-I9VYA='5R97,L(&UE<W-A9V4@<')I
M=F%C>2P@86YD('1A;7!E<B!D971E8W1I;VX@:6X@82!O<&5N+"!I;G1E<F]P
M97)A8FQE('=A>2X@(%,O34E-12!C86X@<')O=FED92!M97-S86=E('!R:79A
M8WD@8GD@96YC<GEP=&EN9R!M97-S86=E<R!T:&%T(&]N;'D@=&AE('-E;F1E
M<B!A;F0@=&AE(&EN=&5N9&5D(')E8VEP:65N=',@8V%N(&1E8V]D92X@($ET
M(&%L;&]W<R!Y;W4@=&\@:61E;G1I9GD@=&AE('-E;F1E<B!O9B!A(&UE<W-A
M9V4@=FEA(&$@9&EG:71A;"!S:6=N871U<F4N("!4;V=E=&AE<BP@=&AI<R!E
M;F-R>7!T:6]N(&%N9"!D:6=I=&%L('-I9VYI;F<@:&5L<"!P<F]V:61E('1A
M;7!E<B!D971E8W1I;VXL(&%L;&]W:6YG(')E8VEP:65N=',@=&\@9&5T97)M
M:6YE('=H971H97(@82!M97-S86=E('=A<R!A;'1E<F5D(&%F=&5R(&ET('=A
M<R!S96YT+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16YA8FQE(%,O34E-
M12!F=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@
M=&AI<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@
M:6UP;W)T('EO=7(@<&5R<V]N86P@4R]-24U%(&ME>7,L(')E860@96YC<GEP
M=&5D(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG;F5D(&UA:6PL(&%N9"!E
M;F-R>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<M<&5R<V]N86QK
M97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@4&5R<V]N86P@
M2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@268@>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@
M;W(@96YC<GEP="!M97-S86=E<R!Y;W4@;75S="!H879E('EO=7(@;W=N('!E
M<G-O;F%L('!U8FQI8R]P<FEV871E(%,O34E-12!K97EP86ER+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M:6UP;W)T+7!E<G-O
M;F%L+6-E<G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z($EM
M<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+W1I=&QE/@H@("`@/&AE861I
M;F<^26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@26UP;W)T('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M
M(&$@4$M#4R`C,3(@9F]R;6%T(&9I;&4N(%!+0U,@(S$R(&9I;&5S(&ES('1H
M92!F:6QE('5S=6%L;'D@9V5N97)A=&5D('=H96X@97AP;W)T:6YG(&$@:V5Y
M(&9R;VT@82!B<F]W<V5R("AE+F<N($EN=&5R;F5T($5X<&QO<F5R+"!&:7)E
M9F]X*2!O<B!F<F]M(&$@8V5R=&EF:6-A=&4@<W1O<F4@;6%I;G1A:6YE9"!B
M>2!A;B!/<&5R871I;F<@4WES=&5M("AE+F<N(%=I;F1O=W,@6%`I+B!)9B!T
M:&4@:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E(&EN<V5R=&5D(&EN=&\@
M>6]U<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L;W-E.R!I
M9B!N;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R971U<FYE
M9"!E>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G-M:6UE+61E;&5T92UP97)S;VYA;"UC97)T<R(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4R]-24U%.B!$96QE=&4@4&5R<V]N86P@0V5R=&EF
M:6-A=&5S/"]T:71L93X*("`@(#QH96%D:6YG/D1E;&5T92!097)S;VYA;"!#
M97)T:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T92!Y
M;W5R('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M('EO=7(@<')E9F5R96YC
M97,N("!9;W4@=VEL;"!N;R!L;VYG97(@8F4@86)L92!T;R!S:6=N(%,O34E-
M12!M97-S86=E<R!O<B!V:65W(&%N>2!3+TU)344@96YC<GEP=&5D(&UE<W-A
M9V5S(&%D9')E<W-E9"!T;R!Y;W4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y3+TU)344Z($UA;F%G92!0=6)L:6,@2V5Y<SPO=&ET;&4^
M"B`@("`\:&5A9&EN9SY3+TU)344Z($UA;F%G92!0=6)L:6,@2V5Y<SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@36%N86=E('EO=7(@4R]-24U%('!U8FQI
M8R!K97D@;&ES="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I97<\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&AE(')A=R!T97AT(&]F('1H
M92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL
M<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5FEE=R!T96-H;FEC86P@9&5T
M86EL<R!O9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T
M:&4@<V5L96-T960@<'5B;&EC(&ME>2!F<F]M('-T;W)A9V4N("!$96QE=&EN
M9R!A('!U8FQI8R!K97D@9F]R(&$@=7-E<B!W:6QL('!R979E;G0@>6]U<B!F
M<F]M(&5N8W)Y<'1I;F<@82!M97-S86=E('1O('1H870@=7-E<BX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R:6YT:6YG(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<FEN=&EN9SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY0<FEN="!A(&UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1O
M('!R:6YT(&$@;65S<V%G92!Y;W4@87)E('9I97=I;F<L(&-L:6-K(&]N('1H
M92`B4')I;G0B(&QI;FL@870@96ET:&5R('1H92!T;W`@;W(@8F]T=&]M(&]F
M('1H92!M97-S86=E+B!4:&4@;65S<V%G92!W:6QL(&]P96X@:6X@82!N97<@
M=VEN9&]W(&9O<FUA=&5D(&9O<B!P<FEN=&EN9RX@($1E<&5N9&EN9R!O;B!Y
M;W5R('=E8B!B<F]W<V5R(&%N9"!O<&5R871I;F<@<WES=&5M+"!T:&4@<')I
M;G0@9&EA;&]G(&)O>"!M87D@;W!E;B!F;W(@>6]U+B`@268@:70@9&]E<R!N
M;W0@;W!E;BP@=&AE;B!P=6QL(&1O=VX@=&AE('=E8B!B<F]W<V5R)W,@(D9I
M;&4B(&UE;G4@86YD(&-H;V]S92`B4')I;G0B('1O(&]P96X@=&AE('!R:6YT
M(&1I86QO9R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)S;W)T:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3;W)T:6YG(&%N
M9"!4:')E861I;F<\+W1I=&QE/@H@("`@/&AE861I;F<^4V]R=&EN9R!%;G1R
M:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!7:&5N('9I97=I;F<@82!L
M:7-T(&]F(&UE<W-A9V5S+"!Y;W4@8V%N('-O<G0@=&AE(&UE<W-A9V5S(&)Y
M(&%N>2!C;VQU;6X@8GD@8VQI8VMI;F<@;VX@=&AE(&%P<')O<')I871E(&-O
M;'5M;B!H96%D:6YG+B`@5&\@<W=I=&-H(&-O;'5M;G,@8F5T=V5E;B!A<V-E
M;F1I;F<@86YD(&1E<V-E;F1I;F<@;W)D97(L(&-L:6-K(&]N('1H92!A<G)O
M=R!I8V]N(&EN('1H92!C;VQU;6X@:&5A9&EN9RX*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E1H<F5A9&EN9SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M5&\@9W)O=7`@;65S<V%G97,@8GD@=&AR96%D<R`H<W5B:F5C="DL('-O(&5A
M8V@@;65S<V%G92!I<R!G<F]U<&5D('=I=&@@86QL(&ET<R!R97!L:65S+"!C
M;&EC:R!T:&4@6U1H<F5A9%T@;&EN:R!I;B!T:&4@<W5B:F5C="!C;VQU;6X@
M:&5A9&EN9RX@(%1O(')E='5R;B!T;R!N;W)M86P@<W5B:F5C="!S;W)T:6YG
M+"!C;&EC:R!O;B!T:&4@6U-U8FIE8W1=(&QI;FL@:6X@=&AE('-U8FIE8W0@
M8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)A;'1E<FYA=&EV92UM<V<B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/DUU;'1I<&%R="]!;'1E<FYA=&EV92!-97-S86=E<SPO=&ET;&4^"B`@("`\
M<&%R83X*("`@(%-O;64@;65S<V%G92!H879E(&)E96X@<V5N="!A<R!A(")M
M=6QT:7!A<G0O86QT97)N871I=F4B('1Y<&4@8GD@=&AE('-E;F1E<BX@5&AE
M<V4@;65S<V%G97,@:&%V92!S979E<F%L('!A<G1S+"!A;&P@9&ES<&QA>6EN
M9R!T:&4@4T%-12!#3TY414Y4(&)U="!I;B!$249&15)%3E0@1D]234%44RX@
M5&AE(&UA:6P@86=E;G0@=VEL;"!D:7-P;&%Y('1H92!L87-T('!A<G0@:6X@
M=&AE(&QI<W0@=&AA="!C86X@8F4@<W5C8V5S<V9U;&QY(&1I<W!L87EE9"!I
M;FQI;F4@:6X@=&AE(&)R;W=S97(L(&EF(&%N>2X@06QL(&]T:&5R(&9O<FUA
M=',@=VEL;"!A<'!E87(@=6YD97(@=&AE(&AE861I;F<@(D%L=&5R;F%T:79E
M('!A<G1S(&9O<B!T:&ES('-E8W1I;VXB(&%N9"!C86X@8F4@=FEE=V5D(&]R
M(&1O=VYL;V%D960@<V5P87)A=&5L>2X@270@:7,@:6UP;W)T86YT('1O(&YO
M=&4@=&AA="!T:&5S92!A;'1E<FYA=&EV92!P87)T<R!C;VYT86EN('1H92!3
M04U%($-/3E1%3E13(&%S('1H92!P87)T('1H870@:7,@<VAO=VX@+2!T:&5Y
M(&%R92!S:6UP;'D@:6X@82!D:69F97)E;G0@;65D:6$@9F]R;6%T("AE+F<N
M('1E>'0@=G,N($A434P@;W5T<'5T*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+7)E;F%M95]S96YT;6%I;%]M;VYT:&QY(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z(%)E;F%M92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L
M9"!L:6ME('1O(')E;F%M92!Y;W5R('-E;G0M;6%I;"!F;VQD97(@870@=&AE
M(&)E9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H92!F;VQD97(@=VEL;"!B
M92!R96YA;65D("AT;R!A(&YA;64@=&AA="!C;VYT86EN<R!T:&4@;6]N=&@@
M86YD('EE87(I(&%N9"!A(&YE=R!S96YT+6UA:6P@9F]L9&5R('=I;&P@8F4@
M8W)E871E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T92!396YT
M+6UA:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4
M=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(&1E;&5T
M92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@=&AE(&)E9VEN;FEN9R!O9B!E
M=F5R>2!M;VYT:"X@(%1H:7,@;6%Y(&)E('5S969U;"!I9B!Y;W4@:&%V92!A
M('%U;W1A+"!F;W(@97AA;7!L92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY7VME97`B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@1&5L971E(%-E;G0M;6%I;"!&;VQD97(@36]N=&AL>2`M(",@;V8@
M1F]L9&5R<R!T;R!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M(&%R92!D96QE=&EN9R!O;&0@<V5N="UM86EL(&9O;&1E<G,@979E<GD@;6]N
M=&@L(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@9F]L9&5R<R!D;R!Y;W4@('=A
M;G0@=&\@:V5E<#\@($%N>2!F;VQD97)S(&]L9&5R('1H86X@=&AI<R!M86YY
M(&UO;G1H<R!W:6QL(&)E(&1E;&5T960N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE;G1S($UO;G1H;'D\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO
M=2!W;W5L9"!L:6ME('1O(&1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S
M(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&ES(&UA>2!B
M92!U<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?
M871T86-H;65N='-?;6]N=&AL>5]K965P(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T92!,:6YK960@
M071T86-H;65N=',@36]N=&AL>2`M(",@;V8@36]N=&AS('1O($ME97`\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E(&1E;&5T:6YG(&]L9"!L
M:6YK960@871T86-H;65N=',@979E<GD@;6]N=&@L(&AO=R!M86YY(&UO;G1H
M<R!O9B!O;&0@871T86-H;65N=',@9&\@>6]U("!W86YT('1O(&ME97`_("!!
M;GD@871T86-H;65N=',@;VQD97(@=&AA;B!T:&ES(&UA;GD@;6]N=&AS('=I
M;&P@8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!R969S+7!U<F=E7W1R87-H(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U<F=E(%1R87-H/"]T:71L
M93X*("`@(#QP87)A/@H@("`@1&\@>6]U('=A;G0@=&\@<'5R9V4@>6]U<B!T
M<F%S:"!F;VQD97(@979E<GD@<V\@;V9T96XN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]I;G1E<G9A;"(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!0=7)G92!4<F%S:"!);G1E<G9A;#PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!A<F4@<'5R9VEN9R!Y;W5R('1R87-H(&9O;&1E<BP@:&]W
M(&]F=&5N('-H;W5L9"!I="!B92!P=7)G960_"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]K965P(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M(%!U<F=E(%1R87-H($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y
M;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L(&UE<W-A9V4@;VQD
M97(@=&AA;B!H;W<@;6%N>2!D87ES('-H;W5L9"!B92!P=7)G960_"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUA='1R:6)?=&5X
M="(@<W1A=&4](FYE=R(^"B`@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-97-S
M86=E($-O;7!O<VET:6]N.B!!='1R:6)U=&EO;B!497AT/"]T:71L93X*("`@
M("`\<&%R83X*("`@("!(97)E('EO=2!C86X@96YT97(@=&AE('!H<F%S92!T
M:&%T('EO=2!W:7-H('1O(&%P<&5A<B!B969O<F4@86YY('%U;W1E9"!T97AT
M(&EN(&$@<F5P;'D@=&AA="!Y;W4@<V5N9"X*("`@("`\+W!A<F$^"B`@("`@
M/'!A<F$^"B`@("`@66]U(&-A;B!I;F-L=61E(&]N92!O<B!M;W)E('-P96-I
M86P@<&QA8V5H;VQD97)S('1O(&EN<V5R="!I;F9O<FUA=&EO;B!A8F]U="!T
M:&4@;65S<V%G92!T;R!W:&EC:"!Y;W4@87)E(')E<&QY:6YG+B!0;&%C96AO
M;&1E<G,@8V]N<VES="!O9B!A("<E)R!F;VQL;W=E9"!B>2!A('-I;F=L92!L
M971T97(N(%1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&%R92!A=F%I;&%B
M;&4Z"B`@("`@/"]P87)A/@H*("`@("`\<&%R83X@)68@.B!4:&4@<V5N9&5R
M)W,@;F%M92!A;F0@96UA:6P@861D<F5S<SPO<&%R83X*("`@("`\<&%R83X@
M)6$@.B!4:&4@<V5N9&5R)W,@96UA:6P@861D<F5S<SPO<&%R83X*("`@("`\
M<&%R83X@)7`@.B!4:&4@<V5N9&5R)W,@;F%M93PO<&%R83X*("`@("`\<&%R
M83X@)7(@.B!4:&4@9G5L;"!21D,@,C@R,B!S='EL92!D871E(&%N9"!T:6UE
M('IO;F4\+W!A<F$^"B`@("`@/'!A<F$^("5D(#H@5&AE(&1A=&4@87,@=W=W
M+"!D9"!M;6T@65E963PO<&%R83X*("`@("`\<&%R83X@)7@@.B!4:&4@9&%T
M92!I;B!T:&4@;&]C86QE)W,@9&5F875L=#PO<&%R83X*("`@("`\<&%R83X@
M)6,@.B!4:&4@9&%T92!A;F0@=&EM92!I;B!T:&4@;&]C86QE)W,@9&5F875L
M=#PO<&%R83X*("`@("`\<&%R83X@)6T@.B!4:&4@365S<V%G92U)1#PO<&%R
M83X*("`@("`\<&%R83X@)7,@.B!4:&4@<W5B:F5C=#PO<&%R83X*("`@("`\
M<&%R83X@)6X@.B!!(&YE=R!L:6YE/"]P87)A/@H@("`@(#QP87)A/B`E)2`Z
M(%1H92`G)2<@8VAA<F%C=&5R/"]P87)A/@H*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?<F5A9"(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E<75E<W0@4F5A9"!296-E
M:7!T<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(")297%U97-T(&$@4F5A9"!2
M96-E:7!T(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E8VEP:65N=',@;V8@
M=&AI<R!M97-S86=E('1O(&YO=&EF>2!Y;W4@=VAE;B!T:&ES(&UE<W-A9V4@
M:7,@;W!E;F5D(&)Y('1H92!R96-I<&EE;G1S+B!.;W0@86QL(&-L:65N=',@
M<W5P<&]R="`O(&AO;F]R('1H:7,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S96YD7VUD;B(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%-E;F0@341./"]T:71L
M93X*("`@(#QP87)A/@H@("`@(E-E;F0@82!-1$XB('-E;F1S(&$@365S<V%G
M92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@*&%L<V\@:VYO=VX@87,@82!R
M96%D(')E8V5I<'0I('=H96X@>6]U('9I97<@82!M97-S86=E(&EN('=H:6-H
M('1H92!U<V5R(&AA<R!R97%U97-T960@=&AA="!T:&5Y(')E8V5I=F4@;F]T
M:69I8V%T:6]N('1H870@>6]U(&AA=F4@<F5A9"!T:&4@;65S<V%G92X@26X@
M;6]S="!C87-E<RP@=&AI<R!W:6QL(&AA<'!E;B!A=71O;6%T:6-A;&QY('=I
M=&AO=70@<')O;7!T:6YG('EO=2X@26X@8V5R=&%I;B!I<V]L871E9"!C87-E
M<RP@>6]U(&UA>2!H879E('1O(&UA;G5A;&QY(&1E8VED92!T;R!S96YD('1H
M92!N;W1I9FEC871I;VX@8GD@8VQI8VMI;F<@;VX@82!L:6YK+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?
M<F5Q=65S=%]D96QI=F5R>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z(%)E<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N/"]T:71L
M93X*("`@(#QP87)A/@H@("`@(E)E<75E<W0@1&5L:79E<GD@0V]N9FER;6%T
M:6]N(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!S97)V97(@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&AA<R!D96QI=F5R960@
M=&AE(&UE<W-A9V4@=&\@=&AE(')E8VEP:65N="=S(&UA:6QB;W@N($ET(&1O
M97-N)W0@;65A;B!T:&4@;65S<V%G92!H87,@8F5E;B!S965N+"!J=7-T('1H
M870@:70G<R!S:71T:6YG(&EN(&$@;6%I;&)O>"!S;VUE=VAE<F4N($YO="!A
M;&P@;6%I;"!S97)V97)S('-U<'!O<G0@=&AI<RX@"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<W!A;5]A9G1E<E]R
M97!O<G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!$
M96QE=&4@4W!A;2!!9G1E<B!297!O<G1I;F<\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!9;W4@;6%Y(&5L96-T('1O(&1O(&]N92!O9B!T:')E92!I=&5M<R!A
M9G1E<B!R97!O<G1I;F<@82!M97-S86=E(&%S(&5I=&AE<B!S<&%M(&]R(&EN
M;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!&:7)S="P@>6]U
M(&-A;B!D96-I9&4@=&\@9&\@;F]T:&EN9R`M('1H92!M97-S86=E('=I;&P@
M8F4@<F5P;W)T960@87,@96ET:&5R('-P86T@;W(@:6YN;V-E;G0@8G5T('=I
M;&P@;W1H97)W:7-E(')E;6%I;B!U;F-H86YG960@:6X@>6]U<B!M86EL8F]X
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!396-O;F0L(&EF(')E<&]R
M=&EN9R!A(&UE<W-A9V4@87,@<W!A;2P@>6]U(&-A;B!I;G-T96%D(&AA=F4@
M=&AE(&UE<W-A9V4@8F4@:6UM961I871E;'D@9&5L971E9"X@(%1H:7,@<V5T
M=&EN9R!H87,@;F\@969F96-T(&]N(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@
M:6YN;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%1H:7)D+"!A
M9G1E<B!R97!O<G1I;F<@82!M97-S86=E(&%S('-P86T@=&AE(&UE<W-A9V4@
M=VEL;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E;G0@;6%I;&)O>"!A;F0@
M;6]V960@=&\@>6]U<B!S<&%M(&9O;&1E<BX@($%L=&5R;F%T:79E;'DL(&EF
M(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN;V-E;G0@=&AE(&UE<W-A9V4@
M=VEL;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E;G0@;6%I;&)O>"!A;F0@
M;6]V960@=&\@>6]U<B!)3D)/6"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+6AT;6Q?:6UA9V5?<F5P;&%C96UE;G0B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!(5$U,($EM86=E(%)E
M<&QA8V5M96YT/"]T:71L93X*("`@(#QP87)A/@H@("`@1F]R($A434P@;65S
M<V%G97,@9&ES<&QA>65D(&EN;&EN92P@<VAO=6QD(&%L;"!I;6%G92!T86=S
M(&)E(&)L;V-K960@=6YT:6P@>6]U('-P96-I9FEC86QL>2!D96-I9&4@=&\@
M=FEE=R!T:&]S92!I;6%G97,_($YO=&4@=&AA="P@:68@=FEE=VEN9R!A;B!(
M5$U,(&%T=&%C:&UE;G0L('1H92!I;6%G97,@=VEL;"!A;'=A>7,@8F4@9&ES
M<&QA>65D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M:'1M;%]I;6%G95]A9&1R8F]O:R(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P;&%C96UE;G0O061D<F5S
M<V)O;VL@4VAO=SPO=&ET;&4^"B`@("`\<&%R83X*("`@($EF(&)L;V-K:6YG
M(&EM86=E<R!F;W(@:6YL:6YE($A434P@;65S<V%G97,L('-H;W5L9"!W92!A
M=71O;6%T:6-A;&QY(&1I<W!L87D@=&AE;2!I;G-T96%D(&EF('1H92!S96YD
M97(@87!P96%R<R!I;B!Y;W5R(&%D9')E<W-B;V]K/PH@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M;6%I;&)O>%]S=&%R="(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6QB;W@@4W1A
M<G0@4&%G93PO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R;6EN97,@=VAI
M8V@@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W('=I;&P@8F4@9&ES<&QA>65D
M('=H96X@>6]U(&%C8V5S<R!A(&UA:6QB;W@@9F]R('1H92!F:7)S="!T:6UE
M+B!.;W1E('1H870@=&AE("=U;G-E96XG(&UE<W-A9V4@;W!T:6]N<R!D;R!N
M;W0@=V]R:R!W:71H('1H92`G5&AR96%D)R!S;W)T:6YG(&]P=&EO;B`M(&EN
M<W1E860L('EO=2!W:6QL(&)E('-E;G0@=&\@=&AE(&QA<W0@<&%G92X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7-A=F5?871T
M86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!3879E($%T=&%C:&UE;G1S(&]N(%-E;G0@365S<V%G97,\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!)9B!S879I;F<@82!C;VUP;W-E9"!M97-S86=E(&EN
M(&$@<V5N="UM86EL(&9O;&1E<BP@9&5T97)M:6YE(&EF(&%L;"!A='1A8VAM
M96YT(&1A=&$@:7,@<V%V960N(%1H92!F;VQL;W=I;F<@;W!T:6]N<R!A<F4@
M879A:6QA8FQE.@H@("`@/"]P87)A/@H*("`@(#QP87)A/BH@(D%L=V%Y<R!S
M879E(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP="!T;R!S879E(&%T=&%C
M:&UE;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@871T86-H;65N=',@87)E
M($%,5T%94R!S879E9"!W:71H('1H92!M97-S86=E+CPO<&%R83X*("`@("`\
M<&%R83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E
M;G0[(&1E9F%U;'0@=&\@6453(B`M($%,5T%94R!P<F]M<'0@=&\@<V%V92!A
M='1A8VAM96YT<R!I;B!T:&4@8V]M<&]S92!S8W)E96X[('1H92!D969A=6QT
M(&ES('1O('-A=F4@871T86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@
M(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F
M875L="!T;R!.3R(@+2!!3%=!65,@<')O;7!T('1O('-A=F4@871T86-H;65N
M=',@:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F875L="!I<R!T;R!N
M;W0@<V%V92!A='1A8VAM96YT<RX\+W!A<F$^"B`@("`@/'!A<F$^*B`B3F5V
M97(@<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A
M='1A8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S
M(&%R92!.159%4B!S879E9"!W:71H('1H92!M97-S86=E+CPO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G9I<G1U86Q?:6YB;W@B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E9I<G1U86P@1F]L9&5R<SH@5FER='5A;"!);F)O>#PO
M=&ET;&4^"B`@("`\<&%R83X*("`@(%9I<G5T86P@26YB;W@@:7,@82!S879E
M9"!S96%R8V@@=&AA="!D;V5S(&%W87D@=VET:"!T:&4@;F5E9"!T;R!S96%R
M8V@@979E<GD@;6%I;&)O>"!F;W(@;65S<V%G97,@;6%R:V5D(&%S(&YE=RX@
M($EN<W1E860L(&%L;"!C=7)R96YT;'D@<W5B<V-R:6)E9"!M86EL8F]X97,@
M87)E('-E87)C:&5D(&9O<B!N97<@;65S<V%G97,@86YD('1H92!R97-U;'1S
M(&%R92!D:7-P;&%Y960@:6X@82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U86Q?=')A<V@B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E9I<G1U86P@1F]L9&5R<SH@5FER='5A;"!4
M<F%S:#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%9I<G1U86P@5')A<V@@:7,@
M82!S879E9"!S96%R8V@@=&AA="!D;V5S(&%W87D@=VET:"!T:&4@;F5E9"!F
M;W(@82!S97!A<F%T92!4<F%S:"!F;VQD97(N("!);G-T96%D(&]F(&UO=FEN
M9R!M97-S86=E<R!T;R!A(&-E;G1R86QI>F5D('1R87-H(&9O;&1E<BP@;65S
M<V%G97,@87)E('-I;7!L>2!M87)K960@87,@9&5L971E9"!I;B!T:&4@8W5R
M<F5N="!F;VQD97(@=&AE>2!L:79E(&EN+B`@5VAE;B`G<VAO=R!D96QE=&5D
M(&UE<W-A9V5S)R!I<R!T=7)N960@;V9F+"!T:&ES(')E<W5L=',@:6X@=&AE
M<V4@;65S<V%G97,@;F]T(&%P<&5A<FEN9R!I;B!A(&UA:6QB;W@@=FEE=RX@
M(%=H96X@82!U<V5R(&-L:6-K<R!O;B!6:7)T=6%L(%1R87-H+"`J86QL*B!M
M86EL8F]X97,@86QL('-E87)C:&5D(&9O<B!M97-S86=E<R!T:&%T(&%R92!F
M;&%G9V5D(&1E;&5T960@86YD('1H97-E(&UE<W-A9V5S(&%R92!D:7-P;&%Y
M960@:6X@82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M/"]H96QP/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+W1R7U12+P``
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S8S`#`Q-S4P,P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM
M<"]L;V-A;&4O=')?5%(O3$-?34534T%'15,O````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#(Q,C<P`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]T<E]44B],0U]-15-304=%4R]I
M;7`N;6\````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#4V-3<R-P`Q,#0Q-S,V,C<V
M,P`P,C(T,S4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0`````D"@``'````#Q1``"%#0``7*(```````!PV```"@``
M`''8```*````?-@```H```"'V```#@```)+8```/````H=@```T```"QV```
M"````+_8```+````R-@```P```#4V```"@```.'8```$````[-@```0```#Q
MV````0```/;8```9````^-@```P````2V0``2````!_9```K````:-D``$0`
M``"4V0``)P```-G9```7`````=H```\````9V@``"P```"G:```.````-=H`
M``4```!$V@``*````$K:```(````<]H```H```!\V@``%0```(?:```2````
MG=H``#(```"PV@``"P```./:```I````[]H``#(````9VP``$````$S;```4
M````7=L``!````!RVP``)@```(/;```G````JML``"8```#2VP``'````/G;
M```.````%MP```H````EW```#0```##<```G````/MP``"````!FW```#@``
M`(?<```7````EMP``"(```"NW```-0```-'<```1````!]T```T````9W0``
M#````"?=```-````--T```8```!"W0``&P```$G=```N````9=T``#<```"4
MW0``?````,S=``!L````2=X``!P```"VW@``'0```-/>```/````\=X``!@`
M```!WP``#````!K?``!%````)]\``"@```!MWP``00```);?```D````V-\`
M``X```#]WP``#P````S@```.````'.````X````KX```"````#K@```.````
M0^````X```!2X```+@```&'@```:````D.```#,```"KX```40```-_@```R
M````,>$``#@```!DX0``5````)WA``!1````\N$``%H```!$X@``5P```)_B
M```T````]^(```<````LXP``"@```#3C```/````/^,```4```!/XP```P``
M`%7C```&````6>,``!$```!@XP``"````'+C```)````>^,```D```"%XP``
M#@```(_C```(````GN,```H```"GXP``)0```++C```@````V.,``!````#Y
MXP``#P````KD```/````&N0```H````JY```!P```#7D```#````/>0```\`
M``!!Y```%````%'D```)````9N0```T```!PY```$@```'[D```/````D>0`
M``H```"AY```#P```*SD```(````O.0```H```#%Y```)````-#D```7````
M]>0``!0````-Y0``%@```"+E```(````.>4``!P```!"Y0``&0```%_E```H
M````>>4``!X```"BY0``&@```,'E```L````W.4``"`````)Y@``,@```"KF
M```'````7>8```P```!EY@``#0```'+F```L````@.8```X```"MY@```P``
M`+SF```+````P.8```<```#,Y@``!P```-3F```%````W.8```4```#BY@``
M"@```.CF```#````\^8``!<```#WY@``"@````_G```/````&N<```X````J
MYP``3@```#GG``!0````B.<``$,```#9YP``0@```!WH```P````8.@``!@`
M``"1Z```(P```*KH```.````SN@``!0```#=Z```%P```/+H```7````"ND`
M`!<````BZ0``$P```#KI```/````3ND``",```!>Z0``!@```(+I```7````
MB>D```X```"AZ0``40```+#I```?`````NH``#4````BZ@``!P```%CJ```&
M````8.H```@```!GZ@``#P```'#J```&````@.H```@```"'Z@``$0```)#J
M```*````HNH``!,```"MZ@``"P```,'J```0````S>H``!4```#>Z@``#0``
M`/3J```3`````NL``",````6ZP``+P```#KK```5````:NL```<```"`ZP``
M$````(CK```%````F>L``!4```"?ZP``$0```+7K```,````Q^L``#````#4
MZP``2`````7L```A````3NP``#L```!P[```.P```*SL```\````Z.P``"L`
M```E[0``,0```%'M```[````@^T``#D```"_[0``-0```/GM```)````+^X`
M``<````Y[@``%````$'N```,````5NX```,```!C[@``!0```&?N```)````
M;>X``!````!W[@``"0```(CN```3````DNX```,```"F[@``.0```*KN```2
M````Y.X```8```#W[@``#````/[N```U````"^\```X```!![P``20```%#O
M```S````FN\```H```#.[P``+0```-GO```+````!_```"<````3\```+```
M`#OP```J````:/```"4```"3\```"0```+GP```)````P_````H```#-\```
M!@```-CP```)````W_````<```#I\```+P```/'P```W````(?$``"X```!9
M\0``50```(CQ```M````WO$``"P````,\@``+0```#GR```M````9_(``$``
M``"5\@``(P```-;R```C````^O(``"T````>\P``,P```$SS```5````@/,`
M`!D```"6\P``*0```+#S```D````VO,``%````#_\P``&````%#T```1````
M:?0``!$```![]```"@```(WT```,````F/0```L```"E]```"@```+'T```*
M````O/0``!````#']```%@```-CT```6````[_0```<````&]0``!P````[U
M```4````%O4```H````K]0``"````#;U```(````/_4```,```!(]0``!P``
M`$SU```'````5/4```8```!<]0``.````&/U```%````G/4```<```"B]0``
M!@```*KU```(````L?4```D```"Z]0``*0```,3U```.````[O4```H```#]
M]0``10````CV```$````3O8```0```!3]@``!P```%CV```)````8/8```8`
M``!J]@``$0```''V```'````@_8``!8```"+]@``!````*+V```G````I_8`
M``@```#/]@``!@```-CV```-````W_8```8```#M]@``'@```/3V```1````
M$_<```@````E]P``#0```"[W```,````//<```<```!)]P```P```%'W```#
M````5?<``!<```!9]P``$P```''W```(````A?<```@```".]P``!````)?W
M```(````G/<```@```"E]P``*@```*[W```K````V?<``%,````%^```00``
M`%GX```@````F_@```8```"\^```!@```,/X```.````RO@``!4```#9^```
M/@```._X```8````+OD``"(```!'^0``+@```&KY```=````F?D``"$```"W
M^0``5````-GY```I````+OH```H```!8^@``!P```&/Z```5````:_H```X`
M``"!^@```@```)#Z```*````D_H```\```">^@``#0```*[Z```/````O/H`
M``T```#,^@``"0```-KZ```4````Y/H```8```#Y^@``&`````#[```=````
M&?L``!,````W^P``%````$O[```$````8/L```P```!E^P``!@```'+[```*
M````>?L```T```"$^P``8@```)+[```G````]?L``%0````=_```7P```'+\
M```$````TOP``!8```#7_```#@```.[\```<````_?P```\````:_0``,P``
M`"K]```H````7OT```4```"'_0``!0```(W]```;````D_T``!H```"O_0``
M#@```,K]```5````V?T``!$```#O_0``$0````'^```1````$_X``!P````E
M_@``*@```$+^```U````;?X``$4```"C_@``$````.G^```A````^OX```4`
M```<_P``$P```"+_```2````-O\```H```!)_P``#P```%3_``!'````9/\`
M`!\```"L_P``)0```,S_```S````\O\``"L````F``$`-0```%(``0!"````
MB``!`!T```#+``$`40```.D``0`1````.P$!`#$```!-`0$`.P```'\!`0`3
M````NP$!`$````#/`0$`.````!`"`0`%````20(!``P```!/`@$`$0```%P"
M`0`-````;@(!``8```!\`@$`!@```(,"`0`7````B@(!``@```"B`@$`#```
M`*L"`0`4````N`(!``\```#-`@$`$````-T"`0`1````[@(!``@``````P$`
M!0````D#`0`1````#P,!``P````A`P$`$````"X#`0`%````/P,!``T```!%
M`P$`!@```%,#`0`'````6@,!``T```!B`P$`!P```'`#`0`+````>`,!``<`
M``"$`P$`!P```(P#`0`)````E`,!`!<```">`P$`)@```+8#`0!/````W0,!
M``D````M!`$`"@```#<$`0`9````0@0!``P```!<!`$`)0```&D$`0`?````
MCP0!`!````"O!`$`!0```,`$`0`E````Q@0!`!(```#L!`$`$P```/\$`0`K
M````$P4!`#L````_!0$`(````'L%`0`;````G`4!`#8```"X!0$`"````.\%
M`0`;````^`4!`!X````4!@$`7````#,&`0`N````D`8!``P```"_!@$`!@``
M`,P&`0`$````TP8!``X```#8!@$`#@```.<&`0`'````]@8!``X```#^!@$`
M"@````T'`0`-````&`<!`!X````F!P$`&P```$4'`0`A````80<!`!X```"#
M!P$`&0```*('`0`>````O`<!`!L```#;!P$`)@```/<'`0`D````'@@!`!L`
M``!#"`$`'@```%\(`0`<````?@@!`"8```";"`$`-@```,((`0`S````^0@!
M`"D````M"0$`00```%<)`0`Z````F0D!`"8```#4"0$`*P```/L)`0`X````
M)PH!`"\```!@"@$`$@```)`*`0`I````HPH!`!(```#-"@$`H@```.`*`0`6
M````@PL!`",```":"P$`*````+X+`0`I````YPL!`"@````1#`$`'P```#H,
M`0`@````6@P!`"4```![#`$`*````*$,`0`P````R@P!`)(```#[#`$`(0``
M`(X-`0`<````L`T!`"8```#-#0$`00```/0-`0`,````-@X!``<```!##@$`
M!P```$L.`0`&````4PX!``T```!:#@$`"P```&@.`0`5````=`X!``T```"*
M#@$`&@```)@.`0`0````LPX!`!T```#$#@$`&0```.(.`0!=````_`X!`!(`
M``!:#P$`$P```&T/`0`2````@0\!``<```"4#P$`!````)P/`0`,````H0\!
M``X```"N#P$`#P```+T/`0`4````S0\!`!,```#B#P$`#0```/8/`0`Y````
M!!`!`!P````^$`$`*````%L0`0`#````A!`!``T```"($`$`!@```)80`0`1
M````G1`!`!<```"O$`$`&P```,<0`0`.````XQ`!``(```#R$`$`!0```/40
M`0`%````^Q`!`!`````!$0$`!````!(1`0`-````%Q$!``X````E$0$``P``
M`#01`0`.````.!$!``@```!'$0$`#P```%`1`0`(````8!$!``H```!I$0$`
M#P```'01`0`-````A!$!`!````"2$0$`&0```*,1`0`:````O1$!``L```#8
M$0$`"0```.01`0`&````[A$!`!0```#U$0$`$P````H2`0`0````'A(!``P`
M```O$@$`$0```#P2`0`5````3A(!`!D```!D$@$`"P```'X2`0`-````BA(!
M`"(```"8$@$`*P```+L2`0`7````YQ(!`#0```#_$@$`,P```#03`0`*````
M:!,!`!@```!S$P$`&0```(P3`0`6````IA,!``<```"]$P$`$````,43`0`<
M````UA,!`!P```#S$P$`#0```!`4`0`'````'A0!``P````F%`$`)@```#,4
M`0`*````6A0!`!0```!E%`$`"P```'H4`0`'````AA0!`"(```".%`$`+P``
M`+$4`0`+````X10!``D```#M%`$`&0```/<4`0`+````$14!``\````=%0$`
M%P```"T5`0`7````114!``D```!=%0$`!P```&<5`0`6````;Q4!``\```"&
M%0$`+0```)85`0`6````Q!4!``X```#;%0$`&@```.H5`0`H````!18!``L`
M```N%@$`&````#H6`0`(````4Q8!``P```!<%@$`(P```&D6`0`-````C18!
M`"8```";%@$`*@```,(6`0`@````[18!`$,````.%P$`"````%(7`0`2````
M6Q<!``0```!N%P$`"````',7`0`+````?!<!`!H```"(%P$`)P```*,7`0`2
M````RQ<!`"````#>%P$`+P```/\7`0`7````+Q@!``4```!'&`$`#````$T8
M`0`.````6A@!``X```!I&`$`!0```'@8`0`&````?A@!``X```"%&`$``P``
M`)08`0`K````F!@!``<```#$&`$`!````,P8`0`.````T1@!``H```#@&`$`
M#````.L8`0`*````^!@!``\````#&0$`$````!,9`0`7````)!D!`!,````\
M&0$`)0```%`9`0`.````=AD!`!$```"%&0$`%P```)<9`0`3````KQD!`!8`
M``##&0$`.````-H9`0`3````$QH!``D````G&@$`!0```#$:`0`+````-QH!
M``H```!#&@$``@```$X:`0`%````41H!``T```!7&@$`&P```&4:`0`7````
M@1H!``D```"9&@$`'0```*,:`0`/````P1H!`!(```#1&@$`#````.0:`0`.
M````\1H!``T`````&P$`$@````X;`0`9````(1L!`!P````[&P$`.````%@;
M`0`8````D1L!`"````"J&P$`$P```,L;`0`#````WQL!`!4```#C&P$`"P``
M`/D;`0`3````!1P!``@````9'`$`#@```"(<`0`0````,1P!`'L```!"'`$`
M&````+X<`0`I````UQP!`"P````!'0$`*````"X=`0`U````5QT!`!$```"-
M'0$`!P```)\=`0`%````IQT!`!@```"M'0$`&0```,8=`0`'````X!T!``@`
M``#H'0$`!@```/$=`0`&````^!T!`!L```#_'0$`$````!L>`0`/````+!X!
M`!`````\'@$`#P```$T>`0`+````71X!``\```!I'@$`#````'D>`0`/````
MAAX!``<```"6'@$`!@```)X>`0`*````I1X!`!(```"P'@$`#0```,,>`0`,
M````T1X!``X```#>'@$`0P```.T>`0`]````,1\!``D```!O'P$`#````'D?
M`0`H````AA\!``\```"O'P$`"````+\?`0`(````R!\!`!,```#1'P$`'@``
M`.4?`0`A````!"`!`"`````F(`$`&0```$<@`0`7````82`!`"4```!Y(`$`
M%P```)\@`0`$````MR`!`!L```"\(`$`#0```-@@`0`,````YB`!``,```#S
M(`$`"````/<@`0`*`````"$!``P````+(0$`"@```!@A`0`@````(R$!`!\`
M``!$(0$`"P```&0A`0`;````<"$!``L```",(0$`$````)@A`0`(````J2$!
M``P```"R(0$`!````+\A`0`$````Q"$!`!,```#)(0$`%````-TA`0`,````
M\B$!``D```#_(0$`#@````DB`0`+````&"(!`!L````D(@$`#@```$`B`0`/
M````3R(!`"4```!?(@$`*@```(4B`0`'````L"(!`!(```"X(@$`&P```,LB
M`0`$````YR(!``<```#L(@$`"@```/0B`0`2````_R(!``H````2(P$`#0``
M`!TC`0`)````*R,!``0````U(P$`!0```#HC`0`(````0",!``,```!)(P$`
M&````$TC`0`0````9B,!``X```!W(P$`'@```(8C`0`:````I2,!``H```#`
M(P$`!````,LC`0`F````T",!``X```#W(P$`?`````8D`0`5````@R0!`$0`
M``"9)`$`!0```-XD`0`'````Y"0!``P```#L)`$`"````/DD`0`*`````B4!
M``8````-)0$`!P```!0E`0`(````'"4!`!$````E)0$`&0```#<E`0`(````
M424!``(```!:)0$`!@```%TE`0`&````9"4!`!0```!K)0$`%0```(`E`0`/
M````EB4!`!$```"F)0$`&@```+@E`0`-````TR4!`!````#A)0$`&P```/(E
M`0`%````#B8!``0````4)@$`#````!DF`0`)````)B8!`!`````P)@$`"0``
M`$$F`0`)````2R8!``0```!5)@$`!0```%HF`0`:````8"8!``4```![)@$`
M&@```($F`0`(````G"8!``8```"E)@$`#P```*PF`0`9````O"8!``X```#6
M)@$`!P```.4F`0`'````[28!`"(```#U)@$`!0```!@G`0`)````'B<!``H`
M```H)P$`#0```#,G`0`&````02<!``T```!()P$`#````%8G`0`)````8R<!
M``8```!M)P$`$@```'0G`0`)````AR<!``<```"1)P$`%````)DG`0`=````
MKB<!``8```#,)P$`"@```-,G`0`$````WB<!``D```#C)P$`"````.TG`0`1
M````]B<!``D````(*`$`!@```!(H`0`-````&2@!``8````G*`$`!````"XH
M`0`$````,R@!`!<````X*`$`.0```%`H`0`]````BB@!`#H```#(*`$`'@``
M``,I`0`%````(BD!``X````H*0$`!````#<I`0`&````/"D!``<```!#*0$`
M(0```$LI`0`5````;2D!``8```"#*0$`!````(HI`0`1````CRD!``8```"A
M*0$`"@```*@I`0`B````LRD!`"<```#6*0$`!@```/XI`0`5````!2H!``P`
M```;*@$`$0```"@J`0`$````.BH!``T````_*@$`!P```$TJ`0`%````52H!
M`!T```!;*@$`!````'DJ`0`,````?BH!``H```"+*@$`"````)8J`0`)````
MGRH!``4```"I*@$`.@```*\J`0`P````ZBH!`#4````;*P$`*0```%$K`0!'
M````>RL!`#@```##*P$`*0```/PK`0`_````)BP!`"X```!F+`$`+0```)4L
M`0`?````PRP!``\```#C+`$`$@```/,L`0`+````!BT!`"8````2+0$`)P``
M`#DM`0`I````82T!`"0```"++0$`)@```+`M`0`H````URT!``@`````+@$`
M"@````DN`0`)````%"X!``<````>+@$`!````"8N`0`<````*RX!`"````!(
M+@$`(````&DN`0`F````BBX!``T```"Q+@$`)P```+\N`0`;````YRX!``P`
M```#+P$`%@```!`O`0`%````)R\!``H````M+P$`&0```#@O`0`I````4B\!
M`!8```!\+P$`$@```),O`0`'````IB\!``H```"N+P$`#````+DO`0`/````
MQB\!`!````#6+P$`0````.<O`0!P````*#`!`&8```"9,`$`!@`````Q`0`*
M````!S$!``X````2,0$`"0```"$Q`0`*````*S$!`!(````V,0$`$P```$DQ
M`0`,````73$!``8```!J,0$`!@```'$Q`0`*````>#$!``X```"#,0$`#P``
M`)(Q`0`.````HC$!`!\```"Q,0$`'@```-$Q`0`C````\#$!`!$````4,@$`
M%0```"8R`0`8````/#(!`!$```!5,@$`$````&<R`0`C````>#(!``\```"<
M,@$`"0```*PR`0`2````MC(!`!T```#),@$`$@```.<R`0`0````^C(!``H`
M```+,P$`$0```!8S`0`%````*#,!`#$````N,P$`)````&`S`0`<````A3,!
M`",```"B,P$`:@```,8S`0`/````,30!``4```!!-`$`$````$<T`0`)````
M6#0!``0```!B-`$`"P```&<T`0`<````<S0!`",```"0-`$`(@```+0T`0`&
M````US0!`!0```#>-`$`%P```/,T`0`,````"S4!`"0````8-0$`(P```#TU
M`0`:````834!``P```!\-0$`#P```(DU`0`5````F34!`"D```"O-0$`*@``
M`-DU`0`F````!#8!`"<````K-@$`*0```%,V`0`J````?38!`!D```"H-@$`
M0@```,(V`0`1````!3<!`!(````7-P$`$P```"HW`0`4````/C<!``\```!3
M-P$`%@```&,W`0`7````>C<!`!````"2-P$`$0```*,W`0`T````M3<!`!,`
M``#J-P$`$@```/XW`0`U````$3@!`!0```!'.`$`!P```%PX`0`,````9#@!
M`"L```!Q.`$`#P```)TX`0`6````K3@!`"````#$.`$`%````.4X`0`1````
M^C@!`"@````,.0$`%P```#4Y`0`<````33D!`!,```!J.0$`"P```'XY`0`1
M````BCD!`!H```"<.0$`'@```+<Y`0`:````UCD!`"$```#Q.0$`(````!,Z
M`0`1````-#H!`!0```!&.@$`%P```%LZ`0`5````<SH!``D```").@$`!@``
M`),Z`0`9````FCH!``0```"T.@$`!P```+DZ`0`+````P3H!`!$```#-.@$`
M!@```-\Z`0`&````YCH!``8```#M.@$`!0```/0Z`0`'````^CH!``<````"
M.P$`!0````H[`0`6````$#L!``8````G.P$`!@```"X[`0`$````-3L!``0`
M```Z.P$`!P```#\[`0`.````1SL!``P```!6.P$`#````&,[`0`-````<#L!
M``(```!^.P$`"@```($[`0`.````C#L!``4```";.P$`*````*$[`0`.````
MRCL!``P```#9.P$`#P```.8[`0`*````]CL!``@````!/`$`"0````H\`0`K
M````%#P!`"X```!`/`$`!````&\\`0`(````=#P!`"8```!]/`$`$@```*0\
M`0`/````MSP!``8```#'/`$`"@```,X\`0`'````V3P!``@```#A/`$`(```
M`.H\`0`)````"ST!`!$````5/0$`"0```"<]`0`,````,3T!``T````^/0$`
M#@```$P]`0`6````6ST!`!$```!R/0$`!@```(0]`0`#````BST!``8```"/
M/0$`&0```)8]`0`'````L#T!``0```"X/0$`"P```+T]`0`+````R3T!``<`
M``#5/0$`$0```-T]`0`'````[ST!`!8```#W/0$`#0````X^`0`-````'#X!
M``H````J/@$`$````#4^`0`/````1CX!`!$```!6/@$`%P```&@^`0`*````
M@#X!`!$```"+/@$`"````)T^`0`$````ICX!``\```"K/@$`.@```+L^`0`A
M````]CX!``4````8/P$`%P```!X_`0`,````-C\!`!X```!#/P$`#@```&(_
M`0`0````<3\!``L```""/P$`?````(X_`0`,````"T`!``D````80`$`!P``
M`")``0`*````*D`!``D````U0`$`#@```#]``0`0````3D`!`!4```!?0`$`
M&@```'5``0`*````D$`!``D```";0`$`"@```*5``0`.````L$`!``P```"_
M0`$`#P```,Q``0`(````W$`!``8```#E0`$`#````.Q``0`'````^4`!``4`
M```!00$`"P````=!`0!'````$T$!``T```!;00$`"0```&E!`0`$````<T$!
M``,```!X00$`#````'Q!`0`3````B4$!`!,```"=00$`$P```+%!`0`&````
MQ4$!``H```#,00$``@```-=!`0`$````VD$!`"4```#?00$``P````5"`0`%
M````"4(!`"H````/0@$`#@```#I"`0`*````24(!``4```!40@$`!````%I"
M`0`*````7T(!``T```!J0@$`'P```'A"`0`'````F$(!`"(```"@0@$`#0``
M`,-"`0`&````T4(!``@```#80@$`"````.%"`0`$````ZD(!``4```#O0@$`
M:````/5"`0`)````7D,!``P```!H0P$`!0```'5#`0`&````>T,!`",```""
M0P$`)0```*9#`0`(````S$,!`#<```#50P$`(@````U$`0`3````,$0!`!L`
M``!$1`$`+P```&!$`0`0````D$0!``H```"A1`$`$0```*Q$`0`/````OD0!
M``\```#.1`$`"@```-Y$`0`)````Z40!`!,```#S1`$`&P````=%`0`8````
M(T4!`!<````\10$`%P```%1%`0`.````;$4!`"8```![10$`)@```*)%`0`#
M````R44!``<```#-10$`"````-5%`0`4````WD4!`!,```#S10$`$`````=&
M`0`-````&$8!``X````F1@$`%@```#5&`0`'````3$8!`!````!41@$`"@``
M`&5&`0`+````<$8!``<```!\1@$`$P```(1&`0`,````F$8!``\```"E1@$`
M#@```+5&`0`,````Q$8!``X```#11@$`40```.!&`0`/````,D<!`!````!"
M1P$`#0```%-'`0`/````84<!``\```!Q1P$`#P```(%'`0`@````D4<!`"X`
M``"R1P$`&@```.%'`0`,````_$<!`"8````)2`$`"P```#!(`0`-````/$@!
M`!H```!*2`$`2@```&5(`0`&````L$@!``8```"W2`$`!@```+Y(`0`?````
MQ4@!``8```#E2`$`"0```.Q(`0`8````]D@!`!<````/20$`!@```"=)`0`-
M````+DD!`"(````\20$`5P```%])`0`3````MTD!`",```#+20$`$P```.])
M`0`"`````TH!``L````&2@$`"````!)*`0`-````&TH!``8````I2@$`"@``
M`#!*`0`'````.TH!`!0```!#2@$`!@```%A*`0`(````7TH!``X```!H2@$`
M!P```'=*`0`*````?TH!``L```"*2@$`!P```)9*`0`,````GDH!``T```"K
M2@$`#````+E*`0`$````QDH!``D```#+2@$`"0```-5*`0`*````WTH!``<`
M``#J2@$`"0```/)*`0`.````_$H!``<````+2P$`"@```!-+`0`;````'DL!
M`!4````Z2P$`$@```%!+`0`*````8TL!``D```!N2P$`$````'A+`0`'````
MB4L!`!(```"12P$`!````*1+`0`$````J4L!`"(```"N2P$`!P```-%+`0`%
M````V4L!``P```#?2P$`!0```.Q+`0`+````\DL!`!0```#^2P$`$0```!-,
M`0`:````)4P!`!8```!`3`$`%````%=,`0`7````;$P!`!@```"$3`$`'```
M`)U,`0`9````NDP!``<```#43`$`!0```-Q,`0`6````XDP!``,```#Y3`$`
M#0```/U,`0`,````"TT!``H````830$`"````"--`0`(````+$T!`!<````U
M30$`"P```$U-`0`,````64T!`!,```!F30$`!````'I-`0`*````?TT!``0`
M``"*30$`#````(]-`0`)````G$T!``P```"F30$`"0```+--`0`%````O4T!
M``<```##30$`!0```,M-`0`$````T4T!``(```#630$`%````-E-`0`-````
M[DT!`!(```#\30$`"P````].`0`;````&TX!`!\````W3@$`%````%=.`0`>
M````;$X!`!4```"+3@$`.````*%.`0`L````VDX!`!(````'3P$`*0```!I/
M`0`R````1$\!``H```!W3P$`+````()/`0`N````KT\!`#,```#>3P$`,P``
M`!)0`0`X````1E`!``\```!_4`$`&````(]0`0`0````J%`!`!,```"Y4`$`
M*@```,U0`0`9````^%`!`!P````240$`'P```"]1`0`/````3U$!`!,```!?
M40$`%````'-1`0`4````B%$!`"````"=40$`$@```+Y1`0`4````T5$!`!4`
M``#F40$`+0```/Q1`0`M````*E(!`#$```!84@$`+@```(I2`0`O````N5(!
M`"P```#I4@$`8@```!93`0`3````>5,!`"4```"-4P$`)````+-3`0`I````
MV%,!``@````"5`$`"`````M4`0`D````%%0!`!(````Y5`$`#@```$Q4`0`K
M````6U0!`!(```"'5`$`(0```)I4`0`:````O%0!``D```#75`$`10```.%4
M`0!!````)U4!``\```!I50$`!````'E5`0`3````?E4!`!0```"250$`#@``
M`*=5`0`&````ME4!`!,```"]50$`&````-%5`0`&````ZE4!``D```#Q50$`
M"@```/M5`0`+````!E8!``D````25@$`#0```!Q6`0`,````*E8!``\````W
M5@$`%P```$=6`0`4````7U8!`!````!T5@$`%@```(56`0`'````G%8!``X`
M``"D5@$`(0```+-6`0`%````U58!`!L```#;5@$`"````/=6`0`&`````%<!
M`!0````'5P$`$0```!Q7`0!$````+E<!`#P```!S5P$`#@```+!7`0`X````
MOU<!``(```#X5P$``@```/M7`0`&````_E<!``X````%6`$`!0```!18`0`'
M````&E@!``X````B6`$`!@```#%8`0`,````.%@!`",```!%6`$`!````&E8
M`0`I````;E@!`#(```"86`$`%P```,M8`0`?````XU@!`#,````#60$`7```
M`#=9`0`4````E%D!`#X```"I60$`#0```.A9`0`?````]ED!`!`````66@$`
M%````"=:`0`'````/%H!``X```!$6@$`#````%-:`0`,````8%H!`!,```!M
M6@$`"@```(%:`0`=````C%H!`!D```"J6@$`!0```,1:`0`1````REH!`!,`
M``#<6@$`#0```/!:`0`1````_EH!`"0````06P$``P```#5;`0`5````.5L!
M`!,```!/6P$`$@```&-;`0`+````=EL!`#0```""6P$`"P```+=;`0`4````
MPUL!`#X```#86P$`#@```!=<`0`3````)EP!`#0````Z7`$`,0```&]<`0`2
M````H5P!`!````"T7`$`&````,5<`0`9````WEP!`",```#X7`$`(@```!Q=
M`0`G````/UT!`%8```!G70$`30```+Y=`0`(````#%X!``D````57@$`#0``
M`!]>`0`*````+5X!``<````X7@$`#P```$!>`0`+````4%X!``0```!<7@$`
M'````&%>`0`-````?EX!`"<```",7@$`&P```+1>`0`,````T%X!``H```#=
M7@$`!P```.A>`0`-````\%X!`"(```#^7@$`(0```"%?`0`(````0U\!``4`
M``!,7P$`'P```%)?`0`&````<E\!`!````!Y7P$`"````(I?`0`'````DU\!
M``T```";7P$`"@```*E?`0`2````M%\!`"$```#'7P$`"P```.E?`0`<````
M]5\!`!@````28`$`"````"M@`0`2````-&`!`"P```!'8`$`&@```'1@`0`)
M````CV`!``H```"98`$`%0```*1@`0`%````NF`!`!0```#`8`$`!````-5@
M`0`0````VF`!``8```#K8`$`!P```/)@`0`>````^F`!`"@````980$`"@``
M`$)A`0`:````36$!`"T```!H80$`"````)9A`0`4````GV$!`"P```"T80$`
M)P```.%A`0`K````"6(!`"H````U8@$`!````&!B`0`$````96(!``L```!J
M8@$`!0```'9B`0`&````?&(!``@```"#8@$`!@```(QB`0`Q````DV(!`!P`
M``#%8@$`"@```.)B`0`;````[6(!`#0````)8P$`-````#YC`0`@````<V,!
M`"D```"48P$`)P```+YC`0`@````YF,!`$$````'9`$`&@```$ED`0`H````
M9&0!`!H```"-9`$`=@```*AD`0!Y````'V4!`!P!``"990$`*````+9F`0`=
M````WV8!`"D```#]9@$`'0```"=G`0`N````16<!`%<```!T9P$`-@```,QG
M`0`L`````V@!`"P````P:`$`,0```%UH`0`N````CV@!`"(```"^:`$`!@``
M`.%H`0`(````Z&@!``4```#Q:`$`"````/=H`0`9`````&D!`!D````::0$`
M*@```#1I`0`0````7VD!`"L```!P:0$`(P```)QI`0`A````P&D!`"X```#B
M:0$`-````!%J`0`(````1FH!`!<```!/:@$`"@```&=J`0`'````<FH!`"$`
M``!Z:@$`$````)QJ`0`-````K6H!`!````"[:@$`!0```,QJ`0`.````TFH!
M``@```#A:@$`"P```.IJ`0`4````]FH!``<````+:P$`$P```!-K`0`(````
M)VL!`#8````P:P$`-P```&=K`0`+````GVL!``D```"K:P$`"@```+5K`0`4
M````P&L!`"\```#5:P$`,@````5L`0`+````.&P!``X```!$;`$`#0```%-L
M`0`/````86P!`!8```!Q;`$`/@```(AL`0`G````QVP!``4```#O;`$`!0``
M`/5L`0`G````^VP!`!\````C;0$`%@```$-M`0`+````6FT!`!<```!F;0$`
M#P```'YM`0`$````CFT!``H```"3;0$`"0```)YM`0`+````J&T!``T```"T
M;0$`#````,)M`0`.````SVT!``4```#>;0$`'@```.1M`0`$`````VX!``T`
M```(;@$`,@```!9N`0!%````26X!``L```"/;@$`#@```)MN`0`.````JFX!
M``D```"Y;@$`"````,-N`0`0````S&X!`!4```#=;@$`$P```/-N`0`7````
M!V\!``<````?;P$`'@```"=O`0`5````1F\!`!0```!<;P$`!0```'%O`0`4
M````=V\!``8```",;P$`"P```)-O`0`'````GV\!`",```"G;P$`%@```,MO
M`0`/````XF\!``X```#R;P$`*@````%P`0`&````+'`!``P````S<`$`&```
M`$!P`0`-````67`!`!$```!G<`$`"P```'EP`0`V````A7`!``T```"\<`$`
M"@```,IP`0`B````U7`!``L```#X<`$`#P````1Q`0`0````%'$!`"X````E
M<0$`.@```%1Q`0`.````CW$!``T```"><0$`!0```*QQ`0`+````LG$!``P`
M``"^<0$`#0```,MQ`0`-````V7$!``X```#G<0$`#0```/9Q`0`@````!'(!
M`"<````E<@$`*P```$UR`0`(````>7(!``H```""<@$`!@```(UR`0`2````
ME'(!``X```"G<@$`%P```+9R`0`R````SG(!`!X````!<P$`%@```"!S`0`<
M````-W,!``X```!4<P$`%````&-S`0`%````>',!``X```!^<P$`$P```(US
M`0`:````H7,!``<```"\<P$`!@```,1S`0`3````RW,!`!0```#?<P$`$0``
M`/1S`0!+````!G0!``<```!2=`$`%````%IT`0`8````;W0!``<```"(=`$`
M!0```)!T`0`,````EG0!``P```"C=`$`$@```+!T`0`$````PW0!``<```#(
M=`$`"@```-!T`0`+````VW0!``P```#G=`$`#@```/1T`0`.`````W4!``4`
M```2=0$`!0```!AU`0`N````'G4!`"8```!-=0$`(P```'1U`0`#````F'4!
M`!(```"<=0$`!@```*]U`0`&````MG4!`!X```"]=0$`%@```-QU`0`8````
M\W4!``X````,=@$`-P```!MV`0`.````4W8!`!<```!B=@$`00```'IV`0`T
M````O'8!`"4```#Q=@$`%0```!=W`0`Q````+7<!`!,```!?=P$`&P```'-W
M`0`J````CW<!`%$```"Z=P$`6@````QX`0!0````9W@!`"4```"X>`$`#0``
M`-YX`0`)````['@!``,```#V>`$`!P```/IX`0`*`````GD!``@````->0$`
M`@```!9Y`0`0````&7D!``@````J>0$`#````#-Y`0`5````0'D!``L```!6
M>0$`&0```&)Y`0`@````?'D!`!(```"=>0$`!0```+!Y`0`*````MGD!`!4`
M``#!>0$`$@```-=Y`0`,````ZGD!``0```#W>0$`!P```/QY`0`R````!'H!
M``H````W>@$`#````$)Z`0`+````3WH!``<```!;>@$`%@```&-Z`0!2````
M>GH!`#H```#->@$`(`````A[`0`/````*7L!`!<````Y>P$`.0```%%[`0`'
M````BWL!``8```"3>P$`"0```)I[`0`.````I'L!``X```"S>P$`!````,)[
M`0`&````QWL!`!8```#.>P$`#````.5[`0`-````\GL!``X`````?`$`%0``
M``]\`0`2````)7P!``\````X?`$`%````$A\`0!#````77P!``H```"A?`$`
M&P```*Q\`0`U````R'P!`!$```#^?`$`$````!!]`0`+````(7T!`&D````M
M?0$`&@```)=]`0`7````LGT!`"<```#*?0$`&P```/)]`0`:````#GX!`!<`
M```I?@$`&P```$%^`0`9````77X!`!\```!W?@$`%P```)=^`0`<````KWX!
M`!<```#,?@$`#````.1^`0`3````\7X!``@````%?P$`!P````Y_`0`(````
M%G\!`!`````??P$`$0```#!_`0`)````0G\!`!4```!,?P$`#0```&)_`0`&
M````<'\!`!T```!W?P$`!P```)5_`0`3````G7\!``,```"Q?P$`1@```+5_
M`0!#````_'\!`#(```!`@`$`/P```'.``0`W````LX`!`%<```#K@`$`!0``
M`$.!`0`?````28$!`"\```!I@0$`"@```)F!`0`-````I($!`!(```"R@0$`
M*0```,6!`0`(````[X$!``T```#X@0$`+0````:"`0!P````-((!`#\```"E
M@@$`.0```.6"`0!&````'X,!``0```!F@P$`$````&N#`0`0````?(,!``P`
M``"-@P$`%````)J#`0`=````KX,!`!P```#-@P$`$0```.J#`0`]````_(,!
M`$\````ZA`$`)0```(J$`0`@````L(0!`!P```#1A`$`"P```.Z$`0`G````
M^H0!`!H````BA0$`'P```#V%`0`=````784!`"@```![A0$`#P```*2%`0`E
M````M(4!`"````#:A0$`)````/N%`0`D````((8!`"````!%A@$`)0```&:&
M`0`+````C(8!``<```"8A@$`#0```*"&`0`,````KH8!`!<```"[A@$`!0``
M`-.&`0`&````V88!`#D```#@A@$`!0```!J'`0`,````((<!``<````MAP$`
M"0```#6'`0`3````/X<!``8```!3AP$`"0```%J'`0`$````9(<!`!````!I
MAP$`"````'J'`0`(````@X<!``0```",AP$`"P```)&'`0`,````G8<!`!(`
M``"JAP$`$0```+V'`0`,````SX<!`!H```#<AP$`#P```/>'`0`'````!X@!
M``T````/B`$`#P```!V(`0`,````+8@!`!0````ZB`$`%````$^(`0`/````
M9(@!``X```!TB`$`$@```(.(`0`4````EH@!``X```"KB`$`#````+J(`0`;
M````QX@!`"P```#CB`$`$P```!")`0`<````)(D!`"@```!!B0$`!@```&J)
M`0`'````<8D!`!,```!YB0$`!0```(V)`0`$````DXD!``P```"8B0$`%P``
M`*6)`0`2````O8D!``L```#0B0$`#0```-R)`0`4````ZHD!`"\```#_B0$`
M"@```"^*`0`,````.HH!``D```!'B@$`!@```%&*`0`)````6(H!``@```!B
MB@$`"0```&N*`0`%````=8H!``H```![B@$`$0```(:*`0`&````F(H!``X`
M``"?B@$`#@```*Z*`0`-````O8H!``L```#+B@$`$````->*`0`=````Z(H!
M`!$````&BP$`"P```!B+`0`"````)(L!``@````GBP$`!P```#"+`0`-````
M.(L!``8```!&BP$`%@```$V+`0`)````9(L!``<```!NBP$`.P```':+`0`H
M````LHL!`#0```#;BP$`%0```!",`0`%````)HP!``L````LC`$`!P```#B,
M`0`(````0(P!``<```!)C`$`!0```%&,`0`'````5XP!``X```!?C`$`"0``
M`&Z,`0`&````>(P!``@```!_C`$`"P```(B,`0`'````E(P!``@```"<C`$`
M!P```*6,`0`6````K8P!``D```#$C`$`!@```,Z,`0`9````U8P!`!H```#O
MC`$`(`````J-`0`+````*XT!`!P````WC0$`%````%2-`0`'````:8T!``@`
M``!QC0$`"````'J-`0`%````@XT!`!````")C0$`$````)J-`0`&````JXT!
M`!D```"RC0$`"@```,R-`0`<````UXT!``<```#TC0$`!0```/R-`0`%````
M`HX!`!`````(C@$`%````!F.`0`+````+HX!``T````ZC@$`%P```$B.`0`+
M````8(X!`!H```!LC@$`%````(>.`0`O````G(X!``D```#,C@$`"@```-:.
M`0`'````X8X!``(```#IC@$`#@```.R.`0`(````^XX!`!\````$CP$`(P``
M`"2/`0`Q````2(\!`#@```!ZCP$`&P```+./`0`Q````SX\!`#$````!D`$`
M)P```#.0`0`B````6Y`!`"````!^D`$`9````)^0`0`=````!)$!`!0````B
MD0$`'````#>1`0!=````5)$!`%4```"RD0$`.`````B2`0`M````09(!`#,`
M``!OD@$`2P```*.2`0!*````[Y(!`%L````ZDP$`*````):3`0`L````OY,!
M`#@```#LDP$`)0```"64`0`H````2Y0!`"P```!TE`$`)P```*&4`0`;````
MR90!`!X```#EE`$`=0````25`0`^````>I4!`$(```"YE0$`/0```/R5`0`]
M````.I8!`"D```!XE@$`*0```**6`0`Q````S)8!`#X```#^E@$`+P```#V7
M`0"I`0``;9<!`",````7F0$`3P```#N9`0`7````BYD!`$@```"CF0$`-@``
M`.R9`0`^````(YH!`#````!BF@$`(````).:`0`_````M)H!`#0```#TF@$`
M'0```"F;`0`>````1YL!`"H```!FFP$`A0```)&;`0`P````%YP!`$$```!(
MG`$`8````(J<`0!;````ZYP!`$D```!'G0$`-````)&=`0`\````QIT!`#@`
M```#G@$`'0```#R>`0`8````6IX!`*<```!SG@$`(0```!N?`0`?````/9\!
M`#P```!=GP$`)````)J?`0`H````OY\!`"L```#HGP$`(@```!2@`0`A````
M-Z`!`"D```!9H`$`)P```(.@`0`7````JZ`!`"D```##H`$`(````.V@`0`R
M````#J$!`!P```!!H0$`+@```%ZA`0`=````C:$!`!$```"KH0$`,P```+VA
M`0`E````\:$!`#@````7H@$`)P```%"B`0`\````>*(!`"8```"UH@$`'P``
M`-RB`0`P````_*(!`&D````MHP$`/@```)>C`0`^````UJ,!`$<````5I`$`
M/0```%VD`0!E````FZ0!`$T````!I0$`4P```$^E`0!7````HZ4!`%4```#[
MI0$`1@```%&F`0`J````F*8!`"\```##I@$`50```/.F`0`@````2:<!`"X`
M``!JIP$`*P```)FG`0`P````Q:<!`"H```#VIP$`/@```"&H`0!4````8*@!
M`%(```"UJ`$`6@````BI`0`R````8ZD!`"L```"6J0$`2````,*I`0!*````
M"ZH!`"H```!6J@$`)@```(&J`0`L````J*H!`$X```#5J@$`,@```"2K`0`P
M````5ZL!`!T```"(JP$`(P```*:K`0`O````RJL!`"P```#ZJP$`+0```">L
M`0!Q````5:P!`&\```#'K`$`LP```#>M`0`7````ZZT!`"4````#K@$`,@``
M`"FN`0`I````7*X!`#X```"&K@$`(@```,6N`0!2````Z*X!`"4````[KP$`
M"P```&&O`0"Q````;:\!`#L````?L`$`)P```%NP`0!.````@[`!`$<```#2
ML`$`8@```!JQ`0!)````?;$!`%4```#'L0$`0````!VR`0`O````7K(!`#(`
M``".L@$`*P```,&R`0`I````[;(!``\````7LP$`10```">S`0`A````;;,!
M`#````"/LP$`+0```,"S`0`E````[K,!`!P````4M`$`,0```#&T`0`Q````
M8[0!``L```"5M`$`!P```*&T`0`'````J;0!``0```"QM`$`#0```+:T`0`+
M````Q+0!``X```#0M`$`"P```-^T`0`%````Z[0!`!````#QM`$``@````*U
M`0`*````!;4!`%8````0M0$`60```&>U`0`%````P;4!`!(```#'M0$`!```
M`-JU`0`'````W[4!``@```#GM0$`!0```/"U`0`#````]K4!`!````#ZM0$`
M%P````NV`0`,````([8!``P````PM@$`#0```#VV`0`3````2[8!``T```!?
MM@$``@```&VV`0`'````<+8!``8```!XM@$`%````'^V`0`,````E+8!`!@`
M``"AM@$`!@```+JV`0`2````P;8!``P```#4M@$``P```.&V`0`J````Y;8!
M``0````0MP$`!@```!6W`0`'````'+<!`!\````DMP$`-0```$2W`0`N````
M>K<!`"\```"IMP$`%P```-FW`0`@````\;<!`!L````2N`$`&````"ZX`0`D
M````1[@!`!\```!LN`$`&@```(RX`0`@````I[@!`!H```#(N`$`,@```..X
M`0`O````%KD!`"L```!&N0$`'P```'*Y`0`C````DKD!`!\```"VN0$`&@``
M`-:Y`0`E````\;D!`"8````7N@$`)0```#ZZ`0`D````9+H!`!@```")N@$`
M'0```**Z`0`D````P+H!`!@```#EN@$`(@```/ZZ`0`E````(;L!`#P```!'
MNP$`'P```(2[`0`C````I+L!`!\```#(NP$`(````.B[`0`:````";P!`!@`
M```DO`$`&````#V\`0`F````5KP!`!X```!]O`$`*0```)R\`0`>````QKP!
M``H```#EO`$`$P```/"\`0`(````!+T!``D````-O0$`%@```!>]`0`,````
M+KT!`!<````[O0$`+P```%.]`0`D````@[T!``<```"HO0$`'P```+"]`0`/
M````T+T!`!0```#@O0$`#@```/6]`0`-````!+X!`"0````2O@$`!0```#>^
M`0`'````/;X!``P```!%O@$`#P```%*^`0`1````8KX!`"(```!TO@$`)0``
M`)>^`0`=````O;X!`!H```#;O@$`$0```/:^`0`'````"+\!`,<````0OP$`
M!@```-B_`0`+````W[\!`!H```#KOP$`%0````;``0`&````',`!``D````C
MP`$`'0```"W``0`8````2\`!``L```!DP`$`%P```'#``0`&````B,`!`#,`
M``"/P`$`$P```,/``0`3````U\`!``<```#KP`$`#P```//``0`1`````\$!
M`!X````5P0$`!P```#3!`0`R````/,$!``0```!OP0$`(0```'3!`0`3````
MEL$!``P```"JP0$`$0```+?!`0`R````R<$!``@```#\P0$`"0````7"`0`*
M````#\(!`!0````:P@$`"@```"_"`0`=````.L(!``@```!8P@$`'P```&'"
M`0`(````@<(!`!H```"*P@$`!@```*7"`0`5````K,(!``<```#"P@$`"```
M`,K"`0`)````T\(!`#\```#=P@$`!P```!W#`0`/````)<,!``X````UPP$`
M$````$3#`0`)````5<,!``D```!?PP$`"````&G#`0`3````<L,!``0```"&
MPP$`!P```(O#`0`2````D\,!`"8```"FPP$`&0```,W#`0`8````Y\,!``L`
M````Q`$`#@````S$`0`9````&\0!``H````UQ`$`)````$#$`0`A````9<0!
M``H```"'Q`$`$P```)+$`0`G````IL0!``D```#.Q`$`#P```-C$`0`7````
MZ,0!`!0`````Q0$`*````!7%`0`/````/L4!`"````!.Q0$`%````&_%`0`*
M````A,4!``P```"/Q0$`%P```)S%`0`$````M,4!`"H```"YQ0$`$0```.3%
M`0`'````]L4!``(```#^Q0$`$`````'&`0`8````$L8!``L````KQ@$``P``
M`#?&`0`(````.\8!``8```!$Q@$`!P```$O&`0`-````4\8!``L```!AQ@$`
M%````&W&`0`5````@L8!``X```"8Q@$`+P```*?&`0`@````U\8!`!P```#X
MQ@$`6@```!7'`0`_````<,<!`#8```"PQP$`#````.?'`0`Q````],<!``D`
M```FR`$`!0```##(`0`2````-L@!`#\```!)R`$`$@```(G(`0`*````G,@!
M``8```"GR`$`!````*[(`0`$````L\@!``H```"XR`$`$P```,/(`0`%````
MU\@!``8```#=R`$`!@```.3(`0`$````Z\@!``P```#PR`$`"@```/W(`0`%
M````",D!`!@````.R0$`&0```"?)`0`?````0<D!`!T```!AR0$`$0```'_)
M`0`"````D<D!``0```"4R0$`"@```)G)`0`&````I,D!``4```"KR0$``P``
M`+')`0`,````M<D!`#L```#"R0$`)P```/[)`0`A````)LH!`"0```!(R@$`
M10```&W*`0`:````L\H!`!T```#.R@$`-0```.S*`0!6````(LL!`"@```!Y
MRP$`4P```*++`0`Z````]LL!`$(````QS`$`&0```'3,`0`7````CLP!`(L`
M``"FS`$`&0```#+-`0`J````3,T!`"L```!WS0$`<@```*/-`0`@````%LX!
M`#4````WS@$`(0```&W.`0!%````C\X!`"8```#5S@$`,````/S.`0!+````
M+<\!`$X```!YSP$`)P```,C/`0`I````\,\!`"$````:T`$`*````#S0`0`K
M````9=`!`!T```"1T`$`*0```*_0`0`F````V=`!`"T`````T0$`)0```"[1
M`0`H````5-$!`"@```!]T0$`(@```*;1`0`I````R=$!`"(```#ST0$`/0``
M`!;2`0!!````5-(!`"@```"6T@$`+````+_2`0`P````[-(!`!(````=TP$`
M$P```##3`0`0````1-,!`'D```!5TP$`"0```,_3`0`<````V=,!`!````#V
MTP$`#P````?4`0`G````%]0!``X````_U`$`<P```$[4`0!\````PM0!`$``
M```_U0$`*P```(#5`0`7````K-4!`"H```#$U0$`-````._5`0`6````)-8!
M``\````[U@$`*````$O6`0`?````=-8!`$````"4U@$`'P```-76`0`<````
M]=8!`%$````2UP$`%````&37`0`/````>=<!``H```")UP$`!0```)37`0`&
M````FM<!``@```"AUP$`!0```*K7`0`2````L-<!``P```##UP$`$````-#7
M`0`3````X=<!`!T```#UUP$`#P```!/8`0`/````(]@!``0````SV`$`"@``
M`#C8`0`$````0]@!``,```!(V`$`"0```$S8`0`'````5M@!``L```!>V`$`
M"````&K8`0`'````<]@!``4```![V`$`"0```('8`0`4````B]@!``8```"@
MV`$`!P```*?8`0`(````K]@!``\```"XV`$`#P```,C8`0`(````V-@!``P`
M``#AV`$`!@```.[8`0`)````]=@!``L```#_V`$`#P````O9`0`&````&]D!
M``<````BV0$`#0```"K9`0`&````.-D!`!0````_V0$`!P```%39`0`#````
M7-D!``D```!@V0$`!@```&K9`0`,````<=D!``H```!^V0$`#````(G9`0`*
M````EMD!``\```"AV0$`!0```+'9`0`(````M]D!``0```#`V0$`"@```,79
M`0`'````T-D!``0```#8V0$`!````-W9`0`9````XMD!``(```#\V0$`"0``
M`/_9`0`&````"=H!``,````0V@$`!@```!3:`0`,````&]H!`"<````HV@$`
M!````%#:`0`$````5=H!``\```!:V@$`$P```&K:`0`'````?MH!``(```"&
MV@$`!P```(G:`0`&````D=H!``8```"8V@$`$````)_:`0`2````L-H!``X`
M``##V@$`#P```-+:`0`&````XMH!``D```#IV@$`(@```//:`0`'````%ML!
M``<````>VP$`"P```";;`0`%````,ML!``(````XVP$`"P```#O;`0`.````
M1]L!``X```!6VP$`:0$``&7;`0`)````S]P!``D```#9W`$`"@```./<`0`.
M````[MP!`!0```#]W`$`"P```!+=`0`(````'MT!``@````GW0$`!@```##=
M`0`)````-]T!``@```!!W0$`!````$K=`0`!````3]T!`!D```!1W0$`"P``
M`&O=`0!'````=]T!`#,```"_W0$`10```//=`0`Q````.=X!`!(```!KW@$`
M%@```'[>`0`-````E=X!``T```"CW@$`!0```+'>`0`=````M]X!``H```#5
MW@$`"````.#>`0`4````Z=X!``T```#^W@$`,P````S?`0`+````0-\!`"(`
M``!,WP$`*0```&_?`0`,````F=\!`!````"FWP$`#@```+??`0`C````QM\!
M`!D```#JWP$`)P````3@`0`:````+.`!`!$```!'X`$`"0```%G@`0`.````
M8^`!`",```!RX`$`'````);@`0`-````L^`!`!X```#!X`$`+P```.#@`0`S
M````$.$!`!````!$X0$`"0```%7A`0`.````7^$!`!````!NX0$`!@```'_A
M`0`:````AN$!`#<```"AX0$`-P```-GA`0!V````$>(!`&H```"(X@$`&0``
M`//B`0`6````#>,!`!$````DXP$`$@```#;C`0`)````2>,!`$H```!3XP$`
M-@```)[C`0!(````U>,!`#0````>Y`$`#````%/D`0`-````8.0!`!<```!N
MY`$`%P```(;D`0`'````GN0!``P```"FY`$`#````+/D`0`S````P.0!`!<`
M``#TY`$`,P````SE`0!%````0.4!`#T```"&Y0$`30```,3E`0!D````$N8!
M`%P```!WY@$`:P```-3F`0!C````0.<!`#\```"DYP$`"0```.3G`0`)````
M[N<!``P```#XYP$`!0````7H`0`"````"^@!``8````.Z`$`%````!7H`0`,
M````*N@!``4````WZ`$`!@```#WH`0`-````1.@!``D```!2Z`$`"@```%SH
M`0`H````9^@!`"H```"0Z`$`#@```+OH`0`1````RN@!``L```#<Z`$`#```
M`.CH`0`(````]>@!``0```#^Z`$`#0````/I`0`-````$>D!``P````?Z0$`
M#@```"SI`0`.````.^D!`!0```!*Z0$`"@```%_I`0`-````:ND!``H```!X
MZ0$`"P```(/I`0`L````C^D!`!,```"\Z0$`%0```-#I`0`4````YND!``X`
M``#[Z0$`%P````KJ`0`C````(NH!`!L```!&Z@$`%P```&+J`0`7````>NH!
M`"<```"2Z@$`'````+KJ`0`Q````U^H!``4````)ZP$`#0````_K`0`0````
M'>L!`#(````NZP$`!P```&'K`0`#````:>L!``H```!MZP$`"@```'CK`0`'
M````@^L!``@```"+ZP$`!@```)3K`0`*````F^L!``0```"FZP$`'````*OK
M`0`+````R.L!``L```#4ZP$`#````.#K`0!%````[>L!`%0````S[`$`/0``
M`(CL`0!$````QNP!`#P````+[0$`&````$CM`0`T````8>T!``D```"6[0$`
M$0```*#M`0`3````LNT!`!@```#&[0$`'0```-_M`0`/````_>T!``P````-
M[@$`&@```!KN`0`)````->X!`!8````_[@$`#@```%;N`0!"````9>X!`!H`
M``"H[@$`.@```,/N`0`&````_NX!``8````%[P$`"`````SO`0`,````%>\!
M``4````B[P$`"P```"CO`0`4````-.\!``D```!)[P$`$@```%/O`0`(````
M9N\!`!````!O[P$`#@```(#O`0`1````C^\!`!D```"A[P$`.0```+OO`0!#
M````]>\!`!<````Y\`$`!@```%'P`0`.````6/`!``4```!G\`$`%0```&WP
M`0`5````@_`!``P```"9\`$`,@```*;P`0!/````V?`!`"@````I\0$`.@``
M`%+Q`0`\````C?$!`#@```#*\0$`,`````/R`0`S````-/(!`#X```!H\@$`
M0````*?R`0!+````Z/(!``@````T\P$`"@```#WS`0`4````2/,!``P```!=
M\P$`!0```&KS`0`%````</,!``4```!V\P$`$0```'SS`0`,````CO,!`!0`
M``";\P$``P```+#S`0`O````M/,!``\```#D\P$`!````/3S`0`*````^?,!
M`"L````$]`$`"P```##T`0!(````//0!`"@```"%]`$`"0```*[T`0`9````
MN/0!``4```#2]`$`)0```-CT`0`D````_O0!`"D````C]0$`+0```$WU`0`,
M````>_4!``4```"(]0$`#````([U`0`'````F_4!``L```"C]0$`"0```*_U
M`0`O````N?4!`"P```#I]0$`+0```!;V`0!?````1/8!`"P```"D]@$`*P``
M`-'V`0`L````_?8!`"P````J]P$`+@```%?W`0`D````AO<!`"@```"K]P$`
M+````-3W`0`R`````?@!`!D````T^`$`'````$[X`0`S````:_@!`"@```"?
M^`$`80```,CX`0`5````*OD!`!,```!`^0$`#@```%3Y`0`*````8_D!`!$`
M``!N^0$`#````(#Y`0`+````C?D!``<```"9^0$`#0```*'Y`0`7````K_D!
M`!P```#'^0$`"0```.3Y`0`'````[OD!`!0```#V^0$`"0````OZ`0`(````
M%?H!``T````>^@$`"P```"SZ`0`+````./H!``<```!$^@$`!@```$SZ`0`Q
M````4_H!``4```"%^@$`!P```(OZ`0`&````D_H!``D```":^@$`"@```*3Z
M`0`Q````K_H!``T```#A^@$`"0```._Z`0!,````^?H!``8```!&^P$`!```
M`$W[`0`'````4OL!``H```!:^P$`!0```&7[`0`0````:_L!``@```!\^P$`
M#````(7[`0`)````DOL!`#````"<^P$`"````,W[`0`#````UOL!``X```#:
M^P$`"````.G[`0`>````\OL!``8````1_`$`"P```!C\`0`0````)/P!``P`
M```U_`$`!P```$+\`0`#````2OP!``,```!._`$`%0```%+\`0`5````:/P!
M``X```!^_`$`!@```(W\`0`&````E/P!``@```";_`$`!P```*3\`0`T````
MK/P!`#4```#A_`$`4P```!?]`0!,````:_T!`!\```"X_0$`!@```-C]`0`%
M````W_T!``\```#E_0$`%P```/7]`0!+````#?X!`!@```!9_@$`&````'+^
M`0`Q````B_X!`!H```"]_@$`'P```-C^`0!W````^/X!`"P```!P_P$`"@``
M`)W_`0`&````J/\!`!@```"O_P$`#@```,C_`0`,````U_\!``P```#D_P$`
M$0```/'_`0`3`````P`"`!$````7``(`$0```"D``@`,````.P`"`!0```!(
M``(`!````%T``@`7````8@`"`!@```!Z``(`&````),``@`6````K``"``,`
M``##``(`!@```,<``@`(````S@`"``\```#7``(`#P```.<``@!H````]P`"
M`#<```!@`0(`:P```)@!`@![````!`("``@```"``@(`&P```(D"`@`6````
MI0("`!X```"\`@(`)````-L"`@`[``````,"`#0````\`P(`!````'$#`@`#
M````=@,"`!\```!Z`P(`%P```)H#`@`)````L@,"`!X```"\`P(`#````-L#
M`@`3````Z`,"``P```#\`P(`)P````D$`@`S````,00"`#$```!E!`(`,0``
M`)<$`@`1````R00"`!H```#;!`(`!P```/8$`@`?````_@0"`!<````>!0(`
M$0```#8%`@`8````2`4"`$L```!A!0(`-````*T%`@`U````X@4"`$(````8
M!@(`/@```%L&`@`W````F@8"`$L```#2!@(`*````!X'`@!4````1P<"`!D`
M``"<!P(`/````+8'`@!"````\P<"`!<````V"`(`0@```$X(`@!"````D0@"
M``4```#4"`(`#P```-H(`@`/````Z@@"``T```#Z"`(`"`````@)`@`'````
M$0D"``T````9"0(`!@```"<)`@`.````+@D"`!8````]"0(`#0```%0)`@`5
M````8@D"`!0```!X"0(`"0```(T)`@`$````EPD"`!$```"<"0(`"P```*X)
M`@`+````N@D"``D```#&"0(`$````-`)`@`%````X0D"``4```#G"0(`#```
M`.T)`@`(````^@D"``D````#"@(`!P````T*`@`&````%0H"``H````<"@(`
M%P```"<*`@`P````/PH"`'T```!P"@(`#0```.X*`@`(````_`H"`!4````%
M"P(`#0```!L+`@`O````*0L"`"\```!9"P(`$````(D+`@`%````F@L"`!P`
M``"@"P(`&````+T+`@`8````U@L"`"P```#O"P(`.P```!P,`@`E````6`P"
M`!L```!^#`(`-P```)H,`@`%````T@P"`!X```#8#`(`(0```/<,`@!I````
M&0T"`$\```"##0(`#````-,-`@`%````X`T"``<```#F#0(`#@```.X-`@`.
M````_0T"``8````,#@(`$0```!,.`@`*````)0X"``T````P#@(`'````#X.
M`@`;````6PX"`!\```!W#@(`'@```)<.`@`?````M@X"`!X```#6#@(`&```
M`/4.`@`@````#@\"`"`````O#P(`(0```%`/`@`D````<@\"`!\```"7#P(`
M'@```+</`@`K````U@\"`"\````"$`(`'0```#(0`@`R````4!`"`#$```"#
M$`(`(P```+40`@`E````V1`"`#$```#_$`(`+@```#$1`@`-````8!$"`"4`
M``!N$0(`#0```)01`@"9````HA$"`!`````\$@(`'P```$T2`@`A````;1("
M`",```"/$@(`)````+,2`@`A````V!("`!X```#Z$@(`)0```!D3`@`H````
M/Q,"`"P```!H$P(`HP```)43`@`8````.10"`",```!2%`(`(@```'84`@!+
M````F10"``X```#E%`(`!````/04`@`'````^10"``4````!%0(`"P````<5
M`@`-````$Q4"`!$````A%0(`#@```#,5`@`8````0A4"``H```!;%0(`(P``
M`&85`@`5````BA4"`'0```"@%0(`#P```!46`@`1````)18"`!,````W%@(`
M"P```$L6`@`$````5Q8"``\```!<%@(`#0```&P6`@`5````>A8"`!L```"0
M%@(`$@```*P6`@`2````OQ8"`%````#2%@(`*@```",7`@`P````3A<"``,`
M``!_%P(`$P```(,7`@`&````EQ<"``X```">%P(`%````*T7`@`6````PA<"
M``\```#9%P(``@```.D7`@`&````[!<"``8```#S%P(`%0```/H7`@`%````
M$!@"``P````6&`(`#````",8`@`#````,!@"``L````T&`(`!@```$`8`@`/
M````1Q@"``H```!7&`(`"@```&(8`@`/````;1@"``\```!]&`(`$0```(T8
M`@`;````GQ@"`!D```"[&`(`"````-48`@`'````WA@"``,```#F&`(`%@``
M`.H8`@`<`````1D"``H````>&0(`"````"D9`@`(````,AD"`!`````[&0(`
M&````$P9`@`)````91D"``D```!O&0(`&0```'D9`@`J````DQD"``\```"^
M&0(`*````,X9`@`X````]QD"``H````P&@(`%````#L:`@`4````4!H"`!0`
M``!E&@(`"0```'H:`@`2````A!H"`!````"7&@(`(0```*@:`@`-````RAH"
M``D```#8&@(`#0```.(:`@`G````\!H"``8````8&P(`$0```!\;`@`(````
M,1L"``H````Z&P(`/````$4;`@`R````@AL"``<```"U&P(`"P```+T;`@`:
M````R1L"``T```#D&P(`%````/(;`@`1````!QP"`!$````9'`(`!0```"L<
M`@`&````,1P"`"`````X'`(`%P```%D<`@`T````<1P"`!X```"F'`(`$@``
M`,4<`@`=````V!P"`#X```#V'`(`!0```#4=`@`/````.QT"``8```!+'0(`
M"@```%(=`@`@````71T"``@```!^'0(`+0```(<=`@`A````M1T"`!T```#7
M'0(`/@```/4=`@`'````-!X"`!,````\'@(`!0```%`>`@`%````5AX"``@`
M``!<'@(`%P```&4>`@`H````?1X"``P```"F'@(`'0```+,>`@`S````T1X"
M`!0````%'P(`!@```!H?`@`-````(1\"`!$````O'P(`$@```$$?`@`'````
M5!\"``<```!<'P(`%P```&0?`@`#````?!\"`"(```"`'P(`!P```*,?`@`'
M````JQ\"`!0```"S'P(`#````,@?`@`2````U1\"``P```#H'P(`#````/4?
M`@`0`````B`"`!@````3(`(`%P```"P@`@`D````1"`"`!4```!I(`(`%```
M`'\@`@`8````E"`"`!D```"M(`(`'P```,<@`@`^````YR`"`!H````F(0(`
M!@```$$A`@`%````2"$"``L```!.(0(`!@```%HA`@`"````82$"`!````!D
M(0(`%P```'4A`@`E````C2$"`!<```"S(0(`$````,LA`@`D````W"$"``X`
M```!(@(`$P```!`B`@`4````)"("``H````Y(@(`"@```$0B`@`3````3R("
M`!\```!C(@(`(@```(,B`@!.````IB("`",```#U(@(`*@```!DC`@`6````
M1","``,```!;(P(`%@```%\C`@`-````=B,"`!0```"$(P(`"@```)DC`@`6
M````I","`!4```"[(P(`<@```-$C`@`=````1"0"`!\```!B)`(`+````((D
M`@`>````KR0"`"T```#.)`(`#@```/PD`@`&````"R4"``0````2)0(`&P``
M`!<E`@`@````,R4"``<```!4)0(`"````%PE`@`%````924"``8```!K)0(`
M%P```'(E`@`-````BB4"``P```"8)0(`#0```*4E`@`,````LR4"``L```#`
M)0(`#@```,PE`@`*````VR4"``\```#F)0(`"````/8E`@`(````_R4"`!``
M```()@(`&````!DF`@`/````,B8"``\```!")@(`%P```%(F`@!-````:B8"
M`"X```"X)@(`#@```.<F`@`.````]B8"`"\````%)P(`%0```#4G`@`#````
M2R<"``T```!/)P(`&@```%TG`@`@````>"<"`",```"9)P(`(@```+TG`@`D
M````X"<"`"(````%*`(`)````"@H`@`?````32@"``H```!M*`(`&@```'@H
M`@`-````DR@"``T```"A*`(`!````*\H`@`%````M"@"``P```"Z*`(`#@``
M`,<H`@`+````UB@"`"<```#B*`(`)P````HI`@`,````,BD"`!P````_*0(`
M#0```%PI`@`2````:BD"``H```!]*0(`#````(@I`@`$````E2D"``4```":
M*0(`%@```*`I`@`6````MRD"`!````#.*0(`"0```-\I`@`,````Z2D"``T`
M``#V*0(`'0````0J`@`2````(BH"``\````U*@(`(````$4J`@`Q````9BH"
M``D```"8*@(`%0```*(J`@`=````N"H"``,```#6*@(`"@```-HJ`@`(````
MY2H"`!@```#N*@(`"0````<K`@`*````$2L"``T````<*P(`!0```"HK`@`%
M````,"L"``4````V*P(``P```#PK`@`-````0"L"``X```!.*P(`"P```%TK
M`@`C````:2L"`",```"-*P(`"@```+$K`@`%````O"L"`"H```#"*P(`#```
M`.TK`@![````^BL"`!<```!V+`(`/@```(XL`@`'````S2P"``4```#5+`(`
M"@```-LL`@`(````YBP"``H```#O+`(`"````/HL`@`$`````RT"``4````(
M+0(`#@````XM`@`<````'2T"``X````Z+0(``@```$DM`@`*````3"T"``8`
M``!7+0(`%````%XM`@`4````<RT"`!0```"(+0(`%````)TM`@`;````LBT"
M`!````#.+0(`$P```-\M`@`5````\RT"``<````)+@(`!@```!$N`@`+````
M&"X"``8````D+@(`#0```"LN`@`'````.2X"``<```!!+@(`!0```$DN`@`%
M````3RX"`!<```!5+@(`!0```&TN`@`=````<RX"``<```"1+@(`!P```)DN
M`@`0````H2X"`!L```"R+@(`#P```,XN`@`)````WBX"``<```#H+@(`(@``
M`/`N`@`$````$R\"``L````8+P(`"@```"0O`@`+````+R\"``8````[+P(`
M#````$(O`@`*````3R\"``L```!:+P(`"@```&8O`@`4````<2\"``@```"&
M+P(`!P```(\O`@`-````ER\"`!P```"E+P(`!P```,(O`@`(````RB\"``0`
M``#3+P(`"0```-@O`@`(````XB\"``X```#K+P(`#0```/HO`@`$````"#`"
M``P````-,`(`!@```!HP`@`&````(3`"``0````H,`(`%````"TP`@`R````
M0C`"`#,```!U,`(`,P```*DP`@`@````W3`"``4```#^,`(`$`````0Q`@`)
M````%3$"``8````?,0(`#@```"8Q`@`?````-3$"`!<```!5,0(`"0```&TQ
M`@`&````=S$"`!L```!^,0(`"````)HQ`@`(````HS$"`!4```"L,0(`'```
M`,(Q`@`%````WS$"`"4```#E,0(`%`````LR`@`7````(#("``8````X,@(`
M#@```#\R`@`)````3C("``D```!8,@(`!P```&(R`@`(````:C("``D```!S
M,@(`"P```'TR`@`(````B3("``D```"2,@(`!0```)PR`@!(````HC("`#<`
M``#K,@(`.P```",S`@`G````7S,"`$D```"',P(`.P```-$S`@`C````#30"
M`#<````Q-`(`(P```&DT`@`:````C30"`!@```"H-`(`"P```,$T`@`0````
MS30"``8```#>-`(`*P```.4T`@`G````$34"`"H````Y-0(`%0```&0U`@`J
M````>C4"`"T```"E-0(``P```-,U`@`%````US4"``H```#=-0(`"@```.@U
M`@`$````\S4"`#(```#X-0(`)````"LV`@`@````4#8"`"L```!Q-@(`$@``
M`)TV`@`R````L#8"`"4```#C-@(`#0````DW`@`E````%S<"``P````]-P(`
M"0```$HW`@`8````5#<"`"\```!M-P(`%````)TW`@`7````LC<"``<```#*
M-P(`#P```-(W`@`0````XC<"`!L```#S-P(`#0````\X`@!%````'3@"`&H`
M``!C.`(`@0```,XX`@`&````4#D"``T```!7.0(`$````&4Y`@`+````=CD"
M``P```"".0(`$````(\Y`@`1````H#D"`!````"R.0(`"@```,,Y`@`-````
MSCD"`!@```#<.0(`'P```/4Y`@`7````%3H"`!P````M.@(`*````$HZ`@`G
M````<SH"`"T```";.@(`&P```,DZ`@`F````Y3H"`"0````,.P(`'P```#$[
M`@`<````43L"`"L```!N.P(`%````)H[`@`&````KSL"``\```"V.P(`*0``
M`,8[`@`8````\#L"`!@````)/`(`!P```"(\`@`3````*CP"``P````^/`(`
M-@```$L\`@`?````@CP"`!H```"B/`(`)````+T\`@!H````XCP"`!````!+
M/0(`"0```%P]`@`5````9CT"``D```!\/0(`!0```(8]`@`%````C#T"`"$`
M``"2/0(`(P```+0]`@`C````V#T"``T```#\/0(`$P````H^`@`?````'CX"
M`!$````^/@(`+````%`^`@`K````?3X"`"0```"I/@(`$0```,X^`@`8````
MX#X"`!(```#Y/@(`+@````P_`@`O````.S\"`#````!K/P(`+P```)P_`@`S
M````S#\"`#(`````0`(`%@```#-``@!#````2D`"`!L```".0`(`&@```*I`
M`@`:````Q4`"`!D```#@0`(`"0```/I``@`=````!$$"`!P````B00(`&@``
M`#]!`@`9````6D$"`!H```!T00(`'````(]!`@`;````K$$"`"X```#(00(`
M#@```/=!`@`'````!D("``\````.0@(`*P```!Y"`@`.````2D("`"4```!9
M0@(`+0```']"`@`2````K4("`!<```#`0@(`,0```-A"`@`9````"D,"`!8`
M```D0P(`%0```#M#`@`0````44,"`!$```!B0P(`'0```'1#`@`D````DD,"
M`!(```"W0P(`(P```,I#`@`C````[D,"`!L````21`(`&0```"Y$`@`7````
M2$0"`!@```!@1`(`!````'E$`@`*````?D0"`!8```")1`(`!````*!$`@`'
M````I40"``\```"M1`(`(````+U$`@`&````WD0"``<```#E1`(`!@```.U$
M`@`&````]$0"``<```#[1`(`!`````-%`@`'````"$4"`!4````010(`!@``
M`"9%`@`%````+44"``8````S10(`!P```#I%`@`%````0D4"``P```!(10(`
M#0```%5%`@`*````8T4"``H```!N10(``@```'E%`@`*````?$4"`!@```"'
M10(`!0```*!%`@`E````ID4"`!(```#,10(`#0```-]%`@`1````[44"`!``
M``#_10(`#````!!&`@`1````'48"`"L````O1@(`-0```%M&`@`(````D48"
M``@```":1@(`"@```*-&`@`*````KD8"``\```"Y1@(`!@```,E&`@`+````
MT$8"``T```#<1@(``P```.I&`@`?````[D8"``H````.1P(`&````!E'`@`)
M````,D<"``D````\1P(`#P```$9'`@`-````5D<"`!H```!D1P(`#P```']'
M`@`'````CT<"``0```"71P(`!0```)Q'`@`=````HD<"``8```#`1P(``P``
M`,='`@`2````RT<"`!````#>1P(`!P```.]'`@`-````]T<"``<````%2`(`
M!0````U(`@`-````$T@"``D````A2`(`#````"M(`@`<````.$@"`!H```!5
M2`(`%0```'!(`@`:````AD@"``D```"A2`(`$@```*M(`@`,````OD@"``@`
M``#+2`(`$0```-1(`@!!````YD@"`!\````H20(`"P```$A)`@`D````5$D"
M``P```!Y20(`)````(9)`@`8````JTD"`!D```#$20(`$P```-Y)`@"G````
M\DD"``T```":2@(`#@```*A*`@`*````MTH"``T```#"2@(`&@```-!*`@`5
M````ZTH"`!T````!2P(`$@```!]+`@`F````,DL"``@```!92P(`"````&)+
M`@`-````:TL"`!,```!Y2P(`#````(U+`@`,````FDL"``,```"G2P(`!0``
M`*M+`@`)````L4L"``4```"[2P(`!0```,%+`@`/````QTL"`$,```#72P(`
M%0```!M,`@`*````,4P"``,````\3`(`!0```$!,`@`-````1DP"`!0```!4
M3`(`%````&E,`@`4````?DP"``@```"33`(`"@```)Q,`@`"````ITP"``0`
M``"J3`(`(````*],`@`#````T$P"``4```#43`(`"0```-I,`@`1````Y$P"
M``H```#V3`(`!`````%-`@`%````!DT"`!`````,30(`#@```!U-`@`J````
M+$T"``P```!730(`+0```&1-`@`2````DDT"``8```"E30(`!P```*Q-`@`)
M````M$T"``0```"^30(`!0```,--`@!C````R4T"``X````M3@(`$0```#Q.
M`@`$````3DX"``T```!33@(`,@```&%.`@`S````E$X"``D```#(3@(`/```
M`-).`@`V````#T\"`"````!&3P(`(0```&=/`@`_````B4\"`!````#)3P(`
M"````-I/`@`6````XT\"`!L```#Z3P(`#P```!90`@`)````)E`"``@````P
M4`(`'0```#E0`@`F````5U`"`"0```!^4`(`(P```*-0`@`2````QU`"`!$`
M``#:4`(`'@```.Q0`@`>````"U$"``4````J40(`!P```#!1`@`#````.%$"
M``\````\40(`$````$Q1`@`0````75$"``\```!N40(`%0```'Y1`@`:````
ME%$"``8```"O40(`$@```+91`@`*````R5$"`!,```#440(`!0```.A1`@`/
M````[E$"``P```#^40(`$0````M2`@`+````'5("``P````I4@(`#0```#92
M`@!(````1%("``X```"-4@(`%0```)Q2`@`0````LE("``\```##4@(`#```
M`--2`@`0````X%("`"(```#Q4@(`.0```!13`@`;````3E,"``H```!J4P(`
M+````'53`@`)````HE,"``L```"L4P(`)P```+A3`@!,````X%,"``8````M
M5`(`!@```#14`@`'````.U0"``H```!#5`(`!````$Y4`@`)````4U0"`",`
M``!=5`(`(@```(%4`@`%````I%0"``@```"J5`(`)@```+-4`@!@````VE0"
M`!(````[50(`)P```$Y5`@`8````=E4"``,```"/50(`#````)-5`@`%````
MH%4"``X```"F50(`"````+55`@`,````OE4"``H```#+50(`"````-95`@`&
M````WU4"``H```#F50(`"0```/%5`@`%````^U4"``H````!5@(`"P````Q6
M`@`#````&%8"``\````<5@(`$@```"Q6`@`2````/U8"``0```!25@(`"@``
M`%=6`@`)````8E8"``D```!L5@(`"P```'96`@`*````@E8"``L```"-5@(`
M"P```)E6`@`(````I58"`"$```"N5@(`%0```-!6`@`+````YE8"``<```#R
M5@(`"````/I6`@`.`````U<"``<````25P(`#P```!I7`@`#````*E<"``(`
M```N5P(`)@```#%7`@`'````6%<"``4```!@5P(`#P```&97`@`%````=E<"
M``@```!\5P(`$@```(57`@`2````F%<"`!4```"K5P(`%0```,%7`@`4````
MUU<"`!(```#L5P(`%P```/]7`@`@````%U@"`!H````X6`(``@```%-8`@`$
M````5E@"`!,```!;6`(`!````&]8`@`.````=%@"``T```"#6`(`"@```)%8
M`@`*````G%@"``<```"G6`(`'````*]8`@`-````S%@"``T```#:6`(`$P``
M`.A8`@`(````_%@"``X````%60(`!P```!19`@`-````'%D"``T````J60(`
M$@```#A9`@`)````2UD"``<```!560(`!P```%U9`@`$````95D"``0```!J
M60(`!0```&]9`@`7````=5D"``T```"-60(`'@```)M9`@`)````NED"`"T`
M``#$60(`)````/)9`@`7````%UH"`#$````O6@(`%0```&%:`@!#````=UH"
M`#H```"[6@(`$@```/9:`@`K````"5L"`#@````U6P(`#@```&Y;`@`I````
M?5L"`#$```"G6P(`-@```-E;`@`V````$%P"`#L```!'7`(`"@```(-<`@`G
M````CEP"`!@```"V7`(`&@```,]<`@`K````ZEP"`!D````670(`'0```#!=
M`@`C````3ET"`!@```!R70(`&````(M=`@`:````I%T"`!@```"_70(`(@``
M`-A=`@`0````^UT"`!0````,7@(`&````"%>`@`G````.EX"`"<```!B7@(`
M*P```(I>`@`H````MEX"`"D```#?7@(`)@````E?`@!@````,%\"`!P```"1
M7P(`-@```*Y?`@`V````Y5\"`#@````<8`(`"0```%5@`@`'````7V`"`#``
M``!G8`(`$````)A@`@`)````J6`"`"8```"S8`(`%P```-I@`@`J````\F`"
M`"`````=80(`"0```#YA`@!#````2&$"`$8```",80(`#P```--A`@`'````
MXV$"`!D```#K80(`'`````5B`@`-````(F("``8````P8@(`#P```#=B`@`5
M````1V("``8```!=8@(`$````&1B`@`/````=6("``P```"%8@(`#````))B
M`@`'````GV("``T```"G8@(`"P```+5B`@`?````P6("`!4```#A8@(`$P``
M`/=B`@`0````"V,"``T````<8P(`#P```"IC`@`7````.F,"``8```!28P(`
M)````%EC`@`%````?F,"``0```"$8P(`#P```(EC`@`,````F6,"`$@```"F
M8P(`60```.]C`@`,````260"`$````!69`(`!````)=D`@`$````G&0"``4`
M``"A9`(`$````*=D`@`/````N&0"``0```#(9`(`%````,UD`@`$````XF0"
M``T```#G9`(`*P```/5D`@`%````(64"`#T````G90(`.````&5E`@`9````
MGF4"`#@```"X90(`+````/%E`@!=````'F8"`!$```!\9@(`10```(YF`@`2
M````U&8"`!\```#G9@(`#P````=G`@`1````%V<"``H````I9P(`$@```#1G
M`@`0````1V<"``<```!89P(`#@```&!G`@`)````;V<"`!8```!Y9P(`'```
M`)!G`@`%````K6<"``X```"S9P(`%0```,)G`@`0````V&<"``X```#I9P(`
M'0```/AG`@`#````%F@"`!`````::`(`&0```"MH`@`4````16@"``P```!:
M:`(`1````&=H`@`/````K&@"`!H```"\:`(`40```-=H`@`1````*6D"`!8`
M```[:0(`,P```%)I`@`I````AFD"`!@```"P:0(`#P```,EI`@`9````V6D"
M`",```#S:0(`)````!=J`@`D````/&H"`"X```!A:@(`1P```)!J`@!)````
MV&H"``@````B:P(`"@```"MK`@`/````-FL"``X```!&:P(`!@```%5K`@`2
M````7&L"`!@```!O:P(`!````(AK`@`N````C6L"`!(```"\:P(`,0```,]K
M`@`E`````6P"``P````G;`(`"P```#1L`@`*````0&P"``T```!+;`(`)@``
M`%EL`@`F````@&P"``@```"G;`(`!0```+!L`@`>````MFP"``8```#5;`(`
M#P```-QL`@`(````[&P"``H```#U;`(`#@````!M`@`/````#VT"`!@````?
M;0(`)0```#AM`@`0````7FT"`!T```!O;0(`(@```(UM`@`&````L&T"``T`
M``"W;0(`+0```,5M`@`-````\VT"``<````!;@(`!P````EN`@`>````$6X"
M``@````P;@(`$````#EN`@`#````2FX"`!,```!.;@(`"````&)N`@`%````
M:VX"`!X```!Q;@(`+0```)!N`@`$````OFX"``T```##;@(`*````-%N`@`'
M````^FX"`!`````";P(`+P```!-O`@`J````0V\"`#(```!N;P(`+0```*%O
M`@`$````SV\"``\```#4;P(`"@```.1O`@`'````[V\"``L```#W;P(`"```
M``-P`@`,````#'`"`#\````9<`(`&0```%EP`@`-````<W`"`!X```"!<`(`
M,0```*!P`@`V````TG`"`!\````)<0(`)````"EQ`@`K````3G$"`",```!Z
M<0(`/P```)YQ`@`?````WG$"`"0```#^<0(`%@```"-R`@!W````.G("`'H`
M``"R<@(`,0$``"US`@`A````7W0"`!@```"!=`(`*````)IT`@`?````PW0"
M`"X```#C=`(`50```!)U`@!"````:'4"`"D```"K=0(`*````-5U`@`L````
M_G4"`#T````K=@(`(0```&EV`@`'````BW8"``@```"3=@(`"0```)QV`@`(
M````IG8"`!D```"O=@(`&0```,EV`@`S````XW8"``\````7=P(`,P```"=W
M`@`J````6W<"`"0```"&=P(`+0```*MW`@`R````V7<"``8````,>`(`&P``
M`!-X`@`'````+W@"``@````W>`(`'P```$!X`@`,````8'@"``P```!M>`(`
M$0```'IX`@`&````C'@"``X```"3>`(`!P```*)X`@`,````JG@"`!4```"W
M>`(`!0```,UX`@`1````TW@"``@```#E>`(`+P```.YX`@`N````'GD"`!(`
M``!->0(`$P```&!Y`@`,````='D"`!@```"!>0(`-````)IY`@`Q````SWD"
M``H````!>@(`%@````QZ`@`5````(WH"`!,````Y>@(`'0```$UZ`@`\````
M:WH"`"T```"H>@(`!0```-9Z`@`%````W'H"`"4```#B>@(`'@````A[`@`5
M````)WL"``<````]>P(`&@```$5[`@`,````8'L"``8```!M>P(`%@```'1[
M`@`4````BWL"``T```"@>P(`#0```*Y[`@`5````O'L"``X```#2>P(`!```
M`.%[`@`2````YGL"``4```#Y>P(`#0```/][`@!(````#7P"`&,```!6?`(`
M#P```+I\`@`6````RGP"`!0```#A?`(`"@```/9\`@`)`````7T"`!$````+
M?0(`%````!U]`@`;````,GT"`!,```!.?0(`!@```&)]`@`?````:7T"`!P`
M``")?0(`&0```*9]`@`-````P'T"``\```#.?0(`#0```-Y]`@`6````['T"
M``L````#?@(`'P````]^`@`4````+WX"`!8```!$?@(`$@```%M^`@`L````
M;GX"``,```";?@(`"0```)]^`@`4````J7X"``H```"^?@(`#P```,E^`@`+
M````V7X"`#(```#E?@(`#0```!A_`@`#````)G\"`!H````J?P(`#0```$5_
M`@`3````4W\"`!<```!G?P(`/P```']_`@!2````OW\"`!`````2@`(`"P``
M`".``@`'````+X`"`!$````W@`(`#P```$F``@`0````68`"``\```!J@`(`
M$````'J``@`0````BX`"`"````"<@`(`+0```+V``@`K````ZX`"``P````7
M@0(`#0```"2!`@`(````,H$"`!4````[@0(`(````%&!`@`4````<H$"`"<`
M``"'@0(`%````*^!`@`<````Q($"`!D```#A@0(`#````/N!`@`1````"(("
M``<````:@@(`$````"*"`@`5````,X("`"$```!)@@(`"````&N"`@`(````
M=(("`!8```!]@@(`%0```)2"`@`1````JH("`&0```"\@@(`!P```"&#`@`:
M````*8,"`"8```!$@P(`"@```&N#`@`#````=H,"`!(```!Z@P(`#@```(V#
M`@`5````G(,"``4```"R@P(`!P```+B#`@`1````P(,"``L```#2@P(`"P``
M`-Z#`@`1````ZH,"`!$```#\@P(`"0````Z$`@`(````&(0"`#0````AA`(`
M+@```%:$`@`N````A80"``@```"TA`(`$0```+V$`@`&````SX0"``8```#6
MA`(`%P```-V$`@`8````]80"`!P````.A0(`#@```"N%`@!#````.H4"`!(`
M``!^A0(`'0```)&%`@!/````KX4"`#(```#_A0(`)P```#*&`@`;````6H8"
M`#,```!VA@(`$@```*J&`@`8````O88"`#$```#6A@(`4P````B'`@!1````
M7(<"`%(```"NAP(`'@````&(`@`.````((@"``H````OB`(``P```#J(`@`(
M````/H@"``L```!'B`(`!0```%.(`@`#````68@"`!$```!=B`(`#@```&^(
M`@`,````?H@"`!0```"+B`(`"P```*"(`@`8````K(@"`!L```#%B`(`%P``
M`.&(`@`%````^8@"``H```#_B`(`%`````J)`@`.````'XD"``\````NB0(`
M!@```#Z)`@`)````18D"`$0```!/B0(`#0```)2)`@`2````HHD"``X```"U
MB0(`#0```,2)`@`L````THD"`$X```#_B0(`1@```$Z*`@`@````E8H"`"$`
M``"VB@(`'0```-B*`@`P````]HH"``4````GBP(`!0```"V+`@`'````,XL"
M``\````[BP(`#P```$N+`@`'````6XL"``,```!CBP(`$P```&>+`@`-````
M>XL"``\```")BP(`#@```)F+`@`;````J(L"`!$```#$BP(`$````-:+`@`@
M````YXL"`#P````(C`(`!0```$6,`@`?````2XP"`#8```!KC`(`#P```**,
M`@`/````LHP"``<```#"C`(`;@```,J,`@`<````.8T"`!4```!6C0(`)@``
M`&R-`@`;````DXT"`!L```"OC0(`%````,N-`@`8````X(T"`!8```#YC0(`
M'````!".`@`:````+8X"`"<```!(C@(`%````'".`@`,````A8X"`!,```"2
MC@(`"@```*:.`@`'````L8X"``L```"YC@(`&````,6.`@`9````WHX"``4`
M``#XC@(`%P```/Z.`@`-````%H\"``8````DCP(`&0```"N/`@`'````18\"
M`!\```!-CP(`!@```&V/`@!*````=(\"`$<```"_CP(`,`````>0`@`Q````
M.)`"`$0```!JD`(`8P```*^0`@`'````$Y$"`#0````;D0(`*````%"1`@`&
M````>9$"`!(```"`D0(`&@```).1`@`N````KI$"``H```#=D0(`"0```.B1
M`@`R````\I$"`)$````ED@(`.0```+>2`@!`````\9("`#H````RDP(`!@``
M`&V3`@`6````=),"`!T```"+DP(`%````*F3`@`C````OI,"`"<```#BDP(`
M(P````J4`@`8````+I0"`$0```!'E`(`6P```(R4`@`K````Z)0"`"\````4
ME0(`)0```$25`@`/````:I4"`#<```!ZE0(`*0```+*5`@`P````W)4"`!\`
M```-E@(`,@```"V6`@`2````8)8"`"<```!SE@(`(0```)N6`@`G````O98"
M`"T```#EE@(`(P```!.7`@`M````-Y<"`!````!EEP(`!P```':7`@`7````
M?I<"`!4```"6EP(`#P```*R7`@`*````O)<"``8```#'EP(`+P```,Z7`@`&
M````_I<"``P````%F`(`!@```!*8`@`$````&9@"`!`````>F`(`#````"^8
M`@`(````/)@"``4```!%F`(`"P```$N8`@`(````5Y@"``@```!@F`(``P``
M`&F8`@`,````;9@"``\```!ZF`(`'P```(J8`@`=````JI@"``\```#(F`(`
M%@```-B8`@`/````[Y@"``8```#_F`(`$@````:9`@`:````&9D"`!(````T
MF0(`&````$>9`@`:````8)D"`!(```![F0(`&````(Z9`@`2````IYD"`!8`
M``"ZF0(`#0```-&9`@`,````WYD"`!D```#LF0(`)P````::`@`/````+IH"
M`"(````^F@(`*P```&&:`@`1````C9H"``X```"?F@(`'````*Z:`@`'````
MRYH"`!````#3F@(`&````.2:`@`4````_9H"`!`````2FP(`#@```".;`@`/
M````,IL"`!D```!"FP(`/@```%R;`@`+````FYL"``H```"GFP(`"@```+*;
M`@`'````O9L"``D```#%FP(`"````,^;`@`)````V)L"``8```#BFP(`#@``
M`.F;`@`.````^)L"``4````'G`(`#P````V<`@`,````'9P"``P````JG`(`
M#0```#><`@`-````19P"`!H```!3G`(`%@```&Z<`@`+````A9P"``,```"1
MG`(`!0```)6<`@`$````FYP"``H```"@G`(`!@```*N<`@`-````LIP"``@`
M``#`G`(`!@```,F<`@!4````T)P"`"@````EG0(`,P```$Z=`@`5````@IT"
M``4```"8G0(`"````)Z=`@`$````IYT"``H```"LG0(`"@```+>=`@`'````
MPIT"``H```#*G0(`%0```-6=`@`,````ZYT"``H```#XG0(`#`````.>`@`(
M````$)X"``8````9G@(`!P```"">`@`&````*)X"`!4````OG@(`"0```$6>
M`@`%````3YX"`!P```!5G@(`&P```'*>`@`A````CIX"``<```"PG@(`(@``
M`+B>`@`&````VYX"`!4```#BG@(`&````/B>`@`+````$9\"``<````=GP(`
M$P```"6?`@`3````.9\"``8```!-GP(`$P```%2?`@`*````:)\"``@```!S
MGP(`!@```'R?`@`(````@Y\"``8```",GP(`$````).?`@`8````I)\"``@`
M``"]GP(`"@```,:?`@`/````T9\"``<```#AGP(`'0```.F?`@`:````!Z`"
M`#H````BH`(`#````%V@`@`0````:J`"``L```![H`(``P```(>@`@`-````
MBZ`"``<```"9H`(`+````*&@`@`J````SJ`"`",```#YH`(`.0```!VA`@`A
M````5Z$"`#(```!YH0(`)````*RA`@`M````T:$"`!0```#_H0(`%P```!2B
M`@!?````+*("``X```",H@(`$````)NB`@`7````K*("`%T```#$H@(`5P``
M`"*C`@`U````>J,"`"@```"PHP(`.P```-FC`@`U````%:0"`%H```!+I`(`
M4P```*:D`@`>````^J0"`"`````9I0(`0@```#JE`@`9````?:4"`"````"7
MI0(`(P```+BE`@`A````W*4"`!4```#^I0(`%@```!2F`@!U````*Z8"`#``
M``"AI@(`/0```-*F`@`U````$*<"`#$```!&IP(`(````'BG`@`>````F:<"
M`#<```"XIP(`/P```/"G`@`E````,*@"`-(!``!6J`(`%````"FJ`@!+````
M/JH"`!````"*J@(`00```)NJ`@`Z````W:H"`#D````8JP(`,P```%*K`@`:
M````AJL"`$@```"AJP(`+````.JK`@`.````%ZP"`!$````FK`(`'P```#BL
M`@!Y````6*P"`#$```#2K`(`/`````2M`@!D````0:T"`%,```"FK0(`3P``
M`/JM`@`R````2JX"`"T```!]K@(`*0```*NN`@`:````U:X"`!````#PK@(`
MHP````&O`@`6````I:\"`!D```"\KP(`,@```-:O`@`5````";`"`!P````?
ML`(`(P```#RP`@`A````8+`"`"$```""L`(`(0```*2P`@`B````QK`"``X`
M``#IL`(`'P```/BP`@`4````&+$"`"8````ML0(`&@```%2Q`@`K````;[$"
M`!H```";L0(`$````+:Q`@`S````Q[$"`!T```#[L0(`.````!FR`@`A````
M4K("`$8```!TL@(`*0```+NR`@`<````Y;("`"X````"LP(`70```#&S`@`W
M````C[,"`#0```#'LP(`10```/RS`@`Y````0K0"`%L```!\M`(`1````-BT
M`@!;````';4"`$D```!YM0(`2P```,.U`@`N````#[8"`"0````^M@(`,@``
M`&.V`@!/````EK8"`",```#FM@(`/@````JW`@`Q````2;<"`#(```![MP(`
M,0```*ZW`@!3````X+<"`%`````TN`(`6````(6X`@!O````WK@"`"X```!.
MN0(`(P```'VY`@!=````H;D"`%$```#_N0(`(P```%&Z`@`K````=;H"`#L`
M``"AN@(`6P```-VZ`@`T````.;L"`"D```!NNP(`'0```)B[`@`F````MKL"
M`"````#=NP(`(0```/Z[`@`C````(+P"`&\```!$O`(`:0```+2\`@"_````
M'KT"`!<```#>O0(`(````/:]`@`\````%[X"`#P```!4O@(`.P```)&^`@`E
M````S;X"`$4```#SO@(`%@```#F_`@`&````4+\"`,4```!7OP(`/@```!W`
M`@`H````7,`"`$8```"%P`(`.````,S``@!/````!<$"`$D```!5P0(`.```
M`)_!`@`J````V,$"`#(````#P@(`-0```#;"`@`G````;,("`"````"4P@(`
M"@```+7"`@!!````P,("`",````"PP(`,````";#`@`O````5\,"`"(```"'
MPP(`'````*K#`@`Z````Q\,"`#(````"Q`(`%0```#7$`@`-````2\0"``@`
M``!9Q`(`!0```&+$`@`,````:,0"``P```!UQ`(`#````(+$`@`+````C\0"
M``8```";Q`(`$@```*+$`@`$````M<0"``4```"ZQ`(`8@```,#$`@!.````
M(\4"``4```!RQ0(`%````'C%`@`$````C<4"``<```"2Q0(`!0```)K%`@`%
M````H,4"``,```"FQ0(`$@```*K%`@`1````O<4"``D```#/Q0(`"@```-G%
M`@`+````Y,4"`!(```#PQ0(`$0````/&`@`"````%<8"``4````8Q@(`!P``
M`![&`@`3````)L8"``P````ZQ@(`%P```$?&`@`&````7\8"`!$```!FQ@(`
M#0```'C&`@`#````AL8"`#(```"*Q@(`!````+W&`@`&````PL8"``<```#)
MQ@(`'````-'&`@`M````[L8"`"X````<QP(`+P```$O'`@`3````>\<"`!X`
M``"/QP(`%P```*['`@`;````QL<"`!X```#BQP(`&0````'(`@`:````&\@"
M`!X````VR`(`%@```%7(`@`I````;,@"`!\```"6R`(`)P```+;(`@`7````
MWL@"`!L```#VR`(`'0```!+)`@`8````,,D"`"0```!)R0(`)@```&[)`@`G
M````E<D"`!<```"]R0(`&````-7)`@`<````[LD"`"(````+R@(`%P```"[*
M`@`>````1LH"`!H```!ER@(`/@```(#*`@`D````O\H"`"<```#DR@(`*@``
M``S+`@`K````-\L"`"4```!CRP(`$@```(G+`@`;````G,L"`"````"XRP(`
M'0```-G+`@`P````]\L"`!T````HS`(`#0```$;,`@`6````5,P"``4```!K
MS`(`"@```'',`@`6````?,P"`!8```"3S`(`$@```*K,`@`H````O<P"`!T`
M``#FS`(`#0````3-`@`;````$LT"``\````NS0(`&0```#[-`@`0````6,T"
M`!L```!IS0(`,0```(7-`@`(````M\T"``H```#`S0(`$````,O-`@`3````
MW,T"`!````#PS0(`(@````'.`@`F````),X"`"4```!+S@(`&0```''.`@`8
M````B\X"``<```"DS@(`P@```*S.`@`)````;\\"`!H```!YSP(`&````)3/
M`@`5````K<\"``@```##SP(`#````,S/`@`5````V<\"`!T```#OSP(`%```
M``W0`@`:````(M`"``4````]T`(`-0```$/0`@`4````>=`"`!0```".T`(`
M!P```*/0`@`*````J]`"`!@```"VT`(`*0```,_0`@`*````^=`"`$`````$
MT0(`"0```$71`@`E````3]$"`!(```!UT0(`%0```(C1`@`/````GM$"`#(`
M``"NT0(`#0```.'1`@`.````[]$"``\```#^T0(`&`````[2`@`*````)]("
M``\````RT@(`!0```$+2`@`?````2-("``H```!HT@(`'P```'/2`@`(````
MD]("`!4```"<T@(`!P```++2`@`(````NM("``H```##T@(`.P```,[2`@`%
M````"M,"``T````0TP(`"@```![3`@`0````*=,"``8````ZTP(`"@```$'3
M`@`'````3-,"`!(```!4TP(`"0```&?3`@`,````<=,"`!P```!^TP(`+```
M`)O3`@`?````R-,"`!\```#HTP(`%P````C4`@`:````(-0"`!T````[U`(`
M$P```%G4`@`@````;=0"`"0```".U`(`#P```+/4`@`?````P]0"`#8```#C
MU`(`$````!K5`@`5````*]4"`!X```!!U0(`,@```&#5`@`E````D]4"``X`
M``"YU0(`*P```,C5`@`3````]-4"``4````(U@(`!@````[6`@`<````%=8"
M``0````RU@(`*@```#?6`@`0````8M8"``4```!SU@(``P```'G6`@`,````
M?=8"`!<```"*U@(`"P```*+6`@`#````KM8"``H```"RU@(`"````+W6`@`+
M````QM8"``X```#2U@(`#P```.'6`@`1````\=8"`!(````#UP(`"@```!;7
M`@`P````(=<"`!L```!2UP(`&````&[7`@!1````A]<"`$0```#9UP(`.@``
M`![8`@`*````6=@"`$@```!DV`(`"P```*W8`@`(````N=@"`!8```#"V`(`
M0@```-G8`@`4````'-D"``\````QV0(`"0```$'9`@`$````2]D"``8```!0
MV0(`%@```%?9`@`:````;MD"``<```")V0(`"````)'9`@`(````FMD"``(`
M``"CV0(`"0```*;9`@`+````L-D"``4```"\V0(`&@```,+9`@`F````W=D"
M`!4````$V@(`'@```!K:`@`1````.=H"``(```!+V@(`!````$[:`@`/````
M4]H"``8```!CV@(`!0```&K:`@`$````<-H"`!0```!UV@(`,0```(K:`@`L
M````O-H"`!L```#IV@(`(@````7;`@!)````*-L"`!$```!RVP(`'@```(3;
M`@`E````H]L"`%P```#)VP(`+P```";<`@!8````5MP"`#@```"OW`(`-0``
M`.C<`@`5````'MT"`!0````TW0(`;0```$G=`@`1````M]T"`!H```#)W0(`
M&@```.3=`@!I````_]T"`!\```!IW@(`/````(G>`@`F````QMX"`#D```#M
MW@(`(@```"??`@`N````2M\"`%@```!YWP(`6P```-+?`@`I````+N`"`"$`
M``!8X`(`'````'K@`@`G````E^`"`"(```"_X`(`&@```.+@`@`U````_>`"
M`#$````SX0(`*@```&7A`@`Q````D.$"`#4```#"X0(`+0```/CA`@`?````
M)N("`"8```!&X@(`(````&WB`@`W````CN("`#<```#&X@(`)````/[B`@`D
M````(^,"`#8```!(XP(`&@```'_C`@`.````FN,"``P```"IXP(`<P```+;C
M`@`&````*N0"`!P````QY`(`$````$[D`@`0````7^0"`!X```!PY`(`#0``
M`(_D`@!U````G>0"`&H````3Y0(`2@```'[E`@`K````R>4"`!````#UY0(`
M'`````;F`@`U````(^8"`!8```!9Y@(`"P```'#F`@`E````?.8"`!H```"B
MY@(`-0```+WF`@`;````\^8"`!4````/YP(`5P```"7G`@`7````?><"``@`
M``"5YP(`"@```)[G`@`%````J><"``8```"OYP(`"````+;G`@`%````O^<"
M`!0```#%YP(`"@```-KG`@`0````Y><"`!8```#VYP(`(`````WH`@`+````
M+N@"``@````ZZ`(`"P```$/H`@`+````3^@"``0```!;Z`(`"0```&#H`@`*
M````:N@"``0```!UZ`(`"P```'KH`@`)````AN@"``@```"0Z`(`!P```)GH
M`@`'````H>@"`!<```"IZ`(`#0```,'H`@`&````S^@"``8```#6Z`(`#@``
M`-WH`@`7````[.@"``L````$Z0(`!P```!#I`@`'````&.D"``@````@Z0(`
M"@```"GI`@`2````-.D"``H```!'Z0(`!````%+I`@`-````5^D"``@```!E
MZ0(`%P```&[I`@`*````AND"``4```"1Z0(`!@```)?I`@`-````GND"`!(`
M``"LZ0(`#````+_I`@`-````S.D"``(```#:Z0(`!@```-WI`@`$````Y.D"
M``8```#IZ0(`!@```/#I`@`/````]^D"``<````'Z@(`!0````_J`@`&````
M%>H"`!0````<Z@(``@```#'J`@`$````-.H"``P````YZ@(`!P```$;J`@`)
M````3NH"`!0```!8Z@(`(@```&WJ`@`"````D.H"``<```"3Z@(`$@```)OJ
M`@`8````KNH"``L```#'Z@(`!````-/J`@`%````V.H"``P```#>Z@(`"@``
M`.OJ`@`/````]NH"`!8````&ZP(`#````!WK`@`.````*NL"``4````YZP(`
M#0```#_K`@`G````3>L"``X```!UZP(`#P```(3K`@`0````E.L"``4```"E
MZP(``@```*OK`@`+````KNL"``T```"ZZP(`#@```,CK`@`!````TPD```X#
M```X!P```````+@"``!$!0``H0,``/(&``!4`````````.,```!D`0``DPD`
M`*L'````````H`<``,L$``#X!@``1P,`````````````9P,`````````````
M+00``-D&````````?@(``&\!````````%P0```,*````````00(```X```!]
M!@``````````````````BP,````````<!P``:@4``$<'````````````````
M````````L0```+H%````````?P(````````^!P``,0,``",'``#;`P``F@<`
M```````=!0``K`<``!H"````````K`,``&\$``#T`@``:P0```````!-!@``
M`````.T(``````````````````"*"```"@8``.('```Q!```XP$```````!:
M`0``VP<``$4"``"%`P``/04``/<(``!;!```8`0`````````````3`,`````
M``!@!P``E@```-<(````````4`$``-H)``"F"```QP4```````"H`P``G`@`
M``````!)`P```````((``````````00``(<%``!=!```Z0$``*H```#U"0``
MW08``-`#```5!0``2P8``)8)``!G"```U`@``.$$```Y`0``U@8````````N
M"```]`4``)P%```````````````````3`P```````/`$````````P0@``$()
M``!*`@``\`$````````]!P``[`$``"X"``"9"0``"@,``$@)``")`@``````
M``````#["0``C0D````````P!@```````!@)````````XP4``'0&``#N"```
MH00``&8&````````CP<``&,%````````'`$```````!>!````````)$#``!S
M`0``I00```````#+"0``4P@```````"S!0``2P(```````"#`P```````.P&
M```9`P``6`<```````!7`@``I@$``.P"``#?!```50$``*<#``"%!@``Q0$`
M`.L%````````JP8``!L%```;"0``F08``&\"``#,!0```P,``&<&``"O`0``
M;`$````````W"```EP4``/\)``"@!@`````````````%"0```````'0!````
M````_`(`````````````XP@```````"7!@```````%X&``#'!```````````
M``"2!@```````%L&``"_`0``7@,``&T!``!H"```)@(``"H"``"\!P``E04`
M````````````BPD``+,#``"5`@``)PD``)X&``#Y`@``_@@`````````````
MM`@``&L'``!K"```)0`````````1!P```````/X&``#'"```I08``)8&``#X
M`P``HP4``+,&`````````````+P#````````5@@``)4$``!K`0``9@```#\#
M``#1!@``%0```'0"```,"0```````$,$````````:04``,L(``"9`0``````
M`$`#````````[0<``$X&``#$`P``^04```````"_!P```````%\'``!'````
M7@4``,H"```D`P```````(T'```G`P```````!D&```8`0``[00```````",
M!@``0P$```4"``#?"```V`8``'$&````````Y08```````!C!@``WP8``'(!
M``#Z!@```````,P```#]!@``[`4``#8%``#J!```7P4``.H#```]`P``````
M`"H'``!C!```#04``!D%``#T!@``6`8```````"C`0``JP$`````````````
MY0@``!@$``"[!```I`4``%$'``"(!`````````````!/!0``H@<``!P)```6
M"@```````.D(``!G!P````$``+H)````````SP0```````"$`P``1`0``!D(
M````````I04```````!="0``<00`````````````"@H```````!=!0``"`0`
M`!\!```"!````````$T(````````X04``,H(````````[`@`````````````
MC@D```````"#!0``%P<```````#[`P``VP(```````!V"```F@8``+8&``#Y
M``````,``$0)``"H!0```````+`$```2!P``V`(`````````````0@4``%P&
M`````````````%0$``!3!0```````+8(``#I"0``S0```#L$``#`"0``D`$`
M`%8%````````OP,``,@"``")`0``MP$```````!A`P``(P4``((!````````
MMP(``.H)``#9`@``(P```%()``!U"````````*("``#>!````````%\(````
M````/@8``)\!``";!0``&P0``.X!``">`0``E`D``-((``#J`@``GP@``"\(
M````````$@```*$(``"`!P``)0(``-D#````````T`@``+P%``"6!0```P@`
M`$X!````````L@D```````#H"0``/P0```````#\`0``/P(``)<!``#<!P``
MDP8```````#&````ZP(``&H)```["```;`@``,4&``!^!P```````'`"````
M````0@,``.D#``"7!P``5`$``-(``````````````%T!``"P`P``M08``%$#
M``"``P``N0,```````"U!`````````````"#"0``(`$``&4$````````2@``
M`/H"``#R`P``L@4``),$````````"0$`````````````L0(``(T#```U!P``
M#0@``"0"``#-!0```````.L'```""```#@D``$('``#="````````#\%``"3
M`P``X@```"D(``"'"````````!@'```@!@``#0``````````````\P(``&@)
M``#2`P``Y04``'\(```["0``50@``/H(``#\`P```````+<(``#W`@``H@@`
M`&@!````````BP$```````!U!```;`<``&,'```P`0``4`,``((%``"T`P``
M^`<``&4(```````````````````P!0``5@,``$$)``#B!0``Q@<``-H(``"=
M"```!@D``,P"````````UP(``+('```$`P``-P,``#\```!^!```6`$``'8#
M``!6`0```````*<%```E"0```````($%```H!0``G08```````"J"0``$P4`
M`(8(``#F`@``6@(``$D!```,"@``2P4``.(&````````HP8``#8'```U!```
MP`$``%$%``"\!````````.<#````````4@,``.8%```U!0``M@0``#P&``#]
M!P``)@8`````````````:@@``.@'```A!@``:`4``'0(```+`0``7`(``/4$
M``#V`@```````.@$`````````````"0%```1`0``L`@``*@`````````7`D`
M``````!+"```\@```(H'``#I!@```````*X)``!<`````````#P$``!6!P``
M`````)0'````````)0@``"(```#,"```@`8``&H'``")!`````````````"J
M"```QP<``%0(````````N@<``````````````````(8&``"L!```1P@``%X(
M``#D"```^@,``'P$``"M"```V@4``/@%```^`P``80<``/,(``"+`@``````
M`-P%```````````````````(`0``````````````````B`$``"D$````````
M`````"$)``"E"0``@@@``"4'``!F`P```````#((``!]`P``_0$``*H!```V
M"````````&0```#X"0````````````#[`@``%`@``-,&```]"```W0$`````
M````````_@,```````!9`P``-`,``'L(`````````````!$`````````V@,`
M`+0&``!B`P``\0<`````````````,`<```(````M"0``\P````````">"```
M*`$``#4!`````````````!L"``!]!0```````%@%````````.P,``+\(````
M````N`8````````K`0````````@%``"\"```G0D``/`(``#(!@``=P(``#$%
M````````:@8``(H&````````2@,``+T'````````&P<``&@"``#2!```0@(`
M`(H````-`P``#P4`````````````O`$``,,(```;"```;0``````````````
M`````(4'`````````````,8!`````````````"(!```D"0````````````"O
M!0``WP$``)('``!N`````````!$&```(!P```````#0!````````OPD``/L(
M````````.P<``!8(``#C!@``[@,``````````````````%4&``!J`0``K@4`
M````````````R@,``#<&````````=@8````````;"@```P$``$`&``#H`P``
M*P(``$\(```T"```QP(``$<%``!#!P``4P,```X$```4!P``M`0``)$"``!,
M!@``+08``$X$````````[@8``'\'```]`0```````-0"`````````````&L&
M``!H!P``#0D``.8```"^`0``U`0``,L`````````@@(``!@&``#,`0``T00`
M``````!H`P``G@D``+D"```4`P````````0%``!2!````````$@#``!W`P``
MU`<``%P'````````,@0``+0%``"F!P``<0(``*8&``"B`P``@@D``.8$````
M``````````4```",!P``-P(``/T%``!``@``]0<``````````````````"H`
M````````00@``!4'``"9"```.0(````````&````0P```&`!```V"0``A`4`
M`````````````````&\'```^!0``LP```!4$``!V!```T0$``)T%``"I!0``
M-`(``*T#``":"0``608``"$*``"W!0``$@4``(\!````````SPD``(H#``#@
M"0``(`4```4#``!(!P``)P<``*D&``#("```0@$``)X%````````"@D``,4%
M``#F"```PP(``%<#``"F"0``^@$`````````````1`(``+\$````````+@$`
M``````!G!````````(X(``!S!@``N08``$@"````````1@```,8&``!?````
MBP```$L)``"?!P```````!H&``#P!P``TP4````````N!```(`H``)H%````
M````M`<``````````````````/,#``!P!P``!P4``$D)````````R```````
M``#F`P````````````"A!P``&`4``!8$````````,0<``,4$````````````
M````````````4`@``"\&``#U!0``^@<```````!`"```.`,``(X"``#L!P``
M``````````#W"0``<@4``.\(``!/"0```````*<(``!N`P``3`0````````=
M!P``'````-\"````````_`@``$P````B"`````````````!L````T@4``,$%
M````````&P,``!$)````````[P(``!,'````````+@,``"D````0````#@$`
M`*D$``")````W0<```````"N````5`<```````!%"```:0@```````#?!P``
MZ04``.\'```/!```.P(``)P#``"]"```S00``*4```#)!@``V00``",(```,
M"```O0```*D!````````)`H```D#``"Q"0``908``-,(````````````````
M``#E`@``2@<``'@'``"K!```\00``-$'````````500```````#+!P``G0(`
M``\````B"@``]P8```````#@`P``D@0```D&``!M"```O@(``'L%``#7"0``
MUP8``&X(````````T0D``-8"```8`P```````%4'`````````````'0#```G
M!@``'`H```X(````````KP,```````"W!@``_P4```````!G````Z@8``,(&
M``"#`@``O````*<)`````````````/$"```/"0``(PD``#L&``#-!@``!@$`
M`!P"```<!@```````/0``````````````-$"`````````````(,$``"M!```
MD`@```````#L"0``G@<``)L(``"C"```%P(```````"T"0``V@$`````````
M````,0$```````!V````S@$``+X%```Z`@```````(\&```*"```D````)8(
M````````+0@``%$&`````````P````````!C`P``,`(``$$#``#@`0``FPD`
M`,0)```I`0``<0$```````!R`@``$0H``,D(````````E@0``($(```0"0``
M;@0```````"]`P``/@0``'D!``!U`P```````"````````````````````#^
M"0```@8``.4)```!`P``D`,`````````````D`(``.`'```X`0``5`D```D(
M``#8`P``B04``"D#````````'`0``(8"```/"```;0,``#(!```Y````,P@`
M`)P'```>"@```````/P%``#E!P``'`,```````#.!P``GP(``-P```#*!@``
M.`4``&@$``!^"````````/X"``"-"```P@$``.@```"E!P``@`4``-L$````
M````\@<``,\```#8````V`@``'@)``!D"```O0$``/`"``#>!0``N@$``'H&
M```J!0``W`D````````D!````````!0)`````````````)0&``!X`P``GP0`
M``\!``#0````=@D``,4'````````XP,``(<#````````U@```"\"``!&`P``
M9`D````````S!0```````$<"`````````````,4````&!````````(0'``#]
M"0````````````!+`P``H04``+L%``!C`0``70@``-0````'!P``5@D``&(`
M``!%!@``A00```````"&!```JP@```H```"L`````````(\"``#A`P``D0$`
M`($#`````````````'H!``"[!P```````+X(``"R`````````&P$```<!0``
M`````)X"``#<!```>@```$4$``#<`P``5P<``&L%````````J`$``%L"``"<
M!@```````.D$``"9!```C`,``*4"```F!P``E0D`````````````````````
M``!8!```9PD``-`!``"C````_@0```P"``!2````%@(`````````"0``+0,`
M`#T````>!0``M@,````````\`0``,P8```````#U````!P,```````!$!P``
MRP8``)(```#5````OP4``.`&``#3`P``U@<``%P(``!G!0``=PD```0"``!=
M!P``E@$``'`)``#Z!0````````P#``!O"0```````.\)``!V`0``4PD``!<)
M``"5`0```````$,)``!4`@```0H```````"8!0``0@0```````"?!@``````
M`'D$``#]"```#P8``%D!``!B`@```````!<```"Q!@```````!,!````````
M8`D``)\)````````"00``#8"```:`P``V0@``($)``"/`P```````"X```!&
M!0``=0<`````````````"@4``*(``````````````$D&``#+`0``_@<``/0'
M``"?!0``P`8``!8'```W!0```````'X%``#9!P``_`````H"```T"0``````
M`$X%```R!@``]@````````!R`P```````-L!```G!````````&T&``!.`P``
MKP8``#\&```F"0````````````#M!0``6@D```````"K"0``Y@<``-P(```Q
M`@``/PD``.\!``````````````8"``!A!`````````````#-`@``Q@,``*<'
M`````````````%(%````````<0@``(L&```$`0```````/X```#G`@``[P``
M``````"8"```40(````````'!```DP@``"P#``"S!```:`````````"W!```
M`````#8```#Y"```>PD``.0'```P````7P0```````#.!@```````)P!``!2
M"```]0,``.\#``#2`0```````!\'``"U`P``;P,```````"*!0``````````
M``#V!```\@D```````#<!@``\P4``,L"``"X"0``Q@@``-X```!1````<`,`
M`*T)``"U!P``,@,``%H&``#R!0`````````````9````L@(``(@&````````
MZ@@``/<!``#%"```>P$``)L&``"J`P``;`(``$\#```A````)P```$<!````
M````S@D``"H)``"_````2@D``&H$``!A`@```````-`"```F"````````-X(
M``#1!0``Z`8``%H$```$!P``K@<``,0'``#>!P```````$((````````````
M````````````)`$``'D&```B!@``PP8```````"@`P``A0D``+0```!!`0``
MX@D``%P!```R`@``C`D```````":`P``'P```',)`````````````'((``!F
M`@``Q@0``"D%````````90$``"P'``#-`0``!P```(X&``!;!P``10<``'\&
M``!8`@``(`,```X&``!C"0``;P@``&8$````````904```````#M`0``B0@`
M`.T&`````````````/,)``#"!P```````!\$```>`````````#\(``!.!P``
MX`4``-4'``!Z`P``G@0``"(%``!F"```"`,```````#!!```9`(``(\)``"#
M!P``.@$```````#B`@``$`<``)(!``!$````J0@`````````````````````
M````````.P$```````!L`P``6@````````#/`P```````*\```#O!0``4P8`
M`),!````````Y0,``&D)``!K`@```````)0!``````````````<&```Q"0``
M]`0``)\#```&"@``L@0``/0)``#0!@``5P@``%`%```]!```6@,``!4)```:
M`````````"`'``!\"```40D``%L)``!/!P````````````"U`@``D00``%<)
M``#_!P```````/\```"$"````````$$$````````R0(``.$)``"E`P``$@0`
M`*,#```^"0``30,``"H&````````30<``'8'```B!P``?`(``*X!```U`P``
MKP(`````````````A0@`````````````<P`````````\!P```08``'X)``!B
M"0``4P<``",*````````>`$``(`$``!X"```>`(``&X!````````^P4``&T"
M````````1`,``,D%``"[````?0$``)()`````````````/8'``#T`0``+04`
M`.H'````````P0<```D)``!T!```00<```T&```>`@``E0,``$P(``#>!@``
MUP<``!D*``!]!```.`(``),```````````````````"X````U08``.8&```:
M!0``K`$``+D`````````/`D```````!Q````504````````A"```(@,``%`)
M``!"````2P<``&D#```>!@``%P8``#D'``````````````````#`!0``````
M`"8!``",`0```````)<```!5`P``9`<``#\!```O!0``@`````````"J!```
M8P(``!,*```J!```104``!8&``!A"0``PPD````````O"0``D0D``!`"````
M````````````````````9P$``"<(``!*`0``LP$``.(!```=````.0@`````
M``!9!P``H`(`````````````1@(``&,(``!#"```*`<``)\````(````5@0`
M`.,)````````A0(```````!I````N0@``-@%``!)`@``F```````````````
M$P(``.<(````````C@<```````"0"0``G@```/4(``!;`P```````.L(``#E
M`0``<@````````!?"0``?@8```P!```"`0``L0<``/L&``"P`@``^`0```8%
M````````0````,\(``!`"0``+0$````$```=!@````````````"]!0``'PH`
M`(<&````````?@````````#D"0``FP,``-T)``!W"```=P0``%4"```]!@``
M+`(``.$&```P"0``30````````!9!0```````&D&``#"!```<P4`````````
M````600``.X%`````````````,P'``"7`P```````,0`````````$@@``)@"
M```R!0``D0<``(@(````````0P(``*`)``"L`@``@`(``%\"```,!0``````
M`,$!````````Y@D``+8)``"("0```````*$&```\````/@(``/$)````````
M:@```+$!``"5!@```````-X#``#B"```\P0```@"````````00```-4(``!R
M!@```````*H&````````+`0```````#$`0``VP```&L)``!D!0```````*D#
M`````````````'P!````````>`8````````4!0``BP<``'L"```Z`````@(`
M``````#I`@```````.X'``#H`0``!`0``*P(````````H`$``-0#``"4`@``
MYPD`````````````9`0``/$```"/"```S@@``(H$`````````````!,)```^
M````=`<``)T!``"O!```R0<```````#P"0```````#,```#=!```H0$``((#
M``!U`0``A0$``'4)```4!```O0(``(T&``#`"```Y`(``.````#]`@``@@<`
M`!T*``#G````M`(``#D%``"K`@``%PH``,\&```$````#````+D)``"\!@``
MP@``````````````+````+D%``!7!0``R@4````````;!@``\````'H)```+
M`P``;P`````````+"0``;`D``,8"``#D`0``JP,``(($``"^!P``R0```*<`
M``!)!P``,PD````%````````,P<```````!?`0``I`@``*0#``#0!P``````
M`&T$``!K`P``S`,``'P%```3!@``I@0``$T%``!L!0``>`0``!P(``#@"```
M``````````!U!@``E@,``$P)````````E`@``.D'``!)!```8`,```````"=
M`P``U`$``-8(``!Y````"P@``!$(``"*`0````````````"Z`@``>P0`````
M``!*!@``]P<``$T"````````9@4```````#<`@``VP@````````+"@``(P(`
M`,$"`````````````"P!``!S!P``U0D```\#```$!@``MPD```````#[!P``
MEPD```````!E`P``/0D``%8```!]"0``(0$``#P#```Q!@``_P(`````````
M````L@@``&4)``#^`0``*P4```````#*!P```````-4"``#O!````````"H(
M``"X!P````````````#_`0``^@D```4*```2`0``F`<`````````````D0@`
M`(P$``"N!````````+`&``#:!````````,H$``!E`@``(P$``)P"````````
M+@8``'L`````````W@(``*0```!Y"`````````````"X`P``NPD````````X
M"0``X0<```````#(`0````(``-`$``#P`P```````(H)````````P`(``,<)
M``!Y!0```````*<!``#N`@``Q@4``&$%``!W````%0,``(`(``!_!```*`8`
M`*,"`````````````&H"```K"0``$P@``,@#``!#!0``N@@````````E!```
M_@4```````#<`0``>P8``'L#``!X!0``(`@``-4!``````````@````````T
M!0``P@D``+,(```:"0``>@(``*<&```6!0````````D'``!X`````````&$`
M````````&`@``.`$``#H`@```````',"```Z!P``FP$``$P%```L!0``````
M``````"N"```M0@``(0!````````T0,``#<'``!>`@``S0,```````#%"0``
M!PH```````"M!P``V`D``"P&``#C!P``-P`````````;````2`4`````````
M````W0(``+L"````````=P<```````"9`````````"H#``"L!0``````````
M``#9````@0(``*T%````````]@,``/$#``"I!P``^@```%X!``#6!0``M0``
M`!`&```^"```^P```.X````L"```Z@$``#()``#Y!@``V`0``#8$``#)`0``
M%@```+\&``"M`0```````*X#```A`P````````````"2"````````'X!``"R
M`0``>0(```,&``#G!P``"`8``!0````A!```[`,```,)``#R!```#0<``*``
M``!/`0``L`D````````U!@``V`<``,T)``#5!0``.P4``$`'````````A@,`
M``D*``````````````````#+`P``0`$``+<'``"$!````````$@!``!7`0``
MY````'<!``!0!```%P@```````"&````A`D```````#J````FP<``&((````
M````G0``````````````$@(``.<&```P`P``ZP```!<!````````4`8`````
M``#.!0``"0``````````````!`H```````!0!P````````````"G!```````
M`+4!``"U"0```````'<%``"-!0``-````.4```!N`@`````````````S`0``
M\0@```(*``"V`````````"P)``"]"0``=0(``-<`````````4P$``-,$```/
M!P``0`0``$8$```+!0```````)@&``#+!0``60```(@#```.!P``@@8`````
M```Z"0``!0<``!4*````````3P```!4!``!<!````````$T)``!&"```(@0`
M`.0#``"H!@``=P8``,`'```D````/`@``,D#``##!```G````)L$``#4!@``
M!08``+P"```:"```"`H``,<```"4`P``P@(``!(#``#G`0``-0(````````U
M"```P0```-\```"A`@``(@D``"4#```+`````````,T'``"X`0```````!\#
M``!+````&`(``/D'``#2!@``10````````"C!P``!@8```````!$!@``J`<`
M`,0%``"Q!0``A`(``-("``#\!P``9P(```````!(!@``3@@``*H"````````
MA@D``!0"``"/!0````````````"0!0````<``)(#````````F0<```````"Y
M!P```````!X(``````````````````!6`@``$`H``.@(``#Y"0``_`0``)L"
M```8````?P$``.T````K`P``8````'()````````[@0``*4(```K````*P8`
M``````!N!@``1PD``+D$``"-`0``D`<``"T'````````S`0```,'````````
MO@0``'\#```M`@``ZP8``%X```!=!@```````/P&```\!0``AP(```````#X
M"```*0(``+T$```-`0``S@```"("``"B`0``?P```($&````````2`@``&D'
M````````"P0```H$````````JP```,\%``#R"```R@D``!D"```?`@``)`<`
M`",$```F!0````````````"B!@``@`$``%X'```?!@``V@````````!)"```
MX@0```````":````'@<``*X&``"D!```7P,```````#M`P``#00``%@)````
M````KPD```````"D"0```````,`$``!"!@``I`$``*,)``#"!0``O@``````
M``!0`@```````)T$```W!```@P8``*`$````````Z`4````````%!0``=`D`
M`-L)``#_!```V0$``'`!```F`P```````#H(``#&"0```````(\`````````
M`````$H%``````````````````!%`P```````'H%``!\"0``;0<```0)``!:
M!P``5P0``)0$```=!````````.\&```,!@``.@0``.$"````````!P(``%(!
M```Y`P``*0<``"T````>!```#PH`````````````U`D``,\'````````````
M`#`$``!]````A@<``&0&``",`@```````-,!```4!@``@0$``(8%``"2!0``
M]`@``&T)``#5`P``Y`8``(@%``")!@``$@D``!(&````````W04``*$````=
M"0``K0```),%```G`@``4P```!D!``"R!@```````!4(```)!0``"@<``,,'
M``#3````6`````````"X!```50D``)D"``#S!@``ZP0``%8&``"Z!@``E```
M`-X)``!8"```&@0``&`&```6`0``ZP$```````!V`@``JP4``,X$```H"```
M`````````````````````#`(```&!P``)P$``,4"```%"```O@8``)H"``#'
M!@```````!8#```%!```>@<``!0*```Y!````````$$&``!_"0``&00`````
M````````B`````@(```Q`````````#X!``!5````1`@```````!:"```R0D`
M`(L%``#>`0``LP(``-D)``#6`0``.P````L'``!B!@``PP4```````#L!```
M5P8```````#%`P``5`,``*P)``!N"0``]@D``'`%```N"0``5`8``"`)``"S
M!P````````````#2"0``0P8```````".`0``8@$``$H(``!@!0```````#0'
M``!J`P```````$X```!;````!@@```P$``#]````R00``*T"```V`P``````
M```````K!`````H``'4%````````'PD``!8)``#$"`````````````!;"```
M"P8``)H$``!B!0````````$'`````````````,$#`````````````%,"```"
M"0``'0$```````#```````````\"`````````````(X$````````G@,``$@`
M```H`P``WP,``-`%````````F0,``,\!```E`0```P0``!H*``!Q"0```04`
M`!\(````````L`4``+P)```2"@``$0,``!X)``!M!0``?`,``#@(``"I````
M?`8``.<%`````````````*4!``!1`0```````!T"```E!0``L0@`````````
M````.`0```````"=!P``TP<```4!``"&`0```````)@$```@!```*`(``*8#
M````````I`8```````#X`@```````%$$``"]!@``20```'`$``"L!@``````
M``````"D`@``[0D``*@$``","```%P,``*,$``"@!0``6P$``",&```V!@``
M0`4``%,$``"M!@```````#P"``#[`0``=````)4```!+`0``_`D```````#0
M"0``\`8``,T(``#3`@``80$``-D%``#!!@``$P```%X)``!%`0``Y`0`````
M``")!P``+P,``'4```!,!P```````'`&```>`0``J0(``&X%``#A````````
M`)<"`````````````!T#````````*P@``%``````````^@0````````1!```
M(0(``+8"````!@```````/8%``!/!```.@,``/@!````````AP$``)$&``!&
M"0``BP@``"X%``!Q!P``?@,```````"<"0``3P(``/\&``"H`@``^0$`````
M````````:00``'('````````Q`8```@)```)`@``-0```#0$``!P````ZP,`
M`````````````````-$```"["```NP8``)@!````````8@0``+H$```7!0``
MD04``&0#``#:`@``@0```'P```!-`0``>P<```8#```O!P```````&D!``!/
M!@```````(L$```;`0``?`<``+H```!&`0````````````"`"0``300```<!
M````````@P$```````"$!@``8P```'H(`````````````'$%``",!0``ZPD`
M`(T```"B!0````````````#C!```3`$```````!Y"0```````/$!``"0!@``
M+P$```````"Y`0``3@D``(@'``";````;P8``!@*````````IP(``.D````T
M!@``.`````````#[!```_0,``"L'``#E!```I@```%('````````_P@``/`%
M``")"0``8`@``-4$``#X````6`,``%L%``!E````;@<```````#W`P``OP(`
M``````"#`````````(<'```_!P``\@$```T*``"3!P````````````!+!```
M&@<``"\`````````UP0``*($``#!"0``9@$``*D)``````````````````!V
M!0```````),"````````_P,``````````````````"0(```R````````````
M``##`P``8`(``(<$``#W!```8@<``+0!``!!!0````````H!````````&0<`
M`+$#``".````UP4``"D&``"P!P``]`,``'H$```$"```I@(``)H(``!L!@``
MI@4`````````````.08``!$%``#4!0``R@````(%````````#@4``(H"``"O
M"`````````````"1``````````P'```1`@``QP,``)<$`````````````!X#
M``#U!@``M@4``-H&``#Y`P``J@4``/<````S`@```````'`(``#:!P``````
M`+````"B"0``L@,````````Z!@```@<`````````````.`8```````!9`@``
M`````-L&``!,`@``4@8``/("````````*0D``,((``!(!```\P$``)@#``!.
M`@`````````````!"0``PP$``*@(```3!```X0$```````"A"0``T0@`````
M``!Y`P``J@<``"8```#U`@``A0`````````````````````````?!0``LPD`
M`"0&``#,!@``X`(``/D$``!]!P```````,X#``"<!```%08```X"``!A!@``
ML00``$H$``"0!````````,X"```4`0``U@,```````#("0````````````!=
M`@``WP4``'0%``#=````X@,```````"5!P``]0$`````````````F04`````
M``#Q!0``SP(``"@$``"4!0``N`4``"X'```U"0````````````#J!0``&@$`
M`',(``"$````#@H````````!`0``+P0``#$(```A!0``Y`4``!D)``#*`0``
M``````,%```0!```@P@``-8)``"D!P``Y@$``.X)``#$`@``80@``-\)````
M````V`$```$(``"%!0``X0@``$,#```0`P``;P4```````"^"0``1@<`````
M````````P@,``',#````````\P<``,@%```J`0``!PD``)8"``"8"0``````
M`(T"``!=```````````````0"```U@0``&4'```="```APD``,`#````````
MM@$``(@"``"/!```AP```#,$``"6!P``:0(```````"!!P````````````#2
M!P``70,```<(````````N`@``)<(``":`0``<0,``"@```!_!0``,P,``.,"
M``"@"```:`8``#H%```-`@```````#T"````````"P(```````!9"0``````
M`'T(````````)@0`````````````MP```"$'``"-!```<P0``&L```#G!```
M`````+L#``#(!P``1`$``/<%````````B0,``/T$`````````````,,````E
M!@``7P8``.T"``"Z`P``(`(````````````````````````5`@``]@@`````
M```C`P``.0D`````````````<@0``%$(``#Q!@``7`,``&8)``"O!P``VP4`
M`$4)``#$!```K@(``%H%```!`@```````+4%```0`0``1@8```````#7`P``
M-@$``,<!``````````````,"``"W`P```````*@)````````@00``%0%````
M````?0(``!`%``#V!@``D@(```````"[`0```````(P```#,"0``1P8`````
M````````C@4``%D(````````-PD``,@$``!<!0``C@,`````````````]@$`
M`)4(``!Y!P``5P````````"P`0``9@<``#('```H"0``204``+X#````````
MM@<```````#=`P````````````!'!````@,`````````````)P4``#<!``!2
M`@```````.P```#7`0`````````@("`@("!4;SH@`"`@("!$871E.B``("`@
M($9R;VTZ(``@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E
M<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(%-U
M8FIE8W0Z(``@870@`"!I;B``(P`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I
M`"5D("5S(&%N9"`E<P`E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@
M;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+@`E9"!M
M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+@`E9"!M97-S86=E<R!H879E(&)E96X@<F5P
M;W)T960@87,@<W!A;2X`)60@=&\@)60@;V8@)60@365S<V%G97,`)60M9&%Y
M(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T
M=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D
M>2!E>&ES=',N`"5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W
M87,@;F]T(')E;F%M960N`"5S(&%T("5S("5S`"5S(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N`"5S(&9O;&1E<B!B96EN9R!R96YA
M;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S(&AA<R!A8V-E<'1E
M9"X`)7,@:&%S(&-A;F-E;&QE9"`E<RX`)7,@:&%S(&1E8VQI;F5D+@`E<R!H
M87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E<R!H87,@<F5P
M;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S('-E;G0@>6]U
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:&%S('1E;G1A=&EV96QY(&%C
M8V5P=&5D+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S
M(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('1O("5S(&]F("5S
M`"5S('=I<VAE<R!T;R!A;6UE;F0@)7,N`"5S('=I<VAE<R!T;R!M86ME('EO
M=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S
M="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S($)O;VL`)7,G
M<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`
M)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I`"A!<'!L>2!T:&5S92!C:&%N
M9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BD`*$1I<V-A<F0@86QL(&-H
M86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*0`H4F5T
M=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@
M8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R<F5N
M="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI`"A396YD(&UE<W-A9V4@
M869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H
M86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI
M960N*0`J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J`"H@4&QE87-E('-E
M;&5C="!A9&1R97-S*&5S*2`J`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$@;65S<V%G92!H87,@8F5E
M;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P
M86TN`#$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`#$@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!S<&%M+@`Q,#`@8VAA<F%C=&5R<P`Q,#`P(&-H87)A8W1E
M<G,`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`,C4P
M(&-H87)A8W1E<G,`-3`P(&-H87)A8W1E<G,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9`!!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D
M('1O('1H:7,@;65S<V%G92X`02!M97-S86=E('EO=2!H879E('-E;G0@:&%S
M(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H92!R
M96-I<&EE;G0N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3
M;F]W(%-H;W=E<G,`04TO4$T`04Y$`$%022!)1`!!8F]U="!T:&ES(&5D:71O
M<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P="!R97%U97-T
M`$%C8V5P=&5D`$%C8V5P=&5D.B``06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT)W,@
M;F%M93H`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@0VAI;&0@1W)O=7``
M061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``
M061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN
M`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@<V]U<F-E`$%D9"!T:&4@
M)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&AI<R!T;R!M>2!C
M86QE;F1A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@87,@86X@871T86-H;65N="X`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(&EN9F]R;6%T
M:6]N(&-A;B!B92!V:65W960@)7,N`$%D9&ET:6]N86P@:6YF;W)M871I;VX@
M9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<P!!9&1I=&EO;F%L
M(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L
M(&UE<W-A9V4@97)R;W(@9&5T86EL<P!!9&1I=&EO;F%L(&UE<W-A9V4@97)R
M;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+@!!9&1R97-S`$%D9')E<W,@
M0F]O:P!!9&1R97-S($)O;VMS`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO
M;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI
M<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!
M;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R
M;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL(&UE<W-A9V5S(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N
M92!-0D]8(&9I;&4Z`$%L;"!M97-S86=E<R!I;B!Y;W5R("(E<R(@9F]L9&5R
M(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY(&1E;&5T
M960N`$%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M
M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T
M960N`$%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M
M86EL8F]X/P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06QT97)N871I=F4@
M<&%R=',@9F]R('1H:7,@<V5C=&EO;CH`06QW87ES`$%L=V%Y<R!S879E(&%T
M=&%C:&UE;G1S`$%M97)I8V%N(%-A;6]A`$%N(&5R<F]R(&]C8W5R960@=VAI
M;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE($E-
M05`@<V5R=F5R('-A:60Z(`!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T
M:&4@;F5W('1A<VLN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U
M<R!0<F]X>0!!;G-W97(`06YS=V5R960`06YS=V5R960@;65S<V%G97,`06YT
M87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI
M8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY($9I;'1E
M<G,`07!P;'D@1FEL=&5R<R!T;R`E<P!!<'!L>2!F:6QT97(@<G5L97,@=7!O
M;B!L;V=G:6YG(&]N/P!!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"
M3U@@:7,@9&ES<&QA>65D/P!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V
M90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V
M*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I
M<R!.3U0@<F5C;VUM96YD960A*0!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&\@=&AI<S\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\`07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T
M=&%C:&UE;G0_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES
M(&9O;&1E<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@
M=')A<V@@9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N
M96YT;'D@9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\`07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@
M<W!A;3\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`
M07)R:79A;"!4:6UE`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES
M;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL`07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8V@`071T86-H($9I;&5S
M`$%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R
M(&UE<W-A9V4_`$%T=&%C:&5D($9I;&4Z`$%T=&%C:&5D(&9I;&4@(B5S(B!E
M>&-E961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A
M='1A8VAE9"X`071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E
M<75E<W0@>6]U('-E;G0N`$%T=&%C:&UE;G0`071T86-H;65N="!S=')I<'!E
M9#H@3W)I9VEN86P@871T86-H;65N="!T>7!E`$%T=&%C:&UE;G1S`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E;F1E97,`071T96YT:6]N
M`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@
M=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`075T;VUA=&EC86QL>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE
M<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2!A9&1R97-S8F]O:S\`
M079A:6QA8FQE($%D9')E<W,@8F]O:W,Z`$%V86EL86)L92!F:65L9',Z`$%W
M86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8U]K
M('1O("5S`$)A8VL@=&\@)7,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87)B861O<P!"87-E;&EN90!"8V,`0F5L87)U<P!"96QG:75M`$)E
M;&EZ90!"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE('-T871U<R!I;F9O
M<FUA=&EO;B!M97-S86=E+@!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A
M>0!";&%C:VQI<W0`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO
M="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";&]C:R!I;6%G
M97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A
M;&QY(')E<75E<W1E9#\`0F]D>0!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O
M<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$`0F]T:`!";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F
M($UE<W-A9V4`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL
M`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S
M86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O
M<&5R=&EE<RXN+@!#7VAA<G-E=`!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R
M=F5R+@!#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E
M<CH@`$-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R
M=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT(&UA:6QB;W@N`$-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R
M;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-C`$-E;&P@4&AO;F4`0V5L;"!0
M<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@
M<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E
M<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%D`$-H86ER(%!E<G-O;@!#:&%N9V4`0VAA;F=E($%L;`!#
M:&%N9V4@1F]L9&5R`$-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H
M;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@:&]W
M(&UE<W-A9V5S(&%R92!S;W)T960N`$-H86YG92!M86EL('-E<G9E<B!A;F0@
M9F]L9&5R('-E='1I;F=S+@!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG
M;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;"X`0VAA<@!#:&%R86-T97)S('1O(&1I<W!L87DZ
M`$-H96-?:R!,:6YK+BXN`$-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`
M0VAE8VL@7T%L;"].;VYE`$-H96-K(&%L;"!M86EL('-E<G9E<G,@>6]U('=A
M;G0@=&\@9F5T8V@@;6%I;"!F<F]M.@!#:&5C:R!S<&5L;&EN9R!B969O<F4@
M<V5N9&EN9R!A(&UE<W-A9V4_`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O
M<V4@06-T:6]N.@!#:&]O<V4@82!M86EL('-E<G9E<CH`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAO;W-E('1H92!A9&1R97-S(&)O
M;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E<W-E<RX`0VAO;W-E('1H92!O
M<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`
M0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A
M`$-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O
M<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N`$-L:6-K("5S('1O(&1O=VYL
M;V%D('1H92!I;6%G92X`0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N
M="!P86=E+@!#;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E
M<&%R871E('=I;F1O=RX`0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O
M9B!T:&ES(&EM86=E+@!#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT
M(&EN(&$@<V5P87)A=&4@=VEN9&]W+@!#;&EC:R`E<R!T;R!V:65W('1H:7,@
M;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RX`
M0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,`0VQI8VL@;VX@;VYE(&]F
M('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@
M86QL(&9I96QD<R!T;R!S96%R8V@N`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K
M('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VL`
M0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U
M<B!!9&1R97-S($)O;VL`0VQI8VMA=&5L;"!V:6$@2%144`!#;&EC:VEN9R!O
M;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T
M:&4@<V5N9&5R`$-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T
M:&4@;65S<V%G92!T;R!B92!R96%D`$-L;W-E`$-L;W-E(%=I;F1O=P!#;&]S
M92!T:&ES('=I;F1O=P!#;&]S960@1F]L9&5R`$-L;W5D<P!#;&]U9'D`0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4`0V]L;&%P<V4@06QL`$-O
M;&QA<'-E($%L;"!&;VQD97)S`$-O;&QA<'-E($9O;&1E<@!#;VQL87!S92!3
M:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R
M($EN9&EC871O<CH@`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O
M;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L
M;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;&5T
M960`0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4`0V]M<&]S92!M97-S86=E<R!I
M;B!A('-E<&%R871E('=I;F1O=S\`0V]M<&]S92!M97-S86=E<R!W:71H(&%N
M($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE
M(&9E871U<F4I/P!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:6=U<F4@:&]W(&UE<W-A
M9V5S(&%R92!D:7-P;&%Y960N`$-O;F9I9W5R92!M86EL('!R979I97<@;W!T
M:6]N<RX`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN
M96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D
M`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!#;VYT:6YU90!#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E
M<RX`0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N`$-O;G1R;VP@=VAE
M;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O
M<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV97,N`$-O;G9E<G0@
M=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\`0V]O:R!)
M<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'D@=&\@9F]L
M9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E>'0`0V]S=&$@4FEC80!#;W1E(&0G
M279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T
M(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&-R96%T
M92!T:&4@5D93(&)A8VME;F0Z("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D
M871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T
M(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@
M)7,N(%1H92!S97)V97(@<V%I9#H@)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!E>&5C
M=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N`$-O=6QD(&YO="!E>'1R86-T
M('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE
M;G0N`$-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M
M('1H92!::7`@87)C:&EV92X`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`
M0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T
M:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU
M86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N
M)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I
M9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#
M<F5A=&4`0W)E871E($9O;&1E<@!#<F5A=&4@2V5Y<P!#<F5A=&4@5FER='5A
M;"!&;VQD97(`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@9')A9G1S(&9O
M;&1E<@!#<F5A=&4@82!N97<@;VYE`$-R96%T92!A(&YE=R!S96YT(&UA:6P@
M9F]L9&5R`$-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(`0W)E871E(&9I;'1E
M<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O
M<G0@:70@:6YT;R!F;VQD97)S+"!A;F0@9&5L971E('-P86TN`$-R96%T92!S
M=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES
M`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&%C8V5S<R!T;R`E<P!#=7)R96YT
M(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE(&%C8V]U;G1S
M(&9O<B!F971C:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N`$-U<W1O
M;6EZ92!H;W<@>6]U('-E;F0@;6%I;"X`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`
M0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A
M:6QY`$1A=%]E`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D
M`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$
M96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C;&EN960Z(`!$96-R96%S92!)
M;F1E;G0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@
M<V]R=&EN9R!C<FET97)I83H`1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CH`
M1&5F:6YI=&EO;G,`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@)7,@4'5B;&EC
M($ME>0!$96QE=&4@0W5R<F5N="!+97ES`$1E;&5T92!&;VQD97(H<RD`1&5L
M971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!6:7)T=6%L($9O
M;&1E<@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E
M;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M90!$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_
M`$1E;&5T92!F<F]M(&UY(&-A;&5N9&%R`$1E;&5T92!O;&0@;&EN:V5D(&%T
M=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(&]L9"!S
M96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T
M92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D`$1E
M;&5T960@;65S<V%G97,`1&5L971E9"!T:&4@871T86-H;65N="`B)7,B+@!$
M96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S`$1E;&EV97)Y('1I;64`1&5N
M;6%R:P!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@
M:6YF;W)M871I;VX`1&5S8V5N9&EN9P!$97-C<FEB92!T:&4@4')O8FQE;0!$
M97-C<FEP=&EO;@!$971A:6QS`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&EM('-I9VYA='5R97,_`$1I
M<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T
M`$1I<F5C=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES
M<&QA>2!/<'1I;VYS`$1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I
M;F<@82!M97-S86=E/P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@
M9F]R;6%T`$1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E`$1I<W!L87D@<&]P
M+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\`1&ES<&]S:71I;VX`1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O($Y/5"!M871C:`!$
M;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;`!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;@!$;R!Y
M;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/P!$;V5S('1H92!F:7)S="!R
M;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI
M<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VYE`$1O=VYL
M;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T`$1O
M=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*0!$;W=N;&]A
M9"!&;VQD97(H<RD`1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%T`
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="X`1&]W;FQO860@:6X@+GII<"!&;W)M870`1')A9G0`1')A9G0@9F]L9&5R
M`$1R869T<R!F;VQD97(Z`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%
M+6UA:6P@061D<F5S<P!%4E(`15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N
M;W0@8F4@9&5L:79E<F5D+@!%8W5A9&]R`$5D:70`161I="!";&%C:VQI<W0`
M161I="!";&]C:P!%9&ET($9I;'1E<G,`161I="!'<F]U<`!%9&ET(%!E<FUI
M<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET(%9I<G1U86P@1F]L9&5R`$5D:70@5FER='5A;"!&;VQD97(@1&5F
M:6YI=&EO;B!F;W(@)7,`161I="!7:&ET96QI<W0`161I="!O<'1I;VYS(&9O
M<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!Y;W5R(&)L86-K;&ES
M=`!%9&ET('EO=7(@9FEL=&5R(')U;&5S`$5D:70@>6]U<B!P<F5F97)E;F-E
M<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N`$5D:70@>6]U
M<B!W:&ET96QI<W0`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE
M;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS
M`$5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N`$5M<'1Y($9O;&1E<BAS
M*0!%;7!T>2!4<F%S:"!F;VQD97(`16UP='D@7U1R87-H`$5M<'1Y(&UE<W-A
M9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!0
M1U`@9G5N8W1I;VYA;&ET>3\`16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y
M/P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/P!%;F%B;&4@;65S<V%G92!P<F5V:65W<S\`16YA8FQE
M(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YC<E]Y<'1I;VX@3W!T:6]N
M<P!%;F0`16YD(&9O<G=A<F1E9"!M97-S86=E`$5N9"!M97-S86=E`$5N9"!M
M97-S86=E(&9R;VT@)7,`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@
M4&%S<W!H<F%S90!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO
M=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`
M16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!N86UE(&9O<B!Y
M;W5R(&YE=R!D<F%F=',@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!S96YT(&UA:6P@9F]L9&5R`$5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!T<F%S:"!F;VQD97(`16YT<GD@(B5S(B!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('1H92!A9&1R97-S(&)O;VL`17%U871O<FEA;"!'=6EN96$`
M17)I=')E80!%<G)O<@!%<G)O<B!S96YD:6YG(')E<&QY.B`E<RX`17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%
M=7)O<&4`179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N`$5V97)Y(#$U(&UI
M;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@
M-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M
M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!!
M;&P`17AP86YD($%L;"!&;VQD97)S`$5X<&%N9"!&;VQD97(`17AP86YD($YA
M;65S`$5X<&%N9"!3:61E8F%R`$5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S
M92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\`17AP
M86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@
M9F]L9&5R<R!V:65W/P!%>'!A;F1I;F<`17AP96-T960@)RDG`$5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$
M871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I
M;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R
M=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y
M('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I<@!&86QK;&%N9"!)<VQA
M;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X
M`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=&-H($UA:6P`
M1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\`1F5T8V@@;65S<V%G
M97,@=7!O;B!L;V=G:6YG(&]N/P!&971C:&UA:6PZ(`!&971C:&UA:6PZ(&YO
M(&YE=R!M97-S86=E<RX`1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&
M:5]L=&5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@
M3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@
M;F]T('-U<'!O<G1E9"X`1FEL=&5R($]P=&EO;G,`1FEL=&5R(%-E='1I;F=S
M`$9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\`1FEL=&5R
M('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN`$9I;'1E<G,`
M1FEL=&5R<R!.3U0@06-T:79E`$9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G
M90!&:6YD`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!-86EL8F]X(%!A9V4`
M1FER<W0@4&%G90!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T
M`$9O7W)W87)D`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]L9&5R
M($YA=FEG871O<@!&;VQD97(@4W5M;6%R>0!&;VQD97(@<VAA<FEN9R!I<R!N
M;W0@96YA8FQE9"X`1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"X`1F]N="!#
M;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED
M92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUA="!O9B!M97-S
M86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A
M=&5D('1O9&%Y`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S
M`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F0`1F]R=V%R9#H`1F]R=V%R9&5D
M(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<P!&;W)W87)D<P!&
M<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R964O0G5S
M>2!);F9O<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E
M<W0`1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]?;0!&<F]M`$9R;VT@061D<F5S<P!&<F]M('1H92``1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9W9#H`1G=D.B``1G=D.B`E=2!&
M;W)W87)D960@365S<V%G97,`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@3W!T:6]N<P!'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R
M;6%N>0!'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI`$=H86YA
M`$=I8G)A;'1A<@!':79E;B!.86UE`$=O('1O($UE<W-A9V4`1V]E9&5L`$=O
M;V=L92!396%R8V@`1W)A;G0@86-C97-S`$=R87ES8V%L90!'<F5E8V4`1W)E
M96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P
M<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E
M<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA
M;F$`2$5210!(5$U,`$A434P@5F5R<VEO;B!O9B!-97-S86=E`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA
M>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP
M('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AE<F4@:7,@=&AE(&UE<W-A9V4@>6]U
M('=E<F4@8V]M<&]S:6YG.@!(:61D96X`2&ED9&5N(&EN(%1H<F5A9"!6:65W
M`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R:6)E9`!(:6=H`$AI9V@@4')I
M;W)I='D`2&EG:&5S=`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO
M;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M
M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@
M3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R
M96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E
M<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N
M=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!D;R!Y;W4@
M=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/P!(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@
M82!R97!L>0!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y
M`$E-05``24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*0!)34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&]V97(@4U-,`$E-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D
M(&-E<G1I9FEC871E*0!)34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"D`24U!
M4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL(%-E<G9E<G,`24Y"3U@`25`@061D
M<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T
M('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA
M=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)
M8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF
M('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E
M('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+@!)9VYO<F4`26=N;W)E($%L;`!);6%G92!0<F5V:65W.@!)
M;6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@
M9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R=`!);7!O
M<G0@2V5Y`$EM<&]R="!+97EP86ER`$EM<&]R="!-97-S86=E<P!);7!O<G0@
M4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y`$EM<&]R
M="!097)S;VYA;"!0=6)L:6,@4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4R]-
M24U%($-E<G1I9FEC871E<P!);7!O<G0@4'5B;&EC($ME>0!);7!O<G0@4'5B
M;&EC(%!'4"!+97D`26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y`$EM<&]R="!3
M+TU)344@2V5Y`$EM<&]R="!M8F]X($9I;&4`26UP;W)T(&UB;W@@9FEL92`E
M<R!I;G1O(&9O;&1E<B`E<RX`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N=`!)
M;7!O<G1A;G0@;65S<V%G97,`26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E
M<RX`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26X@4')O
M8V5S<P!);E]S97)T(%)O=R!!9G1E<@!);F)O>`!);F-L=61E(&$@8G)I968@
M<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_`$EN8VQU9&4@;W)I
M9VEN86P@;65S<V%G92!I;B!A(')E<&QY/P!);F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV
M:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M
M871I;VX@;VX@)7,@4'5B;&EC($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA
M;"!0<FEV871E($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@
M2V5Y`$EN;&EN90!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@0V5R=&EF
M:6-A=&4@2&5R90!);G-E<G0@26UA9V4`26YS97)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>2!(97)E`$EN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME
M>2!(97)E`$EN<V5R="!0=6)L:6,@4$=0($ME>2!(97)E`$EN<V5R="!486)L
M90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`
M26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E
M:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R
M="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU
M;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F
M=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`
M26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E
M`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E
M9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED($%C=&EO;B!S96QE
M8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN=F%L:60@061D<F5S<P!);G9A
M;&ED(%)E;6]T92!-86EL8F]X`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N
M`$EN=F%L:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RX`26YV
M86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@:V5Y`$EN=F%L:60@
M;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2X`26YV86QI
M9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`26YV86QI9"!P<F]T;V-O;"X`
M26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`
M26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`
M27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`
M2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E
M<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2T(`
M2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V
M97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME
M>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP
M90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+@!+97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A
M;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E
M`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,
M87-T($UA:6QB;W@@4&%G90!,87-T(%!A9V4`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,
M969T('9A;'5E<P!,97-O=&AO`$QI7VYK($%T=&%C:&UE;G1S`$QI8F5R:6$`
M3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R
M:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@
M3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E
M<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`
M3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE
M(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:V5D(&%T=&%C:&UE
M;G1S(&%R92!F;W)B:61D96XN`$QI;FMS`$QI;FMS('=I;&P@97AP:7)E(&]N
M("5S`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD
M97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE
M<P!,:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S
M('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"!O;FQY('-E92!C;VYT
M86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI`$QI<W0M07)C
M:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,
M:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@:6X@=&AE
M($AE861E<@!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E
M`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L($UA:6QB;W@Z`$QO8V%L('1I
M;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!I;B!T
M;R`E<P!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B
M96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@
M:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W
M`$QO=R!0<FEO<FET>0!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN
M(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,;W=E<W0`3'5X96UB;W5R
M9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9@!-86-I;G1O<V@@1FEL90!-861A9V%S8V%R`$UA9VEC`$UA
M:6P`36%I;"!!9&UI;@!-86EL(%!R979I97=S`$UA:6P@<V5R=F5R('1Y<&4@
M=&\@8V]N;F5C="!T;SH`36%I;&)O>`!-86EL8F]X(&%N9"!&;VQD97(@1&ES
M<&QA>2!/<'1I;VYS`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!!;&P@365S<V%G97,@:6X@
M1F]L9&5R(&%S(%-E96X`36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S
M(%5N<V5E;@!-87)K(&%S.@!-87)K(&1I9F9E<F5N="!L979E;',@;V8@<75O
M=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_`$UA<FL@;65S<V%G97,@87,@
M<V5E;C\@*$E-05`@;VYL>2D`36%R:R!S:6UP;&4@;6%R:W5P/P!-87)K('=I
M=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T
M:6YI<75E`$UA=&-H($%L;"!1=65R:65S`$UA=&-H($%N>2!1=65R>0!-871C
M:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@
M8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM
M=6T@071T86-H;65N="!3:7IE`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M
M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N`$UA>&EM=6T@=&]T86P@871T
M86-H;65N="!S:7IE(')E86-H960N`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE
M971I;F<@0V%N8V5L;&%T:6]N`$UE971I;F<@26YF;W)M871I;VX`365E=&EN
M9R!0<F]P;W-A;`!-965T:6YG(%)E<&QY`$UE971I;F<@57!D871E`$UE971I
M;F<@57!D871E(%)E<75E<W0`365M8F5R<P!-96YU($9O;&1E<B!,:7-T`$UE
M;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E($-O;7!O<VET
M:6]N`$UE<W-A9V4@1&%T90!-97-S86=E($]P=&EO;G,`365S<V%G92!396%R
M8V@`365S<V%G92!3:7IE`$UE<W-A9V4@4V]U<F-E`$UE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(%9I97=I;F<`365S<V%G
M92!E>'!I<F5D+@!-97-S86=E(&9L86=S`$UE<W-A9V4@9F]L9&5R<P!-97-S
M86=E(&9R;VT@)7,`365S<V%G92!M871C:&5S`$UE<W-A9V4@<F5D:7)E8W1E
M9"!S=6-C97-S9G5L;'DN`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U
M="!N;W0@<V%V960@=&\@)7,`365S<V%G92!S96YT('-U8V-E<W-F=6QL>2X`
M365S<V%G92!T>7!E`$UE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X
M('9I97<N`$UE<W-A9V5S('1O`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M365T:&]D`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N
M96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I
M;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W
M(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG
M(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A
M=&4`36]D:69I960@1&%T90!-;V1I9GD`36]D:69Y(%523`!-;V1U;'5S`$UO
M;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@
M>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-
M;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V90!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!T;R!F;VQD97(`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE
M=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!A<G0O86QT97)N871I=F4`375L
M=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A
M;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3D]410!.86UE
M`$YA;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='D`3F%M:6)I80!.
M875R=0!.965D<R!!8W1I;VX`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N
M9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!2
M96YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!3
M4TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.
M971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5V97(@
M<V%V92!A='1A8VAM96YT<P!.97<`3F5W($-A;&5D;VYI80!.97<@0V%T96=O
M<GD`3F5W($9O;&1E<@!.97<@36%I;`!.97<@36]O;@!.97<@57-E<FYA;64@
M*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@;65S<V%G97,`3F5W('=I;F1O
M=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT($UE<W-A9V4`
M3F5X="!086=E`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I
M80!.:6=H=`!.:75E`$YO`$YO($-E<G1I9FEC871E(&9O=6YD`$YO($5N8W)Y
M<'1I;VX`3F\@2V5Y<R!I;B!+97ER:6YG`$YO($UE<W-A9V5S`$YO(%!'4"!P
M=6)L:6,@:V5Y(&EM<&]R=&5D+@!.;R!097)S;VYA;"!#97)T:69I8V%T92!0
M<F5S96YT`$YO(%!U8FQI8R!+97ES($9O=6YD`$YO(%,O34E-12!P=6)L:6,@
M:V5Y(&EM<&]R=&5D+@!.;R!A='1A8VAM96YT<R!F;W5N9"X`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R
M96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!F;VQD97(@<V5L
M96-T960N`$YO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M
M86EL+@!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&9O;&1E<G,@=VET
M:"!N97<@;65S<V%G97,`3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E
M<P!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!M97-S
M86=E(&)O9'D@=&5X=`!.;R!M97-S86=E('-U<'!L:65D+@!.;R!M97-S86=E
M<R!M871C:&5D('EO=7(@<V5A<F-H+@!.;R!N86UE('-P96-I9FEE9"X`3F\@
M;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC
M871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D
M+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET
M:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<&5R<V]N
M86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!01U`@
M<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@<&5R<V]N86P@4R]-24U%(&-E<G1I
M9FEC871E<R!I;7!O<G1E9"X`3F\@<G5L97,`3F\@<VED97,`3F\@<W!E;&QC
M:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N`$YO('-P96QL:6YG(&5R<F]R
M<P!.;R!S=6=G97-T:6]N<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N`$YO('5S97(@<W!E8VEF:65D+@!.;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V
M97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`3F]N90!.;VYE("AU
M<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L
M86YD`$YO<FUA;`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA
M;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T($1E
M;&5T960`3F]T($1R869T`$YO="!);7!O<G1A;G0`3F]T(%!E<G-O;F%L`$YO
M="!A(&1I<F5C=&]R>0!.;W0@82!V86QI9"!P=6)L:6,@:V5Y+@!.;W0@9&5L
M971E9"!M97-S86=E<P!.;W0@:6UP;&5M96YT960N`$YO="!I;7!O<G1A;G0@
M;65S<V%G97,`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E('1H870@=&AI
M<R!C86X@=&%K92!S;VUE('1I;64`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R
M<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@;6]N=&AS('1O(&ME97`@
M;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE=&EN9R!M;VYT:&QY+@!.
M=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L
M971I;F<@;6]N=&AL>2X`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`
M3U(`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS
M92!F:6QT97(`3V9F:6-E`$]L9"!M97-S86=E<P!/;&0@<V5N="UM86EL(&9O
M;&1E<G,@8F5I;F<@<'5R9V5D+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@9&ES<&QA>2!F;VQD97)S('=I
M=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_`$]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!O
M;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I;VXN
M`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C
M:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P
M96YE9"!&;VQD97(`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/
M<&5R871I;F<@4WES=&5M`$]P=&EO;F%L(%!A<G1I8VEP86YT`$]P=&EO;G,`
M3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A
M;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I
M;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/
M=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!-86EL($%C8V]U;G1S`$]T:&5R($]P
M=&EO;G,`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%!'4`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0
M($5N8W)Y<'0@365S<V%G90!01U`@16YC<GEP=&5D($1A=&$`4$=0($5R<F]R
M.B``4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R
M:79A=&4@:V5Y+@!01U`@3W!T:6]N<P!01U`@4&%S<W!H<F%S92!);G!U=`!0
M1U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+@!01U`@4'5B;&EC($ME>0!01U`@4'5B;&EC($ME
M>2!497AT`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,@*"5S*2(@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"X`4$=0(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U
M8V-E<W-F=6QL>2!D96QE=&5D+@!01U`@4'5B;&EC($ME>7)I;F<`4$=0(%-I
M9VX@365S<V%G90!01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY
M(&%D9&5D+@!01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N`%!'
M4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!01U`@<W5P
M<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S
M:6=N871U<F4@:7,@=6YA8FQE('1O(&)E('9E<FEF:65D+@!01U`@<W5P<&]R
M="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U
M;F%B;&4@=&\@8F4@9&5C<GEP=&5D+@!02%`@0V]D90!02%`@4VAE;&P`4$T@
M3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S
M`%!-(%0M4W1O<FUS`%!/4#,`4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS
M*0!03U`S(&]V97(@4U-,`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E
M<G1I9FEC871E*0!03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"D`4$]0,RP@
M;F\@5$Q3`%!?2%`@4VAE;&P`4&%D9&EN9P!086=E("5D(&]F("5D`%!A9V4@
M=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4`4&%G92!W:71H('1H92!,
M87-T(%5N<V5E;B!-97-S86=E`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`
M4&%R86=U87D`4&%R="AS*0!087)T;'D@0VQO=61Y`%!A<W-P:')A<V4`4&%S
M<W!H<F%S92`H06=A:6XI`%!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A
M9&5D+@!087-S<&AR87-E.@!087-S<&AR87-E<R!C86X@;F]T(&)E(&5M<'1Y
M`%!A<W-P:')A<V5S(&1O(&YO="!M871C:`!087-S=V]R9`!087-S=V]R9"!I
M;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E
M(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O<B!T
M:&ES('5S97(@8V%N(&YO="!B92!C:&%N9V5D+@!097)S;VYA;`!097)S;VYA
M;"!);F9O<FUA=&EO;@!097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@
M<W5C8V5S<V9U;&QY+@!097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E
M<W-F=6QL>2X`4&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP
M;W)T960Z(`!097)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F
M=6QL>2X`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C
M86ER;@!0:7AE;',`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI
M97,@86YD(&9O<G=A<F1S/P!0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E
M`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N
M=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI
M<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0
M;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N
M=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@
M9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`
M4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E(&5N=&5R('1H92!N
M86UE(&]F('1H92!N97<@9F]L9&5R.@!0;&5A<V4@96YT97(@=&AE(&YE=R!N
M86UE.@!0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0
M('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI
M<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN`%!L96%S92!E;G1E
M<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN
M(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@
M;VYC92!P97(@)7,@<V5S<VEO;BX`4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R
M97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@
M=7-I;F<@8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@
M:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R!L;V<@:6X@86=A
M:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME
M97`@871T86-K97)S(&9R;VT@:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@
M5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92X`4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED
M92!Y;W5R('!A<W-W;W)D+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE+@!0
M;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N
M`%!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD
M('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0
M;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@
M86-T:6]N<RX`4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N
M=2!B96QO=RX`4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O
M('-E87)C:"X`4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H
M:7,@;W!E<F%T:6]N+@!0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O
M>"!T;R!T:&4@<FEG:'0Z`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0
M;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4&]W
M97)E9"!B>2!(;W)D90!0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S
M:&5S("@G+2T@)RD_`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS
M*3H@`%!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+@!0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z
M(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0
M<F5V:6]U<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N
M<P!0<FEN=`!0<FEN="!D;V-U;65N=`!0<FEO<FET>0!0<FEV871E($ME>0!0
M<FEV871E($ME>2!087-S=V]R9`!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4')O:F5C=',`4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I
M<R!S96YT.R!D969A=6QT('1O($Y/`%!R;VUP="!E=F5R>2!T:6UE(&%N(&%T
M=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,`4')O;7!T('1E>'0`
M4')O=&]C;VPZ`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B
M;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"X`
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2X`4'5E<G1O(%)I8V\`4'5R7V=E($1E;&5T960`4'5R9V4@1&5L971E
M9`!0=7)G92!&;VQD97(H<RD`4'5R9V4@5')A<V@@:&]W(&]F=&5N.@!0=7)G
M92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M
M;W5N="!O9B!D87ES+@!0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H
M(&9O;&1E<C\`46%T87(`475E<GD`475O=&$@<W1A='5S.B`E+C)F34(@+R`E
M+C)F34(@("@E+C)F)24I`%%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-
M250`475O=&$@<W1A='5S.B!.3R!,24U)5`!1=6]T:6YG("5F.@!24T$@4'5B
M;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A
M<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@
M=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!295]Q=65S="!$96QI=F5R
M>2!#;VYF:7)M871I;VX`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE
M=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL
M>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296-E:79E9"!/;@!296-E:79E9"!3:6YC
M90!296-E:79E9"!5;G1I;`!2961I<F5C7W0`4F5D:7)E8W0`4F5D:7)E8W0@
M365S<V%G90!2961I<F5C="!T:&ES(&UE<W-A9V4`4F5D:7)E8W1I;F<@9F%I
M;&5D+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H($9O;&1E<B!6:65W<SH`
M4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S
M97(`4F5L;V%D`%)E;&]A9"!6:65W`%)E;6%R:W,`4F5M96UB97(@=&AE(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M96UB97(@=&AE(&QA<W0@=FEE=P!2
M96UO=&4@36%I;&)O>#H`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO
M8VL`4F5M;W9E($9I96QD($9R;VT@4V5A<F-H`%)E;6]V92!C;VQU;6X`4F5M
M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!S
M;W5R8V4`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!296YA;64@1F]L
M9&5R*',I`%)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O
M9B!M;VYT:#\`4F5N86UI;F<@(B5S(B!T;R`B)7,B(&9A:6QE9"X@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9`!297!L7WD@=&\@3&ES=`!297!L86-E
M('=I=&@Z`%)E<&QY`%)E<&QY(%-E;G0N`%)E<&QY('1O($%L;`!297!L>2!T
M;R!!;&PZ`%)E<&QY('1O($QI<W0`4F5P;'D@=&\@3&ES=#H`4F5P;'D@=&\@
M7T%L;`!297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G90!297!L>2!W
M:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P;'D@=VET:"!R
M97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L>2U4;P!297!L
M>2U4;SH@`%)E<&QY.@!297!O<G0@87,@26YN;V-E;G0`4F5P;W)T(&%S(%-P
M86T`4F5Q=65S="!A(%]296%D(%)E8V5I<'0`4F5Q=65S="!C;W5L9&XG="!B
M92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S="!D96QI
M=F5R>2!C;VYF:7)M871I;VX_`%)E<75E<W0@<F5A9"!R96-E:7!T<S\`4F5Q
M=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+@!297%U:7)E9"!&:65L9`!297%U
M:7)E9"!087)T:6-I<&%N=`!297-E=`!297-E="!087-S=V]R9`!297-E="!9
M;W5R(%!A<W-W;W)D`%)E<W!O;F1E;G0@4W1A='5S(%5P9&%T960N`%)E<W5L
M=',`4F5S=6UE`%)E<W5M92!Y;W5R('-E<W-I;VX`4F5T=7)N('1O($9E=&-H
M($UA:6P`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O('1H92!M86EL8F]X
M(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A
M(&UE<W-A9V4_`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R
M`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA
M`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P
M97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2
M=V%N9&$`4R]-24U%`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3
M+TU)344@16YC<GEP="!-97-S86=E`%,O34E-12!%;F-R>7!T960@365S<V%G
M90!3+TU)344@17)R;W(Z(`!3+TU)344@17)R;W(Z($YE960@<&%S<W!H<F%S
M92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN`%,O34E-12!/<'1I;VYS`%,O
M34E-12!087-S<&AR87-E($EN<'5T`%,O34E-12!097)S;VYA;"!+97EP86ER
M('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%,O
M34E-12!0=6)L:6,@2V5Y(&9O<B`B)7,B('=A<R!S=6-C97-S9G5L;'D@9&5L
M971E9"X`4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!3
M+TU)344@4'5B;&EC($ME>7)I;F<`4R]-24U%(%!U8FQI8R]0<FEV871E($ME
M>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D+@!3+TU)344@4VEG;B!-97-S86=E
M`%,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G90!3+TU)344@<W5P<&]R="!I
M<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`4R]-24U%('-U<'!O<G0@:7,@
M;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L
M92!T;R!B92!D96-R>7!T960N`%,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B
M;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I9VYE9"!M97-S86=E(&-A
M;B!N;W0@8F4@9&ES<&QA>65D+@!3+TU)344@<W5P<&]R="!I<R!N;W0@96YA
M8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E
M('9E<FEF:65D+@!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@
M4VAE;&P`4U]U8FIE8W0`4V$`4V%?=F4@82!C;W!Y(&EN(`!385]V92!A<P!3
M86EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA
M`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-
M87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E
M<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@071T86-H;65N=',@
M=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_`%-A=F4@1')A9G0`
M4V%V92!/<'1I;VYS`%-A=F4@7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@
M87,@=6YS965N/P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A
M=6QT(&%D9')E<W,@8F]O:S\`4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O
M;&1E<C\`4V%V92!S96YT(&UA:6P_`%-A=F5D("5S(&-O;F9I9W5R871I;VXN
M`%-A=FEN9R!T:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`E<P!38VEE;F-E`%-E87)C:`!396%R8V@@)7,`4V5A<F-H
M($5N9VEN97,`4V5A<F-H(%)E<W5L=',`4V5E;@!396QE8W0`4V5L96-T($%N
M;W1H97(@06-C;W5N=`!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE
M8W0@82!F:65L9`!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W
M(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!3
M96QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A
M<F-H:6YG(&9O<B!A9&1R97-S97,N`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N`%-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W
M:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N`%-E;&5C="!A;B!A8V-O=6YT`%-E
M;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M
M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!3
M96QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4`4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396QE8W1E9"!!9&1R97-S
M(&)O;VMS.@!396YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R`%-E;F0@3&%T
M97-T($EN9F]R;6%T:6]N`%-E;F0@365S<V%G90!396YD(%!R;V)L96T@4F5P
M;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5N="!M86EL(&9O;&1E
M<@!396YT(&UA:6P@9F]L9&5R.@!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT
M96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R`%-E<G9E<B!A;F0@1F]L9&5R
M($EN9F]R;6%T:6]N`%-E<G9E<CH`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@<')E9F5R96YC97,@9F]R
M('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G
M97,N`%-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@
M;65S<V%G97,_`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y
M;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R
M969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3
M971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`
M4VAA<F4@1F]L9&5R<P!3:&%R92!M86EL(&9O;&1E<G,`4VAA<F4@>6]U<B!M
M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RX`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B
M92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E('1O9V=L
M960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+@!3:&]U;&0@=&AE(&)O
M9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@
M9&%T83\`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T
M97(@<V%V:6YG(&$@9')A9G0_`%-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y
M('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\`
M4VAO=P!3:&]W($%L;"!&;VQD97)S`%-H;W<@06QL($AE861E<G,`4VAO=R!$
M96QE=&5D`%-H;W<@3&EM:71E9"!(96%D97)S`%-H;W<@36%I;&EN9R!,:7-T
M($EN9F]R;6%T:6]N`%-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,`4VAO
M=R!5;G-U8G-C<FEB960`4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN
M9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/P!3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\`4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE
M=S\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3
M:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\`4VAO=R!P
M<F5V:65W<R!I;B!T;V]L=&EP<S\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H
M92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE($EM
M86=E<P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!F:6QT97(@:6-O;B!O
M;B!T:&4@;65N=6)A<C\`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/P!3:&]W
M('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H
M;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H;W=N`%-H<FEN:P!3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0`4VE?>F4`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA
M='5R92!!;&=O<FET:&T`4VEG;F5D`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I
M;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3
M;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,
M871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3
M;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@8GD@
M07)R:79A;`!3;W)T(&)Y($1A=&4`4V]R="!B>2!&<F]M($%D9')E<W,`4V]R
M="!B>2!-97-S86=E(%-I>F4`4V]R="!B>2!3=6)J96-T`%-O<G0@8GD@5&AR
M96%D`%-O<G0@8GD@5&\@061D<F5S<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3
M;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E
M<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`
M4W!A:6X`4W!A;0!3<&%M(&9O;&1E<CH`4W!E8VEA;"!#:&%R86-T97(@26YP
M=70`4W!E8VEA;"!#:&%R86-T97)S`%-P96QL($-H96-K`%-P96QL($-H96-K
M97(`4W!E;&P@8VAE8VL@8V]M<&QE=&4`4W!E;&QI;F<@97)R;W)S('!E<B!S
M8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RX`4W!L:70@8V5L;`!3<&QI="!C
M;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A
M<B!4<F5K`%-T87)T`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A
M='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U
M9V@`4W1R:6YG(&QI<W0`4W1R:7`@071T86-H;65N=`!3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<P!3=')I<"!L:6YE8G)E86MS/P!3='EL92!;0U-3
M70!3=0!3=6)?:F5C=`!3=6)J96-T`%-U8FIE8W0@1FEE;&0`4W5B;6ET`%-U
M8G-C<FEB92!T;R!&;VQD97(H<RD`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S
M<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@
M8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6=G
M97-T:6]N<P!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES
M90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U
M<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A
M;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I=&-H($-O;7!O<VET
M:6]N($UE=&AO9`!3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO;@!3=VET8V@@
M=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;@!3=VET>F5R;&%N9`!3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M
M4W1O<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE
M<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E7WAT`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F
M;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP
M;&%T92!!9&UI;FES=')A=&EO;@!496YT871I=F4Z(`!496YT871I=F5L>2!!
M8V-E<'0@<F5Q=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497)M<R!O9B!3
M97)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<`!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL
M86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($9R;VTZ(&-O;'5M;B!O
M9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.@!4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4
M:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL`5&AE($UA8VEN=&]S:"!R97-O
M=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+@!4:&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I
M;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@86-C;W5N="`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!A8V-O=6YT("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R
M92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT
M('1O('5S92!097)M:7-S:6]N<RX`5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F
M;W5N9"X`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R(&1A=&$@
M:7,@:6YV86QI9`!4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D
M+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@8FQO8VL@
M<&]P=7`@=VEN9&]W<S\`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@8V]N=&5N=',@;V8@=&AE($UA
M8VEN=&]S:"!F:6QE(&%R92!B96QO=RX`5&AE(&-U<G)E;G0@9F]L9&5R*',I
M("(E<R(@=VEL;"!B92!R96YA;65D('1O("(E<R(N`%1H92!C=7)R96YT(&QI
M<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@
M;F]T(&)E(')E=')I979E9`!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A
M<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`
M5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92`B)7,B(&9O;&1E<BX`
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BX`5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N
M9&%R+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N
M`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&1E<B`B)7,B(&%L<F5A
M9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!C;VYT86EN<R!I;&QE9V%L(&-H
M87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S92!P<F]B;&5M<RX@
M4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@!4:&4@9F]L
M9&5R("(E<R(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I
M8F5D('1O(&ET+@!4:&4@9F]L9&5R("(E<R(@=V%S(&1E;&5T960@8G5T('EO
M=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="X`5&AE(&9O;&1E<B`B
M)7,B('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED`%1H92!F;VQD97(@(B5S(B!W87,@<W5C
M8V5S<V9U;&QY(&-R96%T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S
M<V9U;&QY(&1E;&5T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U
M;&QY(')E;F%M960@=&\@(B5S(BX`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9O
M;&QO=VEN9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R=#H`5&AE
M(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@
M=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F
M=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD
M(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L
M96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U
M;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E
M('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R(&%D9')E<W-B;V]K+@!4
M:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RX`5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG
M(&5R<F]R(&UE<W-A9V4Z`%1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z`%1H92!M86EL('-E
M<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.@!4:&4@;6%I
M;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+@!4:&4@;65S<V%G92`B)7,B(&9R
M;VT@(B5S(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="X`
M5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%
M>&ET:6YG+@!4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+@!4:&4@;65S
M<V%G92!H87,@8F5E;B!V97)I9FEE9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@
M=F5R:69I960N(%-E;F1E<CH@)7,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M`%1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA
M<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B;&]C:R!P;W!U<"!W
M:6YD;W=S/P!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W
M86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')A
M=R!T97AT(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S
M+@!4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE($U3
M+51.148@871T86-H;65N="X`5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T
M(&5X:7-T(&EN('1H92!::7`@871T86-H;65N="X`5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S
M96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E
M($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B!F<F]M('EO=2!W:&5N('EO=2!H
M879E(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N
M9"!T:&4@;F]T:69I8V%T:6]N(&UE<W-A9V4N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V
M960N`%1H92!S97)V97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB
M;F%I;"!O9B!T:&ES(&EM86=E+@!4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B
M92!R97!L86-E9"X`5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E
M<&QA8V5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N`%1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="X`5&AE
M('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T87-K(&AA<R!B
M965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!O9B!T:&4@;65S<V%G
M90!4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4
M:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G90!4:&4@=&5X="!O9B!T
M:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+@!4:&4@=&5X
M="!O9B!T:&4@<V5N="!M97-S86=E`%1H92!T97AT(&]F('1H92!S96YT(&UE
M<W-A9V4@8V%N(&)E('9I97=E9"`E<RX`5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('5S97(G<R!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE('=E
M871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N
M;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+@!4:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!E
M>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@
M8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R
M92!W87,@86X@97)R;W(@8V]P>6EN9R!M97-S86=E<R!F<F]M("(E<R(@=&\@
M(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R("(E
M<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@(B5S(BX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9`!4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&4@979E
M;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G
M97,@:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I
M<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S
M(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A
M<R!A(&1R869T+@!4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE
M<W-A9V4Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N
M=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI
M<R!M97-S86=E('!A<G0`5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E
M;6)E9&1E9"!I;B!I="X`5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E
M;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@=&AI
M<SH@`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N`%1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O
M('1H92!M97-S86=E+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4
M:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D
M869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W
M:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N
M=',@<&QE87-E('9I<VET("5S`%1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_`%1H:7,@;65S<V%G
M92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+@!4:&ES(&UE<W-A9V4@8V]N
M=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S
M:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T
M=&%C:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN
M9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B!T:&ES(&UE<W-A9V4@:7,@
M=6YK;F]W;BX`5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z(`!4:&ES(&UE
M<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'
M4"!F;W)M870@*&%C8V]R9&EN9R!T;R!21D,@,C`Q-2DN`%1H:7,@;65S<V%G
M92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%
M(&9O<FUA="X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N
M960@=FEA(%!'4"X`5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S
M:6=N960@=FEA(%,O34E-12X`5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y
M<'1E9"!V:6$@4R]-24U%+@!4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP
M=&5D('=I=&@@4$=0+@!4:&ES(&UE<W-A9V4@=&\`5&AI<R!M97-S86=E('=A
M<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@
M>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4
M:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE
M<RX`5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N`%1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AR96%D(%9I
M97<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O
M<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H
M=&]O;'1I<"DZ`%1O`%1O($%D9')E<W,`5&\@<V5L96-T(&UU;'1I<&QE(&9I
M96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!W:&EL92!C;&EC:VEN9RX`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E
M`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?
M=&]P*0!4;W1A;"!!='1A8VAM96YT<R!3:7IE.@!4<F%N<VQA=&EO;G,`5')A
M<V@@9F]L9&5R`%1R87-H(&9O;&1E<CH`5')I;FED860@86YD(%1O8F%G;P!4
M<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX
M.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`
M5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%52
M3"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ
M`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E
M861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O
M(')E=')I979E('%U;W1A`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N86YS=V5R960`56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T90!5
M;F1E<FQI;F4`56YD:7-C;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`
M56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YH86YD;&5D(&-O;7!O;F5N
M="!O9B!T>7!E.B`E<P!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI
M<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A
M=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN
M;W=N($1A=&4`56YK;F]W;B!-965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N('5S97)N86UE(&]R
M('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FQO860@
M4&%S<W!H<F%S90!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS965N
M`%5N<V5T(&-O;&]R`%5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I`%5N<W5P
M<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!!='1A
M8VAM96YT($EN9F]R;6%T:6]N`%5P9&%T92!R97-P;VYD96YT('-T871U<P!5
M<&1A=&4@=7-E<@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L
M;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V
M97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5
M<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@
M24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\`57-E(%-33`!5<V4@:68@;F%M
M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R
M`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN
M:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@
M<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI
M<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``
M5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A
M;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L
M80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`
M5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R
M>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=P!6:65W
M("5S`%9I97<@)7,@4'5B;&EC($ME>0!6:65W($A434P@8V]N=&5N="!I;B!A
M('-E<&%R871E('=I;F1O=P!6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y`%9I
M97<@4&5R<V]N86P@4'5B;&EC($ME>0!6:65W(%1H<F5A9`!6:65W(%1H=6UB
M;F%I;`!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FEE
M=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I97<@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W(&5V96YT`%9I97<@;65S<V%G
M97,@:6X@)7,`5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G
M:6XZ`%9I97<@=&%S:P!6:65W('1H92!);6%G97,`5FER9VEN($ES;&%N9',L
M($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FER='5A;"!&;VQD97(@
M(B5S(B!C<F5A=&5D('-U8V-E<V9U;&QY+@!6:7)T=6%L($9O;&1E<G,`5FER
M='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"X`5FER='5A;"!F;VQD97(@
M;&%B96P`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@
M=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T
M:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R
M+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E
M<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)
M4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S
M:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/P!7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4
M<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@87,@9&5L971E
M9#\`5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@
M>6]U('=A;G0@=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E;G0M;6%I;"P@
M<VAO=6QD('=E('-A=F4@871T86-H;65N="!D871A/P!7:&EC:"!P:&%S97,`
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+@!7:&ET96QI<W0`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H
M(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@
M;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7
M:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T
M<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT
M96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!9
M97,L($D@06=R964`66]U(&%R92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M
M('1H92!F;VQL;W=I;F<@86-C;W5N="AS*3H`66]U(&%R92!C;W!Y:6YG+VUO
M=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@8W)E871I;F<@82!S=6(M
M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E
M<BX`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N`%EO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@`%EO=2!C
M86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N`%EO=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E
M(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@=&\@;&]G:6XN
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O
M;&1E<@!9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE
M(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RX`66]U(&AA=F4@)7,@;F5W(&UE
M<W-A9V5S+@!9;W4@:&%V92`Q(&YE=R!M97-S86=E+@!9;W4@:&%V92!A="!L
M96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@
M=7!L;V%D('EE="X@07)E('EO=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI
M<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N=',_`%EO=2!H879E
M(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(Z`%EO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R<SH`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="X`
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'
M4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G90!9;W4@;75S="!E
M;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K
M97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4`66]U(&UU<W0@<V5L96-T(&$@=&%R
M9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I
M<G-T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M`%EO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G92!F:7)S="X`
M66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!A="!L96%S
M="!O;F4@9FEL92!T;R!A='1A8V@N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U
M(')E9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RX`66]U(')E
M<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S+@!9;W4@=V5R92!N;W0@<W5B
M<V-R:6)E9"!T;R`B)7,B+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED
M`%EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2`B)7,B+B!(97)E(&ES
M('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E('-U8V-E<W-F=6QL>2!S
M=6)S8W)I8F5D('1O("(E<R(`66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B
M<V-R:6)E9"!F<F]M("(E<R(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D
M+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R
M($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!01U`@4'5B;&EC
M+U!R:79A=&4@2V5Y<P!9;W5R(%!R:79A=&4@2V5Y`%EO=7(@4'5B;&EC($ME
M>0!9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,`66]U
M<B!A8V-O=6YT<SH`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP
M92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8VAA<G-E
M="!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&5N8W)Y<'1I
M;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&UE<W-A9V4@=V%S('-U
M8V-E<W-F=6QL>2!D96QI=F5R960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T
M:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M
M;W1E('-E<G9E<G,Z`%EO=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6TYO
M(%-U8FIE8W1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@
M+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E
M<UT`7T%D;6EN:7-T<F%T:6]N`%]"8V,`7T)L86-K;&ES=`!?0TQ)`%]#8P!?
M1&%T851R964`7T1E;&5T90!?1&5L971E(%)O=P!?1F]L9&5R<P!?1W)O=7!S
M`%](96QP`%])9&5N=&ET>0!?26UA9V4@4')O<&5R=&EE<RXN+@!?26YB;W@`
M7TQO9R!I;@!?3&]G(&]U=`!?365S<V%G92!3;W5R8V4`7TUO9&EF>2!,:6YK
M+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4')I;G0`7U!R:6]R:71Y`%]2
M969R97-H("5S`%]296UO=F4@3&EN:RXN+@!?4F5P;'D`7U-E87)C:`!?4V5N
M9"!-97-S86=E`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?5&AR96%D
M`%]4;P!?56YD96QE=&4`7U5S97)S`%]6:65W(%1H<F5A9`!?5VAI=&5L:7-T
M`&%D9')E<W,@8F]O:P!A='1A8VAM96YT`&%T=&%C:&UE;G1S+GII<`!B>71E
M<P!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`9F%L;&EN9P!F:6QE`&9R;VT`
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE
M`&ME>0!L:6YE<UT`;6%I;&)O>"!F:6QE`&UK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+@!N86UE`&YO;F4`;F]T(&EM<&QE;65N=&5D
M`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT`'!I>&5L
M<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``
M<W!E;&QI;F<@97)R;W(`<W!E;&QI;F<@97)R;W)S`'-T96%D>0!T87-K(&QI
M<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`>6]U
M<B!B;&%C:VQI<W0`>6]U<B!W:&ET96QI<W0`4')O:F5C="U)9"U697)S:6]N
M.B!);7`M-"XP+C,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`V+3(X(#$T.C0X*S`S,#`*
M3&%S="U4<F%N<VQA=&]R.B!!=71O;6%T:6-A;&QY(&=E;F5R871E9`I,86YG
M=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I;VXZ
M(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM.0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&
M;W)M<SH@;G!L=7)A;',],3L@<&QU<F%L/3`["@`@("!+:6UE.B``("!487)I
M:#H@`"!+:6UD96XZ("``("@E<R!G_&X@]FYC92D`*$5R:?YI;2!!;F%H=&%R
M_2`E<RD`("@E<R!G_&YD92D`("AB=6?\;BD`("AY87+];BD`("AD_&XI`"`@
M($MO;G4Z(``@9&4H9&$I(``@+3X@`",`)2XR9DU"("\@)2XR9DU"("`H)2XR
M9B4E*0`E9"`E<R!V92`E<P`E9"!I;&5T:6YI;B!I<W1E;FUE>65N(&EL971I
M(&]L;6%D_?#]('-I<W1E;2!Y]FYE=&EC:7-I;F4@<F%P;W(@961I;&1I+@`E
M9"!I;&5T:6YI;B!I<W1E;FUE>65N(&EL971I(&]L;6%D_?#](')A<&]R(&5D
M:6QD:2X`)60@:6QE=&EN:6X@:7-T96YM97EE;B!I;&5T:2!O;&1U\'4@<VES
M=&5M('GV;F5T:6-I<VEN92!R87!O<B!E9&EL9&DN`"5D(&EL971I;FEN(&ES
M=&5N;65Y96X@:6QE=&D@;VQD=?!U(')A<&]R(&5D:6QD:2X`)60@+2`E9"`O
M("5D(&EL971I`"5D+6?\;FS\:R!H879A('1A:&UI;FD`)7,@+2!":6QD:7)I
M;0`E<R!087)M86L@W7II`"5S($M"`"5S($)A:_UM(-W^;&5M;&5R:2`M($]N
M87EL86UA`"5S($%Y87)L87(`)7,@1VER:?X`)7,@06YL8?YM82!+;_YU;&QA
M<OT`)7,@>F%T96X@=F%R+@`E<R!Z871E;B!V87(N($1I>FEN:6YI>B`E<R!Y
M96YI9&5N(&%D;&%N9/UR_6QA;6%D_2X`)7,@9&4@)7,@)7,`)7,@9V7G97)L
M:2!B:7(@<&]S=&$@:W5T=7-U(&1E\&EL+@`E<R!D:7II;B!A>2!B8?[];F1A
M('EE;FED96X@861L86YD_7+];&3]+@`E<R!O;F%Y;&%N9/T`)7,@=F%Z9V7G
M=&DZ("5S+@`E<R!R961D961I;&1I+@`E<R!S97)B97-T+VUE_F=U;"!I<W1E
M\&D@>6%N_71L863]+@`E<R`E<R!D879E=&EN:2!Y86[]=&QA9/TN`"5S('-I
M>F4@<V5R8F5S="]M9?YG=6P@8FEL9VD@9_9N9&5R9&DN(``E<R!G9>=I8VD@
M;VQA<F%K(&]N87EL86YD:0`E<R!I<W1E;FUE:W1E9&ER+@`E<R!D86MI:V$`
M)7,@8G5L=6YA;6%D_2X`)7,@<V5R8F5S="]M9?YG=6P@8FEL9VEN:7II(&ES
M=&5D:2X`)7,@)7,@9&4@8G5L=6YM86[]>OT@:7-T961I+@`E<R`M("5S("\@
M)7,@`"5S("5S(&1E\&G^:6UI;FD@:7-T96UE:W1E9&ER+@`E<R`E<R!K;VYU
M<W5N9&$@:&%B97)D87(@;VQM86[]>OT@:7-T96UE:W1E9&ER+@`E<R`E<R!H
M86MK_6YD82!S;VX@:&%B97)L97)I(&%L;6%N_7K](&ES=&5M96MT961I<BX`
M)7,@061R97,@1&5F=&5R:0`E<R!486MV:6T`)7,@3F]T($1E9G1E<FD`)7,@
M1_9R978@3&ES=&5S:0`E<SH@)7,`)7,Z("5S("@E9"9N8G-P.R\F;F)S<#LE
M9"D`*$1E\&G^:6ML:6ML97)I('5Y9W5L87G];B!V92!B:7(@<V]N<F%K:2!E
M:W)A;F$@9V7G:6XN*0`H1&7P:?YI:VQI:VQE<FD@>6]K<V%Y('9E($]L=?YT
M=7)M82!E:W)A;OUN82!G97)I(&3V;BXI`"C>=2!A;F$@:V%D87(@>6%P_6QA
M;B!D9?!I_FEK;&EK;&5R:2!U>6=U;&$@=F4@3VQU_G1U<FUA(&5K<F%N_6YA
M(&=E<FD@9/9N+B!"=2!E:W)A;F1A:VD@9&7P:?YI:VQI;&5R(%591U5,04Y-
M05E!0T%++BD`*-YU(&%N82!K861A<B!Y87#];&%N(&1E\&G^:6ML97)I('5Y
M9W5L82!V92!I;&5T:7EI(&?V;F1E<BX@0G4@96MR86YD82!O;&%N(&1E\&G^
M:6ML:6ML97(@55E'54Q!3DU!64%#04LN*0`J($5V971E(&)A<V%R86L@96ML
M97EI;B`J`"H@3/QT9F5N(&%D<F5S('-EYVEN("H`+"!F_7)T_6YA;/T@)7,@
M)7,`+"!D9?!I_FEM("5S("T^("5S`"TM(%-EYR`M+0`Q(&EL971I;FEN(&ES
M=&5N;65Y96X@:6QE=&D@;VQM863]\/T@<VES=&5M('GV;F5T:6-I;FEZ92!R
M87!O<B!E9&EL;6G^=&ER+@`Q(&EL971I;FEN(&ES=&5N;65Y96X@:6QE=&D@
M;VQM863]\/T@<F%P;W(@961I;&UI_G1I<BX`,2!I;&5T:6YI;B!I<W1E;FUE
M>65N(&EL971I(&]L9'7P=2!S:7-T96T@>?9N971I8VEN:7IE(')A<&]R(&5D
M:6QM:?YT:7(N`#$@:6QE=&EN:6X@:7-T96YM97EE;B!I;&5T:2!O;&1U\'4@
M<F%P;W(@961I;&UI_G1I<BX`,3`P(&MA<F%K=&5R`#$P,#`@:V%R86MT97(`
M,3(@4V%A=&QI:R!:86UA;B!":>=I;6D`,C0@4V%A=&QI:R!:86UA;B!":>=I
M;6D`,C0@<V%A=``R-3`@:V%R86MT97(`-3`P(&MA<F%K=&5R`$)U(/9B96L@
M:>=I;B!V97)I=&%B86[]('-O;B!U>F%N=/US_2!G97)E:VUE:W1E9&ER+@!/
M;G5L;6%Z(&)I<B!H871A(&]L=?YT=0`E<R!A9/UN9&$@8OQY_&L@9_9R_&YT
M_"!D;W-Y87/](&)U(&EL971I>64@96ML96YD:2X`1_9N9&5R9&GP:6YI>B!I
M;&5T:2!A;/UC_61A;B!B:7(@9&_P<G5L86UA;OUN(&=E;&UE<VD@:6QE('-O
M;G7G;&%N9/TN`-UL971I>6D@_FEF<F5L97EE8FEL;65K(&GG:6X@4$=0(&'G
M_6L@86YA:'1A<OT@9V5R96MM96MT961I<BX`W6UZ86QA;FW]_B!I;&5T:7EI
M(&1O\')U;'7P=6YU('-A\&QA;6%K(&GG:6X@4$=0(&'G_6L@86YA:'1A<OT@
M9V5R96MM96MT961I<BX`W6QE=&EN:6X@_FEF<F5S:6YI(.?V>FUE:R!IYVEN
M(&'G_6L@4$=0(&%N86AT87+]+/9Z96P@4$=0(&%N86AT87+]('9E(&=EYVG^
M('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=;&5T:7EI(&EM>F%L86UA:R!I
MYVEN(&'G_6L@4$=0(&%N86AT87+]+/9Z96P@4$=0(&%N86AT87+]('9E(&=E
MYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=;&5T:6YI;B#^:69R97-I
M;FD@Y_9Z;65K(&GG:6X@8>?]:R!3+TU)344@86YA:'1A<OTL(/9Z96P@4R]-
M24U%(&%N86AT87+]('9E(&=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER
M+@#=;&5T:7EI(&EM>F%L86UA:R!IYVEN(&'G_6L@4R]-24U%(&%N86AT87+]
M+"#V>F5L(%,O34E-12!A;F%H=&%R_2!V92!G9>=I_B!T_&UC96-I\&D@9V5R
M96MM96MT961I<BX`W6QE=&EY:2#^:69R96QE>65B:6QM96L@:>=I;B!AY_UK
M(%--24U%(&%N86AT87+](&=E<F5K;65K=&5D:7(N`-;6(%EA\&UU<@#6UB!3
M8?!N86L`UM8@2&%F:68@2V%R`-;6+]93`%9%`$%022!)1`!$_'IE;FQE>6EC
M:2!H86MK_6YD80!(86MK_6YD82XN+BX`16YA;'0`3W)T87EA`-US=&7P:2!O
M;F%Y;&$`3VYA>6QA;F3]`$]N87EL86YD_3H`5D93(&1I>FEN:2!Y87)A=/UR
M:V5N(&5R:?YI;2!E;F=E;&QE;F1I+@!61E,@9&EZ:6YI('EA<F%T_6S]<FME
M;B!E<FG^:6T@96YG96QL96YD:2X`2&5S87`@4&%R86QO<_T`2&5S87`@1&]N
M9'5R=6QD=2X`2&5S87`@W7-M:3H`2&5S87!L86[]>6]R`$5Y;&5M;&5R`$5K
M;&4`06QT($=R=7`@14ML90!!;'0@W7II;B!%2VQE`$)U<F%Y82!%:VQE.@!9
M96YI($=R=7`@16ML90!996YI(-UZ:6X@16ML90!996YI(&MU;&QA;OUC_2!E
M:VQE.@!+;VQO;B!%:VQE`%EE;FD@_'EE(&5K;&4`W6MI;&D@16ML90!+87EN
M86L@16ML90`E<R!-96[\<_QN_"!-;WII;&QA($ME;F%R(,=U8G7P=2!/;&%R
M86L@16ML90!"=6YU('1A:W9I;6EM92!%:VQE`$%D<F5S(&1E9G1E<FEN92!E
M:VQE.@!!9')E<R!D969T97)I;64@96ML90!+=6QL86[]8_T@16ML90`B)7,B
M(&5K(&]L87)A:R!E:VQE;F1I+@!+=6QL86[]8_T@96ML96UE('-EYVEL96UE
M>B!K_6S];F3]+@#=;&%V92!B:6QG:2`E<R!G]G+\;&5B:6QI<BX`W6QA=F4@
M8FEL9VD@87ER_6YT_6QA<OT`W6QA=F4@:6QE=&D@87ER_6YT_6QA<OT`W6QA
M=F4@:6QE=&D@87ER_6YT_6QA<OT@)7,@9_9R_&QE8FEL:7(N`-UL879E(&EL
M971I(&AA=&$@87ER_6YT_6QA<OT`W6QA=F4@:6QE=&D@:&%T82!A>7+];G3]
M;&%R_2`E<R!G]G+\;G3\;&5N96)I;&ER+@!!9')E<P!!9')E<R!$969T97)I
M`$%D<F5S($1E9G1E<FQE<FD`6?9N971I;2TM1&GP97(@:W5L;&%N_6QA<B!I
MYVEN(&EZ:6YL97)I(&)E;&ER;&5Y:6X`6?9N971I;0!!9',`069G86YI<W1A
M;@!!<FYA=G5T;'5K`$-E>F%Y:7(`UG1E:VD@860`2&EZ86QA`$AI>F%L86UA
M:SH`5/QM_`!4_&T@1&_P<G5L86YM_?X@2W5L;&%N_6/];&%R`%3\;2!'<G5P
M;&%R`%3\;2#=>FEN;&5R`%3\;2!D]G)T('G\>@!$:7II;BAL97(I9&5K:2!B
M_'3\;B!I;&5T:6QE<B!B:7(@=&%N92!-0D]8(&1O<WEA<VEN82!I;F1I<FEL
M96-E:W1I<CH`(B5S(B!D:7II;FEN9&5K:2`E<R!G_&YD96X@9&%H82!E<VMI
M(&]L86X@8OQT_&X@:6QE=&EL97(@:V%L_6/](&]L87)A:R!S:6QI;F5C96MT
M:7(N`"5S(&%Y9&%N(&1A:&$@97-K:2!O;&%N(&+\=/QN(&5S:VD@8F'P;/T@
M96ML97(@<VEL:6YE8V5K=&ER+B``)7,@87ED86X@9&%H82!E<VMI(&]L86X@
M8OQT_&X@9_9N9&5R:6QM:?X@<&]S=&$@9&EZ:6YL97)I('-I;&EN96-E:RX`
M4_QZ9V7G(&MU<F%L;&%R_2!H97)H86YG:2!B:7(@<&]S=&$@:W5T=7-U;F$@
M=7EG=6QA;G/];B!M_3\@`,=O:VQU(&%D<F5S;&5R92!I>FEN('9E<@!3_7)A
M;&%N;?W^(&QI<W1E('3\<OQN_"!A>6%R;&%M87EA(&EZ:6X@=F5R:6QS:6X@
M;6D_`%IA=&5N('9A<@#6=&5K:2!)35-0($=I<FG^:0#6=&5K:2!)35-0(%!A
M<F]L87/]`-9T96MI($E-4U`@2W5L;&%N_6/]($%D_0#6=&5K:2!E;&5K=')O
M;FEK('!O<W1A(&%D<F5S:0#6=&5K:2!T87-L86ML87(`UG1E:VD@;65T:6XZ
M`$)U(&+V;/QM(&GG:6X@]G1E:VD@96ML97(Z`$AE<B!Z86UA;@!(97(@>F%M
M86X@96ML97)I('-A:VQA`$%M97)I:V%N(%-A;6]A`$5K(.?]:V%R=/UL;6%Y
M82#G86S]_OUL_7)K96X@8FER(&AA=&$@;65Y9&%N82!G96QD:2X@24U!4"!S
M=6YU8W4Z(`!'9>=E<G-I>B!D9?!E<B!B96QI<G1I;&1I+@!996YI(&?V<F5V
M('EA<F%T_6S]<FME;B!B:6QI;FUE>65N(&)I<B!H871A(&UE>61A;F$@9V5L
M9&DN`$%N9&]R80!!;F=O;&$`06YG=6EL;&$`06YO;FEM(%!R;WAY`$-E=F%P
M`$-E=F%P;&%N;?W^`$-E=F%P;&%N;?W^(-UL971I;&5R`$%N=&%R=&EK80!!
M;G1I9W5A('9E($)A<F)U9&$`57EG=6QA;6$`57EG=6QA;6$@3&ES=&5S:0!5
M>6=U;&%M82!(87K]<@!3_'IG9>=L97)I(%5Y9W5L80`E<R!IYVEN(%/\>F=E
MYVQE<FD@57EG=6QA`$?\;FS\:R!K87G]=&QA<B!S_7)A<_UN9&$@<_QZ9V7G
M(&MU<F%L;&%R_2!U>6=U;&%N<_UN(&W]/P!3_'IG9><@:W5R86QL87+]($=%
M3$5.($M55%5352!H97(@9_9R_&YT_&QE;F1I\&EN9&4@=7EG=6YL86YS_6X@
M;?T_`$%L="!P87EL8?[];6QA<F$@=7EG=6QA`$]N87EL80!986ML8?[]:R!"
M;WEU=`!.:7-A;@!!<F%PYV$@*%=I;F1O=W,M,3(U-BD`0F5L9V5L:6L@1&]S
M>6$@0G5Y=71U`$)E;&=E;&EK($%D_0!"=2!AY_UK(&%N86AT87+]('-I;&UE
M:R!I<W1E9&GP:6YI>F4@96UI;B!M:7-I;FEZ/P!!;F%H=&%R(&EK:6QI;FEZ
M:2!S:6QM96L@:7-T961I\&EN:7ID96X@96UI;B!M:7-I;FEZ/R`H5&%V<VEY
M92!%1-U,345-14M4143=4B$I`$)U;G4@>6%P;6%K(&ES=&5D:?!I;FEZ9&5N
M(&5M:6X@;6ES:6YI>C\`)7,@:>=I;B!G:7)I_B!I<W1E\&EN:2!K86QD_7)M
M86L@:7-T961I\&EN>F4@96UI;B!M:7-I;FEZ/P!"=2!I;&5T:6QE<FD@2T%,
M24-)(&]L87)A:R!S:6QM96L@:7-T961I\&EZ9&5N(&5M:6X@;6ES:6YI>C\`
M0G4@96MI($M!3$E#22!O;&%R86L@<VEL;65K(&ES=&5D:?!I;FEZ9&5N(&5M
M:6X@;6ES:6YI>C\`0G4@9&EZ:6YI(&)O_F%L=&UA:R!I<W1E9&GP:6YI>F1E
M;B!E;6EN(&UI<VEN:7H_`,?V<"!K=71U;G5Z=2!B;_YA;'1M86L@:7-T961I
M\&EN:7ID96X@96UI;B!M:7-I;FEZ/P!"=2!I;&5T:6QE<FD@:V%L_6/](&]L
M87)A:R!S:6QM96L@:7-T961I\&EN:7ID96X@96UI;B!M:7-I;FEZ/P!"=2!I
M;&5T:7EI('1E;6EZ(&]L87)A:R!R87!O<B!E=&UE:R!I<W1E9&GP:6YI>F1E
M;B!E;6EN(&UI<VEN:7H_`$)U(&EL971I>6D@:7-T96YM97EE;B!I;&5T:2!O
M;&%R86L@<F%P;W(@971M96L@:7-T961I\&EN:7ID96X@96UI;B!M:7-I;FEZ
M/P!!<FIA;G1I;@!%<FUE;FES=&%N`$5R;65N:6-E("A!4DU30TE)+3@I`$=E
M;&G^(%IA;6%N_0!386YA=`!!<G5B80!!<G1A;@!!<V-E;G-I;VX@061A;&%R
M_0!!<V-I:2!386YA=/T`07-Y82]087-I9FEK($+V;&=E<VD`4V]R`$)A:_UM
M(&G^;&5M;&5R:6YD96X@]FYC92!D;_!R=6QA;6$@<V]R=6QS=6X@;74_`$%T
M86UA($MO;&]N;&%R_0!%:VQE`$1O<WEA($5K;&4`4$=0(&'G_6L@86YA:'1A
M<OUN_7H@:6QE=&EN:7IE(&5K;&5N<VEN(&UI/P!$;W-Y82!%:VQE.@!%:VQE
M;FUE:R!I<W1E;F5N(&1O<WEA("(E<R(@96L@8F]Y=70@;&EM:71I;FD@8?[]
M>6]R+D1O<WEA($5+3$5.345914-%2R``16MT96MI('-I>FEN('1A:W9I;2!I
M<W1E\&EN:7IE('EA;OUT=/UR+@!%:R!/;&%R86L`16L@8O9L_&YD_#H@UGIG
M_&X@96L@=/QR_`!%:VQE<@!687(@;VQM87EA;B!B:7(@9W)U8G4@<VEL;64@
M9VER:?YI;6DN`%9A<B!O;&UA>6%N(&)I<B!I>FYI('-I;&UE(&=I<FG^:6UI
M+@!687(@;VQM87EA;B!B:7(@9W)U8G4@9/QZ96YL96UE(&=I<FG^:6UI+@!6
M87(@;VQM87EA;B!B:7(@<&%Y;&'^_6W](&3\>F5N;&5M92!G:7)I_FEM:2X`
M2V%T_6S];6/];&%R`%5Y87+]`-9Z;FET96QI:VQE<@!!\'5S=&]S`$%V=7-T
M=7)A;'EA`$%V=7-T=7)Y80!!=71H7V-Y<G-Q;#H@W7-T96YE;B!I;6%P('5Z
M871A=/US_2!B=6QU;F%M863]+@!!=71H7V-Y<G5S.B#=<W1E;F5N('EE=&5N
M96ML97)E('-A:&EP(&1E\&EL+@!!=71H7V-Y<G5S.B#=<W1E;F5N(&EM87`@
M=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]F='`Z(-US=&5N96X@1E10('5Z
M86YT_7/](&)U;'5N86UA9/TN(%!(4"=Y:2`M+65N86)L92UF='`@<W=I=&-H
M(&1E\&G^=&ER9V5S:7EL92!D97)L97EI;BX`075T:%]I;6%P.B#=<W1E;F5N
M($E-05`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]I;7`Z($=E<F5K;&D@
M24U!4"!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H7VMR8C4Z(-US=&5N96X@
M:W)B-2!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H7VQD87`Z(-US=&5N96X@
M3$1!4"!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H7VEM87`Z("5S(&MU;&QA
M;OUC_7/](&5K;&5N96UE9&DN(%-U;G5C=3H@`$%U=&A?;&1A<#H@)7,@:W5L
M;&%N_6/]<_T@<VEL:6YE;65D:0!!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/]
M(&?\;F-E;&QE;F5M961I`$%U=&A?;6-A;#H@W7-T96YE;B!-0T%,('5Z86YT
M_7/](&)U;'5N86UA9/TN`$%U=&A?<VUB875T:#H@W7-T96YE;B!S;6)A=71H
M('5Z86YT_7/](&)U;'5N86UA9/TN`$1O\')U;&%M82!B8?YA<OUS_7H@;VQD
M=2X`1&_P<G5L86UA(&)A_F%R_7/]>B!O;&1U+B`E<P!$;_!R=6QA;6$@4D%$
M2553('-U;G5C=7-U('1A<F%F_6YD86X@9V5R:2#G979R:6QD:2X`1E10('-U
M;G5C=7-U;F$@9&_P<G5L86UA(&)A_F%R_7/]>B!O;&1U+@!']FYD97)E;B!A
M9')E<R!D969T97)I;61E(&ES92!G]G+\;G3\;&5R(&]T;VUA=&EK(&]L87)A
M:R!(5$U,(&EL971I;&5R:6YI;B!IYVEN9&4@9_9S=&5R:6QS:6X@;6D_`$UE
M=F-U="!!9')E<R!$969T97)I.@!+=6QL86[];/UR(&%L86YL87(Z`%EA;OUT
M($)E:VQI>6]R`$%Z97)B87EC86X`0D]&2"!!Y_UK;&%M86QA<OT`7T=E<FD@
M9/9N("5S`$=E<FD@9/9N("5S`$%R=&%L86X`07)T86QA;B!296YG:0!+]G3\
M(&ME<F)E<F]S('!A<F]L87/]+@!+]G3\(&ME<F)E<F]S(&MU;&QA;OUC_2!A
M9/TN`$)A:&%M86QA<@!"86AR97EN`$)A;'3]:R`H25-/+3@X-3DM,3,I`$)A
M;F=L861E_@!"87)B861O<P!486)A;B#G:7IG:7-I`$=I>FQI($LN($LN`$)E
M>6%Z(%)U<WEA`$)E;.=I:V$`0F5L:7IE`$1U<G5M(&)I;&=I(&EL971I<VEN
M:6X@:&%M(&UE=&EN(&AA;&D@8?YA\/UD863]<BX`0F5N:6X`0F5R;75D80!"
M:'5T86X`1&_P=6UG_&[\`$MA<F$@3&ES=&4`57EG=6QA;6$@(B5S(B!S86AI
M<"!O;&1U\'4@(B5S(B#V8F7P:2!B=6QU;F%M863]+@#68F5K($%Y87)L87+]
M`-9B96L@5/QR_`#6>F5L;&EK;&4@:7-T96YM96UI_G-E($A434P@:6QE=&EL
M97)I;FEN(&GG:6YD96MI(&?V<OQN=/QL97(@96YG96QL96YS:6X@;6D_`-WG
M97)I:P!+;WEU`$)O;&EV>6$`665R(-UM;&5R:0!3_6[]<@!3_6[]<B!+86S]
M;FS]\/TZ`%/];OUR;&%R`$)O<VYA($AE<G-E:P!(97(@W6MI<VD`0F'^;/UK
M($)I;&=I;&5R:2!V92#=;&5T:2#=YV5R:?!I;FEN(&AE<B!I:VES:61E`$)O
M='-V86YA`$%L=`!";W5V970@061A;&%R_0!"<F5Z:6QY80!"<FET86YY82!(
M:6YT($]K>6%N=7-U($+V;&=E<VD`0G)U;F5I`$)U;&=A<FES=&%N`$UA9&1E
M(-UM;&D@3&ES=&4`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-24P!#4DP@
M1&'P_73];2!.;VMT86QA<OT`7TC\8W)E(-9Z96QL:6ML97)I+BXN`$MA<F%K
M=&5R(%]3971I`%1A:W9I;0!$=7)G=6X`2V%M8F_G>6$`2V%M97)U;@!5>F%K
M=&%K:2!E;&5K=')O;FEK('!O<W1A('-U;G5C=7-U;F$@8F'P;&%N_6QA;?UY
M;W(N`%5Z86MT86MI(&5L96MT<F]N:6L@<&]S=&$@<W5N=6-U<W5N82!B8?!L
M86[];&%M_7EO<CH@`$?V<OQN=/QL96YE;6EY;W(@+2#>=2!A;F1A:VD@<&]S
M=&$@:W5T=7-U;F1A(&EL971I;FEN('-A9&5C92`E<R\E<R!P87+G87/](&)U
M;'5N9'4N`%!A<F]L82#V>F1E=FEN:6UL:2!O;&%R86L@<_UF_7)L86YA;6%M
M86MT863]<BP@;/QT9F5N('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BX`24U!4"!S
M=6YU8W5S=6YA(&)A\&QA;OUL863].B`E<P!+86YA9&$`W7!T86P`W6QE=&ED
M96X@5F%Z9V7G`%-O<G5N(%)A<&]R=6YU(-UP=&%L($5T`$)U(&EL971I>6D@
M:7!T86P@971M96LL:>=E<FGP:6YI;B!K86S]8_T@;VQA<F%K('EO:R!O;&UA
M<VEN82!Y;VP@8>=A8V%K=/UR+@`B)7,B(&1O<WEA<_T@<VEL:6YE;65D:2X`
M1V7G:6-I(&1I>FEN(&)U;'5N86UA9/TN`"=T87)G971&:6QE)R!D9?!I_G1I
M<F=E<VD@;VQM861A;B!D979A;2!E9&EL96UE>BX`(B5S(B!D:7II;FD@:V%L
M9/UR_6QA;6%D_2X`2V%L9/UR_6QA;6%D_2`L)60@86QT('EA</T@=F%R+@!9
M96YI9&5N(&3\>F5N;&5M961I+"!Y96YI9&5N(&3\>F5N;&5M92!IYVEN('-A
M\&QA;F%N(&MA>?UT;&%R_6X@<V%Y_7/](&EL92!D97!O;&%N;?W^(&]L86YL
M87+];B!S87G]<_T@9?YL9?YM96UE:W1E9&ER+@!"96QI<G1I;&UI_B!N=6UA
M<F%Y82!I;&5T:2!Y]FYL96YD:7)I;&5M961I+@!#87!E(%9E<F1E`$)A_FS]
M:P!+871E9V]R:6QE<B!V92!%=&EK971L97(`0V%Y;6%N($%D86QA<OT`2V%R
M8F]N($MO<'EA`$-E<"!496QE9F]N=0!(_&-R92#6>F5L;&EK;&5R:0!(_&-R
M92!Y87-T_6ML86UA<_TZ`$C\8W)E(-9Z96QL:6ML97)I`$C\8W)E($)O_FQU
M:VQA<OTZ`$-E<"!496QE9F]N=0!+96QT:6L@*$E33RTX.#4Y+3$T*0!/<G1A
M`$]R=&$@069R:6MA($-U;6AU<FEY971I`$]R=&$@079R=7!A("A)4T\M.#@U
M.2TR*0!/;F%Y($)E;&=E<VD@07ER_6YT_6QA<OT`3VYA>2!"96QG97-I($MU
M<F%L;&%R_0#'860`0F'^:V%N`$1E\&G^=&ER`%3\;?QN_"!$9?!I_G1I<@!$
M:7II;FD@1&7P:?YT:7(`2&5R('-A>69A9&$@:V'G(&EL971I(&?V<OQN96-E
M\&DL:6QE=&EL97)I;B!N87/];"!S_7)A;&%N86-A\/T@9VEB:2!G]G+\;G3\
M;&5M92!S9>=E;F5K;&5R:6YI(&1E\&G^=&ER:6X`16QE:W1R;VYI:R!P;W-T
M82!S=6YU8W4@=F4@9&EZ:6X@87EA<FQA<OUN_2!D9?!I_G1I<FEN+@#=;G-A
M;FQA<OUN('-I>F1E;B!G96QE;B!E;&5K=')O;FEK('!O<W1A;&%R_2!O:W5R
M:V5N('9E(&-E=F%P;&%R:V5N(&?V<F3\:VQE<FD@860@=F4@861R97-I;FEZ
M:2!D9?!I_G1I<FEN+@#=;G-A;FQA<OUN(&?V;F1E<F1I\&EN:7H@96QE:W1R
M;VYI:R!P;W-T86QA<OT@;VMU<FME;B!V92!C979A<&QA<FME;B!G]G)E8V5K
M;&5R:2!A9/UN_7K]+&%D<F5S:6YI>FD@=F4@:6UZ86[]>OT@9&7P:?YT:7)I
M;BX`2V%R86MT97(`1_9R_&YT_&QE;F5C96L@2V%R86MT97)L97(Z`$)A\&QA
M;G3]>?T@1&5?;F5T;&4N+BX`1&EZ:6YI(%EE;FD@4&]S=&$@:>=I;B!$96YE
M=&QE`$AE<'-I;FD@7T1E;F5T;&4O2&GG8FER:6YI($1E;F5T;&5M90!0;W-T
M82!A;&UA:R!I<W1E9&GP:6YI>B!E;&5K=')O;FEK('!O<W1A('-U;G5C=6QA
M<OUN_2!S9>=I;@#=;&5T:2!G]FYD97)M961E;B#V;F-E('EA>OUM(&1E;F5T
M:6UI('5Y9W5L86YS_6X@;?T_`-YI;&D`QVEN`$)A<VET;&7^=&ER:6QM:?X@
MQVEN8V4@*$=",C,Q,BD`1V5L96YE:W-E;"#':6YC92`H0FEG-2D`W?YL96T@
M4V7G`$5L96MT<F]N:6L@<&]S=&$@<W5N=6-U('-EYVEN.@!087)O;&$@<V7G
M:6X`2W5L;&%N_6/](&%D_2!S9>=I;@!%>6QE;2!S9>=I;CH`5&%R:6AL97)I
M;B!N87/];"!G]G-T97)I;&5C9?!I;FD@<V7G:6XZ`$QI<W1E($)IYV5M(%3\
M<OQN_"!39>=I;B`H<_UR86QA;FW]_B!L:7-T96QE<B!IYVEN*0!!9')E<R!E
M:VQE<FME;B!K=6QL86[];&-A:R!A9')E<R!D969T97)I;FD@<V7G:6XN`$%D
M<F5S;&5R:2!AYV%R:V5N(&%R86YA8V%K(&%D<F5S(&1E9G1E<FEN:2!S9>=I
M;BX`0VAR:7-T;6%S($%D86QA<_T`4_UN_68@=&%N_6W](&)U;'5N86UA9/TZ
M)7,`5&5M:7IL90!-4T]F9FEC92!B:>=I;2!I;6QE<FEN:2!T96UI>FQE`$MU
M;&QA;OUC_7G]('1E;6EZ;&4Z("5S`$MU;&QA;OUC_2!T96UI>FQE`$MU;&QA
M;OUC_2!V97)I<VD@=&5M:7IL90!487)A>?UC_6[]>OUN(&?V<W1E<F5B:6QE
M8V7P:2!B:7(@8FGG:6UE(.=E=FER;65K(&GG:6X@)7,@_'IE<FEN92!T_6ML
M87G];BX`1_9R_&YT_"!D;W-Y87/];OT@:6YD:7)M96L@:>=I;B`E<R#\>F5R
M:6YE('3]:VQA>?UN+@`E<R!Y]FYE=&EM('-A>69A<_UN82!G:71M96L@:>=I
M;B`E<R#\>F5R:6YE('3]:VQA>?UN+@!(5$U,(&GG97)I\&EN:2!A>7+](&)I
M<B!P96YC97)E9&4@9_9R;65K(&GG:6X@)7,@_'IE<FEN92!T_6ML87G];BX`
M0G4@9_9R_&YT_&[\;B!M:6YY873\<B!H86QI;FD@9_9R;65K(&GG:6X@)7,@
M_'IE<FEN92!T_6ML87G];BX`16MI(&%Y<OT@8FER('!E;F-E<F5D92!G]G)M
M96L@:>=I;B`E<R#\>F5R:6YE('3]:VQA>?UN+@!"=2#G;VML=2]I;&=I;&D@
M<&%RYV%Y_2!A>7+](&)I<B!P96YC97)E9&4@9_9R;65K(&GG:6X@)7,@_'IE
M<FEN92!T_6ML87G];BX`4F5S:6UL97)I($?64U1%4DU%2R!IYVEN(&)U<F%Y
M82!T_6ML87G];@!39>=I;&UI_B!A9')E<R!D969T97)L97)I;FEZ9&5N(&)I
M<FEN92!T_6ML87G];B!V92!B_'3\;B!A;&%N;&%R_2!A<F%M86L@:>=I;B!S
M9>=I;BX`1&5V86T@971M96L@:>=I;B!T_6ML87G];@!01U`@0>?]:R!!;F%H
M=&%R_6[]>OT@861R97,@9&5F=&5R:6YE('-A:VQA;6%K(&GG:6X@=/UK;&%Y
M_6X`)7,@4R]-24U%(&]N87D@8F5L9V5S:6YI(&%D<F5S(&1E9G1E<FEN:7IE
M('-A:VQA;6%K(&GG:6X@=/UK;&%Y_6XN`$A45%`@>6]L=7EL82!#;&EC:V%T
M96QL`$%D<F5S;&5R92!T_6ML86UA:RP@9_9N9&5R96YE(&MI_FEY92!Y96YI
M(&)I<B!I;&5T:2!O;'7^='5R86-A:W3]<@!!9')E<VQE<F4@=/UK;&%M86LL
M:6QE=&EN:6X@;VMU;FUA:R!IYVEN(&'G_6QM87/];OT@<V'P;&%Y86-A:W3]
M<BX`2V%P870`4&5N8V5R97EI($MA<&%T`%!E;F-E<F5Y:2!K87!A=`!$:7II
M;FD@2V%P870N`$)U;'5T;&%R`$)U;'5T;'4`0V]C;W,@061A;&%R_0!$87)A
M;'0`2&5P<VEN:2!$87)A;'0`0OQT_&X@1&EZ:6YL97)I($1A<F%L=`!$:7II
M;FD@1&%R86QT`$ME;F%R(,=U8G7P=6YU($1A<F%L=`!$87)A;'3];&W]_B!3
M_6[]<FQA<@!+;VQO;6)I>6$`4F5N:P!296YK($?V<W1E<F=E<VDZ(`!296YK
M(%-EYVEC:0!296YK(%-EYVEM:0!+;VQO;FQA<CH`2V]L;VX@0F'^;/UK;&%R
M_0!+;VUI:P!+;VUU=`!+;VUU="!+86)U\'4`0>?]:VQA;6$`3W)T86L@063]
M`$-O;6]R;W,`WFER:V5T`%1A;6%M;&%N9/T`0F'^:V$@8FER(&EL971I(&]L
M=?YT=7(`W6QE=&EY:2!Y96YI('!E;F-E<F5D92!O;'7^='5R;6%K(&ES=&5R
M(&UI<VEN:7H_`%9A<G-A>?UL86X@;VQA<F%K(&EL971I;&5R:2!(5$U,(&MU
M;&QA;OUC_2!A<F%B:7)I;6EY;&4@;VQU_G1U<FUA:R!I<W1E<B!M:7-I;FEZ
M/RA%\&5R('1A<F%Y_6/];OUZ(&)U(/9Z96QL:?!I(&1E<W1E:VQI>6]R<V$I
M`$)I;&=I<V%Y87)L87(`2V_^=6QL87(`66%P_6QA;F3]<FUA($9A<FML87+]
M`%EA</UL86YD_7(Z)7,`W6QE=&EL97)I;B!N87/];"!G]G+\;G3\;&5N96-E
M\&EN:2!Y87#];&%N9/UR_6X`4&]S=&%L87+];B#V;FEZ;&5M92!S9>=E;F5K
M;&5R:6YI('EA</UL86YD_7+];BX`4&%R86QO>?T@1&_P<G5L80!+;VYG;P!$
M96UO:W)A=&EK($MO;F=O($-U;6AU<FEY971I`$)A\&QA;G3](&)A_F%R_7/]
M>B!O;&1U+@!"8?!L86YT_2!B8?YA<OUS_7H@;VQD=3H`0>?]:R!A;F%H=&%R
M('-U;G5C=7-U;F$@8F'P;&%N=/T@<F5D9&5D:6QD:2X`0>?]:R!A;F%H=&%R
M('-U;G5C=7-U;F$@8F'P;&%N=/T@<F5D9&5D:6QD:2X@4V5B96(Z("5S("@E
M<RD`1E10('-U;G5C=6YA(&)A\&QA;G3](&)A_F%R_7/]>B!O;&1U+@!3=6YU
M8W5Y82!B8?!L86YT_2!B8?YA<OUS_7H`W6QE=&G^:6T@;F]K=&%L87+](&)A
M_F%R_7EL82!A9')E<R!D969T97)I;FEZ92!E:VQE;F1I+@!$979A;0`E<R!I
MYVEN(%!'4"!D97-T9?!I;FD@9&5N971L92X`)7,@:>=I;B!3+TU)344@9&5S
M=&7P:6YI(&1E;F5T;&4N`%EE;FD@<&]S=&%N_6X@+&YE('IA;6%N(&1E;F5T
M;&5N96-E\&EN:2!V92!Y96YI('!O<W1L86QA<OUN('-I>F4@8FEL9&ER:6QI
M<"!B:6QD:7)I;&UE>65C9?!I;FEK;VYT;VP@961I;@!-971I;B!D=7EG=2!S
M:6UG96QE<FEN:2!G]G+\;G3\<V5L(&1U>6=U('-I;6=E;&5R:6YE(&3V;OS^
M=/QR;65K(&ES=&5R(&UI<VEN:7H_`$-O;VL@061A;&%R_0#'97)E>@!+;W!Y
M86QA`%-EYVEM:2!+;W!Y86QA`$1I>FEN:2!+;W!Y86QA`$3\>F5L=`!$_'IE
M;'1I;&UI_B!M971I;@!+;W-T82!2:6MA`$-O=&4@9"=)=F]I<F4`W6QE=&D@
M4$=0(&EL92#^:69R96QE;F5M961I+@#=;&5T:2!01U`@:6QE(&EM>F%L86YA
M;6%D_2X`W6QE=&D@4R]-24U%(&EL92!S:69R96QE;F5M961I+@#=;&5T:2!3
M+TU)344@:6QE(&EM>F%L86YA;6%D_2X`W6QE=&G^:6T@;F]K=&%S_2!E:VQE
M;F5M961I+B`E<P!,1$%0('-U;G5C=7-U;F$@8F'P;&%N_6QA;6%D_2X`0F%K
M:7EE(&1E;F5T;&5N96UE9&DN("5S`$1A\/UT_6T@;&ES=&5S:2!Y87)A=/UL
M86UA9/TN("5S`%9&4R!S;VX@8?YA;6%S_2!Y87)A=/UL86UA9/TZ("5S`%!'
M4"!V97)I<VEN:6X@_FEF<F5S:2#G]GK\;&5M961I+@!3+TU)344@=F5R:7-I
M;FEN(/YI9G)E<VD@Y_9Z_&QE;65D:2X`W6QE=&G^:6T@;F]K=&%S_2!S:6QI
M;F5M961I+B`E<P!$8?#]=/UM(&QI<W1E<VD@<VEL:6YE;65D:2X@)7,`)7,@
M:>=I;F1E:VD@:6QE=&EL97(@<VEL:6YE;65D:2X@4W5N=6-U.B`E<P!!;/UC
M_6[];B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!B96QI<FQE;F5M961I+@!"
M86O];2!I_FQE;6QE<FD@>?QR_'3\;&5M961I+@#=<W1E;F5N(&1O<WEA($U3
M+51.148@96MI;F1E;B!S9>=I<"#G_6MA<G3];&%M863]+@!)<W1E;F5N(&1O
M<WEA(%II<"!A<OYI=FEN9&5N('-EYVEP(.?]:V%R=/UL86UA9/TN`$%D<F5S
M(&1E9G1E<FD@=&%M86UE;B!G971I<FEL96UE9&DN`$1A\/UT_6T@;&ES=&5S
M:2!T86UA;65N(&=E=&ER:6QE;65D:2X`1&'P_73];2!L:7-T96QE<FEN:6X@
M;&ES=&5S:2!T86UA;65N(&=E=&ER;&5M961I+@!!;F%H=&%R('-U;G5C=7-U
M;F1A;B!AY_UK(&%N86AT87(@961I;FEL96UE9&DN`"5S(&'G_6QA;6%D_2X`
M36%I;G1E;F%N8V5?5&%S:R!B:7)I;6D@)7,@8>?];&%M863]+@`E<R!O:W5N
M86UA9/TN`-US=&5N96X@:W5L;&%N8_T@:>=I;B!P87)O;&$@<_UF_7)L86YA
M;6%D_2X@0F%Z_2!Y861A('3\;2!A>7+];G3];&%R(&1O\')U(&1E\&EL+B!9
M96YI9&5N(&1E;F5Y:6X@>6%D82!D86AA(&9A>FQA('EA<F3];2!IYVEN('-I
M<W1E;2!Y]FYE=&EN:7IL92!G]G+\_OQN+@!!0TP@97)I_FEL96UE9&DN`$%D
M<F5S(&1E9G1E<FEN92!E<FG^:6QE;65D:2X@)7,`1&'P_73];2!L:7-T97-I
M;F4@97)I_FEL96UE9&DN("5S`$1A\/UT_6T@;&ES=&5L97)I;F4@97)I_FEL
M96UE9&DN("5S`%-U;G5C=6YU;B!Y971E;F5K;&5R:6YE(&5R:?YI;&5M961I
M+@!987#];&%N9/UR;6$@9V5R:2!D]FYD_'+\;&5M961I+BX`)7,@>6%P_6QA
M;F3]<FUA(&MA>61E9&EL96UE9&DN`%EE9&5K(&)I<B!Y87#];&%N9/UR;6$@
M:V%Y9&5D:6QE;65D:2X`665D96L@8FER('EA</UL86YD_7)M82!K87ED961I
M;&5M961I.B`E<P!9961E:R!Y87#];&%N9/UR;6$@9&]S>6%S_2`E<R!K87ED
M961I;&5M961I+@!987#];&%N9/UR;6$@9&]S>6%S_2`E<R!K87ED961I;&5M
M961I+B!"=2!D=7)U;61A+"!K;V1U('1E:W)A<B`E<R!IYVEN92!K87ED971M
M96L@>6%D82!T86MI<"!E9&5N(&MO9'4@96P@:6QE("5S(&GG:6YE(&MO<'EA
M;&%M86LL('-EYV5N96ML97)I;FD@:W5L;&%N86)I;&ER<VEN:7HN`$Q$05`@
M<W5N=6-U<W4@87)A;F%M863]+@#=;&5T:?YI;2!N;VMT87/](&?\;F-E;&QE
M;F5M961I+B`E<P!$8?#]=/UM(&QI<W1E<VD@9_QN8V5L;&5N96UE9&DN("5S
M`$UO>FEL;&$@:V5N87(@YW5B=?!U(&)U;'5N86UA9/TN($ME;F%R(.=U8G7P
M=6YU;B!AY_UK(&]L9'7P=6YD86X@96UI;B!O;'5N+@!387G];&W]_B!M971I
M;@#<;&ME`$1E<G-L97(`66%R870`1&EZ:6X@66%R870`06YA:'1A<B!987)A
M=`!386YA;"!$:7II;B!987)A=`!"8?!L86YT_2!Y87)A=`!996YI('1A<VQA
M:R!D:7II;FD@>6%R870`665N:2!987)A=`!996YI(&?V;F1E<FEL;6G^('!O
M<W1A(&1I>FEN:2!Y87)A=`!996YI(.?V<"!K=71U<W4@>6%R870`1V5L96X@
M<&]S=&%L87+];OUZ_2!D_'IE;FQE;65K+"!D:7II;FQE<FEN(&GG:6YE(&%T
M;6%K('9E(&ES=&5N;65Y96X@:6QE=&EL97)I('-I;&UE:R!IYVEN('/\>F=E
MYR!K=7)A;&QA<FD@>6%R873];BX`06QT(&1I>FEN('EA<F%T`%EA<F%T_6/]
M(-UZ:6YL97)I`$MR961I(&MA<G0@;G5M87)A<_T`2/UR=F%T:7-T86X`2_QB
M80#>=2!!;F1A:VD@6F%M86X`WG4@86YD86MI(%523`#>=2!!;F1A:VD@2&%V
M82!$=7)U;74`)7,@:>=I;B!Y_'+\<FS\:W1E:VD@97)I_FEM`-YU($%N9&%K
M:2#>87)T;&%R.@!9_'+\<FS\:W1E:VD@<VET:6P`1&GP97(@96QE:W1R;VYI
M:R!P;W-T82!H97-A<&QA<OUN_7ID86X@<&]S=&%L87+];B!G971I<FEL;65S
M:6YI(&MI_FES96QL9?YT:7)I;BX`3F%S_6P@<&]S=&$@9_9N9&5R9&GP:6YI
M>FD@:VG^:7-E;&QE_G1I<FEN`"5S(&=I<FG^:6YD92#G86S]_F%C86L@9_9R
M979L97)I(&MI_FES96QL9?YT:7)I;@!+97,`WF7G:6QI(&]L86YL87+](&ME
M<P!+_6)R_7,`2VER:6P@*$M/23@M4BD`2VER:6P@*%=I;F1O=W,M,3(U,2D`
M2VER:6PO56MR87EN82`H2T])."U5*0#'96L@0W5M:'5R:7EE=&D`1T<`1_QN
M;/QK`%1A<FE?:`!697)I($'P86/](%1A<F%Y_6/]<_T`5&%R:6@`1V5L:?X@
M5&%R:6AI`%1A<FEH(%-EYVEM:0!'_&X`2U]O;&]N=2!3:6P`07)A;/UK`$]N
M9&%L_6L@<V%Y_6QA<@!2961D961I;&1I`%)E9&1E9&EL9&D`1VER:6YT:7EI
M($%Z86QT`-9N(%1A;OUM;/T@4F5N:P#6;B!486[];6S]($MI;6QI:P!687)S
M87EI;&%N('/]<F%L86UA(/9LY_QT_#H`5F%R<V%Y_6QA;B!S_7)A;&%M82!Y
M]F[\.@!486[];6QA<@!9971K:6QI`%-I;``E<R!!Y_UK($%N86AT87+];OT@
M4VEL`%G\<OQR;/QK=&5K:2!!;F%H=&%R;&%R_2!3:6P`1&EZ:6YI(%-I;`!'
M<G5P(%-I;`#=>FEN(%-I;`!386YA;"!$:7II;FD@4VEL`-UL971I;&5R:2!S
M:6P@=F4@=&5M:7IL90!(_&-R92!3:6P`2V]L;VX@4VEL`%9A<F]L86X@]G1E
M:VD@=&%S;&'P_2!S:6P`57IA:W1A:VD@<W5N=6-U9&%N(&=E=&ER:6QE;B!I
M;&5T:6QE<FD@<VEL`%1A:W9I;6EM9&5N('-I;`!%<VMI(&)A\&S](&5K;&5R
M(&%Y(&)A_OUN9&$@<VEL:6YS:6X@;6D_`$5S:VD@9_9N9&5R:6QM:?X@<&]S
M=&$@9&EZ:6YL97)I(&%Y(&)A_OUN9&$@<VEL:6YS:6X@;6D_`%-A=/UR_2!S
M:6P`4V7G:6QM:?X@:VEM;&GP:2!S:6P`WG4@86YD86MI(&MO;&]N=2!S:6P`
MWG4@86YD86MI('-A=/UR_2!S:6P`4VEL:6YE8V5K`%-I;&EN96-E:R#=;&5T
M:6QE<@!%:R`B)7,B('-I;&EN9&DN`-UL971I;&5R:6X@4VEL:6YM97-I('9E
M(%1A_OUN;6%S_0!497-L:6T@>F%M86[]`$1A;FEM87)K80#=<W1E\&D@<F5D
M9&5T`%-E<F)E<W0O;67^9W5L(&)I;&=I(&ES=&5K;&5R:6YI(')E9&1E=`!!
M>F%L86X`4V]R=6YU(%1A;OUM;&%Y_6X`0>?]:VQA;6$`07ER_6YT_6QA<@!!
M>7+];G3];&%R("A!>6[]('IA;6%N9&$@2&]R9&4G=6X@9_QN;/QK(&1O<WEA
M<_UN_6X@:>=I;F1E*3H`07ER_6YT_6QA<B!Y]FYE=&EC:2!IYVEN(&?\;FS\
M:R!O;&%R86L@:V%Y9&5D:6QD:2X`1V5L:?YI;0!.96T@36EK=&%R_0!3;VX@
M<V%A='1E:VD@;F5M(&UI:W1A<OTZ(`!.96T@;6EK=&%R_3H@`-UM>F%L87(@
M9VEZ;&5S:6X@;6D_`%-O;&1A;B!S8?!A('GV;FS\`%-A\&1A;B!S;VQA('GV
M;FS\`$1I>FEN`$?V<W1E<@`R-"!S86%T;&EK('IA;6%N(&W](&?V<W1E<FEL
M<VEN/P!']G+\;G3\;&5M92!39>=E;F5K;&5R:0#=;&5T:2!G]FYD97)D:6MT
M96X@<V]N<F$@9&_P<G5L86UA(&?V<OQN=/QL96YS:6X@;6D_`$AA=F$@=&%H
M;6EN:6YI(&?V<OQN=/QL92`H5$%&*0!']G+\;G3\;&5M92!":>=I;6D`W6QE
M=&EN:6X@:>=I;F1E(&?V<OQN=/QL96YS:6X`665N:2!I;&5T:2!B:6QG:7-I
M(&)E;&ER96X@:&%T_7)L871M82!O;&%R86L@9_9R_&YT_&QE;G-I;B!M:3\`
M1/QZ96X`1/QZ96X@0FEL9&ER:6UI`$-I8G5T:0!%_FQE_FUE>65N`$1I>FEN
M:2!996YI(%!O<W1A(&GG:6X@1&5N971L96UE`%-I;&UE>6EN`&UA:6YT96YA
M;F-E+G!H<"!D;W-Y87/];F$@9&_P<G5D86X@97)I_FUE>6EN+@!'96QE;CH@
M:V]L;VYU;F1A(&)A\&QA;G3]('EA<F%T;6$`1&EZ:6YI(&'G;6%K(&ES=&EY
M;W(@;75S=6YU>C\`W6QK('-A=/UR(&%L86X@861L87+];OT@:>=E<FEY;W(@
M;74_($5V970@:7-E(&)U(&MU='5Y=2!S9>=I;CH`1&]M:6YI:P!$;VUI;FEK
M($-U;6AU<FEY971I`$)I='1I`-UN9&ER`"5S(-UN9&ER`"Y::7`@0FGG:6UI
M;F1E(&EN9&ER.B5S`$+\=/QN($5K;&5R:2`H+GII<"!D;W-Y87/](&]L87)A
M:RD@:6YD:7(`1&EZ:6YI(-UN9&ER`$1I>FEN:2#=;F1I<B!;+GII<"!":>=I
M;6EN9&5=`$]L=?YT=7)U;&%N('EA</UL86YD_7)M87G](%!(4"!B971I\&D@
M;VQA<F%K(&EN9&ER+@`N6FEP(&)IYVEM:6YD92!I;F1I<@!487-L86L`5&%S
M;&%K($1I>FEN:0!487-L86ML87(@1&EZ:6YI.@!!_F'P_2!AY_UL_7(@;&ES
M=&4`W6QAYVQA<@!%+5!O<W1A`$5L96MT<F]N:6L@4&]S=&$@061R97-I`$52
M4@!(051!.B#=;&5T:6YI;FEZ('1E<VQI;2!E9&EL96UE9&DN`$5K=F%T;W(`
M1/QZ96YL90!+87)A($QI<W1E>6D@1/QZ96YL90!";&]K($3\>F5N;&4`4_QZ
M9V7G;&5R:2!$_'IE;FQE`$=R=7`@1/QZ96YL90#=>FEN($3\>F5N;&4`W7II
M;FQE<FD@1/QZ96YL90`E<R#=YVEN(-UZ:6YL97)I($3\>F5N;&4`4V%N86P@
M1&EZ:6YL97)I($3\>F5N;&4`)7,@:>=I;B!386YA;"!$:7II;B!486[];?UN
M_2!$_'IE;FQE`$)E>6%Z($QI<W1E>6D@1/QZ96YL90!39>=E;F5K;&5R:2!D
M_'IE;FQE.@`E<R!IYVEN(&EZ:6YL97)I(&3\>F5N;&4`2V%R82!,:7-T96YI
M>FD@1/QZ96YL97EI;@!3_'IG9><@2W5R86QL87+];OUZ_2!$_'IE;FQE>6EN
M`$1I\&5R('!O<W1A(&AE<V%P;&%R_6YA(&5R:?YI;2!IYVEN('1E<F-I:&QE
M<FEN:7II(&3\>F5N;&5Y:6XN`$)E>6%Z($QI<W1E;FEZ:2!$_'IE;FQE>6EN
M`$7P:71I;0!-_7/]<@!%;"!386QV861O<@#6\&4N+BX`16T`16QE:W1R;VYI
M:R!0;W-T80!%;&5K=')O;FEK(%!O<W1A($%D<F5S:0!%;&5K=')O;FEK('!O
M<W1A(&%S<F5S;&5R:2!E_FQE_FUE;&DN`$]N87EL_2!E;&5K=')O;FEK('!O
M<W1A`$1U>6=U('-I;6=E<FQE<FD`)7,@:>=I;F1E:VD@=/QM(&EL971I;&5R
M(&)O_F%L=/UL9/TN`$)O_B!$:7II;BAL97(I`,?V<"!+=71U<W5N=2!";_YA
M;'0`Q_9P($MU='5S=6YU(%]";_YA;'0`0F_^(&EL971I+@!";_X@<V]N=><N
M`$)O_B!A<F%M82!T97)I;6QE<FD`4$=0(&G^;&5V:2!E=&MI;FQE_G1I<FEL
M<VEN(&UI/P!3+TU)344@:?YL979I(&5T:VEN;&7^=&ER:6QS:6X@;6D_`$9O
M=&_P<F%F($=A;&5R:7-I;F1E;B!M971I;FQE<FEN(&GG97)I<VEN92!G]G+\
M;G3\(&5K;&5M92!E=&MI;FQE_G1I<FEL<VEN(&UI/P#=;&5T:2#V;FEZ;&5M
M92!E=&MI;FQE_G1I<FEL<VEN(&UI/P!38?`@=/UK(&GG97)I:R!M96[\<_P@
M971K:6YL9?YT:7)I;'-I;B!M:3\`WFE?9G)E;&5M92!39>=E;F5K;&5R:0!3
M;VX`W6QE=&EL96X@:6QE=&EN:6X@<V]N=0#=;&5T:7EI(&)I=&ER`"5S(&1E
M;B!I;&5T:7EI(&)I=&ER`$)I=&G^('G];/T`1/QZ96YL97EI8VEY:2!'96YI
M_FQE=`!'9>=I_B!4_&UC97-I;FD@1VER:6X`4&%R;VQA;OUZ_2!S_6;]<FQA
M;6%K(&ES=&5D:?!I;FEZ9&4@<V]R=6QM86L@_'IE<F4@8FER(&?\=F5N;&EK
M('-O<G5S=2!G:7)I;BP@UG(N("=%=F-I;"!H87EV86[];OUZ_6X@863](&YE
M9&ER/R<Z`$?V<OQN=/P@861R97-I;FD@8G5R87EA(&=I<FEN`%EE;FD@=&%S
M;&%K(&1I>FEN:6X@863];OT@9VER:6X`665N:2!G]FYD97)I;&UI_B!P;W-T
M82!D:7II;FEN:6X@863];OT@9VER:6X`665N:2#G]G`@:W5T=7-U;G5N(&%D
M_6[](&=I<FEN`"(E<R(@:V%Y_73](&)A_F%R_7EL82!A9')E<R!D969T97)I
M;F4@96ML96YD:0!%:W9A=&]R($=I;F5S:0!%<FET<F4`2&%T80!986[]=/T@
M9_9N9&5R;65D92!H871A.B`E<RX`16QE=')O;FEK('!O<W1A(&3V;F1E<FUE
M9&4@:&%T82X`17-T;VYY80!%=&EY;W!Y80!%=&YI:P!!=G)U<&$`3VQA>2!B
M8?YA<OUY;&$@<VEL:6YD:2X`2&5R(#$U(&1A:VEK80!(97(@,B!D86MI:V$`
M2&5R(#,P('-A;FEY90!(97(@-2!D86MI:V$`2&5R($=I<FG^=&4`2&5R('EA
M<OUM('-A870`2&5R(&1A:VEK80#6<FYE:R!D9?!E<FQE<CH`QV%L_?YT_7(`
M1V5N:?YL970`2&5P<VEN:2!'96YI_FQE=`!"_'3\;B!$:7II;FQE<FD@1V5N
M:?YL970`1&EZ:6YI($=E;FG^;&5T`-US:6UL97)I($?V<W1E<@!+96YA<B#'
M=6)U\'5N=2!'96YI_FQE=`#=;&5T:2!O;'7^='5R;6$@<&5N8V5R97-I;F1E
M(&ES:6UL97(@]GID979I;FEM;&D@;VQA<F%K(&%R=&%L86YD82!AY_UL<_UN
M(&W]/P!"_'3\;B!D:7II;B!A\&%C_6[]('9A<G-A>?UL86X@;VQA<F%K(&=E
M;FG^;&5T`$=E;FG^;&5T:6QI>6]R`"<I)R!"96ML96YI>6]R`%-A9&4@:V5L
M:6UE('9E>6$@86S];G3](&%R86UA('1E<FEM:2!B96ML96YI>6]R`$=EYV5R
M;&EL:6L@4V]N(%1A<FEH:0#<<W0`UFX@06QA;B!296YG:0!!>6%R;&%R(&GG
M:6X@1E10('G\:VQE;65S:0!497)C:6AL97)I;B!G971I;&UE<VD@8F'^87+]
M<_UZ+@!,1$%0('-U;G5C=7-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ+@!334(@
M<W5N=6-U<W5N82!B8?!L86YT_2!B8?YA<OUS_7HN`"(E<R(@:V]N=6UU;F1A
M;B!K;W!Y86QA;6$@8F'^87+]<_UZ+@`B)7,B(&MO;G5M=6YA(&MO<'EA;&%M
M82!B8?YA<OUS_7HN`%EE;FD@4T%33"!B8?!L86YT_7/](&]L=?YT=7)U;&%M
M863]+@`B)7,B(&MO;G5M=6YA('1A_OUM82!B8?YA<OUS_7HN`%5Y9W5N($AA
M=F$`1F%L:VQA;F0@061A;&%R_2`H36%L=FEN82D`1F%R;V4@061A;&%R_0!/
M;G5L;6%Z($AA=&$Z`$9A:W,`WG5B870`2&ES<V5D:6QI>6]R`$AI<W-E9&EL
M:7EO<CH@`%!O<W1A($=E=&ER`%!O<W1A($%Y<OT@0FER(%!E;F-E<F5D92!'
M971I<FEL<VEN(&UI/P!':7)I_B!S_7)A<_UN9&$@:6QE=&EL97(@9V5T:7)I
M;'-I;B!M:3\`4&]S=&$@1V5T:7(Z`%!O<W1A($=E=&ER.B!996YI(&EL971I
M('EO:RX`2&%F:68@4V'P86YA:P!(869I9B!+87(@4V'P86YA\/T`4_Q?>F=E
MYVQE<@!!;&%N(&UA=')I<VD`1FEJ:0!$;W-Y80!$;W-Y82!387G]<_TZ("5S
M(&1O<WEA`$1O<WEA(%-A>?US_3H@)7,@9&]S>6$`1&]S>6$@6?9N971I8VES
M:0!$;W-Y82!!9/T`1&]S>6$@<V7G:6UI`$1O<WEA('G\:VQE;64`1&]S>6$@
M>?QK;&5M92!D97-T96ML96YM:7EO<BX`4_QZ9V7G(%-EYV5N96ML97)I`%/\
M>F=EYR!!>6%R;&%R_0#=;&5T:6QE<B!K_&;\<B!IYVEN('/\>OQL<_QN(&W\
M/P!3_'IG9><@9&5S=&5G:2!B=2!S:7-T96UD92!S9>=I;&ER(&O];/UN;6%M
M_?YT_7(N`%/\>F=EYVQE<@!3_'IG9>=L97(@971K:6X@1$70W4P`4_QZ9V7G
M;&5R.B`E<R!Y]FYE=&EM('-A>69A<_T`0G5L`$9I;FQA;F1I>6$`W6QK(%EA
M<OT`W6QK(%!O<W1A($MU='5S=2!387EF87/]`-UL:R!387EF80#=;&L@QV5Y
M<F5K`$]R86[]('-A8FET;&4`QV5V:7(`2V%Y86X`W6QE7W0`4VES`"5S(&1I
M>FEN:2!Y;VL`1&EZ:6X@1&]L8?[];?T`1&EZ:6X@UGIE=&D`1&EZ:6X@<&%Y
M;&'^_6W]('-EYVEL:7(@:_UL_6YM86W]_BX`1&EZ:6X@:W5L;&%N_6W]('-E
MYVEL:7(@:_UL_6YM86W]_BX`66%Z_2!296YG:0!996UE:P!']G+\;G3\;&5R
M:2!D97-T96ML96UE>65N('1A<F%Y_6/];&%R(&GG:6X`5&%H;6EN("A4048I
M`%1A:&UI;B!'_&YL97)I("A.;W0Z($=E<FD@9/9N_&QE8V5K;&5R(&AE;2!G
M_&X@:&5M(&=E8V4@;VQA<F%K(&3V;OQL96-E:SL@*6+\>?QK(&)I<B!S87G]
M(&=E;FG^(&)I<B#V8F5K;&4@<V]N=>=L86YA8V%K=/UR*0!087)O;&%N_7K]
M(&W]('5N='1U;G5Z/P!0;W-T82!K=71U<W5N9&%K:2!I;&5T:2!T87)I:&QE
M<FEN:6X@8FGG:6UI(&)U9_QN92!T87)I:&QE;FUI_@!&;W)M;&%R`$1E>6G^
M`$1E>6G^('3\<OP`1&5Y:?YL97(`1&5Y:?YL97(@,@!&;W)U;6QA<@#=;&5T
M`-UL970Z`-UL971I;&5N(-UL971I`"5S('1A<F%F_6YD86X@:6QE=&EL96X@
M:6QE=&D`6?9N;&5N9&ER;65L97(`0W4`QV5RYV5V96QE<@!&<F%N<V$`1G)A
M;G-A+"!-97)T;W!O;&ET86X`4V5R8F5S="]-9?YG=6P@0FEL9VD`4V5R8F5S
M="]-9?YG=6P@66%N_70`4V5R8F5S="]-9?YG=6P@W7-T96L`4V5R8F5S="]-
M9?YG=6P@W7-T96L@66%N_73]`$9R86YS_7H@1W5Y86YA<_T`1G)A;G/]>B!0
M;VQI;F5Z>6%S_0!&<F%N<_UZ($?\;F5Y($+V;&=E<VD`2VEM7V1E;@!+:6UD
M96X`1V5L96X@061R97,`2VEM9&5N`%1A;2!"971I;6QE;64`1&]L=6YA>0!!
MY_UK($%D`-UL970Z`-UL970Z`-UL970Z("5U(-UL971I;&5N(-UL971I`$=A
M8F]N`$?V<OQN=/QL97)I;B!A;/UN86-A\/T@9V%L97)I`$=A;&5R:3H`1V%M
M8FEY80!'96YE;"!39>=E;F5K;&5R`"5S(%EA</UL86YD_7)M87/];OT@3VQU
M_G1U<@!/;'7^='5R=6QA;B!+;V0`1_QR8VES=&%N`$%L;6%N>6$`4V%D96-E
M('EE;FD@:6QE=&D@86P@*%-A9&5C92!)34%0*0!'86YA`$-E8F5L:71A<OUK
M`%9E<FEL96X@060`W6QE=&EY92!G:70`1V]E9&5L`$=O;V=L92!!<F%M80!%
M<FG^:6T@=F5R`%-I>6%H($)E>6%Z`%EU;F%N:7-T86X`675N86YC82`H25-/
M+3@X-3DM-RD`1W+V;FQA;F0`1W)E;F%D80!'<G5P(%GV;F5T:6UI`$=R=7`@
M:7-I;6QE<FD@9&]L=2!O;&UA;/UD_7(`1W)U<&QA<@!'=6%D86QU<`!'=6%M
M`$=U871E;6%L80!'=65R;G-E>0!+;VYU:R#=>FEN;&5R:0!+;VYU:R!$969T
M97)I`$=I;F4`1W5I;F4@0FES<V%U`$=U>6%N80!"55)!64$`2%1-3`#=;&5T
M:6YI;B!(5$U,(%/\<OQM_`!(5$U,07)E82!S873]<F1A:VD@<V]N(&C\8W)E
M>6D@<VEL;65Y:2!R961D961I>6]R+@!(5$U,07)E82#G:7IE;&=E9&5K:2!S
M;VX@:V]L;VYU('-I;&UE>6D@<F5D9&5D:7EO<BX`2%1-3$%R96$@YVEZ96QG
M961E:VD@<V]N('-A=/UR_2!S:6QM97EI(')E9&1E9&EY;W(N`$A45%`@2VEM
M;&EK($1E;F5T:6UI(&)U;&%N86UA9/TN`$AA:71I`$AA<V@@06QG;W)I=&UA
M<_T`2&%F:68@4VES`$)A_FS]:P!"8?YL_6L@0FEL9VES:0!(96%R9"!!9&%S
M_2!V92!-8T1O;F%L9"!!9&%L87+]`-UB<F%N:6-E("A)4T\M.#@U.2TX+4DI
M`%G\:W-E:VQI:P!987)D_6T`1/QZ96YL97EI8VD@:W5L;&%R86L@>6%R9/UM
M`%EA<F3];6/]`%EA<OUK_')E`$1O<WEA;OUN(&)A_FQA;F?]8_TZ(`!/;'7^
M='5R=7EO<B!O;&1U\'5N=7H@:6QE=&DZ`$=I>FQI`$AA8F5R(-9B9?!I($?V
M<OQN=/QS_&[\;B!IYVEN9&4@1VEZ;&4`4VEL:6YE8V5K;&5R:2!':5]Z;&4`
MW'EE($]L=6YM87EA;FQA<OT@1VEZ;&4`6?QK<V5K`%G\:W-E:R#6;F-E;&EK
M`$5N('G\:W-E:P!?06YA<V%Y9F$`5F%T:6MA;@!!;F%S87EF80!%=B!!9')E
M<VD`178@5&5L969O;G4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E
M+TMO;&%B.B!"=2!M97-A:B!IYVEN9&4@9V7G97)S:7H@)7,@6$U,('9E<FES
M:2!I;&4@:V%R_OUL8?[];&3].B`E<P!(;W)D92]+;VQA8CH@)7,@;F5S;F5S
M:2!I;&4@:6QG:6QI(&)I<B!I;&5T:2!B=6QU;F%M863]`$AO<F1E+TMO;&%B
M.B`E<R!T_'+\;F1E(&AIYR!B:7(@;F5S;F4@)7,@;65S86K](&GG:6YD92!Y
M;VLN`$AO<F1E+TMO;&%B.B`E<R`B)7,B(&)A_F%R_2!I;&4@<VEL:6YD:0!(
M;W)D92]+;VQA8CH@0OQT_&YL96UE(&UO=&]R=2`G9&]M>&UL)R!02%`@=7IA
M;G3]<_UN82!I:'1I>6'G(&1U>6UA:W1A9/UR`$AO<F1E+TMO;&%B.B`E<R!N
M97-N97-I(&GG:6X@>65N:2!834P@8?!A8_T@;VQU_G1U<G5L86W]>6]R`$AO
M<F1E+TMO;&%B.B!3:6QI;F5M961I("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B`E<R!T_'+\;F1E:VD@:_US_6T@:>=I;B!-24U%($E$(&)U;'5N86UA9/T`
M2&]R9&4O2V]L86(Z($7^;&5N96UE9&D@)7,@(B5S(CH@)7,`4&%Y;&'^_6UL
M87(@9?YL96YE;65D:3H@)7,`0FEL:6YM97EE;B!P87EL8?[];2`B)7,B`%EA
M=&%Y(,=I>F=I`%EA=&%Y('EA<W3]:VQA;6$`66%T87DZ`$)U<F%Y82!N87/]
M;"!G96QD:6YI>C\@*$S\=&9E;B!R87!O<B!E9&EN(2D`16ML97)I(&YA<_UL
M(&?V<OQN=/QL96UE:R!I<W1I>6]R<W5N=7H_`$MAYR!A9&5T(&MO;&]N=2!B
M:7)L9?YT:7)M96L@:7-T:7EO<G-U;G5Z/P!+8><@86QA;B`H:V]L;VXI('9A
M<C\`2V'G(&%D970@<V%T_7+](&)I<FQE_G1I<FUE:R!I<W1I>6]R<W5N=7H_
M`%EA;OUT;&%R9&$@86S];G3]('EA</UL86X@<V%T_7)L87+];B!N:71E;&GP
M:0!.96T`3F5M.B``36EZ86CG_6QA<@!-86-A<FES=&%N`$E-05``24U!4"`H
MW6QE=&G^:6T@2W5R86QL87+];OT@UGID979I;FEM;&D@;VQA<F%K($)U;"D`
M24U!4"!P;W-T82!K=71U<W4@;VQU_G1U<G5L86UA9/TZ("5S`$E-05`@<&]S
M=&$@:W5T=7-U('-I;&EN96UE9&DZ("5S`$E-05`@<&]S=&$@:W5T=7-U(&MO
M=&%S_2!O;'7^='5R=6QA;6%D_3H@)7,`4U-,(/QZ97)I;F1E;B!)34%0`%-3
M3"#\>F5R:6YD96X@24U!4"`H:V5N9&EN9&5N(&EM>F%L_2!O;F%Y(&)E;&=E
M<VDI`%-33"#\>F5R:6YD96X@24U!4"`H:V5N9&EN9&5N(&EM>F%L_2D`24U!
M4"P@5$Q3('EO:P!)34%0+U!/4#,@16QE:W1R;VYI:R!0;W-T82!3=6YU8W5L
M87+]`$=%3$5.($M55%5350!)4"!!9')E<VD`25`@861R97-I(&UE=F-U="!D
M9?!I;"X@`$E0($%D<F5S:2!I>FEN('9E<FEL96X@0TE$4B!B;&_P=2!IYVEN
M9&4@9&7P:6PN`$E0(&MI;&ET;&5M92!I:&QA;&DN`-9N7V-E>64@4V%T_7(@
M665R;&7^=&ER`-UZ;&%N9&$`4V%D96-E(%-I;6=E;&5R`"5S(&GG:6X@<VEM
M9V5L97(`365T:6X@:6QE(&)I<FQI:W1E('-I;6=E;&5R`$MI;6QI\&EN(&%D
M_3H`1?!E<B!D;_!R=2!G]G+\;G3\;&5N96UI>6]R<V$L('EE;FD@<&5N8V5R
M961E(&'G;6%K(&GG:6X@=/UK;&%Y_6X@)7,N`$7P97(@26YT97)N970@17AP
M;&]R97(@:6QE('-I;6=E;&5R:2!G]G)E;6EY;W)S86[]>B!B=2!K=71U>74@
M<V7G97)E:R!03D<@<V%Y9&%M;/WP_6[](&MA<&%T;6%N_7H@9V5R96MI<BX`
M1_9R_&YT_&QE<FD@9_9R96UI>6]R(&9A:V%T(&)U(&UE<V%J_2!G]G)E8FEL
M:7)Y;W)S86[]>BP@>?QK;&5M96L@:7-T961I\&EN:7H@9_9R_&YT_"!T87)A
M>?UC_6[]>B!T87)A9OUN9&%N(&?V<W1E<FEL96UE;65K=&5D:7(N`%EO:W-A
M>0!4_&W\;OP@>6]K<V%Y`$?V<OQN=/P@UFYI>FQE;64`1_9R_&YT_"!54DP`
M1_9R_&YT_"!54DPZ`%-E<F=I9&5N(&?V<OQN=/P`4V5R9VED96X@9_9R_&YT
M_#H`1_9R_&YT_"!Y_&ML96UE:P!']G+\;G3\;&5R`"C=YV5R:2D@06MT87(`
M*-WG97)I*2!!:W1A<FUA($%N86AT87+]`"C=YV5R:2D@06MT87)M82!!;F%H
M=&%R(-UK:6QI<VD`W6QE=&EL97)I("C=YV5R:2D@06MT87(`4$=0($%N86AT
M87+];OT@*-WG97)I*2!!:W1A<@!+:?YI<V5L(-9Z96P@4$=0($%N86AA=&%R
M_2`HW>=E<FDI($%K=&%R`$MI_FES96P@0>?]:R!01U`@06YA:'1A<OT@*-WG
M97)I*2!!:W1A<@!+:?YI<V5L(%,O34E-12!/;F%Y($)E;&=E;&5R:6YI("C=
MYV5R:2D@06MT87(`0>?]:R!!;F%H=&%R_2`HW>=E<FDI($%K=&%R`$'G_6L@
M4$=0($'G_6L@06YA:'1A<OUN_2`HW>=E<FDI($%K=&%R`$'G_6L@4R]-24U%
M($%N86AT87+];OT@*-WG97)I*2!!:W1A<@!3+TU)344@06YA:'1A<OUN_2`H
MW>=E<FDI($%K=&%R`&UB;W@@9&]S>6%S_6[]("C=YV5R:2D@06MT87(`)7,@
M;6)O>"!D;W-Y87/];OT@)7,@9&EZ:6YI;F4@*&GG97)I*2!A:W1A<@#=YV5R
M:2!!:W1A<BP@063];2`E9`#6;F5M;&D`UFYE;6QI(-UL971I;&5R`"5D(&EL
M971I("5S(&MO;G5M=6YD86X@*&GG97)I*2!A:W1A<OUL9/TN`-WG97)I(&%K
M=&%R_6QA;B!A;&%N.B`E<P#=YV5R:2!A:W1A<OUL86X@86QA;FQA<CH`4_QR
M_'EO<@!3;VY?<F%Y82!3873]<B!%:VQE`$=E;&5N($MU='5S=0!"8?YL_6L@
M8FEL9VEL97)I;FEN(&O]<V$@8FER(/9Z971I('EA;OUT82!E:VQE;G-I;B!M
M:3\`UGIG_&X@:6QE=&D@>6%N_71A(&5K;&5N<VEN(&UI/P!986YL_?X@97EL
M96T@:V]D=2!G:7)I;&1I+@!986YL_?X@:W5L;&%N_6/](&%D_2!V92]V97EA
M('!A<F]L82X`66%N;/W^(&MU;&QA;OUC_2!A9/T@=F5Y82#V=&5K:2!A9')E
M<RY996YI9&5N(&1E;F5Y:6X@=F5Y82!D86AA(&9A>FQA('EA<F3];2!IYVEN
M('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BX`1VER:6YT:7EI($%R='3]<@!(:6YD
M:7-T86X`0FER97ES96P@2W5L;&%N_6/];&%R`$5N9&]N97IY80!":6QG:0!"
M:6QG:0`E<R!!Y_UK($%N86AT87+]($AA:VO];F1A($)I;&=I<VD`2VG^:7-E
M;"#6>F5L($%N86AT87(@2&%K:_UN9&$@0FEL9VD`2VG^:7-E;"!!Y_UK($%N
M86AT87(@2&%K:_UN9&$@0FEL9VD`365T:6YE($?V;?QL_`!3;VYR87EA($MO
M7VQO;B!%:VQE`$]N87D@0F5L9V5S:6YI($)U<F%Y82!997)L9?YT:7(`1_9R
M_&YT_"!997)L9?YT:7(`2VG^:7-E;"#6>F5L(%!'4"!!;F%H=&%R_6[]($)U
M<F%Y82!997)L9?YT:7(`2VG^:7-E;"#6>F5L($'G_6L@06YA:'1A<OT@0G5R
M87EA(%EE<FQE_G1I<@!!Y_UK(%!'4"!!;F%H=&%R_6[]($)U<F%Y82!997)L
M9?YT:7(`QVEZ96QG92!997)L9?YT:7(`5V5B($)A\&QA;G3]<_T@665R;&7^
M=&ER`-9N8V5Y92!+;VQO7VX@16ML90!996YI(&MO;&]N=2#^=2!A;F1A:VD@
M:V]L;VYD86X@<V]N<F$@>65R;&7^=&ER`%EE;FD@:V]L;VYU(/YU(&%N9&%K
M:2!K;VQO;F1A;B#V;F-E>64@>65R;&7^=&ER`%EE;FD@<V%T_7+](/YU(&%N
M9&%K:2!S873]<F1A;B!S;VYR87EA('EE<FQE_G1I<@!996YI('-A=/UR_2#^
M=2!A;F1A:VD@<V%T_7)D86X@]FYC97EE('EE<FQE_G1I<@!996YI('!A<F%G
M<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@<V]N<F%Y82!Y97)L9?YT:7(`665N
M:2!P87)A9W)A9OT@_G4@86YD86MI(&3\\/QM9&5N(/9N8V5Y92!Y97)L9?YT
M:7(`UG1E:VD@=&%S;&%K('EE<FQE_G1I<@!996YI(&)I<B!P87)A;&]Y_2!A
M;&%B:6QE8V7P:6YI>B!B:7(@96QE:W1R;VYI:R!P;W-T82!A9')E<VD@9VER
M:6XZ`$C\8W)E>6D@<V]N<F%S_6YA('EE<FQE_G1I<@!(_&-R97EI(/9N8V5S
M:6YE('EE<FQE_G1I<@!+;VQO;G4@<V]N<F%S_6YA('EE<FQE_G1I<@!+;VQO
M;G4@]FYC97-I;F4@>65R;&7^=&ER`$UE<V%J(&=I<@!087)A9W)A9OT@<V]N
M<F%S_6YA('EE<FQE_G1I<@!087)A9W)A9OT@]FYC97-I;F4@>65R;&7^=&ER
M`%-A=/UR_2!S;VYR87/];F$@>65R;&7^=&ER`%-A=/UR_2#V;F-E<VEN92!Y
M97)L9?YT:7(`1_QV96YL:6L@<V]R=7-U;G5N(&-E=F%B_3H`1_9R_&YT_'G\
M(%EE<FQE_G1I<B]$9?!I_G1I<@!"8?!L86YT_2!997)L9?YT:7(O1&7P:?YT
M:7(`1&'P_73];2!L:7-T97-I(&?V;F1E<FUE:R!IYVEN('EE=&5R<VEZ(&MR
M961I+@!9971E<G-I>B!K<F5D:0!486US87G]`%1A;7-A>?T@;&ES=&5S:0!"
M=2!B:6QE_F5N(&GG:6X@9V7G97)S:7H@8FER(&5Y;&5M('-EYVEL9&DN`$=E
MYV5R<VEZ($%D<F5S`$=EYV5R<VEZ(%5Z86L@16QE:W1R;VYI:R!0;W-T82!+
M=71U<W4`1V7G97)S:7H@541(+B`H2W5L;&%N_6/](%9E<FD@0F'^;/UK($)I
M;&=I<VDI`$=EYV5R<VEZ('5Y9W5L86UA+@!'9>=E<G-I>B!Y_?#];B!K:6UL
M:?!I+@!%;&5K=')O;FEK(%!O<W1A(&%D<F5S:6YD92!G9>=E<G-I>B!K87)A
M:W1E<CH@)7,N`$=EYV5R<VEZ('9E<FD@9_9N9&5R:6QD:2X`1V7G97)S:7H@
M=&5S;&EM(&%D<F5S:0!'9>=E<G-I>B!D;W-Y82!B:>=I;6D`1V7G97)S:7H@
M06YA:'1A<@!'9>=E<G-I>B!M<V=?='EP90!'9>=E<G-I>B!Y861A(&%T;&%N
M;?W^(&%P:5]I9`!'9>=E<G-I>B!Y861A(&%T;&%N;?W^(&1E\&G^=&ER9V5L
M97(`1V7G97)S:7H@_'-T(&EZ:6XN`$=EYV5R<VEZ(&MI_FES96P@]GIE;"!0
M1U`@86YA:'1A<OTN`$=EYV5R<VEZ(&MI_FES96P@8>?]:R!01U`@86YA:'1A
M<OTN`$=EYV5R<VEZ(&EL971I_FEM(&MU<F%L;&%R_0!'9>=E<G-I>B!P87EL
M8?[];&%N(&YE<VYE`$=EYV5R<VEZ(&MA>6YA:R!A9')E<VDN`$=EYV5R<VEZ
M('5N:6-O9&4@=F5R:7-I+@!3=&]K`%1E<G,@QV5V:7(`W7)A;B#=<VQA;2!#
M=6UH=7)I>65T:0!)<F%K`-UR;&%N9&$`36%N($%D82!$979L971I`%EA;/UT
M_6QM_?X@9_9K(&?\<OQL=/QL_"!F_7)T_6YA`-US<F%I;`#'_6MA<F%N`-UT
M86QI:P#==&%L>6$`2F%M86EK80!/8V%K`$IA<&]N>6$`2F%P;VYC82`H25-/
M+3(P,C(M2E`I`$IE<G-E>0#<<F3\;@!496UM=7H`2&%Z:7)A;@!987-L80!/
M<G1A>6$@66%S;&$`5&%M86UE;B!987-L80!3;VQA(%EA<VQA`%-A\&$@66%S
M;&$`2T(`2V%Z86MI<W1A;@#6>F?\;B!O;&%N('-A:VQA;G/];B!M_3\`2V5N
M>6$`2V5R8F5R;W,@<W5N=6-U(&1O\')U;&%M87G](')E9&1E='1I+@#'96MI
M<F1E:R!!8V5M:6QE<FD`06YA:'1A<B!987)A=`!!;F%H=&%R(%!A<FUA:VEZ
M:0!!;F%H=&%R(%5Z=6YL=?!U`$%N86AT87(@5&EP:0!!;F%H=&%R($MU;&QA
M;OUM_0!!Y_UK(&%N86AT87(@<W5N=6-U<W5N9&$@86YA:'1A<B!Z871E;B!V
M87(N`$%N86AT87(@8F'^87+]>6QA(&'G_6L@86YA:'1A<B!S=6YU8W5S=6YA
M(&?V;F1E<FEL9&DN`,=O8W5K;&%R`$MI<FEB871I`$MU>F5Y($MO<F4`1_QN
M97D@2V]R90!+;W)E8V4@*&5U8RU+4BD`2W5V97ET`$O]<F?]>FES=&%N`%-A
M>69A(%]$_'IE;FD`1&EL`$QA;R!$96UO:W)A=&EC($AA;&L@0W5M:'5R:7EE
M=&D`4V]N($3V<F3\;@!3;VX@4&]S=&$@2W5T=7-U(%-A>69A<_T`4V]N(%-A
M>69A`-YI_FMI;B!!>0!3;VX@1_QN8V5L;&5M93H`4V]N($=I<FG^.B`E<P!3
M;VX@1VER:?XZ("5S(/QZ97)I;F1E;B`E<P!3;VX@1VER:?XZ($%S;&$`3&5T
M;VYY80!987-A`$3\>F5N`$AIYV)I<B!S_6[]<B!IYVEN(&)O_B!B_7)A:VUA
M`$S\8FYA;@!3;VP`4V]L(&)A_FS]:R!B:6QG:7-I`%-O;&1A:VD@9&7P97)L
M97(`3&5S;W1H;P!%:VQE<FD@7T)A\&QA`$QI8F5R>6$`3&EB>6$`3&EE8VAT
M96YS=&5I;@#':7-E;&EY;W(`2&%F:68@66'P;75R`$5R:V5N(%-A871L97)D
M92!(869I9B!98?!M=7(`1V7G(%-A871L97)D92!(869I9B!98?!M=7(`2&%F
M:68@66'P;75R(%-A\&%N8?#]`$?V:R!G_'+\;'3\;/P@:&%F:68@>6'P;75R
M`$AA9FEF($MA<@!(869I9B!+87(@4V'P86YA\/T`3OQK=&5L:2#>:6ER`$)A
M\&QA;G3]`$)A\&QA;G3](&YO:W1A<_TZ`$?V<OQN=/QL97)K96X@96QE:W1R
M;VYI:R!P;W-T82!A9')E<VEN:2!O;'7^='5R;6$@<V%Y9F%S_6YA(&)A\&QA
M`$)A\&QA;FW]_B!E:VQE<B!Y87-A:VQA;FW]_G3]<BX`0F'P;&%N=/UL87(`
M)7,@=&%R:6AI;F1E(&)A\&QA<OUN('/\<F5S:2!D;VQA8V%K`$QI;G5X(,=E
M<F5Z:0!,:7-T96QE("T@:W5L;&%N_6/](&1I>FEN:2!G]G)E8FEL:7(`5F5R
M:2!486)A;FQA<OUN_2!,:7-T96QE`%EA<F3];2!+;VYU;&%R_6[]($QI<W1E
M;&4`QVEZ96QG96QE<FD@3&ES=&5L90!);&5T:?YI;2!N;VMT86QA<OT@96MR
M86[];OT@>?QK;&5R:V5N('3\;2!I;&5T:?YI;2!N;VMT86QA<OUD82!L:7-T
M96QE;G-I;B!M:3\@*$7P97(@('-EYVEL;65Z(&O];/UN;?W^<V$L('-A9&5C
M92!AY_UKYV$@87)A9/WP_6[]>B!I;&5T:?YI;2!N;VMT86QA<OUN_2!G]G)E
M8V5K<VEN:7HN(`!,:7-T96QE+4%R_FEV`$QI<W1E;&4M66%R9/UM`$QI<W1E
M;&4M260`3&ES=&5L92U386AI<`!,:7-T96QE+4?V;F1E<FEL;6G^(-;P96QE
M<@!,:7-T96QE+5/\<F3\<OQM8_QL97(`3&ES=&5L92U3_')D_'+\;6/\($]L
M;6%Y86YL87(`0F'^;/UK=&$@3&ES=&5L96UE`$MU;&QA;OUC_2!L:7-T96QE
M;64@<V7G:6QE;65Z(&O];/UN9/TN`$5D96)I>6%T`$QI='9A;GEA`%G\:VQE
M;FEY;W(N+BX`665R96P@4&]S=&$@2W5T=7-U.@!997)E;"!Z86UA;CH`665R
M('9E(%IA;6%N`%EE<@!':7)I_@`E<R!':7)I_FD`Q_UK_?X`1VER:?X`1VER
M:?X@1_9R979L97)I`$MU;&QA;OUC_2!A9/T@=F5Y82!P;W)O;&$@9&_P<G4@
M;VQM863]\/T@:>=I;B!G:7)I_B!B8?YA<OUS_7H@;VQD=2X`1VER:?X@8F'^
M87+]<_UZ(&]L9'4N`%5Z=6X@;65T:6X`0?YK`$3\_OQK`$3\_OQK(-9N8V5L
M:6L`2_SG_&L@>75N86X@:&%R9FQE<FD`2_SG_&L@;&%T:6X@:&%R9FQE<FD`
M2_SG_&L@<F]M82!R86MA;6QA<OT`16X@9/S^_&L`3/QK<V5M8G5R9P!!00!-
M3U1$`$U3+51.148@16MI('9E<FD@:>=E<FUE;65K=&5D:7(N`$U31P!-86-A
M;P!-86ME9&]N>6$`36%C:6YT;W-H($1O<WEA<_T`36%D86=A<VMA<@!"_'G\
M`%!O<W1A`%!O<W1A(%GV;F5T:6-I<VD`4&]S=&$@UFYI>FQE;64`0F'P;&%N
M_6QA8V%K(&5L96MT<F]N:6L@<&]S=&$@<W5N=6-U('3\<OPZ`%!O<W1A($MU
M='5S=0!0;W-T82!+=71U<W4@=F4@1&EZ:6X@1_9R_&YT_&QE;64@4V7G96YE
M:VQE<FD`0F'P;&%?;G3](%EA<F%T+BXN`$UA;&%V:0!-86QE>GEA`$UA;&1I
M=FQE<@!-86QI`$UA;'1A`-;P96QE<FD@971I:V5T;&5Y96-E\&EN:7H@:V%T
M96=O<FD@;&ES=&5S:6YI('9E(&MA=&5G;W)I;&5R:2!I;&G^:VEL96YD:7)E
M8V7P:6YI>B!R96YK;&5R:2!Y]FYE=&EN+@!-87`R-"!H87)I=&%S_0!-87!1
M=65S="!H87)I=&%S_0!-87)T`$ME;F%R(&)O_FQU\'4`1&EZ:6YD96MI($+\
M=/QN(-UL971I;&5R:2!/:W5N;77^($]L87)A:R#=_F%R971L92``1&EZ:6YD
M96MI($+\=/QN(-UL971I;&5R:2!/:W5N;6%M_?X@3VQA<F%K(-W^87)E=&QE
M`-W^87)E=&QE.@!&87)K;/T@9/QZ97ED96MI(&%L_6YT_6QA<B!F87)K;/T@
M<F5N:VQE<FQE(&G^87)E=&QE;G-I;B!M:3\`W6QE=&EL97(@9_9R_&QM_/X@
M;VQA<F%K(&G^87)E=&QE;G-I;B!M:3\H4V%D96-E($E-05`I`$)A<VET(&)I
MYVEM;&5M92!I_F%R971L96YS:6X@;6D_`$]K=6YM=?XO3VMU;FUA;?W^(&]L
M87)A:R!I_F%R971L90!$:?!E<B!I;&5T:2!I_F%R971L97)I>6QE(&G^87)E
M=&QE("CV<FYE:SH@UFYE;6QI+T-E=F%P;&%N;?W^*2``36%R<VAA;&P@061A
M;&%R_0!-87)T:6YI:P!"_'3\;B!3;W)G=6QA<FQA($7^;&7^`$AE<FAA;F=I
M($)I<B!3;W)G=7EL82!%_FQE_@!%_FQE;&5N(&%L86YL87(`36]R:71A;GEA
M`$UA=7)I='5S`-UZ:6X@=F5R:6QE;B!E;B!Y_&MS96L@:W)E9&DN`$5N('G\
M:W-E:R!M97-A:B!P87+G87/]('-A>?US_2!A_OUL9/TN`%-O;B`R-"!S86%T
M=&5K:2!E;B!Y_&MS96L@<_UC86ML_6LZ(`!3;VX@-B!S86%T=&5K:2!E;B!Y
M_&MS96L@<_UC86ML_6LZ(`!%;B!"_'G\:R!%:R!";WEU='4`16X@>?QK<V5K
M('5Z=6YL=6L`16X@9F%Z;&$@96L@<V%Y_7/];F$@=6QA_OUL9/TN`$5N(&+\
M>?QK(&5K(&)O>75T=6YA('5L8?[];&3]+@!-87G]<P!-87EO='1E`%3]<`!4
M;W!L86YT_2#=<'1A;&D`5&]P;&%N=/T@0FEL9VES:0!4;W!L86YT_2#6;F5R
M:7-I`%1O<&QA;G3](%EA;OUT_0!4;W!L86YT_2!'_&YC96QL96UE<VD`5&]P
M;&%N=/T@1_QN8V5L;&5M92#=<W1E\&D`W'EE;&5R`$1I>FEN($QI<W1E($UE
M;OQS_`!-96[\($MI<&DZ`$C\8W)E;&5R:2!B:7)L9?YT:7(`W6QE=&D`W6QE
M=&D@3VQU_G1U<FUA`-UL971I(%1A<FEH:0#=;&5T:2!39>=E;F5K;&5R:0#=
M;&5T:2!!<F%M80#=;&5T:2!";WEU='4`W6QE=&D@2V%Y;F'P_0#=;&5R:2!B
M8?YA<OUY;&$@9&_P<G5L86YD_2!A;6$@:6UZ86QA>?UC_6[];B!O;F%Y(&)E
M;&=E<VD@9&_P<G5L86YA;6%D_2X`W6QE=&D@1_9R_&[\;?P`365S86K];B!S
M_')E<VD@8FET=&DN`-UL971I(&G^87)E=&QE<FD`W6QE=&D@9&EZ:6YL97)I
M`"5S(&1E;B!I;&5T:0!%_FQE_F5N(&EL971I;&5R`-UL971I(&)A_F%R_7EL
M82!Y]FYL96YD:7)I;&UI_G1I<BX`W6QE=&D@8F'^87+]>6QA(&?V;F1E<FEL
M9&DL(&9A:V%T("5S(&GG:6YE(&MA>61E9&EL96UE9&DN`-UL971I(&)A_F%R
M_7EL82!G]FYD97)I;&1I+@!-97-A:B!T:7!I`%!O<W1A(&MU='5S=2!G]G+\
M;G3\<_QN9&4@<V%Y9F$@8F'^_6YA(&EL971I`-UL971I;&5R:0!(879A(%)A
M<&]R=0!(879A(')A<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I;"X`
M2&%V82!R87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN($%Y<OUN
M=/UL87(@>?9N971I8VD@:>=I;B!G_&YL_&ML96YD:0!9]FYT96T`365T<FEK
M`$UE:W-I:V$`36EK<F]N97-Y80!/<G1A`$UI;64@5/QR_`!3;VX@,C0@<V%A
M='1E:VD@96X@9/S^_&L@<_UC86ML_6LZ(`!3;VX@-B!S86%T=&5K:2!E;B!D
M_/[\:R!S_6-A:VS]:SH@`%EA;G/]`$UU:'1E;&EF`$)U;'5N86UA>6%N(%!%
M05(@<&%K971I.B!(5%107U)E<75E<W0N`$%T;&%N;?W^('EA</UL86YD_7)M
M82X@0G4@=7EG=6QA;6%Y_2!K=6QL86YM86L@:7-T:7EO<G-A;OUZ('EA</UL
M86YD_7)M87G](/QR971M96L@>F]R=6YD87/];OUZ+@!!=&QA;FW]_B!M97-A
M:B!)1"X`071L86YM_?X@;VQA;B!G97)E:VQI(%!%05(@<&%K971I($UA:6PN
M`$%T;&%N;?W^(&]T=7)U;6$@86ET($E$+@!0>G0`1V5Z:6-I(%!O<W1A`%-A
M:VEN`$1E\&G^:6T@5&%R:6AI`$1E\&G^=&ER`$1E\&G^=&ER.E523`!-;V0@
M5&%B86[]`$UO;&1O=GEA`$UO;F%C;P!-;_!O;&ES=&%N`$%Y('9E('G];`!!
M>6S]:P!-;VYT<V5R<F%T`$%Y($5V<F5L97)I`$9A<P!'96YE;&QI:VQE($'G
M_6L`1V5N96QL:6ML92!"=6QU=&QU`$=E;F5L;&EK;&4@1_QN9?YL:0!48?[]
M`$'^8?#](%1A_OT`4V]L82!48?[]`%-A\&$@5&'^_0!9=6MA<OT@5&'^_0!!
M_F%G_2!48?[]`$1I>FEN92!T8?[]`%EU:V%R_2!T8?[]`$UO>F%M8FEK`,=O
M:VQU(&3\>F5Y(&'^8?#](&'G_6S]<B!L:7-T96QE<@#';VL@4&%RYV%L_2]3
M9>=E;F5K;&D`QV]K;'4@4V7G:6T`2&5S86+];0!0;W)T86S];0!0;W)T86P@
M1/QZ96YI;0!->6%N;6%R`$MA8G5L($5434E93U)530!.3U0`060`060@=F4O
M=F5Y82!E;&5K=')O;FEK('!O<W1A(&)O_B!O;&%M87H`3F%M:6)Y80!.875R
M=0!%>6QE;2!'97)E:VEY;W(`3F5P86P`2&]L;&%N9&$`2&]L;&%N9&$@06YT
M:6QL97)I`$YE='-C87!E(%1A8F%N(%523`!.971S8V%P92!#02#=<'1A;"!5
M4DP`3F5T<V-A<&4@0T$@:W5R86P@55),`$YE='-C87!E(%EE;FEL96UE(%),
M`$YE='-C87!E(-UP=&%L(%523`!.971S8V%P92!34TP@<W5N=6-U(&%D_0!.
M971S8V%P92!O;F%Y(&)E;&=E<VD@8>?]:VQA;6%S_0!.971S8V%P92!O;F%Y
M(&)E;&=E<VD@=/QR_`!!\`!!<VQA`$5K;&5R:2!A<VQA('-A:VQA;6$`665N
M:0!996YI($MA;&5D;VYY80!996YI($MA=&5G;W)I`%EE;FD@1&EZ:6X`665N
M:2!0;W-T80!996YI($%Y`%EE;FD@2W5L;&%N_6/]($%D_2`H4V7G:6UL:2D`
M665N:2!:96QL86YD80!996YI(&EL971I;&5R`%EE;FD@4&5N8V5R92`H7V)O
M_BD`2&%B97)L97(`2&%B97(@1W)U<&QA<OT`4V]N<F%K:0!3;VYR86MI(-UL
M971I`%-O;G)A:VD@4V%Y9F$`4V]N<F%K:2!39>=E;F5K;&5R`$YI:V%R86=U
M80!.:6IE<GEA`$YI:F5R>6$`1V5C90!.:75E`$AA>?UR`$]N87D@0F5L9V5S
M:2!"=6QU;F%M863]`-YI9G)E;&5M92!9;VL`06YA:'1A<B!Z:6YC:7)I;F1E
M(&%N86AT87(@>6]K`-UL971I(%EO:P!(:>=B:7(@4$=0($'G_6L@06YA:'1A
M<OT@*&GG97)I*2!A:W1A<OUL86UA9/T`2VG^:7-E;"!/;F%Y($)E;&=E<VD@
M0G5L=6YM86UA:W1A9/UR`$'G_6L@06YA:'1A<B!"=6QU;F%M863]`$AIYV)I
M<B!3+TU)344@8>?]:R!A;F%H=&%R_2`H:>=E<FDI(&%K=&%R_6QA;6%D_2X`
M2&GG8FER(&5K(&)U;'5N86UA9/TN`$9A<FML87+];B!G]G-T97)I;&5B:6QE
M8V7P:2!K=6QL86[];&%B:6QI<B!Y87#];&%N9/UR;6$@=F5R:7-I('EO:RX`
M25-/(&EM86IL87+](&]U_G1U<FUA:R!IYVEN(&MU;&QA;OUL86)I;&ER(&)I
M<B!Y]FYT96T@>6]K+@!9_?#];B!T87-L8?#]('EO:RX`W7-T96YE;B!K;VYU
M;61A(&AIYV)I<B#V8F5K(&)U;'5N;6%M86MT863]<@!-0T%,(&1O\')U;&%M
M87/](&GG:6X@:&GG8FER('1A:W9I;2!A9/T@<V'P;&%N;6%M_?YT_7(N(`!$
M9?!I_FEK;&EK(%EO:P!"=2!I>FYE(&AIYV)I<B!A;'0@:7II;B!E:VQE;F5M
M97EE8V5K=&ER+@`E<R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES
M:2!B96QI<G1I;&UE9&DN`$944"!61E,@:>=I;B!H:>=B:7(@>6%P_6QA;F3]
M<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+@!344P@5D93(&GG:6X@:&GG8FER
M('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER=&EL;65D:2X`4U%,+49I;&4@
M5D93(&GG:6X@:&GG8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER=&EL
M;65D:2X`2W)E9&D@>6]K+@!(:>=B:7(@=&5S;&EM(&YO:W1A<_T@8F5L:7)T
M:6QM96UI_G1I<BX`2&GG8FER(&1O<WEA('G\:VQE;F5M961I`$AIYV)I<B!D
M:7II;B!S9>=I;&D@9&7P:6PN`$AIYV)I<B!D:7II;B!Y96YI('!O<W1A(&GG
M:6X@9&5N971L96YE;65D:2X`2&GG8FER(&1I>FEN(&)E;&ER=&EL;65D:0!(
M:>=B:7(@9&EZ:6YD92!Y96YI(&EL971I('EO:P!(:>=B:7(@9&EZ:6YD92!G
M]G+\;&UE;6G^(&EL971I('EO:P!(:>=B:7(@<VEM9V4@8G5L=6YA;6%D_2X`
M2&GG8FER('EE<B!B96QI<G1I;&UE9&DN`-UL971I(&?V=F1E<VEN9&4@;65T
M:6X@>6]K`$AIYV)I<B!M97-A:B!S8?!L86YM863]+@!(:>=B:7(@:6QE=&D@
M87)A;6%N_7IL82!E_FQE_FUE9&DN`$%D(&)E;&ER=&EL;65D:2X`3G5M87)A
M(&)E;&ER=&EL;65D:2X`4V%L9/UR9V%N(&1E>6G^(&MU;&QA;FUA`$A45%`@
M9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+@!)34%0(&1O\')U
M;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2X`2V5R8F5R;W,@9&_P<G5L
M86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+@!,;V=I;B!D;_!R=6QA;6%S
M_2!IYVEN('!A<F]L82!G:7)I;&UE9&DN`%!!4U-71"!D;_!R=6QA;6%S_2!I
MYVEN('!A<F]L82!G:7)I;&UE9&DN`%--0B!D;_!R=6QA;6%S_2!IYVEN('!A
M<F]L82!G:7)I;&UE9&DN`$]P96Y34TP@:6MI;&ES:6YE(&AIYV)I<B!Y;VP@
M8G5L=6YA;6%D_2Y/<&5N4U-,(&EK:6QI<VD@4$M#4R`Q,B!V97)I<VEY;&4@
M8V%L_?YM86L@:>=I;B!G97)E:VQI+@#<>64@;VQM86L@:>=I;B!B96ML97EE
M;B!Y;VLN`$AIYV)I<B!K:?YI<V5L(/9Z96P@4$=0(&%N86AT87+]("AIYV5R
M:2D@86MT87+];&%M863]+@!(:>=B:7(@:VG^:7-E;"!AY_UK(%!'4"!A;F%H
M=&%R_2`H:>=E<FDI(&%K=&%R_6QA;6%D_2X`2&GG8FER(&MI_FES96P@4R]-
M24U%(&]N87D@8F5L9V5S:2`H:>=E<FDI(&%K=&%R_6QA;6%D_2X`2W5R86P@
M>6]K`%EA;B!Y;VL`2&GG8FER('EA>OUM(&1E;F5T:6T@<')O9W)A;?T@>6%P
M_6QA;F3]<OUL;6%M_?XN`%EA>OUM(&AA=&%S_2!Y;VL`UFYE<FD@>6]K`-9N
M8F5L;&5K(&GG:6X@9V7G:6-I(&1I>FEN(&)U;'5N86UA9/TN`$MU;&QA;OUC
M_2!B96QI<G1I;&UE9&DN`$MU;&QA;OUC_2!A9/T@=F4O=F5Y82!P87)O;&$@
M9_9N9&5R:6QM961I+@!'9>=E<FQI(%A-3"!V97)I<VD@9V5R:2!D]FYM961I
M+@!$9?!E<B!Y;VL`UGIG_&X@>6%P_6QA;F3]<FUA9&$@<_QR_&T@8G5L=6YA
M;6%D_2Y987#];&%N9/UR;6%Y_2!T96MR87(@_')E=&EN+@#6>F?\;B!Y87#]
M;&%N9/UR;6%N_7ID82!S_'+\;2!B=6QU;F%M863]+EEA</UL86YD_7)M87G]
M('1E:W)A<B#\<F5T:6XN`$MA=/UL_6UC_2!$9?!I;`!(:>=B:7)I`$AIYV)I
M<FD@*-9R=/QL_"!K=6QL86[];BD`2W5Z97D@079R=7!A;/T@*$E33RTX.#4Y
M+3$P*0!.;W)F;VQK($%D87/]`$]L8?!A;@!+=7IE>2!987+];6O\<F4`2W5Z
M97D@36%R:6%N82!!9&%L87+]`$YO<G9EYP!3;VYR87/];F1A($1E\&EL`-9N
M8V5S:6YD92!$9?!I;`!3:6QI;FUE>65C96L`5&%S;&%K($1E\&EL`-9N96US
M:7H`2VG^:7-E;"!$9?!I;`!$:7II;B!D9?!I;`!'9>=E<FQI(&)I<B!AY_UK
M(&%N86AT87(@9&7P:6PN`%-I;&EN;65Y96-E:R!I;&5T:6QE<@!'97+G96ML
M9?YT:7)I;&UE;6G^`-9N96US:7H@:6QE=&EL97(`0F5L:7)T:6QM96UI_@!$
M97-T96ML96YM:7EO<BX`0G4@8FER87H@>F%M86X@86QA8FEL:7(`3F]T;&%R
M`$?V>B!A=/UL86-A:R!B:7+^97D@>6]K+"!G97)I(&3V;OQN+@!+87/];0!3
M87G]`$MA<F%K=&5R('-A>?US_0!+;VQO;B!S87G]<_T`1?!E<B!A>6S]:R!O
M;&%R86L@<VEL:6YI>6]R<V$L(&5S:VD@8F'P;/T@96ML97)I;B!S86ML86YA
M8V'P_2!A>2!S87G]<_TN`$7P97(@87EL_6L@;VQA<F%K('-I;&EN:7EO<G-A
M+"!E<VMI(&?V;F1E<FEL;6G^('!O<W1A(&1I>FEN;&5R:6YI;B!S86ML86YA
M8V'P_2!A>2!S87G]<_TN`%-A=/UR('-A>?US_0!$8?#]=/UM(&QI<W1E;&5R
M:6YI;B!G_&YC96QL96YM97-I(&GG:6X@;G5M87)A;&%R(&)E;&ER=&EL;65M
M:?XN`$5V970`5D5900!.97-N90!.97-N92!987)A=/UC_7/]`%-E:VEZ;&EK
M(%-I<W1E;0!%:VEM`%-A;&3]<F=A;FS]:R!S_'IG96-I`$]F:7,`17-K:2#=
M;&5T:6QE<@!%:W-I(&?V;F1E<FEL;6G^('!O<W1A(&1I>FEN;&5R:2!S:6QI
M;F5C96LN`%5M;6%N`%-A9&5C92!)34%0('-U;G5C=6QA<OT@<&%Y;&'^_6QA
M;B!D:7II;FQE<FD@9&5S=&5K;&5M96MT961I<BX`4V%D96-E(&]K=6YM86W]
M_B!I;&5T:2!IYV5R96X@9&EZ:6YL97(@9_9R_&YT_&QE;G-I;B!M:3\`4V%D
M96-E('-A;&3]<F=A;B!D97EI_FQE<@!3861E8V4@8FER(&5L96MT<F]N:6L@
M<&]S=&$@861R97-I;F4@:7II;B!V97)I;&UE:W1E9&ER+@!"=2!E>6QE;2!I
MYVEN('-A9&5C92!B:7(@9&EZ:6X@<V7G:6QM96QI9&ER+@!":7(@<&%Y;&'^
M_6W];B!S86AI<&QI\&EN:2!V97EA('-A:&EB:6YI('-A9&5C92!S:7-Y96T@
M>?9N971I8VES:2!V97EA('-A:&EB:2!D9?!I_G1I<F5B:6QI<BX`665N:2!P
M96YC97)E9&4@8><`3W!E;E-33"!H871A<_TZW6UZ86QA;FW]_B!3+TU)344@
M<&%RYV%S_6YD86X@=F5R:2!S9>=I<"#G_6MA=/UL86UA9/TN`$?V<OQN=/QL
M96YE;B!$:7II;@!"=2!B8?!L86YT_7G]('EE;FD@<&5N8V5R961E(&'G`-W^
M;&5T:6T@4VES=&5M:0!39>=I;6QI($MA=/UL_6UC_0!39>=E;F5K;&5R`"5S
M(&GG:6X@<V7G96YE:VQE<@!3_7)A;&%N;?W^($QI<W1E`$MU<G5L=?X`2W5R
M=6US86P@0FER:6T`1/QZ96YL96UE`-9Z9_QN('5Y9W5L86UA('1A<VQA\/T`
M)7,@:>=I;F1E:VD@]GIG_&X@=&%S;&%K;&%R.@!$:?!E<@!$:?!E<B!":6QG
M:6QE<@!$:?!E<B!0;W-T82!(97-A<&QA<OT`1&GP97(@4V7G96YE:VQE<@!3
M86AI<"!I>FEN;&5R:0!004T@9&_P<G5L86UA<_T@;65V8W5T(&1E\&EL+@!0
M1U``4$=0(%-A>?US86P@W6UZ80!01U`@:6QE(-YI9G)E;&5N;6G^(-UL971I
M`%!'4"#>:69R96QE;FUI_B!697)I`%!'4"!(871A<_TZ(`!01U`@2&%T87/]
M.B!+:?YI<V5L(/9Z96P@86YA:'1A<B!IYVEN(&=EYVG^('3\;6-E8VGP:2!G
M97)E:VUE:W1E9&ER+@!01U`@4V7G96YE:VQE<FD`4$=0($=EYVG^(%3\;6-E
M8VGP:2!':7)I_FD`4$=0($MI_FES96P@06YA:'1A<B#=:VEL:7-I(&1E<W1E
M\&D@9_QV96YL:2!B:7(@=V5B(&)A\&QA;G3]<_T@9V5R96MT:7)M96MT961I
M<BX@`%!'4"!!Y_UK($%N86AT87+]`%!'4"!!Y_UK($%N86AT87(@365T;FD`
M(B5S("@E<RDB(&GG:6X@4$=0($'G_6L@06YA:'1A<OT@8F'^87+]>6QA(&5K
M;&5N9&DN`"(E<R(@4$=0($'G_6L@06YA:'1A<OT@8F'^87+]>6QA('-I;&EN
M9&DN`%!'4"!!Y_UK($%N86AT87(@6FEN8VER:0!01U`@W6UZ82!-97-A:OT`
M4$=0(-UM>F$OWFEF<F5L96UE($UE<V%J_0!01U`@:6QE(-UM>F%L86YM_?XO
MWFEF<F5L96YM:?X@5F5R:0!01U`@]GIE;"!A;F%H=&%R_2!B8?YA<OUY;&$@
M96ML96YD:2X`4$=0(&'G_6L@86YA:'1A<OT@8F'^87+]>6QA(&5K;&5N9&DN
M`%!'4"!D97-T9?!I(&)U('-I<W1E;61E('-EYVEL96UE>B!K_6S];FW]_G3]
M<BX`4$=0(&1E<W1E\&D@>?QR_')L_&MT92!D9?!I;"!B=2!N961E;FQE('-A
M>?US86P@:6UZ82!D;_!R=6QA;F%M86MT863]<BX`4$=0(&1E<W1E\&D@>?QR
M_')L_&MT92!D9?!I;"!B=2!N961E;FQE(&EL971I;FEN(/YI9G)E<VD@Y_9Z
M_&QE;65M96MT961I<@!02%`@2V]D=0!02%`@2V%B=?!U`-93($AA9FEF(%EA
M\&UU<@#64R!38?!A;F%K;&%R_0#64R!+87(`UE,@2V%R(%-A\&%N86ML87+]
M`-93($?V:R!G_'+\;'3\;/P@9OUR=/UN80!03U`S`%!/4#,@*-UL971I_FEM
M($MU<F%L;&%R_6[](-9Z9&5V:6YI;6QI($%L9_UL82D`4U-,(/QZ97)I;F1E
M;B!03U`S`%-33"#\>F5R:6YD96X@4U-,("AK96YD:6YD96X@:6UZ86S](&]N
M87D@8F5L9V5S:2D`4U-,(/QZ97)I;F1E;B!03U`S("AK96YD:6YD96X@:6UZ
M86S]*0!03U`S+%1,4R!Y;VL`4%](4"!+86)U\'4`66%S=/UK;&%M80!387EF
M82`E9"`M("5D`-UL:R!/:W5N;6%M_?X@W6QE=&EN:6X@0G5L=6YD=?!U(%-A
M>69A`%-O;B!/:W5N;6%M_?X@W6QE=&EN:6X@0G5L=6YD=?!U(%-A>69A`%!A
M:VES=&%N`%!A;&%U`-W^9V%L($5D:6QM:?X@1FEL:7-T:6X@0O9L9V5S:0!0
M86YA;6$`4&%P=6$@665N:2!':6YE`%!A<F%G=6%Y`$+V;/QM*&QE<BD`2_US
M;65N($)U;'5T;'4`1V7G:?X@5/QM8V5C:?!I`$=EYVG^(%3\;6-E8VGP:2`H
M5&5K<F%R*0!'9>=I_B!4_&UC96-I\&D@8F'^87+]>6QA(.?]:V%R=/UL9/TN
M`$=EYVG^(%3\;6-E8VGP:3H`1V7G:?X@5/QM8V5C:6ML97)I(&)O_B!O;&%M
M87H`1V7G:?X@5/QM8V5C:6ML97)I(&7^;&7^;65M96MT961I<@!087)O;&$`
M66%N;/W^('!A<F]L80!2041)55,@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@
M9V5R96MM96MT961I<BX`3VYA>6S](%!A<F]L80!087)O;&$Z`%!A<F]L83H`
M4&%R;VQA;&%R(&7^;&7^;65K('IO<G5N9&%D_7(N`%EA</W^=/UR`%!A;F]D
M86X@>6%P_?YT_7(`66]L`$)E:VQE>65N(-QY96QI:VQE<CH`W6YS86YL87(`
M6?QZ9&4`0F%K_6T@W?YL96UL97)I;FD@1V5RYV5K;&7^=&ER`$)A:_UM(&G^
M;&5M;&5R:2!G:7)I_G1E(&=E<N=E:VQE_G1I<FEL<VEN(&UI/P#=>FEN`-UZ
M:6X@6?9N971I;6D`0G4@:W5L;&%N_6/];OUN(&EZ:6YL97)I(&1E\&G^=&ER
M:6QE;65Z+@!+:?YI<V5L`$MI_FES96P@0FEL9VEL97(`2VG^:7-E;"!01U`@
M86YA:'1A<B!I:VEL:7-I(&)A_F%R_7EL82#\<F5T:6QD:2X`2VG^:7-E;"!0
M1U`@86YA:'1A<FQA<OT@8F'^87+]>6QA('-I;&EN9&DN`$MI_FES96P@4R]-
M24U%(&]N87D@8F5L9V5S:2`H:>=E<FDI($%+5$%224Q!34%$23H@`$MI_FES
M96P@4R]-24U%(&%N86AT87)L87+](&)A_F%R_7EL82!S:6QI;F1I+@!097)U
M`$5V8VEL($AA>79A;FQA<@!&:6QI<&EN;&5R`%1E;&5F;VX`1F]T;_!R869L
M87(`4&ET8V%I<FX`4F5S:6T@0FER:6UI`-UM>F%N_7H@>6%N_71L87)D86X@
M=F4@:6QE=&EL96-E:VQE<F1E;B#V;F-E('EE<FQE_G1I<FEL<VEN(&UI/P#=
M;&5T:6YI;B!$_'H@365T:6X@4_QR_&W\`$)E>6QI:R!3]GIL97(`3/QT9F5N
M(&)I<FMAYR!H_&-R97EE('3]:VQA>?UN`$S\=&9E;B!B=2#V\&5Y:2#G_6MA
M<FUA:R!I<W1E9&GP:6YI>FD@9&_P<G5L87G];CH`3/QT9F5N(&)U(/;P96YI
M;B!B8?#];OT@Y_9Z;65K(&ES=&5D:?!I;FEZ(&1O\')U;&%Y_6XN`$S\=&9E
M;B!B:7(@87D@=F4@8FER('G];"!G:7)I;BX`3/QT9F5N('EE;FD@:V%T96=O
M<FEN:6X@863];OT@9VER:6XZ`$S\=&9E;B!Y96YI('!O<W1A(&MU='5S=2!I
MYVEN(&)I<B!A9"!G:7)I;CH`3/QT9F5N(&=EYV5R;&D@8FER($E0(&%D<F5S
M:2!G:7)I;BX`3/QT9F5N(&=EYV5R;&D@8FER(&?\;B!G:7)I;BP@87ED86MI
M(&?\;B!S87G]<_UN_2!K;VYT<F]L(&5D:6XN`$S\=&9E;B!G9>=E<FQI(&)I
M<B!Z86UA;B!G:7)I;BX`3/QT9F5N('EE;FD@9&EZ:6X@:>=I;B!B:7(@860@
M9VER:6XZ`$S\=&9E;B!Y96YI(&%D_2!G:7)I;CH`3/QT9F5N(%!'4"#V>F5L
M(&%N86AT87+];OUZ(&GG:6X@9V7G:?X@=/QM8V5C:?!I;FD@9VER:6XN0G4@
M9V7G:?X@=/QM8V5C:?!I;FD@:&5R("5S(&]T=7)U;2!IYVEN(&=I<FUE;FEZ
M(&=E<F5K96-E:W1I<BX`3/QT9F5N(%,O34E-12#V>F5L(&%N86AT87+];OUZ
M(&GG:6X@9V7G:?X@=/QM8V5C:?!I;FD@9VER:6XN0G4@9V7G:?X@=/QM8V5C
M:?!I;FD@:&5R("5S(&]T=7)U;2!IYVEN(&=I<FUE;FEZ(&=E<F5K96-E:W1I
M<BX`3/QT9F5N('EE;FED96X@9VER:?X@>6%P_6X@=F4@>65N:2!I;&5T:2!O
M;'7^='5R;6%Y82!D979A;2!E9&EN+D7P97(@YV5R97H@2U5,3$%.34E93U)3
M04Y)6B!V92!Y96YI(&EL971I;FEZ:2!B96QI<F5N('!E;F-E<F5D92!O;'7^
M='5R=7EO<G-A;OUZ+"!Y96YI9&5N(&%N82!P96YC97)E>64@9&4@9VER:?X@
M>6%P;6%N_7H@9V5R96ME8V5K=&ER+D)U+"!S86QD_7)G86YL87+];B!O='5R
M=6T@:VEM;&EK(&YU;6%R86[]>OT@96QE(&=EYVER;65S:6YI(/9N;&5M96L@
M:>=I;F1I<BY286AA='/]>FS]:R!IYVEN(/9Z_'(@9&EL97)I>BX`3/QT9F5N
M('-O<G5N=6X@8FER(/9Z971I;FD@>6%P_6XN`$S\=&9E;B!P87)O;&%N_7K]
M(&=I<FEN+@!,_'1F96X@:W5L;&%N_6/](&%D_2!V92!P87)O;&%N_7K](&=I
M<FEN`$S\=&9E;B!K=6QL86[]8_T@863];OUZ_2!G:7)I;BX`3/QT9F5N(&=E
MYV5R<VEZ('EA9&$@8F5L:7)S:7H@861R97-L97)I(.?V>OQN+@!,_'1F96X@
M=&%K:7`@961E;B!B:6QG:7EI(&?V>F1E;B!G9>=I<FEN+"!A<F3];F1A;B!A
M_F'P_61A:VD@;65N_&1E;B!B:7(@97EL96T@<V7G:6XN`$S\=&9E;B!H97)H
M86YG:2!B:7(@97EL96T@9V5RYV5K;&7^=&ER;65D96X@]FYC92!B:7(@9&EZ
M:6X@<V7G:6XN(`!,_'1F96X@8?YA\/UD86MI(&UE;OQD96X@8FER(&5Y;&5M
M('-EYVEN+@!,_'1F96X@87)A;6$@:>=I;B!E;B!A>B!B:7(@9&EZ:6X@<V7G
M:6XN`$S\=&9E;B!B=2!I_FQE;2!IYVEN('-A9&5C92!B:7(@9&EZ:6X@<V7G
M:6XN`$S\=&9E;B!K=71U;G5N(&GG:6YD96X@<V'P82!D;_!R=2!S9>=I;2!Y
M861A(&3\>F5N;&5M92!Y87#];CH`3/QT9F5N('EE;FD@:V%T96=O<FEN:2!A
M9/T@9VER:6XZ`%!O;&]N>6$`4&]L:71I:V$`3WEL86UA;&%R`%!O<G1E:VEZ
M`$?V<OQN=/P@:V]N=6UL86YD_7+];/UY;W(`QVEZ96QG92!K;VYU;6QA;F3]
M<OUL_7EO<@!"=2!D:7II;F4@9_9N9&5R("A)34%0('1A<F%F_6YD86X@>F]R
M;&%N;6%M86MT863]<BD`2&]R9&4@1&5S:W1E:VQI`-UM>F%N_7H@]FYC97-I
M;F1E(&ME<VEK;&D@YVEZ9VD@*"<M+2<I(&)U;'5N<W5N(&UU/P!3;VX@)7,@
M<V%A='1E(&3\_F5N('EA\&UU<B!V92!K87(@;6EK=&%R_3H`5&5R8VEH;&5R
M:6YI>B!B8?YA<OUY;&$@9_QN8V5L;&5N9&DN`%!R969S7VQD87`Z(-US=&5N
M96X@3$1!4"!U>F%N=/US_2!B=6QU;F%M863]+@!0<F5F<U]S97-S:6]N.B#=
M<W1E;F5N(&]T=7)U;2!U>F%N=/US_2!B=6QU;F%M863]+@!"87/];N<`1&5N
M:7H@<V5V:7EE<VEN9&5K:2!B87/];N<Z`$)A<_UNYSH`UFYI>FQE;64`1_9R
M_&YT_'G\('EE;FD@<&5N8V5R961E(/9N:7IL90#6;F-E:VD@W6QE=&D`UFYC
M96MI(%-A>69A`-9N8V5K:2!S9>=E;F5K;&5R`%EA>F3]<@!"96QG97EI('EA
M>F3]<@#6;F-E;&EK`-9Z96P@06YA:'1A<@#6>F5L($%N86AT87(@4&%R;VQA
M<_T`4V]R=6X`4V]R=6X@5&%N_6UL86UA<_T`4')O:F5L97(`2&5R(&5K(&?V
M;F1E<FEL:7)K96X@<V]R.R#V;G1A;OUM;/T@9&7P97(@2$%925(`2&5R(&5K
M(&?V;F1E<FEL:7)K96X@<V]R.R#V;G1A;OUM;/T@9&7P97(@159%5`!-971I
M;B!B:6QG:2!I<W1E;6D`W6QE=&G^:6T@2W5R86QL87+].@!!Y_UK($%N86AT
M87(`0>?]:R!!;F%H=&%R(&%L9V]R:71M87/]`$'G_6L@4$=0(&%N86AT87(@
M<W5N=6-U<W4@9&5S=&7P:2!S9>=I;&5M97H@:_UL_6YD_2X`0>?]:R_6>F5L
M(&%N86AT87(@:6MI;&ES:2!B8?YA<OUY;&$@>6%R873];&%M863]+@!0;W)T
M;R!2:6MO`%-I;&EN96-E:VQE<FD@7U1E;6EZ;&4`4VEL:6YE8V5K;&5R:2!4
M96UI>FQE`$1I>FEN*&QE<BEI(%1E;6EZ;&4`Q_9P($MU='5S=2!T96UI>FQE
M;64@<_UK;/WP_3H`0G4@:V%D87(@9_QN9&5N(&1A:&$@97-K:2#G]G`@:W5T
M=7-U;F1A:VD@:6QE=&EL97)I('1E;6EZ;&4N`,?V<"!K=71U<W5N9&%K:2!E
M<VMI(&EL971I;&5R('1E;6EZ;&5N<VEN(&UI/P!+871A<@!3;W)G=0!+;W1A
M($1U<G5M=3H@)2XR9DU"("\@)2XR9DU"("@E+C)F)24I`$MO=&$@1'5R=6UU
M.B`E+C)F34(@+R!324Y)4E-)6@!+;W1A($1U<G5M=3H@4TE.25)325H`2V]T
M82`E9@!24T$@0>?]:R!!;F%H=&%R_2`H)60@8FET*0!2861Y;R!39>=I;6D`
M66'P;75R`$5R:V5N(%-A871L97)D92!98?!M=7(`1V7G(%-A871L97)D92!9
M8?!M=7(`4V'P86YA:R!98?#]_@!98?!M=7(@=F4@2V%R`$MA<F$@9/9N_/YE
M8V5K('EA\&UU<@!287-T9V5L92!$97EI_@!/<F%N`%1E7W-L:6T@3VYA>6D@
MW7-T90!/:W5M80#=;&5T:6QE<FD@3VMU`%-I;&UE:R!I<W1E9&GP:6YI>F4@
M9V5RYV5K=&5N(&5M:6X@;6ES:6YI>C\H0G4@:?YL96T@9V5R:2#G979R:6QE
M;65Z*3HE<P!+=6QL86[]8_T@)7,@92!A:70@:W5L;&%N_6/]('9E<FEL97)I
M;FD@<VEL;65K(&ES=&5D:?!I;FEZ92!E;6EN(&UI<VEN:7HN($)U(&G^;&5M
M(&=E<FD@YV5V<FEL96UE>BX`5&%R:6AI;F1E($=E;&5N`%1A<FEH:6YD96X@
M4V]N<F$@1V5L96X`5&%R:6AI;F4@2V%D87(@1V5L96X`6?9N;&5N7V1I<@!9
M]FYL96YD:7(`26QE=&EY:2!9]FYL97)D:7(`0G4@:6QE=&EY:2!Y]FYL96YD
M:7(`6?9N;&5N9&ER;64@8F'^87+]<_UZ(&]L9'4N`%-O;B!E>6QE;6D@=&5K
M<F%R;&$`665N:6QE`$1E=FEN9V5N($UE;OP@UO!E;&5R:6YI(%1A>F5L93H`
M1&EZ:6YI($?V<OQN_&UL97)I;FD@665N:6QE.@!0;W)T86P@1_9R_&[\;?QN
M_"!487IE;&4Z`$3\>F5N;&D@W69A9&4`W6QI_FMI(%1A<F%Y_6/]`%EE;FED
M96X@6?QK;&4`1_9R_&[\;?P@665N:61E;B!9_&ML90!!Y_UK;&%M86QA<@!3
M97)B97-T+TUE_F=U;"!B:6QG:7EI(&AA=/UR;&$N`%-O;B!G]G+\;OQM_"!H
M873]<FQA`%5Z86MT86MI(%!O<W1A($MU='5S=3H`57IA:W1A:VD@4W5N=6-U
M;&%R`%5Z86MT86MI(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ`%-I;`#68F7P:2!3:6P`06QA;OT@07)A;6%D86X@Q_UK87(`2V]L;VYU
M(%-I;`!":>=I;6QE;65Y:2!3:6P`26MI;&EY:2!3:6P`2V%Y9&5D:6QM:?X@
M8F5T:?!I('-U;G5C=6YU(&=EYVEC:2!D:7II;FEN9&5N('-I;"X`2V%Y;F'P
M_2#G_6MA<@!3:6P`0G4@<&%RYV%Y_2!B96QG961E;B#G_6MA<G0`2W5L;&%N
M_6/](%-I;`!+=6QL86[]8_UY_2!S:6PZ("5S`$1I>FEN:2!996YI9&5N($%D
M;&%N9/UR`$?V;F1E<FEL;6G^+7!O<W1A(&1I>FEN:2!A>?UN(&)A_OUN9&$@
M>65N:61E;B!A9&QA;F3]<OUL<_UN(&W]/P`B)7,B("(E<R(@;VQA<F%K('EE
M;FED96X@861L86YD_7+];&UA<_T@8F'^87+]<_UZ(&]L9'4N4W5N=6-U;G5N
M(&)E;&ER='1I\&D@8G5D=7(@`%],:7-T97EI(%EA;OUT;&$`665R:6YE($MO
M>3H`66%N_71L80!986[]="!']FYD97)I;&1I+@!(97)K97-E(%EA;OUT;&$`
M2&5R:V5S92!986[]=&QA.@!,:7-T97EE(%EA;OUT;&$`3&ES=&5Y92!986[]
M=&QA.@!(95]R:V5S92!986[]=&QA`$1E<W1E:VQE;FUE>65N(-UL971I(&EL
M92!986[]=&QA`$=E;&5C96L@,B!A>2!IYVEN('-E<F)E<W0O;67^9W5L(&EL
M92!Y86[]=&QA+@#=<W1E;F5N('-E<F)E<W0O;67^9W5L(&)I;&=I<VD@:6QE
M('EA;OUT;&$N`%EA;OUT+4%D<F5S:0!986[]="!!9')E<VDZ`%EA;OUT;&$Z
M`%1E;6EZ($]L87)A:R!287!O<B!%=`#=<W1E;FUE>65N(-UL971I($]L87)A
M:R!287!O<B!%=`!/:W5N;6$@7T)I;&=I<VD@W7-T90#=<W1E:R!C979A<&QA
M;F%M863]+D3V;OQL96X@:&%T82!K;V1U.B``5&5S;&EM($)I7VQG:7-I(-US
M=&4`3VMU;F1U(&%L_6YD_7/](&ES=&5N<VEN(&UI/P#=<W1E;F5N(&EL971I
M(&)U;'5N86UA9/TN`$=E<F5K96X@06QA;@!'97)E:V5N($MA=/UL_6UC_0!4
M96UI>FQE`%!A<F]L87G]('/]9OUR;&$`4&%R;VQA;OUZ_2!S_6;]<FQA>?UN
M`$MA<O[];/UK($=E;&5N($1U<G5M($?\;F-E;&QE;F1I+@!3;VYUYVQA<@!$
M979A;2!%=`!/='5R=6UU;G5Z82!D979A;2!E9&EN`%!O<W1A($=E=&ER;65Y
M92!$]F[\;@!39>=E;F5K;&5R92!$]F[\;@#=;&5T:6YI;B!S:6QI;FUE<VEN
M9&5N+'1A_OUN;6%S_6YD86X@=F5Y82!K;W!Y86QA;FUA<_UN9&%N('-O;G)A
M('!O<W1A(&MU='5S=2!L:7-T97-I;F4@9/9N_&QS_&X@;?P_`%)E=6YI;VX`
M66%P_6QA;F3]<FUA>?T@1V5R:2!$]FYD_'(`6F5N9VEN($UE=&EN($3\>F5N
M;&5Y:6-I<VD@4V7G96YE:VQE<FD`0FEL;65C96QE<@!38?``4V'P(&)A_FS]
M:R!B:6QG:7-I`$1O\')U(&1E\&5R;&5R`%-A7W3]<B#6>F5L;&EK;&5R:2XN
M+@!']G)E=@!2;VUA;GEA`#$X,"!D97)E8V4@9/9N9/QR`%-O;&$@1/9N9/QR
M`%-A\&$@1/9N9/QR`%-A=/UR(-9Z96QL:6ML97)I`%-A=/UR(/9Z96QL:6ML
M97)I`%-A=/UR;&%R.@#':7IG:6QE<@#':7IG:6QE<B!T_&T@<V%T_7(@=F4@
M:V]L;VYL87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER`,=I>F=I;&5R('-A9&5C
M92!K;VQO;FQA<B!A<F%S_6YD82!B96QI<F5C96MT:7(`QVEZ9VEL97(@<V%D
M96-E('-A=/UR;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<@#'86S]_G3]<@!2
M=7-Y82!&961E<F%S>6]N=0!2=6%N9&$`4R]-24U%`%,O34E-12#>:69R96QE
M;64@W6UZ87/]`%,O34E-12#>:69R96QE;FUI_B#=;&5T:0!3+TU)344@:6QE
M(-YI9G)E;&5N;6G^(-UL971I`%,O34E-12!(871A<_TZ`%,O34E-12!(871A
M<_TZ($MI_FES96P@]GIE;"!A;F%H=&%R(&GG:6X@9V7G:?X@=/QM8V5C:?!I
M(&=E<F5K:7EO<BX`4R]-24U%(%-EYV5N96ML97)I`%,O34E-12!'9>=I_B!4
M_&UC96-I\&D@1VER:?YI`%,O34E-12!+:?YI<V5L($%N86AT87(@W6MI;&ES
M:2!D97-T9?!I(&?\=F5N;&D@8FER('=E8B!B8?!L86YT_7/](&ES=&5M96MT
M961I<BX`(B5S(B!IYVEN(%,O34E-12!!Y_UK($%N86AT87+](&)A_F%R_7EL
M82!S:6QI;F1I+B``4R]-24U%($'G_6L@06YA:'1A<OT@8F'^87+]>6QA(&5K
M;&5N9&DN`%,O34E-12!!Y_UK($%N86AT87(@6FEN8VER:0!3+TU)344@0>?]
M:R_6>F5L($%N86AT87(@W6MI;&ES:2!B8?YA<OUY;&$@96ML96YD:2X`4R]-
M24U%(-UM>F$@365S86K]`%,O34E-12!);7IA+]YI9G)E($UE<V%J_0!3+TU)
M344@9&5S=&7P:2!B=2!S:7-T96UD92!S9>=I;&5M97H@:_UL_6YM_?YT_7(N
M`%,O34E-12!D97-T9?!I('G\<OQR;/QK=&4@9&7P:6P@8G4@;F5D96YL92!I
M;&5T:6YI;B#^:69R97-I;FEN(.?V>OQL;65S:2!O;&%N86MS_7HN`%,O34E-
M12!D97-T9?!I('G\<OQR;/QK=&4@9&7P:6P@8G4@;F5D96YL92!I;7IA;&%N
M;?W^(&EL971I(&?V<OQN=/QL96YE;65Y8V5K=&ER+@!3+TU)344@9&5S=&7P
M:2!Y_'+\<FS\:W1E(&1E\&EL(&)U(&YE9&5N;&4@<V%Y_7-A;"!I;7IA;OUN
M(&1O\')U;&%N;6%S_2!O;&%N86MS_7HN`%-!4TP@9&_P<G5L86UA<_T@;65V
M8W5T(&1E\&EL+@!335,@365S86IL8?YM80!344P@2V%B=?!U`%-32`!"0=Y!
M4DE,20!37U%,($MA8G7P=0!+;U]N=0!#=',`2V]P>6%S:6YI(&MA7WED970`
M7T9A<FML_2!+87ED970`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S('9E($YE
M=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!V92!-:7%U96QO;@!386EN
M="!6:6YC96YT('9E($=R96YA9&EN97,`07EN_2#G97+G979E("AK96Y?9&ES
M:2D`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!V92!0<FEN8VEP90!5>61U
M(%-A\&QA>?UC_0!3=75D:2!!<F%B:7-T86X`2V%Y9&5T`$MA>61E="`E<P!%
M:VQE<BP@:6QE=&D@:6QE(&)I<FQI:W1E(&?V;F1E<FEL;6G^('!O<W1A(&1I
M>FEN:6YE(&MA>61E9&EL<VEN(&UI/P!487-L86L@2V%Y9&5T`%-EYV5N96ML
M97)I($MA>61E=`!?5&%S;&%K($MA>61E=`!&87)K;/T@2V%Y9&5T`%1A<VQA
M:VQA<B!G]G+\;&UE;6G^(&]L87)A:R!K87ED961I;'-I;B!M:3\@`$]L=?YT
M=7)U;&%N('EA</UL86YD_7)M87G](%!(4"!B971I\&D@;VQA<F%K('-U;G5C
M=6YU;B!G9>=I8VD@9&EZ:6YI;F4@:V%Y9&5T+@!!;/UC_6QA<B#V>F1E=FEN
M:6UL:2!O;&%R86L@=F%R<V%Y_6QA;B!A9')E<R!D969T97)I;F4@:V%Y9&5D
M:6QS:6X@;6D_`$%R86UA>?T@<V%N86P@9&EZ:6X@;VQA<F%K('-A:VQA`$?V
M;F1E<FEL;6G^('!O<W1A(&MA>61E9&EL<VEN(&UI/P`E<R!Y87#];&%N9/UR
M;6%S_2!K87ED961I;&1I+@!487-L8?#];B!K87ED961I;&UE<VD@8F'^87+]
M<_UZ(&]L9'4N(%-U;G5C=3H@)7,`0FEL:6T`07)A;6$`07)A.B`E<P!!<F%M
M82!-;W1O<FQA<OT`07)A;6$@4V]N=>=L87+]`$]K=6YM=?X`4V7G`$)A_FMA
M($)I<B!(97-A<"!39><`1&]S>6%L87+](%-EYP!":7(@5&%R:6@@4V7G:6X`
M0FER($%L86X@4V7G:6X`16ML96UE:R!IYVEN(&)I<B!G<G5P('-EYVEN`%EE
M;FD@<V%H:6)I('-EYVEN`$)I<B!S=6YU8W4@<V7G:6X`16ML96UE:R!IYVEN
M(&)I<B!K=6QL86[]8_T@<V7G:6X`061R97,@96ML96UE('9E(&%R86UA(&GG
M:6X@861R97,@9&5F=&5R:2!K87EN86ML87+];OT@<V7G:6XN`$AE<'-I`$+\
M=/QN('1A<FEH(&)I;&7^96YL97)I;FD@<V7G:6X`061R97-L97)I(&=E;FG^
M;&5T:7)K96X@87)A;6$@:>=I;B!B_'3\;B!A;&%N;&%R_2!S9><N`$)I<B!H
M97-A<"!S9>=I;@!":7(@;F5S;F4@<V7G:6X`2&GG8FER:0#=<W1E9&GP;FEZ
M(&MA<F%K=&5R;&5R:2!A_F'P_61A:VD@:W5T=6QA<F1A;B!S9>=I;BX@1&%H
M82!S;VYR82!M971I;B!A;&%N_6YD86X@:V]P>6%L87G]<"!Y87#]_G3]<F%B
M:6QI<G-I;FEZ+@!487)I:"!S_6[]<FQA>?UC_7/];OT@<V7G_6XZ`%1A<FEH
M(&)IYVEM:6YI('-EYVEN.@!$9?!I_G1I<FUE:R!I<W1E9&GP:6YI>B!K:6UL
M:?!I('-EYVEN.@!0;W-T82!S=6YU8W5S=2!T_'+\;OP@<V7G:6X`4V%A="!S
M_6[]<FQA>?UC_7/];OT@<V7G:6XZ`%-A870@8FGG:6UI;FD@<V7G:6XZ`$7^
M;&7^96X@:6MI(&%L86[]('-EYVEN+@!296YK(&3\>F5N:6YI>FD@<V7G:6XN
M`%1E<F-I:"!E='1I\&EN:7H@9&EL:2!S9>=I;CH`4V7G:6QM:?X@061R97,@
M1&5F=&5R;&5R:3H`06YA:'1A<OT@0>?]:R!!;F%H=&%R(%-U;G5C=7-U;F$@
M1_9N9&5R`%-O;B!":6QG:6QE<FD@1_9N9&5R`-UL971I($?V;F1E<@!3;W)U
M;B!287!O<G4@1_9N9&5R`%--4R!']FYD97(`4V5N96=A;`!!;&?];&%Y_6/]
M.@!']FYD97)I;&UI_B!P;W-T82!D:7II;FD`1_9N9&5R:6QM:?X@<&]S=&$@
M9&EZ:6YI.@!%>6S\;`!3_7)B:7-T86X@=F4@36]N=&5N96=R;P!397)I($YU
M;6%R87/]`%-U;G5C=0!3=6YU8W4@=F4@1&EZ:6X@0FEL9VEL97)I`%-U;G5C
M=3H`3W1U<G5M(&MI;6QI\&EN:6X@<_QR97-I(&1O;&1U+@!"96QI<G0`4&%R
M;VQA;OUZ_6[]('5N=71U<G-A;OUZ('/]9OUR;&%M86[]>F$@:7II;B!V97)E
M8V5K('-EYV5N96ML97)I(&)E;&ER=&EN+B``W6QE=&EL97)I('1A_OUM86[]
M>B!Y861A('-I;&UE;FEZ(&1U<G5M=6YD86MI('1E<F-I:&QE<FEN:7II(&)E
M;&ER;&5Y:6X`W6QE=&D@;VQU_G1U<G5R:V5N(%@M4')I;W)I='D@8F'^;/WP
M_2!K;VYS=6X@;74_`%5L8?YM86L@:7-T9?!I;FEZ('5Z86MT86MI('-U;G5C
M=6QA<OT@8F5L:7)L97EI;BX`5&5R8VEH(&5T=&GP:6YI>B!D:6PL('-A870@
M9&EL:6UI('9E('1A<FEH('-EYV5N96ML97)I;FD@8F5L:7)L97EI;BX`0F'^
M;&%N9_WG('5Y9W5L86UA;OUZ_2P@<F5N:R!D_'IE;FEN:7II+"!S87EF82!T
M87IE;&5M92P@=F4@9&GP97(@9_9R_&YT_"!S9>=E;F5K;&5R:6YI(&)E;&ER
M;&5Y:6XN`$%Y87)L87(`2W5R=6QU;2!G_&YC96QL96UE(&)E=&EK;&5R:2!K
M=6QL86[];&%B:6QI<B!D=7)U;61A+@!$9?!I_G1I<F=E(&EL92!B:7)D96X@
M9F%Z;&$@>65R(&W\;6O\;CH@`%-E>?YE;`!087EL8?[];2!$:7II;FQE<FD`
M4&%Y;&'^_6QA;B!P;W-T82!D:7II;FQE<FD`1&GP97(@:W5L;&%N_6/];&%R
M;&$@<&]S=&$@9&EZ:6YL97)I;FD@<&%Y;&'^+@!!;/W^('9E<FG^`$O]<V$@
MUGIE=`#';_!U(&)A\&QA;G3](&GG:6X@97)I_FEM(&%N86AT87+]('1A;OUM
M;&%N<_UN(&W]/P!"_'G\:R#V8F5K;&D@86S];G3]('EA</UL;?W^('-A=/UR
M;&%R(/9N=&%N_6UL_2!O;&%R86L@9_9S=&5R:6QS:6X@>6%D82!G:7IL96YS
M:6X@;6D_+DAA;F=I<VD@<V7G:6QI<G-E('-EYVEL<VEN(&1I\&5R:6YE(&MO
M;&%Y;/UK;&$@9V7G:6QE8FEL:7(N`$3\>B!M971I;B!I;&5T:6QE<FEN(&GG
M97)I\&D@4$=0('9E<FES:2!IYVEN('1A<F%N<_UN(&W]/P!":7(@=&%S;&%K
M(&MA>61E9&EL9&EK=&5N('-O;G)A(&]L=?YT=7)M82!P96YC97)E<VD@:V%P
M86YS_6X@;?T_`%9A<G-A>?UL86X@;VQA<F%K(%!'4"!AY_UK(&%N86AT87+]
M(&EL971I;FEZ92!E:VQE;G-I;B!M:3\`1_9S=&5R`$+\=/QN($1I>FEN;&5R
M:2!']G-T97(`0OQT_&X@0F'^;/UK($)I;&=I<VEN:2!']G-T97(`4VEL:6YE
M8V5K;&5R:2!']G-T97(`4_UN_7)L86YM_?X@0F'^;/UK($)I;&=I<VEN:2!'
M]G-T97(`16QE:W1R;VYI:R!0;W-T82!,:7-T92!":6QG:7-I;FD@1_9S=&5R
M`%-A9&5C92#<>64@3VQU;FUU_B!$:7II;FQE<FD@1_9S=&5R`-QY92!/;'5N
M;6%M_?YL87+]($?V<W1E<@#=;&5T:6QE<F1E;B!E:VQE<FD@86QM87EA(&EZ
M:6X@=F5R;65K(&GG:6X@8FER('-I;6=E(&?V<W1E<FEL<VEN(&UI/P!(86QE
M;B!K87G]=&S](&]L86X@>6%P_6QA;F3]<FUA(&EL92!Y96YI('EA<F%T_6QA
M;B!Y87#];&%N9/UR;6$@87)A<_UN9&%K:2!F87)K;&%R_2!G]G-T97(N`$=I
M<FG^=&4@96X@<V]N(&=I<FG^('1A<FEH:2!G]G-T97)I;'-I;B!M:3\`4&]S
M=&$@:W5T=7-U(&?V<OQN=/QS_&YD92!G]G-T97)G92!B=6QU;G-U;B!M=3\`
MUGIG_&X@;VQA;OT@<V%K;&%M82!S9>=E;F7P:6YI(&?V<W1E<@!39>=I8VEY
M:2!G]G-T97(`4V%D96-E(&]K=6YM86W]_B!I;&5T:6QE<B!IYVEN(&UI(/9N
M:7IL96UE(&?V<W1E<FEL<VEN/P!!<F'G(&EP=>=L87+];F1A(/9N:7IL96UE
M(&?V<W1E<FEL<VEN(&UI/P#':7IE;&=E(&G^;&5M;&5R:2!M96[\(.=U8G7P
M=6YD82!G]G-T97)I;'-I;B!M:3\`)7,@365N_'/\('-O;&1A(&?V<W1E<FEL
M<VEN(&UI/P!-96[\(.=U8G7P=6YD82!0;W-T82!'971I<B!S:6UG97-I(&?V
M<W1E<FEL<VEN(&UI/P!']G+\;G3\;&5R:2!']G-T97(`5&%B;&\@2/QC<F4@
MUGIE;&QI:VQE<FD@2W5T=7-U;G4@9_9S=&5R`%1A8FQO(-9Z96QL:6ML97)I
M($MU='5S=6YU(&?V<W1E<@!486)L;R!3873]<B#6>F5L;&EK;&5R:2!+=71U
M<W5N=2!G]G-T97(`365N_"#G=6)U\'5N9&$@<_QZ9V7G('-I;6=E<VD@9_9S
M=&5R:6QS:6X@;6D_`$?V<OQN=/P@]GIE;&QI:VQE<FD@:W5T=7-U;G4@9_9S
M=&5R`$1I>FEN9&5K:2!T;W!L86T@<&]S=&$@<V%Y_7/](&?V<W1E<FEL<VEN
M(&UI/P!9_&ML96UE>6D@9_9S=&5R`%-A\&%N86L`17)K96X@4V%A=&QE<F1E
M(%-A\&%N86L`1V7G(%-A871L97)D92!38?!A;F%K`,=E=G)E9&4@4V'P86YA
M:P!']G-T97)I;&5N`$O\Y_QL=`#=;&L@;VQA<F%K(&MO;?YU(/;P96QE<B!K
M_.?\;'1S_&X@>6%D82!T8?[];G/];@!";U]Y=70`4VEE<G)A($QE;VYE`-QY
M92!O;`#=;7IA`-UM>F$@06QG;W)I=&UA<_T`W'EE(&]L9'5N=7HN`%-I;F=A
M<'5R`$)O>75T`$)A:_UM_2!!=&QA`%-L;W9A:WEA`%-L;W9E;GEA`$MA<@!+
M87(@4V'P86YA\/T`2V%R(%-A\&%N86ML87+]`$5R:V5N(%-A871L97)D92!+
M87(@4V'P86YA:VQA<OT`1V7G(%-A871L97)D92!+87(@4V'P86YA:VQA<OT`
M2V%R($1E<FEN;&GP:3H@`%EA\&%N(&MA<OUN('-U(&7^:71I.B``4V]L;VUO
M;B!!9&%L87+]`%-O;6%L:0#>87)K_6QA<B`F(-YI:7)L97(`1V5L:?X@6F%M
M86[];F$@1_9R92!3_7)A;&$`5&%R:6AE($?V<F4@4_UR86QA`$=E;&5N($%D
M<F5S92!']G)E(%/]<F%L80!);&5T:2!";WEU='5N82!']G)E(%/]<F%L80!+
M;VYU>6$@1_9R92!3_7)A;&$`2V]N=2#68F7P:6YE($?V<F4@4_UR86QA`$%D
M<F5S92!']G)E(%/]<F%L80!3_7)A;&%M82!D_'IE;FD@<V7G:6UI`$MA>6YA
M:R!A9')E<VD`1_QN97D@069R:6MA`$?\;F5Y($%V<G5P82`H25-/+3@X-3DM
M,RD`1_QN97D@1V5O<F=I82!V92!'_&YE>2!386YD=VEC:"!!9&%L87+]`$?\
M;F5Y(%EA<OUM:_QR90!":71I_FEK(&C\8W)E;&5R(&%R87/];F1A:VD@8F_^
M;'5K`$C\8W)E9&5K:2!S_6[]<B!V92!IYV5R:6L@87)A<_UN9&%K:2!B;_YL
M=6L`0F_^;'5K($%Y87)L87G]8_T`07)A;/UK(&+]<F%K;6$`07)A;/UK(&+]
M<F%K;6$@=F4@>6%S=/UK;&%M80#=<W!A;GEA`-US=&5N;65Y96X@W6QE=&D`
MW7-T96YM97EE;B!I;&5T:2!D:7II;FDZ`-9Z96P@2V%R86MT97(@1VER:?YI
M`-9Z96P@2V%R86MT97)L97(`66%Z_6T@1&5N971I;6D`66%Z_6T@1&5N973G
M:7-I`%EA>OUM(&1E;F5T:6UI('1A;6%M;&%N9/T`66%Z_6T@9&5N971I;6ES
M:2!S_7)A<_UN9&%K:2!E:W)A;B!B8?[];F$@9/S^96X@>6%Z_6T@:&%T86QA
M<OT`2/QC<F5Y:2!B]FP`2V]L;VYU(&+V;`!3873]<OT@8O9L`%-P;W)L87(`
M4W)I($QA;FMA`%-T86YD87)T`%5Z87D@66]L=0!"8?YL870`0F'^;&%N9_WG
M('G];/T`17EA;&5T('9E>6$@W6P`1'5R=6T`1&5P;VQA;6$@8FGG:6UI`%-O
M:V%K($%D<F5S:0#<<W3\(.=I>F=I;&D`1&EZ9VD@;&ES=&5S:0!%:VQE<FD@
MQ_UK87)T`$%D<F5S=&5N(&%L86X@863];OT@Y_UK87)T`%-A=/UR(%-O;FQA
M<OUN_2#'_6MA<G0`4VET:6P@6T-34UT`4'IR`$MO;E]U`$MO;G4`2V]N=2!!
M;&%N_0!']FYD97(`1&EZ:6YE(/QY92!O;`!!;'1S:6UG90!"8?YA<OT`66%P
M_6QA;F3]<FUA(&)A_F%R_7EL82!G97)I(&3V;F3\<OQL9/PN($1E\&G^:6ML
M:6ML97)I(&?V<FUE:R!IYVEN('EE;FED96X@>?QK;&5Y:6XN`%EE9&5K('EA
M</UL86YD_7)M82!B8?YA<OUY;&$@:V%Y9&5D:6QD:2X`665D96L@>6%P_6QA
M;F3]<FUA(&1O<WEA<_T@)7,@8F'^87+]>6QA(&MA>61E9&EL9&DN`"5S(&)A
M_F%R_7EL82!Y87K];&3]+@!3=61A;@#6;F5R:6QE<@#6>F5T`$?\;B!$;_!U
M;74`1_QN(&)A=/UM_0!'_&YE_FQI`$?\;B!D;_!U;74`1_QN(&1O\'5M=2]'
M_&X@8F%T_6W]`$?\;B!D;_!U;74Z(`!'_&X@8F%T_6W]`$?\;B!B873];?TZ
M(`#<<W1S:6UG90!$97-T96L`4W5R:6YA;0!3;WEA9/T`4W9A;&)A<F0@=F4@
M2F%N($UA>65N`%-V87II;&%N9`#=<W9EYP!/;'7^='5R;6$@6?9N=&5M:6YI
M($1E\&G^=&ER`$A434P@3VQA<F%K($]L=?YT=7)M87EA($=EYP!3861E($UE
M=&EN($]L87)A:R!/;'7^='5R;6%Y82!'9><`W7-V:>=R90!!<F%M82!T97)I
M;6QE<FEN9&4@<_9Z9&EZ:6T@:&%T87/]`%-U<FEY90!']FL@9_QR_&QT_&S\
M(&;]<G3];F$`1_9K(&?\<OQL=/QL_"!F_7)T_6YA;&%R`%135B!D;W-Y87/]
M`,=I>F5L9V4`QTEZ96QG92#6>F5L;&EK;&5R:0#':7IE;&=E(/9Z96QL:6ML
M97)I`%1A>79A;@!487EV86XL(,=I;B!E>6%L971I`%1A8VEK:7-T86X`5&%N
M>F%N>6$`2&5D968Z`$?V<F5V;&5R`$U?971I;@!496QE9F]N($YU;6%R87/]
M`%-O;B!S86%T(&GG:6X@<_UC86ML_6LZ(`!3_6-A:VS]:P!3_6-A:VS]:SH@
M`%1A<VQA:R!9]FYE=&EM:0!'9>=I8VDZ`-US=&7P:2!G9>=I8VD@;VQA<F%K
M(&MA8G5L(&5T`$=EYVEC:2!O;&%R86L@:V%B=6P@961I;&1I`$AI>FUE="!+
M;_YU;&QA<OT@9&]S>6%S_2!C;VYF+G!H<"!D;W-Y87/];F1A(&)E;&ER=&EL
M;65M:?X`4V%D96-E($UE=&EN`$UE=&EN(&AI>F%L86UA<_T`365T;FEN(-QS
M=/P`4'+^`%1A:2`H5$E3+38R,"D`5&%Y;&%N9`!3:7-T96UI(&MU;&QA;OUD
M_?#];OUZ(&GG:6X@=&7^96MK_'(@961E<FEZ+@!&5%`@=7IA;G3]<_T@:W5L
M;&%N_6QA8FEL:7(@9'5R=6UD82!D9?!I;"X`W6QE=&EN:6X@2VEM9&5N.B!K
M;VQO;G4@8F'P;&%N;6%L_3H`2&]R9&4O2V]L86(@8OQT_&YL9?YT:7)M92!M
M;W1O<G4@9&5S=&5K;&5M96UE:W1E9&ER.B`B)7,B`$UA8VEN=&]S:"!D;W-Y
M87/];OUN(&MA>6YA:R!K_7-M_0!-86-I;G1O<V@@9&]S>6%S_6[];B!K87EN
M86L@:_US;?T@>?QK;&5N96)I;&ER.B`E<P!"86O];3HZ('/];OUF(&)A_F%R
M_7EL82!Y_&ML96YE;65D:2X`WF7G96YE:VQE<B!P96YC97)E<VD@:V%P86YD
M_2['_6O]_B!Y87#];/UY;W(N`"(E<R(@:&5S86+]('-I;&EN9&DN`"(E<R(@
M:&5S86+](&MA>61E9&EL9&DN`$7P97(@:7II;FQE<FD@:W5L;&%N;6%K(&ES
M=&EY;W)S86[]>B!Y]FYE=&EC:6YI>FEN(-UZ:6X@<VES=&5M:6YI('EA</UL
M86YD_7)M87/](&=E<F5K;65K=&5D:7(N`$5K(&)U;'5N86UA9/TN`%-A9&5C
M92!A;'0@=&%R868`5&%K=FEM('9E<FES:2!G9>=E<G-I>BX`3VQU_G1U<FUA
M('!E;F-E<F5S:2!AY_UL86UA9/TN5&%R87G]8_UN_7H@8F5L:7)E;B!P96YC
M97)E;&5R:65N9V5L;&5M97EE(&%Y87)L86YM_?X@;VQA8FEL:7(N`-UL971I
M_FEM(&YO:W1A<_UN_6X@240G<VD@8F5L:7)L96YE;65D:2P@8F_^(&+]<F%K
M_6QM_?X@=F5Y82!V97)I('1A8F%N_6YD82!B=6QU;F%M863]+@#=;&5T:?YI
M;2!N;VMT87/](&)A_F%R_7EL82!A9')E<R!D969T97)I;FEZ92!E:VQE;F1I
M+@!-86-I;G1O<V@@9&]S>6%S_6[];B!IYV5R:?!I(&'^8?#]9&%D_7(N`%G\
M<OQL_&MT96MI("(E<R(@9&EZ:6YI("(E<R(@;VQA<F%K('EE;FED96X@861L
M86YD_7+];&%C86LN`$)U(&1I>FEN92!E<FG^:6UI(&]L86X@:W5L;&%N_6/]
M(&QI<W1E<VD@9V5T:7)I;&5M961I`,?]:V%R=/UL;?W^(%!'4"!I;7IA(/9B
M9?!I(&EM>F%L86YM_?X@:6QE=&EN:6X@9&_P<G5L=?!U;G5N('-A\&QA;FUA
M<_T@:>=I;B!G97)E:VUE:W1E9&ER+@!$8?#]=/UM(&QI<W1E<VD@240G<VD@
M8F5L:7)L96YE;65D:2P@8F_^(&+]<F%K_6QM_?X@=F5Y82!V97)I('1A8F%N
M_6YD82!B=6QU;F%M863]+@!$8?#]=/UM(&QI<W1E<VD@8F5L:7)L96YE;65D
M:2X`5&%S;&%K("(E<R(@9&EZ:6YI;F4@:V%Y9&5D:6QD:2X`WFEF<F5L96UE
M(/9Z96QL:6ML97)I(&?\=F5N;&D@8FER('=E8B!B8?!L86YT_7/](&=E<F5K
M=&ER;65K=&5D:7(N`$]L87D@=&%K=FEM:6YI>F4@96ML96YD:2X`)7,@9&]S
M>6%S_2`E<R!A>6%R_2!IYV5R;65L:61I<BX`)7,@9&]S>6%S_2`E<R!A>6%R
M;&%R_2!IYV5R;65L:61I<BX`1&]S>6$@:V5N9&D@_'IE<FEN92!K;W!Y86QA
M;F%M87HN`$1O<WEA('9E<FD@:>=E<FUI>6]R+@`B)7,B(&1I>FEN:2!Z871E
M;B!V87(N`"(E<R(@9&EZ:6YI(&%D_6YD82!G9>=E<G-I>B!K87)A:W1E<FQE
M<B!IYV5R;65K=&5D:7(N0G4@<')O8FQE;6QE<F4@>6]L(&'G86)I;&ER+DS\
M=&9E;B!S:7-T96T@>?9N971I8VEN:7IL92!G]G+\_OQN+@`B)7,B(&1I>FEN
M:2!Y87)A=/UL9/T@86UA(&1I>FEN92#\>64@9&7P:6QS:6YI>BX`(B5S(B!D
M:7II;FD@<VEL:6YD:2!A;6$@9&EZ:6X@:>=I;B#\>65L:?!E(&1E=F%M(&5D
M:7EO<G-U;G5Z+@`B)7,B(&1I>FEN:2!Y87)A=/UL86UA9/TN(%-U;G5C=2!B
M=6YU(&)E;&ER=&UE:W1E9&ER+@`B)7,B(&1I>FEN:2!S:6QI;F5M961I+E-U
M;G5C=2!B=6YU(&)E;&ER=&UE:W1E9&ER`"(E<R(@9&EZ:6YI(&)A_F%R_7EL
M82!Y87)A=/UL9/TN`"(E<R(@9&EZ:6YI(&)A_F%R_7EL82!S:6QI;F1I+@`B
M)7,B(&1I>FEN:2`B)7,B(&]L87)A:R!B8?YA<OUY;&$@>65N:61E;B!A9&QA
M;F3]<OUL9/TN`%1A:VEP(&5D96YL97(@8G4@:6QE=&DO<F9C.#(R(&EL971I
M<VD@:>=I;B!B8?YL_6L@8FEL9VEL97)I9&ER+@!486MI<"!E9&5N(&1O<WEA
M;&%R(&)U(&O]<VUA(&5K;&5N9&DZ`$'^86UA9/WP_6W]>B!T87)A>?UC_2!H
M871A;&%R_2!S96)E8FEY;&4@=&%M(&5K<F%N(&MI<&EN:6X@26YT97)N970@
M17AP;&]R97(G;&$@8FER;&EK=&4@<V]R=6X@Y_UK87)D_?#](&)I;&EN;65K
M=&5D:7(N($%N;&%M<_UZ(&?V<OQN=/QL97)L92P@YV%L_?YM87EA;B!M971I
M;B!D_'IE;FQE>6EC:2!I_FQE<FEY;&4@=F4O=F5Y82!T87)A>?UC_6[];B!R
M87-T9V5L92#G]FMM97-I>6QE(&MA<O[];&'^86)I;&ER<VEN:7HN($7P97(@
M<VES=&5M:6YI>B!7:6YD;W=S(#EX(&ES92!Y_&MS96L@:6AT:6UA;"`G1V5N
M97)A;"!0<F]T96-T:6]N($9A=6QT)R!H871A<_T@86S]<"!S:7-T96UI('EE
M;FED96X@8F'^;&%T;6%N_7H@9V5R96ME8V5K+EQN7&Y"=2!B:7(@=7EA<OUY
M9/TN($7P97(@:&%L82!T86T@96MR86X@;65T:6X@9/QZ96YL97EI8VES:6YI
M(&1E;F5M96L@:7-T:7EO<G-A;OUZ($5V970G:2!T_6ML87G];BX`2VEM;&EK
M("(E<R(@<VEL:6YD:2X`1_9N9&5R96X@861R97,@9&5F=&5R:6YI>F1E(&MA
M>?UT;/T@;VQD=?!U(&GG:6X@9_9R_&YT_&QE<B!G]G-T97)I;&5C96MT:7(N
M`%-A9&5C92!S;VP@=&%R868`0W)Y<'1?<&=P.CH@<_UN_6;];F$@1VYU4$<@
M:6MI;&ES:6YI;B!K;VYU;74@=F5R:6QM96L@>F]R=6YD863]<BX`16QE:W1R
M;VYI:R!P;W-T82!S=6YU8W5S=2!T86MI<"!E9&5N(&AA=&$@;65S86K];OT@
M_')E='1I.@!%;&5K=')O;FEK('!O<W1A('-U;G5C=2!T86MI<"!E9&5N(&)I
M;&=I(&UE<V%J_6[](/QR971T:3H`16QE:W1R;VYI:R!P;W-T82!S=6YU8W5S
M=2!T86MI<"!E9&5N(&UE<V%J_2#\<F5T=&DZ`"5S('!O<W1A(&MU='5S=2!Z
M871E;B!B;_XN`-UL971I("(E<R(@*"(E<R(@9&5N(&=E;&5N*2`H)60@8GET
M92D@9V5T:7)M92!B;WEU="!L:6UI=&EN:2!A_FUA:W1A9/UR+@!/;'7^='5R
M=6QA;B!I;&5T:2!K87!A=/UL9/TNQ_UK_?X@>6%P_6S]>6]R+@#=;&5T:2!S
M:6QI;F1I+@#=;&5T:2!D;_!R=6QA;F3]+@#=;&5T:2!D;_!R=6QA;F3]+B!'
M]FYD97)E;CH@)7,N`"5S('1A<FEH:6YD92`E<R!E(&?V;F1E<FEL96X@(B5S
M(B!K;VYU;'4@:6QE=&D@9_9R_&YT_&QE;F1I+@I"=2!I;&5T:6YI;B!O:W5N
M9'7P=2!V97EA(&%N;&'^_6QD_?#];OT@9V%R86YT:6QE;65M96MT961I<BX`
M3VQU_G1U<B!P96YC97)E<VEN92!B8?!L86[]<FME;B!K=6QL86[];&%C86L@
M:7-I;0!(;W)D95]#<GEP=%]S:6UE.CH@<_UN_6;](&]P96YS<VP@8FER:6UI
M(&GG:6X@9V5R96MM96MT961I<BX`1V7G:?X@=/QM8V5C:?!I('!E;F-E<F5S
M:2!AY_UL86UA9/TN5&%R87G]8_UN_7H@8F5L:7)E;B!P96YC97)E;&5R:2!E
M;F=E;&QE;65Y92!A>6%R;&%N;?W^(&]L86)I;&ER+@`B)7,B('1E<F-I:&D@
M=F5R:7-I(&EZ:6X@=F5R:6QE;B!E;B!Y_&MS96L@8F]Y=71U(&=EYW1I\&D@
M:>=I;B!K87ED961I;&5M96UE:W1E9&ER+@!"=2!V97)I('EA<'/];OTH)7,I
M(&?V<W1E<FUE:R!IYVEN(&MU;&QA;OUL86X@<')O9W)A;2!S:7-T96UD92!B
M=6QU;FUA;6%K=&%D_7(N`%!'4"!!Y_UK($%N86AT87+];OUN(&AA;2!M971I
M;B!H86QI(&?V<OQL96)I;&ER.B5S`-US=&5N96X@9&]S>6$@35,M5$Y%1B!E
M:VEN9&4@8G5L=6YM86UA:W1A9/UR+@#=<W1E;F5N(&1O<WEA(%II<"!E:VEN
M9&4@8G5L=6YM86UA:W1A9/UR+@!3861E8V4@<V]L('9E('-A\"!T87)A9FQA
M<@!3861E8V4@<V'P('1A<F%F`$)U(&EL971I>6D@9_9N9&5R96X@<VEZ9&5N
M(&EL971I;FEN(&)A_F%R_7EL82!U;&'^=/WP_6[]('9E('-I>FEN(&]K=?!U
M;G5Z=2!B:6QD:7)E;B!B:7(@=7EA<OT@9_9N9&5R;65N:7II(&ES=&5M96MT
M961I<BY,_'1F96X@9_9N9&5R;65K(&GG:6X@)7,@_'IE<FEN92!T_6ML87G]
M;BX`(B5S(B!S=6YU8W5S=2!S:6QI;F1I+@`B)7,B('-U;G5C=7-U(&MA>61E
M9&EL9&DN`%-U;G5C=2!B=2!G]G+\;G3\;OQN(&UI;GEA=/QR(&)O>75T=6YU
M('EA<F%T86UA9/TN`-UM>F$@>65R:6YE(&MO;F%M863]+@#=;7IA(&)A_F%R
M_7EL82!Y97)I;F4@:V]N9'4N`"5S(&GG:6X@;VQA;B#\>65L:6L@:7-T9?!I
M('-I;&EN9&DN`$)E;&ER=&EL96X@9&]S>6$@8G5L=6YM86UA:W1A9/UR+@!"
M96QI<G1I;&5N('-A=/UR(&)U;'5N;6%M86MT863]<BX`0G4@9_9R978@9_9R
M978@;&ES=&5N:7IE(&5K;&5N9&DN`$=EYVEC:2!D;W-Y82`B)7,B(&)U;'5N
M;6%M86MT863]<BX`W6QE=&EN:6X@;65T;FD`W6QE=&EN:6X@;65T;FD@9_9R
M_&QE8FEL:7(Z("5S+@!$]FYE;B!I;&5T:6YI;B!M971N:0!$]FYE;B!I;&5T
M:6YI;B!M971N:2`@9_9R_&QE8FEL:7(Z("5S+@!']FYD97)I;&UI_B!I;&5T
M:6YI;B!M971N:0!']FYD97)I;&UI_B!I;&5T:6YI;B!M971N:2!G]G+\;&5B
M:6QI<CH@)7,N`%-A9&5C92#\<W0@=F4@86QT('1A<F%F;&%R`%-A9&5C92#\
M<W0@=&%R868`0FER(/9N8V5K:2!A9/UM('/]<F%S_6YD82!Y_&ML96YE;B!V
M97)I(&MA>6)E9&EL9&DN`%G\:VQE;F5N(&1O<WEA(&MA>61E9&EL96UE9&DN
M`$MU;&QA;OUC_6[];B!S97)B97-T+VUE_F=U;"!B:6QG:7-I(&)A_F%R_7EL
M82!D97!O;&%N9/TN`'=E871H97(N8V]M(&MU;&QA;OUL86)I;&ER(&1E\&EL
M+@!-971N92!G]FW\;/P@;VQA<F%K(&?V<W1E<FEL96)I;&5C96L@;VQA<_T@
M:_US_6TH;&%R*2!B=6QU;FUA;6%K=&%D_7(N`$)U('!O<W1A(&MU='5S=6YD
M82!I;&5T:2!B=6QU;FUA;6%K=&%D_7(N`$AIYV)I<B!S9>=E;F5K(&UE=F-U
M="!D9?!I;"X`365T;F4@9_9M_&S\(&]L87)A:R!G]G-T97)I;&5B:6QE8V5K
M(&O]<_UM('EO:P!"=2!A;&%N9&$@YV]K(&9A>FQA(&MA<F%K=&5R('9A<BXE
M<R!T86YE(&MA<F%K=&5R(&=I<F1I;FEZ.R`E<R!T86YE9&5N(&%Z(&=I<FUE
M;FEZ(&=E<F5K:7)D:2X`)7,@('-I;&EN:7)K96X@<V]R=6X@;VQU_G1U+E-U
M;G5C=2!B=6YU(&)I;&1I<FUE:W1E9&ER+@!0;W-T82!K=71U<W5N=6X@<VEL
M:6YM97-I;F1E('-O<G5N(&]L=?YT=2Y3=6YU8W4Z("5S`%!O<W1A(&MU='5S
M=6YU;B!S:6QI;FUE<VEN9&4@<V]R=6X@;VQU_G1U+E-U;G5C=2!B=6YU(&)I
M;&1I<FUE:W1E9&ER+@!$;W-Y82`H:V%R_OUD86XI('G\:VQE;FUE<VEN9&4@
M<V]R=6X@=F%R.B`E<R!Y_&ML96YE;65D:2X`1&]S>6$@>?QK;&5N:7)K96X@
M8FER('-O<G5N(&]L=?YT=3H@)7,@96X@8OQY_&L@:7II;B!V97)I;&5N(&)O
M>75T=&%N("@E9"!B>71E*2!D86AA(&+\>?QK+@!$;W-Y82!Y_&ML96YI<FME
M;B!B:7(@<V]R=6X@;VQU_G1U.B`E<R!S861E8V4@:_US;6D@;VQA<F%K('G\
M:VQE;F1I+@#=;&5T:6QE<FD@(B5S(B!K;VYU;75N9&%N("(E<R(@:V]N=6UU
M;F$@:V]P>6%L87)K96X@:&%T82!O;'7^='4N4W5N=6-U(&)U;G4@8FEL9&ER
M;65K=&5D:7(N`-UL971I;&5R("(E<R(@9&EZ:6YD96X@<VEL:6YI<FME;B!H
M871A(&]L=?YT=2Y3=6YU8W4@8G5N=2!B:6QD:7)M96MT961I<BX`W6QE=&EL
M97(@(B5S(B!D:7II;FEN9&5N('-I;&EN:7)K96X@:&%T82!O;'7^='4N4W5N
M=6-U(&)U;G4@8FEL9&ER;65K=&5D:7(N`-UL971I;&5R:6X@<VEL:6YM97-I
M;F1E(&AA=&$@;VQU_G1U+E-U;G5C=3H@)7,`3VQA>?UN('-I;&EN;65S:6YD
M92!H871A(&]L=?YT=3H@)7,N`-UL971I;FEN(&)U(&O]<VW];OT@9_9R_&YT
M_&QE;FUE<VEN9&4@:&%T82!O;'7^='4N`"(E<R(@9&EZ:6YI;F1E:VD@:6QE
M=&EL97)I(&G^87)E=&QE<FME;B!H871A(&]L=?YT=2Y3=6YU8W4@8G5N=2!B
M:6QD:7)M96MT961I<BX`)7,@*&GG97)I*2!A:W1A<OUL_7)K96X@:&%T82!O
M;'7^='4`W6QE=&G^:6T@;F]K=&%S_6[];B!V97)I;&5R:2`H:>=E<FDI(&%K
M=&%R_6S]<FME;B!H871A(&]L=?YT=2X`3VQA>?UN("AIYV5R:2D@86MT87+]
M;?T@<_UR87/];F1A(&AA=&$@;VQU_G1U.B`E<P!I0V%L96YD87(@=F5R:7-I
M("AIYV5R:2D@86MT87+];/UR:V5N(&AA=&$@;VQU_G1U+@!']G)E=FEN("AI
MYV5R:2D@86MT87+];?T@<_UR87/];F1A(&AA=&$@;VQU_G1U.B5S`$MU;&QA
M;OUC_6[];B!S97)B97-T+VUE_F=U;"!B:6QG:6QE<FEN:6X@*&GG97)I*2!A
M:W1A<OUM_2!S_7)A<_UN9&$@:&%T82!O;'7^='4Z("5S`%EA</UL86YD_7)M
M82!F;W)M=6YD82!B:7(@:&%T82!V87(N($=E<F5K;&D@8FER(&%L86[](&1O
M;&1U<FUA;?W^(&]L86)I;&ER<VEN:7HN`-UL971I;&5R:2`B)7,B(&MO;G5M
M=6YD86X@(B5S(B!K;VYU;75N82!T8?[]<FME;B!H871A(&]L=?YT=2Y3=6YU
M8W4@8G5N=2!B:6QD:7)M96MT961I<BX`0F5L:7)T:6QE;B!A9')E<R!D969T
M97)I(&G^;&5V:6YI;B!G97+G96ML9?YT:7)I;&UE<VD@<_UR87/];F1A('-O
M<G5N(&]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K<F%R(&1E;F5Y:6XN
M`-UL971I('1A<VQA:R!O;&%R86L@:V%Y9&5D:6QI<FME;B!H871A(&]L=?YT
M=2X`W6QE=&D@9_9N9&5R:6QE<FME;B!H871A(&]L=?YT=3H@)7,`W6QE=&G^
M:6T@;F]K=&%S_6[];B!A>7+];G3];&%R_6[](&?\;F-E;&QE<FME;B!H871A
M(&]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K<F%R(&1E;F5Y:6XN`$1A
M\/UT_6T@;&ES=&5S:6YI(&?\;F-E;&QE<FME;B!B:7(@:&%T82!O;'7^='4N
M($S\=&9E;B!D86AA('-O;G)A('1E:W)A<B!D96YE>6EN+@!/;&%Y(&?\;F-E
M;&QE;FER:V5N(&AA=&$@;VQU_G1U.B`E<P#=;&5T:6YI;B!B=2!K_7-M_6YD
M82!M971I;B!B=6QU;FUA;6%K=&%D_7(N`$)U($A434P@:6QE=&ES:6YI;B!I
MYVEN92!G]FW\;&W\_B!G]G+\;G3\;&5R(&)U;'5N;6%K=&%D_7(N`$)U($A4
M34P@:6QE=&ES:6YI;B!IYVEN92!G]FW\;&W\_B!G]G+\;G3\;&5R(&)U;'5N
M;6%K=&%D_7(N($?V<OQN=/QL97(@_O9Y;&4@9_9R_&YE8V5K=&ER.B``0G4@
M24U!4"!S=6YU8W5S=2!P87EL8?[];&%N(&1I>FEN;&5R:2!D97-T96ML96UI
M>6]R+@!"=2!01U`@0>?]:R!!;F%H=&%R_2!I;&5T:7EE(&5K;&5N;6G^=&ER
M+@!"=2!E>6QE;2!D97-T96ML96YM96UE:W1E9&ER+@!"=2!E>6QE;2!H96[\
M>B!G97+G96ML9?YT:7)I;&UE;6G^=&ER+@!"=2!G9>=E<FQI(&)I<B!R87(@
M87+^:79I(&1E\&EL+@!"=2!G9>=E<FQI(&)I<B!Z:7`@9&]S>6%S_2!D9?!I
M;"X`0G4@9V7G97)L:2!B:7(@:V%R="!N=6UA<F%S_2!D9?!I;"X`0G4@<_QR
M_&/\($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@8?`@9V7G
M:61I(/QZ97)I;F1E;B!(5%10($%022!K=6QL86YA<F%K(&UE<V%J(&%T;6%N
M_7IA(&EZ:6X@=F5R:7(N`$)U('/\<OQC_"!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PI(&'P(&=EYVED:2#\>F5R:6YD96X@2%144"!!4$D@:W5L;&%N
M87)A:R!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+@!"=2!S_'+\8_P@4TU4
M4"!Y;VQU>6QA(%9O9&%F;VYE($ET86QY(&'P(&=EYVED:2#\>F5R:6YD96XL
M('-A9&5C92!6;V1E9F]N92!N=6UA<F%L87+];F$@;65S86H@871M86[]>F$@
M:7II;B!V97)I<BX@5F]D969O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!G97)E:W1I<FUE:W1E9&ER+@!"
M=2!G97)E:VQI(&)I<B!A;&%N9/UR+@!"=2!A;&%N('-A9&5C92!S87G](&GG
M97)M96QI9&ER+@!"=2!A;&%N('-A9&5C92!S87G]('9E(&EK:2!N;VMT82#\
M<W3\<W1E(&G^87)E=&D@:>=E<F5B:6QI<BX`0G4@86QA;B!S861E8V4@<V5K
M:7IL:6L@<V%Y_2!S:7-T96UI;F1E;B!D9?!E<FQE(&GG97)E8FEL:7(N`$)U
M(&%L86X@=FER9_QL('9E>6$@8F_^;'5K;&$@87ER_6QM_?X@<V%Y_2!L:7-T
M92!O;&UA;/UD_7(N`$)U(&%L86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L
M_63]<BX`0G4@86QA;B!21T(@2&5X(&)IYVEM:6YD92!B:7(@<F5N:R!K;V1U
M(&GG97)M96QI9&ER+"#V<FYE:SH@)R,Q,C,T868G`$)U(&9O<FT@>F%T96X@
M:?YL96YD:2X`0G4@)7,N`$)U(&)I<B!+;VQA8B!'<F]U<'=A<F4@;F5S;F5S
M:61I<BX@0G4@;F5S;F5Y:2!G]G)E8FEL;65K(&GG:6X@2V]L86(@1W)O=7!W
M87)E(&)IYVEM:6YI(&%N;&%Y86)I;&5N(&)I<B!E;&5K=')O;FEK('!O<W1A
M(&ES=&5M8VES:6YE(&=E<F5K('9A<BY"=2!E;&5K=')O;FEK(&ES=&5M8VD@
M;&ES=&5S:2!IYVEN("5S(&%D<F5S:6YE('7P<F%Y_6XN`$)U(&G^;&5M('IA
M;6%N(&%L86)I;&ER+D1E=F%M(&5T;65K(&ES=&5D:?!I;FEZ92!E;6EN(&UI
M<VEN:7H_`$)U(&EL971I($UA8VEN=&]S:"!D;W-Y87/](&GG97)M96MT961I
M<BX`0G4@:6QE=&D@<V%Y_7-A;"!O;&%R86L@4R]-24U%('EO;'5Y;&$@:6UZ
M86QA;FW]_B!B:7(@96L@:>=E<FUE:W1E9&ER+@!"=2!I;&5T:2!3+TU)344@
M>6]L=7EL82#^:69R96QE;FUI_B!B:7(@96L@:>=E<FUE:W1E9&ER+@!"=2!I
M;&5T:2!T97-L:6T@9'5R=6T@8FEL9VES:2!IYV5R;65K=&5D:7(@86UA(&EL
M971I;FEN(&)IYVEM:2!B:6QI;FUE;65K=&5D:7(N`$)U(&EL971I(&=EYV5R
M;&D@8FER(%!'4"#^:69R96QE;FUI_B!I;&5T:2!O;&%R86L@9_9R_&YM96UE
M:W1E9&ER+B!(871A.B``0G4@:6QE=&D@9&_P<G4@4$=0(&)IYVEM:6YD92!D
M9?!I;&1I<BX@*%)&0R`R,#$U(&4@9_9R92D`0G4@:6QE=&D@9&_P<G4@(%,O
M34E-12!B:>=I;6EN9&4@9&7P:6QD:7(N`$)U(&EL971I('-A>?US86P@;VQA
M<F%K(%!'4"!Y;VQU>6QA(&EM>F%L86YM_?YT_7(N`$)U(&EL971I('-A>?US
M86P@;VQA<F%K(%,O34E-12!Y;VQU>6QA(&EM>F%L86YM_?YT_7(N`$)U(&EL
M971I(%,O34E-12!Y;VQU>6QA(/YI9G)E;&5N;6G^=&ER+@!"=2!I;&5T:2!0
M1U`@:6QE(/YI9G)E;&5N;6G^=&ER+@!"=2!I;&5T:7EI`$)U(&EL971I('-I
M>FEN(&MA<F%K=&5R(&O\;65N:7ID96X@9F%R:VS](&]L87)A:R@E<RD@>6%Z
M_6QM_?YT_7(N`$)U(&YU;6%R82!E;B!A>OUN9&%N(&)I<B!O;&UA;/UD_7(N
M`$)U('-U;G5C=2!Z:7`@=F4@9WII<"!D;W-Y86QA<OUN_2!AYV%M86UA:W1A
M9/UR+@!"=2!S=6YU8W4@9&EZ:6X@<&%Y;&'^_6W];OT@9&5S=&5K;&5M96UE
M:W1E9&ER+@!3:7-T96UI;B!E=&MI;FQI\&D@:V%L9/UR_6QM_?YT_7(N`$)U
M(&1E\&5R(&)I<B!S87G](&]L;6%L_63]<BX`0G4@<&5N8V5R92!B:7(@;VQU
M_G1U<FUA('!E;F-E<F5S:2!T87)A9OUN9&%N(&'G_6QM86S]9/UR+@!"=2!P
M96YC97)E(%-EYV5N96ML97(@<&5N8V5R97-I;F1E;B#G8?!R_6QM86S]9/UR
M+@!(86)E<B#68F7P:2!']G+\;G3\<_P`1_9K(&?\<OQL=/QS_`!":6QE=&QE
M<@!:86UA;@!:86UA;B#=>FQE;64`6F%M86X@0FGG:6UI`%IA;6%N(%-EYVEM
M:0!4:6UO<BU,97-T90!"8?YL_6L`0F'^;/UK("AAY_UK;&%M82DZ`$MI;64`
M061R97,`0FER9&5N(&9A>FQA(&%L86X@<V7G96)I;&UE:R!IYVEN+"!T_6ML
M87)K96X@0V]N=')O;"A00RD@>6%D82!#;VUM86YD*$UA8RD@='7^;&%R_6[]
M(&)A<_UL_2!T=71U;BX`QV]K;'4@]O!E('-EYVEM:2!IYVEN+"!T_6ML87)K
M96X@0V]N=')O;"`H4$,I('9E>6$@0V]M;6%N9"`H36%C*2!T=?YU;F$@8F%S
M_6XN`$)U9_QN`$A434P@2V%Y;F'P_6YA($=EYVEN`%1O9V\`5&]K96QA=0!9
M87+];@!4;VYG80#<<W0`W'-T(,=E<N=E=F4@*-Q?<W0I`%1O<&QA;2!%:R!"
M;WEU='4Z`,=E=FER:6QE<@#']G`@2W5T=7-U`,?V<"!+=71U<W4Z`%1R:6YI
M9&%D('9E(%1O8F%G;P!$;_!R=2!V97EA(%EA;FS]_@!380!4=6YU<P!4_')K
M:7EE`%3\<FOG92`H25-/+3@X-3DM.2D`5/QR:VUE;FES=&%N`%1U<FMS('9E
M($-A:6-O<R!!9&%L87+]`%1U=F%L=0!39>=I;6EN:7II(&=I<FEN.@!5+E8N
M(&5N9&5K<SH@`%523`!"971I:VQE<FEN(&1U<G5M(')A<&]R;&%R_6[];B!T
M97-L:6T@961I;&5C9?!I(%523`!54DPZ`%5G86YD80!5:W)A>6YA`%9&4R!D
M:7II;FEN92!E<FG^:6QE;65M:7EO<BX`W'EE(&]L=7)K96X@96L@:W5L;&%N
M_6/](&)I;&=I<VD@96ML96YE;6EY;W(N`"(E<R(@5D93(&1O<WEA<_UN_6X@
M:7II;FQE<FD@9&7P:?YT:7)I;&5M:7EO<BX`)7,O)7,@5D93(&1O<WEA<_UN
M_6X@:7II;FQE<FD@9&7P:?YT:7)I;&5M:7EO<BX`)7,@9&7P:?YT:7)I;&5M
M961I+@!344P@<W5N=6-U<W5N82!B8?!L86[];&%M_7EO<BX`4U-,(&EL92!B
M8?!L86[];&%M_7EO<BX`5D93(&1O<WEA<_T@:V]P>6%L86YA;?UY;W(N`"(E
M<R(@5D93(&1I>FEN:2!Y87)A=/UL86W]>6]R+@!61E,@9&EZ:6YI('EA<F%T
M_6QA;?UY;W(N`%9&4R!D;W-Y87/]('EA<F%T_6QA;?UY;W(N`$)O_B!61E,@
M9&]S>6%S_2!Y87)A=/UL86W]>6]R+@!697)I('/]:_W^=/UR_6QA;?UY;W(N
M`"(E<R(@9&EZ:6YI('-I;&EN96UI>6]R+"!D:7II;B!B;_X@9&7P:6PN`"5S
M('-I;&EN96UI>6]R+"!D:7II;B!B;_X@9&7P:6P`5D93(&1I>FEN:2#V>GEI
M;F5L:2!O;&%R86L@<VEL:6YE;6EY;W(N`%9&4R!D:7II;FD@<VEL:6YE;6EY
M;W(N`%9&4R!D:7II;FD@<VEL:6YE;6EY;W(Z("5S+@!61E,@9&]S>6%S_2`B
M)7,B('-I;&EN96UI>6]R+@!61E,@9&]S>6%S_2!S:6QI;F5M:7EO<BX`5D93
M(/9Z>6EN96QI(&]L87)A:R!S:6QI;F5M:7EO<CH@)7,N`%G\<OQR;/QK=&5K
M:2!D:7II;F4@:V%R87(@=F5R:6QE;6EY;W(N`$]N87D@8F5L9V5S:2!A>7+]
M;G3];&%R_2#G_6MA<G3];&%M_7EO<@!486[];?T@>?QK;&5N96UI>6]R.B`E
M<P!61E,@9&]S>6%S_2!T8?[];F%M_7EO<BX`5D93(&1O<WEA<_T@(B5S(B!A
MY_UL86W]>6]R+@!61E,@9&]S>6%S_2!Y86UA:R!IYVEN(&'G_6QA;?UY;W(N
M`%9&4R!D;W-Y87/](&'G_6QA;?UY;W(N`%/]:_W^=/UL_6W]_B!A<OYI=B!A
MY_UL86W]>6]R+@!69G-R;V]T(&1I>FEN:2!O:W5N86W]>6]R+@`E<RT^)7,@
M;VQA<F%K('EE;FED96X@861L86YD_7+];&%M_7EO<CH@:&5D968@9&EZ:6X@
M>F%T96X@=F%R+@!61E,@9&EZ:6YI('EE;FED96X@861L86YD_7+];&%M_7EO
M<BX`5D93(&1I>FEN:2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(Z("5S`%9&
M4R!D;W-Y87/]("(E<R(@>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+@`E<R\E
M<R!61E,@9&]S>6%S_2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N`%9&4R!D
M;W-Y87/]('EE;FED96X@861L86YD_7+];&%M_7EO<BX`2V]T82!B96QI<FQE
M;F5M961I`"=M:VES;V9S)R#G86S]_G3]<OUL86W]>6]R+@!"=2!7;W)D(&)E
M;&=E<VD@YV5V:7)I;&EL96UI>6]R+@!61E,@9&]S>6%S_2`B)7,B('EA>OUL
M86W]>6]R+@!61E,@9&]S>6%S_2!Y87K];&%M_7EO<B`H8V]P>2@I(&)A_F%R
M_7/]>B!O;&1U*2X`5D93(&1O<WEA('9E<FES:2!Y87K];&%M_7EO<BX`0V5V
M87!L86YM86W]_@!#979A<&QA;FUA;?W^(-UL971I;&5R`%-I;&UE`$%L=/UN
M_2#G:7H`1_9S=&5R:6QM97EE;B!!;/UC_6QA<@!$9?!I_FEK;&EK;&5R:2!'
M97)I($%L`%-O;B!E>6QE;6D@9V5R:2!A;`!"8?!L86YT_61A('-U;G5C=61A
M;B!B96ML96YM97EE;B!Y86[]=#H@`%-U;G5C=61A;B!B96ML96YM97EE;B!Y
M86[]=#H@`$1O;&1U<G5L;6%M_?X`0FEL:6YM97EE;B!B:6QE_F5N('1I<&DZ
M("5S`%5N:6-O9&4@*%541BTX*0!":7)L9?YI:R!!<F%P($5M:7)L:6ML97)I
M`$)I<FQE_FEK($MR86QL_6L`06UE<FEK82!":7)L9?YI:R!$979L971L97)I
M`$%M97)I:V$@0FER;&7^:6L@1&5V;&5T;&5R:6YI;B!+_.?\:R!5>F%K($%D
M86QA<OT`0FER:6UL97(`0FEL:6YM97EE;@!":6QI;FUE>65N(%1A<FEH`$)I
M;&EN;65Y96X@5&]P;&%N=/T`0FEL:6YM97EE;B!!;/UC_0!":6QI;FUE>65N
M(&%P:6US9VED("A!4$D@365S86H@240I`$)I;&EN;65Y96X@8VQI;7-G:60@
M*-US=&5M8VD@;65S86H@240I`$)I;&EN;65Y96X@:W5L;&%N_6/](&%D_2!V
M97EA('!A<F]L82X`WG4@86YK:2#V\&5N:6X@8F'P_6[](.?V>@!'9>=I_B!4
M_&UC96-I\&EN:2!+86QD_7(`W7-I;7-I>@!!>7+]8V%L_6MS_7H@8F5T:6ML
M97(@<')O9W)A;7-A;"!O;&%R86L@2V5S+TMO<'EA;&$O66%P_?YT_7(G82!G
M_'9E;FQI:R!N961E;FEY;&4@97)I_F5M97IL97(N($)E=&EK;&5R:6X@<&%N
M;WEA(&YA<_UL('5L8?YA8V'P_6[](&?V<W1E<F5N(&UO>FEL;&$N;W)G('1E
M:VYI:R!N;W1U;G4@9_9R;65K(&GG:6X@159%5"!I('3]:VQA>?UN+@!/:W5N
M;6%M_?X`0F5L:7)T:6QM:?X@<F5N:W1E;B!V87IG9><`1&EZ:6YI;B#\>65L
M:?!I;F1E;B#G_6LN`$1E<W1E:VQE;FUE>65N(%5Z86YT_0!'_&YC96QL90!'
M_&YC96QL93H@)7,`16L@0FEL9VES:6YI($?\;F-E;&QE`$-E=F%P;&%Y_6/]
M(&1U<G5M=6YU(&?\;F-E;&QE`$MU;&QA;OUC_7G](&?\;F-E;&QE`%G\:W-E
M;'1M92!B971I\&D@<VEL:6QN9&DN`%G\:VQE`$+\=/QN('5Y9W5L86UA;&%R
M_6X@87EA<B!D;W-Y86QA<OT@<W5N=6-U>6$@>?QK;&5N9&DN`$+\>?QK(&QA
M=&EN(&AA<F9L97)I`$+\>?QK(')O;6$@<F%K86UL87+]`%5R=6=U87D`2W5L
M;&%N.B`E<P#6;B!T86[];6S]($1E\&5R:2!+=6QL86X`24U!4"!D:7II;FEN
M:6X@_'EE;&EK;&5R:2!K=6QL86[];'/];B!M_3\`4U-,(&MU;&QA;@!+=6QL
M86[]8_T@863];OUZ+W!A<F]L86[]>B!)35-0('-U;G5C=2!IYVEN(&9A<FML
M_2!I<V4@:W5L;&%N_6XN`$MU;&QA;OUC_0`E<R!K=6QL86[]8_US_2`E<R!I
MYVEN(&1O\')U;&%N86UA9/TN`$MU;&QA;OUC_2!9]FYE=&EM:0!+=6QL86[]
M8_T@4V7G96YE:VQE<FD`2W5L;&%N_6/]($MA>?UT`$)U('-I=&4@:>=I;B!K
M=6QL86[]8_T@:V%Y9/T@<V7G:6QM97H@:_UL_6YM_?YT_7(N`$MU;&QA;OUC
M_2!!9/T`2W5L;&%N_6/]($%D_3H`2W5L;&%N_6/](&%D_3H@`%-I<W1E;61E
M:VD@:W5L;&%N_6/];&%R.@#6>F)E:VES=&%N`%9&4R!D:7II;FD@>6]K+@!4
M871I;`!'9>=E<FQI(&MO;G5M;&%R_6X@:>=E<F1I:VQE<FDZ`$=EYV5R;&EL
M:6L`WG4@86YD86X@:71I8F%R96X@9&%K:6MA(&1E\&5R:0!$9?!E<FQE<@!$
M9?!E<FQE<FEN('-EYVEL96-E\&D`5F%N=6%T=0!$9?!I_FME;@!696YE>G5E
M;&QA`$1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2`M(&)U(&EL971I(&MU<F-A
M;&%N;?W^(&]L86)I;&ER+B`@`%/\<OQM`%/\<OQM($MO;G1O;/P`1/S^97D@
M2&EZ80!$_/YE>2!Y87-T_6ML86UA`$3\_F5Y.@#';VL@6?QK<V5K`%9I971N
M86T`5FEE=&YA;6-A("A625-#24DI`$?V<OQN=/QL90!']G+\;G3\;&4@)7,`
M)7,@0>?]:R!!;F%H=&%R_6[]($?V<OQN=/QL90!(5$U,(&GG97)I\&EN:2!A
M>7+](&)I<B!P96YC97)E9&4@9_9R_&YT_&QE+@!+:?YI<V5L(-9Z96P@06YA
M:'1A<OT@1_9R_&YT_&QE`$MI_FES96P@0>?]:R!!;F%H=&%R_2!']G+\;G3\
M;&4`2&%B97(@UF)E\&EN:2!']G+\;G3\;&4`36EN>6%T_'(@0F]Y=71T82!'
M]G+\;G3\;&4`0FER(&3]_B!W96(@<V%Y9F%S_2!G]G+\;G3\;&4`)7,@;VQA
M<F%K(&?V<OQN=/QL90!%:VD@87ER_2!B:7(@<&5N8V5R961E(&?V<OQN=/QL
M90#=YV5R:?!I(&%Y<OT@8FER('!E;F-E<F5D92!G]G+\;G3\;&4`3VQA>?T@
M1_9R_&YT_&QE`"5S(&GG:6YD96MI(&EL971I;&5R:2!G]G+\;G3\;&4`1VER
M:?YT96X@<V]N<F$@9_9S=&5R:6QE8V5K(&?V<OQN_&T@>6%D82!P;W-T82!K
M=71U<W4Z`$?V<F5V:2!']G+\;G3\;&4`1_9R_&YT_&QE<FD@1_9R_&YT_&QE
M`$)R:71A;GEA)WEA(&%I="!6:7)G:6X@061A;&%R_0!!;65R:6MA($)I<FQE
M<OYI:R!$979L971L97)I)VYE(&%I="!6:7)G:6X@061A;&%R_0!386YA;"!$
M:7II;B`B)7,B(&)A_F%R_7EL82!Y87)A=/UL9/TN`%-A;F%L($1I>FEN;&5R
M`%-A;F%L($1I>FEN;&5R(&)I<B!E=&EK970@9V5R96MT:7)M96MT961I<BX`
M4V%N86P@9&EZ:6X@971I:V5T:0!']G+\_@!']G+\_CH`4TU44"!Y;VQU>6QA
M(%9O9&%F;VYE(-UT86QY80!705).`%5905))(2$A)7,@W<?=3D1%3B!"153=
MT-T@14P@W4Q%(,=)2T%25$E.+@!786QL:7,@=F4@1G5T=6YA`%5Y87+]`,=R
M_@!(879A(%1A:&UI;FD`2&%V82!V97)I<VD@<V'P;&%Y_6/]<_T`5V5A=&AE
M<BYC;VT`5V5B`%=E8B!3:71E<VD`2&%F=&%L_6L`2&_^9V5L9&EN:7H`)7,@
M2&_^9V5L9&EN:7H`2&_^9V5L9&EN:7HL("5S`$)A=/T@*$E33RTX.#4Y+3$I
M`$)A=/T@*$E33RTX.#4Y+3$U*0!"873](%-A:')A`"5S(&=I<FG^=&5N('-O
M;G)A(&AA;F=I('5Y9W5L86UA>?T@9_9R_&YT_&QE<VEN/P!3_6[]<FQA>?UC
M_2!K87)A:W1E<B!N961I<C\`06MT87+];2!K87)A:W1E<FD@;F5D:7(_`-UL
M971I;&5R:2!S:6QE<FME;BP@<VEL:6YE8V5K(&]L87)A:R!I_F%R971L96UE
M:R!Y97)I;F4@Q_9P($MU='5S=6YA('1A_OUN<_UN(&W]/P!996YI(&)I<B!P
M;W-T82!K=71U<W4@8>?];/UR:V5N+"!H86YG:2!S87EF861A;B!B8?YL86UA
M:R!I<W1E<G-I;FEZ/P!']FYD97)I;&UI_B!P;W-T86QA<OT@:V%Y9&5D97)K
M96XL(&5K;&5R9&4@:V%Y9&5D:6QS:6X@;6D_`$AA;F=I($5V<F4`6F5N9VEN
M($UE=&EN(&3\>F5N;&5Y:6-I<VD@:>=I;B!H86YG:2!U>75M;'4@96ML97(@
M<V7G:6QE8FEL:7(@:_UL_6YS_6XN`$)E>6%Z($QI<W1E`$=E;FG^;&EK`$-3
M4R!B:7)I;6EY;&4@9V5N:?YL:6L`4V]L9&%K:2`E<R!M96[\<_QN_&X@9V5N
M:?YL:?!I("AB:7(@<V]N<F%K:2!G:7)I_G1E(&5T:VEN(&]L86-A:RDZ`,=I
M>F5L9V5N:6X@9V5N:?YL:?!I`$=E;FG^;&EK(&)I<FEM:0!'96YI_FQI:SH`
M5VEK:0!2_'IG87(`17)K96X@4V%A=&QE<F1E(%+\>F=A<@!+;F]T(&)I<FEM
M:6YD92!R_'IG87(@:/UZ_0!2_'IG87(Z`%+\>F=A<CH@`$)I;&=E;&EK`-W^
M`-W^($%D<F5S:0#=_B!496QE9F]N=0!8+5)E9@!8-3`Y=C,@5&5M96P@2_US
M_71L86UA;&%R_0!8-3`Y=C,@1V5N:?YL971I;&UI_B!!;F%H=&%R($MU;&QA
M;OUM_0!8-3`Y=C,@UG1E:VD@2V]N=2!!9/T`6#4P.78S($MO;G4@06YA:'1A
M<B!486[]=/UC_7/]`%@U,#EV,R!U>F%N=/UL87+]`%E9`%E965D`66%H;V\A
M(&AA<FET87/]`%G];&S]:P!996UE;@!%=F5T`$5V970L($MA8G5L($5D:7EO
M<G5M`%1A:VEP(&5D96X@:&5S87!L87)D86X@<&]S=&$@9V5T:7)M96L@_'IE
M<F5S:6YI>BX`665N:2!B:7(@9&EZ:6YE(&MO<'EA;/UY;W)S=6YU>B]T8?[]
M>6]S=6YU>BX`06QT9&EZ:6X@>6%R873];&%C86L@9&EZ:6X@`-QS=&3\>F5Y
M(&)I<B!D:7II;B!Y87)A=/UY;W)S=6YU>BX`3454W4X@34]$54Y$05-)3DE:
M+B!;/#Y=(&3\\&UE;&5R:6YI(&MU;&QA;F%R86L@5UE325=91R!G]G+\;OQM
M_&YE(&3V;OQN+@!$;_!R=6QA;F%M863];OUZ+@!$:7II;B!Y96YI9&5N(&%D
M;&%N9/UR_6S]8V%K.B``)UPG(&MA<F%K=&5R:2!T86T@863];OUZ9&$@8G5L
M=6YA;6%Z+@!(:7IM970@2V_^=6QL87+](&%N;&'^;6%S_6[](&]N87EL86UA
M9/UN_7HL(&)U('-E8F5B;&4@9VER:?X@>6%P;6%N_7IA(&EZ:6X@=F5R:6QM
M96UE:W1E9&ER+@!'9>=E<FQI(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S
M:2!G:7)M961I;FEZ+@`E<R!IYVEN9&4@:V%R_OUL_6L@9V5L96X@86QA;FQA
M<FQA("AIYV5R:2D@86MT87+];&%N(&1O<WEA9&%K:2!A;&%N;&%R_2!E_FQE
M_G1I<FUE9&EN:7HN`$)U(&1I>FEN:6X@97)I_FEM(&AA:VQA<OUN_2!D9?!I
M_G1I<FUE:R!IYVEN(&EZ;FEN:7H@>6]K`$)U(&EL971I>6D@=&%K:7`@961E
M;B!A;/UC_6QA<F$@)25S(&1E(&EL971T:6YI>CH@)7,N`"5S('EE;FD@:6QE
M=&EN:7H@=F%R+@`Q('EE;FD@:6QE=&EN:7H@=F%R+@!(96[\>B!Y_&ML96UE
M9&GP:6YI>B!E;B!A>OUN9&%N(&)I<B!T86YE(&5K('-EYW1I;FEZ+B!"=2!I
M;&5T:7EI(&5K<VEZ(&?V;F1E<FUE:R!I<W1E9&GP:6YI>F1E;B!E;6EN(&UI
M<VEN:7H_`,?]:_W^('EA<&UA9/UN_7HN`$1I>FEN;&5R9&4@>65N:2!P;W-T
M82!V87(Z`$1I>FEN;&5R9&4@>65N:2!P;W-T82!V87(Z`$=EYV5R;&D@8FER
M(&-E<"!T96QE9F]N=2!N=6UA<F%S_2!G:7)M96QI<VEN:7HL('-A>?UL87(@
M=F4@<V7G96YE:VQI(&]L87)A:R!U;'5S;&%R87)A<_T@87)A;6$@]FYE:VD@
M)RLG(`!'9>=E<FQI(&)I<B!D9?!E<B!G:7)M96QI<VEN:7HN`-QY92!K87ED
M_2!Y87!A8FEL;65K(&GG:6X@8FER(%9E<FE!\&%C_2!Y87#];&%N9/UR;6%L
M_7/];OUZ+@!61E,@<V]N(&'^86UA<_UN_2!Y87#];&%N9/UR;6%L_7/];OUZ
M+@!0<F]B;&5M(')A<&]R=2!G]FYD97)M961E;B#V;F-E('-O<G5N=2!T87)F
M:2!E=&UE;&ES:6YI>BX`16X@87H@8FER('1A;F4@86S]8_T@9VER;65L:7-I
M;FEZ+@!"=2!B8?!L86YT_6[];B!G]G-T97)D:?!I(&)I<B!54DP@9VER;65L
M:7-I;FEZ`$)U(&EL971I>6D@9_9R_&YT_&QE>65B:6QM96L@:>=I;B!01U`@
M]GIE;"!A;F%H=&%R_6[]>OUN(&=EYVG^('3\;6-E8VGP:6YI(&=I<FUE;&ES
M:6YI>BX`0G4@:6QE=&EY:2!G]G+\;G3\;&5Y96)I;&UE:R!IYVEN(%,O34E-
M12#V>F5L(&%N86AT87+];OUZ_6X@9V7G:?X@=/QM8V5C:?!I;FD@9VER;65L
M:7-I;FEZ+@#6;F-E(&)I<B!H961E9B!P;W-T82!K=71U<W4@<V7G;65L:7-I
M;FEZ+@!3:6QI;F5C96L@8FER(&AE<V%P('-EYVUE;&ES:6YI>BX`UFYC92!B
M:7(@861R97,@<V7G;65L:7-I;FEZ+@!3:6QI;FUE<VD@:>=I;B!B:7(@<W5N
M=6-U('-EYVUE;&ES:6YI>BX`UFYC92!E;B!A>B!B:7(@:6QE=&D@<V7G;65L
M:7-I;FEZ+@!":7(@86S]8_T@8F5L:7)T;65L:7-I;FEZ+@!496UI>FQE;FUE
M<VEN(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ+@!3
M:6QI;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI<G1M96QI<VEN
M:7HN`$5K;&5N96-E:R!E;B!A>B!B:7(@9&]S>6$@8F5L:7)T;65L:7-I;FEZ
M+@!%:VQE;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI<G1M96QI
M<VEN:7HN`$?\;F-E;&QE;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B
M96QI<G1M96QI<VEN:7HN`$=E<N=E:VQE_G1I<FEL96-E:R!B:7(@97EL96T@
M8F5L:7)T;65L:7-I;FEZ+@!996YI(&MA=&5G;W)Y(&%D_2!G:7)M96QI<VEN
M:7HN`$)U(&EL971I>6D@)7,@92`E)7,@9&4@>?9N;&5N9&ER9&EN:7HN`$)U
M(&EL971I>64@)7,@9&4@8V5V87`@=F5R9&EN:7HN`"(E<R(@9&EZ:6YI;F4@
M_'EE(&1E\&EL<VEN:7HN4W5N=6-U(&)U;G4@8F5L:7)T;65K=&5D:7(`(B5S
M(B#\>65L:?!I;FEZ(&1E=F%M(&5D:7EO<BY3=6YU8W4@8G5N=2!B96QI<G1M
M96MT961I<@`B)7,B(&1I>FEN:6YE(&)A_F%R_7EL82#\>64@;VQD=6YU>BX`
M(B5S(B#\>65L:?!I;F1E;B!B8?YA<OUY;&$@Y_UK=/UN_7HN`"5S(&]T=7)U
M;75N=6X@<_QR97-I(&1O;&1U+B!,_'1F96X@=&5K<F%R(&=I<FG^('EA</UN
M+@!%;&5K=')O;FEK(%!O<W1A($%D<F5S:6YI>@!+:6UD96XZ(&%D<F5S.@!"
M:6QG:6QE<FEN:7H`)7,@;W1U<G5M=6YU>G5N(&)A_FQA;F?]8_UN9&$@W6YT
M97)N970@061R97-I;FEN:7H@9&7P:?YT:2X@1_QV96YL:?!I;FEZ:2!K;W)U
M;6%K(&GG:6XL('EE;FED96X@9VER:?X@>6%P;6%L_7/];OUZ+@!!9/UN_7H`
M4$=0($'G_6LOUGIE;"!!;F%H=&%R;&%R_6[]>@#6>F5L($%N86AT87+];OUZ
M`$'G_6L@06YA:'1A<OUN_7H`4R]-24U%($'G_6LOUGIE;"!/;F%Y($)E;&=E
M;FEZ`$AE<V%P;&%R_6[]>CH`2VEM;&EK(&1E;F5T:6UI;FEZ(&MU;&QA;OUC
M_2!L:7-T96QE;65Y:2!D97-T96ML96UE;65K=&5D:7(@=F5Y82!B=2#V>F5L
M;&EK(&)I<B!N961E;B!Y_'K\;F1E;B!S9>=I;&5M97H@:_UL_6YM_?YT_7(N
M`"5S(&]T=7)U;75N=7IU;B!B8?YL86YG_6/];F1A('1A<F%Y_6/];OUZ(&1E
M\&G^=&DN($?\=F5N;&GP:6YI>FD@:V]R=6UA:R!IYVEN+"!Y96YI9&5N(&=I
M<FG^('EA<&UA;/US_6[]>BX`5&%R87G]8_UN_7H@8G4@9_9R_&YT_"!T_'+\
M;OP@;65T;F4@9_9M_&S\(&?V<W1E<FEM:6YI(&1E<W1E:VQE;65M96MT961I
M<BX`5&%R87G]8_UN_7H@8G4@]GIE;&QI\&D@9&5S=&5K;&5M96UE:W1E9&ER
M+@!:86UA;B!$:6QI;6EN:7HZ`-9N('1A;OUM;/T@:V%R86MT97(@:_QM96YI
M>CH`W6QE=&D@9_9N9&5R;65K(&GG:6X@]FX@=&%N_6UL_2#^:69R96QE;64@
M>?9N=&5M:6YI>CH`UFX@=&%N_6UL_2!K:6UL:?!I;FEZ.@!486T@063];OUZ
M.@#=;&5T:6YI>B!B8?YA<OUY;&$@=&5S;&EM(&5D:6QM:?YT:7(N`"5S(&GG
M:6X@>65N:2!P87)O;&%N_7HZ("5S`%-EYV5N96ML97)I;FEZ(&)U(&]T=7)U
M;75N('/\<F5S:2!IYVEN9&4@9_QN8V5L;&5N9&DN`%-EYV5N96ML97)I;FEZ
M(&?\;F-E;&QE;F1I+@!087)O;&%N_7H@<_UF_7)L86YD_2X`4&%R;VQA;OUZ
M('/]9OUR;&%N9/TL(&5L96MT<F]N:6L@<&]S=&%N_7K](&MO;G1O;"!E9&EN
M('9E('EE;FD@<&%R;VQA;OUZ;&$@9VER:?X@>6%P_6XN`%5Z86MT86MI('-U
M;G5C=6QA<OUN_7HZ`-UM>F%N_7HZ`%EU9V]S;&%V>6$`6F%I<F4`6F%M8FEA
M`%II;6)A8G9E`$C]>FS]`%M!;/UN=/T@365T;FD@4V%K;&%=`%M+;VYU(%EO
M:UT`6U!R;V)L96T@4F%P;W)U70!;06S];G3]($UE=&YI($?V<W1E<B`M`%M!
M;/UN=/T@365T;FD@1_9S=&5R("T@)7,@<V%T_7)=`"5S+R5S('-A=/UR`%]9
M]FYE=&EM`$=I>E]L:2!++DLN`%]+87)A($QI<W1E`%]#3$D`2RX@2V]?<'EA
M`%]697)I0?!A8_T`7U-I;`!3873]<OT@7U-I;`!?1&EZ:6YL97(`7T=R=7!L
M87(`66%R7V3];0!+:5]M;&EK`$?V<OQN=/P@UE]Z96QL:6ML97)I+BXN`%]'
M96QE;B!+=71U<W4`1VE?<FG^`,?]7VO]_@#=7VQE=&D@2V%Y;F'P_0!?0F'P
M;&%N=/UY_2!$9?!I_G1I<BXN+@!?4V7G96YE:VQE<@!?2&%K;&%R`%]987ID
M_7(`UFY?8V5L:6L`7UEE;FEL92`E<P!"8?!L85]N=/UY_2!3:6PN+BX`7T-E
M=F%P(%EA>@!?07)A`-UL971I(%]']FYD97(`7T%Y87)L87(`QVEZ95]L9V4@
MUGIE;&QI:VQE<FDN+BX`2V]N=2#68F7P:0!?2VEM90!3:6Q?;64`2U]U;&QA
M;OUC_6QA<@!?2&%B97(@UF)E\&EN:2!']G(`7T)E>6%Z($QI<W1E`&%D<F5S
M(&1E9G1E<FD`16L`16LN>FEP`&)Y=&4`=&%K=FEM`/UL_6UL_0!B=7)A>6$@
M=/UK;&%Y_6X`9/S^_'EO<@!D;W-Y80!K:6UD96X`)7,@*"5S*2!D96X@)7,@
M)7,@9&4`:#H`06-I;`!-971N92!G]FW\;/P`86YA:'1A<@!S873]<FQA<ET`
M<&]S=&$@:W5T=7-U(&1O<WEA<_T`;6MI<V]F<R!)4T\@>6%P87)K96X@:&%T
M82!K;V1U.B5D+@!A9`!H:>=B:7)I`&=E<N=E:VQE_G1I<FEL;65D:0!H96[\
M>B!G97+G96ML9?YT:7)I;&UE9&D`;F]T(&1E9G1E<FD`=F5Y80!Y_'ID90!R
M97-I;2!B:7)I;6D`>?QK<V5L:7EO<@!F87)K;&%R_2!G]G-T97(`2%144"!Y
M;VQU>6QA('-M<S)E;6%I;`!Y87K];2!H871A<_T`>6%Z_6T@:&%T86QA<OT`
M<V%B:70`9_9R978@;&ES=&5S:0!P87)O;&%Y_2!D;_!R=6QA;6%K(&GG:6X@
M:6MI(&1E9F$@9VER:6X`8FER;&7^=&ER:6QM:?X`861L86YD_7+];&UA;?W^
M`&MU;&QA;OUC_2!S9>=I;6D`=D-A<F0`=SH`=V5A=&AE<BYC;VT`:V%R82!L
M:7-T96YI>@!B97EA>B!L:7-T96YI>@``````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+VQO8V%L92]T<E]44B]H96QP+GAM;```````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#$Q-C8Q,@`Q,#0Q-S,V,C<V,P`P,C$Q-C$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]X;6P@=F5R
M<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM.2(_/@H\(2TM("1(;W)D
M93H@:6UP+VQO8V%L92]T<E]44B]H96QP+GAM;"QV(#$N,RXR+C,@,C`P-B\P
M,2\S,"`Q-3HU-SHU,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UB=71T;VYS(B!M9#4](C,R-3EB83`P83$Y.#4U.6,W9F%A
M-S9E-S@V-S8P,&0Y(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE
M<V%J($3\>F5N;&5N;65S:3H@W?YL96UL97(\+W1I=&QE/@H@("`@/&AE861I
M;F<^W?YL96UL97(\+VAE861I;F<^"B`@("`\<&%R83X*("`@($UE<V%J($?V
M;F1E<B(@92UP;W-T82!M97-A:OUN_7K](&%L_6/]*&QA<OTI;OUZ82!G]FYD
M97)I<BX@0G4@:?YL96T@9V5R:2!A;/UN86UA>6%C8?#];F1A;B!I_FQE;2!B
M:71M961E;B!M97-A:OUN_7K](&?V;F1E<FUE:R!I<W1E9&GP:6YI>F1E;B!E
M;6EN(&]L=6YU>BX@(`H\+W!A<F$^"B`@("`\<&%R83X*("`@(%1A<VQA\/T@
M2V%Y9&5T(B!B:71I<FEL;65M:?X@8FER(&UE<V%J_2!E:W)A;OUN_7K];B!S
M8?`@_'-T(&OV_F5S:6YD92!B=6QU;F%N(&'^8?#](&1O\')U(&'G_6QA;B!K
M=71U9&%K:2`B5&%S;&%K;&%R(B!K;&%S]G+\;F4@:V]Y87(N($UE<V%J_6[]
M>OT@9&%H82!S;VYR82`B5&%S;&%K;&%R(B!K;&%S]G+\;F1E:VD@:V%Y9&5D
M:6QM:?X@:&%L:6YD96X@8>=A<F%K('9E(")$979A;2!%=&UE(B!T=?YU;F$@
M=/UK;&%Y87)A:R!B:71I<F5B:6QI<G-I;FEZ+B!-97-A:OUN_7K]('1A<VQA
M:R!O;&%R86L@:V%Y9&5T;65D96X@]FYC92!K;VYU<W5N=2!Y87IM_?X@;VQM
M86[]>B!487-L86ML87(@:VQA<_9R_&YD92!M97-A:OUN_7K](&MO;&%Y;/UK
M;&$@8G5L;6%N_7K]('-A\&QA>6%C86MT_7(N(B`*/"]P87)A/@H@("`@/'!A
M<F$^"B`@("`@365S86K](-UP=&%L($5T(B!S]GIK;VYU<W4@;65S86K](&EP
M=&%L(&5D97(@=F4@96X@<V]N(&?V<OQN=/QL96UE:W1E(&]L9'7P=6YU>B!K
M;&%S]G)E(&3V;F5R+B(*/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M8V]M<&]S92UF<F]M(B!M9#4](C@R8V8R-&0S,6$V-C=A-6(Y-&4T.#%C9#4Q
M-SEC-3(Y(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE<V%J($3\
M>F5N;&5N;65S:3H@2VEM9&5N/"]T:71L93X*("`@(#QH96%D:6YG/B)+:6UD
M96XB/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!+=7)U;'5M=6YU>F$@8F'P
M;/T@;VQA<F%K+"!A_F'P_2!A:V%N(&)I<B!L:7-T961E;B!39>=E;F5K;&5R
M+29G=#M+:?YI<V5L($)I;&=I;&5R(&O]<VW];F$@9VER9&GP:6YI>B!B:7(@
M:VEM;&GP:2!S9>=E8FEL:7(L('9E>6$@;65S86K];B!G]FYD97)I;&1I\&D@
M861R97,@;VQA<F%K(&?V>OQK;65S:6YI(&ES=&5D:?!I;FEZ(&UA:6P@861R
M97-I;FD@;65T:6X@86QA;OUN82!G:7)E8FEL:7)S:6YI>BXB"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+71O(B!M9#4](C,Q
M8V)A,3=F,38Y-3<R8S,V-V%A.#`Q-#@S,65B.&8X(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/DUE<V%J($3\>F5N;&5N;65S:3H@2VEM93PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY+:6UE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!-97-A:OUN_7K];B!A;/UC_7/](&GG:6X@9&_P<G4@96UA:6P@861R97-I
M;FD@9VER:6XN($9A>FQA(&%L_6/](&=I<FUE:R!IYVEN+"!E;6%I;"!A9')E
M<VQE<FEN:2!V:7)G_&QL97)L92!A>?UR_6XN($AE<FAA;F=I(&1I\&5R(&YO
M:W1A;&%M82!I_F%R971L97)I;FEN(&5M86EL(&%D<F5S;&5R:6YI(&%Y_7)M
M86L@:>=I;B!K=6QL86[];?T@:&%T87EA('-E8F5P(&]L=7(N(@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UC8R(@;60U/2(Y
M-S4W,30S,V%B,#,W968Y8S1D,3`Q834V8F8W-&4R-2(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y-97-A:B!$_'IE;FQE;FUE<VDZ($MO<'EA/"]T
M:71L93X*("`@(#QH96%D:6YG/DMO<'EA/"]H96%D:6YG/@H@("`@/'!A<F$^
M"DUE<V%J_6[]>OUN(&MA<F)O;B!K;W!Y82!A;/UC_7/](&GG:6X@9&_P<G4@
M96UA:6P@861R97-I;FD@9VER:6XN($9A>FQA(&%L_6/](&=I<FUE:R!IYVEN
M+"!E;6%I;"!A9')E<VQE<FEN:2!V:7)G_&QL97)L92!A>?UR_6XN"B`@("`@
M/"]P87)A/@H@("`@/'!A<F$^"DMA<F)O;B!+;W!Y86QA<B!G96YE;&QI:VQE
M(&UE<V%J_6X@9&ER96MT(&%L_6/]<_T@;VQM87EA;B!K:?YI;&5R92!G]FYD
M97)I;&ER+"!A;6$@8FEL9VEL96YM96L@8>?]<_UN9&%N(&UE<V%J_2!A;&UA
M>6$@9V5R96MS:6YI;2!D=7EA8FEL:7)L97(L(&=E;F5L;&EK;&4@96UA:6QI
M;B!K;VYU<W4@:6QE(&1O;&%Y;/T@;VQA<F%K(&EL9VEL:61I<FQE<BX@0OQT
M_&X@(DMI;64Z(B!A;/UC_6QA<OT@=F4@(DMO<'EA.B(@86S]8_UL87+](&AE
M<B!I:VD@=/QR(&%L_6/](&QI<W1E<VEN:6X@=&%M86W];OT@9_9R96)I;&ER
M;&5R+B(*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O
M<V4M8F-C(B!M9#4](F%A.&8Y93)D-#1F9&(W-&1E9C!F83$U,C0P9F8V.#=B
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE<V%J($3\>F5N;&5N
M;65S:3H@1VEZ;&D@2V]P>6$\+W1I=&QE/@H@("`@/&AE861I;F<^(D=I>FQI
M($MO<'EA(CPO:&5A9&EN9SX*("`@(#QP87)A/@I-97-A:OUN_7K];B!G]G+\
M;FUE>B!K87)B;VX@:V]P>6$@86S]8_US_2!IYVEN(&1O\')U(&5M86EL(&%D
M<F5S:6YI(&=I<FEN+B!&87IL82!A;/UC_2!G:7)M96L@:>=I;BP@96UA:6P@
M861R97-L97)I;FD@=FER9_QL;&5R;&4@87G]<OUN+B`@2&5R:&%N9VD@9&GP
M97(@;F]K=&%L86UA(&G^<F5T;&5R:6YI;B!E;6%I;"!A9')E<VQE<FEN:2!A
M>?UR;6%K(&GG:6X@:W5L;&%N_6W](&AA=&%Y82!S96)E<"!O;'5R+B(@(`H@
M("`@("`\+W!A<F$^"B`@("`\<&%R83X*1_9R_&YM97H@:V%R8F]N(&MO<'EA
M;&%R(&=E;F5L;&EK;&4@9&GP97(@86S]8_UL87+];B!D82!O(&5M86EL:2!A
M;&3]\/UN_2!"W4Q-141%3B!Y87K];&%N_2!O:W5M87/](&=E<F5K96X@86S]
M8_UL87)A(&?V;F1E<FEL:7(N($+V>6QE8V4@(F?V<OQN;65Z(B!B=2!A;/UC
M_6QA<OUN(&MI;6QI\&EN:6X@96UA:6QI;B!B_'3\;B!D:?!E<B!A;/UC_6QA
M<OUN9&%N('-A:VQA;F3]\/T@86YL86W];F$@9V5L:7(N(%-A9&5C92!S:7H@
M9_9N9&5R96X@=F4@(D=I>FQI($MO<'EA(B!A;/UC_6QA<OT@8FER(&MO<'EA
M(&%L9/UK;&%R_6[](&)I;&5C96ML97(N(@H@("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](F-O;7!O<V4M<W5B:F5C="(@;60U/2(P-C,Y83@W
M.3!E,S`V86-C.64Q.6(T9#%C93,T,F0U,R(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93Y-97-A:B!$_'IE;FQE;FUE<VDZ($MO;G4\+W1I=&QE/@H@
M("`@/&AE861I;F<^(DMO;G4B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@($UE
M<V%J_6[]>OUN(&MO;G5S=6YU(&=I<FEN+B!+;VYU>74@:_US82P@>6%L_6X@
M=F4@8>?]:VQA>?UC_2!T=71M86L@:7EI9&ER+B!+;VYU('-A=/UR_2!S:7II
M;B!V92!Y87K]_G3]\/UN_7H@:VG^:2!IYVEN(&5M86EL:6X@:>=I;F1E(&YE
M(&]L9'7P=6YU(&5N(&MO;&%Y(/YE:VEL9&4@:&%T_7)L873]<BP@8G4@>?QZ
M9&5N(&5M86EL;&5R:6YI>FD@9/QZ96YL96UE9&4@=F4@<V]N<F%D86X@]FYE
M;6QI(&]L86YL87+];OT@8G5L;6%N_7K]('-A\&QA;6%D82#V;F5M;&ED:7(N
M(@H@("`@(#PO<&%R83X*("`@(#QP87)A/@H@("!!>7+]8V$@+"!B:7(@96UA
M:6QI(")297!L>2(@=F5Y82`B1F]R=V%R9"(@961E<FME;BP@8G4@:V]N=2!S
M873]<OT@>65N:2!M97-A:OUN:VEN92!K;W!Y86QA;OUR(&)U(&5M86EL(&MO
M;G7^;6%S_6YD82!H86YG:2!M97-A:FQA<OUN(&)I<FQI:W1E(&=I9&5R96L@
M8FER(")A:_UC_6S]:R(@;VQU_G1U<F1U\'5N=2!F87)K(&5T;65K(&'G_7/]
M;F1A;B#G;VL@>6%R87)L_2!B:7(@>6]L9'5R+B!":7(@]FYE<FD@;VQA<F%K
M+"!E\&5R(')E<&QI960@=F5Y82!F;W)W87)D960@;65S86IL87(@>65N:2!F
M:6MI<FQE<B!IYV5R:7EO<G-A+"`B2V]N=2(@<V%T_7+];OT@86S]8_UL87+]
M;B`B86O]8_UL_6LB(&EL97)L96UE<VEN:2!T86MI<"!E9&5B:6QM96QE<FD@
M:>=I;B!B:7)A>B!D9?!I_G1I<FUE:R!I<W1E>65B:6QI<G-I;FEZ+B(*("`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO
M;G,B(&UD-3TB-68Q9#4P83<S,V,X8C=E-#9A96-E8V4R.#@R,F9F-S`B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^365S86H@1/QZ96YL96YM97-I
M.B!39>=E;F5K;&5R/"]T:71L93X*("`@(#QH96%D:6YG/E-EYV5N96ML97(\
M+VAE861I;F<^"B`@("`\<&%R83X*0G4@4V7G96YE:VQE<B!M97-A:OUN_7K]
M(&AA>OUR;&%M86L@:>=I;B!S:7IE('EA<F3];2!E9&5R+B(*("`@("`@/"]P
M87)A/@H@("`@/'!A<F$^"MUM;&%N_7K](&MO;G1R;VP@971M96L@:>=I;B`B
M4W!E;&P@0VAE8VLB(&4@=/UK;&%Y_6XN(@H@("`@(#PO<&%R83X*("`@(#QP
M87)A/@I-97-A:F$@9&]S>6$@96ML97EE8FEL96-E\&EN:7H@<V%Y9F%N_6X@
M86QT(&O]<VW];F$@9VET;65K(&GG:6X@(D5K;&5R(B!E('3]:VQA>?UN+@H@
M("`@/"]P87)A/@H\<&%R83X*1?!E<B!G]FYD97)I;&UI_B!P;W-T86[];B!S
M86ML86YM87/];F$@>?9N971I8VEN:7H@=&%R86;];F1A;B!I>FEN('9E<FEL
M;6G^<V4L(")+;W!Y87/];OT@86PB(&YI;B!Y86[];F1A:VD@:W5T=7EU(&G^
M87)E=&QE>65R96L@9_9N9&5R9&GP:6YI>B!M97-A:OUN(&)I<B!K;W!Y87/]
M;OT@<V%K;&%M87G](&%K=&EF(&1U<G5M82!G971I<FUI_B!O;'5R<W5N=7HN
M($)U(&AE9&5F(&ML87/V<B!K96YD:2!H87K]<B!K;&%S]G+\(&1E(&]L86)I
M;&ER('9E>6$@<VEZ:6X@8G4@86UAYR!IYVEN(")39>=E;F5K;&5R+29G=#M+
M:?YI<V5L($)I;&=I;&5R+29G=#M+:6UL:6ML97(B+B!%\&5R('GV;F5T:6-I
M;FEZ(&?V;F1E<FEL96X@;6%I;&QE<FEN(&?V;F1E<FEL96-E\&D@>65R:2!S
M9>=M97EI(&%K=&EF(&5T=&EY<V4L(&ML87/V<OQN_'K\(&)U('-EYV5N9?!I
M;B!Y86[];F1A:VD@8?YA\/T@86MA;B!B:7(@;&ES=&5D96X@<V7G96)I;&EY
M;W(@;VQA8V%K<_UN_7HN(B`*/"]P87)A/@H\<&%R83X*1_9N9&5R9&GP:6YI
M>B#V;F5M;&D@92UP;W-T86QA<OUN(&MO<'EA;&%R_6[]('-A:VQA;6%K(&YE
M(&?V<OS^_&QD_/#\;OP@:V%Y9&5T;65K(&GG:6X@]FYE;6QI9&ER+B!"=6YU
M;FQA(&)I<FQI:W1E+"`B4V7G96YE:VQE<BTF9W0[2VG^:7-E;"!":6QG:6QE
M<BTF9W0[2VEM;&GP:2!D_'IE;FQE(F$@9VED97)E:RP@8G4@]GIE;&QI\&D@
M<VEZ:6X@:VEM;&GP:6YI>B!IYVEN9&4@;W1O;6%T:6L@;VQA<F%K(")AY_UK
M(B!Y87#];BX@4V7G96YE:VQE<FEN:7ID92!A>7+]8V$@8F%K_6T@9_9R979L
M97)I(&]L86X@:VQA<_9R;&5R:2!P97)I>6]D:6L@;VQA<F%K(&)O_F%L=&UA
M('9E>6$@>65N:61E;B!A9&QA;F3]<FUA>?T@9/QZ96YL97EE8FEL:7)S:6YI
M>BXB"CPO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M871T
M86-H(B!M9#4](CDX9&0S,&8S,F%F,69A.#9A.68P9F5A,S$R-&,T964Q(B!S
M=&%T93TB8VAA;F=E9"(^"B`@("`\=&ET;&4^365S86H@1/QZ96YL96YM97-I
M.B!%:SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB16LB/"]H96%D:6YG/@H@("`@
M/'!A<F$^"D7P97(@=&%R87G]8_UN_7H@9&]S>6$@>?QK;&5M97EI(&1E<W1E
M:VQI>6]R<V$@;65S86K];OUZ82!D;W-Y82!E:VQE>65B:6QI<G-I;FEZ+B!"
M:7(@:V5R961E(#$@9&5N(&9A>FQA(&1O<WEA('G\:VQE>65B:6QI<G-I;FEZ
M+B(*("`@("`@/"]P87)A/@H@("`@/'!A<F$^"D%D_6T@,3H@0G4@;65S86IA
M(&5K;&5M96L@:7-T961I\&EN:7H@9&]S>6%N_6X@>6]L=6YU('9E(&ES;6EN
M:2!Y87K];B!V97EA(")']GIA="(@='7^=6YA('3]:VQA>?UN('9E(&5K;&5M
M96L@:7-T961I\&EN:7H@9&]S>6%Y_2!S9>=I;BX@1&]S>6%N_6X@>6]L=2!V
M92!A9/T@_FEM9&D@16ML97(@:W5T=7-U;F1A(&?V<OQN_'EO<BXB"B`@("`@
M/"]P87)A/@H@("`@/'!A<F$^"D%D_6T@,CH@1&]S>6%N_7K];B!E:R!O;&%R
M86L@;?T@>6]K<V$@;65S86K];B!D979A;?T@:&%L:6YD92!S873]<FGG:2!M
M:2!O;&UA<_UN_2!I<W1E9&GP:6YI>F4@:V%R87(@=F5R:6XN($%L_6/];&%R
M_6X@;6%I;"!O:W5D=6ML87+]('EA>OUL_6W];B!M97-A:OUN(&EN;&EN92!G
M]G+\;G3\;&5N96X@9&]S>6$@=&EP:6YI(&)U;'5N9'5R;6%S_2!G97)E:VER
M+"!A:W-I(&AA;&1E(&)U(&O]<_UM(&5K(&]L87)A:R!G]GK\:_QR+B(*("`@
M(#PO<&%R83X*("`@/'!A<F$^"D%D_6T@,SH@(D5K;&4B('1U_G5N82!B87/]
M;BX@1&]S>6$@863]('9E(&+\>?QK;/SP_"!%:VQE<B!L:7-T96YI>F4@96ML
M96YE8V5K=&ER+B(*("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE
M;G1R>2!I9#TB8V]M<&]S92UA='1A8V@B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!='1A
M8V@\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=2!M87D@871T86-H(&9I
M;&5S('1O('EO=7(@;65S<V%G92!I9B!Y;W5R(&)R;W=S97(@<W5P<&]R=',@
M=7!L;V%D:6YG(&]F(&9I;&5S+B!-;W)E('1H86X@,2!F:6QE(&-A;B!B92!U
M<&QO861E9"!A="!O;F-E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`Q
M.B!%:71H97(@='EP92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A(&9I;&4@=&AA
M="!Y;W4@=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@;W(@8VQI8VL@
M=&AE(")"<F]W<V4B(&)U='1O;B!A;F0@<V5L96-T('1H92!F:6QE('1O(&)E
M(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD(&YA;64@;V8@=&AA="!F:6QE(&YO
M=R!A<'!E87)S(&EN('1H92!!='1A8VAM96YT(&)O>"X*("`@(#PO<&%R83X*
M("`@(#QP87)A/E-T97`@,CH@1&5C:61E('=H971H97(@>6]U('=A;G0@=&AE
M(&9I;&4@=&\@8F4@=FEE=V5D(&%S(&%N(&%T=&%C:&UE;G0@;W(@:6YL:6YE
M('=I=&@@=&AE(')E<W0@;V8@=&AE(&UE<W-A9V4N(%1H92!R96-I<&EE;G0G
M<R!M86EL(')E861I;F<@<V]F='=A<F4@;75S="!B92!A8FQE('1O(&AA;F1L
M92!T:&4@:6YL:6YE(&1I<W!L87D@;V8@=&AE(&9I;&4@='EP92P@;W1H97)W
M:7-E('1H:7,@<&%R="!W:6QL(&)E('9I97=E9"!A<R!A;B!A='1A8VAM96YT
M(&EN<W1E860N"B`@("`\+W!A<F$^"B`@("`\=&EP/@H@("`@4&QE87-E(&YO
M=&4@=&AA="!F;W(@;&%R9V4@9FEL97,@86YD+V]R('-L;W=E<B!);G1E<FYE
M="!C;VYN96-T:6]N<RP@=&AE('!R;V-E<W,@;V8@=7!L;V%D:6YG(&%N9"!A
M='1A8VAI;F<@>6]U<B!F:6QE('1O('1H92!E;6%I;"!M87D@=&%K92!A('=H
M:6QE+B!0;&5A<V4@8F4@<&%T:65N="!A;F0@9&\@;F]T(&-L:6-K(&]T:&5R
M(&QI;FMS(&]R(&)U='1O;G,@=VAI;&4@>6]U(&%R92!W86ET:6YG(&9O<B!A
M(&9I;&4@=&\@=7!L;V%D+@H@("`@/"]T:7`^"CPO96YT<GD^+2T^/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M871T86-H(CX*("`@
M(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N.B!!='1A8V@\+W1I=&QE/@H@
M("`@/&AE861I;F<^071T86-H/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9
M;W4@;6%Y(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4@:68@>6]U<B!B
M<F]W<V5R('-U<'!O<G1S('5P;&]A9&EN9R!O9B!F:6QE<RX@36]R92!T:&%N
M(#$@9FEL92!C86X@8F4@=7!L;V%D960@870@;VYC92X*("`@(#PO<&%R83X*
M("`@(#QP87)A/E-T97`@,3H@16ET:&5R('1Y<&4@=&AE('!A=&@@86YD(&YA
M;64@;V8@82!F:6QE('1H870@>6]U('=A;G0@871T86-H960@=&\@=&AI<R!M
M97-S86=E(&]R(&-L:6-K('1H92`B0G)O=W-E(B!B=71T;VX@86YD('-E;&5C
M="!T:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N86UE
M(&]F('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N="!B
M;W@N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#(Z($1E8VED92!W:&5T
M:&5R('EO=2!W86YT('1H92!F:6QE('1O(&)E('9I97=E9"!A<R!A;B!A='1A
M8VAM96YT(&]R(&EN;&EN92!W:71H('1H92!R97-T(&]F('1H92!M97-S86=E
M+B!4:&4@<F5C:7!I96YT)W,@;6%I;"!R96%D:6YG('-O9G1W87)E(&UU<W0@
M8F4@86)L92!T;R!H86YD;&4@=&AE(&EN;&EN92!D:7-P;&%Y(&]F('1H92!F
M:6QE('1Y<&4L(&]T:&5R=VES92!T:&ES('!A<G0@=VEL;"!B92!V:65W960@
M87,@86X@871T86-H;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@/'1I
M<#X*("`@(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S(&%N9"]O
M<B!S;&]W97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C97-S(&]F
M('5P;&]A9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T:&4@96UA
M:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@86YD(&1O
M(&YO="!C;&EC:R!O=&AE<B!L:6YK<R!O<B!B=71T;VYS('=H:6QE('EO=2!A
M<F4@=V%I=&EN9R!F;W(@82!F:6QE('1O('5P;&]A9"X*("`@(#PO=&EP/@H\
M+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6%T=&%C
M:&UE;G1S(B!M9#4](CAA8S`S,F,T86,Q.#)F,V8P9#8T-#9C,C!F,#`X.61D
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE<V%J($3\>F5N;&5N
M;65S:3H@16ML97(\+W1I=&QE/@H@("`@/&AE861I;F<^(D5K;&5R(CPO:&5A
M9&EN9SX*/'!A<F$^"D)U(&+V;/QM(&UE<V%J82#V;F-E9&5N(&5K;&5N;6G^
M(&]L86X@9&]S>6%L87+];B!L:7-T97-I;FD@9_9S=&5R:7(N(@H@("`@(#PO
M<&%R83X*/&AE861I;F<^16ML96YM:?X@9&]S>6%Y_2]D;W-Y86QA<OT@<VEL
M;64\+VAE861I;F<^"CQP87)A/@I%:VQE;FUI_B!D;W-Y87G]+V1O<WEA;&%R
M_2!S:6QM96L@:>=I;CH*("`@(#PO<&%R83X*/'!A<F$^"D%D_6T@,3H@4VEL
M;65K(&ES=&5D:?!I;FEZ(&5K;&5N;6G^(&1O<WEA*&QA<BG];B!Y86[];F1A
M:VD@:?YA<F5T;&5M92!D_/!M97-I;FD@86MT:79E(&5D:6XN"B`@("`\+W!A
M<F$^"CQP87)A/@I!9/UM(#(Z(")%:VQE;G1I($)I;&=I<VEN:2!3:6PB(&D@
M=/UK;&$N(@H@("`@/"]P87)A/@H\:&5A9&EN9SY%:VEN(%EA</US_6[]($1E
M\&G^=&ER;64\+VAE861I;F<^"CQP87)A/@I%:VEN:7II;B!Y87#]<_UN_2!D
M9?!I_G1I<FUE:R!IYVEN.@H@("`@/"]P87)A/@H\<&%R83X*063];2`Q.B!(
M97(@96MI;B!Y87#]<_UN_2!D9?!I_G1I<FEN("T@(G-A=/UR:>=I(B!V97EA
M(")E:R(@;VQA<F%K("T@:7-T96YI;&5N(&1E\&5R92XB"B`@("`\+W!A<F$^
M"CQP87)A/@I!9/UM(#(Z(")%:VQE;G1I($)I;&=I<VEN:2!996YI;&4B('EI
M('3]:VQA+@H@("`@/"]P87)A/@H\:&5A9&EN9SY%:VEN($'G_6ML86UA<_UN
M_2!$9?!I_G1I<FUE:SPO:&5A9&EN9SX*/'!A<F$^"D5K;&5R:6YI>FEN(&'G
M_6ML86UA<_UN_2!D9?!I_G1I<FUE:R!IYVEN("AA;/UC_6[];B!G]G)E8V7P
M:2!E:VD@8>?]:VQA>6%N(&UE=&EN*3H*("`@(#PO<&%R83X*/'!A<F$^"D%D
M_6T@,3H@0>?]:VQA;6$@86QA;OUN82!B:7(@8>?]:VQA;6$@9VER:6XN"B`@
M(#PO<&%R83X*/'!A<F$^"D%D_6T@,CH@(D5K;&5N=&D@0FEL9VES:6YI(%EE
M;FEL92(@>6D@=/UK;&$N(@H@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)C;VUP;W-E+7!R:6]R:71Y(B!M9#4](F(P,C,S-C=C,S9D93-C93$U
M-C=D,C=C8V%A-#4V-#!C(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/DUE<V%J($3\>F5N;&5N;65S:3H@UFYC96QI:SPO=&ET;&4^"B`@("`\:&5A
M9&EN9S[6;F-E;&EK/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@0G4@9VED96X@
M;65S86IL87+];OUZ82`B6"U0<FEO<FET>2(@8F'^;/WP_2!K;WEA<BX@(E@M
M4')I;W)I='DB(&5T:6ME=&D@3F5T<V-A<&4L($UO>FEL;&$L($]P97)A+"!V
M92!/=71L;V]K(&UA:6P@:7-T96UC:6QE<FEN:6X@:V%B=6P@971T:?!I(&)I
M<B!T_'(@(GEA;&%N8_T@<W1A;F1A<G0B=/UR+B!"=2!B8?YL_?#](&MU;&QA
M;FUA>6%N(&+\=/QN(&UA:6P@:7-T96UC:6QE<FD@]FYE;7-E;65Y96-E:W1I
M<BXB"B`@("`@(#PO<&%R83X@("`@"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C
M;VUP;W-E+7-A=F4M871T86-H;65N=',B(&UD-3TB9&(X.3DW,F,T96)B,&(T
M,6%B-CDQ8C9A-S<T-&$X,60B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET
M;&4^365S86H@1/QZ96YL96UE<VDZ($5K;&5R:2!+87ED970\+W1I=&QE/@H@
M("`@/'!A<F$^"D3\>F5N;&5M96YI>F1E:VD@96ML97)I;B!M97-A:FQA<FQA
M(&)I<FQI:W1E("!G]FYD97)I;&UI_BUP;W-T82!K;&%S]G+\;F4@:V%Y9&5D
M:6QI<"!K87ED961I;&UE9&EG:6YE(&MA<F%R('9E<FER+B)%=F5T(B!I<V4L
M96ML:2!V97)I(&MA>61E9&EL96-E:W1I<BX@(DAA>?UR(B!I<V4L(&5K;&D@
M=F5R:73\;2!A;/UC_6QA<F$@9_9N9&5R:6QD:6MT96X@<V]N<F$@;65S86ID
M86X@Y_UK87)T_6S]<BXB2&%Y_7(B(/T@<V7G;65K+"!K87ED961I;&UI_B!M
M97-A:FQA<F1A;B!E:VQI(&)I;&=I;&5R:2`H9V5N96QD92!B_'G\:R!O;'5R
M*2!K86QD_7)A<F%K(&1I<VL@86QA;OUN_7ID86X@=&%S87)R=68@<V'P;&%R
M+B(*("`@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UL:6YK+6%T=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-
M97-S86=E($-O;7!O<VET:6]N.B!,:6YK($%T=&%C:&UE;G1S/"]T:71L93X*
M("`@(#QP87)A/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM
M96YT<R!I;B!Y;W5R(&-O;7!O<VET:6]N(&%R92!S96YT(&%S(&$@<&%R="!O
M9B!T:&4@;6%I;"!M97-S86=E(&]R('=H971H97(@=&AO<V4@871T86-H;65N
M=',@87)E(&ME<'0@;VX@82!L;V-A;"!S97)V97(N("!)9B!A='1A8VAM96YT
M<R!A<F4@;&EN:V5D+"!T:&4@<F5C:7!I96YT*',I(&]F('EO=7(@;65S<V%G
M92!W:6QL(&)E('!R;W9I9&5D(&$@=V5B;&EN:R!W:&5R92!T:&5Y(&-A;B!D
M;W=N;&]A9"!T:&4@871T86-H;65N="AS*2X@($QI;FMI;F<@871T86-H;65N
M=',@:&%S('1H92!A9'9A;G1A9V4@;V8@=')E;65N9&]U<VQY(')E9'5C:6YG
M('1H92!S:7IE(&]F(&]U=&=O:6YG(&UE<W-A9V5S+B`@3&EN:VEN9R!A='1A
M8VAM96YT<R!H87,@=&AE(&1I<V%D=F%N=&%G92!T:&%T('1H92!C;VYT96YT
M(&]F('1H92!A='1A8VAM96YT<R!C86X@;F]T(&)E(&=U87)A;G1E960@=&\@
M8F4@879A:6QA8FQE(&EN('1H92!F=71U<F4@<VEN8V4@=&AE(&%T=&%C:&UE
M;G0@9&%T82!I<R!N;W0@;&]C871E9"!W:71H:6X@=&AE(&4M;6%I;"!M97-S
M86=E+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V5A<F-H
M(B!M9#4](C@V8C)E9C4W8C$Q.30X.3`X,S-D.61D-#EE8F,Y8C,R(B!S=&%T
M93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/DUE<V%J($3\>F5N;&5M97-I.B!-
M97-A:B!!<F%M83PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<F%M82!+<FET97)I
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@($9A<FML_2!A<F%M82!K<FET97)L
M97)I(&MU;&QA;F%R86L@:VQA<_9R;&5R:6YI>F1E(&UE<V%J;&%R_6[]>OT@
M87)A>6%B:6QI<G-I;FEZ"B`@("`@(#PO<&%R83X*("`@(#QP87)A/@H@("!!
M9/UM(#$Z($%R86UA(&MR:71E<FEN:7IE(&5K;&5M96L@:7-T961I\&EN:7H@
M86QA;FQA<F$@;65T:6X@9VER:6YI>BX*("`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("!!9/UM(#(Z($%R86UA(&MR:71E<FEN:7IE(&5K;&5M96L@:7-T961I
M\&EN:7H@;65S86H@8F%Y<F%K;&%R_6[]('-EYVEN:7HN"B`@("`\+W!A<F$^
M"CQP87)A/@H@($%D_6T@,SH@365S86H@87)A;6%K(&ES=&5D:?!I;FEZ(&ML
M87/V<OP@<V7G:6YI>BX*("`@(#PO<&%R83X*/'!A<F$^"B`@063];2`T.B`B
M07)A(B!Y_2!T_6ML87G];OUZ+@H@("`@/"]P87)A/@H\<&%R83X*("!%\&5R
M(&AE<FAA;F=I(&)I<B!M97-A:B!A<F%M82!K<FET97)I;FEZ92!U>75Y;W)S
M82P@8G4@;65S86IL87+];B!K;VYU;&%R_2`B07)A;6$@4V]N=>=L87+](B!E
M:W)A;OUN9&$@9_9R_&YT_&QE;F5C96MT:7(N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(@;60U/2(S,#8X-V5C
M-#<U-S8U8F$T-#8W9#)E9C9D8V5C-#!C,R(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93Y+;&%S]G(@6?9N971I;6DZ(%-EYV5N96ML97(\+W1I=&QE
M/@H@("`@/&AE861I;F<^2VQA<_9R(%-EYV5N96ML97)I/"]H96%D:6YG/@H@
M("`@/'!A<F$^"E-O;"!S_'1U;F1A:VD@8G5T;VYL87+](&MU;&QA;F%R86L@
M8FER(&ML87/V<B!S9>=E8FEL:7)S:6YI>BY"=6YU(&)I<B!K97H@>6%P=/UK
M=&%N('-O;G)A+&ML87/V<B#\>F5R:6YD92!G97+G96ML9?YT:7)M96L@:7-T
M961I\&EN:7H@=&5R8VEH:2!S;VQD86MI('-EYV5N96L@:W5T=7-U(&EL92!S
M9>=I;FEZ("`B(`H@("`@("`\+W!A<F$^"B`@("`\<&%R83X*4V]N<F%K:2!S
M9>=E;F5K;&5R(&GG:6X@=7EA<OUL86-A:W/];OUZ+E-I;&UE('-EYV5N9?!I
M(&MO;G5S=6YD82!D:6MK871L:2!O;'5N=7HL('EA;FS]_FS]:VQA('-I;&5R
M96L@:VQA<_9R9&5K:2!T_&T@;65S86IL87+];OUZ_2!K87EB961E8FEL:7)S
M:6YI>B$B"B`@("`@/"]P87)A/@H\:&5A9&EN9SYM8F]X($1O<WEA<_T@06QM
M86L\+VAE861I;F<^"B`@("`\<&%R83X*0G4@<V7G96YE:R!S9>=T:?!I;FEZ
M(&)I<B!K;&%S]G)E(&UB;W@@9F]R;6%T_6YD82!D;W-Y82!A;&UA;OUZ_2!S
M8?!L87(N($UE<V%J;&%R_2!A;&UA:R!IYVEN(#$H8FER*2!K;&%S]G(@<V7G
M:6YI>B!V92!D86AA('-O;G)A(&)U('1E<F-I:&D@<V7G:6YI>BY$86AA('-O
M;G)A(&UB;W@@9&]S>6%S_6[](&%L;6%K(&GG:6X@=7EA<F%N(&)I<B!S87EF
M87EA('GV;FQE;F1I<FEL96-E:W-I;FEZ+B`B"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M=VED9V5T<R(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^1F]L9&5R($YA=FEG871O<CH@1&ES<&QA>3PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY3:&]W+TAI9&4@56YS=6)S8W)I8F5D/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!)9B!U<VEN9R!)34%0(&9O;&1E<B!S=6)S8W)I
M<'1I;VYS+"!S:&]W+VAI9&4@=&AE('5N<W5B<V-R:6)E9"!F;VQD97)S+B!4
M;R!S=6)S8W)I8F4O=6YS=6)S8W)I8F4@=&\@82!F;VQD97(L('-E;&5C="!T
M:&4@8VAE8VMB;W@@;F5X="!T;R!T:&4@9F]L9&5R;F%M92!A;F0@=7-E('1H
M92!3=6)S8W)I8F4O56YS=6)S8W)I8F4@86-T:6]N(&EN('1H92!&;VQD97(@
M06-T:6]N(&1R;W`M9&]W;B!M96YU+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^17AP86YD($%L;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@17AP86YD
M(&%L;"!F;VQD97(@96YT<FEE<RX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/D-O;&QA<'-E($%L;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0V]L;&%P
M<V4@86QL(&9O;&1E<B!E;G1R:65S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R<R(@;60U/2(U968V,#<X-C<V-V4V,SAF8F8U
M8F$X9F,U8F0U9#ED,B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y&
M:6QT<F5L97(Z(%5Y9W5L83PO=&ET;&4^"B`@("`\:&5A9&EN9SY&:6QT<F4@
M2W5R86QL87+];OT@57EG=6QA/"]H96%D:6YG/@H@("`@/'!A<F$^"E3\;2!M
M97-A:FQA<OUN_7K](&)E;&ER;&5N;6G^(&MU<F%L;&%R82!G]G)E(&9I;'1R
M96QE;65K(&GG:6X@<&]S=&$@:W5T=7-U(&?V<OQN_&W\;F1E>6ME;B!'14Q%
M3B!+55154U4@863];OUN('EA;OUN9&%K:2`B1FEL=')E(%5Y9W5L82(@:6MO
M;G5N=2!T_6ML87G];OUZ+B(*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F9I;'1E<BUE9&ET+7)U;&5S(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y&:6QT97)S.B!%9&ET($9I;'1E<B!2=6QE<SPO=&ET;&4^"B`@("`\
M:&5A9&EN9SY%9&ET(%EO=7(@1FEL=&5R(%)U;&5S/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(@
M=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L
M971E+"!A;F0@961I="!T:&4@8W5R<F5N=&QY(&%C=&EV92!S970@;V8@9FEL
M=&5R(')U;&5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M9FEL=&5R+65D:70M8FQA8VML:7-T(B!M9#4](C@P9F8W.#`S8S8V-3DY8S<P
M,S5F-V8X.#$Q9#(Q.&-C(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/D9I;'1R96QE<CH@2V%R86QI<W1E>6D@9/QZ96YL93PO=&ET;&4^"B`@("`\
M:&5A9&EN9SY+87)A;&ES=&5N:7II(&3\>F5N;&5Y:6YI>CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("!!4TQ!('!O<W1A(&%L;6%K(&ES=&5M961I\&EN:7H@
M92UP;W-T82!A9')E<VQE<FEN:2!E:VQE>65B:6QE8V7P:6YI>BP@<VEL96)I
M;&5C9?!I;FEZ+"!D_'IE;FQE>65B:6QE8V5G:6YI>B!S87EF87EA('GV;FQE
M;F1I<FEL;65K(&GG:6X@(DMA<F%L:7-T96YI>FD@9/QZ96YL97EI;FEZ(B!I
M('3]:VQA>?UN_7HN(@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB9FEL=&5R+65D:70M=VAI=&5L:7-T(B!M9#4](C,S,&,S83AF860Q.3AC
M-V%F93@U-6,Q,#%C-C-C9#!F(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/D9I;'1R96QE<CH@0F5Y87IL:7-T97EI(&3\>F5N;&4\+W1I=&QE/@H@
M("`@/&AE861I;F<^0F5Y87IL:7-T96YI>FD@9/QZ96YL97EI;FEZ/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!(15(@6D%-04X@<&]S=&$@86QM86L@:7-T
M961I\&EN:7H@92UP;W-T82!A9')E<VQE<FEN:2!E:VQE>65B:6QE8V7P:6YI
M>BP@<VEL96)I;&5C9?!I;FEZ+"!D_'IE;FQE>65B:6QE8V5G:6YI>B!S87EF
M87EA('GV;FQE;F1I<FEL;65K(&GG:6X@(D)E>6%Z;&ES=&5N:7II(&3\>F5N
M;&5Y:6YI>B(@:2!T_6ML87G];OUZ+B(*("`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM;&]G:6XB(&UD-3TB,S=D.3(Y-V0Q
M8V-A-#8T,S5E,S9B-F4S.&4T-61C9&(B('-T871E/2)U<'1O9&%T92(^"B`@
M("`\=&ET;&4^1FEL=')E;&5R.B!/='5R=6T@0>=A<FME;B!&:6QT<F5L96UE
M:SPO=&ET;&4^"B`@("`\:&5A9&EN9SY&:6QT<F4@2W5R86QL87+];OT@3W1U
M<G5M($'G87)K96X@57EG=6QA/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@
M2&5R('IA;6%N($E-4"!D92!I;&L@;W1U<G5M(&'G_6S]<FME;B!F:6QT<F5L
M97)I('5Y9W5L86UA:R!IYVEN(&)U('-EYV5N9?!I(&G^87)E=&QE+@H@("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUO;BUD:7-P
M;&%Y(B!M9#4](F8U869C,S`U-#`R968U,F)A9#$P.#DS,V8S9C,S,CDQ(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D;=;'1R96QE<CH@665N:6QE
M<FME;B!F:6QT<F5L93PO=&ET;&4^"B`@("`\:&5A9&EN9SY'14Q%3B!+5515
M4U4G;G4@:&5R(&?V<OQN=/QL96UE9&4@9FEL=')E;&5R:2!U>6=U;&$\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($=%3$5.($M55%5352=N=2!H97(@9_9R
M_&YT_&QE;65D92!F:6QT<F5L97)I('5Y9W5L86UA:R!IYVEN(&)U('-EYV5N
M9?!I(&G^87)E=&QE+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB9FEL=&5R+6%N>2UM86EL8F]X(B!M9#4](C<Q8S4Q93@S.3`Y9CED,&)D
M-#0P9#(R,#<W,F5E,V,V(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/D9I;'1R96QE<CH@2&5R:&%N9VD@0FER(%!O<W1A($MU='5S=6YU($9I=')E
M;&5M96L\+W1I=&QE/@H@("`@/&AE861I;F<^1FEL=')E(&MU<F%L;&%R_6[]
M(&AE<FAA;F=I(&)I<B!P;W-T82!K=71U<W5N82!U>6=U;&%M86L\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($AE<FAA;F=I(&)I<B!P;W-T82!K=71U<W4@
M:>=I;B!F:6QT<F4@:W5R86QL87)N_2!U>6=U;&%Y86)I;&UE:R!IYVEM(&)U
M('-EYV5N9?!I(&G^87)E=&QE>6EN:7HN07-L_6YD82QF:6QT<F4@:W5R86QL
M87+]('-A9&5C92!'14Q%3B!+55153E5:02!G96QE;B!Y96YI('!O<W1A;&%R
M82!U>6=U;&%N_7(N($7P97(@8G4@<V7G96YE:R!I_F%R971L:7ES92P@=/QM
M('!O<W1A(&MU='5L87+];OUZ_6X@<V%Y9F%L87+];F1A(&\@:W5T=61A:VD@
M;65S86IL87)A(&9I;'1R92!K=7)A;&QA<OUN_2!U>6=U;&%M86[]>OT@<V'P
M;&%Y86-A:R!I:V]N;&%R('EE<B!A;&%C86MT_7(N3D]4.B!'14Q%3B!+5515
M4U4@9/W^_6YD86MI('!O<W1A(&MU='5L87+];F1A(&9I;'1R96QE;65K(&=A
M<FEP("CV<FYE:SH@1FEL=')E(&UE<V%J_6X@8FER(&MO<'EA<_UN_6X@9&%H
M82!B=2!K=71U>6$@9V5L;65S:6YE('-E8F5P(&]L86)I;&ER*2!V92]V97EA
M(&ES=&5N;65Y96X@<V]N=>=L87(@_')E=&5B:6QI<BCV<FYE:SH@365S86H@
M8G4@:W5T=7EA(&=E;&1I:W1E;B!S;VYR82!Y96YI(&9I;'1R92!K=7)A;&QA
M<OT@_')E=&EL:7)S92!M97-A:FQA<OUN('-I;&EN;65S:6YE+W1A_OUN;6%S
M_6YA('-E8F5P(&]L86)I;&ER*2XB"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M<'5B:V5Y(B!M9#4](CDW
M-#0V9&)B8C(W-C$V8C1F83,Y8F4X,#%E,3!D9C)D(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/E!'4#H@665R96P@06YA:'1A<B!%:VQE/"]T:71L
M93X*("`@(#QH96%D:6YG/EEE<F5L($%N86AT87(@16ML93PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("!%\&5R('-EYVEL:7ES92!01U`@>65R96P@86YA:'1A
M<OUN_7K];B!B:7(@:V]P>6%S_2P@9?!E<B!M979C=71S82P@9_9N9&5R:6QE
M;B!M97-A:F$@96ML96YE8V5K=&ER+B!01U`@07EA<FQA<OT@96MR86[];F1A
M;B!V87)S87G];&%N(&AA<F5K971I(&%Y87)L87EA8FEL:7)S:6YI>BX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO<'1I;VXM<V-A
M;BUB;V1Y(B!M9#4](C9B86%A9&$P9#0V9&,Q86(P.30Q,#@W9C(S-68S-3EB
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@365T:6X@9_9V
M9&5L97)I;FD@=&%R83PO=&ET;&4^"B`@("`\:&5A9&EN9SY-971I;B!G]G9D
M96QE<FEN:2!T87)A/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@($7P97(@24U0
M('-EYVEL9&EY<V4L(&UE=&EN(&UE<V%J;&%R_6[];B!G]G9D96QE<FEN:2!0
M1U`@8FEL9VES:2!IYVEN(&%R87EA8V%K=/UR('9E(&AE<FAA;F=I(&)I<B!B
M:6QG:2!B=6QU;F1U\'5N9&$@9_9R_&YT_&QE>65C96MT:7(N($)U(&G^;&5M
M('3\;2!M971I;B!M97-A:FQA<OT@:>=E<FGP:6YD92!01U`@8FEL9VES:2!O
M;'5P(&]L;6%D_?#](&MO;G1R;VP@961I;&5C9?!I(&GG:6X@<VES=&5M:2`*
M("`@>6%V8?YL871A8FEL:7(N"B`@("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F-O;7!O<V4M;W!T:6]N<RUE;F-R>7!T(B!M9#4](C$P,3(Q
M-#1F-S0Y9C$Y9C5A,C1C968S.#8P,61A83<Q(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/D]L=?YT=7(Z(-YI9G)E;&5M92!39>=E;F5K;&5R:3PO
M=&ET;&4^"B`@("`\:&5A9&EN9S[>:69R96QE;64@>6]K/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!-97-A:OT@_FEF<F5L96UE(&]L;6%D86X@>6]L;&$@
M*'-A9&4@;65T:6XI+@H@("`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@
M365S86K](-YI9G)E;&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($)U('-E
MYV5N96L@86MT:68@;65S86K]+"!01U`@=F4@86S]8_UL87+];B!K:?YI<V5L
M(&=E;F5L(&%N86AT87)L87+];OT@:W5L;&%N87)A:R#^:69R96QE<B!V92!Y
M;VQL87(N($)U('-EYV5N9?!I(&MU;&QA;F%R86L@<V%D96-E(&)I<B!K:?YI
M>64@;65S86H@>6]L;&%Y86)I;&ER<VEN:7HN($%L_6/];OUN(&=E;F5L(&%N
M86AT87+];OUN(&%D<F5S(&1E9G1E<FEN:7ID92!O;&UA<_T@9V5R96MI<B!A
M:W-I('1A:V1I<F1E(&)U(`H@("`@<V7G96YE:R#G86S]_FUA>6%C86MT_7(N
M($%L_6/];OUN(&=E;F5L(&%N86AT87+](&%D<F5S(&1E9G1E<FEN:7ID92!O
M;&1U\'4@:&%L9&4@:&%L82!H871A;&%R(&%L_7EO<G-A;OUZ+"!A;/UC_2!A
M;&%N_6YD86MI(&4M<&]S=&$@861R97-I>6QE(&=E;F5L(&%N86AT87+];B!T
M=71U;&1U\'4@>65R9&5K:2!E+7!O<W1A(&%D<F5S:6YI;B!E_FQE_G1I\&EN
M:2!K;VYT<F]L(&5D:6YI>BXB"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY0
M1U`@365S86K](-UM>F%L83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@0G4@
M<V7G96YE:R!A:W1I9B!M97-A:OT@=F4@:VG^:7-E;"!G96YE;"!A;F%H=&%R
M_6[]>OT@4$=0(&MU;&QA;F%R86L@9&EJ:71A;"!O;&%R86L@:6UZ86QA>6%C
M86MT_7(N($)U(&1E=G)E9&4@9V5N96P@86YA:'1A<OUN_7H@:>=I;B#^:69R
M92!G:7)M961I>7-E;FEZ+"!S:7ID96X@_FEF<F4@9VER;65N:7H@:7-T96YE
M8V5K=&ER+B!!;/UC_6[];B!S:7II;B!I;7IA;OUZ_2!D:6II=&%L(&]L87)A
M:R!D;_!R=6QA;6%S_2`*("`@(&GG:6X@9V5N96P@86YA:'1A<OUN_7K];B!B
M:7(@:V]P>6%S_6YA('-A:&EP(&]L;6%L_63]<BX*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E!'4"#=;7IA;&%M82_>:69R96QE;64@365S86K]/"]H96%D
M:6YG/@H@("`@/'!A<F$^0G4@<V7G96YE:R!I;&L@;VQA<F%K(&UE<V%J_6[]
M>OT@9&EJ:71A;"!O;&%R86L@:6UZ86QA>6%C86L@=F4@<V]N<F$@Y_UK=/UY
M_2#^:69R96QE>65C96MT:7(N($1A:&$@9F%Z;&$@8FEL9VD@:>=I;B`B4$=0
M($UE<V%J_2#>:69R96QE(B!V92`B4$=0($UE<V%J_2#=;7IA;&$B(&)A_FS]
M:VQA<OUN82!B86O];OUZ+B(*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O
M34E-12!-97-A:OT@WFEF<F5L93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M(%1/1$\*("`@(#PO<&%R83X*("`@/&AE861I;F<^4R]-24U%($UE<V%J_2#=
M;7IA;&$\+VAE861I;F<^"B`@("`\<&%R83X*("`@("!43T1/"B`@("`\+W!A
M<F$^"B`@(#QH96%D:6YG/E,O34E-12!-97-A:OT@W6UZ86QA+]YI9G)E;&4\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@("!43T1/"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I97<B(&UD-3TB,C1B-3$S
M.&(T8C4S9C<S8C5F,F8R-S,Y931C,3@U.&0B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^4$=0.B!'96YE;"!"86O]_CPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY01U`@;F5D:7(_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!01U`@
M9_QV96YL:2!B8?!L86YT_2!V92!B:6QG:2!D97!O;&%M82!IYVEN(&)I<B!A
M<F'G=/UR(/9Z96QL:6ML92!E+7!O<W1A(&EL92!K=6QL86YM86L@:>=I;BX@
M0FEL9VEY:2#^:69R96QE;65K('9E(&1I:FET86P@:6UZ86QA<B!H87K]<FQA
M;6%K(&GG:6X@:W5L;&%N_6QA8FEL:7(N($E-4"!B=2#V>F5L;&GP:2!S8?!L
M86UA:R!IYVEN($=.52!'_'9E;FQI:R!"96OG:7-I;FD@:W5L;&%N_7(N"B`@
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"#V>F5L;&GP:6YI(&%K=&EF
M(&5T/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1?!E<B!B=2!S9>=E;F5K
M('-EYVEL:7)S92P@:VG^:7-E;"!01U`@86YA:'1A<FQA<OT@>6%R871A8FEL
M:7(O9_9R_&YT_&QE>65B:6QI<BP@9&GP97(@8FER97EL97)D96X@9V5N96P@
M86YA:'1A<FQA<B!E:VQE>65B:6QR+W-I;&5B:6QI<BP@_FEF<F5L:2!P;W-T
M86QA<OT@;VMU>6%B:6QI<BP@9&EJ:71A;"!O;&%R86L@:6UZ86QA;FW]_B!M
M86EL;&5R:2!D;_!R=6QA>6%B:6QI<BP@=F4@9VED96X@;6%I;&QE<FEN:7II
M(/YI9G)E;&5Y96)I;&ER+VEM>F%L87EA8FEL:7)S:6YI>BX*("`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T=&%C:"UP
M=6)K97DB(&UD-3TB-38Q8V4T,S,W,&%C-&%F8F-C,V8Y.#$X8SAF8F,R9C8B
M('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0.B!39>=E;F5K;&5R
M("T@1V5N96P@06YA:'1A<B!%:VQE/"]T:71L93X*("`@(#QH96%D:6YG/E-E
MYV5N96ML97(@+2!'96YE;"!!;F%H=&%R($5K;&4\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($7P97(@<V7G:6QI<G-E(%!'4"!G96YE;"!A;F%H=&%R_6[]
M>OUN(&)I<B!K;W!Y87/]+"!E\&5R('9A<G-A+"!V87)S87G];&%N(&]L87)A
M:R!T_&T@9VED96X@<&]S=&%L87+];OUZ82!E:VQE;F5C96MT:7(N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;6%N86=E+7!U8FME
M>2(@;60U/2)B,C@Y96$U.#(T8C=F-CEF,S5C,#<U,30Y-V8T93%C,R(@<W1A
M=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z($=E;F5L($%N86AT87)L
M87+](%GV;F5T/"]T:71L93X*("`@(#QH96%D:6YG/D=A;F5L($)A:_W^/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!"=2!E:W)A;B!A9')E<R!D969T97)I
M;FEZ9&4@4$=0(&=E;F5L(&%N86AT87+](&]L86X@86MT:68@:W5L;&%N_6/]
M;&%R_2!L:7-T96QE<BX@0G4@:W5L;&%N_6/];&%R('EA(#$I(/YI9G)E;&D@
M;65S86H@>6]L;&%D_?#];OUZ('EA(&1A(#(I(&1I:FET86P@:6UZ82!D;_!R
M=6QA9/WP_6[]>B!K=6QL86[]8_UL87)D_7(N"B`@("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/D?V<OQN=/QL93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M4$=0(&=E;F5L(&%N86AT87+];OT@9_9R_&YT_&QE;65K(&GG:6X@8FER('!E
M;F-E<F4@8>=A<BX*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D%Y<OUN=/UL
M87(\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%!'4"!G96YE;"!A;F%H=&%R
M_2!H86MK_6YD82!B87K](&%Y<OUN=/UL87(@9_9S=&5R:7(N"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY3:6P\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($%D<F5S(&1E9G1E<FEN:7ID96X@9V5N96P@86YA:'1A<OT@<VEL97(N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M:6UP;W)T+7!U
M8FME>2(@;60U/2(V964Q,3,P8C0V93EF9C%C83EA9#-A,V$T-V4W8C,X,B(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z($=E;F5L($%N86AT
M87)L87+](%GV;F5T("T@1/W^86S];3PO=&ET;&4^"B`@("`\:&5A9&EN9SY'
M96YE;"!A;F%H=&%R;&%R_2!A;#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@
M0G4@='7^(&UA;G5E;"!O;&%R86L@4$=0(&=E;F5L(&%N86AT87+](&%L86)I
M;&5C9?!I;FEZ(&)I<B!P96YC97)E(&'G87(N($%N86AT87(@;65T:6X@86QA
M;OUN82!K;W!Y86QA;FW]_B!O;&%B:6QI<B!Y861A(&)I;&=I<V%Y87+];OUZ
M9&$@8FER(&1O<WEA9&$@:7-E+"!D_?YA<OUD86X@86S];2!Y87!A8FEL:7)S
M:6YI>BX@06YA:'1A<B!G9>=E<FQI>7-E(&%D<F5S(&1E9G1E<FEN:7IE(&=I
M<FEL8V5K('9E('!E;F-E<F4@:V%P86YA8V%K.R!E\&5R(&=EYV5R;&D@9&7P
M:6QS92P@;F5D96YI;FD@8>?]:VQA>6%N(&)I<B!H871A(&UE<V%J_2!D]FYE
M8V5K=&ER+@H@("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UO=F5R=FEE=RUP97)S;VYA;&ME>2(@;60U/2(R,C!A9C)B-S1A-3AF-#,P
M969D-S)D-F0V8C%F.3DS9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L
M93Y01U`Z($MI_FES96P@06YA:'1A<FQA<OT@6?9N970\+W1I=&QE/@H@("`@
M/&AE861I;F<^1V5N96P@0F%K_?X\+VAE861I;F<^"B`@("`\<&%R83X*1?!E
M<B!M97-A:FQA<OT@9&EJ:71A;"!O;&%R86L@:6UZ86QA;6%K(&ES=&EY;W)S
M86[]>B!V97EA(&1I\&5R;&5R:6YI;B!S:7IE(/YI9G)E;&D@;65S86H@9_9N
M9&5R;65S:6YI(&%K=&EF(&5T;65K(&ES=&EY;W)S86[]>BP@:VG^:7-E;"!G
M96YE;"_V>F5L(%!'4"!A;F%H=&%R(.=I9G1I;F4@<V%H:7`@;VQM86S]<_UN
M_7HN(@H@("`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY'96YE;"!!;F%H=&%R
M_6[]>CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1V5N96P@86YA:'1A<OUN
M_7H@<VEZ92#^:69R96QI(&UE<V%J(&?V9&5R;65S:6YI(&ES=&5D:?!I;FEZ
M(&MI_FQI97)E(&'G_6L@;VQM86S]9/UR(&MI(&)U(&UE<V%J_2!S861E8V4@
M<VEZ(.?V>F5B:6QI<G-I;FEZ*/9Z96P@86YA:'1A<OUN_7K](&MU;&QA;F%R
M86LN*2!%:R!O;&%R86L@9V5N96P@86YA:'1A<OUN_7H@9&EJ:71A;"!M97-A
M:B!Y;VQL863]\/UN_7H@:VG^:6QE<F4@8>?]:R!O;&UA;/UD_7(@+2!G96YE
M;"!A;F%H=&%R(&1I:FET86P@:6UZ87G](&1O\')U;&%M86L@:>=I;B!G97)E
M:VQI9&ER+@H@("`@(#PO<&%R83X*("`@("`\:&5A9&EN9S[6>F5L($%N86AT
M87+];OUZ/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("#6>F5L(&%N86AT87+]
M;OUZ(&=E;F5L(/YI9G)E;FEZ:2!K=6QL86YA<F%K(/YI9G)E;&5N;6G^(&UE
M<V%J;&%R_2#G]GIM96L@:>=I;B!G97)E:VQI9&ER+B!%:R!O;&%R86LL(/9Z
M96P@86YA:'1A<OUN_7H@9&EJ:71A;"!O;&%R86L@;65S86H@:6UZ86QA;6%K
M(&ES=&EY;W)S86[]>B!G97)E:VQI9&ER+B#6>F5L(&%N86AT87+];OUZ(&%N
M86AT87)L87(@;VQU_G1U<G5L9'7P=6YD82!B:7(@_FEF<F5Y;&4@:V]R=6YA
M8V%K=/UR+B!"=2!Y_'ID96X@]GIE;"!A;F%H=&%R_6[]>OT@9V5R96MT:7)E
M;G-B:7(@86MT:79I=&4@;VQD=?!U;F1A+"!)35`@_FEF<F5N:7II('-O<F%C
M86MT_7(N($AE<B!O='5R=6UD82#^:69R96YI>FD@8FER(&ME<F4@9VER;65N
M:7H@9V5R96MM96MT961I<B`M($E-4"!O='5R=6UU(&MA<&%T86YA(&MA9&%R
M(/YI9G)E;FEZ:2!S86ML87(N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<'5B;&EC(B!M9#4](C-C.#0T9#1F
M9CAF9&1A,V4P9#0T-F(T-V$V,S$Q-V4P(B!S=&%T93TB=7!T;V1A=&4B/@H@
M("`@/'1I=&QE/E!'4#H@2VG^:7-E;"!!;F%H=&%R;&%R_2!9]FYE="`M($=E
M;F5L($%N86AT87(\+W1I=&QE/@H@("`@/&AE861I;F<^1_9R_&YT_&QE/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!01U`@9V5N96P@86YA:'1A<OT@9_9R
M_&YT_&QE;65K(&GG:6X@8FER('!E;F-E<F4@8>=A<BX*("`@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^07ER_6YT_6QA<CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@4$=0(&=E;F5L(&%N86AT87+](&EL92!I;&=I;&D@8F%Z_2!A>7+]
M;G3];&%R(&?V<OQN=/QL97(N"B`@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!R:79A=&4B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!0<FEV
M871E($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY%;G1E<B!087-S<&AR87-E
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!T:&4@<&%S<W!H<F%S
M92!D:6%L;V<@=VEN9&]W+B!4:&4@<&%S<W!H<F%S92!E;G1E<F5D+"!I9B!C
M;W)R96-T+"!W:6QL(&)E('-T;W)E9"!B>2!)35`@=6YT:6P@>6]U<B!S97-S
M:6]N(&5N9',N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY5;FQO860@4&%S
M<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4F5M;W9E<R!T:&4@
M<W1O<F5D('!A<W-P:')A<V4@9G)O;2!)35`@+2!A;GD@861D:71I;VYA;"!U
M<V%G92!O9B!T:&4@<')I=F%T92!K97D@=VEL;"!R97%U:7)E('EO=2!T;R!R
M965N=&5R('1H92!P87-S<&AE87-E+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@82!W:6YD
M;W<@=&\@=FEE=R!T:&4@4$=0('!R:79A=&4@:V5Y+B!$3R!.3U0@4T5.1"!4
M2$E3($M%62!43R!!3EE/3D4@+2!T:&ES(&]P=&EO;B!I<R!S=')I8W1L>2!S
M;R!T:&%T('EO=2!C86X@97AP;W)T('EO=7(@24U0('!E<G-O;F%L('!R:79A
M=&4@:V5Y(&9O<B!U<V4@:6X@86YO=&AE<B!P<F]G<F%M+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<')I=F%T
M92!K97DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M
M<&5R<V]N86QK97DM9&5L971E(B!M9#4](F1B9#AC8F4V8F-E-S%C-&9B-3DR
M9&0Q8C-B,C=B-V-E(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'
M4#H@2VG^:7-E;"!!;F%H=&%R;&%R_2!9]FYE=&EN("T@4VEL/"]T:71L93X*
M("`@(#QH96%D:6YG/DMI_FES96P@06YA:'1A<FQA<OT@<VEL/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!"=2!T=?X@:VG^:7-E;"!G96YE;"_V>F5L(&%N
M86AT87(@YVEF=&EN:7II($E-4"!S9>=E;F5K;&5R:6YD96X@<VEL97(N"B`@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L
M:V5Y+6-R96%T92UN86UE(B!M9#4](C<T.&-B,3(T8C=F9C4R.#(P-SDR93(W
M.#`S-V$X8S(W(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@
M2VG^:7-E;"!!;F%H=&%R('EA<F%T("T@W7-I;3PO=&ET;&4^"B`@("`\:&5A
M9&EN9S[=<VEM/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!+:?YI<V5L(&%N
M86AT87)L87+];OUZ82!E:VQE;65K(&ES=&5D:?!I;FEZ(&ES:6TN($=E<F5K
M;&D@8FER(&%L86XN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6-O;6UE;G0B(&UD-3TB938V-F5B
M.68P964T8C0Y9F4P-&8W-&9C,3AD8C@V-#`B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^4$=0.B!+:?YI<V5L($%N86AT87(@>6%R870@+2!9;W)U
M;3PO=&ET;&4^"B`@("`\:&5A9&EN9SY9;W)U;3PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@2VG^:7-E;"!A;F%H=&%R;&%R_6[]>F$@96ML96UE:R!I<W1E
M9&GP:6YI>B!K87)A:W1E<B!D:7II<VDN($]P<VEY;VYE;"!B:7(@86QA;BX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA
M;&ME>2UC<F5A=&4M96UA:6PB(&UD-3TB8S<R.68W,&9D8C-A-S-C8F(W8F$U
M968U.#@X93,P.3(B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0
M.B!+:?YI<V5L($%N86AT87(@>6%R870@+2!%+7!O<W1A(&%D<F5S:3PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY%+7!O<W1A(&%D<F5S:3PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@($MI_FES96P@06YA;G1A<OUN_7IL82!E_FQE_G1I<FUE
M:R!I<W1E9&GP:6YI>B!E+7!O<W1A(&%D<F5S:2X@1V5R96ML:2!B:7(@86QA
M;BX*("`@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E
M<G-O;F%L:V5Y+6-R96%T92UK97EL96YG=&@B(&UD-3TB,C1C838T,6,V,V9B
M-69F,S$P83,Y964P9#-B,65E-34B('-T871E/2)U<'1O9&%T92(^"B`@("`\
M=&ET;&4^4$=0.B!+:?YI<V5L($%N86AT87(@>6%R870@+2!!;F%H=&%R(%5Z
M=6YL=?!U/"]T:71L93X*("`@(#QH96%D:6YG/D%N86AT87(@57IU;FQU\'4\
M+VAE861I;F<^"B`@("`\<&%R83X*W')E=&EL96X@86YA:'1A<OUN_7K];B!A
M;F%H=&%R(%5Z=6YL=?!U("AB>71E(&]L87)A:RDN($1E\&5R(&YE(&MA9&%R
M('G\:W-E:W-E(&MO<G5M82!O(&MA9&%R('G\:W-E:W1I<B`H=F4@87ER_6-A
M('G\:W-E:R#\<F5T:6T@=F4@_FEF<F5L96UE('/\<F5S:2DN(%9A<G-A>?UL
M86X@,3`R-"!B>71E("T@8G4@9&7P97(@;?QK96UM;65L(&MO<G5M82!S8?!L
M87(N"B`@("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP
M97)S;VYA;&ME>2UC<F5A=&4M<&%S<W!H<F%S92(@;60U/2(R9F(Y,S<R.3<P
M8F8S,V8U,64Y.#AB83,Y9&)D-S$Y,R(@<W1A=&4](G5P=&]D871E(CX*("`@
M(#QT:71L93Y01U`Z($MI_FES96P@06YA:'1A<B!Y87)A="`M(-YI9G)E/"]T
M:71L93X*("`@(#QH96%D:6YG/MYI9G)E/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!+:?YI<V5L(/9Z96P@86YA:'1A<OUN_7K](/YI9G)E;&5M96L@=F4@
M:V]R=6UA:R!IYVEN(&MU;&QA;OUL86X@_FEF<F4N($)U(&5N(&%Z(#8@:V%R
M86MT97(@;VQM86S]+"!O='5R=6T@8>=M82#^:69R96YI>FQE(&%Y;OT@;VQM
M86UA;/TL(&%N;&%M;/T@8FER('/V>F/\:R!IYV5R;65M96QI+"!A>7+]8V$@
M:&5M(&YU;6%R82!H96T@:&%R9B!IYV5R;65L:2X@3VYA>6QA;6$@<_QR96-I
M(&GG:6X@8G4@_FEF<F5Y:2!I:VD@:V5Z(&=I<FUE;FEZ(&=E<F5K:7(N($=E
M<F5K;&D@8FER(&%L86XN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6%C=&EO;G,B(&UD-3TB,&8X
M,C,T.3,U8CDV-&,X,S4S,V(T96,T8S$U96(W,3(B('-T871E/2)U<'1O9&%T
M92(^"B`@("`\=&ET;&4^4$=0.B!+:?YI<V5L($%N86AT87(@>6%R870@+2!!
M:W-I>6]N/"]T:71L93X*("`@(#QH96%D:6YG/D%N86AT87)L87(@66%R870\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($MI_FES96P@1V5N96PO]GIE;"!A
M;F%H=&%R(.=I9G1I;FEZ:2!Y87)A=/UN('9E('-A:VQA>?UN+@H@("`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY!;F%H=&%R(,=I9G1I($%L/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!+:?YI<V5L+_9Z96P@86YA:'1A<B#G:69T:2!A
M;"X@0G4@='7^('9A<F]L86X@4$=0(&MI_FES96P@9V5N96PO]GIE;"!A;F%H
M=&%R(.=I9G1I;FEZ:2!A;&UA;OUZ(&GG:6X@8FER('!E;F-E<F4@8>=A<BX@
M06YA:'1A<FQA<B!M971I;B!A;&%N_6YA('EA</W^=/UR_6QM_?X@=F5Y82!L
M;VMA;"!B:6QG:7-A>6%R_6[]>F1A(&)I<B!D;W-Y861A(&]L86)I;&ER+"!O
M;FQA<OT@86QA8FEL:7)S:6YI>BX@06YA:'1A<FQA<B!G9>=E<FQI(&ES92!S
M9>=E;F5K;&5R:6YI>F4@96ML96YI<B!V92!P96YC97)E(&MA<&%N_7([(&7P
M97(@9V7G97)S:7IS92!N961E;B!G9>=E<G-I>B!O;&1U\'5N=2!AY_UK;&%Y
M86X@8FER(&UE<V%J(&3V;F5R+B(*("`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=R(@;60U/2)D,V,W-3)B,3,T-69B
M,F5C8V9E-3<U8S`W-#8Q.38S9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT
M:71L93Y3+TU)344Z($=E;F5L($)A:_W^/"]T:71L93X*("`@(#QH96%D:6YG
M/E,O34E-12!.961I<C\\+VAE861I;F<^"B`@("`\<&%R83X*4R]-24U%(&)I
M<B!AY_UK('9E(&MO;G1R;VP@961I;&5B:6QI<B!B:7(@>6]L;&$@9&EJ:71A
M;"!I;7IA;&%R+"!M97-A:B!G:7IL:6QI\&D@=F4@:7II;G-I>B!E<FG^:6T@
M:V]N=')O;&/\<_P@<V'P;&%Y86X@]GIE;"]G96YE;"!A;F%H=&%R(.=I9G1I
M('-I<W1E;6ED:7(N(%,O34E-12!S861E8V4@>6]L;&%Y86X@=F4@:7-T96YE
M;B!A;/UC_6QA<OUN(.?V>F5B:6QE8V7P:2#^:69R96QE;64@<V'P;&%R+B!-
M97-A:OT@>6]L;&%Y86X@:VG^:7EI(&1I:FET86P@:6UZ82!A<F%C_6S]\/UY
M;&$@=&%N_6UA;OUZ_2!S8?!L87(N($)U(/YI9G)E;&5M92!V92!D:6II=&%L
M(&EM>F%L86UA+"!A;/UC_6QA<OUN(&UE<V%J_6X@>6]L;&%N9/UK=&%N('-O
M;G)A(&1E\&G^=&ER:6QI<"!D9?!I_G1I<FEL;65D:?!I;FD@:V]N=')O;"!E
M=&UE;&5R:6YI('-A\&QA<BXB"B`@("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/E,O34E-12#V>F5L;&EK;&5R:6YI(&%K=&EF(&5T/SPO:&5A9&EN9SX*("`@
M(#QP87)A/@I%\&5R(&)U('-EYV5N96L@<V7G:6QI<G-E+"!K:?YI<V5L(%,O
M34E-12!A;F%H=&%R;&%R_6[]>OT@86QM87EA+"#^:69R96QE;FUI_B!P;W-T
M82!O:W5M87EA+"!D:6II=&%L(&]L87)A:R!I;7IA;&%N;?W^('!O<W1L87+]
M(&1O\')U;&%M87EA('9E(&=I9&5N('!O<W1A;&%R_6[]>OT@_FEF<F5L96UE
M+VEM>F%L86UA;OUZ82!O;&%N86L@=F5R:7(N(@H@("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W+7!E<G-O;F%L:V5Y
M(B!M9#4](CEF-&8S-F%E-S)C8C1A8F,W,S$P-C=D,S,X8F4S8CDX(B!S=&%T
M93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E,O34E-13H@2VG^:7-E;"!!;F%H
M=&%R;&%R/"]T:71L93X*("`@(#QH96%D:6YG/D=E;F5L($)A:_W^/"]H96%D
M:6YG/@H@("`@/'!A<F$^1?!E<B!M97-A:FQA<OT@9&EJ:71A;"!O;&%R86L@
M:6UZ86QA;6%K('9E>6$@_FEF<F5L96UE:R!I<W1I>6]R<V%N_7HL(&ME;F1I
M(&MI_FES96P@9V5N96PO]GIE;"!3+TU)344@86YA:'1A<B#G:69T:6YE('-A
M:&EP(&]L;6%L_7/];OUZ+B(*("`@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<VUI;64M:6UP;W)T+7!E<G-O;F%L+6-E<G1S(B!S=&%T93TB
M=7!T;V1A=&4B(&UD-3TB8V8P960R93-E,C1D,S!D961F.&-F968R8S(V-#4W
M-3DB/@H@("`@/'1I=&QE/E,O34E-13H@26UP;W)T(%!E<G-O;F%L($-E<G1I
M9FEC871E<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY);7!O<G0@4&5R<V]N86P@
M0V5R=&EF:6-A=&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!);7!O<G0@
M<&5R<V]N86P@8V5R=&EF:6-A=&5S(&9R;VT@82!02T-3(",Q,B!F;W)M870@
M9FEL92X@4$M#4R`C,3(@9FEL97,@:7,@=&AE(&9I;&4@=7-U86QL>2!G96YE
M<F%T960@=VAE;B!E>'!O<G1I;F<@82!K97D@9G)O;2!A(&)R;W=S97(@*&4N
M9RX@26YT97)N970@17AP;&]R97(L($9I<F5F;W@I(&]R(&9R;VT@82!C97)T
M:69I8V%T92!S=&]R92!M86EN=&%I;F5D(&)Y(&%N($]P97)A=&EN9R!3>7-T
M96T@*&4N9RX@5VEN9&]W<R!84"DN($EF('1H92!K97ES(&%R92!V86QI9"!T
M:&5Y('=I;&P@8F4@:6YS97)T960@:6YT;R!Y;W5R('!R969E<F5N8V5S(&%N
M9"!T:&4@=VEN9&]W('=I;&P@8VQO<V4[(&EF(&YO="!V86QI9"P@86X@97)R
M;W(@;65S<V%G92!W:6QL(&)E(')E='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M9&5L971E
M+7!E<G-O;F%L+6-E<G1S(B!M9#4](C`Q.&)B-F(V,6$W930Q-C@Y,F1E,C@X
M860Q8S@X,&8T(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E,O34E-
M13H@2VG^:7-E;"!397)T:69I:V%L87+](%-I;#PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY+:?YI<V5L(%-E<G1I9FEK86QA<OT@4VEL/"]H96%D:6YG/@H@("`@
M/'!A<F$^2VG^:7-E;"!397)T:69I:V%L87+];OUZ_2!S9>=E;F5K;&5R:6YI
M>F1E;B!S:6QI;BX@0G5N9&%N('-O;G)A(%,O34E-12!M97-A:FQA<OUN_7K]
M(&]N87EL87EA;6%Z('9E>6$@<VEZ92!G]F1E<FEL96X@4R]-24U%(&EL92#^
M:69R96QE;FUI_B!P;W-T86QA<OT@9_9R96UE>G-I;FEZ+B(*("`@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;6%N86=E+7!U8FME
M>2(@;60U/2(X8C9C-C,V.#1D,V0W,V(S9#`X-#`R-6$W.&9E-V4X."(@<W1A
M=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y3+TU)344Z($=E;F5L($%N86AT
M87)L87+](%GV;F5T/"]T:71L93X*("`@(#QH96%D:6YG/E,O34E-13H@1V5N
M96P@06YA:'1A<FQA<OT@6?9N970\+VAE861I;F<^"B`@("`\<&%R83Y3+TU)
M344@9V5N96P@86YA:'1A<B!L:7-T97-I;FD@>?9N970N"B`@("`@(#PO<&%R
M83X*("`@("`\:&5A9&EN9SY']G+\;OQM/"]H96%D:6YG/@H@("`@/'!A<F$^
M1V5N96P@06YA:'1A<OUN('EA;/UN(&UE=&YI;FD@9_9R+@H@("`@("`\+W!A
M<F$^"CQH96%D:6YG/D%Y<OUN=/UL87(\+VAE861I;F<^"B`@("`\<&%R83Y'
M96YE;"!A;F%H=&%R_6X@=&5K;FEK(&%Y<OUN=/UL87+];OT@9_9R_&YT_&QE
M+@H@("`@("`\+W!A<F$^"CQH96%D:6YG/E-I;#PO:&5A9&EN9SX*("`@(#QP
M87)A/E-EYVEL:2!G96YE;"!A;F%H=&%R_2!K87G]='1A;B!S:6PN($)I<B!K
M=6QL86[]8_T@:>=I;B!G96YE;"!A;F%H=&%R_2!S:6QM96LL(&\@:VG^:7EE
M(/YI9G)E;&5N;6G^('!O<W1A(&?V;F1E<FUE;FEZ:2!E;F=E;&QE<BX*("`@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')I;G1I;F<B('-T
M871E/2)U<'1O9&%T92(@;60U/2)F,C,S8S$Q8C9B-&$V8F5D96(V.&8Q9#5A
M,F$Y-S9D8B(^"B`@("`\=&ET;&4^4')I;G1I;F<\+W1I=&QE/@H@("`@/&AE
M861I;F<^4')I;G0@82!M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!4;R!P<FEN="!A(&UE<W-A9V4@>6]U(&%R92!V:65W:6YG+"!C;&EC:R!O
M;B!T:&4@(E!R:6YT(B!L:6YK(&%T(&5I=&AE<B!T:&4@=&]P(&]R(&)O='1O
M;2!O9B!T:&4@;65S<V%G92X@5&AE(&UE<W-A9V4@=VEL;"!O<&5N(&EN(&$@
M;F5W('=I;F1O=R!F;W)M871E9"!F;W(@<')I;G1I;F<N("!$97!E;F1I;F<@
M;VX@>6]U<B!W96(@8G)O=W-E<B!A;F0@;W!E<F%T:6YG('-Y<W1E;2P@=&AE
M('!R:6YT(&1I86QO9R!B;W@@;6%Y(&]P96X@9F]R('EO=2X@($EF(&ET(&1O
M97,@;F]T(&]P96XL('1H96X@<'5L;"!D;W=N('1H92!W96(@8G)O=W-E<B=S
M(")&:6QE(B!M96YU(&%N9"!C:&]O<V4@(E!R:6YT(B!T;R!O<&5N('1H92!P
M<FEN="!D:6%L;V<@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<V]R=&EN9R(@;60U/2(Q.&-D96%C,S@P,C=F935C-#)B86(V.3-F
M,F$T,C8P82(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y3_6[]9FQA
M;F3]<FUA('9E($=R=7!L86UA/"]T:71L93X*("`@(#QH96%D:6YG/D=I<FG^
M;&5R:2!3_6[]9FQA;F3]<FUA/"]H96%D:6YG/@H@("`@/'!A<F$^0FER(&UE
M<V%J(&QI<W1E<VD@9_9R_&YT_&QE<FME;BQM97-A:FQA<OUN_7K]('5Y9W5N
M('/\='5N(&)A_FS]\/UN82!T_6ML87EA<F%K(&AE<B!S_'1U;B!IYVEN('/]
M;OUF;&%N9/UR86)I;&ER<VEN:7HN(%/\='5N;&%R_2!A>F%L86X@=F4@87)T
M86X@<_UR82!A<F%S_6YD82!D9?!I_G1I<FUE:R!IYVEN('/\='5N(&)A_FS]
M\/UD86MI(&]K('-I;6=E<VEN92!T_6ML87G];BXB"B`@("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/D=R=7!L86UA/"]H96%D:6YG/@H@("`@/'!A<F$^365S
M86IL87+](&ME;F1I(&-E=F%P;&%R_7EL82!B:7)L:6MT92!K;VYU;&%R_6YA
M(&?V<F4@9W)U<&QA;6%K(&GG:6X@:V]N=2!S_'1U;G5N=6X@8F'^_6YD86MI
M(%M4:')E861=(&)A\&QA;G3]<_UN82!T_6ML87G];BX@3F]R;6%L(&MO;G4@
M<_UR86QA;6%S_6YA(&3V;FUE:R!IYVEN(&MO;G4@<_QT=6YU;G5N(&)A_OUN
M9&%K:2!;4W5B:F5C=%T@8F'P;&%N=/US_6YA('3]:VQA>?UN+B(*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F%L=&5R;F%T:79E+6US9R(@
M;60U/2(T.3<X,#<S9C<V.3<W8C9A9C9B-CDX,3!E-&0R,F$V-2(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93[';VMP87+G86S]+T%L=&5R;F%T:68@
M;65S86IL87(\+W1I=&QE/@H@("`@/'!A<F$^2W5L;&%N_6/];&%R(&)A>OT@
M;65S86IL87+](.=O:W!A<N=A;/TO86QT97)N871I9B!O;&%R86L@>6]L;&%Y
M86)I;&ER;&5R+D)U(&UE<V%J;&%R+$%93DD@:>=E<FGP:2!$1=#=WMU+(&9O
M<FUA=&QA<F1A(&?V<W1E<FER;&5R+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DB(&UD
M-3TB-3,P9F$R,&4P869B8S(U9F9D-#`X-S<Y-#@X,S(X.3DB('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^4V7G96YE:VQE<CH@0F%K_6TZ($?V;F1E
M<FEL;6G^+7!O<W1A;&%R(&ML87/V<OQN_"!A>6S]:R!O;&%R86L@>65N:61E
M;B!A9&QA;F3]<CPO=&ET;&4^"B`@("`\<&%R83Y"=2!S9>=E;F7P:2!H97(@
M87G];B!B8?[];F1A(&?V9&5R:6QM:?XM<&]S=&%L87(@:VQA<_9R_&[\('EE
M;FED96X@861L86YD_7)M86L@:7-T:7EO<G-A;OUZ('-EYVEN+B!+;&%S]G(@
M>65N:61E;B!A9&QA;F3]<OUL86-A:R!V92!Y96YI(&?V;F1E<FEL;6G^+7!O
M<W1A;&%R(&ML87/V<OP@>6%R873];&%C86MT_7(N(@H@("`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?
M;6]N=&AL>2(@;60U/2(P8F5E9#$V9&9D-CAE,F8R-64P8S8V.#<Q9F0U-#9D
M9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y39>=E;F5K;&5R.B!"
M86O];3H@1_9N9&5R:6QM:?XM<&]S=&%L87(@:VQA<_9R_&[\(&%Y;/UK(&]L
M87)A:R!S:6P\+W1I=&QE/@H@("`@/'!A<F$^0G4@<V7G96YE\&D@:&5R(&%Y
M_6X@8F'^_6YD82!G]F1E<FEL;6G^+7!O<W1A;&%R(&ML87/V<OQN_"!S:6QM
M96L@:7-T:7EO<G-A;OUZ('-EYVEN+B!"=2!K;W1A;OUZ('9A<G-A(&MU;&QA
M;OW^;/T@;VQA8FEL:7(N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K965P(B!M9#4]
M(C<Q960Q8S)E86(T.&(Y,6$R-6(U8F-D-&(Q-&-C96$Y(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/E-EYV5N96ML97(Z($)A:_UM.B!']FYD97)I
M;&UI_BUP;W-T86QA<B!K;&%S]G+\;OP@87EL_6L@;VQA<F%K('-I;"`M('-A
M:VQA;F%C86L@:VQA<_9R('-A>?US_3PO=&ET;&4^"B`@("`\<&%R83YE\&5R
M(&5S:VDM9_9N9&5R:6QM:?X@<&]S=&%L87(@:VQA<_9R_&[\(&AE<B!A>2!S
M:6QI>6]R<V%N_7HL(&)U(&1O<WEA;&%R_2!K8><@87D@9&%H82!S86ML86UA
M:R!I<W1I>6]R<W5N=7H_($)U('/\<F5D96X@9&%H82!E<VMI(&ML87/V<FQE
M<FEN:7H@<VEL:6YE8V5K=&ER+B(*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+61E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY(B!M
M9#4](C,W,V5A,#)E9&4V9&8U9F,S-#5C868V,S)E,3EA-S5F(B!S=&%T93TB
M=7!T;V1A=&4B/@H@("`@/'1I=&QE/B)39>=E;F5K;&5R.B!"86O];3H@0F'P
M;/T@96ML96YT:6QE<FD@87EL_6L@;VQA<F%K('-I;#PO=&ET;&4^"B`@("`\
M<&%R83Y"=2!S9>=E;F7P:2!H97(@87D@8F'^_6YD82!E<VMI(&5K;&5N=&EL
M97)I;FEZ:2!S:6QM96L@:7-T:7EO<G-A;OUZ('-EYVEN+B!"=2!K;W1A;OUZ
M('9A<G-A(&MU;&QA;OW^;/T@;VQA8FEL:7(N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N
M=&AL>5]K965P(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,6(S-#!A-C`R,31D
M9F9D,#1A96,P,F-C,3$R-V1F-60B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!-86EN=&5N86YC93H@1&5L971E($QI;FME9"!!='1A8VAM96YT<R!-;VYT
M:&QY("T@(R!O9B!-;VYT:',@=&\@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!A<F4@9&5L971I;F<@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!E=F5R>2!M;VYT:"P@:&]W(&UA;GD@;6]N=&AS(&]F(&]L9"!A='1A8VAM
M96YT<R!D;R!Y;W4@('=A;G0@=&\@:V5E<#\@($%N>2!A='1A8VAM96YT<R!O
M;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT:',@=VEL;"!B92!D96QE=&5D+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?
M=')A<V@B(&UD-3TB9&,W,3@W,3$T-F)E,V4T-F%D93`P.#=A.&-F,3@R-S,B
M('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4V7G96YE:VQE<CH@0F%K
M_6TZ(,?V<"!K=71U<W5N=2!T96UI>FQE/"]T:71L93X*("`@(#QP87)A/L?V
M<"!K=71U;G5Z=2!B=2!K861A<B!S_6L@=&5M:7IL96UE:R!I<W1I>6]R(&UU
M<W5N=7H_"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUP=7)G95]T<F%S:%]I;G1E<G9A;"(@;60U/2(W8F4Y,69B96(P-6(R9#@W
M,C@Y9#1C-38P,F0U83,R9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L
M93Y39>=E;F5K;&5R.B!"86O];3H@Q_9P(&MU='5S=6YU('1E;6EZ;&5M92!A
M<F%L_?#]/"]T:71L93X*("`@(#QP87)A/L?V<"!K=71U;G5Z=2!N92!K861A
M<B!S_6ML_6ML82!T96UI>FQI>6]R<W5N=7H_"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]K965P(B!M9#4]
M(C-C8C5A,F(U8C@P8C=A8S$Q-SEA93`P-68Y.#,Y-S!E(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/E-EYV5N96ML97(Z($)A:_UM.B#']G`@:W5T
M=7-U;G4@=&5M:7IL97)K96X@='5T/"]T:71L93X*("`@(#QP87)A/L?V<"!K
M=71U;G5Z=2!T96UI>FQE<FME;B!K8><@9_QN;/QK(&UA:6QL97(@<VEL:6YM
M96QI9&ER+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M871T<FEB7W1E>'0B(&UD-3TB-S(Q83`Y9#=C83`R.&,Y-V4S8F0R8C,X
M8S4Y-V9F9C<B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4V7G96YE
M:VQE<CH@365S86H@2V]M<&]Z:7-Y;VYU(#H@<VEM9V5S96P@365T:6X\+W1I
M=&QE/@H@("`@/'!A<F$^0G5R9&$@<&]S=&%L87)A(&-E=F%P('9E<FER:V5N
M(&?V<OQN;65S:6YI(&ES=&5D:?!I;FEZ('/V>F/\\/P@>6%Z_6XN"B`@("`@
M(#PO<&%R83X*("`@(#QP87)A/D-E=F%P('9E<F1I\&EN:7H@<&]S=&%D82!M
M97-A:FQA(&EL9VEL:2!B:6QG:6QE<B!V97)M96L@:>=I;B!Y97)T=71U8W5L
M87(@:W5L;&%N86)I;&ER<VEN:7HN('EE<G1U='5C=6QA<B`G)2<@=F4@=&%K
M:7`@961E;B!B:7(@:V%R86MT97)D96X@;VQU_G5R+B!B87K]('EE<B!T=71U
M8W5L87(@_G5N;&%R9/UR.B(*("`@("`\+W!A<F$^"B`@("`\<&%R83XE9B`Z
M($?V;F1E<F5N:6X@863]('9E(&4M<&]S=&$@861R97-I"B`@("`\+W!A<F$^
M"CQP87)A/B5A(#H@1_9N9&5R96YI;B!E+7!O<W1A(&%D<F5S:0H@("`@/"]P
M87)A/@H\<&%R83XE<"`Z($?V;F1E<F5N:6X@863]"B`@("`\+W!A<F$^"CQP
M87)A/B5R(#H@=/QM(%)&0R`R.#(R('-T:6QI('1A<FEH('9E('IA;6%N(&1I
M;&EM:0H@("`@/"]P87)A/@H\<&%R83XE9"`Z(%1A<FEH('=W=RP@9V<@86%A
M('EY>7D*("`@(#PO<&%R83X*/'!A<F$^)7@@.B!687)S87G];&%N('EE<F5L
M('1A<FEH"B`@("`\+W!A<F$^"CQP87)A/B5C(#H@5F%R<V%Y_6QA;B!Y97)E
M;"!T87)I:"!V92!Z86UA;@H@("`@/"]P87)A/@H\<&%R83XE;2`Z($UE<V%J
M+6MI;6QI\&D*("`@(#PO<&%R83X*/'!A<F$^)7,@.B!+;VYU"B`@("`\+W!A
M<F$^"CQP87)A/B5N(#H@665N:2!":7(@<V%T_7(*("`@(#PO<&%R83X*/'!A
M<F$^)24@.B`G)2<@:V%R86MT97)I"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7W)E860B(&UD
M-3TB.#EE.3)C-&0V.#(R-&(R,S0U8C4Y.34Y.#<X83<Q-S0B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^4V7G96YE:VQE<CH@3VMU;F1U(&)I;&=I
M<VD@:7-T9?!I/"]T:71L93X*("`@(#QP87)A/B=/:W5N9'4@0FEL9VES:2#=
M<W1E9VDG($%L_6/];&%R9&%N(&UA:6QI;B!O:W5N9'7P=6YA(&1A:7(@8FEL
M9VD@9/9N;65S:2X@2&5R('IA;6%N(&1E<W1E:VQE;FUE>BX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W-E
M;F1?;61N(B!M9#4](C%F93`T935D8S-D938X9#$W,F1A,C@T.#DU.3<S96$Y
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E-EYV5N96ML97(Z($U$
M3B!Y;VQL83PO=&ET;&4^"B`@("`\<&%R83XG341.('EO;&QA)R!-97-A:B!5
M;&'^_6T@57EA<OUS_2`H365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VXI+"!B:7(@;65S86H@;VMU9'7P=6YU>F1A('EO;&QA;F%N(&UE<V%J_2!O
M:W5D=?!U;G5Z82!D86ER(&)I<B!U>6%R_2!I;&5T:7-I+"!M97-A:OT@>6]L
M87EA;B!K:?YI>64L('EO;&QA>6%N(&MI_FD@;VMU;F1U(&)I;&=I<VD@86QM
M86L@:7-T961I>7-E+"!I;&5T:6QI<BX@QV_P=2!D=7)U;61A(&)U(&G^;&5M
M('-I>F4@8FER('5Y87+]('9E<FEL;65D96X@>6%P_6S]<BX@0F%Z_2#V>F5L
M(&1U<G5M;&%R9&$@:7-E('5Y87+](&UA:6QI;FD@8FER(&QI;FME('3]:VQA
M>6%R86L@('EO;&QA;6%Y_2!T97)C:6@@961E8FEL:7)S:6YI>BXB"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO
M;E]R97%U97-T7V1E;&EV97)Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VX\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!$96QI=F5R>2!#;VYF:7)M
M871I;VXB('-E;F1S(&$@<F5Q=65S="!T;R!T:&4@<F5C:7!I96YT)W,@92UM
M86EL('-E<G9E<B!T;R!N;W1I9GD@>6]U('=H96X@:70@:&%S(&1E;&EV97)E
M9"!T:&4@;65S<V%G92!T;R!T:&4@<F5C:7!I96YT)W,@;6%I;&)O>"X@270@
M9&]E<VXG="!M96%N('1H92!M97-S86=E(&AA<R!B965N('-E96XL(&IU<W0@
M=&AA="!I="=S('-I='1I;F<@:6X@82!M86EL8F]X('-O;65W:&5R92X@3F]T
M(&%L;"!M86EL('-E<G9E<G,@<W5P<&]R="!T:&ES+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7W-P86U?869T97)?
M<F5P;W)T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M1&5L971E(%-P86T@069T97(@4F5P;W)T:6YG/"]T:71L93X*("`@(#QP87)A
M/@H@("`@66]U(&UA>2!E;&5C="!T;R!D;R!O;F4@;V8@=&AR964@:71E;7,@
M869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!E:71H97(@<W!A;2!O<B!I
M;FYO8V5N="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@1FER<W0L('EO
M=2!C86X@9&5C:61E('1O(&1O(&YO=&AI;F<@+2!T:&4@;65S<V%G92!W:6QL
M(&)E(')E<&]R=&5D(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C96YT(&)U="!W
M:6QL(&]T:&5R=VES92!R96UA:6X@=6YC:&%N9V5D(&EN('EO=7(@;6%I;&)O
M>"X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V5C;VYD+"!I9B!R97!O
M<G1I;F<@82!M97-S86=E(&%S('-P86TL('EO=2!C86X@:6YS=&5A9"!H879E
M('1H92!M97-S86=E(&)E(&EM;65D:6%T96QY(&1E;&5T960N("!4:&ES('-E
M='1I;F<@:&%S(&YO(&5F9F5C="!O;B!R97!O<G1I;F<@82!M97-S86=E(&%S
M(&EN;F]C96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!4:&ER9"P@
M869T97(@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!S<&%M('1H92!M97-S86=E
M('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD
M(&UO=F5D('1O('EO=7(@<W!A;2!F;VQD97(N("!!;'1E<FYA=&EV96QY+"!I
M9B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT('1H92!M97-S86=E
M('=I;&P@8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD
M(&UO=F5D('1O('EO=7(@24Y"3U@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUH=&UL7VEM86=E7W)E<&QA8V5M96YT(B!M9#4]
M(C(X93%C9C`X93,R.#,T-6$X93<R-S1C.#4S-#DR9#1F(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/E-EYV5N96ML97(Z($A434P@4F5S:6T@16YG
M96QL96UE/"]T:71L93X*("`@(#QP87)A/DA434P@;VQA<F%K(&%T_6QA;B!M
M97-A:FQA<F1A:VD@<F5S:6UL97)I;B!G]G+\;G3\;&5N;65S:2P@<VEZ(&%K
M<VEN:2!B96QI<G1E;F4@:V%D87(@96YG96QL96YI<BX@56YU=&UA>?UN(&MI
M(&5K;&5N=&D@;VQA<F%K(&?V;F1E<FEL96X@2%1-3"!D;W-Y86QA<OUN9&%K
M:2!R97-I;6QE<B!H97)Z86UA;B!G]G+\;G3\;&5N:7(N(@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M:'1M;%]I;6%G95]A9&1R
M8F]O:R(@;60U/2(W-3EF83-D9C(T93!A,V-D.#EF,S(P,3`R,C4R9CDQ82(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y39>=E;F5K;&5R.B!!9')E
M<R!$969T97)I;F1E($1E\&EL<V4@2%1-3"!297-I;2!%;F=E;&QE;64\+W1I
M=&QE/@H@("`@/'!A<F$^1_9N9&5R96X@:VG^:2!A9')E<R!D969T97)I;FEZ
M9&4@>65R(&%L_7EO<G-A+"!(5$U,(&)IYVEM:6YD92!G]FYD97)D:?!I(&UE
M<V%J;&%R9&%K:2!R97-I;6QE<B!G]G+\;G3\;&5N<VEN(&UI/R(*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A
M<G0B(&UD-3TB,V0Q,3DV9C(V-60X8C=C8S0V-65B9C(Q-3$R86-C,#4B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4V7G96YE:VQE<CH@4&]S=&$@
M2W5T=7-U($)A_FQA;F?]YR!3869Y87/]/"]T:71L93X*("`@(#QP87)A/E!O
M<W1A(&MU='5N=7IA(&EL:R!E<FG^=&GP:6YI>F1E(&?V<OQN=/QL96YM97-I
M;FD@:7-T961I\&EN:7H@<V%Y9F%Y_2!B96QI<FQE<BX@56YU=&UA>?UN(&MI
M(&]K=6YM86W]_B!M97-A:B!S9>=E;F7P:2P@:V]N=7EA(&?V<F4@<_UR86QA
M;6$@<V7G96YE\&D@:6QE(&)I<FQI:W1E(.=A;/W^;6%Z+B(@"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E7V%T=&%C:&UE
M;G1S(B!M9#4](C,U8C0V,S,T8V1C8S=F830Q-F(Y9CEF8V$U.#<T93@P(B!S
M=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E-EYV5N96ML97(Z($?V;F1E
M<FEL;6G^($UE<V%J;&%R9&%K:2!%:VQE;G1I;&5R:2!+87ED970N/"]T:71L
M93X*("`@(#QP87)A/D7P97(@9_9N9&5R9&GP:6YI>B!M97-A:OT@:V%Y9&5D
M96-E:W-E;FEZ(&'^8?#]9&%K:2!S9>=E;F5K;&5R:2!K=6QL86YA8FEL:7)S
M:6YI>CH*("`@("`@/"]P87)A/@H@("`@/'!A<F$^*B`G2&5R('IA;6%N(&5K
M;&5N=&EL97)I(&MA>61E="<@+2!!<VQA(&UE<V%J(&?V;F1E<FUE(&5K<F%N
M_6YD82!S:7ID96X@8FEL9VD@:7-T96YM97HN($5K;&5N=&EL97(@:&5R('IA
M;6%N(&UE<V%J;&$@8FER;&EK=&4@:V%Y9&5D:6QI<BXB(`H@("`@(#PO<&%R
M83X*("`@(#QP87)A/BH@)TAE<B!E:VQE;G1I(&?V;F1E<FEL9&GP:6YD92!S
M:7ID96X@8FEL9VD@:7-T96YI<B<@+2!(97(@>F%M86X@;65S86H@9_9N9&5R
M;64@96MR86[];F1A('-I>F1E;B!B:6QG:2!I<W1E;FER.R!!:W-I(&)E;&ER
M=&EL;65D:6OG92!E:VQE;G1I;&5R(&MA>61E9&EL:7(N(@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^*B`G2&5R(&5K;&5N=&D@9_9N9&5R:6QD:?!I;F1E('-I
M>F1E;B!B:6QG:2!I<W1E;FER)R`M($AE<B!Z86UA;B!M97-A:B!G]FYD97)M
M92!E:W)A;OUN9&$@<VEZ9&5N(&)I;&=I(&ES=&5N:7([($%K<VD@8F5L:7)T
M:6QM961I:^=E(&5K;&5N=&EL97(@:V%Y9&5D:6QM97HN(@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^*B`G2&GG8FER('IA;6%N(&5K;&5N=&EL97)I(&MA>61E
M=&UE)R`M($%S;&$@;65S86H@9_9N9&5R;64@96MR86[];F1A('-I>F1E;B!B
M:6QG:2!I<W1E;FUE>BX@16ML96YT:6QE<B!H:>=B:7(@>F%M86X@;65S86IL
M82!B:7)L:6MT92!K87ED961I;&UE>BXB("`*/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB=FER='5A;%]I;F)O>"(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L($EN8F]X/"]T:71L93X*
M("`@(#QP87)A/@H@("`@5FER=71A;"!);F)O>"!I<R!A('-A=F5D('-E87)C
M:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D('1O('-E87)C:"!E=F5R
M>2!M86EL8F]X(&9O<B!M97-S86=E<R!M87)K960@87,@;F5W+B`@26YS=&5A
M9"P@86QL(&-U<G)E;G1L>2!S=6)S8W)I8F5D(&UA:6QB;WAE<R!A<F4@<V5A
M<F-H960@9F]R(&YE=R!M97-S86=E<R!A;F0@=&AE(')E<W5L=',@87)E(&1I
M<W!L87EE9"!I;B!A('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T<F%S:"(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^5FER='5A;"!&;VQD97)S.B!6:7)T=6%L(%1R87-H/"]T
M:71L93X*("`@(#QP87)A/@H@("`@5FER='5A;"!4<F%S:"!I<R!A('-A=F5D
M('-E87)C:"!T:&%T(&1O97,@87=A>2!W:71H('1H92!N965D(&9O<B!A('-E
M<&%R871E(%1R87-H(&9O;&1E<BX@($EN<W1E860@;V8@;6]V:6YG(&UE<W-A
M9V5S('1O(&$@8V5N=')A;&EZ960@=')A<V@@9F]L9&5R+"!M97-S86=E<R!A
M<F4@<VEM<&QY(&UA<FME9"!A<R!D96QE=&5D(&EN('1H92!C=7)R96YT(&9O
M;&1E<B!T:&5Y(&QI=F4@:6XN("!7:&5N("=S:&]W(&1E;&5T960@;65S<V%G
M97,G(&ES('1U<FYE9"!O9F8L('1H:7,@<F5S=6QT<R!I;B!T:&5S92!M97-S
M86=E<R!N;W0@87!P96%R:6YG(&EN(&$@;6%I;&)O>"!V:65W+B`@5VAE;B!A
M('5S97(@8VQI8VMS(&]N(%9I<G1U86P@5')A<V@L("IA;&PJ(&UA:6QB;WAE
M<R!A;&P@<V5A<F-H960@9F]R(&UE<W-A9V5S('1H870@87)E(&9L86=G960@
M9&5L971E9"!A;F0@=&AE<V4@;65S<V%G97,@87)E(&1I<W!L87EE9"!I;B!A
M('-I;F=L92!M86EL8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]L;V-A;&4O=6M?54$O````````````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#$W
M-#4U`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]U:U]502],
M0U]-15-304=%4R\`````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<V,P`P,C$R-#(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O;&]C86QE+W5K7U5!+TQ#7TU%4U-!1T53+VEM<"YM;P``````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#4Q,#0V`#$P-#$W,S8R-S8S`#`R,C,V-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#>$@25`````#8!
M```<````S`D``*,!``!\$P````````@:```*````"1H```0````4&@``%P``
M`!D:```H````,1H``#(```!:&@``,@```(T:```;````P!H``"X```#<&@``
M-P````L;``!\````0QL```@```#`&P``#P```,D;```(````V1L```@```#B
M&P``&0```.L;```'````!1P```X````-'```!0```!P<```#````(AP``$X`
M```F'```4````'4<``!"````QAP```@````)'0``$0```!(=```[````)!T`
M``P```!@'0``"0```&T=```&````=QT```H```!^'0``"P```(D=```1````
ME1T```H```"G'0```P```+(=```(````MAT```D```"_'0``!````,D=```$
M````SAT```8```#3'0``#@```-H=```5````Z1T```(```#_'0``"@````(>
M```&````#1X```H````4'@``#0```!\>``!B````+1X``%\```"0'@``'```
M`/`>```.````#1\```P````<'P``#0```"D?```,````-Q\``!0```!$'P``
M#P```%D?```'````:1\``!````!Q'P``7````((?```$````WQ\```<```#D
M'P``#@```.P?```&````^Q\```T````"(```&@```!`@```=````*R```!D`
M``!)(```70```&,@```"````P2````4```#$(```!````,H@```0````SR``
M`!D```#@(```&@```/H@```&````%2$``!`````<(0``!P```"TA```0````
M-2$``!P```!&(0``"@```&,A```4````;B$``",```"#(0``!````*<A```2
M````K"$```4```"_(0``#@```,4A```$````U"$```4```#9(0``#0```-\A
M```5````[2$``"D````#(@``+````"TB```H````6B(```4```"#(@``$```
M`(DB```0````FB(```\```"K(@``"P```+LB```/````QR(```P```#7(@``
M#P```.0B```*````]"(``!(```#_(@``#0```!(C```,````(",```,````M
M(P``!P```#$C```*````.2,``!````!$(P``!P```%4C```(````72,``!D`
M``!F(P``!````(`C```,````A2,```0```"2(P``#````)<C```1````I",`
M``P```"V(P``"@```,,C```%````SB,```4```#4(P``!@```-HC```*````
MX2,```D```#L(P``$@```/8C```2````"20``!`````<)```"````"TD```)
M````-B0``!````!`)```&@```%$D```&````;"0```P```!S)```!P```(`D
M```+````B"0```(```"4)```!P```)<D```(````GR0```\```"H)```!P``
M`+@D```3````P"0```P```#4)```#@```.$D```,````\"0```X```#])```
M#P````PE```-````'"4```\````J)0``)@```#HE```+````824```8```!M
M)0``!P```'0E```$````?"4```4```"!)0```P```(<E```(````BR4```P`
M``"4)0``!````*$E```,````IB4```D```"S)0```@```+TE```9````P"4`
M`!(```#:)0``!````.TE```+````\B4```D```#^)0``#0````@F```,````
M%B8``!0````C)@``%@```#@F```%````3R8```P```!5)@``(P```&(F```-
M````AB8```T```"4)@``!P```*(F```(````JB8``!4```"S)@``'@```,DF
M```(````Z"8``!0```#Q)@``!0````8G```Q````#"<``!H````^)P``*```
M`%DG```I````@B<``"X```"L)P``-@```-LG```L````$B@``#$````_*```
M$````'$H```-````@B@```4```"0*```$P```)8H```-````JB@``!8```"X
M*```"````,\H```0````V"@``!4```#I*```$P```/\H```'````$RD``!4`
M```;*0``"P```#$I```6````/2D```L```!4*0``.@```&`I```-````FRD`
M``4```"I*0``#````*\I```-````O"D```X```#**0``!0```-DI```&````
MWRD``$L```#F*0``"@```#(J```'````/2H``#D```!%*@``!@```'\J```.
M````ABH```0```"5*@``!@```)HJ```*````H2H```L```"L*@``&@```+@J
M```7````TRH``!<```#K*@``#`````,K```3````$"L``!$````D*P``!@``
M`#8K``!#````/2L``#D```"!*P``#````+LK```1````R"L```0```#:*P``
M$````-\K```7````\"L``!(````(+```"P```!LL```-````)RP``!0````U
M+```+P```$HL```'````>BP```T```""+```%@```)`L```'````IRP```L`
M``"O+```!````+LL```S````P"P``!X```#T+```=0```!,M```^````B2T`
M`$(```#(+0``/0````LN```]````22X``"D```"'+@``*0```+$N```Q````
MVRX``"@````-+P``)@```#8O```^````72\``$<```"<+P``5P```.0O``!5
M````/#```%4```"2,```.P```.@P```/````)#$```4````T,0```@```#HQ
M```-````/3$```,```!+,0``"@```$\Q```3````6C$```@```!N,0``%@``
M`'<Q```,````CC$```<```";,0``!@```*,Q```:````JC$```@```#%,0``
M%````,XQ```'````XS$```<```#K,0``!@```/,Q```-````^C$```L````(
M,@``#````!0R```*````(3(```(````L,@``!@```"\R```#````-C(``"$`
M```Z,@``'0```%PR```9````>C(``!<```"4,@``10```*PR```G````\C(`
M`"L````:,P``'0```$8S```F````9#,``"4```"+,P``/0```+$S``!!````
M[S,``"@````Q-```+````%HT```/````AS0``!````"7-```!````*@T```"
M````K30```X```"P-```#P```+\T``!E`0``SS0```<````U-@```P```#TV
M```4````038``#H```!6-@``,@```)$V```N````Q#8``!L```#S-@``-```
M``\W```V````1#<``'D```![-P``"0```/4W```:````_S<```L````:.```
M$@```"8X```B````.3@```8```!<.```#P```&,X```)````<S@```,```!]
M.```0@```($X``!,````Q#@``$4````1.0``$0```%<Y```2````:3D``#$`
M``!\.0``#P```*XY```,````OCD```H```#+.0``!P```-8Y```'````WCD`
M``X```#F.0``"P```/4Y```#`````3H```\````%.@``"@```!4Z```$````
M(#H```8````E.@``"0```"PZ```.````-CH``!\```!%.@```@```&4Z```4
M````:#H```<```!].@``"P```(4Z```-````D3H``&@```"?.@``9`````@[
M```D````;3L``!(```"2.P``#0```*4[```-````LSL```P```#!.P``$@``
M`,X[```.````X3L```@```#P.P``%````/D[``!*````#CP```D```!9/```
M"0```&,\```1````;3P```@```!_/```#@```(@\```<````ESP``"4```"T
M/```&P```-H\``![````]CP```(```!R/0``!P```'4]```$````?3T``!``
M``""/0``)0```),]```E````N3T```<```#?/0``#0```.<]```'````]3T`
M``T```#]/0``(`````L^```+````+#X``!`````X/@``)````$D^```(````
M;CX``!$```!W/@``"````(D^```/````DCX```H```"B/@``!P```*T^```3
M````M3X``!@```#)/@``)@```.(^```N````"3\``"(````X/P``!P```%L_
M```/````8S\```\```!S/P``#@```(,_```-````DC\```\```"@/P``"0``
M`+`_```2````NC\```X```#-/P``%````-P_```0````\3\```L````"0```
M!`````Y````'````$T````X````;0```#@```"I````)````.4````H```!#
M0```%@```$Y````#````94````\```!I0```"````'E````/````@D```!8`
M``"20```#@```*E````0````N$````4```#)0```"````,]````*````V$``
M``X```#C0```!P```/)````-````^D```!0````(00``$0```!U!```$````
M+T$``!`````T00``&0```$5!```I````7T$```8```")00``#````)!!```%
M````G4$``"````"C00```@```,1!```(````QT$```T```#000``#P```-Y!
M```$````[D$```\```#S00``"@````-"```+````#D(```L````:0@``#@``
M`"9"```.````-4(```X```!$0@``#````%-"```J````8$(```@```"+0@``
M!P```)1"```(````G$(```D```"E0@``!@```*]"```$````MD(```L```"[
M0@``"@```,="```)````TD(```X```#<0@``$0```.M"```"````_4(``!8`
M````0P``(0```!=#```'````.4,```H```!!0P``"P```$Q#```*````6$,`
M``L```!C0P``$````&]#```0````@$,```<```"10P``"P```)E#```M````
MI4,```H```#30P``$````-Y#```'````[T,```8```#W0P``&````/Y#```?
M````%T0```@````W1```$P```$!$```'````5$0``#X```!<1```'P```)M$
M```I````NT0``"X```#E1```,````!1%``!!````144``#(```"'10``.```
M`+I%```/````\T4``!(````#1@``!````!9&```-````&T8```\````I1@``
M&0```#E&```-````4T8``!(```!A1@``%@```'1&```8````BT8```@```"D
M1@``%@```*U&```7````Q$8``!X```#<1@``#````/M&```[````"$<```P`
M``!$1P``"@```%%'```/````7$<```\```!L1P``#P```'Q'```(````C$<`
M``H```"51P``2@```*!'```1````ZT<```@```#]1P``-@````9(```%````
M/4@``!$```!#2```"0```%5(```'````7T@```L```!G2```$P```'-(```9
M````AT@``!4```"A2```%0```+=(```/````S4@``",```#=2```&`````%)
M```&````&DD``#\````A20``.@```&%)```0````G$D``!<```"M20``!0``
M`,5)```7````RTD``!D```#C20``$@```/U)```3````$$H``!P````D2@``
M'0```$%*```M````7TH```0```"-2@``"0```))*```5````G$H```<```"R
M2@``"@```+I*```%````Q4H``#$```#+2@``%````/U*``"`````$DL``"\`
M``"32P``/P```,-+```Q`````TP``#`````U3```'````&9,```;````@TP`
M`"D```"?3```&````,E,```>````XDP``#<````!30``/0```#E-``!)````
M=TT``$D```#!30``2@````M.```V````5DX```L```"-3@``!0```)E.```"
M````GTX```@```"B3@```P```*M.```-````KTX``!,```"]3@``"0```-%.
M```4````VTX```\```#P3@``"0````!/```(````"D\``!T````33P``$0``
M`#%/```6````0T\```X```!:3P``!0```&E/```'````;T\```P```!W3P``
M#0```(1/```-````DD\```\```"@3P```@```+!/```'````LT\```,```"[
M3P``'0```+]/```9````W4\``!@```#W3P``%0```!!0``!%````)E```"0`
M``!L4```(0```)%0```3````LU```#$```#'4```,0```/E0```M````*U$`
M`#@```!940``'````))1```?````KU$```L```#/40``%P```-M1```'````
M\U$```,```#[40``$@```/]1```3````$E(```$````Q`0``4@```(0````-
M`0``.0``````````````>`````````!1`````````,0````*`0``````````
M```J`0``@@```/T```#9````!P$```,!``"E````)0$````````9`0``&`$`
M`'\`````````G0`````````N`0```````+8```#B````;````+<````O`0``
M"P$````````4`````````$$`````````WP```"X````-````9@```'X````3
M`0``)0```%@```"'````U````/(````^````W@```#(!```:`0```````-P`
M```````````````````/`0````````````!S`````````$T````C`0``%@``
M`($````"`0``D0``````````````%@$````````5````[@````````"F````
M`````#,!``#_````E@```+0`````````Y0``````````````X0```!@```!D
M````-0$``$,````7`0```````$H````@`0```````'H```#8````A0````,`
M``#=````K@```!L!`````````````)````!J````]@`````````4`0``O```
M`"L!`````````````!L```#/````>P`````````B`0``*`$```$!````````
MR````!4!``!Q````$`$``*0````A`0``@P```*H```#G`````````.\````&
M`0```@```,(```#M````(@```"````!"````;0```%4````[`````````$X`
M```L`0``)````'<````H````+``````````Q``````````P```"-````\P``
M``H```!H`````````)4````F`0``B0```#````!7````$@```*P`````````
MTP````````"Q````*0$``%P````(`0``\````)0```#J`````````!<```"]
M````R0```*$```!P````_@```#,````K````/``````````)`0``1P```&``
M``#Y````9P````P!````````P`````````!Y````!0````````"S````QP``
M````````````BP```)X```"@`````````*\```#U````'````"$```#!````
M3````&\```"C`````````(H```!>````#@```.@```"Y````F````-(````<
M`0``"P```&$```!V````J0`````````````````````````_````4````"T`
M```Z````3P````8```#Z````$P```#T`````````JP```#8!````````````
M`````````````````)(```!3`````````),```"_`````````-L```"M````
MC@```&4````G`0```````#(````T`0``S0`````````2`0``-```````````
M````L@```(\````W````+P```+X`````````6@```&(```!K`````````$8`
M```:````7P`````````C````=````-8`````````&0```*@`````````_```
M`!\!``````````````````!%````+0$``/<```#+````L````.0```#L````
M-@````0```!I````C````,,`````````A@````````#@````0````$0```!C
M`````````$D```"U````6P```"0!``!4````T0````````#I````F0```)P`
M````````!0$``"H```":````)P````0!``#*`````````!T`````````````
M`/$```!+````2````"8````1`0``.````!T!```````````````````/````
M#@$``+L```"B````Q@```-H````(```````````````I````UP```-````#5
M`````````,X`````````N``````````P`0``-0````````";````$0```+H`
M```'``````````````!6````?````/@```!=``````````````!U````;@``
M`/L`````````@````````````0``Q0```!X!``````````````D```!R````
MZP```````````````````*<```!9````'P```'T`````````'@```.,```#F
M````$````/0`````````EP``````````````B````)\```#,`````"!3=6)J
M96-T.B``(&EN(``E9"!T;R`E9"!O9B`E9"!-97-S86=E<P`E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(&%L<F5A9'D@97AI
M<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&9O;&1E
M<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N`"5S
M.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*0`H07!P;'D@=&AE<V4@8VAA;F=E
M<R!A;F0@;6]V92!T;R!N97AT('-C<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N
M9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BD`*%)E='5R
M;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H
M86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@
M<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*0`R-"!H;W5R<P!!9&0@82!N
M97<@=7-E<CH`061D('!A:7(`061D('5S97(`061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!!9&1R97-S`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%L;`!!;&P@
M;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D
M;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@9FEL93H`06QL(&UE<W-A9V5S(&EN
M('EO=7(@(B5S(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@
M<&5R;6%N96YT;'D@9&5L971E9"X`06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N`$%N
M<W=E<F5D`$%N<W=E<F5D(&UE<W-A9V5S`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R<FEV
M86P@5&EM90!!<V-E;F1I;F<`071T86-H`$%T=&%C:&UE;G0`071T86-H;65N
M=',`079A:6QA8FQE(&9I96QD<SH`0F%C:R!T;R`E<P!"8V,`0FER=&AD87D`
M0FQA8VML:7-T`$)O9'D`0F]T:`!#86YC96P`0V%N8V5L($UE<W-A9V4`0V%N
M8V5L(%!R;V)L96T@4F5P;W)T`$-C`$-E;&P@4&AO;F4`0VAA;F=E`$-H86YG
M92!!;&P`0VAA;F=E($9O;&1E<@!#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U
M8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@
M86YD(&AO=R!M97-S86=E<R!A<F4@<V]R=&5D+@!#:&%N9V4@=&AE(&YA;64L
M(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#:&5C:R!&;VQD
M97(H<RD@9F]R($YE=R!-86EL`$-H;V]S92!!8W1I;VXZ`$-L;W-E(%=I;F1O
M=P!#;&]S960@1F]L9&5R`$-O;&QA<'-E($%L;`!#;VQL87!S92!!;&P@1F]L
M9&5R<P!#;VQL87!S92!&;VQD97(`0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D
M`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A
M;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV
M97,N`$-O<'D`0V]R<F5C=`!#;W)R96-T960@5&5X=`!#<F5A=&4`0W)E871E
M($9O;&1E<@!#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<@!#<F5A=&4@82!N
M97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R
M`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O
M;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@86YD(&1E;&5T92!S
M<&%M+@!$1`!$86EL>0!$871E`$1E9F%U;'0@261E;G1I='D`1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.@!$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.@!$
M96QE=&4`1&5L971E($9O;&1E<BAS*0!$96QE=&5D`$1E;&5T960@;65S<V%G
M97,`1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<P!$97-C96YD:6YG`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R
M($YE=R!-86EL`$1O;F4`1&]W;FQO860@1F]L9&5R*',I`$1R869T`$1R869T
M<R!F;VQD97(Z`$5D:70`16UA:6P`16UP='D@<F5S=6QT+@!%;F0@9F]R=V%R
M9&5D(&UE<W-A9V4`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T
M<R!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I
M;"!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O
M;&1E<@!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`
M179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X<&%N9"!!;&P`17AP86YD
M($%L;"!&;VQD97)S`$5X<&%N9"!&;VQD97(`17AP86YD($YA;65S`$9A>`!&
M:6QT97)S`$9I<G-T(%!A9V4`1F]L9&5R($YA=FEG871O<@!&;W)W87)D`$9O
M<G=A<F0Z`$9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,`1G)O;0!&<F]M($%D
M9')E<W,`2&5L<`!(:61E($1E;&5T960`2&ED92!5;G-U8G-C<FEB960`2&]M
M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`24Y"3U@`26=N;W)E`$EG;F]R
M92!!;&P`26UP;W)T86YT`$EM<&]R=&%N="!M97-S86=E<P!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!,86YG=6%G90!,87-T(%!A9V4`
M3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,
M;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G:6X@5&%S:W,`34T`36%I
M;&)O>`!-87)K(&%S.@!-871C:&EN9R!F:65L9',`365S<V%G90!-97-S86=E
M($-O;7!O<VET:6]N`$UE<W-A9V4@1&%T90!-97-S86=E(%-E87)C:`!-97-S
M86=E(%-I>F4`365S<V%G92!3;W5R8V4`365S<V%G92!6:65W:6YG`$UE<W-A
M9V4@9FQA9W,`365S<V%G92!F;VQD97)S`$UE<W-A9V5S('!E<B!P86=E(&EN
M('1H92!M86EL8F]X('9I97<N`$UE<W-A9V5S('1O`$UO9&EF>0!-;VYT:&QY
M`$UO=F4`3F5V97(`3F5W`$YE=R!-86EL`$YE=R!M97-S86=E<P!.97AT`$YE
M>'0@365S<V%G90!.97AT(%!A9V4`3F\`3F\@9F]L9&5R<R!W97)E('-P96-I
M9FEE9`!.;R!S<&5L;&EN9R!E<G)O<G,`3F]N90!.;W0@1&5L971E9`!.;W0@
M1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&1E;&5T960@
M;65S<V%G97,`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.;W1E<P!/;&0@;65S
M<V%G97,`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"X`3W1H
M97(@3W!T:6]N<P!086=E("5D(&]F("5D`%!A<G0H<RD`4&%S<W=O<F0`4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<P!097)S;VYA;`!097)S;VYA;"!);F9O<FUA=&EO;@!0:&]N90!0;&%C
M92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_
M`%!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z`%!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E<V]L=F4@86UB:6=U;W5S
M(&]R(&EN=F%L:60@861D<F5S<V5S+@!0;&5A<V4@<V5L96-T(&$@9F]L9&5R
M(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RX`4&QE87-E('-E;&5C
M="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"X`4&QE87-E('-E;&5C
M="!O;FQY(&]N92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+@!0<F5V:6]U
M<R!-97-S86=E`%!R979I;W5S(%!A9V4`4')I;G0`4')O8FQE;2!$97-C<FEP
M=&EO;@!0=7)G92!$96QE=&5D`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`4F5D
M:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I<F5C="!T:&ES(&UE<W-A9V4`
M4F5D:7)E8W1I;F<@9F%I;&5D+@!2969R97-H`%)E9G)E<V@@1F]L9&5R(%9I
M97=S.@!296QO860@5FEE=P!296UE;6)E<B!T:&4@;&%S="!V:65W`%)E;6]V
M92!P86ER`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;&%C92!W:71H.@!297!L>0!297!L
M>2!T;R!!;&P`4F5P;'D@=&\@06QL.@!297!O<G0@87,@4W!A;0!297-E=`!2
M97-U;64`4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L
M971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%-A=F4@1')A
M9G0`4V%V92!A<P!3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@)7,`4V5A<F-H`%-E87)C:"!297-U;'1S
M`%-E96X`4V5L96-T`%-E;&5C="!A;&P`4V5L96-T(&YO;F4`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5N9"!-97-S86=E`%-E;F0@4')O8FQE
M;2!297!O<G0`4V5N="!M86EL(&9O;&1E<CH`4V5R=F5R`%-E="!P<F5F97)E
M;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T
M92!M97-S86=E<RX`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S
M960@869T97(@<V%V:6YG(&$@9')A9G0_`%-H;W<@1&5L971E9`!3:&]W(%5N
M<W5B<V-R:6)E9`!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W!E8VEA;"!#:&%R86-T97)S`%-P96QL($-H96-K`%-P
M96QL($-H96-K97(`4W!E;&P@8VAE8VL@8V]M<&QE=&4`4W!E;&QI;F<@97)R
M;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RX`4W5B:F5C=`!3
M=6)J96-T($9I96QD`%-U8G-C<FEB92!T;R!&;VQD97(H<RD`4W5C8V5S<P!3
M=6=G97-T:6]N<P!497AT`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B('=I
M;&P@8F4@<F5N86UE9"!T;R`B)7,B+@!4:&4@9F]L9&5R("(E<R(@86QR96%D
M>2!E>&ES=',`5&AE(&9O;&1E<B`B)7,B(&-O;G1A:6YS(&EL;&5G86P@8VAA
M<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E('!R;V)L96US+B!0
M;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N`%1H92!F;VQD
M97(@(B5S(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB
M960@=&\@:70N`%1H92!F;VQD97(@(B5S(B!W87,@9&5L971E9"!B=70@>6]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+@!4:&4@9F]L9&5R("(E
M<R(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@8W)E871E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S
M9G5L;'D@9&5L971E9"X`5&AE(&9O;&1E<B`B)7,B('=A<R!S=6-C97-S9G5L
M;'D@<F5N86UE9"!T;R`B)7,B+@!4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S
M9G5L;'D@<F5P;&%C960N`%1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES
M(&UA:6QB;W@N`%1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED`%1H97)E('=A<R!A('!R;V)L
M96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@
M:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T
M:&4@9F]L9&5R("(E<R(N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`
M5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!C;VYT:6YU93\`5&AI<R!M97-S86=E('1O`%1I=&QE`%1O`%1R87-H
M(&9O;&1E<CH`55),`%5N86YS=V5R960`56YA;G-W97)E9"!M97-S86=E<P!5
M;F1E;&5T90!5;F1I<V-L;W-E9"!296-I<&EE;G1S`%5N9&\@0VAA;F=E<P!5
M;FYA;65D`%5N<V5E;@!5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS*0!5<V5R
M;F%M90!5<V5R<R!I;B!T:&4@<WES=&5M.@!6:65W("5S`%=A<FYI;F<`5V5E
M:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O
M<FL@4&AO;F4`65D`665A<FQY`%EE<P!9;W4@87)E(&-R96%T:6YG(&$@<W5B
M+69O;&1E<B!T;R``66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B``66]U
M(&AA=F4@)7,@;F5W(&UE<W-A9V5S+@!9;W4@:&%V92`Q(&YE=R!M97-S86=E
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@<V5L96-T(&$@
M=&%R9V5T(&UA:6QB;W@@9FER<W0N`%EO=2!M=7-T('-E;&5C="!A="!L96%S
M="!O;F4@;65S<V%G92!F:7)S="X`66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP
M:65N="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@=V5R
M92!N;W0@<W5B<V-R:6)E9"!T;R`B)7,B+B!(97)E(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2`B)7,B
M+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED`%EO=2!W97)E('-U8V-E
M<W-F=6QL>2!S=6)S8W)I8F5D('1O("(E<R(`66]U('=E<F4@<W5C8V5S<V9U
M;&QY('5N<W5B<V-R:6)E9"!F<F]M("(E<R(`66]U<B!S:6=N871U<F4Z`%M0
M<F]B;&5M(%)E<&]R=%T`;F]N90!O<@!S<&5L;&EN9R!E<G)O<@!S<&5L;&EN
M9R!E<G)O<G,`4')O:F5C="U)9"U697)S:6]N.B!)35`@=C,N,0I297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#(M,#$M,#D@,3DZ,#(K,#(P,`I,87-T+51R86YS;&%T;W(Z($%N
M9')I>2!+;W!Y<W1Y86YS:WD@/&%N<FE`<&]L>6YE="YL=FEV+G5A/@I,86YG
M=6%G92U496%M.B!5:W)A:6YI86X@/'=E8FUA<W1E<D!P;VQY;F5T+FQV:78N
M=6$^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U+3TDX+54*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M."UB:70*`"#TQ<W!.B``(-<@`"5D(-#/("5D(-H@)60@[,G3U*;7`._0Q=+!
MPZ;1(-#2S\:FS,'+U,G>SL_'SR#/PM/,U<?/U]77P<[.T2`E<R`M(/"FQ-37
MQ=+$UL7.SM$`)7,@U=;%(*;3SM6D+B#WP=O!(-#!T,O!("5S(,[%(,+5S,$@
MT,72Q<K-Q<[/U\'.P2X`\,'0R\$@)7,@PM7$Q2#0Q=+%RLW%SL_7P<[!(,[!
M(-#/WL'4R]4@S:;3T</1+@`E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"D`
M*/K!T]3/T]77P=3)(,.F(-K-IL[)(*8@T,72Q<K4R2#.P2#.P=/4U=#.R<H@
MQ<O2P<XN*0`H]Z;$S:;.R=3)(,.F(-K-IL[)(*8@T,_7Q=+.U=3)T]$@Q,\@
MT]37S]+%SL[1(,S)T]3!+BD`*/K!T]3/T]77P=3)(-K2S\+,Q<ZF(,[!(,/%
MRB#>P=,@VLVFSLD@IB#0S]?%TL[5U,G3T2#$SR#3U-?/TL7.SM$@S,G3U,$N
M("#ZS:;.R2#5(-#/U,_>SL_-U2#7ILO.IB#NY2#B]>3U]/@@VL'3U,_3S]?!
MSJ8N*0`R-"#'S\3)SLD`Y,_$P=3)(,[/U\_'SR#+S]+)T]35U\'>P3H`Y,_$
MP=3)(-#!TM4`Y,_$P=3)(,O/TLG3U-77P=[!`.3/Q,'7P<[.T2#+S]+)T]35
MU\'>IM<@VL'"S]+/SL7.Q2X`X<32Q=/!`.'$S:;.IM/4TM77P<[.T0#PT\77
MQ,_.ILT`U].F`/?3IB#,R=/4R2#5(,[!T]35T,[)R"#0P=#!R"#"U<35U-@@
MVL'7P<[4P=;%SJ8@UR#/Q,[)SB#&P<K,($U"3U@Z(`#WTVD@S,G3U,D@U2#W
MP=MIRB#0P=##:2`B)7,B+"#1RZ8@T]3!TMNF(-K!("5S(,3.:=<@PM7$U=38
M(,[!VL'7UL3)(-K.R=W%SFDN`/?3IB#0P=#+R2#7IL2FT\S!SL^G(-#/V]3)
M+"#1RZ8@T]3!TMNF(-K!("5S(,VFT]'#IM<L(,+5Q-74V"#7R=3%TM2F+@#:
M)FYB<W`[UZ;$T,_7IL3$P`#LR=/4R2#:(->FQ-#/UZ;$Q,``]\D@U]#%U\[%
MSJ8L(-W/(,C/WL74Q2#NX?KA]_;DZ2#7R=3%TM3)(,.F(,S)T]3)/P#^P=,@
MSL'$R,_$UL7.SM$`\,\@VM+/T]3!SL[``/#2R<O2IM#)U,D`Y,_$P=3/RP#D
MS\3!U,O)`.3/T]35T,ZF(-#/S-$Z`.[!VL'$(,3/("5S`$)C8P#DQ<[8(,[!
MTL_$UL7.SM$`ML?.S]+5U\'4R0#TILS/`._"R<37P0#WIL3-IL[)U,D`]Z;$
MS:;.R=3)(,S)T]0`]Z;$S:;.R=3)(-#/UZ;$S\W,Q<[.T2#0TL_"S,7-R0!#
M8P#SU*;,V,[)R\_7R<H@U,7,Q<;/S@#ZS:;.R=3)`/K-IL[)U,D@U].F`/K-
MIL[)U,D@T,'0R]4`]\O!UJ;4V"#/T,.FIR#7IL3/PM+!UL7.SM$@+2#+ILS8
MRZ;3U-@@S,G3U*;7+"#1RZ8@UZ;$S\+2P=K)U,D@SL$@T]3/TJ;.R]4L(*8@
MT-+!U\G,SR#3S]+4U=?!SL[1(,S)T]2FURX`]\O!UJ;4V""FS2?1+"#!Q-+%
MT]4@U,$@T*;$T,G3+"#1RZ8@T,_"P=[!U-@@]\';IB#2Q=/0S\[$Q<[4R2P@
MWLG4P<#>R2#!PL\@UZ;$T,_7IL3!P-[)(,[!(/?!VR#,R=/4+@#PS\3)U\G4
MR=/1(-K!(-/7IM;/P"#0S]O4S\`@UR#0P=#+P<@`]\G"Q=*FU-@@S]#%TL'#
MIL`Z`/K!R]+)U,D@UZ;+SL\`^L'+TLG4P2#0P=#+P0#ZQ\_2SM74R2#7TVD`
M^L?/TL[5U,D@U].F(-#!T,O)`/K'S]+.U=3)(-#!T,O5`.O/S=#!SJ;1`/"F
MQ-37Q=+$UL7.SM$@T,'2S\S``/?+P=:FU-@L(-'+(-[!T]3/(,3)U\G4R=/1
M(-K!(-/7IM;/P"#0S]O4S\`@IB#>R2#0S]>FQ,_-S-'4R2#WP=,@T-+/(,[%
MIRX@`.O/T*;`U\'4R0#PTL'7R<S8SL\`]\G0TL'7S,7.R<H@U,7+T]0`\]37
MS]+)U,D`\]37S]+)U,D@T,'0R]4`\]37S]+)U,D@SL_7U2#0P=#+U2#>Q=+.
MQ=3/RP#SU-?/TLG4R2#.S]?5(-#!T,O5(->FQ*;3S,'.R<@@S,G3U*;7`//4
MU\_2R=3)(,[/U]4@T,'0R]4MT\VFU,[)RP#SU-?/TLG4R2#0TL'7R<S!(,:F
MS-C4TM77P<[1T2P@W<_"(,_2Q\'.IMK5U\'4R2#WP=O5(-?(IL3.U2#0S]O4
MU2P@T\_2U-77P=3)(*>G(-#/(-#!T,O!R""F(-?)U,G2P=3)(,[%PL'6P<ZF
M(,S)T]3)("C3T,'-*2X`Y.0`_<_$Q<[.SP#DP=3!`._3SL_7SL$@IM#/T]3!
MT]@`Z]+)U,72ILH@T\_2U-77P<[.T2#:P2#:P<W/U][5U\'.SM'-.@#NP=#2
MT<W/RR#3S]+4U=?!SL[1(-K!(-K!S<_7WM77P<[.T<TZ`/?)U,72U,D`]\G4
MQ=+4R2#0P=#+U0#7R=3%TM2F`/?)U,72U*8@S,G3U,D`]\G4R=+!SL[1(,'"
MSR#0Q=+%SL73Q<[.T2#,R=/4IM<`\,\@T]#!Q,'.SL``[]#)VZ;4V"#0TL_"
MS,7-U0#NQ2#$R=?)U,G3T2#7(-#!T,.F(-K!(-/7IM;/P"#0S]O4S\``^M+/
MPLS%SL\`^L'7P<[4P=;)U,D@\,'0R]4`WL72SL74R\D`\,'0R\$@WL72SL74
MS\LZ`/+%Q,''U=?!U,D`Y2W0S]O4P0#PS]+/ULZFRB#2Q=K5S-C4P=0N`.NF
MSL7#V"#0Q=+%T\S!SL_'SR#,R=/4P0#WU\7$IM38(,[!VM?5(,[/U\^G(-#!
MT,O)(,3,T2#>Q=+.Q=3/RP#WU\7$IM38(,[!VM?5(,[/U\^G(-#!T,O)(,3,
MT2#7IL2FT\S!SL^G(-#/V]3)`/?7Q<2FU-@@SL':U]4@SL_7SZ<@T,'0R\DM
MT\VFU,[)R\$`\,_-R<S+P0#KS];.IB`Q-2#(U\G,R<X`Z\_6SJ8@,S`@T\7+
MU<[$`.O/ULZF(#4@R-?)S,G.`.O/UL[/Q\\@U\C/Q-4`Z\_6SJ8@T*;7Q\_$
MR<[)`/W/R-?)S,G.R0#DP<ZF(,3,T2#0TLG+S,'$U3H`\L_:Q\_2SM74R2#7
MTZ8`\L_:Q\_2SM74R2#7TZ8@T,'0R\D`\L_:Q\_2SM74R2#0P=#+U0#PS]O5
MRR#!Q-+%TP#FP<O3`.:FS-C4TLD`\,72V\$@T]3/TJ;.R\$`\,72Q<?,T<0@
MT,'0S\L`\,72Q=/,P=3)`/#%TL73S,'4R3H`\,72Q=/,P<[)RB#,R=/4(->F
MQ"`E<P#WIL0`^M?/TL_4SM$@P<32Q=/!`.3/T,_-S\?!`//(S]?!U,D@U\G4
MQ=+4I@#SR,_7P=3)(,[%T,72Q<30S,'>Q<ZF`.3/S<';SM$@P<32Q=/!`.3/
MS<';SJ;*(-3%S,7&S\X`2&]R9&4`\\O2R<[8R\$`ML?.S]+5U\'4R0"VQ\[/
MTM77P=3)(-?3I@#7P=;,R=>F`/?!ULS)UZ8@S,G3U,D`MLW0S]+4S]?!SL4@
MT,_,Q3H@)7,`MLW0S]+4S]?!SJ8@T,_,T3H`[<_7P0#OT]3!SL[1(-/4S]*F
MSLO!`/#%TL7,ILL@TL_:Q*;,IM<@Y,_0S\W/Q\D`\,72Q<?,T<0@T]#)T\O5
M(,O/TLG3U-77P=ZFUR#:P<+/TL_.Q<[)RBX`]]>FRM3)`/?7ILK4R2#$SR`E
M<P#WR<K4R0#ZP<3!WJ8L(-W/(-?)R\_.U<#4V-/1(-#2R2#7R,_$I@#M[0#S
MR]+)SMC+P0#WIL3-IM3)U,D@T<LZ`/>FQ-#/UZ;$SJ8@T,_,T0#LR=/4`//4
MU\_2Q<[.T2#,R=/4P0#DP=3!(,S)T]3!`/#/V]7+(,S)T]3!`._"T]''(,S)
MT]3!`/?)R*;$SLG*(-3%R]/4`/#%TL7'S-'$(,S)T]3!`/>FQ,VFU,O)(,S)
MT]3!`/#!T,O)(,S)T]2FUP#LR=/4IM<@SL$@T]3/TJ;.R]4@T-+)(-#%TL7'
MS-'$IB#3R]+)SMC+R2X`[,G3U,D@Q,\`^LVFSLG4R0#]S\VFT]'#T0#PQ=+%
MSL73U,D`[J;+S\S)`,[/UZ8`\]>FUL$@T,_;U,$`[L_7IB#,R=/4R0#NP=/4
MU=#.R<H`[L'3U-70SLG*(,S)T]0`[L'3U-70SL$@T]3/TJ;.R\$`[J8`]L_$
MSL$@T,'0R\$@SL4@U\G"TL'.P0#OTL;/Q]+!QJ;>SLG((-#/S<G,S\L@SL4@
MVL[!RL3%SL\`UL_$SL_'SP#.Q2#7R=3%TM2F`,[%(-[%TL[%U,O)`,[%(-?!
MULS)UZ8`SL4@T-+)U\'4SJ8`[L4@U\G4Q=+4IB#,R=/4R0#NQ2#7P=;,R=>F
M(,S)T]3)`.[/U,'4R\D`\]3!TJ8@S,G3U,D`\]3!TJ8@T,'0R\D@UZ;$IM/,
MP<[)R"#,R=/4IM<@PM7$U=38(,_>R=W%SJ8N`+;.VZ8@[]##IJ<`\]3/TJ;.
MR\$@)60@VB`E9`#BS,_+*,DI`/#!TL_,V`#PP=+/S-@@S=73R=38(-/0IM?0
MP=/4R2X`]\G+S\[!U,D@T-+/QJ;,P<O4R=[.IB#/T,72P<.FIP#0TLG7P=3.
MI@#OT\_"R=/4P2"VSL;/TLW!PZ;1`/3%S,7&S\X`\L_:S:;=U=?!U,D@]\';
M(-"FQ-#)TR#0Q=+%Q"##R=3/U\'.R<W)(,S)T]3!S<D@T-+)(->FQ-#/UZ;$
MIC\`XM7$V"W,P=/+P2P@U]?%Q*;4V"#.S]?5(,[!VM?5.@#BU<38+<S!T\O!
M+"#$P<K4Q2#+S]+/U,O)RB#/T,G3(-#2S\+,Q<W)+@#BU<38+<S!T\O!+"#7
MR\'6IM38(,[!VM?5(,O/TLG3U-77P=[!(*8@T,'2S\S8`.+5Q-@MS,'3R\$L
M(-#%TL77IM+4Q2"FT]3)SLZFT]38(-?+P=K!SLG((,'$TL73+@#BU<38+<S!
MT\O!+"#7R<+%TJ;4V"#0P=#+U2P@T,72VR#.IM8@T-+/U\_$R=3)(,+5Q-@M
MT<NF(,_0Q=+!PZ:G+@#BU<38+<S!T\O!+"#7R<+%TJ;4V"#(S][!(,(@S\3.
MU2#0P=#+U2#$S-$@T,_;U<O5+@#BU<38+<S!T\O!+"#7R\'6IM38(-2FS-C+
MR2#/Q,[5(-#!T,O5(,3,T2##IJ2G(,_0Q=+!PZ:G+@#PS]#%TL7$SJ;*(.S)
MT]0`\,_0Q=+%Q,[1(//4S]*FSLO!`.32U<L`[]#)TR#0TL_"S,7-R0#ZSLG=
MR=3)(-?)U,72U*8`\<L@WL'3U,\@S][)W<'4R2#SS:;4SLG+.@#PQ=+%SL'0
MTL'7R=3)`/#%TL7.P=#2P=?)U,D@[,G3U`#PQ=+%SL'0TL'7R=3)(,/%RB#L
MR=/4`/#%TL7.P=#2P=?,Q<[.T2#.Q=?$P<S%+@#OPL[/U\G4R0#OPL[/U\G4
MR2#7R<?,T<0@\,'0S\LZ`/#%TL7>R=3!U,D@UZ;$S\+2P=;%SL[1`/#!S2?1
MU,'4R2#/T]3!SLZD(->FQ,_"TL'6Q<[.T0#WR=3%TM3)(-#!TM4`[L4@U\3!
MS,_3T2#0Q=+%RLW%SM77P=3)("(E<R(@SL$@(B5S(BX@[]/8(-W/(-/+P=K!
MUR#3Q=+7Q=(`^L'-IL[)U,D@SL$Z`/>FQ-#/UZ;3U,D`]Z;$T,_7IM/4R2#7
MTZ;-`/>FQ-#/UZ;$V"#7TZ;-.@#CQ<H@S,G3U"`M(-/0P<T`[][)T]3)U,D`
M\-+/Q,_7ULG4R0#PS]?%TL[5U,G3T2#$SR#3R]+)SMC+R2#0IM/,T2#7R=3)
MTL'.SM$L(-#%TL7.Q=/%SL[1(,'"SR#+S]"FP-?!SL[1(.S)T]3!/P#ZPL72
MQ<?4R2#^Q=+.Q=3+U0#ZPL72Q<?4R0#NQ2#7Q,',S]/1(-K"Q=+%Q]3)(-[%
MTL[%U,O5+B#OT]@@W<\@T\O!VL'7(-/%TM?%TCH@)7,`\,_;U<L`\L7:U<S8
MU,'4R2#PS]O5R]4`T-+/WLG4P<ZF`/?)PM+!U,D`]\G"TL'4R2#7TZ8`[L4@
MU\G"R=+!U,D@UL_$SL_'SP#WR<+%TJ;4V"#2S]K$ILS`U\'>(,3!U,DZ`/?)
MPL72IM38(,;/TLW!U"#$P=3).@#WR<+%TJ;4V"#&S]+-P=0@WL'3U3H`]Z;$
MIM/,P=3)(.S)T]3!`/>FQ*;3S,'4R2#0S]>FQ,_-S,7.SM$@T-+/(-#2S\+,
MQ<W5`/#!T,O!(->FQ*;3S,'.R<@@S,G3U*;7.@#SQ=+7Q=(`]\O!UJ;4V"P@
MW<\@S<&D(->FQ,+5U,G3T2#0TLD@T,72Q<[%T\7.SJ8@P<+/(-?)U,G2P<[.
MIB#,R=/4IM<N`/K!R]+)U\'4R2#7ILO.SR#SU-?/TL7.SM$@S,G3U,$@T*;3
MS-$@VL+%TL76Q<[.T2#>Q=+.Q=3+R3\`\,_+P=K!U,D@U\G4Q=+4I@#PS\O!
MVL'4R2#.Q=#%TL7$T,S!WL7.I@#OPM/1QP#PTL_0U=/4R=3)(-#2S\:FS,'+
MU,G+U0#WUZ;$(//0Q<.FP<S8SLG((-/)S=?/S*;7`//0Q<.FP<S8SJ8@T\G-
MU\_,R0#PQ=+%UZ;2R\$@T-+!U\_0R=/5`/#2S\?2P<W!(-#%TL77IM++R2#0
MTL'7S]#)T]4`\,72Q=>FTLO5(-#2P=?/T,G3U2#:P=?%TMO%SL\`[]+&S\?2
MP<:FWL[)R"#0S\W)S,_+(,[!(,7+TL'.(-#2R2#0Q=+%UZ;2PZ8N`/3%S<$`
M\,_,Q2#TQ<W)`/#%TL7$T,S!U,G4R2#PP=#+U2C)*0#UT]"FV\[/`/#2S]#/
MVLG#IJ<`],7+T]0`\,_4S][.P2#0P=#+P2C)*2`B)7,B(,+5Q,4@T,72Q<K-
MQ<[/U\'.P2#.P2`B)7,B+@#PP=#+P2`B)7,B(-?6Q2"FT\[5I`#PP=#+P2`B
M)7,B(,VFT]3)U-@@SL7$S]K7S\S%SJ8@T\G-U\_,R2#7(,[!VM>F+B#CQ2#-
MS];%(-/0TLG>R<[)U,D@T-+/PLS%S<DN(.+5Q-@MS,'3R\$L(-#/TL'$V-3%
MT]$@VB#3R=/4Q<W.R<T@P<3-ILZFT]32P=3/TL_-+@#PP=#+U2`B)7,B(-/4
MU\_2Q<[/+"#!S,4@]\D@IZ<@SL4@T,72Q<30S,'4R<S)+@#PP=#+U2`B)7,B
M(,+5S,\@VL[)W<7.SRP@P<S%(/?)(,[%(->FQ,VFSLG,R2#0Q=+%Q-#,P=35
M(,[!(,[%IRX`\,'0R\$@(B5S(B#.Q2#"U<S!(-/4U\_2Q<[!+B#OT]@@W<\@
MT\O!VL'7(-/%TM?%T@#PP=#+P2`B)7,B(,[%(,+5S,$@VL[)W<7.P2X@[]/8
M(-W/(-/+P=K!UR#3Q=+7Q=(`\,'0R]4@(B5S(B#5T]"FV\[/(-/4U\_2Q<[/
M+@#PP=#+U2`B)7,B(-73T*;;SL\@U\G4Q=+4SRX`\,'0R\$@(B5S(B#5T]"F
MV\[/(-#%TL7*S<7.S]?!SL$@SL$@(B5S(BX`\*;$T,G3(-73T*;;SL\@VLVF
MSL7.R<HN`.[%S<$@UL_$SL_'SR#,R=/4P2#7(-/+TLG.V,.F+@#TTL'0R<S!
MT]$@T,_-R<S+P2#0TLD@S][)W<7.SJ8@)7,N(._3V"#=SR#3R\':P=<@T\72
MU\72`/32P=#)S,'3T2#0S\W)S,O!(-#2R2#/WLG=Q<[.IB#3R]+)SMC+R2X@
M[]/8(-W/(-/+P=K!UR#3Q=+7Q=(`]-+!T,G,P=/1(-#/S<G,R\$@T-+)(-?)
MU,G2P<[.IB#,R=/4IM<@VB#0P=#+R2`B)7,B+B#OT]@@W<\@T\O!VL'7(-/%
MTM?%T@#TTL'0R<S!T]$@T,_-R<S+P2#0TLD@U\G4R=+!SLZF(,S)T]2FUR#7
M(-#!T,.F("(E<R(N(._3V"#=SR#3R\':P=<@T\72U\72`/32P=#)S,'3T2#0
MS\W)S,O!(-#2R2#0S]K.P=[%SLZF(,S)T]2FUR#7(-#!T,.F("(E<R(N(._3
MV"#=SR#3R\':P=<@T\72U\72`./%(,W/UL4@VL'*SM'4R2#4TL_(R2#>P=/5
M+B#^R2#WR2#:Q\_$SJ8@T-+/Q,_7UM77P=3)/P#CQ<H@[,G3U"#$SP#TR=35
MS`#DSP#SS:;4SLG+.@!54DP`PL7:(->FQ-#/UZ;$I@#LR=/4R2#"Q=H@UZ;$
MT,_7IL2F`/>FQ,[/U\G4R0#NQ=?)R]+)U*8@S]32R<W5U\'>I@#SR\'3U=?!
MU,D@VLVFSLD`XL7:ILW%SLZF`,[%WLG4P<ZF`/>FQ,VFSLG4R2#0Q=+%Q-#,
MP=35(,[!(/#!T,O5`.[!VM?!(,O/TLG3U-77P=[!`.O/TLG3U-77P=ZF(-<@
MT\G3U,7-ICH`\,72Q<?,T<[5U,D@)7,`]=?!Q\$`_<_4R=;.T0#WP=,@UZ;4
MP:0@)7,`]Z;4P<`@]\'3+"`E<P#RS\+/WL$@P<32Q=/!`/+/PL_>R<H@U,7,
MQ<;/S@#R\@#]S]*FWL[/`/3!RP#WR2#3U-?/TL"DU,4@T,'0R]4@U]/%TL7$
MR<ZF(`#WR2#0Q=+%RLW%SL_7U:34Q2#0P=#+U3H@`/4@]\'3(*0@)7,@SL_7
MR<@@S,G3U*;7+@#U(/?!TR"D(#$@SL_7R<H@S,G3U"X`]\D@T,_7R<[.IB#/
MT,G3P=3)(-#2S\+,Q<W5+"#0Q=+;(,ZFUB#7IL33R<S!U,D@T,_7IL3/S<S%
MSL[1(-#2SR#.Q:<N`//0Q=+;U2#7R\'6IM38(-/+TLG.V,O5(-#2R=K.P=[%
MSL[1+@#ST,72V]4@U\G"Q=*FU-@@R,_>P2#"(,_$R<X@S,G3U"X`]\O!UJ;4
MV"#/U-+)S=77P=[!+@#WP<T@T\RFQ"#7R\':P=3)(,[!VM?5(,O/TLG3U-77
MP=[!(,3,T2#7R<3!S,7.SM$N`/?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2
MR=/4U=?!WL$@Q,S1(,3/Q,'7P<[.T2X`]\D@SL4@T,72Q<30S,'4R<S)("(E
M<R(N(._3V"#=SR#3R\':P=<@T\72U\72`/?)(,[%(->FQ,VFSLG,R2#0Q=+%
MQ-#,P=35(,[!("(E<R(N(._3V"#=SR#3R\':P=<@T\72U\72`/?)(-73T*;;
MSL\@T,72Q<30S,'4R<S)("(E<R(`]\D@UZ;$S:;.R<S)(-#%TL7$T,S!U-4@
MSL$@(B5S(@#WP=L@T*;$T,G3.@!;\,_7IL3/S<S%SL[1(/#2S\+,Q<W)70#6
MS\3.S\?/`,'"SP#'TL'-P=3)WL[!(-#/S<G,R\$`Q]+!S<'4R=[.R<@@T,_-
MR<S/RP``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]L;V-A;&4O=6M?54$O:&5L<"YX;6P`````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,C8T-#<`,3`T,3<S-C(W-C,`,#(Q
M,30R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:6UP+VQO8V%L
M92]U:U]502]H96QP+GAM;"QV(#$N,3<N-BXT(#(P,#8O,#$O,S`@,34Z-3<Z
M-3`@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](F-O;7!O<V4M
M8G5T=&]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^06-T
M:6]N<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5N9"!-97-S86=E(&QA
M=6YC:&5S('EO=7(@96UA:6P@=&\@=&AE(&EN=&5N9&5D(')E8VEP:65N="AS
M*2X@0F4@<W5R92!Y;W4@=V%N="!T;R!S96YD(&)E9F]R92!C;&EC:VEN9R!H
M97)E(&%S(&]N8V4@<V5N="!I="!C86YN;W0@8F4@=&%K96X@8F%C:RX*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V%V92!$<F%F="!P;&%C97,@86X@
M=6YF:6YI<VAE9"!M97-S86=E(&EN(&$@9F]L9&5R(&-A;&QE9"`G1')A9G1S
M)PIA8V-E<W-I8FQE(&)Y('1H92!P;W`M9&]W;B!B;W@@;VX@=&AE(')I9VAT
M('-I9&4@;V8@=&AE(&)L=64@;F%V:6=A=&EO;B!B87(@870@=&]P+B!9;W4@
M8V%N('1H96X@9FEN:7-H('1H92!M97-S86=E(&QA=&5R(&)Y('-W:71C:&EN
M9R!T;R!T:&4@)T1R869T<R<@9F]L9&5R+"!C;&EC:VEN9R!O;B!T:&4@<V%V
M960@;65S<V%G92!T;R!O<&5N(&ET+"!A;F0@=&AE;B!C;&EC:VEN9R!O;B`G
M4F5S=6UE)RX@0F4@<W5R92!T;R!P=70@82!S=6)J96-T(&]N('1H92!E;6%I
M;"!B969O<F4@>6]U('-A=F4@=&AE(&1R869T('-O('1H870@>6]U(&-A;B!E
M87-I;'D@:61E;G1I9GD@=VAI8V@@;65S<V%G92!Y;W4@=V%N="!W:71H:6X@
M=&AE($1R869T<R!F;VQD97(N($%F=&5R('-A=FEN9R!A<R!A($1R869T+"!Y
M;W4@87)E(')E='5R;F5D('1O('EO=7(@24Y"3U@@;W(@=VAA=&5V97(@9F]L
M9&5R('EO=2!W97)E('9I97=I;F<@;&%S="X*("`@(#PO<&%R83X*("`@(#QP
M87)A/@H@("`@0V%N8V5L($UE<W-A9V4@9')O<',@=&AE(&UE<W-A9V4@:6X@
M<')O9W)E<W,@86YD('-I;7!L>2!R971U<FYS('EO=2!T;R!T:&4@24Y"3U@@
M;W(@=VAA=&5V97(@9F]L9&5R('EO=2!W97)E('9I97=I;F<@;&%S="X*("`@
M(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O
M<V4M8G5T=&]N<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@
M06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY!8W1I;VYS/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!396YD($UE<W-A9V4@;&%U;F-H97,@>6]U<B!E
M;6%I;"!T;R!T:&4@:6YT96YD960@<F5C:7!I96YT*',I+B!"92!S=7)E('EO
M=2!W86YT('1O('-E;F0@8F5F;W)E(&-L:6-K:6YG(&AE<F4@87,@;VYC92!S
M96YT(&ET(&-A;FYO="!B92!T86ME;B!B86-K+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!3879E($1R869T('!L86-E<R!A;B!U;F9I;FES:&5D(&UE
M<W-A9V4@:6X@82!F;VQD97(@8V%L;&5D("=$<F%F=',G"F%C8V5S<VEB;&4@
M8GD@=&AE('!O<"UD;W=N(&)O>"!O;B!T:&4@<FEG:'0@<VED92!O9B!T:&4@
M8FQU92!N879I9V%T:6]N(&)A<B!A="!T;W`N(%EO=2!C86X@=&AE;B!F:6YI
M<V@@=&AE(&UE<W-A9V4@;&%T97(@8GD@<W=I=&-H:6YG('1O('1H92`G1')A
M9G1S)R!F;VQD97(L(&-L:6-K:6YG(&]N('1H92!S879E9"!M97-S86=E('1O
M(&]P96X@:70L(&%N9"!T:&5N(&-L:6-K:6YG(&]N("=297-U;64G+B!"92!S
M=7)E('1O('!U="!A('-U8FIE8W0@;VX@=&AE(&5M86EL(&)E9F]R92!Y;W4@
M<V%V92!T:&4@9')A9G0@<V\@=&AA="!Y;W4@8V%N(&5A<VEL>2!I9&5N=&EF
M>2!W:&EC:"!M97-S86=E('EO=2!W86YT('=I=&AI;B!T:&4@1')A9G1S(&9O
M;&1E<BX@069T97(@<V%V:6YG(&%S(&$@1')A9G0L('EO=2!A<F4@<F5T=7)N
M960@=&\@>6]U<B!)3D)/6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@
M=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#86YC
M96P@365S<V%G92!D<F]P<R!T:&4@;65S<V%G92!I;B!P<F]G<F5S<R!A;F0@
M<VEM<&QY(')E='5R;G,@>6]U('1O('1H92!)3D)/6"!O<B!W:&%T979E<B!F
M;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H\+V5N
M=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+69R;VTB('-T
M871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N
M.B!&<F]M/"]T:71L93X*("`@(#QH96%D:6YG/B)&<F]M(CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@16YT97(@>6]U<B!C;W)R96-T(&5M86EL(&%D9')E
M<W,N(%EO=7(@96UA:6P@861D<F5S<R!I<R!A=71O;6%T:6-A;&QY(&5N=&5R
M960@9F]R('EO=2!F;VQL;W=I;F<@(D9R;VTZ(B!I;B!O=71G;VEN9R!E;6%I
M;"X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60]
M(F-O;7!O<V4M9G)O;2(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO
M;CH@1G)O;3PO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M&<F]M)G%U;W0[
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%;G1E<B!Y;W5R(&-O<G)E8W0@
M96UA:6P@861D<F5S<RX@66]U<B!E;6%I;"!A9&1R97-S(&ES(&%U=&]M871I
M8V%L;'D@96YT97)E9"!F;W(@>6]U(&9O;&QO=VEN9R`F<75O=#M&<F]M.B9Q
M=6]T.R!I;B!O=71G;VEN9R!E;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R>3XM
M+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UT;R(@<W1A=&4](G5N
M:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%1O/"]T
M:71L93X*("`@(#QH96%D:6YG/B)4;R(\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H
M;W-E('1O(')E8V5I=F4@>6]U<B!M97-S86=E+B!9;W4@;75S="!S97!A<F%T
M92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO
M;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S
M(")4;SHB(&EN(&]U=&=O:6YG(&UA:6PN("`*("`@(#PO<&%R83X*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M=&\B/@H@("`@/'1I
M=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%1O/"]T:71L93X*("`@(#QH96%D
M:6YG/B9Q=6]T.U1O)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%
M;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T
M;R!R96-E:79E('EO=7(@;65S<V%G92X@66]U(&UU<W0@<V5P87)A=&4@96%C
M:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@<'5N8W1U871I;VX@=VEL
M;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT<GD@9F]L;&]W<R`F<75O
M=#M4;SHF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@(`H@("`@/"]P87)A/@H\
M+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6-C(B!S
M=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO
M;CH@0V,\+W1I=&QE/@H@("`@/&AE861I;F<^(D-C(CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE
M<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&-A<F)O;B!C;W!Y(&]F('EO=7(@
M;65S<V%G92X@4V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM82X@
M66]U<B!E;G1R>2!F;VQL;W=S(")#8SHB(&EN(&]U=&=O:6YG(&UA:6PN($-A
M<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@
M=&AA;B!T:&4@;VYE*',I(&)E:6YG('=R:71T96X@=&\@9&ER96-T;'D@8G5T
M(&%R92!I;7!O<G1A;G0@<F5C:7!I96YT<R!O9B!T:&4@96UA:6P@87,@=V5L
M;"P@=7-U86QL>2!S;VUE;VYE(&EN9&ER96-T;'D@8V]N8V5R;F5D(&%B;W5T
M('1H92!S=6)J96-T(&]F('1H92!E;6%I;"X@($%L;"`G5&\Z)R!R96-I<&EE
M;G1S(&%N9"`G0V,Z)R!R96-I<&EE;G1S(&-A;B!S964@=&AE(&5N=&ER92!L
M:7-T(&]F(&)O=&@@:VEN9',@;V8@<F5C:7!I96YT<RX*("`@(#PO<&%R83X*
M/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8V,B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($-C/"]T:71L93X*("`@
M(#QH96%D:6YG/B9Q=6]T.T-C)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T
M:&]S92!T;R!R96-E:79E(&$@8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E
M+B!397!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA+B!9;W5R(&5N
M=')Y(&9O;&QO=W,@)G%U;W0[0V,Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN
M($-A<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H
M97(@=&AA;B!T:&4@;VYE*',I(&)E:6YG('=R:71T96X@=&\@9&ER96-T;'D@
M8G5T(&%R92!I;7!O<G1A;G0@<F5C:7!I96YT<R!O9B!T:&4@96UA:6P@87,@
M=V5L;"P@=7-U86QL>2!S;VUE;VYE(&EN9&ER96-T;'D@8V]N8V5R;F5D(&%B
M;W5T('1H92!S=6)J96-T(&]F('1H92!E;6%I;"X@($%L;"`G5&\Z)R!R96-I
M<&EE;G1S(&%N9"`G0V,Z)R!R96-I<&EE;G1S(&-A;B!S964@=&AE(&5N=&ER
M92!L:7-T(&]F(&)O=&@@:VEN9',@;V8@<F5C:7!I96YT<RX*("`@(#PO<&%R
M83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UB
M8V,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@/&AE861I;F<^(D)C8R(\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D
M9')E<W,H97,I(&]F('1H;W-E('1O(')E8V5I=F4@82!B;&EN9"!C87)B;VX@
M8V]P>2!O9B!Y;W5R(&UE<W-A9V4N(%EO=2!M=7-T('-E<&%R871E(&5A8V@@
M861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R('!U;F-T=6%T:6]N('=I;&P@
M<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N=')Y(&9O;&QO=W,@(D)C8SHB
M(&EN(&]U=&=O:6YG(&UA:6PN($)L:6YD(&-A<F)O;B!C;W!I97,@87)E('5S
M=6%L;'D@<V5N="!T;R!P96]P;&4@;W1H97(@=&AA;B!D:7)E8W0@86YD(&EN
M9&ER96-T(')E8VEP:65N=',@*")4;SHB(&%N9"`B0V,Z(B!R96-I<&EE;G1S
M*2!W:&\@;F5E9"!T;R!R96%D('=H870@:7,@8F5I;F<@=W)I='1E;B!A<R!W
M96QL(%=)5$A/550@=&AE(&]T:&5R(')E8VEP:65N=',@:VYO=VEN9R!T:&%T
M('1H97D@87)E(')E8V5I=FEN9R!T:&4@96UA:6PN(%1H=7,@)V)L:6YD)R!M
M96%N<R!T:&%T('1H92!I9&5N=&ET>2!O9B!T:&5S92!R96-I<&EE;G1S(&ES
M(&AI9&1E;B!F<F]M(&%L;"!O=&AE<B!R96-I<&EE;G1S(&]F('1H92!E;6%I
M;"P@86YD(&]N;'D@>6]U(&%N9"!T:&5Y(&MN;W<@=&AE>2!G;W0@82!C;W!Y
M+B!9;W4@='EP:6-A;&QY('5S92!T:&ES('1O('1E;&P@86X@875T:&]R:71Y
M(&9I9W5R92!T:&%T('EO=2!A<F4@=&5L;&EN9R!S;VUE;VYE('-O;65T:&EN
M9R!W:71H;W5T(&%L87)M:6YG('1H92!P97)S;VX@>6]U(&%R92!S96YD:6YG
M('1H92!A8W1U86P@96UA:6P@=&\N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES
M:"!E;G1R>3H*/&5N=')Y(&ED/2)C;VUP;W-E+6)C8R(^"B`@("`\=&ET;&4^
M365S<V%G92!#;VUP;W-I=&EO;CH@0F-C/"]T:71L93X*("`@(#QH96%D:6YG
M/B9Q=6]T.T)C8R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT
M97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@
M<F5C96EV92!A(&)L:6YD(&-A<F)O;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@
M66]U(&UU<W0@<V5P87)A=&4@96%C:"!A9&1R97-S('=I=&@@82!C;VUM83L@
M;W1H97(@<'5N8W1U871I;VX@=VEL;"!R97-U;'0@:6X@86X@97)R;W(N(%EO
M=7(@96YT<GD@9F]L;&]W<R`F<75O=#M"8V,Z)G%U;W0[(&EN(&]U=&=O:6YG
M(&UA:6PN($)L:6YD(&-A<F)O;B!C;W!I97,@87)E('5S=6%L;'D@<V5N="!T
M;R!P96]P;&4@;W1H97(@=&AA;B!D:7)E8W0@86YD(&EN9&ER96-T(')E8VEP
M:65N=',@*"9Q=6]T.U1O.B9Q=6]T.R!A;F0@)G%U;W0[0V,Z)G%U;W0[(')E
M8VEP:65N=',I('=H;R!N965D('1O(')E860@=VAA="!I<R!B96EN9R!W<FET
M=&5N(&%S('=E;&P@5TE42$]55"!T:&4@;W1H97(@<F5C:7!I96YT<R!K;F]W
M:6YG('1H870@=&AE>2!A<F4@<F5C96EV:6YG('1H92!E;6%I;"X@5&AU<R`G
M8FQI;F0G(&UE86YS('1H870@=&AE(&ED96YT:71Y(&]F('1H97-E(')E8VEP
M:65N=',@:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R(')E8VEP:65N=',@;V8@
M=&AE(&5M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H97D@:VYO=R!T:&5Y(&=O
M="!A(&-O<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H:7,@=&\@=&5L;"!A;B!A
M=71H;W)I='D@9FEG=7)E('1H870@>6]U(&%R92!T96QL:6YG('-O;65O;F4@
M<V]M971H:6YG('=I=&AO=70@86QA<FUI;F<@=&AE('!E<G-O;B!Y;W4@87)E
M('-E;F1I;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*("`@(#PO<&%R83X*/"]E
M;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US=6)J96-T
M(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@4W5B:F5C=#PO=&ET;&4^"B`@("`\:&5A9&EN9SXB4W5B:F5C="(\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!S=6)J96-T(&]F
M('EO=7(@;65S<V%G92X@66]U<B!E;G1R>2!F;VQL;W=S(")3=6)J96-T.B(@
M:6X@;W5T9V]I;F<@;6%I;"X@2V5E<"!I="!S:&]R="P@<VEM<&QE(&%N9"!D
M97-C<FEP=&EV92X@(%1H92!S=6)J96-T(&QI;F4@:7,@=&AE(&5A<VEE<W0@
M=V%Y(&9O<B!Y;W4@86YD('EO=7(@8V]R<F5S<&]N9&5N=',@=&\@<F5M96UB
M97(@=VAA="!W87,@:6X@=&AE(&5M86EL(&%N9"!T:'5S(&ES('9E<GD@:6UP
M;W)T86YT(&EN(&]R9V%N:7II;F<@>6]U<B!E;6%I;"!A;F0@9FEN9&EN9R!I
M;7!O<G1A;G0@;VYE<R!L871E<BX@($%L<V\L('=H96X@>6]U("=297!L>2<@
M;W(@)T9O<G=A<F0G(&%N9"!E;6%I;"!T:&ES('-U8FIE8W0@;&EN92!I<R!C
M;W!I960@;W9E<B!I;G1O('1H92!N97<@;65S<V%G92!A;F0@<V\@:7,@82!V
M86QU86)L92!W87D@;V8@=&5L;&EN9R!W:&%T(&UE<W-A9V5S(&=O('1O9V5T
M:&5R('1O(&9O<FT@82`B=&AR96%D(B!O9B!A(&-O;G9E<G-A=&EO;BX@($AO
M=V5V97(L(&EF('1H92`G4F5P;'DG(&]R("=&;W)W87)D)R!C;VYT86EN<R!N
M97<@:61E87,L('EO=2!M87D@=V%N="!T;R!A9&0@<VEM<&QE(&UO9&EF:6-A
M=&EO;G,@=&\@=&AE("=3=6)J96-T)R!L:6YE('-O('1H92!R96-I<&EE;G0H
M<RD@8V%N(&9O;&QO=R!T:&4@<')O9W)E<W-I;VX@;V8@=&AE(")T:')E860N
M(@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB
M8V]M<&]S92US=6)J96-T(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET
M:6]N.B!3=6)J96-T/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.U-U8FIE
M8W0F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('1H92!S
M=6)J96-T(&]F('EO=7(@;65S<V%G92X@66]U<B!E;G1R>2!F;VQL;W=S("9Q
M=6]T.U-U8FIE8W0Z)G%U;W0[(&EN(&]U=&=O:6YG(&UA:6PN($ME97`@:70@
M<VAO<G0L('-I;7!L92!A;F0@9&5S8W)I<'1I=F4N("!4:&4@<W5B:F5C="!L
M:6YE(&ES('1H92!E87-I97-T('=A>2!F;W(@>6]U(&%N9"!Y;W5R(&-O<G)E
M<W!O;F1E;G1S('1O(')E;65M8F5R('=H870@=V%S(&EN('1H92!E;6%I;"!A
M;F0@=&AU<R!I<R!V97)Y(&EM<&]R=&%N="!I;B!O<F=A;FEZ:6YG('EO=7(@
M96UA:6P@86YD(&9I;F1I;F<@:6UP;W)T86YT(&]N97,@;&%T97(N("!!;'-O
M+"!W:&5N('EO=2`G4F5P;'DG(&]R("=&;W)W87)D)R!A;F0@96UA:6P@=&AI
M<R!S=6)J96-T(&QI;F4@:7,@8V]P:65D(&]V97(@:6YT;R!T:&4@;F5W(&UE
M<W-A9V4@86YD('-O(&ES(&$@=F%L=6%B;&4@=V%Y(&]F('1E;&QI;F<@=VAA
M="!M97-S86=E<R!G;R!T;V=E=&AE<B!T;R!F;W)M(&$@)G%U;W0[=&AR96%D
M)G%U;W0[(&]F(&$@8V]N=F5R<V%T:6]N+B`@2&]W979E<BP@:68@=&AE("=2
M97!L>2<@;W(@)T9O<G=A<F0G(&-O;G1A:6YS(&YE=R!I9&5A<RP@>6]U(&UA
M>2!W86YT('1O(&%D9"!S:6UP;&4@;6]D:69I8V%T:6]N<R!T;R!T:&4@)U-U
M8FIE8W0G(&QI;F4@<V\@=&AE(')E8VEP:65N="AS*2!C86X@9F]L;&]W('1H
M92!P<F]G<F5S<VEO;B!O9B!T:&4@)G%U;W0[=&AR96%D+B9Q=6]T.PH@("`@
M/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP
M;W-E+6]P=&EO;G,B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S
M86=E($-O;7!O<VET:6]N.B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG
M/B)/<'1I;VYS(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE<V4@3W!T
M:6]N<R!H96QP('EO=2!P<F5P87)E('EO=7(@;65S<V%G92X*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@0VQI8VL@(E-P96QL($-H96-K(B!T;R!C:&5C
M:R!Y;W5R('-P96QL:6YG+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!#
M;&EC:R`B071T86-H;65N=',B('1O('9I97<@870@=&AE(&)O='1O;2!O9B!T
M:&4@<&%G92!A(&QI<W0@;V8@9FEL97,@871T86-H960@=&\@=&AI<R!M97-S
M86=E+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!!8W1I=F%T92!T:&4@
M8VAE8VLM8G5T=&]N(&YE>'0@=&\@(E-A=F4@8V]P>2(@=&\@<V%V92!A(&-O
M<'D@;V8@=&AI<R!M97-S86=E(&EN('EO=7(@(E-E;G0@36%I;"(@9F]L9&5R
M+B!3879E(&-O<&EE<R!O9B!I;7!O<G1A;G0@96UA:6QS('EO=2!S96YD('-O
M('1H870@>6]U(&AA=F4@<V]M971H:6YG('1O(')E9F5R(&)A8VL@=&\@;&%T
M97(@86YD('1O(&ME97`@86X@86-C=7)A=&4@<F5C;W)D(&]F('=H870@=V%S
M('-A:60N(%=E(&1O(&YO="!R96-O;6UE;F0@>6]U('-A=F4@979E<GD@96UA
M:6P@<VEN8V4@=&AE;B!Y;W5R(&1I<VL@<W1O<F%G92!Q=6]T82!W:6QL(&)E
M('5S960@=7`@<75I8VML>2`H97-P96-I86QL>2!W:&5N('EO=2!S96YD(&%T
M=&%C:&UE;G1S*2!A;F0@>6]U<B!M86EL8F]X('=I;&P@8F4@9G5L;"!A;F0@
M=6YA8FQE('1O(')E8V5I=F4@;F5W(&EN8V]M:6YG(&5M86EL+B!9;W4@8V%N
M+"!H;W=E=F5R+"!T=7)N('1H:7,@9F5A='5R92`G;VXG(&%S('EO=7(@9&5F
M875L="!W:71H("=0<F5F97)E;F-E<R<@;VX@=&AE(&)L=64@;F%V:6=A=&EO
M;B!B87(@870@=&]P+B!"92!C87)E9G5L('=H96X@=7-I;F<@=&AI<R!M;V1I
M9FEE9"!D969A=6QT(&%S('EO=2!W:6QL(&YE960@=&\@<&5R:6]D:6-A;&QY
M('!U<F=E('EO=7(@(E-E;G0@36%I;"(@9F]L9&5R(&]R(&ET('=I;&P@979E
M;G1U86QL>2!M86ME('EO=7(@;6%I;&)O>"!F=6QL(&%N9"!U;G5S96%B;&4N
M"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)C
M;VUP;W-E+6]P=&EO;G,B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I
M;VXZ($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[3W!T:6]N
M<R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE<V4@3W!T:6]N
M<R!H96QP('EO=2!P<F5P87)E('EO=7(@;65S<V%G92X*("`@(#PO<&%R83X*
M("`@(#QP87)A/@H@("`@0VQI8VL@)G%U;W0[4W!E;&P@0VAE8VLF<75O=#L@
M=&\@8VAE8VL@>6]U<B!S<&5L;&EN9RX*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@0VQI8VL@)G%U;W0[071T86-H;65N=',F<75O=#L@=&\@=FEE=R!A
M="!T:&4@8F]T=&]M(&]F('1H92!P86=E(&$@;&ES="!O9B!F:6QE<R!A='1A
M8VAE9"!T;R!T:&ES(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*
M("`@($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R`F<75O=#M3
M879E(&-O<'DF<75O=#L@=&\@<V%V92!A(&-O<'D@;V8@=&AI<R!M97-S86=E
M(&EN('EO=7(@)G%U;W0[4V5N="!-86EL)G%U;W0[(&9O;&1E<BX@4V%V92!C
M;W!I97,@;V8@:6UP;W)T86YT(&5M86EL<R!Y;W4@<V5N9"!S;R!T:&%T('EO
M=2!H879E('-O;65T:&EN9R!T;R!R969E<B!B86-K('1O(&QA=&5R(&%N9"!T
M;R!K965P(&%N(&%C8W5R871E(')E8V]R9"!O9B!W:&%T('=A<R!S86ED+B!7
M92!D;R!N;W0@<F5C;VUM96YD('EO=2!S879E(&5V97)Y(&5M86EL('-I;F-E
M('1H96X@>6]U<B!D:7-K('-T;W)A9V4@<75O=&$@=VEL;"!B92!U<V5D('5P
M('%U:6-K;'D@*&5S<&5C:6%L;'D@=VAE;B!Y;W4@<V5N9"!A='1A8VAM96YT
M<RD@86YD('EO=7(@;6%I;&)O>"!W:6QL(&)E(&9U;&P@86YD('5N86)L92!T
M;R!R96-E:79E(&YE=R!I;F-O;6EN9R!E;6%I;"X@66]U(&-A;BP@:&]W979E
M<BP@='5R;B!T:&ES(&9E871U<F4@)V]N)R!A<R!Y;W5R(&1E9F%U;'0@=VET
M:&EN('EO=7(@261E;G1I='DL(&)Y(&=O:6YG('1O($]P=&EO;G,M)F=T.U!E
M<G-O;F%L($EN9F]R;6%T:6]N+29G=#M%9&ET('EO=7(@:61E;G1I=&EE<RX@
M0F4@8V%R969U;"!W:&5N('5S:6YG('1H:7,@;6]D:69I960@9&5F875L="!A
M<R!Y;W4@=VEL;"!N965D('1O('!E<FEO9&EC86QL>2!P=7)G92!Y;W5R("9Q
M=6]T.U-E;G0@36%I;"9Q=6]T.R!F;VQD97(@;W(@:70@=VEL;"!E=F5N='5A
M;&QY(&UA:V4@>6]U<B!M86EL8F]X(&9U;&P@86YD('5N=7-E86)L92X*("`@
M(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M
M<&]S92UA='1A8V@B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S
M86=E($-O;7!O<VET:6]N.B!!='1A8V@\+W1I=&QE/@H@("`@/&AE861I;F<^
M(D%T=&%C:"(\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@("!9;W4@;6%Y
M(&%T=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#$Z($5I=&AE<BP@='EP92!T:&4@<&%T:"!A;F0@;F%M
M92!O9B!A(&9I;&4@=&AA="!Y;W4@=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE
M<W-A9V4@;W(@8VQI8VL@(D)R;W=S92(@8G5T=&]N(&%N9"!S96QE8W0@=&AE
M(&9I;&4@=&\@8F4@871T871C:&5D+B!4:&4@<&%T:"!A;F0@;F%M92!O9B!T
M:&%T(&9I;&4@;F]W(&%P<&5A<G,@:6X@=&AE($%T=&%C:&UE;G0@8F]X+B!.
M;W<@<')O8V5E9"!T;PI3=&5P(#(N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3
M=&5P(#(Z($-L:6-K(")!='1A8V@B(&)U='1O;BX@5&AE(&9I;&4@;F%M92!A
M;F0@<VEZ92!W:6QL(&)E(&%D9&5D('1O('EO=7(@;&ES="!O9B!!='1A8VAM
M96YT<RX@4&QE87-E(&YO=&4@=&AA="!F;W(@;&%R9V4@9FEL97,@86YD+V]R
M('-L;W=E<B!);G1E<FYE="!C;VYN96-T:6]N<RP@=&AE('!R;V-E<W,@;V8@
M=7!L;V%D:6YG(&%N9"!A='1A8VAI;F<@>6]U<B!F:6QE('1O('1H92!E;6%I
M;"!M87D@=&%K92!A('=H:6QE+B!0;&5A<V4@8F4@<&%T:65N="!A;F0@9&\@
M;F]T(&-L:6-K(&]N(&]T:&5R('1H:6YG<R!W:&EL92!Y;W4@87)E('=A:71I
M;F<N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)C;VUP;W-E+6%T=&%C:"(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@071T86-H/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T%T=&%C
M:"9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA>2!A='1A
M8V@@9FEL97,@=&\@>6]U<B!M97-S86=E.R!O;FQY(&]N92!F:6QE(&UA>2!B
M92!A='1A8VAE9"!A="!A('1I;64N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3
M=&5P(#$Z($5I=&AE<BP@='EP92!T:&4@<&%T:"!A;F0@;F%M92!O9B!A(&9I
M;&4@=&AA="!Y;W4@=V%N="!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4@;W(@
M8VQI8VL@)G%U;W0[0G)O=W-E)G%U;W0[(&)U='1O;B!A;F0@<V5L96-T('1H
M92!F:6QE('1O(&)E(&%T=&%T8VAE9"X@5&AE('!A=&@@86YD(&YA;64@;V8@
M=&AA="!F:6QE(&YO=R!A<'!E87)S(&EN('1H92!!='1A8VAM96YT(&)O>"X*
M("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@,CH@1&5C:61E('=H971H97(@
M>6]U('=A;G0@=&AE(&9I;&4@=&\@8F4@=FEE=V5D(&%S(&%N(&%T=&%C:&UE
M;G0@;W(@:6YL:6YE9"!W:71H('1H92!R97-T(&]F('1H92!M97-S86=E+B!4
M:&4@<F5C96EV:6YG('!E<G-O;BAS*2!M86EL(')E861I;F<@<V]F='=A<F4@
M;75S="!B92!A8FQE('1O(&AA;F1L92!T:&4@9FEL92!T>7!E(&EN;&EN93L@
M:68@;F]T+"!T:&ES('!A<G0@=VEL;"!B92!V:65W960@87,@86X@871T86-H
M;65N="!I;G-T96%D+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`S.B!#
M;&EC:R`F<75O=#M!='1A8V@F<75O=#L@8G5T=&]N+B!4:&4@9FEL92!N86UE
M(&%N9"!S:7IE('=I;&P@8F4@861D960@=&\@>6]U<B!L:7-T(&]F($%T=&%C
M:&UE;G1S+B!0;&5A<V4@;F]T92!T:&%T(&9O<B!L87)G92!F:6QE<R!A;F0O
M;W(@<VQO=V5R($EN=&5R;F5T(&-O;FYE8W1I;VYS+"!T:&4@<')O8V5S<R!O
M9B!U<&QO861I;F<@86YD(&%T=&%C:&EN9R!Y;W5R(&9I;&4@=&\@=&AE(&5M
M86EL(&UA>2!T86ME(&$@=VAI;&4N(%!L96%S92!B92!P871I96YT(&%N9"!D
M;R!N;W0@8VQI8VL@;W1H97(@=&AI;F=S('=H:6QE('EO=2!A<F4@=V%I=&EN
M9RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB8V]M<&]S92UA='1A8VAM96YT<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@
M/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:&UE;G1S/"]T:71L
M93X*("`@(#QH96%D:6YG/B)!='1A8VAM96YT<R(\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H:7,@<V5C=&EO;B!D:7-P;&%Y<R!A(&QI<W0@;V8@9FEL
M97,@86QR96%D>2!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V4N(%1O($1E;&5T
M92!A;B!A='1A8VAE9"!F:6QE.@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E
M<"`Q.B!!8W1I=F%T92!T:&4@8VAE8VLM8G5T=&]N(&YE>'0@=&\@=&AE(&%T
M=&%C:&5D(&9I;&5N86UE('EO=2!W86YT('1O($1E;&5T92X*("`@(#PO<&%R
M83X@"B`@("`\<&%R83Y3=&5P(#(Z($-L:6-K(")$96QE=&4@071T86-H;65N
M="AS*2(N"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y
M(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(CX*("`@(#QT:71L93Y-97-S86=E
M($-O;7!O<VET:6]N.B!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SXF<75O=#M!='1A8VAM96YT<R9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@5&AI<R!S96-T:6]N(&1I<W!L87ES(&$@;&ES="!O9B!F:6QE<R!A
M;')E861Y(&%T=&%C:&5D('1O('EO=7(@;65S<V%G92X@5&\@1&5L971E(&%N
M(&%T=&%C:&5D(&9I;&4Z"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#$Z
M($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R!T:&4@871T86-H
M960@9FEL96YA;64@>6]U('=A;G0@=&\@1&5L971E+@H@("`@/"]P87)A/B`*
M("`@(#QP87)A/E-T97`@,CH@0VQI8VL@)G%U;W0[1&5L971E($%T=&%C:&UE
M;G0H<RDF<75O=#LN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*
M("`\96YT<GD@:60](F-O;7!O<V4M<')I;W)I='DB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I;VXZ(%!R:6]R:71Y/"]T:71L
M93X*("`@(#QH96%D:6YG/B)0<FEO<FET>2(\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(%1H:7,@<V5T<R!T:&4@(E@M4')I;W)I='DB(&AE861E<B!O;B!Y
M;W5R(&]U=&=O:6YG(&UE<W-A9V4N(%1H92`B6"U0<FEO<FET>2(@=&%G(&ES
M(&$@<V]R="!O9B`B<'-E=61O('-T86YD87)D(B!T:&%T($YE='-C87!E+"!-
M;WII;&QA+"!/<&5R82P@86YD($]U=&QO;VL@;6%I;"!C;&EE;G1S(&%P<&5A
M<B!T;R!A9W)E92!O;BX@06YY(&UA:6P@8VQI96YT<R!T:&%T(&1O(&YO="!H
M86YD;&4@=&AI<R!H96%D97(@=VEL;"!S:6UP;'D@:6=N;W)E(&ET+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92US879E+6%T
M=&%C:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-97-S86=E($-O
M;7!O<VET:6]N.B!3879E($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A
M/@H@("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y
M;W5R(&-O;7!O<VET:6]N(&%R92!S879E9"!W:71H('1H92!M97-S86=E('=H
M96X@<W1O<F5D(&EN('1H92!S96YT+6UA:6P@9F]L9&5R+B`@268@(EEE<R(L
M('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S879E9"X@($EF(").;R(L
M('1H92!A='1A8VAM96YT(&1A=&$@=VEL;"!B92!S=')I<'!E9"!F<F]M('1H
M92!M97-S86=E(&%F=&5R(&ET(&ES('-E;G0@=&\@86QL(')E8VEP:65N=',N
M("!#:&]O<VEN9R`B3F\B('=I;&P@:&5L<"!C;VYS97)V92!D:7-K('-P86-E
M(&)Y(')E;6]V:6YG("AP;W1E;G1I86QL>2!L87)G92D@871T86-H;65N="!I
M;F9O<FUA=&EO;B!F<F]M('1H92!S879E9"!M97-S86=E<RX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;&EN:RUA='1A8VAM
M96YT<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@3&EN:R!!='1A8VAM96YT<SPO=&ET;&4^"B`@("`\<&%R83X*("`@
M($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@871T86-H;65N=',@:6X@>6]U<B!C
M;VUP;W-I=&EO;B!A<F4@<V5N="!A<R!A('!A<G0@;V8@=&AE(&UA:6P@;65S
M<V%G92!O<B!W:&5T:&5R('1H;W-E(&%T=&%C:&UE;G1S(&%R92!K97!T(&]N
M(&$@;&]C86P@<V5R=F5R+B`@268@871T86-H;65N=',@87)E(&QI;FME9"P@
M=&AE(')E8VEP:65N="AS*2!O9B!Y;W5R(&UE<W-A9V4@=VEL;"!B92!P<F]V
M:61E9"!A('=E8FQI;FL@=VAE<F4@=&AE>2!C86X@9&]W;FQO860@=&AE(&%T
M=&%C:&UE;G0H<RDN("!,:6YK:6YG(&%T=&%C:&UE;G1S(&AA<R!T:&4@861V
M86YT86=E(&]F('1R96UE;F1O=7-L>2!R961U8VEN9R!T:&4@<VEZ92!O9B!O
M=71G;VEN9R!M97-S86=E<RX@($QI;FMI;F<@871T86-H;65N=',@:&%S('1H
M92!D:7-A9'9A;G1A9V4@=&AA="!T:&4@8V]N=&5N="!O9B!T:&4@871T86-H
M;65N=',@8V%N(&YO="!B92!G=6%R86YT965D('1O(&)E(&%V86EL86)L92!I
M;B!T:&4@9G5T=7)E('-I;F-E('1H92!A='1A8VAM96YT(&1A=&$@:7,@;F]T
M(&QO8V%T960@=VET:&EN('1H92!E+6UA:6P@;65S<V%G92X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G-E87)C:"(@<W1A=&4](G5N:VYO
M=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@4V5A<F-H/"]T:71L93X*("`@(#QH
M96%D:6YG/E-E87)C:"!#<FET97)I83PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@("`@($AE;'`@=&5X="!T;R!B92!W<FET=&5N+@H@("`@/"]P87)A/@H\
M(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<V5A<F-H(CX*("`@(#QT
M:71L93Y-97-S86=E(%-E87)C:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY396%R
M8V@@0W)I=&5R:6$\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=2!M87D@
M<V5A<F-H(&9O<B!M97-S86=E<R!F<F]M('EO=7(@9F]L9&5R<R!U<VEN9R!D
M:69F97)E;G0@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^4W1E<"`Q.B!%;G1E<B!T97AT('1O('1H92!F:65L9',@>6]U('=A;G0@
M=&\@861D('1O('EO=7(@<V5A<F-H(&-R:71E<FEA+@H@("`@/"]P87)A/@H@
M("`@/'!A<F$^4W1E<"`R.B!#:&]O<V4@=&AE(&UE<W-A9V4@9FQA9RAS*2!T
M;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#,Z($-H;V]S92!T:&4@9F]L9&5R*',I(&9R;VT@=VAI
M8V@@=&\@<V5A<F-H(&9O<B!T:&4@;65S<V%G97,N"B`@("`\+W!A<F$^"B`@
M("`\<&%R83Y3=&5P(#0Z($-L:6-K("9Q=6]T.U-E87)C:"9Q=6]T.RX*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@268@86YY(&UE<W-A9V5S(&UA=&-H
M960@>6]U<B!S96%R8V@@8W)I=&5R:6$L('1H96X@=&AE('-U8FIE8W1S(&]F
M('1H97-E(&UE<W-A9V5S('=I;&P@8F4@<VAO=VX@:6X@=&AE("9Q=6]T.U-E
M87)C:"!297-U;'1S)G%U;W0[('9I97<N"B`@("`\+W!A<F$^"CPO96YT<GD^
M+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUO<'1I;VYS(B!S=&%T
M93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^1F]L9&5R($UA;F%G96UE;G0\+W1I
M=&QE/@H@("`@/&AE861I;F<^1F]L9&5R($]P=&EO;G,\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@("`@66]U(&-A;B!S96QE8W0@82!F;VQD97(@8GD@=7-I
M;F<@=&AE(')A9&EO(&)U='1O;G,@86QO;F<@=&AE(&QE9G0@8V]L=6UN+B`@
M3VYC92!Y;W4@:&%V92!D;VYE('1H:7,L('-E;&5C="!T:&4@;W!T:6]N('EO
M=2!W:7-H('1O('!E<F9O<FT@;VX@=&AE(&9O;&1E<B!V:6$@=&AE('-E;&5C
M="!B;W@@=&\@=&AE(&QE9G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M("`@66]U('=I;&P@8F4@<')O;7!T960@9F]R(&9U<G1H97(@;W!T:6]N<RX@
M($)E(&-A<F5F=6P@=VET:"!T:&4@9&5L971E(&]P=&EO;BP@87,@>6]U(&-A
M;B!L;W-E(&%L;"!T:&4@;65S<V%G97,@:6X@82!F;VQD97(@:68@>6]U(&1E
M;&5T92!I="!B>2!M:7-T86ME(0H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@
M96YT<GDZ"CQE;G1R>2!I9#TB9F]L9&5R+6]P=&EO;G,B/@H@("`@/'1I=&QE
M/D9O;&1E<B!-86YA9V5M96YT/"]T:71L93X*("`@(#QH96%D:6YG/D9O;&1E
M<B!/<'1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@(%EO=2!C86X@
M<V5L96-T(&$@9F]L9&5R(&)Y('5S:6YG('1H92!R861I;R!B=71T;VYS(&%L
M;VYG('1H92!L969T(&-O;'5M;BX@($]N8V4@>6]U(&AA=F4@9&]N92!T:&ES
M+"!S96QE8W0@=&AE(&]P=&EO;B!Y;W4@=VES:"!T;R!P97)F;W)M(&]N('1H
M92!F;VQD97(@=FEA('1H92!S96QE8W0@8F]X('1O('1H92!L969T+@H@("`@
M/"]P87)A/@H@("`@/'!A<F$^"B`@("`@(%EO=2!W:6QL(&)E('!R;VUP=&5D
M(&9O<B!F=7)T:&5R(&]P=&EO;G,N("!"92!C87)E9G5L('=I=&@@=&AE(&1E
M;&5T92!O<'1I;VXL(&%S('EO=2!C86X@;&]S92!A;&P@=&AE(&UE<W-A9V5S
M(&EN(&$@9F]L9&5R(&EF('EO=2!D96QE=&4@:70@8GD@;6ES=&%K92$*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/DEM<&]R="!M8F]X($9I;&4\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@("`@5&AI<R!O<'1I;VX@=VEL;"!I;7!O<G0@
M82!M8F]X(&9O<FUA="!F:6QE(&EN=&\@=&AE(&9O;&1E<B!O9B!Y;W5R(&-H
M;VEC92X@0VAO;W-E(#$@*&]N92D@9F]L9&5R('1O(&EM<&]R="!T:&4@;65S
M<V%G97,@:6YT;R!A;F0@=&AE;B!S96QE8W0@=&AI<R!O<'1I;VXN(%EO=2!W
M:6QL('1H96X@8F4@=&%K96X@=&\@82!P86=E('1H870@=VEL;"!P<F]M<'0@
M9F]R('1H92!M8F]X(&9I;&4@=&\@:6UP;W)T+@H@("`@/"]P87)A/@H\+V5N
M=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F;VQD97(M=VED9V5T<R(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1F]L9&5R($UA;F%G96UE;G0Z($1I
M<W!L87D\+W1I=&QE/@H@("`@/&AE861I;F<^4VAO=R](:61E(%5N<W5B<V-R
M:6)E9#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=7-I;F<@24U!4"!F
M;VQD97(@<W5B<V-R:7!T:6]N<RP@<VAO=R]H:61E('1H92!U;G-U8G-C<FEB
M960@9F]L9&5R<RX@(%1O('-U8G-C<FEB92]U;G-U8G-C<FEB92!T;R!A(&9O
M;&1E<BP@<V5L96-T('1H92!C:&5C:V)O>"!N97AT('1O('1H92!F;VQD97)N
M86UE(&%N9"!U<V4@=&AE(%-U8G-C<FEB92]5;G-U8G-C<FEB92!O<'1I;VX@
M:6X@=&AE($9O;&1E<B!!8W1I;VX@9')O<"UD;W=N(&UE;G4N"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY%>'!A;F0@06QL/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!%>'!A;F0@86QL(&9O;&1E<B!E;G1R:65S+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^0V]L;&%P<V4@06QL/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!#;VQL87!S92!A;&P@9F]L9&5R(&5N=')I97,N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97)S(B!S=&%T93TB=6YK
M;F]W;B(^"B`@("`\=&ET;&4^1FEL=&5R<SH@07!P;'D\+W1I=&QE/@H@("`@
M/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!#;&EC:R!O;B!T:&4@(D%P<&QY($9I;'1E<B(@:6-O;B!N97AT
M('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X('9I97<@=&\@9FEL
M=&5R(&%L;"!U;F1E;&5T960@;65S<V%G97,@86-C;W)D:6YG('1O('1H92!S
M<&5C:69I960@<G5L97,N("!/<BP@86QT97)N871E=FQY+"!C;&EC:R!O;B`B
M07!P;'D@06QL(%)U;&5S(B!I;B!T:&4@9FEL=&5R(&UE;G4N("!.;W1E('1H
M870@9FEL=&5R:6YG(&ES(&YO="!D;VYE(&%U=&]M871I8V%L;'DN"B`@("`\
M+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)F:6QT97)S
M(CX*("`@(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^"B`@("`\:&5A
M9&EN9SY!<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($-L:6-K(&]N('1H92`F<75O=#M!<'!L>2!&:6QT97(F<75O=#L@:6-O
M;B!N97AT('1O('1H92!)3D)/6"!N86UE(&EN('1H92!M86EL8F]X('9I97<@
M=&\@9FEL=&5R(&%L;"!U;F1E;&5T960@;65S<V%G97,@86-C;W)D:6YG('1O
M('1H92!S<&5C:69I960@<G5L97,N("!/<BP@86QT97)N871E=FQY+"!C;&EC
M:R!O;B`F<75O=#M!<'!L>2!!;&P@4G5L97,F<75O=#L@:6X@=&AE(&9I;'1E
M<B!M96YU+B`@3F]T92!T:&%T(&9I;'1E<FEN9R!I<R!N;W0@9&]N92!A=71O
M;6%T:6-A;&QY+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)F:6QT97(M961I="UR=6QE<R(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^1FEL=&5R<SH@161I="!&:6QT97(@4G5L97,\+W1I=&QE/@H@
M("`@/&AE861I;F<^161I="!9;W5R($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!F:6QT97(@<G5L
M97,B('1O('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L
M(&1E;&5T92P@86YD(&5D:70@=&AE(&-U<G)E;G1L>2!A8W1I=F4@<V5T(&]F
M(&9I;'1E<B!R=6QE<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](F9I;'1E<BUE9&ET+6)L86-K;&ES="(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^1FEL=&5R<SH@161I="!";&%C:VQI<W0\+W1I=&QE/@H@("`@/&AE
M861I;F<^161I="!9;W5R($)L86-K;&ES=#PO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!B;&%C:VQI<W0B('1O('!R;V-E
M960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T92P@86YD
M(&5D:70@=&AE(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y;W4@04Q705E3
M(')E9G5S92!M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)F:6QT97(M961I="UW:&ET96QI<W0B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/D9I;'1E<G,Z($5D:70@5VAI=&5L:7-T/"]T:71L93X*("`@
M(#QH96%D:6YG/D5D:70@66]U<B!7:&ET96QI<W0\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-L:6-K(&]N(")%9&ET('EO=7(@=VAI=&5L:7-T(B!T;R!P
M<F]C965D('1O('1H92!P86=E('=H97)E('EO=2!C86X@861D+"!D96QE=&4L
M(&%N9"!E9&ET('1H92!L:7-T(&]F(&4M;6%I;"!A9&1R97-S97,@>6]U($%,
M5T%94R!A8V-E<'0@;6%I;"!F<F]M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9FEL=&5R+6]N+6QO9VEN(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y&:6QT97)S.B!&:6QT97(@;VX@3&]G:6X\+W1I=&QE/@H@("`@
M/&AE861I;F<^07!P;'D@1FEL=&5R(%)U;&5S(%5P;VX@3&]G;VX_/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!T;R!A;'=A
M>7,@87!P;'D@9FEL=&5R<R!W:&5N(&9I<G-T(&QO9V=I;F<@;VYT;R!)35`N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM
M9&ES<&QA>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@1FEL
M=&5R(&]N(%)E9G)E<V@\+W1I=&QE/@H@("`@/&AE861I;F<^07!P;'D@9FEL
M=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N('1O(&%L=V%Y
M<R!A<'!L>2!F:6QT97)S('=H96YE=F5R('EO=7(@=FEE=R!T:&4@24Y"3U@_
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M86YY
M+6UA:6QB;W@B('-T871E/2)N97<B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($9I
M;'1E<B!A;GD@36%I;&)O>#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!F
M:6QT97(@<G5L97,@=&\@86YY(&UA:6QB;W@_/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!#:&5C:R!T:&ES(&]P=&EO;B!I9B!Y;W4@=V%N="!T;R!B92!A
M;&QO=V5D('1O(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!A;GD@;6%I;&)O>"X@
M3F]R;6%L;'DL(&9I;'1E<FEN9R!R=6QE<R!A<F4@;VYL>2!A<'!L:65D('1O
M(&YE=R!M86EL('1H870@:7,@9&5L:79E<F5D('1O('EO=7(@24Y"3U@N("!)
M9B!T:&ES(&]P=&EO;B!I<R!C:&5C:V5D+"!A;B!I8V]N('=I;&P@87!P96%R
M(&]N(&%L;"!M86EL8F]X('!A9V=E<R!T:&%T('=I;&P@86QL;W<@>6]U('1O
M(&%P<&QY(&9I;'1E<B!R=6QE<R!T;R!T:&4@;65S<V%G97,@:6X@=&AE(&-U
M<G)E;G0@;6%I;&)O>"X@($Y/5$4Z($9I;'1E<FEN9R!I;B!M86EL8F]X97,@
M;W1H97(@=&AA;B!)3D)/6"!M87D@<')O9'5C92!S=')A;F=E("AE+F<N('1H
M92!F:6QT97(@;6%Y(&-A=7-E(&$@8V]P>2!O9B!M97-S86=E<R!T;R!B92!D
M96QI=F5R960@=&\@=&AE('-A;64@;6%I;&)O>"D@86YD+V]R('5N9&5S:7)E
M9"!R97-U;'1S("AE+F<N(&ET(&UA>2!C875S92!M97-S86=E<R!T;R!B92!M
M;W9E9"]D96QE=&5D(&EF(&YE=R!F:6QT97)I;F<@<G5L97,@:&%V92!B965N
M(&EM<&QE;65N=&5D('-I;F-E('1H92!M97-S86=E(&AA<R!B965N(&1E;&EV
M97)E9"!T;R!T:&4@8W5R<F5N="!M86EL8F]X*2X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UC;VUP;W-E+6%T=&%C:"UP=6)K97DB
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@071T86-H(%!U8FQI8R!+
M97D\+W1I=&QE/@H@("`@/&AE861I;F<^071T86-H(%!U8FQI8R!+97D\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($EF('-E;&5C=&5D('1H96X@82!C;W!Y
M(&]F('EO=7(@4$=0('!U8FQI8R!K97DL(&EF(&ET(&5X:7-T<RP@=VEL;"!B
M92!A='1A8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X@(%EO=2!C86X@
M<V5T('1H92!D969A=6QT(&)E:&%V:6]R('9I82!T:&4@4$=0($]P=&EO;G,@
M<V-R965N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P
M+6]P=&EO;BUS8V%N+6)O9'DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'
M4#H@4V-A;B!497AT($)O9&EE<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY38V%N
M(%1E>'0@0F]D:65S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE
M8W1E9"!T:&5N($E-4"!W:6QL('-C86X@=&AE(&)O9'D@;V8@86QL('1E>'0@
M;65S<V%G97,@9F]R(%!'4"!D871A+"!A;F0@9&ES<&QA>2!T:&4@<F5S=6QT
M<R!I9B!A;GD@9&%T82!I<R!F;W5N9"X@($YO=&4@=&AA="!T:&ES(&UA>2!S
M;&]W(&1O=VX@=&AE('-Y<W1E;2!A<R!E=F5R>2!T97AT(&UE<W-A9V4@;75S
M="!B92!S8V%N;F5D(&EN(&ET<R!E;G1I<F5T>2!F;W(@4$=0(&1A=&$N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO
M;G,M96YC<GEP="(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^0V]M<&]S93H@
M16YC<GEP=&EO;B!/<'1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/DYO($5N
M8W)Y<'1I;VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-E;F0@=&AE(&UE
M<W-A9V4@=VET:"!N;R!E;F-R>7!T:6]N("AC;&5A<G1E>'0I+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^4$=0($5N8W)Y<'0@365S<V%G93PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!E;F-R>7!T('1H
M92!C=7)R96YT(&UE<W-A9V4L('5S:6YG(%!'4"!A;F0@=&AE(')E8VEP:65N
M=',@<&5R<V]N86P@<'5B;&EC(&ME>2P@86YD('1H96X@<V5N9"!I="X@66]U
M(&-A;B!O;FQY('-E;F0@82!M97-S86=E('1O(&$@<VEN9VQE('!E<G-O;B!U
M<VEN9R!T:&ES(&]P=&EO;BX@66]U($U54U0@:&%V92!T:&4@<'5B;&EC(&ME
M>2!O9B!T:&4@<F5C:7!I96YT('-T;W)E9"!I;B!Y;W5R(&%D9')E<W-B;V]K
M(&]R(&5L<V4@=&AI<R!O<'1I;VX@=VEL;"!F86EL+B!)9B!Y;W4@:&%V92!T
M:&4@<'5B;&EC(&ME>2!F;W(@=&AE(')E8VEP:65N="!I;B!Y;W5R(&%D9')E
M<W-B;V]K(&%N9"!A<F4@<W1I;&P@<F5C96EV:6YG(&5R<F]R<RP@=F5R:69Y
M('1H870@=&AE(&4M;6%I;"!A9&1R97-S(&EN('1H92!R96-I<&EE;G0@9FEE
M;&0@;6%T8VAE<R!T:&4@92UM86EL(&%D9')E<W,@=VAE<F4@=&AE('!U8FQI
M8R!K97D@:7,@<W1O<F5D+B!4:&4@96YC<GEP=&5D(&1A=&$@=VEL;"!B92!A
M='1A8VAE9"!T;R!T:&4@;W5T9V]I;F<@;65S<V%G92X*("`@(#PO<&%R83X*
M("`@(#QH96%D:6YG/E!'4"!3:6=N($UE<W-A9V4\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H:7,@;W!T:6]N('=I;&P@9&EG:71A;&QY('-I9VX@=&AE
M(&-U<G)E;G0@;65S<V%G92!U<VEN9R!01U`@86YD('EO=7(@<&5R<V]N86P@
M<')I=F%T92!K97DN($EF('EO=2!H879E(&YO="!A;')E861Y(&5N=&5R960@
M=&AE('!A<W-P:')A<V4@9F]R('EO=7(@<')I=F%T92!K97D@9'5R:6YG('1H
M:7,@<V5S<VEO;B!Y;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@:70N("!4:&4@
M<F5C96EP:65N="!M=7-T(&AA=F4@82!C;W!Y(&]F('EO=7(@<'5B;&EC(&ME
M>2!T;R!D:6=I=&%L;'D@=F5R:69Y('EO=7(*("`@('-I9VYA='5R92X*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G
M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!F
M:7)S="!D:6=I=&%L;'D@<VEG;B!Y;W5R(&UE<W-A9V4@86YD('1H96X@=VEL
M;"!E;F-R>7!T('1H92!R97-U;'1I;F<@;W5T<'5T+B!3964@=&AE("=01U`@
M16YC<GEP="!-97-S86=E)R!A;F0@)U!'4"!3:6=N($UE<W-A9V4G(&5N=')I
M97,@9F]R(&9U<G1H97(@:6YF;W)M871I;VXN"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY3+TU)344@16YC<GEP="!-97-S86=E/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("!43T1/"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)
M344@4VEG;B!-97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!43T1/
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)344@4VEG;B]%;F-R>7!T
M($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO=F5R=FEE=R(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!/=F5R=FEE=SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY7:&%T(&ES(%!'4#\\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@(%!'4"!I<R!A('1O;VP@9F]R('-E8W5R92!C;VUM=6YI8V%T:6]N(&%N
M9"!D871A('-T;W)A9V4L(&5S<&5C:6%L;'D@9F]R('5S92!W:71H(&4M;6%I
M;"X@270@8V%N(&)E('5S960@=&\@96YC<GEP="!D871A(&%N9"!T;R!C<F5A
M=&4@9&EG:71A;"!S:6=N871U<F5S+B!)35`@=7-E<R!';G501R`H1TY5(%!R
M:79A8WD@1W5A<F0I('1O('!R;W9I9&4@=&AI<R!F=6YC=&EO;F%L:71Y+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^16YA8FQE(%!'4"!F=6YC=&EO;F%L
M:71Y/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=&AI<R!O<'1I;VX@
M:7,@<V5L96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@8W)E871E+W9I97<@
M>6]U<B!P97)S;VYA;"!01U`@:V5Y<RP@861D+V1E;&5T92!P=6)L:6,@:V5Y
M<R!F<F]M(&]T:&5R(&EN9&EV:61U86QS+"!R96%D(&5N8W)Y<'1E9"!M86EL
M+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@96YC<GEP="]S
M:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!G<"UO<'1I;VXM871T86-H+7!U8FME>2(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!/<'1I;VYS("T@071T86-H(%!U8FQI
M8R!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^3W!T:6]N<R`M($%T=&%C:"!0
M=6)L:6,@2V5Y/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!S96QE8W1E
M9"!T:&5N(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y+"!I9B!I="!E
M>&ES=',L('=I;&P@8GD@9&5F875L="!B92!A='1A8VAE9"!T;R!A;&P@;W5T
M9V]I;F<@;65S<V%G97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P9W`M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4$=0.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@("`@/&AE861I
M;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1H:7,@<V-R
M965N(&QI<W1S(&%L;"!O9B!T:&4@8W5R<F5N="!U<V5R<R!I;B!Y;W5R(&%D
M9')E<W-B;V]K('1H870@:&%V92!01U`@<'5B;&EC(&ME>7,N(%1H97-E('5S
M97)S(&%R92!T:&4@3TY,62!U<V5R<R!T:&%T('EO=2!C86X@96ET:&5R(#$I
M('-E;F0@86X@96YC<GEP=&5D(&UE<W-A9V4@=&\@+4]2+2`R*2!V97)I9GD@
M82!D:6=I=&%L('-I9VYA='5R92X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN9&]W
M('1O('9I97<@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@
M/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&ES
M<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<'5B;&EC(&ME>2X*
M("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E;&5T93PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@1&5L971E<R!T:&4@<'5B;&EC(&ME>2!F<F]M('EO=7(@
M861D<F5S<V)O;VLN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M:6UP;W)T+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4$=0.B!-86YA9V4@4'5B;&EC($ME>7,@+2!);7!O<G0\+W1I=&QE/@H@("`@
M/&AE861I;F<^26UP;W)T(%!U8FQI8R!+97ES/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4:&ES(&)U='1O;B!W:6QL(&]P96X@82!W:6YD;W<@=VAE<F4@
M>6]U(&-A;B!M86YU86QL>2!I;7!O<G0@82!01U`@<'5B;&EC(&ME>2X@(%1H
M92!K97D@8V%N(&5I=&AE<B!B92!P87-T960@:6YT;R!A('1E>'1F:65L9"!O
M<BP@:68@=&AE(&ME>2!R97-I9&5S(&EN(&$@9FEL92!O;B!Y;W5R(&QO8V%L
M(&-O;7!U=&5R+"!Y;W4@8V%N(&EM<&]R="!I="X@($EF('1H92!K97D@:7,@
M=F%L:60@:70@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@861D<F5S<V)O
M;VL@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T('9A;&ED+"!A
M;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP;&%I;FEN9R!W
M:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E
M<G9I97<M<&5R<V]N86QK97DB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!'
M4#H@36%N86=E(%!E<G-O;F%L($ME>7,\+W1I=&QE/@H@("`@/&AE861I;F<^
M3W9E<G9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('EO=2!W86YT
M('1O(&1I9VET86QL>2!S:6=N(&UE<W-A9V5S(&]R(&5N86)L92!O=&AE<G,@
M=&\@<V5N9"!Y;W4@96YC<GEP=&5D(&UE<W-A9V5S+"!Y;W4@;75S="!H879E
M('EO=7(@;W=N('!E<G-O;F%L('!U8FQI8R]P<FEV871E(%!'4"!K97EP86ER
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0=6)L:6,@2V5Y/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!U8FQI8R!K97D@<VAO=6QD
M(&)E(&UA9&4@879A:6QA8FQE('1O(&%N>2!P97)S;VX@=&AA="!Y;W4@=V%N
M="!T;R!B92!A8FQE('1O('-E;F0@>6]U(&5N8W)Y<'1E9"!M97-S86=E<R!T
M:&%T(&]N;'D@64]5(&-A;B!D96-R>7!T("AU<VEN9R!Y;W5R('!R:79A=&4@
M:V5Y*2X@061D:71I;VYA;&QY+"!Y;W5R('!U8FQI8R!K97D@;F5E9',@=&\@
M8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY8F]D>2!Y;W4@<V5N9"!A(&1D:6=I
M=&%L;'D@<VEG;F5D(&UE<W-A9V4@=&\@+2!T:&4@<'5B;&EC(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE(&1I9VET86P@<VEG;F%T=7)E+@H@("`@
M/"]P87)A/@H@("`@/&AE861I;F<^66]U<B!0<FEV871E($ME>3PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@66]U<B!P<FEV871E(&ME>2!I<R!N96-E<W-A
M<GD@=&\@9&5C<GEP="!A;GD@;65S<V%G92!E;F-R>7!T960@=7-I;F<@>6]U
M<B!P=6)L:6,@:V5Y+B!!9&1I=&EO;F%L;'DL('EO=7(@<')I=F%T92!K97D@
M:7,@;F5E9&5D(&EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&$@;65S
M<V%G92X@66]U<B!P<FEV871E(&ME>2!W:6QL(&)E('!R;W1E8W1E9"!V:6$@
M82!P87-S<&AR87-E(&-R96%T960@=VAE;B!T:&4@:V5Y<R!A<F4@9V5N97)A
M=&5D+B!4:'5S+"!T;R!P97)F;W)M(&%N>2!A8W1I=FET>2!T:&%T(')E<75I
M<F5S('EO=7(@<')I=F%T92!K97DL($E-4"!W:6QL('!R;VUP="!Y;W4@9F]R
M('EO=7(@<&%S<W!H<F%S92X@66]U(&]N;'D@;F5E9"!T;R!I;G-E<G0@>6]U
M<B!P87-S<&AR87-E(&]N8V4@<&5R('-E<W-I;VX@+2!)35`@=VEL;"!S=&]R
M92!Y;W5R('!A<W-P:')A<V4@=6YT:6P@>6]U(&QO9V]U="`H4V\@8F4@<W5R
M92!T;R!L;V=O=70A*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UP=6)L:6,B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!0=6)L:6,@2V5Y
M/"]T:71L93X*("`@(#QH96%D:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($]P96YS(&$@=VEN9&]W('1O('9I97<@=&AE(%!'4"!P=6)L:6,@
M:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T
M('1H92!01U`@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UP<FEV871E(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@4')I
M=F%T92!+97D\+W1I=&QE/@H@("`@/&AE861I;F<^16YT97(@4&%S<W!H<F%S
M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@=&AE('!A<W-P:')A
M<V4@9&EA;&]G('=I;F1O=RX@5&AE('!A<W-P:')A<V4@96YT97)E9"P@:68@
M8V]R<F5C="P@=VEL;"!B92!S=&]R960@8GD@24U0('5N=&EL('EO=7(@<V5S
M<VEO;B!E;F1S+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^56YL;V%D(%!A
M<W-P:')A<V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%)E;6]V97,@=&AE
M('-T;W)E9"!P87-S<&AR87-E(&9R;VT@24U0("T@86YY(&%D9&ET:6]N86P@
M=7-A9V4@;V8@=&AE('!R:79A=&4@:V5Y('=I;&P@<F5Q=6ER92!Y;W4@=&\@
M<F5E;G1E<B!T:&4@<&%S<W!H96%S92X*("`@(#PO<&%R83X*("`@(#QH96%D
M:6YG/E9I97<\+VAE861I;F<^"B`@("`\<&%R83X*("`@($]P96YS(&$@=VEN
M9&]W('1O('9I97<@=&AE(%!'4"!P<FEV871E(&ME>2X@1$\@3D]4(%-%3D0@
M5$A)4R!+15D@5$\@04Y93TY%("T@=&AI<R!O<'1I;VX@:7,@<W1R:6-T;'D@
M<V\@=&AA="!Y;W4@8V%N(&5X<&]R="!Y;W5R($E-4"!P97)S;VYA;"!P<FEV
M871E(&ME>2!F;W(@=7-E(&EN(&%N;W1H97(@<')O9W)A;2X*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE861I;F<^"B`@("`\<&%R83X*
M("`@($1I<W!L87ES('-O;64@9&5T86EL<R!A8F]U="!T:&4@4$=0('!R:79A
M=&4@:V5Y+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P
M+7!E<G-O;F%L:V5Y+61E;&5T92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M($1E;&5T93PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@2V5Y<SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!B=71T;VX@=VEL;"!D96QE=&4@>6]U<B!P97)S
M;VYA;"!P=6)L:6,O<')I=F%T92!K97EP86ER(&9R;VT@24U0)W,@<')E9F5R
M96YC97,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M
M<&5R<V]N86QK97DM8W)E871E+6YA;64B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($YA;64\+W1I=&QE/@H@
M("`@/&AE861I;F<^3F%M93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AE
M(&YA;64@>6]U('=A;G0@96UB961D960@:6X@>6]U<B!P97)S;VYA;"!K97ES
M+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UC;VUM96YT(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@
M+2!#;VUM96YT/"]T:71L93X*("`@(#QH96%D:6YG/D-O;6UE;G0\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@($$@8V]M;65N="!S=')I;F<@>6]U('=A;G0@
M96UB961D960@:6X@>6]U<B!P97)S;VYA;"!K97ES+B!!;B!O<'1I;VYA;"!F
M:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP
M97)S;VYA;&ME>2UC<F5A=&4M96UA:6PB('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($4M;6%I;"!!9&1R97-S
M/"]T:71L93X*("`@(#QH96%D:6YG/D4M;6%I;"!!9&1R97-S/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&4@92UM86EL(&%D9')E<W,@>6]U('=A;G0@
M87-S;V-I871E9"!W:71H('EO=7(@<&5R<V]N86P@:V5Y<RX@02!R97%U:7)E
M9"!F:65L9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UP97)S;VYA;&ME>2UC<F5A=&4M:V5Y;&5N9W1H(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@+2!+97EL96YG
M=&@\+W1I=&QE/@H@("`@/&AE861I;F<^2V5Y;&5N9W1H/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!4:&4@:V5Y;&5N9W1H+"!I;B!B>71E<RP@;V8@>6]U
M<B!G96YE<F%T960@:V5Y+B!4:&4@9W)E871E<B!T:&4@=F%L=64L('1H92!G
M<F5A=&5R('1H92!P<F]T96-T:6]N("AA;F0@86QS;R!G<F5A=&5R(&=E;F5R
M871I;VX@=&EM92!A;F0@96YC<GEP=&EO;B!T:6UE*2X@,3`R-"!B>71E<R!I
M<R!T:&4@9&5F875L="`M('1H:7,@=F%L=64@<')O=FED97,@97AC96QL96YT
M('!R;W1E8W1I;VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P9W`M<&5R<V]N86QK97DM8W)E871E+7!A<W-P:')A<V4B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M(%!A
M<W-P:')A<V4\+W1I=&QE/@H@("`@/&AE861I;F<^3F%M93PO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@5&AE('!A<W-P:')A<V4@=7-E9"!T;R!P<F]T96-T
M+V5N8W)Y<'0@>6]U<B!P97)S;VYA;"!P<FEV871E(&ME>2X@5&AI<R!S:&]U
M;&0@8F4@050@3$5!4U0@-B!C:&%R86-T97)S+"!S:&]U;&0@3D]4(&)E('1H
M92!S86UE(&%S('EO=7(@;&]G:6X@<&%S<W=O<F0L('-H;W5L9"!.3U0@8F4@
M8F%S960@;VX@82!D:6-T:6]N87)Y('=O<F0L(&%N9"!S:&]U;&0@:6YC;'5D
M92!B;W1H(&YU;6)E<G,@86YD(&QE='1E<G,N(%EO=2!M=7-T(&5N=&5R('1H
M:7,@<&%S<W!H<F%S92!T=VEC92!F;W(@=F5R:69I8V%T:6]N('!U<G!O<V5S
M+B!!(')E<75I<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UA8W1I;VYS(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($-R96%T92!097)S;VYA;"!+97D@
M+2!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D-R96%T92!+97ES/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!#<F5A=&4@86YD('-T;W)E('EO=7(@
M<&5R<V]N86PO<')I=F%T92!K97EP86ER+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^26UP;W)T($ME>7!A:7(\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($EM<&]R="!A('!E<G-O;F%L+W!R:79A=&4@:V5Y<&%I<BX@5&AI<R!B=71T
M;VX@;W!E;G,@82!W:6YD;W<@=VAE<F4@>6]U(&-A;B!M86YU86QL>2!I;7!O
M<G0@>6]U<B!E>&ES=&EN9R!01U`@<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@
M:V5Y<&%I<BX@(%1H92!K97ES(&-A;B!E:71H97(@8F4@<&%S=&5D(&EN=&\@
M82!T97AT9FEE;&0@;W(L(&EF('1H92!K97ES(')E<VED92!I;B!A(&9I;&4@
M;VX@>6]U<B!L;V-A;"!C;VUP=71E<BP@>6]U(&-A;B!I;7!O<G0@=&AE;2X@
M($EF('1H92!K97ES(&%R92!V86QI9"!T:&5Y('=I;&P@8F4@:6YS97)T960@
M:6YT;R!Y;W5R('!R969E<F5N8V5S(&%N9"!T:&4@=VEN9&]W('=I;&P@8VQO
M<V4[(&EF(&YO="!V86QI9"P@86X@97)R;W(@;65S<V%G92!W:6QL(&)E(')E
M='5R;F5D(&5X<&QA:6YI;F<@=VAY+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E,O34E-13H@3W9E<G9I97<\+W1I=&QE/@H@("`@/&AE861I;F<^
M5VAA="!I<R!3+TU)344_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!3+TU)
M344@:7,@82!P<FEV871E+W!U8FQI8R!K97D@<&%I<B!S>7-T96T@=VAI8V@@
M<')O=FED97,@9&EG:71A;"!S:6=N871U<F5S+"!M97-S86=E('!R:79A8WDL
M(&%N9"!T86UP97(@9&5T96-T:6]N(&EN(&$@;W!E;BP@:6YT97)O<&5R86)L
M92!W87DN("!3+TU)344@8V%N('!R;W9I9&4@;65S<V%G92!P<FEV86-Y(&)Y
M(&5N8W)Y<'1I;F<@;65S<V%G97,@=&AA="!O;FQY('1H92!S96YD97(@86YD
M('1H92!I;G1E;F1E9"!R96-I<&EE;G1S(&-A;B!D96-O9&4N("!)="!A;&QO
M=W,@>6]U('1O(&ED96YT:69Y('1H92!S96YD97(@;V8@82!M97-S86=E('9I
M82!A(&1I9VET86P@<VEG;F%T=7)E+B`@5&]G971H97(L('1H:7,@96YC<GEP
M=&EO;B!A;F0@9&EG:71A;"!S:6=N:6YG(&AE;'`@<')O=FED92!T86UP97(@
M9&5T96-T:6]N+"!A;&QO=VEN9R!R96-I<&EE;G1S('1O(&1E=&5R;6EN92!W
M:&5T:&5R(&$@;65S<V%G92!W87,@86QT97)E9"!A9G1E<B!I="!W87,@<V5N
M="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D5N86)L92!3+TU)344@9G5N
M8W1I;VYA;&ET>3\\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('1H:7,@
M;W!T:6]N(&ES('-E;&5C=&5D+"!Y;W4@=VEL;"!B92!A8FQE('1O(&EM<&]R
M="!Y;W5R('!E<G-O;F%L(%,O34E-12!K97ES+"!R96%D(&5N8W)Y<'1E9"!M
M86EL+"!V97)I9GD@9&EG:71A;&QY('-I9VYE9"!M86EL+"!A;F0@96YC<GEP
M="]S:6=N('EO=7(@;W5T9V]I;F<@;6%I;"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G-M:6UE+6]V97)V:65W+7!E<G-O;F%L:V5Y(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z(%!E<G-O;F%L($ME>7,\
M+W1I=&QE/@H@("`@/&AE861I;F<^3W9E<G9I97<\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($EF('EO=2!W86YT('1O(&1I9VET86QL>2!S:6=N(&]R(&5N
M8W)Y<'0@;65S<V%G97,@>6]U(&UU<W0@:&%V92!Y;W5R(&]W;B!P97)S;VYA
M;"!P=6)L:6,O<')I=F%T92!3+TU)344@:V5Y<&%I<BX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G-M:6UE+6EM<&]R="UP97)S;VYA;"UC
M97)T<R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4R]-24U%.B!);7!O<G0@
M4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH96%D:6YG/DEM
M<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($EM<&]R="!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!A(%!+
M0U,@(S$R(&9O<FUA="!F:6QE+B!02T-3(",Q,B!F:6QE<R!I<R!T:&4@9FEL
M92!U<W5A;&QY(&=E;F5R871E9"!W:&5N(&5X<&]R=&EN9R!A(&ME>2!F<F]M
M(&$@8G)O=W-E<B`H92YG+B!);G1E<FYE="!%>'!L;W)E<BP@1FER969O>"D@
M;W(@9G)O;2!A(&-E<G1I9FEC871E('-T;W)E(&UA:6YT86EN960@8GD@86X@
M3W!E<F%T:6YG(%-Y<W1E;2`H92YG+B!7:6YD;W=S(%A0*2X@268@=&AE(&ME
M>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO=7(@
M<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@;F]T
M('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@97AP
M;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)S;6EM92UD96QE=&4M<&5R<V]N86PM8V5R=',B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E,O34E-13H@1&5L971E(%!E<G-O;F%L($-E<G1I9FEC871E
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY$96QE=&4@4&5R<V]N86P@0V5R=&EF
M:6-A=&5S/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&4@>6]U<B!P
M97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!Y;W5R('!R969E<F5N8V5S+B`@
M66]U('=I;&P@;F\@;&]N9V5R(&)E(&%B;&4@=&\@<VEG;B!3+TU)344@;65S
M<V%G97,@;W(@=FEE=R!A;GD@4R]-24U%(&5N8W)Y<'1E9"!M97-S86=E<R!A
M9&1R97-S960@=&\@>6]U+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<VUI;64M;6%N86=E+7!U8FME>2(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+W1I=&QE/@H@("`@
M/&AE861I;F<^4R]-24U%.B!-86YA9V4@4'5B;&EC($ME>7,\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@($UA;F%G92!Y;W5R(%,O34E-12!P=6)L:6,@:V5Y
M(&QI<W0N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY6:65W/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!6:65W('1H92!R87<@=&5X="!O9B!T:&4@<'5B
M;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/D1E=&%I;',\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&5C:&YI8V%L(&1E=&%I;',@
M;V8@=&AE('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$
M96QE=&4\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T97,@=&AE('-E
M;&5C=&5D('!U8FQI8R!K97D@9G)O;2!S=&]R86=E+B`@1&5L971I;F<@82!P
M=6)L:6,@:V5Y(&9O<B!A('5S97(@=VEL;"!P<F5V96YT('EO=7(@9G)O;2!E
M;F-R>7!T:6YG(&$@;65S<V%G92!T;R!T:&%T('5S97(N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<FEN=&EN9R(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')I;G1I;F<\+W1I=&QE/@H@("`@/&AE861I;F<^4')I
M;G0@82!M97-S86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4;R!P<FEN
M="!A(&UE<W-A9V4@>6]U(&%R92!V:65W:6YG+"!C;&EC:R!O;B!T:&4@(E!R
M:6YT(B!L:6YK(&%T(&5I=&AE<B!T:&4@=&]P(&]R(&)O='1O;2!O9B!T:&4@
M;65S<V%G92X@5&AE(&UE<W-A9V4@=VEL;"!O<&5N(&EN(&$@;F5W('=I;F1O
M=R!F;W)M871E9"!F;W(@<')I;G1I;F<N("!$97!E;F1I;F<@;VX@>6]U<B!W
M96(@8G)O=W-E<B!A;F0@;W!E<F%T:6YG('-Y<W1E;2P@=&AE('!R:6YT(&1I
M86QO9R!B;W@@;6%Y(&]P96X@9F]R('EO=2X@($EF(&ET(&1O97,@;F]T(&]P
M96XL('1H96X@<'5L;"!D;W=N('1H92!W96(@8G)O=W-E<B=S(")&:6QE(B!M
M96YU(&%N9"!C:&]O<V4@(E!R:6YT(B!T;R!O<&5N('1H92!P<FEN="!D:6%L
M;V<@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V]R
M=&EN9R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4V]R=&EN9R!A;F0@5&AR
M96%D:6YG/"]T:71L93X*("`@(#QH96%D:6YG/E-O<G1I;F<@16YT<FEE<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5VAE;B!V:65W:6YG(&$@;&ES="!O
M9B!M97-S86=E<RP@>6]U(&-A;B!S;W)T('1H92!M97-S86=E<R!B>2!A;GD@
M8V]L=6UN(&)Y(&-L:6-K:6YG(&]N('1H92!A<'!R;W!R:6%T92!C;VQU;6X@
M:&5A9&EN9RX@(%1O('-W:71C:"!C;VQU;6YS(&)E='=E96X@87-C96YD:6YG
M(&%N9"!D97-C96YD:6YG(&]R9&5R+"!C;&EC:R!O;B!T:&4@87)R;W<@:6-O
M;B!I;B!T:&4@8V]L=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"B`@("`\:&5A
M9&EN9SY4:')E861I;F<\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1O(&=R
M;W5P(&UE<W-A9V5S(&)Y('1H<F5A9',@*'-U8FIE8W0I+"!S;R!E86-H(&UE
M<W-A9V4@:7,@9W)O=7!E9"!W:71H(&%L;"!I=',@<F5P;&EE<RP@8VQI8VL@
M=&AE(%M4:')E861=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L=6UN(&AE861I
M;F<N("!4;R!R971U<FX@=&\@;F]R;6%L('-U8FIE8W0@<V]R=&EN9RP@8VQI
M8VL@;VX@=&AE(%M3=6)J96-T72!L:6YK(&EN('1H92!S=6)J96-T(&-O;'5M
M;B!H96%D:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M86QT97)N871I=F4M;7-G(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-=6QT
M:7!A<G0O06QT97)N871I=F4@365S<V%G97,\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!3;VUE(&UE<W-A9V4@:&%V92!B965N('-E;G0@87,@82`B;75L=&EP
M87)T+V%L=&5R;F%T:79E(B!T>7!E(&)Y('1H92!S96YD97(N(%1H97-E(&UE
M<W-A9V5S(&AA=F4@<V5V97)A;"!P87)T<RP@86QL(&1I<W!L87EI;F<@=&AE
M(%-!344@0T].5$5.5"!B=70@:6X@1$E&1D5214Y4($9/4DU!5%,N(%1H92!M
M86EL(&%G96YT('=I;&P@9&ES<&QA>2!T:&4@;&%S="!P87)T(&EN('1H92!L
M:7-T('1H870@8V%N(&)E('-U8V-E<W-F=6QL>2!D:7-P;&%Y960@:6YL:6YE
M(&EN('1H92!B<F]W<V5R+"!I9B!A;GDN($%L;"!O=&AE<B!F;W)M871S('=I
M;&P@87!P96%R('5N9&5R('1H92!H96%D:6YG(")!;'1E<FYA=&EV92!P87)T
M<R!F;W(@=&AI<R!S96-T:6]N(B!A;F0@8V%N(&)E('9I97=E9"!O<B!D;W=N
M;&]A9&5D('-E<&%R871E;'DN($ET(&ES(&EM<&]R=&%N="!T;R!N;W1E('1H
M870@=&AE<V4@86QT97)N871I=F4@<&%R=',@8V]N=&%I;B!T:&4@4T%-12!#
M3TY414Y44R!A<R!T:&4@<&%R="!T:&%T(&ES('-H;W=N("T@=&AE>2!A<F4@
M<VEM<&QY(&EN(&$@9&EF9F5R96YT(&UE9&EA(&9O<FUA="`H92YG+B!T97AT
M('9S+B!(5$U,(&]U='!U="DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUR96YA;65?<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!2
M96YA;64@4V5N="UM86EL($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@(#QP
M87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK
M92!T;R!R96YA;64@>6]U<B!S96YT+6UA:6P@9F]L9&5R(&%T('1H92!B96=I
M;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&4@9F]L9&5R('=I;&P@8F4@<F5N
M86UE9"`H=&\@82!N86UE('1H870@8V]N=&%I;G,@=&AE(&UO;G1H(&%N9"!Y
M96%R*2!A;F0@82!N97<@<V5N="UM86EL(&9O;&1E<B!W:6QL(&)E(&-R96%T
M960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD
M96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@4V5N="UM86EL
M($9O;&1E<B!-;VYT:&QY/"]T:71L93X*("`@(#QP87)A/@H@("`@5'5R;B!T
M:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U;&0@;&EK92!T;R!D96QE=&4@;VQD
M('-E;G0M;6%I;"!F;VQD97)S(&%T('1H92!B96=I;FYI;F<@;V8@979E<GD@
M;6]N=&@N("!4:&ES(&UA>2!B92!U<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T
M82P@9F]R(&5X86UP;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUD96QE=&5?<V5N=&UA:6Q?;6]N=&AL>5]K965P(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($1E;&5T92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D@+2`C(&]F($9O;&1E
M<G,@=&\@2V5E<#PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!A<F4@
M9&5L971I;F<@;VQD('-E;G0M;6%I;"!F;VQD97)S(&5V97)Y(&UO;G1H+"!H
M;W<@;6%N>2!M;VYT:',@;V8@;VQD(&9O;&1E<G,@9&\@>6]U("!W86YT('1O
M(&ME97`_("!!;GD@9F]L9&5R<R!O;&1E<B!T:&%N('1H:7,@;6%N>2!M;VYT
M:',@=VEL;"!B92!D96QE=&5D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DB('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@1&5L971E($QI;FME9"!!='1A8VAM96YT<R!-;VYT:&QY/"]T:71L93X*
M("`@(#QP87)A/@H@("`@5'5R;B!T:&ES(&]P=&EO;B!O;B!I9B!Y;W4@=V]U
M;&0@;&EK92!T;R!D96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!T
M:&4@8F5G:6YN:6YG(&]F(&5V97)Y(&UO;G1H+B`@5&AI<R!M87D@8F4@=7-E
M9G5L(&EF('EO=2!H879E(&$@<75O=&$L(&9O<B!E>&%M<&QE+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C
M:&UE;G1S7VUO;G1H;'E?:V5E<"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C
M:&UE;G1S($UO;G1H;'D@+2`C(&]F($UO;G1H<R!T;R!+965P/"]T:71L93X*
M("`@(#QP87)A/@H@("`@268@>6]U(&%R92!D96QE=&EN9R!O;&0@;&EN:V5D
M(&%T=&%C:&UE;G1S(&5V97)Y(&UO;G1H+"!H;W<@;6%N>2!M;VYT:',@;V8@
M;VQD(&%T=&%C:&UE;G1S(&1O('EO=2`@=V%N="!T;R!K965P/R`@06YY(&%T
M=&%C:&UE;G1S(&]L9&5R('1H86X@=&AI<R!M86YY(&UO;G1H<R!W:6QL(&)E
M(&1E;&5T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUP=7)G95]T<F%S:"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G92!4<F%S:#PO=&ET;&4^"B`@
M("`\<&%R83X*("`@($1O('EO=2!W86YT('1O('!U<F=E('EO=7(@=')A<V@@
M9F]L9&5R(&5V97)Y('-O(&]F=&5N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:6YT97)V86PB('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@
M4'5R9V4@5')A<V@@26YT97)V86P\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L(&AO=R!O9G1E
M;B!S:&]U;&0@:70@8F4@<'5R9V5D/PH@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M<'5R9V5?=')A<VA?:V5E<"(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!0=7)G
M92!4<F%S:"!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R
M92!P=7)G:6YG('EO=7(@=')A<V@@9F]L9&5R+"!M97-S86=E(&]L9&5R('1H
M86X@:&]W(&UA;GD@9&%Y<R!S:&]U;&0@8F4@<'5R9V5D/PH@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB7W1E>'0B('-T
M871E/2)N97<B/@H@("`@(#QT:71L93Y0<F5F97)E;F-E<SH@365S<V%G92!#
M;VUP;W-I=&EO;CH@071T<FEB=71I;VX@5&5X=#PO=&ET;&4^"B`@("`@/'!A
M<F$^"B`@("`@2&5R92!Y;W4@8V%N(&5N=&5R('1H92!P:')A<V4@=&AA="!Y
M;W4@=VES:"!T;R!A<'!E87(@8F5F;W)E(&%N>2!Q=6]T960@=&5X="!I;B!A
M(')E<&QY('1H870@>6]U('-E;F0N"B`@("`@/"]P87)A/@H@("`@(#QP87)A
M/@H@("`@(%EO=2!C86X@:6YC;'5D92!O;F4@;W(@;6]R92!S<&5C:6%L('!L
M86-E:&]L9&5R<R!T;R!I;G-E<G0@:6YF;W)M871I;VX@86)O=70@=&AE(&UE
M<W-A9V4@=&\@=VAI8V@@>6]U(&%R92!R97!L>6EN9RX@4&QA8V5H;VQD97)S
M(&-O;G-I<W0@;V8@82`G)2<@9F]L;&]W960@8GD@82!S:6YG;&4@;&5T=&5R
M+B!4:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!A<F4@879A:6QA8FQE.@H@
M("`@(#PO<&%R83X*"B`@("`@/'!A<F$^("5F(#H@5&AE('-E;F1E<B=S(&YA
M;64@86YD(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^("5A(#H@
M5&AE('-E;F1E<B=S(&5M86EL(&%D9')E<W,\+W!A<F$^"B`@("`@/'!A<F$^
M("5P(#H@5&AE('-E;F1E<B=S(&YA;64\+W!A<F$^"B`@("`@/'!A<F$^("5R
M(#H@5&AE(&9U;&P@4D9#(#(X,C(@<W1Y;&4@9&%T92!A;F0@=&EM92!Z;VYE
M/"]P87)A/@H@("`@(#QP87)A/B`E9"`Z(%1H92!D871E(&%S('=W=RP@9&0@
M;6UM(%E965D\+W!A<F$^"B`@("`@/'!A<F$^("5X(#H@5&AE(&1A=&4@:6X@
M=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A<F$^"B`@("`@/'!A<F$^("5C(#H@
M5&AE(&1A=&4@86YD('1I;64@:6X@=&AE(&QO8V%L92=S(&1E9F%U;'0\+W!A
M<F$^"B`@("`@/'!A<F$^("5M(#H@5&AE($UE<W-A9V4M240\+W!A<F$^"B`@
M("`@/'!A<F$^("5S(#H@5&AE('-U8FIE8W0\+W!A<F$^"B`@("`@/'!A<F$^
M("5N(#H@02!N97<@;&EN93PO<&%R83X*("`@("`\<&%R83X@)24@.B!4:&4@
M)R4G(&-H87)A8W1E<CPO<&%R83X*"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7W)E860B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!297%U97-T(%)E860@4F5C96EP=',\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("`B4F5Q=65S="!A(%)E860@4F5C96EP
M="(@<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G1S(&]F('1H:7,@
M;65S<V%G92!T;R!N;W1I9GD@>6]U('=H96X@=&AI<R!M97-S86=E(&ES(&]P
M96YE9"!B>2!T:&4@<F5C:7!I96YT<RX@3F]T(&%L;"!C;&EE;G1S('-U<'!O
M<G0@+R!H;VYO<B!T:&ES+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<V5N9%]M9&XB('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!396YD($U$3CPO=&ET;&4^"B`@
M("`\<&%R83X*("`@(")396YD(&$@341.(B!S96YD<R!A($UE<W-A9V4@1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N("AA;'-O(&MN;W=N(&%S(&$@<F5A9"!R
M96-E:7!T*2!W:&5N('EO=2!V:65W(&$@;65S<V%G92!I;B!W:&EC:"!T:&4@
M=7-E<B!H87,@<F5Q=65S=&5D('1H870@=&AE>2!R96-E:79E(&YO=&EF:6-A
M=&EO;B!T:&%T('EO=2!H879E(')E860@=&AE(&UE<W-A9V4N($EN(&UO<W0@
M8V%S97,L('1H:7,@=VEL;"!H87!P96X@875T;VUA=&EC86QL>2!W:71H;W5T
M('!R;VUP=&EN9R!Y;W4N($EN(&-E<G1A:6X@:7-O;&%T960@8V%S97,L('EO
M=2!M87D@:&%V92!T;R!M86YU86QL>2!D96-I9&4@=&\@<V5N9"!T:&4@;F]T
M:69I8V%T:6]N(&)Y(&-L:6-K:6YG(&]N(&$@;&EN:RX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61I<W!O<VET:6]N7W)E<75E
M<W1?9&5L:79E<GDB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N
M8V5S.B!297%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;CPO=&ET;&4^"B`@
M("`\<&%R83X*("`@(")297%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(@
M<V5N9',@82!R97%U97-T('1O('1H92!R96-I<&EE;G0G<R!E+6UA:6P@<V5R
M=F5R('1O(&YO=&EF>2!Y;W4@=VAE;B!I="!H87,@9&5L:79E<F5D('1H92!M
M97-S86=E('1O('1H92!R96-I<&EE;G0G<R!M86EL8F]X+B!)="!D;V5S;B=T
M(&UE86X@=&AE(&UE<W-A9V4@:&%S(&)E96X@<V5E;BP@:G5S="!T:&%T(&ET
M)W,@<VET=&EN9R!I;B!A(&UA:6QB;W@@<V]M97=H97)E+B!.;W0@86QL(&UA
M:6P@<V5R=F5R<R!S=7!P;W)T('1H:7,N(`H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7W-P86U?869T97)?<F5P;W)T
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@1&5L971E
M(%-P86T@069T97(@4F5P;W)T:6YG/"]T:71L93X*("`@(#QP87)A/@H@("`@
M66]U(&UA>2!E;&5C="!T;R!D;R!O;F4@;V8@=&AR964@:71E;7,@869T97(@
M<F5P;W)T:6YG(&$@;65S<V%G92!A<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N
M="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@1FER<W0L('EO=2!C86X@
M9&5C:61E('1O(&1O(&YO=&AI;F<@+2!T:&4@;65S<V%G92!W:6QL(&)E(')E
M<&]R=&5D(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C96YT(&)U="!W:6QL(&]T
M:&5R=VES92!R96UA:6X@=6YC:&%N9V5D(&EN('EO=7(@;6%I;&)O>"X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@4V5C;VYD+"!I9B!R97!O<G1I;F<@
M82!M97-S86=E(&%S('-P86TL('EO=2!C86X@:6YS=&5A9"!H879E('1H92!M
M97-S86=E(&)E(&EM;65D:6%T96QY(&1E;&5T960N("!4:&ES('-E='1I;F<@
M:&%S(&YO(&5F9F5C="!O;B!R97!O<G1I;F<@82!M97-S86=E(&%S(&EN;F]C
M96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!4:&ER9"P@869T97(@
M<F5P;W)T:6YG(&$@;65S<V%G92!A<R!S<&%M('1H92!M97-S86=E('=I;&P@
M8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D
M('1O('EO=7(@<W!A;2!F;VQD97(N("!!;'1E<FYA=&EV96QY+"!I9B!R97!O
M<G1I;F<@82!M97-S86=E(&%S(&EN;F]C96YT('1H92!M97-S86=E('=I;&P@
M8F4@9&5L971E9"!F<F]M('1H92!C=7)R96YT(&UA:6QB;W@@86YD(&UO=F5D
M('1O('EO=7(@24Y"3U@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUH=&UL7VEM86=E7W)E<&QA8V5M96YT(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@2%1-3"!);6%G92!297!L86-E
M;65N=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($9O<B!(5$U,(&UE<W-A9V5S
M(&1I<W!L87EE9"!I;FQI;F4L('-H;W5L9"!A;&P@:6UA9V4@=&%G<R!B92!B
M;&]C:V5D('5N=&EL('EO=2!S<&5C:69I8V%L;'D@9&5C:61E('1O('9I97<@
M=&AO<V4@:6UA9V5S/R!.;W1E('1H870L(&EF('9I97=I;F<@86X@2%1-3"!A
M='1A8VAM96YT+"!T:&4@:6UA9V5S('=I;&P@86QW87ES(&)E(&1I<W!L87EE
M9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6AT
M;6Q?:6UA9V5?861D<F)O;VLB('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!(5$U,($EM86=E(%)E<&QA8V5M96YT+T%D9')E<W-B;V]K
M(%-H;W<\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!B;&]C:VEN9R!I;6%G
M97,@9F]R(&EN;&EN92!(5$U,(&UE<W-A9V5S+"!S:&]U;&0@=V4@875T;VUA
M=&EC86QL>2!D:7-P;&%Y('1H96T@:6YS=&5A9"!I9B!T:&4@<V5N9&5R(&%P
M<&5A<G,@:6X@>6]U<B!A9&1R97-S8F]O:S\*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+6UA:6QB;WA?<W1A<G0B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EL8F]X(%-T87)T(%!A
M9V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!$971E<FUI;F5S('=H:6-H('!A
M9V4@:6X@=&AE(&UA:6QB;W@@=FEE=R!W:6QL(&)E(&1I<W!L87EE9"!W:&5N
M('EO=2!A8V-E<W,@82!M86EL8F]X(&9O<B!T:&4@9FER<W0@=&EM92X@3F]T
M92!T:&%T('1H92`G=6YS965N)R!M97-S86=E(&]P=&EO;G,@9&\@;F]T('=O
M<FL@=VET:"!T:&4@)U1H<F5A9"<@<V]R=&EN9R!O<'1I;VX@+2!I;G-T96%D
M+"!Y;W4@=VEL;"!B92!S96YT('1O('1H92!L87-T('!A9V4N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUS879E7V%T=&%C:&UE
M;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@4V%V
M92!!='1A8VAM96YT<R!O;B!396YT($UE<W-A9V5S/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@<V%V:6YG(&$@8V]M<&]S960@;65S<V%G92!I;B!A('-E
M;G0M;6%I;"!F;VQD97(L(&1E=&5R;6EN92!I9B!A;&P@871T86-H;65N="!D
M871A(&ES('-A=F5D+B!4:&4@9F]L;&]W:6YG(&]P=&EO;G,@87)E(&%V86EL
M86)L93H*("`@(#PO<&%R83X*"B`@("`\<&%R83XJ(")!;'=A>7,@<V%V92!A
M='1A8VAM96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A='1A8VAM96YT
M<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S(&%R92!!3%=!
M65,@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"B`@("`@/'!A<F$^
M*B`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D
M969A=6QT('1O(%E%4R(@+2!!3%=!65,@<')O;7!T('1O('-A=F4@871T86-H
M;65N=',@:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F875L="!I<R!T
M;R!S879E(&%T=&%C:&UE;G1S+CPO<&%R83X*("`@("`\<&%R83XJ(")0<F]M
M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@
M=&\@3D\B("T@04Q705E3('!R;VUP="!T;R!S879E(&%T=&%C:&UE;G1S(&EN
M('1H92!C;VUP;W-E('-C<F5E;CL@=&AE(&1E9F%U;'0@:7,@=&\@;F]T('-A
M=F4@871T86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@(DYE=F5R('-A
M=F4@871T86-H;65N=',B("T@3D5615(@<')O;7!T('1O('-A=F4@871T86-H
M;65N=',@:6X@8V]M<&]S92!S8W)E96X[('1H92!A='1A8VAM96YT<R!A<F4@
M3D5615(@<V%V960@=VET:"!T:&4@;65S<V%G92X\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)V:7)T=6%L7VEN8F]X(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@26YB;W@\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!6:7)U=&%L($EN8F]X(&ES(&$@<V%V960@<V5A
M<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@=&\@<V5A<F-H(&5V
M97)Y(&UA:6QB;W@@9F]R(&UE<W-A9V5S(&UA<FME9"!A<R!N97<N("!);G-T
M96%D+"!A;&P@8W5R<F5N=&QY('-U8G-C<FEB960@;6%I;&)O>&5S(&%R92!S
M96%R8VAE9"!F;W(@;F5W(&UE<W-A9V5S(&%N9"!T:&4@<F5S=6QT<R!A<F4@
M9&ES<&QA>65D(&EN(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)V:7)T=6%L7W1R87-H(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y6:7)T=6%L($9O;&1E<G,Z(%9I<G1U86P@5')A<V@\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!6:7)T=6%L(%1R87-H(&ES(&$@<V%V
M960@<V5A<F-H('1H870@9&]E<R!A=V%Y('=I=&@@=&AE(&YE960@9F]R(&$@
M<V5P87)A=&4@5')A<V@@9F]L9&5R+B`@26YS=&5A9"!O9B!M;W9I;F<@;65S
M<V%G97,@=&\@82!C96YT<F%L:7IE9"!T<F%S:"!F;VQD97(L(&UE<W-A9V5S
M(&%R92!S:6UP;'D@;6%R:V5D(&%S(&1E;&5T960@:6X@=&AE(&-U<G)E;G0@
M9F]L9&5R('1H97D@;&EV92!I;BX@(%=H96X@)W-H;W<@9&5L971E9"!M97-S
M86=E<R<@:7,@='5R;F5D(&]F9BP@=&AI<R!R97-U;'1S(&EN('1H97-E(&UE
M<W-A9V5S(&YO="!A<'!E87)I;F<@:6X@82!M86EL8F]X('9I97<N("!7:&5N
M(&$@=7-E<B!C;&EC:W,@;VX@5FER='5A;"!4<F%S:"P@*F%L;"H@;6%I;&)O
M>&5S(&%L;"!S96%R8VAE9"!F;W(@;65S<V%G97,@=&AA="!A<F4@9FQA9V=E
M9"!D96QE=&5D(&%N9"!T:&5S92!M97-S86=E<R!A<F4@9&ES<&QA>65D(&EN
M(&$@<VEN9VQE(&UA:6QB;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO8V%L92]Z:%]#3B\`````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<V,P`P,3<T-3(`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C
M86QE+WIH7T-.+TQ#7TU%4U-!1T53+P``````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8S`#`R,3(S-P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]L;V-A;&4O>FA?0TXO3$-?34534T%'15,O:6UP+FUO
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R,C4R,#,`,3`T,3<S-C(W-C,`,#(R
M,S8R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````.`4``!P```#<*0``]P8``)Q3````````>&\```H```!Y;P``
M"@```(1O```*````CV\```X```":;P``"````*EO```,````LF\```H```"_
M;P``!````,IO```$````SV\``!<```#4;P``#P```.QO```+````_&\```X`
M```(<```*````!=P```*````0'```!4```!+<```$@```&%P```R````='``
M``L```"G<```#@```+-P```*````PG````T```#-<```#@```-MP```N````
MZG```#<````9<0``'````%%Q```=````;G$```\```",<0``&````)QQ```,
M````M7$```@```#"<0``+@```,MQ```:````^G$``#(````5<@``.````$AR
M``!4````@7(``%$```#6<@``6@```"AS``!7````@W,``#0```#;<P``!0``
M`!!T```&````%G0``!$````==```"````"]T```E````.'0``"````!>=```
M#P```']T```/````CW0```H```"?=````P```*IT```/````KG0``!0```"^
M=```"0```--T```-````W70``!(```#K=```#P```/YT```/````#G4```@`
M```>=0``)````"=U```(````3'4``!D```!5=0``!P```&]U```,````=W4`
M`"P```"$=0``#@```+%U```#````P'4```L```#$=0``!P```-!U```'````
MV'4```4```#@=0```P```.9U```7````ZG4```H````"=@``#P````UV``!.
M````'78``%````!L=@``0@```+UV```8`````'<```X````9=P``%````"AW
M```7````/7<``!<```!5=P``$P```&UW```.````@7<``!\```"0=P``!P``
M`+!W```&````N'<```@```"_=P``#P```,AW```(````V'<``!$```#A=P``
M"@```/-W```3````_G<```L````2>```%0```!YX```5````-'@```<```!*
M>```!0```%)X```5````6'@``!$```!N>```#````(!X```P````C7@``$@`
M``"^>```(0````=Y```[````*7D``#L```!E>0``*P```*%Y```)````S7D`
M``<```#7>0``%````-]Y```,````]'D```4````!>@``"0````=Z```0````
M$7H``!,````B>@``.0```#9Z```&````<'H``#4```!W>@``"@```*UZ```+
M````N'H``"<```#$>@``+````.QZ```J````&7L``"4```!$>P``"@```&I[
M```&````=7L```D```!\>P``!P```(9[```O````CGL``#<```"^>P``+@``
M`/9[``!5````)7P``"T```![?```+0```*E\```M````UWP``$`````%?0``
M(P```$9]```C````:GT``"T```".?0``,P```+Q]```5````\'T``!D````&
M?@``*0```"!^```D````2GX``!$```!O?@``"@```(%^```*````C'X``!``
M``"7?@``%@```*A^```6````OWX```<```#6?@``!P```-Y^```4````YGX`
M``H```#[?@``"`````9_```#````#W\```<````3?P``!P```!M_```&````
M(W\```4````J?P``!P```#!_```&````.'\```@````_?P``"0```$A_```.
M````4G\```H```!A?P``!````&Q_```$````<7\```<```!V?P``"0```'Y_
M```6````B'\```0```"??P``"````*1_```-````K7\```8```"[?P``'@``
M`,)_```1````X7\```@```#S?P``#0```/Q_```,````"H````<````7@```
M`P```!^````#````(X```!<````G@```!````#^````(````1(````@```!-
M@```(````%:````&````=X````8```!^@```#@```(6````5````E(```!@`
M``"J@```'0```,.```!4````X8```"D````V@0``"@```&"!```.````:X$`
M``(```!Z@0``"@```'V!```4````B($``!@```"=@0``'0```+:!```3````
MU($``!0```#H@0``!````/V!```&`````H(```H````)@@``7P```!2"```<
M````=((```4```"1@@``!0```)>"```;````G8(``!H```"Y@@``#@```-2"
M```1````XX(``!$```#U@@``'`````>#```0````)(,``"$````U@P``$0``
M`%>#```,````:8,```8```!V@P``%P```'V#```,````E8,``!0```"B@P``
M#P```+>#```(````QX,```4```#0@P``#````-:#```&````XX,```<```#J
M@P``#0```/*#```'`````(0```L````(A```!P```!2$```'````'(0```H`
M```DA```#````"^$```0````/(0```4```!-A```)0```%.$```3````>80`
M`#L```"-A```(````,F$```,````ZH0```0```#WA```#@```/R$```'````
M"X4```X````3A0``"@```"*%```-````+84``!X````[A0``&P```%J%```A
M````=H4``!X```"8A0``'@```+>%```;````UH4``!X```#RA0``,P```!&&
M```O````188``!(```!UA@``*0```(B&```2````LH8``!8```#%A@``*```
M`-R&```@````!8<``"$````FAP``00```$B'```'````BH<```8```"2AP``
M#0```)F'```+````IX<``!H```"SAP``'0```,Z'```9````[(<``%T````&
MB```$@```&2(```3````=X@``!(```"+B```!P```)Z(```$````IH@```P`
M``"KB```#P```+B(```3````R(@```T```#<B```#0```.J(```&````^(@`
M`!$```#_B```%P```!&)```;````*8D```X```!%B0```@```%2)```%````
M5XD```0```!=B0``#0```&*)```.````<(D```,```!_B0``"````(.)```/
M````C(D``!````"<B0``&0```*V)```:````QXD```8```#BB0``%````.F)
M```3````_HD``!`````2B@``#````".*```1````,(H``!D```!"B@``!P``
M`%R*```0````9(H``!P```!UB@``#0```)**```'````H(H```H```"HB@``
M%````+.*```'````R(H``"(```#0B@``+P```/.*```+````(XL```D````O
MBP``&0```#F+```+````4XL``!<```!?BP``%P```'>+```)````CXL```<`
M``"9BP``%@```*&+```/````N(L```X```#(BP``"````->+```C````X(L`
M``T````$C```)@```!*,```@````.8P``$,```!:C```"````)Z,```2````
MIXP```0```"ZC```"````+^,```+````R(P``!(```#4C```+P```.>,```%
M````%XT```X````=C0``#@```"R-```&````.XT```X```!"C0```P```%&-
M```'````58T```0```!=C0``"@```&*-```*````;8T```\```!XC0``$```
M`(B-```7````F8T``!$```"QC0``%P```,.-```6````VXT```4```#RC0``
M"P```/B-```%````!(X```T````*C@``&P```!B.```7````-(X```D```!,
MC@``#P```%:.```2````9HX```X```!YC@``#0```(B.```(````EHX```X`
M``"?C@``*0```*Z.```L````V(X``"@````%CP``$0```"Z/```'````0(\`
M``4```!(CP``!P```$Z/```(````5H\```8```!?CP``$````&:/```0````
M=X\```\```"(CP``"P```)B/```/````I(\```P```"TCP``#P```,&/```'
M````T8\```H```#9CP``$@```.2/```-````]X\```\````%D```"````!60
M```3````'I```!X````RD```(0```%&0```@````<Y```!D```"4D```%P``
M`*Z0```E````QI```!<```#LD```&P````21```-````()$```,````ND0``
M"````#*1```*````.Y$```P```!&D0``!````%.1```3````6)$``!0```!L
MD0``#````(&1```)````CI$```L```"8D0``&P```*21```'````P)$```0`
M``#(D0``!P```,V1```*````U9$```H```#@D0``#0```.N1```)````^9$`
M``0````#D@``&`````B2```0````(9(```H````RD@``?````#V2```%````
MNI(```<```#`D@``#````,B2```(````U9(```8```#>D@``!P```.62```(
M````[9(``!$```#VD@``&0````B3```(````(I,```(````KDP``!@```"Z3
M```-````-9,``!````!#DP``!````%23```,````69,```D```!FDP``$```
M`'"3```)````@9,```D```"+DP``!0```)63```&````FY,``!D```"BDP``
M!P```+R3```'````Q),```4```#,DP``"0```-*3```*````W),```T```#G
MDP``"0```/63```&````_Y,``!(````&E```"0```!F4```'````(Y0``!0`
M```KE```'0```$"4```&````7I0```H```!EE```!````'"4```)````=90`
M``@```!_E```$0```(B4```)````FI0```8```"DE```#0```*N4```&````
MN90``!X```#`E```!0```-^4```.````Y90```8```#TE```!P```/N4```A
M`````Y4``!4````EE0``!````#N5```1````0)4```8```!2E0``(@```%F5
M```,````?)4``!$```")E0``'0```)N5```$````N94```P```"^E0``"@``
M`,N5```(````UI4```D```#?E0``!0```.F5```/````[Y4``"<```#_E0``
M)````">6```(````3)8```H```!5E@``!P```&"6```@````:)8``"````")
ME@``)@```*J6```%````T98``!D```#7E@``*0```/&6```'````&Y<```H`
M```CEP``#P```"Z7```&````/I<```H```!%EP``#````%"7```&````79<`
M``H```!DEP``#@```&^7```.````?I<``!\```"-EP``'@```*V7```1````
MS)<``!4```#>EP``#P```/27```)````!)@``!(````.F```$@```"&8```0
M````-)@``"0```!%F```'````&J8```/````AY@```4```"7F```$````)V8
M```)````KI@```L```"XF```'````,28```C````X9@``"(````%F0``#```
M`"B9```/````-9D``!D```!%F0``#P```%^9```3````;YD``!(```"#F0``
M!P```):9```,````GID``!8```"KF0``(````,*9```4````XYD``!$```#X
MF0``%P````J:```<````(IH``!,````_F@``$0```%.:```:````99H``!X`
M``"`F@``&@```)^:```A````NIH``"````#<F@``$0```/V:```7````#YL`
M`!4````GFP``&0```#V;```$````5YL```<```!<FP``"P```&2;```&````
M<)L```8```!WFP``!@```'Z;```%````A9L```<```"+FP``!P```).;```%
M````FYL``!8```"AFP``!@```+B;```&````OYL```0```#&FP``!````,N;
M```.````T)L```P```#?FP``#````.R;```-````^9L```H````'G```#@``
M`!*<```%````(9P``"@````GG```#````%"<```/````79P```H```!MG```
M"````'B<```)````@9P``"L```"+G```"````+><```F````P)P``!(```#G
MG```#P```/J<```&````"IT```H````1G0``"````!R=```@````)9T```D`
M``!&G0``"0```%"=```,````6IT```T```!GG0``#@```'6=```6````A)T`
M`!$```";G0``!@```*V=```&````M)T```<```"[G0``!P```,.=```'````
MRYT``!8```#3G0``#0```.J=```$````^)T```4```#]G0``'@````.>```0
M````(IX```P````SG@``"0```$">```'````2IX```H```!2G@``"0```%V>
M```.````9YX``!````!VG@``&@```(>>```*````HIX```D```"MG@``#@``
M`+>>```,````QIX```\```#3G@``!@```..>```,````ZIX```<```#WG@``
M"P```/^>``!'````"Y\```T```!3GP``"@```&&?```"````;)\```0```!O
MGP``)0```'2?```#````FI\```4```">GP``*@```*2?```*````SY\```H`
M``#:GP``!P```.6?```&````[9\```@```#TGP``"````/V?```$````!J``
M``4````+H```!0```!&@```(````%Z```!L````@H```+P```#R@```0````
M;*````H```!]H```#P```(B@```*````F*````D```"CH```&P```*V@```8
M````R:```!<```#BH```#@```/J@```#````":$```<````-H0``!P```!6A
M```*````':$``!,````HH0``#````#RA```.````2:$```P```!8H0``#@``
M`&6A``!1````=*$``!````#&H0``#0```->A```/````Y:$```P```#UH0``
M)@````*B```+````*:(``!H````UH@``2@```%"B```&````FZ(```8```"B
MH@``!@```*FB```?````L*(```D```#0H@``&````-JB```7````\Z(```8`
M```+HP``5P```!*C```3````:J,``!,```!^HP```@```)*C```+````E:,`
M``T```"AHP``!@```*^C```'````MJ,``!0```"^HP``!@```-.C```(````
MVJ,```X```#CHP``!P```/*C```*````^J,```L````%I```!P```!&D```$
M````&:0```D````>I```"0```"BD```*````,J0```<````]I```"@```$6D
M```2````4*0```H```!CI```"0```&ZD```0````>*0```<```")I```$@``
M`)&D```$````I*0```<```"II```!0```+&D```%````MZ0```L```"]I```
M%````,FD```1````WJ0``!@```#PI```'`````FE```9````)J4```<```!`
MI0``!0```$BE```#````3J4```T```!2I0``"````&"E```(````::4``!<`
M``!RI0``"P```(JE```,````EJ4``!,```"CI0``!````+>E```$````O*4`
M``P```#!I0``"0```,ZE```,````V*4```D```#EI0``!0```.^E```'````
M]:4```4```#]I0``!`````.F```"````"*8``!L````+I@``*0```">F```R
M````4:8``"X```"$I@``,P```+.F```S````YZ8``#@````;IP``$````%2G
M```9````9:<``!,```!_IP``+0```).G```M````P:<``#$```#OIP``+@``
M`"&H```O````4*@``"P```"`J```$P```*VH```2````P:@``"L```#4J```
M&@````"I```)````&ZD``$4````EJ0``00```&NI```4````K:D```X```#"
MJ0``$P```-&I```8````Y:D```8```#^J0``"0````6J```*````#ZH```L`
M```:J@``"0```":J```-````,*H```P````^J@``#P```$NJ```6````6ZH`
M``X```!RJ@``!0```(&J```(````AZH```8```"0J@``%````)>J```1````
MK*H```X```"^J@```@```,VJ```.````T*H```4```#?J@``!P```.6J```&
M````[:H```P```#TJ@``!`````&K```I````!JL``!\````PJP``7````%"K
M```4````K:L```<```#"JP``#@```,JK```,````V:L```P```#FJP``$P``
M`/.K```=````!ZP``!D````EK```!0```#^L```1````1:P```T```!7K```
M$0```&6L```D````=ZP``!4```"<K```$@```+*L```.````Q:P``!D```#4
MK```"````.ZL```)````]ZP```T````!K0``"`````^M```%````&*T``!\`
M```>K0``!@```#ZM```0````1:T```@```!6K0``!P```%^M```(````9ZT`
M`"P```!PK0``&@```)VM```)````N*T```H```#"K0``%0```,VM```%````
MXZT``!0```#IK0``!````/ZM```0`````ZX``!X````4K@``"@```#.N```1
M````/JX```L```!0K@``&@```%RN```(````=ZX``!0```"`K@``+````)6N
M```G````PJX```0```#JK@``"P```.^N```%````^ZX```8````!KP``"```
M``BO```@````$:\``$$````RKP``&@```'2O```H````CZ\``!H```"XKP``
M*````-.O```I````_*\``#8````FL```+````%VP```Q````BK````8```"\
ML```!0```,.P```(````R;```"H```#2L```(P```/VP```A````(;$``"X`
M``!#L0``-````'*Q```(````I[$``!<```"PL0``"@```,BQ```0````T[$`
M``T```#DL0``$````/*Q```%`````[(```L````)L@``$P```!6R```(````
M*;(```L````RL@``"0```#ZR```*````2+(``!0```!3L@``,@```&BR```+
M````F[(```4```"GL@``%P```*VR```/````Q;(```4```#5L@``!````-NR
M```-````X+(``#(```#NL@``"````"&S```0````*K,``!4````[LP``$P``
M`%&S```7````9;,```<```!]LP``%````(6S```%````FK,```<```"@LP``
M#P```*BS```.````N+,``"H```#'LP``!@```/*S```,````^;,```L````&
MM```-@```!*T```+````2;0```\```!5M```#0```&6T```%````<[0```P`
M``!YM```#0```(:T```-````E+0```H```"BM```!@```*VT```R````M+0`
M``4```#GM```!P```.VT```&````];0``$L```#\M```!P```$BU```'````
M4+4```H```!8M0``"P```&.U```,````;[4```,```!\M0``$@```("U```&
M````D[4``!X```":M0``&````+FU```E````TK4```T```#XM0``"0````:V
M```#````$+8```<````4M@```@```!RV```,````'[8``!4````LM@``"P``
M`$*V```9````3K8``"````!HM@``$@```(FV```%````G+8```H```"BM@``
M%0```*VV```2````P[8```P```#6M@``!P```..V```*````Z[8```P```#V
MM@``!P````.W``!2````"[<``!<```!>MP``.0```':W```&````L+<```X`
M``"WMP``!````,:W```&````R[<``!4```#2MP``$@```.BW```/````^[<`
M`!0````+N```"@```""X```;````*[@``!$```!'N```"P```%FX``!I````
M9;@``!H```#/N```%P```.JX```:`````KD``!<````=N0``&P```#6Y```9
M````4;D``!\```!KN0``#````(NY```3````F+D```<```"LN0``"````+2Y
M```)````O;D``!4```#'N0``#0```-VY```&````Z[D```<```#RN0``$P``
M`/JY```#````#KH``#\````2N@``-P```%*Z``!7````BKH``"\```#BN@``
M"@```!*[```(````';L```T````FNP``+0```#2[```$````8KL``!````!G
MNP``#````'B[```=````A;L``!$```"CNP``)0```+6[```+````V[L``!T`
M``#GNP``!@````6\```,````#+P```<````9O```"0```"&\```3````*[P`
M``D````_O```!````$F\```0````3KP```@```!?O```"````&B\```,````
M<;P```\```!^O```!P```(Z\```4````EKP```X```"KO```#````+J\```;
M````Q[P``"P```#CO```$P```!"]```%````)+T```0````JO0``%P```"^]
M```2````1[T```L```!:O0``%````&:]```)````>[T```@```"%O0``"@``
M`(Z]```1````F;T```8```"KO0``#@```+*]```.````P;T```T```#0O0``
M"P```-Z]```"````ZKT```<```#MO0``#0```/6]```&`````[X```D````*
MO@``!P```!2^```5````'+X```4````RO@``"````#B^```'````0;X```<`
M``!)O@``#@```%&^```)````8+X```8```!JO@``"````'&^```+````>KX`
M``<```"&O@``"````(Z^```'````E[X``!8```"?O@``"0```+:^```&````
MP+X```L```#'O@``%````-.^```(````Z+X```8```#QO@``&0```/B^```*
M````$K\``!P````=OP``!P```#J_```%````0K\``!````!(OP``%````%F_
M```+````;K\```T```!ZOP``%P```(B_```$````H+\```D```"EOP```@``
M`*^_```.````LK\```@```#!OP``'P```,J_```C````ZK\``#$````.P```
M)P```$#````B````:,```"````"+P```,P```*S```!*````X,```#@````K
MP0``*````&3!```L````C<$``!L```"ZP0``'@```-;!```I````]<$``"D`
M```?P@``,0```$G"```^````>\(``$@```"ZP@``00````/#``!;````1<,`
M`$D```"APP``(0```.O#```?````#<0``"L````MQ```(0```%G$```S````
M>\0``"4```"OQ```)P```-7$```F````_<0``#`````DQ0``:0```%7%```]
M````O\4``&4```#]Q0``30```&/&```N````L<8``%0```#@Q@``,@```#7'
M```O````:,<``"P```"8QP``+0```,7'```7````\\<``"4````+R```,@``
M`#'(```I````9,@``#X```".R```(@```,W(``!2````\,@``"4```!#R0``
M"P```&G)```/````=<D``"$```"%R0``,````*?)```E````V,D``!P```#^
MR0``,0```!O*```$````3<H```T```!2R@``"P```&#*```.````;,H```L`
M``![R@``!0```(?*```"````C<H``%D```"0R@``!0```.K*```2````\,H`
M``0````#RP``!P````C+```(````$,L```4````9RP``#0```!_+```3````
M+<L```T```!!RP```@```$_+```'````4LL```8```!:RP``%````&'+```,
M````=LL``!@```"#RP``!@```)S+```2````H\L```P```"VRP```P```,/+
M```$````Q\L```8```#,RP``!P```-/+```?````V\L``#4```#[RP``+@``
M`#',```O````8,P``!<```"0S```(````*C,```;````R<P``!@```#ES```
M)````/[,```?````(\T``!H```!#S0``&@```%[-```O````><T``"L```"I
MS0``'P```-7-```C````]<T``!\````9S@``&@```#G.```E````5,X``"8`
M``!ZS@``)0```*'.```D````Q\X``!@```#LS@``'0````7/```D````(\\`
M`!@```!(SP``(@```&'/```E````A,\``!\```"JSP``(P```,K/```?````
M[L\``"`````.T```&@```"_0```F````2M```!X```!QT```'@```)#0```*
M````K]```!,```"ZT```"````,[0```)````U]````P```#AT```%P```.[0
M```O````!M$``"0````VT0``#P```%O1```4````:]$```X```"`T0``#0``
M`(_1```D````G=$```4```#"T0``!P```,C1```=````T-$```8```#NT0``
M%0```/71```&````"](```D````2T@``"P```!S2```7````*-(``#,```!`
MT@``!P```'32```A````?-(``!,```">T@``#````++2```1````O](``#(`
M``#1T@``"`````33```*````#=,``!0````8TP``"@```"W3```=````.-,`
M``@```!6TP``'P```%_3```(````?],``!H```"(TP``!@```*/3```'````
MJM,```@```"RTP``"0```+O3```_````Q=,```<````%U```#P````W4```(
M````'=0``!,````FU```&0```#K4```*````5-0``!<```!?U```%````'?4
M```*````C-0```P```"7U```%P```*34```$````O-0``"H```#!U```$0``
M`.S4```"````_M0``!`````!U0```P```!+5```(````%M4```8````?U0``
M!P```";5```-````+M4```L````\U0``%````$C5```5````7=4```X```!S
MU0``+P```(+5```@````LM4``!P```#3U0``$P```/#5```%````!-8```8`
M```*U@``#````!'6```*````'M8``!$````IU@```@```#O6```$````/M8`
M``H```!#U@``!@```$[6```%````5=8```P```!;U@``10```&C6```H````
MKM8``%,```#7U@``&0```"O7```7````1=<``!D```!=UP``(````'?7```U
M````F-<``$4```#.UP``,````!38```H````1=@``"8```!NV```)0```)78
M```H````N]@``"@```#DV```,`````W9```2````/MD``!````!1V0``>0``
M`&+9```)````W-D``!````#FV0``#P```/?9```.````!]H``',````6V@``
M?````(K:```K````!]L``!<````SVP``'P```$O;```4````:]L```\```"`
MVP``"@```)#;```%````F]L```8```"AVP``"````*C;```,````L=L``!``
M``"^VP``#P```,_;```$````W]L```0```#DVP``&0```.G;```"`````]P`
M``D````&W```#P```!#<```3````(-P```(````TW```#@```#?<```/````
M1MP``"(```!6W```!P```'G<```+````@=P```4```"-W````@```)/<```+
M````EMP``$H!``"BW```"P```.W=```*````^=T```H````$W@``"@````_>
M```'````&MX```<````BW@``"@```"K>```"````-=X```,````XW@``%```
M`#S>```2````4=X```L```!DW@``!P```'#>```2````>-X```<```"+W@``
M"P```)/>```)````G]X``"D```"IW@``"P```-/>```)````W]X```4```#I
MW@``"@```._>```/````^MX``!L````*WP``&@```";?```4````0=\```X`
M``!6WP``#````&7?```2````<M\```H```"%WP``"0```)#?```=````FM\`
M`!0```"XWP``)0```,W?```M````\]\``#P````AX```0````%[@``!`````
MG^```$8```#@X```)P```"?A```%````3^$```@```!5X0``#@```%[A```'
M````;>$``!L```!UX0``&P```)'A```+````K>$```8```"YX0``!````,#A
M```$````Q>$```H```#*X0``#````-7A```*````XN$```H```#MX0``"```
M`/CA```-`````>(```T````/X@``!@```!WB```?````).(```@```!$X@``
M&0```$WB```$````9^(```8```!LX@``'P```'/B```$````D^(```@```"8
MX@``!@```*'B```*````J.(```H```"SX@``!````+[B```$````P^(``!``
M``#(X@``"@```-GB```(````Y.(``#````#MX@``-````![C```@````4^,`
M`!0```!TXP``!@```(GC```.````D.,```X```"?XP``#@```*[C```(````
MO>,```H```#&XP``%0```-'C```&````Y^,```8```#NXP``!@```/7C```(
M````_.,```8````%Y```"@````SD```&````%^0``!`````>Y```"````"_D
M```.````..0``!(```!'Y```!````%KD```$````7^0``!<```!DY```#```
M`'SD```,````B>0``!P```"6Y```)@```+/D```2````VN0``!H```#MY```
M(`````CE```@````*>4```8```!*Y0``"````%'E```6````6N4```@```!Q
MY0``!@```'KE```$````@>4```H```"&Y0``#P```)'E```=````H>4```0`
M``"_Y0``)0```,3E```$````ZN4```0```#OY0``&P```/3E```9````$.8`
M`!L````JY@``&0```$;F```$````8.8```0```!EY@``"````&KF```&````
M<^8``"H```!ZY@``(P```*7F```I````R>8``&L```#SY@``*````%_G```H
M````B.<``"@```"QYP``)P```-KG```:`````N@``!H````=Z```*````#CH
M```N````8>@```D```"0Z```#````)KH```0````I^@```T```"XZ```"P``
M`,;H```(````TN@```D```#;Z```"````.7H```2````[N@``!0````!Z0``
M"@```!;I```$````(>D``!@````FZ0``"````#_I```(````2.D```0```!1
MZ0``"````%;I```&````7^D```8```!FZ0``!````&WI```*````<ND```0`
M``!]Z0``!````(+I```*````A^D```@```"2Z0``"````)OI```&````I.D`
M``0```"KZ0``"````+#I```$````N>D``!0```"^Z0``!````-/I```(````
MV.D```@```#AZ0``!````.KI```.````[^D```0```#^Z0``"`````/J```(
M````#.H```H````5Z@``!@```"#J```,````)^H```,````TZ@``"@```#CJ
M```&````0^H```8```!*Z@``!@```%'J```:````6.H```8```!SZ@``!```
M`'KJ```(````?^H```P```"(Z@``$@```)7J```2````J.H``#$```"[Z@``
M&0```.WJ```&````!^L```@````.ZP``!````!?K```(````'.L``!8````E
MZP``"@```#SK```1````1^L```@```!9ZP``"````&+K```$````:^L```0`
M``!PZP``"````'7K```<````?NL```H```";ZP``!````*;K```$````J^L`
M`!$```"PZP``#P```,+K```*````TNL```@```#=ZP``#@```.;K```-````
M]>L```8````#[```%0````KL```,````(.P```@````M[```!````#;L```*
M````.^P```@```!&[```#@```$_L```*````7NP```@```!I[```!````'+L
M```&````=^P```0```!^[```!````(/L```(````B.P```0```"1[```!@``
M`);L```&````G>P```0```"D[```!````*GL```'````KNP```@```"V[```
M!````+_L```*````Q.P```H```#/[```*P```-KL```:````!NT```@````A
M[0``!````"KM```(````+^T```0````X[0``#````#WM```*````2NT```@`
M``!5[0``%````%[M```8````<^T``!<```",[0``%P```*3M```4````O.T`
M`!(```#1[0``%0```.3M```=````^NT``!T````8[@``#````#;N```7````
M0^X```P```!;[@``%P```&CN```8````@.X``!,```"9[@``%@```*WN```P
M````Q.X```0```#U[@``!````/KN```*````_^X```@````*[P``$@```!/O
M```2````)N\``!(````Y[P``/````$SO```,````B>\```P```"6[P``"@``
M`*/O```(````KN\```0```"W[P``"````+SO```(````Q>\```H```#.[P``
M"````-GO```(````XN\```@```#K[P``$0```/3O```7````!O```!H````>
M\```"@```#GP```"````1/````0```!'\```!````$SP```(````4?````@`
M``!:\```!````&/P```&````:/````@```!O\```#````'CP```-````A?``
M``X```"3\```!````*+P```.````I_````P```"V\```"@```,/P```*````
MSO````@```#9\```#@```.+P```&````\?````H```#X\```#@````/Q```(
M````$O$```0````;\0``!````"#Q```(````)?$```0````N\0``'0```#/Q
M```7````4?$```0```!I\0``"````&[Q```6````=_$```H```".\0``"```
M`)GQ```(````HO$```0```"K\0``!````+#Q```1````M?$```@```#'\0``
M"````-#Q```&````V?$```P```#@\0``!@```.WQ```<````]/$``!0````1
M\@``*0```";R```(````4/(```X```!9\@``!````&CR```$````;?(```<`
M``!R\@``"@```'KR```>````A?(```0```"D\@``"````*GR```(````LO(`
M``@```"[\@``"@```,3R```$````S_(```@```#4\@``!````-WR```(````
MXO(```H```#K\@``"````/;R```(````__(```X````(\P``"````!?S```.
M````(/,``!`````O\P``!````$#S```(````1?,```@```!.\P``"0```%?S
M```5````8?,```P```!W\P``"````(3S```*````C?,```H```"8\P``"0``
M`*/S```)````K?,```0```"W\P``"@```+SS```6````Q_,``!8```#>\P``
M%@```/7S```*````#/0```H````7]```!````"+T```(````)_0```H````P
M]```!````#OT```*````0/0```H```!+]```"0```%;T```(````8/0```H`
M``!I]```!@```'3T```'````>_0```0```"#]```"````(CT```.````D?0`
M``H```"@]```!@```*OT```&````LO0```T```"Y]```$````,?T```5````
MV/0``!0```#N]```$`````/U```0````%/4``!L````E]0``$````$'U```=
M````4O4```@```!P]0``!````'GU```$````?O4```@```"#]0``"@```(SU
M```$````E_4``!,```"<]0``$0```+#U```*````PO4```@```#-]0``"```
M`-;U```5````W_4```8```#U]0``!````/SU```$`````?8```8````&]@``
M!@````WV```&````%/8```@````;]@``!````"3V```.````*?8```@````X
M]@``"````$'V``!.````2O8```0```"9]@``!````)[V```(````H_8```0`
M``"L]@``!````+'V```$````MO8```8```"[]@``#@```,+V```.````T?8`
M``@```#@]@``!@```.GV```$````\/8```H```#U]@``#@````#W```&````
M#_<```H````6]P```@```"'W```(````)/<```0````M]P``!````#+W```$
M````-_<```8````\]P``$@```$/W```(````5O<```0```!?]P``!````&3W
M```(````:?<```(```!R]P``"P```'7W```$````@?<```0```"&]P``$P``
M`(OW```&````G_<```@```"F]P``"@```*_W```2````NO<```8```#-]P``
M"@```-3W```$````W_<```@```#D]P``"````.WW```(````]O<```@```#_
M]P``!@````CX```0````#_@```8````@^```$0```"?X```$````.?@```D`
M```^^```!````$CX```&````3?@``!````!4^```%P```&7X```$````??@`
M``X```""^```!````)'X```1````EO@```P```"H^```#````+7X```&````
MPO@```0```#)^```"````,[X```(````U_@```@```#@^```"````.GX```%
M````\O@```8```#X^```$P```/_X```-````$_D```0````A^0``!@```";Y
M```&````+?D``!4````T^0``%0```$KY```=````8/D```8```!^^0``$```
M`(7Y```@````EOD```0```"W^0``"````+SY```*````Q?D```0```#0^0``
M"````-7Y```(````WOD```0```#G^0``"````.SY```*````]?D```L`````
M^@``$P````SZ```1````(/H```P````R^@``#P```#_Z```-````3_H```0`
M``!=^@``"````&+Z```,````:_H```D```!X^@``%@```(+Z```3````F?H`
M``@```"M^@``!````+;Z```(````N_H```H```#$^@``!````,_Z```4````
MU/H``!(```#I^@``%@```/SZ```(````$_L```P````<^P``#@```"G[```(
M````./L```T```!!^P``$0```$_[```$````8?L```8```!F^P``#@```&W[
M```9````?/L```\```"6^P``#P```*;[```/````MOL```X```#&^P``$```
M`-7[```0````YOL``!8```#W^P``$P````[\```/````(OP``!4````R_```
M%0```$C\```/````7OP```\```!N_```$0```'[\```0````D/P```8```"A
M_```!@```*C\```$````K_P```8```"T_```!@```+O\```$````POP```8`
M``#'_```!@```,[\```$````U?P```P```#:_```$@```.?\```&````^OP`
M``0````!_0``!`````;]```$````"_T```0````0_0``"````!7]```(````
M'OT```@````G_0``"@```##]```*````._T```8```!&_0``$@```$W]```(
M````8/T```@```!I_0``"````'+]```(````>_T```@```"$_0``*````(W]
M```.````MOT```0```#%_0``!````,K]```-````S_T```8```#=_0``"@``
M`.3]```$````[_T```0```#T_0``!@```/G]```(`````/X```8````)_@``
M"0```!#^```.````&OX``!0````I_@``%@```#[^```(````5?X```@```!>
M_@``!@```&?^```&````;OX```@```!U_@``!@```'[^```*````A?X```0`
M``"0_@``!````)7^```=````FOX```P```"X_@``$0```,7^```/````U_X`
M`!,```#G_@``$0```/O^```1````#?\```\````?_P``$P```"__```4````
M0_\```0```!8_P``!@```%W_```(````9/\```H```!M_P``"@```'C_```$
M````@_\```@```"(_P``!````)'_```(````EO\``"L```"?_P``"0```,O_
M```&````U?\```(```#<_P``"````-__```;````Z/\```,````$``$`"```
M``@``0`,````$0`!``P````>``$`"````"L``0`$````-``!``8````Y``$`
M"````$```0`(````20`!``0```!2``$`!@```%<``0`$````7@`!``@```!C
M``$`$@```&P``0`D````?P`!``H```"D``$`"@```*\``0`,````N@`!``H`
M``#'``$`"````-(``0`7````VP`!`!@```#S``$`%P````P!`0`,````)`$!
M``0````Q`0$`"@```#8!`0`$````00$!``D```!&`0$`!@```%`!`0`(````
M5P$!``@```!@`0$`"````&D!`0`(````<@$!`"P```![`0$`"P```*@!`0`(
M````M`$!``8```"]`0$`"````,0!`0`1````S0$!``8```#?`0$`$P```.8!
M`0`K````^@$!``0````F`@$`!````"L"`0`&````,`(!`!(````W`@$`"0``
M`$H"`0`8````5`(!`!<```!M`@$`!````(4"`0`W````B@(!`!````#"`@$`
M$````-,"`0`&````Y`(!``@```#K`@$`"````/0"`0`$````_0(!``0````"
M`P$`"`````<#`0`&````$`,!``0````7`P$`!@```!P#`0`$````(P,!``H`
M```H`P$`"````#,#`0`&````/`,!``0```!#`P$`!````$@#`0`$````30,!
M``0```!2`P$`!````%<#`0`(````7`,!``0```!E`P$`"````&H#`0`(````
M<P,!`!````!\`P$`!````(T#`0`+````D@,!``0```">`P$`"````*,#`0`$
M````K`,!``8```"Q`P$`!````+@#`0`,````O0,!`!,```#*`P$`%P```-X#
M`0`3````]@,!`!$````*!`$`!````!P$`0`(````(00!``(````J!`$`#```
M`"T$`0`&````.@0!``0```!!!`$`$0```$8$`0`&````6`0!``8```!?!`$`
M#P```&8$`0`$````=@0!``(```![!`$`!@```'X$`0`&````A00!``H```",
M!`$`"````)<$`0`&````H`0!``@```"G!`$`!````+`$`0`&````M00!``(`
M``"\!`$`$P```+\$`0`:````TP0!`!\```#N!`$`%P````X%`0`<````)@4!
M`!L```!#!0$`(````%\%`0`*````@`4!``X```"+!0$`$````)H%`0`;````
MJP4!`!L```#'!0$`'P```.,%`0`<`````P8!`!T````@!@$`&@```#X&`0`3
M````608!``P```!M!@$`$P```'H&`0`9````C@8!``8```"H!@$`+P```*\&
M`0`Q````WP8!`!8````1!P$`"````"@'`0`&````,0<!``X````X!P$`!```
M`$<'`0`&````3`<!``8```!3!P$`"@```%H'`0`(````90<!``@```!N!P$`
M"@```'<'`0`,````@@<!``P```"/!P$`"````)P'`0`&````I0<!``8```"L
M!P$`!````+,'`0`&````N`<!``@```"_!P$`!````,@'`0`$````S0<!``H`
M``#2!P$`!@```-T'`0`$````Y`<!``8```#I!P$`!@```/`'`0`$````]P<!
M`",```#\!P$`$P```"`(`0`F````-`@!``X```!;"`$`!````&H(`0`)````
M;P@!``@```!Y"`$`!````(((`0`(````AP@!`!````"0"`$`%````*$(`0`$
M````M@@!``@```"["`$`"````,0(`0`*````S0@!``T```#8"`$`#````.8(
M`0`,````\P@!``P`````"0$`%@````T)`0`,````)`D!``@````Q"0$`$```
M`#H)`0`(````2PD!``0```!4"0$`$````%D)`0`&````:@D!``X```!Q"0$`
M!@```(`)`0`$````APD!``0```","0$`'0```)$)`0`(````KPD!``4```"X
M"0$`!@```+X)`0`-````Q0D!``0```#3"0$`!````-@)`0`$````W0D!``H`
M``#B"0$`#````.T)`0`$````^@D!``@```#_"0$`!`````@*`0`(````#0H!
M``8````6"@$`"````!T*`0`7````)@H!`!D````^"@$`!````%@*`0`&````
M70H!``0```!D"@$`!````&D*`0`(````;@H!`!4```!W"@$`)@```(T*`0`1
M````M`H!`!@```#&"@$`$````-\*`0`1````\`H!`!8````""P$`&````!D+
M`0`>````,@L!`!X```!1"P$`!````'`+`0`$````=0L!``8```!Z"P$`*P``
M`($+`0`6````K0L!`!8```#$"P$`*0```-L+`0`O````!0P!``0````U#`$`
M#````#H,`0`&````1PP!``8```!.#`$`!@```%4,`0`*````7`P!``0```!G
M#`$`"````&P,`0`(````=0P!``0```!^#`$`"````(,,`0`&````C`P!``@`
M``"3#`$`#````)P,`0`:````J0P!``@```#$#`$`!@```,T,`0`4````U`P!
M``0```#I#`$`!````.X,`0`$````\PP!``@```#X#`$`)0````$-`0`$````
M)PT!``@````L#0$`"@```#4-`0`.````0`T!``@```!/#0$`!````%@-`0`-
M````70T!``H```!K#0$`!````'8-`0`)````>PT!``H```"%#0$`*````)`-
M`0`$````N0T!``@```"^#0$`!@```,<-`0`G````S@T!``@```#V#0$`#```
M`/\-`0`(````#`X!``0````5#@$`"````!H.`0`*````(PX!``X````N#@$`
M"````#T.`0`$````1@X!`!<```!+#@$`!````&,.`0`$````:`X!``0```!M
M#@$`*````'(.`0`2````FPX!`!(```"N#@$`"P```,$.`0`(````S0X!``@`
M``#6#@$`!````-\.`0`;````Y`X!``\`````#P$`#P```!`/`0`6````(`\!
M``X````W#P$`!````$8/`0`*````2P\!``H```!6#P$`!````&$/`0`&````
M9@\!``H```!M#P$`#@```'@/`0`*````AP\!`!0```"2#P$`$@```*</`0`2
M````N@\!``8```#-#P$`"````-0/`0`0````W0\!``H```#N#P$`"@```/D/
M`0`'````!!`!``@````,$`$`"````!40`0`&````'A`!`#H````E$`$`#P``
M`&`0`0`D````<!`!``0```"5$`$`"````)H0`0`&````HQ`!``0```"J$`$`
M%@```*\0`0`2````QA`!``X```#9$`$`%````.@0`0`(````_1`!`!$````&
M$0$`#````!@1`0`&````)1$!`$,````L$0$`#0```'`1`0`1````?A$!``T`
M``"0$0$`$0```)X1`0`7````L!$!`!````#($0$`#0```-D1`0`(````YQ$!
M``P```#P$0$`$@```/T1`0`(````$!(!``0````9$@$`+````!X2`0`$````
M2Q(!``8```!0$@$`"````%<2`0`/````8!(!``0```!P$@$`(0```'42`0`C
M````EQ(!`#H```"[$@$`'````/82`0`3````$Q,!``0````G$P$`"````"P3
M`0`A````-1,!``0```!7$P$`#@```%P3`0`,````:Q,!`!````!X$P$`#```
M`(D3`0`@````EA,!``H```"W$P$`$P```,(3`0`$````UA,!`!<```#;$P$`
M!````/,3`0`$````^!,!``@```#]$P$`$@````84`0`$````&10!``@````>
M%`$`$P```"<4`0`5````.Q0!``H```!1%`$`'````%P4`0`2````>10!``P`
M``",%`$`"````)D4`0`3````HA0!`!$```"V%`$`+````,@4`0`&````]10!
M``X```#\%`$`"`````L5`0`,````%!4!``@````A%0$`"````"H5`0`,````
M,Q4!`!0```!`%0$`!````%45`0`(````6A4!``(```!C%0$`!````&85`0`(
M````:Q4!``0```!T%0$`!@```'D5`0`(````@!4!``8```")%0$`!````)`5
M`0`(````E14!``0```">%0$`!````*,5`0`$````J!4!``T```"M%0$`#```
M`+L5`0`$````R!4!``0```#-%0$`!````-(5`0`)````UQ4!``8```#A%0$`
M!````.@5`0`&````[14!``0```#T%0$`!````/D5`0`1````_A4!``0````0
M%@$`%@```!46`0`4````+!8!``T```!!%@$`$@```$\6`0`=````8A8!`!``
M``"`%@$`!````)$6`0`$````EA8!`!4```";%@$`)P```+$6`0`%````V18!
M``@```#?%@$`"````.@6`0`2````\18!``0````$%P$`!@````D7`0`(````
M$!<!``0````9%P$`!@```!X7`0`&````)1<!``X````L%P$`#P```#L7`0`1
M````2Q<!`!@```!=%P$`'````'87`0`6````DQ<!`!0```"J%P$`%````+\7
M`0`>````U!<!`"@```#S%P$`&P```!P8`0`=````.!@!`!T```!6&`$`$0``
M`'08`0`2````AA@!`!@```"9&`$`&````+(8`0`>````RQ@!`!D```#J&`$`
M,@````09`0`O````-QD!`#$```!G&0$`+P```)D9`0`7````R1D!`!<```#A
M&0$`%@```/D9`0`3````$!H!`!\````D&@$`$P```$0:`0`9````6!H!`!8`
M``!R&@$`$0```(D:`0!"````FQH!`"0```#>&@$`.0````,;`0`O````/1L!
M`!L```!M&P$`.````(D;`0`E````PAL!`!X```#H&P$`'@````<<`0`;````
M)AP!`!$```!"'`$`&0```%0<`0`;````;AP!`!L```"*'`$`)````*8<`0`/
M````RQP!`#T```#;'`$`$P```!D=`0`(````+1T!``@````V'0$`$P```#\=
M`0`M````4QT!`!<```"!'0$`#P```)D=`0`D````J1T!``0```#.'0$`"```
M`-,=`0`(````W!T!``@```#E'0$`"P```.X=`0`$````^AT!``8```#_'0$`
M3P````8>`0`$````5AX!``T```!;'@$`!````&D>`0`*````;AX!``0```!Y
M'@$`!````'X>`0`(````@QX!`!````",'@$`!@```)T>`0`&````I!X!``8`
M``"K'@$`!@```+(>`0`5````N1X!``H```#/'@$`$@```-H>`0`&````[1X!
M``X```#T'@$`#`````,?`0`$````$!\!``4````5'P$`!@```!L?`0`&````
M(A\!`!(````I'P$`'0```#P?`0`>````6A\!`!\```!Y'P$`#@```)D?`0`6
M````J!\!`!(```"_'P$`$@```-(?`0`7````Y1\!`!(```#]'P$`$@```!`@
M`0`1````(R`!`!H````U(`$`$0```%`@`0`2````8B`!`!8```!U(`$`%P``
M`(P@`0`2````I"`!`!4```"W(`$`$P```,T@`0`0````X2`!`!<```#R(`$`
M$@````HA`0`7````'2$!`!(````U(0$`$@```$@A`0`1````6R$!`!8```!M
M(0$`&````(0A`0`6````G2$!`!X```"T(0$`'P```-,A`0`8````\R$!`!(`
M```,(@$`%P```!\B`0`6````-R(!``8```!.(@$`#````%4B`0`,````8B(!
M``8```!O(@$`"````'8B`0`$````?R(!`!X```"$(@$`&P```*,B`0`.````
MOR(!`!````#.(@$`!````-\B`0`$````Y"(!`"0```#I(@$`!`````XC`0`&
M````$R,!`!,````:(P$`!@```"XC`0`.````-2,!``0```!$(P$`!P```$DC
M`0`(````42,!``\```!:(P$`)0```&HC`0`&````D",!`!T```"7(P$`"```
M`+4C`0`(````OB,!``@```#'(P$`&P```-`C`0`&````[",!``8```#S(P$`
M#0```/HC`0`,````""0!`!$````5)`$`!````"<D`0`2````+"0!``8````_
M)`$`&````$8D`0`"````7R0!``@```!B)`$`!````&LD`0`(````<"0!`"0`
M``!Y)`$`!````)XD`0`(````HR0!``0```"L)`$`#P```+$D`0`,````P20!
M``H```#.)`$`#@```-DD`0`,````Z"0!``8```#U)`$`"````/PD`0`=````
M!24!``0````C)0$`&P```"@E`0`0````1"4!``8```!5)0$`"````%PE`0`$
M````924!``0```!J)0$`!````&\E`0`$````="4!``D```!Y)0$`"````(,E
M`0`1````C"4!`!(```">)0$`"````+$E`0`C````NB4!``\```#>)0$`#0``
M`.XE`0`(````_"4!``4````%)@$`!@````LF`0`*````$B8!``H````=)@$`
M#0```"@F`0`"````-B8!``(````Y)@$`#````#PF`0`$````228!``0```!.
M)@$`"P```%,F`0`]````7R8!`"$```"=)@$`)0```+\F`0`.````Y28!``X`
M``#T)@$`"P````,G`0`7````#R<!`#\````G)P$`(0```&<G`0`<````B2<!
M`!4```"F)P$`$P```+PG`0`3````T"<!`!,```#D)P$`$P```/@G`0`>````
M#"@!`!`````K*`$`"````#PH`0!1````12@!``@```"7*`$`#````*`H`0`,
M````K2@!``H```"Z*`$`*P```,4H`0!1````\2@!`!L```!#*0$`$P```%\I
M`0`/````<RD!``\```"#*0$`"@```),I`0`(````GBD!``8```"G*0$`!@``
M`*XI`0`(````M2D!``@```"^*0$`"@```,<I`0`4````TBD!``0```#G*0$`
M!@```.PI`0`3````\RD!``,````'*@$`!`````LJ`0`)````$"H!``D````:
M*@$`!````"0J`0`(````*2H!``@````R*@$`&@```#LJ`0`&````5BH!``@`
M``!=*@$`!0```&8J`0`%````;"H!`!````!R*@$``0`````````R`@``F`(`
M`)8#``!P`P``R@0````````(`@`````````````+`P``H`(``%0#````````
M30(``(L```"L`P``Z@````````!8````B`0``(<!``"3`@````````````"U
M`@`````````````0!```[@(``&`#`````````````$D!````````?@```+<$
M``#Z`P``D0```,$$``"Q`0``"@$``+4`````````IP,``"@#``".!```$P0`
M```````M`P``D`$`````````````K````/,#```C!0``T@(```````#7`0``
M:@0```````#,!````````*H$``#S`0``^0,``$L"`````````````&\#````
M````7P0``````````````@(``#`$````````(P0```````"=`@``C0,``$P`
M`````````````(4$``#\`P``T`,``.(!```,`0``\P`````````D`0``HP$`
M`/8!```T`0```````+0$``!3`P```````*````!/!```>@,``#4#````````
M.`,```4%```P!0``]`$``(0"``#[````$0,```````!2!```E0(``-X!```'
M````KP,``````````````````'L"`````````````````````````````'T$
M``#-````?@0```````#%`P``D00```````#R`0````(``!P#```?`````P(`
M``````!P!```-P(``&\$``#I````E0,``,8!```T`P``$````*8!```(````
M`````)X`````````V@$``%X"```Q!0``NP0``,L!````````N0````<$```=
M`0``J00```@!``"U`0``T0```#T"``!>!`````````P$``"A`@``Y`0`````
M``"[`P```````&D"```,!0``!@0``%8$```&`0```````!T#````````JP``
M````````````*`0``&X#``!$`P``&`4```````!H`@``HP0```````!$`0``
M`````"H#````````/P,```````!H`````````#$"``"W`0``N0,```H"``#A
M`0````````@#````````.`4``,L$``#$````;@$```````#W!```U0(``(4`
M````````?`$``"D%```"!````````+8````H````W0$``,@"````````-0``
M``(#````````00```.L```#2!```80(```````";`P``[0```#8%```=`@``
M:0$````````-`0``&00```$!``````````````````">!````````(<`````
M````P`,``,0!````````J@,``*4#```D`@```````!4"``!-!```*0,``*(!
M``#.`@``<`(``-H#````````*P0``!D```!Y!```GP$``-$$``"M`@``N`0`
M`+0!``!G`@``*`(``%(!``"E`0``^`$``!T$``#I`P``M````!$%``!.````
MN0(`````````````_`(``-L#``#M`0````````````#[`P``V0,`````````
M````_`0``````````````````````````0````````````#]`@```````(L"
M``#Y````,@```'`!``"-`0``&P0``*X"```>`@````````````!B`@``````
M`(X"``````````````````#M`@``&`$``.<$```/`P``90,``$8`````````
M`````+<#``!%`@``S@,``&`!``#V`@``_00```````!,`0```````)D#```)
M!0```````#D"``#C````DP$``%4!``"!`@``@@(```````"`````RP(``$T!
M``#D`P``\`(``,\$````````+````%$#`````````````#<%````````````
M`*(````R!0``L@(``-``````````[@$``+\#````````<P,```````#)!```
M4P0``!(%``!+`P``W0````````!1!```6`,``-<"```2`0``Y@````````!)
M`@``P@,```````#&!```S0$``)<`````````H@(``$4!``#L````:`0`````
M``"P`0``[`,``)P#`````````````&H!```@````N0$``.$```"?`@``WP``
M`)(```!R`@```````,`$```^`@``R@```+P!```Q!```5P```%8````,`@``
MJ@$``!<#``"X`P``0`$``"@!``!_`````````$`$``"]`0``VP$```4$``"R
M`P``$@(```````!4````.`$``'P#``".````#0,``&8$````````D@0`````
M````````,@0``'H!``"W`@```````"X%``#N!```-0$``-<```"G````>@``
M``,%``#I`@``1P```"D$```0`@```````"X"``!^`@```````",````(!0``
M;`````````!7`@``7@```+X"````````)@(``````````````````)H"``"G
M`0``'P(`````````````*`4``"X$``#9`0``N@(``+`$```G`P``'`````\!
M``!\!```%04``!8"``!'`0``N@$``"`"```&!0````````````!U`P``TP$`
M`+X#```R`P``]@````````##!````````%<$````````<P```+L!``":`0``
M,P```)H#```:!```.@(``/X`````````^@(``$\``````````````"8%``![
M!```:00``!H#````````0P````````"#`0```````&P$```F`0``,`,``($$
M```3`@``^00``&`"``"O!```Z0$``',"````````!@(```````!'!```````
M`/<"``"=!``````````````````````````````*!````````"$#```G````
M`````$X#``#$`@``<@,``#\`````````K`(```<"``#6`0``8P0``!X%```R
M`0``F0(```````"I`0``#@$``.8!``"?````>0,``"H$``"/`P``R@$``'D"
M``#@!```=@```+,#``"]`P``<@0```````"N`0``AP,``/4"``#B`P``P0,`
M```````3`P```````)<#```K`@``````````````````#0```!L#```\````
MT`$``,<!``#+`P```````)D$``"4!````````+D$``!A!````````$(!``"0
M`P```````*$$`````````````+8!````````'P$``.8"``!<`````````)P"
M````````E`(```````"@!```'04``)H$```>`P``;`(``&8!```W`0``"0(`
M```````G`0``_@$``+<`````````V@(```````";````A`````````#3!```
MT@,``$@```#Q`P``;`,``'0"``!O`0```````'<$````````/00``+\$``#K
M`@``\`0``'8$``#Z!```8P$``,,"``!$`@``R`0``'@$```"````-````*L!
M``"^````U00``)P$`````````````%(#``!M`0````````8#``"H!```2`$`
M`$X$````````O`(``-@!``!&`@``E`,``,4$``"X`0``8`0``(<"````````
M``````````":````+P```.@"```1`````````````````````````-4#``"X
M`````````/P```!6`P``^`(``````````P```````*@!````````=`0``,8#
M``#3````"@4``%0"```F`P``9@(``&0```````````````````!W`@``````
M`(0$```!`P``+`0``%X#``"H`@``40(``*\"``#_!```K00``+`#```M````
M.````&\"``"*`P``P@```,<````0`P``3@(`````````````.@,``+$#````
M````600``-T#``"=`````````&T`````````W@(``.P!``!K`0``````````
M``````````````````"K!````````#L#````````\@```/X#```1`@``&P4`
M`/$"``">`P``"0$```````!3`0``"P$`````````````*0(``-,"```/````
MCP$``*X````.`P``/P0``&L#``"2`0``:`$``*8"``"\`P``\@0``!H```"O
M`0```P,``)8!``#@`@```````%L"``!4!```?@,```P#```?`P``!0,``%,`
M``"#`P``6`(``,$"``!*!```+P,``,4````/`@``W`(``&H"``#[!```````
M`*,#``"+`P``N@0```````#E`0``%00``-(```#'`P``!`0``!D%````````
M-`(``+0#``!!`@``````````````````T0$``"L#``!"````9P,``/4!``!]
M`@````````T"```F````700``/<#``"-!````````,D`````````\P0``-8"
M```C`0```````/\"``#,`````````,$```!W`0``;00``'H"```>````4@(`
M```````Z`0```````%$````X!```4`(`````````````E0`````````&````
M+0(``(@````M!```8@0``!,%``#V`P``;@0``#<``````````````*<"``#U
M!`````````````!2````;`$``&T#```>!```"0```(D!````````F`,``-P!
M````````G@$``!H%```8`P````4``'(```!K!````````,P!``!9`0``A0$`
M`&L"``"F````T0(``,``````````4`0``$\"````````4````#T!``!_!```
M&`0``&H#```?!0``YP,``%L#```A!0``8````!<"````````#@(``(X#``#=
M`@```````)0```"H````"P4``'$#``!1`0``%@4```````!U`````````)@`
M``!:`0``/`$`````````````\````)P!``"<````DP,``+8#```%`0``I0(`
M``````"D!```-P0``($!````````!````*$!``#)`0``5@$`````````````
M5P,``'@````J`````````-8$``!Q`0```````*X$``#D````]`(```````!B
M`0```````$\!````````A0,``*`!````````G0$``((`````````]P$`````
M```P`0``20````````#K!```*P4```````!&`P``(00``(<$``!+````````
M``X````@`P``V`0``,H#``!D`P``J@```#X!```)`P``O0(``%@!```!!0``
M```````````B`````@4``&H```"Z`P``````````````````7@$```````#<
M````Y`(``+,!````````&0$```<%````````Z00``#8"``"3````70,``.,$
M``!G``````````````"0`@``NP(``/L!````````F`0``*D```!C`P``CP0`
M`.4$``"!````E@0``'$$``"I`@``900````````P````6@(````````Z````
M`````+4#```I`0``I`$``%`!``"?`P``M00```H```"&`0``!`,````````_
M`0``W`,``/,"``"#!```!`4``(L!``#G````JP,``#@"````````8P```.\#
M```````````````````D!0``30,``%<!````````-04``*L"``!*````@P``
M`'```````````````)\$``#Y`0``%P4````````;`@``,P0```@$``!$````
MI`````````!;`0`````````````O!0````````D$````````&0(```4"``#*
M`@``,0$```\$``!+`0```````"4!`````````````&T"``#O!```50,``.8$
M````````_P$`````````````9`(``%D"``"%`@``"@,````````@!```````
M`%\````$`@``E0$```````!T`0``_@(```````!"!```200```,```!F`P``
M%@,``,(!``!%```````````````B!0``'`0``.T#``!R`0``)````(P$``#8
M`P``+P(```````#>!```%`(``!L!``!*`0``%`$``*($````````EP0``,,!
M``"L`0``]0```+X!````````%`4``*T``````````````,@```!G`0``````
M`"\!`````````````'T!``"(`P``%0,``$L$``!I`P``2`,``(P```"O````
M``````````#'`@``Z`,``.4#``",`@``=0(``-L$````````U````)("````
M````]````$``````````8P(`````````````7`0``#,%``#-`P``QP0``!,`
M```G!0```````%D#``!3`@``(@,``-\#``"S!````````"X!```=````'`$`
M`#8#```!!````````-4```!?`@``:P```-\$``!X`P```````%\!``!!`0``
MB0```"$````V`0``<P0``%D```!'`@``F`$```````!U`0````````T%````
M````Z`$``,X$```0`0``LP````````#Z`0``O00``(L$``#]`0``*P$``*D#
M``#F`P``\0```,P"``#&`@``?P$``$0$``#7!````````"($````````$@,`
M`/$$```Y`P``WP(``,,```!=`@``XP,````````E!0``3`(``&4"``#B````
M`0(``/D"``!'`P``6@```"$!``"A`````````*X#```S`0``%@```"(!```>
M`0``?P,``+`"````````=@,```````!N````*@$`````````````%`,``#L`
M``"E````W`0`````````````6P0`````````````D0,``'L`````````/`(`
M`.0!```8`@``TP,``.$"``!]`P``ZP,``/4#`````````````(`$```K````
MD````","``"*!````````'@!````````/@`````````+````-`0```````#E
M````G@(``#D```!O````L00```````!V`0``L0(``&4`````````CP```'0`
M``#>````B0,``&$`````````L@```*,"``#B!``````````````W`P``````
M`````````````````'$```!=````[`(``&@#```N`P``7`,```````#P`0``
M=P```,4!``!8!```S0(``)4$````````U`(``-8#``"7`@``70$``&0!```?
M!```/0,``,\!````````_0,``,\`````````<P$``/(#``#8`````````.<"
M``#T!```/`,```````#O`0``G0,``%P!``#)`P``@@0`````````````C0``
M`-$#``!T`P``.0$``#8`````````O``````````.!````````/@$``"&````
M)0``````````````.P(```````#8`@```````.X#````````3P,```````#T
M`P``7`(`````````````!`$``.@$```U`@``9`0```````#_````YP$``$T`
M``#]````R`,``#$```!5`@``"P(``$4#``!_`@```````-0$``"H`P``9@``
M`*`#``#_`P``2`0``.@````U!`````````````#0!```V00```L$```/!0``
M=00``,P#````````A@0``$4$```L`P``X@(`````````````Q0(```````!]
M`````````-H$``!5!```!0`````````M!0``@`$``````````````````%H$
M``!Y````6P```/$!````````D0$``!P"```_`@```````(\"````````>P,`
M`-0!```@!0```````"$"``#J!```_`$``!`%```]`````````(`"``!Z!```
M`````.$$``"J`@```````(D"````````A@,``.4"```E`@``0P(`````````
M````U@```/X$```8````/@0``-X#````````000``$("````````F0```$H#
M````````)P(``"4#``#L!```@0,```,$````````+`$``+,"````````H@,`
M`$D#``#(`0``+P0````````'`P``````````````````VP```-D````:`@``
MD0(``(H!``"9`0``*@(``#D$```D`P``X````&$#``#.`0``OP(``-`"```4
M````N@```"`!``#X`P```````&$!``#.````I@0``.,"``#$`P``%P$``)L$
M```M`0``B`(```````````````````````!:`P``K`0``$H"````````H0,`
M`,($````````````````````````@P(``#L$``""`0``3`0``!$$```I````
M`````.\"``!,`P``FP$``",#``!#!```]P````````!&!```<0(```````#+
M````+`4``+T```#2`0``%0```*T#````````D@,```````#Z````E`$``%8"
M```S`P``V0(``"<$``"_````L````$,!```\!```E@(``$`#``"(`0``/@,`
M``````#/`@``$@0````````J!0```````+($``!I````.@0``-<#``"M`0``
M9P0``.L!``#?`0``00,``*0#``"&`@``HP```+0"``#V!```1@$```<!``#-
M!```C`,``+(!``!#`P```````/@```!B````%P```$X!````````A`,``(X!
M````````X0,``.\```#&````L0```(P!``#@`0```````,$!````````XP$`
M`'<#``!B`P````````(!``"6`````````'P"```B`@``B@(``,("````````
M>`(```````![`0`````````````3`0``'`4``!8$```T!0``\@(``*8#```#
M`0``DP0``+8$````````Z@,``"X```#)`@``#````.H!```5`0``)@0```T$
M```9`P``D`0``-0#````````SP,``,0$```1`0```````(T"```V!```````
M``````#:````X`,``.T$``!\````4`,`````````````,0,```````#=!```
M`````+\!``#J`@``IP0``+P$``!?`P``M@(``+@"```P`@``FP(``(0!````
M!````````!(````D!````````,`!``!V`@``VP(``#L!```E!```B00``'X!
M```.!0``PP,``/L"```S`@``U0$``((#``#N````;@(``*0"``!5````%P0`
M`(`#````````\`,``!8!``!4`0``EP$```````!``@``&P```,`"``"[````
M`````"P"``!(`@``I00``+X$````````&@$``!0$``!E`0``>0$``$(#``"*
M```````````@("`@("!4;SH@`"`@("!$871E.B``("`@($9R;VTZ(``@*"5S
M(&1A>7,@86=O*0`@*'1O9&%Y*0`@*'EE<W1E<F1A>2D`(%-U8FIE8W0Z(``@
M870@`"!I;B``)60@=&\@)60@;V8@)60@365S<V%G97,`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M
M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%L<F5A9'D@
M97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N`"5S(&%T
M("5S("5S`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD
M+@`E<R!T;R`E<R!O9B`E<P`H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V
M92!T;R!N97AT('-C<F5E;BXI`"A$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R
M971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BD`*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@3TL@*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`L
M(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E
M;&5C="`M+0`R-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER
M960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S
M<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S
M86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!
M8F]U="XN+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@9G)O
M>F5N+@!!8V-O=6YT)W,@;F%M93H`06-C;W5N=&EN9P!!9&0`061D($-H:6QD
M($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W
M($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`061D
M(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!
M9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QL`$%L;"!!=71H
M96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L
M;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E
M(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"!F:6QE.@!!;&P@;65S<V%G97,@
M:6X@>6]U<B`B)7,B(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B
M92!P97)M86YE;G1L>2!D96QE=&5D+@!!;&P@;VQD('-E;G0M;6%I;"!F;VQD
M97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L<F5A9'D@97AI<W1S`$%L=&5R
M;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R
M;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!T96UP;&%T97,`06UE<FEC
M86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O
M<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R960`
M06YS=V5R960@;65S<V%G97,`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B
M=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T
M;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M
M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/P!!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H
M:7,@:7,@3D]4(')E8V]M;65N9&5D(2D`07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&1O('1H:7,_`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_`$%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\`07)G
M96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)R:79A;"!4
M:6UE`$%R=6)A`$%S8V5N9&EN9P!!<V-E;G-I;VX@27-L86YD`$%S:6$O4&%C
M:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&%C:`!!='1A8V@@82!C;W!Y
M(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/P!!='1A
M8VAM96YT`$%T=&%C:&UE;G1S`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@
M<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0F%C
M:R!T;R`E<P!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L
M=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"8V,`0F5L
M87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T
M:&1A>0!";&%C:VQI<W0`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";V1Y
M`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]S;FEA(&%N9"!(97)Z96=O=FEN
M80!";W1H`$)O='-W86YA`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG
M87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#
M4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0V%L;0!#86UB;V1I80!#86UE
M<F]O;@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`
M0V%N8V5L`$-A;F-E;"!-97-S86=E`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U
M<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R
M960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M`$-A<&4@5F5R9&4`0V%Y;6%N($ES;&%N9',`0V,`0V5L;"!0:&]N90!#96QT
M:6,@*$E33RTX.#4Y+3$T*0!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N
M=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL
M<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@06QL
M`$-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M96UA:6PN`$-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6P`0VAI;&4`0VAI
M;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I`$-H;V]S92!!8W1I;VXZ`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E
M<SH`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"X`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-L;W5D
M<P!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!!;&P`0V]L;&%P
M<V4@06QL($9O;&1E<G,`0V]L;&%P<V4@1F]L9&5R`$-O;&]M8FEA`$-O;&]R
M`$-O;&]R(%!I8VME<@!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O
M;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;F1I=&EO;G,`
M0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H
M92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE
M9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$-O;VL@27-L86YD<P!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<G)E
M8W0`0V]R<F5C=&5D(%1E>'0`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N
M`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN`$-O=6YT<GD`0W)E871E`$-R96%T92!&;VQD97(`0W)E871E($ME>7,`
M0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E871E(&$@;F5W('-E;G0@
M;6%I;"!F;VQD97(`0W)E871E(&$@;F5W('1R87-H(&9O;&1E<@!#<F5A=&4@
M9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I
M;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L(&%N9"!D96QE=&4@<W!A;2X`0W)E
M871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A
M<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%1I;64`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=70@
M<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE
M8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@
M<V5L96-T:6]N`$1A>0!$96-E;6)E<@!$96-R96%S92!);F1E;G0`1&5F875L
M="!)9&5N=&ET>0!$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z`$1E9F%U;'0@
M<V]R=&EN9R!D:7)E8W1I;VXZ`$1E;&5T90!$96QE=&4@)7,@4'5B;&EC($ME
M>0!$96QE=&4@0W5R<F5N="!+97ES`$1E;&5T92!&;VQD97(H<RD`1&5L971E
M($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S
M<V%G97,`1&5L971E9`!$96QE=&5D(&UE<W-A9V5S`$1E;&5T:6YG(&%N9"!-
M;W9I;F<@365S<V%G97,`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-E;F1I
M;F<`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<P!$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN
M=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C
M=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I
M<F5C=&]R>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA
M>2!/<'1I;VYS`$1I<W!L87D@9F]R;6%T`$1J:6)O=71I`$1O($YO="!#:&5C
M:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$1O(&YO="!D96QE=&4`1&\@;F]T
M(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&\@>6]U('=A;G0@
M=&\@;W!E;B!T:&%T(&9O;&1E<C\`1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$
M;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N90!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$;W=N;&]A9"!&;VQD97(H<RD`1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')A9G0`1')A9G1S(&9O
M;&1E<CH`1')O<"!D;W=N(&QI<W0`12U-86EL`$4M;6%I;"!!9&1R97-S`$52
M4@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R
M;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M`$5D:70@>6]U<B!F:6QT97(@<G5L97,`16=Y<'0`16P@4V%L=F%D;W(`16UA
M:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`
M16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y($9O;&1E
M<BAS*0!%;7!T>2!4<F%S:"!F;VQD97(`16UP='D@;65S<V%G92X`16UP='D@
M<F5S=6QT+@!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!T:&4@;F%M
M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<@!%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R`$5Q=6%T;W)I86P@1W5I;F5A`$5R
M:71R96$`17)R;W(`17-T;VYI80!%=&AI;W!I80!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>&5C=71E`$5X<&%N9"!!;&P`17AP86YD($%L;"!&;VQD97)S
M`$5X<&%N9"!&;VQD97(`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$944"!U
M<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E
M<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X
M`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9I:FD`1FEL92!#
M;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G
M97(`1FEL92!.86UE`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QT97)S`$9I;F0`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T
M(%!A9V4`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0`1F]L9&5R($YA=FEG871O<@!&;VYT($-O;&]R`$9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R=6US`$9O<G=A<F0`1F]R=V%R
M9#H`1F]R=V%R9&5D(&UE<W-A9V4`1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E
M<P!&;W)W87)D<P!&<@!&<F%N8V4`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L
M>6YE<VEA`$9R;VT`1G)O;2!!9&1R97-S`$9R;VT@=&AE(`!&=6QL($1E<V-R
M:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%M8FEA`$=E;F5R
M871E("5S($-O;F9I9W5R871I;VX`1V5O<F=I80!'97)M86YY`$=H86YA`$=I
M8G)A;'1A<@!':79E;B!.86UE`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R
M965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O
M=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`
M1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES
M<V%U`$=U>6%N80!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I
M=&D`2&%S:"U!;&=O<FET:&T`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(
M96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9&4@1&5L971E9`!(:61E(%5N<W5B<V-R
M:6)E9`!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@
M061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(
M;W)I>F]N=&%L(%)U;&4`2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T
M86-H;65N=',_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E
M/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`
M24Y"3U@`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)8V5L86YD`$EC;VYS($]N
M;'D`26-O;G,@=VET:"!T97AT`$EG;F]R90!)9VYO<F4@06QL`$EM86=E('5P
M;&]A9`!);6%G97,`26UP;W)T($ME>0!);7!O<G0@2V5Y<&%I<@!);7!O<G0@
M4$=0($ME>0!);7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y`$EM<&]R
M="!097)S;VYA;"!0=6)L:6,@4$=0($ME>0!);7!O<G0@4'5B;&EC($ME>0!)
M;7!O<G0@4'5B;&EC(%!'4"!+97D`26UP;W)T+"!3=&5P("5D`$EM<&]R=&%N
M=`!);7!O<G1A;G0@;65S<V%G97,`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R
M=&5D(&9I96QD<SH`26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P
M;'D_`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC<F5A<V4@26YD
M96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F]R;6%T
M:6]N`$EN9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97D`26YF;W)M871I;VX@
M;VX@4&5R<V]N86P@4')I=F%T92!+97D`26YF;W)M871I;VX@;VX@4&5R<V]N
M86P@4'5B;&EC($ME>0!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN
M<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&UE<W-A9V5S`$EN<V5R
M="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@4F5M;W1E($UA:6QB;W@`26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV
M86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN
M=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN
M=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P
M97)M:7-S:6]N+@!);G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2X`
M26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2X`26YV86QI9"!P<F]T
M;V-O;"X`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E
M(&1A=&$N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD
M`$ES;&4@;V8@36%N`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I
M8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E
M>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L
M;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@
M;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@
M3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI<FEB871I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O
M9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%N9W5A9V4`
M3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA
M<W0@4&%G90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA='9I80!,87EO=70`3&5B86YO;@!,97-O=&AO`$QI8F5R:6$`3&EB>6%N
M($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI;FL`3&EN:W,`3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES
M="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]C
M86P@36%I;&)O>#H`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V<@
M:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,=7AE;6)O=7)G`$U-
M`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-
M4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F`$UA9&%G87-C87(`36%I;"!!9&UI;@!-86EL8F]X`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA<F-H`$UA<FL@87,Z`$UA
M<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S
M`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET
M:75S`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!L
M96YG=&@`36%Y`$UA>6]T=&4`365M8F5R<P!-96YU(&UO9&4Z`$UE<W-A9V4@
M0V]M<&]S:71I;VX`365S<V%G92!$871E`$UE<W-A9V4@4V5A<F-H`$UE<W-A
M9V4@4VEZ90!-97-S86=E(%-O=7)C90!-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E(&9L86=S
M`$UE<W-A9V4@9F]L9&5R<P!-97-S86=E('1Y<&4`365S<V%G97,@<&5R('!A
M9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RX`365S<V%G97,@=&\`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`365T:&]D`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9@!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@
M`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&EF
M:65D($1A=&4`36]D:69Y`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`
M36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E
M<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO=F4`36]V92!$;W=N`$UO=F4@
M3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]Z86UB:7%U90!-=6QT:7!L92!S
M96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U
M=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U
M<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T
M<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C
M87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP90!.971W;W)K`$YE=F5R`$YE=P!.97<@0V%L961O;FEA`$YE=R!-86EL
M`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD
M`$YE=R!M97-S86=E<P!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5X=`!.
M97AT($UE<W-A9V4`3F5X="!086=E`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`
M3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(%!'4"!P=6)L:6,@:V5Y
M(&EM<&]R=&5D+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P
M;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@
M9FEL92!U<&QO861E9`!.;R!F;VQD97)S('=E<F4@<W!E8VEF:65D`$YO(&QO
M8V%T:6]N(&ES('-E="X`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!S<&5L;&EN9R!E<G)O<G,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE
M9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L
M86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@1&5L971E9`!.
M;W0@1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&$@9&ER
M96-T;W)Y`$YO="!I;7!O<G1A;G0@;65S<V%G97,`3F]T('-U<'!O<G1E9"X`
M3F]T97,`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$]+`$]B:F5C="!#<F5A
M=&]R`$]C=&%L`$]C=&]B97(`3V9F:6-E`$]L9"!M97-S86=E<P!/;6%N`$]N
M;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@
M;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=&AE<B!/<'1I;VYS`$]W;F5R(%!E<FUI
M<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!0
M1U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0
M=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`
M4$A0(%-H96QL`%!A9V4@)60@;V8@)60`4&%K:7-T86X`4&%L874`4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U
M:6YE80!087)A9W5A>0!087)T*',I`%!A<W-W;W)D`%!A<W-W;W)D(')E<75I
M<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M
M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E
M;F1I;F<@4VEG;G5P<SH`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS
M`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P`4&5R<V]N86P@26YF
M;W)M871I;VX`4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2X`4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C97-S9G5L
M;'DN`%!E<G4`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!E;G1E
M<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CH`4&QE87-E(&5N=&5R('1H
M92!N97<@;F%M93H`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9`!0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R
M;2!A;GD@86-T:6]N<RX`4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L
M9&5R('1O('-E87)C:"X`4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD97(@
M9F]R('1H:7,@;W!E<F%T:6]N+@!0;VQA;F0`4&]L;',`4&]R='5G86P`4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969E<F5N8V5S('-U
M8V-E<W-F=6QL>2!U<&1A=&5D+@!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D
M('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U
M<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:6]U<R!-97-S86=E
M`%!R979I;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0<FEN=`!0<FEV871E
M($ME>0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT
M`%!R;W1O8V]L.@!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN`%!U97)T;R!2:6-O`%%A=&%R`%)302!0=6)L:6,@2V5Y("@E9"!B:70I
M`%)A9&EO('-E;&5C=&EO;@!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A
M;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5D:7)E8W0`4F5D:7)E8W0@365S<V%G90!2961I<F5C="!T:&ES(&UE
M<W-A9V4`4F5D:7)E8W1I;F<@9F%I;&5D+@!2961O97,@>6]U<B!L87-T(&%C
M=&EO;@!2969R97-H`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;6%R
M:W,`4F5M;W1E($UA:6QB;W@Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E
M($)L;V-K`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=7-E<@!296UO
M=F4@=7-E<CH@)7,`4F5P;&%C92!W:71H.@!297!L>0!297!L>2!T;R!!;&P`
M4F5P;'D@=&\@06QL.@!297!L>2!T;R!,:7-T`%)E<&QY+51O.B``4F5P;'DZ
M`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@`%)E<V5T`%)E<W5L=',`4F5S=6UE`%)E='5R;B!T;R!T:&4@;6%I
M;&)O>"!L:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI
M;F<@82!M97-S86=E/P!2975N:6]N`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A
M=&4@3&5F=`!2;W1A=&4@4FEG:'0`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2
M=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%
M;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3
M`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@
M3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`
M4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R
M;W9I9&5R`%-A=61I($%R86)I80!3879E("5S`%-A=F4@1')A9G0`4V%V92!/
M<'1I;VYS`%-A=F4@87,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879I;F<@=&AE(&1R
M869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`
M4V5A<F-H`%-E87)C:"!297-U;'1S`%-E96X`4V5L96-T`%-E;&5C="!A(&=R
M;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R
M`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!A8V-O=6YT`%-E;&5C="!N;VYE
M`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@365S<V%G90!396YD(%!R
M;V)L96T@4F5P;W)T`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I
M82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<@!397)V97(Z
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O
M<'1I;VYS+@!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P
M87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M`%-H;W<`4VAO=R!!;&P@2&5A9&5R<P!3:&]W($1E;&5T960`4VAO=R!-86EL
M:6YG($QI<W0@26YF;W)M871I;VX`4VAO=R!5;G-U8G-C<FEB960`4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('!I8VME<@!3
M:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:')I;FL`4VEE<G)A($QE
M;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN
M9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI
M80!3;F]W(&1E<'1H.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]R="!O
M<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E
M`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!E8VEA;"!#
M:&%R86-T97)S`%-P96QL($-H96-K`%-P96QL(&-H96-K(&-O;7!L971E`%-R
M:2!,86YK80!3=&%N9&%R9`!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E
M`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T
M:')O=6=H`%-T<FEN9R!L:7-T`%-U`%-U8FIE8W0`4W5B:F5C="!&:65L9`!3
M=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY('=R;W1E("5S
M`%-U9&%N`%-U;B!2:7-E`%-U;B!3970`4W5N<FES90!3=6YR:7-E+U-U;G-E
M=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O
M<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W
M87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WER:6%N($%R86(@4F5P=6)L
M:6,`5%-6(&9I;&4`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`
M5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E
M=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z
M(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN:7-T
M<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL
M86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%C8V]U;G0@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@86-C;W5N="`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&4@8W5R<F5N="!F;VQD97(H<RD@(B5S(B!W:6QL(&)E(')E;F%M
M960@=&\@(B5S(BX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T
M:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I
M;F=S+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&1E<B`B
M)7,B(&%L<F5A9'D@97AI<W1S`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S
M<V9U;&QY(&-R96%T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U
M;&QY(&1E;&5T960N`%1H92!F;VQD97(@(B5S(B!W87,@<W5C8V5S<V9U;&QY
M(')E;F%M960@=&\@(B5S(BX`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U
M:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P
M<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S
M(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE
M('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S
M(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D
M+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N
M`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&UE
M<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E
M<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM
M=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T
M:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q
M=6ER960@9FEE;&0N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&9I96QD(&ES(')E<75I<F5D
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN
M('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4
M:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@
M)7,N`%1H:7,@;65S<V%G92!T;P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1I;64`
M5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO
M<BU,97-T90!4:71L90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1R87-H(&9O;&1E<CH`5')I;FED
M860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y
M`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N
M(&EN9&5X.B``55),`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N
M(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82X`56YA;G-W97)E9`!5;F%N<W=E<F5D(&UE<W-A9V5S`%5N9&5L
M971E`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A
M8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@
M`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@
M2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N`%5N<V5E;@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D
M871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BX`57)U9W5A>0!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E
M<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`57-E<FYA;64Z(`!5<V5R
M<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`
M5F%L=65S`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO
M;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E
M9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6:65T($YA;0!6:65T
M;F%M97-E("A625-#24DI`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE
M=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD
M<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+@!786QL:7,@86YD($9U='5N80!790!796%T:&5R($9O
M<F5C87-T`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O
M("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@
M*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D
M96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T
M97(_`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=O<FL@061D
M<F5S<P!7;W)K(%!H;VYE`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H
M;V\A(&UA<`!996%R;'D`665M96X`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@
M5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C
M:R!T;R!765-)5UE'+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@
M)7,N`%EO=2!H879E("5S(&YE=R!M97-S86=E<RX`66]U(&AA=F4@,2!N97<@
M;65S<V%G92X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!D97-C
M<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B
M;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@
M8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@
M16UA:6P@061D<F5S<P!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@
M061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@4')I=F%T92!+97D`
M66]U<B!0=6)L:6,@2V5Y`%EO=7(@86-C;W5N=',Z`%EO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`66]U<B!S:6=N871U
M<F4Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%M.;R!3=6)J
M96-T70!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!F:6QE`&9R
M;VT`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`;F]T
M(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;W(`<W!E;&QI;F<@
M97)R;W(`<W!E;&QI;F<@97)R;W)S`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FT`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T
M:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($E-4"`T+C`M8W9S"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P,2TV+3$R(#$X.C,Y*S`X,#`*3&%S="U4<F%N<VQA=&]R.B!7
M86YG2&5N9U=E;B`\=VAW0&UY,38Y+F-O;3X*3&%N9W5A9V4M5&5A;3H@0VAI
M;F5S92`\=VAW0&UY,38Y+F-O;3X*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4=",C,Q,@I#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`("`@RM6\_LC+H[H`("`@R-7&VJ.Z
M(``@(+>BO/[(RZ.Z`"`H)7,@S.S'L"D`("B]\<SL*0`@*-?RS.PI`"`@("#6
M]\SBH[H`T]H`(-3:`+33("5D(+6]("5D(+FR("5D(+?B`-?NO?P@)60@S.S&
M^,_SU*2QJ``E<R`M(+&XS?S"O``E<R#6N,[&`"5S(,ZLNZ2RV=?W("T@R+?(
MSP`E<R#7HK+A`"5S(,VLTN+/[L2_`"5S(-+1M.;4V@#.Q+S^O-`E<]+1OJVT
MYM3:HZS$X[7$SL2\_KS0)7/#N]/0L;NXQ,/[+@`E<R#4VB`E<R`E<P"QV-#H
MTJH@)7,`)7,@M]8`U=*RN[6]("5S+@`@)7,@M;T@)7,@N;(@)7,`(-.FT\/5
MXM"IN,2QY+*BTL:VK[6]S\+2N\;!`+?%QOK+^=/0N/RXQ+*BM[6[V+6]T+33
MRKS^`"H@M>.[]\BWMJBPM,6EU/:\TR`J`"H@Q^O1H=3QM=C6MR`J`"P@U?.W
MYR`E<R`E<P`LL>2[K\&_M-,@)7,@M;T@)7,`+2T@T:'4\2`M+0`R-"#0H<JQ
MUL8`M,O'^+_IL=C0Z]*JUKBVJ,K]OMV_XK?^SO&VRRX`MZ+)^L'+TKNX]M'/
MUMBUQ+3MSO,`T_N\T\/<T\J\_BR[N=#HTJK3T-*[N/8@4$=0(+FKOZK#W-2_
M+@#3^]'IUJ32T<>IP_NUQ-/*O/XLN[G0Z-*JT]#2N[CV(%!'4""YJ[^JP]S4
MORX`T_N]XL/<T\J\_BR[N=#HTJK3T-*[N/:YJ[^J(%!'4"##W-2_+,N]P]P@
M4$=0(,/<U+\LTM2\L+_:P>XN`-/[UK30T-/*O/['J</[++NYT.C2JM/0TKNX
M]KFKOZH@4$=0(,/<U+\LR[W#W"!01U`@P]S4ORS2U+RPO]K![BX`T_N]XL/<
MT\J\_BR[N=#HTJK3T-*[N/:YJ[^J(%--24U%(,/<U+\LR[W#W"!334E-12##
MW-2_+-+4O+"_VL'N+@#3^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J
M(%,O34E-12##W-2_+,N]P]P@4R]-24U%(,/<U+\LTM2\L+_:P>XN`-/[O-/#
MW-/*O/XLN[G0Z-*JT]#2N[CV(%--24U%(+FKOZK#W-2_+@!!32]030!!4$D@
ML>"ZQ0"YV-/:U>*X]K'@O*W&]P"YV-/:+BXN`,BHS]ZRN]?C+,[>MZB]J,&B
M(%9&4R#$O\*\+@#(J,_>LKO7XRS.WK>HO:C!HB!61E,@SL2\_BX`U<NZQ=+1
MMK.]X2X`U<JZQ:.Z`+WAU<H`T,+4]@#0PM3VS\*\MM?I`-#"U/;/PKRVR*C/
MW@#4VK3+T,+4]J.Z`-#"U/;3P[NGU^D`T,+4]LBHS]X`T,+4]M*[N/;3P[NG
M.@#0PM3VTKNX]K/)U+$Z`-#"U/:VU`#0PM3V("5S(,ZJ($UO>FEL;&$@4VED
M96)A<B"RR[6E`-#"U/;3P[NG`-#"U/;3P[NGM<2YIL3<M;''L+&[N=BQU2X`
MM=C6MP"UV-:WL;X`L\G.JKG<P.W4L2`M(,ZJQN3+_-/#NZ?%Y-;#R*C/W@"Y
MW,#M`+GCN.:YW,#M`+"BN+NZN0"PHK;[L,W$X=''`+"BMON\L,#[T<<`L?##
M^P#+^=/0`,OYT]#2T='IUJ2UQ-/#NZ<`R_G3T-/#NZ?7Z0#+^=/0R*C/W@#+
M^=/0U-K/PL'0T\K/Y-;0M<33RKS^O:NQN\_"U-BUO=*[N/9-0D]8SL2\_M;0
MH[H`R_G3T-3:(B5S(L[$O/Z\T-;0M<34Y]/:)7/,[,>PM<33RKS^O:NQN]/`
MOL/0U,F^L_VAHP#+^=/0M//3VB5SN/;4PK7$MZ*\_L_DO:NQN\F^L_VAHP#4
MRM#MMN"X]K7GU]/3RKS^M=C6MP#2T;3FU-H`L>2X_"!)35-0(+7'PKP`L>2X
M_"!)35-0(,/<PNL`L>2X_"!)35-0(-/#NZ<`L>2X_,2CL.8`P\#*],CXQ*;1
MQP#2N[CVLKNZS[>HM<36M;&[RKG3PRX`L+*UP+;[`+"RN.?`K0"PLKGGP*T`
MQ.3#^[3ZP.T`TM&[V+BT`-+1N]BXM-/*O/X`Q,^\J];>`+"RS.&YS[RPL,VV
M^[*\M.\`TZ;3P[/,T/(`TZ;3P[/,T/+2T;[-T/<`TZ;3P[6]R_G3T,_"O+:Y
MLL_M`,7ZU[P`R\34P@"PHL"MLJ[.Q"`H5VEN9&]W<RTQ,C4V*0#1N<OUSL2\
M_K3ST*$`T;G+]<[$O/[#^[/&`,3CR+?0Q<3CTJK)OK/]N,.YJ[FRP]S4O\+P
MH[\`Q./(M]#%Q./2JLF^L_W#W-2_MM2COZ.HLKO-QKSVM<3@WJ.AHZD`Q./(
MM]#%Q./2JM7BP[37]J._`,3ZR+>VJ-*JR;ZS_2`E<R"UQ->BLN'"\"`_`,3C
MR+?0Q<3CTJK3P+[#T-3)OK/]U>+0J<_[SZ+"\*._`,3CR+?0Q<3CTJK3P+[#
MT-3)OK/]U>+0J<_[SZ+"\*._`+"BN/G-H@#1Q\/`Q.'1QP#1Q\/`Q.'1Q\[$
M("A!4DU30TE)+3@I`+6]M._*L;SD`+"BPK.PS0#)_=#R`+"BR:W+R<BZM;H`
MT<?6WB_,J\:]T?.UV,?X`-:TT-#.K+NDLMG7]\>PS]3*OLBWR,^VU+NPO_(_
M`-6SS/D`N+V\T]*[N/;$X[7$4$=0N:NYLL/<U+^UO<3CM<33RKS^UM"COP"X
MO;S^`+B]O/X`RM3-O,F^L_W2N[CVLKNTYM3:M<33P[NGU^DN`,K4S;S)OK/]
MTKNX]K*[M.;4VK7$R*C/WBX`RM3-O+'@O*W2N[CVLKNTYM3:M<33P[NGU^DN
M`,K4S;RQX+RMTKNX]K*[M.;4VK7$N;+/[2X`RO30U`"PR]3"`+#$M//`^]''
M`+#"M=C`^P!!=71H7V-R>7-Q;#H@U=*RN[6]R_G0Z-*JM<0@:6UA<"#`J=6Y
MU^F\_BX`075T:%]C>7)U<SH@M_[.\;;+LJ+.M,SAN:FXP\_NUJ>SUBX`075T
M:%]C<GEU<SH@U=*RN[6]R_G0Z-*JM<0@:6UA<"#`J=6YU^F\_BX`075T:%]F
M='`Z(-72LKNUO<OYT.C2JK7$($944"#`J=6YU^F\_B['Z];8T,*QX-+K(%!(
M4""RHL?2O-/(ZR`M+65N86)L92UF='`@T:'/[BS`_<CG(&-O;F9I9W5R92`M
M+65N86)L92UF='``075T:%]I;6%P.B#5TK*[M;W+^=#HTJJUQ"!)34%0(,"I
MU;G7Z;S^+@!!=71H7VMR8C4Z(-72LKNUO<OYT.C2JK7$(&MR8C4@P*G5N=?I
MO/XN`$%U=&A?;&1A<#H@U=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\_BX`
M075T:%]L9&%P.B#.WK>HT,+4]M/#NZ<@)7,N(+?^SO'&][O8TZ8Z`$%U=&A?
M;&1A<#H@SMZWJ,F^L_W3P[NG("5S`$%U=&A?;&1A<#H@SMZWJ+C\T,+3P[NG
M("5S`$%U=&A?;6-A;#H@U=*RN[6]R_G0Z-*JM<0@34-!3"#`J=6YU^F\_BX`
M075T:%]S;6)A=71H.B#5TK*[M;W+^=#HTJJUQ"!S;6)A=71H(,"IU;G7Z;S^
M+@#1Z=:DRJ>PW"X`T>G6I,JGL-PN("5S`%)!1$E54R#1Z=:DM.W.\RX`1E10
M(-'IUJ2T[<[S+@"_R=/#M<37UK;..@"PHLC[L-V]K@"WM;O8M;T@)7,`L;.^
ML-'5R:L`:V5R8F5R;W,@P]S"Z[3MSO,N`&ME<F)E<F]S(-/#NZ?#^[3MSO,N
M`+#-N?["[<BZM;H`L,W!U@"RJ,+>M<2ZH\[$("A)4T\M.#@U.2TQ,RD`P\^\
MT\"MN?H`L,VPS;;@R[D`L+7+S0"PU[;MPM[+N0"QR,#[RK$`LJ[`^]?(`+&T
MQ/X`L-G$O;3SR+JUN@"RN[6D`,GZR-4`O-/(Z[K:P_NUI0#'^+_IQ>36PP#'
M^+_IP.#0S0#$VLC=H[H`M-;,Y0"RH\#[SJS1QP#*Z<>I`+*HR[G$X=''NLVZ
MVLC[N.?.K,3'`,BKLK\`LJFTQ,W?Q,D`LJC.K,S8M;H`L,W.]P#3HLKTTZ&V
MR-'SP>RUV`#.Q,"S`+&CO-/`^]''`,_NQ+^W^[K%`+*\O*K$R;>HR_<`LKS"
MH;7/`,3:R-VYW,#MS[7-LP!#4D,`0U),(+?6LKRUXP#!X[RVM^<`O.W&TM6O
M`+^FPO/"H0#.WK>HP:J[^M;!($E-05`@M_[.\<;W.B`E<P"\T\3#M/,`R*'/
M^P#(H<_[S_O/H@#(H<_[SLK,XK&HN.8`SMZWJ,F^L_W.Q+S^("(E<R(N`,[>
MMZC)OK/]Q+_"O"`B)7,B+@#.WK>HUMC7Z:&CR_G,X;FIM<2\Q\*\ROW$O]/K
MS\C'L,OYL:.TYK7$ROV^W;*[M_LN`,[>MZBTJ\O-T,7/HK6]UKBVJ+7$NL7"
MZRX`M_"UP[W'`+^JPOS(NK6Z`+.MR\T`TL:VK[7GN[``R/NV^\S8SL0@*$E3
M3RTX.#4Y+3$T*0#6T+?'N;*ZS;GZ`-;0Q;<@*$E33RTX.#4Y+3(I`,:^UJ3/
MN+W:`,:^UJ2RW\+4`-6GM<,`N/RXQ`"X_+C$R_G3T`"X_+C$Q..UQ,/[U]:C
MK-/*O/ZUV-:WNLW'J</[`+SLLNG0PM/*O/X`UL?`^P#6T+GZ`+SRS.76T,[$
M("A'0C(S,3(I`+>QS.76T,[$("A":6<U*0#1H=3QLMG7]Z.Z`-&AU/'#W,+K
M`-&AU/'2N[CVT\.[I\/[`,C5QMK/U,J^M[W*O3H`RJ6UKK6Z`-72LKNUO2`E
M<R"UQ,#@L?"VJ-+E+@"PM,KSL>J\_+S,T/@`N=BQU;2PO]H`U,;!OP"_QK_&
MR[G(NK6Z`-7;M?[+^=/0`-7;M?[+^=/0SL2\_KS0`-7;M?[.Q+S^O-``N.?"
MU['(T<<`T=7)JP"U]\FKQ<P`OZC-J`##_,'N`,/\P>Z]Q;&^`+&XUZ(`S:C3
MP\/[`+_&Q*;"W@"YJ\N^`,SUO/X`Q>36PR`E<P#(M\C/P]S"ZP"XU;G[`+C5
MN?NYLKK-N?H`P:R]T\JGL-PZ(`#!K+W3UL&YJ[^JP]S4O[?^SO'&]\JQU.*^
MW+[X+B#4K=+R.B`E<R`H)7,I`,&LO=/6P2!&5%`@SL2\_K?^SO'&]\JGL-PN
M`+_BO\O(NK6Z`+BTUL8`N+36QM&AU/$`N/S5_0"X_-7]NO.UQ,[$L;X`N.?+
MN;3OP.B\TP"_QLS8M<_-WP#.WK>HTM0@4$=0(+S3P]S3RKS^+@#.WK>HSJH@
M4$=0(-:TT-#3RKS^QZG#^RX`SMZWJ-+4(%,O34E-12"\T\/<T\J\_BX`SMZW
MJ,ZJ(%,O34E-12#3RKS^QZG#^RX`SMZWJ+#SMJ@@3$1!4""W_L[QQO<`SMZW
MJ+WBP]P@4$=0(,K]OMTN`,[>MZB]XL/<(%,O34E-12#*_;[=+@#.WK>HOO:V
MJ,K5O/[(R[7$M>?7T]/*O/ZUV-:W+@#.WK>HU]3#W-2_M_[.\<;WR*&UP[FK
MOZK#W-2_+@#.WK>HM/*_JB`E<RX`SMZWJ+3ROZK.K+NDN:37]\2CO^D@)7,`
MSMZWJ+;!R*$@)7,N`,[>MZBVP<BAM.;(H;_8UL:Q[2A!0TPI`,[>MZBVP<BA
MM_[.\<;WM<3/X+G8S-C0U`#.WK>HL:.TYB`E<R"UQ,7DUL,N`,[>MZBRZ=72
M($Q$05`@(+?^SO'&]RX`U=*RN[6]($UO>FEL;&$@4VED96)A<BX@Q^O(M\C/
M('-I9&5B87(@RL>W\;3ROZHN`+GZO-(`M+2]J`"TM+VHSL2\_KS0`+2TO:C#
MW-2_`+2TO:C2N[CVT,*UQ++=N.7/Y`"TM+VHTKNX]M#"M<2WHKS^S^0`M+2]
MJ-*[N/;0PK7$P*R[^,_D`+2TO:BY_<++N>;4\M?IUJ_$X\K5M;VUQ-/*O/ZC
MK+&CM.:UO<[$O/Z\T-;0O+#)OK/]P*R[^-/*O/ZAHP"]J,&BU]/.Q+S^O-``
MO:C!HM7?M<3(J,_>`-#%T\._J+K%PNL`O\O"WK78T<<`N<6PS0"UL<>PRK&\
MY`"UL<>PS.S&^`"UL<>PU[2_]CH@`+6QQ["WY[CQ`+STQ]#1H=3Q`,C[QM;"
MM\NY`,[WP.^V^\[$("A+3TDX+5(I`,[WP.^V^\[$("A7:6YD;W=S+3$R-3$I
M`,[WP.^V^\[$+\[:O\O`O,[$("A+3TDX+54I`+W=O\NYLKK-N?H`R-4`P[_(
MU0#(U<;:`,K5M;W(U<;:`-&AU/'(U<;:`+#7S.P`RJZV_M3"`+SUR=G+]<7%
M`,2LR,_)[;?=RK:Q\`#$K,C/Q<70\K'JU[PZ`,2LR,_%Q=#RM[W/\J.Z`,F^
ML_T`R;ZS_25SN:NYLL/<U+\`R;ZS_;6QQ[##W-2_`,F^L_W.Q+S^O-``R;ZS
M_=/#NZ?7Z0#)OK/]R*C/W@#)OK/]H:+'Y;_5T\J\_@#2T<F^L_T`TM')OK/]
MT\J\_@#)OK/]LJ+2QK:OT\J\_@"UW<O-RK&\Y`"UI,+S`,3FT/(`SLK,XL/H
MRO8`S[B]V@#/N+W:("C'Z[+.O[P@2&]R9&4@O,?"O,[$O/XI.@#/N+W:Q^NR
MSK^\S[7-L[G<P.VUQ\*\+@#1T+>B`,*VM>/.PK;(`-?NNO/2N]"ARK&UQ,*V
MM>/.PK;(.B``PK:UX\["ML@Z(`"TT]?SUL'3T@"TT]/2UL'7\P#$O\*\`,_4
MRKX`TM0@,C0@T*'*L=;&S]3*OC\`S]3*OM&AS^X`S]3*OKCQRKT`O*JRO,SA
M`+*[O.RRZ=#"T\J\_@"RN\F^L_T`LKO2JM:QO=.TYLBA(&UA:6YT96YA;F-E
M+G!H<`#$X\_KM/*_JKC#SL2\_KS0PO"COP"UVM*[L<J\Q\*\RL>W\;#\NJS7
MUK;.P_NSQC\@R.>Y^\K'Q^O1H=3Q+@"VX,/7Q.&\TP"VX,/7Q.&\T[FRNLVY
M^@#-ZK/)`,_"U-@`S\+4V"`E<P#/PM38SL2\_KS0`,_"U-C)^K/)M<3%Y-;#
MSL2\_LZJ(%!(4""SS-#R+@"RW;CE`++=N.7/Y*.Z`,_"P*VRR[6E`+7GU]/3
MRKS^`$4M36%I;+78UK<`M.W.\P"V\KG/MN"V^P"QX+RM`+'@O*W'^+_I`+'@
MO*W3P[NGU^D`L>"\K<BHS]X`L>"\K<BHS]X`L>"\K2`E<R"UQ,BHS]X`L>"\
MK=&AS^X`L>"\K2`E<R"UQ,BHS]X`L>"\K<3CM<2Y_<++N>;4\@"PH[RP`,CX
MMOO-W[;@`+7GU]/3RKS^`$5M86ELM=C6MP"UY]?3T\J\_K78UK>QV-#KSL>Z
MSRX`M>?7T]/*O/[(M\C/`+'MQ^FW^[K%`,?EL_W.Q+S^O-``Q^6S_<"LN_C/
MY`"_U;#7T,6\_BX`O]6PU[WAN?LN`,3JM=<`M\6T\['@O*W&]P#'Z\KDR.O0
MPK7$LMVXY<_DM<3#^]?6`,?KRN3(Z]#"M<2WHKS^S^2UQ,/[U]8`Q^O*Y,CK
MT,*UQ,"LN_C/Y+7$P_O7U@"SX+7`O+C$VM''`+;RP:+,V,#OT<<`M.W.\P"P
MKLFSQ.'1QP"PH\C[MNVQR-''`,6WUMX`P[^X]#$UM];6TP##O[CT,S##Z];3
M`,._N/0UM];6TP##O[3.M<?"O`##O[CTL.O0H<JQ`,._M];6TP"WML#]UK4Z
M`-:TT-``U;F_JLOYT]``U;F_JLOYT]#.Q+S^O-``U;F_JL[$O/Z\T`"UO<;:
MR-4`O>++M=2Q`$944"#)S[2KQ>36PRX`ML'(H<:KNL/%Y-;#RJ>PW`#.WK>H
MP:R]TR!,1$%0(+?^SO'&]RX`SMZWJ,&LO=,@4TU"(+?^SO'&]RX`N+36QLJG
ML-S7U"`B)7,B+@"XM-;&RJ>PW+6]("(E<R(N`,[>MZB]J,&BTKNX]M#"M<0@
M4T%33"#!K+W3+@#2QK:OM;T@(B5S(LJGL-PN`+>HP+R_R[BCR+JUNB`HPNVV
M^\ZLQ,G+N<BZM;HI`+>HPM[(NK6Z`+2KU>8`MO[4P@"XT+[US_'*QP"XT+[U
MS_'*QSH@`.RSO,,`SL2\_LK]Q+\Z("5S(+CVSL2\_@#.Q+S^ROW$OSH@)7,@
MSL2\_@#.Q+S^N=S`[<;W`,[$O/[#^[/&`,[$O/[)S[2K`,[$O/[)S[2KN:;$
MW,ZTL;O6I[/6+@"Y_<++QO<`LNG5T@"WTL"\`,G/L.O4P@"UVM*[TK,`R<_/
MTM3"`+G,MJBQR,#]`+>MUZH`Q+_"O"`E<R"RN[3FU-H`T\K/Y+6\NKT`U];0
MS='5R:L`U*2QJ,SLROT@*-2DL:C,[,K]L/S`J+#7S.S2U+RPTKF\Y+7$ROV^
MW3O(Y[G[U*2QJ,SLROV]S[.DO:O5O-/#L<B]S[_MM_FUQ+#FP^8I`+2PS.4`
MR^/#_`#+X\/\P.#0S0#+X\/\`,+;S+,`UZJWH@#7JK>BH[H`M-,E<]>JMZ*U
MQ-/*O/X`M-,E<]>JMZ*UQ-/*O/X`U]2VK]>JT,4`T,?&VL[E`+>HN?H`MZC*
M]+GGT<?$QP"WJ,KTLJ/`^\3ASO?1QP"WHKS^R,L`MZ*\_LC+M=C6MP"TTP#-
MZM7[P^C*]@#"^M3"`,BKP_L`O-/%[@"XU+'(T<<`LOK)^B`E<R"UQ,^US;/%
MY-;#`+CQPK.\JM''`+7"N?H`Y<C$R0#6L;*\PM[-TP##^P!';V]G;&4@R]'+
M]P"[TK;(`,^CP+``SZ/`L,[$("A)4T\M.#@U.2TW*0"X\<'JP+P`N/'!UL3)
MM.\`T\.[I]?IN=S`[0#3P[NGU^G#^[/&LKNUP[_5L-<`T\.[I]?I`+G/M<+"
MWL;5M;H`N=BUN@#.H[78PNW`K0"X\;;WSO>UN@"WP[_-R*C/W@"WP[_-P?31
MU`"\N,3:T<<`O+C$VM''L<C)W+FRNLVY^@"YY]''Q,<`U=*RN[6]($A45%`@
MT>G6I"X`NJ.UV`#4T[35+<OCMZ@`L>W-MP#3RKS^S;<`NM6UPKK-PO2UL<#-
MR+JUN@#/H[*NP+3.Q"`H25-/+3@X-3DM."U)*0"P[];Z`+'@O*W&]\JYT\.P
M[];Z`+#OUOH`U>+`[\K'SL2\_K7$OZK*O#H`TOZRV-+1R;ZS_;7$`-+^LMC.
MM+:IU,2UQ`#H\[79N-0`RM?2LP#*U]*SM=C6MP#*U]*SM>>[L`"ZZ;:\P*W+
MN0#6T+GZS^.XVP!(;W)D90#+KL:]S]\`Q.//H\W[R.>ZSL_4RKZXO;S^/P#7
MUK;.ROW$O[FRO,8_`,JJML@`RJJVR#H@`-#9T<#`^P!)34%0(-/*S^2]J,&B
MRJ>PW#H@)7,`24U!4"#3RL_DR;ZS_<JGL-PZ("5S`$E-05`@T\K/Y+3%Q<S%
MY-;#O:C!HLJGL-PZ("5S`,K5O/[/Y`!)4""UV-:WSMZWJ,JYT\,N`$E0(+78
MUK>RHK*[U-H@0TE$4B"UQ+W3RMS'^+_IUM`N`+'YM;H`UKO3T,V\L>H`S;RQ
MZKRPSL37U@"Z]L+4`+KVPM3+^=/0`,G/M*O-O,:L`,V\QJP`M;S(Z\/<U+\`
MM;S(Z\/<U+^VU`"UO,CK4$=0P]S4OP"UO,CKN/;(R\N]R,M01U##W-2_`+6\
MR.NX]LC+N:NYLE!'4,/<`+6\R.NYJ[FRP]S4OP"UO,CKN:NYLE!'4,/<U+\`
MN^/(ZRP@LKW6Z"`E9`#6V-*J`-;8TJK3RKS^`+OCR.O7UK;..B`E<P"[X\CK
MU]:VSCH`U-J[V+BTUM"P_+JLU*W*O-/*O/ZCOP#*Y,CKLKO5_<BWM<37]]/#
MPNLN`-3VO-/+]<7%`-.AML@`N/:Q\-/#NZ<`TZ&VR,3ASO?1QP#0Q<^B`+G8
MT]JYJ[FRP]S4OR5SM<30Q<^B`+G8T]K+O<C+P]S4O[7$T,7/H@"YV-/:N/;(
MR[FKN;+#W-2_M<30Q<^B`++ER.NQ[;CQ`++ER.O-^,+GP:R]TP"RY<CKO\G,
MYK3ZQ*.PY@"RY<CKT\J\_@"RY<CK+['DN/S-O,:L`++ER.LOL>2X_,WXPN?!
MK+W3`-7[ROT`U?O*_<'0`+?'MZBUQ-3+L\S3RL_D`,[>T*>UQ"!51$@HT\.[
MI\K]OMVQ[<VW*2X`SM[0I[7$TZ;3P[/,T/(N`,[>T*>UQ,7ZM,ZZQ<+K+@#,
MX;V[M<3*_;[=SM[0IRX`SM[0I[7$Q+^QZM>AUK<`LKNZS[>HM<3.Q+S^N/'*
MO0#.WM"GM<0@;7-G7W1Y<&4N`,[>T*>UQ+ORU=*RN[6](&%P:5]I9"X`SM[0
MI[7$N_+5TK*[M;VRSLK]+@"RN[K/MZBUQ+BXR*C/WBX`M\>WJ+7$N/;(RU!'
M4,N]R,O#W-2_`+?'MZBUQ+CVR,M01U"YJ[FRP]S4OP#.WM"GM<3-J-&VT*W2
MZ2X`SM[0I[7$P+34M->AUK<N`,[>T*>UQ,WRT\/"Z\K]OMTN`-+!P,K2P<NY
MP+RYLKK-N?H`TL'`K;_+`+"NMOO`O`#"_+6Z`-+4R:O!T`#'J;>BU=\`T+',
MY0#2XK3SP/L`T<#"\KS3`-*[U,(`2F%P86X@*,C5L;XI`,C5SL0@*$E33RTR
M,#(R+4I0*0#4\\[WM;H`U+RUJ0#&W]3"`,'YU,(`UL/6T`#7\]/2MM3&ZP"_
MO]?SMM3&ZP"_O]/2MM3&ZP"Y_LCXO\O+N<RY`+&CP?34K='Y(#\`O\_$X=''
M`$ME<F)E<F]S(,C/UJ2T[<[S+@##W-2_O:C!H@##W-2_S-C5]P##W-2_LZ2V
MR`##W-2_P.#0S0##W-2_T^^WJ`"UL<>PM<2YJ[^JP]S4O[?^SO'&]];0+-+1
MOJVTYM3:Q/JUQ,/<U+\N`+OYP.^PS<NYN;*ZS;GZ`+.OS\H`NJNY^@"ZJ\[$
M("A%54,M2U(I`+_&S?[,V`"\JK;[O*K+N<RY`-/OT=0`P,_.S@#/PK#KU,(`
MU^ZZ\]*[TK,`S\+/TM3"`,G/M,ZX_-#".@#)S]*[M,ZUQ\*\.B`E<P#)S]*[
MM,ZUQ\*\.B`E<R#7U"`E<P#)S]*[M,ZUQ\*\.B"UVM*[M,ZUQ\*\`,"MS='.
MK-''`+#FP^;%Y-;#`,#HL,W$VP#`L\OWS=``P/NQR,#OT<<`P/NQR-''`,'0
MUJ>VV,J_M<<`P:R]TP#!K+W3`,'0L_8@+2#3P[NGO\G2U+^TM;W5XKCVSL2\
M_KS0`,'0L_;+M</WL>K,X@#,UL+;T\.[I]?I+<[$O/ZY\0#,UL+;T\.[I]?I
M+<?SUOH`S-;"V]/#NZ?7Z2W*MK'PNL7"ZP#,UL+;T\.[I]?I+=.UT]#5WP#,
MUL+;T\.[I]?I+;S$O/[(RP#,UL+;T\.[I]?I+;:IU,0`S-;"V]/#NZ?7Z2W(
MH<_[MJG4Q`#!T+/VT\.[I[7$N:;$W+&[N=BQU0#.Q-&G`,&BS-7-\`"QOK78
MT\K/Y`"UL;78RK&\Y#H@`+78Q_C3Z\JQO.0`M<?"O`"UQ\*\M;TE<P#7HL_Z
M`+7'PKS(SL[Q`+7'PKS*I[#<+"#'Z[SLLNG$^K7$T\.[I\/[NLW#W,+K+"#(
MN[KSUMC*U"X`M<?"O,JGL-PN`,*LR:VQI`#4P@##O\C5T,7/H@!-4RU43D5&
M(+B]O-/.Q+S^UM##N]/0ROV^W2X`35-'`-;0N?JPQ,/%`,+MQN2VV;FRNLVY
M^@#"[;3OO-/+N;S3M;H`T\J\_KG<P.T`T\K/Y`#"[<"MS?X`PNW`M,[WT<<`
MPNVV^[3ZM_(`PNW`^P#"[;;ZR_L`R/W4P@"QZKS'SJJCN@"QZKS'L\D@O[2Y
M_2_.M+^TN?T`L>J\Q[/)QN3+_+7$RK:Q\"`HP/W(YRX@UMC2JB_2T;O8N+0I
M`,+MR=RV^\BZM;H`PNW,X<3AO\NUN@#5_=3:QJ7%Y-?6MLX`PZO`[\O^Q.'1
MQP##J\#OQ_/+N0"XO;S^ROW$O]+1LZRS]KW3RMS)S\_>+@#7[KW\(#(T(-"A
MRK&UQ-?NN-_.PK;(.B``U^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B``O=/*W-?N
MM/.SI+;(`,[EU,(`PNW4O,S8R+JUN@"SR=2Q`-&AM:7$H\J].@#0M-/*O/X`
MT\J\_LC5QMH`T\J\_K+IU=(`T\J\_K3ST*$`U*W*O-#%SZ(`T\J\_M'IUJ32
MT<WJL\DLM:O*Q]/#NZ>UQ,>IP_O(M,[>MZC-J+G]T>G6I"X`T,7/HM+1N?W&
MVBX`T\J\_K'JUKX`T\J\_KS0`-#%SZ+`X-#-`,._TK//U,J^M<33RKS^ROTN
M`-/*O/ZUO0!-971A<B#'^+_ISMZWJ,JYT\,N`$UE=&%R(,?XO^G.WK>HRKG3
MPRX@S[B]VL?KLLZ_O,^US;.YW,#MM<?"O"X`M[VWJ`"YJ];&`,2KSO>XYP##
MW+_+PM[$X<[WT<?!JK#NN?H`36EM92#`X-#-`-?NO?P@,C0@T*'*L;7$U^ZU
MS<["ML@Z(`#7[KW\(#8@T*'*L;7$U^ZXW\["ML@Z(`#3L\GD`,7DUL/.Q+S^
MTL7*IRX@R.>Y^]*JRKG3P]7BN/;3IM/#L\S0\L3ZL=C0Z\_6U-J^S;+ZR?K+
M^RX`U=*RN[6]T,7/HK7$($E$+@#5TK*[M;V[X<;:M<0@240N`-#'QMK2NP#0
MT+:OT\J\_@"X_-#"R-7&V@"QX+RM`,2CO^D`Q*:V^[;@S=\`Q*;$R;CG`,/)
MN<4`U,*ZS<3J`,._U,(`P\G,V,C[P*W,V`#4PL'!TZ^_]P#$IL+EN.<`TL:V
MKP#/PM+&`-?STL8`T]+2Q@#)S]+&`,2JR:.QR+_+`+BTT:$`SM*UQ-7+NL4`
MSM*UQ,/%NZ<`SM*UQ,/%NZ?2L\/FQ>36PP##Y;7I`+*[+,[2LKO-K-+B`,/[
ML\8`Q,G#U['(T<<`Z*?"LP#$X;*TMOL`NLG`O`"ZR<KTL+*UV,'0R[D`N_G3
MVDYE='-C87!E(+7$S?C6MP!.971S8V%P92!34TP@M_[.\<;WP_NSQ@!.971S
M8V%P92#(S]:DM<3%^M>B`$YE='-C87!E(,C/UJ3`X-#-`,WXPN<`M-/`M,.[
MT]``T,(`T,*_IL#OMN#$X=''`-#"T\J\_@#0PM3"`-#"T\.[I\/[("BWQ['8
MTJHI`-#"SO?`O`#0PM/*O/X`T,*TL+_:("A?8FQA;FLI`-#"SL4`S\(`S\+2
MN[?B`,_"TKO2LP#/PM*[N/;1H<_N`,3AO-/`K;G/`,3AR-6V^P#$X<C5P/O1
MQP#-[<G/`,6FL*.UN@"RNP##N]/04$=0N:NYLL/<U+^UO,CK`,OYUKBVJ+7$
MSKO6P\G/P[O3T,?XO^FTYM3:`,.[T]#,X;FIR-7`^L/[L\;2U+FI($U#04P@
MT>G6I"X`P[O3T-:XMJBUQ"`E<R#%Y-;#T,7/HBX`P[O3T-:XMJBUQ"!&5%`@
M5D93(,7DUL/0Q<^B+@##N]/0UKBVJ+7$(%-13"!61E/%Y-;#T,7/HBX`P[O3
MT-:XMJBUQ"!344PM1FEL92!61E/%Y-;#T,7/HBX`SL2\_LZTR<^TJP##N]/0
MUKBVJ,[$O/Z\T`#.N];#T,7/HLG0SK3%Y-;#`,.[T]#6N+:HP]S"Z]+4N:D@
M2%144"#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI($E-05`@T>G6I"X`P[O3T-:X
MMJC#W,+KTM2YJ2!+97)B97)O<R#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI($QO
M9VEN(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4N:D@4$%34U=$(-'IUJ0N`,.[T]#6
MN+:HP]S"Z]+4N:D@4TU"(-'IUJ0N`,.[T]"T_<GSM<37HK+AR>K'ZRX`P[O3
MT-/OMZBT[<[S`,[>U-VTYL2_PKR_R;FIO^S(H2X`P[O3T+K/MZBUQ"!834P@
MROV^W;&[M*N[V`"_U;#7UK4`U*W*O,7DUL/.Q+S^UM#5TK*[M;VPYK&^T,7/
MHBX@UMC0PK+ZR?K%Y-;#SL2\_BX`U-K$^K7$Q>36P\[$O/[6T-72LKNUO;#F
ML;[0Q<^B+B#6V-#"LOK)^L7DUL/.Q+S^+@#(U;;ZPOS.Q"`H25-/+3@X-3DM
M,3`I`,6UN*._R[6Z`+&QL.O'\@"QL<+MP._1Q\3)R+JUN@#%LLW^`+?'UJZZ
M\P"WQ]:NQ[``P[O3T,F^L_VUQ`"RN\K'LMVXY0"RN];8TJJUQ`"RN\K'N/;(
MR[7$`+*[RL?2N[CVQ+_"O`"RN];8TJJUQ-/*O/X`SK2QN]:GL]8`L;C-_,*\
M`,JNTKO4P@#*_=?6`-?6M_O*_0#7UK;.ROW$OP"QRLK]`,BWMJ@`MM3/\[VH
MP:+5WP"PR[WXSKL`RJ[4P@"P[+FKRM(`OLG3RKS^`+"BPOP`UKO3T"!)34%0
M(+?^SO'&]]:GL];.Q+S^O-"YLL_MN:;$W"X`UKN]T\K<TKNX]M/*O/ZUV-:W
M+@#6N]/0T[73T-7?T^O/M<VSN=S`[=2QO\G2U+'DN/RYLL_MR*C/W@#4VM#"
MM+"_VM;0M/*_J@#1H<_N`"5S(+7$T:'/[@#/[L2_L>"ZQ0#7Z=:O`-?IUJ^U
MI<Z[`-2MRKS3IM/#L\S0\L2CL.8`U-H@)7,Z(-;0M<34K<J\Q*.PYBX`QN3+
M_`#&Y,O\T,7/H@#&Y,O[T:'/[@#3M=/0U=_(J,_>`%!!32#1Z=:DSM[0IRX`
M4$=0(,K]U];'J</[`%!'4""\T\/<U\K!SP!01U`@N:N_JL/<U+\`4$=0(-+1
MQZG#^R_2T;S3P]P@U\K!SP!02%`@L\S0\K3ZPNL`4$A0(+W%L;X`M=H@)60@
MTK.YLB`E9"#2LP"PS;OYR[G,N0#%P<#-`+#-P-7+N<RYL;O5O,'LQ_@`L,W$
MP\+M`+#-LKS1Q]#"O+C$VM''`+#-P*VYYP"XO;S^`,/<PNL`P[O3T-:XMJC#
MW,+KTM2YJ2!2041)55,@T>G6I"X`P]S"Z\BWR,\`P]S"ZSH`P]S"ZSH@`,/<
MPNNQV-#KSL>ZSRX`S/G)SP#,^<G/`,*WOK8`M/W)\[7'PKRCN@#6M-#0SJR[
MI++9U_<`R*C/W@"TYLBAU.*^W`#(J,_>`,BHS]ZYW,#M`+CVR,NUQ`"X]LC+
MT,7/H@"X]LC+4$=0P]S4O[;4L\FYILGZL\FAHP"X]LC+4$=0P]S4O]+1OJVS
MR;FFR;ZS_:&C`,/8PK,`M\;"R;'V`+7GN[``U=7&K`#&I,S8O[6UN@#'Z\KD
MR.O2N[CVU,*WW;RPQ.JWW2X`Q^O*Y,CKTKNX]KK/MZBUQ,C5QMH[T:'4\;3+
MU,*WW;7$R-7&VBX`Q^O*Y,CKNL^WJ+7$RK&\Y"X`Q^O*Y,CKT,*UQ,[$O/Z\
MT+7$P_NSQJ.Z`,?KRN3(Z]#"M<3#^[/&H[H`Q^O,X;FISLK,XK7$U:K2JBX`
MQ^O*Y,CKQ/JUQ-/#NZ?#^[RPP]S"ZP#'Z]&AU/'$X]*JLMG7][7$SL2\_KS0
MH:,`Q^O1H=3QUL')V=*[N/;2JK+IU=*UQ,[$O/Z\T*&C`,?KUKO1H=3QTKNX
M]L3CTJJRV=?WM<3.Q+S^O-"AHP"RJ,"\`,VVQK$`QL_,T='``+7=R\W3RKS^
MM;W5XKCVSL2\_KS0("AN;W0@96YF;W)C960@8GD@24U!4"D`U^Z]_"`E<R#0
MH<JQM<2]M=/JP;\Z(`#%Y-;#T,7/HM+1OJVWX;FFN/RXQ*&C`%!R969S7VQD
M87`Z(-72LKNUO<OYT.C2JK7$($Q$05`@P*G5N=?IO/XN`%!R969S7W-E<W-I
M;VXZ(-72LKNUO<OYT.C2JK7$('-E<W-I;VX@P*G5N=?IO/XN`,;XT;D`NJ/&
MO</FQOC1N3H@`,;XT;DZ(`#)S]*[M^(`R<_2N[?B`,G/TKNX]M&AS^X`M/+3
MH0#+O</<P]S4OP#.RLSBP^C*]@#7J+"X`,SARK[$VLC=`-"MTNFCN@"YJ[^J
MP]S4OP"YJ[^JP]S4O]'=R^,`N:N_JB_+O</<P]S4O[;4LJ+.M+&[LOK)^BX`
MLJBVX,#HN/<`OZC+_K;[`%)302"YJ[^JP]S4OR`H)60@SKLI`+6ET:$`L<C"
MR@"VP<BA`+;!R*'3RKS^`-7FM<32JLF^L_T@)7,@PO`_(-7BS^ZRV=?WO:O.
MWK>HN]:XM"X`UMB\Q`#6V+S$T\J\_@#6V+S$N,/3RKS^`-;8O,33RKS^RJ>P
MW*&C`,BAS_NXM-2M`,NBT,(`RZ+0PL/%NZ?*T\V\.@"YYM3RL>VT[\J]`,;`
MPML`U+:SS-/*S^0Z`-2VL\RW_L[QQO<`U+:SS,WXUK<@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@#)OK/]`,F^L_W'^+_I`,F^L_VVU`#7U+?^
MSO'&]]3=M.;$O\*\UM#)OK/]TM&QH[3FM<3%Y-;#L\S0\BX`R;ZS_=/#NZ<`
MR;ZS_=/#NZ<Z("5S`,SFN[O.JJ.Z`+3PN+0`M/"XM,OYT]``M/"XM,OYT]"C
MN@"[V+BTM;W3RKS^P="Q[0"[V+BTM;VCN@"[V+BT`-#HQ_/.M+&[S^S3ICH@
MM.W.\[K%PNLZ`-;8UL,`O>&Y^P"[UKBT`,F^L_VAHM+&MJ^AHKBTUL;3RKS^
MNO.WM;O8M;W3RKS^P="Q[=;0H[\`4F5U;FEO;B`HP?3$X<WZM;HI`%)O;6%N
M:6$@*,+>PNW$X=''*0#0_=>J(#$X,""VR`#/\M?ST/W7J@#/\M/2T/W7J@#6
MM-#0`%)U<W-I86X@1F5D97)A=&EO;B`HMNW"WLNY*0!2=V%N9&$@*,*LL+*T
M[RD`4R]-24U%(+S3P]S'J</[`-/*O/[2T<JYT\,@4R]-24U%(+S3P]P`4T%3
M3"#1Z=:DSM[0IRX`T,7/H@#*_;[=O^*]Q;&^`+S3P]S6U;;+N_H`L\FYI@#0
MQ\;:P?D`RJ6ZU<#5Q,.UN@#*I;OYM<*ZS<'0SJS+N0#*I<*LSO?1Q[6Z`,JE
MQJ2PH[;[NLW"\[_+PM?(NK6Z`,JESL3)K<S8NLVX\<'6Q,FT[P#-K-*[N/:T
ML+_:("A?<V5L9BD`R/C$IM''`,JEPNW!IL6U`,JEMN##P+K-QM7!UL[WL<@`
MSL#0Q\SAN:G5WP#)L\S8L*+`K;*N`+&CM.8@)7,`M.;.JK+=N.4`L:.TYM&A
MS^X`P>VTYLZJ`+VKLOK)^K7$Q>36P\[$O/[2U"!02%`@T^_1U+CQRKVQH[3F
MM;W$^K7$M_[.\<;WU-VTYL2_PKS6T"X`Q>36PR`E<R#2T;&CM.8N`+&CM.:R
MW;CERJ>PW*.LM_[.\<;WN]C3IM#%SZ+(Y\_"H[HE<P"RZ=72`++IU=*]X;G[
M`-+1U,2VP0#1H=3Q`-&AU/'2N[CVT\.[I]?IT\/2U-#"U/8`T:'4\=*[SKO0
MPK7$T[73T-7?`-&AU/'2N[*_M_[.\<;W`-&AU/'2N\Z[T\.[I]/#TM30PM3V
M`-&AU/'+^=/0`-&AU/'+^=/0R-7&VM?IO/XN`-&AU/'2N[CVU<JZQ0"RN]&A
MU/$`T]K2U,_"M<2TL+_:UM#1H<BAQ/K2JK7$U]:W^R[2U,KSL>JXM-;&R_G1
MH<[$U]8LR+NZ\\SYR<_.Q+S^L>"\K<?X+@#1H=3QR-7&VK?6N/0Z`-&AU/'(
MU<;:R-7&VKCQRKTZ`-&AU/'*L;SDM]:X]#H`T:'4\<C5QMK*L;SDN/'*O3H`
MT:'4\<_@NZ7&I<7DM<2V_KCVU]:VSBX`T:'4\<3ZM<31U<FKQ>36PP#1H=3Q
MQJNZP]/OT=0Z`+>BR\W3RKS^`+2KR\W.RLSBM[33I@!396YE9V%L("C(^\3:
MO-.V^RD`M*NXT,;W.B``OL74P@!397)B:6$@86YD($UO;G1E;F5G<F\@*,C[
MMOO.K-''T^O#R<S8Q.&XY\+>*0#0\KK%`+?^SO'&]P"W_L[QQO>CN@"[X<;:
M($E$(-+1N?W&VBX`Q>36PP#%Y-;#U+:SS+?^SO'&]\G/RO33VL3ZM<2X]LC+
MU;[,J"X`Q>36P\3ZM<3&J[K#T^_1U"P@RK''^-+4O+#(U<;:N/'*O2X`Q>36
MP\3ZM<3&],J\TZ;3P[/,T/(LT=7)J\7DUL,LTK/#YKC\T,+&M<+*++RPQN3+
M_,_4RK[1H<_N+@#3T+K#O+BX]K78M>.ZS=7BN/:RSLK]T]"YV#H@`%-E>6-H
M96QL97,@*,C[SO2V^RD`N;K.[P"\\K;,U:K2J@#*Q[?QSJJT\[*_M]VUQ,&L
MO=.VJ-+EO^R]W;FFQ-R\_#\`S]3*O@#/U,J^R_G3T-/*O/[-MP#/U,J^TM')
MOK/]M<0`S]3*OM/*O/[!T+'MT,7/H@#/U,J^SK2VJ=3$M<0`P[^TSK7'PKRZ
M\\_4RK[)S]*[M,ZUQ+7'PKS*L;SD(#\`S]3*OK7CT:'&]P#3VM?SL=_/U,J^
M("5S(+++M:4_`,K5R_4`4VEE<G)A($QE;VYE("C*J-?3R;VY^BD`UZ*RX0#'
MJ</[`,>IP_O1W<OC`%-I;F=A<&]R92`HT,*\T\;"*0"T\]"A`,+4N?W.K+ND
M`%-L;W9A:VEA("C+N<+EMZ6_RRD`4VQO=F5N:6$@*,NYPN6WI<3AT<<I`+O]
MT:G)[K;(.B``4V]L;VUO;B!)<VQA;F1S("C+]\+>P\7(NK6Z*0!3;VUA;&EA
M("C+]\+MP/O1QRD`Q<7!T+>]S_+1H=3Q`,"TU+2UV-:W`%-O=71H($%F<FEC
M82`HQ,^WQRD`Q,_%MR`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`Q,^PZ\?R`%-P86EN("C.][#@
MT<`I`,"LN_C3RKS^`,S8RN+7UK?[RN3(ZP#,V,KBU]:W^P#&M-"TO.RRZ0#&
MM-"TO.RRZ<WJL<\`4W)I($QA;FMA("C+N<#OP+R_J"D`L>K7O`#&],J\Q.JW
MW0#*H0#7M,RL`+&CM.:X\<J]`+W6M<``R;ZS_<_?`-?6M_NTKL'0`-#'QMK,
M[`#6]\SB`-;WS.+7UK;.`,SAO;L`S\*QZ@"SR;FF`-+1L\FYIKBRN,<@)7,`
M4W5D86X@*,O5M:0I`,C5L_8`R-7"Y`#(U;/V`,C5L_8OR-7"Y`#(U;/V.B``
MR-7"Y`#(U<+D.B``R<^QZ@#6I[/6`%-U<FEN86UE("C+U<#[Q,\I`+3"NL4`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0@*,JWS=^\P\"\*0!3
M=V5D96X@*,CPM>0I`%-W:71Z97)L86YD("C(\,J_*0!3>7)I86X@07)A8B!2
M97!U8FQI8R`HT/#`^]''*0!404(@M]:X]+CQRKW.Q+S^`,RHS>4`S*C-Y0!4
M86II:VES=&%N("C+_KRJR[G,N2D`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9B`HS+G)T,3AT<<I`,2_L>HZ`+3]L.S*PL_N`+7GN["ZQ<+K`-?NO?S2
MN]"ARK&UQ,["ML@Z(`#.PK;(`,["ML@Z(`#$H[#FN=S`[0#.Q+&^`+2_SL37
MU@#0Q\;:R\0`S*G.Q"`H5$E3+38R,"D`5&AA:6QA;F0@*,RIN?HI`-"[T+O$
M^LJYT\.QOL^US;,N`$944"#1T\GL*&5X=&5N<VEO;BG.WM"G+@!-86EN=&5N
M86YC92#`X+'PLJ+.M+/)N:;4V,CK`-&AS^ZTL+_:TM2YV+'5+L#KOZK6T"X`
MU<JZQ2(E<R+2T;ZML;O)OK/]H:,`U<JZQ2(E<R+2T;ZML;NQH[3FH:,`M;''
ML,[$O/Z\T"(E<R*]J[&[N,3#^\ZJ(B5S(J&C`-'IUJ33RKS^QZG#^]#HTJK3
MT-*[N/;2T;WBOZJUQ"!01U`@Q_B_Z2X`T.C2JM*[N/:^K;G]O-/#W+7$S?C"
MY\&LO=,N`,[$O/X@)7,@TZ:XP[#\NJS2N[CV("5S(,7DUL,N`,[$O/X@)7,@
MTZ:XP[#\NJS2N]"I("5S(,7DUL,N`+3+SL2\_M;0P[O3T,K]OMTN`,[$O/Z\
MT"(E<R+2T;ZMM.;4V@#.Q+S^O-`B)7,BTM&^K;/)N::TM+VHH:,`SL2\_KS0
M(B5S(M+1OJVSR;FFR;ZS_:&C`,[$O/Z\T"(E<R+2T;ZML\FYIKC$P_O.JB(E
M<R*AHP#2U,_"RL<@<F9C.#(R(-/*O/ZUQ+'MS;<N`$=N=5!'(+;^U*K.Q+S^
MM<3"M[ZVL=C0Z[:HTN74VB!#<GEP=%]P9W`Z.B#`X+'PUM`N`$AO<F1E7T-R
M>7!T7W-M:6UE.CH@P."Q\"RQV-#HTJK3T"!O<&5N<W-L(,2CO^DN`+3+QJNZ
MPR`B)7,B(,K]OMW2\LZJLZRY_=?NM/.]T\K<UK4LR_G2U,[>MZBQN[&CM.8`
MT\/2U+SLRM.TR\K]OMW`X-#-("@E<RD@M<2SS-#RLJ*RN[3FU-K3VL^US;/)
MSRX`M,NW_L[QQO<@(B5S(B#2T;&[R;ZS_2X`M,NW_L[QQO<@(B5S(B#2T;&[
ML:.TYBX`)7,@M<37HK+AT.C'\]+1L;O)OK/]+@#6N+:HM<2\Q\*\LJ*RN[3F
MU-HN`+33R<_2N[CVLKW6Z-:NNO/)S[2KM<3*_;[=TL7*IRX`R<^TJ\[$O/ZR
MHLZTL;NQH[3F+@!W96%T:&5R+F-O;2#'^+_ISMZWJ,JYT\,N`-3:N,/3RL_D
MUM##N]/0R,ZZSM/*O/X`SMZXO;S^O\G6L;W3M/*_JBX`M,O7UK;.UM"P_+JL
MS*NVX+7$U];*_2[$^M+1RN3(ZR`E<R"X]M?6ROT[Q/K*Y,CKM<37ULK]L=C0
MZ]"AT]H@)7,N`,G/M*O.Q+S^RK&WHLGZTKNX]L[*S.(Z("5S(,ZTL;O)S[2K
M+@#)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB.B`E<R"T\]"ALZRY_;W3RMS7[K3S
MUK4@*"5D(&)Y=&5S*2X`R<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@O?:RO[?6
MM<0@)7,@SL2\_K&[R<^TJRX`N^/(Z[3+S:C1MK*^ROV^W<JQMZ+)^K3MSO,N
M`-3:Q>36P[2PS.76T+>BR?K!R]*[N/:T[<[S+M/0O\G$W,3ZTL7"J<'+L=C0
MZ\SNT+2UQ-?6MLXN`+3+($E-05`@M_[.\<;WLJ+.M-:GL];.Q+S^O-"WUL_M
MN:;$W"X`U>++QKKULKO*Q]7]R+>UQ"!R87(@T;G+]<[$O/XN`-7BR\:Z];*[
MRL?5_<BWM<0@>FEP(-&YR_7.Q+S^+@#5XLO&NO6RN\K'U?W(M[7$T,73P[^H
MNL7"ZRX`M,O7UK;.RL>QV-#HTJJUQ"X`M,O7UK;.Q-K(W=:[O=/*W-7[ROW*
M_=?6+@"TR]?6ML[$VLC=UKN]T\K<ROW7UKRPP["ZQ2X`M,O7UK;.Q-K(W=:[
MO=/*W+#+O?C6QLK]UK4N`+3+U]:VSL3:R-VQV-#KSJJVNKK%N_*_U;#7M]:X
M]+7$ROW7U@"QV-#KRL?2N[CVROW7UBX`M,O7UK;.Q-K(W;'8T.NP_+JLTKO7
MZ<JNP?F]^-;&M<0@4D="(-'5R:NT^L+K+,#]R.<@)R,Q,C,T868G+@#5XKCV
MM+#,Y=+1L;NTIL#MN?TN`-7BRL<@)7,N`+C#T\J\_K6]`+3+ROW6M=?NR=FQ
MV-#KRL<@,2X`M,NW_L[QQO?.WK>HMM0@>FEP(+RP(&=Z:7`@N/'*O<[$O/Z]
M^-#0O>+1N<OU`+3+S[7-L[6QQ[#*Q\VCT\.UQ->TS*PN`+'8T.O*Q]*[N/;*
M_=?6+@"TR[2PO]JQV-#KTJK3R=&AS^ZTL+_:*$]P=&EO;BG+^;KTO=``RK&\
MY`#*L;SDU[?7V0#*L;SDN/'*O0#*L<?XT:'4\0!4:6UO<BU,97-T90"QZLSB
M`,K5O/[(RP#(Y[G[TJJXM-&A+,?KU-JUX]&ARO.QZK7$S:S*L;"T($-O;G1R
M;VR\_"BX]LC+O,;+X[OZ*2"[\B!#;VUM86YDO/PHQKNY^[S&R^.[^BDN`+WQ
MS.P`2%1-3"#4K<J\SL2\_@"VX+CG`,W0O\O`S<BZM;H`P_?,[`#,P+S3`,"L
MN_C/Y*.Z`,S8P:+$X;3ONLVVX+#-N.<`U>:[\KS9`-#'QMJV_@#-N\3AR[D`
MS<&V^L;D`,W!MOK&Y,[$("A)4T\M.#@U.2TY*0#-P;_BPOS+N<RY`,S8O\O+
MN;K-OZV_QLNYR+JUN@#-O,W?PJP`RN3(Z\3ZM<31H=3Q.B``U\_-XL_?UKC*
M_3H@`,WXUK<`S?C6MSH`SMJXR;3O`,[:O\O`O`#.WK>HM.;(H2!61E,@Q+_"
MO"X`UZ*RX<JQSMZWJ-3VO-.V[LWBM<33P[NGT,7/HBX`SMZWJ+C$L>0@5D93
M(,[$O/X@(B5S(B"UQ,BHS]XN`,[>MZBQY+C\(%9&4R#.Q+S^("5S+R5S(+7$
MR*C/WBX`SMZWJ+'DN/S.JB`E<RX`SMZWJ,&LO=/6P2!344P@M_[.\<;W+@#.
MWK>HRKG3PR!34TP@P:R]TRX`SMZWJ+BTUL8@5D93(,[$O/XN`,[>MZB]J,&B
M(%9&4R#$O\*\("(E<R(N`,[>MZB]J,&B(%9&4R#$O\*\+@#.WK>HO:C!HB!6
M1E,@SL2\_BX`SMZWJ+VKROV^W;WBT;G+]2X`SMZWJ,F^L_T@)7,LM,O$O\*\
MLJ*WQ[_5L-<`SMZWJ+7=N>G)OK/]Q+_"O"X`SMZWJ,F^L_T@5D93(,2_PKPN
M`,[>MZC)OK/](%9&4R#$O\*\.B`E<RX`SMZWJ,F^L_T@5D93(,[$O/X@(B5S
M(BX`SMZWJ,F^L_T@5D93(,[$O/XN`,[>MZBUW;GIR;ZS_2!61E,Z("5S+@#.
MWK>HQ="VS[6QQ["UQ,2_PKPN`,[>MZB]XK^JQK[6I,^XO=H`SMZWJ+S3U-@@
M)7,@M<2VJ-+EROV^W2X`SMZWJ-+&MJ\@5D93(,[$O/XN`,[>MZBT\K^J(%9&
M4R#.Q+S^("(E<R(N`,[>MZC0M,CK(%9&4R#.Q+S^+@#.WK>HM/*_JB!61E,@
MSL2\_BX`SMZWJ+3ROZK1N<OUSL2\_BX`SMZWJ+;!R*$@=F9S<F]O="#$O\*\
M+@#.WK>HL>2X_"!61E,@Q+_"O+7$P_NSQBX`SMZWJ,F^L_T@5D93(,2_PKPZ
M("5S+@#.WK>HL>2X_"!61E,@SL2\_B`B)7,B(+7$P_NSQBX`SMZWJ+'DN/P@
M5D93(,[$O/X@)7,O)7,@M<3#^[/&+@#.WK>HL>2X_"!61E,@SL2\_K7$P_NS
MQBX`SMZWJ->JN[L@5V]R9"#.Q+S^`,[>MZC0M,CK(%9&4R`B)7,B(,[$O/XN
M`,[>MZC0M,CK(%9&4R#.Q+S^ROV^W2X`SK2T\+BT`,ZTM/"XM+7$T\J\_@"[
MUKBTTM')OK/]M<0`S\*[KL_?`,BAS_NX_+C$`+BTU*T`M_[.\<;WP:R]T\JQ
MMZ+)^LZTU*3&VK7$N]C3ICH@`+>BR?K.M-2DQMJUQ+O8TZ8LT\FW_L[QQO<Z
M(`#-\M/#PNL@*%541BTX*0"PHL"MLJ[!JKK/Q_6SI+GZ`-.BN?H`P\"Y^@!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`M:74J@#.M-:J
MM<0`SK36JK7$T\.[I\/[N_+#W,+K+@#.M++IO[0`SK36I[/6M<3`J=6YP_L`
ML>2X_`"X_-#"("5S`+C\T,+3P[NG`+C\T,*SS-#RTM')OK/]+@#2T<G/M*O+
M^=/0TZ;3P[/,T/*UQ,7DUL/.Q+S^M;VW_L[QQO<N`,[:P*VYYP#3P[NG("5S
M(,ZTS:BY_2`E<R"UQ,K:R*C1Z=:D+@#3P[NGN=S`[0#3P[NGT:'/[@#3P[NG
MUZ*RX0"TR]6^S*BUQ-/#NZ?7HK+AS[7-L]+1S:/3PRX`T\.[I\/[`-/#NZ<Z
M(`#/M<VSUM"UQ-/#NZ<Z`,[:U\BQ\+_+R[G,N0!61E,@Q+_"O+*BLKNTYM3:
M+@"\V<;:`-+1U=*UO=/0T*>UQ+78M>,Z(`#3T-"GT-0`TM2WUM;3SJJUI<Z[
M*+33S];4VL;PR^,I`-:U`,W?PK.PHLV\`+'DNZ\`SJ_$VLCPP*T`T>G6I,JG
ML-P@+2"TR]/*O/Z_R<3<TM'4XLC+R</7U+3;N,0N`+#FL;X`L.:QOK_8UL8`
MU+W$SP#4O<3/SL0@*%9)4T-)22D`U-K0PK2PO]JT\K^J`-+4("5S(++IO[0`
MTZ+*],ZLMON^J<BZM;H`P\#*],ZLOJG(NK6Z`,3<O/NVR`#$W+S[ML@Z(`#2
MXK3SP/NW_+7"M^>UY]#%N:O+OLVXN?T@4TU44`"^K[CF`+ZON.8A(2$@M-,@
M)7,@RM:VK\F^L_VSS-#R+@#-W\#[R[FZS;B[S;S(NK6Z`-#'QMK(_0#,[,;X
MU*2RX@#-^-6^`,WXU;X`P[_6W`"[MM.M`+NVTZVUO2`E<P"[MM.M+"`E<P#.
M]\6W("A)4T\M.#@U.2TQ*0#.]\6W("A)4T\M.#@U.2TQ-2D`SO?(]KG^P*T`
MM<?"O+KSTZ:XP\_(S]3*OB`E<R#$Q-*[N/;3IM/#L\S0\C\`U]:VSK7$M]:X
M]-?6M_L_`-+]RO:UQ,>PM;RW^S\`M^?+V2B]VBD`M^?+V3H`M^?+V3H@`+#L
MN:O*TK78UK<`L.RYJ\K2M>>[L`!8-3`Y=C,@P*G5N</[`,3J`,3J`%EA:&]O
M("$@M=C-O`##O\3J`-*RP\4`RL>UQ"S.TLVLTN(`Q/JUL<>PRKG3P[2_SL37
MUK'@T+3$H\J]+B#*N=/#(%L\/ET@L+3%I;_)Q]"[N\ZJS?C2L['@T+3$H\J]
M+@#$^K*BSK3*Y,CKTKNX]KK/MZBUQ+7GU]/3RKS^M=C6MRX`Q/JRHLZTT\FU
MO,CKM<3.Q+S^UM"VU-.SR,ZZSM?6MLZUO2`E<P#$X]/0)7.WXM#"T\J\_@#$
MX]/0TKNWXM#"T\J\_@#$^M+1OJW7HL_Z+@#$^K'8T.O*Y,CKTKNX]KK/MZBU
MQ-:U+@#$^K'8T.O/R+GFNZZZP\K]OMW*]RA$871A5')E92FW_L[QMLNRQ<3<
MO,S0^,JYT\/0PM/#NZ?7HK+AM_[.\2X`Q^O#Z,KVSLK,XJ.LU-K$^K2KR\W.
MRLSBL:BXYM:NQ[`N`,3ZL=C0Z\KDR.NTR\&LO=/+^=:XS_*UQ,WXUK<`Q^O6
MN+:HTJK)OK/]M<2W_L[QQO<N`,?KUKBVJ-*JR;ZS_;7$T\.[IRX`Q^O6N+:H
MTJK0PM3VM<33P[NG+@#'Z]:XMJC2JKC\T,*UQ-/#NZ<N`,?KUKBVJ-*JUK30
MT+7$U_?3PRX`Q/JUQ"`E<R"[X<;:TM&Y_<JQ+L?KUMC0PK7'PKPN`,3ZM<2U
MY]?3T\J\_K78UK<`Q/JUQ-#%SZ(`U]2TT\3ZM<0@)7,@N^'&VK^JRKS2U,"T
MQ/JUQ-+RS-C-^+78UK?2T;'DN/PN(,ZJL:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQ
MV-#KUMC0PK7'PKPN`,3CM<3#^]?6`,3CM<3+O<C+P]S4OP#$X[7$N:NYLL/<
MU+\`Q..UQ-7*NL6CN@#$^K7$T>G6I+;+LJ+.M-:GL];!T+/VT\.[I[ORN,.Y
MIL3<TM&QN[G8L=4N`-?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<3DK\#`
MQO?+QKKUTM&QY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8T,*U
MQ\*\+@#$^K7$Y*_`P,;WLJ+.M-:GL];5XKCVN:;$W"X`Q/JUL<>PR_G%Y-;#
MM<3*L<?X.@#$^K7$T:'/[M+1N/S0PBX`Q/JUQ-2VL\RW_L[QQO<Z`,3CM<3'
MJ</[H[H`Q,_+N<"MM_(`U/K2P;;[`-3>L<C1QP"]\K#-LKS.I`!;SM[6]\SB
M70!;SLK,XK&HN.9=`%O.N]/:T-`@)7,@N;(@)7,@T-!=`,[$O/X`MZ*\_LC+
M`+33("5S("@E<RD@T]H@)7,@)7,`RK$Z`,&BO+0`R=#.M,JUS]8N`,G0SK3*
MM<_6+@"[\M7?`,:TT+2T[<[S`,:TT+2T[<[S`-39M,[*Y,CKQ/JUQ,/<PNO2
MU,BWR,_.WL[S`,ZTP_S#^P#3P[NGT:'4\0!V0V%R9`#0Q\;:.@!W96%T:&5R
M+F-O;2#-^-6^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]Z:%]#3B]H96QP+GAM;```````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R-C0T-P`Q,#0Q-S,V,C<V,P`P
M,C$Q,S<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!I;7`O;&]C
M86QE+WIH7T-.+VAE;'`N>&UL+'8@,2XQ-BXV+C0@,C`P-B\P,2\S,"`Q-3HU
M-SHU,"!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB8V]M<&]S
M92UB=71T;VYS(B!S=&%T93TB=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G
M92!#;VUP;W-I=&EO;CH@06-T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY!
M8W1I;VYS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!396YD($UE<W-A9V4@
M;&%U;F-H97,@>6]U<B!E;6%I;"!T;R!T:&4@:6YT96YD960@<F5C:7!I96YT
M*',I+B!"92!S=7)E('EO=2!W86YT('1O('-E;F0@8F5F;W)E(&-L:6-K:6YG
M(&AE<F4@87,@;VYC92!S96YT(&ET(&-A;FYO="!B92!T86ME;B!B86-K+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!3879E($1R869T('!L86-E<R!A
M;B!U;F9I;FES:&5D(&UE<W-A9V4@:6X@82!F;VQD97(@8V%L;&5D("=$<F%F
M=',G"F%C8V5S<VEB;&4@8GD@=&AE('!O<"UD;W=N(&)O>"!O;B!T:&4@<FEG
M:'0@<VED92!O9B!T:&4@8FQU92!N879I9V%T:6]N(&)A<B!A="!T;W`N(%EO
M=2!C86X@=&AE;B!F:6YI<V@@=&AE(&UE<W-A9V4@;&%T97(@8GD@<W=I=&-H
M:6YG('1O('1H92`G1')A9G1S)R!F;VQD97(L(&-L:6-K:6YG(&]N('1H92!S
M879E9"!M97-S86=E('1O(&]P96X@:70L(&%N9"!T:&5N(&-L:6-K:6YG(&]N
M("=297-U;64G+B!"92!S=7)E('1O('!U="!A('-U8FIE8W0@;VX@=&AE(&5M
M86EL(&)E9F]R92!Y;W4@<V%V92!T:&4@9')A9G0@<V\@=&AA="!Y;W4@8V%N
M(&5A<VEL>2!I9&5N=&EF>2!W:&EC:"!M97-S86=E('EO=2!W86YT('=I=&AI
M;B!T:&4@1')A9G1S(&9O;&1E<BX@069T97(@<V%V:6YG(&%S(&$@1')A9G0L
M('EO=2!A<F4@<F5T=7)N960@=&\@>6]U<B!)3D)/6"!O<B!W:&%T979E<B!F
M;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@("`@/"]P87)A/@H@("`@
M/'!A<F$^"B`@("!#86YC96P@365S<V%G92!D<F]P<R!T:&4@;65S<V%G92!I
M;B!P<F]G<F5S<R!A;F0@<VEM<&QY(')E='5R;G,@>6]U('1O('1H92!)3D)/
M6"!O<B!W:&%T979E<B!F;VQD97(@>6]U('=E<F4@=FEE=VEN9R!L87-T+@H@
M("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M
M<&]S92UB=71T;VYS(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET:6]N
M.B!!8W1I;VYS/"]T:71L93X*("`@(#QH96%D:6YG/D%C=&EO;G,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%-E;F0@365S<V%G92!L875N8VAE<R!Y;W5R
M(&5M86EL('1O('1H92!I;G1E;F1E9"!R96-I<&EE;G0H<RDN($)E('-U<F4@
M>6]U('=A;G0@=&\@<V5N9"!B969O<F4@8VQI8VMI;F<@:&5R92!A<R!O;F-E
M('-E;G0@:70@8V%N;F]T(&)E('1A:V5N(&)A8VLN"B`@("`\+W!A<F$^"B`@
M("`\<&%R83X*("`@(%-A=F4@1')A9G0@<&QA8V5S(&%N('5N9FEN:7-H960@
M;65S<V%G92!I;B!A(&9O;&1E<B!C86QL960@)T1R869T<R<*86-C97-S:6)L
M92!B>2!T:&4@<&]P+61O=VX@8F]X(&]N('1H92!R:6=H="!S:61E(&]F('1H
M92!B;'5E(&YA=FEG871I;VX@8F%R(&%T('1O<"X@66]U(&-A;B!T:&5N(&9I
M;FES:"!T:&4@;65S<V%G92!L871E<B!B>2!S=VET8VAI;F<@=&\@=&AE("=$
M<F%F=',G(&9O;&1E<BP@8VQI8VMI;F<@;VX@=&AE('-A=F5D(&UE<W-A9V4@
M=&\@;W!E;B!I="P@86YD('1H96X@8VQI8VMI;F<@;VX@)U)E<W5M92<N($)E
M('-U<F4@=&\@<'5T(&$@<W5B:F5C="!O;B!T:&4@96UA:6P@8F5F;W)E('EO
M=2!S879E('1H92!D<F%F="!S;R!T:&%T('EO=2!C86X@96%S:6QY(&ED96YT
M:69Y('=H:6-H(&UE<W-A9V4@>6]U('=A;G0@=VET:&EN('1H92!$<F%F=',@
M9F]L9&5R+B!!9G1E<B!S879I;F<@87,@82!$<F%F="P@>6]U(&%R92!R971U
M<FYE9"!T;R!Y;W5R($E.0D]8(&]R('=H871E=F5R(&9O;&1E<B!Y;W4@=V5R
M92!V:65W:6YG(&QA<W0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($-A
M;F-E;"!-97-S86=E(&1R;W!S('1H92!M97-S86=E(&EN('!R;V=R97-S(&%N
M9"!S:6UP;'D@<F5T=7)N<R!Y;W4@=&\@=&AE($E.0D]8(&]R('=H871E=F5R
M(&9O;&1E<B!Y;W4@=V5R92!V:65W:6YG(&QA<W0N"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M9G)O;2(@
M<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S:71I
M;VXZ($9R;VT\+W1I=&QE/@H@("`@/&AE861I;F<^(D9R;VTB/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!%;G1E<B!Y;W5R(&-O<G)E8W0@96UA:6P@861D
M<F5S<RX@66]U<B!E;6%I;"!A9&1R97-S(&ES(&%U=&]M871I8V%L;'D@96YT
M97)E9"!F;W(@>6]U(&9O;&QO=VEN9R`B1G)O;3HB(&EN(&]U=&=O:6YG(&5M
M86EL+@H@("`@/"]P87)A/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I
M9#TB8V]M<&]S92UF<F]M(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET
M:6]N.B!&<F]M/"]T:71L93X*("`@(#QH96%D:6YG/B9Q=6]T.T9R;VTF<75O
M=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@($5N=&5R('EO=7(@8V]R<F5C
M="!E;6%I;"!A9&1R97-S+B!9;W5R(&5M86EL(&%D9')E<W,@:7,@875T;VUA
M=&EC86QL>2!E;G1E<F5D(&9O<B!Y;W4@9F]L;&]W:6YG("9Q=6]T.T9R;VTZ
M)G%U;W0[(&EN(&]U=&=O:6YG(&5M86EL+@H@("`@/"]P87)A/@H\+V5N=')Y
M/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+71O(B!S=&%T93TB
M=6YK;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@5&\\
M+W1I=&QE/@H@("`@/&AE861I;F<^(E1O(CPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@861D<F5S<RAE<RD@;V8@
M=&AO<V4@=&\@<F5C96EV92!Y;W5R(&UE<W-A9V4N(%EO=2!M=7-T('-E<&%R
M871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$[(&]T:&5R('!U;F-T=6%T
M:6]N('=I;&P@<F5S=6QT(&EN(&%N(&5R<F]R+B!9;W5R(&5N=')Y(&9O;&QO
M=W,@(E1O.B(@:6X@;W5T9V]I;F<@;6%I;"X@(`H@("`@/"]P87)A/@H\(2TM
M($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UT;R(^"B`@("`\
M=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@5&\\+W1I=&QE/@H@("`@/&AE
M861I;F<^)G%U;W0[5&\F<75O=#L\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F('1H;W-E
M('1O(')E8V5I=F4@>6]U<B!M97-S86=E+B!9;W4@;75S="!S97!A<F%T92!E
M86-H(&%D9')E<W,@=VET:"!A(&-O;6UA.R!O=&AE<B!P=6YC='5A=&EO;B!W
M:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@66]U<B!E;G1R>2!F;VQL;W=S("9Q
M=6]T.U1O.B9Q=6]T.R!I;B!O=71G;VEN9R!M86EL+B`@"B`@("`\+W!A<F$^
M"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M8V,B
M('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O<VET
M:6]N.B!#8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB0V,B/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!%;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S
M*&5S*2!O9B!T:&]S92!T;R!R96-E:79E(&$@8V%R8F]N(&-O<'D@;V8@>6]U
M<B!M97-S86=E+B!397!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA
M+B!9;W5R(&5N=')Y(&9O;&QO=W,@(D-C.B(@:6X@;W5T9V]I;F<@;6%I;"X@
M0V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S96YT('1O('!E;W!L92!O=&AE
M<B!T:&%N('1H92!O;F4H<RD@8F5I;F<@=W)I='1E;B!T;R!D:7)E8W1L>2!B
M=70@87)E(&EM<&]R=&%N="!R96-I<&EE;G1S(&]F('1H92!E;6%I;"!A<R!W
M96QL+"!U<W5A;&QY('-O;65O;F4@:6YD:7)E8W1L>2!C;VYC97)N960@86)O
M=70@=&AE('-U8FIE8W0@;V8@=&AE(&5M86EL+B`@06QL("=4;SHG(')E8VEP
M:65N=',@86YD("=#8SHG(')E8VEP:65N=',@8V%N('-E92!T:&4@96YT:7)E
M(&QI<W0@;V8@8F]T:"!K:6YD<R!O9B!R96-I<&EE;G1S+@H@("`@/"]P87)A
M/@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB8V]M<&]S92UC8R(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@0V,\+W1I=&QE/@H@
M("`@/&AE861I;F<^)G%U;W0[0V,F<75O=#L\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@($5N=&5R('1H92!C;W)R96-T(&5M86EL(&%D9')E<W,H97,I(&]F
M('1H;W-E('1O(')E8V5I=F4@82!C87)B;VX@8V]P>2!O9B!Y;W5R(&UE<W-A
M9V4N(%-E<&%R871E(&5A8V@@861D<F5S<R!W:71H(&$@8V]M;6$N(%EO=7(@
M96YT<GD@9F]L;&]W<R`F<75O=#M#8SHF<75O=#L@:6X@;W5T9V]I;F<@;6%I
M;"X@0V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S96YT('1O('!E;W!L92!O
M=&AE<B!T:&%N('1H92!O;F4H<RD@8F5I;F<@=W)I='1E;B!T;R!D:7)E8W1L
M>2!B=70@87)E(&EM<&]R=&%N="!R96-I<&EE;G1S(&]F('1H92!E;6%I;"!A
M<R!W96QL+"!U<W5A;&QY('-O;65O;F4@:6YD:7)E8W1L>2!C;VYC97)N960@
M86)O=70@=&AE('-U8FIE8W0@;V8@=&AE(&5M86EL+B`@06QL("=4;SHG(')E
M8VEP:65N=',@86YD("=#8SHG(')E8VEP:65N=',@8V%N('-E92!T:&4@96YT
M:7)E(&QI<W0@;V8@8F]T:"!K:6YD<R!O9B!R96-I<&EE;G1S+@H@("`@/"]P
M87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E
M+6)C8R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M
M<&]S:71I;VXZ($)C8SPO=&ET;&4^"B`@("`\:&5A9&EN9SXB0F-C(CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE(&-O<G)E8W0@96UA:6P@
M861D<F5S<RAE<RD@;V8@=&AO<V4@=&\@<F5C96EV92!A(&)L:6YD(&-A<F)O
M;B!C;W!Y(&]F('EO=7(@;65S<V%G92X@66]U(&UU<W0@<V5P87)A=&4@96%C
M:"!A9&1R97-S('=I=&@@82!C;VUM83L@;W1H97(@<'5N8W1U871I;VX@=VEL
M;"!R97-U;'0@:6X@86X@97)R;W(N(%EO=7(@96YT<GD@9F]L;&]W<R`B0F-C
M.B(@:6X@;W5T9V]I;F<@;6%I;"X@0FQI;F0@8V%R8F]N(&-O<&EE<R!A<F4@
M=7-U86QL>2!S96YT('1O('!E;W!L92!O=&AE<B!T:&%N(&1I<F5C="!A;F0@
M:6YD:7)E8W0@<F5C:7!I96YT<R`H(E1O.B(@86YD(")#8SHB(')E8VEP:65N
M=',I('=H;R!N965D('1O(')E860@=VAA="!I<R!B96EN9R!W<FET=&5N(&%S
M('=E;&P@5TE42$]55"!T:&4@;W1H97(@<F5C:7!I96YT<R!K;F]W:6YG('1H
M870@=&AE>2!A<F4@<F5C96EV:6YG('1H92!E;6%I;"X@5&AU<R`G8FQI;F0G
M(&UE86YS('1H870@=&AE(&ED96YT:71Y(&]F('1H97-E(')E8VEP:65N=',@
M:7,@:&ED9&5N(&9R;VT@86QL(&]T:&5R(')E8VEP:65N=',@;V8@=&AE(&5M
M86EL+"!A;F0@;VYL>2!Y;W4@86YD('1H97D@:VYO=R!T:&5Y(&=O="!A(&-O
M<'DN(%EO=2!T>7!I8V%L;'D@=7-E('1H:7,@=&\@=&5L;"!A;B!A=71H;W)I
M='D@9FEG=7)E('1H870@>6]U(&%R92!T96QL:6YG('-O;65O;F4@<V]M971H
M:6YG('=I=&AO=70@86QA<FUI;F<@=&AE('!E<G-O;B!Y;W4@87)E('-E;F1I
M;F<@=&AE(&%C='5A;"!E;6%I;"!T;RX*("`@(#PO<&%R83X*/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](F-O;7!O<V4M8F-C(CX*("`@(#QT:71L
M93Y-97-S86=E($-O;7!O<VET:6]N.B!"8V,\+W1I=&QE/@H@("`@/&AE861I
M;F<^)G%U;W0[0F-C)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!%
M;G1E<B!T:&4@8V]R<F5C="!E;6%I;"!A9&1R97-S*&5S*2!O9B!T:&]S92!T
M;R!R96-E:79E(&$@8FQI;F0@8V%R8F]N(&-O<'D@;V8@>6]U<B!M97-S86=E
M+B!9;W4@;75S="!S97!A<F%T92!E86-H(&%D9')E<W,@=VET:"!A(&-O;6UA
M.R!O=&AE<B!P=6YC='5A=&EO;B!W:6QL(')E<W5L="!I;B!A;B!E<G)O<BX@
M66]U<B!E;G1R>2!F;VQL;W=S("9Q=6]T.T)C8SHF<75O=#L@:6X@;W5T9V]I
M;F<@;6%I;"X@0FQI;F0@8V%R8F]N(&-O<&EE<R!A<F4@=7-U86QL>2!S96YT
M('1O('!E;W!L92!O=&AE<B!T:&%N(&1I<F5C="!A;F0@:6YD:7)E8W0@<F5C
M:7!I96YT<R`H)G%U;W0[5&\Z)G%U;W0[(&%N9"`F<75O=#M#8SHF<75O=#L@
M<F5C:7!I96YT<RD@=VAO(&YE960@=&\@<F5A9"!W:&%T(&ES(&)E:6YG('=R
M:71T96X@87,@=V5L;"!7251(3U54('1H92!O=&AE<B!R96-I<&EE;G1S(&MN
M;W=I;F<@=&AA="!T:&5Y(&%R92!R96-E:79I;F<@=&AE(&5M86EL+B!4:'5S
M("=B;&EN9"<@;65A;G,@=&AA="!T:&4@:61E;G1I='D@;V8@=&AE<V4@<F5C
M:7!I96YT<R!I<R!H:61D96X@9G)O;2!A;&P@;W1H97(@<F5C:7!I96YT<R!O
M9B!T:&4@96UA:6PL(&%N9"!O;FQY('EO=2!A;F0@=&AE>2!K;F]W('1H97D@
M9V]T(&$@8V]P>2X@66]U('1Y<&EC86QL>2!U<V4@=&AI<R!T;R!T96QL(&%N
M(&%U=&AO<FET>2!F:6=U<F4@=&AA="!Y;W4@87)E('1E;&QI;F<@<V]M96]N
M92!S;VUE=&AI;F<@=VET:&]U="!A;&%R;6EN9R!T:&4@<&5R<V]N('EO=2!A
M<F4@<V5N9&EN9R!T:&4@86-T=6%L(&5M86EL('1O+@H@("`@/"]P87)A/@H\
M+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7-U8FIE
M8W0B('-T871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!3=6)J96-T/"]T:71L93X*("`@(#QH96%D:6YG/B)3=6)J96-T
M(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE('-U8FIE8W0@
M;V8@>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y(&9O;&QO=W,@(E-U8FIE8W0Z
M(B!I;B!O=71G;VEN9R!M86EL+B!+965P(&ET('-H;W)T+"!S:6UP;&4@86YD
M(&1E<V-R:7!T:79E+B`@5&AE('-U8FIE8W0@;&EN92!I<R!T:&4@96%S:65S
M="!W87D@9F]R('EO=2!A;F0@>6]U<B!C;W)R97-P;VYD96YT<R!T;R!R96UE
M;6)E<B!W:&%T('=A<R!I;B!T:&4@96UA:6P@86YD('1H=7,@:7,@=F5R>2!I
M;7!O<G1A;G0@:6X@;W)G86YI>FEN9R!Y;W5R(&5M86EL(&%N9"!F:6YD:6YG
M(&EM<&]R=&%N="!O;F5S(&QA=&5R+B`@06QS;RP@=VAE;B!Y;W4@)U)E<&QY
M)R!O<B`G1F]R=V%R9"<@86YD(&5M86EL('1H:7,@<W5B:F5C="!L:6YE(&ES
M(&-O<&EE9"!O=F5R(&EN=&\@=&AE(&YE=R!M97-S86=E(&%N9"!S;R!I<R!A
M('9A;'5A8FQE('=A>2!O9B!T96QL:6YG('=H870@;65S<V%G97,@9V\@=&]G
M971H97(@=&\@9F]R;2!A(")T:')E860B(&]F(&$@8V]N=F5R<V%T:6]N+B`@
M2&]W979E<BP@:68@=&AE("=297!L>2<@;W(@)T9O<G=A<F0G(&-O;G1A:6YS
M(&YE=R!I9&5A<RP@>6]U(&UA>2!W86YT('1O(&%D9"!S:6UP;&4@;6]D:69I
M8V%T:6]N<R!T;R!T:&4@)U-U8FIE8W0G(&QI;F4@<V\@=&AE(')E8VEP:65N
M="AS*2!C86X@9F]L;&]W('1H92!P<F]G<F5S<VEO;B!O9B!T:&4@(G1H<F5A
M9"XB"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)C;VUP;W-E+7-U8FIE8W0B/@H@("`@/'1I=&QE/DUE<W-A9V4@0V]M<&]S
M:71I;VXZ(%-U8FIE8W0\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[4W5B
M:F5C="9Q=6]T.SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@16YT97(@=&AE
M('-U8FIE8W0@;V8@>6]U<B!M97-S86=E+B!9;W5R(&5N=')Y(&9O;&QO=W,@
M)G%U;W0[4W5B:F5C=#HF<75O=#L@:6X@;W5T9V]I;F<@;6%I;"X@2V5E<"!I
M="!S:&]R="P@<VEM<&QE(&%N9"!D97-C<FEP=&EV92X@(%1H92!S=6)J96-T
M(&QI;F4@:7,@=&AE(&5A<VEE<W0@=V%Y(&9O<B!Y;W4@86YD('EO=7(@8V]R
M<F5S<&]N9&5N=',@=&\@<F5M96UB97(@=VAA="!W87,@:6X@=&AE(&5M86EL
M(&%N9"!T:'5S(&ES('9E<GD@:6UP;W)T86YT(&EN(&]R9V%N:7II;F<@>6]U
M<B!E;6%I;"!A;F0@9FEN9&EN9R!I;7!O<G1A;G0@;VYE<R!L871E<BX@($%L
M<V\L('=H96X@>6]U("=297!L>2<@;W(@)T9O<G=A<F0G(&%N9"!E;6%I;"!T
M:&ES('-U8FIE8W0@;&EN92!I<R!C;W!I960@;W9E<B!I;G1O('1H92!N97<@
M;65S<V%G92!A;F0@<V\@:7,@82!V86QU86)L92!W87D@;V8@=&5L;&EN9R!W
M:&%T(&UE<W-A9V5S(&=O('1O9V5T:&5R('1O(&9O<FT@82`F<75O=#MT:')E
M860F<75O=#L@;V8@82!C;VYV97)S871I;VXN("!(;W=E=F5R+"!I9B!T:&4@
M)U)E<&QY)R!O<B`G1F]R=V%R9"<@8V]N=&%I;G,@;F5W(&ED96%S+"!Y;W4@
M;6%Y('=A;G0@=&\@861D('-I;7!L92!M;V1I9FEC871I;VYS('1O('1H92`G
M4W5B:F5C="<@;&EN92!S;R!T:&4@<F5C:7!I96YT*',I(&-A;B!F;VQL;W<@
M=&AE('!R;V=R97-S:6]N(&]F('1H92`F<75O=#MT:')E860N)G%U;W0["B`@
M("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F-O
M;7!O<V4M;W!T:6]N<R(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE
M<W-A9V4@0V]M<&]S:71I;VXZ($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE861I
M;F<^(D]P=&EO;G,B/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&5S92!/
M<'1I;VYS(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M97-S86=E+@H@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("!#;&EC:R`B4W!E;&P@0VAE8VLB('1O(&-H
M96-K('EO=7(@<W!E;&QI;F<N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M($-L:6-K(")!='1A8VAM96YT<R(@=&\@=FEE=R!A="!T:&4@8F]T=&]M(&]F
M('1H92!P86=E(&$@;&ES="!O9B!F:6QE<R!A='1A8VAE9"!T;R!T:&ES(&UE
M<W-A9V4N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@($%C=&EV871E('1H
M92!C:&5C:RUB=71T;VX@;F5X="!T;R`B4V%V92!C;W!Y(B!T;R!S879E(&$@
M8V]P>2!O9B!T:&ES(&UE<W-A9V4@:6X@>6]U<B`B4V5N="!-86EL(B!F;VQD
M97(N(%-A=F4@8V]P:65S(&]F(&EM<&]R=&%N="!E;6%I;',@>6]U('-E;F0@
M<V\@=&AA="!Y;W4@:&%V92!S;VUE=&AI;F<@=&\@<F5F97(@8F%C:R!T;R!L
M871E<B!A;F0@=&\@:V5E<"!A;B!A8V-U<F%T92!R96-O<F0@;V8@=VAA="!W
M87,@<V%I9"X@5V4@9&\@;F]T(')E8V]M;65N9"!Y;W4@<V%V92!E=F5R>2!E
M;6%I;"!S:6YC92!T:&5N('EO=7(@9&ES:R!S=&]R86=E('%U;W1A('=I;&P@
M8F4@=7-E9"!U<"!Q=6EC:VQY("AE<W!E8VEA;&QY('=H96X@>6]U('-E;F0@
M871T86-H;65N=',I(&%N9"!Y;W5R(&UA:6QB;W@@=VEL;"!B92!F=6QL(&%N
M9"!U;F%B;&4@=&\@<F5C96EV92!N97<@:6YC;VUI;F<@96UA:6PN(%EO=2!C
M86XL(&AO=V5V97(L('1U<FX@=&AI<R!F96%T=7)E("=O;B<@87,@>6]U<B!D
M969A=6QT('=I=&@@)U!R969E<F5N8V5S)R!O;B!T:&4@8FQU92!N879I9V%T
M:6]N(&)A<B!A="!T;W`N($)E(&-A<F5F=6P@=VAE;B!U<VEN9R!T:&ES(&UO
M9&EF:65D(&1E9F%U;'0@87,@>6]U('=I;&P@;F5E9"!T;R!P97)I;V1I8V%L
M;'D@<'5R9V4@>6]U<B`B4V5N="!-86EL(B!F;VQD97(@;W(@:70@=VEL;"!E
M=F5N='5A;&QY(&UA:V4@>6]U<B!M86EL8F]X(&9U;&P@86YD('5N=7-E86)L
M92X*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60]
M(F-O;7!O<V4M;W!T:6]N<R(^"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I
M=&EO;CH@3W!T:6]N<SPO=&ET;&4^"B`@("`\:&5A9&EN9SXF<75O=#M/<'1I
M;VYS)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&5S92!/<'1I
M;VYS(&AE;'`@>6]U('!R97!A<F4@>6]U<B!M97-S86=E+@H@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@("!#;&EC:R`F<75O=#M3<&5L;"!#:&5C:R9Q=6]T
M.R!T;R!C:&5C:R!Y;W5R('-P96QL:6YG+@H@("`@/"]P87)A/@H@("`@/'!A
M<F$^"B`@("!#;&EC:R`F<75O=#M!='1A8VAM96YT<R9Q=6]T.R!T;R!V:65W
M(&%T('1H92!B;W1T;VT@;V8@=&AE('!A9V4@82!L:7-T(&]F(&9I;&5S(&%T
M=&%C:&5D('1O('1H:7,@;65S<V%G92X*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O("9Q=6]T
M.U-A=F4@8V]P>29Q=6]T.R!T;R!S879E(&$@8V]P>2!O9B!T:&ES(&UE<W-A
M9V4@:6X@>6]U<B`F<75O=#M396YT($UA:6PF<75O=#L@9F]L9&5R+B!3879E
M(&-O<&EE<R!O9B!I;7!O<G1A;G0@96UA:6QS('EO=2!S96YD('-O('1H870@
M>6]U(&AA=F4@<V]M971H:6YG('1O(')E9F5R(&)A8VL@=&\@;&%T97(@86YD
M('1O(&ME97`@86X@86-C=7)A=&4@<F5C;W)D(&]F('=H870@=V%S('-A:60N
M(%=E(&1O(&YO="!R96-O;6UE;F0@>6]U('-A=F4@979E<GD@96UA:6P@<VEN
M8V4@=&AE;B!Y;W5R(&1I<VL@<W1O<F%G92!Q=6]T82!W:6QL(&)E('5S960@
M=7`@<75I8VML>2`H97-P96-I86QL>2!W:&5N('EO=2!S96YD(&%T=&%C:&UE
M;G1S*2!A;F0@>6]U<B!M86EL8F]X('=I;&P@8F4@9G5L;"!A;F0@=6YA8FQE
M('1O(')E8V5I=F4@;F5W(&EN8V]M:6YG(&5M86EL+B!9;W4@8V%N+"!H;W=E
M=F5R+"!T=7)N('1H:7,@9F5A='5R92`G;VXG(&%S('EO=7(@9&5F875L="!W
M:71H:6X@>6]U<B!)9&5N=&ET>2P@8GD@9V]I;F<@=&\@3W!T:6]N<RTF9W0[
M4&5R<V]N86P@26YF;W)M871I;VXM)F=T.T5D:70@>6]U<B!I9&5N=&ET:65S
M+B!"92!C87)E9G5L('=H96X@=7-I;F<@=&AI<R!M;V1I9FEE9"!D969A=6QT
M(&%S('EO=2!W:6QL(&YE960@=&\@<&5R:6]D:6-A;&QY('!U<F=E('EO=7(@
M)G%U;W0[4V5N="!-86EL)G%U;W0[(&9O;&1E<B!O<B!I="!W:6QL(&5V96YT
M=6%L;'D@;6%K92!Y;W5R(&UA:6QB;W@@9G5L;"!A;F0@=6YU<V5A8FQE+@H@
M("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C
M;VUP;W-E+6%T=&%C:"(@<W1A=&4](G5N:VYO=VXB/@H@("`@/'1I=&QE/DUE
M<W-A9V4@0V]M<&]S:71I;VXZ($%T=&%C:#PO=&ET;&4^"B`@("`\:&5A9&EN
M9SXB071T86-H(CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@("`@(%EO=2!M
M87D@871T86-H(&9I;&5S('1O('EO=7(@;65S<V%G92X*("`@(#PO<&%R83X*
M("`@(#QP87)A/E-T97`@,3H@16ET:&5R+"!T>7!E('1H92!P871H(&%N9"!N
M86UE(&]F(&$@9FEL92!T:&%T('EO=2!W86YT(&%T=&%C:&5D('1O('1H:7,@
M;65S<V%G92!O<B!C;&EC:R`B0G)O=W-E(B!B=71T;VX@86YD('-E;&5C="!T
M:&4@9FEL92!T;R!B92!A='1A=&-H960N(%1H92!P871H(&%N9"!N86UE(&]F
M('1H870@9FEL92!N;W<@87!P96%R<R!I;B!T:&4@071T86-H;65N="!B;W@N
M($YO=R!P<F]C965D('1O"E-T97`@,BX*("`@(#PO<&%R83X*("`@(#QP87)A
M/E-T97`@,CH@0VQI8VL@(D%T=&%C:"(@8G5T=&]N+B!4:&4@9FEL92!N86UE
M(&%N9"!S:7IE('=I;&P@8F4@861D960@=&\@>6]U<B!L:7-T(&]F($%T=&%C
M:&UE;G1S+B!0;&5A<V4@;F]T92!T:&%T(&9O<B!L87)G92!F:6QE<R!A;F0O
M;W(@<VQO=V5R($EN=&5R;F5T(&-O;FYE8W1I;VYS+"!T:&4@<')O8V5S<R!O
M9B!U<&QO861I;F<@86YD(&%T=&%C:&EN9R!Y;W5R(&9I;&4@=&\@=&AE(&5M
M86EL(&UA>2!T86ME(&$@=VAI;&4N(%!L96%S92!B92!P871I96YT(&%N9"!D
M;R!N;W0@8VQI8VL@;VX@;W1H97(@=&AI;F=S('=H:6QE('EO=2!A<F4@=V%I
M=&EN9RX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@
M:60](F-O;7!O<V4M871T86-H(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!!='1A8V@\+W1I=&QE/@H@("`@/&AE861I;F<^)G%U;W0[071T
M86-H)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!9;W4@;6%Y(&%T
M=&%C:"!F:6QE<R!T;R!Y;W5R(&UE<W-A9V4[(&]N;'D@;VYE(&9I;&4@;6%Y
M(&)E(&%T=&%C:&5D(&%T(&$@=&EM92X*("`@(#PO<&%R83X*("`@(#QP87)A
M/E-T97`@,3H@16ET:&5R+"!T>7!E('1H92!P871H(&%N9"!N86UE(&]F(&$@
M9FEL92!T:&%T('EO=2!W86YT(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92!O
M<B!C;&EC:R`F<75O=#M"<F]W<V4F<75O=#L@8G5T=&]N(&%N9"!S96QE8W0@
M=&AE(&9I;&4@=&\@8F4@871T871C:&5D+B!4:&4@<&%T:"!A;F0@;F%M92!O
M9B!T:&%T(&9I;&4@;F]W(&%P<&5A<G,@:6X@=&AE($%T=&%C:&UE;G0@8F]X
M+@H@("`@/"]P87)A/@H@("`@/'!A<F$^4W1E<"`R.B!$96-I9&4@=VAE=&AE
M<B!Y;W4@=V%N="!T:&4@9FEL92!T;R!B92!V:65W960@87,@86X@871T86-H
M;65N="!O<B!I;FQI;F5D('=I=&@@=&AE(')E<W0@;V8@=&AE(&UE<W-A9V4N
M(%1H92!R96-E:79I;F<@<&5R<V]N*',I(&UA:6P@<F5A9&EN9R!S;V9T=V%R
M92!M=7-T(&)E(&%B;&4@=&\@:&%N9&QE('1H92!F:6QE('1Y<&4@:6YL:6YE
M.R!I9B!N;W0L('1H:7,@<&%R="!W:6QL(&)E('9I97=E9"!A<R!A;B!A='1A
M8VAM96YT(&EN<W1E860N"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3=&5P(#,Z
M($-L:6-K("9Q=6]T.T%T=&%C:"9Q=6]T.R!B=71T;VXN(%1H92!F:6QE(&YA
M;64@86YD('-I>F4@=VEL;"!B92!A9&1E9"!T;R!Y;W5R(&QI<W0@;V8@071T
M86-H;65N=',N(%!L96%S92!N;W1E('1H870@9F]R(&QA<F=E(&9I;&5S(&%N
M9"]O<B!S;&]W97(@26YT97)N970@8V]N;F5C=&EO;G,L('1H92!P<F]C97-S
M(&]F('5P;&]A9&EN9R!A;F0@871T86-H:6YG('EO=7(@9FEL92!T;R!T:&4@
M96UA:6P@;6%Y('1A:V4@82!W:&EL92X@4&QE87-E(&)E('!A=&EE;G0@86YD
M(&1O(&YO="!C;&EC:R!O=&AE<B!T:&EN9W,@=VAI;&4@>6]U(&%R92!W86ET
M:6YG+@H@("`@/"]P87)A/@H\+V5N=')Y/BTM/CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(B!S=&%T93TB=6YK;F]W;B(^"B`@
M("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@071T86-H;65N=',\+W1I
M=&QE/@H@("`@/&AE861I;F<^(D%T=&%C:&UE;G1S(CPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!S96-T:6]N(&1I<W!L87ES(&$@;&ES="!O9B!F
M:6QE<R!A;')E861Y(&%T=&%C:&5D('1O('EO=7(@;65S<V%G92X@5&\@1&5L
M971E(&%N(&%T=&%C:&5D(&9I;&4Z"B`@("`\+W!A<F$^"B`@("`\<&%R83Y3
M=&5P(#$Z($%C=&EV871E('1H92!C:&5C:RUB=71T;VX@;F5X="!T;R!T:&4@
M871T86-H960@9FEL96YA;64@>6]U('=A;G0@=&\@1&5L971E+@H@("`@/"]P
M87)A/B`*("`@(#QP87)A/E-T97`@,CH@0VQI8VL@(D1E;&5T92!!='1A8VAM
M96YT*',I(BX*("`@(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT
M<GD@:60](F-O;7!O<V4M871T86-H;65N=',B/@H@("`@/'1I=&QE/DUE<W-A
M9V4@0V]M<&]S:71I;VXZ($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QH96%D
M:6YG/B9Q=6]T.T%T=&%C:&UE;G1S)G%U;W0[/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!4:&ES('-E8W1I;VX@9&ES<&QA>7,@82!L:7-T(&]F(&9I;&5S
M(&%L<F5A9'D@871T86-H960@=&\@>6]U<B!M97-S86=E+B!4;R!$96QE=&4@
M86X@871T86-H960@9FEL93H*("`@(#PO<&%R83X*("`@(#QP87)A/E-T97`@
M,3H@06-T:79A=&4@=&AE(&-H96-K+6)U='1O;B!N97AT('1O('1H92!A='1A
M8VAE9"!F:6QE;F%M92!Y;W4@=V%N="!T;R!$96QE=&4N"B`@("`\+W!A<F$^
M(`H@("`@/'!A<F$^4W1E<"`R.B!#;&EC:R`F<75O=#M$96QE=&4@071T86-H
M;65N="AS*29Q=6]T.RX*("`@(#PO<&%R83X*/"]E;G1R>3XM+3X\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UP<FEO<FET>2(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^365S<V%G92!#;VUP;W-I=&EO;CH@4')I;W)I='D\+W1I
M=&QE/@H@("`@/&AE861I;F<^(E!R:6]R:71Y(CPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@5&AI<R!S971S('1H92`B6"U0<FEO<FET>2(@:&5A9&5R(&]N
M('EO=7(@;W5T9V]I;F<@;65S<V%G92X@5&AE(")8+5!R:6]R:71Y(B!T86<@
M:7,@82!S;W)T(&]F(")P<V5U9&\@<W1A;F1A<F0B('1H870@3F5T<V-A<&4L
M($UO>FEL;&$L($]P97)A+"!A;F0@3W5T;&]O:R!M86EL(&-L:65N=',@87!P
M96%R('1O(&%G<F5E(&]N+B!!;GD@;6%I;"!C;&EE;G1S('1H870@9&\@;F]T
M(&AA;F1L92!T:&ES(&AE861E<B!W:6QL('-I;7!L>2!I9VYO<F4@:70N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7-A=F4M
M871T86-H;65N=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUE<W-A9V4@
M0V]M<&]S:71I;VXZ(%-A=F4@071T86-H;65N=',\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!$971E<FUI;F5S('=H971H97(@=&AE(&%T=&%C:&UE;G1S(&EN
M('EO=7(@8V]M<&]S:71I;VX@87)E('-A=F5D('=I=&@@=&AE(&UE<W-A9V4@
M=VAE;B!S=&]R960@:6X@=&AE('-E;G0M;6%I;"!F;VQD97(N("!)9B`B665S
M(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W:6QL(&)E('-A=F5D+B`@268@(DYO
M(BP@=&AE(&%T=&%C:&UE;G0@9&%T82!W:6QL(&)E('-T<FEP<&5D(&9R;VT@
M=&AE(&UE<W-A9V4@869T97(@:70@:7,@<V5N="!T;R!A;&P@<F5C:7!I96YT
M<RX@($-H;V]S:6YG(").;R(@=VEL;"!H96QP(&-O;G-E<G9E(&1I<VL@<W!A
M8V4@8GD@<F5M;W9I;F<@*'!O=&5N=&EA;&QY(&QA<F=E*2!A='1A8VAM96YT
M(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-A=F5D(&UE<W-A9V5S+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UL:6YK+6%T=&%C
M:&UE;G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y-97-S86=E($-O;7!O
M<VET:6]N.B!,:6YK($%T=&%C:&UE;G1S/"]T:71L93X*("`@(#QP87)A/@H@
M("`@1&5T97)M:6YE<R!W:&5T:&5R('1H92!A='1A8VAM96YT<R!I;B!Y;W5R
M(&-O;7!O<VET:6]N(&%R92!S96YT(&%S(&$@<&%R="!O9B!T:&4@;6%I;"!M
M97-S86=E(&]R('=H971H97(@=&AO<V4@871T86-H;65N=',@87)E(&ME<'0@
M;VX@82!L;V-A;"!S97)V97(N("!)9B!A='1A8VAM96YT<R!A<F4@;&EN:V5D
M+"!T:&4@<F5C:7!I96YT*',I(&]F('EO=7(@;65S<V%G92!W:6QL(&)E('!R
M;W9I9&5D(&$@=V5B;&EN:R!W:&5R92!T:&5Y(&-A;B!D;W=N;&]A9"!T:&4@
M871T86-H;65N="AS*2X@($QI;FMI;F<@871T86-H;65N=',@:&%S('1H92!A
M9'9A;G1A9V4@;V8@=')E;65N9&]U<VQY(')E9'5C:6YG('1H92!S:7IE(&]F
M(&]U=&=O:6YG(&UE<W-A9V5S+B`@3&EN:VEN9R!A='1A8VAM96YT<R!H87,@
M=&AE(&1I<V%D=F%N=&%G92!T:&%T('1H92!C;VYT96YT(&]F('1H92!A='1A
M8VAM96YT<R!C86X@;F]T(&)E(&=U87)A;G1E960@=&\@8F4@879A:6QA8FQE
M(&EN('1H92!F=71U<F4@<VEN8V4@=&AE(&%T=&%C:&UE;G0@9&%T82!I<R!N
M;W0@;&]C871E9"!W:71H:6X@=&AE(&4M;6%I;"!M97-S86=E+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<V5A<F-H(B!S=&%T93TB=6YK
M;F]W;B(^"B`@("`\=&ET;&4^365S<V%G92!396%R8V@\+W1I=&QE/@H@("`@
M/&AE861I;F<^4V5A<F-H($-R:71E<FEA/"]H96%D:6YG/@H@("`@/'!A<F$^
M"B`@("`@("`@2&5L<"!T97AT('1O(&)E('=R:71T96XN"B`@("`\+W!A<F$^
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)S96%R8V@B/@H@("`@
M/'1I=&QE/DUE<W-A9V4@4V5A<F-H/"]T:71L93X*("`@(#QH96%D:6YG/E-E
M87)C:"!#<FET97)I83PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@66]U(&UA
M>2!S96%R8V@@9F]R(&UE<W-A9V5S(&9R;VT@>6]U<B!F;VQD97)S('5S:6YG
M(&1I9F9E<F5N="!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^"B`@("`\
M<&%R83Y3=&5P(#$Z($5N=&5R('1E>'0@=&\@=&AE(&9I96QD<R!Y;W4@=V%N
M="!T;R!A9&0@=&\@>6]U<B!S96%R8V@@8W)I=&5R:6$N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83Y3=&5P(#(Z($-H;V]S92!T:&4@;65S<V%G92!F;&%G*',I
M('1O(&%D9"!T;R!Y;W5R('-E87)C:"!C<FET97)I82X*("`@(#PO<&%R83X*
M("`@(#QP87)A/E-T97`@,SH@0VAO;W-E('1H92!F;VQD97(H<RD@9G)O;2!W
M:&EC:"!T;R!S96%R8V@@9F]R('1H92!M97-S86=E<RX*("`@(#PO<&%R83X*
M("`@(#QP87)A/E-T97`@-#H@0VQI8VL@)G%U;W0[4V5A<F-H)G%U;W0[+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!)9B!A;GD@;65S<V%G97,@;6%T
M8VAE9"!Y;W5R('-E87)C:"!C<FET97)I82P@=&AE;B!T:&4@<W5B:F5C=',@
M;V8@=&AE<V4@;65S<V%G97,@=VEL;"!B92!S:&]W;B!I;B!T:&4@)G%U;W0[
M4V5A<F-H(%)E<W5L=',F<75O=#L@=FEE=RX*("`@(#PO<&%R83X*/"]E;G1R
M>3XM+3X\+V5N=')Y/@H@(#QE;G1R>2!I9#TB9F]L9&5R+6]P=&EO;G,B('-T
M871E/2)U;FMN;W=N(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E;65N=#PO
M=&ET;&4^"B`@("`\:&5A9&EN9SY&;VQD97(@3W!T:6]N<SPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@("!9;W4@8V%N('-E;&5C="!A(&9O;&1E<B!B>2!U
M<VEN9R!T:&4@<F%D:6\@8G5T=&]N<R!A;&]N9R!T:&4@;&5F="!C;VQU;6XN
M("!/;F-E('EO=2!H879E(&1O;F4@=&AI<RP@<V5L96-T('1H92!O<'1I;VX@
M>6]U('=I<V@@=&\@<&5R9F]R;2!O;B!T:&4@9F]L9&5R('9I82!T:&4@<V5L
M96-T(&)O>"!T;R!T:&4@;&5F="X*("`@(#PO<&%R83X*("`@(#QP87)A/@H@
M("`@("!9;W4@=VEL;"!B92!P<F]M<'1E9"!F;W(@9G5R=&AE<B!O<'1I;VYS
M+B`@0F4@8V%R969U;"!W:71H('1H92!D96QE=&4@;W!T:6]N+"!A<R!Y;W4@
M8V%N(&QO<V4@86QL('1H92!M97-S86=E<R!I;B!A(&9O;&1E<B!I9B!Y;W4@
M9&5L971E(&ET(&)Y(&UI<W1A:V4A"B`@("`\+W!A<F$^"CPA+2T@16YG;&ES
M:"!E;G1R>3H*/&5N=')Y(&ED/2)F;VQD97(M;W!T:6]N<R(^"B`@("`\=&ET
M;&4^1F]L9&5R($UA;F%G96UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^1F]L
M9&5R($]P=&EO;G,\+VAE861I;F<^"B`@("`\<&%R83X*("`@("`@66]U(&-A
M;B!S96QE8W0@82!F;VQD97(@8GD@=7-I;F<@=&AE(')A9&EO(&)U='1O;G,@
M86QO;F<@=&AE(&QE9G0@8V]L=6UN+B`@3VYC92!Y;W4@:&%V92!D;VYE('1H
M:7,L('-E;&5C="!T:&4@;W!T:6]N('EO=2!W:7-H('1O('!E<F9O<FT@;VX@
M=&AE(&9O;&1E<B!V:6$@=&AE('-E;&5C="!B;W@@=&\@=&AE(&QE9G0N"B`@
M("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@66]U('=I;&P@8F4@<')O;7!T
M960@9F]R(&9U<G1H97(@;W!T:6]N<RX@($)E(&-A<F5F=6P@=VET:"!T:&4@
M9&5L971E(&]P=&EO;BP@87,@>6]U(&-A;B!L;W-E(&%L;"!T:&4@;65S<V%G
M97,@:6X@82!F;VQD97(@:68@>6]U(&1E;&5T92!I="!B>2!M:7-T86ME(0H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^26UP;W)T(&UB;W@@1FEL93PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@("!4:&ES(&]P=&EO;B!W:6QL(&EM<&]R
M="!A(&UB;W@@9F]R;6%T(&9I;&4@:6YT;R!T:&4@9F]L9&5R(&]F('EO=7(@
M8VAO:6-E+B!#:&]O<V4@,2`H;VYE*2!F;VQD97(@=&\@:6UP;W)T('1H92!M
M97-S86=E<R!I;G1O(&%N9"!T:&5N('-E;&5C="!T:&ES(&]P=&EO;BX@66]U
M('=I;&P@=&AE;B!B92!T86ME;B!T;R!A('!A9V4@=&AA="!W:6QL('!R;VUP
M="!F;W(@=&AE(&UB;W@@9FEL92!T;R!I;7!O<G0N"B`@("`\+W!A<F$^"CPO
M96YT<GD^+2T^/"]E;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUW:61G971S
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&;VQD97(@36%N86=E;65N=#H@
M1&ES<&QA>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY3:&]W+TAI9&4@56YS=6)S
M8W)I8F5D/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!U<VEN9R!)34%0
M(&9O;&1E<B!S=6)S8W)I<'1I;VYS+"!S:&]W+VAI9&4@=&AE('5N<W5B<V-R
M:6)E9"!F;VQD97)S+B`@5&\@<W5B<V-R:6)E+W5N<W5B<V-R:6)E('1O(&$@
M9F]L9&5R+"!S96QE8W0@=&AE(&-H96-K8F]X(&YE>'0@=&\@=&AE(&9O;&1E
M<FYA;64@86YD('5S92!T:&4@4W5B<V-R:6)E+U5N<W5B<V-R:6)E(&]P=&EO
M;B!I;B!T:&4@1F]L9&5R($%C=&EO;B!D<F]P+61O=VX@;65N=2X*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/D5X<&%N9"!!;&P\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($5X<&%N9"!A;&P@9F]L9&5R(&5N=')I97,N"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SY#;VQL87!S92!!;&P\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-O;&QA<'-E(&%L;"!F;VQD97(@96YT<FEE<RX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<G,B('-T871E/2)U
M;FMN;W=N(CX*("`@(#QT:71L93Y&:6QT97)S.B!!<'!L>3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L97,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-L:6-K(&]N('1H92`B07!P;'D@1FEL=&5R(B!I8V]N(&YE
M>'0@=&\@=&AE($E.0D]8(&YA;64@:6X@=&AE(&UA:6QB;W@@=FEE=R!T;R!F
M:6QT97(@86QL('5N9&5L971E9"!M97-S86=E<R!A8V-O<F1I;F<@=&\@=&AE
M('-P96-I9FEE9"!R=6QE<RX@($]R+"!A;'1E<FYA=&5V;'DL(&-L:6-K(&]N
M(")!<'!L>2!!;&P@4G5L97,B(&EN('1H92!F:6QT97(@;65N=2X@($YO=&4@
M=&AA="!F:6QT97)I;F<@:7,@;F]T(&1O;F4@875T;VUA=&EC86QL>2X*("`@
M(#PO<&%R83X*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](F9I;'1E
M<G,B/@H@("`@/'1I=&QE/D9I;'1E<G,Z($%P<&QY/"]T:71L93X*("`@(#QH
M96%D:6YG/D%P<&QY($9I;'1E<B!2=6QE<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@0VQI8VL@;VX@=&AE("9Q=6]T.T%P<&QY($9I;'1E<B9Q=6]T.R!I
M8V]N(&YE>'0@=&\@=&AE($E.0D]8(&YA;64@:6X@=&AE(&UA:6QB;W@@=FEE
M=R!T;R!F:6QT97(@86QL('5N9&5L971E9"!M97-S86=E<R!A8V-O<F1I;F<@
M=&\@=&AE('-P96-I9FEE9"!R=6QE<RX@($]R+"!A;'1E<FYA=&5V;'DL(&-L
M:6-K(&]N("9Q=6]T.T%P<&QY($%L;"!2=6QE<R9Q=6]T.R!I;B!T:&4@9FEL
M=&5R(&UE;G4N("!.;W1E('1H870@9FEL=&5R:6YG(&ES(&YO="!D;VYE(&%U
M=&]M871I8V%L;'DN"B`@("`\+W!A<F$^"CPO96YT<GD^+2T^/"]E;G1R>3X*
M("`\96YT<GD@:60](F9I;'1E<BUE9&ET+7)U;&5S(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y&:6QT97)S.B!%9&ET($9I;'1E<B!2=6QE<SPO=&ET;&4^
M"B`@("`\:&5A9&EN9SY%9&ET(%EO=7(@1FEL=&5R(%)U;&5S/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R(&9I;'1E<B!R
M=6QE<R(@=&\@<')O8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D
M9"P@9&5L971E+"!A;F0@961I="!T:&4@8W5R<F5N=&QY(&%C=&EV92!S970@
M;V8@9FEL=&5R(')U;&5S+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB9FEL=&5R+65D:70M8FQA8VML:7-T(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y&:6QT97)S.B!%9&ET($)L86-K;&ES=#PO=&ET;&4^"B`@("`\
M:&5A9&EN9SY%9&ET(%EO=7(@0FQA8VML:7-T/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!#;&EC:R!O;B`B161I="!Y;W5R(&)L86-K;&ES="(@=&\@<')O
M8V5E9"!T;R!T:&4@<&%G92!W:&5R92!Y;W4@8V%N(&%D9"P@9&5L971E+"!A
M;F0@961I="!T:&4@;&ES="!O9B!E+6UA:6P@861D<F5S<V5S('EO=2!!3%=!
M65,@<F5F=7-E(&UA:6P@9G)O;2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F9I;'1E<BUE9&ET+7=H:71E;&ES="(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^1FEL=&5R<SH@161I="!7:&ET96QI<W0\+W1I=&QE/@H@
M("`@/&AE861I;F<^161I="!9;W5R(%=H:71E;&ES=#PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@0VQI8VL@;VX@(D5D:70@>6]U<B!W:&ET96QI<W0B('1O
M('!R;V-E960@=&\@=&AE('!A9V4@=VAE<F4@>6]U(&-A;B!A9&0L(&1E;&5T
M92P@86YD(&5D:70@=&AE(&QI<W0@;V8@92UM86EL(&%D9')E<W-E<R!Y;W4@
M04Q705E3(&%C8V5P="!M86EL(&9R;VTN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM;&]G:6XB('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/D9I;'1E<G,Z($9I;'1E<B!O;B!,;V=I;CPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!<'!L>2!&:6QT97(@4G5L97,@57!O;B!,;V=O;C\\+VAE
M861I;F<^"B`@("`\<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N('1O(&%L
M=V%Y<R!A<'!L>2!F:6QT97)S('=H96X@9FER<W0@;&]G9VEN9R!O;G1O($E-
M4"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUO
M;BUD:7-P;&%Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y&:6QT97)S.B!&
M:6QT97(@;VX@4F5F<F5S:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!<'!L>2!F
M:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@0VAE8VL@=&AI<R!O<'1I;VX@=&\@86QW
M87ES(&%P<&QY(&9I;'1E<G,@=VAE;F5V97(@>6]U<B!V:65W('1H92!)3D)/
M6#\*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUA
M;GDM;6%I;&)O>"(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^1FEL=&5R<SH@
M1FEL=&5R(&%N>2!-86EL8F]X/"]T:71L93X*("`@(#QH96%D:6YG/D%P<&QY
M(&9I;'1E<B!R=6QE<R!T;R!A;GD@;6%I;&)O>#\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($-H96-K('1H:7,@;W!T:6]N(&EF('EO=2!W86YT('1O(&)E
M(&%L;&]W960@=&\@87!P;'D@9FEL=&5R(')U;&5S('1O(&%N>2!M86EL8F]X
M+B!.;W)M86QL>2P@9FEL=&5R:6YG(')U;&5S(&%R92!O;FQY(&%P<&QI960@
M=&\@;F5W(&UA:6P@=&AA="!I<R!D96QI=F5R960@=&\@>6]U<B!)3D)/6"X@
M($EF('1H:7,@;W!T:6]N(&ES(&-H96-K960L(&%N(&EC;VX@=VEL;"!A<'!E
M87(@;VX@86QL(&UA:6QB;W@@<&%G9V5S('1H870@=VEL;"!A;&QO=R!Y;W4@
M=&\@87!P;'D@9FEL=&5R(')U;&5S('1O('1H92!M97-S86=E<R!I;B!T:&4@
M8W5R<F5N="!M86EL8F]X+B`@3D]413H@1FEL=&5R:6YG(&EN(&UA:6QB;WAE
M<R!O=&AE<B!T:&%N($E.0D]8(&UA>2!P<F]D=6-E('-T<F%N9V4@*&4N9RX@
M=&AE(&9I;'1E<B!M87D@8V%U<V4@82!C;W!Y(&]F(&UE<W-A9V5S('1O(&)E
M(&1E;&EV97)E9"!T;R!T:&4@<V%M92!M86EL8F]X*2!A;F0O;W(@=6YD97-I
M<F5D(')E<W5L=',@*&4N9RX@:70@;6%Y(&-A=7-E(&UE<W-A9V5S('1O(&)E
M(&UO=F5D+V1E;&5T960@:68@;F5W(&9I;'1E<FEN9R!R=6QE<R!H879E(&)E
M96X@:6UP;&5M96YT960@<VEN8V4@=&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L
M:79E<F5D('1O('1H92!C=7)R96YT(&UA:6QB;W@I+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6-O;7!O<V4M871T86-H+7!U8FME
M>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4$=0.B!!='1A8V@@4'5B;&EC
M($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY!='1A8V@@4'5B;&EC($ME>3PO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@<V5L96-T960@=&AE;B!A(&-O
M<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2P@:68@:70@97AI<W1S+"!W:6QL
M(&)E(&%T=&%C:&5D('1O('1H92!O=71G;VEN9R!M97-S86=E+B`@66]U(&-A
M;B!S970@=&AE(&1E9F%U;'0@8F5H879I;W(@=FEA('1H92!01U`@3W!T:6]N
M<R!S8W)E96XN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M;W!T:6]N+7-C86XM8F]D>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4$=0.B!38V%N(%1E>'0@0F]D:65S/"]T:71L93X*("`@(#QH96%D:6YG/E-C
M86X@5&5X="!";V1I97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('-E
M;&5C=&5D('1H96X@24U0('=I;&P@<V-A;B!T:&4@8F]D>2!O9B!A;&P@=&5X
M="!M97-S86=E<R!F;W(@4$=0(&1A=&$L(&%N9"!D:7-P;&%Y('1H92!R97-U
M;'1S(&EF(&%N>2!D871A(&ES(&9O=6YD+B`@3F]T92!T:&%T('1H:7,@;6%Y
M('-L;W<@9&]W;B!T:&4@<WES=&5M(&%S(&5V97)Y('1E>'0@;65S<V%G92!M
M=7-T(&)E('-C86YN960@:6X@:71S(&5N=&ER971Y(&9O<B!01U`@9&%T82X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M;W!T
M:6]N<RUE;F-R>7!T(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y#;VUP;W-E
M.B!%;F-R>7!T:6]N($]P=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^3F\@
M16YC<GEP=&EO;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4V5N9"!T:&4@
M;65S<V%G92!W:71H(&YO(&5N8W)Y<'1I;VX@*&-L96%R=&5X="DN"B`@("`\
M+W!A<F$^"B`@("`\:&5A9&EN9SY01U`@16YC<GEP="!-97-S86=E/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL(&5N8W)Y<'0@
M=&AE(&-U<G)E;G0@;65S<V%G92P@=7-I;F<@4$=0(&%N9"!T:&4@<F5C:7!I
M96YT<R!P97)S;VYA;"!P=6)L:6,@:V5Y+"!A;F0@=&AE;B!S96YD(&ET+B!9
M;W4@8V%N(&]N;'D@<V5N9"!A(&UE<W-A9V4@=&\@82!S:6YG;&4@<&5R<V]N
M('5S:6YG('1H:7,@;W!T:6]N+B!9;W4@35535"!H879E('1H92!P=6)L:6,@
M:V5Y(&]F('1H92!R96-I<&EE;G0@<W1O<F5D(&EN('EO=7(@861D<F5S<V)O
M;VL@;W(@96QS92!T:&ES(&]P=&EO;B!W:6QL(&9A:6PN($EF('EO=2!H879E
M('1H92!P=6)L:6,@:V5Y(&9O<B!T:&4@<F5C:7!I96YT(&EN('EO=7(@861D
M<F5S<V)O;VL@86YD(&%R92!S=&EL;"!R96-E:79I;F<@97)R;W)S+"!V97)I
M9GD@=&AA="!T:&4@92UM86EL(&%D9')E<W,@:6X@=&AE(')E8VEP:65N="!F
M:65L9"!M871C:&5S('1H92!E+6UA:6P@861D<F5S<R!W:&5R92!T:&4@<'5B
M;&EC(&ME>2!I<R!S=&]R960N(%1H92!E;F-R>7!T960@9&%T82!W:6QL(&)E
M(&%T=&%C:&5D('1O('1H92!O=71G;VEN9R!M97-S86=E+@H@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^4$=0(%-I9VX@365S<V%G93PO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@5&AI<R!O<'1I;VX@=VEL;"!D:6=I=&%L;'D@<VEG;B!T
M:&4@8W5R<F5N="!M97-S86=E('5S:6YG(%!'4"!A;F0@>6]U<B!P97)S;VYA
M;"!P<FEV871E(&ME>2X@268@>6]U(&AA=F4@;F]T(&%L<F5A9'D@96YT97)E
M9"!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!P<FEV871E(&ME>2!D=7)I;F<@
M=&AI<R!S97-S:6]N('EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!I="X@(%1H
M92!R96-E:7!I96YT(&UU<W0@:&%V92!A(&-O<'D@;V8@>6]U<B!P=6)L:6,@
M:V5Y('1O(&1I9VET86QL>2!V97)I9GD@>6]U<@H@("`@<VEG;F%T=7)E+@H@
M("`@/"]P87)A/@H@("`@/&AE861I;F<^4$=0(%-I9VXO16YC<GEP="!-97-S
M86=E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4:&ES(&]P=&EO;B!W:6QL
M(&9I<G-T(&1I9VET86QL>2!S:6=N('EO=7(@;65S<V%G92!A;F0@=&AE;B!W
M:6QL(&5N8W)Y<'0@=&AE(')E<W5L=&EN9R!O=71P=70N(%-E92!T:&4@)U!'
M4"!%;F-R>7!T($UE<W-A9V4G(&%N9"`G4$=0(%-I9VX@365S<V%G92<@96YT
M<FEE<R!F;W(@9G5R=&AE<B!I;F9O<FUA=&EO;BX*("`@(#PO<&%R83X*("`@
M(#QH96%D:6YG/E,O34E-12!%;F-R>7!T($UE<W-A9V4\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%1/1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O
M34E-12!3:6=N($UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/
M1$\*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-12!3:6=N+T5N8W)Y
M<'0@365S<V%G93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5$]$3PH@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6]V97)V:65W(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($]V97)V:65W/"]T:71L93X*
M("`@(#QH96%D:6YG/E=H870@:7,@4$=0/SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@4$=0(&ES(&$@=&]O;"!F;W(@<V5C=7)E(&-O;6UU;FEC871I;VX@
M86YD(&1A=&$@<W1O<F%G92P@97-P96-I86QL>2!F;W(@=7-E('=I=&@@92UM
M86EL+B!)="!C86X@8F4@=7-E9"!T;R!E;F-R>7!T(&1A=&$@86YD('1O(&-R
M96%T92!D:6=I=&%L('-I9VYA='5R97,N($E-4"!U<V5S($=N=5!'("A'3E4@
M4')I=F%C>2!'=6%R9"D@=&\@<')O=FED92!T:&ES(&9U;F-T:6]N86QI='DN
M"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY%;F%B;&4@4$=0(&9U;F-T:6]N
M86QI='D_/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!)9B!T:&ES(&]P=&EO
M;B!I<R!S96QE8W1E9"P@>6]U('=I;&P@8F4@86)L92!T;R!C<F5A=&4O=FEE
M=R!Y;W5R('!E<G-O;F%L(%!'4"!K97ES+"!A9&0O9&5L971E('!U8FQI8R!K
M97ES(&9R;VT@;W1H97(@:6YD:79I9'5A;',L(')E860@96YC<GEP=&5D(&UA
M:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG;F5D(&UA:6PL(&%N9"!E;F-R>7!T
M+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<&=P+6]P=&EO;BUA='1A8V@M<'5B:V5Y(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y01U`Z($]P=&EO;G,@+2!!='1A8V@@4'5B
M;&EC($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY/<'1I;VYS("T@071T86-H
M(%!U8FQI8R!+97D\+VAE861I;F<^"B`@("`\<&%R83X*("`@($EF('-E;&5C
M=&5D('1H96X@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97DL(&EF(&ET
M(&5X:7-T<RP@=VEL;"!B>2!D969A=6QT(&)E(&%T=&%C:&5D('1O(&%L;"!O
M=71G;VEN9R!M97-S86=E<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!G<"UM86YA9V4M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y<SPO=&ET;&4^"B`@("`\:&5A
M9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&AI<R!S
M8W)E96X@;&ES=',@86QL(&]F('1H92!C=7)R96YT('5S97)S(&EN('EO=7(@
M861D<F5S<V)O;VL@=&AA="!H879E(%!'4"!P=6)L:6,@:V5Y<RX@5&AE<V4@
M=7-E<G,@87)E('1H92!/3DQ9('5S97)S('1H870@>6]U(&-A;B!E:71H97(@
M,2D@<V5N9"!A;B!E;F-R>7!T960@;65S<V%G92!T;R`M3U(M(#(I('9E<FEF
M>2!A(&1I9VET86P@<VEG;F%T=7)E+@H@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@82!W:6YD
M;W<@=&\@=FEE=R!T:&4@4$=0('!U8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@
M("`\:&5A9&EN9SY$971A:6QS/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$
M:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O=70@=&AE(%!'4"!P=6)L:6,@:V5Y
M+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5L971E/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!$96QE=&5S('1H92!P=6)L:6,@:V5Y(&9R;VT@>6]U
M<B!A9&1R97-S8F]O:RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UI;7!O<G0M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y01U`Z($UA;F%G92!0=6)L:6,@2V5Y<R`M($EM<&]R=#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY);7!O<G0@4'5B;&EC($ME>7,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%1H:7,@8G5T=&]N('=I;&P@;W!E;B!A('=I;F1O=R!W:&5R
M92!Y;W4@8V%N(&UA;G5A;&QY(&EM<&]R="!A(%!'4"!P=6)L:6,@:V5Y+B`@
M5&AE(&ME>2!C86X@96ET:&5R(&)E('!A<W1E9"!I;G1O(&$@=&5X=&9I96QD
M(&]R+"!I9B!T:&4@:V5Y(')E<VED97,@:6X@82!F:6QE(&]N('EO=7(@;&]C
M86P@8V]M<'5T97(L('EO=2!C86X@:6UP;W)T(&ET+B`@268@=&AE(&ME>2!I
M<R!V86QI9"!I="!W:6QL(&)E(&EN<V5R=&5D(&EN=&\@>6]U<B!A9&1R97-S
M8F]O:R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L;W-E.R!I9B!N;W0@=F%L:60L
M(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R971U<FYE9"!E>'!L86EN:6YG
M('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UO
M=F5R=FEE=RUP97)S;VYA;&ME>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@>6]U('=A
M;G0@=&\@9&EG:71A;&QY('-I9VX@;65S<V%G97,@;W(@96YA8FQE(&]T:&5R
M<R!T;R!S96YD('EO=2!E;F-R>7!T960@;65S<V%G97,L('EO=2!M=7-T(&AA
M=F4@>6]U<B!O=VX@<&5R<V]N86P@<'5B;&EC+W!R:79A=&4@4$=0(&ME>7!A
M:7(N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY9;W5R(%!U8FQI8R!+97D\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%EO=7(@<'5B;&EC(&ME>2!S:&]U
M;&0@8F4@;6%D92!A=F%I;&%B;&4@=&\@86YY('!E<G-O;B!T:&%T('EO=2!W
M86YT('1O(&)E(&%B;&4@=&\@<V5N9"!Y;W4@96YC<GEP=&5D(&UE<W-A9V5S
M('1H870@;VYL>2!93U4@8V%N(&1E8W)Y<'0@*'5S:6YG('EO=7(@<')I=F%T
M92!K97DI+B!!9&1I=&EO;F%L;'DL('EO=7(@<'5B;&EC(&ME>2!N965D<R!T
M;R!B92!M861E(&%V86EL86)L92!T;R!A;GEB;V1Y('EO=2!S96YD(&$@9&1I
M9VET86QL>2!S:6=N960@;65S<V%G92!T;R`M('1H92!P=6)L:6,@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!T:&4@9&EG:71A;"!S:6=N871U<F4N"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SY9;W5R(%!R:79A=&4@2V5Y/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!9;W5R('!R:79A=&4@:V5Y(&ES(&YE8V5S
M<V%R>2!T;R!D96-R>7!T(&%N>2!M97-S86=E(&5N8W)Y<'1E9"!U<VEN9R!Y
M;W5R('!U8FQI8R!K97DN($%D9&ET:6]N86QL>2P@>6]U<B!P<FEV871E(&ME
M>2!I<R!N965D960@:68@>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@82!M
M97-S86=E+B!9;W5R('!R:79A=&4@:V5Y('=I;&P@8F4@<')O=&5C=&5D('9I
M82!A('!A<W-P:')A<V4@8W)E871E9"!W:&5N('1H92!K97ES(&%R92!G96YE
M<F%T960N(%1H=7,L('1O('!E<F9O<FT@86YY(&%C=&EV:71Y('1H870@<F5Q
M=6ER97,@>6]U<B!P<FEV871E(&ME>2P@24U0('=I;&P@<')O;7!T('EO=2!F
M;W(@>6]U<B!P87-S<&AR87-E+B!9;W4@;VYL>2!N965D('1O(&EN<V5R="!Y
M;W5R('!A<W-P:')A<V4@;VYC92!P97(@<V5S<VEO;B`M($E-4"!W:6QL('-T
M;W)E('EO=7(@<&%S<W!H<F%S92!U;G1I;"!Y;W4@;&]G;W5T("A3;R!B92!S
M=7)E('1O(&QO9V]U="$I+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!U8FQI8R(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4$=0.B!-86YA9V4@4&5R<V]N86P@2V5Y<R`M(%!U8FQI8R!+
M97D\+W1I=&QE/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@3W!E;G,@82!W:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!U8FQI
M8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!$:7-P;&%Y<R!S;VUE(&1E=&%I;',@86)O
M=70@=&AE(%!'4"!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+7!R:79A=&4B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!'4#H@36%N86=E(%!E<G-O;F%L($ME>7,@+2!0
M<FEV871E($ME>3PO=&ET;&4^"B`@("`\:&5A9&EN9SY%;G1E<B!087-S<&AR
M87-E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!/<&5N<R!T:&4@<&%S<W!H
M<F%S92!D:6%L;V<@=VEN9&]W+B!4:&4@<&%S<W!H<F%S92!E;G1E<F5D+"!I
M9B!C;W)R96-T+"!W:6QL(&)E('-T;W)E9"!B>2!)35`@=6YT:6P@>6]U<B!S
M97-S:6]N(&5N9',N"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY5;FQO860@
M4&%S<W!H<F%S93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@4F5M;W9E<R!T
M:&4@<W1O<F5D('!A<W-P:')A<V4@9G)O;2!)35`@+2!A;GD@861D:71I;VYA
M;"!U<V%G92!O9B!T:&4@<')I=F%T92!K97D@=VEL;"!R97%U:7)E('EO=2!T
M;R!R965N=&5R('1H92!P87-S<&AE87-E+@H@("`@/"]P87)A/@H@("`@/&AE
M861I;F<^5FEE=SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@3W!E;G,@82!W
M:6YD;W<@=&\@=FEE=R!T:&4@4$=0('!R:79A=&4@:V5Y+B!$3R!.3U0@4T5.
M1"!42$E3($M%62!43R!!3EE/3D4@+2!T:&ES(&]P=&EO;B!I<R!S=')I8W1L
M>2!S;R!T:&%T('EO=2!C86X@97AP;W)T('EO=7(@24U0('!E<G-O;F%L('!R
M:79A=&4@:V5Y(&9O<B!U<V4@:6X@86YO=&AE<B!P<F]G<F%M+@H@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO:&5A9&EN9SX*("`@(#QP87)A
M/@H@("`@1&ES<&QA>7,@<V]M92!D971A:6QS(&%B;W5T('1H92!01U`@<')I
M=F%T92!K97DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M9W`M<&5R<V]N86QK97DM9&5L971E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y01U`Z($UA;F%G92!097)S;VYA;"!+97ES("T@1&5L971E/"]T:71L93X*
M("`@(#QH96%D:6YG/D1E;&5T92!097)S;VYA;"!+97ES/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@("!4:&ES(&)U='1O;B!W:6QL(&1E;&5T92!Y;W5R('!E
M<G-O;F%L('!U8FQI8R]P<FEV871E(&ME>7!A:7(@9G)O;2!)35`G<R!P<F5F
M97)E;F-E<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!G
M<"UP97)S;VYA;&ME>2UC<F5A=&4M;F%M92(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@3F%M93PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY.86UE/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!4
M:&4@;F%M92!Y;W4@=V%N="!E;6)E9&1E9"!I;B!Y;W5R('!E<G-O;F%L(&ME
M>7,N($$@<F5Q=6ER960@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6-O;6UE;G0B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME
M>2`M($-O;6UE;G0\+W1I=&QE/@H@("`@/&AE861I;F<^0V]M;65N=#PO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@02!C;VUM96YT('-T<FEN9R!Y;W4@=V%N
M="!E;6)E9&1E9"!I;B!Y;W5R('!E<G-O;F%L(&ME>7,N($%N(&]P=&EO;F%L
M(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P
M+7!E<G-O;F%L:V5Y+6-R96%T92UE;6%I;"(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@12UM86EL($%D9')E
M<W,\+W1I=&QE/@H@("`@/&AE861I;F<^12UM86EL($%D9')E<W,\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%1H92!E+6UA:6P@861D<F5S<R!Y;W4@=V%N
M="!A<W-O8VEA=&5D('=I=&@@>6]U<B!P97)S;VYA;"!K97ES+B!!(')E<75I
M<F5D(&9I96QD+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UK97EL96YG=&@B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME>2`M($ME>6QE
M;F=T:#PO=&ET;&4^"B`@("`\:&5A9&EN9SY+97EL96YG=&@\+VAE861I;F<^
M"B`@("`\<&%R83X*("`@(%1H92!K97EL96YG=&@L(&EN(&)Y=&5S+"!O9B!Y
M;W5R(&=E;F5R871E9"!K97DN(%1H92!G<F5A=&5R('1H92!V86QU92P@=&AE
M(&=R96%T97(@=&AE('!R;W1E8W1I;VX@*&%N9"!A;'-O(&=R96%T97(@9V5N
M97)A=&EO;B!T:6UE(&%N9"!E;F-R>7!T:6]N('1I;64I+B`Q,#(T(&)Y=&5S
M(&ES('1H92!D969A=6QT("T@=&AI<R!V86QU92!P<F]V:61E<R!E>&-E;&QE
M;G0@<')O=&5C=&EO;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M<&%S<W!H<F%S92(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4$=0.B!#<F5A=&4@4&5R<V]N86P@2V5Y("T@
M4&%S<W!H<F%S93PO=&ET;&4^"B`@("`\:&5A9&EN9SY.86UE/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!4:&4@<&%S<W!H<F%S92!U<V5D('1O('!R;W1E
M8W0O96YC<GEP="!Y;W5R('!E<G-O;F%L('!R:79A=&4@:V5Y+B!4:&ES('-H
M;W5L9"!B92!!5"!,14%35"`V(&-H87)A8W1E<G,L('-H;W5L9"!.3U0@8F4@
M=&AE('-A;64@87,@>6]U<B!L;V=I;B!P87-S=V]R9"P@<VAO=6QD($Y/5"!B
M92!B87-E9"!O;B!A(&1I8W1I;VYA<GD@=V]R9"P@86YD('-H;W5L9"!I;F-L
M=61E(&)O=&@@;G5M8F5R<R!A;F0@;&5T=&5R<RX@66]U(&UU<W0@96YT97(@
M=&AI<R!P87-S<&AR87-E('1W:6-E(&9O<B!V97)I9FEC871I;VX@<'5R<&]S
M97,N($$@<F5Q=6ER960@9FEE;&0N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM8W)E871E+6%C=&EO;G,B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!'4#H@0W)E871E(%!E<G-O;F%L($ME
M>2`M($%C=&EO;G,\+W1I=&QE/@H@("`@/&AE861I;F<^0W)E871E($ME>7,\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@($-R96%T92!A;F0@<W1O<F4@>6]U
M<B!P97)S;VYA;"]P<FEV871E(&ME>7!A:7(N"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SY);7!O<G0@2V5Y<&%I<CPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@26UP;W)T(&$@<&5R<V]N86PO<')I=F%T92!K97EP86ER+B!4:&ES(&)U
M='1O;B!O<&5N<R!A('=I;F1O=R!W:&5R92!Y;W4@8V%N(&UA;G5A;&QY(&EM
M<&]R="!Y;W5R(&5X:7-T:6YG(%!'4"!P97)S;VYA;"!P=6)L:6,O<')I=F%T
M92!K97EP86ER+B`@5&AE(&ME>7,@8V%N(&5I=&AE<B!B92!P87-T960@:6YT
M;R!A('1E>'1F:65L9"!O<BP@:68@=&AE(&ME>7,@<F5S:61E(&EN(&$@9FEL
M92!O;B!Y;W5R(&QO8V%L(&-O;7!U=&5R+"!Y;W4@8V%N(&EM<&]R="!T:&5M
M+B`@268@=&AE(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E
M9"!I;G1O('EO=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C
M;&]S93L@:68@;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@
M<F5T=7)N960@97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=R(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4R]-24U%.B!/=F5R=FEE=SPO=&ET;&4^"B`@("`\:&5A9&EN
M9SY7:&%T(&ES(%,O34E-13\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%,O
M34E-12!I<R!A('!R:79A=&4O<'5B;&EC(&ME>2!P86ER('-Y<W1E;2!W:&EC
M:"!P<F]V:61E<R!D:6=I=&%L('-I9VYA='5R97,L(&UE<W-A9V4@<')I=F%C
M>2P@86YD('1A;7!E<B!D971E8W1I;VX@:6X@82!O<&5N+"!I;G1E<F]P97)A
M8FQE('=A>2X@(%,O34E-12!C86X@<')O=FED92!M97-S86=E('!R:79A8WD@
M8GD@96YC<GEP=&EN9R!M97-S86=E<R!T:&%T(&]N;'D@=&AE('-E;F1E<B!A
M;F0@=&AE(&EN=&5N9&5D(')E8VEP:65N=',@8V%N(&1E8V]D92X@($ET(&%L
M;&]W<R!Y;W4@=&\@:61E;G1I9GD@=&AE('-E;F1E<B!O9B!A(&UE<W-A9V4@
M=FEA(&$@9&EG:71A;"!S:6=N871U<F4N("!4;V=E=&AE<BP@=&AI<R!E;F-R
M>7!T:6]N(&%N9"!D:6=I=&%L('-I9VYI;F<@:&5L<"!P<F]V:61E('1A;7!E
M<B!D971E8W1I;VXL(&%L;&]W:6YG(')E8VEP:65N=',@=&\@9&5T97)M:6YE
M('=H971H97(@82!M97-S86=E('=A<R!A;'1E<F5D(&%F=&5R(&ET('=A<R!S
M96YT+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^16YA8FQE(%,O34E-12!F
M=6YC=&EO;F%L:71Y/SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@268@=&AI
M<R!O<'1I;VX@:7,@<V5L96-T960L('EO=2!W:6QL(&)E(&%B;&4@=&\@:6UP
M;W)T('EO=7(@<&5R<V]N86P@4R]-24U%(&ME>7,L(')E860@96YC<GEP=&5D
M(&UA:6PL('9E<FEF>2!D:6=I=&%L;'D@<VEG;F5D(&UA:6PL(&%N9"!E;F-R
M>7!T+W-I9VX@>6]U<B!O=71G;VEN9R!M86EL+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M;W9E<G9I97<M<&5R<V]N86QK97DB
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E,O34E-13H@4&5R<V]N86P@2V5Y
M<SPO=&ET;&4^"B`@("`\:&5A9&EN9SY/=F5R=FEE=SPO:&5A9&EN9SX*("`@
M(#QP87)A/@H@("`@268@>6]U('=A;G0@=&\@9&EG:71A;&QY('-I9VX@;W(@
M96YC<GEP="!M97-S86=E<R!Y;W4@;75S="!H879E('EO=7(@;W=N('!E<G-O
M;F%L('!U8FQI8R]P<FEV871E(%,O34E-12!K97EP86ER+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<VUI;64M:6UP;W)T+7!E<G-O;F%L
M+6-E<G1S(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3+TU)344Z($EM<&]R
M="!097)S;VYA;"!#97)T:69I8V%T97,\+W1I=&QE/@H@("`@/&AE861I;F<^
M26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E<SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@26UP;W)T('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M(&$@
M4$M#4R`C,3(@9F]R;6%T(&9I;&4N(%!+0U,@(S$R(&9I;&5S(&ES('1H92!F
M:6QE('5S=6%L;'D@9V5N97)A=&5D('=H96X@97AP;W)T:6YG(&$@:V5Y(&9R
M;VT@82!B<F]W<V5R("AE+F<N($EN=&5R;F5T($5X<&QO<F5R+"!&:7)E9F]X
M*2!O<B!F<F]M(&$@8V5R=&EF:6-A=&4@<W1O<F4@;6%I;G1A:6YE9"!B>2!A
M;B!/<&5R871I;F<@4WES=&5M("AE+F<N(%=I;F1O=W,@6%`I+B!)9B!T:&4@
M:V5Y<R!A<F4@=F%L:60@=&AE>2!W:6QL(&)E(&EN<V5R=&5D(&EN=&\@>6]U
M<B!P<F5F97)E;F-E<R!A;F0@=&AE('=I;F1O=R!W:6QL(&-L;W-E.R!I9B!N
M;W0@=F%L:60L(&%N(&5R<F]R(&UE<W-A9V4@=VEL;"!B92!R971U<FYE9"!E
M>'!L86EN:6YG('=H>2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G-M:6UE+61E;&5T92UP97)S;VYA;"UC97)T<R(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4R]-24U%.B!$96QE=&4@4&5R<V]N86P@0V5R=&EF:6-A
M=&5S/"]T:71L93X*("`@(#QH96%D:6YG/D1E;&5T92!097)S;VYA;"!#97)T
M:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T92!Y;W5R
M('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M('EO=7(@<')E9F5R96YC97,N
M("!9;W4@=VEL;"!N;R!L;VYG97(@8F4@86)L92!T;R!S:6=N(%,O34E-12!M
M97-S86=E<R!O<B!V:65W(&%N>2!3+TU)344@96YC<GEP=&5D(&UE<W-A9V5S
M(&%D9')E<W-E9"!T;R!Y;W4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y3+TU)344Z($UA;F%G92!0=6)L:6,@2V5Y<SPO=&ET;&4^"B`@
M("`\:&5A9&EN9SY3+TU)344Z($UA;F%G92!0=6)L:6,@2V5Y<SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@36%N86=E('EO=7(@4R]-24U%('!U8FQI8R!K
M97D@;&ES="X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E9I97<\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%9I97<@=&AE(')A=R!T97AT(&]F('1H92!P
M=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^1&5T86EL<SPO
M:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5FEE=R!T96-H;FEC86P@9&5T86EL
M<R!O9B!T:&4@<'5B;&EC(&ME>2X*("`@(#PO<&%R83X*("`@(#QH96%D:6YG
M/D1E;&5T93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@1&5L971E<R!T:&4@
M<V5L96-T960@<'5B;&EC(&ME>2!F<F]M('-T;W)A9V4N("!$96QE=&EN9R!A
M('!U8FQI8R!K97D@9F]R(&$@=7-E<B!W:6QL('!R979E;G0@>6]U<B!F<F]M
M(&5N8W)Y<'1I;F<@82!M97-S86=E('1O('1H870@=7-E<BX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R:6YT:6YG(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<FEN=&EN9SPO=&ET;&4^"B`@("`\:&5A9&EN9SY0
M<FEN="!A(&UE<W-A9V4\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1O('!R
M:6YT(&$@;65S<V%G92!Y;W4@87)E('9I97=I;F<L(&-L:6-K(&]N('1H92`B
M4')I;G0B(&QI;FL@870@96ET:&5R('1H92!T;W`@;W(@8F]T=&]M(&]F('1H
M92!M97-S86=E+B!4:&4@;65S<V%G92!W:6QL(&]P96X@:6X@82!N97<@=VEN
M9&]W(&9O<FUA=&5D(&9O<B!P<FEN=&EN9RX@($1E<&5N9&EN9R!O;B!Y;W5R
M('=E8B!B<F]W<V5R(&%N9"!O<&5R871I;F<@<WES=&5M+"!T:&4@<')I;G0@
M9&EA;&]G(&)O>"!M87D@;W!E;B!F;W(@>6]U+B`@268@:70@9&]E<R!N;W0@
M;W!E;BP@=&AE;B!P=6QL(&1O=VX@=&AE('=E8B!B<F]W<V5R)W,@(D9I;&4B
M(&UE;G4@86YD(&-H;V]S92`B4')I;G0B('1O(&]P96X@=&AE('!R:6YT(&1I
M86QO9R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)S
M;W)T:6YG(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y3;W)T:6YG(&%N9"!4
M:')E861I;F<\+W1I=&QE/@H@("`@/&AE861I;F<^4V]R=&EN9R!%;G1R:65S
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!7:&5N('9I97=I;F<@82!L:7-T
M(&]F(&UE<W-A9V5S+"!Y;W4@8V%N('-O<G0@=&AE(&UE<W-A9V5S(&)Y(&%N
M>2!C;VQU;6X@8GD@8VQI8VMI;F<@;VX@=&AE(&%P<')O<')I871E(&-O;'5M
M;B!H96%D:6YG+B`@5&\@<W=I=&-H(&-O;'5M;G,@8F5T=V5E;B!A<V-E;F1I
M;F<@86YD(&1E<V-E;F1I;F<@;W)D97(L(&-L:6-K(&]N('1H92!A<G)O=R!I
M8V]N(&EN('1H92!C;VQU;6X@:&5A9&EN9RX*("`@(#PO<&%R83X*("`@(#QH
M96%D:6YG/E1H<F5A9&EN9SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@5&\@
M9W)O=7`@;65S<V%G97,@8GD@=&AR96%D<R`H<W5B:F5C="DL('-O(&5A8V@@
M;65S<V%G92!I<R!G<F]U<&5D('=I=&@@86QL(&ET<R!R97!L:65S+"!C;&EC
M:R!T:&4@6U1H<F5A9%T@;&EN:R!I;B!T:&4@<W5B:F5C="!C;VQU;6X@:&5A
M9&EN9RX@(%1O(')E='5R;B!T;R!N;W)M86P@<W5B:F5C="!S;W)T:6YG+"!C
M;&EC:R!O;B!T:&4@6U-U8FIE8W1=(&QI;FL@:6X@=&AE('-U8FIE8W0@8V]L
M=6UN(&AE861I;F<N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)A;'1E<FYA=&EV92UM<V<B('-T871E/2)N97<B/@H@("`@/'1I=&QE/DUU
M;'1I<&%R="]!;'1E<FYA=&EV92!-97-S86=E<SPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(%-O;64@;65S<V%G92!H879E(&)E96X@<V5N="!A<R!A(")M=6QT
M:7!A<G0O86QT97)N871I=F4B('1Y<&4@8GD@=&AE('-E;F1E<BX@5&AE<V4@
M;65S<V%G97,@:&%V92!S979E<F%L('!A<G1S+"!A;&P@9&ES<&QA>6EN9R!T
M:&4@4T%-12!#3TY414Y4(&)U="!I;B!$249&15)%3E0@1D]234%44RX@5&AE
M(&UA:6P@86=E;G0@=VEL;"!D:7-P;&%Y('1H92!L87-T('!A<G0@:6X@=&AE
M(&QI<W0@=&AA="!C86X@8F4@<W5C8V5S<V9U;&QY(&1I<W!L87EE9"!I;FQI
M;F4@:6X@=&AE(&)R;W=S97(L(&EF(&%N>2X@06QL(&]T:&5R(&9O<FUA=',@
M=VEL;"!A<'!E87(@=6YD97(@=&AE(&AE861I;F<@(D%L=&5R;F%T:79E('!A
M<G1S(&9O<B!T:&ES('-E8W1I;VXB(&%N9"!C86X@8F4@=FEE=V5D(&]R(&1O
M=VYL;V%D960@<V5P87)A=&5L>2X@270@:7,@:6UP;W)T86YT('1O(&YO=&4@
M=&AA="!T:&5S92!A;'1E<FYA=&EV92!P87)T<R!C;VYT86EN('1H92!304U%
M($-/3E1%3E13(&%S('1H92!P87)T('1H870@:7,@<VAO=VX@+2!T:&5Y(&%R
M92!S:6UP;'D@:6X@82!D:69F97)E;G0@;65D:6$@9F]R;6%T("AE+F<N('1E
M>'0@=G,N($A434P@;W5T<'5T*2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+7)E;F%M95]S96YT;6%I;%]M;VYT:&QY(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M(%)E;F%M92!396YT+6UA:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L
M:6ME('1O(')E;F%M92!Y;W5R('-E;G0M;6%I;"!F;VQD97(@870@=&AE(&)E
M9VEN;FEN9R!O9B!E=F5R>2!M;VYT:"X@(%1H92!F;VQD97(@=VEL;"!B92!R
M96YA;65D("AT;R!A(&YA;64@=&AA="!C;VYT86EN<R!T:&4@;6]N=&@@86YD
M('EE87(I(&%N9"!A(&YE=R!S96YT+6UA:6P@9F]L9&5R('=I;&P@8F4@8W)E
M871E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+61E;&5T95]S96YT;6%I;%]M;VYT:&QY(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T92!396YT+6UA
M:6P@1F]L9&5R($UO;G1H;'D\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!4=7)N
M('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W;W5L9"!L:6ME('1O(&1E;&5T92!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@870@=&AE(&)E9VEN;FEN9R!O9B!E=F5R
M>2!M;VYT:"X@(%1H:7,@;6%Y(&)E('5S969U;"!I9B!Y;W4@:&%V92!A('%U
M;W1A+"!F;W(@97AA;7!L92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+61E;&5T95]S96YT;6%I;%]M;VYT:&QY7VME97`B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@1&5L971E(%-E;G0M;6%I;"!&;VQD97(@36]N=&AL>2`M(",@;V8@1F]L
M9&5R<R!T;R!+965P/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U(&%R
M92!D96QE=&EN9R!O;&0@<V5N="UM86EL(&9O;&1E<G,@979E<GD@;6]N=&@L
M(&AO=R!M86YY(&UO;G1H<R!O9B!O;&0@9F]L9&5R<R!D;R!Y;W4@('=A;G0@
M=&\@:V5E<#\@($%N>2!F;VQD97)S(&]L9&5R('1H86X@=&AI<R!M86YY(&UO
M;G1H<R!W:6QL(&)E(&1E;&5T960N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL>2(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!$96QE=&4@3&EN:V5D($%T=&%C:&UE;G1S($UO;G1H;'D\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!4=7)N('1H:7,@;W!T:6]N(&]N(&EF('EO=2!W
M;W5L9"!L:6ME('1O(&1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T
M('1H92!B96=I;FYI;F<@;V8@979E<GD@;6]N=&@N("!4:&ES(&UA>2!B92!U
M<V5F=6P@:68@>6]U(&AA=F4@82!Q=6]T82P@9F]R(&5X86UP;&4N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?871T
M86-H;65N='-?;6]N=&AL>5]K965P(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1E;&5T92!,:6YK960@071T
M86-H;65N=',@36]N=&AL>2`M(",@;V8@36]N=&AS('1O($ME97`\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@87)E(&1E;&5T:6YG(&]L9"!L:6YK
M960@871T86-H;65N=',@979E<GD@;6]N=&@L(&AO=R!M86YY(&UO;G1H<R!O
M9B!O;&0@871T86-H;65N=',@9&\@>6]U("!W86YT('1O(&ME97`_("!!;GD@
M871T86-H;65N=',@;VQD97(@=&AA;B!T:&ES(&UA;GD@;6]N=&AS('=I;&P@
M8F4@9&5L971E9"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+7!U<F=E7W1R87-H(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U<F=E(%1R87-H/"]T:71L93X*
M("`@(#QP87)A/@H@("`@1&\@>6]U('=A;G0@=&\@<'5R9V4@>6]U<B!T<F%S
M:"!F;VQD97(@979E<GD@<V\@;V9T96XN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]I;G1E<G9A;"(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!0=7)G92!4<F%S:"!);G1E<G9A;#PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($EF('EO=2!A<F4@<'5R9VEN9R!Y;W5R('1R87-H(&9O;&1E<BP@:&]W(&]F
M=&5N('-H;W5L9"!I="!B92!P=7)G960_"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]K965P(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z(%!U
M<F=E(%1R87-H($ME97`\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M87)E('!U<F=I;F<@>6]U<B!T<F%S:"!F;VQD97(L(&UE<W-A9V4@;VQD97(@
M=&AA;B!H;W<@;6%N>2!D87ES('-H;W5L9"!B92!P=7)G960_"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUA='1R:6)?=&5X="(@
M<W1A=&4](FYE=R(^"B`@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-97-S86=E
M($-O;7!O<VET:6]N.B!!='1R:6)U=&EO;B!497AT/"]T:71L93X*("`@("`\
M<&%R83X*("`@("!(97)E('EO=2!C86X@96YT97(@=&AE('!H<F%S92!T:&%T
M('EO=2!W:7-H('1O(&%P<&5A<B!B969O<F4@86YY('%U;W1E9"!T97AT(&EN
M(&$@<F5P;'D@=&AA="!Y;W4@<V5N9"X*("`@("`\+W!A<F$^"B`@("`@/'!A
M<F$^"B`@("`@66]U(&-A;B!I;F-L=61E(&]N92!O<B!M;W)E('-P96-I86P@
M<&QA8V5H;VQD97)S('1O(&EN<V5R="!I;F9O<FUA=&EO;B!A8F]U="!T:&4@
M;65S<V%G92!T;R!W:&EC:"!Y;W4@87)E(')E<&QY:6YG+B!0;&%C96AO;&1E
M<G,@8V]N<VES="!O9B!A("<E)R!F;VQL;W=E9"!B>2!A('-I;F=L92!L971T
M97(N(%1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&%R92!A=F%I;&%B;&4Z
M"B`@("`@/"]P87)A/@H*("`@("`\<&%R83X@)68@.B!4:&4@<V5N9&5R)W,@
M;F%M92!A;F0@96UA:6P@861D<F5S<SPO<&%R83X*("`@("`\<&%R83X@)6$@
M.B!4:&4@<V5N9&5R)W,@96UA:6P@861D<F5S<SPO<&%R83X*("`@("`\<&%R
M83X@)7`@.B!4:&4@<V5N9&5R)W,@;F%M93PO<&%R83X*("`@("`\<&%R83X@
M)7(@.B!4:&4@9G5L;"!21D,@,C@R,B!S='EL92!D871E(&%N9"!T:6UE('IO
M;F4\+W!A<F$^"B`@("`@/'!A<F$^("5D(#H@5&AE(&1A=&4@87,@=W=W+"!D
M9"!M;6T@65E963PO<&%R83X*("`@("`\<&%R83X@)7@@.B!4:&4@9&%T92!I
M;B!T:&4@;&]C86QE)W,@9&5F875L=#PO<&%R83X*("`@("`\<&%R83X@)6,@
M.B!4:&4@9&%T92!A;F0@=&EM92!I;B!T:&4@;&]C86QE)W,@9&5F875L=#PO
M<&%R83X*("`@("`\<&%R83X@)6T@.B!4:&4@365S<V%G92U)1#PO<&%R83X*
M("`@("`\<&%R83X@)7,@.B!4:&4@<W5B:F5C=#PO<&%R83X*("`@("`\<&%R
M83X@)6X@.B!!(&YE=R!L:6YE/"]P87)A/@H@("`@(#QP87)A/B`E)2`Z(%1H
M92`G)2<@8VAA<F%C=&5R/"]P87)A/@H*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61I<W!O<VET:6]N7W)E<75E<W1?<F5A9"(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%)E<75E<W0@4F5A9"!296-E:7!T
M<SPO=&ET;&4^"B`@("`\<&%R83X*("`@(")297%U97-T(&$@4F5A9"!296-E
M:7!T(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E8VEP:65N=',@;V8@=&AI
M<R!M97-S86=E('1O(&YO=&EF>2!Y;W4@=VAE;B!T:&ES(&UE<W-A9V4@:7,@
M;W!E;F5D(&)Y('1H92!R96-I<&EE;G1S+B!.;W0@86QL(&-L:65N=',@<W5P
M<&]R="`O(&AO;F]R('1H:7,N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S96YD7VUD;B(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z(%-E;F0@341./"]T:71L93X*
M("`@(#QP87)A/@H@("`@(E-E;F0@82!-1$XB('-E;F1S(&$@365S<V%G92!$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@*&%L<V\@:VYO=VX@87,@82!R96%D
M(')E8V5I<'0I('=H96X@>6]U('9I97<@82!M97-S86=E(&EN('=H:6-H('1H
M92!U<V5R(&AA<R!R97%U97-T960@=&AA="!T:&5Y(')E8V5I=F4@;F]T:69I
M8V%T:6]N('1H870@>6]U(&AA=F4@<F5A9"!T:&4@;65S<V%G92X@26X@;6]S
M="!C87-E<RP@=&AI<R!W:6QL(&AA<'!E;B!A=71O;6%T:6-A;&QY('=I=&AO
M=70@<')O;7!T:6YG('EO=2X@26X@8V5R=&%I;B!I<V]L871E9"!C87-E<RP@
M>6]U(&UA>2!H879E('1O(&UA;G5A;&QY(&1E8VED92!T;R!S96YD('1H92!N
M;W1I9FEC871I;VX@8GD@8VQI8VMI;F<@;VX@82!L:6YK+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&ES<&]S:71I;VY?<F5Q
M=65S=%]D96QI=F5R>2(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z(%)E<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N/"]T:71L93X*
M("`@(#QP87)A/@H@("`@(E)E<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N
M(B!S96YD<R!A(')E<75E<W0@=&\@=&AE(')E8VEP:65N="=S(&4M;6%I;"!S
M97)V97(@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&AA<R!D96QI=F5R960@=&AE
M(&UE<W-A9V4@=&\@=&AE(')E8VEP:65N="=S(&UA:6QB;W@N($ET(&1O97-N
M)W0@;65A;B!T:&4@;65S<V%G92!H87,@8F5E;B!S965N+"!J=7-T('1H870@
M:70G<R!S:71T:6YG(&EN(&$@;6%I;&)O>"!S;VUE=VAE<F4N($YO="!A;&P@
M;6%I;"!S97)V97)S('-U<'!O<G0@=&AI<RX@"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?<W!A;5]A9G1E<E]R97!O
M<G0B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!$96QE
M=&4@4W!A;2!!9G1E<B!297!O<G1I;F<\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!9;W4@;6%Y(&5L96-T('1O(&1O(&]N92!O9B!T:')E92!I=&5M<R!A9G1E
M<B!R97!O<G1I;F<@82!M97-S86=E(&%S(&5I=&AE<B!S<&%M(&]R(&EN;F]C
M96YT+@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!&:7)S="P@>6]U(&-A
M;B!D96-I9&4@=&\@9&\@;F]T:&EN9R`M('1H92!M97-S86=E('=I;&P@8F4@
M<F5P;W)T960@87,@96ET:&5R('-P86T@;W(@:6YN;V-E;G0@8G5T('=I;&P@
M;W1H97)W:7-E(')E;6%I;B!U;F-H86YG960@:6X@>6]U<B!M86EL8F]X+@H@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@("!396-O;F0L(&EF(')E<&]R=&EN
M9R!A(&UE<W-A9V4@87,@<W!A;2P@>6]U(&-A;B!I;G-T96%D(&AA=F4@=&AE
M(&UE<W-A9V4@8F4@:6UM961I871E;'D@9&5L971E9"X@(%1H:7,@<V5T=&EN
M9R!H87,@;F\@969F96-T(&]N(')E<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN
M;V-E;G0N"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@(%1H:7)D+"!A9G1E
M<B!R97!O<G1I;F<@82!M97-S86=E(&%S('-P86T@=&AE(&UE<W-A9V4@=VEL
M;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E;G0@;6%I;&)O>"!A;F0@;6]V
M960@=&\@>6]U<B!S<&%M(&9O;&1E<BX@($%L=&5R;F%T:79E;'DL(&EF(')E
M<&]R=&EN9R!A(&UE<W-A9V4@87,@:6YN;V-E;G0@=&AE(&UE<W-A9V4@=VEL
M;"!B92!D96QE=&5D(&9R;VT@=&AE(&-U<G)E;G0@;6%I;&)O>"!A;F0@;6]V
M960@=&\@>6]U<B!)3D)/6"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+6AT;6Q?:6UA9V5?<F5P;&%C96UE;G0B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!(5$U,($EM86=E(%)E<&QA
M8V5M96YT/"]T:71L93X*("`@(#QP87)A/@H@("`@1F]R($A434P@;65S<V%G
M97,@9&ES<&QA>65D(&EN;&EN92P@<VAO=6QD(&%L;"!I;6%G92!T86=S(&)E
M(&)L;V-K960@=6YT:6P@>6]U('-P96-I9FEC86QL>2!D96-I9&4@=&\@=FEE
M=R!T:&]S92!I;6%G97,_($YO=&4@=&AA="P@:68@=FEE=VEN9R!A;B!(5$U,
M(&%T=&%C:&UE;G0L('1H92!I;6%G97,@=VEL;"!A;'=A>7,@8F4@9&ES<&QA
M>65D+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M:'1M;%]I;6%G95]A9&1R8F]O:R(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($A434P@26UA9V4@4F5P;&%C96UE;G0O061D<F5S<V)O
M;VL@4VAO=SPO=&ET;&4^"B`@("`\<&%R83X*("`@($EF(&)L;V-K:6YG(&EM
M86=E<R!F;W(@:6YL:6YE($A434P@;65S<V%G97,L('-H;W5L9"!W92!A=71O
M;6%T:6-A;&QY(&1I<W!L87D@=&AE;2!I;G-T96%D(&EF('1H92!S96YD97(@
M87!P96%R<R!I;B!Y;W5R(&%D9')E<W-B;V]K/PH@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M;6%I;&)O>%]S=&%R="(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6QB;W@@4W1A<G0@
M4&%G93PO=&ET;&4^"B`@("`\<&%R83X*("`@($1E=&5R;6EN97,@=VAI8V@@
M<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W('=I;&P@8F4@9&ES<&QA>65D('=H
M96X@>6]U(&%C8V5S<R!A(&UA:6QB;W@@9F]R('1H92!F:7)S="!T:6UE+B!.
M;W1E('1H870@=&AE("=U;G-E96XG(&UE<W-A9V4@;W!T:6]N<R!D;R!N;W0@
M=V]R:R!W:71H('1H92`G5&AR96%D)R!S;W)T:6YG(&]P=&EO;B`M(&EN<W1E
M860L('EO=2!W:6QL(&)E('-E;G0@=&\@=&AE(&QA<W0@<&%G92X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7-A=F5?871T86-H
M;65N=',B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!3
M879E($%T=&%C:&UE;G1S(&]N(%-E;G0@365S<V%G97,\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!S879I;F<@82!C;VUP;W-E9"!M97-S86=E(&EN(&$@
M<V5N="UM86EL(&9O;&1E<BP@9&5T97)M:6YE(&EF(&%L;"!A='1A8VAM96YT
M(&1A=&$@:7,@<V%V960N(%1H92!F;VQL;W=I;F<@;W!T:6]N<R!A<F4@879A
M:6QA8FQE.@H@("`@/"]P87)A/@H*("`@(#QP87)A/BH@(D%L=V%Y<R!S879E
M(&%T=&%C:&UE;G1S(B`M($Y%5D52('!R;VUP="!T;R!S879E(&%T=&%C:&UE
M;G1S(&EN(&-O;7!O<V4@<V-R965N.R!T:&4@871T86-H;65N=',@87)E($%,
M5T%94R!S879E9"!W:71H('1H92!M97-S86=E+CPO<&%R83X*("`@("`\<&%R
M83XJ(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[
M(&1E9F%U;'0@=&\@6453(B`M($%,5T%94R!P<F]M<'0@=&\@<V%V92!A='1A
M8VAM96YT<R!I;B!T:&4@8V]M<&]S92!S8W)E96X[('1H92!D969A=6QT(&ES
M('1O('-A=F4@871T86-H;65N=',N/"]P87)A/@H@("`@(#QP87)A/BH@(E!R
M;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L
M="!T;R!.3R(@+2!!3%=!65,@<')O;7!T('1O('-A=F4@871T86-H;65N=',@
M:6X@=&AE(&-O;7!O<V4@<V-R965N.R!T:&4@9&5F875L="!I<R!T;R!N;W0@
M<V%V92!A='1A8VAM96YT<RX\+W!A<F$^"B`@("`@/'!A<F$^*B`B3F5V97(@
M<V%V92!A='1A8VAM96YT<R(@+2!.159%4B!P<F]M<'0@=&\@<V%V92!A='1A
M8VAM96YT<R!I;B!C;VUP;W-E('-C<F5E;CL@=&AE(&%T=&%C:&UE;G1S(&%R
M92!.159%4B!S879E9"!W:71H('1H92!M97-S86=E+CPO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G9I<G1U86Q?:6YB;W@B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E9I<G1U86P@1F]L9&5R<SH@5FER='5A;"!);F)O>#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@(%9I<G5T86P@26YB;W@@:7,@82!S879E9"!S
M96%R8V@@=&AA="!D;V5S(&%W87D@=VET:"!T:&4@;F5E9"!T;R!S96%R8V@@
M979E<GD@;6%I;&)O>"!F;W(@;65S<V%G97,@;6%R:V5D(&%S(&YE=RX@($EN
M<W1E860L(&%L;"!C=7)R96YT;'D@<W5B<V-R:6)E9"!M86EL8F]X97,@87)E
M('-E87)C:&5D(&9O<B!N97<@;65S<V%G97,@86YD('1H92!R97-U;'1S(&%R
M92!D:7-P;&%Y960@:6X@82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U86Q?=')A<V@B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E9I<G1U86P@1F]L9&5R<SH@5FER='5A;"!4<F%S
M:#PO=&ET;&4^"B`@("`\<&%R83X*("`@(%9I<G1U86P@5')A<V@@:7,@82!S
M879E9"!S96%R8V@@=&AA="!D;V5S(&%W87D@=VET:"!T:&4@;F5E9"!F;W(@
M82!S97!A<F%T92!4<F%S:"!F;VQD97(N("!);G-T96%D(&]F(&UO=FEN9R!M
M97-S86=E<R!T;R!A(&-E;G1R86QI>F5D('1R87-H(&9O;&1E<BP@;65S<V%G
M97,@87)E('-I;7!L>2!M87)K960@87,@9&5L971E9"!I;B!T:&4@8W5R<F5N
M="!F;VQD97(@=&AE>2!L:79E(&EN+B`@5VAE;B`G<VAO=R!D96QE=&5D(&UE
M<W-A9V5S)R!I<R!T=7)N960@;V9F+"!T:&ES(')E<W5L=',@:6X@=&AE<V4@
M;65S<V%G97,@;F]T(&%P<&5A<FEN9R!I;B!A(&UA:6QB;W@@=FEE=RX@(%=H
M96X@82!U<V5R(&-L:6-K<R!O;B!6:7)T=6%L(%1R87-H+"`J86QL*B!M86EL
M8F]X97,@86QL('-E87)C:&5D(&9O<B!M97-S86=E<R!T:&%T(&%R92!F;&%G
M9V5D(&1E;&5T960@86YD('1H97-E(&UE<W-A9V5S(&%R92!D:7-P;&%Y960@
M:6X@82!S:6YG;&4@;6%I;&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H
M96QP/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+WIH7U17+P``````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S8S`#`Q-S4P-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M;V-A;&4O>FA?5%<O3$-?34534T%'15,O````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C,`,#(Q,C<Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQO8V%L92]Z:%]45R],0U]-15-304=%4R]I;7`N
M;6\````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#4V-C<W-P`Q,#0Q-S,V,C<V,P`P
M,C(T-#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````!%"P``'````$1:```'#P``;+0```````"(\```"@```(GP
M```*````E/````H```"?\```"@```*KP```.````M?````\```#$\```#0``
M`-3P```(````XO````L```#K\```#````/?P```*````!/$```0````/\0``
M!````!3Q```8````&?$``!L````R\0``+0```$[Q```=````?/$``"0```":
M\0``*0```+_Q```9````Z?$```$````#\@``&0````7R```F````'_(```P`
M``!&\@``"P```%/R```D````7_(``!X```"$\@``2````*/R```K````[/(`
M`$0````8\P``)P```%WS```7````A?,```\```"=\P``"P```*WS```.````
MN?,```4```#(\P``*````,[S```(````]_,```H`````]```%0````OT```2
M````(?0``#(````T]```"P```&?T```I````<_0``#(```"=]```$````-#T
M```6````X?0``!````#X]```)@````GU```I````,/4``"8```!:]0``'```
M`('U``"%````GO4```X````D]@``"@```#/V```-````/O8``"<```!,]@``
M(@```'3V```.````E_8``"(```"F]@``)````,GV```W````[O8``!$````F
M]P``#0```#CW```,````1O<```T```!3]P``!@```&'W```;````:/<``)0`
M``"$]P``+@```!GX```W````2/@```8```"`^```#````(?X``!\````E/@`
M`&P````1^0``'````'[Y```=````F_D```H```"Y^0``#P```,3Y```8````
MU/D```P```#M^0``&P```/KY``!%````%OH``"@```!<^@``00```(7Z```D
M````Q_H```X```#L^@``#P```/OZ```.````"_L```X````:^P``"````"G[
M```.````,OL```X```!!^P``"0```%#[```N````6OL``!H```")^P``,P``
M`*3[``!1````V/L``#(````J_```.````%W\``!4````EOP``%$```#K_```
M6@```#W]``!7````F/T``#0```#P_0``"0```"7^```-````+_X```<````]
M_@``"@```$7^```/````4/X```4```!@_@```P```&;^```&````:OX``!$`
M``!Q_@``"````(/^```)````C/X```D```"6_@``'0```*#^```.````OOX`
M``@```#-_@``"@```-;^```E````X?X``"`````'_P``$P```"C_```0````
M//\```\```!-_P``#P```%W_```*````;?\```<```!X_P```P```(#_```9
M````A/\```\```">_P``%````*[_```)````P_\```T```#-_P``$@```-O_
M```9````[O\``!X````(``$`#P```"<``0`*````-P`!``\```!"``$`"```
M`%(``0`*````6P`!`"0```!F``$`%P```(L``0`4````HP`!`!8```"X``$`
M$@```,\``0`(````X@`!`!P```#K``$`3@````@!`0`M````5P$!`!D```"%
M`0$`8````)\!`0`H``````(!`!X````I`@$`&@```$@"`0`L````8P(!`"``
M``"0`@$`,@```+$"`0`'````Y`(!``P```#L`@$`#0```/D"`0!4````!P,!
M`&,```!<`P$`+````,`#`0`.````[0,!``,```#\`P$`"P`````$`0`'````
M#`0!``<````4!`$`!0```!P$`0`%````(@0!``H````H!`$``P```#,$`0`7
M````-P0!``H```!/!`$`#P```%H$`0`.````:@0!`$X```!Y!`$`4````,@$
M`0!#````&04!`$(```!=!0$`/0```*`%`0`6````W@4!`#````#U!0$`&```
M`"8&`0`C````/P8!``X```!C!@$`%````'(&`0`7````AP8!`!<```"?!@$`
M%P```+<&`0`3````SP8!``\```#C!@$`(P```/,&`0`&````%P<!`!<````>
M!P$`#@```#8'`0!1````10<!`!\```"7!P$`'0```+<'`0`U````U0<!`#4`
M```+"`$`!P```$$(`0`&````20@!``@```!0"`$`#P```%D(`0`&````:0@!
M``@```!P"`$`$0```'D(`0`*````BP@!`!,```"6"`$`"P```*H(`0`0````
MM@@!`!4```#'"`$`#0```-T(`0`3````ZP@!`",```#_"`$`+P```",)`0`5
M````4PD!``<```!I"0$`$````'$)`0`%````@@D!`!4```"("0$`$0```)X)
M`0`,````L`D!`#\```"]"0$`,````/T)`0!(````+@H!`"$```!W"@$`.P``
M`)D*`0`[````U0H!`#P````1"P$`.````$X+`0`K````APL!`#````"S"P$`
M,0```.0+`0`[````%@P!`#D```!2#`$`-0```(P,`0`)````P@P!``<```#,
M#`$`%````-0,`0`,````Z0P!``,```#V#`$`!0```/H,`0`)``````T!`!``
M```*#0$`"0```!L-`0`3````)0T!``,````Y#0$`.0```#T-`0`2````=PT!
M``P```"*#0$`-0```)<-`0`.````S0T!`$D```#<#0$`,P```"8.`0`*````
M6@X!`!8```!E#@$`+0```'P.`0`+````J@X!`"<```"V#@$`+````-X.`0`J
M````"P\!`"4````V#P$`"0```%P/`0`)````9@\!``H```!P#P$`!@```'L/
M`0`)````@@\!``<```",#P$`+P```)0/`0`W````Q`\!`"X```#\#P$`50``
M`"L0`0`M````@1`!`"P```"O$`$`+0```-P0`0`]````"A$!`#\```!($0$`
M+0```(@1`0!`````MA$!`",```#W$0$`(P```!L2`0!`````/Q(!`"T```"`
M$@$`,P```*X2`0`E````XA(!`!4````($P$`&0```!X3`0`I````.!,!`"0`
M``!B$P$`*````(<3`0!0````L!,!`!@````!%`$`$0```!H4`0`1````+!0!
M``H````^%`$`"P```$D4`0`*````510!`",```!@%`$`%@```(04`0`*````
MFQ0!`!````"F%`$`%@```+<4`0`6````SA0!`"X```#E%`$`!P```!05`0`'
M````'!4!`!0````D%0$`"@```#D5`0`(````1!4!`"<```!-%0$`"````'45
M`0`#````?A4!``<```""%0$`!P```(H5`0`&````DA4!`#@```"9%0$`!0``
M`-(5`0`'````V!4!``8```#@%0$`"````.<5`0`)````\!4!`"D```#Z%0$`
M#@```"06`0`*````,Q8!`$4````^%@$`!````(06`0`$````B18!``<```".
M%@$`"0```)86`0`&````H!8!`!$```"G%@$`!P```+D6`0`6````P18!``0`
M``#8%@$`)P```-T6`0`(````!1<!``8````.%P$`#0```!47`0`&````(Q<!
M`!X````J%P$`$0```$D7`0`(````6Q<!``T```!D%P$`#````'(7`0`'````
M?Q<!``,```"'%P$``P```(L7`0`7````CQ<!`!,```"G%P$`"````+L7`0`=
M````Q!<!``@```#B%P$`!````.L7`0`(````\!<!``@```#Y%P$`*@````(8
M`0`K````+1@!`%,```!9&`$`00```*T8`0`:````[Q@!`"`````*&0$`%0``
M`"L9`0`&````01D!``8```!(&0$`#@```$\9`0`5````7AD!`#X```!T&0$`
M&````+,9`0`B````S!D!`"X```#O&0$`'0```!X:`0`A````/!H!`%0```!>
M&@$`*0```+,:`0`*````W1H!``<```#H&@$`%0```/`:`0`.````!AL!``(`
M```5&P$`"@```!@;`0`/````(QL!``T````S&P$`#P```$$;`0`-````41L!
M``D```!?&P$`%````&D;`0`&````?AL!`!@```"%&P$`'0```)X;`0`3````
MO!L!`!$```#0&P$`%````.(;`0!/````]QL!``0```!''`$`#````$P<`0`&
M````61P!``H```!@'`$`#0```&L<`0`4````>1P!`&(```".'`$`)P```/$<
M`0!4````&1T!`%\```!N'0$`9````,X=`0`$````,QX!`!8````X'@$`#@``
M`$\>`0`<````7AX!``\```!['@$`,P```(L>`0`H````OQX!``4```#H'@$`
M!0```.X>`0`;````]!X!`!H````0'P$`#@```"L?`0`3````.A\!`!4```!.
M'P$`,````&0?`0`1````E1\!`!$```"G'P$`'````+D?`0`J````UA\!`#4`
M```!(`$`10```#<@`0`0````?2`!`"$```".(`$`!0```+`@`0`3````MB`!
M``L```#*(`$`$@```-8@`0`*````Z2`!``\```#T(`$`#0````0A`0!'````
M$B$!`!\```!:(0$`)0```'HA`0`S````H"$!`"L```#4(0$`-0`````B`0!"
M````-B(!`!T```!Y(@$`40```)<B`0`1````Z2(!`#$```#[(@$`.P```"TC
M`0`3````:2,!`$````!](P$`.````+XC`0`%````]R,!``P```#](P$`$0``
M``HD`0`-````'"0!``8````J)`$`#````#$D`0`&````/B0!`!<```!%)`$`
M"````%TD`0`,````9B0!`!0```!S)`$`#P```(@D`0`0````F"0!`!$```"I
M)`$`"````+LD`0`%````Q"0!`!$```#*)`$`#````-PD`0`0````Z20!``4`
M``#Z)`$`#0`````E`0`&````#B4!``<````5)0$`#0```!TE`0`'````*R4!
M``L````S)0$`!P```#\E`0`'````1R4!``D```!/)0$`%P```%DE`0`F````
M<24!`$\```"8)0$`"0```.@E`0`)````\B4!``H```#\)0$`&0````<F`0`]
M````(28!`!T```!?)@$`#````'TF`0`E````BB8!`!\```"P)@$`$````-`F
M`0`%````X28!`"4```#G)@$`(@````TG`0`2````,"<!`!,```!#)P$`*P``
M`%<G`0`[````@R<!`"````"_)P$`&P```.`G`0`(````_"<!`#8````%*`$`
M(0```#PH`0`0````7B@!``@```!O*`$`&P```'@H`0`>````E"@!`"\```"S
M*`$`7````.,H`0`N````0"D!``P```!O*0$`!````'PI`0`/````@2D!``X`
M``"1*0$`#@```*`I`0`'````KRD!``X```"W*0$`"@```,8I`0`-````T2D!
M`!\```#?*0$`'````/\I`0`A````'"H!`!X````^*@$`&0```%TJ`0`>````
M=RH!`!T```"6*@$`&P```+0J`0`L````T"H!`"````#]*@$`+@```!XK`0`F
M````32L!`"0```!T*P$`'````)DK`0`>````MBL!`!P```#5*P$`)@```/(K
M`0`V````&2P!`"L```!0+`$`,P```'PL`0`I````L"P!`$$```#:+`$`.@``
M`!PM`0`F````5RT!`"L```!^+0$`.````*HM`0`=````XRT!`!4````!+@$`
M+P```!<N`0`@````1RX!`!(```!H+@$`*0```'LN`0`>````I2X!`#T```#$
M+@$`(`````(O`0`2````(R\!`*(````V+P$`%@```-DO`0`C````\"\!`"@`
M```4,`$`*0```#TP`0`Z````9S`!`"@```"B,`$`'P```,LP`0`5````ZS`!
M`"`````!,0$`)0```"(Q`0`H````2#$!`"T```!Q,0$`,````)\Q`0"2````
MT#$!`"$```!C,@$`%@```(4R`0`<````G#(!`"8```"Y,@$`*@```.`R`0!!
M````"S,!`$0```!-,P$`#````)(S`0`'````GS,!``<```"G,P$`!@```*\S
M`0`-````MC,!``L```#$,P$`%0```-`S`0`4````YC,!``T```#[,P$`&```
M``DT`0`:````(C0!`!`````]-`$`'0```$XT`0`9````;#0!`%T```"&-`$`
M%0```.0T`0`E````^C0!`!(````@-0$`$P```#,U`0`2````1S4!``<```!:
M-0$`!````&(U`0`0````9S4!``P```!X-0$`#@```(4U`0`-````E#4!``\`
M``"B-0$`%````+(U`0`3````QS4!``T```#;-0$`.0```.DU`0`<````(S8!
M`"@```!`-@$``P```&DV`0`-````;38!``8```![-@$`$0```((V`0`7````
ME#8!`!L```"L-@$`#@```,@V`0`"````US8!`$D```#:-@$`!0```"0W`0`%
M````*C<!`!`````P-P$`#P```$$W`0`$````43<!``T```!6-P$`#@```&0W
M`0`#````<S<!``X```!W-P$`"````(8W`0`/````CS<!``@```"?-P$`"@``
M`*@W`0`/````LS<!``<```##-P$`#0```,LW`0`0````V3<!`!0```#J-P$`
M#0```/\W`0`9````#3@!`!H````G.`$`"P```$(X`0`)````3C@!``8```!8
M.`$`%````%\X`0`+````=#@!`!,```"`.`$`$````)0X`0`,````I3@!``H`
M``"R.`$`$0```+TX`0`7````SS@!`!$```#G.`$`%0```/DX`0`G````#SD!
M`!D````W.0$`"P```%$Y`0`-````73D!`"(```!K.0$`*P```(XY`0`7````
MNCD!`#0```#2.0$`,P````<Z`0`;````.SH!`#0```!7.@$`"@```(PZ`0`8
M````ESH!`!0```"P.@$`&0```,4Z`0`6````WSH!``<```#V.@$`$````/XZ
M`0`B````#SL!`!P````R.P$`'````$\[`0`-````;#L!``<```!Z.P$`#```
M`(([`0`F````CSL!``H```"V.P$`%````,$[`0`+````UCL!``<```#B.P$`
M(@```.H[`0`O````#3P!``L````]/`$`"0```$D\`0`9````4SP!``L```!M
M/`$`*@```'D\`0`/````I#P!`!<```"T/`$`%P```,P\`0`)````Y#P!``<`
M``#N/`$`%@```/8\`0`/````#3T!`"T````=/0$`&0```$L]`0`6````93T!
M``X```!\/0$`&@```(L]`0`H````ICT!`"T```#//0$`+@```/T]`0`+````
M+#X!`!@````X/@$`"````%$^`0`,````6CX!`",```!G/@$`#0```(L^`0`F
M````F3X!`"H```#`/@$`(````.L^`0!#````##\!``@```!0/P$`$@```%D_
M`0`?````;#\!``0```",/P$`"````)$_`0`+````FC\!`!H```"F/P$`)P``
M`,$_`0`2````Z3\!`"````#\/P$`+P```!U``0`7````34`!``4```!E0`$`
M#````&M``0`.````>$`!``X```"'0`$`!0```)9``0`&````G$`!``X```"C
M0`$``P```+)``0`#````MD`!`"L```"Z0`$`!P```.9``0`$````[D`!``X`
M``#S0`$`"@````)!`0`,````#4$!``H````:00$`#P```"5!`0`0````-4$!
M`!<```!&00$`$P```%Y!`0`E````<D$!``X```"800$`$0```*=!`0`9````
MN4$!`!<```#300$`$P```.M!`0`6````_T$!`#@````60@$`$P```$]"`0`)
M````8T(!``4```!M0@$`"P```'-"`0`*````?T(!``4```"*0@$`#0```)!"
M`0`;````GD(!`!<```"Z0@$`%````-)"`0`)````YT(!`!T```#Q0@$`#P``
M``]#`0`6````'T,!`!(````V0P$`"P```$E#`0`,````54,!``X```!B0P$`
M#0```'%#`0`2````?T,!`!D```"20P$`'````*Q#`0`X````R4,!`!@````"
M1`$`(````!M$`0`3````/$0!``D```!01`$``P```%I$`0`5````7D0!``L`
M``!T1`$`$P```(!$`0`(````E$0!``X```"=1`$`$````*Q$`0![````O40!
M`!@````Y10$`)P```%)%`0`I````>D4!`"P```"D10$`*````-%%`0`.````
M^D4!`#4````)1@$`$0```#]&`0`'````448!``4```!91@$`*0```%]&`0`8
M````B48!`!X```"B1@$`&P```,%&`0`9````W48!`!@```#W1@$`&P```!!'
M`0`3````+$<!``<```!`1P$`"````$A'`0`&````44<!``8```!81P$`&P``
M`%]'`0`0````>T<!``\```",1P$`$````)Q'`0`/````K4<!``L```"]1P$`
M#P```,E'`0`,````V4<!``\```#F1P$`!P```/9'`0`&````_D<!``H````%
M2`$`$@```!!(`0`-````(T@!``P````Q2`$`#@```#Y(`0!#````34@!`#T`
M``"12`$`"0```,](`0`,````V4@!``\```#F2`$`"````/9(`0`(````_T@!
M`!,````(20$`"P```!Q)`0`>````*$D!`"$```!'20$`(````&E)`0`9````
MBDD!`!<```"D20$`)0```+Q)`0`7````XDD!`!8```#Z20$`!````!%*`0`;
M````%DH!``T````R2@$`#````$!*`0`#````34H!``4```!12@$`"````%=*
M`0`*````8$H!``P```!K2@$`"@```'A*`0`@````@TH!`!\```"D2@$`&P``
M`,1*`0`9````X$H!``L```#Z2@$`&P````9+`0`+````(DL!`!`````N2P$`
M"````#]+`0`,````2$L!``0```!52P$`!````%I+`0`3````7TL!`!0```!S
M2P$`#````(A+`0`)````E4L!``X```"?2P$`"P```*Y+`0`;````NDL!``X`
M``#62P$`#P```.5+`0`E````]4L!`"H````;3`$`!P```$9,`0`2````3DP!
M`!L```!A3`$`!````'U,`0`'````@DP!``H```"*3`$`$@```)5,`0`*````
MJ$P!``T```"S3`$`"0```,%,`0`$````RTP!``4```#03`$`"````-9,`0`#
M````WTP!`!@```#C3`$`'0```/Q,`0`0````&DT!``X````K30$`'@```#I-
M`0`:````64T!``H```!T30$`!````']-`0`F````A$T!``X```"K30$`?```
M`+I-`0`5````-TX!`$0```!-3@$`!0```)).`0`'````F$X!``P```"@3@$`
M"````*U.`0`*````MDX!``8```#!3@$`!P```,A.`0`(````T$X!`!$```#9
M3@$`&0```.M.`0`(````!4\!``(````.3P$`!@```!%/`0`&````&$\!`!0`
M```?3P$`&@```#1/`0`-````3T\!`!````!=3P$`&P```&Y/`0`%````BD\!
M``0```"03P$`#````)5/`0`)````HD\!`!````"L3P$`"0```+U/`0`)````
MQT\!``0```#13P$`!0```-9/`0`:````W$\!``4```#W3P$`"````/U/`0`&
M````!E`!``\````-4`$`&0```!U0`0`.````-U`!``<```!&4`$`!P```$Y0
M`0`B````5E`!``4```!Y4`$`"0```']0`0`*````B5`!``(```"44`$`#0``
M`)=0`0`@````I5`!``8```#&4`$`"P```,U0`0`-````V5`!``P```#G4`$`
M"0```/10`0`&````_E`!`!(````%40$`"0```!A1`0`'````(E$!`!0````J
M40$`'0```#]1`0!"````75$!`"4```"@40$`)0```,91`0`&````[%$!``H`
M``#S40$`!````/Y1`0`)`````U(!``@````-4@$`$0```!92`0`)````*%(!
M``8````R4@$`#0```#E2`0`&````1U(!``0```!.4@$`!````%-2`0`7````
M6%(!`!X```!P4@$`!0```(]2`0`.````E5(!``0```"D4@$`!@```*E2`0`'
M````L%(!`"$```"X4@$`#0```-I2`0`5````Z%(!``8```#^4@$`!`````53
M`0`1````"E,!``8````<4P$`"@```"-3`0`B````+E,!`"<```!14P$`!@``
M`'E3`0`5````@%,!``P```"64P$`$0```*-3`0`$````M5,!``T```"Z4P$`
M!P```,A3`0`%````T%,!`!T```#64P$`!````/13`0`,````^5,!``X````&
M5`$`"@```!54`0`(````(%0!``D````I5`$`!0```#-4`0`Z````.50!`#``
M``!T5`$`-0```*54`0`I````VU0!`$<````%50$`.````$U5`0`I````AE4!
M`#\```"P50$`+@```/!5`0`M````'U8!`!\```!-5@$`#P```&U6`0`2````
M?58!``L```"05@$`)@```)Q6`0`G````PU8!`"D```#K5@$`)````!57`0`F
M````.E<!`"@```!A5P$`"````(I7`0`*````DU<!``D```">5P$`!P```*A7
M`0`$````L%<!`!P```"U5P$`-P```-)7`0`@````"E@!`"`````K6`$`)@``
M`$Q8`0`-````<U@!`"<```"!6`$`&P```*E8`0`B````Q5@!``P```#H6`$`
M%@```/58`0`%````#%D!``H````260$`&0```!U9`0`I````-UD!`!(```!A
M60$`!P```'19`0`*````?%D!``P```"'60$`#P```)19`0`0````I%D!`$``
M``"U60$`1````/99`0`\````.UH!`'````!X6@$`9@```.E:`0`&````4%L!
M``H```!76P$`!0```&);`0`.````:%L!``D```!W6P$`"@```(%;`0`2````
MC%L!`!,```"?6P$`#````+-;`0`&````P%L!``8```#'6P$`"@```,Y;`0`.
M````V5L!``\```#H6P$`#@```/A;`0`;````!UP!`!\````C7`$`'@```$-<
M`0`C````8EP!`!$```"&7`$`%0```)A<`0`8````KEP!`!$```#'7`$`$```
M`-E<`0`C````ZEP!``\````.70$`"0```!Y=`0`2````*%T!`!T````[70$`
M$@```%E=`0`0````;%T!``H```!]70$`$0```(A=`0`%````FET!`#$```"@
M70$`)````-)=`0`<````]UT!`",````47@$`:@```#A>`0`/````HUX!``4`
M``"S7@$`$````+E>`0`)````REX!``0```#47@$`"P```-E>`0`@````Y5X!
M`!P````&7P$`(P```"-?`0`B````1U\!``8```!J7P$`%````'%?`0`7````
MAE\!``P```">7P$`)````*M?`0`C````T%\!`!H```#T7P$`#`````]@`0`/
M````'&`!`!4````L8`$`*0```$)@`0`J````;&`!`"8```"78`$`)P```+Y@
M`0`I````YF`!`"H````080$`&0```#MA`0!"````56$!`!$```"880$`$@``
M`*IA`0`3````O6$!`!0```#180$`#P```.9A`0`6````]F$!`!<````-8@$`
M$````"5B`0`1````-F(!`#0```!(8@$`$P```'UB`0`2````D6(!`#4```"D
M8@$`%````-IB`0`'````[V(!``P```#W8@$`*P````1C`0`/````,&,!`!8`
M``!`8P$`(````%=C`0`0````>&,!`!0```")8P$`$0```)YC`0`H````L&,!
M`!<```#98P$`'````/%C`0`3````#F0!``L````B9`$`%````"YD`0`:````
M0V0!`!$```!>9`$`&@```'!D`0`>````BV0!`!H```"J9`$`$P```,5D`0`A
M````V60!`"````#[9`$`%0```!QE`0`1````,F4!`!<```!$90$`%````%QE
M`0`7````<64!`!4```")90$`"0```)]E`0`&````J64!`!````"P90$`&0``
M`,%E`0`$````VV4!``<```#@90$`"P```.AE`0`1````]&4!``8````&9@$`
M!@````UF`0`&````%&8!``4````;9@$`!P```"%F`0`'````*68!``4````Q
M9@$`%@```#=F`0`&````3F8!``8```!59@$`!````%QF`0`$````868!``<`
M``!F9@$`#@```&YF`0`,````?68!``P```"*9@$`#0```)=F`0`"````I68!
M``H```"H9@$`#@```+-F`0`%````PF8!`"@```#(9@$`#@```/%F`0`,````
M`&<!``\````-9P$`"@```!UG`0`(````*&<!``D````Q9P$`*P```#MG`0!/
M````9V<!`$<```"W9P$`4P```/]G`0`N````4V@!``0```"":`$`"````(=H
M`0`F````D&@!`!(```"W:`$`#P```,IH`0`&````VF@!``H```#A:`$`!P``
M`.QH`0`(````]&@!`"````#]:`$`"0```!YI`0`1````*&D!``D````Z:0$`
M%````$1I`0`,````66D!``T```!F:0$`#@```'1I`0`6````@VD!`!$```":
M:0$`!@```*QI`0`#````LVD!``8```"W:0$`!P```+YI`0`$````QFD!``L`
M``#+:0$`"P```-=I`0`'````XVD!``<```#K:0$`%@```/-I`0`-````"FH!
M``T````8:@$`"@```"9J`0`0````,6H!``\```!":@$`$0```%)J`0`7````
M9&H!``H```!\:@$`$0```(=J`0`(````F6H!``0```"B:@$`$0```*=J`0`/
M````N6H!`#H```#):@$`(0````1K`0`%````)FL!`!<````L:P$`'@```$1K
M`0`.````8VL!`!````!R:P$`"P```(-K`0!\````CVL!``P````,;`$`"0``
M`!EL`0`'````(VP!``H````K;`$`"0```#9L`0`.````0&P!`!````!/;`$`
M%0```&!L`0`;````=FP!`!@```"2;`$`&@```*ML`0`*````QFP!``D```#1
M;`$`"@```-ML`0`.````YFP!``P```#U;`$`#P````)M`0`(````$FT!``8`
M```;;0$`#````")M`0`'````+VT!``4````W;0$`"P```#UM`0!'````26T!
M``T```"1;0$`"0```)]M`0`$````J6T!``,```"N;0$`#````+)M`0`3````
MOVT!`!,```#3;0$`$P```.=M`0`&````^VT!``H````";@$``@````UN`0`$
M````$&X!`"4````5;@$``P```#MN`0`%````/VX!`"H```!%;@$`#@```'!N
M`0`*````?VX!``4```"*;@$`!````)!N`0`*````E6X!``T```"@;@$`'P``
M`*YN`0`'````SFX!`"(```#6;@$`#0```/EN`0`&````!V\!``@````.;P$`
M"````!=O`0`$````(&\!``4````E;P$`:````"MO`0`)````E&\!``P```">
M;P$`!0```*MO`0`&````L6\!`",```"X;P$`)0```-QO`0`(`````G`!`#<`
M```+<`$`(@```$-P`0`3````9G`!`!L```!Z<`$`+P```)9P`0`0````QG`!
M``H```#7<`$`$0```.)P`0`/````]'`!``\````$<0$`"@```!1Q`0`)````
M'W$!`!,````I<0$`&P```#UQ`0`8````67$!`!<```!R<0$`%P```(IQ`0`9
M````HG$!`!\```"\<0$`#@```-QQ`0`F````ZW$!`"8````2<@$``P```#ER
M`0`'````/7(!``@```!%<@$`!P```$YR`0`0````5G(!``H```!G<@$`"P``
M`')R`0`'````?G(!`!,```"&<@$`#````)IR`0`/````IW(!``X```"W<@$`
M#````,9R`0`.````TW(!`%$```#B<@$`#P```#1S`0`0````1',!``T```!5
M<P$`#P```&-S`0`/````<W,!`!<```"#<P$`%````)MS`0`1````L',!``\`
M``#"<P$`(````-)S`0`N````\W,!`!H````B=`$`#````#UT`0`F````2G0!
M``L```!Q=`$`&@```'UT`0!*````F'0!`!D```#C=`$`!@```/UT`0`:````
M!'4!`"4````?=0$`!@```$5U`0`&````3'4!`!\```!3=0$`!@```'-U`0`)
M````>G4!`!@```"$=0$`%P```)UU`0`H````M74!``8```#>=0$`#0```.5U
M`0`B````\W4!`%<````6=@$`$P```&YV`0`C````@G8!`!,```"F=@$``@``
M`+IV`0`+````O78!``@```#)=@$`#0```-)V`0`&````X'8!``H```#G=@$`
M!P```/)V`0`4````^G8!``8````/=P$`"````!9W`0`.````'W<!``<````N
M=P$`"@```#9W`0`+````07<!`#(```!-=P$`*P```(!W`0`'````K'<!``P`
M``"T=P$`#0```,%W`0`,````SW<!``0```#<=P$`"0```.%W`0`)````ZW<!
M``H```#U=P$`!P````!X`0`)````"'@!`$`````2>`$`#@```%-X`0`'````
M8G@!``H```!J>`$`&P```'5X`0`5````D7@!`!4```"G>`$`$@```+UX`0`*
M````T'@!`!8```#;>`$`"0```/)X`0`0````_'@!``<````->0$`$@```!5Y
M`0`$````*'D!``0````M>0$`!````#)Y`0`A````-WD!``<```!9>0$`!0``
M`&%Y`0`,````9WD!``4```!T>0$`"P```'IY`0`4````AGD!`!$```";>0$`
M&@```*UY`0`6````R'D!`!0```#?>0$`%P```/1Y`0`8````#'H!`!P````E
M>@$`&0```$)Z`0`'````7'H!``4```!D>@$`%@```&IZ`0`#````@7H!``T`
M``"%>@$`#````)-Z`0`*````H'H!``@```"K>@$`"P```+1Z`0`1````P'H!
M``@```#2>@$`%P```-MZ`0`+````\WH!``P```#_>@$`#`````Q[`0`?````
M&7L!`!H````Y>P$`$P```%1[`0`$````:'L!``H```!M>P$`!````'A[`0`,
M````?7L!``D```"*>P$`#````)1[`0`%````H7L!``D```"G>P$`!0```+%[
M`0`'````MWL!``4```"_>P$`!````,5[`0`"````RGL!`!0```#->P$`#0``
M`.)[`0`2````\'L!``L````#?`$`&P````]\`0`?````*WP!``\```!+?`$`
M%````%M\`0`>````<'P!`!4```"/?`$`.````*5\`0`L````WGP!`!(````+
M?0$`*0```!Y]`0`R````2'T!``H```![?0$`+````(9]`0`N````LWT!`#,`
M``#B?0$`,P```!9^`0`X````2GX!``\```"#?@$`&````)-^`0`O````K'X!
M`!````#<?@$`$P```.U^`0`J`````7\!`!D````L?P$`'````$9_`0`?````
M8W\!``\```"#?P$`$P```)-_`0`5````IW\!`!0```"]?P$`%````-)_`0`@
M````YW\!`!(````(@`$`%````!N``0`M````,(`!`"T```!>@`$`,0```(R`
M`0`N````OH`!`"\```#M@`$`+````!V!`0!B````2H$!`!,```"M@0$`)0``
M`,&!`0`D````YX$!`"D````,@@$`2````#:"`0`-````?X(!``@```"-@@$`
M%P```):"`0`(````KH(!`"0```"W@@$`$@```-R"`0`,````[X(!``X```#\
M@@$`-P````N#`0`K````0X,!`!(```!O@P$`(0```(*#`0`:````I(,!``D`
M``"_@P$`10```,F#`0!!````#X0!``\```!1A`$`!````&&$`0`3````9H0!
M`!0```!ZA`$`#@```(^$`0`&````GH0!`!,```"EA`$`&````+F$`0`&````
MTH0!``D```#9A`$`"@```..$`0`+````[H0!``D```#ZA`$`#0````2%`0`,
M````$H4!``\````?A0$`%P```"^%`0`4````1X4!`!````!<A0$`%@```&V%
M`0`'````A(4!``X```",A0$`(0```)N%`0`%````O84!``<```##A0$`&P``
M`,N%`0`J````YX4!``@````2A@$`!@```!N&`0`4````(H8!`!$````WA@$`
M1````$F&`0`\````CH8!``X```#+A@$`.````-J&`0`"````$X<!``(````6
MAP$`!@```!F'`0`.````((<!``4````OAP$`!P```#6'`0`&````/8<!`"@`
M``!$AP$`#````&V'`0`,````>H<!`!P```"'AP$`(P```*2'`0`$````R(<!
M`"D```#-AP$`,@```/>'`0`?````*H@!`#,```!*B`$`7````'Z(`0`,````
MVX@!`!0```#HB`$`/@```/V(`0`-````/(D!`!\```!*B0$`$````&J)`0`4
M````>XD!``<```"0B0$`#@```)B)`0`,````IXD!``P```"TB0$`$P```,&)
M`0`*````U8D!`!T```#@B0$`&0```/Z)`0`%````&(H!`!$````>B@$`$P``
M`#"*`0`-````1(H!``\```!2B@$`$0```&**`0`D````=(H!`!(```"9B@$`
M`P```*R*`0`5````L(H!`!,```#&B@$`$@```-J*`0`+````[8H!`#0```#Y
MB@$`"P```"Z+`0`4````.HL!`#X```!/BP$`#@```(Z+`0`3````G8L!`#0`
M``"QBP$`,0```.:+`0`2````&(P!`!`````KC`$`&````#R,`0`9````58P!
M`",```!OC`$`(@```).,`0`G````MHP!`%8```#>C`$`30```#6-`0"Y````
M@XT!``@````]C@$`"0```$:.`0`-````4(X!``H```!>C@$`!P```&F.`0`/
M````<8X!``8```"!C@$`"P```(B.`0`$````E(X!`!P```"9C@$`#0```+:.
M`0`G````Q(X!`!L```#LC@$`#`````B/`0`:````%8\!``H````PCP$`!P``
M`#N/`0`-````0X\!`"(```!1CP$`(0```'2/`0`(````EH\!``4```"?CP$`
M'P```*6/`0`&````Q8\!`!````#,CP$`"````-V/`0`'````YH\!``T```#N
MCP$`"@```/R/`0`2````!Y`!`"$````:D`$`"P```#R0`0`;````2)`!`!@`
M``!DD`$`"````'V0`0`>````AI`!`!(```"ED`$`+````+B0`0`:````Y9`!
M``D`````D0$`"@````J1`0`5````%9$!``4````KD0$`%````#&1`0`$````
M1I$!`!````!+D0$`!@```%R1`0`'````8Y$!`!X```!KD0$`*````(J1`0`*
M````LY$!`!P```"^D0$`$0```-N1`0`+````[9$!`!H```#YD0$`+````!22
M`0`(````09(!`!0```!*D@$`+````%^2`0`G````C)(!`"L```"TD@$`*@``
M`."2`0`$````"Y,!``0````0DP$`"P```!63`0`%````(9,!``8````GDP$`
M"````"Z3`0`&````-Y,!`#$````^DP$`'````'"3`0"B````C9,!`!L````P
ME`$`-````$R4`0`T````@90!`"````"VE`$`*0```->4`0`G`````94!`"``
M```IE0$`00```$J5`0`:````C)4!`"@```"GE0$`&@```-"5`0!V````ZY4!
M`'D```!BE@$`'`$``-R6`0`H````^9<!`!T````BF`$`*0```$"8`0`=````
M:I@!`%````"(F`$`+@```-F8`0`V````")D!`"P````_F0$`,0```&R9`0`N
M````GID!`"(```#-F0$`!@```/"9`0`(````]YD!``4`````F@$`"`````::
M`0`9````#YH!`!D````IF@$`*@```$.:`0`0````;IH!`"L```!_F@$`(P``
M`*N:`0`9````SYH!`"$```#IF@$`+@````N;`0`T````.IL!``@```!OFP$`
M%P```'B;`0`*````D)L!``<```";FP$`(0```*.;`0`0````Q9L!``T```#6
MFP$`$````.2;`0`%````]9L!``X```#[FP$`"`````J<`0`+````$YP!`!0`
M```?G`$`!P```#2<`0`3````/)P!``@```!0G`$`-@```%F<`0`W````D)P!
M``L```#(G`$`"0```-2<`0`*````WIP!`!0```#IG`$`#P```/Z<`0`O````
M#IT!`#(````^G0$`"P```'&=`0`.````?9T!``T```",G0$`#P```)J=`0`6
M````JIT!`#X```#!G0$`)P````">`0`F````*)X!`"0```!/G@$`!0```'2>
M`0`%````>IX!``4```"`G@$`)P```(:>`0`?````KIX!`!8```#.G@$`"P``
M`.6>`0`7````\9X!``\````)GP$`!````!F?`0`*````'I\!``D````IGP$`
M"P```#.?`0`-````/Y\!``P```!-GP$`#@```%J?`0`%````:9\!``0```!O
MGP$`#0```'2?`0`R````@I\!`$4```"UGP$`"P```/N?`0`.````!Z`!``X`
M```6H`$`"0```"6@`0`(````+Z`!`!`````XH`$`%0```$F@`0`3````7Z`!
M`!<```!SH`$`!P```(N@`0`>````DZ`!`!4```"RH`$`%````,B@`0`%````
MW:`!`!0```#CH`$`!@```/B@`0`+````_Z`!``<````+H0$`(P```!.A`0`6
M````-Z$!``\```!.H0$`#@```%ZA`0`J````;:$!``8```"8H0$`#````)^A
M`0`8````K*$!``T```#%H0$`$0```-.A`0`+````Y:$!`#8```#QH0$`#0``
M`"BB`0`*````-J(!`"(```!!H@$`"P```&2B`0`/````<*(!`!````"`H@$`
M+@```)&B`0`Z````P*(!``X```#[H@$`#0````JC`0`%````&*,!``L````>
MHP$`#````"JC`0`-````-Z,!``T```!%HP$`#@```%.C`0`-````8J,!`"``
M``!PHP$`)P```)&C`0`K````N:,!``@```#EHP$`"@```.ZC`0`&````^:,!
M`!(`````I`$`#@```!.D`0`7````(J0!`#(````ZI`$`%@```&VD`0`<````
MA*0!`"4```"AI`$`,````,>D`0`Q````^*0!`"T````JI0$`#@```%BE`0`4
M````9Z4!``4```!\I0$`#@```(*E`0`3````D:4!`!H```"EI0$`$@```,"E
M`0`'````TZ4!``8```#;I0$`$P```.*E`0`?````]J4!`!0````6I@$`$0``
M`"NF`0!+````/:8!`!,```")I@$`!P```)VF`0`4````I:8!`!@```"ZI@$`
M!P```-.F`0`%````VZ8!``P```#AI@$`#````.ZF`0`2````^Z8!``0````.
MIP$`!P```!.G`0`*````&Z<!``L````FIP$`#````#*G`0`.````/Z<!``X`
M``!.IP$`!0```%VG`0`%````8Z<!`"X```!IIP$`)@```)BG`0`C````OZ<!
M``,```#CIP$`$@```.>G`0`&````^J<!``8````!J`$`'@````BH`0`6````
M)Z@!`!@````^J`$`#@```%>H`0`W````9J@!``X```">J`$`%P```*VH`0!!
M````Q:@!`#0````'J0$`)0```#RI`0`5````8JD!`#$```!XJ0$`$P```*JI
M`0`;````OJD!`"H```#:J0$`40````6J`0!9````5ZH!`%````"QJ@$`OP``
M``*K`0`E````PJL!``T```#HJP$`"0```/:K`0`#`````*P!``<````$K`$`
M"@````RL`0`(````%ZP!``(````@K`$`$````".L`0`(````-*P!``P````]
MK`$`%0```$JL`0`+````8*P!`!D```!LK`$`(````(:L`0`2````IZP!``4`
M``"ZK`$`"@```,"L`0`5````RZP!`!(```#AK`$`#````/2L`0`$`````:T!
M``D````&K0$`!P```!"M`0`R````&*T!``H```!+K0$`"@```%:M`0`5````
M8:T!``P```!WK0$`#P```(2M`0`+````E*T!``<```"@K0$`%@```*BM`0!2
M````OZT!`#H````2K@$`(````$VN`0`/````;JX!`!<```!^K@$`)````):N
M`0`Y````NZX!`!(```#UK@$`!P````BO`0`&````$*\!``D````7KP$`#@``
M`"&O`0`.````,*\!``X````_KP$`!````$ZO`0`&````4Z\!`!8```!:KP$`
M#````'&O`0`-````?J\!``X```",KP$`%0```)NO`0`2````L:\!``\```#$
MKP$`%````-2O`0`4````Z:\!`$,```#^KP$`"@```$*P`0`;````3;`!`#4`
M``!IL`$`$0```)^P`0`0````L;`!``L```#"L`$`:0```,ZP`0`:````.+$!
M`!<```!3L0$`*````&NQ`0`G````E+$!`!L```"\L0$`&@```-BQ`0`7````
M\[$!`!L````+L@$`&0```">R`0`?````0;(!`!<```!AL@$`'````'FR`0`7
M````EK(!``P```"NL@$`$P```+NR`0`(````S[(!`"\```#8L@$`!P````BS
M`0`(````$+,!`!`````9LP$`$0```"JS`0`)````/+,!`!4```!&LP$`#0``
M`%RS`0`&````:K,!`!T```!QLP$`(P```(^S`0`'````L[,!``T```"[LP$`
M$P```,FS`0`(````W;,!``,```#FLP$`1@```.JS`0!#````,;0!`#(```!U
MM`$`/P```*BT`0`W````Z+0!`%<````@M0$`!0```'BU`0`?````?K4!`"\`
M``">M0$`"@```,ZU`0`-````V;4!`!(```#GM0$`*0```/JU`0`(````)+8!
M``T````MM@$`+0```#NV`0!P````:;8!`#\```#:M@$`.0```!JW`0!&````
M5+<!``0```";MP$`$````*"W`0`0````L;<!``P```#"MP$`%````,^W`0`=
M````Y+<!`!P````"N`$`$0```!^X`0`]````,;@!`$\```!ON`$`)0```+^X
M`0`@````Y;@!``L````&N0$`)P```!*Y`0`:````.KD!`!\```!5N0$`'0``
M`'6Y`0`H````D[D!``\```"\N0$`)0```,RY`0`@````\KD!`"0````3N@$`
M)````#BZ`0`@````7;H!`"4```!^N@$`"P```*2Z`0`'````L+H!``T```"X
MN@$`#````,:Z`0`7````T[H!``4```#KN@$`!@```/&Z`0`%````^+H!``P`
M``#^N@$`!P````N[`0`)````$[L!`!,````=NP$`!@```#&[`0`)````.+L!
M``0```!"NP$`$````$>[`0`(````6+L!``@```!ANP$`!````&J[`0`+````
M;[L!``P```![NP$`$@```(B[`0`1````F[L!``P```"MNP$`#P```+J[`0`'
M````RKL!``T```#2NP$`#P```."[`0`,````\+L!`!0```#]NP$`%````!*\
M`0`/````)[P!``X````WO`$`$@```$:\`0`4````6;P!``X```!NO`$`#```
M`'V\`0`;````BKP!`"P```"FO`$`$P```-.\`0`&````Y[P!``<```#NO`$`
M$P```/:\`0`%````"KT!``0````0O0$`#````!6]`0`7````(KT!`!(````Z
MO0$`*0```$V]`0`+````=[T!``T```"#O0$`%````)&]`0`O````IKT!``H`
M``#6O0$`#````.&]`0`)````[KT!``8```#XO0$`"0```/^]`0`(````";X!
M``D````2O@$`!0```!R^`0`*````(KX!`!$````MO@$`"@```#^^`0`0````
M2KX!`!````!;O@$`"P```&R^`0`&````>+X!``X```!_O@$`#@```(Z^`0`-
M````G;X!``L```"KO@$`$````+>^`0`=````R+X!`!$```#FO@$`"P```/B^
M`0`"````!+\!``@````'OP$`'````!"_`0`'````+;\!``T````UOP$`!@``
M`$._`0!D````2K\!`!8```"OOP$`"0```,:_`0`'````T+\!`"8```#8OP$`
M.````/^_`0`:````.,`!`"H```!3P`$`.P```'[``0`H````NL`!`#0```#C
MP`$`&0```!C!`0`5````,L$!``4```!(P0$`"P```$[!`0`'````6L$!``@`
M``!BP0$`!P```&O!`0`%````<\$!``<```!YP0$`#@```('!`0`)````D,$!
M``8```":P0$`"````*'!`0`+````JL$!``<```"VP0$`"````+[!`0`'````
MQ\$!`!8```#/P0$`"0```.;!`0`&````\,$!`!D```#WP0$`&@```!'"`0`@
M````+,(!``L```!-P@$`$````%G"`0`&````:L(!`!P```!QP@$`%````(["
M`0`'````H\(!`!$```"KP@$`"````+W"`0`.````QL(!``@```#5P@$`!0``
M`-["`0`0````Y,(!`!````#UP@$`!@````;#`0`9````#<,!``H````GPP$`
M'````#+#`0`'````3\,!``4```!7PP$`!0```%W#`0`0````8\,!`!0```!T
MPP$`"P```(G#`0`-````E<,!`"@```"CPP$`&````,S#`0`7````Y<,!``L`
M``#]PP$`&@````G$`0`4````),0!`"\````YQ`$`!````&G$`0`)````;L0!
M``H```!XQ`$`!P```(/$`0`"````B\0!``X```".Q`$`"````)W$`0`C````
MIL0!`#$```#*Q`$`.````/S$`0!X````-<4!`"8```"NQ0$`&P```-7%`0`Q
M````\<4!`#$````CQ@$`)P```%7&`0`B````?<8!`"````"@Q@$`9````,'&
M`0`=````)L<!`!0```!$QP$`'````%G'`0!=````=L<!`%4```#4QP$`.```
M`"K(`0`M````8\@!`#,```"1R`$`2P```,7(`0!*````$<D!`%L```!<R0$`
M*````+C)`0`L````X<D!`#@````.R@$`)0```$?*`0`A````;<H!`"@```"/
MR@$`+````+C*`0`F````Y<H!`!L````,RP$`'@```"C+`0!U````1\L!`#X`
M``"]RP$`0@```/S+`0`]````/\P!`#T```!]S`$`*0```+O,`0`I````Y<P!
M`#$````/S0$`/@```$'-`0`O````@,T!`",```"PS0$`8@```-3-`0!/````
M-\X!`!<```"'S@$`2````)_.`0`V````Z,X!`#X````?SP$`,````%[/`0`@
M````C\\!`#\```"PSP$`-````/#/`0`=````)=`!`!X```!#T`$`*@```&+0
M`0"%````C=`!`#`````3T0$`)0```$31`0!!````:M$!`&````"LT0$`6P``
M``W2`0!)````:=(!`#$```"ST@$`-````.72`0`\````&M,!`#@```!7TP$`
M'0```)#3`0`8````KM,!`*<```#'TP$`*P```&_4`0`A````F]0!`!\```"]
MU`$`/````-W4`0`D````&M4!`"@````_U0$`*P```&C5`0`B````E-4!`"$`
M``"WU0$`(P```-G5`0`E````_=4!`"4````CU@$`*0```$G6`0`G````<]8!
M`!<```";U@$`*0```+/6`0`@````W=8!`#(```#^U@$`'````#'7`0`N````
M3M<!`#H```!]UP$`'0```+C7`0`1````UM<!`#,```#HUP$`)0```!S8`0`X
M````0M@!`"<```![V`$`(````*/8`0`\````Q-@!`"8````!V0$`'P```"C9
M`0`P````2-D!`&D```!YV0$`+@```./9`0`Q````$MH!`$$```!$V@$`/@``
M`(;:`0`S````Q=H!`"4```#YV@$`/0```!_;`0!E````7=L!`$T```##VP$`
M4P```!'<`0!7````9=P!`%4```"]W`$`1@```!/=`0`J````6MT!`"\```"%
MW0$`50```+7=`0`@````"]X!`"X````LW@$`*P```%O>`0`P````A]X!`"H`
M``"XW@$`/@```./>`0!4````(M\!`%(```!WWP$`6@```,K?`0`R````)>`!
M`"L```!8X`$`2````(3@`0!*````S>`!`"H````8X0$`)@```$/A`0`L````
M:N$!`$X```"7X0$`,@```.;A`0`P````&>(!`!T```!*X@$`(P```&CB`0`O
M````C.(!`"P```"\X@$`+0```.GB`0`7````%^,!`"4````OXP$`,@```%7C
M`0`I````B.,!`#X```"RXP$`(@```/'C`0!2````%.0!`"4```!GY`$`"P``
M`(WD`0"Q````F>0!`#L```!+Y0$`)P```(?E`0!.````K^4!`$<```#^Y0$`
M8@```$;F`0!)````J>8!`%4```#SY@$`0````$GG`0`O````BN<!`#(```"Z
MYP$`*P```.WG`0`I````&>@!``\```!#Z`$`10```%/H`0`A````F>@!`#``
M``"[Z`$`+0```.SH`0`E````&ND!`!P```!`Z0$`,0```%WI`0`Q````C^D!
M``X```#!Z0$`"P```-#I`0`'````W.D!``<```#DZ0$`!````.SI`0`-````
M\>D!``L```#_Z0$`#@````OJ`0`+````&NH!``4````FZ@$`$````"SJ`0`"
M````/>H!``H```!`Z@$`5@```$OJ`0!9````HNH!`$X```#\Z@$`!0```$OK
M`0`2````4>L!``0```!DZP$`!P```&GK`0`(````<>L!``4```!ZZP$``P``
M`(#K`0`0````A.L!`!<```"5ZP$`#````*WK`0`-````NNL!`!,```#(ZP$`
M#0```-SK`0`"````ZNL!``<```#MZP$`!@```/7K`0`4````_.L!``P````1
M[`$`&````![L`0`&````-^P!`!(````^[`$`#````%'L`0`#````7NP!``0`
M``!B[`$`!@```&?L`0`'````;NP!`!\```!V[`$`-0```);L`0`N````S.P!
M`"\```#[[`$`%P```"OM`0`B````0^T!`"4```!F[0$`(````(SM`0`;````
MK>T!`!@```#)[0$`)````.+M`0`?````!^X!`!H````G[@$`(0```$+N`0`@
M````9.X!`!H```"%[@$`,@```*#N`0`:````T^X!`"\```#N[@$`*P```![O
M`0`?````2N\!`",```!J[P$`'P```([O`0`:````KN\!`"$```#)[P$`)0``
M`.OO`0`F````$?`!`"4````X\`$`)````%[P`0`8````@_`!`!T```"<\`$`
M)````+KP`0`8````W_`!`"(```#X\`$`+````!OQ`0`O````2/$!`!4```!X
M\0$`)0```([Q`0`\````M/$!`!\```#Q\0$`(P```!'R`0`?````-?(!`"``
M``!5\@$`&@```';R`0`8````D?(!`!@```"J\@$`)@```,/R`0`>````ZO(!
M`"D````)\P$`'@```#/S`0`Q````4O,!``H```"$\P$`$P```(_S`0`(````
MH_,!``D```"L\P$`%@```+;S`0`,````S?,!`!<```#:\P$`+P```/+S`0`D
M````(O0!``<```!']`$`'P```$_T`0`/````;_0!`!0```!_]`$`#@```)3T
M`0`-````H_0!`"0```"Q]`$`!0```-;T`0`'````W/0!``P```#D]`$`.P``
M`/'T`0`/````+?4!`!$````]]0$`(@```$_U`0`E````<O4!`!H```"8]0$`
M'0```+/U`0`:````T?4!`!$```#L]0$`!P```/[U`0#'````!O8!``8```#.
M]@$`"P```-7V`0`:````X?8!`!4```#\]@$`!@```!+W`0`)````&?<!`!@`
M```C]P$`"P```#SW`0`-````2/<!`!<```!6]P$`!@```&[W`0`S````=?<!
M`!,```"I]P$`$P```+WW`0`'````T?<!``\```#9]P$`$0```.GW`0`>````
M^_<!``<````:^`$`&0```"+X`0`R````//@!``0```!O^`$`1@```'3X`0`A
M````N_@!`!,```#=^`$`#````/'X`0`1````_O@!`#(````0^0$`%@```$/Y
M`0`(````6OD!`!T```!C^0$`"0```('Y`0`*````B_D!`!0```"6^0$`"@``
M`*OY`0`=````MOD!``@```#4^0$`'P```-WY`0`(````_?D!`!H````&^@$`
M!@```"'Z`0`5````*/H!``<````^^@$`"````$;Z`0`)````3_H!`#\```!9
M^@$`!P```)GZ`0`/````H?H!``X```"Q^@$`$````,#Z`0`)````T?H!``D`
M``#;^@$`"````.7Z`0`3````[OH!``0````"^P$`!P````?[`0`2````#_L!
M`"8````B^P$`#0```$G[`0`9````5_L!`!@```!Q^P$`"P```(K[`0`.````
MEOL!`!D```"E^P$`"@```+_[`0`D````ROL!`"$```#O^P$`"@```!'\`0`3
M````'/P!`"<````P_`$`"0```%C\`0`/````8OP!`!<```!R_`$`%````(K\
M`0`H````G_P!`!X```#(_`$`#P```.?\`0`@````]_P!``T````8_0$`%```
M`";]`0`-````._T!`!0```!)_0$`)````%[]`0`4````@_T!``H```"8_0$`
M#````*/]`0`7````L/T!``0```#(_0$`*@```,W]`0`,````^/T!`!$````%
M_@$`!P```!?^`0`"````'_X!`!`````B_@$`&````#/^`0`+````3/X!``,`
M``!8_@$`"````%S^`0`&````9?X!``<```!L_@$`#0```'3^`0`+````@OX!
M`!0```"._@$`%0```*/^`0`.````N?X!`"\```#(_@$`(````/C^`0`<````
M&?\!`%<````V_P$`6@```([_`0`_````Z?\!`#8````I``(`?@```&```@`5
M````WP`"``P```#U``(`,0````(!`@`)````-`$"``4````^`0(`$@```$0!
M`@`_````5P$"`!(```"7`0(`"@```*H!`@`&````M0$"``0```"\`0(`!```
M`,$!`@`*````Q@$"`!,```#1`0(`!0```.4!`@`&````ZP$"``8```#R`0(`
M"````/D!`@`$`````@("``P````'`@(`"@```!0"`@`Y````'P("`"X```!9
M`@(`&0```(@"`@`?````H@("`!T```#"`@(`$0```.`"`@`"````\@("``0`
M``#U`@(`"@```/H"`@`&````!0,"``4````,`P(``P```!(#`@`,````%@,"
M`#L````C`P(`3P```%\#`@`U````KP,"`"<```#E`P(`(0````T$`@`D````
M+P0"`$4```!4!`(`)@```)H$`@`R````P00"`#,```#T!`(`&@```"@%`@`=
M````0P4"`'@```!A!0(`-````-H%`@`A````#P8"`%8````Q!@(`*````(@&
M`@!3````L08"`#H````%!P(`0@```$`'`@`9````@P<"`!<```"=!P(`)0``
M`+4'`@`9````VP<"`"H```#U!P(`*P```"`(`@!R````3`@"`"````"_"`(`
M-0```.`(`@`A````%@D"`$4````X"0(`)@```'X)`@`P````I0D"`$L```#6
M"0(`3@```"(*`@`G````<0H"`"D```"9"@(`(0```,,*`@`H````Y0H"`"L`
M```."P(`'0```#H+`@`I````6`L"`"8```"""P(`)0```*D+`@`H````SPL"
M`"@```#X"P(`(@```"$,`@`Z````1`P"`"L```!_#`(`*0```*L,`@`B````
MU0P"`#T```#X#`(`00```#8-`@`H````>`T"`"P```"A#0(`,````,X-`@`2
M````_PT"`!,````2#@(`$````"8.`@!Y````-PX"``D```"Q#@(`'````+L.
M`@`0````V`X"``\```#I#@(`*P```/D.`@`G````)0\"``X```!-#P(`2P``
M`%P/`@"A````J`\"`',```!*$`(`?````+X0`@!`````.Q$"`"L```!\$0(`
M5````*@1`@`7````_1$"`"H````5$@(`-````$`2`@`G````=1("`!8```"=
M$@(`#P```+02`@"O````Q!("`!<```!T$P(`*````(P3`@`?````M1,"`$``
M``#5$P(`'P```!84`@`<````-A0"`%$```!3%`(`&@```*44`@`4````P!0"
M``\```#5%`(`"@```.44`@`%````\!0"``8```#V%`(`"````/T4`@`0````
M!A4"`!(````7%0(`#````"H5`@`0````-Q4"`!$```!(%0(`$P```%H5`@`=
M````;A4"`"````",%0(`#P```*T5`@`/````O14"``0```#-%0(`"@```-(5
M`@`$````W14"``,```#B%0(`"0```.85`@`'````\!4"``L```#X%0(`"```
M``06`@`'````#18"``4````5%@(`"0```!L6`@`4````)18"``8````Z%@(`
M!P```$$6`@`(````218"``\```!2%@(`#P```&(6`@`,````<A8"``@```!_
M%@(`#````(@6`@`&````E18"``D```"<%@(`"P```*86`@`/````LA8"``8`
M``#"%@(`!P```,D6`@`-````T18"``8```#?%@(`%````.86`@`'````^Q8"
M``,````#%P(`"0````<7`@`&````$1<"``P````8%P(`"@```"47`@`,````
M,!<"`!$````]%P(`"@```$\7`@`/````6A<"``4```!J%P(`"````'`7`@`9
M````>1<"`!$```"3%P(`"@```*47`@`8````L!<"`!,```#)%P(`'````-T7
M`@`1````^A<"``\````,&`(`!````!P8`@`$````(1@"`!D````F&`(`!P``
M`$`8`@`"````2!@"``(```!+&`(`$0```$X8`@`)````8!@"``8```!J&`(`
M$@```'$8`@`7````A!@"``,```"<&`(`!@```*`8`@`,````IQ@"``(```"T
M&`(`!````+<8`@`$````O!@"``\```#!&`(`$P```-$8`@`'````Y1@"``(`
M``#M&`(`!P```/`8`@`1````^!@"``8````*&0(`"P```!$9`@`8````'1D"
M``8````V&0(`$P```#T9`@`0````41D"`!(```!B&0(`#@```'49`@`/````
MA!D"``(```"4&0(`!@```)<9`@`,````GAD"``D```"K&0(`$0```+49`@`B
M````QQD"``<```#J&0(`!P```/(9`@`+````^AD"``4````&&@(``@````P:
M`@`+````#QH"``X````;&@(`#@```"H:`@!>`0``.1H"``D```"8&P(`"P``
M`*(;`@`)````KAL"``H```"X&P(`"@```,,;`@`,````SAL"``H```#;&P(`
M!P```.8;`@`'````[AL"``<```#V&P(`!P```/X;`@`"````!AP"``@````)
M'`(`$0```!(<`@`8````)!P"`"L````]'`(`&@```&D<`@`=````A!P"`!,`
M``"B'`(`$0```+8<`@`$````R!P"`!D```#-'`(`*0```.<<`@`-````$1T"
M``<````?'0(`&P```"<=`@`2````0QT"`#(```!6'0(`'@```(D=`@`U````
MJ!T"`!P```#>'0(`%````/L=`@`2````$!X"``L````C'@(`!P```"\>`@`%
M````-QX"`!(````]'@(`!P```%`>`@`'````6!X"``L```!@'@(`"0```&P>
M`@`D````=AX"``L```";'@(`&@```*<>`@`:````PAX"``H```#='@(`#P``
M`.@>`@`*````^!X"`"$````#'P(`%0```"4?`@`8````.Q\"``X```!4'P(`
M/````&,?`@`)````H!\"``4```"J'P(`"@```+`?`@`4````NQ\"`!,```#0
M'P(`#P```.0?`@`7````]!\"`!<````,(`(`(````"0@`@`*````12`"``H`
M``!0(`(`"@```%L@`@`*````9B`"``8```!Q(`(`&P```'@@`@!9````E"`"
M`"$```#N(`(`&````!`A`@`&````*2$"``@````P(0(`+P```#DA`@`O````
M:2$"`!(```"9(0(`)0```*PA`@`'````TB$"``P```#:(0(`$@```.<A`@`*
M````^B$"`!$````%(@(`+0```!<B`@`;````12("`"L```!A(@(`&0```(TB
M`@`*````IR("``L```"R(@(`"0```+XB`@`)````R"("``D```#2(@(`"@``
M`-PB`@`*````YR("``8```#R(@(`'0```/DB`@`4````%R,"`"<````L(P(`
M/P```%0C`@`E````E","`"T```"Z(P(`0````.@C`@!$````*20"`$0```!N
M)`(`2@```+,D`@`G````_B0"``@````F)0(`"````"\E`@`(````."4"``@`
M``!!)0(`"````$HE`@`)````4R4"``(```!=)0(`"````&`E`@`.````:24"
M``<```!X)0(`!@```(`E`@`&````AR4"`!@```".)0(`"````*<E`@`&````
ML"4"``@```"W)0(`&P```,`E`@`;````W"4"``@```#X)0(`"@````$F`@`+
M````#"8"`!L````8)@(`!````#0F`@`(````.28"``0```!")@(`%````$<F
M`@`*````7"8"``H```!G)@(`"0```'(F`@`(````?"8"``@```"%)@(`$0``
M`(XF`@`0````H"8"``\```"Q)@(`"````,$F`@`-````RB8"``8```#8)@(`
M"@```-\F`@`9````ZB8"`!(````$)P(`#P```!<G`@`0````)R<"`!(````X
M)P(`"@```$LG`@`4````5B<"`#,```!K)P(`*P```)\G`@`;````RR<"`$H`
M``#G)P(`%0```#(H`@`.````2"@"``X```!7*`(`&P```&8H`@`2````@B@"
M`!\```"5*`(`!````+4H`@`&````NB@"``8```#!*`(`60```,@H`@!V````
M(BD"`"$```"9*0(`!````+LI`@`$````P"D"`!0```#%*0(`%````-HI`@`4
M````[RD"``@````$*@(`!`````TJ`@`)````$BH"``0````<*@(`$@```"$J
M`@`(````-"H"``@````]*@(`!@```$8J`@`T````32H"`"$```""*@(`+0``
M`*0J`@`G````TBH"`#0```#Z*@(`#P```"\K`@`@````/RL"`!8```!@*P(`
M%P```'<K`@`&````CRL"``X```"6*P(`#@```*4K`@`0````M"L"`!````#%
M*P(`"````-8K`@`(````WRL"`!$```#H*P(`!````/HK`@`0````_RL"`!T`
M```0+`(`-@```"XL`@`3````92P"`!4```!Y+`(`&P```(\L`@`;````JRP"
M`!````#'+`(`#P```-@L`@`3````Z"P"``P```#\+`(`!`````DM`@`&````
M#BT"``H````5+0(`%0```"`M`@`J````-BT"``@```!A+0(`#````&HM`@`.
M````=RT"``P```"&+0(`$0```),M`@`B````I2T"`"$```#(+0(`$@```.HM
M`@`$````_2T"``@````"+@(`!`````LN`@`7````$"X"``H````H+@(`"@``
M`#,N`@`C````/BX"`!L```!B+@(`)P```'XN`@`-````IBX"`!H```"T+@(`
M'@```,\N`@`>````[BX"`"0````-+P(`)````#(O`@`D````5R\"`"0```!\
M+P(`'0```*$O`@`H````OR\"`!H```#H+P(`$@````,P`@`2````%C`"`!8`
M```I,`(`"````$`P`@`$````23`"`!````!.,`(`"````%\P`@`0````:#`"
M``@```!Y,`(`#P```((P`@`$````DC`"`!L```"7,`(`"````+,P`@`(````
MO#`"`!X```#%,`(`"0```.0P`@`P````[C`"`",````?,0(`!````$,Q`@`-
M````2#$"`!@```!6,0(`!````&\Q`@`9````=#$"`!D```".,0(`&0```*@Q
M`@`9````PC$"``@```#<,0(`!````.4Q`@`$````ZC$"``0```#O,0(`%```
M`/0Q`@`0````"3("`"H````:,@(`(P```$4R`@`I````:3("`&L```"3,@(`
M*````/\R`@`G````*#,"`"@```!0,P(`,0```'DS`@`Q````JS,"`"@```#=
M,P(`*0````8T`@`<````,#0"`!P```!--`(`,0```&HT`@`H````G#0"`"X`
M``#%-`(`%````/0T`@`)````"34"``P````3-0(`$````"`U`@`-````,34"
M``T````_-0(`/0```$TU`@`-````BS4"``L```"9-0(`"@```*4U`@`5````
ML#4"``@```#&-0(`!P```,\U`@`,````US4"``P```#D-0(`!````/$U`@`(
M````]C4"`!(```#_-0(`&````!(V`@`:````*S8"`!````!&-@(`#@```%<V
M`@`8````9C8"`!,```!_-@(`$0```),V`@`4````I38"``0```"Z-@(`"```
M`+\V`@`'````R#8"`!````#0-@(`#P```.$V`@`=````\38"``P````/-P(`
M$````!PW`@`-````+3<"``0````[-P(`!@```$`W`@`A````1S<"``@```!I
M-P(`"````'(W`@`L````>S<"``0```"H-P(`!````*TW`@`2````LC<"``0`
M``#%-P(`!````,HW`@`(````SS<"``0```#8-P(`+0```-TW`@`$````"S@"
M`!0````0.`(`$0```"4X`@`$````-S@"``T````\.`(`#0```$HX`@`>````
M6#@"`!@```!W.`(`$P```)`X`@`(````I#@"`!D```"M.`(`$````,<X`@`(
M````V#@"``,```#A.`(`"@```.4X`@`/````\#@"``8`````.0(`$P````<Y
M`@`&````&SD"``8````B.0(`$0```"DY`@`1````.SD"`!P```!-.0(`'```
M`&HY`@`Z````ASD"`"8```#".0(`$0```.DY`@`:````^SD"`!(````6.@(`
M#P```"DZ`@`$````.3H"``@````^.@(`#````$<Z`@`G````5#H"`!(```!\
M.@(`#P```(\Z`@`C````GSH"`!(```##.@(`&@```-8Z`@`Q````\3H"`!D`
M```C.P(`$P```#T[`@`(````43L"``H```!:.P(`&0```&4[`@`$````?SL"
M``@```"$.P(`"@```(T[`@`+````F#L"``H```"D.P(`"P```*\[`@`(````
MNSL"`!8```#$.P(`!````-L[`@`E````X#L"`!$````&/`(`"````!@\`@`*
M````(3P"``@````L/`(`)P```#4\`@`+````73P"``0```!I/`(`!````&X\
M`@`(````<SP"``H```!\/`(`#````(<\`@`P````E#P"`!T```#%/`(`&P``
M`.,\`@`G````_SP"`"T````G/0(`!````%4]`@`-````6CT"``T```!H/0(`
M"@```'8]`@`.````@3T"`!T```"0/0(`'@```*X]`@`,````S3T"``P```#:
M/0(`$0```.<]`@`/````^3T"``T````)/@(`#0```!<^`@`1````)3X"`"$`
M```W/@(`"````%D^`@`2````8CX"``T```!U/@(`$@```(,^`@`?````ECX"
M`"````"V/@(`&0```-<^`@`5````\3X"``(````'/P(`%`````H_`@`(````
M'S\"``X````H/P(`"@```#<_`@`0````0C\"``8```!3/P(`'P```%H_`@`1
M````>C\"`!D```",/P(`(0```*8_`@`9````R#\"`!L```#B/P(`+````/X_
M`@`0````*T`"`",````\0`(`#@```&!``@`G````;T`"`"P```"70`(`%```
M`,1``@`6````V4`"``P```#P0`(`!````/U``@`(`````D$"``H````+00(`
M#````!9!`@`$````(T$"``8````H00(``@```"]!`@`7````,D$"``0```!*
M00(`!````$]!`@`.````5$$"``H```!C00(`"@```&Y!`@`(````>4$"`!,`
M``""00(`!````)9!`@`(````FT$"``8```"D00(`#@```*M!`@`#````ND$"
M``@```"^00(`!````,=!`@`$````S$$"``@```#100(`!````-I!`@`$````
MWT$"`!````#D00(`!````/5!`@`&````^D$"``X````!0@(`$P```!!"`@`Y
M````)$("``0```!>0@(`!````&-"`@`$````:$("``0```!M0@(`-````')"
M`@`-````IT("``<```"U0@(`$0```+U"`@`-````ST("``@```#=0@(`#```
M`.9"`@`R````\T("`!<````F0P(`"0```#Y#`@`*````2$,"`!L```!30P(`
M*0```&]#`@`:````F4,"`!````"T0P(`!@```,5#`@`?````S$,"`!0```#L
M0P(`#0````%$`@`$````#T0"`!0````41`(`%P```"E$`@`7````040"`!T`
M``!91`(`%````'=$`@`7````C$0"``0```"D1`(`#````*E$`@`$````MD0"
M``P```"[1`(`!````,A$`@`*````S40"`!<```#81`(`&````/!$`@`5````
M"44"`!D````?10(`%P```#E%`@`7````444"`!(```!I10(`%````'Q%`@`4
M````D44"`!````"F10(`%@```+=%`@`6````SD4"`"(```#E10(`%`````A&
M`@`E````'48"`!,```!#1@(`%0```%=&`@`2````;48"`!0```"`1@(`(0``
M`)5&`@`6````MT8"`!T```#.1@(`$````.Q&`@`D````_48"`"`````B1P(`
M%0```$-'`@`7````64<"`!D```!Q1P(`$@```(M'`@`2````GD<"`!T```"Q
M1P(`%0```,]'`@`,````Y4<"`!<```#R1P(`$@````I(`@`J````'4@"`!8`
M``!(2`(`#````%](`@!+````;$@"`"<```"X2`(`$@```.!(`@`4````\T@"
M`!0````(20(`+@```!U)`@`8````3$D"``T```!E20(`$@```'-)`@`3````
MADD"`!$```":20(`%0```*Q)`@`9````PDD"`!0```#<20(`3````/%)`@`6
M````/DH"``X```!52@(`$@```&1*`@`4````=TH"`!D```",2@(`*@```*9*
M`@`M````T4H"``8```#_2@(`!`````9+`@`$````"TL"``0````02P(`!```
M`!5+`@`(````&DL"``X````C2P(`$````#)+`@`,````0TL"`!(```!02P(`
M$@```&-+`@`,````=DL"`!(```"#2P(`$@```)9+`@!!````J4L"``P```#K
M2P(`#P```/A+`@`,````"$P"``P````53`(`"@```"),`@`2````+4P"``L`
M``!`3`(`"````$Q,`@`(````54P"``@```!>3`(`#````&=,`@`(````=$P"
M`!,```!]3`(`#````)%,`@`*````GDP"`"````"I3`(`$0```,I,`@`?````
MW$P"``0```#\3`(`!`````%-`@`1````!DT"`!$````830(`%P```"I-`@`:
M````0DT"`!L```!=30(``@```'E-`@!5````?$T"``0```#230(`!@```-=-
M`@`,````WDT"``H```#K30(`!````/9-`@`(````^TT"``@````$3@(`!```
M``U.`@`*````$DX"``8````=3@(`"@```"1.`@`$````+TX"``8````T3@(`
M"````#M.`@`$````1$X"``@```!)3@(`#@```%).`@`,````84X"`!4```!N
M3@(`#P```(1.`@`/````E$X"``0```"D3@(`!@```*E.`@`$````L$X"`!``
M``"U3@(`"@```,9.`@`.````T4X"``0```#@3@(`"````.5.`@`(````[DX"
M``@```#W3@(`$`````!/`@`(````$4\"``X````:3P(`&````"E/`@`.````
M0D\"``H```!13P(`"````%Q/`@`2````94\"`!<```!X3P(`$@```)!/`@`C
M````HT\"`!T```#'3P(`#@```.5/`@`@````]$\"``8````54`(`&````!Q0
M`@`,````-5`"``X```!"4`(`#````%%0`@`&````7E`"``H```!E4`(`%0``
M`'!0`@`3````AE`"``X```":4`(`"````*E0`@`.````LE`"``@```#!4`(`
M$````,I0`@`(````VU`"``@```#D4`(`!````.U0`@`$````\E`"`!T```#W
M4`(`%P```!51`@`$````+5$"``@````R40(`%@```#M1`@`*````4E$"`!,`
M``!=40(`"0```'%1`@`(````>U$"``@```"$40(`!````(U1`@`(````DE$"
M`!$```";40(`"````*U1`@`<````ME$"``X```#340(`#@```.)1`@`(````
M\5$"`!````#Z40(`%0````M2`@`C````(5("`",```!%4@(`!````&E2`@`(
M````;E("`!$```!W4@(`!@```(E2`@`,````D%("``8```"=4@(`'````*12
M`@`,````P5("`!````#.4@(`*0```-]2`@`3````"5,"`",````=4P(`&P``
M`$%3`@`$````75,"``0```!B4P(`!P```&=3`@`@````;U,"`"@```"04P(`
M!````+E3`@`0````OE,"`!P```#/4P(`&@```.Q3`@`$````!U0"``8````,
M5`(`!P```!-4`@`*````&U0"``0````F5`(`"````"M4`@`,````-%0"``0`
M``!!5`(`!````$94`@`9````2U0"`!(```!E5`(`!````'A4`@`*````?50"
M``@```"(5`(`"````)%4`@`(````FE0"``@```"C5`(`"````*Q4`@`,````
MM50"``X```#"5`(`&````-%4`@`,````ZE0"``@```#W5`(`#@````!5`@`,
M````#U4"``X````<50(`$````"M5`@`C````/%4"`!````!@50(`!````'%5
M`@`,````=E4"`!8```"#50(`!P```)I5`@`(````HE4"``P```"K50(`%0``
M`+A5`@`,````SE4"`!,```#;50(`"````.]5`@`7````^%4"``0````05@(`
M$@```!56`@`4````*%8"``P````]5@(`#````$I6`@`)````5U8"``D```!A
M5@(`#````&M6`@`*````>%8"``T```"#5@(`*@```)%6`@`-````O%8"`!,`
M``#*5@(`"@```-Y6`@`&````Z58"``0```#P5@(`#````/56`@`(`````E<"
M``T````+5P(`"````!E7`@`*````(E<"``@````M5P(`/````#97`@`2````
M<U<"`!0```"&5P(`%````)M7`@`8````L%<"`!(```#)5P(`"````-Q7`@`>
M````Y5<"`!X````$6`(`%````"-8`@`$````.%@"`"8````]6`(`%````&18
M`@`;````>5@"`!L```"56`(`%@```+%8`@`7````R%@"`!<```#@6`(`%0``
M`/A8`@`2````#ED"`!,````A60(`!````#59`@`-````.ED"`!$```!(60(`
M"@```%I9`@`)````95D"``H```!O60(`"0```'I9`@`(````A%D"``@```"-
M60(`!@```)99`@`'````G5D"``0```"E60(`!````*I9`@`$````KUD"``X`
M``"T60(`"@```,-9`@`(````SED"``H```#760(`(@```.)9`@`B````!5H"
M``8````H6@(`"````"]:`@`&````.%H"``8````_6@(`"````$9:`@`-````
M3UH"``H```!=6@(`$````&A:`@`7````>5H"`!8```"16@(`$````*A:`@`0
M````N5H"`!L```#*6@(`$````.9:`@`,````]UH"``0````$6P(`+@````E;
M`@`-````.%L"``D```!&6P(`!````%!;`@`$````55L"``0```!:6P(`!```
M`%];`@`&````9%L"``@```!K6P(`%P```'1;`@`?````C%L"`!8```"L6P(`
M$P```,-;`@`*````UUL"`!4```#B6P(`!@```/A;`@`(````_UL"``H````(
M7`(`"````!-<`@`+````'%P"``0````H7`(`$P```"U<`@`1````05P"``@`
M``!37`(`"````%Q<`@`(````95P"``@```!N7`(`%0```'=<`@`*````C5P"
M``H```"87`(`&P```*-<`@`=````OUP"``@```#=7`(`#@```.9<`@`5````
M]5P"``0````+70(`#@```!!=`@`&````'UT"``X````F70(`!@```#5=`@`$
M````/%T"``@```!!70(`"````$I=`@`$````4UT"``8```!870(``@```%]=
M`@`.````8ET"`!$```!Q70(`"@```(-=`@`*````CET"`!<```"970(`#P``
M`+%=`@`(````P5T"``0```#*70(`&P```,]=`@`.````ZUT"`$X```#Z70(`
M"@```$E>`@`:````5%X"``0```!O7@(`!````'1>`@`(````>5X"``0```""
M7@(`!@```(=>`@`$````CEX"``0```"37@(`!0```)A>`@`.````GEX"`!``
M``"M7@(`"````+Y>`@`&````QUX"``0```#.7@(`#0```-->`@`4````X5X"
M`!(```#V7@(`&@````E?`@`A````)%\"`!L```!&7P(`"````&)?`@`&````
M:U\"``H```!R7P(``@```'U?`@`(````@%\"``0```")7P(`!````(Y?`@`%
M````DU\"``8```"97P(`%@```*!?`@`,````MU\"``4```#$7P(`#P```,I?
M`@`(````VE\"`!(```#C7P(`$````/9?`@`6````!V`"``X````>8`(`)@``
M`"U@`@`,````5&`"`!0```!A8`(`!````'9@`@`$````>V`"``@```"`8`(`
M$0```(E@`@`&````FV`"``L```"B8`(`"P```*Y@`@`(````NF`"``0```##
M8`(`#0```,A@`@`3````UF`"`!0```#J8`(`$@```/]@`@`(````$F$"`!``
M```;80(`*0```"QA`@`;````5F$"`!L```!R80(`!````(YA`@`5````DV$"
M``L```"I80(`%````+5A`@`(````RF$"``@```#380(`"````-QA`@`/````
MY6$"`"````#U80(`#P```!9B`@`$````)F("``P````K8@(`#0```#AB`@`1
M````1F("``P```!88@(`"0```&5B`@`"````;V("``0```!R8@(`!````'=B
M`@`A````?&("``8```">8@(`%P```*5B`@`$````O6("``0```#"8@(`#@``
M`,=B`@`$````UF("``0```#;8@(`$0```.!B`@`7````\F("``0````*8P(`
M$`````]C`@`*````(&,"``H````K8P(``@```#9C`@`&````.6,"``0```!`
M8P(`!````$5C`@`1````2F,"``(```!<8P(`"````%]C`@`&````:&,"``@`
M``!O8P(`$P```'AC`@`0````C&,"``4```"=8P(`,````*-C`@`>````U&,"
M`"P```#S8P(`(0```"!D`@`N````0F0"`"8```!Q9`(`(0```)AD`@`Q````
MNF0"`"$```#L9`(`'0````YE`@`<````+&4"``8```!)90(`"````%!E`@`%
M````664"`!8```!?90(`&0```'9E`@`5````D&4"``T```"F90(`$0```+1E
M`@`8````QF4"``0```#?90(`!@```.1E`@`(````ZV4"`!````#T90(`!```
M``5F`@`<````"F8"`",````G9@(`%0```$MF`@`5````868"`!T```!W9@(`
M#0```)5F`@`G````HV8"`!L```#+9@(`%````.=F`@`,````_&8"`!0````)
M9P(`!@```!YG`@`'````)6<"`!`````M9P(`(````#YG`@`.````7V<"``X`
M``!N9P(`!@```'UG`@`(````A&<"``H```"-9P(`#P```)AG`@`P````J&<"
M`#H```#99P(`(@```!1H`@!I````-V@"`#X```"A:`(`!````.!H`@`(````
MY6@"``0```#N:`(`"0```/-H`@`(````_6@"``D````&:0(`#````!!I`@`-
M````'6D"``@````K:0(`!````#1I`@`$````.6D"``@````^:0(`"@```$=I
M`@`(````4FD"``T```!;:0(`#0```&EI`@`8````=VD"`!@```"0:0(`%0``
M`*EI`@`,````OVD"`!$```#,:0(`%0```-YI`@`0````]&D"``X````%:@(`
M(0```!1J`@`-````-FH"``0```!$:@(`"````$EJ`@`7````4FH"``P```!J
M:@(`"0```'=J`@`&````@6H"``X```"(:@(`!@```)=J`@`3````GFH"`!,`
M``"R:@(`$P```,9J`@`:````VFH"`$8```#U:@(`"````#QK`@`,````16L"
M``H```!2:P(`$````%UK`@`$````;FL"``0```!S:P(`#0```'AK`@`2````
MAFL"`!$```"9:P(`$0```*MK`@`0````O6L"`!````#.:P(`$````-]K`@`(
M````\&L"`!P```#Y:P(`'````!9L`@`5````,VP"``@```!);`(`#````%)L
M`@`0````7VP"`!P```!P;`(`'````(UL`@`8````JFP"`!@```##;`(`&@``
M`-QL`@`:````]VP"``X````2;0(`&P```"%M`@`0````/6T"`!````!.;0(`
M#@```%]M`@`.````;FT"``@```!];0(`#@```(9M`@`.````E6T"``P```"D
M;0(`#````+%M`@`/````OFT"``T```#.;0(`$0```-QM`@`A````[FT"``D`
M```0;@(`!````!IN`@`&````'VX"`!T````F;@(`#````$1N`@`.````46X"
M`!L```!@;@(`$````'QN`@`/````C6X"``\```"=;@(`(````*UN`@`/````
MSFX"``X```#>;@(`#@```.UN`@`*````_&X"``T````';P(`"P```!5O`@`0
M````(6\"`!8````R;P(`$P```$EO`@`-````76\"`!$```!K;P(`&````'UO
M`@`8````EF\"``T```"O;P(`#P```+UO`@`1````S6\"``\```#?;P(`#P``
M`.]O`@`1````_V\"``0````1<`(`!@```!9P`@`(````'7`"`"`````F<`(`
M#0```$=P`@`0````57`"`!(```!F<`(`"````'EP`@`/````@G`"``8```"2
M<`(`!````)EP`@`.````GG`"`!````"M<`(`!````+YP`@`,````PW`"`!(`
M``#0<`(`!@```.-P`@`-````ZG`"``0```#X<`(`!````/UP`@`$`````G$"
M``0````'<0(`"`````QQ`@`(````%7$"``@````><0(``@```"=Q`@`*````
M*G$"``H````U<0(`#````$!Q`@`2````37$"``@```!@<0(`"````&EQ`@`(
M````<G$"``@```![<0(`"````(1Q`@`(````C7$"`"@```"6<0(`+@```+]Q
M`@`G````[G$"`"D````6<@(`(0```$!R`@`$````8G("`!,```!G<@(`+0``
M`'MR`@`9````J7("``T```##<@(`#P```-%R`@`*````X7("``H```#L<@(`
M!````/=R`@`G````_'("``8````D<P(`$````"MS`@`(````/',"`!(```!%
M<P(`!@```%AS`@`)````7W,"``X```!I<P(`%````'AS`@`6````C7,"`!$`
M``"D<P(`!````+9S`@`(````NW,"`!````#$<P(`!````-5S`@`(````VG,"
M``8```#C<P(`$````.IS`@`2````^W,"`!\````.=`(`&@```"YT`@`$````
M270"``0```!.=`(`"````%-T`@`(````7'0"``8```!E=`(`"````&QT`@`$
M````=70"``8```!Z=`(`!@```(%T`@`$````B'0"``T```"-=`(`"0```)MT
M`@`@````I70"`!L```#&=`(`!````.)T`@`.````YW0"`!\```#V=`(`"@``
M`!9U`@`,````(74"``@````N=0(`6@```#=U`@`/````DG4"``T```"B=0(`
M$0```+!U`@`/````PG4"``\```#2=0(`#0```.)U`@`1````\'4"``P````"
M=@(`$`````]V`@`2````('8"`!8````S=@(`!````$IV`@`2````3W8"``D`
M``!B=@(`)@```&QV`@`*````DW8"``H```">=@(`!````*EV`@`$````KG8"
M``D```"S=@(`!````+UV`@`$````PG8"``@```#'=@(`+0```-!V`@`)````
M_G8"``0````(=P(`!`````UW`@`"````$G<"``8````5=P(`#````!QW`@`,
M````*7<"``P````V=P(`!````$-W`@`3````2'<"``(```!<=P(`"````%]W
M`@`;````:'<"``,```"$=P(`#````(AW`@`Y````E7<"``H```#/=P(`%P``
M`-IW`@`$````\G<"``@```#W=P(`"`````!X`@`(````"7@"`!<````2>`(`
M!````"IX`@`4````+W@"``T```!$>`(`#P```%)X`@`3````8G@"`!,```!V
M>`(`"P```(IX`@`.````EG@"`"````"E>`(`"@```,9X`@`-````T7@"``0`
M``#?>`(`!````.1X`@`2````Z7@"`!0```#\>`(`!P```!%Y`@`9````&7D"
M`"@````S>0(`#@```%QY`@`2````:WD"`"0```!^>0(`'0```*-Y`@`7````
MP7D"``X```#9>0(`#````.AY`@`*````]7D"`!<`````>@(`%````!AZ`@`/
M````+7H"`!<````]>@(`&````%5Z`@`7````;GH"``P```"&>@(`#@```)-Z
M`@`,````HGH"``P```"O>@(`$0```+QZ`@`1````SGH"``0```#@>@(`$@``
M`.5Z`@`$````^'H"``0```#]>@(`"@````)[`@`)````#7L"``H````7>P(`
M!````")[`@`(````)WL"``@````P>P(`"````#E[`@`(````0GL"``@```!+
M>P(`"@```%1[`@`N````7WL"``@```".>P(`"P```)=[`@`(````HWL"``8`
M``"L>P(`"0```+-[`@`0````O7L"``H```#.>P(`"@```-E[`@`(````Y'L"
M`!$```#M>P(`'````/][`@`-````''P"``@````J?`(`$P```#-\`@`&````
M1WP"`!,```!.?`(`*P```&)\`@`1````CGP"``0```"@?`(`$@```*5\`@`:
M````N'P"``0```#3?`(`#P```-A\`@`N````Z'P"``0````7?0(`"0```!Q]
M`@`8````)GT"`!<````_?0(`%````%=]`@`$````;'T"``0```!Q?0(`'@``
M`'9]`@`U````E7T"`!````#+?0(`'````-Q]`@`0````^7T"``8````*?@(`
M"````!%^`@`$````&GX"``@````??@(`!````"A^`@`(````+7X"``0````V
M?@(`'P```#M^`@`/````6WX"``\```!K?@(`!@```'M^`@`$````@GX"``@`
M``"'?@(`!````)!^`@`C````E7X"`"````"Y?@(`!@```-I^`@`(````X7X"
M``@```#J?@(`"````/-^`@`$````_'X"``0````!?P(`!`````9_`@`$````
M"W\"``0````0?P(`!````!5_`@`T````&G\"``P```!/?P(`!````%Q_`@`5
M````87\"`!````!W?P(`#P```(A_`@`(````F'\"``0```"A?P(`"````*9_
M`@`,````KW\"``@```"\?P(`$````,5_`@`.````UG\"``L```#E?P(``@``
M`/%_`@`$````]'\"``0```#Y?P(`(0```/Y_`@`2````((`"``P````S@`(`
M#````$"``@`.````38`"`!(```!<@`(`(P```&^``@`5````DX`"`!4```"I
M@`(`%0```+^``@`1````U8`"`!$```#G@`(`%P```/F``@`3````$8$"`!$`
M```E@0(`"````#>!`@`$````0($"`!````!%@0(`!````%:!`@`<````6X$"
M``@```!X@0(`"@```(&!`@`&````C($"``0```"3@0(`"0```)B!`@`$````
MHH$"`!4```"G@0(`%````+V!`@`&````TH$"``8```#9@0(`$0```."!`@`-
M````\H$"``\`````@@(`!````!""`@`(````%8("``8````>@@(`!@```"6"
M`@`&````+(("``H````S@@(`!@```#Z"`@`4````18("``P```!:@@(`$@``
M`&>"`@`$````>H("``T```!_@@(``@```(V"`@`.````D(("``H```"?@@(`
M%````*J"`@`(````OX("`!8```#(@@(`#P```-^"`@`*````[X("``X```#Z
M@@(`&`````F#`@`-````(H,"`!D````P@P(`&@```$J#`@`-````98,"`!H`
M``!S@P(`(0```(Z#`@`)````L(,"`!L```"Z@P(`%P```-:#`@`<````[H,"
M`!L````+A`(`(````">$`@`+````2(0"``L```!4A`(`(````&"$`@`*````
M@80"``\```",A`(`(0```)R$`@`2````OH0"`!8```#1A`(`&@```.B$`@`+
M`````X4"`!`````/A0(`$0```""%`@`,````,H4"``L````_A0(`%0```$N%
M`@`+````884"``L```!MA0(`&P```'F%`@`;````E84"`!\```"QA0(`'```
M`-&%`@`=````[H4"`!H````,A@(`2````">&`@`3````<(8"`!L```"$A@(`
M&P```*"&`@`:````O(8"`",```#7A@(`#@```/N&`@`&````"H<"`!4````1
MAP(`!@```">'`@`3````+H<"``@```!"AP(`"````$N'`@`$````5(<"`!L`
M``!9AP(`$P```'6'`@`/````B8<"`!<```"9AP(`%P```+&'`@`&````R8<"
M`"L```#0AP(`+0```/R'`@`(````*H@"``8````SB`(`$0```#J(`@`6````
M3(@"`!D```!CB`(`!````'V(`@`&````@H@"`!@```")B`(`#0```**(`@`&
M````L(@"``8```"WB`(`!@```+Z(`@`&````Q8@"``8```#,B`(`!@```-.(
M`@`,````VH@"``\```#GB`(`"@```/>(`@`-`````HD"``H````0B0(`!@``
M`!N)`@`(````(HD"`"$````KB0(`!@```$V)`@`*````5(D"`!(```!?B0(`
M'@```'*)`@`&````D8D"``0```"8B0(`!@```)V)`@`(````I(D"`#8```"M
MB0(`,````.2)`@`$````%8H"`!D````:B@(`!````#2*`@`"````.8H"``0`
M```\B@(`"@```$&*`@`&````3(H"``0```!3B@(`!@```%B*`@`7````7XH"
M``8```!WB@(`!@```'Z*`@`,````A8H"`!<```"2B@(`"P```*J*`@`C````
MMHH"`!X```#:B@(`$P```/F*`@`C````#8L"`"8````QBP(`#````%B+`@`.
M````98L"`"T```!TBP(`#````**+`@`2````KXL"``@```#"BP(`#@```,N+
M`@`$````VHL"``8```#?BP(`"````.:+`@`$````[XL"``@```#TBP(`!```
M`/V+`@`0`````HP"`!0````3C`(`!````"B,`@`(````+8P"``@````VC`(`
M"````#^,`@`.````2(P"``H```!7C`(`#0```&*,`@`0````<(P"``,```"!
MC`(`#````(6,`@`,````DHP"``P```"?C`(`"@```*R,`@`D````MXP"``@`
M``#<C`(`#````.6,`@`I````\HP"``P````<C0(`$````"F-`@`C````.HT"
M`!T```!>C0(`#@```'R-`@`,````BXT"`!4```"8C0(`%@```*Z-`@`7````
MQ8T"`!<```#=C0(`&P```/6-`@`J````$8X"`"`````\C@(`<@```%V.`@`*
M````T(X"``@```#;C@(`"````.2.`@`(````[8X"``@```#VC@(`"````/^.
M`@`&````"(\"``@````/CP(`!````!B/`@`<````'8\"``T````ZCP(`)P``
M`$B/`@`;````<(\"``P```",CP(`%````)F/`@`*````KH\"``0```"YCP(`
M$````+Z/`@`6````SX\"`!@```#FCP(`$P```/^/`@`,````$Y`"`#`````@
MD`(`#P```%&0`@`A````89`"`!$```"#D`(`!````)60`@`$````FI`"``0`
M``"?D`(`#````*20`@`/````L9`"``4```#!D`(`#````,>0`@`*````U)`"
M``0```#?D`(`#0```.20`@`*````\I`"`!T```#]D`(`"````!N1`@`%````
M))$"``8````JD0(`#0```#&1`@`$````/Y$"``0```!$D0(`!````$F1`@`*
M````3I$"``0```!9D0(`!@```%Z1`@`,````99$"`!4```!RD0(`!````(B1
M`@`3````C9$"``@```"AD0(`!````*J1`@`(````KY$"`!<```"XD0(`!```
M`-"1`@`(````U9$"`!H```#>D0(`&````/F1`@`=````$I("`!L````PD@(`
M"P```$R2`@`$````6)("`!0```!=D@(`!````'*2`@`$````=Y("``@```!\
MD@(`!````(62`@`M````BI("`!````"XD@(`D0```,F2`@`0````6Y,"`!,`
M``!LDP(`&P```("3`@`5````G),"`!4```"RDP(`&0```,B3`@`8````XI,"
M`"8```#[DP(`%0```"*4`@`5````.)0"``\```!.E`(`,P```%Z4`@`\````
MDI0"`,X```#/E`(`$0```)Z5`@`/````L)4"`!H```#`E0(`%0```-N5`@`N
M````\94"`!D````@E@(`$````#J6`@`:````2Y8"`!(```!FE@(`(0```'F6
M`@`3````FY8"``T```"OE@(`!````+V6`@`$````PI8"`!$```#'E@(`"```
M`-F6`@`(````XI8"`"L```#KE@(`$````!>7`@`9````*)<"`!8```!"EP(`
M#@```%F7`@`/````:)<"`"D```!XEP(`+P```**7`@`$````TI<"``P```#7
MEP(`!@```.27`@`$````ZY<"`!(```#PEP(`"@````.8`@`&````#I@"``H`
M```5F`(`"````""8`@`(````*9@"``0````RF`(`"````#>8`@`,````0)@"
M``0```!-F`(`"````%*8`@`$````6Y@"`#$```!@F`(`+P```)*8`@`(````
MPI@"``D```#+F`(`"````-68`@`,````WI@"``P```#KF`(`'0```/B8`@`:
M````%ID"`!8````QF0(`#````$B9`@`*````59D"``H```!@F0(`$P```&N9
M`@`H````?YD"`!4```"HF0(`&0```+Z9`@`8````V)D"``P```#QF0(`!```
M`/Z9`@`(`````YH"`",````,F@(`&@```#":`@`0````2YH"``@```!<F@(`
M%@```&6:`@`&````?)H"``(```"#F@(`!@```(::`@`&````C9H"``0```"4
MF@(`!@```)F:`@`&````H)H"``@```"GF@(`!````+":`@`$````M9H"``@`
M``"ZF@(`)0```,.:`@`R````Z9H"``H````<FP(`#````">;`@`,````-)L"
M``H```!!FP(`"````$R;`@`(````59L"``X```!>FP(`#0```&V;`@`(````
M>YL"``@```"$FP(`%0```(V;`@`/````HYL"`!4```"SFP(`"@```,F;`@`*
M````U)L"``@```#?FP(`"````.B;`@`$````\9L"`!$```#VFP(`$@````B<
M`@`)````&YP"``H````EG`(`*````#"<`@`$````69P"``@```!>G`(`$```
M`&><`@`(````>)P"``@```"!G`(`!@```(J<`@`G````D9P"``H```"YG`(`
M!````,2<`@`4````R9P"``H```#>G`(`#@```.F<`@`(````^)P"`!T````!
MG0(`)P```!^=`@`0````1YT"``<```!8G0(`!````&"=`@`*````99T"``@`
M``!PG0(`"0```'F=`@`.````@YT"``\```"2G0(`"@```**=`@`2````K9T"
M`"````#`G0(`'@```.&=`@`&`````)X"``@````'G@(`!0```!">`@`.````
M%IX"``P````EG@(`%@```#*>`@`7````29X"`!0```!AG@(`"P```':>`@`1
M````@IX"`!H```"4G@(`%P```*^>`@`5````QYX"``@```#=G@(`#@```.:>
M`@`$````]9X"``@```#ZG@(`#0````.?`@`.````$9\"`!`````@GP(`!```
M`#&?`@`(````-I\"``@````_GP(`$````$B?`@`,````69\"``@```!FGP(`
M*````&^?`@`.````F)\"`!(```"GGP(`"````+J?`@`.````PY\"``0```#2
MGP(`!````->?`@`(````W)\"``8```#EGP(`"P```.R?`@`$````^)\"`!(`
M``#]GP(`"P```!"@`@`0````'*`"`!`````MH`(`!@```#Z@`@`&````1:`"
M``(```!,H`(`!````$^@`@`,````5*`"``@```!AH`(`!@```&J@`@`$````
M<:`"`!L```!VH`(`#P```)*@`@`&````HJ`"``\```"IH`(`#P```+F@`@`6
M````R:`"``T```#@H`(`)P```.Z@`@`+````%J$"``\````BH0(`+````#*A
M`@`A````7Z$"`!H```"!H0(`$0```)RA`@`B````KJ$"``\```#1H0(`&```
M`.&A`@`>````^J$"`",````9H@(`+P```#VB`@`G````;:("`'@```"5H@(`
M#@````ZC`@`$````':,"``H````BHP(`"@```"VC`@`$````.*,"``P````]
MHP(`!@```$JC`@`&````4:,"``P```!8HP(`"@```&6C`@`7````<*,"`"P`
M``"(HP(`%@```+6C`@`9````S*,"`#,```#FHP(`$@```!JD`@`2````+:0"
M`!4```!`I`(`*````%:D`@`*````?Z0"`!L```"*I`(`!````*:D`@`)````
MJZ0"``<```"UI`(`&@```+VD`@`(````V*0"``@```#AI`(`#````.JD`@`(
M````]Z0"``@`````I0(`"@````FE`@`(````%*4"`!D````=I0(`.````#>E
M`@!"````<*4"`!X```"SI0(`"0```-*E`@`/````W*4"`!<```#LI0(`'```
M``2F`@`(````(:8"``0````JI@(`!````"^F`@`'````-*8"``@````\I@(`
M"````$6F`@`(````3J8"``0```!7I@(`!````%RF`@`.````8:8"``@```!P
MI@(`#````'FF`@`,````AJ8"`!0```"3I@(`$@```*BF`@`.````NZ8"``T`
M``#*I@(`%@```-BF`@`;````[Z8"``@````+IP(`$0```!2G`@`G````)J<"
M``P```!.IP(`#````%NG`@`&````:*<"`$,```!OIP(`#0```+.G`@`1````
MP:<"`!(```#3IP(`%0```.:G`@`0````_*<"``T````-J`(`$0```!NH`@`7
M````+:@"`!````!%J`(`#0```%:H`@`/````9*@"`!@```!TJ`(`#@```(VH
M`@`(````G*@"``P```"EJ`(`"````+*H`@`@````NZ@"`!(```#<J`(`"```
M`.^H`@`*````^*@"``L````#J0(`!`````^I`@`L````%*D"``0```!!J0(`
M!@```$:I`@`2````3:D"`!L```!@J0(`!P```'RI`@`(````A*D"``\```"-
MJ0(`!````)VI`@`(````HJD"`"@```"KJ0(`(P```-2I`@`A````^*D"`"$`
M```:J@(`(P```#RJ`@`Z````8*H"``0```";J@(`#````*"J`@`<````K:H"
M`!,```#*J@(`"@```-ZJ`@`*````Z:H"`!\```#TJ@(`!````!2K`@`(````
M&:L"`"$````BJP(`1P```$2K`@`J````C*L"`"D```"WJP(`(````.&K`@`$
M`````JP"``X````'K`(`#````!:L`@`*````(ZP"``P````NK`(`$````#NL
M`@`4````3*P"``H```!AK`(`)P```&RL`@`?````E*P"`"````"TK`(`(P``
M`-6L`@`*````^:P"`!L````$K0(`(0```""M`@`4````0JT"`!4```!7K0(`
M(P```&VM`@`(````D:T"`!8```":K0(`%````+&M`@`2````QJT"`!D```#9
MK0(`%````/.M`@`8````"*X"``@````AK@(`"````"JN`@`(````,ZX"``@`
M```\K@(`"@```$6N`@`$````4*X"``0```!5K@(`!@```%JN`@`7````8:X"
M``0```!YK@(`!````'ZN`@`(````@ZX"``8```",K@(`$@```).N`@`$````
MIJX"``@```"KK@(`$P```+2N`@`5````R*X"``(```#>K@(`!````.&N`@`$
M````YJX"``@```#KK@(`"````/2N`@`*````_:X"`!P````(KP(`$@```"6O
M`@`&````.*\"``P````_KP(`"````$RO`@`.````5:\"``P```!DKP(`"```
M`'&O`@`(````>J\"``X```"#KP(`#````)*O`@`(````GZ\"`!,```"HKP(`
M$0```+RO`@`L````SJ\"``8```#[KP(`!@````*P`@`$````";`"``H````.
ML`(`#@```!FP`@`(````*+`"``<````QL`(`#````#FP`@`(````1K`"`!\`
M``!/L`(`"````&^P`@`(````>+`"``P```"!L`(`(P```(ZP`@`(````LK`"
M``@```"[L`(`!@```,2P`@`$````R[`"`!0```#0L`(`!````.6P`@`*````
MZK`"``0```#UL`(`"````/JP`@`"`````[$"``0````&L0(`"0````NQ`@`)
M````%;$"``4````?L0(`!````"6Q`@`(````*K$"``0````SL0(`!@```#BQ
M`@`&````/[$"``@```!&L0(`&````$^Q`@`)````:+$"``H```!RL0(`!@``
M`'VQ`@`&````A+$"`!$```"+L0(`!````)VQ`@`(````HK$"``0```"KL0(`
M/P```+"Q`@`$````\+$"``0```#UL0(`!````/JQ`@`9````_[$"`"4````9
ML@(`#P```#^R`@`8````3[("`"4```!HL@(`%0```(ZR`@`8````I+("``\`
M``"]L@(`#P```,VR`@`,````W;("``0```#JL@(`!````.^R`@`$````]+("
M``0```#YL@(``@```/ZR`@`$`````;,"``D````&LP(`!@```!"S`@`$````
M%[,"``8````<LP(`!````".S`@`$````*+,"`!$````MLP(`!````#^S`@`6
M````1+,"`!0```!;LP(`#0```'"S`@`0````?K,"`!(```"/LP(`%````**S
M`@`2````M[,"``X```#*LP(`#````-FS`@`4````YK,"`!T```#[LP(`!```
M`!FT`@`(````'K0"``0````GM`(`#````"RT`@`0````.;0"``0```!*M`(`
M"````$^T`@`(````6+0"``0```!AM`(`!````&:T`@`5````:[0"`"<```"!
MM`(`!0```*FT`@`(````K[0"``8```"XM`(`"````+^T`@`2````R+0"``0`
M``#;M`(`!@```."T`@`A````Y[0"`!`````)M0(`"````!JU`@`&````([4"
M``P````JM0(`"````#>U`@`@````0+4"``0```!AM0(`!@```&:U`@`(````
M;;4"``P```!VM0(`!@```(.U`@`.````BK4"``\```"9M0(`&````*FU`@`D
M````PK4"`"$```#GM0(`.`````FV`@`4````0K8"``X```!7M@(`&````&:V
M`@`<````?[8"`!8```"<M@(`%P```+.V`@`7````R[8"`#L```#CM@(`#P``
M`!^W`@`&````+[<"`!(````VMP(`/````$FW`@`F````AK<"`!\```"MMP(`
M%0```,VW`@`F````X[<"`"@````*N`(`*````#.X`@`Z````7+@"``\```"7
MN`(`'0```*>X`@`;````Q;@"`"````#AN`(`%0````*Y`@`=````&+D"`!T`
M```VN0(`$P```%2Y`@`1````:+D"`!````!ZN0(`10```(NY`@`;````T;D"
M`!\```#MN0(`'0````VZ`@`=````*[H"`!@```!)N@(`&````&*Z`@`A````
M>[H"`!D```"=N@(`$P```+>Z`@`5````R[H"`#P```#AN@(`,````!Z[`@`&
M````3[L"`#````!6NP(`'0```(>[`@`;````I;L"`!D```#!NP(`&````-N[
M`@!%````]+L"`!\````ZO`(`#P```%J\`@`/````:KP"`!\```!ZO`(`90``
M`)J\`@`>`````+T"``\````?O0(`+P```"^]`@`X````7[T"`#$```"8O0(`
M+P```,J]`@`5````^KT"`"0````0O@(`)````#6^`@`@````6KX"``@```![
MO@(`!@```(2^`@`T````B[X"`!D```#`O@(`%P```-J^`@`7````\KX"`!T`
M```*OP(`$0```"B_`@`/````.K\"`!8```!*OP(`$P```&&_`@`3````=;\"
M`!$```")OP(`$0```)N_`@`1````K;\"`",```"_OP(`$P```.._`@`(````
M][\"`!,`````P`(`"````!3``@`3````'<`"``@````QP`(`$P```#K``@`=
M````3L`"``@```!LP`(`!@```'7``@`?````?,`"`!,```"<P`(`(@```+#`
M`@`9````T\`"`!@```#MP`(`(0````;!`@`;````*,$"``T```!$P0(`$0``
M`%+!`@!"````9,$"`!<```"GP0(`)````+_!`@`E````Y,$"`"$````*P@(`
M'P```"S"`@`<````3,("`"0```!IP@(`.0```(["`@`O````R,("`#,```#X
MP@(`*P```"S#`@`M````6,,"`"8```"&PP(`'````*W#`@`7````RL,"`"T`
M``#BPP(`%P```!#$`@`;````*,0"`!P```!$Q`(`(@```&'$`@`@````A,0"
M`"@```"EQ`(`.````,[$`@`S````!\4"`#$````[Q0(`'0```&W%`@`:````
MB\4"`"L```"FQ0(`*0```-+%`@`<````_,4"`!(````9Q@(`%P```"S&`@`E
M````1,8"`"4```!JQ@(`&P```)#&`@`5````K,8"`!<```#"Q@(`'@```-K&
M`@`>````^<8"`!L````8QP(`$0```#3'`@`9````1L<"`!L```!@QP(`&P``
M`'S'`@`D````F,<"``\```"]QP(`/0```,W'`@`3````"\@"``@````?R`(`
M:@```"C(`@`>````D\@"`!L```"RR`(`,P```,[(`@`O`````LD"`"X````R
MR0(`*0```&')`@`P````B\D"`",```"\R0(`'````.#)`@`?````_<D"`!D`
M```=R@(`%@```#?*`@`(````3LH"`#,```!7R@(`$P```(O*`@`M````G\H"
M`"$```#-R@(`%P```._*`@`/````!\L"`"(````7RP(`)````#K+`@`(````
M7\L"``P```!HRP(``@```'7+`@`(````>,L"``0```"!RP(`"````(;+`@`(
M````C\L"``@```"8RP(`"P```*'+`@`$````K<L"``\```"RRP(`!@```,++
M`@`*````R<L"`%$```#4RP(`2P```";,`@`Y````<LP"``0```"LS`(`"P``
M`+',`@`+````O<P"``<```#)S`(`!````-',`@`,````ULP"``0```#CS`(`
M$0```.C,`@`3````^LP"``8````.S0(`!P```!7-`@`.````'<T"``8````L
MS0(`!@```#/-`@`2````.LT"``\```!-S0(`%0```%W-`@`,````<\T"`!@`
M``"`S0(`#P```)G-`@`.````J<T"``P```"XS0(`!````,7-`@`%````RLT"
M``\```#0S0(`$````.#-`@`2````\<T"`!\````$S@(`'@```"3.`@`?````
M0\X"``X```!CS@(`%@```'+.`@`9````B<X"`!0```"CS@(`$@```+C.`@`2
M````R\X"`!<```#>S@(`$@```/;.`@`2````"<\"`!<````<SP(`&````#3/
M`@`1````3<\"`!T```!?SP(`$0```'W/`@`:````C\\"`!$```"JSP(`$@``
M`+S/`@`6````S\\"`!<```#FSP(`$@```/[/`@`7````$=`"`!4````IT`(`
M$P```#_0`@`0````4]`"`!$```!DT`(`$@```';0`@`7````B=`"`!(```"A
MT`(`$@```+30`@`/````Q]`"`"8```#7T`(`*0```/[0`@`.````*-$"`!8`
M```WT0(`)P```$[1`@`8````=M$"`!8```"/T0(`'@```*;1`@`?````Q=$"
M`!@```#ET0(`%````/[1`@`3````$]("`!(````GT@(`%P```#K2`@`B````
M4M("`!8```!UT@(`(````(S2`@`&````K=("``P```"TT@(`"@```,'2`@`$
M````S-("``H```#1T@(`"````-S2`@`$````Y=("`!X```#JT@(`&P````G3
M`@`&````)=,"`!8````LTP(`#@```$/3`@`G````4M,"`!4```!ZTP(`%```
M`)#3`@`D````I=,"``0```#*TP(`!@```,_3`@`*````UM,"`"````#ATP(`
M"@````+4`@`.````#=0"`"4````<U`(`)````$+4`@`/````9]0"`!<```!W
MU`(`$@```(_4`@`(````HM0"``8```"KU`(`C0```++4`@`&````0-4"``@`
M``!'U0(`"````%#5`@`.````6=4"``0```!HU0(`!P```&W5`@`,````==4"
M``H```""U0(`"P```(W5`@`/````F=4"``0```"IU0(`(P```*[5`@`,````
MTM4"``P```#?U0(`$````.S5`@`.````_=4"``H````,U@(`%0```!?6`@`(
M````+=8"``\````VU@(`-0```$;6`@`&````?-8"`#````"#U@(`'P```+36
M`@`*````U-8"``H```#?U@(`"@```.K6`@`=````]=8"`!`````3UP(`"@``
M`"37`@`7````+]<"``L```!'UP(`"````%/7`@`/````7-<"`!4```!LUP(`
M$0```(+7`@`$````E-<"`!(```"9UP(`!@```*S7`@`8````L]<"``(```#,
MUP(`"````,_7`@`2````V-<"``0```#KUP(`%````/#7`@`D````!=@"``0`
M```JV`(`"````"_8`@`(````.-@"``@```!!V`(`!0```$K8`@`&````4-@"
M``\```!7V`(`#P```&?8`@`$````=]@"``<```!\V`(`$````(38`@`6````
ME=@"``0```"LV`(`$0```+'8`@`1````P]@"``@```#5V`(`"````-[8`@`,
M````Y]@"``H```#TV`(`$````/_8`@`,````$-D"``@````=V0(`$````";9
M`@`1````-]D"``P```!)V0(`"````%;9`@`F````7]D"`",```"&V0(`&0``
M`*K9`@`1````Q-D"``H```#6V0(`%P```.'9`@`*````^=D"``H````$V@(`
M"@````_:`@`*````&MH"`!`````EV@(`#@```#;:`@`&````1=H"``@```!,
MV@(`'0```%7:`@`$````<]H"`!L```!XV@(`#0```)3:`@`1````HMH"``0`
M``"TV@(`!@```+G:`@`(````P-H"``P```#)V@(`$````-;:`@`$````Y]H"
M``0```#LV@(`!````/':`@`$````]MH"``D```#[V@(`"`````7;`@`1````
M#ML"`!(````@VP(`&0```#/;`@`C````3=L"``\```!QVP(`#P```(';`@`C
M````D=L"`"T```"UVP(`(````./;`@`I````!-P"`&,````NW`(`%@```)+<
M`@`(````J=P"`"(```"RW`(`"````-7<`@`$````WMP"`!,```#CW`(`(P``
M`/?<`@`(````&]T"``@````DW0(`!0```"W=`@`(````,]T"``(````\W0(`
M!@```#_=`@`(````1MT"``4```!/W0(`!@```%7=`@`$````7-T"``@```!A
MW0(`!````&K=`@`*````;]T"``H```!ZW0(`.````(7=`@`P````OMT"`!,`
M``#OW0(`$P````/>`@`5````%]X"``T````MW@(``@```#O>`@`"````/MX"
M``P```!!W@(`!````$[>`@`,````4]X"``(```!@W@(`"P```&/>`@`A````
M;]X"`"4```"1W@(`&0```+?>`@`>````T=X"`!D```#PW@(`'0````K?`@`]
M````*-\"`!<```!FWP(`&0```'[?`@`=````F-\"``L```"VWP(`&````,+?
M`@!%````V]\"`"$````AX`(`%````$/@`@`@````6.`"`"$```!YX`(`)0``
M`)O@`@`@````P>`"`"8```#BX`(`$`````GA`@`.````&N$"``\````IX0(`
M"P```#GA`@`9````1>$"`!<```!?X0(`4P```'?A`@`7````R^$"`$$```#C
MX0(`*````"7B`@`A````3N("`!L```!PX@(`'````(SB`@`L````J>("`"\`
M``#6X@(`(0````;C`@`=````*.,"`!L```!&XP(`%0```&+C`@`?````>.,"
M`!4```"8XP(`%0```*[C`@`5````Q.,"`!4```#:XP(`%0```/#C`@`3````
M!N0"`!<````:Y`(`)````#+D`@`B````5^0"`",```!ZY`(`%0```)[D`@`:
M````M.0"`!X```#/Y`(`$0```.[D`@`5`````.4"`!X````6Y0(`$````#7E
M`@`7````1N4"``@```!>Y0(`4P```&?E`@`(````N^4"`!8```#$Y0(`#```
M`-OE`@`,````Z.4"`"(```#UY0(`&0```!CF`@`1````,N8"`#X```!$Y@(`
M5@```(/F`@`M````VN8"`%$````(YP(`*0```%KG`@`;````A.<"`#8```"@
MYP(`$P```-?G`@`7````Z^<"`!<````#Z`(`&0```!OH`@`3````->@"``D`
M``!)Z`(`9````%/H`@`/````N.@"`!,```#(Z`(`&````-SH`@`;````]>@"
M``\````1Z0(`$@```"'I`@`Z````-.D"``\```!OZ0(`#P```'_I`@`)````
MC^D"`!4```"9Z0(`#````*_I`@`/````O.D"`!$```#,Z0(`"@```-[I`@`*
M````Z>D"``@```#TZ0(`"@```/WI`@`+````".H"``L````4Z@(`$@```"#J
M`@`6````,^H"`!0```!*Z@(`!@```%_J`@`*````9NH"``@```!QZ@(`"```
M`'KJ`@`&````@^H"``H```"*Z@(`!@```)7J`@`(````G.H"``@```"EZ@(`
M!@```*[J`@`&````M>H"``H```"\Z@(`#0```,?J`@`(````U>H"``8```#>
MZ@(`!@```.7J`@`,````[.H"``T```#YZ@(`!@````?K`@`&````#NL"``8`
M```5ZP(`"@```!SK`@`&````)^L"``T````NZP(`#P```#SK`@`&````3.L"
M``8```!3ZP(`"@```%KK`@`&````9>L"``T```!LZP(`!@```'KK`@`(````
M@>L"``P```"*ZP(`"````)?K`@`*````H.L"``H```"KZP(`!@```+;K`@`.
M````O>L"``0```#,ZP(`#P```-'K`@`%````X>L"``8```#GZP(`$0```.[K
M`@`,`````.P"``0````-[`(`#@```!+L`@`(````(>P"`!(````J[`(`#```
M`#WL`@`*````2NP"``0```!5[`(``@```%KL`@`3````7>P"``0```!Q[`(`
M`P```';L`@`"````>NP"`!(```!][`(`!````)#L`@`0````E>P"``T```"F
M[`(`#````+3L`@`$````P>P"``,```#&[`(`"````,KL`@`"````T^P"``0`
M``#6[`(`!````-OL`@`)````X.P"``D```#J[`(`!@```/3L`@`$````^^P"
M``8`````[0(`"`````?M`@`$````$.T"``<````5[0(`$````!WM`@`$````
M+NT"``P````S[0(`"````$#M`@`3````2>T"``H```!=[0(`"@```&CM`@`"
M````<^T"``0```!V[0(`"````'OM`@`&````A.T"``P```"+[0(`&@```)CM
M`@`$````L^T"``8```"X[0(`"@```+_M`@`%````RNT"``4```#0[0(`$```
M`-;M`@`*````Y^T"``P```#R[0(``0```&L*```V````S@@````````W"```
M=P,``)(#```+"0```````,$!````````)@0`````````````0@H``&P)``#L
M"0``V@,``(<````;"0``XP4````````I!P``[P<````````="0``X@8``)@*
M``!A````7`4``,0*``!N"```20@```8(```6`````````%$!````````1P``
M`",'``!V!```(@$``)D'```3"0``%0$``%\'``"G"0``B0<``$X(``#_`0``
M7@$``&H````X"0```````-4'``!7`@``)```````````````````````````
M`````````#D````-````E@D``)\&```M"P``/@4``+D!``!P"@``[P```*X*
M``!A!````````.L)````````0@L``'8%``!X!0````````````#S````````
M`)P%``#+````V@4`````````````:`@``,0(``#B`0``T0,``$L$```P!P``
M-00``'4#``!\`0``[`H``$D'````````_00``"X%``"+!```*@(``/4"``!L
M!0````````````#_!0``9@<````````H"0``FPD```T)``"'!@``\0D``'D!
M``"P`P``408``"D#``!I!````0<```````""!P``3````*0$``#G````````
M`,X%``#G!@``10$``(8(````````````````````````'P@``)8'``!F"```
MF00```````#V`0``5`(```````!P!@``````````````````6P<```D*````
M````-@(``+\%``#B!P``X`D``!D%```I"0``DPH``'D``````````````%`!
M``!=`P``U````,@'``"B!```*0L``*\!````````X0(``.T!```.!P``````
M`+X#``#0"0``]P$``#8#``".!P``O````*\&``"H"0```````','``!I"0``
MNP,````````G!```R`````````"-!P```````#H&``#+"0```````#8*``!C
M!```U@,``/D)```E"```[`<``*H!```Q!P``GP@`````````````'0@`````
M```G"P```````-D%``"V"0``IP`````````7"```Z0$``'0&``"S!```-`H`
M``````#;"```"0(``(P)````````M````#T+``!<!P``,@0``&0&```Z"0``
M`````/X&```X"```4`,``(L)``!R````CP$``(D!``"R"@``,08```````#C
M"@``I`<``"X+``!<"```X08``-H(````````0P0```@````K`P``-P,`````
M``#8!@``$@@```````#*!P``^`H```````#*!@``````````````````"@0`
M`````````````````'0%```U!0``@0(``,$)``````````````````#A"@``
M2PD```````!X!```4P0```D'```6`P``3`H``+<)``!<!@``[@```,T"``":
M!@``=P@``!0#````````@P0````````\!P``>`H``'P```!3"@```````%H%
M```8"```X`(`````````````804```$!``#7!P````````````"-`P``M@8`
M`(8)```````````````````D`0``90@``&\'``"G!@```````+P%``"@!P``
M`````.,(``"E!P````````````"3`````````)($````````,PH``*$"``"K
M"@```````'(#```R!0``WPH``````````````````%8'``#=`@``&`H`````
M``"L!0``LP,``-H'``#0!P``7````"X````E!P``D`8``,X)``#'!P``'0(`
M`-($```%"0``5P,``/X'```P"0``J@@``'T"`````````````-<$``!?!```
M!`D``,$%```\"```G0$``((%````````908``#D+``!=`0``,@L``/$%```6
M!P```````&4)````````-PH``*H#``#D`0``!0@```````!_!P``=P$``*H%
M``!O"@``+0$``,L$``!.`P``$0<``(L'``#*`0````,``!$$````````<@D`
M`'H*```=`0```````*\*``#)`P``!P0``&$*``!,`0``````````````````
M4@(``&X$``"8!@``I@4`````````````SPH````````````````````````+
M`P````````````"*"0``<PH``+X$````````-@$``%<$``#L"```.P@``-X)
M```T`P```````.L!`````````````#D%```J"0```````"L$```C"```````
M`#X)````````6P,``+<(```=!@```````/X*```$"@````````````#9!```
M+`8`````````````.0H``%4&```R!P``Y0,``/8&``#Z`P```````!@#````
M`````````-X"``#O`0``8P,``#P"``"6!```MP4``/8)```A"```:@H``.D#
M````````=`,```````!)`@````````````!6"```+@<`````````````)P4`
M`&H)``#'`@````````````!>!P``)P```&T#````````'@8```````!]!P``
M`````%$#`````````````$P'```M!@``?`D`````````````6`(```````"J
M!P```````$T!``!P!```%00`````````````3@$``$\)```$!P```````#D!
M``"3!0```P8`````````````[`$``#<'``#W"@``)`<``$0$``#P!```R08`
M``````#Q`@``SP4``&($```.!````````$T'``#Q"```1`$``,\(``#@!P``
M```````````Q`0``'````)T$``#G`0``(00````````)"````````$8#``#I
M`@``N`$``%8%````````;`,``.0*````````@0,``)@(``!'`@``K0D``)0`
M````````X@0``"L*````````+PH``#4)``"P`0``9`@```````"'`P``````
M`,T'``""!```?04``%X*``!9!0``VP4```````!X!P``FP8``&P'````````
MM`H``-0*``"*````7@D``*X&````````'0<```````#/`P``:@8``"@+``#J
M!@````````````!["```"@,``*`"``#5"@``1@H``#P*``"<`0``````````
M``!H!0``3`4``-`&``!F``````````T$```3`@`````````````8"0``00D`
M``````"T`0``+00``/(#```T`@``M@H``*H$```0`0```````%L*``#6````
M?@D``````````````````!4#``"C!```V@D``-4"``!#"P```04``%0!```>
M`P``HP@``.D)``"H"@``N08``$X'``"Y"```I@$``!("``":"0``?0```$,)
M``#W`@``N`@``'8&``#Z!@```````#X*````````^04``,4```!$"P``,0``
M`!D``````````````&0$````````)`,``"P(``#>!@```````)$'```=!```
M`````#,)``":`@``:P0``"P!``!4"@``8`8```4!``"%"````````'L```#`
M"@```````*$&`````````````/`&````````L0$`````````````BP4``.$(
M````````C@H``'X#``!!`@``U@(``*@#````````.0@``&("````````J`(`
M``````!]!@```````+0$````````%`0`````````````WP```*L```#]`@``
M(@```#<!```3!0``+PD``!P&``!=!0``&0,``',&```N`P``8P```$X%``"U
M"````````'$&````````)`@``-$(``#"!P```````)<&``"T!P```````)@`
M```5!@``F0@``#,%````````4@,```````#R"0```````$@(``"*!@``X@,`
M`+4#````````(`4``*H*``"5"0```````$L!``!S!```N@$``*4)```W"P``
M````````````````/0<``"`$```S"P``]0$``+@$``#E!P``N@4``&D(```L
M`@``S`4``,,$``"="```]@(``(T*``"H!@``)0D``(\"````````I@<`````
M```Q!```6`,``)X"``#=``````````````"M!@````````````"``@``"@@`
M`)4"```9"@``L@(``*T"```A"0``"`4``*D*```:`0``I`8``,`#``"7`@``
MT`$```\%``!`!```$`H``.<)``"^!P``Z08```X+``"-!0``4P8``!0&````
M````S`,```H"``"9!@``*@4```````!U!@``Z`(``-T(````````V`H``'H'
M``#D`P```````'L!````````X`@````````E```````````````&`@``````
M``````!T`@``:@4``/8#``"/!P``:08``%T'````````N`H``,,(``#N`0``
MGP<``&,'``#K`P``EP@```X#```X`@``^PD````````<"```<04``/<(```2
M"0``S00``"T```#("```$P<```$$````````*@@``$H"``"U`@``,@8``%L(
M````````]P8``.<#```@!@```````%<)``!W!```\@8``#$%``#:"@``'0``
M`),$``!D!P``V`0``-@(```7!0``V@(``(\(``"!"@``#08``$L*``!N"@``
M`````%`)```,`````````-D```!>!```J`$```````#X"```50$``,@&``!^
M`@``SPD```````"#`P```````#X"``!Z`P``/0D``$`(```2!```/P4```@(
M```?`P``#0L```````!N!@``)@4``,`"``#*`P```````$D````B!0``:`$`
M`+<!``"G!````PL``$0```!0`@``XP<``-0&```(!P``OP(``#`%````````
M(P$````````[!```=`@``"\#``!]"@``UP$``-\&``!E`@```````/0"```J
M"@``QPH```````#;`0``D@(``.@!``!+"```Y0@``#<%``!:````````````
M``"-"```,`(``'T#```1"P``:P,``&((``!2`0```````"8*````````Q`0`
M`#T```"""@``@````,P'``!3"````````/0`````````[@<``$(!```V!@``
M`````",&``"B`@``?@<``/0!````````V0@``#H#``#B!0```````*0(``!E
M!```IP<`````````````J04```,````\!0```````.((```=`P```````#$*
M````````=PD``(`)``#M"````````%D#``"3!P``O04``/@%``#G!```R`$`
M`!`+```@"@``U`@``)<!``![!P``9P$``)<%````````4@````8&````````
MY@(``#4&````````K`D``'8!``#.!P``O0<```````#Z!```0@D```H%``!U
M"0``W```````````````4P<``#L#```5`````````$T*``#/!```X00``(P$
M``!!!```-P``````````````OP```&L'``!D!0``O`(``#8'``#O!```T`4`
M`(D)``"N`0```````#`$``!G!0``@@D``%4'``#Q!P``;00``/T'``"B````
M8@8````````-`0``+P8```,(``#Q"@``B04``*(*````````W@,`````````
M````7P,``+$#``#<"````````#X(``#K````M@0``#L!``#`!````````(<$
M``!R!@```````"("``!S`````````)<)````````O08````````Z!0``````
M``X(```(!@``(P,``````````````````.X(`````````````'H!``#H"0``
M(0(``'0$``#'!0``?PH``/L!````````=@`````````E!0``R00``+8(````
M`````````/(*``#L!````````%$*``!?`@``G@@```\!```C"P```````)T*
M``!)!````````'`"````````````````````````D@H``"L```#Z!0``````
M`/0*```D`@``?P,```4*``!#`````````($!````````:P8``+T!``!F!0``
MT@@``$8$```X"@``BP$``(T!``#2`@``ZP4``%<'```[`@````````````#L
M!0``#P````\#```P"@``.0D``.4`````````9`(``+\(``""`````````%0`
M````````7P$``(4%``#?!0``_P@``,P$````````````````````````$P8`
M`&('````````9`$``.0&``"*`P``)0H``%X"``#B"@```````"4"``#!!@``
M```````````Z!P``P`D```$(``!W````X`H```````!U!```Q`D````````J
M"P``B@@``)H#``"["@``1@```+0%``#_`P``1`@``,0'``"S`0```````$X)
M````````B@<``*8$``"X`P```````'<%```1!@```````*8(``!]`0``]@0`
M``````!2!````````#L'`````````````````````````````$8!````````
ML`0``.<(```5!P``N@```#\(````````6@@``(\*``"!!0``U@H`````````
M````.@$``(@$````````I08``-,`````````-0(````````!"P```````-@!
M``"9````[@0```````!:!`````````````"Y`@```````!T%``"@!@``@P@`
M`/4(````````8P4``.P`````````P@0``-<#```@"P``JP,``.8#```0````
M2`8``$4#``#(`@``;0```$<)``"C!0``?@8``'L&``!8"```C`8``!P+````
M`````````*T'``"^`@``7`$```````"#"@``7P@`````````````?@@``*@%
M```,!@``L08`````````````\@$``'4```"9"0``1`(``!\$``![!0``^0$`
M`#\&``""`@``:P````````!/`P``N`(````````S`@``#`<```````"^"0``
M0P,``!,+````````TP4``&`)``!7`````````)8"````````4`8`````````
M`````````(<'`````````````-(*`````````````/D$``!!!P``@`<``'@#
M``!F`P``UP4``-,*```-"@``[@(``'D#```6"@``L0H``$4````H"@``J00`
M``````"."```1@(``$$&``#N"@``/0(``*T#````````2`$```\(````````
MQ0H``.8$``#=!```=@(``.@'``"M"@````````````"9`@````````````!/
M!@```````$,&``":"@``50,`````````````Y@````````"@!```DP(``'<&
M````````_`,`````````````\`H``-@"````````/08``(H%``!\"@``5@0`
M`,4'```+!@``904``*D&``!L!````````$@)``!Q`@``3@8``)@$```>!P``
MU@4```````!>!0``V0<``$`+``#N`P``90<``$$*``#`"```A`4``,T)````
M````T````"``````````I0(``.T*``!]"0``[@8``/0)````````\`(```,$
M``````````````,*```^!P``70H``*(%```:!P```````*('````````504`
M`-H!```K"0``[0<``)`"``#6!P```````,P*```,`P``#PD````````R`0``
M0@```*\(```H!@``)@,``!@&``"K`@```````$@$``!A"````@D```````"R
M!```C@````````!'!P``T@,``,0!``"D!0``-@4``"(&`````````````)$%
M````````(0,```````!U`@```````$$+`````````````&X%``#7"0``I@(`
M`(X$``#J`P``OP<``"()``"M"```Y````)\"``!Q`P``*@,```````"/!```
MS@8``&$&`````````````-L"``"V`@```````,P"``!X!@```````'8'````
M````+`H``%@*``##`P``+P0``'0'``"W!@``$P0``,(#```\`````````(D#
M``!0!```NP0``"D```"<"```B`,```H'``!&"0```@4``)P'````````"@$`
M`$,'``"@````'P<``'L*````````%`<```8+````````E`,```<%``"4!```
MRP8``)<'``"X!@``Z0`````````("P``^@H``-\'````````(P0``$0)```(
M`@````````````#T!@``7`(```````#!"@``1`<``&<(``#;!```>`D`````
M```E!```RP4```````"1`````````%T$````````%0@``)X)```2`P``]P0`
M`$@*``"L"@``8P8``$D!``#F!@``&P,``'P%``";`0``L`@``$,(``#J`@``
M``````X"``#1!````@0``%X#````````ZPH```````!F!```VP<``!<'``"+
M`@``=@@``-4%```_````]0H``+T#`````````````+L'``"3`P``&P0`````
M``#`!@````````````#("@````````````#Q!```R@H``)8%``#H````IP$`
M``````!%"P``_@(``+,*``#M!0``3@````D&``"[`@``:`8``+H'``!@"```
M`````&T(````````ZP(``'\&````````>@D``+X&``!&!P``;@```-D&``#H
M!@```````%0)``#;"0```````,P!``!"!```!P,``"8)``#$!0```````,X!
M``"?"0``$@L``,D(````````E0<``*D"``#2`0``=@D````````S`P``````
M```````R"````````&@)``!'!@```````#P+``#Z`0```````,$'```>`0``
M`````,D'``!%`@``+`0``!\*````````"@L``&,*````````00,``!H*``#,
M````-````/(%``"+"@``````````````````N@8```````"8!P``N`<```$#
M``!3`P``U@0```````"M`0``\0$````````K!P``PPD`````````````&`(`
M``P(````````'`$``/,&``!K`0``!PD``&P!```7!```'`H``/D"``#\!P``
MG@4``!L'``"%````*@```!@!```?`0```````!T+``"^`0``TPD``)T'```;
M!@``E`8``.4$``!O!0``:0<``)@"````````GP`````````:!@``_@$````!
M``!N`P``<P4``-4!``!O!````````#,(``#:!@```````,L(``";"```````
M`!<"``"S!@``B@0``#$(``#=!@``_P(``"D&```]`0```````,("``#D!```
M`````+8!``"="0``@`0``)\#``#-!@``B@H``%L"```6!@``CP8``!(%``#A
M!P``(08``)$!``!'!0``)P8````````+"@```````!4)``!:`0``Z@<``+L(
M``!*"```A0H````````:!```(`<```````#D"0``0````&4#````````````
M`(0*``!Q"```%PL```````#!````G````(L(``"Q`@``X`0``%(&````````
M`````.<%``#/````H0<```L$```6`@``$`@`````````````P`4`````````
M`````````&T!``#>`0``H0$````````5"P``+0D``%8!``#9`0``;08`````
M``#?`@``5`8``%\````>"P``(04``'T$`````````0H``#<$```X`0``40``
M`%L```````````````````#<"@``+`L``'H(``#4!```+@$``$H#````````
MKP``````````````50```-4$``#H"@``LP(``)<```"0````_04``%@&````
M````&P$``+`&``!X`@``:`H``$P)````````'`D``#H$``!4!````````/,)
M``#7`@``X0D```````#*`````````-L```"$`@``R@@``/`%```H!```````
M`"@(``#%"0``````````````````HP```#D"``!L`````````.4*```$!0``
MUP@``)`(`````````````"4#```@`0``M0$``+@)````````G0```(,!``"P
M"@``B0@``",)```X"P```````&(````#`P``)`H``.P"``#_!@``I`,```\'
M````````7`,``,$$````````90```/H`````````HP8``!P%````````%```
M`"<)``!["0``_@D`````````````]`0```````",````V0H```````!H````
M```````````M`@``?`<```````!P"0``]`4```````!#`@```````/8````\
M!```CP```&8*````````Q`,``%@'```$`@``30,```````#Q`P``B@(``!,#
M```D!```A@,``(0'``"N`@``E@```"\+```5"@````````X`````````^0``
M`!D&``#%!````````&T'``"0!P``[P,````````)`0``IP@``*\"```[!@``
M60$`````````````$0(``%H#``#F"```K@D``-X(``"I`0```````+(!```I
M"@````````````"$````+@0```````#F`0``DP$``)D%````````]`<``'\"
M``"O!0``````````````````M`8``/0(```K"P``<@0````*```1`P``3P4`
M`)4%``!\!@``C`$````````-`@``G@0``.,$```$!@``-@@``'\(```6!```
M`````"<*````````GPH``.T"````````I0@``$$(``"Z"@``"@8``%(%``#F
M"0``RP<```````#="@``:@,``#``````````A@(``-@%````````+0H``,,'
M``"I"0``K@0```````"+````.@@``%T)``"?!0``MP<``#4'````````_`0`
M`)H'``#2!0``"0`````````0!@``?@4``.T#````````4@H``/($````````
MP0(``!X)``"3"````````#\)```N`@``F@````````#\"@```````+D)````
M````70```(`(```Z````70(``.X)``#S!0``#`D````````X!````````!H#
M``"]"```P````-X$``#O"```L@@````````X!0``70@``#<)``!-`@``K00`
M`.X%``!@!P``AP4```````!:"@``O`,``#\$`````````````/`)``"1`@``
MB0(```````"N"```.00````````9!```PP$````````@"``````````````8
M"P``#@D``.L&``!;"0``>0H``#X&``#G`@``D`H````````S`0```````"$*
M``"\"@```````-@#``#A`P``T`@``%8)```:!0``JP<`````````````````
M`/@'````````9`,``#T*```6"0``Q@```*0"``!T`0``=PH``-8)``#O!@``
M`````(0&```+"```W0D`````````````6P$``&X'``!I````%P,`````````
M````?@$```````"%`0``/0,``````````````````&(%``#%!@``H@$`````
M``#3`0``W`4``-,$``"4`@```````)H%``";!0````````````"H!```4@D`
M`````````````P$``.4%``!?!@```````-0"```*````HPD```````#P!P``
MD@4``,T!``!3"0``O@H``*,!``"U"@``B`D```````!9!```)@(``$T$``!?
M"@````````````#4`P``2`,``,$#````````T@<``#,&``"8!0``80<``/<#
M``#_!P```````!X"``#["```10H``*D(``!D"@````````````!Y!0``!P@`
M`$T(``"S````!@D``/T&```&!P``(@<````````L"0``IP4``$\(```""```
M6@D``$P#``!U!0```````"T'``#X!@```````)X&``!1"0``$04`````````
M`````````),)``#U!```\08``-T%````````9`````````"2`````````.`%
M``"(!0``&@L``+`'``#M!@``C`,```````!C`@``M00``!,(``#;"@``````
M`*,#```8!```+@@``'4'```6!0``\@```%('``"&"@``7`0``)T%``#^"```
M+@D`````````````$`(``-,#```4"P``-0```+<"``"G"@``00```$4%``";
M"@``C@$``-T!`````````````+4'```U`P``$`4``&H"``#A````,P0``%D&
M``#.`P``R@D``&,!``"&!```>@```+8%````````M`,``%`%````````?P``
M``8*``#K!P``Q04```D+``!1!0``;P$``,@$```D"P``^`(``$0#```B!```
MK`$```,"```X!@```````$`&`````````@```!L"````````5`<``.D(``!+
M!@``!0,``-@'```+!P``*04``!\+``"8"0``Z@H``)P&```@`@``````````
M````````=`D`````````````[00```X&``"'"@```````&8&````````E@$`
M`%`*``#_"@``]04``-<```"2!@``,@````````"Y``````````````!(`@``
M`````)D#`````````````````````````````.()``!_`0``/@0``(D*``"T
M"0``3`8```````!4`P``U@$``.@(`````````````#0&```Z"P``_`$```\"
M``!"!P``3@H``#0$``"+`P``(P(````````#!P``B0```,T#``"X!0``\P@`
M`,X```"4`0``)@<``(T$`````````0(``*P'````````F@@``&\)``!%"```
M%0(``$4&``!6!@``@P(````````0"0``;P````````#&!@``&0D````````T
M"0``J@```,<#````````0`,``)8(`````````````(,%``!H`@``#PH``$D&
M````````M`(``(0#``#;`P``E@,``+`)``!V"@``G`0``.0(```,`@``````
M`*$$``!*````Q`8``*`)````"P``0PH``+H"``#C`0``#@4```````"B"```
M/00``!$!````````9P<``)$(````````(@H```````!9"@```````",%``#C
M!@```````%4(```M"```KP<``#$)````````K`@``$L%````````V0(``$D%
M````````L0<````````\"0``K@4``*<#``!G!```\P<`````````````A0,`
M````````````;04````````."@``N0<````````"!@``<0``````````````
M^0H``"X*`````````````&\(````````]P<``-,"````````````````````
M````=@,``"L%``#'`0``APD``$<!```O`@``0P$``)0)``#=`P``Q0,`````
M``````````````````!/````'`0``-`$``#]`0``S@0``%T&``!Q!P``P@$`
M`,4"``"(`0```````,@)```'````(@@``&$#`````````````+<#````````
M)P@``"<"```L!0``%04``%,```"5`P``H@,```P*``":`0``2`4``+L&```3
M"@``#@$``-0%``#'!@``O`8``#<&```_"P````````````"!"```Z@@``*$#
M``!O`P``H0H``,8(``"0`0``"0D``+H(``"Z"0``KP0``$X$``#7!@``````
M`%<%`````````````(L&````````D0H``!H`````!```I`D```````!\!```
M`````-\!``"4!P```````-X%``#K"`````````````#(!0```````+,)``#/
M!@````````````#I!P```````&8!```J!P``.08````"``"^!0``(0<``$`)
M````````EPH``,T`````````W@H``*\)```;"```W`8``-()``!6`P``````
M`,X"``!P`P`````````````T"```'@4`````````````A`$`````````````
M"04````````$"P````````````!:`@``5P@```````!'`P```0D``$("``##
M!@``!P8``/L"``##`@``(@,``$H*````````20H```````"U!@``E00``/L$
M``#&"@``K`(``*,"````````L0```,8)```?````U`D``&$)``"@"@``.PH`
M`#(*``!(````>@(``+\*````````H`4``/H'``!G!@``B`H``!<````1"0``
M=```````````````3@(``$P$``!Q`0``=P<``,((``"E"@```````"8(``">
M!P```````/P%``"[!0``$@```!(*```<`@``T`(``'`'``"?`0``````````
M``"]"0```````,(*````````O`0``,\'``!*!@``T0<``!H"```&!0``Q0@`
M`+L!``"%`@```````,D````[!0``60<``-D#``"M````Y08``.`!````!@``
MD0D``/P)``!,`@``Q````/P&````"````````'P(``"L!@```````#X#``"K
M"0```````*$(``#+`0``"`H```````!B`P```````&`*``#J!````````%$"
M```F`0``/`8``!X*```@`P``2@0````````(`P``I0````````#?`P``304`
M`&(!````````+P```(8%``#<"0``2P(```````!5"0```````'@```#U`P``
M;@(``%X&``"#!P``J@8``-<*```Q`P`````````````%`@``A@8``(@&``!P
M"```N@0``+\&``"H!P``1`4``'\%````!P``?P0``.D$``!,"```FP0``,<(
M```8!P``,@D``,()``"$"```00$````````'`0``0`H```````"/`P``/PH`
M```````7"@``_@0``(X&``#Z"```W0<``(,)``"F````K@```)`%```_`@``
MD@D``)@#``!1!P``9P(``*L(``!S"`````````````#J````*`<``+P)``"^
M"```F0H``!X$``!O`@```````#X+``"*`0````````````"/!0``````````
M```?`@``"P```&@'``#<`@``G@,``#H*``"S!0``M`@``'$*``"&`0``&PL`
M`#L`````````D@<``(T)``"H"```1`8``*8&```X````<`$```````"$"0``
M<@4``$4'```$````@@@``(D&``#&!```308``((!```4`0``)@8```(*````
M````I`$``!P#````````-`$``-(```"]!```D@@``!0)````````@P``````
M``",!0``*`$``-0!```K!@``E@8``)$&````````)0$```````!5"@``````
M`'@!``"(`@``J0````````#1"@``EP,``$8(``"`!0````````T#````````
M5`4``/8(````````)`4``-X````X`P``*@0```````#Y"```_0@``,\!``!'
M"@``]0<``#P#``#;!@``]@H```````!'"```R@(``"(+```U"```<```````
M```2`0``&PH``'`%```L`P```````+H#``"!!@``/04``#0+````````G`H`
M````````````L@```&,(````````XP(```````"D"@```````/8'``#Y!@``
MA0<``/P`````````U@8``$(&``!R`0``>00``&`#``#E`0``*`(```````#!
M"```"P(````````@"0````````0(``#-"````````&<````C````<00``&@$
M``#G!P``?PD```````"B!@``+0,``*4#``!9`@``@@,```(#```P`P``````
M`.\"``#M"0``R0(````````9`0``"00``$L'``#R`@``,P<````````E!@``
MI0$``,@#``!C"0``!00``.H%``#5````JP8``*4$``#-!0```````+8```#-
M"@```````&`!````````C@(``,D*```*"0``8`4``+D#``#Y`P```````+``
M`````````````(T"````````L00``((&``"Y!````````-4&```,"P``80(`
M`)L"````````'0H```````"'`@```````!H(```["0``E`@``#`+``!U"@``
M*P(``'D(````````A`0``/((``"J"0``!0L``'X$``````````````````!)
M`P``9@(``"<#`````````````+L)``#+`P```````'4(``!/`@``-0L``$`!
M``!L"```&@D```````"G`@``E0@``#T(````````C`@``'L$``!A`0``>P,`
M`,4!``"%!@``R0D```````"L`P``W`,```````#>!P``.PL``"D"``!Z!```
MXP,```````"4!0``'@@``%@$``#<!P``X@(``+P!``!Z!@``#04``/L#````
M````"`$``'("``#:````[`,``&T*``")!```Y0D````````$`0``7PD```<+
M```)`P``G@H``'D&```O!P``L@<```P$``#Z"0``,0L``/\$````````````
M```````^`0``]P```````````````````)$$```M!0``<@@``/T`````````
M`````/P(``#H`P``@`H``/L*```1"````````)X!``"1`P```````)@!```3
M````XPD```````"U````400```@$``````````````4'``!K`@``>`@``!L%
M``!N"0```````%4"``"C!P````````8#``!I`0``=P(``/<)``#"!0``<P(`
M`*`#``"``0````````````"`!@``M@,``%@````D!@```````/`!``!*!P``
M60D```````````````````````"M!0````````T(``##!0``=`H``!@```#?
M"0``D`D``/`(```+!0````````0$```E"P``,@,``(4$````````(0$```\$
M`````````````-\$``"5`0``%P8``-(&````````_@,```P%``!3`0``*0@`
M`(X%``!:!P``!@0``/,!``#]"0``@P8``*L!``!0"`````````4%``"<"0``
M```````````0`P``WP@``.8%`````````````.\)``![`@``0`(``%,%````
M`````@L``!(&``!>````H0D``.`#```6"```1@8```````!Y!P``2@4``)T"
M```L!P``-@L``)4&````````?`(```4&``#[!P``*@8``$((``!-"0``*P@`
M`/,*````````+P@``#P!``!K"```,`@```("``````````````````#1!@``
M*00``($$```P`0``_0H``!D'`````````````!`$``#5`P``T`H``&D#``!7
M"@``K`0`````````````!P<``/@$``!/!```,0(````````/"P``9PH``+4)
M`````````````"8```!/`0``:@0`````````````MPH``#0%``!$"@``S`@`
M`%4$````````H04``#H"````````!@$``!,!``!?!0``0@,```````"9`0``
MA@````````#6"```1@4``)T#``"!"0``X`8``*D#``!"!0``T`,````````J
M`0``90$``$\*``#5"0``R@0`````````````?0@``&X!``!B"@``````````
M``"'`0````````````!S"0``C0```*X#``!)"0``N`````````";!P``,@(`
M`#4*```4`@``J0<``$4$``#9"0``[0```+(&````````F@0``,<`````````
MC08``-$%```?"0``K````````````````````+$)``"_`0``.0,``&H'``#,
M!@``-`<``,`'```_!P``&0L``%@)``!;!`````4``+T"`````````````+X`
M``","@``G@``````````````]0D```H*```4"```40@```````!>"```0P4`
M`&P*``#,"0``30```"\%``#U!@```````$H!``"F"0``'P4````````'`@``
M`````#,```!0!P``*`,``)<$``#T`P``D`0``(<(`````````````,8%``!R
M"@```````+\$``!;!0``%PD```````"6"@``````````````````U`<`````
M``!0````L`(``"L!``#'!```JP4``-@```"B"0``!@````T'````````````
M`,,*``#[!0``PP```#@'``#X````K@<```````!I"@```````/X```"F"@``
M%@L`````````````'P8````````H!0```````/<%``#J"0```````&P&````
M`````````%0(``#+"@``W`$``%L&``"F`P``L@D``.@$````````````````
M```"`0``Z04``)4```"_`P````````````!L`@``&P```+<`````````A@<`
M``````!+`P``9@D````````/!@``L0@`````````````=0$```````#&`P``
M`````(@(```````````````````U`0``FP,```````#X`0``W`0```````!3
M`@``J``````````1````XP``````````````5@(``/4```"/"0``TP<``%P)
M``"Y"@``#`$````````W`@```````)(!``#1````<@<``.0"```0!P``?`,`
M``````#A!0``[P4``&T"``"\!P``O0```$L```"U!0``!`,``,\"````"0``
MZ0H``/\```!/!P``:@@```````````````````````!G"0``X0$``)L```".
M"0```````($```"Y!0``:PD``,`!``"W!```_@4```````!Q"0``````````
M``#"!@``?@H``!D(```#"0```````%8````2!P``````````````````````
M````````````^`D`````````````Z`4``(P'````````(0``````````````
M``````````"%"0``^0<```````#S!````````&4*````````8@D``$$%``"(
M`````````,(````C"@``:0(``%P*```("0``G08``.4"``"Q!0``Q@<``!$*
M``#S`@``O`@``&0)``!(!P``'`<``%<&````````]@4``+(%``!S`0``````
M`"0)`````````````)4*```4!0``-@0``*`(```G`0``>0(``.(````N!@``
MG`(``-$)```"!P```````,H%``"J`@``_PD`````````````5P$````````F
M"P``D`,```L+``#J`0``TP@``+8'`````````````.8'``#P`P```````+\)
M````````10D```````"[````5@H``),&```6`0``60````````!^````!PH`
M``````#)`0``QPD``+T*``#5"```8`(``.0%``#\`@``6`4``($'``"?!```
M[PH``+,(``!*"0``%P$```$&```^````<P,``-H$``#Q````60@```4```"D
M````S@H``*`!``!@````\P,``/('```O`0``1P0```````!2"````````!@%
M``#G"@``8`0``-$"``#L!@``Q`(```````#@````Q@(``"<'````````````
M`"@```!`!P``G`,```````!Y"0``KP,```````"E!0``TP8````````L````
MQ@$``/@#``"``P``HPH``(X#````````B`<```````!G`P```````#8)``"P
M!0``RP(````````Y!P```````'H%```P!@``&0(```````!M"0``LP<``!X`
M``#[``````````````#)!0``:P4``*L$``#F"@``*0$``-$!``!:!@``````
M`#\#```_`0``:`,``!0*``!I!0````````L!```#!0```````(P"``#D!P``
MH0```&\&``"4"@```````"$+``!8`0``L@,``/H"``!`!0```````-@)``#K
M!```^P8``&H!``#P````_0,````@("`@("!#8SH@`"`@("`@(%1O.B``("`@
M($1A=&4Z(``@("`@1G)O;3H@`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@4W5B:F5C=#H@`"!A="``(&EN(``B)7,B(&ES(&YO="!A(&1I
M<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@
M;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I
M;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`C`"4N,F9-
M0B`O("4N,F9-0B`@*"4N,F8E)2D`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D($UE<W-A9V5S`"5D(&1A
M>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"!M97-S86=E<R!H
M879E(&)E96X@9&5L971E9"X`)60@;65S<V%G97,@:&%V92!B965N(')E<&]R
M=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M`"5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2X`
M)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U
M<B!S>7-T96T@861M:6YI<W1R871O<BX`)60@;65S<V%G97,@:&%V92!B965N
M(')E<&]R=&5D(&%S('-P86TN`"5D('1O("5D(&]F("5D($UE<W-A9V5S`"5D
M+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+
M0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S
M(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L
M<F5A9'D@97AI<W1S+@`E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD
M97(@=V%S(&YO="!R96YA;65D+@`E<R!A="`E<R`E<P`E<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!M86EL8F]X+@`E<R!F;VQD97(@8F5I;F<@
M<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+@`E<R!H87,@86-C
M97!T960N`"5S(&AA<R!C86YC96QL960@(B5S(BX`)7,@:&%S(&1E8VQI;F5D
M+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E<R!H
M87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`B)7,B+@`E<R!H87,@
M<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!H87,@=&5N=&%T
M:79E;'D@86-C97!T960N`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N
M;W0@9F]U;F0N`"5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+@`E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("(E<R(N`"5S('1O
M("5S(&]F("5S`"5S('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@(B5S(BX`
M)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("(E<R(N`"5S('=I<VAE
M<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@(B5S
M(BX`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P
M860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z("5S("@E9"9N8G-P.V]F)FYB
M<W`[)60I`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@
M:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK
M<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P
M97)S;VYA;"!I;F9O<FUA=&EO;BX`*$%P<&QY('1H97-E(&-H86YG97,@86YD
M(&UO=F4@=&\@;F5X="!S8W)E96XN*0`H1&ES8V%R9"!A;&P@8VAA;F=E<R!A
M;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI`"A(5$U,*0`H4&QA
M:6X@5&5X="D`*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@
M87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@
M;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*0`H
M4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@
M=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL
M($Y/5"!B92!A<'!L:65D+BD`*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@
M*@`J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*@`L(&=U<W1I;F<@`"P@
M9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L
M96-T("TM`#$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+@`Q(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BX`,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M+@`Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A
M;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+@`Q(&UE<W-A9V4@:&%S
M(&)E96X@<F5P;W)T960@87,@<W!A;2X`,3`P(&-H87)A8W1E<G,`,3`P,"!C
M:&%R86-T97)S`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO
M=7)S`#(U,"!C:&%R86-T97)S`#4P,"!C:&%R86-T97)S`#Q0<F5V:6]U<P!!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@;&%R9V4@:6UA9V4@;F%M
M960@)7,@:7,@871T86-H960@=&\@=&AI<R!M97-S86=E+@!!(&UE<W-A9V4@
M>6]U(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I
M8V%T:6]N(&9R;VT@=&AE(')E8VEP:65N="X`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO
M=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@
M4VAO=V5R<P!!32]030!!3D0`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B
M;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97!T(&%N9"!A9&0@=&\@
M;7D@8V%L96YD87(`06-C97!T(')E<75E<W0`06-C97!T960`06-C97!T960Z
M(`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I
M;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N="=S
M(&YA;64Z`$%C8V]U;G1I;F<`06-T:6]N<P!!9&0`061D("5S('1O(&UY($%D
M9')E<W,@0F]O:P!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I
M;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N
M`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES
M<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N
M97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@<V]U<F-E`$%D9"!T:&4@)7,@365N
M=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&AI<R!T;R!M>2!C86QE;F1A
M<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K
M`$%D9"!T;R!M>2!C86QE;F1A<@!!9&0@=7-E<@!!9&1E9"`B)7,B(&%S(&%N
M(&%T=&%C:&UE;G0N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O
M=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S
M+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1I=&EO;F%L(&AE861E
M<G,@=&\@9&ES<&QA>2!W:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N
M=&5R(&5A8V@@:&5A9&5R(&]N(&$@;F5W(&QI;F4I/"]E;3X`061D:71I;VYA
M;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+@!!9&1I=&EO;F%L(&EN
M9F]R;6%T:6]N(&1E=&%I;',`061D:71I;VYA;"!M97-S86=E(&1E=&%I;',`
M061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`
M061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',`061D:71I;VYA;"!M
M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RX`061D<F5S
M<P!!9&1R97-S($)O;VL`061D<F5S<R!";V]K<P!!9&1R97-S97,@=&\@0D-#
M(&%L;"!M97-S86=E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R
M97-S(&]N(&$@;F5W(&QI;F4I/"]E;3X`061D<F5S<V5S('1O(&5X<&QI8VET
M;'D@=&EE('1O('1H:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R
M(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^`$%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T
M:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI
M9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL
M($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL(&UE
M<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W
M;FQO861E9"!I;G1O(&]N92!-0D]8(&9I;&4Z`$%L;"!M97-S86=E<R!I;B!Y
M;W5R("(E<R(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E
M<FUA;F5N=&QY(&1E;&5T960N`$%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S
M(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"X`06QL
M(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L
M9"!W:6QL(&)E(&1E;&5T960N`$%L;"!R:6=H=',@;VX@9F]L9&5R("(E<R(@
M<W5C8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@(B5S(BX`06QL;W<@1F]L
M9&5R($-R96%T:6]N/P!!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE
M9"!I;B!A;GD@;6%I;&)O>#\`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L
M;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI
M<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%L
M=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ`$%L=V%Y<P!!;'=A
M>7,@<V%V92!A='1A8VAM96YT<P!!;65R:6-A;B!386UO80!!;B!E<G)O<B!O
M8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE
M;G0N(%1H92!)34%0('-E<G9E<B!S86ED.B``06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!
M;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE
M=R!N;W1E+@!!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I
M;F<@=&AE(&YE=R!T87-K+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N
M>6UO=7,@4')O>'D`06YS=V5R`$%N<W=E<F5D`$%N<W=E<F5D(&UE<W-A9V5S
M`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!
M<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!&
M:6QT97)S`$%P<&QY($9I;'1E<G,@=&\@)7,`07!P;'D@9FEL=&5R(')U;&5S
M('5P;VX@;&]G9VEN9R!O;C\`07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R
M($E.0D]8(&ES(&1I<W!L87EE9#\`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P
M<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M
M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!6:7)T=6%L($9O;&1E<B!$
M969I;FET:6]N/P!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H
M:7,@<'5B;&EC(&ME>3\`07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T
M92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/P!!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E
M('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$52
M34%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E
M<C\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@
M9F]L9&5R/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@
M9&5L971E('1H97-E(&UE<W-A9V5S/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\`07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\`
M07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)R:79A
M;"!4:6UE`$%R=`!!<G5B80!!<V-E;F1I;F<`07-C96YS:6]N($ES;&%N9`!!
M<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL`07-K(&9O<B!C;VYF
M:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_
M`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8V@@1FEL97,`071T86-H(&$@8V]P
M>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\`071T
M86-H960@1FEL93H`071T86-H960@9FEL92`B)7,B(&5X8V5E9',@=&AE(&%T
M=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+@!!='1A
M8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N
M="X`071T86-H;65N=`!!='1A8VAM96YT("5S(&1E;&5T960N`$%T=&%C:&UE
M;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP90!!='1A8VAM
M96YT<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD965S
M`$%T=&5N=&EO;@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I
M80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L
M92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!2
M96UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE
M('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U
M:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT
M:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N
M(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@
M4TU"('-E<G9E<B!F86EL960N`$%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@
M:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@861D
M<F5S<V)O;VL_`$%V86EL86)L92!!9&1R97-S(&)O;VMS.@!!=F%I;&%B;&4@
M9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!!>F5R8F%I:F%N`$)A8U]K('1O
M("5S`$)A8VL@=&\@)7,`0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@
M26YD97@`0F%C:R!T;R!4:')E860@1&ES<&QA>0!"86-K9W)O=6YD`$)A8VMG
M<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R
M;W,@=7-E<FYA;64N`$)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R
M(%)E<W!O;F1E9#H@)7,`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X
M-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)C8P!"96QA<G5S`$)E
M;&=I=6T`0F5L:7IE`$)E;&]W(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A
M='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N`$)E;FEN`$)E<FUU9&$`0FAU=&%N
M`$)I<G1H9&%Y`$)L86-K;&ES=`!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N
M("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)L
M;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S
M<&5C:69I8V%L;'D@<F5Q=65S=&5D/P!";V1Y`$)O;&0`0F]L:79I80!";V]K
M;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA
M(&%N9"!(97)Z96=O=FEN80!";W1H`$)O=&@@2&5A9&5R($QI<W1I;F<@86YD
M($)O9'D@;V8@365S<V%G90!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N
M9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE
M:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&
M87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#
M7V5L;"!0<F]P97)T:65S+BXN`$-?:&%R<V5T`$-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`
M0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N`$-A
M;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B``0V%N
M(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O9B!T
M:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@;6%I;&)O>"X`0V%N(&YO="!R
M97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E
M<R(N`$-A;F%D80!#86YC96P`0V%N8V5L($UE<W-A9V4`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N
M96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N`$-A;FYO="!D96QE=&4@9FEL
M92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@
M3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-C`$-E;&P@4&AO;F4`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A
M8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE
M<@!#97)T:69I8V%T92!0;VQI8VEE<P!#97)T:69I8V%T92!I;7!O<G0@:7,@
M;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@
M=&AI<R!S97)V97(N`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@
M06QL`$-H86YG92!&;VQD97(`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E
M(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO
M=2!S964@;VX@96%C:"!P86=E(&%N9"!H;W<@;65S<V%G97,@87)E('-O<G1E
M9"X`0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N`$-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9V4@
M=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL+@!#
M:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N`$-H87(`0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.@!#:&5C7VL@
M3&EN:RXN+@!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL`$-H96-K(%]!
M;&PO3F]N90!#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E
M=&-H(&UA:6P@9G)O;3H`0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@
M82!M97-S86=E/P!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%C=&EO
M;CH`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!M86EL('-E<G9E<CH`
M0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@<FEG
M:'0Z`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H;V]S92!T:&4@861D<F5S<R!B;V]K
M('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N`$-H;V]S92!T:&4@;W)D
M97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@
M861D<F5S<V5S+@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L
M96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R
M('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K("5S('1O(&-O;G9E<G0@
M=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N
M('9I97<N`$-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92X`0VQI8VL@
M)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+@!#;&EC:R`E<R!T;R!V
M:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@
M)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+@!#;&EC:R`E
M<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W
M+@!#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R
M="!I;B!A('-E<&%R871E('=I;F1O=RX`0VQI8VL@:&5R92!T;R!32$]7('1H
M92!);6%G97,`0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T960@861D<F5S
M<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T;R!S96%R8V@N
M`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+
M97D@:6X@>6]U<B!!9&1R97-S(&)O;VL`0VQI8VL@=&\@4V%V92!3+TU)344@
M8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O;VL`0VQI8VMA
M=&5L;"!V:6$@2%144`!#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O
M;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R`$-L:6-K:6YG(&]N
M('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D
M`$-L;W-E`$-L;W-E(%=I;F1O=P!#;&]S92!T:&ES('=I;F1O=P!#;&]S960@
M1F]L9&5R`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L
M:6YG*2!)<VQA;F1S`$-O;&QA<'-E`$-O;&QA<'-E($%L;`!#;VQL87!S92!!
M;&P@1F]L9&5R<P!#;VQL87!S92!&;VQD97(`0V]L;&%P<V4@4VED96)A<@!#
M;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!);F1I8V%T
M;W(Z(`!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU
M;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N
M=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&QE=&5D`$-O;7!O
M<V4@86YO=&AE<B!M97-S86=E`$-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A
M<F%T92!W:6YD;W<_`$-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=5
M22!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92!F96%T=7)E
M*3\`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H
M(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FEG=7)E(&AO=R!M
M97-S86=E<R!A<F4@9&ES<&QA>65D+@!#;VYF:6=U<F4@;6%I;"!P<F5V:65W
M(&]P=&EO;G,N`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&1R;W!P960@
M8GD@24U!4"!S97)V97(N`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N
M(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D`$-O;G1A
M8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE
M.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;VYT<F]L(%!'4"!S=7!P
M;W)T(&9O<B`E<RX`0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N`$-O
M;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N
M`$-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A
M;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2!W:&5N(&ET(&%R<FEV
M97,N`$-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@
M;VYE<S\`0V]O:R!)<VQA;F1S`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@
M<V5L96-T:6]N`$-O<'D@=&\@9F]L9&5R`$-O<G)E8W0`0V]R<F5C=&5D(%1E
M>'0`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!B:6YD
M('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#
M;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S="X@4F5A<V]N($=I=F5N.B`E<P!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N
M;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!C<F5A=&4@
M=&AE(%9&4R!B86-K96YD.B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E
M<RX@5&AE('-E<G9E<B!S86ED.B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P
M('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@97AE8W5T
M92!M86EN=&5N86YC92!O<&5R871I;VYS+@!#;W5L9"!N;W0@97AT<F%C="!T
M:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT
M+@!#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T
M:&4@6FEP(&%R8VAI=F4N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R
M97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N
M("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(&]P96X@<V5C=7)E(&-O
M;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R+B`E<R`Z("5S+@!#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`
M0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E
M9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O
M<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V
M92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R;VT@24U!4"!S97)V
M97(N`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD
M:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T
M('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H
M97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A
M8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E
M<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@
M9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B
M87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T
M97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E($9O;&1E<@!#<F5A
M=&4@2V5Y<P!#<F5A=&4@5FER='5A;"!&;VQD97(`0W)E871E(&$@3F5W($%C
M8V]U;G0`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@4W!A;2!F;VQD97(`
M0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(`0W)E871E(&$@;F5W(&]N90!#
M<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<@!#<F5A=&4@82!N97<@=')A
M<V@@9F]L9&5R`$-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@
M>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@86YD
M(&1E;&5T92!S<&%M+@!#<F5A=&4@;F5W('-T871I;VYE<GD`0W)E871E('-T
M871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+@!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O
M871I80!#=6)A`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E
M;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E
M;G0@86-C97-S('1O("5S`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S
M='EL90!#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O
M;2!O=&AE<B!A8V-O=6YT<RX`0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL
M+@!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U
M=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!$86EL>0!$871?90!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO
M;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E
M7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L:6YE
M9`!$96-L:6YE9#H@`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-E87)C:"!&:65L9`!$
M969A=6QT(%-H96QL`$1E9F%U;'0@<V]R=&EN9R!C<FET97)I83H`1&5F875L
M="!S;W)T:6YG(&1I<F5C=&EO;CH`1&5F:6YI=&EO;G,`1&5L96=A=&5D`$1E
M;&5T90!$96QE=&4@)7,@4'5B;&EC($ME>0!$96QE=&4@0V5L;`!$96QE=&4@
M0W5R<F5N="!+97ES`$1E;&5T92!&;VQD97(H<RD`1&5L971E($=R;W5P`$1E
M;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(%-E;&5C=&5D($9O
M;&1E<G,`1&5L971E(%-T871I;VYE<GD`1&5L971E(%9I<G1U86P@1F]L9&5R
M`$1E;&5T92!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E<P!$96QE
M=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU
M;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@
M9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_`$1E;&5T92!F
M<F]M(&UY(&-A;&5N9&%R`$1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S
M(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\`1&5L971E(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_`$1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y`$1E;&5T92!S<&%M(&UE<W-A9V5S`$1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D
M`$1E;&5T960@;65S<V%G97,`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="`B)7,B+@!$96QE=&5D('1H92!A='1A8VAM96YT("(E<R(N`$1E;&5T:6YG
M(&%N9"!-;W9I;F<@365S<V%G97,`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;@!$97-C96YD:6YG`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T
M:6]N`$1E=&%I;',`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:60@;F]T(&%T=&%C:"`B)7,B(&%S('1H
M92!F:6QE('=A<R!E;7!T>2X`1&EM('-I9VYA='5R97,_`$1I<F5C=&EO;B!L
M969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R
M>0!$:7-P;&%Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I
M;VYS`$1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S
M86=E/P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A
M<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&QA>2!I;B!";V1Y(&]F($UE
M<W-A9V4`1&ES<&QA>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL
M/P!$:7-P;&%Y('1H92`B16UP='D@4W!A;2(@;&EN:R!I;B!T:&4@;65N=6)A
M<C\`1&ES<&QA>2!T:&4@(D5M<'1Y(%1R87-H(B!L:6YK(&EN('1H92!M96YU
M8F%R/P!$:7-P;W-I=&EO;@!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II
M8F]U=&D`1&\@3D]4(&UA=&-H`$1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R
M($YE=R!-86EL`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'``1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T
M:&4@1G)O;3H@8V]L=6UN`$1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD
M97(_`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N
M(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]N
M90!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"`E<R!I;B`N>FEP($9O
M<FUA=`!$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92D`
M1&]W;FQO860@1F]L9&5R*',I`$1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F
M;W)M871=`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N`$1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T`$1R869T`$1R869T
M(&9O;&1E<@!$<F%F=',@9F]L9&5R.@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%
M+4UA:6P`12UM86EL($%D9')E<W,`14Y$`$524@!%4E)/4CH@66]U<B!M97-S
M86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N`$5C=6%D;W(`161I=`!%9&ET
M($)L86-K;&ES=`!%9&ET($)L;V-K`$5D:70@1FEL=&5R<P!%9&ET($=R;W5P
M`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S`$5D:70@5FER='5A;"!&;VQD97(`161I="!6:7)T=6%L
M($9O;&1E<B!$969I;FET:6]N(&9O<B`E<P!%9&ET(%=H:71E;&ES=`!%9&ET
M(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@>6]U<B!B;&%C:VQI<W0`161I="!Y
M;W5R(&9I;'1E<B!R=6QE<P!%9&ET('EO=7(@<')E9F5R96YC97,@9F]R(&%C
M8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+@!%9&ET('EO=7(@=VAI=&5L
M:7-T`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M
M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y
M`$5M;W1I8V]N<P!%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+@!%;7!T
M>2!&;VQD97(H<RD`16UP='D@4V5L96-T960@1F]L9&5R<P!%;7!T>2!4<F%S
M:"!F;VQD97(`16UP='D@7U-P86T`16UP='D@7U1R87-H`$5M<'1Y(&UE<W-A
M9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!0
M1U`@9G5N8W1I;VYA;&ET>3\`16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y
M/P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/P!%;F%B;&4@;65S<V%G92!P<F5V:65W<S\`16YA8FQE
M(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YC<E]Y<'1I;VX@3W!T:6]N
M<P!%;F-R>7!T960`16YD`$5N9"!F;W)W87)D960@;65S<V%G90!%;F0@;65S
M<V%G90!%;F0@;65S<V%G92!F<F]M("5S`$5N9"!Y96%R`$5N;&%R9V4@161I
M=&]R`$5N=&5R(%!A<W-P:')A<V4`16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(`16YT97(@=&AE(&YA;64@
M9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R
M('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(`16YT97(@=&AE(&YA;64@9F]R
M('EO=7(@;F5W('1R87-H(&9O;&1E<@!%;G1I<F4@365S<V%G90!%;G1R>2`B
M)7,B('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O
M:P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-O;FYE
M8W1I;F<@=&\@24U!4"!S97)V97(N("5S(#H@)7,N`$5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N
M=#H@)7,`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<P!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H
M:6]P:6$`171H;FEC`$5U<F]P90!%=F5N="!S=6-C97-S9G5L;'D@9&5L971E
M9"X`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@
M<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L
M9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%
M>'!A;F0`17AP86YD($%L;`!%>'!A;F0@06QL($9O;&1E<G,`17AP86YD($9O
M;&1E<@!%>'!A;F0@3F%M97,`17AP86YD(%-I9&5B87(`17AP86YD(&YA;65S
M(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H92!B
M86-K9W)O=6YD/P!%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D
M969A=6QT(&EN('1H92!F;VQD97)S('9I97<_`$5X<&%N9&EN9P!%>'!E8W1E
M9"`G*2<`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U
M<&QO860@;V8@<V5T=7``1E]E=&-H($UA:6P`1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@
M8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO
M=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R
M<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME
M.B``1F5T8V@@36%I;`!&971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W
M/P!&971C:"!M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_`$9E=&-H960@)60@
M;65S<V%G97,@9G)O;2`E<P!&971C:&5D(#$@;65S<V%G92!F<F]M("5S`$9E
M=&-H;6%I;#H@`$9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+@!&97<@4VAO
M=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I7VQT97)S`$9I96QD(&UA=')I>`!&
M:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I
M;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97(@
M3W!T:6]N<P!&:6QT97(@4V5T=&EN9W,`1FEL=&5R(&UE<W-A9V4@8V]N=&5N
M="!F;W(@<')O9F%N:71Y/P!&:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O
M;B!T:&ES('-Y<W1E;2X`1FEL=&5R<P!&:6QT97)S($Y/5"!!8W1I=F4`1FEL
M=&5R<SH@)7,@;6%N86=E;65N="!P86=E`$9I;F0`1FEN;&%N9`!&:7)S="!(
M86QF`$9I<G-T($UA:6QB;W@@4&%G90!&:7)S="!086=E`$9I<G-T(%%U87)T
M97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]?<G=A<F0`1F]G`$9O;&1E<B`E
M<R!D;V5S(&YO="!E>&ES=`!&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO
M;@!&;VQD97(@3F%V:6=A=&]R`$9O;&1E<B!3=6UM87)Y`$9O;&1E<B!S:&%R
M:6YG(&ES(&YO="!E;F%B;&5D+@!&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D
M+@!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@
M:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;6%T
M(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S
M<V%G97,@9&%T960@=&]D87D`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`
M1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9`!&;W)W87)D.@!&
M;W)W87)D960@;65S<V%G90!&;W)W87)D960@;65S<V%G92!F<F]M("5S`$9O
M<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`
M1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&<F5N
M8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]?
M;0!&<F]M`$9R;VT@061D<F5S<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO
M;@!&=6QL($UO;VX`1G5L;"!.86UE`$9W9#H`1G=D.B``1G=D.B`E=2!&;W)W
M87)D960@365S<V%G97,`1V%B;VX`1V%L;&5R>3H`1V%M8FEA`$=E;F5R86P@
M3W!T:6]N<P!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#
M;V1E`$=E;W)G:6$`1V5R;6%N>0!'970@;VYL>2!N97<@;65S<V%G97,_("A)
M34%0(&]N;'DI`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O('1O
M($UE<W-A9V4`1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F("(E<R(`1V]E
M9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A;G0@86-C97-S`$=R
M87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'
M<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'
M=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K
M`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(15)%`$A434P`2%1-3"!6
M97)S:6]N(&]F($UE<W-A9V4`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O
M<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I
M;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93H`2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R
M92!C;VUP;W-I;F<Z`$AI9&1E;@!(:61D96X@:6X@5&AR96%D(%9I97<`2&ED
M92!$96QE=&5D`$AI9&4@56YS=6)S8W)I8F5D`$AI9V@`2&EG:"!0<FEO<FET
M>0!(:6=H97-T`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I
M`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`
M2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B
M)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO
M;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`
M2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@=&\@871T<FEB=71E('%U;W1E
M9"!L:6YE<R!I;B!A(')E<&QY`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I
M<W1S`$AU;F=A<GD`24U!4`!)34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I
M`$E-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E
M<W!O;F1E9#H@)7,`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!O=F5R(%-33`!)34%0
M(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92D`24U!4"!O=F5R
M(%-33"`H<V5L9BUS:6=N960I`$E-05`@<V5R=F5R(&-L;W-E9"!T:&4@8V]N
M;F5C=&EO;BX`24U!4"P@;F\@5$Q3`$E-05`O4$]0,R!-86EL(%-E<G9E<G,`
M24Y"3U@`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E?;G-E
M<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S
M`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO
M="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W
M('=I;F1O=RX`268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V92!T
M:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"X`268@>6]U(&-O;G1I
M;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E(&QO
M<W0A`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T
M($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@
M='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EG;F]R
M90!)9VYO<F4@06QL`$EM86=E`$EM86=E(%!R979I97<Z`$EM86=E(%523`!)
M;6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE
M<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T`$EM<&]R="!+97D`26UP
M;W)T($ME>7!A:7(`26UP;W)T($UE<W-A9V5S`$EM<&]R="!01U`@2V5Y`$EM
M<&]R="!097)S;VYA;"!#97)T:69I8V%T90!);7!O<G0@4&5R<V]N86P@4')I
M=F%T92!01U`@2V5Y`$EM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>0!)
M;7!O<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<P!);7!O<G0@4'5B
M;&EC($ME>0!);7!O<G0@4'5B;&EC(%!'4"!+97D`26UP;W)T(%!U8FQI8R!3
M+TU)344@2V5Y`$EM<&]R="!3+TU)344@2V5Y`$EM<&]R="!M8F]X($9I;&4`
M26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RX`26UP;W)T+"!3
M=&5P("5D`$EM<&]R=&%N=`!);7!O<G1A;G0@;65S<V%G97,`26UP;W)T960@
M)60@;65S<V%G97,@9G)O;2`E<RX`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R
M=&5D(&9I96QD<SH`26X@4')O8V5S<P!);E]S97)T(%)O=R!!9G1E<@!);F)O
M>`!);F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@
M<F5P;'D_`$EN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/P!)
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@
M26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`
M26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`
M26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>0!);F9O<FUA=&EO;B!O;B!0
M97)S;VYA;"!0<FEV871E($ME>0!);F9O<FUA=&EO;B!O;B!097)S;VYA;"!0
M=6)L:6,@2V5Y`$EN;&EN90!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M0V5R=&EF:6-A=&4@2&5R90!);G-E<G0@26UA9V4`26YS97)T(%!E<G-O;F%L
M(%!R:79A=&4@4$=0($ME>2!(97)E`$EN<V5R="!097)S;VYA;"!0=6)L:6,@
M4$=0($ME>2!(97)E`$EN<V5R="!0=6)L:6,@4$=0($ME>2!(97)E`$EN<V5R
M="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E
M`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R
M`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R
M="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R
M87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@
M869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y
M($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE
M;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED($%C=&EO
M;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN=F%L:60@061D<F5S
M<P!);G9A;&ED(%)E;6]T92!-86EL8F]X`$EN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!C:&%R86-T97(@:6X@
M92UM86EL(&%D9')E<W,Z("5S+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!)
M;G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M
M870`26YV86QI9"!K97D`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L
M;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O
M<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE
M<B!I9"X`26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN`$EN=F%L
M:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN`$EN=F%L:60@<')O9'5C="!C
M;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S
M(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R=`!);G9E
M<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)
M<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)
M<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A
M;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU
M<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F
M=`!*=7-T:69Y(%)I9VAT`$M"`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`
M2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT
M`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2V5Y(&=E;F5R871I;VX@
M;6%Y('1A:V4@82!L;VYG('1I;64@=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W
M:71H(&ME>2!G96YE<F%T:6]N/P!+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B
M;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R
M+@!+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H879E(&YO(&%D
M9')E<W,@8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R(&-O;G1A8W1S+@!+97D@
M<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$MI
M9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A
M:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$
M96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T($UA:6QB;W@@4&%G
M90!,87-T(%!A9V4`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R
M`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,
M96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,
M:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,
M:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H
M="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC
M:P!,:6YK`$QI;FL@071T86-H;65N=',_`$QI;FL@<&]I;G1S('1O.@!,:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG`$QI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+@!,
M:6YK<P!,:6YK<R!W:6QL(&5X<&ER92!O;B`E<P!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@
M=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"!O
M;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET
M;'DI`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R
M`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI
M<W1I;F<@:6X@=&AE($AE861E<@!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C
M86P@36%I;&)O>#H`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A
M=&EO;@!,;V<@:6X`3&]G(&EN('1O("5S`$QO9R!O=70`3&]G:6X`3&]G:6X@
M5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D
M+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W(%!R:6]R:71Y`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QO=V5S=`!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA8VEN=&]S:"!&:6QE
M`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:6P@4')E=FEE
M=W,`36%I;"!S97)V97(@='EP92!T;R!C;VYN96-T('1O.@!-86EL8F]X`$UA
M:6QB;W@@86YD($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,`36%K92!L:6Y?:RXN
M+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-
M87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;@!-87)K($%L;"!-
M97-S86=E<R!I;B!&;VQD97(@87,@56YS965N`$UA<FL@87,Z`$UA<FL@9&EF
M9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R
M<S\`36%R:R!M97-S86=E<R!A<R!S965N/R`H24U!4"!O;FQY*0!-87)K('-I
M;7!L92!M87)K=7`_`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-
M87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8V@@06QL(%%U97)I97,`
M36%T8V@@06YY(%%U97)Y`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA
M=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@
M;&%S="`V(&AO=7)S.B``36%X:6UU;2!!='1A8VAM96YT(%-I>F4`36%X:6UU
M;2!.=6UB97(@;V8@1F]L9&5R<P!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@
M0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>&EM=6T@;G5M8F5R(&]F(&%T=&%C
M:&UE;G1S(')E86-H960N`$UA>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE
M(')E86-H960N`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!&
M;VQD97(@3&ES=`!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S
M<V%G92!#;VUP;W-I=&EO;@!-97-S86=E($1A=&4`365S<V%G92!/<'1I;VYS
M`$UE<W-A9V4@4V5A<F-H`$UE<W-A9V4@4VEZ90!-97-S86=E(%-O=7)C90!-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!6
M:65W:6YG`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!F;&%G<P!-97-S86=E
M(&9O;&1E<G,`365S<V%G92!F<F]M("5S`$UE<W-A9V4@:&%S(&%T=&%C:&UE
M;G1S`$UE<W-A9V4@:7,@96YC<GEP=&5D`$UE<W-A9V4@:7,@<VEG;F5D`$UE
M<W-A9V4@;6%T8VAE<P!-97-S86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY
M+@!-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O
M("5S`$UE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN`$UE<W-A9V4@='EP90!-
M97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W+@!-97-S86=E
M<R!T;P!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE
M=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E
M9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI
M<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC
M871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!0
M14%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I
M;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>0!-;V1I9GD@
M55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O
M;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H
M87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X
M<&5C=&5D("5D+@!-;W)E('1H86X@;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I
M96QD("(E<R(N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`
M36]S=&QY(%-U;FYY`$UO=F4`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I
M9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@<W!A;2!M97-S86=E<R!T;R!S
M<&%M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@24Y"3U@`36]V
M92!T;R!F;VQD97(`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:7!A<G0O86QT97)N871I=F4`375L=&EP;&4@
M365S<V%G92!6:65W`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY
M($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO
M=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3D].10!.3U1%`$YA;64`
M3F%M92!A;F0O;W(@96UA:6P@8V%N;F]T(&)E(&5M<'1Y`$YA;6EB:6$`3F%U
M<G4`3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S
M($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C
M871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N
M97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=F5R('-A
M=F4@871T86-H;65N=',`3F5W`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y
M`$YE=R!&;VQD97(`3F5W($UA:6P`3F5W($UE<W-A9V4`3F5W($UE<W-A9V4@
M=&\@)7,`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE
M86QA;F0`3F5W(&UE<W-A9V5S`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@
M=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X
M="!-97-S86=E`$YE>'0@4&%G90!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A
M9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!#97)T:69I8V%T
M92!F;W5N9`!.;R!%;F-R>7!T:6]N`$YO($ME>7,@:6X@2V5Y<FEN9P!.;R!-
M97-S86=E<P!.;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"X`3F\@4&5R<V]N
M86P@0V5R=&EF:6-A=&4@4')E<V5N=`!.;R!0<F5V:65W(%1E>'0`3F\@4'5B
M;&EC($ME>7,@1F]U;F0`3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N
M`$YO(&%T=&%C:&UE;G1S(&9O=6YD+@!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T
M96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+@!.;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@
M:V5Y+@!.;R!F:6QE('5P;&]A9&5D`$YO(&9O;&1E<B!S96QE8W1E9"X`3F\@
M9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN`$YO(&9O
M;&1E<G,@=V5R92!S<&5C:69I960`3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S
M86=E<P!.;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S`$YO(&EC;VYS
M(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I
M9&5D+@!.;R!M97-S86=E(&)O9'D@=&5X=`!.;R!M97-S86=E('-U<'!L:65D
M+@!.;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H+@!.;R!N86UE('-P
M96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!P97)S;VYA;"!01U`@<')I
M=F%T92!K97D@:6UP;W)T960N`$YO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y
M(&EM<&]R=&5D+@!.;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM
M<&]R=&5D+@!.;R!P97)S;VYA;"!P<FEV871E(&ME>2!E>&ES=',@<V\@=&AE
M(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"X`3F\@<75O=&$@
M<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E
M<P!.;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"X`3F\@<W!E
M;&QI;F<@97)R;W)S`$YO('-U8V@@9FEL90!.;R!S=6=G97-T:6]N<P!.;R!S
M=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@
M9F]U;F0N`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C
M86-H92X`3F\@=7-E<B!S<&5C:69I960N`$YO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V
M86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO;B!087)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I
M="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R;6%L
M`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S
M`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@1&5L971E9`!.;W0@
M1')A9G0`3F]T($EM<&]R=&%N=`!.;W0@4&5R<V]N86P`3F]T(&$@9&ER96-T
M;W)Y`$YO="!A('9A;&ED('!U8FQI8R!K97DN`$YO="!D96QE=&5D(&UE<W-A
M9V5S`$YO="!I;7!L96UE;G1E9"X`3F]T(&EM<&]R=&%N="!M97-S86=E<P!.
M;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&4@=&AA="!T:&ES(&-A;B!T86ME
M('-O;64@=&EM90!.;W1E<P!.;W1H:6YG`$YO=&AI;F<@=&\@8G)O=W-E+"!G
M;R!B86-K+@!.;W1I9FEC871I;VXZ($QI;FME9"!A='1A8VAM96YT(&1O=VYL
M;V%D960`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@
M;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN`$YU;6)E
M<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN
M9R!M;VYT:&QY+@!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/4@!/
M8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9I8V4`3VQD
M(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@;65S
M<V%G97,`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="X`3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"X`3VUA;@!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&1I<W!L87D@9F]L9&5R<R!W:71H('5N<F5A9"!M97-S86=E<R!I;B!T:&5M
M/P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@;VYE(&9O
M;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+@!/;FQY
M('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E
M(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/
M<&5N($9O7VQD97(`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="X`3W!E;F5D($9O;&1E<@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T
M:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]T:&5R($UA:6P@06-C;W5N=',`
M3W1H97(@3W!T:6]N<P!/=71B;W5N9"!397)V97(`3W=N97(@4&5R;6ES<VEO
M;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z
M.DUA:6P@8F%C:V5N9`!01U``4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%
M;F-R>7!T($UE<W-A9V4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!%<G)O<CH@
M`%!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV
M871E(&ME>2X`4$=0($]P=&EO;G,`4$=0(%!A<W-P:')A<V4@26YP=70`4$=0
M(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`4$=0(%!U8FQI8R!+97D`4$=0(%!U8FQI8R!+97D@
M5&5X=`!01U`@4'5B;&EC($ME>2!F;W(@(B5S("@E<RDB('=A<R!S=6-C97-S
M9G5L;'D@861D960N`%!'4"!0=6)L:6,@2V5Y(&9O<B`B)7,B('=A<R!S=6-C
M97-S9G5L;'D@9&5L971E9"X`4$=0(%!U8FQI8R!+97ER:6YG`%!'4"!3:6=N
M($UE<W-A9V4`4$=0(%-I9VXO16YC<GEP="!-97-S86=E`%!'4"!3:6=N960O
M16YC<GEP=&5D($1A=&$`4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A
M9&1E9"X`4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+@!01U`@
M<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2X`4$=0('-U<'!O
M<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG
M;F%T=7)E(&ES('5N86)L92!T;R!B92!V97)I9FEE9"X`4$=0('-U<'!O<G0@
M:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA
M8FQE('1O(&)E(&1E8W)Y<'1E9"X`4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P
M=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U
M<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S
M="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"!F96%T=7)E
M<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`4$A0($-O9&4`4$A0(%-H96QL
M`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO
M=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]0,P!03U`S("A!=71O($1E=&5C
M="!0<F]T;V-O;',I`%!/4#,@;W9E<B!34TP`4$]0,R!O=F5R(%-33"`H<V5L
M9BUS:6=N960@8V5R=&EF:6-A=&4I`%!/4#,@;W9E<B!34TP@*'-E;&8M<VEG
M;F5D*0!03U`S+"!N;R!43%,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`
M4%](4"!3:&5L;`!0861D:6YG`%!A9V4@)60@;V8@)60`4&%G92!W:71H('1H
M92!&:7)S="!5;G-E96X@365S<V%G90!086=E('=I=&@@=&AE($QA<W0@56YS
M965N($UE<W-A9V4`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T*',I`%!A<G1L>2!#;&]U9'D`4&%S<W!H<F%S90!087-S<&AR87-E
M("A!9V%I;BD`4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@=6YL;V%D960N`%!A
M<W-P:')A<V4Z`%!A<W-P:')A<V5S(&-A;FYO="!B92!E;7!T>0!087-S<&AR
M87-E<R!D;R!N;W0@;6%T8V@`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S
M=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U
M:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@
M;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0
M96YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D
M96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R
M(&-A;FYO="!B92!C:&%N9V5D+@!097)S;VYA;`!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2X`
M4&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z(`!0
M97)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2X`4&5R
M=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE
M;',`4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O
M<G=A<F1S/P!0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E`%!L87D@<V]U
M;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T
M;R!S=7!P;W)T(&5M8F5D9&5D('-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D
M;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL
M;"!R97%U:7)E(&$@<&QU9VEN+@!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E
M;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.@!0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@96YT
M97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z`%!L96%S92!E;G1E<B!T
M:&4@;F5W(&YA;64Z`%!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@
M>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R!E
M;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BX`4&QE
M87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV
M871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O(&5N=&5R('1H:7,@<&%S
M<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+@!0;&5A<V4@;&]G(&EN(&%G
M86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@
M87)E($Y/5"!U<VEN9R!C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M
M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O(&QO
M9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@
M:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2!H:6IA8VMI;F<@>6]U<B!S97-S
M:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E+@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@<&%S<W=O<F0N`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64N`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L
M96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RX`
M4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY
M(&%C=&EO;G,N`%!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T
M;R!S96%R8V@N`%!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T
M:&ES(&]P97)A=&EO;BX`4&QE87-E('-E;&5C="!O<B!E9&ET(&EN('1H92!B
M;W@@=&\@=&AE(')I9VAT.@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!O
M=V5R960@8GD@2&]R9&4`4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A
M<VAE<R`H)RTM("<I/P!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969E<F5N8V5S('-U
M8V-E<W-F=6QL>2!U<&1A=&5D+@!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D
M('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U
M<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!-97-S86=E`%!R
M979I;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0<FEN=`!0<FEN="!D;V-U
M;65N=`!0<FEO<FET>0!0<FEV871E($ME>0!0<FEV871E($ME>2!087-S=V]R
M9`!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T
M(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O
M($Y/`%!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@
M9&5F875L="!T;R!915,`4')O;7!T('1E>'0`4')O=&]C;VPZ`%!U8FQI8R!+
M97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI
M8R!01U`@:V5Y<V5R=F5R('-U<'!O<G0@:&%S(&)E96X@9&ES86)L960N`%!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN`%!U97)T;R!2:6-O`%!U<E]G92!$96QE=&5D`%!U<F=E($1E;&5T960`
M4'5R9V4@1F]L9&5R*',I`%!U<F=E(%1R87-H(&AO=R!O9G1E;CH`4'5R9V4@
M;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U
M;G0@;V8@9&%Y<RX`4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F
M;VQD97(_`%!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N
M`%!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+@!1871A<@!1
M=65R>0!1=6]T80!1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N
M,F8E)2D`475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5`!1=6]T82!S
M=&%T=7,Z($Y/($Q)34E4`%%U;W1I;F<@)68Z`%)302!0=6)L:6,@2V5Y("@E
M9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,
M871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A
M;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5C96EV960@3VX`4F5C96EV960@
M4VEN8V4`4F5C96EV960@56YT:6P`4F5D:7)E8U]T`%)E9&ER96-T`%)E9&ER
M96-T($UE<W-A9V4`4F5D:7)E8W0@=&AI<R!M97-S86=E`%)E9&ER96-T:6YG
M(&9A:6QE9"X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!&;VQD97(@5FEE
M=W,Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"
M<F]W<V5R`%)E;&]A9`!296QO860@5FEE=P!296UA<FMS`%)E;65M8F5R('1H
M92!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E;65M8F5R('1H92!L87-T('9I
M97<`4F5M;W1E($UA:6QB;W@Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E
M($)L;V-K`%)E;6]V92!&:65L9"!&<F]M(%-E87)C:`!296UO=F4@8V]L=6UN
M`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO
M=F4@<V]U<F-E`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5N86UE
M($9O;&1E<BAS*0!296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI
M;F<@;V8@;6]N=&@_`%)E;F%M:6YG("(E<R(@=&\@(B5S(B!F86EL960N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`4F5P;%]Y('1O($QI<W0`4F5P
M;&%C92!W:71H.@!297!L>0!297!L>2!396YT+@!297!L>2!T;R!!;&P`4F5P
M;'D@=&\@06QL.@!297!L>2!T;R!,:7-T`%)E<&QY('1O($QI<W0Z`%)E<&QY
M('1O(%]!;&P`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P
M;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I
M=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DM5&\`
M4F5P;'DM5&\Z(`!297!L>3H`4F5P;W)T(&%S($EN;F]C96YT`%)E<&]R="!A
M<R!3<&%M`%)E<75E<W0@82!?4F5A9"!296-E:7!T`%)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W0@
M<F5A9"!R96-E:7!T<S\`4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+@!2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"!&:65L9`!297%U:7)E9"!087)T:6-I<&%N=`!297-E=`!2
M97-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W!O;F1E;G0@
M4W1A='5S(%5P9&%T960N`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E
M<W5M90!297-U;64@>6]U<B!S97-S:6]N`%)E='5R;B!T;R`B365S<V%G92!#
M;VUP;W-I=&EO;B(`4F5T=7)N('1O($9E=&-H($UA:6P`4F5T=7)N('1O($]P
M=&EO;G,`4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L
M971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_`%)E='EP92!N
M97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D
M97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N
M:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R
M;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N
M`%)W86YD80!3+TU)344`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M`%,O34E-12!%;F-R>7!T($UE<W-A9V4`4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E`%,O34E-12!%<G)O<CH@`%,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR
M87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2X`4R]-24U%($]P=&EO;G,`
M4R]-24U%(%!A<W-P:')A<V4@26YP=70`4R]-24U%(%!E<G-O;F%L($ME>7!A
M:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`
M4R]-24U%(%!U8FQI8R!+97D@9F]R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+@!3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N
M`%,O34E-12!0=6)L:6,@2V5Y<FEN9P!3+TU)344@4'5B;&EC+U!R:79A=&4@
M2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N`%,O34E-12!3:6=N($UE<W-A
M9V4`4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E`%,O34E-12!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+@!3+TU)344@<W5P<&]R="!I
M<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA
M8FQE('1O(&)E(&1E8W)Y<'1E9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N
M86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@
M8V%N;F]T(&)E(&1I<W!L87EE9"X`4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N
M86)L960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B
M92!V97)I9FEE9"X`4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN
M9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L
M>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N
M9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%,O34E-12!F96%T=7)E<R!W
M:6QL(&YO="!W;W)K(&-O<G)E8W1L>2X`4T%33"!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`
M4U5#0T534P!37U%,(%-H96QL`%-?=6)J96-T`%-A`%-A7W9E(&$@8V]P>2!I
M;B``4V%?=F4@87,`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I
M<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF
M*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E
M;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A
M=F4@)7,`4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM
M86EL(&9O;&1E<C\`4V%V92!$<F%F=`!3879E($EM86=E`%-A=F4@26UA9V4@
M:6X@1V%L;&5R>0!3879E($]P=&EO;G,`4V%V92!3=&%T:6]N97)Y`%-A=F4@
M7T1R869T`%-A=F4@87,`4V%V92!D<F%F=',@87,@=6YS965N/P!3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F4@<F5C:7!I96YT
M<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\`
M4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E<C\`4V%V92!S96YT(&UA
M:6P_`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`B)7,B+@!3879I;F<@=&AE(&1R869T(&9A:6QE9"X@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`4V-A='1E<F5D(%0M
M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"`E<P!396%R8V@@16YG:6YE
M<P!396%R8V@@3W!T:6]N<P!396%R8V@@4F5S=6QT<P!3965N`%-E;&5C=`!3
M96QE8W0@06YO=&AE<B!!8V-O=6YT`%-E;&5C="!&:6QE<P!396QE8W0@82!D
M871E`%-E;&5C="!A(&9I96QD`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE
M8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('-T871I
M;VYE<GDZ`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A9&1R97-S(&)O
M;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E
M<W-E<RX`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`
M4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D
M9')E<W-E<RX`4V5L96-T(&%N(&%C8V]U;G0`4V5L96-T(&%N(&]B:F5C=`!3
M96QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!G
M86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+@!396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!M86EL('-E<G9E
M<B!T>7!E`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE
M8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93H`4V5L96-T960@061D<F5S<R!B;V]K<SH`4V5N9"!+97D@=&\@
M4'5B;&EC($ME>7-E<G9E<@!396YD($QA=&5S="!);F9O<FUA=&EO;@!396YD
M($UE<W-A9V4`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YD(')E
M860@<F5C96EP="!W:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/P!396YE
M9V%L`%-E;G-O<CH@`%-E;G0@;6%I;"!F;VQD97(`4V5N="!M86EL(&9O;&1E
M<CH`4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M
M8F5R`%-E<G9E<@!397)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO;@!397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397)V97(Z`%-E<W-I
M;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T
M(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@
M:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@<')E9F5R96YC97,@9F]R('=H
M870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N
M`%-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S
M<V%G97,_`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAA
M<F4@1F]L9&5R<P!3:&%R92!M86EL(&9O;&1E<G,`4VAA<F4@>6]U<B!M86EL
M(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RX`4VAO<'!I;F<`4VAO<G0@4W5M
M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\`4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S
M:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E('1O9V=L960@
M96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+@!3:&]U;&0@=&AE(&)O9'D@
M;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T
M83\`4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@
M<V%V:6YG(&$@9')A9G0_`%-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O
M(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\`4VAO
M=P!3:&]W($%L;"!&;VQD97)S`%-H;W<@06QL($AE861E<G,`4VAO=R!$96QE
M=&5D`%-H;W<@3&EM:71E9"!(96%D97)S`%-H;W<@36%I;&EN9R!,:7-T($EN
M9F]R;6%T:6]N`%-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,`4VAO=R!5
M;G-U8G-C<FEB960`4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O
M9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/P!3:&]W(&1I9F9E<F5N8V5S
M(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\`4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\`
M4VAO=R!P:6-K97(`4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE<W-A9V5S
M(&]N;'D_`%-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_`%-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\`4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H92!M96YU8F%R
M/P!3:&]W('1H92!);6%G97,`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_`%-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN
M(&9O;&1E<C\`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H
M;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:&]W;@!3:')I
M;FL`4VE?>F4`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA
M='5R92!!;&=O<FET:&T`4VEG;F5D`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I
M;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3
M;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,
M871E`%-N;W<@9&5P=&@Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG
M<R`F(%!O96US`%-O<G0@8GD@07)R:79A;`!3;W)T(&)Y($1A=&4`4V]R="!B
M>2!&<F]M($%D9')E<W,`4V]R="!B>2!-97-S86=E(%-I>F4`4V]R="!B>2!3
M=6)J96-T`%-O<G0@8GD@5&AR96%D`%-O<G0@8GD@5&\@061D<F5S<P!3;W)T
M(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD
M('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE
M<F4`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3
M<&%M`%-P86T@9F]L9&5R.@!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&5C
M:6%L($-H87)A8W1E<G,`4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N;F]T
M(&)E(&5D:71E9"X`4W!E;&P@0VAE8VL`4W!E;&P@0VAE8VME<@!3<&5L;"!C
M:&5C:R!C;VUP;&5T90!3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N
M('-P96QL(&-H96-K:6YG+@!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI
M="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A
M<G0`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T:6]N97)Y`%-T
M871I;VYE<GD@;F%M93H`4W1A=&EO;F5R>2!T>7!E.@!3=&%T:6]N97)Y.@!3
M=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR
M;W5G:`!3=')I;F<@;&ES=`!3=')I<"!!='1A8VAM96YT`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T<FEP(&QI;F5B<F5A:W,_`%-T>6QE(%M#
M4U-=`%-U`%-U8E]J96-T`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M4W5B:F5C=`!3=6)J96-T($9I96QD`%-U8FUI=`!3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C
M<FEB92!T;R!&;VQD97(H<RD`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U
M;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C
M97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3
M=61A;@!3=6=G97-T:6]N<P!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N
M;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U
M;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3
M=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I=&-H
M($-O;7!O<VET:6]N($UE=&AO9`!3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO
M;@!3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;@!3=VET>F5R;&%N
M9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R
M;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`
M5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A
M;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E7WAT`%1E
M;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U
M<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,
M;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T
M92!!9&UI;FES=')A=&EO;@!496YT871I=F4Z(`!496YT871I=F5L>2!!8V-E
M<'0@<F5Q=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497)M<R!O9B!397)V
M:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<`!497AT`%1E>'0@
M3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA
M:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE
M($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D
M.@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@(B5S(@!4:&4@24U!4"!S97)V97(@9&]E<R!N;W0@87!P96%R
M('1O('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!S96QE8W1E
M9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BX`
M5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA
M8VEN=&]S:"!R97-O=7)C92!F;W)K`%1H92!-86-I;G1O<V@@<F5S;W5R8V4@
M9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RX`5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%C8V]U;G0@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@86-C;W5N="`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N`%1H92!A='1A8VAM96YT('=A<R!N;W0@9F]U;F0N
M`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C86QE;F1A<B!D871A(&ES(&EN
M=F%L:60`5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R
M:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O(&)L;V-K('!O<'5P
M('=I;F1O=W,_`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O
M<V@@9FEL92!A<F4@8F5L;W<N`%1H92!C=7)R96YT(&9O;&1E<BAS*2`B)7,B
M('=I;&P@8F4@<F5N86UE9"!T;R`B)7,B+@!4:&4@8W5R<F5N="!L:7-T(&]F
M('5S97)S('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B
M92!R971R:65V960`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!D
M<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@(B5S(B!F;VQD97(N`%1H92!E
M;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN`%1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BX`
M5&AE(&9I96QD("(E<R(@8V%N)W0@8F4@97AP86YD960N`%1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N`%1H92!F;VQD97(@(B5S(B!A;')E861Y(&5X:7-T<P!4:&4@9F]L
M9&5R("(E<R(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N
M86UE+B!)="!M87D@8V%U<V4@<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BX`5&AE(&9O;&1E<B`B)7,B('=A<R!C<F5A
M=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="X`5&AE(&9O
M;&1E<B`B)7,B('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S
M8W)I8F5D(&9R;VT@:70N`%1H92!F;VQD97(@(B5S(B!W87,@;F]T(&-R96%T
M960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE(&9O;&1E<B`B
M)7,B('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9`!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D
M+@!4:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+@!4
M:&4@9F]L9&5R("(E<R(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O("(E
M<R(N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE
M<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F;VQL;W=I;F<@9FEL97,@=V5R
M92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!I;6%G92!S879E('=I;F1O=R!C86X@;F]T
M(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R
M('1O(&)L;V-K('!O<'5P('=I;F1O=W,_`%1H92!I;6%G97,@=VEL;"!B92!D
M:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U
M<B!A9&1R97-S8F]O:RX`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M86EL('-E<G9E<B!G96YE<F%T
M960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.@!4:&4@;6%I;"!S97)V
M97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S
M86=E.@!4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@
M;65S<V%G93H`5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2X`5&AE
M(&UE<W-A9V4@(B5S(B!F<F]M("(E<R(@*"5D(&)Y=&5S*2!E>&-E961S(&9E
M=&-H('-I>F4@;&EM:70N`%1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA
M<R!B965N(&-L;W-E9"X@17AI=&EN9RX`5&AE(&UE<W-A9V4@:&%S(&)E96X@
M9&5L971E9"X`5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N`%1H92!M
M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+@!4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B
M965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@
M;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L
M(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE
M.CH@8VQA<W,N`%1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N
M960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B;&]C
M:R!P;W!U<"!W:6YD;W=S/P!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI
M;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+@!4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y(&-A
M;B!B92!V:65W960@)7,N`%1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E
M>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+@!4:&4@<F5Q=65S=&5D
M(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM96YT+@!4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'D`5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S
M=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(&9R;VT@
M>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S92!C
M;&EC:R`E<R!T;R!S96YD('1H92!N;W1I9FEC871I;VX@;65S<V%G92X`5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C
M<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92X`5&AE('-I9VYA='5R
M92!C;W5L9"!N;W0@8F4@<F5P;&%C960N`%1H92!S:6=N871U<F4@=V%S('-U
M8V-E<W-F=6QL>2!R97!L86-E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N
M;W0@97AI<W0N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4
M:&4@<W1A=&EO;F5R>2`B)7,B(&AA<R!B965N(&%D9&5D+@!4:&4@<W1A=&EO
M;F5R>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S=&%T:6]N97)Y("(E
M<R(@:&%S(&)E96X@=7!D871E9"X`5&AE('1A<VL@:&%S(&)E96X@861D960@
M=&\@>6]U<B!T87-K;&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E
M<R!N;W0@97AI<W0N`%1H92!T97AT(&]F('1H92!M97-S86=E`%1H92!T97AT
M(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT(&]F
M('1H92!R971U<FYE9"!M97-S86=E`%1H92!T97AT(&]F('1H92!R971U<FYE
M9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N`%1H92!T97AT(&]F('1H92!S
M96YT(&UE<W-A9V4`5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92!C86X@
M8F4@=FEE=V5D("5S+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA
M=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D
M871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!U<V5R)W,@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N`%1H
M92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@
M9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@86QT97)N
M871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE
M<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"X`5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY
M(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E
M<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H
M97)E(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M
M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M
M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES
M=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E
M<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM
M=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T
M:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE
M<W-A9V5S(&9R;VT@(B5S(B!T;R`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<R!F<F]M('1H92!F;VQD97(@(B5S(BX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9`!4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@
M:6X@=&AE(&9O;&1E<B`B)7,B+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED`%1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E
M<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R("(E<R(N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@
M>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E
M<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O;2`B)7,B('1O("(E<R(N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60`5&AE<F4@=V%S(&%N(&5R<F]R('!E
M<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!S
M879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N`%1H97)E('=A<R!A;B!E
M<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R
M92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES($A434P@
M;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+@!4:&ES($A434P@
M;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM
M86=E<R!A<'!E87(@;&EK92!T:&ES.B``5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!01U`@4'5B;&EC
M($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N`%1H:7,@86-T:6]N
M(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP
M;&5M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UA
M>2!T86ME('-O;64@=&EM92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O
M;G1I;G5E/P!4:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL
M92X`5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H
M87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N`%1H:7,@;65S
M<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC
M<GEP=&5D('9I82!3+TU)344N`%1H:7,@;65S<V%G92!C;VYT86EN<R!M86EL
M(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M870@
M;V8@=&AI<R!M97-S86=E(&ES('5N:VYO=VXN`%1H:7,@;65S<V%G92!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A
M9V4N($5R<F]R.B``5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!I;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T("AA8V-O<F1I;F<@=&\@4D9#
M(#(P,34I+@!4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN
M('1H92!C;W)R96-T(%,O34E-12!F;W)M870N`%1H:7,@;65S<V%G92!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N`%1H:7,@;65S<V%G92!H
M87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N`%1H:7,@;65S
M<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12X`5&AI<R!M97-S
M86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"X`5&AI<R!M97-S86=E
M('1O`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S
M970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A(&-O;7!O<V4@=VEN
M9&]W+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W`%1H<F5A9"!$:7-P;&%Y`%1H<F5A9"!6:65W`%1H=6YD97(`
M5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S
M96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4
M;P!4;R!!9&1R97-S`%1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@
M8VQI8VMI;F<N`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@
M8VQI8VMI;F<N`%1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B
M92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@-2XP+C8@;W(@:&EG:&5R+@!4
M;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W
M`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1O=&%L($%T=&%C:&UE;G1S
M(%-I>F4Z`%1R87-H(&9O;&1E<@!4<F%S:"!F;VQD97(Z`%1R:6YI9&%D(&%N
M9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K
M:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O
M<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E
M>#H@`%523`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R
M;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET
M:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R971R:65V92!Q=6]T80!5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N86YS=V5R960`
M56YA;G-W97)E9"!M97-S86=E<P!5;F1E;&5T90!5;F1E<FQI;F4`56YD:7-C
M;&]S960@4F5C:7!I96YT<P!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S
M="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@`%5N9FEL960`56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<P!5
M;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N($1A=&4`56YK;F]W
M;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O
M;F1E9#H@)7,`56YK;F]W;B!-965T:6YG`%5N:VYO=VX@4F5C:7!I96YT`%5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R
M;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@
M=&AE(&-U<G)E;G0@96QE;65N=`!5;FQO860@4&%S<W!H<F%S90!5;FYA;65D
M`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO
M4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS965N`%5N<V5T(&-O;&]R`%5N<W5B
M<V-R:6)E(&9R;VT@1F]L9&5R*',I`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5
M<&1A=&4`57!D871E("5S`%5P9&%T92!R97-P;VYD96YT('-T871U<P!5<&1A
M=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA
M;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!$969A=6QT
M(%9A;'5E`%5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/P!5<V4@4U-,
M`%5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\`57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("(E
M<R(@<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O
M<B!T:&4@9F]L9&5R("(E<R(N`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@
M9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R
M(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S
M97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE
M.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`
M5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M
M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M
M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T
M:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE
M=&YA;65S92`H5DE30TE)*0!6:65W`%9I97<@)7,`5FEE=R`E<R!0=6)L:6,@
M2V5Y`%9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W`%9I
M97<@365S<V%G97,`5FEE=R!097)S;VYA;"!0<FEV871E($ME>0!6:65W(%!E
M<G-O;F%L(%!U8FQI8R!+97D`5FEE=R!4:')E860`5FEE=R!4:'5M8FYA:6P`
M5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I97<@871T
M86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=P!6:65W(&-O;G1E;G0@:6X@
M82!S97!A<F%T92!W:6YD;W<`5FEE=R!E=F5N=`!6:65W(&UE<W-A9V5S(&EN
M("5S`%9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.@!6
M:65W('1A<VL`5FEE=R!T:&4@26UA9V5S`%9I<F=I;B!)<VQA;F1S+"!"<FET
M:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<G1U86P@1F]L9&5R("(E<R(@
M8W)E871E9"!S=6-C97-F=6QL>2X`5FER='5A;"!&;VQD97(@9&]E<R!N;W0@
M97AI<W0N`%9I<G1U86P@1F]L9&5R<P!6:7)T=6%L($9O;&1E<G,@<F5Q=6ER
M92!A(&QA8F5L+@!6:7)T=6%L($E.0D]8`%9I<G1U86P@24Y"3U@@1F]L9&5R
M`%9I<G1U86P@5')A<V@`5FER='5A;"!4<F%S:"!&;VQD97(`5FER='5A;"!4
M<F%S:"!&;VQD97(@9&]E<R!N;W0@97AI<W0N`%9I<G1U86P@9F]L9&5R(&QA
M8F5L`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I
M82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9
M($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N
M:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D
M(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I
M`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_`%=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S
M86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M(&]R
M(&EN;F]C96YT/P!7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@
M=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG('1H96T@
M87,@9&5L971E9#\`5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H
M('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_`%=H96X@<V%V:6YG('-E
M;G0M;6%I;"P@<VAO=6QD('=E('-A=F4@871T86-H;65N="!D871A/P!7:&5N
M('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O
M;6%I;B!S:&]U;&0@=V4@87!P96YD('1O('5N<75A;&EF:65D(&%D9')E<W-E
M<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@(D`B*3\`5VAE<F5I<R!!=7-T
M<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=H:71E;&ES=`!7:61T:`!7
M:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE
M(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F
M('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%
M87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`
M5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O
M=6YD("5D+@!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE
M87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@86)O=70@=&\@
M9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ`%EO
M=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A
M:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U(&%R92!A='1E
M;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X`66]U
M(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N`%EO=2!A<F4@
M8W)E871I;F<@82!S=6(M9F]L9&5R('1O(`!9;W4@87)E(&-R96%T:6YG(&$@
M=&]P+6QE=F5L(&9O;&1E<BX`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@
M=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N`%EO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD
M97)S+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@87)E(')E;F%M
M:6YG('1H92!F;VQD97(Z(`!9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L
M86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE
M(&-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R
M92X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+@!9;W4@8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@(B5S(BX`
M66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R
M965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"!T;R!L;V=I;BX`66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED
M;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@
M=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@9&\@;F]T(&AA
M=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R
M`%EO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L
M;&]W:6YG(')E8VEP:65N=',Z("5S+@!9;W4@:&%V92`E<R!N97<@;65S<V%G
M97,N`%EO=2!H879E(#$@;F5W(&UE<W-A9V4N`%EO=2!H879E(&%L<F5A9'D@
M<W5B;6ET=&5D('1H:7,@<&%G92X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+@!9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CH`
M66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E
M;G1E<B!A="!L96%S="!O;F4@<F5C:7!I96YT+@!9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O
M('9I97<@=&AI<R!M97-S86=E`%EO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@
M;65S<V%G90!9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S
M="X`66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"X`
M66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N`%EO=2!M=7-T('-E
M;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<V5L96-T
M(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+@!9;W4@;75S="!S<&5C:69Y
M(&$@<F5C:7!I96YT+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O(&AA=F4@(B5S
M(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RX`66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W4@<F5D
M:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+@!9;W4@<F5P;&EE
M9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N`%EO=2!W97)E(&YO="!S=6)S8W)I
M8F5D('1O("(E<R(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60`66]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M("(E<R(N($AE<F4@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60`66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C
M<FEB960@=&\@(B5S(@!9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I
M8F5D(&9R;VT@(B5S(@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O
M;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(%!'4"!0=6)L:6,O4')I
M=F%T92!+97ES`%EO=7(@4')I=F%T92!+97D`66]U<B!0=6)L:6,@2V5Y`%EO
M=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3X`66]U
M<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S`%EO=7(@86-C
M;W5N=',Z`%EO=7(@86QI87,@861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E
M;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H
M96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I
M;6%G92!T>7!E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R
M:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@8VAA
M<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SH`66]U<B!D969A=6QT(&5N8W)Y
M<'1I;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.@!9;W5R(&1E9F%U
M;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED
M96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L:6YK960@871T86-H;65N
M="!H87,@8F5E;B!D;W=N;&]A9&5D(&)Y(&%T(&QE87-T(&]N92!U<V5R+@H*
M071T86-H;65N="!N86UE.B`E<PI!='1A8VAM96YT(&1A=&4Z("5S"@I#;&EC
M:R!O;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@<&5R;6%N96YT;'D@9&5L971E
M('1H92!A='1A8VAM96YT.@HE<P!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9
M;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N`%EO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M
M;W1E('-E<G9E<G,Z`%EO=7(@<VEG;F%T=7)E.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!;2&ED92!!9&1R97-S97-=`%M(:61E(%%U;W1E
M9"!497AT70!;3F\@4W5B:F5C=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!!
M9&1R97-S97,@+0!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%M3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP:65N
M='-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T)C8P!?0FQA
M8VML:7-T`%]#3$D`7T-C`%]$871A5')E90!?1&5L971E`%]$96QE=&4@4F]W
M`%]&;VQD97)S`%]'<F]U<',`7TAE;'``7TED96YT:71Y`%]);6%G92!0<F]P
M97)T:65S+BXN`%]);F)O>`!?3&]G(&EN`%],;V<@;W5T`%]-97-S86=E(%-O
M=7)C90!?36]D:69Y($QI;FLN+BX`7TYE=R!-97-S86=E`%]/<'1I;VYS`%]0
M97)M:7-S:6]N<P!?4')I;G0`7U!R:6]R:71Y`%]2969R97-H("5S`%]296UO
M=F4@3&EN:RXN+@!?4F5P;'D`7U-E87)C:`!?4V5N9"!-97-S86=E`%]3971U
M<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?5&AR96%D`%]4;P!?56YD96QE=&4`
M7U5S97)S`%]6:65W(%1H<F5A9`!?5VAI=&5L:7-T`&%D9')E<W,@8F]O:P!A
M9&1R97-S964@=6YK;F]W;@!A='1A8VAM96YT`&%T=&%C:&UE;G1S+GII<`!B
M>71E<P!C86QE;F1A<@!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO
M="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R
M<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E;G1R>2!N;W0@9F]U;F0`9FEL
M90!F<F]M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H
M:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U
M='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!K97D`;&EN97-=
M`&UA:6QB;W@@9FEL90!M;0!N86UE`&YO;F4`;F]T(&EM<&QE;65N=&5D`&YO
M="!Y970@:6UP;&5M96YT960`;F]T97!A9`!O<@!P97)C96YT`'!E<FUI<W-I
M;VX@9&5N:65D`'!I>&5L<P!R96-I<&EE;G1S70!R96UO=&4@97)R;W(@:6X@
M<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F
M97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W!E;&QI;F<@97)R;W(`<W!E
M;&QI;F<@97)R;W)S`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T
M`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z
M`'=E871H97(N8V]M`'EO=7(@8FQA8VML:7-T`'EO=7(@=VAI=&5L:7-T`%!R
M;VIE8W0M260M5F5R<VEO;CH@24U0(#0N,"UC=G,*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#8M,#$M,#4@,34Z,#0K,#@P,`I03RU2979I<VEO;BU$871E.B`R,#`S
M+3`Q+3`X(#$P.C4S*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!$879I9"!#:&%N
M9SQD879I9$!T;78N9V]V+G1W/@I,86YG=6%G92U496%M.B!4<F%D:71I;VYA
M;"!#:&EN97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4))1S4*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"`@(+#&I;LZ(``@
M(""FK*7SI$@Z(``@(""DZ;3!.B``(""Q2*7SI$@Z(``@*"5S(*31JV4I`"`H
MI]:QML'D("5S*0`@*"5S(*31I+HI`"`HI+6DT2D`("BI^J31*0`@**Q1I-$I
M`""E1*:N.B``J?,`(*GSK>RDY2``(B5S(B"DHZQ/I$"MTZ78O_T`(B5S(B"D
MHZQ/I$"MTZ:SKL2JNK_OOMPN`"(E<R(@J7REO*9B($A/4D1%(*JZM?FE5<#)
M*%)E9VES=')Y*:2DLUVI=RX`I^2DHZCL("(E<R(@=')E92!R96YD97)E<BX`
M(B5S(J1WIJBE7*JZI5ND2JCLN'.RU:ATLLZDI"X`(B5S(J1WI5ND2L5VK:VH
M=++.+@`B)7,BJ,.EO*O8I=\Z("5S+@"]<[BY`"4N,F9-0B`O("4N,F9-0B`@
M*"4N,F8E)2D`I'>HSZ7.("4N,F9-0B`LKF6V<2`E+C)F34(@++/1OFP@*"4N
M,F8E)2D`)60@)7,@I4BDSB`E<P`E9""V;*7S`+/,JO&D0*:XL4N]6,7<I_.I
M\R`E9""DT:ME+@`E9""KRK9LI?.D=[-1IU*PHRX`)60@J\JV;*7SI'>S4;?M
MIJB\<Z=IMFRE\ZC#IE:G0:JZIOBJ0;ZYNMZR>JW[IEZS^"X`)60@J\JV;*7S
MI'>S4:9>L_BDHZQ/O'.G:;9LI?,N`+-O("5D(*O*MFRE\Z1WLU&W[::HJ56G
MH[9LI?.HPZ96IT&JNJ;XJD&^N;K>LGJM^\%\M6\N`"5D(*O*MFRE\Z1WLU&F
M7K/XK$^\<Z=IMFRE\RX`L7$@)60@J.P@)60@ID`@)60@J\H`L\RJ\2`E9""D
MT:[PMDBY=[/X`"5S("T@L\:GT;_]`"5S(*O\K[X`)7,@2T(`)7,@NOO%0+[>
MIT`@+2"]5+M[`"5S(+-=J7<`)7,@M?FE50`E<R"F4+=.MK6EV``E<R"D=Z9S
MIF(`)7,@I'>F<Z9B+B"G0:JZ("5S(*M(I?.G6*C#I;RS4:?SIE<N`"5S(*9B
M("5S("5S`"5S(*;\I4>DHZQ/I$"MTZ98JFNJNK9LO6,N`"5S(*M(I?.G6+%.
MJ?.DZZKLKLFS4:?SIE<N`"5S(*1WL;6H_"X`)7,@I'>H^J[X("(E<R(N`"5S
M(*1WL/NIVBX`)7,@I'>F7L+0I$"MTR!F<F5E+V)U<WD@N.JP5+W0J$0N`"5S
M(*1WIE["T,'<O="UN2`B)7,B+@`E<R"D=[%.MWS$L[CJL%2VQ[!EM;FG02X`
M)7,@I'>\R*[)L;6H_"X`)7,@I'>T3J15ID.HQK:UJKJZ^\5`OMZG0+1.NOPN
M(+W0J?.FN:[)I,2_[Z=!MU&M;K[>IT"JNK:UI=@N`*6RN]VM;B`E<P`E<R"D
MP`"GY*2CJ.P@)7,N`"5S(+QXN-^G0:JZMWS$L[CJL%0N`"5S(,'<O="G0:58
MKG4@(B5S(BX`("5S(*CL("5S(*9`("5S`"5S(*1WIJBE7*JZMW.\5Z;<("(E
M<R(N`"5S(*?&L>:TH[_TIT&J8+=.("(E<R(N`"5S(*?&L>;%JJCZP_:I\R`B
M)7,B(*JZL\RW<[CJL%0N`"5SJKJS<;!4O_T`)7.JNJ;FJ,:^Y``E<ZJZL\:G
MT;_]`"5SJKJKW;_LPZ\`)7,Z("5S`"5S.B`E<R`H)60F;F)S<#MO9B9N8G-P
M.R5D*0`E<SH@LV^KRJM(I?.DHZ1`J7>O=:71JTBDI*JZL4BE\Z1(J=*Q2+5O
M+B"]T*I@MTZD5:9#J=*FLZJZNO2X]+-SM;*FLZ5IK^"LJKI\IT&JNJW3I$BX
MZJ[&+@`HP+.ESK-OJ,>G[\7<J,.ROK#*J.RD5:1`K=.U9:VQ+BD`J?&Q\ZG2
MIK.G\Z?OJ,.F7JCLO&>V;*7S`"BZ]*VV*0`HK\*DY:9R*0`HO52I=Z?SI^^H
MPZ9>J.RV;*7SO&>G0"P@I_.G[Z2CMWRF8K-OM66ML:7-KL0N*0`HO52I=Z?S
MI^^HPZ9>J.RV;*7SO&>G0"P@I_.G[Z2CMWRF8K-OM66ML:7-KL0N*0`J(*OV
MO52[>Z>YIJBW<[Q7("H`*B"]T+_OOMRF8:=]*$-44DP@IFBMJZ%!4TA)1E0@
MO62S\BD@*@`L(+!]K;<@`"P@L'VMMR`E<R`E<P`LQ=RDQK9QL7$@)7,@J.P@
M)7,`+2T@O^^^W"`M+0`Q(*O*MFRE\Z1WLU&G4K"C+@`Q(*O*MFRE\Z1WIE:G
M0:JZIOBJ0;ZYNMZR>JW[IEZS^*2CK$^\<Z=IMFRE\RX`,2"KRK9LI?.D=Z9>
ML_BDHZQ/O'.G:;9LI?,N`#$@J\JV;*7SI'>F5J=!JKJF^*I!OKFZWK)ZK?NF
M7K/XK+"\<Z=IMFRE\RX`,2"KRK9LI?.D=Z9>L_BLL+QSIVFV;*7S+@`Q,#`@
MK=.F<J2X`#$P,#`@K=.F<J2X`#$R(*1PKLFH[@`R-""D<*[)J.X`,C0@I'"N
MR:CN`#(U,""MTZ9RI+@`-3`P(*W3IG*DN`"D5Z1`K;8`IKFPS[;TI;*VMZUN
MJ_RI=[CJKL:N=Z;XJD&ZW2X`M6^ES:1&I$"MT\19K:NJNK_YNWX`I$"MTZ1J
MI-BD;ZJZN<^D^<#)("5S(*1WJOZE6ZCLIKFV;*7SI*0N`*1`J\JG0;2_N&>M
M;JA$++W0N>^DZ+9LI?.F^*I!OKFVQ[N\MFRE\[!EN4:JNKU4NWNF7JCG+*1W
MLU&P9;E&+@"Q_:5;L4NV;*7S+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N
M`+']Q>?#TJ1WP[&SN:JZMFRE\RS!V;O=K6ZFLZ1`K=,@4$=0(*2]MGVJ]\9?
M+@"Q_;C1L4NV;*7S+,'9N]VM;J:SI$"MTZ2]MGT@4$=0(*KWQE\LJ'"Q2R!0
M1U`@JO?&7RRE2*3.LW'#]J1FI4\N`+']L/6FYK9LI?/#L;.Y+,'9N]VM;J:S
MI$"MTZ2]MGT@4$=0(*KWQE\LJ'"Q2R!01U`@JO?&7RRE2*3.LW'#]J1FI4\N
M`+']N-&Q2[9LI?,LP=F[W:UNIK.D0*W3I+VV?2!334E-12"J]\9?+*APL4L@
M4TU)344@JO?&7RRE2*3.LW'#]J1FI4\N`+']L/6FYK9LI?/#L;.Y+,'9N]VM
M;J:SI$"MTZ2]MGT@4R]-24U%(*KWQE\LJ'"Q2R!3+TU)344@JO?&7RRE2*3.
MLW'#]J1FI4\N`+']I5NQ2[9LI?,LP=F[W:UNIK.D0*W3(%--24U%(*2]MGVJ
M]\9?+@"DR*MEIK.VLP"DR*MEI'"K0@"DR*MEIK.K0@"DR*MEL'VK0@"DR*ME
ML'VSMP"DR*ME+Z3(J^$`I,X`05!)(+USN+D`P_:I\[-OK=.]<[_HOKD`P_:I
M\RXN+@"EOZ15I.@`I;^DI*6A`+&UJ/RHPZ5;I$JH[*?:JKJFYJC&ON2DI`"Q
MM:C\O="H1`"D=[&UJ/P`I'>QM:C\.B``Q7:MK:2CJ*PLM4RJ:ZO8I=\@5D93
M(*78O_TN`,5VK:VDHZBL++5,JFNKV*7?(%9&4R#`R:[7+@"Q8KBYN.JP5`"Q
M8KBYNU"Q2[U8`+%BN+FD=ZWAM;(N`*RPIT&JNJ5^LZ&V;*7SJ/JMT\/1IT^F
M5[K9.@"ULK%B`*=`I<ZDZ*:A`+=SO%<`MW.\5R`E<R"H[*?:JKJS<;!4O_T`
MMW.\5Z:XN'.RU0"W<[Q7I&S%=JVM`*9BIKFW<[Q7.@"W<[Q7N'.RU0"W<[Q7
MQ7:MK0"W<[Q7IKBX<[+5J.P@(B5S(@"W<[Q7IKC%=JVMIMPB)7,B`+=SO%>D
M0*W3J,^ESJK,.@"W<[Q7Q.:F[`"W<[Q7I$"MTZ:HK?LZ`+=SO%>Y[P"W<[Q7
MLW&P5+_]`+=SO%<@)7,@K+`@36]Z:6QL82"JNJ3`K;8`I5ND2JCLI]JJNJ;F
MJ,:^Y*2D`+=SO%>H[*JZLW&P5+_].@"W<[Q7J.RGVJJZLW&P5+_]`*5;I$JH
M[*?:JKJFYJC&ON2DI`"W<[Q7J,^ESJK,`""D=[=SO%<@(B5S(B"LL*K^I?,N
M`*1WMW.\5R`B)7,B(*CLJ'2RSJ2D+B"F_;5,JFNW<[Q7PT*E?JJZM?FE5;CJ
ML%0Z("5S+@"D=[=SO%<@(B5S(B"H[*ATLLZDI"X@IT&R>Z9BI6FE2+9IIN:U
M;J1*I$8N`+=SO%>HSZ7.JLRJNJ5<K^"EV*MELU'#]K.L+@"F8K9LI?.V?;'2
MJKJF4*[)Q>.EW,-"I7ZJNJKMP%DZ(#QE;3XHJT2ELK:W+*9PIK.F:+6GO="E
M2*1`IN:D0+6GO^FD2BD\+V5M/@"HY*5,N.JP5+W0J_8@)7,@P,NU^"X`J.2E
M3*JZN.JP5++3N&``J.2E3*JZMFRE\[+3N&``J.2E3*JZMFRE\[+3N&"]T*OV
M("5S(,#+M?@N`*CDI4RJNK9LI?._^;M^LM.X8`"HY*5,JKJV;*7SO_F[?K+3
MN&"]T*OV("5S(,#+M?@N`*9AIWT`LW&P5+_]`+-QL%2__0"]<[QGJTBE\Z[)
M++EWLUVD5:9#MFRE\Z9AIWVLL*^UI?.PQJ6[IJRE\[GOMD@Z(#QE;3XHJT2E
MLK:W+*9PIK.F:+6GO="E2*1`IN:D0+6GO^FD2BD\+V5M/@"F<*I'IJRE\Z2D
MJKJFK*7SN>^V2*5=IW2D5:9#IF&G?:%!JVBF7L+0H4+"X+%(N-.K2*7SKLFE
M2+-OK=.HK:7WP]&G3ZC3LT*R>CH@/&5M/BBK1*6RMK<LIG"FLZ9HM:>]T*5(
MI$"FYJ1`M:>_Z:1**3PO96T^`*:HK+"ZWK)ZK?L@+2"LL*CDI4RHSZ7.JLRS
M7:EWQ7:MK0"ZWK)Z`+QSIVD`069G:&%N:7-T86X@**K\M$FFO2D`06QB86YI
M82`HJORZN*3:I:>HR"D`06QG97)I82`HJORZN*3.IU&HR"D`MFRE\Z=/IE<`
MN>^[]`"Y[[OTI.BFH3H`J=*FLP"ITJ:SI'?%Y\/2JKJHSZ7.JLP`J=*FL[AS
MLM4`J=*FL\5VK:T`I7ZNV+UU`*15ID.K2*7SIUBDI*JZJ=*FL[9LI?.Q3K-1
MI%6X_*:HI$"MTR!M8F]X(*NLND&JNL#)KM<`(B5S(B"DI"`E<R"DT:MEJKJV
M;*7SL4ZS4:7#N[>G4K"C`*G2IK,@)7,@K=.DZZ5(I%>D=\+@IG.LL+KTIWVJ
MNL+"JOZE\[%.LU&G4K"C+@"ITJ:S("5S(*W3I.NE2*17JKK"PK%(I?.SQJ7W
MIUBQ3K-1IU*PHRX`JTBE\Z=8("(E<R(@I*2ITJ:SP_:I\ZC/I<ZJS"`B)7,B
M(*JZQ7:MK:1WIJBE7*JZLKZPHP"DN;-<J]BEWZM(I?.G6#\`I+FS7+E,PF^S
M5ZMHKDVESJ;<I?2D0*W3JTBE\Z=8(#\`I+FS7*9NM%BMT[EQI&RV;*7SIF&G
M?0"DN;-<Q=RG\[:UI=B]<[BYJKJKK+I!/P"D=Z9SIF(`Q=RG\R!)35-0(+5N
MI$H`Q=RG\R!)35-0(+%+O5@`Q=RG\R!)35-0(*C/I<ZJS`#%W*?SN7&D;+9L
MI?.F[:=]`,7<I_.\RZI/`+3`I4ZDY:9R`*:YMFRE\ZJZJ.2E3*[FIJ$Z`*7#
MN[<`I<.[M\!XIG.J_J5;P,FNUP!!;65R:6-A;B!386UO82`HK/S$4K#MPL2\
MKZC(*0"YP;C5IMNV;*7SI6BPHZK^I?.NR;5OI<VD0*W3O_F[?BX@24U!4""V
M;*7SIOBJ0;ZYIE[`LSH`I$"MT[5,KL2JNJW(LU&HSZ7.+@"U;Z7-I$:D0*W3
MI;RJOJJZO_F[?BX`J]BEW[=SNDNM;J[)M6^ES:6\JKZJNK_YNWXN`*O8I=^W
M<ZC&MK6NR;5OI<VEO*J^JKJ_^;M^+@!!;F1O<G)A("BF=[E$IM4I`$%N9V]L
M82`HIG>M]*G4*0!!;F=U:6QL82`HIG>F8ZG4KG$I`+#.IE>E3K)ZIG.H^@"U
MJJ[7`*1WIE["T`"D=Z9>PM"V;*7S`$%N=&%R8W1I8V$@**MNMZ6D:K.P*0!!
M;G1I9W5A(&%N9"!"87)B=61A("BF=[2CI<JN<:3.I-JZN*6LN4:N<2D`P+.E
MSK5[IJ$`P+.ESK5[IJ&R3;/F`,"SI<ZU>Z:AI'>T3KK\`*Y-I<ZK2*7SN4S"
M;P"N3:7.MFRE\[E,PF^H["`E<P"W[;5NI$JZ]+CTMFRGO:OA+*;;L,JN3:7.
MN4S";[-7JV@_`*A#M^VFK*7SIUBS4<6JJ/JNR:%!KDVESKE,PF^S5ZMH/P"N
M3:7.J.RITJ:SJKJFN*9`J,D`I^6MXP"Y=Z;TI&JD<`"E?*3K`*K\J=2G0J3E
M("A7:6YD;W=S+3$R-38I`,"CP5G`R:1JI'``P*/!6<#)IE>ZV0"G0;U4J7>M
M;J=2L*.S;ZW3M>K`P*M(I?.G6*JZJ7>X<;;</P"G0;U4J7>M;J=2L*.S;ZW3
MI+VV?:KWQE^VW#\`IT&]5*EWK6ZG4K"CIT&JNJKWQE^Y[[;</R`HI*.KV,2S
ML/6FYB$I`*=!O52I=\1^Q/*VW#\`IT&]5*EWK6ZG4K"C("5S(*JZM?FE5;;<
M(#\`IT&]5+M[K6ZEPZ1;IF&G4K"CLV^HQ[9LI?.VW*%(`*=!O52[>ZUNI<.D
M6Z9AIU*PH[-OK=.J_J7SMMRA2`"G0;U4J7>M;J=2L*,@(B5S(B"E2*3.I?2F
M\ZJZIKBX<[+5(#\`IT&]5+M[K6ZR3;"CIKFK2*7SIUBDI*JZJ=*FL[9LI?.V
MW*%(`*=!O52[>ZUNLDVPHZ:YO'.G:;UCI*2JNJG2IK.V;*7SMMRA2`"G0;U4
MNWNM;K)-L*.FN:E5IZ.]8Z2DJKJITJ:SMFRE\[;<H4@`IT&]5+M[K6ZEPZ1;
MIF&G4K"CLV^HQ[9LI?.VW#\`IT&]5+M[LV^KRJM(I?.HPZM$O'.G:;9LI?.H
MPZ5"P=FE2+)-I=4@/P"G0;U4NWNM;J9>L_BS;ZQ/O'.G:;9LI?,@/P!!<F=E
M;G1I;F$@**K\KMJGRBD`07)M96YI82`HJ,BL_*6GJ,@I`*C(K/REIZC(I.4@
M*$%235-#24DM."D`J.RY1J[)MJ$`P\"S3@!!<G5B82`HJOR^?*3:KG$I`*71
MI?VFW*OA`$%S8V5N<VEO;B!)<VQA;F0`I.6F<L/`LTX`J,BL=R^DTZ6MK':F
M8;#/`+C?L-T`L/6FYK[>IT"Z^\5`JV7%XZ7<O52[>[GON-P_`*3`L'3$YJ;L
M`*K^I5O`R:[7`*9BMFRE\Z2DJOZD5Z=!JKH@4$=0(*2]MGVJ]\9?/P"J_J5;
MP,FNUSH`JOZE\R`B)7,B(*1JI'"D=[97I5BDN;-<I%>MK2ZG0:JZP,FNUZA3
MIK.S4:K^I5LN`*1WJOZD5Z=!J=*M;JA$ML>P9:JZ(&E#86QE;F1A<B#`R:[7
M`*K^I?,`JOZE\R5SI'>G4K"C+@"J_J7SI'>E:+"C.B"M[*ELJOZE\ZNLND$`
MJOZE\P#`?+C5IU*PHZ1`K=.DHZ9SIF*JNKASLM4N`,!\N-6G4K"CI$"MTZ2C
MIG.F8JJZQ7:MK2X`P'RXU;USO^BD0*W3I*.F<Z9BJKJX<[+5+@#`?+C5O7._
MZ*1`K=.DHZ9SIF*JNJ9`J,DN`*58KG6D2*W[`*I@MTX`Q-VIR@"D2Z3K`$%U
M<W1R86QI82`HOT2D:J=1J,@I`$%U<W1R:6$@*+;XIF&G42D`075T:%]C<GES
M<6PZ(*?DI*.H[*G2N]VM;JJZ(&EM87`@J;6F^:Y-I?,N`$%U=&A?8WER=7,Z
M(*;XJD&ZW:C#I;RTHZC1N-.VM:3DM*DN`$%U=&A?8W)Y=7,Z(*?DI*.H[*G2
MN]VM;JJZ(&EM87`@J;6F^:Y-I?,N`$%U=&A?9G1P.B"GY*2CJ.RITKO=K6ZJ
MNB!&5%`@J;6F^:Y-I?,NO="MJ[=SO7/$MB!02%`@J,.E0J5;I$H@+2UE;F%B
M;&4M9G1P(+_OMK4LJ-*F<"!C;VYF:6=U<F4@+2UE;F%B;&4M9G1P`$%U=&A?
M:6UA<#H@I^2DHZCLJ=*[W:UNJKH@24U!4""IM:;YKDVE\RX`075T:%]I;7`Z
M(*?DI*.H[*G2N]VM;JJZ($E-05`@J;6F^:Y-I?,N`$%U=&A?:W)B-3H@I^2D
MHZCLJ=*[W:UNJKH@:W)B-2"IM:;YKDVE\RX`075T:%]L9&%P.B"W<[Q7J,^E
MSJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]JD&PR`!!=71H7VQD87`Z(*=2
ML*.HSZ7.JLRS;[:UI5ROX*78JV6HPZ2CI.2TJ:78O_VJ0;#(`$%U=&A?;&1A
M<#H@I^2DHZCLJ=*[W:UNJKH@3$1!4""IM:;YKDVE\RX`075T:%]L9&%P.B"U
M3*IKMW.\5ZC/I<ZJS"`E<RX@IOBJ0;ZYIE[`LSH`075T:%]L9&%P.B"U3*IK
MLKZPHZC/I<ZJS"`E<P!!=71H7VQD87`Z(+5,JFNG\[=SJ,^ESJK,("5S`$%U
M=&A?;&1A<#H@I_.W<ZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!
ML,@`075T:%]M8V%L.B"GY*2CJ.RITKO=K6ZJNB!-0T%,(*FUIOFN3:7S+@!!
M=71H7W-M8F%U=&@Z(*?DI*.H[*G2N]VM;JJZ('-M8F%U=&@@J;6F^:Y-I?,N
M`$E-05`@IOBJ0;ZYQ>?#TK_YNWXN`,7GP]*EHK'1+@#%Y\/2I:*QT2X@)7,`
M4D%$2553(,7GP]*_^;M^+@!&5%`@Q>?#TK_YNWXN`%--0B#%Y\/2O_F[?BX`
MIMNPRL7CI=P@2%1-3""V;*7SI*2JNJG2IK.YSZ3Y+*9PJD>Q2*7SI$BF8J?:
MJKJS<;!4O_VF5[/FI*0@/P"E::7.JKJS<;!4O_TZ`*5II<ZJNL3FINPZ`+6E
MJ]VF7L"SI*0`07IE<F)A:6IA;B`HJ,BVZZOTM4TI`*9>J.Q?:R5S`*9>J.P@
M)7,`IEZH[,#+M?BOP:3>`*9>J.S#]L%PQ>.EW`"M2;2Z`*U)M+K#0Z;B`&ME
M<F)E<F]S(+%+O5B_^;M^+@!K97)B97)O<R"HSZ7.JLRF5[K9O_F[?BX`O_F[
M?JJZO="H1"X@IOBJ0;ZYIE[`LSH@)7,`0F%H86UA<R`HI-JKHK"H*0!"86AR
M86EN("BDVJI,*0"J:<.YJKJN_*3E("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:"`HJ7.E6ZG4*0!"87)B861O<R`HI-JHJ:9H*0"GY*2CJ.RYSZ7<I=B__2`B
M)7,B+@"P\KUU`*^UI?.PQJ6[`$)E;&%R=7,`0F5L9VEU;2`HI/&G4:[)*0!"
M96QI>F4@**BIJ+VTM2D`I4BD5:Q/JJRZ0;!4KJ>V;*7SJKJM[*ELN.JNQBX`
M0F5N:6X@**BIN><I`$)E<FUU9&$@**;*O'VY1BD`0FAU=&%N("BDHZ2F*0"E
MS:3I`+;"IE>SY@"GY*2CJ.S`LZ7.M7NFH2(E,B1S(JJZL,^V]"(E,21S(BX`
ML,^V]+-=J7<`L,^V]*NLND$`P?3"PR!(5$U,(+9LI?.DI*JZN<^D^2RPHZM$
MIF*V;*7SI*2O4Z=/J_RI^C\`I;NDY0"RRL7I`$)O;&EV:6$@**S!IU&Z^ZC(
M*0"NT<72`*[8O74`KMB]=:1JI'``KMB]=0!";W-N:6$@86YD($AE<GIE9V]V
M:6YA("BJ::1HI:>HR*3.ML+!R:WTNONHNBD`I?ZSH0"J[<!9ID.J[:5(I,ZV
M;*7SI43%Z0!";W1S=V%N82`HJFFEOJBZ*0"IL[.A`$)O=79E="!)<VQA;F0`
M0G)A>FEL("BDVJ;H*0!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`
M0G)U;F5I($1A<G5S<V%L86T@**A:M=PI`$)U;&=A<FEA("BK3Z5;IU&HR"D`
MMK6EV++%N+D`0G5R:VEN82!&87-O("BEK+18K\>J:Z_!*0!"=7)U;F1I("B[
M6K:IIF$I`*JIK;&ZWK)Z`$-20P!#4DP@I,"SH<))`,!XIG.NYJ2ZKF4N+BY?
M90"]<[U87V@`I]:H^JKLJ6RDQJE\I;RGN::H+@"FYJC&ON0`N7.OQ:VW`$-A
M;6)O9&EA("BL6JY(N>LI`$-A;65R;V]N("BSV+/!MJDI`+5,JFNS<[6RJ.R[
MM[K=JKJV;*7SIOBJ0;ZY.B``M4RJ:[-SM;*H[+NWNMVJNK9LI?.F^*I!OKDZ
M(`"U3*IKQ>.EW"`M(*9BI=BK9:JZJTBE\Z=8I*2E=:?DJ.P@)3(D<R"MTZ2D
MJKH@)3$D<R"MTZK^I?,N`+5,JFNFV[#*K:NX;;%+O5@LO=#!<+6XIT&JNJAT
MLLZZWK)ZK?LN`+5,JFN\9Z1*P,FNUR`B)7,B`+5,JFNS<[UUIMP@24U!4""F
M^*I!OKDZ("5S`+5,JFNV?;'2P,FNUR`B)7,B+@!#86YA9&$@**5;KK.D:BD`
MJ/JN^`"H^J[XMFRE\P"H^J[XL-W#1*9>L_@`J/JN^+USO&>W<[9LI?.Q3K=\
MO_*EHJM(I?.DI*JZJ=*FLZ2ZKF4N`+5,JFNG4K"CP,FNUR`B)7,B+@"GY*2C
MJ.R\R*9SI=B__2X`K\JDUB`G=&%R9V5T1FEL92<@L-&\QK5,JFO$?L3RLT*R
M>BX`M4RJ:[*^L*.EV+_]("(E<R(N`+5,JFNROK"C.R`E9""MTZ1LMK"D=Z9S
MIF(N`+5,JFNMJ[+5H4.ITK2CJ-&JNK!/O_V\QJ78NU"E_:MEJ=+`>*9SJKJX
MZJ[&I*.RQ2X`M4RJ:[;'L&7"LK!4J.RK_*EWJKJXN;U8+@!#87!E(%9E<F1E
M("BZ^[QWJ*0I`+NAJ?JDY:9R`*3`P_Z[4+S0Q=(`0V%Y;6%N($ES;&%N9',@
M*+9]L-*X<ZYQ*0"PQJ6[`*;FL,JY<;C<`,!XIG.NYJ2ZKF4`P'BF<Z[FN=2E
M4CH`P'BF<Z[FI+JN90#`>*9SKN:VH;9:.@"FYK#*N7&XW`"VZ[JXKU.DY2`H
M25-/+3@X-3DM,30I`+AMI*0`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC("BD
MI*M$ID"I3;#J*0"DI+S:("A)4T\M.#@U.2TR,`"^S,/2LM.X8`"^S,/2OM:F
MLZK,`+[,P]*L1K6F`+[,P]*VUZ1*M4RNQ"X@IOBJ0;ZYI;RQTJ7.P,FNUZ17
MML>E7*_@+@!#:&%D("BL9+QW*0"E1*YU`*?SI^\`I?ZSH<7<I_,`Q=RG\ZM(
MI?.G6`"G\Z?OIT&JNK%+O5@`I_.G[\7CI=R_[[:U+""F<*A#K;;%XZ7<MFRE
M\[S&I=@LMFRE\Z9PIO.QQJ9#M:4N`,7<I_.V;*7SIOBJ0;ZYI4BDSJM(I?.G
M6+-=J7<N`*?SI^^G0:JZJKJE_J97I4BDSJ9>MFRF8:=]+@"G\Z?ON]6D5:JZ
MI?ZF5RRF7K9LIF&G?2RQ2*7SL\:E]ZE-P[&F5RX`I=BK9:JZLUVI=ZC#I;RD
MY+2IL4N]6,7<I_,N(+W0P7"UN*=!JKJZWK)ZK?LN`*9RI+@`Q>.EW*JZIG*D
MN+S&.@#`RZQDLW.ULBXN+E]K`,#+K&2W<[9LI?,`O^^H^B"E_K.A+[5,7T$`
MI,2_[Z=!MU&M;L6JJ/JJNJ5^LZ&V;*7SL6*XN3H`IF*VQ[!EMFRE\Z2GJV4L
MI?VP]:;FJ_>F<L#+K&0_`$-H:6QE("BTO*=1*0!#:&EN82`HI*2PZBD`PK+%
MZ:2DI.4@*$=",C,Q,BD`I;_%Z:2DI.4@*$)I9S4I`+_OOMRG0*7.I.BFH3H`
MO^^^W,"SI<ZU>Z:A.@"]T+_OOMRV;*7SIOBJ0;ZY.@"]T*15J=2_[[[<J<Z]
M<[_HI6O#Y*JZN.JNQJ5(P7*T^CH`O^^^W+%+O5@`O^^^W*1`K=.HSZ7.JLRF
M5[K9`*3IM,'%XZ7<I.BFH3H`O^^^W+:UI=BKK+I!JKJMMZ[F`+_OOMRY=[-=
MJKJS<;!4O_VA0:5(IU&W<[Q7IF&G?2X`O^^^W+-QL%2__;=JM$VVMJ?'+*5(
MJTNI;:97P7*T^BX`0VAR:7-T;6%S($ES;&%N9"`HN'2]SZYQ*0"GY*2CJ.P@
M)7,@JKK#_J=/J7>X<2X`M+@`LDVPH[=,LVX@3V9F:6-E(+S0Q=(`LDVPHZQD
MN-\`LDVPHZC/I<ZJS#H@)7,`LDVPHZC/I<ZJS`"R3;"CJ,^ESJK,JKJXZJ[&
M`+'?PN"TN`#"2;_O("5S(,+@M*NYSZ3YP,FH[,)SQ/V^N:17K;$N`,))O^\@
M)7,@I%6X_+G/I/DN`,))O^\@)7,@MFFD2B`E<R"ZWK)ZK;:ML2X`PDF_[R`E
M<R"F8K=SM?BUH:2DP,NU^"!(5$U,(*2ZKF4N`,))O^\@)7,@P,NU^*:YN<^D
M^:JZP5FYSRX`PDF_[R`E<R"F8K=SM?BUH:2DP,NU^*K^I?,N`,))O^\@)7,@
MIF*W<[7XM:&DI,#+M?AM=6QT:7!A<G0O<F5L871E9*K^I?,N`,))O^^FN;-"
MQ>.EW+G/I/D`K+"H0Z1`I;N_[[[<JKJS<;!4O_VS7:EWP7*T^JJZQ.:F["X`
MJ_:WQKFKP>2E2,1^Q/(`PDF_[[-ON,S`>*9S(%!'4""DO;9]JO?&7ZCLIT&J
MNK-QL%2__:2D`,))O^^S;[C,P'BF<R`E<R"JNB!3+TU)344@OLS#TJCLIT&J
MNK-QL%2__:2D`$-L:6-K871E;&P@LWJY3"!(5%10`+USO&>W<[9LI?.UN;-O
MK=.Q2*7SI$@`MGVQTKC3J\JV;*7S`,/VLZP`P_:SK+7XM:$`P_:SK*:YM?BU
MH0"K2*7SIUBD=\/VLZP`MK.V<0"FK:9HMK,`L[$`0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',`I^G%?`"GZ<5\`*?IQ7RITJ:SJTBE\Z=8`*?IQ7RK2*7SIU@`
MI^G%?+CJKL:GJ`"GZ<5\P^2LR0!#;VQO;6)I82`HK?2MVZ3QJ,@I`,-#IN(`
MPT.FXKS0L$\`O=6FXKU,`#$VMFFF[,-#IN*E3KU8`,3F.@#$YJ;LO-##1`"E
M9+-Q`*E2I4\`I^6FN*E2I4\`M?FXT0"ZV:E)`$-O;6]R;W,@**SLO*_#N2D`
MI+VE<0"D=Z>YIJ@`Q'[$\KQGJ.2E3*JZJT@`O7.\9[9LI?.I\[=SM?BUH:2D
M/P"Y=[-=J,^ESKKTK;8H2%1-3"FYSZ?.I,:DMJVQO7.\9[9LI?,HN]VHSZ7.
MN/NW<ZJZPG/XL+ZY*3\`N7&XHP#`]+G2`+'XI?,`KG2RIP"[4"!01$$@M'BD
M5ZNLN7&XHRRTO+QZJZRDXK[WI4BDSB!/=71L;V]K(*JZIE"H0K-=J7<N`+-=
MJ7>XZJ[&N4RTP2X`LUVI=R`E<P"S7:EWIG"F\\7CI=RV;*7S+@"V;*7SN7?$
M_;-=J7<N`+U4NWNQ2[U8`$-O;F=O("BMZ*I'*0!#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE("BMZ*I'ID"I3;#J*0"S<[6RLU$@24U!
M4""F^*I!OKFRUZ3N+@"S<[6RI:*QT2X`LW.ULJ6BL=$Z(`"S<[6RIMRDO;9]
MJO?&7Z;XJD&^N:[)OD2IVBX`LW.ULJ;<I+VV?:KWQE^F^*I!OKFNR;Y$J=HN
M(*WLIETZ("5S("@E<RD`LW.ULJ;<($944"#`R:[7IOBJ0;ZYI:*QT2X`LW.U
MLJ;<IOBJ0;ZYI:*QT0"S<[6XI$@`L$^__:1WIJBE7*9AMW.\5Z;<IT&JNK-Q
ML%2__:2D+@#`H\%9P,FNUZJZI+JN9:NLND$Z(``B)7,B(,#)KM>DNJYE`,1^
MQ/(`L;&H[B`E<R"JNB!01U`@I.2TJ2X`L;&H[B`E<R"JNB!3+TU)344@I.2T
MJ2X`MFRE\[=JM$VJNJS;P_:QL:CNO^^VM2X`M^VW<[9LI?.H[+E&KLDL(*Q/
MIU^S<:J^N]6D52X`PN"TJZKML:&DY:9RK+"YSZ[7(#\`0V]O:R!)<VQA;F1S
M("BL[*=*N'.N<2D`O<:[<P"]QKMSI:*QT3H@)7,`O<:[<P"]QKMSJ.RK2*7S
MIU@`I_.EOP"M[*3EI'>G\Z6_`$-O<W1A(%)I8V$@**WTM+6D:KZDI5LI`$-O
M=&4@9"=)=F]I<F4@*+9(I/JN_*FD*0"U3*IKI4@@4$=0(*5;L4NV;*7S.B``
MM4RJ:Z5((%!'4""P]:;FMFRE\\.QL[DZ(`"U3*IKI4@@4R]-24U%(*5;L4NV
M;*7S+@"U3*IKK+`@4R]-24U%(+9LI?/#L;.Y+@"U3*IKMW.\5[-SM;BD2"X@
M)7,`M4RJ:\.TM;(@3$1!4""F^*I!OKD`M4RJ:\.TM;(@;&1A<""F^*I!OKD`
MM4RJ:\#+K&2W;*]Q+B`E<P"U3*IKI[FFJ+W0J$0N(*WLIETZ("5S`+5,JFNS
M<[6RIMP@;&1A<""F^*I!OKD`M4RJ:[-SM;*FW*;XJD&^N2`B)7,B(*C/I<X@
M1E10.B`E<P"U3*IKJ]BEW[!TN&VX<[+5+B`E<P"U3*IKJ]BEW[7JP,#`R:[7
MJ'2RSBA61E,IJKJF^*I!NMTZ("5S`+5,JFNXT;%+(%!'4""XZJ[&.B``M4RJ
M:[C1L4L@4R]-24U%(+CJKL8N`+5,JFNG4K"CLW.UN*1(+B`E<P"U3*IKIU*P
MH[!TN&VR3;/F+B`E<P"U3*IKIML@)7,@IU*PH[9LI?,NIOBJ0;ZYIE[`LSH@
M)7,`M4RJ:Z=2L*.G\[=SM7NFH2`B)7,B+@"U3*IKJ$VI=Z:LI?.D2*JZN7&D
M;+9LI?.F[*=]+@"U3*IKL/6FYKK[Q4"^WJ=``+5,JFNFVR!-4RU43D5&(,/^
MJZRJNJ>HL6'`R:[7N-'`H\%9+@"U3*IKIML@6FEP(,/^JZRJNJ>HL6'`R:[7
MN-'`H\%9+@"U3*IKP/*H^J>YON.JNK-QL%2__2X`M4RJ:\#RJ/JGN;[CJKJP
M=+AMLDVSYBX`M4RJ:\#RJ/JP=+AMLDVSYJ2DJKJX<[+5+@"U3*IKN/RD2K6F
MLJ0@(B5S(BX`M4RJ:ZO8I=^EV+_]("(E<R(N`+5,JFNFVZKWQE^F^*I!OKFH
M^K%OI+VV?:KWQE\N`+5,JFNV?;'2("(E<R(@I4B\9Z1*+@"U3*IKMGVQTB`E
M<RX`M4RJ:[9]L=*Z^\5`I'6G0+S2LM4@)7,`M4RJ:[9]L=*EV+_]("(E<R(N
M`+5,JFNV?;'2J.P@24U!4""F^*I!OKFJNJ9WI?ZS<[6R+B`E<R`Z("5S+@"U
M3*IKLW.QM2!,1$%0(""F^*I!OKDN`+5,JFO%JJCZ("5S+@"U3*IKK:NW<[-=
MJ7>HSZ7.JLRJNK%+O5@N(+.AI,"JNK+3N&"DHZ6_O50N(+W0P7"UN*=!JKJH
M=++.NMZR>JW[I4BH\Z=5LT*R>BX`M4RJ:\6JJ/JF<ZCZL;&H[JKM*$%C8V5S
M<R!#;VYT<F]L($QI<W0I`+5,JFO%JJCZLW&P5+_]+B`E<P"U3*IKQ:JH^K!T
MN&VR3:55+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E<P"U3*IKIML@24U!4""F
M^*I!OKG%JJCZJ5*F5ZK%MJ$H;F%M97-P86-E*;CJL%0N`+5,JFO%JJCZIOBJ
M0;ZYJKJLV\/VKU.IR@"U3*IKIEZT7[-=J7<N`+5,JFNG4K"CI=B__2`B)7,B
M+@"U3*IKP'BF<R`E<R"JNK-=J7<N`+5,JFO`>*9SL\:E][-=J7<N`+5,JFO`
M>*9SL\:E][-=J7<Z("5S+@"U3*IKP'BF<Z?SMW.U>Z:AJ.PZ("(E<R(N`+5,
MJFO`>*9SL\:E][-=J7<@)7,N`+5,JFO`>*9SLUVI=\#))7,N(*=!I6FE2*C/
MI<XE<Z2DJKJHY*5,I5ROX,!XIG.S7:EWJ<ZDXK#*O<:[<Z15K;&U>Z:AO5BH
M["`E<RX`M4RJ:[=JM$T@3$1!4"`@IOBJ0;ZY+@"U3*IKIU*PHR`B)7,B+@"U
M3*IKI_.W<[-SM;BD2"X@)7,`M4RJ:Z?SMW.P=+AMLDVE52X@)7,`M4RJ:\+0
MO&<@(B5S(CH@)7,@JKJS7:EW+@"GY*2CJ.P@36]Z:6QL82"JNJ3`K;8N(+W0
MO52[>Z3`K;:L3Z=?MGVQTBX`M4RJ:[WAI*FHSZ7.JLP@(B5S(B"D5:9#Q7:M
MK:CLJTBE\Z=8("(E<R(Z("5S`*?>LTZE>0"PZJYA`+W2JNT`J]BEWP"KV*7?
M`*O8I=^J]\9?`*O8I=^UZL#`JTBE\Z=8`*O8I=^D0*W3MW.JNK%BN+D`J]BE
MWZ1`K=.S<[6R`*O8I=^D0*W3MW.JNKQSIVF]8P"KV*7?I$"MT[=SJKJO\[U:
MO6,`J]BEWZ1`K=.W<ZJZ`*O8I=^D0*W3MW.JNK%(I?.]8P"KV*7?I$"MT[=S
MJKJI5:>CO6,`J]BEW[E,PF^S5ZMHI4BP=+AMJ=*FLZC3JT@L(+'&ID.K2*7S
MIUBDI*JZJTBE\RP@I4BDSJ=2L*.\<Z=IMFRE\RX`J]BEW[=SJKJK2+K@`*O8
MI=^K2+K@NU"UJL+0+@"KV*7?IKBK2*7SIU@`J]BEWZK,JKK%=JVM`*M(I<ZE
M9+BYO5@`0W)O871I82`HITK#N:;HJ,@I`$-U8F$@**5JI-HI`*78JV6W?+3!
M`*78JV6NR;:A`*78JV6Z]*=]`*78JV6JNJC/I<ZJS`"EV*MEI-&N\``E<R"E
MV*MEJ=*]X:2IJKK%=JVM`*78JV6JNJJLJG`Z(`"EV*MEJKJMMZ[F`+-=J7>E
M?K.AMFRE\ZJZL6*XN2S%JJCZI7ZSH;9LI?,N`*;;K7&F<*;SML>P9;9LI?,N
M`*;;K7&D0*C'M6ZD2B5SJ^&ITJUNL/6FYJJZI'6G0"X`L,6D50"PQ:15`$-Y
M<')U<R`HP<FTMK#'M+4I`*;HJ+VZN*3E("A+3TDX+5(I`*;HJ+VZN*3E("A7
M:6YD;W=S+3$R-3$I`*;HJ+VZN*3E+Z]1ITK$]:3E("A+3TDX+54I`$-Z96-H
M(%)E<'5B;&EC("BQMJ=*ID"I3;#J*0"DZ0"XZJ[&J-.WO:97NMD@*+W0L-&F
MTB!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I`*A#I.D`I.FTP5]E`+[PJJRXZJ[&PG/$
M_0"XZJ[&KG>W:K1-`*3IM,$`IJRH[*3IM,$`O^^^W*3IM,$`I=6DT0"G4K"C
MQ.:F[%]L`*11I$>DZP"D4;9IINR\QJ9R`,'"M;0`P<*UM#H@`+3NI-;!6;'&
M`+EWLUT`N7>S7<-#IN(`N7>S7:JZJ*VE]\/1IT\`N7>S7;=JM$W$YJ;L`+EW
MLUVI4J5/N-&J4KZY*%-H96QL*0"Y=[-=JKJQQJ9#LU>K:#H`N7>S7:JZL<:F
M0[:VI\<Z`*EWN'$`I'>I9;!5`*=2L*,`IU*PHR`E<R"DO;9]JO?&7P"G4K"C
MP'BF<Z[F`*=2L*.EV*MEJKJJ]\9?`*=2L*,`IU*PH[ASLM4`IU*PHZSVO_T`
MIU*PH\5VK:T`IU*PHZG2O^^JNJM(I?.Y:`"G4K"CJTBZX`"G4K"CM>K`P*M(
MI?.Y:`"G4K"CM>K`P*M(I?.G6"`E<R"JNJEWN'$`IU*PHZ%"LDVJQ;9LI?,`
MIU*PH\!XIG.NY@"G4K"CQ.:F[`"G4K"CLGNF<ZJZM,"E3KS+JD\`Q:JH^JOA
M+*;;IOBJ0;ZYIU*PH[9LI?,`L7&GVJJZIN:HQK[DI*2G4K"C`*GSJ$.DZZKL
M+*=2L*.D=\+@IG.LL+KTIWVJNL+"JOZE\R`_`*GSJ$.DZZKL+*=2L*/"PJJZ
ML4BE\[/&I?>G6"`_`*=2L*,B)7,BJKK%=JVM`+U4J7>M;J=2L*,B)7,BJKK%
M=JVMI4BDSJ:XQ7:MK2`_`*=2L*.F0P"G4K"CJ=*_[[[<JKJHK:7WP]&G3[CJ
MKL8`IU*PH[QSIVFV;*7S`*=2L*.EV*MEJKK$YJ;L`*=2L*.EV*MEJKJF0P"D
M=Z=2L*,`I'>G4K"CMFRE\P"G\[=SM7NFH2`B)7,B(*1WIU*PHRX`IU*PHZ:Y
MI$"J_J7S("(E<R(@+@"G4K"CI,ZW:+*^MFRE\P"[O+!EKLFVH0!$96YM87)K
M("BDIK/!*0"IVK6TO="H1`"IVK6TIEZUJK=\Q+.XZK!4`*71J^&FW*7]`+#=
MPT2T>:UZ`+1YK7H`LM.X8`"RT[A@("B]T+#1IM(@2&]R9&4@L$^__<#)KM<I
M.@"RT[A@O="PT:;2J'2RSKK>LGJU;K_]+@"LX[5O`,53PDFWQ:O7`+/,J^&D
M0*1PKLFJNL53PDFWQ:O7.B``Q5/"2;?%J]<Z(`"EO*K^I5NJQ:75P,FNUR`B
M)7,B`+)(I,;#L:97/P"Q<:6JIMRE:P"Q<:5KIMREJ@"EV+_]`,7CI=R_[[:U
M`*5((#(T(*1PKLFH[L7CI=P_`,7CI=R_[[:U`+?MML>P9:>YMFRE\ZOA+,7C
MI=R]5+M[L%2NIS\`Q>.EW+C4LM.JNKEWL_@`Q>.EW+EWL_@@*%1!1BD`Q>.E
MW*[FIJ$`Q>.EW*GSMFRE\Z5$Q>FD5P"THZ7<M^VFL[=SMFRE\ZCLN4:NR3\`
MIF*E7*_@JNVDI,7CI=PBLDVJQ;QSIVF]8R*FN:1`LW.ULC\`IF*E7*_@JNVD
MI,7CI=PBLDVJQ:E5IZ.]8R*FN:1`LW.ULC\`L'2X;0"VQ[!EIEZQ^`!$:FEB
M;W5T:2`HIDZEK*9A*0"DH[+%IE@`I*/`RZQDMW.V;*7S`*2CIU*PHP"DHZUN
MJKVQM:9SJ/H@;6%I;G1E;F%N8V4N<&AP`*2PN_*D7:2CM6^ES0"L3Z=?MGVQ
MTJ:YI.6E\R`_`++$I$"UI[!/O_VL3Z=?I5VG=,3FINRF5[K9/R"F<*I'K$^]
MT*3$O^\N`$1O;6EN:6-A("BF:*GZI:>E6RD`1&]M:6YI8V%N(%)E<'5B;&EC
M("BF:*GZI:>E6Z9`J4VPZBD`P=FH4Z:SJ,^ESK%BN+FVW#\@I=.]T*1`K=,N
M`*>YIJ@`I%6X_`"D5;C\("5S`+%.("5S(*15N/RFJ*RP("YZ:7`@KN:FH:JZ
MP*/!6<#)`+%.J=*FLZK^I?.D5;C\IJBLL*1`K=,@+GII<""NYJ:AJKK`H\%9
MP,D`I%6X_`"D5;C\(%LN>FEP(*[FIJ%=`*15N/RS7:EWP,FNUZ5TIG.LL"!0
M2%`@M7NFH2X`I%6X_*:HK+`@+GII<""NYJ:AJKK`H\%9P,D`K_.]6@"O\[U:
MIU@`K_.]6KUC.@"D5:G4I5ROX*KM`,/$JWX`N7&D;+9LI?,`N7&D;+9LI?.F
M8:=]`+6RI_0`O_F[?@"_^;M^.B"G0:JZMFRE\[5,JFNS4;N\L&4N`$5C=6%D
M;W(@**3,I<JF:+JX*0"]<[_H`+USO^BVPJ97L^8`O7._Z+#/MO0`O7._Z+E,
MPF\`O7._Z+ASLM4`O7._Z,5VK:T`O7._Z,5VK:T`O7._Z"5SJKK%=JVM`+US
MO^BUZL#`JTBE\Z=8`+USO^@@)7,@JKJUZL#`JTBE\Z=8J7>X<0"]<[_HI,VU
MO:97L^8`O7._Z+_OMK4`O7._Z"(E<R*JNL5VK:T`O7._Z"5SJKK%=JVM`+US
MO^BG0:JZML*F5[/F`+USO^BG0:JZN4S";[-7JV@`K+"G0:CDI4RJNKEQI&RV
M;*7SL6*XN;USO^BPOJ9NLUVI=RX`O7._Z*=!JKJDS;6]IE>SY@"QT*A\`$5G
M>7!T("BN2J3.*0!%;"!386QV861O<B`HPL2ZN*7+IF@I`*2XI?,N+BX`N7&D
M;+9LI?,`N7&D;+9LI?.F8:=]`+EQI&RV;*7SINVG?:6RMK>G:Z98+@"Y<:1L
MMFRE\[U4NWL`16UA:6PM=&\M4TU3(+EHN42^N0"J[;&ALL6XN0"D=[)-JL6I
MTJ:S("5S(*2DJKJV;*7S+@"R3:K%`+)-JL6ITK_OOMRJNJM(I?.G6`"R3;"C
MJ56GH[UCI*2ITJ:SMFRE\P"R3:K%O'.G:;UC7U,`LDVJQ:E5IZ.]8U]4`*K%
MI=6K2*7S+@"JQ:75M;*J1RX`JL6EU;=JM$VVM:78`+'2I<X@4$=0(#\`L=*E
MSB!3+TU)344@/P"DN;-<IMO#P+19M*&D2K?3I/FH[*M(I?.DI"BZ]*VVO7.\
M9[S2IJ$I(#\`L=*ESK9LI?.Y=\3]/P"QTK#*M\:YJZ5KP>2E7*_@JNT_`*5;
ML4N_[[:U7WD`I'>E6[%+`+6RI\``I[FFJ,+@L4BV;*7S`*>YIJBV;*7S`*>Y
MIJBV;*7SIML@)7,`M;*G]*9^I?<`J?&D:KUSO^B^N0"_Z:1*L4N]6`"F<*I'
MIT&[W:UNK:NS7;%+O5@LO="_Z:1*I$"MTZ9WI?ZPW:5Y+*C2IG`@)Z=!PV2J
MJZJZIE>ZV2`_)SH`IF*FN;_II$J\=KFSJKJZ]*=]`+W0O^FD2K=SO'.G:;UC
MJKJF5[K9`+W0O^FD2K=SK_.]6KUCJKJF5[K9`+W0O^FD2K=SL4BE\[/&I?>]
M8ZJZIE>ZV0"]T+_II$JI5:>CO6.JNJ97NMD`ON.KRK9LI?,`L$^__2`B)7,B
M(*1WIJBE7*9AMW.\5Z;<LW&P5+_]`$5Q=6%T;W)I86P@1W5I;F5A("BHJKE$
MM%BDNJC(*0!%<FET<F5A("BDS*7?KU.HO:9W*0"_^;M^`+-SM;*H["!)34%0
M(*;XJD&^N:[)M6^ES;_YNWXN("5S(#H@)7,N`*O8I=^PS[;T)7.NR;5OI<V_
M^;M^`*=2L*.F4*A"P>/"23H@)7,@KLFU;Z7-O_F[?@"G4K"CIE"H0K!/O_TZ
M("5S(*[)M6^ES;_YNWX`Q:JH^J2ZKF4Z)7,@KLFU;Z7-O_F[?@"VQ[!EIE["
MT*[)M6^ES;_YNWXZ("5S+@"G\[=SL4N]6#H@)7,@KLFU;Z7-O_F[?@"\9Z1*
M("(E<R(@KLFU;Z7-O_F[?BX`17-T;VYI82`HMU*H1J6GJ,@I`$5T:&EO<&EA
M("BFYZ_!I/&HR"D`NMBQV@!%=7)O<&4@*+S:K'<I`*C&I?.D=Z:HI5RJNK*^
ML*,N`*A#(#$U(*3`Q,$`J$,@,B"DP,3!`*A#(#,P(*SMQ,$`J$,@-2"DP,3!
M`*A#IKBU;J1*`*A#I6*D<*[)`*A#I,#$P0"]9*C2K<@Z`+#UIN8`KFFV?0"N
M:;9]`*YIMGVITJ:SJTBE\Z=8`*YIMGVK2*7SIU@`J6VF5\%RM/H`KFFV?;CJ
MKL:GJ`"F8KUSO&>V;*7SM?BUH:2D++GUJ^&P]:;FJ6VF5\%RM/H_`+?MK&2L
MW:M(I?.G6*[)++EWI?VN:;9]J=*FLZM(I?.G6#\`P7*T^J2D`*UNJ$0@)RDG
M`*CLM,&DZ0"XT;NAK?L`JV6TNL-#IN(`1E10(*17ML>S7:EW+@"E?K.AMFRE
M\U]E`,6JJ/JPOJ9NLUVI=Z6BL=$`M4RJ:[-SO76FW"!,1$%0(*;XJD&^N2X`
MM4RJ:[-SO76FW"!334(@IOBJ0;ZY+@"]QKMSI:*QT:;;("(E<R(N`+W&NW.E
MHK'1J.P@(B5S(BX`M4RJ:ZO8I=^D0*W3MW.JNB!305-,(+-SL;4N`+=HLKZE
MHK'1J.P@(B5S(BX`PEZH^J6BL=$Z("5S`+2VLW$`1F%L:VQA;F0@27-L86YD
M<R"J:\3UITJZUKASKG$@*+"HNKBZ^Z_'M+6X<ZYQ*0!&87)O92!)<VQA;F1S
M`,19K:N_^;M^.@"VQZ]U`+;'KW4`I$>DZP"W4,2Q`+=0Q+$Z(`"E?K.AMFRE
M\P"F8K=SM:&D9J2DIJRH^J5^LZ&V;*7S/P"U;J1*NO2X]+9LI[VKX:;;L,JF
MK*CZI7ZSH;9LI?,_`*1WL7$E,B1SQ:JH^B4Q)&2KRK9LI?,`I'>Q<25SQ:JH
M^B`Q(*O*MFRE\P"E?K.AMFRE\SH@`*5^LZ&V;*7S.B"H4Z:SMW.V;*7S+@"D
M\J3RJT(`M76\R+!]L[<`MFRE\[E,PF]?;`#$YJ;LL'VF0P!&:6II("BTM,#9
M*0"J_J7S`,#)KM>\QJ78.B`E<R"MT\#)KM<`P,FNU[S&I=@Z("5S(,#)KM<`
MP,FNU\%@NMX`P,FNUZ97NMD`P,FNU[_OOMP`P,FNUZ17ML<`P,FNUZ17ML>E
M7*_@I;RS4:3DM*DN`+E,PF^^N;_OMK4`N4S";[ZYLUVI=P"Y3,)OIW2FLZ2C
MMJZDY:9RI+JN9:JZMFRE\S\`N4S";[ZYI.2TJ:C#I;RF8J6[J'2RSJ2DL=*E
MSBX`MFRE\[E,PF\`MFRE\[E,PF^EO+'2I<X`MFRE\[E,PF\Z("5S(+K>LGJM
MMJVQ`+1-I^0`1FEN;&%N9"`HJN+$]2D`I%>E8J3K`*M(I?.G6*JZLL2D0*VV
M`++$I$"MM@"D5ZFV`*E4J7>D\:C2`*17I%7$0:W+`*]"L,H`PN"Q2%]R`,/Z
M`*78O_T@)7,@I*.F<Z9B`*M(I?.G6+[>IT`@+2"]5+M[`*M(I?.G6+K>LGH`
MJTBE\Z=8NDNM;@"K2*7SIUBF0*C)I5ROX*C#I;RQTJ7.+@"K2*7SIUBI?*6\
ML=*ESBX`IG*KK,-#IN(`K;FJJP"F7:RPPG/$_;ZYJ,.EO*3DM*F\=KFSI5RO
MX"X`KO"V2+EWL_@@*%1!1BD`N7>S^*31O,8@*+EWL_BDT;S&I5VL0:75I-&E
M2*3.J5VVH:JZN.JNQCNF<*I'N7>S^*31O,:X^ZKXL4ZF^Z7.I/&X^[QEM%2J
MNJJIK;$I`*?1L$^Q2[U8(#\`JTBE\Z=8P,NU^*2DI.FTP<3FINRJNJ[FIJ$`
MJNVSY@"D<+MY`*1PNWG#_JNL`*1PNWD`I'"[>2`R`+W7OL(`PN"Q2`#"X+%(
M.@"V;*7SPN"Q2*1WI[FFJ`"Q<2`E<R#"X+%(JKJV;*7S`*;;L,K"X*M(`*Q0
MM,&DK0"NV*Q;`$9R86YC92`HJFNPZBD`1G)A;F-E+"!-971R;W!O;&ET86X`
MIE[`LZ5II<ZNR;:AJKJ]T*A$`$9R96YC:"!'=6EA;F$@**IKQ-V[7*C(J+HI
M`$9R96YC:"!0;VQY;F5S:6$@**IKQ-VLP:=1I:>FZ*C(*0!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`L4BE\Z1(7VT`L4BE\Z1(`+%(I?.D2*9AIWT`
ML7$`I[F^X[1YK7H`NJ&DZP"E_J97`,+@L4@Z`,+@L4@Z(`#"X+%(.B"D=\+@
ML4@@)74@J\JV;*7S`$=A8F]N("BE6[1>*0##P+19.@!'86UB:6$@**7,I/&H
MR"D`I$"OZ[_OMK4`LJ.ES2`E<R"MTZATLLZS7:EW`*1WLJ.ES:JZLUVI=[CJ
MKL8`1V5O<F=I82`HL^RJ=JC(ID"I3;#J*0!'97)M86YY("B\=[#J*0"E=<6J
MJ/JX^[=SJKJV;*7S*+;(OD&ESJGS($E-05`@IOBJ0;ZY*0!':&%N82`HK7NO
MQRD`1VEB<F%L=&%R("BJO:6LP[FJ^RD`IE>ZV0"K9:FY`*9>K>RK2*7S`*CL
M(B5S(K-QL%2__;!/O_TN`*WTO'>ZN`!';V]G;&4@IF&YSP!';V]G;&4@MVJT
M30"]X:2IQ7:MK0"FQ[:E`$=R965C92`HI\;#OBD`I\;#OJ3E("A)4T\M.#@U
M.2TW*0!'<F5E;FQA;F0@**[FLZ[$]:YQ*0!G<F5N861A("BNYK?GK\>Y1BD`
MN'.RU;K>LGH`N'.RU:97NMFDH[%OJL6EU0!'<F]U<%]L9&%P.B"U3*IKMW.\
M5[ASLM4@)7,N(*;XJD&^N:9>P+,Z(`!'<F]U<%]L9&%P.B"U3*IKIU*PH[AS
MLM4@)7,`1W)O=7!?;&1A<#H@M4RJ:Z?SMW.X<[+5("5S`+ASLM4`1W5A9&5L
M;W5P92`HK?2\=ZREM+8I`$=U86T@*,/VKG$I`$=U871E;6%L82`HI<JF8;"H
MJ=0I`*[FKJ:FZ*YQ`*C3NZO%=JVM`+-8J\BO9*BE`$=U:6YE82`HM%BDNJC(
M*0!'=6EN96$M0FES<V%U("BT6*2ZJ,BD\:_!ID"I3;#J*0!'=7EA;F$@*+M<
MJ,BHNBD`LV^XS`"V5Z3ELW.ULKMYJ*4`2%1-3""NYJ:AMFRE\P"GY*2CJ.P@
M2%144"#%Y\/2+@!(86ET:2`HKORF82D`POBTZBVZ=+KB`,9'`*KMP%D`JNW`
M60!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`I&JY<*M"`*?&
MIT*HTZ3E("A)4T\M.#@U.2TX+4DI`+"JJ]<`NZ&I^@"]<[_HOKFHSZ7.NZ&I
M^@"[H:GZ`*5BLGD`LV^XS*Q/P,FNUZJZMGVI;#H`I4BD5:Q/IT&JNK9LI?.]
M<[_HI+JN93H`P?3"PP#!],+#J?/#]L%PP,NU^*2D`,'TPL.D=Z=2L*,`P?3"
MPZ6\K7&^7`"PJ@"PJL!UI?T`L\RPJ@"N85]M`$AO;'D@4V5E("BQZ[_-J:,I
M`*YA`*;MKF&F8:=]`*YAI=B__0"F[:YAN7&XW`!(;VYD=7)A<R`HI[NSHZG4
MM+4I`$AO;F<@2V]N9R`HK;NTY"D`2&]R9&4`2&]R9&4O2V]L86(Z(+9LI?,@
M)3(D<R"DI+E*J.RU3*[$JKH@)3$D<R!834RXZJ[&`$AO<F1E+TMO;&%B.B"U
M3+9LI?.^0:98JJNE\R`E<P!(;W)D92]+;VQA8CH@MFRE\R`E,B1S(*2DI^2D
MHZCLJJNE\ZNLND$@)3$D<P!(;W)D92]+;VQA8CH@I'>FJ*5<JKJROK"C("5S
M("(E<R(`2&]R9&4O2V]L86(Z(+[CIEBD=;5[N]VM;B`G9&]M>&UL)R"JNB!0
M2%`@J;6F^0!(;W)D92]+;VQA8CH@M4RJ:ZO8I=\@)7,@JJNE\ZJZ(%A-3""^
M\`!(;W)D92]+;VQA8CH@M4RJ:[*^L*,@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(+5,JFO`\JCZLZ&E]R`E<R"KK+I!JKH@34E-12##T:=/N+F]6`!(;W)D
M92]+;VQA8CH@M4RJ:Z90J$(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(+5,
MJFNF4*A"I,"HR3H@)7,`2&]R9&4O2V]L86(Z(*6\JKZJNJ3`J,D@(B5S(@"D
M]*6MO74`I/2EK;G4I5(`I/2EK3H`IT&F<*;SJ.RFN2`_("B]T+'4K7HA*0"G
M0:6TNN*F<*;SQ>.EW*K^I5O`R:[7J4\_`*=!K6ZF6*C6IFBDUJW3Q.:F[*E/
M/P#$YJ;LO,:EV*9`K7`_`*=!K6ZF6*C6IFBDUJ9#J4\_`*9PIO.I=[AQIE["
MT*3EI?.JNJ3>K7JF0P"WPZO7`+?#J]<Z(`"WQKU=I&JN=@!(=6YG87)Y("BF
M2:3ZIU$I`$E-05``24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*0!)34%0
M(*;XJD&^N</VLZRS<[6R+B"F^*I!OKFF7L"S.B`E<P!)34%0(+9LO6.KV*7?
MI:*QT3H@)7,`24U!4""V;+UCIU*PHZ6BL=$Z("5S`$E-05`@MFR]8[K/NM"P
M=+AMJ]BEWZ6BL=$Z("5S`$E-05`@;W9E<B!34TP`24U!4"!O=F5R(%-33"`H
M<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I`$E-05`@;W9E<B!34TP@*'-E;&8M
M<VEG;F5D*0!)34%0(*;XJD&^N</VLZRS<[6R+@!)34%0+"!N;R!43%,`24U!
M4"]03U`S(+9LI?.F^*I!OKD`IJRE\Z=8`$E0(*;LIWT`25`@INRG?;5,JFNH
MSZ7.+@!)4""F[*=]J,.DHZ9B($-)1%(@JKJDN;-<L,^V]*2D+@"F8JOAK;&T
MH:1*ID-?;@!)8V5L86YD("BF0JYQ*0"OPKG/I=P`)7.JNKG/I=P`N<^EW*3.
MI.6F<@"HK:7WP]&G3ZJZIE>ZV3H`IG"J1[5,JFNEO[U4IF'%XZ7<+"`E<R"E
M2*5TMGVQTK9LI?.I\[=SM?BUH;?MI*0N`*9PL?VHSZ7.(%-33""ISB!43%,@
MI5NQ2[-SM;(N(%!(4""ELK:WI?VX_*1*(&]P96YS<VP@J;6F^2X`IG"J1\1^
MQ/(LJTBE\Z=8I*2JNJG2IK.V;*7SL4Z_\J6B(0"HSZ7.($EN=&5R;F5T($5X
M<&QO<F5R(,)SQ/V^N:[)IG"J1ZA3IK.LW:CLI?2F\ZJZI'"YSZ7<+""G0:5I
MK^"[W:UNI,2_[[-OK=.VM:78I4C#]K.L(%!.1R"\=KFSJKK!],+#KL2J1RX`
MIG"J1ZS=J.RS;ZMHJ%.FL[QVN;.JNK!4KJ<LLV^J[:7<IT&JNL)SQ/V^N;5,
MJFO%XZ7<I%>VQZJZO':YLRX`J;^RI`"IO[*DJ=*FLP"YSZ3Y`+QVN;.Y=\3]
M.@"\=KFSNO2G?0"\=KFSNO2G?3H`O':YLZC3IMO#P+19`+QVN;.HTZ;;P\"T
M63H`I%>VQ[QVN;,`O':YLP"VUZ1*`+;7I$JJ]\9?`+;7I$JJ]\9?N>\`MM>D
M2K9LI?,`MM>D2B!01U`@JO?&7P"VUZ1*K=.D2+[,P](N`+;7I$JMTZ1(JKH@
M4$=0(*APL4NJ]\9?+@"VUZ1*K=.D2*JZ(%!'4""DO;9]JO?&7RX`MM>D2JW3
MI$@@4R]-24U%(+[,P](N`+;7I$JDO;9]JO?&7P"VUZ1*(%!'4""DO;9]JO?&
M7P"VUZ1*(%,O34E-12"DO;9]JO?&7RX`MM>D2B!3+TU)344@JO?&7P"VUZ1*
M(&UB;W@@P,FNUP"VUZ1*(&UB;W@@P,FNUR`E<R"H[*M(I?.G6"`E<R"DI"X`
MMM>D2BP@J$+&2B`E9`"MJZUN`*VKK6ZV;*7S`*1WMM>D2B`E9""KRK9LI?.F
MVR`E<R`N`+;7I$K$YJ;L.B`E<P"VUZ1*Q.:F[#H`MFFFYJ2D`*9BJ^&ML;2A
MI$JF0U]S`*:LI?.G6`"F7L+0KLFE7:Q!O-#`6;I+K6X_`*9>PM"NR:5=K$&M
M[*ELI.6E\S\`O^FD2J2CI;^]5*JZIT"ESKU8+@"]T,#+K&2G0:JZJ,^ESJK,
MIE>ZV:3.L4N]6`"HSZ7.JLRF5[K9I*.EO[U4J<ZJS+EQI&RV;*7SINVG?:1W
MQ=RG\RZ]T,%PM;BG0:JZJ'2RSKK>LGJM^Z5(J/.G5;-"LGHN`+Q7I5O!6;'&
M`$EN9&EA("BF3*O7*0"MTZ=/J,^ESJK,`$EN9&]N97-I82`HIDREIRD`N.JP
M5`"XZK!4`+5,I6FESJJZN.JP5"X`I+VV?:KWQE\@)7,@JKJXZK!4`*W3I$BH
M<+%+JO?&7[CJL%0N`*W3I$BDO;9]JO?&7[CJL%0N`*J]L;7%XZ7<J?.ENZ3E
ML,\`IF*KX:VQM*&D2L3FINQ?;P"F8J:YM*&D2K[,P]*XZJ[&`+2AI$JYSZ3Y
M`*9BIKFTH:1*K=.D2*JZ(%!'4""H<+%+JO?&7RX`IF*FN;2AI$JMTZ1(JKH@
M4$=0(*2]MGVJ]\9?+@"F8J:YM*&D2B!01U`@I+VV?:KWQE\`M*&D2JKMKN8`
MM*&D2KKTN/2S<[6R`*9BJV6ML;2AI$K$YJ;L7T,`IF*EV*MEQ.:F[*OAK;&T
MH:1*I$"MT[=SQ.:F[`"F8J78JV7$YJ;LJV6ML;2AI$JD0*W3MW/$YJ;L`*9B
MI=BK9:9#J^&ML;2AI$JD0*W3MW.F0P"F8J78JV6F0ZMEK;&TH:1*I$"MT[=S
MID,`IF*EV*MEN&#"2:OAK;&TH:1*I$"MTZQQN*@`IF*EV*MEN&#"2:MEK;&T
MH:1*I$"MTZQQN*@`M*&D2J5IM,"E3KS+JD\`MW.Q2[U8L4ZQ2+5OJ.RS;ZW3
MMFRE\Z9AIWTZ`*9BJ^&ML;2AI$K`>*9SKN8`IF*K9:VQM*&D2L!XIG.NY@"F
M8JOAK;&TH:1*Q.:F[`"F8JMEK;&TH:1*Q.:F[`"TH:1*MFRE\P"F8JOAK;&T
MH:1*K'&XJ`"F8JMEK;&TH:1*K'&XJ`"F8JOAK;&TH:1*ID,`IF*K9:VQM*&D
M2J9#`*9WI?ZPW:5YJKJUJJ[7.@"TH:1*+\7<I_.\=KFS`+2AI$HOQ=RG\[KT
MN/2S<[6R`,))O,:DHZBLI4BFW*GSM4RJ:[;'L&6UN;!TN&VX<[+5+@#"2;S&
MI*.HK"X`ON.\Q@"^X[S&ID,`J=*_[[[<JKJG0*7.I.BFH;GOIKFDN*7SM4RN
MQ"X`I*.F6*IKJKJF[:=]`+5,KL2JNKNWNMVV;+UC`+5,KL2JNB!51$@HJ,^E
MSJK,N.JNQJKMP%DI+@"U3*[$JKH@6DE0(+CJKL8N`+5,KL2JNL"SI<ZU>Z:A
M+@"U3*[$JKJGY::XN+F]6"X`N7&D;+9LI?.F[:=].B`E<R"G=*:SM4RNQ*JZ
MIG*DN"X`L&6E6*JZN.JNQK5,KL0N`+5,KL2JNJ78O-"F[:=]`+5,KL2JNL#)
MKM>NYJ:A`+5,KL2JNJKWQE\`M4RNQ*JZL<+%=KU8+@"U3*[$JKJF8;#/+@"U
M3*[$JKH@;7-G7W1Y<&4N`+5,KL2JNJG.I^2DHZCL(&%P:5]I9"X`M4RNQ*JZ
MJ<ZGY*2CJ.RPT;S&+@"U3*[$JKJD]\5VK:TN`+5,KL2JNKG9IO'#T:=/O5@N
M`+5,KL2JNB!01U`@K=.D2*APL4NJ]\9?+@"U3*[$JKH@4$=0(*W3I$BDO;9]
MJO?&7RX`M4RNQ*JZLJ.K?KU8+@"U3*[$JKJS<;!4J/.I=RX`M4RNQ*JZIJRE
M\Z1(.B(E<R(`M4RNQ*JZI,"HR:JKI?,N`+5,KL2JNJC3M[VF[:=]+@"U3*[$
MJKJX5;#JO5BXZJ[&+@"XZK*C`*3/O^^^W`"F7K1?O^^^W`!)<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F("BE[*[4*0!)<F%Q("BE[*G4ITHI`$ER96QA;F0@
M*+=2NKC$]2D`27-L92!O9B!-86X@*+#2KG$I`*>]LZ&Y<*M"`$ES<F%E;"`H
MI4BFXJ9#*0##L;5OJLP`L=?%Z0!)=&%L>2`HN'&D:J=1*0!*86UA:6-A("BD
M^K92I5LI`*1`I.L`2F%P86X@**3II;LI`*3II.4@*$E33RTR,#(R+4I0*0"_
M0:;HKG$`2F]R9&%N("BL^:6Y*0"D0Z3K`*2[I.L`N>^[]`"X;:2D`*6JI6NY
M[[OT`+YAI:JY[[OT`+YAI6NY[[OT`$M"`$MA>F%K:'-T86X`JT^O9*WLO,L@
M/P!+96YY82`HJM:HR"D`2V5R8F5R;W,@NWO#TK_YNWXN`*[6I-^W<Z3B`*KW
MQE^KV*7?`*KWQE^O4[QX`*KWQE^J^*O7`*KWQE^KK+I!`*KWQE^[>:IK`*78
MJV6JNJ2]MGVJ]\9?IOBJ0;ZYI*0LI'>X9Z9SIF*G0:JZJO?&7RX`JO?&7ZJZ
MNW.G0*5IK^"[W:UNJN&D0*C'KLFVH:C3I[FFJ"X@K$^G7\1^Q/(@/P"J]\9?
MMM>D2K5,KL0N(*;XJD&^N:6\L=*ESL#)KM>D5[;'I5ROX"X`JO?&7[;7I$JU
M3*[$+B"W<[Q7P7"UN*1(I;RK_*EWN7>S7;-QL%2__2X`JO?&7Z1WIJBE7*JZ
MML>P9:;<I+VV?:KWQE^F^*I!OKDN`*C@M:,`2VER:6)A=&D@*+#RJ+VDVK2U
M*0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B`HI5_!
M^BD`2V]R96$L(%)E<'5B;&EC(&]F("BK;L'Z*0#!^J3E("A%54,M2U(I`$MU
M=V%I="`HK.RKPJ]3*0!+>7)G>7IS=&%N`*JIK;&P=+AM7WD`NWFHI0!,86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R`HO&2PZBD`I%6E8J3K`*M(
MI?.G6*JZL\RKX:1`K;8`L\RKX:1`K;8`L\RJ\:1`IKBQ2[U8Q=RG\ZGS`*15
MJ;:DZP"D5Z:XI_.W<SH`I%>D0*:XM6ZD2CH@)7,`I%>D0*:XM6ZD2CH@)7,@
MIML@)7,`I%>D0*:XM6ZD2CH@LL2D0*:XM6ZD2@!,871V:6$@**G4LN:Z^ZC(
M*0"J:ZO?`*JIK;&P=+AM`$QE8F%N;VX@*+ZDI-JYX"D`I:K#Y`"EJL/DJNW`
M60"EJL/DK<@`3&5S;W1H;R`HO^"OP::K*0!,:6)E<FEA("B_X*3QM^>HR"D`
M3&EB>6%N($%R86(@2F%M86AI<FEY82`HIU&D\:C(*0!,:65C:'1E;G-T96EN
M("BF0Z3DM+"TM;5N*0"W3*M"`*1PJT(`IJVFLZ1PJT(`L=^FLZ1PJT(`I'"P
M?:M"`*1PJT*FL[EP`*1PL[<`I'"P?;.W`*6TJF^XU@"S<[6R`*K^I?/"X*9S
MNO2G?3\`LW.ULL))J.PZ`,7CI=RNR;-SM;*V;*7SINVG?:CLO7.\9[9LI?.M
MMJVQ`+5,JFNF<ZCZI'?"X*9SK+"Z]*=]JKJJ_J7S+@"S<[6R`*:SKL2DZ:;<
M)7.LL*3N`*9#I5@@+2"HSZ7.JLRE::5(K-VH[+-OK=.K2*7SIU@`ID.E6+CJ
MKL:N=P"F0Z58NZ&I^KS0PT0`ID.E6*KMKN8`O7.\9[9LI?.NR2RF8K-QL%2_
M_;5EK;&DI,7CI=RITJ:SP7"UN*1(/R`HIG"J1Z2CI,2_[Z:YMK4LLW&P5+_]
MM66ML;;(Q>.EW+M0MVJT3:S;LL6JNKCJKL8I`+!1O=>X<[+5+<#)KM?"9`"P
M4;W7N'.RU2VH1*=5`+!1O=>X<[+5+</1IT^XN;U8`+!1O=>X<[+5+;[6IK.J
MS`"P4;W7N'.RU2VQ2*7SI$@`L%&]U[ASLM4MK7&^7`"P4;W7N'.RU2VH^J[X
MK7&^7`"F8JKMP%FDI*9#JNT`ID.E6+=\M,&EHK'1.B`E<P"F0Z58J,^ESJK,
MI:*QT3H@)7,`ID.E6*C/I<ZJS*JZI5ROX+-1P_:SK`"DY;['`$QI=&AU86YI
M82`HI=^SLZE[*0"X_*1*I*0N+BX`L4[%JJCZJKJE?K.AMFRE\RRI\;AMJ?.D
M5:9#JKJENZ9AMFR]8SH`M^VF8:[)MJ$Z(`"F8;#/NU"NR;:A`*;LN&T`M6ZD
M2@"U;J1*J.P@)7,`M6ZE6`"U;J1*`+5NI$JD=:=``+5NI$JEHK'1+""]T,#+
MK&2[U:15JKJESJ3AIE>I3;%+O5@L(+5-J^&MJ[C5+@"U;J1*I:*QT2X`JOBE
M>0"W4K&A`*=#`*=#P'6E_0"D<+QGI\;#OKS&IG(`I'"\9ZG4I$*\QJ9R`*1P
MO&?#N;"HO,:F<@"SS*=#`$QU>&5M8F]U<F<@*+]CM,NS^2D`I.L`J$.DZ;!4
MKJ<`35,M5$Y%1B"J_J5;P,FNUZ2DJ%.FL[CJKL8N`$U31P!-86-A;R`HOT2J
M^2D`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M("BPJ*CDN7FF0*E-L.HI`+/!JO>V\,#)KM<`36%D86=A<V-A<B`HL*BY1J5;
MM+6E6RD`Q5VS3@"Z]+CTMFRGO0"V;*7SNMZR>@"V;*7SN7?$_0"Q_;-SL;6J
MNK9LI?.F^*I!OKFKK+I!.@"V;+UC`+9LO6.DSJM(I?.G6,7CI=R_[[:U`*O8
MI=^S<[6R7VLN+BX`36%L87=I("BPJ*G4J\(I`$UA;&%Y<VEA("BPJ*C3INBH
MR"D`36%L9&EV97,@*+"HNKBF8:32*0!-86QI("BPJ*=1*0!-86QT82`HL*BZ
MN*5,*0"ZWK)ZIT&JNJ3`P_XLJ,.E0JRPI,##_K-=J7?#0Z;B+@!-87`R-""F
M8;G/`$UA<%%U97-T(*9AN<\`I%2DZP##Y*S)`+S0L$^ITJ:SJTBE\ZRPK-VY
M3`"\T+!/J=*FLZM(I?.LL*6\K-VY3`"\T+!/IJ@Z`*5(I*.F4*JZPT.FXK#/
MN6JF7L+0I.6SN3\`L4ZV;*7SO-"P3Z:HI'>LW;E,*+;(OD&ESJGS($E-05`@
MIOBJ0;ZY*0"\T+!/PK*SYKC+N:(@/P"\T+!/IJ@@K-VY3"^EO*S=N4P`O-"P
M3Z:HJ.2E3*JZP]&G3R`HJ-*F<"X@K:NM;B^D=Z9>PM`I`$UA<G-H86QL($ES
M;&%N9',@*+"HKDRZN+ASKG$I`$UA<G1I;FEQ=64@*+"HM*.EIZ=*KG$I`*3'
ML'2ITJ:SJKJL9+C?`*3'L'2E]*1`K&2XWP"DQ[!TQ.:F[*2D`$UA=7)I=&%N
M:6$@**U4IU&V\*6GJ,@I`$UA=7)I=&EU<R`HO*^HO:;HM+4I`*2YLURJNK/,
MI&K"2;S&+@"J_J7SO,:EV*1WME>E6*2YLURD5ZVM+@"SS*KQ(#(T(*1PKLFJ
MNK/,L*JWQ:O7.B``L\RJ\2`V(*1PKLFJNK/,L*JWQ:O7.B``JOZE\Z2YLURD
M5ZVM`*M(I?.G6*17K:V\QJ78`+#/MO2D5ZVMO,:EV`"DN;-<L\RD:JKXJ]<`
MJOZE\[S&I=BD=[E&I%>MK2X`JOZE\Z1JI'"D=[E&I%>MK2X`I*VDZP!-87EO
M='1E("BPJ*SYKU.N<2D`PN6^QP"FJ*W[`*M(I?.G6*9#JNT`O^^SYKS2IJ$Z
M`*98J-;`>*9SKN8`MFRE\P"V;*7SO&>G0`"V;*7SI.FTP0"V;*7SO^^VM0"V
M;*7SMVJT30"V;*7SI&JD<`#`R[7XK>RI;,#)`+9LI?/%Y\/2I'>GN::H+*;]
MK$^HSZ7.JLRJNL.QL[FK;[5,JFNS<;E,Q>?#TBX`MFRE\\#+M?@`PK*P5*1W
MN4RTP2X`MFRE\[S0P]$`JTBE\Z=8`+9LI?.FVR`E<P"V;*7SI+JG=*K^I5O`
MR:[7`+9LI?.D=Z5;L4L`MFRE\Z1WP[&SN0"DQ[!TL?BE\P"V;*7SPN"G?;N\
ML&6FJ*5<+@"V;*7SN[RP9::HI5PLIOVI?*6\P'BF<Z;<("5S`+9LI?.[O+!E
MIJBE7"X`PK*P5*NLND$`J$.MML7CI=RJNK9LI?.\QJ78+@"V;*7SJ.P`365T
M87(@L,^V]+5,JFNHSZ7.+@!-971A<B"PS[;TM4RJ:ZC/I<XN(++3N&"]T+#1
MIM*H=++.NMZR>K5NO_TN`$UE=&%R1$(@J7REO+-SL;4N`*3HJFL`I.BJ:R`B
M)7,B(*6\LU&I=[AQ`*3HJFNEO*EWN'$N(*5(J4FE<Z3HJFLZ("5S`*2]J.X`
M365X:6-O("B^I:;HK?0I`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8@*+%+ITK#N:6GINBHR"D`I*2VH0!-:6UE(*NLND$`L\RJ\2`R-""D<*[)
MJKJSS*=#M\6KUSH@`+/,JO$@-B"D<*[)JKJSS+"JM\6KUSH@`+/,M76Q2[U8
MKL2TP:E\I;RH[+3!`*Q-KF<`POBVM0"GY*2CJ.P@4$5!4B"E7;C+($A45%!?
M4F5Q=65S="X`LUVI=\#)O_*EHBX@IG"J1ZUNJ,^ESK-OK=/`LZ7.M7NFH:=!
MI;*VM[)[IF*T3K*CI<VE3"X`I^2DHZCLPK*P5*JZ($E$+@"GY*2CJ.RELK:W
MJKH@4$5!4B"E7;C+($UA:6PN`*?DI*.H[+=\M,&JNB!)1"X`K%"TP:1``*;F
ML,JV;*7S`+?%J4T`I_.W<Z3IM,$`Q=RG\P"MUZ?ONO2G?0"\TK+5`$UO;&1O
M=F$L(%)E<'5B;&EC(&]F("B\K[JXIFBERRD`36]N86-O("B\KZ_'K?0I`$UO
M;F=O;&EA("B[6*5J*0"DZZ3.IGX`J$.DZP"[6+;KJ=2O4P"DZZS;`*9BLL0E
M9*;FI^2H[*JZQ.:F[+S&I=BD=[97I5BY=[3!)60N`*9BME>Y3*1`M:>JNJ9A
MIWVDI*?DJ.S$YJ;L("(E<R(N`+ROK*6M]`"F:+:SKLFTN`"F:+:SKLFSL0"T
MN*[)IFBVLP"W:+*^`*15LKX`I:JRO@"E:[*^`*17LKX`I%6RO@"W:+*^O'.G
M:;9LI?.H[+QSIVF]8ZG.L4ZDHZQ/O'.G::JZMFRE\[=HLKZH[*:LI?.]8Z2D
M`+=HLKZH[*M(I?.G6`"D5[*^`$UO>F%M8FEQ=64@*++VI%2D\:=**0"]QK_O
MIJ&D5:G4I5ROX*KM`*9HK:NRU::H+Z5IM,"E3@"V;*7SP,NU^`"]QK_O`*?:
MJKJQ8KBY`*?:JKJQ8KBYN.JP5`"MTZ1(K[BE>`"MTZ1(K[BE>*VVK;&P=+AM
M`$UY86YM87(@*+UQJ&PI`*2C+*?:I*.F4+=.`+5,`+/&M?D`IE>ZV0"F5[K9
M(*3.+ZG.(+EQI&RV;*7SINRG?:2CI6FLL*K%I=4`3F%M:6)I82`HJ+JFS*3Q
MJ,@I`$YA=7)U("B_U;Y\*0"[W:UNIT"ESJ3HIJ$`3F5P86P@**6GJGFZN"D`
M3F5T:&5R;&%N9',@*++\Q/4I`$YE=&AE<FQA;F1S($%N=&EL;&5S("BR_,3=
MIG>F8:9#M+4I`$YE='-C87!E(*RPL/+"IJJZNO2G?0!.971S8V%P92"^S,/2
MIT"\;[KTIWT`3F5T<V-A<&4@OLS#TJQ&M::Z]*=]`$YE='-C87!E(*?SMW.Z
M]*=]`$YE='-C87!E(*=`O&^Z]*=]`$YE='-C87!E(%-33""F^*I!OKFF5[K9
M`$YE='-C87!E(+[,P]*JNK7YN-$`3F5T<V-A<&4@OLS#TJNLND$`NO2X]*1U
MJ.,`I<.DHP"EPZ2CP'BF<ZK^I5O`R:[7`+=SJKH`3F5W($-A;&5D;VYI82`H
MMW.SV*B]IFBEIZC(*0"W<[Q7I,##_@"W<ZJZJTBE\Z=8`+=SMFRE\P"\9ZM(
M`+QGJTBUN2`E<P"W<Z3K`+=SJ,^ESJK,IE>ZV2`HJT2ELJUN*0!.97<@6F5A
M;&%N9"`HK\.FZ,3U*0"W<[9LI?,`MW.Q2[U8`+=SL4N]6+%.J?,E>*CLM,$N
M`+=SL4N]6*2CLL6F6"X`MW.U^+6A("A?8FQA;FLI`+=SNT0`MW.[1+ASLM4`
MI%6D0*A"`*15I$"KR@"D5:1`K;8`I%6D0*W3O^^VM0"D5:1`K;8`3FEC87)A
M9W5A("BEIZ5;J=2ERBD`3FEG97(@**6GI.DI`$YI9V5R:6$@**E@I,ZG4:C(
M*0"QWZ17`$YI=64@**_#KDJN<2D`IU\`I^2DHZCLOLS#TKCJKL8`MFRE\Z2C
MI5NQ2P#&7[#-P/2D5ZA3IK.E]*;SJO?&7P"H4Z:SMFRE\P"U3"!01U`@I+VV
M?:KWQE^S4;;7I$HN`*W3I$B^S,/2I*.F<Z9B+@"U3+EWQ/VDNJYE`*?DI*.H
M[*2]MGVJ]\9?`%,O34E-12"DO;9]JO?&7ZA3IK.VUZ1*+@"H4Z:SJOZE6\#)
MKM<N`+5,I6FHT<7CI=RN=+*GJKJS7:EWN.JNQBX`M4RE::7.JKJUIK*DJ]BS
M>2!)4T\@O':YLRX`J%.FLZ?EIKB\RZ:A+@"ITJO\J7>JNJ;LN&VD5ZA3IK.P
MS[;TIG.F8@"H4Z:SM*.HT:;FJ,:^Y*97NMFE2*C1($U#04P@Q>?#TBX`J%.F
ML\7<I_,N`+5,JFNF8J78JV7%=JVMI*2\5Z5;IKC%=JVM+@"H4Z:SJ_RI=ZJZ
M("5S(+-=J7>XZK!4+@"H4Z:SJ_RI=ZJZ($944"!61E,@LUVI=[CJL%0N`*A3
MIK.K_*EWJKH@4U%,(%9&4[-=J7>XZK!4+@"H4Z:SJ_RI=ZJZ(%-13"U&:6QE
M(%9&4[-=J7>XZK!4+@"U3+/1OFS"2;S&+@"EO+2CJ-&EV*JZ+@"DO;9]JO?&
M7Z2DI;RE7:=TN7&D;+9LI?.LV\/VN.JP5`#`R:[7I;RD5[;'`*E\I;R_[[[<
MJTBE\Z=8+@"ITJ:SP,NL9+E,JKJK2*7SIUBDI+.CJ%.FL[=SMFRE\RX`O="_
M[[[<J_RI=ZJZJTBE\Z=8`*A3IK.E7:=TMW.V;*7SJKJK2*7SIU@`J%.FLZ5=
MIW2EO*S=N4RV;*7SJKJK2*7SIU@`I^2DHZCLN<^EW"X`INRX;;CJL%2I?*6\
MLUVI=P"I?*6\M*.HT:;LN&VXZK!4+@"H4Z:SMFRE\Z2ZKF4`I;RTHZC1PK*P
M5"X`J%.FL[9LI?.RQ:98MVJT3;'XI?,N`*6\J_RI=Z97NMDN`*6\J_RI=[BY
MO5@N`*A3IK.K_*EWL4N]6*5(J-$@2%144"#%Y\/2+@"H4Z:SJ_RI=[%+O5BE
M2*C1($E-05`@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!+97)B97)O<R#%Y\/2
M+@"H4Z:SJ_RI=[%+O5BE2*C1($QO9VEN(,7GP](N`*A3IK.K_*EWL4N]6*5(
MJ-$@4$%34U=$(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@4TU"(,7GP](N`*6\
MO^FD2B!/<&5N4U-,(*1'I+BP]:;FP,FJNJ7^N/2N?"X@4$M#4R`Q,B"S5Z[F
MJKJE6[%+N.JNQKO=K6ZESJCLN-.U>Z:A+@"H4Z:SJ]V\9JJZM?FE5:73O=`N
M`%!'4""MTZ1(J'"Q2ZKWQE^H4Z:SLU&VUZ1*+@!01U`@K=.D2*2]MGVJ]\9?
MJ%.FL[-1MM>D2BX`4R]-24U%(*W3I$B^S,/2J%.FL[-1MM>D2BX`K\JDUJW3
MI$BH<+%+JO?&7Z9=IKFV;*7SM4RJ:[-1N-&Q2RX`NL^ZT+!TPT*EO+-=J7<`
MM4RNYKUU`*E\I;RK_*EWQ.:F[*3`N6JF<J2X+@"U3*[8O74`J_>F<L#+K&2U
M>Z:AI;RS7:EW+@"K]Z9RI;^]5`"U3*:YP,FNUP"KV,2S`*?DI*.H[*3DM*FJ
MNB!)34%0(+M[P]*DZ*:A+@"U3+S(IG.EV+_]I6FHT:?6J/HN`*E\I;RK_*EW
MJ,^ESJK,+@"EO+;'L&6HSZ7.JLRF5[K9J<ZQ2[U8+@"U3*5II<ZJNB!834P@
MN.JNQK-1ML>F7@"JQ:75K<@`K>RI;+-=J7?`R:2DI^2DHZCLJJFEN[CJL%0N
M(*VKMW.RHZ7-LUVI=\#)+@"F8J=!JKJS7:EWP,FDI*?DI*.H[*JII;NXZK!4
M+B"MJ[=SLJ.ES;-=J7?`R2X`JT2E6*YUJLP`I*._[[[<`+5,("AU<V4@:6UP
M;&EC:70I`*3IIM6PTJ3E("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0@
M*+_5NM:G2JYQ*0"D0*_K`*5?I6*R>0!.;W)T:&5R;B!-87)I86YA($ES;&%N
M9',`3F]R=V%Y("BNOZO"*0"K1*2GJ^$`JT2DIZME`*6\IU*PHP"K1*_SO5H`
MI*.MJZUN`*M$K=.D2`"DHZQ/I$"MTZ78O_T`M4RNQ*JZI+VV?:KWQE\N`*6\
MIU*PH[9LI?,`M7NFH:E\I;RGN::H+@"DHZVKK6ZV;*7S`*2CLUVI=P"EO+-1
MI.2TJ0"J8+=.++-OK=.PRJ=`I6FOX+O=K6ZF:*KAI$"HQZ[)MJ$`L\:GT;_]
M`*2PN_*D7:2CL+4`J%.FLZ5IPG/$_:JZ+*9>I6@N`+-QJKXZ(,+@IG.LL+KT
MIWVJNJK^I?.D=[-1I%6X_`"D4:1`I.L`O,:F<@"F<J2XO,8`IG*DN+QEJ]<`
MIG"J1ZA#I.NG4K"CI$"FN"RF:*36I.NE]Z1WPN"F<ZRPNO2G?:JZPL*J_J7S
ML4ZS4:M/IG,N`*9PJD>H0Z3KIU*PHZ1`IK@LIFBDUJ3KI?>JNL+"L4BE\[/&
MI?>G6+%.LU&K3Z9S+@"FYKS&`*?SMW.P=+AMN'.RU:[)I;RK_*EWO,:EV"X`
MO52[>P"IS@"JJZ7S`*JKI?.KV*7?JLP`I$NV::;L`*11I.L`O^RDO:O'`+=S
ML4N]6*6RMK>[4,+"L4N]6*2CIE`N`,+"MFRE\P#"PK%+O5@`PL*Q2[U8I*.E
MO[U4`,+"JKJQ2*7SL\:E]Z=8L4ZS4;)-JL4N`$]M86X@**K\L-(I`*5UIK,@
M24U!4""F^*I!OKFDY+2IJTBE\Z=8I,"HR:5<K^`N`*5UQ>.EW*5=IW2EO,6J
MJ/JV;*7SJKJK2*7SIU@@/P"E=:2YLURD0*W3MFRE\Z;MIWTN`*9!IKFG0*7.
MI.BFH:2DIT&VR*_@O^^^W*1`K=.K2*7SIU@N`*5UIK.^UJ:SJLR[4*ATLLZZ
MWK)ZK?NE::5(Q=RG\Z9`J,G%=JVM`+9]L=*K2*7SIUA?;`"F8K=SJKJU^+6A
MMGVQT@!/<&5N4U-,(+_YNWXZ(+5,JFNQ<2!3+TU)344@P[&SN:K^I?.XT;9]
MN.JNQBX`JTBE\Z=8I'>V?;'2`*9BMW.JNK7XM:&V?;'2LW.UL@"G0+=^J'2R
MS@"E6*YUJLPHJT2ELK:W*0"_[[:U`"5SO^^VM0"VM:78O7.XN0"RU<*T`++5
MPK2SYJ;L`++5PK0`K>RI;,"SI<ZU>Z:AO,NJ3P"F8B`E<SH@I*2JNJWLJ6R\
MRZI/+@"HY*5,`*CDI4RXZK!4`*CDI4R_[[:U`*CDI4R_[[:U`+9LI?.E?KN\
MIOBJ0;ZY`+[6IK.JS,5VK:T`4$%-(,7GP]*U3*[$+@!014%2.CJV;*7SIOBJ
M0;K=`%!'4`!01U`@O,:F[,.QL[D`4$=0(+9LI?.E6[%+`%!'4""E6[%+N.JN
MQ@!01U`@O_F[?CH@`%!'4""_^;M^.JW3I$BH<+%+JO?&7[O=K6ZFLZ1`LM6Q
M2[U8+@!01U`@O^^VM0!01U`@L4N]6+_II$H`4$=0(*W3I$BJ]\9?N>^ELK:W
MIK.F=Z7^J<JZ]+CTLW.ULJJZI.2TJ2X`4$=0(*2]MGVJ]\9?`%!'4""DO;9]
MJO?&7Z2ZKF4`(B5S("@E<RDB(*JZ4$=0(*2]MGVJ]\9?I'>W<[Q7I[FFJ"X`
M4$=0(*2]MGVJ]\9?("(E<R(@I'>G4K"CI[FFJ"X`4$=0(*2]MGVJ]\9?P/0`
M4$=0(+9LI?/#L;.Y`%!'4""V;*7SP[&SN2^V;*7SI5NQ2P!01U`@I'?#L;.Y
M+Z1WI5NQ2R"XZJ[&`%!'4""H<+%+JO?&7Z1WMW.\5Z>YIJ@N`%!'4""DO;9]
MJO?&7Z1WMW.\5Z>YIJ@N`%!'4""DY+2IJ,.EO*9BI;NH=++.I*2QTJ7.+@!0
M1U`@I.2TJ:C#I;RS4;'2I<XLJ=*E2+S&INS#L;.YM4RJ:[-1Q>?#TBX`4$=0
M(*3DM*FHPZ6\L=*ESBRV;*7SM4RJ:[-1N-&Q2RX`4$=0(*JZI.2TJ;O=K6ZH
MSZ7.PMN\=;7XM:$H<&]P=7`@=VEN9&]W<RDN(+"RIG"G0:JZPG/$_;ZYI=BK
M9:C#I;RQTJ7.N-.VM<+;O'6U^+6AI5ROX"R]T+'2I<ZEIJ=?JV@@4$=0(+%.
MM4RJ:Z=`I<XN`%!(4""U>Z:AO5@`4$A0(*_SO5H`I,BKX:1PJT(`I,BKX;!]
MJT(`I,BKX::SL[<`I,BKX;!]L[<`I,BKX;2X`*3(J^&Y<*M"`%!/4#,`4$]0
M,R`H075T;R!$971E8W0@4')O=&]C;VQS*0!03U`S(&]V97(@4U-,`%!/4#,@
M;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*0!03U`S(&]V97(@
M4U-,("AS96QF+7-I9VYE9"D`4$]0,RP@;F\@5$Q3`%!/4TE8(&5X=&5N<VEO
M;B"_\J6B`%!(4""O\[U:7T@`N=2E4@"RQ"`E9""MMJ9`("5D(*VV`++$I$"K
MRJ6\K-VY3*M(I?.JNJVVK;$`L\RKX:1`J\JEO*S=N4RK2*7SJKJMMJVQ`%!A
M:VES=&%N("BDVK#RM+6I6BD`4&%L874@**FMKULI`%!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960@**3:L,>TM:E:ION[XK#/*0!086YA;6$@**3:
MKK.PJ"D`4&%P=6$@3F5W($=U:6YE82`HI-JEK*C(MW.T6*2ZJ,@I`%!A<F%G
M=6%Y("BDVJG4IF,I`*K^I?,`IFBVLP"Q2[U8`+%+O5@HID&]5+M[*0"Q2[U8
MI'>FJ*5<J/BX_"X`L4N]6#H`L4N]6*2CI6FJQ:75`+%+O5BDHZ=KIE@`L4N]
M6`"Q2[U8Q=RG\Z>YIJ@N`+%+O5BDHZ6_O50`J%.FLZO\J7>Q2[U8I4BHT2!2
M041)55,@Q>?#TBX`L4N]6+U4NWL`L4N]6#H`L4N]6#H@`+%+O5BELK:WIVNF
M6"X`MDND5P"V2Z17`+CTKGP`J]V\9K5NO_VA1P"FJ*W[`*;*I,"D\0"P]:;F
MNOO%0+[>IT``J?.U;J1*J^&P]:;FNOO%0+[>IT`_`,5VK:T`(B5S(JJZQ7:M
MK:6\LU&G4K"C+@"F<ZCZOD2IV@#%=JVM`,5VK:VZWK)Z`*:YJ,^ESJK,JKK%
M=JVMM4RJ:\7<I_,N`*W3I$@`K=.D2+CJL%0`K=.D2"!01U`@JO?&7[GOI'>R
MHZ7-I[FFJ"X`K=.D2"!01U`@JO?&7Z1WIU*PHZ>YIJ@N`*W3I$@@4R]-24U%
M(+[,P]*H4Z:SLU&VUZ1*.B`@`*W3I$@@4R]-24U%(*KWQE^D=Z=2L*.GN::H
M+@!097)U("BOM;Y\*0##9*JK`%!H:6QI<'!I;F5S("BUX:O?NZLI`+EQN-P`
MP\"T60!0:71C86ER;@"YLZ_``+?MIE["T*3.PN"U;[9LI?.NR;%.P[&F5ZGQ
MIF*K2*7SI+JN9:JZMGVI;+-"/P"OPJ3EIG*NYJ:AJKJV;*7S`+?MMW.V;*7S
MJ.RY1J[)O+>I\:VUO-8_(*=!JKK"<\3]OKF[W:UNI.2TJ:VUO-:DNJYRP,FN
MURX@M;2D:K.AI,"F8K=,LVZ[4+/!JO>V\*JZPG/$_;ZYLZ.H4Z:SL-W#1"P@
MIOVHY*5,IT"W?JATLLZJNL)SQ/V^N:5IK^"[W:UNIG>XR[2AI?,H<&QU9VEN
M*2X`O="V::1*P'BF<Z[FPDF_[P"]T+U4J7>M;K*^L*.FN:2XI?,Z`+W0O52I
M=Z=!K6ZDI,)?IKFDN*7SJKJS<[6R+@"]T+_II$JD0*W3I.NE]Z3.IGZE]RX`
MO="_Z:1*MW.\5Z3`P_ZJNJ97NMDZ`+W0O^FD2J1`K=.W<ZM(I?.G6*JZIE>Z
MV3H`O="_Z:1*I$"MTZ:SKL2JNB!)4""F[*=]`+W0O^FD2J1`K=.FLZ[$JKJD
MZ;3!.Z3$O^^FN:3KI?>JNJ3IM,$N`+W0O^FD2J1`K=.FLZ[$JKJNR;:A+@"]
MT+_II$JW<ZM(I?.G6*JZIE>ZV3H`O="_Z:1*MW.JNJ97NMDZ`+W0O^FD2J=!
MJKH@4$=0(*W3I$BJ]\9?L4N]6"XE<[5NI$JTP;:ALZ.[W;_II$JD0*:X+@"]
MT+_II$JG0:JZ(%,O34E-12"MTZ1(JO?&7[%+O5@NJ$.FN+5NI$JTP;:A("5S
M(+.CN]V_Z:1*I$"FN"X`O="MJ[=SM6ZD2J5(Q'[$\KUSO^BG0:JZMFRE\RX@
MIG"J1\)SQ/V^N:C#I;RHSZ7.(&-O;VMI97,@IM.E0J=!K$^F8K=SJKJU^+6A
MI*2]<[_HMFRE\RRHNKW0IT&ELK:WK6ZF0:WLI?VU;J1*JKJU^+6AM66ML:9!
MI$"FN+5NI$HNI*>ITJ5(LV^[\K"UK$^LL*1&P=>G2\!BJ\C"ZJEWIT&JNK=\
MM,'#T:=/N+F]6"AS97-S:6]N($E$*2X@I*.K2Z2GLT+!V;W0J*.]S"X`O="T
MHZC1L-W#1*JZNDNM;BX`O="_Z:1*IT&JNK%+O5@N`+W0O^FD2J=!JKJHSZ7.
MJLRF5[K9I,ZQ2[U8`+W0O^FD2J=!JKJHSZ7.JLRF5[K9+@"]T+Y<Q:JD5:9#
MI+JN92ZG0:6RMK>F4+=.LV^HQZC&MK6D?J_@J,^ESJATLLXN`+W0K:NW<[_I
MI$JEO[U4JKJY<;9LIF&G?2X`O="_[[[<I$"MTZM(I?.G6`"]T+_OOMRFW*36
MI$"MTZM(I?.G6*C3MVJT30"]T+_OOMRVR*1`K=.K2*7SIU@`O="D5:G4O^^^
MW*G.O7._Z*5KP^2JNKCJKL:E2,%RM/HZ`+W0O^FD2K=SJKJDP,/^IE>ZV3H`
M4&]L86YD("BJ:<3U*0"L1JIV`*?KLKP`4&]R='5G86P@*+BRM>6D^BD`O':Y
MLZ;LN&T`JNVNYJ;LN&T`N[RP9;9LI?.H[+-OK=.K2*7SIU@@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*0!0;W=E<F5D(&)Y($AO<F1E`*9BIT&JNL.QIE>K9:5;
MI$H@*"<M+2`G*3\`L\RJ\2`E<R"D<*[)JKJML*M"MG$Z(`"ML*M"/&)R("\^
MOO>R=@"_[[:UI'>GN::HI_.W<RX`4')E9G-?;&1A<#H@I^2DHZCLJ=*[W:UN
MJKH@3$1!4""IM:;YKDVE\RX`4')E9G-?<V5S<VEO;CH@I^2DHZCLJ=*[W:UN
MJKH@<V5S<VEO;B"IM:;YKDVE\RX`KO#`HP"N_*6MK;&N\,"C.B``KO#`HSH@
M`+EWQ/T`IF*W<ZJZM?BUH;EWQ/V\=KFS`*17I$"KRK9LI?,`I%>D0*VV`*17
MI$"MT[_OMK4`I,VUO:9#IDP`ID.F3*3EI?,`P'6E_0"H<+%+JO?&7P"H<+%+
MJO?&7[%+O5@`L-W#1`"PW<-$M'FM>@"Q3:[7`+2CI=RGVBRH0Z1`J\JE7:=T
MJOZE6\#)KM>JNJM(I?.Q2*58J^$[(+EWLUVLL*2CK6X`M*.EW*?:+*A#I$"K
MRJ5=IW2J_J5;P,FNUZJZJTBE\[%(I5BKX3L@N7>S7:RPK6X`M*.EW*2ZKF4`
MLW&K2*CSJ7<Z`*2]MGVJ]\9?`*2]MGVJ]\9?NG2ZX@"DO;9]JO?&7[CJL%0`
MI+VV?:KWQE^F^*I!OKFJNJ3DM*FD=[-1J/JN^"X`I+VV?2^H<+%+JO?&7[GO
MJ,.EO+-1LJ.ES2X`4'5E<G1O(%)I8V\@**IIIFB^I*95*0"R3;"CI'>G4K"C
M7V<`LDVPHZ1WIU*PHP"R3:K%JTBE\Z=8`*E5IZ.]8Z9HI%NR3;"CI$"FN#H`
MJ$.FN+[CLGJI5:>CO6.NR2RR3;"CIFBDUJ31O,:E2*MEJKJV;*7S+@"R3;"C
MJ56GH[UCI*2JNL+"MFRE\S\`IMNI5:>CO6.DI+)-L*,@)60@J\JV;*7S+@"F
MVZE5IZ.]8Z2DLDVPHR`Q(*O*MFRE\RX`46%T87(@**5DN48I`*QDN-\`NL^Z
MT+!TN&T`NL^ZT*K%MJ$Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2D`NL^Z
MT*K%MJ$Z("`E+C)F34(@+R"EO+-=K:T`NL^ZT*K%MJ$Z(*6\LUVMK0"DWJUZ
M("5F.@!24T$@I+VV?:KWQE\@*"5D(*;LI+@I`+_OOMRV<P"K0@"FK::SJT(`
ML=^FLZM"`+!]JT(`JT*FL[.W`*M"PN"SMP#`2+[WI'"[>0"D\;)V`,6JJ/H`
MQ:JH^K9LI?,`KW6JNJUNIU*PHR`E<R"VW#\@LV^VM;[>IT"Q3K5,JFNK[+1?
M+@"O=:JZK6ZR3;"CJ,^ESJK,("5S(*JZN.JNQK;<(#\@LV^VM;[>IT"Q3K5,
MJFNK[+1?+@"F8J:LI?.DZ;3!`+%QIJRE\Z3IM,&KX0"H[*:LI?.DZ;3!JV4`
MPN"G?;N\L&5?=`#"X*=]N[RP90#"X*=]N[RP90#"X*=]N[RP9::YMFRE\P#"
MX*=]N[RP9:6BL=$N`*CZKOBT7ZWL`*VKMW.^X[)Z`*VKMW.^X[)ZL,JZ0:78
MO_VDN*7S.@"G\[=SJTBE\Z=8P,NU^#H`K:NW<[[CLGJMTZ1(K[BE>*2ZKF4Z
M`+%@LU>J[:7<IJ$`P_;!<,)SQ/V^N0"MJ[=SQ:JH^@"G\[=SP,NU^`"U^[W7
M`+!/INVS;ZW3MWS$L[CJL%0N`+!/OM"SS*KQJKK%XZ7<I.BFH0"[M[K=MFR]
M8SH`N[>ZW:;XJD&^N0"[M[K=NO2G?2`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`+*^L*,`LKZPH[#/MO0`L7&W:K1-I*2ROK"CQ.:F[`"ROK"C
MQ.:F[`"E:+"CKN:FH0"ROK"CN>\`IMNF^*I!OKF\R*9SI=B__:2DLKZPHZ1W
MP'BF<ZJZLUVI=[5[IJ$N`+*^L*.S<;!4O_T`LKZPHP"FVZ3EI?.DI+*^L*.F
MN:1`N&#"20"ROK"CJ,^ESJK,`+*^L*.HSZ7.JLPZ("5S`*?SI^^F5[K9`*GS
MJ$.DZZKLI_.G[[%(I?.SQJ7WIUBJNJ97NMD_`+%.IE>ZV2`B)7,B(*?SIE>L
ML"`B)7,B(*6BL=$NIOBJ0;ZYIE[`LP"F7L+0M;FP4;W7N'.RU5]Y`*CZI4ZL
ML#H`IE["T`"F7L+0I'>VQ[!E`*9>PM"ITJ:S`*9>PM"ITJ:S.@"F7L+0M;FP
M4;W7N'.RU0"F7L+0M;FP4;W7N'.RU3H`IE["T*G2IK-?00"E2*6\I.2TJ:JZ
MMFRE\Z9>PM``IE["T*6\J-.D1ZW3I.NJNB!F<F5E+V)U<WD@N.JP5"X`I4BI
MTKW0J$2JNB!F<F5E+V)U<WD@N.JP5*9>PM`N`*9>PM"H[`"F7L+0J.PZ(`"F
M7L+0.@"S;Z2CK$^\<Z=IMFRE\P"S;ZQ/O'.G:;9LI?,`O="FK*7SI$BVQ[!E
MQ:JH^J9>L?A?4@"[W:A$I;RS4:9>P+,Z(+_YNWZXN;U8.@"]T*:LI?.D2+;'
ML&7%JJCZIEZQ^`"GY*2CJ.RV;*7S+@"GY*2CJ.RITKO=JKJJ0;#(+@`E,B1S
M(*JZLUVI=Z6RMK>K_*EW("(E,21S(@!61E,@JKJS7:EWI;*VMZO\J7<@(B5S
M(@"S7:EWN.JNQJ6RMK>K_*EW("(E<R(`I;*VM\3FINP`I;*VMZUNIK.E6*YU
MJLP`K:NS70"MJ[-=L4N]6`"MJ[-=IT&JNK%+O5@Z`*9>P+.JK+I!I'>G\[=S
M`*9>IG.SS*OAI$"MTZQDN-\`M;*J1P#$?L3RO7._Z`"MJ[=SM6ZD2@"F7B*V
M;*7SO&>G0+_OMK4B`*9>J.RE?K.AMFRE\P"F7JCLO^^VM0"W[:=2L*,L(+=H
MLKZISKW&NW.V;*7SKLDL(*9>J.RV;*7SP,NEW*9#`*9!IKB_Z:1*MW.Q2[U8
M`%)E=6YI;VX@**]DI:>I]*YQ*0"F7K1?LUVI=P"Z]*VVO7._Z+ZYO^^VM0#!
MO+MY`*5KP^0`I6O#Y*KMP%D`I6O#Y*W(`*9#I+JN95]W+BXN`*BDIN(`4F]M
M86YI82`HP[FPJ*6GJ,@I`+';PN`@,3@P(*O7`+!FKLFP=R`Y,""KU[';PN``
MMK:NR;!W(#DP(*O7L=O"X`"F0Z2ZKF4`ID.DNJYE`*9#`*[FO74`Q.:F[+M0
MID.NYKUU`,3FINRNYKUU`*9#KN:]=0"P]:;F`%)U<W-I86X@1F5D97)A=&EO
M;B`HJUC#N;2U*0!2=V%N9&$@*+]CIG>Y1BD`4R]-24U%`%,O34E-12"E6[%+
MP[&SN0!3+TU)344@MFRE\Z5;L4L`MFRE\Z1WJ,^ESB!3+TU)344@I5NQ2P!3
M+TU)344@O_F[?CH@`%,O34E-12"_^;M^.JW3I$BH<+%+JO?&7[O=K6ZFLZ1`
MLM6Q2[U8+@!3+TU)344@O^^VM0!3+TU)344@L4N]6+_II$H`4R]-24U%(*W3
MI$BJ]\9?N>^ELK:WIK.F=Z7^J<JZ]+CTLW.ULJJZI.2TJ2X`(B5S(JJZ(%,O
M34E-12"DO;9]JO?&7Z1WIU*PHZ>YIJ@N`%,O34E-12"DO;9]JO?&7Z1WMW.\
M5Z>YIJ@N`%,O34E-12"DO;9]JO?&7\#T`%,O34E-12"DO;9]+ZAPL4NJ]\9?
MN>\LI'>W<[Q7I[FFJ"X`4R]-24U%(+9LI?/#L;.Y`%,O34E-12"V;*7SP[&S
MN2^V;*7SI5NQ2P!3+TU)344@I.2TJ:C#I;RF8J6[J'2RSJ2DL=*ESBX`4R]-
M24U%(*3DM*FHPZ6\L=*ESBRV;*7SM4RJ:[-1N-&Q2RX`4R]-24U%(*3DM*FH
MPZ6\L=*ESBRL2:5(O,:F[,.QL[FJNJM(I?.U3*IKQ>.EW"X`4R]-24U%(*3D
MM*FHPZ6\L=*ESBR\QJ;LP[&SN;5,JFNS4<7GP](N`%,O34E-12"JNJ3DM*F[
MW:UNJ,^ESL+;O'6U^+6A*'!O<'5P('=I;F1O=W,I+B"PLJ9PIT&JNL)SQ/V^
MN:78JV6HPZ6\L=*ESKC3MK7"V[QUM?BUH:5<K^`LO="QTJ7.I::G7ZMH(%,O
M34E-12"Q3K5,JFNG0*7.+@!305-,(,7GP]*U3*[$+@#"LK!4`+CJKL:N=Z_S
MO5H`I5NQ2[+7NMV^]P"FJ*5<`+CJKL:N=Z_SO5I?40"E1*:N7W4`K%"TP:2[
M`+%(I?.SQJ7WJ?-?=@"E=*9SMW/`R5]V`%-A:6YT($AE;&5N82`HN'2[KK#'
MK\<I`%-A:6YT($MI='1S(&%N9"!.979I<R`HN'2G2JB]M+6F:+K6I,ZEI[K[
MM+4I`%-A:6YT($QU8VEA("BX=,53INBHR"D`4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R`HN'2D
MY;3+I,ZNYK?GJ+JD0BD`IE"D0*W3M?BUH2`H7W-E;&8I`%-A;6]A("C"Q+RO
MJ,BX<ZYQ*0!386X@36%R:6YO("BX=+"HIU&_U2D`4V%O(%1O;64@86YD(%!R
M:6YC:7!E("BX=*9HK/RDSK2VJDRFZ*3Q*0"]PZQ0M*.HT:K,`%-A=61I($%R
M86)I82`HJ$:O4:9AJORIU*="*0#`>*9S`,!XIG,@(B5S(@#`>*9S("5S`*K^
MI?.L3Z=?P$BUV[%(I?.D0+!?L\:E]R`_`*9SK+"O\[U:`,!XIG.YSZ3Y`,!X
MIG.H[,/`M%FDI`#`>*9SO^^VM0#`>*9SJTBZX`"F<ZRPK_.]6E]$`*5TIG.W
M<\#)`+%.P'BF<ZJZK_.]6KS0L$^FJ*6\K-VY3"X`L4ZRHZ7-JKJS7:EWP,FE
M2"!02%`@NWFHI:[FIJ'`>*9SJ.RG0:JZIOBJ0;ZYO,BF<Z78O_VDI"X`L4BG
MN:M(I?.KX2RFV[#*L4ZXT[%(I?.DI*G2IK.FK*7SN>^V2*JZIF&G?2S`>*9S
MJ.RY=[-=JKJS<;!4O_VDI"`_`,!XIG.W:K1-JTBE\Z:HI$"MT[7JP,"K2*7S
MIU@@/P#`>*9SL4BE\S\`LUVI=R`E<R"D=\!XIG,N`*?SMW.U>Z:AI'?`>*9S
MJ.PZ("(E<R(N`,!XIG.O\[U:I:*QT2X@IOBJ0;ZYIE[`LSH@)7,`N7.L4+EP
MJT(`K.R^QP"W:K1-`+=JM$T@)7,`MVJT3:3>P+H`MVJT3;_OMK4`MVJT3;6R
MJD<`K-VY3`"_[[[<`+_OOMRE=*1`K=.Q8KBY`+_OOMS`R:[7`+_OOMRD0*W3
MI.FTP0"_[[[<I$"MT\3FINP`O^^^W*1`K=.X<[+5I<ZE2+=SO%<`O^^^W*1`
MINRW<ZJZOM:FLZK,`+_OOMRD0+.AIOBJ0;ZY`+_OOMRD0*W3JTBZX#H`O^^^
MW*1`INRHSZ7.JLRESJ5(MW.\5P"_[[[<LW&P5+_]I4BW:K1-I,ZW<[Q7IF&G
M?2X`O^^^W*G2IK,`O^^^W*G2IK.DZ;3!I+BE\RX`M^VP]:;FJ6VF5\%RM/JN
MR:%!O^^^W*G2IK/$YJ;LI4BG4;=JM$TN`+_OOMRD0*W3L6*XN0"_[[[<I$"M
MTZJKI?,`I*._[[[<`*GSI4BD5:JZM?BUH:2DO^^H^J=!K6ZJNJ9RI+@NI4BW
MQKFKO<:[<ZG2O^^DY:9R++5-J^&V2Z17I.6E\[USO^BPSRX`O^^^W*3IM,&D
MP+EJ.@"_[[[<I.FTP:3IM,&NYJ:A.@"_[[[<P\"T6:5(P'BF<[G/I/D`O^^^
MW+']Q=RG\ZJZJ*VE]\/1IT\Z`+_OOMRF^*I!OKFJNJNLND$`O^^^W*[)MJ&D
MP+EJ.@"_[[[<I.FTP:[)MJ&NYJ:A.@"_[[[<K-NDK*3'L'2JNJ1'K=/$YJ;L
M+@"_[[[<IT&JNL-#IN*P=+AM`+_OOMRPOJ9NNWFHI3H`I'>_[[[<JKJS<;!4
MO_TZ`+;'L&6J]\9?IMRDO;9]JO?&7Z;XJD&^N0"VQ[!EL\RW<ZJZN.JP5`"V
MQ[!EMFRE\P"VQ[!EL-W#1*3/P+,`ML>P9<*RL%0`M^VQ2*7SJLRM;JA$ML>P
M9:9>L?BNR<7CI=RTHZ7<(#\`4V5N96=A;"`HMNNDNJ5;NK@I`+=0M/J^N3H@
M`+%(I?.SQJ7WIU@`L4BE\[/&I?>G6#H`I$6DZP!397)B:6$@86YD($UO;G1E
M;F5G<F\@*+;KNKBZ^ZC(NU"[6*]3I:>M],.Y*0"GQ[BY`*;XJD&^N0"F^*I!
MOKFDSJM(I?.G6+CJL%0`IOBJ0;ZYN.JNQK_YNWZISJK,M4RJ:ZC/I<XN`*;X
MJD&^N3H`MWRTP;K>LGH`MWRTP2!)1""D=[E,M,$N`+=\M,$`KM:H^J3HMO0`
MI+FS7*=!J?.GT;!/L4N]6*JZKLFMU"RE::5(IMNFYJVKLUVQ2[U8+@"S7:EW
MJ$.W[;O5I%6W:+*^J4VG4K"CMFRE\Z[)JKJPOJ9N+@"]<[QGMW.V;*7SKLDL
MK$^G7Z2YLURS7:EWJ.3`=:7](#\`LUVI=[NWNMVF^*I!OKFD5\3=J?.G0:JZ
MK=.D2*^XI7@N`+-=J7>G0:JZL+ZF;KMYJ*4L(*[)L,^E2*3.I.FTP:[FIJ$N
M`+-=J7>G0:JZL=*I;,"SI<ZU>Z:A+,-#IN*P=+AM+*VVK;&G\[=SP%>R=BRD
MSJCDI4S%XZ7<O^^VM2X`LUVI=P"G\[=SM7NFH;1.NOP`IK.F;K18K=.F8<))
MJ4VS;ZW3L-&\QJ:SP_8Z(`!397EC:&5L;&5S("BVZZGUNK@I`*3`J,FK2*7S
MIU@`I,"HR:M(I?.G6`"V?:GQIT&JNJM(I?.G6,7]J.2E3*1(I6FE2*C/I<XN
M`,'*JJL`PK*U=;I+K6X`K$^G7ZRPI&JSH:7WJKJS<[6RJ7>X<:?6L;:E7*_@
MP>0_`*9PJD>K2*7SI+JN9:=TIK.D:KUGM%2JNJ3>K7JDY:9R++?MMGVQTKC3
MJTBE\Z[)N7>S7:RPQ>.EW*G.JLS!],+#I-ZM>B`_`*Q/IU^QO;K+MFRE\Z2Z
MKF4H=&5X="]P;&%I;BFDI*JZ(%!'4""XZJ[&/P"W[;=SMFRE\Z9SI$JO\[U:
MIZBKX:Q/IU_#]K.LO7.\9[9LI?.U^+6A/P"H0ZO*I7ZQ2+9LI?.GH:K^I%<@
M4$=0(*2]MGVJ]\9?/P#%XZ7<`,7CI=RITJ:SJTBE\Z=8`,7CI=RV;*7SJNW`
M60#%XZ7<I'>G4K"C`,'TPL.V;*7SJNW`60#%XZ7<L%&]U[ASLM6XZK!4`*5U
MQ>.EW*1WK7&^7*JZJTBE\Z=8`,7CI=REO*UQOEP`K$^G7Z9BMFRE\Z2DQ>.E
MW*1`K=.ESJC3I6BPHZK^I?.JNKG/I=P_`,7CI=RW<[*CI<V[4*WLP'BF<[-=
MJ7?`R:JZKG2RIRX`J$.FN+5NI$JKX<7CI=RD5Z1`IKBJNK5NI$JNR;:A(#\`
MIF*V;+UCP,NU^*2DQ>.EW*95P_ZV;*7SN<^EW*JZNZ&I^C\`Q>.EW,))O^^^
MN0"E=::SI;RLW;E,JKJV;*7SI'ZY=\3]Q>.EW#\`M^VWQKFKJ_R\T+*^IMRE
M1*:NQ.:F[*[)N7?$_<7CI=P_`,7CI=RJ[:[FOMZG0*5<K^"J[2`_`*GSI:K#
MY,7CI=P@)7,@I5ROX*KM/P"F8J5<K^"J[:2DQ>.EW"`GI7ZSH;9LI?,G(*:Y
MI$"S<[6R/P#%XZ7<N<^D^0#%XZ7<P'BF<Z[FI+JN9;GON-RDZ+;T`,7CI=RJ
M[:[FI+JN9;GON-RDZ+;T`,7CI=RF0Z2ZKF6Y[[C<I.BV]`"F8J5<K^"J[:2D
MQ>.EW+E,PF^^N;G/IJ$_`,7CI=R\=KFSI+JN9;GON-RDZ+;T`,7CI=RK2*7S
MIUBDI*JZJTBE\\%@O,8@/P#%XZ7<I%>VQP"K^<3RL'VK0@"FK::SL'VK0@"Q
MWZ:SL'VK0@"[MZ3HIK.P?:M"`,7CI=P`IJS!60"D:J1P7WH`4VEE<G)A($QE
M;VYE("BWX*1LI'.PZBD`M?FE50##L;.Y`,.QL[FZ=+KB`*1WP[&SN0!3:6YG
M87!O<F4@*+=SI5NI62D`I&JD<`"RI+E,NOO%0`!3;&]V86MI82`HM+6LI:7O
MITHI`%-L;W9E;FEA("BTM:REI>^EIZC(*0"SMP"P?;.W`+!]L[<`IJVFL[!]
ML[<`L=^FL[!]L[<`OVZSM[)@J]<Z(`!3;VQO;6]N($ES;&%N9',@**_!P[FJ
M^;ASKG$I`%-O;6%L:6$@**_!L*BG4:C(*0"Z<;M0N-8`J.RY1J3IM,&QQJ9#
M`*3IM,&QQJ9#`+%(I?.D2*9AIWVQQJ9#`+9LI?.D:J1PL<:F0P"E1*:NL<:F
M0P##]L%PL<:F0P"FK*7SI$BF8:=]L<:F0P"QQJ9#I.BF5K_OOMP`J-.WO:9A
MIWT`4V]U=&@@069R:6-A("BK;JM$*0"K;KS:("A)4T\M.#@U.2TS*0!3;W5T
M:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P"K;J5B
MLGD`JL6EU:;F`+:AMEH`MJ&V6KM0N=2E4@!3<&%I;B`HINBO6J3Z*0"I5:>C
MMFRE\P"\<Z=IO6,Z`*]3KNVF<J2XO^FD2@"O4Z[MIG*DN`"UZL#`JTBE\Z=8
MQ-VO4Z[MI<ZS?K5,JFNS4;USO^@N`*OWO&?`RZQD`*OWIG+`RZQD`*OWIG+`
MRZQDI[FFJ`"P]:;FJ_>F<L#+K&2NR:A#I$"MMJG2Q>.EW*JZO_F[?KS&+@"D
MP+/.P'BF<P"DP+/.Q.:F[`"DP+/.ID,`N4*PR@!3<FD@3&%N:V$@*+2UJ+W$
M]:5D*0"\T+?'`*Q0N]JJI\51OM0`L=*PR@"QTJELIGZE]P"LV0"K2+K@`*M(
MNN"F5[K9.@"K2+K@JZRZ03H`JTBZX#H`JJRZ00#`>*9SKN:FH0"U\[E$`*=2
ML*.]=0"F<J;JID,`I6BPHZK^I?,`IMNV;*7SIF&G?:2DI6BPH[KTL.RF5[K9
M`*5HL*/"7Z;F/P"\RZ:A(%M#4U-=`*Q0M,&DT0"E1*:N7VH`I^2DHZCLIKBE
MV+_]("(E<R(`I42FK@"E1*:NQ.:F[`"THZ7F`+Q7I5L@(B5S(B"H[*ATLLZJ
MNJ73O="D=[!EI5@N(*=!I;*VM[6EJ.RXTZ73O="S4:[6K>.KX:1^K^"U;J1*
M+@"M<;Y<`*15O-``IJBE7`"FJ*5<JKJE6Z1*("(E<R(@J.RH=++.I*0N`*:H
MI5RJNJ;;J'2RSJ2DLDVPHZC/I<ZJS"`B)7,B(*JZN.JNQBX`(B5S(J1WIU*P
MHZ>YIJ@N`*:HI5RJNJ;;J'2RSJ2DLKZPHR`B)7,B+@"D=Z:HI5RJNJ9>M%^S
M7:EW+B"]T*VKMW.X_*1*P,NU^*YTLJ<N`*1WIJBE7*JZL\:E][-=J7>XZJ[&
M+@"D=Z:HI5RJNK/&I?>S7:EWN.JNQB`E<RX`IJBE7*JZI_.W<R`B)7,B`*1W
MIJBE7*JZPM"\9R`E<P!3=61A;B`HQ*RDIBD`J]C$LP"Z2ZUN`*3II5@`I.FX
MJ`"TN`"DZ:58`*3II5@OI.FXJ`"DZ:58.B``I.FXJ`"DZ;BH.B``I%>\T`"D
MY+2I`%-U<FEN86UE("C$K*=1JVXI`+KON+D`4W9A;&)A<F0@86YD($IA;B!-
M87EE;@!3=V%Z:6QA;F0@**5VI<O`V<3U*0!3=V5D96X@*+?GJ.4I`*3!M*NV
M;*7SO7.\9Z3HIJ$`I,&TJZRPNO2MMKUSO&>\TJ:A`*3!M*NLL*_"I.6F<KUS
MO&>\TJ:A`%-W:71Z97)L86YD("BWYZ1H*0"F4*A"L$^__:1WIU*PHP"F4*A"
MIN:PRKC+N&T`MVJT3;:UI=BDI*JZNWFJ:[_YNWX`4WER:6%N($%R86(@4F5P
M=6)L:6,@*+'4IU&HR"D`N7"K0@"Y<*M"IK.MMP"Y<*M"`*:MIK.K^<3RN7"K
M0@!404(@I,"Y:J[FIJ'`R:[7`*KML^8`JNVNYJ2ZKF4`JNVNYJ2ZKF4`I7C&
M5P"E>,97`%1A:FEK:7-T86X@*+;PIDZTM:E:*0!486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F("BI6JE\I:>HR"D`I=B\T#H`J]V_[*C&MK4`I+JN95]X
M`+EQN-RXN;U8`+/,JO&D0*1PKLFJNK?%J]<Z(`"WQ:O7`+?%J]<Z(`"WQ:O7
M/&)R("\^*"5SL*HE<R\E<Z=#)7,I("9D96<[)7,`I^2DHZCLO,NJ3R`B)7,B
M+@"\RZI/NMZR>@"\R*[).B``O,BNR;&UJ/R]T*A$`+S(KLFQM:C\`*I!L,BV
MM:78P,FHPZ6\IF(@8V]N9BYP:'`@I*2K_*EW`*2ZKF4`K\*DY:9R`+GON_2D
MY:9R`+GON_2DY:9RL[NZW0"L4+3!I7P`KO6DY2`H5$E3+38R,"D`5&AA:6QA
M;F0@**[UL.HI`$944""IM:;Y*&5X=&5N<VEO;BFU3*[$+@"W[<))O^^V;+UC
MP,NU^*2DJKJQ2*7SI$C$YJ;LKLDLP+.XTSH`2&]R9&4O2V]L86(@ON.F6*1U
MM7NHPZ6\I.2TJ2`B)7,B`$E-05`@IOBJ0;ZYI*.DY+2IJ=*K_*EWJKK%Y\/2
MI.BFH2X@O=#!<+6XIT&JNJATLLZZWK)ZK?LN`$E-4U`@K/:__;5,JFNS4:KL
MJ6PN`+/!JO>V\+CJM[VDP*3D`+/!JO>V\+CJM[VDP*3DI6FS4:15N/PE<P!-
M86EN=&5N86YC92##_J=/J,.EO*:HI5RX_*1*`+_OMK6U^+6AI4C#]K.L+L+W
MMGVDI"X`LV^MT[%BN+D@(B5S(B"D=[-1IU*PHRX`LV^MT[%BN+D@(B5S(B"D
M=[-1P'BF<RX`IT&JNJATLLZZWK)ZK?NELK:WI?VS7:EWIFZD0*W3Q7:MK:OA
MNMVD?J_@Q?VG0:C/I<[%=JVMJ'2RSBX`I^2DHZCLJOZE6\#)KM<N`*FSKMB]
M=0"DHZ6_O52JNJ;FJ,:^Y+CJKL8`M4RJ:[9]L=*V;*7SO7.\9[7XM:$N(*:S
MI6FOX*=!I'>Q3L)SQ/V^N:JZPMN\=;7XM:&E7*_@PNJI=R`_`,%PM;BXN;U8
MI;RK_*EW+*K%I=6ISJ9BN.JNQJYWI*2GY*2CJ.PN`*1WIJBE7*JZL4[!<+6X
MI$BW<[Q7IMRS<;!4O_VDI"X`L\&J][;PP,FNUZJZI+JN9:9PI%4N`*78JV6J
MNK-OJ,>K2*7SIU@@(B5S(B"Q3K-1I_.F5ZRP("(E<R(N`+5,JFO%JJCZJ=*F
ML\/VJ?.S;ZW3JTBE\Z=8JKJF<ZCZQ7:MK;-=J7<`Q>?#TK9LI?/#L;.YN]VM
M;J:SI$"MTZ1WN-&V?:JZ(%!'4""PS[;T+@"P=+AMN'.RU:JZP]&G3[BYO5@H
M240II*.L3Z6\J_RI=RRT3JQ/JL6EU:G.JLRDHZ9BN.JNQJYWI*0N`+!TN&VX
M<[+5I;RK_*EW+@"FN:O*K_.]6J1WP'BF<ZCLJTBE\Z=8(B5S(J2D+@"[W:UN
MI$"MT[AGN4RE6[%+JKJZ]+CTLW.ULBX`IKFHQJ7SI'>FJ*5<JKJ\5Z5;J.RG
M0:JZIN:HQK[DI*0`Q.:F["`B)7,B(+5,JFNS4<%RM/HN`,#)KM<@)7,@P+.X
MTZ5=IW2D0*W3("5S(+-=J7<N`,#)KM<@)7,@P+.XTZ5=IW2D0*C'("5S(+-=
MJ7<N`+5,JFN]QKMSJ.RFVZBMP,FNURX`IKG`R:[7I*2H4Z:SN.JNQBX`JTBE
M\Z=8(B5S(J1WIG.F8@"K2*7SIU@B)7,BIE>ZV:=TIK.DHZ98JFNJNJ9RI+@L
MLV^Q3K-YIJBD0*C'L-W#1"Z]T+-SM;BG0:JZJ'2RSKK>LGJM^RX`JTBE\Z=8
M(B5S(J1WJ]BGM*;]J7REO*UQOEPN`*M(I?.G6"(E<R*D=Z=2L*.F_:E\I;RH
M^J[XK7&^7"X`JTBE\Z=8(B5S(JC#I;RKV*7?+J;XJD&^N:9>P+,`JTBE\Z=8
M(B5S(JC#I;RG4K"C+J;XJD&^N:9>P+,`JTBE\Z=8("`B)7,B(*1WIJBE7*O8
MI=\N`*M(I?.G6"`@(B5S(B"D=Z:HI5RG4K"C+@"K2*7SIU@@("(E<R(@I'>F
MJ*5<LU&G\Z97K+`@(B5S(BX`I4BD5:Q/(')F8S@R,B"V;*7SJKJJ[<!9+@"F
MN:K^I?.E7:=TI%6F0\#)KM<Z`*BMI??#T:=/("5S(*1WLU&G4K"C+@"U3*IK
MMGVQTKG/I/G`>*9SM?BUH2X@IK.E::_@IT&D=[%.PG/$_;ZYJKK"V[QUM?BU
MH:5<K^#"ZJEW(#\`I=&I\[%(I?.D2*9BIT&JNK-QL%2__:2D+*9=IKFFV[#*
MQ>.EW*M(I*2JNKG/I/DN`*6JKMB]=0!';G501R"D1Z2XP,FJNKCTKGRELK:W
MJ7>X<:9B($-R>7!T7W!G<#HZ(,/^IT^DI"X`MFRE\Z;XJD&^N;*CI<VE2*15
MJKJ_^;M^L%2NISH`IKFV;*7SIOBJ0;ZYLJ.ES:5(I%6JNK!4KJ<Z`+9LI?.F
M^*I!OKFRHZ7-I4BD5:JZL%2NISH`MFR]8R`@(B5S(B"EV*MEI'>X9[)-JL4N
M`+%Q("(E,B1S(B#%JJCZMFFHTZJZI7ZSH:M(I?,@(B4Q)',B(*CDI&JD<"@E
M,R1D(&)Y=&5S*:1WME>E6+-=J7>D5ZVM+@"V;*7SO&>G0*JZM?BUH:1WLU'#
M]K.L+B"ULJ?TI*0N`*:YMFRE\Z1WLU&G4K"C+@"FN;9LI?.D=[-1Q>?#TBX`
MIKFV;*7SI'>S4<7GP](N(+9LI?.Q2*7SJLPZ("5S+@"G0;2_J?,@)7,@L4BU
MN2`E<R"D0*O*I42FKJRP("(E<R(@JKJK2*7SI'>S4;9]L=(N"J;]LV^HPZ2C
MK^"K3\/2N-.K2*7SJKJDNJYEI'>GN:7^LU&FK*7SI$BLW:>YJ<ZD1KC1+@"S
M<[6RJ.R]<[QGMFRE\ZVVK;&ITJC/I<ZJNJ97NMD`I;*VMZQ/I$"MT[S&IG(N
M`$AO<F1E7T-R>7!T7W-M:6UE.CH@P_ZG3RRELKO=K6ZFLR!O<&5N<W-L(+S2
MLM4N`+5,JFNV?;'2L4N]6+7XM:$N(*:SI6FOX*=!I'>Q3L)SQ/V^N:JZPMN\
M=;7XM:&E7*_@PNJI=R`_`*:YL+ZF;B`B)7,B(+CJKL:F7:RPME>Y3+/,I&JD
MN;-<K<@LJ=*E2+5,JFNS4<!XIG,`I<ZE2,#+M?BFN;CJKL;#_JNL("@E<RD@
MJKJU>Z:AJ,.DHZ9SIF*I\ZATLLZD5RX`I-ZM>J9RI;*VMZRPL^:D0*9RI+@N
M`,))O^\@)7,@P,NU^"!01U`@I+VV?:KWQE^JNJWLJ6RDNJYE+@"F8B!-4RU4
M3D5&(*K^I?.DI*?DI*.H[*G2MK>M;JJZP,FNURX`IF(@6FEP(*K^I?.DI*?D
MI*.H[*G2MK>M;JJZP,FNURX`I:JE:Z[8O74`I6NNV+UU`+9LI?.Q2*7SJLRM
M;JA$IE[`LZKMI=RG0:1WQ:JH^K9LI?,LO=#"2;_O)7.VQ[!EIEZQ^"X`Q.:F
M[*3`N6JF<J6RMK>LL+/FI$"F<J2X+@"FN:;XJD&^N2`B)7,B(*1WLU&G4K"C
M+@"FN:;XJD&^N2`B)7,B(*1WLU'`>*9S+@"F^*I!OKFU3*IKK+"S;ZW3N<^D
M^:O8I=_!6;G/+@"FN<.QIE>U3*IKLU&X;;2K+@##L:97I'>X;;2KI[FFJ"X`
M)7,@JKJU^:55N]VH1*1WLU&ROK"C+@"K_*EWJKK`R:[7J,.DHZ9SIF(N`*O\
MJ7>JNK!/O_VHPZ2CIG.F8BX`JTBZX"(E<R*W<[Q7I[FFJ"X`JTBZX"(E<R*G
M4K"CI[FFJ"X`JTBZX"(E<R*G\[=SI[FFJ"X`IKFKW;_LJ,:VM:1WIJBE7*5;
MI$JH[*=!JKJKW;_LPZ^DI"X`O,BF<\#)KM<B)7,BI*.F<Z9B+@"V;*7SI+JN
M90"V;*7SI+JN9;W0L-&FTB`E<R`N`+!HI?.DNJYE`+!HI?.DNJYEO="PT:;2
M("5S("X`L&6E\Z2ZKF4`L&6E\Z2ZKF6]T+#1IM(@)7,@+@"G0:G2O^FD2JJZ
MN.JNQKM0M66ML;CJKL:DH[+%+@"D5Z15KMB]=0"D5Z[8O74`L7&D5Z1`K=.H
M0L9*I*>KX:17ML>JNKCJKL:_\J6B+@"D5[;'P,FNUZC#I;RS4<!XIG,N`*C/
MI<ZJS*JZ(&9R964O8G5S>2"XZK!4I'?`>*9SI[FFJ"X`=V5A=&AE<BYC;VT@
ML,^V]+5,JFNHSZ7.+@"GY*2CJ.R\RZ:AL'2X;:78O_T@(B5S(BX`I;NDY;#/
MM4RJ:\7CI=RFN;9LI?.JNJ5TI$"ZV*[FIJ$N`*78JV6S;ZW3MFR]8Z2DJ%.F
MLZ7TIO.K2*7S+@"U3*5II<ZJNK_OMK4N`+5,JOZE\Z5IJKVQM;9]L=(N`*:Y
MQ.:F[*2DI5VG=*33IFBJNJ9RO,8NIT&D=[_II$H@)7,@K=.F<KS&.Z=!O^FD
M2JJZIG*\QJ6RMK>D<*GS("5S+@"H4Z:SI+JN9:5IQ>.EW*GSI;NDY;#/+@"W
M<[Q7("(E<R(@J.RH=++..B`E<R"NR;5OI<VD0*W3L-W#1"X`IMNH=++.LDVP
MHR`B)7,B(*JZN.JNQJ[)M6^ES:1`K=.PW<-$.@"^4+>TMFR]8Z[)M6^ES;#=
MPT0NIOBJ0;ZYIE[`LSH@)7,`IMNH=++.LKZPHR`B)7,B(*[)M6^ES:1`K=.P
MW<-$.@"G\[=S("(E<R(Z("5S(*[)M6^ES:1`K=.PW<-$`*17ML?`R:[7KLFU
M;Z7-I$"MT[#=PT0Z("5S(*6\LU&D5[;'+@"D5[;'P,FNUZ[)M6^ES:1`K=.P
MW<-$.B`E<R"D:J1PME>Y3*2YLURSS*1JK<@@*"5D(&)Y=&5S*2X`I%>VQ\#)
MKM>NR;5OI<VD0*W3L-W#1#H@MLBSH:3`JKH@)7,@P,FNU[-1I%>VQRX`I=$@
M(B5S(B"]QKMSMFRE\ZCLJTBE\Z=8("(E<R(@KLFU;Z7-O_F[?BZF^*I!OKFF
M7L"S`+%QJTBE\Z=8("(E<R(@IU*PH[9LI?.NR;5OI<V_^;M^+J;XJD&^N:9>
MP+,`IF*K2*7SIU@@(B5S(B"DI*=2L*.V;*7SKLFU;Z7-O_F[?BZF^*I!OKFF
M7L"S`*=2L*.K2*7SKLFU;Z7-I$"MT[_YNWXN(*;XJD&^N:9>P+,Z("5S`*=2
ML*.HQJ7S.B`E<R"NR;5OI<VD0*W3O_F[?BX`P,NU^+9LI?.NR;5OI<VD0*W3
MO_F[?BX`IF*K2*7SIU@@(B5S(B"DI+S0P]&V;*7SKLFU;Z7-O_F[?BZF^*I!
MOKFF7L"S`+;7I$H@)7,@KLFU;Z7-I$"MT[_YNWXN`+;7I$JFN;-QL%2__;CJ
MKL:NR;5OI<V_^;M^+@"VUZ1*J,:E\SH@)7,@KLFU;Z7-I$"MT[_YNWXN`+;7
MI$H@:4-A;&5N9&%R(+CJKL:NR;5OI<VD0*W3O_F[?BX`MM>D2JO=O^RHQK:U
M.B`E<R"NR;5OI<VD0*W3O_F[?BX`MM>D2JC/I<ZJS*JZMWS$L[CJL%0Z("5S
M(*[)M6^ES:1`K=._^;M^+@"F8K-=J7>J[;/FI*2U;Z7-I$:D0*W3O_F[?BZF
MLZ5IK^"G0;_RNGRD1J6RMK>V\;QGJKK$YJ;L+@"ET2`B)7,B(+=HLKZV;*7S
MJ.RK2*7SIU@@(B5S(B"NR;5OI<V_^;M^+J;XJD&^N:9>P+,`L/6FYK-QL%2_
M_:O\J7>E7*_@KLFU;Z7-I$"MT[_YNWXN(+W0M7FKX:9!N-6D0*:X+@"Q3JM(
MI?.F<ZRPK_.]6J[)M6^ES:1`K=._^;M^+@"VQ[!EMFRE\Z[)M6^ES:1`K=._
M^;M^.B`E<P"G\[=SP7"UN*1(N.JNQJ[)M6^ES:1&I$"MT[_YNWXN(+W0M7FK
MX:9!N-4N`*?SMW.P=+AMN'.RU:[)M6^ES:1&I$"MT[_YNWXN(+W0M7FKX:9!
MN-4N`*?SMW.HQJ7S.B`E<R"NR;5OI<VD0*W3O_F[?BX`IKFV;*7SJ%.FLZ3E
MIG*DNJYE`*:YJ\H@2%1-3""V;*7SI+JT3[G/I/DN`*:YJ\H@2%1-3""V;*7S
MI+JT3[G/I/DNK-VP7ZC3N;.S;[S+.B``IKD@24U!4""F^*I!OKFHPZ6\I.2T
MJ:M(I?.G6*3`J,FE7*_@+@!01U`@I+VV?:KWQE^D=ZK^I5NH[*:YMFRE\RX`
MLV^MTZ=`I<ZDZ*:AI*.S4:3DM*DN`+-OK=.G0*7.I.BFH:E\I;RS4;GJIT`N
M`+-OIORE1Z2CK$^EO[U4JKH@<F%R(,"CP5G`R:[7+@"S;Z;\I4>DHZQ/I;^]
M5*JZ('II<"#`H\%9P,FNURX`LV^F_*5'I*.L3Z6_O52JNJM(I<ZE9+BYO5@N
M`*:YQ.:F[*Q/I;*[W:UNJKHN`*:YQ.:F[*2ZKF6E=:2YLUR^X[S&O,:F<BX`
MIKG$YJ;LI+JN9:5UI+FS7+S&IG*DSJM?N+DN`*:YQ.:F[*2ZKF6E=:2YLURD
M2[9IINR\QJW(+@"FN<3FINRDNJYEI;*VMZRPLW*XN:G.JL6EU:3`N6JJNKS&
MIG(`I;*VMZQ/I$"MT[S&IG(N`*:YQ.:F[*2ZKF6ELK:WI5VG=*1`LM6D4:2[
MMFFF[*JZ(%)'0B##0Z;BI4Z]6"RHTJ9P("<C,3(S-&%F)RX`LV^MTZKML^:D
M=[-1LT*R>KE,+@"S;ZQ/("5S+@"S;ZQ/($MO;&%B(+ASLM6JNJ1`K=.JJZ7S
M+B"Q_<#+M?BFN:JKI?.[W:UNK^"DY+2I2V]L86(@N'.RU:[FIJ&JNKEQI&RV
M;*7SLV[%Z2Z]T+#1IM(@)7,@I4BD1KC1LV^HQ[9LI?.S;L7I`+-OK=.PRJ=`
ML4ZOT[9/I$"HQZ[)MJ$NQ'[$\K;</P"S;ZO*MFRE\Z5=IW2D0*W3L\&J][;P
MP,FNURX`IKFV;*7SJ=*GJ+%AJKJD0*W3JOZE\Z1WN&>S>KE,(%,O34E-12"L
M2:5(O,:F[,.QL[DN`*:YMFRE\ZG2IZBQ8:JZI$"MTZK^I?.D=[AGLWJY3"!3
M+TU)344@K$FE2*5;L4LN`+-OJ\JK2*5=IW2V;*7SN[RP9:JLND&JNKCJL%0L
MIOVL3ZM(I?.NYJ:AI;RJOBX`IKFV;*7SIORE1Z2CK$^L3Z6_O52JNB!01U`@
MI5NQ2Z[FIJ$NO_F[?CH`IKFV;*7SIORE1Z2CK$^L3Z6_O52JNB!01U`@KN:F
MH2`HJ,R^VB!21D,@,C`Q-2DN`*:YMFRE\Z;\I4>DHZQ/K$^EO[U4JKH@4R]-
M24U%(*[FIJ$N`*:YMFRE\Z1WN&>S>KE,(%!'4""\QJ;LP[&SN2X`IKFV;*7S
MI'>X9[-ZN4P@4R]-24U%(+S&INS#L;.Y+@"FN;9LI?.D=ZC/I<X@4R]-24U%
M(*5;L4LN`*:YMFRE\Z1WJ,^ESB!01U`@I5NQ2RX`N-.V;*7SJ.P`LV^KRK9L
MI?.HPZM$I4BG0;I$I<ZJNJ9RI+BVL*;3K$^HSZ7.("@E<RD@KM&\9Z;3IJ@N
M`*:YO,:MR+/,I-:ELK:WK$\@,2X`IKFF^*I!OKFU3*IKN>\@>FEP(*3.(&=Z
M:7`@KN:FH<#)KM>V::;FN-'`H\%9`+-OLZ&F^*I!OKFHPZ6\I.2TJ:M(I?.G
M6*3`J,FE7*_@+@"FN:ATLLZEV*MEK$^PL:7.JKJJK+I!+@"ELK:WK$^D0*W3
MO,:F<BX`LV^MT[7XM:&ELK:WN&>ET;9LI?.\9Z=`M?BUH:C3J4FE<P"FN;7X
MM:&ELK:WK6ZET;_OMK6U^+6A*$]P=&EO;BFITJE)I7,`P_;!<,7CI=P`MFRE
M\\/VP7#`R[7X`+EP`+#=PT2P;,+<`*[)MJ$`KLFVH:O\JVX`KLFVH:[FIJ$`
MKLFPS[_OOMP`5&EM;W(M3&5S=&4`O-##1`"\T,-$("AT;V]L=&EP*3H`IJRE
M\Z1(`*:LI?.D2*9AIWT`IG"J1ZUNO<:_[\3FINPLO="F8L))O^^WQKFKJKJN
MR:90KLFK]B!#;VYT<F]LP>0HK=.D2+EQN*,I(*G.($-O;6UA;F3!Y"C$JZI'
MN7&XHRDN`*9PJD>M;KW&O^\LO="F8L))O^^WQKFKJKJF4*[)J_8@0V]N=')O
M;,'D**W3I$BY<;BC*2"ISB!#;VUM86YDP>0HQ*NJ1[EQN*,I+@"Q_:C/I<X@
M5$Q3(+KTN/2S<[6R+""G0:6RMK>HSZ7.(%!(4"`U+C`N-B"E2*17**=T*:JZ
MJJFENRX`I+6DT0!(5$U,(*WLJ6S`R0!4;V=O("BF:*WT*0!4;VME;&%U`*GZ
MI-$`5&]N9V$@**I&I5LI`+.[LZ$`L\RD5[QHKMBL6R`H7W1O<"D`J=*FLZJZ
MJOZE\\%@K7"D:J1P.@"I5:>CIU@`J56GH[UC.@"D9*B]N4:DSJ:KJ*FM]`"O
M=:G.L+``K%"TP:1'`%1U;FES:6$@**SPI:>FZ*C(*0!4=7)K97D@**1GIM6H
MY"D`I&>FU:CDI.4@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',`5'5V86QU("BD9Z7+OGPI`+_II$JG0:JZO^^^
MW#H@`+6UI7Z]=:O\O,8Z(`"Z]*=]`+KTIWTZ`%5G86YD82`HKU&D>KE&*0!5
M:W)A:6YE("BO4:=*Q/4I`+5,JFNF<ZCZ(%9&4R"EV+_]+@"U^:55KLFU3*IK
MO%>E6\-"I7ZJNJC/I<ZJS+CJL%0N`+5,JFNG[\7<(%9&4R#`R:[7("(E<R(@
MJKK%=JVM+@"U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNL5VK:TN`+5,JFO%
MW*?SK+`@)7,N`+5,JFO`RZQDP,FNUZ1JI'`@(B5S(BX`M4RJ:\#+K&3`R:[7
MI&JD<"`B)7,O)7,B+@"U3*IKLW.ULB!344P@IOBJ0;ZY+@"U3*IKJ,^ESB!3
M4TP@LW.ULBX`M4RJ:[W&NW,@5D93(,#)KM<N`+5,JFNKV*7?(%9&4R"EV+_]
M("(E<R(N`+5,JFNKV*7?(%9&4R"EV+_]+@"U3*IKJ]BEWR!61E,@P,FNURX`
MM4RJ:ZO8I=\@5D93(*78O_T@(B5S(BX`M4RJ:ZO8I=^JQ:75JKH@5D93(,#)
MKM<N`+5,JFNQ3KCJKL:XT<"CP5DN`+5,JFNG4K"C("(E<R(LIKFEV+_]J,.K
M1*K%I=4N`+5,JFNG4K"C("(E<R(Z("5S`+5,JFNG4K"C("5S+*:YI=B__:C#
MJT2JQ:75`+5,JFN[O+!JIU*PHZ78O_TN`+5,JFNG4K"C(%9&4R"EV+_]+@"U
M3*IKIU*PHR!61E,@I=B__3H@)7,N`+5,JFNG4K"C(%9&4R#`R:[7("(E<R(N
M`+5,JFNG4K"C(%9&4R#`R:[7+@"U3*IKIU*PHR!61E,@I=B__2`B)7,B+@"U
M3*IKN[RP:J=2L*,@5D93.B`E<RX`M4RJ:Z=0PE^EV*MEJKJEV+_]+@"U3*IK
MN-&V?;[,P]*RT[A@`+5,JFNX_*1*)7.JNJEWN'$N`+5,JFNW:+*^(%9&4R#`
MR:[7+@"U3*IKMGVQTB!61E,@P,FNUR`B)7,B+@"U3*IKO&>D2B!61E,@P,FN
MURX`M4RJ:[9]L=(@5D93(,#)KM<N`+5,JFNV?;'2P*/!6<#)+@"U3*IKQ:JH
M^B!61E,@P,FNUR`H9FEL97-I>F4H*2!F86EL960I+@"U3*IKQ:JH^B!61E,@
MP,FNUR`H9V5T1FEL95-I>F4H*2!F86EL960I+@"U3*IKQ:JH^L#)KM<Z(`"U
M3*IKQ:JH^B!V9G-R;V]T(*78O_TN`+5,JFNG\Z97("5S(*RP("5S.B"F7:RP
MI=B\T*M(I?.G6*1WIG.F8@"U3*IKQ=RG\R!61E,@I=B__:JZIE>ZV2X`M4RJ
M:[*^L*,@5D93(*78O_TZ("5S+@"U3*IKQ=RG\R!61E,@P,FNUR`B)7,B(*JZ
MIE>ZV2X`M4RJ:\7<I_,@5D93(,#)KM<@)7,O)7,@JKJF5[K9+@"U3*IKQ=RG
M\R!61E,@P,FNUZJZIE>ZV2X`M4RJ:\6JJ/JZS[K0L'2X;;CJKL8`M4RJ:[#U
MIN8@)VUK:7-O9G,G+@"U3*IKPN"TJR!7;W)D(*3EI?,`M4RJ:[QGI$H@5D93
M("(E<R(@P,FNURX`M4RJ:[QGI$H@5D93(,#)KM<@*&-O<'DH*2!F86EL960I
M+@"U3*IKO&>D2B!61E,@P,FNU[CJKL8N`+5,JFN\9Z1*(%9&4R#`R:[7+""Z
MS[K0L'3#0J1WNJ$N`*6\IE["T`"EO*9>PM"JNK9LI?,`M%^M[*1WIU*PHP"I
ML[UU`,'TPL.FK*7SI$@`J/JN^*?SI^\`M%^M[`"F^*I!OKFS<[6RKLFU;Z7-
MI;RY=[3!JKJF7L"S.B``M6^ES:6\N7>TP:JZIE[`LRRET:;XJD&^N3H@`*6\
MI,##_@"U3*IKM'BQL:JZI+BE\ZNLND$Z("5S`+A5L.J]6"`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S("BJ_*G4IT+!<*98I&JDO;#J*0!5;FET960@
M2VEN9V1O;2`HK5ZPZBD`56YI=&5D(%-T871E<R`HK/RPZBD`56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`+/FINP`I;RJOJJZ`*6\JKZJ
MNJ3IM,$`I;RJOJJZ($E-05`@IE[`LRX@IOBJ0;ZYIE[`LSH@)7,`I;RJOJJZ
MMWS$LP"EO*J^JKJFK*7SN>^V2`"EO*J^JKH@05!)(+!4KJ>]<[BY("A!4$D@
M365S<V%G92!)1"DN`*6\JKZJNJO(I.&P5*ZGO7.XN2`H05!)($UE<W-A9V4@
M240I+@"EO*J^JKJF[+AMN.JP5"X`I;RJOJJZJ,^ESJK,IE>ZV:G.L4N]6"X`
MI*3"7Z78JV6DN*7SJKJS<[6R`*CXN/RQ2[U8`*6\J5*F5P"F7:9WI?[%5;Q[
MI*.DN;-<I;RQPL5VJKJU>Z:AL/6FYK#%I%4OO<:[<R^V2Z17+B#"2;_OO52I
M=Z5(P,NU^"!M;WII;&QA+F]R9R"ITK2CJ-&JNJS;P_:GWK-.I.6E\RS%_:=!
MI6FE2+C1L*.FN:1`K:VH[JC#IMNFYK9]J?&U>Z:AIG.H^K#%MDO#KRX`I;RL
MW;E,`*CZKOC#0Z;B`*CZKOBM<;Y<`*6\I.2TJ:JZL,;`R:97`,7<I_,`I_.W
M<R`E<P"G\[=SIE[`LZJLND$`I_.W<ZC/I<ZJS``B)7,BI'>G\[=S+@"G\[=S
MM7NFH:1WIU*PHRX`I%>VQP"D=Z17ML>ITJ:SP+.ESK5[IJ&JNK-=J7?`R:CL
MIOBJ0;ZY+@"D:KQGJ=2D0KS&IG(`I&J\9\.YL*B\QJ9R`%5R=6=U87D@**]1
MJ=2F8RD`J,^ESJ78JV6JNCH@)7,`J,^ESKEWLUVMR`"HSZ7.($E-05`@JTBE
M\Z=8K7&^7#\`J,^ESB!34TP`J,^ESK7JP,"I5:>CO6,_`*9PJD>G0:JZJ,^E
MSJK,IE>ZV2^Q2[U8NU`@24U34""F^*I!OKFDHZ90+*5IIF*FN;-=J7<N`*C/
MI<ZJS`"HSZ7.JLP@(B5S(B"D=Z:HI5RJNK-1O>&DJ:15ID/%=JVMJ.RK2*7S
MIU@@(B5S(BX`J,^ESJK,("5S(*6\LW&Y3"`E<R"JNK'"Q7;%Y\/2+@"HSZ7.
MJLRZWK)Z`*C/I<ZJS+_OMK4`J,^ESJK,M?FE50"FN:^XI7BJNJC/I<ZJS+7Y
MI56H=++.I'>PL:7.+@"GY*2CJ.RHSZ7.JLRQ8KBY`*C/I<ZJS*97NMD`J,^E
MSJK,IE>ZV2`B)7,B(*1WIG.F8BX`J,^ESJK,IE>ZV3H`J,^ESJK,.B``J'2R
MSJ2DJKJHSZ7.JLPZ`%5Z8F5K:7-T86X@**]1K_>G3Z=**0!61E,@I=B__:C#
MI*.F<Z9B+@"PLK3!`*1WI^2H[*:SKL2JNJ9APDDZ(`"FLZ[$J<H`I4BDP,3!
MK+"SYJ;L*+%QLGNF8K!?NN(I`*W(`+_OJ/JMR*;;`%9A;G5A='4@**7+I:.J
M_+G/*0#%W*3&`%9E;F5Z=65L82`HJ66DNK?GJ=0I`,7GP]*EHK'1("T@IKFV
M;*7SI6FOX*1WOD2D2+[5IMN_>:?O+@"JJ:6[`*JII;NQL:CN`*NKJKVY[[OT
M`*NKJKVYU*52`*NKJKTZ`*M$L6"PJ@!6:65T($YA;2`HME:K;BD`ME:K;J3E
M("A625-#24DI`,#+M?@`P,NU^"`E<P#`R[7X("5S(*2]MGVJ]\9?`*9BMW.U
M^+6AP,NU^"!(5$U,(*2ZKF4`P,NU^`#`R[7XK=.D2*APL4NJ]\9?+@#`R[7X
MK=.D2*2]MGVJ]\9?+@##]L%PP,NU^`#!6;G/P,NU^`"F8K=SM?BUH;9]L=(`
MI4@@)7,@P,NU^`"F8K=SM?BUH<#+M?BJ_J7S`*9BMW.U^+6AP,NU^`#`R[7X
MJ,:E\P#`R[7X("5S(*2DJKJV;*7S`+5NI$JKX<7CI=RK2*7SIU@Z`,#+M?BK
MW;_LJ,:VM0#`R[7XN<^D^0!6:7)G:6X@27-L86YD<RP@0G)I=&ES:"`HK5[$
MW;K[J,JX<ZYQ*0!6:7)G:6X@27-L86YD<RP@52Y3+B`HK/S$W;K[J,JX<ZYQ
M*0"UZL#`JTBE\Z=8(B5S(J1WJ]BEWZ>YIJ@N`+7JP,"K2*7SIUBDHZ9SIF(N
M`+7JP,"K2*7SIU@`M>K`P*M(I?.G6+O=K6ZD0*W3IE>ZV2X`M>K`P*:LI?.G
M6`"UZL#`IJRE\Z=8`+7JP,"I5:>CO6,`M>K`P*E5IZ.]8P"UZL#`J56GH[UC
MI*.F<Z9B`+7JP,"K2*7SIUBF5[K9`*_@J*.KUP"OX*BCJ]<Z(`"X<:1JIU&E
M\;QWK;>Y<:M(I+VE<;-ZN4P@4TU44`#$M:=I`,2UIVDA(2$@L7$@)7,@I.*P
MRK*^L*.U>Z:A+@!724X@N&>ET2!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`,2U
MIVD`K%"TP:14`*31KO"Y=[3Z`*[PMDBXZJ[&M*.HT0!W96%T:&5R+F-O;2"Z
M]*^X`+KTK[@`NO2ON`"H0[9G`,5WJN\`Q7>J[ZCL("5S`,5WJN\L("5S`*;H
MO-H@*$E33RTX.#4Y+3$I`*;HO-H@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A
M:&%R82`HINB\NZNBJ=0I`+5NI$JKX<"SN-.E_<7CI=P@)7,@K?ZD0*W3P+.E
MSK5[IJ$_`,3FINRJNJ3`N6JF<J2X/P"DWJUZJKJK9;AMIG*DN#\`M^VV;*7S
MLU&F7K/XK+"\<Z=IJ<ZDHZQ/O'.G::[)P+.XTS\`M^VG4K"CMFRE\Z[)+""D
MH[S0NWBFJ*1WIU*PHZ;3JKVQM;*^J.RI5:>CO6,_`+9]L=*K2*7SIUBNR2RG
M0:?&L>:Q<:W^I$"MMK9]J6P_`,!XIG.Q2*7SL\:E]Z[)+*Q/IU^D7:UNI$"H
MUL!XIG.J_J5;P,FNUR`_`+;'L&6V;*7SJ<ZI;:97P7*T^J[)H4&F<*I'J%.F
ML[_II$JFK*7SN>^V2*JZNO2P[*97NMDHN7&D;+9LI?.F[:=]J%.FLR)`(BD_
MH4&E2*:YL+6LL+EWLUVJNKKTL.RF5[K9/P!7:&5R96ES($%U<W1R86QI82"F
M8;G/`*W^K=.DZZS;`+KTK;:]<[_HOKFJNK2AI?,H<&QU9VEN<RFQTK#*L;&H
M[BX`I,VUO:97L^8`O&6KUP"E2"!#4U,@K+"SYJ;LJKJ\9:O7`*6JP^0E<Z5<
MK^"J[:JZO&6KURBD5::XM6ZD2JELI<VNQ"DZ`*KMKN:\9:O7`+QEJ]>SYJ;L
M`+QEJ]<Z`+:PQ>FST*=``*VW`*:MIK.MMP"MM[-T*+A@*0"MM[-T.@"MM[-T
M.B``M+R\>@"TP:O=PJ>JJP"D=:=``+_LI+VKQZ9AIWT`O^RDO:O'N7&XW`"R
MQ"5DIN:JNL3FINR\QJ78I*.EO[U4+B#`L[C3K6ZFLR5DK=/$YJ;L+*5UI^2H
M["5DK=/$YJ;L+@#$YJ;LO,:EV*2CI;^]5"X@P+.XTZUNIK,E9*W3Q.:F["RE
M=:?DJ.PE9*W3Q.:F["X`6#4P.78S(*FUIOFJ]\9?NWFJ:P!8-3`Y=C,@I42F
MKK3`I4ZF5[K9`%@U,#EV,R"E1*:NJO?&7\/1IT^JS`!8-3`Y=C,@L,;`R:97
M`*9^`*9^`%EA:&]O("$@IF&YSP"H0Z9^`%EE;65N("BXK:KY*0"L3P"L3ZJZ
M+*?:IE"W3@"G0:6_IF+`?+C5I=&D5:9#L6*XN::LJ/JE?K.AMFRE\SH`IT&E
MOZ9BP'RXU:=2L*.D5:9#JTBE\Z=8I*2JNJG2IK.V;*7S+@"G0:6_IF+`?+C5
MIU*PHZ15ID.K2*7SIU@N`*=!I;^F8KW&NW,OMVBROJCLI$"MT[=SJTBE\Z=8
M+@"G0:6_IF*KV*7?MW.JNJ:XJTBE\Z=8J.P@`*=!I;^F8JO8I=^D0*W3L\RD
M5[QHJKJK2*7SIU@N`*=!I=BK9:C/I<ZOPJ3EIG*]<[QGO-*FH2X@J,^ESB!;
M/#Y=(*OVMG.E::3!M*NLL+KTK;:]<[QGO-*FH2X`IT&H4Z:SJ]BEWZM(I?.G
M6*JZQ7:MK2X`I*.DN;-<IT&KV*7?)62E2*17JKJPS[;T+@"DHZ2YLURG0:O8
MI=\E9*W3I4BD5ZJZJTBE\Z=8+@"G0:6\LU&QPL5V+@"G0:6_IF*LL*M(I?.G
M6*?SMW.F5[K9.B``IT&E::5(IF*K2+K@I*2HSZ7.I%6F0ZMEN&VF<J2X.B`E
M8R"J[:7<I=BK9:M(I?.DI*JZI+JN93L@)7,@JNVEW,.QIE<N`*=!JKJE_J97
MI*2DHZ5IIK,@)UPG(+-OO,NJNJ9RI+@N(`"G0;5,JFNH^J[XK7&^7"`B)7,B
M+@"G0:E\I;RF4+=.J,^ESK'XM-HLM4RJ:\7]IT&U;J1*+@"G0:C#I;R_Z:1*
MI$"MTZ:SKL2JNKEQI&RV;*7SINRG?2X`IT&HPZ6\I=&VUZ1*JKK`R:[7I*2Y
M[ZQ-I?2F\\3FINRH["`E<P"G0:A3IK/%W*?SIKFK2*7SIUBF<ZCZL;&H[JJZ
MQ7:MK0"G0;2_N&>I\R`E)7,@PN"Q2+-OJ\JK2*7SM;FS;ZC'I$@Z("5S+@"G
M0::S("5S(*O*MW.V;*7S`*=!IK.D0*O*MW.V;*7S`*=!I'>P9:58IKFMMJVQ
M+@"G0:1WN&>U;J58+@"G0:9BI%6F0ZM(I?.G6*2DIK.W<[9LI?,Z`*=!IF*D
M5:9#MFR]8Z2DIK.W<[9LI?,Z`+W0O^FD2J1`K=.FLZ[$JKJY<;C<N+F]6"RP
MZKO:N7&XW+BYO5BVR*5UI+FS7+S&IG*XN;U8+*C#M?BQH:IPI6FI\ZMEK;&F
M0:5;I$"MTR`G*R<N`*=!I;*VM[_II$JD0*W3IK.NQ*JZK<@N`*=!I;*VMZ7]
MLU>YNJ9NOO"JK+CJKL8H1&%T851R964IIOBJ0;K=I'ZOX,1^Q/*HSZ7.MW.E
MSJ3AM?FE5:I!L,@N`*=!I;*VMZ7]LU>YNJ1`K=.UZL#`P,FNUZATLLXH5D93
M*:;XJD&ZW2X`O="T>:UZL-W#1*%!IF*G0;;'L&6PW<-$L_BG::2GJV4N`*=!
MI;*VMZ;<I-:_Z:1*I$"F[*:LI?.Y[[9(+@"G0:6RMK>_Z:1*IKFS<[6RJ=*K
M_*96JKJZ]*=]`*UNP,NU^*:YMFRE\Z6RMK>E_;_II$JG0:JZ(%!'4""MTZ1(
MJO?&7[%+O5@N`*UNP,NU^*:YMFRE\Z6RMK>E_;_II$JG0:JZ(%,O34E-12"M
MTZ1(JO?&7[%+O5@N`*VZI?VA0:=!I;*VMZ7]O^^^W*1`K=.EV*JZJTBE\Z=8
M+@"G0:6RMK>E_;_OOMRD0*W3K6ZG4K"CJKJQ8KBY+@"MNJ7]H4&G0:6RMK>E
M_;_OOMRD0*W3IF&G?2X`O="K_*EWK6ZG4K"CJKJF^*I!OKDN`*VZI?VA0:=!
MI;*VMZ7]O^^^W*;<I-:D0*O*MFRE\RX`IT&ELK:WJ_RI=Z1`K=.FK*7SI$@N
M`+W0J_RI=ZUNLDVPHZJZJ,^ESJK,+@"]T*O\J7>M;K*^L*.JNJC/I<ZJS"X`
MO="K_*EWK6ZW<[Q7JKJHSZ7.JLPN`+W0J_RI=ZUNI_.W<ZJZJ,^ESJK,+@"]
MT*O\J7>M;K#UIN:JNJ=`I<XN`*=!I;*VM[_II$JW<Z3`P_ZJNJ97NMDN`*=!
MI;*VMZUNIF*Z^\5`OMZG0*JZO^^VM:2DI,2_[R`B)7,B+@"G0:6RMK>THZC1
MI$"MT[AQI&JG4;G2I+JJNKEQN-RXN;U8`*=!I'>I\R`E)3(D<R#"X*=]N[RP
M9::YJTBE\[6Y("4Q)',N`*=!I'>I\R`E<R"F7L+0IKFK2*7S+@"G0:C#I;RM
M<;Y<("(E<R(NIOBJ0;ZYIE[`LP"G0:C#I;RH^J[XK7&^7"`B)7,B+J;XJD&^
MN:9>P+,`IT&D=Z:HI5RM<;Y<("(E<R(`IT&D=Z:HI5RH^J[XK7&^7"`B)7,B
M`*=!JKH@)7,@MWRTP:1WN4RNR2Z]T*VKMW.U;J1*+@"G0:JZN7&D;+9LI?.F
M[:=]`*=!JKJQ2*7SI$BY<:1LMFRE\Z;MIWTZ`*=!JKJXZK!4`*;;L7&G0:JZ
M("5S(+=\M,&V?:ELI4BHTZ=!JKJZ]+O:NO2X]*;LIWVD=\7<I_,N(*RPJT_%
M0*=!JKJF=Z7^L%^HHZ%!IT&ELK:WK:NW<[5NI$HN`*=!JKJF5[K9`*=!JKH@
M4$=0(*2]MGTOJ'"Q2ZKWQE\`IT&JNJAPL4NJ]\9?`*=!JKJDO;9]JO?&7P"[
MU:15JKJF7K9LIF&G?2`\96T^**M$I;*VMZJZ*3PO96T^`*=!JKH@4R]-24U%
M(*2]MGTOJ'"Q2[[,P](`I7ZSH;9LI?/#T:=/IE>ZV3H`N]6D5:JZIT^F5[EQ
MI&RV;*7SIF&G?3H@/&5M/BBK1*6RMK<LIG"FLZ9HM:>]T*5(MW.FYK_II$HI
M/"]E;3X`IT&JNL7GP]*F^*I!NMVHPZ2CI.2TJ;=SO%>HSZ7.JLPN(*9PJD>G
M0:?&L>:ZWK)ZJ,^ESJK,L6*XN2RG0:6RMK>E=+_OJ.2E3*JZQ>?#TJ;XJD&Z
MW2X`IT&JNL7GP]*ZW:C#I;RDY+2IID.E6*C/I<ZJS*G.N-.E7*_@I'>S4</V
MLZPN`*;;L7&G0:JZ("5S(+=\M,&V?:ELI4BHTZ=!JKK"<\3]OKFF_*5'I'?%
MW*?S+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!I;*VMZVKMW.U;J1*+@"G0:JZ
MPG/$_;ZYJ,.EO*3DM*FFN;K8N<^D^:[FIJ&JNJJ]L;7%XZ7<+@"G0:JZPG/$
M_;ZYJ,.EO*3DM*FS;ZW3I5ROX"X`IT&JNL)SQ/V^N:C#I;RDY+2IID.F3+_O
MMK4NO="K]B!#5%),+T-O;6UA;F0@*R!0(*9#IDPN`*=!I=BK9:G2LUVI=ZJZ
MKLFPSSH`ML>P9;9LI?.JNKEWLUV]<[U8I.BFH3H`ML>P9;9LI?.JNKEWLUVE
M6[%+I.BFH3H`N]6D5;EWLUVJNJBMI??#T:=/I'?%W*?S+@"[U:15N7>S7:JZ
MJ*VE]\/1IT\Z`*=!JKJE_J97.@#"X*9SK+"Z]*=]JKJJ_J7SI'>S4:1`K=.E
M2*17JKJFK*7SN>^V2*15N/PN"@JJ_J7SIE>ZV3H@)7,*JOZE\Z3IM,$Z("5S
M"@K"2;_OI%6F0[-SM;*E2+*^L*.XTZK^I?,Z"B5S`*=!JKJU;J1*I'>H[+3!
M+@"G0:JZMFRE\Z1WN[RP9:>YIJ@N`*=!IF(@)7,@I*2JNK=SL4N]6*Q/.B`E
M<P"G0:9BM6ZD2K3!MJ&JNK_OMK6D=[-1I_.W<RX`IT&JNK_OMK6D=Z?SMW,N
M`*=!JKJQ2[U8I'>MJ[=SLUVI=P"Q2[U8I'>S4:VKMW.S7:EW++=SJKJQ2[U8
MI'>S>KE,N7&D;+9LI?.Q2+5OO="E2+C3L4N]6+5NI$HN`*=!JKJQ2[U8I'>H
M[+3!+@"G0:JZN[>ZW:;XJD&^N3H`IT&JNL.QIE<Z`%EU9V]S;&%V:6$@**MN
MM+6IU*32*0!:86ER92`HPL2E["D`6F%M8FEA("BI?*3QJ,@I`%II;6)A8G=E
M("BHKZ3:J\(I`%O!],+#INVG?5T`6\'TPL.DWJUZ70!;M4RE1*:N70!;L-W#
M1*3/K$U=`%O%XZ7<INVG?2`M`%O%XZ7<I-ZM>B`M`%O%XZ7<I-ZM>B`M("5S
M(*;F70!;Q>.EW*;MIWT@+2`E<R"FK*7SI$A=`%NF[*GSIN8@)7,@ID`@)7,@
MIN9=`+K>LGI?00"OM:7SL,:ENU]"`+;"IE>SYE]"`*E2I4^F0U]#`+#&I;M?
M0P"^\*JLN.JNQE]$`*=2L*-?1`"G4K"CID-?1`"K2*7SIUA?1@"X<[+57T<`
MNZ&I^E](`*BMI??#T:=/7TD`O':YLZ2ZKF5?22XN+@"FK*7SIUA?20"U;J1*
M7TP`M6ZE6%],`,#+M?BM[*ELP,E?30"MUZ?OLW.ULE]-+BXN`+QGJTA?3@"_
M[[:U7T\`Q7:MK5]0`*3-M;VF0Z9,7U``P'6E_5]0`*VKMW.^X[)Z7U(@)7,`
MLKZPH[GOLW.ULE]2+BXN`*9>PM!?4@"W:K1-7U,`ML>P9;9LI?-?4P"S7:EW
M7U,`JNVNYJ2ZKF5?5"XN+@##]L%P7U0`IJRE\Z1(7U0`M%^M[*1WIU*PHU]5
M`*C/I<ZJS%]5`,/VP7#`R[7X7U8`I,VUO:97L^9?5P"S<;!4O_T`I;RJOJJZ
MMFRE\Z;MIWT`JOZE\P!A='1A8VAM96YT<RYZ:7``8GET97,`IN:HQK[D`+5,
MJFNKV*7?O^FE6,#)KM<N`+5,JFNV?;'2O^FD2@"K]J:Y`+%+I4^F0[MYJFN_
M^;M^`+-=J7>_^;M^`+_RI:*MJZUNJKJH=++.P,FNUP"XZJ[&KN:FH;_YNWX`
MI^2DHZCLL$^__0#`R:[7`+%Q`+%Q("5S("@E<RD@J?,@)7,@)7,`L'VMMP"N
MR3H`KLD`I;RJOJJZMFRE\Z5$OO>F5[K9`*7?IUD`JKVQM<7CI=RI\Z6[I.6P
MSP"_Z:1*+[_II5B_^;M^`*2ZLZ&S;L7IO_F[?@"J]\9?`*;F70"V;+UCP,FN
MUP"DP`"F5[K9`*A3IK,`J7REO+GJIT`N`*E\I;RYZJ=`+@"SQJ?1O_T`J<ZJ
MS`"FRJ3`I/$`IG.H^KY$J=H`N;.OP`"FK*7SI$A=`+-QJTBH\ZEWN[>ZW;_Y
MNWX`I%>DR0"U3*5II<ZJNJI!L,@`Q>.EW*YTLJ<`<VUS,F5M86EL(+AGI=$@
M2%144`"MTZOWIG*_^;M^`*W3J_>F<K_YNWX`K.T`PZVI=P"H=++.O_F[?@"K
MW;_LPZ\`O,BNR:G*JKJEHK'1`*9!IKB_Z:1*IT&JNK%+O5BE2+U4NWNU3+M^
M`+[CIE@`I;RI4J97`*C/I<ZJS+_OOMP`=D-A<F0`K%"TP3H`=V5A=&AE<BYC
M;VT@NO2ON`"G0:JZML*F5[/F`*=!JKJDS;6]IE>SY@``+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O;&]C86QE+WIH7U17+VAE;'`N>&UL````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<W,S,R`#$P-#$W,S8R-S8S
M`#`R,3$V-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)":6<U(C\^"CPA
M+2T@)$AO<F1E.B!I;7`O;&]C86QE+WIH7U17+VAE;'`N>&UL+'8@,2XR,"XV
M+C4@,C`P-B\P,B\Q,"`Q-#HP,3HU,"!J86X@17AP("0@+2T^"CQH96QP/@H@
M(#QE;G1R>2!I9#TB8V]M<&]S92UB=71T;VYS(B!M9#4](C,R-3EB83`P83$Y
M.#4U.6,W9F%A-S9E-S@V-S8P,&0Y(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@
M/'1I=&QE/K9LI?.\9Z=`.B"G0*7.I.BFH3PO=&ET;&4^"B`@("`\:&5A9&EN
M9SZG0*7.I.BFH3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@(K;'L&6V;*7S
M(B#%5:97J^2X<;1.K$^Q3J=!JKJV;*7SI^N[O*58I6BUN:=!J=*GQK'FIJRH
M[*JZI$BA0Z9BIT&K]J:YJ_:V<Z2GJV6]T+U4NWNFK*7SN>^V2*%!IEVLL+9L
MI?.D0*;]L&6E6*OAM$ZU3*IKJ/JF7J%#"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@("*F<ZRPK_.]6B(@L4ZEO*>YIJBJNK9LI?.F<ZGQJ?.K2*7SIU@@
M(D1R869T<R(@I*2A0;JXJ^&G0:5II4BX9Z71I6ND5Z3HJKJK2*7SIUBD5:G4
MI5ROX*KMMFFD2J_SO5JG6"`G1')A9G1S)R"HP\))O^\@)\1^Q/*]<[QG)R"E
M2*>YIJBXT[9LI?.A0Z3!L$^F8J=!L4ZV;*7SIG.LL*_SO5JK9;W0K+"XT[9L
MI?.V\;QGI42FKJ5(I.BK2Z3IJ^&_Z\/1H4,*("`@(#PO<&%R83X*("`@(#QT
M:7`^"B`@(""U^*=!JKJF=[C+L:&J<*;3J7>A0:=!I6FE2*9BL+ZF;K_OMK6D
MI+-=J7>D0*;]P'BF<ZRPK_.]6JOAH4&F7JCLK>S`R[7XI*2JNJM(I?.G6*G.
MK$^F7JCLK>RK2*7SH4,*("`@(#PO=&EP/@H@("`@/'!A<F$^"B`@("`BJ/JN
M^+9LI?,B(,55IE>KY+AQM$ZL3ZGQL?.EV*MEJ=*EOZ9BO7.\9ZJZMFRE\ZC#
MIEZH[*WLI?VITJ6_IF+`R[7XJKJK2*7SIUBDI*%#"B`@("`\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M9G)O;2(@;60U/2(X,F-F
M,C1D,S%A-C8W835B.31E-#@Q8V0U,3<Y8S4R.2(@<W1A=&4](G5P=&]D871E
M(CX*("`@(#QT:71L93ZV;*7SO&>G0#H@L4BE\Z1(/"]T:71L93X*("`@(#QH
M96%D:6YG/K%(I?.D2#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@IG"J1[K>
MLGJM^Z2YLURG0:9BIKFHSZ7.IT&JNKEWJ]BHK:3`P]&G3Z%!IT&E::5(I=&D
M5:G4I5ROX*KMO^^^W*1`K=.ET2`\<70^O^^VM2TF9W0[K=.D2+CJL%0\+W%T
M/JG2J]BEWZJZJ*VDP,/1IT^A0:G.JLRG0:1=I6FE2*9BQ.:F[*2DJKVQM;_I
MI$JG0:JZMFRE\Z9AIWVE2+?MIT"XTZM(I?.JNK%(I?.D2*9AIWVA0PH@("`@
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+71O(B!M
M9#4](C,Q8V)A,3=F,38Y-3<R8S,V-V%A.#`Q-#@S,65B.&8X(B!S=&%T93TB
M=7!T;V1A=&4B/@H@("`@/'1I=&QE/K9LI?.\9Z=`.B"FK*7SI$@\+W1I=&QE
M/@H@("`@/&AE861I;F<^IJRE\Z1(/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M(""LL*=!JKJK2*7SO^FD2J:LI?.Y[[9(JKJY<:1LMFRE\Z;MIWVA0Z9PJD>G
M0:JZIJRE\[GOMDBLL*1'I$BE2*17H4&]T*C/I<ZS<KBYJ-.PS[EJI*.F4*JZ
MN7&D;+9LI?.F[:=]H4&E2,'7ITN_^;M^M6^ES:%#"B`@("`\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M8V,B(&UD-3TB.3<U-S$T
M,S-A8C`S-V5F.6,T9#$P,6$U-F)F-S1E,C4B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^MFRE\[QGIT`Z(+#&I;L\+W1I=&QE/@H@("`@/&AE861I
M;F<^L,:ENSPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@K+"G0:JZJTBE\[_I
MI$JPQJ6[IJRE\[GOMDBJNKEQI&RV;*7SINVG?:%#IG"J1Z=!JKJPQJ6[IJRE
M\[GOMDBLL*1'I$BE2*17H4&]T*C/I<ZS<KBYJ-.PS[EJI*.F4*JZN7&D;+9L
MI?.F[:=]H4&E2,'7ITN_^;M^M6^ES:%#"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@(+#&I;NFK*7SI$BS<;%@NU"V;*7SJ,.U3*J]L;7#]JM9H4:X9Z71
MJTBE\Z5$IJZJNJ?CK6Z[H:GZIVRDWK#&I;NFK*7SI$BJNL/VJF"HP\#RJ/JV
M;*7SJ=*THZC1JKJP5*ZGH4.ITJ:SJKHBIJRE\Z1((J:LI?.Y[[9(NU`BL,:E
MNR*FK*7SN>^V2*9BI4RMS*G2IJRH[*JZJTBE\Z2DH4&SHZ5IK-VHHZF\IKFS
MHZQ/JTBE\ZJZIJRE\[GOMDBDIZ1`H4,*("`@(#PO<&%R83X*("`\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB8V]M<&]S92UB8V,B(&UD-3TB86$X9CEE,F0T-&9D
M8C<T9&5F,&9A,34R-#!F9C8X-V(B('-T871E/2)U<'1O9&%T92(^"B`@("`\
M=&ET;&4^MFRE\[QGIT`Z(*^UI?.PQJ6[/"]T:71L93X*("`@(#QH96%D:6YG
M/J^UI?.PQJ6[/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""_Z:1*K[6E\[#&
MI;NFK*7SN>^V2*JZN7&D;+9LI?.F[:=]H4.F<*I'IT&JNJ^UI?.PQJ6[IJRE
M\[GOMDBLL*1'I$BE2*17H4&]T*C/I<ZS<KBYJ-.PS[EJI*.F4*JZN7&D;+9L
MI?.F[:=]H4&E2,'7ITN_^;M^M6^ES:%#"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@(+-QL6"OM:7SL,:ENZ7.J?.A1Z9BI*.S4:CDI4RFK*7SN>^V2*J^
MN42JNK&AI\ZD5::LJ/JK2*7SH4.OM:7SL,:ENZCCIK.PSL+<JKJNQ*I'H4&H
MY*BMI?>PHZ1&L4BE\Z1(NU"OM:7SL,:ENZ:LI?.Y[[9(I;NHK:%!JTBE\Z2D
MJKJHY*5,IJRE\Z1(J,.U3*IKL6^JOJ%#"B`@("`\+W!A<F$^"B`@/"]E;G1R
M>3X*("`\96YT<GD@:60](F-O;7!O<V4M<W5B:F5C="(@;60U/2(P-C,Y83@W
M.3!E,S`V86-C.64Q.6(T9#%C93,T,F0U,R(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93ZV;*7SO&>G0#H@I42FKCPO=&ET;&4^"B`@("`\:&5A9&EN
M9SZE1*:N/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""_Z:1*MFRE\ZJZI42F
MKJ%#NLFE::_@I4C"LK/FI^.M;JJZM'FM>JC3NZ&I^J5$IJZA0Z5$IJZL3[/,
MKF6I]L7]I$BOX+#WIF*DZ:OAIEZW4;!?LV^KRK9LI?.DNJYEJKJDZ*IKH4&F
M7::YIF*DZ:OALM7"M+M0M$VGY+9LI?.E1*:NM$ZG\\7CL6^MJZUNJKJA0PH@
M("`@/"]P87)A/@H@("`@/'!A<F$^"B`@(""FTZ5"H4&W[:=!(J9>PM`BJ<XB
MPN"Q2"*V;*7SKLFE1*:NI%VQ3K=\I$"HUJGQMFFW<[9LI?.DI*%!IG"FN:1`
MJ-.V;*7SI*>VH:1^K^"KK*:HI$"ZV,/VP7"A0[5-IM.A0:9PJD>G0;GO(J9>
MPM`BJ<XBPN"Q2"*JNK9LI?.DNJYEI*2PM:1&J,>S7*JZI^_%W*%!J<ZS7*=!
MI6FE2*;2O'NF8B*E1*:N(J17O%>E6ZC'LURJNL7<L,JA0:9PIKFITJ:SJKJF
MK*M(N>^V2*1^K^#$?L3RJ,RT8*:YI$`BP_;!<"*A0PH@("`@/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+6]P=&EO;G,B(&UD-3TB
M-68Q9#4P83<S,V,X8C=E-#9A96-E8V4R.#@R,F9F-S`B('-T871E/2)U<'1O
M9&%T92(^"B`@("`\=&ET;&4^MFRE\[QGIT`Z(+_OMK4\+W1I=&QE/@H@("`@
M/&AE861I;F<^O^^VM3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@LV^HQ[_O
MMK6ESJC3P+"G5:=!O7.\9[9LI?.A0PH@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("#"2;_O(JOWO&?`RZQD(J%!P,NL9+9LI?.DNJYEJKJSYJ3EJ_>\9ZQ/
MIU^FL[M^H4,*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@PDF_[R*J_J7S
M(J%!I]:S=*3!M*NH[*VVK;&D5:3HJKK`R:[7JOZE6ZOVMG.A0<7]IT&J_J5;
MP,FNUZCLMFRE\Z2DH4,*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@IG"J
M1ZATLLZZWK)ZK?NDN;-<IT&Q3K%(I?.SQJ3`H4&G0:5II4BDQ+_O(K%(I?.S
MQJ3`(J5(P'BF<Z=!JKJQ2*7SH4.Q2*7SL\:DP*JZINRX;;-QL6"LL+EWLUVK
M2*7SIUBISJQ/IF(BO^^VM2TF9W0[K=.D2+CJL%0M)F=T.ZBMI??#T:=/(JG2
MJ_RI=ZJZJTBE\Z=8H4.F<*I'J'2RSKK>LGJM^Z2YLURG0:;;IN:H3:EWL4BE
M\[/&I,"G6*%!IT'!V:5II4BS>KE,I%6IU*5<K^"J[;_OOMRHY*5,JKJK2*7S
MIUBSQJ7WH4,*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@K+"MJZUNJKJQ
M2*7SL\:DP*5(J-&DZ:OAL$^__:%"L-&FTJQ/I$"ZV*9NJKJRW[I$H4.G0:5I
MI4C"QZ71PDF_[R*_[[:U+29G=#NMTZ1(N.JP5"TF9W0[O7._Z*=!JKJHK:7W
MP]&G3[CJKL8BK+"H0ZW3J*VE]\/1IT^JNK%(I?.SQJ7WI5ROX+EWLUVMR+-=
MJ7>LL"*QTJ7.(J%!IE"NR:9BO^^VM:2DIT&D7:5II4BS7:EWI$"HQ[K[Q4"D
M=:=`Q?VH=++.K^"I=Z[)LDVJQ:G.I_.F5[-OJ,>K2*7SIUBA0PH@("`@/"]P
M87)A/@H@("`@/'=A<FX^"B`@(""ET:GSNL^ZT*K%MJ&MK:CNJKJFTK9QH4&G
M0:2CI$"I=[O=K6ZLL*A#I$"KRK%(I?.SQJ7WH4&O4Z=/K$^W[;%(M6^G=*:S
MI&JJ_J5;P,FNUZ[)H4.W[;K/NM"JQ;:AI*.HK*[)IT&Q3K5,JFNF0::LJ.RE
M]*;SJKJW<[9LI?.A0R(*("`@(#PO=V%R;CX*("`\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB8V]M<&]S92UA='1A8V@B(&UD-3TB93@P-F4U93$V-#%F8C(U,S%C
M8SDU9#)D9C(W-S@U,68B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^
MMFRE\[QGIT`Z(*K^I5O`R:[7/"]T:71L93X*("`@(#QH96%D:6YG/JK^I5O`
MR:[7/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""F<*I'IT&JNL)SQ/V^N:3D
MM*G`R:[7I%>VQZ5<K^"A0:=!I6FE2*1`IKBJ_J5;O,:MT\#)KM>A0PH@("`@
M/"]P87)A/@H@("`@/'!A<F$^J$+&2B`Q.B"_Z:1*P,FNUZJZN/2N?+M0IE>Z
MV:G.JLS"2;_O(L)SQ/TBJ_:V<[_OOMRM;JK^I5NJNL#)KM>A0[)[IF+`R:[7
MJKJX]*Y\NU"F5[K9P+.XTZ58LGNF8JK^I?.DZ+;TI*2A0PH@("`@/"]P87)A
M/@H@("`@/'!A<F$^J$+&2B`R.B"H3:EWJOZE6\#)KM>F8K9LI?.DI*JZIV6R
M>Z3HIJ&L3Z5(JOZE\ZG.JKVQM<7CI=RI\Z6[I.6A0Z9PJD>L3ZJ]L;7%XZ7<
MJ?.ENZ3EH4&FK*7SN>^V2*JZMFRE\[Y<Q:JS;L7II;*VMZ_@I.2TJ;C3JZRZ
M0:JZJOZE6\#)KM>A0:=?JVBDM+=\K$^E2*K^I?.JNJ3HIJ&G9;)[H4,*("`@
M(#PO<&%R83X*("`@(#QP87)A/JA"QDH@,SH@PDF_[R`BJOZE6R(@J_:V<Z%#
M(+C3P,FNUZ97NMFDSJ1JI'"Q3K-1MW.\5ZCLJOZE\[)-L^:DI*%#"B`@("`\
M+W!A<F$^"B`@("`\=&EP/@H@("`@O="J8+=.N>^I\[C[I&JJNL#)KM<@I,XO
MJ<X@N/NZ0ZJZNO2X]+-SO76S=*O7H4&S;ZW3J$+&2K%.MWROT[9/I$"HQZ[)
MMJ&A0PH@("`@P,FNUZ17ML>TP;:AO="M0*3?M:6MU*C#I4*DHZUNPDF_[ZCD
MI4RS<[6RMWRK]K9SH4,*("`@(#PO=&EP/@H@(#PO96YT<GD^"B`@/&5N=')Y
M(&ED/2)C;VUP;W-E+6%T=&%C:&UE;G1S(B!M9#4](CAA8S`S,F,T86,Q.#)F
M,V8P9#8T-#9C,C!F,#`X.61D(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/K9LI?.\9Z=`.B"J_J7S/"]T:71L93X*("`@(#QH96%D:6YG/JK^I?,\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(*:YL,^P[,7CI=RV;*7SI*2ITJ:S
MJOZE6\#)KM>R3;/FH4,*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/J=2L*.J
M_J5;P,FNUSPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@L?VG4K"CJOZE6\#)
MKM>JNJA"QDJF<*15.@H@("`@/"]P87)A/@H@("`@/'!A<F$^"B`@(""H0L9*
M(#$Z(*3$O^^D=ZK^I5O`R:[7I%6DZ*JZIU*PHZ3HMO2A0PH@("`@/"]P87)A
M/@H@("`@/'!A<F$^"B`@(""H0L9*(#(Z(,))O^\BQ=RG\R*A0PH@("`@/"]P
M87)A/@H@("`@/&AE861I;F<^Q=RG\ZK^I?.P=+AM/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@(""Q_<7<I_.J_J7SL'2X;:JZJ$+&2J9PI%4Z"B`@("`\+W!A
M<F$^"B`@("`\<&%R83X*("`@(*A"QDH@,3H@J?.J_J5;P,FNUZ15I.BJNK!T
MN&W$YJ;LO^^H^B*JO;&UQ>.EW*GSI;NDY;#/(JG.(JK^I?,BH4,*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@J$+&2B`R.B#"2;_O(L7<I_,BH4,*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/L7<I_.J_J7SM'FM>CPO:&5A9&EN9SX*
M("`@(#QP87)A/@H@("`@Q=RG\ZK^I?.T>:UZJKJH0L9*IG"D52`HJ=*FLZ:L
MI?.Y[[9(L4ZW?*S=J.RFN:1`M'FM>BDZ"B`@("`\+W!A<F$^"B`@("`\<&%R
M83X*("`@(*A"QDH@,3H@J?.T>:UZQ.:F[+_II$K"LK5UL=2M>J%#"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@(*A"QDH@,CH@PDF_[R+%W*?S(J%#"B`@
M("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](F-O;7!O<V4M<')I
M;W)I='DB(&UD-3TB8C`R,S,V-V,S-F1E,V-E,34V-V0R-V-C86$T-38T,&,B
M('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^MFRE\[QGIT`Z(,!UI?VV
MMJ?'/"]T:71L93X*("`@(#QH96%D:6YG/L!UI?VVMJ?'/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@(""FN;_OMK6ESJC3LUVI=[%(L&6V;*7SJKHB6"U0<FEO
M<FET>2*J[<!9H4,B6"U0<FEO<FET>2*L3R!.971S8V%P9:%"36]Z:6QL8:%"
M3W!E<F%RI,X@3W5T;&]O:R"UI;9LI?.^7,6JLV[%Z:G2NWNE::JZI$"ZV"*U
MZL#`(B"\T,72H4.ET:GSJ.2E3*JZMFRE\[Y<Q:JS;L7IJ,.DHZ3DM*FS;[K8
MJNW`6:G2I4BQ3K=\J;^RI+9LI?.DI*JZP'6E_;:VI\>A0PH@("`@/"]P87)A
M/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)C;VUP;W-E+7-A=F4M871T86-H
M;65N=',B('-T871E/2)U<'1O9&%T92(@;60U/2)D8C@Y.3<R8S1E8F(P8C0Q
M86(V.3%B-F$W-S0T83@Q9"(^"B`@("`\=&ET;&4^MFRE\[QGIT`Z(,!XIG.J
M_J7S/"]T:71L93X*("`@(#QP87)A/@H@("`@J$VI=\!XIG.Q2*7SL\:E]Z[)
MH4&L3Z=?I%VM;J1`J-;`>*9SL4BE\Z2DJKJJ_J5;P,FNUZ%#IG"J1R*L3R*A
M0:K^I5O`R:[7L4ZW?,!XIG.A0Z9PJD<BIU\BH4&J_J5;P,FNU[%.J?.V;*7S
ML4BE6*OAI6BPHZ;3I*.W?+-1P'BF<Z9BL4BE\[/&I?>G6*2DH4._[[[<(J=?
M(JJZIFZS0JQ/H4>E:<+'I=&E:+"C**1JJZR\Y\+#*:K^I?.A0;A@K-FV;+UC
MNL^ZT*K%MJ&A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)S96%R8V@B(&UD-3TB.#9B,F5F-3=B,3$Y-#@Y,#@S,V0Y9&0T.65B8SEB
M,S(B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^MFRE\[=JM$T\+W1I
M=&QE/@H@("`@/&AE861I;F<^MVJT3;'XI?,\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(,+'I=&DHZ90JKJW:K1-L?BE\Z=!I6FE2+=JM$VITJ:SJTBE\Z=8
MI*2JNK9LI?.A0PH@("`@/"]P87)A/@H@("`@/'!A<F$^J$+&2B`Q.B"I\[']
MMVJT3;'XI?.JNL3FINRDI+_II$K#]L'DI.6F<J%#"B`@("`\+W!A<F$^"B`@
M("`\<&%R83ZH0L9*(#(Z(+_OOMRV;*7SO-##T:C#I5ND2JCLMVJT3;'XI?.D
MI*%#"B`@("`\+W!A<F$^"B`@("`\<&%R83ZH0L9*(#,Z(+_OOMRM;K=JM$VJ
MNJM(I?.G6*%#"B`@("`\+W!A<F$^"B`@("`\<&%R83ZH0L9*(#0Z(,))O^\@
M(K=JM$TBH4,*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@IG"J1Z:SI?2F
M\ZJZMFRE\[M0IT&JNK=JM$VQ^*7SK-NRQ:%!"B`@(""XT[9LI?.JNJ5$IJZQ
M3L7CI=RI\R*W:K1-(K6RJD>JNK5EK;&DI*%#"B`@("`\+W!A<F$^"B`@/"]E
M;G1R>3X*("`\96YT<GD@:60](F9O;&1E<BUO<'1I;VYS(B!M9#4](C,P-C@W
M96,T-S4W-C5B830T-C=D,F5F-F1C96,T,&,S(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/JM(I?.G6+K>LGH\+W1I=&QE/@H@("`@/&AE861I;F<^
MJTBE\Z=8O^^VM3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@(""G0:5II4BD
MQ+_OI:JDZ,3FINRDI*JZI$"MTZM(I?.G6*%#M4VKX:9!I%6IU"*_[[[<IT"E
MSJ3HIJ$BI5ROX*KMH4&HP[_OOMRD0*W3IT"ESJ3HIJ&HT[GOJ=*_[[[<JKJK
M2*7SIUBV::;FOMZG0*%#"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@("`@
MIT&Q3K=\LU&M;JA$O^FD2JC'LURJNJS;P_:^WJ=`N.JNQJ%#O="D<*3?JKJP
M]:;F(J=2L*.K2*7SIU@BI,XBLDVJQ:M(I?.G6"*S;Z1'NMBG0+=^H4&F7:RP
MJTBE\Z=8I$"EN;Y$IU*PHZG.LDVJQ:%!J.2DI*JZMFRE\Z1=L4ZD0*C6KOBE
MHK5,JFNF7K1?H4,*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/K;7I$H@;6)O
M>""KK+I!N7&D;+9LI?/`R:[7/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("`@
M(+-OK=._[[:UL4ZVUZ1*I$"MTR!M8F]X(*NLND&Y<:1LMFRE\\#)KM>H[*=!
MJ=*_[ZEWJKJK2*7SIUBDI*%#O^^^W*1`K=.M;K;7I$JV;*7SJKJK2*7SIUBU
M3:OAID&_[[[<LV^MT[_OMK6A0Z2GJ^&G0;%.LU&DWK[)J.RE=*1`K=.MMJVQ
MI*2V?:ELL/6FYK;7I$JPRJ=`H4,*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB9F]L9&5R+7=I9&=E=',B('-T871E/2)U<'1O9&%T92(@
M;60U/2)B.6)C-C@Y-#`R9C<U-S4W-S%D-S0U-S!E-V8V9C@P82(^"B`@("`\
M=&ET;&4^JTBE\Z=8NMZR>CH@Q>.EW#PO=&ET;&4^"B`@("`\:&5A9&EN9S[%
MXZ7<+\'TPL,@I;RM<;Y</"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""F<*I'
MJ,^ESB!)34%0(*M(I?.G6*UQOERA0<7CI=POP?3"PZ6\K7&^7*JZJTBE\Z=8
MH4.Q_:UQOEPOJ/JN^*UQOERK2*7SIUB]T*7]I,2_[ZM(I?.G6*%!ID&ET:=`
MI<ZDZ*:AI5ROX*KMI%6IU+_OJ/JM<;Y<+ZCZKOBM<;Y<H4,*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/JYIMGT\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(*YIMGVITJ:SJKJK2*7SIUBA0PH@("`@/"]P87)A/@H@("`@/&AE861I;F<^
MNE#%?#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@NE#%?*G2IK.JNJM(I?.G
M6*%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E
M<G,B(&UD-3TB-65F-C`W.#8W-C=E-C,X9F)F-6)A.&9C-6)D-60Y9#(B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^MFRE\[E,PF\Z(*Y-I<X\+W1I
M=&QE/@H@("`@/&AE861I;F<^KDVESJG2IK.S5ZMH/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@(""F8K9LO6/`R[7XM66ML:2DPDF_[Z:LI?.G6*['P^2JNB*V
M;*7SN4S";R*YSZ7<H4&E2*Y-I<ZK_*EWJKJS5ZMHJ.P*("`@(*G2IK.V;*7S
MI%>A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT
M97(M961I="UR=6QE<R(@<W1A=&4](G5P=&]D871E(B!M9#4](C5B86$U-S`X
M86,Y-#0Y93<Y-V8Y-C<S,3-A.64Q83(W(CX*("`@(#QT:71L93ZV;*7SN4S"
M;SH@O7._Z+E,PF^S5ZMH/"]T:71L93X*("`@(#QH96%D:6YG/KUSO^BG0:JZ
MN4S";[-7JV@\+VAE861I;F<^"B`@("`\<&%R83X*("`@(,))O^\BO7._Z*=!
MJKJY3,)OLU>K:"+%_:=!MW.\5Z%!IU*PHZ5(I,Z]<[_HI=BK9:1WL=*PRJJZ
MLU>K:*%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](F9I
M;'1E<BUE9&ET+6)L86-K;&ES="(@<W1A=&4](G5P=&]D871E(B!M9#4](C@P
M9F8W.#`S8S8V-3DY8S<P,S5F-V8X.#$Q9#(Q.&-C(CX*("`@(#QT:71L93ZV
M;*7SN4S";SH@O7._Z+;"IE>SYCPO=&ET;&4^"B`@("`\:&5A9&EN9SZ]<[_H
MIT&JNK;"IE>SYCPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@PDF_[R*]<[_H
MIT&JNK;"IE>SYB+%_:=!MW.\5Z%!IU*PHZ5(I,Z]<[_HI$"E]Z=!I<.[MZ2C
MMU&FK*M(JKJY<:1LMFRE\Z97L^:A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^
M"B`@/&5N=')Y(&ED/2)F:6QT97(M961I="UW:&ET96QI<W0B('-T871E/2)U
M<'1O9&%T92(@;60U/2(S,S!C,V$X9F%D,3DX8S=A9F4X-35C,3`Q8S8S8V0P
M9B(^"B`@("`\=&ET;&4^MFRE\[E,PF\Z(+USO^BDS;6]IE>SYCPO=&ET;&4^
M"B`@("`\:&5A9&EN9SZ]<[_HIT&JNJ3-M;VF5[/F/"]H96%D:6YG/@H@("`@
M/'!A<F$^"B`@("#"2;_O(KUSO^BG0:JZI,VUO:97L^8BQ?VG0;=SO%>A0:=2
ML*.E2*3.O7._Z*1`I?>G0;=1IJRK2*JZN7&D;+9LI?.F5[/FH4,*("`@(*3-
MM;VF5[/FJKJEV*JZIF*I\Z%'I=&I\Z3-M;VF5[/FOM:FLZ3QN/NPJJJZN4S"
M;\!UI?W%=J%!I6G!UZ=+MFRE\[Y$"B`@(""HY*5,LU>K:+=MI?VN3:7.LWFF
MJ+_RI:*UI:OAJD>A0;U4JT^Y[Z3HJTBE\[=\LU&P9;E&IJRE\Z=8I*2A0PH@
M("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M;VXM
M;&]G:6XB('-T871E/2)U<'1O9&%T92(@;60U/2(S-V0Y,CDW9#%C8V$T-C0S
M-64S-F(V93,X930U9&-D8B(^"B`@("`\=&ET;&4^MFRE\[E,PF\Z(+5NI$JN
MR:Y-I<X\+W1I=&QE/@H@("`@/&AE861I;F<^J?.U;J1*KLFN3:7.J=*FL[E,
MPF^S5ZMH(#\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(*3$O^^S;ZW3O^^V
MM:%!I4BK2Z3IJ^&H0Z:XM6ZD2KKTN/2V;*>]KLFA0:Y-I<ZITJ:SLU>K:*%#
M"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](F9I;'1E<BUO
M;BUD:7-P;&%Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB9C5A9F,S,#4T,#)E
M9C4R8F%D,3`X.3,S9C-F,S,R.3$B/@H@("`@/'1I=&QE/K9LI?.Y3,)O.B"M
MJ[=SON.R>J[)I$"HUJY-I<X\+W1I=&QE/@H@("`@/&AE861I;F<^J$.FN+9]
ML=*FK*7SIUBNR:%!I$"HUK%.J=*FL[E,PF^S5ZMHKDVESJCDI%>A0SPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@I,2_[[-OK=._[[:UH4&E2*OAJ$.FN+9]
ML=*FK*7SIUBJNJ90KLFA0:1=L4ZITJ:SN4S";[-7JVBN3:7.J?.FK*7SIU@@
M/PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)F:6QT97(M
M86YY+6UA:6QB;W@B('-T871E/2)U<'1O9&%T92(@;60U/2(W,6,U,64X,SDP
M.68Y9#!B9#0T,&0R,C`W-S)E93-C-B(^"B`@("`\=&ET;&4^MFRE\[E,PF\Z
M(*Y-I<ZI\Z7TI$"MTZM(I?.G6#PO=&ET;&4^"B`@("`\:&5A9&EN9SZQ3KE,
MPF^S5ZMHKDVESJGSI?2D0*W3JTBE\Z=8(#\\+VAE861I;F<^"B`@("`\<&%R
M83X*("`@(*9PJD>G0:?&L>:Y3,)OLU>K:*_@KDVESJGSI?2D0*W3JTBE\Z=8
MI*2A0;W0I,2_[[-OK=._[[:UH4.S<;%@N4S";[-7JVBE=:Y-I<ZI\Z:LI?.G
M6*2DJKJW<[9LI?.A0Z9PJD>DQ+_OLV^MT[_OMK6A0:9BJ=*FLZM(I?.G6*JZ
MMFR]8\#+M?BU9:VQI*2Q3J58LGND0*W3N<^EW*%!PDF_[[C3N<^EW*5IL4ZY
M3,)OLU>K:*Y-I<ZH[*78JV6JNJM(I?.G6*%#M?DZKDVESJGSI?2D0*M(I?.G
M6*3QL%^N3:7.J?.FK*7SIUBE::_@LJ.ES;C[IFBJNK#=PT0HJ-*F<*%#LU>K
M:+-1KDVESJOAJTBE\Z13LU&MJ[W&N[RP9:CLIE"D0*W3JTBE\Z=8I*0II4(O
MJ<ZU;Z7-M4RJ:[EWM,&JNK6RJD<HJ-*F<*%#J^&HTZO8I=^JNK=SLU>K:*U0
MJ,^EV*MEJTBE\Z=8I*2JNJM(I?.S4;=HLKXOIU*PHRFA0PH@("`@/"]P87)A
M/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M8V]M<&]S92UA='1A8V@M
M<'5B:V5Y(B!M9#4](CDW-#0V9&)B8C(W-C$V8C1F83,Y8F4X,#%E,3!D9C)D
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@JOZD5Z2]MGVJ
M]\9?/"]T:71L93X*("`@(#QH96%D:6YG/JK^I%>DO;9]JO?&7SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@IG"J1Z3$O^^FN:1`MK6EV*%!I4*G0:JZ(%!'
M4""DO;9]JO?&7Z1=IG.F8JJZN-RA0:MHL4BE6*JZJTBE\Z2DL4ZJ_J17IT&J
MNB!01U`@I+VV?:KWQE^A0Z=!I6FE2+AGI=&F8B!01U`@O^^VM:JZM66ML:2D
MLUVI=Z:YI$"Y=[-=IN:LL*%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UO<'1I;VXM<V-A;BUB;V1Y(B!M9#4](C9B86%A9&$P
M9#0V9&,Q86(P.30Q,#@W9C(S-68S-3EB(B!S=&%T93TB=7!T;V1A=&4B/@H@
M("`@/'1I=&QE/E!'4#H@L;VT>;9LI?.DNJYE/"]T:71L93X*("`@(#QH96%D
M:6YG/K&]M'FV;*7SI+JN93PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@IG"J
M1Z3$O^^FN:1`MK6EV*%!NO2X]+9LI[VQ3J;;L,JF8JA#I$"KRJ_"I.6F<J[F
MIJ&V;*7SI*2QO;1Y(%!'4""XZJ[&H4&F<*I'IK.QO;1YJ.P@4$=0(+CJKL:K
M:,7CI=RXT[CJKL:A0[W0JF"W3J%!I=&I\ZA#I$"KRJ_"I.6F<J[FIJ&V;*7S
MLZ.S4;&]M'FE2+1-I^0@4$=0(+CJKL:A0:9=IKFS;[:UI5ROX+%.OLFM4*AT
MLLZS=*O7Q=RZ0Z%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](F-O;7!O<V4M;W!T:6]N<RUE;F-R>7!T(B!M9#4](C$P,3(Q-#1F-S0Y
M9C$Y9C5A,C1C968S.#8P,61A83<Q(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@
M/'1I=&QE/K9LI?.\9Z=`.B"E6[%+O^^VM3PO=&ET;&4^"B`@("`\:&5A9&EN
M9SZV;*7SI*.E6[%+/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""DHZ5;L4NV
M;*7SIM.JO;&UML>P92`HJ?JDY2FA0PH@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^4$=0(+9LI?.E6[%+/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""S;ZW3
MO^^VM;%.J,^ESJ:LI?.Y[[9(JKH@4$=0(*W3I$BDO;9]JO?&7Z%!K+"EV*ME
MO7.\9ZJZMFRE\Z5;L4NA0ZC/I<ZS;ZW3O^^VM;USO&>V;*7SKLFA0::LI?.Y
M[[9(MLBE=:_@IK.D0*;LH4.F8J=!JKJS<;!4O_VDI*6RMK>F<Z:SLV^F[*:L
MI?.Y[[9(JKH@4$=0(*2]MGVJ]\9?H4&G7ZMHL4ZW?*58LGN_^;M^JKJJK*IP
MH4.F<*I'IT&JNK-QL%2__:2DO52YZJ1WIG.F8K-OINRFK*7SN>^V2*JZ(%!'
M4""DO;9]JO?&7Z%!IOVDM+5-IJRH[+_YNWZJNK!4KJ>NR:%!O=#`RZQDI$"D
M5::LI?.Y[[9(JKJY<:1LMFRE\Z;MIWVL3Z=?NU"S<;!4O_VDI+C3M:<@4$=0
M(*2]MGVJ]\9?JKJY<:1LMFRE\Z;MIWVLVZ=KIEBA0Z5;L4NXZJ[&L4ZJ_J5;
MJ?.V;*7SI*2D0*C6L4BE6*%#"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY0
M1U`@MFRE\\.QL[D\+VAE861I;F<^"B`@("`\<&%R83X*("`@(+-OK=._[[:U
ML4ZHSZ7.IT&JNJW3I$BH<+%+JO?&7ZRPI=BK9;USO&>JNK9LI?.L2:5((%!'
M4""\QJ;LP[&SN:%#IG"J1Z=!J7REO*9BLV^MT[5NI$JTP;:AI*2_Z:1*IT&J
MNJW3I$BH<+%+JO?&7[%+O5BA0:BZIT&Q3K=\LU&M;JA$ID&FN+_II$JA0Z:L
MI?.Y[[9(I;*VMZUNOM:FLZ=!JKJMTZ1(I+VV?:KWQE^E2+9IIN:\QJ;LQ>?#
MTJ=!JKK#L;.YH4,*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/E!'4""V;*7S
MP[&SN2^V;*7SI5NQ2SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@LV^MT[_O
MMK6Q3J7]N>^V;*7SL/6FYKS&INS#L;.YJKJPRJ=`M4VKX:9!L/6FYK9LI?.E
M6[%+H4.G\[9II$"H0JJZN.JP5+W0L-&FTB`B4$=0(+9LI?.E6[%+(B"DSB`B
M4$=0(+9LI?/#L;.Y(J%#"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY3+TU)
M344@MFRE\Z5;L4L\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%1/1$\*("`@
M(#PO<&%R83X*("`@(#QH96%D:6YG/E,O34E-12"V;*7SP[&SN3PO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5$]$3PH@("`@/"]P87)A/@H@("`@/&AE861I
M;F<^4R]-24U%(+9LI?/#L;.Y+[9LI?.E6[%+/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("!43T1/"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](G!G<"UO=F5R=FEE=R(@;60U/2(R-&(U,3,X8C1B-3-F-S-B-68R9C(W
M,SEE-&,Q.#4X9"(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z
M(+>GK7H\+W1I=&QE/@H@("`@/&AE861I;F<^I+"[\JQ/(%!'4#\\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(%!'4""L3Z1`NMBESJGSLW&P5*5(I,ZXZJ[&
MJKJE6[%+I'6HXZ%!KU.G3ZQ/I<ZI\[EQI&RV;*7SH4-01U`@I6FESJGSN.JN
MQJJZI5NQ2Z%"J]BEW[S&INS#L;.YH4.Z]+CTMFRGO2!)35`@J,^ESB!';G50
M1R`H1TY5(%!R:79A8WD@1W5A<F0I(*5(M*.HT::YMK6E7*_@H4,*("`@(#PO
M<&%R83X*("`@(#QH96%D:6YG/K'2I<X@4$=0(#\\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(*3$O^^S;ZW3MK6EV*OAH4&G0;%.K^"P]R"KV*7?+\#+M?@@
MIT&JNB!01U`@K=.D2*KWQE^Y[Z%!MW.\5R^G4K"C(*C3IMNE3*1(J=*J_K!E
MJKJDO;9]JO?&7Z%!Q:JH^J5;L4NV;*7SH4'%Y\/2O,:F[,.QL[FV;*7SH4&E
M2*3.K+"G0:UNL4BU;ZJZMFRE\ZQ)I4BE6[%++\.QL[FJNJ5<K^"A0PH@("`@
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W!T:6]N+6%T
M=&%C:"UP=6)K97DB(&UD-3TB-38Q8V4T,S,W,&%C-&%F8F-C,V8Y.#$X8SAF
M8F,R9C8B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0.B"_[[:U
M("T@JOZD5Z2]MGVJ]\9?/"]T:71L93X*("`@(#QH96%D:6YG/K_OMK4@+2"J
M_J17I+VV?:KWQE\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(*9PJD>DQ+_O
MIKFD0+:UI=BA0:5"IT&JNB!01U`@I+VV?:KWQE^D7:9SIF*JNKC<H4&K:+%(
MI5BJNJM(I?.DI+%.JOZD5Z=!JKH@4$=0(*2]MGVJ]\9?H4,*("`@(#PO<&%R
M83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+6UA;F%G92UP=6)K97DB
M(&UD-3TB8C(X.65A-3@R-&(W9C8Y9C,U8S`W-3$T.3=F-&4Q8S,B('-T871E
M/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0.B"ZWK)ZI+VV?:KWQE\\+W1I
M=&QE/@H@("`@/&AE861I;F<^MZ>M>CPO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@LV^MT[5EK;&F0Z58I=BK9:9BIT&JNK-QL%2__:2DOM:FLZ2]MGVJ]\9?
MJKJITJ:SJ,^ESJK,H4.E=::SLV^HQZC/I<ZJS*5II4@@,2G%_:=!ML>P9:1`
MJ\JE6[%+JKJV;*7S("VISBT@,BG%_:=!Q>?#TJ5,J=*Q2+5OJKJ\QJ;LP[&S
MN:%#"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9S[`R[7X/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@(""V?;'2I$"MT[7XM:&E2,#+M?@@4$=0(*2]MGVJ]\9?
MH4,*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/K+3N&`\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(,7CI=S#]JGSIKD@4$=0(*2]MGVJ]\9?JKJSH:3`LM.X
M8*%#"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SZG4K"C/"]H96%D:6YG/@H@
M("`@/'!A<F$^"B`@(""FVZ=!JKJS<;!4O_VDI*=2L*.FN:1`I+VV?:KWQE^A
M0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M:6UP
M;W)T+7!U8FME>2(@;60U/2(V964Q,3,P8C0V93EF9C%C83EA9#-A,V$T-V4W
M8C,X,B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z(+K>LGJD
MO;9]JO?&7R`M(+;7I$H\+W1I=&QE/@H@("`@/&AE861I;F<^MM>D2J2]MGVJ
M]\9?/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""S;ZW3J_:V<[%.MGVQTJ1`
MK=.U^+6AI4BHT:=!I.*PRJ9AMM>D2J1`K=,@4$=0(*2]MGVJ]\9?H4.G0:5I
MI4BQ3JKWQE^V2Z1*J.RDY:9RQ.:F[*2DH4&ISJK,IMNG0:JZK=.D2+EQN*.Q
M3J2]MGVJ]\9?JKVQM;;7I$JA0Z9PJD>XTZKWQE^L3Z:SKL2JNJ6FMWRS4:GQ
MIF*G0:JZK=.D2+-QL%2__:2DH4'`2*OALV^MT[7XM:&Q3J1`J-;#]K.LH4.F
M<*I'I*.L3Z:SKL2JNJKWQE^A0:MHIT&Q3K=\K-VHH[_YNWZJNJWLIEVA0PH@
M("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M;W9E<G9I
M97<M<&5R<V]N86QK97DB(&UD-3TB,C(P868R8C<T834X9C0S,&5F9#<R9#9D
M-F(Q9CDY,V8B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^4$=0.B"Z
MWK)ZK=.D2*KWQE\\+W1I=&QE/@H@("`@/&AE861I;F<^MZ>M>CPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@IG"J1Z=!MU&M;KGOMFRE\ZQ)I4B\QJ;LP[&S
MN:G.JLS%_:5,I$BOX+#WL4BUN:=!I5NQ2ZJZMFRE\Z%!J+JG0:6RMK>M;J7]
MOM:FL\3=J?.FVZ1VJKJDO;9]+ZAPL4M01U"J]\9?N>^A0PH@("`@/"]P87)A
M/@H@("`@/&AE861I;F<^IT&JNJ2]MGVJ]\9?/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@(""G0:JZI+VV?:KWQE^E::5(L4BUN:BZJ,>A0:=!I\:QYKGOI.BW
M?+%(M6^E6[%+MFRE\[6YIT&JNJ1(H4.E6[%+J^&JNK9LI?.E=::SIT&OX+C1
ML4LHJ,^ESJ=!JKJH<+%+JO?&7RFA0Z5TI7ZA0:=!JKJDO;9]JO?&7Z5II4BQ
M2+6YI?2F\Z1`INRA0:=!M+^Q2+5OM;FE3+S&INS#L;.YMFRE\ZJZI$@@+2"F
M7:RPO,:F[,.QL[FJNL7GP]*[W:UNIT&JNJ2]MGVJ]\9?H4,*("`@(#PO<&%R
M83X*("`@(#QH96%D:6YG/J=!JKJH<+%+JO?&7SPO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@IT&JNJAPL4NJ]\9?LU&ESJC3H4&XT;%+J=*FLZ5(IT&DO;9]
MJO?&7Z5;L4NJNK9LI?.A0Z5TI7ZA0:9PJD>G0;=1K6ZY[[%(M6^JNK9LI?.L
M2:5(O,:F[,.QL[FA0;-OI%V[W:UNIT&JNJAPL4NJ]\9?H4.G0:JZJ'"Q2ZKW
MQE^Q3K-1M^VJ[*KWQE^KV*7?KLFITK*CI<VJNJ1`LM6Q2[U8J=*K3\5`H4.F
M7::YM^VFLZ7TIO.[W:UNIT&JNJAPL4NJ]\9?L_6F6*[)H4&Z]+CTMFRGO;%.
MMWRTHZ7<IT&_Z:1*L4N]6*%#"B`@(""G0:5UN]VM;J9BJ$.MT[5NI$JTP;:A
MO^FD2J=!JKJQ2[U8IUFE:2`M(+KTN/2V;*>]L4ZW?*;;L,K`>*9SIT&JNK%+
MO5BJO:CLIT&U;J58K+"D[BBITJ5(M^VDHZC/I<ZZ]+CTMFRGO:JZKLFMU*%!
ML$^Q;ZUNO52YZK5NI5BN0*%)*0H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM<'5B;&EC(B!M9#4](C-C.#0T
M9#1F9CAF9&1A,V4P9#0T-F(T-V$V,S$Q-V4P(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/E!'4#H@NMZR>JW3I$BJ]\9?("T@I+VV?:KWQE\\+W1I
M=&QE/@H@("`@/&AE861I;F<^P,NU^#PO:&5A9&EN9SX*("`@(#QP87)A/@H@
M("`@MGVQTJ1`K=.U^+6AI4C`R[7X(%!'4""DO;9]JO?&7Z%#"B`@("`\+W!A
M<F$^"B`@("`\:&5A9&EN9SZRT[A@/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("#%XZ7<P_:I\Z:Y(%!'4""DO;9]JO?&7ZJZLZ&DP++3N&"A0PH@("`@/"]P
M87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N86QK97DM
M<')I=F%T92(@;60U/2(Q.#4Q8C8W83%A965F,3(T,F9C,V$R8CDT868W-6,P
M,R(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z(+K>LGJMTZ1(
MJO?&7R`M(*APL4NJ]\9?/"]T:71L93X*("`@(#QH96%D:6YG/K_II$JQ2[U8
M/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""V?;'2L4N]6+GON-RU^+6AH4.F
M<*I'O^FD2J6_O52JNK%+O5BA0;%+O5BQ3K-1NO2X]+9LI[T@24U0(,!XIG.A
M0:J]J.RG0:JZM6ZD2K3!MJ&ULJ?TK+"D[J%#"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9SZH^+C\L4N]6#PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@IMNZ
M]+CTMFRGO;*^L*.D=\!XIG.JNK%+O5@@+2"E]*;SJ^'$\JJZJ'"Q2ZKWQE^S
M0K)ZLZ.ELK:WID&MJ[=SO^FD2J:YL4N]6*%#"B`@("`\+W!A<F$^"B`@("`\
M:&5A9&EN9S[`R[7X/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""V?;'2I$"M
MT[7XM:&E2,#+M?@@4$=0(*APL4NJ]\9?H4,@(J2CK6ZQ3J:YJ'"Q2ZKWQE^V
MQ[!EM;FE]*;SI$@B("T@IKF_[[:UK$_$6<+4IF&A0:9PIKFD0*C3IT&E::5(
ML4ZG0:JZNO2X]+9LI[VH<+%+JO?&7[;7I5BHT:CDI4RU>Z:AJ,^ESJ%#"B`@
M("`\+W!A<F$^"B`@("`\:&5A9&EN9SZRT[A@/"]H96%D:6YG/@H@("`@/'!A
M<F$^"B`@("#%XZ7<P_:I\Z:Y(%!'4""H<+%+JO?&7ZJZLZ&DP++3N&"A0PH@
M("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P9W`M<&5R<V]N
M86QK97DM9&5L971E(B!M9#4](F1B9#AC8F4V8F-E-S%C-&9B-3DR9&0Q8C-B
M,C=B-V-E(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@NMZR
M>JW3I$BJ]\9?("T@IU*PHSPO=&ET;&4^"B`@("`\:&5A9&EN9SZG4K"CK=.D
M2*KWQE\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(,))O^^S;ZW3J_:V<Z%!
MMWRQ3J=!P'BF<Z9BNO2X]+9LI[VPOJ9NLUVI=Z2DJKJMTZ1(I+VV?2^H<+%+
MJO?&7[GOIU*PHZ%#O="J8+=.H4>ET:GSK=.D2*APL4NJ]\9?NU"MTZ1(I+VV
M?:KWQE^L3Z:HN>^JNJ%!I$"F_:KWQE^Y[ZO8I=^GN::HJ,^ESJK,P+.XT[K)
MI6FOX,'7ITNE:*=2L*.EIJ%#IEVLL*9PJD>D4Z9!IKBMJ[=SJ]BEWZKWQE^Y
M[Z%!I*>K9:G2IK.Q2+5OM;FJ0J3-J,.L>;-QIF*E?JJZI+VV?:KWQE^Q3K5,
MJFN[4+=SJ]BJNJAPL4NJ]\9?IVNF6*%#*+"CJT2G0;%.MW.KV*JZI+VV?:KW
MQE^MJ[=SL4BU;RD*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<&=P+7!E<G-O;F%L:V5Y+6-R96%T92UN86UE(B!M9#4](C<T.&-B,3(T
M8C=F9C4R.#(P-SDR93(W.#`S-V$X8S(W(B!S=&%T93TB=7!T;V1A=&4B/@H@
M("`@/'1I=&QE/E!'4#H@J]BEWZW3I$BJ]\9?("T@IE>ZV3PO=&ET;&4^"B`@
M("`\:&5A9&EN9SZF5[K9/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@(""S;ZW3
MIE>ZV;%.M$^D2JCLIT&JNJW3I$BJ]\9?I*2A0[-OK$^ELK:WQ.:F[*%#"B`@
M("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA
M;&ME>2UC<F5A=&4M8V]M;65N="(@;60U/2)E-C8V96(Y9C!E931B-#EF93`T
M9C<T9F,Q.&1B.#8T,"(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y0
M1U`Z(*O8I=^MTZ1(JO?&7R`M(+7YN-$\+W1I=&QE/@H@("`@/&AE861I;F<^
MM?FXT3PO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@IT&GQK'FK+"FN:W3I$BJ
M]\9?M*.HT:JZNZ&I^J%!LV^HQ[7YN-&Q3K1/I$JH[*=!JKJMTZ1(JO?&7Z2D
MH4.S;ZQ/O^^^W*G*Q.:F[*%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M96UA:6PB(&UD-3TB
M8S<R.68W,&9D8C-A-S-C8F(W8F$U968U.#@X93,P.3(B('-T871E/2)U<'1O
M9&%T92(^"B`@("`\=&ET;&4^4$=0.B"KV*7?K=.D2*KWQE\@+2"Y<:1LMFRE
M\Z9AIWT\+W1I=&QE/@H@("`@/&AE861I;F<^N7&D;+9LI?.F8:=]/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@(""G0:G2I\:QYKM0K=.D2*KWQE^ULJ98JKJY
M<:1LMFRE\Z9AIWVA0[-OK$^ELK:WQ.:F[*%#"B`@("`\+W!A<F$^"B`@/"]E
M;G1R>3X*("`\96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M:V5Y
M;&5N9W1H(B!M9#4](C(T8V$V-#%C-C-F8C5F9C,Q,&$S.65E,&0S8C%E934U
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@J]BEWZW3I$BJ
M]\9?("T@JO?&7ZKXJ]<\+W1I=&QE/@H@("`@/&AE861I;F<^JO?&7ZKXJ]<\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(*=!J=*RHZ7-JKJJ]\9?H4&HY*KX
MJ]>L3Z5(INRDN++5K+"SYJ;LH4.J^*O7ME:J^*%!JT_%0*G*ME:HSB`HK-NY
M[ZJZH4&X^ZKX"B`@(""JNJKWQE^[W:UNN/NF:*JZKLFVH:C3LJ.ES:%!I4BD
MSJ5;L4LIH4,Q,#(T(*;LI+BRU:Q/N7>S7:KXJ]<@+2"S;ZW3JOBKUPH@("`@
MM*.HT;6TJ,ZJNJM/Q4"IRJ%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\
M96YT<GD@:60](G!G<"UP97)S;VYA;&ME>2UC<F5A=&4M<&%S<W!H<F%S92(@
M;60U/2(R9F(Y,S<R.3<P8F8S,V8U,64Y.#AB83,Y9&)D-S$Y,R(@<W1A=&4]
M(G5P=&]D871E(CX*("`@(#QT:71L93Y01U`Z(*O8I=^MTZ1(JO?&7R`M(+%+
MO5@\+W1I=&QE/@H@("`@/&AE861I;F<^L4N]6#PO:&5A9&EN9SX*("`@(#QP
M87)A/@H@("`@L4N]6*7.J-.K3\5`+Z5;L4NG0:JZK=.D2*APL4NJ]\9?H4.Q
M2[U8JKJS7:EWIK.T6*W3K>RK:*%',2D@IMRDUB`V(*W3IG(HK5ZDY:G.O,:F
M<BFA0R`R*2"DHZUNJ4VU;J1*L4N]6*S;IE"A0R`S*2"F8J9RJ.6DI*?DI*.H
M[*%#-"D@K5ZDY:9RNU"\QJ9RI>;"^*C/I<ZA0Z=!I;*VM[_II$JD1Z:XL4N]
M6*%!I4B]5*M/IT&H4Z:SNWZS7:%#LV^L3Z6RMK?$YJ;LH4,*("`@(#PO<&%R
M83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<&=P+7!E<G-O;F%L:V5Y+6-R
M96%T92UA8W1I;VYS(B!M9#4](C!F.#(S-#DS-6(Y-C1C.#,U,S-B-&5C-&,Q
M-65B-S$R(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/E!'4#H@J]BE
MWZW3I$BJ]\9?("T@L,JG0#PO=&ET;&4^"B`@("`\:&5A9&EN9SZKV*7?JO?&
M7SPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@J]BEWZC#P'BF<Z=!JKJMTZ1(
MI+VV?2^H<+%+JO?&7[GOH4,*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/K;7
MI$JJ]\9?N>\\+VAE861I;F<^"B`@("`\<&%R83X*("`@(+;7I$JD0++5K=.D
M2""DO;9]+ZAPL4L@JO?&7[GOH4.S;ZW3J_:V<[%.MGVQTJ1`K=.U^+6AH4&H
MT:=!MM>D2J=!JKI01U"MTZ1(I+VV?2^H<+%+JO?&7[GOH4.G0:5II4BQ3JKW
MQE^V2Z1*J.RDY:9RQ.:F[*2DH4&ISJK,JKVQM:71IT&JNKEQN*.Q3J2]MGVJ
M]\9?MM>D2J%#IG"J1[C3JO?&7ZQ/IK.NQ*JZI::Q3K=\LU&F<ZGQIF*G0:JZ
MLUVI=Z2DH4'`2*OALV^MT[7XM:&Q3J1`J-;#]K.LH4.F<*I'I*.L3Z:SKL2J
MNJKWQE^A0:MHIT&Q3K=\K-VHH[_YNWZJNJWLIEVA0PH@("`@/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UO=F5R=FEE=R(@;60U/2)D
M,V,W-3)B,3,T-69B,F5C8V9E-3<U8S`W-#8Q.38S9B(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y3+TU)344Z(+>GK7H\+W1I=&QE/@H@("`@/&AE
M861I;F<^I+"[\JQ/(%,O34E-13\\+VAE861I;F<^"B`@("`\<&%R83X*("`@
M(%,O34E-12"L3Z1`NMBH<+%++Z2]MGVJ]\9?N>^H=++.H4.XTZATLLZTHZC1
MO=&F<*%'O,:F[,.QL[FA0;9LI?.E6[%+H4&E2*3.IF*V?:GQID"ESJ17M*.H
MT<*KI^^PN[3ZJKJGWK-.H4,@4R]-24U%(*5II4BTHZC1MFRE\Z5;L4NJNJ5<
MK^"A0:5;L4NKX:JZMFRE\Z5UIK.Q2+!EJLRDSJ:LI?.JS*5II4BXT;%+H4-3
M+TU)344@P=FE::5(N&>ET;S&INS#L;.YJ-._Z\/1L4BP9:K,JKJHK:7WH4.E
M6[%+NU"\QJ;LP[&SN:1`L%^HSZ7.I_.E::5(M*.HT<*KI^^PN[3ZJKJE7*_@
MH4&F;L7]J=*FLZ:LI?.Y[[9(IU"I=[9LI?.F8K%(M6^KX:Q/IU^TO[-1PJNG
M[Z%#"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SZQTK#*(%,O34E-12`_/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@(""DQ+_OLV^MT[:UI=BKX:%!IT&Q3J_@
ML/>VUZ1*IT&JNJW3I$@@4R]-24U%(*KWQE^A0<6JJ/JE6[%+MFRE\Z%!Q>?#
MTKS&INS#L0H@("`@L[FV;*7SH4&E2*3.K+"G0:UNL4BU;ZJZMFRE\ZQ)I4BE
M6[%++\.QL[FJNJ5<K^"A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N
M=')Y(&ED/2)S;6EM92UO=F5R=FEE=RUP97)S;VYA;&ME>2(@;60U/2(Y9C1F
M,S9A93<R8V(T86)C-S,Q,#8W9#,S.&)E,V(Y."(@<W1A=&4](G5P=&]D871E
M(CX*("`@(#QT:71L93Y3+TU)344Z(*W3I$BJ]\9?/"]T:71L93X*("`@(#QH
M96%D:6YG/K>GK7H\+VAE861I;F<^"B`@("`\<&%R83X*("`@(*9PJD>G0;=1
MK6ZY[[9LI?.L2:5(O,:F[,.QL[FISJK,I5NQ2Z%!J+JG0:6RMK>M;J7]OM:F
ML\3=J?.FVZ1VJKJDO;9]+ZAPL4M3+TU)346J]\9?N>^A0PH@("`@/"]P87)A
M/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)S;6EM92UI;7!O<G0M<&5R<V]N
M86PM8V5R=',B('-T871E/2)U<'1O9&%T92(@;60U/2)C9C!E9#)E,V4R-&0S
M,&1E9&8X8V9E9C)C,C8T-3<U.2(^"B`@("`\=&ET;&4^4R]-24U%.B!);7!O
M<G0@4&5R<V]N86P@0V5R=&EF:6-A=&5S/"]T:71L93X*("`@(#QH96%D:6YG
M/DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T97,\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@($EM<&]R="!P97)S;VYA;"!C97)T:69I8V%T97,@9G)O;2!A
M(%!+0U,@(S$R(&9O<FUA="!F:6QE+B!02T-3(",Q,B!F:6QE<R!I<R!T:&4@
M9FEL92!U<W5A;&QY(&=E;F5R871E9"!W:&5N(&5X<&]R=&EN9R!A(&ME>2!F
M<F]M(&$@8G)O=W-E<B`H92YG+B!);G1E<FYE="!%>'!L;W)E<BP@1FER969O
M>"D@;W(@9G)O;2!A(&-E<G1I9FEC871E('-T;W)E(&UA:6YT86EN960@8GD@
M86X@3W!E<F%T:6YG(%-Y<W1E;2`H92YG+B!7:6YD;W=S(%A0*2X@268@=&AE
M(&ME>7,@87)E('9A;&ED('1H97D@=VEL;"!B92!I;G-E<G1E9"!I;G1O('EO
M=7(@<')E9F5R96YC97,@86YD('1H92!W:6YD;W<@=VEL;"!C;&]S93L@:68@
M;F]T('9A;&ED+"!A;B!E<G)O<B!M97-S86=E('=I;&P@8F4@<F5T=7)N960@
M97AP;&%I;FEN9R!W:'DN"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)S;6EM92UD96QE=&4M<&5R<V]N86PM8V5R=',B('-T871E/2)U<'1O
M9&%T92(@;60U/2(P,3AB8C9B-C%A-V4T,38X.3)D93(X.&%D,6,X.#!F-"(^
M"B`@("`\=&ET;&4^4R]-24U%.B!$96QE=&4@4&5R<V]N86P@0V5R=&EF:6-A
M=&5S/"]T:71L93X*("`@(#QH96%D:6YG/D1E;&5T92!097)S;VYA;"!#97)T
M:69I8V%T97,\+VAE861I;F<^"B`@("`\<&%R83X*("`@($1E;&5T92!Y;W5R
M('!E<G-O;F%L(&-E<G1I9FEC871E<R!F<F]M('EO=7(@<')E9F5R96YC97,N
M("!9;W4@=VEL;"!N;R!L;VYG97(@8F4@86)L92!T;R!S:6=N(%,O34E-12!M
M97-S86=E<R!O<B!V:65W(&%N>2!3+TU)344@96YC<GEP=&5D(&UE<W-A9V5S
M(&%D9')E<W-E9"!T;R!Y;W4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)S;6EM92UM86YA9V4M<'5B:V5Y(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB.&(V8S8S-C@T9#-D-S-B,V0P.#0P,C5A-SAF93=E.#@B/@H@("`@
M/'1I=&QE/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]T:71L93X*("`@
M(#QH96%D:6YG/E,O34E-13H@36%N86=E(%!U8FQI8R!+97ES/"]H96%D:6YG
M/@H@("`@/'!A<F$^"B`@("!-86YA9V4@>6]U<B!3+TU)344@<'5B;&EC(&ME
M>2!L:7-T+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^5FEE=SPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@5FEE=R!T:&4@<F%W('1E>'0@;V8@=&AE('!U
M8FQI8R!K97DN"B`@("`\+W!A<F$^"B`@("`\:&5A9&EN9SY$971A:6QS/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!6:65W('1E8VAN:6-A;"!D971A:6QS
M(&]F('1H92!P=6)L:6,@:V5Y+@H@("`@/"]P87)A/@H@("`@/&AE861I;F<^
M1&5L971E/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!$96QE=&5S('1H92!S
M96QE8W1E9"!P=6)L:6,@:V5Y(&9R;VT@<W1O<F%G92X@($1E;&5T:6YG(&$@
M<'5B;&EC(&ME>2!F;W(@82!U<V5R('=I;&P@<')E=F5N="!Y;W5R(&9R;VT@
M96YC<GEP=&EN9R!A(&UE<W-A9V4@=&\@=&AA="!U<V5R+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')I;G1I;F<B(&UD-3TB9C(S,V,Q
M,6(V8C1A-F)E9&5B-CAF,60U83)A.3<V9&(B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^ID.F3#PO=&ET;&4^"B`@("`\:&5A9&EN9SZF0Z9,I$"K
MRK9LI?,\+VAE861I;F<^"B`@("`\<&%R83X*("`@(+']ID.D0*O*I;^F8L#+
MM?BJNK9LI?.A02"]T,))O^^V;*7SK;:ML:17I.BISJ15I.BJNB*DS;6]ID.F
M3"*A0Z[FIJ&DQJOAJKJV;*7SL4ZV?;'2J?.W<[7XM:&DI+6EJ]VF0Z9,H4,@
MM?BG0:JZPG/$_;ZYNU"G0+=^J'2RSJ;3J7>A0;-QL6"FN:[)MWRV?;'2I$"M
MTZ9#IDREYKW-M?BUH:%#(*9PJD>H4Z:SMGVQTJ%!O=#"2;_OPG/$_;ZYJKHB
MP,FNUR*KX:9!PDF_[R*F0Z9,(J5(MGVQTJ9#IDREYKW-M?BUH:%#"B`@("`\
M+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G-O<G1I;F<B(&UD-3TB
M,3AC9&5A8S,X,#(W9F4U8S0R8F%B-CDS9C)A-#(V,&$B('-T871E/2)U<'1O
M9&%T92(^"B`@("`\=&ET;&4^L<:GQ[M0P_;!<#PO=&ET;&4^"B`@("`\:&5A
M9&EN9SZQQJ?'/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("#`R[7XMFRE\[)-
ML^:NR:%!PL>ET<))O^^D5Z3HJKJE]*1`K=/$YJ;LIE>ZV;E&J.RV;*7SL<:G
MQZJZI=BJNJ%#PDF_[\3FINRF5[K9KL>JNKUBP%FYSZ7<I6FE2,7<I_.QQJ?'
MJKJDZ*96H4,*("`@(#PO<&%R83X*("`@(#QH96%D:6YG/L/VP7`\+VAE861I
M;F<^"B`@("`\<&%R83X*("`@(,+'I='"2;_OI42FKL3FINRDI*JZ(%O#]L%P
M72"S<[6RH4&HS[9LI?.HS*F\IKG#]L%PJ<H@**5$IJXIL<:F0Z;3LJ.ES;AS
MNT6NQ*I'H4.F<*I'K6ZF7JCLI$"OZZ6_L6"JNJ5$IJZQQJ?'H4&]T,))O^^E
M1*:NQ.:F[*2DJKH@6Z5$IJY=(+-SM;*A0PH@("`@/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)A;'1E<FYA=&EV92UM<V<B(&UD-3TB-#DW.#`W
M,V8W-CDW-V(V868V8C8Y.#$P931D,C)A-C4B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^IFBMJ[+5IJ@OI6FTP*5.(*NLMFRE\R`H375L=&EP87)T
M+T%L=&5R;F%T:79E($UE<W-A9V4I/"]T:71L93X*("`@(#QP87)A/@H@("`@
MIF*Z]+CTI%>FLZ1`J,>V;*7SK$^E2*1`NMBITK_7JKH@(FUU;'1I<&%R="]A
M;'1E<FYA=&EV92(@JZRZ0;-1ML>P9:%!J=*_UR*F:*VKLM6FJ"*JNK=.J^2L
M3ZO\LV^KRK9LI?.E7:=TO,:MT[+5IJBA0:G2IK.RU::HJKJDNJYEJ.2YZJQ/
MI$"\RZJZH4&E=:2CN4RL3Z5(I*.F4*JZKN:FH<!XIG.A0[EQI&RV;*7SOES%
MJK-NQ>FY2JCLLV^ZV,/^JZRV;*7SJKJS0K)ZI.BFH:Q/H4&F8L)SQ/V^N:2D
MI4BDNJ3EJKVQM<7CI=RSS*OAI$"MT[+5IJBA0Z;<J?.V;*7SI*2HY+YLJKJR
MU::HH4&K:*C#ID/%XZ7<IF(@(J:YMFRE\ZJZJ.2E3*[FIJ$B(*15I.BA0:C1
MK=.G3\#+M?BISJ15N/RA0[W0PM2P3Z9BI-^A0;-OJ,>RU::HIK.UVR`BK-NF
M4"(@JKJDNJYE("T@I76L3Z[FIJ&DHZ90IM.D=Z%#"B`@("`\+W!A<F$^"B`@
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7)E;F%M95]S96YT;6%I;%]M
M;VYT:&QY(B!M9#4](C4S,&9A,C!E,&%F8F,R-69F9#0P.#<W.30X.#,R.#DY
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/K"^IFZS7:EW.B"Z^\5`
M.B"I\ZA#I.NJ[*?SI^^Q2*7SL\:E]Z=8JKJF5[K9/"]T:71L93X*("`@(#QP
M87)A/@H@("`@IG"J1Z=!I\:QYKKTN/2V;*>]H4&I\ZA#K=.DZZKLI_.G[Z=!
MJKJQ2*7SL\:E]Z=8IE>ZV:%!O="DQ+_OH4.Q2*7SL\:E]Z=8L*.D1J?SIE>L
ML,+"JKJQ2*7SL\:E]Z=8I7XHI_.F5ZOAJKJF5[K9I5VG=*3KI,ZF?J7W*:%!
MJ,.F8J?SIE>KX:O8I=^E=*1`K=.W<ZJZJL6EU;%(I?.SQJ7WIUBA0PH@("`@
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD96QE=&5?
M<V5N=&UA:6Q?;6]N=&AL>2(@;60U/2(P8F5E9#$V9&9D-CAE,F8R-64P8S8V
M.#<Q9F0U-#9D9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93ZPOJ9N
MLUVI=SH@NOO%0#H@J?.H0Z3KJNRG4K"CPL*JNK%(I?.SQJ7WIU@\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@(""F<*I'IT&GQK'FNO2X]+9LI[VA0:GSJ$.MTZ3K
MJNRG4K"CPL*JNK%(I?.SQJ7WIUBA0;W0I,2_[Z%#IG"J1[KTN/2V;*>]L'>Y
M[ZC/I<ZJS+-=J7>ZS[K0JL6VH;!TPT*A0;-OK=._[[:UL4ZFLZ=5J?/!UZ=+
MNL^ZT*K%MJ&DHZBLJKJU;Z7-H4,*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7W-E;G1M86EL7VUO;G1H;'E?:V5E
M<"(@;60U/2(W,65D,6,R96%B-#AB.3%A,C5B-6)C9#1B,31C8V5A.2(@<W1A
M=&4](G5P=&]D871E(CX*("`@(#QT:71L93ZPOJ9NLUVI=SH@NOO%0#H@IG"J
M1ZA#I.NG4K"CI$"FN*%!IFBDUJ3KI?>JNL+"L4BE\[/&I?>G6+%.LU&K3Z9S
M/"]T:71L93X*("`@(#QP87)A/@H@("`@IG"J1Z=!I'>DQ+_O("*I\ZA#I.NJ
M[*=2L*/"PJJZL4BE\[/&I?>G6"(@LV^MT[_OMK6JNKC<H4&G0:5II4BF8J:Y
MO^FD2J1`K=.K3Z]DI.NE][S&K<BA0ZM/KV2DZZ7WO,:MR*2GJV6ITJ:SPL*J
MNK%(I?.SQJ7WIUBQ3J1`J]^G4K"CH4,*("`@(#PO<&%R83X*("`\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H
M;'DB('-T871E/2)U<'1O9&%T92(@;60U/2(S-S-E83`R961E-F1F-69C,S0U
M8V%F-C,R93$Y83<U9B(^"B`@("`\=&ET;&4^L+ZF;K-=J7<Z(+K[Q4`Z(*GS
MJ$.DZZKLIU*PHZ1WPN"F<ZRPNO2G?:JZJOZE\SPO=&ET;&4^"B`@("`\<&%R
M83X*("`@(*9PJD>G0:?&L>:Z]+CTMFRGO:%!J?.H0ZW3I.NJ[*=2L*.D=\+@
MIG.LL+KTIWVJNL+"JOZE\Z%!O="DQ+_OH4.F<*I'NO2X]+9LI[VP=[GOJ,^E
MSJK,LUVI=[K/NM"JQ;:AL'3#0J%!LV^MT[_OMK6Q3J:SIU6I\\'7ITNZS[K0
MJL6VH:2CJ*RJNK5OI<VA0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD96QE=&5?871T86-H;65N='-?;6]N=&AL>5]K965P
M(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,6(S-#!A-C`R,31D9F9D,#1A96,P
M,F-C,3$R-V1F-60B/@H@("`@/'1I=&QE/K"^IFZS7:EW.B"Z^\5`.B"F<*I'
MJ$.DZZ=2L*.D0*:XH4&F:*36I.NE]Z1WPN"F<ZRPNO2G?:JZPL*J_J7SL4ZS
M4:M/IG,\+W1I=&QE/@H@("`@/'!A<F$^"B`@(""F<*I'IT&D=Z3$O^\@(JGS
MJ$.DZZKLIU*PHZ1WPN"F<ZRPNO2G?:JZJOZE\R(@LV^MT[_OMK6JNKC<H4&G
M0:5II4BF8J:YO^FD2J1`K=.K3Z]DI.NE][S&K<BA0ZM/KV2DZZ7WO,:MR*2G
MJV6ITJ:SPN"F<ZRPNO2G?:JZPL*J_J7SL4ZD0*O?IU*PHZ%#"B`@("`\+W!A
M<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+7!U<F=E7W1R87-H
M(B!M9#4](F1C-S$X-S$Q-#9B93-E-#9A9&4P,#@W83AC9C$X,C<S(B!S=&%T
M93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/K"^IFZS7:EW.B"Z^\5`.B"R3;"C
MJ56GH[UCI*2JNL+"MFRE\SPO=&ET;&4^"B`@("`\<&%R83X*("`@(*=!K$^G
M7Z?&L>:X9[%@LDVPHZE5IZ.]8Z2DJKK"PK9LI?.A0PH@("`@/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]I;G1E
M<G9A;"(@;60U/2(W8F4Y,69B96(P-6(R9#@W,C@Y9#1C-38P,F0U83,R9B(@
M<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93ZPOJ9NLUVI=SH@NOO%0#H@
MJ56GH[UCIFBD6[)-L*.D0*:X/"]T:71L93X*("`@(#QP87)A/@H@("`@IG"J
M1Z=!I'>DQ+_O("*R3;"CJ56GH[UCI*2JNL+"MFRE\R(@LV^MT[_OMK6JNKC<
MH4&G0:?&L>:F:*1;LDVPHZ1`IKBA2`H@("`@/"]P87)A/@H@(#PO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUP=7)G95]T<F%S:%]K965P(B!M9#4](C-C
M8C5A,F(U8C@P8C=A8S$Q-SEA93`P-68Y.#,Y-S!E(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/K"^IFZS7:EW.B"Z^\5`.B"H0Z:XON.R>JE5IZ.]
M8Z[)H4&R3;"CIFBDUJ31O,:E2*MEJKJV;*7S/"]T:71L93X*("`@(#QP87)A
M/@H@("`@IG"J1Z=!I'>DQ+_O("*R3;"CJ56GH[UCI*2JNL+"MFRE\R(@LV^M
MT[_OMK6JNKC<H4&G0:?&L>:R3;"CIFBDUJ31O,:E2*MEJKJV;*7SH4@*("`@
M(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M871T<FEB
M7W1E>'0B('-T871E/2)U<'1O9&%T92(@;60U/2(W,C%A,#ED-V-A,#(X8SDW
M93-B9#)B,SAC-3DW9F9F-R(^"B`@("`@/'1I=&QE/K"^IFZS7:EW.B"V;*7S
MO&>G0#H@I.6F<L3=J<H\+W1I=&QE/@H@("`@(#QP87)A/@H@("`@(*=!I6FE
M2*9BIKFI=[AQIE["T*3EI?.JNJ3>K7JF0Z%#"B`@("`@/"]P87)A/@H@("`@
M(#QP87)A/@H@("`@(*=!I6FE2*RPIT&ITJUNIE["T*JZJTBE\[2AI$JD0*C'
MQ=R\QJ%#(,7<O,:JNJNLND&L3Z5(("<E)ZOAK;&F0:5;I%>D0*W3IG*DN*G2
MLM6FJ*%#(*5(I%6F0Z58I6FHT;=FL'2HSZ7.JKK%W+S&.@H@("`@(#PO<&%R
M83X*"B`@("`@/'!A<F$^("5F(#H@L4BE\ZK,JKJF5[K9I,ZY<:1LMFRE\Z;M
MIWT\+W!A<F$^"B`@("`@/'!A<F$^("5A(#H@L4BE\ZK,JKJY<:1LMFRE\Z;M
MIWT\+W!A<F$^"B`@("`@/'!A<F$^("5P(#H@L4BE\ZK,JKJF5[K9/"]P87)A
M/@H@("`@(#QP87)A/B`E<B`Z(*>YON.JNB!21D,@,C@R,B"DZ;3!KN:FH:3.
MKLFPSSPO<&%R83X*("`@("`\<&%R83X@)60@.B"DZ;3!**Q0M,&A0:3I(*3K
M(*;HI+BF?BD\+W!A<F$^"B`@("`@/'!A<F$^("5X(#H@M^VF8;EWLUVNYJ:A
MJKJDZ;3!/"]P87)A/@H@("`@(#QP87)A/B`E8R`Z(+?MIF&Y=[-=KN:FH:JZ
MI.FTP:3.KLFVH3PO<&%R83X*("`@("`\<&%R83X@)6T@.B"V;*7SO7.XN3PO
M<&%R83X*("`@("`\<&%R83X@)7,@.B"V;*7SI42FKCPO<&%R83X*("`@("`\
M<&%R83X@)6X@.B"D0*9#JL6EU:;F/"]P87)A/@H@("`@(#QP87)A/B`E)2`Z
M("<E)R"F<J2X/"]P87)A/@H*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&ES<&]S:71I;VY?<F5Q=65S=%]R96%D(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB.#EE.3)C-&0V.#(R-&(R,S0U8C4Y.34Y.#<X83<Q-S0B/@H@("`@
M/'1I=&QE/K"^IFZS7:EW.B"]T*:LI?.D2+;'L&7%JJCZIEZQ^#PO=&ET;&4^
M"B`@("`\<&%R83X*("`@("*]T*:LI?.D2+;'L&7%JJCZIEZQ^"(@I<ZHTZUN
MJ$2FK*7SN>^V2*%!MGVQTJM(I?.NR;:VJTNVQ[!EIEZQ^+6YL4BK2*1(H4&J
M[:GZJ-.K2*1WIJRH[*%#O="J8+=.J,.DHZQ/J=*FLZJZMFRE\[Y<Q:JS;L7I
MLZ.DY+2ILV^VM:5<K^"A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]S96YD7VUD;B(@<W1A=&4](G5P
M=&]D871E(B!M9#4](C%F93`T935D8S-D938X9#$W,F1A,C@T.#DU.3<S96$Y
M(CX*("`@(#QT:71L93ZPOJ9NLUVI=SH@ML>P9:9>L?@\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("`BML>P9:9>L?@B(+?ML4BE\Z1(J?.K2*7SI*2M;JA$IJRE
M\[GOMDBA0;9]L=*K2*7SKLFVMJM+ML>P9:9>L?BUN;%(I?.D2*KMI=RK2*7S
MI'>H[*%#I$"OZZ;3J*6F7K'XLW&JOK=\P+.Q2*7SI$BJNJUNJ$2FV[#*MFFF
MYK;'L&6A0Z2CN4RF8KKTN/2V;*>]JKK`]+G2I*2G0:6RMK>FVZ;FPDF_[[-S
MM;*E2+;'L&6F7K'XJKJQ2*7SI$BA0PH@("`@/"]P87)A/@H@(#PO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD:7-P;W-I=&EO;E]R97%U97-T7V1E;&EV
M97)Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB,C8U.3AE,CEA9C`U83`W9&4U
M93$S-C0T-C8Y8F4W,3(B/@H@("`@/'1I=&QE/K"^IFZS7:EW.B"]T*:LI?.F
M^*I!OKFVQ[N\L&6Y1KU4NWL\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`BO="F
MK*7SIOBJ0;ZYML>[O+!EN4:]5+M[(B"M;JA$IJRE\[GOMDBITL3=JKJV;*7S
MIOBJ0;ZYI$"EN::LJ.RK2*7SJ^&EWZ=9ML>P9;U4NWNP5*ZGM;FQ2*M(I$BA
M0[W0JF"W3J%!MFRE\[%(N4:Y[Z3HJKJF^*I!OKFHPZ2CJNVEW*:LI?.Y[[9(
MI'>X9ZS=N4RG0:JZJTBE\Z%#MLBOX+C1Q:JLL*%'JTBL3[%(J.RD1J%!IOVF
MLZA3IK.D2*5HK-VK:*2CL6^FTZJ^H4.HPZM$J=*FLZJZMFRE\Z;XJD&^N;.C
MIK.DY+2ILV^VM:5<K^"A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD96QE=&5?<W!A;5]A9G1E<E]R97!O<G0B('-T871E
M/2)U<'1O9&%T92(@;60U/2)C969A.&(U,F4P.6(P861A.3!E,#@X.6$S.34Y
M969E82(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($1E;&5T92!3<&%M($%F
M=&5R(%)E<&]R=&EN9SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%EO=2!M87D@
M96QE8W0@=&\@9&\@;VYE(&]F('1H<F5E(&ET96US(&%F=&5R(')E<&]R=&EN
M9R!A(&UE<W-A9V4@87,@96ET:&5R('-P86T@;W(@:6YN;V-E;G0N"B`@("`\
M+W!A<F$^"B`@("`\<&%R83X*("`@($9I<G-T+"!Y;W4@8V%N(&1E8VED92!T
M;R!D;R!N;W1H:6YG("T@=&AE(&UE<W-A9V4@=VEL;"!B92!R97!O<G1E9"!A
M<R!E:71H97(@<W!A;2!O<B!I;FYO8V5N="!B=70@=VEL;"!O=&AE<G=I<V4@
M<F5M86EN('5N8VAA;F=E9"!I;B!Y;W5R(&UA:6QB;W@N"B`@("`\+W!A<F$^
M"B`@("`\<&%R83X*("`@(%-E8V]N9"P@:68@<F5P;W)T:6YG(&$@;65S<V%G
M92!A<R!S<&%M+"!Y;W4@8V%N(&EN<W1E860@:&%V92!T:&4@;65S<V%G92!B
M92!I;6UE9&EA=&5L>2!D96QE=&5D+B`@5&AI<R!S971T:6YG(&AA<R!N;R!E
M9F9E8W0@;VX@<F5P;W)T:6YG(&$@;65S<V%G92!A<R!I;FYO8V5N="X*("`@
M(#PO<&%R83X*("`@(#QP87)A/@H@("`@5&AI<F0L(&%F=&5R(')E<&]R=&EN
M9R!A(&UE<W-A9V4@87,@<W!A;2!T:&4@;65S<V%G92!W:6QL(&)E(&1E;&5T
M960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M;W9E9"!T;R!Y;W5R
M('-P86T@9F]L9&5R+B`@06QT97)N871I=F5L>2P@:68@<F5P;W)T:6YG(&$@
M;65S<V%G92!A<R!I;FYO8V5N="!T:&4@;65S<V%G92!W:6QL(&)E(&1E;&5T
M960@9G)O;2!T:&4@8W5R<F5N="!M86EL8F]X(&%N9"!M;W9E9"!T;R!Y;W5R
M($E.0D]8+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M:'1M;%]I;6%G95]R97!L86-E;65N="(@<W1A=&4](G5P=&]D871E(B!M
M9#4](C(X93%C9C`X93,R.#,T-6$X93<R-S1C.#4S-#DR9#1F(CX*("`@(#QT
M:71L93ZPOJ9NLUVI=SH@P?3"PR!(5$U,(+9LI?.DI*JZN<^D^3PO=&ET;&4^
M"B`@("`\<&%R83X*("`@($A434P@MFRE\Z2DH4&ITJ:SK^"JO;&UQ>.EW*JZ
MN<^D^:%!K$^G7\"SN-/!],+#J,.E2*SUIN*\T*7<I4ZTP""A2`H@("`@/"]P
M87)A/@H@("`@/'!A<F$^IK.HQZE5IZ.V;*7SIF*V?;'2JKJF4*[)H4'`2*=9
ML=*PRKM0N<^D^:S;LW.ULJJZH76P;,+<N,NX;:%VH4&]T*5"JKVQM:=IMD2I
M5:>CMFRE\[%(L&6JS*%'LV^KRKQSIVFK2*1WLU&EM+9]IM.E0K-OK=.K2+UC
MK$^FLZ[$JKJK2+UCH4&EO*C3IT&JNJM(O6/"PK=\M[VWO:2CPE^JNJ:LJ.RI
M5:>CJTBA0PH@("`@/"]P87)A/@H@("`@/'!A<F$^P?3"P[G/I/FE::5(JT_%
M0*=!I76LW:CLIT&W4:UNK-VJNKG/I/FA0:C#I4*D7:90KLFJ_;[7I$:A=;!L
MPMRXR[AMH7:JNKE"IT"A0Z5UK6ZG0;U4J7>S;ZO*JTBDHZQ/O'.G::M(H4'"
M2;_OH77%XZ7<N<^D^:%VH4&T3J5II4BLW:CLLV^KRJM(N,RML:JZN<^D^:1&
MH4,*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M:'1M;%]I;6%G95]A9&1R8F]O:R(@<W1A=&4](G5P=&]D871E(B!M9#4](C<U
M.69A,V1F,C1E,&$S8V0X.68S,C`Q,#(R-3)F.3%A(CX*("`@(#QT:71L93ZP
MOJ9NLUVI=SH@IMNPRL7CI=P@2%1-3""V;*7SI*2JNJG2IK.YSZ3Y/"]T:71L
M93X*("`@(#QP87)A/@H@("`@IG"J1['2I<XBP?3"PR!(5$U,(+9LI?.DI*JZ
MN<^D^2*S;[:UI5ROX*%!IM.E0K%(I?.D2*58LGNF8J?:JKJS<;!4O_VDI*%!
MK$^G7Z;;L,K%XZ7<N-.K2*7SI*2JNKG/I/FA2"`*("`@(#PO<&%R83X*("`\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M;6%I;&)O>%]S=&%R="(@<W1A
M=&4](G5P=&]D871E(B!M9#4](C-D,3$Y-F8R-C5D.&(W8V,T-C5E8F8R,34Q
M,F%C8S`U(CX*("`@(#QT:71L93ZPOJ9NLUVI=SH@MFR]8[!?J6RMMJVQ/"]T
M:71L93X*("`@(#QP87)A/@H@("`@M^VD0*W3MFR]8[+$I$"FN+-1IG.H^J[)
MH4&H3:EWJ.3`R[7XM66ML:UNI?W%XZ7<K?ZD0*W3K;:ML:%#L\:U^:%'(J6\
MK-VY3"*K2*7SO^^VM:9B(L/VP7`BL<:GQZ2DM4RJ:Z=`I<ZA0:C#I4*Q3J5(
MJTB]8ZJZL\RKX:1`K;:E3K3`H4,*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M<V%V95]A='1A8VAM96YT<R(@<W1A=&4](G5P
M=&]D871E(B!M9#4](C,U8C0V,S,T8V1C8S=F830Q-F(Y9CEF8V$U.#<T93@P
M(CX*("`@(#QT:71L93ZPOJ9NLUVI=SH@JOZE\\!(L4BE\Z1`L%^SQJ7W/"]T
M:71L93X*("`@(#QP87)A/@H@("`@IG"J1\!XIG.Q2*7SL\:E]Z[)H4&H3:EW
MK$^G7Z1=K6ZD0*C6P'BF<ZK^I5O`R:[7H4.D5:9#O^^VM:5IJ-&PT:;2H4<*
M("`@(#PO<&%R83X*"B`@("`\<&%R83X*("`@("H@(J7#N[?`>*9SJOZE6\#)
MKM<B("T@IF*V;*7SO7.\9[5EK;&DI*7#N[>DHZUNM*.EW,!XIG.J_J5;P,FN
MUZ%&IM.E0JK^I5O`R:[7I<.[M\!(M=NK2*7SI$"P7[/&I,"A0PH@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("`J("*THZ7<I]JA0:A#I$"KRJ5=IW2J_J5;
MP,FNUZJZJTBE\[%(I5BKX3L@N7>S7:RPK6XB("T@IF*V;*7SO7.\9[5EK;&D
MI*7#N[>THZ7<P'BF<ZK^I5O`R:[7H4:Y=[-=K+#`>*9SH4,*("`@(#PO<&%R
M83X*("`@(#QP87)A/@H@("`@*B`BM*.EW*?:H4&H0Z1`J\JE7:=TJOZE6\#)
MKM>JNJM(I?.Q2*58J^$[(+EWLUVLL*2CK6XB("T@IF*V;*7SO7.\9[5EK;&D
MI*7#N[>THZ7<P'BF<ZK^I5O`R:[7H4:Y=[-=K+"DH\!XIG.A0PH@("`@/"]P
M87)A/@H@("`@/'!A<F$^"B`@("`J("*EPZ2CP'BF<ZK^I5O`R:[7(B`M(*9B
MMFRE\[USO&>U9:VQI*2EP[NWI*.M;K2CI=S`>*9SJOZE6\#)KM>A1J;3I4*J
M_J5;P,FNUZ7#N[>DH[=\P$BUVZM(I?.D0+!?L\:DP*%#"B`@("`\+W!A<F$^
M"B`@/"]E;G1R>3X*("`\96YT<GD@:60](G9I<G1U86Q?:6YB;W@B('-T871E
M/2)U<'1O9&%T92(@;60U/2(T9#$Y-CEE-C0P9C9E,&)E9#1F.#DU.&8P,3AC
M,F0P-R(^"B`@("`\=&ET;&4^M>K`P*M(I?.G6#H@M>K`P*:LI?.G6#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@(+7JP,"FK*7SIUBW?*;;L,JW:K1-I=B\T*M(
MI?.G6*2DJKJITJ:SMW.V;*7SH4&HP[%.J=*FL[CSJTBE\Z=8MVJT3:JZM;*J
M1\!XIG.LL+/FI$"K2*7SIUBA0Z:SIT^I\Z:LI?.G6*%!M>K`P*:LI?.G6*G2
MIG.I\:JZMLBE=:Q/MVJT3:JZM;*J1Z;3I*.L3ZM(I?.A0ZG2O]>EV+S0JTBE
M\Z=8J_RJNJQ/.J5((JM(I?.G6"TF9W0[O^^^W*=`I<ZDZ*:A+29G=#O`RZQD
MMW.V;*7S(JG2I,2_[ZJZJTBE\Z=8H4,*("`@(#PO<&%R83X*("`\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB=FER='5A;%]T<F%S:"(@<W1A=&4](G5P=&]D871E
M(B!M9#4](C$Q9CDQ.#$Q8CEB,F%F.3!F938X-S0P9C9A.#9C968V(CX*("`@
M(#QT:71L93ZUZL#`JTBE\Z=8.B"UZL#`J56GH[UC/"]T:71L93X*("`@(#QP
M87)A/@H@("`@5FER='5A;"!4<F%S:"!I<R!A('-A=F5D('-E87)C:"!T:&%T
M(&1O97,@87=A>2!W:71H('1H92!N965D(&9O<B!A('-E<&%R871E(%1R87-H
M(&9O;&1E<BX@($EN<W1E860@;V8@;6]V:6YG(&UE<W-A9V5S('1O(&$@8V5N
M=')A;&EZ960@=')A<V@@9F]L9&5R+"!M97-S86=E<R!A<F4@<VEM<&QY(&UA
M<FME9"!A<R!D96QE=&5D(&EN('1H92!C=7)R96YT(&9O;&1E<B!T:&5Y(&QI
M=F4@:6XN("!7:&5N("=S:&]W(&1E;&5T960@;65S<V%G97,G(&ES('1U<FYE
M9"!O9F8L('1H:7,@<F5S=6QT<R!I;B!T:&5S92!M97-S86=E<R!N;W0@87!P
M96%R:6YG(&EN(&$@;6%I;&)O>"!V:65W+B`@5VAE;B!A('5S97(@8VQI8VMS
M(&]N(%9I<G1U86P@5')A<V@L("IA;&PJ(&UA:6QB;WAE<R!A;&P@<V5A<F-H
M960@9F]R(&UE<W-A9V5S('1H870@87)E(&9L86=G960@9&5L971E9"!A;F0@
M=&AE<V4@;65S<V%G97,@87)E(&1I<W!L87EE9"!I;B!A('-I;F=L92!M86EL
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQO
M8V%L92\N:'1A8V-E<W,`````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`Q-@`Q,#0Q-S,V,C<V,P`P,C`R-#$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1&5N>2!F<F]M(&%L;`H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R\`````````````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-C8`,#$U-C,S`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+W!O+VMO7TM2+G!O````````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#,V,3`T-@`Q,#0Q-S,V,C<V,P`P,3<R,#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R!+;W)E86X@
M=')A;G-L871I;VYS(&9O<B!H;W)D92!P86-K86=E"B,@:&]R9&4@QM#%L,'V
MOZ$@M.O'T2#'T;&YONX@N?B_JKFN+@HC($-O<'ER:6=H="`H0RD@,C`P-2!(
M;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R
M('1H92!S86UE(&QI8V5N<V4@87,@=&AE(&AO<F1E('!A8VMA9V4N"B,*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($E-4"`T+C`M
M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,2TQ,2TP.2`Q-CHR.2LP
M.3`P7&XB"B),87-T+51R86YS;&%T;W(Z($II;FAY;VL@2&5O(#QN;W9E;6)R
M94!O=7)N871U<F4N;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T
M<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]155#+4M27&XB"B)#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@("`@("!#8SH@(@IM<V=S='(@(KG>
MM,*[Y[;W.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$U"FUS9VED("(@("`@
M("!4;SH@(@IM<V=S='(@(KG>M,*[Y[;W.B`B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z-#`S"FUS9VED("(@("`@1&%T93H@(@IM<V=S='(@(K.OPJ4Z("(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT,#8*;7-G:60@(B`@("!&<F]M.B`B"FUS9W-T
M<B`BNKBSO;OGMO<Z("(*"B,Z(&UA:6QB;W@N<&AP.C0R,B!T96UP;&%T97,O
M9F]L9&5R<R]H96%D+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C
M97-S:V5Y("5S*2(*;7-G<W1R("(@*+3<P^#%L"`E<RDB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z-#$R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(L&FN/$Z
M("(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I
M9"`B(&EN("(*;7-G<W1R("(@.B`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1H
M<F5A9"YP:'`Z,34Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!-
M97-S86=E<R(*;7-G<W1R("+&[<'V(+[XP+TB"@HC.B!M86EL8F]X+G!H<#HQ
M-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA
M=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(E9+"S(,;MP?8@P?:_]L'\+B`B
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T
M('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
MP,P@QNW!]K3"(+W#O;K%VR"P_+BNP-J_H;#4(+VZQM3`N+?.(+JXL.VUQ[[Z
MO<"TS[39+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!N;W0@<W!A;2XB"FUS9W-T<B`BP,P@QNW!]K3"(+W#O;K%VR"P_+BNP-J_
MH;#4(+VZQM3`N+?.(+JXL.VUQ[[ZO<"TS[39+B(*"B,Z(&QI8B]3<&%M+G!H
M<#HQ-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(L#,(,;MP?:TPB"]P[VZQ=L@L/RXKL#:
MOZ&PU""]NL;4P+BWSB"ZN+#MM<>^^KW`M,^TV2XB"@HC.B!L:6(O4W!A;2YP
M:'`Z,34P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E
M<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`BP,P@QNW!
M]K3"(+W#O;K%VR"P_+BNP-J_H;#4(+VZQM3`N+?.(+JXL.VUQ[[ZO<"TS[39
M+B(*"B,Z(&UA:6QB;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"`O("5D("C&[<'V
M.B`E9"DB"@HC.B!M86EL8F]X+G!H<#HV-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@
M;F]T(')E;F%M960N(@IM<V=S='(@(B5S(+"A(,#,N<P@P;C`Y\?5M,^TV2X@
M)7,@QNW!]L?4P,<@P,RXI\"[(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!L
M:6(O365S<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@
M(B5S(+3"(,&DN_/`^\#.(,;MP?;'U,"XM\X@NKC`S,'V(+[*O<"TS[39+B(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT
M:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@8F5I
M;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G<W1R
M("(E<R#&[<'VQ]3`QR#`S+BGP+L@N,6_^</*(+JOL.;'U;3/M-DN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(L;MP?;'U"!<(B5S
M7"+`S"!<(B5S7"*_H2"\NK#XP/O`N+?.(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H92!I;G9I
M=&%T:6]N('1O("5S+B(*;7-G<W1R("(E<R#!I,#'N*8@P-#`NR"\]B"^^+W`
MM,^TV2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("*UI<#,Q;@@P-/&]\:N(+_`M_DB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U
M<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(L;MP?8@O*VY]B#!I+JXN^?'UR(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!<
M(B5S7"(N(@IM<V=S='(@(L;MP?;'U"!<(B5S7"+`S"!<(B5S7"*_H2"\NK#X
MP/O`N+?.(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O
M(&%M;65N9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@
M;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I
M;VX@86)O=70@)7,N(@IM<V=S='(@(B5S(,&DP,>XIB#`T,"[(+SV(+[XO<"T
MS[39+B(*"B,Z(&UE<W-A9V4N<&AP.C(X-2!M97-S86=E+G!H<#HR.3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC.C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*2(*;7-G<W1R("(E
M<SH@)7,@*"5D)FYB<W`[+R9N8G-P.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N
M9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BDB"FUS9W-T<B`B*+JOL.:[
MY\?7(,#[O^L@R,0@M-G`O2#(K;CIP+BWSB#`S+6_*2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`*;7-G:60@(BA$:7-C87)D(&%L
M;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BDB
M"FUS9W-T<B`B*+CPM><@NJ^PYKOGQ]<@P^N\TB#(Q""UQ[6YOL:PH;'B+BDB
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@
M(BA(5$U,*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!497AT*2(*;7-G<W1R("(B"@HC
M.B!S<&5L;&EN9RYP:'`Z,C@P"FUS9VED("(B"B(H4F5T=7)N('1O('1H92!C
M;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E
M('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@
M=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BBX\+7G(+JOL.:[
MY\?7(,#[O^L@R,0@M<>UN;[&L*@N(,?VP.<@R*VXZ<#'(+JOL.:SN[_KP+H@
MP/N_Z[7'P?8@OLJ]P+3/M-DN*2(*"B,Z('-P96QL:6YG+G!H<#HR-S<*;7-G
M:60@(B(*(BA396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG
M97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE("(*(F-U<G)E;G0@
M<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(HN/"U
MYR"ZK[#FL[N_Z\"[(,#[O^L@R,0@QNW!]B"ZN+.[L>(N(,?VP.<@R*VXZ<#'
M(+JOL.:SN[_KP+H@P/N_Z[7'P?8@OLJ]P+3/(@HBM-DN*2(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D9"!T
M:&5S92!B>2!C;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@3TNXIB#%K+BOQ\^_
MJ2##W["AQ\^\O+_D("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I
M("HB"FUS9W-T<B`B*B#!UKS2N*8@O+'%P\?/O+R_Y"`J(@H*(SH@;6%I;&)O
M>"YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`BQNW!]B#!]K_VP?PB"@HC.B!L:6(O4W!A;2YP
M:'`Z,3@P"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P
M;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`BP,P@QNW!]K3"(+W#O;K%VR"P_+BNP-J_H;#4(+VZQM3`
MN+?.(+JXL.VUQ[[ZO<"TS[39+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C`*(RP@
M9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2XB"FUS9W-T<B`BP,P@QNW!]K3"(+W#O;K%VR"P_+BNP-J_H;#4
M(+VZQM3`N+?.(+JXL.VUQ[[ZO<"TS[39+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ
M-S(*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(L#,(,;MP?:TPB"]P[VZQ=L@L/RXKL#:OZ&PU""]NL;4P+BWSB"ZN+#M
MM<>^^KW`M,^TV2XB"@HC.B!L:6(O4W!A;2YP:'`Z,34R"B,L(&9U>GIY"FUS
M9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS
M9W-T<B`BP,P@QNW!]K3"(+W#O;K%VR"P_+BNP-J_H;#4(+VZQM3`N+?.(+JX
ML.VUQ[[ZO<"TS[39+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*
M;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(C$P,,#:(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R,@IM<V=I9"`B,3`P,"!C:&%R86-T97)S
M(@IM<V=S='(@(C$P,##`VB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,C`*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(C(U,,#:(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,0IM<V=I9"`B-3`P(&-H87)A8W1E
M<G,B"FUS9W-T<B`B-3`PP-HB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B02!L87)G92!I;6%G92!N
M86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N(@IM<V=S='(@
M(B5SMO.TPB#%JR"QU[BRP,P@QNW!]K^A(,.WNLZUQ[[ZO<"TS[39+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4P"FUS9VED("(B
M"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@82!R
M971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE("(*(G)E8VEP:65N="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4*;7-G
M:60@(D%.1"(*;7-G<W1R("*QU[BNL.TB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3DP"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W"FUS9VED(")!8V-E
M<'0@<F5Q=65S="!A;F0@861D(&ET('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3,*;7-G:60@(D%C
M8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HR-3<*;7-G:60@(D%C8V5P=&5D.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C8V]U;G0G<R!N
M86UE.B(*;7-G<W1R("*PZ,&D(,#,N*<Z(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4R,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,P"B,L
M(&9U>GIY"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(KW'Q^`B"@HC.B!L:6(O
M34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C`Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,@=&\@;7D@061D
M<F5S<R!";V]K(@IM<V=S='(@(EPB)7-<(KBF(,'6O-*WS[^A(,/?L*$B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*;7-G:60@
M(D%D9"!S;W5R8V4B"FUS9W-T<B`BO-*]NB##W["A(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4W-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3@X"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HQ,C4V"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("+#M[K.QL3`
MSRA<(B5S7"(I(,/?L*&URB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3@*(RP@9G5Z>GD*;7-G:60@(B(*(D%D9&ET:6]N86P@:&5A9&5R<R!T;R!D
M:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C
M:"!H96%D97(@(@HB;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"B+&
M[<'V(+J\(+:G(,/?L*&WSB"ZN+^IP=D@N-.XM+B[*&AE861E<BDZ(#QI/BB\
ML<7#N^?'U\#,N.<L(,?1(,'9OZ$@N-.XM+B[(,?/(@HBLZJ^OR"^LKR\O^0N
M*3PO:3XB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O
M<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("*PL\#.(,&DNK@B
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@HC+"!F
M=7IZ>0IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO;B!D971A:6QS(@IM
M<V=S='(@(K"SP,X@P:2ZN"(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.CDS"B,L(&9U>GIY"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T
M86EL<R(*;7-G<W1R("*PL\#.(,&DNK@B"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L
M(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`HC+"!F=7IZ>0IM
M<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T
M<B`BL+/`SB#!I+JX(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R
M<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M8V]N=&%C=',N<&AP.C@U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,S.2!T
M96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E
M<W,@0F]O:R(*;7-G<W1R("+!UKS2M\\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,T"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(L'6O-*W
MSR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*(RP@9G5Z>GD*;7-G
M:60@(B(*(D%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P
M=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@(@HB;&EN92D\
M+V5M/B(*;7-G<W1R("(B"B*X\+7G(,;MP?:_H2##W["AQ](@O/O`NL+\P;8@
MP=:\TCH@/&D^*+RQQ<.[Y\?7P,RXYRP@Q]$@P=F_H2#!UKS2(,?/LZJ^OR"^
MLKR\(@HBO^0N*3PO:3XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q
M"B,L(&9U>GIY"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T
M:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C
M:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB
MN/"UYR#&[<'VOZ$@P]^PH<?2(+S[P+K"_,&V(,'6O-(Z(#QI/BB\L<7#N^?'
MU\#,N.<L(,?1(,'9OZ$@P=:\TB#'S[.JOK\@OK*\O"(*(K_D+BD\+VD^(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")!;&PB"FUS9W-T<B`BN/"USB"\L<7#
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,PIM<V=I
M9"`B(@HB06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I
M('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8("(*(F9I;&4Z(@IM
M<V=S='(@(K39P+T@QNW!]L?4P,<@N/"UYR#&[<'VN*8@Q\^SJL#'($U"3U@@
MQL3`S[?.(+39O^ZWSK7EQ]6TS[39+B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W!U<F=E7W1R87-H+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!;&P@;65S<V%G97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H
M86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N(@IM
M<V=S='(@(EPB)7-<(B#&[<'VQ]2_H;RM("5S(,#/NKBTV2"_P+>AM<@@QNW!
M]KBF(,'VO_.TS[39+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T
M95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E('1H86X@)7,@
M;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@(B5S(+"SO_FZ
MN+39(+_`MZ&UR"#&[<'VP,<@N+7%J2##M[K.(,;$P,_`NR#!]K_SM,^TV2XB
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E
M(&1E;&5T960N(@IM<V=S='(@(B5S(+"SO_FZN+39(+_`MZ&UR""ZN+.]QNW!
M]L?4P+L@N/"USB#!]K_SM,^TV2XB"@HC.B!A8VPN<&AP.C@U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@<FEG:'1S(&]N(&9O;&1E<B!<(B5S
M7"(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@7"(E<UPB+B(*;7-G
M<W1R("+&[<'VQ]0@7"(E<UPBP,P@7"(E<UPBM\X@NJ^PYK7'OOJ]P+3/M-DN
M(@H*(SH@;&EB+V%P:2YP:'`Z-S8*;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A
M=&EO;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C0X"FUS9VED(")!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE
M9"!I;B!A;GD@;6%I;&)O>#\B"FUS9W-T<B`BN/"UYR#&[<'VQ]2_H2#'RL7-
M(+'4Q*+`NR#`^[_KQ](@O/8@P-:PU"#'TK'NO^0_(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E
M('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ(@IM<V=S='(@(L#,(+K.NM"_H2"T
MZ\?1(+39N*4@M.O#O""SN[_K.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-S(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X-`IM<V=I9"`B06QW87ES
M(@IM<V=S='(@(L?7N_,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34W
M"FUS9VED(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R("+'U[OS
M(,.WNL[&Q,#/(,#ZP.7'S['B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4P-0IM
M<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O
M('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@(@HB<V%I
M9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#@*(RP@9G5Z
M>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A
M=&EN9R!T:&4@;F5W(&YO=&4N(@IM<V=S='(@(KOU(,?7N/$@P]^PH;W#(+[+
MO/8@OOBTPB"_P+?Y(+G?N_TN(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X-PHC
M+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE
M(&-R96%T:6YG('1H92!N97<@=&%S:RXB"FUS9W-T<B`BN_4@Q]>X\2##W["A
MO<,@OLN\]B"^^+3"(+_`M_D@N=^[_2XB"@HC.B!M97-S86=E+G!H<#HU,#`@
M;6%I;&)O>"YP:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R
M("*TY,#EQ]0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS
M9VED(")!;G-W97)E9"!M97-S86=E<R(*;7-G<W1R("*TY,#EQ]$@QNW!]B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PIM<V=I9"`B07!P
M;'D@1FEL=&5R<R(*;7-G<W1R("+'RL7-(,#[O^O'S['B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`B)7,@QNW!]L?4OZ$@Q\K%
MS2#`^[_KQ\^QXB(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS
M-@IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\B
M"FUS9W-T<B`BM\ZQU\#.Q](@MJ<@Q\K%S2#`^[_K(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C0R"FUS9VED(")!<'!L>2!F:6QT97(@<G5L
M97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/R(*;7-G<W1R("*YWL"Z
MQNW!]L?4(+"[O<6]PR#'RL7-(,#[O^LB"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!F=7IZ
M>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES
M('!U8FQI8R!K97D_(@IM<V=S='(@(L#,(,;MP?:XIB"_M;_XR/<@P?:_[+#:
MO<"TS['N/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"B,L(&9U>GIY"FUS9VED("(B"B)!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H
M:7,@:7,@3D]4(')E8V]M;65N9&5D(2DB"FUS9W-T<B`BP,P@QNW!]KBF(+^U
MO_C(]R#!]K_LL-J]P+3/L>X_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\B"FUS9W-T
M<B`BL.B\TR#!^,?@Q\^]P[#:O<"TS['N/R(*"B,Z(&UE<W-A9V4N<&AP.C0P
M-R!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV.`IM<V=I9"`B
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T
M:&5S92!M97-S86=E<S\B"FUS9W-T<B`BP,P@QNW!]KBF(+^UO_C(]R#!]K_L
ML-J]P+3/L>X_(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(Q-0IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T
M92!T:&ES(&%T=&%C:&UE;G0_(@IM<V=S='(@(L#,(,.WNL[&Q,#/P+L@O[6_
M^,CW(,'VO^RPVKW`M,^Q[C\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M
M<'1Y('1H:7,@9F]L9&5R/R(*;7-G<W1R("+`S"#&[<'VQ]3`NR"Z\;_LO<.P
MVKW`M,^Q[C\B"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@9F]L
M9&5R/R(*;7-G<W1R("+!]K_NQNW!]L?4*%1R87-H*<"[(+KQO^R]P[#:O<"T
MS['N/R(*"B,Z(&QI8B])35`N<&AP.CDV-@IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/R(*;7-G<W1R
M("+!]K_NQNW!]L?4*%1R87-H*<"[(+KQO^R]P[#:O<"TS['N/R(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S
M<V%G97,_(@IM<V=S='(@(L#,(,;MP?:XIB"_S\#\R/<@P?:_[+#:O<"TS['N
M/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"B,L(&9U>GIY"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S
M<V%G92!A<R!I;FYO8V5N=#\B"FUS9W-T<B`BP,P@QNW!]KBF(+^UO_C(]R#!
M]K_LL-J]P+3/L>X_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP
M="YI;F,Z-S4@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*
M(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O
M<G0@=&AI<R!M97-S86=E(&%S('-P86T_(@IM<V=S='(@(L#,(,;MP?:XIB"_
MM;_XR/<@P?:_[+#:O<"TS['N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,38*;7-G:60@(D%R<FEV86P@5&EM92(*;7-G<W1R("*UM<+X(+W#L*,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E;F1I
M;F<B"FUS9W-T<B`BO\"XI\+WO/@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3<Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#,*;7-G:60@(D%S:R(*
M;7-G<W1R("*YL+[NNKBQXB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4Q.0IM<V=I9"`B071T86-H(@IM<V=S='(@(L;$P,\@P[>ZSB(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W-0IM<V=I9"`B
M071T86-H($9I;&5S(@IM<V=S='(@(L;$P,\@P[>ZSB(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U-@IM<V=I9"`B071T86-H(&$@8V]P
M>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.0IM<V=I
M9"`B071T86-H960@1FEL93HB"FUS9W-T<B`BP[>ZSK7((,;$P,\Z(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0U,2!L:6(O0V]M<&]S92YP:'`Z-3,V"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E
M9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C
M:&5D+B(*;7-G<W1R("(E<[3"(,;$P,_#M[K.(,6IL>(@Q]&PZ+BF(,/*L/K'
MS[^I(,.WNLZUQ\'V(+[*OM*]P+3/M-DN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C,W-@IM<V=I9"`B071T86-H960@:7,@82!R97!L>2!T;R!A
M(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M<&QA=&5S+V-O;7!O
M<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4P-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ
M<SHY-PIM<V=I9"`B071T86-H;65N="(*;7-G<W1R("+&Q,#/P[>ZSB(*"B,Z
M(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP.C0V-@IM<V=I9"`B
M071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N="!T>7!E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C,T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S,*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$P-S,*;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S='(@
M(L;$P,\@P[>ZSB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#(*
M(RP@9G5Z>GD*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R("+&Q,#/(,.WNLXB
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PIM<V=I
M9"`B071T96YT:6]N(@IM<V=S='(@(K[+N+(B"@HC.B!L:6(O075T:"]I;7`N
M<&AP.C0T"FUS9VED(")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C0P"FUS9VED("(B"B)!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S
M(&EN($A434P@;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*
M(F%D9')E<W-B;V]K/R(*;7-G<W1R("(B"B*ZN+.]N^>V]\#,(,'6O-*WS[^A
M(+7ION[`UK3"(+#FO^P@2%1-3"#&[<'VP,<@P,RYS,'VN*8@P-JUO\"XM\X@
MNKB_J<'9L>Z_Y#\B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHR.3@*;7-G:60@(D%V86EL86)L92!!9&1R97-S(&)O;VMS.B(*;7-G
M<W1R("+`S+_KL*&TR<?1(,'6O-*WSSHB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S$Y"FUS9VED(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8U]K('1O("5S(@IM<V=S='(@
M(E]K)7.WSB"UN;[&L*&QXB(*"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R("(E<[?.(+6YOL:PH;'B(@H*
M(SH@=&AR96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S
M<V%G92!6:65W($EN9&5X(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,R
M"FUS9VED(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W)E8V]M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C
M8R(*;7-G<W1R("*\^\"ZPOS!MB(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B0F5L;W<@:7,@=&AE(')A=R!T
M97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S<V%G92XB"FUS9W-T
M<B`BQNW!]B#`_+3>(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`BO/:]Q;#%NLXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C(Y"FUS9VED(")";&]C:R!I;6%G97,@:6X@
M2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E
M<75E<W1E9#\B"FUS9W-T<B`BO^3#N\#,(+[XM-FXZ2!(5$U,(,;MP?;`QR"Q
MU[BRP+L@N+?`N['NO^0_(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(*;7-G:60@
M(D)O9'DB"FUS9W-T<B`BNKNYKB(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z,C,@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS.0HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4U('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-S$*;7-G:60@(D)O=&@B"FUS9W-T<B`BN/"USB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV.#<*;7-G:60@(D)O=&@@2&5A9&5R($QI<W1I
M;F<@86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R("*USK"AP?8@N/"USB(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,@IM<V=I9"`B
M0U]H87)S970B"FUS9W-T<B`BN:[`VKS"(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]F:65L9',N:6YC.C,V"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("*TWK?"
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N
M;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R
M("*_W+K.(+C>P,^\K;GVOZ$@P:*\T\?2(+SV(+[XO<"TS[39+B(*"B,Z(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE
M8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(K_<NLX@
MN-[`S[RMN?:_H2#!HKS3Q](@O/8@OOB]P+3/M-DZ("(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S
M(&]F('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*
M;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP
M;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z
M,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L
M871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S
M92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM
M<V=I9"`B0V%N8V5L(@IM<V=S='(@(L/KO-(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHW,2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT,S4*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q
M,0IM<V=I9"`B0V%N8V5L($UE<W-A9V4B"FUS9W-T<B`BQNW!]B##Z[S2(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")#86YC96QL:6YG('1H:7,@
M;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S
M+B(*;7-G<W1R("+#Z[S2Q\^XZ2#`S"#&[<'VP,<@L[N_Z\"Z(+^UL;C(]R#!
M]K_VP?:PU""UR[3/M-DN(@H*(SH@;65S<V%G92YP:'`Z,C8U('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W)E8V]M<&]S92YI;F,Z,34@;&EB+U-E87)C:"YP:'`Z,S`*;7-G:60@
M(D-C(@IM<V=S='(@(L+\P;8B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V
M86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R`B
M"B)S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW,#$*(RP@9G5Z>GD*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R
M("*PL\#.(,;MP?8B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R("*ZK[#F(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL
M(@IM<V=S='(@(KCPM<X@NJ^PYB(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHY,@IM<V=I9"`B0VAA;F=E($9O;&1E<B(*;7-G<W1R("+&[<'VQ]0@NJ^P
MYB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3(*;7-G:60@(B(*(D-H
M86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E
M<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S(&%R
M92!S;W)T960N(@IM<V=S='(@(K"B(,;DP,S!]K3G(,;MP?8@L+F\]K_-(,;M
MP?8@P:2WQ""\^+RM(+RSP:0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C0*;7-G:60@(D-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I
M;F=S+B(*;7-G<W1R("*XWL#/O*VY]K_-(,;MP?;'U""\L\&D(+JOL.8B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@(B(*(D-H86YG92!T
M:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD("(*(G)E<&QY('1O('EO=7(@96UA:6PN
M(@IM<V=S='(@(L;MP?:XIB"ZN+.^(+:G(+OGO^O'TB#`S+BG+"#!UKS2+""\
MK;CMP+L@NJ^PYL?5M,^TV2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#(T"FUS9VED(")#:&%R86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#
M:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(L;MP?;'U+^A
MO*T@N_4@N-[`SR"PR[OG(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C<U"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C$P('1E;7!L871E<R]F
M971C:&UA:6PO9F5T8VAM86EL+FEN8SHR,0IM<V=I9"`B0VAE8VL@86QL(&UA
M:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*;7-G:60@(D-H
M96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T
M<B`BQNW!]B"ZN+.[L>(@P/P@P[;`VB"PR[OGQ\^QXB(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G:60@(D-H;V]S92!!8W1I;VXZ
M(@IM<V=S='(@(KRQQ<.[Y\?7.B(*"B,Z(&-O;F9I9R]S97)V97)S+G!H<"YD
M:7-T.C$X,@HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z
M(@IM<V=S='(@(KRQQ<.[Y\?7.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C$R-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ
M-C8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C$W"B,L(&9U
M>GIY"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E9&ET('1H92!A9&1R97-S
M('1O('1H92!R:6=H=#HB"FUS9W-T<B`BO+'%P\?/L,6SJB"_P+BEPLH@M-G`
MO<?7N/'`NR"\]L&DQ\^\O+_D.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,0HC+"!F=7IZ
M>0IM<V=I9"`B0VAO;W-E(&%N(&%C=&EO;CHB"FUS9W-T<B`BO+'%P[OGQ]<Z
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"B,L
M(&9U>GIY"FUS9VED(")#:&]O<V4@=&AE(&%D9')E<W,@8F]O:R!T;R!U<V4@
M=VAE;B!A9&1I;F<@861D<F5S<V5S+B(*;7-G<W1R("+!UKS2N*8@P]^PH;W#
M(,'6O-*WSR"[Y[_K+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('1H92!O<F1E<B!O
M9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R
M97-S97,N(@IM<V=S='(@(L'6O-(@R*[`Y;W#(+#+N_;'TB#!UKS2M\\@O/B\
MK2"\L<7#(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM
M86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N
M(@IM<V=S='(@(KKJMO._[,&NL*$@NKP@O/8@P-:TPB#'_+W$P+BWSB"QU[BR
M(,;$P,_`NR"ZK\BOQ\^WP;CI("5SN*8@M*FXH[R\O^0N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQI8VL@)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+B(*;7-G<W1R("+`S+G,
MP?:XIB"SN[?!N=[`N+?!N.D@)7.XIB"TJ;BCO+R_Y"XB"@HC.B!L:6(O1FEL
M=&5R+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@
M9V\@=&\@)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R("(E<[BF(+2IN*.X
MZ2`E<R"P_+BNQN3`S,'VM\X@L*FTS[39+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@
M=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM
M<V=S='(@(KOU(,.BOZ&\K2!H=&UL(+.[O^O`NR"ZN+?!N.D@)7.XIB"TJ;BC
MO+R_Y"XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I
M;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R("+`S""QU[BRP,<@O>:SU\#/P+L@
MNKBWP;CI("5SN*8@M*FXH[R\O^0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@
M=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS
M9W-T<B`BN_4@PZ*_H;RM(,.WNLZXIB"ZN+?!N.D@)7.XIB"TJ;BCO+R_Y"XB
M"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R
M96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(L#,
M(+K.NM#`NR"[]2##HK^AO*T@NKBWP;CI("5SN*8@Q:RXK\?/O+R_Y"XB"@HC
M.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE
M<F4@=&\@4TA/5R!T:&4@26UA9V5S(@IM<V=S='(@(L#,N<S!]KBF(+JXM\&X
MZ2"_J;'BN*8@M*FXH[R\O^0N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C
M97-E;&5C="YI;F,Z,S(Q"B,L(&9U>GIY"FUS9VED("(B"B)#;&EC:R!O;B!O
M;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E
M;&5C="!A;&P@9FEE;&1S('1O("(*(G-E87)C:"XB"FUS9W-T<B`BO+'%P[7(
M(,'6O-*WS\'?(,?/LZJXIB"\L<7#Q]'(Q""PR[OV(,?7N/'`NR"\L<7#Q\^\
MO+_D+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,0IM<V=I9"`B
M0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@
M8F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R!T;R!3879E(%,O34E-
M12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O:R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34P"FUS9VED(")#
M;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S
M<V%G92!T;R!T:&4@<V5N9&5R(@IM<V=S='(@(L'6O-*XIB#%K+BOQ\^XZ2"Z
MN+.]P,R_H;#4(+OU(,;MP?:XIB"^N;3/M-DN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDU,0IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@
M=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860B"FUS9W-T<B`BP=:\
MTKBF(,6LN*_'S[CI(,;MP?:XIB"ZN+^IP=VTS[39+B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B
M0VQO<V4B"FUS9W-T<B`BN_4@QNW!]B(*"B,Z(&-O;7!O<V4N<&AP.C@R."!C
M;VUP;W-E+G!H<#HQ,30X"FUS9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G
M<W1R("+#HB"TW;'B(@H*(SH@9F]L9&5R<RYP:'`Z-#(Y"FUS9VED(")#;&]S
M960@1F]L9&5R(@IM<V=S='(@(K3=R/D@QNW!]L?4(@H*(SH@9F]L9&5R<RYP
M:'`Z-#0Y"FUS9VED(")#;VQL87!S92(*;7-G<W1R("*TW;'B(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E
M($%L;"(*;7-G<W1R("*X\+7.(+3=L>(B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B
M"FUS9W-T<B`BN/"UYR#&[<'VQ]0@M-VQXB(*"B,Z(&9O;&1E<G,N<&AP.C0T
M.0IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM<V=S='(@(L;MP?;'U""TW;'B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C4Q"FUS9VED
M(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3`S"B,L(&9U>GIY"FUS9VED(")#;VUM96YT(@IM<V=S
M='(@(KOU(,;MP?8B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8Y
M"B,L(&9U>GIY"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`BN_4@QNW!]B(*
M"B,Z(&-O;7!O<V4N<&AP.C@R-R!C;VUP;W-E+G!H<#HQ,30W"FUS9VED(")#
M;VUP;W-E(&%N;W1H97(@;65S<V%G92(*;7-G<W1R("*[]2#&[<'V(,#;O+HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP;W-E
M(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R("*[]2##
MHK^AO*T@QNW!]B#`V[RZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M,PIM<V=I9"`B(@HB0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@1U5)
M(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE("(*(F9E871U
M<F4I/R(*;7-G<W1R("(B"B(HNNJV\[_LP:ZPH2"QXK3)P+L@P?:_^,?2(+#F
MO^PI(,;MP?:XIB"^M2"VIR!(5$U,(,#;O+JX\+7EN*8@L>*ZN\"XM\X@Q]*Q
M[K_D/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-PIM<V=I9"`B0V]N
M9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+B(*;7-G<W1R("+&
M[<'V(+JXM,(@N>:Y_<"[(+RSP:3'U;3/M-DN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDW"FUS9VED(")#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P
M=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S<P
M"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&1R;W!P960@8GD@24U!4"!S
M97)V97(N(@IM<V=S='(@(KRMN?8@OZRPX2"]Q\;0(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@(D-O;FYE8W1I;VX@=&\@<V5R=F5R
M(&9A:6QE9"(*;7-G<W1R("*\K;GV(+^LL.$@O<?&T"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O
M;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O
M;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R
M96QA=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W
M:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R
M(&]R(&YO="!T;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS
M9W-T<B`BN_4@QNW!]B"UM<+X(+[+N+(@N^>_ZR"\L\&D(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8Y-@IM<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M
M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R("*YKL#:(,#,
MN/#&O,3<P+L@L=>XLL"XM\X@N=FRW+'NO^0_(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@(KJYN^<B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'D@=&\@
M9F]L9&5R(@IM<V=S='(@(L;MP?;'U,"XM\X@NKF[YR(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G
M<W1R("*QL\&D(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`BL;/!I+7((+J[
MN:XB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S="X@4F5A<V]N($=I
M=F5N.B`E<R(*;7-G<W1R("(B"@HC.B!A='1A8VAM96YT+G!H<#HU,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E('1H92!61E,@8F%C
M:V5N9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M
M97-S86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@
M(EPB)7-<(K?.NL[%S2#&[<'V(,'VO^RQXB"]Q\;0+B"\K;GVP,<@O\"W^3H@
M(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C,Q.`HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T
M<B`BQNW!]L?4(+_NO^L@(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HU.`IM<V=I9"`B0V]U;&0@;F]T
M(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H
M:79E+B(*;7-G<W1R("(B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<S"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R
M;VT@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z,S$T
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,`IM
M<V=I9"`B0W)E871E(@IM<V=S='(@(KBXM>FQXB(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C8*;7-G:60@(D-R96%T92!&;VQD97(B"FUS
M9W-T<B`BN_4@QNW!]L?4(+BXM>FQXB(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,S<*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@
M(KBXM>FQXB(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-`IM
M<V=I9"`B0W)E871E(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(K"AN_,@QNW!
M]L?4(+BXM>FQXB(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S
M96QE8W0N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!.97<@06-C
M;W5N="(*;7-G<W1R("*TV;BE(+C>P,\@L.C!I"(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S<&%M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A;7-E
M;&5C="YI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE=R!3<&%M
M(&9O;&1E<B(*;7-G<W1R("*[]2#!]K_NQNW!]L?4(+BXM>FQXB(*"B,Z('1E
M;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P
M<F5F<R]F;VQD97)S96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@
M9')A9G1S(&9O;&1E<B(*;7-G<W1R("+`T[W#NKBP_,?4(+OUM\X@N+BUZ;'B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR-B!T
M96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0R"FUS9VED(")#
M<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("*[]2"ZN+.]
MQNW!]L?4(+BXM>FQXB(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C
M="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR-`IM
M<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R("*[]2#!
M]K_NQNW!]L?4(+BXM>FQXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C@*;7-G:60@(B(*(D-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI
M>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@
M(@HB86YD(&1E;&5T92!S<&%M+B(*;7-G<W1R("+'RL7-(+'4Q*(@N+BUZ;'B
M+"#&[<'VQ]0@P:2WQ+SXO*TL(+VZQM0@P?:_[+'B(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A
M=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`BN_4@NKBSO<;MP?;'U""XN+7I
ML>(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED(")#<F5A
M=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N
M=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS
M9W-T<B`BM-FXI2"PZ,&DP+BWSKK.Q<T@N-[`S\"[(+"AP:Z_P+6UM\\@O+/!
MI,?5M,^TV2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@
M(D-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"XB"FUS9W-T<B`BQNW!]B"Z
MN+.[M,(@N>:Y_2"\L\&DQ]6TS[39+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("+`I;C>
MP,\@M\ZQU\#.O<,@O<?'X,?2(,#;OO?`NR"\L\&DQ]6TS[39+B(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*;7-G:60@
M(D1A=%]E(@IM<V=S='(@(K.OPJ4B"@HC.B!M97-S86=E+G!H<#HR-C(@=&AR
M96%D+G!H<#HQ-#@*;7-G:60@(D1A=&4B"FUS9W-T<B`BLZ_"I2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3<*(RP@9G5Z>GD*;7-G:60@(D1E
M8VQI;F5D(@IM<V=S='(@(L'VO_;!_"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HR-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F
M875L="(*;7-G<W1R("+!]K_LL>(B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F
M875L='-E87)C:'-E;&5C="YI;F,Z,3@*;7-G:60@(D1E9F%U;'0@4V5A<F-H
M($9I96QD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,C,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`B
ML>*ZNR#!I+?$(,?7N/$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS
M,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B
ML>*ZNR#!I+?$(+GFN?TB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S8U"B,L(&9U>GIY"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`BP?:_]L'\
M(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHV.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(T-"!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(X
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM<V=I9"`B1&5L971E(@IM
M<V=S='(@(L'VO^RQXB(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@)7,@4'5B;&EC($ME>2(*;7-G<W1R("+`_,.\
M(,#,N*<Z(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z.#4*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#
M=7)R96YT($ME>7,B"FUS9W-T<B`BN+BUZ;'B(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*
M;7-G<W1R("+&[<'VQ]0@P?:_[+'B(@H*(SH@9F]L9&5R<RYP:'`Z,C@U"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R
M("+&[<'VQ]0@P?:_[+'B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4W1A=&EO;F5R>2(*
M;7-G<W1R("*PH;OS(,;MP?;'U"#!]K_LL>(B"@HC.B!F;VQD97)S+G!H<#HT
M,3D*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("*PH;OS
M(,;MP?;'U"#!]K_LL>(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-#,*;7-G:60@(D1E;&5T92!F971C:&5D(&UE<W-A9V5S(&9R;VT@
M<F5M;W1E('-E<G9E<C\B"FUS9W-T<B`BO]RZSKRMN?:_H;RM(+"AP:Z_PB#&
M[<'VN*8@P?:_[['NO^0_(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8R.`IM<V=I9"`B1&5L971E(&9R;VT@;7D@8V%L96YD87(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B1&5L971E
M(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H
M/R(*;7-G<W1R("*XQ;_YP\H@O\"WH;7((+BUQ:D@P[>ZSL;$P,\@P?:_[+'B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B1&5L971E
M(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M(@IM<V=S='(@(KC%O_G#RB"_P+>AM<@@NKBSO<;MP?;'U"#!]K_LL>(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@<W!A;2!M97-S86=E<R(*;7-G<W1R("+!]K_VP?@@QNW!]B(*"B,Z
M(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I
M9"`B1&5L971E9"(*;7-G<W1R("+!]K_VP?PB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S
M='(@(L'VO_;!^"#&[<'V(@H*(SH@8V]M<&]S92YP:'`Z,S`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T960@=&AE(&%T=&%C:&UE;G0@7"(E<UPB+B(*
M;7-G<W1R("+#M[K.QL3`SR!<(B5S7"(@P?:_]L'\(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@36]V:6YG($UE
M<W-A9V5S(@IM<V=S='(@(L;MP?8@P?:_[+'B(+G7(,#,M;\B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3DR"FUS9VED(")$96YY(')E<75E<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T,`HC
M+"!F=7IZ>0IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF
M;W)M871I;VXB"FUS9W-T<B`BQNW!]B"\K;GV(,&DNKB[Y\?7(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDS,@IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G
M<W1R("*SN[BRPO>\^"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Y"FUS9VED
M(")$97-C<FEP=&EO;B(*;7-G<W1R("+#M[K.(+RSN.TZ(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"B,L(&9U
M>GIY"FUS9VED(")$971A:6QS(@IM<V=S='(@(L#/NK`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C<W"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B"FUS
M9W-T<B`BO*VX[<"[(,CEN+3'S[#4(,>EO<,B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R
M("+'I;W#(,?\O<0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Y"FUS
M9VED(")$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S
M<V%G93\B"FUS9W-T<B`BQNW!]KBF(+JXL[NP[2"SJKRM(,BNP,X@QZ6]P[BF
M(,?2L>Z_Y#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED
M(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R("+&[<'V(+J[
MN:Z_H2"ZN+^IP=:QXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3(*
M;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I
M;#\B"FUS9W-T<B`BN_4@QNW!]B"UM<+XO<,@QLN^]\.BP+BWSB"^R[BR(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`HC+"!F=7IZ>0IM<V=I9"`B
M1&ES<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A
M<C\B"FUS9W-T<B`B)\'VO^[&[<'VQ]0@NO&_\B?`NR"XWK2ZN=F_H2"ZN+^I
MP=FQ[K_D/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-3`*(RP@9G5Z
M>GD*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP='D@5')A<VA<(B!L:6YK(&EN
M('1H92!M96YU8F%R/R(*;7-G<W1R("(GP?:_[L;MP?;'U""Z\;_R)\"[(+C>
MM+JYV;^A(+JXOZG!V;'NO^0_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C$Q"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R("*Y
MZ,2A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C(V"FUS9VED
M(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`BP,_$H<?/P?8@OLJQXB(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$V"FUS9VED(")$;R!.;W0@
M0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G<W1R("*[]2#&[<'V
M(+#+N^?'S\'V(+[*P+TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34R
M"FUS9VED(")$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C
M;VQU;6XB"FUS9W-T<B`BN=ZTPKOGMO<@Q]>X\;^A(+BUQ:FXIB"XN+7IP?8@
MOLJ]P+3/M-DN(@H*(SH@;&EB+TE-4"YP:'`Z,3`W-0IM<V=I9"`B1&\@>6]U
M('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`BQNW!]L?4P+L@
MOZVQ[K_D/R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,R"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C8*;7-G
M:60@(D1O;F4B"FUS9W-T<B`BO\^WX2(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S
M+G!H<#HQ.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,@:6X@
M+GII<"!&;W)M870B"FUS9W-T<B`B)7.XIB"^T,/@QL3`SRAZ:7`IP+BWSB"S
MN[?!N=ZQXB(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R
M"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL
M92DB"FUS9W-T<B`BOM##X,;$P,\H>FEP*;?.(,?1(+GXOZ$@L[NWP;G>L>(B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,`IM<V=I9"`B
M1&]W;FQO860@1F]L9&5R*',I(@IM<V=S='(@(L;MP?;'U""SN[?!N=ZQXB(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")$
M;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(*;7-G<W1R("*^T,/@
MQL3`SRAZ:7`IM\X@QNW!]L?4(+.[M\&YWK'B(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M870B
M"FUS9W-T<B`BOM##X,;$P,\H>FEP*;?.(+.[M\&YWK'B(@H*(SH@;65S<V%G
M92YP:'`Z-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T
M(@IM<V=S='(@(L#3O</&[<'V(@H*(SH@9F]L9&5R<RYP:'`Z,SDR"FUS9VED
M(")$<F%F="!F;VQD97(B"FUS9W-T<B`BP-.]P[JXL/S'U#HB"@HC.B!T96UP
M;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I9"`B1')A9G1S
M(&9O;&1E<CHB"FUS9W-T<B`BP-.]P[JXL/S'U#HB"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3`X"FUS9VED(")%+6UA:6P@061D<F5S<R(*;7-G<W1R
M("+`S+C>P,\@P=:\TCHB"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S`Y"B,L(&9U
M>GIY"FUS9VED(")%3D0B"FUS9W-T<B`BL=>XKK#M(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D524D]2.B!9
M;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B
MQNW!]K"A(+RZL/C`^\"XM\X@P/R\V[7'OOJ]P+3/M-DN(@H*(SH@9F]L9&5R
M<RYP:'`Z-#(P('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ.0IM
M<V=I9"`B161I="(*;7-G<W1R("+&[<'](@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET($)L86-K;&ES="(*;7-G<W1R
M("*\]KW%L,6ZSB"X\;?/(+SVP:0B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R("+'RL7-
M(+SVP:0B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")%9&ET(%9I<G1U86P@1F]L
M9&5R(@IM<V=S='(@(K"AN_,@QNW!]L?4(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHQ,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E<R(*;7-G<W1R
M("(E<R#!I,#'N*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM
M<V=S='(@(KSVO<6]PL#.(+CQM\\@O/;!I"(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*
M;7-G<W1R("*\]KW%L,6ZSB"X\;?/(+SVP:0B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@<G5L
M97,B"FUS9W-T<B`BQ\K%S2"QU,2B(+SVP:0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#8Q"FUS9VED(")%9&ET('EO=7(@<')E9F5R96YC97,@9F]R
M(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+B(*;7-G<W1R("*_W+K.
M(+C>P,\@L.C!I+^A(,&BL=G'S['B(,"GQ]$@O+'%P[OGQ]<@O/;!I,?/L>(B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D
M:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`BO/:]Q;W"P,X@N/&WSR"\]L&D
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,SD*;7-G
M:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`BP,RXWL#/(,'6O-(B"@HC.B!L
M:6(O365S<V%G92YP:'`Z-C4W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("(E<[?.
MNL[%S2#`_+3>M<@@QNW!]B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`BQNW!
M]L?4(+KQO_(B"@HC.B!F;VQD97)S+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@
M(D5M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`BQNW!]L?4(+KQO_(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B
M16UP='D@5')A<V@@9F]L9&5R(@IM<V=S='(@(L'VO^[&[<'VQ]0@NO&_\B(*
M"B,Z(&QI8B])35`N<&AP.CDW,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@7U-P
M86TB"FUS9W-T<B`B7W3!]K_NQNW!]L?4(+KQO_(B"@HC.B!L:6(O24U0+G!H
M<#HY-C8*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R(")?=,'VO^[&[<'V
MQ]0@NO&_\B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4$=0(&9U;F-T
M:6]N86QI='D_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHV"FUS9VED
M(")%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3$*(RP@9G5Z>GD*;7-G:60@(D5N
M86)L92!M97-S86=E('!R979I97=S/R(*;7-G<W1R("(E<[?.NL[%S2#`_+3>
MM<@@QNW!]B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0T
M,@IM<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*;7-G<W1R(")?>;[/R*/(
MK2"_R;S'(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q-R!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C4W"B,L(&9U>GIY"FUS9VED(")%;F0B
M"FUS9W-T<B`BR*[`Y2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#0*;7-G:60@
M(D5N9"!F;W)W87)D960@;65S<V%G92(*;7-G<W1R("+`_+3>(,;MP?8@LZ$B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0Q"B,L(&9U>GIY"FUS9VED(")%;F0@
M;65S<V%G92(*;7-G<W1R("*_OK.O(,;MP?8B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G
M92!F<F]M("5S(@IM<V=S='(@(B5SM\ZZSL7-(,#\M-ZUR"#&[<'V(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.CD*(RP@9G5Z>GD*
M;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E
M<B(*;7-G<W1R("*[]2#!]K_NQNW!]L?4(,#,N*<@P-2WPB(*"B,Z('1E;7!L
M871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H
M92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(KOU
M(,#3O<.ZN+#\Q]3`QR#`S+BG(,#4M\(B"@HC.B!T96UP;&%T97,O<')E9G,O
M<V5N=&UA:6QS96QE8W0N:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("*[]2"ZN+.]
MQNW!]L?4P,<@P,RXIR#`U+?"(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H
M<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(KOU(,'VO^[&[<'VQ]0@P,RXIR#`
MU+?"(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(D5N
M=&ER92!-97-S86=E(@IM<V=S='(@(L;MP?8@P/RTWB(*"B,Z(&UE<W-A9V4N
M<&AP.C$Y-"!C;VUP;W-E+G!H<#HQ,3,T('1H<F5A9"YP:'`Z-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")<(B5S7"*PH2#!
MUKS2M\^_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C$X('1E;7!L871E<R]P9W`O<&=P+FEN8SHR,0HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C,W-B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HS.#8*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S(@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38S"FUS9VED(")%<G)O<B(*;7-G
M<W1R("*_P+?Y(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E<G9E
M<BX@)7,@.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C,P.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`W"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`Q"B,L(&9U
M>GIY"FUS9VED(")%=F5N="!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T
M<B`BO+'%P[OGQ]>UZ<#,(+RZL/C`^\"XM\X@P/K`Y;7'OOJ]P+3/M-DN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@
M;6EN=71E<R(*;7-G<W1R("(Q-;K0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<W.0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("(S,,/*
MN+:TV2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#$*;7-G:60@(D5V
M97)Y(#4@;6EN=71E<R(*;7-G<W1R("(UNM"XMK39(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<X,PIM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S
M='(@(C,PNM"XMK39(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,`IM
M<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(KC%NM"XMK39(@H*(SH@9F]L
M9&5R<RYP:'`Z-#4W"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BR*[`Y2(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A
M;F0@06QL(@IM<V=S='(@(KCPM<X@R*[`Y2(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A;F0@06QL($9O;&1E<G,B
M"FUS9W-T<B`BN/"UYR#&[<'VQ]0@R*[`Y<?/L>(B"@HC.B!F;VQD97)S+G!H
M<#HT-3<*;7-G:60@(D5X<&%N9"!&;VQD97(B"FUS9W-T<B`BQNW!]L?4(,BN
MP.4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#`@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4S"FUS9VED(")%>'!A;F0@
M3F%M97,B"FUS9W-T<B`BP,RXIR"_S[RZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-C,*;7-G:60@(D5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S
M92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\B"FUS
M9W-T<B`BQNW!]B#`V[RZQ](@MJ<@P,RXI\"[(,#:M;_`N+?.(+_/O+HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@P"FUS9VED(")%>'!A;F0@=&AE
M(&5N=&ER92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S
M('9I97<_(@IM<V=S='(@(L;MP?;'U""X\;?/P+L@NKP@MJ<@L>*ZN\"XM\X@
MP/S#O"#&[<'VQ]0@R*[`Y<?/L>(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHQ-#0@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,3DT"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(T-2!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3`Q"FUS9VED(")%>'!A;F1I
M;F<B"FUS9W-T<B`BP-JUO[_/O+HB"@HC.B!L:6(O24U0+G!H<#HY.#0@;&EB
M+TE-4"YP:'`Z.3@V"B,L(&9U>GIY"FUS9VED(")&7V5T8V@@36%I;"(*;7-G
M<W1R("*_W+K.QNW!]B"PH<&NO\"QXB(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9F5T8VAM86EL+FEN8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T
M"FUS9VED(")&971C:"!-86EL(@IM<V=S='(@(K_<NL[&[<'V(+"AP:Z_P+'B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V.0IM<V=I9"`B1F5T8V@@
M36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`BN_4@PZ*_H;RM
M(+_<NLX@QNW!]B"PH<&NO\"QXB(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G
M:6YG(&]N/R(*;7-G<W1R("*WSK'7P,['TB"VIR"_W+K.(,;MP?8@L*'!KK_`
ML>(B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@9G)O;2`E<R(*;7-G
M<W1R("(E9,#'(,;MP?:XIB`E<[?.NL[%S2"PH<&NO\@B"@HC.B!L:6(O1F5T
M8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9E
M=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B)63`QR#&[<'VN*8@
M)7.WSKK.Q<T@L*'!KK_((@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@U(&QI
M8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@
M9G5Z>GD*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(K_<NL[&[<'V(+"A
MP:Z_P+'B(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"FUS9VED(")&971C
M:&UA:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS9W-T<B`BQNW!]K"AP:Z_P+'B
M.B"[]2#&[<'V(+[XP+TN(@H*(SH@;&EB+TE-4"YP:'`Z.3DP"FUS9VED(")&
M:5]L=&5R<R(*;7-G<W1R(")?3,?*Q<TB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:G,Z.#(*;7-G:60@(D9I;&4B"FUS9W-T<B`BQL3`SR(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHS,0IM<V=I9"`B1FEL=&5R($]P=&EO
M;G,B"FUS9W-T<B`BQ\K%S2"\L<7#N^?'UR(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHY"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T
M<B`BQ\K%S2"\L\&D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P,`HC
M+"!F=7IZ>0IM<V=I9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O
M9F%N:71Y/R(*;7-G<W1R("*Z\;S3ONZPH2"UYR"SN[_KP,<@QNW!]B#'RL7-
MN+4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$Q"FUS
M9VED(")&:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM
M<V=I9"`B1FEL=&5R<R(*;7-G<W1R("+'RL7-(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O;F]T86-T:79E+FEN8SHS"B,L(&9U>GIY"FUS9VED(")&:6QT97)S
M($Y/5"!!8W1I=F4B"FUS9W-T<B`BQ\K%S2"\L<7#N^?'UR(*"B,Z(&QI8B]&
M:6QT97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1FEL
M=&5R<SH@)7,@;6%N86=E;65N="!P86=E(@IM<V=S='(@(L?*Q<TZ("4@L/RX
MKB#&Y,#,P?8B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$X-@IM<V=I9"`B1FEN9"(*;7-G<W1R("+#H['B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP-0IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E(@IM
M<V=S='(@(L.YQN3`S,'V(@H*(SH@;6%I;&)O>"YP:'`Z,S0U"FUS9VED(")&
M:7)S="!086=E(@IM<V=S='(@(L.YQN3`S,'V(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R(")?<L#\
MM-XB"@HC.B!F;VQD97)S+G!H<#HR-C8@=&5M<&QA=&5S+V9O;&1E<G,O9F]L
M9&5R<U]C;VYF:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@+2!#
M;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S`S('1E
M;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S
M+VEN:71I86QP86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I
M;FET:6%L<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T
M;W(B"FUS9W-T<B`BQNW!]L?4(,6]N_:QXB(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HS"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R("+&[<'V
MQ]0@O^2^X"(*"B,Z(&%C;"YP:'`Z,C0*;7-G:60@(D9O;&1E<B!S:&%R:6YG
M(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HV
M,@IM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B1F]R;6%T
M(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S
M<V%G97,@9&%T960@=&]D87DB"FUS9W-T<B`BO\"TPR"SK\*E(,;MP?:_H2"T
MZ\?1(+.OPJ4@QZ6]PR#'_+W$(@H*(SH@8V]M<&]S92YP:'`Z-S@P('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G
M<W1R("+`_+3>(@H*(SH@8V]M<&]S92YP:'`Z-S8U"FUS9VED(")&;W)W87)D
M.B(*;7-G<W1R("+`_+3>.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-CD*;7-G
M:60@(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(L#\M-ZUR"#&[<'V(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(B5SM\ZZSL7-(,#\
MM-ZUR"#&[<'V(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,PHC
M+"!F=7IZ>0IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@
M(L;MP?8@O*VY]B#!I+JXN^?'UR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.30*;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U
M<WD@4F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-#`Q"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C(W"FUS9VED(")&<F]?;2(*;7-G<W1R(")?;;JXL[V[Y[;W(@H*
M(SH@;65S<V%G92YP:'`Z,C8S('1H<F5A9"YP:'`Z,30Y('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.CDY"B,Z(&QI8B]396%R8V@N<&AP.C(R"FUS
M9VED(")&<F]M(@IM<V=S='(@(KJXL[V[Y[;W(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ.`IM<V=I9"`B1G)O;2!!9&1R97-S(@IM<V=S='(@(KJX
ML[V[Y[;W(,'6O-(B"@HC.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP:'`Z
M-S@Q"FUS9VED(")&=V0Z(@IM<V=S='(@(L#\M-XZ(@H*(SH@8V]M<&]S92YP
M:'`Z,3(Y-`IM<V=I9"`B1G=D.B`B"FUS9W-T<B`BP/RTWCHB"@HC.B!C;VUP
M;W-E+G!H<#HQ,CDV"B,L('!H<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R
M=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(L#\M-XZ("5U(,#\M-X@QNW!]B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S
M='(@(L#/N=W`^\#.(+_)O,<B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M97-S86=E<S\@*$E-
M05`@;VYL>2DB"FUS9W-T<B`BN_6WSK_N(+C>P,^XN""PH<&NO\.Q[K_D/R`H
M24U!4"#`_+_K*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C,Q"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$S-@IM
M<V=I9"`B1V\@=&\@365S<V%G92(*;7-G<W1R("+&[<'VM\X@L*&QXB(*"B,Z
M(&QI8B])35`N<&AP.C0Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R(")<
M(B5S7"*XIB#!UKS2M\^_H2##W["A(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$S-0IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C4T-B!L:6(O1FEL=&5R+G!H<#HQ,#4@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z.34*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,3`R(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C$Q-@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H
M<#HV,B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L
M:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HT,3@*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE
M+G!H<#HT,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C$R-PIM<V=I9"`B2$5212(*;7-G<W1R("*_J;'B(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,Q(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,3<*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP
M.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C(U
M-@IM<V=I9"`B2%1-3"!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B2%1-
M3"#'_+W$(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`BN-.XM+';(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M
M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V.`IM<V=I9"`B2&ED9&5N(@IM<V=S='(@
M(K"HP]^QXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C<*;7-G:60@
M(DAI9&1E;B!I;B!4:')E860@5FEE=R(*;7-G<W1R("*T\;';NKBQXK^AO*T@
ML*C#W['B(@H*(SH@;6%I;&)O>"YP:'`Z,S8W"FUS9VED(")(:61E($1E;&5T
M960B"FUS9W-T<B`BP?:_]L'X(,;MP?8@O/NQXK'B(@H*(SH@9F]L9&5R<RYP
M:'`Z,CDX"FUS9VED(")(:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R("*[Y[_K
MQ\_!]B"^RK3"(,;MP?;'U""\^['H(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C(Y-R!M86EL8F]X+G!H<#HW,C0@=&5M<&QA=&5S+VUA:6QB
M;W@O;&5G96YD+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B2&EG:"!0<FEO<FET
M>2(*;7-G<W1R("*_[+RQO/C`IR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(Y,PIM<V=I9"`B2&EG:&5S="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X"FUS9VED(")(;W<@9&\@>6]U('=A
M;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T<B`BP[>ZSL;$P,_`
MNR"^[K:[L-0@QZ6]P\?/L>*XIB"_^,?/O<JTS['N/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,#0*;7-G:60@(DAO=R!T;R!A='1R:6)U=&4@<75O
M=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`BM.3`Y;^A(+OGO^O'TB#`
MSK_KN:XZ(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*;7-G:60@
M(DE-05`B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T
M<B`B24U!4"`H4')O=&]C;VQS(,#:M;\@L*C!]BDB"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E
M<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38V
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V97(@
M4U-,(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,34R
M"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T
M92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-C<*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R
M("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`HC+"!F=7IZ>0IM<V=I
M9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R
M("+!HKS3Q](@N-[`S[RMN?;`QR#!OK?Y.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,38U(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS
M9VED("))34%0+"!N;R!43%,B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HT.0IM<V=I9"`B24U!4"]03U`S($UA:6P@4V5R=F5R<R(*
M;7-G<W1R("))34%0+U!/4#,@N-[`SR"\K;GV(@H*(SH@;&EB+TE-4"YP:'`Z
M.#8V"FUS9VED("))3D)/6"(*;7-G<W1R("*YWL"ZQNW!]L?4(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HT,3$*;7-G:60@(DEF('5S:6YG(%-33"!O<B!4
M3%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L(&5X=&5N<VEO;B!L
M;V%D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E
M<G-?8V]N9FER;2YH=&UL.C$R"B,L(&9U>GIY"FUS9VED("))9B!Y;W4@8V]N
M=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@
M;&]S="$B"FUS9W-T<B`BQNW!]L?4P,<@N/"UYR#&[<'VL*$@P?:_]L']M,^T
MV2$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#(*;7-G
M:60@(DEG;F]R92(*;7-G<W1R("*YJ[W#(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@S"FUS9VED("))9VYO<F4@06QL(@IM<V=S='(@
M(KCPM<X@N:N]PR(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E
M+FEN8SHX"FUS9VED("));6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]I;7!O<G0N:6YC.C(P"FUS9VED("));7!O<G0B"FUS9W-T<B`B
ML*'!KK_`L>(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M.#4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-0HC+"!F=7IZ>0IM
M<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R("+`T+[NO\"QXBC`T\;WQJXI(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S.0HC+"!F=7IZ>0IM<V=I9"`B
M26UP;W)T($ME>7!A:7(B"FUS9W-T<B`BP=^_Y,?1(,;MP?8B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PIM<V=I9"`B26UP;W)T($UE
M<W-A9V5S(@IM<V=S='(@(L;MP?8@L*'!KK_`L>(B"@HC.B!P9W`N<&AP.C0R
M"B,L(&9U>GIY"FUS9VED("));7!O<G0@4$=0($ME>2(*;7-G<W1R("+`T+[N
MO\"QXBC`T\;WQJXI(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY
M,0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,30*(RP@9G5Z
M>GD*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97DB"FUS
M9W-T<B`BP-"^[K_`L>(HP-/&]\:N*2(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L
M(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(L#0ONZ_P+'B*,#3QO?&KBDB"@HC
M.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP
M;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHT,"!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!0=6)L:6,@2V5Y
M(@IM<V=S='(@(L#\P[P@P,RXISHB"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C0*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0
M($ME>2(*;7-G<W1R("+`T+[NO\"QXBC`T\;WQJXI(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@*(RP@9G5Z>GD*;7-G:60@(DEM<&]R
M="!0=6)L:6,@4R]-24U%($ME>2(*;7-G<W1R("+`_,.\(,#,N*<Z(@H*(SH@
M<VUI;64N<&AP.C$V"B,L(&9U>GIY"FUS9VED("));7!O<G0@4R]-24U%($ME
M>2(*;7-G<W1R("+`T+[NO\"QXBC`T\;WQJXI(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@;6)O>"!&:6QE(@IM
M<V=S='(@(FUB;W@@QL3`SR"PH<&NO\"QXB`B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N(@IM<V=S='(@(B5S(&UB
M;W@@QL3`S\"[("5SM\X@L*'!KK_`L>(B"@HC.B!M97-S86=E+G!H<#HU,#(@
M;6%I;&)O>"YP:'`Z-S,T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$V
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;&5G96YD+FEN8SHW"FUS9VED("));7!O<G1A;G0B"FUS9W-T
M<B`BP=^_Y,?4(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHT-PIM
M<V=I9"`B26UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(L'?O^3'T2#&[<'V
M(@H*(SH@9F]L9&5R<RYP:'`Z,38W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("(E
M<[^AO*T@)62PLR#&[<'V(+"AP:Z_R"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW-S,*;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T<B`B(@H*(SH@
M9F]L9&5R<RYP:'`Z,S@T(&QI8B]&;VQD97(N<&AP.C@V(&QI8B]&;VQD97(N
M<&AP.C(Q-"!L:6(O24U0+G!H<#HS,3,*(SH@;&EB+TE-05`O5')E92YP:'`Z
M,3$T(&QI8B])34%0+U1R964N<&AP.C(Q.0IM<V=I9"`B26YB;W@B"FUS9W-T
M<B`BN=[`NL;MP?;'U"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3(*
M;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D97(@
M:6X@82!R97!L>3\B"FUS9W-T<B`BM.3`Y;^A(+"CM-S'T2"XT[BTN+L@O^2^
MX,"[(,;WQ]3'TK'NO^0_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X
M-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_
M(@IM<V=S='(@(K3DP.6_H2"QXL&X(,;MP?:XIB#&]\?4Q]*Q[K_D/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$S,`IM<V=I9"`B26YF;R(*;7-G<W1R("+!
MI+JX(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DEN9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97DB"FUS9W-T<B`BP/S#O"#`
MS+BG.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF
M;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S(*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U
M8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4P-PHC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY.`HC
M+"!F=7IZ>0IM<V=I9"`B26YL:6YE(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*
M"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("))
M;G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R<V]N
M86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T(%!E<G-O
M;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED("));G-E<G0@4'5B;&EC
M(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E9"!F
M;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP
M.C4X-"!M86EL8F]X+G!H<#HV,C8*;7-G:60@(DEN=F%L:60@061D<F5S<R(*
M;7-G<W1R("+`W[CXM<@@P=:\TB(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,S`W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X
M(@IM<V=S='(@(K_<NLX@QNW!]L?4.B(*"B,Z(&-O;7!O<V4N<&AP.C$U.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA
M:6P@861D<F5S<SH@)7,N(@IM<V=S='(@(L#?N/BUR"#`S+C>P,\@P=:\TCH@
M)7,B"@HC.B!S;6EM92YP:'`Z.#(@<&=P+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!K97DB"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@<&=P
M+G!H<#HQ.38*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!R:79A=&4@
M:V5Y+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$W,0IM<V=I9"`B26YV86QI
M9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B26YV97)T(@IM
M<V=S='(@(KRQQ<,@N=W`_"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4W-PIM<V=I9"`B2T(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@
M9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@
M($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E;F5R871I;VX_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C,W"FUS9VED(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B
M;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R
M="!I<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@
M9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@H*
M(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME>2!S=6-C97-S9G5L;'D@<V5N="!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,38*;7-G:60@(DQA;F=U86=E(@IM<V=S
M='(@(K[PONXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`V"FUS9VED
M("),87-T($UA:6QB;W@@4&%G92(*;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*
M(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`B
MN+;!]KBW(,;DP,S!]B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,X.0IM<V=I9"`B3&E?;FL@071T86-H;65N=',B"FUS9W-T<B`B7V[#
MM[K.QL3`SR"XM<6IQ\^QXB(*"B,Z(&%T=&%C:&UE;G0N<&AP.C,T(&QI8B]#
M;VUP;W-E+G!H<#HQ,#8S"B,L(&9U>GIY"FUS9VED("),:6YK960@871T86-H
M;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`BQL3`SR##M[K.(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN
M:W,@=VEL;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S
M('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L
M960L('EO=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E
M87)C:"!F;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@HBP=:\TK?/(,BMN.G`
MNR##XK?"Q]*VIR"X\+7G(,'6O-*XIB##XK?"Q]*Q[K_D/R`HO+'%P\?/P?8@
MOLK`N+CI+"#!]\&B(+#+N_;'T2`B"B+!UKS2N+@@NKP@O/8@P-:]P+3/M-DN
M*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#4*;7-G:60@(DQI<W1I
M;F<@:6X@=&AE($AE861E<B(*;7-G<W1R("*XT[BTN+N_H2"SJK^MQ\^QXB(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`IM<V=I9"`B
M3&]C86P@36%I;&)O>#HB"FUS9W-T<B`BN^>_Z\?2(+_LQNW'U#HB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C<T"B,L(&9U>GIY"FUS9VED("),
M;V-A=&EO;B(*;7-G<W1R("*]Q\?@(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,C4*;7-G:60@(DQO9R!I;B(*;7-G<W1R("*WSK'7P,XB"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G
M:60@(DQO9R!I;B!T;R`E<R(*;7-G<W1R("(E<[^A(+?.L=?`SB(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,W"FUS9VED("),;V=I;B(*;7-G
M<W1R("*WSK'7P,XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(K?.L=?`SB"]P\#;P-N^]R(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-@IM<V=I9"`B3&]W
M(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X+G!H<#HW
M,C<@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PHC+"!F=7IZ>0IM
M<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(K_LO+&\^,"G(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H
M<#HT-`HC+"!F=7IZ>0IM<V=I9"`B36%C:6YT;W-H($9I;&4B"FUS9W-T<B`B
MQNW!]B#'RL7-(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC
M.C$S"FUS9VED(")-86EL(@IM<V=S='(@(KC>P,\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.38*(RP@9G5Z>GD*;7-G:60@(DUA:6P@4')E=FEE=W,B
M"FUS9W-T<B`BQNW!]B#'RL7-(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D
M<FEV97)?<V5L96-T+FEN8SHQ-@IM<V=I9"`B36%I;"!S97)V97(@='EP92!T
M;R!C;VYN96-T('1O.B(*;7-G<W1R("+!HKS3Q](@N-[`S[RMN?;`QR#!OK?Y
M.B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I;&)O>"(*;7-G<W1R
M("*_[,;MQ]0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"FUS9VED
M(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(L;MP?;'U"##XK?"(+RSP:0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R
M(&%S(%-E96XB"FUS9W-T<B`BQNW!]L?4P,<@N/"UYR#&[<'VN*8@P-#`O<"X
MM\X@QZ6]PR(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y
M"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N
M(@IM<V=S='(@(L;MP?;'U,#'(+CPM><@QNW!]KBF(,#0P?8@OLK`O<"XM\X@
MQZ6]PR(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-
M87)K(&%S.B(*;7-G<W1R("+&[<'V(,>EO<,Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8U,`IM<V=I9"`B36%R:R!D:69F97)E;G0@;&5V96QS(&]F
M('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/R(*;7-G<W1R("+`SK_K
M(+3<L.BXMK39(+39N*4@N_;`N+?.(,>EO<.XIB#'TK'NO^0_(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE
M<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI(@IM<V=S='(@(L;MP?:XIB#`
MT,"]P+BWSB#'I;W#Q]*Q[K_D/R`H24U!4"#`_+_K*2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B
M"FUS9W-T<B`BL*.TW,?1(&UA<FMU<,"[(,>EO</'TK'NO^0_(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0V"FUS9VED(")-871C:"!!;&P@
M475E<FEE<R(*;7-G<W1R("*PR[OVONX@N/"USB#`S\2A(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C0R"FUS9VED(")-871C:"!!;GD@475E
M<GDB"FUS9W-T<B`BL,N[]K[N(,?/LZH@P,R[\R#`S\2A(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")-87AI;75M($%T
M=&%C:&UE;G0@4VEZ92(*;7-G<W1R("+#M[K.QL3`SR##UK3K(,6IL>(B"@HC
M.B!L:6(O87!I+G!H<#HW.0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@1F]L
M9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT.30*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T
M=&%C:&UE;G1S(')E86-H960N(@IM<V=S='(@(L.WNL[&Q,#/(,/6M.L@Q:FQ
MXB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X.0HC+"!F
M=7IZ>0IM<V=I9"`B36%X:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A
M8VAE9"XB"FUS9W-T<B`BP[>ZSL;$P,\@P]:TZR#%J;'B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B365E=&EN9R!#86YC96QL
M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4W-0HC+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G
M<W1R("*PL\#.(,&DNK@B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3@U"B,L(&9U>GIY"FUS9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S='(@
M(KW#P-O'S['B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-PHC
M+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!297!L>2(*;7-G<W1R("*]P\#;Q\^Q
MXB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3@*(RP@9G5Z>GD*
M;7-G:60@(DUE971I;F<@57!D871E(@IM<V=S='(@(KW#P-O'S['B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,PHC+"!F=7IZ>0IM<V=I9"`B
M365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R("*]P\#;Q\^QXB(*"B,Z
M(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@
M(DUE;G4@1F]L9&5R($QI<W0B"FUS9W-T<B`BQNW!]L?4(+^ML>(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S,Q"FUS9VED(")-97-S86=E(@IM<V=S='(@(L;M
MP?8B"@HC.B!C;VUP;W-E+G!H<#HU-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O
M<V4N<&AP.C8T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE
M<W-A9V4@0V]M<&]S:71I;VXB"FUS9W-T<B`BQNW!]B#`V[RZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E(@IM
M<V=S='(@(L;MP?8@LZ_"I2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PIM<V=I
M9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(L;MP?8@O+'%P[OGQ]<B"@HC
M.B!S96%R8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T
M<B`BQNW!]B##H['B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM
M<V=I9"`B365S<V%G92!3:7IE(@IM<V=S='(@(L;MP?8@Q:FQXB(*"B,Z(&UE
M<W-A9V4N<&AP.C,X-`IM<V=I9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`B
MQNW!]B"\TKVZNKBQXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM
M<V=I9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@(L;MP?8@NKBQXB(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-@IM<V=I9"`B365S<V%G92!F
M;&%G<R(*;7-G<W1R("+&[<'V(+&XNM`B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E(&9O;&1E<G,B"FUS9W-T<B`B
MQNW!]L?4(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B)7/`QR#&[<'V(@H*
M(SH@;6%I;&)O>"YP:'`Z-C8W"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&AA
M<R!A='1A8VAM96YT<R(*;7-G<W1R("+&[<'V(,#/Q*$B"@HC.B!M86EL8F]X
M+G!H<#HV-3@*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@96YC<GEP=&5D
M(@IM<V=S='(@(L;MP?8@Q]>X\2(*"B,Z(&UA:6QB;W@N<&AP.C8U,PHC+"!F
M=7IZ>0IM<V=I9"`B365S<V%G92!I<R!S:6=N960B"FUS9W-T<B`BQNW!]B#'
MU[CQ(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C,S"FUS9VED
M(")-97-S86=E(&UA=&-H97,B"FUS9W-T<B`BQNW!]B#`S\2A(@H*(SH@8V]M
M<&]S92YP:'`Z.#(T(&-O;7!O<V4N<&AP.C@S.`IM<V=I9"`B365S<V%G92!R
M961I<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BQNW!]K"A(+RZL/C`
M^\"XM\X@P/RTWK7'OOJ]P+3/M-DN(@H*(SH@8V]M<&]S92YP:'`Z,3`X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY
M+"!B=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@(L;MP?:PH2"\NK#XP/O`
MN+?.(+G?O-NUQ[[ZP?:XN"P@)7._H2#`^L#EM<?!]B"^RK[2O<"TS[39+B(*
M"B,Z(&-O;7!O<V4N<&AP.C$Q-#,@8V]M<&]S92YP:'`Z,3$U.`IM<V=I9"`B
M365S<V%G92!S96YT('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BQNW!]K"A(+RZ
ML/C`^\"XM\X@NKBSN\&SO<"TS[39+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-#$*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL
M8F]X('9I97<N(@IM<V=S='(@(L;MP?;'U"#&Y,#,P?:TYR#&[<'V(+"YO/8B
M"@HC.B!M86EL8F]X+G!H<#HS,C(*;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S
M='(@(L;MP?;'U""\L<7#(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C(Y
M"FUS9VED(")-;V1I9GDB"FUS9W-T<B`BNJ^PYB(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@=&AA;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E
M<UPB+B(*;7-G<W1R("+'S[.J(,#,N_/`QR#!UKS2L*$@N=^PW[7'OOJ]P+3/
MM-DZ("<E<R<B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G
M:60@(DUO=F4B"FUS9W-T<B`BP,RUOR(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M;W5R8V5S96QE8W0N:6YC.C,Q-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@
M(K[&MZ&WSB#`S+6_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.`IM
M<V=I9"`B36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I
M;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4@=&\@9F]L9&5R
M(@IM<V=S='(@(L;MP?;'U,"XM\X@P,RUOR(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,Q-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R
M("+`I[?.(,#,M;\B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N
M<&AP.C$R-PIM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@
M(B(*"B,Z('1H<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*
M;7-G:60@(DUU;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R("+&[<'V(+JX
ML>(B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B3D].12(*;7-G<W1R("+!UL#'(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM
M<V=I9"`B3D]412(*;7-G<W1R("+!UL#'(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR,S@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8X.`IM<V=I9"`B3F%M92(*;7-G<W1R("+`S+BG(@H*(SH@<&=P+G!H<#HQ
M,3`*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W.`HC
M+"!F=7IZ>0IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(KW'Q^`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W.`IM<V=I9"`B
M3F5V97(B"FUS9W-T<B`BN^>_Z\?/P?8@OLK`O2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-C`*;7-G:60@(DYE=F5R('-A=F4@871T86-H;65N=',B
M"FUS9W-T<B`BP[>ZSL;$P,\@P/K`Y;[(Q]0B"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`BN_4@QNW!]B(*"B,Z
M(&QI8B])35`N<&AP.C4V,PIM<V=I9"`B3F5W($9O;&1E<B(*;7-G<W1R("*[
M]2#&[<'VQ]0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#@*;7-G:60@
M(DYE=R!-86EL(@IM<V=S='(@(KOU(,;MP?8B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,S,*(RP@
M9G5Z>GD*;7-G:60@(DYE=R!-97-S86=E(@IM<V=S='(@(K39P+T@QNW!]B(*
M"B,Z(&UA:6QB;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S
M(@IM<V=S='(@(KOU(,;MP?8B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C$Y"FUS9VED(").97<@;65S<V%G97,B"FUS9W-T<B`BN_4@QNW!]B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@
M(DYE>'0B"FUS9W-T<B`BM-G`O2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G92(*;7-G
M<W1R("*TV<"](,;MP?8B"@HC.B!M86EL8F]X+G!H<#HS-38*;7-G:60@(DYE
M>'0@4&%G92(*;7-G<W1R("*TV<"](,;DP,S!]B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3<W"FUS9VED(").;R(*;7-G<W1R("*^QK3/O\`B"@HC.B!S;6EM92YP:'`Z
M,C(V"FUS9VED(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*(RP@9G5Z
M>GD*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T<B`B7WF^S\BCR*T@O\F\
MQR(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y
M<R!I;B!+97ER:6YG(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C,W-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*;7-G<W1R("+&[<'V
M(+[XP+TB"@HC.B!P9W`N<&AP.C$S-PIM<V=I9"`B3F\@4$=0('!U8FQI8R!K
M97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC871E(%!R
M97-E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,R.0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT(@IM<V=S='(@(KG,N*ZZN+'B
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS9W-T<B`BP/S#O"#`S+BG
M.B(*"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L:6,@
M:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O
M=6YD+B(*;7-G<W1R("+&Q,#/(,.WNLXB"@HC.B!L:6(O0W)Y<'0O4TU)344N
M<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I;VX@;&]C871E9"!I
M;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HW,B!A
M8VPN<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97(@<V5L96-T960N
M(@IM<V=S='(@(L;MP?;'U""\L<7#(+_`M_DB"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD97)S(&%R92!B96EN9R!C:&5C
M:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L:6(O1F]L9&5R+G!H<#HU-3`*;7-G
M:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I960B"FUS9W-T<B`BQNW!]L?4
MP+L@O+'%P\?/O+R_Y"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#<*
M;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`B
MN_4@QNW!]K"A(,#6M,(@QNW!]L?4(+[XP+TB"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,30T"FUS9VED(").;R!F;VQD97)S('=I=&@@=6YS965N(&UE
M<W-A9V5S(@IM<V=S='(@(L#0P?8@OLK`NB#&[<'VL*$@P-:TPB#&[<'VQ]0@
MOOC`O2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,C4*;7-G:60@(DYO(&UE<W-A
M9V4@8F]D>2!T97AT(@IM<V=S='(@(L;MP?8@NKNYKB"^^,"](@H*(SH@;&EB
M+TUA:6QB;W@N<&AP.C,W,0IM<V=I9"`B3F\@;65S<V%G97,@;6%T8VAE9"!Y
M;W5R('-E87)C:"XB"FUS9W-T<B`BPZ.TPB#&[<'VL*$@OOB]P+3/M-DN(@H*
M(SH@<&=P+G!H<#HQ.#D*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P<FEV871E
M(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ-C4*;7-G
M:60@(DYO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G
M<W1R("(B"@HC.B!S;6EM92YP:'`Z,C`Q"FUS9VED(").;R!P97)S;VYA;"!3
M+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!S
M<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").;R!S<&5L;&-H96-K:6YG('!R;V=R
M86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(").;R!S<&5L;&EN9R!E<G)O<G,B
M"FUS9W-T<B`BP[;`VB"_P+?Y(+[XP+TB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3`P"B,L(&9U>GIY"FUS9VED(").;R!S=6=G97-T
M:6]N<R(*;7-G<W1R("+!IK[((@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU
M-C0*;7-G:60@(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I8V%T:6]N(&UE
M=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HV
M."!A8VPN<&AP.CDT"B,L(&9U>GIY"FUS9VED(").;R!U<V5R('-P96-I9FEE
M9"XB"FUS9W-T<B`BQNW!]L?4P+L@O+'%P\?/O+R_Y"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,#D*;7-G:60@(DYO;B!087)T:6-I<&%N="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Q
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#`*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S4@=&5M<&QA=&5S+W!R
M969S+W-P86US96QE8W0N:6YC.C(T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV-C0*;7-G:60@(DYO;F4B"FUS9W-T<B`BN/"USB"\L<7#(+[(Q]0B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.34*;7-G:60@
M(DYO<FUA;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G
M:60@(DYO="!$96QE=&5D(@IM<V=S='(@(L'VO_;!]L'V(+[*P+TB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$R('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM<V=S='(@(L#3
MO</&[<'V(+[&M-0B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-PHC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,T"FUS9VED(").;W0@
M26UP;W)T86YT(@IM<V=S='(@(L'?O^3'S\'V(+[*P+TB"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS9VED(").;W0@4&5R<V]N86PB
M"FUS9W-T<B`BL+/`SL;MP?8@OL:TU"(*"B,Z(&QI8B]#<GEP="]01U`N<&AP
M.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S-"!L:6(O0W)Y<'0O4TU)344N
M<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV-PIM<V=I9"`B
M3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T<B`BP?:_]L'VP?8@OLK`NB#&
M[<'V(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B
M3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R("+!W[_DQ\_!]B"^RL"Z
M(,;MP?8B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G
M:6XN<&AP.C<Q"FUS9VED(").;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE
M('1I;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q
M-@IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<W"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@;6]N=&AS
M('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE=&EN9R!M
M;VYT:&QY+B(*;7-G<W1R("*XQ;_Y(,;MP?;'U,"[(,'VO^\@L.:_[""ZN+#\
MQ](@O[G`_""ZN+.](,;MP?;'U,#'(+"YO/8B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4Y"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F
M;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B
MN,6_^2#&[<'VQ]3`NR#!]K_O(+#FO^P@NKBP_,?2(+^YP/P@NKBSO2#&[<'V
MQ]3`QR"PN;SV(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR-30@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4U,@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S,S"FUS9VED(")/2R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-2!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?
M:V5Y+FEN8SHT.`IM<V=I9"`B3U(B"FUS9W-T<B`BR*3`NB(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z,34*;7-G:60@(D]L9"!M97-S86=E<R(*
M;7-G<W1R("*_OK.O(,;MP?8B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D
M96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N(@IM<V=S='(@(KJXL[W&[<'V
MQ]0H4V5N="G`QR"_P+>AM<@@QNW!]KBF(,'VO^RP[2#`UKW`M,^TV2XB"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D]N
M;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H
M96T_(@IM<V=S='(@(L#0P?8@OLK`NB#&[<'VL*$@P-:TPB#&[<'VQ]0@OOC`
MO2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-SD*(RP@
M9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T
M960@9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R("*]Q\?@Q](@Q\^SJL#'(,;M
MP?;'U,"[(+RQQ</'S[R\O^0N(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$P
M('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E;B!&
M;U]L9&5R(@IM<V=S='(@(L;MP?;'U""_K;'B(@H*(SH@9F]L9&5R<RYP:'`Z
M-#(W"FUS9VED(")/<&5N960@1F]L9&5R(@IM<V=S='(@(K^MN+`@QNW!]L?4
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P-0IM<V=I9"`B3W!T
M:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL+G!H
M<#HS,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H97(@36%I
M;"!!8V-O=6YT<R(*;7-G<W1R("*TV;BE(+C>P,\@L.C!I"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM
M<V=S='(@(K'BQ;@@O+/!I"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C`Q"FUS9VED(")/=71B;W5N9"!397)V97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ-B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HQ-C4*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`T
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,`IM<V=I9"`B4$=0(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z
M-PHC+"!F=7IZ>0IM<V=I9"`B4$=0($5N8W)Y<'0@365S<V%G92(*;7-G<W1R
M("+&[<'VM\X@L*&QXB(*"B,Z(&-O;7!O<V4N<&AP.C,U.`HC+"!F=7IZ>0IM
M<V=I9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`BP-"^[K_`L>(HP-/&]\:N*2"_
MP+?Y.B`B"@HC.B!C;VUP;W-E+G!H<#HS,S<*;7-G:60@(E!'4"!%<G)O<CH@
M3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@HC+"!F=7IZ
M>0IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`BR*^PYB"\L\&D(@H*(SH@
M<&=P+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A<V4@26YP=70B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4U"FUS9VED(")01U`@
M4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E
M>'0B"FUS9W-T<B`BP/S#O"#`S+BG.B(*"B,Z('!G<"YP:'`Z,30Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E
M<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`BQNW!
M]L?4(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+B(*"B,Z('!G<"YP:'`Z,C0U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F
M;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B
MQNW!]L?4(%PB)7-<(L#,(+OHP::UQ[[ZO<"TS[39+B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B4$=0(%!U8FQI8R!+
M97ER:6YG(@IM<V=S='(@(L#\P[P@P,RXISHB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!'4"!3
M:6=N($UE<W-A9V4B"FUS9W-T<B`BQNW!]B#`_+S;(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"B,L(&9U>GIY"FUS9VED(")0
M1U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`BQNW!]B#`_+S;(@H*
M(SH@<&=P+G!H<#HR,#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!P<FEV871E(&ME
M>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(KRMN.W`S""ZK[#FM<>^
M^KW`M,^TV2XB"@HC.B!P9W`N<&AP.C$W-PHC+"!F=7IZ>0IM<V=I9"`B4$=0
M('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(E<R#&
MQ,#/P,P@P-/&]\:NM<>^^KW`M,^TV2XB"@HC.B!T96UP;&%T97,O<&=P+VYO
M=&%C=&EV92YI;F,Z-`IM<V=I9"`B4$=0('-U<'!O<G0@:7,@9&ES86)L960@
M;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C(P.`IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U
M<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N
M86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,CDU"FUS9VED("(B"B)01U`@<W5P<&]R="!I
M<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B
M;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,@IM<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@
M<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES
M(&-U<G)E;G1L>2`B"B)S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y
M;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B
M"B)F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G
M:60@(E!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B4$]0
M,R`H4')O=&]C;VQS(,#:M;\@L*C!]BDB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R
M(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")03U`S(&]V
M97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`B)60@+R`E
M9"#&Y,#,P?8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS9VED
M(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@
M(L#0P?8@OLK`NB##N;GXPK`@QNW!]K"A(,#6M,(@QN3`S,'V(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H('1H92!,
M87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(L#0P?8@OLK`NB"XML'VN+<@
MQNW!]K"A(,#6M,(@QN3`S,'V(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A
M9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`BNLZZT"(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C,*;7-G:60@(E!A<W-P:')A<V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R.`IM<V=I
M9"`B4&%S<W!H<F%S92`H06=A:6XI(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H
M<#HR,S4@<&=P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-P:')A<V4@
M<W5C8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R("+&[<'VL*$@N=^\V[7'
MOOK!]KBX+"#`^L#EM<?!]B"^RK[2O<"TS[39+B(*"B,Z('1E;7!L871E<R]S
M;6EM92]P87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A<W-P:')A
M<V4N:6YC.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R("(B"@HC.B!P
M9W`N<&AP.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B92!E;7!T
M>2(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$Q-`IM<V=I9"`B4&%S<W!H<F%S
M97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3(*;7-G
M:60@(E!A<W-W;W)D(@IM<V=S='(@(K[/R*,B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BM\ZQU\#.(+W#(,"O
MP?:P_+BN(,#;OO<@O<?'X"(*"B,Z(&%C;"YP:'`Z-S8@86-L+G!H<#HQ,#(*
M;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N(&YO="!B92!C
M:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HT.3,@;6%I;&)O
M>"YP:'`Z-S`S('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,`IM<V=I9"`B4&5R<V]N
M86PB"FUS9W-T<B`BL+/`SL;MP?8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(K"S
MP,X@P:2ZN"(*"B,Z('!G<"YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")097)S
M;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R("+&[<'VL*$@O+JP^,#[P+BWSB#`_+3>M<>^^KW`M,^TV2XB"@HC.B!P
M9W`N<&AP.C$R-PHC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7,@
M9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(L;MP?:PH2"\NK#XP/O`
MN+?.(,#\M-ZUQ[[ZO<"TS[39+B(*"B,Z('-M:6UE+G!H<#HR,#<*;7-G:60@
M(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$S,@HC+"!F=7IZ>0IM<V=I9"`B
M4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM
M<V=S='(@(L;MP?:PH2"\NK#XP/O`N+?.(,#\M-ZUQ[[ZO<"TS[39+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L86-E('EO=7(@
M<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\B"FUS9W-T
M<B`BR+B]Q2"YUR#`_+3>(+[5OZ$@O*VX[<"[(,/?L*''U;3/M-DN(@H*(SH@
M8V]M<&]S92YP:'`Z,C4T"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-
M97-S86=E(@IM<V=S='(@(L;RN:XH4&QA:6YT97AT*2#'_+W$(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y.0IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O
M;B!N97<@;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U
M<'!O<G0@96UB961D960@(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O
M(&]N(%=I;F1O=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL
M("(*(G)E<75I<F4@82!P;'5G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X
M+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(KOU(,;MP?;'U,#'(,#,
MN*?`NR#`U+?"Q\^\O+_D.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,3`R('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,3`T"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F
M;VQD97(Z(@IM<V=S='(@(KOU(,;MP?;'U,#'(,#,N*?`NR#`U+?"Q\^\O+_D
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,W"FUS
M9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.B(*;7-G<W1R("*[]2#`
MS+BGP+L@P-2WPL?/O+R_Y#HB"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A
M<V4N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E
M<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO
M=2!W:6QL(&]N;'D@;F5E9"!T;R`B"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@
M;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)
M344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E
M<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@<F5C;VUP;W-E+G!H<#HY-PIM<V=I9"`B(@HB4&QE87-E(&QO
M9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@
M268@>6]U(&%R92!.3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U(&%R92!C
M;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@
M:&%V92!T;R`B"B)L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A
M<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@(@HB:&EJ
M86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A;GD@
M:6YC;VYV96YI96YC92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('!R;W9I9&4@
M>6]U<B!P87-S=V]R9"XB"FUS9W-T<B`BN^>_Z\#:(,#,N*>P^B"^S\BCN*8@
MP-2WPL?/O+R_Y"XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8W
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M+B(*;7-G<W1R("*[Y[_KP-H@P,RXI[#Z(+[/R*.XIB#`U+?"Q\^\O+_D+B(*
M"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O24U0+G!H<#HT-3D*;7-G:60@(E!L
M96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB
M"FUS9W-T<B`BN-[`SR#!UKS2L*$@N/#(H\?/L,6SJB#`W[CXM<>^^KW`M,^T
MV2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C0R"B,L(&9U>GIY
M"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M
M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@(@HB
M;65N=2!B96QO=RXB"FUS9W-T<B`BL,N[]L?2(,/6O-+'T2#'T;"SP,<@QNW!
M]L?4P+L@O+'%P\?/O+R_Y"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F
M;VQD97)S+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E
M9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`BO<?'X,#\
MOZ$@QNW!]L?4P+L@O+'%P\?/O+R_Y"XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3`R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&%N
M(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R("*PR[OVQ](@
MP]:\TL?1(,?1L+/`QR#&[<'VQ]3`NR"\L<7#Q\^\O+_D+B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S
M96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@
M(K#+N_;'TB##UKS2Q]$@Q]&PL\#'(,;MP?;'U,"[(+RQQ</'S[R\O^0N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,@IM<V=I9"`B
M4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H:7,@;W!E<F%T
M:6]N+B(*;7-G<W1R("*]Q\?@Q](@Q\^SJL#'(,;MP?;'U,"[(+RQQ</'S[R\
MO^0N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"B,L
M(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O
M>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(KRQQ</'S[#%LZH@O\"XI<+*(+39
MP+W'U[CQP+L@O/;!I,?/O+R_Y#HB"@HC.B!C;VYF:6<O;6]T9"YP:'`N9&ES
M=#HT,0IM<V=I9"`B4&]W97)E9"!B>2!(;W)D92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$T"FUS9VED(")0<F5C961E('EO=7(@
M<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_(@IM<V=S='(@(KRMN.W`
MNR`H)RTM("<IM\X@O</`V\?5M,^TV2C#W\.UQ]0I+B(*"B,Z('-M:6UE+G!H
M<#HR-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"FUS9VED(")0
M<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`BO+'%
MP[OGQ]>UZ<#,(+RZL/C`^\"XM\X@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*;7-G:60@(E!R979I
M97<B"FUS9W-T<B`BN<RXKKJXL>(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U<R!-97-S86=E
M(@IM<V=S='(@(L#,P/P@QNW!]B(*"B,Z(&UA:6QB;W@N<&AP.C,T-PIM<V=I
M9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R("+`S,#\(,;DP,S!]B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B
M4')I;G0B"FUS9W-T<B`BP,Z\XB(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C,X"FUS9VED(")0<FEO<FET>2(*;7-G<W1R("*_[+RQO/C`
MIR(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I
M9"`B4')I=F%T92!+97D@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4U.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@
M86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@
M(L.WNL['TB"VI[BVM-D@N;"^[KJXL>(HL>*ZN["J.B"^QK3/O\`I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U.`IM<V=I9"`B4')O;7!T(&5V97)Y
M('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4R(*
M;7-G<W1R("+#M[K.Q](@MJ>XMK39(+FPONZZN+'B*+'BNKNPJCH@O[DI(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0
M<F]T;V-O;#HB"FUS9W-T<B`BQ\&WSL7DQ-TZ(@H*(SH@;&EB+T-R>7!T+U!'
M4"YP:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T
M(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS7V1E;&5T960N:6YC.C@*;7-G:60@(E!U<E]G92!$96QE=&5D(@IM<V=S
M='(@(E]GP?:_[B#&[<'V(+KQO^RQXB(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L
M971E9"YI;F,Z.`IM<V=I9"`B4'5R9V4@1&5L971E9"(*;7-G<W1R("+!]K_N
M(,;MP?8@NO&_[+'B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,C0*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R("+&[<'VQ]0@
MP?:_[+'B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-@IM<V=I9"`B
M4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G<W1R("+!]K_NQNW!]L?4(+KQ
MO^RQXB"]Q\?@P=:QXCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`U
M"FUS9VED(")0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@
M=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*;7-G<W1R("+!]L&DM<@@P,\@
MO/:ZN+39(+_`MZ&UR""_P+>AM<@@QNW!]B#!]K_NQNW!]L?4OZ&\K2#!]K_L
ML>(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(")0=7)G
M92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS9W-T<B`B
MP?:_[L;MP?;'U+^AO*T@O\"WH;7((,;MP?8@P?:_[['NO^0_(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@
M5')A<V@@9F]L9&5R+B(*;7-G<W1R("+!]K_NQNW!]L?4OZ&\K2`E9+"S(,;M
MP?:XIB#!]K_R(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A
M<V@N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")0=7)G:6YG(#$@;65S<V%G92!F
M<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`BP?:_[L;MP?;'U+^AO*T@)62P
MLR#&[<'VN*8@P?:_\B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@
M+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q
M=6]T82]Q=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@
M<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E%U;W1A('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T
M:6YG("5F.B(*;7-G<W1R("(E9B!W<F]T93HB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS.#8*;7-G:60@(E)E7W%U97-T($1E;&EV97)Y
M($-O;F9I<FUA=&EO;B(*;7-G<W1R(")?4;SVO<4@R*[`SB"_Y,.[(@H*(SH@
M;&EB+U-E87)C:"YP:'`Z-3`*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@
M(KSVO<4@LZ_"I3HB"@HC.B!L:6(O4V5A<F-H+G!H<#HU.`IM<V=I9"`B4F5C
M96EV960@4VEN8V4B"FUS9W-T<B`BLZ_"I2"]P\#;.B(*"B,Z(&QI8B]396%R
M8V@N<&AP.C4T"FUS9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R("*SK\*E
M(+.A.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(E]4N=FWSB#`_+3>(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS
M9VED(")2961I<F5C="(*;7-G<W1R("*YV;?.(,#\M-XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I<F5C="!-
M97-S86=E(@IM<V=S='(@(L;MP?8@P/RTWB(*"B,Z(&-O;7!O<V4N<&AP.C<X
M-PIM<V=I9"`B4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S='(@(L;MP?8@
MP/RTWB(*"B,Z(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E8W1I;F<@
M9F%I;&5D+B(*;7-G<W1R("+&[<'V(,#\M-X@O\"W^3HB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU.#,*;7-G:60@(E)E9G)E<V@B"FUS
M9W-T<B`BN_6WSB#`T+'B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X
M-`IM<V=I9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(L;MP?;'
MU""[];?.(,#0L>(Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z
M.2!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C0*;7-G:60@(E)E;&]A
M9"(*;7-G<W1R("*[];?.(+#MQ*<B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H
M96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R("*[];?.(+#M
MQ*<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(V(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU-#4*(RP@9G5Z>GD*;7-G:60@(E)E;65M8F5R
M('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(L;MP?8@O*VY
M]B#!I+JXN^?'UR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-SD*;7-G
M:60@(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS9W-T<B`BN+;!]KBW(,BM
MN.D@L>*^[R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR
M-PIM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(K_<NLX@QNW!]L?4
M.B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B
M4F5M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0IM<V=I9"`B4F5M;W9E
M('-O=7)C92(*;7-G<W1R("*\TKVZ(,'VO^RQXB(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E;F%M92!&;VQD97(H<RDB
M"FUS9W-T<B`BQNW!]L?4(,#,N*<@NJ^PYB(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#$*;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T
M(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BNKBSO<;MP?;'U"A396YT
M*2#`S+BGP+L@N,6_^</*(+JOL.;'U;3/M-DN(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z-#4U"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG(%PB)7-<(B!T
M;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M(@IM<V=S='(@(EPB)7-<(KBF(%PB)7-<(K?.(,#,N*?`NR"ZK[#FQ\_!]B"X
M^,??O<"TS[39+B"\K;GV(+_`M_DZ("(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B
M"FUS9W-T<B`B7WFXKKVZQJX@R+B]Q2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T
M<B`BN=FRW""YKL#:OZTZ(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S='(@(LBXO<4B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$Q(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT,#D*(RP@9G5Z>GD*;7-G:60@(E)E<&QY(%-E;G0N(@IM
M<V=S='(@(LBXO<4Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!!;&PB"FUS9W-T<B`BP/S#
MO"#(N+W%(@H*(SH@8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L>2!T;R!!
M;&PZ(@IM<V=S='(@(L#\P[P@R+B]Q3HB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G:60@(E)E<&QY('1O($QI<W0B
M"FUS9W-T<B`BN*Z]NL:N(,BXO<4B"@HC.B!C;VUP;W-E+G!H<#HW,S4*;7-G
M:60@(E)E<&QY('1O($QI<W0Z(@IM<V=S='(@(KBNO;K&KB#(N+W%.B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I
M9"`B4F5P;'D@=&\@7T%L;"(*;7-G<W1R(")?0<#\P[P@R+B]Q2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4S-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W"B,L
M(&9U>GIY"FUS9VED(")297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G
M92(*;7-G<W1R("+`T,'V(+[*P+H@P[FY^,*P(,;MP?:PH2#`UK3"(,;DP,S!
M]B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S4*;7-G:60@(E)E
M<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,T"B,L(&9U>GIY
M"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(K6EP,S%N"#`T\;WQJX@O\"W^2(*"B,Z(&UE<W-A
M9V4N<&AP.C(V-PIM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`BR+B]Q3HB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z-#`Y"FUS9VED(")297!L>2U4;SH@(@IM<V=S
M='(@(LBXO<4Z(@H*(SH@8V]M<&]S92YP:'`Z-S,Q"FUS9VED(")297!L>3HB
M"FUS9W-T<B`BR+B]Q3HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,C8*(RP@9G5Z>GD*;7-G:60@(E)E<&]R="!A<R!);FYO8V5N="(*;7-G<W1R
M("*]NL;4(+#MN=\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*
M;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(KVZQM0@L.VYWR(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X,PIM<V=I9"`B4F5Q
M=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`B7U*TY,#E(+_DP[LB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E
M;&EV97)Y(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`BO/:]Q2#(KL#.(+_DP[LB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S"FUS9VED(")297%U97-T
M(')E860@<F5C96EP=',_(@IM<V=S='(@(K3DP.4@O^3#NR(*"B,Z(&UA:6QB
M;W@N<&AP.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDW
M"B,L(&9U>GIY"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R
M("*TY,#E(+_DP[LB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T
M,R!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C$V,0IM<V=I9"`B4F5S970B"FUS9W-T<B`BN_6WSL#;
MO+HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$U"FUS9VED(")2
M97-P;VYD96YT(%-T871U<R!5<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E
M<W5M92(*;7-G<W1R("+`Y\#;O+HB"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS
M9VED(")297-U;64@>6]U<B!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B
M4F5T=7)N('1O(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM<V=S='(@(L;M
MP?8@P-N\NB(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C
M="YI;F,Z,S$@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8Y"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C,R"FUS
M9VED(")2971U<FX@=&\@1F5T8V@@36%I;"(*;7-G<W1R("*_W+K.QNW!]B"P
MH<&NO\"QXK?.(+6YOL:PH;'B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,C(*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#$@=&5M<&QA=&5S+W-M
M:6UE+VYO=&%C=&EV92YI;F,Z,30*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$V,B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3<S
M"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("*\L<7#N^?'U\"X
MM\X@M;F^QK"AL>(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S$X"FUS
M9VED("(B"B)2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D
M96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\B"FUS9W-T
M<B`BQNW!]L#'(+OHP:8L(,#,M;\L(+JYN^?(Q+^AM,(@QNW!]L?4P+BWSB"U
MN;[&L*&QXC\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS
M9VED(")2;VQE(@IM<V=S='(@(K^JQ](B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C$T,B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S-PHC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.0HC+"!F=7IZ>0IM<V=I
M9"`B4R]-24U%(@IM<V=S='(@(K_)O,<@P/K`Y2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(E,O
M34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`BQNW!]B#`_+S;(@H*(SH@
M8V]M<&]S92YP:'`Z,SDT"B,L(&9U>GIY"FUS9VED(")3+TU)344@17)R;W(Z
M("(*;7-G<W1R("+`T+[NO\"QXBC`T\;WQJXI(+_`M_DZ("(*"B,Z(&-O;7!O
M<V4N<&AP.C,W,PIM<V=I9"`B4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A
M<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"B,L(&9U>GIY"FUS9VED(")3+TU)
M344@3W!T:6]N<R(*;7-G<W1R("*_R;S'(,#ZP.4B"@HC.B!S;6EM92YP:'`Z
M-#D*;7-G:60@(E,O34E-12!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-30*;7-G:60@(E,O34E-
M12!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ-#`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y
M(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R
M("+&[<'VQ]0@7"(E<UPBP,P@N^C!IK7'OOJ]P+3/M-DN(@H*(SH@<VUI;64N
M<&AP.C$V,@HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C
M8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(E<R#&Q,#/P,P@P-/&]\:NM<>^
M^KW`M,^TV2XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P"B,L
M(&9U>GIY"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B
MP/S#O"#`S+BG.B(*"B,Z('-M:6UE+G!H<#HR,3$*(RP@9G5Z>GD*;7-G:60@
M(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A
M9&1E9"XB"FUS9W-T<B`BO*VX[<#,(+JOL.:UQ[[ZO<"TS[39+B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*(RP@9G5Z>GD*
M;7-G:60@(E,O34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`BQNW!]B#`_+S;
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ-`HC
M+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E(@IM
M<V=S='(@(L;MP?8@P/R\VR(*"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I
M=F4N:6YC.C0*;7-G:60@(E,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N
M('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T
M(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L92!T
M;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,3<S"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I
M<R!N;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@
M;65S<V%G92!C86X@;F]T("(*(F)E(&1I<W!L87EE9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*;7-G:60@(B(*(E,O
M34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I
M9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@IM<V=I9"`B(@HB
M4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U
M<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES("(*(F-U<G)E;G1L>2!S970@=&\@
M9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S
M971T:6YG(&]R(&5L<V4@(@HB=&AE(%,O34E-12!F96%T=7)E<R!W:6QL(&YO
M="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,#4*;7-G:60@(E--5%`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4U"FUS9VED(")37W5B
M:F5C="(*;7-G<W1R(")?=<&FN/$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS-C,*;7-G:60@(E-A7W9E(&$@8V]P>2!I;B`B"FUS9W-T
M<B`B7W:_H2"ZN;OGNKL@P/K`Y<?/L>(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A7W9E(&%S(@IM<V=S
M='(@(K39N*4@P,RXI\"XM\X@P/K`Y2(*"B,Z('-E87)C:"YP:'`Z,S$V('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-PIM<V=I9"`B4V%V92(*
M;7-G<W1R("+`^L#E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE;G1S('=I=&@@;65S<V%G92!I
M;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R("+#M[K.QL3`S\"[(+JXL[W&
M[<'VQ]2_H2#`^L#EQ]*Q[K_D/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S
M,PIM<V=I9"`B4V%V92!$<F%F="(*;7-G<W1R("+`T[W#NKBP_,?4OZ$@P/K`
MY2(*"B,Z('-A=F5I;6%G92YP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(E-A=F4@
M26UA9V4B"FUS9W-T<B`BM-FXI<#,N*?`N+?.(,#ZP.4B"@HC.B!L:6(O34E-
M12]#;VYT96YT<RYP:'`Z,C`T"FUS9VED(")3879E($EM86=E(&EN($=A;&QE
M<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C4Y('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`P"B,Z('1E;7!L871E
M<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ-#@*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$S"FUS9VED
M(")3879E($]P=&EO;G,B"FUS9W-T<B`BO+'%P[OGQ]<@P/K`Y2(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,`HC+"!F=7IZ>0IM<V=I
M9"`B4V%V92!3=&%T:6]N97)Y(@IM<V=S='(@(KRQQ<.[Y\?7(,#ZP.4B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@(E-A=F4@7T1R869T(@IM
M<V=S='(@(L#3O<.ZN+#\Q]2_H2#`^L#E(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")3879E(&%S(@IM<V=S
M='(@(K39N*7`S+BGP+BWSB#`^L#E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R
M("+`T[W#QNW!]KBF(,#0P?8@OLK`O2"[\\7"M\X@P/K`Y2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#<R"FUS9VED(")3879E(')E8VEP:65N=',@
M875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_(@IM
M<V=S='(@(KG>M,*[Y[;WP+L@P-JUO\"XM\X@P=:\TK?/OZ$@P]^PH<?2L>Z_
MY#\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$R-PIM<V=I9"`B
M4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E<C\B"FUS9W-T<B`BL,N[
M]K#AL/JTPB"PH;OSQNW!]L?4OZ$@P/K`Y<?2L>Z_Y#\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED(")3879E('-E;G0@;6%I;#\B"FUS
M9W-T<B`BNKBSO<;MP?;'U+^A(,#ZP.4B"@HC.B!C;VUP;W-E+G!H<#HQ,C(W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I;&5D
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("+`
MT[W#QNW!]B#`^L#E(+_`M_DN(+RMN?;`QR"_P+?Y.B`E<R(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M86EL
M8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP
M:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R("+#H['B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VAE
M861E<BYI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S(@IM
M<V=S='(@(B5S(+#+N_8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(P
M"B,L(&9U>GIY"FUS9VED(")396%R8V@@3W!T:6]N<R(*;7-G<W1R("*\L<7#
MN^?'UR#`^L#E(@H*(SH@<V5A<F-H+G!H<#HR-C4*;7-G:60@(E-E87)C:"!2
M97-U;'1S(@IM<V=S='(@(K#+N_8@L.&P^B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,30@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHS,0IM<V=I9"`B4V5E;B(*;7-G<W1R("+`T,"](@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHY"FUS9VED(")396QE8W0B"FUS9W-T<B`B
MQNW!]B"\L<7#(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C<P"FUS9VED(")396QE8W0@06YO=&AE<B!!8V-O=6YT(@IM<V=S='(@(K39
MN*4@L.C!I""\L<7#(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC
M.C,V"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(K.OPJ4@O+'%PR(*
M"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHQ,`IM<V=I9"`B4V5L
M96-T(&$@9FEE;&0B"FUS9W-T<B`BQ]>X\2"\L<7#(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$W"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!S=&%T:6]N97)Y.B(*;7-G<W1R("*SK\*E(+RQQ<,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")396QE8W0@861D<F5S<R!B
M;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R
M97-S97,N(@IM<V=S='(@(L'6O-(@L,N[]B"YUR##W["AN*8@P*?'T2#!UKS2
MM\\@O+'%PR(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#@*;7-G
M:60@(E-E;&5C="!A;&PB"FUS9W-T<B`BN/"USB"\L<7#(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(S"FUS9VED(")396QE8W0@
M86QL(&9I96QD<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S
M+B(*;7-G<W1R("+!UKS2(,BNP.6]PR"PR[OVQ](@Q]>X\2"\L<7#(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C$*;7-G
M:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@(K#HP:0@O+'%PR(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C="!N
M;VYE(@IM<V=S='(@(KRQQ<,@P^N\TB(*"B,Z('1E;7!L871E<R]S879E:6UA
M9V4O<V%V96EM86=E+FEN8SHY"FUS9VED(")396QE8W0@=&AE(&=A;&QE<GD@
M=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C
M="!T:&4@;6%I;"!S97)V97(@='EP92(*;7-G<W1R("*XWL#/O*VY]B#!OK?Y
M(+RQQ<,Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S`Y"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G<W1R("*\
ML<7#M<@@P=:\TK?/.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM
M<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`T"B,L(&9U>GIY"FUS
M9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R("+&[<'V(+RM
MN?8@P:2ZN+OGQ]<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHV-R!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S$*;7-G:60@
M(E-E;F0@365S<V%G92(*;7-G<W1R("+&[<'V(+JXL[NQXB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW,#,*(RP@9G5Z>GD*;7-G:60@(E-E;F0@<F5A
M9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD97(_(@IM<V=S
M='(@(L#;O+K`VB"_Y,.[O<,@341.*+C>P,_`_+S;R*[`SBD@NKBSOK'NO^0_
M(@H*(SH@9F]L9&5R<RYP:'`Z,SDW"FUS9VED(")396YT(&UA:6P@9F]L9&5R
M(@IM<V=S='(@(KJXL[W&[<'VQ]0B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C,X"FUS9VED(")396YT(&UA:6P@9F]L9&5R.B(*
M;7-G<W1R("*ZN+.]QNW!]L?4.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3,R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS
M9W-T<B`BO*VY]B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PIM<V=I
M9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VXB"FUS9W-T<B`BO*VY
M]K_-(,;MP?;'U"#!I+JX(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C(S"FUS9VED(")397)V97(Z(@IM<V=S='(@(KRMN?8Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@<')E9F5R96YC
M97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@
M;65S<V%G97,N(@IM<V=S='(@(L;MP?8@N^C!IB"YUR#`S+6_O<,@R*^PYB"\
ML\&D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R.0IM<V=I9"`B4V5T
M('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN9R!M97-S86=E
M<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q"FUS
M9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(K#XP*\@QNW!]L?4(@H*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C@V"B,L(&9U>GIY"FUS9VED(")3:&%R
M92!M86EL(&9O;&1E<G,B"FUS9W-T<B`BNKBSO2#&[<'VQ]0Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,R"B,L(&9U>GIY"FUS9VED(")3:&%R92!Y
M;W5R(&UA:6P@9F]L9&5R<R!W:71H(&]T:&5R('5S97)S+B(*;7-G<W1R("*Z
MN+.](,;MP?;'U#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8Y"FUS
M9VED("(B"B)3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT(&)E
M('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@(@HB=&]G
M9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N(@IM<V=S='(@(B(*
M(K'D(,#.O^NQV\#'(+#FO^P@L>*ZN\"XM\X@NKB_J<'9L>Z_Y"P@OL:TS[CI
M(+"HP^*Q[K_D/R"^[K:R(+#-P+L@O+'%P\?/M/6V\R(*(K6U+""PH[3<R/<@
MP/S(K\?2(+SV(,#6O<"TS[39+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S
M86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B4VAO=6QD('1H92!C
M;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_
M(@IM<V=S='(@(L#3O<.ZN+#\Q]2_H2#`^L#E(,C$(,#;O+K#HL"[(+3=P+NQ
M[K_D/R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHT"FUS9VED(")3:&]U
M;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R
M(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B
M"FUS9W-T<B`BN/"UYR#&[<'VQ]0@NKBQXB(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VAE861E<G,N:6YC.C8W"FUS9VED(")3:&]W($%L;"!(96%D97)S(@IM
M<V=S='(@(KCPM><@N-.XM+';(+JXL>(B"@HC.B!M86EL8F]X+G!H<#HS-C4*
M;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R("+!]K_VP?@@QNW!]B"ZN+'B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*;7-G:60@
M(E-H;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(K'BNKL@N-.XM+';(+JX
ML>(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW,`IM<V=I
M9"`B4VAO=R!-86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T<B`BN-[`
MS[BUN*Z]NL:N(,&DNK@@NKBQXB(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z.3(*;7-G:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B
M"FUS9W-T<B`BN^>_Z\?/M,(@QNW!]L?4N+@@NKBQXB(*"B,Z(&9O;&1E<G,N
M<&AP.C(Y.`IM<V=I9"`B4VAO=R!5;G-U8G-C<FEB960B"FUS9W-T<B`BN^>_
MZ\?/P?8@OLJTPB#&[<'VQ]0@NKBQXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV,#@*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I
M;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`BQNW!
M]K^AO*T@P[>ZSL;$P,\@N^C!IB"^QL#,Q-S`NR"ZN+^IP=FQ[K_D/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`R"FUS9VED(")3:&]W(&QE9V5N
M9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R("+&[<'VQ]0@NKBQXK^A
MO*T@N?S!UB"ZN+'B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T,`IM
M<V=I9"`B4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE<W-A9V5S(&]N;'D_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#@*;7-G
M:60@(E-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-S<*;7-G:60@(E-H;W<@=&AE($9E
M=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`BL*'!KK_`
ML>(@OL;`S,3<P+L@N-ZTNKG9OZ$@NKB_J<'9L>Z_Y#\B"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE
M($EM86=E<R(*;7-G<W1R("*QU[BR(+JXL>(B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z-30*;7-G:60@(E-H;W<@=&AE(&9I;'1E<B!I8V]N
M(&]N('1H92!M96YU8F%R/R(*;7-G<W1R("*XWK2ZN=F_H2#'RL7-(+[&P,S$
MW,"[(+JXOZG!V;'NO^0_(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(X
M"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_
M(@IM<V=S='(@(L;MP?;'U"#`_,.\(,;MP?8@L+F\]KBF(,>EO</'TK'NO^0_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-@IM<V=I9"`B4VAO=VXB
M"FUS9W-T<B`BNKB_J<'6L>(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C0R"FUS9VED(")3:5]Z92(*;7-G<W1R(")?>L6I
ML>(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$W"FUS9VED
M(")3:6=N960B"FUS9W-T<B`BOL_(H\BMM<HB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R("+%
MJ;'B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@
M(K3QL=NZN+'B(,&DM\0B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($1A=&4B
M"FUS9W-T<B`BM/&QV[JXL>(@P:2WQ"(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C8*;7-G:60@(E-O<G0@8GD@1G)O;2!!
M9&1R97-S(@IM<V=S='(@(KJXL[V[Y[;W(,&DM\0B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0Q"FUS9VED(")3;W)T(&)Y
M($UE<W-A9V4@4VEZ92(*;7-G<W1R("+&[<'V(,6IL>(@P:2WQ"(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S8*;7-G:60@
M(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R("+!IKCQ(,&DM\0B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"FUS9VED(")3
M;W)T(&)Y(%1H<F5A9"(*;7-G<W1R("*T\;';NKBQXB#!I+?$(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B
M4V]R="!B>2!4;R!!9&1R97-S(@IM<V=S='(@(KG>M,*[Y[;W(,&DM\0B"@HC
M.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C,*;7-G:60@(E-P
M86T@9F]L9&5R.B(*;7-G<W1R("*]NL;HQNW!]L?4.B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T-@IM<V=I9"`B4W!E8VEA;"!#:&%R
M86-T97)S(@IM<V=S='(@(L:OO/8@N:[`VB(*"B,Z('-E87)C:"YP:'`Z,3,S
M"FUS9VED(")3<&5C:6%L(%9I<G1U86P@1F]L9&5R<R!C86X@;F]T(&)E(&5D
M:71E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S0S"FUS9VED(")3<&5L;"!#:&5C:R(*;7-G<W1R("+#ML#:(+#+
MN^<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G
M:60@(E-P96QL($-H96-K97(B"FUS9W-T<B`BP[;`VB"PR[OGL>(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS9VED(")3<&5L;"!C:&5C:R!C;VUP
M;&5T92(*;7-G<W1R("+#ML#:(+#+N^<@O\^WX2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-S$*;7-G:60@(E-P96QL:6YG(&5R<F]R<R!P97(@<V-R
M965N('=H96X@<W!E;&P@8VAE8VMI;F<N(@IM<V=S='(@(L.VP-H@L,N[Y[W#
M(,?1(,BMN.F_H2#'I;W#Q](@O\"W^;"YO/8B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3$R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3(*
M;7-G:60@(E-T87)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B
M4W1A=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+T-O;G1E;G1S+G!H<#HR,34*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B
M"FUS9W-T<B`BP[>ZSL;$P,\@P::PQ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*
M;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(E]*P::X\2(*"B,Z(&UE<W-A9V4N
M<&AP.C(V."!T:')E860N<&AP.C$U,"!T96UP;&%T97,O8V]M<&]S92]R96-O
M;7!O<V4N:6YC.C(U"B,Z(&QI8B]396%R8V@N<&AP.C,X"FUS9VED(")3=6)J
M96-T(@IM<V=S='(@(L&FN/$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3(P"FUS9VED(")3=6)J96-T($9I96QD(@IM<V=S='(@(L&FN/$B"@HC.B!S
M96%R8V@N<&AP.C,Q."!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI
M;F,Z,3@*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S$*;7-G:60@(E-U8FUI="(*
M;7-G<W1R("+`U+?"(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,3$*;7-G:60@(E-U8G-C<FEB92!T;R!&;VQD97(H<RDB"FUS9W-T<B`B
MQNW!]L?4(+OGO^O'S['B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HS.#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S@Y"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C@W"FUS9VED(")3=6-C97-S(@IM<V=S='(@
M(KRZL/@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*
M;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S='(@(L&FOL@B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C8R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-C0*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BLZK`QR"_
MY+[@.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,"!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#,*(RP@9G5Z>GD*;7-G
M:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B2%1-3"#`
MV[RZN/"UY;?.(,#\R*\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM
M<V=S='(@(DA434P@P-N\NKCPM>6WSB#`_,BO(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@=&\@<&QA:6X@
M=&5X="!C;VUP;W-I=&EO;B(*;7-G<W1R("+%V+VZQJX@P-N\NKCPM>6WSB#`
M_,BO(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#$Y"FUS
M9VED(")495]X="(*;7-G<W1R(")?>+J[N:XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,C8Y"FUS9VED(")496YT871I=F4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DQ"FUS9VED(")496YT
M871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S8Q"FUS9VED(")496YT871I=F5L>2!!8V-E
M<'1E9"(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O
M9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S`*
M(RP@9G5Z>GD*;7-G:60@(E1E>'0B"FUS9W-T<B`B7WBZN[FN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDU-`IM<V=I9"`B5&AE($9R;VTZ(&-O;'5M
M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.B(*;7-G<W1R("*Y
MWK3"N^>V]R#'U[CQP,P@OZRPX;7)(+#W(+RQQ</'S['B(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HU,S(*;7-G:60@(B(*(E1H92!)34%0('-E<G9E<B!D
M;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@
M;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0Q"FUS9VED(")4:&4@36%C:6YT;W-H(')E
M<V]U<F-E(&9O<FLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P
M<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C
M:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`BL.C!I"!<(B5S7"(@L*$@P?:_]L&SO<"TS[39+B(*"B,Z
M(&9E=&-H;6%I;'!R969S+G!H<#HW-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(K#H
MP:0@7"(E<UPB(+"A(,#ZP.6UQ[[ZO<"TS[39+B(*"B,Z(&%T=&%C:&UE;G0N
M<&AP.C0S"B,L(&9U>GIY"FUS9VED(")4:&4@871T86-H;65N="!W87,@;F]T
M(&9O=6YD+B(*;7-G<W1R("+&Q,#/(,.WNLXB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-CD*;7-G:60@(E1H92!C86QE;F1A<B!D871A(&ES(&EN
M=F%L:60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I9"`B(@HB5&AE(&-O;7!O<V4@=VEN
M9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U
M<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#(*;7-G
M:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E
M;&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA
M;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M
M960@=&\@7"(E<UPB+B(*;7-G<W1R("+']L#G(,;MP?;'U"!<(B5S7"*XIB!<
M(B5S7"*WSB"ZK[#FQ]6TS[39+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHQ,#<*;7-G:60@(B(*(E1H92!C=7)R96YT(&QI<W0@;V8@=7-E<G,@=VET
M:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E=')I979E
M9"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C,V"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@7"(E
M<UPB(&9O;&1E<BXB"FUS9W-T<B`BP-N\NB#!W\#.(,;MP?:PH2`G)7,G(,;M
MP?;'U+^A(,#ZP.6UQ[[ZO<"TS[39+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ,SD*;7-G:60@(E1H92!E=F5N="!W87,@861D960@=&\@>6]U
M<B!C86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M97AP86YD+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*;7-G<W1R("(E<[BF
M(+_/O+K'TB"\]B"^^+W`M,^TV2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B7"(E<UPB(,;MP?;'U+3"(,#,N<P@P;C`Y\?5
MM,^TV2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A;"!C
M:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O8FQE
M;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HBQNW!]L?4(%PB)7-<(K3"(,#?N/BUR""YKL#:N*8@QO?'U,?/
ML.T@P-:]P+3/M-DN(,#,L.:_[""YKL&FN*8@P,_`N,6PM,(@L.:_["`B"B*]
MP[VZQ=L@L/RXKL#:OZ$@N:[`Q\?/O<.QXB"YV;;XM,^TV2XB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I
M8F5D('1O(&ET+B(*;7-G<W1R("+&[<'VQ]0@7"(E<UPBM,(@N_V\NK7'OOK!
M]KBX+""[Y[_KP=_`S,'V(+[*O<"TS[39+B(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W
M87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M
M(&ET+B(*;7-G<W1R("+&[<'VQ]0@7"(E<UPBM,(@P?:_]L&SP?:XN"P@N^>_
MZ[OSQ<*XIB#'V,&FQ\_!]B"^RK[2O<"TS[39+B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<
M(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60B"FUS9W-T<B`BQNW!]L?4(%PB)7-<(K"A(+BXM>F^[L'VP?8@OLJ^TKW`
MM,^TV2X@O*VY]B"_P+?Y.B`B"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D
M96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(L;MP?;'U"!<(B5S7"*PH2#!]K_VP?;!]B"^RK[2O<"TS[39+B"\K;GV(+_`
MM_DZ("(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T
M960N(@IM<V=S='(@(L;MP?;'U"!<(B5S7"*PH2"XN+7ION[!L[W`M,^TV2XB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*
M;7-G<W1R("+&[<'VQ]0@7"(E<UPBL*$@P?:_]L&SO<"TS[39+B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C0U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L
M9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@7"(E<UPB
M+B(*;7-G<W1R("+&[<'VQ]0@7"(E<UPBL*$@7"(E<UPBM\X@N=FR[K[ZO<"T
MS[39+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY,@IM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R
M=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]S
M879E:6UA9V5?=VEN+FIS.C$R"FUS9VED("(B"B)4:&4@:6UA9V4@<V%V92!W
M:6YD;W<@8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T
M('EO=7(@8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3<*(RP@9G5Z
M>GD*;7-G:60@(B(*(E1H92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C
M875S92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U<B`B"B)A9&1R97-S
M8F]O:RXB"FUS9W-T<B`B(@HBNKBSO;OGMO?`S"#!UKS2M\^_H2"UZ;[NP-:T
MPB"PYK_L($A434P@QNW!]L#'(,#,N<S!]KBF(,#:M;_`N+?.(+JXOZG!V;'N
MO^0_(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S4*(RP@9G5Z
M>GD*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO
M=VEN9R!E<G)O<B!M97-S86=E.B(*;7-G<W1R("*XWL#/(+RMN?:_S2#&[<'V
MQ]0@P:2ZN""ZK[#F(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE
M<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z(@IM
M<V=S='(@(KC>P,\@O*VY]K_-(,;MP?;'U"#!I+JX(+JOL.8B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z
M(@IM<V=S='(@(KC>P,\@O*VY]K_-(,;MP?;'U"#!I+JX(+JOL.8B"@HC.B!L
M:6(O365S<V%G92YP:'`Z-C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M
M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(L;MP?;'U"!<
M(B5S7"*TPB#`S+G,(+KQON[`UL"]+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP
M.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!<(B5S7"(@
M9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@;&EM
M:70N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3`S"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!B96EN9R!C
M;VUP;W-E9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(L;M
MP?8@P?:_]L'\(@H*(SH@;65S<V%G92YP:'`Z,30X"FUS9VED(")4:&4@;65S
M<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+&[<'V(,'VO_;!_"(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(KW$
MNK#`VB!<(B5S7"(@L*$@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HS.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S
M+B(*;7-G<W1R("*]Q+JPP-H@7"(E<UPB(+"A(,#ZP.6UQ[[ZO<"TS[39+B(*
M"B,Z('1E;7!L871E<R]S;6EM92]O<&5N7W-M:6UE7W=I;BYJ<SHQ,"!T96UP
M;&%T97,O<&=P+V]P96Y?<&=P7W=I;BYJ<SHQ,`IM<V=I9"`B(@HB5&AE('!A
M<W-P:')A<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@
M:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O
M=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<F%W('1E>'0@;V8@=&AE(%!'
M4"!0=6)L:6,@2V5Y(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E
M<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C
M:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8T"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@
M:6X@=&AE(%II<"!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!M97-S86=E
M+G!H<#HU-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('-E;F1E<B!O
M9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S=&EN9R!A($UE<W-A9V4@1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N("(*(F9R;VT@>6]U('=H96X@>6]U(&AA=F4@
M<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S92!C;&EC:R`E<R!T;R!S96YD('1H
M92`B"B)N;W1I9FEC871I;VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(E1H
M92!S97)V97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O
M9B!T:&ES(&EM86=E+B(*;7-G<W1R("+`S""QU[BRP,<@O>:SU\#/P+L@NKBW
MP;CI("5SN*8@M*FXH[R\O^0N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YJ<SHQ,#0*;7-G:60@(E1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E
M(')E<&QA8V5D+B(*;7-G<W1R("*\K;CMP+L@NJ^PYL?2(+SV(+[XO<"TS[39
M+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`R"FUS9VED
M(")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N(@IM
M<V=S='(@(KRMN.W`S""ZK[#FM<>^^KW`M,^TV2XB"@HC.B!A='1A8VAM96YT
M+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R("(B"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA
M<R!B965N(&%D9&5D+B(*;7-G<W1R("*PZ,&D(%PB)7-<(B"PH2#`^L#EM<>^
M^KW`M,^TV2XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(K#HP:0@7"(E<UPB(+"A(,'VO_;!L[W`M,^T
MV2XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N('5P9&%T
M960N(@IM<V=S='(@(K#HP:0@7"(E<UPB(+"A(,'VO_;!L[W`M,^TV2XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED
M(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*
M;7-G<W1R("+!UKS2(%PB)7-<(K3"("5SOZ$@P]^PH;7'OOJ]P+3/M-DN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G:60@(E1H92!T
M97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(L;MP?8@L[N_ZR(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("+&[<'V(+.[O^LB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@
M=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`BQNW!]B#`_+3>(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E
M(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(L;MP?8@P/RTWB(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L(&9U>GIY"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@(L;M
MP?8@P/RTWB(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP
M.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T
M:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(L;M
MP?8@P/RTWB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-30*(RP@
M9G5Z>GD*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(KRMN.W`S""ZK[#F
MM<>^^KW`M,^TV2XB"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N
M<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z,PIM<V=I9"`B
M5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"XB"FUS9W-T
M<B`BP,P@QNW!]L?4OZ$@QNW!]K"A(+[XO<"TS[39+B(*"B,Z('1H<F5A9"YP
M:'`Z,3`Y"FUS9VED(")4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HV,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B
M"FUS9W-T<B`B)7,@N^C!IB"_P+?Y+B"\K;GV(+_`M_DZ("(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HV-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@
M<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(L;MP?;'U""[Z,&F(+_`M_DN(+RM
MN?8@O\"W^3H@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8R,0IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BQNW!]L?4(+OHP:8@
MO\"W^2X@O*VY]B"_P+?Y.B`B"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI
M<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+&[<'VN*8@
M7"(E<UPBM\X@NKF[YR"_P+?Y+B"\K;GV(+_`M_DZ("(*"B,Z(&QI8B]-97-S
M86=E+G!H<#HQ.3@@;&EB+TUE<W-A9V4N<&AP.C(Q,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G
M97,@9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T("(*(G1H
M92!S97)V97(@<V%I9"(*;7-G<W1R("+&[<'VQ]0@7"(E<UPBM\ZZSL7-(,;M
MP?8@P?:_[+'B(+_`M_DN(+RMN?;`QR"_P+?Y.B`B"@HC.B!L:6(O365S<V%G
M92YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<
M(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+&
M[<'VQ]0@7"(E<UPBOZ&\K2#&[<'V(,'VO^RQXB"_P+?Y+B"\K;GVP,<@O\"W
M^3H@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(Q,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A
M9V5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R
M("+&[<'V(,'VO^RQXB"_P+?Y+B"\K;GVP,<@O\"W^3H@(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.CDY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E
M<RXB"FUS9W-T<B`BM:7`S,6X(,#3QO?&KB"_P+?Y(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR:6-H960N
M<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("+&[<'V(,>EO<,@O\"W^2(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9FQA9V=I
M;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA
M="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`BQNW!]L?4(%PB)7-<(K^A
MO*T@QNW!]B#'I;W#O\"W^2X@O*VY]L#'(+_`M_DZ("(*"B,Z(&9O;&1E<G,N
M<&AP.C$V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R("(E<R"PH<&NO\"QXB"_P+?Y(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@979E;G0Z("5S+B(*;7-G<W1R("*UI<#,Q;@@P-/&]\:N(+_`M_DB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38V"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ
M("5S+B(*;7-G<W1R("*PH<&NO\"QXB"_P+?Y.B`E<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(K6EP,S%N"#`T\;WQJX@
MO\"W^2(*"B,Z(&QI8B]-97-S86=E+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R
M;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V
M97(@<V%I9"(*;7-G<W1R(")<(B5S7"*_H;RM(%PB)7-<(K?.(,#,M;\@O\"W
M^2X@O*VY]B"_P+?Y.B`B"@HC.B!C;VUP;W-E+G!H<#HQ,C0T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R
M869T+B(*;7-G<W1R("+`T[W#QNW!]B#`^L#E(+_`M_DB"@HC.B!C;VUP;W-E
M+G!H<#HQ,#`V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS9W-T<B`BQNW!]B"Z
MN+.[L>(@O\"W^3H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`BM:7`S,6X
M(,#3QO?&KB"_P+?Y(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU
M.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A
M<G0B"FUS9W-T<B`BL[N_Z\#,(+[XO<"TS[39+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@:&%S
M(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS9W-T<B`BP,P@2%1-3"#&[<'V
MM,(@L=>XLL#,(+7ION[`UKW`M,^TV2XB"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z.3`*;7-G:60@(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I
M;6%G97,@96UB961D960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L
M:6ME("(*(G1H:7,Z("(*;7-G<W1R("(B"B+`S"!(5$U,(,;MP?:TPB"QU[BR
MP,P@M>F^[L#6O<"TS[39+B"ZN+[(N_,@L=>XLL"Z(+39P+VP^B"PL,#,(,>E
MO<.UR[3/M-DZ(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V"B,L
M(&9U>GIY"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE
M9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B)7.V\[3"(,6K(+'7N++`S"#&
M[<'VOZ$@P[>ZSK7'OOJ]P+3/M-DN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$P-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$X"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#,@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$U-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<S(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,30*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q
M.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`BP,S`V[[WP+H@
MON"PH\#'(+W#L*/`S""\TK_DM<NTS[39+B"PZ+S3P?C'X,?/O<.PVKW`M,^Q
M[C\B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS
M9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3`*
M;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT
M('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R\B"B)-24U%
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q
M-`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@
M=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B
M"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@
M:6YF;W)M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G
M92!I<R!U;FMN;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HS,34*(RP@9G5Z>GD*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE
M<W-A9V4N($5R<F]R.B`B"FUS9W-T<B`B)7,@M,(@P:2[\\#[P,X@QNW!]L?4
MP+BWSB"ZN,#,P?8@OLJ]P+3/M-DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,C0P(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,U,`IM<V=I9"`B
M(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@
M8V]R<F5C="!01U`@9F]R;6%T("AA8V-O<F1I;F<@=&\@(@HB4D9#(#(P,34I
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W
M,`IM<V=I9"`B5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I
M;B!T:&4@8V]R<F5C="!3+TU)344@9F]R;6%T+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#4@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z-#$V"B,L(&9U>GIY"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E
M96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G<W1R("+&[<'V(,'V
MO_;!_"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30S"B,L(&9U
M>GIY"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I
M9VYE9"!V:6$@4R]-24U%+B(*;7-G<W1R("+&[<'V(,'VO_;!_"(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3,Y(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S
M(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(L;MP?8@P?:_
M]L'\(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`Q(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!M97-S
M86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`BQNW!
M]B#!]K_VP?PB"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S
M<V%G92!T;R(*;7-G<W1R("+&[<'V(,#,M;_'S['B(@H*(SH@86-L+G!H<#HT
M-@IM<V=I9"`B5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3`Y"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z('1H
M<F5A9"YP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")4:')E860@1&ES<&QA>2(*
M;7-G<W1R("+'I;W#(,?\O<0B"@HC.B!T:')E860N<&AP.C<V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,C(*;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@
M(K3QL=L@NKBQXB(*"B,Z(&UE<W-A9V4N<&AP.C(V-"!M86EL8F]X+G!H<#HV
M,#8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,3D*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H+G!H<#HR-@IM<V=I9"`B
M5&\B"FUS9W-T<B`BN=ZTPKOGMO<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$Y"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(KG>M,*[Y[;W(,'6
MO-(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*
M;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB
M8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M,3,T"FUS9VED("(B"B)4;R!U<V4@82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU
M<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@;V8@4$A0(#4N,"XV(&]R("(*(FAI
M9VAE<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-3<W"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*;7-G
M<W1R("+`_,.\(,.WNL[&Q,#/(,6IL>(B"@HC.B!F;VQD97)S+G!H<#HS.#@*
M;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G<W1R("+!]K_NQNW!]L?4(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A
M<V@@9F]L9&5R.B(*;7-G<W1R("+!]K_NQNW!]L?4.B(*"B,Z(&QI8B]1=6]T
M82]C>7)U<RYP:'`Z-C4@;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z-SD@;&EB
M+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1=6]T82]L;V=F:6QE+G!H
M<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+VUD865M
M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS=V5R
M960B"FUS9W-T<B`BM.3`Y<?/P?8@OLK`O2(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z,S4*;7-G:60@(E5N86YS=V5R960@;65S<V%G97,B"FUS
M9W-T<B`BM.3`Y<?/P?8@OLK`NB#&[<'V(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,3,*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(KJYL;@B"@HC
M.B!M86EL8F]X+G!H<#HU.#D@;6%I;&)O>"YP:'`Z-C`R(&QI8B]-24U%+TAE
M861E<G,N<&AP.C(Q,@IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I96YT<R(*
M;7-G<W1R("*^R[SV(+[XM,(@O/:]Q<#.(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@
M8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N
M<&AP.C4V-0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@
M(K[+(+SV(+[XM,(@O/:]Q<#.(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O;G-E
M(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8S-0HC+"!F=7IZ
M>0IM<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@(K[+(+SV(+[XM,(@
MO/:]Q<#.(@H*(SH@;6%I;&)O>"YP:'`Z-C$X"FUS9VED(")5;FMN;W=N(%)E
M8VEP:65N="(*;7-G<W1R("*^RR"\]B"^^+3"(+SVO<7`SB(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<W"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!F
M971C:&UA:6QP<F5F<RYP:'`Z-C4*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B
MP,RXIR"^^,"](@H*(SH@;65S<V%G92YP:'`Z-#DY(&UA:6QB;W@N<&AP.C<P
M."!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C8*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C,R"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N
M9"YI;F,Z-0IM<V=I9"`B56YS965N(@IM<V=S='(@(L#0P?:^RL"](@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3(*;7-G:60@(E5N<W5B
M<V-R:6)E(&9R;VT@1F]L9&5R*',I(@IM<V=S='(@(L;MP?;'U""[Y[_KQ\_!
M]B"^RL"](@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@T
M"FUS9VED(")5<&1A=&4@071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R
M("+#M[K.QL3`SR#!I+JX(+OUM\ZP[<2G(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8R,`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"B,L(&9U>GIY
M"FUS9VED(")5<&QO860B"FUS9W-T<B`BN_6WSB"P[<2G(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E
M9F%U;'0@5F%L=64B"FUS9W-T<B`BL>*ZN["J(+OGO^LB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED(")5<V4@24U!4"!F;VQD97(@<W5B
M<V-R:7!T:6]N<S\B"FUS9W-T<B`B24U!4"#&[<'VQ]0@4W5B<V-R:7!T:6]N
M(+OGO^LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,U"B,L(&9U>GIY
M"FUS9VED(")5<V4@5FER='5A;"!4<F%S:"!&;VQD97(_(@IM<V=S='(@(K"A
MN_,@QNW!]L?4(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$T,@HC+"!F
M=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("*[Y[_KP-JX[2(*"B,Z(&%C;"YP
M:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB57-E<B!<(B5S7"(@<W5C
M8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ-S<*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(KOGO^O`
MVKCM(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$W"FUS
M9VED(")5<V5R;F%M93HB"FUS9W-T<B`BN^>_Z\#:N.TZ(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C8X"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<B"FUS9W-T
M<B`BNKBQXB(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.CDR(&QI8B]-
M24U%+U9I97=E<B]T;F5F+G!H<#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R`E<R(*;7-G<W1R("(E<R"ZN+'B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,@4'5B;&EC($ME>2(*;7-G
M<W1R("+`_,.\(,#,N*<Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$Q-@IM<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<B"FUS9W-T<B`BN_4@PZ*_H;RM($A434P@L[N_ZR"ZN+'B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C@*(RP@9G5Z>GD*;7-G
M:60@(E9I97<@365S<V%G97,B"FUS9W-T<B`BN_4@QNW!]B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<W"FUS9VED(")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<R"B,L(&9U>GIY"FUS9VED(")6:65W(%!E<G-O;F%L
M(%!U8FQI8R!+97DB"FUS9W-T<B`BP/S#O"#`S+BG.B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I
M9"`B5FEE=R!4:')E860B"FUS9W-T<B`B7U:T\;';NKBQXB(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,R!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ-C4*(RP@9G5Z>GD*;7-G:60@(E9I97<@5&AU;6)N86EL(@IM
M<V=S='(@(E]6M/&QV[JXL>(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C0Q.`IM<V=I9"`B5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@
M=VEN9&]W(@IM<V=S='(@(KOU(,.BOZ&\K2##M[K.(+JXL>(B"@HC.B!L:6(O
M34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*;7-G:60@(E9I97<@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R("*[]2##HK^AO*T@L[N_
MZR"ZN+'B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,`HC+"!F
M=7IZ>0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R("(E<R"ZN+'B(@H*(SH@
M9F]L9&5R<RYP:'`Z,S@P(&UA:6QB;W@N<&AP.C4S-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(B5SP,<@QNW!
M]B"ZN+'B(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T
M+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T
M97(@;&]G:6XZ(@IM<V=S='(@(K?.L=?`SB#(Q""ZN+^IP=D@L/<B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<P"B,L(&9U>GIY"FUS9VED(")6
M:65W('1A<VLB"FUS9W-T<B`B)7,@NKBQXB(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,#$*;7-G:60@(E9I97<@=&AE($EM86=E<R(*;7-G<W1R
M("*QU[BR(+JXL>(B"@HC.B!S96%R8V@N<&AP.C(V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F
M=6QL>2XB"FUS9W-T<B`BL*&[\R#&[<'VQ]0@7"(E<UPBL*$@N_V\NK7'OOJ]
MP+3/M-DN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@;&EB
M+TE-05`O5')E92YP:'`Z,3,X(&QI8B])34%0+U1R964N<&AP.C$U,0HC.B!L
M:6(O24U!4"]4<F5E+G!H<#HQ-3,@;&EB+TE-05`O5')E92YP:'`Z,34W(&QI
M8B])34%0+U1R964N<&AP.C$U.`HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-CD@
M;&EB+TE-05`O5')E92YP:'`Z,SDS(&QI8B])34%0+U1R964N<&AP.C0S,PIM
M<V=I9"`B5FER='5A;"!&;VQD97)S(@IM<V=S='(@(K"AN_,@QNW!]L?4(@H*
M(SH@<V5A<F-H+G!H<#HR-#4*;7-G:60@(E9I<G1U86P@1F]L9&5R<R!R97%U
M:7)E(&$@;&%B96PN(@IM<V=S='(@(K"AP.7&[<'VQ]3`NB#`S+BGP,P@Q\J_
MY,?5M,^TV2XB"@HC.B!L:6(O5D9O;&1E<BYP:'`Z,3<U(&QI8B]61F]L9&5R
M+G!H<#HQ.#`*;7-G:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`B(@H*(SH@
M9F]L9&5R<RYP:'`Z-#$V"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L($E.0D]8
M($9O;&1E<B(*;7-G<W1R("*PH;OS(,;MP?;'U"(*"B,Z(&UA:6QB;W@N<&AP
M.C0U,B!L:6(O5D9O;&1E<BYP:'`Z,3$T(&QI8B]61F]L9&5R+G!H<#HQ,3D*
M(RP@9G5Z>GD*;7-G:60@(E9I<G1U86P@5')A<V@B"FUS9W-T<B`BL*&[\R#&
M[<'VQ]0B"@HC.B!F;VQD97)S+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(E9I
M<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(K"AN_,@QNW!]L?4(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U86P@
M9F]L9&5R(&QA8F5L(@IM<V=S='(@(K"AP.7&[<'VQ]0@P,RXIR(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<T"FUS9VED(")787)N:6YG(@IM
M<V=S='(@(K#FL.TB"@HC.B!L;V=I;BYP:'`Z,3,X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(LBOO[7'U;3/
MM-DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.0IM<V=I9"`B(@HB
M5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H
M97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@(@HB;W(@:6YN;V-E;G0_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,C<*;7-G
M:60@(B(*(E=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y
M;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A
M<R!D96QE=&5D/R(*;7-G<W1R("+&[<'VN*8@P?:_[+CI+"#!]K_R(,>EO<.X
MIB#'S[3"(+3KO<4@P?:_[L;MP?;'U,"XM\X@P,RUO\?5M,^TV2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS9VED(")7:&5N(&]P96YI;F<@
M82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R
M="!O;C\B"FUS9W-T<B`BQNW!]L?4P+L@OZT@MJ<L(+[NMK(@QN3`S,'VOZ&\
MK2"]P\#;Q\^QXKBF(+_XQ\^]RK3/L>X_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U
M;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(KJXL[T@QNW!
M]KBF(,#ZP.7'TB"VIRP@P[>ZSL;$P,_`NR#`^L#EQ]*Q[K_D/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN
M9R!M86EL(&]R(&5X<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H
M;W5L9"!W92!A<'!E;F0@=&\@(@HB=6YQ=6%L:69I960@861D<F5S<V5S("AE
M;6%I;"!A9&1R97-S97,@=VET:&]U="!<(D!<(BD_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B5VAI=&5L:7-T
M(@IM<V=S='(@(KSVO<6]PL#.(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@
M(EEE<R(*;7-G<W1R("*_N2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E
M=&-H;6%I;%]L;V=I;BYP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@
M86)O=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U
M;G0H<RDZ(@IM<V=S='(@(K[&MZ'`QR#&[<'VN*8@N^C!IL?5M,^TV3H@(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3`*
M(RP@9G5Z>GD*;7-G:60@(B(*(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE
M=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<B(*(BAS*2XB"FUS9W-T<B`BOL:WH<#'(,;MP?;'U,"[(,'VO^RWP;#M
M(,?5M,^TV3H@(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF
M:7)M+FAT;6PZ.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!A='1E;7!T:6YG
M('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2XB"FUS9W-T<B`B
MOL:WH<#'(,;MP?;'U,"[(,'VO^RWP;#M(,?5M,^TV3H@(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O<'EI;F<O
M;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`BN_4@QOJT];?.(+JY
MN^<OP,RUOR#'S[?!L.T@Q]6TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3`R"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@
M<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`BQ\_`IR#&[<'VQ]3`NR"XN+7LM,^T
MV2X@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*
M;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*
M;7-G<W1R("*[\\"G(,;MP?;'U,"[(+BXM>RTS[39+B`B"@HC.B!L:6(O1F]L
M9&5R+G!H<#HS,C`*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@(KOSP*<@QNW!]L?4P+L@
MN+BU[+3/M-DN("(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S4*;7-G:60@(EEO=2!A<F4@<F5N86UI
M;F<@=&AE(&9O;&1E<CH@(@IM<V=S='(@(L;MP?;'U"#`S+BG(+JOL.8Z("(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM
M<V=S='(@(EPB)7-<(B#&[<'VQ]3`NR"[Y[_KQ\_!]B"^RKW`M,^TV2XB"@HC
M.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@=&AE(&9O;&QO=VEN9R!P;&%C
M96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X=#H@)6,@9F]R('1H92`B
M"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R('1H92!S:6=N871U
M<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A
M9W)E96UE;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED(&YO="!A9W)E92!T
M;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O('EO=2!W97)E
M(&YO="!A;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,38Y"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,CD*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N
M("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R
M("+&[<'V(,#\M-XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@;65S<V%G
M97,N(@IM<V=S='(@(B5SL+/`QR"[]2#&[<'VL*$@P-:]P+3/M-DN(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H879E
M(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(C&PL\#'(+OU(,;MP?:PH2#`UKW`
MM,^TV2XB"@HC.B!C;VUP;W-E+G!H<#HT.30*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!H879E(&%L<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T<B`B
M,;"SP,<@N_4@QNW!]K"A(,#6O<"TS[39+B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA=F4@870@
M;&5A<W0@;VYE(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T
M('5P;&]A9"!Y970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD
M('1H:7,@;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S/R(*;7-G
M<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@:&%V92!N
M97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`BM-G`
MO<#'(,;MP?;'U+^A(+OU(,;MP?:PH2#`UKW`M,^TV3HB"@HC.B!L:6(O24U0
M+G!H<#HQ,#<Y"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L
M;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(K39P+W`QR#&[<'VQ]2_H2"[]2#&
M[<'VL*$@P-:]P+3/M-DZ(@H*(SH@8V]M<&]S92YP:'`Z,34S"FUS9VED(")9
M;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@<F5C:7!I96YT+B(*;7-G<W1R
M("*YWK3"N^>V]\"[(,#4M\+'S[R\O^0N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,S`R"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES
M(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR-#D*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@
M(@HB;65S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHR,#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL
M8F]X(&9I<G-T+B(*;7-G<W1R("*TZ[OS(,;MP?;'U,"[(+C5P/H@O+'%P\?8
MOM\@Q]6TS[39+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX-0HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`BN-7`^B"[Z,&FQ](@O<2ZL,#:N*8@O+'%P\?8OM\@
MQ]6TS[39+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M.#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*
M;7-G<W1R("+!UKS2N*8@N-7`^B"\L<7#Q]B^WR#'U;3/M-DN(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA
M:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X
M+VIA=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T
M(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R("+&[<'VN*8@N-7`
M^B"\L<7#Q\^\O+_D+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T
M+FEN8SHQ,PIM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="XB
M"FUS9W-T<B`BO/:]Q<#.P,P@OOB]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:G,Z,CD*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@870@;&5A<W0@;VYE(&9I;&4@=&\@871T86-H+B(*;7-G<W1R("+&Q,#/
M(,.WNLZXIB"XU<#Z(,#4M\+'V+[?(,?5M,^TV2XB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N86)L960@:6X@>6]U
M<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R("+`K\'VL/RXKB#'U[CQ
MP,<@)R5S)R"\L\&DP+L@Q-&USK[NOM_'U;3/M-DN(@H*(SH@;&EB+TUA:6QL
M;V<N<&AP.C$S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E
M9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T<B`B
MQNW!]B#`_+3>(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$T,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N
M(@IM<V=S='(@(B5SOZ$@M.3`Y2"ZN+._+B(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R
M:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B
M"FUS9W-T<B`B7"(E<UPB(,;MP?;'U""[Y[_KQ\^QXB"_P+?Y+B"\K;GVP,<@
MO\"W^3H@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34Y"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(N
M($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B7"(E<UPB
M(,;MP?;'U""[Y[_KQ\_!]B"^RL"](+_`M_DN(+RMN?;`QR"_P+?Y.B`B"@HC
M.B!L:6(O1F]L9&5R+G!H<#HU,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@7"(E<UPB(@IM<V=S
M='(@(EPB)7-<(B#&[<'VQ]3`NR"[Y[_KQ]6TS[39+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C
M97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB(@IM<V=S='(@(EPB
M)7-<(B#&[<'VQ]3`NR"[Y[_KQ\_!]B"^RKW`M,^TV2XB"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z.3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*
M;7-G<W1R("+`S+BG.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU,`HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*
M;7-G<W1R("+`_,.\(,#,N*<Z(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`BP/S#O"#`S+BG.B(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C<@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<Q"B,L(&9U>GIY"FUS9VED(")9;W5R(%!U8FQI8R!+97DB"FUS
M9W-T<B`BP/S#O"#`S+BG.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C4*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE
M;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`BR+B]Q2#!UKS2.B`\:3XHO+'%
MP[OGQ]<I/"]I/B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#D*
M;7-G:60@(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?
M<V5L96-T+FEN8SHQ-@IM<V=I9"`B66]U<B!A8V-O=6YT<SHB"FUS9W-T<B`B
ML.C!I#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<S"B,L(&9U>GIY
M"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I;VYA
M;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS
M9W-T<B`B(@HBN/"UYR#&[<'VOZ$@P]^PH<?2(+S[P+K"_,&V(,'6O-(Z(#QI
M/BB\L<7#N^?'U\#,N.<L(,?1(,'9OZ$@P=:\TB#'S[.JOK\@OK*\O"(*(K_D
M+BD\+VD^(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*;7-G
M:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P
M;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`BNNJV\[_LP:ZPH2#`
MS""QU[BR(,?\O<3`NR#'I;W#Q\_!]B"X^,?5M,^TV2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E
M="!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`BQNW!]B"ZN+.^(+:G
M(+OGO^O'TB"QXKJ[(+FNP-J\PCHB"@HC.B!T96UP;&%T97,O<')E9G,O96YC
M<GEP='-E;&5C="YI;F,Z,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT
M(&5N8W)Y<'1I;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G
M<W1R("+&[<'V(+JXL[X@MJ<@N^>_Z\?2(+'BNKL@N:[`VKS".B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@Y"FUS9VED(")9;W5R(&UE<W-A
M9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(L;MP?:P
MH2"\NK#XP/O`N+?.(,#\O-NUQ[[ZO<"TS[39+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#8*;7-G:60@(EEO=7(@<VEG;F%T=7)E.B(*;7-G<W1R
M("*\K;CM.B(*"B,Z(&UE<W-A9V4N<&AP.C(X."!C;VUP;W-E+G!H<#HQ,C@T
M(&UA:6QB;W@N<&AP.C4T.2!L:6(O0V]M<&]S92YP:'`Z.#$X"FUS9VED(");
M3F\@4W5B:F5C=%TB"FUS9W-T<B`B6\&FN/$@OOC`O5TB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*;7-G:60@(E]"8V,B"FUS9W-T
M<B`B7T*\^\"ZPOS!MB(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ
M-@IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R(")?0KSVO<6PQ;K.(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,34T"FUS9VED(")?0V,B
M"FUS9W-T<B`B7T/"_,&V(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B
M7T1E;&5T92(*;7-G<W1R(")?1,'VO^RQXB(*"B,Z(&QI8B])35`N<&AP.CDW
M.0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`B7T;&[<'VQ]0B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,0IM<V=I9"`B7TED96YT:71Y
M(@IM<V=S='(@(E])O<2ZL,#:(@H*(SH@;&EB+TE-4"YP:'`Z.38Q"FUS9VED
M(")?26YB;W@B"FUS9W-T<B`B7TFYWL"ZQNW!]L?4(@H*(SH@;&EB+TE-4"YP
M:'`Z,3`R,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7TRWSK'7OL:_]"(*
M"B,Z(&UE<W-A9V4N<&AP.C,X-`IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM
M<V=S='(@(E]-QNW!]B"\TKVZNKBQXB(*"B,Z(&QI8B])35`N<&AP.CDW-@HC
M+"!F=7IZ>0IM<V=I9"`B7TYE=R!-97-S86=E(@IM<V=S='(@(KOU(,;MP?8B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*
M;7-G:60@(E]0<FEN="(*;7-G<W1R(")?4,#.O.(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,C@Y"FUS9VED(")?4')I;W)I='DB"FUS9W-T<B`B7U#!W[_D
MM;4B"@HC.B!M86EL8F]X+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@(E]2N_6WSB#`T+'B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@
M(E]297!L>2(*;7-G<W1R(")?4K3DP.4B"@HC.B!L:6(O24U0+G!H<#HY.#$*
M;7-G:60@(E]396%R8V@B"FUS9W-T<B`B7U.PR[OV(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#,Q"FUS9VED(")?4V5N9"!-97-S86=E(@IM<V=S='(@(E]3
MQNW!]B"ZN+.[L>(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE
M861E<G,N:6YC.C,R"FUS9VED(")?5&AR96%D(@IM<V=S='(@(E]4M/&QV[SX
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3$V"FUS9VED
M(")?5&\B"FUS9W-T<B`B7U2YWK3"N^>V]R(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`B
M7U6ZN;&X(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$X"FUS9VED(")?5FEE=R!4:')E860B"FUS9W-T<B`B7U:T\;';NKBQ
MXB(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR
M-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B7U=H
M:71E;&ES="(*;7-G<W1R(")?5[SVO<6]PL#.(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$W-@IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C0T,`HC+"!F=7IZ>0IM<V=I9"`B871T86-H
M;65N="(*;7-G<W1R("+&Q,#/P[>ZSB(*"B,Z('9I97<N<&AP.CDY"B,L(&9U
M>GIY"FUS9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`BQL3`SR##M[K.
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED
M(")B>71E<R(*;7-G<W1R("*YV<#,QJXB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,C`P"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S(*;7-G:60@(F-A;FYO="!O<&5N
M(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C0*;7-G
M:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,C(P"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.38*;7-G:60@(F-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$V.`IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(R-`IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3DP"FUS9VED(")F<F]M(@IM<V=S='(@(L"GQ*$B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3@P"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`T"FUS9VED(")I
M;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$X.`IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C(Y('!G<"YP:'`Z-CD*;7-G:60@(FME>2(*
M;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HQ-C$*;7-G:60@(FUA:6QB;W@@
M9FEL92(*;7-G<W1R("*_[,;MQ]0@QL3`SR(*"B,Z(&-O;7!O<V4N<&AP.C$P
M-C<@;&EB+TUE<W-A9V4N<&AP.C0V-@IM<V=I9"`B;F%M92(*;7-G<W1R("+`
MS+BG(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<V"FUS
M9VED(")N;VYE(@IM<V=S='(@(K[XP+TB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*;7-G<W1R("*VQ[3"(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C(Q-@IM<V=I9"`B<&5R;6ES<VEO;B!D96YI
M960B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q,@IM<V=I9"`B
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.#0*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V
M"FUS9VED(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R("+#ML#:(+_`M_DB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P
M96QL:6YG(&5R<F]R<R(*;7-G<W1R("+#ML#:(+_`M_DB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3DR"B,L(&9U>GIY"FUS9VED(")S>7-T96T@97)R;W(B"FUS
M9W-T<B`BP[;`VB"_P+?Y(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P.`IM<V=I
M9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E
M<BYP:'`Z-3$*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM<V=S='(@(KSVO<6P
MQ;K.N/&WSR(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H
M:71E;&ES="(*;7-G<W1R("*\]KW%O<+`SKCQM\\B"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+V5S
M7T53+G!O````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#0S,C<W,``Q,#0Q-S,V,C<V,P`P,3<R,#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!3<&%N:7-H('1R86YS;&%T
M:6]N<R!F;W(@:&]R9&4@<&%C:V%G90HC(%1R861U8V-I;VYE<R!A;"!E<W!A
M\6]L('!A<F$@96P@<&%Q=65T92!H;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P
M,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U
M;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K86=E+@HC
M($%U=&]M871I8V%L;'D@9V5N97)A=&5D+"`R,#`T+@HC"FUS9VED("(B"FUS
M9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!)35`@-"XP+6-V<UQN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$U(#$W.C,R*S`Q,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,34@,3<Z,S(K,#$P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!-86YU96P@4"X@07EA;&$@/&UA>6%L84!U;F5X
M+F5S/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR
M.R!P;'5R86P]*&X@(3T@,2D[7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#(Y
M"FUS9VED("(@("`@("!#8SH@(@IM<V=S='(@(B`@("`@($-C.B`B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z-#(V"FUS9VED("(@("`@("!4;SH@(@IM<V=S='(@
M(B`@("!087)A.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$T"FUS9VED("(@
M("`@1&%T93H@(@IM<V=S='(@(B`@($9E8VAA.B`B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z-#$W"FUS9VED("(@("`@1G)O;3H@(@IM<V=S='(@(B`@("`@($1E
M.B`B"@HC.B!M86EL8F]X+G!H<#HT,#D@=&5M<&QA=&5S+V9O;&1E<G,O:&5A
M9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB
M"FUS9W-T<B`B("A!;'0@*R`E<RDB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#(S
M"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(B!!<W5N=&\Z("(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I9"`B(&EN("(*
M;7-G<W1R("(@96X@(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*;7-G<W1R("(C(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-
M0B`O("4N,F9-0B`@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"("\@)2XR9DU"
M("`H)2XR9B4E*2(*"B,Z('1H<F5A9"YP:'`Z,34V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D($UE<W-A9V5S(@IM<V=S='(@(B5D(&UE;G-A:F5S(@H*(SH@
M;6%I;&)O>"YP:'`Z,3<V"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A
M9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")392!H82AN*2!E;&EM
M:6YA9&\@)60@;65N<V%J92AS*2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3DV"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R(")392!H86X@;F]T:69I8V%D;R`E9"!M96YS86IE<R!N
M;W)M86QE<R!A;"!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G
M97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R(")3
M92!H86X@;F]T:69I8V%D;R`E9"!M96YS86IE<R!N;W)M86QE<RXB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3@X"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A
M9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E-E(&AA;B!N;W1I9FEC861O("5D
M(&UE;G-A:F5S('-P86T@86P@861M:6YI<W1R861O<B!D92!S:7-T96UA<RXB
M"@HC.B!L:6(O4W!A;2YP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R
M(")392!H86X@;F]T:69I8V%D;R`E9"!M96YS86IE<R!S<&%M+B(*"B,Z(&UA
M:6QB;W@N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!T;R`E9"!O
M9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"!A;"`E9"!D92`E9"!M96YS86IE
M*',I(@H*(SH@;6%I;&)O>"YP:'`Z-C,V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W
M87,@;F]T(')E;F%M960N(@IM<V=S='(@(B5S('EA(&5X:7-T92X@3&$@8V%R
M<&5T82`E<R!N;R!S92!H82!R96YO;6)R861O+B(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HV.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B)7,@;F\@<&%R
M96-E('5N(&)U>O-N(';A;&ED;RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S
M:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@=&AE('-T87)T
M(&]F('1H92!M;VYT:"XB"FUS9W-T<B`B3&$@8V%R<&5T82`E<R!S92!R96YO
M;6)R87+A(&%L(&EN:6-I;R!D96P@;65S+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HR-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C
M8V5P=&5D+B(*;7-G<W1R("(E<R!H82!A8V5P=&%D;RXB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C$W"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!C86YC96QL960@7"(E<UPB+B(*;7-G<W1R("(E<R!H82!C86YC96QA
M9&\@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R
M("(E<R!H82!R96-H87IA9&\N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T
M;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R("(E<R!H82!R97-P;VYD
M:61O(&$@=6YA(&-O;G-U;'1A(&1E('1I96UP;R!D:7-P;VYI8FQE+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@7"(E
M<UPB+B(*;7-G<W1R("(E<R!H82!R97-P;VYD:61O(&$@;&$@:6YV:71A8VGS
M;B!P87)A(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#@S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(&QE(&AA(&EN9F]R;6%D
M;R!S;V)R92!S=2!T:65M<&\@9&ES<&]N:6)L92XB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@:&$@86-E<'1A
M9&\@<')O=FES:6]N86QM96YT92XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-#@X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO
M=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(E<R!D97-E82!C
M;VYO8V5R('-U('1I96UP;R!D:7-P;VYI8FQE+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q
M=65S=',@>6]U<B!P<F5S96YC92!A="!<(B5S7"(N(@IM<V=S='(@(B5S('-O
M;&EC:71A('-U(&%S:7-T96YC:6$@82!<(B5S7"(N(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B)7,@<V4@:&$@8?%A
M9&ED;R!C;W)R96-T86UE;G1E(&$@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES
M:&5S('1O(&%M;65N9"!<(B5S7"(N(@IM<V=S='(@(B5S(&1E<V5A(&-O<G)E
M9VER("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E
M(&]F(%PB)7-<(BXB"FUS9W-T<B`B)7,@9&5S96$@<&]N97)L92!A;"!T86YT
M;R!S;V)R92!<(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@<F5C96EV
M92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T(%PB)7-<(BXB"FUS9W-T
M<B`B)7,@9&5S96$@<F5C:6)I<B!I;F9O<FUA8VGS;B!A8W1U86QI>F%D82!S
M;V)R92!<(B5S7"(N(@H*(SH@;65S<V%G92YP:'`Z,CDS(&UE<W-A9V4N<&AP
M.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z
M("5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7W1O<"YI;F,Z,C`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[
M)60I(@IM<V=S='(@(B5S.B`E<R`H)60F;F)S<#MD929N8G-P.R5D*2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(BA!
M<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BDB
M"FUS9W-T<B`B*$%P;&EC87(@;&]S(&-A;6)I;W,@>2!P87-A<B!A(&QA('-I
M9W5I96YT92!P86YT86QL82XI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@86YD
M(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("(H1&5S
M96-H87(@;&]S(&-A;6)I;W,@>2!R96=R97-A<B!A(&QA('!A;G1A;&QA(&1E
M(')E9&%C8VGS;BXI(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C$V"FUS9VED("(H2%1-3"DB"FUS9W-T<B`B*$A434PI(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@
M5&5X="DB"FUS9W-T<B`B*%/S;&\@=&5X=&\I(@H*(SH@<W!E;&QI;F<N<&AP
M.C(W.0IM<V=I9"`B(@HB*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@
M869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@("(*
M(D-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P
M<&QI960N*2(*;7-G<W1R("(B"B(H4F5G<F5S87(@82!L82!P86YT86QL82!D
M92!R961A8V-I\VX@9&5S<'7I<R!D92!A<&QI8V%R(&QO<R!C86UB:6]S(&AE
M8VAO<R`B"B)H87-T82!E;"!M;VUE;G1O+B!,;W,@8V%M8FEO<R!D92!L82!P
M86YT86QL82!A8W1U86P@3D\@<V4@87!L:6-A<N%N+BDB"@HC.B!S<&5L;&EN
M9RYP:'`Z,C<V"FUS9VED("(B"B(H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY
M:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H
M92`B"B)C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS
M9W-T<B`B(@HB*$5N=FEA<B!E;"!M96YS86IE('1R87,@87!L:6-A<B!T;V1O
M<R!L;W,@8V%M8FEO<R!H96-H;W,@:&%S=&$@87%U[2X@3&]S("(*(F-A;6)I
M;W,@9&4@;&$@<&%N=&%L;&$@86-T=6%L($Y/('-E(&%P;&EC87+A;BXI(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@
M(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B!!\6%D
M:7(@Z7-T;W,@:&%C:65N9&\@8VQI8R!E;B!!8V5P=&%R("HB"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A
M<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS9W-T<B`B*B!0;W(@9F%V;W(L
M('-E;&5C8VEO;F4@;&$H<RD@9&ER96-C:?-N*&5S*2`J(@H*(SH@;6%I;&)O
M>"YP:'`Z,3<T"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(#$@;65N<V%J92XB"@HC.B!L:6(O
M4W!A;2YP:'`Z,3DX"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B4V4@:&$@;F]T:69I8V%D;R`Q(&UE;G-A:F4@;F]R;6%L(&%L
M(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,N(@H*(SH@;&EB+U-P86TN<&AP
M.C$W.`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO
M="!S<&%M+B(*;7-G<W1R(")392!H82!N;W1I9FEC861O(#$@;65N<V%J92!N
M;W)M86PN(@H*(SH@;&EB+U-P86TN<&AP.C$Y,`IM<V=I9"`B,2!M97-S86=E
M(&AA<R!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B4V4@:&$@;F]T:69I8V%D;R`Q(&UE;G-A
M:F4@<W!A;2!A;"!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-S`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O
M<G1E9"!A<R!S<&%M+B(*;7-G<W1R(")392!H82!N;W1I9FEC861O(#$@;65N
M<V%J92!S<&%M+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C@P
M.`IM<V=I9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B,3`P(&-A<F%C=&5R
M97,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX,3$*;7-G:60@
M(C$P,#`@8VAA<F%C=&5R<R(*;7-G<W1R("(Q,#`P(&-A<F%C=&5R97,B"@HC
M.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX,#D*;7-G:60@(C(U,"!C
M:&%R86-T97)S(@IM<V=S='(@(C(U,"!C87)A8W1E<F5S(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z.#$P"FUS9VED("(U,#`@8VAA<F%C=&5R
M<R(*;7-G<W1R("(U,#`@8V%R86-T97)E<R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E
M(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB
M"FUS9W-T<B`B4V4@:&$@861J=6YT861O(&$@97-T92!M96YS86IE('5N82!I
M;6%G96X@9W)A;F1E(&QL86UA9&$@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@
M:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I
M;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G<W1R("(B"B)392!H82!R
M96-I8FED;R!U;B!A=FES;R!D92!D979O;'5C:?-N(&1E;"!D97-T:6YA=&%R
M:6\@9&4@=6X@;65N<V%J92!Q=64@(@HB:&%B[6$@96YV:6%D;RXB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0IM<V=I9"`B04Y$(@IM<V=S
M='(@(EDB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@R"FUS9VED
M(")!8V-E<'0@86YD(&%D9"!T;R!M>2!C86QE;F1A<B(*;7-G<W1R(")!8V5P
M=&%R('D@8?%A9&ER(&$@;&$@86=E;F1A(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4X-0IM<V=I9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B
M06-E<'1A<B!P971I8VGS;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW-#8*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(D%C97!T861A(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U.`IM<V=I9"`B06-C97!T960Z
M("(*;7-G<W1R(")!8V5P=&%D83H@(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C8V]U;G0G<R!N86UE.B(*;7-G<W1R
M(").;VUB<F4@9&4@;&$@8W5E;G1A.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU,C(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<R-0IM<V=I
M9"`B06-T:6]N<R(*;7-G<W1R(")!8V-I;VYE<R(*"B,Z(&QI8B]-24U%+TAE
M861E<G,N<&AP.C$Y,B!L:6(O34E-12](96%D97)S+G!H<#HQ.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D("5S('1O(&UY($%D9')E<W,@0F]O:R(*;7-G
M<W1R(")!\6%D:7(@)7,@82!L82!,:6)R971A(&1E(&1I<F5C8VEO;F5S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`S"FUS9VED
M(")!9&0@<V]U<F-E(@IM<V=S='(@(D'Q861I<B!F=65N=&4B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3<S"FUS9VED(")!9&0@=&AI<R!T;R!M
M>2!C86QE;F1A<B(*;7-G<W1R(")!\6%D:7(@82!L82!A9V5N9&$B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@S"FUS9VED(")!9&0@=&\@;7D@
M8V%L96YD87(B"FUS9W-T<B`B0?%A9&ER(&$@;&$@86=E;F1A(@H*(SH@8V]M
M<&]S92YP:'`Z-3DP"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<
M(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R(")392!H82!A\6%D:61O(%PB
M)7-<(B!C;VUO(&%D:G5N=&\N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,3DX"FUS9VED("(B"B)!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES
M<&QA>2!W:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@
M:&5A9&5R("(*(F]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB0V%B
M96-E<F%S(&%D:6-I;VYA;&5S(&UO<W1R861A<R!A;"!V:7-U86QI>F%R.B`\
M96T^*&]P8VEO;F%L+"!I;F1I<75E(&-A9&$@(@HB8V%B96-E<F$@96X@;.UN
M96%S(&1I<W1I;G1A<RD\+V5M/B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I
M9FEC871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N
M86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B4V4@
M<'5E9&4@=FES=6%L:7IA<B`E<R!L82!I;F9O<FUA8VGS;B!A9&EC:6]N86PN
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*;7-G
M:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<R(*;7-G<W1R(")$
M971A;&QE<R!D92!I;F9O<FUA8VGS;B!A9&EC:6]N86PB"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I;VYA;"!M97-S
M86=E(&1E=&%I;',B"FUS9W-T<B`B1&5T86QL97,@861I8VEO;F%L97,@9&5L
M(&UE;G-A:F4B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL
M<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")392!P=65D96X@=FES=6%L
M:7IA<B`E<R!L;W,@9&5T86QL97,@861I8VEO;F%L97,@9&5L(&UE;G-A:F4N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D
M9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@(D1E=&%L
M;&5S(&%D:6-I;VYA;&5S(&1E(&UE;G-A:F4@9&4@97)R;W(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R(")392!P=65D96X@=FES=6%L:7IA<B`E<R!L;W,@
M9&5T86QL97,@861I8VEO;F%L97,@9&4@;65N<V%J92!D92!E<G)O<BXB"@HC
M.B!C;VYT86-T<RYP:'`Z.#4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ.#`*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y
M('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,@IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(D1I<F5C8VEO;F5S(@H*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z,3,T"FUS9VED(")!9&1R97-S($)O;VMS(@IM
M<V=S='(@(DQI8G)E=&%S(&1E(&1I<F5C8VEO;F5S(@H*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z,3@Y"FUS9VED("(B"B)!9&1R97-S97,@=&\@
M0D-#(&%L;"!M97-S86=E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A
M9&1R97-S(&]N(&$@;F5W("(*(FQI;F4I/"]E;3XB"FUS9W-T<B`B(@HB1&ER
M96-C:6]N97,@82!L87,@<75E($)#0R!T;V1O<R!L;W,@;65N<V%J97,Z(#QE
M;3XH;W!C:6]N86PL(&EN9&EQ=64@8V%D82`B"B)D:7)E8V-I\VX@96X@=6YA
M(&SM;F5A(&1I<W1I;G1A*3PO96T^(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L
M>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@
M96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B
M(@HB1&ER96-C:6]N97,@96YL87IA9&%S(&5X<&SM8VET86UE;G1E(&$@97-T
M82!I9&5N=&ED860Z(#QE;3XH;W!C:6]N86PL("(*(FEN9&EQ=64@8V%D82!D
M:7)E8V-I\VX@96X@=6YA(&SM;F5A(&1I<W1I;G1A*3PO96T^(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HX,3(*;7-G:60@(D%L;"(*;7-G<W1R(")4;V1O<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*;7-G:60@(B(*
M(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL
M(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G<W1R
M("(B"B)4;V1O<R!L;W,@;65N<V%J97,@9&4@;&$H<RD@<VEG=6EE;G1E*',I
M(&-A<G!E=&$H<RD@<V4@9&5S8V%R9V%RX6X@8V]M;R!U;B`B"B+Z;FEC;R!A
M<F-H:79O($U"3U@Z("(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E
M7W1R87-H+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S
M<V%G97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y
M<R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N(@IM<V=S='(@(B(*
M(E-E(&5L:6UI;F%RX6X@<&5R;6%N96YT96UE;G1E('1O9&]S(&QO<R!M96YS
M86IE<R!D92!S=2!C87)P971A(%PB)7-<(B!C;VX@(@HB86YT:6?\961A9"!S
M=7!E<FEO<B!A("5S(&3M87,N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP.C4Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA
M;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B(@HB
M4V4@96QI;6EN87+A;B!T;V1O<R!L;W,@861J=6YT;W,@=FEN8W5L861O<R!C
M;VX@;>%S(&1E("5S(&UE<V5S(&1E("(*(F%N=&EG_&5D860N(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@<V5N="UM86EL(&9O
M;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D
M+B(*;7-G<W1R("(B"B)392!E;&EM:6YA<N%N('1O9&%S(&QA<R!C87)P971A
M<R!<(D5N=FEA9&]S7"(@8V]N(&WA<R!D92`E<R!M97-E<R!D92`B"B)A;G1I
M9_QE9&%D+B(*"B,Z(&%C;"YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M06QL(')I9VAT<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO
M=F5D(&9O<B!U<V5R(%PB)7-<(BXB"FUS9W-T<B`B(@HB4V4@:&%N(&5L:6UI
M;F%D;R!C;W)R96-T86UE;G1E(&1E(&QA(&-A<G!E=&$@7"(E<UPB('1O9&]S
M(&QO<R!D97)E8VAO<R!D96P@(@HB=7-U87)I;R!<(B5S7"(N(@H*(SH@;&EB
M+V%P:2YP:'`Z-S8*;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A=&EO;C\B"FUS
M9W-T<B`BOU!E<FUI=&ER(&QA(&-R96%C:?-N(&1E(&-A<G!E=&%S/R(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@
M9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM
M<V=S='(@(K]!<&QI8V%R(')E9VQA<R!D92!F:6QT<F%D;R!A(&-U86QQ=6EE
M<B!B=7KS;C\B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP
M.C$Q,`IM<V=I9"`B06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO
M;CHB"FUS9W-T<B`B4&%R=&5S(&%L=&5R;F%T:79A<R!D92!E<W1A('-E8V-I
M\VXZ(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-3<R"FUS9VED
M(")!;'=A>7,B"FUS9W-T<B`B4VEE;7!R92(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C4U-PIM<V=I9"`B06QW87ES('-A=F4@871T86-H;65N
M=',B"FUS9W-T<B`B1W5A<F1A<B!S:65M<')E(&QO<R!A9&IU;G1O<R(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HU-30*;7-G:60@(B(*(D%N(&5R<F]R(&]C8W5R
M960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@
M5&AE($E-05`@<V5R=F5R("(*(G-A:60Z("(*;7-G<W1R("(B"B)392!H82!P
M<F]D=6-I9&\@=6X@97)R;W(@86P@:6YT96YT87(@96QI;6EN87(@96P@861J
M=6YT;RX@R7-T;R!E<R!L;R!Q=64@(@HB9&EJ;R!E;"!S97)V:61O<B!)34%0
M.B`B"@HC.B!L:6(O365S<V%G92YP:'`Z-#,W"FUS9VED(")!;B!U;FMN;W=N
M(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N;W1E+B(*
M;7-G<W1R(")392!H82!P<F]D=6-I9&\@=6X@97)R;W(@9&5S8V]N;V-I9&\@
M86P@8W)E87(@;&$@;F]T82XB"@HC.B!L:6(O365S<V%G92YP:'`Z-#,V"FUS
M9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@
M=&AE(&YE=R!T87-K+B(*;7-G<W1R(")392!H82!P<F]D=6-I9&\@=6X@97)R
M;W(@9&5S8V]N;V-I9&\@86P@8W)E87(@;&$@=&%R96$N(@H*(SH@;65S<V%G
M92YP:'`Z-3`T(&UA:6QB;W@N<&AP.C<P.2!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,U"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-@IM<V=I9"`B06YS=V5R
M960B"FUS9W-T<B`B4F5S<&]N9&ED;R(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@
M(DUE;G-A:F5S(')E<W!O;F1I9&]S(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHW"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(D%P
M;&EC87(@9FEL=')O<R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<'!L>2!&:6QT97)S('1O("5S
M(@IM<V=S='(@(D%P;&EC87(@9FEL=')O<R!E;B`E<R(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHS-@IM<V=I9"`B07!P;'D@9FEL=&5R(')U
M;&5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`BOT%P;&EC87(@<F5G;&%S
M(&1E(&9I;'1R861O(&%L(&EN:6-I87(@<V5S:?-N/R(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHT,@IM<V=I9"`B07!P;'D@9FEL=&5R(')U
M;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS9W-T<B`BOT%P
M;&EC87(@<F5G;&%S(&1E(&9I;'1R861O(&%L('9I<W5A;&EZ87(@;&$@8V%R
M<&5T82!D92!%3E12041!/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE
M=&4@=&AI<R!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N/R(*;7-G<W1R("*_
M17-TX2!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&5S=&$@9&5F:6YI
M8VGS;B!D92!#87)P971A(%9I<G1U86P_(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@
M:V5Y/R(*;7-G<W1R("*_17-TX2!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI
M;F%R(&5S=&$@8VQA=F4@</IB;&EC83\B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B
M(@HB07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A
M:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(B(*(K]%
M<W1A('-E9W5R;R!D92!Q=64@9&5S96$@96QI;6EN87(@<W4@8VQA=F4_("BA
M3F\@97,@3D%$02!R96-O;65N9&%B;&4A*2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:G,Z-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_
M(@IM<V=S='(@(K]%<W3A('-E9W5R;R!D92!Q=64@9&5S96$@:&%C97(@Z7-T
M;S\B"@HC.B!M97-S86=E+G!H<#HT,#D@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@
M(K]%<W3A('-E9W5R;R!D92!Q=64@9&5S96$@96QI;6EN87(@4$5234%.14Y4
M14U%3E1%(&5S=&]S(&UE;G-A:F5S/R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S
M+G!H<#HR,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-
M04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT/R(*;7-G<W1R("*_17-T
MX2!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(%!%4DU!3D5.5$5-14Y4
M12!E<W1E(&%D:G5N=&\_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T
M>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`BOT5S=.$@<V5G=7)O(&1E('%U92!D
M97-E82!V86-I87(@97-T82!C87)P971A/R(*"B,Z(&QI8B])35`N<&AP.CDT
M.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@
M<W!A;2!F;VQD97(_(@IM<V=S='(@(K]%<W3A('-E9W5R;R!D92!Q=64@9&5S
M96$@=F%C:6%R(&QA(&-A<G!E=&$@9&4@<W!A;3\B"@HC.B!L:6(O24U0+G!H
M<#HY-#(*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y
M;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`BOT5S=.$@<V5G=7)O(&1E('%U
M92!D97-E82!V86-I87(@;&$@<&%P96QE<F$_(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS
M9W-T<B`BOT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!015)-
M04Y%3E1%345.5$4@97-T;W,@;65N<V%J97,_(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z-SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R("*_
M17-TX2!S96=U<F\@9&4@<75E(&1E<V5A(&-O;G-I9&5R87(@97-T92!M96YS
M86IE(&-O;6\@:6YO9F5N<VEV;S\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHW-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHW-`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R
M="!T:&ES(&UE<W-A9V4@87,@<W!A;3\B"FUS9W-T<B`BOT5S=.$@<V5G=7)O
M(&1E('%U92!D97-E82!C;VYS:61E<F%R(&5S=&4@;65N<V%J92!C;VUO('-P
M86T_(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3`U"FUS9VED
M(")!<G)I=F%L(%1I;64B"FUS9W-T<B`B4&]R(&AO<F$@9&4@;&QE9V%D82(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B07-C
M96YD:6YG(@IM<V=S='(@(D%S8V5N9&5N=&4B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HU-S$*;7-G:60@(D%S:R(*;7-G<W1R(")#;VYS=6QT
M87(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S(*;7-G
M:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R(")!9&IU;G1A<B!A<F-H:79O<R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U,PIM<V=I9"`B
M071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@
M;65S<V%G93\B"FUS9W-T<B`BOT%D:G5N=&%R('5N82!C;W!I82!D92!L82!C
M;&%V92!01U`@</IB;&EC82!A;"!M96YS86IE/R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]T;F5F+G!H<#HQ,3$*;7-G:60@(D%T=&%C:&5D($9I;&4Z(@IM<V=S
M='(@(D%R8VAI=F\@861J=6YT;SHB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#8R
M(&QI8B]#;VUP;W-E+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M071T86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T86-H;65N="!S
M:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(@IM<V=S='(@(B(*(D5L
M(&%R8VAI=F\@861J=6YT;R!<(B5S7"(@<W5P97)A(&5L(&SM;6ET92!D92!T
M86UA\6\@9&4@861J=6YT;W,N($Y/('-E(&AA("(*(F%D:G5N=&%D;R!E;"!A
M<F-H:79O+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S<*;7-G
M:60@(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T
M('EO=2!S96YT+B(*;7-G<W1R(")392!A9&IU;G1A(&QA(')E<W!U97-T82!A
M(&QA('-O;&EC:71U9"!D92!A9V5N9&$@<75E(&AA8NUA(&AE8VAO+B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4P,"!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT
M<RYJ<SHU-0IM<V=I9"`B071T86-H;65N="(*;7-G<W1R(")!9&IU;G1O(@H*
M(SH@871T86-H;65N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B071T
M86-H;65N="`E<R!D96QE=&5D+B(*;7-G<W1R(")392!H82!B;W)R861O(&5L
M(&%D:G5N=&\@)7,N(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Q,C4*;7-G:60@
M(D%T=&%C:&UE;G0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I\VX@
M9&4@861J=6YT;R(*"B,Z(&-O;7!O<V4N<&AP.C$Q,#4@;&EB+TUE<W-A9V4N
M<&AP.C4Q-0IM<V=I9"`B071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@
M871T86-H;65N="!T>7!E(@IM<V=S='(@(D%D:G5N=&\@96QI;6EN861O.B!4
M:7!O(&1E(&%D:G5N=&\@;W)I9VEN86PB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#<P"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#DS"FUS9VED(")!='1A8VAM
M96YT<R(*;7-G<W1R(")!9&IU;G1O<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV-S@*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")!<VES=&5N
M=&5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*
M;7-G:60@(D%T=&5N=&EO;B(*;7-G<W1R(")!=&5N8VGS;B(*"B,Z(&QI8B]!
M=71H+VEM<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UP.B!H86-E
M(&9A;'1A(&QA(&5X=&5N<VGS;B!)34%0+B(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C8R.`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W
M(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I
M;B!M>2`B"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@HBOTUO<W1R87(@875T
M;VWA=&EC86UE;G1E(&QA<R!I;>%G96YE<R!D92!L;W,@;65N<V%J97,@2%1-
M3"!S:2!E;"!R96UI=&5N=&4@(@HB97-TX2!E;B!M:2!L:6)R971A(&1E(&1I
M<F5C8VEO;F5S/R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C(Y.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S
M='(@(DQI8G)E=&%S(&1E(&1I<F5C8VEO;F5S(&1I<W!O;FEB;&5S.B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,30*;7-G:60@(D%W86ET:6YG
M(%)E<W!O;G-E(@IM<V=S='(@(D5S<&5R86YD;R!R97-P=65S=&$B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H
M<"UF;W)M870*;7-G:60@(D)A8U]K('1O("5S(@IM<V=S='(@(E)E9W)E<V%R
M(&$@)7,@*%]K*2(*"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0F%C:R!T;R`E<R(*;7-G<W1R(")296=R97-A<B!A("5S(@H*(SH@=&AR
M96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6
M:65W($EN9&5X(@IM<V=S='(@(E)E9W)E<V%R(&%L(.UN9&EC92!D92!M96YS
M86IE<R(*"B,Z('1H<F5A9"YP:'`Z,3,R"FUS9VED(")"86-K('1O(%1H<F5A
M9"!$:7-P;&%Y(@IM<V=S='(@(E)E9W)E<V%R(&$@;&$@=FES=&$@<&]R('-E
M8W5E;F-I87,B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")"860@;&]G:6X@;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`B57-U87)I;R!O(&-O;G1R87-E\6$@:6YC;W)R96-T;W,N(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N9&5D.B`E
M<R(*;7-G<W1R(")0971I8VGS;B!I;F-O<G)E8W1A(&\@;6%L9F]R;6%D82X@
M16P@<V5R=FED;W(@:&$@<F5S<&]N9&ED;SH@)7,B"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C4W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"860@<F5Q=65S
M=#H@)7,N(@IM<V=S='(@(E!E=&EC:?-N(&EN=N%L:61A.B`E<RXB"@HC.B!M
M97-S86=E+G!H<#HR-S0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR,C(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L
M:6(O4V5A<F-H+G!H<#HV,#$*;7-G:60@(D)C8R(*;7-G<W1R(")"8V,B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W
M(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE
M<W-A9V4N(@IM<V=S='(@(D$@8V]N=&EN=6%C:?-N('-E(&UU97-T<F$@96P@
M;65N<V%J92!D92!I;F9O<FUA8VGS;B!D92!E<W1A9&\N(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED(")";&%C:VQI<W0B"FUS9W-T
M<B`B3&ES=&$@;F5G<F$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HV,3<*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N
M;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/R(*;7-G<W1R
M("(B"B*_0FQO<75E87(@;&%S(&EMX6=E;F5S(&1E(&QO<R!M96YS86IE<R!(
M5$U,(&$@;65N;W,@<75E('-E('-O;&EC:71E;B`B"B)E<W!E8^UF:6-A;65N
M=&4_(@H*(SH@;&EB+U-E87)C:"YP:'`Z-C`Y"FUS9VED(")";V1Y(@IM<V=S
M='(@(D-U97)P;R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,C,@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS.0HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C4U('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-S$*
M;7-G:60@(D)O=&@B"FUS9W-T<B`B06UB;W,B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HV.#0*;7-G:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@
M86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R(")486YT;R!E;B!L87,@8V%B
M96-E<F%S(&-O;6\@96X@96P@8W5E<G!O(&1E;"!M96YS86IE(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HU,#$*;7-G:60@(D-204TM340U(&]R($1)1T53
M5"U-1#4@<F5Q=6ER97,@=&AE($%U=&A?4T%33"!P86-K86=E('1O(&)E(&EN
M<W1A;&QE9"XB"FUS9W-T<B`B(@HB4&%R82!U<V%R($-204TM340U(&\@1$E'
M15-4+4U$-2!H87D@<75E('1E;F5R(&EN<W1A;&%D;R!E;"!P87%U971E($%U
M=&A?4T%33"XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M-S(*;7-G:60@(D-?:&%R<V5T(@IM<V=S='(@(E]*=65G;R!D92!C87)A8W1E
M<F5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED
M(")#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R
M96UO=&4@;6%I;"!S97)V97(N(@IM<V=S='(@(DYO('-E('!U961E(&-O;F5C
M=&%R(&%L('-E<G9I9&]R(&1E(&-O<G)E;R!R96UO=&\N(@H*(SH@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HQ.3D*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T
M;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B`B"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@8V]N96-T87(@86P@<V5R=FED;W(@9&4@8V]R<F5O(')E;6]T;SH@(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@
M;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT("(*
M(FUA:6QB;W@N(@IM<V=S='(@(B(*(DYO('-E('!U961E(&UO<W1R87(@+2!E
M;B!E;"!B=7KS;B!A8W1U86P@<_-L;R!S92!H82!E;F-O;G1R861O("5S('!A
M<G1E<R!D92`E(@HB<R!D92!E<W1E(&UE;G-A:F4N(@H*(SH@9F]L9&5R<RYP
M:'`Z,C<P('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4U"B,Z
M('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C$@=&5M<&QA=&5S+W-A
M=F5I;6%G92]S879E:6UA9V4N:6YC.C$Y"B,Z('1E;7!L871E<R]S;6EM92]P
M87-S<&AR87-E+FEN8SHR,2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z.#8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,"!T
M96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,R"B,Z('1E;7!L871E<R]P
M9W`O:6UP;W)T7VME>2YI;F,Z-C8*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")#
M86YC96QA<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<Q
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@365S
M<V%G92(*;7-G<W1R(")#86YC96QA<B!M96YS86IE(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YJ<SHV"FUS9VED(")#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL
M('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+B(*;7-G<W1R(")#
M86YC96QA<B!E<W1E(&UE;G-A:F4@9&5S96-H87+A('!E<FUA;F5N=&5M96YT
M92!S=2!C;VYT96YI9&\N(@H*(SH@;65S<V%G92YP:'`Z,C<S('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W)E8V]M<&]S92YI;F,Z,34@;&EB+U-E87)C:"YP:'`Z-3DW"FUS9VED
M(")#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z.3,*;7-G:60@(B(*(D-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A
M:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*
M(G-E<G9E<BXB"FUS9W-T<B`B(@HB3F\@<V4@9&ES<&]N92!D92!I;7!O<G1A
M8VGS;B!D92!C97)T:69I8V%D;W,N($5S=&4@<V5R=FED;W(@;F\@=&EE;F4@
M(@HB86-T:79A9&$@;&$@8V%R9V$@9&4@87)C:&EV;W,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8Y-@IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM
M<V=S='(@(D]C=7!A;G1E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C@P"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B0V%M8FEA<B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I9"`B0VAA
M;F=E($%L;"(*;7-G<W1R(")#86UB:6%R('1O9&]S(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.CDR"FUS9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S='(@
M(D-A;6)I87(@8V%R<&5T82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H
M(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N
M9"`B"B)H;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`B(@HB0V%M
M8FEA(&]P8VEO;F5S(&1E('9I<W5A;&EZ86-I\VX@=&%L97,@8V]M;R!L82!C
M86YT:61A9"!D92!M96YS86IE<R!P;W(@(@HB<.%G:6YA('D@8_-M;R!O<F1E
M;F%R;&]S+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(T"FUS
M9VED(")#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB
M"FUS9W-T<B`B0V%M8FEA(&QA(&-O;F9I9W5R86-I\VX@9&4@<V5R=FED;W(@
M>2!C87)P971A(&1E(&-O<G)E;RXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A9&1R97-S
M+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B(@HB0V%M
M8FEA(&5L(&YO;6)R92P@9&ER96-C:?-N(&5L96-T<O-N:6-A('D@9FER;6$@
M=FES:6)L97,@86P@;&5E<B!O(')E<W!O;F1E<B`B"B)A('-U<R!M96YS86IE
M<RXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX,3,*;7-G:60@
M(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B0V%R86-T97)E<R!V
M:7-U86QI>F%D;W,Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,34*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS
M9W-T<B`B0V]M<')O8F%R(&-O<G)E;R!N=65V;R(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S
M='(@(D-O;7!R;V)A<B!?5&]D87,O3FEN9W5N82(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K(&%L;"!M86EL('-E<G9E
M<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.B(*;7-G<W1R(")#;VUP
M<F]B87(@=&]D;W,@;&]S('-E<G9I9&]R97,@9&4@;&]S('%U92!Q=6EE<F4@
M=')A97(@8V]R<F5O.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C0V,PIM<V=I9"`B0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M
M97-S86=E/R(*;7-G<W1R("*_0V]M<')O8F%R(&]R=&]G<F%F[6$@86YT97,@
M9&4@96YV:6%R('5N(&UE;G-A:F4_(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z-`IM<V=I9"`B0VAO;W-E($%C=&EO;CHB"FUS9W-T<B`B
M16QE9VER(&%C8VGS;CHB"@HC.B!C;VYF:6<O+F)A:R]S97)V97)S+G!H<"YD
M:7-T.C(P,@IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@
M(D5L:6IA('5N('-E<G9I9&]R(&1E(&-O<G)E;SHB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHQ,C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,38V"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Q-PIM<V=I9"`B0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S
M<R!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E-E;&5C8VEO;F4@=6YA(&-O:6YC
M:61E;F-I82!O(&UO9&EF:7%U92!L82!D:7)E8V-I\VX@9&4@;&$@9&5R96-H
M83HB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*
M;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D
M9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(D5L:6IA(&QA(&QI8G)E=&$@9&4@
M9&ER96-C:6]N97,@=7-A9&$@86P@8?%A9&ER(&1I<F5C8VEO;F5S+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PIM<V=I9"`B
M0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W
M:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(D5L:6IA(&5L(&]R
M9&5N(&1E(&+Z<W%U961A(&5N(&QA<R!L:6)R971A<R!A;"!E>'!A;F1I<B!D
M:7)E8V-I;VYE<RXB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N=F5R="!T
M:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@
M=FEE=RXB"FUS9W-T<B`B(@HB4'5L<V4@)7,@<&%R82!C;VYV97)T:7(@96P@
M87)C:&EV;R!D92!I;6%G96X@82!U;B!F;W)M871O('-O<&]R=&%D;R!P;W(@
M<W4@(@HB;F%V96=A9&]R+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!D;W=N
M;&]A9"!T:&4@:6UA9V4N(@IM<V=S='(@(E!U;'-E("5S('!A<F$@9&5S8V%R
M9V%R(&QA(&EM86=E;BXB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N
M="!P86=E+B(*;7-G<W1R(")0=6QS92`E<R!P87)A(&ER(&$@;&$@<.%G:6YA
M(&1E(&=E<W1I\VX@9&4@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W
M($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B
M4'5L<V4@)7,@<&%R82!V97(@96P@8V]N=&5N:61O($A434P@96X@=6YA('9E
M;G1A;F$@<V5P87)A9&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,38T"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@
M82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B4'5L<V4@)7,@
M<&%R82!V97(@=6YA(&UI;FEA='5R82!D92!L82!I;6%G96XN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R
M871E('=I;F1O=RXB"FUS9W-T<B`B4'5L<V4@)7,@<&%R82!V97(@96P@861J
M=6YT;R!E;B!U;F$@=F5N=&%N82!S97!A<F%D82XB"@HC.B!L:6(O34E-12]6
M:65W97(O<F5L871E9"YP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A<G0@:6X@
M82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(B(*(E!U;'-E("5S('!A<F$@
M=F5R(&5S=&$@<&%R=&4@;75L=&EP87)T92]R96QA8VEO;F%D82!E;B!U;F$@
M=F5N=&%N82!S97!A<F%D82XB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP
M:'`Z.3@*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S(@IM
M<V=S='(@(E!U;'-E(&%Q=>T@<&%R82!-3U-44D%2(&QA<R!I;>%G96YE<R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,0IM<V=I
M9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T960@861D<F5S<R!B
M;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T;R`B"B)S96%R8V@N
M(@IM<V=S='(@(B(*(E!U;'-E('-O8G)E('5N82!D92!L87,@;&EB<F5T87,@
M9&4@9&ER96-C:6]N97,@>2!L=65G;R!S96QE8V-I;VYE(&QO<R!C86UP;W,@
M(@HB<&]R(&QO<R!Q=64@9&5S96$@8G5S8V%R+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C$W,`IM<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B
M;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R(")0=6QS92!P
M87)A(&=U87)D87(@;&$@8VQA=F4@4$=0('#Z8FQI8V$@96X@;&$@3&EB<F5T
M82!D92!D:7)E8V-I;VYE<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-
M24U%(&-E<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K(@IM
M<V=S='(@(B(*(E!U;'-E('!A<F$@9W5A<F1A<B!E;"!C97)T:69I8V%D;R!3
M+TU)344@9&4@)7,@96X@;&$@3&EB<F5T82!D92!D:7)E8V-I;VYE<R(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDS.0IM<V=I9"`B0VQI8VMI
M;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@
M=&\@=&AE('-E;F1E<B(*;7-G<W1R(")!;"!P=6QS87(@96X@;&$@9&ER96-C
M:?-N('-E(')E9&%C=&%RX2!U;B!M96YS86IE('!A<F$@96P@<F5M:71E;G1E
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.30P"FUS9VED(")#
M;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@
M=&\@8F4@<F5A9"(*;7-G<W1R(")!;"!P=6QS87(@96X@;&$@9&ER96-C:?-N
M('-E(&%B<FERX2!E;"!M96YS86IE(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]F971C:&UA:6PN:6YC.C(X"FUS9VED(")#;&]S92(*;7-G<W1R(")#97)R
M87(B"@HC.B!C;VUP;W-E+G!H<#HT,3@*;7-G:60@(D-L;W-E('1H:7,@=VEN
M9&]W(@IM<V=S='(@(D-E<G)A<B!E<W1A('9E;G1A;F$B"@HC.B!F;VQD97)S
M+G!H<#HT,3`*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS9W-T<B`B0V%R<&5T
M82!C97)R861A(@H*(SH@9F]L9&5R<RYP:'`Z-#,P"FUS9VED(")#;VQL87!S
M92(*;7-G<W1R(")#;VQA<'-A<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C0P"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T<B`B0V]L
M87!S87(@=&]D87,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHT,`IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T<B`B0V]L
M87!S87(@=&]D87,@;&%S(&-A<G!E=&%S(@H*(SH@9F]L9&5R<RYP:'`Z-#,P
M"FUS9VED(")#;VQL87!S92!&;VQD97(B"FUS9W-T<B`B0V]L87!S87(@8V%R
M<&5T82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHU,0IM
M<V=I9"`B0V]L;W(@26YD:6-A=&]R.B`B"FUS9W-T<B`B26YD:6-A9&]R(&1E
M(&-O;&]R.B`B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`S"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(D-O;65N=&%R:6\B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S8R"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B
M5&5R;6EN861O(@H*(SH@8V]M<&]S92YP:'`Z-#$W"FUS9VED(")#;VUP;W-E
M(&%N;W1H97(@;65S<V%G92(*;7-G<W1R(")2961A8W1A<B!O=')O(&UE;G-A
M:F4B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT,S0*;7-G:60@
M(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_(@IM<V=S
M='(@(K]2961A8W1A<B!M96YS86IE<R!E;B!U;F$@=F5N=&%N82!S97!A<F%D
M83\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@
M(B(*(D-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A
M=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS
M9W-T<B`B(@HBOU)E9&%C=&%R(&UE;G-A:F5S('!O<B!O;6ES:?-N(&5N('5N
M(&5N=&]R;F\@1U5)(&1E($A434P@*'-I(&5L(&YA=F5G861O<B!L;R`B"B)S
M;W!O<G1A*3\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HV-PIM
M<V=I9"`B0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+B(*
M;7-G<W1R(")#;VYF:6=U<F$@8_-M;R!S92!M=65S=')A;B!L;W,@;65N<V%J
M97,N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@
M(D-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB"FUS9W-T<B`B0V]N
M9FEG=7)A<B!L87,@;W!C:6]N97,@9&4@=FES=&$@<')E=FEA(&1E;"!C;W)R
M96\N(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G:60@(D-O;FYE
M8W1I;VX@9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T<B`B0V]N97AI
M\VX@9&5S86-T:79A9&$@<&]R(&5L('-E<G9I9&]R($E-05`N(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@(D-O;FYE8W1I;VX@=&\@
M<V5R=F5R(&9A:6QE9"(*;7-G<W1R(")%<G)O<B!A;"!C;VYE8W1A<B!A;"!S
M97)V:61O<B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$T,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E
M<RXB"FUS9W-T<B`B0V]N=')O;&$@96P@<V]P;W)T92!01U`@<&%R82`E<RXB
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM
M<V=S='(@(D-O;G1R;VQA(&5L('-O<&]R=&4@4R]-24U%('!A<F$@)7,N(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3(Q"FUS9VED(")#;VYT
M<F]L(&]P=&EO;G,@<F5L871I;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG+B(*
M;7-G<W1R(")/<&-I;VYE<R!D92!C;VYT<F]L(')E;&%C:6]N861A<R!C;VX@
M;&$@8OIS<75E9&$@9&4@;65N<V%J97,N(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O;G1R;VP@=VAE;B!N97<@;6%I
M;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@
M;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV97,N(@IM<V=S='(@(B(*(D-O
M;G1R;VQA(&QA(&-O;7!R;V)A8VGS;B!D92!C;W)R96\@;G5E=F\@>2!S:2!S
M92!L92!N;W1I9FEC87+A(&\@;F\@86P@(@HB<F5C:6)I<FQO+B(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C8W-`IM<V=I9"`B0V]N=F5R="!T
M97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R
M("*_0V]N=F5R=&ER(&5M;W1I8V]N97,@9&4@=&5X=&\@96X@9W+A9FEC;W,_
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y
M(@IM<V=S='(@(D-O<&EA<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHU,0IM<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T<B`B0V]P:6%R(&$@
M;&$@8V%R<&5T82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G<W1R(")#;W)R96=I<B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#`*;7-G:60@(D-O<G)E
M8W1E9"!497AT(@IM<V=S='(@(E1E>'1O(&-O<G)E9VED;R(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z,S@R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S(@IM<V=S
M='(@(DYO('-E('!U961E(&-O;7!L971A<B!L82!P971I8VGS;BX@4F%Z\VX@
M86QE9V%D83H@)7,B"@HC.B!A='1A8VAM96YT+G!H<#HU,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E('1H92!61E,@8F%C:V5N9#H@
M)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@8W)E87(@96P@;6]T;W(@5D93.B`E
M<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S86=E<R!F<F]M("5S+B!4:&4@<V5R
M=F5R('-A:60Z("5S(@IM<V=S='(@(B(*(DYO('-E('!U961E;B!E;&EM:6YA
M<B!L;W,@;65N<V%J97,@9&4@)7,N(,ES=&\@97,@;&\@<75E(&1I:F\@96P@
M<V5R=FED;W(Z("5S(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C,S,PIM<V=I9"`B
M0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS
M9W-T<B`B3F\@<V4@<'5E9&5N(')E86QI>F%R(&QA<R!O<&5R86-I;VYE<R!D
M92!M86YT96YI;6EE;G1O+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H
M<#HU-`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F
M:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B3F\@
M<V4@<'5E9&4@97AT<F%E<B!E;"!A<F-H:79O('-O;&EC:71A9&\@9&5L(&%D
M:G5N=&\@35,M5$Y%1BXB"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HU
M.`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE
M(&9R;VT@=&AE(%II<"!A<F-H:79E+B(*;7-G<W1R(").;R!S92!P=65D92!E
M>'1R865R(&5L(&%R8VAI=F\@<V]L:6-I=&%D;R!D96P@87)C:&EV;R!::7`N
M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@<V5C=7)E(&-O;FYE8W1I;VX@=&\@=&AE
M($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R(").;R!S92!P=65D92!A
M8G)I<B!U;F$@8V]N97AI\VX@<V5G=7)A(&-O;B!E;"!S97)V:61O<B!)34%0
M+B`E<R`Z("5S+B(*"B,Z(&QI8B]397-S:6]N+G!H<#HR.#`*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!N86UE<W!A8V4@:6YF;W)M871I;VX@9G)O;2!)
M34%0('-E<G9E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@<F5C=7!E<F%R(&QA
M(&EN9F]R;6%C:?-N(&1E(&YO;6)R97,@9&5L('-E<G9I9&]R($E-05`N(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E
M<R]A8VPO86-L+FEN8SHS.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0W)E87(B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHV"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM
M<V=S='(@(D-R96%R(&-A<G!E=&$B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3,W"FUS9VED(")#<F5A=&4@2V5Y<R(*;7-G<W1R(")#<F5A<B!C;&%V
M97,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN
M8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W($%C8V]U;G0B"FUS9W-T<B`B0W)E
M87(@=6YA(&-U96YT82(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T
M+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*;7-G
M:60@(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R(")#<F5A<B!U
M;F$@8V%R<&5T82!D92!S<&%M(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S
M='(@(D-R96%R(&-A<G!E=&$@9&4@8F]R<F%D;W)E<R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S+W!R969S
M+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@;F5W('-E
M;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B0W)E87(@8V%R<&5T82!D92!C;W)R
M96\@96YV:6%D;R(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI
M;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR-`IM<V=I
M9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R(")#<F5A<B!P
M87!E;&5R82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$R.`IM
M<V=I9"`B(@HB0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y
M;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"`B"B)A
M;F0@9&5L971E('-P86TN(@IM<V=S='(@(B(*(D-R96$@<F5G;&%S(&1E(&9I
M;'1R861O('!A<F$@;W)G86YI>F%R(&5L(&-O<G)E;R!E;G1R86YT92P@8VQA
M<VEF:6-A<FQO(&5N("(*(F-A<G!E=&%S('D@96QI;6EN87(@<W!A;2XB"@HC
M.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*;7-G:60@(D-R
M96%T92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R(")#<F5A<B!P;&%N=&EL;&$B
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT-#D*;7-G:60@(D-R
M96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB"FUS9W-T<B`B
M0W)E87(@<&QA;G1I;&QA<R!Y(')E<W!U97-T87,@9&4@9F]R;75L87)I;W,N
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(D%C8V5S;R!A
M8W1U86P@82`E<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P
M-0IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL
M(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(E!E<G-O;F%L:7IA(&-U
M96YT87,@<&%R82!T<F%E<B!C;W)R96\@9&4@;W1R87,@:61E;G1I9&%D97,N
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D-U
M<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"XB"FUS9W-T<B`B4&5R<V]N86QI
M>F%R(&5L(&5N=NUO(&1E(&-O<G)E;RXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!E<G-O
M;F%L:7IA(&QA<R!T87)E87,@82!E:F5C=71A<B!A;"!I;FEC:6%R('-E<VGS
M;B!E;B`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C$W"FUS9VED(")$871?92(*;7-G<W1R(")?1F5C:&$B"@HC.B!M
M97-S86=E+G!H<#HR-S`@=&AR96%D+G!H<#HQ-3,*;7-G:60@(D1A=&4B"FUS
M9W-T<B`B1F5C:&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4P
M"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")296-H87IA9&$B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,C8T"FUS9VED(")$96-L:6YE9#H@(@IM
M<V=S='(@(E)E8VAA>F%D83H@(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z-3,W"FUS9VED(")$969A=6QT(@IM<V=S='(@(E!O<B!O;6ES:?-N
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC
M.C(Q"FUS9VED(")$969A=6QT(%-E87)C:"!&:65L9"(*;7-G<W1R(")#86UP
M;R!D92!B^G-Q=65D82!P;W(@;VUI<VGS;B(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.CDQ,@IM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E
M<FEA.B(*;7-G<W1R(")#<FET97)I;R!D92!C;&%S:69I8V%C:?-N('!O<B!O
M;6ES:?-N.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDR,@IM
M<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B4V5N
M=&ED;R!D92!C;&%S:69I8V%C:?-N('!O<B!O;6ES:?-N.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-3@*;7-G:60@(D1E;&5G871E9"(*;7-G
M<W1R(")$96QE9V%D;R(*"B,Z(&9O;&1E<G,N<&AP.C0P,"!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHR-#0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHR.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G
M:60@(D1E;&5T92(*;7-G<W1R(")%;&EM:6YA<B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0=6)L:6,@2V5Y(@IM<V=S
M='(@(D5L:6UI;F%R(&QA(&-L879E('#Z8FQI8V$@9&4@)7,B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHX-0IM<V=I9"`B1&5L971E($-U<G)E;G0@2V5Y<R(*;7-G<W1R(")%;&EM
M:6YA<B!L87,@8VQA=F5S(&%C='5A;&5S(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G
M<W1R(")%;&EM:6YA<B!C87)P971A*',I(@H*(SH@9F]L9&5R<RYP:'`Z,C<Q
M"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R(")%;&EM
M:6YA<B!C87)P971A<R!S96QE8V-I;VYA9&%S(@H*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C0R"FUS9VED(")$96QE=&4@4W1A=&EO;F5R
M>2(*;7-G<W1R(")%;&EM:6YA<B!P;&%N=&EL;&$B"@HC.B!F;VQD97)S+G!H
M<#HT,#`*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")%
M;&EM:6YA<B!C87)P971A('9I<G1U86PB"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!6
M:7)T=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E<R(*;7-G<W1R(")%;&EM
M:6YA<B!L82!D969I;FEC:?-N(&1E(&-A<G!E=&$@=FER='5A;"!D92`E<R(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B
M1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*
M;7-G<W1R("*_0F]R<F%R(&1E;"!S97)V:61O<B!R96UO=&\@;&]S(&UE;G-A
M:F5S('1R8>UD;W,_(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q
M.0IM<V=I9"`B1&5L971E(&9R;VT@;7D@8V%L96YD87(B"FUS9W-T<B`B475I
M=&%R(&1E(&UI(&%G96YD82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C,V.`IM<V=I9"`B1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@
M870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R("*_16QI;6EN87(@861J
M=6YT;W,@=FEN8W5L861O<R!A;G1I9W5O<R!A;"!I;FEC:6\@9&5L(&UE<S\B
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-3`*;7-G:60@(D1E
M;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/R(*;7-G<W1R("*_16QI;6EN87(@8V%R<&5T87,@7")%;G9I861O<UPB
M(&%N=&EG=6%S(&%L(&EN:6-I;R!D96P@;65S/R(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C8P-0IM<V=I9"`B1&5L971E('-P86T@;65S<V%G
M97,B"FUS9W-T<B`B16QI;6EN87(@;65N<V%J97,@<W!A;2(*"B,Z(&UE<W-A
M9V4N<&AP.C4P-R!M86EL8F]X+G!H<#HW,S4@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L
M971E9"(*;7-G<W1R(")%;&EM:6YA9&\B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@
M(DUE;G-A:F5S(&5L:6UI;F%D;W,B"@HC.B!C;VUP;W-E+G!H<#HU-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@871T86-H;65N="!<(B5S
M7"(N(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!E;"!A9&IU;G1O(%PB)7-<
M(BXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B
M1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<R(*;7-G<W1R(")%;&EM:6YA
M;F1O('D@=')A<VQA9&%N9&\@;65N<V%J97,B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3@W"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B
M1&5N96=A<B!L82!P971I8VGS;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU-#(*;7-G:60@(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N(@IM<V=S='(@(D1E;F5G87(@;&$@<&5T:6-I\VX@9&4@:6YF
M;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HY,C$*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T
M<B`B1&5S8V5N9&5N=&4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-@IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I<&-I\VXB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G
M:60@(D1E=&%I;',B"FUS9W-T<B`B1&5T86QL97,B"@HC.B!C;VUP;W-E+G!H
M<#HU.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ED(&YO="!A='1A8V@@7"(E
M<UPB(&%S('1H92!F:6QE('=A<R!E;7!T>2XB"FUS9W-T<B`B3F\@<V4@:&$@
M861J=6YT861O(%PB)7-<(B!Y82!Q=64@96P@87)C:&EV;R!E<W3A('9A8^UO
M+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C8V-0IM<V=I9"`B
M1&EM('-I9VYA='5R97,_(@IM<V=S='(@(K]!=&5N=6%R(&9I<FUA<S\B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B
M1&ES<&QA>2(*;7-G<W1R(")-;W-T<F%R(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z-#<Y"FUS9VED(")$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A
M9G1E<B!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`BOTUO<W1R87(@=6YA
M(&-O;F9I<FUA8VGS;B!T<F%S(&5N=FEA<B!U;B!M96YS86IE/R(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C8X,PIM<V=I9"`B1&ES<&QA>2!I
M;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B36]S=')A<B!E;B!E;"!C=65R
M<&\@9&5L(&UE;G-A:F4B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HW.#$*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N
M97<@;6%I;#\B"FUS9W-T<B`BOTUO<W1R87(@879I<V\@96UE<F=E;G1E(&1E
M(&-O<G)E;R!N=65V;S\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HW-#<*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP='D@4W!A;5PB(&QI;FL@
M:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(K]-;W-T<F%R(&5L(';M;F-U;&\@
M<'5R9V%R(%PB4W!A;5PB(&5N(&QA(&)A<G)A(&1E(&UE;OIS/R(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C<S.0IM<V=I9"`B1&ES<&QA>2!T
M:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S
M='(@(K]-;W-T<F%R(&5L(';M;F-U;&\@7")686-I87)<(B!P87!E;&5R82!E
M;B!L82!B87)R82!D92!M96[Z<S\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYI;F,Z,3$*;7-G:60@(D1I<W!O<VET:6]N(@IM<V=S='(@
M(D1I<W!O<VEC:?-N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC
M.C(V"FUS9VED(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`B3D\@:&%Y(&-O:6YC
M:61E;F-I87,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ
M-@IM<V=I9"`B1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB
M"FUS9W-T<B`B3F\@8V]M<')O8F%R(&-O<G)E;R!N=65V;R(*"B,Z(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.CDT,0IM<V=I9"`B1&\@;F]T(&=E;F5R
M871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(DYO(&=E
M;F5R87(@=NUN8W5L;R!E;B!L82!C;VQU;6YA($1E.B(*"B,Z(&QI8B])35`N
M<&AP.C$P-3,*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD
M97(_(@IM<V=S='(@(K]$97-E82!A8G)I<B!E<V$@8V%R<&5T83\B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(S,0IM<V=I9"`B1&]N)W0@:&%V
M92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("*_3F\@9&ES<&]N92!D
M92!C=65N=&$_(%-O;&EC[71E;&$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B1&]N92(*;7-G<W1R(")(96-H;R(*
M"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B1&5S
M8V%R9V%R("5S(&5N(&9O<FUA=&\@+GII<"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VAE861E<G,N:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H
M;65N=',@*&EN("YZ:7`@9FEL92DB"FUS9W-T<B`B1&5S8V%R9V%R('1O9&]S
M(&QO<R!A9&IU;G1O<R`H96X@=6X@87)C:&EV;R`N>FEP*2(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS9VED(")$;W=N;&]A9"!&
M;VQD97(H<RDB"FUS9W-T<B`B1&5S8V%R9V%R(&-A<G!E=&$H<RDB"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1&]W;FQO
M860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%TB"FUS9W-T<B`B1&5S8V%R9V%R
M(&-A<G!E=&$H<RD@6V9O<FUA=&\@+GII<%TB"@HC.B!L:6(O34E-12]#;VYT
M96YT<RYP:'`Z,C$V"FUS9VED(")$;W=N;&]A9"!I;B`N>FEP($9O<FUA="(*
M;7-G<W1R(")$97-C87)G87(@96X@9F]R;6%T;R`N>FEP(@H*(SH@;65S<V%G
M92YP:'`Z-3`U(&UA:6QB;W@N<&AP.C<Q-"!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T
M(@IM<V=S='(@(D)O<G)A9&]R(@H*(SH@9F]L9&5R<RYP:'`Z,S<S"FUS9VED
M(")$<F%F="!F;VQD97(B"FUS9W-T<B`B0V%R<&5T82!D92!B;W)R861O<F5S
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS
M9VED(")$<F%F=',@9F]L9&5R.B(*;7-G<W1R(")#87)P971A(&1E(&)O<G)A
M9&]R97,Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I9"`B
M12UM86EL($%D9')E<W,B"FUS9W-T<B`B0V]R<F5O(&5L96-T<O-N:6-O(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,P,@IM<V=I9"`B14Y$(@IM<V=S='(@(D9)
M3D%,(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@
M(D524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB
M"FUS9W-T<B`B15)23U(Z($YO('-E('!U961E(&5N=FEA<B!E;"!M96YS86IE
M+B(*"B,Z(&9O;&1E<G,N<&AP.C0P,2!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,3D*;7-G:60@(D5D:70B"FUS9W-T<B`B36]D:69I8V%R(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET
M($)L86-K;&ES="(*;7-G<W1R(")-;V1I9FEC87(@;&ES=&$@;F5G<F$B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@
M1FEL=&5R<R(*;7-G<W1R(")-;V1I9FEC87(@9FEL=')O<R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C$V"FUS9VED(")%9&ET(%-E87)C:"!1=65R>2(*;7-G<W1R
M(")-;V1I9FEC87(@8V]N<W5L=&$@9&4@8OIS<75E9&$B"@HC.B!F;VQD97)S
M+G!H<#HT,#$@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$W"FUS9VED
M(")%9&ET(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(DUO9&EF:6-A<B!C87)P
M971A('9I<G1U86PB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC
M.C$S"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@
M1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B36]D:69I8V%R(&QA(&1E9FEN
M:6-I\VX@9&4@8V%R<&5T82!V:7)T=6%L(&1E("5S(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*
M;7-G<W1R(")-;V1I9FEC87(@;&ES=&$@8FQA;F-A(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET('EO=7(@8FQA8VML
M:7-T(@IM<V=S='(@(DUO9&EF:6-A<B!L82!L:7-T82!N96=R82(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM<V=I9"`B161I="!Y;W5R
M(&9I;'1E<B!R=6QE<R(*;7-G<W1R(")-;V1I9FEC87(@;&%S(')E9VQA<R!D
M92!F:6QT<F%D;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C@U
M,`IM<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@
M;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B36]D:69I8V%R(&QA<R!O
M<&-I;VYE<R!P87)A(&%C8V5D97(@82!O=')A<R!C=65N=&%S(&1E(&-O<G)E
M;RXB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@
M(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B36]D:69I8V%R(&QA(&QI
M<W1A(&)L86YC82(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D1I<F5C8VGS
M;B!D92!C;W)R96\B"@HC.B!L:6(O365S<V%G92YP:'`Z-CDW"B,L('!H<"UF
M;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM
M<V=S='(@(E-E(&AA;B!E;&EM:6YA9&\@=&]D;W,@;&]S(&UE;G-A:F5S(&1E
M("5S+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-S,*;7-G:60@(D5M<'1I960@
M86QL(&UE<W-A9V5S(&9R;VT@5FER='5A;"!4<F%S:"!&;VQD97(N(@IM<V=S
M='(@(E-E(&AA;B!E;&EM:6YA9&\@=&]D;W,@;&]S(&UE;G-A:F5S(&1E(&QA
M(%!A<&5L97)A('9I<G1U86PN(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,C(*;7-G:60@(D5M<'1Y($9O;&1E<BAS*2(*;7-G<W1R(")6
M86-I87(@8V%R<&5T82AS*2(*"B,Z(&9O;&1E<G,N<&AP.C(W,@IM<V=I9"`B
M16UP='D@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R(")686-I87(@8V%R<&5T
M87,@<V5L96-C:6]N861A<R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C,Y"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`B
M5F%C:6%R(@H*(SH@;&EB+TE-4"YP:'`Z.30Y"FUS9VED(")%;7!T>2!?4W!A
M;2(*;7-G<W1R(")3<&%M("A?;BDB"@HC.B!L:6(O24U0+G!H<#HY-#(*;7-G
M:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R(")686-I87(@*%]X*2(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ('1E;7!L871E<R]P9W`O;F]T86-T:79E
M+FEN8SHV"FUS9VED(")%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S
M='(@(K]!8W1I=F%R(&-A<&%C:61A9"!01U`_(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHQ('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC
M.C8*;7-G:60@(D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\B"FUS9W-T
M<B`BOT%C=&EV87(@8V%P86-I9&%D(%,O34E-13\B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HX,#`*;7-G:60@(D5N86)L92!M97-S86=E('!R
M979I97=S/R(*;7-G<W1R("*_06-T:79A<B!V:7-T87,@<')E=FEA<R!D92!M
M96YS86IE<S\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M,SD*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B7T]P8VEO
M;F5S(&1E(&-I9G)A9&\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N
M:6YC.C$X"FUS9VED(")%;F-R>7!T960B"FUS9W-T<B`B0VEF<F%D;R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,38@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Q.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4Q
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3,*;7-G:60@(D5N9"(*;7-G
M<W1R(")&:6YA;"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.34*;7-G:60@(D5N
M9"!F;W)W87)D960@;65S<V%G92(*;7-G<W1R(")497)M:6YA<B!M96YS86IE
M(')E96YV:6%D;R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-3(*;7-G:60@(D5N
M9"!M97-S86=E(@IM<V=S='(@(E1E<FUI;F%R(&UE;G-A:F4B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D5N9"!M97-S
M86=E(&9R;VT@)7,B"FUS9W-T<B`B5&5R;6EN87(@;65N<V%J92!D92`E<R(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<W"FUS9VED(")%;G1E<B!087-S<&AR87-E(@IM<V=S='(@
M(DEN=')O9'5Z8V$@;&$@9G)A<V4@8VQA=F4B"@HC.B!T96UP;&%T97,O<')E
M9G,O<W!A;7-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R
M('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(DEN=')O9'5Z8V$@96P@
M;F]M8G)E(&1E(&QA(&-A<G!E=&$@9&4@<W!A;2(*"B,Z('1E;7!L871E<R]P
M<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(DEN=')O9'5Z
M8V$@96P@;F]M8G)E(&1E(&QA(&YU979A(&-A<G!E=&$@9&4@8F]R<F%D;W)E
M<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*
M;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@
M9F]L9&5R(@IM<V=S='(@(DEN=')O9'5Z8V$@96P@;F]M8G)E(&1E(&QA(&YU
M979A(&-A<G!E=&$@9&4@8V]R<F5O(&5N=FEA9&\B"@HC.B!T96UP;&%T97,O
M<')E9G,O=')A<VAS96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B26YT<F]D=7IC
M82!E;"!N;VUB<F4@9&4@;&$@;G5E=F$@<&%P96QE<F$B"@HC.B!L:6(O4V5A
M<F-H+G!H<#HV,3,*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(E1O
M9&\@96P@;65N<V%J92(*"B,Z(&UE<W-A9V4N<&AP.C$Y-2!C;VUP;W-E+G!H
M<#HQ,3<R('1H<F5A9"YP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT
M<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E
M<W,@8F]O:R(*;7-G<W1R("(B"B)392!H82!A\6%D:61O(&-O<G)E8W1A;65N
M=&4@96P@<F5G:7-T<F\@7"(E<UPB(&$@;&$@;&EB<F5T82!D:7)E8V-I;VYE
M<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,S@Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,`HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R<F]R(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HT,S$@;&EB+TE-05`O0VQI96YT+G!H<#HT-30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E
M<G9E<BX@)7,@.B`E<RXB"FUS9W-T<B`B17)R;W(@86P@8V]N96-T87(@86P@
M<V5R=FED;W(@24U!4"X@)7,@.B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,S$P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM
M<V=S='(@(D5R<F]R(&%L(&5N=FEA<B!L82!R97-P=65S=&$Z("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#(*;7-G:60@(D5V96YT('-U
M8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@
M8V]R<F5C=&%M96YT92!E;"!A8V]N=&5C:6UI96YT;RXB"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HW-S$*;7-G:60@(D5V97)Y(#$U(&UI;G5T
M97,B"FUS9W-T<B`B0V%D82`Q-2!M:6YU=&]S(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z-S8X"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM
M<V=S='(@(D-A9&$@,S`@<V5G=6YD;W,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HW-S`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R
M(")#861A(#4@;6EN=71O<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C<W,@IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D-A9&$@
M;65D:6$@:&]R82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C<V
M.0IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(D-A9&$@;6EN=71O(@H*
M(SH@9F]L9&5R<RYP:'`Z-#,X"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B17AP
M86YD:7(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM
M<V=I9"`B17AP86YD($%L;"(*;7-G<W1R(")%>'!A;F1I<B!T;V1A<R(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")%>'!A
M;F0@06QL($9O;&1E<G,B"FUS9W-T<B`B17AP86YD:7(@=&]D87,@;&%S(&-A
M<G!E=&%S(@H*(SH@9F]L9&5R<RYP:'`Z-#,X"FUS9VED(")%>'!A;F0@1F]L
M9&5R(@IM<V=S='(@(D5X<&%N9&ER(&-A<G!E=&$B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C4S"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T<B`B17AP
M86YD:7(@;F]M8G)E<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$P-3(*;7-G:60@(D5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD
M;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\B"FUS9W-T<B`B
M(@HBOT5X<&%N9&ER(&%U=&]MX71I8V%M96YT92!C;VUO('1A<F5A(&1E(&9O
M;F1O(&QO<R!N;VUB<F5S(&5N(&QA('9E;G1A;F$@9&4@(@HB<F5D86-C:?-N
M/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B
M17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T
M:&4@9F]L9&5R<R!V:65W/R(*;7-G<W1R(")0;W(@;VUI<VGS;BP@OV5X<&%N
M9&ER(&5L(.%R8F]L(&5N=&5R;R!E;B!L82!V:7-T82!D92!C87)P971A<S\B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(T-2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z,3`Q"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V5?97AP86YD
M+FIS.C0Y"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T<B`B17AP86YD:65N9&\B
M"@HC.B!L:6(O24U0+G!H<#HY-C`@;&EB+TE-4"YP:'`Z.38R"FUS9VED(")&
M7V5T8V@@36%I;"(*;7-G<W1R(")?5')A97(B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C8@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,3`T"FUS9VED(")&971C:"!-86EL(@IM<V=S='(@(E1R865R(&-O
M<G)E;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C@U.`IM<V=I
M9"`B1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B
MOU1R865R(&-O<G)E;R!E;B!U;F$@=F5N=&%N82!S97!A<F%D83\B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#8*;7-G:60@(D9E=&-H
M(&UE<W-A9V5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`BOU1R865R(&UE
M;G-A:F5S(&%L(&EN:6-I87(@<V5S:?-N/R(*"B,Z(&QI8B]&971C:&UA:6PN
M<&AP.C(Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D("5D(&UE<W-A
M9V5S(&9R;VT@)7,B"FUS9W-T<B`B4V4@:&%N('1R8>UD;R`E9"!M96YS86IE
M<R!D92`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S(@IM<V=S='(@
M(E-E(&AA('1R8>UD;R`Q(&UE;G-A:F4@9&4@)7,B"@HC.B!L:6(O1F5T8VAM
M86EL+G!H<#HR.#<@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y(&QI8B]&971C:&UA
M:6PN<&AP.C(Y,0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B5')A97(@
M8V]R<F5O.B`B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3,*;7-G:60@(D9E
M=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")&971C:&UA:6PZ
M(&YO(&AA>2!M96YS86IE<R!N=65V;W,N(@H*(SH@;&EB+TE-4"YP:'`Z.38V
M"FUS9VED(")&:5]L=&5R<R(*;7-G<W1R(")?1FEL=')O<R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-B!T96UP;&%T97,O8V]M<&]S
M92]A='1A8VAM96YT<RYJ<SHT,`IM<V=I9"`B1FEL92(*;7-G<W1R(")!<F-H
M:79O(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"FUS9VED
M(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYE<R!D92!F:6QT<F%D
M;R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHY"FUS9VED(")&
M:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`B0V]N9FEG=7)A8VGS;B!D92!F:6QT
M<F%D;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C4X.`IM<V=I
M9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*;7-G
M<W1R("*_1FEL=')A<B!C;VYT96YI9&\@;V)S8V5N;R!E;B!E;"!M96YS86IE
M/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,3$*;7-G
M:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M
M+B(*;7-G<W1R(")%;B!E<W1E('-I<W1E;6$@<V4@:&$@9&5S:&%B:6QI=&%D
M;R!E;"!S;W!O<G1E(&1E(&9I;'1R861O+B(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT
M<F]S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHS"FUS
M9VED(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B3&]S(&9I;'1R;W,@
M3D\@97-TX6X@86-T:79O<R(*"B,Z(&QI8B]&:6QT97(N<&AP.C$S,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4B
M"FUS9W-T<B`B1FEL=')O<SH@<.%G:6YA(&1E(&=E<W1I\VX@9&4@)7,B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B
M1FEN9"(*;7-G<W1R(")%;F-O;G1R87(B"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HX.30*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G
M<W1R(")0<FEM97)A('#A9VEN82!D96P@8G5Z\VXB"@HC.B!M86EL8F]X+G!H
M<#HS,S$*;7-G:60@(D9I<G-T(%!A9V4B"FUS9W-T<B`B4')I;65R82!PX6=I
M;F$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,34@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O
M7W)W87)D(@IM<V=S='(@(E)E96Y?=FEA<B(*"B,Z(&9O;&1E<G,N<&AP.C(U
M,B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HU"FUS
M9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R(")!
M8V-I;VYE<R!D92!C87)P971A("T@0V]N9FER;6%C:?-N(@H*(SH@9F]L9&5R
M<RYP:'`Z,C@Y('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD*(SH@=&5M
M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L
M871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O
M;&1E<B!.879I9V%T;W(B"FUS9W-T<B`B3F%V96=A9&]R(&1E(&-A<G!E=&%S
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D9O;&1E<B!3
M=6UM87)Y(@IM<V=S='(@(E)E<W5M96X@9&4@;&$@8V%R<&5T82(*"B,Z(&%C
M;"YP:'`Z,C,*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D
M+B(*;7-G<W1R(").;R!S92!H82!A8W1I=F%D;R!L82!C;VUP87)T:6-I\VX@
M9&4@8V%R<&5T87,N(@H*(SH@9F]L9&5R<RYP:'`Z-#<*;7-G:60@(D9O;&1E
M<B!U<V4@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(DYO('-E(&AA(&%C=&EV
M861O(&5L('5S;R!D92!C87)P971A<RXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HY-3@*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S
M(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y
M(@IM<V=S='(@(D9O<FUA=&\@9&4@9F5C:&$@9&4@;&]S(&UE;G-A:F5S(&9E
M8VAA9&]S(&AO>2!E;B!L82!V:7-T82!D92!B=7IO;F5S(@H*(SH@8V]M<&]S
M92YP:'`Z.#(P('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I
M9"`B1F]R=V%R9"(*;7-G<W1R(")2965N=FEA<B(*"B,Z(&-O;7!O<V4N<&AP
M.C@P-0IM<V=I9"`B1F]R=V%R9#HB"FUS9W-T<B`B4F5E;G9I87(Z(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,X,`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4B
M"FUS9W-T<B`B365N<V%J92!R965N=FEA9&\B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S<X"B,L('!H<"UF;W)M870*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E
M(&9R;VT@)7,B"FUS9W-T<B`B365N<V%J92!R965N=FEA9&\@9&4@)7,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`R"FUS9VED(")&<F5E+T)U
M<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R(")297-P=65S=&$@82!P971I
M8VGS;B!D92!T:65M<&\@9&ES<&]N:6)L92(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R;U]M(@IM<V=S
M='(@(E]$92(*"B,Z(&UE<W-A9V4N<&AP.C(W,2!T:')E860N<&AP.C$U-"!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H
M+G!H<#HU.#D*;7-G:60@(D9R;VTB"FUS9W-T<B`B1&4B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(D9R;VT@061D<F5S<R(*
M;7-G<W1R(")0;W(@<F5M:71E;G1E(@H*(SH@8V]M<&]S92YP:'`Z.#$W(&-O
M;7!O<V4N<&AP.C@R,0IM<V=I9"`B1G=D.B(*;7-G<W1R(")&=V0Z(@H*(SH@
M8V]M<&]S92YP:'`Z,3,Q,0IM<V=I9"`B1G=D.B`B"FUS9W-T<B`B1G=D.B`B
M"@HC.B!C;VUP;W-E+G!H<#HQ,S$S"B,L('!H<"UF;W)M870*;7-G:60@(D9W
M9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(D9W9#H@)74@;65N
M<V%J97,@<F5E;G9I861O<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C$S(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(R"B,Z(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.C,P(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C,X"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS9W-T<B`B3W!C
M:6]N97,@9V5N97)A;&5S(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0
M(&]N;'DI(@IM<V=S='(@(K]4<F%E<B!S\VQO(&UE;G-A:F5S(&YU979O<S\@
M*'/S;&\@24U!4"DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHS,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34T"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,C@*;7-G:60@(D=O(@IM<V=S='(@(DER(@H*
M(SH@=&AR96%D+G!H<#HQ,S8*;7-G:60@(D=O('1O($UE<W-A9V4B"FUS9W-T
M<B`B27(@86P@;65N<V%J92(*"B,Z(&QI8B])35`N<&AP.C4P,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")';R!T;R!A9&1R97-S(&)O;VL@96YT<GD@;V8@7"(E
M<UPB(@IM<V=S='(@(DER(&%L(')E9VES=')O(&1E(%PB)7-<(B!E;B!L82!L
M:6)R971A(&1E(&1I<F5C8VEO;F5S(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$S-@IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(D-O;F-E9&5R
M(&%C8V5S;R(*"B,Z(&UE<W-A9V4N<&AP.C4U,"!L:6(O1FEL=&5R+G!H<#HQ
M,S$@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.C$Q,2!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ,3,*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T(&QI
M8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,3D*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A
M=&EO;BYP:'`Z-C@*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"B,Z(&QI8B]-24U%+U9I
M97=E<B]A<'!L961O=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,3<R"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R,"!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%4D4B"FUS9W-T
M<B`B05%5S2(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS
M,2!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3(P"B,Z(&QI8B]-24U%+U9I
M97=E<B]R96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,
M(@H*(SH@8V]M<&]S92YP:'`Z,C8P"FUS9VED(")(5$U,(%9E<G-I;VX@;V8@
M365S<V%G92(*;7-G<W1R(")697)S:?-N($A434P@9&5L(&UE;G-A:F4B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU.`IM<V=I9"`B2&5A
M9&5R<R(*;7-G<W1R(")#86)E8V5R87,B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@=&AE(&UE<W-A9V4@
M>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R(")!<77M('1I96YE(&5L(&UE
M;G-A:F4@<75E(&5S=&%B82!R961A8W1A;F1O.B(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C8U-@IM<V=I9"`B2&ED9&5N(@IM<V=S='(@(D]C
M=6QT;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C8U-0IM<V=I
M9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(D]C=6QT;R!E;B!L
M82!V:7-T82!D92!S96-U96YC:6%S(@H*(SH@;6%I;&)O>"YP:'`Z,S4S"FUS
M9VED(")(:61E($1E;&5T960B"FUS9W-T<B`B3V-U;'1A<B!E;&EM:6YA9&]S
M(@H*(SH@9F]L9&5R<RYP:'`Z,C@T"FUS9VED(")(:61E(%5N<W5B<V-R:6)E
M9"(*;7-G<W1R(")/8W5L=&%R(&YO('-U<V-R:71O<R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-`IM<V=I9"`B2&EG:"(*;7-G<W1R
M(")!;'1A(@H*(SH@;65S<V%G92YP:'`Z,S`U(&UA:6QB;W@N<&AP.C<Q.2!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H(%!R
M:6]R:71Y(@IM<V=S='(@(E!R:6]R:61A9"!A;'1A(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDS"FUS9VED(")(:6=H97-T(@IM<V=S
M='(@(D5L979A9&$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HV
M.#4*;7-G:60@(DAO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE
M;G1S/R(*;7-G<W1R("*_0_-M;R!D97-E82!M;W-T<F%R(&QO<R!A9&IU;G1O
M<S\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU,#0*;7-G:60@
M(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS
M9W-T<B`B0_-M;R!R97-A;'1A<B!L87,@;.UN96%S(&-I=&%D87,@96X@=6YA
M(')E<W!U97-T82(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3,T"FUS
M9VED("))34%0(@IM<V=S='(@(DE-05`B"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS
M*2(*;7-G<W1R("))34%0("A!=71O9&5T96-C:?-N(&1E('!R;W1O8V]L;W,I
M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!397)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B!397)V
M97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R(")%;"!S97)V:61O<B!)34%0(&AA
M(&-E<G)A9&\@;&$@8V]N97AI\VXN($5L('-E<G9I9&]R(&1I:F\Z("5S(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C4@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB"FUS9W-T<B`B
M24U!4"!S;V)R92!34TPB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$U
M,@IM<V=I9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A
M=&4I(@IM<V=S='(@(DE-05`@<V]B<F4@4U-,("AC97)T:69I8V%D;R!A=71O
M+69I<FUA9&\I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C8*
M;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R("))
M34%0('-O8G)E(%-33"`H875T;RUF:7)M861O*2(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z,S8X"FUS9VED("))34%0('-E<G9E<B!C;&]S960@=&AE(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(D5L('-E<G9I9&]R($E-05`@:&$@8V]R=&%D
M;R!L82!C;VYE>&GS;BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C$V-"!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@
M;F\@5$Q3(@IM<V=S='(@(DE-05`L('-I;B!43%,B"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C0Y"FUS9VED("))34%0+U!/4#,@36%I;"!397)V97)S
M(@IM<V=S='(@(E-E<G9I9&]R97,@9&4@8V]R<F5O($E-05`O4$]0,R(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@
M;W(@5$Q3+"!Y;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I
M;VX@;&]A9&5D+B(*;7-G<W1R(")3:2!S92!U=&EL:7IA(%-33"!O(%1,4R!N
M96-E<VET82!C87)G87(@;&$@97AT96YS:?-N(%!(4"!O<&5N<W-L+B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"FUS
M9VED("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L
M9&5R*',I('=I;&P@8F4@;&]S="$B"FUS9W-T<B`B4VD@<VEG=64L(*%T;V1O
M<R!L;W,@;65N<V%J97,@9&4@;&$H<RD@8V%R<&5T82AS*2!S92!P97)D97+A
M;B$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#(*;7-G
M:60@(DEG;F]R92(*;7-G<W1R("))9VYO<F%R(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C@S"FUS9VED("))9VYO<F4@06QL(@IM<V=S
M='(@(DEG;F]R87(@=&]D87,B"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A
M=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`B26UA9V5N(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,`IM<V=I9"`B26UP
M;W)T(@IM<V=S='(@(DEM<&]R=&%R(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M-C4*;7-G:60@(DEM<&]R="!+97DB"FUS9W-T<B`B26UP;W)T87(@8VQA=F4B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y"FUS9VED("));7!O<G0@
M2V5Y<&%I<B(*;7-G<W1R("));7!O<G1A<B!C;&%V97,B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PIM<V=I9"`B26UP;W)T($UE<W-A
M9V5S(@IM<V=S='(@(DEM<&]R=&%R(&UE;G-A:F5S(@H*(SH@<&=P+G!H<#HT
M,0IM<V=I9"`B26UP;W)T(%!'4"!+97DB"FUS9W-T<B`B26UP;W)T87(@8VQA
M=F4@4$=0(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0IM<V=I
M9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@(DEM<&]R
M=&%R(&-E<G1I9FEC861O('!E<G-O;F%L(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHQ-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>2(*;7-G<W1R("));7!O<G1A<B!C;&%V92!P97)S;VYA;"!0
M1U`@<')I=F%D82(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M.0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S
M='(@(DEM<&]R=&%R(&-L879E('!E<G-O;F%L(%!'4"!P^F)L:6-A(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R
M="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S(@IM<V=S='(@(DEM<&]R
M=&%R(&-E<G1I9FEC861O<R!P97)S;VYA;&5S(%,O34E-12(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C0R"FUS9VED("));7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("));7!O<G1A
M<B!C;&%V92!P^F)L:6-A(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B
M26UP;W)T87(@8VQA=F4@4$=0('#Z8FQI8V$B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)
M344@2V5Y(@IM<V=S='(@(DEM<&]R=&%R(&-L879E(%,O34E-12!P^F)L:6-A
M(@H*(SH@<VUI;64N<&AP.C$V"FUS9VED("));7!O<G0@4R]-24U%($ME>2(*
M;7-G<W1R("));7!O<G1A<B!C;&%V92!3+TU)344B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]I;7!O<G0N:6YC.CD*;7-G:60@(DEM<&]R="!M8F]X($9I;&4B
M"FUS9W-T<B`B26UP;W)T87(@87)C:&EV;R!M8F]X(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O:6UP;W)T+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G<W1R("))
M;7!O<G1A<B!E;"!A<F-H:79O(&UB;W@@)7,@82!L82!C87)P971A("5S+B(*
M"B,Z(&UE<W-A9V4N<&AP.C4P-B!M86EL8F]X+G!H<#HW,CD@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS,PHC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G
M:60@(DEM<&]R=&%N="(*;7-G<W1R("));7!O<G1A;G1E(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT(&UE<W-A
M9V5S(@IM<V=S='(@(DUE;G-A:F5S(&EM<&]R=&%N=&5S(@H*(SH@9F]L9&5R
M<RYP:'`Z,34Q"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D("5D(&UE
M<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(DEM<&]R=&%D;W,@)60@;65N<V%J
M97,@9&4@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V-@IM
M<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R(")0<F]C97-A;F1O(@H*(SH@9F]L
M9&5R<RYP:'`Z,S8U('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C
M="YI;F,Z,30@;&EB+T9O;&1E<BYP:'`Z.#8*(SH@;&EB+T9O;&1E<BYP:'`Z
M,C$Q(&QI8B])35`N<&AP.C@S,"!L:6(O24U!4"]4<F5E+G!H<#HQ,3D*(SH@
M;&EB+TE-05`O5')E92YP:'`Z,C(R"FUS9VED("));F)O>"(*;7-G<W1R(")%
M;G1R861A(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-#DR"FUS
M9VED("));F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN
M(&$@<F5P;'D_(@IM<V=S='(@(K]);F-L=6ER('5N(')E<W5M96X@9&4@;&$@
M8V%B96-E<F$@96X@;&$@<F5S<'5E<W1A/R(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S
M86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(K]);F-L=6ER(&UE;G-A:F4@;W)I
M9VEN86P@96X@;&$@<F5S<'5E<W1A/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$S,`IM<V=I9"`B26YF;R(*;7-G<W1R("));F9O<FUA8VGS;B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(DEN9F]R;6%T:6]N(&]N("5S
M(%!U8FQI8R!+97DB"FUS9W-T<B`B26YF;W)M86-I\VX@9&4@;&$@8VQA=F4@
M</IB;&EC82!D92`E<R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM
M<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS
M9W-T<B`B26YF;W)M86-I\VX@9&4@;&$@8VQA=F4@<&5R<V]N86P@<')I=F%D
M82(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA
M;"!0=6)L:6,@2V5Y(@IM<V=S='(@(DEN9F]R;6%C:?-N(&1E(&QA(&-L879E
M('!E<G-O;F%L('#Z8FQI8V$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYI;F,Z,34@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-3`Q"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C4V"FUS
M9VED("));FQI;F4B"FUS9W-T<B`B16X@;.UN96$B"@HC.B!T96UP;&%T97,O
M<VUI;64O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I9FEC
M871E($AE<F4B"FUS9W-T<B`B26YS97)T87(@87%U[2!E;"!C97)T:69I8V%D
M;R(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,34*;7-G:60@
M(DEN<V5R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R92(*;7-G<W1R
M("));G-E<G1A<B!A<77M(&QA(&-L879E('!E<G-O;F%L(%!'4"!P<FEV861A
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B
M26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B
M26YS97)T87(@87%U[2!L82!C;&%V92!P97)S;VYA;"!01U`@</IB;&EC82(*
M"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-0IM<V=I9"`B26YS
M97)T(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B26YS97)T87(@87%U
M[2!L82!C;&%V92!01U`@</IB;&EC82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT,3,*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O
M<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`B4V4@:&$@<V5L96-C:6]N861O
M('5N82!A8V-I\VX@;F\@=N%L:61A('!A<F$@97-T92!C;VUP;VYE;G1E+B(*
M"B,Z(&UA:6QB;W@N<&AP.C4W-2!M86EL8F]X+G!H<#HV,C(*;7-G:60@(DEN
M=F%L:60@061D<F5S<R(*;7-G<W1R("),82!D:7)E8V-I\VX@;F\@97,@=N%L
M:61A(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HS,#<*;7-G:60@(DEN
M=F%L:60@4F5M;W1E($UA:6QB;W@B"FUS9W-T<B`B16P@8G5Z\VX@<F5M;W1O
M(&YO(&5S(';A;&ED;R(*"B,Z(&-O;7!O<V4N<&AP.C$U.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S
M<SH@)7,N(@IM<V=S='(@(D-A<F%C=&5R97,@;F\@=N%L:61O<R!E;B!L82!D
M:7)E8V-I\VX@9&4@8V]R<F5O.B`E<RXB"@HC.B!S;6EM92YP:'`Z-S@@<&=P
M+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K97DB"FUS9W-T<B`B0VQA=F4@;F\@
M=N%L:61A(@H*(SH@<&=P+G!H<#HQ.3(*;7-G:60@(DEN=F%L:60@<&5R<V]N
M86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R(")#;&%V92!P97)S;VYA;"!0
M1U`@<')I=F%D82!N;R!VX6QI9&$B"@HC.B!P9W`N<&AP.C$V-PIM<V=I9"`B
M26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T<B`B0VQA
M=F4@<&5R<V]N86P@4$=0('#Z8FQI8V$@;F\@=N%L:61A(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B26YV97)T(@IM<V=S
M='(@(DEN=F5R=&ER(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-3DQ"FUS9VED(")+0B(*;7-G<W1R(")+0B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B5&%M
M8?%O(&1E(&-L879E(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM
M<V=I9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@
M=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N
M/R(*;7-G<W1R("(B"B),82!G96YE<F%C:?-N(&1E(&QA<R!C;&%V97,@<'5E
M9&4@=&%R9&%R(&)A<W1A;G1E('1I96UP;RX@OT-O;G1I;G5A<B!C;VX@;&$@
M(@HB9V5N97)A8VGS;B!D92!L87,@8VQA=F5S/R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS
M9VED(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D
M(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"B).
M;R!S92!D:7-P;VYE(&1E(&EM<&]R=&%C:?-N(&1E(&-L879E<RX@17-T92!S
M97)V:61O<B!N;R!T:65N92!A8W1I=F%D82!L82`B"B)C87)G82!D92!A<F-H
M:79O<RXB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N
M;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE
M9"!T;R!A9&0@>6]U<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@HB3F\@<V4@
M9&ES<&]N92!D92!I;7!O<G1A8VGS;B!D92!C;&%V97,N($YO(&AA(&1E9FEN
M:61O('5N82!L:6)R971A(&1E("(*(F1I<F5C8VEO;F5S(&$@;&$@<75E(&'Q
M861I<B!L;W,@8V]N=&%C=&]S+B(*"B,Z('!G<"YP:'`Z,S$T"FUS9VED(")+
M97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(D-L879E(&5N=FEA9&$@8V]R<F5C=&%M96YT92!A;"!S97)V
M:61O<B!D92!C;&%V97,@</IB;&EC;RXB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(Q-0IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B261I;VUA
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#DU"FUS9VED("),
M87-T($UA:6QB;W@@4&%G92(*;7-G<W1R("+:;'1I;6$@<.%G:6YA(&1E;"!B
M=7KS;B(*"B,Z(&UA:6QB;W@N<&AP.C,T-`IM<V=I9"`B3&%S="!086=E(@IM
M<V=S='(@(MIL=&EM82!PX6=I;F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU-#D*;7-G:60@(DQI;FL@071T86-H;65N=',_(@IM<V=S
M='(@(K]6:6YC=6QA<B!A9&IU;G1O<S\B"@HC.B!A='1A8VAM96YT+G!H<#HS
M-"!L:6(O0V]M<&]S92YP:'`Z,3`X-`IM<V=I9"`B3&EN:V5D(&%T=&%C:&UE
M;G1S(&%R92!F;W)B:61D96XN(@IM<V=S='(@(DYO('-E('!E<FUI=&5N(&%D
M:G5N=&]S('9I;F-U;&%D;W,N(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Q,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,B
M"FUS9W-T<B`B3&]S(';M;F-U;&]S(&5X<&ER87+A;B!E;"`E<R(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P-S$*;7-G:60@(B(*(DQI<W0@
M86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N
M/R`H:68@9&ES86)L960L('EO=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S
M('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@HB
MOTQI<W1A<B!T;V1O<R!L;W,@8V]N=&%C=&]S(&%L(&-A<F=A<B!L82!P86YT
M86QL82!D92!C;VYT86-T;W,_("A3:2!E<W3A("(*(F1E<VAA8FEL:71A9&\L
M('/S;&\@=F5RX2!L;W,@8V]N=&%C=&]S('%U92!B=7-Q=64@9&4@9F]R;6$@
M97AP;.UC:71A*2(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C8X
M,@IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A9&5R(@IM<V=S='(@(DQI<W1A
M<B!E;B!L82!C86)E8V5R82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHS,`IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`B0G5Z
M\VX@;&]C86PZ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W,0IM
M<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B56)I8V%C:?-N(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C0*;7-G:60@(DQO9R!I;B(*;7-G<W1R
M("));FEC:6%R('-E<VGS;B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O("5S(@IM<V=S='(@
M(DEN:6-I87(@<V5S:?-N(&5N("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,S@*;7-G:60@(DQO9VEN(@IM<V=S='(@(DEN:6-I87(@<V5S
M:?-N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@
M(DQO9VEN(%1A<VMS(@IM<V=S='(@(E1A<F5A<R!D92!I;FEC:6\@9&4@<V5S
M:?-N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDV"FUS
M9VED("),;W<B"FUS9W-T<B`B0F%J82(*"B,Z(&UE<W-A9V4N<&AP.C,P-R!M
M86EL8F]X+G!H<#HW,C(@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ
M,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(E!R:6]R:61A9"!B86IA
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED
M("),;W=E<W0B"FUS9W-T<B`B4F5D=6-I9&$B"@HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0T"FUS9VED(")-86-I;G1O<V@@1FEL92(*
M;7-G<W1R(")!<F-H:79O($UA8VEN=&]S:"(*"B,Z('1E;7!L871E<R]S;6EM
M92]P87-S<&AR87-E+FEN8SHQ,PIM<V=I9"`B36%I;"(*;7-G<W1R(")#;W)R
M96\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B
M36%I;"!0<F5V:65W<R(*;7-G<W1R(")6:7-T87,@<')E=FEA<R!D92!C;W)R
M96\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM
M<V=S='(@(E1I<&\@9&4@<V5R=FED;W(@9&4@8V]R<F5O(&%L('%U92!C;VYE
M8W1A<G-E.B(*"B,Z(&9O;&1E<G,N<&AP.C,V.2!F;VQD97)S+G!H<#HS.#,*
M;7-G:60@(DUA:6QB;W@B"FUS9W-T<B`B0G5Z\VXB"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HQ,3$*;7-G:60@(DUA:6QB;W@@86YD($9O;&1E
M<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N97,@9&4@=FES=6%L
M:7IA8VGS;B!D92!B=7IO;F5S('D@8V%R<&5T87,B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@365S<V%G
M97,@:6X@1F]L9&5R(&%S(%-E96XB"FUS9W-T<B`B36%R8V%R(&QO<R!M96YS
M86IE<R!D92!L82!C87)P971A(&-O;6\@;&7M9&]S(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL($UE<W-A
M9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T<B`B36%R8V%R(&QO<R!M
M96YS86IE<R!D92!L82!C87)P971A(&-O;6\@<VEN(&QE97(B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C4@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHS,`IM<V=I9"`B36%R:R!A<SHB"FUS9W-T
M<B`B36%R8V%R(&-O;6\Z(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z-C,X"FUS9VED(")-87)K(&1I9F9E<F5N="!L979E;',@;V8@<75O=&EN
M9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_(@IM<V=S='(@(K]297-A;'1A<B!N
M:79E;&5S(&1E(&-I=&%S(&-O;B!C;VQO<F5S(&1I<W1I;G1O<S\B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*;7-G:60@(DUA<FL@
M;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS9W-T<B`BOTUA<F-A
M<B!M96YS86IE<R!C;VUO(&QE:61O<S\@*%/S;&\@24U!4"DB"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HV-#8*;7-G:60@(DUA<FL@<VEM<&QE
M(&UA<FMU<#\B"FUS9W-T<B`BOU)E<V%L=&%R(&UA<F-A9&]R('-I;7!L93\B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#D*;7-G:60@(DUA
M=&-H($%L;"!1=65R:65S(@IM<V=S='(@(D-O:6YC:61I<B!E;B!T;V1A<R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT-0IM<V=I9"`B36%T
M8V@@06YY(%%U97)Y(@IM<V=S='(@(D-O:6YC:61I<B!E;B!C=6%L<75I97)A
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`W"FUS9VED
M(")-87AI;75M($%T=&%C:&UE;G0@4VEZ92(*;7-G<W1R(")486UA\6\@;>%X
M:6UO(&1E(&%D:G5N=&\B"@HC.B!L:6(O87!I+G!H<#HW.0IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@1F]L9&5R<R(*;7-G<W1R(").^FUE<F\@;>%X:6UO
M(&1E(&-A<G!E=&%S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#@Y"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R
M96%C:&5D+B(*;7-G<W1R(")392!H82!A;&-A;GIA9&\@96P@;OIM97)O(&WA
M>&EM;R!D92!A9&IU;G1O<RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT.#4*;7-G:60@(DUA>&EM=6T@=&]T86P@871T86-H;65N="!S
M:7IE(')E86-H960N(@IM<V=S='(@(E-E(&AA(&%L8V%N>F%D;R!E;"!T86UA
M\6\@;>%X:6UO(&1E(&%D:G5N=&]S+B(*"B,Z(&QI8B]";&]C:R]T<F5E7V9O
M;&1E<G,N<&AP.C,*;7-G:60@(DUE;G4@1F]L9&5R($QI<W0B"FUS9W-T<B`B
M3&ES=&%D;R!D96P@;65N^B!D92!C87)P971A<R(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HS-#(*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B365N<V%J92(*"B,Z
M(&-O;7!O<V4N<&AP.C4Y."!C;VUP;W-E+G!H<#HV,C4@8V]M<&]S92YP:'`Z
M-C<Y"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C4P"FUS9VED(")-
M97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@(E)E9&%C8VGS;B!D96P@;65N
M<V%J92(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDP-@IM<V=I
M9"`B365S<V%G92!$871E(@IM<V=S='(@(E!O<B!F96-H82(*"B,Z(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C8U"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C<X(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C@W"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.CDU(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P
M,PIM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S(&1E
M(&UE;G-A:F5S(@H*(SH@<V5A<F-H+G!H<#HS,#8*;7-G:60@(DUE<W-A9V4@
M4V5A<F-H(@IM<V=S='(@(D+Z<W%U961A(&1E(&UE;G-A:F5S(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3$P"FUS9VED(")-97-S86=E(%-I
M>F4B"FUS9W-T<B`B4&]R('1A;6'Q;R(*"B,Z(&UE<W-A9V4N<&AP.C,Y,@IM
M<V=I9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`B3W)I9V5N(&1E;"!M96YS
M86IE(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@
M(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R(")6:7-U86QI>F%C:?-N(&1E(&UE
M;G-A:F5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED
M(")-97-S86=E(&9L86=S(@IM<V=S='(@(D)A;F1E<F%S(&1E;"!M96YS86IE
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX,PIM<V=I9"`B365S
M<V%G92!F;VQD97)S(@IM<V=S='(@(D-A<G!E=&%S(&1E(&UE;G-A:F5S(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B365N<V%J92!D92`E<R(*"B,Z(&UA
M:6QB;W@N<&AP.C8V,PIM<V=I9"`B365S<V%G92!H87,@871T86-H;65N=',B
M"FUS9W-T<B`B16P@;65N<V%J92!T:65N92!A9&IU;G1O<R(*"B,Z(&UA:6QB
M;W@N<&AP.C8U-`IM<V=I9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T
M<B`B16P@;65N<V%J92!E<W3A(&-I9G)A9&\B"@HC.B!M86EL8F]X+G!H<#HV
M-#D*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(D5L(&UE;G-A
M:F4@97-TX2!F:7)M861O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N
M:6YC.C,V"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS9W-T<B`B365N<V%J
M97,@8V]I;F-I9&5N=&5S(@H*(SH@8V]M<&]S92YP:'`Z.#8T(&-O;7!O<V4N
M<&AP.C@W,0IM<V=I9"`B365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`B4V4@:&$@<F5D:7)I9VED;R!C;W)R96-T86UE;G1E(&5L
M(&UE;G-A:F4N(@H*(SH@8V]M<&]S92YP:'`Z,3$R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A
M=F5D('1O("5S(@IM<V=S='(@(E-E(&5N=FGS(&-O<G)E8W1A;65N=&4@96P@
M;65N<V%J92P@<&5R;R!N;R!S92!G=6%R9/,@96X@)7,B"@HC.B!C;VUP;W-E
M+G!H<#HQ,3@Q(&-O;7!O<V4N<&AP.C$Q.#D*;7-G:60@(DUE<W-A9V4@<V5N
M="!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E-E(&5N=FGS(&-O<G)E8W1A;65N
M=&4@96P@;65N<V%J92XB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HY,S`*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X
M('9I97<N(@IM<V=S='(@(DUE;G-A:F5S('!O<B!PX6=I;F$@96X@96P@;&ES
M=&%D;R!D96P@8G5Z\VXN(@H*(SH@;6%I;&)O>"YP:'`Z,S$Q"FUS9VED(")-
M97-S86=E<R!T;R(*;7-G<W1R(")-96YS86IE<R!A(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB"FUS9W-T<B`B36]D:69I
M8V%R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHQ,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-;W)E('1H86X@;VYE(&%D9')E<W,@9F]U;F0@
M9F]R(&9I96QD(%PB)7-<(BXB"FUS9W-T<B`B4V4@:&$@96YC;VYT<F%D;R!M
MX7,@9&4@=6YA(&1I<F5C8VGS;B!P87)A(&5L(&-A;7!O(%PB)7-<(BXB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4B"FUS
M9W-T<B`B5')A<VQA9&%R(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S$V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1&5S<&QA
M>F%R(&AA8VEA(&%B86IO(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z-C`V"FUS9VED(")-;W9E('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD
M97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(B(*
M(E1R87-L861A<B!L;W,@;65N<V%J97,@9&4@<W!A;2!A(&QA(&-A<G!E=&$@
M9&4@<W!A;2!Y(&QO<R!M96YS86IE<R`B"B)I;F]F96YS:79O<V$@;&$@8V%R
M<&5T82!D92!%;G1R861A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C4P"FUS9VED(")-;W9E('1O(&9O;&1E<B(*;7-G<W1R(")4<F%S;&%D87(@
M82!L82!C87)P971A(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C
M="YI;F,Z,S$T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(D1E<W!L87IA<B!H
M86-I82!A<G)I8F$B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N
M<&AP.C$R-PIM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@
M(DUU;'1I<&%R="]A;'1E<FYA=&EV92(*"B,Z('1H<F5A9"YP:'`Z-S8@=&AR
M96%D+G!H<#HQ-3<*;7-G:60@(DUU;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G
M<W1R(")6:7-U86QI>F%C:?-N(&1E(&UE;G-A:F5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C@*;7-G:60@(DY/3D4B
M"FUS9W-T<B`B3DE.1U5.3R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT."!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`B3T)3
M15)604-)TTXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(S."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@S"FUS9VED(").86UE
M(@IM<V=S='(@(DYO;6)R92(*"B,Z('!G<"YP:'`Z,3`V"FUS9VED(").86UE
M(&%N9"]O<B!E;6%I;"!C86YN;W0@8F4@96UP='DB"FUS9W-T<B`B16P@;F]M
M8G)E('DO;R!L82!D:7)E8V-I\VX@;F\@<'5E9&5N(&1E:F%R<V4@96X@8FQA
M;F-O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,0IM<V=I9"`B
M3F5E9',@06-T:6]N(@IM<V=S='(@(E-E(&YE8V5S:71A('5N82!A8V-I\VXB
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU-S`@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z-S8W"FUS9VED(").979E<B(*;7-G<W1R(").
M=6YC82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C4V,`IM<V=I
M9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(").=6YC82!G=6%R
M9&%R(&%D:G5N=&]S(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R-`IM
M<V=I9"`B3F5W(@IM<V=S='(@(DYU979O<R(*"B,Z(&QI8B])35`N<&AP.C4Y
M-0IM<V=I9"`B3F5W($9O;&1E<B(*;7-G<W1R(")#87)P971A(&YU979A(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#@*;7-G:60@(DYE=R!-
M86EL(@IM<V=S='(@(D-O<G)E;R!N=65V;R(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(SH@;&EB+T)L
M;V-K+W1R965?9F]L9&5R<RYP:'`Z-#8*;7-G:60@(DYE=R!-97-S86=E(@IM
M<V=S='(@(E)E9&%C=&%R(@H*(SH@;6%I;&)O>"YP:'`Z-S<Q(&QI8B]-24U%
M+TAE861E<G,N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S
M<V%G92!T;R`E<R(*;7-G<W1R(")-96YS86IE(&YU979O('!A<F$@)7,B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Y"FUS9VED(").97<@;65S
M<V%G97,B"FUS9W-T<B`B365N<V%J97,@;G5E=F]S(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B3F5X="(*;7-G<W1R
M(")3:6=U:65N=&4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C,S"FUS9VED(").97AT($UE<W-A9V4B"FUS9W-T<B`B4'+S
M>&EM;R!M96YS86IE(@H*(SH@;6%I;&)O>"YP:'`Z,S0R"FUS9VED(").97AT
M(%!A9V4B"FUS9W-T<B`B4'+S>&EM82!PX6=I;F$B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU-#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-34S"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDV
M-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F\B"@HC.B!S;6EM92YP:'`Z,C(R"FUS
M9VED(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R(").;R!S92!H82!E
M;F-O;G1R861O('5N(&-E<G1I9FEC861O(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHU"FUS9VED(").;R!%;F-R>7!T:6]N(@IM
M<V=S='(@(E-I;B!C:69R87(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,3D*;7-G:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R(").;R!H87D@
M8VQA=F5S(&5N(&5L(&QL879E<F\B"@HC.B!M86EL8F]X+G!H<#HS-C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B"FUS9W-T<B`B4VEN(&UE
M;G-A:F5S(@H*(SH@<&=P+G!H<#HQ,S,*;7-G:60@(DYO(%!'4"!P=6)L:6,@
M:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(").;R!S92!H82!I;7!O<G1A9&\@=6YA
M(&-L879E(%!'4"!P^F)L:6-A+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC871E(%!R97-E
M;G0B"FUS9W-T<B`B3F\@:&%Y('5N(&-E<G1I9FEC861O('!E<G-O;F%L(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,Q.0IM<V=I9"`B3F\@4')E=FEE=R!497AT
M(@IM<V=S='(@(E9I<W1A('!R979I82!S:6X@=&5X=&\B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C$U"FUS9VED(").;R!0=6)L:6,@2V5Y<R!&
M;W5N9"(*;7-G<W1R(").;R!S92!H86X@96YC;VYT<F%D;R!C;&%V97,@</IB
M;&EC87,B"@HC.B!S;6EM92YP:'`Z,30W"FUS9VED(").;R!3+TU)344@<'5B
M;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B3F\@<V4@:&$@:6UP;W)T861O
M(&QA(&-L879E(%,O34E-12!P^F)L:6-A+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]T;F5F+G!H<#HY,@IM<V=I9"`B3F\@871T86-H;65N=',@9F]U;F0N(@IM
M<V=S='(@(DYO('-E(&AA;B!E;F-O;G1R861O(&%D:G5N=&]S+B(*"B,Z(&QI
M8B]#<GEP="]334E-12YP:'`Z,30P"FUS9VED(").;R!E;6%I;"!I;F9O<FUA
M=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+B(*;7-G<W1R(").;R!S
M92!E;F-U96YT<F$@:6YF;W)M86-I\VX@9&4@9&ER96-C:?-N(&5N(&QA(&-L
M879E('#Z8FQI8V$N(@H*(SH@86-L+G!H<#HW,2!A8VPN<&AP.CDW"FUS9VED
M(").;R!F;VQD97(@<V5L96-T960N(@IM<V=S='(@(FYO(&AA>2!C87)P971A
M<R!S96QE8V-I;VYA9&%S+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M-#D*;7-G:60@(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE
M=R!M86EL+B(*;7-G<W1R(").;R!S92!C;VUP<G5E8F$@96P@8V]R<F5O(&YU
M979O(&5N(&YI;F=U;F$@8V%R<&5T82XB"@HC.B!F;VQD97)S+G!H<#HR,#$@
M;&EB+T9O;&1E<BYP:'`Z-3`P(&QI8B]&;VQD97(N<&AP.C4U,`IM<V=I9"`B
M3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9"(*;7-G<W1R(").;R!S92!E<W!E
M8VEF:6-A<F]N(&-A<G!E=&%S(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$U-0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<R(*;7-G
M<W1R(").;R!H87D@8V%R<&5T87,@8V]N(&UE;G-A:F5S(&YU979O<R(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-3(*;7-G:60@(DYO(&9O;&1E<G,@
M=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`B3F\@:&%Y(&-A<G!E=&%S
M(&-O;B!M96YS86IE<R!S:6X@;&5E<B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M,S8*;7-G:60@(DYO(&UE<W-A9V4@8F]D>2!T97AT(@IM<V=S='(@(DYO(&AA
M>2!T97AT;R!E;B!E;"!C=65R<&\@9&5L(&UE;G-A:F4B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4V.`IM<V=I9"`B3F\@;65S<V%G92!R971U<FYE9"XB
M"FUS9W-T<B`B3F\@<V4@:&$@9&5V=65L=&\@;FEN9_IN(&UE;G-A:F4N(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,V,@IM<V=I9"`B3F\@;65S<V%G97,@;6%T
M8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B3F\@:&%Y(&UE;G-A:F5S('%U
M92!C;VEN8VED86X@8V]N('-U(&+Z<W%U961A+B(*"B,Z('!G<"YP:'`Z,3@U
M"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N
M(@IM<V=S='(@(DYO('-E(&AA(&EM<&]R=&%D;R!L82!C;&%V92!P97)S;VYA
M;"!01U`@<')I=F%D82XB"@HC.B!P9W`N<&AP.C$V,0IM<V=I9"`B3F\@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DYO('-E
M(&AA(&EM<&]R=&%D;R!L82!C;&%V92!P97)S;VYA;"!01U`@</IB;&EC82XB
M"@HC.B!S;6EM92YP:'`Z,3DW"FUS9VED(").;R!P97)S;VYA;"!3+TU)344@
M8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G<W1R(").;R!S92!H86X@:6UP
M;W)T861O(&-E<G1I9FEC861O<R!P97)S;VYA;&5S(%,O34E-12XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T-B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR.3D*;7-G:60@(B(*(DYO('!E<G-O;F%L('!R:79A=&4@:V5Y
M(&5X:7-T<R!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP
M=&5D+B(*;7-G<W1R("(B"B).;R!H87D@8VQA=F4@<')I=F%D82!P97)S;VYA
M;"!P;W(@;&\@<75E(&YO('-E('!U961E(&1E<V-I9G)A<B!E;"!M96YS86IE
M+B(*"B,Z('-P96QL:6YG+G!H<#HR,C`*;7-G:60@(DYO('-P96QL8VAE8VMI
M;F<@<')O9W)A;2!C;VYF:6=U<F5D+B(*;7-G<W1R(").;R!S92!H82!C;VYF
M:6=U<F%D;R!U;B!P<F]G<F%M82!D92!C;W)R96-I\VX@;W)T;V=RX69I8V$N
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED
M(").;R!S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B3F\@:&%Y(&5R<F]R97,@
M9&4@;W)T;V=R86;M82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHQ,#`*;7-G:60@(DYO('-U9V=E<W1I;VYS(@IM<V=S='(@(DYO(&AA
M>2!S=6=E<F5N8VEA<R(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-38P"FUS
M9VED(").;R!S=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@
M8V]U;&0@8F4@9F]U;F0N(@IM<V=S='(@(DYO('-E('!U961E(&QO8V%L:7IA
M<B!U;B!MZ71O9&\@9&4@875T96YT:69I8V%C:?-N($E-05`@<V]P;W)T861O
M+B(*"B,Z(&%C;"YP:'`Z-C<@86-L+G!H<#HY,PIM<V=I9"`B3F\@=7-E<B!S
M<&5C:69I960N(@IM<V=S='(@(DYO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!U
M<W5A<FEO+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#0*;7-G
M:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R(")3:6X@<&%R=&EC:7!A;G1E
M<R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@=&5M<&QA
M=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*(SH@=&5M<&QA=&5S+W!R
M969S+W-E;G1M86EL<V5L96-T+FEN8SHT,"!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS-0HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z,C0@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR-`HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Q"FUS9VED(").;VYE(@IM
M<V=S='(@(DYI;F=U;F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR.34*;7-G:60@(DYO<FUA;"(*;7-G<W1R(").;W)M86PB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S='(@
M(DYO(&5L:6UI;F%D;R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR
M,PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").
M;W0@1')A9G0B"FUS9W-T<B`B3F\@8F]R<F%D;W(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,T"FUS9VED(").;W0@26UP;W)T86YT(@IM<V=S='(@(DYO(&EM<&]R
M=&%N=&4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS
M9VED(").;W0@4&5R<V]N86PB"FUS9W-T<B`B3F\@<&5R<V]N86PB"@HC.B!L
M:6(O0W)Y<'0O4$=0+G!H<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@
M;&EB+T-R>7!T+U--24U%+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A;&ED('!U
M8FQI8R!K97DN(@IM<V=S='(@(DYO(&5S('5N82!C;&%V92!P^F)L:6-A(';A
M;&ED82XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED
M(").;W0@9&5L971E9"!M97-S86=E<R(*;7-G<W1R(")-96YS86IE<R!N;R!E
M;&EM:6YA9&]S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM
M<V=I9"`B3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(")-96YS86IE
M<R!N;R!I;7!O<G1A;G1E<R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E
M=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A
M;B!T86ME('-O;64@=&EM92(*;7-G<W1R(")496YG82!E;B!C=65N=&$@<75E
M(.ES=&\@<'5E9&4@;&QE=F%R('5N(')A=&\B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HV,#0*;7-G:60@(DYO=&AI;F<B"FUS9W-T<B`B3F%D
M82(*"B,Z(&%T=&%C:&UE;G0N<&AP.C@Y"FUS9VED(").;W1I9FEC871I;VXZ
M($QI;FME9"!A='1A8VAM96YT(&1O=VYL;V%D960B"FUS9W-T<B`B3F]T:69I
M8V%C:?-N.B!!9&IU;G1O('9I;F-U;&%D;R!D97-C87)G861O(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED(").=6UB97(@;V8@
M;6]N=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE
M=&EN9R!M;VYT:&QY+B(*;7-G<W1R("(B"B).^FUE<F\@9&4@;65S97,@<75E
M('-E(&-O;G-E<G9A;B!L;W,@861J=6YT;W,@=FEN8W5L861O<R!A;G1I9W5O
M<R!A;"`B"B)E;&EM:6YA<FQO<R!M96YS=6%L;65N=&4N(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z,S4Y"FUS9VED(").=6UB97(@;V8@;VQD
M('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL
M>2XB"FUS9W-T<B`B(@HB0V%R<&5T87,@7")%;G9I861O<UPB(&%N=&EG=6%S
M('%U92!S92!C;VYS97)V86X@86P@96QI;6EN87(@;65N<W5A;&UE;G1E+B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T"FUS9VED
M(")/2R(*;7-G<W1R(")!8V5P=&%R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F
M:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0Y
M"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-#@*;7-G:60@(D]2
M(@IM<V=S='(@(D\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$U
M"FUS9VED(")/;&0@;65S<V%G97,B"FUS9W-T<B`B365N<V%J97,@86YT:6=U
M;W,B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?
M;6]N=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B
M96EN9R!P=7)G960N(@IM<V=S='(@(E!U<F=A;F1O(&-A<G!E=&%S(%PB16YV
M:6%D;W-<(B!A;G1I9W5A<RXB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,C@*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE
M<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(K]-;W-T<F%R('/S;&\@;&%S(&-A
M<G!E=&%S('%U92!C;VYT96YG86X@;65N<V%J97,@<VEN(&QE97(_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHX,0IM<V=I9"`B3VYL
M>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I
M;VXN(@IM<V=S='(@(E!A<F$@97-T82!A8V-I\VX@:&%Y('%U92!S96QE8V-I
M;VYA<B!S\VQO('5N82!C87)P971A+B(*"B,Z('1E;7!L871E<R]M96YU+FEN
M8SHQ,"!T96UP;&%T97,O;65N=2YI;F,Z,S`*;7-G:60@(D]P96X@1F]?;&1E
M<B(*;7-G<W1R(")!8G)?:7(@8V%R<&5T82(*"B,Z(&9O;&1E<G,N<&AP.C0P
M.`IM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G<W1R(")#87)P971A(&%B:65R
M=&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`P"FUS9VED(")/
M<'1I;VYA;"!087)T:6-I<&%N="(*;7-G<W1R(")087)T:6-I<&%N=&4@;W!C
M:6]N86PB"@HC.B!F971C:&UA:6PN<&AP.C0S('1E;7!L871E<R]F971C:&UA
M:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL
M+FEN8SHV"FUS9VED(")/=&AE<B!-86EL($%C8V]U;G1S(@IM<V=S='(@(D]T
M<F%S(&-U96YT87,@9&4@8V]R<F5O(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,3$P(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$Q.0HC
M.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,3,S"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C$T,2!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@
M(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B3W1R87,@;W!C:6]N97,B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,`IM<V=I9"`B3W5T8F]U;F0@
M4V5R=F5R(@IM<V=S='(@(E-E<G9I9&]R(&1E('-A;&ED82(*"B,Z('1E;7!L
M871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,38T"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P,R!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR.#D*;7-G:60@(E!'4"(*;7-G<W1R(")0
M1U`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*
M;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B0VEF<F%R(&UE
M;G-A:F4@8V]N(%!'4"(*"B,Z(&-O;7!O<V4N<&AP.C,S-0IM<V=I9"`B4$=0
M($5R<F]R.B`B"FUS9W-T<B`B17)R;W(@9&4@4$=0.B`B"@HC.B!C;VUP;W-E
M+G!H<#HS,30*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O
M<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@HB17)R;W(@9&4@
M4$=0.B!(86-E(&9A;'1A('5N82!F<F%S92!C;&%V92!P87)A(&QA(&-L879E
M('!E<G-O;F%L('!R:79A9&$N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,30R"FUS9VED(")01U`@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYE
M<R!D92!01U`B"@HC.B!P9W`N<&AP.C,P"FUS9VED(")01U`@4&%S<W!H<F%S
M92!);G!U="(*;7-G<W1R(")%;G1R861A(&1E(&9R87-E(&-L879E(%!'4"(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O
M;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B(@HB2&%C92!F86QT82!U;F$@8V]N97AI\VX@
M=V5B('-E9W5R82!P87)A('5T:6QI>F%R(&5L('-O<&]R=&4@9&4@8VQA=F5S
M("(*(G!E<G-O;F%L97,@4$=0(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,3<R"FUS9VED(")01U`@4'5B;&EC($ME>2!497AT(@IM<V=S='(@(E1E
M>'1O(&1E(&QA(&-L879E(%!'4"!P^F)L:6-A(@H*(SH@<&=P+G!H<#HQ-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@
M*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E-E(&AA
M(&'Q861I9&\@8V]R<F5C=&%M96YT92!L82!C;&%V92!01U`@</IB;&EC82!D
M92!<(B5S("@E<RE<(BXB"@HC.B!P9W`N<&AP.C(T,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&-O<G)E
M8W1A;65N=&4@;&$@8VQA=F4@4$=0('#Z8FQI8V$@9&4@7"(E<UPB+B(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-`IM<V=I9"`B4$=0(%!U8FQI8R!+
M97ER:6YG(@IM<V=S='(@(DQL879E<F\@4$=0('#Z8FQI8V\B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*;7-G:60@(E!'4"!3
M:6=N($UE<W-A9V4B"FUS9W-T<B`B365N<V%J92!C;VX@9FER;6$@4$=0(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"FUS9VED
M(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B365N<V%J92!F
M:7)M861O+V-I9G)A9&\@8V]N(%!'4"(*"B,Z('!G<"YP:'`Z,3DX"FUS9VED
M(")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R
M(")392!H82!A\6%D:61O(&-O<G)E8W1A;65N=&4@;&$@8VQA=F4@4$=0('!R
M:79A9&$N(@H*(SH@<&=P+G!H<#HQ-S,*;7-G:60@(E!'4"!P=6)L:6,@:V5Y
M('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B4V4@:&$@8?%A9&ED;R!C
M;W)R96-T86UE;G1E(&QA(&-L879E(%!'4"!P^F)L:6-A+B(*"B,Z('1E;7!L
M871E<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")01U`@<W5P<&]R="!I
M<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B16X@97-T92!S
M:7-T96UA('-E(&AA(&1E<V%C=&EV861O(&5L('-O<&]R=&4@4$=0+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-PIM<V=I9"`B(@HB4$=0('-U
M<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@
M<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T
M<B`B(@HB16P@<V]P;W)T92!01U`@;F\@97-TX2!A8W1I=F%D;R!A8W1U86QM
M96YT92!P;W(@;&\@<75E(&YO('-E('!U961E(&-O;7!R;V)A<B`B"B)L82!F
M:7)M82!D:6=I=&%L+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y
M-`IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I
M=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB
M"FUS9W-T<B`B(@HB16P@<V]P;W)T92!01U`@;F\@97-TX2!A8W1I=F%D;R!A
M8W1U86QM96YT92!P;W(@;&\@<75E(&YO('-E('!U961E(&1E<V-I9G)A<B`B
M"B)E;"!M96YS86IE+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS
M9VED("(B"B)01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O
M(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY("(*(G-E
M="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T
M:&ES('-E='1I;F<@;W(@96QS92!T:&4@4$=0("(*(F9E871U<F5S('=I;&P@
M;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)%;"!S;W!O<G1E(%!'
M4"!N96-E<VET82!U=&EL:7IA<B!V96YT86YA<R!E;65R9V5N=&5S+B!3:2!L
M87,@:&$@9&5S86-T:79A9&\@(@HB96X@<W4@;F%V96=A9&]R+"!T96YD<N$@
M<75E(')E86-T:79A<FQA<R!O(&QA<R!C87)A8W1E<NUS=&EC87,@4$=0(&YO
M("(*(F9U;F-I;VYA<N%N(&-O<G)E8W1A;65N=&4N(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B"FUS9W-T<B`B4$]0,R(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`P"FUS9VED(")03U`S("A!
M=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(E!/4#,@*$%U=&]D971E
M8V-I\VX@9&4@<')O=&]C;VQO<RDB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R(")03U`S('-O
M8G)E(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(S"FUS9VED
M(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS
M9W-T<B`B4$]0,R!S;V)R92!34TP@*&-E<G1I9FEC861O(&%U=&\M9FER;6%D
M;RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V.`IM<V=I9"`B
M4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I(@IM<V=S='(@(E!/4#,@<V]B
M<F4@4U-,("AA=71O+69I<FUA9&\I(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R(")03U`S+"!S
M:6X@5$Q3(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHR,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")086=E("5D(&]F("5D(@IM<V=S='(@(E#A
M9VEN82`E9"!D92`E9"(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C@Y,@IM<V=I9"`B4&%G92!W:71H('1H92!&:7)S="!5;G-E96X@365S<V%G
M92(*;7-G<W1R(")0X6=I;F$@9&5L('!R:6UE<B!M96YS86IE('-I;B!L965R
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#DS"FUS9VED(")0
M86=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B4.%G
M:6YA(&1E;"#Z;'1I;6\@;65N<V%J92!S:6X@;&5E<B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VAE861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S
M='(@(E!A<G1E*',I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R,PIM
M<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R(")&<F%S92!C;&%V92(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@*$%G
M86EN*2(*;7-G<W1R(")&<F%S92!C;&%V92`H<F5P971I8VGS;BDB"@HC.B!S
M;6EM92YP:'`Z,C,Q('!G<"YP:'`Z,S`V"FUS9VED(")087-S<&AR87-E('-U
M8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`B1G)A<V4@8VQA=F4@9&5S
M8V%R9V%D82!C;W)R96-T86UE;G1E+B(*"B,Z('1E;7!L871E<R]S;6EM92]P
M87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC
M.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R(")&<F%S92!C;&%V93HB
M"@HC.B!P9W`N<&AP.C$P.`IM<V=I9"`B4&%S<W!H<F%S97,@8V%N;F]T(&)E
M(&5M<'1Y(@IM<V=S='(@(DQA<R!F<F%S97,@8VQA=F4@;F\@<'5E9&5N(&1E
M:F%R<V4@96X@8FQA;F-O(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(E!A<W-P
M:')A<V5S(&1O(&YO="!M871C:"(*;7-G<W1R("),87,@9G)A<V5S(&-L879E
M(&YO(&-O:6YC:61E;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S$*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3$*;7-G:60@(E!A<W-W;W)D
M(@IM<V=S='(@(D-O;G1R87-E\6$B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BOU)E86QI>F%R(&]P97)A8VEO
M;F5S(&1E(&UA;G1E;FEM:65N=&\@86P@:6YI8VEA<B!S97-I\VX_/R(*"B,Z
M(&%C;"YP:'`Z-S4@86-L+G!H<#HQ,#$*;7-G:60@(E!E<FUI<W-I;VYS(&9O
M<B!T:&ES('5S97(@8V%N;F]T(&)E(&-H86YG960N(@IM<V=S='(@(DYO('-E
M('!U961E;B!C86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D92!E<W1E('5S=6%R
M:6\N(@H*(SH@;65S<V%G92YP:'`Z-#DT(&UA:6QB;W@N<&AP.C8Y."!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(T"B,Z('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z,3`*;7-G:60@(E!E<G-O;F%L(@IM<V=S='(@(E!E
M<G-O;F%L(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,30*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:?-N
M('!E<G-O;F%L(@H*(SH@<&=P+G!H<#HQ,38*;7-G:60@(E!E<G-O;F%L(%!'
M4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E-E
M(&AA;B!G96YE<F%D;R!C;W)R96-T86UE;G1E(&QA<R!C;&%V97,@<&5R<V]N
M86QE<R!01U`N(@H*(SH@<&=P+G!H<#HQ,C,*;7-G:60@(E!E<G-O;F%L(%!'
M4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")392!H86X@
M96QI;6EN861O(&-O<G)E8W1A;65N=&4@;&%S(&-L879E<R!P97)S;VYA;&5S
M(%!'4"XB"@HC.B!S;6EM92YP:'`Z,C`S"FUS9VED(")097)S;VYA;"!3+TU)
M344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S='(@(DYO('-E
M(&AA;B!I;7!O<G1A9&\@8V5R=&EF:6-A9&]S('!E<G-O;F%L97,@4R]-24U%
M+B(*"B,Z('-M:6UE+G!H<#HQ,C@*;7-G:60@(E!E<G-O;F%L(%,O34E-12!K
M97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")392!H86X@96QI
M;6EN861O(&-O<G)E8W1A;65N=&4@;&%S(&-L879E<R!P97)S;VYA;&5S(%,O
M34E-12XB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G
M:60@(E!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F
M;W)W87)D<S\B"FUS9W-T<B`BOT'Q861I<B!S=2!F:7)M82!A;G1E<R!D92!L
M82!C;VYT97-T86-I\VX@;R!E;"!R965N=NUO/R(*"B,Z(&-O;7!O<V4N<&AP
M.C(U.`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G92(*;7-G
M<W1R(")697)S:?-N(&5N('1E>'1O(&1E;"!M96YS86IE(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z-S@X"FUS9VED("(B"B)0;&%Y('-O=6YD
M(&]N(&YE=R!M86EL/R`@5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@
M<W5P<&]R="!E;6)E9&1E9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@
M9&\@;VX@5VEN9&]W<R!A;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I
M;&P@(@HB<F5Q=6ER92!A('!L=6=I;BXB"FUS9W-T<B`B(@HBOU)E<')O9'5C
M:7(@<V]N:61O(&-O;B!L82!R96-E<&-I\VX@9&4@8V]R<F5O/R!(86-E(&9A
M;'1A('%U92!E;"!N879E9V%D;W(@(@HB<&5R;6ET82!A<F-H:79O<R!D92!S
M;VYI9&\@:6YC;'5I9&]S+B!,82!M87EO<NUA(&1E(&QO<R!D92!7:6YD;W=S
M('D@36%C(&QO("(*(G!E<FUI=&5N+"!P97)O(&]T<F%S('!L871A9F]R;6%S
M('!U961E;B!P<F5C:7-A<B!U;B!P;'5G:6XN(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z,3DR"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B26YT<F]D=7IC82!E;"!N;VUB
M<F4@9&4@;&$@;G5E=F$@8V%R<&5T83HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C$P-"!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$P-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H
M92!N97<@9F]L9&5R.B(*;7-G<W1R("));G1R;V1U>F-A(&5L(&YO;6)R92!D
M92!L82!N=65V82!C87)P971A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3,Y"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N
M86UE.B(*;7-G<W1R("));G1R;V1U>F-A(&5L(&YU979O(&YO;6)R93HB"@HC
M.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@
M>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R`B
M"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB
M"FUS9W-T<B`B(@HB26YT<F]D=7IC82!L82!F<F%S92!C;&%V92!P87)A(&QA
M(&-L879E(%!'4"!P<FEV861A+B!3\VQO('1E;F1RX2!Q=64@(@HB:6YT<F]D
M=6-I<FQA('5N82!V97H@<&]R('-E<VGS;B!D92`E<RXB"@HC.B!T96UP;&%T
M97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O
M34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D("(*(G1O(&5N
M=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G
M<W1R("(B"B));G1R;V1U>F-A(&QA(&9R87-E(&-L879E('!A<F$@;&$@8VQA
M=F4@4R]-24U%('!R:79A9&$N(%/S;&\@=&5N9'+A('%U92`B"B)I;G1R;V1U
M8VER;&$@=6YA('9E>B!P;W(@<V5S:?-N(&1E("5S+B(*"B,Z(')E8V]M<&]S
M92YP:'`Z.38*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S
M=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S
M:6YG("(*(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S
M(&EN('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN
M(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T
M;R!K965P(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I
M;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM
M<V=S='(@(B(*(E9U96QV82!A(&EN:6-I87(@;&$@<V5S:?-N('!A<F$@<F5A
M;G5D87(@;&$@<F5D86-C:?-N(&1E;"!M96YS86IE+B!3:2!.3R`B"B)U=&EL
M:7IA(&-O;VMI97,@62!E<W3A(')E9&%C=&%N9&\@;&]S(&UE;G-A:F5S(&5N
M('9E;G1A;F%S(&5M97)G96YT97,L("(*(G1E;F1RX2!Q=64@:6YI8VEA<B!S
M97-I\VX@=&%M8FGI;B!E;B!L82!V96YT86YA('!R:6YC:7!A;"X@17,@;F5C
M97-A<FEO('!A<F$@(@HB979I=&%R('%U92!U;B!A<V%L=&%N=&4@<W5P;&%N
M=&4@<W4@240@9&4@<V5S:?-N+B!$:7-C=6QP92!L87,@;6]L97-T:6%S+B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S$*;7-G:60@(E!L96%S
M92!P<F]V:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S='(@(DEN=')O9'5Z8V$@
M<W4@8V]N=')A<V7Q82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C8W"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE+B(*;7-G
M<W1R("));G1R;V1U>F-A('-U(&YO;6)R92!D92!U<W5A<FEO+B(*"B,Z(&-O
M;7!O<V4N<&AP.C$P-B!L:6(O24U0+G!H<#HT-C,*;7-G:60@(E!L96%S92!R
M97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T
M<B`B4F5S=65L=F$@9&ER96-C:6]N97,@96QE8W1R\VYI8V%S(&%M8FEG=6%S
M(&\@:6YVX6QI9&%S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z-C,*;7-G:60@(E!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E
M('EO=2!P97)F;W)M('1H:7,@86-T:6]N+B(*;7-G<W1R(")396QE8V-I;VYE
M('5N82!C87)P971A(&%N=&5S(&1E(')E86QI>F%R(&5S=&$@86-C:?-N+B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@
M(E!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N
M(@IM<V=S='(@(E-E;&5C8VEO;F4@86P@;65N;W,@=6YA(&-A<G!E=&$@<&%R
M82!L82!B^G-Q=65D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$R"FUS9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E
M<B!F;W(@=&AI<R!O<&5R871I;VXN(@IM<V=S='(@(E-E;&5C8VEO;F4@=6YA
M(/IN:6-A(&-A<G!E=&$@<&%R82!E<W1A(&]P97)A8VGS;BXB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-S,*;7-G:60@(E!L96%S92!S
M96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T
M<B`B4V5L96-C:6]N92!O(&UO9&EF:7%U92!E;B!E;"!R96-U861R;R!D92!L
M82!D97)E8VAA.B(*"B,Z(&-O;F9I9R\N8F%K+VUO=&0N<&AP+F1I<W0Z-#$*
M;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B4&]T96YC:6%D;R!P
M;W(@2&]R9&4B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR,30*
M;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M
M+2`G*3\B"FUS9W-T<B`BOT5N8V%B97IA<B!L82!F:7)M82!C;VX@9W5I;VYE
M<R`H)RTM("<I/R(*"B,Z('-M:6UE+G!H<#HR,S<@<&=P+G!H<#HR-3,@9FEL
M=&5R<')E9G,N<&AP.C,Y"FUS9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L
M;'D@=7!D871E9"XB"FUS9W-T<B`B4V4@:&%N(&%C='5A;&EZ861O(&-O<G)E
M8W1A;65N=&4@;&%S('!R969E<F5N8VEA<RXB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R
M(")6:7-T82!P<F5V:6$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U<R!-97-S86=E(@IM<V=S
M='(@(DUE;G-A:F4@86YT97)I;W(B"@HC.B!M86EL8F]X+G!H<#HS,S,*;7-G
M:60@(E!R979I;W5S(%!A9V4B"FUS9W-T<B`B4.%G:6YA(&%N=&5R:6]R(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS
M9VED(")0<FEN="(*;7-G<W1R("));7!R:6UI<B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VAE861E<G,N:6YC.C,X"FUS9VED(")0<FEO<FET>2(*;7-G<W1R
M(")0<FEO<FED860B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z-S8*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@(D-O
M;G1R87-E\6$@9&4@8VQA=F4@<')I=F%D82(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C4U.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@
M871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@(D-O
M;G-U;'1A<B!C861A('9E>B!Q=64@<V4@96YV[64@=6X@861J=6YT;SL@3D\@
M<&]R(&]M:7-I\VXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU
M-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@
M<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B0V]N<W5L=&%R(&-A9&$@
M=F5Z('%U92!S92!E;G;M92!U;B!A9&IU;G1O.R!3S2!P;W(@;VUI<VGS;B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B
M4')O=&]C;VPZ(@IM<V=S='(@(E!R;W1O8V]L;SHB"@HC.B!L:6(O0W)Y<'0O
M4$=0+G!H<#HT,S`*;7-G:60@(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O
M<G0@:&%S(&)E96X@9&ES86)L960N(@IM<V=S='(@(E-E(&AA(&1E<V%C=&EV
M861O(&5L('-O<&]R=&4@9&4@<V5R=FED;W)E<R!D92!C;&%V97,@4$=0('#Z
M8FQI8V]S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I
M9"`B4'5R7V=E($1E;&5T960B"FUS9W-T<B`B5F%C:6%R("A?>"DB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC.C<*;7-G:60@(E!U<F=E($1E;&5T
M960B"FUS9W-T<B`B5F%C:6%R(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,C0*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R(")6
M86-I87(@8V%R<&5T82AS*2(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G<W1R
M(")#=>%N(&$@;65N=61O('9A8VEA<B!L82!P87!E;&5R83HB"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E(&UE<W-A
M9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F
M(&1A>7,N(@IM<V=S='(@(B(*(D5L:6UI;F%R(&1E(&QA('!A<&5L97)A(&QO
M<R!M96YS86IE<R!MX7,@86YT:6=U;W,@<75E(&5S=&4@;OIM97)O(&1E(&3M
M87,N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED
M(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS
M9W-T<B`BOT5L:6UI;F%R(&1E(&QA('!A<&5L97)A(&QO<R!M96YS86IE<R!A
M;G1I9W5O<S\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S
M:"YP:'`Z-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S
M86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B16QI;6EN86YD;R`E
M9"!M96YS86IE<R!D92!L82!P87!E;&5R82XB"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C,*;7-G:60@(E!U<F=I;F<@,2!M
M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R(")%;&EM:6YA;F1O
M(#$@;65N<V%J92!D92!L82!P87!E;&5R82XB"@HC.B!T96UP;&%T97,O<75O
M=&$O<75O=&$N:6YC.C$W"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T
M871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R(")%<W1A
M9&\@9&5L(&5S<&%C:6\@87-I9VYA9&\Z("4N,F9-0B`O("4N,F9-0B`@*"4N
M,F8E)2DB"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-
M250B"FUS9W-T<B`B17-T861O(&1E;"!E<W!A8VEO(&%S:6=N861O.B`E+C)F
M34(@+R!324X@3,U-251%(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN
M8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z($Y/($Q)
M34E4(@IM<V=S='(@(D5S=&%D;R!D96P@97-P86-I;R!A<VEG;F%D;SH@4TE.
M($S-34E412(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C4P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T:6YG("5F.B(*;7-G<W1R("(E9B!H
M82!E<V-R:71O.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C(Y"FUS9VED(")296)U:6QD($9O;&1E<B!4<F5E(@IM<V=S='(@(E)E8V]N
M<W1R=6ER(.%R8F]L(&1E(&-A<G!E=&%S(@H*(SH@;&EB+U-E87)C:"YP:'`Z
M-C$W"FUS9VED(")296-E:79E9"!/;B(*;7-G<W1R(")296-I8FED;W,@96PB
M"@HC.B!L:6(O4V5A<F-H+G!H<#HV,C4*;7-G:60@(E)E8V5I=F5D(%-I;F-E
M(@IM<V=S='(@(E)E8VEB:61O<R!D97-D92(*"B,Z(&QI8B]396%R8V@N<&AP
M.C8R,0IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`B4F5C:6)I9&]S
M(&AA<W1A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$V"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B4F5D:7)I9VER("A?
M<2DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(E)E9&ER:6=I<B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E9&ER
M96-T($UE<W-A9V4B"FUS9W-T<B`B7U)E9&ER:6=I<B!M96YS86IE(@H*(SH@
M8V]M<&]S92YP:'`Z.#(W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B
M"FUS9W-T<B`B4F5D:6=I<B!E<W1E(&UE;G-A:F4B"@HC.B!C;VUP;W-E+G!H
M<#HX.#`*;7-G:60@(E)E9&ER96-T:6YG(&9A:6QE9"XB"FUS9W-T<B`B1F%L
M;/,@96P@<F5D:7)E8V-I;VYA;6EE;G1O+B(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C<W,PIM<V=I9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z
M(@IM<V=S='(@(D%C='5A;&EZ87(@=FES=&%S(&1E(&-A<G!E=&$Z(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.2!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C0*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")!8W1U86QI
M>F%R(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B
M4F5L;V%D(%9I97<B"FUS9W-T<B`B06-T=6%L:7IA<B!V:7-T82(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4T-PIM<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B4F5C;W)D87(@;&$@:6YF;W)M86-I\VX@9&4@
M=&EE;7!O(&1I<W!O;FEB;&4N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z.38X"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S
M='(@(E)E8V]R9&%R(&QA(/IL=&EM82!V:7-T82(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHR-PIM<V=I9"`B4F5M;W1E($UA:6QB;W@Z
M(@IM<V=S='(@(D)U>O-N(')E;6]T;SHB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M(%-E87)C
M:"(*;7-G<W1R(")1=6ET87(@8V%M<&]S(&1E(&QA(&+Z<W%U961A(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`U"FUS9VED(")2
M96UO=F4@<V]U<F-E(@IM<V=S='(@(D5L:6UI;F%R(&]R:6=E;B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E;F%M92!&
M;VQD97(H<RDB"FUS9W-T<B`B4F5N;VUB<F%R(&-A<G!E=&$H<RDB"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E;F%M92!S
M96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T
M<B`BOU)E;F]M8G)A<B!L82!C87)P971A(%PB16YV:6%D;W-<(B!A;"!I;FEC
M:6\@9&5L(&UE<S\B"@HC.B!L:6(O1F]L9&5R+G!H<#HT-3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL960N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B17)R;W(@
M86P@<F5N;VUB<F%R(%PB)7-<(B!C;VUO(%PB)7-<(BX@R7-T;R!E<R!L;R!Q
M=64@9&EJ;R!E;"!S97)V:61O<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS
M9W-T<B`B4F5S<&]N9&5R(&$@;&$@;&ES=&$B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")297!L86-E('=I=&@Z(@IM
M<V=S='(@(E-U<W1I='5I<B!P;W(Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S='(@(E)E
M<W!O;F1E<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3(@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,`IM<V=I9"`B4F5P;'D@4V5N="XB
M"FUS9W-T<B`B4F5S<'5E<W1A(&5N=FEA9&$N(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!!
M;&PB"FUS9W-T<B`B4F5S<&]N9&5R(&$@=&]D;W,B"@HC.B!C;VUP;W-E+G!H
M<#HW-S$*;7-G:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B4F5S<&]N9&5R
M(&$@=&]D;W,Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C$P"FUS9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@(E)E<W!O
M;F1E<B!A(&QA(&QI<W1A(@H*(SH@8V]M<&]S92YP:'`Z-S<S"FUS9VED(")2
M97!L>2!T;R!,:7-T.B(*;7-G<W1R(")297-P;VYD97(@82!L82!L:7-T83HB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*
M;7-G:60@(E)E<&QY('1O(%]!;&PB"FUS9W-T<B`B4F5S<&]N9&5R(&$@=&]D
M;W,@*%]Z*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S`@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4S.0HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-30Y"FUS9VED(")297!L>2!W:71H($YO="!3=7!P;W)T960@
M365S<V%G92(*;7-G<W1R(")297-P;VYD97(@8V]N('5N(&UE;G-A:F4@;F\@
M<V]P;W)T861O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-PIM
M<V=I9"`B4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N
M(@IM<V=S='(@(E)E<W!O;F1E<B!C;VX@96P@=&EE;7!O(&1I<W!O;FEB;&4@
M9'5R86YT92!L;W,@<'+S>&EM;W,@,B!M97-E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3,V"FUS9VED(")297!L>2!W:71H(')E<75E<W1E
M9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(E)E<W!O;F1E<B!C
M;VX@;&$@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4@<&5D:61A
M+B(*"B,Z(&UE<W-A9V4N<&AP.C(W-0IM<V=I9"`B4F5P;'DM5&\B"FUS9W-T
M<B`B4F5S<&]N9&5R+4$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#(P"FUS9VED
M(")297!L>2U4;SH@(@IM<V=S='(@(E)E<W!O;F1E<BU!.B`B"@HC.B!C;VUP
M;W-E+G!H<#HW-CD*;7-G:60@(E)E<&QY.B(*;7-G<W1R(")297-P;VYD97(Z
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,X
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(V"FUS9VED(")297!O
M<G0@87,@26YN;V-E;G0B"FUS9W-T<B`B3F]T:69I8V%R(&-O;6\@:6YO9F5N
M<VEV;R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHS-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,PIM<V=I9"`B
M4F5P;W)T(&%S(%-P86TB"FUS9W-T<B`B3F]T:69I8V%R(&-O;6\@<W!A;2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B
M4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`B4V]L:6-I=&%R('5N
M(&%C=7-E(&1E(%]R96-I8F\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HU-S,*;7-G:60@(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T
M<B`BOU-O;&EC:71A<B!A8W5S97,@9&4@<F5C:6)O/R(*"B,Z(&UA:6QB;W@N
M<&AP.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+B(*
M;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!M96YS86IE('-O;&EC:71A9&\N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y,@IM<V=I9"`B4F5Q
M=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B4&%R=&EC:7!A;G1E(')E<75E
M<FED;R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3,X('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHR.0HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,38R"FUS9VED(")297-E="(*;7-G<W1R("),:6UP:6%R(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-@IM<V=I9"`B4F5S<&]N9&5N
M="!3=&%T=7,@57!D871E9"XB"FUS9W-T<B`B06-T=6%L:7IA9&\@96P@97-T
M861O(&1E(')E<W!U97-T82XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R(")296%N
M=61A<B(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G:60@(E)E<W5M92!Y;W5R
M('-E<W-I;VXB"FUS9W-T<B`B4F5A;G5D87(@<V5S:?-N(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0T"FUS9VED(")2971U<FX@=&\@
M7")-97-S86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`B5F]L=F5R(&$@7")2
M961A8V-I\VX@9&5L(&UE;G-A:F5<(B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9')I=F5R7W-E;&5C="YI;F,Z,S$@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C8Y"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S
M96QE8W0N:6YC.C,Q"FUS9VED(")2971U<FX@=&\@1F5T8V@@36%I;"(*;7-G
M<W1R(")296=R97-A<B!A(%1R865R(&-O<G)E;R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHV,"!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I
M=F4N:6YC.C(R"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`Q('1E
M;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$U"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ-#D@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C,@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$W-0IM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
M4F5G<F5S87(@82!O<&-I;VYE<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C<P-PIM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X(&QI
M<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE
M<W-A9V4_(@IM<V=S='(@(B(*(K]296=R97-A<B!A;"!L:7-T861O(&1E;"!B
M=7KS;B!T<F%S(&5L:6UI;F%R+"!T<F%S;&%D87(@;R!C;W!I87(@=6X@;65N
M<V%J93\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@S"FUS9VED
M(")2;VQE(@IM<V=S='(@(D9U;F-I\VXB"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C$T,B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S-PHC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0R-`IM<V=I9"`B4R]-24U%
M(@IM<V=S='(@(E,O34E-12(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y
M<'1?;&ES="YI;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B
M"FUS9W-T<B`B365N<V%J92!C:69R861O(&5N(%,O34E-12(*"B,Z(&-O;7!O
M<V4N<&AP.C,W,0IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B17)R
M;W(@4R]-24U%.B`B"@HC.B!C;VUP;W-E+G!H<#HS-3`*;7-G:60@(E,O34E-
M12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E
M(&ME>2XB"FUS9W-T<B`B(@HB17)R;W(@4R]-24U%.B!(86-E(&9A;'1A('5N
M82!F<F%S92!C;&%V92!P87)A(&QA(&-L879E('!E<G-O;F%L('!R:79A9&$N
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,34Q"FUS9VED(")3
M+TU)344@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYE<R!3+TU)344B"@HC.B!S
M;6EM92YP:'`Z-#8*;7-G:60@(E,O34E-12!087-S<&AR87-E($EN<'5T(@IM
M<V=S='(@(D5N=')A9&$@9&4@9G)A<V4@8VQA=F4@4R]-24U%(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B4R]-24U%(%!E<G-O
M;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B(@HB2&%C92!F86QT82!U;F$@8V]N97AI\VX@
M=V5B('-E9W5R82!P87)A('5T:6QI>F%R(&5L('-O<&]R=&4@9&4@8VQA=F5S
M("(*(G!E<G-O;F%L97,@4R]-24U%(@H*(SH@<VUI;64N<&AP.C$S-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@7"(E<UPB
M('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B4V4@:&$@96QI
M;6EN861O(&-O<G)E8W1A;65N=&4@;&$@8VQA=F4@4R]-24U%('#Z8FQI8V$@
M9&4@7"(E<UPB+B(*"B,Z('-M:6UE+G!H<#HQ-3@*;7-G:60@(E,O34E-12!0
M=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B4V4@:&$@
M8?%A9&ED;R!C;W)R96-T86UE;G1E(&QA(&-L879E('#Z8FQI8V$@4R]-24U%
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-
M24U%(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(DQL879E<F\@4R]-24U%('#Z
M8FQI8V\B"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")3+TU)344@4'5B;&EC
M+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(E-E(&AA;B!A\6%D:61O(&-O<G)E8W1A;65N=&4@;&%S(&-L879E<R!P^F)L
M:6-A+W!R:79A9&$@4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC
M<GEP=%]L:7-T+FEN8SHQ,PIM<V=I9"`B4R]-24U%(%-I9VX@365S<V%G92(*
M;7-G<W1R(")-96YS86IE(&-O;B!F:7)M82!3+TU)344B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$T"FUS9VED(")3+TU)344@
M4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B365N<V%J92!F:7)M861O
M+V-I9G)A9&\@96X@4R]-24U%(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C
M=&EV92YI;F,Z-`IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@
M;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(D5N(&5S=&4@<VES=&5M82!S92!H
M82!D97-A8W1I=F%D;R!E;"!S;W!O<G1E(%,O34E-12XB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U<'!O
M<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES
M('5N86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(B(*(D5L('-O
M<&]R=&4@4R]-24U%(&YO(&5S=.$@86-T:79A9&\@86-T=6%L;65N=&4@<&]R
M(&QO('%U92!N;R!S92!P=65D92`B"B)D97-C:69R87(@96P@;65N<V%J92XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PIM<V=I9"`B(@HB
M4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S
M(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N;F]T("(*(F)E(&1I<W!L87EE
M9"XB"FUS9W-T<B`B(@HB16P@<V]P;W)T92!3+TU)344@;F\@97-TX2!A8W1I
M=F%D;R!P;W(@;&\@<75E(&YO('-E('!U961E(&UO<W1R87(@96P@(@HB8V]N
M=&5N:61O9&4@97-T92!M96YS86IE(&9I<FUA9&\N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T
M(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U
M;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(D5L('-O<&]R
M=&4@4R]-24U%(&YO(&5S=.$@86-T:79A9&\@86-T=6%L;65N=&4@<&]R(&QO
M('%U92!N;R!S92!P=65D92`B"B)C;VUP<F]B87(@;&$@9FER;6$@9&EG:71A
M;"XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*
M(E,O34E-12!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@
M=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O
M(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@
M<V5T=&EN9R!O<B!E;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N
M;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(D5L('-O<&]R=&4@4R]-
M24U%(&YE8V5S:71A('5T:6QI>F%R('9E;G1A;F%S(&5M97)G96YT97,N(%-I
M(&QA<R!H82`B"B)D97-A8W1I=F%D;R!E;B!S=2!N879E9V%D;W(L('1E;F1R
MX2!Q=64@<F5A8W1I=F%R;&%S(&\@;&%S(&-A<F%C=&5R[7-T:6-A<R!3+R(*
M(DU)344@;F\@9G5N8VEO;F%RX6X@8V]R<F5C=&%M96YT92XB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P-`IM<V=I9"`B4TU44"(*;7-G<W1R
M(")33510(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4U
M"FUS9VED(")37W5B:F5C="(*;7-G<W1R(")!<U]U;G1O(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S8S"FUS9VED(")385]V92!A(&-O
M<'D@:6X@(@IM<V=S='(@(D=U87)?9&%R('5N82!C;W!I82!E;B`B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@
M(E-A7W9E(&%S(@IM<V=S='(@(D=U87)D87(@8V]M;R`H7W<I(@H*(SH@<V5A
M<F-H+G!H<#HS,#@@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W
M"FUS9VED(")3879E(@IM<V=S='(@(D=U87)D87(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU,S8*;7-G:60@(E-A=F4@071T86-H;65N
M=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_(@IM<V=S='(@
M(K]'=6%R9&%R(&%D:G5N=&]S(&-O;B!L;W,@;65N<V%J97,@96X@;&$@8V%R
M<&5T82!D92!C;W)R96\@96YV:6%D;S\B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHT,S`*;7-G:60@(E-A=F4@1')A9G0B"FUS9W-T<B`B1W5A<F1A<B!B;W)R
M861O<B(*"B,Z('-A=F5I;6%G92YP:'`Z-#(*;7-G:60@(E-A=F4@26UA9V4B
M"FUS9W-T<B`B1W5A<F1A<B!I;6%G96XB"@HC.B!L:6(O34E-12]#;VYT96YT
M<RYP:'`Z,C(X"FUS9VED(")3879E($EM86=E(&EN($=A;&QE<GDB"FUS9W-T
M<B`B1W5A<F1A<B!I;6%G96X@96X@;&$@9V%L97+M82(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,R!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O;F]T
M86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(D=U
M87)D87(@;W!C:6]N97,B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z-#`*;7-G:60@(E-A=F4@4W1A=&EO;F5R>2(*;7-G<W1R(")'=6%R
M9&%R('!L86YT:6QL82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,`IM<V=I
M9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B7T=U87)D87(@8F]R<F%D;W(B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G
M:60@(E-A=F4@87,B"FUS9W-T<B`B1W5A<F1A<B!C;VUO(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z-3(Q"FUS9VED(")3879E(&1R869T<R!A
M<R!U;G-E96X_(@IM<V=S='(@(K]'=6%R9&%R(&)O<G)A9&]R97,@8V]M;R!N
M;R!L9>UD;W,_(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3`V
M,0IM<V=I9"`B4V%V92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE
M(&1E9F%U;'0@861D<F5S<R!B;V]K/R(*;7-G<W1R("(B"B*_0?%A9&ER(&%U
M=&]MX71I8V%M96YT92!L;W,@9&5S=&EN871A<FEO<R!A(&QA($QI8G)E=&$@
M9&4@9&ER96-C:6]N97,@<&]R("(*(F]M:7-I\VX_(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHQ,C(*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@
M=FER='5A;"!F;VQD97(_(@IM<V=S='(@(K]'=6%R9&%R(&+Z<W%U961A(&-O
M;6\@=6YA(&-A<G!E=&$@=FER='5A;#\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HR,S`*;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R
M("*_1W5A<F1A<B!C;W)R96\@96YV:6%D;S\B"@HC.B!C;VUP;W-E+G!H<#HQ
M,C8S"B,L('!H<"UF;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I
M;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R
M(")&86QL;R!A;"!G=6%R9&%R(&5L(&)O<G)A9&]R+B#)<W1O(&5S(&QO('%U
M92!D:6IO(&5L('-E<G9I9&]R.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI
M;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z-30*;7-G:60@
M(E-E87)C:"(*;7-G<W1R(")"=7-C87(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@)7,B"FUS9W-T<B`B0G5S
M8V%R(&5N("5S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3(P
M"FUS9VED(")396%R8V@@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYE<R!D92!B
M^G-Q=65D82(*"B,Z('-E87)C:"YP:'`Z,C8S"FUS9VED(")396%R8V@@4F5S
M=6QT<R(*;7-G<W1R(")297-U;'1A9&]S(&1E(&QA(&+Z<W%U961A(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM<V=S='(@(DQE[61O
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHY"FUS9VED(")3
M96QE8W0B"FUS9W-T<B`B4V5L96-C:6]N87(B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-S`*;7-G:60@(E-E;&5C="!!;F]T:&5R($%C
M8V]U;G0B"FUS9W-T<B`B4V5L96-C:6]N92!O=')A(&-U96YT82(*"B,Z('1E
M;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B4V5L96-T(&$@
M9&%T92(*;7-G<W1R(")396QE8V-I;VYE('5N82!F96-H82(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHQ,`IM<V=I9"`B4V5L96-T(&$@9FEE
M;&0B"FUS9W-T<B`B4V5L96-C:6]N92!U;B!C86UP;R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PIM<V=I9"`B4V5L96-T(&$@<W1A
M=&EO;F5R>3HB"FUS9W-T<B`B4V5L96-C:6]N87(@=6YA('!L86YT:6QL83HB
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E
M;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R
M8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB4V5L96-C:6]N82!L
M82!L:6)R971A(&1E(&1I<F5C8VEO;F5S(&]R:6=E;B!P87)A(&%D:6-I\VX@
M>2!B^G-Q=65D82!D92`B"B)D:7)E8V-I;VYE<RXB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@
M(E-E;&5C8VEO;F%R('1O9&%S(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C
M97-E;&5C="YI;F,Z,S(S"FUS9VED(")396QE8W0@86QL(&9I96QD<R!T;R!S
M96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R(")%;&EJ
M82!L;W,@8V%M<&]S(&5N(&QO<R!Q=64@8G5S8V%R(&%L(&5X<&%N9&ER(&1I
M<F5C8VEO;F5S+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S
M96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R
M(")396QE8V-I;VYE('5N82!C=65N=&$B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C@Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")!;G5L
M87(@<V5L96-C:?-N(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA
M9V4N:6YC.CD*;7-G:60@(E-E;&5C="!T:&4@9V%L;&5R>2!T;R!S879E('1H
M92!I;6%G92!I;BXB"FUS9W-T<B`B4V5L96-C:6]N92!L82!G86QE<NUA(&5N
M(&QA('%U92!G=6%R9&%R(&QA(&EM86=E;BXB"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@=&AE
M(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T<B`B4V5L96-C:6]N92!E;"!T:7!O
M(&1E('-E<G9I9&]R(&1E(&-O<G)E;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M;W5R8V5S96QE8W0N:6YC.C,P.0IM<V=I9"`B4V5L96-T960@061D<F5S<R!B
M;V]K<SHB"FUS9W-T<B`B3&EB<F5T87,@9&4@9&ER96-C:6]N97,@<V5L96-C
M:6]N861A<SHB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@
M(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`B16YV:6%R
M(&-L879E(&%L('-E<G9I9&]R(&1E(&-L879E<R!P^F)L:6-O(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PIM<V=I9"`B4V5N9"!,871E<W0@
M26YF;W)M871I;VXB"FUS9W-T<B`B16YV:6%R(&EN9F]R;6%C:?-N(&%C='5A
M;&EZ861A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(X"FUS9VED(")396YD
M($UE<W-A9V4B"FUS9W-T<B`B16YV:6%R(&UE;G-A:F4B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FIS.C$R-@IM<V=I9"`B4V5N9"!M97-S86=E
M('=I=&AO=70@82!3=6)J96-T/R(*;7-G<W1R("*_16YV:6%R(&5L(&UE;G-A
M:F4@4TE.($%S=6YT;S\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HV.3(*;7-G:60@(E-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D
M(&)Y('1H92!S96YD97(_(@IM<V=S='(@(K]%;G9I87(@8V]N9FER;6%C:?-N
M(&1E(&QE8W1U<F$@<VD@;&\@<V]L:6-I=&$@96P@<F5M:71E;G1E/R(*"B,Z
M(&9O;&1E<G,N<&AP.C,W.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G
M<W1R(")#87)P971A(&1E(&-O<G)E;W,@96YV:6%D;W,B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,X"FUS9VED(")396YT(&UA
M:6P@9F]L9&5R.B(*;7-G<W1R(")#87)P971A(&1E(&-O<G)E;W,@96YV:6%D
M;W,Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S,@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-#4*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ-3(*;7-G:60@(E-E<G9E<B(*;7-G<W1R(")397)V:61O<B(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(S"FUS9VED(")397)V
M97(@86YD($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VGS
M;B!D92!S97)V:61O<B!Y(&1E(&-A<G!E=&$B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B
M4V5R=FED;W(Z(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#`*
M;7-G:60@(E-E="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@
M>6]U(&UO=F4@86YD(&1E;&5T92!M97-S86=E<RXB"FUS9W-T<B`B(@HB17-T
M86)L96-E('!R969E<F5N8VEA<R!D92!L;R!Q=64@;V-U<G)I<N$@86P@=')A
M<VQA9&%R(&\@96QI;6EN87(@;65N<V%J97,N(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3970@=&AE(%@M4')I;W)I='D@
M:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R("*_17-T
M86)L96-E<B!L82!C86)E8V5R82!8+5!R:6]R:71Y(&%L(')E9&%C=&%R(&UE
M;G-A:F5S/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,Q"FUS
M9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(D-O;7!A<G1I<B!C87)P971A
M<R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@IM<V=I9"`B4VAA<F4@
M;6%I;"!F;VQD97)S(@IM<V=S='(@(D-O;7!A<G1I<B!C87)P971A<R!D92!C
M;W)R96\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I
M9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB
M"FUS9W-T<B`B0V]M<&%R=&ER('-U<R!C87)P971A<R!D92!C;W)R96\@8V]N
M(&]T<F]S('5S=6%R:6]S+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C8U-PIM<V=I9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T
M960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N
M(&)E("(*(G1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+B(*
M;7-G<W1R("(B"B*_36]S=')A<B!U(&]C=6QT87(@<&]R(&]M:7-I\VX@;&]S
M(&)L;W%U97,@9W)A;F1E<R!D92!T97AT;R!C:71A9&\_(%-E('!U961E("(*
M(F-O;FUU=&%R(&-O;B!F86-I;&ED860@96QI:F$@;&\@<75E(&5L:6IA+B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW"FUS9VED(")3:&]U;&0@=&AE
M(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!0
M1U`@9&%T83\B"FUS9W-T<B`BOT)U<V-A<B!D871O<R!01U`@96X@96P@8W5E
M<G!O(&1E(&QO<R!M96YS86IE<R!D92!T97AT;R]P;&%N;S\B"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@
M8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T
M/R(*;7-G<W1R("*_0V5R<F%R(&QA('9E;G1A;F$@9&4@<F5D86-C:?-N('1R
M87,@9W5A<F1A<B!U;B!B;W)R861O<C\B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-`IM<V=I9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@
M8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*;7-G
M<W1R("*_061J=6YT87(@<&]R(&]M:7-I\VX@;&$@8VQA=F4@4$=0('#Z8FQI
M8V$@82!L;W,@;65N<V%J97,_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHY,@IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")-;W-T
M<F%R('1O9&%S(&QA<R!C87)P971A<R(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VAE861E<G,N:6YC.C8W"FUS9VED(")3:&]W($%L;"!(96%D97)S(@IM<V=S
M='(@(DUO<W1R87(@=&]D87,@;&%S(&-A8F5C97)A<R(*"B,Z(&UA:6QB;W@N
M<&AP.C,U,0IM<V=I9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(DUO<W1R87(@
M96QI;6EN861O<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC
M.C8Q"FUS9VED(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R(")-;W-T
M<F%R(&-A8F5C97)A<R!R961U8VED87,B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]H96%D97)S+FEN8SHW,`IM<V=I9"`B4VAO=R!-86EL:6YG($QI<W0@26YF
M;W)M871I;VXB"FUS9W-T<B`B36]S=')A<B!I;F9O<FUA8VGS;B!D92!L:7-T
M87,@9&4@8V]R<F5O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY
M,@IM<V=I9"`B4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<R(*;7-G<W1R
M(")-;W-T<F%R('/S;&\@8V%R<&5T87,@<W5S8W)I=&%S(@H*(SH@9F]L9&5R
M<RYP:'`Z,C@T"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")-
M;W-T<F%R(&YO('-U<V-R:71O<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C4Y-@IM<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP
M<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*;7-G<W1R("(B
M"B*_36]S=')A<B!U;B!I8V]N;R!P87)A('!E<FUI=&ER(&QA(&5L:6UI;F%C
M:?-N(&1E(&QO<R!A9&IU;G1O<R!D92!L;W,@(@HB;65N<V%J97,_(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3DQ"FUS9VED(")3:&]W(&QE
M9V5N9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R("*_36]S=')A<B!C
M;VUE;G1A<FEO<R!E;B!L82!V:7-T82!D96P@8G5Z\VX_(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z.#(Y"FUS9VED(")3:&]W('!R979I97=S
M(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\B"FUS9W-T<B`BOTUO<W1R87(@
M=FES=&$@<')E=FEA('/S;&\@9&4@;&]S(&UE;G-A:F5S('-I;B!L965R/R(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C@S-PIM<V=I9"`B4VAO
M=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\B"FUS9W-T<B`BOTUO<W1R87(@=FES
M=&$@<')E=FEA(&5N(&QO<R!C;VYS96IO<S\B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HX-C8*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA:6P@
M:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`BOTUO<W1R87(@96P@:6-O
M;F\@5')A97(@8V]R<F5O(&5N(&QA(&)A<G)A(&1E(&UE;OH_(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VAT;6PN<&AP.CDX"FUS9VED(")3:&]W('1H92!);6%G
M97,B"FUS9W-T<B`B36]S=')A<B!I;>%G96YE<R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHU-`IM<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC
M;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(K]-;W-T<F%R(&5L(&EC;VYO
M(&1E(&9I;'1R861O(&5N(&QA(&)A<G)A(&1E(&UE;OH_(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C,Q"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O
M9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(K]-;W-T<F%R(&5L(&[Z;65R
M;R!T;W1A;"!D92!M96YS86IE<R!P;W(@8V%R<&5T83\B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HV-30*;7-G:60@(E-H;W=N(@IM<V=S='(@
M(DUO<W1R861O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHT,@IM<V=I9"`B4VE?>F4B"FUS9W-T<B`B5&%?;6'Q;R(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*;7-G:60@(E-I9VYE
M9"(*;7-G<W1R(")&:7)M861O(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%M8?%O(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM
M<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@(D]R9&5N87(@<&]R(&QL
M96=A9&$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C$V"FUS9VED(")3;W)T(&)Y($1A=&4B"FUS9W-T<B`B3W)D96YA<B!P
M;W(@9F5C:&$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C(V"FUS9VED(")3;W)T(&)Y($9R;VT@061D<F5S<R(*;7-G<W1R
M(")/<F1E;F%R('!O<B!R96UI=&5N=&4B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C0Q"FUS9VED(")3;W)T(&)Y($UE<W-A
M9V4@4VEZ92(*;7-G<W1R(")/<F1E;F%R('!O<B!T86UA\6\@9&5L(&UE;G-A
M:F4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C,V"FUS9VED(")3;W)T(&)Y(%-U8FIE8W0B"FUS9W-T<B`B3W)D96YA<B!P
M;W(@87-U;G1O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHS,0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B3W)D
M96YA<B!P;W(@<V5C=65N8VEA(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S
M(@IM<V=S='(@(D]R9&5N87(@<&]R(&1E<W1I;F%T87)I;R(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR,PIM<V=I9"`B4W!A;2!F;VQD
M97(Z(@IM<V=S='(@(D-A<G!E=&$@9&4@<W!A;3HB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R<R(*;7-G<W1R(")#87)A8W1E<F5S(&5S<&5C:6%L97,B"@HC.B!S96%R
M8V@N<&AP.C$T,@IM<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N
M;F]T(&)E(&5D:71E9"XB"FUS9W-T<B`B3&%S(&-A<G!E=&%S('9I<G1U86QE
M<R!E<W!E8VEA;&5S(&YO('-E('!U961E;B!M;V1I9FEC87(N(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0S"FUS9VED(")3<&5L;"!#
M:&5C:R(*;7-G<W1R(")#;W)R96-C:?-N(&]R=&]G<N%F:6-A(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")3<&5L;"!#
M:&5C:V5R(@IM<V=S='(@(D-O<G)E8W1O<B!O<G1O9W+A9FEC;R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L
M971E(@IM<V=S='(@(D-O<G)E8V-I\VX@;W)T;V=RX69I8V$@8V]M<&QE=&$B
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@(E-P
M96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N
M(@IM<V=S='(@(B(*(D[Z;65R;R!D92!E<G)O<F5S(&]R=&]G<N%F:6-O<R!P
M;W(@<&%N=&%L;&$@9'5R86YT92!L82!C;W)R96-C:?-N("(*(F]R=&]G<N%F
M:6-A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#<@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4P.0HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C0R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#0*;7-G:60@
M(E-T87)T(@IM<V=S='(@(D5M<&EE>F$B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS,3$*;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`B4&QA;G1I;&QA(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3
M=&%T:6]N97)Y(&YA;64Z(@IM<V=S='(@(DYO;6)R92!D92!L82!P;&%N=&EL
M;&$Z(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS
M9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(E1I<&\@9&4@<&QA;G1I
M;&QA.B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM
M<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B4&QA;G1I;&QA.B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#,*;7-G:60@(E-T871U<R(*;7-G
M<W1R(")%<W1A9&\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C,Y"FUS
M9VED(")3=')I<"!!='1A8VAM96YT(@IM<V=S='(@(D5L:6UI;F%R(&%D:G5N
M=&\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX,C$*;7-G:60@
M(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S='(@(K]%>'1R865R('-A;'1O<R!D
M92!L[6YE83\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C,W"FUS9VED(")3=6)?:F5C="(*;7-G<W1R(")!<U]U;G1O(@H*
M(SH@;65S<V%G92YP:'`Z,C<V('1H<F5A9"YP:'`Z,34U('1E;7!L871E<R]C
M;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C4*(SH@;&EB+U-E87)C:"YP:'`Z-C`U
M"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D%S=6YT;R(*"B,Z(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.CDP.0IM<V=I9"`B4W5B:F5C="!&:65L9"(*
M;7-G<W1R(")0;W(@87-U;G1O(@H*(SH@<V5A<F-H+G!H<#HS,3`@=&5M<&QA
M=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C$X"B,Z('1E;7!L871E<R]S
M;6EM92]P87-S<&AR87-E+FEN8SHR,"!T96UP;&%T97,O<&=P+W!A<W-P:')A
M<V4N:6YC.C,Q"FUS9VED(")3=6)M:70B"FUS9W-T<B`B16YV:6%R(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3$*;7-G:60@(E-U8G-C
M<FEB92!T;R!&;VQD97(H<RDB"FUS9W-T<B`B4W5S8W)I8FER<V4@82!L82AS
M*2!C87)P971A*',I(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS
M.#4@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDS"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C@W"FUS9VED(")3=6-C97-S(@IM<V=S='(@(LEX
M:71O(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@V"FUS
M9VED(")3=6=G97-T:6]N<R(*;7-G<W1R(")3=6=E<F5N8VEA<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3D@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8V,0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")297-U;65N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,SDW('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,`IM<V=I9"`B4W=I=&-H($-O;7!O
M<VET:6]N($UE=&AO9"(*;7-G<W1R(")#;VYM=71A<B!MZ71O9&\@9&4@<F5D
M86-C:?-N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`Q
M"FUS9VED(")3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R(")#
M;VYM=71A<B!A(')E9&%C8VGS;B!(5$U,(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#`Q"FUS9VED(")3=VET8V@@=&\@<&QA:6X@=&5X
M="!C;VUP;W-I=&EO;B(*;7-G<W1R(")#;VYM=71A<B!A(')E9&%C8VGS;B!D
M92!T97AT;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Q
M-@IM<V=I9"`B5&5?>'0B"FUS9W-T<B`B7U1E>'1O(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(W,`IM<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T
M<B`B4')O=FES:6]N86PZ("(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#8*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S
M='(@(D%C97!T87(@<&5T:6-I\VX@<')O=FES:6]N86QM96YT92(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-30*;7-G:60@(E1E;G1A=&EV96QY
M($%C8V5P=&5D(@IM<V=S='(@(D%C97!T861A('!R;W9I<VEO;F%L;65N=&4B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O9B!397)V:6-E(&9I;&4@
M;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G<W1R(").;R!S92!H86X@
M:6YD:6-A9&\@;&]S('3I<FUI;F]S(&1E;"!A<F-H:79O(&1E('-E<G9I8VEO
M(&5N(&-O;F8N<&AP(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C,P"FUS9VED(")497AT(@IM<V=S='(@(E1E>'1O(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z.30S"FUS9VED(")4:&4@1G)O;3H@8V]L
M=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@
M(D/S;6\@=FEN8W5L87(@;&$@8V]L=6UN82!$93H@9&5L(&UE;G-A:F4Z(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,C4*;7-G:60@(B(*(E1H92!)34%0
M('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@875T:&5N
M=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).;R!P87)E
M8V4@<75E(&5L('-E<G9I9&]R($E-05`@<V]P;W)T92!E;"!S:7-T96UA(&1E
M(&%U=&5N=&EF:6-A8VGS;B`B"B)S96QE8V-I;VYA9&\N(%#S;F=A<V4@96X@
M8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0IM<V=I9"`B
M5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(@IM<V=S='(@(D9O<FL@9&4@
M<F5C=7)S;W,@9&4@36%C:6YT;W-H(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P
M<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C
M:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM
M<V=S='(@(E-E('!U961E(&1E<V-A<F=A<B`E<R!E;"!F;W)K(&1E(')E8W5R
M<V]S(&1E($UA8VEN=&]S:"XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!L82!C=65N
M=&$@7"(E<UPB+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HW-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@<V%V
M960N(@IM<V=S='(@(E-E(&AA(&=U87)D861O(&QA(&-U96YT82!<(B5S7"(N
M(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT
M('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N='+S(&5L(&%D
M:G5N=&\N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q"FUS9VED
M(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(DQO<R!D
M871O<R!D92!L82!A9V5N9&$@;F\@<V]N(';A;&ED;W,B"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N
M=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B
M02!C;VYT:6YU86-I\VX@97-TX2!E;"!C;VYT96YI9&\@9&5L(&%R8VAI=F\@
M36%C:6YT;W-H+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S
M96YT;6%I;%]M;VYT:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T
M;R!<(B5S7"(N(@IM<V=S='(@(DQA*',I(&-A<G!E=&$H<RD@7"(E<UPB('-E
M(')E;F]M8G)A<N$H;BD@8V]M;R!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U
M<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@
M<F5T<FEE=F5D(@IM<V=S='(@(B(*(DYO('-E('!U961E(&]B=&5N97(@;&$@
M;&ES=&$@9&4@=7-U87)I;W,@86-T=6%L('%U92!T:65N96X@86-C97-O(&$@
M97-T82`B"B)C87)P971A(@H*(SH@8V]M<&]S92YP:'`Z,3(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE
M(%PB)7-<(B!F;VQD97(N(@IM<V=S='(@(E-E(&AA(&=U87)D861O(&5L(&)O
M<G)A9&]R(&5N(&QA(&-A<G!E=&$@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ-#`*;7-G:60@(E1H92!E=F5N="!W87,@861D960@
M=&\@>6]U<B!C86QE;F1A<BXB"FUS9W-T<B`B4V4@:&$@8?%A9&ED;R!E;"!A
M8V]N=&5C:6UI96YT;R!A(&QA(&%G96YD82XB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E>'!A;F0N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M96QD(%PB)7-<(B!C86XG="!B92!E>'!A;F1E9"XB"FUS9W-T<B`B3F\@<V4@
M<'5E9&4@97AP86YD:7(@96P@8V%M<&\@7"(E<UPB+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(")982!E>&ES=&4@;&$@8V%R
M<&5T82!<(B5S7"(B"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL
M96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB
M<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB3&$@8V%R<&5T82!<(B5S7"(@=&EE;F4@8V%R86-T
M97)E<R!I;&5G86QE<R!E;B!E;"!N;VUB<F4N(,ES=&\@<'5E9&4@(@HB;W)I
M9VEN87(@<')O8FQE;6%S+B!#;VYS=6QT92!A;"!A9&UI;FES=')A9&]R(&1E
M('-I<W1E;6%S+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@8W)E871E9"!B=70@
M>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@:70N(@IM<V=S='(@(E-E(&AA
M(&-R96%D;R!L82!C87)P971A(%PB)7-<(B!P97)O(&YO('-E(&AA('-U<V-R
M:71O(&$@96QL82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T
M('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B
M4V4@:&$@96QI;6EN861O(&QA(&-A<G!E=&$@7"(E<UPB('!E<F\@;F\@<V4@
M:&$@9&5S=7-C<FET;R!D92!E;&QA+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,S
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@
M;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS
M9W-T<B`B3F\@<V4@:&$@8W)E861O(&QA(&-A<G!E=&$@7"(E<UPB+B#)<W1O
M(&5S(&QO('%U92!D:6IO(&5L('-E<G9I9&]R(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9"(*;7-G<W1R(").;R!S92!H82!E;&EM:6YA9&\@;&$@8V%R<&5T82!<(B5S
M7"(N(,ES=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(B"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+B(*;7-G<W1R(")3
M92!H82!C<F5A9&\@8V]R<F5C=&%M96YT92!L82!C87)P971A(%PB)7-<(BXB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*
M;7-G<W1R(")392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92!L82!C87)P
M971A(%PB)7-<(BXB"@HC.B!L:6(O1F]L9&5R+G!H<#HT-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B4V4@:&$@<F5N;VUB<F%D
M;R!C;W)R96-T86UE;G1E(&QA(&-A<G!E=&$@7"(E<UPB(&-O;6\@7"(E<UPB
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY-`IM<V=I9"`B5&AE
M(&9O;&QO=VEN9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R=#HB
M"FUS9W-T<B`B4V4@:&%B[6%N(&'Q861I9&\@;&]S(&%R8VAI=F]S('-I9W5I
M96YT97,@82!E<W1A('!A<G1E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W!O<'5P+FIS.C4Y"FUS9VED("(B"B)4:&4@:6UA9V4@<V%V92!W:6YD;W<@
M8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@
M8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B
M"B).;R!S92!P=65D92!A8G)I<B!L82!V96YT86YA(&1E(&=U87)D861O(&1E
M(&EMX6=E;F5S+B"_2&$@8V]N9FEG=7)A9&\@<W4@(@HB;F%V96=A9&]R('!A
M<F$@<75E(&)L;W%U964@;&%S('9E;G1A;F%S(&5M97)G96YT97,_(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P,`IM<V=I9"`B(@HB5&AE(&EM
M86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@:7,@
M<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R("(B"B)3
M92!M;W-T<F%RX6X@;&%S(&EMX6=E;F5S('EA('%U92!E;"!R96UI=&5N=&4@
M97-TX2!E;B!S=2!,:6)R971A(&1E("(*(F1I<F5C8VEO;F5S+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I;"!S
M97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93HB
M"FUS9W-T<B`B16P@<V5R=FED;W(@9&4@8V]R<F5O(&AA(&=E;F5R861O(&5L
M('-I9W5I96YT92!M96YS86IE(&1E(&5R<F]R.B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"FUS9VED(")4:&4@;6%I;"!S97)V
M97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S
M86=E.B(*;7-G<W1R(")%;"!S97)V:61O<B!D92!C;W)R96\@:&$@9V5N97)A
M9&\@96P@<VEG=6EE;G1E(&UE;G-A:F4@9&4@:6YF;W)M86-I\VXZ(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H92!M86EL
M('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.B(*;7-G
M<W1R(")%;"!S97)V:61O<B!D92!C;W)R96\@:&$@9V5N97)A9&\@96P@<VEG
M=6EE;G1E(&UE;G-A:F4Z(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M
M<'1Y+B(*;7-G<W1R(")%;"!B=7KS;B`E<R!Y82!E<W3A('9A8^UO+B(*"B,Z
M(&QI8B]&971C:&UA:6PN<&AP.C(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E
M961S(&9E=&-H('-I>F4@;&EM:70N(@IM<V=S='(@(B(*(D5L(&UE;G-A:F4@
M7"(E<UPB(&1E(%PB)7-<(B`H)60@8GET97,I('-U<&5R82!E;"!T86UA\6\@
M;.UM:71E(&1E(&]B=&5N8VGS;BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$P,PIM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M
M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")392!H
M82!C97)R861O(&5L(&UE;G-A:F4@<75E(&5S=&%B82!R961A8W1A;F1O+B!3
M86QI96YD;RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$R
M-@IM<V=I9"`B5&AE(&UE<W-A9V4@9&]E<R!N;W0@:&%V92!A(%-U8FIE8W0@
M96YT97)E9"XB"FUS9W-T<B`B16P@;65N<V%J92!C87)E8V4@9&4@07-U;G1O
M+B(*"B,Z(&UE<W-A9V4N<&AP.C$T.0IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&5L(&UE
M;G-A:F4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDW"FUS9VED
M(")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"XB"FUS9W-T<B`B4V4@
M:&$@8V]M<')O8F%D;R!E;"!M96YS86IE+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,S@Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S
M86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R(")3
M92!H82!C;VUP<F]B861O(&5L(&UE;G-A:F4N(%)E;6ET96YT93H@)7,N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N
M(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B4V4@<'5E9&4@=F5R("5S(&5L('1E
M>'1O(&1E(&QA(&-L879E(%!'4"!P^F)L:6-A+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O
M97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S
M='(@(DYO(&5X:7-T92!E;"!A<F-H:79O('-O;&EC:71A9&\@96X@96P@861J
M=6YT;R!-4RU43D5&+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T
M"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@
M=&AE(%II<"!A='1A8VAM96YT+B(*;7-G<W1R(").;R!E>&ES=&4@96P@87)C
M:&EV;R!S;VQI8VET861O(&5N(&5L(&%D:G5N=&\@6FEP+B(*"B,Z(&UE<W-A
M9V4N<&AP.C4U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R
M(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V
M92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@
M=&AE("(*(FYO=&EF:6-A=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"B)%;"!R
M96UI=&5N=&4@9&4@97-T92!M96YS86IE(&QE('-O;&EC:71A('5N82!.;W1I
M9FEC86-I\VX@9&4@0V]N<W5L=&$@9&4@(@HB365N<V%J92!C=6%N9&\@;&\@
M:&%Y82!L9>UD;RX@4'5L<V4@)7,@<&%R82!E;G9IX7)S96QA+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8W"FUS9VED(")4:&4@<V5R=F5R
M('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I
M;6%G92XB"FUS9W-T<B`B16P@<V5R=FED;W(@;F\@<'5D;R!G96YE<F%R('5N
M82!M:6YI871U<F$@9&4@97-T82!I;6%G96XN(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YJ<SHY,`IM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L
M9"!N;W0@8F4@<F5P;&%C960N(@IM<V=S='(@(DYO('-E('!U9&\@<W5S=&ET
M=6ER(&QA(&9I<FUA+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:G,Z.#@*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R
M97!L86-E9"XB"FUS9W-T<B`B4V4@<W5S=&ET=7GS(&-O<G)E8W1A;65N=&4@
M;&$@9FER;6$N(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S
M<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B16P@87)C
M:&EV;R!E<W!E8VEF:6-A9&\@;F\@97AI<W1E+B(*"B,Z('-T871I;VYE<GDN
M<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB
M)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T<B`B4V4@:&$@8?%A9&ED;R!L
M82!P;&%N=&EL;&$@7"(E<UPB+B(*"B,Z('-T871I;VYE<GDN<&AP.C8S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@;&$@<&QA
M;G1I;&QA(%PB)7-<(BXB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@
M=7!D871E9"XB"FUS9W-T<B`B4V4@:&$@86-T=6%L:7IA9&\@;&$@<&QA;G1I
M;&QA(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<P
M"FUS9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML
M:7-T+B(*;7-G<W1R(")392!H82!A\6%D:61O(&QA('1A<F5A(&$@<W4@;&ES
M=&$@9&4@=&%R96%S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.CDU"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92(*;7-G<W1R(")%
M;"!T97AT;R!D96P@;65N<V%J92(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H
M92!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(E-E('!U961E
M('9E<B`E<R!E;"!T97AT;R!D96P@;65N<V%J92XB"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HX,`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E
M='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`B16P@=&5X=&\@9&5L(&UE;G-A:F4@
M9&5V=65L=&\B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@
M;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")392!P=65D92!V
M97(@)7,@96P@=&5X=&\@9&5L(&UE;G-A:F4@9&5V=65L=&\N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*;7-G:60@(E1H92!T
M97AT(&]F('1H92!S96YT(&UE<W-A9V4B"FUS9W-T<B`B16P@=&5X=&\@9&5L
M(&UE;G-A:F4@96YV:6%D;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F
M('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B
M4V4@<'5E9&4@=F5R("5S(&5L('1E>'1O(&1E;"!M96YS86IE(&5N=FEA9&\N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-0IM<V=I9"`B5&AE
M('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY
M('-T;W)E9"XB"FUS9W-T<B`B(@HB4V4@86QM86-E;O,@8V]R<F5C=&%M96YT
M92!L82!I;F9O<FUA8VGS;B!D92!T:65M<&\@9&ES<&]N:6)L92!D96P@=7-U
M87)I;RXB"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C@V
M"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3F\@:&%Y('!A<G1E
M<R!A;'1E<FYA=&EV87,@<75E('-E('!U961A;B!M;W-T<F%R(&5N(&SM;F5A
M+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V5M<'1Y7VUA:6QB;W@N:6YC.C,*
M;7-G:60@(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N
M(@IM<V=S='(@(DYO(&AA>2!M96YS86IE<R!E;B!E<W1E(&)U>O-N+B(*"B,Z
M('1H<F5A9"YP:'`Z,3$P"FUS9VED(")4:&5R92!I<R!N;R!T97AT('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DYO(&AA>2!T97AT
M;R!Q=64@<V4@<'5E9&$@;6]S=')A<B!E;B!L[6YE82XB"@HC.B!L:6(O365S
M<V%G92YP:'`Z-CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@<V5R=F5R('-A
M:60Z("5S(@IM<V=S='(@(B(*(E-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@
M=F%C:6%R(&5L(&)U>O-N+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L('-E<G9I
M9&]R.B`E(@HB<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S
M<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE
M("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E-E('!R;V1U:F\@=6X@97)R
M;W(@86P@8V]P:6%R(&UE;G-A:F5S(&1E(%PB)7-<(B!A(%PB)7-<(BX@R7-T
M;R!E<R!L;R!Q=64@(@HB9&EJ;R!E;"!S97)V:61O<B(*"B,Z(&QI8B]-97-S
M86=E+G!H<#HR,C8@;&EB+TUE<W-A9V4N<&AP.C(T-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G
M97,@9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T("(*(G1H
M92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&5L:6UI;F%R(&UE;G-A:F5S(&1E(&QA(&-A<G!E=&$@7"(E<UPB+B#)
M<W1O(&5S(&QO("(*(G%U92!D:6IO(&5L('-E<G9I9&]R(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C,R,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<
M(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T
M<B`B(@HB4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!E;&EM:6YA<B!M96YS86IE
M<R!D92!L82!C87)P971A(%PB)7-<(BX@R7-T;R!E<R!L;R`B"B)Q=64@9&EJ
M;R!E;"!S97)V:61O<B(*"B,Z(&QI8B]-97-S86=E+G!H<#HR-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE
M<W-A9V5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G
M<W1R("(B"B)392!P<F]D=6IO('5N(&5R<F]R(&%L(&5L:6UI;F%R(&UE;G-A
M:F5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L('-E<G9I9&]R.B`E<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@
M)7,N(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@96QI;6EN87(@
M96P@86-O;G1E8VEM:65N=&\Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M;&%I;BYP:'`Z-3(@;&EB+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS-PIM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!M;W-T
M<F%R(&5S=&$@<&%R=&4@9&5L(&UE;G-A:F4B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-3DT"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@
M5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)3
M92!P<F]D=6IO('5N(&5R<F]R(&%L(&UA<F-A<B!M96YS86IE<R!D92!L82!C
M87)P971A(%PB)7-<(BX@R7-T;R!E<R!L;R!Q=64@(@HB9&EJ;R!E;"!S97)V
M:61O<B(*"B,Z(&9O;&1E<G,N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R(")3
M92!P<F]D=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*
M;7-G<W1R(")392!P<F]D=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R(&5L(&%C
M;VYT96-I;6EE;G1O.B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,38W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R(")392!P<F]D=6IO
M('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QA('1A<F5A.B`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,34S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S
M>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(B(*(E-E('!R;V1U:F\@=6X@
M97)R;W(@86P@:6UP;W)T87(@;&$@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I
M<W!O;FEB;&4@9&5L("(*(G5S=6%R:6\Z("5S+B(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N
M(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB
M4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!T<F%S;&%D87(@;65N<V%J97,@9&4@
M7"(E<UPB(&$@7"(E<UPB+B#)<W1O(&5S(&QO('%U92`B"B)D:6IO(&5L('-E
M<G9I9&]R(@H*(SH@8V]M<&]S92YP:'`Z,3(X,`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE<W-A9V4@87,@82!D<F%F="XB"FUS
M9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!G=6%R9&%R(&5S=&4@;65N
M<V%J92!C;VUO(&)O<G)A9&]R+B(*"B,Z(&-O;7!O<V4N<&AP.C$P,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@
M>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R(")392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&5N=FEA<B!E;"!M96YS86IE.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(E-E
M('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L:7IA<B!E;"!A8V]N=&5C:6UI
M96YT;SH@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU.0IM
M<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0B
M"FUS9W-T<B`B3F\@:&%B[6$@=&5X=&\@96X@97-T82!P87)T92!D96P@;65N
M<V%J92(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G:60@
M(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N
M(@IM<V=S='(@(D5S=&4@;65N<V%J92!(5$U,('1I96YE(&EMX6=E;F5S(&EN
M8V]R<&]R861A<RXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3,*
M;7-G:60@(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D
M960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L:6ME("(*(G1H:7,Z
M("(*;7-G<W1R("(B"B)%<W1E(&UE;G-A:F4@2%1-3"!T:65N92!I;>%G96YE
M<R!I;F-O<G!O<F%D87,N($QA<R!I;>%G96YE<R!B;&]Q=65A9&%S("(*(F%P
M87)E8V5N(&%S[3H@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U
M"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T
M:&4@;65S<V%G92XB"FUS9W-T<B`B4V4@861J=6YT\R!E<W1A(&-L879E(%!'
M4"!P^F)L:6-A(&%L(&UE;G-A:F4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$Y"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#0@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$U.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<T(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,34*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D5S=&$@86-C:?-N(&YO(&5S
M=.$@<V]P;W)T861A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M.#`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0R,`IM<V=I9"`B5&AI<R!A
M8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B17-T82!A
M8V-I\VX@=&]D87;M82!N;R!E<W3A(&1E<V%R<F]L;&%D82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$T"FUS9VED(")4:&ES(&UA
M>2!T86ME('-O;64@=&EM92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O
M;G1I;G5E/R(*;7-G<W1R(")%<W1O('!U961E('1A<F1A<B!U;B!R871O+B"_
M17-T82!S96=U<F\@9&4@<75E(&1E<V5A(&-O;G1I;G5A<C\B"@HC.B!L:6(O
M34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED(")4:&ES(&UE
M<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS9W-T<B`B17-T
M92!M96YS86IE(&-O;G1I96YE('5N(&%R8VAI=F\@36%C:6YT;W-H+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$U"FUS9VED("(B"B)4:&ES
M(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N
M(&1I9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS9W-T<B`B(@HB
M17-T92!M96YS86IE(&-O;G1I96YE('5N(&%D:G5N=&\@<75E('-E(&AA(&9I
M<FUA9&\@9&EG:71A;&UE;G1E(&UE9&EA;G1E(%,O(@HB34E-12XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.0IM<V=I9"`B5&AI<R!M97-S
M86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R
M>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B17-T92!M96YS86IE(&-O;G1I
M96YE('5N(&%D:G5N=&\@<75E('-E(&AA(&-I9G)A9&\@;65D:6%N=&4@4R]-
M24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,`IM<V=I
M9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A
M='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B`B"B)T:&ES(&UE
M<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T<B`B(@HB17-T92!M96YS86IE('1I
M96YE(&EN9F]R;6%C:?-N(&1E(&5S=&%D;R!D92!E;G;M;R!D96P@8V]R<F5O
M+"!P97)O(&5L("(*(F9O<FUA=&\@9&5L(&UE;G-A:F4@97,@9&5S8V]N;V-I
M9&\N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S$Y"FUS9VED("(B
M"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@(@IM<V=S='(@(D5S=&4@
M;65N<V%J92`@;F\@<&%R96-E('-E<B!U;B!M96YS86IE(&-I9G)A9&\@4$=0
M(';A;&ED;RX@17)R;W(Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(S.2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS-30*;7-G:60@(B(*(E1H
M:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E
M8W0@4$=0(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS
M9W-T<B`B(@HB17-T92!M96YS86IE(&YO('!A<F5C92!S97(@9&5L(&9O<FUA
M=&\@4$=0(&-O<G)E8W1O("AD92!A8W5E<F1O(&-O;B!L82!21D,@(@HB,C`Q
M-2DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S`*;7-G:60@
M(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O
M<G)E8W0@4R]-24U%(&9O<FUA="XB"FUS9W-T<B`B17-T92!M96YS86IE(&YO
M('!A<F5C92!E<W1A<B!E;B!E;"!F;W)M871O(%,O34E-12!C;W)R96-T;RXB
M"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z-#(P"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@
M9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G<W1R(")%<W1E(&UE;G-A
M:F4@<V4@:&$@9FER;6%D;R!D:6=I=&%L;65N=&4@;65D:6%N=&4@4$=0+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30S"FUS9VED(")4:&ES
M(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-24U%
M+B(*;7-G<W1R(")%<W1E(&UE;G-A:F4@<V4@:&$@9FER;6%D;R!D:6=I=&%L
M;65N=&4@;65D:6%N=&4@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,3,Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,X"FUS
M9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)
M344N(@IM<V=S='(@(D5S=&4@;65N<V%J92!S92!H82!C:69R861O(&UE9&EA
M;G1E(%,O34E-12XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#`@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP"FUS9VED(")4:&ES(&UE<W-A
M9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R(")%<W1E
M(&UE;G-A:F4@<V4@:&$@8VEF<F%D;R!M961I86YT92!01U`N(@H*(SH@;65S
M<V%G92YP:'`Z,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T<B`B
M17-T92!M96YS86IE(&$B"@HC.B!A8VPN<&AP.C0U"FUS9VED(")4:&ES('-E
M<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T
M<B`B17-T92!S97)V:61O<B!N;R!S;W!O<G1A(&QA(&-O;7!A<G1I8VGS;B!D
M92!C87)P971A<RXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$P.0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R(")%<W1A('9E;G1A;F$@<_-L
M;R!P=65D92!A8G)I<G-E(&1E<V1E('5N82!D92!R961A8V-I\VXN(@H*(SH@
M=&AR96%D+G!H<#HQ-3<*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@
M(E9I<W5A;&EZ87(@<V5C=65N8VEA<R(*"B,Z('1H<F5A9"YP:'`Z-S8@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3$Q"FUS9VED(")4:')E860@5FEE
M=R(*;7-G<W1R(")0;W(@<V5C=65N8VEA<R(*"B,Z(&UE<W-A9V4N<&AP.C(W
M,B!M86EL8F]X+G!H<#HV,#(@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHR,B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H
M+G!H<#HU.3,*;7-G:60@(E1O(@IM<V=S='(@(E!A<F$B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HY,#@*;7-G:60@(E1O($%D9')E<W,B"FUS
M9W-T<B`B4&]R(&1E<W1I;F%T87)I;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M;W5R8V5S96QE8W0N:6YC.C,R-@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I
M<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!W:&EL92`B"B)C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&%R
M82!S96QE8V-I;VYA<B!V87)I;W,@8V%M<&]S+"!M86YT96YG82!P=6QS861A
M(&QA('1E8VQA($-O;G1R;VP@*%!#*2!O("(*(D-O;6%N9&\@*$UA8RD@86P@
M<'5L<V%R(&-O;B!E;"!R873S;BXB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C$S-`IM<V=I9"`B(@HB5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO=2!M
M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C$N,"!O<B`B"B)H
M:6=H97(N(@IM<V=S='(@(B(*(E!A<F$@=71I;&EZ87(@=6YA(&-O;F5X:?-N
M(%1,4R!T:65N92!Q=64@=71I;&EZ87(@4$A0('9E<G-I\VX@-2XQ+C`@;R`B
M"B)S=7!E<FEO<BXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU.3$*;7-G:60@(E1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z(@IM<V=S='(@
M(E1A;6'Q;R!T;W1A;"!D92!A9&IU;G1O<SHB"@HC.B!F;VQD97)S+G!H<#HS
M-CD*;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G<W1R(")087!E;&5R82(*"B,Z
M('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C,*;7-G:60@(E1R
M87-H(&9O;&1E<CHB"FUS9W-T<B`B4&%P96QE<F$Z(@H*(SH@;&EB+U%U;W1A
M+V-Y<G5S+G!H<#HV-"!L:6(O475O=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O
M475O=&$O8V]M;6%N9"YP:'`Z-S$*(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP
M.C@X(&QI8B]1=6]T82]C;W5R:65R+G!H<#HU,R!L:6(O475O=&$O;61A96UO
M;BYP:'`Z-#@*;7-G:60@(E5N86)L92!T;R!R971R:65V92!Q=6]T82(*;7-G
M<W1R("));F-A<&%Z(&1E(&]B=&5N97(@96P@97-P86-I;R!D:7-P;VYI8FQE
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS=V5R960B"FUS
M9W-T<B`B4VEN(')E<W!O;F1E<B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z,S4*;7-G:60@(E5N86YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B
M365N<V%J97,@<VEN(')E<W!O;F1E<B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T92(*;7-G<W1R(")296-U<&5R87(B
M"@HC.B!M86EL8F]X+G!H<#HU.#`@;6%I;&)O>"YP:'`Z-3DX(&QI8B]-24U%
M+TAE861E<G,N<&AP.C(P-`IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I96YT
M<R(*;7-G<W1R(")$97-T:6YA=&%R:6]S(&]C=6QT;W,B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4U-@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;R!!551(14Y424-!5$4@8V]M;6%N9"XB"FUS9W-T<B`B
M4F5S<'5E<W1A(&EN97-P97)A9&$@9&5L('-E<G9I9&]R(&%L(&UA;F1A=&\@
M05542$5.5$E#051%+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3(P"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($1I9V5S
M="U-1#4@<F5S<&]N<V4N(@IM<V=S='(@(E)E<W!U97-T82!I;F5S<&5R861A
M(&1E;"!S97)V:61O<B!A(&QA(')E<W!U97-T82!$:6=E<W0M340U+B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-3,V"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O($Q/1TE.(&-O;6UA;F0N(@IM<V=S='(@
M(E)E<W!U97-T82!I;F5S<&5R861A(&1E;"!S97)V:61O<B!A;"!M86YD871O
M($Q/1TE.+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E
M.B`E<R(*;7-G<W1R(")#;VUP;VYE;G1E(&YO('-O<&]R=&%D;R!D92!T:7!O
M.B`E<R(*"B,Z(&UA:6QB;W@N<&AP.C4U.`IM<V=I9"`B56YK;F]W;B!$871E
M(@IM<V=S='(@(D9E8VAA(&1E<V-O;F]C:61A(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0
M(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@
M)7,B"FUS9W-T<B`B4F5S<'5E<W1A($E-05`@9&5S8V]N;V-I9&$@9&5L('-E
M<G9I9&]R+B!%;"!S97)V:61O<B!R97-P;VYD:?,Z("5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B56YK;F]W;B!-965T:6YG
M(@IM<V=S='(@(E)E=6YI\VX@9&5S8V]N;V-I9&$B"@HC.B!M86EL8F]X+G!H
M<#HV,30*;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@(D1E<W1I
M;F%T87)I;R!D97-C;VYO8VED;R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")5;FQO
M860@4&%S<W!H<F%S92(*;7-G<W1R(")/;'9I9&%R(&9R87-E(&-L879E(@H*
M(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S
M='(@(E-I;B!N;VUB<F4B"@HC.B!M97-S86=E+G!H<#HU,#,@;6%I;&)O>"YP
M:'`Z-S`S('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M-@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$U('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHU"FUS9VED(")5;G-E96XB"FUS9W-T<B`B4VEN(&QE97(B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B
M56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RDB"FUS9W-T<B`B1&5S=7-C<FEB
M:7)S92!D92!L82AS*2!C87)P971A*',I(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3$U"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B06-T
M=6%L:7IA<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3(*;7-G
M:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R(")!8W1U86QI
M>F%R(&5S=&%D;R!D92!R97-P=65S=&$B"@HC.B!T96UP;&%T97,O<VUI;64O
M:6UP;W)T7VME>2YI;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(D-A<F=A<B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*;7-G:60@(E5S92!$
M969A=6QT(%9A;'5E(@IM<V=S='(@(E5S87(@=F%L;W(@<&]R(&]M:7-I\VXB
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR-38*;7-G:60@(E5S
M92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/R(*;7-G<W1R("*_57-A<B!S
M=7-C<FEP8VEO;F5S(&$@8V%R<&5T87,@24U!4#\B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HW,C0*;7-G:60@(E5S92!6:7)T=6%L(%1R87-H
M($9O;&1E<C\B"FUS9W-T<B`BOU5S87(@<&%P96QE<F$@=FER='5A;#\B"@HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,30S"FUS9VED(")5<V5R(@IM<V=S
M='(@(E5S=6%R:6\B"@HC.B!A8VPN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E
M8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(B(*(E-E(&AA;B!C;VYC961I9&\@8V]R<F5C=&%M96YT92!A;"!U<W5A<FEO
M(%PB)7-<(B!L;W,@9&5R96-H;W,@97-P96-I9FEC861O<R`B"B)P87)A(&QA
M(&-A<G!E=&$@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,3<V"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")5<W5A<FEO(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$W"FUS9VED(")5<V5R
M;F%M93HB"FUS9W-T<B`B57-U87)I;SHB"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,C<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R(*;7-G<W1R(")697(B"@HC
M.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS
M9W-T<B`B5F5R("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR
M-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(E9E<B!C;&%V92!P^F)L
M:6-A(&1E("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0IM
M<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B
M"FUS9W-T<B`B5F5R(&-O;G1E;FED;R!(5$U,(&5N('5N82!V96YT86YA('-E
M<&%R861A(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C@*
M;7-G:60@(E9I97<@365S<V%G97,B"FUS9W-T<B`B5F5R(&UE;G-A:F5S(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+97DB
M"FUS9W-T<B`B5F5R(&-L879E('!E<G-O;F%L('!R:79A9&$B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW,@IM<V=I9"`B5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@
M(E9E<B!C;&%V92!P97)S;VYA;"!P^F)L:6-A(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")6:65W(%1H<F5A
M9"(*;7-G<W1R(")697(@<V5C=65N8VEA(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,38T(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M-@IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B5F5R(&UI;FEA='5R
M82(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"FUS9VED(")6
M:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B
M5F5R(&%D:G5N=&\@96X@=6YA('9E;G1A;F$@<V5P87)A9&$B"@HC.B!L:6(O
M34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*;7-G:60@(E9I97<@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")697(@8V]N=&5N:61O
M(&5N('5N82!V96YT86YA('-E<&%R861A(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$T,0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R(")697(@
M86-O;G1E8VEM:65N=&\B"@HC.B!F;VQD97)S+G!H<#HS-C$@;6%I;&)O>"YP
M:'`Z-3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@;65S<V%G97,@:6X@
M)7,B"FUS9W-T<B`B5F5R(&UE;G-A:F5S(&1E("5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O
M<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S='(@(E9I
M<W1A(&\@8G5Z\VX@;6]S=')A9&]S(&%L(&EN:6-I87(@;&$@<V5S:?-N.B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S$*;7-G:60@(E9I97<@
M=&%S:R(*;7-G<W1R(")697(@=&%R96$B"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3`T"FUS9VED(")6:65W('1H92!);6%G97,B"FUS9W-T<B`B
M5F5R(&QA<R!I;>%G96YE<R(*"B,Z('-E87)C:"YP:'`Z,C8P"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<(B!C<F5A=&5D('-U
M8V-E<V9U;&QY+B(*;7-G<W1R(")392!H82!C<F5A9&\@8V]R<F5C=&%M96YT
M92!L82!C87)P971A('9I<G1U86P@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])34%0+U1R964N<&AP.C$T,2!L:6(O
M24U!4"]4<F5E+G!H<#HQ-30*(SH@;&EB+TE-05`O5')E92YP:'`Z,34V(&QI
M8B])34%0+U1R964N<&AP.C$V,"!L:6(O24U!4"]4<F5E+G!H<#HQ-C$*(SH@
M;&EB+TE-05`O5')E92YP:'`Z,S<Q(&QI8B])34%0+U1R964N<&AP.C,Y-2!L
M:6(O24U!4"]4<F5E+G!H<#HT,S,*;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*
M;7-G<W1R(")6:7)T=6%L97,B"@HC.B!S96%R8V@N<&AP.C(U,@IM<V=I9"`B
M5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB"FUS9W-T<B`B3&%S
M(&-A<G!E=&%S('9I<G1U86QE<R!N96-E<VET86X@=6YA(&5T:7%U971A+B(*
M"B,Z(&QI8B]396%R8V@N<&AP.C0R,`IM<V=I9"`B5FER='5A;"!)3D)/6"(*
M;7-G<W1R(")%;G1R861A(@H*(SH@9F]L9&5R<RYP:'`Z,SDW"FUS9VED(")6
M:7)T=6%L($E.0D]8($9O;&1E<B(*;7-G<W1R(")#87)P971A(&1E($5N=')A
M9&$@=FER='5A;"(*"B,Z(&QI8B]-86EL8F]X+G!H<#HQ-38@;&EB+U-E87)C
M:"YP:'`Z,S8V"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(E!A<&5L
M97)A(@H*(SH@9F]L9&5R<RYP:'`Z,SDT"FUS9VED(")6:7)T=6%L(%1R87-H
M($9O;&1E<B(*;7-G<W1R(")#87)P971A(%!A<&5L97)A('9I<G1U86PB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$R.`IM<V=I9"`B5FER='5A
M;"!F;VQD97(@;&%B96PB"FUS9W-T<B`B171I<75E=&$@9&4@8V%R<&5T82!V
M:7)T=6%L(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-SD*;7-G
M:60@(E=A<FYI;F<B"FUS9W-T<B`B079I<V\B"@HC.B!L;V=I;BYP:'`Z,34R
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B
M0FEE;G9E;FED;W,@82`E<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C8P-PIM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M
M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P
M86T@(@HB;W(@:6YN;V-E;G0_(@IM<V=S='(@(B(*(K]1=>D@9&5B97+M86UO
M<R!H86-E<B!C;VX@;&]S(&UE;G-A:F5S('-P86T@=')A<R!H86)E<FQO<R!N
M;W1I9FEC861O(&-O;6\@(@HB<W!A;2!O(&EN;V9E;G-I=F]S/R(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C<Q-@IM<V=I9"`B(@HB5VAE;B!D
M96QE=&EN9R!M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L
M9&5R(&EN<W1E860@;V8@;6%R:VEN9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM
M<V=S='(@(B(*(D%L(&5L:6UI;F%R(&UE;G-A:F5S+""_=')A<VQA9&%R;&]S
M(&$@;&$@<&%P96QE<F$@96X@=F5Z(&1E(&UA<F-A<FQO<R!C;VUO("(*(F5L
M:6UI;F%D;W,_(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#DV
M"FUS9VED(")7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G
M92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\B"FUS9W-T<B`B06P@86)R:7(@
M=6X@8G5Z\VXL(+]E;B!Q=>D@<.%G:6YA(&1E<V5A(&5M<&5Z87(_(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A
M=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T
M83\B"FUS9W-T<B`BOT=U87)D87(@9&%T;W,@861J=6YT;W,@86P@9W5A<F1A
M<B!E;"!C;W)R96\@96YV:6%D;S\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HT,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN9R!M86EL(&]R(&5X
M<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E
M;F0@=&\@(@HB=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S
M97,@=VET:&]U="!<(D!<(BD_(@IM<V=S='(@(B(*(D%L(&5N=FEA<B!C;W)R
M96\@;R!E>'!A;F1I<B!D:7)E8V-I;VYE<RP@OU%UZ2!D;VUI;FEO('-E(&1E
M8F5R[6$@8?%A9&ER(&$@(@HB;&%S(&1I<F5C8VEO;F5S(&YO(&-A;&EF:6-A
M9&%S("AD:7)E8V-I;VYE<R!D92!C;W)R96\@<VEN(%PB0%PB*3\B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E=H:71E;&ES="(*
M;7-G<W1R("),:7-T82!B;&%N8V$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU,SD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-34R"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDV-PIM<V=I9"`B
M665S(@IM<V=S='(@(E/M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T
M8VAM86EL7VQO9VEN+G!H<#HU.`IM<V=I9"`B66]U(&%R92!A8F]U="!T;R!F
M971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N="AS*3HB"FUS
M9W-T<B`B17-TX2!A('!U;G1O(&1E('1R865R(&-O<G)E;R!D92!L82AS*2!S
M:6=U:65N=&4H<RD@8W5E;G1A*',I.B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P"FUS9VED("(B"B)9;W4@87)E(&%T
M=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@
M=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@(DEN=&5N=&$@
M96QI;6EN87(@=&]D;W,@;&]S(&UE;G-A:F5S(&1E(&QA<R!S:6=U:65N=&5S
M(&-A<G!E=&%S+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N
M9FER;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE
M=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(DEN=&5N=&$@
M96QI;6EN87(@;&$H<RD@<VEG=6EE;G1E*',I(&-A<G!E=&$H<RDN(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O
M<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B17-TX2!C
M;W!I86YD;R]T<F%S;&%D86YD;R!A('5N82!N=65V82!C87)P971A+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")9
M;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`B17-T
MX2!C<F5A;F1O('5N82!S=6(M8V%R<&5T82!D92`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-@IM<V=I9"`B66]U(&%R92!C<F5A
M=&EN9R!A('1O<"UL979E;"!F;VQD97(N(@IM<V=S='(@(D5S=.$@8W)E86YD
M;R!U;F$@8V%R<&5T82!D96P@;FEV96P@<W5P97)I;W(N(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,S$U"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!F;VQD97)S+B(*;7-G<W1R(").;R!D:7-P;VYE(&1E('!R:79I;&5G
M:6]S('!A<F$@8W)E87(@8V%R<&5T87,N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,S(R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R(").;R!D
M:7-P;VYE(&1E('!R:79I;&5G:6]S('!A<F$@8W)E87(@;>%S(&1E("5D(&-A
M<G!E=&%S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,3,W"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z("(*;7-G
M<W1R(")%<W3A(')E;F]M8G)A;F1O(&QA(&-A<G!E=&$Z("(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R
M<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*(F-U<G)E
M;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB"FUS
M9W-T<B`B(@HB4'5E9&4@=71I;&EZ87(@;&]S('-I9W5I96YT97,@8V]M;V1I
M;F5S(&5N(&5L('1E>'1O(&1E(&QA('!L86YT:6QL83H@)6,@<&%R82`B"B)E
M;"!C;VYT96YI9&\@86-T=6%L(&1E;"!M96YS86IE.R`E<R!P87)A(&QA(&9I
M<FUA+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@7"(E<UPB+B(*;7-G
M<W1R(")392!H82!D97-U<V-R:71O(&-O<G)E8W1A;65N=&4@9&4@7"(E<UPB
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z
M,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O
M9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@
M(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*(DYO(&5S=.$@9&4@86-U97)D;R!C
M;VX@;&%S(&-O;F1I8VEO;F5S(&1E;"!397)V:6-I;RP@<&]R(&QO('%U92!N
M;R!S92!L92`B"B)P97)M:71E(&EN:6-I87(@<V5S:?-N+B(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ-S`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS
M9W-T<B`B3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A(&-A;6)I87(@
M96P@86-C97-O(&$@97-T82!C87)P971A(@H*(SH@;&EB+TUA:6QL;V<N<&AP
M.C$S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9F]R=V%R9&5D('1H:7,@
M;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E
M<RXB"FUS9W-T<B`B2&$@<F5E;G9I861O(&5S=&4@;65N<V%J92!D92`E)7,@
M82!L;W,@<VEG=6EE;G1E<R!D97-T:6YA=&%R:6]S.B`E<RXB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@:&%V92`E<R!N97<@;65S<V%G97,N(@IM<V=S='(@(E1I96YE("5S
M(&UE;G-A:F5S(&YU979O<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R
M="YI;F,Z,PIM<V=I9"`B66]U(&AA=F4@,2!N97<@;65S<V%G92XB"FUS9W-T
M<B`B5&EE;F4@,2!M96YS86IE(&YU979O+B(*"B,Z(&-O;7!O<V4N<&AP.C0X
M,@IM<V=I9"`B66]U(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E
M+B(*;7-G<W1R(")982!H82!E;G9I861O(&5S=&$@<.%G:6YA+B(*"B,Z(&QI
M8B])35`N<&AP.C$P-3(*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H
M92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R(")4:65N92!C;W)R96\@;G5E
M=F\@96X@;&$@<VEG=6EE;G1E(&-A<G!E=&$Z(@H*(SH@;&EB+TE-4"YP:'`Z
M,3`U-PIM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN
M9R!F;VQD97)S.B(*;7-G<W1R(")4:65N92!C;W)R96\@;G5E=F\@96X@;&%S
M('-I9W5I96YT97,@8V%R<&5T87,Z(@H*(SH@8V]M<&]S92YP:'`Z,34S"FUS
M9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@<F5C:7!I96YT+B(*
M;7-G<W1R(")4:65N92!Q=64@:6YD:6-A<B!A;"!M96YO<R!U;B!D97-T:6YA
M=&%R:6\N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S`V"FUS9VED
M("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!0
M1U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B
M(@HB4&%R82!V97(@97-T92!M96YS86IE('1I96YE('%U92!I;G1R;V1U8VER
M(&QA(&9R87-E(&-L879E(&1E('-U(&-L879E(%!'4"`B"B)P<FEV861A(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-30*;7-G:60@(B(*(EEO
M=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P
M<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*;7-G<W1R("(B
M"B)087)A('9E<B!E<W1E(&UE;G-A:F4@=&EE;F4@<75E(&EN=')O9'5C:7(@
M;&$@9G)A<V4@8VQA=F4@9&4@<W4@8VQA=F4@4R]-24U%("(*(G!R:79A9&$B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHV-"!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+B(*;7-G<W1R(")0
M<FEM97)O('1I96YE('%U92!S96QE8V-I;VYA<B!U;B!B=7KS;B!D92!D97-T
M:6YO+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX-0IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B
M5&EE;F4@<75E('-E;&5C8VEO;F%R('5N82!C=65N=&$@82!E;&EM:6YA<BXB
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C@Q"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B
M4')I;65R;R!T:65N92!Q=64@<V5L96-C:6]N87(@=6YA(&1I<F5C8VGS;BXB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8S"FUS9VED(")9;W4@;75S="!S
M96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@(E!R
M:6UE<F\@=&EE;F4@<75E('-E;&5C8VEO;F%R(&%L(&UE;F]S('5N(&UE;G-A
M:F4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G<W1R(")4
M:65N92!Q=64@:6YD:6-A<B!U;B!D97-T:6YA=&%R:6\N(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N86)L960@:6X@>6]U<B!M
M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R(")4:65N92!Q=64@86-T:79A
M<B!<(B5S7"(@96X@<W5S(&]P8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\N(@H*
M(SH@;&EB+TUA:6QL;V<N<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+B(*;7-G
M<W1R(")(82!R961I<FEG:61O(&5S=&4@;65N<V%J92!A("5S(&5N("4E<RXB
M"@HC.B!L:6(O36%I;&QO9RYP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RXB"FUS9W-T<B`B
M2&$@8V]N=&5S=&%D;R!A(&5S=&4@;65N<V%J92!E;B`E<RXB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HU,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@
M;F]T('-U8G-C<FEB960@=&\@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(DYO('-E(&AA('-U<V-R:71O(&$@7"(E<UPB
M+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L('-E<G9I9&]R(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-34Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E(&YO
M="!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B3F\@<V4@:&$@9&5S=7-C<FET;R!D92!<
M(B5S7"(N(,ES=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HU,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E
M<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@7"(E<UPB(@IM<V=S='(@
M(E-E(&AA('-U<V-R:71O(&-O<G)E8W1A;65N=&4@82!<(B5S7"(B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HU-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E
M<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G
M<W1R(")392!H82!D97-U<V-R:71O(&-O<G)E8W1A;65N=&4@9&4@7"(E<UPB
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"FUS9VED(")9;W5R($YA
M;64B"FUS9W-T<B`B4W4@;F]M8G)E(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C4P"FUS9VED(")9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES(@IM
M<V=S='(@(D-L879E<R!01U`@4/IB;&EC82]0<FEV861A(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B4W4@8VQA=F4@
M<')I=F%D82(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C<@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<Q"FUS9VED(")9;W5R(%!U8FQI8R!+97DB
M"FUS9W-T<B`B4W4@8VQA=F4@</IB;&EC82(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C$V-0IM<V=I9"`B66]U<B!297!L>2UT;SH@861D<F5S
M<SH@/&5M/BAO<'1I;VYA;"D\+V5M/B(*;7-G<W1R(")3=2!D:7)E8V-I\VX@
M4F5S<&]N9&5R+6$Z(#QE;3XH;W!C:6]N86PI/"]E;3XB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-12!0=6)L
M:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS9W-T<B`B4W5S(&-E<G1I9FEC
M861O<R!3+TU)344@4/IB;&EC;R]0<FEV861O(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*;7-G:60@(EEO=7(@86-C
M;W5N=',Z(@IM<V=S='(@(E-U<R!C=65N=&%S.B(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C$W,PIM<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R
M97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A
M(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(E-U<R!D:7)E8V-I;VYE<R!A
M<&]D;SH@/&5M/BAO<&-I;VYA;"P@:6YD:7%U92!C861A(&1I<F5C8VGS;B!E
M;B!U;F$@;.UN96$@(@HB9&ES=&EN=&$I/"]E;3XB"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ,#$*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP
M92XB"FUS9W-T<B`B(@HB16P@;F%V96=A9&]R(&YO(&%D;6ET92!L82!V:7-U
M86QI>F%C:?-N(&5N(&SM;F5A(&1E(&5S=&4@=&EP;R!D92!I;6%G96XN(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-3,Y"FUS9VED(")9;W5R
M(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T
M<B`B2G5E9V\@9&4@8V%R86-T97)E<R!P;W(@;VUI<VGS;B!P87)A(&5L(&5N
M=NUO(&1E(&UE;G-A:F5S.B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T
M<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M
M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(DWI=&]D;R!D
M92!C:69R861O('!O<B!O;6ES:?-N('!A<F$@96P@96YV[6\@9&4@;65N<V%J
M97,Z(@H*(SH@871T86-H;65N="YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U<B!L:6YK960@871T86-H;65N="!H87,@8F5E;B!D;W=N;&]A
M9&5D(&)Y(&%T(&QE87-T(&]N92!U<V5R+EQN(@HB7&XB"B)!='1A8VAM96YT
M(&YA;64Z("5S7&XB"B)!='1A8VAM96YT(&1A=&4Z("5S7&XB"B)<;B(*(D-L
M:6-K(&]N('1H92!F;VQL;W=I;F<@;&EN:R!T;R!P97)M86YE;G1L>2!D96QE
M=&4@=&AE(&%T=&%C:&UE;G0Z7&XB"B(E<R(*;7-G<W1R("(B"B)%;"!A<F-H
M:79O(&%D:G5N=&\@=FEN8W5L861O(&AA('-I9&\@9&5S8V%R9V%D;R!A;"!M
M96YO<R!P;W(@=6X@=7-U87)I;SI<;B(*(EQN(@HB3F]M8G)E(&1E;"!A9&IU
M;G1O.B`E<UQN(@HB1F5C:&$@9&5L(&%D:G5N=&\Z("5S7&XB"B)<;B(*(E!U
M;'-E(&5L(';M;F-U;&\@<VEG=6EE;G1E('!A<F$@96QI;6EN87(@9&4@9F]R
M;6$@<&5R;6%N96YT92!E;"!A9&IU;G1O.EQN(@HB)7,B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HX.0IM<V=I9"`B66]U<B!M97-S86=E('=A
M<R!S=6-C97-S9G5L;'D@9&5L:79E<F5D+B(*;7-G<W1R(")392!E;G9I\R!C
M;W)R96-T86UE;G1E('-U(&UE;G-A:F4N(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS9W-T
M<B`B1FER;6$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O861D<F5S<V5S
M0FQO8VMS+FIS.C<*;7-G:60@(EM(:61E($%D9')E<W-E<UTB"FUS9W-T<B`B
M6T]C=6QT87(@9&ER96-C:6]N97-=(@H*(SH@;65S<V%G92YP:'`Z,CDV(&-O
M;7!O<V4N<&AP.C$S,#$@;6%I;&)O>"YP:'`Z-3,V(&QI8B]#;VUP;W-E+G!H
M<#HX,S@*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");4VEN(&%S=6YT
M;UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N
M:G,Z.`IM<V=I9"`B6U-H;W<@061D<F5S<V5S("TB"FUS9W-T<B`B6TUO<W1R
M87(@9&ER96-C:6]N97,@+2(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!A9&1R97-S97,@+2`E<R!R
M96-I<&EE;G1S72(*;7-G<W1R(");36]S=')A<B!D:7)E8V-I;VYE<R`M("5S
M(&1E<W1I;F%T87)I;W-=(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C`U"FUS9VED(")?0F-C(@IM<V=S='(@(E]"8V,B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(E]";&%C:VQI<W0B"FUS
M9W-T<B`B3&ES=&$@;F5?9W)A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,34T"FUS9VED(")?0V,B"FUS9W-T<B`B7T-C(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHQ,`IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")%7VQI;6EN
M87(B"@HC.B!L:6(O24U0+G!H<#HY-34*;7-G:60@(E]&;VQD97)S(@IM<V=S
M='(@(E]#87)P971A<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C@Q"FUS9VED(")?261E;G1I='DB"FUS9W-T<B`B7TED96YT:61A9"(*
M"B,Z(&QI8B])35`N<&AP.CDR-`IM<V=I9"`B7TEN8F]X(@IM<V=S='(@(E]%
M;G1R861A(@H*(SH@;&EB+TE-4"YP:'`Z.3DV"FUS9VED(")?3&]G(&]U="(*
M;7-G<W1R(")?4V%L:7(B"@HC.B!M97-S86=E+G!H<#HS.3(*;7-G:60@(E]-
M97-S86=E(%-O=7)C92(*;7-G<W1R(")/<FEG96X@9&5L(&UE;G-A7VIE(@H*
M(SH@;&EB+TE-4"YP:'`Z.34R"FUS9VED(")?3F5W($UE<W-A9V4B"FUS9W-T
M<B`B7U)E9&%C=&%R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C,S"FUS9VED(")?4')I;G0B"FUS9W-T<B`B25]M<')I;6ER
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(X.0IM<V=I9"`B7U!R:6]R:71Y
M(@IM<V=S='(@(E!R:6]R:61A9"`H7WDI(@H*(SH@;6%I;&)O>"YP:'`Z-#`U
M"B,L('!H<"UF;W)M870*;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@(D%C
M='5A;&E?>F%R("5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C@*;7-G:60@(E]297!L>2(*;7-G<W1R(")297-P;VY?9&5R
M(@H*(SH@;&EB+TE-4"YP:'`Z.34W"FUS9VED(")?4V5A<F-H(@IM<V=S='(@
M(E]"=7-C87(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV
M-R!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C@*;7-G:60@(E]3
M96YD($UE<W-A9V4B"FUS9W-T<B`B7T5N=FEA<B!M96YS86IE(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,@IM<V=I9"`B
M7U1H<F5A9"(*;7-G<W1R(")396-?=65N8VEA(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,3$V"FUS9VED(")?5&\B"FUS9W-T<B`B7U!A
M<F$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I
M9"`B7U5N9&5L971E(@IM<V=S='(@(E)E8W5P97)A<B`H7W<I(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")?
M5FEE=R!4:')E860B"FUS9W-T<B`B7U9E<B!S96-U96YC:6$B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS
M9W-T<B`B3&ES=&$@8FQ?86YC82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S4*
M;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(F1E<W1I;F%T87)I
M;R!D97-C;VYO8VED;R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-3$*;7-G:60@
M(F%T=&%C:&UE;G0B"FUS9W-T<B`B861J=6YT;R(*"B,Z('9I97<N<&AP.CDW
M"FUS9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B861J=6YT;W,N>FEP
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`W"FUS9VED
M(")B>71E<R(*;7-G<W1R(")B>71E<R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M.3D*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B
M;F\@<V4@<'5E9&4@8W)E87(@96P@87)C:&EV;R!D92!D97-T:6YO(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$W,0IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B
M"FUS9W-T<B`B;F\@<V4@<'5E9&4@86)R:7(@96P@;W)I9V5N(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$V,PIM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R
M<F]R(@IM<V=S='(@(F5R<F]R(&1E(&SM;F5A(&1E(&-O;6%N9&\B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,C$Y"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R
M(@IM<V=S='(@(F5R<F]R(&1E(&-O;F9I9W5R86-I\VXB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3DU"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S
M:6YG(@IM<V=S='(@(F9A;'1A('5N(&%R8VAI=F\@8W+M=&EC;R!D96P@<VES
M=&5M82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C<*;7-G:60@(F1A=&$@9F]R
M;6%T(&5R<F]R(@IM<V=S='(@(F5R<F]R(&1E(&9O<FUA=&\@9&4@9&%T;W,B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(S"FUS9VED(")E;G1R>2!N;W0@9F]U
M;F0B"FUS9W-T<B`B96YT<F%D82!N;R!E;F-O;G1R861A(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS
M9W-T<B`B9&4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<Y"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R(")N;VUB<F4@9&4@86YF:71R:?-N(&1E
M<V-O;F]C:61O(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P,PIM<V=I9"`B:6YP
M=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(F5R<F]R(&1E(&5N=')A9&$O<V%L
M:61A(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-PIM<V=I9"`B:6YT97)N86P@
M<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B97)R;W(@9&4@<V]F='=A<F4@:6YT
M97)N;R(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8X"FUS9VED(")K97DB
M"FUS9W-T<B`B8VQA=F4B"@HC.B!F;VQD97)S+G!H<#HQ-#4*;7-G:60@(FUA
M:6QB;W@@9FEL92(*;7-G<W1R(")A<F-H:79O(&1E(&)U>O-N(@H*(SH@8V]M
M<&]S92YP:'`Z,3$P-2!L:6(O365S<V%G92YP:'`Z-3$U"FUS9VED(")N86UE
M(@IM<V=S='(@(FYO;6)R92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*;7-G<W1R(")N:6YG=6YO(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C4*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B;W(B
M"FUS9W-T<B`B;R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,34*;7-G:60@(G!E
M<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(G!R:79I;&5G:6\@9&5N96=A9&\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z
M.`IM<V=I9"`B<F5C:7!I96YT<UTB"FUS9W-T<B`B9&5S=&EN871A<FEO<UTB
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$Q"FUS9VED(")R96UO=&4@97)R;W(@
M:6X@<')O=&]C;VPB"FUS9W-T<B`B97)R;W(@<F5M;W1O(&1E('!R;W1O8V]L
M;R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#,*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B<V5R=FEC:6\@;F\@9&ES<&]N:6)L92(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E
M;&QI;F<@97)R;W(B"FUS9W-T<B`B97)R;W(@9&4@;W)T;V=R86;M82(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E
M;&QI;F<@97)R;W)S(@IM<V=S='(@(F5R<F]R97,@9&4@;W)T;V=R86;M82(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3$*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R(")E<G)O<B!D96P@<VES=&5M82(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,#<*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(F9A;&QO
M('1E;7!O<F%L(@H*(SH@;&EB+T9I;'1E<BYP:'`Z-SD*;7-G:60@(GEO=7(@
M8FQA8VML:7-T(@IM<V=S='(@(G-U(&QI<W1A(&YE9W)A(@H*(SH@;&EB+T9I
M;'1E<BYP:'`Z.#D*;7-G:60@(GEO=7(@=VAI=&5L:7-T(@IM<V=S='(@(G-U
M(&QI<W1A(&)L86YC82(*```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]P;R]Z:%]#3BYP;P``````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`S-#$U-#0`,3`T,3<S-C(W-C,`,#$W,C`Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",@24U0
M(%-I;7!L:69I960@0VAI;F5S92!4<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H
M0RD@,C`P,2!786YG2&5N9U=E;BX*(R!786YG2&5N9U=E;B`\=VAW0&UY,38Y
M+F-O;3XL(#(P,#$N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED
M+59E<G-I;VXZ($E-4"`T+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@
M,C`P,2TV+3$R(#$X.C,Y*S`X,#!<;B(*(DQA<W0M5')A;G-L871O<CH@5V%N
M9TAE;F=796X@/'=H=T!M>3$V.2YC;VT^7&XB"B),86YG=6%G92U496%M.B!#
M:&EN97-E(#QW:'=`;7DQ-CDN8V]M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U'0C(S,3)<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@("`@("!#8SH@
M(@IM<V=S='(@(B`@(,K5O/[(RZ.Z(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q
M-0IM<V=I9"`B("`@("`@5&\Z("(*;7-G<W1R("(@("#*U;S^R,NCNB(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT,#,*;7-G:60@(B`@("!$871E.B`B"FUS9W-T
M<B`B("`@R-7&VJ.Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#8*;7-G:60@
M(B`@("!&<F]M.B`B"FUS9W-T<B`B(""WHKS^R,NCNB(*"B,Z(&UA:6QB;W@N
M<&AP.C0R,B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z-#$R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@
M(B`@("#6]\SBH[HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-S`*;7-G:60@(B!I;B`B"FUS9W-T<B`B(-3:(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R
M("(B"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)60@365S<V%G97,B"FUS9W-T<B`BM=H@)60@M^*YLB`E9""WXB(*
M"B,Z(&UA:6QB;W@N<&AP.C$W-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)60@;65S<V%G97,@:&%V92!B965N(&1E;&5T960N(@IM<V=S='(@(M7*
MNL5<(B5S7"+2T;ZML;O)OK/]H:,B"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O4W!A;2YP:'`Z,34X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!N;W0@<W!A;2XB"FUS9W-T<B`B(@H*(SH@;&EB+U-P86TN<&AP.C$W,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P
M;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O4W!A;2YP:'`Z,34P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HS-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@=&\@)60@;V8@)60@365S<V%G97,B"FUS9W-T<B`BM-,@
M)60@M;T@)60@N;(@)60@M^(B"@HC.B!M86EL8F]X+G!H<#HV-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT
M96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S
M(&9O;&1E<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@(L[$O/Z\T"5STM&^
MK;3FU-JCK,3CM<3.Q+S^O-`E<\.[T]"QN[C$P_LN(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C8T.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!M86EL8F]X+B(*;7-G<W1R("(B"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP
M:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E:6YG(')E
M;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H
M87,@9&5C;&EN960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI
M960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I
M=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T
M<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<
M(BXB"FUS9W-T<B`BSL2\_KS07"(E<UPBTM&^K;/)N::XQ,/[SJI<(B5S7"*A
MHR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N9"`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE
M(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RXB"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,C@U(&UE<W-A9V4N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7W1O<"YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z
M("5S("@E9"9N8G-P.V]F)FYB<W`[)60I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(BA!<'!L>2!T
M:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BDB"FUS9W-T
M<B`B(-.FT\/5XM"IN,2QY+*BTL:VK[6]S\+2N\;!(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL
M(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*
M;7-G<W1R("*WQ<;ZR_G3T+C\N,2RHK>UN]BUO="TT\J\_B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*$A434PI(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ
M-@IM<V=I9"`B*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG
M+G!H<#HR.#`*;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R
M965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N
M("`B"B)#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B
M92!A<'!L:65D+BDB"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(W-PIM
M<V=I9"`B(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA
M;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N
M="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J
M($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@M>.[]\BW
MMJBPM,6EU/:\TR`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J
M(@IM<V=S='(@(BH@Q^O1H=3QM=C6MR`J(@H*(SH@;6%I;&)O>"YP:'`Z,3<T
M"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`BU<JZQ5PB)7-<(M+1OJVQN\F^L_VAHR(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ.#`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O4W!A;2YP:'`Z,38P"FUS9VED("(Q(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]3<&%M+G!H<#HQ-S(*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*;7-G:60@(C$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Y"B,L(&9U>GIY"FUS9VED("(Q
M,#`@8VAA<F%C=&5R<R(*;7-G<W1R("+,V,KBU]:W^R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,C(*(RP@9G5Z>GD*;7-G:60@(C$P,#`@8VAA<F%C
M=&5R<R(*;7-G<W1R("+,V,KBU]:W^R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,C`*(RP@9G5Z>GD*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S
M='(@(LS8RN+7UK?[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,0HC
M+"!F=7IZ>0IM<V=I9"`B-3`P(&-H87)A8W1E<G,B"FUS9W-T<B`BS-C*XM?6
MM_LB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B02!L87)G92!I;6%G92!N86UE9"`E<R!I<R!A='1A
M8VAE9"!T;R!T:&ES(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4P"FUS9VED("(B"B)!(&UE<W-A
M9V4@>6]U(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T
M:69I8V%T:6]N(&9R;VT@=&AE("(*(G)E8VEP:65N="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4*;7-G:60@(D%.1"(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DP"FUS
M9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3@W"FUS9VED(")!8V-E<'0@<F5Q=65S="!A;F0@
M861D(&ET('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW-3,*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3<*;7-G:60@(D%C
M8V5P=&5D.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C<*;7-G:60@(D%C8V]U;G0G<R!N86UE.B(*;7-G<W1R("+5
MRKK%H[HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(P(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW,S`*(RP@9G5Z>GD*;7-G:60@(D%C=&EO
M;G,B"FUS9W-T<B`B(+:OU_<B"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR
M,#`@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C`Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@)7,@=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@
M(B#4]KS3M;VUV-:WL;X@*"5S*2`B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,#,*;7-G:60@(D%D9"!S;W5R8V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-R!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3@X"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C86QE
M;F1A<B(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C4V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T86-H
M;65N="XB"FUS9W-T<B`B(-3VO-.XO;S^(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I
M<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H
M(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@:6YF
M;W)M871I;VX@9&5T86EL<R(*;7-G<W1R("*X]LC+T,7/HB(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.CDS"FUS9VED(")!9&1I=&EO;F%L(&UE
M<W-A9V4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L
M(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D
M:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R
M961I<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("*U
MV-:WL;XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(K78UK>QOB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*;7-G:60@(B(*(D%D9')E<W-E<R!T
M;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H
M(&%D9')E<W,@;VX@82!N97<@(@HB;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S
M97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO
M<'1I;VYA;"P@96YT97(@96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I
M/"]E;3XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHQ,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")!;&PB
M"FUS9W-T<B`BR_G3T"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3,*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W
M:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/
M6"`B"B)F:6QE.B(*;7-G<W1R("++^=/0U-K/PL'0T\K/Y-;0M<33RKS^O:NQ
MN\_"U-BUO=*[N/9-0D]8SL2\_M;0H[HB"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]P=7)G95]T<F%S:"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB06QL(&UE<W-A9V5S(&EN('EO=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T
M:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B(*
M;7-G<W1R("++^=/0U-I<(B5S7"+.Q+S^O-#6T+7$U.?3VB5SS.S'L+7$T\J\
M_KVKL;O3P+[#T-3)OK/]H:,B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D
M96QE=&5?871T86-H;65N='-?;6]N=&AL>2YP:'`Z-3D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO
M<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T
M<B`BR_G3T+3ST]HE<[CVU,*UQ+>BO/[/Y+VKL;O)OK/]H:,B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S96YT+6UA:6P@9F]L
M9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N
M(@IM<V=S='(@(LOYT]"T\]/:)7.X]M3"M<2WHKS^S^2]J[&[R;ZS_:&C(@H*
M(SH@86-L+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL
M(')I9VAT<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO=F5D
M(&9O<B!U<V5R(%PB)7-<(BXB"FUS9W-T<B`BSL2\_KS07"(E<UPBTM&^K;/)
MN::XQ,/[SJI<(B5S7"*AHR(*"B,Z(&QI8B]A<&DN<&AP.C<V"FUS9VED(")!
M;&QO=R!&;VQD97(@0W)E871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U
M;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$P"FUS9VED
M(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<R(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU.#0*;7-G:60@(D%L=V%Y<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34W"B,L(&9U>GIY"FUS9VED(")!;'=A
M>7,@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R("(@U/:\T[B]O/XB"@HC.B!L
M:6(O365S<V%G92YP:'`Z-3`U"FUS9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D
M('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H
M92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O
M<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T92XB"FUS9W-T
M<B`BU/:\T]#"S/7$O\JQMZ+)^LZTUJJT[<[SH:,B"@HC.B!L:6(O365S<V%G
M92YP:'`Z,S@W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C
M8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+B(*;7-G<W1R("+4
M]KS3T,+,]<2_RK&WHLGZSK36JK3MSO.AHR(*"B,Z(&UE<W-A9V4N<&AP.C4P
M,"!M86EL8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHY"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D(@IM<V=S
M='(@(M+1N]BXM"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S$*
M;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(M+1N]BXM-/*O/XB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@9G5Z>GD*
M;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`BTZ;3P[G]PLO&]R(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B07!P;'D@1FEL=&5R<R!T;R`E<R(*;7-G<W1R("+3
MIM/#N?W"R\;W(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V
M"B,L(&9U>GIY"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G
M:6YG(&]N/R(*;7-G<W1R("*UL;7'PKS*L=.FT\.Y_<++N>;4\J&C(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED
M(")!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA
M>65D/R(*;7-G<W1R("*UL<NBT,+3RL_DRK'3IM/#N?W"R[GFU/*AHR(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(W"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L
M971E('1H:7,@<'5B;&EC(&ME>3\B"FUS9W-T<B`BQ./(M]#%Q./2JLF^L_VX
MP[FKN;+#W-2_PO"COR(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@
M:7,@3D]4(')E8V]M;65N9&5D(2DB"FUS9W-T<B`BQ./(M]#%Q./2JLF^L_W#
MW-2_MM2COZ.HLKO-QKSVM<3@WJ.AHZDB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS
M.C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(*
M;7-G<W1R("+$X\BWT,7$X]*JU>+#M-?VH[\B"@HC.B!M97-S86=E+G!H<#HT
M,#<@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@
M=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(L3CR+?0Q<3CTJK3P+[#T-3)OK/]
MU>+0J<_[SZ+"\*._(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(Q-0HC
M+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!
M3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_(@IM<V=S='(@(L3CR+?0
MQ<3CTJK3P+[#T-3)OK/]U>+0J<_[SZ+"\*._(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`BQ./(M]#%Q./2
MJM/`OL/0U,F^L_W5XM"IS_O/HL+PH[\B"@HC.B!L:6(O24U0+G!H<#HY-S,*
M(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T
M>2!Y;W5R('-P86T@9F]L9&5R/R(*;7-G<W1R("+$X\BWT,7$X]*JT\"^P]#4
MR;ZS_=7BT*G/^\^BPO"COR(*"B,Z(&QI8B])35`N<&AP.CDV-@HC+"!F=7IZ
M>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@
M=')A<V@@9F]L9&5R/R(*;7-G<W1R("+$X\BWT,7$X]*JT\"^P]#4R;ZS_=7B
MT*G/^\^BPO"COR(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C@*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P
M97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(L3C
MR+?0Q<3CTJK3P+[#T-3)OK/]U>+0J<_[SZ+"\*._(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-SD*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT
M/R(*;7-G<W1R("+$X\BWT,7$X]*JT\"^P]#4R;ZS_=7BT*G/^\^BPO"COR(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L
M871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"B,L(&9U>GIY"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G
M92!A<R!S<&%M/R(*;7-G<W1R("+$X\BWT,7$X]*JT\"^P]#4R;ZS_=7BT*G/
M^\^BPO"COR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,38*;7-G:60@
M(D%R<FEV86P@5&EM92(*;7-G<W1R("*UO;3ORK&\Y"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,S$*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R("+)
M_=#R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$Y"FUS9VED(")!='1A8V@B
M"FUS9W-T<B`BU;/,^2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0W-0HC+"!F=7IZ>0IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S='(@
M(KB]O/XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-38*
M;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T
M;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@(KB]O-/2N[CVQ..UQ%!'4+FKN;+#
MW-2_M;W$X[7$T\J\_M;0H[\B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")!='1A8VAE9"!&:6QE.B(*;7-G<W1R
M("+5L\SY(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0U,2!L:6(O0V]M<&]S92YP
M:'`Z-3,V"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%T=&%C:&5D(&9I;&4@
M7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I
M;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,S<V"FUS9VED(")!='1A8VAE9"!I<R!A(')E<&QY('1O
M(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N="XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-3`V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FIS.CDW"FUS9VED(")!='1A8VAM96YT(@IM<V=S='(@(KB]O/XB"@HC.B!C
M;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*;7-G:60@(D%T
M=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<S"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ,#<S"FUS9VED(")!='1A8VAM96YT<R(*;7-G<W1R("*X
MO;S^(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,@HC+"!F=7IZ
M>0IM<V=I9"`B071T96YD965S(@IM<V=S='(@(KB]O/XB"@HC.B!L:6(O34E-
M12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B
M071T96YT:6]N(@IM<V=S='(@(B"VK]?W(@H*(SH@;&EB+T%U=&@O:6UP+G!H
M<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8T,`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W(&EM86=E<R!I
M;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2`B"B)A
M9&1R97-S8F]O:S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,CDX"B,L(&9U>GIY"FUS9VED(")!=F%I;&%B;&4@
M061D<F5S<R!B;V]K<SHB"FUS9W-T<B`BO\G3P[7$M=C6M[&^H[HB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S$Y"FUS9VED(")!=V%I=&EN9R!2
M97-P;VYS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C(V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")"86-?:R!T;R`E<R(*;7-G<W1R("*WM;O8M;T@)7,B"@HC.B!T:')E860N
M<&AP.C$S-R!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B
MM[6[V+6]("5S(@H*(SH@=&AR96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@
M375L=&EP;&4@365S<V%G92!6:65W($EN9&5X(@IM<V=S='(@(B(*"B,Z('1H
M<F5A9"YP:'`Z,3,R"FUS9VED(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R
M(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8V
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z
M,S0*;7-G:60@(D)C8R(*;7-G<W1R("*PM<O-(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,38Q"FUS9VED(")"96QO=R!I<R!T:&4@<F%W('1E
M>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(D)L
M86-K;&ES="(*;7-G<W1R("*\T\CKNMK#^[6E(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8R.0IM<V=I9"`B0FQO8VL@:6UA9V5S(&EN($A434P@;65S
M<V%G97,@=6YL97-S('1H97D@87)E('-P96-I9FEC86QL>2!R97%U97-T960_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP.C0R"FUS9VED(")";V1Y
M(@IM<V=S='(@(L3:R-VCNB(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,C,@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS.0HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C4U('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z-S$*;7-G:60@(D)O=&@B"FUS9W-T<B`BR*NROR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.#<*;7-G:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@
M86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(*;7-G:60@(D-?:&%R<V5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I
M9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HR,#$*(RP@9G5Z>GD*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T
M:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R("+!JKW3M;W3RKS^M_[.
M\<;WRJ>PW"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3DY"B,L(&9U
M>GIY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL
M('-E<G9E<CH@(@IM<V=S='(@(L&JO=.UO=/*O/ZW_L[QQO?*I[#<(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@
M)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT("(*(FUA
M:6QB;W@N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C(X-"!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-0HC.B!T96UP;&%T97,O9F]L
M9&5R<R]I;7!O<G0N:6YC.C(Q('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM
M86=E+FEN8SHQ.0HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z
M,C$@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@V"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`@=&5M<&QA=&5S+W!G<"]P
M87-S<&AR87-E+FEN8SHS,@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C8V"FUS9VED(")#86YC96PB"FUS9W-T<B`BR*'/^R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0S-0HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z,3$Q"FUS9VED(")#86YC96P@365S<V%G92(*;7-G<W1R("+(H<_[
MS_O/HB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN
M9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C
M;VYT96YT<RXB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8U('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W)E8V]M<&]S92YI;F,Z,34@;&EB+U-E87)C:"YP:'`Z,S`*;7-G
M:60@(D-C(@IM<V=S='(@(K.MR\TB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T
M(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI
M<R`B"B)S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW,#$*(RP@9G5Z>GD*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G
M<W1R("*X]LC+M<0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R("*X_+C$(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL
M(@IM<V=S='(@(KC\N,3+^=/0(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.CDR"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S='(@(K2T
MO:C.Q+S^O-`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"B,L(&9U
M>GIY"FUS9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@
M:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*
M(FAO=R!M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R("*X_+C$S]3*OM&A
MS^[(Y\7DR:NWO;"XHZS#O]*SS]3*OM/*O/[*_;RPT\J\_L7%T/*WO<J]H:,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@
M(D-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+B(*;7-G
M<W1R("*X_+C$T\J\_K?^SO'&]\GHMJBAHR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A9&1R97-S
M+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`BN/RXQ,3C
MM<3#^]?6HZS3RKS^M=C6M[K-QZG#^R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,C0*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,34*;7-G
M:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`BO.RR
MZ=#"T\J\_B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHW-0IM<V=I
M9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K(&%L;"!M86EL('-E<G9E
M<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8S"FUS9VED(")#:&5C:R!S<&5L
M;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G:60@(D-H;V]S
M92!!8W1I;VXZ(@IM<V=S='(@(M&AU/&RV=?WH[HB"@HC.B!C;VYF:6<O<V5R
M=F5R<RYP:'`N9&ES=#HQ.#(*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A(&UA
M:6P@<V5R=F5R.B(*;7-G<W1R("*X_+C$T\J\_K?^SO'&]\GHMJBAHR(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C$W"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E9&ET
M('1H92!A9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,2!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S,Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@86-T:6]N.B(*
M;7-G<W1R("+1H=3QLMG7]Z.Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C
M97-E;&5C="YI;F,Z,S0Y"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=&AE(&%D
M9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+B(*;7-G
M<W1R("+1H=3QU/:\T[78UK?*L<OYRKG3P[7$M=C6M[&^(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"B,L(&9U>GIY"FUS9VED
M(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H
M('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`BT:'4\=3VO-.U
MV-:WRK'+^<JYT\.UQ+78UK>QOB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!C
M;VYV97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B<F]W
M<V5R(&-A;B!V:65W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!D;W=N;&]A9"!T:&4@:6UA9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT
M97(N<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G
M;R!T;R`E<R!M86YA9V5M96YT('!A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W+B(*;7-G<W1R("+4VM#"M+"_VM;0T+33RKS^(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I
M;6%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM
M<V=S='(@(M3:T,*TL+_:UM#0M-/*O/XB"@HC.B!L:6(O34E-12]6:65W97(O
M<F5L871E9"YP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@
M=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S97!A
M<F%T92!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H
M=&UL+G!H<#HY-0IM<V=I9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C
M="YI;F,Z,S(Q"FUS9VED("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE
M8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S
M('1O("(*(G-E87)C:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED(")#;&EC:R!T;R!3879E(%!'
M4"!0=6)L:6,@2V5Y(&EN('EO=7(@061D<F5S<R!B;V]K(@IM<V=S='(@(KVK
M4$=0N:NYLL/<U+^QH[3FM;W$X[7$M=C6M[&^UM`B"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C(P,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@
M>6]U<B!!9&1R97-S($)O;VLB"FUS9W-T<B`BO:M01U"YJ[FRP]S4O[&CM.:U
MO<3CM<2UV-:WL;[6T"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3`*
M;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A
M(&YE=R!M97-S86=E('1O('1H92!S96YD97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDU,0IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE
M(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC
M.C(X"B,L(&9U>GIY"FUS9VED(")#;&]S92(*;7-G<W1R("+0M-/*O/XB"@HC
M.B!C;VUP;W-E+G!H<#HX,C@@8V]M<&]S92YP:'`Z,3$T.`IM<V=I9"`B0VQO
M<V4@=&AI<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#(Y
M"B,L(&9U>GIY"FUS9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(M7;M?[.
MQ+S^O-`B"@HC.B!F;VQD97)S+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(D-O
M;&QA<'-E(@IM<V=S='(@(M7;M?[+^=/0(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R
M("+5V[7^R_G3T"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C,Y"FUS9VED(")#;VQL87!S92!!;&P@1F]L9&5R<R(*;7-G<W1R("+5V[7^
MR_G3T,[$O/Z\T"(*"B,Z(&9O;&1E<G,N<&AP.C0T.0IM<V=I9"`B0V]L;&%P
M<V4@1F]L9&5R(@IM<V=S='(@(M7;M?[.Q+S^O-`B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC871O
M<CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`BL;C7HB(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW-CD*(RP@9G5Z>GD*;7-G:60@(D-O;7!L971E9"(*
M;7-G<W1R("*QN->B(@H*(SH@8V]M<&]S92YP:'`Z.#(W(&-O;7!O<V4N<&AP
M.C$Q-#<*(RP@9G5Z>GD*;7-G:60@(D-O;7!O<V4@86YO=&AE<B!M97-S86=E
M(@IM<V=S='(@(M"TT\J\_B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,S0*(RP@9G5Z>GD*;7-G:60@(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A
M<F%T92!W:6YD;W<_(@IM<V=S='(@(M3:T,*TL+_:UM#0M-/*O/XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0S"FUS9VED("(B"B)#;VUP;W-E(&UE
M<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H:68@8G)O=W-E
M<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-PIM<V=I9"`B0V]N9FEG=7)E(&AO=R!M
M97-S86=E<R!A<F4@9&ES<&QA>65D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3<*(RP@9G5Z>GD*;7-G:60@(D-O;F9I9W5R92!M
M86EL('!R979I97<@;W!T:6]N<RXB"FUS9W-T<B`BN/RXQ-/*O/ZW_L[QQO?)
MZ+:HH:,B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM<V=I9"`B0V]N
M;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO
M;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!0
M1U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3
M+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA
M=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N
M(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R
M(&YO="!T;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y-@IM<V=I9"`B0V]N
M=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G
M:60@(D-O<'DB"FUS9W-T<B`BN+36QB(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS
M9W-T<B`BQ^6S_<"LN_C/Y"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G<W1R("*X_-7](@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B0V]R
M<F5C=&5D(%1E>'0B"FUS9W-T<B`BN/S5_;KSM<3.Q+&^(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HS.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S
M(@IM<V=S='(@(K*[Q-S)OK/]M-,E<\"TM<33RKS^H[HE<R(*"B,Z(&%T=&%C
M:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M365S<V%G92YP:'`Z-C0P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@
M<V%I9#H@)7,B"FUS9W-T<B`BLKO$W,F^L_VTTR5SP+2UQ-/*O/ZCNB5S(@H*
M(SH@;&EB+U-E<W-I;VXN<&AP.C,Q.`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`B
MSJR[I++9U_<B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-30*;7-G
M:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M
M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C
M="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]397-S:6]N+G!H<#HR-S,*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!N86UE<W!A8V4@:6YF;W)M871I;VX@9G)O;2!)34%0
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS,30@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L
M+FEN8SHS.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38P"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`BM+2]J"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C8*;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T<B`BM+2]
MJ,[$O/Z\T"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*;7-G:60@
M(D-R96%T92!+97ES(@IM<V=S='(@(K2TO:C#W-2_(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]H96%D97(N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@
M5FER='5A;"!&;VQD97(B"FUS9W-T<B`BM+2]J,[$O/Z\T"(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"FUS9VED(")#
M<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!N97<@4W!A
M;2!F;VQD97(B"FUS9W-T<B`BM+2]J-*[N/;0PK7$P*R[^,_D(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R
M969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D
M<F%F=',@9F]L9&5R(@IM<V=S='(@(K2TO:C2N[CVT,*UQ++=N.7/Y"(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA
M=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E
M(&$@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`BM+2]J-*[N/;0PK7$
MMZ*\_L_D(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHQ
M,B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS9VED(")#
M<F5A=&4@82!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(K2TO:C2N[CVT,*U
MQ,"LN_C/Y"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C@*;7-G:60@
M(B(*(D-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I
M;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@(@HB86YD(&1E
M;&5T92!S<&%M+B(*;7-G<W1R("*TM+VHN?W"R[GFU/+7Z=:OQ./*U;6]M<33
MRKS^HZRQH[3FM;W.Q+S^O-#6T+RPR;ZS_<"LN_C3RKS^H:,B"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@
M(D-R96%T92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R("*TM+VHTKNX]M#"M<2W
MHKS^S^0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED(")#
M<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U"B,L(&9U>GIY"FUS9VED(")#=7-T
M;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A
M8V-O=6YT<RXB"FUS9W-T<B`BMJC6QM7*NL6TT\;DR_Q03U`S+TE-05"W_L[Q
MQO?*U<BAT\J\_J&C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"B,L
M(&9U>GIY"FUS9VED(")#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN(@IM
M<V=S='(@(K:HUL;$X[7$RM6\_L_DNLVRW;CES^2AHR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G
M<W1R("*VJ-;&M<?"O+6])7/*L<OYTJJ]^-#0M<3.K+NDLMG7]Z&C(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-PHC+"!F
M=7IZ>0IM<V=I9"`B1&%T7V4B"FUS9W-T<B`BR-7&VB(*"B,Z(&UE<W-A9V4N
M<&AP.C(V,B!T:')E860N<&AP.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R("+(
MU<;:(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U-PHC+"!F=7IZ
M>0IM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`BTM')OK/](@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C(V,PIM<V=I9"`B1&5C;&EN960Z("(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,W"B,L(&9U>GIY
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(LF^L_TB"@HC.B!T96UP;&%T97,O
M<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z,3@*;7-G:60@(D1E9F%U
M;'0@4V5A<F-H($9I96QD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,C,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB
M"FUS9W-T<B`BQ*S(S\7%T/*QZM>\.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,S,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM
M<V=S='(@(L2LR,_%Q=#RM[W/\J.Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<V-0HC+"!F=7IZ>0IM<V=I9"`B1&5L96=A=&5D(@IM<V=S='(@
M(M+1R;ZS_2(*"B,Z(&9O;&1E<G,N<&AP.C0Q.2!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR-#0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z."!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FEN8SHR.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D1E
M;&5T92(*;7-G<W1R("+)OK/](@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS9W-T<B`BR;ZS_25S
MN:NYLL/<U+\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B1&5L971E($-U<G)E;G0@
M2V5Y<R(*;7-G<W1R("+)OK/]M;''L,/<U+\B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHY"FUS9VED(")$96QE=&4@1F]L9&5R*',I(@IM
M<V=S='(@(LF^L_W.Q+S^O-`B"@HC.B!F;VQD97)S+G!H<#HR.#4*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(LF^
ML_W.Q+S^O-`B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M-#(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!3=&%T:6]N97)Y(@IM<V=S='(@
M(LF^L_W.Q+S^O-`B"@HC.B!F;VQD97)S+G!H<#HT,3D*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("+)OK/]SL2\_KS0
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED
M(")$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*
M;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M
M;VYT:#\B"FUS9W-T<B`BU-K#O[CVU,*S]<F^L_V^R;7$MZ*\_L_D(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`HC+"!F=7IZ>0IM<V=I9"`B1&5L
M971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N
M=&@_(@IM<V=S='(@(M3:P[^X]M3"L_7)OK/]OLFUQ+>BO/[/Y"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!S<&%M(&UE<W-A9V5S(@IM<V=S='(@(LF^L_W3RKS^(@H*(SH@;65S<V%G
M92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<T,"!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(P"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHX"FUS9VED(")$96QE
M=&5D(@IM<V=S='(@(M+1R;ZS_2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS9W-T<B`BTM')
MOK/]T\J\_B(*"B,Z(&-O;7!O<V4N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@871T86-H;65N="!<(B5S7"(N(@IM
M<V=S='(@(LF^L_W2N[CVN+V\_B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.0IM<V=I9"`B1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<R(*;7-G
M<W1R("+)OK/]LJ+2QK:OT\J\_B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU.3(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30P"FUS9VED(")$96YY(')E<75E
M<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,R"FUS9VED(")$97-C96YD:6YG(@IM
M<V=S='(@(L3FT/(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT
M<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V.0HC+"!F=7IZ
M>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BT:'/[B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I
M9"`B1&5T86EL<R(*;7-G<W1R("+/N+W:(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8W-PHC+"!F=7IZ>0IM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM
M<V=S='(@(L3CM<3'J</[H[HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R("+/U,J^(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W.0IM<V=I9"`B1&ES<&QA>2!C
M;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#8*;7-G:60@(D1I<W!L
M87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.3(*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF
M:6-A=&EO;B!O9B!N97<@;6%I;#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3
M<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%
M;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS9W-T<B`BS]3*OM&AS^XB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/
M5"!M871C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHQ-@IM<V=I9"`B1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@
M3F5W($UA:6PB"FUS9W-T<B`BLKN\[++IT,+3RKS^(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E;F5R871E(&$@;&EN
M:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N
M<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD
M97(_(@IM<V=S='(@(L3CS^NT\K^JN,/.Q+S^O-#"\*._(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,S(*;7-G:60@(D1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B1&]N92(*;7-G<W1R("+-
MZK/)(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C$Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU,@IM<V=I
M9"`B1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P
M"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RDB"FUS9W-T<B`BS\+4V,[$O/Z\
MT"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(Q"B,L(&9U
M>GIY"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(*
M;7-G<W1R("+/PM38SL2\_KS0(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP
M.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B
M(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*
M;7-G:60@(D1R869T(@IM<V=S='(@(K+=N.4B"@HC.B!F;VQD97)S+G!H<#HS
M.3(*(RP@9G5Z>GD*;7-G:60@(D1R869T(&9O;&1E<B(*;7-G<W1R("*RW;CE
MS^2CNB(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S
M"FUS9VED(")$<F%F=',@9F]L9&5R.B(*;7-G<W1R("*RW;CES^2CNB(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#@*;7-G:60@(D4M;6%I;"!!9&1R
M97-S(@IM<V=S='(@(D4M36%I;+78UK<B"@HC.B!L:6(O36%I;&)O>"YP:'`Z
M,S`Y"FUS9VED(")%3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2.B!9;W5R(&UE<W-A9V4@8V]U
M;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP
M:'`Z-#(P('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ.0IM<V=I
M9"`B161I="(*;7-G<W1R("*QX+RM(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")%9&ET($)L86-K;&ES="(*
M;7-G<W1R("*\T\CKNMK#^[6E(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")%9&ET($9I;'1E<G,B"FUS9W-T
M<B`BN?W"R\;W(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S96%R
M8V@O:&5A9&5R+FEN8SHQ-@IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F
M:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`BL>"\K<3C
MM<2Y_<++N>;4\B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ
M,PIM<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(*;7-G<W1R("*QX+RM
MQ..UQ+G]PLNYYM3R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V,0IM
M<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H
M97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<')E9G,N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")%9&ET('EO=7(@
M=VAI=&5L:7-T(@IM<V=S='(@(K'@O*W$X[7$N?W"R[GFU/(B"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S.0IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R(")%;6%I;+78UK<B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C4W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%;7!T:65D(&%L
M;"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("+'Y;/]R_G3T+33)7/`M+7$
MT\J\_J&C(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C(*
M;7-G:60@(D5M<'1Y($9O;&1E<BAS*2(*;7-G<W1R("+'Y;/]SL2\_KS0(@H*
M(SH@9F]L9&5R<RYP:'`Z,C@V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!396QE
M8W1E9"!&;VQD97)S(@IM<V=S='(@(L?EL_W.Q+S^O-`B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@
M9F]L9&5R(@IM<V=S='(@(L?EL_W`K+OXS^0B"@HC.B!L:6(O24U0+G!H<#HY
M-S,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%]3<&%M(@IM<V=S='(@(L?EL_W`
MK+OXS^0B"@HC.B!L:6(O24U0+G!H<#HY-C8*(RP@9G5Z>GD*;7-G:60@(D5M
M<'1Y(%]4<F%S:"(*;7-G<W1R("+'Y;/]P*R[^,_D(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C8*
M;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ('1E;7!L871E<R]S;6EM
M92]N;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L92!3+TU)344@9G5N8W1I
M;VYA;&ET>3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@Q,0IM<V=I9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0T,@IM<V=I
M9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3$W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-3<*;7-G:60@(D5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S@T"B,L(&9U>GIY"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B
M"FUS9W-T<B`BM-,E<]>JMZ*UQ-/*O/XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,S0Q"B,L(&9U>GIY"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R("*^R=/*
MO/XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(K33)7/7
MJK>BM<33RKS^(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A
M<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N
M:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R("+'Z\KDR.O0PK7$P*R[^,_DM<3#
M^]?6(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM
M<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD
M97(B"FUS9W-T<B`BQ^O*Y,CKT,*UQ++=N.7/Y+7$P_O7UB(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@(D5N=&5R
M('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S
M='(@(L?KRN3(Z]#"M<2WHKS^S^2UQ,/[U]8B"@HC.B!T96UP;&%T97,O<')E
M9G,O=')A<VAS96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O
M<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`BQ^O*Y,CKT,*UQ,"L
MN_C/Y+7$P_O7UB(*"B,Z(&QI8B]396%R8V@N<&AP.C0V"B,L(&9U>GIY"FUS
M9VED(")%;G1I<F4@365S<V%G92(*;7-G<W1R("*\T\/<T\J\_B(*"B,Z(&UE
M<W-A9V4N<&AP.C$Y-"!C;VUP;W-E+G!H<#HQ,3,T('1H<F5A9"YP:'`Z-S$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5N=')Y(%PB)7-<(B!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`BS/7$OUPB)7-<(M+1OJVSR;FFM<3,[;S3M;VUV-:WL;[`[R(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(Q"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<V(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,X-@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G
M:60@(D5R<F]R(@IM<V=S='(@(K3MSO,B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C;VYN96-T:6YG
M('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R
M97!L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D
M96QE=&5D+B(*;7-G<W1R("+%Y-;#T,7/HM+1OJVWX;FFN/RXQ*&C(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN
M=71E<R(*;7-G<W1R("+#O[CT,36WUM;3(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<W.0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("+#
MO[CT,S##Z];3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I
M9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(L._N/0UM];6TR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#,*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R("+#O[CTL.O0H<JQ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<X,`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(L._M];6TR(*
M"B,Z(&9O;&1E<G,N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B17AP86YD(@IM
M<V=S='(@(M6YOZK+^=/0(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`BU;F_JLOYT]`B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.`IM<V=I9"`B
M17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(M6YOZK+^=/0SL2\_KS0(@H*
M(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S
M='(@(M6YOZK.Q+S^O-`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4S"B,L
M(&9U>GIY"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T<B`BU;F_JL[$O/Z\
MT"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8S"FUS9VED(")%>'!A
M;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@
M:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.#`*;7-G:60@(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E
M<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C$P,0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD:6YG(@IM<V=S
M='(@(M6YOZK+^=/0(@H*(SH@;&EB+TE-4"YP:'`Z.3@T(&QI8B])35`N<&AP
M.CDX-@HC+"!F=7IZ>0IM<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T<B`BT,+3
MRKS^(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D9E
M=&-H($UA:6PB"FUS9W-T<B`BT,+3RKS^(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@V.0HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@36%I;"!I;B!A('-E
M<&%R871E('=I;F1O=S\B"FUS9W-T<B`BU-K0PK2PO]K6T$9E=&-H($UA:6PB
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#8*(RP@9G5Z
M>GD*;7-G:60@(D9E=&-H(&UE<W-A9V5S('5P;VX@;&]G9VEN9R!O;C\B"FUS
M9W-T<B`BM;&UQ\*\RK'3IM/#N?W"R[GFU/*AHR(*"B,Z(&QI8B]&971C:&UA
M:6PN<&AP.C(X.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE
M9"`E9"!M97-S86=E<R!F<F]M("5S(@IM<V=S='(@(L?EL_W+^=/0M-,E<\"T
MM<33RKS^H:,B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B
M"FUS9W-T<B`BM-,E<]>JMZ*UQ-/*O/XB"@HC.B!L:6(O1F5T8VAM86EL+G!H
M<#HR.#4@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP
M.C(X.0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T9E
M=&-H;6%I;"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")&971C:&UA:6PZ(&YO
M(&YE=R!M97-S86=E<RXB"FUS9W-T<B`BUKN[\<BAT,+3RKS^(@H*(SH@;&EB
M+TE-4"YP:'`Z.3DP"B,L(&9U>GIY"FUS9VED(")&:5]L=&5R<R(*;7-G<W1R
M("*Y_<++QO<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.#(*(RP@9G5Z
M>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`BN?W"R\;W(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")&:6QT97(@
M3W!T:6]N<R(*;7-G<W1R("+&Y,O[T:'/[B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHY"B,L(&9U>GIY"FUS9VED(")&:6QT97(@4V5T=&EN
M9W,B"FUS9W-T<B`BN?W"R[GFU/(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C`P"FUS9VED(")&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F
M86YI='D_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C
M=&EV92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D
M(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S='(@(KG]PLO&]R(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,PIM<V=I9"`B
M1FEL=&5R<R!.3U0@06-T:79E(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N
M<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97)S.B`E<R!M86YA
M9V5M96YT('!A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ.#8*;7-G:60@(D9I;F0B"FUS9W-T<B`BLNG5TB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*(RP@9G5Z>GD*;7-G:60@
M(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R("*UVM*[TK,B"@HC.B!M86EL
M8F]X+G!H<#HS-#4*;7-G:60@(D9I<G-T(%!A9V4B"FUS9W-T<B`BM=K2N]*S
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"B,L(&9U>GIY"FUS
M9VED(")&;U]R=V%R9"(*;7-G<W1R("+7JK>B(@H*(SH@9F]L9&5R<RYP:'`Z
M,C8V('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C4*
M;7-G:60@(D9O;&1E<B!!8W1I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9O;&1E<G,N<&AP.C,P,R!T96UP;&%T97,O9F]L9&5R<R]H96%D
M+FEN8SHY"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI
M;F,Z-@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC
M.C$P"FUS9VED(")&;VQD97(@3F%V:6=A=&]R(@IM<V=S='(@(M/*S^2UO+J]
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@
M(D9O;&1E<B!3=6UM87)Y(@IM<V=S='(@(K;^U,(B"@HC.B!A8VPN<&AP.C(T
M"FUS9VED(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-C(*;7-G:60@(D9O;&1E<B!U<V4@:7,@
M;F]T(&5N86)L960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-CD*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H
M92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S
M='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C<X,"!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,34*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`BUZJWHB(*"B,Z
M(&-O;7!O<V4N<&AP.C<V-0IM<V=I9"`B1F]R=V%R9#HB"FUS9W-T<B`BUZJW
MHJ.Z(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,V.0IM<V=I9"`B1F]R=V%R9&5D
M(&UE<W-A9V4B"FUS9W-T<B`BM-,E<]>JMZ*UQ-/*O/XB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D9O<G=A<F1E9"!M
M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`BM-,E<]>JMZ*UQ-/*O/XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@S"B,L(&9U>GIY"FUS9VED(")&
M<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`BM_[.\<;WT,7/HB(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.30*;7-G:60@(D9R964O0G5S
M>2!297!L>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Q"FUS9VED(")&<F5E+T)U
M<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(W"B,L(&9U>GIY"FUS9VED
M(")&<F]?;2(*;7-G<W1R("*WHKS^R,LB"@HC.B!M97-S86=E+G!H<#HR-C,@
M=&AR96%D+G!H<#HQ-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M.3D*(SH@;&EB+U-E87)C:"YP:'`Z,C(*;7-G:60@(D9R;VTB"FUS9W-T<B`B
MMZ*\_LC+(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ.`IM<V=I9"`B
M1G)O;2!!9&1R97-S(@IM<V=S='(@(K>BO/[(R[78UK<B"@HC.B!C;VUP;W-E
M+G!H<#HW-S<@8V]M<&]S92YP:'`Z-S@Q"B,L(&9U>GIY"FUS9VED(")&=V0Z
M(@IM<V=S='(@(M>JMZ*CNB(*"B,Z(&-O;7!O<V4N<&AP.C$R.30*(RP@9G5Z
M>GD*;7-G:60@(D9W9#H@(@IM<V=S='(@(M>JMZ*CNB(*"B,Z(&-O;7!O<V4N
M<&AP.C$R.38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9W9#H@)74@
M1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(K33)7/7JK>BM<33RKS^(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X"B,L(&9U>GIY"FUS9VED(")'96YE<F%L($]P=&EO
M;G,B"FUS9W-T<B`BT:'/[B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHS-PHC+"!F=7IZ>0IM<V=I9"`B1V5T(&]N;'D@;F5W(&UE<W-A
M9V5S/R`H24U!4"!O;FQY*2(*;7-G<W1R("+6N[OQR*'0PM/*O/XB"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,0IM<V=I9"`B1V\B"FUS
M9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(D=O
M('1O($UE<W-A9V4B"FUS9W-T<B`BS\+2N[?B(@H*(SH@;&EB+TE-4"YP:'`Z
M-#DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")';R!T;R!A9&1R97-S
M(&)O;VL@96YT<GD@;V8@7"(E<UPB(@IM<V=S='(@(B#4]KS3M;VUV-:WL;X@
M*"5S*2`B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3,U"FUS9VED(")'
M<F%N="!A8V-E<W,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-30V(&QI
M8B]&:6QT97(N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY
M-0HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#(@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$V,R!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,Z(&QI8B]-24U%+U9I97=E<B]R
M96QA=&5D+G!H<#HW.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC
M.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C$W,PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HQ,C`@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(W"FUS9VED
M(")(15)%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHS,2!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$W"B,Z(&QI
M8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G
M<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HR-38*;7-G:60@(DA434P@5F5R<VEO
M;B!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VAE861E<G,N:6YC.C4X"FUS9VED(")(96%D97)S(@IM<V=S='(@(M/*O/[-
MMR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z-0IM<V=I
M9"`B2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP;W-I;F<Z(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C@*;7-G:60@
M(DAI9&1E;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C8W"FUS9VED(")(:61D96X@:6X@5&AR96%D(%9I97<B"FUS9W-T<B`B(@H*
M(SH@;6%I;&)O>"YP:'`Z,S8W"FUS9VED(")(:61E($1E;&5T960B"FUS9W-T
M<B`BTOZRV-+1R;ZS_;7$(@H*(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")(
M:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R("+2_K+8SK2VJ=3$M<0B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N<&AP.C<R
M-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H
M(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(Y,PIM<V=I9"`B2&EG:&5S="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X"FUS9VED(")(;W<@9&\@>6]U('=A
M;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T<B`BQ.//H\W[R.>Z
MSL_4RKZXO;S^/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*;7-G
M:60@(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*;7-G
M:60@(DE-05`B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!397)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N
M+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$V-B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-33"(*;7-G<W1R("(B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I9"`B24U!4"!O=F5R(%-33"`H
M<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,38W"FUS9VED("))34%0(&]V97(@4U-,
M("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HS-C@*;7-G:60@(DE-05`@<V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ-C4@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-#`*;7-G:60@(DE-05`L
M(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C0Y"FUS9VED("))34%0+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B])35`N<&AP.C@V-@IM<V=I9"`B24Y"3U@B"FUS9W-T<B`BRM6\
M_L_D(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT,3$*;7-G:60@(DEF('5S
M:6YG(%-33"!O<B!43%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L
M(&5X=&5N<VEO;B!L;V%D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"B,L(&9U>GIY"FUS9VED
M("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R
M*',I('=I;&P@8F4@;&]S="$B"FUS9W-T<B`BR_G3T-3:N,/3RL_DUM"UQ-/*
MO/ZVO+VKMJK*IZ.LQ./(M]#%TJK5XL.TU_;"\*._(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T
M<B`BNO;"U"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX
M,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G<W1R("*Z]L+4R_G3T"(*"B,Z('1E
M;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHX"FUS9VED("));6%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC
M.C(P"B,L(&9U>GIY"FUS9VED("));7!O<G0B"FUS9W-T<B`BUMC2JB(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C8U"FUS9VED("));7!O<G0@2V5Y(@IM<V=S
M='(@(K6\R.O#W-2_(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S.0IM
M<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`BM;S(Z\/<U+^VU"(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(W"B,L(&9U>GIY"FUS
M9VED("));7!O<G0@365S<V%G97,B"FUS9W-T<B`BUMC2JM/*O/XB"@HC.B!P
M9W`N<&AP.C0R"FUS9VED("));7!O<G0@4$=0($ME>2(*;7-G<W1R("*UO,CK
M4$=0P]S4OR(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3$*(RP@
M9G5Z>GD*;7-G:60@(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G
M<W1R("*UO,CKN/;(R\N]R,M01U##W-2_(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHQ-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>2(*;7-G<W1R("*UO,CKN/;(R\N]R,M01U##W-2_(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@
M4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`BM;S(Z[CVR,NYJ[FR
M4$=0P]PB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-`HC
M+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I
M8V%T97,B"FUS9W-T<B`BM;S(Z[CVR,O+O<C+4$=0P]S4OR(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C0R"FUS9VED("));7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("*UO,CKN:NY
MLL/<U+\B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0*;7-G
M:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("*UO,CKN:NYLE!'
M4,/<U+\B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`HC
M+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S
M='(@(K6\R.NYJ[FRP]S4OR(*"B,Z('-M:6UE+G!H<#HQ-@HC+"!F=7IZ>0IM
M<V=I9"`B26UP;W)T(%,O34E-12!+97DB"FUS9W-T<B`BM;S(Z\/<U+\B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.CD*(RP@9G5Z>GD*;7-G
M:60@(DEM<&]R="!M8F]X($9I;&4B"FUS9W-T<B`BM;S(Z\/<U+\B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N(@IM
M<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,B!M86EL8F]X+G!H<#HW,S0@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N
M:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R("+6V-*J(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT(&UE
M<W-A9V5S(@IM<V=S='(@(M;8TJK3RKS^(@H*(SH@9F]L9&5R<RYP:'`Z,38W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"`E9"!M97-S
M86=E<R!F<F]M("5S+B(*;7-G<W1R("+'Y;/]R_G3T+33)7/`M+7$T\J\_J&C
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,PIM<V=I9"`B26X@
M4')O8V5S<R(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS.#0@;&EB+T9O
M;&1E<BYP:'`Z.#8@;&EB+T9O;&1E<BYP:'`Z,C$T(&QI8B])35`N<&AP.C,Q
M,PHC.B!L:6(O24U!4"]4<F5E+G!H<#HQ,30@;&EB+TE-05`O5')E92YP:'`Z
M,C$Y"FUS9VED("));F)O>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DR"B,L(&9U>GIY"FUS9VED("));F-L=61E(&$@8G)I968@
M<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM<V=S='(@(M3:
MN]BXM-;0L/RZK-2MRKS3RKS^H[\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#@W"FUS9VED("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R
M97!L>3\B"FUS9W-T<B`BU-J[V+BTUM"P_+JLU*W*O-/*O/ZCOR(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G
M<W1R("*Z]L+4(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*;7-G<W1R("*YV-/:N:NY
MLL/<U+\E<[7$T,7/HB(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM
M<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS
M9W-T<B`BN=C3VLN]R,O#W-2_M<30Q<^B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@
M(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B
MN=C3VKCVR,NYJ[FRP]S4O[7$T,7/HB(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V%T=&%C:&UE;G1S+FEN8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU,#<*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z
M.3@*;7-G:60@(DEN;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T($-E
M<G1I9FEC871E($AE<F4B"FUS9W-T<B`BU-K5XL#OLN7(Z\/<U+\B"@HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"B,L(&9U>GIY"FUS9VED
M("));G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T
M<B`BM;S(Z[CVR,O+O<C+4$=0P]S4OR(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!097)S;VYA
M;"!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(K6\R.NX]LC+N:NYLE!'
M4,/<(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R
M("*UO,CKN:NYLE!'4,/<U+\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI
M<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4X-"!M
M86EL8F]X+G!H<#HV,C8*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@061D<F5S
M<R(*;7-G<W1R(")%;6%I;+78UK<B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C,P-PIM<V=I9"`B26YV86QI9"!296UO=&4@36%I;&)O>"(*;7-G<W1R
M("*WQ[>HM<34R[/,T\K/Y"(*"B,Z(&-O;7!O<V4N<&AP.C$U.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D
M<F5S<SH@)7,N(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HX,B!P9W`N<&AP
M.C$V"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&ME>2(*;7-G<W1R("*WQ[>H
MM<101U##W-2_(@H*(SH@<&=P+G!H<#HQ.38*;7-G:60@(DEN=F%L:60@<&5R
M<V]N86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R("*WQ[>HM<2X]LC+4$=0
MR[W(R\/<U+\B"@HC.B!P9W`N<&AP.C$W,0IM<V=I9"`B26YV86QI9"!P97)S
M;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T<B`BM\>WJ+7$N/;(RU!'4+FK
MN;+#W-2_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM
M<V=I9"`B26YV97)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B2T(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T:"(*;7-G
M<W1R("+#W-2_LZ2VR"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*
M;7-G:60@(B(*(DME>2!G96YE<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE
M('1O(&-O;7!L971E+B`@0V]N=&EN=64@=VET:"!K97D@(@HB9V5N97)A=&EO
M;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS
M-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,S<*;7-G:60@(DME>2!I;7!O<G0@
M:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@
M;VX@=&AI<R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,S<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,Y"FUS9VED
M("(B"B)+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H879E(&YO
M(&%D9')E<W,@8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R("(*(F-O;G1A8W1S
M+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C,Q.`IM<V=I9"`B2V5Y('-U8V-E
M<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(Q-@IM<V=I9"`B
M3&%N9W5A9V4B"FUS9W-T<B`BT^_1U"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,#8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@36%I;&)O>"!086=E(@IM
M<V=S='(@(M?NNO/2N]*S(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED("),
M87-T(%!A9V4B"FUS9W-T<B`BU^ZZ\]*[TK,B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS.#D*(RP@9G5Z>GD*;7-G:60@(DQI7VYK($%T
M=&%C:&UE;G1S(@IM<V=S='(@(KB]O/XB"@HC.B!A='1A8VAM96YT+G!H<#HS
M-"!L:6(O0V]M<&]S92YP:'`Z,3`V,PIM<V=I9"`B3&EN:V5D(&%T=&%C:&UE
M;G1S(&%R92!F;W)B:61D96XN(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ,#@P"B,L('!H<"UF;W)M870*;7-G:60@(DQI;FMS('=I;&P@97AP
M:7)E(&]N("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#@R"FUS9VED("(B"B),:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I
M;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL
M;"`B"B)O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X
M<&QI8VET;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.#4*;7-G:60@(DQI<W1I;F<@:6X@=&AE($AE861E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S`*;7-G:60@
M(DQO8V%L($UA:6QB;W@Z(@IM<V=S='(@(K&^M=C3RL_D(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8W-`HC+"!F=7IZ>0IM<V=I9"`B3&]C871I
M;VXB"FUS9W-T<B`B(+:OU_<B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(K7'PKPB"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(DQO
M9R!I;B!T;R`E<R(*;7-G<W1R("*UQ\*\M;TE<R(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3,W"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G
M<W1R("*UQ\*\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED
M("),;V=I;B!487-K<R(*;7-G<W1R("*UQ\*\R,[.\2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@
M(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X+G!H<#HW,C<@=&5M<&QA
M=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B3&]W(%!R:6]R:71Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y-PIM<V=I9"`B3&]W97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]A<'!L961O=6)L92YP:'`Z-#0*;7-G:60@(DUA8VEN=&]S:"!&:6QE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN
M8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B36%I;"(*;7-G<W1R("+3RL_D(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")-86EL(%!R979I97=S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E
M;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C
M="!T;SHB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#`R"FUS9VED(")-
M86EL8F]X(@IM<V=S='(@(M/*S^0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$Q"B,L(&9U>GIY"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES
M<&QA>2!/<'1I;VYS(@IM<V=S='(@(L_4RK[1H<_N(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL($UE<W-A
M9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")-87)K($%L;"!-97-S
M86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-2!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-87)K(&%S.B(*;7-G<W1R
M("*QZKS'SJJCNB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G
M:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF
M9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E
M96X_("A)34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0V"FUS9VED
M(")-871C:"!!;&P@475E<FEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,3,*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM
M<V=S='(@(KB]O/XB"@HC.B!L:6(O87!I+G!H<#HW.0IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT.30*;7-G:60@(DUA>&EM=6T@;G5M8F5R
M(&]F(&%T=&%C:&UE;G1S(')E86-H960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X.0IM<V=I9"`B36%X:6UU;2!T
M;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B365E=&EN9R!#
M86YC96QL871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!);F9O<FUA=&EO
M;B(*;7-G<W1R("*W_L[QQO?0Q<^B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4X-0IM<V=I9"`B365E=&EN9R!0<F]P;W-A;"(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W"FUS9VED(")-965T
M:6YG(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU.3@*;7-G:60@(DUE971I;F<@57!D871E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#,*;7-G:60@(DUE971I;F<@
M57!D871E(%)E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?
M9F]L9&5R<RYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!&;VQD97(@3&ES
M="(*;7-G<W1R("*T\K^JSL2\_KS0(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S
M,0HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+3RKS^M;TB"@HC
M.B!C;VUP;W-E+G!H<#HU-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O<V4N<&AP
M.C8T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@
M0V]M<&]S:71I;VXB"FUS9W-T<B`BT+33RKS^(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(M/*
MO/[(U<;:(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`S"B,L(&9U>GIY"FUS9VED
M(")-97-S86=E($]P=&EO;G,B"FUS9W-T<B`BT\J\_K6](@H*(SH@<V5A<F-H
M+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@4V5A<F-H(@IM<V=S='(@(M/*O/ZR
MZ=72(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I9"`B365S
M<V%G92!3:7IE(@IM<V=S='(@(M/*O/ZT\]"A(@H*(SH@;65S<V%G92YP:'`Z
M,S@T"FUS9VED(")-97-S86=E(%-O=7)C92(*;7-G<W1R("+4K<J\T,7/HB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@HC+"!F=7IZ>0IM<V=I9"`B
M365S<V%G92!6:65W:6YG(@IM<V=S='(@(M/*O/ZT\]"A(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-97-S86=E(&9L86=S(@IM
M<V=S='(@(M/*O/ZQZM:^(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM<V=S='(@(M/*O/Z\T"(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DUE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("+3RKS^O-`B"@HC.B!M
M86EL8F]X+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:&%S(&%T
M=&%C:&UE;G1S(@IM<V=S='(@(LF^L_W2N[CVN+V\_B(*"B,Z(&UA:6QB;W@N
M<&AP.C8U.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!I<R!E;F-R>7!T960B
M"FUS9W-T<B`BT\J\_M?6MLXB"@HC.B!M86EL8F]X+G!H<#HV-3,*(RP@9G5Z
M>GD*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(M/*O/[7UK;.
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C,S"B,L(&9U>GIY
M"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS9W-T<B`BT\J\_LC5QMHB"@HC
M.B!C;VUP;W-E+G!H<#HX,C0@8V]M<&]S92YP:'`Z.#,X"B,L(&9U>GIY"FUS
M9VED(")-97-S86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M("*X]LC+4$=0P]S4O]+1OJVSR;FFR;ZS_:&C(@H*(SH@8V]M<&]S92YP:'`Z
M,3`X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365S<V%G92!S96YT
M('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<R(*;7-G<W1R("+3
MRKS^TM&^K;/)N::WHLO-HZRUJ\K'P[O3T+&CM.:UO2(*"B,Z(&-O;7!O<V4N
M<&AP.C$Q-#,@8V]M<&]S92YP:'`Z,3$U.`HC+"!F=7IZ>0IM<V=I9"`B365S
M<V%G92!S96YT('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BT\J\_M+1OJVSR;FF
MMZ++S:.LM:O*Q\.[T]"QH[3FM;TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.30Q"FUS9VED(")-97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O
M>"!V:65W+B(*;7-G<W1R("+#O]*SS]3*OK7$T\J\_LK]+B(*"B,Z(&UA:6QB
M;W@N<&AP.C,R,@IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`BT\J\_K6]
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB
M"FUS9W-T<B`BL>"\K2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI
M;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!T:&%N(&]N92!A9&1R
M97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM<V=I9"`B36]V92(*;7-G<W1R
M("+2QK:O(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S$V"B,L(&9U>GIY"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`BS\+2QB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3@*;7-G:60@(DUO=F4@<W!A
M;2!M97-S86=E<R!T;R!S<&%M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G
M97,@=&\@24Y"3U@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C4P"B,L(&9U>GIY"FUS9VED(")-;W9E('1O(&9O;&1E<B(*;7-G
M<W1R("+1H=3QSL2\_KS0(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S$T"B,L(&9U>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@
M(LG/TL8B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$R
M-PIM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@(B(*"B,Z
M('1H<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@
M(DUU;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R("+3RKS^M//0H2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHU"FUS
M9VED(").3TY%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHT."!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S@@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B3F%M92(*;7-G<W1R
M("+#^[/&(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD+V]R(&5M
M86EL(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<W.`HC+"!F=7IZ>0IM<V=I9"`B3F5E9',@06-T
M:6]N(@IM<V=S='(@(B"VK]?W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@R"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-S@*;7-G:60@(DYE=F5R(@IM<V=S='(@(K33P+3#N]/0
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`HC+"!F=7IZ>0IM<V=I
M9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R("+)OK/]TKNX]KB]
MO/XB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B
M"FUS9W-T<B`BT,(B"@HC.B!L:6(O24U0+G!H<#HU-C,*(RP@9G5Z>GD*;7-G
M:60@(DYE=R!&;VQD97(B"FUS9W-T<B`BM/*_JL[$O/Z\T"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`B
MT,+3RKS^(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y(&QI8B]";&]C
M:R]T<F5E7V9O;&1E<G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(").97<@365S
M<V%G92(*;7-G<W1R("+/PM*[M^(B"@HC.B!M86EL8F]X+G!H<#HW-S8@;&EB
M+TU)344O2&5A9&5R<RYP:'`Z,3DR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("+0PM/*O/XB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Y"FUS9VED(").97<@;65S<V%G
M97,B"FUS9W-T<B`BT,+3RKS^(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$S,PIM<V=I9"`B3F5X="(*;7-G<W1R("+/PB(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@
M(DYE>'0@365S<V%G92(*;7-G<W1R("+/PM*[M^(B"@HC.B!M86EL8F]X+G!H
M<#HS-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R("+/PM*[TK,B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#(@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDW-PIM<V=I9"`B3F\B"FUS9W-T<B`BLKLB"@HC.B!S;6EM
M92YP:'`Z,C(V"FUS9VED(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*
M;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$Y"FUS9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS
M9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S<U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!-97-S86=E<R(*;7-G<W1R("+0PM/*O/XB"@HC.B!P
M9W`N<&AP.C$S-PIM<V=I9"`B3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N
M(@IM<V=S='(@(L.[T]!01U"YJ[FRP]S4O[6\R.LB"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C@T"B,L(&9U>GIY"FUS9VED(").;R!097)S;VYA
M;"!#97)T:69I8V%T92!0<F5S96YT(@IM<V=S='(@(K6\R.NX]LC+R[W(RU!'
M4,/<U+\B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S(Y"B,L(&9U>GIY"FUS9VED
M(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`BN/S5_;KSM<3.Q+&^(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B
M3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS9W-T<B`BQ..UQ+FKN;+#W-2_(@H*
M(SH@<VUI;64N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B3F\@4R]-24U%('!U
M8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(L.[T]!01U"YJ[FRP]S4O[6\
MR.LB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3`*(RP@9G5Z>GD*
M;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R("*XO;S^(@H*
M(SH@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(DYO
M(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K97DN
M(@IM<V=S='(@(KG8T]JYJ[FRP]S4OR5SM<30Q<^B(@H*(SH@86-L+G!H<#HW
M,B!A8VPN<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97(@<V5L96-T
M960N(@IM<V=S='(@(L.[T]#6N+:HSL2\_KS0(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$T,0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE
M8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP
M.C(Q."!L:6(O1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS
M9VED(").;R!F;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(L.[T]#6
MN+:HSL2\_KS0(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T-PHC+"!F
M=7IZ>0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<R(*;7-G
M<W1R("+6N[OQR*'0PM/*O/XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,30T"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@=6YS965N(&UE
M<W-A9V5S(@IM<V=S='(@(L.[T]#6N+:HSL2\_KS0(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C,R-0HC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!B;V1Y('1E
M>'0B"FUS9W-T<B`BTL:VK]/*O/ZUO2(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS
M-S$*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S
M96%R8V@N(@IM<V=S='(@(L.[T]#5TK6]M_NZS\SUO/ZUQ-/*O/XB"@HC.B!P
M9W`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!R
M:79A=&4@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("*WQ[>HM<2X]LC+4$=0R[W(
MR\/<U+\B"@HC.B!P9W`N<&AP.C$V-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(L.[T]!0
M1U"YJ[FRP]S4O[6\R.LB"@HC.B!S;6EM92YP:'`Z,C`Q"FUS9VED(").;R!P
M97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G<W1R
M("(B"@HC.B!S<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").;R!S<&5L;&-H96-K
M:6YG('!R;V=R86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(").;R!S<&5L;&EN
M9R!E<G)O<G,B"FUS9W-T<B`BP[O3T-/OMZBT[<[S(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO
M;G,B"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-C0*;7-G
M:60@(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!C
M;W5L9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HV."!A8VPN
M<&AP.CDT"B,L(&9U>GIY"FUS9VED(").;R!U<V5R('-P96-I9FEE9"XB"FUS
M9W-T<B`BP[O3T-:XMJC.Q+S^O-`B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S`Y"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,2!T96UP;&%T97,O
M<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,U('1E;7!L871E<R]P<F5F<R]S<&%M<V5L
M96-T+FEN8SHR-`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8T"B,L
M(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(LWJL\DB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.34*;7-G:60@(DYO<FUA;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(Q('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE
M=&5D(@IM<V=S='(@(L.[T]#)OK/]M<0B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C$R('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT
M,@IM<V=I9"`B3F]T($1R869T(@IM<V=S='(@(K*[RL>RW;CE(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHS-`IM<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R("*R
MN];8TJJUQ"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*
M;7-G:60@(DYO="!097)S;VYA;"(*;7-G<W1R("*RN\K'N/;(R[7$(@H*(SH@
M;&EB+T-R>7!T+U!'4"YP:'`Z,3,Y(&QI8B]#<GEP="]334E-12YP:'`Z,3,T
M(&QI8B]#<GEP="]334E-12YP:'`Z,30Y"B,L(&9U>GIY"FUS9VED(").;W0@
M82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G<W1R("*WQ[>HM<2X]LC+4$=0N:NY
MLL/<U+\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W"B,L(&9U
M>GIY"FUS9VED(").;W0@9&5L971E9"!M97-S86=E<R(*;7-G<W1R("+2T<F^
ML_W3RKS^(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I
M9"`B3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R("*RN];8TJJUQ-/*
MO/XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN
M<&AP.C<Q"FUS9VED(").;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I
M;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q-@HC
M+"!F=7IZ>0IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R("+2_=/#(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B3G5M8F5R(&]F(&UO;G1H
M<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L971I;F<@
M;6]N=&AL>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,U.0HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@
M(M3:P[^X]M3"L_7)OK/]OLFUQ+>BO/[/Y"(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C4T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU-3(*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,PIM<V=I9"`B
M3TLB"FUS9W-T<B`BR+>VJ"(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.0HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$U"FUS9VED
M(")/;&0@;65S<V%G97,B"FUS9W-T<B`BOLG3RKS^(@H*(SH@;&EB+TUA:6YT
M96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C4R"B,L
M(&9U>GIY"FUS9VED(")/;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R
M9V5D+B(*;7-G<W1R("+4VL._N/;4PK/UR;ZS_;[)M<2WHKS^S^0B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D]N;'D@9&ES<&QA>2!F
M;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-SD*(RP@
M9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T
M960@9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R("+'Z]:[T:'4\=*[N/;$X]*J
MLMG7][7$SL2\_KS0H:,B"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,3`@=&5M
M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")/<&5N($9O7VQD
M97(B"FUS9W-T<B`BM/*_JL[$O/Z\T"(*"B,Z(&9O;&1E<G,N<&AP.C0R-PHC
M+"!F=7IZ>0IM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G<W1R("*T\K^JSL2\
M_KS0(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P-0IM<V=I9"`B
M3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL
M+G!H<#HS,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@HC+"!F=7IZ>0IM<V=I
M9"`B3W1H97(@36%I;"!!8V-O=6YT<R(*;7-G<W1R("+&Y,O[T:'/[B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I
M;VYS(@IM<V=S='(@(L;DR_O1H<_N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,#$*;7-G:60@(D]U=&)O=6YD(%-E<G9E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP"FUS9VED(")01U`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T
M+FEN8SHW"B,L(&9U>GIY"FUS9VED(")01U`@16YC<GEP="!-97-S86=E(@IM
M<V=S='(@(KS3P]S3RKS^(@H*(SH@8V]M<&]S92YP:'`Z,S4X"B,L(&9U>GIY
M"FUS9VED(")01U`@17)R;W(Z("(*;7-G<W1R("*T[<[S(@H*(SH@8V]M<&]S
M92YP:'`Z,S,W"FUS9VED(")01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F
M;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!/<'1I
M;VYS(@IM<V=S='(@(M&AS^XB"@HC.B!P9W`N<&AP.C,P"FUS9VED(")01U`@
M4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA;"!+97EP86ER('-U<'!O
M<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PHC+"!F=7IZ>0IM
M<V=I9"`B4$=0(%!U8FQI8R!+97D@5&5X="(*;7-G<W1R("+$X[7$N:NYLL/<
MU+\B"@HC.B!P9W`N<&AP.C$T.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S
M9G5L;'D@861D960N(@IM<V=S='(@(L[$O/Z\T%PB)7-<(M+1OJVSR;FFM+2]
MJ*&C(@H*(SH@<&=P+G!H<#HR-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!D96QE=&5D+B(*;7-G<W1R("+.Q+S^O-!<(B5S7"+2T;ZML\FYILF^L_VA
MHR(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I
M9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(L3CM<2YJ[FRP]S4OR(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`HC+"!F
M=7IZ>0IM<V=I9"`B4$=0(%-I9VX@365S<V%G92(*;7-G<W1R("*WHLO-T\J\
M_B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.0HC
M+"!F=7IZ>0IM<V=I9"`B4$=0(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S
M='(@(K>BR\W3RKS^(@H*(SH@<&=P+G!H<#HR,#(*(RP@9G5Z>GD*;7-G:60@
M(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(L7DUL/0Q<^BTM&^K;?AN::X_+C$H:,B"@HC.B!P9W`N<&AP.C$W-PHC+"!F
M=7IZ>0IM<V=I9"`B4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D
M+B(*;7-G<W1R("+%Y-;#T,7/HM+1OJVWX;FFN/RXQ*&C(@H*(SH@=&5M<&QA
M=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T(&ES
M(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR,#@*;7-G:60@(B(*(E!'4"!S=7!P;W)T
M(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I9VYA
M='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I9"`B(@HB4$=0
M('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A
M9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(B(*(E!'4"!S=7!P;W)T
M(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@
M8G)O=W-E<B!I<R!C=7)R96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@<&]P=7`@
M=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E
M('1H92!01U`@(@HB9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS
M9VED(")03U`S(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,3`P"FUS9VED(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$W"FUS9VED
M(")03U`S(&]V97(@4U-,(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3(S"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE
M9"!C97)T:69I8V%T92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ-CD*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG
M;F5D*2(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q
M,0IM<V=I9"`B4$]0,RP@;F\@5$Q3(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VAE861E<BYI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4&%G92`E9"!O9B`E9"(*;7-G<W1R("*UVB`E9"#2L[FR("5D(-*S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP,PIM<V=I9"`B4&%G92!W:71H('1H
M92!&:7)S="!5;G-E96X@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3`T"FUS9VED(")086=E('=I=&@@=&AE($QA<W0@
M56YS965N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`BN+V\
M_B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C,*;7-G:60@(E!A<W-P
M:')A<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R
M.`IM<V=I9"`B4&%S<W!H<F%S92`H06=A:6XI(@IM<V=S='(@(B(*"B,Z('-M
M:6UE+G!H<#HR,S4@<&=P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-P
M:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R("+%Y-;#T,7/
MHM+1OJVWX;FFN/RXQ*&C(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A
M<V4N:6YC.C$X('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,CD*(RP@
M9G5Z>GD*;7-G:60@(E!A<W-P:')A<V4Z(@IM<V=S='(@(L/<PNLZ(@H*(SH@
M<&=P+G!H<#HQ,3(*;7-G:60@(E!A<W-P:')A<V5S(&-A;B!N;W0@8F4@96UP
M='DB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,30*;7-G:60@(E!A<W-P:')A
M<V5S(&1O(&YO="!M871C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z,C`@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K
M97DN:6YC.C<Q"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3DR"FUS
M9VED(")087-S=V]R9"(*;7-G<W1R("+#W,+K(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L(&9U>GIY"FUS9VED(")097)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(K7'
MPKS*L=:TT-#.K+NDLMG7]R(*"B,Z(&%C;"YP:'`Z-S8@86-L+G!H<#HQ,#(*
M;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N(&YO="!B92!C
M:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HT.3,@;6%I;&)O
M>"YP:'`Z-S`S('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,`IM<V=I9"`B4&5R<V]N
M86PB"FUS9W-T<B`BN/;(R[7$(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("*X]LC+
MT,7/HB(*"B,Z('!G<"YP:'`Z,3(P"FUS9VED(")097)S;VYA;"!01U`@:V5Y
M<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("*X]LC+4$=0
MP]S4O[;4L\FYILGZL\FAHR(*"B,Z('!G<"YP:'`Z,3(W"FUS9VED(")097)S
M;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
MN/;(RU!'4,/<U+_2T;ZML\FYILF^L_VAHR(*"B,Z('-M:6UE+G!H<#HR,#<*
M;7-G:60@(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R
M=&5D.B`B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$S,@HC+"!F=7IZ>0IM
M<V=I9"`B4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(KCVR,M01U##W-2_TM&^K;/)N:;)OK/]H:,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(R"FUS9VED(")0;&%C92!Y;W5R('-I
M9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_(@IM<V=S='(@
M(B(*"B,Z(&-O;7!O<V4N<&AP.C(U-`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I
M;VX@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-SDY"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@
M5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E
M9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A
M;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q=6ER92!A
M('!L=6=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V
M87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z,3DR"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`BQ^O*Y,CKT,*UQ,[$O/Z\T+7$
MP_NSQJ.Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ
M,#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@
M(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS
M9W-T<B`BQ^O*Y,CKT,*UQ,[$O/Z\T+7$P_NSQJ.Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S<*;7-G:60@(E!L96%S92!E;G1E
M<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@(L?KRN3(Z]#"M<3#^[/&H[HB"@HC
M.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@
M>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R`B
M"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC
M.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@
M<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W
M:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC
M92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@<F5C;VUP;W-E+G!H
M<#HY-PIM<V=I9"`B(@HB4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@
M8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@
M(@HB8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@
M<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R`B"B)L;V<@:6X@86=A
M:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME
M97`@871T86-K97)S(&9R;VT@(@HB:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)
M1"X@5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,0HC+"!F=7IZ
M>0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"XB"FUS9W-T
M<B`BQ^O*Y,CKQ..UQ-/#NZ?#^[K-P]S"ZR(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(L?KRN3(Z\3CM<33P[NGP_NZS</<
MPNLB"@HC.B!C;VUP;W-E+G!H<#HQ,#8@;&EB+TE-4"YP:'`Z-#4Y"FUS9VED
M(")0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S
M97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-#(*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O
M<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B
M"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L
M9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B
MQ^O1H=3QQ./2JK+9U_>UQ,[$O/Z\T*&C(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4P,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('-E;&5C="!A
M;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T<B`BQ^O1H=3Q
MUL')V=*[N/;2JK+IU=*UQ,[$O/Z\T*&C(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]J879A<V-R:7!T+FEN8SHT,0IM<V=I9"`B4&QE87-E('-E;&5C="!A="!L
M96%S="!O;F4@9F]L9&5R('1O('-E87)C:"XB"FUS9W-T<B`BQ^O1H=3QUL')
MV=*[N/;2JK+IU=*UQ,[$O/Z\T*&C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9F]L9&5R<RYJ<SHQ,@IM<V=I9"`B4&QE87-E('-E;&5C="!O;FQY(&]N
M92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+B(*;7-G<W1R("+'Z]:[T:'4
M\=*[N/;$X]*JLMG7][7$SL2\_KS0H:,B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z-S,*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!S96QE
M8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T<B`B
MQ^O1H=3QUL')V=*[N/;2JK+IU=*UQ,[$O/Z\T*&C(@H*(SH@8V]N9FEG+VUO
M=&0N<&AP+F1I<W0Z-#$*;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-`IM<V=I9"`B4')E
M8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G
M<W1R("(B"@HC.B!S;6EM92YP:'`Z,C0Q('!G<"YP:'`Z,C4W(&9I;'1E<G!R
M969S+G!H<#HT,`IM<V=I9"`B4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P
M9&%T960N(@IM<V=S='(@(L7DUL/0Q<^BTM&^K;?AN::X_+C$H:,B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PHC+"!F=7IZ>0IM
M<V=I9"`B4')E=FEE=R(*;7-G<W1R("+)S]*[M^(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U
M<R!-97-S86=E(@IM<V=S='(@(LG/TKNWXB(*"B,Z(&UA:6QB;W@N<&AP.C,T
M-PIM<V=I9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R("+)S]*[M^(B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@
M(E!R:6YT(@IM<V=S='(@(K3RTZ$B"@HC.B!T96UP;&%T97,O;65S<V%G92]H
M96%D97)S+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B4')I;W)I='DB"FUS9W-T
M<B`BM/+3H2(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B4')I=F%T92!+97D@4&%S<W=O<F0B"FUS9W-T
M<B`BQ..UQ,N]R,O#W-2_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U
M.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S
M96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T
M=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0
M<F]T;V-O;#HB"FUS9W-T<B`BT*W2Z:.Z(@H*(SH@;&EB+T-R>7!T+U!'4"YP
M:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA
M<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M7V1E;&5T960N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!U<E]G92!$96QE=&5D
M(@IM<V=S='(@(M+^LMC2T<F^L_VUQ"(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L
M971E9"YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@1&5L971E9"(*;7-G
M<W1R("+2_K+8TM')OK/]M<0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHR-`HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@1F]L9&5R*',I(@IM
M<V=S='(@(LF^L_W.Q+S^O-`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*(RP@9G5Z>GD*;7-G:60@
M(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H
M:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@(LOYT]#4VEPB)7-<(L[$O/Z\
MT-;0M<34Y]/:)7/,[,>PM<33RKS^O:NQN]/`OL/0U,F^L_VAHR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*(RP@9G5Z>GD*;7-G:60@(E!U<F=E
M(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R("*T
MM+VHTKNX]M#"M<3`K+OXS^0B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P
M=7)G95]T<F%S:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S
M='(@(K2TO:C2N[CVT,*UQ,"LN_C/Y"(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W!U<F=E7W1R87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4'5R9VEN
M9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(K2TO:C2
MN[CVT,*UQ,"LN_C/Y"(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@
M+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q
M=6]T82]Q=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@
M<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E%U;W1A('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4P,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B475O=&EN9R`E9CHB"FUS9W-T<B`BTOW3PR(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B4F5?<75E<W0@1&5L:79E
M<GD@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP
M.C4P"FUS9VED(")296-E:79E9"!/;B(*;7-G<W1R("(B"@HC.B!L:6(O4V5A
M<F-H+G!H<#HU.`IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+U-E87)C:"YP:'`Z-30*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(M;8
MO,0B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(M;8O,0B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I<F5C="!-
M97-S86=E(@IM<V=S='(@(M;8O,33RKS^(@H*(SH@8V]M<&]S92YP:'`Z-S@W
M"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T<B`BUMB\Q+C#
MT\J\_B(*"B,Z(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E8W1I;F<@
M9F%I;&5D+B(*;7-G<W1R("+6V+S$T\J\_LJGL-RAHR(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X,PIM<V=I9"`B4F5F<F5S:"(*;7-G
M<W1R("++HM#"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X-`IM<V=I
M9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA:6QB;W@O:&5A
M9&5R+FEN8SHT"FUS9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I97<B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R-B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-30U"FUS9VED(")296UE;6)E<B!T:&4@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3<Y"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V
M:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHR-PIM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(M2VL\S3
MRL_D.B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I
M9"`B4F5M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R("+)OK/]TM'1H=;0M<2XO;S^
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.`HC+"!F=7IZ
M>0IM<V=I9"`B4F5N86UE($9O;&1E<BAS*2(*;7-G<W1R("+.Q+S^O-"XQ,/[
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I
M9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/R(*;7-G<W1R("+4VL._N/;4PK/UR;ZS_;[)M<2WHKS^S^0B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HT-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E;F%M:6YG(%PB)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(K&CM.:RW;CERJ>PW*.LM_[.
M\<;WN]C3IM#%SZ+(Y\_"H[HE<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;%]Y('1O
M($QI<W0B"FUS9W-T<B`BN]BXM+6]T\J\_L'0L>TB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")297!L86-E('=I=&@Z
M(@IM<V=S='(@(LSFN[O.JJ.Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S='(@(K3PN+0B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$Q(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT,#D*(RP@9G5Z>GD*;7-G:60@(E)E<&QY(%-E;G0N
M(@IM<V=S='(@(KO8N+2UO2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL(@IM<V=S='(@
M(K3PN+3+^=/0(@H*(SH@8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L>2!T
M;R!!;&PZ(@IM<V=S='(@(K3PN+3+^=/0H[HB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G:60@(E)E<&QY('1O($QI
M<W0B"FUS9W-T<B`BN]BXM+6]T\J\_L'0L>TB"@HC.B!C;VUP;W-E+G!H<#HW
M,S4*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O($QI<W0Z(@IM<V=S='(@(KO8
MN+2UO=/*O/[!T+'M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!?06QL(@IM
M<V=S='(@(K3PN+3+^=/0(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4R."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,W"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U
M<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,S4*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O
M<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3,T"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N
M<&AP.C(V-PHC+"!F=7IZ>0IM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`BN]BX
MM+6]H[HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`Y"FUS9VED(")297!L>2U4
M;SH@(@IM<V=S='(@(KO8N+2UO:.Z(@H*(SH@8V]M<&]S92YP:'`Z-S,Q"FUS
M9VED(")297!L>3HB"FUS9W-T<B`BN]BXM"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHR-@IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHS-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,PIM<V=I9"`B
M4F5P;W)T(&%S(%-P86TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S@S"B,L(&9U>GIY"FUS9VED(")297%U97-T(&$@
M7U)E860@4F5C96EP="(*;7-G<W1R("+0Z-*JT\J\_KO8UK0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y
M(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4W,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I
M<'1S/R(*;7-G<W1R("+0Z-*JT\J\_KO8UK0B"@HC.B!M86EL8F]X+G!H<#HQ
M.#D*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-PIM<V=I9"`B
M4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHQ-#,@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N
M:6YC.C(V"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C$*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(M;8UL,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3$U"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R("*[UKBT(@H*(SH@<F5C;VUP
M;W-E+G!H<#HY.`IM<V=I9"`B4F5S=6UE('EO=7(@<V5S<VEO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#0*(RP@
M9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!<(DUE<W-A9V4@0V]M<&]S:71I;VY<
M(B(*;7-G<W1R("+0M-/*O/XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R
M:79E<E]S96QE8W0N:6YC.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHV.0HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T
M+FEN8SHS,@IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C8P('1E;7!L871E
M<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,C(*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHQ,#$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z
M,30*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T.2!T96UP;&%T97,O<&=P
M+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V
M,B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3<S"B,L(&9U>GIY"FUS9VED(")2
M971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("+1H<_N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Q.`IM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL
M8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN
M9R!A(&UE<W-A9V4_(@IM<V=S='(@(LF^L_VAHM+&MJ^AHKBTUL;3RKS^NO.W
MM;O8M;W3RKS^P="Q[=;0H[\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C@X"FUS9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,C,W"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS9VED(")3
M+TU)344B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP
M=%]L:7-T+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5N8W)Y<'0@
M365S<V%G92(*;7-G<W1R("*\T\/<T\J\_B(*"B,Z(&-O;7!O<V4N<&AP.C,Y
M-`IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B(@H*(SH@8V]M<&]S
M92YP:'`Z,S<S"FUS9VED(")3+TU)344@17)R;W(Z($YE960@<&%S<W!H<F%S
M92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3$*(RP@9G5Z>GD*;7-G:60@(E,O34E-
M12!/<'1I;VYS(@IM<V=S='(@(K&CM.;1H<_N(@H*(SH@<VUI;64N<&AP.C0Y
M"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)344@
M4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,30P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F
M;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B
MSL2\_KS07"(E<UPBTM&^K;/)N:;)OK/]H:,B"@HC.B!S;6EM92YP:'`Z,38R
M"B,L(&9U>GIY"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L
M;'D@861D960N(@IM<V=S='(@(L7DUL/0Q<^BTM&^K;?AN::X_+C$H:,B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P"B,L(&9U>GIY"FUS9VED
M(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`BM;S(Z[FKN;+#W-2_
M(@H*(SH@<VUI;64N<&AP.C(Q,0IM<V=I9"`B4R]-24U%(%!U8FQI8R]0<FEV
M871E($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"B,L(&9U
M>GIY"FUS9VED(")3+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(K>BR\W3
MRKS^(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ
M-`HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E
M(@IM<V=S='(@(KS3P]S3RKS^(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C
M=&EV92YI;F,Z-`IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@
M;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,C0Q"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N
M;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE
M('1O(&)E("(*(F1E8W)Y<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-S,*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T
M(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I9VYE
M9"!M97-S86=E(&-A;B!N;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T-@IM<V=I9"`B(@HB
M4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@
M<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"FUS9VED("(B
M"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E
M('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY('-E="!T
M;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES
M('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S('=I;&P@
M;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(P-0IM<V=I9"`B4TU44"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-34*(RP@9G5Z>GD*
M;7-G:60@(E-?=6)J96-T(@IM<V=S='(@(M;WS.(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS-C,*(RP@9G5Z>GD*;7-G:60@(E-A7W9E
M(&$@8V]P>2!I;B`B"FUS9W-T<B`BL:.TYKBQL;ZUO2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@HC+"!F=7IZ>0IM<V=I
M9"`B4V%?=F4@87,B"FUS9W-T<B`BP>VTYLZJ(@H*(SH@<V5A<F-H+G!H<#HS
M,38@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W"B,L(&9U>GIY
M"FUS9VED(")3879E(@IM<V=S='(@(L'MM.;.JB(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4S.`IM<V=I9"`B4V%V92!!='1A8VAM96YT
M<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,S"FUS9VED(")3879E($1R869T
M(@IM<V=S='(@(K3FSJJRW;CE(@H*(SH@<V%V96EM86=E+G!H<#HT,@HC+"!F
M=7IZ>0IM<V=I9"`B4V%V92!);6%G92(*;7-G<W1R("+![;3FSJHB"@HC.B!L
M:6(O34E-12]#;VYT96YT<RYP:'`Z,C`T"FUS9VED(")3879E($EM86=E(&EN
M($=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C4Y('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`P"B,Z('1E
M;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$R('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-#@*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$S
M"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BL:.TYM&AS^XB"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G
M:60@(E-A=F4@4W1A=&EO;F5R>2(*;7-G<W1R("*QH[3FT:'/[B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0S,PHC+"!F=7IZ>0IM<V=I9"`B4V%V92!?1')A
M9G0B"FUS9W-T<B`BM.;.JK+=N.4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T<B`B
MP>VTYLZJ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,0IM<V=I9"`B
M4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`W,@IM<V=I9"`B4V%V92!R96-I<&EE;G1S(&%U
M=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$R-PIM<V=I
M9"`B4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E<C\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B4V%V92!S
M96YT(&UA:6P_(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(K&CM.:R
MW;CERJ>PW*.LM_[.\<;WN]C3IM#%SZ+(Y\_"H[HE<R(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M86EL8F]X
M+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z
M-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R("*RZ=72(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]H96%D97(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-E87)C:"`E
M<R(*;7-G<W1R("*RZ=72(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`BL:.T
MYM&AS^XB"@HC.B!S96%R8V@N<&AP.C(V-0IM<V=I9"`B4V5A<F-H(%)E<W5L
M=',B"FUS9W-T<B`BLNG5TKWAN?LB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C$T('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S$*
M;7-G:60@(E-E96XB"FUS9W-T<B`BTM'4Q+;!(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHY"FUS9VED(")396QE8W0B"FUS9W-T<B`BT:'4
M\2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW,`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G<W1R("+1
MH=3QTKNX]M7*NL4B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z
M,S8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BT:'4
M\=*[N/;5RKK%(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R("+1H=3Q
MR_G3T"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PHC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B
MT:'4\=*[N/;5RKK%(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O
M<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R
M("+1H=3QU/:\T[78UK?*L<OYRKG3P[7$M=C6M[&^(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R
M("+1H=3QR_G3T"(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,R,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@
M<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`BT:'4
M\=3VO-.UV-:WRK'+^<JYT\.UQ+78UK>QOB(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@86X@
M86-C;W5N="(*;7-G<W1R("+1H=3QTKNX]M7*NL4B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C@Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R
M("*RN]&AU/$B"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI
M;F,Z.0IM<V=I9"`B4V5L96-T('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM
M86=E(&EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R
M:79E<E]S96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@=&AE(&UA:6P@<V5R
M=F5R('1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C
M97-E;&5C="YI;F,Z,S`Y"B,L(&9U>GIY"FUS9VED(")396QE8W1E9"!!9&1R
M97-S(&)O;VMS.B(*;7-G<W1R("+1H=3QM=C6M[&^H[HB"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(E-E;F0@2V5Y('1O(%!U8FQI8R!+
M97ES97)V97(B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8P-`HC+"!F=7IZ>0IM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I
M;VXB"FUS9W-T<B`BM_[.\<;WT,7/HB(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0S,0IM<V=I9"`B4V5N9"!-97-S86=E(@IM<V=S='(@(K>BR\W3RKS^(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P,PIM<V=I9"`B4V5N9"!R96%D
M(')E8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,SDW"B,L(&9U>GIY"FUS9VED(")396YT
M(&UA:6P@9F]L9&5R(@IM<V=S='(@(K2TO:C2N[CVT,*UQ+>BO/[/Y"(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,S@*(RP@9G5Z
M>GD*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(Z(@IM<V=S='(@(K2TO:C2N[CV
MT,*UQ+>BO/[/Y"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS9W-T<B`BM_[.
M\<;W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"B,L(&9U>GIY"FUS
M9VED(")397)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G<W1R("*W
M_L[QQO?0Q<^B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C(S"FUS9VED(")397)V97(Z(@IM<V=S='(@(K?^SO'&]Z.Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@<')E9F5R96YC97,@
M9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S
M<V%G97,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP
M;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,0HC+"!F=7IZ>0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G
M<W1R("+.Q+S^O-`B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.#8*(RP@
M9G5Z>GD*;7-G:60@(E-H87)E(&UA:6P@9F]L9&5R<R(*;7-G<W1R("+3RKS^
MO-`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E
M('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*;7-G:60@(B(*(E-H
M;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@
M:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL
M>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D>2!O9B!T
M97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D871A/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$S"FUS9VED
M(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S
M879I;F<@82!D<F%F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C0*(RP@9G5Z>GD*;7-G:60@(E-H;W5L9"!Y;W5R(%!'4"!P=6)L
M:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F
M875L=#\B"FUS9W-T<B`BN+V\T]*[N/;$X[7$4$=0N:NYLL/<U+^UO<3CM<33
MRKS^UM"COR(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@
M9G5Z>GD*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`BS]3*OLOY
MT]#3RKS^S;<B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV
M-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R("+/U,J^R_G3T-/*
MO/[-MR(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM<V=I9"`B4VAO=R!$96QE=&5D
M(@IM<V=S='(@(L_4RK[2T<F^L_VUQ"(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VAE861E<G,N:6YC.C8Q"B,L(&9U>GIY"FUS9VED(")3:&]W($QI;6ET960@
M2&5A9&5R<R(*;7-G<W1R("+/U,J^R_G3T-/*O/[-MR(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VAE861E<G,N:6YC.C<P"FUS9VED(")3:&]W($UA:6QI;F<@
M3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R("+/U,J^T\J\_L'0L>W0Q<^B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@HC+"!F=7IZ>0IM<V=I
M9"`B4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<R(*;7-G<W1R("+/U,J^
MSK2VJ=3$M<0B"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(E-H;W<@56YS
M=6)S8W)I8F5D(@IM<V=S='(@(L_4RK[.M+:IU,2UQ"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,#@*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO
M=R!S=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,#(*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM
M<V=S='(@(L._TK//U,J^M<33RKS^ROTN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@T,`IM<V=I9"`B4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE
M<W-A9V5S(&]N;'D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-#@*;7-G:60@(E-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-S<*;7-G:60@
M(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDU"FUS9VED
M(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F:6QT97(@:6-O
M;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C(X"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL
M<R!I;B!F;VQD97(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-C8*;7-G:60@(E-H;W=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G
M:60@(E-I7WIE(@IM<V=S='(@(K3ST*$B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")3:6=N960B"FUS9W-T
M<B`BM//0H2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN
M8SHS"FUS9VED(")3:7IE(@IM<V=S='(@(K3ST*$B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3;W)T(&)Y
M($%R<FEV86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@1G)O;2!!9&1R97-S(@IM
M<V=S='(@(K>BO/[(R[78UK<B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C0Q"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($UE
M<W-A9V4@4VEZ92(*;7-G<W1R("+3RKS^M//0H2(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@
M(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R("+.WM;WS.(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"B,L(&9U>GIY"FUS
M9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R("+.M-3$ML$B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q"B,L(&9U>GIY
M"FUS9VED(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`BMZ*\_LC+M=C6
MMR(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR,PHC+"!F
M=7IZ>0IM<V=I9"`B4W!A;2!F;VQD97(Z(@IM<V=S='(@(L"LN_C/Y*.Z(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0V"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T<B`BS-C*XM?6M_LB"@HC.B!S96%R
M8V@N<&AP.C$S,PIM<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N
M(&YO="!B92!E9&ET960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,T,PIM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T
M<B`BQK30M+SLLNDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-#8*(RP@9G5Z>GD*;7-G:60@(E-P96QL($-H96-K97(B"FUS9W-T<B`B
MQK30M+SLLNDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-#@@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS9VED(")3
M<&5L;"!C:&5C:R!C;VUP;&5T92(*;7-G<W1R("+&M-"TO.RRZ<WJL<\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Q"FUS9VED(")3<&5L;&EN9R!E
M<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$R(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-3(*(RP@9G5Z>GD*;7-G:60@(E-T87)T(@IM
M<V=S='(@(M>TS*PB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3$*;7-G:60@
M(E-T871I;VYE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T:6]N97)Y(&YA;64Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR.`IM
M<V=I9"`B4W1A=&EO;F5R>2!T>7!E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S,*;7-G:60@(E-T871I;VYE<GDZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*
M;7-G:60@(E-T871U<R(*;7-G<W1R("+7M,RL(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C(Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1R:7`@071T86-H;65N
M="(*;7-G<W1R("*XO;S^(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S
M,@IM<V=I9"`B4W1R:7`@;&EN96)R96%K<S\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-PHC+"!F=7IZ
M>0IM<V=I9"`B4W5B7VIE8W0B"FUS9W-T<B`BUO?,XB(*"B,Z(&UE<W-A9V4N
M<&AP.C(V."!T:')E860N<&AP.C$U,"!T96UP;&%T97,O8V]M<&]S92]R96-O
M;7!O<V4N:6YC.C(U"B,Z(&QI8B]396%R8V@N<&AP.C,X"FUS9VED(")3=6)J
M96-T(@IM<V=S='(@(M;WS.(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3(P"FUS9VED(")3=6)J96-T($9I96QD(@IM<V=S='(@(M;WS.+7UK;.(@H*
M(SH@<V5A<F-H+G!H<#HS,3@@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA
M9V4N:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR
M,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"FUS9VED(")3=6)M
M:70B"FUS9W-T<B`BS.&]NR(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R
M*',I(@IM<V=S='(@(LF^L_W.Q+S^O-`B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C,X,"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.#D*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@(E-U8V-E<W,B
M"FUS9W-T<B`BL\FYIB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B4W5G9V5S=&EO;G,B"FUS9W-T<B`B
ML:.TYM&AS^XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8R(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(E-U;6UA<GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`P
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,PIM<V=I9"`B4W=I
M=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!(
M5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O('!L86EN('1E
M>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#$Y"B,L(&9U>GIY"FUS9VED(")495]X="(*;7-G
M<W1R("+.Q+&^(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.0IM
M<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4Y,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T(')E
M<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<V,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5R;7,@;V8@4V5R=FEC92!F:6QE(&YO
M="!S<&5C:69I960@:6X@8V]N9BYP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,P"FUS9VED(")497AT(@IM<V=S
M='(@(L[$L;XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED
M(")4:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L
M:6YK960Z(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3,R
M"FUS9VED("(B"B)4:&4@24U!4"!S97)V97(@9&]E<R!N;W0@87!P96%R('1O
M('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"`B"B)S96QE8W1E
M9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H
M<#HT,0IM<V=I9"`B5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($UA8VEN=&]S:"!R97-O=7)C92!F
M;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+B(*;7-G<W1R("(B"@HC.B!F971C
M:&UA:6QP<F5F<RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C
M8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(M7*NL5<
M(B5S7"+2T;ZML;O)OK/]H:,B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B
M965N('-A=F5D+B(*;7-G<W1R("+5RKK%7"(E<UPBTM&^K;&[L:.TYJ&C(@H*
M(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT('=A
M<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV.0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-O
M;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W:6YD;W<@
M8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R
M;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,@IM<V=I9"`B
M5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S
M96YT;6%I;%]M;VYT:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T
M;R!<(B5S7"(N(@IM<V=S='(@(K6QQ[#.Q+S^O-!<(B5S7"*]J[&[N,3#^\ZJ
M7"(E<UPBH:,B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3`W"FUS9VED
M("(B"B)4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O
M('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960B"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z,3(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F;VQD97(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,SD*
M;7-G:60@(E1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@
M8F4@97AP86YD960N(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!A;')E
M861Y(&5X:7-T<R(*;7-G<W1R("+.Q+S^O-!<(B5S7"+2T;ZMM.;4VB(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@9F]L9&5R(%PB)7-<(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@
M:6X@:71S(&YA;64N($ET(&UA>2!C875S92`B"B)P<F]B;&5M<RX@4&QE87-E
M('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC
M.B!L:6(O1F]L9&5R+G!H<#HS-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R
M92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`BSL2\_KS07"(E<UPB
MTM&^K;/)N::XQ,/[SJI<(B5S7"*AHR(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@
M9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET
M+B(*;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HS-#,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@
M8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R
M("+.Q+S^O-`G)7,GP[O3T+&[R;ZS_:.LM_[.\<;WT,7/HLCGS\*CNB(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C(V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(L[$O/Z\T"<E<R?#N]/0
ML;O)OK/]HZRW_L[QQO?0Q<^BR.?/PJ.Z(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,S4Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A
M<R!S=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`BSL2\_KS07"(E<UPB
MTM&^K;/)N::TM+VHH:,B"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!D96QE=&5D+B(*;7-G<W1R("+.Q+S^O-!<(B5S7"+2T;ZML\FYILF^
ML_VAHR(*"B,Z(&QI8B]&;VQD97(N<&AP.C0U,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M
M960@=&\@7"(E<UPB+B(*;7-G<W1R("+.Q+S^O-!<(B5S7"+2T;ZML\FYIKC$
MP_O.JEPB)7-<(J&C(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDR
M"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@
M=&AI<R!P87)T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7W-A=F5I;6%G95]W:6XN:G,Z,3(*;7-G:60@(B(*(E1H92!I;6%G
M92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@
M:&%V92!S970@>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I;F1O
M=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY
M-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A
M=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B
M;V]K+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L
M;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"FUS9VED(")4:&4@;6%I;"!S
M97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M
M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HV-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!M86EL
M8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(L[$O/Z\T%PB)7-<
M(M+1OJVTYM3:(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B`H
M)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,#,*;7-G
M:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E
M9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,30X"B,L
M(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("+5RKK%7"(E<UPBTM&^K;&[R;ZS_:&C(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,SDS"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G
M92!H87,@8F5E;B!V97)I9FEE9"XB"FUS9W-T<B`BU<JZQ5PB)7-<(M+1OJVQ
MN[&CM.:AHR(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF
M:65D+B!396YD97(Z("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI
M;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA=&5S+W!G<"]O<&5N7W!G
M<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S<&AR87-E('=I;F1O=R!C
M86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O
M=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(')A=R!T97AT(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@
M8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z-C`*;7-G:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO
M="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`IM<V=I9"`B5&AE(')E
M<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H
M;65N="XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-30W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES
M(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E
M+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C8Y"FUS9VED(")4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C
M<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#0*;7-G:60@(E1H
M92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P,@HC+"!F=7IZ
M>0IM<V=I9"`B5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA
M8V5D+B(*;7-G<W1R("+.Q+S^O-!<(B5S7"+2T;ZML\FYIK2TO:BAHR(*"B,Z
M(&%T=&%C:&UE;G0N<&AP.C4Y"FUS9VED(")4:&4@<W!E8VEF:65D(&9I;&4@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z('-T871I;VYE<GDN<&AP
M.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R
M>2!<(B5S7"(@:&%S(&)E96X@861D960N(@IM<V=S='(@(M7*NL5<(B5S7"+2
MT;ZML;NQH[3FH:,B"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(M7*NL5<(B5S7"+2T;ZML;O)OK/]H:,B
M"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N('5P9&%T960N
M(@IM<V=S='(@(M7*NL5<(B5S7"+2T;ZML;O)OK/]H:,B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,38Y"FUS9VED(")4:&4@=&%S:R!H87,@8F5E
M;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M('1E>'0@;V8@=&AE(&UE<W-A9V4B"FUS9W-T<B`BR;ZS_=/*O/XB"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX
M,`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE
M<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@
M(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4B"FUS9W-T<B`BUMB\Q+C#
MT\J\_B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE
M<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$U-`IM<V=I9"`B5&AE('5S97(G<R!F<F5E
M+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX
M-@IM<V=I9"`B5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V5M<'1Y7VUA:6QB;W@N:6YC.C,*;7-G:60@(E1H97)E
M(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N(@IM<V=S='(@(M3:
MN,/3RL_DUM##N]/0R,ZZSM/*O/XB"@HC.B!T:')E860N<&AP.C$P.0IM<V=I
M9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C$R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X
M<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G
M<W1R("+.Q+S^O-`G)7,GP[O3T+&[R;ZS_:.LM_[.\<;WT,7/HLCGS\*CNB(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C8R,0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E
M>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`BSL2\_KS0)R5S)\.[T]"QN\F^L_VCK+?^SO'&]]#%
MSZ+(Y\_"H[HB"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG
M(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+.Q+S^O-`G)7,GP[O3T+&[
MR;ZS_:.LM_[.\<;WT,7/HLCGS\*CNB(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ
M.3@@;&EB+TUE<W-A9V4N<&AP.C(Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S
M(&9R;VT@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="`B"B)T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`BSL2\_KS0)R5S)\.[T]"QN\F^L_VCK+?^
MSO'&]]#%SZ+(Y\_"H[HB"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@
M:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`BSL2\_KS0)R5S
M)\.[T]"QN\F^L_VCK+?^SO'&]]#%SZ+(Y\_"H[HB"@HC.B!L:6(O365S<V%G
M92YP:'`Z,C$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(L[$O/Z\T"<E<R?#N]/0L;O)
MOK/]HZRW_L[QQO?0Q<^BR.?/PJ.Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E<B]E
M;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G
M:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(L[$O/Z\T"<E<R?#N]/0
ML;O)OK/]HZRW_L[QQO?0Q<^BR.?/PJ.Z(@H*(SH@9F]L9&5R<RYP:'`Z,38U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38V"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34R
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S
M86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@
M(@HB<V5R=F5R('-A:60B"FUS9W-T<B`BSL2\_KS0)R5S)\.[T]"QN\F^L_VC
MK+?^SO'&]]#%SZ+(Y\_"H[HB"@HC.B!C;VUP;W-E+G!H<#HQ,C0T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A
M(&1R869T+B(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,#`V"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO
M=7(@;65S<V%G93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0B"FUS
M9W-T<B`BU-JXP]/*S^36T,.[T]#(SKK.T\J\_B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@:&%S
M(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.CDP"FUS9VED("(B"B)4:&ES($A434P@;65S
M<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E
M<R!A<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@
M2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P-"!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,3$X"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M-#,@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-PHC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,3<S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS
M,30*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@
M;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`HC+"!F=7IZ>0IM<V=I9"`B5&AI
M<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!C;VYT:6YU93\B"FUS9W-T<B`BQ./(M[:HTJJ\S-#XPO"COR(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@
M;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q,`IM<V=I9"`B(@HB
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$T"FUS9VED(")4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B
M965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S
M<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO
M;BP@8G5T('1H92!F;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO
M=VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q
M-0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,S4P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M
M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4:&ES(&UE
M<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O
M34E-12!F;W)M870N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C(P-2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*;7-G:60@
M(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!0
M1U`N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,30S"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I
M9VYE9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S
M.`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@
M4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HR,#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDQ"FUS9VED(")4:&ES
M(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R
M("(B"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G92!T
M;R(*;7-G<W1R("*XP]/*O/ZUO2(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H
M:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$P.0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A
M(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$U
M,@HC+"!F=7IZ>0IM<V=I9"`B5&AR96%D($1I<W!L87DB"FUS9W-T<B`BS]3*
MOB(*"B,Z('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR
M,@HC+"!F=7IZ>0IM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`BSK34Q+;!
M(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP.C8P-B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E<R]C;VUP;W-E
M+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O
M<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS9VED(")4;R(*;7-G<W1R
M("+*U;S^R,LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$Y"B,L(&9U
M>GIY"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(K>BO/[(R[78UK<B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@
M(B(*(E1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI
M;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS
M9VED("(B"B)4;R!U<V4@82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@
M<G5N;FEN9R!A('9E<G-I;VX@;V8@4$A0(#4N,"XV(&]R("(*(FAI9VAE<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-3<W"B,L(&9U>GIY"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*
M;7-G<W1R("*XO;S^(@H*(SH@9F]L9&5R<RYP:'`Z,S@X"B,L(&9U>GIY"FUS
M9VED(")4<F%S:"!F;VQD97(B"FUS9W-T<B`BP*R[^,_DH[HB"@HC.B!T96UP
M;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F
M;VQD97(Z(@IM<V=S='(@(L"LN_C/Y*.Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S
M+G!H<#HV-2!L:6(O475O=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O
M8V]M;6%N9"YP:'`Z-S(*(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI
M8B]1=6]T82]C;W5R:65R+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z
M-#@*;7-G:60@(E5N86)L92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G
M<W1R("+.M+3PN+0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,U
M"FUS9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(LZTM/"XM+7$
MT\J\_B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHT('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5
M;F1E;&5T92(*;7-G<W1R("*[UKBTTM')OK/]M<0B"@HC.B!M86EL8F]X+G!H
M<#HU.#D@;6%I;&)O>"YP:'`Z-C`R(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q
M,@IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I96YT<R(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#0W"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T
M<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-38U"FUS9VED(")5;FMN;W=N($1A=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE
M('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8S-0IM<V=I9"`B56YK;F]W;B!-
M965T:6YG(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C8Q.`IM<V=I9"`B
M56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G
M:60@(E5N;&]A9"!087-S<&AR87-E(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I
M;'!R969S+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R
M("+3P[NGP_LB"@HC.B!M97-S86=E+G!H<#HT.3D@;6%I;&)O>"YP:'`Z-S`X
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$U('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,S(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHU"FUS9VED(")5;G-E96XB"FUS9W-T<B`BSK2RZ;^T(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3(*;7-G:60@(E5N<W5B<V-R
M:6)E(&9R;VT@1F]L9&5R*',I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4X-`IM<V=I9"`B57!D871E($%T=&%C:&UE
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8R,`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED(")5
M<&QO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL
M<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U;'0@5F%L=64B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B57-E
M($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW,S4*(RP@9G5Z>GD*;7-G:60@(E5S92!6
M:7)T=6%L(%1R87-H($9O;&1E<C\B"FUS9W-T<B`BQ^6S_<"LN_C/Y"(*"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-#(*(RP@9G5Z>GD*;7-G:60@(E5S
M97(B"FUS9W-T<B`BT\.[I\/[(@H*(SH@86-L+G!H<#HX-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@
M=&AE('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-PIM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`BT\.[I\/[(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")5<V5R
M;F%M93HB"FUS9W-T<B`BT\.[I\/[(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+WII<"YP:'`Z.3(@;&EB+TU)344O5FEE=V5R+W1N968N
M<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W("5S(%!U8FQI8R!+97DB"FUS9W-T<B`BR;ZS_25SN:NYLL/<U+\B"@HC
M.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,L(&9U>GIY"FUS9VED
M(")6:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G
M<W1R("+4VM#"M+"_VM;01F5T8V@@36%I;"(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C(X"B,L(&9U>GIY"FUS9VED(")6:65W($UE<W-A
M9V5S(@IM<V=S='(@(M#"T\J\_B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"B,L(&9U>GIY"FUS
M9VED(")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(K6\R.NX
M]LC+R[W(RU!'4,/<U+\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@HC+"!F=7IZ>0IM<V=I9"`B
M5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(K6\R.NX]LC+N:NY
MLE!'4,/<(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$X"B,L(&9U>GIY"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R("+.
MM-3$ML$B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38U"FUS9VED(")6:65W(%1H=6UB
M;F%I;"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W(@IM<V=S='(@(M3:T,*TL+_:UM!&971C:"!-86EL(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L(&9U>GIY"FUS
M9VED(")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T
M<B`BU-K0PK2PO]K6T$9E=&-H($UA:6PB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,30P"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(B(*"B,Z
M(&9O;&1E<G,N<&AP.C,X,"!M86EL8F]X+G!H<#HU,S0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E9I97<@;65S<V%G97,@:6X@)7,B"FUS9W-T<B`B
MT,+3RKS^(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T
M+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T
M97(@;&]G:6XZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-S`*;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")6:65W
M('1H92!);6%G97,B"FUS9W-T<B`BR;ZS_=/*O/XB"@HC.B!S96%R8V@N<&AP
M.C(V,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FER='5A;"!&;VQD
M97(@7"(E<UPB(&-R96%T960@<W5C8V5S9G5L;'DN(@IM<V=S='(@(L[$O/Z\
MT%PB)7-<(M+1OJVSR;FFR;ZS_:&C(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E92YP:'`Z,3,X(&QI8B])34%0+U1R
M964N<&AP.C$U,0HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ-3,@;&EB+TE-05`O
M5')E92YP:'`Z,34W(&QI8B])34%0+U1R964N<&AP.C$U.`HC.B!L:6(O24U!
M4"]4<F5E+G!H<#HS-CD@;&EB+TE-05`O5')E92YP:'`Z,SDS(&QI8B])34%0
M+U1R964N<&AP.C0S,PHC+"!F=7IZ>0IM<V=I9"`B5FER='5A;"!&;VQD97)S
M(@IM<V=S='(@(K2TO:C.Q+S^O-`B"@HC.B!S96%R8V@N<&AP.C(T-0IM<V=I
M9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+U9&;VQD97(N<&AP.C$W-2!L:6(O5D9O;&1E<BYP:'`Z,3@P
M"FUS9VED(")6:7)T=6%L($E.0D]8(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C0Q-@IM<V=I9"`B5FER='5A;"!)3D)/6"!&;VQD97(B"FUS9W-T<B`B
M(@H*(SH@;6%I;&)O>"YP:'`Z-#4R(&QI8B]61F]L9&5R+G!H<#HQ,30@;&EB
M+U9&;VQD97(N<&AP.C$Q.0IM<V=I9"`B5FER='5A;"!4<F%S:"(*;7-G<W1R
M("(B"@HC.B!F;VQD97)S+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(E9I<G1U
M86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(L?EL_W`K+OXS^0B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$S,PIM<V=I9"`B5FER='5A;"!F;VQD
M97(@;&%B96PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HS-S0*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B(@H*(SH@;&]G:6XN
M<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM
M<V=S='(@(KNVTZVUO2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M,3D*;7-G:60@(B(*(E=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S
M86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*
M(F]R(&EN;F]C96YT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S(W"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M
M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K
M:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP-PIM<V=I9"`B5VAE;B!O<&5N:6YG(&$@;F5W
M(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C$*;7-G
M:60@(E=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD('=E('-A=F4@871T
M86-H;65N="!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#(V"FUS9VED("(B"B)7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A
M;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD
M('1O("(*(G5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S
M('=I=&AO=70@7")`7"(I/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,3D*;7-G:60@(E=H:71E;&ES="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#$@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDW.`IM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-3@*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O
M;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(L3CU-K/PL'0
MT\K/Y-;0T]#3RKS^H[I<7&XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD
M97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U(&%R
M92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D
M(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R("+$X]3:
MS\+!T-/*S^36T-/0T\J\_J.Z7%QN(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M9F]L9&5R<U]C;VYF:7)M+FAT;6PZ.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R
M92!A='1E;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS
M*2XB"FUS9W-T<B`BQ./4VL_"P=#3RL_DUM#3T-/*O/ZCNEQ<;B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B66]U(&%R92!C;W!Y
M:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R"FUS9VED(")9;W4@
M87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(EEO
M=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R("(B
M"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*;7-G:60@(EEO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L9&5R<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ
M,S4*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E
M<CH@(@IM<V=S='(@(L3CU-K/PL'0T\K/Y-;0T]#3RKS^H[I<7&XB"@HC.B!L
M:6(O1F]L9&5R+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A
M;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E
M:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*
M(F-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G
M<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O
M('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@
M;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ-CD*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@
M=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+B(*;7-G<W1R("+$X]/0
M)7.WXM#"T\J\_B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS
M"FUS9VED(")9;W4@:&%V92`Q(&YE=R!M97-S86=E+B(*;7-G<W1R("+$X]/0
MTKNWXM#"T\J\_B(*"B,Z(&-O;7!O<V4N<&AP.C0Y-`HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E+B(*;7-G
M<W1R("+$X]/0TKNWXM#"T\J\_B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T
M=&%C:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA=F4@870@;&5A<W0@
M;VYE(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T('5P;&]A
M9"!Y970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD('1H:7,@
M;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S/R(*;7-G<W1R("(B
M"@HC.B!L:6(O24U0+G!H<#HQ,#<T"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V
M92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`B
MQ./4VL_"P=#3RL_DUM#3T-/*O/ZCNEQ<;B(*"B,Z(&QI8B])35`N<&AP.C$P
M-SD*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`BQ./4VL_"P=#3RL_DUM#3T-/*
MO/ZCNEQ<;B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PHC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS9W-T
M<B`BQ..QV-#KUL')V=/0TKNX]LK5O/[(RRXB"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HS,#(*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H
M:7,@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C(T.0IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P
M:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI
M<R`B"B)M97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VIA=F%S8W)I<'0N:6YC.C8T('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I
M<'0N:6YC.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@
M=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM<V=S='(@(L3CL=C0Z];!R=G3T-*[
MN/;*U;S^R,LN(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE
M=&5D+B(*;7-G<W1R("+$X['8T.O/R-&AUM#2JLF^L_VUQ+B]O/XN(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S
M='(@(L3CL=C0Z];!R=G3T-*[N/;*U;S^R,LN(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I
M<'0N:6YC.C(V,PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T
M(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R("+$X['8T.O6P<G9
MT]#2N[CVRM6\_LC++B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T
M+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A(')E
M8VEP:65N="XB"FUS9W-T<B`BQ..QV-#KUL')V=/0TKNX]LK5O/[(RRXB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHR.0HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@9FEL92!T
M;R!A='1A8V@N(@IM<V=S='(@(L3CL=C0Z];!R=G3T-*[N/;*U;S^R,LN(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N86)L960@
M:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!L
M:6(O36%I;&QO9RYP:'`Z,3,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+B(*
M;7-G<W1R("+6V+S$N,/3RKS^(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$T,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI
M<R!M97-S86=E(&]N("5S+B(*;7-G<W1R("+6V+S$N,/3RKS^(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-3`W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E
M(&YO="!S=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E
M9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*
M;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HU,3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I
M8F5D('1O(%PB)7-<(B(*;7-G<W1R("+.Q+S^O-!<(B5S7"+2T;ZML\FYIKC$
MP_O.JEPB)7-<(J&C(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-38R"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB
M960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`BQ..UQ,/[U]8B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`BQ..UQ,N]
MR,O#W-2_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB
M"FUS9W-T<B`BQ..UQ,N]R,O#W-2_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHV-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S$*;7-G:60@(EEO
M=7(@4'5B;&EC($ME>2(*;7-G<W1R("+$X[7$N:NYLL/<U+\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,38U"FUS9VED(")9;W5R(%)E<&QY+71O.B!A
M9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#D*;7-G:60@(EEO=7(@4R]-24U%
M(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHQ-@IM<V=I
M9"`B66]U<B!A8V-O=6YT<SHB"FUS9W-T<B`BQ..UQ-7*NL6CNB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S,*;7-G:60@(B(*(EEO=7(@86QI87,@
M861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@
M;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I
M;6%G92!T>7!E+B(*;7-G<W1R("+$X[7$Y*_`P,;WLKO6I[/6M/+3H;FFQ-RC
MK+"T0U123"M0M/+3H:&C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S
M.0IM<V=I9"`B66]U<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S
M<V%G97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T
M<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M
M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S
M='(@(L[$O/Z\T%PB)7-<(M+1OJVSR;FFR;ZS_:&C(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(P-@IM<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM<V=S
M='(@(L3CM<3'J</[H[HB"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S92YP
M:'`Z,3(X-"!M86EL8F]X+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q.`IM
M<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EO.WM;WS.)=(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,L(&9U>GIY"FUS9VED
M(")?0F-C(@IM<V=S='(@(K"UR\TB"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B
MO-/(Z[K:P_NUI2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C$U-`HC+"!F=7IZ>0IM<V=I9"`B7T-C(@IM<V=S='(@(K.MR\TB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")?1&5L971E(@IM<V=S
M='(@(LF^L_TB"@HC.B!L:6(O24U0+G!H<#HY-SD*(RP@9G5Z>GD*;7-G:60@
M(E]&;VQD97)S(@IM<V=S='(@(L[$O/Z\T"(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C@Q"FUS9VED(")?261E;G1I='DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-4"YP:'`Z.38Q"FUS9VED(")?26YB;W@B"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-4"YP:'`Z,3`R,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`BUZ+/^B(*"B,Z(&UE<W-A9V4N<&AP.C,X-`HC+"!F=7IZ
M>0IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(M2MRKS0Q<^B(@H*
M(SH@;&EB+TE-4"YP:'`Z.3<V"B,L(&9U>GIY"FUS9VED(")?3F5W($UE<W-A
M9V4B"FUS9W-T<B`BT,+3RKS^(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")?4')I;G0B"FUS
M9W-T<B`BM/+3H2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(W,B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.#D*;7-G:60@
M(E]0<FEO<FET>2(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HT,3@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@
M(LNBT,(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B7U)E<&QY(@IM<V=S='(@(K3PN+0B"@HC
M.B!L:6(O24U0+G!H<#HY.#$*(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS
M9W-T<B`BLNG5TB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0HC+"!F=7IZ
M>0IM<V=I9"`B7U-E;F0@365S<V%G92(*;7-G<W1R("*WHLO-T\J\_B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S(*(RP@
M9G5Z>GD*;7-G:60@(E]4:')E860B"FUS9W-T<B`BSK34Q+;!(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3$V"B,L(&9U>GIY"FUS9VED
M(")?5&\B"FUS9W-T<B`BRM6\_LC+(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E]5;F1E;&5T92(*;7-G
M<W1R("*[UKBTTM')OK/]M<0B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(E]6:65W(%1H<F5A
M9"(*;7-G<W1R("+.M-3$ML$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$W-@IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0T,`HC+"!F=7IZ>0IM<V=I9"`B
M871T86-H;65N="(*;7-G<W1R("*XO;S^(@H*(SH@=FEE=RYP:'`Z.3D*(RP@
M9G5Z>GD*;7-G:60@(F%T=&%C:&UE;G1S+GII<"(*;7-G<W1R("*XO;S^(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B
M>71E<R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`P"FUS9VED
M(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ-S(*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C0*;7-G:60@(F-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,C(P"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.38*;7-G:60@(F-R:71I8V%L('-Y
M<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$V.`IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C(R-`IM<V=I9"`B96YT<GD@;F]T(&9O=6YD
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3DP"FUS9VED(")F<F]M(@IM<V=S='(@(K>BO/[(RR(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.#`*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#0*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@X
M"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!S;6EM92YP:'`Z,CD@<&=P+G!H<#HV.0IM<V=I9"`B:V5Y(@IM<V=S='(@
M(B(*"B,Z(&9O;&1E<G,N<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B;6%I;&)O
M>"!F:6QE(@IM<V=S='(@(M/*S^0B"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI
M8B]-97-S86=E+G!H<#HT-C8*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T
M<B`BP_NSQB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B;F]N92(*;7-G<W1R("+-ZK/)(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B;W(B"FUS
M9W-T<B`BN_+5WR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,38*;7-G:60@(G!E
M<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,3(*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@T"FUS9VED(")S97)V:6-E('5N
M879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS9W-T<B`B
MQK30M+3MSO,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R<R(*;7-G<W1R("+&M-"TM.W.\R(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E
M;2!E<G)O<B(*;7-G<W1R("+&M-"TM.W.\R(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,#@*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&:6QT97(N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")Y;W5R(&)L86-K
M;&ES="(*;7-G<W1R("*\T\CKNMK#^[6E(@H*(SH@;&EB+T9I;'1E<BYP:'`Z
M-C$*;7-G:60@(GEO=7(@=VAI=&5L:7-T(@IM<V=S='(@(B(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O<&\O
M>FA?5%<N<&\`````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,S8U,S8Q`#$P-#$W,S8R-S8S`#`Q-S(S-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C($E-4"!4<F%D:71I;VYA
M;"!#:&EN97-E(%1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`Q($1A
M=FED($-H86YG+K%IJ'VDY2RE>,97"B,@1DP@2T]&(#QK;V9?9FQ`:&]T;6%I
M;"YC;VT^+"`R,#`Q+@HC($1A=FED($-H86YG(#QD879I9$!T;78N9V]V+G1W
M/BP@,C`P,2X*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($E-4"`T+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M
M,#$M,#4@,34Z,#0K,#@P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP
M,2TP."`Q,#HU,RLP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($1A=FED($-H
M86YG/&1A=FED0'1M=BYG;W8N='<^7&XB"B),86YG=6%G92U496%M.B!4<F%D
M:71I;VYA;"!#:&EN97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]0DE'-5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M."UB:71<;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,CD*;7-G:60@(B`@("`@
M($-C.B`B"FUS9W-T<B`B("`@L,:ENSH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0R-@IM<V=I9"`B("`@("`@5&\Z("(*;7-G<W1R("(@(""FK*7SI$@Z("(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,30*;7-G:60@(B`@("!$871E.B`B"FUS
M9W-T<B`B("`@I.FTP3H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q-PIM<V=I
M9"`B("`@($9R;VTZ("(*;7-G<W1R("(@(+%(I?.D2#H@(@H*(SH@;6%I;&)O
M>"YP:'`Z-#`U('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`HI]:Q
MML'D("5S*2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,C,*;7-G:60@(B!3=6)J
M96-T.B`B"FUS9W-T<B`B(*5$IJXZ("(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHW,`IM<V=I9"`B(&EN("(*;7-G<W1R("(@J?.M[*3E
M("(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,3(*;7-G:60@(B,B"FUS9W-T<B`BO7.XN2(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@+R`E+C)F
M34(@("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2DB"@HC.B!T:')E860N<&AP.C$U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!-97-S86=E<R(*;7-G<W1R("(E9""V;*7S(@H*(SH@;6%I;&)O>"YP:'`Z
M,3<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R("(E9""KRK9LI?.D=[-1IU*PHRXB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE
M<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(E9""KRK9LI?.D=[-1
MM^VFJ+QSIVFV;*7SJ,.F5J=!JKJF^*I!OKFZWK)ZK?NF7K/X+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G
M97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(E
M9""KRK9LI?.D=[-1IEZS^*2CK$^\<Z=IMFRE\RXB"@HC.B!L:6(O4W!A;2YP
M:'`Z,3@W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(K-O("5D(*O*MFRE\Z1WLU&W[::HJ56GH[9LI?.H
MPZ96IT&JNJ;XJD&^N;K>LGJM^\%\M6\N(@H*(SH@;&EB+U-P86TN<&AP.C$V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@
M<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`B)60@J\JV;*7SI'>S4:9>L_BL
M3[QSIVFV;*7S+B(*"B,Z(&UA:6QB;W@N<&AP.C,U-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("*Q<2`E
M9""H["`E9""F0"`E9""KRB(*"B,Z(&UA:6QB;W@N<&AP.C8R.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RX@66]U
M<B`E<R!F;VQD97(@=V%S(&YO="!R96YA;65D+B(*;7-G<W1R("(E<R"D=Z9S
MIF(N(*=!JKH@)7,@JTBE\Z=8J,.EO+-1I_.F5RXB"@HC.B!L:6(O365S<V%G
M92YP:'`Z-C4V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B5S(*;\I4>D
MHZQ/I$"MTZ98JFNJNK9LO6,N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O
M9B!T:&4@;6]N=&@N(@IM<V=S='(@(B5S(*M(I?.G6+%.J?.DZZKLKLFS4:?S
MIE<N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B5S(*1W
ML;6H_"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@7"(E<UPB+B(*;7-G
M<W1R("(E<R"D=ZCZKO@@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&1E8VQI
M;F5D+B(*;7-G<W1R("(E<R"D=[#[J=HN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P
M;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R("(E<R"D=Z9>
MPM"D0*W3(&9R964O8G5S>2"XZK!4O="H1"XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R
M97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O(%PB)7-<(BXB"FUS9W-T<B`B
M)7,@I'>F7L+0P=R]T+6Y(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!S96YT
M('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(*1WL4ZW
M?,2SN.JP5+;'L&6UN:=!+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('1E;G1A=&EV96QY
M(&%C8V5P=&5D+B(*;7-G<W1R("(E<R"D=[S(KLFQM:C\+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B5S(+QXN-^G0:JZMWS$L[CJL%0N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4X,`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC
M92!A="!<(B5S7"(N(@IM<V=S='(@(B5S(,'<O="G0:58KG4@7"(E<UPB+B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@
M(B5S(*1WIJBE7*JZMW.\5Z;<(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3DR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!W:7-H97,@=&\@86UM96YD(%PB)7-<(BXB"FUS9W-T<B`B)7,@I\:QYK2C
MO_2G0:I@MTX@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W
M,0IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F(%PB)7-<
M(BXB"FUS9W-T<B`B)7,@I\:QYK2CO_2G0:I@MTX@7"(E<UPB+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO
M;B!A8F]U="!<(B5S7"(N(@IM<V=S='(@(B5S(*?&L>;%JJCZP_:I\R!<(B5S
M7"(@JKJSS+=SN.JP5"XB"@HC.B!M97-S86=E+G!H<#HR.#4@;65S<V%G92YP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E
M<SH@)7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?=&]P+FEN8SHQ
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D)FYB<W`[;V8F;F)S
M<#LE9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B
M*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN
M*2(*;7-G<W1R("(HP+.ESK-OJ,>G[\7<J,.ROK#*J.RD5:1`K=.U9:VQ+BDB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED
M("(H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP
M;W-E('-C<F5E;BXI(@IM<V=S='(@(JGQL?.ITJ:SI_.G[ZC#IEZH[+QGMFRE
M\R(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I
M9"`B*$A434PI(@IM<V=S='(@(BBZ]*VV*2(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*%!L86EN(%1E>'0I(@IM<V=S
M='(@(BBOPJ3EIG(I(@H*(SH@<W!E;&QI;F<N<&AP.C(W.0IM<V=I9"`B(@HB
M*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@
M86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE
M(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R
M("(HO52I=Z?SI^^HPZ9>J.RV;*7SO&>G0"P@I_.G[Z2CMWRF8K-OM66ML:7-
MKL0N*2(*"B,Z('-P96QL:6YG+G!H<#HR-S8*;7-G:60@(B(*(BA396YD(&UE
M<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A
M<BX@($-H86YG97,@;VX@=&AE("(*(F-U<G)E;G0@<V-R965N('=I;&P@3D]4
M(&)E(&%P<&QI960N*2(*;7-G<W1R("(HO52I=Z?SI^^HPZ9>J.RV;*7SO&>G
M0"P@I_.G[Z2CMWRF8K-OM66ML:7-KL0N*2(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D9"!T:&5S92!B>2!C
M;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@J_:]5+M[I[FFJ+=SO%<@*B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS9VED("(J
M(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(+W0O^^^
MW*9AIWTH0U123""F:*VKH4%32$E&5""]9+/R*2`J(@H*(SH@;6%I;&)O>"YP
M:'`Z,3<R"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B,2"KRK9LI?.D=[-1IU*PHRXB"@HC.B!L:6(O4W!A;2YP:'`Z,3DW
M"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P
M86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B,2"K
MRK9LI?.D=Z96IT&JNJ;XJD&^N;K>LGJM^Z9>L_BDHZQ/O'.G:;9LI?,N(@H*
M(SH@;&EB+U-P86TN<&AP.C$W-PIM<V=I9"`B,2!M97-S86=E(&AA<R!B965N
M(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(Q(*O*MFRE\Z1WIEZS
M^*2CK$^\<Z=IMFRE\RXB"@HC.B!L:6(O4W!A;2YP:'`Z,3@Y"FUS9VED("(Q
M(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(Q(*O*MFRE\Z1WIE:G0:JZ
MIOBJ0;ZYNMZR>JW[IEZS^*RPO'.G:;9LI?,N(@H*(SH@;&EB+U-P86TN<&AP
M.C$V.0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P
M86TN(@IM<V=S='(@(C$@J\JV;*7SI'>F7K/XK+"\<Z=IMFRE\RXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`W"FUS9VED("(Q,#`@8VAA<F%C=&5R
M<R(*;7-G<W1R("(Q,#`@K=.F<J2X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Q,`IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S='(@(C$P,#`@
MK=.F<J2X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P.`IM<V=I9"`B
M,C4P(&-H87)A8W1E<G,B"FUS9W-T<B`B,C4P(*W3IG*DN"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,#D*;7-G:60@(C4P,"!C:&%R86-T97)S(@IM
M<V=S='(@(C4P,""MTZ9RI+@B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B02!L87)G92!I;6%G92!N
M86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N(@IM<V=S='(@
M(J1`K=.D:J38I&^JNKG/I/G`R2`E<R"D=ZK^I5NH[*:YMFRE\Z2D+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4P"FUS9VED("(B
M"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@82!R
M971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE("(*(G)E8VEP:65N="XB"FUS
M9W-T<B`BI$"KRJ=!M+^X9ZUNJ$0LO="Y[Z3HMFRE\Z;XJD&^N;;'N[RV;*7S
ML&6Y1JJZO52[>Z9>J.<LI'>S4;!EN48N(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]F:65L9',N:6YC.C4*;7-G:60@(D%.1"(*;7-G<W1R("*DSB(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#(*;7-G:60@(D%C8V5P="!A;F0@
M861D('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(K&UJ/RHPZ5;I$JH[*?:JKJF
MYJC&ON2DI"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G
M:60@(D%C8V5P="!R97%U97-T(@IM<V=S='(@(K&UJ/R]T*A$(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<T-@IM<V=I9"`B06-C97!T960B"FUS
M9W-T<B`BI'>QM:C\(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U
M.`IM<V=I9"`B06-C97!T960Z("(*;7-G<W1R("*D=[&UJ/PZ("(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT
M)W,@;F%M93HB"FUS9W-T<B`BK+"G0:JZI7ZSH;9LI?.H^JW3P]&G3Z97NMDZ
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S(U"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(J=`
MI<ZDZ*:A(@H*(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,3DR(&QI8B]-24U%
M+TAE861E<G,N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,@
M=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@(K=SO%<@)7,@J.RGVJJZLW&P
M5+_](@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`S
M"FUS9VED(")!9&0@<V]U<F-E(@IM<V=S='(@(K=SO%>S<;!4O_TB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<S"FUS9VED(")!9&0@=&AI<R!T
M;R!M>2!C86QE;F1A<B(*;7-G<W1R("*E6Z1*J.RGVJJZIN:HQK[DI*0B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@S"FUS9VED(")!9&0@=&\@
M;7D@8V%L96YD87(B"FUS9W-T<B`BI5ND2JCLI]JJNJ;FJ,:^Y*2D(@H*(SH@
M8V]M<&]S92YP:'`Z-3@X"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB
M)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("(@I'>W<[Q7(%PB)7-<
M(B"LL*K^I?,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`IM<V=I
M9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W
M:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B"B)O;B!A
M(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(J9BMFRE\[9]L=*JNJ90KLG%
MXZ7<PT*E?JJZJNW`63H@/&5M/BBK1*6RMK<LIG"FLZ9HM:>]T*5(I$"FYJ1`
MM:>_Z:1**3PO96T^(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O
M<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("*HY*5,N.JP5+W0
MJ_8@)7,@P,NU^"XB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HV,@IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO;B!D971A:6QS
M(@IM<V=S='(@(JCDI4RJNKCJL%2RT[A@(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.3,*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D971A
M:6QS(@IM<V=S='(@(JCDI4RJNK9LI?.RT[A@(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T
M<B`BJ.2E3*JZMFRE\[+3N&"]T*OV("5S(,#+M?@N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G
M92!E<G)O<B!D971A:6QS(@IM<V=S='(@(JCDI4RJNK9LI?._^;M^LM.X8"(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<W"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(JCDI4RJNK9LI?._^;M^LM.X8+W0
MJ_8@)7,@P,NU^"XB"@HC.B!C;VYT86-T<RYP:'`Z.#4@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,S,Y('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN
M8SHU,@IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(K-QL%2__2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*;7-G:60@(D%D9')E<W,@0F]O
M:W,B"FUS9W-T<B`BLW&P5+_](@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$X.0IM<V=I9"`B(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z
M(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B
M"B)L:6YE*3PO96T^(@IM<V=S='(@(B(*(KUSO&>K2*7SKLDLN7>S7:15ID.V
M;*7SIF&G?:RPK[6E\[#&I;NFK*7SN>^V2#H@/&5M/BBK1*6RMK<LIG"FLZ9H
MM:>]T*5(I$"FYJ1`(@HBM:>_Z:1**3PO96T^(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$X,0IM<V=I9"`B(@HB061D<F5S<V5S('1O(&5X<&QI8VET
M;'D@=&EE('1O('1H:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R
M(&5A8V@@(@HB861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@
M(B(*(J9PJD>FK*7SI*2JNJ:LI?.Y[[9(I5VG=*15ID.F8:=]H4&K:*9>PM"A
M0L+@L4BXTZM(I?.NR:5(LV^MTZBMI??#T:=/J-.S0K)Z.B`B"B(\96T^**M$
MI;*VMRRF<*:SIFBUI[W0I4BD0*;FI$"UI[_II$HI/"]E;3XB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,3$*;7-G:60@(D%L;"(*;7-G<W1R("*ITJ:S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,PIM<V=I9"`B(@HB06QL(&UE
M<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W
M;FQO861E9"!I;G1O(&]N92!-0D]8("(*(F9I;&4Z(@IM<V=S='(@(J15ID.K
M2*7SIUBDI*JZJ=*FL[9LI?.Q3K-1I%6X_*:HI$"MTR!M8F]X(*NLND&JNL#)
MKM<B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('EO
M=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P
M97)M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R(")<(B5S7"(@I*0@)7,@
MI-&K9:JZMFRE\[%.LU&EP[NWIU*PHR(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@
M(JG2IK,@)7,@K=.DZZ5(I%>D=\+@IG.LL+KTIWVJNL+"JOZE\[%.LU&G4K"C
M+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E
M;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@
M8F4@9&5L971E9"XB"FUS9W-T<B`BJ=*FLR`E<R"MTZ3KI4BD5ZJZPL*Q2*7S
ML\:E]Z=8L4ZS4:=2L*,N(@H*(SH@86-L+G!H<#HX-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!;&P@<FEG:'1S(&]N(&9O;&1E<B!<(B5S7"(@<W5C8V5S<V9U
M;&QY(')E;6]V960@9F]R('5S97(@7"(E<UPB+B(*;7-G<W1R("*K2*7SIU@@
M7"(E<UPB(*2DJ=*FL\/VJ?.HSZ7.JLP@7"(E<UPB(*JZQ7:MK:1WIJBE7*JZ
MLKZPHR(*"B,Z(&QI8B]A<&DN<&AP.C<V"FUS9VED(")!;&QO=R!&;VQD97(@
M0W)E871I;VX_(@IM<V=S='(@(J2YLURKV*7?JTBE\Z=8/R(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R
M(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@
M(J2YLURY3,)OLU>K:*Y-I<ZFW*7TI$"MTZM(I?.G6"`_(@H*(SH@;&EB+TU)
M344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T
M:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ(@IM<V=S='(@(J:YMFRE\ZJZ
MJ.2E3*[FIJ$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,@IM<V=I
M9"`B06QW87ES(@IM<V=S='(@(J7#N[<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-34W"FUS9VED(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(*;7-G
M<W1R("*EP[NWP'BF<ZK^I5O`R:[7(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4Q
M-0IM<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG
M('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@(@HB
M<V%I9#H@(@IM<V=S='(@(KG!N-6FV[9LI?.E:+"CJOZE\Z[)M6^ES:1`K=._
M^;M^+B!)34%0(+9LI?.F^*I!OKFF7L"S.B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HS.3@*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C
M<F5A=&EN9R!T:&4@;F5W(&YO=&4N(@IM<V=S='(@(JO8I=^W<[I+K6ZNR;5O
MI<VEO*J^JKJ_^;M^+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.3<*;7-G:60@
M(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@
M;F5W('1A<VLN(@IM<V=S='(@(JO8I=^W<ZC&MK6NR;5OI<VEO*J^JKJ_^;M^
M+B(*"B,Z(&UE<W-A9V4N<&AP.C0Y-B!M86EL8F]X+G!H<#HW,#$@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHY"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS-0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C8*
M;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(J1WIE["T"(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S
M(@IM<V=S='(@(J1WIE["T+9LI?,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C<*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`BKDVE
MSJM(I?.Y3,)O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS
M9W-T<B`BKDVESK9LI?.Y3,)OJ.P@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,S8*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N
M(&QO9V=I;F<@;VX_(@IM<V=S='(@(K?MM6ZD2KKTN/2V;*>]J^$LIMNPRJY-
MI<ZY3,)OLU>K:#\B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M-#(*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I
M<R!D:7-P;&%Y960_(@IM<V=S='(@(JA#M^VFK*7SIUBS4<6JJ/JNR:%!KDVE
MSKE,PF^S5ZMH/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z
M,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI
M<R!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N/R(*;7-G<W1R("*G0;U4J7>M
M;J=2L*.S;ZW3M>K`P*M(I?.G6*JZJ7>X<;;</R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B
M;&EC(&ME>3\B"FUS9W-T<B`BIT&]5*EWK6ZG4K"CLV^MTZ2]MGVJ]\9?MMP_
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z.#4*;7-G:60@(B(*(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM
M96YD960A*2(*;7-G<W1R("*G0;U4J7>M;J=2L*.G0:JZJO?&7[GOMMP_("BD
MHZO8Q+.P]:;F(2DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI
M;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(*;7-G<W1R("*G0;U4
MJ7?$?L3RMMP_(@H*(SH@;65S<V%G92YP:'`Z-#`Q('1E;7!L871E<R]M86EL
M8F]X+VIA=F%S8W)I<'0N:6YC.C8X"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*
M;7-G<W1R("*G0;U4NWNM;J7#I%NF8:=2L*.S;ZC'MFRE\[;<H4@B"@HC.B!L
M:6(O34E-12]#;VYT96YT<RYP:'`Z,C(R"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N
M=#\B"FUS9W-T<B`BIT&]5+M[K6ZEPZ1;IF&G4K"CLV^MTZK^I?.VW*%((@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS
M9W-T<B`BIT&]5+M[K6ZR3;"CIKFK2*7SIUBDI*JZJ=*FL[9LI?.VW*%((@H*
M(SH@;&EB+TE-4"YP:'`Z.34V"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`BIT&]5+M[
MK6ZR3;"CIKF\<Z=IO6.DI*JZJ=*FL[9LI?.VW*%((@H*(SH@;&EB+TE-4"YP
M:'`Z.30Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@
M>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(J=!O52[>ZUNLDVPHZ:YJ56G
MH[UCI*2JNJG2IK.V;*7SMMRA2"(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P
M97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(J=!
MO52[>ZUNI<.D6Z9AIU*PH[-OJ,>V;*7SMMP_(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z-SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R("*G
M0;U4NWNS;ZO*JTBE\ZC#JT2\<Z=IMFRE\ZC#I4+!V:5(LDVEU2`_(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-S4@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S('-P86T_(@IM
M<V=S='(@(J=!O52[>ZUNIEZS^+-OK$^\<Z=IMFRE\R`_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP-`IM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S
M='(@(JCLN4:NR;:A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ.0IM
M<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(J71I?VFW*OA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4W,0IM<V=I9"`B07-K(@IM<V=S='(@(KC?L-TB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-CD*;7-G:60@
M(D%T=&%C:"!&:6QE<R(*;7-G<W1R("*J_J5;P,FNUR(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U,`IM<V=I9"`B071T86-H(&$@8V]P
M>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\B"FUS
M9W-T<B`BIF*V;*7SI*2J_J17IT&JNB!01U`@I+VV?:KWQE\_(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W1N968N<&AP.C$Q,0IM<V=I9"`B071T86-H960@1FEL
M93HB"FUS9W-T<B`BJOZE6\#)KM<Z(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0V
M,B!L:6(O0V]M<&]S92YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@
M<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("*J_J7S
M(%PB)7-<(B"D:J1PI'>V5Z58I+FS7*17K:TNIT&JNL#)KM>H4Z:SLU&J_J5;
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S<*;7-G:60@(D%T
M=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S
M96YT+B(*;7-G<W1R("*D=ZK^I%>G0:G2K6ZH1+;'L&6JNB!I0V%L96YD87(@
MP,FNUR(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-R!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHU-0IM<V=I9"`B071T86-H;65N="(*;7-G<W1R("*J
M_J7S(@H*(SH@871T86-H;65N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B071T86-H;65N="`E<R!D96QE=&5D+B(*;7-G<W1R("*J_J7S)7.D=Z=2
ML*,N(@H*(SH@8V]M<&]S92YP:'`Z,3`Y-R!L:6(O365S<V%G92YP:'`Z-#<V
M"FUS9VED(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM
M96YT('1Y<&4B"FUS9W-T<B`BJOZE\Z1WI6BPHSH@K>RI;*K^I?.KK+I!(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0V-PHC.B!L:6(O0V]M<&]S92YP:'`Z
M,3`Y,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`BJOZE\R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-S@*;7-G:60@(D%T=&5N9&5E<R(*
M;7-G<W1R("*E6*YUI$BM^R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C4S"FUS9VED(")!='1E;G1I;VXB"FUS9W-T<B`BJF"W3B(*
M"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M:6UP.B"GY*2CJ.RITKO=K6ZJNB!)34%0(*FUIOFN3:7S+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV,C@*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@
M<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@
M:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM<V=S='(@(J;;L,K%XZ7<($A4
M34P@MFRE\Z2DJKJITJ:SN<^D^2RF<*I'L4BE\Z1(IF*GVJJZLW&P5+_]IE>S
MYJ2D(#\B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR
M.3@*;7-G:60@(D%V86EL86)L92!!9&1R97-S(&)O;VMS.B(*;7-G<W1R("*E
M::7.JKJS<;!4O_TZ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q
M-`IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`BM:6KW:9>P+.D
MI"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`B
MIEZH[%]K)7,B"@HC.B!T:')E860N<&AP.C$S-B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A8VL@=&\@)7,B"FUS9W-T<B`BIEZH["`E<R(*"B,Z('1H<F5A9"YP:'`Z
M,3,S"FUS9VED(")"86-K('1O($UU;'1I<&QE($UE<W-A9V4@5FEE=R!);F1E
M>"(*;7-G<W1R("*F7JCLP,NU^*_!I-XB"@HC.B!T:')E860N<&AP.C$S,0IM
M<V=I9"`B0F%C:R!T;R!4:')E860@1&ES<&QA>2(*;7-G<W1R("*F7JCLP_;!
M<,7CI=PB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,X-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")"860@;W(@;6%L9F]R;65D(')E<75E<W0N(%-E<G9E<B!2
M97-P;VYD960Z("5S(@IM<V=S='(@(K_YNWZJNKW0J$0N(*;XJD&^N:9>P+,Z
M("5S(@H*(SH@;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S
M92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G<W1R
M("*OM:7SL,:ENR(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V
M,0IM<V=I9"`B0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@
M:6YF;W)M871I;VX@;65S<V%G92XB"FUS9W-T<B`BI4BD5:Q/JJRZ0;!4KJ>V
M;*7SJKJM[*ELN.JNQBXB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,38*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R("*VPJ97L^8B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")";&]C:R!I;6%G97,@:6X@
M2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E
M<75E<W1E9#\B"FUS9W-T<B`BP?3"PR!(5$U,(+9LI?.DI*JZN<^D^2RPHZM$
MIF*V;*7SI*2O4Z=/J_RI^C\B"@HC.B!L:6(O4V5A<F-H+G!H<#HT,@IM<V=I
M9"`B0F]D>2(*;7-G<W1R("*ENZ3E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R("*E_K.A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8W-0IM<V=I9"`B0F]T:"!(96%D97(@3&ES
M=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(JKMP%FF0ZKMI4BD
MSK9LI?.E1,7I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,C<R"FUS9VED(")#7VAA<G-E="(*;7-G<W1R("*]<[U87V@B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(D-A;&5N9&%R(@IM
M<V=S='(@(J;FJ,:^Y"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C`Q
M"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E
M<G9E<BXB"FUS9W-T<B`BM4RJ:[-SM;*H[+NWNMVJNK9LI?.F^*I!OKDZ("(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T
M(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@
M(K5,JFNS<[6RJ.R[M[K=JKJV;*7SIOBJ0;ZY.B`B"@HC.B!L:6(O34E-12]6
M:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O
M9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@(@HB;6%I;&)O>"XB"FUS
M9W-T<B`BM4RJ:\7CI=P@+2"F8J78JV6JNJM(I?.G6*2DI76GY*CL("4R)',@
MK=.DI*JZ("4Q)',@K=.J_J7S+B(*"B,Z(&9O;&1E<G,N<&AP.C(V,R!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-0HC.B!T96UP;&%T97,O
M9F]L9&5R<R]I;7!O<G0N:6YC.C(Q('1E;7!L871E<R]S879E:6UA9V4O<V%V
M96EM86=E+FEN8SHQ.0HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI
M;F,Z,C$@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@V"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`@=&5M<&QA=&5S+W!G
M<"]P87-S<&AR87-E+FEN8SHS,@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K
M97DN:6YC.C8V"FUS9VED(")#86YC96PB"FUS9W-T<B`BJ/JN^"(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0R.0HC.B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@365S<V%G92(*;7-G<W1R("*H
M^J[XMFRE\R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L
M;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET
M<R!C;VYT96YT<RXB"FUS9W-T<B`BJ/JN^+USO&>W<[9LI?.Q3K=\O_*EHJM(
MI?.DI*JZJ=*FLZ2ZKF4N(@H*(SH@;65S<V%G92YP:'`Z,C8U('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W)E8V]M<&]S92YI;F,Z,34@;&EB+U-E87)C:"YP:'`Z,S`*;7-G:60@
M(D-C(@IM<V=S='(@(K#&I;LB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V
M86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R`B
M"B)S97)V97(N(@IM<V=S='(@(K[,P]*VUZ1*M4RNQ"X@IOBJ0;ZYI;RQTJ7.
MP,FNUZ17ML>E7*_@+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M.38*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R("*E1*YU(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED(")#:&%N9V4B
M"FUS9W-T<B`BI_.G[R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R("*E_K.AQ=RG\R(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B0VAA;F=E($9O
M;&1E<B(*;7-G<W1R("+%W*?SJTBE\Z=8(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S
M=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E
M(&%N9"`B"B)H;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`BI_.G
M[\7CI=R_[[:U+""F<*A#K;;%XZ7<MFRE\[S&I=@LMFRE\Z9PIO.QQJ9#M:4N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS9VED(")#:&%N9V4@
M;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS9W-T<B`BQ=RG
M\[9LI?.F^*I!OKFE2*3.JTBE\Z=8LUVI=RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92P@861D<F5S
M<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD("(*(G)E<&QY('1O('EO=7(@96UA:6PN(@IM<V=S='(@(J?SI^^[
MU:15JKJE_J97+*9>MFRF8:=]++%(I?.SQJ7WJ4W#L:97+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,3(*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES
M<&QA>3HB"FUS9W-T<B`BQ>.EW*JZIG*DN+S&.B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#:&5C:R!&;VQD97(H<RD@
M9F]R($YE=R!-86EL(@IM<V=S='(@(L#+K&2W<[9LI?,B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*
M;7-G<W1R("*_[ZCZ(*7^LZ$OM4Q?02(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K(&%L;"!M86EL('-E<G9E<G,@>6]U
M('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.B(*;7-G<W1R("*DQ+_OIT&W4:UN
MQ:JH^JJZI7ZSH;9LI?.Q8KBY.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-C,*;7-G:60@(D-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@
M;65S<V%G93\B"FUS9W-T<B`BIF*VQ[!EMFRE\Z2GJV4LI?VP]:;FJ_>F<L#+
MK&0_(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I
M9"`B0VAO;W-E($%C=&EO;CHB"FUS9W-T<B`BO^^^W*=`I<ZDZ*:A.B(*"B,Z
M(&-O;F9I9R]S97)V97)S+G!H<"YD:7-T.C$W.0IM<V=I9"`B0VAO;W-E(&$@
M;6%I;"!S97)V97(Z(@IM<V=S='(@(KW0O^^^W+9LI?.F^*I!OKDZ(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHR,3<*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@
M=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R("*]T*15J=2_[[[<
MJ<Z]<[_HI6O#Y*JZN.JNQJ5(P7*T^CHB"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS-#D*;7-G:60@(D-H;V]S92!T:&4@861D<F5S
M<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@
M(K_OOMRY=[-=JKJS<;!4O_VA0:5(IU&W<[Q7IF&G?2XB"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3,*;7-G:60@(D-H;V]S92!T
M:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A
M;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("*_[[[<LW&P5+_]MVJT3;:VI\<L
MI4BK2ZEMIE?!<K3Z+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!C;VYV97)T
M('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B<F]W<V5R(&-A
M;B!V:65W+B(*;7-G<W1R("+"2;_O("5S(,+@M*NYSZ3YP,FH[,)SQ/V^N:17
MK;$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G
M92XB"FUS9W-T<B`BPDF_[R`E<R"D5;C\N<^D^2XB"@HC.B!L:6(O1FEL=&5R
M+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@
M=&\@)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R("+"2;_O("5S(+9II$H@
M)7,@NMZR>JVVK;$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W($A434P@
M8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`BPDF_[R`E
M<R"F8K=SM?BUH:2DP,NU^"!(5$U,(*2ZKF4N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,38T"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K
M("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T
M<B`BPDF_[R`E<R#`R[7XIKFYSZ3YJKK!6;G/+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z-#(S"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K
M("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD
M;W<N(@IM<V=S='(@(L))O^\@)7,@IF*W<[7XM:&DI,#+M?BJ_J7S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T
M960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`BPDF_[R`E
M<R"F8K=SM?BUH:2DP,NU^&UU;'1I<&%R="]R96QA=&5DJOZE\RXB"@HC.B!L
M:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3@*;7-G:60@(D-L:6-K(&AE<F4@
M=&\@4TA/5R!T:&4@26UA9V5S(@IM<V=S='(@(L))O^^FN;-"Q>.EW+G/I/DB
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*;7-G
M:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@
M8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H
M+B(*;7-G<W1R("*LL*A#I$"EN[_OOMRJNK-QL%2__;-=J7?!<K3ZJKK$YJ;L
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,`IM<V=I9"`B0VQI
M8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O
M:R(*;7-G<W1R("+"2;_OLV^XS,!XIG,@4$=0(*2]MGVJ]\9?J.RG0:JZLW&P
M5+_]I*0B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(P,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I
M8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O:R(*;7-G<W1R("+"2;_O
MLV^XS,!XIG,@)7,@JKH@4R]-24U%(+[,P]*H[*=!JKJS<;!4O_VDI"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S@*;7-G:60@(D-L:6-K:6YG(&]N
M('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H
M92!S96YD97(B"FUS9W-T<B`BO7.\9[=SMFRE\[6YLV^MT[%(I?.D2"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,SD*;7-G:60@(D-L:6-K:6YG(&]N
M('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D
M(@IM<V=S='(@(K9]L=*XTZO*MFRE\R(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9F5T8VAM86EL+FEN8SHR.`IM<V=I9"`B0VQO<V4B"FUS9W-T<B`BP_:S
MK"(*"B,Z(&-O;7!O<V4N<&AP.C0Q-PIM<V=I9"`B0VQO<V4@=&AI<R!W:6YD
M;W<B"FUS9W-T<B`BP_:SK*:YM?BUH2(*"B,Z(&9O;&1E<G,N<&AP.C0P.`IM
M<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G<W1R("*K2*7SIUBD=\/VLZPB"@HC
M.B!F;VQD97)S+G!H<#HT,C@*;7-G:60@(D-O;&QA<'-E(@IM<V=S='(@(J?I
MQ7PB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I
M9"`B0V]L;&%P<V4@06QL(@IM<V=S='(@(J?IQ7PB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O
M;&1E<G,B"FUS9W-T<B`BI^G%?*G2IK.K2*7SIU@B"@HC.B!F;VQD97)S+G!H
M<#HT,C@*;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R("*GZ<5\JTBE
M\Z=8(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C4Q"FUS
M9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R("+#0Z;BO-"P3R(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*;7-G:60@(D-O;6UE;G0B"FUS
M9W-T<B`BM?FXT2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C(*
M;7-G:60@(D-O;7!L971E9"(*;7-G<W1R("*D=Z>YIJ@B"@HC.B!C;VUP;W-E
M+G!H<#HT,38*;7-G:60@(D-O;7!O<V4@86YO=&AE<B!M97-S86=E(@IM<V=S
M='(@(L1^Q/*\9ZCDI4RJNJM((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0S-`IM<V=I9"`B0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E('=I
M;F1O=S\B"FUS9W-T<B`BO7.\9[9LI?.I\[=SM?BUH:2D/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G
M97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U
M<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`BN7>S7:C/I<ZZ]*VV
M*$A434PIN<^GSJ3&I+:ML;USO&>V;*7S*+O=J,^ESKC[MW.JNL)S^+"^N2D_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U
M<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S='(@(K-=J7>F
M<*;SQ>.EW+9LI?,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS
M9VED(")#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N(@IM<V=S='(@
M(K9LI?.Y=\3]LUVI=RXB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM
M<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G
M<W1R("*S<[6RLU$@24U!4""F^*I!OKFRUZ3N+B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,C,T"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F
M86EL960B"FUS9W-T<B`BLW.ULJ;<IOBJ0;ZYI:*QT2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O
M;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(K&QJ.X@)7,@JKH@4$=0
M(*3DM*DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYT<F]L(%,O34E-12!S=7!P;W)T(&9O<B`E<RXB
M"FUS9W-T<B`BL;&H[B`E<R"JNB!3+TU)344@I.2TJ2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P=&EO;G,@<F5L
M871I;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R("*V;*7SMVJT
M3:JZK-O#]K&QJ.Z_[[:U+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE
M8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U("(*
M(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`BM^VW<[9LI?.H[+E&KLDL(*Q/
MIU^S<:J^N]6D52XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@T"FUS
M9VED(")#;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN=&\@9W)A<&AI8V%L
M(&]N97,_(@IM<V=S='(@(L+@M*NJ[;&AI.6F<JRPN<^NUR`_(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@
M(KW&NW,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@
M(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@(KW&NW.H[*M(I?.G6"(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHV,PIM<V=I9"`B0V]R<F5C
M="(*;7-G<W1R("*G\Z6_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`BK>RD
MY:1WI_.EOR(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S
M;VX@1VEV96XZ("5S(@IM<V=S='(@(K5,JFNGN::HO="H1"X@K>RF73H@)7,B
M"@HC.B!A='1A8VAM96YT+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8W)E871E('1H92!61E,@8F%C:V5N9#H@)7,B"FUS9W-T<B`B
MM4RJ:ZO8I=^UZL#`P,FNUZATLLXH5D93*:JZIOBJ0;K=.B`E<R(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HV-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!M97-S86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z
M("5S(@IM<V=S='(@(K5,JFNFVR`E<R"G4K"CMFRE\RZF^*I!OKFF7L"S.B`E
M<R(*"B,Z(&QI8B]397-S:6]N+G!H<#HS,C(*;7-G:60@(D-O=6QD(&YO="!E
M>&5C=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@(K5,JFNP
M]:;FNOO%0+[>IT`B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-30*
M;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F
M<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(K5,JFNFVR!-
M4RU43D5&(,/^JZRJNJ>HL6'`R:[7N-'`H\%9+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@
M<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@
M(K5,JFNFVR!::7`@P_ZKK*JZIZBQ8<#)KM>XT<"CP5DN(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@<V5C=7)E(&-O;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R
M+B`E<R`Z("5S+B(*;7-G<W1R("*U3*IKMGVQTJCL($E-05`@IOBJ0;ZYJKJF
M=Z7^LW.ULBX@)7,@.B`E<RXB"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<R"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N
M(&9R;VT@24U!4"!S97)V97(N(@IM<V=S='(@(K5,JFNFVR!)34%0(*;XJD&^
MN<6JJ/JI4J97JL6VH2AN86UE<W!A8V4IN.JP5"XB"@HC.B!S96%R8V@N<&AP
M.C,Q-"!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C,Y"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ
M-C$*;7-G:60@(D-R96%T92(*;7-G<W1R("*KV*7?(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E<B(*
M;7-G<W1R("*KV*7?(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM
M<V=I9"`B0W)E871E($ME>7,B"FUS9W-T<B`BJ]BEWZKWQE\B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,30*;7-G:60@(D-R96%T92!6:7)T
M=6%L($9O;&1E<B(*;7-G<W1R("*KV*7?M>K`P*M(I?.G6"(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"FUS9VED(")#
M<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("*KV*7?I$"MT[=SJKJQ8KBY
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C$R('1E;7!L
M871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@
M;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(JO8I=^D0*W3MW.JNKQSIVF]8R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L
M871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@
M82!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R("*KV*7?I$"MT[=SJKJO\[U:
MO6,B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(V
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#(*;7-G:60@
M(D-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(JO8I=^D
M0*W3MW.JNK%(I?.]8R(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C
M="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR-`IM
M<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R("*KV*7?
MI$"MT[=SJKJI5:>CO6,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X
M"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE
M('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*
M(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`BJ]BEW[E,PF^S5ZMHI4BP=+AM
MJ=*FLZC3JT@L(+'&ID.K2*7SIUBDI*JZJTBE\RP@I4BDSJ=2L*.\<Z=IMFRE
M\RXB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*;7-G
M:60@(D-R96%T92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R("*KV*7?MW.JNJM(
MNN`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED(")#<F5A
M=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S='(@(JO8
MI=^K2+K@NU"UJL+0+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G
M<W1R("(E<R"EV*MEJ=*]X:2IJKK%=JVM(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-0IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C
M:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(K-=J7>E
M?K.AMFRE\ZJZL6*XN2S%JJCZI7ZSH;9LI?,N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4Q"FUS9VED(")#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA
M:6PN(@IM<V=S='(@(J;;K7&F<*;SML>P9;9LI?,N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`BIMNM
M<:1`J,>U;J1*)7.KX:G2K6ZP]:;FJKJD=:=`+B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*;7-G:60@(D1A=%]E(@IM
M<V=S='(@(J3IM,%?92(*"B,Z(&UE<W-A9V4N<&AP.C(V,B!T:')E860N<&AP
M.C$T-PIM<V=I9"`B1&%T92(*;7-G<W1R("*DZ;3!(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<U,`IM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B
MP<*UM"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C0*;7-G:60@
M(D1E8VQI;F5D.B`B"FUS9W-T<B`BP<*UM#H@(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S-PIM<V=I9"`B1&5F875L="(*;7-G<W1R("*Y=[-=(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C$X
M"FUS9VED(")$969A=6QT(%-E87)C:"!&:65L9"(*;7-G<W1R("*Y=[-=MVJT
M3<3FINPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$Q"FUS9VED(")$
M969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(KEWLUVJNK'&ID.S
M5ZMH.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C$*;7-G:60@(D1E
M9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(KEWLUVJNK'&ID.V
MMJ?'.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3@*;7-G:60@
M(D1E;&5G871E9"(*;7-G<W1R("*D=ZEEL%4B"@HC.B!F;VQD97)S+G!H<#HS
M.3@@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`BIU*PHR(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0=6)L:6,@
M2V5Y(@IM<V=S='(@(J=2L*,@)7,@I+VV?:KWQE\B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM
M<V=I9"`B1&5L971E($-U<G)E;G0@2V5Y<R(*;7-G<W1R("*G4K"CI=BK9:JZ
MJO?&7R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G
M:60@(D1E;&5T92!&;VQD97(H<RDB"FUS9W-T<B`BIU*PHR(*"B,Z(&9O;&1E
M<G,N<&AP.C(V-`IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E<G,B"FUS
M9W-T<B`BIU*PHZG2O^^JNJM(I?.Y:"(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHT,@IM<V=I9"`B1&5L971E(%-T871I;VYE<GDB"FUS
M9W-T<B`BIU*PHZM(NN`B"@HC.B!F;VQD97)S+G!H<#HS.3@*;7-G:60@(D1E
M;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("*G4K"CM>K`P*M(I?.Y:"(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@
M9F]R("5S(@IM<V=S='(@(J=2L*.UZL#`JTBE\Z=8("5S(*JZJ7>X<2(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L
M971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G
M<W1R("+%JJCZJ^$LIMNF^*I!OKFG4K"CMFRE\R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV,3D*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N
M9&%R(@IM<V=S='(@(K%QI]JJNJ;FJ,:^Y*2DIU*PHR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(D1E;&5T92!O;&0@;&EN:V5D(&%T
M=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BJ?.H
M0Z3KJNPLIU*PHZ1WPN"F<ZRPNO2G?:JZPL*J_J7S(#\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S4P"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I
M;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BJ?.H
M0Z3KJNPLIU*PH\+"JKJQ2*7SL\:E]Z=8(#\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C`U"FUS9VED(")$96QE=&4@<W!A;2!M97-S86=E<R(*;7-G
M<W1R("*G4K"CO'.G:;9LI?,B"@HC.B!M97-S86=E+G!H<#HT.3D@;6%I;&)O
M>"YP:'`Z-S(W('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C`*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS."!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C@*;7-G:60@(D1E;&5T960B"FUS9W-T<B`BI'>G
M4K"C(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B
M1&5L971E9"!M97-S86=E<R(*;7-G<W1R("*D=Z=2L*.V;*7S(@H*(SH@8V]M
M<&]S92YP:'`Z-38X"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@=&AE
M(&%T=&%C:&UE;G0@7"(E<UPB+B(*;7-G<W1R("*G4K"CIKFD0*K^I?,@7"(E
M<UPB("XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E
M;&5T:6YG(&%N9"!-;W9I;F<@365S<V%G97,B"FUS9W-T<B`BIU*PHZ3.MVBR
MOK9LI?,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W"FUS9VED
M(")$96YY(')E<75E<W0B"FUS9W-T<B`BJ=JUM+W0J$0B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-30R"FUS9VED(")$96YY(')E<75E<W0@9F]R
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("*IVK6TIEZUJK=\Q+.X
MZK!4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B1&5S
M8V5N9&EN9R(*;7-G<W1R("*ET:OAIMRE_2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C8V"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("*T>:UZ(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W
M"FUS9VED(")$971A:6QS(@IM<V=S='(@(K+3N&`B"@HC.B!C;VUP;W-E+G!H
M<#HU.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ED(&YO="!A='1A8V@@7"(E
M<UPB(&%S('1H92!F:6QE('=A<R!E;7!T>2XB"FUS9W-T<B`BI;RJ_J5;JL6E
MU<#)KM<@7"(E<UPB(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-0IM
M<V=I9"`B1&EM('-I9VYA='5R97,_(@IM<V=S='(@(K)(I,;#L:97/R(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$
M:7-P;&%Y(@IM<V=S='(@(L7CI=R_[[:U(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0W.0IM<V=I9"`B1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@
M<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(K?MML>P9:>YMFRE\ZOA+,7C
MI=R]5+M[L%2NIS\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<T"FUS
M9VED(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R("+%XZ7<
MJ?.V;*7SI43%Z:17(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,`IM
M<V=I9"`B1&ES<&QA>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL
M/R(*;7-G<W1R("*THZ7<M^VFL[=SMFRE\ZCLN4:NR3\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S0V"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y
M(%-P86U<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R("*F8J5<K^"J
M[:2DQ>.EW%PBLDVJQ;QSIVF]8UPBIKFD0+-SM;(_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<S.`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!4
M<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(J9BI5ROX*KM
MI*3%XZ7<7"*R3:K%J56GH[UC7"*FN:1`LW.ULC\B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,3$*;7-G:60@(D1I<W!O<VET:6]N
M(@IM<V=S='(@(K!TN&TB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C:"(*;7-G<W1R("*DH[+%IE@B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B1&\@
M3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`BI*/`
MRZQDMW.V;*7S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,`IM<V=I
M9"`B1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN
M(@IM<V=S='(@(J2PN_*D7:2CM6^ES2(*"B,Z(&QI8B])35`N<&AP.C$P-3<*
M;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD97(_(@IM<V=S
M='(@(JQ/IU^V?;'2IKFDY:7S(#\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(S,0IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+B(*;7-G<W1R("+!V:A3IK.HSZ7.L6*XN;;</R"ET[W0I$"MTRXB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(V"FUS9VED(")$
M;VYE(@IM<V=S='(@(J>YIJ@B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z
M,3DY"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@
M1F]R;6%T(@IM<V=S='(@(K%.("5S(*15N/RFJ*RP("YZ:7`@KN:FH:JZP*/!
M6<#)(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3(*;7-G
M:60@(D1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*2(*
M;7-G<W1R("*Q3JG2IK.J_J7SI%6X_*:HK+"D0*W3("YZ:7`@KN:FH:JZP*/!
M6<#)(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C`*;7-G
M:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R("*D5;C\(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D1O=VYL;V%D
M($9O;&1E<BAS*2!;+GII<"!F;W)M871=(@IM<V=S='(@(J15N/P@6RYZ:7`@
MKN:FH5TB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DY"FUS9VED(")$
M;W=N;&]A9"!I;B`N>FEP($9O<FUA="(*;7-G<W1R("*D5;C\IJBLL"`N>FEP
M(*[FIJ&JNL"CP5G`R2(*"B,Z(&UE<W-A9V4N<&AP.C0Y-R!M86EL8F]X+G!H
M<#HW,#8@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(R('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHY"FUS9VED(")$<F%F="(*;7-G<W1R("*O\[U:(@H*(SH@
M9F]L9&5R<RYP:'`Z,S<Q"FUS9VED(")$<F%F="!F;VQD97(B"FUS9W-T<B`B
MK_.]6J=8(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z
M,C,*;7-G:60@(D1R869T<R!F;VQD97(Z(@IM<V=S='(@(J_SO5J]8SHB"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`X"FUS9VED(")%+6UA:6P@061D
M<F5S<R(*;7-G<W1R("*Y<:1LMFRE\Z9AIWTB"@HC.B!L:6(O36%I;&)O>"YP
M:'`Z,S$Y"FUS9VED(")%3D0B"FUS9W-T<B`BM;*G]"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED(")%4E)/4CH@66]U<B!M97-S
M86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N(@IM<V=S='(@(K_YNWXZ(*=!
MJKJV;*7SM4RJ:[-1N[RP92XB"@HC.B!F;VQD97)S+G!H<#HS.3D@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S
M='(@(KUSO^@B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*
M;7-G:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(KUSO^BVPJ97L^8B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@
M1FEL=&5R<R(*;7-G<W1R("*]<[_HN4S";R(*"B,Z(&9O;&1E<G,N<&AP.C,Y
M.2!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,38*;7-G:60@(D5D:70@
M5FER='5A;"!&;VQD97(B"FUS9W-T<B`BO7._Z+7JP,"K2*7SIU@B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B
M"FUS9W-T<B`BO7._Z"`E<R"JNK7JP,"K2*7SIUBI=[AQ(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES
M="(*;7-G<W1R("*]<[_HI,VUO:97L^8B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS
M9W-T<B`BO7._Z*=!JKJVPJ97L^8B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@<G5L97,B"FUS
M9W-T<B`BO7._Z*=!JKJY3,)OLU>K:"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-#D*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C
M97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(JRPIT&HY*5,
MJKJY<:1LMFRE\[%BN+F]<[_HL+ZF;K-=J7<N(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET('EO=7(@=VAI=&5L:7-T
M(@IM<V=S='(@(KUSO^BG0:JZI,VUO:97L^8B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(S.0IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R("*Y<:1LMFRE\Z9AIWTB"@HC.B!L:6(O365S<V%G92YP:'`Z-C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R
M;VT@)7,N(@IM<V=S='(@(J1WLDVJQ:G2IK,@)7,@I*2JNK9LI?,N(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D5M<'1Y
M($9O;&1E<BAS*2(*;7-G<W1R("*R3:K%(@H*(SH@9F]L9&5R<RYP:'`Z,C8U
M"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(K)-JL6I
MTK_OOMRJNJM(I?.G6"(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C,Y"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`BLDVP
MHZE5IZ.]8Z2DJ=*FL[9LI?,B"@HC.B!L:6(O24U0+G!H<#HY-38*;7-G:60@
M(D5M<'1Y(%]3<&%M(@IM<V=S='(@(K)-JL6\<Z=IO6-?4R(*"B,Z(&QI8B])
M35`N<&AP.CDT.0IM<V=I9"`B16UP='D@7U1R87-H(@IM<V=S='(@(K)-JL6I
M5:>CO6-?5"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4$=0(&9U;F-T
M:6]N86QI='D_(@IM<V=S='(@(K'2I<X@4$=0(#\B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI
M;F,Z-@IM<V=I9"`B16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G
M<W1R("*QTJ7.(%,O34E-12`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<Y.0IM<V=I9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_(@IM<V=S='(@
M(K'2I<ZV;*7SN7?$_3\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT,S8*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B
MI5NQ2[_OMK5?>2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M,3@*;7-G:60@(D5N8W)Y<'1E9"(*;7-G<W1R("*D=Z5;L4LB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3$V(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,3@*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U,2!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C4S"FUS9VED(")%;F0B"FUS9W-T<B`B
MM;*GP"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.34*;7-G:60@(D5N9"!F;W)W
M87)D960@;65S<V%G92(*;7-G<W1R("*GN::HPN"Q2+9LI?,B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,S4R"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R("*G
MN::HMFRE\R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16YD(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("*GN::HMFRE
M\Z;;("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B
M"FUS9W-T<B`BO^FD2K%+O5@B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E
M;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W
M(%-P86T@9F]L9&5R(@IM<V=S='(@(KW0O^FD2K=SO'.G:;UCJKJF5[K9(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B
M16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS
M9W-T<B`BO="_Z:1*MW.O\[U:O6.JNJ97NMDB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@;F%M
M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("*]T+_I
MI$JW<[%(I?.SQJ7WO6.JNJ97NMDB"@HC.B!T96UP;&%T97,O<')E9G,O=')A
M<VAS96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`BO="_Z:1*J56GH[UCJKJF5[K9
M(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*;7-G:60@(D5N=&ER92!-97-S86=E
M(@IM<V=S='(@(K[CJ\JV;*7S(@H*(SH@;65S<V%G92YP:'`Z,3DT(&-O;7!O
M<V4N<&AP.C$Q-C0@=&AR96%D+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%;G1R>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@
M861D<F5S<R!B;V]K(@IM<V=S='(@(K!/O_T@7"(E<UPB(*1WIJBE7*9AMW.\
M5Z;<LW&P5+_](@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ."!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HS.#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDP"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T<B`BO_F[?B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-#,Q(&QI8B])34%0+T-L:65N="YP:'`Z
M-#4T"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@
M24U!4"!S97)V97(N("5S(#H@)7,N(@IM<V=S='(@(K-SM;*H["!)34%0(*;X
MJD&^N:[)M6^ES;_YNWXN("5S(#H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C,Q,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`X"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*
M;7-G<W1R("*VQ[!EIE["T*[)M6^ES;_YNWXZ("5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,#(*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL
M>2!D96QE=&5D+B(*;7-G<W1R("*HQJ7SI'>FJ*5<JKJROK"C+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S`*;7-G:60@(D5V97)Y(#$U(&UI;G5T
M97,B"FUS9W-T<B`BJ$,@,34@I,#$P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-C<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BJ$,@
M,S`@K.W$P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-CD*;7-G:60@
M(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("*H0R`U(*3`Q,$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S<Q"FUS9VED(")%=F5R>2!H86QF(&AO=7(B
M"FUS9W-T<B`BJ$.E8J1PKLDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S8X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BJ$.DP,3!(@H*(SH@
M9F]L9&5R<RYP:'`Z-#,V"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BKFFV?2(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%
M>'!A;F0@06QL(@IM<V=S='(@(JYIMGTB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"!&;VQD97)S(@IM
M<V=S='(@(JYIMGVITJ:SJTBE\Z=8(@H*(SH@9F]L9&5R<RYP:'`Z-#,V"FUS
M9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(JYIMGVK2*7SIU@B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#`@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C4S"FUS9VED(")%>'!A;F0@3F%M97,B"FUS
M9W-T<B`BJ6VF5\%RM/HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U
M,0IM<V=I9"`B17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A
M=71O;6%T:6-A;&QY(&EN('1H92!B86-K9W)O=6YD/R(*;7-G<W1R("*F8KUS
MO&>V;*7SM?BUH:2D++GUJ^&P]:;FJ6VF5\%RM/H_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDV.`IM<V=I9"`B17AP86YD('1H92!E;G1I<F4@9F]L
M9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/R(*;7-G
M<W1R("*W[:QDK-VK2*7SIUBNR2RY=Z7]KFFV?:G2IK.K2*7SIU@_(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C$P,0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(L%RM/JDI"(*"B,Z(&QI
M8B])35`N<&AP.CDV-R!L:6(O24U0+G!H<#HY-CD*;7-G:60@(D9?971C:"!-
M86EL(@IM<V=S='(@(J5^LZ&V;*7S7V4B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V9E=&-H;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-`IM<V=I9"`B1F5T8V@@36%I;"(*;7-G<W1R("*E?K.AMFRE\R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-3<*;7-G:60@(D9E=&-H($UA:6P@:6X@
M82!S97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(J9BMW.UH:1FI*2FK*CZI7ZS
MH;9LI?,_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0V
M"FUS9VED(")&971C:"!M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S
M='(@(K5NI$JZ]+CTMFRGO:OAIMNPRJ:LJ/JE?K.AMFRE\S\B"@HC.B!L:6(O
M1F5T8VAM86EL+G!H<#HR.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE
M9"`E9"!M97-S86=E<R!F<F]M("5S(@IM<V=S='(@(J1WL7$E,B1SQ:JH^B4Q
M)&2KRK9LI?,B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R
M("*D=[%Q)7/%JJCZ(#$@J\JV;*7S(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z
M,C@W(&QI8B]&971C:&UA:6PN<&AP.C(X.2!L:6(O1F5T8VAM86EL+G!H<#HR
M.3$*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(J5^LZ&V;*7S.B`B"@HC
M.B!L:6(O1F5T8VAM86EL+G!H<#HR.3,*;7-G:60@(D9E=&-H;6%I;#H@;F\@
M;F5W(&UE<W-A9V5S+B(*;7-G<W1R("*E?K.AMFRE\SH@J%.FL[=SMFRE\RXB
M"@HC.B!L:6(O24U0+G!H<#HY-S,*;7-G:60@(D9I7VQT97)S(@IM<V=S='(@
M(K9LI?.Y3,)O7VPB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHT.3,@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z-#`*;7-G
M:60@(D9I;&4B"FUS9W-T<B`BJOZE\R(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHS,0IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B
MN4S";[ZYO^^VM2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHY
M"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`BN4S";[ZYLUVI=R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#@*;7-G:60@(D9I;'1E<B!M
M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`BN4S";Z=T
MIK.DH[:NI.6F<J2ZKF6JNK9LI?,_(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B1FEL=&5R('-U<'!O<G0@:7,@9&ES
M86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(KE,PF^^N:3DM*FHPZ6\
MIF*ENZATLLZDI+'2I<XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-PIM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("*V;*7SN4S";R(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,PIM<V=I9"`B1FEL=&5R<R!.
M3U0@06-T:79E(@IM<V=S='(@(K9LI?.Y3,)OI;RQTJ7.(@H*(SH@;&EB+T9I
M;'1E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<G,Z("5S
M(&UA;F%G96UE;G0@<&%G92(*;7-G<W1R("*V;*7SN4S";SH@)7,@NMZR>JVV
MK;$B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM
M<V=I9"`B1FEN9"(*;7-G<W1R("*T3:?D(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Y,PIM<V=I9"`B1FER<W0@36%I;&)O>"!086=E(@IM<V=S='(@
M(JM(I?.G6*JZLL2D0*VV(@H*(SH@;6%I;&)O>"YP:'`Z,S(W"FUS9VED(")&
M:7)S="!086=E(@IM<V=S='(@(K+$I$"MMB(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]?<G=A<F0B"FUS9W-T<B`BPN"Q2%]R
M(@H*(SH@9F]L9&5R<RYP:'`Z,C0U('1E;7!L871E<R]F;VQD97)S+V9O;&1E
M<G-?8V]N9FER;2YH=&UL.C4*;7-G:60@(D9O;&1E<B!!8W1I;VYS("T@0V]N
M9FER;6%T:6]N(@IM<V=S='(@(JM(I?.G6+[>IT`@+2"]5+M[(@H*(SH@9F]L
M9&5R<RYP:'`Z,C@R('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD*(SH@
M=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHV"B,Z('1E
M;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@
M(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T<B`BJTBE\Z=8NMZR>B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(")&;VQD97(@4W5M;6%R>2(*
M;7-G<W1R("*K2*7SIUBZ2ZUN(@H*(SH@86-L+G!H<#HR,PIM<V=I9"`B1F]L
M9&5R('-H87)I;F<@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(JM(I?.G6*9`
MJ,FE7*_@J,.EO+'2I<XN(@H*(SH@9F]L9&5R<RYP:'`Z-#<*;7-G:60@(D9O
M;&1E<B!U<V4@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(JM(I?.G6*E\I;RQ
MTJ7.+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3<*;7-G:60@(D9O
M<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R
M(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@(JM(I?.G6,#+M?BDI*3I
MM,'$YJ;LJKJNYJ:A(@H*(SH@8V]M<&]S92YP:'`Z.#$X('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R("+"
MX+%((@H*(SH@8V]M<&]S92YP:'`Z.#`S"FUS9VED(")&;W)W87)D.B(*;7-G
M<W1R("+"X+%(.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#`*;7-G:60@(D9O
M<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(K9LI?/"X+%(I'>GN::H(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&;W)W
M87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(K%Q("5S(,+@L4BJNK9L
MI?,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`R"FUS9VED(")&
M<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R("*F7L"SI6FESJ[)
MMJ&JNKW0J$0B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C(W"FUS9VED(")&<F]?;2(*;7-G<W1R("*Q2*7SI$A?;2(*"B,Z
M(&UE<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T."!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I
M9"`B1G)O;2(*;7-G<W1R("*Q2*7SI$@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3`V"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`BL4BE\Z1(
MIF&G?2(*"B,Z(&-O;7!O<V4N<&AP.C@Q-2!C;VUP;W-E+G!H<#HX,3D*;7-G
M:60@(D9W9#HB"FUS9W-T<B`BPN"Q2#HB"@HC.B!C;VUP;W-E+G!H<#HQ,CDV
M"FUS9VED(")&=V0Z("(*;7-G<W1R("+"X+%(.B`B"@HC.B!C;VUP;W-E+G!H
M<#HQ,CDX"B,L('!H<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R=V%R9&5D
M($UE<W-A9V5S(@IM<V=S='(@(L+@L4@Z(*1WPN"Q2"`E=2"KRK9LI?,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@*;7-G:60@(D=E;F5R86P@3W!T:6]N<R(*;7-G<W1R
M("*D0*_KO^^VM2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHS-PIM<V=I9"`B1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY
M*2(*;7-G<W1R("*E=<6JJ/JX^[=SJKJV;*7S*+;(OD&ESJGS($E-05`@IOBJ
M0;ZY*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Q(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-30*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<R.`IM<V=I9"`B1V\B"FUS9W-T<B`BJV6IN2(*"B,Z('1H
M<F5A9"YP:'`Z,3,U"FUS9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@(J9>
MK>RK2*7S(@H*(SH@;&EB+TE-4"YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T
M<B`BJ.Q<(B5S7"*S<;!4O_VP3[_]+B(*"B,Z('1E;7!L871E<R]A8VPO86-L
M+FEN8SHQ,S8*;7-G:60@(D=R86YT(&%C8V5S<R(*;7-G<W1R("*]X:2IQ7:M
MK2(*"B,Z(&UE<W-A9V4N<&AP.C4T,B!L:6(O1FEL=&5R+G!H<#HQ,#4@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$Q,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ
M,3,*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,3D*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-C@*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"B,Z(&QI8B]-24U%+U9I97=E<B]A
M<'!L961O=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<R
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%4D4B"FUS9W-T<B`BLV^X
MS"(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,2!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3(P"B,Z(&QI8B]-24U%+U9I97=E<B]R
M96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R("*V5Z3ELW.ULKMY
MJ*4B"@HC.B!C;VUP;W-E+G!H<#HR-C`*;7-G:60@(DA434P@5F5R<VEO;B!O
M9B!-97-S86=E(@IM<V=S='(@(DA434P@KN:FH;9LI?,B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G
M<W1R("*J[<!9(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN
M8SHU"FUS9VED(")(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O
M<VEN9SHB"FUS9W-T<B`BI4BD5:Q/IT&JNK9LI?.]<[_HI+JN93HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4V"FUS9VED(")(:61D96XB"FUS9W-T
M<B`BP?3"PR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-34*;7-G:60@
M(DAI9&1E;B!I;B!4:')E860@5FEE=R(*;7-G<W1R("+!],+#J?/#]L%PP,NU
M^*2D(@H*(SH@;6%I;&)O>"YP:'`Z,S0Y"FUS9VED(")(:61E($1E;&5T960B
M"FUS9W-T<B`BP?3"PZ1WIU*PHR(*"B,Z(&9O;&1E<G,N<&AP.C(W-PIM<V=I
M9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`BP?3"PZ6\K7&^7"(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-`IM<V=I9"`B2&EG
M:"(*;7-G<W1R("*PJB(*"B,Z(&UE<W-A9V4N<&AP.C(Y-R!M86EL8F]X+G!H
M<#HW,3$@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,@IM<V=I9"`B
M2&EG:"!0<FEO<FET>2(*;7-G<W1R("*PJL!UI?TB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T
M<B`BL\RPJB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-S8*;7-G:60@
M(DAO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/R(*;7-G
M<W1R("*G0:6TNN*F<*;SQ>.EW*K^I5O`R:[7J4\_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P-`IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q=6]T
M960@;&EN97,@:6X@82!R97!L>2(*;7-G<W1R("*F<*;SJ7>X<:9>PM"DY:7S
MJKJDWJUZID,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$S-`IM<V=I
M9"`B24U!4"(*;7-G<W1R("))34%0(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB
M"FUS9W-T<B`B24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*2(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z,SDQ"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E<W!O
M;F1E9#H@)7,B"FUS9W-T<B`B24U!4""F^*I!OKG#]K.LLW.ULBX@IOBJ0;ZY
MIE[`LSH@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-3
M3"(*;7-G<W1R("))34%0(&]V97(@4U-,(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HQ-3(*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D
M(&-E<G1I9FEC871E*2(*;7-G<W1R("))34%0(&]V97(@4U-,("AS96QF+7-I
M9VYE9"!C97)T:69I8V%T92DB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$V-@IM<V=I9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960I(@IM
M<V=S='(@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z,S8X"FUS9VED("))34%0('-E<G9E<B!C;&]S960@
M=&AE(&-O;FYE8W1I;VXN(@IM<V=S='(@(DE-05`@IOBJ0;ZYP_:SK+-SM;(N
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C0@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R
M("))34%0+"!N;R!43%,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C0Y
M"FUS9VED("))34%0+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@(DE-05`O
M4$]0,R"V;*7SIOBJ0;ZY(@H*(SH@;&EB+TE-4"YP:'`Z.#,W"FUS9VED("))
M3D)/6"(*;7-G<W1R("*FK*7SIU@B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V
M92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B
MIG"Q_:C/I<X@4U-,(*G.(%1,4R"E6[%+LW.ULBX@4$A0(*6RMK>E_;C\I$H@
M;W!E;G-S;""IM:;Y+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?
M8V]N9FER;2YH=&UL.C$R"FUS9VED("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M
M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S="$B"FUS9W-T
M<B`BIG"J1\1^Q/(LJTBE\Z=8I*2JNJG2IK.V;*7SL4Z_\J6B(2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,@IM<V=I9"`B26=N;W)E
M(@IM<V=S='(@(JF_LJ0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z.#,*;7-G:60@(DEG;F]R92!!;&PB"FUS9W-T<B`BJ;^RI*G2IK,B
M"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.`IM<V=I
M9"`B26UA9V4B"FUS9W-T<B`BN<^D^2(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VEM<&]R="YI;F,Z,C`*;7-G:60@(DEM<&]R="(*;7-G<W1R("*VUZ1*(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@U('1E;7!L871E
M<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C4*;7-G:60@(DEM<&]R="!+97DB"FUS
M9W-T<B`BMM>D2JKWQE\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y
M"FUS9VED("));7!O<G0@2V5Y<&%I<B(*;7-G<W1R("*VUZ1*JO?&7[GO(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C<*;7-G:60@(DEM
M<&]R="!-97-S86=E<R(*;7-G<W1R("*VUZ1*MFRE\R(*"B,Z('!G<"YP:'`Z
M-#$*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@(K;7I$H@4$=0(*KW
MQE\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDQ"FUS9VED("))
M;7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&4B"FUS9W-T<B`BMM>D2JW3I$B^
MS,/2+B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,30*;7-G
M:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97DB"FUS9W-T<B`B
MMM>D2JW3I$BJNB!01U`@J'"Q2ZKWQE\N(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC
M(%!'4"!+97DB"FUS9W-T<B`BMM>D2JW3I$BJNB!01U`@I+VV?:KWQE\N(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM
M<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S(@IM<V=S='(@(K;7
MI$JMTZ1((%,O34E-12"^S,/2+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS9VED("));7!O
M<G0@4'5B;&EC($ME>2(*;7-G<W1R("*VUZ1*I+VV?:KWQE\B"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L
M:6,@4$=0($ME>2(*;7-G<W1R("*VUZ1*(%!'4""DO;9]JO?&7R(*"B,Z('1E
M;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX"FUS9VED("));7!O<G0@
M4'5B;&EC(%,O34E-12!+97DB"FUS9W-T<B`BMM>D2B!3+TU)344@I+VV?:KW
MQE\N(@H*(SH@<VUI;64N<&AP.C$V"FUS9VED("));7!O<G0@4R]-24U%($ME
M>2(*;7-G<W1R("*VUZ1*(%,O34E-12"J]\9?(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@;6)O>"!&:6QE(@IM
M<V=S='(@(K;7I$H@;6)O>"#`R:[7(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M:6UP;W)T+FEN8SHQ-@IM<V=I9"`B26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O
M(&9O;&1E<B`E<RXB"FUS9W-T<B`BMM>D2B!M8F]X(,#)KM<@)7,@J.RK2*7S
MIU@@)7,@I*0N(@H*(SH@;65S<V%G92YP:'`Z-#DX(&UA:6QB;W@N<&AP.C<R
M,2!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C<*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C,S"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N
M9"YI;F,Z-PIM<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(JVKK6XB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@
M;65S<V%G97,B"FUS9W-T<B`BK:NM;K9LI?,B"@HC.B!F;VQD97)S+G!H<#HQ
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@
M9G)O;2`E<RXB"FUS9W-T<B`BI'>VUZ1*("5D(*O*MFRE\Z;;("5S("XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8V"FUS9VED("));B!0<F]C
M97-S(@IM<V=S='(@(K9IIN:DI"(*"B,Z(&9O;&1E<G,N<&AP.C,V,R!L:6(O
M1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,3(@;&EB+TE-4"YP:'`Z
M,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$P.2!L:6(O24U!4"]4<F5E+G!H
M<#HR,30*;7-G:60@(DEN8F]X(@IM<V=S='(@(J:LI?.G6"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.3(*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S
M=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`BIE["
MT*[)I5VL0;S0P%FZ2ZUN/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.#<*;7-G:60@(DEN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY
M/R(*;7-G<W1R("*F7L+0KLFE7:Q!K>RI;*3EI?,_(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z,3,P"FUS9VED("));F9O(@IM<V=S='(@(KCJL%0B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(J2]MGVJ]\9?("5S(*JZN.JP5"(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@
M;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`BK=.D2*APL4NJ]\9?
MN.JP5"XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R
M<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R("*MTZ1(I+VV?:KWQE^XZK!4+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-2!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.3@*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:G,Z-38*;7-G:60@(DEN;&EN92(*;7-G<W1R
M("*JO;&UQ>.EW*GSI;NDY;#/(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.CD*;7-G:60@(DEN<V5R="!#97)T:69I8V%T92!(97)E(@IM
M<V=S='(@(J9BIKFTH:1*OLS#TKCJKL8B"@HC.B!T96UP;&%T97,O<&=P+VEM
M<&]R=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T
M92!01U`@2V5Y($AE<F4B"FUS9W-T<B`BIF*FN;2AI$JMTZ1(JKH@4$=0(*AP
ML4NJ]\9?+B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,3`*
M;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2!(97)E(@IM
M<V=S='(@(J9BIKFTH:1*K=.D2*JZ(%!'4""DO;9]JO?&7RXB"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4*;7-G:60@(DEN<V5R="!0=6)L
M:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(J9BIKFTH:1*(%!'4""DO;9]JO?&
M7R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3,*;7-G:60@(DEN
M=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS
M9W-T<B`BJ=*_[[[<JKJG0*7.I.BFH;GOIKFDN*7SM4RNQ"XB"@HC.B!M86EL
M8F]X+G!H<#HU-S(@;6%I;&)O>"YP:'`Z-C$T"FUS9VED("));G9A;&ED($%D
M9')E<W,B"FUS9W-T<B`BI*.F6*IKJKJF[:=](@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B
M"FUS9W-T<B`BM4RNQ*JZN[>ZW;9LO6,B"@HC.B!C;VUP;W-E+G!H<#HQ-3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!C:&%R86-T97(@:6X@92UM
M86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R("*Y<:1LMFRE\Z;MIWTZ("5S(*=T
MIK.U3*[$JKJF<J2X+B(*"B,Z('-M:6UE+G!H<#HW."!P9W`N<&AP.C$V"FUS
M9VED("));G9A;&ED(&ME>2(*;7-G<W1R("*U3*[$JKJJ]\9?(@H*(SH@<&=P
M+G!H<#HQ.3(*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!R:79A=&4@
M:V5Y+B(*;7-G<W1R("*U3*[$JKH@4$=0(*W3I$BH<+%+JO?&7RXB"@HC.B!P
M9W`N<&AP.C$V-PIM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC
M(&ME>2XB"FUS9W-T<B`BM4RNQ*JZ(%!'4""MTZ1(I+VV?:KWQE\N(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B26YV97)T
M(@IM<V=S='(@(J3/O^^^W"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4X.`IM<V=I9"`B2T(B"FUS9W-T<B`B2T(B"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3$S"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@
M(JKWQE^J^*O7(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I
M9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@=&\@
M8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*
M;7-G<W1R("*J]\9?JKJ[<Z=`I6FOX+O=K6ZJX:1`J,>NR;:AJ-.GN::H+B"L
M3Z=?Q'[$\B`_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS-2!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,S<*;7-G:60@(DME>2!I;7!O<G0@:7,@
M;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@
M=&AI<R!S97)V97(N(@IM<V=S='(@(JKWQE^VUZ1*M4RNQ"X@IOBJ0;ZYI;RQ
MTJ7.P,FNUZ17ML>E7*_@+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,S<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,Y"FUS9VED("(B"B)+97D@
M:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H879E(&YO(&%D9')E<W,@
M8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R("(*(F-O;G1A8W1S+B(*;7-G<W1R
M("*J]\9?MM>D2K5,KL0N(+=SO%?!<+6XI$BEO*O\J7>Y=[-=LW&P5+_]+B(*
M"B,Z('!G<"YP:'`Z,S$T"FUS9VED(")+97D@<W5C8V5S<V9U;&QY('-E;G0@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(JKWQE^D=Z:HI5RJ
MNK;'L&6FW*2]MGVJ]\9?IOBJ0;ZY+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C$U"FUS9VED("),86YG=6%G92(*;7-G<W1R("*[>:BE(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y-`IM<V=I9"`B3&%S="!-86EL
M8F]X(%!A9V4B"FUS9W-T<B`BJTBE\Z=8JKJSS*OAI$"MMB(*"B,Z(&UA:6QB
M;W@N<&AP.C,T,`IM<V=I9"`B3&%S="!086=E(@IM<V=S='(@(K/,J^&D0*VV
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30V"FUS9VED
M("),:6YK($%T=&%C:&UE;G1S/R(*;7-G<W1R("*J_J7SPN"F<[KTIWT_(@H*
M(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C$P.#,*;7-G
M:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R
M("*U3*IKIG.H^J1WPN"F<ZRPNO2G?:JZJOZE\RXB"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,3$P,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:6YK<R!W:6QL(&5X
M<&ER92!O;B`E<R(*;7-G<W1R("*FLZ[$I.FFW"5SK+"D[B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#<P"FUS9VED("(B"B),:7-T(&%L;"!C;VYT
M86-T<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I
M<V%B;&5D+"!Y;W4@=VEL;"`B"B)O;FQY('-E92!C;VYT86-T<R!T:&%T('EO
M=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI(@IM<V=S='(@(B(*(KUSO&>V;*7S
MKLDLIF*S<;!4O_VU9:VQI*3%XZ7<J=*FL\%PM;BD2#\@**9PJD>DHZ3$O^^F
MN;:U++-QL%2__;5EK;&VR,7CI=R[4+=J(@HBM$VLV[+%JKJXZJ[&*2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-S,*;7-G:60@(DQI<W1I;F<@:6X@
M=&AE($AE861E<B(*;7-G<W1R("*F8JKMP%FDI*9#JNTB"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S`*;7-G:60@(DQO8V%L($UA:6QB
M;W@Z(@IM<V=S='(@(K%.Q:JH^JJZI7ZSH;9LI?,LJ?&X;:GSI%6F0ZJZI;NF
M8;9LO6,Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W,0IM<V=I
M9"`B3&]C871I;VXB"FUS9W-T<B`BINRX;2(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C(T"FUS9VED("),;V<@:6XB"FUS9W-T<B`BM6ZD2B(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&]G(&EN('1O("5S(@IM<V=S='(@(K5NI$JH["`E<R(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,X"FUS9VED("),;V=I;B(*;7-G
M<W1R("*U;J1*(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED
M("),;V=I;B!487-K<R(*;7-G<W1R("*U;J1*I'6G0"(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@
M(J=#(@H*(SH@;65S<V%G92YP:'`Z,CDY(&UA:6QB;W@N<&AP.C<Q-"!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$S"FUS9VED("),;W<@4')I;W)I
M='DB"FUS9W-T<B`BIT/`=:7](@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E<W0B"FUS9W-T<B`BL\RG0R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#0*;7-G:60@(DUA
M8VEN=&]S:"!&:6QE(@IM<V=S='(@(K/!JO>V\,#)KM<B"@HC.B!T96UP;&%T
M97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*;7-G:60@(DUA:6PB"FUS9W-T
M<B`BNO2X]+9LI[TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*;7-G
M:60@(DUA:6P@4')E=FEE=W,B"FUS9W-T<B`BMFRE\[EWQ/TB"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C$V"FUS9VED(")-
M86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM<V=S='(@(K']LW.Q
MM:JZMFRE\Z;XJD&^N:NLND$Z(@H*(SH@9F]L9&5R<RYP:'`Z,S8W(&9O;&1E
M<G,N<&AP.C,X,0IM<V=I9"`B36%I;&)O>"(*;7-G<W1R("*V;+UC(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0IM<V=I9"`B36%I;&)O>"!A;F0@
M1F]L9&5R($1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("*V;+UCI,ZK2*7SIUC%
MXZ7<O^^VM2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X
M"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*
M;7-G<W1R("*\T+!/J=*FLZM(I?.LL*S=N4PB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@
M:6X@1F]L9&5R(&%S(%5N<V5E;B(*;7-G<W1R("*\T+!/J=*FLZM(I?.LL*6\
MK-VY3"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-
M87)K(&%S.B(*;7-G<W1R("*\T+!/IJ@Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8S.`IM<V=I9"`B36%R:R!D:69F97)E;G0@;&5V96QS(&]F('%U
M;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/R(*;7-G<W1R("*E2*2CIE"J
MNL-#IN*PS[EJIE["T*3EL[D_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E96X_("A)
M34%0(&]N;'DI(@IM<V=S='(@(K%.MFRE\[S0L$^FJ*1WK-VY3"BVR+Y!I<ZI
M\R!)34%0(*;XJD&^N2DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0V
M"FUS9VED(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(KS0L$_"LK/F
MN,NYHB`_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0V"FUS
M9VED(")-871C:"!!;&P@475E<FEE<R(*;7-G<W1R("*DQ[!TJ=*FLZJZK&2X
MWR(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT,@IM<V=I9"`B
M36%T8V@@06YY(%%U97)Y(@IM<V=S='(@(J3'L'2E]*1`K&2XWR(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-`IM<V=I9"`B36%X:6UU
M;2!!='1A8VAM96YT(%-I>F4B"FUS9W-T<B`BJOZE\Z2YLURD5ZVM(@H*(SH@
M;&EB+V%P:2YP:'`Z-SD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($9O;&1E
M<G,B"FUS9W-T<B`BJTBE\Z=8I%>MK;S&I=@B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT.#8*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F
M(&%T=&%C:&UE;G1S(')E86-H960N(@IM<V=S='(@(JK^I?.\QJ78I'>Y1J17
MK:TN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@R"FUS
M9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*
M;7-G<W1R("*J_J7SI&JD<*1WN4:D5ZVM+B(*"B,Z(&QI8B]";&]C:R]T<F5E
M7V9O;&1E<G,N<&AP.C,*;7-G:60@(DUE;G4@1F]L9&5R($QI<W0B"FUS9W-T
M<B`BJTBE\Z=8ID.J[2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-#(*;7-G:60@
M(DUE<W-A9V4B"FUS9W-T<B`BMFRE\R(*"B,Z(&-O;7!O<V4N<&AP.C4Y-B!C
M;VUP;W-E+G!H<#HV,C,@8V]M<&]S92YP:'`Z-C<W(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO;B(*;7-G<W1R
M("*V;*7SO&>G0"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*;7-G
M:60@(DUE<W-A9V4@1&%T92(*;7-G<W1R("*V;*7SI.FTP2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P,PIM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@
M(K9LI?._[[:U(@H*(SH@<V5A<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@
M4V5A<F-H(@IM<V=S='(@(K9LI?.W:K1-(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDP.0IM<V=I9"`B365S<V%G92!3:7IE(@IM<V=S='(@(K9LI?.D
M:J1P(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS9VED(")-97-S86=E(%-O=7)C
M92(*;7-G<W1R("+`R[7XK>RI;,#)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8V"FUS9VED(")-97-S86=E(%9I97=I;F<B"FUS9W-T<B`BMFRE\\#+
MM?@B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G:60@(DUE
M<W-A9V4@9FQA9W,B"FUS9W-T<B`BMFRE\[S0P]$B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E(&9O;&1E<G,B"FUS
M9W-T<B`BJTBE\Z=8(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T<B`BMFRE\Z;;
M("5S(@H*(SH@;6%I;&)O>"YP:'`Z-C4U"FUS9VED(")-97-S86=E(&AA<R!A
M='1A8VAM96YT<R(*;7-G<W1R("*V;*7SI+JG=*K^I5O`R:[7(@H*(SH@;6%I
M;&)O>"YP:'`Z-C0V"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E9"(*;7-G
M<W1R("*V;*7SI'>E6[%+(@H*(SH@;6%I;&)O>"YP:'`Z-C0Q"FUS9VED(")-
M97-S86=E(&ES('-I9VYE9"(*;7-G<W1R("*V;*7SI'?#L;.Y(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C,S"FUS9VED(")-97-S86=E(&UA
M=&-H97,B"FUS9W-T<B`BI,>P=+'XI?,B"@HC.B!C;VUP;W-E+G!H<#HX-C(@
M8V]M<&]S92YP:'`Z.#8Y"FUS9VED(")-97-S86=E(')E9&ER96-T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("*V;*7SPN"G?;N\L&6FJ*5<+B(*"B,Z(&-O
M;7!O<V4N<&AP.C$Q,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B365S<V%G92!S
M96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<R(*;7-G<W1R
M("*V;*7SN[RP9::HI5PLIOVI?*6\P'BF<Z;<("5S(@H*(SH@8V]M<&]S92YP
M:'`Z,3$W,R!C;VUP;W-E+G!H<#HQ,3@Q"FUS9VED(")-97-S86=E('-E;G0@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R("*V;*7SN[RP9::HI5PN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDR.0IM<V=I9"`B365S<V%G97,@<&5R('!A
M9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`BJ$.MML7CI=RJNK9L
MI?.\QJ78+B(*"B,Z(&UA:6QB;W@N<&AP.C,P.`IM<V=I9"`B365S<V%G97,@
M=&\B"FUS9W-T<B`BMFRE\ZCL(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C(Y"FUS9VED(")-;V1I9GDB"FUS9W-T<B`BQ=RG\R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N
M(@IM<V=S='(@(J9BME>Y3*1`M:>JNJ9AIWVDI*?DJ.S$YJ;L(%PB)7-<(BXB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4B
M"FUS9W-T<B`BMVBROB(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,Q-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(J15LKXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`V"FUS9VED(")-;W9E('-P86T@
M;65S<V%G97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S
M('1O($E.0D]8(@IM<V=S='(@(K=HLKZ\<Z=IMFRE\ZCLO'.G:;UCJ<ZQ3J2C
MK$^\<Z=IJKJV;*7SMVBROJCLIJRE\[UCI*0B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@
M(K=HLKZH[*M(I?.G6"(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,Q-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("*D5[*^(@H*(SH@
M;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU
M;'1I<&%R="]A;'1E<FYA=&EV92(*;7-G<W1R("*F:*VKLM6FJ"^E:;3`I4XB
M"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z,34Q"FUS9VED(")-=6QT
M:7!L92!-97-S86=E(%9I97<B"FUS9W-T<B`BMFRE\\#+M?@B"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z-0IM<V=I9"`B
M3D].12(*;7-G<W1R("*U3"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT."!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`BL\:U
M^2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,X(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#,*;7-G:60@(DYA;64B"FUS9W-T
M<B`BIE>ZV2(*"B,Z('!G<"YP:'`Z,3`V"FUS9VED(").86UE(&%N9"]O<B!E
M;6%I;"!C86YN;W0@8F4@96UP='DB"FUS9W-T<B`BIE>ZV2"DSB^ISB"Y<:1L
MMFRE\Z;LIWVDHZ5IK+"JQ:75(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<W,0IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(KO=K6ZG0*7.
MI.BFH2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S`@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<V-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`BI<.DHR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C`*;7-G:60@(DYE=F5R('-A
M=F4@871T86-H;65N=',B"FUS9W-T<B`BI<.DH\!XIG.J_J5;P,FNUR(*"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,C0*;7-G:60@(DYE=R(*;7-G<W1R
M("*W<ZJZ(@H*(SH@;&EB+TE-4"YP:'`Z-3<T"FUS9VED(").97<@1F]L9&5R
M(@IM<V=S='(@(K=SJKJK2*7SIU@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#@*;7-G:60@(DYE=R!-86EL(@IM<V=S='(@(K=SMFRE\R(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HR,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,C(*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,S<*;7-G:60@(DYE
M=R!-97-S86=E(@IM<V=S='(@(KQGJT@B"@HC.B!M86EL8F]X+G!H<#HW-C,@
M;&EB+TU)344O2&5A9&5R<RYP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@
M(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(KQGJTBUN2`E<R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E
M<R(*;7-G<W1R("*W<[9LI?,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3,S"FUS9VED(").97AT(@IM<V=S='(@(J15I$"H0B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G
M:60@(DYE>'0@365S<V%G92(*;7-G<W1R("*D5:1`J\HB"@HC.B!M86EL8F]X
M+G!H<#HS,S@*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R("*D5:1`K;8B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S<@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-34P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-C4*;7-G:60@(DYO(@IM<V=S='(@(J=?(@H*(SH@<VUI;64N<&AP
M.C(R,@IM<V=I9"`B3F\@0V5R=&EF:6-A=&4@9F]U;F0B"FUS9W-T<B`BI^2D
MHZCLOLS#TKCJKL8B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI
M<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T<B`BMFRE\Z2C
MI5NQ2R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B3F\@
M2V5Y<R!I;B!+97ER:6YG(@IM<V=S='(@(L9?L,W`]*17J%.FLZ7TIO.J]\9?
M(@H*(SH@;6%I;&)O>"YP:'`Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(DYO
M($UE<W-A9V5S(@IM<V=S='(@(JA3IK.V;*7S(@H*(SH@<&=P+G!H<#HQ,S,*
M;7-G:60@(DYO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("*U
M3"!01U`@I+VV?:KWQE^S4;;7I$HN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHX-`IM<V=I9"`B3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E
M<V5N="(*;7-G<W1R("*MTZ1(OLS#TJ2CIG.F8BXB"@HC.B!L:6(O36%I;&)O
M>"YP:'`Z,S,V"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`BM4RY
M=\3]I+JN92(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G
M:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(J?DI*.H[*2]MGVJ
M]\9?(@H*(SH@<VUI;64N<&AP.C$T-PIM<V=I9"`B3F\@4R]-24U%('!U8FQI
M8R!K97D@:6UP;W)T960N(@IM<V=S='(@(E,O34E-12"DO;9]JO?&7ZA3IK.V
MUZ1*+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY,@IM<V=I9"`B
M3F\@871T86-H;65N=',@9F]U;F0N(@IM<V=S='(@(JA3IK.J_J5;P,FNURXB
M"@HC.B!L:6(O0W)Y<'0O4TU)344N<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@
M:6YF;W)M871I;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T
M<B`BI+VV?:KWQE^DI*6\I5VG=+EQI&RV;*7SK-O#]KCJL%0B"@HC.B!A8VPN
M<&AP.C<Q(&%C;"YP:'`Z.3<*;7-G:60@(DYO(&9O;&1E<B!S96QE8W1E9"XB
M"FUS9W-T<B`BJ7REO+_OOMRK2*7SIU@N(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$T-@IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME
M9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(JG2IK/`RZQDN4RJNJM(I?.G6*2D
MLZ.H4Z:SMW.V;*7S+B(*"B,Z(&9O;&1E<G,N<&AP.C$Y-R!L:6(O1F]L9&5R
M+G!H<#HU,#@@;&EB+T9O;&1E<BYP:'`Z-34X"FUS9VED(").;R!F;VQD97)S
M('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(KW0O^^^W*O\J7>JNJM(I?.G6"(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-3(*;7-G:60@(DYO(&9O;&1E
M<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`BJ%.FLZ5=IW2W<[9LI?.J
MNJM(I?.G6"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#D*;7-G:60@
M(DYO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`BJ%.F
MLZ5=IW2EO*S=N4RV;*7SJKJK2*7SIU@B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,S,V"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R("*H4Z:S
MMFRE\Z2ZKF4B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S@P"FUS9VED(").;R!M
M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H+B(*;7-G<W1R("*H4Z:SMFRE
M\[+%IEBW:K1-L?BE\RXB"@HC.B!P9W`N<&AP.C$X-0IM<V=I9"`B3F\@<&5R
M<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(")01U`@
MK=.D2*APL4NJ]\9?J%.FL[-1MM>D2BXB"@HC.B!P9W`N<&AP.C$V,0IM<V=I
M9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S
M='(@(E!'4""MTZ1(I+VV?:KWQE^H4Z:SLU&VUZ1*+B(*"B,Z('-M:6UE+G!H
M<#HQ.3<*;7-G:60@(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@
M:6UP;W)T960N(@IM<V=S='(@(E,O34E-12"MTZ1(OLS#TJA3IK.S4;;7I$HN
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#8@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,CDY"FUS9VED("(B"B).;R!P97)S;VYA;"!P<FEV
M871E(&ME>2!E>&ES=',@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E
M(&1E8W)Y<'1E9"XB"FUS9W-T<B`BK\JDUJW3I$BH<+%+JO?&7Z9=IKFV;*7S
MM4RJ:[-1N-&Q2RXB"@HC.B!S<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").;R!S
M<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`BJ_>F
M<L#+K&2U>Z:AI;RS7:EW+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@
M(JOWIG*EO[U4(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`BJ]C$LR(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-3<P"FUS9VED(").;R!S=7!P;W)T960@
M24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N(@IM
M<V=S='(@(J?DI*.H[*3DM*FJNB!)34%0(+M[P]*DZ*:A+B(*"B,Z(&%C;"YP
M:'`Z-C<@86-L+G!H<#HY,PIM<V=I9"`B3F\@=7-E<B!S<&5C:69I960N(@IM
M<V=S='(@(JE\I;RK_*EWJ,^ESJK,+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW,#0*;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R("*K
M1*58KG6JS"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*(SH@=&5M<&QA
M=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,"!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS-0HC.B!T96UP;&%T97,O<')E9G,O<W!A
M;7-E;&5C="YI;F,Z,C0@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN
M8SHR-`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Q"FUS9VED(").
M;VYE(@IM<V=S='(@(J2CO^^^W"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(Y-0IM<V=I9"`B3F]R;6%L(@IM<V=S='(@(J1`K^LB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S
M='(@(J6\IU*PHR(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@
M1')A9G0B"FUS9W-T<B`BJT2O\[U:(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-`IM
M<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R("*DHZVKK6XB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS9VED(").;W0@4&5R<V]N
M86PB"FUS9W-T<B`BJT2MTZ1((@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z,3,Y
M(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP="]334E-12YP:'`Z
M,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G<W1R("*U
M3*[$JKJDO;9]JO?&7RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C8W"FUS9VED(").;W0@9&5L971E9"!M97-S86=E<R(*;7-G<W1R("*EO*=2
ML*.V;*7S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I
M9"`B3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R("*DHZVKK6ZV;*7S
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H
M<#HW,0IM<V=I9"`B3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE
M(@IM<V=S='(@(JI@MTXLLV^MT[#*IT"E::_@N]VM;J9HJN&D0*C'KLFVH2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#0*;7-G:60@(DYO=&AI;F<B
M"FUS9W-T<B`BI+"[\J1=I*.PM2(*"B,Z(&%T=&%C:&UE;G0N<&AP.C@Y"FUS
M9VED(").;W1I9FEC871I;VXZ($QI;FME9"!A='1A8VAM96YT(&1O=VYL;V%D
M960B"FUS9W-T<B`BLW&JOCH@PN"F<ZRPNO2G?:JZJOZE\Z1WLU&D5;C\(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B3G5M8F5R(&]F
M(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L
M971I;F<@;6]N=&AL>2XB"FUS9W-T<B`BIG"J1ZA#I.NG4K"CI$"FN"RF:*36
MI.NE]Z1WPN"F<ZRPNO2G?:JZPL*J_J7SL4ZS4:M/IG,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,U.0IM<V=I9"`B3G5M8F5R(&]F(&]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM
M<V=S='(@(J9PJD>H0Z3KIU*PHZ1`IK@LIFBDUJ3KI?>JNL+"L4BE\[/&I?>G
M6+%.LU&K3Z9S+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C4T"FUS9VED(")/2R(*;7-G<W1R("*]5+M[(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K
M97DN:6YC.C0Y"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-#@*
M;7-G:60@(D]2(@IM<V=S='(@(JG.(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@(L+"MFRE
M\R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E
M:6YG('!U<F=E9"XB"FUS9W-T<B`BPL*JNK%(I?.SQJ7WIUBQ3K-1LDVJQ2XB
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C@*;7-G:60@(D]N;'D@9&ES
M<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM
M<V=S='(@(J5UQ>.EW*5=IW2EO,6JJ/JV;*7SJKJK2*7SIU@@/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-SD*;7-G:60@(D]N;'D@
M;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N
M+B(*;7-G<W1R("*F0::YIT"ESJ3HIJ&DI*=!MLBOX+_OOMRD0*W3JTBE\Z=8
M+B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ,"!T96UP;&%T97,O;65N=2YI
M;F,Z,S`*;7-G:60@(D]P96X@1F]?;&1E<B(*;7-G<W1R("*V?;'2JTBE\Z=8
M7VPB"@HC.B!F;VQD97)S+G!H<#HT,#8*;7-G:60@(D]P96YE9"!&;VQD97(B
M"FUS9W-T<B`BJTBE\Z=8I'>V?;'2(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<P,`IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T
M<B`BI5BN=:K,**M$I;*VMRDB"@HC.B!F971C:&UA:6PN<&AP.C0S('1E;7!L
M871E<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9F5T8VAM86EL+FEN8SHV"FUS9VED(")/=&AE<B!-86EL($%C8V]U;G1S
M(@IM<V=S='(@(JCDI4R_[[:U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`BJ.2E3+_OMK4B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,`IM<V=I9"`B3W5T
M8F]U;F0@4V5R=F5R(@IM<V=S='(@(K9LI?.E?KN\IOBJ0;ZY(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ-B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HQ-C0*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`S(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C(X.0IM<V=I9"`B4$=0(@IM<V=S='(@
M(E!'4"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z
M-PIM<V=I9"`B4$=0($5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")01U`@MFRE
M\Z5;L4LB"@HC.B!C;VUP;W-E+G!H<#HS,S4*;7-G:60@(E!'4"!%<G)O<CH@
M(@IM<V=S='(@(E!'4""_^;M^.B`B"@HC.B!C;VUP;W-E+G!H<#HS,30*;7-G
M:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P
M<FEV871E(&ME>2XB"FUS9W-T<B`B4$=0(+_YNWXZK=.D2*APL4NJ]\9?N]VM
M;J:SI$"RU;%+O5@N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM
M<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B4$=0(+_OMK4B"@HC.B!P9W`N
M<&AP.C,P"FUS9VED(")01U`@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R(")0
M1U`@L4N]6+_II$HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G
M:60@(E!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(E!'4""MTZ1(JO?&7[GO
MI;*VMZ:SIG>E_JG*NO2X]+-SM;*JNJ3DM*DN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,3<R"FUS9VED(")01U`@4'5B;&EC($ME>2!497AT(@IM
M<V=S='(@(E!'4""DO;9]JO?&7Z2ZKF4B"@HC.B!P9W`N<&AP.C$T-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<R`H)7,I
M7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B7"(E<R`H)7,I
M7"(@JKI01U`@I+VV?:KWQE^D=[=SO%>GN::H+B(*"B,Z('!G<"YP:'`Z,C0Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S
M7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")01U`@I+VV
M?:KWQE\@7"(E<UPB(*1WIU*PHZ>YIJ@N(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B
M4$=0(*2]MGVJ]\9?P/0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T
M7VQI<W0N:6YC.C@*;7-G:60@(E!'4"!3:6=N($UE<W-A9V4B"FUS9W-T<B`B
M4$=0(+9LI?/#L;.Y(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L
M:7-T+FEN8SHY"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS
M9W-T<B`B4$=0(+9LI?/#L;.Y+[9LI?.E6[%+(@H*(SH@<&=P+G!H<#HQ.3@*
M;7-G:60@(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM
M<V=S='(@(E!'4""H<+%+JO?&7Z1WMW.\5Z>YIJ@N(@H*(SH@<&=P+G!H<#HQ
M-S,*;7-G:60@(E!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB
M"FUS9W-T<B`B4$=0(*2]MGVJ]\9?I'>W<[Q7I[FFJ"XB"@HC.B!T96UP;&%T
M97,O<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4$=0('-U<'!O<G0@:7,@
M9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(E!'4""DY+2IJ,.E
MO*9BI;NH=++.I*2QTJ7.+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(P-PIM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A
M8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B
M92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B4$=0(*3DM*FHPZ6\LU&QTJ7.+*G2
MI4B\QJ;LP[&SN;5,JFNS4<7GP](N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,CDT"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C
M<GEP=&5D+B(*;7-G<W1R(")01U`@I.2TJ:C#I;RQTJ7.++9LI?.U3*IKLU&X
MT;%++B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED("(B"B)0
M1U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N
M("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A
M8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I
M;F<@;W(@96QS92!T:&4@4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O<FL@
M8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)01U`@JKJDY+2IN]VM;JC/I<["V[QU
MM?BUH2AP;W!U<"!W:6YD;W=S*2X@L+*F<*=!JKK"<\3]OKFEV*MEJ,.EO+'2
MI<ZXT[:UPMN\=2(*(K7XM:&E7*_@++W0L=*ESJ6FIU^K:"!01U`@L4ZU3*IK
MIT"ESBXB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B
M4$]0,R(*;7-G<W1R(")03U`S(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,#`*;7-G:60@(E!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS
M9W-T<B`B4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,3$W"FUS9VED(")03U`S(&]V97(@4U-,(@IM
M<V=S='(@(E!/4#,@;W9E<B!34TPB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R
M=&EF:6-A=&4I(@IM<V=S='(@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D
M(&-E<G1I9FEC871E*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,38X"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T
M<B`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R
M(")03U`S+"!N;R!43%,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N
M:6YC.C(P"B,L('!H<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS
M9W-T<B`BLL0@)60@K;:F0"`E9""MMB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX.3$*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE
M<W-A9V4B"FUS9W-T<B`BLL2D0*O*I;RLW;E,JTBE\ZJZK;:ML2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.3(*;7-G:60@(E!A9V4@=VET:"!T:&4@
M3&%S="!5;G-E96X@365S<V%G92(*;7-G<W1R("*SS*OAI$"KRJ6\K-VY3*M(
MI?.JNJVVK;$B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHT
M,PIM<V=I9"`B4&%R="AS*2(*;7-G<W1R("*J_J7S(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$R,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R("*Q
M2[U8(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R.`IM<V=I9"`B4&%S
M<W!H<F%S92`H06=A:6XI(@IM<V=S='(@(K%+O5@HID&]5+M[*2(*"B,Z('-M
M:6UE+G!H<#HR,S$@<&=P+G!H<#HS,#8*;7-G:60@(E!A<W-P:')A<V4@<W5C
M8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R("*Q2[U8I'>FJ*5<J/BX_"XB
M"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA
M=&5S+W!G<"]P87-S<&AR87-E+FEN8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB
M"FUS9W-T<B`BL4N]6#HB"@HC.B!P9W`N<&AP.C$P.`IM<V=I9"`B4&%S<W!H
M<F%S97,@8V%N;F]T(&)E(&5M<'1Y(@IM<V=S='(@(K%+O5BDHZ5IJL6EU2(*
M"B,Z('!G<"YP:'`Z,3$P"FUS9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T
M8V@B"FUS9W-T<B`BL4N]6*2CIVNF6"(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3$*;7-G:60@
M(E!A<W-W;W)D(@IM<V=S='(@(K%+O5@B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BJ?.U;J1*J^&P]:;FNOO%
M0+[>IT`_(@H*(SH@86-L+G!H<#HW-2!A8VPN<&AP.C$P,0IM<V=I9"`B4&5R
M;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C86YN;W0@8F4@8VAA;F=E9"XB"FUS
M9W-T<B`BIKFHSZ7.JLRJNL5VK:VU3*IKQ=RG\RXB"@HC.B!M97-S86=E+G!H
M<#HT.#8@;6%I;&)O>"YP:'`Z-CDP('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,`IM
M<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`BK=.D2"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS
M9W-T<B`BK=.D2+CJL%0B"@HC.B!P9W`N<&AP.C$Q-@IM<V=I9"`B4&5R<V]N
M86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`BK=.D2"!01U`@JO?&7[GOI'>RHZ7-I[FFJ"XB"@HC.B!P9W`N<&AP.C$R
M,PIM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(JW3I$@@4$=0(*KWQE^D=Z=2L*.GN::H+B(*"B,Z('-M
M:6UE+G!H<#HR,#,*;7-G:60@(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T
M97,@3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`BK=.D2"!3+TU)344@OLS#TJA3
MIK.S4;;7I$HZ("`B"@HC.B!S;6EM92YP:'`Z,3(X"FUS9VED(")097)S;VYA
M;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
MK=.D2"!3+TU)344@JO?&7Z1WIU*PHZ>YIJ@N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F
M;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/R(*;7-G<W1R("*W[:9>PM"DSL+@
MM6^V;*7SKLFQ3L.QIE>I\:9BJTBE\Z2ZKF6JNK9]J6RS0C\B"@HC.B!C;VUP
M;W-E+G!H<#HR-3@*;7-G:60@(E!L86EN=&5X="!697)S:6]N(&]F($UE<W-A
M9V4B"FUS9W-T<B`BK\*DY:9RKN:FH:JZMFRE\R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.#<*;7-G:60@(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA
M:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M
M8F5D9&5D("(*(G-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD
M;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U
M:7)E(&$@<&QU9VEN+B(*;7-G<W1R("(B"B*W[;=SMFRE\ZCLN4:NR;RWJ?&M
MM;S6/R"G0:JZPG/$_;ZYN]VM;J3DM*FMM;S6I+JN<L#)KM<N(+6TI&JSH:3`
MIF*W3+-NNU"SP:KW(@HBMO"JNL)SQ/V^N;.CJ%.FL[#=PT0L(*;]J.2E3*=`
MMWZH=++.JKK"<\3]OKFE::_@N]VM;J9WN,NTH:7S*'!L=6=I;BDN(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`BO="_Z:1*
MI$"MT[=SJTBE\Z=8JKJF5[K9.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3`R('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3`T"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE
M=R!F;VQD97(Z(@IM<V=S='(@(KW0O^FD2K=SJTBE\Z=8JKJF5[K9.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,W"FUS9VED(")0
M;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.B(*;7-G<W1R("*]T+_II$JW<ZJZ
MIE>ZV3HB"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H
M<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@
M;F5E9"!T;R`B"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@
M<V5S<VEO;BXB"FUS9W-T<B`BO="_Z:1*IT&JNB!01U`@K=.D2*KWQE^Q2[U8
M+B5SM6ZD2K3!MJ&SH[O=O^FD2J1`IK@N(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L
M96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I
M=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES
M('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`BO="_
MZ:1*IT&JNB!3+TU)344@K=.D2*KWQE^Q2[U8+JA#IKBU;J1*M,&VH2`E<R"S
MH[O=O^FD2J1`IK@N(@H*(SH@<F5C;VUP;W-E+G!H<#HY-@IM<V=I9"`B(@HB
M4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG('EO=7(@
M;65S<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@
M>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@
M>6]U('=I;&P@:&%V92!T;R`B"B)L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN
M('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R
M;VT@(@HB:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE
M(&9O<B!A;GD@:6YC;VYV96YI96YC92XB"FUS9W-T<B`B(@HBO="MJ[=SM6ZD
M2J5(Q'[$\KUSO^BG0:JZMFRE\RX@IG"J1\)SQ/V^N:C#I;RHSZ7.(&-O;VMI
M97,@IM.E0J=!K$^F8K=SJKJU^+6AI*0B"B*]<[_HMFRE\RRHNKW0IT&ELK:W
MK6ZF0:WLI?VU;J1*JKJU^+6AM66ML:9!I$"FN+5NI$HNI*>ITJ5(LV^[\K"U
MK$^LL*1&P=>G2\!B(@HBJ\C"ZJEWIT&JNK=\M,'#T:=/N+F]6"AS97-S:6]N
M($E$*2X@I*.K2Z2GLT+!V;W0J*.]S"XB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C<Q"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W
M;W)D+B(*;7-G<W1R("*]T+_II$JG0:JZL4N]6"XB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C8W"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE+B(*;7-G<W1R("*]T+_II$JG0:JZJ,^ESJK,IE>ZV2XB"@HC
M.B!C;VUP;W-E+G!H<#HQ,#8@;&EB+TE-4"YP:'`Z-#<P"FUS9VED(")0;&5A
M<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N(@IM
M<V=S='(@(KW0K:NW<[_II$JEO[U4JKJY<;9LIF&G?2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L
M96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB
M"FUS9W-T<B`BO="_[[[<I$"MTZM(I?.G6"(*"B,Z('1E;7!L871E<R]S96%R
M8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@870@
M;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(KW0O^^^W*;<
MI-:D0*W3JTBE\Z=8J-.W:K1-(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ,@IM<V=I9"`B4&QE87-E('-E;&5C="!O;FQY(&]N92!F
M;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+B(*;7-G<W1R("*]T+_OOMRVR*1`
MK=.K2*7SIU@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z
M-S,*;7-G:60@(E!L96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O
M('1H92!R:6=H=#HB"FUS9W-T<B`BO="D5:G4O^^^W*G.O7._Z*5KP^2JNKCJ
MKL:E2,%RM/HZ(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*;7-G:60@
M(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B4&]W97)E9"!B>2!(;W)D92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,30*;7-G:60@(E!R96-E9&4@
M>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B
MIF*G0:JZP[&F5ZMEI5ND2B`H)RTM("<I/R(*"B,Z('-M:6UE+G!H<#HR,S<@
M<&=P+G!H<#HR-3,@9FEL=&5R<')E9G,N<&AP.C0P"FUS9VED(")0<F5F97)E
M;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`BO^^VM:1WI[FF
MJ*?SMW,N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC
M.C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`BN7?$_2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G:60@(E!R979I
M;W5S($UE<W-A9V4B"FUS9W-T<B`BI%>D0*O*MFRE\R(*"B,Z(&UA:6QB;W@N
M<&AP.C,R.0IM<V=I9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R("*D5Z1`K;8B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*
M;7-G:60@(E!R:6YT(@IM<V=S='(@(J3-M;VF0Z9,(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*;7-G:60@(E!R:6]R:71Y(@IM<V=S
M='(@(L!UI?TB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M-S8*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@(JAPL4NJ
M]\9?L4N]6"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3D*;7-G:60@
M(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F
M875L="!T;R!.3R(*;7-G<W1R("*THZ7<I]HLJ$.D0*O*I5VG=*K^I5O`R:[7
MJKJK2*7SL4BE6*OA.R"Y=[-=K+"DHZUN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4U.`IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H
M;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4R(*;7-G<W1R("*THZ7<I]HL
MJ$.D0*O*I5VG=*K^I5O`R:[7JKJK2*7SL4BE6*OA.R"Y=[-=K+"M;B(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O
M=&]C;VPZ(@IM<V=S='(@(K-QJTBH\ZEW.B(*"B,Z(&QI8B]#<GEP="]01U`N
M<&AP.C0S,`IM<V=I9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H
M87,@8F5E;B!D:7-A8FQE9"XB"FUS9W-T<B`BI+VV?:KWQE^F^*I!OKFJNJ3D
MM*FD=[-1J/JN^"XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC.C<*
M;7-G:60@(E!U<E]G92!$96QE=&5D(@IM<V=S='(@(K)-L*.D=Z=2L*-?9R(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I9"`B4'5R9V4@
M1&5L971E9"(*;7-G<W1R("*R3;"CI'>G4K"C(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,C0*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*
M;7-G<W1R("*R3:K%JTBE\Z=8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G<W1R("*I
M5:>CO6.F:*1;LDVPHZ1`IK@Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0P-0IM<V=I9"`B4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L
M9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RXB"FUS9W-T<B`BJ$.FN+[C
MLGJI5:>CO6.NR2RR3;"CIFBDUJ31O,:E2*MEJKJV;*7S+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(E!U<F=E(&]L9"!M97-S86=E
M<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R("*R3;"CJ56GH[UCI*2J
MNL+"MFRE\S\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S
M:"YP:'`Z-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S
M86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`BIMNI5:>CO6.DI+)-
ML*,@)60@J\JV;*7S+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E
M7W1R87-H+G!H<#HV,PIM<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4
M<F%S:"!F;VQD97(N(@IM<V=S='(@(J;;J56GH[UCI*2R3;"C(#$@J\JV;*7S
M+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E
M+C)F)24I(@IM<V=S='(@(KK/NM"JQ;:A.B`E+C)F34(@+R`E+C)F34(@("@E
M+C)F)24I(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z("4N,F9-0B`O($Y/($Q)
M34E4(@IM<V=S='(@(KK/NM"JQ;:A.B`@)2XR9DU"("\@I;RS7:VM(@H*(SH@
M=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")1=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM<V=S='(@(KK/NM"JQ;:A
M.B"EO+-=K:TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`P"B,L('!H
M<"UF;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(J3>K7H@)68Z
M(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3`*;7-G:60@(E)E8V5I=F5D($]N(@IM
M<V=S='(@(J9BIJRE\Z3IM,$B"@HC.B!L:6(O4V5A<F-H+G!H<#HU.`IM<V=I
M9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`BL7&FK*7SI.FTP:OA(@H*(SH@
M;&EB+U-E87)C:"YP:'`Z-30*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM<V=S
M='(@(JCLIJRE\Z3IM,&K92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(L+@
MIWV[O+!E7W0B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(L+@IWV[O+!E(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,`IM<V=I9"`B
M4F5D:7)E8W0@365S<V%G92(*;7-G<W1R("+"X*=]N[RP92(*"B,Z(&-O;7!O
M<V4N<&AP.C@R-0IM<V=I9"`B4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S
M='(@(L+@IWV[O+!EIKFV;*7S(@H*(SH@8V]M<&]S92YP:'`Z.#<X"FUS9VED
M(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(L+@IWV[O+!EI:*QT2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<R"FUS9VED(")2969R97-H
M($9O;&1E<B!6:65W<SHB"FUS9W-T<B`BI_.W<ZM(I?.G6,#+M?@Z(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.2!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C0*;7-G:60@(E)E;&]A9"(*;7-G<W1R("*MJ[=SQ:JH
M^B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C,*;7-G:60@(E)E
M;&]A9"!6:65W(@IM<V=S='(@(J?SMW/`R[7X(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W
M"FUS9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("*P3Z;MLV^MT[=\Q+.XZK!4+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-C<*;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS
M9W-T<B`BL$^^T+/,JO&JNL7CI=RDZ*:A(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C(W"FUS9VED(")296UO=&4@36%I;&)O>#HB"FUS
M9W-T<B`BN[>ZW;9LO6,Z(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C0Q"FUS9VED(")296UO=F4@1FEE;&0@1G)O;2!396%R8V@B"FUS9W-T
M<B`BL7&W:K1-I*2ROK"CQ.:F["(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R
M8V5S96QE8W0N:6YC.C,P-0IM<V=I9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R
M("*ROK"CLW&P5+_](@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z.`IM<V=I9"`B4F5N86UE($9O;&1E<BAS*2(*;7-G<W1R("*G\Z?OIE>Z
MV2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E;F%M
M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS
M9W-T<B`BJ?.H0Z3KJNRG\Z?OL4BE\[/&I?>G6*JZIE>ZV3\B"@HC.B!L:6(O
M1F]L9&5R+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@
M7"(E<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60B"FUS9W-T<B`BL4ZF5[K9(%PB)7-<(B"G\Z97K+`@7"(E<UPB
M(*6BL=$NIOBJ0;ZYIE[`LR(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS9W-T
M<B`BIE["T+6YL%&]U[ASLM5?>2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T<B`B
MJ/JE3JRP.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHX"FUS9VED(")297!L>2(*;7-G<W1R("*F7L+0(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C,Q,B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#$P"FUS9VED(")297!L>2!396YT+B(*;7-G<W1R("*F7L+0I'>VQ[!E
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S
M"FUS9VED(")297!L>2!T;R!!;&PB"FUS9W-T<B`BIE["T*G2IK,B"@HC.B!C
M;VUP;W-E+G!H<#HW-CD*;7-G:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B
MIE["T*G2IK,Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C$P"FUS9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@(J9>PM"U
MN;!1O=>X<[+5(@H*(SH@8V]M<&]S92YP:'`Z-S<Q"FUS9VED(")297!L>2!T
M;R!,:7-T.B(*;7-G<W1R("*F7L+0M;FP4;W7N'.RU3HB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY
M('1O(%]!;&PB"FUS9W-T<B`BIE["T*G2IK-?02(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU,S`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S
M.0HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30Y"FUS9VED(")297!L
M>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R("*E2*6\I.2T
MJ:JZMFRE\Z9>PM`B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,W
M"FUS9VED(")297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H
M<RXB"FUS9W-T<B`BIE["T*6\J-.D1ZW3I.NJNB!F<F5E+V)U<WD@N.JP5"XB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,V"FUS9VED(")297!L
M>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(J5(J=*]T*A$JKH@9G)E92]B=7-Y(+CJL%2F7L+0+B(*"B,Z(&UE<W-A
M9V4N<&AP.C(V-PIM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`BIE["T*CL(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C0R,`IM<V=I9"`B4F5P;'DM5&\Z("(*;7-G
M<W1R("*F7L+0J.PZ("(*"B,Z(&-O;7!O<V4N<&AP.C<V-PIM<V=I9"`B4F5P
M;'DZ(@IM<V=S='(@(J9>PM`Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E;G0B"FUS9W-T<B`BLV^D
MHZQ/O'.G:;9LI?,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*
M;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(K-OK$^\<Z=IMFRE\R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X,PIM<V=I9"`B
M4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`BO="FK*7SI$BVQ[!E
MQ:JH^J9>L?A?4B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S,*;7-G
M:60@(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T<B`BO="FK*7SI$BV
MQ[!EQ:JH^J9>L?@B"@HC.B!M86EL8F]X+G!H<#HQ.#<*;7-G:60@(E)E<75E
M<W1E9"!M97-S86=E(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLMFRE\RXB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDR"FUS9VED(")297%U
M:7)E9"!087)T:6-I<&%N="(*;7-G<W1R("*ELK:WK6ZFLZ58KG6JS"(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,30S('1E;7!L871E<R]S96%R
M8V@O:&5A9&5R+FEN8SHR-@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R
M"FUS9VED(")297-E="(*;7-G<W1R("*MJ[-=(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$Q-@IM<V=I9"`B4F5S<&]N9&5N="!3=&%T=7,@57!D
M871E9"XB"FUS9W-T<B`BIE[`LZJLND&D=Z?SMW,B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*
M;7-G<W1R("+$?L3RO7._Z"(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G:60@
M(E)E<W5M92!Y;W5R('-E<W-I;VXB"FUS9W-T<B`BK:NW<[5NI$HB"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#0*;7-G:60@(E)E='5R
M;B!T;R!<(DUE<W-A9V4@0V]M<&]S:71I;VY<(B(*;7-G<W1R("*F7EPBMFRE
M\[QGIT"_[[:U7"(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S
M96QE8W0N:6YC.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV
M.0HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS
M,@IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`BIEZH[*5^
MLZ&V;*7S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C8P('1E
M;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,C(*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHQ,#$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV
M92YI;F,Z,34*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T.2!T96UP;&%T
M97,O<&=P+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$V,R!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3<U"FUS9VED(")2971U
M<FX@=&\@3W!T:6]N<R(*;7-G<W1R("*F7JCLO^^VM2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW,#8*;7-G:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I
M;&)O>"!L:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI
M;F<@82!M97-S86=E/R(*;7-G<W1R("*W[:=2L*,L(+=HLKZISKW&NW.V;*7S
MKLDL(*9>J.RV;*7SP,NEW*9#(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8X,PIM<V=I9"`B4F]L92(*;7-G<W1R("*HI*;B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C0*;7-G
M:60@(E,O34E-12(*;7-G<W1R(")3+TU)344B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$R"FUS9VED(")3+TU)344@16YC<GEP
M="!-97-S86=E(@IM<V=S='(@(E,O34E-12"V;*7SI5NQ2R(*"B,Z(&-O;7!O
M<V4N<&AP.C,W,0IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B4R]-
M24U%(+_YNWXZ("(*"B,Z(&-O;7!O<V4N<&AP.C,U,`IM<V=I9"`B4R]-24U%
M($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@
M:V5Y+B(*;7-G<W1R(")3+TU)344@O_F[?CJMTZ1(J'"Q2ZKWQE^[W:UNIK.D
M0++5L4N]6"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"FUS9VED
M(")3+TU)344@3W!T:6]N<R(*;7-G<W1R(")3+TU)344@O^^VM2(*"B,Z('-M
M:6UE+G!H<#HT-@IM<V=I9"`B4R]-24U%(%!A<W-P:')A<V4@26YP=70B"FUS
M9W-T<B`B4R]-24U%(+%+O5B_Z:1*(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHU-`IM<V=I9"`B4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P
M<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B4R]-24U%(*W3I$BJ]\9?N>^ELK:WIK.F=Z7^J<JZ]+CTLW.ULJJZI.2T
MJ2XB"@HC.B!S;6EM92YP:'`Z,3,V"B,L('!H<"UF;W)M870*;7-G:60@(E,O
M34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+B(*;7-G<W1R(")<(B5S7"*JNB!3+TU)344@I+VV?:KWQE^D=Z=2
ML*.GN::H+B(*"B,Z('-M:6UE+G!H<#HQ-3@*;7-G:60@(E,O34E-12!0=6)L
M:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B4R]-24U%(*2]
MMGVJ]\9?I'>W<[Q7I[FFJ"XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$P"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B
M4R]-24U%(*2]MGVJ]\9?P/0B"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")3
M+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D
M960N(@IM<V=S='(@(E,O34E-12"DO;9]+ZAPL4NJ]\9?N>\LI'>W<[Q7I[FF
MJ"XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S
M"FUS9VED(")3+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(E,O34E-12"V
M;*7SP[&SN2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI
M;F,Z,30*;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G
M<W1R(")3+TU)344@MFRE\\.QL[DOMFRE\Z5;L4LB"@HC.B!T96UP;&%T97,O
M<VUI;64O;F]T86-T:79E+FEN8SHT"FUS9VED(")3+TU)344@<W5P<&]R="!I
M<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B4R]-24U%(*3D
MM*FHPZ6\IF*ENZATLLZDI+'2I<XN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HR-#$*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!C
M=7)R96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@
M8F4@(@HB9&5C<GEP=&5D+B(*;7-G<W1R(")3+TU)344@I.2TJ:C#I;RQTJ7.
M++9LI?.U3*IKLU&XT;%++B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,3<S"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE
M9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S<V%G92!C86YN
M;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R(")3+TU)344@I.2TJ:C#I;RQ
MTJ7.+*Q)I4B\QJ;LP[&SN:JZJTBE\[5,JFO%XZ7<+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R
M="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@
M=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R(")3+TU)344@I.2T
MJ:C#I;RQTJ7.++S&INS#L;.YM4RJ:[-1Q>?#TBXB"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(')E
M<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O
M=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN
M9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E("(*
M(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN
M(@IM<V=S='(@(B(*(E,O34E-12"JNJ3DM*F[W:UNJ,^ESL+;O'6U^+6A*'!O
M<'5P('=I;F1O=W,I+B"PLJ9PIT&JNL)SQ/V^N:78JV6HPZ6\L=*ESKC3MK4B
M"B+"V[QUM?BUH:5<K^`LO="QTJ7.I::G7ZMH(%,O34E-12"Q3K5,JFNG0*7.
M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`T"FUS9VED(")3
M3510(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(U-0IM<V=I9"`B4U]U8FIE8W0B"FUS9W-T<B`BI42FKE]U(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S8S"FUS9VED(")385]V
M92!A(&-O<'D@:6X@(@IM<V=S='(@(K%(I?.SQJ7WJ?-?=B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%?
M=F4@87,B"FUS9W-T<B`BI72F<[=SP,E?=B(*"B,Z('-E87)C:"YP:'`Z,S$V
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-PIM<V=I9"`B4V%V
M92(*;7-G<W1R("+`>*9S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-3,S"FUS9VED(")3879E($%T=&%C:&UE;G1S('=I=&@@;65S<V%G
M92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R("*J_J7SK$^G7\!(M=NQ
M2*7SI$"P7[/&I?<@/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R-PIM<V=I
M9"`B4V%V92!$<F%F="(*;7-G<W1R("*F<ZRPK_.]6B(*"B,Z('-A=F5I;6%G
M92YP:'`Z-#(*;7-G:60@(E-A=F4@26UA9V4B"FUS9W-T<B`BP'BF<[G/I/DB
M"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$Q"FUS9VED(")3879E($EM
M86=E(&EN($=A;&QE<GDB"FUS9W-T<B`BP'BF<ZCLP\"T6:2D(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4Y('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,3`P"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC
M.C$S('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-#@*(SH@=&5M<&QA=&5S+W!G
M<"]N;W1A8W1I=F4N:6YC.C$S"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T
M<B`BP'BF<[_OMK4B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z-#`*;7-G:60@(E-A=F4@4W1A=&EO;F5R>2(*;7-G<W1R("+`>*9SJTBZ
MX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R-PIM<V=I9"`B4V%V92!?1')A
M9G0B"FUS9W-T<B`BIG.LL*_SO5I?1"(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%V92!A<R(*;7-G<W1R
M("*E=*9SMW/`R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G
M:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`BL4[`>*9SJKJO
M\[U:O-"P3Z:HI;RLW;E,+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#8P"FUS9VED(")3879E(')E8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T
M:&4@9&5F875L="!A9&1R97-S(&)O;VL_(@IM<V=S='(@(K%(I[FK2*7SJ^$L
MIMNPRK%.N-.Q2*7SI*2ITJ:SIJRE\[GOMDBJNJ9AIWTLP'BF<ZCLN7>S7:JZ
MLW&P5+_]I*0@/R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(W
M"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/R(*;7-G
M<W1R("+`>*9SMVJT3:M(I?.FJ*1`K=.UZL#`JTBE\Z=8(#\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED(")3879E('-E;G0@;6%I;#\B
M"FUS9W-T<B`BP'BF<[%(I?,_(@H*(SH@8V]M<&]S92YP:'`Z,3(U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`BP'BF<Z_S
MO5JEHK'1+B"F^*I!OKFF7L"S.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI
M;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z-#4*;7-G:60@
M(E-E87)C:"(*;7-G<W1R("*W:K1-(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S(@IM<V=S='(@(K=JM$T@
M)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(P"FUS9VED(")396%R
M8V@@3W!T:6]N<R(*;7-G<W1R("*W:K1-O^^VM2(*"B,Z('-E87)C:"YP:'`Z
M,C8U"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R("*W:K1-M;*J1R(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,30@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHS,0IM<V=I9"`B4V5E;B(*;7-G<W1R("*L
MW;E,(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHY"FUS9VED
M(")396QE8W0B"FUS9W-T<B`BO^^^W"(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N
M="(*;7-G<W1R("*_[[[<I72D0*W3L6*XN2(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R
M("*_[[[<I$"MTZ3IM,$B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z,3`*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(K_OOMRD0*W3
MQ.:F["(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PIM
M<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`BO^^^W*1`K=.K
M2+K@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E
M;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R
M8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`BO^^^W+-QL%2__:5(MVJT
M3:3.MW.\5Z9AIWTN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX
M.`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("*_[[[<J=*FLR(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L
M96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E
M<W-E<RXB"FUS9W-T<B`BM^VP]:;FJ6VF5\%RM/JNR:%!O^^^W*G2IK/$YJ;L
MI4BG4;=JM$TN(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E
M;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@
M(K_OOMRD0*W3L6*XN2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(J2CO^^^W"(*"B,Z('1E
M;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS9VED(")396QE
M8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@
M(K_OOMS#P+19I4C`>*9SN<^D^2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S
M97)V97(@='EP92(*;7-G<W1R("*_[[[<IOBJ0;ZYJKJKK+I!(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"FUS9VED(")396QE
M8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G<W1R("*D=[_OOMRJNK-QL%2__3HB
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(E-E;F0@2V5Y
M('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`BML>P9:KWQE^FW*2]MGVJ
M]\9?IOBJ0;ZY(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PIM
M<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T<B`BML>P9;/,
MMW.JNKCJL%0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV
M-R!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C4*;7-G:60@(E-E
M;F0@365S<V%G92(*;7-G<W1R("*VQ[!EMFRE\R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV.3$*;7-G:60@(E-E;F0@<F5A9"!R96-E:7!T('=H96X@
M<F5Q=65S=&5D(&)Y('1H92!S96YD97(_(@IM<V=S='(@(K?ML4BE\ZK,K6ZH
M1+;'L&6F7K'XKLG%XZ7<M*.EW"`_(@H*(SH@9F]L9&5R<RYP:'`Z,S<V"FUS
M9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(K%(I?.SQJ7WIU@B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,X"FUS9VED
M(")396YT(&UA:6P@9F]L9&5R.B(*;7-G<W1R("*Q2*7SL\:E]Z=8.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,S('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,30U"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,34R"FUS9VED(")397)V97(B"FUS9W-T<B`BIOBJ0;ZY(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(S"FUS9VED(")397)V97(@86YD($9O;&1E<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R("*F^*I!OKFDSJM(I?.G6+CJL%0B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E<G9E
M<CHB"FUS9W-T<B`BIOBJ0;ZY.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,`IM<V=I9"`B4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@
M=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+B(*;7-G<W1R("*S
M7:EWJ$.W[;O5I%6W:+*^J4VG4K"CMFRE\Z[)JKJPOJ9N+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET
M>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(KUS
MO&>W<[9LI?.NR2RL3Z=?I+FS7+-=J7>HY,!UI?T@/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G<W1R
M("*DP*C)JTBE\Z=8(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C@V"FUS
M9VED(")3:&%R92!M86EL(&9O;&1E<G,B"FUS9W-T<B`BI,"HR:M(I?.G6"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U
M<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`BMGVI
M\:=!JKJK2*7SIUC%_:CDI4RD2*5II4BHSZ7.+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-3<*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@
M;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_
M($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H
M;V]S92XB"FUS9W-T<B`B(@HBIG"J1ZM(I?.DNJYEIW2FLZ1JO6>T5*JZI-ZM
M>J3EIG(LM^VV?;'2N-.K2*7SKLFY=[-=K+#%XZ7<J<ZJS,'TPL.DWJUZ(#\B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM<V=I9"`B4VAO=6QD('1H
M92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@
M4$=0(&1A=&$_(@IM<V=S='(@(JQ/IU^QO;K+MFRE\Z2ZKF4H=&5X="]P;&%I
M;BFDI*JZ(%!'4""XZJ[&/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D
M(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R("*W[;=SMFRE\Z9SI$JO
M\[U:IZBKX:Q/IU_#]K.LO7.\9[9LI?.U^+6A/R(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME
M>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_
M(@IM<V=S='(@(JA#J\JE?K%(MFRE\Z>AJOZD5R!01U`@I+VV?:KWQE\_(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@IM<V=I9"`B4VAO=R!!
M;&P@1F]L9&5R<R(*;7-G<W1R("+%XZ7<J=*FLZM(I?.G6"(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VAE861E<G,N:6YC.C8W"FUS9VED(")3:&]W($%L;"!(
M96%D97)S(@IM<V=S='(@(L7CI=RV;*7SJNW`62(*"B,Z(&UA:6QB;W@N<&AP
M.C,T-PIM<V=I9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(L7CI=RD=Z=2L*,B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B
M4VAO=R!,:6UI=&5D($AE861E<G,B"FUS9W-T<B`BP?3"P[9LI?.J[<!9(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-S`*;7-G:60@(E-H
M;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N(@IM<V=S='(@(L7CI=RP4;W7
MN'.RU;CJL%0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"FUS
M9VED(")3:&]W($]N;'D@4W5B<V-R:6)E9"!&;VQD97)S(@IM<V=S='(@(J5U
MQ>.EW*1WK7&^7*JZJTBE\Z=8(@H*(SH@9F]L9&5R<RYP:'`Z,C<W"FUS9VED
M(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R("+%XZ7<I;RM<;Y<(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y-@IM<V=I9"`B4VAO=R!A;B!I8V]N
M('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A
M9V5S/R(*;7-G<W1R("*L3Z=?IF*V;*7SI*3%XZ7<I$"MTZ7.J-.E:+"CJOZE
M\ZJZN<^EW#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3DP"FUS9VED
M(")3:&]W(&QE9V5N9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R("*F
M8K9LO6/`R[7XI*3%XZ7<IE7#_K9LI?.YSZ7<JKJ[H:GZ/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,C@*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R
M('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R("*E=::SI;RLW;E,JKJV
M;*7SI'ZY=\3]Q>.EW#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,V
M"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R("*W
M[;?&N:NK_+S0LKZFW*5$IJ[$YJ;LKLFY=\3]Q>.EW#\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#8U"FUS9VED(")3:&]W('1H92!&971C:"!-86EL
M(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(J9BI5ROX*KMI*3%XZ7<
M(">E?K.AMFRE\R<@IKFD0+-SM;(_(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT
M;6PN<&AP.CDX"FUS9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`BQ>.E
MW+G/I/DB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-30*;7-G
M:60@(E-H;W<@=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/R(*;7-G
M<W1R("*F8J5<K^"J[:2DQ>.EW+E,PF^^N;G/IJ$_(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C,Q"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M
M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(L7CI=RK2*7SIUBDI*JZJTBE\\%@
MO,8@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-30*;7-G:60@(E-H
M;W=N(@IM<V=S='(@(L7CI=PB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C0R"FUS9VED(")3:5]Z92(*;7-G<W1R("*D:J1P
M7WHB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$W"FUS9VED
M(")3:6=N960B"FUS9W-T<B`BI'?#L;.Y(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O871T86-H;65N=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS9W-T<B`BI&JD
M<"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,3$*;7-G:60@(E-O<G0@8GD@07)R:79A;"(*;7-G<W1R("*H[+E&I.FTP;'&
MID,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C$V"FUS9VED(")3;W)T(&)Y($1A=&4B"FUS9W-T<B`BI.FTP;'&ID,B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(V"FUS
M9VED(")3;W)T(&)Y($9R;VT@061D<F5S<R(*;7-G<W1R("*Q2*7SI$BF8:=]
ML<:F0R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z-#$*;7-G:60@(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(K9L
MI?.D:J1PL<:F0R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,S8*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R("*E
M1*:NL<:F0R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,S$*;7-G:60@(E-O<G0@8GD@5&AR96%D(@IM<V=S='(@(L/VP7"Q
MQJ9#(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHR,0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S(@IM<V=S='(@(J:LI?.D
M2*9AIWVQQJ9#(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC
M.C(S"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`BO'.G:;UC.B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T-@IM<V=I9"`B4W!E
M8VEA;"!#:&%R86-T97)S(@IM<V=S='(@(J]3KNVF<J2X(@H*(SH@<V5A<F-H
M+G!H<#HQ,S,*;7-G:60@(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;FYO
M="!B92!E9&ET960N(@IM<V=S='(@(K7JP,"K2*7SIUC$W:]3KNVESK-^M4RJ
M:[-1O7._Z"XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M-#,*;7-G:60@(E-P96QL($-H96-K(@IM<V=S='(@(JOWO&?`RZQD(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")3<&5L
M;"!#:&5C:V5R(@IM<V=S='(@(JOWIG+`RZQD(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C0X('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHU-@IM<V=I9"`B4W!E;&P@8VAE8VL@8V]M<&QE=&4B"FUS9W-T
M<B`BJ_>F<L#+K&2GN::H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W
M,0IM<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L
M;"!C:&5C:VEN9RXB"FUS9W-T<B`BL/6FYJOWIG+`RZQDKLFH0Z1`K;:ITL7C
MI=RJNK_YNWZ\QBXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`W
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#D*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8T,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C0T
M"FUS9VED(")3=&%R="(*;7-G<W1R("*QTK#*(@H*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S$Q"FUS9VED(")3=&%T:6]N97)Y(@IM<V=S='(@(JM(NN`B"@HC
M.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T
M871I;VYE<GD@;F%M93HB"FUS9W-T<B`BJTBZX*97NMDZ(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y
M('1Y<&4Z(@IM<V=S='(@(JM(NN"KK+I!.B(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T
M<B`BJTBZX#HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@S"FUS
M9VED(")3=&%T=7,B"FUS9W-T<B`BJJRZ02(*"B,Z(&QI8B]-24U%+T-O;G1E
M;G1S+G!H<#HR,C(*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T<B`B
MI6BPHZK^I?,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(P"FUS9VED
M(")3=')I<"!L:6YE8G)E86MS/R(*;7-G<W1R("*E:+"CPE^FYC\B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,W"FUS9VED
M(")3=6)?:F5C="(*;7-G<W1R("*E1*:N7VHB"@HC.B!M97-S86=E+G!H<#HR
M-C@@=&AR96%D+G!H<#HQ-#D@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E
M+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*
M;7-G<W1R("*E1*:N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP.`IM
M<V=I9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R("*E1*:NQ.:F["(*"B,Z('-E
M87)C:"YP:'`Z,S$X('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN
M8SHQ.`HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C`@=&5M
M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,0IM<V=I9"`B4W5B;6ET(@IM
M<V=S='(@(K2CI>8B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R("*M
M<;Y<(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#4@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,SDS"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C@W"FUS9VED(")3=6-C97-S(@IM<V=S='(@(J:HI5PB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E
M<W1I;VYS(@IM<V=S='(@(JO8Q+,B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C4Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C$*;7-G:60@
M(E-U;6UA<GDB"FUS9W-T<B`BNDNM;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,Y-"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS.3<*;7-G:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T
M<B`BI,&TJ[9LI?.]<[QGI.BFH2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,Y.`IM<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I
M;VXB"FUS9W-T<B`BI,&TJZRPNO2MMKUSO&>\TJ:A(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,SDX"FUS9VED(")3=VET8V@@=&\@<&QA
M:6X@=&5X="!C;VUP;W-I=&EO;B(*;7-G<W1R("*DP;2KK+"OPJ3EIG*]<[QG
MO-*FH2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Q,PIM
M<V=I9"`B5&5?>'0B"FUS9W-T<B`BI+JN95]X(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C(W,`IM<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B
MO,BNR3H@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-@IM<V=I
M9"`B5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`BO,BNR;&U
MJ/R]T*A$(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U-`IM<V=I
M9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`BO,BNR;&UJ/PB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O9B!397)V:6-E(&9I;&4@;F]T
M('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G<W1R("*J0;#(MK6EV,#)J,.E
MO*9B(&-O;F8N<&AP(*2DJ_RI=R(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R("*DNJYE(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,@IM<V=I9"`B5&AE($9R;VTZ(&-O
M;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.B(*;7-G<W1R
M("*W[<))O^^V;+UCP,NU^*2DJKJQ2*7SI$C$YJ;LKLDLP+.XTSHB"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C4S,PIM<V=I9"`B(@HB5&AE($E-05`@<V5R
M=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A
M=&EO;B!M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DE-05`@IOBJ0;ZYI*.D
MY+2IJ=*K_*EWJKK%Y\/2I.BFH2X@O=#!<+6XIT&JNJATLLZZWK)ZK?LN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0IM<V=I9"`B
M5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(@IM<V=S='(@(K/!JO>V\+CJ
MM[VDP*3D(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E
M(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(K/!JO>V\+CJ
MM[VDP*3DI6FS4:15N/PE<R(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`BLV^MT[%BN+D@7"(E<UPB(*1WLU&G4K"C
M+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HW-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S
M='(@(K-OK=.Q8KBY(%PB)7-<(B"D=[-1P'BF<RXB"@HC.B!A='1A8VAM96YT
M+G!H<#HT,PIM<V=I9"`B5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N9"XB
M"FUS9W-T<B`BI^2DHZCLJOZE6\#)KM<N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<Q"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A
M;&ED(@IM<V=S='(@(J2CI;^]5*JZIN:HQK[DN.JNQB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V]M<&]S95]W:6XN:G,Z,S<*;7-G:60@(B(*
M(E1H92!C;VUP;W-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@
M>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W
M:6YD;W=S/R(*;7-G<W1R("*U3*IKMGVQTK9LI?.]<[QGM?BUH2X@IK.E::_@
MIT&D=[%.PG/$_;ZYJKK"V[QUM?BUH:5<K^#"ZJEW(#\B"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N
M=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B
ML\&J][;PP,FNUZJZI+JN9:9PI%4N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C@W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!C=7)R96YT(&9O;&1E<BAS*2!<(B5S7"(@=VEL;"!B
M92!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`BI=BK9:JZLV^HQZM(I?.G
M6"!<(B5S7"(@L4ZS4:?SIE>LL"!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U
M<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@
M<F5T<FEE=F5D(@IM<V=S='(@(K5,JFO%JJCZJ=*FL\/VJ?.S;ZW3JTBE\Z=8
MJKJF<ZCZQ7:MK;-=J7<B"@HC.B!C;VUP;W-E+G!H<#HQ,C8P"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@
M7"(E<UPB(&9O;&1E<BXB"FUS9W-T<B`BIKFKRJ_SO5JD=\!XIG.H[*M(I?.G
M6%PB)7-<(J2D+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#`*
M;7-G:60@(E1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BXB
M"FUS9W-T<B`BIKFHQJ7SI'>FJ*5<JKJ\5Z5;J.RG0:JZIN:HQK[DI*0B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I96QD(%PB)7-<(B!C86XG="!B92!E>'!A;F1E9"XB
M"FUS9W-T<B`BQ.:F["!<(B5S7"(@M4RJ:[-1P7*T^BXB"@HC.B!L:6(O1F]L
M9&5R+G!H<#HS,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<
M(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`BJTBE\Z=87"(E<UPBI'>F
M<Z9B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS(&EL;&5G86P@8VAA
M<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E("(*(G!R;V)L96US
M+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(JM(I?.G6%PB)7-<(J97NMFG=*:SI*.F6*IKJKJF<J2X++-OL4ZS
M>::HI$"HQ[#=PT0NO="S<[6XIT&JNJATLLZZWK)ZK?LN(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E
M9"!T;R!I="XB"FUS9W-T<B`BJTBE\Z=87"(E<UPBI'>KV*>TIOVI?*6\K7&^
M7"XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E
M(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`BJTBE\Z=87"(E
M<UPBI'>G4K"CIOVI?*6\J/JN^*UQOEPN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,S0Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A
M<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*
M;7-G<W1R("*K2*7SIUA<(B5S7"*HPZ6\J]BEWRZF^*I!OKFF7L"S(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M;VQD97(@7"(E<UPB('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9"(*;7-G<W1R("*K2*7SIUA<(B5S7"*HPZ6\IU*PHRZF
M^*I!OKFF7L"S(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@
M8W)E871E9"XB"FUS9W-T<B`BJTBE\Z=8("!<(B5S7"(@I'>FJ*5<J]BEWRXB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*
M;7-G<W1R("*K2*7SIU@@(%PB)7-<(B"D=Z:HI5RG4K"C+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C0V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R
M(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@7"(E<UPB+B(*
M;7-G<W1R("*K2*7SIU@@(%PB)7-<(B"D=Z:HI5RS4:?SIE>LL"!<(B5S7"(N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDT"FUS9VED(")4:&4@
M9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@=&AI<R!P87)T.B(*
M;7-G<W1R("*FN:K^I?.E7:=TI%6F0\#)KM<Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]S879E:6UA9V5?=VEN+FIS.C$R"FUS9VED("(B"B)4
M:&4@:6UA9V4@<V%V92!W:6YD;W<@8V%N(&YO="!B92!O<&5N960N(%!E<FAA
M<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U
M<"!W:6YD;W=S/R(*;7-G<W1R("*U3*IKMGVQTKG/I/G`>*9SM?BUH2X@IK.E
M::_@IT&D=[%.PG/$_;ZYJKK"V[QUM?BUH:5<K^#"ZJEW(#\B"@HC.B!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3`P"FUS9VED("(B"B)4:&4@:6UA9V5S
M('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S
M96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN(@IM<V=S='(@(J71J?.Q2*7S
MI$BF8J=!JKJS<;!4O_VDI"RF7::YIMNPRL7CI=RK2*2DJKJYSZ3Y+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I
M;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G
M93HB"FUS9W-T<B`BMFRE\Z;XJD&^N;*CI<VE2*15JKJ_^;M^L%2NISHB"@HC
M.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0IM<V=I9"`B
M5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R
M;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`BIKFV;*7SIOBJ0;ZYLJ.ES:5(
MI%6JNK!4KJ<Z(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*
M;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN
M9R!M97-S86=E.B(*;7-G<W1R("*V;*7SIOBJ0;ZYLJ.ES:5(I%6JNK!4KJ<Z
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R("*V
M;+UC("!<(B5S7"(@I=BK9:1WN&>R3:K%+B(*"B,Z(&QI8B]&971C:&UA:6PN
M<&AP.C(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!<(B5S
M7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@
M;&EM:70N(@IM<V=S='(@(B(*(K%Q(%PB)3(D<UPB(,6JJ/JV::C3JKJE?K.A
MJTBE\R!<(B4Q)'-<(B"HY*1JI'`H)3,D9"!B>71E<RFD=[97I5BS7:EWI%>M
MK2XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PIM
M<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO
M<V5D+B!%>&ET:6YG+B(*;7-G<W1R("*V;*7SO&>G0*JZM?BUH:1WLU'#]K.L
M+B"ULJ?TI*0N(@H*(SH@;65S<V%G92YP:'`Z,30X"FUS9VED(")4:&4@;65S
M<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("*FN;9LI?.D=[-1IU*P
MHRXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3<*;7-G:60@(E1H
M92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G<W1R("*FN;9LI?.D
M=[-1Q>?#TBXB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I
M9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T<B`BIKFV;*7SI'>S4<7GP](N(+9L
MI?.Q2*7SJLPZ("5S+B(*"B,Z('1E;7!L871E<R]S;6EM92]O<&5N7W-M:6UE
M7W=I;BYJ<SHQ,"!T96UP;&%T97,O<&=P+V]P96Y?<&=P7W=I;BYJ<SHQ,`IM
M<V=I9"`B(@HB5&AE('!A<W-P:')A<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE
M9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L
M;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(K5,JFNV?;'2L4N]6+7XM:$N
M(*:SI6FOX*=!I'>Q3L)SQ/V^N:JZPMN\=;7XM:&E7*_@PNJI=R`_(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`BPDF_[R`E<R#`R[7X(%!'4""DO;9]JO?&
M7ZJZK>RI;*2ZKF4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C8P
M"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@
M=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`BIF(@35,M5$Y%1B"J
M_J7SI*2GY*2CJ.RITK:WK6ZJNL#)KM<N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C0*;7-G:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO
M="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N(@IM<V=S='(@(J9B(%II
M<""J_J7SI*2GY*2CJ.RITK:WK6ZJNL#)KM<N(@H*(SH@;65S<V%G92YP:'`Z
M-30S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI
M<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@
M=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB
M;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(K9LI?.Q2*7SJLRM;JA$
MIE[`LZKMI=RG0:1WQ:JH^K9LI?,LO=#"2;_O)7.VQ[!EIEZQ^"XB"@HC.B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HV-PIM<V=I9"`B5&AE('-E<G9E
M<B!W87,@;F]T(&%B;&4@=&\@8W)E871E(&$@=&AU;6)N86EL(&]F('1H:7,@
M:6UA9V4N(@IM<V=S='(@(J;XJD&^N;5,JFNLL+-OK=.YSZ3YJ]BEW\%9N<\N
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#<*;7-G:60@
M(E1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R
M("*FN<.QIE>U3*IKLU&X;;2K+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:G,Z,3`U"FUS9VED(")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S
M9G5L;'D@<F5P;&%C960N(@IM<V=S='(@(L.QIE>D=[AMM*NGN::H+B(*"B,Z
M(&%T=&%C:&UE;G0N<&AP.C4Y"FUS9VED(")4:&4@<W!E8VEF:65D(&9I;&4@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(JO\J7>JNL#)KM>HPZ2CIG.F8BXB
M"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@861D960N(@IM<V=S='(@
M(JM(NN!<(B5S7"*W<[Q7I[FFJ"XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`BJTBZX%PB)7-<(J=2L*.GN::H+B(*
M"B,Z('-T871I;VYE<GDN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A=&5D+B(*;7-G<W1R
M("*K2+K@7"(E<UPBI_.W<Z>YIJ@N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$W,`IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@
M>6]U<B!T87-K;&ES="XB"FUS9W-T<B`BIKFKW;_LJ,:VM:1WIJBE7*5;I$JH
M[*=!JKJKW;_LPZ^DI"XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HY-0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4B"FUS9W-T<B`B
MMFRE\Z2ZKF4B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C
M86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("*V;*7SI+JN9;W0L-&FTB`E<R`N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#`*;7-G:60@(E1H
M92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(@IM<V=S='(@(K!HI?.D
MNJYE(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A
M9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`BL&BE\Z2ZKF6]T+#1IM(@
M)7,@+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@
M(K!EI?.DNJYE(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E
M;G0@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("*P9:7SI+JN
M9;W0L-&FTB`E<R`N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U
M-0IM<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S
M('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T<B`BJ,^ESJK,JKH@9G)E92]B
M=7-Y(+CJL%2D=\!XIG.GN::H+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E
M<FYA=&EV92YP:'`Z.#8*;7-G:60@(E1H97)E(&%R92!N;R!A;'1E<FYA=&EV
M92!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M("*ENZ3EL,^U3*IKQ>.EW*:YMFRE\ZJZI72D0+K8KN:FH2XB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS"FUS9VED(")4:&5R
M92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*;7-G<W1R("*E
MV*MELV^MT[9LO6.DI*A3IK.E]*;SJTBE\RXB"@HC.B!T:')E860N<&AP.C$P
M.0IM<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R("*H4Z:SI+JN9:5IQ>.EW*GSI;NDY;#/+B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`BOE"WM+9LO6.NR;5OI<VPW<-$
M+J;XJD&^N:9>P+,Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG
M(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("*ET2!<(B5S7"(@O<:[<[9L
MI?.H[*M(I?.G6"!<(B5S7"(@KLFU;Z7-O_F[?BZF^*I!OKFF7L"S(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C(P,2!L:6(O365S<V%G92YP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H
M870@(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(K%QJTBE\Z=8(%PB)7-<
M(B"G4K"CMFRE\Z[)M6^ES;_YNWXNIOBJ0;ZYIE[`LR(*"B,Z(&QI8B]-97-S
M86=E+G!H<#HR.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E
M<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@
M(J9BJTBE\Z=8(%PB)7-<(B"DI*=2L*.V;*7SKLFU;Z7-O_F[?BZF^*I!OKFF
M7L"S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(Q-PIM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("*G4K"CJTBE\Z[)M6^ES:1`K=._
M^;M^+B"F^*I!OKFF7L"S.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(J=2L*.HQJ7S
M.B`E<R"NR;5OI<VD0*W3O_F[?BXB"@HC.B!L:6(O34E-12]6:65W97(O<&QA
M:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E<B]E;G)I8VAE9"YP:'`Z,S<*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T(@IM<V=S='(@(L#+M?BV;*7SKLFU;Z7-I$"MT[_YNWXN(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C4U-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O
M;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B
M"FUS9W-T<B`BIF*K2*7SIU@@7"(E<UPB(*2DO-##T;9LI?.NR;5OI<V_^;M^
M+J;XJD&^N:9>P+,B"@HC.B!F;VQD97)S+G!H<#HQ-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RXB"FUS
M9W-T<B`BMM>D2B`E<R"NR;5OI<VD0*W3O_F[?BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,3,W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T
M<B`BMM>D2JC&I?,Z("5S(*[)M6^ES:1`K=._^;M^+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S
M='(@(K;7I$JKW;_LJ,:VM3H@)7,@KLFU;Z7-I$"MT[_YNWXN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U
M<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R("*VUZ1*J,^ESJK,JKJW?,2S
MN.JP5#H@)7,@KLFU;Z7-I$"MT[_YNWXN(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!M;W9I;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES
M(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(J71(%PB)7-<
M(B"W:+*^MFRE\ZCLJTBE\Z=8(%PB)7-<(B"NR;5OI<V_^;M^+J;XJD&^N:9>
MP+,B"@HC.B!C;VUP;W-E+G!H<#HQ,C8X"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T+B(*;7-G<W1R
M("*Q3JM(I?.F<ZRPK_.]6J[)M6^ES:1`K=._^;M^+B(*"B,Z(&-O;7!O<V4N
M<&AP.C$P,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R("*VQ[!EMFRE
M\Z[)M6^ES:1`K=._^;M^.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(J?SMW.HQJ7S
M.B`E<R"NR;5OI<VD0*W3O_F[?BXB"@HC.B!L:6(O34E-12]6:65W97(O<&QA
M:6XN<&AP.C4Y"FUS9VED(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R("*FN;9LI?.H4Z:SI.6F<J2ZKF4B"@HC.B!L
M:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`P"FUS9VED(")4:&ES($A434P@
M;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B(*;7-G<W1R("*F
MN:O*($A434P@MFRE\Z2ZM$^YSZ3Y+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H
M=&UL+G!H<#HY,PIM<V=I9"`B(@HB5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM
M86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI
M:V4@(@HB=&AI<SH@(@IM<V=S='(@(J:YJ\H@2%1-3""V;*7SI+JT3[G/I/DN
MK-VP7ZC3N;.S;[S+.B`B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ
M-C4*;7-G:60@(E1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O
M('1H92!M97-S86=E+B(*;7-G<W1R(")01U`@I+VV?:KWQE^D=ZK^I5NH[*:Y
MMFRE\RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`U(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,3D*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$T-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34X"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S0@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C,Q-0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`BLV^MTZ=`I<ZDZ*:AI*.S4:3DM*DN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$X,"!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#(P"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N
M=&5D+B(*;7-G<W1R("*S;ZW3IT"ESJ3HIJ&I?*6\LU&YZJ=`+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,30*;7-G:60@(E1H:7,@
M;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M8V]N=&EN=64_(@IM<V=S='(@(K-OK=.PRJ=`L4ZOT[9/I$"HQZ[)MJ$NQ'[$
M\K;</R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*
M;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE
M+B(*;7-G<W1R("*S;ZO*MFRE\Z5=IW2D0*W3L\&J][;PP,FNURXB"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q-0IM<V=I9"`B(@HB5&AI<R!M
M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D
M:6=I=&%L;'D@<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(J:YMFRE
M\ZG2IZBQ8:JZI$"MTZK^I?.D=[AGLWJY3"!3+TU)344@K$FE2+S&INS#L;.Y
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS9VED(")4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B
M965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R("*FN;9LI?.ITJ>H
ML6&JNJ1`K=.J_J7SI'>X9[-ZN4P@4R]-24U%(*Q)I4BE6[%++B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,`IM<V=I9"`B(@HB5&AI<R!M
M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T
M:6]N+"!B=70@=&AE(&9O<FUA="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@=6YK
M;F]W;BXB"FUS9W-T<B`BLV^KRJM(I5VG=+9LI?.[O+!EJJRZ0:JZN.JP5"RF
M_:Q/JTBE\Z[FIJ&EO*J^+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C,Q.0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*
M;7-G<W1R("*FN;9LI?.F_*5'I*.L3ZQ/I;^]5*JZ(%!'4""E6[%+KN:FH2Z_
M^;M^.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(S.2!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HS-30*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA
M="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T<B`BIKFV;*7S
MIORE1Z2CK$^L3Z6_O52JNB!01U`@KN:FH2`HJ,R^VB!21D,@,C`Q-2DN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S`*;7-G:60@(E1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@
M4R]-24U%(&9O<FUA="XB"FUS9W-T<B`BIKFV;*7SIORE1Z2CK$^L3Z6_O52J
MNB!3+TU)344@KN:FH2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z-#(P"FUS9VED(")4:&ES(&UE
M<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G
M<W1R("*FN;9LI?.D=[AGLWJY3"!01U`@O,:F[,.QL[DN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S<V%G92!H
M87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM<V=S='(@
M(J:YMFRE\Z1WN&>S>KE,(%,O34E-12"\QJ;LP[&SN2XB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C(S.`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E
M9"!V:6$@4R]-24U%+B(*;7-G<W1R("*FN;9LI?.D=ZC/I<X@4R]-24U%(*5;
ML4LN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`P(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(Y,`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B
M965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`BIKFV;*7SI'>HSZ7.
M(%!'4""E6[%++B(*"B,Z(&UE<W-A9V4N<&AP.C(Q,0IM<V=I9"`B5&AI<R!M
M97-S86=E('1O(@IM<V=S='(@(KC3MFRE\ZCL(@H*(SH@86-L+G!H<#HT-0IM
M<V=I9"`B5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N(@IM<V=S='(@(K-OLZ&F^*I!OKFHPZ6\I.2TJ:M(I?.G6*3`J,FE
M7*_@+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y
M"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M
M<&]S92!W:6YD;W<N(@IM<V=S='(@(K-OK=.U^+6AI;*VM[AGI=&V;*7SO&>G
M0+7XM:&HTZE)I7,B"@HC.B!T:')E860N<&AP.C$U,0IM<V=I9"`B5&AR96%D
M($1I<W!L87DB"FUS9W-T<B`BP_;!<,7CI=PB"@HC.B!T:')E860N<&AP.C<V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3`*;7-G:60@(E1H<F5A9"!6:65W
M(@IM<V=S='(@(K9LI?/#]L%PP,NU^"(*"B,Z(&UE<W-A9V4N<&AP.C(V-"!M
M86EL8F]X+G!H<#HU.30@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHR,B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H+G!H
M<#HR-@IM<V=I9"`B5&\B"FUS9W-T<B`BIJRE\Z1((@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP-PIM<V=I9"`B5&\@061D<F5S<R(*;7-G<W1R("*F
MK*7SI$BF8:=](@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,S(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H
M:6QE("(*(F-L:6-K:6YG+B(*;7-G<W1R("(B"B*F<*I'K6Z]QK_OQ.:F["R]
MT*9BPDF_[[?&N:NJNJ[)IE"NR:OV($-O;G1R;VS!Y"BMTZ1(N7&XHRD@J<X@
M0V]M;6%N9,'D*,2KJD>Y<2(*(KBC*2XB"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C$S-`IM<V=I9"`B(@HB5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO
M=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C`N-B!O<B`B
M"B)H:6=H97(N(@IM<V=S='(@(K']J,^ESB!43%,@NO2X]+-SM;(L(*=!I;*V
MMZC/I<X@4$A0(#4N,"XV(*5(I%<HIW0IJKJJJ:6[+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X.`IM<V=I9"`B5&]T86P@071T86-H
M;65N=',@4VEZ93HB"FUS9W-T<B`BJ=*FLZJZJOZE\\%@K7"D:J1P.B(*"B,Z
M(&9O;&1E<G,N<&AP.C,V-PIM<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@
M(JE5IZ.G6"(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z
M,C,*;7-G:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`BJ56GH[UC.B(*"B,Z
M(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C0@;&EB+U%U;W1A+VUE<F-U<GDS,BYP
M:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1=6]T82]L
M;V=F:6QE+G!H<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U
M;W1A+VUD865M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@
M<75O=&$B"FUS9W-T<B`BM4RJ:\6JJ/JZS[K0L'2X;;CJKL8B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R("*EO*9>
MPM`B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5
M;F%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(J6\IE["T*JZMFRE\R(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T92(*
M;7-G<W1R("*T7ZWLI'>G4K"C(@H*(SH@;6%I;&)O>"YP:'`Z-3<W(&UA:6QB
M;W@N<&AP.C4Y,"!L:6(O34E-12](96%D97)S+G!H<#HR,#0*;7-G:60@(E5N
M9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`BP?3"PZ:LI?.D2"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R
M("*U3*IKM'BQL:JZI+BE\ZNLND$Z("5S(@H*(SH@;6%I;&)O>"YP:'`Z-34W
M"FUS9VED(")5;FMN;W=N($1A=&4B"FUS9W-T<B`BI;RJOJJZI.FTP2(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N:VYO=VX@24U!4"!R97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E
M<B!297-P;VYD960Z("5S(@IM<V=S='(@(J6\JKZJNB!)34%0(*9>P+,N(*;X
MJD&^N:9>P+,Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R
M-@IM<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@(J6\JKZJNK=\Q+,B
M"@HC.B!M86EL8F]X+G!H<#HV,#8*;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT
M(@IM<V=S='(@(J6\JKZJNJ:LI?.Y[[9((@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@
M(E5N;&]A9"!087-S<&AR87-E(@IM<V=S='(@(JCXN/RQ2[U8(@H*(SH@9F5T
M8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@(J6\
MJ5*F5R(*"B,Z(&UE<W-A9V4N<&AP.C0Y-2!M86EL8F]X+G!H<#HV.34@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHS,@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC
M.C4*;7-G:60@(E5N<V5E;B(*;7-G<W1R("*EO*S=N4PB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@
M9G)O;2!&;VQD97(H<RDB"FUS9W-T<B`BJ/JN^*UQOEPB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3(*;7-G:60@(E5P9&%T92(*;7-G
M<W1R("+%W*?S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q,@IM
M<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@(J?SMW.F
M7L"SJJRZ02(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU
M."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED(")5<&QO
M860B"FUS9W-T<B`BI%>VQR(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I
M;'-E;&5C="YI;F,Z-#$*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S
M='(@(JC/I<ZY=[-=K<@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V
M"FUS9VED(")5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T
M<B`BJ,^ESB!)34%0(*M(I?.G6*UQOEP_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<R,PIM<V=I9"`B57-E(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*
M;7-G<W1R("*HSZ7.M>K`P*E5IZ.]8S\B"@HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,30S"FUS9VED(")5<V5R(@IM<V=S='(@(JC/I<ZJS"(*"B,Z(&%C
M;"YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB57-E<B!<(B5S7"(@
M<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BJ,^ESJK,(%PB)7-<(B"D=Z:H
MI5RJNK-1O>&DJ:15ID/%=JVMJ.RK2*7SIU@@7"(E<UPB+B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<V"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R("*HSZ7.JLRF5[K9(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`BJ,^ESJK,IE>Z
MV3HB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I
M9"`B5FEE=R(*;7-G<W1R("+`R[7X(@H*(SH@;&EB+TU)344O5FEE=V5R+WII
M<"YP:'`Z.3(@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$Q,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(L#+M?@@)7,B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(%!U8FQI8R!+
M97DB"FUS9W-T<B`BP,NU^"`E<R"DO;9]JO?&7R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HQ,3D*;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN
M(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(J9BMW.U^+6AP,NU^"!(5$U,
M(*2ZKF4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR.`IM
M<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R("+`R[7X(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B
MP,NU^*W3I$BH<+%+JO?&7RXB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE=R!0
M97)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(L#+M?BMTZ1(I+VV?:KWQE\N
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X
M"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R("+#]L%PP,NU^"(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V-"!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HQ-C8*;7-G:60@(E9I97<@5&AU;6)N86EL(@IM<V=S='(@
M(L%9N<_`R[7X(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C,*
M;7-G:60@(E9I97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*
M;7-G<W1R("*F8K=SM?BUH<#+M?BJ_J7S(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W)E;&%T960N<&AP.C<Y"FUS9VED(")6:65W(&-O;G1E;G0@:6X@82!S97!A
M<F%T92!W:6YD;W<B"FUS9W-T<B`BIF*W<[7XM:'`R[7X(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$T,0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G
M<W1R("+`R[7XJ,:E\R(*"B,Z(&9O;&1E<G,N<&AP.C,U.2!M86EL8F]X+G!H
M<#HU,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!M97-S86=E<R!I;B`E
M<R(*;7-G<W1R("+`R[7X("5S(*2DJKJV;*7S(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M
M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S='(@(K5NI$JK
MX<7CI=RK2*7SIU@Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W
M,0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(L#+M?BKW;_LJ,:VM2(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#0*;7-G:60@(E9I97<@=&AE
M($EM86=E<R(*;7-G<W1R("+`R[7XN<^D^2(*"B,Z('-E87)C:"YP:'`Z,C8S
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<(B!C
M<F5A=&5D('-U8V-E<V9U;&QY+B(*;7-G<W1R("*UZL#`JTBE\Z=87"(E<UPB
MI'>KV*7?I[FFJ"XB"@HC.B!L:6(O075T:"]I;7`N<&AP.C$W-0IM<V=I9"`B
M5FER='5A;"!&;VQD97(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(K7JP,"K
M2*7SIUBDHZ9SIF(N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ
M,3$@;&EB+TE-05`O5')E92YP:'`Z,3,S(&QI8B])34%0+U1R964N<&AP.C$T
M-@HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ-#@@;&EB+TE-05`O5')E92YP:'`Z
M,34R(&QI8B])34%0+U1R964N<&AP.C$U,PHC.B!L:6(O24U!4"]4<F5E+G!H
M<#HS-C,@;&EB+TE-05`O5')E92YP:'`Z,S@W(&QI8B])34%0+U1R964N<&AP
M.C0R-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(@IM<V=S='(@(K7JP,"K2*7S
MIU@B"@HC.B!S96%R8V@N<&AP.C(T-0IM<V=I9"`B5FER='5A;"!&;VQD97)S
M(')E<75I<F4@82!L86)E;"XB"FUS9W-T<B`BM>K`P*M(I?.G6+O=K6ZD0*W3
MIE>ZV2XB"@HC.B!L:6(O5D9O;&1E<BYP:'`Z,3<V(&QI8B]61F]L9&5R+G!H
M<#HQ.#8*;7-G:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`BM>K`P*:LI?.G
M6"(*"B,Z(&9O;&1E<G,N<&AP.C,Y-0IM<V=I9"`B5FER='5A;"!)3D)/6"!&
M;VQD97(B"FUS9W-T<B`BM>K`P*:LI?.G6"(*"B,Z(&UA:6QB;W@N<&AP.C0S
M-2!L:6(O36%I;&)O>"YP:'`Z,3<P(&QI8B]61F]L9&5R+G!H<#HQ,3$@;&EB
M+U9&;VQD97(N<&AP.C$R,PIM<V=I9"`B5FER='5A;"!4<F%S:"(*;7-G<W1R
M("*UZL#`J56GH[UC(@H*(SH@9F]L9&5R<RYP:'`Z,SDR"FUS9VED(")6:7)T
M=6%L(%1R87-H($9O;&1E<B(*;7-G<W1R("*UZL#`J56GH[UC(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8S.0IM<V=I9"`B5FER='5A;"!4<F%S:"!&;VQD97(@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(K7JP,"I5:>CO6.DHZ9SIF(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$S,PIM<V=I9"`B5FER='5A
M;"!F;VQD97(@;&%B96PB"FUS9W-T<B`BM>K`P*M(I?.G6*97NMDB"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W.0IM<V=I9"`B5V%R;FEN9R(*
M;7-G<W1R("+$M:=I(@H*(SH@;&]G:6XN<&AP.C$T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(L5WJN^H["`E<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#<*;7-G:60@(B(*(E=H870@<VAO
M=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G<W1R
M("*W[;9LI?.S4:9>L_BLL+QSIVFISJ2CK$^\<Z=IKLG`L[C3/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW,34*;7-G:60@(B(*(E=H96X@9&5L971I
M;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I
M;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE=&5D/R(*;7-G<W1R
M("*W[:=2L*.V;*7SKLDL(*2CO-"[>*:HI'>G4K"CIM.JO;&ULKZH[*E5IZ.]
M8S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DU"FUS9VED(")7:&5N
M(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N
M="!T;R!S=&%R="!O;C\B"FUS9W-T<B`BMGVQTJM(I?.G6*[)+*=!I\:QYK%Q
MK?ZD0*VVMGVI;#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38Q"FUS
M9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T
M=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`BP'BF<[%(I?.SQJ7WKLDLK$^G7Z1=
MK6ZD0*C6P'BF<ZK^I5O`R:[7(#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#(V"FUS9VED("(B"B)7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I
M;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD('1O
M("(*(G5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S('=I
M=&AO=70@7")`7"(I/R(*;7-G<W1R("(B"B*VQ[!EMFRE\ZG.J6VF5\%RM/JN
MR:%!IG"J1ZA3IK._Z:1*IJRE\[GOMDBJNKKTL.RF5[K9*+EQI&RV;*7SINVG
M?:A3IK-<(D`B"B)<(BD_H4&E2*:YL+6LL+EWLUVJNKKTL.RF5[K9/R(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B5VAI=&5L:7-T
M(@IM<V=S='(@(J3-M;VF5[/F(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-3,V('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38V"FUS9VED(")997,B"FUS
M9W-T<B`BK$\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?
M;&]G:6XN<&AP.C4X"FUS9VED(")9;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M
M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O=6YT*',I.B(*;7-G<W1R("*G
M0:6_IF+`?+C5I=&D5:9#L6*XN::LJ/JE?K.AMFRE\SHB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`IM<V=I9"`B(@HB
M66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N
M=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R
M("*G0:6_IF+`?+C5IU*PHZ15ID.K2*7SIUBDI*JZJ=*FL[9LI?,N(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ.0IM<V=I
M9"`B66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG
M(&9O;&1E<BAS*2XB"FUS9W-T<B`BIT&EOZ9BP'RXU:=2L*.D5:9#JTBE\Z=8
M+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B66]U
M(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S='(@
M(J=!I;^F8KW&NW,OMVBROJCLI$"MT[=SJTBE\Z=8+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R"FUS9VED(")9;W4@87)E(&-R
M96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`BIT&EOZ9BJ]BEW[=S
MJKJFN*M(I?.G6*CL("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3`T"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L
M(&9O;&1E<BXB"FUS9W-T<B`BIT&EOZ9BJ]BEWZ1`K=.SS*17O&BJNJM(I?.G
M6"XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,3@*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@(J=!J%.FLZO8
MI=^K2*7SIUBJNL5VK:TN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(U"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R("*DHZ2YLURG0:O8I=\E
M9*W3I4BD5ZJZJTBE\Z=8+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD
M97(Z("(*;7-G<W1R("*G0:6_IF*LL*M(I?.G6*?SMW.F5[K9.B`B"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@=&AE(&9O;&QO=VEN9R!P;&%C96AO
M;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X=#H@)6,@9F]R('1H92`B"B)C
M=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R('1H92!S:6=N871U<F4N
M(@IM<V=S='(@(J=!I6FE2*9BJTBZX*2DJ,^ESJ15ID.K9;AMIG*DN#H@)6,@
MJNVEW*78JV6K2*7SI*2JNJ2ZKF4[("5S(*KMI=S#L:97+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C4V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N;F]T
M('5N<W5B<V-R:6)E(&9R;VT@7"(E<UPB+B(*;7-G<W1R("*G0;5,JFNH^J[X
MK7&^7"!<(B5S7"(N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G
M<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O
M('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@
M;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(J=!J7REO*90MTZH
MSZ7.L?BTVBRU3*IKQ?VG0;5NI$HN(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$W,`IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@
M8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B(*;7-G<W1R("*G0:A3IK/%
MW*?SIKFK2*7SIUBF<ZCZL;&H[JJZQ7:MK2(*"B,Z(&QI8B]-86EL;&]G+G!H
M<#HQ,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O<G=A<F1E9"!T:&ES
M(&UE<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@
M)7,N(@IM<V=S='(@(J=!M+^X9ZGS("4E<R#"X+%(LV^KRJM(I?.UN;-OJ,>D
M2#H@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+B(*
M;7-G<W1R("*G0::S("5S(*O*MW.V;*7S(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H879E(#$@;F5W(&UE<W-A9V4N
M(@IM<V=S='(@(J=!IK.D0*O*MW.V;*7S(@H*(SH@8V]M<&]S92YP:'`Z-#@P
M"FUS9VED(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N
M(@IM<V=S='(@(J=!I'>P9:58IKFMMJVQ+B(*"B,Z(&QI8B])35`N<&AP.C$P
M-38*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@
M9F]L9&5R.B(*;7-G<W1R("*G0:9BI%6F0ZM(I?.G6*2DIK.W<[9LI?,Z(@H*
M(SH@;&EB+TE-4"YP:'`Z,3`V,0IM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@
M:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.B(*;7-G<W1R("*G0:9BI%6F0[9L
MO6.DI*:SMW.V;*7S.B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PIM<V=I9"`B66]U
M(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS9W-T<B`B
MIT&ELK:WIMRDUK_II$JD0*;LIJRE\[GOMD@N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,S`V"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@
M<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T
M:&ES(&UE<W-A9V4B"FUS9W-T<B`BK6[`R[7XIKFV;*7SI;*VMZ7]O^FD2J=!
MJKH@4$=0(*W3I$BJ]\9?L4N]6"XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C(U-`IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P
M:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI
M<R`B"B)M97-S86=E(@IM<V=S='(@(JUNP,NU^*:YMFRE\Z6RMK>E_;_II$JG
M0:JZ(%,O34E-12"MTZ1(JO?&7[%+O5@N(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O:F%V87-C<FEP="YI;F,Z-C0@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,C`Q"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@
M;6%I;&)O>"!F:7)S="XB"FUS9W-T<B`BK;JE_:%!IT&ELK:WI?V_[[[<I$"M
MTZ78JKJK2*7SIU@N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*
M;7-G<W1R("*G0:6RMK>E_;_OOMRD0*W3K6ZG4K"CJKJQ8KBY+B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z.#$*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R("*MNJ7]H4&G
M0:6RMK>E_;_OOMRD0*W3IF&G?2XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8SHV,B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHR,#@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M,C8S"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A
M9V4@9FER<W0N(@IM<V=S='(@(JVZI?VA0:=!I;*VMZ7]O^^^W*;<I-:D0*O*
MMFRE\RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3,*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!R96-I<&EE;G0N(@IM<V=S='(@
M(J=!I;*VMZO\J7>D0*W3IJRE\Z1(+B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@;F5E
M9"!T;R!H879E(%PB)7-<(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@
M;W!T:6]N<RXB"FUS9W-T<B`BIT&ELK:WK6ZF8KK[Q4"^WJ=`JKJ_[[:UI*2D
MQ+_O(%PB)7-<(BXB"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,X"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E
M<R!O;B`E)7,N(@IM<V=S='(@(J=!I'>I\R`E)3(D<R#"X*=]N[RP9::YJTBE
M\[6Y("4Q)',N(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N
M(@IM<V=S='(@(J=!I'>I\R`E<R"F7L+0IKFK2*7S+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@
M<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`BIT&HPZ6\K7&^7"!<(B5S7"(NIOBJ0;ZYIE[`LR(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C4V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES
M('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(J=!J,.EO*CZKOBM<;Y<
M(%PB)7-<(BZF^*I!OKFF7L"S(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3$X"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S
M8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R("*G0:1WIJBE7*UQOEP@7"(E<UPB
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3<P"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S
M7"(B"FUS9W-T<B`BIT&D=Z:HI5RH^J[XK7&^7"!<(B5S7"(B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z.3@*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R
M("*G0:JZIE>ZV2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU,`IM<V=I
M9"`B66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*;7-G<W1R("*G0:JZ
M(%!'4""DO;9]+ZAPL4NJ]\9?(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*;7-G:60@(EEO=7(@
M4')I=F%T92!+97DB"FUS9W-T<B`BIT&JNJAPL4NJ]\9?(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S$*;7-G:60@(EEO=7(@4'5B;&EC($ME>2(*;7-G<W1R("*G0:JZI+VV?:KW
MQE\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"FUS9VED(")9;W5R
M(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S
M='(@(KO5I%6JNJ9>MFRF8:=](#QE;3XHJT2ELK:WJKHI/"]E;3XB"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-
M12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS9W-T<B`BIT&JNB!3
M+TU)344@I+VV?2^H<+%+OLS#TB(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M86-C;W5N=%]S96QE8W0N:6YC.C$V"FUS9VED(")9;W5R(&%C8V]U;G1S.B(*
M;7-G<W1R("*E?K.AMFRE\\/1IT^F5[K9.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-S,*;7-G:60@(B(*(EEO=7(@86QI87,@861D<F5S<V5S.B`\
M96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN
M92D\+V5M/B(*;7-G<W1R("*[U:15JKJG3Z97N7&D;+9LI?.F8:=].B`\96T^
M**M$I;*VMRRF<*:SIFBUI[W0I4BW<Z;FO^FD2BD\+V5M/B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C$P,0IM<V=I9"`B66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G
M92!T>7!E+B(*;7-G<W1R("*G0:JZPG/$_;ZYJ,.EO*3DM*FFN;K8N<^D^:[F
MIJ&JNJJ]L;7%XZ7<+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,SD*
M;7-G:60@(EEO=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE<W-A
M9V5S.B(*;7-G<W1R("*VQ[!EMFRE\ZJZN7>S7;USO5BDZ*:A.B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R
M(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G
M97,Z(@IM<V=S='(@(K;'L&6V;*7SJKJY=[-=I5NQ2Z3HIJ$Z(@H*(SH@871T
M86-H;65N="YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!L
M:6YK960@871T86-H;65N="!H87,@8F5E;B!D;W=N;&]A9&5D(&)Y(&%T(&QE
M87-T(&]N92!U<V5R+EQN(@HB7&XB"B)!='1A8VAM96YT(&YA;64Z("5S7&XB
M"B)!='1A8VAM96YT(&1A=&4Z("5S7&XB"B)<;B(*(D-L:6-K(&]N('1H92!F
M;VQL;W=I;F<@;&EN:R!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE(&%T=&%C
M:&UE;G0Z7&XB"B(E<R(*;7-G<W1R("(B"B+"X*9SK+"Z]*=]JKJJ_J7SI'>S
M4:1`K=.E2*17JKJFK*7SN>^V2*15N/PN7&XB"B)<;B(*(JK^I?.F5[K9.B`E
M<UQN(@HBJOZE\Z3IM,$Z("5S7&XB"B)<;B(*(L))O^^D5:9#LW.ULJ5(LKZP
MH[C3JOZE\SI<;B(*(B5S(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP
M:'`Z.#D*;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E
M;&EV97)E9"XB"FUS9W-T<B`BIT&JNK9LI?.D=[N\L&6GN::H+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@(EEO=7(@<VEG;F%T=7)E
M.B(*;7-G<W1R("*G0:JZP[&F5SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]A9&1R97-S97-";&]C:W,N:G,Z-PIM<V=I9"`B6TAI9&4@061D<F5S<V5S
M72(*;7-G<W1R(");P?3"PZ;MIWU=(@H*(SH@;65S<V%G92YP:'`Z,C@X(&-O
M;7!O<V4N<&AP.C$R.#8@;6%I;&)O>"YP:'`Z-3,U(&QI8B]#;VUP;W-E+G!H
M<#HX,S@*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");M4RE1*:N72(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V%D9')E<W-E<T)L;V-K<RYJ<SHX
M"FUS9VED(");4VAO=R!!9&1R97-S97,@+2(*;7-G<W1R(");Q>.EW*;MIWT@
M+2(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(");4VAO=R!A9&1R97-S97,@+2`E<R!R96-I<&EE;G1S72(*;7-G
M<W1R(");Q>.EW*;MIWT@+2`E<R"FK*7SI$A=(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,C`U"FUS9VED(")?0F-C(@IM<V=S='(@(J^U
MI?.PQJ6[7T(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*;7-G
M:60@(E]";&%C:VQI<W0B"FUS9W-T<B`BML*F5[/F7T(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-30*;7-G:60@(E]#8R(*;7-G<W1R
M("*PQJ6[7T,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"FUS9VED(")?1&5L971E
M(@IM<V=S='(@(J=2L*-?1"(*"B,Z(&QI8B])35`N<&AP.CDV,@IM<V=I9"`B
M7T9O;&1E<G,B"FUS9W-T<B`BJTBE\Z=87T8B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHX,0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@
M(JBMI??#T:=/7TDB"@HC.B!L:6(O24U0+G!H<#HY,S$*;7-G:60@(E]);F)O
M>"(*;7-G<W1R("*FK*7SIUA?22(*"B,Z(&QI8B])35`N<&AP.C$P,#,*;7-G
M:60@(E],;V<@;W5T(@IM<V=S='(@(K5NI5A?3"(*"B,Z(&UE<W-A9V4N<&AP
M.C,X-`IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(L#+M?BM[*EL
MP,E?32(*"B,Z(&QI8B])35`N<&AP.CDU.0IM<V=I9"`B7TYE=R!-97-S86=E
M(@IM<V=S='(@(KQGJTA?3B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B7U!R:6YT(@IM<V=S='(@(J3-M;VF
M0Z9,7U`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@Y"FUS9VED(")?4')I
M;W)I='DB"FUS9W-T<B`BP'6E_5]0(@H*(SH@;6%I;&)O>"YP:'`Z-#`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@(JVKMW.^
MX[)Z7U(@)7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z.`IM<V=I9"`B7U)E<&QY(@IM<V=S='(@(J9>PM!?4B(*"B,Z(&QI
M8B])35`N<&AP.CDV-`IM<V=I9"`B7U-E87)C:"(*;7-G<W1R("*W:K1-7U,B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C4*;7-G:60@(E]396YD($UE<W-A
M9V4B"FUS9W-T<B`BML>P9;9LI?-?4R(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S(*;7-G:60@(E]4:')E860B"FUS9W-T
M<B`BP_;!<%]4(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,3$V"FUS9VED(")?5&\B"FUS9W-T<B`BIJRE\Z1(7U0B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B7U5N9&5L971E(@IM
M<V=S='(@(K1?K>RD=Z=2L*-?52(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S
M='(@(L/VP7#`R[7X7U8B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`BI,VUO:97L^9?5R(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ-S4*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N
M(@IM<V=S='(@(J6\JKZJNK9LI?.F[:=](@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0U,0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R("*J_J7S(@H*(SH@=FEE
M=RYP:'`Z.3<*;7-G:60@(F%T=&%C:&UE;G1S+GII<"(*;7-G<W1R(")A='1A
M8VAM96YT<RYZ:7`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU,#0*;7-G:60@(F)Y=&5S(@IM<V=S='(@(F)Y=&5S(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$Y.0IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL
M92(*;7-G<W1R("*U3*IKJ]BEW[_II5C`R:[7+B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ-S$*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(K5,
MJFNV?;'2O^FD2B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C,*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("*Q2Z5/ID.[>:IKO_F[
M?B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,3D*;7-G:60@(F-O;F9I9W5R871I
M;VX@97)R;W(B"FUS9W-T<B`BLUVI=[_YNWXB"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3DU"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM
M<V=S='(@(K_RI:*MJZUNJKJH=++.P,FNUR(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ-C<*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(KCJKL:N
MYJ:AO_F[?B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C,*;7-G:60@(F5N=')Y
M(&YO="!F;W5N9"(*;7-G<W1R("*GY*2CJ.RP3[_](@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS9W-T
M<B`BL7$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<Y"FUS9VED(")H;W-T(&YA
M;64@=6YK;F]W;B(*;7-G<W1R("*EO*J^JKJV;*7SI42^]Z97NMDB"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,C`S"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B
M"FUS9W-T<B`BO^FD2B^_Z:58O_F[?B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M.#<*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(J2Z
MLZ&S;L7IO_F[?B(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8X"FUS9VED
M(")K97DB"FUS9W-T<B`BJO?&7R(*"B,Z(&9O;&1E<G,N<&AP.C$T,0IM<V=I
M9"`B;6%I;&)O>"!F:6QE(@IM<V=S='(@(K9LO6/`R:[7(@H*(SH@8V]M<&]S
M92YP:'`Z,3`Y-R!L:6(O365S<V%G92YP:'`Z-#<V"FUS9VED(")N86UE(@IM
M<V=S='(@(J97NMDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`BJ%.FLR(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(F]R(@IM<V=S='(@
M(JG.JLPB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$U"FUS9VED(")P97)M:7-S
M:6]N(&1E;FEE9"(*;7-G<W1R("*F<ZCZOD2IVB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V%D9')E<W-E<T)L;V-K<RYJ<SHX"FUS9VED(")R96-I<&EE
M;G1S72(*;7-G<W1R("*FK*7SI$A=(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q
M,0IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(K-Q
MJTBH\ZEWN[>ZW;_YNWXB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@S"FUS9VED
M(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(K5,I6FESJJZJD&PR"(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B
M<W!E;&QI;F<@97)R;W(B"FUS9W-T<B`BK=.K]Z9RO_F[?B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@
M97)R;W)S(@IM<V=S='(@(JW3J_>F<K_YNWXB"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3DQ"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`BJ'2RSK_YNWXB
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`W"FUS9VED(")T96UP;W)A<GD@9F%I
M;'5R92(*;7-G<W1R("*\R*[)J<JJNJ6BL=$B"@HC.B!L:6(O1FEL=&5R+G!H
M<#HU,0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`BIT&JNK;"IE>S
MYB(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H:71E;&ES
M="(*;7-G<W1R("*G0:JZI,VUO:97L^8B"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]P;R]H=5](52YP;P``````````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`T,S8R,#4`,3`T,3<S-C(W-C,`,#$W,C`W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````",@
M24U0($AU;F=A<FEA;B!T<F%N<VQA=&EO;B!F:6QE+@HC($-O<'ER:6=H="`H
M0RD@,C`P,BTR,#`V($QA<WIL;R!,+B!4;W)N;V-I"B,@5&AI<R!F:6QE(&ES
M(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($E-
M4"!P86-K86=E+@HC($QA=&5S="!V97)S:6]N<SH@9G1P.B\O>&5N:6$N<V]T
M92YH=2]P=6(O;&EN=7@O:&]R9&4O"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0
M<F]J96-T+4ED+59E<G-I;VXZ($E-4"`T+C%<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-BTP,BTQ-R`Q,#HP,"LP,3`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`V+3`R+3$X(#`Y.C0V*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@3&%S>FQO($PN(%1O<FYO8VD@/'1O<FQA<WI`>&5N:6$N<V]T92YH=3Y<
M;B(*(DQA;F=U86=E+51E86TZ($AU;F=A<FEA;B`\:3$X;D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3)<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HT,CD*;7-G:60@(B`@("`@($-C.B`B"FUS9W-T<B`B("`@("`@0V,Z("(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,C8*;7-G:60@(B`@("`@(%1O.B`B"FUS
M9W-T<B`B($/M;7IE='0Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,30*;7-G
M:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@1.%T=6TZ("(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HT,3<*;7-G:60@(B`@("!&<F]M.B`B"FUS9W-T<B`B("!&
M96QA9/,Z("(*"B,Z(&UA:6QB;W@N<&AP.C0P.2!T96UP;&%T97,O9F]L9&5R
M<R]H96%D+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(@*$%L="UB:6QL96YT>?L@)7,I(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0R,PIM<V=I9"`B(%-U8FIE8W0Z("(*;7-G<W1R(")487)T
M86QO;3H@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<P
M"FUS9VED("(@:6X@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T<B`B(R(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z
M('1H<F5A9"YP:'`Z,34V"B,L('!H<"UF;W)M870*;7-G:60@(B5D($UE<W-A
M9V5S(@IM<V=S='(@(B5D(&QE=NEL(@H*(SH@;6%I;&)O>"YP:'`Z,3<V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("(E9"!L979E;&5T('3V<O9L=/QN:RXB"@HC.B!L:6(O
M4W!A;2YP:'`Z,3DV"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A
M9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B(E9"!L979E;&5T(&UI
M;O5S[71E='0@;F5M('-P86UN96L@82!R96YD<WIE<F=A>F3A;F%K(&O\;&3V
M='0@:F5L96YTZ7-B96XN(@H*(SH@;&EB+U-P86TN<&AP.C$W-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86TN(@IM<V=S='(@(B5D(&QE=F5L970@;6EN]7/M=&5T="!N
M96T@<W!A;6YE:RXB"@HC.B!L:6(O4W!A;2YP:'`Z,3@X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S
M<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B5D
M(&QE=F5L970@;6EN]7/M=&5T="!S<&%M;F5K(&$@<F5N9'-Z97)G87IDX6YA
M:R!K_&QD]G1T(&IE;&5N=.ES8F5N+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E
M<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(B5D(&QE=F5L970@;6EN]7/M=&5T
M="!S<&%M;F5K+B(*"B,Z(&UA:6QB;W@N<&AP.C,U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"`M
M("5D("CV<W-Z97-E;B`E9"!L97;I;"DB"@HC.B!M86EL8F]X+G!H<#HV,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP
M.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9
M;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@(B5S(&WA
M<B!LZ71E>FEK+B!!("5S(&UA<'#A="!N96T@<VEK97+\;'0@X71N979E>FYI
M+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV.#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB
M"FUS9W-T<B`B)7,@;F5M(&5G>2#I<G;I;GEE<R!L97;I;&SA9&$N(@H*(SH@
M;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN
M<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9O;&1E<B!B96EN9R!R
M96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N(@IM<V=S='(@(D$@
M)7,@;6%P<&$@82!H\VYA<"!E;&5JZ6X@;F5V97KU9&EK(.%T+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R("(E<R!E;&9O9V%D=&$@82!M
M96=H[7;A<W0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@8V%N8V5L;&5D(%PB)7-<(BXB
M"FUS9W-T<B`B)7,@=/9R]FQT92!A*'HI(%PB)7-<(B!E<V5MZ6YY="XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&AA<R!D96-L:6YE9"XB"FUS9W-T<B`B)7,@96QU=&%S[71O
M='1A(&$@;65G:.UVX7-T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@
M82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B)7,@=N%L87-Z;VQT(&%Z
M(&ED]6)E;W-Z=.%S:2!A9&%T:^ERZ7-R92XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R
M97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O(%PB)7-<(BXB"FUS9W-T<B`B
M)7,@=N%L87-Z;VQT(&$H>BD@7"(E<UPB+7)E('-Z\VSS(&UE9VCM=N%S<F$N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+B(*;7-G<W1R("(E<R!I9/5B96]S>G3A<VD@:6YF;W)MX6-I\W0@:_QL
M9/9T="#6;FYE:RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A8V-E
M<'1E9"XB"FUS9W-T<B`B)7,@9F5L=.ET96QE<V5N(&5L9F]G861T82!A(&UE
M9VCM=N%S="XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(E<R!I9/5B96]S>G3A<VD@861A=&]K
M870@:^ER(-9N=/5L+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S
M96YC92!A="!<(B5S7"(N(@IM<V=S='(@(B5S('-Z97)E=&[I+"!H82!RZ7-Z
M="!T=61N82!V96YN:2!A(&OV=F5T:V5Z]2!E<V5MZ6YY96XZ(%PB)7-<(BXB
M"@HC.B!L:6(O365S<V%G92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@7"(E<UPB+B(*;7-G<W1R
M("(E<RUT('-I:V5R97-E;B!H;WIZX71E='3\:R!<(B5S7"(M:&5Z+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=VES:&5S('1O(&%M;65N9"!<(B5S7"(N(@IM<V=S='(@(B5S
M(';A;'1O>G1A=.%S="!S>F5R971N92!A*'HI(%PB)7-<(B!E<V5MZ6YN>65L
M(&MA<&-S;VQA=&]S86XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4W,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y
M;W4@87=A<F4@;V8@7"(E<UPB+B(*;7-G<W1R("(E<R!TX6KI:V]Z=&%T;FD@
M:^UVX6YJ82#6;G0@82!K]G9E=&ME>O4@97-E;>EN>7+U;#H@7"(E<UPB+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O
M<FUA=&EO;B!A8F]U="!<(B5S7"(N(@IM<V=S='(@(B5S(&$@;&5G9G)I<W-E
M8F(@:6YF;W)MX6-I\W0@<WIE<F5T;ND@;65G:V%P;FD@82AZ*2!<(B5S7"(@
M97-E;>EN>7+U;"XB"@HC.B!M97-S86=E+G!H<#HR.3,@;65S<V%G92YP:'`Z
M,CDX"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?=&]P+FEN8SHR,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS
M9W-T<B`B)7,Z("5S("@E9"9N8G-P.V$F;F)S<#LE9"UB]6PI(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B*$%P<&QY
M('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*;7-G
M<W1R("(H02!VX6QT;WIT873A<V]K(&UE9W3I=&5L92!U=.%N('3I<FK\;FL@
MX70@82!K]G9E=&ME>O4@:^EP97)N>?5R92XI(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H
M86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G
M<W1R("(B"B(H5F]N:G5K('9I<W-Z82!A>B#V<W-Z97,@=N%L=&]Z=&%TX7-T
M(.ES('3I<FK\;FL@=FES<WIA(&$@;&5VZ6SM<N%S:&]Z+BDB"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA(5$U,*2(*
M;7-G<W1R("(H2%1-3"DB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!497AT*2(*;7-G<W1R("(H<VEM82!S
M>O9V96<I(@H*(SH@<W!E;&QI;F<N<&AP.C(W.0IM<V=I9"`B(@HB*%)E='5R
M;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H
M86YG97,@;6%D92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U<G)E
M;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H
M5.ER:OQN:R!V:7-S>F$@82!L97;I;.URX7-H;WH@87H@961D:6=I(';A;'1O
M>G1A=.%S;VL@;65G=.ET96QE('5TX6XN($$@(@HB:F5L96YL96=I(&OI<&5R
M;GGU;B!LX71H873S(';A;'1O>G1A=.%S;VL@87IO;F)A;B!.14T@=/9R=.EN
M;F5K(&UE9RXB"@HC.B!S<&5L;&EN9RYP:'`Z,C<V"FUS9VED("(B"B(H4V5N
M9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU
M<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W:6QL
M($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*$O\;&1J_&L@96P@82!L
M979E;&5T(&%Z(&5D9&EG:2!VX6QT;WIT873A<V]K(&UE9W3I=&5L92!U=.%N
M+B!!(&IE;&5N;&5G:2`B"B)KZ7!E<FYY]6X@;.%T:&%T\R!VX6QT;WIT873A
M<V]K(&%Z;VYB86X@3D5-('3V<G3I;FYE:R!M96<N(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@(BH@061D('1H97-E
M(&)Y(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B!!>B!/2R!G;VUB<F$@:V%T
M=&EN='9A(&%D:G5K(&AO>GKA(&5Z96ME="`J(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C
M="!A9&1R97-S*&5S*2`J(@IM<V=S='(@(BH@2^ER:OQK(';A;&%S<WIO;B!C
M[6TH96LI970@*B(*"B,Z(&UA:6QB;W@N<&AP.C$W-`IM<V=I9"`B,2!M97-S
M86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(C$@;&5V96QE="!T]G+V
M;'3\;FLN(@H*(SH@;&EB+U-P86TN<&AP.C$Y.`IM<V=I9"`B,2!M97-S86=E
M(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(C$@;&5V96QE="!M:6[U<^UT
M971T(&YE;2!S<&%M;F5K(&$@<F5N9'-Z97)G87IDX6YA:R!K_&QD]G1T(&IE
M;&5N=.ES8F5N+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S@*;7-G:60@(C$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B
M,2!L979E;&5T(&UI;O5S[71E='0@;F5M('-P86UN96LN(@H*(SH@;&EB+U-P
M86TN<&AP.C$Y,`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D
M(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B,2!L979E;&5T(&UI;O5S[71E='0@<W!A;6YE:R!A(')E;F1S>F5R9V%Z
M9.%N86L@:_QL9/9T="!J96QE;G3I<V)E;BXB"@HC.B!L:6(O4W!A;2YP:'`Z
M,3<P"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A
M;2XB"FUS9W-T<B`B,2!L979E;&5T(&UI;O5S[71E='0@<W!A;6YE:RXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`X"FUS9VED("(Q,#`@8VAA<F%C
M=&5R<R(*;7-G<W1R("(Q,#`@:V%R86MT97(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#$Q"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B
M,3`P,"!K87)A:W1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#D*
M;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(C(U,"!K87)A:W1E<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3`*;7-G:60@(C4P,"!C:&%R
M86-T97)S(@IM<V=S='(@(C4P,"!K87)A:W1E<B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA
M<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G
M92XB"FUS9W-T<B`B16=Y("5S(&YE=OL@;F%G>6WI<F5T^R!KZ7`@=F%N(&-S
M871O;'9A(&5H:&5Z(&$@;&5VZ6QH97HN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@
M:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I
M;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G<W1R(")!>B!E;&O\;&3V
M='0@;&5VZ6QR92!V:7-S>F%J96QZZ7,@Z7)K97IE='0@82!C[6UZ971T]6PN
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4*;7-G:60@(D%.
M1"(*;7-G<W1R("+)4R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M.#(*;7-G:60@(D%C8V5P="!A;F0@861D('1O(&UY(&-A;&5N9&%R(@IM<V=S
M='(@(D9O9V%D:G5K(&5L(&$@;65G:.UVX7-T(.ES(.UR:G5K(&)E(&%Z(&5S
M96WI;GET(&$@;F%P=.%R=6YK8F$B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3@U"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")E;&9O
M9V%D;VT@82!M96=H[7;A<W0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S0V"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R(")E;&9O9V%D=F$B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4X"FUS9VED(")!8V-E<'1E
M9#H@(@IM<V=S='(@(D5L9F]G861V83H@(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C8V]U;G0G<R!N86UE.B(*;7-G
M<W1R(")!>B#A='3V;'3I<VAE>B!VX6QA<WIT;W1T(&5L;F5V97KI<SHB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(R(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW,C4*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B3&5H973U
M<^EG96LB"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(@;&EB+TU)344O
M2&5A9&5R<RYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"`E<R!T
M;R!M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B861J=6L@:&]Z>N$@)7,M="!A
M(&/M;6IE9WEZZ6ME;6AE>B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C,P,PIM<V=I9"`B061D('-O=7)C92(*;7-G<W1R(")A9&IU
M:R!H;WIZX2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S,*;7-G
M:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(F%D:G5K(&AO
M>GKA(&$@;F%P=.%R86UH;WHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3@S"FUS9VED(")!9&0@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B861J
M=6L@:&]Z>N$@82!N87!TX7)A;6AO>B(*"B,Z(&-O;7!O<V4N<&AP.C4Y,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T86-H
M;65N="XB"FUS9W-T<B`B7"(E<UPB+70@;65L;.EK;&5T:^EN="!C<V%T;VQT
M=6LN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`IM<V=I9"`B(@HB
M061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\
M96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B"B)O;B!A(&YE=R!L
M:6YE*3PO96T^(@IM<V=S='(@(B(*(D$@<WIO:^%S;W-A:V]N(&OM=OQL(&UE
M;'D@9F5J;.EC<V]R;VMA="`H;6%I;"!H96%D97(I(&OM=N%N(&UE9VIE;&5N
M[71T971N:2`B"B(\96T^*&YE;2!K]G1E;&5Z]2P@;6EN9&5N(&9E:FSI8W-O
M<B!K_&SV;B!S;W)B82!K97+\;&KV;BD\+V5M/B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E<RXB"FUS
M9W-T<B`B5&]VX6)B:2!I;F9O<FWA8VGS(&SA=&AA=/,@)7,N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*;7-G:60@(D%D9&ET
M:6]N86P@:6YF;W)M871I;VX@9&5T86EL<R(*;7-G<W1R(")4;W;A8F)I('+I
M<WIL971E<R!I;F9O<FWA8VGS(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z.3,*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(@IM
M<V=S='(@(E1O=N%B8FD@<NES>FQE=&5K(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA
M;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B
M07H@_'IE;F5T('1O=N%B8FD@<NES>FQE=&5I(&SA=&AA=/-K("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<X"FUS9VED(")!9&1I=&EO
M;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R(*;7-G<W1R(")4;W;A8F)I('+I
M<WIL971E<R!H:6)A_'IE;F5T(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S
M86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B
M5&]VX6)B:2!RZ7-Z;&5T97,@:&EB8?QZ96YE="!LX71H873S("5S+B(*"B,Z
M(&-O;G1A8W1S+G!H<#HX-2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$X,`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,SD@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4R"FUS9VED(")!9&1R
M97-S($)O;VLB"FUS9W-T<B`B0^UM:F5G>7KI:R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S0*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B
M0^UM:F5G>7KI:V5K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM
M<V=I9"`B(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH
M;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE
M*3PO96T^(@IM<V=S='(@(B(*(DUE;'D@8^UM96MR92!K[7;A;B!M:6YD96X@
M96QK_&QD]G1T(&QE=NEL<O5L(%PB0D-#7"(@;>%S;VQA=&]T(&O\;&1E;FDZ
M(#QE;3XB"B(H;F5M(&OV=&5L97KU+"!M:6YD96X@8^UM(&O\;/9N('-O<F)A
M(&ME<OQL:O9N*3PO96T^(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B(@HB061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H
M:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D
M<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(D%Z;VL@82!C
M[6UE:RP@;65L>65K<F4@Z7)K97KU(&QE=F5L96ME="!E:&AE>B!A>B!A>F]N
M;W/M=/-H;WH@:^UVX6X@:_9T;FD@(@HB/&5M/BAN96T@:_9T96QE>O4L(&UI
M;F1E;B!C[6T@:_QL]FX@<V]R8F$@:V5R_&QJ]FXI/"]E;3XB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,3(*;7-G:60@(D%L;"(*;7-G<W1R(")A>B#V<W-Z97-E="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*;7-G:60@(B(*
M(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL
M(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G<W1R
M("(B"B)!(&OV=F5T:V5Z]2!M87!P82AK*2!T87)T86QM82!L973V;.ES<F4@
M:V5R_&P@96=Y('-T86YD87)D(&UB;W@@9F]R;>%T=6WZ("(*(F;A:FQB83HB
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('EO=7(@
M7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P97)M
M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R("(B"B)!>B#6;B!<(B5S7"(@
M;6%P<.%JX6)A;B!A>B#V<W-Z97,@)7,@;F%P;N%L('+I9V5B8FD@;&5VZ6P@
M=NEGZ7)VZ6YY97-E;B`B"B)T]G)L]61N:2!F;V<N(@H*(SH@;&EB+TUA:6YT
M96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP.C4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE
M;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB
M"FUS9W-T<B`B(@HB07H@]G-S>F5S+"`E<R!H\VYA<&[A;"!RZ6=E8F)I+"!H
M:79A=&MO>N%S(&9O<FWA:N%B86X@:_QL9/9T="!M96QLZ6ML970@(@HB97)E
M9&5T:2!PZ6QDX6YYX70@=/9R]FQJ_&LN(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF
M;W)M870*;7-G:60@(D%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T
M:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("(B
M"B)!("5S(&CS;F%P;W-NX6P@<NEG96)B:2P@96QK_&QD]G1T(&QE=F5L96ME
M="!T87)T86QM87KS("AS96YT+6UA:6PI(&UA<'#A:R`B"B)T]G)LZ7-R92!K
M97+\;&YE:RXB"@HC.B!A8VPN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L;'D@<F5M
M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(B(*(EPB)7-<(B!M87!P
MX6AO>B!T]G)TZ6[U(&AO>GKA9NERZ7-I(&IO9V]K870@<VEK97)E<V5N(&UE
M9W9O;G1U:R!<(B5S7"(@(@HB9F5L:&%S>F[A;/-T\VPN(@H*(SH@;&EB+V%P
M:2YP:'`Z-S8*;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A=&EO;C\B"FUS9W-T
M<B`B16YG961J_&L@;65G(&UA<'#A:R!LZ71R96AO>N%SX70_(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0X"FUS9VED(")!;&QO=R!F:6QT
M97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O>#\B"FUS9W-T
M<B`B02!S>OMRZ7-I('-Z86+A;'EO:V%T(&+A<FUE;'EI:R!M87!PX7)A(&5N
M9V5D:OQK(&%L:V%L;6%Z;FD_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R
M;F%T:79E+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T
M:&ES('-E8W1I;VXZ(@IM<V=S='(@(D5N;F5K(&$@<NES>FYE:R!A>B!A;'1E
M<FYA=.UV(';A;'1O>F%T86DZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4W,@IM<V=I9"`B06QW87ES(@IM<V=S='(@(FUI;F1I9R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-3<*;7-G:60@(D%L=V%Y<R!S879E(&%T=&%C
M:&UE;G1S(@IM<V=S='(@(DUI;F1I9R!M96YT<_QK(&5L(&$@;65L;.EK;&5T
M96ME="XB"@HC.B!L:6(O365S<V%G92YP:'`Z-34T"FUS9VED("(B"B)!;B!E
M<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T
M=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B
M(@HB2&EB82!T]G)TZ6YT(&$@;65L;.EK;&5T;F5K(&$@;&5VZ6QR]6P@=/9R
M=.EN]2!L97;A;&%S>G3A<V$@<V]RX6XN($%Z($E-05`@(@HB<WIE<G9E<B#\
M>F5N971E.B`B"@HC.B!L:6(O365S<V%G92YP:'`Z-#,W"FUS9VED(")!;B!U
M;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N
M;W1E+B(*;7-G<W1R(")!>B#Z:B!F96QJ96=Y>NES(&SI=')E:&]ZX7-A('-O
M<N%N('9A;&%M:2!H:6)A('3V<G3I;G0N(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C0S-@IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R
M96%T:6YG('1H92!N97<@=&%S:RXB"FUS9W-T<B`B07H@^FH@9F5L861A="!L
MZ71R96AO>N%S82!S;W+A;B!V86QA;6D@:&EB82!T]G)TZ6YT+B(*"B,Z(&UE
M<W-A9V4N<&AP.C4P-"!M86EL8F]X+G!H<#HW,#D@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHY"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS
M-0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C8*;7-G:60@(D%N
M<W=E<F5D(@IM<V=S='(@(FUE9W;A;&%S>F]L="(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM
M<V=S='(@(DUE9W;A;&%S>F]L="!L979E;&5K(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHW"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S
M='(@(DMA<&-S;VQJ=6L@8F4@82!S>OMR]6ME="(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<'!L
M>2!&:6QT97)S('1O("5S(@IM<V=S='(@(D%L:V%L;6%Z>G5K(&$@<WK[<O5K
M970@)7,M<F4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S8*
M;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_(@IM
M<V=S='(@(D$@<WK[<NES:2!S>F%BX6QY;VMA="!A(&)E:F5L96YT:V5ZZ7-K
M;W(@86QK86QM87IZ=6L_(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C0R"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"
M3U@@:7,@9&ES<&QA>65D/R(*;7-G<W1R("(B"B)!;&MA;&UA>GIU:R!A('-Z
M^W+I<VD@<WIA8N%L>6]K870@87H@24Y"3U@@;6%P<&$@;6EN9&5N(&UE9VIE
M;&5N[73I<V4@97-E=.EN/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE
M=&4@=&AI<R!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N/R(*;7-G<W1R(")"
M:7IT;W,L(&AO9WD@=/9R]FQN:2!A:V%R:F$@97IT('9I<G1UX6QI<R!M87!P
MX70_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(*;7-G<W1R(")":7IT;W,L
M(&AO9WD@=/9R]FQN:2!K[7;A;FIA(&5Z="!A(&YY:6QVX6YO<R!K=6QC<V]T
M/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M
M;65N9&5D(2DB"FUS9W-T<B`B0FEZ=&]S86X@=/9R]FQN:2!A:V%R:F$@82!S
M86KA="!K=6QC<W#A<FKA=#\@*$5Z($Y%32!A:N%N;&%T;W,A*2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&1O('1H:7,_(@IM<V=S='(@(D)I>G1O<RP@:&]G>2!E>G0@:^UVX6YJ
M82!T96YN:3\B"@HC.B!M97-S86=E+G!H<#HT,#D@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM
M<V=S='(@(D)I>G1O<RP@:&]G>2!6R4?)4E;)3EE%4T5.('3V<O9L;FD@:^UV
MX6YJ82!E>F5K970@82!L979E;&5K970_(@H*(SH@;&EB+TU)344O0V]N=&5N
M=',N<&AP.C(S.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%
M4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_(@IM<V=S='(@(D)I
M>G1O<RP@:&]G>2!6R4?)4E;)3EE%4T5.('3V<O9L;FD@:^UVX6YJ82!E>G0@
M82!M96QLZ6ML971E=#\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y
M('1H:7,@9F]L9&5R/R(*;7-G<W1R(")":7IT;W,L(&AO9WD@:VD@<WIE<F5T
M;ND@_'+M=&5N:2!E>G0@82!M87!PX70_(@H*(SH@;&EB+TE-4"YP:'`Z.30Y
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S
M<&%M(&9O;&1E<C\B"FUS9W-T<B`B0FEZ=&]S+"!H;V=Y(&MI('-Z97)E=&[I
M(/QR[71E;FD@82!S<&%M(&$@;6%P<.%T/R(*"B,Z(&QI8B])35`N<&AP.CDT
M,@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@
M=')A<V@@9F]L9&5R/R(*;7-G<W1R(")":7IT;W,L(&AO9WD@:VD@<WIE<F5T
M;ND@_'+M=&5N:2!A('-Z96UE=&5S("A4<F%S:"D@82!M87!PX70_(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M
M97-S86=E<S\B"FUS9W-T<B`B0FEZ=&]S(&%B8F%N+"!H;V=Y(';I9VQE9R!T
M]G+V;&YI(&OM=N%N:F$@97IE:V5T(&$@;&5V96QE:V5T/R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E;7!L871E<R]M86EL
M8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\B"FUS
M9W-T<B`B(@HB0FEZ=&]S+"!H;V=Y(&YE;7-P86UN96L@:^UVX6YJ82!M:6[U
M<^UT96YI(&5Z="!A(&QE=F5L970@82!L979E;&5Z]7)E;F1S>F5R("(*(G-Z
MX6WA<F$_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z
M-S4@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E
M(&%S('-P86T_(@IM<V=S='(@(B(*(D)I>G1O<RP@:&]G>2!S<&%M;F5K(&OM
M=N%N:F$@;6EN]7/M=&5N:2!E>G0@82!L979E;&5T(&$@;&5V96QE>O5R96YD
M<WIE<B`B"B)S>N%MX7)A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,#4*;7-G:60@(D%R<FEV86P@5&EM92(*;7-G<W1R("+)<FME>NES:2!I9/4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(P"FUS9VED(")!<V-E;F1I
M;F<B"FUS9W-T<B`B;O9V96MV]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-S$*;7-G:60@(D%S:R(*;7-G<W1R(")VX6QA<WIT:&%S<V%K(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<R"FUS9VED(")!='1A
M8V@@1FEL97,B"FUS9W-T<B`B1N%J;&]K(&-S871O;.%S82(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U,PIM<V=I9"`B071T86-H(&$@
M8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\B
M"FUS9W-T<B`B365L;.EK96QJ_&L@87H@UFX@4$=0(&YY:6QVX6YO<R!K=6QC
M<^%T(&$@;&5VZ6QH97H_(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C$Q,0IM<V=I9"`B071T86-H960@1FEL93HB"FUS9W-T<B`B0W-A=&]L="!F
MX6IL.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-C(@;&EB+T-O;7!O<V4N<&AP
M.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!='1A8VAE9"!F:6QE(%PB
M)7-<(B!E>&-E961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE
M($Y/5"!A='1A8VAE9"XB"FUS9W-T<B`B(@HB02!M96QLZ6ME;&YI(&OM=N%N
M="!<(B5S7"(@X6QL;VWA;FYY86P@=/IL;.EP;ND@82!M96QLZ6ML971E:R!M
MZ7)E=.ER92`B"B)V;VYA=&MO>O,@:V]R;.%T;VMA="X@07H@9N%J;'0@3D5-
M(&-S871O;'1U:RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S<W
M"FUS9VED(")!='1A8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q
M=65S="!Y;W4@<V5N="XB"FUS9W-T<B`B02!M96QLZ6ML971B96X@87H@UFX@
M:63U8F5O<WITX7-I(&OI<NESZ7)E(&%D;W1T(';A;&%S>B!V86XN(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-3`P('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FIS.C4U"FUS9VED(")!='1A8VAM96YT(@IM<V=S='(@(DUE;&SI:VQE="(*
M"B,Z(&%T=&%C:&UE;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D%T
M=&%C:&UE;G0@)7,@9&5L971E9"XB"FUS9W-T<B`B02AZ*2`E<R!M96QLZ6ML
M971E="!T]G+V;'3\:RXB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3$R-0IM<V=I
M9"`B071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R(")!(&UE;&SI:VQE
M=&5K(&%D871A:2(*"B,Z(&-O;7!O<V4N<&AP.C$Q,#4@;&EB+TUE<W-A9V4N
M<&AP.C4Q-0IM<V=I9"`B071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@
M871T86-H;65N="!T>7!E(@IM<V=S='(@(D$@;65L;.EK;&5T970@;&5VX6QA
M<WIT;W1T=6LZ(&%Z(&5R961E=&D@;65L;.EK;&5T('3M<'5S82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T.2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT-S`*(SH@;&EB+T-O;7!O<V4N<&AP.C$P.3,*
M;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S='(@(DUE;&SI:VQE=&5K(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W.`IM<V=I9"`B071T96YD965S
M(@IM<V=S='(@(E+I<WIT=F5V]6LB"@HC.B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HU,PIM<V=I9"`B071T96YT:6]N(@IM<V=S='(@(D9I
M9WEE;&UE>G1E=.ES(@H*(SH@;&EB+T%U=&@O:6UP+G!H<#HT-`IM<V=I9"`B
M075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]I;7`Z(&$@<WK\:^EG97,@24U!4"!B]7;M=/5F=6YK
M8VGS(&YE;2!T86SA;&AA=/,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8R.`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W(&EM86=E<R!I;B!(
M5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2`B"B)A9&1R
M97-S8F]O:S\B"FUS9W-T<B`B(@HB2F5L96[M='/\:RUE(&UE9R!A=71O;6%T
M:6MU<V%N(&$@2%1-3"!F;W)MX71U;?H@;&5V96QE:V)E;B!L97;U(&OI<&5K
M970L(&AA("(*(F$@9F5L863S(&UE9W1A;.%L:&%T\R!A>B#6;B!C[6UTX7+A
M8F%N/R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y
M.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(D$@
M<F5N9&5L:V5ZZ7-R92#A;&SS(&/M;6IE9WEZZ6ME:SHB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S$T"FUS9VED(")!=V%I=&EN9R!297-P;VYS
M92(*;7-G<W1R(")VX6QA<WIR82!VX7(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A8U]K('1O("5S(@IM<V=S='(@(E9I<W-Z7V$@)7,M:&5Z(@H*(SH@=&AR
M96%D+G!H<#HQ,S<@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"86-K('1O("5S(@IM<V=S
M='(@(E9I<W-Z82`E<RUH97HB"@HC.B!T:')E860N<&AP.C$S-`IM<V=I9"`B
M0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@B"FUS9W-T<B`B
M5FES<WIA(&$@;&5VZ6QL:7-TX6AO>B(*"B,Z('1H<F5A9"YP:'`Z,3,R"FUS
M9VED(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(E9I<W-Z82!A
M(&QO9VEK86D@;NEZ971H97HB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")"860@;&]G:6X@;F%M92!O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B27-M97)E=&QE;B!F96QH87-Z;N%L\VD@;NEV('9A
M9WD@:F5L<WKS+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L('!H
M<"UF;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R
M=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B2&EBX7,@24U!4"!P87)A;F-S
M+B!!('-Z97)V97(@=N%L87-Z83H@)7,B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C4W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"860@<F5Q=65S=#H@)7,N
M(@IM<V=S='(@(DAI8N%S(&QE:^ERZ7,Z("5S+B(*"B,Z(&UE<W-A9V4N<&AP
M.C(W-"!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,@HC.B!T
M96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(P(&QI8B]396%R8V@N
M<&AP.C8P,0IM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM<V=I9"`B0F5L;W<@:7,@=&AE(')A
M=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S<V%G92XB"FUS
M9W-T<B`B06SA8F(@;.%T:&%T\R!A('-TX71U<WH@:6YF;W)MX6-I\R!N>65R
M<RP@<WKV=F5G97,@=N%L=&]Z871A+B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(E1I;'3S;&ES
M=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")";&]C
M:R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E
M8VEF:6-A;&QY(')E<75E<W1E9#\B"FUS9W-T<B`B(@HB5&EL='-U:RUE(&QE
M(&$@2%1-3"!F;W)MX71U;?H@;&5V96QE:V)E;B!L97;U(&OI<&5K(&OI<NES
M(&[I;&O\;&DL("(*(F%U=&]M871I:W5S(&UE9VIE;&5N[73I<^ET/R(*"B,Z
M(&QI8B]396%R8V@N<&AP.C8P.0IM<V=I9"`B0F]D>2(*;7-G<W1R("),97;I
M;'3V<GIS(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I
M9"`B0F]T:"(*;7-G<W1R(")-:6YD:V5T=/4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C@T"FUS9VED(")";W1H($AE861E<B!,:7-T:6YG(&%N9"!"
M;V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B82!F96ILZ6-B96X@=F%L\R!F96QS
M;W)O;.%S(.ES(&$@;&5VZ6QT]G)Z<V)E;B!V86SS(&UE9VIE;&5N[73I<R!I
M<R(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3`Q"FUS9VED(")#4D%-+4U$
M-2!O<B!$24=%4U0M340U(')E<75I<F5S('1H92!!=71H7U-!4TP@<&%C:V%G
M92!T;R!B92!I;G-T86QL960N(@IM<V=S='(@(B(*(D$@0U)!32U-1#4@:6QL
M+B!A($1)1T535"U-1#4@:&%S>F[A;&%TX6AO>B!T96QE<.UT96YI(&ME;&P@
M87H@075T:%]305-,("(*(F-S;VUA9V]T+B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(W,@IM<V=I9"`B0U]H87)S970B"FUS9W-T<B`B
M7TMA<F%K=&5R:^ES>FQE="(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B3F%P=.%R(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N;W0@8V]N
M;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R(")!('3A
M=F]L:2!L979E;&5Z]7-Z97)V97(@;F5M(.ER:&5T]2!E;"XB"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C;VYN96-T
M('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R(")!('3A=F]L
M:2!L979E;&5Z]7-Z97)V97(@;F5M(.ER:&5T]2!E;#H@(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R
M=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT("(*(FUA:6QB;W@N
M(@IM<V=S='(@(B(*(DYE;2!J96QE;NUT:&5T]2!M96<@+2!A(&QE=NEL;F5K
M(&-S86L@)7,@9&%R86)JX70@=&%LX6QN:2!M96<@82AZ*2`E<RUB]6P@(@HB
M96)B96X@82!M87!PX6)A;BXB"@HC.B!F;VQD97)S+G!H<#HR-S`@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I
M;6%G92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC
M.C(Q('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O
M<&%S<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHV-@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(DWI9W-E(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#,R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHQ,3$*;7-G:60@(D-A;F-E;"!-97-S86=E(@IM<V=S='(@(DWI
M9W-E;2!K96QL(&5Z(&$@;&5VZ6PB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R
M961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*
M;7-G:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT
M;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(D$@:VELZ7#I<R!K
M]G9E=&ME>G3I8F5N(&4@;&5VZ6P@=&%R=&%L;6$@=NEG;&5G97-E;B!E;';I
M<WHN(@H*(SH@;65S<V%G92YP:'`Z,C<S('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S
M92YI;F,Z,34@;&EB+U-E87)C:"YP:'`Z-3DW"FUS9VED(")#8R(*;7-G<W1R
M(")#8R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G:60@
M(B(*(D-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE
M('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB"FUS
M9W-T<B`B(@HB02!T86[Z<^UT=N%N>2!N96T@:6UP;W)TX6QH873S+B!!('-Z
M97)V97)E;B!N:6YC<R!E;F=E9.EL>65Z=F4@87H@X6QL;VWA;GEO:R`B"B)F
M96QT]FQTZ7-E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.38*
M;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R(")%;&[V:R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(E;A;'1O>G1A=.%S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(E;A;'1O
M>G1A<W-U:R!M96<@87H@]G-S>F5S970B"@HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z.3(*;7-G:60@(D-H86YG92!&;VQD97(B"FUS9W-T<B`B3>%S:6L@
M;6%P<&$@:VEVX6QA<WITX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S
M(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"`B
M"B)H;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`B(@HB365G:F5L
M96[M=.ES:2!B9>%L;.UTX7-O:RP@<&PN(&QI<W3A>N%S:V]R(&CA;GD@;&5V
MZ6P@:V5R_&P@96=Y(&]L9&%L<F$L(&$@(@HB;&5V96QE:R!S;W)R96YD:F4@
M<W1B+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B0VAA
M;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@
M(D$@;&5V96QE>O5S>F5R=F5R+2!I;&PN(&UA<'!A8F7A;&SM=.%S;VL@;65G
M=N%L=&]Z=&%TX7-A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T
M=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P
M;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B(@HB07H@UFX@X6QT86P@96QK
M_&QD]G1T(&QE=F5L96ME;B!S>F5R97!L]2!NZ78L(&/M;2P@X6QL86YD\R!L
M97;I;';I9WKU9.ES("(*(BAS:6=N871U<F4I(&)EX6QL[73A<V$N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q,PIM<V=I9"`B0VAA<F%C=&5R<R!T
M;R!D:7-P;&%Y.B(*;7-G<W1R(")(X6YY(&MA<F%K=&5R="!M=71A<W-U;FL@
M82!L97;I;"!E;&5JZ7+U;#HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHQ-0IM<V=I9"`B0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I
M;"(*;7-G<W1R(")%;&QE;O5R:7IZ_&LL(&AO9WD@:O9T="UE(/IJ(&QE=NEL
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C<U"FUS9VED(")#:&5C
M:R!?06QL+TYO;F4B"FUS9W-T<B`B2F5L]FQJ_&L@:VD@;6EN9"]E9WEI:V5T
M('-E;2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ
M,"!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@
M(D-H96-K(&%L;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I
M;"!F<F]M.B(*;7-G<W1R(")*96SV;&IE(&MI+"!M96QY(&QE=F5L97KU<WIE
M<G9E<F5K<O5L(&OM=N%N(&QE=F5L96ME="#A='3V;'1E;FDZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0V,PIM<V=I9"`B0VAE8VL@<W!E;&QI;F<@
M8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R(")%;&QE;O5R:7IZ
M_&L@82!H96QY97/M<N%S="!A(&QE=NEL(&5L:_QL9.ES92!E;/5T=#\B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT"FUS9VED(")#:&]O
M<V4@06-T:6]N.B(*;7-G<W1R(")-:2!T]G)TZ6YJ96XZ(@H*(SH@8V]N9FEG
M+W-E<G9E<G,N<&AP+F1I<W0Z,C`R"FUS9VED(")#:&]O<V4@82!M86EL('-E
M<G9E<CHB"FUS9W-T<B`B5N%L87-S>F]N(&QE=F5L97KU<WIE<G9E<G0Z(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR,3<*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D
M:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R(")+Z7)E;2P@
M:&]G>2!J;V)B(&]L9&%L:2!M97KU8F5N(';A;&%S<WIA(&MI+"!V86=Y(&WS
M9&]S[71S83HB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS-#D*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W
M:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(DUE;'EI:R!C[6UJ96=Y
M>NEK970@:^UVX6YJ82!H87-Z;N%L;FD@^FH@8^UM96L@<O9G>NUTZ7/I<F4N
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"FUS
M9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A
M<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB02!C
M[6URZ7-Z;&5T('1E;&IE<R!C[6UMZ2!A;&%K[73A<V%K;W(@;6EL>65N('-O
M<G)E;F1B96X@:V5R97-S96X@82!GZ7`@82`B"B)C[6UJ96=Y>NEK96MB96XN
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3$U"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I
M;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N(@IM<V=S
M='(@(B(*(B5S(&MA='1I;G1S;VXL(&AA(&$@:^EP970@;VQY86X@9F]R;>%T
M=6UR82!K[7;A;FIA(&%L86OM=&%N:2P@86UI="!A("(*(F+V;F?I<WKU<')O
M9W)A;6IA(&UE9R!T=60@:F5L96[M=&5N:2XB"@HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HQ,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+B(*;7-G<W1R(")(82!L92!S>F5R
M971NZ2!T]FQT96YI(&$@:^EP970L(&MA='1I;G1S;VX@)7,N(@H*(SH@;&EB
M+T9I;'1E<BYP:'`Z,3,R"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S
M('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G92XB"FUS9W-T<B`B)7,@:V%T
M=&EN='-O;BP@:&$@)7,@;65N961Z<VUE;G0@;VQD86SA<F$@<WIE<F5T;F4@
M;65N;FDN(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B)7,@:V%T=&EN='-O
M;BP@82!(5$U,('1A<G1A;&]M(&O\;/9N(&%B;&%K8F%N('9A;/,@;65G:F5L
M96[M=.ESZ6AE>BXB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H
M=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R("(E<R!K871T:6YT<V]N
M+"!H82!A(&OI<&5T('!I8VEB96X@<WIE<F5T;ND@;.%T;FDN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R
M871E('=I;F1O=RXB"FUS9W-T<B`B)7,@:V%T=&EN='-O;BP@82!M96QLZ6ML
M970@:_QL]FX@86)L86MB86X@=F%L\R!M96=J96QE;NUTZ7/I:&5Z+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T
M960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B(@HB)7,@
M:V%T=&EN='-O;BP@82!M96QLZ6ML970@92!RZ7-ZZ6YE:R!K_&SV;B!A8FQA
M:V)A;B!V86SS(&UE9VIE;&5N[73I<^EH97HN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VAT;6PN<&AP.CDX"FUS9VED(")#;&EC:R!H97)E('1O(%-(3U<@=&AE
M($EM86=E<R(*;7-G<W1R(")+871T:6YT<V]N(&ED92!A(&OI<&5K(&UE9VIE
M;&5N[73I<^EH97HB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHS,C$*;7-G:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C
M=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@
M=&\@(@HB<V5A<F-H+B(*;7-G<W1R("(B"B)+871T:6YT<V]N(&%Z(&5G>6EK
M(&MI=N%L87-Z=&]T="!C[6UJ96=Y>NEK<F4L(&UA:F0@=N%L87-S>F$@:VDL
M(&AO9WD@;65L>6EK("(*(FUE>O5K8F5N('3V<G3I;FIE;B!K97)E<^ES+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,`IM<V=I9"`B0VQI8VL@
M=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*
M;7-G<W1R("(B"B)+871T:6YT<V]N(&ED92P@:&$@8^UM:F5G>7KI:^EB96X@
M96P@:^UVX6YJ82!TX7)O;&YI(&5Z="!A(%!'4"!N>6EL=N%N;W,@(@HB:W5L
M8W-O="(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C`R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC
M871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K(@IM<V=S='(@(B(*(DMA
M='1I;G1S;VX@82!-96YTZ7,@9F5L:7)A=')A+"!H82!C[6UJ96=Y>NEKZ6)E
M;B!E;"!K[7;A;FIA('3A<F]L;FD@)7,@4R\B"B)-24U%('1A;OIS[71VX6YY
MX70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Y"FUS9VED(")#;&EC
M:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G
M92!T;R!T:&4@<V5N9&5R(@IM<V=S='(@(D$@8^UM<F4@:V%T=&EN='9A(&$@
M^FH@;&5V96QE="#M<FAA='5N:R!A(&9E;&%D\VYA:R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-#`*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R
M97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D(@IM<V=S='(@
M(D$@8^UM<F4@:V%T=&EN='9A(&UE9VYY[6QI:R!A(&QE=NEL(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(X"FUS9VED(")#;&]S
M92(*;7-G<W1R(")"97KA<N%S(@H*(SH@8V]M<&]S92YP:'`Z-#$X"FUS9VED
M(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R(")!>B!A8FQA:R!B97KA<N%S
M82(*"B,Z(&9O;&1E<G,N<&AP.C0Q,`IM<V=I9"`B0VQO<V5D($9O;&1E<B(*
M;7-G<W1R("):X7)T(&UA<'!A(@H*(SH@9F]L9&5R<RYP:'`Z-#,P"FUS9VED
M(")#;VQL87!S92(*;7-G<W1R(")#<W5K:G5K(&)E(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z-#`*;7-G:60@(D-O;&QA<'-E($%L;"(*
M;7-G<W1R(")#<W5K:G5K(&)E(&%Z(/9S<WIE<V5T(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z-#`*;7-G:60@(D-O;&QA<'-E($%L;"!&
M;VQD97)S(@IM<V=S='(@(D-S=6MJ=6L@]G-S>F4@87H@]G-S>F5S(&UA<'#A
M="(*"B,Z(&9O;&1E<G,N<&AP.C0S,`IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R
M(@IM<V=S='(@(D-S=6MJ=6L@]G-S>F4@82!M87!PX70B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC
M871O<CH@(@IM<V=S='(@(E-Z[6YJ96SV;.ES.B`B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DUE9VIE
M9WEZZ7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8R"FUS9VED
M(")#;VUP;&5T960B"FUS9W-T<B`B8F5F96IE>G9E(@H*(SH@8V]M<&]S92YP
M:'`Z-#$W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S<V%G92(*;7-G<W1R
M("+::F%B8B!L97;I;"#M<N%S82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,S0*;7-G:60@(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W
M:6YD;W<_(@IM<V=S='(@(D$@;&5VZ6SM<N%S(&O\;/9N(&%B;&%K8F%N('3V
M<G3I;FKI:S\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,PIM<V=I
M9"`B(@HB0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E
M9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE("(*(F9E871U<F4I/R(*
M;7-G<W1R("(B"B),979E;&5I="!(5$U,+6)E;B!K[7;A;FIA(.UR;FD@86QA
M<.ER=&5L;65Z971T(&AE;'EZ971B96X@*&9E;'3I=F4L(&AO9WD@(@HB8O9N
M9^ES>O5P<F]G<F%M:F$@=.%M;V=A=&IA(&5Z="!A(&QE:&5T]7/I9V5T*3\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<*;7-G:60@(D-O;F9I9W5R
M92!H;W<@;65S<V%G97,@87)E(&1I<W!L87EE9"XB"FUS9W-T<B`B02!L979E
M;&5K(&UE9VIE;&5N[73I<^EN96L@8F7A;&SM=.%S86DN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")#;VYF:6=U<F4@;6%I;"!P<F5V
M:65W(&]P=&EO;G,N(@IM<V=S='(@(D5L]6[I>F5T:2`H;6%I;"!P<F5V:65W
M*2!B9>%L;.UTX7-O:RXB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM
M<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G
M<W1R(")!>B!)34%0('-Z97)V97(@;65G<WIA:^UT;W1T82!A(&MA<&-S;VQA
M=&]T+B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C,T"FUS9VED(")#
M;VYN96-T:6]N('1O('-E<G9E<B!F86EL960B"FUS9W-T<B`B02!S>F5R=F5R
M<F5L(&YE;2!V96AE=/4@9F5L(&$@:V%P8W-O;&%T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L
M(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B)7,@4$=0('3A;6]G873A
M<^%N86L@8F7A;&SM=.%S86DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%,O34E-12!S=7!P
M;W)T(&9O<B`E<RXB"FUS9W-T<B`B)7,@4R]-24U%('3A;6]G873A<^%N86L@
M8F7A;&SM=.%S86DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM
M<V=I9"`B0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E
M87)C:&EN9RXB"FUS9W-T<B`B02!L979E;&5K(&OV>O9T=&D@:V5R97/I<W-E
M;"!K87!C<V]L871O<R!B9>%L;.UTX7-O:RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O;G1R;VP@=VAE;B!N97<@;6%I;"!W
M:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T
M:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV97,N(@IM<V=S='(@(B(*(DUI:V]R
M(&5L;&5N]7)I>GK\:R#Z:B!L979E;&5K(.ER:V5ZZ7/I="P@Z7,@:V%P:F]N
M+64@Z7)T97/M=.ES="!A>B#Z:B`B"B)L979E;&5K(.ER:V5ZZ7-E:V]R+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-S0*;7-G:60@(D-O;G9E<G0@
M=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T
M<B`B(@HB07H@Z7)Z96QE;73\:W+V>O4@<WKV=F5G97,@:V%R86MT97)C<V]P
M;W)T;VMA="`H96UO=&EC;VYS+"!<(G-M:6QE>7-<(BD@(@HB8W-E<NEL:OQK
M(&=R869I:W5S(&EK;VYO:W)A/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHU,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")-X7-O;&IU:R#A="(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM<V=I9"`B0V]P>2!T;R!F
M;VQD97(B"FUS9W-T<B`B3>%S;VQJ=6L@:61E(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S='(@
M(DAI8N%T;&%N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`B2F%V[71O='0@
M<WKV=F5G(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E87-O
M;B!':79E;CH@)7,B"FUS9W-T<B`B02!KZ7+I<W0@;F5M('-I:V5R_&QT(';I
M9W)E:&%J=&%N:2X@07H@;VL@82!K]G9E=&ME>O4Z("5S(@H*(SH@871T86-H
M;65N="YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R
M96%T92!T:&4@5D93(&)A8VME;F0Z("5S(@IM<V=S='(@(D$@5D93(&CA='3I
M<G!R;V=R86T@;F5M(&AO>FAA=/,@;.ET<F4Z("5S(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS
M9W-T<B`B3F5M('-I:V5R_&QT("5S+6+U;"!T]G+V;&YI(&$@;&5V96QE:V5T
M+B!!('-Z97)V97(@_'IE;F5T93H@)7,B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z
M,S,S"FUS9VED(")#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R
M871I;VYS+B(*;7-G<W1R(").96T@<VEK97+\;'0@96QVZ6=E>FYI(&$@:V%R
M8F%N=&%R=.%S:2!F96QA9&%T;VMA="XB"@HC.B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U
M97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S
M='(@(D$@:^UVX6YT(.%L;&]MX6YY="!N96T@<VEK97+\;'0@:VEN>65R;FD@
M87H@35,M5$Y%1B!M96QLZ6ML971B]6PN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U
M97-T960@9FEL92!F<F]M('1H92!::7`@87)C:&EV92XB"FUS9W-T<B`B02!K
M[7;A;G0@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!K:6)O;G1A;FD@82!::7`@
M9N%J;&+S;"XB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0T-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!S96-U<F4@8V]N;F5C=&EO
M;B!T;R!T:&4@24U!4"!S97)V97(N("5S(#H@)7,N(@IM<V=S='(@(B(*(DYE
M;2!S:6ME<OQL="!A('1I=&MO<^UT;W1T(&MA<&-S;VQA="!F96QVZ71E;&4@
M87H@24U!4"!S>F5R=F5R<F5L+B`E<R`Z("5S+B(*"B,Z(&QI8B]397-S:6]N
M+G!H<#HR.#`*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!N86UE<W!A8V4@
M:6YF;W)M871I;VX@9G)O;2!)34%0('-E<G9E<BXB"FUS9W-T<B`B07H@24U!
M4"!S>F5R=F5R=/5L(&YE;2!S:6ME<OQL="!M96=K87!N:2!A(%PB;F%M97-P
M86-E7"(@861A=&]K870N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L+FEN8SHS.0HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,38Q"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3.ET
M<F5H;WKA<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C8*
M;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T<B`BVFH@;6%P<&$@;.ET<F5H
M;WKA<V$B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED(")#
M<F5A=&4@2V5Y<R(*;7-G<W1R(")+=6QC<W#A<B!LZ71R96AO>N%S82(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"FUS
M9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("+::B!A>F]N;W/M
M=/,@;.ET<F5H;WKA<V$B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"FUS
M9VED(")#<F5A=&4@82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B2&]Z>G5N
M:R!LZ71R92#Z:B!3<&%M(&UA<'#A="(*"B,Z('1E;7!L871E<R]P<F5F<R]F
M;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE
M8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<B(*
M;7-G<W1R(")(;WIZ=6YK(&SI=')E(/IJ(&UA<'#A="!A(&UU;FMA<.EL9.%N
M>6]K("AD<F%F=',I('-ZX6WA<F$B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C(V('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E
M;&5C="YI;F,Z-#(*;7-G:60@(D-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L
M9&5R(@IM<V=S='(@(DAO>GIU;FL@;.ET<F4@^FH@;6%P<.%T(&%Z(&5L:_QL
M9/9T="!L979E;&5K("AS96YT+6UA:6PI('-ZX6WA<F$B"@HC.B!T96UP;&%T
M97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]T
M<F%S:'-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!T<F%S:"!F
M;VQD97(B"FUS9W-T<B`B2&]Z>G5N:R!LZ71R92#Z:B`G4WIE;65T97,G("A4
M<F%S:"D@;6%P<.%T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R.`IM
M<V=I9"`B(@HB0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y
M;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"`B"B)A
M;F0@9&5L971E('-P86TN(@IM<V=S='(@(B(*(E-Z^W+U9F5L=.ET96QE:R!A
M9&AA=/-K(&UE9RP@;65L>65K:V5L(&$@8F7I<FME>O4@;&5V96QE:R!A=71O
M;6%T:6MU<V%N("(*(FUA<'#A:V)A(')E;F1E>FAE=/5K+B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-`IM<V=I9"`B0W)E871E(&YE
M=R!S=&%T:6]N97)Y(@IM<V=S='(@(MIJ(&QE=NEL<&%P[7(@;.ET<F5H;WKA
M<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED(")#<F5A
M=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S='(@(DQE
M=NEL<&%P[7(@=F%G>2!F;W)M86YY;VUT871VX6YY(&SI=')E:&]ZX7-A+B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G<W1R(")!*'HI("5S(&UA
M<'#A:&]Z('9A;/,@:F5L96YL96=I(&AO>GKA9NERZ7-I(&IO9V]S=6QT<^%G
M;VLZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I9"`B0W5S
M=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@;W1H97(@
M86-C;W5N=',N(@IM<V=S='(@(B(*(D$@;&5V96QE:R!I9&5G96X@;&5V96QE
M>O5S>F5R=F5R96MR]6P@=/9R=.EN]2#A='3V;'3I<^EN96L@8F7A;&SM=.%S
M86DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED(")#=7-T
M;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN(@IM<V=S='(@(D$@;&5VZ6QK_&QD
MZ7-S96P@:V%P8W-O;&%T;W,@8F7A;&SM=.%S;VLN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@HB
M36EL>65N('!A<F%N8W-O:R!F=7-S86YA:R!L92!A=71O;6%T:6MU<V%N(&$@
M)7-B92!T]G)TZ6[U(&)E:F5L96YT:V5ZZ7-K;W(N(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-PIM<V=I9"`B1&%T7V4B
M"FUS9W-T<B`B1.%T=6TB"@HC.B!M97-S86=E+G!H<#HR-S`@=&AR96%D+G!H
M<#HQ-3,*;7-G:60@(D1A=&4B"FUS9W-T<B`B1.%T=6TB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S4P"FUS9VED(")$96-L:6YE9"(*;7-G<W1R
M(")E;'5T87/M='9A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V
M-`IM<V=I9"`B1&5C;&EN960Z("(*;7-G<W1R(")%;'5T87/M='9A.B`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,W"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(D%L87#I<G1E;&UE>F5T="(*"B,Z('1E;7!L871E<R]P<F5F<R]D
M969A=6QT<V5A<F-H<V5L96-T+FEN8SHR,0IM<V=I9"`B1&5F875L="!396%R
M8V@@1FEE;&0B"FUS9W-T<B`B07H@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@
M:V5R97/I<VD@;65Z]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3(*
M;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`B02!S
M;W)B87)E;F1E>NES(&%L87#I<G1E;&UE>NES('-Z97)I;G1I('-Z96UP;VYT
M:F$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,@IM<V=I9"`B1&5F
M875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B02!S;W)B87)E;F1E
M>NES(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&ERX6YY83HB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S4X"FUS9VED(")$96QE9V%T960B"FUS
M9W-T<B`B;>%S;F%K(.%T861V82(*"B,Z(&9O;&1E<G,N<&AP.C0P,"!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHR-#0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]C;VUP;W-E
M+V%T=&%C:&UE;G1S+FEN8SHR.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,C<*;7-G:60@(D1E;&5T92(*;7-G<W1R(")4]G)LZ7,B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,@4'5B;&EC($ME>2(*
M;7-G<W1R(")4]G+V;&K\:R`E<R!N>6EL=N%N;W,@:W5L8W-O="(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C@U"FUS9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(D$@
M:F5L96YL96=I(&MU;&-S;VL@=/9R;.ES92(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.CD*;7-G:60@(D1E;&5T92!&;VQD97(H<RDB"FUS
M9W-T<B`B36%P<&$H:RD@=/9R;.ES92(*"B,Z(&9O;&1E<G,N<&AP.C(W,0IM
M<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B02!K:7;A
M;&%S>G1O='0@;6%P<.%K('3V<FSI<V4B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z-#(*;7-G:60@(D1E;&5T92!3=&%T:6]N97)Y(@IM
M<V=S='(@(E3V<O9L:OQK(&5Z="!A(&QE=NEL<&%P[7)T(@H*(SH@9F]L9&5R
M<RYP:'`Z-#`P"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD97(B"FUS9W-T
M<B`B5FER='7A;&ES(&UA<'!A('3V<FSI<V4B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]H96%D97(N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M92!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E<R(*;7-G<W1R(")!
M*'HI("5S('9I<G1UX6QI<R!M87!P82!T]G)LZ7-E+B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L971E(&9E=&-H
M960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G<W1R(")4]G+V
M;&K\:R!A('3A=F]L:2!S>F5R=F5R<O5L(&%Z(.%T:&]Z;W1T(&QE=F5L96ME
M=#\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$Y"FUS9VED(")$
M96QE=&4@9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R(")4]G+V;&K\:R!A(&YA
M<'3A<F%M8O-L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I
M9"`B1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG
M(&]F(&UO;G1H/R(*;7-G<W1R("(B"B)4]G+V;&K\:R!A(&CS;F%P(&5L96KI
M;B!A('+I9VDL(&AI=F%T:V]ZX7,@9F]R;>%JX6)A;B!K_&QD]G1T(&UE;&SI
M:VQE=&5K("(*(G3I;GEL96=E<R!PZ6QDX6YY86ET/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-3`*;7-G:60@(D1E;&5T92!O;&0@<V5N="UM86EL
M(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R("(B"B)4
M]G+V;&K\:R!A('+I9VD@96QK_&QD]G1T(&QE=F5L96ME="`H<V5N="UM86EL
M*2!T87)T86QM87KS(&UA<'#A:V%T(&$@:/-N87`@(@HB96QE:NEN/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#4*;7-G:60@(D1E;&5T92!S<&%M
M(&UE<W-A9V5S(@IM<V=S='(@(E3V<O9L:OQK(&$@<W!A;2!L979E;&5K970B
M"@HC.B!M97-S86=E+G!H<#HU,#<@;6%I;&)O>"YP:'`Z-S,U('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C`*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C@*
M;7-G:60@(D1E;&5T960B"FUS9W-T<B`B=/9R]FQT(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B1&5L971E9"!M97-S86=E<R(*
M;7-G<W1R(")4]G+V;'0@;&5V96QE:R(*"B,Z(&-O;7!O<V4N<&AP.C4W,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB
M)7-<(BXB"FUS9W-T<B`B02!<(B5S7"(@;65L;.EK;&5T970@=/9R]FQT_&LN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN
M9R!A;F0@36]V:6YG($UE<W-A9V5S(@IM<V=S='(@(D$@;&5V96QE:R!T]G)L
MZ7-E(.ES(.%T:&5L>65ZZ7-E(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4X-PIM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(F5L=71A<^UT
M;VT@82!M96=H[7;A<W0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-30R"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;B(*;7-G<W1R(")!>B!I9/5B96]S>G3A<VD@861A=&OI<NES(&5L=71A
M<^UTX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I9"`B
M1&5S8V5N9&EN9R(*;7-G<W1R(")C<_9K:V5N]2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C8V"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("),9>URX7,B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S<*;7-G:60@(D1E=&%I;',B"FUS9W-T<B`B4NES>FQE=&5S96XB"@HC
M.B!C;VUP;W-E+G!H<#HU.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ED(&YO
M="!A='1A8V@@7"(E<UPB(&%S('1H92!F:6QE('=A<R!E;7!T>2XB"FUS9W-T
M<B`B7"(E<UPB(&YE;2!K97+\;'0@8W-A=&]LX7-R82P@;65R="!A>B#A;&QO
M;>%N>2#\<F5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C4*;7-G
M:60@(D1I;2!S:6=N871U<F5S/R(*;7-G<W1R(")!>B#A;&QA;F3S(&QE=NEL
M=NEG>O5DZ7,@*'-I9VYA='5R92D@:&%L=N%N>6%N(&IE;&5N:F5N(&UE9S\B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I
M9"`B1&ES<&QA>2(*;7-G<W1R(")-96=J96QE;NUTZ7,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#<Y"FUS9VED(")$:7-P;&%Y(&-O;F9I<FUA=&EO
M;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B02!L97;I;"!E
M;&O\;&3I<V4@=73A;B!J96QE;FIE;B!M96<@96=Y(&5Z="!M96=E<O5S[73U
M(/QZ96YE=#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@S"FUS9VED
M(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R(")A(&QE=NEL
M=/9R>G-B96X@=F%L\R!M96=J96QE;NUTZ7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S@Q"FUS9VED(")$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I
M;VX@;V8@;F5W(&UA:6P_(@IM<V=S='(@(MIJ(&QE=NEL(.ER:V5ZZ7/I<O5L
M(&O\;/9N(&9E;&)U:VMA;O,@86)L86MB86X@:^ER(.ER=&5S[73I<W0_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T-PIM<V=I9"`B1&ES<&QA>2!T
M:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T
M<B`B3&5G>65N(&5G>2!<(E-P86T@;6%P<&$@_'+M=.ES7"(@<&]N=&IA(&$@
M;65N_'-O<FYA:S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,Y"FUS
M9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@
M;65N=6)A<C\B"FUS9W-T<B`B3&5G>65N(&5G>2!<(E-Z96UE=&5S(&UA<'!A
M(/QR[73I<UPB('!O;G1J82!A(&UE;OQS;W)N86L_(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$Q"FUS9VED(")$:7-P;W-I=&EO
M;B(*;7-G<W1R(")%;&AE;'EE>NES(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F
M:65L9',N:6YC.C(V"FUS9VED(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`B3D4@
M;&5G>65N(&)E;FYE(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,38*;7-G:60@(D1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-
M86EL(@IM<V=S='(@(DYE(&5L;&5N]7)I>GK\:RP@:&]G>2!J]G1T+64@^FH@
M;&5VZ6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30Q"FUS9VED(")$
M;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS
M9W-T<B`B02!&96QA9/,@;W-Z;&]P<F$@:V%T=&EN='9A(&YE('3V<G3I;FIE
M;B!S96UM:2(*"B,Z(&QI8B])35`N<&AP.C$P-3,*;7-G:60@(D1O('EO=2!W
M86YT('1O(&]P96X@=&AA="!F;VQD97(_(@IM<V=S='(@(DUE9R!K[7;A;FIA
M(&YY:71N:2!A(&UA<'#A=#\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(S,0IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+B(*;7-G<W1R(").:6YC<R!MZ6<@;&]G:6X@;F5V93\@26?I;GEE;&IE;B!E
M9WEE="XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(V
M"FUS9VED(")$;VYE(@IM<V=S='(@(DOI<WHB"@HC.B!L:6(O34E-12]#;VYT
M96YT<RYP:'`Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S
M(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(E3V;'1S_&L@;&4@)7,M="`N>FEP
M(&9O<FWA='5M8F%N+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ
M:7`@9FEL92DB"FUS9W-T<B`B07H@]G-S>F5S(&UE;&SI:VQE="!L973V;'3I
M<V4@*&5G>2`N>FEP(&;A:FQB82DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR,`IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S
M='(@(E3V;'1S_&L@;&4@82!M87!PX2AK82ET(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS
M*2!;+GII<"!F;W)M871=(@IM<V=S='(@(E3V;'1S_&L@;&4@82!M87!PX2AK
M82ET("AE9WD@+GII<"!FX6IL8F$I(@H*(SH@;&EB+TU)344O0V]N=&5N=',N
M<&AP.C(Q-@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M870B"FUS9W-T
M<B`B5/9L='/\:R!L92`N>FEP(&9O<FWA='5M8F%N+B(*"B,Z(&UE<W-A9V4N
M<&AP.C4P-2!M86EL8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHQ,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C(R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHY"FUS9VED(")$<F%F="(*
M;7-G<W1R(")M=6YK87#I;&3A;GDB"@HC.B!F;VQD97)S+G!H<#HS-S,*;7-G
M:60@(D1R869T(&9O;&1E<B(*;7-G<W1R(")-=6YK87#I;&3A;GD@;6%P<&$B
M"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I
M9"`B1')A9G1S(&9O;&1E<CHB"FUS9W-T<B`B375N:V%PZ6QDX6YY(&UA<'!A
M.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#@*;7-G:60@(D4M;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D5M86EL(&/M;2(*"B,Z(&QI8B]-86EL8F]X
M+G!H<#HS,#(*;7-G:60@(D5.1"(*;7-G<W1R(")6R4=%(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2.B!9;W5R(&UE
M<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B2$E"03H@
M;&5V96SI="!N96T@<VEK97+\;'0@:^EZ8F5S[71E;FDN(@H*(SH@9F]L9&5R
M<RYP:'`Z-#`Q('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ.0IM
M<V=I9"`B161I="(*;7-G<W1R(")-\V1O<^UTX7,B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM
M<V=S='(@(D$@=&EL=/-L:7-T82!M\V1O<^UTX7-A(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C$S"FUS9VED(")%9&ET($9I;'1E<G,B"FUS
M9W-T<B`B02!S>OMR]69E;'3I=&5L96L@;?-D;W/M=.%S82(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C$V"FUS9VED(")%9&ET(%-E87)C:"!1=65R>2(*;7-G<W1R
M(")!(&ME<F5SZ7,@;?-D;W/M=.%S82(*"B,Z(&9O;&1E<G,N<&AP.C0P,2!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3<*;7-G:60@(D5D:70@5FER
M='5A;"!&;VQD97(B"FUS9W-T<B`B5FER='7A;&ES(&UA<'!A(.%T9&5F:6YI
MX6SA<V$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI
M=&EO;B!F;W(@)7,B"FUS9W-T<B`B02AZ*2`E<R!V:7)T=>%L:7,@;6%P<&$@
MX71D969I;FGA;.%S82XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(D%Z(&5N9V5D
MZ6QY97KI<VD@;&ES=&$@;?-D;W/M=.%S82(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*
M;7-G<W1R(")!>B#6;B!T:6QT\VQI<W3A:N%N86L@;?-D;W/M=.%S82(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM<V=I9"`B161I="!Y
M;W5R(&9I;'1E<B!R=6QE<R(*;7-G<W1R(")!('-Z^W+U9F5L=.ET96QE:R!M
M\V1O<^UTX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U,`IM<V=I
M9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@
M;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B02!K_&QS]2!S>F5R=F5R96MR]6P@
M=/9R=.EN]2!L97;I;.%T=/9L=.ES(&)EX6QL[73A<V%I+B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHR,PIM<V=I9"`B161I="!Y;W5R('=H
M:71E;&ES="(*;7-G<W1R(")!>B!E;F=E9.EL>65ZZ7-I(&QI<W1A(&WS9&]S
M[73A<V$B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S
M.0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%;6%I;"!C[6TB"@HC
M.B!L:6(O365S<V%G92YP:'`Z-CDW"B,L('!H<"UF;W)M870*;7-G:60@(D5M
M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(D%Z(/9S<WIE
M<R!L979E;&5T('3V<O9L=/QK("5S+6+U;"XB"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C<S"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M(%9I<G1U
M86P@5')A<V@@1F]L9&5R+B(*;7-G<W1R(")!('9I<G1UX6QI<R!S>F5M971E
M<VUA<'#A="!K:?QR[71E='3\:RXB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR,@IM<V=I9"`B16UP='D@1F]L9&5R*',I(@IM<V=S='(@
M(MQR[71S_&L@:VD@82!M87!PX2AK82ET(@H*(SH@9F]L9&5R<RYP:'`Z,C<R
M"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(MQR[71S
M_&L@:VD@82!K:7;A;&%S>G1O='0@;6%P<.%K870B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@9F]L
M9&5R(@IM<V=S='(@(MQR[71S_&L@:VD@82`G4WIE;65T97,G("A4<F%S:"D@
M;6%P<.%T(@H*(SH@;&EB+TE-4"YP:'`Z.30Y"FUS9VED(")%;7!T>2!?4W!A
M;2(*;7-G<W1R(")!(%-P86T@;6%P<&$@_'+M=.ES92(*"B,Z(&QI8B])35`N
M<&AP.CDT,@IM<V=I9"`B16UP='D@7U1R87-H(@IM<V=S='(@(D$@<WIE;65T
M97,@;6%P<&$@_'+M=.ES92(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@
M4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(D%K=&EVX6QJ=6L@82!01U`@
M<WIO;&?A;'1A=.%S;VMA=#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B
M16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")!:W1I=N%L
M:G5K(&%Z(%,O34E-12!S>F]L9^%L=&%TX7-O:V%T/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,#`*;7-G:60@(D5N86)L92!M97-S86=E('!R979I
M97=S/R(*;7-G<W1R(")3>F5R971N92!B96QE;NEZ;FD@82!L979E;&5K8F4@
M86[I;&O\;"P@:&]G>2!RX6IU:R!K871T:6YT86YA/R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S.0IM<V=I9"`B16YC<E]Y<'1I;VX@
M3W!T:6]N<R(*;7-G<W1R(")47VET:V]S[73A<VD@8F7A;&SM=.%S;VLB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$X"FUS9VED(")%;F-R
M>7!T960B"FUS9W-T<B`B5&ET:V]S[71O='0@861A="(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,38@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4Q.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4Q(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-3,*;7-G:60@(D5N9"(*;7-G<W1R(")6Z6<B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,SDU"FUS9VED(")%;F0@9F]R=V%R9&5D
M(&UE<W-A9V4B"FUS9W-T<B`B5NEG92!A('1O=N%B8NUT;W1T(/QZ96YE=&YE
M:R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-3(*;7-G:60@(D5N9"!M97-S86=E
M(@IM<V=S='(@(D$@;&5VZ6P@=NEG92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YD(&UE<W-A9V4@9G)O;2`E<R(*
M;7-G<W1R("(E<R!L979E;.EN96L@=NEG92(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED
M(")%;G1E<B!087-S<&AR87-E(@IM<V=S='(@(D$@:F5L;6]N9&%T(&UE9V%D
MX7-A(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.CD*;7-G
M:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<B(*
M;7-G<W1R(")!9&IA(&UE9R!A>B#Z:B!3<&%M(&UA<'!A(&YE=NET(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B16YT
M97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T
M<B`B061J82!M96<@82!M=6YK87#I;&3A;GEO:R`H9')A9G1S*2!LZ71R96AO
M>F%N9/,@^FH@;6%P<.%JX6YA:R!N97;I="(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@(D5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(B(*(D%D
M:F$@;65G(&%Z(&5L:_QL9/9T="!L979E;&5K("AS96YT+6UA:6PI(&SI=')E
M:&]Z86YD\R#Z:B!M87!PX6KA;F%K(&YE=NET(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W1R87-H<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(D%D:F$@;65G(&%Z
M(/IJ("=3>F5M971E<R<@*%1R87-H*2!M87!P82!N97;I="(*"B,Z(&QI8B]3
M96%R8V@N<&AP.C8Q,PIM<V=I9"`B16YT:7)E($UE<W-A9V4B"FUS9W-T<B`B
M02!T96QJ97,@;&5VZ6PB"@HC.B!M97-S86=E+G!H<#HQ.34@8V]M<&]S92YP
M:'`Z,3$W,B!T:')E860N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D5N
M=')Y(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B02!C[6UJ96=Y>NEK:&5Z('-I:V5R97-E;B!H
M;WIZX6%D='5K(%PB)7-<(BUT+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,S@Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C,Y,`HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@
M(DAI8F$B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0S,2!L:6(O24U!4"]#
M;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C;VYN
M96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R(")!>B!)
M34%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"X@)7,@.B`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,S$P(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R
M97!L>3H@)7,N(@IM<V=S='(@(DAI8F$@=/9R=.EN="!A(';A;&%S>B!K_&QD
MZ7-E:V]R.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#(*
M;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")!
M>B!E<V5MZ6YY="!S:6ME<F5S96X@=/9R]FQT_&LN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<W,0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G
M<W1R("(Q-2!P97)C96YKZ6YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<V.`IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("(S,"!MX7-O
M9'!E<F-E;FOI;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<P"FUS
M9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B-2!P97)C96YKZ6YT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W,@IM<V=I9"`B179E<GD@:&%L
M9B!H;W5R(@IM<V=S='(@(F;I;/-RX6YKZ6YT(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<V.0IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(G!E
M<F-E;FOI;G0B"@HC.B!F;VQD97)S+G!H<#HT,S@*;7-G:60@(D5X<&%N9"(*
M;7-G<W1R(").>6ES<W5K('-ZZ70B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHS.0IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R(").>6ES
M<W5K('-ZZ70@87H@]G-S>F5S970B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHS.0IM<V=I9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S
M='(@(DYY:7-S=6L@<WKI="!A>B#V<W-Z97,@;6%P<.%T(@H*(SH@9F]L9&5R
M<RYP:'`Z-#,X"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(DYY:7-S
M=6L@<WKI="!A(&UA<'#A="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,T,"!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3,*
M;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R(")!(&/M;7+I<WIL970@=&5L
M:F5S<^D@96?I<WKM=.ES92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#4R"FUS9VED(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W
M(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(D5G
MZ7-Z[71S_&LM92!K:2!A(&YE=F5K970@875T;VUA=&EK=7-A;B!L97;I;.UR
MX7,@:_9Z8F5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-CD*;7-G
M:60@(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@
M:6X@=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T<B`B02!M87!PX6L@;NEZ973I
M8F5N('+V9W3V;B!K:6YY:71V82!J96QE;FIE;B!M96<@87H@]G-S>F5S(&UA
M<'!A/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$T-"!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ.30*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C0U('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHQ,#$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S95]E
M>'!A;F0N:G,Z-#D*;7-G:60@(D5X<&%N9&EN9R(*;7-G<W1R(")#[6URZ7-Z
M;&5T(&MI96?I<WKM=.ES92XN+B(*"B,Z(&QI8B])35`N<&AP.CDV,"!L:6(O
M24U0+G!H<#HY-C(*;7-G:60@(D9?971C:"!-86EL(@IM<V=S='(@(DQE=F5L
M96L@X71T]FQTZ7-E(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA
M:6PN:6YC.C(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@(D9E
M=&-H($UA:6PB"FUS9W-T<B`B3&5V96QE:R#A='3V;'3I<V4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#4X"FUS9VED(")&971C:"!-86EL(&EN(&$@
M<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")!(&QE=F5L96L@X71T]FQTZ7-E
M(&O\;/9N(&%B;&%K8F%N('3V<G3I;FKI:S\B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-#8*;7-G:60@(D9E=&-H(&UE<W-A9V5S('5P
M;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`B0F5J96QE;G1K97KI<VMO<B!A=71O
M;6%T:6MU<V%N(&EN9'5L:F]N(&UE9R!A(&QE=F5L96L@X71T]FQTZ7-E/R(*
M"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(Y,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&971C:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,B"FUS9W-T<B`B)60@;&5V
MZ6P@=/9L=/5D]G1T(.%T("5S+7+U;"XB"@HC.B!L:6(O1F5T8VAM86EL+G!H
M<#HR.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@
M9G)O;2`E<R(*;7-G<W1R("(Q(&QE=NEL('3V;'3U9/9T="#A="`E<RUR]6PN
M(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP
M.C(X.2!L:6(O1F5T8VAM86EL+G!H<#HR.3$*;7-G:60@(D9E=&-H;6%I;#H@
M(@IM<V=S='(@(DQE=NELX71T]FQTZ7,Z("(*"B,Z(&QI8B]&971C:&UA:6PN
M<&AP.C(Y,PIM<V=I9"`B1F5T8VAM86EL.B!N;R!N97<@;65S<V%G97,N(@IM
M<V=S='(@(DQE=NELX71T]FQTZ7,Z(&YI;F-S(/IJ(&QE=F5L92XB"@HC.B!L
M:6(O24U0+G!H<#HY-C8*;7-G:60@(D9I7VQT97)S(@IM<V=S='(@(E-Z^W+U
M:R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-B!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHT,`IM<V=I9"`B1FEL92(*
M;7-G<W1R(")&X6IL(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C,Q"FUS9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(")3>OMRZ7-I(&)E
MX6QL[73A<V]K(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.CD*
M;7-G:60@(D9I;'1E<B!3971T:6YG<R(*;7-G<W1R(")3>OMR]69E;'3I=&5L
M96LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@X"FUS9VED(")&:6QT
M97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_(@IM<V=S='(@(E-Z
M^W)J_&L@:VD@82!K]GKV;G/I9V5S("AP<F]FX6XI(&MI9F5J97KI<V5K970@
M82!L979E;&5K('1A<G1A;&WA8O-L/R(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+VYO=&%C=&EV92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")%>B!A(')E;F1S>F5R
M(&YE;2!TX6UO9V%T:F$@82!L97;I;'-Z^W+I<W0N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")3>OMR
M]6LB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C,*;7-G
M:60@(D9I;'1E<G,@3D]4($%C=&EV92(*;7-G<W1R(")!('-Z^W+U:R!K:2!V
M86YN86L@:V%P8W-O;'9A(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G92(*
M;7-G<W1R(")3>OMR]6LZ("5S(&WS9&]S[73A<VD@;VQD86PB"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN9"(*
M;7-G<W1R(")+97)E<^ES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y
M-`IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E(@IM<V=S='(@(D$@;6%P<&$@
M96QS]2!O;&1A;&$B"@HC.B!M86EL8F]X+G!H<#HS,S$*;7-G:60@(D9I<G-T
M(%!A9V4B"FUS9W-T<B`B16QS]2!O;&1A;"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]?<G=A<F0B"FUS9W-T<B`B5&]VX5]B
M8NUTX7,B"@HC.B!F;VQD97)S+G!H<#HR-3(@=&5M<&QA=&5S+V9O;&1E<G,O
M9F]L9&5R<U]C;VYF:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@
M+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B02!M87!PX6MO;B!VZ6=Z971T(&W[
M=F5L970@;65G97+U<^UTZ7-E(@H*(SH@9F]L9&5R<RYP:'`Z,C@Y('1E;7!L
M871E<R]F;VQD97)S+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN
M:71I86QP86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET
M:6%L<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T;W(B
M"FUS9W-T<B`B36%P<.%K(&ME>F5LZ7-E(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C,*;7-G:60@(D9O;&1E<B!3=6UM87)Y(@IM<V=S='(@(DUA<'!A
M(/9S<WIE9F]G;&%LX7,B"@HC.B!A8VPN<&AP.C(S"FUS9VED(")&;VQD97(@
M<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B(@HB3FEN8W,@;65G
M96YG961V92P@:&]G>2!MX7,@9F5L:&%S>F[A;/-K;F%K(&AO>GKA9NERZ7-I
M(&IO9V]T(&%D:G5N:R`B"B)M87!PX6EN:VAO>BXB"@HC.B!F;VQD97)S+G!H
M<#HT-PIM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T
M<B`B02!M87!PX6L@:&%S>F[A;&%T82!N:6YC<R!M96=E;F=E9'9E+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3@*;7-G:60@(D9O<FUA="!O9B!M
M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S
M(&1A=&5D('1O9&%Y(@IM<V=S='(@(D%Z(&%Z;F%P(&MA<&]T="!L979E;&5K
M(.ER:V5ZZ7-I(&ED]7!O;G1JX6YA:R!F;W)MX71U;6$B"@HC.B!C;VUP;W-E
M+G!H<#HX,C`@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$U"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED
M(")&;W)W87)D(@IM<V=S='(@(E1O=N%B8NUTX7,B"@HC.B!C;VUP;W-E+G!H
M<#HX,#4*;7-G:60@(D9O<G=A<F0Z(@IM<V=S='(@(E1O=N%B8NUTX7,Z(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C,X,`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A
M9V4B"FUS9W-T<B`B5&]VX6)B[71O='0@;&5VZ6PB"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,S<X"B,L('!H<"UF;W)M870*;7-G:60@(D9O<G=A<F1E9"!M97-S
M86=E(&9R;VT@)7,B"FUS9W-T<B`B5&]VX6)B[71O='0@;&5VZ6P@)7,@8^UM
M<O5L(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P,@IM<V=I9"`B
M1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4B"FUS9W-T<B`B5N%L87-Z(&5L
M9F]G;&%L='/A9VD@:^ER9.ES<F4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C(W"FUS9VED(")&<F]?;2(*;7-G<W1R(")&
M96QA9/,B"@HC.B!M97-S86=E+G!H<#HR-S$@=&AR96%D+G!H<#HQ-30@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.3D*(SH@;&EB+U-E87)C:"YP
M:'`Z-3@Y"FUS9VED(")&<F]M(@IM<V=S='(@(D9E;&%D\R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G
M<W1R(")!(&9E;&%D\R!C[6UE(@H*(SH@8V]M<&]S92YP:'`Z.#$W(&-O;7!O
M<V4N<&AP.C@R,0IM<V=I9"`B1G=D.B(*;7-G<W1R(")&=V0Z(@H*(SH@8V]M
M<&]S92YP:'`Z,3,Q,0IM<V=I9"`B1G=D.B`B"FUS9W-T<B`B(@H*(SH@8V]M
M<&]S92YP:'`Z,3,Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O
M<G=A<F1E9"!-97-S86=E<R(*;7-G<W1R(")&=V0Z("5U('1O=N%B8NUT;W1T
M(/QZ96YE="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1V5N97)A;"!/<'1I
M;VYS(@IM<V=S='(@(L%L=&%LX6YO<R!B9>%L;.UTX7-O:R(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS-PIM<V=I9"`B1V5T(&]N;'D@
M;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*2(*;7-G<W1R(")#<V%K(&%Z(/IJ
M(&QE=F5L96ME="!H;WIZ=6L@X70_("AC<V%K($E-05`I(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S(@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4U-`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S(X"FUS
M9VED(")';R(*;7-G<W1R(")-96AE="(*"B,Z('1H<F5A9"YP:'`Z,3,V"FUS
M9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@(D$@;&5VZ6QH97HB"@HC.B!L
M:6(O24U0+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V\@=&\@861D
M<F5S<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R(")-96YJ_&YK(&$@
M:_9V971K97KU(&/M;6IE9WEZZ6L@861A=&AO>CH@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-@IM<V=I9"`B1W)A;G0@86-C97-S(@IM
M<V=S='(@(DIO9V]S=6QT<^%G(&%DX7-A(@H*(SH@;65S<V%G92YP:'`Z-34P
M(&QI8B]&:6QT97(N<&AP.C$S,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ,#0*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3$Q(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C$Q,PHC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0HC
M.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-
M12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6:65W
M97(O<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT
M,C,*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HQ-S(*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM
M<V=I9"`B2$5212(*;7-G<W1R("))5%0B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R
M,`HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA4
M34PB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,C8P"FUS9VED(")(5$U,
M(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R(")!(&QE=NEL($A434P@=N%L
M=&]Z871A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`B1F5J;.EC(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M
M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B271T(&%Z(-9N
M(.%L=&%L(&9O9V%L;6%Z;W1T(&QE=NEL.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-38*;7-G:60@(DAI9&1E;B(*;7-G<W1R(")N92!M=71A<W-S
M=6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4U"FUS9VED(")(:61D
M96X@:6X@5&AR96%D(%9I97<B"FUS9W-T<B`B;&]G:6MA:2`H=&AR96%D*2!N
MZ7IE=&)E;B!N92!M=71A<W-U:R(*"B,Z(&UA:6QB;W@N<&AP.C,U,PIM<V=I
M9"`B2&ED92!$96QE=&5D(@IM<V=S='(@(D$@=/9R]FQT96ME="!N92!M=71A
M<W-U:R(*"B,Z(&9O;&1E<G,N<&AP.C(X-`IM<V=I9"`B2&ED92!5;G-U8G-C
M<FEB960B"FUS9W-T<B`B02!H87-Z;N%L871O;B!K[7;\;"!H96QY97IE='0@
M*'5N<W5B<V-R:6)E9"D@;6%P<.%K870@;F4@;75T87-S=6LB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B"FUS
M9W-T<B`B;F%G>2(*"B,Z(&UE<W-A9V4N<&AP.C,P-2!M86EL8F]X+G!H<#HW
M,3D@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,@IM<V=I9"`B2&EG
M:"!0<FEO<FET>2(*;7-G<W1R(")3_')G]7,B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T<B`B
M;&5G;F%G>6]B8B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#4*;7-G
M:60@(DAO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/R(*
M;7-G<W1R(")(;V=Y86X@:^UVX6YJ82!M96=J96QE;NUT=&5T;FD@82!M96QL
MZ6ML971E:V5T/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*;7-G
M:60@(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB
M"FUS9W-T<B`B5N%L87-Z;VSA<VMO<B!H;V=Y86X@:F5L97IZ_&LL(&AO9WD@
M:VET]6P@:63I>G3\;FLB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$S
M-`IM<V=I9"`B24U!4"(*;7-G<W1R("))34%0(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O
M8V]L<RDB"FUS9W-T<B`B24U!4"`H875T;VUA=&EK=7,@<')O=&]K;VQL(&UE
M9VAA=.%R;WKA<W-A;"DB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@=&AE(&-O
M;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(D%Z($E-
M05`@<WIE<G9E<B!M96=S>F%K[71O='1A(&$@:V%P8W-O;&%T;W0N($$@<WIE
M<G9E<B!VX6QA<WIA.B`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,38U(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0
M(&]V97(@4U-,(@IM<V=S='(@(DE-05`@4U-,(&;V;/9T="(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,34R"FUS9VED("))34%0(&]V97(@4U-,("AS
M96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B24U!4"!34TP@9O9L
M]G1T("CV;G1A;OIS[71VX6YN>6%L*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,38V"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE
M9"DB"FUS9W-T<B`B4U-,(&;V;/9T="`H]FYT86[Z<^UT=N%N;GEA;"DB"@HC
M.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!4"!S97)V97(@
M8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R(")!>B!)34%0('-Z97)V
M97(@;65G<WIA:^UT;W1T82!A(&MA<&-S;VQA=&]T+B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,38T(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,30P"FUS9VED("))34%0+"!N;R!43%,B"FUS9W-T<B`B24U!4"P@5$Q3(&[I
M;&O\;"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z-#D*;7-G:60@(DE-
M05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B24U!4"]03U`S(&QE=F5L
M97KU<WIE<G9E<F5K(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT,3$*;7-G
M:60@(DEF('5S:6YG(%-33"!O<B!43%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(
M4"!O<&5N<W-L(&5X=&5N<VEO;B!L;V%D960N(@IM<V=S='(@(B(*(D%Z(%-3
M3"!V86=Y(%133"!H87-Z;N%L873A:&]Z(&$@4$A0(&]P96YS<VP@8O5V[73I
M<^EN96L@8F4@:V5L;"!T]FQT]61N:64N(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3(*;7-G:60@(DEF('EO=2!C;VYT
M:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L
M;W-T(2(*;7-G<W1R(")(82!F;VQY=&%T:F$L(&$@;6%P<.$H:REB86X@;&5V
M]2#V<W-Z97,@;&5VZ6P@=/9R;/5D:6LA(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T<B`B3F4@
M=F5G>?QK(&9I9WEE;&5M8F4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z.#,*;7-G:60@(DEG;F]R92!!;&PB"FUS9W-T<B`B16=Y:6ME
M="!S92!V96=Y_&L@9FEG>65L96UB92(*"B,Z('1E;7!L871E<R]S879E:6UA
M9V4O<V%V96EM86=E+FEN8SHX"FUS9VED("));6%G92(*;7-G<W1R(")+Z7`B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P"FUS9VED("))
M;7!O<G0B"FUS9W-T<B`B26UP;W)TX6SA<R(*"B,Z('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C8U"FUS9VED("));7!O<G0@2V5Y(@IM<V=S='(@(DMU;&-S(&EM<&]R
M=.%LX7-A(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S.0IM<V=I9"`B
M26UP;W)T($ME>7!A:7(B"FUS9W-T<B`B2W5L8W-PX7(@:6UP;W)TX6SA<V$B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PIM<V=I9"`B
M26UP;W)T($UE<W-A9V5S(@IM<V=S='(@(DQE=F5L96L@:6UP;W)TX6SA<V$B
M"@HC.B!P9W`N<&AP.C0Q"FUS9VED("));7!O<G0@4$=0($ME>2(*;7-G<W1R
M(")01U`@:W5L8W,@:6UP;W)TX6SA<V$B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.CDQ"FUS9VED("));7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A
M=&4B"FUS9W-T<B`B4WIE;>EL>65S('1A;OIS[71VX6YY(&EM<&]R=.%LX7-A
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ-`IM<V=I9"`B
M26UP;W)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>2(*;7-G<W1R(")3>F5M
MZ6QY97,L('1I=&MO<R!01U`@:W5L8W,@:6UP;W)TX6SA<V$B"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.CD*;7-G:60@(DEM<&]R="!097)S
M;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G<W1R(")3>F5MZ6QY97,L(&YY:6QV
MX6YO<R!01U`@:W5L8W,@:6UP;W)TX6SA<V$B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%,O
M34E-12!#97)T:69I8V%T97,B"FUS9W-T<B`B4WIE;>EL>65S(%,O34E-12!T
M86[Z<^UT=N%N>6]K(&EM<&]R=.%LX7-A(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHT,"!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#(*;7-G:60@
M(DEM<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(DYY:6QVX6YO<R!K=6QC<R!I
M;7!O<G3A;.%S82(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M-`IM<V=I9"`B26UP;W)T(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(DYY:6QV
MX6YO<R!01U`@:W5L8W,@:6UP;W)TX6SA<V$B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)
M344@2V5Y(@IM<V=S='(@(DYY:6QVX6YO<R!3+TU)344@:W5L8W,@:6UP;W)T
MX6SA<V$B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@
M2V5Y(@IM<V=S='(@(E,O34E-12!K=6QC<R!I;7!O<G3A;.%S82(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB
M;W@@1FEL92(*;7-G<W1R(")3=&%N9&%R9"!M8F]X(&;A:FP@:6UP;W)TX6SA
M<V$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD
M97(@)7,N(@IM<V=S='(@(B5S('-T86YD87)D(&UB;W@@9N%J;"!I;7!O<G3A
M;.%S82`H9F5L=/9L=.ES92D@82AZ*2`E<R!M87!PX6)A+B(*"B,Z(&UE<W-A
M9V4N<&AP.C4P-B!M86EL8F]X+G!H<#HW,CD@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R
M=&%N="(*;7-G<W1R(")F;VYT;W,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B
M1F]N=&]S(&QE=F5L96LB"@HC.B!F;VQD97)S+G!H<#HQ-3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E<RXB"FUS
M9W-T<B`B)60@;&5V96QE="!I;7!O<G3A;'1U;FL@)7,M8O5L+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C8*;7-G:60@(DEN(%!R;V-E<W,B
M"FUS9W-T<B`B9F]L>6%M871B86XB"@HC.B!F;VQD97)S+G!H<#HS-C4@=&5M
M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHQ-"!L:6(O1F]L
M9&5R+G!H<#HX-@HC.B!L:6(O1F]L9&5R+G!H<#HR,3$@;&EB+TE-4"YP:'`Z
M.#,P(&QI8B])34%0+U1R964N<&AP.C$Q.0HC.B!L:6(O24U!4"]4<F5E+G!H
M<#HR,C(*;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.3(*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y
M(&]F('1H92!H96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`B5N%L87-Z;VSA
M<VMO<B!I9.EZ>OQK+64@8F4@82!L97;I;"!F96ILZ6/I;F5K(&9O;G1O<V%B
M8B!S;W)A:70_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I
M9"`B26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_(@IM<V=S
M='(@(E;A;&%S>F]LX7-K;W(@:63I>GK\:R!B92!A(&UE9W;A;&%S>F]L86YD
M\R!L979E;&5T/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN
M<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$S,`IM<V=I9"`B
M26YF;R(*;7-G<W1R("));F9O<FWA8VGS(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*
M;7-G<W1R("));F9O<FWA8VGS("5S(&YY:6QVX6YO<R!K=6QC<W+S;"(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@
M;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B26YF;W)MX6-I\R!A
M('-Z96WI;'EE<RP@=&ET:V]S(&MU;&-S<O-L(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G
M:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T
M<B`B26YF;W)MX6-I\R!A('-Z96WI;'EE<RP@;GEI;';A;F]S(&MU;&-S<O-L
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P,0HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYJ<SHU-@IM<V=I9"`B26YL:6YE(@IM<V=S
M='(@(DQE=NEL8F5N:2(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y
M+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R
M("))9&4@;>%S;VQJ82!B92!A('1A;OIS[71VX6YY="(*"B,Z('1E;7!L871E
M<R]P9W`O:6UP;W)T7VME>2YI;F,Z,34*;7-G:60@(DEN<V5R="!097)S;VYA
M;"!0<FEV871E(%!'4"!+97D@2&5R92(*;7-G<W1R("))9&4@;>%S;VQJ82!B
M92!A('-Z96WI;'EE<RP@=&ET:V]S(%!'4"!K=6QC<^%T(@H*(SH@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T(%!E<G-O
M;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B261E(&WA<V]L:F$@
M8F4@82!S>F5MZ6QY97,L(&YY:6QVX6YO<R!01U`@:W5L8W/A="(*"B,Z('1E
M;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U
M8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B261E(&WA<V]L:F$@8F4@82!N
M>6EL=N%N;W,@4$=0(&MU;&-S;W0B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-#$S"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@
M=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(D5Z(&$@;&5H973U<^EG(&YE;2!V
MX6QA<WIT:&%T\R!E8F)E;B!A>B!E<V5T8F5N+B(*"B,Z(&UA:6QB;W@N<&AP
M.C4W-2!M86EL8F]X+G!H<#HV,C(*;7-G:60@(DEN=F%L:60@061D<F5S<R(*
M;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@8^UM+B(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(%)E;6]T92!-
M86EL8F]X(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!TX79O;&D@
M;&5VZ6QLX61A+B(*"B,Z(&-O;7!O<V4N<&AP.C$U.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@
M)7,N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A;&%N(&MA<F%K=&5R(&%Z
M(&5M86EL(&/M;6)E;CH@)7,N(@H*(SH@<VUI;64N<&AP.C<X('!G<"YP:'`Z
M,38*;7-G:60@(DEN=F%L:60@:V5Y(@IM<V=S='(@(DAI8N%S(&MU;&-S(@H*
M(SH@<&=P+G!H<#HQ.3(*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!R
M:79A=&4@:V5Y+B(*;7-G<W1R(")(:6+A<R!01U`@<WIE;>EL>65S+"!T:71K
M;W,@:W5L8W,N(@H*(SH@<&=P+G!H<#HQ-C<*;7-G:60@(DEN=F%L:60@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97DN(@IM<V=S='(@(DAI8N%S(%!'4"!S>F5M
MZ6QY97,L(&YY:6QVX6YO<R!K=6QC<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C$R"FUS9VED("));G9E<G0B"FUS9W-T<B`B87H@96QL
M96YK97KU:NET(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-3DQ"FUS9VED(")+0B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,3$S"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(DMU;&-S:&]S
M<WKZ<^%G(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I9"`B
M(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@=&\@8V]M
M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*;7-G
M<W1R("(B"B)!(&MU;&-S(&SI=')E:&]ZX7-A(&AO<W-Z86)B(&ED]70@=F5H
M970@:6?I;GEB92X@1F]L>71A<W-U:R!A(&MU;&-S("(*(FSI=')E:&]ZX7/A
M=#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N;W0@879A
M:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E
M<G9E<BXB"FUS9W-T<B`B(@HB02!K=6QC<R!N96T@:6UP;W)TX6QH873S+B!!
M('-Z97)V97)E;B!N:6YC<R!E;F=E9.EL>65Z=F4@87H@X6QL;VWA;GEO:R`B
M"B)F96QT]FQTZ7-E+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,S<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,Y"FUS9VED("(B"B)+97D@:6UP
M;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H879E(&YO(&%D9')E<W,@8F]O
M:R!D969I;F5D('1O(&%D9"!Y;W5R("(*(F-O;G1A8W1S+B(*;7-G<W1R("(B
M"B)!(&MU;&-S(&YE;2!I;7!O<G3A;&AA=/,N($YI;F-S(&UE9V%D=F$@82!C
M[6UJ96=Y>NEK+"!A:&]V82!E;"!L96AE=&YE("(*(FUE;G1E;FD@87H@861A
M=&]K870N(@H*(SH@<&=P+G!H<#HS,30*;7-G:60@(DME>2!S=6-C97-S9G5L
M;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B02!K
M=6QC<V]T('-I:V5R97-E;B!E;&O\;&1T_&L@82!N>6EL=N%N;W,@:W5L8W-O
M:V%T('3A<F]L\R!S>F5R=F5R;F5K+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C$U"FUS9VED("),86YG=6%G92(*;7-G<W1R(").>65L=B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.34*;7-G:60@(DQA<W0@36%I
M;&)O>"!086=E(@IM<V=S='(@(D$@;6%P<&$@=71O;'/S(&]L9&%L82(*"B,Z
M(&UA:6QB;W@N<&AP.C,T-`IM<V=I9"`B3&%S="!086=E(@IM<V=S='(@(E5T
M;VQS\R!O;&1A;"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4T.0IM<V=I9"`B3&EN:R!!='1A8VAM96YT<S\B"FUS9W-T<B`B02!M96QL
MZ6ML971E:V5T(&AI=F%T:V]ZX7,@9F]R;>%JX6)A;B!K_&QD:OQK/R(*"B,Z
M(&%T=&%C:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#@T"FUS9VED
M("),:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B
M02!M96QLZ6ML971E:R!H:79A=&MO>N%S(&9O<FWA:N%B86X@=F%L\R!K_&QD
MZ7-E(&YE;2!M96=E;F=E9&5T="XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3$P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:6YK<R!W:6QL(&5X<&ER92!O;B`E
M<R(*;7-G<W1R(")!(&AI=F%T:V]Z;W1T(&UE;&SI:VQE=&5K(&5K:V]R('3V
M<FSU9&YI(&9O9VYA:SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`W,0IM<V=I9"`B(@HB3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG
M('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@
M(@HB;VYL>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L
M:6-I=&QY*2(*;7-G<W1R("(B"B),:7-TX7IZ=6L@:VD@87H@]G-S>F5S('!A
M<G1N97)T(&$@8^UM:F5G>7KI:R!B96CM=N%S86MO<C\@*&AA(&YE;2P@86MK
M;W(@(@HB8W-A:R!A>F]K(&$@<&%R=&YE<F5K(&IE;&5N;F5K(&UE9RP@;65L
M>65K<F4@<N%K97)E<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@R
M"FUS9VED("),:7-T:6YG(&EN('1H92!(96%D97(B"FUS9W-T<B`B82!F96IL
MZ6-B96X@=F%L\R!F96QS;W)O;.%S(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C,P"FUS9VED("),;V-A;"!-86EL8F]X.B(*;7-G<W1R
M(")(96QY:2!M87!P83HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C<Q"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")(96QY(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C0*;7-G:60@(DQO9R!I;B(*;7-G<W1R
M(")"96IE;&5N=&ME>NES(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("),;V<@:6X@=&\@)7,B"FUS9W-T<B`B
M0F5J96QE;G1K97KI<R`E<RUB92(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3,X"FUS9VED("),;V=I;B(*;7-G<W1R(")"96IE;&5N=&ME>NES
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R(")"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA=&]S(&9E
M;&%D871O:R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y
M-@IM<V=I9"`B3&]W(@IM<V=S='(@(F%L86-S;VYY(@H*(SH@;65S<V%G92YP
M:'`Z,S`W(&UA:6QB;W@N<&AP.C<R,B!T96UP;&%T97,O;6%I;&)O>"]L96=E
M;F0N:6YC.C$S"FUS9VED("),;W<@4')I;W)I='DB"FUS9W-T<B`B3F5M('/\
M<F?U<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-PIM
M<V=I9"`B3&]W97-T(@IM<V=S='(@(FQE9V%L86-S;VYY86)B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`IM<V=I9"`B36%C:6YT
M;W-H($9I;&4B"FUS9W-T<B`B36%C:6YT;W-H(&;A:FPB"@HC.B!T96UP;&%T
M97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*;7-G:60@(DUA:6PB"FUS9W-T
M<B`B3&5V96QE>NES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS
M9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(D$@;&5V96QE:R!E;/5NZ7IE
M=&4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM
M<V=S='(@(D%Z(&ED96=E;B!L979E;&5Z]7-Z97)V97(@=.UP=7-A.B(*"B,Z
M(&9O;&1E<G,N<&AP.C,V.2!F;VQD97)S+G!H<#HS.#,*;7-G:60@(DUA:6QB
M;W@B"FUS9W-T<B`B3&5VZ6QLX61A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,0IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T
M:6]N<R(*;7-G<W1R(")!(&QE=NEL;.%D82!I;&PN(&$@;6%P<.%K(&UE9VIE
M;&5N[73I<VD@8F7A;&SM=.%S86DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L
M9&5R(&%S(%-E96XB"FUS9W-T<B`B02!M87!P82#V<W-Z97,@;&5V96SI="!O
M;'9A<V]T=&OI;G0@:F5L]FQJ_&L@;65G(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN
M($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T<B`B02!M87!P82#V<W-Z97,@;&5V
M96SI="!O;'9A<V%T;&%N:^EN="!J96SV;&K\:R!M96<B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C4@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHS,`IM<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`B
M2F5L]FQJ_&L@;65G+"!M:6YT.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,S@*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG
M('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`B07H@:63I>F5T96L@
M:_QL]FYB]GKU('-Z:6YT:F5I="!E;'3I<O4@<WKM;FYE;"!J96QE>GK\:S\B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*;7-G:60@
M(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS9W-T<B`B
M3VQV87-O='1KZ6YT(&IE;/9L:OQK(&UE9R!A(&QE=F5L96ME=#\@*&-S86L@
M24U!4"DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0V"FUS9VED(")-
M87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(DIE;&5Z>OQK(&%Z(&5G>7-Z
M97+[8F(@2%1-3"!K\V1O:V%T/R(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A
M9&5R+FEN8SHT.0IM<V=I9"`B36%T8V@@06QL(%%U97)I97,B"FUS9W-T<B`B
M07H@]G-S>F5S(&ME<F5S]69E;'3I=&5L="!K:65LZ6?M=&EK(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0U"FUS9VED(")-871C:"!!;GD@
M475E<GDB"FUS9W-T<B`B0N%R;65L>6EK(&ME<F5S]69E;'3I=&5L="!K:65L
MZ6?M=&EK(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`W
M"FUS9VED(")-87AI;75M($%T=&%C:&UE;G0@4VEZ92(*;7-G<W1R(")-87AI
M;>%L:7,@;65L;.EK;&5T(&WI<F5T(@H*(SH@;&EB+V%P:2YP:'`Z-SD*;7-G
M:60@(DUA>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B"FUS9W-T<B`B02!M87!P
MX6L@;6%X:6WA;&ES('-ZX6UA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#@Y"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM
M96YT<R!R96%C:&5D+B(*;7-G<W1R(")!(&-S871O;'0@;65L;.EK;&5T96L@
M<WKA;6$@;F5M(&[V=F5L:&5T]2!T;W;A8F(N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#@U"FUS9VED(")-87AI;75M('1O=&%L(&%T
M=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*;7-G<W1R("(B"B)!(&-S871O;'0@
M;65L;.EK;&5T96L@]G-S>FWI<F5T92!E;.ER=&4@82!M87AI;>%L:7,@;65G
M96YG961E='0@Z7)TZ6ME="XB"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S
M+G!H<#HS"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@(DUA<'!A
M(&QI<W3A>O,@;65N_"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-#(*;7-G:60@
M(DUE<W-A9V4B"FUS9W-T<B`B3&5VZ6PB"@HC.B!C;VUP;W-E+G!H<#HU.3@@
M8V]M<&]S92YP:'`Z-C(U(&-O;7!O<V4N<&AP.C8W.2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S:71I;VXB"FUS9W-T
M<B`B3&5VZ6SM<N%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-@IM
M<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(D$@;&5VZ6P@9.%T=6UA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`S"FUS9VED(")-97-S86=E($]P=&EO;G,B
M"FUS9W-T<B`B3&5V96QE:W)E('9O;F%T:V]Z\R!B9>%L;.UTX7-O:R(*"B,Z
M('-E87)C:"YP:'`Z,S`V"FUS9VED(")-97-S86=E(%-E87)C:"(*;7-G<W1R
M(")+97)E<^ES(&$@;&5VZ6QB96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$P"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`B02!L97;I;"!M
MZ7)E=&4B"@HC.B!M97-S86=E+G!H<#HS.3(*;7-G:60@(DUE<W-A9V4@4V]U
M<F-E(@IM<V=S='(@(D$@;&5VZ6P@9F]R<N%S82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@
M(D$@;&5VZ6P@;65G=&5K:6YTZ7-E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHV"FUS9VED(")-97-S86=E(&9L86=S(@IM<V=S='(@(D$@;&5V
MZ6P@9F%J=.%J82(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#,*
M;7-G:60@(DUE<W-A9V4@9F]L9&5R<R(*;7-G<W1R(")-96QY:6L@;6%P<&$B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("),97;I;"`E<RUT]6PB"@HC.B!M
M86EL8F]X+G!H<#HV-C,*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C:&UE;G1S
M(@IM<V=S='(@(D$@;&5VZ6QH97H@;65L;.EK;&5T96L@:7,@=F%N;F%K(@H*
M(SH@;6%I;&)O>"YP:'`Z-C4T"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E
M9"(*;7-G<W1R(")!(&QE=NEL(&OS9&]L=F$@=F%N(@H*(SH@;6%I;&)O>"YP
M:'`Z-C0Y"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G<W1R(")!(&QE
M=NEL(&1I9VETX6QI<R!A;.'M<N%S<V%L('9A;B!E;&SA='9A(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C,V"FUS9VED(")-97-S86=E(&UA
M=&-H97,B"FUS9W-T<B`B02!K97)E<V5T="!L979E;&5K(@H*(SH@8V]M<&]S
M92YP:'`Z.#8T(&-O;7!O<V4N<&AP.C@W,0IM<V=I9"`B365S<V%G92!R961I
M<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B02!L979E;&5T('-I:V5R
M97-E;B#A=&ERX6YY[71O='1U:RXB"@HC.B!C;VUP;W-E+G!H<#HQ,3(R"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL
M(&)U="!N;W0@<V%V960@=&\@)7,B"FUS9W-T<B`B02!L97;I;"!E;&UE;G0L
M(&1E(&YE;2!S:6ME<OQL="!E;&UE;G1E;FD@:71T.B`E<R(*"B,Z(&-O;7!O
M<V4N<&AP.C$Q.#$@8V]M<&]S92YP:'`Z,3$X.0IM<V=I9"`B365S<V%G92!S
M96YT('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B02!L979E;&5T(&5L:_QL9'3\
M:RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,P"FUS9VED(")-97-S
M86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W+B(*;7-G<W1R(")!
M>B!E9WD@;VQD86QO;B!M96=J96QE;O4@;&5V96QE:R!S>N%M82!A(&QE=NEL
M;.%D82!M96=T96MI;G3I<V5K;W(N(@H*(SH@;6%I;&)O>"YP:'`Z,S$Q"FUS
M9VED(")-97-S86=E<R!T;R(*;7-G<W1R(")A(&QE=F5L96ME="!I9&4N+BXB
M"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,CD*;7-G:60@(DUO9&EF>2(*
M;7-G<W1R(")-\V1O<^UTX7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E>'!A
M;F0N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@
M861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R(")4]F)B
M+"!M:6YT(&5G>2!C[6UE="!T86SA;'1U;FL@82!<(B5S7"(@;65Z]7)E+B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3@@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM<V=I9"`B36]V92(*
M;7-G<W1R(")496=Y_&L@X70B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,38*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")V:6=Y
M_&L@;&5J:F5B8B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#8*;7-G
M:60@(DUO=F4@<W!A;2!M97-S86=E<R!T;R!S<&%M(&9O;&1E<B!A;F0@:6YN
M;V-E;G0@;65S<V%G97,@=&\@24Y"3U@B"FUS9W-T<B`B(@HB02!S<&%M(&O\
M;&1E;>EN>65K970@=&5G>?QK(.%T(&$@<W!A;2!M87!PX6)A+"!A('3V8F)I
M="!P961I9R!A>B!)3D)/6"UB82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHU,`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B=&5G>?QK
M(.%T(&5B8F4@82!M87!PX6)A(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C
M97-E;&5C="YI;F,Z,S$T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(G9I9WG\
M:R!F]FQJ96)B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H
M<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E<FYA=&EV92(*;7-G<W1R(")4
M]F)B+"!A;'1E<FYA=.UV('+I<WIT('1A<G1A;&UA>B(*"B,Z('1H<F5A9"YP
M:'`Z-S8@=&AR96%D+G!H<#HQ-3<*;7-G:60@(DUU;'1I<&QE($UE<W-A9V4@
M5FEE=R(*;7-G<W1R("),97;I;&QI<W1A(&[I>F5T(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C@*;7-G:60@(DY/3D4B
M"FUS9W-T<B`B4T5-34DB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-#@@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHR"FUS9VED(").3U1%(@IM<V=S='(@(DU%1TI%
M1UE:R5,B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S
M."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@S"FUS9VED(").86UE(@IM
M<V=S='(@(D[I=B(*"B,Z('!G<"YP:'`Z,3`V"FUS9VED(").86UE(&%N9"]O
M<B!E;6%I;"!C86YN;W0@8F4@96UP='DB"FUS9W-T<B`B02!NZ78@:6QL+B!E
M;6%I;"!C[6T@;F5M(&UA<F%D:&%T(/QR97-E;B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW-S$*;7-G:60@(DYE961S($%C=&EO;B(*;7-G<W1R
M(")N:6YC<R!VX6QA<WHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-C<*;7-G:60@(DYE=F5R(@IM<V=S
M='(@(G-O:&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38P"FUS9VED
M(").979E<B!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(D$@;65L;.EK;&5T
M96ME="!S;W-E(&UE;G1S_&L@96PN(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$R-`IM<V=I9"`B3F5W(@IM<V=S='(@(OIJ(@H*(SH@;&EB+TE-4"YP
M:'`Z-3DU"FUS9VED(").97<@1F]L9&5R(@IM<V=S='(@(MIJ(&UA<'!A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@36%I;"(*
M;7-G<W1R("+::B!L97;I;"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR
M,2!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C(*(SH@;&EB+T)L;V-K+W1R965?
M9F]L9&5R<RYP:'`Z-#8*;7-G:60@(DYE=R!-97-S86=E(@IM<V=S='(@(MIJ
M(&QE=NEL(@H*(SH@;6%I;&)O>"YP:'`Z-S<Q(&QI8B]-24U%+TAE861E<G,N
M<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E
M<R(*;7-G<W1R("+::B!L97;I;"`E<R!C[6UR92(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R
M("+::B!L979E;&5K(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$S,PIM<V=I9"`B3F5X="(*;7-G<W1R(")+]G9E=&ME>O4B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S"FUS9VED
M(").97AT($UE<W-A9V4B"FUS9W-T<B`B2_9V971K97KU(&QE=NEL(@H*(SH@
M;6%I;&)O>"YP:'`Z,S0R"FUS9VED(").97AT(%!A9V4B"FUS9W-T<B`B2_9V
M971K97KU(&]L9&%L(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-30P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4U,PHC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38V"FUS9VED(").;R(*;7-G<W1R(").
M96TB"@HC.B!S;6EM92YP:'`Z,C(R"FUS9VED(").;R!#97)T:69I8V%T92!F
M;W5N9"(*;7-G<W1R(").96T@=&%LX6QH873S('1A;OIS[71VX6YY(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHU"FUS9VED(").
M;R!%;F-R>7!T:6]N(@IM<V=S='(@(E1I=&MO<^UTX7,O9&EG:73A;&ES(&%L
MX>URX7,@;NEL:_QL(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Y"FUS
M9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B16=Y(&MU;&-S('-I
M;F-S('3A<F]L=F$B"@HC.B!M86EL8F]X+G!H<#HS-C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F\@365S<V%G97,B"FUS9W-T<B`B3FEN8W,@;&5VZ6PB"@HC
M.B!P9W`N<&AP.C$S,PIM<V=I9"`B3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T
M960N(@IM<V=S='(@(DYE;2!I;7!O<G3A;'1U;FL@96=Y(&YY:6QVX6YO<R!0
M1U`@:W5L8W-O="!S96TN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHX-`IM<V=I9"`B3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N="(*
M;7-G<W1R(").96T@=&%LX6QH873S('-Z96WI;'EE<R!T86[Z<^UT=N%N>2(*
M"B,Z(&QI8B]-86EL8F]X+G!H<#HS,3D*;7-G:60@(DYO(%!R979I97<@5&5X
M="(*;7-G<W1R(").:6YC<R!M96=J96QE;NUT:&5T]2!S>O9V96<B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$U"FUS9VED(").;R!0=6)L:6,@
M2V5Y<R!&;W5N9"(*;7-G<W1R(").96T@=&%LX6QH873S(&YY:6QVX6YO<R!K
M=6QC<R(*"B,Z('-M:6UE+G!H<#HQ-#<*;7-G:60@(DYO(%,O34E-12!P=6)L
M:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(").96T@:6UP;W)TX6SS9&]T="!3
M+TU)344@;GEI;';A;F]S(&MU;&-S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T
M;F5F+G!H<#HY,@IM<V=I9"`B3F\@871T86-H;65N=',@9F]U;F0N(@IM<V=S
M='(@(DYI;F-S(&UE;&SI:VQE="XB"@HC.B!L:6(O0W)Y<'0O4TU)344N<&AP
M.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I;VX@;&]C871E9"!I;B!T
M:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B02!N>6EL=N%N;W,@:W5L8W,@;F5M
M('1A<G1A;&UA>B!E;6%I;')E('9O;F%T:V]Z\R!I;F9O<FWA8VGS="XB"@HC
M.B!A8VPN<&AP.C<Q(&%C;"YP:'`Z.3<*;7-G:60@(DYO(&9O;&1E<B!S96QE
M8W1E9"XB"FUS9W-T<B`B3FEN8W,@:VEJ96SV;'0@;6%P<&$N(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C$T.0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@
M8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(D5G>2!M87!P
MX6)A;B!S96T@96QL96[U<FEZ>OQK+"#I<FME>F5T="UE(/IJ(&QE=NEL+B(*
M"B,Z(&9O;&1E<G,N<&AP.C(P,2!L:6(O1F]L9&5R+G!H<#HU,#`@;&EB+T9O
M;&1E<BYP:'`Z-34P"FUS9VED(").;R!F;VQD97)S('=E<F4@<W!E8VEF:65D
M(@IM<V=S='(@(D5G>2!M87!P82!S96T@=F]L="!K:6IE;/9L=F4B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,34U"FUS9VED(").;R!F;VQD97)S('=I
M=&@@;F5W(&UE<W-A9V5S(@IM<V=S='(@(DYI;F-S(/IJ(&QE=F5L970@=&%R
M=&%L;6%Z\R!M87!P82(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-3(*
M;7-G:60@(DYO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T
M<B`B3FEN8W,@;VQV87-A=&QA;B!L979E;&5T('1A<G1A;&UA>O,@;6%P<&$B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,V"FUS9VED(").;R!M97-S86=E(&)O
M9'D@=&5X="(*;7-G<W1R(")!(&QE=NEL=/9R>G,@_')E<R(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z-38X"FUS9VED(").;R!M97-S86=E(')E='5R;F5D
M+B(*;7-G<W1R(").:6YC<R!L97;I;"XB"@HC.B!L:6(O36%I;&)O>"YP:'`Z
M,S8R"FUS9VED(").;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H+B(*
M;7-G<W1R(")!(&ME<F5SZ7,@;F5M('1A;.%L="!S96UM:70N(@H*(SH@<&=P
M+G!H<#HQ.#4*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I
M;7!O<G1E9"XB"FUS9W-T<B`B3F5M(&EM<&]R=.%L\V1O='0@82!01U`@<WIE
M;>EL>65S+"!T:71K;W,@:W5L8W,N(@H*(SH@<&=P+G!H<#HQ-C$*;7-G:60@
M(DYO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R
M(").96T@:6UP;W)TX6SS9&]T="!A(%!'4"!S>F5MZ6QY97,L(&YY:6QVX6YO
M<R!K=6QC<RXB"@HC.B!S;6EM92YP:'`Z,3DW"FUS9VED(").;R!P97)S;VYA
M;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G<W1R(").96T@
M:6UP;W)TX6SS9&]T="!3+TU)344@<WIE;>EL>65S('1A;OIS[71VX6YY+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0V(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C(Y.0IM<V=I9"`B(@HB3F\@<&5R<V]N86P@<')I=F%T
M92!K97D@97AI<W1S('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D
M96-R>7!T960N(@IM<V=S='(@(B(*(DYI;F-S(&UE9R!A('1I=&MO<R!S>F5M
MZ6QY97,@:W5L8W,L(&5ZZ7)T(&$@:_-D;VQT(&QE=NEL('1A<G1A;&UA(&YE
M;2`B"B)F96IT:&5T]2!V:7-S>F$N(@H*(SH@<W!E;&QI;F<N<&AP.C(R,`IM
M<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N(@IM
M<V=S='(@(D$@:&5L>65S[7+A<V5L;&5N]7)Z]2!P<F]G<F%M(&YI;F-S(&MO
M;F9I9W5RX6QV82XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-#@*;7-G:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(").:6YC
M<R!H96QY97/M<N%S:2!H:6)A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B
M3FEN8W,@:F%V87-L870B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4V,`IM
M<V=I9"`B3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T:&]D
M(&-O=6QD(&)E(&9O=6YD+B(*;7-G<W1R("(B"B).:6YC<R!O;'EA;B!F96QH
M87-Z;N%L\V%Z;VYO<^UTX7-I(&WS9'-Z97(L(&%M:70@87H@24U!4"!S>F5R
M=F5R('3A;6]G870N(@H*(SH@86-L+G!H<#HV-R!A8VPN<&AP.CDS"FUS9VED
M(").;R!U<V5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F5M(&IE;/9L="!M96<@
M9F5L:&%S>F[A;/-T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M,#0*;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R(").96T@<NES>G1V
M97;U(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,2!T96UP
M;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR-`HC.B!T96UP;&%T97,O
M<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P('1E;7!L871E<R]P<F5F<R]S
M;W5R8V5S96QE8W0N:6YC.C,U"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L
M96-T+FEN8SHR-"!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C$*;7-G:60@(DYO;F4B
M"FUS9W-T<B`B96=Y:6LH970I('-E;2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(Y-0IM<V=I9"`B3F]R;6%L(@IM<V=S='(@(FOV>F5P
M97,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(Q('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D
M(@IM<V=S='(@(FYE;2!T]G+V;'0B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,C,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM
M<V=I9"`B3F]T($1R869T(@IM<V=S='(@(FYE;2!M=6YK87#I;&3A;GDB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C@@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-PHC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C,T"FUS9VED(").;W0@26UP;W)T86YT(@IM<V=S
M='(@(FYE;2!F;VYT;W,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C(U"FUS9VED(").;W0@4&5R<V]N86PB"FUS9W-T<B`B;F5M('-Z96WI
M;'EE<R(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)
M344N<&AP.C$S-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T
M(&$@=F%L:60@<'5B;&EC(&ME>2XB"FUS9W-T<B`B3F5M(.ER=NEN>65S(&YY
M:6QVX6YO<R!K=6QC<RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C8W"FUS9VED(").;W0@9&5L971E9"!M97-S86=E<R(*;7-G<W1R(").96T@
M=/9R]FQT(&QE=F5L96LB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C4Q"FUS9VED(").;W0@:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(DYE
M;2!F;VYT;W,@;&5V96QE:R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E
M=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A
M;B!T86ME('-O;64@=&EM92(*;7-G<W1R(")%>B!E;'1A<G1H870@96=Y(&ED
M96EG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P-`IM<V=I9"`B3F]T
M:&EN9R(*;7-G<W1R(")396UM:2(*"B,Z(&%T=&%C:&UE;G0N<&AP.C@Y"FUS
M9VED(").;W1I9FEC871I;VXZ($QI;FME9"!A='1A8VAM96YT(&1O=VYL;V%D
M960B"FUS9W-T<B`B5.%JZ6MO>G1A=.%S.B!A(&AI=F%T:V]Z;W1T(&UE;&SI
M:VQE=&5T(&QE=/9L=/9T=/QK(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W-PIM<V=I9"`B3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK
M960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B
M(@HB(&CS;F%P:6<@=&%R='-U:R!M96<@82!H:79A=&MO>N%S(&9O<FWA:N%B
M86X@:_QL9/9T="!M96QLZ6ML971E:R!TZ6YY;&5G97,@(@HB<.EL9.%N>>%T
M+"!H879I('3V<FSI<R!E<V5TZ6XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,U.0IM<V=I9"`B3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(F1B
M('+I9VD@96QK_&QD]G1T(&QE=F5L96ME="!T87)T86QM87KS("AS96YT+6UA
M:6PI(&UA<'#A="!T87)T<W5N:R!M96<L(&AA=FD@(@HB=/9R;.ES(&5S973I
M;B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T"FUS
M9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE
M;&1S+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.0HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*
M;7-G<W1R(")604=9(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ
M-0IM<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@(E+I9VD@;&5V96QE:R(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT
M:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG
M('!U<F=E9"XB"FUS9W-T<B`B5/9R;/5D;F5K(&$@<NEG:2!E;&O\;&3V='0@
M;&5V96QE:V5T('1A<G1A;&UA>O,@*'-E;G0M;6%I;"D@;6%P<.%K+B(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR.`IM<V=I9"`B3VYL>2!D:7-P;&%Y
M(&9O;&1E<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T
M<B`B0W-A:R!A>F]K870@82!M87!PX6MA="!M=71A<W-U:RP@;65L>65K8F5N
M('9A;B!O;'9A<V%T;&%N(&QE=NEL/R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z.#$*;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U
M;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R(")+Z7)E
M;2P@:&]G>2!E:&AE>B!A(&9E;&%D871H;WH@8W-A:R!E9WD@;6%P<.%T(&IE
M;/9L:O9N(&MI+B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ,"!T96UP;&%T
M97,O;65N=2YI;F,Z,S`*;7-G:60@(D]P96X@1F]?;&1E<B(*;7-G<W1R(")-
M87!P82!N>6ETX7,B"@HC.B!F;VQD97)S+G!H<#HT,#@*;7-G:60@(D]P96YE
M9"!&;VQD97(B"FUS9W-T<B`B2VEN>6ET;W1T(&UA<'!A(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<P,`IM<V=I9"`B3W!T:6]N86P@4&%R=&EC
M:7!A;G0B"FUS9W-T<B`B5N%L87-Z=&AA=/,@<NES>G1V97;U(@H*(SH@9F5T
M8VAM86EL+G!H<#HT,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC
M.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B
M3W1H97(@36%I;"!!8V-O=6YT<R(*;7-G<W1R("))9&5G96X@;&5V96QE>O5S
M>F5R=F5R96ME;B!L97;U(&QE=NEL;.%DX6LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3D*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U,`IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R(")%
M9WGI8B!B9>%L;.UTX7-O:R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C`P"FUS9VED(")/=71B;W5N9"!397)V97(B"FUS9W-T<B`B2VEM96[U
M("A33510*2!S>F5R=F5R(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E
M+FEN8SHQ-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C0*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,C`S(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(X.0IM<V=I9"`B4$=0(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-PIM<V=I9"`B4$=0($5N8W)Y<'0@365S
M<V%G92(*;7-G<W1R(")4:71K;W/M='-U:R!A(&QE=F5L970@4$=0+79E;"(*
M"B,Z(&-O;7!O<V4N<&AP.C,S-0IM<V=I9"`B4$=0($5R<F]R.B`B"FUS9W-T
M<B`B4$=0(&AI8F$Z("(*"B,Z(&-O;7!O<V4N<&AP.C,Q-`IM<V=I9"`B4$=0
M($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@
M:V5Y+B(*;7-G<W1R(")01U`@:&EB83H@82!S>F5MZ6QY97,@=&ET:V]S(&MU
M;&-S(&AA<WINX6QA=.%H;WH@:F5L;6]N9&%T('-Z_&MSZ6=E<RXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")01U`@3W!T:6]N<R(*
M;7-G<W1R(")01U`@8F7A;&SM=.%S;VLB"@HC.B!P9W`N<&AP.C,P"FUS9VED
M(")01U`@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("+-<FIA(&)E(&$@4$=0
M(&IE;&UO;F1A=.%T(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4U"FUS
M9VED(")01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B)!(%!'4"!S>F5M
MZ6QY97,@:W5L8W-PX7(@=.%M;V=A=.%S('1I=&MO<^UT;W1T('=E8B!K87!C
M<V]L871O="!I9^EN>65L+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C$W,@IM<V=I9"`B4$=0(%!U8FQI8R!+97D@5&5X="(*;7-G<W1R(")01U`@
M;GEI;';A;F]S(&MU;&-S('-Z]G9E9V4B"@HC.B!P9W`N<&AP.C$T-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<R`H)7,I
M7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B7"(E<R`H)7,I
M7"(@;GEI=N%N;W,@4$=0(&MU;&-SX70@<VEK97)E<V5N(&9E;'9E='3\:RXB
M"@HC.B!P9W`N<&AP.C(T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B
M;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB
M"FUS9W-T<B`B7"(E<UPB(&YY:7;A;F]S(%!'4"!K=6QC<^%T('-I:V5R97-E
M;B!T]G+V;'3\:RXB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")01U`@;GEI;';A;F]S
M(&MU;&-S;VLB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N
M:6YC.C@*;7-G:60@(E!'4"!3:6=N($UE<W-A9V4B"FUS9W-T<B`B3.%S<W5K
M(&5L(&$@;&5V96QE="!01U`@9&EG:73A;&ES(&%LX>URX7-S86PB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.CD*;7-G:60@(E!'
M4"!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")4:71K;W/M='-U:R#I
M<R!D:6=I=.%L:7-A;B#M<FIU:R!A;.$@82!L979E;&5T(%!'4"UV96PB"@HC
M.B!P9W`N<&AP.C$Y.`IM<V=I9"`B4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F
M=6QL>2!A9&1E9"XB"FUS9W-T<B`B02!01U`@=&ET:V]S(&MU;&-S;W0@<VEK
M97)E<V5N(&9E;'9E='3\:RXB"@HC.B!P9W`N<&AP.C$W,PIM<V=I9"`B4$=0
M('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")!(%!'
M4"!N>6EL=N%N;W,@:W5L8W-O="!S:6ME<F5S96X@9F5L=F5T=/QK+B(*"B,Z
M('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")01U`@<W5P
M<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B02!0
M1U`@=.%M;V=A=.%S(&EN86MT:7;A;'9A('9A;B!A(')E;F1S>F5R8F5N+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-PIM<V=I9"`B(@HB4$=0
M('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET
M86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS
M9W-T<B`B(@HB02!01U`@=.%M;V=A=.%S(&IE;&5N;&5G(&YI;F-S(&%K=&EV
MX6QV82P@97KI<G0@82!L97;I;"!D:6=I=.%L:7,@(@HB86SA[7+A<^%N86L@
M:&ET96QE<W/I9V4@;F5M(&5L;&5N]7)I>FAE=/4N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,CDT"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N
M;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@
M=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B"B)!(%!'4"!TX6UO9V%TX7,@
M:F5L96YL96<@;FEN8W,@86MT:7;A;'9A+"!E>NER="!A(&OS9&]L="!L97;I
M;"!T87)T86QM82!N96T@(@HB9F5J=&AE=/4@=FES<WIA+B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHR"FUS9VED("(B"B)01U`@<W5P<&]R="!R97%U
M:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S
M97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O
M=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@
M4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G
M<W1R("(B"B)!(%!'4"!TX6UO9V%TX7,@9F5L8G5K:V%N\R`H<&]P=7`I(&%B
M;&%K;VMA="!I9^EN>65L+B!(82!A>B#6;B`B"B)B]FYGZ7-Z]7!R;V=R86UJ
M82#Z9WD@=F%N(&)EX6QL[71V82P@:&]G>2!L971I;'1J82!A(&9E;&)U:VMA
M;O,@86)L86MO:V%T+"`B"B)A:VMO<B!V86=Y(';A;'1O>G1A<W-O;B!A(&)E
MX6QL[73A<V]K;VXL('9A9WD@82!01U`@<WIO;&?A;'1A=.%S;VL@;F5M("(*
M(F9O9VYA:R!M96=F96QE;/5E;B!M^VOV9&YI+B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM<V=S='(@(E!/4#,B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T
M;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R(")03U`S("AA=71O;6%T:6MU
M<R!P<F]T;VMO;&P@;65G:&%TX7)O>N%S<V%L*2(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3$W"FUS9VED(")03U`S(&]V97(@4U-,(@IM<V=S='(@
M(E!/4#,@4U-,(&;V;/9T="(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,3(S"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I
M8V%T92DB"FUS9W-T<B`B4$]0,R!34TP@9O9L]G1T("CV;G1A;OIS[71VX6YN
M>6%L*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38X"FUS9VED
M(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B4$]0,R!3
M4TP@9O9L]G1T("CV;G1A;OIS[71VX6YN>6%L*2(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3$Q"FUS9VED(")03U`S+"!N;R!43%,B"FUS9W-T<B`B
M4$]0,BP@5$Q3(&[I;&O\;"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&%G92`E9"!O9B`E9"(*
M;7-G<W1R("(E9"X@;VQD86P@82`E9"UB]6PB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#DR"FUS9VED(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E
M;B!-97-S86=E(@IM<V=S='(@(D%Z(&5L<_4@;VQV87-A=&QA;B!L979E;&5T
M('1A<G1A;&UA>O,@;VQD86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#DS"FUS9VED(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B
M"FUS9W-T<B`B07H@=71O;'/S(&]L=F%S871L86X@;&5V96QE="!T87)T86QM
M87KS(&]L9&%L(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z
M-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`B4NES>BAE:RDB"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS9VED(")087-S<&AR87-E(@IM<V=S
M='(@(DIE;&UO;F1A="(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*
M;7-G:60@(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R(")*96QM;VYD870@
M*&WI9R!E9WES>F5R*2(*"B,Z('-M:6UE+G!H<#HR,S$@<&=P+G!H<#HS,#8*
M;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G
M<W1R(")!(&IE;&UO;F1A=&]T('-I:V5R97-E;B!E;'3A=F]L[71O='1U:RXB
M"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA
M=&5S+W!G<"]P87-S<&AR87-E+FEN8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB
M"FUS9W-T<B`B2F5L;6]N9&%T.B(*"B,Z('!G<"YP:'`Z,3`X"FUS9VED(")0
M87-S<&AR87-E<R!C86YN;W0@8F4@96UP='DB"FUS9W-T<B`B02!J96QM;VYD
M870@;F5M(&QE:&5T(/QR97,B"@HC.B!P9W`N<&AP.C$Q,`IM<V=I9"`B4&%S
M<W!H<F%S97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(D$@:F5L;6]N9&%T;VL@
M;F5M(&5G>65Z;F5K(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C(P('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y,0IM<V=I9"`B4&%S<W=O<F0B
M"FUS9W-T<B`B2F5L<WKS(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C0X"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7-K;W(@:&%J='-U
M:R!VZ6=R92!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K870_(@H*(SH@86-L
M+G!H<#HW-2!A8VPN<&AP.C$P,0IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R('1H
M:7,@=7-E<B!C86YN;W0@8F4@8VAA;F=E9"XB"FUS9W-T<B`B02!F96QH87-Z
M;N%L\R!J;V=O<W5L='/A9V%I(&YE;2!VX6QT;WIT871H873S:R!M96<N(@H*
M(SH@;65S<V%G92YP:'`Z-#DT(&UA:6QB;W@N<&AP.C8Y."!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C(T"B,Z('1E;7!L871E<R]M86EL8F]X+VQE
M9V5N9"YI;F,Z,3`*;7-G:60@(E!E<G-O;F%L(@IM<V=S='(@(G-Z96WI;'EE
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-`IM<V=I9"`B4&5R<V]N
M86P@26YF;W)M871I;VXB"FUS9W-T<B`B4WIE;>EL>65S(&%D871O:R(*"B,Z
M('!G<"YP:'`Z,3$V"FUS9VED(")097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!('-Z96WI;'EE<R!01U`@
M:W5L8W-PX7)T('-I:V5R97-E;B!LZ71R96AO>G1U:RXB"@HC.B!P9W`N<&AP
M.C$R,PIM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(D$@<WIE;>EL>65S(%!'4"!K=6QC<V]K870@<VEK
M97)E<V5N('3V<O9L=/QK+B(*"B,Z('-M:6UE+G!H<#HR,#,*;7-G:60@(E!E
M<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B"FUS
M9W-T<B`B3D5-(&EM<&]R=.%L\V1O='0@4R]-24U%('-Z96WI;'EE<R!T86[Z
M<^UT=N%N>6]K.B`B"@HC.B!S;6EM92YP:'`Z,3(X"FUS9VED(")097)S;VYA
M;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M02!S>F5MZ6QY97,@4R]-24U%(&MU;&-S;VMA="!S:6ME<F5S96X@=/9R]FQT
M_&LN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA
M8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S
M/R(*;7-G<W1R("(B"B)!>B#6;B#A;&QA;F3S(&QE=NEL=NEG>O5DZ7/I="`H
M<VEG;F%T=7)E*2!VX6QA<WIO;.%S:V]R(&EL;"X@(@HB;&5VZ6QT;W;A8F+M
M=.%S:V]R(&$@8F5I9.EZ971T(&QE=NEL(&5LZ2!H96QY97IZ_&L_(@H*(SH@
M8V]M<&]S92YP:'`Z,C4X"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-
M97-S86=E(@IM<V=S='(@(D$@;&5VZ6P@<VEM82!T97AT(';A;'1O>F%T82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#@*;7-G:60@(B(*(E!L87D@
M<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E
M<B!T;R!S=7!P;W)T(&5M8F5D9&5D("(*(G-O=6YD(&9I;&5S+B`@06QM;W-T
M(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R
M;7,@=VEL;"`B"B)R97%U:7)E(&$@<&QU9VEN+B(*;7-G<W1R("(B"B)+Z7(@
M:&%N9VIE;'KI<W0@^FH@;&5VZ6P@Z7)K97KI<V5K;W(_($5H:&5Z(&+V;F?I
M<WKU<')O9W)A;6KA;F%K('3A;6]G871N:6$@(@HB:V5L;"!A(&AA;F=L96KA
M='-ZX7-T+B!%<G)E(&$@5VEN9&]W<R#I<R!-86,@<')O9W)A;6]K(&-S86MN
M96T@;6EN9&5G>6EK92`B"B)KZ7!E<RP@9&4@;>%S('!L871F;W)M;VMO;B!K
M:65GZ7-Z[73U("AP;'5G:6XI('!R;V=R86T@=&5L97#M=.ES92!S>OQK<^EG
M97,N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@
M=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")0
M;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T
M<B`B2^ER96T@861J82!M96<@87H@^FH@;6%P<&$@;F5VZ70Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#8*;7-G:60@(E!L96%S92!E;G1E<B!T
M:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B2^ER96T@861J
M82!M96<@87H@^FH@;6%P<&$@;F5VZ70Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9F]L9&5R<RYJ<SHQ,SD*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@
M;F5W(&YA;64Z(@IM<V=S='(@(DOI<F5M(&%D:F$@;65G(&%Z(/IJ(&YE=F5T
M.B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E
M(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D
M('1O("(*(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S
M:6]N+B(*;7-G<W1R("(B"B)+Z7)E;2!A9&IA(&UE9R!A('-Z96WI;'EE<RP@
M=&ET:V]S(%!'4"!K=6QC<^%H;WH@=&%R=&]Z\R!J96QM;VYD871O="X@17H@
M(@HB8W-A:R!E9WES>F5R(&ME;&P@8F7M<FYI82!A;&MA;&UA;FOI;G0@82`E
M<R!H87-Z;N%L871A:V]R+B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR
M87-E+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y
M+B!9;W4@=VEL;"!O;FQY(&YE960@(@HB=&\@96YT97(@=&AI<R!P87-S<&AR
M87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*(DOI<F5M(&%D
M:F$@;65G(&$@<WIE;>EL>65S+"!T:71K;W,@4R]-24U%(&MU;&-SX6AO>B!T
M87)T;WKS(&IE;&UO;F1A=&]T+B!%>B`B"B)C<V%K(&5G>7-Z97(@:V5L;"!B
M9>UR;FEA(&%L:V%L;6%N:^EN="!A("5S(&AA<WINX6QA=&%K;W(N(@H*(SH@
M<F5C;VUP;W-E+G!H<#HY-@IM<V=I9"`B(@HB4&QE87-E(&QO9R!I;B!A9V%I
M;B!T;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R
M92!.3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@
M;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R`B
M"B)L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4
M:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@(@HB:&EJ86-K:6YG('EO
M=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI
M96YC92XB"FUS9W-T<B`B(@HB2^ER:OQK(&IE;&5N=&ME>GIE;B!B92!I<VWI
M="!A(&QE=NEL[7+A<R!F;VQY=&%TX7/A:&]Z+B!(82!B]FYGZ7-Z]7!R;V=R
M86UJ82`B"B).14T@96YG963I;'EE>FD@82!C;V]K:64M:R!H87-Z;N%L873A
M="#)4R!F96QB=6MK86[S(&%B;&%K8F%N(.UR:F$@;&5V96QE:70@(@HB86MK
M;W(@82!F]2!A8FQA:V)A;B!I<R!B92!K96QL(&IE;&5N=&ME>FYI92X@17H@
M87H@UFX@8FEZ=&]N<^%G82#I<F1E:^EB96X@(@HB=F%N(.UG>2P@:&]G>2!N
M92!TZ7+M=&AE<W/I:R!E;"!A('-Z97)V97)R96P@:V]RX6)B86X@9F5LZ7#M
M=&5T="`B"B)K87!C<V]L873A="X@16QNZ7KI<^ET(&OI<FK\:R!A(&ME;&QE
M;65T;&5N<^EGZ7)T+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S$*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S
M='(@(DOI<F5M(&%D:F$@;65G(&$@:F5L<WIA=N%T+B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-C<*;7-G:60@(E!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64N(@IM<V=S='(@(DOI<F5M(&%D:F$@;65G(&$@8F5J96QE
M;G1K97KI<VD@;F5VZ70N(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])35`N
M<&AP.C0V,PIM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN
M=F%L:60@861D<F5S<V5S+B(*;7-G<W1R(")+Z7)E;2!J87;M='-A(&MI(&$@
M:&EBX7,@=F%G>2!N96T@96=YZ7)T96QM^R!C[6UE:V5T+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C,*;7-G:60@(E!L96%S92!S
M96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M('1H:7,@86-T:6]N
M+B(*;7-G<W1R(")+Z7)E;2!J96SV;&KV;B!K:2!E9WD@;6%P<.%T(&$@9F5L
M861A="!VZ6=R96AA:G3A<V$@96SU='0N(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]J879A<V-R:7!T+FEN8SHT,0IM<V=I9"`B4&QE87-E('-E;&5C="!A="!L
M96%S="!O;F4@9F]L9&5R('1O('-E87)C:"XB"FUS9W-T<B`B2^ER96T@:F5L
M]FQJ]FX@:VD@;&5G86SA8F(@96=Y(&UA<'#A="P@86UI8F5N(&$@:V5R97-N
M:2#S:&%J="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$R"FUS9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@
M=&AI<R!O<&5R871I;VXN(@IM<V=S='(@(DOI<F5M+"!H;V=Y(&5H:&5Z(&$@
M9F5L861A=&AO>B!C<V%K(&5G>2!M87!PX70@:F5L]FQJ]FX@:VDN(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"FUS9VED(")0;&5A
M<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM
M<V=S='(@(DOI<F5M+"!H;V=Y(&IO8F(@;VQD86QI(&UE>O5B96X@=N%L87-S
M>F$@:VDL('9A9WD@;?-D;W/M='-A.B(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD
M:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S='(@(D5Z(&5G
M>2!(;W)D92!R96YD<WIE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,30*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@
M*"<M+2`G*3\B"FUS9W-T<B`B(@HB3&5G>65N(&%Z(-9N(.%L;&%N9/,@;&5V
MZ6QVZ6=Z]63I<V4@*'-I9VYA='5R92D@96SU='0@:^ET(&OV=/5J96P@*"<M
M+2`G*3\B"@HC.B!S;6EM92YP:'`Z,C,W('!G<"YP:'`Z,C4S(&9I;'1E<G!R
M969S+G!H<#HS.0IM<V=I9"`B4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P
M9&%T960N(@IM<V=S='(@(D$@8F7A;&SM=.%S;VMA="!S:6ME<F5S96X@96QM
M96YT971T_&LN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N
M:6YC.C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B0F5T96MI;G3I<R(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G
M:60@(E!R979I;W5S($UE<W-A9V4B"FUS9W-T<B`B16SU>O4@;&5VZ6PB"@HC
M.B!M86EL8F]X+G!H<#HS,S,*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS9W-T
M<B`B16SU>O4@;VQD86PB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@(DYY;VUT873A
M<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X"FUS9VED
M(")0<FEO<FET>2(*;7-G<W1R(")0<FEO<FETX7,@*'/\<F?U<W/I9RDB"@HC
M.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S8*;7-G:60@(E!R
M:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@(D$@=&ET:V]S(&MU;&-S(&IE
M;'-Z879A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U.0IM<V=I9"`B
M4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A
M=6QT('1O($Y/(@IM<V=S='(@(E;A;&%S>G1H87-S86LL(&AA(&UE;&SI:VQE
M="!V86X@82!L97;I;&)E;CL@3D5-(&%Z(&%L87#I<G1E;&UE>F5T="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R
M>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B
M"FUS9W-T<B`B5N%L87-Z=&AA<W-A:RP@:&$@;65L;.EK;&5T('9A;B!A(&QE
M=NEL8F5N.R!)1T5.(&%Z(&%L87#I<G1E;&UE>F5T="(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM
M<V=S='(@(E!R;W1O:V]L;#HB"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HT,S`*
M;7-G:60@(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O<G0@:&%S(&)E96X@
M9&ES86)L960N(@IM<V=S='(@(D$@;GEI;';A;F]S(%!'4"!K=6QC<W-Z97)V
M97(@=.%M;V=A=.%S(&YI;F-S(&5N9V5DZ6QY>G9E+B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I9"`B4'5R7V=E($1E;&5T960B"FUS
M9W-T<B`B7U;I9VQE9V5S('3V<FSI<R(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L
M971E9"YI;F,Z-PIM<V=I9"`B4'5R9V4@1&5L971E9"(*;7-G<W1R(")6Z6=L
M96=E<R!T]G)LZ7,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHR-`IM<V=I9"`B4'5R9V4@1F]L9&5R*',I(@IM<V=S='(@(DUA<'!A*&LI
M('3V<FSI<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"FUS9VED
M(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(DUI;'EE;B!G>6%K
M<F%N(/QR[71S_&L@82`G4WIE;65T97,G("A4<F%S:"D@;6%P<.%T/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E(&UE<W-A
M9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F
M(&1A>7,N(@IM<V=S='(@(FYA<&[A;"!RZ6=E8F)I(&QE=F5L96ME="#\<NUT
M<_QK(&MI(&$@)U-Z96UE=&5S)R`H5')A<V@I(&UA<'#A8O-L(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B4'5R9V4@;VQD(&UE<W-A
M9V5S(&EN('1H92!4<F%S:"!F;VQD97(_(@IM<V=S='(@(D$@)U-Z96UE=&5S
M)R`H5')A<V@I(&UA<'#A8O-L('3V<O9L:OQK(&MI(&$@<NEG:2!L979E;&5K
M970_(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP
M.C8U"B,L('!H<"UF;W)M870*;7-G:60@(E!U<F=I;F<@)60@;65S<V%G97,@
M9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(B5D(&QE=NEL('3V<FSU9&EK
M(&$@)U-Z96UE=&5S)R`H5')A<V@I(&UA<'#A8O-L+B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV,PIM<V=I9"`B4'5R9VEN
M9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(C$@;&5V
MZ6P@=/9R;/5D:6L@82`G4WIE;65T97,G("A4<F%S:"D@;6%P<.%B\VPN(@H*
M(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHQ-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2DB"FUS9W-T<B`B2W;S=&$Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB
M"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250B"FUS
M9W-T<B`B2W;S=&$Z("4N,F9-0B`O(&YI;F-S(&QI;6ET(@H*(SH@=&5M<&QA
M=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1
M=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM<V=S='(@(DMV\W1A.B!N:6YC<R!L
M:6UI="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T<B`B263I>F5T("@E9BDZ
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,CD*;7-G:60@
M(E)E8G5I;&0@1F]L9&5R(%1R964B"FUS9W-T<B`BR7#M='/\:R#Z:G)A(&$@
M;6%P<&%S=')U:W3Z<N%T(@H*(SH@;&EB+U-E87)C:"YP:'`Z-C$W"FUS9VED
M(")296-E:79E9"!/;B(*;7-G<W1R(")%>F5N(&$@;F%P;VX@Z7)K97IE='0B
M"@HC.B!L:6(O4V5A<F-H+G!H<#HV,C4*;7-G:60@(E)E8V5I=F5D(%-I;F-E
M(@IM<V=S='(@(D5Z=73A;B#I<FME>F5T="(*"B,Z(&QI8B]396%R8V@N<&AP
M.C8R,0IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`B17IE;/5T="#I
M<FME>F5T="(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(L%T:7+A;GGM=.%S
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")2961I<F5C="(*;7-G<W1R("+!=&ERX6YY[73A<R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E9&ER
M96-T($UE<W-A9V4B"FUS9W-T<B`B02!L97;I;"#A=&ERX6YY[73A<V$B"@HC
M.B!C;VUP;W-E+G!H<#HX,C<*;7-G:60@(E)E9&ER96-T('1H:7,@;65S<V%G
M92(*;7-G<W1R("))<N%N>>UT<W5K(.%T(&5Z="!A(&QE=F5L970B"@HC.B!C
M;VUP;W-E+G!H<#HX.#`*;7-G:60@(E)E9&ER96-T:6YG(&9A:6QE9"XB"FUS
M9W-T<B`B07H@X71I<N%N>>UTX7,@;F5M('-I:V5R_&QT+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-S,*;7-G:60@(E)E9G)E<V@@1F]L9&5R(%9I
M97=S.B(*;7-G<W1R(")&<FES<^UT<_QK(&$@;6%P<.%K(&QI<W3A:N%T.B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHT"FUS9VED(")296QO860B"FUS9W-T<B`B1G)I
M<W/M=.ES(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I
M9"`B4F5L;V%D(%9I97<B"FUS9W-T<B`B2^ER:OQK(&QE(/IJ<F$@97IT(&%Z
M(&]L9&%L="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-PIM<V=I9"`B4F5M96UB97(@=&AE
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B5.%R;VQJ=6L@96P@
M87H@:63U8F5O<WITX7-I(&%D871O:V%T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-C@*;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS
M9W-T<B`B5.%R;VQJ=6L@96P@87H@=71O;'/S(&[I>F5T970B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T92!-
M86EL8F]X.B(*;7-G<W1R(")4X79O;&D@;&5VZ6QLX61A.B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I96QD
M($9R;VT@4V5A<F-H(@IM<V=S='(@(DAA9WEJ=6L@:VD@82!M97KU="!A(&ME
M<F5SZ7-B]6PB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS,#4*;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T<B`B=.%V;VSM='-U
M:R!E;"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*;7-G
M:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T<B`B36%P<&$H:RD@X71N979E
M>NES92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E
M;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B
M"FUS9W-T<B`B(@HB3F5V97IZ_&L@X70@87H@96QK_&QD]G1T(&QE=F5L96ME
M="!T87)T86QM87KS("AS96YT+6UA:6PI(&UA<'#A="!A(&CS;F%P("(*(F5L
M96KI;C\B"@HC.B!L:6(O1F]L9&5R+G!H<#HT-3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB02`@7"(E<UPB
M+7+U;"!<(B5S7"(M<F4@=/9R=.EN]2#A=&YE=F5ZZ7,@;F5M('-I:V5R_&QT
M+B!!('-Z97)V97(@_'IE;F5T92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS
M9W-T<B`B5N%L87-Z(&$@;&ES=.%R82(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T
M<B`B0W-E<NEL:OQK(&MI(&5Z>F5L.B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L>2(*;7-G<W1R(")6
MX6QA<WHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$R(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT,3`*;7-G:60@(E)E<&QY(%-E;G0N(@IM
M<V=S='(@(D$@=N%L87-Z="!E;&O\;&1T_&LN(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!!
M;&PB"FUS9W-T<B`B5N%L87-Z(&%Z(/9S<WIE<R!C[6UR92(*"B,Z(&-O;7!O
M<V4N<&AP.C<W,0IM<V=I9"`B4F5P;'D@=&\@06QL.B(*;7-G<W1R(")6X6QA
M<WH@87H@]G-S>F5S(&/M;7)E.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;'D@=&\@3&ES="(*;7-G
M<W1R(")6X6QA<WH@82!L:7-TX7)A(@H*(SH@8V]M<&]S92YP:'`Z-S<S"FUS
M9VED(")297!L>2!T;R!,:7-T.B(*;7-G<W1R(")6X6QA<WH@82!L:7-TX7)A
M.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ
M,PIM<V=I9"`B4F5P;'D@=&\@7T%L;"(*;7-G<W1R(")6X6QA<WH@87H@]G-S
M>F5S(&/M;7)E(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S,"!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,Y"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU-#D*;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E
M9"!-97-S86=E(@IM<V=S='(@(D%Z(&%D;W1T(&OI<NES="!A(')E;F1S>F5R
M(&YE;2!TX6UO9V%T:F$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3,W"FUS9VED(")297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO
M;G1H<RXB"FUS9W-T<B`B07H@:63U8F5O<WITX7-I(&%D871KZ7+I<W0@,B!H
M\VYA<')A('1E;&IE<^UT96TN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4S-@IM<V=I9"`B4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R(")!>B!I9/5B96]S>G3A<VD@861A=&OI
M<NES('1E;&IE<^UTZ7-E+B(*"B,Z(&UE<W-A9V4N<&AP.C(W-0IM<V=I9"`B
M4F5P;'DM5&\B"FUS9W-T<B`B5FES>F]N=';A;&%S>B!C[6TB"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#(P"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(E9I
M<WIO;G1VX6QA<WH@8^UM.B`B"@HC.B!C;VUP;W-E+G!H<#HW-CD*;7-G:60@
M(E)E<&QY.B(*;7-G<W1R(")6X6QA<WHZ(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E;G0B"FUS9W-T
M<B`B3F5M+7-P86T@8F5J96QE;G3I<R(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHS-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHR,PIM<V=I9"`B4F5P;W)T(&%S(%-P86TB"FUS9W-T<B`B4W!A
M;2!B96IE;&5N=.ES(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,S@V"FUS9VED(")297%U97-T(&$@7U)E860@4F5C96EP="(*;7-G<W1R
M(")6:7-S>F%I9V%Z;VSA<W0@:^ER96L@82!L97;I;"!E;&]L=F%SX7/A<O-L
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,PIM<V=I9"`B4F5Q=65S
M="!R96%D(')E8V5I<'1S/R(*;7-G<W1R(")+Z7(@=FES<WIA:6=A>F]LX7-T
M(&%R<O-L+"!A;6EK;W(@82!C[6UZ971T(&5L;VQV87-S82!A(&QE=F5L970_
M(@H*(SH@;6%I;&)O>"YP:'`Z,3@Y"FUS9VED(")297%U97-T960@;65S<V%G
M92!N;W0@9F]U;F0N(@IM<V=S='(@(D$@:^UVX6YT(&QE=NEL(&YE;2!T86SA
M;&AA=/,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y,@IM<V=I
M9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B<WK\:W/I9V5S('+I
M<WIT=F5V]2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3,X('1E
M;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHR.0HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,38R"FUS9VED(")297-E="(*;7-G<W1R(")297-E="(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,38*;7-G:60@(E)E<W!O;F1E
M;G0@4W1A='5S(%5P9&%T960N(@IM<V=S='(@(D$@=N%L87-Z863S('-TX71U
M<WKA="!M96?Z:NUT;W1T=6LN(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T<B`B1F]L
M>71A=.%S(@H*(SH@<F5C;VUP;W-E+G!H<#HY-PIM<V=I9"`B4F5S=6UE('EO
M=7(@<V5S<VEO;B(*;7-G<W1R(")&;VQY=&%S<W5K(&$@;&5VZ6SM<N%S="(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT-`IM<V=I9"`B
M4F5T=7)N('1O(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM<V=S='(@(E9I
M<W-Z82!A(%PB3&5VZ6SM<N%S7"(M:&]Z(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]D<FEV97)?<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT
M7W-E;&5C="YI;F,Z,S$*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM
M<V=S='(@(E9I<W-Z82!A(&QE=NELX71T]FQTZ7-H97HB"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T
M86-T:79E+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P
M,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN
M8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38S('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ-S4*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S
M='(@(E9I<W-Z82!A>B!O<&-I\VMH;WHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S`W"FUS9VED("(B"B)2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES
M=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S
M<V%G93\B"FUS9W-T<B`B5.ER:OQN:R!V:7-S>F$@82!L97;I;&QI<W3A:&]Z
M('3V<FSI<RP@X71H96QY97KI<R!V86=Y(&WA<V]LX7,@=73A;C\B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@S"FUS9VED(")2;VQE(@IM<V=S
M='(@(E-Z97)E<"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30R
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z-#(T"FUS9VED(")3+TU)344B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,@IM<V=I
M9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")!(&QE=NEL('1I
M=&MO<^UTX7-A(%,O34E-12UM86PB"@HC.B!C;VUP;W-E+G!H<#HS-S$*;7-G
M:60@(E,O34E-12!%<G)O<CH@(@IM<V=S='(@(E,O34E-12!H:6)A.B`B"@HC
M.B!C;VUP;W-E+G!H<#HS-3`*;7-G:60@(E,O34E-12!%<G)O<CH@3F5E9"!P
M87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B
M(@HB4R]-24U%(&AI8F$Z(&$@<WIE;>EL>65S('1I=&MO<R!K=6QC<R!H87-Z
M;N%L873A:&]Z(&IE;&UO;F1A="!S>OQK<^EG97,N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U,0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS9W-T
M<B`B4R]-24U%(&)EX6QL[73A<V]K(@H*(SH@<VUI;64N<&AP.C0V"FUS9VED
M(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("+-<FIA(&)E(&%Z
M(%,O34E-12!J96QM;VYD873A="(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-30*;7-G:60@(E,O34E-12!097)S;VYA;"!+97EP86ER('-U<'!O
M<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(B(*(D%Z(%,O34E-12!S>F5MZ6QY97,@:W5L8W-PX7(@=.%M;V=A=.%S('1I
M=&MO<^UT;W1T('=E8B!K87!C<V]L871O="!I9^EN>65L+B(*"B,Z('-M:6UE
M+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+
M97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(EPB)7-<(B!N>6EVX6YO<R!3+TU)344@:W5L8W/A="!S:6ME<F5S96X@
M=/9R]FQT_&LN(@H*(SH@<VUI;64N<&AP.C$U.`IM<V=I9"`B4R]-24U%(%!U
M8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")!(&YY:7;A
M;F]S(%,O34E-12!K=6QC<V]T('-I:V5R97-E;B!F96QV971T_&LN(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U
M8FQI8R!+97ER:6YG(@IM<V=S='(@(E,O34E-12!N>6EL=N%N;W,@:W5L8W-O
M:R(*"B,Z('-M:6UE+G!H<#HR,#<*;7-G:60@(E,O34E-12!0=6)L:6,O4')I
M=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B07H@
M4R]-24U%(&YY:6QVX6YO<R]T:71K;W,@:W5L8W-PX7)T('-I:V5R97-E;B!F
M96QV971T_&LN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T
M+FEN8SHQ,PIM<V=I9"`B4R]-24U%(%-I9VX@365S<V%G92(*;7-G<W1R("),
MX7-S=6L@96P@82!L979E;&5T(%,O34E-12!D:6=I=.%L:7,@86SA[7+A<W-A
M;"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*
M;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")4
M:71K;W/M='-U:R#I<R!D:6=I=.%L:7-A;B#M<FIU:R!A;.$@82!L979E;&5T
M(%,O34E-12UM86PB"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN
M8SHT"FUS9VED(")3+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES
M('-Y<W1E;2XB"FUS9W-T<B`B17IE;B!A(')E;F1S>F5R96X@;FEN8W-E;B!3
M+TU)344@=.%M;V=A=.%S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,C0Q"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*
M(F1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB07H@4R]-24U%('3A;6]G873A<R!J
M96QE;FQE9R!N:6YC<R!A:W1I=N%L=F$L(&5ZZ7)T(&$@:_-D;VQT(&QE=NEL
M('1A<G1A;&UA("(*(FYE;2!F96IT:&5T]2!V:7-S>F$N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-S,*;7-G:60@(B(*(E,O34E-12!S=7!P
M;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I
M9VYE9"!M97-S86=E(&-A;FYO="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@
M(B(*(D%Z(%,O34E-12!TX6UO9V%TX7,@:F5L96YL96<@;FEN8W,@86MT:7;A
M;'9A+"!E>NER="!E(&1I9VETX6QI<V%N(&%LX>UR="`B"B)L97;I;"!T87)T
M86QM82!N96T@:F5L96[M=&AE=/4@;65G+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N
M;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE
M('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)!>B!3+TU)344@=.%M
M;V=A=.%S(&IE;&5N;&5G(&YI;F-S(&%K=&EVX6QV82P@97KI<G0@82!L97;I
M;"!D:6=I=.%L:7,@(@HB86SA[7+A<^%N86L@:&ET96QE<W/I9V4@;F5M(&5L
M;&5N]7)I>FAE=/4N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR
M"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD
M;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N
M=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H
M86YG92!T:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U
M<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)!>B!3
M+TU)344@=.%M;V=A=.%S(&9E;&)U:VMA;O,@*'!O<'5P*2!A8FQA:V]K870@
M:6?I;GEE;"X@2&$@87H@UFX@(@HB8O9N9^ES>O5P<F]G<F%M:F$@^F=Y('9A
M;B!B9>%L;.UT=F$L(&AO9WD@;&5T:6QT:F$@82!F96QB=6MK86[S(&%B;&%K
M;VMA="P@(@HB86MK;W(@=F%G>2!VX6QT;WIT87-S;VX@82!B9>%L;.UTX7-O
M:V]N+"!V86=Y(&%Z(%,O34E-12!S>F]L9^%L=&%TX7-O:R!N96T@(@HB9F]G
M;F%K(&UE9V9E;&5L]65N(&W[:_9D;FDN(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,#0*;7-G:60@(E--5%`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4U"FUS9VED(")37W5B:F5C
M="(*;7-G<W1R(")?5.%R9WDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHS-C,*;7-G:60@(E-A7W9E(&$@8V]P>2!I;B`B"FUS9W-T<B`B
M365N='/\;FL@96P@96=Y('#I;&3A;GET(&5B8F5N(&$@;6%P<.%B86XZ("(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM
M<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B365N=.ES(@H*(SH@<V5A<F-H+G!H
M<#HS,#@@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W"FUS9VED
M(")3879E(@IM<V=S='(@(DUE;G3I<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4S-@IM<V=I9"`B4V%V92!!='1A8VAM96YT<R!W:71H
M(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B(@HB02!M
M96QLZ6ML971E:V5T(&$@;&5VZ6QL96P@96=Y_'1T(&UE;G1S_&L@96P@87H@
M96QK_&QD]G1T(&QE=F5L96L@;6%P<.%JX6)A;C\B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT,S`*;7-G:60@(E-A=F4@1')A9G0B"FUS9W-T<B`B365N='/\
M:R!E;"!M=6YK87#I;&3A;GEKZ6YT(@H*(SH@<V%V96EM86=E+G!H<#HT,@IM
M<V=I9"`B4V%V92!);6%G92(*;7-G<W1R(")!(&OI<"!E;&UE;G3I<V4B"@HC
M.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C(X"FUS9VED(")3879E($EM86=E
M(&EN($=A;&QE<GDB"FUS9W-T<B`B02!KZ7`@9V%LZ7)IX6)A;B!T]G)TZ6[U
M(&5L;65N=.ES92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU
M.2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O
M<VUI;64O;F]T86-T:79E+FEN8SHQ,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,30X"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B
M4V%V92!/<'1I;VYS(@IM<V=S='(@(DUE;G3I<R(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHT,`IM<V=I9"`B4V%V92!3=&%T:6]N97)Y
M(@IM<V=S='(@(D$@;&5VZ6QP87#M<B!E;&UE;G3I<V4B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,S`*;7-G:60@(E-A=F4@7T1R869T(@IM<V=S='(@(DUE
M;G1S_&L@96P@;75?;FMA<.EL9.%N>6OI;G0B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS
M9W-T<B`B365N=.ES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,0IM
M<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R(")!(&UU;FMA
M<.EL9.%N>6OI;G0@96QM96YT971T(&QE=F5L96ME="!O;'9A<V%T;&%N:^EN
M="!J96SV;&K\:R!M96<_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-C$*;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H
M92!D969A=6QT(&%D9')E<W,@8F]O:S\B"FUS9W-T<B`B(@HB365N='/\:R!E
M;"!A=71O;6%T:6MU<V%N(&$@8^UM>F5T=&5K(&%D871A:70@87H@86QA<.ER
M=&5L;65Z971T("(*(F/M;6IE9WEZZ6MB96X_(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHQ,C(*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER
M='5A;"!F;VQD97(_(@IM<V=S='(@(DUE;G1S_&L@96P@82!K97)E<^ES="!V
M:7)T=>%L:7,@;6%P<&%KZ6YT/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,S`*;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R(")-96YT<_QK
M(&5L(&%Z(&5L:_QL9/9T="!L979E;&5K970_(@H*(SH@8V]M<&]S92YP:'`Z
M,3(V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A
M:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B02!M=6YK87#I;&3A;GEKZ6YT('9A;/,@;65N=.ES(&YE;2!S:6ME<OQL
M="X@02!S>F5R=F5R(';A;&%S>F$Z("5S(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HU-`IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(DME<F5SZ7,B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VAE861E<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN
M8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@)7,B"FUS9W-T<B`B
M2V5R97/I<R!A*'HI("5S(&UA<'#A8F%N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R,`IM<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`B02!K
M97)E<^ES<V5L(&MA<&-S;VQA=&]S(&)EX6QL[73A<V]K(@H*(SH@<V5A<F-H
M+G!H<#HR-C,*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(D$@:V5R
M97/I<R!E<F5D;>EN>64B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$T('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@
M(E-E96XB"FUS9W-T<B`B;>%R(&]L=F%S;W1T(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHY"FUS9VED(")396QE8W0B"FUS9W-T<B`B5N%L
M87-S>G5K(&MI+"`H86UI*2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G
M<W1R(")6X6QA<W-Z;VX@:VD@96=Y(&WA<VEK(&%Z;VYO<^UT\W0B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(E-E;&5C="!A
M(&1A=&4B"FUS9W-T<B`B5N%L87-S>F]N(&MI(&5G>2!DX71U;6]T(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P"FUS9VED(")396QE8W0@
M82!F:65L9"(*;7-G<W1R(")6X6QA<W-Z;VX@:VD@96=Y(&UE>O5T(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$W"FUS9VED(")396QE
M8W0@82!S=&%T:6]N97)Y.B(*;7-G<W1R(")6X6QA<W-Z;VX@:VD@96=Y(&QE
M=NEL<&%P[7)T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G
M:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N
M9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB2VEVX6QA
M<WIT:&%T\RP@:&]G>2!M96QY:6L@8^UM:F5G>7KI:V5K:&5Z(&OM=N%N(&AO
M>GKA=&5N;FDL(&EL;"X@;65L>65K8F5N("(*(FOM=N%N(&ME<F5S;FDN(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I9"`B4V5L96-T
M(&%L;"(*;7-G<W1R(")-:6YD970@:VEJ96SV;&K\:R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L96-T(&%L
M;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB
M"FUS9W-T<B`B(@HB02!C[6URZ7-Z;&5T('1E;&IE<R!C[6UMZ2!A;&%K[73A
M<V%K;W(@82!C[6UJ96=Y>NEK96L@;6EN9&5N(&UE>O5JZ6)E;B`B"B)T]G)T
MZ6YJ96X@:V5R97/I<S\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U
M;G1?<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS
M9W-T<B`B5N%L87-S>F]N(&5G>2!A>F]N;W/M=/-T(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T
M<B`B16=Y('-E(&QE9WEE;B!K:6IE;/9L=F4B"@HC.B!T96UP;&%T97,O<V%V
M96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B4V5L96-T('1H92!G86QL
M97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R(")6X6QA<W-Z82!K
M:2P@;65L>6EK(&=A;.ER:>%B86X@:^UVX6YJ82!A(&OI<&5T(&5L:&5L>65Z
M;FDN(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN
M8SHR,0IM<V=I9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S
M='(@(E;A;&%S<WIA(&MI(&$@;&5V96QE>O5S>F5R=F5R('3M<'5SX70B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*;7-G:60@
M(E-E;&5C=&5D($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(D$@:VEVX6QA<WIT
M;W1T(&/M;6IE9WEZZ6ME:SHB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S(*;7-G:60@(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T
M<B`B2_QL9&K\:R!E;"!A(&MU;&-S;W0@96=Y(&YY:6QVX6YO<R!K=6QC<W-Z
M97)V97)R92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3<*;7-G
M:60@(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(DOI<F5M(&$@
M;&5G9G)I<W-E8F(@:6YF;W)MX6-I\VMA="(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0R.`IM<V=I9"`B4V5N9"!-97-S86=E(@IM<V=S='(@(DO\;&1J_&L@
M96PB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$R-@IM<V=I
M9"`B4V5N9"!M97-S86=E('=I=&AO=70@82!3=6)J96-T/R(*;7-G<W1R(")+
M_&QD:OQK(&5L(&$@;&5V96QE="!A(%3A<F=Y(&UE9V%DX7-A(&[I;&O\;#\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CDR"FUS9VED(")396YD(')E
M860@<F5C96EP="!W:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G
M<W1R("(B"B)+_&QD:OQN:R!A(&)EZ7)K97KU(&QE=NEL(&5L;VQV87/A<^%R
M\VP@=FES<WIA:6=A>F]LX7-T+"!H82!KZ7)T(&EL>65T(&$@(@HB9F5L863S
M/R(*"B,Z(&9O;&1E<G,N<&AP.C,W.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E
M<B(*;7-G<W1R(")!>B!E;&O\;&3V='0@;&5V96QE:R!M87!PX6IA(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I9"`B
M4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`B07H@96QK_&QD]G1T(&QE=F5L
M96L@;6%P<.%J83HB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S
M,R!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$T-0HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$U,@IM<V=I9"`B4V5R=F5R(@IM<V=S='(@(E-Z
M97)V97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*;7-G:60@(E-E
M<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E-Z97)V97(@
MZ7,@;6%P<&$@:6YF;W)MX6-I\VLB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B4WIE<G9E
M<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P
M<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD
M(&1E;&5T92!M97-S86=E<RXB"FUS9W-T<B`B02!L979E;&5K(.%T:&5L>65Z
MZ7/I=F5L(.ES('3V<FSI<^EV96P@:V%P8W-O;&%T;W,@8F7A;&SM=.%S;VLN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R.0IM<V=I9"`B4V5T('1H
M92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN9R!M97-S86=E<S\B
M"FUS9W-T<B`B3&5VZ6SM<N%S:V]R(&)EX6QL[73S9&KI:RUE(&$@6"U0<FEO
M<FET>2!F96ILZ6-S;W(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q
M"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(DUA<'#A:6YK(&AO>GKA
M9NERZ7-I(&IO9V]S=6QT<^%GX6YA:R!M96=O<WITX7-A(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C@V"FUS9VED(")3:&%R92!M86EL(&9O;&1E<G,B
M"FUS9W-T<B`B36%P<.%I;FMH;WH@=F%L\R!H;WIZX6;I<NES:2!J;V=O<W5L
M='/A9V]K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R"FUS9VED(")3
M:&%R92!Y;W5R(&UA:6P@9F]L9&5R<R!W:71H(&]T:&5R('5S97)S+B(*;7-G
M<W1R(")(;WIZX6;I<NES="!A9&AA="!MX7,@9F5L:&%S>F[A;/-K;F%K(&5G
M>65S(&UA<'#A:6AO>BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4W
M"FUS9VED("(B"B)3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT
M(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@(@HB
M=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N(@IM<V=S='(@
M(B(*(D$@:&]S<WKZ(&)E:63I>F5T="!L97;I;'+I<WIL971E:V5T(&%L87#I
M<G1E;&UE>NES:^EN="!N92!M=71A<W-U:S\@0N%R:&]G>2`B"B)VX6QA<WIO
M;"P@97H@:_9N;GEE;B!K:2]B96MA<&-S;VQH873S+B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@;V8@=&5X
M="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\B"FUS
M9W-T<B`B02!T97AT+W!L86EN(&QE=F5L96L@=/9R>G/I="!V:7IS9^%L:G5K
M(';I9VEG(%!'4"!A9&%T;VMA="!K97)E<W9E/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD
M;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R("(B
M"B)#<W5K\V1J;VXM92!B92!A>B!A8FQA:RP@:&$@;&5VZ6SM<N%S:V]R(&UU
M;FMA<.EL9.%N>6OI;G0@96QM96YT:OQK(&%Z("(*(F%D9&EG:2!M=6YKX6YK
M870_(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0*;7-G:60@(E-H;W5L
M9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@
M;65S<V%G97,@8GD@9&5F875L=#\B"FUS9W-T<B`B2_QL9&K\:R!E;"!A>B#6
M;B!01U`@;GEI;';A;F]S(&MU;&-SX70@;65L;.EK;&5T:^EN="!M:6YD96X@
M;&5VZ6QL96P_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@IM
M<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")-=71A<W-U:R!A>B#V
M<W-Z97,@;6%P<.%T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-C<*;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B375T87-S
M=6L@82!L97;I;"!T96QJ97,@9F5J;.ECZ70B"@HC.B!M86EL8F]X+G!H<#HS
M-3$*;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R(")!('3V<O9L=&5K970@
M:7,@;75T87-S=6LB"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN
M8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D($AE861E<G,B"FUS9W-T<B`B0W-A
M:R!A('-Z;VOA<V]S(&9E:FSI8W+I<WIE:V5T(&UU=&%S<W5K(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-S`*;7-G:60@(E-H;W<@36%I
M;&EN9R!,:7-T($EN9F]R;6%T:6]N(@IM<V=S='(@(D$@;&5V96QE>NES:2!L
M:7-TX7)A('9O;F%T:V]Z\R!I;F9O<FWA8VGS:R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D
M($9O;&1E<G,B"FUS9W-T<B`B0W-A:R!A(&AA<WINX6QA=&)A(&AE;'EE>F5T
M="`H<W5B<V-R:6)E9"D@;6%P<.$H:V$I="!M=71A<W-U:R(*"B,Z(&9O;&1E
M<G,N<&AP.C(X-`IM<V=I9"`B4VAO=R!5;G-U8G-C<FEB960B"FUS9W-T<B`B
M02!H87-Z;N%L871O;B!K[7;\;"!H96QY97IE='0@*'5N<W5B<V-R:6)E9"D@
M;6%P<.%K870@:7,@;75T87-S=6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3DV"FUS9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG
M(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(E-Z_&MS
MZ6=E('9A;BUE(&]L>6%N(&EK;VYR82P@86UI=F5L(&MI=/9R]FQH973U(&5G
M>2!L97;I;"!M96QLZ6ML971E/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.3$*;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_
M(@IM<V=S='(@(DQE9WEE;B!J96QM86=Y87+A>F%T(&$@;&5VZ6QL:7-TX6L@
M;65G:F5L96[M=.ES96MO<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#(Y"FUS9VED(")3:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@
M;VYL>3\B"FUS9W-T<B`B0W-A:R!A>B!O;'9A<V%T;&%N(&QE=F5L96MN96L@
M;&5G>65N(&5L]6[I>F5T93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#,W"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R
M("(B"B)!>B!E;/5NZ7IE="!A:VMO<B!J96QE;FIE;B!M96<L(&AA(&%Z(&5G
M97)E="!A(&QE=NEL('-O<F$@9O9LZ2!V:7-S>OQK/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-C8*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA:6P@
M:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B3&5G>65N(&$@;65N_&)E
M;B!E9WD@3&5VZ6SA='3V;'3I<R!I:V]N/R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HY.`IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM<V=S='(@
M(DUU=&%S<W5K(&$@:^EP96ME="(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHU-`IM<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC;VX@;VX@=&AE
M(&UE;G5B87(_(@IM<V=S='(@(DQE9WEE;B!E9WD@:6MO;B!A(&QE=NEL<WK[
M<NES:&5Z(&$@;65N_'-O<F)A;C\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,S$*;7-G:60@(E-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O
M;&1E<C\B"FUS9W-T<B`B375T87-S=6L@82!M87!P82#V<W-Z97,@;&5V96QE
M:6YE:R!S>N%MX70_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U-`IM
M<V=I9"`B4VAO=VXB"FUS9W-T<B`B;75T87-S=6LB"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0R"FUS9VED(")3:5]Z92(*
M;7-G<W1R(")-Z7)E="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI
M;F,Z,3<*;7-G:60@(E-I9VYE9"(*;7-G<W1R(")$:6=I=.%L:7-A;B!A;.'M
M<G0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM
M<V=I9"`B4VEZ92(*;7-G<W1R(")-Z7)E="(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3$*;7-G:60@(E-O<G0@8GD@07)R
M:79A;"(*;7-G<W1R(")"9>ER:V5ZZ7,@<WIE<FEN=&D@<V]R<F5N9"(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,38*;7-G
M:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R("))9/5P;VYT('-Z97)I;G1I('-O
M<G)E;F0B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C(V"FUS9VED(")3;W)T(&)Y($9R;VT@061D<F5S<R(*;7-G<W1R(")&
M96QA9/,@<WIE<FEN=&D@<V]R<F5N9"(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*;7-G:60@(E-O<G0@8GD@365S<V%G
M92!3:7IE(@IM<V=S='(@(DQE=NEL;>ER970@<WIE<FEN=&D@<V]R<F5N9"(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S8*
M;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R(")4X7)G>2!S>F5R:6YT
M:2!S;W)R96YD(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHS,0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B3&]G
M:6MA:2`H=&AR96%D*2!S;W)R96YD(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R
M97-S(@IM<V=S='(@(D/M;7IE='0@<WIE<FEN=&D@<V]R<F5N9"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR,PIM<V=I9"`B4W!A;2!F
M;VQD97(Z(@IM<V=S='(@(E-P86T@;6%P<&$Z(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,S0V"FUS9VED(")3<&5C:6%L($-H87)A8W1E
M<G,B"FUS9W-T<B`B4W!E8VGA;&ES(&MA<F%K=&5R96LB"@HC.B!S96%R8V@N
M<&AP.C$T,@IM<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N;F]T
M(&)E(&5D:71E9"XB"FUS9W-T<B`B02!S<&5C:>%L:7,@=FER='7A;&ES(&UA
M<'#A:R!N96T@;?-D;W/M=&AA=/-K+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,T,PIM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`B
M2&5L>65S[7+A<V5L;&5N]7)ZZ7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z-#8*;7-G:60@(E-P96QL($-H96-K97(B"FUS9W-T<B`B
M2&5L>65S[7+A<V5L;&5N]7)Z]2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@(D$@:&5L
M>65S[7+A<V5L;&5N]7)ZZ7,@8F5F96IE>O5D]G1T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0W,0IM<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S
M8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T<B`B2&5L>65S[7+A
M<V5L;&5N]7)ZZ7-K;W(@87H@96=Y(&OI<&5R;GGU;B!M96=J96QE;NUT971T
M(&AI8N%K('-ZX6UA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,#<@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4P.0HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C0R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-#0*;7-G:60@(E-T87)T(@IM<V=S='(@(DME>F1E="(*"B,Z('1E;7!L871E
M<R]S=&%T:6]N97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R("),97;I
M;'!A<.UR(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V
M"FUS9VED(")3=&%T:6]N97)Y(&YA;64Z(@IM<V=S='(@(D$@;&5VZ6QP87#M
M<B!N979E.B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR
M.`IM<V=I9"`B4W1A=&EO;F5R>2!T>7!E.B(*;7-G<W1R(")!(&QE=NEL<&%P
M[7(@9F%J=.%J83HB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,S,*;7-G:60@(E-T871I;VYE<GDZ(@IM<V=S='(@(DQE=NEL<&%P[7(Z
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,PIM<V=I9"`B4W1A
M='5S(@IM<V=S='(@(E-TX71U<WHB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP
M:'`Z,C,Y"FUS9VED(")3=')I<"!!='1A8VAM96YT(@IM<V=S='(@(D$@;65L
M;.EK;&5T(&5L=.%V;VSM=.%S82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,C$*;7-G:60@(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S='(@(DAA9WEJ
M=6L@9FEG>65L;65N(&OM=OQL(&$@<V]R=/9RZ7-E:V5T/R(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*;7-G:60@(E-U
M8E]J96-T(@IM<V=S='(@(E3A<F=Y(@H*(SH@;65S<V%G92YP:'`Z,C<V('1H
M<F5A9"YP:'`Z,34U('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z
M,C4*(SH@;&EB+U-E87)C:"YP:'`Z-C`U"FUS9VED(")3=6)J96-T(@IM<V=S
M='(@(E3A<F=Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP.0IM<V=I
M9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R(")4X7)G>2!M97KU(@H*(SH@<V5A
M<F-H+G!H<#HS,3`@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC
M.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,"!T96UP
M;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"FUS9VED(")3=6)M:70B"FUS
M9W-T<B`B2_QL9&K\:R!E;"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R*',I(@IM<V=S
M='(@(D$@;6%P<.$H:V$I="!H96QY97IZ_&L@:&%S>F[A;&%T8F$@*'-U8G-C
M<FEB92DB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X-2!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HS.3,*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z.#<*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4VEK97+\;'0B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@
M(E-U9V=E<W1I;VYS(@IM<V=S='(@(DIA=F%S;&%T;VLB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C4Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-C$*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BUG-S>F5F;V=L86SA<R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Y-R!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#`*;7-G:60@(E-W:71C:"!#;VUP
M;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B5N%L='-U;FL@;&5VZ6SM<N%S:2!M
M\V1O="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,0IM
M<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I;VXB"FUS9W-T<B`B5N%L
M='-U;FL@2%1-3"!F;W)MX71U;?H@;&5VZ6SM<N%S<F$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#$*;7-G:60@(E-W:71C:"!T;R!P
M;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@(E;A;'1S=6YK('-I;6$@
M=&5X="!F;W)MX71U;?H@;&5VZ6SM<N%S<F$B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,38*;7-G:60@(E1E7WAT(@IM<V=S='(@(E]3
M>O9V96<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C<P"FUS9VED
M(")496YT871I=F4Z("(*;7-G<W1R(")&96QTZ71E;&5S.B`B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3@V"FUS9VED(")496YT871I=F5L>2!!
M8V-E<'0@<F5Q=65S="(*;7-G<W1R(")F96QTZ71E;&5S96X@96QF;V=A9&]M
M(&$@;65G:.UVX7-T(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U
M-`IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B9F5L=.ET
M96QE<V5N(&5L9F]G861V82(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O
M<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E<FUS
M(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP(@IM
M<V=S='(@(B(*(D$@8V]N9BYP:'`M8F5N(&YI;F-S(&UE9V%D=F$@82!3>F]L
M9^%L=&%TX7,@1F5L=.ET96QE:70@=&%R=&%L;6%Z\R!FX6IL+B(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*
M;7-G<W1R(")3>O9V96<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30S
M"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L
M9"!B92!L:6YK960Z(@IM<V=S='(@(D$@;&5VZ6P@1F5L863S(&]S>FQO<.%R
M82!K871T:6YT=F$@;6D@=/9R=.EN:F5N.B(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z-3(U"FUS9VED("(B"B)4:&4@24U!4"!S97)V97(@9&]E<R!N;W0@
M87!P96%R('1O('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"`B
M"B)S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@HB07H@24U!4"!S>F5R=F5R(/IG>2!T^VYI
M:RP@;F5M('3A;6]G871J82!A(&MI=N%L87-Z=&]T="`B"B)F96QH87-Z;N%L
M\V%Z;VYO<^UTX7-I(&WS9'-Z97)T+B!&;W)D=6QJ;VX@82!R96YD<WIE<F=A
M>F3A:&]Z+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z
M-#$*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R
M(")-86-I;G1O<V@@7")R97-O=7)C92!F;W)K7"(B"@HC.B!L:6(O34E-12]6
M:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E
M9"`E<RXB"FUS9W-T<B`B02!-86-I;G1O<V@@7")R97-O=7)C92!F;W)K7"(@
M;&5T]FQT:&5T]2`E<RXB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%Z;VYO<^UT\W0@:VET
M]G+V;'3\:RXB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!A>F]N;W/M=/-T(&5L;65N=&5T=/QK
M+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C0S"FUS9VED(")4:&4@871T86-H;65N
M="!W87,@;F]T(&9O=6YD+B(*;7-G<W1R(")!(&UE;&SI:VQE="!N96T@=&%L
MX6QH873S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,0IM<V=I
M9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R(")!(&YA
M<'3A<B!A9&%T;VL@:&EBX7-A:R]E;&9O9V%D:&%T871L86YO:R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C
M;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G
M<W1R(")!($UA8VEN=&]S:"!FX6IL('1A<G1A;&UA(&%LX6)B('1E:VEN=&AE
M=/4@;65G+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT
M;6%I;%]M;VYT:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T;R!<
M(B5S7"(N(@IM<V=S='(@(D$@7"(E<UPB(&UA<'!A*&MA*70@X71N979E>GK\
M:R!<(B5S7"(M<F4N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P-PIM
M<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S
M<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM<V=S
M='(@(B(*(DYE;2!S:6ME<OQL="!M96=H873A<F]Z;FD@87IO:VYA:R!A(&9E
M;&AA<WINX6SS:VYA:R!A(&QI<W3A:N%T(&%K:6L@(@HB:&]Z>N%FZ7)N96L@
M96AH97H@82!M87!PX6AO>BXB"@HC.B!C;VUP;W-E+G!H<#HQ,C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T
M:&4@7"(E<UPB(&9O;&1E<BXB"FUS9W-T<B`B02!M=6YK87#I;&3A;GET(&$H
M>BD@7"(E<UPB(&UA<'#A8F%N(&UE;G1E='3\:R!E;"XB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,30P"FUS9VED(")4:&4@979E;G0@=V%S(&%D
M9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(D%Z(&5S96WI;GET(&)E
M[7)T=6L@82!N87!TX7+A8F$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP
M86YD+FEN8SHY"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L9"!<(B5S
M7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&UE
M>O4@=&%R=&%L;6$@;F5M(&5GZ7-Z[71H973U(&MI+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(")!(%PB)7-<(B!N97;[(&UA
M<'!A(&WA<B!LZ71E>FEK(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38R"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS
M(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E
M("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(D$@7"(E<UPB(&9O;&1E<B!N97;I8F5N(&YE
M;2!M96=E;F=E9&5T="!K87)A:W1E<F5K('9A;FYA:RX@17H@9V]N9&]T("(*
M(F]K;WIH870N($OI<F5M(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N
M;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B(@HB02!<(B5S7"(@;6%P
M<.%T(&SI=')E:&]Z='5K+"!D92!N:6YC<R!H87-Z;N%L871B82!H96QY97IV
M92`H<W3A='5S>F$@(@HB=6YS=6)S8W)I8F5D*2(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C(V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<
M(B!W87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F
M<F]M(&ET+B(*;7-G<W1R("(B"B)!(%PB)7-<(B!M87!PX70@=/9R]FQT_&LL
M(&1E('1O=N%B8G)A(&ES(&AA<WINX6QA=')A('9A;B!K:6IE;/9L=F4@*'-T
MX71U<WIA("(*(G-U8G-C<FEB960I(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S,X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N
M;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G
M<W1R(")!(%PB)7-<(B!M87!PX70@;F5M('-I:V5R_&QT(&SI=')E:&]Z;FDN
M($$@<WIE<G9E<B#\>F5N971E(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@
M9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R
M(")!*'HI(%PB)7-<(B!M87!PX70@;F5M('-I:V5R_&QT('3V<O9L;FDN($$@
M<WIE<G9E<B#\>F5N971E(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4T"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B02!<(B5S7"(@;6%P<.%T('-I:V5R
M97-E;B!LZ71R96AO>G1U:RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E
M<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")!(%PB)7-<(B!M87!PX70@<VEK
M97)E<V5N('3V<O9L=/QK+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0U-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S
M<V9U;&QY(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")!(%PB)7-<(B!M
M87!PX70@<VEK97)E<V5N(.%T;F5V97IT_&L@7"(E<UPB+7)E+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY-`IM<V=I9"`B5&AE(&9O;&QO=VEN
M9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R=#HB"FUS9W-T<B`B
M16AH97H@82!RZ7-Z:&5Z(&$@:_9V971K97KU(&;A:FQO:V%T(&-S871O;'3A
M:SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P;W!U<"YJ<SHU.0IM<V=I
M9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D
M+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@(@HB=&\@8FQO
M8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB02!KZ7`@96QM96YTZ7/I
M:&5Z('-Z_&MSZ6=E<R!A8FQA:R!N96T@;GEI=&AA=/,@;65G+B!,96AE="P@
M:&]G>2!A("(*(F+V;F?I<WKU<')O9W)A;6IA(&)EX6QL[73A<V%I8F%N(&QE
M=&EL=&]T=&$@82!F96QB=6MK86[S("AP;W!U<"D@86)L86MO:V%T/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G:60@(B(*(E1H92!I
M;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES
M('!R97-E;G0@:6X@>6]U<B`B"B)A9&1R97-S8F]O:RXB"FUS9W-T<B`B(@HB
M02!KZ7!E:V5T(&UE9VIE;&5N[71J_&LL(&UE<G0@82!F96QA9/,@;65G=&%L
MX6QH873S(&%Z(-9N(&/M;6IE9WEZZ6OI8F5N+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N
M97)A=&5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B
M02!L979E;&5Z]7-Z97)V97(@82!K]G9E=&ME>O4@:&EB8?QZ96YE=&5T(&O\
M;&1T93HB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU
M,0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W
M:6YG(&EN9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`B02!L979E;&5Z
M]7-Z97)V97(@82!K]G9E=&ME>O4@=.%JZ6MO>G1A=.%S="!K_&QD=&4Z(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H92!M
M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.B(*
M;7-G<W1R(")!(&QE=F5L97KU<WIE<G9E<B!A(&OV=F5T:V5Z]2#\>F5N971E
M="!K_&QD=&4Z(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8Y,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*
M;7-G<W1R(")!(%PB)7-<(B!N97;[(&UA<'!A(&WA<B#\<F5S+B(*"B,Z(&QI
M8B]&971C:&UA:6PN<&AP.C(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S
M(&9E=&-H('-I>F4@;&EM:70N(@IM<V=S='(@(B(*(D$@7"(E<UPB(&QE=NEL
M("AI;FYE;CH@)7,L(&WI<F5T93H@)60@8N%J="D@;F%G>6]B8BP@;6EN="!A
M(&UE9V5N9V5D971T("(*(FQE9VYA9WEO8F(@X71T]FQT:&5T]2!L97;I;"XB
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PIM<V=I
M9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D
M+B!%>&ET:6YG+B(*;7-G<W1R(")!>B#I<'!E;B!F;V=A;&UA>F]T="!L97;I
M;"!B97KA<F]D;W1T+B!+:6SI<.ES(&OV=F5T:V5Z:6LN(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,C8*;7-G:60@(E1H92!M97-S86=E
M(&1O97,@;F]T(&AA=F4@82!3=6)J96-T(&5N=&5R960N(@IM<V=S='(@(DYE
M;2#M<G0@<V5M;6ET(&$@;&5VZ6P@5.%R9WD@;65Z96KI8F4N(@H*(SH@;65S
M<V%G92YP:'`Z,30Y"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R(")!(&QE=F5L970@:VET]G+V;'3\:RXB"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HS.3<*;7-G:60@(E1H92!M97-S86=E(&AA
M<R!B965N('9E<FEF:65D+B(*;7-G<W1R(")!(&QE=NEL('1A<G1A;&UA(&UE
M9V9E;&5L(&$@9&EG:73A;&ES(&%LX>URX7-N86LN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HS.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@)7,N(@IM<V=S
M='(@(D$@;&5VZ6P@=&%R=&%L;6$@;65G9F5L96P@82!D:6=I=.%L:7,@86SA
M[7+A<VYA:RX@02!F96QA9/,Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!R87<@=&5X="!O
M9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T
M<B`B02!01U`@;GEI;';A;F]S(&MU;&-S(&UE9VIE;&5N[73I<V4@;GEE<G,@
M<WKV=F5G97,@9F]R;>%T=6UB86XZ("5S(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W1N968N<&AP.C8P"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N
M;W0@97AI<W0@:6X@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B
M02!K[7;A;G0@X6QL;VWA;GD@;FEN8W,@8F5N;F4@87H@35,M5$Y%1B!M96QL
MZ6ML971B96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G
M:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@
M6FEP(&%T=&%C:&UE;G0N(@IM<V=S='(@(D$@:^UVX6YT(.%L;&]MX6YY(&YI
M;F-S(&)E;FYE(&$@6FEP(&UE;&SI:VQE=&)E;BXB"@HC.B!M97-S86=E+G!H
M<#HU-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('-E;F1E<B!O9B!T
M:&ES(&UE<W-A9V4@:7,@<F5Q=65S=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N("(*(F9R;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A
M9"!T:&ES(&UE<W-A9V4N(%!L96%S92!C;&EC:R`E<R!T;R!S96YD('1H92`B
M"B)N;W1I9FEC871I;VX@;65S<V%G92XB"FUS9W-T<B`B(@HB02!F96QA9/,@
M=FES<WIA:6=A>F]LX7-T(&OI<B!A<G+S;"P@:&]G>2#6;B!E;&]L=F%S=&$@
M97IT(&$@;&5V96QE="X@2^ER96T@)2(*(G,@:V%T=&EN='-O;BP@:&$@=&5L
M:F5S[71E;FD@:^UVX6YJ82!E>G0@82!KZ7+I<W0N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z-C<*;7-G:60@(E1H92!S97)V97(@=V%S(&YO
M="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*
M;7-G<W1R(")!('-Z97)V97(@;F5M('1U9&]T="!P:6-I(';A;'1O>F%T;W0@
M8W-I;N%L;FD@82!KZ7!B]6PN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YJ<SHY,`IM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L9"!N;W0@8F4@
M<F5P;&%C960N(@IM<V=S='(@(D%Z(.%L;&%N9/,@;&5VZ6QVZ6=Z]63I<W0@
M*'-I9VYA='5R92D@;F5M('-I:V5R_&QT(&9E;/QL[7)N:2XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C@X"FUS9VED(")4:&4@<VEG;F%T
M=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N(@IM<V=S='(@(D%Z(.%L
M;&%N9/,@;&5VZ6QVZ6=Z]63I<W0@*'-I9VYA='5R92D@<VEK97)E<V5N(&UE
M9W;A;'1O>G1A='1U:RXB"@HC.B!A='1A8VAM96YT+G!H<#HU.0IM<V=I9"`B
M5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!
M(&UE9V%D;W1T(&;A:FP@;F5M(&SI=&5Z:6LN(@H*(SH@<W1A=&EO;F5R>2YP
M:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E
M<UPB(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R("),Z71R96AO>G1U:R!A*'HI
M(%PB)7-<(B!L97;I;'!A<.UR="XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B02AZ*2!<(B5S7"(@;&5VZ6QP87#M
M<G0@=/9R]FQT_&LN(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N('5P
M9&%T960N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&QE=NEL<&%P[7)T(&WS9&]S
M[71O='1U:RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<P"FUS
M9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T
M+B(*;7-G<W1R(")!(&9E;&%D871O="!H;WIZX>UR='5K(&$@;&ES=.%H;WHN
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G:60@(E1H
M92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(D$@;&5VZ6P@<WKV=F5G
M92(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(D$@;&5VZ6P@<WKV=F5G92!M96=T96MI;G1H
M973U("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R
M(")!(';A;&%S>B!S>O9V96=E(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M(')E='5R;F5D(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B
M02!VX6QA<WH@<WKV=F5G92!M96=T96MI;G1H973U("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@(D%Z(&5L:_QL9/9T="!L
M97;I;"!S>O9V96=E(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M('-E;G0@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")!>B!E
M;&O\;&3V='0@;&5VZ6P@<WKV=F5G92!M96=T96MI;G1H973U("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-34*;7-G:60@(E1H92!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R
M960N(@IM<V=S='(@(D$@9F5L:&%S>F[A;/,@96QF;V=L86QT<^%G:2!A9&%T
M86ET('-I:V5R97-E;B!E;&UE;G1E='3\:RXB"@HC.B!L:6(O34E-12]6:65W
M97(O86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT
M97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB
M"FUS9W-T<B`B(@HB02!L97;I;&YE:R!N:6YC<R!O;'EA;B!A;'1E<FYA=.UV
M('+I<WIE+"!M96QY(&$@8O9N9^ES>O5P<F]G<F%M:N%B86X@(@HB;65G:F5L
M96[M=&AE=/4@;&5N;F4N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?
M;6%I;&)O>"YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN
M('1H:7,@;6%I;&)O>"XB"FUS9W-T<B`B16)B96X@82!M87!PX6)A;B!N:6YC
M<R!L97;I;"XB"@HC.B!T:')E860N<&AP.C$Q,`IM<V=I9"`B5&AE<F4@:7,@
M;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M(").:6YC<R!A(&QE=NEL(&)E;'-E:NEB96X@;65G:F5L96[M=&AE=/4@<WKV
M=F5G+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB
M;W@N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@HB2&EB82!J96QE
M;G1K97IE='0@82!T]G+V;'0@;&5V96QE:VYE:R!A(&QE=NEL;.%DX6+S;"!T
M]G)TZ6[U(&MI_'+M=.ES96MO<BX@02`B"B)S>F5R=F5R(/QZ96YE=&4Z("5S
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Q,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@8V]P>6EN9R!M97-S86=E<R!F<F]M
M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R
M('-A:60B"FUS9W-T<B`B(@HB02!L979E;&5K(%PB)7-<(BUB]6P@7"(E<UPB
M(&UA<'#A8F$@=/9R=.EN]2!MX7-O;.%S86MO<B!H:6)A('3V<G3I;G0N($$@
M(@HB<WIE<G9E<B#\>F5N971E(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(R-B!L
M:6(O365S<V%G92YP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F
M;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED
M(@IM<V=S='(@(D$@;&5V96QE:R!<(B5S7"(@;6%P<.%B\VP@=F%L\R!T]G)L
MZ7-E(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R(/QZ96YE=&4B"@HC.B!L:6(O
M365S<V%G92YP:'`Z,S(P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R
M(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G
M<W1R(")!(&QE=F5L96L@7"(E<UPB(&UA<'#A8O-L('9A;/,@=/9R;.ES92!N
M96T@<VEK97+\;'0N($$@<WIE<G9E<B#\>F5N971E(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("5S(@IM<V=S='(@(D$@;&5V96QE:R!T]G)LZ7-E:V]R(&AI
M8F$@=/9R=.EN="X@02!S>F5R=F5R(/QZ96YE=&4Z("5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS
M9W-T<B`B2&EB82!T]G)TZ6YT(&%Z(&5S96WI;GD@=/9R;.ES96MO<CH@)7,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-12]6
M:65W97(O96YR:6-H960N<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")!(&QE
M=NEL(&4@<NES>NEN96L@;65G:F5L96[M=.ES96MO<B!H:6)A('3V<G3I;G0B
M"@HC.B!L:6(O365S<V%G92YP:'`Z-3DT"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T
M:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@
M<V%I9"(*;7-G<W1R("(B"B)!(&QE=F5L96L@7"(E<UPB(&UA<'#A8F%N('9A
M;/,@;65G:F5L]FSI<V4@<V]RX6X@:&EB82!T]G)TZ6YT+B!!('-Z97)V97(@
M(@HB_'IE;F5T92(*"B,Z(&9O;&1E<G,N<&AP.C$T.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G
M<W1R("(E<R!I;7!O<G3A;.%S82!S;W+A;B!H:6)A('3V<G3I;G0N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@
M)7,N(@IM<V=S='(@(D%Z(&5S96WI;GD@:6UP;W)TX6SA<V$@<V]RX6X@:&EB
M82!T]G)TZ6YT.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(D$@9F5L861A="!I;7!O
M<G3A;.%S82!S;W+A;B!H:6)A('3V<G3I;G0Z("5S(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF
M;W)M871I;VXZ("5S+B(*;7-G<W1R("(B"B)!(&9E;&AA<WINX6SS(&5L9F]G
M;&%L='/A9VD@861T86EN86L@:6UP;W)TX6SA<V$@<V]RX6X@:&EB82!T]G)T
MZ6YT.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E
M<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB
M<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB02!L979E;&5K(%PB)7-<(BUB]6P@
M7"(E<UPB(&UA<'#A8F$@=F%L\R#A=&AE;'EE>NES92!S;W+A;B!H:6)A('3V
M<G3I;G0N($$@(@HB<WIE<G9E<B#\>F5N971E(@H*(SH@8V]M<&]S92YP:'`Z
M,3(X,`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE
M<W-A9V4@87,@82!D<F%F="XB"FUS9W-T<B`B02!L97;I;"!M=6YK87#I;&3A
M;GEKZ6YT('9A;/,@96QM96YTZ7-E:V]R(&AI8F$@=/9R=.EN="XB"@HC.B!C
M;VUP;W-E+G!H<#HQ,#,Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS9W-T<B`B
M02!L97;I;"!K_&QDZ7-E:V]R(&AI8F$@=/9R=.EN=#H@)7,B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S+B(*
M;7-G<W1R(")!>B!E<V5MZ6YY(&%D871A:6YA:R!F96S\;.URX7-A:V]R(&AI
M8F$@=/9R=.EN=#H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP
M.C4Y"FUS9VED(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@
M<&%R="(*;7-G<W1R(")!(&QE=NEL(&4@<NES>NEB96X@;F5M('9O;'0@<WKV
M=F5G(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P,`IM<V=I9"`B
M5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB
M"FUS9W-T<B`B17H@82!(5$U,(&QE=NEL(&OI<&5K970@=&%R=&%L;6%Z+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY,PIM<V=I9"`B(@HB5&AI
M<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO
M8VME9"!I;6%G97,@87!P96%R(&QI:V4@(@HB=&AI<SH@(@IM<V=S='(@(B(*
M(D5Z(&$@2%1-3"!L97;I;"!KZ7!E:V5T('1A<G1A;&UA>BX@02!N96T@;65G
M:F5L96[M=&5T="!KZ7!E:R!H96QYZ6X@97H@(@HB;.%T<WII:SH@(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U"FUS9VED(")4:&ES(%!'4"!0
M=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T
M<B`B02!L97;I;&AE>B!E>G0@82!01U`@;GEI;';A;F]S(&MU;&-S;W0@8W-A
M=&]L=.%K+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#4@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q.0HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,30T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3@*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W-"!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,S$U"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(")%>G0@82!VX6QA<WITX7-I(&QE:&5T]7/I9V5T(&$@
M<F5N9'-Z97(@;F5M('3A;6]G871J82XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3@P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,C`*;7-G
M:60@(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S
M='(@(D5Z="!A(';A;&%S>G3A<VD@;&5H973U<^EG970@82!R96YD<WIE<B!E
M9WEE;/5R92!N96T@=.%M;V=A=&IA+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,30*;7-G:60@(E1H:7,@;6%Y('1A:V4@<V]M92!T
M:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_(@IM<V=S
M='(@(D5Z(&AO<W-Z86)B(&ED]70@=F5H970@:6?I;GEB92X@0FEZ=&]S86X@
M9F]L>71A=&YI(&OM=N%N:F$_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE
M9&]U8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@
M36%C:6YT;W-H(&9I;&4N(@IM<V=S='(@(D5Z(&$@;&5VZ6P@96=Y($UA8VEN
M=&]S:"#A;&QO;>%N>70@=&%R=&%L;6%Z+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z-#$U"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@8V]N=&%I
M;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N
M960@=FEA(%,O(@HB34E-12XB"FUS9W-T<B`B(@HB17H@82!L97;I;"!3+TU)
M344@<WIA8G;A;GD@<WIE<FEN="!D:6=I=.%L:7-A;B!A;.'M<G0@;65L;.EK
M;&5T970@=&%R=&%L;6%Z+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#$Y"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H
M;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G
M<W1R(")%>B!A(&QE=NEL(%,O34E-12!S>F%B=N%N>2!S>F5R:6YT('1I=&MO
M<^UT;W1T(&UE;&SI:VQE=&5T('1A<G1A;&UA>BXB"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C
M;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T
M('1H92!F;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM
M<V=S='(@(B(*(D5Z(&$@;&5VZ6P@:^EZ8F5S[73I<VD@=FES<WIA:6=A>F]L
MX7-T('1A<G1A;&UA>BP@9&4@:7-M97)E=&QE;B!F;W)MX71U;6)A;BXB"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,3D*;7-G:60@(B(*(E1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC
M<GEP=&5D(&UE<W-A9V4N($5R<F]R.B`B"FUS9W-T<B`BVF=Y('3[;FEK(&5Z
M(&$@;&5VZ6P@;F5M(%!'4"!S>F%B=N%N>2!S>F5R:6YT('9A;B!T:71K;W/M
M='9A+B!!(&AI8F$Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(S
M.2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS-30*;7-G:60@(B(*(E1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@
M4$=0(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T
M<B`B(@HB17H@82!L97;I;"!N96T@9F5L96P@;65G(&$@<&]N=&]S(%!'4"!S
M>F%B=N%N>6YA:R`H87H@4D9#(#(P,34@<WIE<FEN="DN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-S`*;7-G:60@(E1H:7,@;65S<V%G92!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O
M<FUA="XB"FUS9W-T<B`B17H@82!L97;I;"!N96T@9F5L96P@;65G(&$@<&]N
M=&]S(%,O34E-12!S>F%B=N%N>6YA:RXB"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z-#(P"FUS9VED
M(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@
M4$=0+B(*;7-G<W1R(")%>B!A(&QE=NEL(%!'4"!S>F%B=N%N>?H@9&EG:73A
M;&ES(&%LX>URX7-T('1A<G1A;&UA>BXB"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C$T,PIM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I
M9VET86QL>2!S:6=N960@=FEA(%,O34E-12XB"FUS9W-T<B`B17H@82!L97;I
M;"!3+TU)344@<WIA8G;A;GGZ(&1I9VETX6QI<R!A;.'M<N%S="!T87)T86QM
M87HN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ,SD@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@(E1H:7,@;65S<V%G92!H
M87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B17IT(&$@
M;&5V96QE="!3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&]T=.%K
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P,"!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR.3`*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E
M;B!E;F-R>7!T960@=VET:"!01U`N(@IM<V=S='(@(D5Z="!A(&QE=F5L970@
M4$=0('-Z86)VX6YY('-Z97)I;G0@=&ET:V]S[71O='3A:RXB"@HC.B!M97-S
M86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G92!T;R(*;7-G<W1R(")%
M>G0@82!L979E;&5T(&ED92XN+B(*"B,Z(&%C;"YP:'`Z-#4*;7-G:60@(E1H
M:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*
M;7-G<W1R("(B"B)%>B!A('-Z97)V97(@;F5M('1E<WII(&QE:&5T]7;I+"!H
M;V=Y(&WA<R!F96QH87-Z;N%L\VMN86L@:&]Z>N%FZ7+I<VD@:F]G;W0@(@HB
M861J=6YK(&UA<'#A:6YK:&]Z+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3`Y"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N(@IM<V=S='(@(D5Z="!A>B!A
M8FQA:R!C<V%K(&%Z(/IJ(&QE=NEL(&9O9V%L;6%ZX7-A:V]R(&CM=FAA=/,N
M(@H*(SH@=&AR96%D+G!H<#HQ-3<*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM
M<V=S='(@(DQO9VEK86D@*'1H<F5A9"D@;NEZ970B"@HC.B!T:')E860N<&AP
M.C<V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3$*;7-G:60@(E1H<F5A9"!6
M:65W(@IM<V=S='(@(DQO9VEK86D@*'1H<F5A9"D@;NEZ970B"@HC.B!M97-S
M86=E+G!H<#HR-S(@;6%I;&)O>"YP:'`Z-C`R('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C8Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,3`@
M;&EB+U-E87)C:"YP:'`Z-3DS"FUS9VED(")4;R(*;7-G<W1R(")#[6UZ971T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP.`IM<V=I9"`B5&\@061D
M<F5S<R(*;7-G<W1R(")!(&/M;7IE='0B"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT
M:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM<V=S='(@(B(*(DAA
M('3V8F(@;65Z]70@:^UVX6X@:VEJ96SV;&YI+"!A:VMO<B!T87)T<V$@;GEO
M;79A(&$@0V]N=')O;"`H4$,M;BD@:6QL+B`B"B)#;VUM86YD("A-86,M96XI
M(&)I;&QE;G1Y^W0L(.ES(/IG>2!K871T:6YT<V]N(&%Z(&5GZ7)R96P@82!T
M;W;A8F)I(&UE>O5K<F4N(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HQ,S0*
M;7-G:60@(B(*(E1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B
M92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@-2XQ+C`@;W(@(@HB:&EG:&5R
M+B(*;7-G<W1R("(B"B)43%,@:V%P8W-O;&%T(&AA<WINX6QA=.%H;WH@82!0
M2%`@-2XQ+C`M<RP@=F%G>2#Z:F%B8B!V97)Z:?-JX7)A('9A;B!S>OQK<^EG
M+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Y,0IM<V=I
M9"`B5&]T86P@071T86-H;65N=',@4VEZ93HB"FUS9W-T<B`B365L;.EK;&5T
M96L@]G-S>FWI<F5T93HB"@HC.B!F;VQD97)S+G!H<#HS-CD*;7-G:60@(E1R
M87-H(&9O;&1E<B(*;7-G<W1R(")!("=3>F5M971E<R<@*%1R87-H*2!M87!P
M82(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C,*;7-G
M:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`B02`G4WIE;65T97,G("A4<F%S
M:"D@;6%P<&$Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV-"!L:6(O475O
M=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N9"YP:'`Z-S$*
M(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T82]C;W5R:65R
M+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*;7-G:60@(E5N86)L
M92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R(")!(&MV\W1A(&EN9F]R;>%C
M:?,@;F5M(.ER:&5T]2!E;"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHQ.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,V"FUS9VED
M(")5;F%N<W=E<F5D(@IM<V=S='(@(FUE9W;A;&%S>F]L871L86XB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5;F%N<W=E<F5D
M(&UE<W-A9V5S(@IM<V=S='(@(DUE9W;A;&%S>F]L871L86X@;&5V96QE:R(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T
M92(*;7-G<W1R(")4]G)LZ7,@=FES<WIA(@H*(SH@;6%I;&)O>"YP:'`Z-3@P
M(&UA:6QB;W@N<&AP.C4Y."!L:6(O34E-12](96%D97)S+G!H<#HR,#0*;7-G
M:60@(E5N9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`B02!C[6UZ971T
M96L@;&ES=.%J82!N96T@:7-M97)T(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HU-38*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\@05542$5.5$E#051%(&-O;6UA;F0N(@IM<V=S='(@(E;A<F%T;&%N(';A
M;&%S>B#I<FME>F5T="!A('-Z97)V97)T]6P@87H@05542$5.5$E#051%('!A
M<F%N8W-R82XB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4R,`IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;R!$:6=E<W0M340U
M(')E<W!O;G-E+B(*;7-G<W1R(")6X7)A=&QA;B!VX6QA<WH@Z7)K97IE='0@
M82!S>F5R=F5R=/5L(&$@1&EG97-T+4U$-2!A9&%T<F$N(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HU,S8*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\@3$]'24X@8V]M;6%N9"XB"FUS9W-T<B`B5N%R871L
M86X@=N%L87-Z(.ER:V5Z971T(&$@<WIE<G9E<G3U;"!A($Q/1TE.('!A<F%N
M8W-R82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#0X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@
M)7,B"FUS9W-T<B`B27-M97)E=&QE;B!T[7!U<SH@)7,B"@HC.B!M86EL8F]X
M+G!H<#HU-3@*;7-G:60@(E5N:VYO=VX@1&%T92(*;7-G<W1R("))<VUE<F5T
M;&5N(&3A='5M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE
M('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B07H@24U!
M4"!S>F5R=F5R=/5L(&ES;65R971L96X@=N%L87-Z(.ER:V5Z971T+B!!('-Z
M97)V97(@=N%L87-Z83H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C(V"FUS9VED(")5;FMN;W=N($UE971I;F<B"FUS9W-T<B`B27-M97)E
M=&QE;B!M96=B97-ZZ6SI<R(*"B,Z(&UA:6QB;W@N<&AP.C8Q-`IM<V=I9"`B
M56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`B27-M97)E=&QE;B!C[6UZ971T
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E5N;&]A9"!087-S<&AR87-E(@IM<V=S
M='(@(D$@;65G861O='0@:F5L;6]N9&%T('9I<W-Z87;I=&5L92(*"B,Z(&9E
M=&-H;6%I;'!R969S+G!H<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").
M:6YC<R!E;&YE=F5Z=F4B"@HC.B!M97-S86=E+G!H<#HU,#,@;6%I;&)O>"YP
M:'`Z-S`S('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M-@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$U('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHU"FUS9VED(")5;G-E96XB"FUS9W-T<B`B;F5M(&]L=F%S
M;W1T(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3(*;7-G
M:60@(E5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I(@IM<V=S='(@(D$@:_9V
M971K97KU(&UA<'#A*&MA*70@:&5L>65Z>OQK(&AA<WINX6QA=&]N(&OM=OQL
M("AU;G-U8G-C<FEB92DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU,34*;7-G:60@(E5P9&%T92(*;7-G<W1R(")-\V1O<^UTX7,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$R"FUS9VED(")5<&1A=&4@
M<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B3?-D;W/M='-U:R!A(';A;&%S
M>F%D\R!S=.%T=7-ZX70B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I
M9"`B57!L;V%D(@IM<V=S='(@(D9E;'3V;'3I<R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*;7-G:60@(E5S92!$969A=6QT
M(%9A;'5E(@IM<V=S='(@(D%Z(&%L87#I<G1E;&UE>F5T="#I<G3I:R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-38*;7-G:60@(E5S92!)34%0(&9O
M;&1E<B!S=6)S8W)I<'1I;VYS/R(*;7-G<W1R(")!;&MA;&UA>GIU:R!A>B!)
M34%0(&AA<WINX6QA=&)A(';I=&5L:2`H<W5B<V-R:7!T:6]N*2!M96-H86YI
M>FUU<^%T/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,C0*;7-G:60@
M(E5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\B"FUS9W-T<B`B2&%S>F[A;&IU
M;FL@=FER='7A;&ES('-Z96UE=&5S;6%P<.%T/R(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ-#,*;7-G:60@(E5S97(B"FUS9W-T<B`B1F5L:&%S>F[A
M;/-I(&[I=B(*"B,Z(&%C;"YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB57-E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I
M960@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@HB
M7"(E<UPB(&9E;&AA<WINX6SS;F%K('-I:V5R97-E;B!M96=A9'1U:R!A(&MI
M=N%L87-Z=&]T="`M(%PB)7-<(B!M87!PX6AO>B`B"B)T]G)TZ6[U("T@:&]Z
M>N%FZ7+I<VD@:F]G;VMA="XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$W-@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B1F5L:&%S>F[A;/-I
M(&[I=B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ-PIM
M<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D9E;&AA<WINX6SS:2!NZ78Z(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I
M97<B"FUS9W-T<B`B365G=&5K:6YTZ7,B"@HC.B!L:6(O34E-12]6:65W97(O
M>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3$P"B,L('!H
M<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B)7,@;65G=&5K:6YT
MZ7-E(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B5S(&YY:6QVX6YO<R!K=6QC<R!M96=T
M96MI;G3I<V4B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$Y"FUS
M9VED(")6:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*
M;7-G<W1R(")!($A434P@=&%R=&%L;6%T(&O\;/9N(&%B;&%K8F%N('-Z97)E
M=&[I;2!LX71N:2(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C(X"FUS9VED(")6:65W($UE<W-A9V5S(@IM<V=S='(@(DQE=F5L96L@;65G
M=&5K:6YTZ7-E(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@
M4')I=F%T92!+97DB"FUS9W-T<B`B02!S>F5MZ6QY97,@=&ET:V]S(&MU;&-S
M(&UE9W1E:VEN=.ES92(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")6:65W(%!E<G-O
M;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B02!S>F5MZ6QY97,@;GEI;';A;F]S
M(&MU;&-S(&UE9W1E:VEN=.ES92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B5FEE=R!4:')E860B"FUS9W-T
M<B`B5FES>F]N=';A;&%S>F]K:V%L(&5G>?QT="(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C$V-"!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ-C8*;7-G:60@(E9I97<@5&AU;6)N86EL(@IM<V=S='(@(DUI;FEKZ7!E
M:R!M96=J96QE;NUTZ7-E(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,C,*;7-G:60@(E9I97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I
M;F1O=R(*;7-G<W1R(")!(&UE;&SI:VQE=&5T(&O\;/9N(&%B;&%K8F%N('-Z
M97)E=&[I;2!LX71N:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H
M<#HW.0IM<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W
M(@IM<V=S='(@(D$@=&%R=&%L;6%T(&O\;/9N(&%B;&%K8F%N('-Z97)E=&[I
M;2!LX71N:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#$*;7-G
M:60@(E9I97<@979E;G0B"FUS9W-T<B`B07H@96QF;V=L86QT<^%G(&UE9W1E
M:VEN=.ES92(*"B,Z(&9O;&1E<G,N<&AP.C,V,2!M86EL8F]X+G!H<#HU,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G
M<W1R(")!*'HI("5S(&UA<'!A(&UE9W1E:VEN=.ES92(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,C,*;7-G:60@(E9I97<@
M;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.B(*;7-G<W1R(")"
M96IE;&5N=&ME>NES('5TX6X@;6EL>65N(&OI<&5R;GGU=F5L(&OM=N%N(&ME
M>F1E;FDZ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,0IM<V=I
M9"`B5FEE=R!T87-K(@IM<V=S='(@(D$@9F5L861A="!M96=T96MI;G3I<V4B
M"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`T"FUS9VED(")6:65W
M('1H92!);6%G97,B"FUS9W-T<B`B02!KZ7!E:R!M96=J96QE;NUTZ7-E(@H*
M(SH@<V5A<F-H+G!H<#HR-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FER='5A
M;"!&;VQD97(@7"(E<UPB(&-R96%T960@<W5C8V5S9G5L;'DN(@IM<V=S='(@
M(D$H>BD@7"(E<UPB('9I<G1UX6QI<R!M87!PX70@<VEK97)E<V5N(&SI=')E
M:&]Z='5K+B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3$Q(&QI
M8B])34%0+U1R964N<&AP.C$T,2!L:6(O24U!4"]4<F5E+G!H<#HQ-30*(SH@
M;&EB+TE-05`O5')E92YP:'`Z,34V(&QI8B])34%0+U1R964N<&AP.C$V,"!L
M:6(O24U!4"]4<F5E+G!H<#HQ-C$*(SH@;&EB+TE-05`O5')E92YP:'`Z,S<Q
M(&QI8B])34%0+U1R964N<&AP.C,Y-2!L:6(O24U!4"]4<F5E+G!H<#HT,S,*
M;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*;7-G<W1R(")6:7)T=>%L:7,@;6%P
M<.%K(@H*(SH@<V5A<F-H+G!H<#HR-3(*;7-G:60@(E9I<G1U86P@1F]L9&5R
M<R!R97%U:7)E(&$@;&%B96PN(@IM<V=S='(@(D$@=FER='7A;&ES(&UA<'#A
M="!E;"!K96QL(&YE=F5Z;FD@=F%L86UI;F5K+B(*"B,Z(&QI8B]396%R8V@N
M<&AP.C0R,`IM<V=I9"`B5FER='5A;"!)3D)/6"(*;7-G<W1R(")6:7)T=>%L
M:7,@24Y"3U@B"@HC.B!F;VQD97)S+G!H<#HS.3<*;7-G:60@(E9I<G1U86P@
M24Y"3U@@1F]L9&5R(@IM<V=S='(@(E9I<G1UX6QI<R!)3D)/6"!M87!P82(*
M"B,Z(&QI8B]-86EL8F]X+G!H<#HQ-38@;&EB+U-E87)C:"YP:'`Z,S8V"FUS
M9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(E9I<G1UX6QI<R!S>F5M971E
M<VUA<'!A(@H*(SH@9F]L9&5R<RYP:'`Z,SDT"FUS9VED(")6:7)T=6%L(%1R
M87-H($9O;&1E<B(*;7-G<W1R(")6:7)T=>%L:7,@<WIE;65T97-M87!P82(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(X"FUS9VED(")6:7)T
M=6%L(&9O;&1E<B!L86)E;"(*;7-G<W1R(")!('9I<G1UX6QI<R!M87!P82!E
M;&YE=F5ZZ7-E(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-SD*
M;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B1FEG>65L;65Z=&5TZ7,B"@HC.B!L
M;V=I;BYP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@
M)7,B"FUS9W-T<B`BW&1V]GKV;&K\:R$@17H@82`E<R!L979E;&5Z]7)E;F1S
M>F5R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#<*;7-G:60@(B(*
M(E=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T
M:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT
M/R(*;7-G<W1R("(B"B)-:2!T]G)TZ6YJ96X@82!L97;I;&QE;"P@;6EU=.%N
M('-P86UKZ6YT('9A9WD@;F5M+7-P86UKZ6YT(&)E:F5L96YT971T_&L_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q-@IM<V=I9"`B(@HB5VAE;B!D
M96QE=&EN9R!M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L
M9&5R(&EN<W1E860@;V8@;6%R:VEN9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM
M<V=S='(@(B(*(E3V<FSI<VMO<B!A('3V<FSI<W)E('9A;/,@:VEJ96SV;.ES
M(&AE;'EE='0@<F%K:G5K(.%T(&$@;&5V96QE:V5T(&$@(@HB)U-Z96UE=&5S
M)R`H5')A<V@I(&UA<'#A8F$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@Y-@IM<V=I9"`B5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H
M('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_(@IM<V=S='(@(MIJ(&UA
M<'!A(&UE9VYY:73A<V%K;W(@;65L>6EK(&]L9&%L="!K[7;A;FIA(&UE9VIE
M;&5N[71E;FD_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,0IM<V=I
M9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A
M8VAM96YT(&1A=&$_(@IM<V=S='(@(B(*(D%Z(&5L:_QL9/9T="!L979E;&5K
M(&O\;/9N(&UA<'#A8F$@=/9R=.EN]2!M96YTZ7-E:V]R(&UE;G1S_&LM92!E
M;"!A("(*(FUE;&SI:VQE=&5K970@:7,_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP
M86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N
M9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E
M<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T<B`B(@HB3&5VZ6QK_&QDZ7-K;W(@
M:6QL+B!C[6UE:R!K:65GZ7-Z[73I<V5K;W(@;6EL>65N(&1O;6%I;G0@*%PB
M0%PB('5TX6YI('+I<WHI("(*(G1E9WG\;FL@82!<(D!<(B!NZ6QK_&QI(&/M
M;65K(';I9^ER93\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*
M;7-G:60@(E=H:71E;&ES="(*;7-G<W1R(")%;F=E9.EL>65ZZ7-I(&QI<W1A
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,Y('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4U,@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.38W"FUS9VED(")997,B"FUS9W-T<B`B26=E;B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-3@*;7-G
M:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L
M;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(M9N(&$@:_9V971K97KU(&%Z
M;VYO<^UT\RAK*2!L979E;&5I="!KZ7-Z_&P@X71T]FQT96YI.B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P"FUS9VED
M("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E
M<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM
M<V=S='(@(D$@:_9V971K97KU(&UA<'#A:R!T87)T86QMX70@:^UVX6YJ82!T
M]G+V;&YI+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER
M;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@
M=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(D$@:_9V971K97KU
M(&UA<'#A:V%T(&OM=N%N:F$@=/9R]FQN:2XB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A
M<V-R:7!T+FEN8SHQ.3(*;7-G:60@(EEO=2!A<F4@8V]P>6EN9R]M;W9I;F<@
M=&\@82!N97<@9F]L9&5R+B(*;7-G<W1R("+::B!M87!PX6)A(&OM=N%N(&WA
M<V]L;FDOX71H96QY97IN:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F
M;VQD97)S+FIS.C$P-`IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U8BUF
M;VQD97(@=&\@(@IM<V=S='(@(D%L;6%P<.%T(&OM=N%N(&YY:71N:2!A(&OV
M=F5T:V5Z]2!M87!PX6+S;"`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F
M;VQD97)S+FIS.C$P-@IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('1O<"UL
M979E;"!F;VQD97(N(@IM<V=S='(@(MIJ("AL96=F96QS]2!S>FEN=/LI(&UA
M<'#A="!H;WH@;.ET<F4N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S$U"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!F;VQD97)S+B(*;7-G
M<W1R("+6;FYE:R!N:6YC<R!J;V=O<W5L='/A9V$@;6%P<.%K870@;.ET<F5H
M;WIN:2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&9O;&1E<G,N(@IM<V=S='(@(M9N;F5K(&YI;F-S(&IO9V]S=6QT<^%G
M82!T]F)B+"!M:6YT("5D(&UA<'#A="!LZ71R96AO>FYI+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,W"FUS9VED(")9;W4@87)E
M(')E;F%M:6YG('1H92!F;VQD97(Z("(*;7-G<W1R(")!(&OV=F5T:V5Z]2!M
M87!PX70@:^UVX6YJ82#A=&YE=F5Z;FDZ("(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@
M<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G
M92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB"FUS9W-T<B`B(@HB
M02!K]G9E=&ME>O4@<WII;6+S;'5M;VMA="!H87-Z;N%L:&%T:F$@82!L97;I
M;'!A<.UR;VMO;CH@)6,@:F5L>FD@82!L97;I;"`B"B)T87)T86QMX70L("5S
M('!E9&EG(&%Z(.%L;&%N9/,@;&5VZ6QVZ6=Z]63I<W0@*'-I9VYA='5R92DN
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!C86YN;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(B(*(DYE;2!S:6ME<OQL="!H87-Z;N%L871O;B!K[7;\;')E(&AE;'EE>FYI
M92`H=6YS=6)S8W)I8F4I(&$@7"(E<UPB(&UA<'#A="XB"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB
M66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R
M965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB
M"FUS9W-T<B`B(@HBUFX@;F5M(&5G>65Z971T(&)E;&4@82!3>F]L9^%L=&%T
MX7,@1F5L=.ET96QE:6)E+"!E>NER="!N96T@:F5L96YT:V5Z:&5T(&)E+B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S`*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F
M;VQD97(B"FUS9W-T<B`BUFX@;F5M(&IO9V]S=6QT(&UE9W;A;'1O>G1A=&YI
M(&5N;F5K(&$@;6%P<.%N86L@82!H;WIZX6;I<FAE=/5SZ6?I="(*"B,Z(&QI
M8B]-86EL;&]G+G!H<#HQ,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O
M<G=A<F1E9"!T:&ES(&UE<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@
M<F5C:7!I96YT<SH@)7,N(@IM<V=S='(@(B(*(M9N('1O=N%B8NUT;W1T82!E
M>G0@82!L979E;&5T("AE:VMO<CH@)25S*2!A(&OV=F5T:V5Z]2!C[6UZ971T
M96MN96LZ("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!H879E("5S(&YE=R!M97-S86=E
M<RXB"FUS9W-T<B`B)7,@^FH@;&5V96QE(.ER:V5Z971T+B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED(")9;W4@:&%V92`Q(&YE
M=R!M97-S86=E+B(*;7-G<W1R("+)<FME>F5T="!E9WD@^FH@;&5V96QE+B(*
M"B,Z(&-O;7!O<V4N<&AP.C0X,@IM<V=I9"`B66]U(&AA=F4@86QR96%D>2!S
M=6)M:71T960@=&AI<R!P86=E+B(*;7-G<W1R(")%>G0@87H@;VQD86QT(&WA
M<B!E;&O\;&1T92!E9WES>F5R+B(*"B,Z(&QI8B])35`N<&AP.C$P-3(*;7-G
M:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R
M.B(*;7-G<W1R("+::B!L979E;&4@=F%N(&$@:_9V971K97KU(&UA<'#A8F%N
M.B(*"B,Z(&QI8B])35`N<&AP.C$P-3<*;7-G:60@(EEO=2!H879E(&YE=R!M
M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`BVFH@;&5V
M96QE('9A;B!A(&OV=F5T:V5Z]2!M87!PX6MB86XZ(@H*(SH@8V]M<&]S92YP
M:'`Z,34S"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@<F5C
M:7!I96YT+B(*;7-G<W1R("),96=A;.%B8B!E9WD@8^UM>F5T=&5T(&UE9R!K
M96QL(&%D;FEA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,P-@IM
M<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO
M=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E(@IM<V=S
M='(@(B(*(D5N;F5K(&$@;&5VZ6QN96L@82!M96=T96MI;G3I<^EH97H@;65G
M(&ME;&P@861N:6$@87H@UFX@=&ET:V]S(%!'4"!K=6QC<^%H;WH@(@HB=&%R
M=&]Z\R!J96QM;VYD871O="XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C(U-`IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A
M<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R`B
M"B)M97-S86=E(@IM<V=S='(@(B(*(D5N;F5K(&$@;&5VZ6QN96L@82!M96=T
M96MI;G3I<^EH97H@;65G(&ME;&P@861N:6$@87H@UFX@=&ET:V]S(%,O34E-
M12`B"B)K=6QC<^%H;WH@=&%R=&]Z\R!J96QM;VYD871O="XB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHV-"!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A('1A<F=E="!M86EL8F]X(&9I<G-T+B(*;7-G<W1R(")%;/5S>O9R(&/I
M;&OI;G0@:VD@:V5L;"!VX6QA<WIT86YI82!E9WD@;6%P<.%T+B(*"B,Z(&9E
M=&-H;6%I;'!R969S+G!H<#HX-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N
M(&%C8V]U;G0@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B16SU<WKV<B!K:2!K
M96QL(';A;&%S>G1A;FEA(&$@=/9R;&5N9/4@87IO;F]S[73S="XB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C@Q"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B16SU<WKV
M<B!K:2!K96QL(';A;&%S>G1A;FEA(&5G>2!C[6UE="XB"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP;&%T97,O;6%I;&)O
M>"]J879A<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z,C8S"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A
M<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@(D5L]6)B(&QE9V%LX6)B
M(&5G>2!L979E;&5T(&MI(&ME;&P@=N%L87-Z=&%N:6$N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G<W1R(")-96<@:V5L;"!A9&YI82!A
M(&/M;7IE='1E="XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@=&\@:&%V92!<
M(B5S7"(@96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM
M<V=S='(@(D5N9V5DZ6QY97IN:64@:V5L;"!<(B5S7"(M="!A(&MA<F)A;G1A
M<G3A<VD@9F5L861A=&]K(&)EX6QL[73A<V%I8F%N+B(*"B,Z(&QI8B]-86EL
M;&]G+G!H<#HQ,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E9&ER96-T
M960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T<B`BUFX@)7,M
M<F4@:7+A;GGM=&]T=&$@X70@97IT(&$@;&5V96QE="`E)7,M96XN(@H*(SH@
M;&EB+TUA:6QL;V<N<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM<V=S='(@(D5R<F4@
M82!L97;I;')E(';A;&%S>F]L="!E:VMO<CH@)7,N(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-3`W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E(&YO="!S
M=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@
M<V%I9"(*;7-G<W1R("(B"B)!(%PB)7-<(B!M87!P82!N96T@=F]L="!H87-Z
M;N%L871B82!VZ79E("AS=.%T=7-Z82!U;G-U8G-C<FEB960I+B!!('-Z97)V
M97(@(@HB_'IE;F5T93HB"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M
M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R
M("(B"B)!(%PB)7-<(B!M87!P82!H87-Z;N%L871R82!V;VQT(&MI:F5L]FQV
M92`H<W3A='5S>F$@<W5B<V-R:6)E9"DN($$@<WIE<G9E<B`B"B+\>F5N971E
M.B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4Q,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R!<(B5S7"(B
M"FUS9W-T<B`B4VEK97)E<V5N(&IE;/9L=&4@:VD@:&%S>F[A;&%T<F$@*'-U
M8G-C<FEB960I(&$@7"(E<UPB(&UA<'#A="XB"@HC.B!L:6(O1F]L9&5R+G!H
M<#HU-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U
M;&QY('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R(")3:6ME<F5S
M96X@:&5L>65Z=&4@:&%S>F[A;&%T;VX@:^UV_&QR92`H=6YS=6)S8W)I8F5D
M*2!A(%PB)7-<(B!M87!PX70N(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B07H@UFX@;F5V92(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHU,`IM<V=I9"`B66]U<B!01U`@4'5B
M;&EC+U!R:79A=&4@2V5Y<R(*;7-G<W1R(")!>B#6;B!N>6EL=N%N;W,O=&ET
M:V]S(%!'4"!K=6QC<V%I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I
M=F%T92!+97DB"FUS9W-T<B`B07H@UFX@<WIE;>EL>65S+"!T:71K;W,@:W5L
M8W-A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-S$*;7-G:60@(EEO=7(@4'5B;&EC($ME>2(*;7-G
M<W1R(")!>B#6;B!N>6EL=N%N;W,@:W5L8W-A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$V-0IM<V=I9"`B66]U<B!297!L>2UT;SH@861D<F5S<SH@
M/&5M/BAO<'1I;VYA;"D\+V5M/B(*;7-G<W1R(")!>B#6;B!V:7-Z;VYT=N%L
M87-Z("A297!L>2UT;SHI(&/M;64Z(#QE;3XH;W!C:6]NX6QI<RD\+V5M/B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#D*;7-G:60@(EEO=7(@
M4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<R(*;7-G<W1R(")!
M>B#6;B!N>6EL=N%N;W,O=&ET:V]S(%,O34E-12!T86[Z<^UT=N%N>6%I(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*
M;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S='(@(D%Z(-9N(&%Z;VYO<^UT
M\VDZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PIM<V=I9"`B(@HB
M66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A
M8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(D%Z
M(-9N(&%L:6%S(&/M;65I.CQE;3XH;F5M(&OV=&5L97KU+"!M:6YD96X@8^UM
M(&O\;/9N('-O<F)A(&ME<OQL:O9N*3PO96T^(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,3`Q"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N
M(@IM<V=S='(@(B(*(D%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO
M9V%T:F$@96YN96L@82!KZ7!T[7!U<VYA:R!A(&OV>G9E=&QE;B`B"B)M96=J
M96QE;NUTZ7/I="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,Y"FUS
M9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E
M<SHB"FUS9W-T<B`B07H@UFX@86QA<.ER=&5L;65Z971T(&MA<F%K=&5R:^ES
M>FQE=&4@82!L97;I;.URX7-H;WHZ(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M8W)Y<'1S96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T
M:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B07H@
MUFX@86QA<.ER=&5L;65Z971T('1I=&MO<^UTX7-I(&WS9&IA(&$@;&5V96QE
M>NES:&5Z.B(*"B,Z(&%T=&%C:&UE;G0N<&AP.CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@;&EN:V5D(&%T=&%C:&UE;G0@:&%S(&)E96X@9&]W
M;FQO861E9"!B>2!A="!L96%S="!O;F4@=7-E<BY<;B(*(EQN(@HB071T86-H
M;65N="!N86UE.B`E<UQN(@HB071T86-H;65N="!D871E.B`E<UQN(@HB7&XB
M"B)#;&EC:R!O;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@<&5R;6%N96YT;'D@
M9&5L971E('1H92!A='1A8VAM96YT.EQN(@HB)7,B"FUS9W-T<B`B(@HB02!H
M:79A=&MO>N%S(&9O<FWA:N%B86X@96QK_&QD]G1T(&UE;&SI:VQE=.ET(&WA
M<B!L96=A;.%B8B!E9WD@8^UM>F5T="`B"B)L973V;'3V='1E+EQN(@HB7&XB
M"B)!(&UE;&SI:VQE="!N979E.B`E<UQN(@HB02!M96QLZ6ML970@9.%T=6UA
M.B`E<UQN(@HB7&XB"B)+871T:6YT<V]N(&$@:_9V971K97KU('-Z]G9E9W)E
M+"!H82!VZ6=L96<@=/9R]FQN:2!K[7;A;FIA(&$@;65L;.EK;&5T970Z7&XB
M"B(E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@Y"FUS9VED
M(")9;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM
M<V=S='(@(D%Z(-9N(&QE=F5L92!S:6ME<F5S96X@:^EZ8F5S[73I<W)E(&ME
M<OQL="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9
M;W5R('-I9VYA='5R93HB"FUS9W-T<B`B07H@UFX@X6QL86YD\R!L97;I;';I
M9WKU9.ES92`H<VEG;F%T=7)E*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]A9&1R97-S97-";&]C:W,N:G,Z-PIM<V=I9"`B6TAI9&4@061D<F5S<V5S
M72(*;7-G<W1R(");3F4@;75T87-S=6L@82!C[6UE:V5T72(*"B,Z(&UE<W-A
M9V4N<&AP.C(Y-B!C;VUP;W-E+G!H<#HQ,S`Q(&UA:6QB;W@N<&AP.C4S-B!L
M:6(O0V]M<&]S92YP:'`Z.#,X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T
M<B`B6U3A<F=Y(&[I;&O\;%TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A
M9&1R97-S97-";&]C:W,N:G,Z.`IM<V=I9"`B6U-H;W<@061D<F5S<V5S("TB
M"FUS9W-T<B`B6TUU=&%S<W5K(&$@8^UM96ME="`M(@H*(SH@;&EB+TU)344O
M2&5A9&5R<RYP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(&%D
M9')E<W-E<R`M("5S(')E8VEP:65N='-=(@IM<V=S='(@(EM-=71A<W-U:R!A
M(&/M;65K970@+2`E<R!C[6UZ971T72(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(P-0IM<V=I9"`B7T)C8R(*;7-G<W1R(")?0F-C(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED(")?0FQA8VML
M:7-T(@IM<V=S='(@(E1I;'3S;&ES=&$B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHQ-30*;7-G:60@(E]#8R(*;7-G<W1R(")?0V,B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-B!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C$P"FUS9VED(")?1&5L971E(@IM<V=S='(@(E]4
M]G)LZ7,B"@HC.B!L:6(O24U0+G!H<#HY-34*;7-G:60@(E]&;VQD97)S(@IM
M<V=S='(@(E]-87!PX6LB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHX,0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@(E]!>F]N;W/M=/,B
M"@HC.B!L:6(O24U0+G!H<#HY,C0*;7-G:60@(E]);F)O>"(*;7-G<W1R(")?
M26YB;W@B"@HC.B!L:6(O24U0+G!H<#HY.38*;7-G:60@(E],;V<@;W5T(@IM
M<V=S='(@(E]+:6IE;&5N=&ME>NES(@H*(SH@;65S<V%G92YP:'`Z,SDR"FUS
M9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T<B`B02!L97;I;"!F;W)RX7-A
M(@H*(SH@;&EB+TE-4"YP:'`Z.34R"FUS9VED(")?3F5W($UE<W-A9V4B"FUS
M9W-T<B`BVFH@;&5V96QE:R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B7U!R:6YT(@IM<V=S='(@(E].>6]M
M=&%TX7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@Y"FUS9VED(")?4')I
M;W)I='DB"FUS9W-T<B`B4')I;W)I=.%S("AS_')G]7-SZ6<I(@H*(SH@;6%I
M;&)O>"YP:'`Z-#`U"B,L('!H<"UF;W)M870*;7-G:60@(E]2969R97-H("5S
M(@IM<V=S='(@(B5S(&9R:7-S[73I<V4B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B7U)E<&QY(@IM<V=S='(@
M(E]6X6QA<WHB"@HC.B!L:6(O24U0+G!H<#HY-3<*;7-G:60@(E]396%R8V@B
M"FUS9W-T<B`B2V5R95]SZ7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C@*
M;7-G:60@(E]396YD($UE<W-A9V4B"FUS9W-T<B`B2_QL9&K\:R!?96PB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,R"FUS
M9VED(")?5&AR96%D(@IM<V=S='(@(DQO9VEK86D@<V]R<F5N9"(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Q-@IM<V=I9"`B7U1O(@IM
M<V=S='(@(D/M7VUZ971T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,3,*;7-G:60@(E]5;F1E;&5T92(*;7-G<W1R(")4]G)LZ7,@=FES
M<WIA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$X"FUS9VED(")?5FEE=R!4:')E860B"FUS9W-T<B`B5FES>F]N=';A;&%S
M>F]K:V%L(%]E9WG\='0B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B16YG963I;'EE>NES:2!L
M:7-T82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S4*;7-G:60@(F%D9')E<W-E
M92!U;FMN;W=N(@IM<V=S='(@(F$@8^UM>F5T="!I<VUE<F5T;&5N(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0U,0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R
M(")M96QLZ6ML970B"@HC.B!V:65W+G!H<#HY-PIM<V=I9"`B871T86-H;65N
M=',N>FEP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4P-PIM<V=I9"`B8GET97,B"FUS9W-T<B`B8N%J="(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ.3D*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T
M(&9I;&4B"FUS9W-T<B`B82!K:6UE;F5T:2#A;&QO;>%N>2!N96T@:&]Z:&%T
M\R!LZ71R92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S$*;7-G:60@(F-A;FYO
M="!O<&5N(&EN<'5T(@IM<V=S='(@(F$@8F5M96[U(.%L;&]MX6YY(&YE;2!N
M>6ET:&%T\R!M96<B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38S"FUS9VED(")C
M;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B<&%R86YC<W-O<FD@
M:&EB82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,3D*;7-G:60@(F-O;F9I9W5R
M871I;VX@97)R;W(B"FUS9W-T<B`B:V]N9FEG=7+A8VGS<R!H:6)A(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$Y-0IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I
M;&4@;6ES<VEN9R(*;7-G<W1R(")H:>%N>7II:R!E9WD@9F]N=&]S(')E;F1S
M>F5RX6QL;VWA;GDB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38W"FUS9VED(")D
M871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")A9&%T9F]R;>%T=6T@:&EB82(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C,*;7-G:60@(F5N=')Y(&YO="!F;W5N
M9"(*;7-G<W1R(")A>B!A9&%T(&YE;2!T86SA;&AA=/,B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B9G)O;2(*;7-G
M<W1R(")I='0B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<Y"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R(")A(&?I<"!N979E(&YE;2!I<VUE<G0B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`S"FUS9VED(")I;G!U="]O=71P=70@
M97)R;W(B"FUS9W-T<B`B:6YP=70O;W5T<'5T(&AI8F$B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3@W"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*
M;7-G<W1R(")B96QS]2!P<F]G<F%M:&EB82(*"B,Z('-M:6UE+G!H<#HR.2!P
M9W`N<&AP.C8X"FUS9VED(")K97DB"FUS9W-T<B`B:W5L8W,B"@HC.B!F;VQD
M97)S+G!H<#HQ-#4*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R(")M86EL
M8F]X(&;A:FPB"@HC.B!C;VUP;W-E+G!H<#HQ,3`U(&QI8B]-97-S86=E+G!H
M<#HU,34*;7-G:60@(FYA;64B"FUS9W-T<B`B;NEV(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<V"FUS9VED(")N;VYE(@IM<V=S='(@
M(F5G>2!S96TB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L
M96-T+FEN8SHR-0HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,3`U"FUS9VED(")O<B(*;7-G<W1R(")V86=Y(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(Q-0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B;FEN
M8W,@;65G9F5L96SU(&IO9V]S=6QT<^%G82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V%D9')E<W-E<T)L;V-K<RYJ<SHX"FUS9VED(")R96-I<&EE;G1S
M72(*;7-G<W1R(")C[6UZ971T72(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,3$*
M;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")A9&%T
MX71V:71E;&D@*'!R;W1O:V]L;"D@:&EB82(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ.#,*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B82!S
M>F]L9^%L=&%TX7,@;F5M(.%L;"!R96YD96QK97KI<W)E(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E
M<G)O<B(*;7-G<W1R(")H96QY97/M<N%S:2!H:6)A(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O
M<G,B"FUS9W-T<B`B:&5L>65S[7+A<VD@:&EB82(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ.3$*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")R96YD<WIE
M<FAI8F$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`W"FUS9VED(")T96UP;W)A
M<GD@9F%I;'5R92(*;7-G<W1R("+A=&UE;F5T:2!H:6)A(@H*(SH@;&EB+T9I
M;'1E<BYP:'`Z-SD*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM<V=S='(@(G1I
M;'3S;&ES=.%J82(*"B,Z(&QI8B]&:6QT97(N<&AP.C@Y"FUS9VED(")Y;W5R
M('=H:71E;&ES="(*;7-G<W1R(")E;F=E9.EL>65ZZ7-I(&QI<W3A:F$B"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM
M<"]P;R]F:5]&22YP;P``````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`T,C4Q,S$`,3`T,3<S-C(W-C0`,#$W,34P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@1FEN;FES:"!T
M<F%N<VQA=&EO;B!F;W(@26UP+@HC($-O<'ER:6=H="`H0RD*(R!,965N82!(
M96EN;R`\;&EI;G5`=71A+F9I/BP@,C`P,2TR,#`V+@HC"FUS9VED("(B"FUS
M9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!);7`@-"XQ+6-V<UQN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3(W(#$Y.C4Q*S`R,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,C8@,3(Z-3DK,#(P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!,965N82!(96EN;R`\;&EI;G5`=71A+F9I/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@1FEN;FES:"`\:3$X;D!L:7-T<RYH;W)D92YO
M<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M-#(Y"FUS9VED("(@("`@("!#8SH@(@IM<V=S='(@(B`@("`@("`@2V]P:6\Z
M("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,C8*;7-G:60@(B`@("`@(%1O.B`B
M"FUS9W-T<B`B(%9A<W1A86YO='1A:F$Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HT,30*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@("`@(%#D:7;D
M>7,Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3<*;7-G:60@(B`@("!&<F]M
M.B`B"FUS9W-T<B`B("`@("!,Y&AE='3D:N0Z("(*"B,Z(&UA:6QB;W@N<&AP
M.C0P."!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%!I:V%NY'!P
MY&EN("5S*2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,C,*;7-G:60@(B!3=6)J
M96-T.B`B"FUS9W-T<B`B("`@("`@($]T<VEK:V\Z("(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I9"`B(&EN("(*;7-G<W1R
M("(@(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHQ,@IM<V=I9"`B(R(*;7-G<W1R(").<F\B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR
M9DU"("`H)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@+R`E+C)F34(@("@E+C)F
M)24I(@H*(SH@=&AR96%D+G!H<#HQ-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@365S<V%G97,B"FUS9W-T<B`B)60@=FEE<W1IY"(*"B,Z(&UA:6QB;W@N
M<&AP.C$W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B<&]I<W1E='1I:6X@)60@=FEE<W1I
MY"XB"@HC.B!L:6(O4W!A;2YP:'`Z,3DV"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A
M;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(E9"!V
M:65S=&GD(&]N(')A<&]R=&]I='4@96DM<F]S:V%P;W-T:6YA(&KD<FIE<W1E
M;&WD;B!Y;&SD<&ED;VQL92XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E
M9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B)60@=FEE<W1IY"!O;B!R87!O<G1O
M:71U(&5I+7)O<VMA<&]S=&EN82XB"@HC.B!L:6(O4W!A;2YP:'`Z,3@X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O
M<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B5D('9I97-T:>0@;VX@<F%P;W)T;VET=2!R;W-K87!O<W1I;F$@
M:N1R:F5S=&5L;>1N('EL;.1P:61O;&QE+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N
M(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(B5D('9I97-T:>0@;VX@<F%P
M;W)T;VET=2!R;W-K87!O<W1I;F$N(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D($UE<W-A9V5S(@IM
M<V=S='(@(E9I97-T:70@)60@+2`E9"`H>6AT965N<^0Z("5D*2(*"B,Z(&UA
M:6QB;W@N<&AP.C8S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G
M<W1R("(E<R!+0B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S
M96YT;6%I;%]M;VYT:&QY+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA
M;65D+B(*;7-G<W1R("(E<R!O;B!J;R!O;&5M87-S82X@2V%N<VEO=&%S:2`E
M<R!E:2!N:6UE='1Y('5U9&5L;&5E;BXB"@HC.B!L:6(O365S<V%G92YP:'`Z
M-C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B5S(&5I('9A:6MU=&$@
M;VQE=F%N('!O<W1I:V%N<VEO+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@
M;V8@=&AE(&UO;G1H+B(*;7-G<W1R("(E<R!K86YS:6\@;FEM973DY&X@=75D
M96QL965N(&MU=6MA=61E;B!A;'5S<V$N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C(U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@86-C
M97!T960N(@IM<V=S='(@(B5S(&]N(&AY=N1K<WEN>70N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!H87,@8V%N8V5L;&5D(%PB)7-<(BXB"FUS9W-T<B`B)7,@;VX@<&5R=75T
M=&%N=70@7"(E<UPB.FXN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@9&5C;&EN960N(@IM
M<V=S='(@(B5S(&]N(&MI96QTY'ET>6YY="XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-#DR"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R
M97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S(&]N
M('9A<W1A;FYU="!V87!A82]V87)A='1U('!Y>6YT]O9N+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@7"(E<UPB+B(*
M;7-G<W1R("(E<R!O;B!V87-T86YN=70@:W5T<W5U;B!<(B5S7"(Z<W3D+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`B)7,@;VX@;.1H971TY&YY="!S:6YU;&QE('9A<&%A+W9A
M<F%T='4@=&EE=&]J82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A
M8V-E<'1E9"XB"FUS9W-T<B`B)7,@;VX@86QU<W1A=F%S=&D@:'EVY&MS>71T
M>2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B5S('!Y>73DY"!S:6YU;'1A('9A<&%A+W9A<F%T
M='4@=&EE=&]J82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@<')E<V5N
M8V4@870@7"(E<UPB+B(*;7-G<W1R("(E<R!P>7ETY.0@<VEN=6$@;VQE;6%A
M;B!P86EK86QL82!<(B5S7"(Z<W/D+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HT
M-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(B5S(&QI<^1T=&EI;B!<(B5S7"(Z
MY.1N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N9"!<(B5S7"(N(@IM
M<V=S='(@(B5S(&AA;'5A82!M=75T=&%A(%PB)7-<(CKDY"XB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B!<(B5S7"(N(@IM<V=S
M='(@(B5S(&AA;'5A82!I;&UO:71T86$@<VEN=6QL92!<(B5S7"(Z<W3D+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O
M<FUA=&EO;B!A8F]U="!<(B5S7"(N(@IM<V=S='(@(B5S(&AA;'5A82!S86%D
M82!U=7-I;6UA="!T:65D;W0@7"(E<UPB.G-TY"XB"@HC.B!M97-S86=E+G!H
M<#HR.3(@;65S<V%G92YP:'`Z,CDW"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?=&]P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@
M*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P
M.R\F;F)S<#LE9"DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3,S"FUS9VED("(H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T
M;R!N97AT('-C<F5E;BXI(@IM<V=S='(@(BA!<V5T82!M=75T;VMS970@=F]I
M;6%A;B!J82!S:6ER<GD@<V5U<F%A=F%L;&4@<VEV=6QL92XI(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A
M<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E
M96XN*2(*;7-G<W1R("(H2'EL:^3D(&MA:6MK:2!M=75T;VMS970@:F$@<VEI
M<G)Y('9I97-T:6YK:7)J;VET=7-S:79U;&QE+BDB"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G<W1R
M("(H2%1-3"DB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,38*;7-G:60@(BA0;&%I;B!497AT*2(*;7-G<W1R("(H4&5L:VOD('1E:W-T
M:2DB"@HC.B!S<&5L;&EN9RYP:'`Z,C<Y"FUS9VED("(B"B(H4F5T=7)N('1O
M('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E
M<R!M861E('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S
M8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BA086QA
M82!T86MA:7-I;B!V:65S=&EN:VER:F]I='5S<VEV=6QL92!J82!A<V5T82!V
M;VEM86%N(&MA:6MK:2!TY&CD;B!A<W1I("(*(G1E:&1Y="!M=75T;VMS970N
M($YY:WEI<V5L;&4@<VEV=6QL92!T96AT>6KD(&UU=71O:W-I82!E:2!A<V5T
M971A('9O:6UA86XN*2(*"B,Z('-P96QL:6YG+G!H<#HR-S8*;7-G:60@(B(*
M(BA396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D
M92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE("(*(F-U<G)E;G0@<V-R965N
M('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H3.1H973D('9I
M97-T:2!K=6X@:V%I:VMI(&UU=71O:W-E="!O;B!A<V5T971T=2!V;VEM86%N
M+B!-=75T;VMS970@96EVY'0@;N1Y("(*(FYY:WEI<V5L;.0@<VEV=6QL82XI
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G
M:60@(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B!,
M:7/DY"!NY&WD(&YA<'-A=71T86UA;&QA($]++7!A:6YI:V5T=&$@*B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS9VED("(J
M(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(%9A;&ET
M<V4@;W-O:71T965T("HB"@HC.B!M86EL8F]X+G!H<#HQ-S,*;7-G:60@(C$@
M;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(Q('9I97-T:2!O
M;B!P;VES=&5T='4N(@H*(SH@;&EB+U-P86TN<&AP.C$Y.`IM<V=I9"`B,2!M
M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(C$@=FEE<W1I(&]N(')A
M<&]R=&]I='4@96DM<F]S:V%P;W-T:6YA(&KD<FIE<W1E;&WD;B!Y;&SD<&ED
M;VQL92XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"FUS9VED("(Q(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(C$@=FEE
M<W1I(&]N(')A<&]R=&]I='4@96DM<F]S:V%P;W-T:6YA+B(*"B,Z(&QI8B]3
M<&%M+G!H<#HQ.3`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(C$@=FEE<W1I(&]N(')A<&]R=&]I='4@<F]S:V%P;W-T:6YA(&KD<FIE
M<W1E;&WD;B!Y;&SD<&ED;VQL92XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<P"FUS
M9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS
M9W-T<B`B,2!V:65S=&D@;VX@<F%P;W)T;VET=2!R;W-K87!O<W1I;F$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P.`IM<V=I9"`B,3`P(&-H87)A
M8W1E<G,B"FUS9W-T<B`B,3`P(&UE<FMK:>0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#$Q"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B
M,3`P,"!M97)K:VGD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P.0IM
M<V=I9"`B,C4P(&-H87)A8W1E<G,B"FUS9W-T<B`B,C4P(&UE<FMK:>0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$P"FUS9VED("(U,#`@8VAA<F%C
M=&5R<R(*;7-G<W1R("(U,#`@;65R:VMIY"(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E
M(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB
M"FUS9W-T<B`B5.1MY&X@=FEE<W1I:6X@;VX@;&EI=&5T='D@<W5U<FD@:W5V
M871I961O<W1O("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I
M;VXN<&AP.C4P"FUS9VED("(B"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H
M87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE
M("(*(G)E8VEP:65N="XB"FUS9W-T<B`B3.1H971TY&WD<VD@=FEE<W1I(&%I
M:&5U='1I('!A;&%U='5S:6QM;VET=6MS96X@=F%S=&%A;F]T=&%J86QT82XB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0IM<V=I9"`B04Y$
M(@IM<V=S='(@(DI!(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X
M,@IM<V=I9"`B06-C97!T(&%N9"!A9&0@=&\@;7D@8V%L96YD87(B"FUS9W-T
M<B`B2'EVY&MS>2!J82!L:7/DY"!T87!A:'1U;6$@:V%L96YT97)I:7-I+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(D%C8V5P
M="!R97%U97-T(@IM<V=S='(@(DAY=N1K<WD@<'EY;G3V(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<T-@IM<V=I9"`B06-C97!T960B"FUS9W-T
M<B`B2'EVY&MS>71T>2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-3@*;7-G:60@(D%C8V5P=&5D.B`B"FUS9W-T<B`B2'EVY&MS>71T>3H@(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C
M8V]U;G0G<R!N86UE.B(*;7-G<W1R(")3Y&AK]G!O<W1I=&EL:6X@;FEM:3HB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(R(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW,C4*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B5&]I
M;6EN;F]T(@H*(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,3DR(&QI8B]-24U%
M+TAE861E<G,N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,@
M=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@(DQI<^3D("5S(&]S;VET96MI
M<FIA86YI(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S`S"FUS9VED(")!9&0@<V]U<F-E(@IM<V=S='(@(FQI<^3D(&SD:&1E(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W,PIM<V=I9"`B061D('1H
M:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B3&ESY.0@=.1MY"!K86QE;G1E
M<FEI;FDB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@S"FUS9VED
M(")!9&0@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B3&ESY.0@:V%L96YT97)I
M:6YI(@H*(SH@8V]M<&]S92YP:'`Z-3DP"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("),:6ET
M971T:6EN(%PB)7-<(B!L:6ET971I961O<W1O:W-I+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.3@*;7-G:60@(B(*(D%D9&ET:6]N86P@:&5A9&5R
M<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@96YT
M97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R
M("(B"B).Y'ET971TY';D="!L:7/D;W1S86MK965T.B`\96T^*'9A<&%A96AT
M;VEN96XL(&QA:71A(&IO:V%I;F5N(&]T<V%K92!O;6%L;&4@(@HB<FEV:6QL
M965N*3PO96T^(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA
M=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("),:7/D=&EE=&]J82!V
M;VET(&MA='-O82`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T
M:6]N+G!H<#HV,@IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO;B!D971A
M:6QS(@IM<V=S='(@(DQI<^1T:65T;VIE;B!Y:W-I='EI<VMO:&1A="(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDS"FUS9VED(")!9&1I=&EO
M;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G<W1R(")6:65S=&EN(&QI<^1T:65D
M;W0B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@
M8F4@=FEE=V5D("5S+B(*;7-G<W1R(")6:65S=&EN(&QI<^1T:65T;VIA('9O
M:70@:V%T<V]A("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<X"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R(*
M;7-G<W1R(")V:65S=&EN('9I<FAE:6QM;VET=6MS96X@>6MS:71Y:7-K;VAD
M870B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL
M<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")6:65S=&EN('9I<FAE:6QM
M;VET=6MS96X@=F]I="!K871S;V$@)7,N(@H*(SH@8V]N=&%C=',N<&AP.C@U
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,S-R!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R
M(")/<V]I=&5K:7)J82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*
M;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B3W-O:71E:VER:F%T(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I9"`B(@HB061D<F5S
M<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R
M(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM<V=S='(@
M(B(*(D]S;VET=&5E="P@:F]T:V$@;&EI=&5TY.1N('!I:6QO:V]P:6]I;F$@
M*$)#0RD@:F]K86ES965N('9I97-T:6EN.B`\96T^(@HB*'9A<&%A96AT;VEN
M96XL(&QA:71A(&IO:V%I;F5N(&]S;VET92!O;6%L;&4@<FEV:6QL965N*3PO
M96T^(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,0IM<V=I9"`B(@HB
M061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H:7,@:61E;G1I='DZ
M(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D<F5S<R!O;B!A(&YE
M=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(D]S;VET=&5E="!J;W1K82!L:6ET
M='EVY'0@=.1HY&X@<')O9FEI;&EI;CH@/&5M/BAV87!A865H=&]I;F5N+"!L
M86ET82`B"B)J;VMA:6YE;B!O<V]I=&4@;VUA;&QE(')I=FEL;&5E;BD\+V5M
M/B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3`@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@Q,@IM<V=I9"`B06QL(@IM<V=S='(@(DMA:6MK
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*;7-G
M:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS
M*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*
M;7-G<W1R("(B"B)+86EK:VD@=FEE<W1I="!S975R86%V:7-T82!K86YS:6]I
M<W1A('1A;&QE;FYE=&%A;B!Y:&1E:W-I($U"3U@M=&EE9&]S=&]K<VDZ(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R(%PB
M)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N
M96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB2V%I:VMI(&MA;G-I;W-S
M82!<(B5S7"(@;VQE=F%T("5S('#D:7;DY"!V86YH96UM870@=FEE<W1I="!P
M;VES=&5T86%N("(*(FQO<'5L;&ES97-T:2XB"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]D96QE=&5?871T86-H;65N='-?;6]N=&AL>2YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK960@871T86-H;65N=',@
M;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G
M<W1R(")+86EK:VD@)7,@:W5U:V%U='1A('9A;FAE;6UA="!L:6YK:71E='ET
M(&QI:71E=&EE9&]S=&]T('!O:7-T971A86XN(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(D%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R
M92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R
M("(B"B)+86EK:VD@)7,@:W5U:V%U='1A('9A;FAE;6UA="!LY&AE=&5T='EJ
M96X@=FEE<W1I96X@:V%N<VEO="!P;VES=&5T86%N+B(*"B,Z(&%C;"YP:'`Z
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(')I9VAT<R!O;B!F;VQD97(@
M7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U<V5R(%PB)7-<(BXB
M"FUS9W-T<B`B2V%N<VEO<W1A(%PB)7-<(B!P;VES=&5T=&EI;B!K86EK:VD@
M;VEK975D970@:^1Y='3D:N1L=.0@7"(E<UPB+B(*"B,Z(&QI8B]A<&DN<&AP
M.C<V"FUS9VED(")!;&QO=R!&;VQD97(@0W)E871I;VX_(@IM<V=S='(@(E-A
M;&QI=&%A;FMO(&MA;G-I;VED96X@;'5O;G1I/R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U;&5S
M('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(E-U;V1A
M='5S<^3D;F[V="!K;W-K979A="!K86EK:VEA('!O<W1I;&%A=&EK;VET82XB
M"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM<V=I
M9"`B06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS9W-T
M<B`B5F%I:'1O96AT;VES970@;W-A="!TY&QL92!O<VEO;&QE.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S(*;7-G:60@(D%L=V%Y<R(*;7-G<W1R
M(")!:6YA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U-PIM<V=I9"`B
M06QW87ES('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B5&%L;&5T82!A:6YA
M(&QI:71E=&EE9&]S=&]T(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4U,0IM<V=I
M9"`B(@HB06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-T
M<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@(@HB<V%I9#H@
M(@IM<V=S='(@(B(*(E1A<&%H='5I('9I<FAE('!O:7-T971T865S<V$@;&EI
M=&5T:65D;W-T;V$N($E-05`M<&%L=F5L:6UE;B!V:7)H96EL;6]I='5S("(*
M(F]L:3H@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0S-0IM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T
M92XB"FUS9W-T<B`B575D96X@;75I<W1I:6YP86YO;B!L=6]N;FES<V$@=&%P
M86AT=6D@='5N=&5M871O;B!V:7)H92XB"@HC.B!L:6(O365S<V%G92YP:'`Z
M-#,T"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E
M871I;F<@=&AE(&YE=R!T87-K+B(*;7-G<W1R(")5=61E;B!T96ATY';D;B!L
M=6]N;FES<V$@=&%P86AT=6D@='5N=&5M871O;B!V:7)H92XB"@HC.B!M86EL
M8F]X+G!H<#HW,#@@;65S<V%G92YP:'`Z-3`S('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;&)O>"]L
M96=E;F0N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ.`HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,U"FUS9VED(")!;G-W
M97)E9"(*;7-G<W1R(")687-T871T=2(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@
M(E9A<W1A='5T('9I97-T:70B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C<*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B4W5O9&%T
M82!V:65S=&ET(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS
M9W-T<B`B2^1Y=.0@<W5O9&%T=&EM:6$@:V%N<VEO<W-A("5S(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS9VED(")!<'!L>2!F:6QT
M97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")3=6]D871A('9I
M97-T:70@<VESY.1N:VER:F%U='5M:7-E;B!Y:'1E>61E<W/D+B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT,@IM<V=I9"`B07!P;'D@9FEL
M=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS9W-T
M<B`B4W5O9&%T82!V:65S=&ET(&MU;B!)3D)/6"!P;W-T:6MA;G-I;W1A('#D
M:79I=&5TY.1N+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z
M,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI
M<R!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N/R(*;7-G<W1R(")/;&5T:V\@
M=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@=.1MY&X@5FER='5A86QI:V%N
M<VEO;>3D<FET96QMY&X_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(*;7-G
M<W1R(")/;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@=.1MY&X@
M:G5L:VES96X@879A:6UE;C\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4
M:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(D]L971K;R!V87)M
M82P@971TY"!H86QU870@<&]I<W1A82!O;6%N(&%V86EN<&%R:7-I/R`H14D@
M<W5O<VET96QL82$I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ
M<SHV('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\B"FUS9W-T<B`B3VQE
M=&MO('9A<FUA+"!E='3D(&AA;'5A="!T96ADY"!TY&WD;B!T;VEM96YP:71E
M96X_(@H*(SH@;65S<V%G92YP:'`Z-#`X('1E;7!L871E<R]M86EL8F]X+VIA
M=F%S8W)I<'0N:6YC.C8X"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@4$5234%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R
M(")/;&5T:V\@86EV86X@=F%R;6$L(&5T=.0@:&%L=6%T($Q/4%5,3$E315-4
M22!P;VES=&%A(&[D;>0@=FEE<W1I=#\B"@HC.B!L:6(O34E-12]#;VYT96YT
M<RYP:'`Z,C,Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$52
M34%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B3VQE
M=&MO('9A<FUA+"!E='3D(&AA;'5A="!,3U!53$Q)4T535$D@<&]I<W1A82!T
MY&WD;B!L:6ET971I961O<W1O;C\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&5M<'1Y('1H:7,@9F]L9&5R/R(*;7-G<W1R(")/;&5T:V\@=F%R;6$L(&5T
M=.0@:&%L=6%T('1Y:&IE;G3DY"!TY&WD;B!K86YS:6]N/R(*"B,Z(&QI8B])
M35`N<&AP.CDU,PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M
M<'1Y('EO=7(@<W!A;2!F;VQD97(_(@IM<V=S='(@(D]L971K;R!V87)M82P@
M971TY"!H86QU870@='EH:F5N=.3D(')O<VMA<&]S=&EK86YS:6]N/R(*"B,Z
M(&QI8B])35`N<&AP.CDT-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/R(*;7-G<W1R(")/;&5T:V\@
M=F%R;6$L(&5T=.0@:&%L=6%T('1Y:&IE;G3DY"!R;W-K86MO<FEK86YS:6]N
M/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@
M=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(D]L971K;R!A:79A;B!V87)M82P@
M971TY"!H86QU870@;&]P=6QL:7-E<W1I('!O:7-T86$@;N1MY"!V:65S=&ET
M/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I
M;FYO8V5N=#\B"FUS9W-T<B`B3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!R
M87!O<G1O:61A('3D;>1N('9I97-T:6X@=FEA='1O;6%N83\B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHW-2!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHW-`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\B"FUS9W-T
M<B`B3VQE=&MO('9A<FUA(&5T=.0@:&%L=6%T(')A<&]R=&]I9&$@=.1MY&X@
M=FEE<W1I;B!R;W-K87!O<W1I;F$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDP-0IM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(E-A87!U;6ES
M86EK82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C`*;7-G:60@(D%S
M8V5N9&EN9R(*;7-G<W1R(").;W5S979A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4W,0IM<V=I9"`B07-K(@IM<V=S='(@(DMY<WDB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S`*;7-G:60@(D%T=&%C:"!&
M:6QE<R(*;7-G<W1R("),:6ETY"!T:65D;W-T;W0B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT-3$*;7-G:60@(D%T=&%C:"!A(&-O<'D@
M;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S
M='(@(DQI:73D('9I97-T:6EN(&MO<&EO(&IU;&MI<V5S=&$@4$=0+6%V86EM
M97-T87-I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,3$*;7-G
M:60@(D%T=&%C:&5D($9I;&4Z(@IM<V=S='(@(DQI:71E='1Y('1I961O<W1O
M.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-C(@;&EB+T-O;7!O<V4N<&AP.C4U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!='1A8VAE9"!F:6QE(%PB)7-<
M(B!E>&-E961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/
M5"!A='1A8VAE9"XB"FUS9W-T<B`B(@HB5&EE9&]S=&\@7"(E<UPB('EL:71T
MY.0@;&EI=&5T:65D;W-T;VIE;B!S=75R:6UM86X@<V%L;&ET=6X@:V]O;BX@
M5&EE9&]S=&]A("(*(D5)(&QI:71E='1Y+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HS-S<*;7-G:60@(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@
M82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+B(*;7-G<W1R("),:6ET=&5E
M;N0@;VX@=F%S=&%U<R!LY&AE='3D;>3D<VD@:V%L96YT97)I=&EE=&]P>7EN
M=/;V;BXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$V('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-`HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHU-2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT.3@*;7-G:60@(D%T=&%C:&UE;G0B"FUS9W-T<B`B
M3&EI=&4B"@HC.B!A='1A8VAM96YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!='1A8VAM96YT("5S(&1E;&5T960N(@IM<V=S='(@(DQI:71E("5S
M(&]N('!O:7-T971T=2XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3$R-0IM<V=I
M9"`B071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R("),:6ET=&5E;B!T
M:65D;W0B"@HC.B!C;VUP;W-E+G!H<#HQ,3`U(&QI8B]-97-S86=E+G!H<#HU
M,3,*;7-G:60@(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C
M:&UE;G0@='EP92(*;7-G<W1R("),:6ET92!P;VES=&5T='4Z($%L:W5P97+D
M:7-E;B!L:6ET971I961O<W1O;B!T>7EP<&DB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS-#<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#8X"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#DS"FUS9VED(")!='1A
M8VAM96YT<R(*;7-G<W1R("),:6ET=&5E="(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-S@*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")/<V%L
M;&ES='5J870B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H
M<#HU,PIM<V=I9"`B071T96YT:6]N(@IM<V=S='(@(DAU;VUI;R(*"B,Z(&QI
M8B]!=71H+VEM<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UP.B!4
M87)V:71T879A82!)34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,C@*;7-G:60@(B(*(D%U=&]M871I
M8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S
M96YD97(@:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM<V=S='(@(B(*(D[D
M>73D($A434PM=FEE<W1I96X@:W5V870@875T;VUA871T:7-E<W1I+"!J;W,@
M;.1H971TY&KD(&]N(&UA:6YI='1U("(*(F]S;VET96MI<FIA<W-A;FDN(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDX"FUS9VED
M(")!=F%I;&%B;&4@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`B2^1Y=&5T=.1V
M:7-SY"!O;&5V870@;W-O:71E:VER:F%T.B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S
M='(@(D]D;W1E=&%A;B!V87-T875S=&$B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A8U]K('1O("5S(@IM<V=S='(@(E!A;&%A(%]T86MA:7-I;B`E<R(*"B,Z
M('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*
M;7-G<W1R(")086QA82!T86MA:7-I;B`E<R(*"B,Z('1H<F5A9"YP:'`Z,3,T
M"FUS9VED(")"86-K('1O($UU;'1I<&QE($UE<W-A9V4@5FEE=R!);F1E>"(*
M;7-G<W1R(")486MA:7-I;B!U<V5A;B!V:65S=&EN(&AA:V5M:7-T;V[D:WEM
MY.1N(@H*(SH@=&AR96%D+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D
M($1I<W!L87DB"FUS9W-T<B`B5&%K86ES:6X@:V5S:W5S=&5L=7/D:65NY&MY
M;>3D;B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D)A9"!L;V=I;B!N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R
M(")6Y.1RY"!KY'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$N(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D
M(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N9&5D.B`E<R(*
M;7-G<W1R(")6Y.1RY"!T86D@=FER:&5E;&QI;F5N('!Y>6YT]BX@4&%L=F5L
M:6UE;B!I;&UO:71U<R!O;&DZ("5S(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HU-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(')E<75E<W0Z("5S+B(*
M;7-G<W1R(")%<.1K96QP;R!P>7EN=/8Z("5S+B(*"B,Z(&UE<W-A9V4N<&AP
M.C(W,R!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,@HC.B!T
M96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(P(&QI8B]396%R8V@N
M<&AP.C8P,0IM<V=I9"`B0F-C(@IM<V=S='(@(E!I:6QO:V]P:6\B"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES
M('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A
M9V4N(@IM<V=S='(@(D%L;&$@;VX@=&EL871I971O=FEE<W1I(')A86MA;75O
M9&]S<V$N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED
M(")";&%C:VQI<W0B"FUS9W-T<B`B375S=&$@;&ES=&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")";&]C:R!I;6%G97,@:6X@2%1-
M3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E
M<W1E9#\B"FUS9W-T<B`BQ&SD(&[D>73D($A434PM=FEE<W1I96X@:W5V:6$L
M(&5L;&5T(&YI:73D(&5R:6MS965N('!Y>63D+B(*"B,Z(&QI8B]396%R8V@N
M<&AP.C8P.0IM<V=I9"`B0F]D>2(*;7-G<W1R(")3:7/D;'3V(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R
M(")-;VQE;6UA="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#0*;7-G
M:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*
M;7-G<W1R(")6:65S=&EN(&]T<VEK:V\@:F$@=FEE<W1I;B!S:7/D;'3V(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,#$*;7-G:60@(D-204TM340U(&]R
M($1)1T535"U-1#4@<F5Q=6ER97,@=&AE($%U=&A?4T%33"!P86-K86=E('1O
M(&)E(&EN<W1A;&QE9"XB"FUS9W-T<B`B(@HB0U)!32U-1#4@=&%I($1)1T53
M5"U-1#4@=F%A=&EV870@971TY"!!=71H7U-!4TP@;&%A:F5N;G5S(&]N(&%S
M96YN971T=2XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M-S`*;7-G:60@(D-?:&%R<V5T(@IM<V=S='(@(DUE7W)K:7-T]B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`B2V%L96YT97)I(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HR,#$*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA
M:6P@<V5R=F5R+B(*;7-G<W1R(")%=.1P;W-T:7!A;'9E;&EM965N(&5I('-A
M871U('EH=&5Y='3D+B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3DY
M"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E
M<G9E<CH@(@IM<V=S='(@(D5TY'!O<W1I<&%L=F5L:6UE96X@96D@<V%A9&$@
M>6AT97ET=.0Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P87)T:6%L+G!H<#HU
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T(&1I<W!L87D@+2!F
M;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S<V%G92!I;B!T
M:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R("(B"B)%:2!V;VD@;N1Y
M='3DY"`M(%!O<W1I;&%A=&EK;W-S82!O;&D@=FEE<W1I<W3D('9A:6X@)7,@
M;W-I;W1A(&IA('!I=.1I<VD@(@HB;VQL82`E<R(*"B,Z(&9O;&1E<G,N<&AP
M.C(W,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#8*(SH@=&5M
M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S879E
M:6UA9V4O<V%V96EM86=E+FEN8SHQ.0HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C8V('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-0HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED(")#86YC96PB"FUS9W-T<B`B4&5R
M=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,`HC.B!T96UP;&%T97,O8V]M
M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@365S<V%G92(*
M;7-G<W1R(")097)U('9I97-T:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:G,Z-B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-0IM
M<V=I9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L
M>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS9W-T<B`B2F]S('!E<G5T('9I
M97-T:6XL(&YI:6X@=FEE<W1I;B!S:7/D;'3V('1U:&]U='5U+B(*"B,Z(&UE
M<W-A9V4N<&AP.C(W,B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(R,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI
M8B]396%R8V@N<&AP.C4Y-PIM<V=I9"`B0V,B"FUS9W-T<B`B2V]P:6\B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDS"FUS9VED("(B"B)#97)T
M:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@
M:7,@;F]T(&5N86)L960@;VX@=&AI<R`B"B)S97)V97(N(@IM<V=S='(@(B(*
M(E-E<G1I9FEK86%T=&EE;B!T=6]N=&D@96D@;VQE(&OD>71E='3D=FES<^0N
M(%1I961O<W1O:F$@96D@=F]I('1U;W1A('3D;&QE("(*(G!A;'9E;&EM96QL
M92XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDV"FUS9VED(")#
M:&%I<B!097)S;VXB"FUS9W-T<B`B4'5H965N:F]H=&%J82(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(DUU=71A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(DUU=71A(&MA:6MK
M:2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B0VAA;F=E
M($9O;&1E<B(*;7-G<W1R(")-=75T82!K86YS:6]T82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3(*;7-G:60@(B(*(D-H86YG92!D:7-P;&%Y(&]P
M=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A
M8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S(&%R92!S;W)T960N(@IM<V=S
M='(@(B(*(E9O:70@;75U='1A82!NY&MY;>3D;B!L:6ET='EV:>0@87-E='5K
M<VEA(&MU=&5N('9I97-T:65N(&WDY'+DY"!J82`B"B)JY')J97-T>7-TY"!S
M:79U;&QA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B
M0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S
M='(@(B(*(E9O:70@;75U='1A82!P;W-T:7!A;'9E;&EM96X@:^1Y='3V]FX@
M:F$@:V%N<VEO:6AI;B!L:6ET='EV:>0@87-E='5K<VEA+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE
M+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N
M('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T
M<B`B(@HB5F]I="!M=75T=&%A(&SD:&5T=.1M:7-SY'-I('/D:&OV<&]S=&5I
M<W-A(&[D:WEV:>0@;FEM:2T@=&%I(&]S;VET971I971O:F$@(@HB:F$@:^1Y
M='3D;>3D<VD@86QL96MI<FIO:71U<W1A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,3,*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB"FUS
M9W-T<B`B3N1Y=&5T=.1V:65N(&UE<FMK:65N(&WDY'+D.B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#:&5C:R!&;VQD
M97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(E1A<FMI<W1A(&MA;G-I;VED
M96X@=75D970@<^1H:_9P;W-T:70B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C<U('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C(*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R(")686QI
M='-E(%]K86EK:VDO96D@;6ETY.1N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]F971C:&UA:6PN:6YC.C$P('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM
M86EL+FEN8SHR,0IM<V=I9"`B0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@
M=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S='(@(E9A;&ET<V4@:V%I
M:VMI('!O<W1I<&%L=F5L:6UE="P@:F]I;'1A(&AA;'5A="!H86ME82!V:65S
M=&5JY#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8S"FUS9VED(")#
M:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S
M='(@(E1A<FMI<W1A('9I97-T:6X@;VEK96EN:VER:F]I='5S(&5N;F5N(&SD
M:&5T=.1M:7-TY"XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHT"FUS9VED(")#:&]O<V4@06-T:6]N.B(*;7-G<W1R(")686QI='-E('1O
M:6UI;G1O.B(*"B,Z(&-O;F9I9R]S97)V97)S+G!H<"YD:7-T.C(P,@IM<V=I
M9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@(E9A;&ET<V4@<&]S
M=&EP86QV96QI;CHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHQ,C,@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,38T"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Q-0IM<V=I9"`B0VAO;W-E
M(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z(@IM
M<V=S='(@(E9A;&ET<V4@=&%I(&UU;VMK86$@;W-O:71T96ET82!O:6ME86X@
M<'5O;&5I<V5S<V$@;&%A=&EK;W-S83HB"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS-#D*;7-G:60@(D-H;V]S92!T:&4@861D<F5S
M<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@
M(E9A;&ET<V4@;W-O:71E:VER:F$L(&IO:&]N(&]S;VET=&5E="!L:7/D=.3D
M;BXB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3,*
M;7-G:60@(D-H;V]S92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S
M96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("(B"B)6
M86QI='-E(&]S;VET=&5I9&5N(&QA86IE;FYU:W-E;B!Y:'1E>61E<W/D(&OD
M>71E='3D=FEE;B!O<V]I=&5K:7)J;VIE;B`B"B)H86MU:N1R:F5S='ES.B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$Q-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R`E<R!T;R!C;VYV97)T('1H92!I;6%G92!F:6QE
M(&EN=&\@82!F;W)M870@>6]U<B!B<F]W<V5R(&-A;B!V:65W+B(*;7-G<W1R
M("(B"B).87!S875T82`E<R!M=75T=&%A:W-E<VD@:W5V86X@<V5L;&%I<V5E
M;B!M=6]T;V]N+"!J;VYK82!S96QA:6UE<VD@<'ES='EY("(*(F[D>71TY&WD
MY&XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G
M92XB"FUS9W-T<B`B3F%P<V%U=&$@)7,@=&%L;&5N=&%A:W-E<VD@:W5V86XN
M(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3,R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G92XB"FUS9W-T
M<B`B3F%P<V%U=&$@)7,@;65N;N1K<V5S:2`E<R!H86QL:6YT87-I=G5L;&4N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A
M('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B3F%P<V%U=&$@)7,@:V%T<V]A
M:W-E<VD@2%1-3"UM=6]T;VES96X@<VESY&QL]FX@97)I;&QI<V5S<^0@:6MK
M=6YA<W-A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W(&$@=&AU;6)N
M86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(DYA<'-A=71A("5S(&MA='-O
M86MS97-I('3D;>1N(&MU=F%N('!I:VMU:W5V86YA(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HT,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R871E('=I
M;F1O=RXB"FUS9W-T<B`B3F%P<V%U=&$@)7,@:V%T<V]A:W-E<VD@;&EI='1E
M96X@97)I;&QI<V5S<^0@:6MK=6YA<W-A+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]R96QA=&5D+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E
M<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E
M<&%R871E('=I;F1O=RXB"FUS9W-T<B`B(@HB3F%P<V%U=&$@)7,@:V%T<V]A
M:W-E<VD@=.1MY&X@;75L=&EP87)T+W)E;&%T960@;W-I;VX@97)I;&QI<V5S
M<^0@:6MK=6YA<W-A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY
M.`IM<V=I9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,B"FUS9W-T
M<B`B3F%P<V%U=&$@=.1S=.0@3L195%3$Q$M315-)(&MU=F%T(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(Q"FUS9VED("(B"B)#
M;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N
M9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S('1O("(*(G-E87)C:"XB"FUS9W-T
M<B`B(@HB5F%L:71S92!E;G-I;B!O<V]I=&5K:7)J82!J82!V86QI='-E('-E
M;B!JY&QK965N(&YE(&ME;G3D="P@:F]I<W1A('1I971O:F$@(@HB:&%E=&%A
M;BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S`*;7-G:60@(D-L
M:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O
M;VLB"FUS9W-T<B`B3F%P<V%U=&$@=.1S=.0@=&%L;&5T=&%A:W-E<VD@:G5L
M:VES96X@4$=0+6%V86EM96X@;W-O:71E:VER:F%A<VDB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R
M($%D9')E<W,@0F]O:R(*;7-G<W1R(").87!S875T82!TY'-TY"!T86QL971T
M86%K<V5S:2`E<SIN(%,O34E-12UV87)M96YT965N(&]S;VET96MI<FIA87-I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS.0IM<V=I9"`B0VQI8VMI
M;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@
M=&\@=&AE('-E;F1E<B(*;7-G<W1R(").87!S875T=&%M86QL82!O<V]I=&5T
M=&$@=F]I="!K:7)J;VET=&%A('5U9&5N('9I97-T:6X@;.1H971TY&KD;&QE
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#`*;7-G:60@(D-L:6-K
M:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B
M92!R96%D(@IM<V=S='(@(DYA<'-A=71T86UA;&QA(&]S;VET971T82!V;VET
M(&%U:V%I<W1A('9I97-T:6X@;'5E='1A=F%K<VDN(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(X"FUS9VED(")#;&]S92(*;7-G
M<W1R(")3=6QJ92(*"B,Z(&-O;7!O<V4N<&AP.C0Q.`IM<V=I9"`B0VQO<V4@
M=&AI<R!W:6YD;W<B"FUS9W-T<B`B4W5L:F4@=.1MY"!I:VMU;F$B"@HC.B!F
M;VQD97)S+G!H<#HT,3`*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS9W-T<B`B
M4W5L:F5T='4@:V%N<VEO(@H*(SH@9F]L9&5R<RYP:'`Z-#,P"FUS9VED(")#
M;VQL87!S92(*;7-G<W1R(")0:65N96YNY"(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C0P"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T
M<B`B4&EE;F5N;N0@:V%I:VMI(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z-#`*;7-G:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S
M='(@(E!I96YE;F[D(&MA:6MK:2!K86YS:6]T(@H*(SH@9F]L9&5R<RYP:'`Z
M-#,P"FUS9VED(")#;VQL87!S92!&;VQD97(B"FUS9W-T<B`B4&EE;F5N;N0@
M:V%N<VEO(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C4Q
M"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R(")6Y')I;65R:VEN
M=.0Z("(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*;7-G:60@(D-O
M;6UE;G0B"FUS9W-T<B`B2V]M;65N='1I(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<V,@IM<V=I9"`B0V]M<&QE=&5D(@IM<V=S='(@(E-U;W)I
M=&5T='4B"@HC.B!C;VUP;W-E+G!H<#HT,3<*;7-G:60@(D-O;7!O<V4@86YO
M=&AE<B!M97-S86=E(@IM<V=S='(@(DMI<FIO:71A('1O:6YE;B!V:65S=&DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP;W-E
M(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")+:7)J
M;VET82!V:65S=&ET(&5R:6QL:7-E<W/D(&EK:W5N87-S82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#0S"FUS9VED("(B"B)#;VUP;W-E(&UE<W-A
M9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H:68@8G)O=W-E<B!S
M=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_(@IM<V=S='(@(B(*(D]L971U:W-E
M;F$@:VER:F]I=&$@=FEE<W1I="!(5$U,(&OD>71T]FQI:71T>6WD;&SD("A*
M;W,@<V5L86EM97-I('1U:V5E('3D=.0@(@HB=&]I;6EN=&]A*2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@
M;65S<V%G97,@87)E(&1I<W!L87EE9"XB"FUS9W-T<B`B5F]I="!MY.1R:71E
M;&SD(&MU:6YK82!V:65S=&ET(&[D>71E=.3D;BXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D-O;F9I9W5R92!M86EL('!R979I97<@
M;W!T:6]N<RXB"FUS9W-T<B`B5F]I="!M=75T=&%A('9I97-T:65N(&5S:6MA
M='-E;'5U;B!L:6ET='EV:>0@87-E='5K<VEA+B(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z,S<P"FUS9VED(")#;VYN96-T:6]N(&1R;W!P960@8GD@24U!
M4"!S97)V97(N(@IM<V=S='(@(EEH=&5Y<R!)34%0+7!A;'9E;&EM965N(&MA
M=&ME<VDN(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@
M(D-O;FYE8W1I;VX@=&\@<V5R=F5R(&9A:6QE9"(*;7-G<W1R(")9:'1E>7,@
M<&%L=F5L:6UE96X@97#D;VYN:7-T=6DN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%!'4"!S
M=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B5F]I="!M=75T=&%A("5S.FX@4$=0
M+6%S971U:W-I82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R
M("5S+B(*;7-G<W1R(")6;VET(&UU=71T86$@)7,Z;B!3+TU)344M87-E='5K
M<VEA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G:60@(D-O
M;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N
M(@IM<V=S='(@(E9O:70@87-E='1A82!H86MU=6X@;&EI='1Y=FGD(&%S971U
M:W-I82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*
M(D-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A
M;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R
M<FEV97,N(@IM<V=S='(@(B(*(E9O:70@;>3D<FET=.3D(&UI=&5N('5S96EN
M('1A<FMI<W1E=&%A;B!U=7-I96X@=FEE<W1I96X@<V%A<'5M:6YE;B!J82`B
M"B)I;&UO:71E=&%A;FMO('-I;G5L;&4@=75S:7-T82!V:65S=&5I<W3D+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-S0*;7-G:60@(D-O;G9E<G0@
M=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T
M<B`B375U=&$@=&5K<W1I;75O=&]I<V5T(&AY;6GV="!G<F%A9FES:6MS:2XB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'DB
M"FUS9W-T<B`B2V]P:6]I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C4Q"FUS9VED(")#;W!Y('1O(&9O;&1E<B(*;7-G<W1R(")+;W!I;VD@:V%N
M<VEO;VXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-C,*
M;7-G:60@(D-O<G)E8W0B"FUS9W-T<B`B2V]R:F%A(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E
M>'0B"FUS9W-T<B`B2V]R:F%T='4@=&5K<W1I(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HS.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O
M;7!L971E(')E<75E<W0N(%)E87-O;B!':79E;CH@)7,B"FUS9W-T<B`B4'EY
M;G3VY"!E:2!V;VD@<W5O<FET=&%A.B!086QV96QI;65N(&EM;VET=7,Z("5S
M(@H*(SH@871T86-H;65N="YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z("5S(@IM<V=S='(@
M(D5I('9O:61A(&QU;V1A(%9&4RUT875S=&%JY')J97-T96QMY.0Z("5S(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C8W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@
M<V%I9#H@)7,B"FUS9W-T<B`B(@HB5FEE<W1E:N0@96D@=F]I='4@<&]I<W1A
M82!K86YS:6]S=&$@)7,N(%!A;'9E;&EM96X@=FER:&5I;&UO:71U<R!O;&DZ
M("5S(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C,S,PIM<V=I9"`B0V]U;&0@;F]T
M(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`B66QL
MY'!I=&]T;VEM96YP:71E:73D(&5I('9O:71U('-U;W)I='1A82XB"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!E
M>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T
M=&%C:&UE;G0N(@IM<V=S='(@(E9A;&ET='5A('1I961O<W1O82!E:2!V;VET
M=2!P=7)K86$@35,M5$Y%1B!L:6ET971I961O<W1O<W1A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C
M="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM
M<V=S='(@(E9A;&ET='5A('1I961O<W1O82!E:2!V;VET=2!P=7)K86$@6FEP
M+71I961O<W1O<W1A+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N('-E8W5R92!C;VYN
M96-T:6]N('1O('1H92!)34%0('-E<G9E<BX@)7,@.B`E<RXB"FUS9W-T<B`B
M16D@=F]I='4@;75O9&]S=&%A('-A;&%T='5A('EH=&5Y='3D($E-05`M<&%L
M=F5L:6UE;&QE+B`E<SH@)7,N(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(X,`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO
M;B!F<F]M($E-05`@<V5R=F5R+B(*;7-G<W1R("))34%0+7!A;'9E;&EM96QT
M82!E:2!V;VET=2!H86ME82!T:65T;VIA(&YI;6EA=F%R=75D97-T82XB"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C,Y"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C$*
M;7-G:60@(D-R96%T92(*;7-G<W1R("),=6\B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHV"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S
M='(@(DQU;R!K86YS:6\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W
M"FUS9VED(")#<F5A=&4@2V5Y<R(*;7-G<W1R("),=6\@879A:6UE="(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"FUS
M9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("),=6\@=75S:2!S
MY&AK]G!O<W1I=&EL:2(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T
M+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*;7-G
M:60@(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R("),=6\@=75S
M:2!R;W-K87!O<W1I:V%N<VEO(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S
M='(@(DQU;R!U=7-I(&QU;VYN;W-K86YS:6\B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(V('1E;7!L871E<R]P<F5F<R]S96YT
M;6%I;'-E;&5C="YI;F,Z-#(*;7-G:60@(D-R96%T92!A(&YE=R!S96YT(&UA
M:6P@9F]L9&5R(@IM<V=S='(@(DQU;R!U=7-I(&SD:&5T971T>6IE;B!V:65S
M=&EE;B!K86YS:6\B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N
M:6YC.C$R('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*;7-G
M:60@(D-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B3'5O('5U
M<VD@<F]S:V%K;W)I:V%N<VEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R.`IM<V=I9"`B(@HB0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A
M;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S
M+"`B"B)A;F0@9&5L971E('-P86TN(@IM<V=S='(@(B(*(E9O:70@;'5O9&$@
M<W5O9&%T:6YSY.1N=/9JY"P@:F]I;&QA('9O:70@<VEI<G3DY"!S86%P=79A
M;B!V:65S=&EN(&MA;G-I;VEH:6X@(@HB=&%I('!O:7-T86$@<F]S:V%P;W-T
M96IA+B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-`IM
M<V=I9"`B0W)E871E(&YE=R!S=&%T:6]N97)Y(@IM<V=S='(@(DQU;R!U=7-I
M(&MI<FIE<&]H:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS
M9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM
M<V=S='(@(DQU;R!K:7)J97!O:&II82!J82!V86QM:7-V87-T875K<VEA+B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G<W1R(").>6MY:7-E="!O
M:6ME=61E="!K86YS:6]O;B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#4*;7-G:60@(D-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@
M;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(*;7-G<W1R(")6;VET(&UU=71T
M86$@;6ET96X@=FEE<W1E:N0@:&%E=&%A;B!T;VES:6QT82!SY&AK]G!O<W1I
M=&EL96EL=.0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED
M(")#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN(@IM<V=S='(@(E9O:70@
M;75O:V%T82!V:65S=&EE;B!LY&AE='3D;6ES965N(&QI:71T>79IY"!A<V5T
M=6MS:6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RXB"FUS9W-T<B`B(@HB5F]I="!M=6]K871A('1E:'3D=FGD+"!J
M;W1K82!S=6]R:71E=&%A;B!K=6X@:VER:F%U9'5T86%N('-I<^3D;B!O:&IE
M;&UA86X@)2(*(G,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHQ-PIM<V=I9"`B1&%T7V4B"FUS9W-T<B`B4.1I=N1?>7,B
M"@HC.B!M97-S86=E+G!H<#HR-CD@=&AR96%D+G!H<#HQ-3,*;7-G:60@(D1A
M=&4B"FUS9W-T<B`B4.1I=N1Y<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-3`*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(DMI96QTY'ET>6DB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8T"FUS9VED(")$96-L
M:6YE9#H@(@IM<V=S='(@(DMI96QTY'ET>6DZ("(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,S<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B3VQE='5S
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC
M.C(Q"FUS9VED(")$969A=6QT(%-E87)C:"!&:65L9"(*;7-G<W1R(")/;&5T
M=7-H86MU:V5N='3D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ,@IM
M<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")/;&5T
M=7-JY')J97-T>7,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,@IM
M<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B3VQE
M='5S:N1R:F5S='EK<V5N('-U=6YT83HB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S4X"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`B5F%L='5U
M=&5T='4B"@HC.B!F;VQD97)S+G!H<#HT,#`@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ,"!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C@*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-#0@=&5M<&QA
M=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(X"FUS9VED(")$96QE=&4B
M"FUS9W-T<B`B4&]I<W1A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B4&]I<W1A("5S
M(&IU;&MI;F5N(&%V86EN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T92!#
M=7)R96YT($ME>7,B"FUS9W-T<B`B4&]I<W1A(&YY:WEI<V5T(&%V86EM970B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHY"FUS9VED(")$
M96QE=&4@1F]L9&5R*',I(@IM<V=S='(@(E!O:7-T82!K86YS:6]T(@H*(SH@
M9F]L9&5R<RYP:'`Z,C<Q"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R
M<R(*;7-G<W1R(")0;VES=&$@=F%L:71U="!K86YS:6]T(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0R"FUS9VED(")$96QE=&4@4W1A
M=&EO;F5R>2(*;7-G<W1R(")0;VES=&$@:VER:F5P;VAJ82(*"B,Z(&9O;&1E
M<G,N<&AP.C0P,`IM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L9&5R(@IM<V=S
M='(@(E!O:7-T82!V:7)T=6%A;&EK86YS:6\B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]H96%D97(N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M92!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E<R(*;7-G<W1R(")-
M=6]K:V%A('9I<G1U86%L:7-E;B!K86YS:6]N(&WDY')I='1E;'GD("5S(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$
M96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM
M<V=S='(@(E!O:7-T82!H865T=70@=FEE<W1I="!E=.1P;W-T:7!A;'9E;&EM
M96QT82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$Y"FUS9VED
M(")$96QE=&4@9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R(")0;VES=&$@:V%L
M96YT97)I<W1A;FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"FUS
M9VED(")$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI
M;F<@;V8@;6]N=&@_(@IM<V=S='(@(E!O:7-T82!V86YH870@;&EN:VET971Y
M="!L:6ET971I961O<W1O="!K=75K875D96X@86QU<W-A+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-3`*;7-G:60@(D1E;&5T92!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")0
M;VES=&$@:W5U:V%U9&5N(&%L=7-S82!V86YH870@;.1H971E='1Y:F5N('9I
M97-T:65N(&MA;G-I;W0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P
M-0IM<V=I9"`B1&5L971E('-P86T@;65S<V%G97,B"FUS9W-T<B`B4&]I<W1E
M='5T(')O<VMA<&]S=&EV:65S=&ET(@H*(SH@;6%I;&)O>"YP:'`Z-S,T(&UE
M<W-A9V4N<&AP.C4P-B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C@*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,"!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,X"FUS9VED(")$96QE=&5D(@IM<V=S='(@
M(E!O:7-T971T=2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-C,*
M;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B4&]I<W1E='5T('9I
M97-T:70B"@HC.B!C;VUP;W-E+G!H<#HU-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E9"!T:&4@871T86-H;65N="!<(B5S7"(N(@IM<V=S='(@(E!O
M:7-T971T:6EN(&QI:71E=&EE9&]S=&\@7"(E<UPB+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B1&5L971I;F<@86YD($UO=FEN9R!-
M97-S86=E<R(*;7-G<W1R(")6:65S=&EE;B!P;VES=&%M:6YE;B!J82!S:6ER
M=.1M:6YE;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*;7-G
M:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R(")+:65L;.0@<'EY;G3V(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T,@IM<V=I9"`B1&5N>2!R97%U
M97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T<B`B2VEE;&SD
M('9A<&%A+W9A<F%T='4@=&EE=&]J96X@<'EY;G3V(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR,0IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("),
M87-K979A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC
M.C(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C8*;7-G:60@(D1E<V-R
M:7!T:6]N(@IM<V=S='(@(DMU=F%U<R(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B1&5T86EL<R(*
M;7-G<W1R(")487)K96UM870@=&EE9&]T(@H*(SH@8V]M<&]S92YP:'`Z-3@R
M"B,L('!H<"UF;W)M870*;7-G:60@(D1I9"!N;W0@871T86-H(%PB)7-<(B!A
M<R!T:&4@9FEL92!W87,@96UP='DN(@IM<V=S='(@(E1I961O<W1O82!<(B5S
M7"(@96D@;&EI=&5T='DL(&MO<VMA('-E(&]L:2!T>6AJY"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C8U"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B
M"FUS9W-T<B`B2&EM;65N;N0@86QL96MI<FIO:71U:W-E="XB"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA
M>2(*;7-G<W1R(").Y'ETY"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-SD*;7-G:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@
M82!M97-S86=E/R(*;7-G<W1R(").Y'ETY"!V87)M:7-T=7,@:W5N('9I97-T
M:2!O;B!LY&AE=&5T='DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X
M,PIM<V=I9"`B1&ES<&QA>2!I;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B
M3N1Y=.0@=FEE<W1I;B!S:7/D;'3V(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<X,0IM<V=I9"`B1&ES<&QA>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F
M(&YE=R!M86EL/R(*;7-G<W1R("));&UO:71A('5U<VES=&$@=FEE<W1E:7-T
MY"!E<FEL;&ES97-SY"!I:VMU;F%S<V$N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<T-PIM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@
M;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B3N1Y=.0@)UPB='EH:F5N
M;N0@<F]S:V%P;W-T:71<(BUL:6YK:VD@;75I9&5N(&EK;VYI96X@:F]U:V]S
M<V$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S.0IM<V=I9"`B1&ES
M<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_
M(@IM<V=S='(@(D[D>73D(%PB='EH:F5N;N0@<F]S:V%K;W)I7"(M;&EN:VMI
M(&UU:61E;B!I:V]N:65N(&IO=6MO<W-A+B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS
M9W-T<B`B5'EY<'!I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC
M.C(V"FUS9VED(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`B14D@=.1S;>3D(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O
M($YO="!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(L1L
MY"!T87)K:7-T82!O;FMO(&MA;G-I;V]N('1U;&QU="!U=7-I82!SY&AK]G!O
M<W1I=FEE<W1E:N0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30Q"FUS
M9VED(")$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU
M;6XB"FUS9W-T<B`BQ&SD(&UU;V1O<W1A(&QI;FMK96KD($SD:&5T=.1JY#H@
M<V%R86MK965S<V$B"@HC.B!L:6(O24U0+G!H<#HQ,#4W"FUS9VED(")$;R!Y
M;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/R(*;7-G<W1R(")(86QU871K
M;R!A=F%T82!K86YS:6]N/R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C,Q"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(E-I;G5L;&$@96D@;VQE('1U;FYU<W1A+B!+:7)J875D=2!K
MY'ET=.1JY&MS:2XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3(V"FUS9VED(")$;VYE(@IM<V=S='(@(E9A;&UI<R(*"B,Z(&QI8B]-
M24U%+T-O;G1E;G1S+G!H<#HR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W
M;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B5&%L;&5N;F$@)7,@
M+GII<"!M=6]D;W-S82(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ
M:7`@9FEL92DB"FUS9W-T<B`B5&%L;&5N;F$@:V%I:VMI(&QI:71E=&EE9&]S
M=&]T("@N>FEP('1I961O<W1O:W-I*2(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C(P"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RDB"FUS
M9W-T<B`B5&%L;&5N;F$@:V%N<VEO="(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RD@6RYZ
M:7`@9F]R;6%T72(*;7-G<W1R(")486QL96YN82!K86YS:6]T(%LN>FEP(&UU
M;V1O<W-A72(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,38*;7-G:60@
M(D1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(E1A;&QE;FYA("YZ
M:7`@;75O9&]S<V$B"@HC.B!M86EL8F]X+G!H<#HW,3,@;65S<V%G92YP:'`Z
M-3`T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3$*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHY('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,C(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHT,0IM<V=I9"`B1')A9G0B"FUS9W-T<B`B3'5O;FYO<R(*"B,Z
M(&9O;&1E<G,N<&AP.C,W,PIM<V=I9"`B1')A9G0@9F]L9&5R(@IM<V=S='(@
M(DQU;VYN;W-K86YS:6\Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E
M;&5C="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD97(Z(@IM<V=S='(@(DQU
M;VYN;W-K86YS:6\Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM
M<V=I9"`B12UM86EL($%D9')E<W,B"FUS9W-T<B`B4^1H:_9P;W-T:6]S;VET
M92(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,38*;7-G:60@(D5.1"(*;7-G<W1R
M("),3U!052(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS
M9VED(")%4E)/4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R
M960N(@IM<V=S='(@(E9)4DA%.B!6:65S=&GD<VD@96D@=F]I='4@=&]I;6ET
M=&%A('!E<FEL;&4N(@H*(SH@9F]L9&5R<RYP:'`Z-#`Q('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHQ.0IM<V=I9"`B161I="(*;7-G<W1R(")-
M=6]K:V%A(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS
M9VED(")%9&ET($)L86-K;&ES="(*;7-G<W1R(")-=6]K:V%A(&UU<W1A82!L
M:7-T86$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G
M:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R(")-=6]K:V%A('-U;V1A='1I;6EA
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$Y('1E;7!L871E
M<R]M86EL8F]X+VAE861E<BYI;F,Z,38*;7-G:60@(D5D:70@4V5A<F-H(%%U
M97)Y(@IM<V=S='(@(DUU;VMK86$@:&%K=6MY<V5L>>0B"@HC.B!F;VQD97)S
M+G!H<#HT,#$@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$W"FUS9VED
M(")%9&ET(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(DUU;VMK86$@=FER='5A
M86QI<W1A(&MA;G-I;W1A(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L
M9&5R($1E9FEN:71I;VX@9F]R("5S(@IM<V=S='(@(DUU;VMK86$@=FER='5A
M86QI<V5N(&MA;G-I;VX@;>3D<FET=&5L>>0@)7,B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM
M<V=S='(@(DUU;VMK86$@=F%L:V]I<W1A(&QI<W1A82(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!Y;W5R(&)L86-K
M;&ES="(*;7-G<W1R(")-=6]K:V%A(&UU<W1A82!L:7-T86%S:2(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM<V=I9"`B161I="!Y;W5R
M(&9I;'1E<B!R=6QE<R(*;7-G<W1R(")-=6]K:V%A('-U;V1A=&EN<^3D;G3V
M:N1S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-3`*;7-G:60@(D5D
M:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@
M86-C;W5N=',N(@IM<V=S='(@(DUU;VMK86$@973D<&]S=&EL86%T:6MO:6AI
M;B!L:6ET='EV:>0@87-E='5K<VEA+B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHR,PIM<V=I9"`B161I="!Y;W5R('=H:71E;&ES="(*;7-G
M<W1R(")-=6]K:V%A('9A;&MO:7-T82!L:7-T86%S:2(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(E/D:&OV<&]S=&EO<V]I=&4B"@HC.B!L:6(O365S<V%G
M92YP:'`Z-CDS"B,L('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE
M<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(E1Y:&IE;FYE='1I:6X@:V%I:VMI
M('9I97-T:70@:V]H=&5E<W1A("5S+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV
M-CD*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@5FER='5A;"!4
M<F%S:"!&;VQD97(N(@IM<V=S='(@(E1Y:&IE;FYE='1I:6X@:V%I:VMI('9I
M97-T:70@=FER='5A86QI<V5S=&$@<F]S:V%K;W)I:V%N<VEO<W1A+B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T
M>2!&;VQD97(H<RDB"FUS9W-T<B`B5'EH:F5N;N0@:V%N<VEO="(*"B,Z(&9O
M;&1E<G,N<&AP.C(W,@IM<V=I9"`B16UP='D@4V5L96-T960@1F]L9&5R<R(*
M;7-G<W1R(")4>6AJ96YNY"!V86QI='5T(&MA;G-I;W0B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@
M9F]L9&5R(@IM<V=S='(@(E1Y:&IE;F[D(')O<VMA:V]R:6MA;G-I;R(*"B,Z
M(&QI8B])35`N<&AP.CDU,PIM<V=I9"`B16UP='D@7U-P86TB"FUS9W-T<B`B
M5'EH:F5N;N0@<F]?<VMA<&]S=&DB"@HC.B!L:6(O24U0+G!H<#HY-#8*;7-G
M:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R(")?5'EH:F5N;N0@<F]S:V%K;W)I
M(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C8@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$*;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET
M>3\B"FUS9W-T<B`B2^1Y=.0@4$=0+71O:6UI;G1O82XB"@HC.B!T96UP;&%T
M97,O<VUI;64O;F]T86-T:79E+FEN8SHV('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,0IM<V=I9"`B16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*
M;7-G<W1R(")+Y'ETY"!3+TU)344M=&]I;6EN=&]A+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,#`*;7-G:60@(D5N86)L92!M97-S86=E('!R979I
M97=S/R(*;7-G<W1R(")+Y'ETY"!V:65S=&EE;B!E<VEK871S96QU82XB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S<*;7-G:60@(D5N
M8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B4V%L875?:W-E;B!A<V5T=6MS
M970B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$X"FUS9VED
M(")%;F-R>7!T960B"FUS9W-T<B`B4V%L871T=2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU,38@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q
M.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4Q(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-3,*;7-G:60@(D5N9"(*;7-G<W1R(")0Y.1T='EY
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,Y-0IM<V=I9"`B16YD(&9O<G=A<F1E
M9"!M97-S86=E(@IM<V=S='(@(E;D;&ET971T>2!V:65S=&D@<.3D='1Y>2(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-3(*;7-G:60@(D5N9"!M97-S86=E(@IM
M<V=S='(@(E9I97-T:6X@;&]P<'4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S4P
M"B,L('!H<"UF;W)M870*;7-G:60@(D5N9"!M97-S86=E(&9R;VT@)7,B"FUS
M9W-T<B`B)7,@;.1H971TY&WD;B!V:65S=&EN(&QO<'!U+B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<W"FUS9VED(")%;G1E<B!087-S<&AR87-E(@IM<V=S='(@(D%N;F$@<V%L
M87-A;F%T96MS=&DB"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI
M;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P86T@
M9F]L9&5R(@IM<V=S='(@(D%N;F$@;FEM:2!U=61E;&QE(')O<VMA<&]S=&EK
M86YS:6]L;&5S:2(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N
M:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F
M=',@9F]L9&5R(@IM<V=S='(@(D%N;F$@;FEM:2!U=61E;&QE(&QU;VYN;W-K
M86YS:6]L;&5S:2(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C
M="YI;F,Z,C,*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S
M96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(D%N;F$@;FEM:2!U=61E;&QE(&SD
M:&5T971T>6IE;B!V:65S=&EE;B!K86YS:6]L;&5S:2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA
M;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R(")!;FYA(&YI
M;6D@=75D96QL92!R;W-K86MO<FEK86YS:6]L;&5S:2(*"B,Z(&QI8B]396%R
M8V@N<&AP.C8Q,PIM<V=I9"`B16YT:7)E($UE<W-A9V4B"FUS9W-T<B`B2V]K
M;R!V:65S=&DB"@HC.B!C;VUP;W-E+G!H<#HQ,3<R(&UE<W-A9V4N<&AP.C$Y
M-"!T:')E860N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B7"(E<UPB(&QI<^1T=&EI;B!O;FYI<W1U;F5E<W1I(&]S
M;VET96MI<FIA86XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$X
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHR,0HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C,X,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3`*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S(@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z,38S"FUS9VED(")%<G)O<B(*;7-G<W1R(")6:7)H92(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#,Q(&QI8B])34%0+T-L:65N="YP
M:'`Z-#4T"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@
M=&\@24U!4"!S97)V97(N("5S(#H@)7,N(@IM<V=S='(@(E9I<FAE('EH9&ES
M=&5T=.1E<W/D($E-05`M<&%L=F5L:6UE;&QE+B`E<R`Z("5S+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3`@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C0P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG
M(')E<&QY.B`E<RXB"FUS9W-T<B`B5FER:&4@;.1H971E='3D97-SY"!V87-T
M875S=&$Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#(*
M;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")4
M87!A:'1U;6%N('!O:7-T;R!O;FYI<W1U:2XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S<Q"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@
M(C$U(&UI;G5U=&EN(';D;&5I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-C@*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B,S`@<V5K
M=6YN:6X@=N1L96EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W,`IM
M<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(C4@;6EN=75T:6X@=N1L
M96EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W,@IM<V=I9"`B179E
M<GD@:&%L9B!H;W5R(@IM<V=S='(@(E!U;VQE;B!T=6YN:6X@=N1L96EN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V.0IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(DUI;G5U=&EN(';D;&5I;B(*"B,Z(&9O;&1E<G,N<&AP
M.C0S.`IM<V=I9"`B17AP86YD(@IM<V=S='(@(DQA86IE;FYA(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5X<&%N9"!!
M;&PB"FUS9W-T<B`B3&%A:F5N;F$@:V%I:VMI(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R
M<R(*;7-G<W1R("),86%J96YN82!K86EK:VD@:V%N<VEO="(*"B,Z(&9O;&1E
M<G,N<&AP.C0S.`IM<V=I9"`B17AP86YD($9O;&1E<B(*;7-G<W1R("),86%J
M96YN82!K86YS:6\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS,S@@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4S"FUS9VED
M(")%>'!A;F0@3F%M97,B"FUS9W-T<B`B3&%A:F5N;F$@;FEM970B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U,@IM<V=I9"`B17AP86YD(&YA;65S
M(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H92!B
M86-K9W)O=6YD/R(*;7-G<W1R("),86%J96YN82!N:6UE="!A=71O;6%A='1I
M<V5S=&D@=&%U<W1A;&QA('9I97-T:6YK:7)J;VET=7-I:VMU;F%S<V$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B17AP86YD('1H
M92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R
M<R!V:65W/R(*;7-G<W1R("),86%J96YN82!O;&5T=6MS96YA(&MO:V\@:V%N
M<VEO<'5U(&MA;G-I;VED96X@:&%L;&EN;F%S<V$N(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S95]E>'!A;F0N:G,Z-#D@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,30R"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C$Y,B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#,*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0IM<V=I9"`B
M17AP86YD:6YG(@IM<V=S='(@(DQA86IE;FYE=&%A;B(*"B,Z(&QI8B])35`N
M<&AP.CDV-"!L:6(O24U0+G!H<#HY-C8*;7-G:60@(D9?971C:"!-86EL(@IM
M<V=S='(@(DAA7V4@=FEE<W1I="(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M9F5T8VAM86EL+FEN8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS
M9VED(")&971C:"!-86EL(@IM<V=S='(@(DAA92!V:65S=&ET(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@U.`IM<V=I9"`B1F5T8V@@36%I;"!I;B!A
M('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B2&%E('9I97-T:70@97)I;&QI
M<V5S<^0@:6MK=6YA<W-A+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG
M(&]N/R(*;7-G<W1R(")(864@=FEE<W1I="!S:7/DY&YK:7)J875T=6UI<V5N
M('EH=&5Y9&5S<^0B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S(@IM
M<V=S='(@(DAA971T:6EN("5D('9I97-T:>0@<&%L=F5L:6UE;'1A("5S(@H*
M(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B2&%E='1I:6X@
M,2!V:65S=&D@<&%L=F5L:6UE;'1A("5S(@H*(SH@;&EB+T9E=&-H;6%I;"YP
M:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP.C(X.2!L:6(O1F5T8VAM86EL+G!H
M<#HR.3$*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(DAA92!V:65S=&ET
M.B`B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3,*;7-G:60@(D9E=&-H;6%I
M;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")&971C:&UA:6PZ(&5I('5U
M<VEA('9I97-T96KD+B(*"B,Z(&QI8B])35`N<&AP.CDW,`IM<V=I9"`B1FE?
M;'1E<G,B"FUS9W-T<B`B4W5O7V1A='1I;65T(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:G,Z-#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#DT"FUS9VED(")&:6QE(@IM<V=S='(@(E1I961O<W1O(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"FUS9VED(")&:6QT
M97(@3W!T:6]N<R(*;7-G<W1R(")3=6]D871I;B!A<V5T=6MS970B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0IM<V=I9"`B1FEL=&5R(%-E
M='1I;F=S(@IM<V=S='(@(E-U;V1A=&EN(&%S971U:W-E="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU.#@*;7-G:60@(D9I;'1E<B!M97-S86=E(&-O
M;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`B4W5O9&%T82!V:65S=&D@
M;&]U:VMA879I<W1A('-A;F]I<W1A+B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+VYO=&%C=&EV92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")4Y'-SY"!JY')J97-T
M96QMY'-SY"!E:2!V;VD@:^1Y='3DY"!S=6]D871T:6UI82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S='(@
M(E-U;V1A='1I;65T(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E
M+FEN8SHS"FUS9VED(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B4W5O
M9&%T=&EM970@;W9A="!03TE3(%#$Q$Q4Q"(*"B,Z(&QI8B]&:6QT97(N<&AP
M.C$S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97)S.B`E<R!M86YA9V5M
M96YT('!A9V4B"FUS9W-T<B`B4W5O9&%T=7,Z("5S(&AA;&QI;G1A<VEV=2(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS9VED
M(")&:6YD(@IM<V=S='(@(DAA:W4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#DT"FUS9VED(")&:7)S="!-86EL8F]X(%!A9V4B"FUS9W-T<B`B4&]S
M=&EL86%T:6MO;B!E;G-I;6WD:6YE;B!S:79U(@H*(SH@;6%I;&)O>"YP:'`Z
M,S,P"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(D5N<VEM;>1I;F5N('-I
M=G4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,34@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O
M7W)W87)D(@IM<V=S='(@(E;D;%]I=.0B"@HC.B!F;VQD97)S+G!H<#HR-3(@
M=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ-0IM<V=I
M9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B2V%N
M<VEO;VX@;&EI='1Y=N0@=&]I;6EN=&\@+2!687)M:7-T=7,B"@HC.B!F;VQD
M97)S+G!H<#HR.#D@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T
M+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI
M;F,Z,3`@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.0IM<V=I9"`B1F]L
M9&5R($YA=FEG871O<B(*;7-G<W1R(")+86YS:6]I9&5N(&AA;&QI;G1A(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D9O;&1E<B!3=6UM
M87)Y(@IM<V=S='(@(DMA;G-I;VED96X@>6AT965N=F5T;R(*"B,Z(&%C;"YP
M:'`Z,C,*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+B(*
M;7-G<W1R(")+86YS:6]I9&5N(&IA:V%M:6YE;B!E:2!O;&4@:^1Y=/9S<^0N
M(@H*(SH@9F]L9&5R<RYP:'`Z-#<*;7-G:60@(D9O;&1E<B!U<V4@:7,@;F]T
M(&5N86)L960N(@IM<V=S='(@(DMA;G-I;VET82!E:2!V;VD@:^1Y='3DY"XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34X"FUS9VED(")&;W)M870@
M;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S
M86=E<R!D871E9"!T;V1A>2(*;7-G<W1R("(B"B)!:F%N(&5S:71Y<W1A<&$@
M;FEI;&QE('9I97-T96EL;&4L(&IO:7-S82!O;B!K=6QU=F%N('#D:7;D;B!P
MY&EVY&WDY'+D+B(*"B,Z(&-O;7!O<V4N<&AP.C@R,"!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B5N1L
M:73D(&5D96QL965N(@H*(SH@8V]M<&]S92YP:'`Z.#`U"FUS9VED(")&;W)W
M87)D.B(*;7-G<W1R(")6Y&QI=.0@961E;&QE96XZ(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C,X,`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B
M161E;&QE96YVY&QI=&5T='D@=FEE<W1I(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C,W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&;W)W87)D960@;65S<V%G92!F
M<F]M("5S(@IM<V=S='(@(D5D96QL965N=N1L:71E='1Y('9I97-T:2!LY&AE
M='3D:N1L=.0@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`R
M"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R(")6
M87-T875S('9A<&%A+W9A<F%T='4@<'EY;G3V]FXB"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(W"FUS9VED(")&<F]?;2(*
M;7-G<W1R("),Y&AE='3D7VKD(@H*(SH@;65S<V%G92YP:'`Z,C<P('1H<F5A
M9"YP:'`Z,34T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.CDW"B,Z
M(&QI8B]396%R8V@N<&AP.C4X.0IM<V=I9"`B1G)O;2(*;7-G<W1R("),Y&AE
M='3D:N0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS9VED(")&
M<F]M($%D9')E<W,B"FUS9W-T<B`B3.1H971TY&KD;B!O<V]I=&4B"@HC.B!C
M;VUP;W-E+G!H<#HX,3<@8V]M<&]S92YP:'`Z.#(Q"FUS9VED(")&=V0Z(@IM
M<V=S='(@(D9W9#HB"@HC.B!C;VUP;W-E+G!H<#HQ,S$Q"FUS9VED(")&=V0Z
M("(*;7-G<W1R(")&=V0Z("(*"B,Z(&-O;7!O<V4N<&AP.C$S,3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1G=D.B`E=2!&;W)W87)D960@365S<V%G97,B"FUS
M9W-T<B`B1G=D.B`E=2!E9&5L;&5E;G;D;&ET971T>>0@=FEE<W1IY"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.`IM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S='(@
M(EEL96ES970@87-E='5K<V5T(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@;65S<V%G97,_("A)
M34%0(&]N;'DI(@IM<V=S='(@(DAA92!V86EN('5U9&5T('9I97-T:70@*'9A
M:6X@24U!4"DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS
M,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34T"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW,C@*;7-G:60@(D=O(@IM<V=S='(@(DUE;F4B"@HC
M.B!T:')E860N<&AP.C$S-@IM<V=I9"`B1V\@=&\@365S<V%G92(*;7-G<W1R
M(")-96YE('9I97-T:6EN(@H*(SH@;&EB+TE-4"YP:'`Z-3`R"B,L('!H<"UF
M;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S
M7"(B"FUS9W-T<B`B365N92!O<V]I=&5K:7)J82!M97)K:6YTY.1N(%PB)7-<
M(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,S8*;7-G:60@(D=R86YT
M(&%C8V5S<R(*;7-G<W1R(")!;FYA(&]I:V5U9&5T(@H*(SH@;65S<V%G92YP
M:'`Z-30Y(&QI8B]&:6QT97(N<&AP.C$S,2!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HV,@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T
M:6]N+G!H<#HV."!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,3D@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C$Q,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,3,*(SH@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z-#(S"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,B!L
M:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$R-PIM<V=I9"`B2$5212(*;7-G<W1R(")4Q%-4Q"(*"B,Z('1E;7!L871E
M<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,2!L:6(O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(P"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HX,`IM
M<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@8V]M<&]S92YP:'`Z,C8P
M"FUS9VED(")(5$U,(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R(")6:65S
M=&D@2%1-3"UM=6]D;W-S82(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E
M<G,N:6YC.C4X"FUS9VED(")(96%D97)S(@IM<V=S='(@(D]T<VEK;W0B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE
M<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R
M(")4Y'-SY"!O;B!V:65S=&DL(&IO=&$@;VQI="!K:7)J;VET=&%M87-S83HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4V"FUS9VED(")(:61D96XB
M"FUS9W-T<B`B4&EI;&]T971T=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-34*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE=R(*;7-G<W1R(")0
M:6EL;W1E='1U(&ME<VMU<W1E;'5SY&EE;N1K>6WD<W/D(@H*(SH@;6%I;&)O
M>"YP:'`Z,S4R"FUS9VED(")(:61E($1E;&5T960B"FUS9W-T<B`B4&EI;&]T
M82!P;VES=&5T=70B"@HC.B!F;VQD97)S+G!H<#HR.#0*;7-G:60@(DAI9&4@
M56YS=6)S8W)I8F5D(@IM<V=S='(@(E!I:6QO=&$@=&EL86%M871T;VUA="(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,@IM<V=I9"`B
M2&EG:"(*;7-G<W1R(")+;W)K96$B"@HC.B!M86EL8F]X+G!H<#HW,3@@;65S
M<V%G92YP:'`Z,S`T('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3(*
M;7-G:60@(DAI9V@@4')I;W)I='DB"FUS9W-T<B`B2V]R:V5A('!R:6]R:71E
M971T:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,0IM
M<V=I9"`B2&EG:&5S="(*;7-G<W1R(")+;W)K96EN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8X-0IM<V=I9"`B2&]W(&1O('EO=2!W86YT('1O(&1I
M<W!L87D@871T86-H;65N=',_(@IM<V=S='(@(DUI=&5N(&QI:71E=&EE9&]S
M=&]T(&[D>71E=.3D;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`T
M"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E9"!L:6YE<R!I;B!A(')E
M<&QY(@IM<V=S='(@(DUI=&5N('9A<W1A=6MS965N(&UE<FMI=.3D;B!K96YE
M;&QE(&QA:6YA='5T(')I=FET(&MU=6QU=F%T(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T<B`B24U!4"(*"B,Z
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(Y"FUS9VED("))34%0("A!=71O
M($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(DE-05`@*%1U;FYI<W1A('!R
M;W1O:V]L;&$@875T;VUA871T:7-E<W1I*2(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,SDQ"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@4V5R=F5R(&-L
M;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS
M9W-T<B`B24U!4"UP86QV96QI;B!S=6QK:2!Y:'1E>61E;BX@4&%L=F5L:6UE
M;B!I;&UO:71U<SH@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C$V-2!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!4"!O
M=F5R(%-33"(*;7-G<W1R("))34%0(&IA(%-33"US86QA=7,B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I9"`B24U!4"!O=F5R(%-33"`H
M<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(DE-05`@:F$@4U-,
M+7-A;&%U<R`H:71S92!A;&QE:VER:F]I=&5T='4@=F%R;65N;F4I(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C8*;7-G:60@(DE-05`@;W9E
M<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R("))34%0(&IA(%-33"US86QA
M=7,@*&ET<V4@86QL96MI<FIO:71E='1U('9A<FUE;FYE*2(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z,S8X"FUS9VED("))34%0('-E<G9E<B!C;&]S960@
M=&AE(&-O;FYE8W1I;VXN(@IM<V=S='(@(DE-05`M<&%L=F5L:6X@<W5L:VD@
M>6AT97ED96XN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C0@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,
M4R(*;7-G<W1R("))34%0(&5I(%1,4RUS86QA=7-T82(*"B,Z(&QI8B]&971C
M:&UA:6PO:6UA<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E
M<G,B"FUS9W-T<B`B24U!4"]03U`S('/D:&OV<&]S=&EP86QV96QI;65T(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT,3$*;7-G:60@(DEF('5S:6YG(%-3
M3"!O<B!43%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L(&5X=&5N
M<VEO;B!L;V%D960N(@IM<V=S='(@(B(*(DIO<R!KY'ETY'0@4U-,('1A:2!4
M3%,@<V%L875S=&$L(&YI:6X@<VEN=6QL82!P:73DY"!O;&QA(&OD>71E='3D
M=FES<^0@4$A0.FX@(@HB;W!E;G-S;"UL86%J96YN=7,N(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3(*;7-G:60@(DEF
M('EO=2!C;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@
M=VEL;"!B92!L;W-T(2(*;7-G<W1R(")*;W,@:F%T:V%T+"!N:6EN(&MA:6MK
M:2!V:65S=&ET(&MA;G-I;VES<V$@='5H;W5T=79A="$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G
M<W1R("+$;.0@:'5O;6EO:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G<W1R(")*Y'3D(&MA
M:6MK:2!H=6]M:6]I;6%T=&$B"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A
M=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`B2W5V82(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C`*;7-G:60@(DEM<&]R
M="(*;7-G<W1R(")4=6\B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z.#4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-0IM<V=I
M9"`B26UP;W)T($ME>2(*;7-G<W1R(")4=6\@879A:6XB"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3,Y"FUS9VED("));7!O<G0@2V5Y<&%I<B(*;7-G
M<W1R(")4=6\@879A:6YP87)I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,C<*;7-G:60@(DEM<&]R="!-97-S86=E<R(*;7-G<W1R(")4
M=6\@=FEE<W1I="(*"B,Z('!G<"YP:'`Z-#$*;7-G:60@(DEM<&]R="!01U`@
M2V5Y(@IM<V=S='(@(E1U;R!01U`M879A:6XB"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.CDQ"FUS9VED("));7!O<G0@4&5R<V]N86P@0V5R=&EF
M:6-A=&4B"FUS9W-T<B`B5'5O(&AE;FMI;/9K;VAT86EN96X@<V5R=&EF:6MA
M871T:2(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,30*;7-G
M:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97DB"FUS9W-T<B`B
M5'5O(&AE;FMI;/9K;VAT86EN96X@<V%L86EN96X@4$=0+6%V86EN(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@
M4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B5'5O(&AE;FMI;/9K
M;VAT86EN96X@:G5L:VEN96X@4$=0+6%V86EN(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!097)S;VYA;"!3
M+TU)344@0V5R=&EF:6-A=&5S(@IM<V=S='(@(E1U;R!H96YK:6SV:V]H=&%I
M<V5T(%,O34E-12US97)T:69I:V%A=&ET(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHT,"!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#(*;7-G:60@
M(DEM<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(E1U;R!J=6QK:6YE;B!A=F%I
M;B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B
M26UP;W)T(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(E1U;R!J=6QK:6YE;B!0
M1U`M879A:6XB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M.`IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(E1U
M;R!J=6QK:6YE;B!3+TU)344M879A:6XB"@HC.B!S;6EM92YP:'`Z,38*;7-G
M:60@(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@(E1U;R!3+TU)344M879A
M:6XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.CD*;7-G:60@
M(DEM<&]R="!M8F]X($9I;&4B"FUS9W-T<B`B5'5O(&UB;W@M=&EE9&]S=&\B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@
M)7,N(@IM<V=S='(@(E1U;R!M8F]X+71I961O<W1O("5S(&MA;G-I;V]N("5S
M+B(*"B,Z(&UA:6QB;W@N<&AP.C<R."!M97-S86=E+G!H<#HU,#4@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E;7!L871E
M<R]M86EL8F]X+VQE9V5N9"YI;F,Z-R!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$V"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S,*
M;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R(")4Y')K9>0B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@;65S<V%G
M97,B"FUS9W-T<B`B5.1R:V7D="!V:65S=&ET(@H*(SH@9F]L9&5R<RYP:'`Z
M,34Q"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S
M(&9R;VT@)7,N(@IM<V=S='(@(E1U;W1I:6X@)60@=FEE<W1IY"!LY&AT965S
M=.0@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V-@IM<V=I
M9"`B26X@4')O8V5S<R(*;7-G<W1R(")496ME:6QLY"(*"B,Z(&9O;&1E<G,N
M<&AP.C,V-2!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC
M.C$T(&QI8B]&;VQD97(N<&AP.C@U"B,Z(&QI8B])35`N<&AP.C@S,B!L:6(O
M24U!4"]4<F5E+G!H<#HQ,3D@;&EB+TE-05`O5')E92YP:'`Z,C(R"FUS9VED
M("));F)O>"(*;7-G<W1R("));F)O>"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3(*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H
M92!H96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`B3&EI=.0@=F%S=&%U:W-E
M96X@;'EH>70@>6AT965N=F5T;R!O='-A:V5T:65D;VES=&$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA
M;"!M97-S86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(DQI:73D(&%L:W5P97+D
M:6YE;B!V:65S=&D@=F%S=&%U:W-E96XN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R+W-T871U<RYP
M:'`Z,3,P"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L
M:6,@2V5Y(@IM<V=S='(@(E1I971O:F$@)7,Z;B!J=6QK:7-E<W1A(&%V86EM
M97-T82(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF
M;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B5&EE
M=&]J82!O;6%S=&$@<V%L86ES97-T82!A=F%I;65S=&$B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC($ME>2(*
M;7-G<W1R(")4:65T;VIA(&]M87-T82!J=6QK:7-E<W1A(&%V86EM97-T87-I
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C4V"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y.0IM<V=I9"`B26YL:6YE(@IM<V=S
M='(@(E9I97-T:6X@>6AT97ED97-SY"(*"B,Z('1E;7!L871E<R]S;6EM92]I
M;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R
M92(*;7-G<W1R("),86ET82!S97)T:69I:V%A='1I('3D:.1N(@H*(SH@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E
M<G-O;F%L(%!R:79A=&4@4$=0($ME>2!(97)E(@IM<V=S='(@(DQA:71A(&AE
M;FMI;/9K;VAT86EN96X@<V%L86EN96X@4$=0+6%V86EN('3D:.1N(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T
M(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B3&%I=&$@
M:&5N:VEL]FMO:'1A:6YE;B!J=6QK:6YE;B!01U`M879A:6X@=.1HY&XB"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4*;7-G:60@(DEN<V5R
M="!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(DQA:71A(&IU;&MI;F5N
M(%!'4"UA=F%I;B!TY&CD;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT,3,*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES
M(&-O;7!O;F5N="XB"FUS9W-T<B`B5.1L;&4@:V]M<&]N96YT:6QL92!O;B!V
M86QI='1U(';DY'+D('1O:6UI;G1O+B(*"B,Z(&UA:6QB;W@N<&AP.C4W-"!M
M86EL8F]X+G!H<#HV,C$*;7-G:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R
M(")%<.1K96QP;R!O<V]I=&4B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C,P-PIM<V=I9"`B26YV86QI9"!296UO=&4@36%I;&)O>"(*;7-G<W1R(")6
M:7)H965L;&EN96X@973D<&]S=&EL86%T:6MK;R(*"B,Z(&-O;7!O<V4N<&AP
M.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I
M;B!E+6UA:6P@861D<F5S<SH@)7,N(@IM<V=S='(@(D5PY&ME;'!O(&UE<FMK
M:2!SY&AK]G!O<W1I;W-O:71T965S<V$Z("5S+B(*"B,Z('!G<"YP:'`Z,38@
M<VUI;64N<&AP.C<X"FUS9VED("));G9A;&ED(&ME>2(*;7-G<W1R(")6:7)H
M965L;&EN96X@879A:6XB"@HC.B!P9W`N<&AP.C$Y,@IM<V=I9"`B26YV86QI
M9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN(@IM<V=S='(@(E9I<FAE96QL
M:6YE;B!H96YK:6SV:V]H=&%I;F5N('-A;&%I;F5N(%!'4"UA=F%I;BXB"@HC
M.B!P9W`N<&AP.C$V-PIM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B
M;&EC(&ME>2XB"FUS9W-T<B`B5FER:&5E;&QI;F5N(&AE;FMI;/9K;VAT86EN
M96X@:G5L:VEN96X@4$=0+6%V86EN+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R(")+Y.1N=&5I
M;F5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3DQ"FUS
M9VED(")+0B(*;7-G<W1R(")+0B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ,3,*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B079A:6UE;B!P:71U
M=7,B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+
M97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T
M92X@($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E;F5R871I;VX_(@IM<V=S='(@
M(D%V86EM96X@;'5O;G1I('9O:2!V:65DY"!P:71KY&X@86IA;BX@2F%T:V5T
M86%N:V\@879A:6UE;B!L=6]N=&EA/R(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED(")+
M97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO
M="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"B)!=F%I;6EE
M;B!T=6]N=&D@96D@;VQE(&OD>71E='3D=FES<^0N(%3D;&QE('!A;'9E;&EM
M96QL92!E:2!V;VD@='5O9&$@(@HB=&EE9&]S=&]J82XB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P+FEN8SHS
M.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@
M:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C
M;VYT86-T<RXB"FUS9W-T<B`B(@HB079A:6UI96X@='5O;G1I(&5I(&]L92!K
MY'ET971TY'9I<W/D+B!3:6YU;&QA(&5I(&]L92!O<V]I=&5K:7)J86$@(@HB
M;>3D<FET96QT>6[D('EH=&5Y<W1I961O:7-S82XB"@HC.B!P9W`N<&AP.C,Q
M-`IM<V=I9"`B2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R(")!=F%I;65N(&SD:&5T>7,@;VYN:7-T=6D@
M:G5L:VES96QL92!A=F%I;G!A;'9E;&EM96QL92XB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(Q-0IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B
M2VEE;&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DU"FUS9VED("),
M87-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")0;W-T:6QA871I:V]N('9I:6UE
M:6YE;B!S:79U(@H*(SH@;6%I;&)O>"YP:'`Z,S0S"FUS9VED("),87-T(%!A
M9V4B"FUS9W-T<B`B5FEI;65I;F5N('-I=G4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU-#<*;7-G:60@(DQI;FL@071T86-H;65N=',_
M(@IM<V=S='(@(DQI;FMI=.0@;&EI=&5T:65D;W-T;W0N(@H*(SH@871T86-H
M;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C$P.#0*;7-G:60@(DQI;FME
M9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R("),:6YK:71E
M='ET(&QI:71E=&EE9&]S=&]T(&]N(&MI96QL971T>2XB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3$P,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:6YK<R!W:6QL
M(&5X<&ER92!O;B`E<R(*;7-G<W1R("),:6YK:70@=F%N:&5N='5V870@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W,0IM<V=I9"`B(@HB3&ES
M="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E
M96X_("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@(@HB;VYL>2!S964@8V]N=&%C
M=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*2(*;7-G<W1R("(B
M"B).Y'ETY"!K86EK:VD@>6AT97ES=&EE9&]T('EH=&5Y<W1I961O="UNY&MY
M;>1S<^0@*$IO<R!TY&WD(&%S971U<R!O;B!P;VES("(*(G#DY&QTY"P@;FEI
M;B!NY'ET973DY&X@=F%I;B!H865T=70@>6AT97ES=&EE9&]T*2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#(*;7-G:60@(DQI<W1I;F<@:6X@=&AE
M($AE861E<B(*;7-G<W1R(")/='-I:VMO=&EE=&]J96X@='5L;W-T=7,B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S`*;7-G:60@(DQO
M8V%L($UA:6QB;W@Z(@IM<V=S='(@(E!A:6MA;&QI;F5N('!O<W1I:V%N<VEO
M.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-S$*;7-G:60@(DQO
M8V%T:6]N(@IM<V=S='(@(E!A:6MK82(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C(T"FUS9VED("),;V<@:6XB"FUS9W-T<B`B2VER:F%U9'4@
M<VESY.1N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("),;V<@:6X@=&\@)7,B"FUS9W-T<B`B2VER:F%U9'4@
M<VESY.1N(&]H:F5L;6%A;B`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3,X"FUS9VED("),;V=I;B(*;7-G<W1R(")+:7)J875D=2!S:7/D
MY&XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(DQO9VEN
M(%1A<VMS(@IM<V=S='(@(E1E:'3D=N1T('-I<^3D;FMI<FIA=71U;6ES97-S
M82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-`IM<V=I
M9"`B3&]W(@IM<V=S='(@(DUA=&%L82(*"B,Z(&UA:6QB;W@N<&AP.C<R,2!M
M97-S86=E+G!H<#HS,#8@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ
M,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(D%L:&%I;F5N('!R:6]R
M:71E971T:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y
M-0IM<V=I9"`B3&]W97-T(@IM<V=S='(@(D%L:&%I<VEN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`IM<V=I9"`B36%C:6YT;W-H
M($9I;&4B"FUS9W-T<B`B36%C:6YT;W-H('1I961O<W1O(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"FUS9VED(")-86EL(@IM<V=S
M='(@(E/D:&OV<&]S=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*
M;7-G:60@(DUA:6P@4')E=FEE=W,B"FUS9W-T<B`B5FEE<W1I96X@97-I:V%T
M<V5L=2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI
M;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SHB
M"FUS9W-T<B`B4&]S=&EP86QV96QI;65N('1Y>7!P:2P@:F]H;VX@;W1E=&%A
M;B!Y:'1E>71TY#HB"@HC.B!F;VQD97)S+G!H<#HS-CD@9F]L9&5R<RYP:'`Z
M,S@S"FUS9VED(")-86EL8F]X(@IM<V=S='(@(DMA;G-I;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3$*;7-G:60@(DUA:6QB;W@@86YD($9O;&1E
M<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B4&]S=&EK86YS:6\M(&IA(&MA
M;G-I;V[D:WEMY&X@87-E='5K<V5T(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O
M;&1E<B!A<R!3965N(@IM<V=S='(@(DUE<FMI='-E(&MA:6MK:2!V:65S=&ET
M(&MA;G-I;W-S82!V86YH;VEK<VDB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHQ.0IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L
M9&5R(&%S(%5N<V5E;B(*;7-G<W1R(")-97)K:71S92!K86EK:VD@=FEE<W1I
M="!K86YS:6]S<V$@=75S:6MS:2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,P"FUS9VED(")-87)K(&%S.B(*;7-G<W1R(")-97)K:71S93HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C,X"FUS9VED(")-87)K(&1I9F9E
M<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_
M(@IM<V=S='(@(DUE<FMI='-E(&5R:2!L86EN875K<V5T(&5R:2!VY')E:6QL
MY"XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*;7-G
M:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS9W-T
M<B`B365R:VET<V4@=FEE<W1I="!V86YH;VEK<VD_("AV86EN($E-05`I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T-@IM<V=I9"`B36%R:R!S:6UP
M;&4@;6%R:W5P/R(*;7-G<W1R(")-97)K:71S92!Y:W-I;FME<G1A:7-E;&QA
M(&UE<FMI;F[D;&SD+B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN
M8SHT.0IM<V=I9"`B36%T8V@@06QL(%%U97)I97,B"FUS9W-T<B`B5.1S;>3D
M=N1T(&MA:6MK:2!H86MU96AD;W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z-#4*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R(")3
M;W!I=F%T(&IO:6AI;FMI;B!H86MU96AT;VEH:6XB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU,#4*;7-G:60@(DUA>&EM=6T@071T86-H
M;65N="!3:7IE(@IM<V=S='(@(DQI:71E=&EE9&]S=&]N('-U=7)I;B!S86QL
M:71T=2!K;VMO(@H*(SH@;&EB+V%P:2YP:'`Z-SD*;7-G:60@(DUA>&EM=6T@
M3G5M8F5R(&]F($9O;&1E<G,B"FUS9W-T<B`B2V%N<VEO:61E;B!E;FEM;>1I
M<VWDY'+D(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@W
M"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D
M+B(*;7-G<W1R("),:6ET971I961O<W1O:F$@;VX@<W5U<FEN('-A;&QI='1U
M(&WDY'+D+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X
M,PIM<V=I9"`B36%X:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE
M9"XB"FUS9W-T<B`B3&EI=&5T:65D;W-T;VIE;B!Y:'1E96YL87-K971T=2!K
M;VMO(&]N('-U=7)I;B!S86QL:71T=2XB"@HC.B!L:6(O0FQO8VLO=')E95]F
M;VQD97)S+G!H<#HS"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@
M(E9A;&EK:V\@:V%N<VEO;&ES=&$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0R
M"FUS9VED(")-97-S86=E(@IM<V=S='(@(E9I97-T:2(*"B,Z(&-O;7!O<V4N
M<&AP.C4Y."!C;VUP;W-E+G!H<#HV,C4@8V]M<&]S92YP:'`Z-C<Y(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO
M;B(*;7-G<W1R(")6:65S=&EN(&MI<FIO:71U<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,#8*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G<W1R(")6
M:65S=&EN('#D:7;D>7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#D@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDU(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#,*;7-G:60@
M(DUE<W-A9V4@3W!T:6]N<R(*;7-G<W1R(")6:65S=&EA<V5T=6MS970B"@HC
M.B!S96%R8V@N<&AP.C,P,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T
M<B`B2&%K=2!V:65S=&ES=.0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3$P"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`B5FEE<W1I;B!K;VMO
M(@H*(SH@;65S<V%G92YP:'`Z,SDQ"FUS9VED(")-97-S86=E(%-O=7)C92(*
M;7-G<W1R(")6:65S=&D@<F%A:V%M=6]D;W-S82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@
M(E9I97-T:6X@;'5K=2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M-@IM<V=I9"`B365S<V%G92!F;&%G<R(*;7-G<W1R(")6:65S=&EN('1I;&%T
M:65D;W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED
M(")-97-S86=E(&9O;&1E<G,B"FUS9W-T<B`B5FEE<W1I:V%N<VEO="(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B365S
M<V%G92!F<F]M("5S(@IM<V=S='(@(E9I97-T:2!LY&AE='3D:N1L=.0@)7,B
M"@HC.B!M86EL8F]X+G!H<#HV-C(*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C
M:&UE;G1S(@IM<V=S='(@(E9I97-T:7-SY"!O;B!L:6ET=&5I=.0B"@HC.B!M
M86EL8F]X+G!H<#HV-3,*;7-G:60@(DUE<W-A9V4@:7,@96YC<GEP=&5D(@IM
M<V=S='(@(E9I97-T:2!O;B!S86QA='1U(@H*(SH@;6%I;&)O>"YP:'`Z-C0X
M"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G<W1R(")6:65S=&EN(&]N
M(&%L;&5K:7)J;VET971T=2(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHS-@IM<V=I9"`B365S<V%G92!M871C:&5S(@IM<V=S='(@(E9I97-T
M:2!TY'-MY.0B"@HC.B!C;VUP;W-E+G!H<#HX-C0@8V]M<&]S92YP:'`Z.#<Q
M"FUS9VED(")-97-S86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(")6:65S=&EN(&]H:F%U<R!O;FYI<W1U:2XB"@HC.B!C;VUP;W-E+G!H
M<#HQ,3(R"B,L('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C
M97-S9G5L;'DL(&)U="!N;W0@<V%V960@=&\@)7,B"FUS9W-T<B`B5FEE<W1I
M;B!LY&AE='ES(&]N;FES='5I+"!M=71T82!S:73D(&5I('1A;&QE=&5T='4@
M:V%N<VEO;VX@)7,B"@HC.B!C;VUP;W-E+G!H<#HQ,3@Q(&-O;7!O<V4N<&AP
M.C$Q.#D*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(E9I97-T:6X@;.1H971Y<R!O;FYI<W1U:2XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3,P"FUS9VED(")-97-S86=E<R!P97(@<&%G92!I;B!T
M:&4@;6%I;&)O>"!V:65W+B(*;7-G<W1R(")6:65S=&EE;B!L=6MU;>3D<N0@
M<&]S=&EK86YS:6]NY&MY;>1S<^0N(@H*(SH@;6%I;&)O>"YP:'`Z,S$P"FUS
M9VED(")-97-S86=E<R!T;R(*;7-G<W1R(")6:65S=&ET(&MA;G-I;V]N(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB"FUS
M9W-T<B`B375U=&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC
M.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@861D<F5S
M<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R("),86%J96YN971T
M879A;&QE(&ME;G3D;&QE(%PB)7-<(B!L]GET>6D@=7-E86UP:2!K=6EN('EK
M<VD@=F%I:'1O96AT;RXB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M-3`*;7-G:60@(DUO=F4B"FUS9W-T<B`B4VEI<G+D(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$V"FUS9VED(")-;W9E(&1O=VXB
M"FUS9W-T<B`B4VEI<G+D(&%L87-PY&EN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8P-@IM<V=I9"`B36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@
M9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6"(*;7-G<W1R
M("(B"B)3:6ER<N0@<F]S:V%P;W-T:79I97-T:70@<F]S:V%P;W-T:6MA;G-I
M;V]N(&IA(&5I(')O<VMA<&]S=&EV:65S=&ET($E.0D]8("(*(FMA;G-I;V]N
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E
M('1O(&9O;&1E<B(*;7-G<W1R(")3:6ER<N0@:V%N<VEO;VXB"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,30*;7-G:60@(DUO=F4@
M=7`B"FUS9W-T<B`B4VEI<G+D('EL]G-PY&EN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E
M<FYA=&EV92(*;7-G<W1R(")-=6QT:7!A<G0O86QT97)N871I=F4B"@HC.B!T
M:')E860N<&AP.C<V('1H<F5A9"YP:'`Z,34W"FUS9VED(")-=6QT:7!L92!-
M97-S86=E(%9I97<B"FUS9W-T<B`B36]N:79I97-T:6[D:WEMY"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHX"FUS9VED
M(").3TY%(@IM<V=S='(@(D5)($U)5,3$3B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(DY/5$4B"FUS
M9W-T<B`B2%5/34%!(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,S@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,PIM<V=I9"`B
M3F%M92(*;7-G<W1R(").:6UI(@H*(SH@<&=P+G!H<#HQ,#8*;7-G:60@(DYA
M;64@86YD+V]R(&5M86EL(&-A;FYO="!B92!E;7!T>2(*;7-G<W1R(").:6UI
M('1A:2!SY&AK]G!O<W1I;W-O:71E(&5I('-A82!O;&QA('1Y:&KD(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,0IM<V=I9"`B3F5E9',@06-T
M:6]N(@IM<V=S='(@(E9A871I:2!T;VEM96YP:61E='3D(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8W
M"FUS9VED(").979E<B(*;7-G<W1R(")%:2!K;W-K86%N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4V,`IM<V=I9"`B3F5V97(@<V%V92!A='1A8VAM
M96YT<R(*;7-G<W1R("+$;.0@=&%L;&5T82!L:6ET971I961O<W1O:F$B"@HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T
M<B`B575S:2(*"B,Z(&QI8B])35`N<&AP.C4Y-0IM<V=I9"`B3F5W($9O;&1E
M<B(*;7-G<W1R(")5=7-I(&MA;G-I;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX.`IM<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`B5'5L979A="!V:65S
M=&ET(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(Q(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HR,@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HT
M-@IM<V=I9"`B3F5W($UE<W-A9V4B"FUS9W-T<B`B575S:2!V:65S=&DB"@HC
M.B!M86EL8F]X+G!H<#HW-S`@;&EB+TU)344O2&5A9&5R<RYP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@
M(E5U<VD@=FEE<W1I("5S.FQL92(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R(")5=61E="!V
M:65S=&ET(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S
M,PIM<V=I9"`B3F5X="(*;7-G<W1R(")3975R86%V82(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@
M365S<V%G92(*;7-G<W1R(")3975R86%V82!V:65S=&DB"@HC.B!M86EL8F]X
M+G!H<#HS-#$*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(")3975R86%V82!S
M:79U(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,X('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4U,0HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.38V"FUS9VED(").;R(*;7-G<W1R(")%:2(*"B,Z('-M
M:6UE+G!H<#HR,C(*;7-G:60@(DYO($-E<G1I9FEC871E(&9O=6YD(@IM<V=S
M='(@(E9A<FUE;FYE='1A(&5I(&SV>71Y;GET(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHU"FUS9VED(").;R!%;F-R>7!T:6]N
M(@IM<V=S='(@(D5I('-A;&%U<W1A(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$Y"FUS9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B16D@
M86EN=71T86MA86X@879A:6YT82!A=F%I;G)E;FMA87-S82(*"B,Z(&UA:6QB
M;W@N<&AP.C,V,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*
M;7-G<W1R(")%:2!V:65S=&5JY"(*"B,Z('!G<"YP:'`Z,3,S"FUS9VED(").
M;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B16D@='5O='4@
M86EN=71T86MA86X@:G5L:VES=&$@4$=0+6%V86EN=&$N(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHX-`IM<V=I9"`B3F\@4&5R<V]N86P@0V5R
M=&EF:6-A=&4@4')E<V5N="(*;7-G<W1R(")(96YK:6SV:V]H=&%I<W1A('9A
M<FUE;FYE='1A(&5I(&]L92!S86%T879I;&QA(@H*(SH@;&EB+TUA:6QB;W@N
M<&AP.C,S,PIM<V=I9"`B3F\@4')E=FEE=R!497AT(@IM<V=S='(@(D5I(&5S
M:6MA='-E;'5A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ-0IM
M<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS9W-T<B`B2G5L:VES:6$@
M879A:6UI82!E:2!L]GET>6YY="(*"B,Z('-M:6UE+G!H<#HQ-#<*;7-G:60@
M(DYO(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(")%:2!T
M=6]T=2!A:6YU='1A:V%A;B!J=6QK:7-T82!3+TU)344M879A:6YT82XB"@HC
M.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(DYO(&%T=&%C
M:&UE;G1S(&9O=6YD+B(*;7-G<W1R("),:6ET971I961O<W1O:F$@96D@;/9Y
M='EN>70N(@H*(SH@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#`*;7-G:60@(DYO
M(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K97DN
M(@IM<V=S='(@(E/D:&OV<&]S=&ET:65T;VIA(&5I(&]L;'5T(&IU;&MI<V5S
M<V$@879A:6UE<W-A+B(*"B,Z(&%C;"YP:'`Z-S$@86-L+G!H<#HY-PIM<V=I
M9"`B3F\@9F]L9&5R('-E;&5C=&5D+B(*;7-G<W1R(")%:2!K86YS:6]I=&$@
M=F%L:71T=6YA+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#D*;7-G
M:60@(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M86EL
M+B(*;7-G<W1R(")9:&1E<W3D:^3D;B!K86YS:6]I<W1A(&5I('1A<FMA<W1E
M=&$@=75S:6$@=FEE<W1E:N0N(@H*(SH@9F]L9&5R<RYP:'`Z,C`Q(&QI8B]&
M;VQD97(N<&AP.C0V-R!L:6(O1F]L9&5R+G!H<#HU,3<*;7-G:60@(DYO(&9O
M;&1E<G,@=V5R92!S<&5C:69I960B"FUS9W-T<B`B16D@:V%N<VEO:71A(&WD
MY')I=&5T='ENY"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-34*;7-G
M:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`B66AD
M97-SY&ODY&X@:V%N<VEO<W-A(&5I(&]L92!U=7-I82!V:65S=&5JY"(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-3(*;7-G:60@(DYO(&9O;&1E<G,@
M=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`B66AD97-SY&ODY&X@:V%N
M<VEO<W-A(&5I(&]L92!L=6ME;6%T=&]M:6$@=FEE<W1E:N0B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,S,V"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*
M;7-G<W1R(")%:2!T96MS=&GD('9I97-T:6X@=FEE<W1I;W-I;W-S82(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-38X"FUS9VED(").;R!M97-S86=E(')E
M='5R;F5D+B(*;7-G<W1R(")6:65S=&ES=.0@96D@='5L;'5T('-I<^1L=/;D
M+B(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS-S4*;7-G:60@(DYO(&UE<W-A9V5S
M(&UA=&-H960@>6]U<B!S96%R8V@N(@IM<V=S='(@(DAA:W5E:&1O:6QL82!E
M:2!L]GET>6YY="!Y:'3D:^3D;B!V:65S=&GD+B(*"B,Z('!G<"YP:'`Z,3@U
M"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N
M(@IM<V=S='(@(D5I('1U;W1U(&%I;G5T=&%K86%N('-A;&%I<W1A(%!'4"UA
M=F%I;G1A(@H*(SH@<&=P+G!H<#HQ-C$*;7-G:60@(DYO('!E<G-O;F%L(%!'
M4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(")%:2!T=6]T=2!A:6YU
M='1A:V%A;B!J=6QK:7-T82!01U`M879A:6YT82(*"B,Z('-M:6UE+G!H<#HQ
M.3<*;7-G:60@(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP
M;W)T960N(@IM<V=S='(@(D5I('1U;W1U(&%I;G5T=&%K86%N(&AE;FMI;/9K
M;VAT86ES=&$@4R]-24U%+7-E<G1I9FEK86%T=&EA+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,C0V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(Y.0IM<V=I9"`B(@HB3F\@<&5R<V]N86P@<')I=F%T92!K97D@97AI<W1S
M('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N(@IM
M<V=S='(@(B(*(E-A;&%I<W1A(&%V86EN=&$@96D@;VQE(&]L96UA<W-A+"!J
M;W1E;B!S86QA='1U82!V:65S=&GD(&5I('9O:2!A=6MA:7-T82XB"@HC.B!S
M<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").;R!S<&5L;&-H96-K:6YG('!R;V=R
M86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`B2VER:F]I='5S=FER:&5I9&5N('1A
M<FMI<W1U<V]H:F5L;6%A(&5I(&]L92!MY.1R:71E;'1Y+B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI
M;F<@97)R;W)S(@IM<V=S='(@(D5I(&MI<FIO:71U<W9I<FAE:73D(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P,`IM<V=I9"`B3F\@
M<W5G9V5S=&EO;G,B"FUS9W-T<B`B16D@96AD;W1U:W-I82(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z-38P"FUS9VED(").;R!S=7!P;W)T960@24U!4"!A
M=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N(@IM<V=S='(@
M(E1U971T=6$@24U!4"UA=71E;G1I:V%A=&EO=&%P86$@96D@;/9Y='EN>70N
M(@H*(SH@86-L+G!H<#HV-R!A8VPN<&AP.CDS"FUS9VED(").;R!U<V5R('-P
M96-I9FEE9"XB"FUS9W-T<B`B16D@:^1Y='3D:N3D(&WDY')I=&5L='ENY"XB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`T"FUS9VED(").;VX@
M4&%R=&EC:7!A;G0B"FUS9W-T<B`B16D@;W-A;&QI<W1U:F$B"@HC.B!T96UP
M;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR-"!T96UP;&%T97,O<')E
M9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P"B,Z('1E;7!L871E<R]P<F5F<R]S
M;W5R8V5S96QE8W0N:6YC.C,U('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T
M+FEN8SHR-`HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8V,0IM<V=I9"`B3F]N92(*;7-G<W1R(")%:2!M
M:73DY&XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*
M;7-G:60@(DYO<FUA;"(*;7-G<W1R(").;W)M86%L:2(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS.0IM<V=I9"`B3F]T($1E;&5T960B"FUS9W-T<B`B16D@<&]I
M<W1E='1U(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHQ,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(S"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#(*;7-G:60@(DYO="!$<F%F
M="(*;7-G<W1R(")%:2!L=6]N;F]S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-`IM
M<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R(")%:2!TY')K9>0B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS9VED(").;W0@4&5R
M<V]N86PB"FUS9W-T<B`B16D@:&5N:VEL]FMO:'1A:6YE;B(*"B,Z(&QI8B]#
M<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP="]334E-12YP:'`Z,30Y(&QI
M8B]#<GEP="]01U`N<&AP.C$S.0IM<V=I9"`B3F]T(&$@=F%L:60@<'5B;&EC
M(&ME>2XB"FUS9W-T<B`B17#D:V5L<&\@:G5L:VEN96X@879A:6XN(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T
M960@;65S<V%G97,B"FUS9W-T<B`B4&]I<W1A;6%T=&]M870@=FEE<W1I="(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-3$*;7-G:60@(DYO="!I
M;7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B16D@=.1R:V7D="!V:65S=&ET
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H
M<#HW,0IM<V=I9"`B3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE
M(@IM<V=S='(@(DAU;VUA871H86XL(&5T=.0@=.1MY"!V;VD@:V5S=.3D(&IO
M;FMI;B!A:6MA82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#0*;7-G
M:60@(DYO=&AI;F<B"FUS9W-T<B`B16D@;6ETY.1N(@H*(SH@871T86-H;65N
M="YP:'`Z.#D*;7-G:60@(DYO=&EF:6-A=&EO;CH@3&EN:V5D(&%T=&%C:&UE
M;G0@9&]W;FQO861E9"(*;7-G<W1R("));&UO:71U<SH@5&%L;&5T971T:6EN
M(&QI;FMI=&5T='D@;&EI=&5T:65D;W-T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S<*;7-G:60@(DYU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O
M;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM
M<V=S='(@(B(*(DIO<R!V:65S=&ET('!O:7-T971A86X@:W5U:V%U<VET=&%I
M;BP@;FEI;B!K=6EN:V$@;6]N=&$@:W5U:V%U='1A("(*(G/D:6QY=&5TY.1N
M('9A;FAO:F$@;&EN:VET971T>6KD(&QI:71E=&EE9&]S=&]J82XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"FUS9VED(").=6UB97(@;V8@;VQD
M('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL
M>2XB"FUS9W-T<B`B(@HB2F]S('9I97-T:70@<&]I<W1E=&%A;B!K=75K875S
M:71T86EN+"!N:6EN(&MU:6YK82!M;VYT82!V86YH86$@;.1H971E='1Y:F5N
M("(*(G9I97-T:65N(&MA;G-I;W1A('/D:6QY=&5TY.1N+B(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T"FUS9VED(")/2R(*;7-G
M<W1R(")/2R(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT
M.2!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0HC.B!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*;7-G<W1R(")404DB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$U"FUS9VED(")/;&0@
M;65S<V%G97,B"FUS9W-T<B`B5F%N:&%T('9I97-T:70B"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-3(*
M;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N(@IM
M<V=S='(@(E!O:7-T971A86X@=FEE<W1E:N0@=F%N:&]I<W1A(&SD:&5T971T
M>6IE;B!V:65S=&EE;B!K86YS:6]I<W1A+B(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HR.`IM<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U
M;G)E860@;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T<B`B3N1Y=.0@=F%I;B!N
M92!K86YS:6]T+"!J;VES<V$@;VX@;'5K96UA='1O;6EA('9I97-T96KD+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z.#$*;7-G:60@
M(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@
M86-T:6]N+B(*;7-G<W1R(")686QI='-E('9A:6X@>6MS:2!K86YS:6\@=.1H
MY&X@=&]I;6EN=&]O;BXB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,3`@=&5M
M<&QA=&5S+VUE;G4N:6YC.C,P"FUS9VED(")/<&5N($9O7VQD97(B"FUS9W-T
M<B`B079A82!K85]N<VEO(@H*(SH@9F]L9&5R<RYP:'`Z-#`X"FUS9VED(")/
M<&5N960@1F]L9&5R(@IM<V=S='(@(D%V86$@:V%N<VEO(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<P,`IM<V=I9"`B3W!T:6]N86P@4&%R=&EC
M:7!A;G0B"FUS9W-T<B`B36%H9&]L;&EN96X@;W-A;&QI<W1U:F$B"@HC.B!F
M971C:&UA:6PN<&AP.C0S('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL
M+FEN8SHV"B,Z('1E;7!L871E<R]F971C:&UA:6PO=&]P+FEN8SHS"FUS9VED
M(")/=&AE<B!-86EL($%C8V]U;G1S(@IM<V=S='(@(DUU=70@<^1H:_9P;W-T
M:71I;&ET(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@
M(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B375U="!A<V5T=6MS970B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,`IM<V=I9"`B3W5T8F]U;F0@
M4V5R=F5R(@IM<V=S='(@(DSD:'1E=N0@<&%L=F5L:6XB"@HC.B!T96UP;&%T
M97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C$V-`HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#,@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,C@Y"FUS9VED(")01U`B"FUS9W-T<B`B4$=0
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHW"FUS
M9VED(")01U`@16YC<GEP="!-97-S86=E(@IM<V=S='(@(E!'4"US86QA='1U
M('9I97-T:2(*"B,Z(&-O;7!O<V4N<&AP.C,S-0IM<V=I9"`B4$=0($5R<F]R
M.B`B"FUS9W-T<B`B4$=0('9I<FAE.B`B"@HC.B!C;VUP;W-E+G!H<#HS,30*
M;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA
M;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B4$=0('9I<FAE.B!386QA:6YE;B!A
M=F%I;B!V86%T:6D@<V%L87-A;F%T96MS=&EN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B4$=0
M($%S971U:W-E="(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!087-S<&AR
M87-E($EN<'5T(@IM<V=S='(@(E!'4"!S>6]TY"!S86QA<V%N871E:W-T:2(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O
M;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B2&5N:VEL]FMO:'1A:6YE;B!01U`M879A:6YP
M87)I('9A871I:2!S86QA='1U82!75U<M>6AT97ET=.0N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,3<R"FUS9VED(")01U`@4'5B;&EC($ME>2!4
M97AT(@IM<V=S='(@(DIU;&MI<V5N(%!'4"UA=F%I;65N('1E:W-T:2(*"B,Z
M('!G<"YP:'`Z,30U"B,L('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(&9O<B!<(B5S("@E<RE<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D+B(*
M;7-G<W1R(")*=6QK:6YE;B!01U`M879A:6X@;&ESY'ES(&]N;FES='5I(&]S
M;VET=&5E;&QE.B!<(B5S("@E<RE<(B(*"B,Z('!G<"YP:'`Z,C0Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")*=6QK:6YE;B!01U`M
M879A:6X@<&]I<W1E='1I:6X@;W-O:71T965L=&$Z(%PB)7-<(B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER
M:6YG(@IM<V=S='(@(DIU;&MI;F5N(%!'4"UA=F%I;G)E;F=A<R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`IM<V=I9"`B4$=0
M(%-I9VX@365S<V%G92(*;7-G<W1R(")01U`M86QL96MI<FIO:71A('9I97-T
M:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.0IM
M<V=I9"`B4$=0(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(E!'4"US
M86QA82!J82!A;&QE:VER:F]I=&$@=FEE<W1I(@H*(SH@<&=P+G!H<#HQ.3@*
M;7-G:60@(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM
M<V=S='(@(E-A;&%I<V5N(%!'4"UA=F%I;65N(&QI<^1Y<R!O;FYI<W1U:2XB
M"@HC.B!P9W`N<&AP.C$W,PIM<V=I9"`B4$=0('!U8FQI8R!K97D@<W5C8V5S
M<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")*=6QK:7-E;B!01U`M879A:6UE;B!L
M:7/D>7,@;VYN:7-T=6DN(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N
M:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@
M<WES=&5M+B(*;7-G<W1R(")01U`@:^1Y='3V(&]N(&5S=&5T='D@=.1S<^0@
M:N1R:F5S=&5L;>1S<^0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,C`W"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C
M=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E
M("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)01U`@96D@;VQE(&OD>73V<W/D
M+"!J;W1E;B!D:6=I=&%A;&ES:6$@86QL96MI<FIO:71U:W-I82!E:2!V;VD@
M=&%R:VES=&%A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-`IM
M<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@
M<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS
M9W-T<B`B4$=0(&5I(&]L92!KY'ET]G-SY"P@:F]T96X@<V%L871T=6IA('9I
M97-T96KD(&5I('9O:2!A=6MA:7-T82XB"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,@IM<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@
M=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E
M;G1L>2`B"B)S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S
M="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F96%T
M=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4$=0
M.FX@:^1Y='3V(&5D96QL>71TY.0@<&]N;F%H9'5S:6MK=6YO:71A+B!*;W,@
M<V5L86EM97-I(&%S971U:W-E="!E<W3D=N1T("(*(F5R:6QL:7-T96X@:6MK
M=6YO:61E;B!A=F%A;6ES96XL(&YI:6X@<VEN=6X@<&ETY.0@;75U='1A82!N
MY&ETY"!A<V5T=6MS:6$@(@HB=&%I(&5T('9O:2!KY'ET=.3D(%!'4"UT;VEM
M:6YT;VIA+B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS9VED
M(")03U`S(@IM<V=S='(@(E!/4#,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*
M;7-G<W1R(")03U`S("A4=6YN:7-T82!P<F]T;VMO;&QA(&%U=&]M86%T=&ES
M97-T:2DB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q-PIM<V=I9"`B
M4$]0,R!O=F5R(%-33"(*;7-G<W1R(")03U`S(&IA(%-33"US86QA=7,B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R
M(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(E!/4#,@
M:F$@4U-,+7-A;&%U<R`H:71S92!A;&QE:VER:F]I=&5T='4@=F%R;65N;F4I
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C@*;7-G:60@(E!/
M4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R(")03U`S(&IA(%-3
M3"US86QA=7,@*&ET<V4@86QL96MI<FIO:71E='1U('9A<FUE;FYE*2(*"B,Z
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$Q"FUS9VED(")03U`S+"!N;R!4
M3%,B"FUS9W-T<B`B4$]0,RP@96D@5$Q3+7-A;&%U<W1A(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHR,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")086=E("5D(&]F("5D(@IM<V=S='(@(E-I=G4@)60@+R`E9"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.3(*;7-G:60@(E!A9V4@=VET:"!T:&4@
M1FER<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B4VEV=2P@:F]S<V$@96YS
M:6UMY&EN96X@=75S:2!V:65S=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#DS"FUS9VED(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A
M9V4B"FUS9W-T<B`B4VEV=2P@:F]S<V$@;VX@=FEI;65I;F5N('5U<VD@=FEE
M<W1I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-#,*;7-G
M:60@(E!A<G0H<RDB"FUS9W-T<B`B3W-A*'0I(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$R,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R(")386QA
M<V%N871E:W-T:2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G
M:60@(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R(")386QA<V%N871E:W-T
M:2`H575D97-T86%N*2(*"B,Z('!G<"YP:'`Z,S`V('-M:6UE+G!H<#HR,S$*
M;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G
M<W1R(")386QA<V%N871E:W-T:6X@<&]I<W1O(&]N;FES='5I+B(*"B,Z('1E
M;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P
M+W!A<W-P:')A<V4N:6YC.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R
M(")386QA<V%N871E:W-T:3HB"@HC.B!P9W`N<&AP.C$P.`IM<V=I9"`B4&%S
M<W!H<F%S97,@8V%N;F]T(&)E(&5M<'1Y(@IM<V=S='(@(E-A;&%S86YA=&5K
M<W1I(&5I('-A82!O;&QA('1Y:&KD(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@
M(E!A<W-P:')A<V5S(&1O(&YO="!M871C:"(*;7-G<W1R(")386QA<V%N871E
M:W-T:70@96EVY'0@=.1S;>3D("(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHW,2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y,0HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C`*;7-G:60@(E!A
M<W-W;W)D(@IM<V=S='(@(E-A;&%S86YA(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C0X"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E-U;W)I=&$@>6QLY'!I
M=&]T;VEM96YP:71E970@<VESY.1N:VER:F%U='5M:7-E;B!Y:'1E>61E<W/D
M+B(*"B,Z(&%C;"YP:'`Z-S4@86-L+G!H<#HQ,#$*;7-G:60@(E!E<FUI<W-I
M;VYS(&9O<B!T:&ES('5S97(@8V%N;F]T(&)E(&-H86YG960N(@IM<V=S='(@
M(E3D;>1N(&OD>71TY&KD;B!O:6ME=6MS:6$@96D@=F]I(&UU=71T86$N(@H*
M(SH@;6%I;&)O>"YP:'`Z-CDW(&UE<W-A9V4N<&AP.C0Y,R!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C$P"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,C0*;7-G:60@(E!E<G-O;F%L(@IM<V=S='(@(DAE;FMI;/9K
M;VAT86EN96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@
M(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D]M870@=&EE9&]T(@H*
M(SH@<&=P+G!H<#HQ,38*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E
M;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DAE;FMI;/9K;VAT86ES
M96X@4$=0+6%V86EN<&%R:6X@;'5O;G1I(&]N;FES='5I+B(*"B,Z('!G<"YP
M:'`Z,3(S"FUS9VED(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B2&5N:VEL]FMO:'1A:7-T96X@4$=0+6%V86EM
M:65N('!O:7-T;R!O;FYI<W1U:2XB"@HC.B!S;6EM92YP:'`Z,C`S"FUS9VED
M(")097)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@
M(@IM<V=S='(@(DAE;FMI;/9K;VAT86ES:6$@4R]-24U%+79A<FUE;G1E:71A
M($5)('1U;W1U.B`B"@HC.B!S;6EM92YP:'`Z,3(X"FUS9VED(")097)S;VYA
M;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M2&5N:VEL]FMO:'1A:7-T96X@4R]-24U%+6%V86EM:65N('!O:7-T;R!O;FYI
M<W1U:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(R"FUS9VED(")0
M;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R
M9',_(@IM<V=S='(@(DQA:71A(&%L;&5K:7)J;VET=7,@=F%S=&%U<W9I97-T
M:65N(&IA(';D;&ET971TY'9I96X@=FEE<W1I96X@86QK=75N+B(*"B,Z(&-O
M;7!O<V4N<&AP.C(U.`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S
M<V%G92(*;7-G<W1R(")6:65S=&D@=&5K<W1I;75O9&]S<V$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<X.`IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O
M;B!N97<@;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U
M<'!O<G0@96UB961D960@(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O
M(&]N(%=I;F1O=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL
M("(*(G)E<75I<F4@82!P;'5G:6XN(@IM<V=S='(@(B(*(E-O:71A(.3D;FD@
M=75S:7-T82!V:65S=&5I<W3D/R!4Y&WD('1O:6UI;G1O('9A871I:2!S96QA
M:6UE96X@;&EI=&5T='EJY"`B"B+DY&YI=&EE9&]S=&]J82X@3.1H97,@:V%I
M:VMI('-E;&%I;65T(%=I;F1O=W,@:F$@36%C(&%L=7-T86QL82!S:7/D;'3D
M=N1T("(*(N3D;FET:65D;W-T;VIA+"!M=71T82!M=6EL;&$@86QU<W1O:6QL
M82!S86%T971A86X@=&%R=FET82!L86%J96YN=6MS:6$N(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B06YN82!U=61E;B!K
M86YS:6]N(&YI;6DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ,#0@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#8*
M;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E
M<CHB"FUS9W-T<B`B06YN82!U=61E;B!K86YS:6]N(&YI;6DZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,SD*;7-G:60@(E!L96%S
M92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@(D%N;F$@=75S:2!N:6UI
M.B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E
M(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D
M('1O("(*(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S
M:6]N+B(*;7-G<W1R("(B"B)!;FYA('-A;&%I<V5N(%!'4"UA=F%I;65N('-A
M;&%S86YA=&5K<W1I+B!3:6YU;B!P:73DY"!A;G1A82!TY&WD('1E:W-T:2!V
M86EN("(*(FME<G)A;B`E<RUI<W1U;FYO;B!A:6MA;F$N(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3
M+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E
M;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS
M9W-T<B`B(@HB06YN82!S86QA:7-E;B!3+TU)344M879A:6UE;B!S86QA<V%N
M871E:W-T:2X@4VEN=6X@<&ETY.0@86YT86$@=.1MY"!T96MS=&D@(@HB=F%I
M;B!K97)R86X@)7,M:7-T=6YN;VX@86EK86YA+B(*"B,Z(')E8V]M<&]S92YP
M:'`Z.38*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE
M(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG
M("(*(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN
M('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G
M86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K
M965P(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@
M240N(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S
M='(@(B(*(DMI<FIA=61U('5U9&5S=&%A;B!S:7/DY&X@:F%T:V%A:W-E<VD@
M=FEE<W1I;B!K:7)J;VET=&%M:7-T82X@2F]S($54(&OD>73D("(*(F5VY'-T
M96ETY"!*02!K:7)J;VET870@=FEE<W1E:N0@<&]N;F%H9'5S:6MK=6YA<W-A
M+"!N:6EN('-I;G5N('!I=.3D("(*(FMI<FIA=71U82!S:7/DY&X@;7GV<R!P
MY.1I:VMU;F%S<V$N(%3D;>0@;VX@<&%K:V\@=&5H9.0@<VEK<VDL(&5T=.0@
M(@HB;6%H9&]L;&ES970@:'GV:VODY&KD="!E:7;D="!S86$@=&EE=.3D('-E
M<W-I;VX@240@=&EE=&]J87-I+B!0>7EDY&UM92!J;R`B"B)E='5KY'1E96X@
M86YT965K<VD@86EH975T=&%M86%M;64@:.1I<FGV=.0N(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHW,0IM<V=I9"`B4&QE87-E('!R;W9I9&4@
M>6]U<B!P87-S=V]R9"XB"FUS9W-T<B`B06YN82!S86QA<V%N87-I+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C<*;7-G:60@(E!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(D%N;F$@:^1Y='3D:N1T
M=6YN=6MS97-I+B(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O24U0+G!H<#HT
M-C,*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED
M(&%D9')E<W-E<RXB"FUS9W-T<B`B2V]R:F%A(&5PY&WDY'+D:6YE;B!T86D@
M=FER:&5E;&QI;F5N(&]S;VET92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C8S"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R
M(&)E9F]R92!Y;W4@<&5R9F]R;2!T:&ES(&%C=&EO;BXB"FUS9W-T<B`B5F%L
M:71S92!K86YS:6\@96YN96X@=.1MY&X@=&]I;6EN;F]N('-U;W)I='1A;6ES
M=&$N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]J879A<V-R:7!T+FEN8SHT,0IM
M<V=I9"`B4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E
M87)C:"XB"FUS9W-T<B`B5F%L:71S92!A:6YA:VEN('EK<VD@:V%N<VEO+"!J
M;W-T82!H865T86%N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R
M(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B5F%L:71S92!TY&QL92!O
M<&5R86%T:6]L;&4@=F%I;B!Y:W-I(&MA;G-I;RXB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z-S,*;7-G:60@(E!L96%S92!S96QE8W0@
M;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T<B`B5F%L
M:71S92!T86D@;75O:VMA82!O:6ME86X@<'5O;&5I<V5S<V$@;&%A=&EK;W-S
M83HB"@HC.B!C;VYF:6<O;6]T9"YP:'`N9&ES=#HT,0IM<V=I9"`B4&]W97)E
M9"!B>2!(;W)D92(*;7-G<W1R(")+Y'ET=.3D($AO<F1E82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,30*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N
M871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B3&%I=&$@86QL
M96MI<FIO:71U:W-E;B!E=&5E;B!E<F]T=&EM970@*"<M+2`G*2(*"B,Z(&9I
M;'1E<G!R969S+G!H<#HS.2!P9W`N<&AP.C(U,R!S;6EM92YP:'`Z,C,W"FUS
M9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T
M<B`B07-E='5K<VEE;B!PY&EV:71Y<R!O;FYI<W1U:2XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4')E=FEE=R(*
M;7-G<W1R(")%<VEK871S96QU(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@365S<V%G92(*
M;7-G<W1R(")%9&5L;&EN96X@=FEE<W1I(@H*(SH@;6%I;&)O>"YP:'`Z,S,R
M"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(D5D96QL:6YE;B!S:79U
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S
M"FUS9VED(")0<FEN="(*;7-G<W1R(")4=6QO<W1A(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*;7-G:60@(E!R:6]R:71Y(@IM<V=S
M='(@(E!R:6]R:71E971T:2(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHW-@IM<V=I9"`B4')I=F%T92!+97D@4&%S<W=O<F0B"FUS9W-T
M<B`B4V%L86ES96X@879A:6UE<VD@<V%L87-A;F$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-34Y"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B"FUS9W-T<B`B2WES
M>2!J;VMA(&ME<G1A(&MU;B!LY&AE=&5TY.1N(&QI:71E=&EE9&]S=&\[($]L
M971U:W-E;F$@14DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X"FUS
M9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[
M(&1E9F%U;'0@=&\@6453(@IM<V=S='(@(DMY<WD@:F]K82!K97)T82!K=6X@
M;.1H971E=.3D;B!L:6ET971I961O<W1O.R!/;&5T=6MS96YA($M93$S$(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0
M<F]T;V-O;#HB"FUS9W-T<B`B4')O=&]K;VQL83HB"@HC.B!L:6(O0W)Y<'0O
M4$=0+G!H<#HT,S`*;7-G:60@(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O
M<G0@:&%S(&)E96X@9&ES86)L960N(@IM<V=S='(@(DIU;&MI<V5N(%!'4"UA
M=F%I;G!A;'9E;&EM96X@:^1Y='3V(&]N(&5S=&5T='DN(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<U]D96QE=&5D+FEN8SHW"FUS9VED(")0=7)?9V4@1&5L971E9"(*
M;7-G<W1R(")4=5]H;V$@<&]I<W1E='5T(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D
M96QE=&5D+FEN8SHW"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(E1U
M:&]A('!O:7-T971U="(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C(T"FUS9VED(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B5'5H;V$@
M<&]I<W1E='5T(&MA;G-I;VES=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@
M(DUI=&5N('5S96EN(')O<VMA:V]R:2!K86YS:6\@='EH:F5N;F5TY.1N.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E(&UE
M<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT
M(&]F(&1A>7,N(@IM<V=S='(@(E!O:7-T82!NY&EN(&UO;F5N('#D:7;D;B!I
M:^1I<V5T('9I97-T:70@<F]S:V%K;W)I:V%N<VEO<W1A+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(E!U<F=E(&]L9"!M97-S86=E
M<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R(")0;VES=&$@=F%N:&%T
M('9I97-T:70@<F]S:V%K;W)I:V%N<VEO<W1A+B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+B(*
M;7-G<W1R(")0;VES=&5T=&EI;B`E9"!V:65S=&GD(')O<VMA:V]R:6MA;G-I
M;W-T82XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z-C,*;7-G:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L
M9&5R+B(*;7-G<W1R(")0;VES=&5T=&EI;B`Q('9I97-T:2!R;W-K86MO<FEK
M86YS:6]S=&$N(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHQ-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N
M,F9-0B`@*"4N,F8E)2DB"FUS9W-T<B`B4&]S=&EK:6EN=&GV.B`E+C)F34(@
M+R`E+C)F34(@("@E+C)F)24I(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A
M+FEN8SHR,0HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z("4N
M,F9-0B`O($Y/($Q)34E4(@IM<V=S='(@(E!O<W1I:VEI;G1I]CH@)2XR9DU"
M("\@14D@4D%*3TE455-402(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI
M;F,Z,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B!.3R!,
M24U)5"(*;7-G<W1R(")0;W-T:6MI:6YT:?8Z($5)(%)!2D])5%535$$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`P"B,L('!H<"UF;W)M870*;7-G
M:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(DQA:6YA=7,@)68Z(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,CD*;7-G:60@(E)E8G5I;&0@
M1F]L9&5R(%1R964B"FUS9W-T<B`B4F%K:V5N;F$@:V%N<VEO<'5U('5U9&5L
M;&5E;B(*"B,Z(&QI8B]396%R8V@N<&AP.C8Q-PIM<V=I9"`B4F5C96EV960@
M3VXB"FUS9W-T<B`B4V%A<'5I('!E<FEL;&4B"@HC.B!L:6(O4V5A<F-H+G!H
M<#HV,C4*;7-G:60@(E)E8V5I=F5D(%-I;F-E(@IM<V=S='(@(E-A87!U:2!P
M97)I;&QE(&KD;&ME96XB"@HC.B!L:6(O4V5A<F-H+G!H<#HV,C$*;7-G:60@
M(E)E8V5I=F5D(%5N=&EL(@IM<V=S='(@(E-A87!U:2!P97)I;&QE(&5N;F5N
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B575D96QL965N;VAJ85]A(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS
M9VED(")2961I<F5C="(*;7-G<W1R(")5=61E;&QE96YO:&IA82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E9&ER
M96-T($UE<W-A9V4B"FUS9W-T<B`B575D96QL965N;VAJ86$@=FEE<W1I(@H*
M(SH@8V]M<&]S92YP:'`Z.#(W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A
M9V4B"FUS9W-T<B`B575D96QL965N;VAJ86$@=.1MY"!V:65S=&DB"@HC.B!C
M;VUP;W-E+G!H<#HX.#`*;7-G:60@(E)E9&ER96-T:6YG(&9A:6QE9"XB"FUS
M9W-T<B`B575D96QL965N;VAJ875S(&5PY&]N;FES='5I+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-S,*;7-G:60@(E)E9G)E<V@@1F]L9&5R(%9I
M97=S.B(*;7-G<W1R(")0Y&EV:73D('!O<W1I:V%N<VEO;N1K>6WDY#HB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C0@=&5M<&QA=&5S+V9O
M;&1E<G,O:&5A9"YI;F,Z.0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(DQA=&%A
M('5U9&5S=&%A;B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C,*
M;7-G:60@(E)E;&]A9"!6:65W(@IM<V=S='(@(DQA=&%A(&[D:WEMY"!U=61E
M<W1A86XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(X(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E;65M8F5R('1H92!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(DUU:7-T82!V87!A82]V
M87)A='1U('1I961O="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38X
M"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S='(@(DUU:7-T
M82!E9&5L;&EN96X@;N1K>6WD(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C(W"FUS9VED(")296UO=&4@36%I;&)O>#HB"FUS9W-T<B`B
M173D<&]S=&EL86%T:6MK;SHB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD
M<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M(%-E87)C:"(*;7-G
M<W1R(")0;VES=&$@:V5N='3D(&AA:W5E:&1O:7-T82(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0IM<V=I9"`B4F5M;W9E('-O
M=7)C92(*;7-G<W1R(")P;VES=&$@;.1H9&4B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHX"FUS9VED(")296YA;64@1F]L9&5R*',I(@IM
M<V=S='(@(DYI;67D(&MA;G-I;W0@=75D96QL965N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD
M97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(").:6UEY"!LY&AE
M=&5T='EJ96X@=FEE<W1I96X@:V%N<VEO('5U9&5L;&5E;B!K=75K875D96X@
M86QU<W-A+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0R-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296YA;6EN9R!<(B5S7"(@=&\@7"(E<UPB(&9A:6QE9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)+86YS:6]N
M(%PB)7-<(B!N:6UEY&UI;F5N(%PB)7-<(B!E<.1O;FYI<W1U:2X@4&%L=F5L
M:6UE;B!V:7)H96EL;6]I='5S(&]L:2(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B
M"FUS9W-T<B`B5F%S=&%?82!L:7-T86QL92(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS
M9W-T<B`B2V]R=F%A('9A:6AT;V5H9&]L;&$Z(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S
M='(@(E9A<W1A82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3(@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,`IM<V=I9"`B4F5P;'D@4V5N
M="XB"FUS9W-T<B`B5F%S=&%U<R!LY&AE=&5T='DN(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T
M;R!!;&PB"FUS9W-T<B`B5F%S=&%A(&MA:6MI;&QE(@H*(SH@8V]M<&]S92YP
M:'`Z-S<Q"FUS9VED(")297!L>2!T;R!!;&PZ(@IM<V=S='(@(E9A<W1A82!K
M86EK:6QL93HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,3`*;7-G:60@(E)E<&QY('1O($QI<W0B"FUS9W-T<B`B5F%S=&%A
M(&QI<W1A;&QE(@H*(SH@8V]M<&]S92YP:'`Z-S<S"FUS9VED(")297!L>2!T
M;R!,:7-T.B(*;7-G<W1R(")687-T86$@;&ES=&%L;&4Z(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L
M>2!T;R!?06QL(@IM<V=S='(@(E]687-T86$@:V%I:VEL;&4B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3,P(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,SD*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T.0IM<V=I
M9"`B4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B
M3.1H973D('9A<W1A=7-V:65S=&D@96DM='5E='5S<V$@;75O9&]S<V$N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-PIM<V=I9"`B4F5P;'D@
M=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(B(*
M(DSD:&5TY"!V87-T875K<V5N82!V87!A82]V87)A='1U('1I961O="!S975R
M86%V86QL92!K86AD96QL92!K=75K875D96QL92XB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3,V"FUS9VED(")297!L>2!W:71H(')E<75E<W1E
M9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(DSD:&5TY"!V87-T
M875K<V5N82!P>7ED971Y="!V87!A82]V87)A='1U('1I961O="XB"@HC.B!M
M97-S86=E+G!H<#HR-S0*;7-G:60@(E)E<&QY+51O(@IM<V=S='(@(E9A<W1A
M=7-O<V]I=&4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#(P"FUS9VED(")297!L
M>2U4;SH@(@IM<V=S='(@(E9A<W1A=7-O<V]I=&4Z("(*"B,Z(&-O;7!O<V4N
M<&AP.C<V.0IM<V=I9"`B4F5P;'DZ(@IM<V=S='(@(E9A<W1A=7,Z(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(V"FUS9VED(")297!O<G0@87,@
M26YN;V-E;G0B"FUS9W-T<B`B26QM;VET82!H87)M:71T;VUA;F$B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3
M<&%M(@IM<V=S='(@(DEL;6]I=&$@<F]S:V%P;W-T:6YA(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@T"FUS9VED(")297%U97-T(&$@
M7U)E860@4F5C96EP="(*;7-G<W1R(")?4'EY9.0@:6QM;VET=7,@=FEE<W1I
M;B!L=6ME;6ES97-T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S,*
M;7-G:60@(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T<B`B4'EY9.0@
M:6QM;VET=7,@=FEE<W1I;B!L=6ME;6ES97-T82XB"@HC.B!M86EL8F]X+G!H
M<#HQ.#@*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4'EY9&5T='GD('9I97-T:>0@96D@;/9Y='EN>70N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y,@IM<V=I9"`B4F5Q=6ER960@4&%R
M=&EC:7!A;G0B"FUS9W-T<B`B4&%K;VQL:6YE;B!O<V%L;&ES='5J82(*"B,Z
M('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHR.2!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C$T,`HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R
M"FUS9VED(")297-E="(*;7-G<W1R(")4>6AJ96YNY"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,38*;7-G:60@(E)E<W!O;F1E;G0@4W1A='5S
M(%5P9&%T960N(@IM<V=S='(@(E9A<W1A86IA;B!T:6QA=&EE9&]T(&]N('#D
M:79I=&5T='DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R(")*871K82(*"B,Z(')E
M8V]M<&]S92YP:'`Z.3<*;7-G:60@(E)E<W5M92!Y;W5R('-E<W-I;VXB"FUS
M9W-T<B`B2F%T:V$@:7-T=6YT;V%S:2(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHT-`IM<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#
M;VUP;W-I=&EO;EPB(@IM<V=S='(@(E!A;&%A(%PB5FEE<W1I;B!K:7)J;VET
M=6MS965N7"(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE
M8W0N:6YC.C,Q"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE
M8W0N:6YC.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0IM
M<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`B4&%L86$@=&%K
M86ES:6X@2&%E('9I97-T96EH:6XB"@HC.B!T96UP;&%T97,O<VUI;64O;F]T
M86-T:79E+FEN8SHQ-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,0HC
M.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,34@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$T.0HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N
M:6YC.C(R('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHV,`HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,38S('1E;7!L871E<R]A8VPO86-L+FEN8SHQ
M-S4*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E!A;&%A(&%S
M971U:W-I:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S`W"FUS9VED
M("(B"B)2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE
M=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B
M(@HB4&%L86$@<&]S=&EK86YS:6]S:79U;&QE(&MU;B!V:65S=&D@;VX@<&]I
M<W1E='1U+"!S:6ER<F5T='D@=&%I(&MO<&EO:71U+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV.#,*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]O
M;&DB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T,B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(S-PHC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C0R-`IM<V=I9"`B4R]-24U%(@IM<V=S='(@(E,O34E-12(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3(*;7-G:60@
M(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%('-A;&%T
M='4@=FEE<W1I(@H*(SH@8V]M<&]S92YP:'`Z,S<Q"FUS9VED(")3+TU)344@
M17)R;W(Z("(*;7-G<W1R(")3+TU)344@=FER:&4Z("(*"B,Z(&-O;7!O<V4N
M<&AP.C,U,`IM<V=I9"`B4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@
M9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R(")3+TU)344@5FER
M:&4Z(%-A;&%I;F5N(&%V86EN('9A871I:2!S86QA<V%N871E:W-T:6XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"FUS9VED(")3+TU)344@3W!T
M:6]N<R(*;7-G<W1R(")3+TU)344M87-E='5K<V5T(@H*(SH@<VUI;64N<&AP
M.C0V"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R(")3
M+TU)344@<WGV=.0@<V%L87-A;F%T96MS=&DB"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y<&%I
M<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R(")(96YK:6SV:V]H=&%I;F5N(%,O34E-12UA=F%I;G!A<FD@=F%A
M=&EI('-A;&%T='5A(%=75RUY:'1E>71TY"XB"@HC.B!S;6EM92YP:'`Z,3,V
M"B,L('!H<"UF;W)M870*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y(&9O<B!<
M(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")*=6QK
M:6YE;B!3+TU)344M879A:6X@<&]I<W1E='1I:6X@;W-O:71T965L=&$@7"(E
M<UPB(@H*(SH@<VUI;64N<&AP.C$U.`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+
M97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")*=6QK:7-E;B!3+TU)
M344M879A:6UE;B!L:7/D>7,@;VYN:7-T=6DN(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97ER:6YG
M(@IM<V=S='(@(DIU;&MI;F5N(%,O34E-12UA=F%I;G)E;F=A<R(*"B,Z('-M
M:6UE+G!H<#HR,#<*;7-G:60@(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP
M86ER('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B2G5L:VEN96XO4V%L
M86EN96X@4R]-24U%+6%V86EN<&%R:6X@;&ESY'ES(&]N;FES='5I+B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*;7-G:60@
M(E,O34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%+6%L;&5K:7)J
M;VET82!V:65S=&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI
M<W0N:6YC.C$T"FUS9VED(")3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A9V4B
M"FUS9W-T<B`B4R]-24U%+7-A;&%A(&IA(&%L;&5K:7)J;VET82!V:65S=&DB
M"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHT"FUS9VED(")3
M+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS
M9W-T<B`B4R]-24U%(&OD>71T]B!O;B!E<W1E='1Y('3D<W/D(&KD<FIE<W1E
M;&WD<W/D+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L
M960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E
M9"XB"FUS9W-T<B`B4R]-24U%(&5I(&]L92!KY'ET]G-SY"P@:F]T96X@<V%L
M871T=6IA('9I97-T96KD(&5I('9O:61A(&%U:V%I<W1A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<S"FUS9VED("(B"B)3+TU)344@<W5P
M<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S
M:6=N960@;65S<V%G92!C86YN;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R
M("(B"B)3+TU)344@96D@;VQE(&OD>73V<W/D+"!J;W1E;B!TY&WD;B!D:6=I
M=&%A;&ES97-T:2!A;&QE:VER:F]I=&5T=6X@=FEE<W1I;B`B"B)S:7/D;'3V
MY"!E:2!V;VED82!NY'ET=.3D+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA
M8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E
M("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)3+TU)344@96D@;VQE(&OD>73V
M<W/D+"!J;W1E;B!D:6=I=&%A;&ES:6$@86QL96MI<FIO:71U:W-I82!E:2!V
M;VED82`B"B)T87)K:7-T86$N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHR"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U
M<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB
M8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M
M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%
M(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B
M"B)3+TU)344Z;B!KY'ET=/8@961E;&QY='3DY"!P;VYN86AD=7-I:VMU;F]I
M=&$N($IO<R!S96QA:6UE<VD@87-E='5K<V5T("(*(F5S=.1VY'0@97)I;&QI
M<W1E;B!I:VMU;F]I9&5N(&%V86%M:7-E;BP@;FEI;B!S:6YU;B!P:73DY"!M
M=75T=&%A(&[D:73D("(*(F%S971U<W1A('1A:2!E="!V;VD@:^1Y='3DY"!3
M+TU)344M=&]I;6EN=&]J82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(P-`IM<V=I9"`B4TU44"(*;7-G<W1R(")33510(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4S"FUS9VED(")37W5B:F5C="(*
M;7-G<W1R(")/=%]S:6MK;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,V,0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R(")4
M85]L;&5T82!K;W!I;R!K86YS:6]O;B`B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A7W9E(&%S(@IM<V=S
M='(@(E1A7VQL971A(&YI;65L;.0B"@HC.B!S96%R8V@N<&AP.C,P-"!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*;7-G:60@(E-A=F4B"FUS
M9W-T<B`B5&%L;&5T82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C4S-`IM<V=I9"`B4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@
M:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B5&%L;&5T82!L:6ET971I
M961O<W1O="!V:65S=&EE;B!M=6MA;F$@;.1H971E='1Y:F5N('9I97-T:65N
M(&MA;G-I;V]N+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R.`IM<V=I9"`B
M4V%V92!$<F%F="(*;7-G<W1R(")486QL971A(&QU;VYN;W,B"@HC.B!S879E
M:6UA9V4N<&AP.C0R"FUS9VED(")3879E($EM86=E(@IM<V=S='(@(E1A;&QE
M=&$@:W5V82(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,C@*;7-G:60@
M(E-A=F4@26UA9V4@:6X@1V%L;&5R>2(*;7-G<W1R(")T86QL971A(&MU=F$@
M9V%L;&5R:6%A;B(*"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC
M.C$S('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`P"B,Z('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHQ,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,30X"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.0IM<V=I9"`B
M4V%V92!/<'1I;VYS(@IM<V=S='(@(E1A;&QE=&$@87-E='5K<V5T(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"FUS9VED(")3879E
M(%-T871I;VYE<GDB"FUS9W-T<B`B5&%L;&5T82!K:7)J97!O:&IA(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#(X"FUS9VED(")3879E(%]$<F%F="(*;7-G
M<W1R(")486QL971A(%]L=6]N;F]S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")3879E(&%S(@IM<V=S='(@
M(E1A;&QE=&$@;FEM96QLY"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B5&%L
M;&5T82!L=6]N;F]K<V5T('1I;&%T:65D;VQL82!U=7-I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-C$*;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A
M=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\B"FUS
M9W-T<B`B5&%L;&5T82!V87-T86%N;W1T86IA="!A=71O;6%A='1I<V5S=&D@
M;VQE='5S;W-O:71E:VER:F%A;BXB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$R,PIM<V=I9"`B4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O
M;&1E<C\B"FUS9W-T<B`B5&%L;&5T971A86YK;R!H86MU('9I<G1U86%L:7-E
M96X@:V%N<VEO;VX_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM
M<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(E1A;&QE=&$@;.1H=&5V
MY"!V:65S=&DN(@H*(SH@8V]M<&]S92YP:'`Z,3(V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B3'5O;FYO<W9I97-T:6X@
M=&%L;&5T=7,@97#D;VYN:7-T=6DN(%!A;'9E;&EM96X@=FER:&5I;&UO:71U
M<R!O;&DZ("5S(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ
M,2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y.0HC.B!L:6(O
M0FQO8VLO=')E95]F;VQD97)S+G!H<#HU-`IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(DAA:W4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C$@
M=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")396%R8V@@)7,B"FUS9W-T<B`B2&%K=2`E<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C`*;7-G:60@(E-E87)C:"!/<'1I;VYS(@IM
M<V=S='(@(DAA=6X@87-E='5K<V5T(@H*(SH@<V5A<F-H+G!H<#HR-3@*;7-G
M:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(DAA=6X@='5L;VMS970B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$T('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E96XB"FUS9W-T<B`B5F%N
M:&$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*;7-G:60@
M(E-E;&5C="(*;7-G<W1R(")686QI='-E(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C<P"FUS9VED(")396QE8W0@06YO=&AE<B!!8V-O
M=6YT(@IM<V=S='(@(E9A;&ET<V4@<^1H:_9P;W-T:71I;&DB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`B5F%L:71S92!PY&EVY&WDY'+D(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]F:65L9',N:6YC.C$P"FUS9VED(")396QE8W0@82!F:65L9"(*
M;7-G<W1R(")686QI='-E(&ME;G1TY"(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,Q-0IM<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB
M"FUS9W-T<B`B5F%L:71S92!K:7)J97!O:&IA.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U
M<F-E<R!F;W(@861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB
M"FUS9W-T<B`B(@HB5F]I="!V86QI=&$@;W-O:71E:VER:F%T+"!J;VEH:6X@
M;&ESY'3DY&X@:F$@:F]I<W1A(&AA971A86X@;W-O:71T96ET82XB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL
M(@IM<V=S='(@(E9A;&ET<V4@:V%I:VMI(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-O=7)C97-E;&5C="YI;F,Z,S(S"FUS9VED(")396QE8W0@86QL(&9I96QD
M<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R
M(")686QI='-E(&]S;VET=&5I9&5N(&QA86IE;FYU:W-E<W-A(&OD>71E='3D
M=N1T(&ME;G3D="XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?
M<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T
M<B`B5F%L:71S92!SY&AK]G!O<W1I=&EL:2(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(E!O
M:7-T82!V86QI;FYA="(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM
M86=E+FEN8SHY"FUS9VED(")396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T
M:&4@:6UA9V4@:6XN(@IM<V=S='(@(E9A;&ET<V4@9V%L;&5R:6$L(&IO:&]N
M(&MU=F$@=&%L;&5T971A86XN(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D
M<FEV97)?<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T('1H92!M86EL('-E
M<G9E<B!T>7!E(@IM<V=S='(@(E9A;&ET<V4@<&]S=&EP86QV96QI;65N('1Y
M>7!P:2(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P
M.0IM<V=I9"`B4V5L96-T960@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`B5F%L
M:71S92!O<V]I=&5K:7)J870Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<R"FUS9VED(")396YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R(@IM<V=S
M='(@(DSD:&5TY"!A=F%I;B!J=6QK:7-E;&QE(&%V86EN<&%L=F5L:6UE;&QE
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PIM<V=I9"`B4V5N
M9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T<B`B3.1H973D('9I:6UE:7-I
M;6WD="!T:65D;W0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHV-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C8*;7-G:60@
M(E-E;F0@365S<V%G92(*;7-G<W1R("),Y&AE=.0@=FEE<W1I(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,C8*;7-G:60@(E-E;F0@;65S
M<V%G92!W:71H;W5T(&$@4W5B:F5C=#\B"FUS9W-T<B`B3.1H973D('9I97-T
M:2!I;&UA;B!O='-I:VMO83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-CDR"FUS9VED(")396YD(')E860@<F5C96EP="!W:&5N(')E<75E<W1E9"!B
M>2!T:&4@<V5N9&5R/R(*;7-G<W1R("),Y&AE=.0@;'5K=6MU:71T875S(&MU
M;B!LY&AE='3D:N0@;VX@<VETY"!P>7ETY&YY="XB"@HC.B!F;VQD97)S+G!H
M<#HS-S@*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B3.1H971E
M='1Y:F5N('9I97-T:65N(&MA;G-I;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M96YT;6%I;'-E;&5C="YI;F,Z,S@*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(Z
M(@IM<V=S='(@(DSD:&5T971T>6IE;B!V:65S=&EE;B!K86YS:6\Z(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S,@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ-#4*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-3(*;7-G:60@(E-E<G9E<B(*;7-G<W1R(")086QV96QI;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,PIM<V=I9"`B4V5R=F5R(&%N9"!&;VQD97(@
M26YF;W)M871I;VXB"FUS9W-T<B`B4&%L=F5L:6UE;B!J82!K86YS:6]I9&5N
M(&%S971U:W-E="(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHR,PIM<V=I9"`B4V5R=F5R.B(*;7-G<W1R(")086QV96QI;CHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F97)E;F-E
M<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M
M97-S86=E<RXB"FUS9W-T<B`B(@HB5F]I="!M=75T=&%A('9I97-T:6X@:V]P
M:6]I;6ES965N('1A:2!S:6ER=.1M:7-E96X@;&EI='1Y=FGD(&%S971U:W-I
M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3970@
M=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S
M/R(*;7-G<W1R(")!<V5T82!8+5!R:6]R:71Y(&ME;G1TY"!V:65S=&EN(&MI
M<FIO:71U:W-E<W-A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM
M<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G<W1R(")+86YS:6]I9&5N(&IA:V%M
M:6YE;B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@IM<V=I9"`B4VAA
M<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(DUU=71A(&MA;G-I;VED96X@:F%K
M;VIA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R"FUS9VED(")3:&%R
M92!Y;W5R(&UA:6P@9F]L9&5R<R!W:71H(&]T:&5R('5S97)S+B(*;7-G<W1R
M(")6;VET(&%N=&%A('1O:7-I;&QE(&OD>71TY&II;&QE(&]I:V5U:W-I82!K
M86YS:6]I:&ES:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4W"FUS
M9VED("(B"B)3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT(&)E
M('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@(@HB=&]G
M9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N(@IM<V=S='(@(B(*
M(D[D>73D('1A:2!P:6EL;W1A(&]L971U:W-E;F$@=FEE<W1I<W3D('-U=7)E
M="!T96MS=&EL86EN875K<V5T+B!!<V5T=6MS96X@(@HB=F]I(&UU=71T86$@
M:&5L<&]S=&D@;6EL;&]I;B!T86AA;G-A+B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I
M;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\B"FUS9W-T<B`B
M171S:2!T97AT+W!L86EN('1Y>7!P:7-I<W3D('9I97-T96ES=.0@4$=0+71I
M971O:F$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B
M4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V
M:6YG(&$@9')A9G0_(@IM<V=S='(@(E-U;&IE('9I97-T:6YK:7)J;VET=7-I
M:VMU;F$@:W5N('9I97-T:2!O;B!T86QL971E='1U(&QU;VYN;W-K86YS:6]O
M;BXB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I9"`B4VAO=6QD
M('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M
M97-S86=E<R!B>2!D969A=6QT/R(*;7-G<W1R("),:6ETY"!O;&5T=6MS96YA
M(&IU;&MI;F5N(%!'4"UA=F%I;65S:2!LY&AT979I:6X@=FEE<W1E:6AI;BXB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"FUS9VED(")3:&]W
M($%L;"!&;VQD97)S(@IM<V=S='(@(D[D>73D(&MA:6MK:2!K86YS:6]T(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C<*;7-G:60@(E-H
M;W<@06QL($AE861E<G,B"FUS9W-T<B`B3N1Y=.0@:V%I:VMI(&]T<VEK:V]T
M:65D;W0B"@HC.B!M86EL8F]X+G!H<#HS-3`*;7-G:60@(E-H;W<@1&5L971E
M9"(*;7-G<W1R(").Y'ETY"!P;VES=&5T=70B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D($AE861E
M<G,B"FUS9W-T<B`B3N1Y=.0@;W-A(&]T<VEK:V]T:65D;VES=&$B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW,`IM<V=I9"`B4VAO=R!-
M86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T<B`B3N1Y=.0@<&]S=&EL
M:7-T871I961O="(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*
M;7-G:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B
M3N1Y=.0@=F%I;B!T:6QA='5T(&MA;G-I;W0B"@HC.B!F;VQD97)S+G!H<#HR
M.#0*;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D(@IM<V=S='(@(D[D>73D('1I
M;&%A;6%T=&]M870B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3DV"FUS
M9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG(&]F(&%T=&%C
M:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(D[D>73D(&EK;VYI+"!J
M;W,@;&EI='1E96X@=F]I('!O:7-T86$@=FEE<W1I<W3D+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.3$*;7-G:60@(E-H;W<@;&5G96YD(&EN('1H
M92!M86EL8F]X('9I97<_(@IM<V=S='(@(D[D>73D('9I97-T:6X@=&EL;VIE
M;B!S96QI=&4@<&]S=&EK86YS:6]NY&MY;>1S<^0N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R.0IM<V=I9"`B4VAO=R!P<F5V:65W<R!F;W(@=6YR
M96%D(&UE<W-A9V5S(&]N;'D_(@IM<V=S='(@(DOD>73D(&5S:6MA='-E;'5A
M('9A:6X@;'5K96UA='1O;6EI;B!V:65S=&5I:&EN+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,S<*;7-G:60@(E-H;W<@<')E=FEE=W,@:6X@=&]O
M;'1I<',_(@IM<V=S='(@(D[D>73D(&5S:6MA='-E;'4@=&]O;'1I<',Z96ES
M<^0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V-@IM<V=I9"`B4VAO
M=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R
M(").Y'ETY"!<(DAA92!V:65S=&ET7"(M:6MO;FD@;75I9&5N(&EK;VYI96X@
M:F]U:V]S<V$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDX"FUS
M9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B3N1Y=.0@:W5V870B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-30*;7-G:60@(E-H;W<@
M=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R(").Y'ET
MY"!<(E-U;V1A=&EN7"(M:6MO;FD@;75I9&5N(&EK;VYI96X@:F]U:V]S<V$N
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,Q"FUS9VED(")3:&]W('1O
M=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(D[D>73D
M('9I97-T:65N(&QU:W5MY.1RY"!K86YS:6]S<V$N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8U-`IM<V=I9"`B4VAO=VXB"FUS9W-T<B`B3N1Y=&5T
M='DB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C0R"FUS9VED(")3:5]Z92(*;7-G<W1R(")+;U]K;R(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*;7-G:60@(E-I9VYE9"(*;7-G<W1R
M(")!;&QE:VER:F]I=&5T='4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")+;VMO(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM<V=I
M9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@(DKD<FIE<W3D('1U;&]A:F%N
M(&UU:V%A;B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,38*;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R(")*Y')J97-T
MY"!PY&EVY&WDY'+D;B!M=6MA86XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C(V"FUS9VED(")3;W)T(&)Y($9R;VT@061D
M<F5S<R(*;7-G<W1R(")*Y')J97-TY"!LY&AE='3D:N1N(&UU:V%A;B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*;7-G
M:60@(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(DKD<FIE<W3D('9I
M97-T:6X@:V]O;B!M=6MA86XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C,V"FUS9VED(")3;W)T(&)Y(%-U8FIE8W0B"FUS
M9W-T<B`B2N1R:F5S=.0@;W1S:6MO;B!M=6MA86XB"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"FUS9VED(")3;W)T(&)Y
M(%1H<F5A9"(*;7-G<W1R(")*Y')J97-TY"!K97-K=7-T96QU<^1I:V5E;B!M
M=6MA86XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C(Q"FUS9VED(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`B2N1R
M:F5S=.0@=F%S=&%A;F]T=&%J86X@;75K86%N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-P86US96QE8W0N:6YC.C(S"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS
M9W-T<B`B4F]S:V%P;W-T:6MA;G-I;SHB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS-#0*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*
M;7-G<W1R(")%<FEK;VES;65R:VET(@H*(SH@<V5A<F-H+G!H<#HQ,S<*;7-G
M:60@(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;FYO="!B92!E9&ET960N
M(@IM<V=S='(@(D5R:71Y:7-IY"!V:7)T=6%A;&EK86YS:6]I=&$@96D@=F]I
M(&UU;VMA=&$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,S0Q"FUS9VED(")3<&5L;"!#:&5C:R(*;7-G<W1R(")487)K:7-T82!O:6ME
M:6YK:7)J;VET=7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-#8*;7-G:60@(E-P96QL($-H96-K97(B"FUS9W-T<B`B3VEK96EN:VER
M:F]I='5S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU-@IM<V=I9"`B4W!E
M;&P@8VAE8VL@8V]M<&QE=&4B"FUS9W-T<B`B3VEK96EN:VER:F]I='5S(&]N
M('1A<FMI<W1E='1U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W,0IM
M<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C
M:&5C:VEN9RXB"FUS9W-T<B`B36]N=&%K;R!K:7)J;VET=7-V:7)H971TY"!N
MY'ET973DY&X@>6AD96QTY"!S:79U;'1A/R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,#<@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4P.0HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C0R(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-#0*;7-G:60@(E-T87)T(@IM<V=S='(@(D%L:V%A(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.CD@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S`Y"FUS9VED(")3=&%T:6]N97)Y(@IM
M<V=S='(@(DMI<FIE<&]H:F$B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@;F%M93HB"FUS9W-T<B`B
M2VER:F5P;VAJ86X@;FEM:3HB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,C@*;7-G:60@(E-T871I;VYE<GD@='EP93HB"FUS9W-T<B`B
M2VER:F5P;VAJ86X@='EY<'!I(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C,S"FUS9VED(")3=&%T:6]N97)Y.B(*;7-G<W1R(")+:7)J
M97!O:&IA.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#,*;7-G
M:60@(E-T871U<R(*;7-G<W1R(")4:6QA(@H*(SH@;&EB+TU)344O0V]N=&5N
M=',N<&AP.C(S.0IM<V=I9"`B4W1R:7`@071T86-H;65N="(*;7-G<W1R(")0
M;VES=&$@;&EI=&5T:65D;W-T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,C$*;7-G:60@(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S='(@(E!O:7-T
M82!R:79I;G9A:6AD;W0N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHS-PIM<V=I9"`B4W5B7VIE8W0B"FUS9W-T<B`B3W1S
M7VEK:V\B"@HC.B!M97-S86=E+G!H<#HR-S4@=&AR96%D+G!H<#HQ-34@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A<F-H
M+G!H<#HV,#4*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B3W1S:6MK;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#D*;7-G:60@(E-U8FIE8W0@1FEE
M;&0B"FUS9W-T<B`B3W1S:6MK;VME;G1TY"(*"B,Z('-E87)C:"YP:'`Z,S`V
M('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,`HC.B!T96UP;&%T
M97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P
M87-S<&AR87-E+FEN8SHS,0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(DSD:&5T
MY"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Q"FUS9VED
M(")3=6)S8W)I8F4@=&\@1F]L9&5R*',I(@IM<V=S='(@(E1I;&%A(&MA;G-I
M;W0B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X-2!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HS.3,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z.#<*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B3VYN:7-T=6DB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U
M9V=E<W1I;VYS(@IM<V=S='(@(D5H9&]T=6MS970B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C4Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-C$*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B66AT965N=F5T;R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Y-2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS.3@*;7-G:60@(E-W:71C:"!#;VUP;W-I=&EO
M;B!-971H;V0B"FUS9W-T<B`B5F%I:&1A(&MI<FIO:71U<W1I;&%A(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,SDY"FUS9VED(")3=VET
M8V@@=&\@2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R(")686EH9&$@2%1-3"UT
M:6QA86XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.3D*
M;7-G:60@(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S
M='(@(E9A:6AD82!T96MS=&ET:6QA86XB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,30*;7-G:60@(E1E7WAT(@IM<V=S='(@(E1E7VMS
M=&DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C<P"FUS9VED(")4
M96YT871I=F4Z("(*;7-G<W1R(")!;'5S=&%V87-T:3H@(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4X-@IM<V=I9"`B5&5N=&%T:79E;'D@06-C
M97!T(')E<75E<W0B"FUS9W-T<B`B2'EVY&MS>2!P>7EN=/8@86QU<W1A=F%S
M=&DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4T"FUS9VED(")4
M96YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R(")!;'5S=&%V87-T:2!H>7;D
M:W-Y='1Y(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N
M="YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5R;7,@;V8@4V5R=FEC
M92!F:6QE(&YO="!S<&5C:69I960@:6X@8V]N9BYP:'`B"FUS9W-T<B`B5&5R
M;7,@;V8@4V5R=FEC92`M=&EE9&]S=&]A(&5I(&]L92!MY.1R:71E;'1Y(&-O
M;F8N<&AP('1I961O<W1O<W-A(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C,P"FUS9VED(")497AT(@IM<V=S='(@(E1E:W-T:2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#,*;7-G:60@(E1H92!&<F]M.B!C
M;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#HB"FUS9W-T
M<B`B5FEE<W1I;B!,Y&AE='3D:N0Z(')I=FD@;VX@;&EN:VMI.B`B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C4R-0IM<V=I9"`B(@HB5&AE($E-05`@<V5R
M=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A
M=&EO;B!M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DE-05`M<&%L=F5L
M:6X@96D@;N1Y=.0@='5K979A;B!V86QI='1U82!A=71E;G1I:V]I;G1I=&%P
M86$N($]T82!Y:'1E>71TY"`B"B)JY')J97-T96QMY"!Y;&SD<&ET;V]N+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@
M(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R(")-86-I;G1O
M<V@@=&EE9&]S=&]N(')E<W5R<W-I;W-I;R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S
M+B(*;7-G<W1R(")-86-I;G1O<V@@=&EE9&]S=&]N(')E<W5R<W-I;W-I;R!V
M;VD@;&%D871A("5S+B`B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(E/D:&OV<&]S=&ET:6QI(%PB)7-<(B!O;B!P
M;VES=&5T='4N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`B4^1H:_9P;W-T:71I;&D@7"(E<UPB(&]N('1A;&QE=&5T
M='4N(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM
M96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(DQI:71E=&EE9&]S=&]A(&5I
M(&SV>71Y;GET(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q"FUS
M9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(D5P
MY&ME;'!O(&MA;&5N=&5R:71I971O(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P
M<&QE9&]U8FQE+G!H<#HT,@IM<V=I9"`B5&AE(&-O;G1E;G1S(&]F('1H92!-
M86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N(@IM<V=S='(@(DUA8VEN=&]S:"!T
M:65D;W-T;VX@<VESY&QT]B!O;B!A;&QA+B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I
M;&P@8F4@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(DYY:WEI<V5T(&MA
M;G-I;W0@7"(E<UPB(&YI;65TY.1N('5U9&5L;&5E;B!<(B5S7"(Z:W-I+B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,#<*;7-G:60@(B(*(E1H92!C
M=7)R96YT(&QI<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD
M97(@8V]U;&0@;F]T(&)E(')E=')I979E9"(*;7-G<W1R("(B"B)%:2!V;VET
M=2!H86ME82!L:7-T86$@;FEI<W3D(&OD>71TY&II<W3D+"!J;VEL;&$@;VX@
M;VEK975S('3D:.1N(&MA;G-I;V]N+B(*"B,Z(&-O;7!O<V4N<&AP.C$R-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B965N('-A=F5D
M('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R("),=6]N;F]S(&]N('1A
M;&QE=&5T='4@:V%N<VEO;VX@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ-#`*;7-G:60@(E1H92!E=F5N="!W87,@861D960@=&\@
M>6]U<B!C86QE;F1A<BXB"FUS9W-T<B`B5&%P86AT=6UA(&QI<^1T=&EI;B!K
M86QE;G1E<FEI<VDN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN
M8SHY"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L9"!<(B5S7"(@8V%N
M)W0@8F4@97AP86YD960N(@IM<V=S='(@(DME;G1TY.0@7"(E<UPB(&5I('9O
M:2!L86%J96YT86$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB(&%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(DMA;G-I;R!<(B5S7"(@;VX@:F\@;VQE;6%S<V$B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HQ-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN
M(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O8FQE;7,N(%!L96%S92!S
M964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB2V%N
M<VEO;B!N:6UE<W/D(%PB)7-<(B!O;B!K:65L;&5T='EJY"!K:7)J86EM:6$N
M($[D;>0@:VER:F%I;65T('9O:79A="`B"B)A:6AE=71T86$@;VYG96QM:6$N
M($]T82!Y:'1E>71TY"!JY')J97-T96QMY&X@>6QLY'!I=.1JY.1N+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C,Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9F]L9&5R(%PB)7-<(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U
M8G-C<FEB960@=&\@:70N(@IM<V=S='(@(DMA;G-I;R!<(B5S7"(@;VX@;'5O
M='4L(&UU='1A(&5T(&]L92!V:65LY"!T:6QA;FYU="!S:73D+B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L
M9&5R(%PB)7-<(B!W87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N<W5B
M<V-R:6)E9"!F<F]M(&ET+B(*;7-G<W1R(")+86YS:6\@7"(E<UPB(&]N('!O
M:7-T971T=2!M=71T82!S96X@=&EL875S=&$@96D@;&]P971E='1U+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9F]L9&5R(%PB)7-<(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B2V%N<VEO=&$@7"(E<UPB(&5I('9O
M:71U(&QU;V1A+B!086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M;VQD97(@7"(E<UPB('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9"(*;7-G<W1R(")+86YS:6]T82!<(B5S7"(@96D@<&]I
M<W1E='1U+B!086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,S$U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B
M2V%N<VEO(%PB)7-<(B!O;B!L=6]T=2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")+86YS:6\@7"(E<UPB
M(&]N('!O:7-T971T=2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B2V%N<VEO(%PB)7-<
M(B!O;B!N:6UE='1Y(%PB)7-<(CIK<VDN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W1N968N<&AP.CDT"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@
M871T86-H960@=&\@=&AI<R!P87)T.B(*;7-G<W1R(")4Y&CD;B!O<VEO;VX@
M;VX@;&EI=&5T='D@;&EI=&5T:65D;W-T;W0Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<&]P=7`N:G,Z-3D*;7-G:60@(B(*(E1H92!I;6%G92!S879E
M('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S
M970@>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I;F1O=W,_(@IM
M<V=S='(@(B(*(E9I97-T:6YK:7)J;VET=7-I:VMU;F%A(&5I('9O:71U(&%V
M871A+B!/;&5T:V\@;6%H9&]L;&ES97-T:2!K:65L=.1N>70@(@HB<V5L86EN
M=&%S:2!A=6MA:7-E;6%S=&$@<&]N;F%H9'5S:6MK=6YO:71A/R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G:60@(B(*(E1H92!I;6%G
M97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES('!R
M97-E;G0@:6X@>6]U<B`B"B)A9&1R97-S8F]O:RXB"FUS9W-T<B`B2W5V870@
M;N1Y=&5TY.1N(&MO<VMA('9I97-T:6X@;.1H971TY&KD;B!O<V]I=&4@;VX@
M;W-O:71E:VER:F%S<V%S:2XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(E!O<W1I<&%L=F5L
M:6UE;'1A('1U;&D@=FER:&5V:65S=&DZ(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-3$*;7-G:60@(E1H92!M86EL('-E<G9E<B!G
M96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z
M(@IM<V=S='(@(E!O<W1I<&%L=F5L:6UE;'1A('1U;&D@=&EE9&]T979I97-T
M:3HB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B
M5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A
M9V4Z(@IM<V=S='(@(E!O<W1I<&%L=F5L:6UE;'1A('1U;&D@=FEE<W1I.B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B4&]S
M=&EK86YS:6\@)7,@;VX@:F\@='EH:N0N(@H*(SH@;&EB+T9E=&-H;6%I;"YP
M:'`Z,C0W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(%PB)7-<
M(B!F<F]M(%PB)7-<(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L
M:6UI="XB"FUS9W-T<B`B(@HB5FEE<W1I(%PB)7-<(B!LY&AE='3D:N1NY"!<
M(B5S7"(@*"5D('1A=G5A*2!Y;&ET=.3D(&AA971T879A;B!V:65S=&EN("(*
M(G-U=7)I;6UA;B!S86QL:71U;B!K;V]N+B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,3`S"FUS9VED(")4:&4@;65S<V%G92!B96EN
M9R!C;VUP;W-E9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N(@IM<V=S='(@
M(DMI<FIO:71T86UA<VD@=FEE<W1I(&]N('-U;&IE='1U+B`@4&]I<W1U=&%A
M;BXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$R-@IM<V=I
M9"`B5&AE(&UE<W-A9V4@9&]E<R!N;W0@:&%V92!A(%-U8FIE8W0@96YT97)E
M9"XB"FUS9W-T<B`B5FEE<W1I<W/D(&5I(&]L92!O='-I:VMO82XB"@HC.B!M
M97-S86=E+G!H<#HQ-#@*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(E9I97-T:2!O;B!P;VES=&5T='4N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDW"FUS9VED(")4:&4@;65S<V%G92!H
M87,@8F5E;B!V97)I9FEE9"XB"FUS9W-T<B`B5FEE<W1I(&]N('1A<FMA<W1E
M='1U+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D
M+B!396YD97(Z("5S+B(*;7-G<W1R(")6:65S=&D@;VX@=&%R:V%S=&5T='4N
M($SD:&5T=.1JY#H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,3<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!R87<@=&5X="!O9B!T:&4@
M4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B3'5K
M96%K<V5S:2!J=6QK:7-E;B!01U`M879A:6UE;B!T96MS=&EN(')A86MA;75O
M9&]S<V$@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C8P"FUS
M9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE
M($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B5F%L:71T=6$@=&EE9&]S
M=&]A(&5I(&]L;'5T($U3+51.148@;&EI=&5T:65D;W-T;W-S82XB"@HC.B!L
M:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`IM<V=I9"`B5&AE(')E<75E<W1E
M9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H;65N="XB
M"FUS9W-T<B`B5F%L:71T=6$@=&EE9&]S=&]A(&5I(&]L;'5T(%II<"UT:65D
M;W-T;W-S82XB"@HC.B!M97-S86=E+G!H<#HU-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S
M=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("(*(F9R
M;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S
M92!C;&EC:R`E<R!T;R!S96YD('1H92`B"B)N;W1I9FEC871I;VX@;65S<V%G
M92XB"FUS9W-T<B`B(@HB5.1MY&X@=FEE<W1I;B!LY&AE='3D:N0@<'EY=.3D
M($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("A-1$XI("(*(FEL
M;6]I='5S=FEE<W1IY"!K=6X@;VQE="!L=6ME;G5T('3D;>1N('9I97-T:6XN
M($YA<'-A=71A("5S(&SD:&5T=.3D:W-E<VD@(@HB=.1MY&X@:6QM;VET=7-V
M:65S=&EN+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8W"FUS
M9VED(")4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M
M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B4&%L=F5L:6X@96D@=F]I
M;G5T(&QU;V1A('!I:VMU:W5V86$@=.1S=.0@:W5V87-T82XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.CDP"FUS9VED(")4:&4@<VEG;F%T
M=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"XB"FUS9W-T<B`B06QL96MI<FIO
M:71U<W1A(&5I('9O:71U(&MO<G9A=&$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YJ<SHX.`IM<V=I9"`B5&AE('-I9VYA='5R92!W87,@<W5C
M8V5S<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R(")!;&QE:VER:F]I='5S(&]N
M(&MO<G9A='1U('5U9&5L;&$N(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G
M:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B5F%L:71T=6$@=&EE9&]S=&]A(&5I(&]L92!O;&5M87-S82XB"@HC.B!S
M=&%T:6]N97)Y+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A
M=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@861D960N(@IM<V=S='(@(DMI<FIE
M<&]H:F$@7"(E<UPB(&]N(&QI<^1T='DN(@H*(SH@<W1A=&EO;F5R>2YP:'`Z
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DMI<FIE<&]H:F$@7"(E<UPB
M(&]N('!O:7-T971T=2XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@
M=7!D871E9"XB"FUS9W-T<B`B2VER:F5P;VAJ82!<(B5S7"(@;VX@<.1I=FET
M971T>2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<P"FUS9VED
M(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*
M;7-G<W1R(")496ATY';D(&]N(&QI<^1T='D@=&5H=.1VY&QI<W1A87-I+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDU"FUS9VED(")4:&4@
M=&5X="!O9B!T:&4@;65S<V%G92(*;7-G<W1R(")6:65S=&EN('1E:W-T:2(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W
M960@)7,N(@IM<V=S='(@(E9O:70@:V%T<V]A('9I97-T:6X@=&5K<W1I;B`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX,`IM<V=I9"`B
M5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`B4&%L
M875T971U;B!V:65S=&EN('1E:W-T:2XB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O
M9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G
M<W1R(")6;VET(&MA='-O82!P86QA=71E='5N('9I97-T:6X@=&5K<W1I;B`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`IM
M<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92(*;7-G<W1R("),
MY&AE=&5T>6X@=FEE<W1I="!T96MS=&DB"@HC.B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM
M<V=S='(@(E9O:70@:V%T<V]A(&SD:&5T971Y;B!V:65S=&EN('1E:W-T:6X@
M)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-0IM<V=I9"`B
M5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U
M;&QY('-T;W)E9"XB"FUS9W-T<B`B2^1Y='3D:N1N('9A<&%A+W9A<F%T='4@
M=&EE=&]J96X@=&%L;&5T=7,@;VYN:7-T=6DN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM<V=I9"`B5&AE<F4@87)E(&YO(&%L
M=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M(@IM<V=S='(@(D5I(&]L92!V86EH=&]E:'1O:7-I82!O<VEA+"!J;W1K82!V
M;VED86%N(&[D>71TY.0@=FEE<W1I96X@>6AT97ED97-SY"XB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS"FUS9VED(")4:&5R
M92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*;7-G<W1R(")4
MY'-SY"!K86YS:6]S<V$@96D@;VQE('9I97-T96KD+B(*"B,Z('1H<F5A9"YP
M:'`Z,3$P"FUS9VED(")4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D5I(&]L92!T96MS=&GD+"!J;VMA
M('9O:61A86X@;N1Y='3DY"!V:65S=&EE;B!Y:'1E>61E<W/D+B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HV.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V
M97(@<V%I9#H@)7,B"FUS9W-T<B`B2V%N<VEO;B!T>6AJ96YTY&UI<V5S<^0@
M;VQI(&]N9V5L;6EA+B!086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI.B`E
M<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G97,@9G)O
M;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E
M<B!S86ED(@IM<V=S='(@(B(*(E1A<&%H='5I('9I<FAE(&MO<&EO:61E<W-A
M('9I97-T96KD(&MA;G-I;W-T82!<(B5S7"(@:V%N<VEO;VX@7"(E<UPB+B`B
M"B)086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C(R-B!L:6(O365S<V%G92YP:'`Z,C0T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE
M('-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E1A<&%H='5I('9I<FAE('!O:7-T
M971T865S<V$@=FEE<W1E:N0@:V%N<VEO<W1A(%PB)7-<(BX@4&%L=F5L:6UE
M;B`B"B)V:7)H96EL;6]I='5S(&]L:2(*"B,Z(&QI8B]-97-S86=E+G!H<#HS
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES
M(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E1A<&%H
M='5I('9I<FAE('!O:7-T971T865S<V$@=FEE<W1E:N0@:V%N<VEO<W-A(%PB
M)7-<(BX@4&%L=F5L:6UE;B`B"B)V:7)H96EL;6]I='5S(&]L:2(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("(B"B)487!A:'1U:2!V:7)H
M92!P;VES=&5T=&%E<W-A('9I97-T96KD+B!086QV96QI;65N('9I<FAE:6QM
M;VET=7,@;VQI.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(E1A<&%H='5I('9I<FAE
M('!O:7-T971T865S<V$@=&%P86AT=6UA83H@)7,B"@HC.B!L:6(O34E-12]6
M:65W97(O96YR:6-H960N<&AP.C,W(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP
M:'`Z-3(*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E1A<&%H='5I('9I<FAE(&[D>71E
M='3D97-SY"!V:65S=&EN('3D=.0@;W-I;W1A(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB
M5&%P86AT=6D@:F]K:6X@=FER:&4@87-E=&5T=&%E<W-A(&UE<FMK:6QI<'!U
M:F$@:V%N<VEO;B!<(B5S7"(@=FEE<W1E:6AI;BX@(@HB4&%L=F5L:6UE;B!V
M:7)H96EL;6]I='5S(&]L:2(*"B,Z(&9O;&1E<G,N<&AP.C$T.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S
M+B(*;7-G<W1R(")487!A:'1U:2!J;VMI;B!V:7)H92!T=6]T865S<V$@;.1H
M=&5E<W3D("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")487!A:'1U:2!V:7)H92!T
M=6]T865S<V$@=&%P86AT=6UA83H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS9W-T<B`B5&%P
M86AT=6D@=FER:&4@='5O=&%E<W-A('3D=.0@=&5H=.1VY.0Z("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`B2^1Y='3D:N1N('9A
M<&%A+W9A<F%T='4@=&EE=&]J96X@='5O;FYI<W-A('1A<&%H='5I('9I<FAE
M.B`E<RXB"@HC.B!L:6(O365S<V%G92YP:'`Z,3`U"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@
M9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E
M<G9E<B!S86ED(@IM<V=S='(@(B(*(E1A<&%H='5I(&IO:VEN('9I<FAE('-I
M:7)E='3D97-SY"!V:65S=&5JY"!K86YS:6]S=&$@7"(E<UPB(&MA;G-I;V]N
M(%PB)7-<(BX@(@HB4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L:2(*"B,Z
M(&-O;7!O<V4N<&AP.C$R.#`*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S
M879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N(@IM<V=S='(@(E1A<&%H
M='5I(&IO:VEN('9I<FAE(&QU;VYN;W-V:65S=&GD('1A;&QE='1A97-S82XB
M"@HC.B!C;VUP;W-E+G!H<#HQ,#,Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS
M9W-T<B`B5&%P86AT=6D@=FER:&4@;.1H971E='3D97-SY"!V:65S=&GD<VDZ
M("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&5V96YT.B`E<RXB"FUS9W-T<B`B5&%P86AT=6D@=FER:&4@<.1I=FET971T
MY&5S<^0@=&%P86AT=6UA83H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3`P"FUS9VED(")4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S
M(&5M8F5D9&5D(&EN(&ET+B(*;7-G<W1R(")4Y'-SY"!(5$U,+79I97-T:7-S
MY"!O;B!K=79I82!U<&]T971T=6EN82XB"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z.3,*;7-G:60@(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I
M;6%G97,@96UB961D960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L
M:6ME("(*(G1H:7,Z("(*;7-G<W1R("(B"B)4Y'-SY"!(5$U,+79I97-T:7-S
MY"!O;B!K=79I82!U<&]T971T=6EN82X@17-T971E='ET(&MU=F%T(&[D>71T
MY';D="`B"B)TY&WD;FQA:7-I;F$Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C$V-0IM<V=I9"`B5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T
M86-H960@=&\@=&AE(&UE<W-A9V4N(@IM<V=S='(@(E3D;>0@:G5L:VEN96X@
M4$=0+6%V86EN(&]L:2!L:6ET971T>2!V:65S=&EI;BXB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3`U(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ,3D*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T-"!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,34X"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-S0@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q-0IM<V=I9"`B
M5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B5.1MY"!T
M;VEM:6YT;R!E:2!O;&4@='5E='1U+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ.#`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0R,`IM<V=I
M9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T
M<B`B5.1MY"!T;VEM:6YT;R!E:2!O;&4@=FEE;.0@=&]T975T971T=2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$T"FUS9VED(")4
M:&ES(&UA>2!T86ME('-O;64@=&EM92X@07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&-O;G1I;G5E/R(*;7-G<W1R(")4Y&WD('9O:2!K97-TY.0@:F]N:VEN
M(&%I:V%A+B!/;&5T:V\@86EV86X@=F%R;6$_(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%P<&QE9&]U8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E(&-O
M;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N(@IM<V=S='(@(E3D;>0@=FEE<W1I
M('-I<^1L=.3D($UA8VEN=&]S:"!T:65D;W-T;VXN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HT,34*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C
M;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY
M('-I9VYE9"!V:6$@4R\B"B)-24U%+B(*;7-G<W1R("(B"B)4Y'-SY"!V:65S
M=&ES<^0@;VX@;&EI=&5T:65D;W-T;RP@:F]K82!O;B!D:6=I=&%A;&ES97-T
M:2!A;&QE<FMI<FIO:71E='1U(%,O(@HB34E-13IL;.0N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HT,3D*;7-G:60@(E1H:7,@;65S<V%G92!C
M;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D
M('9I82!3+TU)344N(@IM<V=S='(@(E3D<W/D('9I97-T:7-SY"!O;B!L:6ET
M971I961O<W1O+"!J;VMA(&]N('-A;&%T='4@:^1Y='3D96X@4R]-24U%.N0N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B
M"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@
M:6YF;W)M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G
M92!I<R!U;FMN;W=N+B(*;7-G<W1R("(B"B)4Y&WD('9I97-T:2!S:7/D;'3D
MY"!V:65S=&EN('!E<FEL;&5M96YO;VX@;&EI='1Y=N3D('1I971O82P@;75T
M=&$@=FEE<W1I;B`B"B)M=6]T;R!O;B!T=6YT96UA=&]N+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,Q.0IM<V=I9"`B(@HB5&AI<R!M97-S86=E
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@
M;65S<V%G92X@17)R;W(Z("(*;7-G<W1R(")4Y&WD('9I97-T:2!E:2!V86EK
M=71A(%!'4"US86QA='5L=&$@=FEE<W1I;'3D+B!6:7)H96EL;6]I='5S.B`B
M"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,SD@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,S4T"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C
M8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(B(*(E3D;>0@=FEE
M<W1I(&5I(&[D>73D(&]L979A;B!O:6ME87-S82!01U`M;75O9&]S<V$@*&UU
M;W1O(&]N(&WDY')I=&5L='D@4D9#("(*(C(P,34@9&]K=6UE;G1I<W-A*2XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI
M<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C
M="!3+TU)344@9F]R;6%T+B(*;7-G<W1R(")4Y&WD('9I97-T:2!E:2!NY'ET
MY"!O;&5V86X@;VEK96%S<V$@4R]-24U%+6UU;V1O<W-A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HT,C`*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@
M<VEG;F5D('9I82!01U`N(@IM<V=S='(@(E3D;>0@;VX@4$=0.FQLY"!D:6=I
M=&%A;&ES97-T:2!A;&QE:VER:F]I=&5T='4@=FEE<W1I+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,30S"FUS9VED(")4:&ES(&UE<W-A9V4@
M:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-24U%+B(*;7-G<W1R
M(")4Y&WD(&]N(%,O34E-13IL;.0@9&EG:71A86QI<V5S=&D@86QL96MI<FIO
M:71E='1U('9I97-T:2XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S.`IM<V=I9"`B5&AI
M<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G
M<W1R(")4Y&WD(%,O34E-13IL;.0@<V%L871T=2!V:65S=&DN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`P(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(Y,`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E
M9"!W:71H(%!'4"XB"FUS9W-T<B`B5.1MY"!01U`Z;&SD('-A;&%T='4@=FEE
M<W1I+B(*"B,Z(&UE<W-A9V4N<&AP.C(Q,`IM<V=I9"`B5&AI<R!M97-S86=E
M('1O(@IM<V=S='(@(E3D;>0@=FEE<W1I(&MA;G-I;V]N(@H*(SH@86-L+G!H
M<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N(@IM<V=S='(@(E3D;>0@<&%L=F5L:6X@96D@='5E(&MA
M;G-I;VED96X@:F%K86UI<W1A+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3`Y"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N(@IM<V=S='(@(E3D;>1N(&EK
M:W5N86X@=F]I(&%U:V%I<W1A('9A:6X@=FEE<W1I;FMI<FIO:71U<VEK:W5N
M87-T82(*"B,Z('1H<F5A9"YP:'`Z,34W"FUS9VED(")4:')E860@1&ES<&QA
M>2(*;7-G<W1R(")+97-K=7-T96QU<^1I96[D:WEMY"(*"B,Z('1H<F5A9"YP
M:'`Z-S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ,0IM<V=I9"`B5&AR96%D
M(%9I97<B"FUS9W-T<B`B2V5S:W5S=&5L=7/D:6ME:71TY&EN(@H*(SH@;6%I
M;&)O>"YP:'`Z-C`Q(&UE<W-A9V4N<&AP.C(W,2!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C(R"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C$Y('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S
M92YI;F,Z,3`*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C8Q
M(&QI8B]396%R8V@N<&AP.C4Y,PIM<V=I9"`B5&\B"FUS9W-T<B`B5F%S=&%A
M;F]T=&%J82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#@*;7-G:60@
M(E1O($%D9')E<W,B"FUS9W-T<B`B5F%S=&%A;F]T=&%J86X@;W-O:71E(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(V"FUS9VED
M("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE("(*(F-L:6-K
M:6YG+B(*;7-G<W1R("(B"B)6;VED86MS97-I('9A;&ET82!U<V5A;7!I82!V
M86EH=&]E:'1O:F$L('!I9.0@<&]H:F%S<V$@0V]N=')O;"]/<'1I;VX@+2(*
M(F[D<'#D:6YTY"!K=6X@;F%P<V%U=&%T(&AI:7)E;B!P86EN:6ME='1A+B(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@
M82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I
M;VX@;V8@4$A0(#4N,2XP(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B(@HB2^1Y
M='3DY&MS97-I(%1,4RUY:'1E>71TY"!S:6YU;&QA('!I=.3D(&]L;&$@:^1Y
M=/9S<^0@4$A0('9E<G-I;R`U+C$N,"!T86D@(@HB<VETY"!U=61E;7!I+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Y,0IM<V=I9"`B
M5&]T86P@071T86-H;65N=',@4VEZ93HB"FUS9W-T<B`B3&EI=&5T:65D;W-T
M;VIE;B!K;VMO('EH=&5E;G/D.B(*"B,Z(&9O;&1E<G,N<&AP.C,V.0IM<V=I
M9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(E)O<VMA:V]R:6MA;G-I;R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C,*;7-G:60@(E1R
M87-H(&9O;&1E<CHB"FUS9W-T<B`B4F]S:V%K;W)I:V%N<VEO.B(*"B,Z(&QI
M8B]1=6]T82]C;W5R:65R+G!H<#HU,R!L:6(O475O=&$O8V]M;6%N9"YP:'`Z
M-S$@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X"B,Z(&QI8B]1=6]T82]C>7)U
M<RYP:'`Z-C0@;&EB+U%U;W1A+V-Y<G5S9W%R+G!H<#HT-"!L:6(O475O=&$O
M8WER=7-G<7(N<&AP.C<W"B,Z(&QI8B]1=6]T82]M9&%E;6]N+G!H<#HT."!L
M:6(O475O=&$O;65R8W5R>3,R+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(')E
M=')I979E('%U;W1A(@IM<V=S='(@(E!O<W1I:VEI;G1I]G1I971O:F$@96D@
M=F]I='4@:&%K96$N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N
M86YS=V5R960B"FUS9W-T<B`B5F%S=&%A;6%T;VXB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S
M(@IM<V=S='(@(E9A<W1A86UA='1O;6%T('9I97-T:70B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-"!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B56YD96QE=&4B"FUS9W-T<B`B
M4&%L875T82(*"B,Z(&UA:6QB;W@N<&AP.C4W.2!M86EL8F]X+G!H<#HU.3<@
M;&EB+TU)344O2&5A9&5R<RYP:'`Z,C`T"FUS9VED(")5;F1I<V-L;W-E9"!2
M96-I<&EE;G1S(@IM<V=S='(@(E-A;&%T=6EL;&4@=F%S=&%A;F]T=&%J:6QL
M92(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-34V"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($%55$A%3E1)0T%412!C;VUM
M86YD+B(*;7-G<W1R(")086QV96QI;B!LY&AE='1I(&]D;W1T86UA='1O;6%N
M('9A<W1A=6MS96X@05542$5.5$E#051%(&MO;65N=&]O;BXB"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C4R,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;R!$:6=E<W0M340U(')E<W!O;G-E+B(*;7-G<W1R
M(")086QV96QI;B!LY&AE='1I(&]D;W1T86UA='1O;6%N($1I9V5S="U-1#4@
M=F%S=&%U:W-E;BXB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4S-@IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;R!,3T=)3B!C
M;VUM86YD+B(*;7-G<W1R(")086QV96QI;B!LY&AE='1I(&]D;W1T86UA='1O
M;6%N('9A<W1A=6MS96X@3$]'24X@:V]M96YT;V]N+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YH
M86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R(")+;VUP;VYE
M;G1T:71Y>7!I;&QE(&5I(&]L92!KY'-I='1E;&EJY.0Z("5S(@H*(SH@;6%I
M;&)O>"YP:'`Z-34W"FUS9VED(")5;FMN;W=N($1A=&4B"FUS9W-T<B`B5'5N
M=&5M871O;B!PY&EVY&WDY'+D(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O;G-E
M(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T
M<B`B5'5N=&5M871O;B!V87-T875S($E-05`M<&%L=F5L:6UE;'1A+B!086QV
M96QI;65N(&EL;6]I='5S(&]L:3H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C(V"FUS9VED(")5;FMN;W=N($UE971I;F<B"FUS9W-T<B`B
M5'5N=&5M871O;B!T87!A86UI;F5N(@H*(SH@;6%I;&)O>"YP:'`Z-C$S"FUS
M9VED(")5;FMN;W=N(%)E8VEP:65N="(*;7-G<W1R(")4=6YT96UA=&]N('9A
M<W1A86YO='1A:F$B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P
M:')A<V4B"FUS9W-T<B`B4&]I<W1A('-A;&%S86YA=&5K<W1I(@H*(SH@9F5T
M8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@(DYI
M;65T]FXB"@HC.B!M86EL8F]X+G!H<#HW,#(@;65S<V%G92YP:'`Z-3`R('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,R"FUS9VED(")5;G-E96XB"FUS9W-T<B`B575S:2(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$R"FUS9VED(")5;G-U8G-C<FEB92!F
M<F]M($9O;&1E<BAS*2(*;7-G<W1R("),;W!E=&$@:V%N<VEO:61E;B!T:6QA
M=7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3,*;7-G
M:60@(E5P9&%T92(*;7-G<W1R(")0Y&EV:73D(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8Q,@IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A
M='5S(@IM<V=S='(@(E#D:79I=.0@=F%S=&%A:F%N('1I;&%T:65D;W0B"@HC
M.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-3@@=&5M<&QA=&5S
M+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@
M(E1U;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z
M-#$*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(DOD>73D(&]L
M971U<V%R=F]A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I
M9"`B57-E($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(DOD
M>73D($E-05`M<')O=&]K;VQL86X@:V%N<VEO:61E;B!T:6QA=7-T82XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(T"FUS9VED(")5<V4@5FER='5A
M;"!4<F%S:"!&;VQD97(_(@IM<V=S='(@(DOD>73D('9I<G1U86%L:7-T82!R
M;W-K86MO<FEK86YS:6]T82XB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M,30S"FUS9VED(")5<V5R(@IM<V=S='(@(DOD>71TY&KD(@H*(SH@86-L+G!H
M<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C
M97-S9G5L;'D@9VEV96X@=&AE('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+Y'ET=.1JY&QL92!<(B5S7"(@;VYN
M:7-T=71T:6EN(&%N=&%M86%N(&]I:V5U9&5T(&MA;G-I;V]N(%PB)7-<(BXB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-@IM<V=I9"`B57-E
M<FYA;64B"FUS9W-T<B`B2^1Y='3D:N1T=6YN=7,B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z,3<*;7-G:60@(E5S97)N86UE.B(*;7-G
M<W1R(")+Y'ET=.1JY'1U;FYU<SHB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R(*;7-G<W1R(").Y'ETY"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,3`@;&EB+TU)344O5FEE=V5R
M+WII<"YP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G
M<W1R(").Y'ETY"`E<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,@4'5B;&EC($ME>2(*;7-G<W1R(").Y'ETY"!J=6QK:6YE
M;B!A=F%I;B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,3D*
M;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W
M(@IM<V=S='(@(D[D>73D('9I97-T:65N($A434PM;75O=&]I;F5N('-I<^1L
M=/8@97)I;&QI<V5S<^0@:6MK=6YA<W-A(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,C@*;7-G:60@(E9I97<@365S<V%G97,B"FUS9W-T
M<B`B3N1Y=.0@=FEE<W1I="(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6:65W(%!E
M<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(D[D>73D(&AE;FMI;/9K;VAT
M86EN96X@<V%L86EN96X@879A:6XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE
M=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(D[D>73D(&AE;FMI;/9K
M;VAT86EN96X@:G5L:VEN96X@879A:6XB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3@*;7-G:60@(E9I97<@5&AR96%D(@IM
M<V=S='(@(D[D>73D($ME<VMU<W1E;'5SY&EE(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,38T(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V-@IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B3N1Y=.0@<&EK
M:W5K=79A(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C,*;7-G
M:60@(E9I97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G
M<W1R(").Y'ETY"!L:6ET92!E<FEL;&ES97-SY"!I:VMU;F%S<V$B"@HC.B!L
M:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*;7-G:60@(E9I97<@8V]N
M=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(").Y'ETY"!V:65S
M=&EN('-I<^1L=/8@97)I;&QI<V5S<^0@:6MK=6YA<W-A(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$T,0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G
M<W1R(").Y'ETY"!T87!A:'1U;6$B"@HC.B!F;VQD97)S+G!H<#HS-C$@;6%I
M;&)O>"YP:'`Z-3(P"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@;65S<V%G
M97,@:6X@)7,B"FUS9W-T<B`B3N1Y=.0@=FEE<W1I="!K86YS:6]S<V$@)7,B
M"@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C(S
M"FUS9VED(")6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I
M;CHB"FUS9W-T<B`B3N1K>6WD('1A:2!P;W-T:6MA;G-I;RP@:F]K82!NY'ET
M973DY&X@<VESY.1N:VER:F%U='5M:7-E;B!JY&QK965N.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ-S$*;7-G:60@(E9I97<@=&%S:R(*;7-G
M<W1R(").Y'ETY"!T96ATY';D(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$P-`IM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM<V=S='(@(D[D>73D
M(&MU=F%T(@H*(SH@<V5A<F-H+G!H<#HR-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FER='5A;"!&;VQD97(@7"(E<UPB(&-R96%T960@<W5C8V5S9G5L;'DN
M(@IM<V=S='(@(E9I<G1U86%L:6MA;G-I;R!<(B5S7"(@;VX@;'5O='4N(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,3(@;&EB+TE-05`O5')E
M92YP:'`Z,30Q(&QI8B])34%0+U1R964N<&AP.C$U-`HC.B!L:6(O24U!4"]4
M<F5E+G!H<#HQ-38@;&EB+TE-05`O5')E92YP:'`Z,38P(&QI8B])34%0+U1R
M964N<&AP.C$V,0HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-S$@;&EB+TE-05`O
M5')E92YP:'`Z,SDU(&QI8B])34%0+U1R964N<&AP.C0S,PIM<V=I9"`B5FER
M='5A;"!&;VQD97)S(@IM<V=S='(@(E9I<G1U86%L:6MA;G-I;W0B"@HC.B!S
M96%R8V@N<&AP.C(T-PIM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@
M82!L86)E;"XB"FUS9W-T<B`B5FER='5A86QI:V%N<VEO:6QL92!P:73DY"!A
M;G1A82!N:6UI+B(*"B,Z(&QI8B]396%R8V@N<&AP.C0R,`IM<V=I9"`B5FER
M='5A;"!)3D)/6"(*;7-G<W1R(")6:7)T=6%A;&EN96X@24Y"3U@B"@HC.B!F
M;VQD97)S+G!H<#HS.3<*;7-G:60@(E9I<G1U86P@24Y"3U@@1F]L9&5R(@IM
M<V=S='(@(E9I<G1U86%L:6YE;B!)3D)/6"UK86YS:6\B"@HC.B!L:6(O36%I
M;&)O>"YP:'`Z,3<Q(&QI8B]396%R8V@N<&AP.C,V-@IM<V=I9"`B5FER='5A
M;"!4<F%S:"(*;7-G<W1R(")6:7)T=6%A;&EN96X@<F]S:V%K;W)I(@H*(SH@
M9F]L9&5R<RYP:'`Z,SDT"FUS9VED(")6:7)T=6%L(%1R87-H($9O;&1E<B(*
M;7-G<W1R(")6:7)T=6%A;&EN96X@<F]S:V%K;W)I:V%N<VEO(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,CD*;7-G:60@(E9I<G1U86P@9F]L
M9&5R(&QA8F5L(@IM<V=S='(@(E9I<G1U86%L:6MA;G-I;VX@;FEM:2(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<Y"FUS9VED(")787)N:6YG
M(@IM<V=S='(@(E9A<F]I='5S(@H*(SH@;&]G:6XN<&AP.C$U,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E1E<G9E='5L
M;V$@;VAJ96QM86%N("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P
M-PIM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A
M9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@(@HB
M;W(@:6YN;V-E;G0_(@IM<V=S='(@(B(*(DUI=.0@=&5H9.3D;B!R;W-K87!O
M<W1I=FEE<W1E:6QL92!K=6X@;F4@;VX@<F%P;W)T;VET=2!J;VMO(')O<VMA
M<&]S=&EN82!T86D@(@HB96D@<F]S:V%P;W-T:6YA+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW,38*;7-G:60@(B(*(E=H96X@9&5L971I;F<@;65S
M<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D
M(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE=&5D/R(*;7-G<W1R("(B"B)+
M=6X@=FEE<W1E:N0@<&]I<W1E=&%A;BP@<VEI<G+D(&YE(')O<VMA:V]R:6MA
M;G-I;V]N('-E;B!S:6IA86XL(&5T=.0@;F4@(@HB;65R:VET=.1I<VEI;B!P
M;VES=&5T=6MS:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DV"FUS
M9VED(")7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D
M;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\B"FUS9W-T<B`B2W5N('5U<VD@<&]S
M=&EK86YS:6\@875K86ES=&%A;BP@;FEI;B!M:6QTY"!S:79U;'1A(&AA;'5A
M="!A;&]I='1A83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38Q"FUS
M9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T
M=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B(@HB5&%L;&5T971T865S<V$@;.1H
M=&5V:>0@=FEE<W1E:N0L('1A;&QE=&$@;7GV<R!LY&AE=&5T='D@;&EI=&5T
M:65D;W-T;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(V"FUS9VED
M("(B"B)7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S
M+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD('1O("(*(G5N<75A;&EF
M:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@7")`7"(I
M/R(*;7-G<W1R("(B"B)+=6X@;.1H971E=.3D;B!V:65S=&GD(&QA86IE;G1A
M;6%T=&]M:6EN(&]S;VET=&5I<VEI;BP@;FEI;B!M:6OD(&1O;6%I;BTB"B)T
M:65T;R!L:7/D=.3D;B!E<.1MY.1RY&ES:6EN(&]S;VET=&5I<VEI;B`H<^1H
M:_9P;W-T:6]S;VET=&5E="!I;&UA;B!<(D!<(BTB"B)M97)K:VGD*3\B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E=H:71E;&ES
M="(*;7-G<W1R(")686QK;VEN96X@;&ES=&$B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU,S<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-34P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-C<*;7-G:60@
M(EEE<R(*;7-G<W1R(")+>6QLY"(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-3@*;7-G:60@(EEO=2!A<F4@86)O=70@
M=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ
M(@IM<V=S='(@(D]L970@:&%K96UA<W-A('/D:&OV<&]S=&EA('-E=7)A879I
M;'1A('/D:&OV<&]S=&ET:6QE:6QTY#HB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`IM<V=I9"`B(@HB66]U(&%R92!A
M='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D(&EN
M('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R(")/;&5T('!O
M:7-T86UA<W-A(&MA:6MK:6$@=FEE<W1E:N0@<V5U<F%A=FES=&$@:V%N<VEO
M:7-T82XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN
M:'1M;#HY"FUS9VED(")9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H
M92!F;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G<W1R(")/;&5T('!O:7-T86UA
M<W-A('-E=7)A879I82!K86YS:6]I=&$N(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O
M(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B3VQE="!K;W!I;VEM87-S82]S:6ER
M=.1MY'-SY"!V:65S=&5JY"!U=71E96X@:V%N<VEO;VXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(EEO=2!A<F4@
M8W)E871I;F<@82!S=6(M9F]L9&5R('1O("(*;7-G<W1R(")/;&5T('1E:V5M
MY'-SY"!A;&EK86YS:6]T82!K86YS:6]L;&4@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#8*;7-G:60@(EEO=2!A<F4@8W)E871I
M;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R(")/;&5T('1E:V5MY'-S
MY"!Y;&EM;>1N('1A<V]N(&MA;G-I;W1A+B(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C(W-@IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@9F]L
M9&5R<RXB"FUS9W-T<B`B66QI;6WD;B!T87-O;B!K86YS:6]I9&5N(&QU;VYT
M:2!O;B!E<W1E='1Y+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(X,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@9F]L9&5R<RXB"FUS9W-T<B`B170@=F]I(&QU;V1A(&5N
M96UPY.0@:W5I;B`E9"!K86YS:6]T82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C$S-PIM<V=I9"`B66]U(&%R92!R96YA;6EN9R!T
M:&4@9F]L9&5R.B`B"FUS9W-T<B`B3VQE="!N:6UEY&WD<W/D('5U9&5L;&5E
M;B!K86YS:6]T83H@(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C,U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!C86X@=7-E('1H
M92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&EN('1H92!S=&%T:6]N97)Y('1E
M>'0Z("5C(&9O<B!T:&4@(@HB8W5R<F5N="!M97-S86=E(&-O;G1E;G0[("5S
M(&9O<B!T:&4@<VEG;F%T=7)E+B(*;7-G<W1R("(B"B)6;VET(&OD>71TY.0@
M<V5U<F%A=FEA(&UE<FMK:6IO;F]J82!E<FEK;VES;65R:VET>6MS97-SY"!K
M:7)J97!O:&IA<W-A.B`E8R`B"B)T87)K;VET=&%A('9I97-T:6X@<V5N(&AE
M=&MI<W3D('-I<^1L=/;D.R`E<R!A;&QE:VER:F]I='5S=&$N(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-3(T"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!C86YN
M;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D5T('9O:2!L
M;W!E='1A82!T:6QA=7-T82!K86YS:6]O;B!<(B5S7"(N(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*
M(EEO=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G
M<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN
M(@IM<V=S='(@(B(*(D5T(&AY=N1K<WEN>70@:N1R:F5S=&5L;>1N(&OD>71T
M]F5H=&]J82P@:F]T96X@970@=F]I(&MI<FIA=71U82!S:7/DY&XN(@H*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$W,`IM<V=I9"`B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E
M<B(*;7-G<W1R(")3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@;75U='1A82!T
MY&WD;B!K86YS:6]N(&]I:V5U:W-I82(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O<G=A<F1E9"!T:&ES(&UE
M<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N
M(@IM<V=S='(@(E;D;&ET:70@=.1MY&X@=FEE<W1I;B`E)7,@<.1I=N1NY"!V
M87-T86%N;W1T86II;&QE.B`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M;&5R="YI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N
M97<@;65S<V%G97,N(@IM<V=S='(@(E-I;G5L;&4@;VX@)7,@=75T=&$@=FEE
M<W1IY"XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PIM<V=I
M9"`B66]U(&AA=F4@,2!N97<@;65S<V%G92XB"FUS9W-T<B`B4VEN=6QL92!O
M;B`Q('5U<VD@=FEE<W1I+B(*"B,Z(&-O;7!O<V4N<&AP.C0X,@IM<V=I9"`B
M66]U(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E+B(*;7-G<W1R
M(")/;&5T(&IO(&SD:&5T=.1N>70@=.1MY&X@<VEV=6XN(@H*(SH@;&EB+TE-
M4"YP:'`Z,3`U-@IM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(Z(@IM<V=S='(@(E-I;G5L;&4@;VX@=75S:6$@=FEE
M<W1E:N0@:V%N<VEO<W-A.B(*"B,Z(&QI8B])35`N<&AP.C$P-C$*;7-G:60@
M(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SHB
M"FUS9W-T<B`B4VEN=6QL92!O;B!U=7-I82!V:65S=&5JY"!K86YS:6]I<W-A
M.B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PIM<V=I9"`B66]U(&UU<W0@96YT97(@
M870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS9W-T<B`B4VEN=6X@<&ETY.0@
M;>3D<FET96QLY"!A:6YA:VEN('EK<VD@=F%S=&%A;F]T=&%J82XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HS,#8*;7-G:60@(B(*(EEO=2!M=7-T
M(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME
M>2!T;R!V:65W('1H:7,@;65S<V%G92(*;7-G<W1R("(B"B)3:6YU;B!P:73D
MY"!A;G1A82!S86QA<V%N871E:W-T:2!V;VED86MS97-I(&OD>71TY.0@<V%L
M86ES=&$@4$=0+6%V86EN=&$@(@HB=.1MY&X@=FEE<W1I;B!A=F%A;6ES96MS
M:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C4T"FUS9VED("(B
M"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)
M344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS9W-T
M<B`B(@HB4VEN=6X@<&ETY.0@86YT86$@<V%L87-A;F%T96MS=&D@=F]I9&%K
M<V5S:2!KY'ET=.3D('-A;&%I<W1A(%,O34E-12UA=F%I;G1A("(*(G3D;>1N
M('9I97-T:6X@879A86UI<V5K<VDB"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHR,#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL
M8F]X(&9I<G-T+B(*;7-G<W1R(")3:6YU;B!P:73DY"!V86QI=&$@:V]H9&5K
M86YS:6\N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R
M(")3:6YU;B!P:73DY"!V86QI=&$@<&]I<W1E='1A=F$@<^1H:_9P;W-T:71I
M;&DN(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S
M='(@(E-I;G5N('!I=.3D(&5N<VEN('9A;&ET82!O<V]I=&4N(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA
M:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X
M+VIA=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T
M(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R(")3:6YU;B!P:73D
MY"!V86QI=&$@86EN86MI;B!Y:W-I('9I97-T:2XB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z,3,*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!R96-I<&EE;G0N(@IM<V=S='(@(E-I;G5N('!I=.3D(&WDY')I=&5L
M;.0@=F%S=&%A;F]T=&%J82XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@=&\@
M:&%V92!<(B5S7"(@96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO
M;G,N(@IM<V=S='(@(DAU;VTZ(%-I;G5L;&$@<&ETY.0@;VQL82!Y;&SD<&ET
M;W1O:6UI<W-A('9A;&ET='5N82!<(B5S7"(N(@H*(SH@;&EB+TUA:6QL;V<N
M<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5D:7)E8W1E9"!T
M:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+B(*;7-G<W1R(")/:&IA<VET('3D
M;>1N('9I97-T:6X@=F%S=&%A;F]T=&%J86QL92`E<R`E)7,@<.1I=N1NY"XB
M"@HC.B!L:6(O36%I;&QO9RYP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RXB"FUS9W-T<B`B
M5F%S=&%S:70@=.1HY&X@=FEE<W1I:6X@)7,@<.1I=N1NY"XB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@
M;F]T('-U8G-C<FEB960@=&\@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(DMA;G-I;VX@7"(E<UPB('1I;&%A;6EN96X@
M97#D;VYN:7-T=6DN(%!A;'9E;&EM96X@=FER:&5I;&UO:71U<R!O;&DB"@HC
M.B!L:6(O1F]L9&5R+G!H<#HU,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W
M:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)4:6QA=6MS96X@;&]P
M971T86UI;F5N(&MA;G-I;V]N(%PB)7-<(B!E<.1O;FYI<W1U:2X@4&%L=F5L
M:6UE;B!V:7)H96EL;6]I='5S("(*(F]L:2(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C0W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L
M;'D@<W5B<V-R:6)E9"!T;R!<(B5S7"(B"FUS9W-T<B`B2V%N<VEO;B!<(B5S
M7"(@=&EL875S(&]N;FES='5I(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U
M8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B5&EL875K<V5N(&QO<&5T
M=&%M:6YE;B!K86YS:6]O;B!<(B5S7"(@;VYN:7-T=6DB"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z.3@*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(").
M:6UE<VDB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G:60@(EEO
M=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B2G5L:VEN96X@
M:F$@<V%L86EN96X@4$=0+6%V86EM97-I(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*;7-G:60@
M(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B4V%L86EN96X@879A:6UE<VDB
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW,0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y(@IM<V=S='(@
M(DIU;&MI;F5N(&%V86EM97-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$V-0IM<V=I9"`B66]U<B!297!L>2UT;SH@861D<F5S<SH@/&5M/BAO<'1I
M;VYA;"D\+V5M/B(*;7-G<W1R(")687-T875S;W-O:71T965S:3H@/&5M/BAV
M87!A865H=&]I;F5N*3PO96T^(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHT.0IM<V=I9"`B66]U<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R
M=&EF:6-A=&5S(@IM<V=S='(@(DIU;&MI;F5N(&IA('-A;&%I;F5N(%,O34E-
M12UV87)M96YT965S:2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N
M=%]S96QE8W0N:6YC.C$V"FUS9VED(")9;W5R(&%C8V]U;G1S.B(*;7-G<W1R
M(")3Y&AK]G!O<W1I=&EL:7-I.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-S,*;7-G:60@(B(*(EEO=7(@86QI87,@861D<F5S<V5S.B`\96T^*&]P
M=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M
M/B(*;7-G<W1R("(B"B)3Y&AK]G!O<W1I86QI86MS97-I.B`\96T^*'9A<&%A
M96AT;VEN96XL(&QA:71A(&IO:V%I;F5N(&]S;VET92!O;6%L;&4@(@HB<FEV
M:6QL965N*3PO96T^(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M,3`Q"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI
M;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(B(*(E-E
M;&%I;65S:2!E:2!T=64@=.1MY&X@='EY<'!I<W1E;B!K=79I96X@;N1Y='3D
M;6ES=.0@=FEE<W1I96X@>6AT97ED97-SY"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,SD*;7-G:60@(EEO=7(@9&5F875L="!C:&%R<V5T(&9O<B!S
M96YD:6YG(&UE<W-A9V5S.B(*;7-G<W1R(")/;&5T=6MS96YA('9I97-T:6X@
M;.1H971Y:W-E<W/D(&OD>71E='3D=N0@;65R:VES=/8Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F
M875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB
M"FUS9W-T<B`B3VQE='5K<V5N82!KY'ET971TY';D('9I97-T:65N('-A;&%U
M<W1A<&$Z(@H*(SH@871T86-H;65N="YP:'`Z.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!L:6YK960@871T86-H;65N="!H87,@8F5E;B!D;W=N
M;&]A9&5D(&)Y(&%T(&QE87-T(&]N92!U<V5R+EQN(@HB7&XB"B)!='1A8VAM
M96YT(&YA;64Z("5S7&XB"B)!='1A8VAM96YT(&1A=&4Z("5S7&XB"B)<;B(*
M(D-L:6-K(&]N('1H92!F;VQL;W=I;F<@;&EN:R!T;R!P97)M86YE;G1L>2!D
M96QE=&4@=&AE(&%T=&%C:&UE;G0Z7&XB"B(E<R(*;7-G<W1R("(B"B),:6YK
M:71TY&WD<VD@;&EI='1E96X@;VX@=&%L;&5N=&%N=70@86EN86MI;B!Y:W-I
M(&OD>71TY&KD+EQN(@HB7&XB"B),:6ET971I961O<W1O;B!N:6UI.B`E<UQN
M(@HB3&EI=&5T:65D;W-T;VX@<.1I=N1MY.1RY#H@)7-<;B(*(EQN(@HB3F%P
M<V%U=&$@<V5U<F%A=F%S=&$@;&EN:VES=.0@<&]I<W1A86MS97-I(&QI:71T
M965N('!Y<WEVY'-T:3I<;B(*(B5S(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z.#D*;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U
M;&QY(&1E;&EV97)E9"XB"FUS9W-T<B`B5FEE<W1I<VD@;VX@;65N;GET('!E
M<FEL;&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-@IM<V=I9"`B
M66]U<B!S:6=N871U<F4Z(@IM<V=S='(@(D%L;&5K:7)J;VET=6MS97-I.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V%D9')E<W-E<T)L;V-K<RYJ<SHW
M"FUS9VED(");2&ED92!!9&1R97-S97-=(@IM<V=S='(@(EM0:6EL;W1A(&]S
M;VET=&5E=%TB"@HC.B!C;VUP;W-E+G!H<#HQ,S`Q(&UA:6QB;W@N<&AP.C4S
M-2!M97-S86=E+G!H<#HR.34@;&EB+T-O;7!O<V4N<&AP.C@S.`IM<V=I9"`B
M6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM%:2!O='-I:VMO85TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z.`IM<V=I9"`B
M6U-H;W<@061D<F5S<V5S("TB"FUS9W-T<B`B6T[D>73D(&]S;VET=&5E="`M
M(@H*(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(EM3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP:65N='-=(@IM<V=S
M='(@(EM.Y'ETY"!O<V]I='1E970@+2`E<R!V87-T86%N;W1T86II;F%=(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`S"FUS9VED(")?
M0F-C(@IM<V=S='(@(E]0:6EL;VMO<&EO(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C$V"FUS9VED(")?0FQA8VML:7-T(@IM<V=S='(@(E]-=7-T
M82!L:7-T82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$U
M,@IM<V=I9"`B7T-C(@IM<V=S='(@(E]+;W!I;R(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,3`*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B7U!O:7-T82(*"B,Z(&QI
M8B])35`N<&AP.CDU.0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`B7TMA;G-I
M;W0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHW.0IM<V=I
M9"`B7TED96YT:71Y(@IM<V=S='(@(E]0<F]F:6EL:2(*"B,Z(&QI8B])35`N
M<&AP.CDR.`IM<V=I9"`B7TEN8F]X(@IM<V=S='(@(E]);F)O>"(*"B,Z(&QI
M8B])35`N<&AP.C$P,#`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E]+:7)J
M875D=2!U;&]S(@H*(SH@;65S<V%G92YP:'`Z,SDQ"FUS9VED(")?365S<V%G
M92!3;W5R8V4B"FUS9W-T<B`B7U9I97-T:2!R86%K86UU;V1O<W-A(@H*(SH@
M;&EB+TE-4"YP:'`Z.34V"FUS9VED(")?3F5W($UE<W-A9V4B"FUS9W-T<B`B
M7U5U<VD@=FEE<W1I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C,S"FUS9VED(")?4')I;G0B"FUS9W-T<B`B7U1U;&]S=&$B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-S`@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@W"FUS9VED(")?4')I;W)I='DB
M"FUS9W-T<B`B7U!R:6]R:71E971T:2(*"B,Z(&UA:6QB;W@N<&AP.C0P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")?4F5F<F5S:"`E<R(*;7-G<W1R(")?4.1I
M=FETY"`E<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHX"FUS9VED(")?4F5P;'DB"FUS9W-T<B`B7U9A<W1A82(*"B,Z(&QI
M8B])35`N<&AP.CDV,0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?2&%K=2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8U('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R-@IM<V=I9"`B7U-E;F0@365S<V%G
M92(*;7-G<W1R(")?3.1H973D('9I97-T:2(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S(*;7-G:60@(E]4:')E860B"FUS
M9W-T<B`B7TME<VMU<W1E;'5SY&EE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,3$T"FUS9VED(")?5&\B"FUS9W-T<B`B7U9A<W1A86YO
M='1A:F$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM
M<V=I9"`B7U5N9&5L971E(@IM<V=S='(@(E]086QA=71A(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")?5FEE
M=R!4:')E860B"FUS9W-T<B`B7T[D>73D($ME<VMU<W1E;'5SY&EE(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")?5VAI=&5L:7-T
M(@IM<V=S='(@(E]686QK;VEN96X@;&ES=&$B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3<U"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")T=6YT
M96UA=&]N(&]S;VET92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-3$*;7-G:60@
M(F%T=&%C:&UE;G0B"FUS9W-T<B`B;&EI=&5T:65D;W-T;R(*"B,Z('9I97<N
M<&AP.CDW"FUS9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B871T86-H
M;65N=',N>FEP(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-3`U"FUS9VED(")B>71E<R(*;7-G<W1R(")T879U82(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ.3D*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B
M"FUS9W-T<B`B96D@=F]I(&QU;V1A('1U;&]S=&EE9&]S=&]A(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$W,0IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS
M9W-T<B`B96D@=F]I(&%U:V%I<W1A(&SD:&1E='3D(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C$V,PIM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM
M<V=S='(@(G9I<FAE(&MO;65N=&]R:79I;&SD(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(Q.0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")A
M<V5T=7-V:7)H92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.34*;7-G:60@(F-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B:W)I:71T:6YE
M;B!JY')J97-T96QMY'1I961O<W1O('!U=71T=74B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,38W"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")M
M=6]T;W9I<FAE('1I961O:7-S82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C,*
M;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")T:65T=65T=&$@96D@
M;/9Y='EN>70B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$Y,`IM<V=I9"`B9G)O;2(*;7-G<W1R(")LY&AD92(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ-SD*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@
M(G1U;G1E;6%T;VX@<&%L=F5L:6UE;B!N:6UI(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(P,PIM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(FEO
M+79I<FAE(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-PIM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B;VAJ96QM:7-T;VX@<VESY&EN
M96X@=FER:&4B"@HC.B!P9W`N<&AP.C8X('-M:6UE+G!H<#HR.0IM<V=I9"`B
M:V5Y(@IM<V=S='(@(F%V86EN(@H*(SH@9F]L9&5R<RYP:'`Z,30U"FUS9VED
M(")M86EL8F]X(&9I;&4B"FUS9W-T<B`B;6%I;&)O>"UT:65D;W-T;R(*"B,Z
M(&-O;7!O<V4N<&AP.C$Q,#4@;&EB+TUE<W-A9V4N<&AP.C4Q,PIM<V=I9"`B
M;F%M92(*;7-G<W1R(")N:6UI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C<V"FUS9VED(")N;VYE(@IM<V=S='(@(F5I(&UI=.3D;B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(U
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@
M(F]R(@IM<V=S='(@(G1A:2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,34*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(FOD>71T]B!K:65L;&5T
M='DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N
M:G,Z.`IM<V=I9"`B<F5C:7!I96YT<UTB"FUS9W-T<B`B=F%S=&%A;F]T=&%J
M871=(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q,0IM<V=I9"`B<F5M;W1E(&5R
M<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(F5TY'9I<FAE('!R;W1O:V]L;&%S
M<V$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@S"FUS9VED(")S97)V:6-E('5N
M879A:6QA8FQE(@IM<V=S='(@(G!A;'9E;'4@96D@;VQE(&OD>71E='3D=FES
M<^0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G
M:60@(G-P96QL:6YG(&5R<F]R(@IM<V=S='(@(FMI<FIO:71U<W9I<FAE(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S
M<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B:VER:F]I='5S=FER:&5I=.0B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3DQ"FUS9VED(")S>7-T96T@97)R;W(B"FUS
M9W-T<B`B:N1R:F5S=&5L;>1V:7)H92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR
M,#<*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(G;D;&EA:6MA
M:6YE;B!V:7)H92(*"B,Z(&QI8B]&:6QT97(N<&AP.C<Y"FUS9VED(")Y;W5R
M(&)L86-K;&ES="(*;7-G<W1R(")M=7-T82!L:7-T87-I(@H*(SH@;&EB+T9I
M;'1E<BYP:'`Z.#D*;7-G:60@(GEO=7(@=VAI=&5L:7-T(@IM<V=S='(@(G9A
M;&MO:6YE;B!L:7-T87-I(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R]E=%]%12YP;P``````````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S-34T,3,`,3`T,3<S-C(W
M-C0`,#$W,38R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",@24U0($535$].24%.(%1204Y33$%424]."B,@5&]O;6%S($%A
M<R`\=&]O;6%S+F%A<T!M86EL+F5E/BP@,C`P,B`*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U0(#0N,"UC=G-<;B(*(E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)0
M3U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)0
M3RU2979I<VEO;BU$871E.B`R,#`T+3`V+3`R(#$P.C0Y*S`R,#!<;B(*(DQA
M<W0M5')A;G-L871O<CH@5&]O;6%S($%A<R`\=&]O;6%S+F%A<T!M86EL+F5E
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@17-T;VYI86X@/&1E=D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$S7&XB"B)#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z("(*;7-G<W1R("(@
M2V5L;&5L93H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q-0IM<V=I9"`B("`@
M("`@5&\Z("(*;7-G<W1R("(@2V5L;&5L93H@(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C0P,PIM<V=I9"`B("`@($1A=&4Z("(*;7-G<W1R("(@2W5U<.1E=CH@
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P-@IM<V=I9"`B("`@($9R;VTZ("(*
M;7-G<W1R("(@2V5L;&5L=#H@(@H*(SH@;6%I;&)O>"YP:'`Z-#(R('1E;7!L
M871E<R]F;VQD97)S+VAE860N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HT,3(*;7-G:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B("`@5&5E;6$Z("(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW,`HC+"!F=7IZ
M>0IM<V=I9"`B(&EN("(*;7-G<W1R("),;V=I('-I<W-E(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G
M<W1R("(B"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T<B`B)60@:VER:2`E9"US="(*
M"B,Z(&UA:6QB;W@N<&AP.C$W-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)60@;65S<V%G97,@:&%V92!B965N(&1E;&5T960N(@IM<V=S='(@(D[D
M:71A(&MI<FIA('#D<F%S="!F:6QT<FET92!R86ME;F1A;6ES="XB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@
M=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B4V5L;&4@
M:VER:F$@:V]H=&$@;VX@<V%A9&5T=60@:V%E8G5S('/\<W1E96UI(&%D;6EN
M:7-T<F%A=&]R:6QE+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O
M<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B4V5L;&4@:VER:F$@:V]H=&$@
M;VX@<V%A9&5T=60@:V%E8G5S('/\<W1E96UI(&%D;6EN:7-T<F%A=&]R:6QE
M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E-E;&QE
M(&MI<FIA(&MO:'1A(&]N('-A861E='5D(&MA96)U<R!S_'-T965M:2!A9&UI
M;FES=')A871O<FEL92XB"@HC.B!L:6(O4W!A;2YP:'`Z,34P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P
M;W)T960@87,@<W!A;2XB"FUS9W-T<B`B4V5L;&4@:VER:F$@:V]H=&$@;VX@
M<V%A9&5T=60@:V%E8G5S('/\<W1E96UI(&%D;6EN:7-T<F%A=&]R:6QE+B(*
M"B,Z(&UA:6QB;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!T
M;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R(")+:7)J860@)60@:W5N:2`E
M9"P@:V]K:W4@)60B"@HC.B!M86EL8F]X+G!H<#HV-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E
M<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@(B5S(&]N(&IU8F$@;VQE;6%S
M+B!3:6YU("5S(&MA=7-T82!E:2!N:6UE=&%T=60@_&UB97(N(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8T.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!M86EL8F]X+B(*;7-G<W1R("(B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E
M:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"XB"FUS9W-T
M<B`B)7,@:V%U<W0@;FEM971A=&%K<V4@_&UB97(@:W5U(&%L9W5S97,N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H
M87,@9&5C;&EN960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI
M960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I
M=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T
M<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<
M(BXB"FUS9W-T<B`B2V%U<W0@7"(E<UPB(&YI;65T871I(/QM8F5R(%PB)7-<
M(BUK<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@
M=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RXB"FUS9W-T<B`B(@H*
M(SH@;65S<V%G92YP:'`Z,C@U(&UE<W-A9V4N<&AP.C(Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7W1O<"YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I(@IM<V=S='(@(B5S.B`E<R`H
M)60F;F)S<#LO)FYB<W`[)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$S,PIM<V=I9"`B*$%P<&QY('1H97-E(&-H86YG97,@86YD
M(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*;7-G<W1R("(H4V%L=F5S=&$@;F5E
M9"!M=75T=7-E9"!J82!M:6YE(&KD<F=M:7-E;&4@96MR86%N:6QE+BDB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED("(H
M1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E
M('-C<F5E;BXI(@IM<V=S='(@(BCD<F$@<V%L=F5S=&$@;75U='5S:2!J82!M
M:6YE('1A9V%S:2!K:7)J82!J=75R9&4N*2(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*$A434PI(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B
M*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG+G!H<#HR.#`*
M;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R
M(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("`B"B)#:&%N
M9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D
M+BDB"FUS9W-T<B`B(@HB*$UI;F4@=&%G87-I(&MI<FIA(&IU=7)D92!SY&EL
M:71A9&5S(&OU:6L@<V5N:2!S86QV97-T871U9"!M=75D871U<V5D+B`B"B)3
M96QL96P@96MR86%N:6P@=&5H='5D(&UU=61A='5S:2!%22!304Q615-4051!
M+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"B,L(&9U>GIY"FUS9VED("(B"B(H
M4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@
M=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W
M:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*$UI;F4@=&%G87-I
M(&MI<FIA(&IU=7)D92!SY&EL:71A9&5S(&OU:6L@<V5N:2!S86QV97-T871U
M9"!M=75D871U<V5D+B`B"B)396QL96P@96MR86%N:6P@=&5H='5D(&UU=61A
M='5S:2!%22!304Q615-4051!+BDB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI
M;F<@3TL@*B(*;7-G<W1R("(J($QI<V$@;F5E9"!V86IU=&%D97,@3TL@*B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS9VED
M("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(%!A
M;'5N('9A;&D@86%D<F5S<RAI9"D@*B(*"B,Z(&UA:6QB;W@N<&AP.C$W-`HC
M+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(DED96YT:71E970@7"(E<UPB(&]N(&MU<W1U=&%T=60N(@H*(SH@
M;&EB+U-P86TN<&AP.C$X,`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA
M<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(E-E;&QE(&MI<FIA(&MO:'1A(&]N('-A
M861E='5D(&MA96)U<R!S_'-T965M:2!A9&UI;FES=')A871O<FEL92XB"@HC
M.B!L:6(O4W!A;2YP:'`Z,38P"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(E-E;&QE
M(&MI<FIA(&MO:'1A(&]N('-A861E='5D(&MA96)U<R!S_'-T965M:2!A9&UI
M;FES=')A871O<FEL92XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<R"B,L(&9U>GIY
M"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T
M;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")396QL92!K
M:7)J82!K;VAT82!O;B!S86%D971U9"!K865B=7,@<_QS=&5E;6D@861M:6YI
M<W1R86%T;W)I;&4N(@H*(SH@;&EB+U-P86TN<&AP.C$U,@HC+"!F=7IZ>0IM
M<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN(@IM
M<V=S='(@(E-E;&QE(&MI<FIA(&MO:'1A(&]N('-A861E='5D(&MA96)U<R!S
M_'-T965M:2!A9&UI;FES=')A871O<FEL92XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#$Y"B,L(&9U>GIY"FUS9VED("(Q,#`@8VAA<F%C=&5R<R(*
M;7-G<W1R(")%<FEMY')G:60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#(R"B,L(&9U>GIY"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B
M17)I;>1R9VED(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,`HC+"!F
M=7IZ>0IM<V=I9"`B,C4P(&-H87)A8W1E<G,B"FUS9W-T<B`B17)I;>1R9VED
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,0HC+"!F=7IZ>0IM<V=I
M9"`B-3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B17)I;>1R9VED(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38R"B,L('!H<"UF;W)M870*;7-G
M:60@(D$@;&%R9V4@:6UA9V4@;F%M960@)7,@:7,@871T86-H960@=&\@=&AI
M<R!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M97-S86=E('EO=2!H879E
M('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F
M<F]M('1H92`B"B)R96-I<&EE;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!3D0B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,`IM<V=I9"`B06-C97!T
M(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4X-PIM<V=I9"`B06-C97!T(')E<75E<W0@86YD(&%D9"!I="!T;R!M
M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S4S"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,C4W"FUS9VED(")!8V-E<'1E9#H@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW
M"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT)W,@;F%M93HB"FUS9W-T<B`B261E
M;G1I=&5E9&D@;FEM:3HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3(P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S`*(RP@9G5Z>GD*;7-G
M:60@(D%C=&EO;G,B"FUS9W-T<B`B5&5G979U<R(*"B,Z(&QI8B]-24U%+TAE
M861E<G,N<&AP.C(P,"!L:6(O34E-12](96%D97)S+G!H<#HR,#$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"`E<R!T;R!M>2!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B3&ES82!A861R97-S:7)A86UA='5S<V4@*"5S*2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P,PHC+"!F=7IZ
M>0IM<V=I9"`B061D('-O=7)C92(*;7-G<W1R(")L:7-A(&%L;&EK87,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R
M(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R-38*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT
M+B(*;7-G<W1R("),:7-A<VEN(&QI<V%N9&DN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O
M(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E
M86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@
M:6YF;W)M871I;VX@9&5T86EL<R(*;7-G<W1R("))<VEK;&EK(&EN9F\B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G
M:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS
M(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;G1A8W1S+G!H
M<#HX-2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X,`HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,SD@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C4R"FUS9VED(")!9&1R97-S($)O;VLB"FUS
M9W-T<B`B06%D<F5S<VER86%M870B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,T"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@
M(D%A9')E<W-I<F%A;6%T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE
M;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L
M:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.#$*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!E>'!L:6-I=&QY('1I92!T
M;R!T:&ES(&ED96YT:71Y.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H("(*
M(F%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$P(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,C,*;7-G:60@(D%L;"(*;7-G<W1R(")+]6EK(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,PIM<V=I9"`B(@HB06QL
M(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@
M9&]W;FQO861E9"!I;G1O(&]N92!-0D]8("(*(F9I;&4Z(@IM<V=S='(@(DOU
M:6L@:VER:F%D(&KD<F=M:7-T97,@:V%U<W1A9&5S('-A;'9E<W1A=&%K<V4@
M_&AT92!-0D]8(&9A:6QI.B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U
M<F=E7W1R87-H+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!;&P@
M;65S<V%G97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H86X@)7,@
M9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N(@IM<V=S='(@
M(B(*(DOU:6L@:VER:F%D('-I;G4@7"(E<UPB(&MA=7-T87,@;6ES(&]N('9A
M;F5M860@:W5I("5S('#D979A(&MU<W1U=&%T86MS92`B"B)JY.1D879A;'0N
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S
M7VUO;G1H;'DN<&AP.C4Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS
M(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@(B(*(DOU:6L@<V%A9&5T
M=60@:VER:F%D92!K875S=&%D+"!M:7,@;VX@<F]H:V5M(&MU:2`E<R!K=75D
M('9A;F%D+"!K=7-T=71A=&%K<V4N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF;W)M
M870*;7-G:60@(D%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N
M("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("(B"B)+
M]6EK('-A861E='5D(&MI<FIA9&4@:V%U<W1A9"P@;6ES(&]N(')O:&ME;2!K
M=6D@)7,@:W5U9"!V86YA9"P@:W5S='5T871A:W-E+B(*"B,Z(&%C;"YP:'`Z
M.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%L;"!R:6=H=',@;VX@
M9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B!<
M(B5S7"(N(@IM<V=S='(@(DMA=7-T(%PB)7-<(B!N:6UE=&%T:2#\;6)E<B!<
M(B5S7"(M:W,B"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L
M9&5R($-R96%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z-#@*;7-G:60@(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B
M92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B06QT97)N
M871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3@T"FUS9VED(")!;'=A>7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4U-PHC+"!F=7IZ>0IM<V=I9"`B06QW87ES('-A=F4@
M871T86-H;65N=',B"FUS9W-T<B`B3&ES87-I;B!L:7-A;F1I+B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HU,#4*;7-G:60@(B(*(D%N(&5R<F]R(&]C8W5R960@
M=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE
M($E-05`@<V5R=F5R("(*(G-A:60Z("(*;7-G<W1R("(B"@HC.B!L:6(O365S
M<V%G92YP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R
M(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N;W1E+B(*;7-G<W1R
M(")5=64@<VES<V5K86YD92!L:7-A;6ES96P@=&5K:VES('1U;F1M871U('9I
M9V$N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X-PHC+"!F=7IZ>0IM<V=I9"`B
M06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N
M97<@=&%S:RXB"FUS9W-T<B`B575E('-I<W-E:V%N9&4@;&ES86UI<V5L('1E
M:VMI<R!T=6YD;6%T=2!V:6=A+B(*"B,Z(&UE<W-A9V4N<&AP.C4P,"!M86EL
M8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHY"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3@@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(E9A
M<W1A='5D(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I
M9"`B06YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B5F%S=&%T=60@:VER:F%D
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY
M"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(E)A:V5N9&$@9FEL=')E
M:60B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS
M9W-T<B`B4F%K96YD82!F:6QT<F5I9"(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL=&5R(')U
M;&5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`B4F%K96YD82!F:6QT<FET
M('-I<W-E;&]G:6UI<V5L+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('=H
M96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS9W-T<B`B4F%K96YD82!F
M:6QT<FET(&MI<FIA:V%S=&D@=N1R<VME;F1A;6ES96PB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PHC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E
M;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(DMA<R!O;&5D(&MI;F1E
M;"!E="!S;V]V:60@<V5D83\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4
M:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:G,Z-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(&1O('1H:7,_(@IM<V=S='(@(DMA<R!O;&5D(&MI;F1E;"!E="!S;V]V:60@
M<V5D83\B"@HC.B!M97-S86=E+G!H<#HT,#<@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S
M='(@(DMA<R!O;&5D(&MI;F1E;"!E="!S;V]V:60@;F5E9"!K:7)J860@2L3$
M1$%604Q4(&MU<W1U=&%D83\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z
M,C$U"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B
M2V%S(&]L960@:VEN9&5L(&5T('-O;W9I9"!N965D(&MI<FIA9"!*Q,1$059!
M3%0@:W5S='5T861A/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C,Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@
M=&AI<R!F;VQD97(_(@IM<V=S='(@(DMA<R!O;&5D(&MI;F1E;"!E="!S;V]V
M:60@<V5L;&4@:V%U<W1A('3\:&IE;F1A9&$_(@H*(SH@;&EB+TE-4"YP:'`Z
M.3<S"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`B2V%S(&]L960@:VEN
M9&5L(&5T('-O;W9I9"!S96QL92!K875S=&$@=/QH:F5N9&%D83\B"@HC.B!L
M:6(O24U0+G!H<#HY-C8*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`B
M2V%S(&]L960@:VEN9&5L(&5T('-O;W9I9"!S96QL92!K875S=&$@=/QH:F5N
M9&%D83\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,L
M(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N
M96YT;'D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R(")+87,@;VQE
M9"!K:6YD96P@970@<V]O=FED(&YE960@:VER:F%D($K$Q$1!5D%,5"!K=7-T
M=71A9&$_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z
M.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*(RP@9G5Z
M>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI
M<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R(")+87,@;VQE9"!K:6YD
M96P@970@<V]O=FED('-E;&QE(&MA=7-T82!T_&AJ96YD861A/R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"B,L(&9U>GIY"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S
M<&%M/R(*;7-G<W1R(")+87,@;VQE9"!K:6YD96P@970@<V]O=FED('-E;&QE
M(&MA=7-T82!T_&AJ96YD861A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,38*;7-G:60@(D%R<FEV86P@5&EM92(*;7-G<W1R(")386%B=6UI<V4@
M865G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,0IM<V=I9"`B07-C
M96YD:6YG(@IM<V=S='(@(DMA<W9A=B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,PIM<V=I9"`B07-K
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4Q.0IM<V=I9"`B071T86-H(@IM<V=S='(@(DQI<V$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S4*(RP@9G5Z>GD*;7-G:60@(D%T
M=&%C:"!&:6QE<R(*;7-G<W1R("),:7-A;F1I9"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0U-@IM<V=I9"`B071T86-H(&$@8V]P>2!O
M9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.0HC+"!F=7IZ
M>0IM<V=I9"`B071T86-H960@1FEL93HB"FUS9W-T<B`B3&ES82(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HT-3$@;&EB+T-O;7!O<V4N<&AP.C4S-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S
M('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,W
M-@IM<V=I9"`B071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E
M<75E<W0@>6]U('-E;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z,38@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:6YC.C$T"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P
M-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY-PIM<V=I9"`B
M071T86-H;65N="(*;7-G<W1R("),:7-A;F0B"@HC.B!C;VUP;W-E+G!H<#HQ
M,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*;7-G:60@(D%T=&%C:&UE;G0@<W1R
M:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#D@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<S"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M,#<S"FUS9VED(")!='1A8VAM96YT<R(*;7-G<W1R("),:7-A;F1I9"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#(*(RP@9G5Z>GD*;7-G:60@
M(D%T=&5N9&5E<R(*;7-G<W1R("),:7-A;F1I9"(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!='1E
M;G1I;VXB"FUS9W-T<B`B5&5G979U<R(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z
M-#0*;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-#`*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@
M2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D
M<F5S<V)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R
M8V5S96QE8W0N:6YC.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B079A:6QA8FQE($%D
M9')E<W,@8F]O:W,Z(@IM<V=S='(@(DMA<W5T871A=F%D(&%A9')E<W-I<F%A
M;6%T=60Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q.0IM<V=I
M9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`B5&%G87-I("5S
M)VDB"@HC.B!T:')E860N<&AP.C$S-R!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8VL@
M=&\@)7,B"FUS9W-T<B`B5&%G87-I("5S)VDB"@HC.B!T:')E860N<&AP.C$S
M-`IM<V=I9"`B0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@B
M"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@
M5&AR96%D($1I<W!L87DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&]R(&UA;&9O<FUE
M9"!R97%U97-T+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!M97-S86=E+G!H<#HR-C8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,C(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR
M,"!L:6(O4V5A<F-H+G!H<#HS-`IM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM<V=I9"`B0F5L
M;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$V"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`B375S="!N:6UE:VER
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,CD*;7-G:60@(D)L;V-K
M(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C
M:69I8V%L;'D@<F5Q=65S=&5D/R(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H
M+G!H<#HT,@IM<V=I9"`B0F]D>2(*;7-G<W1R(")+96AA(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")-
M]6QE;6%D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-PIM<V=I9"`B
M0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,@IM
M<V=I9"`B0U]H87)S970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]F:65L9',N:6YC.C,V"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(P,0IM<V=I9"`B0V%N(&YO="!C
M;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T
M(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY
M("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N
M="`B"B)M86EL8F]X+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR.#0@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V96EM86=E
M+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A
M<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E
M<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(DQO;V)U(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,U"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W)E9&ER96-T+FEN8SHQ,3$*;7-G:60@(D-A;F-E;"!-97-S86=E(@IM<V=S
M='(@(DQO;V)U(&MI<FIA<W0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G
M:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@
M9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(E-E;&QE<W0@:VER:F%S
M="!L;V]B=6UI<V5G82!LY&AE8B!T96UA('-I<W4@:6=A=F5S96MS(&MA;W1S
M:2XB"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E
M+FEN8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM<V=I9"`B0V,B"FUS9W-T<B`B
M2V]O<&EA(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,PIM<V=I
M9"`B(@HB0V5R=&EF:6-A=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I
M;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@(@HB<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Q"B,L
M(&9U>GIY"FUS9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`B27-I:VQI:R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(DUU=61A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(DUU
M=61A(&OU:6LB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.3(*;7-G:60@
M(D-H86YG92!&;VQD97(B"FUS9W-T<B`B375U9&$@:V%U<W1A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B(@HB0VAA
M;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S
M('EO=2!S964@;VX@96%C:"!P86=E(&%N9"`B"B)H;W<@;65S<V%G97,@87)E
M('-O<G1E9"XB"FUS9W-T<B`B(@HB375U9&$@96MR86%N:2!S96%D96ED+"!N
MY&ET96MS(';D<G9I<VME96UI+"!M:71U="!K:7)J82!NY&5D(&MO<G)A9V$@
M(@HB96MR86%N:6P@:F$@:W5I9&%S(&]N(&MI<FIA9"!S;W)T965R:71U9"XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@
M(D-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+B(*;7-G
M<W1R(")-=75D82!P;W-T:7-E<G9E<FD@<V5A9&5I9"XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92P@
M861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD("(*(G)E<&QY('1O('EO=7(@96UA:6PN(@IM<V=S='(@
M(B(*(DUU=61A(&YI;64L(&%A9')E<W-I(&IA(&%L;&MI<FIA(&UI9&$@:6YI
M;65S960@;N1E=F%D(&MU:2!N860@<VEN=2!K:7)J82`B"B)L;V5V860@:F$@
M<V5L;&5L92!V87-T879A9"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#(T"FUS9VED(")#:&%R86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#
M:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(DMO;G1R;VQL
M:2!K87,@:V%U<W1A*&1E*7,@;VX@=75S:2!K:7)J=2(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN
M8SHQ,"!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C$*;7-G
M:60@(D-H96-K(&%L;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@
M;6%I;"!F<F]M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#8S"B,L(&9U>GIY"FUS9VED(")#:&5C:R!S<&5L;&EN9R!B969O<F4@
M<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(DMI<FIA('-A871M:7-E;"!T
M96MK:7,@=FEG83H@)7,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHT"FUS9VED(")#:&]O<V4@06-T:6]N.B(*;7-G<W1R(")686QI('1E
M9V5V=7,Z(@H*(SH@8V]N9FEG+W-E<G9E<G,N<&AP+F1I<W0Z,3@R"B,L(&9U
M>GIY"FUS9VED(")#:&]O<V4@82!M86EL('-E<G9E<CHB"FUS9W-T<B`B375U
M9&$@<&]S=&ES97)V97)I('-E861E:60N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,3<*
M;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@
M=&AE(')I9VAT.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*(RP@9G5Z
M>GD*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(E9A;&D@=&5G
M979U<SHB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M-#D*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O
M('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(E9A;&D@86%D
M<F5S<VER86%M870@:W5H=2!A861R97-S92!L:7-A9&$N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"B,L(&9U>GIY"FUS9VED
M(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H
M('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B5F%L:2!A861R
M97-S:7)A86UA='5T92!JY')J96MO<F0@;6ED82!K87-U=&%D82!A861R97-S
M:61E(&QE:61M:7-E:W,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E
M<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@
M8V%N('9I97<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O
M=VYL;V%D('1H92!I;6%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP
M:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O
M("5S(&UA;F%G96UE;G0@<&%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<N(@IM<V=S='(@(DMI<FIU=&$@:VER:F%D(&5R86QD:2!A:VYA
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O
M9B!T:&ES(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R871E('=I
M;F1O=RXB"FUS9W-T<B`B2VER:G5T82!K:7)J860@97)A;&1I(&%K;F%S+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E
M;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDU"FUS9VED(")#;&EC:R!H
M97)E('1O(%-(3U<@=&AE($EM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*(RP@9G5Z>GD*;7-G:60@
M(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O
M:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*
M;7-G<W1R("(B"B)+;/5P<V$@_&AE(&]M82!V86QI='5D(&%A9')E<W-I<F%A
M;6%T=2!P96%L(&IA('-I:7,@=F%L:2!K]6EK(';D;&IA9"!M:6QL97-T("(*
M(F]T<VED82XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S$*;7-G
M:60@(D-L:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R
M97-S(&)O;VLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@=&\@4V%V92!3
M+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,`IM<V=I
M9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W
M(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D
M<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C@*
M(RP@9G5Z>GD*;7-G:60@(D-L;W-E(@IM<V=S='(@(DMI<FIU=&$B"@HC.B!C
M;VUP;W-E+G!H<#HX,C@@8V]M<&]S92YP:'`Z,3$T.`IM<V=I9"`B0VQO<V4@
M=&AI<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#(Y"FUS
M9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(DMA=7-T('-U;&5T=60B"@HC
M.B!F;VQD97)S+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E(@IM
M<V=S='(@(E-U;&4@:_5I:R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C,Y"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T<B`B4W5L92!K
M]6EK(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G
M:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S='(@(E-U;&4@:_5I:R!K
M875S=&%D(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS9VED(")#;VQL87!S92!&
M;VQD97(B"FUS9W-T<B`B4W5L92!K875S="(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@26YD:6-A=&]R.B`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P,PIM<V=I
M9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S8Y"B,L(&9U>GIY"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B
M2VER:G5T82(*"B,Z(&-O;7!O<V4N<&AP.C@R-R!C;VUP;W-E+G!H<#HQ,30W
M"B,L(&9U>GIY"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S<V%G92(*;7-G
M<W1R(")+:7)J82!K;V]S=&%M:6YE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0S-`HC+"!F=7IZ>0IM<V=I9"`B0V]M<&]S92!M97-S86=E<R!I;B!A
M('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B2VER:G5T82!K:7)J860@97)A
M;&1I(&%K;F%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G
M:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D
M969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED
M(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PHC+"!F=7IZ>0IM
M<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+B(*;7-G<W1R
M(")-=75D82!P;W-T:7-E<G9E<FD@<V5A9&5I9"XB"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C,W,`IM<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-
M05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G
M:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S96%R
M8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE
M8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U("(*
M(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB3>3D<F$@;6EL;&%L(&MO
M;G1R;VQL:61A('5U=&4@:VER:F%D92!S86%B=6UI<W0@:F$@:V%S(&%N9&$@
M<W5L;&4@;>1R:W4@:W5I("(*(FYA9"!S86%B=79A9"XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-CDV"FUS9VED(")#;VYV97)T('1E>'1U86P@96UO
M=&EC;VYS(&EN=&\@9W)A<&AI8V%L(&]N97,_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM<V=I9"`B0V]P>2(*;7-G<W1R
M(")+;W!E97)I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"B,L
M(&9U>GIY"FUS9VED(")#;W!Y('1O(&9O;&1E<B(*;7-G<W1R(")4_&AJ96YD
M82!P<OQG:6MA=7-T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S='(@(M5I9V4B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,30P"FUS9VED(")#;W)R96-T
M960@5&5X="(*;7-G<W1R(")087)A;F1A='5D('1E:W-T(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HS.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S
M(@IM<V=S='(@(D5I(/5N;F5S='5N=60@:W5S='5T861A(&MI<FIU("5S+7-T
M.B`E<R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C0P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@
M)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B16D@]6YN97-T=6YU
M9"!K=7-T=71A9&$@:VER:G4@)7,M<W0Z("5S(@H*(SH@;&EB+U-E<W-I;VXN
M<&AP.C,Q.`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&5X96-U=&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`B2&]O;&1U<W3V]F0B"@HC
M.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-30*;7-G:60@(D-O=6QD(&YO
M="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!-4RU43D5&
M(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z
M:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S
M=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]397-S:6]N+G!H<#HR-S,*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!N86UE<W!A8V4@:6YF;W)M871I;VX@9G)O;2!)34%0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS,30@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L+FEN8SHS.0HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,38P"FUS9VED(")#<F5A=&4B"FUS9W-T
M<B`B575S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM
M<V=I9"`B0W)E871E($9O;&1E<B(*;7-G<W1R("),;V\@:V%U<W0B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"B,L(&9U>GIY"FUS9VED(")#<F5A
M=&4@2V5Y<R(*;7-G<W1R(")5=7,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!6:7)T=6%L($9O
M;&1E<B(*;7-G<W1R("),;V\@:V%U<W0B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W
M($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(@IM
M<V=S='(@(DQO;R!U=7,@<'+\9VEK875S="(*"B,Z('1E;7!L871E<R]P<F5F
M<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S
M96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E
M<B(*;7-G<W1R("),;V\@=75S(&UU<W1A;F1I=&4@:V%U<W0B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(V('1E;7!L871E<R]P
M<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#(*;7-G:60@(D-R96%T92!A(&YE
M=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(DQO;R!U=7,@<V%A9&5T=60@
M:VER:F%D92!K875S="(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C
M="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR-`IM
M<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R("),;V\@
M=75S('!R_&=I:V%U<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X
M"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE
M('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*
M(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`B(@HB3&]O(&9I;'1R965R:6UI
M<W)E96=L:60@970@:V]R<F%S=&%D82!O;6$@<V%A8G5V870@<&]S=&DL('-O
M<G1E97)I9&$@<V5E("(*(FMA=7-T861E<W-E(&IA(&MU<W1U=&%D82!RY&UP
M<W!O<W0N(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T
M"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T
M<B`B3&]O('5U<R!S86%D971U9"!K:7)J861E(&MA=7-T(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0T.0IM<V=I9"`B0W)E871E('-T871I;VYE<GD@
M86YD(&9O<FT@<F5S<&]N<V5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A
M8V-E<W,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-0IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN
M9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B0W5S=&]M
M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R(")-Y.1R82!K=6ED87,@
M<V%A=&$@:VER:G4@:F$@:W5H=2!S86QV97-T861A(&UU<W1A;F1E:60N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB
M"FUS9W-T<B`B2V]R<F%L9&$@=/9I9"!M:61A('1E:&%K<V4@)7,M:2!S:7-S
M96QO9VEM:7-E;"!A=71O;6%A='-E;'0N(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B1&%T
M7V4B"FUS9W-T<B`B2W5U<.1E=B(*"B,Z(&UE<W-A9V4N<&AP.C(V,B!T:')E
M860N<&AP.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R(")+=75PY&5V(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5C;&EN960B"FUS9W-T<B`B2W5S='5T871U9"(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HR-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I
M9"`B1&5F875L="(*;7-G<W1R(")+=7-T=71A(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C$X"FUS9VED(")$969A=6QT
M(%-E87)C:"!&:65L9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3(S"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM
M<V=S='(@(E9A:6MI;6ES:2!S;W)T965R:6UI;F4Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDS,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C
M=&EO;CHB"FUS9W-T<B`B5F%I:VEM:7-I('-O<G1E97)I;6ES92!S=75N9#HB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U"B,L(&9U>GIY"FUS
M9VED(")$96QE9V%T960B"FUS9W-T<B`B2W5S='5T871U9"(*"B,Z(&9O;&1E
M<G,N<&AP.C0Q.2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C@*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-#0@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ,`HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR.`HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D1E;&5T92(*;7-G<W1R(")+=7-T
M=71A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@
M(D1E;&5T92!#=7)R96YT($ME>7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS
M*2(*;7-G<W1R(")+=7-T=71A(&MA=7-T*&%D*2(*"B,Z(&9O;&1E<G,N<&AP
M.C(X-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E<G,B
M"FUS9W-T<B`B2W5S='5T82!K875S="AA9"DB"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!3
M=&%T:6]N97)Y(@IM<V=S='(@(DMU<W1U=&$@:V%U<W0H860I(@H*(SH@9F]L
M9&5R<RYP:'`Z-#$Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@5FER='5A;"!&
M;VQD97(B"FUS9W-T<B`B2W5S='5T82!K875S="AA9"DB"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#,*;7-G:60@(D1E;&5T92!F971C
M:&5D(&UE<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R.`IM<V=I9"`B1&5L971E
M(&9R;VT@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V.`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&]L9"!L:6YK
M960@871T86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R
M(")+=7-T=71A('9A;F%D('-A861E='5D(&MI<FIA9&4@:V%U<W1A9"!K=74@
M86QG=7-E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3`*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G
M:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")+=7-T=71A('9A;F%D('-A861E
M='5D(&MI<FIA9&4@:V%U<W1A9"!K=74@86QG=7-E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M
M(&UE<W-A9V5S(@IM<V=S='(@(DMU<W1U=&$@:VER:F%D(@H*(SH@;65S<V%G
M92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<T,"!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(P"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHX"FUS9VED(")$96QE
M=&5D(@IM<V=S='(@(DMU<W1U=&%T=60B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@
M(DMU<W1U=&%T=60@:VER:F%D(@H*(SH@8V]M<&]S92YP:'`Z,S`W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT
M(%PB)7-<(BXB"FUS9W-T<B`B3&ES86YD(&MU<W1U=&%T=60N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@36]V
M:6YG($UE<W-A9V5S(@IM<V=S='(@(DMI<FIA9&4@:W5S='5T86UI;F4@:F$@
M_&UB97)T]7-T;6EN92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M.3(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-30P"FUS9VED(")$96YY(')E<75E<W0@9F]R
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3,R"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@
M(DMA:&%N978B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI
M;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V.0HC+"!F=7IZ>0IM
M<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B375U9"!HY.1L97-T=7-E9"(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW-PIM<V=I9"`B1&5T86EL<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C<W"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B"FUS9W-T
M<B`B3N1I=&$@86QL:VER:F$@='5H;6EL="(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@
M(D5K<F%A;FD@<V5A9&5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W
M.0IM<V=I9"`B1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A
M(&UE<W-A9V4_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.#8*;7-G:60@(D1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3(*(RP@9G5Z>GD*
M;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I
M;#\B"FUS9W-T<B`B06YN82!MY')K=2!U=71E(&MI<FIA9&4@<V%A8G5M:7-E
M<W0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES
M<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I
M9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE
M;G5B87(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS
M9W-T<B`B16MR86%N:2!S96%D960B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B1&\@
M3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`BQ')A
M(&MO;G1R;VQL:2!K875S=&$H9&4I<R!U=71E(&MI<FIA9&4@;VQE;6%S;VQU
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T
M(&=E;F5R871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z(&QI8B])35`N<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O
M(&]P96X@=&AA="!F;VQD97(_(@IM<V=S='(@(DMA<R!T86AA9"!A=F%D82!S
M96QL92!K875S=&$_(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M,S(*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R
M-@IM<V=I9"`B1&]N92(*;7-G<W1R(")686QM:7,B"@HC.B!L:6(O34E-12]#
M;VYT96YT<RYP:'`Z,3DR"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D
M("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VAE861E<G,N:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@071T
M86-H;65N=',@*&EN("YZ:7`@9FEL92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C`*;7-G:60@(D1O=VYL;V%D($9O
M;&1E<BAS*2(*;7-G<W1R(")+;W!E97)I(&MA=7-T*&%D*2(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")$
M;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(*;7-G<W1R(")+;W!E
M97)I(&MA=7-T*&%D*2(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*
M;7-G:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(B(*"B,Z
M(&UE<W-A9V4N<&AP.C4P,2!M86EL8F]X+G!H<#HW,3D@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C(R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z-#$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHY"FUS9VED
M(")$<F%F="(*;7-G<W1R(")-=7-T86YD(@H*(SH@9F]L9&5R<RYP:'`Z,SDR
M"B,L(&9U>GIY"FUS9VED(")$<F%F="!F;VQD97(B"FUS9W-T<B`B375S=&%N
M9&ET92!K875S=#HB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T
M+FEN8SHR,PIM<V=I9"`B1')A9G1S(&9O;&1E<CHB"FUS9W-T<B`B375S=&%N
M9&ET92!K875S=#HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`X"B,L
M(&9U>GIY"FUS9VED(")%+6UA:6P@061D<F5S<R(*;7-G<W1R(")386%T:F$@
M86%D<F5S<R(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,#D*;7-G:60@(D5.1"(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-`IM
M<V=I9"`B15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E
M<F5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S='(@
M(E!A<F%N9&$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*
M(RP@9G5Z>GD*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(DUU<W0@
M;FEM96MI<FDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*
M(RP@9G5Z>GD*;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R(")&:6QT<FED
M(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHQ-@IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F
M;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@
M(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B4&%R86YD82!F:6QT<F5E
M<FEM:7-R965G;&5I9"(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHQ,PIM<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(*;7-G<W1R(")0
M87)A;F1A(&9I;'1R965R:6UI<W)E96=L96ED(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@V,0IM<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O
M<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"B,L(&9U>GIY"FUS
M9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(E!A<F%N9&$@9FEL
M=')E97)I;6ES<F5E9VQE:60B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(S.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R(")386%T:F$@86%D<F5S<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV
M-3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE
M<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(DOU:6L@:VER:F%D("5S+7-T('-A
M:60@:W5S='5T871U9"XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHR,@IM<V=I9"`B16UP='D@1F]L9&5R*',I(@IM<V=S='(@(DMU<W1U
M=&$@:V%U<W0H860I(@H*(SH@9F]L9&5R<RYP:'`Z,C@V"B,L(&9U>GIY"FUS
M9VED(")%;7!T>2!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(DMU<W1U=&$@
M:V%U<W0H860I(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,SD*;7-G:60@(D5M<'1Y(%1R87-H(&9O;&1E<B(*;7-G<W1R(")4_&AJ96YD
M82!P<OQG:6MA=7-T(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"FUS9VED(")%;7!T
M>2!?4W!A;2(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HY-C8*(RP@9G5Z
M>GD*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R(")4_&AJ96YD82!P<OQG
M:6MA=7-T(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$@=&5M<&QA=&5S
M+W!G<"]N;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L92!01U`@9G5N8W1I
M;VYA;&ET>3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHQ('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C8*;7-G:60@
M(D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q,0IM<V=I9"`B16YA8FQE(&UE<W-A
M9V4@<')E=FEE=W,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0T,@IM<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$W(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3<*;7-G:60@(D5N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S@T"FUS9VED(")%;F0@9F]R=V%R
M9&5D(&UE<W-A9V4B"FUS9W-T<B`B161A<W1A='5D(&MI<FIA(&SU<'`B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,S0Q"B,L(&9U>GIY"FUS9VED(")%;F0@;65S
M<V%G92(*;7-G<W1R(")686YA9"!K:7)J860B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G
M92!F<F]M("5S(@IM<V=S='(@(D5D87-T871U9"!K:7)I("5S)VQT(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.CD*(RP@9G5Z>GD*
M;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E
M<B(*;7-G<W1R(")3:7-E<W1A('5U92!P<OQG:6MA=7-T82!N:6UI(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B16YT
M97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T
M<B`B4VES97-T82!U=64@;75S=&%N9&ET92!K875S=&$@;FEM:2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@(D5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM
M<V=S='(@(E-I<V5S=&$@=75E('-A861E='5D(&MI<FIA9&4@:V%U<W1A(&YI
M;6DB"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.CD*;7-G
M:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(B
M"FUS9W-T<B`B4VES97-T82!U=64@<'+\9VEK875S=&$@;FEM:2(*"B,Z(&QI
M8B]396%R8V@N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")%;G1I<F4@365S<V%G
M92(*;7-G<W1R(")3=75N82!K:7)I(&5D87-I(@H*(SH@;65S<V%G92YP:'`Z
M,3DT(&-O;7!O<V4N<&AP.C$Q,S0@=&AR96%D+G!H<#HW,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")<(B5S7"(@
M;&ES871I(&%A9')E<W-I<F%A;6%T=7-S92(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C,X-@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N
M("5S(#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HS,#D@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,0HC+"!F=7IZ
M>0IM<V=I9"`B179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@
M(DMA=7-T(%PB)7-<(B!O;B!JY.1D879A;'0@:W5S='5T871U9"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@R"FUS9VED(")%=F5R>2`Q-2!M:6YU
M=&5S(@IM<V=S='(@(DEG82`Q-2!M:6YU=&D@=&%G86YT(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<W.0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*
M;7-G<W1R("))9V$@,S`@<V5K=6YD:2!T86=A;G0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@Q"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T
M<B`B26=A(#4@;6EN=71I('1A9V%N="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.#,*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("))9V$@
M<&]O;&4@='5N;FD@=&%G86YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<X,`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(DMO<F0@;6EN=71I
M<R(*"B,Z(&9O;&1E<G,N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B17AP86YD
M(@IM<V=S='(@(D%V82!K]6EK(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`B079A(&OU
M:6LB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.`IM<V=I
M9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(D%V82!K]6EK(&MA=7-T
M860B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X<&%N9"!&;VQD97(B
M"FUS9W-T<B`B079A(&MA=7-T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU
M,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(DQA:&5N9&$@;FEM960B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V,PIM<V=I9"`B17AP86YD
M(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN
M('1H92!B86-K9W)O=6YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3@P"B,L(&9U>GIY"FUS9VED(")%>'!A;F0@=&AE(&5N=&ER
M92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_
M(@IM<V=S='(@(DMA=7-T861E('9A871E<R!A=F$@=F%I:VEM:7-I('1E<G9E
M(&MA=7-T87!U=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C$T-"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ.30*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C0U('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHQ,#$*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9&EN
M9R(*;7-G<W1R(")!=F$@:_5I:R(*"B,Z(&QI8B])35`N<&AP.CDX-"!L:6(O
M24U0+G!H<#HY.#8*(RP@9G5Z>GD*;7-G:60@(D9?971C:"!-86EL(@IM<V=S
M='(@(E;D<G-K92!P;W-T(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C
M:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*(RP@9G5Z
M>GD*;7-G:60@(D9E=&-H($UA:6PB"FUS9W-T<B`B5N1R<VME('!O<W0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8Y"B,L(&9U>GIY"FUS9VED(")&
M971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")+:7)J
M=71A(&MI<FIA9"!E<F%L9&D@86MN87,N(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C0V"B,L(&9U>GIY"FUS9VED(")&971C:"!M97-S
M86=E<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(E)A:V5N9&$@9FEL=')I
M="!S:7-S96QO9VEM:7-E;"XB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G
M97,@9G)O;2`E<R(*;7-G<W1R(")+]6EK(&MI<FIA9"`E<RUS="!S86ED(&MU
M<W1U=&%T=60N(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S
M(@IM<V=S='(@(D5D87-T871U9"!K:7)I("5S)VQT(@H*(SH@;&EB+T9E=&-H
M;6%I;"YP:'`Z,C@U(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM
M86EL+G!H<#HR.#D*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&971C:&UA:6PN<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B1F5T8VAM
M86EL.B!N;R!N97<@;65S<V%G97,N(@IM<V=S='(@(E-U;&QE(&]N("5S('5U
M="!K:7)J82XB"@HC.B!L:6(O24U0+G!H<#HY.3`*(RP@9G5Z>GD*;7-G:60@
M(D9I7VQT97)S(@IM<V=S='(@(D9I;'1R:60B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B1FEL
M=')I9"(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS,0HC+"!F
M=7IZ>0IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B375U9"!S96%D
M960B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0HC+"!F=7IZ
M>0IM<V=I9"`B1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(D9I;'1R965R:6UI
M<W)E96=L:60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`P"B,L(&9U
M>GIY"FUS9VED(")&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI
M='D_(@IM<V=S='(@(D9I;'1R965R:2!K:7)J861E('-I<W4N(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B1FEL=&5R
M('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(D9I;'1E
M<G,B"FUS9W-T<B`B1FEL=')I9"(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO
M=&%C=&EV92YI;F,Z,PIM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*;7-G:60@
M(D9I;F0B"FUS9W-T<B`B3&5I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,#4*(RP@9G5Z>GD*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G
M<W1R(")%<VEM96YE(&QE:&5K_&QG(@H*(SH@;6%I;&)O>"YP:'`Z,S0U"FUS
M9VED(")&:7)S="!086=E(@IM<V=S='(@(D5S:6UE;F4@;&5H96O\;&<B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@
M(D9O7W)W87)D(@IM<V=S='(@(D5D87-T82(*"B,Z(&9O;&1E<G,N<&AP.C(V
M-B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HU"FUS
M9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B
M"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI
M;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC
M.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHQ
M,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R(")+875S=&%P=74B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B
M1F]L9&5R(%-U;6UA<GDB"FUS9W-T<B`B5F5E8G)U87(B"@HC.B!A8VPN<&AP
M.C(T"FUS9VED(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS
M9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-C(*;7-G:60@(D9O;&1E<B!U<V4@
M:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-CD*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN
M('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM
M<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C<X,"!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,34*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B161A<W1A
M(@H*(SH@8V]M<&]S92YP:'`Z-S8U"FUS9VED(")&;W)W87)D.B(*;7-G<W1R
M(")%9&%S=&$Z(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,V.0HC+"!F=7IZ>0IM
M<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B161A<W1A='5D(&MI
M<FIA(&SU<'`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8W"B,L('!H<"UF;W)M
M870*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B
M161A<W1A='5D(&MI<FD@)7,G;'0B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-#@S"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I
M;VXB"FUS9W-T<B`B4V5R=F5R:2!I;F9O(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0Y-`IM<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#@*;7-G:60@(D9R
M964O0G5S>2!297%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT,#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O
M;G-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,C<*(RP@9G5Z>GD*;7-G:60@(D9R;U]M(@IM<V=S='(@
M(DME;&QE;'0B"@HC.B!M97-S86=E+G!H<#HR-C,@=&AR96%D+G!H<#HQ-#D@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.3D*(SH@;&EB+U-E87)C
M:"YP:'`Z,C(*;7-G:60@(D9R;VTB"FUS9W-T<B`B2V5L;&5L="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D<F5S<R(*
M;7-G<W1R(")386%T:F$@86%D<F5S<R(*"B,Z(&-O;7!O<V4N<&AP.C<W-R!C
M;VUP;W-E+G!H<#HW.#$*(RP@9G5Z>GD*;7-G:60@(D9W9#HB"FUS9W-T<B`B
M161A<W1A.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.30*(RP@9G5Z>GD*;7-G:60@
M(D9W9#H@(@IM<V=S='(@(D5D87-T83HB"@HC.B!C;VUP;W-E+G!H<#HQ,CDV
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O<G=A<F1E
M9"!-97-S86=E<R(*;7-G<W1R(")%9&%S=&%T=60@:VER:F$@;/5P<"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.`HC+"!F=7IZ>0IM<V=I9"`B1V5N97)A;"!/<'1I;VYS
M(@IM<V=S='(@(DUU=60@:.3D;&5S='5S960B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M97-S
M86=E<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z
M('1H<F5A9"YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")';R!T;R!-97-S86=E
M(@IM<V=S='(@(DKD<F=M:6YE(&MI<FDB"@HC.B!L:6(O24U0+G!H<#HT.3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O
M:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B3&ES82!A861R97-S:7)A86UA
M='5S<V4@*"5S*2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,S4*;7-G
M:60@(D=R86YT(&%C8V5S<R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU
M-#8@;&EB+T9I;'1E<BYP:'`Z,3`U(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.CDU"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P,B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*
M(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(SH@;&EB+TU)344O5FEE
M=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M-#$X"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C<*
M;7-G:60@(DA%4D4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C,Q(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,3<*
M(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C@P"FUS9VED(")(5$U,
M(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C(U-@IM<V=I9"`B2%1-3"!6
M97)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED
M(")(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V.`IM<V=I9"`B
M2&ED9&5N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-C<*(RP@9G5Z>GD*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE=R(*;7-G
M<W1R(")*=71U;/5N9V$@=F%A9&4B"@HC.B!M86EL8F]X+G!H<#HS-C<*;7-G
M:60@(DAI9&4@1&5L971E9"(*;7-G<W1R(")096ED82!K=7-T=71A='5D(@H*
M(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")(:61E(%5N<W5B<V-R:6)E9"(*
M;7-G<W1R(")096ED82!T96QL:6UA=&$B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N<&AP.C<R-"!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H(%!R:6]R:71Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,PIM
M<V=I9"`B2&EG:&5S="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C@X"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A
M='1A8VAM96YT<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q=6]T
M960@;&EN97,@:6X@82!R97!L>2(*;7-G<W1R(")+=6ED87,@97)I<W1A9&$@
M='-I=&5E<FET=60@=&5K<W1I('9A<W1U<V5S.B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3,T"FUS9VED("))34%0(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(Y"FUS9VED("))34%0("A!=71O($1E
M=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,SDQ"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@4V5R=F5R(&-L
M;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C8@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-3(*;7-G
M:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-PIM
M<V=I9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960I(@IM<V=S='(@(B(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S8X"FUS9VED("))34%0('-E<G9E
M<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,38U(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,30P"FUS9VED("))34%0+"!N;R!43%,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HT.0IM<V=I9"`B24U!4"]03U`S($UA:6P@
M4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HX-C8*;7-G:60@
M(DE.0D]8(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#$Q
M"FUS9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@;75S="!H879E('1H
M92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,@HC
M+"!F=7IZ>0IM<V=I9"`B268@>6]U(&-O;G1I;G5E+"!A;&P@;65S<V%G97,@
M:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E(&QO<W0A(@IM<V=S='(@(DOU:6L@
M:VER:F%D(&MA=7-T861E<R!LY&AE=F%D(&MA;W1S:2$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G
M<W1R("))9VYO<F5E<FDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z.#,*;7-G:60@(DEG;F]R92!!;&PB"FUS9W-T<B`B26=N;W)E97)I
M(&OU:6MI(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC
M.C@*;7-G:60@(DEM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+VEM<&]R="YI;F,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="(*;7-G
M<W1R(")4Y&AT:7,B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z.#4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-0HC+"!F=7IZ
M>0IM<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R(")4Y&AT:7,B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3,Y"B,L(&9U>GIY"FUS9VED("));7!O<G0@
M2V5Y<&%I<B(*;7-G<W1R(")4Y&AT:7,B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($UE<W-A
M9V5S(@IM<V=S='(@(E3D:'1S860@:VER:F%D(@H*(SH@<&=P+G!H<#HT,@IM
M<V=I9"`B26UP;W)T(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L($-E
M<G1I9FEC871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T
M7VME>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'
M4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC
M.C0*;7-G:60@(DEM<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#`@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS9VED("));7!O<G0@4'5B;&EC
M($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I9"`B
M26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(B(*"B,Z('-M:6UE
M+G!H<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O
M<G0@;6)O>"!&:6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T(&UB
M;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`B(@H*(SH@;65S
M<V%G92YP:'`Z-3`R(&UA:6QB;W@N<&AP.C<S-"!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,S
M"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM<V=I9"`B26UP
M;W)T86YT(@IM<V=S='(@(E3D:'1I<R(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-#<*;7-G:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R
M(")4Y&AT<V%D(&MI<FIA9"(*"B,Z(&9O;&1E<G,N<&AP.C$V-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@9G)O
M;2`E<RXB"FUS9W-T<B`B2_5I:R!K:7)J860@)7,M<W0@<V%I9"!K=7-T=71A
M='5D+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-S,*;7-G:60@
M(DEN(%!R;V-E<W,B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S@T(&QI
M8B]&;VQD97(N<&AP.C@V(&QI8B]&;VQD97(N<&AP.C(Q-"!L:6(O24U0+G!H
M<#HS,3,*(SH@;&EB+TE-05`O5')E92YP:'`Z,3$T(&QI8B])34%0+U1R964N
M<&AP.C(Q.0IM<V=I9"`B26YB;W@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y,@HC+"!F=7IZ>0IM<V=I9"`B26YC;'5D92!A(&)R
M:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A(')E<&QY/R(*;7-G<W1R
M(")6]71A('9A<W1U<V5S<V4@86QG;F4@:VER:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.#<*;7-G:60@(DEN8VQU9&4@;W)I9VEN86P@;65S<V%G
M92!I;B!A(')E<&QY/R(*;7-G<W1R(")6]71A('9A<W1U<V5S<V4@86QG;F4@
M:VER:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$S,`HC+"!F=7IZ>0IM<V=I
M9"`B26YF;R(*;7-G<W1R("))9VYO<F5E<FDB"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I
M9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O
M;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ
M<SHY.`HC+"!F=7IZ>0IM<V=I9"`B26YL:6YE(@IM<V=S='(@(D5I(&UI9&%G
M:2XN+B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS
M9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@
M4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T
M(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED("));G-E<G0@
M4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE
M8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*"B,Z(&UA:6QB
M;W@N<&AP.C4X-"!M86EL8F]X+G!H<#HV,C8*;7-G:60@(DEN=F%L:60@061D
M<F5S<R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C,P
M-PIM<V=I9"`B26YV86QI9"!296UO=&4@36%I;&)O>"(*;7-G<W1R("(B"@HC
M.B!C;VUP;W-E+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI
M9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R("(B
M"@HC.B!S;6EM92YP:'`Z.#(@<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K
M97DB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ.38*;7-G:60@(DEN=F%L:60@
M<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!P9W`N
M<&AP.C$W,0IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME
M>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHQ,@IM<V=I9"`B26YV97)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B2T(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T
M:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS
M9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T
M;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E;F5R871I;VX_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S4@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED(")+97D@:6UP;W)T(&ES
M(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N
M('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P+FEN8SHS.0IM<V=I9"`B
M(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A
M9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C;VYT86-T<RXB
M"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME>2!S=6-C97-S
M9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,38*;7-G:60@(DQA
M;F=U86=E(@IM<V=S='(@(DME96PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3`V"B,L(&9U>GIY"FUS9VED("),87-T($UA:6QB;W@@4&%G92(*;7-G
M<W1R(")6:6EM86YE(&QE:&5K_&QG(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"FUS
M9VED("),87-T(%!A9V4B"FUS9W-T<B`B5FEI;6%N92!L96AE:_QL9R(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X.0HC+"!F=7IZ>0IM
M<V=I9"`B3&E?;FL@071T86-H;65N=',B"FUS9W-T<B`B3&ES86YD:60B"@HC
M.B!A='1A8VAM96YT+G!H<#HS-"!L:6(O0V]M<&]S92YP:'`Z,3`V,PIM<V=I
M9"`B3&EN:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B:61D96XN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#@P"B,L('!H<"UF;W)M870*;7-G
M:60@(DQI;FMS('=I;&P@97AP:7)E(&]N("5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@R"FUS9VED("(B"B),:7-T(&%L;"!C
M;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF
M(&1I<V%B;&5D+"!Y;W4@=VEL;"`B"B)O;FQY('-E92!C;VYT86-T<R!T:&%T
M('EO=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#4*;7-G:60@(DQI<W1I;F<@:6X@=&AE
M($AE861E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@(DQO8V%L($UA:6QB;W@Z(@IM
M<V=S='(@(DMI<FIA:V%S="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-S0*(RP@9G5Z>GD*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E1E9V5V
M=7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R-0IM<V=I9"`B
M3&]G(&EN(@IM<V=S='(@(DQO9VD@<VES<V4B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E
M<R(*;7-G<W1R("),;V=I('-I<W-E("5S)VDB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$S-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T
M<B`B3&]G:2!S:7-S92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM
M<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5/;V9"!S:7-S96QO9VEM:7-E
M;"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-@IM<V=I
M9"`B3&]W(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X
M+G!H<#HW,C<@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I
M9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(Y-PIM<V=I9"`B3&]W97-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#0*(RP@9G5Z
M>GD*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM<V=S='(@(D9I;'1R:60B"@HC
M.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*(RP@9G5Z>GD*
M;7-G:60@(DUA:6PB"FUS9W-T<B`B2VER:F%K87-T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDV"B,L(&9U>GIY"FUS9VED(")-86EL(%!R979I97=S
M(@IM<V=S='(@(D9I;'1R:60B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R
M:79E<E]S96QE8W0N:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O
M(&-O;FYE8W0@=&\Z(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM
M<V=I9"`B36%I;&)O>"(*;7-G<W1R(")+:7)J86MA<W0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$Q"B,L(&9U>GIY"FUS9VED(")-86EL8F]X(&%N
M9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D5K<F%A;FD@<V5A
M9&5D(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G
M:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS
M9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED
M(")-87)K(&%S.B(*;7-G<W1R(")!=')I8G5U9&ED.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L
M<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`B
M5.1H:7-T82!E<FEN979A9"!T<VET965R:6UI<W1A<V5M960@97)I;F5V82!V
MY')V:6=A(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0P
M"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3@*;7-G:60@
M(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]H96%D97(N:6YC.C0V"FUS9VED(")-871C:"!!;&P@475E<FEE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z
M-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3,*(RP@9G5Z>GD*;7-G:60@
M(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM<V=S='(@(DQI<V%N9"(*"B,Z
M(&QI8B]A<&DN<&AP.C<Y"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!&;VQD
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0Y-`IM<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@871T86-H;65N=',@
M<F5A8VAE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#@Y"FUS9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@
M<VEZ92!R96%C:&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C(V"FUS9VED(")-965T:6YG($-A;F-E;&QA=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<U"B,L(&9U
M>GIY"FUS9VED(")-965T:6YG($EN9F]R;6%T:6]N(@IM<V=S='(@(E-E<G9E
M<FD@:6YF;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G
M:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I9"`B365E=&EN9R!297!L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DX"FUS9VED
M(")-965T:6YG(%5P9&%T92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C`S"FUS9VED(")-965T:6YG(%5P9&%T92!297%U97-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,*
M(RP@9G5Z>GD*;7-G:60@(DUE;G4@1F]L9&5R($QI<W0B"FUS9W-T<B`B079A
M(&MA=7-T(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0HC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92(*;7-G<W1R(")MY')G:71U9"!K:7)J860@:V%U<W1A.B(*
M"B,Z(&-O;7!O<V4N<&AP.C4V,"!C;VUP;W-E+G!H<#HU.#<@8V]M<&]S92YP
M:'`Z-C0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G
M92!#;VUP;W-I=&EO;B(*;7-G<W1R(")+:7)J82!K;V]S=&%M:6YE(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E
M(@IM<V=S='(@(DMI<FIA(&MU=7#D978B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDU(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#,*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@3W!T:6]N<R(*;7-G<W1R(")M
MY')G:71U9"!K:7)J860@:V%U<W1A.B(*"B,Z('-E87)C:"YP:'`Z,S$R"FUS
M9VED(")-97-S86=E(%-E87)C:"(*;7-G<W1R(")/='-I(&MI<FIA(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I9"`B365S<V%G92!3:7IE
M(@IM<V=S='(@(DMI<FIA('-U=7)U<R(*"B,Z(&UE<W-A9V4N<&AP.C,X-`IM
M<V=I9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`B2VER:F$@86QG=&5K<W0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(DUE<W-A9V4@
M5FEE=VEN9R(*;7-G<W1R(")+:7)J82!V86%T86UI;F4B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B"FUS
M9W-T<B`B2VER:F$@871R:6)U=61I9"(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z.#,*;7-G:60@(DUE<W-A9V4@9F]L9&5R<R(*;7-G<W1R(")+
M875S=&%D(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B365S<V%G92!F<F]M("5S(@IM<V=S='(@(DMA=7-T
M860B"@HC.B!M86EL8F]X+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(DUE<W-A
M9V4@:&%S(&%T=&%C:&UE;G1S(@IM<V=S='(@(DQI<V%N9"!K=7-T=71A='5D
M+B(*"B,Z(&UA:6QB;W@N<&AP.C8U.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G
M92!I<R!E;F-R>7!T960B"FUS9W-T<B`B5N1L:F%D(@H*(SH@;6%I;&)O>"YP
M:'`Z-C4S"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G
M<W1R(")6Y&QJ860B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z
M,S,*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R(")+
M:7)J82!K=75PY&5V(@H*(SH@8V]M<&]S92YP:'`Z.#(T(&-O;7!O<V4N<&AP
M.C@S.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!R961I<F5C=&5D('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B2VER:2!S86%D971I('1E96QE(&MU:60@96D@
M<V%L=F5S=&%T=60B"@HC.B!C;VUP;W-E+G!H<#HQ,#@T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B
M=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@(DMI<FD@<V%A9&5T:2!T965L
M92!K=6ED(&5I('-A;'9E<W1A='5D(@H*(SH@8V]M<&]S92YP:'`Z,3$T,R!C
M;VUP;W-E+G!H<#HQ,34X"B,L(&9U>GIY"FUS9VED(")-97-S86=E('-E;G0@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")+:7)I('-A861E=&D@=&5E;&4@:W5I
M9"!E:2!S86QV97-T871U9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-#$*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I
M97<N(@IM<V=S='(@(DMO<G)A9V$@;N1H=&%V871E(&MI<FIA9&4@87)V(&QE
M:&5K_&QJ96PN(@H*(SH@;6%I;&)O>"YP:'`Z,S(R"FUS9VED(")-97-S86=E
M<R!T;R(*;7-G<W1R(")MY')G:71U9"!K:7)J860@:V%U<W1A.B(*"B,Z('1E
M;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I9"`B36]D:69Y(@IM<V=S='(@
M(DUU=61A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHQ,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E('1H86X@;VYE(&%D9')E<W,@9F]U
M;F0@9F]R(&9I96QD(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E(@IM<V=S='(@(E3U<W1A
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$V"B,L
M(&9U>GIY"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B;&EI9W4@86QL82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3@*;7-G:60@(DUO=F4@<W!A
M;2!M97-S86=E<R!T;R!S<&%M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G
M97,@=&\@24Y"3U@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C4P"B,L(&9U>GIY"FUS9VED(")-;W9E('1O(&9O;&1E<B(*;7-G
M<W1R(")V86QI(&MA=7-T(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S$T"B,L(&9U>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@
M(FQI:6=U(/QL97,B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N
M<&AP.C$R-PIM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@
M(B(*"B,Z('1H<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*
M;7-G:60@(DUU;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R(")+:7)J82!V
M86%T86UI;F4B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E
M;&5C="YI;F,Z-0IM<V=I9"`B3D].12(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED(").
M3U1%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@
M(DYA;64B"FUS9W-T<B`B3FEM:2(*"B,Z('!G<"YP:'`Z,3$P"FUS9VED(").
M86UE(&%N9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-S@*(RP@9G5Z>GD*;7-G
M:60@(DYE961S($%C=&EO;B(*;7-G<W1R(")496=E=G5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@R
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S@*;7-G:60@(DYE=F5R(@IM
M<V=S='(@(DUI='1E(&MU;F%G:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-C`*(RP@9G5Z>GD*;7-G:60@(DYE=F5R('-A=F4@871T86-H;65N=',B
M"FUS9W-T<B`B3&ES86YD(&MU<W1U=&%T=60N(@H*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$R-`IM<V=I9"`B3F5W(@IM<V=S='(@(E5U<R(*"B,Z(&QI
M8B])35`N<&AP.C4V,PHC+"!F=7IZ>0IM<V=I9"`B3F5W($9O;&1E<B(*;7-G
M<W1R(")!=F$@:V%U<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#@*
M;7-G:60@(DYE=R!-86EL(@IM<V=S='(@(E;D<G-K92!P;W-T(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C$Y(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N
M<&AP.C,S"B,L(&9U>GIY"FUS9VED(").97<@365S<V%G92(*;7-G<W1R(")*
MY')G;6EN92!K:7)I(@H*(SH@;6%I;&)O>"YP:'`Z-S<V(&QI8B]-24U%+TAE
M861E<G,N<&AP.C$Y,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B575E9"!K:7)J860B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Y"FUS9VED(").97<@;65S<V%G97,B
M"FUS9W-T<B`B575E9"!K:7)J860B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z,3,S"FUS9VED(").97AT(@IM<V=S='(@(DKD<F=M:6YE
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHS
M,PIM<V=I9"`B3F5X="!-97-S86=E(@IM<V=S='(@(DKD<F=M:6YE(&MI<FDB
M"@HC.B!M86EL8F]X+G!H<#HS-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R
M(")*Y')G;6EN92!L96AE:_QL9R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS9VED
M(").;R(*;7-G<W1R(")%:2(*"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO
M($-E<G1I9FEC871E(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3D*;7-G
M:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X
M+G!H<#HS-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO($UE<W-A
M9V5S(@IM<V=S='(@(E5U960@:VER:F%D(@H*(SH@<&=P+G!H<#HQ,S<*;7-G
M:60@(DYO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S
M;VYA;"!#97)T:69I8V%T92!0<F5S96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M86EL8F]X+G!H<#HS,CD*(RP@9G5Z>GD*;7-G:60@(DYO(%!R979I97<@5&5X
M="(*;7-G<W1R(")087)A;F1A='5D('1E:W-T(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHQ-0IM<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$U,0IM<V=I9"`B3F\@4R]-24U%
M('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]T;F5F+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B3F\@871T86-H
M;65N=',@9F]U;F0N(@IM<V=S='(@(DQI<V%N9&ED(@H*(SH@;&EB+T-R>7!T
M+U--24U%+G!H<#HQ-#`*;7-G:60@(DYO(&5M86EL(&EN9F]R;6%T:6]N(&QO
M8V%T960@:6X@=&AE('!U8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z(&%C;"YP
M:'`Z-S(@86-L+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R('-E
M;&5C=&5D+B(*;7-G<W1R(")K875S="!P;VQE('9A;&ET=60B"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD97)S(&%R92!B
M96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L:6(O1F]L9&5R+G!H
M<#HU-3`*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I960B"FUS9W-T
M<B`BW&AT:VD@:V%U<W1A(&5I(&WDY')A='5D(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$T-PHC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H
M(&YE=R!M97-S86=E<R(*;7-G<W1R(")-:71T92!K=7-T=71A='5D(&MI<FIA
M9"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G
M:60@(DYO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`B
M36ET=&4@:W5S='5T871U9"!K:7)J860B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,S(U"B,L(&9U>GIY"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G
M<W1R(")T]7-T82!K:7)I(&MA=7-T82(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS
M-S$*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S
M96%R8V@N(@IM<V=S='(@(E!O;&4@_&AT:VD@<V]B:79A="!K:7)J82(*"B,Z
M('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K
M97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,38U"FUS9VED
M(").;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C(P,0IM<V=I9"`B3F\@<&5R<V]N86P@4R]-
M24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<W!E
M;&QI;F<N<&AP.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M
M(&-O;F9I9W5R960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM
M<V=S='(@(DMI<FIA=FEG=2!E:2!O;&4B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G
M<W1R(")3;V]V:71U<VD@96D@;VQE(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HU-C0*;7-G:60@(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I8V%T:6]N
M(&UE=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@86-L+G!H
M<#HV."!A8VPN<&AP.CDT"B,L(&9U>GIY"FUS9VED(").;R!U<V5R('-P96-I
M9FEE9"XB"FUS9W-T<B`BW&AT:VD@:V%U<W1A(&5I(&WDY')A='5D(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P.0IM<V=I9"`B3F]N(%!A<G1I
M8VEP86YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3$@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT
M,`HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-2!T96UP
M;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B3F]N92(*;7-G<W1R(")-:71T92!M
M:61A9VDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.34*
M;7-G:60@(DYO<FUA;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S='(@(DUI='1E(&MU<W1U=&%T
M=60B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM
M<V=S='(@(DUI='1E(&UU<W1A;F0B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,T"FUS
M9VED(").;W0@26UP;W)T86YT(@IM<V=S='(@(DUI='1E('3D:'1I<R(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*;7-G:60@(DYO="!0
M97)S;VYA;"(*;7-G<W1R(")-:71T92!I<VEK;&EK(@H*(SH@;&EB+T-R>7!T
M+U!'4"YP:'`Z,3,Y(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP
M="]334E-12YP:'`Z,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W
M"FUS9VED(").;W0@9&5L971E9"!M97-S86=E<R(*;7-G<W1R(")-:71T92!K
M=7-T=71A='5D(&MI<FIA9"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B
M36ET=&4@=.1H='-A9"!K:7)J860B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S
M:R]F971C:&UA:6Q?;&]G:6XN<&AP.C<Q"FUS9VED(").;W1E('1H870@=&AI
M<R!C86X@=&%K92!S;VUE('1I;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8Q-@HC+"!F=7IZ>0IM<V=I9"`B3F]T:&EN9R(*;7-G
M<W1R(")4<VET965R:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W
M"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@;6]N=&AS('1O(&ME97`@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G
M<W1R("(B"B)3Y&EL:71A=&%V871E('9A;F%D92!S86%D971U9"!K:7)J861E
M(&MA=7-T861E(&%R=B!I9V%K=6ES96P@:W5S='5T86UI<V5L(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,U.0HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R
M(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG
M(&UO;G1H;'DN(@IM<V=S='(@(B(*(E/D:6QI=&%T879A=&4@=F%N861E('-A
M861E='5D(&MI<FIA9&4@:V%U<W1A9&4@87)V(&EG86MU:7-E;"!K=7-T=71A
M;6ES96PB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U
M-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW,S,*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU('1E;7!L871E<R]S;6EM92]I
M;7!O<G1?:V5Y+FEN8SHT.0HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C0X"FUS9VED(")/4B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C$U"FUS9VED(")/;&0@;65S<V%G97,B"FUS9W-T<B`B
M5F%N860@:VER:F%D(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E
M7W-E;G1M86EL7VUO;G1H;'DN<&AP.C4R"FUS9VED(")/;&0@<V5N="UM86EL
M(&9O;&1E<G,@8F5I;F<@<'5R9V5D+B(*;7-G<W1R(")686YA9"!S86%D971U
M9"!K:7)J861E(&MA=7-T860@=/QH:F5N9&%T86MS92XB"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S
M('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-SD*(RP@9G5Z>GD*
M;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R
M('1H:7,@86-T:6]N+B(*;7-G<W1R(")086QU;B!V86QI('-E;&QE:W,@;W!E
M<F%T<VEO;VYI:W,@86EN=6QT(/QK<R!K875S="XB"@HC.B!T96UP;&%T97,O
M;65N=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS
M9VED(")/<&5N($9O7VQD97(B"FUS9W-T<B`B079A(&MA=7-T(@H*(SH@9F]L
M9&5R<RYP:'`Z-#(W"B,L(&9U>GIY"FUS9VED(")/<&5N960@1F]L9&5R(@IM
M<V=S='(@(D%V82!K875S="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW,#4*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*
M"B,Z(&9E=&-H;6%I;"YP:'`Z,S,@=&5M<&QA=&5S+V9E=&-H;6%I;"]T;W`N
M:6YC.C,*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C8*
M(RP@9G5Z>GD*;7-G:60@(D]T:&5R($UA:6P@06-C;W5N=',B"FUS9W-T<B`B
M375U9"!S96%D960B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3D*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,`IM
M<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R(")-=75D('-E861E9"(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`Q"FUS9VED(")/=71B;W5N
M9"!397)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR
M87-E+FEN8SHQ-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C4*(SH@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`T(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(Y,`IM<V=I9"`B4$=0(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B4$=0
M($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("),;V]B=2!K:7)J87-T(@H*(SH@
M8V]M<&]S92YP:'`Z,S4X"FUS9VED(")01U`@17)R;W(Z("(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HS,S<*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P
M87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@HC+"!F=7IZ>0IM<V=I
M9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B2.3D;&5S='5S(@H*(SH@<&=P+G!H
M<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4U"FUS9VED(")01U`@4&5R<V]N
M86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN
M96-T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HQ-S,*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E>'0B"FUS9W-T<B`B(@H*
M(SH@<&=P+G!H<#HQ-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(&9O<B!<(B5S("@E<RE<(B!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D+B(*;7-G<W1R(")+875S="!<(B5S7"(@;VX@961U:V%L="!L;V]D
M=60N(@H*(SH@<&=P+G!H<#HR-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!D96QE=&5D+B(*;7-G<W1R(")+875S="!<(B5S7"(@;VX@:N3D9&%V86QT
M(&MU<W1U=&%T=60N(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T"FUS
M9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHX"B,L(&9U>GIY"FUS9VED
M(")01U`@4VEG;B!-97-S86=E(@IM<V=S='(@(E-A861A(&MI<FDB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.CD*;7-G:60@(E!'
M4"!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!P9W`N<&AP
M.C(P,@HC+"!F=7IZ>0IM<V=I9"`B4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F
M=6QL>2!A9&1E9"XB"FUS9W-T<B`B06QL:VER:2!O;B!A<V5N9&%T=60N(@H*
M(SH@<&=P+G!H<#HQ-S<*;7-G:60@(E!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F
M=6QL>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A
M8W1I=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N
M('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR,#@*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R
M96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B
M;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@
M;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE
M('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(*;7-G:60@(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S('!O
M<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C
M=7)R96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U
M(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H92!01U`@(@HB
M9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`P"FUS9VED
M(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$W"FUS9VED(")03U`S(&]V97(@
M4U-,(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(S
M"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T
M92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-CD*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R
M("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q,0IM<V=I9"`B4$]0
M,RP@;F\@5$Q3(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE
M861E<BYI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&%G92`E9"!O9B`E
M9"(*;7-G<W1R("),96AE:_QL9R`E9"`E9"US="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,#,*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER<W0@56YS
M965N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S='(@(D]S82AD*2(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ,C,*;7-G:60@(E!A<W-P:')A<V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R.`IM<V=I9"`B
M4&%S<W!H<F%S92`H06=A:6XI(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR
M,S4@<&=P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-P:')A<V4@<W5C
M8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R(")+:7)I('-A861E=&D@=&5E
M;&4@:W5I9"!E:2!S86QV97-T871U9"(*"B,Z('1E;7!L871E<R]S;6EM92]P
M87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC
M.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP
M.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B92!E;7!T>2(*;7-G
M<W1R("(B"@HC.B!P9W`N<&AP.C$Q-`IM<V=I9"`B4&%S<W!H<F%S97,@9&\@
M;F]T(&UA=&-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3(*;7-G:60@(E!A
M<W-W;W)D(@IM<V=S='(@(E-A;&%S]6YA(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C0X"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E1E92!S
M:7-S96QO9VEM:7-E;"!H;V]L9'5S=/9I9"XB"@HC.B!A8VPN<&AP.C<V(&%C
M;"YP:'`Z,3`R"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R(&-A
M;B!N;W0@8F4@8VAA;F=E9"XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z
M-#DS(&UA:6QB;W@N<&AP.C<P,R!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C(T"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3`*;7-G
M:60@(E!E<G-O;F%L(@IM<V=S='(@(DES:6ML:6LB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM
M<V=S='(@(DES:6ML:6L@:6YF;R(*"B,Z('!G<"YP:'`Z,3(P"FUS9VED(")0
M97)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$R-PIM<V=I9"`B4&5R<V]N86P@4$=0
M(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z('-M
M:6UE+G!H<#HR,#<*;7-G:60@(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T
M97,@3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$S
M,@IM<V=I9"`B4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C(*;7-G:60@(E!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S
M(&%N9"!F;W)W87)D<S\B"FUS9W-T<B`B4&%I9W5T82!A;&QK:7)I(&5N;F4@
M=F%S='5S="(*"B,Z(&-O;7!O<V4N<&AP.C(U-`IM<V=I9"`B4&QA:6YT97AT
M(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SDY"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M
M86EL/R`@5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E
M;6)E9&1E9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN
M9&]W<R!A;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q
M=6ER92!A('!L=6=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,3DR"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B4&%L=6X@<VES97-T
M82!U=64@:V%U<W1A(&YI;6DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ,#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ,#0*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W
M(&9O;&1E<CHB"FUS9W-T<B`B4&%L=6X@<VES97-T82!U=64@:V%U<W1A(&YI
M;6DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S<*
M;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@(E!A
M;'5N('-I<V5S=&$@=75S(&YI;6DZ(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S
M<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@
M96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y
M+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB96YT97(@=&AI<R!P87-S<&AR
M87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@
M4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@(@HB=&\@
M96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G:60@(B(*(E!L96%S
M92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A
M9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI97,@04Y$('EO=2!A
M<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I;F1O=W,L('EO=2!W
M:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD
M;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C:V5R<R!F<F]M("(*
M(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@
M86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-S$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!P<F]V
M:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S='(@(E!A;'5N('-I<V5S=&$@;VUA
M(&MA<W5T86IA;FEM:2!J82!S86QA<_5N82(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(E!A;'5N('-I<V5S=&$@;VUA(&MA
M<W5T86IA;FEM:2!J82!S86QA<_5N82(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L
M:6(O24U0+G!H<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U
M<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B4&%L=6X@<&%R86YD
M82!V:6=A<V5D(';U:2!M:71M973D:&5N9'5S;&EK=60@86%D<F5S<VED+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*(E!L
M96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H
M96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@
M<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B16YN92!K=6D@;6ED86=I
M('1E960@=F%L:2!K875S="XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3`R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO
M;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R(")086QU;B!V86QI(&]T
M<VEM:7-E:W,@=N1H96UA;'0@_&MS(&MA=7-T+B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@
M870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(E!A;'5N
M('9A;&D@;W1S:6UI<V5K<R!VY&AE;6%L="#\:W,@:V%U<W0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,@IM<V=I9"`B4&QE87-E
M('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+B(*
M;7-G<W1R(")086QU;B!V86QI('-E;&QE:W,@;W!E<F%T<VEO;VYI:W,@86EN
M=6QT(/QK<R!K875S="XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z-S,*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!S96QE8W0@;W(@961I
M="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T<B`B4&%L=6X@=F%L
M:2!O='-I;6ES96MS(';D:&5M86QT(/QK<R!K875S="XB"@HC.B!C;VYF:6<O
M;6]T9"YP:'`N9&ES=#HT,0IM<V=I9"`B4&]W97)E9"!B>2!(;W)D92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$T"B,L(&9U>GIY
M"FUS9VED(")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G
M+2T@)RD_(@IM<V=S='(@(E!A:6=U=&$@86QL:VER:F$@971T92!K<FEI<'-U
M9"`H)RTM("<I(@H*(SH@<VUI;64N<&AP.C(T,2!P9W`N<&AP.C(U-R!F:6QT
M97)P<F5F<RYP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!R969E<F5N8V5S('-U
M8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")+875S="!<(B5S7"(@;VX@
M961U:V%L="!L;V]D=60N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS9W-T<B`B
M165L;6EN92!L96AE:_QL9R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,C@*;7-G:60@(E!R979I;W5S($UE<W-A9V4B"FUS
M9W-T<B`B165L;6EN92!K:7)I(@H*(SH@;6%I;&)O>"YP:'`Z,S0W"FUS9VED
M(")0<F5V:6]U<R!086=E(@IM<V=S='(@(D5E;&UI;F4@;&5H96O\;&<B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*;7-G
M:60@(E!R:6YT(@IM<V=S='(@(E!R:6YD:2(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VAE861E<G,N:6YC.C,X"B,L(&9U>GIY"FUS9VED(")0<FEO<FET>2(*
M;7-G<W1R(")0<FEN9&DB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z-S8*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP
M="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T
M;R!.3R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X
M"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E
M;G0[(&1E9F%U;'0@=&\@6453(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0R.0IM<V=I9"`B4'5B;&EC
M(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"B,L(&9U
M>GIY"FUS9VED(")0=7)?9V4@1&5L971E9"(*;7-G<W1R(")+=7-T=71A(&SU
M<&QI:W5L="(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z.`IM<V=I
M9"`B4'5R9V4@1&5L971E9"(*;7-G<W1R(")+=7-T=71A(&SU<&QI:W5L="(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(T"B,L(&9U>GIY
M"FUS9VED(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B2W5S='5T82!K875S
M="AA9"DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"FUS9VED(")0
M=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(DMU:2!T:6AT:2!T_&AJ
M96YD861A('!R_&=I:V%U<W1A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,#4*(RP@9G5Z>GD*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H
M(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S
M='(@(DMU<W1U=&$@<'+\9VEK875S=&%S="!K:7)J860@;6ES(&]N('9A;F5M
M860@:W5I(&WD<F=I='5D(&%R=B!PY&5V:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#8*(RP@9G5Z>GD*;7-G:60@(E!U<F=E(&]L9"!M97-S86=E
M<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R(")+=7-T=71A('9A;F$@
M:VER:2!P<OQG:6MA=7-T87-T(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M<'5R9V5?=')A<V@N<&AP.C8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G
M<W1R(")+=7-T=71A;B`E9"!K:7)J82!P<OQG:6MA<W1I<W0B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C,*(RP@9G5Z>GD*
M;7-G:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+B(*
M;7-G<W1R(")+=7-T=71A;B`E9"!K:7)J82!P<OQG:6MA<W1I<W0B"@HC.B!T
M96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C$W"B,L('!H<"UF;W)M870*;7-G
M:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@
M3$E-250B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN
M8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z($Y/($Q)
M34E4(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S
M='(@(E1S:71E97)I;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,X-@IM<V=I9"`B4F5?<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP.C4P"B,L(&9U>GIY"FUS
M9VED(")296-E:79E9"!/;B(*;7-G<W1R(")386%B=6YU9"(*"B,Z(&QI8B]3
M96%R8V@N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!3:6YC92(*
M;7-G<W1R(")386%B=6YU9"(*"B,Z(&QI8B]396%R8V@N<&AP.C4T"B,L(&9U
M>GIY"FUS9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R(")386%B=6YU9"(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@HC
M+"!F=7IZ>0IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(E-U=6YA(&5D87-I
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")2961I<F5C="(*;7-G<W1R(")3=75N82!E9&%S:2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E9&ER
M96-T($UE<W-A9V4B"FUS9W-T<B`B4W5U;F$@:VER:2!E9&%S:2(*"B,Z(&-O
M;7!O<V4N<&AP.C<X-PIM<V=I9"`B4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM
M<V=S='(@(E-U=6YA('-E92!K:7)I(&5D87-I(@H*(SH@8V]M<&]S92YP:'`Z
M.#0W"FUS9VED(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(D5D87-I
M<W5U;F%M:6YE(&5B8?5N;F5S='5S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-3@S"FUS9VED(")2969R97-H(@IM<V=S='(@(E;D<G-K
M96YD82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E
M9G)E<V@@1F]L9&5R(%9I97=S.B(*;7-G<W1R(")6Y')S:V5N9&$@:V%U<W1A
M9&4@<VES=3HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY('1E
M;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B
M4F5L;V%D(@IM<V=S='(@(E;D<G-K96YD82!V86%D92(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+VAE860N:6YC.C,*;7-G:60@(E)E;&]A9"!6:65W(@IM<V=S
M='(@(E;D<G-K96YD82!V86%D92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,C8@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM<V=I9"`B
M4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW.0IM<V=I9"`B4F5M96UB
M97(@=&AE(&QA<W0@=FEE=R(*;7-G<W1R(")096$@=FEI;6%N92!V86%D92!M
M965L97,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*;7-G<W1R(")+:7)J
M86MA<W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G
M:60@(E)E;6]V92!&:65L9"!&<F]M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T<B`B965M86QD82!A;&QI:V%S
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.`HC+"!F=7IZ
M>0IM<V=I9"`B4F5N86UE($9O;&1E<BAS*2(*;7-G<W1R(").:6UE=&$@:V%U
M<W0@_&UB97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U
M>GIY"FUS9VED(")296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI
M;F<@;V8@;6]N=&@_(@IM<V=S='(@(DYI;65T82!S86%D971U9"!K:7)J861E
M(&MA=7-T(&MU=2!A;&=U<V5S(/QM8F5R(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M-#4U"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG(%PB)7-<(B!T;R!<
M(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(EPB)7-<(B#\;6)E<FYI;65T86UI;F4@7"(E<UPB+6MS(&5B8?5N
M;F5S='5S+B!397)V97(@_'1L97,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E)E<&Q?>2!T
M;R!,:7-T(@IM<V=S='(@(E9A<W1A(&OU:6=I;&4B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")297!L86-E('=I=&@Z
M(@IM<V=S='(@(D%S96YD82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L>2(*;7-G<W1R(")687-T82(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0P.0HC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@4V5N="XB
M"FUS9W-T<B`B5F%S=&$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R(")6
M87-T82!K]6EG:6QE(@H*(SH@8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L
M>2!T;R!!;&PZ(@IM<V=S='(@(E9A<W1A(&OU:6=I;&4Z(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS
M9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@(E9A<W1A(&OU:6=I;&4B"@HC
M.B!C;VUP;W-E+G!H<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O($QI
M<W0Z(@IM<V=S='(@(E9A<W1A(&OU:6=I;&4Z(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")2
M97!L>2!T;R!?06QL(@IM<V=S='(@(E9A<W1A(&OU:6=I;&4B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3(X(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,S<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-PIM<V=I
M9"`B4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-0IM<V=I9"`B4F5P
M;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E
M<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8W"B,L(&9U>GIY"FUS9VED(")2
M97!L>2U4;R(*;7-G<W1R(")687-T83HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M-#`Y"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(E9A<W1A.B(*"B,Z(&-O
M;7!O<V4N<&AP.C<S,0IM<V=I9"`B4F5P;'DZ(@IM<V=S='(@(E9A<W1A.B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS."!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR-@HC+"!F=7IZ>0IM<V=I
M9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S='(@(DMU<F1A('+D;7!S<&]S
M=&D@_&QE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C,U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(S"FUS9VED
M(")297!O<G0@87,@4W!A;2(*;7-G<W1R(")+=7)D82!RY&UP<W!O<W1I(/QL
M92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X,PHC+"!F
M=7IZ>0IM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`B
M2_QS:2!L865K=6UI<VMI;FYI='5S="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU.#4*;7-G:60@(E)E<75E<W0@9&5L:79E<GD@8V]N9FER;6%T:6]N
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S"B,L
M(&9U>GIY"FUS9VED(")297%U97-T(')E860@<F5C96EP=',_(@IM<V=S='(@
M(DO\<VD@;&%E:W5M:7-K:6YN:71U<W0B"@HC.B!M86EL8F]X+G!H<#HQ.#D*
M;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-PIM<V=I9"`B4F5Q
M=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHQ-#,@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC
M.C(V"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C$*(RP@9G5Z>GD*;7-G
M:60@(E)E<V5T(@IM<V=S='(@(DKD=&MA(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$Q-0IM<V=I9"`B4F5S<&]N9&5N="!3=&%T=7,@57!D871E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T<B`B2N1T:V$B"@HC
M.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")297-U;64@>6]U<B!S97-S:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHT-`HC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#;VUP
M;W-I=&EO;EPB(@IM<V=S='(@(DMI<FIA(&MO;W-T86UI;F4B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C,Q('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,@IM<V=I9"`B4F5T=7)N('1O($9E
M=&-H($UA:6PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,C(*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#$@=&5M<&QA=&5S+W-M
M:6UE+VYO=&%C=&EV92YI;F,Z,30*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$V,B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3<S
M"B,L(&9U>GIY"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")-
M=75D(&CDY&QE<W1U<V5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q
M.`IM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T
M97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM
M<V=S='(@(B(*(E#D<F%S="!K:7)J82!K=7-T=71A;6ES="P@_&UB97)T]7-T
M;6ES="!V]6D@:V]P965R:6UI<W0@</;V<F1U('1A9V%S:2`B"B)P;W-T:V%S
M=&D@;FEM96MI<FIA(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X
M.`IM<V=I9"`B4F]L92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C$T,B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S-PHC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.0IM<V=I9"`B4R]-24U%
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES
M="YI;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T
M<B`B(@H*(SH@8V]M<&]S92YP:'`Z,SDT"FUS9VED(")3+TU)344@17)R;W(Z
M("(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS-S,*;7-G:60@(E,O34E-
M12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E
M(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U
M,0HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS9W-T<B`B2.3D
M;&5S='5S(@H*(SH@<VUI;64N<&AP.C0Y"FUS9VED(")3+TU)344@4&%S<W!H
M<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P
M;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R
M("(B"@HC.B!S;6EM92YP:'`Z,30P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B2V%U<W0@7"(E<UPB(&]N(&KDY&1A
M=F%L="!K=7-T=71A='5D+B(*"B,Z('-M:6UE+G!H<#HQ-C(*;7-G:60@(E,O
M34E-12!0=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-
M24U%(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR
M,3$*;7-G:60@(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E
M<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%
M(%-I9VX@365S<V%G92(*;7-G<W1R(")386%D82!K:7)I(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ-`IM<V=I9"`B4R]-24U%
M(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E,O34E-12!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%
M('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S
M86=E(&ES('5N86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<S"FUS9VED("(B"B)3
M+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@
M;V8@=&AI<R!S:6=N960@;65S<V%G92!C86X@;F]T("(*(F)E(&1I<W!L87EE
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ
M-#8*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O
M('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R
M:69I960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,@IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@
M=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES("(*(F-U
M<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S
M="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@(@HB=&AE(%,O34E-12!F
M96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#4*;7-G:60@(E--5%`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,C4U"B,L(&9U>GIY"FUS9VED(")37W5B:F5C="(*;7-G<W1R(")4965M82(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,V,PHC+"!F=7IZ
M>0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R(")386QV97-T82!K
M;V]P:6$@:V%U<W1A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")385]V92!A<R(*;7-G<W1R
M(")386QV97-T82(*"B,Z('-E87)C:"YP:'`Z,S$V('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B4V%V92(*;7-G
M<W1R(")386QV97-T82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C4S.`IM<V=I9"`B4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@
M:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#,S"FUS9VED(")3879E($1R869T(@IM<V=S='(@(E-A;'9E
M<W1A(&UU<W1A;F0B"@HC.B!S879E:6UA9V4N<&AP.C0R"B,L(&9U>GIY"FUS
M9VED(")3879E($EM86=E(@IM<V=S='(@(E-A;'9E<W1A(@H*(SH@;&EB+TU)
M344O0V]N=&5N=',N<&AP.C(P-`IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL
M97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHU.2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T
M97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,PHC+"!F
M=7IZ>0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(DUU=60@:.3D;&5S
M='5S960B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#`*
M;7-G:60@(E-A=F4@4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,S,*(RP@9G5Z>GD*;7-G:60@(E-A=F4@7T1R869T(@IM
M<V=S='(@(E-A;'9E<W1A(&UU<W1A;F0B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T
M<B`B4V%L=F5S=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Q"FUS
M9VED(")3879E(&1R869T<R!A<R!U;G-E96X_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<R"FUS9VED(")3879E(')E8VEP:65N
M=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(W
M"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"B,L(&9U>GIY
M"FUS9VED(")3879E('-E;G0@;6%I;#\B"FUS9W-T<B`B4V%L=F5S=&$@<V%A
M9&5T=60@:VER:2(*"B,Z(&-O;7!O<V4N<&AP.C$R,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DUU<W1A;F1I('-A;'9E
M<W1A;6EN92!E8F'U;FYE<W1U<RX@4V5R=F5R(/QT;&5S.B`E<R(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R
M<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R(")/='-I;F<B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHQ,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4V5A<F-H("5S(@IM<V=S='(@(D]T<VEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!/<'1I;VYS(@IM
M<V=S='(@(DUU=60@:.3D;&5S='5S960B"@HC.B!S96%R8V@N<&AP.C(V-0IM
M<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B3W1S:6YG=2!T=6QE;75S
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM<V=S='(@
M(DQO971U9"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z.0IM
M<V=I9"`B4V5L96-T(@IM<V=S='(@(E9A;&DB"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!!
M;F]T:&5R($%C8V]U;G0B"FUS9W-T<B`BQ')A(&WD<F=I(&UI9&%G:2(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")686QI(&ED96YT:71E970B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(DWD<F=I(&OU:6LB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@(L1R82!MY')G:2!M
M:61A9VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN
M9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S='(@(E9A;&D@
M86%D<F5S<VER86%M871U9"!A861R97-S:61E(&]T<VEM:7-E:W,@:F$@;&ES
M86UI<V5K<RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS
M9VED(")396QE8W0@86QL(@IM<V=S='(@(DWD<F=I(&OU:6LB"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N(@IM<V=S='(@(E9A;&D@86%D<F5S<VER86%M871U=&4@
M:N1R:F5K;W)D(&UI9&$@:V%S=71A9&$@86%D<F5S<VED92!L96ED;6ES96MS
M+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC
M.C(Q"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R
M("+$<F$@;>1R9VD@;6ED86=I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHX.0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`BQ')A(&WD<F=I
M(&UI9&%G:2(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN
M8SHY"FUS9VED(")396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA
M9V4@:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I
M=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S97)V
M97(@='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,#D*(RP@9G5Z>GD*;7-G:60@(E-E;&5C=&5D($%D9')E
M<W,@8F]O:W,Z(@IM<V=S='(@(E9A;&ET=60@86%D<F5S<VER86%M871U9#HB
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(E-E;F0@2V5Y
M('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8P-`HC+"!F=7IZ>0IM<V=I9"`B4V5N9"!,871E
M<W0@26YF;W)M871I;VXB"FUS9W-T<B`B4V5R=F5R:2!I;F9O(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#,Q"FUS9VED(")396YD($UE<W-A9V4B"FUS9W-T
M<B`B4V%A9&$@:VER:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,#,*
M;7-G:60@(E-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H
M92!S96YD97(_(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PHC+"!F
M=7IZ>0IM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")386%D971U
M9"!K:7)J861E(&MA=7-T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I
M;'-E;&5C="YI;F,Z,S@*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(Z(@IM<V=S
M='(@(E-A861E='5D(&MI<FIA9&4@:V%U<W0Z(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ,S(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-#8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-3,*(RP@9G5Z>GD*
M;7-G:60@(E-E<G9E<B(*;7-G<W1R(")-:71T92!K=6YA9VDB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!A
M;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E-E<G9E<FD@:6YF;R(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,PHC+"!F=7IZ
M>0IM<V=I9"`B4V5R=F5R.B(*;7-G<W1R(")-:71T92!K=6YA9VDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F97)E;F-E
M<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M
M97-S86=E<RXB"FUS9W-T<B`B3>3D<F$@;6ES(&IU:'1U8B!K=6D@<V$@:VER
M:G4@:W5S='5T860@:F$@_&UB97(@=/5S=&%D+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET>2!H96%D
M97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0HC+"!F=7IZ>0IM<V=I9"`B4VAA<F4@
M1F]L9&5R<R(*;7-G<W1R(")-=75D82!K875S=&$B"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z.#8*(RP@9G5Z>GD*;7-G:60@(E-H87)E(&UA:6P@9F]L
M9&5R<R(*;7-G<W1R(")386%D971U9"!K:7)J861E(&MA=7-T.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL
M(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V.0IM<V=I9"`B(@HB4VAO=6QD(&QA<F=E
M(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@
M9&5F875L=#\@270@8V%N(&)E("(*(G1O9V=L960@96%S:6QY('=H:6-H979E
M<B!Y;W4@8VAO;W-E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-PIM<V=I9"`B4VAO=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@
M;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@4$=0(&1A=&$_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T
M:&4@8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R
M869T/R(*;7-G<W1R(")3=6QE(&MI<FIA(&%K96X@<.1R87-T(&UU<W1A;F1I
M('-A;'9E<W1A;6ES="(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHT"FUS
M9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE
M9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`B4W5L92!K]6EK(&MA=7-T860B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV-PIM<V=I9"`B
M4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HS
M-C4*;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R(").Y&ET82!K=7-T=71A
M='5D(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*;7-G
M:60@(E-H;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P"B,L(&9U>GIY"FUS9VED(")3
M:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R("))<VEK;&EK
M(&EN9F\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"B,L(&9U
M>GIY"FUS9VED(")3:&]W($]N;'D@4W5B<V-R:6)E9"!&;VQD97)S(@IM<V=S
M='(@(E1E;&QI(&MA=7-T*&%D*2(*"B,Z(&9O;&1E<G,N<&AP.C(Y.`IM<V=I
M9"`B4VAO=R!5;G-U8G-C<FEB960B"FUS9W-T<B`B3N1I=&$@=&5L;&EM871A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P.`IM<V=I9"`B4VAO=R!A
M;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M
M(&UE<W-A9V5S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`P,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!L96=E;F0@:6X@=&AE(&UA
M:6QB;W@@=FEE=S\B"FUS9W-T<B`B3N1I=&$@:VER:F%K87-T:2!A:VYA<R!L
M96=E;F1I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#`*;7-G:60@
M(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3
M:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#<W"FUS9VED(")3:&]W('1H92!&971C:"!-
M86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B4VAO=R!T:&4@26UA9V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU
M-`IM<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR.`IM<V=I
M9"`B4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8V"B,L(&9U>GIY
M"FUS9VED(")3:&]W;B(*;7-G<W1R(")0<G5U;B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@
M(E-I7WIE(@IM<V=S='(@(E-U=7)U<R(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VQE9V5N9"YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(E-I9VYE9"(*;7-G<W1R
M(")3=75R=7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI
M;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")3=75R=7,B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3;W)T
M(&)Y($%R<FEV86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@1G)O;2!!9&1R97-S
M(@IM<V=S='(@(E-A871J82!A861R97-S(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHT,0HC+"!F=7IZ>0IM<V=I9"`B4V]R
M="!B>2!-97-S86=E(%-I>F4B"FUS9W-T<B`B2VER:F$@<W5U<G5S(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-@HC+"!F
M=7IZ>0IM<V=I9"`B4V]R="!B>2!3=6)J96-T(@IM<V=S='(@(E1E96UA('!U
M=61U8B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@5&AR96%D(@IM<V=S='(@
M(DIU='5L]6YG(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S
M(@IM<V=S='(@(E-A871J82!A861R97-S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-P86US96QE8W0N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")3<&%M(&9O;&1E
M<CHB"FUS9W-T<B`B4'+\9VEK875S=#HB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*
M;7-G<W1R(")%<FEMY')G:60B"@HC.B!S96%R8V@N<&AP.C$S,PIM<V=I9"`B
M4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N(&YO="!B92!E9&ET960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T
M,PIM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`BU6EG96MI<FIA(&MO;G1R
M;VQL(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS
M9VED(")3<&5L;"!#:&5C:V5R(@IM<V=S='(@(M5I9V5K:7)J82!K;VYT<F]L
M;&EJ82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT."!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@(E-P96QL
M(&-H96-K(&-O;7!L971E(@IM<V=S='(@(M5I9V5K:7)J82!K;VYT<F]L;"!L
M]7!E=&%T=60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Q"FUS9VED
M(")3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K
M:6YG+B(*;7-G<W1R(")+:7)J879I9V%D92!A<G8@96MR86%N:6PN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q,B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C4R"FUS9VED(")3=&%R="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS,3$*;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED
M(")3=&%T:6]N97)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHR.`IM<V=I9"`B4W1A=&EO;F5R>2!T>7!E
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,S,*;7-G:60@(E-T871I;VYE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(E-T871U<R(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U>GIY"FUS
M9VED(")3=')I<"!!='1A8VAM96YT(@IM<V=S='(@(DQI<V%N9"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A
M:W,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-U8E]J96-T(@IM<V=S
M='(@(E1E96UA(@H*(SH@;65S<V%G92YP:'`Z,C8X('1H<F5A9"YP:'`Z,34P
M('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C4*(SH@;&EB+U-E
M87)C:"YP:'`Z,S@*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B5&5E;6$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(P"FUS9VED(")3=6)J96-T($9I
M96QD(@IM<V=S='(@(E1E96UA(';D;&DB"@HC.B!S96%R8V@N<&AP.C,Q."!T
M96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3@*(SH@=&5M<&QA
M=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E;7!L871E<R]P9W`O<&%S
M<W!H<F%S92YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(E-U8FUI="(*;7-G<W1R
M(")4965M82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Q
M"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R*',I(@IM<V=S='(@(E1E;&QI
M(&MA=7-T*&%D*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@P
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X.0HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U
M9V=E<W1I;VYS(@IM<V=S='(@(E-O;W9I='5S960B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C8R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-C0*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#`P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C0P,PIM<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M,#0*;7-G:60@(E-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I
M9"`B4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#$Y"B,L(&9U
M>GIY"FUS9VED(")495]X="(*;7-G<W1R(")496MS="(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HR-CD*;7-G:60@(E1E;G1A=&EV93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@
M(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV96QY
M($%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E
M<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R(")496MS="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-30*;7-G:60@(E1H92!&<F]M.B!C;VQU;6X@;V8@
M=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HU,S(*;7-G:60@(B(*(E1H92!)34%0('-E
M<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@875T:&5N=&EC
M871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"FUS9VED(")4:&4@36%C:6YT
M;W-H(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED96YT:71E970@7"(E<UPB(&]N
M(&MU<W1U=&%T=60N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(DED96YT:71E970@7"(E<UPB(&]N('-A
M;'9E<W1A='5D+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C0S"FUS9VED(")4:&4@
M871T86-H;65N="!W87,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-CD*;7-G:60@(E1H92!C86QE;F1A<B!D
M871A(&ES(&EN=F%L:60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I9"`B(@HB5&AE(&-O
M;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V
M92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP
M:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I
M;&4@87)E(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I(%PB)7-<(B!W:6QL
M(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")+Y&5S;VQE=B!K875S
M="!<(B5S7"(@;FEM971A=&%K<V4@_&UB97(@7"(E<UPB+6MS(@H*(SH@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@
M;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L
M9"!N;W0@8F4@<F5T<FEE=F5D(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP
M.C$R,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B965N
M('-A=F5D('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3,Y"FUS9VED(")4:&4@979E;G0@
M=V%S(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I96QD(%PB)7-<(B!C86XG="!B92!E>'!A;F1E
M9"XB"FUS9W-T<B`B261E;G1I=&5E="!<(B5S7"(@;VX@:W5S='5T871U9"XB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B2V%U
M<W0@7"(E<UPB(&]N(&IU8F$@;VQE;6%S(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,38S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB
M(&-O;G1A:6YS(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@
M;6%Y(&-A=7-E("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DMA=7-T82!<(B5S7"(@;FEM
M97,@;VX@;'5B86UA='5I9"!MY')K92X@4V5E(';U:6(@=&5K:71A9&$@<')O
M8FQE96UE+B!096$@(@HB;O5U('/\<W1E96UI(&%D;6EN:7-T<F%A=&]R:6=A
M+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@
M;F]T('-U8G-C<FEB960@=&\@:70N(@IM<V=S='(@(DMA=7-T(%PB)7-<(B!L
M;V]D:2!A9V$@<V$@96D@;VQE('-E9&$@=&5L;&EN=60N(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I
M8F5D(&9R;VT@:70N(@IM<V=S='(@(DMA=7-T(%PB)7-<(B!K=7-T=71A=&D@
M86=A('-U;"!O;B!S964@:N1T:W5V86QT('1E;&QI='5D+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R
M(%PB)7-<(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60B"FUS9W-T<B`B2V%U<W1A(%PB)7-<(B!E:2!L;V]D=60N(%-E
M<G9E<B#\=&QE<R(*"B,Z(&QI8B]&;VQD97(N<&AP.C(V-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D
M96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(DMA=7-T82`G)7,G(&5I(&MU<W1U=&%T=60N(%-E<G9E<B#\=&QE<R(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N(@IM<V=S
M='(@(DMA=7-T(%PB)7-<(B!O;B!E9'5K86QT(&QO;V1U9"XB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")+
M875S="!<(B5S7"(@;VX@:N3D9&%V86QT(&MU<W1U=&%T=60N(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N
M(@IM<V=S='(@(DMA=7-T(%PB)7-<(B!N:6UE=&%T:2#\;6)E<B!<(B5S7"(M
M:W,B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H
M92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?<V%V
M96EM86=E7W=I;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN
M9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y
M;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"FUS9VED("(B
M"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E
M;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED
M(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@97)R
M;W(@;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-3$*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE
M<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDP"FUS
M9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@
M;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UA:6QB;W@@)7,@:7,@
M86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B2V%U<W0@7"(E<UPB(&]N(&IU8F$@
M;VQE;6%S(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B`H)60@
M8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,#,*(RP@9G5Z
M>GD*;7-G:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B2^1S:6QO;&5V(&MI<FD@<W5L
M971I+B!6Y&QJ=6XN(@H*(SH@;65S<V%G92YP:'`Z,30X"B,L(&9U>GIY"FUS
M9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))
M9&5N=&ET965T(%PB)7-<(B!O;B!K=7-T=71A='5D+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B5&AE(&UE<W-A
M9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(DED96YT:71E970@7"(E
M<UPB(&]N('-A;'9E<W1A='5D+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA
M<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA=&5S
M+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S<&AR
M87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@
M<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F('1H92!01U`@4'5B
M;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@(E1H92!R97%U97-T960@
M9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`IM
M<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H
M92!::7`@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z
M-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI
M<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@
M=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB
M;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4:&4@<V5R=F5R('=A<R!N
M;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ
M,#0*(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E
M(')E<&QA8V5D+B(*;7-G<W1R(")!;&QK:7)J82!E:2#U;FYE<W1U;G5D(&%S
M96YD861A+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`R
M"FUS9VED(")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C
M960N(@IM<V=S='(@(D%L;&MI<FD@;VX@87-E;F1A='5D+B(*"B,Z(&%T=&%C
M:&UE;G0N<&AP.C4Y"FUS9VED(")4:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z('-T871I;VYE<GDN<&AP.C@T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S
M7"(@:&%S(&)E96X@861D960N(@IM<V=S='(@(DED96YT:71E970@7"(E<UPB
M(&]N('-A;'9E<W1A='5D+B(*"B,Z('-T871I;VYE<GDN<&AP.C8S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5E="!<(B5S7"(@
M;VX@:W5S='5T871U9"XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA
M<R!B965N('5P9&%T960N(@IM<V=S='(@(DED96YT:71E970@7"(E<UPB(&]N
M(&MU<W1U=&%T=60N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V
M.0IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K
M;&ES="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP
M:'`Z.34*(RP@9G5Z>GD*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E
M(@IM<V=S='(@(FMU<W1U=&$@:VER:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F
M('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M('-E;G0@;65S<V%G92(*;7-G<W1R(")3=75N82!S964@:VER:2!E9&%S:2(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@
M8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B5&AE('5S97(G<R!F
M<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB
M"FUS9W-T<B`B06QL:VER:2!O;B!A<V5N9&%T=60N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM<V=I9"`B5&AE<F4@87)E(&YO
M(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V5M<'1Y7VUA
M:6QB;W@N:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T
M:&ES(&UA:6QB;W@N(@IM<V=S='(@(E-E;&QE<R!K:7)J86MA<W1I<R!E:2!O
M;&4@:VER:G4N(@H*(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES
M(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8Q,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(E<R!T_&AJ96YD86UI
M<V5L('1E:VMI<R!V:6=A+B!397)V97(@_'1L97,B"@HC.B!L:6(O365S<V%G
M92YP:'`Z-C4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E
M<B!S86ED.B`E<R(*;7-G<W1R(")+:7)J86MA<W1I('3\:&IE;F1A;6ES96P@
M=&5K:VES('9I9V$N(%-E<G9E<B#\=&QE<R(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HV,C$*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H
M92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(DMI<FIA:V%S=&D@=/QH:F5N9&%M:7-E;"!T96MK:7,@=FEG82X@4V5R
M=F5R(/QT;&5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.CDP"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@8V]P>6EN
M9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA
M="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B2VER:F%D92!K;W!E97)I
M;6ES96P@7"(E<UPB+6D@=&5K:VES('9I9V$N(%-E<G9E<B#\=&QE<R(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HQ.3@@;&EB+TUE<W-A9V4N<&AP.C(Q,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T("(*(G1H92!S97)V97(@<V%I9"(*;7-G<W1R(")+:7)J861E(&MU<W1U
M=&%M:7-E;"!K875S=&%S="!<(B5S7"(@=&5K:VES('9I9V$N(%-E<G9E<B#\
M=&QE<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HR-S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S
M(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E
M<G9E<B!S86ED(@IM<V=S='(@(DMI<FIA9&4@:W5S='5T86UI<V5L(&MA=7-T
M87,@7"(E<UPB('1E:VMI<R!V:6=A+B!397)V97(@_'1L97,B"@HC.B!L:6(O
M365S<V%G92YP:'`Z,C$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DMI<FIA9&4@:W5S
M='5T86UI<V5L('1E:VMI<R!V:6=A+B!397)V97(@_'1L97,B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z.3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z
M("5S+B(*;7-G<W1R(")3;V]V:71U9"!K:7)J82!V86%T86UI<V5L('1E:VMI
M<R!V:6=A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3(@;&EB
M+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS-PIM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T
M<B`B2VER:F$@;W-A(&5S:71A;6ES96P@=&5K:VES('9I9V$B"@HC.B!L:6(O
M365S<V%G92YP:'`Z-30U(&QI8B]-97-S86=E+G!H<#HU.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE
M<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE
M("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(DMI<FIA9&4@;>1R:VEM:7-E;"!K
M875S=&%S(%PB)7-<(B!T96MK:7,@=FEG82X@4V5R=F5R(/QT;&5S(@H*(SH@
M9F]L9&5R<RYP:'`Z,38U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R(")-=7-T
M86YD:2!S86QV97-T86UI<V5L('1E:VMI<R!V:6=A+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E
M<RXB"FUS9W-T<B`B4V]O=FET=60@:VER:F$@=F%A=&%M:7-E;"!T96MK:7,@
M=FEG82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!T87-K.B`E<RXB"FUS9W-T<B`B4V]O=FET=60@:VER:F$@
M=F%A=&%M:7-E;"!T96MK:7,@=FEG82XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF
M;W)M871I;VXZ("5S+B(*;7-G<W1R(")+:7)J82!S86%T;6ES96P@=&5K:VES
M('9I9V$Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;6]V:6YG
M(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R(")+:7)J861E('3U<W1M:7-E
M;"!K875S=&$@7"(E<UPB('1E:VMI<R!V:6=A+B!397)V97(@_'1L97,B"@HC
M.B!C;VUP;W-E+G!H<#HQ,C0T"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T+B(*;7-G
M<W1R(")+:7)J82!O<V$@97-I=&%M:7-E;"!T96MK:7,@=FEG82(*"B,Z(&-O
M;7!O<V4N<&AP.C$P,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R(")+
M:7)J82!S86%T;6ES96P@=&5K:VES('9I9V$Z("5S(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N
M(@IM<V=S='(@(DMI<FIA('-A871M:7-E;"!T96MK:7,@=FEG83H@)7,B"@HC
M.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4Y"B,L(&9U>GIY"FUS9VED
M(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R="(*;7-G
M<W1R(")+:7)J82!O<V$@97-I=&%M:7-E;"!T96MK:7,@=FEG82(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B5&AI<R!(5$U,(&UE
M<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP"FUS9VED("(B"B)4:&ES
M($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C
M:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED(")4:&ES(%!'
M4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P-"!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,3$X"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-#,@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-PHC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<S(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HS,30*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M-SD@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A
M8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI
M<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!C;VYT:6YU93\B"FUS9W-T<B`B4V5E(';U:6(@=O5T=&$@;F%T=6ME(&%E
M9V$N($MA<R!O;&5D(&MI;F1E;"!E="!S;V]V:60@:N1T:V%T83\B"@HC.B!L
M:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED(")4:&ES
M(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3`*;7-G:60@(B(*
M(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S
M(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R\B"B)-24U%+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q-`IM<V=I9"`B
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@
M8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B"B)4:&ES(&UE
M<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M871I
M;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G92!I<R!U;FMN
M;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS
M,34*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R<F]R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C0P(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,U,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R
M;6%T("AA8V-O<F1I;F<@=&\@(@HB4D9#(#(P,34I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI<R!M
M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3
M+TU)344@9F]R;6%T+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR,#4@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z-#$V"FUS9VED
M(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@
M4$=0+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C$T,PIM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S
M:6=N960@=FEA(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HQ,SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR
M,S@*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA
M(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,C`Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,0IM<V=I9"`B5&AI
M<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T
M<B`B(@H*(SH@;65S<V%G92YP:'`Z,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@
M=&\B"FUS9W-T<B`B:VER:2!K875S=&$B"@HC.B!A8VPN<&AP.C0V"FUS9VED
M(")4:&ES('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ,#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@
M8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`B4V5E(&%K
M96X@='5L96(@879A9&$@=75E(&MI<FIA(&%K;F%S="(*"B,Z('1H<F5A9"YP
M:'`Z,34R"B,L(&9U>GIY"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G<W1R
M(")%:W)A86YI('-E861E9"(*"B,Z('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR,@IM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B
M2G5T=6SU;F=A('9A861E(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N
M<&AP.C8P-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O
M8V]M<&]S92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS
M9VED(")4;R(*;7-G<W1R(")+96QL96QE(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDQ.0HC+"!F=7IZ>0IM<V=I9"`B5&\@061D<F5S<R(*;7-G<W1R
M(")386%T:F$@86%D<F5S<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C,R-@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I
M96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!W:&EL92`B"B)C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HQ,S0*;7-G:60@(B(*(E1O('5S92!A(%1,4R!C;VYN
M96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@
M-2XP+C8@;W(@(@HB:&EG:&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*(RP@9G5Z>GD*;7-G:60@(E1O=&%L
M($%T=&%C:&UE;G1S(%-I>F4Z(@IM<V=S='(@(DQI<V%N9&ED(@H*(SH@9F]L
M9&5R<RYP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")4<F%S:"!F;VQD97(B"FUS
M9W-T<B`B4'+\9VEK875S=#HB"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS
M96QE8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM<V=S='(@(E!R
M_&=I:V%U<W0Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV-2!L:6(O475O
M=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N9"YP:'`Z-S(*
M(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T82]C;W5R:65R
M+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*;7-G:60@(E5N86)L
M92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R(")687-T86UA=&$B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5;F%N
M<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(E9A<W1A;6%T82!K:7)J860B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-"!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B56YD96QE=&4B
M"FUS9W-T<B`B5&%A<W1A(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y(&UA:6QB;W@N
M<&AP.C8P,B!L:6(O34E-12](96%D97)S+G!H<#HR,3(*;7-G:60@(E5N9&ES
M8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`B3N1H=&%M871U9"!A9')E<W-A
M861I9"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E
M<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU-C4*;7-G:60@(E5N:VYO
M=VX@1&%T92(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N($E-05`@<F5S<&]N<V4@
M9G)O;2!T:&4@<V5R=F5R+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C,U"FUS9VED(")5
M;FMN;W=N($UE971I;F<B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-C$X
M"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(%)E8VEP:65N="(*;7-G<W1R(").
MY&AT86UA='5D(&%D<F5S<V%A9&ED(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E5N
M;&]A9"!087-S<&AR87-E(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S
M+G!H<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").:6UE='4B"@HC.B!M
M97-S86=E+G!H<#HT.3D@;6%I;&)O>"YP:'`Z-S`X('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,S(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHU"FUS9VED(")5
M;G-E96XB"FUS9W-T<B`B3'5G96UA=&$B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O;2!&;VQD
M97(H<RDB"FUS9W-T<B`B3&]O8G4@:V%U<W1A*&1E*2!T96QL:6UI<V5S="(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X-`IM<V=I9"`B
M57!D871E($%T=&%C:&UE;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R,`IM<V=I9"`B57!D871E(')E
M<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C4V"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U
M;'0@5F%L=64B"FUS9W-T<B`B2V%S=71A('9A:6ME=N3D<G1U<W0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"B,L(&9U>GIY"FUS9VED(")5<V4@
M24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T<B`B2V%S=71A($E-
M05`@:V%U<W1A9&4@=&5L;&EM=7-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<S-0HC+"!F=7IZ>0IM<V=I9"`B57-E(%9I<G1U86P@5')A<V@@1F]L
M9&5R/R(*;7-G<W1R(")4_&AJ96YD82!P<OQG:6MA=7-T(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$T,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G
M<W1R(")+87-U=&%J86YI;6DB"@HC.B!A8VPN<&AP.C@W"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T
M:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<W"FUS
M9VED(")5<V5R;F%M92(*;7-G<W1R(")+87-U=&%J86YI;6DB"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@
M(E5S97)N86UE.B(*;7-G<W1R(")+87-U=&%J86YI;6DB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-C@*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B5FEE
M=R(*;7-G<W1R(")686%T82`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N
M<&AP.CDR(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")686%T82`E<R(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,@4'5B;&EC($ME
M>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V
M"B,L(&9U>GIY"FUS9VED(")6:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R
M871E('=I;F1O=R(*;7-G<W1R(")+:7)J=71A(&MI<FIA9"!E<F%L9&D@86MN
M87,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C@*(RP@
M9G5Z>GD*;7-G:60@(E9I97<@365S<V%G97,B"FUS9W-T<B`B575E9"!K:7)J
M860B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R!097)S;VYA;"!0<FEV871E
M($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE=R!097)S
M;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B5FEE
M=R!4:')E860B"FUS9W-T<B`B2G5T=6SU;F<B"@HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M,38U"FUS9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B5FEE
M=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(DMI
M<FIU=&$@:VER:F%D(&5R86QD:2!A:VYA<RXB"@HC.B!L:6(O34E-12]6:65W
M97(O<F5L871E9"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E9I97<@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")+:7)J=71A(&MI<FIA
M9"!E<F%L9&D@86MN87,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$T,`IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R("(B"@HC.B!F;VQD97)S
M+G!H<#HS.#`@;6%I;&)O>"YP:'`Z-3,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(E9A871A(&MI
M<FIU(&MA=7-T87,@(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E
M<V5L96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L
M87D@869T97(@;&]G:6XZ(@IM<V=S='(@(E9A861E(';U:2!K:7)J86MA<W0@
M;6ED82!NY&ED871A('#D<F%S="!S:7-S96QO9VEM:7-T.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ-S`*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M=&%S:R(*;7-G<W1R(")686%T82`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(E9I97<@=&AE($EM86=E<R(*
M;7-G<W1R(")686%T82!K:7)J=2!K875S=&%S("(*"B,Z('-E87)C:"YP:'`Z
M,C8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L($9O;&1E
M<B!<(B5S7"(@8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`B2V%U<W0@
M7"(E<UPB(&]N(&KDY&1A=F%L="!K=7-T=71A='5D+B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])34%0+U1R964N<&AP.C$S."!L
M:6(O24U!4"]4<F5E+G!H<#HQ-3$*(SH@;&EB+TE-05`O5')E92YP:'`Z,34S
M(&QI8B])34%0+U1R964N<&AP.C$U-R!L:6(O24U!4"]4<F5E+G!H<#HQ-3@*
M(SH@;&EB+TE-05`O5')E92YP:'`Z,S8Y(&QI8B])34%0+U1R964N<&AP.C,Y
M,R!L:6(O24U!4"]4<F5E+G!H<#HT,S,*(RP@9G5Z>GD*;7-G:60@(E9I<G1U
M86P@1F]L9&5R<R(*;7-G<W1R("),;V\@:V%U<W0B"@HC.B!S96%R8V@N<&AP
M.C(T-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+U9&;VQD97(N<&AP.C$W-2!L:6(O5D9O;&1E
M<BYP:'`Z,3@P"FUS9VED(")6:7)T=6%L($E.0D]8(@IM<V=S='(@(B(*"B,Z
M(&9O;&1E<G,N<&AP.C0Q-@IM<V=I9"`B5FER='5A;"!)3D)/6"!&;VQD97(B
M"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-#4R(&QI8B]61F]L9&5R+G!H
M<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0IM<V=I9"`B5FER='5A;"!4<F%S
M:"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,3,*(RP@9G5Z>GD*;7-G
M:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(E3\:&IE;F1A('!R
M_&=I:V%U<W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$S,PIM
M<V=I9"`B5FER='5A;"!F;VQD97(@;&%B96PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S0*;7-G:60@(E=A<FYI;F<B"FUS
M9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE('1O("5S(@IM<V=S='(@(E1E<F4@='5L96UA<W0@)7,M:2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3D*;7-G:60@(B(*(E=H870@
M<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA
M=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(W"B,L(&9U>GIY
M"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@
M=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H
M96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HB2VER:F%D92!K=7-T=71A;6ES
M96P@=/5S=&$@;F5E9"!K=7-T=71A='5K<R!MY')K:6UI<V4@87-E;65L('!R
M_&=I:V%U<W1A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G
M:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O
M('EO=2!W86YT('1O('-T87)T(&]N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA
M:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE
M;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D
M;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R
M97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7
M:&ET96QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@
M(EEE<R(*;7-G<W1R(")*86@B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F
M971C:&UA:6Q?;&]G:6XN<&AP.C4X"B,L(&9U>GIY"FUS9VED(")9;W4@87)E
M(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O
M=6YT*',I.B(*;7-G<W1R(")382!P_/QA9"!K=7-T=71A9&$@:N1R9VUI<VD@
M:V%U<W1U.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER
M;2YH=&UL.C$P"B,L(&9U>GIY"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I
M;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O
M;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@(E-A('#\_&%D(&MU<W1U
M=&%D82!JY')G;6ES:2!K875S='4Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M9F]L9&5R<U]C;VYF:7)M+FAT;6PZ.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R
M92!A='1E;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS
M*2XB"FUS9W-T<B`B4V$@</S\860@:W5S='5T861A(&KD<F=M:7-I(&MA=7-T
M=3HB"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T
M96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!A<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R
M+B(*;7-G<W1R(")382!N:6UE=&%D(/QM8F5R(&MA=7-T83H@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#(*;7-G:60@(EEO=2!A
M<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O("(*;7-G<W1R(")382!L;V]D
M(&%L86UK875S=&$@:V%U<W1A;&4@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!T
M;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R(")382!L;V]D(/QL96UI<V4@=&%S
M96UE(&MA=7-T82`B"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N
M(@IM<V=S='(@(E-A(&QO;V0@_&QE;6ES92!T87-E;64@:V%U<W1A("(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L9&5R
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ,S4*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@
M(@IM<V=S='(@(E-A(&YI;65T860@_&UB97(@:V%U<W1A.B`B"@HC.B!L:6(O
M1F]L9&5R+G!H<#HU-3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EEO
M=2!C86X@;F]T('5N<W5B<V-R:6)E(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")3
M82!L;V]B=7-I9"!K875S=&$@7"(E<UPB('1E;&QI;75S97-T+B(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L
M9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*(F-U
M<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E
M;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O('1H
M92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T
M(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-CD*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M
M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE
M(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")3=6QL92!O
M;B`E<R!U=70@:VER:F$N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N
M:6YC.C,*;7-G:60@(EEO=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@
M(E-U;&QE(&]N(#$@=75S(&MI<FDN(@H*(SH@8V]M<&]S92YP:'`Z-#DT"B,L
M(&9U>GIY"FUS9VED(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES
M('!A9V4N(@IM<V=S='(@(E-U;&QE(&]N(#$@=75S(&MI<FDN(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,3$U"FUS9VED("(B"B)9
M;W4@:&%V92!A="!L96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T
M('EO=2!D:61N)W0@=7!L;V%D('EE="X@07)E("(*(GEO=2!S=7)E('EO=2!W
M86YT('1O('-E;F0@=&AI<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H
M;65N=',_(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-S0*;7-G:60@
M(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*
M;7-G<W1R(")3=6QL92!O;B!U=7-I(&MI<FIU(&MA=7-T87,Z(@H*(SH@;&EB
M+TE-4"YP:'`Z,3`W.0IM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE
M(&9O;&QO=VEN9R!F;VQD97)S.B(*;7-G<W1R(")3=6QL92!O;B!U=7-I(&MI
M<FIU(&KD<F=M:7-T97,@:V%U<W1A9&5S.B(*"B,Z(&-O;7!O<V4N<&AP.C$U
M,PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE
M(')E8VEP:65N="XB"FUS9W-T<B`B2VER:F%L('!E86(@;VQE;6$@=N1H96UA
M;'0@_&MS('-A86IA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,P
M,@IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R
M('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Y"FUS
M9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U
M<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI
M;F,Z-C0@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS
M9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB
M"FUS9W-T<B`B2_5I9V5P96%L="!P96%D('9A;&EM82!K875S=&$N(@H*(SH@
M9F5T8VAM86EL<')E9G,N<&AP.C@U"B,L(&9U>GIY"FUS9VED(")9;W4@;75S
M="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")0
M96%D('9A;&EM82!I9&5N=&ET965D:2!M:61A('-O;W9I9"!K=7-T=71A9&$N
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@
M(DOU:6=E<&5A;'0@<&5A9"!V86QI;6$@86%D<F5S<VDN(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA
M=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE
M87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R(")+]6EG97!E86QT('!E
M860@=F%L:6UA(';D:&5M86QT(/QH92!K:7)J82XB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z,3,*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!R96-I<&EE;G0N(@IM<V=S='(@(DMI<FIA('-A86IA('!E86(@;VQE
M;6$@;>3D<F%T=60N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:G,Z,CD*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@870@
M;&5A<W0@;VYE(&9I;&4@=&\@871T86-H+B(*;7-G<W1R(")+]6EG97!E86QT
M('!E860@=F%L:6UA(&9A:6QI(&UI9&$@<V]O=FED(&QI<V%D82XB"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@96YA8FQE9"!I;B!Y
M;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M86EL;&]G+G!H<#HQ,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EEO
M=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N(@IM<V=S
M='(@(E-U=6YA('-E92!K:7)I(&5D87-I(@H*(SH@;&EB+TUA:6QL;V<N<&AP
M.C$T,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@
M=&\@=&AI<R!M97-S86=E(&]N("5S+B(*;7-G<W1R(")3=75N82!S964@:VER
M:2!E9&%S:2(*"B,Z(&QI8B]&;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE
M<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B4W5L(&5I(/5N
M;F5S='5N=60@=&5L;&ED82!K875S=&$@7"(E<UPB+B!397)V97(@_'1L97,B
M"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(BX@2&5R92!I
M<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")3=6P@96D@]6YN97-T
M=6YU9"!T_&AI<W1A9&$@:V%U<W1A(%PB)7-<(B!T96QL:6UU<W0N(%-E<G9E
M<B#\=&QE<R(*"B,Z(&QI8B]&;VQD97(N<&AP.C4Q,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R!<
M(B5S7"(B"FUS9W-T<B`B4V$@=&5L;&ES:60@:V%U<W1A(%PB)7-<(BXB"@HC
M.B!L:6(O1F]L9&5R+G!H<#HU-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*
M;7-G<W1R(")382!L;V]B=7-I9"!K875S=&$@7"(E<UPB('1E;&QI;75S97-T
M+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHY.`HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!.86UE(@IM<V=S='(@(E-I;G4@=.1I<VYI;6DZ(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C4P"FUS9VED(")9;W5R(%!'4"!0=6)L:6,O
M4')I=F%T92!+97ES(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-S$@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<V"FUS9VED(")9
M;W5R(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<Q"B,L(&9U
M>GIY"FUS9VED(")9;W5R(%!U8FQI8R!+97DB"FUS9W-T<B`B4VEN=2!TY&ES
M;FEM:3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"B,L(&9U>GIY
M"FUS9VED(")9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L
M*3PO96T^(@IM<V=S='(@(E-I;G4@5F%S=&$Z(&%A9')E<W,Z(#QI/BAP;VQE
M(&MO:'5S='5S;&EK*3PO:3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T
M:69I8V%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A
M8V-O=6YT7W-E;&5C="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@86-C
M;W5N=',Z(@IM<V=S='(@(E-I;G4@:61E;G1I=&5E9&ED.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-S,*;7-G:60@(B(*(EEO=7(@86QI87,@861D
M<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@
M82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G
M92!T>7!E+B(*;7-G<W1R("(B"B)3:6YU(&)R;W=S97(@96D@=&]E=&$@<V5D
M82!P<FEN=&EM:7-E(';U:6UA;'5S="X@5F%J=71A('!R:6YT:6UI<V5K<R!#
M=')L*U`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B
M66]U<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN
M8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R
M('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")9;W5R(&UE<W-A
M9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(DMA=7-T
M(%PB)7-<(B!O;B!JY.1D879A;'0@:W5S='5T871U9"XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS
M9W-T<B`B4VEN=2!A;&QK:7)I.B(*"B,Z(&UE<W-A9V4N<&AP.C(X."!C;VUP
M;W-E+G!H<#HQ,C@T(&UA:6QB;W@N<&AP.C4T.2!L:6(O0V]M<&]S92YP:'`Z
M.#$X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6U1E96UA('!U=61U
M8ETB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*(RP@
M9G5Z>GD*;7-G:60@(E]"8V,B"FUS9W-T<B`B0F-C(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")?0FQA8VML:7-T
M(@IM<V=S='(@(DUU<W0@;FEM96MI<FDB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHQ-30*(RP@9G5Z>GD*;7-G:60@(E]#8R(*;7-G<W1R
M(")+;V]P:6$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED
M(")?1&5L971E(@IM<V=S='(@(DMU<W1U=&$B"@HC.B!L:6(O24U0+G!H<#HY
M-SD*(RP@9G5Z>GD*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@(DMA=7-T860B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,0HC+"!F=7IZ
M>0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@(DED96YT:71E970B"@HC.B!L
M:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G<W1R("(B"@HC.B!L
M:6(O24U0+G!H<#HQ,#(P"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U="(*;7-G
M<W1R("),;V=I(';D;&IA(@H*(SH@;65S<V%G92YP:'`Z,S@T"B,L(&9U>GIY
M"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T<B`B2VER:F$@86QG=&5K
M<W0B"@HC.B!L:6(O24U0+G!H<#HY-S8*(RP@9G5Z>GD*;7-G:60@(E].97<@
M365S<V%G92(*;7-G<W1R(")5=65D(&MI<FIA9"(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B
M7U!R:6YT(@IM<V=S='(@(E!R:6YD:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(W,B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHR.#D*;7-G:60@(E]0<FEO<FET>2(*;7-G<W1R("(B"@HC.B!M86EL8F]X
M+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E]2969R97-H
M("5S(@IM<V=S='(@(E;D<G-K96YD82(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED(")?4F5P;'DB
M"FUS9W-T<B`B5F%S=&$B"@HC.B!L:6(O24U0+G!H<#HY.#$*(RP@9G5Z>GD*
M;7-G:60@(E]396%R8V@B"FUS9W-T<B`B3W1S:6YG(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#,Q"B,L(&9U>GIY"FUS9VED(")?4V5N9"!-97-S86=E(@IM
M<V=S='(@(E-A861A(&MI<FDB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")?5&AR96%D(@IM
M<V=S='(@(DIU='5L]6YG(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,3$V"B,L(&9U>GIY"FUS9VED(")?5&\B"FUS9W-T<B`B2V5L;&5L
M92(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"B,L(&9U
M>GIY"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`B5&%A<W1A(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"B,L(&9U>GIY
M"FUS9VED(")?5FEE=R!4:')E860B"FUS9W-T<B`B2G5T=6SU;F<B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W-@IM<V=I9"`B861D
M<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0T,`HC+"!F=7IZ>0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R("),:7-A
M;F0B"@HC.B!V:65W+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B871T86-H;65N
M=',N>FEP(@IM<V=S='(@(DQI<V%N9&ED(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B>71E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,C`P"FUS9VED(")C86YN;W0@8W)E871E(&]U
M='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S(*
M;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ-C0*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(P"FUS9VED(")C
M;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ.38*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V.`IM<V=I9"`B9&%T
M82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C(R-`IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")F<F]M
M(@IM<V=S='(@(FME;&QE;'0B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@P"FUS
M9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,C`T"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X.`IM<V=I9"`B:6YT97)N86P@
M<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(Y('!G
M<"YP:'`Z-CD*;7-G:60@(FME>2(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R(")+
M:7)J86MA<W0B"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H
M<#HT-C8*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T<B`B3FEM:2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N
M92(*;7-G<W1R(")%:2!M:61A9VDN+BXB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*;7-G<W1R(")V]6DB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,C$V"FUS9VED(")P97)M:7-S:6]N(&1E;FEE
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$R"FUS9VED(")R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$X-`IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*
M;7-G:60@(G-P96QL:6YG(&5R<F]R(@IM<V=S='(@(FMI<FIA=FEG82(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E
M;&QI;F<@97)R;W)S(@IM<V=S='(@(FMI<FIA=F5A9"(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G
M<W1R(")K:7)J879I9V$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`X"FUS9VED
M(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R
M+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T
M<B`B375S="!N:6UE:VER:2(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED
M(")Y;W5R('=H:71E;&ES="(*;7-G<W1R("(B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O<&\O4D5!1$U%````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#(S`#$P-#$W,S8R-S8T`#`Q-C4P,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!S964@:&]R9&4O<&\O4D5!1$U%````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+W)U7U)5+G!O````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0S,S(R,0`Q,#0Q-S,V
M,C<V-``P,3<R,C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!)35`@4G5S<VEA;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG
M:'0@*$,I"B,@06YT;VX@3F5K:&]R;W-H:6@@/&%N=&]N0'9A;'5E:&]S="YR
M=3XL(#(P,#$*(R!&961O<B!!+B!&971I<V]V(#QF869`<W-C+G)U/BP@,C`P
M,@HC($%L97AE>2!:86MH87)O=B`\8F%B97)`;6]S9V$N;F5T/BP@,C`P-@HC
M"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!)35`@
M2#,@=C0N,2U20S-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ
M-R`Q-SHP,RLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$W
M(#$W.C,P*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@06QE>&5Y(%IA:VAA
M<F]V(#QB86)E<D!M;W-G82YN970^7&XB"B),86YG=6%G92U496%M.B!2=7-S
M:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@
M,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0U`Q
M,C4Q7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z-#(Y"B,L(&9U>GIY"FUS9VED("(@("`@("!#
M8SH@(@IM<V=S='(@(B`@("`@(,KN[/,Z(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0R-@IM<V=I9"`B("`@("`@5&\Z("(*;7-G<W1R("(@("`@("#*[NSS.B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,30*;7-G:60@(B`@("!$871E.B`B"FUS
M9W-T<B`B("`@(,3@\N`Z(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q-PIM<V=I
M9"`B("`@($9R;VTZ("(*;7-G<W1R("(@("`@SO(@ZN[C[CHB"@HC.B!M86EL
M8F]X+G!H<#HT,#D@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C0R,PIM<V=I9"`B(%-U8FIE8W0Z("(*;7-G
M<W1R("(@TN7LX#H@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C<P"FUS9VED("(@:6X@(@IM<V=S='(@(B#B("(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C<R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I
M(@IM<V=S='(@(LCQ[^[K_.?NXN#M[CH@)2XR9LSA(.CG("4N,F;,X2`H)2XR
M9B4E*2(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA
M=`HC.B!T:')E860N<&AP.C$U-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!-
M97-S86=E<R(*;7-G<W1R("(E9"#Q[N[A^>7MZ.DB"@HC.B!M86EL8F]X+G!H
M<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+/[NK@Y_OBX/+\(/'N[N'Y
MY>WH_R#J[O+N\/OE(._P[OCKZ"#WY?#EYR#TZ.O\\O`N(@H*(SH@;&EB+U-P
M86TN<&AP.C$Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)60@
M;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(L[A(/WR[NP@[^CQ
M_.SE+"#JX.H@[B#Q[^#LY2#A^^ON(/'N[N'YY>WN(.#D[.CMZ/'R\.#R[O#S
M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@
M<W!A;2XB"FUS9W-T<B`BSN$@_?+N["#OZ/'\[.4L(.K@ZB#N(/'OX.SE(.'[
MZ^X@\>[NX?GE[>X@X.3LZ.WH\?+PX/+N\/,N(@H*(SH@;&EB+U-P86TN<&AP
M.C$X.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@
M:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`BSN$@_?+N["#OZ/'\[.4L(.K@ZB#N(/'O
MX.SE(.'[Z^X@\>[NX?GE[>X@X.3LZ.WH\?+PX/+N\/,N(@H*(SH@;&EB+U-P
M86TN<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S
M<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(L[A
M(/WR[NP@[^CQ_.SE+"#JX.H@[B#Q[^#LY2#A^^ON(/'N[N'YY>WN(.#D[.CM
MZ/'R\.#R[O#S+B(*"B,Z(&UA:6QB;W@N<&AP.C,U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"#O
M[B`E9"#HYR`E9"#Q[N[A^>7MZ.DB"@HC.B!M86EL8F]X+G!H<#HV,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9;W5R
M("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@(B5S(//FY2#Q
M\_GE\N+SY?(N(,+@^.`@)7,@[^#OZN`@[>4@X?OKX"#OY?#EZ.SE[>[BX.W@
M+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV.#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E
M;G1M86EL7VUO;G1H;'DN<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N
M=&@N(@IM<V=S='(@(B5S(._@[^K@(.'SY.7R(._E\.7H[.7M[N+@[>`@XB#M
MX/?@Z^4@[.7Q__;@+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@8V%N8V5L;&5D(%PB)7-<
M(BXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(
M,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(L_@[^K@(%PB)7-<(B#A^^O@(//Q
M[^7X[>X@[^7PY>CLY>WNXN#MX"#B(%PB)7-<(BY<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[J
MX"`E<R#HYR`E<UU<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S
M+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E<UU<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN
M(@HB6_'R\.[JX"`E<R#HYR`E<UU<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E
M<UU<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M
M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E<UTB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!D96-L:6YE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C0Y,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0
M('8T+C`N,BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBSOCHX>K@(.[R[_#@
MXNKH(._H\?SLX#H@)7-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L[XZ.'JX"#N\N_PX.+JZ"#O
MZ/'\[.`Z("5S7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP
M+C,I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-
M4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@[O+O\.#BZN@@[^CQ_.S@
M.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H92!I
M;G9I=&%T:6]N('1O(%PB)7-<(BXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(L_E
M\.7MX._PX.+H\OP@_?+N(/'N[N'YY>WHY5QN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN
M(.?@X_#SY^CR_"#N[_#EY.7KY>WHY2`E<RY<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HBS>7B[N?L[N;M
M[B#GX./P\^?H\OP@[N_PY>3EZ^7MZ.4@)7,N7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(LWEXN[G[.[F
M[>X@Y^#C\//GZ/+\(.[O\.7DY>OE[>CE("5S+EQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SN
MYNWN(.?@X_#SY^CR_"#N[_#EY.7KY>WHY2`E<RY<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HBS>7B[N?L
M[N;M[B#GX./P\^?H\OP@[N_PY>3EZ^7MZ.4@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0X,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`BSOCHX>K@(.[R[_#@XNKH(._H\?SLX#H@)7,B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN(@IM<V=S='(@(LCM].[P[.#VZ/\@[B#QY?#BY?#E(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC
M+2,*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M
M(RTC+2,*(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S
M+C`N,RD@(",M(RTC+2,M(PHC(&9U>GIY"B,@(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4X,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="!<(B5S7"(N(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N
M,BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@=C0N,"XR*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBPN#XX"#H
M[?3N\.S@]NC_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP
M+C,I("`C+2,M(RTC+2-<;B(*(L+@^.`@Z.WT[O#LX/;H_UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+"
MX/C@(.CM].[P[.#VZ/\B"@HC.B!L:6(O365S<V%G92YP:'`Z-#8S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`BS^#OZN`@7"(E<UPB(.'[Z^`@\_'O
MY?CM[B#OY?#EZ.SE[>[BX.W@(.(@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5S('=I<VAE<R!T;R!A;6UE;F0@7"(E<UPB+B(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N
M-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(UQN(@HBS^#OZN`@7"(E<UPB(.'[Z^`@\_'OY?CM[B#OY?#EZ.SE[>[BX.W@
M(.(@7"(E<UPB+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N
M,"XV*2`@(RTC+2,M(RTC7&XB"B);\?+P[NK@("5S(.CG("5S75QN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB
M"B);\?+P[NK@("5S(.CG("5S75QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B);\?+P[NK@("5S(.CG("5S
M75QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC
M+2,M(RTC7&XB"B);\?+P[NK@("5S(.CG("5S75QN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B);\?+P[NK@
M("5S(.CG("5S72(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W
M87)E(&]F(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U
M="!<(B5S7"(N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@=C0N,"XR*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M
M(UQN(@HBS>7B[N?L[N;M[B#GX./P\^?H\OP@[N_PY>3EZ^7MZ.4@)7,N7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC
M+2-<;B(*(LWEXN[G[.[F[>X@Y^#C\//GZ/+\(.[O\.7DY>OE[>CE("5S+EQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M
M(RTC7&XB"B+-Y>+NY^SNYNWN(.?@X_#SY^CR_"#N[_#EY.7KY>WHY2`E<RXB
M"@HC.B!M97-S86=E+G!H<#HR.3,@;65S<V%G92YP:'`Z,CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?=&]P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7,Z("5S
M("@E9"9N8G-P.^CG)FYB<W`[)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B*$%P<&QY('1H97-E(&-H86YG97,@
M86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*;7-G<W1R("(HT>[U\.#MZ/+\
M(.CG[.7MY>WH_R#H(._E\.7I\N@@Y.#KY>4I(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H
M86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G
M<W1R("(HSO+LY>WH\OP@XO'E(.CG[.7MY>WH_R#H(._E\.7I\N@@ZB#PY>3@
MZO+H\.[BX.WH_BDB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!497AT*2(*
M;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP:'`Z,C<Y"FUS9VED("(B"B(H4F5T
M=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@
M8VAA;F=E<R!M861E('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O;B!T:&4@8W5R
M<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(BC"
MY?#M\_+\\?\@XB#PY>3@ZO+N\"P@\>[U\.#MZ.(@XNWE\>7M[?OE(.CG[.7M
MY>WH_RXI(@H*(SH@<W!E;&QI;F<N<&AP.C(W-@HC+"!F=7IZ>0IM<V=I9"`B
M(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M
M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E
M96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(BC"Y?#M\_+\\?\@
MXB#PY>3@ZO+N\"P@\>[U\.#MZ.(@XNWE\>7M[?OE(.CG[.7MY>WH_RXI(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@
M(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B#$Z_\@
MY.[AX.+KY>WH_R#MX.;LZ/+E($]+("HB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D
M9')E<W,H97,I("HB"FUS9W-T<B`B*B#/[N;@Z_/I\?+@(.+[X>7PZ/+E(.#D
M\.7Q*.`I("HB"@HC.B!M86EL8F]X+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@
M(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+/\.[TZ.O\
M(%PB)7-<(B#A^^L@\^3@Z^7M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.3@*(RP@
M9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("+.X2#]\N[L(._H\?SLY2P@ZN#J(.X@\>_@[.4@X?OK[B#Q[N[A^>7M[B#@
MY.SH[>CQ\O#@\N[P\RXB"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L(&9U>GIY
M"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P
M86TN(@IM<V=S='(@(L[A(/WR[NP@[^CQ_.SE+"#JX.H@[B#Q[^#LY2#A^^ON
M(/'N[N'YY>WN(.#D[.CMZ/'R\.#R[O#S+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ
M.3`*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(L[A(/WR[NP@[^CQ_.SE+"#JX.H@[B#Q[^#LY2#A^^ON(/'N[N'YY>WN
M(.#D[.CMZ/'R\.#R[O#S+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S`*(RP@9G5Z
M>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M+B(*;7-G<W1R("+.X2#]\N[L(._H\?SLY2P@ZN#J(.X@\>_@[.4@X?OK[B#Q
M[N[A^>7M[B#@Y.SH[>CQ\O#@\N[P\RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#`X"B,L(&9U>GIY"FUS9VED("(Q,#`@8VAA<F%C=&5R<R(*;7-G
M<W1R("+1[^7VZ.#K_.W[Y2#QZ.SB[NO[(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Q,0HC+"!F=7IZ>0IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM
M<V=S='(@(M'OY?;HX.O\[?OE(/'H[.+NZ_LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#`Y"B,L(&9U>GIY"FUS9VED("(R-3`@8VAA<F%C=&5R<R(*
M;7-G<W1R("+1[^7VZ.#K_.W[Y2#QZ.SB[NO[(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@Q,`HC+"!F=7IZ>0IM<V=I9"`B-3`P(&-H87)A8W1E<G,B
M"FUS9W-T<B`BT>_E]NC@Z_SM^^4@\>CLXN[K^R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA
M<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA
M<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@
M(@HB<F5C:7!I96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+V9I96QD<RYI;F,Z-0IM<V=I9"`B04Y$(@IM<V=S='(@(L@B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3@R"B,L(&9U>GIY"FUS9VED(")!8V-E
M<'0@86YD(&%D9"!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP
M+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+3Y.#KZ/+\(._@\/-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC
M+2,M(UQN(@HBT^3@Z^CR_"#OX/#S7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A(;W)D92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(M/DX.OH\OP@[^#P\UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M
M(RTC7&XB"B+3Y.#KZ/+\(._@\/-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HBT^3@Z^CR_"#OX/#S7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC
M+2-<;B(*(M/DX.OH\OP@[^#P\UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B+3Y.#KZ/+\(._@\/-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M
M(UQN(@HBT^3@Z^CR_"#OX/#S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4X-0IM<V=I9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<T-@IM<V=I9"`B06-C97!T960B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U.`IM
M<V=I9"`B06-C97!T960Z("(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT)W,@
M;F%M93HB"FUS9W-T<B`BS_#N].CK_#HB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3(R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,C4*(RP@
M9G5Z>GD*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`BQ.7I\?+BZ.4B"@HC.B!L
M:6(O34E-12](96%D97)S+G!H<#HQ.3(@;&EB+TU)344O2&5A9&5R<RYP:'`Z
M,3DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,@=&\@;7D@
M061D<F5S<R!";V]K(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`S"B,L(&9U>GIY"FUS
M9VED(")!9&0@<V]U<F-E(@IM<V=S='(@(N3NX>#BZ/+\(/+EZO'R(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W,PHC+"!F=7IZ>0IM<V=I9"`B
M061D('1H:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N,BD@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N
M,"XS*2`@(RTC+2,M(RTC7&XB"B+3Y.#KZ/+\(._@\/-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBT^3@
MZ^CR_"#OX/#S7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP
M+C,I("`C+2,M(RTC+2-<;B(*(M/DX.OH\OP@[^#P\R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.#,*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M
M>2!C86QE;F1A<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC
M+2-<;B(*(M/DX.OH\OP@[^#P\UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+3Y.#KZ/+\(._@\/-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M
M(UQN(@HBT^3@Z^CR_"#OX/#S(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!C
M;VUP;W-E+G!H<#HU.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB(&%S(&%N(&%T=&%C:&UE;G0N(@IM<V=S='(@(M3@Z>L@7"(E<UPB(._P
MZ.KPY>_KY>T@ZB#OZ/'\[/,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3DX"FUS9VED("(B"B)!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES<&QA>2!W
M:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@:&5A9&5R
M("(*(F]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HBQ.[O[NOMZ/+E
MZ_SM[B#N\N[A\.#FX/+\(/'KY>3S_OGHY2#GX./NZ^[BZN@Z("`\96T^*.WE
M(.[A_^?@\N7K_.W[+"#JX.;D^^D@\2`B"B+M[N+NZ2#Q\O#NZN@I/"]E;3XB
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO
M;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("++Z/?M^^4@[>#Q\O#NZ>KH
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@
M9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<R(*
M;7-G<W1R("++Z/?M^^4@[>#Q\O#NZ>KH(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@;65S
M<V%G92!D971A:6QS(@IM<V=S='(@(LOH]^W[Y2#MX/'R\.[IZN@B"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D
M("5S+B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C<X"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@
M9&5T86EL<R(*;7-G<W1R("+$[N_NZ^WH\N7K_.W@_R#H[?3N\.S@]NC_(.[A
M(.[XZ.'JY2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<W"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D
M971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(L3N[^[K[>CRY>O\
M[>#_(.CM].[P[.#VZ/\@[N$@[OCHX>KE(.SNYN7R(.'[\OP@[_#N\>SN\O#E
M[>`@)7,N(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3(*
M;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*
M"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`IM<V=I9"`B
M061D<F5S<R!";V]K<R(*;7-G<W1R("+`Y/#E\>W[Y2#J[>CCZ"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*;7-G:60@(B(*(D%D9')E<W-E<R!T
M;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H
M(&%D9')E<W,@;VX@82!N97<@(@HB;&EN92D\+V5M/B(*;7-G<W1R("(B"B+-
MX._PX.+K__+\(.KN[^CH(.+QY?4@\>[NX?GE[>CI(.3@[>W[["#@Y/#E\>#R
MX.PZ("`\96T^*.WE(.[A_^?@\N7K_.W[+"`B"B+JX.;D^^D@\2#M[N+NZ2#Q
M\O#NZN@I/"]E;3XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"FUS
M9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I
M9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"`B"B)A9&1R97-S
M(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HBP.3PY?'@+"#N\NWN
M\?_YZ.7Q_R#J(.3@[>WN[/,@[_#N].CK_CH@(#QE;3XH[>4@[N'_Y^#RY>O\
M[?LL(.K@YN3[Z2#Q(.WNXN[I("(*(O'R\.[JZ"D\+V5M/B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3`@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Q,@IM<V=I9"`B06QL(@IM<V=S='(@(L+QY2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,@=&5M<&QA=&5S+V9O;&1E<G,O
M:F%V87-C<FEP="YI;F,Z-0IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('1H
M92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O
M(&]N92!-0D]8("(*(F9I;&4Z(@IM<V=S='(@(L+QY2#Q[N[A^>7MZ/\@XB#S
MZN#GX.WM[ND@[^#OZN4HX/4I(.'SY//R(._E\.7LY?GE[?L@XB#TX.GK($U"
M3U@Z(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP
M.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y
M;W5R(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@
M<&5R;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HBPO'E(/'N[N'Y
MY>WH_R#B("#"X/CEZ2#OX._JY2!<(B5S7"(@\?+@\/CE("5S(.3M_RCD[>7I
M*2#A\^3S\B#S[>CW\N[FY>WM^RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S
M:R]D96QE=&5?871T86-H;65N='-?;6]N=&AL>2YP:'`Z-3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S
M(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS
M9W-T<B`BPO'E(._@[^KH(.[R[_#@XNOE[>W[]2#Q[N[A^>7MZ.D@\?+@\/CE
M("5S(.SE\?_VY>(@X?/D\_(@\^3@Z^7M^RXB"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@
M(L+QY2#OX._JZ"#N\N_PX.+KY>WM^_4@\>[NX?GE[>CI(/'RX/#XY2`E<R#L
MY?'_]N7B(.'SY//R(//DX.OE[?LN(@H*(SH@86-L+G!H<#HX-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(')I9VAT<R!O;B!F;VQD97(@7"(E
M<UPB('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U<V5R(%PB)7-<(BXB"FUS
M9W-T<B`BS^#OZN`@7"(E<UPB(.'[Z^`@\_'OY?CM[B#OY?#EZ.SE[>[BX.W@
M(.(@7"(E<UPB+B(*"B,Z(&QI8B]A<&DN<&AP.C<V"FUS9VED(")!;&QO=R!&
M;VQD97(@0W)E871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U;&5S('1O
M(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$P"FUS9VED(")!;'1E
M<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*;7-G<W1R("+`Z_SR
MY?#MX/+HXNW[Z2#BZ.0@_?+NX^X@\>[NX?GE[>C_.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-S(*(RP@9G5Z>GD*;7-G:60@(D%L=V%Y<R(*;7-G
M<W1R("+/\>7BY.[MZ.PB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-3<*;7-G:60@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(@IM<V=S
M='(@(L+QY>/DX"#Q[O7PX.W_\OP@XNONYN7MZ/\B"@HC.B!L:6(O365S<V%G
M92YP:'`Z-34T"FUS9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T
M=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0('-E
M<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C0S-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D
M('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T92XB"FUS9W-T<B`BS>7HY^+E
M\?+MX/\@[OCHX>K@(._PZ"#D[N'@XNOE[>CH(.WNXN[I(.?@[^CQZ"XB"@HC
M.B!L:6(O365S<V%G92YP:'`Z-#,V"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN
M;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K
M+B(*;7-G<W1R("+-Y>CGXN7Q\NW@_R#N^.CAZN`@[_#H(.3NX>#BZ^7MZ.@@
M[>[B[ND@Y^#OZ/'H+B(*"B,Z(&UE<W-A9V4N<&AP.C4P-"!M86EL8F]X+G!H
M<#HW,#D@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHY
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3@@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T96UP;&%T97,O;6%I;&)O>"]L
M96=E;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(L[RXN7WY>WM
M^^4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS9VED(")!
M;G-W97)E9"!M97-S86=E<R(*;7-G<W1R("+.\N+E]^7M[?OE(/'N[N'YY>WH
M_R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW
M"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(L+JZ_[WZ/+\(/3HZ_SR
M\.#VZ/XB"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z('1E;7!L871E<R]M86EL
M8F]X+VAE861E<BYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<'!L>2!&
M:6QT97)S('1O("5S(@IM<V=S='(@(L+JZ_[WZ/+\(/3HZ_SR\.#VZ/X@Y.O_
M("5S(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,S8*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_
M(@IM<V=S='(@(L_PZ.SE[>CR_"#O\.#BZ.O@(/3HZ_SR\.#VZ.@@[_#H(.+U
M[N3E(.(@\>CQ\N7L\R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C0R"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V
M97(@24Y"3U@@:7,@9&ES<&QA>65D/R(*;7-G<W1R("+/\.CLY>WH\OP@[_#@
MXNCKX"#TZ.O\\O#@]NCH(._PZ"#NX>WNXNOE[>CH(._N]_+NXN[C[B#_^>CJ
MX"XB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z
M,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI
M<R!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N/R(*;7-G<W1R("+"^R#SXN7P
MY>W[+"#W\NX@]>[RZ/+E(/'DY>O@\OP@_?+N/R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L
M(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E
M('1H:7,@<'5B;&EC(&ME>3\B"FUS9W-T<B`BPOL@\^+E\.7M^RP@]_+N(/7N
M\NCRY2#QY.7KX/+\(/WR[C\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME
M>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(L+[
M(//BY?#E[?LL(/?R[B#U[O+H\N4@\>3EZ^#R_"#]\NX_(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YJ<SHV"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&\@=&AI<S\B"FUS9W-T<B`BPOL@\^+E\.7M^RP@]_+N(/7N\NCRY2#QY.7K
MX/+\(/WR[C\B"@HC.B!M97-S86=E+G!H<#HT,#D@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM
M<V=S='(@(L+[(//BY?#E[?LL(/?R[B#U[O+H\N4@SLK.S=?`TL7+W,W.(//D
MX.OH\OP@_?+H(/'N[N'YY>WH_S\B"@HC(&9U>GIY"B,Z(&QI8B]-24U%+T-O
M;G1E;G1S+G!H<#HR,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT/R(*;7-G<W1R
M("+"^R#SXN7PY>W[+"#W\NX@]>[RZ/+E(,[*SLW7P-+%R]S-SB#SY.#KZ/+\
M(/WRZ"#BZ^[FY>WH_S\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y
M('1H:7,@9F]L9&5R/R(*;7-G<W1R("+"^R#SXN7PY>W[+"#W\NX@]>[RZ/+E
M(.[WZ/'RZ/+\(/WR\R#OX._J\S\B"@HC(&9U>GIY"B,Z(&QI8B])35`N<&AP
M.CDT.0HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&5M<'1Y('EO=7(@<W!A;2!F;VQD97(_(@IM<V=S='(@(L+[(//BY?#E[?LL
M(/?R[B#U[O+H\N4@[O?H\?+H\OP@ZN[PY^CM\S\B"@HC(&9U>GIY"B,Z(&QI
M8B])35`N<&AP.CDT,@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/R(*;7-G<W1R("+"^R#SXN7PY>W[
M+"#W\NX@]>[RZ/+E(.[WZ/'RZ/+\(.KN\.?H[?,_(@H*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE
M<W-A9V5S/R(*;7-G<W1R("+"^R#SXN7PY>W[+"#W\NX@]>[RZ/+E(,[*SLW7
MP-+%R]S-SB#SY.#KZ/+\(/WRZ"#Q[N[A^>7MZ/\_(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-SD*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT
M/R(*;7-G<W1R("+"^R#SXN7PY>W[+"#W\NX@]>[RZ/+E(.[WZ/'RZ/+\(/WR
M\R#OX._J\S\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN
M8SHW-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW-`HC+"!F
M=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T
M:&ES(&UE<W-A9V4@87,@<W!A;3\B"FUS9W-T<B`BPOL@\^+E\.7M^RP@]_+N
M(/7N\NCRY2#N]^CQ\NCR_"#]\O,@[^#OZO,_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP-0IM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(L+P
MY>S_(._NZ_/WY>WH_R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C`*
M;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R("+/[B#B[N?PX/'RX.WH_B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S$*;7-G:60@(D%S:R(*;7-G<W1R
M("+1[_#@^.CBX/+\(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT-S(*;7-G:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R("+/
M\.CJ\.7OZ/+\(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#4S"FUS9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K
M97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R("+/\.CK[N;H\OP@ZB#OZ/'\
M[/,@ZN[OZ/X@[_/AZ^CW[>[C[B!01U`@ZNO^]^`_(@H*(R!F=7IZ>0HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3$Q"FUS9VED(")!='1A8VAE9"!&
M:6QE.B(*;7-G<W1R("+/\.CJ\.7OZ^7M[?OE.B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HT-C(@;&EB+T-O;7!O<V4N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A
M8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,W-PIM<V=I9"`B
M071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U
M('-E;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N
M9"YI;F,Z,38@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P,"!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHU-0IM<V=I9"`B071T86-H;65N
M="(*;7-G<W1R("+"Z^[FY>WHY2(*"B,Z(&%T=&%C:&UE;G0N<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D%T=&%C:&UE;G0@)7,@9&5L971E9"XB"FUS
M9W-T<B`BPNONYN7MZ.4@)7,@\^3@Z^7M[B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ,3(U"B,L(&9U>GIY"FUS9VED(")!='1A8VAM96YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(L[A[>[BZ/+\(.CM].[P[.#VZ/X@[B#BZ^[FY>WH__4B"@HC
M.B!C;VUP;W-E+G!H<#HQ,3`U(&QI8B]-97-S86=E+G!H<#HU,34*;7-G:60@
M(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP
M92(*;7-G<W1R("+"Z^[FY>WHY2#MY2#Q[O7PX.W_Z^[Q_"P@\NCO(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0W,`HC.B!L:6(O0V]M<&]S92YP:'`Z,3`Y
M,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`BPNONYN7MZ/\B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")!
M='1E;F1E97,B"FUS9W-T<B`BS_#HZO#E[^OE[>W[Y2(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!
M='1E;G1I;VXB"FUS9W-T<B`BQ.7I\?+BZ.4B"@HC.B!L:6(O075T:"]I;7`N
M<&AP.C0T"FUS9VED(")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C(X"FUS9VED("(B"B)!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S
M(&EN($A434P@;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*
M(F%D9')E<W-B;V]K/R(*;7-G<W1R("+.\N[A\.#FX/+\(.K@\/+H[>KH(.(@
M2%1-3"#Q[N[A^>7MZ/_U(.3K_R#@Y/#E\>#R[N(@Z.<@X.3PY?'M[ND@ZNWH
MX^@B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3@*
M(RP@9G5Z>GD*;7-G:60@(D%V86EL86)L92!!9&1R97-S(&)O;VMS.B(*;7-G
M<W1R("+$[O'R\^_M^^4@X.3PY?'M^^4@ZNWHX^@Z(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<Q-`IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B
M"FUS9W-T<B`B(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*
M;7-G:60@(D)A8U]K('1O("5S(@IM<V=S='(@(L+E\.WS\OSQ_R#B("5S(@H*
M(R!P:'`M9F]R;6%T"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0F%C:R!T;R`E<R(*;7-G<W1R("+"Y?#M\_+\\?\@XB`E<R(*"B,Z('1H
M<F5A9"YP:'`Z,3,T"FUS9VED(")"86-K('1O($UU;'1I<&QE($UE<W-A9V4@
M5FEE=R!);F1E>"(*;7-G<W1R("+([>3EZO$B"@HC.B!T:')E860N<&AP.C$S
M,@HC+"!F=7IZ>0IM<V=I9"`B0F%C:R!T;R!4:')E860@1&ES<&QA>2(*;7-G
M<W1R("+1[^CQ[NH@Y^#DX/<@[_/Q\BXB"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C4W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&QO9VEN
M(&YA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(L_NYN#K\^GQ\N`L(.+BY>3H
M\N4@PN#XZ"#H[/\@[^[K_.?NXN#RY>O_(.@@[^#P[NO\(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&]R
M(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4W-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")"860@<F5Q=65S=#H@)7,N(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C(W-"!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(R,@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(P(&QI
M8B]396%R8V@N<&AP.C8P,0IM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,0HC+"!F=7IZ>0IM<V=I
M9"`B0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M
M871I;VX@;65S<V%G92XB"FUS9W-T<B`BS^7PY>W@[_#@XNCR_"#]\NX@\>[N
MX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED
M(")";&%C:VQI<W0B"FUS9W-T<B`BU^7P[?OI(/'OZ/'NZB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV,3<*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(
M5$U,(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q
M=65S=&5D/R(*;7-G<W1R("+-Y2#N\N[A\.#FX/+\(.K@\/+H[>KH(.(@2%1-
M3"#Q[N[A^>7MZ/_U(@H*(SH@;&EB+U-E87)C:"YP:'`Z-C`Y"FUS9VED(")"
M;V1Y(@IM<V=S='(@(M+EZO'R(/'N[N'YY>WH_R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,C,@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS
M.0HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4U('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z-S$*;7-G:60@(D)O=&@B"FUS9W-T<B`BPNSE\?+E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-`IM<V=I9"`B0F]T:"!(
M96%D97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(L(@
MY^#C[NONXNKE(.@@XB#RY>OE(/'N[N'YY>WH_R(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z-3`Q"FUS9VED(")#4D%-+4U$-2!O<B!$24=%4U0M340U(')E
M<75I<F5S('1H92!!=71H7U-!4TP@<&%C:V%G92!T;R!B92!I;G-T86QL960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(W,@IM<V=I9"`B0U]H87)S970B"FUS9W-T<B`BRN[DZ/#NXNK@(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R("+%YN7MY>3EZ_SMZ.HB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO
M=&4@;6%I;"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E
M;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F
M('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G
M<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR-S`@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T
M+FEN8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*
M(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI
M;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I
M9"`B0V%N8V5L(@IM<V=S='(@(L[R[.7MX"(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0S,@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q
M"FUS9VED(")#86YC96P@365S<V%G92(*;7-G<W1R("+.\NSE[>CR_"#N\N_P
MX.+J\R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN
M9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C
M;VYT96YT<RXB"FUS9W-T<B`BS_#H(.[R[.7MY2#N\N_PX.+JZ"#]\N[C[B#Q
M[N[A^>7MZ/\@XO'E(.7C[B#Q[N3E\.;@[>CE(.'SY.7R(//RY?#_[>XN(@H*
M(SH@;65S<V%G92YP:'`Z,C<S('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z
M,34@;&EB+U-E87)C:"YP:'`Z-3DW"FUS9VED(")#8R(*;7-G<W1R(")#8R(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G:60@(B(*(D-E
M<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A
M9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-@HC+"!F=7IZ>0IM
M<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(LOH]^W[Y2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(LCG[.7MZ/+\(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(LCG[.7MZ/+\
M(,+QY2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B0VAA
M;F=E($9O;&1E<B(*;7-G<W1R("+(Y^SE[>CR_"#OX._J\R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3(*;7-G:60@(B(*(D-H86YG92!D:7-P;&%Y
M(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N
M(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S(&%R92!S;W)T960N(@IM
M<V=S='(@(B(*(LW@\?+P[NGJZ"#O\.[Q[.[R\.`@\>[NX?GE[>CI+B`HRN[K
MZ/?E\?+B[B#Q[N[A^>7MZ.D@[>`@\?+PX.WH]N4L(._N\/_D[NH@(@HB\>[P
M\NCP[N+JZ"XI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS9VED
M(")#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS
M9W-T<B`BS>#Q\O#NZ/+\(._@[^KH(.3K_R#PX.?KZ/?M^_4@[?/FY"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB
M"FUS9W-T<B`BS>#Q\O#NZ>KH(.CLY>WH+"#@Y/#E\>`L(._NY._H\>@N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q,PIM<V=I9"`B0VAA<F%C=&5R
M<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ-0IM<V=I9"`B0VAE8VL@1F]L9&5R*',I(&9O<B!.
M97<@36%I;"(*;7-G<W1R("+/\.[BY?#H\OP@[^[W\O,@XB#OX._JY2C@]2DB
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K
M(%]!;&PO3F]N92(*;7-G<W1R("+"^^3EZ^CR_"#B\>4B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]F971C:&UA:6PN:6YC.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S
M97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B
MQ^#A\.#R_"#O[O?R\R#Q(//JX.?@[>W[]2#O[O?R[N+[]2#QY?#BY?#NXCHB
M"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*;7-G:60@
M(D-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS
M9W-T<B`BS_#NXN7P__+\(.[P].[C\.#TZ/X@[^7PY>0@[O+O\.#BZN[I(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I9"`B0VAO
M;W-E($%C=&EO;CHB"FUS9W-T<B`BQ.7I\?+BZ.4Z(@H*(SH@8V]N9FEG+W-E
M<G9E<G,N<&AP+F1I<W0Z,C`R"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!M
M86EL('-E<G9E<CHB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,C$W"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!M871C:"!O
M<B!E9&ET('1H92!A9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`BS^[F
MX.OSZ?'RX"P@XOOAY?#H\N4@Z.OH(.[R\.7DX.KRZ/#SZ?+E.B(*"B,@9G5Z
M>GD*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"FUS
M9VED(")#:&]O<V4@=&AE(&%D9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I
M;F<@861D<F5S<V5S+B(*;7-G<W1R("+"^^'E\.CRY2#@Y/#E\>WS_B#J[>CC
M\R#DZ_\@Y.[AX.+KY>WH_R#B(.WEY2#@Y/#E\>[B+B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B
M0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W
M:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(L+[X>7PZ/+E(._N
M\/_D[NH@[^7PY>'N\.`@X.3PY?'M^_4@ZNWHXR#O\.@@[^[H\>KE(.#D\.7Q
M[N(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3$U"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E
M(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@
M:6UA9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M
M96YT('!A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL
M+G!H<#HQ,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S
M('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*
M;7-G<W1R("+1[N?DX/+\(._H\?SLX"#B(/#@Y^W[]2#NZNW@]2XB"@HC.B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@
M=&AI<R!I;6%G92XB"FUS9W-T<B`BT>[GY.#R_"#OZ/'\[.`@XB#PX.?M^_4@
M[NKMX/4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE
M(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(M'N
MY^3@\OP@[^CQ_.S@(.(@\.#G[?OU(.[J[>#U+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]R96QA=&5D+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A
M<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(M'NY^3@\OP@[^CQ
M_.S@(.(@\.#G[?OU(.[J[>#U+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL
M+G!H<#HY.`IM<V=I9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,B
M"FUS9W-T<B`BS>#FYNCRY2#GY.7Q_"#W\N[A^R#3PLC$Q=+<(.CG[N'PX.;E
M[>C_+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R
M,0HC+"!F=7IZ>0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L
M96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD
M<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(LKKZ.KMZ/+E(.S[^.KNZ2#O
M[B#B^^'PX.WNZ2#J[>CCY2#H+"#GX/+E["P@[O+LY?+\\N4@XO'E(._NZ_\@
MY.O_(._NZ/'JX"XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S`*
M;7-G:60@(D-L:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!
M9&1R97-S(&)O;VLB"FUS9W-T<B`BS>#F[.CRY2#GY.7Q_"#W\N[A^R#GX._H
M\>#R_"#O\^'KZ/?M^^D@ZNO^]R#B(.#D\.7Q[?/^(.KMZ./S(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@
M>6]U<B!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDS.0IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@
M=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G
M<W1R("+1[N?DX.WHY2#M[N+NX^X@\>[NX?GE[>C_(.3K_R#DX.WM[N/N(.#D
M\.7QX/+@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,`IM<V=I9"`B
M0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E
M('1O(&)E(')E860B"FUS9W-T<B`BSO+J\/ORZ.4@XO7NY/_YY>/N(._H\?SL
MX"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN
M:6YC.C(X"FUS9VED(")#;&]S92(*;7-G<W1R("+'X.KP^_+\(@H*(SH@8V]M
M<&]S92YP:'`Z-#$X"FUS9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R
M("(B"@HC.B!F;VQD97)S+G!H<#HT,3`*;7-G:60@(D-L;W-E9"!&;VQD97(B
M"FUS9W-T<B`BQ^#J\/ORX/\@[^#OZN`B"@HC.B!F;VQD97)S+G!H<#HT,S`*
M(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E(@IM<V=S='(@(M'BY?#M\_+\(.+Q
MY2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0P"FUS9VED
M(")#;VQL87!S92!!;&PB"FUS9W-T<B`BT>+E\.WS\OP@XO'E(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-#`*;7-G:60@(D-O;&QA<'-E
M($%L;"!&;VQD97)S(@IM<V=S='(@(M'BY?#M\_+\(.+QY2#OX._JZ"(*"B,Z
M(&9O;&1E<G,N<&AP.C0S,`IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM<V=S
M='(@(M'BY?#M\_+\(._@[^KS(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C4Q"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R
M("+6XN7R[N+NZ2#H[>3HZN#R[O`Z(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(LKN[.SE
M[?+@\.CI(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V,@HC+"!F
M=7IZ>0IM<V=I9"`B0V]M<&QE=&5D(@IM<V=S='(@(LWNXN[E(/'N[N'YY>WH
MY2(*"B,Z(&-O;7!O<V4N<&AP.C0Q-PHC+"!F=7IZ>0IM<V=I9"`B0V]M<&]S
M92!A;F]T:&5R(&UE<W-A9V4B"FUS9W-T<B`BT>[Q\N#BZ^7MZ.4@\>[NX?GE
M[>C_(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,T"FUS
M9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*
M;7-G<W1R("+1[N?DX.+@\OP@[>[B[N4@[^CQ_.SN(.(@[O+DY>O\[>[L(.[J
M[>4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0S"FUS9VED("(B"B)#
M;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H
M:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_(@IM<V=S='(@
M(L+JZ_[WZ/+\(.+HY_/@Z_SM^^D@\.7DX.KR[O`@[^X@\^SNZ_?@[>C^(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@
M:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S='(@(LW@\?+P[NGJ
MX"#PY>;H[.[B(.[R[N'PX.;E[>C_(/'N[N'YY>WHZ2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE
M=R!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,W,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-
M05`@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E
M\.+E\.[L($Q$05`N(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,S0*
M;7-G:60@(D-O;FYE8W1I;VX@=&\@<V5R=F5R(&9A:6QE9"(*;7-G<W1R("(B
M"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R
M="!F;W(@)7,N(@IM<V=S='(@(L_NY.3E\.;JX"#T\^WJ]NCI(%!'4"#DZ_\@
M)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G
M<W1R("+/[N3DY?#FZN`@]//MZO;HZ2!3+TU)344@Y.O_("5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM<V=I9"`B0V]N=')O;"!O<'1I;VYS
M(')E;&%T:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RXB"FUS9W-T<B`BS>#Q
M\O#NZ>K@(._@\.#LY?+P[N(L(/'B_^?@[>W[]2#Q(._NZ/'J[NP@\>[NX?GE
M[>CI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED("(B"B)#
M;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C:&5C:V5D(&9O<BP@86YD
M('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@(@HB=VAE;B!I="!A<G)I
M=F5S+B(*;7-G<W1R("+-X/'R\.[IZN@@[_#NXN7PZN@@[^[W\OL@Z"#HY^+E
M^>7MZ.D@[B#M[N+NZ2#O[O?RY2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C<T"FUS9VED(")#;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN=&\@
M9W)A<&AI8V%L(&]N97,_(@IM<V=S='(@(LKN[>+E\/+H\.[BX/+\(/+EZO'R
M[N+[Y2#][.[VZ.@@XB#C\.#TZ/?E\>KHY3\B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'DB"FUS9W-T<B`BRN[OZ/#NXN#R
M_"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0HC+"!F=7IZ>0IM
M<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T<B`B(._@[^K@(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T
M(@IM<V=S='(@(L[XZ.'JX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHQ-#`*;7-G:60@(D-O<G)E8W1E9"!497AT(@IM<V=S='(@(L_P
M[N+E\.7M[?OI(/+EZO'R(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VUP;&5T
M92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S(@IM<V=S='(@(LWE(.SNX_,@
M[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&%T=&%C
M:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M365S<V%G92YP:'`Z-C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@
M<V%I9#H@)7,B"FUS9W-T<B`BSOCHX>K@(._PZ"#SY.#KY>WHZ"#OZ/'E["#H
MYR#OX._JZ"!<(B5S7"(N(-'E\.+E\"#N\N+E\NCK(@H*(SH@;&EB+U-E<W-I
M;VXN<&AP.C,S,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&5X96-U=&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`BSN_E\.#VZ.@@SN'Q
MZ_/FZ.+@[>C_(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C4T"FUS
M9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O
M;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O>FEP+G!H<#HU.`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A
M8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H:79E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0T-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@<V5C=7)E(&-O
M;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R
M("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@
M;&EB+U-E<W-I;VXN<&AP.C(X,`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R
M=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L
M($Q$05`N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W
M('1E;7!L871E<R]A8VPO86-L+FEN8SHS.0HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,38Q"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C8*;7-G:60@(D-R96%T
M92!&;VQD97(B"FUS9W-T<B`BT>[GY.#R_"#OX._J\R(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I9"`B0W)E871E($ME>7,B
M"FUS9W-T<B`BT>[GY.#R_"#JZ_[WZ"(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I
M9"`B0W)E871E(&$@3F5W($%C8V]U;G0B"FUS9W-T<B`BT>[GY.#R_"#M[N+[
MZ2(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC
M.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-`IM<V=I9"`B
M0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(M'NY^3@\OP@[>[B
M\_X@[^#OZO,@Y.O_(/'OX.S@(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S
M='(@(M'NY^3@\OP@[>[B\_X@[^#OZO,@Y.O_(/?E\.WNXNCJ[N(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(V('1E;7!L871E
M<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#(*;7-G:60@(D-R96%T92!A
M(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(M'NY^3@\OP@[>[B\_X@
M[^#OZO,@Y.O_(.[R[_#@XNOE[>W[]2#Q[N[A^>7MZ.DB"@HC.B!T96UP;&%T
M97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]T
M<F%S:'-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!T<F%S:"!F
M;VQD97(B"FUS9W-T<B`BT>[GY.#R_"#M[N+S_B#J[O#GZ.WS(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R.`IM<V=I9"`B(@HB0W)E871E(&9I;'1E
M<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O
M<G0@:70@:6YT;R!F;VQD97)S+"`B"B)A;F0@9&5L971E('-P86TN(@IM<V=S
M='(@(B(*(M'NY^3@[>CE(/3HZ_SR\.[B(.3K_R#B]>[D__GEZ2#O[O?R^RP@
M\>[P\NCP[N+JX"#O[O?R^R#B(._@[^K@]2P@\^3@Z^7MZ.4@(@HB\>_@[.`N
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"FUS9VED
M(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`BT>[GY.#R_"#M[N+[
MZ2#XX.'K[NTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED
M(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S
M='(@(M'NY^3@\OP@^.#AZ^[M^R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C8V5S<R!T;R`E
M<R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#4*;7-G:60@(D-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@
M;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(*;7-G<W1R("(B"B+-X/'R\.[I
MZN`@XN[G[.[F[>[Q\N@@\>'N\.`@[^[W\OL@\2#BX/CH]2#O[O?R[N+[]2#_
M^>CJ[N(L(/#@\>_NZ^[FY>WM^_4@[>`@(@HBY/#SX^CU(/'E\.+E\.#U(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED(")#=7-T;VUI>F4@
M:&]W('EO=2!S96YD(&UA:6PN(@IM<V=S='(@(LW@\?+P[NGJX"#PY>;H[.[B
M(/'N\?+@XNOE[>C_(.WNXOOU(/'N[N'YY>WHZ2P@\>[U\.#MY>WH_R#WY?#M
M[N+HZN[B(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F
M=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*
M;7-G<W1R("+'X.3@]^@L(.+[[^[K[?_E[/OE(.(@[.[LY>WR(.+U[N3@(.(@
MS^[W\O,B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,3<*;7-G:60@(D1A=%]E(@IM<V=S='(@(L3@\N`B"@HC
M.B!M97-S86=E+G!H<#HR-S`@=&AR96%D+G!H<#HQ-3,*;7-G:60@(D1A=&4B
M"FUS9W-T<B`BQ.#RX"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M-3`*(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(M/DX.OE[>W[
MY2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C0*(RP@9G5Z>GD*
M;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`BT^3@Z^7M[?OE(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L
M="(*;7-G<W1R("+3Y.#KZ/+\(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')E
M9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z,C$*;7-G:60@(D1E9F%U;'0@
M4V5A<F-H($9I96QD(@IM<V=S='(@(L_NZ^4@[^[H\>K@(._N(//L[NOWX.WH
M_B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3(*;7-G:60@(D1E9F%U
M;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`BT>[P\NCP[N+JX"#O[B#S
M[.[K]^#MZ/XZ(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3(R"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*;7-G<W1R
M("+/[O#_Y.[J(/'N\/+H\.[BZN@B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S4X"B,L(&9U>GIY"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`B
MT^3@Z^7M[?OE(@H*(SH@9F]L9&5R<RYP:'`Z-#`P('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(T-"!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:6YC.C(X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM<V=I9"`B
M1&5L971E(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS
M9W-T<B`BPN#XY2#O[NOM[N4@Z.S_.B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*
M;7-G:60@(D1E;&5T92!#=7)R96YT($ME>7,B"FUS9W-T<B`BT^3@Z^CR_"#R
MY>KS^>CE(.KK_O?H(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G<W1R("+3Y.#KZ/+\
M(._@[^KS*.@I(@H*(R!F=7IZ>0HC.B!F;VQD97)S+G!H<#HR-S$*;7-G:60@
M(D1E;&5T92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(M/DX.OH\OP@XOOA
M\.#M[?OE(._@[^KH(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z-#(*;7-G:60@(D1E;&5T92!3=&%T:6]N97)Y(@IM<V=S
M='(@(M/DX.OH\OP@^.#AZ^[M(@H*(R!F=7IZ>0HC.B!F;VQD97)S+G!H<#HT
M,#`*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("+3Y.#K
MZ/+\(.+H\/+SX.O\[?/^(._@[^KS(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S(@IM<V=S='(@
M(M/DX.OH\OP@[^#OZO,HZ"DB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-#,*;7-G:60@(D1E;&5T92!F971C:&5D(&UE<W-A9V5S(&9R
M;VT@<F5M;W1E('-E<G9E<C\B"FUS9W-T<B`BT^3@Z^CR_"#O\.CM__+[Y2#Q
M[N[A^>7MZ/\@\>X@\?+N\.[M[>7C[B#QY?#BY?#@(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8Q.0IM<V=I9"`B1&5L971E(&9R;VT@;7D@8V%L
M96YD87(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V
M.`IM<V=I9"`B1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G
M:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R("+3Y.#K__+\(/'RX/#[Y2#BZ^[F
MY>WH_R#B(.W@]^#KY2#LY?'_]N`_(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S4P"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I;"!F
M;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BT^3@Z__R
M_"#OX._J\R#N\N_PX.+KY>WM^_4@\>[NX?GE[>CI(.(@[>#WX.OE(.SE\?_V
MX#\B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#4*;7-G
M:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM<V=S='(@(M/DX.O_\OP@\>_@
M["(*"B,Z(&UE<W-A9V4N<&AP.C4P-R!M86EL8F]X+G!H<#HW,S4@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R("+3Y.#KY>WM^^4B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A
M9V5S(@IM<V=S='(@(M/DX.OE[>W[Y2#Q[N[A^>7MZ/\B"@HC.B!C;VUP;W-E
M+G!H<#HU-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@
M=&AE(&%T=&%C:&UE;G0@7"(E<UPB+B(*;7-G<W1R("+3Y.#KY>WM^^D@[_#H
MZO#E[^OE[>W[Z2#TX.GK+B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S
M(@IM<V=S='(@(M/DX.OE[>W[Y2#Q[N[A^>7MZ/\B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3@W"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T,@HC+"!F=7IZ
M>0IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I
M;VXB"FUS9W-T<B`BR.WT[O#LX/;H_R#N(/'E\.+E\.4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@
M(L_N(//A^^+@[>C^(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V
M-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BSN_H\>#MZ.4B"@HC(&9U
M>GIY"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW-PIM<V=I9"`B1&5T86EL<R(*;7-G<W1R("+([?3N\.S@]NC_(@H*
M(SH@8V]M<&]S92YP:'`Z-3@R"B,L('!H<"UF;W)M870*;7-G:60@(D1I9"!N
M;W0@871T86-H(%PB)7-<(B!A<R!T:&4@9FEL92!W87,@96UP='DN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C4*;7-G:60@(D1I
M;2!S:6=N871U<F5S/R(*;7-G<W1R("+.\O+E[?_R_"#O[N3OZ/'H/R(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$
M:7-P;&%Y(@IM<V=S='(@(L[A[NON]^K@(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0W.0IM<V=I9"`B1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@
M<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(L[R[N'PX.;@\OP@[^[D\N+E
M\.;DY>WHY2#O[O'KY2#N\N_PX.+JZ"#Q[N[A^>7MZ/\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C@S"FUS9VED(")$:7-P;&%Y(&EN($)O9'D@;V8@
M365S<V%G92(*;7-G<W1R("+"(/+EZ^4@\>[NX?GE[>C_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I9"`B1&ES<&QA>2!P;W`M=7`@;F]T
M:69I8V%T:6]N(&]F(&YE=R!M86EL/R(*;7-G<W1R("+.\N[A\.#FX/+\(.+Q
M[^O[XN#^^>7E(/'N[N'YY>WHY2#O\.@@[_#H]>[DY2#O[O?R^S\B"@HC(&9U
M>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-#<*;7-G:60@(D1I<W!L
M87D@=&AE(%PB16UP='D@4W!A;5PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM
M<V=S='(@(L[R[N'PX.;@\OP@ZNWN[^KS("?.]^CQ\NCR_"#1[^#L)R#B(.+E
M\/7MY>P@[.7M_C\B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW,SD*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP='D@5')A<VA<(B!L:6YK
M(&EN('1H92!M96YU8F%R/R(*;7-G<W1R("+.\N[A\.#FX/+\(.KM[N_J\R`G
MSO?H\?+H\OP@ZN[PY^CM\R<@XB#BY?#U[>7L(.SE[?X_(@H*(R!F=7IZ>0HC
M.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,3$*;7-G:60@
M(D1I<W!O<VET:6]N(@IM<V=S='(@(M+H[R#BZ^[FY>WH_R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA=&-H
M(@IM<V=S='(@(LW%(/'NXN_@Y.#E\B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C$V"FUS9VED(")$;R!.;W0@0VAE8VL@1F]L9&5R*',I
M(&9O<B!.97<@36%I;"(*;7-G<W1R("+-Y2#O\.[BY?#_\OP@[^#OZO,HZ"D@
M[>`@[>[B\_X@[^[W\O,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30Q
M"FUS9VED(")$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C
M;VQU;6XB"FUS9W-T<B`BS>CJX.KNX^X@Y.7I\?+BZ/\B"@HC.B!L:6(O24U0
M+G!H<#HQ,#4S"FUS9VED(")$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L
M9&5R/R(*;7-G<W1R("+"^R#U[O+H\N4@[O+J\/OR_"#]\O,@[^#OZO,_(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,S$*;7-G:60@(D1O;B=T
M(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B1&]N92(*
M;7-G<W1R("+"^^_NZ^WE[>XB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z
M,C$V"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@
M1F]R;6%T(@IM<V=S='(@(L?@X_#SY^CR_"`E<R#B(.#P]>CB(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU,@IM<V=I9"`B
M1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I(@IM<V=S
M='(@(L?@X_#SY^CR_"#B\>4@XNONYN7MZ/\@XB#@\/7HXB(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS9VED(")$;W=N;&]A9"!&
M;VQD97(H<RDB"FUS9W-T<B`BQ^#C\//GZ/+\(._@[^KS*.@I(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B
M1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%TB"FUS9W-T<B`BQ^#C
M\//GZ/+\(._@[^KS*.@I(.(@X/#UZ.(B"@HC.B!L:6(O34E-12]#;VYT96YT
M<RYP:'`Z,C$V"FUS9VED(")$;W=N;&]A9"!I;B`N>FEP($9O<FUA="(*;7-G
M<W1R("+'X./P\^?H\OP@XB#@\/7HXB(*"B,Z(&UE<W-A9V4N<&AP.C4P-2!M
M86EL8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHQ,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(R
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;&5G96YD+FEN8SHY"FUS9VED(")$<F%F="(*;7-G<W1R("+7
MY?#M[N+HZN@B"@HC.B!F;VQD97)S+G!H<#HS-S,*(RP@9G5Z>GD*;7-G:60@
M(D1R869T(&9O;&1E<B(*;7-G<W1R("+/X._JX"#WY?#M[N+HZN[B.B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS9VED(")$
M<F%F=',@9F]L9&5R.B(*;7-G<W1R("+/X._JX"#WY?#M[N+HZN[B.B(*"B,@
M9G5Z>GD*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I9"`B12UM
M86EL($%D9')E<W,B"FUS9W-T<B`BP.3PY?$@12UM86EL(@H*(SH@;&EB+TUA
M:6QB;W@N<&AP.C,P,@IM<V=I9"`B14Y$(@IM<V=S='(@(B(*"B,@9G5Z>GD*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2
M.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T
M<B`BSMC(P<K`.B#"X/CE(/'N[N'YY>WHY2#MY2#A^^ON(.3N\?+@XNOE[>X@
M[^[K\_?@\N7K_B(*"B,Z(&9O;&1E<G,N<&AP.C0P,2!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z,3D*;7-G:60@(D5D:70B"FUS9W-T<B`BT.7D
MX.KRZ/#NXN#MZ.4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,3@*(RP@9G5Z>GD*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(M?E
M\.W[Z2#Q[^CQ[NHB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHQ,PIM<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(M#EY.#J
M\NCP[N+@\OP@].CK_/+P^R(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$V"B,L(&9U
M>GIY"FUS9VED(")%9&ET(%-E87)C:"!1=65R>2(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2-<;B(*(M#EY.#J\NCP[N+@\OP@Y^#O\.[Q7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A7:'5P<R`Q+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+0Y>3@ZO+H
M\.[BX/+\(@H*(R!F=7IZ>0HC(&9U>GIY"B,Z(&9O;&1E<G,N<&AP.C0P,2!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3<*;7-G:60@(D5D:70@5FER
M='5A;"!&;VQD97(B"FUS9W-T<B`BT.7DX.KRZ/#NXN#R_"#BZ/#R\^#K_.WS
M_B#OX._J\R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B!$969I
M;FET:6]N(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(D5D:70@5VAI=&5L:7-T
M(@IM<V=S='(@(M#EY.#J\NCP[N+@[>CE(,+@^.CU(._PX.+HZR#TZ.O\\O#@
M]NCH(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"B,L(&9U
M>GIY"FUS9VED(")%9&ET('EO=7(@8FQA8VML:7-T(@IM<V=S='(@(M#EY.#J
M\NCP[N+@[>CE(,+@^.CU(._PX.+HZR#TZ.O\\O#@]NCH(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$S"FUS9VED(")%9&ET('EO=7(@9FEL
M=&5R(')U;&5S(@IM<V=S='(@(M#EY.#J\NCP[N+@[>CE(,+@^.CU(._PX.+H
MZR#TZ.O\\O#@]NCH(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U,`IM
M<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H
M97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`BT.7DX.KRZ/#NXN#R_"#MX/'R
M\.[IZN@@\>'N\.`@[^[W\OL@\2#D\//CZ/4@\>7PXN7P[N(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(D5D
M:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`BT.7DX.KRZ/#NXN#MZ.4@PN#X
MZ/4@[_#@XNCK(/3HZ_SR\.#VZ.@B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C(S.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R("+1(.#D\.7QX"(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8Y-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;7!T
M:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("+.]^CYY>W[(.+Q
MY2#Q[N[A^>7MZ/\@Z.<@)7,B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&QI
M8B]-97-S86=E+G!H<#HV-S,*(RP@9G5Z>GD*;7-G:60@(D5M<'1I960@86QL
M(&UE<W-A9V5S(&9R;VT@5FER='5A;"!4<F%S:"!&;VQD97(N(@IM<V=S='(@
M(L[WZ/GE[?L@XO'E(/'N[N'YY>WH_R#HYR`E<R(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H<RDB
M"FUS9W-T<B`BSO?H\?+H\OP@[^#OZO,HZ"DB"@HC(&9U>GIY"B,Z(&9O;&1E
M<G,N<&AP.C(W,@IM<V=I9"`B16UP='D@4V5L96-T960@1F]L9&5R<R(*;7-G
M<W1R("+.]^CQ\NCR_"#B^^'PX.WM^^4@[^#OZN@B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@9F]L
M9&5R(@IM<V=S='(@(L[WZ/+H\OP@ZN[PY^CM\R(*"B,@9G5Z>GD*(SH@;&EB
M+TE-4"YP:'`Z.30Y"B,L(&9U>GIY"FUS9VED(")%;7!T>2!?4W!A;2(*;7-G
M<W1R("+.]^CRZ/+\(.KN\.?H[?,B"@HC(&9U>GIY"B,Z(&QI8B])35`N<&AP
M.CDT,@IM<V=I9"`B16UP='D@7U1R87-H(@IM<V=S='(@(L[WZ/+H\OP@ZN[P
MY^CM\R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$@=&5M
M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L92!01U`@
M9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`BPNKK_O?H\OP@[^[DY.7PYNKS(%!'
M4#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$@=&5M<&QA=&5S
M+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%,O34E-12!F
M=6YC=&EO;F%L:71Y/R(*;7-G<W1R("+"ZNO^]^CR_"!3+TU)344B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`P"B,L(&9U>GIY"FUS9VED(")%;F%B
M;&4@;65S<V%G92!P<F5V:65W<S\B"FUS9W-T<B`BS^7PY>_PX.+KY>WNY2#Q
M[N[A^>7MZ.4@[O(@)7,B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0S.0IM<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*
M;7-G<W1R("+8Z/3P[N+@[>CE(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C$X"FUS9VED(")%;F-R>7!T960B"FUS9W-T<B`B
MQ^#XZ/3P[N+@[>XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$V
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3@*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8U,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4S
M"B,L(&9U>GIY"FUS9VED(")%;F0B"FUS9W-T<B`BT.#GXN7P[?/R_"#B\>4B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,SDU"FUS9VED(")%;F0@9F]R=V%R9&5D
M(&UE<W-A9V4B"FUS9W-T<B`BRN[MY?8@[^7PY?'[Z^#E[.[C[B#Q[N[A^>7M
MZ/\B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S4R"B,L(&9U>GIY"FUS9VED(")%
M;F0@;65S<V%G92(*;7-G<W1R("+1\N#P^^4@\>[NX?GE[>C_(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C,U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M16YD(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("+/Y?#E[_#@XNOE[>[E(/'N
M[N'YY>WHY2#N\B`E<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")%;G1E<B!087-S
M<&AR87-E(@IM<V=S='(@(L+BY?'RZ"#OX/#NZ_PB"@HC.B!T96UP;&%T97,O
M<')E9G,O<W!A;7-E;&5C="YI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B16YT97(@
M=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(L+B
MY>3H\N4@Z.S_(._@[^KH(.3K_R#"X/CEZ2#M[N+NZ2#J[O#GZ.W[(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B16YT
M97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T
M<B`BPN+EY.CRY2#H[/\@[>[B[ND@[^#OZN@@Y.O_(/?E\.WNXNCJ[N(B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(S"FUS9VED
M(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E
M<B(*;7-G<W1R("+"XN7DZ/+E(.CL_R#M[N+NZ2#OX._JZ"#DZ_\@[O+O\.#B
MZ^7M[?OU(/'N[N'YY>WHZ2(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E
M;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W
M('1R87-H(&9O;&1E<B(*;7-G<W1R("+"XN7DZ/+E(.CL_R#OX._JZ"#DZ_\@
MPN#XY>D@[>[B[ND@ZN[PY^CM^R(*"B,@9G5Z>GD*(SH@;&EB+U-E87)C:"YP
M:'`Z-C$S"FUS9VED(")%;G1I<F4@365S<V%G92(*;7-G<W1R("+1[N[A^>7M
MZ.4@]N7KZ.KN["(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@;65S<V%G92YP
M:'`Z,3DU(&-O;7!O<V4N<&AP.C$Q-S(@=&AR96%D+G!H<#HW,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%;G1R>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(L?@[^CQ_"!<(B5S
M7"(@X?OKX"#D[N'@XNOE[>`@XB#@Y/#E\>WS_B#J[>CC\R(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C(Q"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@Q(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C,Y,`HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@
M(D5R<F]R(@IM<V=S='(@(L[XZ.'JX"(*"B,Z(&QI8B])34%0+T-L:65N="YP
M:'`Z-#,Q(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!C;VYN96-T:6YG('1O($E-05`@<V5R=F5R
M+B`E<R`Z("5S+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E
M\.+E\.[L($Q$05`N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q
M,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED
M(")%=F5N="!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`BS^#OZN`@
M7"(E<UPB(.'[Z^`@\_'OY?CM[B#SY.#KY>W@+B(*"B,@9G5Z>GD*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<W,0IM<V=I9"`B179E<GD@,34@;6EN=71E
M<R(*;7-G<W1R("+*X.;D^^4@,34@[.CM\_(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S8X"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@
M(LK@YN3[Y2`S,"#QY>KS[>0B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-S`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("+*
MX.;D^^4@-2#LZ.WS\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S(*
M;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+*X.;D^^4@[^[K]^#Q
MX"(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V.0IM<V=I
M9"`B179E<GD@;6EN=71E(@IM<V=S='(@(LK@YN3S_B#LZ.WS\O,B"@HC.B!F
M;VQD97)S+G!H<#HT,S@*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"(*;7-G<W1R
M("+0X.?BY?#M\_+\(.+QY2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C,Y"FUS9VED(")%>'!A;F0@06QL(@IM<V=S='(@(M#@Y^+E\.WS
M\OP@XO'E(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*
M;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R("+0X.?BY?#M\_+\
M(.+QY2#OX._JZ"(*"B,Z(&9O;&1E<G,N<&AP.C0S.`IM<V=I9"`B17AP86YD
M($9O;&1E<B(*;7-G<W1R("+0X.?BY?#M\_+\(._@[^KS(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E
M+W)E9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@
M(M#@Y^+E\.WS\OP@Z.SE[>`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`U,@IM<V=I9"`B17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O
M=R!A=71O;6%T:6-A;&QY(&EN('1H92!B86-K9W)O=6YD/R(*;7-G<W1R("+0
MX.?B[O#@]^CBX/+\(.CLY>W@(.#B\N[LX/+H]^7QZN@B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.38Y"FUS9VED(")%>'!A;F0@=&AE(&5N=&ER92!F
M;VQD97(@=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_(@IM
M<V=S='(@(M#@Y^+E\.WS\OP@Y.7PY>+N(._@[^[J(._N(//L[NOWX.WH_C\B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(T-2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z,3`Q"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V5?97AP86YD
M+FIS.C0Y"B,L(&9U>GIY"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T<B`BT.#G
MXN7P[?/R_"#B\>4B"@HC(&9U>GIY"B,@9G5Z>GD*(SH@;&EB+TE-4"YP:'`Z
M.38P(&QI8B])35`N<&AP.CDV,@IM<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T
M<B`BT>'N\"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C
M:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@
M(D9E=&-H($UA:6PB"FUS9W-T<B`BT>'N\"(*"B,@9G5Z>GD*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@U.`IM<V=I9"`B1F5T8V@@36%I;"!I;B!A('-E
M<&%R871E('=I;F1O=S\B"FUS9W-T<B`BT>[AZ/#@\OP@[^[W\O,@XB#N\N3E
MZ_SM[NP@[NKMY2XB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G
M:6YG(&]N/R(*;7-G<W1R("+/\.CM__+\(/'N[N'YY>WH_R#O\.@@XO7NY.4@
MXB#QZ/'RY>SS(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!L:6(O1F5T8VAM
M86EL+G!H<#HR.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M
M97-S86=E<R!F<F]M("5S(@IM<V=S='(@(L_PZ.W_\NX@)60@[^CQY>P@Z.<@
M)7,B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&QI8B]&971C:&UA:6PN<&AP
M.C(X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D(#$@;65S<V%G92!F
M<F]M("5S(@IM<V=S='(@(L_PZ.W_\NX@,2#Q[N[A^>7MZ.4@[O(@)7,B"@HC
M(&9U>GIY"B,@9G5Z>GD*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&
M971C:&UA:6PN<&AP.C(X.2!L:6(O1F5T8VAM86EL+G!H<#HR.3$*;7-G:60@
M(D9E=&-H;6%I;#H@(@IM<V=S='(@(M'A[O`@[^[W\OLZ("(*"B,@9G5Z>GD*
M(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDS"FUS9VED(")&971C:&UA:6PZ(&YO
M(&YE=R!M97-S86=E<RXB"FUS9W-T<B`BQ.O_(,+@\2#MY?(@[>[B^_4@\>[N
MX?GE[>CI+B(*"B,@9G5Z>GD*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")&
M:5]L=&5R<R(*;7-G<W1R("+4Z.O\\O#[(@H*(R!F=7IZ>0HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.38@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:G,Z-#`*;7-G:60@(D9I;&4B"FUS9W-T<B`BU.#IZR(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS,0HC+"!F=7IZ>0IM
M<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`BQ/#SX^CE(.W@\?+P[NGJ
MZ"(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHY"B,L(&9U>GIY
M"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`BS_#@XNCKX"#TZ.O\
M\O#@]NCH(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X.`IM<V=I9"`B
M1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R
M("+4Z.O\\O#NXN#R_"#Q[N3E\.;H[.[E(/'N[N'YY>WHZ3\B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$Q"FUS9VED(")&:6QT97(@
M<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B
MS^[DY.7PYNK@(/3HZ_SR\.#VZ.@@XB#BX/CEZ2#QZ/'RY>SE(.WE(.+JZ_[W
MY>W@(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS
M9VED(")&:6QT97)S(@IM<V=S='(@(M3HZ_SR\/LB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C
M=&EV92(*;7-G<W1R("+4Z.O\\O#@]NC_(,[2RLO>U\7-P"(*"B,Z(&QI8B]&
M:6QT97(N<&AP.C$S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97)S.B`E
M<R!M86YA9V5M96YT('!A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*;7-G:60@(D9I;F0B"FUS9W-T<B`B
MS>#I\N@B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.30*
M;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R("+/Y?#BX/\@\?+P
MX.WH]N`B"@HC.B!M86EL8F]X+G!H<#HS,S$*;7-G:60@(D9I<G-T(%!A9V4B
M"FUS9W-T<B`BS^7PXN#_(/'R\.#MZ/;@(@H*(R!F=7IZ>0HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O7W)W87)D(@IM<V=S='(@
M(L_E\.7QZ^#R_"(*"B,Z(&9O;&1E<G,N<&AP.C(U,B!T96UP;&%T97,O9F]L
M9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HU"FUS9VED(")&;VQD97(@06-T
M:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("+/[N3RXN7PYN3E[>CE(.3E
MZ?'RXNC_(/$@[^#OZN[I(@H*(SH@9F]L9&5R<RYP:'`Z,C@Y('1E;7!L871E
M<R]F;VQD97)S+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I
M86QP86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L
M<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T;W(B"FUS
M9W-T<B`BS>#BZ./@\N[P(._@[^[J(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,PIM<V=I9"`B1F]L9&5R(%-U;6UA<GDB"FUS9W-T<B`B
MT?+@\NCQ\NCJX"(*"B,Z(&%C;"YP:'`Z,C,*;7-G:60@(D9O;&1E<B!S:&%R
M:6YG(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HT-PIM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU.`IM<V=I9"`B1F]R
M;6%T(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@
M;65S<V%G97,@9&%T960@=&]D87DB"FUS9W-T<B`BU.[P[.#R(.[R[N'PX.;E
M[>C_(.3@\OL@Y.O_(/'N[N'YY>WHZ2P@[_#H^.7D^.CU(/'EX^[D[?\B"@HC
M.B!C;VUP;W-E+G!H<#HX,C`@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C$U"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C(Q"FUS9VED(")&;W)W87)D(@IM<V=S='(@(L_E\.7QZ^#R_"(*"B,Z(&-O
M;7!O<V4N<&AP.C@P-0IM<V=I9"`B1F]R=V%R9#HB"FUS9W-T<B`BS^7PY?'K
MX/+\.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#`*(RP@9G5Z>GD*;7-G:60@
M(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(LKN[>7V(._E\.7Q^^O@Y>SN
MX^X@\>[NX?GE[>C_(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,W.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S
M='(@(L_E\.7O\.#BZ^7M[N4@\>[NX?GE[>CE(.[R("5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0P,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E
M<W0@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(W"FUS9VED(")&<F]?;2(*
M;7-G<W1R("+.\B#J[N/N(@H*(SH@;65S<V%G92YP:'`Z,C<Q('1H<F5A9"YP
M:'`Z,34T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.CDY"B,Z(&QI
M8B]396%R8V@N<&AP.C4X.0IM<V=I9"`B1G)O;2(*;7-G<W1R("+.\B#J[N/N
M(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS9VED
M(")&<F]M($%D9')E<W,B"FUS9W-T<B`BP.3PY?$@[O+O\.#BZ/+EZ_\B"@HC
M.B!C;VUP;W-E+G!H<#HX,3<@8V]M<&]S92YP:'`Z.#(Q"FUS9VED(")&=V0Z
M(@IM<V=S='(@(D9W9#HB"@HC.B!C;VUP;W-E+G!H<#HQ,S$Q"B,L(&9U>GIY
M"FUS9VED(")&=V0Z("(*;7-G<W1R(")&=V0Z(@H*(SH@8V]M<&]S92YP:'`Z
M,3,Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1G=D.B`E=2!&;W)W
M87)D960@365S<V%G97,B"FUS9W-T<B`BRN[MY?8@[^7PY?'[Z^#E[.[C[B#Q
M[N[A^>7MZ/\B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1V5N
M97)A;"!/<'1I;VYS(@IM<V=S='(@(L[A^>CE(.W@\?+P[NGJZ"(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS-PIM<V=I9"`B1V5T(&]N
M;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*2(*;7-G<W1R("+/[NOS]^CR
M_"#R[NO\ZNX@[>[B^^4@\>[NX?GE[>C_("CDZ_\@24U!4"DB"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-34T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,C@*
M;7-G:60@(D=O(@IM<V=S='(@(L_E\.7I\N@B"@HC(&9U>GIY"B,Z('1H<F5A
M9"YP:'`Z,3,V"FUS9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@(L_E\.7I
M\N@@ZB#OZ/'\[/,B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@<&AP+69O<FUA
M=`HC.B!L:6(O24U0+G!H<#HU,#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T
M<B`BQ.[AX.+H\OP@XB#@Y/#E\>WS_B#J[>CC\R`H)7,I(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$S-@IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4U,"!L:6(O1FEL=&5R+G!H<#HQ,S$@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C$Q,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ,3,*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,3D*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C@*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,3<R"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R,"!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%4D4B"FUS9W-T<B`B
MQ\3%T=PB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S$@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R,`HC.B!L:6(O34E-12]6:65W
M97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@
M8V]M<&]S92YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")(5$U,(%9E<G-I;VX@
M;V8@365S<V%G92(*;7-G<W1R("+1Z^7D\_[YY>4@\>[NX?CE[>CE(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@(DAE861E
M<G,B"FUS9W-T<B`BQ^#C[NONXNKH(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M97-S86=E('EO
M=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C4V"FUS9VED(")(:61D96XB"FUS9W-T<B`B
MT>KP^^+@\OPB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-34*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE=R(*;7-G<W1R("+1ZO#[
MXN#R_"#O\.@@X_#S[^_H\.[BZN4B"@HC.B!M86EL8F]X+G!H<#HS-3,*;7-G
M:60@(DAI9&4@1&5L971E9"(*;7-G<W1R("+1ZO#[\OP@\^3@Z^7M[?OE(@H*
M(SH@9F]L9&5R<RYP:'`Z,C@T"FUS9VED(")(:61E(%5N<W5B<V-R:6)E9"(*
M;7-G<W1R("+1ZO#[\OP@[>7O[N3OZ/'@[>W[Y2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-`HC+"!F=7IZ>0IM<V=I9"`B2&EG:"(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP
M+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0('8T+C`N,BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@=C0N,"XR*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP
M+C,I("`C+2,M(RTC+2-<;B(*(LWHZN[CY.!<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBS>CJ[N/DX%QN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M
M(RTC7&XB"B+-Z.KNX^3@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(LWHZN[CY.!<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBS>CJ
M[N/DX%QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@
M(RTC+2,M(RTC7&XB"B+-Z.KNX^3@(@H*(SH@;65S<V%G92YP:'`Z,S`U(&UA
M:6QB;W@N<&AP.C<Q.2!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R
M"B,L(&9U>GIY"FUS9VED(")(:6=H(%!R:6]R:71Y(@IM<V=S='(@(L_E]^#R
M_"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,PIM<V=I
M9"`B2&EG:&5S="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C@U"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A
M8VAM96YT<S\B"FUS9W-T<B`BRN#JZ.P@[N'PX.?N["#N\N[A\.#FX/+\(.+K
M[N;E[>C_/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*;7-G:60@
M(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS
M9W-T<B`BRN#JZ.P@[N'PX.?N["#O[NSE]^#R_"#B\?+@XNOE[>W[Z2#B(.[R
MXN7R(.[PZ./H[>#K_.W[Z2#RY>KQ\CHB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$S-`IM<V=I9"`B24U!4"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H075T;R!$971E8W0@
M4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@
M=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38U(&QI8B]&971C
M:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V97(@4U-,(@IM<V=S
M='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,34R"FUS9VED("))
M34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C8*;7-G:60@
M(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R("(B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C,V.`HC+"!F=7IZ>0IM<V=I9"`B24U!4"!S
M97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R("+2Z.\@\?+N
M\.[M[>7C[B#O[O?R[N+NX^X@\>7PXN7PX#HB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$V-"!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM
M<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B
M"FUS9W-T<B`BT>7PXN7P(%!/4#,O24U!4"(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@;75S
M="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+B(*;7-G
M<W1R("(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?
M8V]N9FER;2YH=&UL.C$R"FUS9VED("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M
M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S="$B"FUS9W-T
M<B`BQ?'KZ"#B^R#O\.[D[NOFZ/+E+"#B\>4@\>[NX?GE[>C_(.(@[^#OZN4@
MX?/D\_(@\_+E\/_M^R$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G<W1R("+(X^WN\.CP[N+@\OPB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#,*;7-G:60@
M(DEG;F]R92!!;&PB"FUS9W-T<B`BR./M[O#H\.[BX/+\(.+QY2(*"B,Z('1E
M;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHX"B,L(&9U>GIY"FUS
M9VED("));6%G92(*;7-G<W1R("+*X/#RZ.WJZ"(*"B,@9G5Z>GD*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,`IM<V=I9"`B26UP;W)T(@IM
M<V=S='(@(LCL[^[P\NCP[N+@\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T97,O<&=P+VEM<&]R=%]K
M97DN:6YC.C8U"FUS9VED("));7!O<G0@2V5Y(@IM<V=S='(@(LCL[^[P\NCP
M[N+@\OP@ZNO^]R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$S.0IM<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`BR.SO[O#RZ/#N
MXN#R_"#OX/#S(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHR-PIM<V=I9"`B26UP;W)T($UE<W-A9V5S(@IM<V=S='(@(LCL
M[^[P\NCP[N+@\OP@\>[NX?GE[>C_(@H*(SH@<&=P+G!H<#HT,0HC+"!F=7IZ
M>0IM<V=I9"`B26UP;W)T(%!'4"!+97DB"FUS9W-T<B`BPN#F[?OE(@H*(R!F
M=7IZ>0HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDQ"FUS9VED("))
M;7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&4B"FUS9W-T<B`BR.SO[O#RZ/#N
MXN#R_"#OY?#Q[NW@Z_SM^^D@\>7P\NCTZ.K@\B(*"B,Z('1E;7!L871E<R]P
M9W`O:6UP;W)T7VME>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0
M<FEV871E(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC
M(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!097)S;VYA;"!3+TU)344@0V5R
M=&EF:6-A=&5S(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHT,"!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#(*;7-G
M:60@(DEM<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(LCL[^[P\NCP[N+@\OP@
M[_/AZ^CW[?OI(.KK_O<B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!U8FQI8R!01U`@2V5Y(@IM
M<V=S='(@(LCL[^[P\NCP[N+@\OP@[_/AZ^CW[?OI(.KK_O<@4$=0(@H*(R!F
M=7IZ>0HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I
M9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(LCL[^[P\NCP
M[N+@\OP@[_/AZ^CW[?OI(.KK_O<@4R]-24U%(@H*(R!F=7IZ>0HC.B!S;6EM
M92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@(LCL
M[^[P\NCP[N+@\OP@ZNO^]R!3+TU)344B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]I;7!O<G0N:6YC.CD*;7-G:60@(DEM<&]R="!M8F]X($9I;&4B"FUS9W-T
M<B`BR.SO[O#RZ/#NXN#R_"#O[O?R[N+[Z2#_^>CJ(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O:6UP;W)T+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G<W1R("+(
M[._N\/+H\.[BX/+\(/3@Z>L@)7,@XB#_^>CJ("5S(@H*(SH@;65S<V%G92YP
M:'`Z-3`V(&UA:6QB;W@N<&AP.C<R.2!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,S"B,Z('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM<V=I9"`B26UP;W)T86YT
M(@IM<V=S='(@(L+@YNW[Y2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z-#<*;7-G:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R("+"X.;M
M^^4@\>[NX?GE[>C_(@H*(SH@9F]L9&5R<RYP:'`Z,34Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S
M+B(*;7-G<W1R("+/Y?#E[_#@XNOE[>[E(/'N[N'YY>WHY2#N\B`E<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C8*(RP@9G5Z>GD*;7-G:60@
M(DEN(%!R;V-E<W,B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A)35`@=C0N,"XR*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M
M(RTC7&XB"B+`Y/#E\5QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@
M=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+`Y/#E\5QN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+`Y/#E\2(*
M"B,Z(&9O;&1E<G,N<&AP.C,V-2!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A
M9V5S96QE8W0N:6YC.C$T(&QI8B]&;VQD97(N<&AP.C@V"B,Z(&QI8B]&;VQD
M97(N<&AP.C(Q,2!L:6(O24U0+G!H<#HX,S`@;&EB+TE-05`O5')E92YP:'`Z
M,3$Y"B,Z(&QI8B])34%0+U1R964N<&AP.C(R,@IM<V=I9"`B26YB;W@B"FUS
M9W-T<B`BPO7NY/_YZ.4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR
M"FUS9VED("));F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R
M(&EN(&$@<F5P;'D_(@IM<V=S='(@(L+JZ_[WX/+\(/?@\?+\(.?@X^[K[N+J
MX"#OZ/'\[.`@[_#H(.[RXN7RY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.#<*;7-G:60@(DEN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E
M<&QY/R(*;7-G<W1R("+"ZNO^]^#R_"#RY>KQ\B#N\.CCZ.W@Z_SM[N/N(/'N
M[N'YY>WH_R#O\.@@[O+BY?+E(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3,P
M"B,L(&9U>GIY"FUS9VED("));F9O(@IM<V=S='(@(LCC[>[PZ/#NXN#R_"(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));F9O
M<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(L+@^.4@[^[K[>[E
M(.CL_SHB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(DEN
M9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0
M=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4P,0HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT
M<RYJ<SHU-@IM<V=I9"`B26YL:6YE(@IM<V=S='(@(N(@\N7J\?(B"@HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T
M($-E<G1I9FEC871E($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R
M:79A=&4@4$=0($ME>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O:6UP;W)T7VME>2YI;F,Z,3`*;7-G:60@(DEN<V5R="!097)S;VYA;"!0
M=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O:6UP;W)T7VME>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@
M2V5Y($AE<F4B"FUS9W-T<B`BPO'RX.+\\N4@[_/AZ^CW[?OI(%!'4"#JZ_[W
M(/+S\B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3,*;7-G:60@
M(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB
M"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-3<U(&UA:6QB;W@N<&AP.C8R
M,@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!!9&1R97-S(@IM<V=S='(@(M$@
MX.3PY?'@(@H*(R!F=7IZ>0HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C,P
M-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!296UO=&4@36%I;&)O>"(*;7-G
M<W1R("+/X._JX"#MX"#Q\N[P[NWMY>P@\>7PXN7PY3HB"@HC.B!C;VUP;W-E
M+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!C:&%R86-T
M97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R("(B"@HC.B!S;6EM
M92YP:'`Z-S@@<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K97DB"FUS9W-T
M<B`B(@H*(SH@<&=P+G!H<#HQ.3(*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@
M4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$V-PIM
M<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I
M9"`B26YV97)T(@IM<V=S='(@(LCMXN7P\NCP[N+@\OPB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU.3$*;7-G:60@(DM"(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,
M96YG=&@B"FUS9W-T<B`BQ.OH[>`@ZNO^]^`B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K
M92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y
M("(*(F=E;F5R871I;VX_(@IM<V=S='(@(L/E[>7PX/;H_R#JZ_[WY>D@[.[F
MY?(@Y^#M__+\(.[O\.7DY>OE[>WNY2#B\.7L_RX@T>/E[>7PZ/#NXN#R_"#J
MZ_[WZ#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N;W0@
M879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHS-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,SD*;7-G:60@(B(*(DME
M>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA=F4@;F\@861D<F5S
M<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@(@HB8V]N=&%C=',N(@IM<V=S
M='(@(B(*"B,Z('!G<"YP:'`Z,S$T"FUS9VED(")+97D@<W5C8V5S<V9U;&QY
M('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(LKK_O<@
M\_'OY?CM[B#O[O'KX.T@[>`@[_/AZ^CW[?OI(/'E\.+E\"(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$U"FUS9VED("),86YG=6%G92(*;7-G
M<W1R("+?Y_OJ(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#DU"FUS9VED("),87-T($UA:6QB;W@@4&%G92(*;7-G<W1R("+/[O'KY>3M
M__\@\?+PX.WH]N`B"@HC.B!M86EL8F]X+G!H<#HS-#0*;7-G:60@(DQA<W0@
M4&%G92(*;7-G<W1R("+/[O'KY>3M__\@\?+PX.WH]N`B"@HC(&9U>GIY"B,@
M9G5Z>GD*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30Y"FUS
M9VED("),:6YK($%T=&%C:&UE;G1S/R(*;7-G<W1R("+.\N_PX.+K__+\(.+K
M[N;E[>C_(.K@ZB#Q\?OKZN@B"@HC.B!A='1A8VAM96YT+G!H<#HS-"!L:6(O
M0V]M<&]S92YP:'`Z,3`X-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:V5D(&%T=&%C
M:&UE;G1S(&%R92!F;W)B:61D96XN(@IM<V=S='(@(L_PZ.KPY>_KY>WM^^4B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3$P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("),:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`W,0IM<V=I9"`B(@HB3&ES="!A;&P@8V]N
M=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D
M:7-A8FQE9"P@>6]U('=I;&P@(@HB;VYL>2!S964@8V]N=&%C=',@=&AA="!Y
M;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*2(*;7-G<W1R("+.\N[A\.#FX/+\
M(.(@X.3PY?'M[ND@ZNWHX^4@XO'E(.KN[?+@ZO+[/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.#(*;7-G:60@(DQI<W1I;F<@:6X@=&AE($AE861E
M<B(*;7-G<W1R("+"(.?@X^[K[N+JY2#Q[N[A^>7MZ/\B"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`IM<V=I9"`B3&]C
M86P@36%I;&)O>#HB"FUS9W-T<B`BS^#OZN`@[>`@Z^[JX.O\[>[L(/'E\.+E
M\.4Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W,0HC+"!F=7IZ
M>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BQ.7I\?+BZ.4B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R-`IM<V=I9"`B3&]G(&EN(@IM<V=S
M='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G<W1R("+"[NGRZ"#B
M("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S@*(RP@9G5Z
M>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(L+U[N0B"@HC(&9U>GIY"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS
M9W-T<B`BPO7NY"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C,P
M-R!M86EL8F]X+G!H<#HW,C(@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(L_E
M]^#R_"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-PIM
M<V=I9"`B3&]W97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A
M<'!L961O=6)L92YP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@(DUA8VEN=&]S:"!&
M:6QE(@IM<V=S='(@(L_N]_+NXOOE(/3HZ_SR\/LB"@HC(&9U>GIY"B,Z('1E
M;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PIM<V=I9"`B36%I;"(*
M;7-G<W1R("+/[O?RX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@HC
M+"!F=7IZ>0IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MS>#GX.0B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N
M:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z
M(@IM<V=S='(@(M+H[R#Q\N[P[NWMY>/N(._N]_+NXN[C[B#QY?#BY?#@.B(*
M"B,Z(&9O;&1E<G,N<&AP.C,V.2!F;VQD97)S+G!H<#HS.#,*;7-G:60@(DUA
M:6QB;W@B"FUS9W-T<B`BW_GHZN@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$Q"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I
M;VYS(@IM<V=S='(@(L_@\.#LY?+P^R#N\N[A\.#FY>WH_R#OX._NZB(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X"FUS9VED(")-87)K
M($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G<W1R("+/[NSE
M\NCR_"#B\>4@\>[NX?GE[>C_(.K@ZB#O\.[WZ/+@[>W[Y2(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")-87)K($%L;"!-
M97-S86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM<V=S='(@(L_N[.7RZ/+\
M(.+QY2#Q[N[A^>7MZ/\@ZN#J(.WE[_#N]^CRX.WM^^4B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C4@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHS,`IM<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`B
MSO+LY?+H\OP@ZN#J.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,S@*
M;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@
M9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`BPOODY>O_\OP@]N+E\N#LZ"#P
MX.?M^^4@\_#NXNWH(/;H\NCP[N+@[>C_(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E
M96X_("A)34%0(&]N;'DI(@IM<V=S='(@(L_N[.7RZ/+\(/'N[N'YY>WH_R#J
MX.H@[_#N]^CRX.WM^^4@*.3K_R!)34%0*2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-#8*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T
M<B`BS^[LY??@\OP@[_#N\?+S_B#PX.?LY?+J\S\B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-#D*;7-G:60@(DUA=&-H($%L;"!1=65R:65S
M(@IM<V=S='(@(L_N(,+1Q<P@ZO#H\N7PZ/_L(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C0U"FUS9VED(")-871C:"!!;GD@475E<GDB"FUS
M9W-T<B`BS^X@R][!SLS3(.KPZ/+E\.C^(@H*(R!F=7IZ>0HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#<*;7-G:60@(DUA>&EM=6T@071T
M86-H;65N="!3:7IE(@IM<V=S='(@(LS@ZO'H[.#K_.W[Z2#PX.?LY?`@XNON
MYN7MZ.DB"@HC.B!L:6(O87!I+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@1F]L9&5R<R(*;7-G<W1R("+,X.KQZ.S@Z_SM[N4@
MZN[KZ/?E\?+B[B#Q\O#@[>CV(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT.#D*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@
M;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N(@IM<V=S='(@(LS@ZO'H
M[.#K_.W[Z2#PX.?LY?`@XNONYN7MZ.DB"@HC(&9U>GIY"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X-0HC+"!F=7IZ>0IM<V=I9"`B36%X
M:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE9"XB"FUS9W-T<B`B
MS.#J\>CLX.O\[?OI(/#@Y^SE\"#BZ^[FY>WHZ2(*"B,Z(&QI8B]";&]C:R]T
M<F5E7V9O;&1E<G,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@1F]L9&5R
M($QI<W0B"FUS9W-T<B`BSO+J\/OR_"#OX._J\R(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HS-#(*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BT>[NX?GE[>CE(@H*
M(SH@8V]M<&]S92YP:'`Z-3DX(&-O;7!O<V4N<&AP.C8R-2!C;VUP;W-E+G!H
M<#HV-SD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P"FUS9VED(")-97-S86=E
M($-O;7!O<VET:6]N(@IM<V=S='(@(M'N\?+@XNOE[>CE(/'N[N'YY>WH_R(*
M"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-@IM<V=I9"`B
M365S<V%G92!$871E(@IM<V=S='(@(L+PY>S_(.[R[_#@XNKH(@H*(R!F=7IZ
M>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#D@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#<@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#,*;7-G:60@(DUE<W-A9V4@3W!T:6]N
M<R(*;7-G<W1R("+-X/'R\.[IZN@@\>[NX?GE[>CI(@H*(SH@<V5A<F-H+G!H
M<#HS,#8*;7-G:60@(DUE<W-A9V4@4V5A<F-H(@IM<V=S='(@(L_NZ/'J(/'N
M[N'YY>WH_R(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ
M,`IM<V=I9"`B365S<V%G92!3:7IE(@IM<V=S='(@(M#@Y^SE\"#Q[N[A^>7M
MZ/\B"@HC.B!M97-S86=E+G!H<#HS.3(*;7-G:60@(DUE<W-A9V4@4V]U<F-E
M(@IM<V=S='(@(LCQ]>[D[>CJ(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C8*;7-G:60@(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R("+/
M\.[Q[.[R\"#Q[N[A^>7MZ/\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`BS^[LY?+JZ"#Q
M[N[A^>7MZ/\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS
M9VED(")-97-S86=E(&9O;&1E<G,B"FUS9W-T<B`BS^#OZN@@\>[NX?GE[>CI
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,T,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B365S<V%G92!F<F]M("5S(@IM<V=S='(@(L_@[^KH(/'N[N'Y
MY>WHZ2(*"B,@9G5Z>GD*(SH@;6%I;&)O>"YP:'`Z-C8S"B,L(&9U>GIY"FUS
M9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R("+1[N+OX.3E
M[>CE.B(*"B,Z(&UA:6QB;W@N<&AP.C8U-`HC+"!F=7IZ>0IM<V=I9"`B365S
M<V%G92!I<R!E;F-R>7!T960B"FUS9W-T<B`BS^[K_R#Q[N[A^>7MZ.DB"@HC
M.B!M86EL8F]X+G!H<#HV-#D*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@
M<VEG;F5D(@IM<V=S='(@(L_NZ_\@\>[NX?GE[>CI(@H*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S8*;7-G:60@(DUE<W-A9V4@
M;6%T8VAE<R(*;7-G<W1R("+1[N+OX.3E[>CE.B(*"B,Z(&-O;7!O<V4N<&AP
M.C@V-"!C;VUP;W-E+G!H<#HX-S$*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@
M<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(M'N[N'YY>WHY2#S
M\>_E^.WN(.[R[_#@XNOE[>XL(.WN(.WE(/'N]?#@[>7M[B#B(@H*(R!F=7IZ
M>2P@<&AP+69O<FUA=`HC.B!C;VUP;W-E+G!H<#HQ,3(R"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@
M<V%V960@=&\@)7,B"FUS9W-T<B`BT>[NX?GE[>CE(//Q[^7X[>X@[O+O\.#B
MZ^7M[BP@[>X@[>4@\>[U\.#MY>WN(.(@)7,B"@HC(&9U>GIY"B,Z(&-O;7!O
M<V4N<&AP.C$Q.#$@8V]M<&]S92YP:'`Z,3$X.0IM<V=I9"`B365S<V%G92!S
M96YT('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BT>[NX?GE[>CE(//Q[^7X[>X@
M[O+O\.#BZ^7M[BXB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,S`*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X
M('9I97<N(@IM<V=S='(@(M'J[NO\ZNX@\>[NX?GE[>CI(.[R[N'PX.;@\OP@
M[>`@\?+PX.WH]N4B"@HC.B!M86EL8F]X+G!H<#HS,3$*;7-G:60@(DUE<W-A
M9V5S('1O(@IM<V=S='(@(M'N[N'YY>WH_R#B(@H*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB"FUS9W-T<B`BT.7DX.KRZ/#N
MXN#R_"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD
M(&9O<B!F:65L9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHU,`IM<V=I9"`B36]V92(*;7-G<W1R("+/Y?#E[.7Q
M\NCR_"(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q
M-@HC+"!F=7IZ>0IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(N_E\.7LY?'R
MZ/+\(.+MZ.<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`V"FUS9VED
M(")-;W9E('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C
M96YT(&UE<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(L_E\.7LY?G@\OP@\>_@
M["#B(/'OY?;HX.O\[?/^(._@[^KS+"#@(.WE(/'OX.P@XNX@PO7NY/_YZ.4B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*(RP@9G5Z>GD*;7-G
M:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@(N+[X>7PZ/+E(._@[^KS(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$T"B,L(&9U
M>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@(N_E\.7LY?'RZ/+\(.+BY?#U
M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G
M:60@(DUU;'1I<&%R="]A;'1E<FYA=&EV92(*;7-G<W1R("(B"@HC(&9U>GIY
M"B,@9G5Z>GD*(SH@=&AR96%D+G!H<#HW-B!T:')E860N<&AP.C$U-PIM<V=I
M9"`B375L=&EP;&4@365S<V%G92!6:65W(@IM<V=S='(@(L_P[O'L[O+P(/'N
M[N'YY>WHZ2(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S
M96%R8VAS96QE8W0N:6YC.C@*;7-G:60@(DY/3D4B"FUS9W-T<B`B+2#MY?(@
M+2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT."!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`BUB[3+B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV.#,*;7-G:60@(DYA;64B"FUS9W-T<B`BR.S_(@H*(SH@<&=P
M+G!H<#HQ,#8*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;FYO="!B92!E
M;7!T>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S<Q"B,L(&9U>GIY"FUS9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`BQ.7I
M\?+BZ.4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-C<*;7-G:60@(DYE=F5R(@IM<V=S='(@(LWHZN[C
MY.`B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C`*;7-G
M:60@(DYE=F5R('-A=F4@871T86-H;65N=',B"FUS9W-T<B`BS>CJ[N/DX"#M
MY2#Q[O7PX.W_\OP@XNONYN7MZ/\B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`BS>[B^^4B"@HC(&9U>GIY"B,Z
M(&QI8B])35`N<&AP.C4Y-0IM<V=I9"`B3F5W($9O;&1E<B(*;7-G<W1R("+-
M[N+@_R#OX._JX"(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#@*;7-G:60@(DYE=R!-86EL(@IM<V=S='(@(LWNXN#_(._N
M]_+@(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C$@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C(R"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E
M<G,N<&AP.C0V"FUS9VED(").97<@365S<V%G92(*;7-G<W1R("+-X._H\>#R
M_"(*"B,Z(&UA:6QB;W@N<&AP.C<W,2!L:6(O34E-12](96%D97)S+G!H<#HQ
M.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O
M("5S(@IM<V=S='(@(LWNXOOE(/'N[N'YY>WH_R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R
M("+-[N+[Y2#Q[N[A^>7MZ/\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3,S"FUS9VED(").97AT(@IM<V=S='(@(L3@Z^7E(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHS,PIM<V=I
M9"`B3F5X="!-97-S86=E(@IM<V=S='(@(M'KY>3S_OGEY2#Q[N[A^.7MZ.4B
M"@HC.B!M86EL8F]X+G!H<#HS-#(*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R
M("+1Z^7D\_[YY?\@\?+PX.WH]N`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU-#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-34S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-C8*;7-G:60@(DYO(@IM
M<V=S='(@(LWE\B(*"B,Z('-M:6UE+G!H<#HR,C(*;7-G:60@(DYO($-E<G1I
M9FEC871E(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO;B(*;7-G
M<W1R("+!Y><@^.CT\.[BX.WH_R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I;B!+97ER:6YG(@IM<V=S='(@(LWE\B#J
MZ_[WY>D@XB#QXO_GZN4B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&UA:6QB
M;W@N<&AP.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*
M;7-G<W1R("+-Y?(@\>[NX?GE[>CI(@H*(SH@<&=P+G!H<#HQ,S,*;7-G:60@
M(DYO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S;VYA
M;"!#97)T:69I8V%T92!0<F5S96YT(@IM<V=S='(@(LWE\B#OY?#Q[NW@Z_SM
M^_4@\>7P\NCTZ.K@\N[B(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,Q.0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT(@IM<V=S='(@(LW@Y^#D(@H*
M(R!F=7IZ>0HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$U"FUS9VED
M(").;R!0=6)L:6,@2V5Y<R!&;W5N9"(*;7-G<W1R("+/\^'KZ/?M^_4@ZNO^
M]^7I(.WE(.W@Z>3E[>XB"@HC.B!S;6EM92YP:'`Z,30W"FUS9VED(").;R!3
M+TU)344@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W1N968N<&AP.CDR"B,L(&9U>GIY"FUS9VED(").;R!A
M='1A8VAM96YT<R!F;W5N9"XB"FUS9W-T<B`BS_#HZO#E[^OE[>W[Y2(*"B,Z
M(&QI8B]#<GEP="]334E-12YP:'`Z,30P"FUS9VED(").;R!E;6%I;"!I;F9O
M<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+B(*;7-G<W1R("(B
M"@HC.B!A8VPN<&AP.C<Q(&%C;"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYO
M(&9O;&1E<B!S96QE8W1E9"XB"FUS9W-T<B`B[>4@XOOA\.#MX"#OX._JX"(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#D*;7-G:60@(DYO(&9O;&1E
M<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M86EL+B(*;7-G<W1R("(B
M"@HC.B!F;VQD97)S+G!H<#HR,#$@;&EB+T9O;&1E<BYP:'`Z-3`P(&QI8B]&
M;VQD97(N<&AP.C4U,`IM<V=I9"`B3F\@9F]L9&5R<R!W97)E('-P96-I9FEE
M9"(*;7-G<W1R("+"^R#MY2#SZN#GX.OH(._@[^KH(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C$U-0HC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R<R!W
M:71H(&YE=R!M97-S86=E<R(*;7-G<W1R("+-Y2#SY.#KY>WM^^4@\>[NX?GE
M[>C_(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$U,@HC+"!F=7IZ>0IM
M<V=I9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<R(*;7-G<W1R
M("+-Y2#SY.#KY>WM^^4@\>[NX?GE[>C_(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C,S-@HC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!B;V1Y('1E>'0B"FUS
M9W-T<B`BS^7PY>SE\?+H\OP@\>[NX>[YY>WH_R#B(@H*(SH@;&EB+TE-05`O
M0VQI96YT+G!H<#HU-C@*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@<F5T
M=7)N960N(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,@9G5Z>GD*(SH@;&EB+TUA
M:6QB;W@N<&AP.C,V,@IM<V=I9"`B3F\@;65S<V%G97,@;6%T8VAE9"!Y;W5R
M('-E87)C:"XB"FUS9W-T<B`BT>[NX?GE[>CI+"#SY.[BZ^7RXN[P__[YZ/4@
MZO#H\N7PZ/_L(._NZ/'JX"P@[>4@[>#IY.7M[B(*"B,Z('!G<"YP:'`Z,3@U
M"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N
M(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,38Q"FUS9VED(").;R!P97)S;VYA
M;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<VUI
M;64N<&AP.C$Y-PIM<V=I9"`B3F\@<&5R<V]N86P@4R]-24U%(&-E<G1I9FEC
M871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HR-#8@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDY"B,L
M(&9U>GIY"FUS9VED("(B"B).;R!P97)S;VYA;"!P<FEV871E(&ME>2!E>&ES
M=',@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB
M"FUS9W-T<B`B(@HBS^[DY.7PYNK@(/+E]>WNZ^[CZ.@@4$=0(.[R\?/R\?+B
M\^7R(.W@(.+@^.7L(/'E\.+E\.4L(._N_?+N[/,@[^[D[^CQ_"#MY2`B"B+L
M[N;E\B#A^_+\(._P[N+E\.7MX"(*"B,Z('-P96QL:6YG+G!H<#HR,C`*;7-G
M:60@(DYO('-P96QL8VAE8VMI;F<@<')O9W)A;2!C;VYF:6=U<F5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*
M;7-G:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G<W1R("+.^.CA[NH@[O#T
M[N/PX/3HZ"#MY2#MX.GDY>WN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B
MS>CJX.KH]2#O\.7DZ^[FY>WHZ2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M-38P"FUS9VED(").;R!S=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M
M971H;V0@8V]U;&0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z
M-C<@86-L+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<B!S<&5C:69I
M960N(@IM<V=S='(@(L+[(.WE(//JX.?@Z^@@[^#OZN@B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S`T"FUS9VED(").;VX@4&%R=&EC:7!A;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M,2!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR-`HC.B!T96UP
M;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,U"B,Z('1E;7!L871E<R]P<F5F<R]S
M<&%M<V5L96-T+FEN8SHR-"!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N
M:6YC.C(T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C$*;7-G:60@
M(DYO;F4B"FUS9W-T<B`BS>7R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDU"FUS9VED(").;W)M86PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C,Y"FUS9VED(").;W0@1&5L971E9"(*;7-G<W1R("+-
MY2#SY.#KY>WM^^4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T
M($1R869T(@IM<V=S='(@(LWE(/?E\.WNXNCJZ"(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S0*;7-G:60@(DYO="!);7!O<G1A;G0B"FUS9W-T<B`BS>4@XN#F[?OE
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B
M3F]T(%!E<G-O;F%L(@IM<V=S='(@(LWE(.OH]^WNY2(*"B,Z(&QI8B]#<GEP
M="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S-"!L:6(O0W)Y
M<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@<'5B;&EC(&ME
M>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV
M-PIM<V=I9"`B3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T<B`BS>4@\^3@
MZ^7M[?OE(/'N[N'YY>WH_R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B
MS>4@XN#F[?OE(/'N[N'YY>WH_R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES
M(&-A;B!T86ME('-O;64@=&EM92(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#0*;7-G:60@(DYO=&AI;F<B"FUS9W-T
M<B`BS>CWY>/N(@H*(SH@871T86-H;65N="YP:'`Z.#D*;7-G:60@(DYO=&EF
M:6-A=&EO;CH@3&EN:V5D(&%T=&%C:&UE;G0@9&]W;FQO861E9"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED(").=6UB
M97(@;V8@;6]N=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I
M9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R("+'X"#QZN[K_.KN(.SE\?_V
MY>(@]?#@[>CR_"#Q\N#P^^4@XNONYN7MZ/\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4Y"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F
M;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B
MQ^`@\>KNZ_SJ[B#LY?'_]N7B(/7PX.WH\OP@\?+@\/OE(._@[^KH(.[R[_#@
MXNOE[>W[]2#Q[N[A^>7MZ.DB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(U-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-2!T96UP;&%T97,O<VUI;64O:6UP
M;W)T7VME>2YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHT.`IM<V=I9"`B3U(B"FUS9W-T<B`BR,O((@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@
M(M'RX/#[Y2#Q[N[A^>7MZ/\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D
M96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N(@IM<V=S='(@(M'RX/#@_R#O
MX._JX"#DZ_\@[O+O\.#BZ^7M[?OU(/'N[N'YY>WHZ2#N]^CYY>WMX"XB"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C@*;7-G:60@(D]N;'D@9&ES<&QA
M>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S
M='(@(M+NZ_SJ[B#O[B#OX._JX.P@\2#MY>_P[O?H\N#M[?OLZ"#Q[N[A^>7M
MZ/_LZ#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C@Q
M('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C<Q"B,L(&9U>GIY
M"FUS9VED(")/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O
M<B!T:&ES(&%C=&EO;BXB"FUS9W-T<B`BS^[FX.OSZ?'RX"P@XOOAY?#H\N4@
M\N[K_.KN(.[D[?,@[^#OZO,@Y.O_(/WR[ND@[N_E\.#VZ.@N(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O;65N=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC
M.C,P"FUS9VED(")/<&5N($9O7VQD97(B"FUS9W-T<B`BSO+J\/OR_"#OX._J
M\R(*"B,Z(&9O;&1E<G,N<&AP.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3W!E;F5D
M($9O;&1E<B(*;7-G<W1R("+.\NKP^_+\(._@[^KS(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<P,`IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A
M;G0B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!F971C:&UA:6PN<&AP.C0S('1E
M;7!L871E<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO9F5T8VAM86EL+FEN8SHV"FUS9VED(")/=&AE<B!-86EL($%C8V]U
M;G1S(@IM<V=S='(@(L+@^.@@[^[W\N[B^^4@__GHZN@@[>`@Y/#SX^CU(/'E
M\.+E\.#U(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3D*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U
M,`IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R("+$\//CZ.4@[>#Q\O#N
MZ>KH(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#`*;7-G:60@
M(D]U=&)O=6YD(%-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P
M+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V
M-`HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#,@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,C@Y"FUS9VED(")01U`B"FUS9W-T<B`B(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*;7-G
M:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`BV.CT\.[BX.WMZ.4@
M4$=0(@H*(R!F=7IZ>0HC.B!C;VUP;W-E+G!H<#HS,S4*;7-G:60@(E!'4"!%
M<G)O<CH@(@IM<V=S='(@(L[XZ.'JX"!01U`B"@HC.B!C;VUP;W-E+G!H<#HS
M,30*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S
M;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`BSOCHX>K@.B#-Y>[A]>[DZ.P@
M[^#P[NO\(.3K_R#OY?#Q[NW@Z_SM[N/N(.KK_O?@+B(*"B,@9G5Z>GD*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B
M"FUS9W-T<B`BS>#Q\O#NZ>KH(%!'4"(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@
M(E!'4"!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(E!'4"#/X/#NZ_PB"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA
M;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN(@IM<V=S='(@(L_NY.3E\.;JX"!01U`@\O#EX?/E\B#GX/GH^>7M
M[>[C[B#Q[N7DZ.WE[>C_(@H*(R!F=7IZ>0HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HQ-S(*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E>'0B"FUS9W-T
M<B`BTN7J\?(@[_/AZ^CW[>[C[B#JZ_[WX"!01U`B"@HC(&9U>GIY+"!P:'`M
M9F]R;6%T"B,Z('!G<"YP:'`Z,30U"B,L('!H<"UF;W)M870*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(&9O<B!<(B5S("@E<RE<(B!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D+B(*;7-G<W1R("+/\^'KZ/?M^^D@ZNO^]R!01U`@Y.O_("5S("@E
M<RD@X?OK(//Q[^7X[>X@Y.[AX.+KY>TB"@HC(&9U>GIY+"!P:'`M9F]R;6%T
M"B,Z('!G<"YP:'`Z,C0Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")0
M1U`@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L
M971E9"XB"FUS9W-T<B`BS_/AZ^CW[?OI(.KK_O<@4$=0(.3K_R`E<R`H)7,I
M(.'[ZR#S\>_E^.WN(//DX.OE[2(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T
M<B`BT>+_Y^K@(._SX>OH]^W[]2#JZ_[WY>D@4$=0(@H*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*;7-G:60@(E!'
M4"!3:6=N($UE<W-A9V4B"FUS9W-T<B`BS^[D[^CQ_"!01U`B"@HC(&9U>GIY
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.0IM<V=I
M9"`B4$=0(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(L_NY._H\?P@
MZ"#XZ/3P[N+@[>CE(%!'4"(*"B,@9G5Z>GD*(SH@<&=P+G!H<#HQ.3@*;7-G
M:60@(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S
M='(@(M'EZO#E\NW[Z2#JZ_[W(//Q[^7X[>X@Y.[AX.+KY>TB"@HC(&9U>GIY
M"B,Z('!G<"YP:'`Z,3<S"FUS9VED(")01U`@<'5B;&EC(&ME>2!S=6-C97-S
M9G5L;'D@861D960N(@IM<V=S='(@(L_SX>OH]^W[Z2#JZ_[W(//Q[^7X[>X@
MY.[AX.+KY>TB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E
M+FEN8SHT"FUS9VED(")01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES
M('-Y<W1E;2XB"FUS9W-T<B`BS^[DY.7PYNK@(%!'4"#B(.+@^.7I(/'H\?+E
M[.4@[>4@XNKK_O?E[>`B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M,#<*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T
M:79E('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@
M(@HB=F5R:69I960N(@IM<V=S='(@(B(*(L_NY.3E\.;JX"#RY?7M[NONX^CH
M(%!'4"#B(.3@[>W[Z2#L[NSE[?(@[O+JZ_[WY>W@+"#O[OWR[NSS(._NY._H
M\?P@[>4@[.[FY?(@(@HBX?OR_"#O\.[BY?#E[>`B"@HC(&9U>GIY"B,Z(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-`IM<V=I9"`B(@HB4$=0('-U<'!O
M<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@
M=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HBS^[DY.7PYNK@
M(/+E]>WNZ^[CZ.@@4$=0(.(@Y.#M[?OI(.SN[.7M\B#N\NKK_O?E[>`L(._N
M_?+N[/,@\>[NX?GE[>CE(.WE("(*(NSNYN7R(.'[\OP@\.#Q^.CT\.[BX.WN
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(B(*(E!'4"!S
M=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF
M('EO=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@
M<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O
M<B!E;'-E('1H92!01U`@(@HB9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R
M96-T;'DN(@IM<V=S='(@(B(*(L_NY.3E\.;JX"!01U`@Z/'O[NO\Y_/E\B#D
MZ_\@\.#A[O+[(.+Q[^O[XN#^^>CE(.[J[>`N(,7QZ^@@XN#X(.'PX//GY?`@
M(@HB[>#Q\O#NY>T@[>`@[^[DX.+KY>WHY2#B\>_K^^+@_OGH]2#NZN[M+"#B
MX.P@[>7NX?7NY.CL[B#HY^SE[>CR_"#]\N@@(@HB[>#Q\O#NZ>KH+"#H[>#W
MY2#O[N3DY?#FZN`@4$=0(.WE(/'L[N;E\B#PX.'N\N#R_"#O\.#BZ.O\[>XN
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G
M:60@(E!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3<*;7-G:60@(E!/4#,@;W9E
M<B!34TPB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M,C,*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC
M871E*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C$V.`IM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$Q"FUS9VED(")0
M3U`S+"!N;R!43%,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHR,@HC+"!P:'`M9F]R;6%T"FUS9VED(")086=E("5D(&]F
M("5D(@IM<V=S='(@(M'R\.#MZ/;@("5D(.CG("5D(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@Y,@IM<V=I9"`B4&%G92!W:71H('1H92!&:7)S="!5
M;G-E96X@365S<V%G92(*;7-G<W1R("+/Y?#B[N4@[>7O\.[WZ/+@[>WNY2#Q
M[N[A^>7MZ.4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DS"FUS9VED
M(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B
MS^[QZ^7D[>7E(.WE[_#N]^CRX.WM[N4@\>[NX?GE[>CE(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS
M9W-T<B`BPNONYN7MZ/\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S
M"FUS9VED(")087-S<&AR87-E(@IM<V=S='(@(L_@\.[K_"(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@*$%G86EN
M*2(*;7-G<W1R("+/X/#NZ_P@*._NXO+N\.CR_"DB"@HC.B!S;6EM92YP:'`Z
M,C,Q('!G<"YP:'`Z,S`V"B,L(&9U>GIY"FUS9VED(")087-S<&AR87-E('-U
M8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`BT>[NX?GE[>CE(//Q[^7X
M[>X@[O+O\.#BZ^7M[BP@[>X@[>4@\>[U\.#MY>WN(.(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S
M<&AR87-E+FEN8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`BS^#P
M[NO\.B(*"B,Z('!G<"YP:'`Z,3`X"FUS9VED(")087-S<&AR87-E<R!C86YN
M;W0@8F4@96UP='DB"FUS9W-T<B`BS^#P[NO\(.WE(.SNYN7R(.'[\OP@[_/Q
M\OOL(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(E!A<W-P:')A<V5S(&1O(&YO
M="!M871C:"(*;7-G<W1R("+/X/#NZ^@@[>4@\>[B[^#DX/[R(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$Y,0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\(@H*(R!F
M=7IZ>0HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`BPOOO[NOMZ/+\(.[OY?#@]NCH(.[A\>OSYNCBX.WH_R#O\.@@
MXO7NY.4@XB#QZ/'RY>SS(@H*(SH@86-L+G!H<#HW-2!A8VPN<&AP.C$P,0IM
M<V=I9"`B4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C86YN;W0@8F4@8VAA
M;F=E9"XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-#DT(&UA:6QB;W@N
M<&AP.C8Y."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(T"B,Z('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3`*;7-G:60@(E!E<G-O;F%L
M(@IM<V=S='(@(LOH]^W[Y2(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$T"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R
M("++Z/?M^^4B"@HC(&9U>GIY"B,Z('!G<"YP:'`Z,3$V"FUS9VED(")097)S
M;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R("+/Y?#Q[NW@Z_SMX/\@[^#PX"!01U`@ZNO^]^7I(.'[Z^`@\_'OY?CM
M[B#QX^7MY?#H\.[BX.W@+B(*"B,Z('!G<"YP:'`Z,3(S"B,L(&9U>GIY"FUS
M9VED(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`BT>[NX?GE[>CE(//Q[^7X[>X@[O+O\.#BZ^7M[BP@[>X@[>4@
M\>[U\.#MY>WN(.(B"@HC.B!S;6EM92YP:'`Z,C`S"FUS9VED(")097)S;VYA
M;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S='(@
M(B(*"B,Z('-M:6UE+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L
M(%,O34E-12!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+1
M[N[A^>7MZ.4@\_'OY?CM[B#N\N_PX.+KY>WN+"#M[B#MY2#Q[O7PX.WE[>X@
MXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L86-E
M('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\B
M"FUS9W-T<B`BT.#G[.7YX/+\(._NY._H\?P@[^7PY>0@[O+BY?+@[.@@Z"#O
MY?#E\?OKZN#LZ#\B"@HC.B!C;VUP;W-E+G!H<#HR-3@*(RP@9G5Z>GD*;7-G
M:60@(E!L86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`BPB#R
MY>OE(/'N[N'YY>WH_R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#@*
M;7-G:60@(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I
M<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D("(*(G-O=6YD
M(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U
M="!O=&AE<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@<&QU9VEN+B(*
M;7-G<W1R("(B"B+(\>_NZ_SG[N+@\OP@Y^+SZN[B[N4@\^+EY.[LZ^7MZ.4_
M(-WR[B#R\.7A\^7R(._NY.3E\.;JZ"#B(.'PX//GY?#E+"#B[N?NYNWN("(*
M(O$@[^[L[OG\_B#Q[^7VZ.#K_.W[]2#OZ^#CZ.WNXBXB"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E
M<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(L+BY>3H
M\N4@Z.S_(.WNXN[I(._@[^KH.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3`T('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3`V"B,Z('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.CDT
M('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.CDV"FUS9VED(")0
M;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S
M='(@(L+BY>3H\N4@Z.S_(.WNXN[I(._@[^KH.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,Y('1E;7!L871E<R]F;VQD97)S+VIA
M=F%S8W)I<'0N:6YC.C$R.0IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N97<@
M;F%M93HB"FUS9W-T<B`BS^[FX.OSZ?'RX"#BXN7DZ/+E(.WNXN[E(.CL_SHB
M"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F
M;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T
M;R`B"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO
M;BXB"FUS9W-T<B`B(@HBPN+EY.CRY2#OX/#NZ_P@Y.O_(.+@^.7C[B#QY>KP
MY?+M[N/N(%!'4"#JZ_[WX"X@PN#L(.WE[N'U[N3H[.X@XN+NY.CR_"`B"B+O
MX/#NZ_P@[N3H[2#PX.<@Y^`@\>7Q\>C^(/#@X>[R^R#Q("5S(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U
M<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T
M;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@<F5C;VUP;W-E+G!H<#HY-@IM<V=I9"`B(@HB4&QE
M87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S
M<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U
M(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U
M('=I;&P@:&%V92!T;R`B"B)L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I
M;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@
M(@HB:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O
M<B!A;GD@:6YC;VYV96YI96YC92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!P87-S=V]R9"XB"FUS9W-T<B`BS^[FX.OSZ?'RX"P@\^K@
MYNCRY2#"X/CH(.ONX^CM(.@@[^#P[NO\(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`BS^[FX.OSZ?'RX"P@\^K@YNCRY2#"
MX/CH(.ONX^CM(.@@[^#P[NO\(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])
M35`N<&AP.C0V,PIM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R
M(&EN=F%L:60@861D<F5S<V5S+B(*;7-G<W1R("+/[N;@Z_/I\?+@+"#SY.#K
MZ/+E(/'N[.WH\N7K_.W[Y2#HZ^@@[>7O\.#BZ.O\[?OE(.#D\.7QX"XB"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R:7!T+FEN8SHU,PIM<V=I9"`B
M4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY
M(&%C=&EO;G,N(@IM<V=S='(@(L_NYN#K\^GQ\N`L(.+[X>7PZ/+E(._@[^KS
M(._E\.7D(.[Q\_GE\?+BZ^7MZ.7L(.3EZ?'RXNC_+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(E!L
M96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M('1H:7,@
M86-T:6]N+B(*;7-G<W1R("+/[N;@Z_/I\?+@+"#B^^'E\.CRY2#OX._J\R#O
MY?#EY"#N\?/YY?'RXNOE[>CE["#DY>GQ\N+H_RXB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VIA=F%S8W)I<'0N:6YC.C0Q"FUS9VED(")0;&5A<V4@<V5L96-T
M(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+B(*;7-G<W1R("+/[N;@
MZ_/I\?+@+"#B^^'E\.CRY2#U[O+_(.'[(.[D[?,@[^#OZO,@Y.O_(._NZ/'J
MX"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R('1E
M;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C0*;7-G:60@(E!L96%S
M92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB
M"FUS9W-T<B`BS^[FX.OSZ?'RX"P@XOOAY?#H\N4@\N[K_.KN(.[D[?,@[^#O
MZO,@Y.O_(/WR[ND@[N_E\.#VZ.@N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C<S"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T
M(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(L_N
MYN#K\^GQ\N`L(.+[X>7PZ/+E(.CKZ"#N\O#EY.#J\NCP\^GRY3HB"@HC.B!C
M;VYF:6<O;6]T9"YP:'`N9&ES=#HT,0IM<V=I9"`B4&]W97)E9"!B>2!(;W)D
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$T"FUS
M9VED(")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@
M)RD_(@IM<V=S='(@(L[RY.7KZ/+\(.+@^/,@[^[D[^CQ_"#N\B#Q[N[A^>7M
MZ/\@]^7P\N[I/R(*"B,Z('-M:6UE+G!H<#HR,S<@<&=P+G!H<#HR-3,@9FEL
M=&5R<')E9G,N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")0<F5F97)E;F-E<R!S
M=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`BS^#OZN`@7"(E<UPB(.'[
MZ^`@\_'OY?CM[B#Q[N?DX.W@+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T
M=&%C:&UE;G1S+FEN8SHS"B,L(&9U>GIY"FUS9VED(")0<F5V:65W(@IM<V=S
M='(@(LW@Y^#D(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@365S<V%G92(*;7-G<W1R("+/
M\.7D^^3S^>7E(/'N[N'YY>WHY2(*"B,Z(&UA:6QB;W@N<&AP.C,S,PIM<V=I
M9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R("+/\.7D^^3S^>#_(/'R\.#MZ/;@
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S
M"FUS9VED(")0<FEN="(*;7-G<W1R("+/Y??@\OPB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B4')I;W)I
M='DB"FUS9W-T<B`BS^7WX/+\(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C<V"FUS9VED(")0<FEV871E($ME>2!087-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34Y"FUS9VED(")0
M<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U
M;'0@=&\@3D\B"FUS9W-T<B`BT>_PX/CHXN#R_"#JX.;D^^D@\.#G(._PZ"#B
MZ^[FY>WHZ"P@[^X@\^SNZ_?@[>C^(,W%TB(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C
M:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`BT>_PX/CH
MXN#R_"#JX.;D^^D@\.#G(._PZ"#BZ^[FY>WHZ"P@[^X@\^SNZ_?@[>C^(,3`
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED
M(")0<F]T;V-O;#HB"FUS9W-T<B`BS_#N\N[J[NLZ(@H*(SH@;&EB+T-R>7!T
M+U!'4"YP:'`Z-#,P"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P
M;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I9"`B4'5R7V=E($1E
M;&5T960B"FUS9W-T<B`BSO?H\?+H\OP@RN[PY^CM\R(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I9"`B4'5R9V4@1&5L971E9"(*;7-G
M<W1R("+.]^CQ\NCR_"#*[O#GZ.WS(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHR-`IM<V=I9"`B4'5R9V4@1F]L9&5R*',I
M(@IM<V=S='(@(L[WZ/'RZ/+\(._@[^KS*.@I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*
M;7-G<W1R("+.]^CYX/+\(.KN\.?H[?,Z(@H*(R!F=7IZ>0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#`U"FUS9VED(")0=7)G92!M97-S86=E<R!I;B!4
M<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*
M;7-G<W1R("+3Y.#K__+\(.CG(.KN\.?H[?L@\>[NX?GE[>C_(/'RX/#XY2#S
MZN#GX.WM[N/N(.KNZ^CWY?'RXN`@Y.WEZ2(*"B,@9G5Z>GD*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B4'5R9V4@;VQD(&UE<W-A9V5S
M(&EN('1H92!4<F%S:"!F;VQD97(_(@IM<V=S='(@(M/DX.O_\OP@\?+@\/OE
M(/'N[N'YY>WH_R#HYR#*[O#GZ.W[/R(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W!U<F=E7W1R87-H+G!H<#HV-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4'5R9VEN9R`E9"!M97-S86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB
M"FUS9W-T<B`BT^3@Z^7M[B`E9"#Q[N[A^>7MZ.D@Z.<@RN[PY^CM^RXB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C,*(RP@
M9G5Z>GD*;7-G:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L
M9&5R+B(*;7-G<W1R("+3Y.#KY>WN("5D(/'N[N'YY>WHZ2#HYR#*[O#GZ.W[
M+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E
M+C)F)24I(@IM<V=S='(@(LCQ[^[K_.?NXN#M[CH@)2XR9LSA(.CG("4N,F;,
MX2`H)2XR9B4E*2(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR
M9DU"("\@3D\@3$E-250B"FUS9W-T<B`BR/'O[NO\Y^[BX.WN.B`E+C)FS.$@
MZ.<@)2XR9LSA("@E+C)F)24I(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A
M+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z($Y/
M($Q)34E4(@IM<V=S='(@(B(*"B,@<&AP+69O<FUA=`HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`P"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1I;F<@
M)68Z(@IM<V=S='(@(M;H\NCP\_X@)68Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,CD*;7-G:60@(E)E8G5I;&0@1F]L9&5R(%1R964B
M"FUS9W-T<B`BS^7PY?'R\.[H\OP@Y.7PY>+N(@H*(R!F=7IZ>0HC.B!L:6(O
M4V5A<F-H+G!H<#HV,3<*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@(L_N
MZ_/WY>WM[CHB"@HC(&9U>GIY"B,Z(&QI8B]396%R8V@N<&AP.C8R-0IM<V=I
M9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`BS^[K\_?E[>WN(&,Z(@H*(R!F
M=7IZ>0HC.B!L:6(O4V5A<F-H+G!H<#HV,C$*;7-G:60@(E)E8V5I=F5D(%5N
M=&EL(@IM<V=S='(@(L_NZ_/WY>WM[B#D[CHB"@HC(&9U>GIY"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D
M:7)E8U]T(@IM<V=S='(@(L_E\.7MX._PX.+H\OPB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,38*;7-G:60@(E)E9&ER96-T
M(@IM<V=S='(@(L_E\.7MX._PX.+H\OPB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I<F5C="!-97-S86=E(@IM
M<V=S='(@(L_E\.7MX._PX.+H\OP@\>[NX?GE[>CE(@H*(SH@8V]M<&]S92YP
M:'`Z.#(W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B
MS^7PY>W@[_#@XNCR_"#]\NX@\>[NX?GE[>CE(@H*(SH@8V]M<&]S92YP:'`Z
M.#@P"FUS9VED(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(L[XZ.'J
MX"#OY?#E[>#O\.#BZ^7MZ/\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<W,PIM<V=I9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(L_P
M[N+E\/_R_"#O[O?R\R#MX"#QY?#BY?#E.B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHT
M"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`BS_#N]^CRX.WM^^4B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHS"FUS9VED(")296QO
M860@5FEE=R(*;7-G<W1R("+/Y?#EX_#SY^CR_"#O\.[Q[.[R\"(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4T-PHC+"!F=7IZ>0IM<V=I9"`B4F5M96UB97(@=&AE(&9R964O
M8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`BR.WT[O#LX/;H_R#N(/'E\.+E
M\.4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38X"FUS9VED(")296UE
M;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S='(@(L?@[^[L[>CR_"#O[O'KY>3M
MY>4@\>[Q\N[_[>CE(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*;7-G<W1R
M("+/X._JX"#MX"#Q\N[P[NWMY>P@\>7PXN7PY3HB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M
M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,#4*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!S;W5R8V4B
M"FUS9W-T<B`B\^3@Z^CR_"#H\?7NY.WNY2(*"B,@9G5Z>GD*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5N86UE($9O;&1E
M<BAS*2(*;7-G<W1R("+/Y?#EZ.SE[>[BX/+\(._@[^KS(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F
M;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R("+/Y?#EZ.SE
M[>[B^^+@\OP@[^#OZO,@[O+O\.#BZ^7M[?OU(/'N[N'YY>WHZ2#B(.W@]^#K
MY2#LY?'_]N`_(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#4X"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E;F%M:6YG(%PB)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(L_E\.7H[.7M
M[N+@[>CE(%PB)7-<(B#B(%PB)7-<(B#MY2#SY.#K[O'\+B#1Y?#BY?`@[^CX
MY?(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS9W-T<B`BSO+B
MY?+H\OP@XB#PX/'Q^^OJ\R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T<B`BQ^#L
MY>WH\OP@[>`Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S='(@(L[RXN7RZ/+\(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q,B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#$P"B,L(&9U>GIY"FUS9VED(")297!L>2!396YT+B(*;7-G
M<W1R("+*[NSS(.[RXN7RZ/+\(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!!;&PB"FUS9W-T
M<B`BSO+BY?+H\OP@XO'E["(*"B,Z(&-O;7!O<V4N<&AP.C<W,0IM<V=I9"`B
M4F5P;'D@=&\@06QL.B(*;7-G<W1R("+.\N+E\NCR_"#B\>7L.B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ
M>0IM<V=I9"`B4F5P;'D@=&\@3&ES="(*;7-G<W1R("+.\N+E\NCR_"#B\>7L
M(@H*(SH@8V]M<&]S92YP:'`Z-S<S"B,L(&9U>GIY"FUS9VED(")297!L>2!T
M;R!,:7-T.B(*;7-G<W1R("+.\N+E\NCR_"#B\>7L.B(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED
M(")297!L>2!T;R!?06QL(@IM<V=S='(@(L[RXN7RZ/+\(.+QY>PB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,P(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU,SD*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T.0HC
M+"!F=7IZ>0IM<V=I9"`B4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A
M9V4B"FUS9W-T<B`BS^7PXN[E(.WE[_#N]^CRX.WM[N4@\>[NX?GE[>CE(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-PHC+"!F=7IZ>0IM<V=I
M9"`B4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N
M,BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@=C0N,"XR*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L[X
MZ.'JX"#N\N_PX.+JZ"#OZ/'\[.`Z("5S7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@
M[O+O\.#BZN@@[^CQ_.S@.B`E<UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBSOCHX>K@(.[R[_#@
MXNKH(._H\?SLX#H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3,V"B,L(&9U>GIY"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(L[XZ.'JX"#N\N_PX.+JZ"#O
MZ/'\[.`Z("5S(@H*(R!F=7IZ>0HC.B!M97-S86=E+G!H<#HR-S4*;7-G:60@
M(E)E<&QY+51O(@IM<V=S='(@(LKN[/,@[O+BY?+H\OPZ(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0R,`IM<V=I9"`B4F5P;'DM5&\Z("(*;7-G<W1R("+.\N+E
M\NCR_"(*"B,Z(&-O;7!O<V4N<&AP.C<V.0IM<V=I9"`B4F5P;'DZ(@IM<V=S
M='(@(L[RXN7RZ/+\.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR
M-@HC+"!F=7IZ>0IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S='(@
M(L[R[_#@XNCR_"#Q[N[A^>7MZ.4@[B#Q[^#LY2(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS-2!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHR,PIM<V=I9"`B4F5P;W)T(&%S(%-P86TB"FUS9W-T
M<B`BSO+O\.#BZ/+\(/'N[N'YY>WHY2#N(/'OX.SE(@H*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#8*;7-G:60@(E)E<75E
M<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(L?@[_#N\>CR_"#O[N3RXN7P
MYN3E[>CE(._NZ_/WY>WH_R(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4W,PIM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G
M<W1R("+'X._P[O'H\OP@[^[D\N+E\.;DY>WHY2#O[NOS]^7MZ/\_(@H*(SH@
M;6%I;&)O>"YP:'`Z,3@Y"FUS9VED(")297%U97-T960@;65S<V%G92!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV.3(*(RP@9G5Z>GD*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM
M<V=S='(@(L?@[_#N\>CR_"#O[N3RXN7PYN3E[>CE(._NZ_/WY>WH_R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3,X('1E;7!L871E<R]S96%R
M8V@O:&5A9&5R+FEN8SHR.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R
M"FUS9VED(")297-E="(*;7-G<W1R("+1X?#N\>CR_"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,38*;7-G:60@(E)E<W!O;F1E;G0@4W1A='5S
M(%5P9&%T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHS,`IM<V=I9"`B4F5S=6UE(@IM<V=S='(@(L_P
M[N3NZ^;H\OPB"@HC.B!R96-O;7!O<V4N<&AP.CDW"FUS9VED(")297-U;64@
M>6]U<B!S97-S:6]N(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C0T"FUS9VED(")2971U<FX@=&\@7")-
M97-S86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`BPN7P[?/R_/'_(.H@[>#Q
M\O#NZ>K@["(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV
M97)?<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI
M;F,Z,S$*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@(L+E
M\.WS\OSQ_R#J(.W@\?+P[NGJX.PB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHR
M,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP;&%T97,O
M<VUI;64O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,38S('1E;7!L871E<R]A8VPO86-L+FEN8SHQ
M-S4*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(L+E\.WS\OSQ
M_R#J(.W@\?+P[NGJX.PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S`W
M"FUS9VED("(B"B)2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E
M<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\B"FUS
M9W-T<B`BSO+NX?#@Y^CR_"#O[O?R[N+[Z2#_^>CJ(._N\>OE(//DX.OE[>C_
M(.CKZ"#OY?#E[.7YY>WH_R#Q[N[A^>7MZ/\B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C@S"FUS9VED(")2;VQE(@IM<V=S='(@(M'VY>W@\.CI
M(@H*(R!F=7IZ>0HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T,B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S-PHC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C0R-`HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(@IM<V=S
M='(@(LW@\?+P[NGJZ"!3+TU)344B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M;F-R>7!T7VQI<W0N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")3+TU)344@16YC
M<GEP="!-97-S86=E(@IM<V=S='(@(L_E\.7@Y/#E\>#VZ/\@\>[NX?GE[>C_
M(@H*(SH@8V]M<&]S92YP:'`Z,S<Q"B,L(&9U>GIY"FUS9VED(")3+TU)344@
M17)R;W(Z("(*;7-G<W1R("+.^.CAZN`B"@HC.B!C;VUP;W-E+G!H<#HS-3`*
M;7-G:60@(E,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S
M;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34Q"FUS9VED(")3+TU)344@3W!T:6]N<R(*
M;7-G<W1R("+-X/'R\.[IZN@@4R]-24U%(@H*(SH@<VUI;64N<&AP.C0V"FUS
M9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R
M<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,3,V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`BS^#O
MZN`@7"(E<UPB(.'[Z^`@\_'OY?CM[B#SY.#KY>W@+B(*"B,Z('-M:6UE+G!H
M<#HQ-3@*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y('-U8V-E
M<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`BS^#OZN`@7"(E<UPB(.'[Z^`@\_'O
MY?CM[B#SY.#KY>W@+B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97ER:6YG(@IM<V=S
M='(@(M'B_^?JX"#O\^'KZ/?M^_4@ZNO^]^7I(%,O34E-12(*"B,Z('-M:6UE
M+G!H<#HR,#<*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!0=6)L:6,O4')I=F%T
M92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`BS^[D[^CQ
M_"#S\>_E^.WN(.?@[.7MY>W@+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N
M8W)Y<'1?;&ES="YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!3:6=N
M($UE<W-A9V4B"FUS9W-T<B`BSO+O\.#BZ/+\(/'N[N'YY>WHY2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*(RP@9G5Z>GD*
M;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R("+.
M\N_PX.+H\OP@\>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C
M=&EV92YI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@
M9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(L_NY.3E\.;JX"#T
MZ.O\\O#@]NCH(.(@XN#XY>D@\>CQ\N7LY2#MY2#BZNO^]^7MX"(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"B,L(&9U>GIY"FUS9VED("(B
M"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@
M=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E9"XB"FUS
M9W-T<B`B(@HBS^[DY.7PYNK@(/+E]>WNZ^[CZ.@@4$=0(.[R\?/R\?+B\^7R
M(.W@(.+@^.7L(/'E\.+E\.4L(._N_?+N[/,@[^[D[^CQ_"#MY2`B"B+L[N;E
M\B#A^_+\(._P[N+E\.7MX"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,3<S"B,L(&9U>GIY"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N
M;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S
M<V%G92!C86YN;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R("(B"B+/[N3D
MY?#FZN`@\N7U[>[K[N/HZ"!01U`@[O+Q\_+Q\N+SY?(@[>`@XN#XY>P@\>7P
MXN7PY2P@[^[]\N[L\R#O[N3OZ/'\(.WE("(*(NSNYN7R(.'[\OP@[_#NXN7P
MY>W@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*(RP@9G5Z
M>GD*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O
M('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R
M:69I960N(@IM<V=S='(@(B(*(L_NY.3E\.;JX"#RY?7M[NONX^CH(%!'4"#N
M\O'S\O'RXO/E\B#MX"#BX/CE["#QY?#BY?#E+"#O[OWR[NSS(._NY._H\?P@
M[>4@(@HB[.[FY?(@X?OR_"#O\.[BY?#E[>`B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(')E<75I
M<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E
M<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W
M<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E("(*(G1H
M92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM
M<V=S='(@(B(*(L_NY.3E\.;JX"!3+TU)344@Z/'O[NO\Y_/E\B#DZ_\@\.#A
M[O+[(.+Q[^O[XN#^^>CE(.[J[>`N(,7QZ^@@XN#X(.'PX//GY?`@(@HB[>#Q
M\O#NY>WMX"#O[N3@XNOE[>CE(.+Q[^O[XN#^^>CU(.[J[NTL(.+@["#MY>[A
M]>[DZ.SN(.CG[.7MZ/+\(/WRZ"`B"B+MX/'R\.[IZN@L(.CMX/?E[^[DY.7P
MYNK@(%,O34E-12#MY2#Q[.[FY?(@\.#A[O+@\OP@[_#@XNCK_.WN+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`T"FUS9VED(")33510(@IM
M<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C4U"FUS9VED(")37W5B:F5C="(*;7-G<W1R("+2Y>S@(@H*(R!F
M=7IZ>0HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-C,*;7-G
M:60@(E-A7W9E(&$@8V]P>2!I;B`B"FUS9W-T<B`BT>[U\.#MZ/+\(.KN[^C^
M(.(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHS,@IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`BT>[U\.#MZ/+\
M(.K@ZB(*"B,@9G5Z>GD*(SH@<V5A<F-H+G!H<#HS,#@@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C8W"FUS9VED(")3879E(@IM<V=S='(@(M'N
M]?#@[>CR_"#JX.HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU,S8*;7-G:60@(E-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN
M('-E;G0M;6%I;"!F;VQD97(_(@IM<V=S='(@(M'N]?#@[>CR_"#BZ^[FY>WH
M_R#B[?/R\.@@\>[NX?GE[>CI(.(@[^#OZN4@[O+O\.#BZ^7M[>[I(._N]_+[
M/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,`IM<V=I9"`B4V%V92!$<F%F
M="(*;7-G<W1R("+1[O7PX.WH\OP@ZN#J(/?E\.WNXNCJ(@H*(SH@<V%V96EM
M86=E+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B4V%V92!);6%G92(*;7-G<W1R
M("+1[O7PX.WH\OP@ZN#J(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(R
M.`IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E
M+FEN8SHQ,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS(@IM
M<V=S='(@(L?@[^CQX/+\(.W@\?+P[NGJZ"(*"B,@9G5Z>GD*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"FUS9VED(")3879E(%-T871I
M;VYE<GDB"FUS9W-T<B`BT>[U\.#MZ/+\(@H*(R!F=7IZ>0HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,S`*;7-G:60@(E-A=F4@7T1R869T(@IM<V=S='(@(M'N
M]?#@[>CR_"#JX.H@]^7P[>[BZ.HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T<B`B
MT>[U\.#MZ/+\(.K@ZB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*
M;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`BS^[LY??@
M\OP@]^7P[>[BZ.KH(.K@ZB#MY>_P[O?H\N#M[?OE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-C$*;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A=71O
M;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\B"FUS9W-T
M<B`BP.+R[NS@\NCWY?'JZ"#GX._H\?OBX/+\(._NZ_/WX/+EZ_\@XB#@Y/#E
M\>WS_B#J[>CC\R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(R
M"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/R(*;7-G
M<W1R("+'X._H\>#R_"#PY>?SZ_SRX/(@[^[H\>K@(.(@XNCP\O/@Z_SM\_X@
M[^#OZO,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B
M4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(M'N]?#@[?_R_"#N\N_PX.+KY>WM
M^^4@\>[NX?GE[>C_/R(*"B,Z(&-O;7!O<V4N<&AP.C$R-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(L[XZ.'JX"#GX._H
M\>@@]^7P[>[BZ.K@+B#1Y?#BY?`@[O+BY?+HZSH@)7,B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y.2!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C$Q"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP
M.C4T"FUS9VED(")396%R8V@B"FUS9W-T<B`BS^[H\>HB"@HC(&9U>GIY+"!P
M:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI
M;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S(@IM<V=S='(@
M(LCQZN#R_"`E<R(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(P"FUS9VED(")396%R8V@@3W!T:6]N<R(*;7-G<W1R("+/
M[NCQZB(*"B,Z('-E87)C:"YP:'`Z,C8S"FUS9VED(")396%R8V@@4F5S=6QT
M<R(*;7-G<W1R("+0Y>?SZ_SRX/+[(._NZ/'JX"(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,30@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS,0IM<V=I9"`B4V5E;B(*;7-G<W1R("+/\.[WZ/+@[>W[Y2(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z.0IM<V=I9"`B4V5L96-T
M(@IM<V=S='(@(L+[X?#@\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C
M;W5N="(*;7-G<W1R("+"^^'PX/+\(.3P\^/NZ2#O\.[TZ.O\.B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&$@9&%T92(*;7-G<W1R("+"^^'PX/+\(._P[O3HZ_PB"@HC(&9U
M>GIY"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHQ,`IM<V=I9"`B
M4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`BPOOAY?#H\N4@[^[KY2(*"B,@9G5Z
M>GD*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$W"FUS9VED
M(")396QE8W0@82!S=&%T:6]N97)Y.B(*;7-G<W1R("+"^^'E\.CRY2#XX.'K
M[NTB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G
M:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N
M9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`BPOOAY?#H\N4@
MX.3PY?'M\_X@ZNWHX_,@Y.O_(.3NX>#BZ^7MZ/\@XB#MY>4@X.3PY?'NXBXB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE
M8W0@86QL(@IM<V=S='(@(L+[X?#@\OP@XO'E(@H*(R!F=7IZ>0HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*;7-G:60@(E-E;&5C
M="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S
M97,N(@IM<V=S='(@(L+[X>7PZ/+E(._NZ_\@Y.O_(._NZ/'JX"#O\.@@\.#G
MXN[PX/?HXN#MZ.@@Z.SE[2XB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@86X@
M86-C;W5N="(*;7-G<W1R("+"^^'E\.CRY2#O\.[TZ.O\(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS
M9W-T<B`BSO+LY>WH\OP@XOOA[O`B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]S
M879E:6UA9V4O<V%V96EM86=E+FEN8SHY"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@
M(M#EYNCL(/#@X>[R^R#O[O'KY2#B]>[DX"#B(,?@[_#N\?LZ(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHR,0IM<V=I9"`B
M4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S='(@(L+[X>7PZ/+E
M(/+H[R#O[O?R[N+NX^X@\>7PXN7PX"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"FUS9VED(")396QE8W1E9"!!
M9&1R97-S(&)O;VMS.B(*;7-G<W1R("+"^^'PX.WM^^4@X.3PY?'M^^4@ZNWH
MX^@Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")396YD
M($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R(@IM<V=S='(@(L_N\>O@\OP@ZNO^
M]R#MX"#O\^'KZ/?M^^D@\>7PXN7P(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Y-PHC+"!F=7IZ>0IM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M
M871I;VXB"FUS9W-T<B`BR.WT[O#LX/;H_R#N(/'E\.+E\.4B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,C@*;7-G:60@(E-E;F0@365S<V%G92(*;7-G<W1R
M("+.\N_PX.+H\OP@\>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YJ<SHQ,C8*;7-G:60@(E-E;F0@;65S<V%G92!W:71H;W5T(&$@
M4W5B:F5C=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8Y,@IM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T960@
M8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`BSO+Q^^O@\OP@Y^#O\.[XY>WM[N4@
MX.3PY?'@\N[L(._NY/+BY?#FY.7MZ.4@[B#O\.[W\N7MZ.@_(@H*(SH@9F]L
M9&5R<RYP:'`Z,S<X"B,L(&9U>GIY"FUS9VED(")396YT(&UA:6P@9F]L9&5R
M(@IM<V=S='(@(L_@[^K@(.[R[_#@XNOE[>W[]2#Q[N[A^>7MZ.DZ(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I9"`B
M4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`BS^#OZN`@[O+O\.#BZ^7M[?OU
M(/'N[N'YY>WHZ3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S
M,R!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$T-0HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$U,@IM<V=I9"`B4V5R=F5R(@IM<V=S='(@(M'E
M\.+E\"(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"FUS
M9VED(")397)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G<W1R("+/
MX._JZ"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C(S"FUS9VED(")397)V97(Z(@IM<V=S='(@(M'E\.+E\"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,`IM<V=I9"`B4V5T('!R969E<F5N8V5S
M(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE
M<W-A9V5S+B(*;7-G<W1R("+-X/'R\.[IZN`@[.#MZ._SZ__VZ.D@\2#SY.#K
MY>WM^^SH(.CKZ"#OY?#E[.7YY>WM^^SH(/'N[N'YY>WH_^SH(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R.0IM<V=I9"`B4V5T('1H92!8+5!R:6]R
M:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN9R!M97-S86=E<S\B"FUS9W-T<B`B
MT_'RX.WNXNCR_"#O\.CN\.CRY?(@[^CQ_.S@(._PZ"#N\N_PX.+JY2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0HC+"!F=7IZ>0IM<V=I9"`B4VAA
M<F4@1F]L9&5R<R(*;7-G<W1R("+/X._JX"#N\N_PX.+KY>WM^_4@\>[NX?GE
M[>CI.B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@HC+"!F=7IZ>0IM
M<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(L_@[^K@(.[R[_#@
MXNOE[>W[]2#Q[N[A^>7MZ.DZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,R"B,L(&9U>GIY"FUS9VED(")3:&%R92!Y;W5R(&UA:6P@9F]L9&5R<R!W
M:71H(&]T:&5R('5S97)S+B(*;7-G<W1R("+/X._JX"#N\N_PX.+KY>WM^_4@
M\>[NX?GE[>CI.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3<*;7-G
M:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@
M<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T;V=G
M;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`BS^X@
M\^SNZ_?@[>C^+"#QZO#[XN#R_"#A[NO\^.CE(.'K[NKH(/;H\NCP\^7L[N/N
M(/+EZO'RX#\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM<V=I9"`B
M4VAO=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A
M;FYE9"!F;W(@4$=0(&1A=&$_(@IM<V=S='(@(LCQZN#R_"#B(/+EZ^4@\N7J
M\?+NXOOU(/'N[N'YY>WHZ2#DX.WM^^4@4$=0/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD
M;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R("+'
MX.KP^^+@\OP@[NKM[B#Q[O'RX.+KY>WH_R#Q[N[A^>7MZ/\L(._PZ"#Q[O7P
MX.WE[>CH(/?E\.WNXNCJX#\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-`IM<V=I9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T
M86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*;7-G<W1R("(B
M"B+$[N'@XNO_\OP@XN#X(._SX>OH]^W[Z2#JZ_[W(.KN(.+QY>P@Z/'U[N3_
M^>CL(/'N[N'YY>WH_^P@[^X@\^SNZ_?@[>C^/R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@(E-H;W<@06QL($9O
M;&1E<G,B"FUS9W-T<B`BT>+E\.WS\OP@XO'E(._@[^KH(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C<*;7-G:60@(E-H;W<@06QL($AE
M861E<G,B"FUS9W-T<B`BS^[JX.?@\OP@XO'E(.?@X^[K[N+JZ"(*"B,Z(&UA
M:6QB;W@N<&AP.C,U,0IM<V=I9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(L_N
MZN#GX/+\(//DX.OE[>W[Y2(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E
M<G,N:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R
M("+1ZO#[\OP@Y^#C[NONXNKH(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;65S
M<V%G92]H96%D97)S+FEN8SHW,`IM<V=I9"`B4VAO=R!-86EL:6YG($QI<W0@
M26YF;W)M871I;VXB"FUS9W-T<B`BS^[JX.?@\OP@Y^#C[NONXNKH(/#@\?'[
MZ^KH(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@HC+"!F=7IZ
M>0IM<V=I9"`B4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<R(*;7-G<W1R
M("+/[N3OZ/'@\OSQ_R#MX"#OX._J\RCH*2(*"B,Z(&9O;&1E<G,N<&AP.C(X
M-`IM<V=I9"`B4VAO=R!5;G-U8G-C<FEB960B"FUS9W-T<B`BS^[JX.?@\OP@
M[>7O[N3OZ/'@[>W[Y2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.38*
M;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@871T
M86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`BS^[GXN[K__+\(//D
MX.O_\OP@XNONYN7MZ/\@Z.<@[^CQY>PL(.W@YN#RZ.7L(.W@(.CJ[NWJ\R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.3$*;7-G:60@(E-H;W<@;&5G
M96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S='(@(L_NZN#G^^+@\OP@
MZ^7CY>WD\R#O\.@@[_#N\>SN\O#E(/_YZ.K@/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,CD*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A
M9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#,W"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8V"FUS
M9VED(")3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_
M(@IM<V=S='(@(L[R[N'PX.?H\OP@Z.KN[>KS(/'A[O#@(._N]_+[(.(@XN7P
M]>WE["#LY>W^/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY.`HC
M+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM<V=S='(@(L_P[O'L
M[O+P(/'N[N'YY>WH_R#B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C4T"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!F:6QT97(@:6-O;B!O
M;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`BSO+NX?#@Y^CR_"#HZN[MZO,@\>'N
M\.`@[^[W\OL@XB#BY?#U[>7L(.SE[?X_(@H*(R!F=7IZ>0HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,S$*;7-G:60@(E-H;W<@=&]T86P@;G5M8F5R(&]F
M(&UA:6QS(&EN(&9O;&1E<C\B"FUS9W-T<B`BS^[JX.?@\OP@\?/L[.#P[>[E
M(.KNZ^CWY?'RXNX@[^CQY>P@XB#OX._JY3\B"@HC(&9U>GIY"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-30*;7-G:60@(E-H;W=N(@IM<V=S='(@(L[R
M[N'PX.;@\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z-#(*;7-G:60@(E-I7WIE(@IM<V=S='(@(M#@Y^SE
M\"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ
M-PIM<V=I9"`B4VEG;F5D(@IM<V=S='(@(L_NY._H\>#M[B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")3:7IE(@IM
M<V=S='(@(M#@Y^SE\"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@07)R:79A
M;"(*;7-G<W1R("+1[O#RZ/#NXN#R_"#O[B#RY>SE(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B4V]R="!B>2!$871E(@IM<V=S='(@(M'N\/+H\.[BX/+\(._N(/+E[.4B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(V
M"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($9R;VT@061D<F5S<R(*;7-G<W1R
M("+1(.#D\.7QX"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z-#$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@365S<V%G92!3
M:7IE(@IM<V=S='(@(M#@Y^SE\"#Q[N[A^>7MZ/\B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,V"B,L(&9U>GIY"FUS9VED
M(")3;W)T(&)Y(%-U8FIE8W0B"FUS9W-T<B`BP>7G(/+E[/LB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"B,L(&9U>GIY
M"FUS9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R("+1[O#RZ/#NXN#R_"#O
M[B#RY>SE(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S(@IM
M<V=S='(@(M$@X.3PY?'@(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')E9G,O
M<W!A;7-E;&5C="YI;F,Z,C,*;7-G:60@(E-P86T@9F]L9&5R.B(*;7-G<W1R
M("+-Y>;EZ^#RY>O\[?OE(/#@\?'[Z^KH.B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,T-@IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97)S
M(@IM<V=S='(@(M'OY?;HX.O\[?OE(/'H[.+NZ_LB"@HC.B!S96%R8V@N<&AP
M.C$T,@IM<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N;F]T(&)E
M(&5D:71E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S0S"FUS9VED(")3<&5L;"!#:&5C:R(*;7-G<W1R("+/\.[B
MY?#JX"#N\/3NX_#@].CH(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C0V"FUS9VED(")3<&5L;"!#:&5C:V5R(@IM<V=S='(@(L_P[N+E
M\.K@(.[P].[C\.#TZ.@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-#@@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS
M9VED(")3<&5L;"!C:&5C:R!C;VUP;&5T92(*;7-G<W1R("+/\.[BY?#JX"#N
M\/3NX_#@].CH(.?@XN7P^.7MX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-S$*;7-G:60@(E-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@
M<W!E;&P@8VAE8VMI;F<N(@IM<V=S='(@(LKNZ^CWY?'RXNX@[O+NX?#@YN#E
M[/OU(.[XZ.'NZB#N\/3NX_#@].CH(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4P-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`Y"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I9"`B4W1A<G0B"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V-"XP+C(I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0
M('8T+C`N,BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+*X.OE[>3@\/Q<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN
M(@HBRN#KY>WDX/#\7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,RXP+C,I("`C+2,M(RTC+2-<;B(*(LK@Z^7MY.#P_"(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.CD@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,S$Q"FUS9VED(")3=&%T:6]N97)Y(@IM<V=S
M='(@(MC@X>ON[?LB"@HC(&9U>GIY"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T:6]N97)Y(&YA;64Z
M(@IM<V=S='(@(LW@Y^+@[>CE.B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z
M(@IM<V=S='(@(M+H[SHB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B
MV.#AZ^[M.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#,*(RP@
M9G5Z>GD*;7-G:60@(E-T871U<R(*;7-G<W1R("+*X.OE[>3@\/PB"@HC(&9U
M>GIY"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,SD*;7-G:60@(E-T<FEP
M($%T=&%C:&UE;G0B"FUS9W-T<B`BT^3@Z^CR_"#BZ^[FY>WHY2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C$*;7-G:60@(E-T<FEP(&QI;F5B<F5A
M:W,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-U8E]J96-T(@IM<V=S
M='(@(M+E[.`B"@HC.B!M97-S86=E+G!H<#HR-S8@=&AR96%D+G!H<#HQ-34@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A
M<F-H+G!H<#HV,#4*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BTN7LX"(*"B,@
M9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP.0IM<V=I9"`B4W5B
M:F5C="!&:65L9"(*;7-G<W1R("+2Y>S@(/'N[N'YY>WH_R(*"B,@9G5Z>GD*
M(SH@<V5A<F-H+G!H<#HS,3`@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA
M9V4N:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR
M,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"FUS9VED(")3=6)M
M:70B"FUS9W-T<B`BSNHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R
M("+/[N3OZ/'@\OSQ_R#MX"#OX._J\RCH*2(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,S@U(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S
M<R(*;7-G<W1R("+"^^_NZ^WE[>XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S='(@(L?@
M[.7MZ/+\(.W@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U.2!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Q"B,L(&9U>GIY"FUS9VED(")3
M=6UM87)Y(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(L/KX.+MX/]<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.3<@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#`P"B,L(&9U>GIY"FUS9VED(")3=VET8V@@0V]M<&]S
M:71I;VX@365T:&]D(@IM<V=S='(@(L+HY_/@Z_SM^^D@\.7DX.KR[O`B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#$*;7-G:60@(E-W
M:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(L+HY_/@Z_SM^^D@
M\.7DX.KR[O`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M,#$*;7-G:60@(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM
M<V=S='(@(L_E\.7JZ_[WZ/+\\?\@XB#NX?OW[?OI(/#EYNCL(/'N\?+@XNOE
M[>C_(/'N[N'YY>WH_R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#$V"FUS9VED(")495]X="(*;7-G<W1R("+2Y>KQ\B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-S`*;7-G:60@(E1E;G1A
M=&EV93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#8*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-30*;7-G:60@
M(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D
M(&EN(&-O;F8N<&AP(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C,P"FUS9VED(")497AT(@IM<V=S='(@
M(M+EZO'R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,PIM<V=I9"`B
M5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN
M:V5D.B(*;7-G<W1R("+*X.KNY2#DY>GQ\N+HY2#B^^?[XN#E\B#YY>OW[NH@
M[^X@X.3PY?'S(.[R[_#@XNCRY>O_.B(*"B,Z(&QI8B])34%0+T-L:65N="YP
M:'`Z-3(U"FUS9VED("(B"B)4:&4@24U!4"!S97)V97(@9&]E<R!N;W0@87!P
M96%R('1O('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"`B"B)S
M96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U
M8FQE+G!H<#HT,0IM<V=I9"`B5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP
M:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($UA8VEN=&]S:"!R97-O
M=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+B(*;7-G<W1R("(B"@HC
M(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`BS_#N].CK_"!<(B5S7"(@X?OK(//DX.OE
M[2XB"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&9E=&-H;6%I;'!R969S+G!H
M<#HW-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@
M:&%S(&)E96X@<V%V960N(@IM<V=S='(@(L_P[O3HZ_P@7"(E<UPB(.'[ZR#Q
M[O7PX.WE[2XB"@HC.B!A='1A8VAM96YT+G!H<#HT,PHC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N9"XB"FUS9W-T<B`BS_#H
MZO#E[^OE[>W[Y2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,0IM
M<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-O;7!O<V5?=VEN+FIS
M.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@;W!E
M;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB
M8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,@IM<V=I9"`B5&AE(&-O;G1E;G1S
M(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT
M:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8W5R<F5N="!F
M;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T;R!<(B5S7"(N(@IM
M<V=S='(@(M+EZO/YX/\@[^#OZN`HZ"D@7"(E<UPB(.'SY.7R(._E\.7H[.7M
M[N+@[>`@XB!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P
M-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C
M8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM
M<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R-S(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@
M7"(E<UPB(&9O;&1E<BXB"FUS9W-T<B`BS_#N].CK_"!<(B5S7"(@X?OK(/'N
M]?#@[>7M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#`*;7-G
M:60@(E1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEE;&0@7"(E<UPB(&-A
M;B=T(&)E(&5X<&%N9&5D+B(*;7-G<W1R("+/[N3OZ/'\(.WE(.SNYN7R(.'[
M\OP@Y^#LY>WE[>`N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S,R"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB(&%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(L_@[^K@(%PB)7-<(B#SYN4@\?/YY?'RXO/E\B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M9F]L9&5R(%PB)7-<(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@
M:71S(&YA;64N($ET(&UA>2!C875S92`B"B)P<F]B;&5M<RX@4&QE87-E('-E
M92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+/X._J
MX"!<(B5S7"(@\>[DY?#FZ/(@Y^#O\.7YY>WM^^4@\>CLXN[K^R#B(.CLY>WH
M+B#=\NX@[.[FY?(@XOOG^^+@\OP@(@HB[_#NX>OE[/LN(,_NYN#K\^GQ\N`L
M(/'B_^;H\N7Q_"#Q(,+@^.CL(/'H\>#D[.CM[NPN(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E
M<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T
M;R!I="XB"FUS9W-T<B`BS^#OZN`@7"(E<UPB(.'[Z^`@\>[GY.#MX"P@[>X@
MPOL@[>4@X?OKZ"#MX"#MY>4@[^[D[^CQX.W[+B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C(V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<
M(B!W87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F
M<F]M(&ET+B(*;7-G<W1R("+/X._JX"!<(B5S7"(@X?OKX"#SY.#KY>W@+"#M
M[B#"^R#MY2#@[>WSZ^CP[N+@Z^@@[^[D[^CQZO,@[>`@[>7E+B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C,S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L
M9&5R(%PB)7-<(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`BS^#OZN`@7"(E<UPB(.WE(.'[Z^`@\>[G
MY.#MX"X@T>7PXN7P(.[RXN7RZ.LB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO
M="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(L_@[^K@(%PB)7-<(B#MY2#A^^O@(//DX.OE[>`N(-'E\.+E\"#N\N+E
M\NCK(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E871E
M9"XB"FUS9W-T<B`BS^#OZN`@7"(E<UPB(.'[Z^`@\_'OY?CM[B#Q[N?DX.W@
M+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N
M(@IM<V=S='(@(L_@[^K@(%PB)7-<(B#A^^O@(//Q[^7X[>X@\^3@Z^7MX"XB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HT-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O
M(%PB)7-<(BXB"FUS9W-T<B`BS^#OZN`@7"(E<UPB(.'[Z^`@\_'OY?CM[B#O
MY?#EZ.SE[>[BX.W@(.(@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T
M;F5F+G!H<#HY-`IM<V=I9"`B5&AE(&9O;&QO=VEN9R!F:6QE<R!W97)E(&%T
M=&%C:&5D('1O('1H:7,@<&%R=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]S879E:6UA9V5?=VEN+FIS.C$R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W!O<'5P+FIS.C4Y"FUS9VED("(B"B)4:&4@:6UA
M9V4@<V%V92!W:6YD;W<@8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U
M(&AA=F4@<V5T('EO=7(@8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U<"!W:6YD
M;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M,3`P"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES
M<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@
M(@HB861D<F5S<V)O;VLN(@IM<V=S='(@(L[R[N'PX.;@\OP@ZN#P\NCMZN@@
MXB!(5$U,(/'N[N'YY>WH__4@Y.O_(.#D\.7QX/+NXB#HYR#@Y/#E\>WNZ2#J
M[>CCZ"(*"B,@9G5Z>GD*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-S4*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO
M=VEN9R!E<G)O<B!M97-S86=E.B(*;7-G<W1R("+/[O?R[N+[Z2#QY?#BY?`@
M[_#H\>O@ZR#QZ^7D\_[YY>4@\>[NX?GE[>CE(.[A(.[XZ.'JY3HB"@HC.B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG
M(&EN9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`BS>#Q\O#NZ>KH(._N
M]_+NXN[C[B#QY?#BY?#@(.@@Z.WT[O#LX/;HZ"#N(._@[^K@]2XB"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A
M9V4Z(@IM<V=S='(@(LW@\?+P[NGJZ"#O[O?R[N+NX^X@\>7PXN7PX"#H(.CM
M].[P[.#VZ.@@[B#OX._JX/4N(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!L
M:6(O365S<V%G92YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M
M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(L_@[^K@(%PB
M)7-<(B#SYN4@[_/Q\N#_(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C0W"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB
M)7-<(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M,#,*(RP@9G5Z>GD*;7-G:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D
M(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`BT>[GY.#BX.7L
M[N4@\>[NX?GE[>CE(.'[Z^X@Y^#J\/OR[BX@POOU[N;S+B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3(V"B,L(&9U>GIY"FUS9VED(")4
M:&4@;65S<V%G92!D;V5S(&YO="!H879E(&$@4W5B:F5C="!E;G1E<F5D+B(*
M;7-G<W1R("+/\.[TZ.O\(%PB)7-<(B#A^^L@\>[U\.#MY>TN(@H*(SH@;65S
M<V%G92YP:'`Z,30Y"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("+/\.[TZ.O\(%PB)7-<(B#A^^L@\^3@
MZ^7M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y-PHC+"!F=7IZ
M>0IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S
M='(@(L_P[O3HZ_P@7"(E<UPB(.'[ZR#Q[O7PX.WE[2XB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C,X.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@
M)7,N(@IM<V=S='(@(L_P[O3HZ_P@7"(E<UPB(.'[ZR#Q[O7PX.WE[2XB"@HC
M.B!T96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA
M=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S
M<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA
M=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S
M/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F('1H92!01U`@
M4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("+1X.P@ZNO^
M]R#O\.[Q[.[R\.7R_"#B^R#Q[.[FY?+E("5S(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.C8P"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E
M<R!N;W0@97AI<W0@:6X@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G:60@(E1H
M92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T
M=&%C:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G
M92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC
M871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S
M<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE("(*(FYO=&EF:6-A
M=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HV-PIM<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@
M=&\@8W)E871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z.3`*(RP@9G5Z
M>GD*;7-G:60@(E1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D
M+B(*;7-G<W1R("+/[N3OZ/'\(.WE(.SNYN7R(.'[\OP@Y^#LY>WE[>`N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHX.`IM<V=I9"`B5&AE
M('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R
M("+/[N3OZ/'\(//Q[^7X[>X@Y^#LY>WE[>`N(@H*(SH@871T86-H;65N="YP
M:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@
M8F5E;B!A9&1E9"XB"FUS9W-T<B`BQ^#CZ^#BZ.4@)7,@X?OK[B#D[N'@XNOE
M[>XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(M'E\.+E\"`E<R#A^^L@\^3@Z^7M(@H*(SH@<W1A=&EO
M;F5R>2YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S
M=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("+1
MY?#BY?`@)7,@X?OK(//DX.OE[2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-S`*(RP@9G5Z>GD*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D
M9&5D('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(L_P[O3HZ_P@7"(E<UPB
M(.'[ZR#Q[O7PX.WE[2XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HY-0HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4B
M"FUS9W-T<B`B\^3@Z^CR_"#Q[N[A^>7MZ.4B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS
M9W-T<B`B\^3@Z^CR_"#Q[N[A^>7MZ.4B"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`BS^7PY>W@[_#@XNCR_"#]\NX@
M\>[NX?GE[>CE(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S
M+B(*;7-G<W1R("+2Y>KQ\B#BY?#M\^+XY>/N\?\@[^CQ_.S@(.SNYN7R(.'[
M\OP@[_#N\>SN\O#E[2`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M('-E;G0@;65S<V%G92(*;7-G<W1R("+/Y?#E[>#O\.#BZ/+\(/WR[B#Q[N[A
M^>7MZ.4B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M('-E;G0@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("+/Y?#E
M[>#O\.#BZ/+\(/WR[B#Q[N[A^>7MZ.4B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,34U"B,L(&9U>GIY"FUS9VED(")4:&4@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G
M<W1R("+/[N3OZ/'\(//Q[^7X[>X@Y^#LY>WE[>`N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM<V=I9"`B5&AE<F4@87)E(&YO
M(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V5M<'1Y7VUA
M:6QB;W@N:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T
M:&ES(&UA:6QB;W@N(@IM<V=S='(@(L(@_?+N["#_^>CJY2#MY?(@[^CQY>PN
M(@H*(SH@=&AR96%D+G!H<#HQ,3`*;7-G:60@(E1H97)E(&ES(&YO('1E>'0@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N
M(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`BS_#NX>OE[.`@[_#H(._N
M[_ORZN4@XOOWY?#J[?/R_"#O[O?R[N+[Z2#_^>CJ+B#1Y?#BY?`@\>K@Y^#K
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Q,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G
M97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*
M(G-E<G9E<B!S86ED(@IM<V=S='(@(L[XZ.'JX"#O\.@@ZN[OZ/#NXN#MZ.@@
M[^CQY>P@XB!<(B5S7"(N(-'E\.+E\"#N\N+E\NCK(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C(R-B!L:6(O365S<V%G92YP:'`Z,C0T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE
M('-E<G9E<B!S86ED(@IM<V=S='(@(L[XZ.'JX"#O\.@@\^3@Z^7MZ.@@[^CQ
MY>P@Z.<@[^#OZN@@7"(E<UPB+B#1Y?#BY?`@[O+BY?+HZR(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HS,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@
M7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S
M='(@(L[XZ.'JX"#O\.@@\^3@Z^7MZ.@@[^CQY>P@Z.<@[^#OZN@@7"(E<UPB
M+B#1Y?#BY?`@[O+BY?+HZR(*"B,Z(&QI8B]-97-S86=E+G!H<#HR-#(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@)7,B"FUS9W-T<B`BS_#NX>OE[.`@[_#H(//DX.OE[>CH(._H\>7L+B#1
MY?#BY?`@\>K@Y^#K(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(L_P[N'KY>S@
M(._PZ"#O\.[Q[.[R\.4@Y^#O\.[XY>WM[N/N(._H\?SLX"XB"@HC.B!L:6(O
M34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E<B]E;G)I
M8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(L[XZ.'JX"#O\.@@[O+N
MX?#@YN7MZ.@@_?+NZ2#WX/'RZ"#Q[N[A^>7MZ/\B"@HC.B!L:6(O365S<V%G
M92YP:'`Z-3DT"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<
M(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+.
M^.CAZN`@[_#H(._N[.7RZN4@[^CQY>P@XB#OX._JY2!<(B5S7"(N(-'E\.+E
M\"#N\N+E\NCK("(*"B,Z(&9O;&1E<G,N<&AP.C$T.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E
M<RXB"FUS9W-T<B`BSOCHX>K@(._PZ"#GX._H\>@@]^7P[>[BZ.K@+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&5V96YT.B`E<RXB"FUS9W-T<B`BS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#G
MX._P[OCE[>WNX^X@[^CQ_.S@+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R("+/
M\.[AZ^7LX"#O\.@@[_#N\>SN\O#E(.?@[_#N^.7M[>[C[B#OZ/'\[.`N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U
M<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`BSOCH
MX>K@(.[R[_#@XNKH(._H\?SLX#H@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z
M,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<
M(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+.
M^.CAZN`@[_#H(._E\.7LY?GE[>CH(._H\?SLX"#B(%PB)7-<(BX@T>7PXN7P
M(.[RXN7RZ.LB"@HC.B!C;VUP;W-E+G!H<#HQ,C@P"B,L(&9U>GIY"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A
M(&1R869T+B(*;7-G<W1R("+.^.CAZN`@[_#H(.[R[N'PX.;E[>CH(/WR[ND@
M]^#Q\N@@\>[NX?GE[>C_(@H*(SH@8V]M<&]S92YP:'`Z,3`S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R
M(&UE<W-A9V4Z("5S(@IM<V=S='(@(L[XZ.'JX"#N\N_PX.+JZ"#OZ/'\[.`Z
M("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(L[XZ.'JX"#N\N_PX.+JZ"#O
MZ/'\[.`Z("5S(@H*(R!F=7IZ>0HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN
M<&AP.C4Y"FUS9VED(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R("+=\NX@[^CQ_.SN(.WE(/'NY.7PYNCR(/+EZO'R
MX"(*"B,@9G5Z>GD*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P,`IM
M<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I
M;B!I="XB"FUS9W-T<B`BW?+N(/'N[N'YY>WHY2#Q[N3E\.;H\B#B\?+P[N7M
M[?OE(.CG[N'PX.;E[>C_+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY,PIM<V=I9"`B(@HB5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E
M;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@(@HB
M=&AI<SH@(@IM<V=S='(@(B(*(MWR[B#Q[N[A^>7MZ.4@\>[DY?#FZ/(@XO'R
M\.[E[>W[Y2#HY^[A\.#FY>WH_RX@Q^#AZ^[JZ/#NXN#M[?OE(.CG[N'PX.;E
M[>C_("(*(N+[X^O_Y/_R(/+@ZCHB"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-C4*;7-G:60@(E1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C
M:&5D('1O('1H92!M97-S86=E+B(*;7-G<W1R("+*(/'N[N'YY>WH_B#O\.CK
M[N;E[2#O\^'KZ/?M^^D@4$=0(.KK_O<N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$Y"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#0@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$U.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<T
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,34*(RP@9G5Z>GD*;7-G:60@
M(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N,BD@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@=C0N,"XR*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!V
M-"XP+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WH
MY5QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@
M(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-
M[N+NY2#Q[N[A^>7MZ.4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3@P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,C`*(RP@9G5Z>GD*;7-G
M:60@(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0('8T+C`N,BD@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M=C0N,"XR*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$E-4"!V-"XP+C(I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E
M(/'N[N'YY>WHY5QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N
M,"XS*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)
M35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M
M(RTC7&XB"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C$T('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I
M<'0N:6YC.C8*;7-G:60@(E1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_(@IM<V=S='(@(MWR[B#L
M[N;E\B#GX.W_\OP@ZN#J[N4M\NX@XO#E[/\N(,+[(/+N]^WN(/7N\NCRY2#O
M\.[D[NOFZ/+\/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP
M:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S
M:"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C0Q-0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A
M:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L;'D@<VEG
M;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(MWR[B#OZ/'\[.X@X?OK[B#O
M[N3OZ/'@[>X@]NCT\.[B[ND@[^[D[^CQ_/X@4$=0(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HT,3D*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT
M86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I
M82!3+TU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C$V,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA
M:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA
M="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S$Y"FUS9VED("(B"B)4:&ES
M(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@4$=0(&5N
M8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(S.2!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HS-30*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D:6YG('1O
M("(*(E)&0R`R,#$U*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HQ-S`*;7-G:60@(E1H:7,@;65S<V%G92!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`T(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C0R,`IM<V=I9"`B5&AI<R!M97-S86=E(&AA
M<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"XB"FUS9W-T<B`BW?+N
M(._H\?SL[B#A^^ON(._NY._H\>#M[B#VZ/3P[N+NZ2#O[N3OZ/'\_B!01U`B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T,PHC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@
M=FEA(%,O34E-12XB"FUS9W-T<B`BW?+N(._H\?SL[B#A^^ON(._NY._H\>#M
M[B#VZ/3P[N+NZ2#O[N3OZ/'\_B!01U`B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E
M9"!V:6$@4R]-24U%+B(*;7-G<W1R("+/\.[TZ.O\(%PB)7-<(B#A^^L@\^3@
MZ^7M+B(*"B,@9G5Z>GD*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`P
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,`IM<V=I9"`B5&AI<R!M97-S
M86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`BW?+N
M(._H\?SL[B#A^^ON(.?@^.CT\.[BX.WN(%!'4"(*"B,Z(&UE<W-A9V4N<&AP
M.C(Q,0IM<V=I9"`B5&AI<R!M97-S86=E('1O(@IM<V=S='(@(MWR[B#Q[N[A
M^>7MZ.4@XB(*"B,Z(&%C;"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P.0HC+"!F=7IZ
M>0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A(&-O
M;7!O<V4@=VEN9&]W+B(*;7-G<W1R("+=\NX@[NKM[B#D[NOF[>X@XOOG^^+@
M\OSQ_R#HYR#NZNW@(/'NY^3@[>C_(/'N[N'YY>WH_R(*"B,Z('1H<F5A9"YP
M:'`Z,34W"B,L(&9U>GIY"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G<W1R
M("+.\N[A\.#FY>WHY2#TX.GK[N(B"@HC.B!T:')E860N<&AP.C<V('1E;7!L
M871E<R]T:')E860O=&]P+FEN8SHS(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,3$*;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@(L_P[O'L[O#R(._N(/+E
M[.#L(@H*(SH@;65S<V%G92YP:'`Z,C<R(&UA:6QB;W@N<&AP.C8P,B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O
M;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C4Y,PIM<V=I9"`B5&\B"FUS
M9W-T<B`BRN[L\R(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDP.`IM<V=I9"`B5&\@061D<F5S<R(*;7-G<W1R("+`Y/#E\2#O[NOS]^#R
MY>O_(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(V
M"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE("(*
M(F-L:6-K:6YG+B(*;7-G<W1R("+$Z_\@XOOA[O#@(.WE\>KNZ_SJZ/4@[^[K
MY>D@Y.7PYNCRY2#JZ^#BZ/CS($-T<FPB"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C$S-`IM<V=I9"`B(@HB5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO
M=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C$N,"!O<B`B
M"B)H:6=H97(N(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3DQ"FUS9VED(")4;W1A;"!!='1A8VAM96YT
M<R!3:7IE.B(*;7-G<W1R("+.X?GHZ2#PX.?LY?`@XNONYN7MZ.DZ(@H*(SH@
M9F]L9&5R<RYP:'`Z,S8Y"B,L(&9U>GIY"FUS9VED(")4<F%S:"!F;VQD97(B
M"FUS9W-T<B`BS//Q[O#MX/\@ZN[PY^CMX#HB"@HC.B!T96UP;&%T97,O<')E
M9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM
M<V=S='(@(LSS\>[P[>#_(.KN\.?H[>`Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S
M+G!H<#HV-"!L:6(O475O=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O
M8V]M;6%N9"YP:'`Z-S$*(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI
M8B]1=6]T82]C;W5R:65R+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z
M-#@*;7-G:60@(E5N86)L92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G
M<W1R("+-Y2#N\N+E]^7M[?OE(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M97-S86=E<R(*;7-G<W1R("+-
MY2#N\N+E]^7M[?OE(/'N[N'YY>WH_R(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T92(*;7-G<W1R("+"[O'Q\N#M[N+H
M\OPB"@HC.B!M86EL8F]X+G!H<#HU.#`@;6%I;&)O>"YP:'`Z-3DX(&QI8B]-
M24U%+TAE861E<G,N<&AP.C(P-`IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I
M96YT<R(*;7-G<W1R("+-Y?#@\>KP^_+[Y2#O[NOS]^#RY>OH(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HU-38*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\@05542$5.5$E#051%(&-O;6UA;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3(P"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($1I9V5S="U-1#4@<F5S
M<&]N<V4N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3,V
M"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($Q/
M1TE.(&-O;6UA;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O
M;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H
M<#HU-3@*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@1&%T92(*;7-G<W1R("+-
MY?#@\>KP^_+[Y2#O[NOS]^#RY>OH(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O
M;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-@HC+"!F
M=7IZ>0IM<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@(LWE\.#QZO#[
M\OOE(._NZ_/WX/+EZ^@B"@HC.B!M86EL8F]X+G!H<#HV,30*(RP@9G5Z>GD*
M;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@(LWE\.#QZO#[\OOE
M(._NZ_/WX/+EZ^@B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P
M:')A<V4B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(LWE[>#GXN#M[?OE(@H*(SH@;65S<V%G
M92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<P,R!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,R"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-0IM<V=I9"`B56YS965N
M(@IM<V=S='(@(LWNXOOE(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,3(*;7-G:60@(E5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I(@IM
M<V=S='(@(L[R[.7MZ/+\(._NY._H\>KS(.W@(,_@[^KS*.@I(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,34*;7-G:60@
M(E5P9&%T92(*;7-G<W1R("+/\.CLY>WH\OPB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C$R"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T
M=7,B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<VUI;64O:6UP
M;W)T7VME>2YI;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU
M-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(L?@X_#SY^CR_"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*;7-G:60@(E5S92!$
M969A=6QT(%9A;'5E(@IM<V=S='(@(LCQ[^[K_.?NXN#R_"#G[>#WY>WH_R#O
M[B#S[.[K]^#MZ/XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"FUS
M9VED(")5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T<B`B
MR/'O[NO\Y^[BX/+\(._NY._H\>KS(.W@(._@[^KH($E-05`_(@H*(R!F=7IZ
M>0HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,C0*;7-G:60@
M(E5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\B"FUS9W-T<B`BR/'O[NO\Y^[B
MX/+\(,+H\/+SX.O\[?/^(,KN\.?H[?,_(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$T,PHC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("+([/\@
M[^[K_.?NXN#RY>O_(@H*(SH@86-L+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE('-P
M96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-@IM<V=I9"`B
M57-E<FYA;64B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,@9G5Z>GD*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$W"FUS9VED(")5
M<V5R;F%M93HB"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,@9G5Z>GD*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I
M97<B"FUS9W-T<B`BS_#N\>SN\O`B"@HC.B!L:6(O34E-12]6:65W97(O>FEP
M+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3$P"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`BS_#N\>SN\O`@)7,B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(L+@^.4@[^[K[>[E(.CL_SHB"@HC.B!L
M:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")6
M:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R
M("+1[N?DX/+\(._H\?SLX"#B(/#@Y^W[]2#NZNW@]2XB"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X"FUS9VED(")6:65W
M($UE<W-A9V5S(@IM<V=S='(@(L_P[O'L[O+PY?+\(/'N[N'YY>WH_R(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<W"FUS9VED(")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"B,L(&9U>GIY"FUS9VED(")6:65W(%!E
M<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`BPN#XY2#O[NOM[N4@Z.S_.B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM
M<V=I9"`B5FEE=R!4:')E860B"FUS9W-T<B`BS_#N\>SN\O#E\OP@[^X@\N7L
MX.PB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C0@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")6:65W
M(%1H=6UB;F%I;"(*;7-G<W1R("+/\.[Q[.[R\.7R_"#O[B#RY>S@["(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"B,L(&9U>GIY"FUS9VED
M(")6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T
M<B`BT>[GY.#R_"#OZ/'\[.`@XB#PX.?M^_4@[NKMX/4N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")6:65W
M(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`BT>[GY.#R
M_"#OZ/'\[.`@XB#PX.?M^_4@[NKMX/4N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$T,0HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G
M<W1R("+/\.[Q[.[R\"#O\.CJ\.7OZ^7M[>[C[B#TX.GKX"(*"B,@9G5Z>GDL
M('!H<"UF;W)M870*(SH@9F]L9&5R<RYP:'`Z,S8Q(&UA:6QB;W@N<&AP.C4R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S(@IM
M<V=S='(@(L_P[O'L[O+P(/'N[N'YY>WHZ2#B("5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O
M<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S='(@(L_P
M[O'L[O+P(/_YZ.K@(._N\>OE(.+U[N3@(.(@\>CQ\N7L\SHB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED(")6:65W
M('1A<VLB"FUS9W-T<B`BS_#N\>SN\O`@)7,B"@HC.B!L:6(O34E-12]6:65W
M97(O:'1M;"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")6:65W('1H92!);6%G
M97,B"FUS9W-T<B`BS_#N\>SN\O`@\>[NX?GE[>C_(.(B"@HC.B!S96%R8V@N
M<&AP.C(V,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FER='5A;"!&
M;VQD97(@7"(E<UPB(&-R96%T960@<W5C8V5S9G5L;'DN(@IM<V=S='(@(L_@
M[^K@(%PB)7-<(B#A^^O@(//Q[^7X[>X@\^3@Z^7MX"XB"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])34%0+U1R964N
M<&AP.C$T,2!L:6(O24U!4"]4<F5E+G!H<#HQ-30*(SH@;&EB+TE-05`O5')E
M92YP:'`Z,34V(&QI8B])34%0+U1R964N<&AP.C$V,"!L:6(O24U!4"]4<F5E
M+G!H<#HQ-C$*(SH@;&EB+TE-05`O5')E92YP:'`Z,S<Q(&QI8B])34%0+U1R
M964N<&AP.C,Y-2!L:6(O24U!4"]4<F5E+G!H<#HT,S,*;7-G:60@(E9I<G1U
M86P@1F]L9&5R<R(*;7-G<W1R("+"Z/#R\^#K_.W[Y2#OX._JZ"(*"B,Z('-E
M87)C:"YP:'`Z,C4R"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L($9O;&1E<G,@
M<F5Q=6ER92!A(&QA8F5L+B(*;7-G<W1R("+-X.?BX.WHY2#BZ/#R\^#K_.WN
MZ2#OX._JZ"(*"B,Z(&QI8B]61F]L9&5R+G!H<#HQ-S8@;&EB+U9&;VQD97(N
M<&AP.C$X-B!L:6(O4V5A<F-H+G!H<#HT,C`*;7-G:60@(E9I<G1U86P@24Y"
M3U@B"FUS9W-T<B`BPNCP\O/@Z_SM^^4@PO7NY/_YZ.4B"@HC(&9U>GIY"B,@
M9G5Z>GD*(SH@9F]L9&5R<RYP:'`Z,SDW"FUS9VED(")6:7)T=6%L($E.0D]8
M($9O;&1E<B(*;7-G<W1R("+"Z/#R\^#K_.W[Y2#"]>[D__GHY2(*"B,@9G5Z
M>GD*(R!F=7IZ>0HC.B!L:6(O36%I;&)O>"YP:'`Z,34V(&QI8B]61F]L9&5R
M+G!H<#HQ,3$@;&EB+U9&;VQD97(N<&AP.C$R,PHC.B!L:6(O4V5A<F-H+G!H
M<#HS-C8*;7-G:60@(E9I<G1U86P@5')A<V@B"FUS9W-T<B`BPNCP\O/@Z_SM
MX/\@ZN[PY^CMX"(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!F;VQD97)S+G!H<#HS
M.30*;7-G:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(L+H\/+S
MX.O\[>#_(.KN\.?H[>`B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C$R.`IM<V=I9"`B5FER='5A;"!F;VQD97(@;&%B96PB"FUS9W-T<B`BS>#G
MXN#MZ.4@XNCP\O/@Z_SM[ND@[^#OZN@B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C,W.0HC+"!F=7IZ>0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R
M("+0X.?BY?#M\_+\(.+QY2(*"B,Z(&QO9VEN+G!H<#HQ-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+$[N'P[B#O[N;@
MZ^[BX/+\(.(@)7,B"@HC(&9U>GIY"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8P-PIM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET
M:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D
M(&%S('-P86T@(@HB;W(@:6YN;V-E;G0_(@IM<V=S='(@(B(*(M?R[B#DY>O@
M\OP@\2#Q[N[A^>7MZ.7L+"#O[O'KY2#R[N/N(.K@ZB#N[>X@X?OK[B#O[NSE
M]^7M[B#JX.H@\>_@["#HZ^@@[>4@(@HB\>_@[#\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S$V"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A
M9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O
M9B!M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HBS_#H
M(//DX.OE[>CH(/'N[N'YY>WH_RP@[^7PY>SE\?+H\OP@Y>/N(.(@RN[PY^CM
M\RP@X"#MY2#O[NSE]^#R_"#JX.H@(@HB\^3@Z^7M[>[E/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX.38*;7-G:60@(E=H96X@;W!E;FEN9R!A(&YE
M=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N
M/R(*;7-G<W1R("+/\.@@[O+J\/ORZ.@@[>[B[N/N(/_YZ.K@+"#JX.KHY2#Q
M[N[A^>7MZ/\@[O+NX?#@Y^CR_"#Q\.#G\S\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H
M;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`BT>[U\.#M
M__+\(.+K[N;E[>C_(.(@Z/'U[N3_^>CU(/'N[N'YY>WH__4_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG
M(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO
M=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R97-S97,@*&5M
M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T<B`BQ.[LY>T@
M[^X@\^SNZ_?@[>C^.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ
M.0IM<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4S.2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHU-3(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV-PIM<V=I
M9"`B665S(@IM<V=S='(@(L3@(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M9F5T8VAM86EL7VQO9VEN+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R
M92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C
M;W5N="AS*3HB"FUS9W-T<B`BPOL@]>[RZ/+E(//DX.OH\OP@\>OEY//^^>CE
M(._@[^KH.B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R
M<U]C;VYF:7)M+FAT;6PZ,3`*;7-G:60@(B(*(EEO=2!A<F4@871T96UP=&EN
M9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@9F]L
M;&]W:6YG(&9O;&1E<B(*(BAS*2XB"FUS9W-T<B`BPOL@[_ORX.7RY?'\(//D
MX.OH\OP@XO'E(/'N[N'YY>WH_R#B(/'KY>3S_OGEZ2#OX._JY3HB"@HC(&9U
M>GIY"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL
M.CD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@=&AE(&9O
M;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(L+[(._[\N#E\N7Q_"#SY.#K
MZ/+\(/'KY>3S_OGHY2#OX._JZ#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@8V]P>6EN9R]M;W9I
M;F<@=&\@82!N97<@9F]L9&5R+B(*;7-G<W1R("+"^R#OY?#EZ.SE[>[B^^+@
MY?+E(._@[^KS.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C$P-"!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R:7!T+FEN8SHY-`IM
M<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@(@IM<V=S
M='(@(L+[(/'NY^3@Y?+E(.+K[N;E[>WS_B#OX._J\R#B("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`V('1E;7!L871E<R]F;VQD
M97)S+VIA=F%S8W)I<'0N:6YC.CDV"FUS9VED(")9;W4@87)E(&-R96%T:6YG
M(&$@=&]P+6QE=F5L(&9O;&1E<BXB"FUS9W-T<B`BPOL@\>[GY.#E\N4@[^#O
MZO,@XN7P]>WEX^X@\_#NXNW_+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,Q-0HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M9F]L9&5R<RXB"FUS9W-T<B`BPOL@\>[GY.#E\N4@[^#OZO,@XN7P]>WEX^X@
M\_#NXNW_+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9F]L9&5R<RYJ<SHQ,S<@=&5M<&QA=&5S+V9O;&1E<G,O:F%V87-C
M<FEP="YI;F,Z,3(W"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD
M97(Z("(*;7-G<W1R("+"^R#OY?#EZ.SE[>[B^^+@Y?+E(._@[^KS.B`B"@HC
M.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@=&AE(&9O;&QO=VEN9R!P;&%C
M96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X=#H@)6,@9F]R('1H92`B
M"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R('1H92!S:6=N871U
M<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A;FYO="!U;G-U8G-C<FEB92!F
M<F]M(%PB)7-<(BXB"FUS9W-T<B`BPOL@\_'OY?CM[B#N\NK@Y^#KZ/'\(.[R
M(._NY._H\>KH(.W@(%PB)7-<(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+W1O<U]A9W)E96UE;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED(&YO="!A
M9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O('EO
M=2!W97)E(&YO="!A;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3<P"FUS9VED(")9;W4@9&\@;F]T
M(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L
M9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,S`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S
M86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*
M;7-G<W1R("+/Y?#E[>#O\.#BZ/+\(/WR[B#Q[N[A^>7MZ.4B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@:&%V92`E<R!N97<@;65S<V%G97,N(@IM<V=S='(@(L3K_R#"X/$@
MY?'R_"`E<R#M[N+[]2#Q[N[A^>7MZ.DN(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H879E(#$@;F5W(&UE<W-A9V4N
M(@IM<V=S='(@(L3K_R#"X/$@Y?'R_"#NY.WN(.WNXN[E(/'N[N'YY>WHY2XB
M"@HC.B!C;VUP;W-E+G!H<#HT.#(*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E
M(&%L<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T<B`BQ.O_(,+@
M\2#E\?+\(.[D[>X@[>[B[N4@\>[NX?GE[>CE+B(*"B,Z(&QI8B])35`N<&AP
M.C$P-3(*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I
M;F<@9F]L9&5R.B(*;7-G<W1R("+$Z_\@PN#Q(.7Q\OP@[^[W\N`@XB#QZ^7D
M\_[YY>D@[^#OZN4Z(@H*(SH@;&EB+TE-4"YP:'`Z,3`U-PIM<V=I9"`B66]U
M(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.B(*;7-G
M<W1R("+$Z_\@PN#Q(.7Q\OP@[^[W\N`@XB#QZ^7D\_[YZ/4@[^#OZN#U.B(*
M"B,Z(&-O;7!O<V4N<&AP.C$U,PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS9W-T<B`BPOL@Y.[K
MYNW[(//JX.?@\OP@[^X@ZO#@Z>WEZ2#LY?#E(.[D[>[C[B#O[NOS]^#RY>O_
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,P-@IM<V=I9"`B(@HB
M66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R
M:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E(@IM<V=S='(@(B(*(L+[
M(.3NZ^;M^R#BXN7Q\N@@[^#P[NO\(/'B[N7C[B#QY>KPY?+M[N/N(.KK_O?@
M(.3K_R#R[N/N(/?R[N'[(._P[O'L[O+PY?+\("(*(O'N[N'YY>WHY2(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C4T"FUS9VED("(B"B)9;W4@
M;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I
M=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-C0@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS9VED(")9;W4@;75S
M="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB"FUS9W-T<B`BPOL@
MY.[KYNW[(//JX.?@\OP@\>W@]^#KX"#B(.K@ZO/^(._@[^KS+B(*"B,Z(&9E
M=&-H;6%I;'!R969S+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BPOL@
MY.[KYNW[(.+[X?#@\OP@[_#N].CK_"#DZ_\@\^3@Z^7MZ/\N(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(L+[(.3NZ^;M
M^R#Q[>#WX.O@(.+[X?#@\OP@X.3PY?$N(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N
M:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M
M97-S86=E(&9I<G-T+B(*;7-G<W1R("+"^R#D[NOF[?L@\>W@]^#KX"#B^^'P
MX/+\(._N(.KPX.GMY>D@[.7PY2#NY.WN(/'N[N'YY>WHY2XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3,*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!R96-I<&EE;G0N(@IM<V=S='(@(L+[(.3NZ^;M^R#SZN#G
MX/+\(._NZ_/WX/+EZ_\N(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF
M;W)M870*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N
M86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R("+"
MX.P@[>7NX?7NY.CL[B#H[.7R_"#BZNO^]^7M[>[I(.[O]NC^("<E<R<@XB#N
M[^7PX/;H__4@[N'QZ_/FZ.+@[>C_("(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ
M,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!R961I<F5C=&5D
M('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N(@IM<V=S='(@(L_E\.7MX._P
MX.+H\OP@_?+N(/'N[N'YY>WHY2(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@
M;&EB+TUA:6QL;V<N<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM<V=S='(@(L+[(.[R
MXN7RZ.OH(.W@(/WR[B#Q[N[A^>7MZ.4@)7,B"@HC.B!L:6(O1F]L9&5R+G!H
M<#HU,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('-U8G-C
M<FEB960@=&\@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED
M(@IM<V=S='(@(L+[(.WE(.'[Z^@@[^[D[^CQX.W[(.W@(%PB)7-<(BX@T>7P
MXN7P(.[RXN7RZ.LB"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB
M)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("+"
M^R#MY2#Q[.[CZ^@@[NK@Y^#R_/'_(.[R(._NY._H\>KH(.W@(%PB)7-<(BX@
MT>7PXN7P(.[RXN7RZ.LB"@HC.B!L:6(O1F]L9&5R+G!H<#HU,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB
M960@=&\@7"(E<UPB(@IM<V=S='(@(L+[(//Q[^7X[>X@[^[D[^CQX.OH\?P@
M[>`@7"(E<UPB(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-38R"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@
M9G)O;2!<(B5S7"(B"FUS9W-T<B`BPOL@\_'OY?CM[B#N\NK@Y^#KZ/'\(.[R
M(._NY._H\>KH(.W@(%PB)7-<(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`BPN#XY2#H
M[/\Z(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G
M:60@(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`BPN#X
MZ"#O\^'KZ/?M^^4O\>7J\.7R[?OE(.KK_O?H(%!'4"(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`BPN#X
M(/'EZO#E\NW[Z2#JZ_[W.B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHV-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S$*;7-G:60@
M(EEO=7(@4'5B;&EC($ME>2(*;7-G<W1R("+"X/@@[_/AZ^CW[?OI(.KK_O<Z
M(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"FUS9VED
M(")9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^
M(@IM<V=S='(@(L+@^"#@Y/#E\2#DZ_\@[O+BY?+@(#QI/BCMY2#NX?_GX/+E
MZ^7M*3PO:3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS
M9VED(")9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B
M"FUS9W-T<B`BPN#XZ"#O\^'KZ/?M^^4O\>7J\.7R[?OE(/'E\/+H].CJX/+[
M(%,O34E-12(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O
M=6YT7W-E;&5C="YI;F,Z,38*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S
M='(@(L+@^.@@[_#N].CKZ#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I
M;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB
M"FUS9W-T<B`B(@HBPN#XZ"#@Y/#E\>`M[_'EXN3N[>CL^R`\96T^*.WE(.[A
M_^?@\N7K_.W[+"#JX.;D^^D@\2#M[N+NZ2#Q\O#NZN@I/"]E;3XB"@HC.B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y
M(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`BPN#X(.'P[O/GY?`@[>4@
M[^[DY.7PYNCBX.7R(.[O]NC^(._E]^#RZ"X@Q.O_(._E]^#RZ"#MX.;LZ/+E
M($-44DPK4"XB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,SD*;7-G:60@(EEO=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE
M<W-A9V5S.B(*;7-G<W1R("+*[N3H\.[BZN`@[^X@\^SNZ_?@[>C^(.3K_R#H
M\?7NY/_YZ/4@\>[NX?GE[>CI.B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R
M>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO
M;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(LSE\N[D
M(/CH]/#NXN#MZ/\@Z/'U[N3_^>CU(/'N[N'YY>WHZ3HB"@HC.B!A='1A8VAM
M96YT+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&QI;FME
M9"!A='1A8VAM96YT(&AA<R!B965N(&1O=VYL;V%D960@8GD@870@;&5A<W0@
M;VYE('5S97(N7&XB"B)<;B(*(D%T=&%C:&UE;G0@;F%M93H@)7-<;B(*(D%T
M=&%C:&UE;G0@9&%T93H@)7-<;B(*(EQN(@HB0VQI8VL@;VX@=&AE(&9O;&QO
M=VEN9R!L:6YK('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&4@871T86-H;65N
M=#I<;B(*(B5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")9;W5R(&UE<W-A9V4@=V%S('-U
M8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(L_@[^K@(%PB)7-<(B#A
M^^O@(//Q[^7X[>X@\^3@Z^7MX"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS9W-T<B`BPN#XX"#O
M[N3OZ/'\.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V%D9')E<W-E<T)L
M;V-K<RYJ<SHW"B,L(&9U>GIY"FUS9VED(");2&ED92!!9&1R97-S97-=(@IM
M<V=S='(@(L3N[.#X[>CI(.#D\.7Q(@H*(SH@;65S<V%G92YP:'`Z,CDV(&-O
M;7!O<V4N<&AP.C$S,#$@;6%I;&)O>"YP:'`Z-3,V(&QI8B]#;VUP;W-E+G!H
M<#HX,S@*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");P>7G(/+E[/M=
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-"
M;&]C:W,N:G,Z.`HC+"!F=7IZ>0IM<V=I9"`B6U-H;W<@061D<F5S<V5S("TB
M"FUS9W-T<B`BP.3PY?$@[^[K\_?@\N7K_R(*"B,Z(&QI8B]-24U%+TAE861E
M<G,N<&AP.C(Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!A9&1R97-S
M97,@+2`E<R!R96-I<&EE;G1S72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*(RP@9G5Z>GD*;7-G:60@(E]"8V,B
M"FUS9W-T<B`B0F-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V
M"B,L(&9U>GIY"FUS9VED(")?0FQA8VML:7-T(@IM<V=S='(@(M?E\.W[Z2#Q
M[^CQ[NHB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C$U-`IM<V=I9"`B7T-C(@IM<V=S='(@(LKN[^CH(@H*(R!F=7IZ>0HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-B!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C$P"FUS9VED(")?1&5L971E(@IM<V=S='(@(M/D
MX.OH\OPB"@HC.B!L:6(O24U0+G!H<#HY-34*;7-G:60@(E]&;VQD97)S(@IM
M<V=S='(@(L_@[^KH(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHX,0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@(L_P[O3H
MZ_PB"@HC.B!L:6(O24U0+G!H<#HY,C0*;7-G:60@(E]);F)O>"(*;7-G<W1R
M("+"]>[D__GHY2(*"B,@9G5Z>GD*(SH@;&EB+TE-4"YP:'`Z.3DV"FUS9VED
M(")?3&]G(&]U="(*;7-G<W1R("+"^_7NY"(*"B,@9G5Z>GD*(SH@;65S<V%G
M92YP:'`Z,SDR"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T<B`BR/'U
M[N3MZ.H@(@H*(R!F=7IZ>0HC.B!L:6(O24U0+G!H<#HY-3(*;7-G:60@(E].
M97<@365S<V%G92(*;7-G<W1R("+-X._H\>#R_"(*"B,@9G5Z>GD*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")?
M4')I;G0B"FUS9W-T<B`BS^7WX/+\(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C<R('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(X.0HC+"!F=7IZ>0IM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(L_E]^#R
M_"(*"B,Z(&UA:6QB;W@N<&AP.C0P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B7U)E9G)E<V@@)7,B"FUS9W-T<B`BSN'M[N+H\OPB"@HC(&9U>GIY
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS
M9VED(")?4F5P;'DB"FUS9W-T<B`BSO+BY?+H\OPB"@HC(&9U>GIY"B,Z(&QI
M8B])35`N<&AP.CDU-PIM<V=I9"`B7U-E87)C:"(*;7-G<W1R("+/[NCQZB(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R.`HC+"!F=7IZ>0IM<V=I9"`B7U-E
M;F0@365S<V%G92(*;7-G<W1R("+.\N_PX.+H\OP@\>[NX?GE[>CE(@H*(R!F
M=7IZ>0HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C,R"FUS9VED(")?5&AR96%D(@IM<V=S='(@(N_N(/+E[.#L(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*;7-G:60@
M(E]4;R(*;7-G<W1R("+*[NSS(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B7U5N9&5L971E(@IM<V=S='(@
M(L+N\?'RX.WNXNCR_"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ.`IM<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S='(@(L_N
M(/+E[.#L(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED
M(")?5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M-S4*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@
M(L#D\.7Q[>#_(.KMZ./@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0U,0HC+"!F
M=7IZ>0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R("+/\.CJ\.7OZ__E[.[E
M(@H*(SH@=FEE=RYP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(F%T=&%C:&UE;G1S
M+GII<"(*;7-G<W1R("+/\.CJ\.7OZ^7M[?OE(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3`W"FUS9VED(")B>71E<R(*;7-G<W1R("+A
MX.GR(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y.0IM<V=I9"`B8V%N;F]T(&-R
M96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3<Q"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,38S"FUS9VED(")C;VUM86YD(&QI;F4@=7-A
M9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q.0IM
M<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,3DU"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M
M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C<*;7-G
M:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R("+.\NSE[>CR_"#HY^SE[>7MZ/\B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B9G)O;2(*;7-G<W1R("+N
M\B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-SD*;7-G:60@(FAO<W0@;F%M92!U
M;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#,*;7-G
M:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3@W"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,CD@<&=P+G!H<#HV.`IM<V=I9"`B
M:V5Y(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C$T-0HC+"!F=7IZ>0IM
M<V=I9"`B;6%I;&)O>"!F:6QE(@IM<V=S='(@(M_YZ.KH(@H*(SH@8V]M<&]S
M92YP:'`Z,3$P-2!L:6(O365S<V%G92YP:'`Z-3$U"B,L(&9U>GIY"FUS9VED
M(")N86UE(@IM<V=S='(@(LCL_R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*;7-G<W1R("+MY?(B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-0HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*
M;7-G<W1R("+HZ^@B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$U"B,L(&9U>GIY
M"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<
M;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR
M_"#O\.#BX"#D[O'R\^_@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O861D
M<F5S<V5S0FQO8VMS+FIS.C@*;7-G:60@(G)E8VEP:65N='-=(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,3$*;7-G:60@(G)E;6]T92!E<G)O
M<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,3@S"B,L(&9U>GIY"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S
M='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<B(*
M;7-G<W1R("+N\/3NX_#@].CWY?'JX/\@[OCHX>K@(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O
M<G,B"FUS9W-T<B`B[O#T[N/PX/3H]^7QZNCE(.[XZ.'JZ"(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.3$*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R("+N\/3NX_#@].CWY?'JX/\@[OCHX>K@(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C(P-PHC+"!F=7IZ>0IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B
M"FUS9W-T<B`BS^[H\>HB"@HC.B!L:6(O1FEL=&5R+G!H<#HW.0HC+"!F=7IZ
M>0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`BU^7P[?OI(/'OZ/'N
MZB(*"B,Z(&QI8B]&:6QT97(N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")Y;W5R
M('=H:71E;&ES="(*;7-G<W1R("+0Y>3@ZO+H\.[BX.WHY2#"X/CH]2#O\.#B
MZ.L@].CK_/+PX/;HZ"(*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+W!O+V=L7T53+G!O````````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#,V-#0W,P`Q,#0Q-S,V,C<V-``P,3<R,#``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R!)35`@
M,RXR+C(@1V%L:6-I86X@=')A;G-L871I;VXN"B,*(R!697)S:6]N(&EN:6-I
M86P@9&4Z"B,*(R!2869A96P@5F%R96QA(#QR869A96PN=F%R96QA0'5S8RYE
M<SX*(R!'=6EL;&5R;6\@365N9&5Z(#QG=6EL;&5`=7-C+F5S/@HC(%-E<G9I
M8VEO(&1E(&%T96YC:6]N(&$@=7-U87)I;W,@92!S:7-T96UA<PHC(%5N:79E
M<G-I9&%D92!D92!386YT:6%G;R!D92!#;VUP;W-T96QA"B,*(R!2979I<V%D
M82!Y(&-O<G)E9VED82!P;W(Z"B,@"B,@4V5R=FEC:6\@9&4@;F]R;6%L:7IA
M8VEO;B!L:6YG=6ES=&EC82`\<VYL=7-C0'5S8RYE<SX*(R!5;FEV97)S:61A
M9&4@9&4@4V%N=&EA9V\@9&4@0V]M<&]S=&5L80HC"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($E-4"`S+C%<;B(*(E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`S+3$Q+3`S(#$S.C,S1TU4*S%<;B(*(DQA<W0M
M5')A;G-L871O<CH@9W5I;&QE(#QG=6EL;&5`=7-C+F5S/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@1V%L96=O7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*
M(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E@M1V5N97)A
M=&]R.B!+0F%B96P@,"XY+C5<;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3@*
M(RP@9G5Z>GD*;7-G:60@(B`@("`@($-C.B`B"FUS9W-T<B`B("`@(%!A<F$Z
M("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,34*;7-G:60@(B`@("`@(%1O.B`B
M"FUS9W-T<B`B("`@(%!A<F$Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#,*
M;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@1&%T83H@(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C0P-@IM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R("(@
M("`@("!$93H@(@H*(SH@;6%I;&)O>"YP:'`Z-#(R('1E;7!L871E<R]F;VQD
M97)S+VAE860N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K
M97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3(*;7-G
M:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B($%S=6YT;SH@(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<P"FUS9VED("(@:6X@(@IM<V=S
M='(@(B!E;B`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@(B,B"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@
M)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$U
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@365S<V%G97,B"FUS
M9W-T<B`B)60@9&4@)60@;65N<V%X97,B"@HC.B!M86EL8F]X+G!H<#HQ-S8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")6:7-U86QI>F%R(&$@;65N<V%X92!C
M86YD;R!S92!A<&QI<75E;B!O<R!F:6QT<F]S+B(*"B,Z(&QI8B]3<&%M+G!H
M<#HQ-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A
M9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")%<W1A(&UE;G-A>&4@9F]I
M(&1E;G5N8VEA9&$@8V]M;R!S<&%M(/,@861M:6YI<W1R861O<B!D;R!S:7-T
M96UA+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2XB"FUS9W-T<B`B17-T82!M96YS87AE(&9O:2!D96YU;F-I861A
M(&-O;6\@<W!A;2#S(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M82XB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")%<W1A(&UE;G-A>&4@
M9F]I(&1E;G5N8VEA9&$@8V]M;R!S<&%M(/,@861M:6YI<W1R861O<B!D;R!S
M:7-T96UA+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M+B(*;7-G<W1R(")%<W1A(&UE;G-A>&4@9F]I(&1E;G5N8VEA9&$@
M8V]M;R!S<&%M(/,@861M:6YI<W1R861O<B!D;R!S:7-T96UA+B(*"B,Z(&UA
M:6QB;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!T;R`E9"!O
M9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"!O("5D(&1E("5D(&UE;G-A>&5S
M(@H*(SH@;6%I;&)O>"YP:'`Z-C0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($M"(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M
M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R
M96YA;65D+B(*;7-G<W1R("(E<R!X82!E>&ES=&4N($YO;B!L;&4@8V%M8FEO
M=2!O(&YO;64@;R!C87)T869O;"`E<RXB"@HC.B!L:6(O365S<V%G92YP:'`Z
M-C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A
M="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G<W1R(")/(&YO;64@9&\@
M8V%R=&%F;VP@)7,@=F%I(&UU9&%R(&$@8V]M97IO<R!D92!M97,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@
M9&5C;&EN960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@
M=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8Q-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L
M>2!A8V-E<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y
M;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB
M"FUS9W-T<B`B3R!C87)T869O;"!<(B5S7"(@8V%M8FGS=7-E;&QE(&\@;F]M
M92!C;W)R96-T86UE;G1E(&$@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S
M('1O(&%M;65N9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@
M=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A
M8F]U="`E<RXB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C@U(&UE<W-A
M9V4N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7W1O<"YI;F,Z,3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[
M)60I(@IM<V=S='(@(B5S.B`E<R`H)60F;F)S<#MD929N8G-P.R5D*2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(BA!
M<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BDB
M"FUS9W-T<B`B*$%P;&EC82!O<R!C86UB:6]S(&4@<&%S82#A('-E9W5I;G1E
M('!A;G1A;&QA+BDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3(P"FUS9VED("(H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N
M('1O('1H92!C;VUP;W-E('-C<F5E;BXI(@IM<V=S='(@(BA$97-F86-E<B!T
M\V1O;&]S(&-A;6)I;W,@92!R96=R97-A<B#A('!A;G1A;&QA(&1E(')E9&%C
M8VGS;BXI(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V
M"FUS9VED("(H2%1-3"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I
M;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB"FUS9W-T
M<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E='5R;B!T
M;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG
M97,@;6%D92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U<G)E;G0@
M<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H4F5G
M<F5S87(@X2!P86YT86QL82!D92!R961A8V-I\VX@9&5S<&]I<R!D92!A<&QI
M8V%R('3S9&]L;W,@8V%M8FEO<R!F96ET;W,@(@HB871A(&%G;W)A+B!/<R!C
M86UB:6]S(&YA('!A;G1A;&QA(&%C='5A;"!.3TX@<V4@87!L:6-A<N%N+BDB
M"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"B,L(&9U>GIY"FUS9VED("(B"B(H4V5N
M9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU
M<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W:6QL
M($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*%)E9W)E<V%R(.$@<&%N
M=&%L;&$@9&4@<F5D86-C:?-N(&1E<W!O:7,@9&4@87!L:6-A<B!T\V1O;&]S
M(&-A;6)I;W,@9F5I=&]S("(*(F%T82!A9V]R82X@3W,@8V%M8FEO<R!N82!P
M86YT86QL82!A8W1U86P@3D].('-E(&%P;&EC87+A;BXI(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@(BH@061D('1H
M97-E(&)Y(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B!%;F=A9&ER(&5S=&5S
M('!R96UE;F1O(&5N($]+("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H
M97,I("HB"FUS9W-T<B`B*B!396QE8V-I;VYE(&\H<RD@96YD97)E>F\H<RD@
M*B(*"B,Z(&UA:6QB;W@N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S
M86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D5L:6UI;F]U<V4@82!I
M9&5N=&ED861E(%PB)7-<(B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*(RP@9G5Z
M>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@
M<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")%
M<W1A(&UE;G-A>&4@9F]I(&1E;G5N8VEA9&$@8V]M;R!S<&%M(/,@861M:6YI
M<W1R861O<B!D;R!S:7-T96UA+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C`*(RP@
M9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2XB"FUS9W-T<B`B17-T82!M96YS87AE(&9O:2!D96YU;F-I861A
M(&-O;6\@<W!A;2#S(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M82XB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3<R"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S
M(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R(")%<W1A(&UE;G-A>&4@9F]I(&1E;G5N8VEA9&$@
M8V]M;R!S<&%M(/,@861M:6YI<W1R861O<B!D;R!S:7-T96UA+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R(")%<W1A(&UE;G-A>&4@
M9F]I(&1E;G5N8VEA9&$@8V]M;R!S<&%M(/,@861M:6YI<W1R861O<B!D;R!S
M:7-T96UA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*(RP@9G5Z
M>GD*;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(D-A<F%C=&5R97,@
M97-P96-I86ES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,@HC+"!F
M=7IZ>0IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S='(@(D-A<F%C=&5R
M97,@97-P96-I86ES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,`HC
M+"!F=7IZ>0IM<V=I9"`B,C4P(&-H87)A8W1E<G,B"FUS9W-T<B`B0V%R86-T
M97)E<R!E<W!E8VEA:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(Q
M"B,L(&9U>GIY"FUS9VED("(U,#`@8VAA<F%C=&5R<R(*;7-G<W1R(")#87)A
M8W1E<F5S(&5S<&5C:6%I<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA
M;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G
M:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I
M;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z
M-0IM<V=I9"`B04Y$(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU.3`*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@(D%C8V5P
M="!R97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U,PIM<V=I9"`B06-C
M97!T960B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C(U-PIM<V=I9"`B06-C97!T960Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B06-C
M;W5N="=S(&YA;64Z(@IM<V=S='(@(EAE<W1O<B!D82!C;VYT82(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C`@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<S,`HC+"!F=7IZ>0IM<V=I9"`B06-T:6]N<R(*;7-G<W1R(")!
M8V-I\VXB"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)344O
M2&5A9&5R<RYP:'`Z,C`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@)7,@=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@(D5N9V%D:7(@X2!A
M>&5N9&$@9&4@96YD97)E>F]S("@E<RDB"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS,#,*(RP@9G5Z>GD*;7-G:60@(D%D9"!S;W5R
M8V4B"FUS9W-T<B`B96YG861I<B!U;FAA(&9O;G1E(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4W-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3@X"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HQ,C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T86-H;65N="XB"FUS9W-T<B`B
M16YG861I=7-E('5N(&%R<75I=F\@86YE>&\N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O
M(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E
M86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@
M:6YF;W)M871I;VX@9&5T86EL<R(*;7-G<W1R("));F9O<FUA8VGS;B!P97)S
M;V%L(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3,*;7-G:60@
M(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(&-A;B!B92!V:65W960@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<X"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@
M9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!C;VYT
M86-T<RYP:'`Z.#4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M.#`*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L
M871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,@IM<V=I9"`B061D<F5S<R!"
M;V]K(@IM<V=S='(@(D%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O
M;VMS(@IM<V=S='(@(D%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3@Y"FUS9VED("(B"B)!9&1R97-S97,@=&\@0D-#
M(&%L;"!M97-S86=E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R
M97-S(&]N(&$@;F5W("(*(FQI;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$X,0IM<V=I9"`B(@HB061D<F5S<V5S('1O
M(&5X<&QI8VET;'D@=&EE('1O('1H:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N
M86PL(&5N=&5R(&5A8V@@(@HB861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,PIM<V=I9"`B06QL(@IM<V=S
M='(@(E1O9&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ,PIM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@
M9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8("(*
M(F9I;&4Z(@IM<V=S='(@(B(*(E3S9&%L87,@;65N<V%X97,@9&\H<RD@<V5G
M=6EN=&4H<RD@8V%R=&%F;VPH97,I(&1E<V-A<F=A<F%N<V4@;G5N(&%R<75I
M=F\@9&4@(@HB=&EP;R!-0D]8.B`B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S
M:R]P=7)G95]T<F%S:"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M06QL(&UE<W-A9V5S(&EN('EO=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N
M("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G
M<W1R("(B"B)686YS92!B;W)R87(@9&4@=F5Z(&%S(&UE;G-A>&5S(&1O(&-A
M<G1A9F]L(%PB)7-<(B!C;VX@;>%I<R!D92`E<R!D[6%S('-E<N%N("(*(F5L
M:6UI;F%D87,@<&5R;6%N96YT96UE;G1E+B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK960@871T86-H
M;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D
M+B(*;7-G<W1R("(B"B)686YS92!E;&EM:6YA<B!O<R!C87)T869O;&5S(&1E
M(&UE;G-A>&5S(&5N=FEA9&%S(&AA:2!MX6ES(&1E("`E<R!M97-E<R`N(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H
M;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D
M96QE=&5D+B(*;7-G<W1R("(B"B)686YS92!E;&EM:6YA<B!O<R!C87)T869O
M;&5S(&1E(&UE;G-A>&5S(&5N=FEA9&%S(&AA:2!MX6ES(&1E("`E<R!M97-E
M<R`N(@H*(SH@86-L+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B06QL(')I9VAT<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R
M96UO=F5D(&9O<B!U<V5R(%PB)7-<(BXB"FUS9W-T<B`B3R!C87)T869O;"!<
M(B5S7"(@8V%M8FGS=7-E;&QE(&\@;F]M92!C;W)R96-T86UE;G1E(&$@7"(E
M<UPB+B(*"B,Z(&QI8B]A<&DN<&AP.C<V"FUS9VED(")!;&QO=R!&;VQD97(@
M0W)E871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P
M<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$P"FUS9VED(")!;'1E<FYA=&EV
M92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3<R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.#0*;7-G:60@(D%L=V%Y<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-34W"B,L(&9U>GIY"FUS9VED(")!;'=A>7,@<V%V92!A='1A
M8VAM96YT<R(*;7-G<W1R(")%;F=A9&EU<V4@=6X@87)Q=6EV;R!A;F5X;RXB
M"@HC.B!L:6(O365S<V%G92YP:'`Z-3`U"FUS9VED("(B"B)!;B!E<G)O<B!O
M8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE
M;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T92XB
M"FUS9W-T<B`B4')O9'5C:75S92!U;B!P<F]B;&5M82!D97-C;_%E8VED;R#S
M(&5N9V%D:7(@;R!N;W9O(')E>&ES=')O+B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HS.#<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E
M9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(E!R;V1U
M8VEU<V4@=6X@<')O8FQE;6$@9&5S8V_Q96-I9&\@\R!E;F=A9&ER(&\@;F]V
M;R!R97AI<W1R;RXB"@HC.B!M97-S86=E+G!H<#HU,#`@;6%I;&)O>"YP:'`Z
M-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z.0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R(")297-P;VYD:61A
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B06YS
M=V5R960@;65S<V%G97,B"FUS9W-T<B`B365N<V%X97,@<F5S<&]N9&ED87,B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@9G5Z>GD*
M;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B07!L:6-A<B!O<R!F:6QT
M<F]S(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<'!L>2!&:6QT97)S('1O("5S(@IM
M<V=S='(@(D%P;&EC87(@;W,@9FEL=')O<R(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL=&5R
M(')U;&5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`B07!L:6-A<B!A<R!R
M96=R87,@9&4@9FEL=')A>&4@\R!I;FEC:6\@9&$@<V5S:?-N+B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B
M07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE
M9#\B"FUS9W-T<B`B07!L:6-A<B!A<R!R96=R87,@9&4@9FEL=')A>&4@\R!D
M97-C87)G87(@;R!C;W)R96\N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@9G5Z>GD*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L
M:6,@:V5Y/R(*;7-G<W1R("*_17-TX2!S96=U<F\@9&4@<75E(&1E<V5X82!F
M86-E<B!I<W1O/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@
M3D]4(')E8V]M;65N9&5D(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YJ<SHV"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI
M<S\B"FUS9W-T<B`BOT5S=.$@<V5G=7)O(&1E('%U92!D97-E>&$@9F%C97(@
M:7-T;S\B"@HC.B!M97-S86=E+G!H<#HT,#<@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S
M='(@(K]%<W3A('-E9W5R;R!D92!Q=64@9&5S97AA(&5L:6UI;F%R($1%(%9%
M6B!E<W1A<R!M96YS87AE<S\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z
M,C$U"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B
MOT5S=.$@<V5G=7)O(&1E('%U92!D97-E>&$@96QI;6EN87(@1$4@5D5:(&5S
M=&%S(&UE;G-A>&5S/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C,Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@
M=&AI<R!F;VQD97(_(@IM<V=S='(@(K]%<W3A('-E9W5R;R!Q=64@9&5S97AA
M(&)A;&5I<F%R(&5S=&4@8V%R=&%F;VP_(@H*(SH@;&EB+TE-4"YP:'`Z.3<S
M"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP
M='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`BOT5S=.$@<V5G=7)O('%U
M92!D97-E>&$@8F%L96ER87(@97-T92!C87)T869O;#\B"@HC.B!L:6(O24U0
M+G!H<#HY-C8*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`BOT5S=.$@
M<V5G=7)O('%U92!D97-E>&$@8F%L96ER87(@97-T92!C87)T869O;#\B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L
M971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("*_17-TX2!S96=U<F\@9&4@
M<75E(&1E<V5X82!E;&EM:6YA<B!$12!615H@97-T87,@;65N<V%X97,_(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*(RP@9G5Z>GD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E
M(&%S(&EN;F]C96YT/R(*;7-G<W1R("*_17-TX2!S96=U<F\@<75E(&1E<V5X
M82!B86QE:7)A<B!E<W1E(&-A<G1A9F]L/R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C<T"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*;7-G<W1R
M("*_17-TX2!S96=U<F\@<75E(&1E<V5X82!B86QE:7)A<B!E<W1E(&-A<G1A
M9F]L/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,38*;7-G:60@(D%R
M<FEV86P@5&EM92(*;7-G<W1R(")0;W(@:&]R82!D92!C:&5G861A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,0IM<V=I9"`B07-C96YD:6YG(@IM
M<V=S='(@(D%S8V5N9&5N=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3<Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#,*;7-G:60@(D%S:R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3D*
M;7-G:60@(D%T=&%C:"(*;7-G<W1R(")!8V]M<&'Q87(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S4*(RP@9G5Z>GD*;7-G:60@(D%T
M=&%C:"!&:6QE<R(*;7-G<W1R(")!;F5X;W,B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT-38*;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@
M>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#D*(RP@9G5Z>GD*
M;7-G:60@(D%T=&%C:&5D($9I;&4Z(@IM<V=S='(@(D%C;VUP8?%A<B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT-3$@;&EB+T-O;7!O<V4N<&AP.C4S-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E
M961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A
M8VAE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C,W-@IM<V=I9"`B071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R
M(')E<75E<W0@>6]U('-E;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC.C$T"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4P-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY-PIM<V=I
M9"`B071T86-H;65N="(*;7-G<W1R(")!8V]M<&'Q87(@=6X@87)Q=6EV;R(*
M"B,Z(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP.C0V-@IM<V=I
M9"`B071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N="!T
M>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S,*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$P-S,*;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S
M='(@(D%N97AO<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#(*
M(RP@9G5Z>GD*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")!;F5X;W,B"@HC
M.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PHC+"!F=7IZ
M>0IM<V=I9"`B071T96YT:6]N(@IM<V=S='(@(D%C8VGS;B(*"B,Z(&QI8B]!
M=71H+VEM<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-#`*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO
M=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@
M:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B
M079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(D%X96YD87,@9&4@
M96YD97)E>F]S(&1I<W!O\6EB;&5S.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,C8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A8U]K('1O("5S(@IM
M<V=S='(@(E)E9W)E<V%R(&$@)7,B"@HC.B!T:')E860N<&AP.C$S-R!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B4F5G<F5S87(@82`E
M<R(*"B,Z('1H<F5A9"YP:'`Z,3,T"FUS9VED(")"86-K('1O($UU;'1I<&QE
M($UE<W-A9V4@5FEE=R!);F1E>"(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP
M.C$S,@IM<V=I9"`B0F%C:R!T;R!4:')E860@1&ES<&QA>2(*;7-G<W1R("(B
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,X-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")"860@;W(@;6%L9F]R;65D(')E<75E<W0N(%-E<G9E<B!297-P;VYD
M960Z("5S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,@HC.B!T96UP;&%T97,O8V]M
M<&]S92]R96-O;7!O<V4N:6YC.C(P(&QI8B]396%R8V@N<&AP.C,T"FUS9VED
M(")"8V,B"FUS9W-T<B`B0T-/(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z,38Q"FUS9VED(")"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE
M('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(D)L86-K;&ES="(*
M;7-G<W1R("),:7-T82!N96=R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,CD*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N
M;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/R(*;7-G<W1R
M("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HT,@IM<V=I9"`B0F]D>2(*;7-G<W1R
M(")497AT;R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,C,@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS.0HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C4U('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-S$*;7-G
M:60@(D)O=&@B"FUS9W-T<B`B06UB;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C@W"FUS9VED(")";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y
M(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C<R"FUS9VED(")#7VAA<G-E="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(D-A;&5N
M9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C`Q
M"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M.3D*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@
M<V5R=F5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I
M86PN<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES
M<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S
M86=E(&EN('1H92!C=7)R96YT("(*(FUA:6QB;W@N(@IM<V=S='(@(B(*"B,Z
M(&9O;&1E<G,N<&AP.C(X-"!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C(U-0HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(Q('1E
M;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.0HC.B!T96UP;&%T
M97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C$@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C@V"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHQ,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,@HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8V"FUS9VED(")#86YC96PB
M"FUS9W-T<B`B0V%N8V5L87(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHW,2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S4*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,0IM<V=I9"`B
M0V%N8V5L($UE<W-A9V4B"FUS9W-T<B`B0V%N8V5L87(@82!M96YS87AE(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")#86YC96QL:6YG('1H:7,@
M;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S
M+B(*;7-G<W1R(")392!C86YC96QA(&5S=&$@;65N<V%X92!P97)D97+A(&\@
M8V]N=&ED;RXB"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C
M;VUP;W-E+FEN8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM<V=I9"`B0V,B"FUS
M9W-T<B`B0V,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDS"FUS
M9VED("(B"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@
M1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R`B"B)S97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#$*
M(RP@9G5Z>GD*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R(")097)S;V%L
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED
M(")#:&%N9V4B"FUS9W-T<B`B0V%M8FEA<B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R
M(")#86UB:6%L87,@=&]D87,B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M.3(*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!&;VQD97(B"FUS9W-T<B`B0W)E
M87(@=6X@8V%R=&%F;VPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R
M"FUS9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W
M(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO
M=R!M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R("(B"B)#86UB:6%R(&]P
M8VGS;G,@9&4@=FES=6%L:7IA8VGS;B!T86QE<R!C;VUO(&/A;G1A<R!M96YS
M87AE<R!V97+A('!O<B!PX7AI;F$@(@HB92!C;VUO('-E(&]R9&5N86XN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY"FUS9VED(")#
M:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS9W-T
M<B`B0V%M8FEA<B!A<R!O<&-I\VYS(&1O('-E<G9I9&]R(&1E(&-O<G)E;RXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@(B(*(D-H86YG
M92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD("(*(G)E<&QY('1O('EO=7(@96UA
M:6PN(@IM<V=S='(@(B(*(D-A;6)I87(@;R!N;VUE+"!O(&5N9&5R97IO(&5L
M96-T<O-N:6-O(&4@82!S:6YA='5R82!Q=64@<V4@=F4@8V%N9&\@;&5N(&4@
M(@HB<F5S<&]N9&5N(.%S('/Z87,@;65N<V%X97,N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R-`IM<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P;&%Y
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ-0IM<V=I9"`B0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G
M<W1R(")"=7-C87(@8V]R<F5O(&YO=F\@8FES(&-A<G1A9F]L97,B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO
M3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC
M.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O
M(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0V,PHC+"!F=7IZ>0IM<V=I9"`B0VAE8VL@<W!E;&QI;F<@
M8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R(")(;W5B;R!U;B!E
M<G)O(/,@96YV:6%R(&$@<_IA(&UE;G-A>&4Z("5S(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I9"`B0VAO;W-E($%C=&EO;CHB
M"FUS9W-T<B`B16QI>&ER('5N:&$@86-C:?-N.B(*"B,Z(&-O;F9I9R]S97)V
M97)S+G!H<"YD:7-T.C$X,@HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@;6%I
M;"!S97)V97(Z(@IM<V=S='(@(D-A;6)I87(@87,@;W!C:?-N<R!D;R!S97)V
M:61O<B!D92!C;W)R96\N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$V-@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,3<*;7-G:60@(D-H
M;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT
M.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(Q
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*(RP@9G5Z>GD*;7-G:60@
M(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(D5L:7AI<B!U;FAA(&%C8VGS
M;CHB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*
M(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S
M92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(D5L:7AA('5N:&$@
M87AE;F1A('!A<F$@96YG861I<B!E;F1E<F5Z;W,N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"B,L(&9U>GIY"FUS9VED(")#
M:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H
M96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB16QI>&$@82!O
M<F1E(&1E(&)U<V-A(&YA<R!A>&5N9&%S(&1E(&5N9&5R97IO<R!C86YD;R!E
M>'!A;F1A(&5N9&5R97IO<RXB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N
M=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E
M<B!C86X@=FEE=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@
M9&]W;FQO860@=&AE(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R
M+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@
M=&\@)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3$V"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN
M9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A
M('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A
M('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B4F5D86-T87(@;65N<V%X97,@
M;G5N:&$@>&%N96QA(.$@<&%R=&4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E
M;&%T960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A
M=&4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M
M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,R,0HC+"!F=7IZ>0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO
M=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL
M(&9I96QD<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(E!R96UA(&YU;FAA
M(&1A<R!A>&5N9&%S(&1E(&5N9&5R97IO<R!S96QE8V-I;VYA9&%S(&4@;&]G
M;R!S96QE8V-I;VYE(&]S("(*(F-A;7!O<R!P;VQO<R!Q=64@9&5S97AA(&)U
M<V-A<BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S$*;7-G:60@
M(D-L:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S
M(&)O;VLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@=&\@4V%V92!3+TU)
M344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,`IM<V=I9"`B
M0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE
M<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S
M<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C@*(RP@
M9G5Z>GD*;7-G:60@(D-L;W-E(@IM<V=S='(@(DYO=F$B"@HC.B!C;VUP;W-E
M+G!H<#HX,C@@8V]M<&]S92YP:'`Z,3$T.`IM<V=I9"`B0VQO<V4@=&AI<R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#(Y"FUS9VED(")#
M;&]S960@1F]L9&5R(@IM<V=S='(@(D-A<G1A9F]L('!E8VAA9&\B"@HC.B!F
M;VQD97)S+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E(@IM<V=S
M='(@(D-O;7!R:6UI;&]S('1O9&]S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R(")#
M;VUP<FEM:6QO<R!T;V1O<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C,Y"FUS9VED(")#;VQL87!S92!!;&P@1F]L9&5R<R(*;7-G<W1R
M(")#;VUP<FEM:7(@=/-D;VQO<R!C87)T869O;&5S(@H*(SH@9F]L9&5R<RYP
M:'`Z-#0Y"FUS9VED(")#;VQL87!S92!&;VQD97(B"FUS9W-T<B`B0V]M<')I
M;6ER(&\@8V%R=&%F;VPB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC871O<CH@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*;7-G:60@(D-O;6UE;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V.0HC
M+"!F=7IZ>0IM<V=I9"`B0V]M<&QE=&5D(@IM<V=S='(@(DYO=F$B"@HC.B!C
M;VUP;W-E+G!H<#HX,C<@8V]M<&]S92YP:'`Z,3$T-PHC+"!F=7IZ>0IM<V=I
M9"`B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B"FUS9W-T<B`B4F5D86-T87(@
M=6YH82!N;W9A(&UE;G-A>&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#,T"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN
M9&]W/R(*;7-G<W1R(")2961A8W1A<B!M96YS87AE<R!N=6YH82!X86YE;&$@
MX2!P87)T92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0S"FUS9VED
M("(B"B)#;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F
M875L="`H:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-PIM<V=I9"`B
M0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*(RP@9G5Z>GD*;7-G
M:60@(D-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB"FUS9W-T<B`B
M0V%M8FEA<B!A<R!O<&-I\VYS(&1O('-E<G9I9&]R(&1E(&-O<G)E;RXB"@HC
M.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM<V=I9"`B0V]N;F5C=&EO;B!D
M<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V
M97(@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R
M="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3+TU)344@<W5P
M<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M
M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL
M('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N
M;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB0V]N
M=')O;&$@82!C;VUP<F]B86-I\VX@9&\@8V]R<F5O(&YO=F\@92!A('/Z82!N
M;W1I9FEC86-I\VX@<&]L;R!S:7-T96UA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV.38*;7-G:60@(D-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@
M:6YT;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EA
M<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0HC+"!F=7IZ>0IM
M<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T<B`B0F%L96ER87(@82!P87!E
M;&5I<F$@9&\@;&EX;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G<W1R(")#;W)R:7AI<B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#`*;7-G:60@(D-O
M<G)E8W1E9"!497AT(@IM<V=S='(@(E1E>'1O(&-O<G)I>&ED;R(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z,S@R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S="X@4F5A<V]N($=I=F5N
M.B`E<R(*;7-G<W1R(").;VX@<'5I9&\@96QI;6EN87(@87,@;65N<V%X97,@
M9&4@)7,Z("5S(@H*(SH@871T86-H;65N="YP:'`Z-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-#`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@
M9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R(").;VX@<'5I
M9&\@96QI;6EN87(@87,@;65N<V%X97,@9&4@)7,Z("5S(@H*(SH@;&EB+U-E
M<W-I;VXN<&AP.C,Q.`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&5X96-U
M=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`B3W!E<F%C:?-N
M<R!D92!M86YT96UE;G1O(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HU.`IM<V=I9"`B0V]U;&0@;F]T
M(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H
M:79E+B(*;7-G<W1R("(B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<S"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R
M;VT@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z,S$T
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,`IM
M<V=I9"`B0W)E871E(@IM<V=S='(@(D-R96%R(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E<B(*;7-G
M<W1R(")#<F5A<B!U;B!C87)T869O;"(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,S<*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@
M(D-R96%R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$T"B,L
M(&9U>GIY"FUS9VED(")#<F5A=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B
M0W)E87(@=6X@8V%R=&%F;VPB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C
M8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W($%C8V]U
M;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N
M:6YC.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@
M(D-R96%R('5N(&YO=F\@8V%R=&%F;VP@<&%R82!O(&QI>&\B"@HC.B!T96UP
M;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E
M9G,O9F]L9&5R<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W(&1R
M869T<R!F;VQD97(B"FUS9W-T<B`B0W)E87(@=6X@;F]V;R!C87)T869O;"(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M
M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E
M871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B0W)E87(@=6X@
M;F]V;R!C87)T869O;"!D;R!C;W)R96\@96YV:6%D;R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R
M87-H<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O
M;&1E<B(*;7-G<W1R(")#<F5A<B!U;B!N;W9O(&-A<G1A9F]L('!A<F$@;R!L
M:7AO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R.`IM<V=I9"`B(@HB
M0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M
M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"`B"B)A;F0@9&5L971E
M('-P86TN(@IM<V=S='(@(B(*(D-R96%R(')E9W)A<R!D92!F:6QT<F%X92!P
M87)A(&]R9V%N:7IA<B!O(&-O<G)E;R!Q=64@96YT<F$L(&-L87-I9FEC86QO
M(&5N("(*(F-A<G1A9F]L97,@92!E;&EM:6YA<B!O(&-O<G)E;R!N;VX@9&5S
M97AA9&\N(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T
M"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T
M<B`B0W)E87(@=6X@;F]V;R!C87)T869O;"!D;R!C;W)R96\@96YV:6%D;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*;7-G:60@(D-R96%T92!S
M=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#4*;7-G:60@(D-U<W1O;6EZ92!A8V-O=6YT<R!F
M;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*(RP@9G5Z>GD*;7-G
M:60@(D-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"XB"FUS9W-T<B`B(@HB
M4&5R<V]N86QI>F%R(&\@96YV[6\@9&4@8V]R<F5O(&4@;R!L=6=A<B!O;F1E
M('-E('9A;B!G87)D87(@;W,@8F]R<F%D;W)E<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")097)S
M;VYA;&EZ87(@87,@=&%R969A<R!Q=64@<V4@97AE8W5T96X@\R!I;FEC:6%R
M(&$@<V5S:?-N(&5N("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(D1A=%]E(@IM<V=S
M='(@(D1A=&$B"@HC.B!M97-S86=E+G!H<#HR-C(@=&AR96%D+G!H<#HQ-#@*
M;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW-3<*(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D(@IM<V=S
M='(@(D5L:6UI;F%D82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G
M<W1R(")%;&EM:6YA<B(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A
M<F-H<V5L96-T+FEN8SHQ.`IM<V=I9"`B1&5F875L="!396%R8V@@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,PIM<V=I
M9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")#<FET97)I
M;R!D92!C;&%S:69I8V%C:?-N('!R961E=&5R;6EN861O.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,S,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D
M:7)E8W1I;VXZ(@IM<V=S='(@(D]R9&4@9&4@8VQA<VEF:6-A8VGS;B!P<F5D
M971E<FUI;F%D;SHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U
M"B,L(&9U>GIY"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`B16QI;6EN861A
M(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHV.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(T-"!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(X
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM<V=I9"`B1&5L971E(@IM
M<V=S='(@(D5L:6UI;F%R(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME>7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B1&5L
M971E($9O;&1E<BAS*2(*;7-G<W1R(")%;&EM:6YA<B!C87)T869O;"AE<RDB
M"@HC.B!F;VQD97)S+G!H<#HR.#4*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!3
M96QE8W1E9"!&;VQD97)S(@IM<V=S='(@(D5L:6UI;F%R(&-A<G1A9F]L*&5S
M*2(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,@HC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E(%-T871I;VYE<GDB"FUS9W-T<B`B16QI;6EN
M87(@8V%R=&%F;VPH97,I(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B16QI;6EN
M87(@8V%R=&%F;VPH97,I(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M
M(')E;6]T92!S97)V97(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T
M(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B16QI;6EN87(@;W,@8V%R
M=&%F;VQE<R!D92!M96YS87AE<R!E;G9I861A<R!A('!R:6YC:7!I;W,@9&\@
M;65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B1&5L
M971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N
M=&@_(@IM<V=S='(@(D5L:6UI;F%R(&]S(&-A<G1A9F]L97,@9&4@;65N<V%X
M97,@96YV:6%D87,@82!P<FEN8VEP:6]S(&1O(&UE<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M
M(&UE<W-A9V5S(@IM<V=S='(@(D5L:6UI;F%R(&%S(&UE;G-A>&5S(@H*(SH@
M;65S<V%G92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<T,"!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C(P"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHX"FUS9VED
M(")$96QE=&5D(@IM<V=S='(@(D5L:6UI;F%D82(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS
M9W-T<B`B365N<V%X97,@96QI;6EN861A<R(*"B,Z(&-O;7!O<V4N<&AP.C,P
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@871T
M86-H;65N="!<(B5S7"(N(@IM<V=S='(@(D5L:6UI;F]U('5N(&%R<75I=F\N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN
M9R!A;F0@36]V:6YG($UE<W-A9V5S(@IM<V=S='(@(D5L:6UI;F%N9&\@92!M
M;W9E;F1O(&UE;G-A>&5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU-#`*;7-G:60@(D1E;GD@<F5Q=65S="!F
M;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,S(*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T
M<B`B1&5S8V5N9&5N=&4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V.0HC+"!F
M=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B3W!C:?-N<R!D;R!U
M<W5A<FEO(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<W"FUS9VED(")$971A:6QS(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-S<*;7-G:60@(D1I;2!S:6=N871U<F5S
M/R(*;7-G<W1R("*_071E;G5A<B!A('-I;F%T=7)A/R(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$:7-P;&%Y(@IM
M<V=S='(@(E9I<W5A;&EZ87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#<Y"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A9G1E
M<B!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B(@HBOT%M;W-A<B!C;VYF
M:7)M86-I\VX@9&5S<&]I<R!D92!E;G9I87(@=6YH82!M96YS87AE/R`H<_,@
M8V%N9&\@;F]N('-E('5S92`B"B)U;FAA('AA;F5L82!D92!C;VUP;W-I8VGS
M;B!P;W`M=7`I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-@IM<V=I
M9"`B1&ES<&QA>2!I;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y,@IM<V=I9"`B1&ES<&QA>2!P;W`M
M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL/R(*;7-G<W1R(")-;W-T<F%R
M(&$@>&%N96QA(&1E(&YO=&EF:6-A8VGS;B!D92!C;W)R96\@;F]V;RXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4X"FUS9VED(")$:7-P;&%Y('1H
M92!<(D5M<'1Y(%-P86U<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4P"FUS9VED(")$:7-P
M;&%Y('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N
M:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R(")/
M<&-I\VYS(&1E('9I<W5A;&EZ86-I\VXB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C:"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B
M1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B
M3F]N(&5X86UI;F%R(&-A<G1A9F]L97,@<&%R82!B=7-C87(@;R!C;W)R96\@
M;F]V;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3(*;7-G:60@(D1O
M(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;B(*;7-G
M<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#<U"FUS9VED(")$;R!Y;W4@=V%N
M="!T;R!O<&5N('1H870@9F]L9&5R/R(*;7-G<W1R("*_1&5S97AA(&%B<FER
M(&5S92!C87)T869O;#\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(S,@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,3(V"FUS9VED(")$;VYE(@IM<V=S='(@(D9E:71O(@H*(SH@;&EB+TU)344O
M0V]N=&5N=',N<&AP.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R!I;B`N>FEP($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHU,@IM<V=I9"`B1&]W;FQO860@06QL($%T
M=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS9VED(")$;W=N;&]A9"!&
M;VQD97(H<RDB"FUS9W-T<B`B1&5S8V%R9V%R(&-A<G1A9F]L*&5S*2(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(Q"B,L(&9U>GIY"FUS
M9VED(")$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(*;7-G<W1R
M(")$97-C87)G87(@8V%R=&%F;VPH97,I(@H*(SH@;&EB+TU)344O0V]N=&5N
M=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M870B"FUS
M9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N
M:6YC.CD*;7-G:60@(D1R869T(@IM<V=S='(@(D)O<G)A9&]R(@H*(SH@9F]L
M9&5R<RYP:'`Z,SDR"B,L(&9U>GIY"FUS9VED(")$<F%F="!F;VQD97(B"FUS
M9W-T<B`B0V%R=&%F;VP@9&]S(&)O<G)A9&]R97,Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD
M97(Z(@IM<V=S='(@(D-A<G1A9F]L(&1O<R!B;W)R861O<F5S.B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ,#@*(RP@9G5Z>GD*;7-G:60@(D4M;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1E(&-O<G)E;R!E;&5C='+S
M;FEC;R(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,#D*;7-G:60@(D5.1"(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-`IM<V=I
M9"`B15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D
M+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S='(@(D5D
M:71A<B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ.`HC+"!F
M=7IZ>0IM<V=I9"`B161I="!";&%C:VQI<W0B"FUS9W-T<B`B3&ES=&$@;F5G
M<F$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R(")&:6QT<F]S(&1E(&-O
M<G)E;R(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z,38*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I
M;VX@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHR,PIM<V=I9"`B161I="!7:&ET96QI<W0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"B,L(&9U>GIY"FUS
M9VED(")%9&ET('EO=7(@8FQA8VML:7-T(@IM<V=S='(@(D5D:71A<B!A<R!R
M96=R87,@9&4@9FEL=')A>&4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@<G5L97,B"FUS9W-T
M<B`B161I=&%R(&%S(')E9W)A<R!D92!F:6QT<F%X92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-C$*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E
M<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHR,PHC+"!F=7IZ
M>0IM<V=I9"`B161I="!Y;W5R('=H:71E;&ES="(*;7-G<W1R(")%9&ET87(@
M87,@<F5G<F%S(&1E(&9I;'1R87AE(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHR,SD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T
M<B`B16YD97)E>F\@9&4@8V]R<F5O(&5L96-T<O-N:6-O(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C8U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B16UP
M=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T<B`B16QI;6ENX7)O
M;G-E('3S9&%L87,@;65N<V%X97,@9&4@)7,N(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D5M<'1Y($9O;&1E<BAS*2(*
M;7-G<W1R(")"86QE:7)A<B!O<R!C87)T869O;"AE<RDB"@HC.B!F;VQD97)S
M+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O;&1E
M<G,B"FUS9W-T<B`B0F%L96ER87(@;W,@8V%R=&%F;VPH97,I(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y(%1R
M87-H(&9O;&1E<B(*;7-G<W1R(")"86QE:7)A<B!A('!A<&5L96ER82!D;R!L
M:7AO(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")%;7!T
M>2!?4W!A;2(*;7-G<W1R(")"86QE:7)A<B!O(&QI>&\B"@HC.B!L:6(O24U0
M+G!H<#HY-C8*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R
M(")"86QE:7)A<B!O(&QI>&\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE
M(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI
M;F,Z-@IM<V=I9"`B16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS9VED(")%
M;F%B;&4@;65S<V%G92!P<F5V:65W<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#0R"FUS9VED(")%;F-R7WEP=&EO
M;B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,3<@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U-PIM<V=I9"`B
M16YD(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#0*;7-G:60@
M(D5N9"!F;W)W87)D960@;65S<V%G92(*;7-G<W1R(")&:6X@9&$@;65N<V%X
M92!R965N=FEA9&$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0Q"B,L(&9U>GIY
M"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R(")-96YS87AE<R!V96QL87,B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(DUE;G-A>&4@
M<F5E;G9I861A(&1E;F1E("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R
M(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P
M86US96QE8W0N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R("));G1R;V1U>F$@
M;R!N;VUE(&1O(&YO=F\@8V%R=&%F;VP@9&\@;&EX;R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N
M86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(DEN=')O
M9'5Z82!O(&YO;64@9&\@;F]V;R!C87)T869O;"!D;W,@8F]R<F%D;W)E<R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G
M:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L
M9&5R(@IM<V=S='(@(DEN=')O9'5Z82!O(&YO;64@9&\@;F]V;R!C87)T869O
M;"!D;R!C;W)R96\@96YV:6%D;R(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S
M:'-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@
M;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R("));G1R;V1U>F$@;R!N;VUE(&1O
M(&YO=F\@8V%R=&%F;VP@9&\@;&EX;R(*"B,Z(&QI8B]396%R8V@N<&AP.C0V
M"B,L(&9U>GIY"FUS9VED(")%;G1I<F4@365S<V%G92(*;7-G<W1R(")2961I
M<F5C8VEO;F%R(&$@;65N<V%X92(*"B,Z(&UE<W-A9V4N<&AP.C$Y-"!C;VUP
M;W-E+G!H<#HQ,3,T('1H<F5A9"YP:'`Z-S$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5N=')Y(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3R!R97AI<W1R;R!<(B5S
M7"(@96YG861I=7-E(&-O<G)E8W1A;65N=&4@X2!A>&5N9&$@9&]S(&5N9&5R
M97IO<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X-@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R<F\B"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!C;VYN96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D5V96YT('-U
M8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")/(&-A<G1A9F]L(%PB)7-<
M(B!F;VD@96QI;6EN861O(&-O<G)E8W1A;65N=&4N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G
M<W1R(")#861A(#$U(&UI;G5T;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S<Y"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D-A9&$@
M,S`@<V5G=6YD;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q"FUS
M9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B0V%D82`U(&UI;G5T;W,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@S"FUS9VED(")%=F5R>2!H
M86QF(&AO=7(B"FUS9W-T<B`B0V%D82!M961I82!H;W)A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X,`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S
M='(@(D-A9&$@;6EN=71O(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"B,L(&9U>GIY
M"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B17AP86YD:7(@(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB
M"FUS9W-T<B`B17AP86YD:7(@(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R
M(")%>'!A;F1I<B!T;V1O<R!O<R!C87)T869O;&5S(@H*(SH@9F]L9&5R<RYP
M:'`Z-#4W"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(D5X<&%N9&ER
M(&\@8V%R=&%F;VPB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4S"FUS9VED
M(")%>'!A;F0@3F%M97,B"FUS9W-T<B`B17AP86YD:7(@;W,@;F]M97,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V,PIM<V=I9"`B17AP86YD(&YA
M;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H
M92!B86-K9W)O=6YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3@P"FUS9VED(")%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E
M92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_(@IM<V=S='(@(B(*
M(K]%>'!A;F1I<B!P;W(@9&5F96-T;R!T;V1A(&$@X7)B;W)E(&1O<R!C87)T
M869O;&5S(&YA('9I<W1A(&1E(&-A<G1A9F]L97,_(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0HC+"!F
M=7IZ>0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(D5X<&%N9&ER("(*"B,Z
M(&QI8B])35`N<&AP.CDX-"!L:6(O24U0+G!H<#HY.#8*(RP@9G5Z>GD*;7-G
M:60@(D9?971C:"!-86EL(@IM<V=S='(@(D-O<G)E;R!N;W9O(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D9E=&-H($UA:6PB"FUS
M9W-T<B`B0V]R<F5O(&YO=F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#8Y"B,L(&9U>GIY"FUS9VED(")&971C:"!-86EL(&EN(&$@<V5P87)A=&4@
M=VEN9&]W/R(*;7-G<W1R(")2961A8W1A<B!M96YS87AE<R!N=6YH82!X86YE
M;&$@X2!P87)T92XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-#8*(RP@9G5Z>GD*;7-G:60@(D9E=&-H(&UE<W-A9V5S('5P;VX@;&]G
M9VEN9R!O;C\B"FUS9W-T<B`B07!L:6-A<B!A<R!R96=R87,@9&4@9FEL=')A
M>&4@\R!I;FEC:6\@9&$@<V5S:?-N+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP
M.C(X.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M
M97-S86=E<R!F<F]M("5S(@IM<V=S='(@(D5L:6UI;N%R;VYS92!T\V1A;&%S
M(&UE;G-A>&5S(&1E("5S+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@
M9G)O;2`E<R(*;7-G<W1R(")-96YS87AE(')E96YV:6%D82!D96YD92`E<R(*
M"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-2!L:6(O1F5T8VAM86EL+G!H<#HR
M.#<@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"FUS9VED(")&971C:&UA:6PZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@9G5Z>GD*
M;7-G:60@(D9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")4
M96X@)7,@;65N<V%X97,@;F]V87,N(@H*(SH@;&EB+TE-4"YP:'`Z.3DP"B,L
M(&9U>GIY"FUS9VED(")&:5]L=&5R<R(*;7-G<W1R(")&:6QT<F]S(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`R('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C@R"B,L(&9U>GIY"FUS9VED(")&:6QE
M(@IM<V=S='(@(D9I;'1R;W,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S
M='(@(D]U=')A<R!O<&-I\VYS(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D9I;'1E<B!3971T:6YG<R(*;7-G
M<W1R(")296=R87,@9&4@9FEL=')A>&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C`P"B,L(&9U>GIY"FUS9VED(")&:6QT97(@;65S<V%G92!C;VYT
M96YT(&9O<B!P<F]F86YI='D_(@IM<V=S='(@(D9I;'1R87(@;W,@8V]N=&ED
M;W,@;V)S8V5N;W,@9&%S(&UE;G-A>&5S+B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+VYO=&%C=&EV92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES
M(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S='(@
M(D9I;'1R;W,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC
M.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C=&EV92(*;7-G<W1R("(B"@HC.B!L
M:6(O1FEL=&5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R
M<SH@)7,@;6%N86=E;65N="!P86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS9VED(")&:6YD(@IM<V=S
M='(@(D%T;W!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*(RP@
M9G5Z>GD*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")0<FEM
M96ER82!PX7AI;F$B"@HC.B!M86EL8F]X+G!H<#HS-#4*;7-G:60@(D9I<G-T
M(%!A9V4B"FUS9W-T<B`B4')I;65I<F$@<.%X:6YA(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")&;U]R=V%R9"(*
M;7-G<W1R(")2965N=FEA<B(*"B,Z(&9O;&1E<G,N<&AP.C(V-B!T96UP;&%T
M97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HU"FUS9VED(")&;VQD
M97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.0HC.B!T
M96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C8*(SH@=&5M
M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHQ,`IM<V=I9"`B
M1F]L9&5R($YA=FEG871O<B(*;7-G<W1R(").879E9V%D;W(@9&]S(&-A<G1A
M9F]L97,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PHC+"!F=7IZ>0IM
M<V=I9"`B1F]L9&5R(%-U;6UA<GDB"FUS9W-T<B`B1F5B<F5I<F\B"@HC.B!A
M8VPN<&AP.C(T"FUS9VED(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE
M9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-C(*;7-G:60@(D9O;&1E
M<B!U<V4@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-CD*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A
M=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O
M9&%Y(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C<X,"!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B
M4F5E;G9I87(B"@HC.B!C;VUP;W-E+G!H<#HW-C4*;7-G:60@(D9O<G=A<F0Z
M(@IM<V=S='(@(E)E96YV:6%R.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-CD*
M(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(D9I
M;B!D82!M96YS87AE(')E96YV:6%D82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4@9G)O
M;2`E<R(*;7-G<W1R(")-96YS87AE(')E96YV:6%D82!D96YD92`E<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*(RP@9G5Z>GD*;7-G:60@
M(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VGS;B!D
M;R!S97)V:61O<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.30*
M;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S
M="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Q
M"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(W
M"B,L(&9U>GIY"FUS9VED(")&<F]?;2(*;7-G<W1R(")$92(*"B,Z(&UE<W-A
M9V4N<&AP.C(V,R!T:')E860N<&AP.C$T.2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I9"`B1G)O
M;2(*;7-G<W1R(")$92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3@*
M;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R(")%;F1E<F5Z;R!D;R!R96UI
M=&5N=&4B"@HC.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP:'`Z-S@Q"FUS
M9VED(")&=V0Z(@IM<V=S='(@(E)E96YV.B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M.30*(RP@9G5Z>GD*;7-G:60@(D9W9#H@(@IM<V=S='(@(E)E96YV.B(*"B,Z
M(&-O;7!O<V4N<&AP.C$R.38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(D9I;B!D82!M
M96YS87AE(')E96YV:6%D82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`HC+"!F=7IZ>0IM
M<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S='(@(D]P8VGS;G,@9&\@=7-U
M87)I;R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS-PIM
M<V=I9"`B1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,0IM
M<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S8*(RP@9G5Z
M>GD*;7-G:60@(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B4V5G=6EN=&4@;65N
M<V%X92(*"B,Z(&QI8B])35`N<&AP.C0Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*
M;7-G<W1R(")%;F=A9&ER(.$@87AE;F1A(&1E(&5N9&5R97IO<R`H)7,I(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@86-C
M97-S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-B!L:6(O1FEL=&5R
M+G!H<#HQ,#4@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(SH@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$P-`HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ
M-C,@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC.B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP
M:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(SH@;&EB+TU)
M344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(P
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM<V=I9"`B2$5212(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-PHC.B!L:6(O34E-12]6
M:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*
M(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I;VX@;V8@365S
M<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S
M+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@=&AE
M(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8X"FUS9VED(")(:61D96XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PHC+"!F=7IZ>0IM
M<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(E9E:2!P;VQO
M(&;M;R(*"B,Z(&UA:6QB;W@N<&AP.C,V-PIM<V=I9"`B2&ED92!$96QE=&5D
M(@IM<V=S='(@(D]C=6QT87(@87,@96QI;6EN861A<R(*"B,Z(&9O;&1E<G,N
M<&AP.C(Y.`IM<V=I9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`B3V-U
M;'1A<B!A<R!N;VX@<W5B<V-R:71A<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(Y-`IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!M
M97-S86=E+G!H<#HR.3<@;6%I;&)O>"YP:'`Z-S(T('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI9V@@4')I;W)I='DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDS"FUS
M9VED(")(:6=H97-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.#@*;7-G:60@(DAO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T
M=&%C:&UE;G1S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E
M9"!L:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(E!R969I>&\@<&%R82!C:71A
M<B!A<R!L:?%A<R!D82!M96YS87AE(&1E(')E<W!O<W1A.CHB"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$S-`IM<V=I9"`B24U!4"(*;7-G<W1R("(B
M"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H
M075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E
M<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,38V(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V
M97(@4U-,(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,34R"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I
M8V%T92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ-C<*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G
M<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!
M4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0
M,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.#8V
M"FUS9VED("))3D)/6"(*;7-G<W1R("))3D)/6"(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@
M;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I
M<FTN:'1M;#HQ,@HC+"!F=7IZ>0IM<V=I9"`B268@>6]U(&-O;G1I;G5E+"!A
M;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E(&QO<W0A(@IM
M<V=S='(@(J%%;&EM:6YA<F%N<V4@=/-D86QA<R!M96YS87AE<R!D;RAS*2!C
M87)T869O;"AE<RDA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T<B`B26=N;W)A<B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E
M($%L;"(*;7-G<W1R("))9VYO<F%L87,@=&]D87,B"@HC.B!T96UP;&%T97,O
M<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,`HC+"!F
M=7IZ>0IM<V=I9"`B26UP;W)T(@IM<V=S='(@(DEM<&]R=&%N=&4B"@HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($ME
M>2(*;7-G<W1R("));7!O<G1A;G1E(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$S.0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T
M<B`B26UP;W)T86YT92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C(W"B,L(&9U>GIY"FUS9VED("));7!O<G0@365S<V%G97,B"FUS9W-T
M<B`B365N<V%X97,@:6UP;W)T86YT97,B"@HC.B!P9W`N<&AP.C0R"FUS9VED
M("));7!O<G0@4$=0($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.CDQ"FUS9VED("));7!O<G0@4&5R<V]N86P@0V5R=&EF
M:6-A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHQ-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC
M.CD*;7-G:60@(DEM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-`IM
M<V=I9"`B26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHT,"!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-#(*;7-G:60@(DEM<&]R="!0=6)L:6,@2V5Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M-`IM<V=I9"`B26UP;W)T(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX"FUS9VED("));7!O
M<G0@4'5B;&EC(%,O34E-12!+97DB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP
M.C$V"FUS9VED("));7!O<G0@4R]-24U%($ME>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.CD*;7-G:60@(DEM<&]R="!M
M8F]X($9I;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP
M;W)T+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@;6)O>"!F
M:6QE("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G<W1R("(B"@HC.B!M97-S86=E
M+G!H<#HU,#(@;6%I;&)O>"YP:'`Z-S,T('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$V('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHW"FUS9VED("));7!O<G1A
M;G0B"FUS9W-T<B`B26UP;W)T86YT92(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-#<*;7-G:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R
M(")-96YS87AE<R!I;7!O<G1A;G1E<R(*"B,Z(&9O;&1E<G,N<&AP.C$V-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G
M97,@9G)O;2`E<RXB"FUS9W-T<B`B16QI;6ENX7)O;G-E('3S9&%L87,@;65N
M<V%X97,@9&4@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W
M,PIM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HS.#0@;&EB+T9O;&1E<BYP:'`Z.#8@;&EB+T9O;&1E<BYP:'`Z,C$T(&QI
M8B])35`N<&AP.C,Q,PHC.B!L:6(O24U!4"]4<F5E+G!H<#HQ,30@;&EB+TE-
M05`O5')E92YP:'`Z,C$Y"FUS9VED("));F)O>"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR"B,L(&9U>GIY"FUS9VED("));F-L
M=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_
M(@IM<V=S='(@(K]);F-L=>UR(&$@;65N<V%X92!O<FEX:6YA;"!N82!R97-P
M;W-T83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W"FUS9VED("))
M;F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B"FUS9W-T<B`B
MOTEN8VQU[7(@82!M96YS87AE(&]R:7AI;F%L(&YA(')E<W!O<W1A/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B26YF;R(*
M;7-G<W1R("))9VYO<F%R(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(DEN9F]R;6%T
M:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FEN8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#<*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3@*(RP@9G5Z
M>GD*;7-G:60@(DEN;&EN92(*;7-G<W1R(")N:6YG^FXB"@HC.B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I
M9FEC871E($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A=&4@
M4$=0($ME>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z,3`*;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@
M4$=0($ME>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q
M,@IM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M
M<&]N96YT+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O
M>"YP:'`Z-C(V"B,L(&9U>GIY"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS
M9W-T<B`B16YD97)E>F\@9&4@8V]R<F5O(&5L96-T<O-N:6-O(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E
M($UA:6QB;W@B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,34X"B,L('!H
M<"UF;W)M870*;7-G:60@(DEN=F%L:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A
M9&1R97-S.B`E<RXB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C@R('!G<"YP
M:'`Z,38*;7-G:60@(DEN=F%L:60@:V5Y(@IM<V=S='(@(B(*"B,Z('!G<"YP
M:'`Z,3DV"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME
M>2XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@
M<&5R<V]N86P@4$=0('!U8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3(*;7-G:60@(DEN=F5R="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*
M;7-G:60@(DM"(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ,3,*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I9"`B(@HB2V5Y(&=E;F5R871I;VX@
M;6%Y('1A:V4@82!L;VYG('1I;64@=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W
M:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C,U('1E;7!L871E<R]P9W`O<&=P+FEN8SHS
M-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P
M;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS-R!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,SD*;7-G:60@(B(*(DME>2!I;7!O<G0@:7,@;F]T(&%V
M86EL86)L92X@66]U(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@
M861D('EO=7(@(@HB8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z
M,S$X"FUS9VED(")+97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C$V"FUS9VED("),86YG=6%G92(*;7-G<W1R("),:6YG=6$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`V"B,L(&9U>GIY"FUS9VED
M("),87-T($UA:6QB;W@@4&%G92(*;7-G<W1R("+:;'1I;6$@<.%X:6YA(@H*
M(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`B
MVFQT:6UA('#A>&EN82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,X.0HC+"!F=7IZ>0IM<V=I9"`B3&E?;FL@071T86-H;65N=',B"FUS
M9W-T<B`B06YE>&]S(@H*(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O
M<V4N<&AP.C$P-C,*;7-G:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R
M8FED9&5N+B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3`X,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("),:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X,@IM<V=I
M9"`B(@HB3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT
M86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@(@HB;VYL>2!S
M964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@U"FUS9VED
M("),:7-T:6YG(&EN('1H92!(96%D97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P"B,L(&9U>GIY"FUS9VED("),
M;V-A;"!-86EL8F]X.B(*;7-G<W1R(")#86EX82!D92!C;W)R96\B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C<T"B,L(&9U>GIY"FUS9VED("),
M;V-A=&EO;B(*;7-G<W1R(")!8V-I\VXB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(R-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D5N=')A<B(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&]G(&EN('1O("5S(@IM<V=S='(@(D5N=')A<B!A("5S(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S<*(RP@9G5Z>GD*;7-G:60@
M(DQO9VEN(@IM<V=S='(@(D5N=')A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5&%R969A<R!D
M92!I;FEC:6\@9&4@<V5S:?-N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDV"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@;65S<V%G
M92YP:'`Z,CDY(&UA:6QB;W@N<&AP.C<R-R!T96UP;&%T97,O;6%I;&)O>"]L
M96=E;F0N:6YC.C$S"FUS9VED("),;W<@4')I;W)I='DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED("),
M;W=E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U
M8FQE+G!H<#HT-`HC+"!F=7IZ>0IM<V=I9"`B36%C:6YT;W-H($9I;&4B"FUS
M9W-T<B`B1FEL=')O<R!D92!C;W)R96\B"@HC.B!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(DUA:6PB"FUS9W-T
M<B`B0V%I>&$@9&4@8V]R<F5O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDV"B,L(&9U>GIY"FUS9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(D9I
M;'1R;W,@9&4@8V]R<F5O(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV
M97)?<V5L96-T+FEN8SHQ-@IM<V=I9"`B36%I;"!S97)V97(@='EP92!T;R!C
M;VYN96-T('1O.B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,#(*;7-G
M:60@(DUA:6QB;W@B"FUS9W-T<B`B0V%I>&$@9&4@8V]R<F5O(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B36%I;&)O
M>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")/<&-I\VYS
M(&1E('9I<W5A;&EZ86-I\VXB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R
M(&%S(%-E96XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E
M<B!A<R!5;G-E96XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM<V=S='(@(DUA<F-A<B!C;VUO
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G:60@(DUA<FL@
M9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O
M;&]R<S\B"FUS9W-T<B`BOTUA<F-A<B!O<R!N:79E:7,@9&EF97)E;G1E<R!D
M82!C:71A(&-O;B!C;W)E<R!D:7-T:6YT87,_(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S
M('-E96X_("A)34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0V"FUS
M9VED(")-871C:"!!;&P@475E<FEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU,3,*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE
M(@IM<V=S='(@(D%C;VUP8?%A<B!U;B!A<G%U:79O(@H*(SH@;&EB+V%P:2YP
M:'`Z-SD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DT"FUS
M9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M.#D*;7-G:60@(DUA>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE(')E86-H
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,C8*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S4*(RP@9G5Z>GD*;7-G:60@
M(DUE971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I\VX@9&\@
M<V5R=FED;W(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@U"FUS
M9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,3<*;7-G:60@(DUE971I;F<@4F5P;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y.`IM<V=I
M9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8P,PIM<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS
M"B,L(&9U>GIY"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@(D%B
M<FER(&\@8V%R=&%F;VPB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Q"FUS9VED
M(")-97-S86=E(@IM<V=S='(@(DUE;G-A>&4B"@HC.B!C;VUP;W-E+G!H<#HU
M-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O<V4N<&AP.C8T,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S:71I;VXB"FUS
M9W-T<B`B4F5D86-T87(@=6YH82!M96YS87AE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(D1A
M=&$@9&$@;65N<V%X92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PHC+"!F=7IZ
M>0IM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(DUE;G-A>&5S(&$B
M"@HC.B!S96%R8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS
M9W-T<B`B0G5S8V$@9&4@;65N<V%X97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`B4&]R('1A
M;6'Q;R!D82!M96YS87AE(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS9VED(")-
M97-S86=E(%-O=7)C92(*;7-G<W1R(")#\V1I9V\@9F]N=&4@9&$@;65N<V%X
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G
M92!6:65W:6YG(@IM<V=S='(@(E9I<W5A;&EZ86-I\VX@9&4@;65N<V%X97,B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G:60@(DUE<W-A
M9V4@9FQA9W,B"FUS9W-T<B`B36%R8V%S(&1A(&UE;G-A>&4B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E(&9O;&1E
M<G,B"FUS9W-T<B`B0V%R=&%F;VQE<R!D92!M96YS87AE<R(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE
M<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")#87)T869O;&5S(&1E(&UE;G-A>&5S
M(@H*(SH@;6%I;&)O>"YP:'`Z-C8W"B,L(&9U>GIY"FUS9VED(")-97-S86=E
M(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R(")%;&EM:6YO=2!U;B!A<G%U:79O
M+B(*"B,Z(&UA:6QB;W@N<&AP.C8U.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G
M92!I<R!E;F-R>7!T960B"FUS9W-T<B`B0V%M<&]S(&1A(&UE;G-A>&4B"@HC
M.B!M86EL8F]X+G!H<#HV-3,*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@
M<VEG;F5D(@IM<V=S='(@(D-A;7!O<R!D82!M96YS87AE(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")-97-S
M86=E(&UA=&-H97,B"FUS9W-T<B`B1&%T82!D82!M96YS87AE(@H*(SH@8V]M
M<&]S92YP:'`Z.#(T(&-O;7!O<V4N<&AP.C@S.`HC+"!F=7IZ>0IM<V=I9"`B
M365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B02!M
M96YS87AE(&5N=FEO=7-E+"!P97)O(&YO;B!S92!G87)D;W4@96XB"@HC.B!C
M;VUP;W-E+G!H<#HQ,#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-
M97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S
M(@IM<V=S='(@(D$@;65N<V%X92!E;G9I;W5S92P@<&5R;R!N;VX@<V4@9V%R
M9&]U(&5N(@H*(SH@8V]M<&]S92YP:'`Z,3$T,R!C;VUP;W-E+G!H<#HQ,34X
M"B,L(&9U>GIY"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R(")!(&UE;G-A>&4@96YV:6]U<V4L('!E<F\@;F]N('-E(&=A<F1O
M=2!E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE
M<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@
M(DUE;G-A>&5S('!O<B!PX7AI;F$@;F$@;&ES=&$@9&$@8V%I>&$@9&\@8V]R
M<F5O+B(*"B,Z(&UA:6QB;W@N<&AP.C,R,@IM<V=I9"`B365S<V%G97,@=&\B
M"FUS9W-T<B`B365N<V%X97,@82(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHR.0IM<V=I9"`B36]D:69Y(@IM<V=S='(@(DUO9&EF:6-A<B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHU,`IM<V=I9"`B36]V92(*;7-G<W1R(")-;W9E<B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-@HC+"!F=7IZ>0IM<V=I9"`B
M36]V92!D;W=N(@IM<V=S='(@(FUO=F5R('!A<F$@86)A:7AO(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8Q.`IM<V=I9"`B36]V92!S<&%M(&UE<W-A
M9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T;R!)
M3D)/6"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M-3`*(RP@9G5Z>GD*;7-G:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@(G-E
M;&5C8VEO;F%R('5N(&-A<G1A9F]L(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,S$T"B,L(&9U>GIY"FUS9VED(")-;W9E('5P(@IM
M<V=S='(@(FUO=F5R('!A<F$@87)R:6)A(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E<FYA
M=&EV92(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z
M,34R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!-97-S86=E(%9I97<B"FUS
M9W-T<B`B5FES=6%L:7IA8VGS;B!D92!M96YS87AE<R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHU"FUS9VED(").3TY%
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHT."!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S@@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B3F%M92(*;7-G<W1R(").;VUE(@H*
M(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;B!N
M;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<W.`HC+"!F=7IZ>0IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S
M='(@(D%C8VGS;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S`@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4X,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S<X"FUS9VED(").979E<B(*;7-G<W1R(").=6YC82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-C`*(RP@9G5Z>GD*;7-G:60@(DYE=F5R('-A
M=F4@871T86-H;65N=',B"FUS9W-T<B`B16QI;6EN;W4@=6X@87)Q=6EV;RXB
M"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS
M9W-T<B`B3F]V82(*"B,Z(&QI8B])35`N<&AP.C4V,PHC+"!F=7IZ>0IM<V=I
M9"`B3F5W($9O;&1E<B(*;7-G<W1R(")!8G)I<B!O(&-A<G1A9F]L(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@36%I;"(*;7-G
M<W1R(")#;W)R96\@;F]V;R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M.2!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS,PHC+"!F=7IZ>0IM<V=I
M9"`B3F5W($UE<W-A9V4B"FUS9W-T<B`B4V5G=6EN=&4@;65N<V%X92(*"B,Z
M(&UA:6QB;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM
M<V=S='(@(DUE;G-A>&5S(&YO=F%S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHQ.0IM<V=I9"`B3F5W(&UE<W-A9V5S(@IM<V=S='(@(DUE;G-A
M>&5S(&YO=F%S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$S,PIM<V=I9"`B3F5X="(*;7-G<W1R(")396=U:6YT92(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE
M>'0@365S<V%G92(*;7-G<W1R(")396=U:6YT92!M96YS87AE(@H*(SH@;6%I
M;&)O>"YP:'`Z,S4V"FUS9VED(").97AT(%!A9V4B"FUS9W-T<B`B4V5G=6EN
M=&4@<.%X:6YA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-30R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S<*;7-G:60@(DYO(@IM<V=S
M='(@(DYO;B(*"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO($-E<G1I9FEC
M871E(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N
M8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3D*;7-G:60@(DYO($ME
M>7,@:6X@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HS-S4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO($UE<W-A9V5S(@IM<V=S
M='(@(DUE;G-A>&5S(&YO=F%S(@H*(SH@<&=P+G!H<#HQ,S<*;7-G:60@(DYO
M(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S;VYA;"!#
M97)T:69I8V%T92!0<F5S96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EL8F]X
M+G!H<#HS,CD*(RP@9G5Z>GD*;7-G:60@(DYO(%!R979I97<@5&5X="(*;7-G
M<W1R(")497AT;R!C;W)R:7AI9&\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C$U"FUS9VED(").;R!0=6)L:6,@2V5Y<R!&;W5N9"(*;7-G<W1R
M("(B"@HC.B!S;6EM92YP:'`Z,34Q"FUS9VED(").;R!3+TU)344@<'5B;&EC
M(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W1N968N<&AP.CDP"B,L(&9U>GIY"FUS9VED(").;R!A='1A8VAM96YT<R!F
M;W5N9"XB"FUS9W-T<B`B06YE>&]S(@H*(SH@;&EB+T-R>7!T+U--24U%+G!H
M<#HQ-#`*;7-G:60@(DYO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@
M=&AE('!U8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-S(@86-L
M+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R('-E;&5C=&5D+B(*
M;7-G<W1R(")N;VX@<V5L96-C:6]N;W4@;FEN9_IN(&-A<G1A9F]L(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T,0IM<V=I9"`B3F\@9F]L9&5R<R!A
M<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(B(*"B,Z
M(&9O;&1E<G,N<&AP.C(Q."!L:6(O1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E
M<BYP:'`Z-34P"FUS9VED(").;R!F;VQD97)S('=E<F4@<W!E8VEF:65D(@IM
M<V=S='(@(DYO;B!E<W!E8VEF:6-O=2!N:6YG^FX@8V%R=&%F;VPB"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30W"B,L(&9U>GIY"FUS9VED(").;R!F
M;VQD97)S('=I=&@@;F5W(&UE<W-A9V5S(@IM<V=S='(@(DUE;G-A>&5S(&YO
M;B!E;&EM:6YA9&%S(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T-`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E
M<R(*;7-G<W1R(")-96YS87AE<R!N;VX@96QI;6EN861A<R(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HS,C4*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@8F]D
M>2!T97AT(@IM<V=S='(@(FUO=F5R(&$@;65N<V%X92!P87)A(@H*(SH@;&EB
M+TUA:6QB;W@N<&AP.C,W,0HC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G97,@
M;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B3F]N(&AA:2!M96YS87AE
M<R!Q=64@8W5M<')A;B!O(&-R:71E<FEO(&1A(&)U<V-A(@H*(SH@<&=P+G!H
M<#HQ.#D*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O
M<G1E9"XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ-C4*;7-G:60@(DYO('!E
M<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!S;6EM92YP:'`Z,C`Q"FUS9VED(").;R!P97)S;VYA;"!3+TU)344@8V5R
M=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP
M:'`Z,C(P"FUS9VED(").;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG
M=7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C0X"FUS9VED(").;R!S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B
M3F]N(&AA:2!E<G)O<R!D92!O<G1O9W)A9NUA(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B
M"FUS9W-T<B`B3F]N(&AA:2!S=7AE<W1I\VYS(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HU-C0*;7-G:60@(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M86-L+G!H<#HV."!A8VPN<&AP.CDT"B,L(&9U>GIY"FUS9VED(").;R!U<V5R
M('-P96-I9FEE9"XB"FUS9W-T<B`B3F]N(&5S<&5C:69I8V]U(&YI;F?Z;B!C
M87)T869O;"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#D*;7-G
M:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C$Q('1E;7!L871E<R]P<F5F<R]S96YT;6%I
M;'-E;&5C="YI;F,Z-#`*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C
M="YI;F,Z,S4@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(DYO;F4B"FUS
M9W-T<B`B3FEN9W5N:&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR.34*;7-G:60@(DYO<FUA;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S='(@(DYO;B!E
M;&EM:6YA9&$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R
M869T(@IM<V=S='(@(DYO;B#I('5N(&)O<G)A9&]R(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS-`IM<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R(").;VX@Z2!I
M;7!O<G1A;G1E(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR
M-0IM<V=I9"`B3F]T(%!E<G-O;F%L(@IM<V=S='(@(DYO;B#I('!E<G-O86PB
M"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H
M<#HQ,S0@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A
M;&ED('!U8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z-C<*;7-G:60@(DYO="!D96QE=&5D(&UE<W-A9V5S(@IM
M<V=S='(@(DUE;G-A>&5S(&YO;B!E;&EM:6YA9&%S(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B3F]T(&EM<&]R=&%N="!M97-S
M86=E<R(*;7-G<W1R(")-96YS87AE<R!N;VX@:6UP;W)T86YT97,B"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C<Q"FUS
M9VED(").;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I;64B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q-@HC+"!F=7IZ>0IM
M<V=I9"`B3F]T:&EN9R(*;7-G<W1R(")#:71A;F1O(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-PHC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&UO
M;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L971I
M;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB3OIM97)O(&1E(&-A<G1A9F]L97,@
M9&4@8V]R<F5O(&5N=FEA9&\@<75E('-E('9A;B!M86YT97(@\R!E;&EM:6YA
M;&]S("(*(FUE;G-U86QM96YT92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-3D*;7-G:60@(DYU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@
M=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R("(B"B).^FUE
M<F\@9&4@8V%R=&%F;VQE<R!D92!C;W)R96\@96YV:6%D;R!Q=64@<V4@=F%N
M(&UA;G1E<B#S(&5L:6UI;F%L;W,@(@HB;65N<W5A;&UE;G1E(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-30@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4U,@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S,S"FUS9VED(")/2R(*;7-G<W1R(")#;W)R96-T;R(*"B,Z('1E;7!L871E
M<R]S96%R8V@O9FEE;&1S+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHT.0HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X
M"FUS9VED(")/4B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$U"FUS9VED(")/;&0@;65S<V%G97,B"FUS9W-T<B`B365N<V%X
M97,@=F5L;&%S(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E
M;G1M86EL7VUO;G1H;'DN<&AP.C4R"FUS9VED(")/;&0@<V5N="UM86EL(&9O
M;&1E<G,@8F5I;F<@<'5R9V5D+B(*;7-G<W1R(")%;&EM:6YA;F1O(&]S(&-A
M<G1A9F]L97,@9&4@8V]R<F5O(&5N=FEA9&\@=F5L;&]S(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C(U"FUS9VED(")/;FQY(&1I<W!L87D@9F]L9&5R
M<R!W:71H('5N<F5A9"!M97-S86=E<R!I;B!T:&5M/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"B,L(&9U>GIY
M"FUS9VED(")/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O
M<B!T:&ES(&%C=&EO;BXB"FUS9W-T<B`B4V5L96-C:6]N92!U;B!S\R!C87)T
M869O;"!P87)A(&5S=&$@;W!E<F%C:?-N(@H*(SH@=&5M<&QA=&5S+VUE;G4N
M:6YC.C$P('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B
M3W!E;B!&;U]L9&5R(@IM<V=S='(@(D%B<FER(&\@8V%R=&%F;VPB"@HC.B!F
M;VQD97)S+G!H<#HT,C<*(RP@9G5Z>GD*;7-G:60@(D]P96YE9"!&;VQD97(B
M"FUS9W-T<B`B06)R:7(@;R!C87)T869O;"(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW,#4*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM
M<V=S='(@(B(*"B,Z(&9E=&-H;6%I;"YP:'`Z,S,@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]T;W`N:6YC.C,*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA
M:6PN:6YC.C8*(RP@9G5Z>GD*;7-G:60@(D]T:&5R($UA:6P@06-C;W5N=',B
M"FUS9W-T<B`B3W5T<F%S(&]P8VGS;G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3D*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U,`IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R(")/=71R
M87,@;W!C:?-N<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`Q
M"FUS9VED(")/=71B;W5N9"!397)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ-B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-C4*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`T(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(Y,`IM<V=I9"`B4$=0(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-PHC+"!F
M=7IZ>0IM<V=I9"`B4$=0($5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")#86YC
M96QA<B!A(&UE;G-A>&4B"@HC.B!C;VUP;W-E+G!H<#HS-3@*(RP@9G5Z>GD*
M;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S='(@(D5R<F\B"@HC.B!C;VUP;W-E
M+G!H<#HS,S<*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O
M<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,@HC+"!F=7IZ>0IM<V=I9"`B4$=0($]P=&EO
M;G,B"FUS9W-T<B`B3W!C:?-N<R(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'
M4"!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P
M<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"FUS9VED(")0
M1U`@4'5B;&EC($ME>2!497AT(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,30Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F
M;W(@7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T
M<B`B3R!C87)T869O;"!<(B5S7"(@9F]I(&-R96%D;R!C;W)R96-T86UE;G1E
M+B(*"B,Z('!G<"YP:'`Z,C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@
M9&5L971E9"XB"FUS9W-T<B`B3R!C87)T869O;"!<(B5S7"(@9F]I(&5L:6UI
M;F%D;R!C;W)R96-T86UE;G1E+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`HC+"!F=7IZ
M>0IM<V=I9"`B4$=0(%-I9VX@365S<V%G92(*;7-G<W1R(")%;G9I87(@82!M
M96YS87AE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN
M8SHY"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@<&=P+G!H<#HR,#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!P<FEV871E
M(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(D$@<VEN871U<F$@
M<W5B<W1I='7M=7-E(&-O<G)E8W1A;65N=&4N(@H*(SH@<&=P+G!H<#HQ-S<*
M;7-G:60@(E!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C0*;7-G
M:60@(E!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#@*;7-G
M:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O
M('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R
M:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(Y-0IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A
M8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G
M:60@(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@
M8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@(@HB<V5T
M('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H
M:7,@<V5T=&EN9R!O<B!E;'-E('1H92!01U`@(@HB9F5A='5R97,@=VEL;"!N
M;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`P"FUS9VED(")03U`S("A!=71O($1E
M=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3$W"FUS9VED(")03U`S(&]V97(@4U-,(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(S"FUS9VED(")03U`S(&]V
M97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-CD*;7-G:60@(E!/4#,@
M;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R("(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C$Q,0IM<V=I9"`B4$]0,RP@;F\@5$Q3(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4&%G92`E9"!O9B`E9"(*;7-G<W1R(")0X7AI
M;F$@)60@9&4@)60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS
M9VED(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#0*;7-G:60@(E!A
M9V4@=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R
M="AS*2(*;7-G<W1R(")087)T92AS*2(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,C,*;7-G:60@(E!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$R.`IM<V=I9"`B4&%S<W!H<F%S92`H06=A
M:6XI(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR,S4@<&=P+G!H<#HS,3`*
M(RP@9G5Z>GD*;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A
M9&5D+B(*;7-G<W1R(")!(&UE;G-A>&4@96YV:6]U<V4L('!E<F\@;F]N('-E
M(&=A<F1O=2!E;B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN
M8SHQ."!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C(Y"FUS9VED(")0
M87-S<&AR87-E.B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$Q,@IM<V=I9"`B
M4&%S<W!H<F%S97,@8V%N(&YO="!B92!E;7!T>2(*;7-G<W1R("(B"@HC.B!P
M9W`N<&AP.C$Q-`IM<V=I9"`B4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR
M,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S$*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3(*;7-G:60@(E!A<W-W;W)D(@IM<V=S
M='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHT.`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R
M871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")296%L:7IA<B!A<R!O<&5R86-I
M\VYS(&1E(&UA;G1E;65N=&\@\R!I;FEC:6\@9&4@<V5S:?-N(@H*(SH@86-L
M+G!H<#HW-B!A8VPN<&AP.C$P,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R('1H
M:7,@=7-E<B!C86X@;F]T(&)E(&-H86YG960N(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HW,#,@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N
M:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R(")097)S;V%L(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")097)S;VYA;"!);F9O
M<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VGS;B!P97)S;V%L(@H*(SH@<&=P
M+G!H<#HQ,C`*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3(W"FUS
M9VED(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(P-PIM<V=I9"`B4&5R<V]N86P@
M4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z("(*;7-G<W1R("(B
M"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S;VYA;"!3+TU)344@:V5Y
M<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA8V4@>6]U<B!S:6=N871U
M<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/R(*;7-G<W1R("*_475E
M<F4@8V]L;V-A<B!A('/Z82!S:6YA='5R82!N82!M96YS87AE(&1E(')E<W!O
M<W1A(&4@;F]S(')E96YV[6]S/R(*"B,Z(&-O;7!O<V4N<&AP.C(U-`IM<V=I
M9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDY"FUS9VED("(B"B)0;&%Y('-O
M=6YD(&]N(&YE=R!M86EL/R`@5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@
M=&\@<W5P<&]R="!E;6)E9&1E9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A
M;&P@9&\@;VX@5VEN9&]W<R!A;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS
M('=I;&P@(@HB<F5Q=6ER92!A('!L=6=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA
M:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"B,L(&9U>GIY"FUS9VED(")0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B
M26YT<F]D=7IA(&\@;F]M92!D;R!N;W9O(&-A<G1A9F]L.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R('1E;7!L871E<R]J879A
M<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")0;&5A<V4@96YT97(@=&AE
M(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(DEN=')O9'5Z82!O
M(&YO;64@9&\@;F]V;R!C87)T869O;#HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C$S-PIM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N
M97<@;F%M93HB"FUS9W-T<B`B26YT<F]D=7IA(&\@;F]V;R!N;VUE.B(*"B,Z
M('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y
M;W5R(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O("(*
M(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I
M;&P@;VYL>2!N965D("(*(G1O(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E
M('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!R96-O;7!O<V4N<&AP
M.CDW"FUS9VED("(B"B)0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C
M;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R`B
M"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P
M;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O("(*(FQO9R!I;B!A9V%I
M;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E
M<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$
M+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<Q"B,L(&9U>GIY
M"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D+B(*;7-G<W1R
M("));F1I<75E(&\@<V5U(&YO;64@9&4@=7-U87)I;R!E(&$@8VAA=F4@9&4@
M86-C97-O(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PHC+"!F
M=7IZ>0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS
M9W-T<B`B26YD:7%U92!O('-E=2!N;VUE(&1E('5S=6%R:6\@92!A(&-H879E
M(&1E(&%C8V5S;R(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O24U0+G!H<#HT
M-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED
M(&%D9')E<W-E<RXB"FUS9W-T<B`B0V]R<FEX82!O<R!E;F1E<F5Z;W,@86UB
M:6=U;W,@;W4@:6YC;W)R96-T;W,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8T,@IM<V=I9"`B(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W
M:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C$*;7-G:60@(E!L96%S92!S96QE
M8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS+B(*
M;7-G<W1R(")396QE8V-I;VYE('5N(&-A<G1A9F]L(&%N=&5S(&1E(')E86QI
M>F%R(&-A;'%U97)A(&%C8VGS;BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3`R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R(")396QE8V-I;VYE
M('!O;&\@;65N;W,@=6X@8V%R=&%F;VP@;F\@<75E(')E86QI>F%R(&$@8G5S
M8V$N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]J879A<V-R:7!T+FEN8SHT,0IM
M<V=I9"`B4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E
M87)C:"XB"FUS9W-T<B`B4V5L96-C:6]N92!P;VQO(&UE;F]S('5N(&-A<G1A
M9F]L(&YO('%U92!R96%L:7IA<B!A(&)U<V-A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@
M;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B
M4V5L96-C:6]N92!U;B!S\R!C87)T869O;"!P87)A(&5S=&$@;W!E<F%C:?-N
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"B,L(&9U
M>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T
M;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E-E;&5C8VEO;F4@82!C86EX82!D92!E
M9&EC:?-N(&$@8V%R\VX@9&4Z(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z
M-#$*;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q-`HC+"!F=7IZ>0IM<V=I9"`B4')E8V5D
M92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R
M(")!;G1E<&_Q97(@82!S^F$@<VEN871U<F$@8V]N(&=U:?-N<R`H)RTM("<I
M(@H*(SH@<VUI;64N<&AP.C(T,2!P9W`N<&AP.C(U-R!F:6QT97)P<F5F<RYP
M:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!R969E<F5N8V5S('-U8V-E<W-F=6QL
M>2!U<&1A=&5D+B(*;7-G<W1R(")/(&-A<G1A9F]L(%PB)7-<(B!F;VD@8W)E
M861O(&-O<G)E8W1A;65N=&4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS9W-T
M<B`B4.%X:6YA(&%N=&5R:6]R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@365S<V%G92(*
M;7-G<W1R(")-96YS87AE(&%N=&5R:6]R(@H*(SH@;6%I;&)O>"YP:'`Z,S0W
M"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(E#A>&EN82!A;G1E<FEO
M<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS
M,PIM<V=I9"`B4')I;G0B"FUS9W-T<B`B26UP<FEM:7(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B4')I
M;W)I='DB"FUS9W-T<B`B26UP<FEM:7(B"@HC.B!T96UP;&%T97,O<VUI;64O
M:6UP;W)T7VME>2YI;F,Z-S8*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3D*;7-G
M:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@
M9&5F875L="!T;R!.3R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-34X"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM
M96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C
M;VPZ(@IM<V=S='(@(B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0R.0IM<V=I
M9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A
M8FQE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN
M8SHX"B,L(&9U>GIY"FUS9VED(")0=7)?9V4@1&5L971E9"(*;7-G<W1R(")2
M96-I8VQA<B!O(&QI>&\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC
M.C@*;7-G:60@(E!U<F=E($1E;&5T960B"FUS9W-T<B`B4F5C:6-L87(@;R!L
M:7AO(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C0*(RP@
M9G5Z>GD*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R(")%;&EM:6YA
M<B!C87)T869O;"AE<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV
M"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(E)E8VEC
M;&%R(&\@;&EX;R!C;VX@97-T82!F<F5C=65N8VEA.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R
M87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM
M<V=S='(@(E)E8VEC;&%R(&1O(&QI>&\@87,@;65N<V%X97,@<75E('1E\6%N
M(&WA:7,@9&5S=&5S(&3M87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@V"B,L(&9U>GIY"FUS9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE
M(%1R87-H(&9O;&1E<C\B"FUS9W-T<B`B4F5C:6-L87(@87,@;65N<V%X97,@
M=F5L;&%S(&1O(&QI>&\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G
M95]T<F%S:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!U
M<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@
M(E)E8VEC;&%N9&\@)60@;65N<V%X92AS*2!D;R!L:7AO(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8S"B,L(&9U>GIY"FUS
M9VED(")0=7)G:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS
M9W-T<B`B4F5C:6-L86YD;R`E9"!M96YS87AE*',I(&1O(&QI>&\B"@HC.B!T
M96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C$W"B,L('!H<"UF;W)M870*;7-G
M:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@
M3$E-250B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN
M8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z($Y/($Q)
M34E4(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S
M='(@(D-I=&%N9&\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS.#8*;7-G:60@(E)E7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HU,`HC+"!F=7IZ>0IM<V=I
M9"`B4F5C96EV960@3VXB"FUS9W-T<B`B4F5C:6)I9&$@;R(*"B,Z(&QI8B]3
M96%R8V@N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!3:6YC92(*
M;7-G<W1R(")296-I8FED82!O(@H*(SH@;&EB+U-E87)C:"YP:'`Z-30*(RP@
M9G5Z>GD*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM<V=S='(@(E)E8VEB:61A
M(&\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,38*(RP@9G5Z>GD*;7-G:60@(E)E9&ER96-?="(*;7-G<W1R(")2961I<F5C
M8VEO;F$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(E)E9&ER96-C:6]N82(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*;7-G:60@
M(E)E9&ER96-T($UE<W-A9V4B"FUS9W-T<B`B4F5D:7)E8V-I;VYA<B!A(&UE
M;G-A>&4B"@HC.B!C;VUP;W-E+G!H<#HW.#<*;7-G:60@(E)E9&ER96-T('1H
M:7,@;65S<V%G92(*;7-G<W1R(")2961I<F5C8VEO;F%R(&5S=&$@;65N<V%X
M92(*"B,Z(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E8W1I;F<@9F%I
M;&5D+B(*;7-G<W1R(")&86QL;W4@;R!R961I<F5C8VEO;F%M96YT;RXB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU.#,*;7-G:60@(E)E
M9G)E<V@B"FUS9W-T<B`B06-T=6%L:7IA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E<V@@1F]L9&5R(%9I97=S.B(*;7-G
M<W1R(")!8W1U86QI>F%R(&$@=FES=&$@9&]S(&-A<G1A9F]L97,B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY('1E;7!L871E<R]M86EL8F]X
M+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(E)E8V%R9V%R(&$@=FES=&$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D
M+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R(")296-A<F=A<B!A
M('9I<W1A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R-B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-30U"FUS9VED(")296UE;6)E<B!T:&4@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3<Y"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V
M:65W(@IM<V=S='(@(DQE;6)R87(@82#Z;'1I;6$@=FES=&$B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*(RP@9G5Z>GD*;7-G:60@
M(E)E;6]T92!-86EL8F]X.B(*;7-G<W1R(")#86EX82!D92!C;W)R96\B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V
M92!&:65L9"!&<F]M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!S;W5R8V4B"FUS9W-T<B`B<75I=&%R(&$@9F]N=&4B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED(")2
M96YA;64@1F]L9&5R*',I(@IM<V=S='(@(D-A;6)I87)L;&4@;R!N;VUE(/,@
M8V%R=&%F;VPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED
M(")296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N
M=&@_(@IM<V=S='(@(D-A;6)I87)L;&4@;R!N;VUE(/,@8V%R=&%F;VP@9&\@
M8V]R<F5O(&5N=FEA9&\@\R!I;FEC:6\@9&\@;65S(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-#4U"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG(%PB)7-<
M(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(B(*(D9A;&QO=2#S(&-A;6)I87)L;&4@;R!N;VUE(%PB
M)7-<(B!A(%PB)7-<(BX@17-T82!F;VD@82!R97-P;W-T82!D;R!S97)V:61O
M<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ
M,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS9W-T<B`B4F5S
M<&]N9&5R;&QE<R!A('1O9&]S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G<W1R(")3
M=6)S=&ET=>UR(&-O;CHB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`B4F5S<&]N9&5R
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q,2!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-#`Y"B,L(&9U>GIY"FUS9VED(")297!L>2!396YT
M+B(*;7-G<W1R(")297-P;VYD97)L;&4B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*
M;7-G<W1R(")297-P;VYD97)L;&5S(&$@=&]D;W,B"@HC.B!C;VUP;W-E+G!H
M<#HW,S,*;7-G:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B4F5S<&]N9&5R
M;&QE<R!A('1O9&]S.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@=&\@3&ES="(*
M;7-G<W1R(")297-P;VYD97)L;&5S(&$@=&]D;W,B"@HC.B!C;VUP;W-E+G!H
M<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O($QI<W0Z(@IM<V=S='(@
M(E)E<W!O;F1E<FQL97,@82!T;V1O<SHB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E<&QY
M('1O(%]!;&PB"FUS9W-T<B`B4F5S<&]N9&5R;&QE<R!A('1O9&]S(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3,W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*
M;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S4*;7-G:60@
M(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,T"FUS9VED
M(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-PHC+"!F=7IZ>0IM<V=I
M9"`B4F5P;'DM5&\B"FUS9W-T<B`B4F5S<&]N9&5R;&QE.B`B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#`Y"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(E)E
M<W!O;F1E<FQL93H@(@H*(SH@8V]M<&]S92YP:'`Z-S,Q"FUS9VED(")297!L
M>3HB"FUS9W-T<B`B4F5S<&]N9&5R.B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT
M(@IM<V=S='(@(D1E;G5N8VEA<B!E<W1A(&UE;G-A>&4@8V]M;R!C;W)R96\M
M;&EX;R`H<W!A;2DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*
M;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(D1E;G5N8VEA<B!E<W1A
M(&UE;G-A>&4@8V]M;R!C;W)R96\M;&EX;R`H<W!A;2DB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#,*(RP@9G5Z>GD*;7-G:60@(E)E
M<75E<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(E-O;&EC:71A<B!U;B!A
M=FES;R!D92!R96-E<&-I\VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y(&-O;F9I<FUA=&EO;C\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,PHC+"!F=7IZ
M>0IM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G<W1R(")3;VQI
M8VET87(@=6X@879I<V\@9&4@<F5C97!C:?-N(@H*(SH@;6%I;&)O>"YP:'`Z
M,3@Y"FUS9VED(")297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.3<*;7-G:60@
M(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z,30S('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHR-@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q"FUS9VED(")2
M97-E="(*;7-G<W1R(")296EN:6-I87(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3$U"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R(")296%N=61A<B(*
M"B,Z(')E8V]M<&]S92YP:'`Z.3@*;7-G:60@(E)E<W5M92!Y;W5R('-E<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C0T"B,L(&9U>GIY"FUS9VED(")2971U<FX@=&\@7")-97-S86=E($-O
M;7!O<VET:6]N7"(B"FUS9W-T<B`B4F5D86-T87(@=6YH82!M96YS87AE(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHS,2!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-CD*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,S(*;7-G:60@(E)E='5R
M;B!T;R!&971C:"!-86EL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHV,"!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N
M:6YC.C(R"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`Q('1E;7!L
M871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$T"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-#D@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C(@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$W,PHC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS
M9W-T<B`B3W!C:?-N<R!D;R!U<W5A<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<Q.`IM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X(&QI
M<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE
M<W-A9V4_(@IM<V=S='(@(B(*(K]296=R97-A<B#A(&QI<W1A(&1A(&-A:7AA
M(&1E(&-O<G)E;R!D97-P;VES(&1E(&5L:6UI;F%R+"!M;W9E<B!O=2!C;W!I
M87(@(@HB=6YH82!M96YS87AE/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV.#@*;7-G:60@(E)O;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3D*;7-G:60@
M(E,O34E-12(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R
M>7!T7VQI<W0N:6YC.C$R"FUS9VED(")3+TU)344@16YC<GEP="!-97-S86=E
M(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C,Y-`IM<V=I9"`B4R]-24U%
M($5R<F]R.B`B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,S<S"FUS9VED
M(")3+TU)344@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@
M<')I=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-3$*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!/<'1I;VYS(@IM<V=S
M='(@(D]P8VGS;G,B"@HC.B!S;6EM92YP:'`Z-#D*;7-G:60@(E,O34E-12!0
M87-S<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-30*;7-G:60@(E,O34E-12!097)S;VYA;"!+97EP86ER
M('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ-#`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U
M8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")/(&-A<G1A9F]L(%PB)7-<
M(B!F;VD@96QI;6EN861O(&-O<G)E8W1A;65N=&4N(@H*(SH@<VUI;64N<&AP
M.C$V,@IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D
M9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C$P"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B(@H*
M(SH@<VUI;64N<&AP.C(Q,0IM<V=I9"`B4R]-24U%(%!U8FQI8R]0<FEV871E
M($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"B,L(&9U>GIY
M"FUS9VED(")3+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(D5N=FEA<B!A
M(&UE;G-A>&4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N
M:6YC.C$T"FUS9VED(")3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-`IM
M<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,C0Q"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY
M(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E
M8W)Y<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HQ-S,*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B
M;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I9VYE9"!M97-S86=E(&-A
M;B!N;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$T-@IM<V=I9"`B(@HB4R]-24U%('-U<'!O
M<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES
M('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"FUS9VED("(B"B)3+TU)344@<W5P
M<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y
M;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O
M<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@
M96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R
M<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(P-0IM<V=I9"`B4TU44"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR-34*(RP@9G5Z>GD*;7-G:60@(E-?=6)J
M96-T(@IM<V=S='(@(D%S=6YT;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,V,PHC+"!F=7IZ>0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN
M("(*;7-G<W1R(")'87)D87(@82!C;W!I82!E;B`B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@
M(E-A7W9E(&%S(@IM<V=S='(@(D=A<F1A<B!C;VUO(@H*(SH@<V5A<F-H+G!H
M<#HS,38@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W"B,L(&9U
M>GIY"FUS9VED(")3879E(@IM<V=S='(@(D=A<F1A<B!C;VUO(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E($%T
M=&%C:&UE;G1S('=I=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV
M.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@(E-A
M=F4@1')A9G0B"FUS9W-T<B`B1V%R9&%R(&\@8F]R<F%D;W(B"@HC.B!S879E
M:6UA9V4N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")3879E($EM86=E(@IM<V=S
M='(@(D=A<F1A<B!C;VUO(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(P
M-`IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E
M+FEN8SHQ,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4V%V92!/
M<'1I;VYS(@IM<V=S='(@(D]P8VGS;G,@9&\@=7-U87)I;R(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,`IM<V=I9"`B4V%V92!3=&%T
M:6]N97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PHC
M+"!F=7IZ>0IM<V=I9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B1V%R9&%R(&\@
M8F]R<F%D;W(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T<B`B1V%R9&%R(&-O;6\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Q"FUS9VED(")3879E(&1R
M869T<R!A<R!U;G-E96X_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#<R"FUS9VED(")3879E(')E8VEP:65N=',@875T;VUA=&EC
M86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(W"FUS9VED(")3879E
M('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"B,L(&9U>GIY"FUS9VED(")3879E
M('-E;G0@;6%I;#\B"FUS9W-T<B`B1V%R9&%R(&%S(&UE;G-A>&5S(&5N=FEA
M9&%S(@H*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B1F%L;&]U(/,@9V%R9&%R(&\@8F]R
M<F%D;W(N($5S=&$@9F]I(&$@<F5S<&]S=&$@9&\@<V5R=FED;W(Z("5S(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA
M=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F
M;VQD97)S+G!H<#HT,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(D)U<V-A<B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ."!T96UP;&%T97,O
M;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")396%R8V@@)7,B"FUS9W-T<B`B0G5S8V%R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($]P=&EO
M;G,B"FUS9W-T<B`B3W!C:?-N<R!D;R!U<W5A<FEO(@H*(SH@<V5A<F-H+G!H
M<#HR-C4*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(E)E<W5L=&%D
M;W,@9&$@8G5S8V$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C$T('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E
M96XB"FUS9W-T<B`B5FES=&\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.CD*;7-G:60@(E-E;&5C="(*;7-G<W1R(")396QE8V-I;VYA<B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW,`HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G<W1R(")1=6ET
M87(@82!S96QE8V-I\VXB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B
M4V5L96-C:6]N92!U;FAA(&ED96YT:61A9&4B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+V9I96QD<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&9I
M96QD(@IM<V=S='(@(E-E;&5C8VEO;F%L87,@=&]D87,B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@(E%U:71A<B!A('-E;&5C8VGS
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N
M9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB4V5L96-C
M:6]N87(@87,@9F]N=&5S(&1E(&1A=&]S(&1A<R!A>&5N9&%S(&1E(&5N9&5R
M97IO<R!P87)A(&5N9V%D:7(@92`B"B)B=7-C87(@96YD97)E>F]S(&1E(&-O
M<G)E;RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED
M(")396QE8W0@86QL(@IM<V=S='(@(E-E;&5C8VEO;F%L87,@=&]D87,B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X
M<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(B(*(D5L:7AA(&$@;W)D92!D
M92!B=7-C82!N87,@87AE;F1A<R!D92!E;F1E<F5Z;W,@8V%N9&\@97AP86YD
M82!E;F1E<F5Z;W,N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT
M7W-E;&5C="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A8V-O
M=6YT(@IM<V=S='(@(E%U:71A<B!A('-E;&5C8VGS;B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S
M='(@(E%U:71A<B!A('-E;&5C8VGS;B(*"B,Z('1E;7!L871E<R]S879E:6UA
M9V4O<V%V96EM86=E+FEN8SHY"FUS9VED(")396QE8W0@=&AE(&=A;&QE<GD@
M=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C
M="!T:&4@;6%I;"!S97)V97(@='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C=&5D($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(D%X96YD87,@9&4@
M96YD97)E>F]S('-E;&5C8VEO;F%D87,Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<R"FUS9VED(")396YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#0*
M(RP@9G5Z>GD*;7-G:60@(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S
M='(@(DEN9F]R;6%C:?-N(&1O('-E<G9I9&]R(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#,Q"FUS9VED(")396YD($UE<W-A9V4B"FUS9W-T<B`B16YV:6%R
M(&$@;65N<V%X92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,#,*;7-G
M:60@(E-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S
M96YD97(_(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PHC+"!F=7IZ
M>0IM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")#87)T869O;"!D
M87,@;65N<V%X97,@96YV:6%D87,Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E
M;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB
M"FUS9W-T<B`B0V%R=&%F;VP@9&%S(&UE;G-A>&5S(&5N=FEA9&%S.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,34S"FUS9VED(")397)V97(B"FUS9W-T<B`B4V5R=FED;W(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!A
M;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:?-N(&1O
M('-E<G9I9&]R(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C(S"B,L(&9U>GIY"FUS9VED(")397)V97(Z(@IM<V=S='(@(E-E<G9I9&]R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@<')E
M9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D
M96QE=&4@;65S<V%G97,N(@IM<V=S='(@(B(*(D5S=&%B;&5C92!A<R!P<F5F
M97)E;F-I87,@<&%R82!A<R!A8V-I\VYS('%U92!O8V]R<F5N(&-A;F1O(&UO
M=F$@;W4@96QI;6EN92`B"B)M96YS87AE<RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3(Y"FUS9VED(")3970@=&AE(%@M4')I;W)I='D@:&5A9&5R
M('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S$*(RP@9G5Z>GD*;7-G:60@(E-H87)E($9O
M;&1E<G,B"FUS9W-T<B`B0V%R=&%F;VQE<R(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S
M(@IM<V=S='(@(D-A<G1A9F]L(&1A<R!M96YS87AE<R!E;G9I861A<SHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@
M;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*;7-G:60@(B(*(E-H;W5L9"!L
M87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N
M(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC
M:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D>2!O9B!T97AT+W!L
M86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D871A/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$S"FUS9VED(")3:&]U
M;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S879I;F<@
M82!D<F%F=#\B"FUS9W-T<B`BOT1E8F4@<&5C:&%R<V4@82!X86YE;&$@9&4@
M<F5D86-C:?-N(&1E<W!O:7,@9&4@9V%R9&%R('5N(&)O<G)A9&]R/R(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U<B!0
M1U`@<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S
M(&)Y(&1E9F%U;'0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B
M"FUS9W-T<B`B0V]M<')I;6ER('3S9&]L;W,@8V%R=&%F;VQE<R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8W"FUS9VED(")3:&]W($%L
M;"!(96%D97)S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM<V=I
M9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(DUO<W1R87(@87,@96QI;6EN861A
M<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED
M(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHW,`HC+"!F=7IZ>0IM<V=I9"`B4VAO
M=R!-86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I
M\VX@<&5R<V]A;"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*
M(RP@9G5Z>GD*;7-G:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B
M"FUS9W-T<B`B4W5B<V-R:6)I<G-E(/-S(&-A<G1A9F]L*&5S*2(*"B,Z(&9O
M;&1E<G,N<&AP.C(Y.`IM<V=I9"`B4VAO=R!5;G-U8G-C<FEB960B"FUS9W-T
M<B`B36]S=')A<B!A<R!S=6)S8W)I8VGS;G,@8V%N8V5L861A<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#@*;7-G:60@(E-H;W<@86X@:6-O;B!T
M;R!A;&QO=R!S=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S86=E
M<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,#(*
M;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S
M='(@(DUO<W1R87(@=6YH82!L96YD82!N82!L:7-T82!D82!C86EX82!D92!C
M;W)R96\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T,`IM<V=I9"`B
M4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE<W-A9V5S(&]N;'D_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#@*;7-G:60@(E-H
M;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-S<*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA
M:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.CDU"FUS9VED(")3:&]W('1H92!);6%G97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4T
M"FUS9VED(")3:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(X"FUS9VED
M(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C8*;7-G:60@(E-H
M;W=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(E-I7WIE(@IM<V=S='(@
M(E1A;6'Q;R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*
M(RP@9G5Z>GD*;7-G:60@(E-I9VYE9"(*;7-G<W1R(")486UA\6\B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ
M92(*;7-G<W1R(")486UA\6\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3;W)T(&)Y($%R<FEV86PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C8*(RP@9G5Z
M>GD*;7-G:60@(E-O<G0@8GD@1G)O;2!!9&1R97-S(@IM<V=S='(@(D5N9&5R
M97IO(&1O(')E;6ET96YT92(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z-#$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@365S
M<V%G92!3:7IE(@IM<V=S='(@(E!O<B!T86UA\6\@9&$@;65N<V%X92(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S8*(RP@
M9G5Z>GD*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R(")396X@87-U
M;G1O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHS,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B
M1NUO(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHR,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S(@IM<V=S
M='(@(D5N9&5R97IO(&1O(')E;6ET96YT92(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S<&%M<V5L96-T+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B4W!A;2!F;VQD
M97(Z(@IM<V=S='(@(DQI>&\Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S0V"FUS9VED(")3<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T
M<B`B0V%R86-T97)E<R!E<W!E8VEA:7,B"@HC.B!S96%R8V@N<&AP.C$S,PIM
M<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N(&YO="!B92!E9&ET
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,T,PIM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`B0V]M<')O8F%R
M(&$@;W)T;V=R86;M82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHT-@IM<V=I9"`B4W!E;&P@0VAE8VME<B(*;7-G<W1R(")#;W)R96-T
M;W(@;W)T;V=RX69I8V\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-#@@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS
M9VED(")3<&5L;"!C:&5C:R!C;VUP;&5T92(*;7-G<W1R(")2979I<VGS;B!D
M92!O<G1O9W)A9NUA(&-O;7!L971A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0W,0IM<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE
M;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T<B`B17)R;W,@;W)T;V=RX69I8V]S
M('!O<B!P86YT86QL82!D=7)A;G1E(&$@<F5V:7-I\VXN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4Q,B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C4R"FUS9VED(")3=&%R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHS,3$*;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T
M:6]N97)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHR.`IM<V=I9"`B4W1A=&EO;F5R>2!T>7!E.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S,*
M;7-G:60@(E-T871I;VYE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")3
M=')I<"!!='1A8VAM96YT(@IM<V=S='(@(D%C;VUP8?%A<B!U;B!A<G%U:79O
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S,@IM<V=I9"`B4W1R:7`@
M;&EN96)R96%K<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHS-PHC+"!F=7IZ>0IM<V=I9"`B4W5B7VIE
M8W0B"FUS9W-T<B`B07-U;G1O(@H*(SH@;65S<V%G92YP:'`Z,C8X('1H<F5A
M9"YP:'`Z,34P('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C4*
M(SH@;&EB+U-E87)C:"YP:'`Z,S@*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B
M07-U;G1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B
M4W5B:F5C="!&:65L9"(*;7-G<W1R(")#86UP;R!D;R!A<W5N=&\B"@HC.B!S
M96%R8V@N<&AP.C,Q."!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI
M;F,Z,3@*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@
M(E-U8FUI="(*;7-G<W1R(")!<W5N=&\B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E<BAS
M*2(*;7-G<W1R(")3=6)S8W)I8FER<V4@\W,@8V%R=&%F;VPH97,I(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#`@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@W
M"FUS9VED(")3=6-C97-S(@IM<V=S='(@(D-O<G)E8W1A;65N=&4B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E
M<W1I;VYS(@IM<V=S='(@(E-U>&5S=&GS;G,B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C8R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*
M;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#`P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0P,PIM<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*
M;7-G:60@(E-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B
M4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#$Y"B,L(&9U>GIY
M"FUS9VED(")495]X="(*;7-G<W1R(")497AT;R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HR-CD*;7-G:60@(E1E;G1A=&EV93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E
M;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV96QY($%C
M8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O
M<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E<FUS
M(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS
M,`IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT;R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-30*;7-G:60@(E1H92!&<F]M.B!C;VQU;6X@;V8@=&AE
M(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HU,S(*;7-G:60@(B(*(E1H92!)34%0('-E<G9E
M<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@875T:&5N=&EC871I
M;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"FUS9VED(")4:&4@36%C:6YT;W-H
M(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(D5L:6UI;F]U<V4@82!I9&5N=&ED861E
M(%PB)7-<(B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HW-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R(")'87)D;W5S92!A(&ED96YT:61A9&4@7"(E<UPB
M+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C0S"FUS9VED(")4:&4@871T86-H;65N
M="!W87,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-CD*;7-G:60@(E1H92!C86QE;F1A<B!D871A(&ES(&EN
M=F%L:60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I9"`B(@HB5&AE(&-O;7!O<V4@=VEN
M9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U
M<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#(*;7-G
M:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E
M;&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA
M;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M
M960@=&\@7"(E<UPB+B(*;7-G<W1R(")/<R!C87)T869O;"AE<RD@7"(E<UPB
M(&-A;6)I87+A<V5L;&5S(&\@;F]M92!A(%PB)7-<(BXB"@HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,3`W"FUS9VED("(B"B)4:&4@8W5R<F5N="!L:7-T
M(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO
M="!B92!R971R:65V960B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3(S
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9')A9G0@:&%S(&)E96X@<V%V
M960@=&\@=&AE(%PB)7-<(B!F;VQD97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,SD*;7-G:60@(E1H92!E=F5N="!W87,@
M861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*
M;7-G<W1R(")%;&EM:6YO=7-E(&$@:61E;G1I9&%D92!<(B5S7"(B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O
M;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B3R!C87)T869O
M;"!<(B5S7"(@>&$@97AI<W1E(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A
M:6YS(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A
M=7-E("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*(D\@;F]M92!D;R!C87)T869O;"!<(B5S
M7"(@8V]N=.EN(&-A<F%C=&5R97,@;F]N(';A;&ED;W,N($ES=&\@<&]D92!C
M875S87(@(@HB<')O8FQE;6%S+B!#;VYT86-T92!C;R!A9&UI;FES=')A9&]R
M(&1O('-I<W1E;6$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4V"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U
M="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B0W)E
M;W5S92!O(&-A<G1A9F]L(%PB)7-<(B!P97)O('9O<W1E9&4@;F]N(&5S=.$@
M<W5B<V-R:71O(&$@96PN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!D96QE=&5D
M(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N(@IM<V=S
M='(@(D5L:6UI;F]U<V4@;R!C87)T869O;"!<(B5S7"(@<&5R;R!N;VX@<V4@
M8V%N8V5L;W4@82!S^F$@<W5B<V-R:6-I\VXN(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9"(*;7-G<W1R(").;VX@<V4@8W)E;W4@;R!C87)T869O;"!<(B5S7"(N($5S
M=&$@9F]I(&$@<F5S<&]S=&$@9&\@<V5R=FED;W(B"@HC.B!L:6(O1F]L9&5R
M+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(D$@8V%R<&5T82!<(B5S7"(@;F]N(&9O:2!E;&EM:6YA
M9&$N($ES=&$@9F]I(&$@<F5S<&]S=&$@9&\@<V5R=FED;W(B"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+B(*;7-G<W1R(")/
M(&-A<G1A9F]L(%PB)7-<(B!F;VD@8W)E861O(&-O<G)E8W1A;65N=&4N(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS
M9W-T<B`B3R!C87)T869O;"!<(B5S7"(@9F]I(&5L:6UI;F%D;R!C;W)R96-T
M86UE;G1E+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0U,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E
M;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")/(&-A<G1A9F]L(%PB)7-<(B!C
M86UB:?-U<V5L;&4@;R!N;VUE(&-O<G)E8W1A;65N=&4@82!<(B5S7"(N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDR"FUS9VED(")4:&4@9F]L
M;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@=&AI<R!P87)T.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7W-A=F5I;6%G
M95]W:6XN:G,Z,3(*;7-G:60@(B(*(E1H92!I;6%G92!S879E('=I;F1O=R!C
M86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B
M<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B(@HB5&AE
M(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@
M:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-0IM<V=I9"`B5&AE
M(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R(&UE
M<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C4Q"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D
M('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B
M5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A
M9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!M86EL8F]X("5S(&ES(&%L<F5A
M9'D@96UP='DN(@IM<V=S='(@(D\@8V%R=&%F;VP@7"(E<UPB('AA(&5X:7-T
M92(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(T-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S
M*2!E>&-E961S(&9E=&-H('-I>F4@;&EM:70N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`S"B,L(&9U>GIY"FUS
M9VED(")4:&4@;65S<V%G92!B96EN9R!C;VUP;W-E9"!H87,@8F5E;B!C;&]S
M960N($5X:71I;F<N(@IM<V=S='(@(D$@;65N<V%X92!Q=64@97-T86)A(')E
M9&%C=&%N9&\@<&5C:&]U<V4N(%-A[6YD;RXB"@HC.B!M97-S86=E+G!H<#HQ
M-#@*(RP@9G5Z>GD*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(D5L:6UI;F]U<V4@82!I9&5N=&ED861E(%PB)7-<(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(D=A
M<F1O=7-E(&$@:61E;G1I9&%D92!<(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE
M<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@)7,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]O<&5N7W-M:6UE7W=I;BYJ<SHQ,"!T
M96UP;&%T97,O<&=P+V]P96Y?<&=P7W=I;BYJ<SHQ,`IM<V=I9"`B(@HB5&AE
M('!A<W-P:')A<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y
M;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I
M;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<F%W('1E>'0@;V8@=&AE
M(%!'4"!0=6)L:6,@2V5Y(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E
M<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T
M=&%C:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8T"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI
M<W0@:6X@=&AE(%II<"!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HU-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('-E;F1E
M<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S=&EN9R!A($UE<W-A9V4@1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N("(*(F9R;VT@>6]U('=H96X@>6]U(&AA
M=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S92!C;&EC:R`E<R!T;R!S96YD
M('1H92`B"B)N;W1I9FEC871I;VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-CD*;7-G:60@(E1H92!S97)V
M97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES
M(&EM86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FIS.C$P-`HC+"!F=7IZ>0IM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L
M9"!N;W0@8F4@<F5P;&%C960N(@IM<V=S='(@(DYO;B!S92!P=6ED;R!S=6)S
M=&ET=>UR(&$@<VEN871U<F$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YJ<SHQ,#(*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F
M=6QL>2!R97!L86-E9"XB"FUS9W-T<B`B02!S:6YA='5R82!S=6)S=&ET=>UU
M<V4@8V]R<F5C=&%M96YT92XB"@HC.B!A='1A8VAM96YT+G!H<#HU.0IM<V=I
M9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M("(B"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&%D9&5D
M+B(*;7-G<W1R(")'87)D;W5S92!A(&ED96YT:61A9&4@7"(E<UPB+B(*"B,Z
M('-T871I;VYE<GDN<&AP.C8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B16QI;6EN;W5S92!A(&ED96YT:61A9&4@7"(E<UPB(@H*(SH@<W1A
M=&EO;F5R>2YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A=&5D+B(*;7-G<W1R
M(")%;&EM:6YO=7-E(&$@:61E;G1I9&%D92!<(B5S7"(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,38Y"FUS9VED(")4:&4@=&%S:R!H87,@8F5E
M;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M('1E>'0@;V8@=&AE(&UE<W-A9V4B"FUS9W-T<B`B8F]R<F%R(&$@;65N<V%X
M92(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S
M<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T
M=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!F=7IZ
M>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92(*;7-G<W1R
M(")2961I<F5C8VEO;F%R(&5S=&$@;65N<V%X92(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U
M-`HC+"!F=7IZ>0IM<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T<B`B02!S:6YA
M='5R82!S=6)S=&ET=>UU<V4@8V]R<F5C=&%M96YT92XB"@HC.B!L:6(O34E-
M12]6:65W97(O86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@
M;F\@86QT97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?
M;6%I;&)O>"YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN
M('1H:7,@;6%I;&)O>"XB"FUS9W-T<B`B3F]N(&AA:2!M96YS87AE<R!N97-T
M82!C86EX82!D92!C;W)R96\N(@H*(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@
M(E1H97)E(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8Q,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)(
M;W5B;R!U;B!P<F]B;&5M82#S(&)A;&5I<F%R(&$@8V%I>&$@9&\@8V]R<F5O
M("5S+B!%<W1A(&9O:2!A(')E<W!O<W1A(&1O("(*(G-E<G9I9&]R(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N
M(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@HB2&]U8F\@=6X@<')O
M8FQE;6$@\R!B86QE:7)A<B!A(&-A:7AA(&1O(&-O<G)E;RX@17-T82!F;VD@
M82!R97-P;W-T82!D;R`B"B)S97)V:61O<B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HV,C$*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H
M92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(B(*(DAO=6)O('5N('!R;V)L96UA(/,@8F%L96ER87(@82!C86EX82!D
M;R!C;W)R96\N($5S=&$@9F]I(&$@<F5S<&]S=&$@9&\@(@HB<V5R=FED;W(B
M"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S
M(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S
M97)V97(@<V%I9"(*;7-G<W1R("(B"B)(;W5B;R!U;B!E<G)O(/,@8V]P:6%R
M(&%S(&UE;G-A>&5S('!A<F$@7"(E<UPB+B!%<W1A(&9O:2!A(')E<W!O<W1A
M(&1O("(*(G-E<G9I9&]R(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Y."!L:6(O
M365S<V%G92YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD
M97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(B(*(DAO=6)O('5N(&5R<F\@\R!E;&EM:6YA<B!A<R!M96YS87AE
M<R!D;R!C87)T869O;"!<(B5S7"(N($5S=&$@9F]I(&$@<F5S<&]S=&$@(@HB
M9&\@<V5R=FED;W(B"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H
M92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)(;W5B;R!U;B!E<G)O(/,@
M96QI;6EN87(@87,@;65N<V%X97,@9&\@8V%R=&%F;VP@7"(E<UPB+B!%<W1A
M(&9O:2!A(')E<W!O<W1A("(*(F1O('-E<G9I9&]R(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C(Q,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R(")(;W5B;R!U;B!E<G)O<B#S
M(&5L:6UI;F%R(&%S(&UE;G-A>&5S+B!%<W1A(&9O:2!A(')E<W!O<W1A(&1O
M('-E<G9I9&]R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.CDY"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B2&]U8F\@=6X@97)R
M;R#S('9I<W5A;&EZ87(@82!M96YS87AE('-O;&EC:71A9&$N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR
M:6-H960N<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")(;W5B;R!U;B!E<G)O
M(/,@=FES=6%L:7IA<B!E<W1A('!A<G1E(&1A(&UE;G-A>&4B"@HC.B!L:6(O
M365S<V%G92YP:'`Z-30U(&QI8B]-97-S86=E+G!H<#HU.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE
M<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE
M("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(DAO=6)O('5N(&5R<F\@\R!M
M87)C87(@87,@;65N<V%X97,@;F\@8V%R=&%F;VP@7"(E<UPB+B!%<W1A(&9O
M:2!A(')E<W!O<W1A("(*(F1O('-E<G9I9&]R(@H*(SH@9F]L9&5R<RYP:'`Z
M,38U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R(")(;W5B;R!U;B!E<G)O(/,@
M9V%R9&%R(&\@8F]R<F%D;W(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C$S-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")(
M;W5B;R!U;B!E<G)O(/,@=FES=6%L:7IA<B!A(&UE;G-A>&4@<V]L:6-I=&%D
M82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!T87-K.B`E<RXB"FUS9W-T<B`B2&]U8F\@=6X@97)R;R#S('9I
M<W5A;&EZ87(@82!M96YS87AE('-O;&EC:71A9&$N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$U,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`B2&]U8F\@=6X@97)R;R#S
M(&5N=FEA<B!A('/Z82!M96YS87AE.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S
M7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B
M(@HB2&]U8F\@=6X@97)R;R#S(&UO=F5R(&UE;G-A>&5S(&$@7"(E<UPB+B!)
M<W1A(&9O:2!A(')E<W!O<W1A(&1O('-E<G9I9&]R(@H*(SH@8V]M<&]S92YP
M:'`Z,3(T-`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A
M=FEN9R!T:&ES(&UE<W-A9V4@87,@82!D<F%F="XB"FUS9W-T<B`B2&]U8F\@
M=6X@97)R;R#S('9I<W5A;&EZ87(@97-T82!P87)T92!D82!M96YS87AE(@H*
M(SH@8V]M<&]S92YP:'`Z,3`P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM<V=S
M='(@(DAO=6)O('5N(&5R<F\@\R!E;G9I87(@82!S^F$@;65N<V%X93H@)7,B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B2&]U8F\@=6X@97)R;R#S(&5N=FEA
M<B!A('/Z82!M96YS87AE.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I
M;BYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!N;R!T97AT(&EN
M('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(DAO=6)O('5N(&5R<F\@\R!V
M:7-U86QI>F%R(&5S=&$@<&%R=&4@9&$@;65N<V%X92(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@
M:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP"FUS9VED("(B"B)4:&ES($A434P@
M;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM
M86=E<R!A<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED(")4:&ES(%!'4"!0=6)L
M:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P-"!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,3$X"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ-#,@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-PHC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3<S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HS,30*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@
M:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@
M=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT
M:6YU93\B"FUS9W-T<B`B27-T;R!P;V1E(&QE=F%R(&%L9_IN('1E;7!O+B"_
M17-T82!S96=U<F\@9&4@<75E(&1E<V5X82!C;VYT:6YU87(_(@H*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M
M97-S86=E(&-O;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$P"FUS9VED("(B"B)4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B
M965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,30*;7-G:60@(E1H
M:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E
M96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,`IM<V=I9"`B(@HB5&AI<R!M97-S
M86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N
M+"!B=70@=&AE(&9O<FUA="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@=6YK;F]W
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S$U
M"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(T,"!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HS-3`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA
M="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S`*;7-G:60@(E1H:7,@;65S
M<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-
M24U%(&9O<FUA="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,C`U(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C0Q-@IM<V=I9"`B
M5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'
M4"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ
M-#,*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG
M;F5D('9I82!3+TU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,3,Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,X
M"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('9I82!3
M+TU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(P,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3$*;7-G:60@(E1H:7,@
M;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N(@IM<V=S='(@
M(B(*"B,Z(&UE<W-A9V4N<&AP.C(Q,0IM<V=I9"`B5&AI<R!M97-S86=E('1O
M(@IM<V=S='(@(D$@;65N<V%X92!P87)A(@H*(SH@86-L+G!H<#HT-@IM<V=I
M9"`B5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3`Y"B,L(&9U>GIY"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N(@IM<V=S='(@(D$@>&%N
M96QA(&1E8F4@8VAA;6%R<V4@9&5N9&4@82!X86YE;&$@9&4@<F5D86-C:?-N
M(@H*(SH@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A9"!$
M:7-P;&%Y(@IM<V=S='(@(E9I<W5A;&EZ87(B"@HC.B!T:')E860N<&AP.C<V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C(*;7-G:60@(E1H<F5A9"!6:65W
M(@IM<V=S='(@(E9E:2!P;VQO(&;M;R(*"B,Z(&UE<W-A9V4N<&AP.C(V-"!M
M86EL8F]X+G!H<#HV,#8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHR,B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H+G!H
M<#HR-@IM<V=I9"`B5&\B"FUS9W-T<B`B4&%R82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,3D*(RP@9G5Z>GD*;7-G:60@(E1O($%D9')E<W,B"FUS
M9W-T<B`B16YD97)E>F\@9&\@<F5M:71E;G1E(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S(V"FUS9VED("(B"B)4;R!S96QE8W0@
M;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I('=H:6QE("(*(F-L:6-K:6YG+B(*;7-G<W1R("(B
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C$S-`IM<V=I9"`B(@HB5&\@=7-E
M(&$@5$Q3(&-O;FYE8W1I;VXL('EO=2!M=7-T(&)E(')U;FYI;F<@82!V97)S
M:6]N(&]F(%!(4"`U+C`N-B!O<B`B"B)H:6=H97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PHC+"!F=7IZ>0IM
M<V=I9"`B5&]T86P@071T86-H;65N=',@4VEZ93HB"FUS9W-T<B`B06YE>&]S
M(@H*(SH@9F]L9&5R<RYP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")4<F%S:"!F
M;VQD97(B"FUS9W-T<B`B3&EX;SHB"@HC.B!T96UP;&%T97,O<')E9G,O=')A
M<VAS96QE8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM<V=S='(@
M(DQI>&\Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV-2!L:6(O475O=&$O
M;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N9"YP:'`Z-S(*(SH@
M;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T82]C;W5R:65R+G!H
M<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*;7-G:60@(E5N86)L92!T
M;R!R971R:65V92!Q=6]T82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R(")396X@<F5S<&]N9&5R
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA
M;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")-96YS87AE<R!S96X@<F5S<&]N
M9&5R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@(E5N
M9&5L971E(@IM<V=S='(@(E)E8W5P97)A<B(*"B,Z(&UA:6QB;W@N<&AP.C4X
M.2!M86EL8F]X+G!H<#HV,#(@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$R"FUS
M9VED(")5;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(DYO;B!S92!E
M<W!E8VEF:6-O=2!N:6YG^FX@9&5S=&EN871A<FEO(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA
M;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&UA
M:6QB;W@N<&AP.C4V-0IM<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N:VYO=VX@24U!4"!R97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E
M<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV,S4*;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G
M<W1R("(B"@HC.B!M86EL8F]X+G!H<#HV,3@*(RP@9G5Z>GD*;7-G:60@(E5N
M:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@(DYO;B!S92!E<W!E8VEF:6-O=2!N
M:6YG^FX@9&5S=&EN871A<FEO(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E5N;&]A
M9"!087-S<&AR87-E(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H
M<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")396X@;F]M92(*"B,Z(&UE
M<W-A9V4N<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS
M,@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N
M<V5E;B(*;7-G<W1R(").;VX@=FES=&$B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O;2!&;VQD
M97(H<RDB"FUS9W-T<B`B0V%N8V5L87(@82!S=6)S8W)I8VGS;B!D;RAS*2!C
M87)T869O;"AE<RDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU.#0*;7-G:60@(E5P9&%T92!!='1A8VAM96YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C`*;7-G
M:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-3@@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*;7-G
M:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(D5M<')E9V%R('5N('9A
M;&]R('!R961E=&5R;6EN861O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U-@HC+"!F=7IZ>0IM<V=I9"`B57-E($E-05`@9F]L9&5R('-U8G-C<FEP
M=&EO;G,_(@IM<V=S='(@(E5S87(@87,@<W5B<V-R:6-I\VYS(/-S(&-A<G1A
M9F]L97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,U"B,L(&9U>GIY
M"FUS9VED(")5<V4@5FER='5A;"!4<F%S:"!&;VQD97(_(@IM<V=S='(@(D)A
M;&5I<F%R(&$@<&%P96QE:7)A(&1O(&QI>&\B"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,30R"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(E5S
M=6%R:6\B"@HC.B!A8VPN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E8VEF:65D
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<W"FUS9VED(")5<V5R;F%M
M92(*;7-G<W1R(")5<W5A<FEO(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`B57-U87)I;R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<W"B,L(&9U>GIY"FUS9VED(")6:65W(@IM<V=S='(@(E9E<B`E<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.CDR(&QI8B]-24U%+U9I97=E<B]T
M;F5F+G!H<#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G
M<W1R(")697(@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!(5$U,
M(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B4F5D86-T
M87(@;65N<V%X97,@;G5N:&$@>&%N96QA(.$@<&%R=&4N(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C@*(RP@9G5Z>GD*;7-G:60@(E9I
M97<@365S<V%G97,B"FUS9W-T<B`B365N<V%X97,@;F]V87,B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW-PIM<V=I9"`B5FEE=R!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE=R!097)S;VYA;"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!4:')E860B"FUS
M9W-T<B`B1NUO(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V-0IM<V=I9"`B5FEE=R!4
M:'5M8FYA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HT,3@*(RP@9G5Z>GD*;7-G:60@(E9I97<@871T86-H;65N="!I;B!A
M('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")2961A8W1A<B!M96YS87AE<R!N
M=6YH82!X86YE;&$@X2!P87)T92XB"@HC.B!L:6(O34E-12]6:65W97(O<F5L
M871E9"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E9I97<@8V]N=&5N="!I;B!A
M('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")2961A8W1A<B!M96YS87AE<R!N
M=6YH82!X86YE;&$@X2!P87)T92XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,30P"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(B(*"B,Z(&9O
M;&1E<G,N<&AP.C,X,"!M86EL8F]X+G!H<#HU,S0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E9I97<@;65S<V%G97,@:6X@)7,B"FUS9W-T<B`B5F5R
M(&%S(&UE;G-A>&5S(&5N(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP
M86=E<V5L96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I
M<W!L87D@869T97(@;&]G:6XZ(@IM<V=S='(@(E9I<W1A(&]U(&-A:7AA(&1O
M(&-O<G)E;R!A(&UO<W1R87(@9&5S<&]I<R!D92!I;FEC:6%R(&$@<V5S:?-N
M.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S`*(RP@9G5Z>GD*
M;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R(")697(@)7,B"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")6:65W('1H
M92!);6%G97,B"FUS9W-T<B`B5F5R(&%S(&UE;G-A>&5S(&5N(@H*(SH@<V5A
M<F-H+G!H<#HR-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I<G1U
M86P@1F]L9&5R(%PB)7-<(B!C<F5A=&5D('-U8V-E<V9U;&QY+B(*;7-G<W1R
M(")/(&-A<G1A9F]L(%PB)7-<(B!F;VD@96QI;6EN861O(&-O<G)E8W1A;65N
M=&4N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@;&EB+TE-
M05`O5')E92YP:'`Z,3,X(&QI8B])34%0+U1R964N<&AP.C$U,0HC.B!L:6(O
M24U!4"]4<F5E+G!H<#HQ-3,@;&EB+TE-05`O5')E92YP:'`Z,34W(&QI8B])
M34%0+U1R964N<&AP.C$U.`HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-CD@;&EB
M+TE-05`O5')E92YP:'`Z,SDS(&QI8B])34%0+U1R964N<&AP.C0S,PHC+"!F
M=7IZ>0IM<V=I9"`B5FER='5A;"!&;VQD97)S(@IM<V=S='(@(D-R96%R('5N
M(&-A<G1A9F]L(@H*(SH@<V5A<F-H+G!H<#HR-#4*;7-G:60@(E9I<G1U86P@
M1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN(@IM<V=S='(@(B(*"B,Z(&QI8B]6
M1F]L9&5R+G!H<#HQ-S4@;&EB+U9&;VQD97(N<&AP.C$X,`IM<V=I9"`B5FER
M='5A;"!)3D)/6"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,38*;7-G
M:60@(E9I<G1U86P@24Y"3U@@1F]L9&5R(@IM<V=S='(@(B(*"B,Z(&UA:6QB
M;W@N<&AP.C0U,B!L:6(O5D9O;&1E<BYP:'`Z,3$T(&QI8B]61F]L9&5R+G!H
M<#HQ,3D*;7-G:60@(E9I<G1U86P@5')A<V@B"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L(%1R87-H($9O
M;&1E<B(*;7-G<W1R(")"86QE:7)A<B!A('!A<&5L96ER82!D;R!L:7AO(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U
M86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,S<T"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%V:7-O
M(@H*(SH@;&]G:6XN<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(D)E;G9I9&]S+V%S(&$@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C$Y"FUS9VED("(B"B)7:&%T('-H;W5L9"!W
M92!D;R!W:71H('-P86T@;65S<V%G97,@869T97(@=&AE>2!H879E(&)E96X@
M<F5P;W)T960@87,@<W!A;2`B"B)O<B!I;FYO8V5N=#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<R-PIM<V=I9"`B(@HB5VAE;B!D
M96QE=&EN9R!M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L
M9&5R(&EN<W1E860@;V8@;6%R:VEN9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM
M<V=S='(@(B(*(D-A;F1O('-E(&5L:6UI;F5N(&UE;G-A>&5S+""_8F]T86QA
M<R#S(&QI>&\@96X@=')O<75E<R!D92!M87)C86QA<R!C;VUO("(*(F5L:6UI
M;F%D87,_+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@
M(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO
M=2!W86YT('1O('-T87)T(&]N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL
M('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE;B!S
M96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA
M:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R97-S
M97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7:&ET
M96QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@(EEE
M<R(*;7-G<W1R(")3:2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H
M;6%I;%]L;V=I;BYP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@86)O
M=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H
M<RDZ(@IM<V=S='(@(D5S=.$@:6YT96YT86YD;R!E;&EM:6YA<B!O<R!S96=U
M:6YT97,@8V%R=&%F;VQE<SHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD
M97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U(&%R
M92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D
M(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R(")%<W3A
M(&EN=&5N=&%N9&\@96QI;6EN87(@;W,@<V5G=6EN=&5S(&-A<G1A9F]L97,Z
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ
M.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T
M92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2XB"FUS9W-T<B`B17-TX2!I;G1E
M;G1A;F1O(&5L:6UI;F%R(&]S('-E9W5I;G1E<R!C87)T869O;&5S.B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E
M<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S
M='(@(D5S=&%L;&4@8V%M8FEA;F1O(&\@;F]M92#S(&-A<G1A9F]L.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R"FUS9VED(")9
M;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`B17-T
MX2!C<F5A;F1O('5N('-U8F-A<G1A9F]L(&5N("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")9;W4@87)E(&-R96%T
M:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BXB"FUS9W-T<B`B17-TX2!C<F5A;F1O
M('5N('-U8F-A<G1A9F]L(&1E(&[M=F5L('-U<&5R:6]R+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C,R,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@9F]L9&5R<RXB"FUS9W-T<B`B17-TX2!C<F5A;F1O
M('5N('-U8F-A<G1A9F]L(&1E(&[M=F5L('-U<&5R:6]R+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L9&5R<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ
M,S4*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@(@IM<V=S
M='(@(D5S=&%L;&4@8V%M8FEA;F1O(&\@;F]M92#S(&-A<G1A9F]L.B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S
M='(@(D9O:2!D861O(&1E(&)A:7AA(&-O<G)E8W1A;65N=&4@9&4@7"(E<UPB
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@
M<&QA8V5H;VQD97)S(&EN('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T
M:&4@(@HB8W5R<F5N="!M97-S86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG
M;F%T=7)E+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T
M;W-?86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R
M964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@
M=V5R92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V.0IM<V=I9"`B66]U(&1O(&YO="!H
M879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E
M<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@;65S<V%G97,N(@IM<V=S='(@
M(E1E;B`E<R!M96YS87AE<R!N;W9A<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A;&5R="YI;F,Z,PIM<V=I9"`B66]U(&AA=F4@,2!N97<@;65S<V%G92XB
M"FUS9W-T<B`B5&5N(#$@;65N<V%X92!N;W9A+B(*"B,Z(&-O;7!O<V4N<&AP
M.C0Y-`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@86QR96%D>2!S=6)M:71T
M960@=&AI<R!P86=E+B(*;7-G<W1R(")496X@,2!M96YS87AE(&YO=F$N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,3$U"FUS9VED
M("(B"B)9;W4@:&%V92!A="!L96%S="!O;F4@871T86-H;65N="!S96QE8W1E
M9"!T:&%T('EO=2!D:61N)W0@=7!L;V%D('EE="X@07)E("(*(GEO=2!S=7)E
M('EO=2!W86YT('1O('-E;F0@=&AI<R!M97-S86=E('=I=&AO=70@=&AE<V4@
M871T86-H;65N=',_(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-S0*
M;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L
M9&5R.B(*;7-G<W1R(")496X@8V]R<F5O(&YO=F\@;F\@<V5G=6EN=&4@8V%R
M=&%F;VPZ(@H*(SH@;&EB+TE-4"YP:'`Z,3`W.0IM<V=I9"`B66]U(&AA=F4@
M;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.B(*;7-G<W1R(")4
M96X@8V]R<F5O(&YO=F\@;F]S('-E9W5I;G1E<R!C87)T869O;&5S.B(*"B,Z
M(&-O;7!O<V4N<&AP.C$U,PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@96YT
M97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS9W-T<B`B1&5B92!P;_%E
M<B!P;VQO(&UE;F]S('5N(&1E<W1I;F%T87)I;R!N;R!C86UP;R!087)A.B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,P,@IM<V=I9"`B(@HB66]U
M(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A
M=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Y"FUS9VED("(B"B)9;W4@;75S
M="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T
M92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-C0@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS9VED(")9;W4@;75S="!S
M96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB"FUS9W-T<B`B4')I;65I
M<F\@<V5L96-C:6]N92!U;B!C;W)R96\@9&4@9&5S=&EN;RXB"@HC.B!F971C
M:&UA:6QP<F5F<RYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E-E;&5C
M8VEO;F4@=6YH82!I9&5N=&ED861E('!A<F$@96QI;6EN87(N(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(E!R:6UE:7)O
M('-E;&5C8VEO;F4@=6X@96YD97)E>F\N(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N
M:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M
M97-S86=E(&9I<G-T+B(*;7-G<W1R(")0<FEM96ER;R!S96QE8V-I;VYE('5N
M:&$@;65N<V%X92P@<&]L;R!M96YO<RXB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z,3,*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!R
M96-I<&EE;G0N(@IM<V=S='(@(D5S<&5C:69I<75E('5N(&1E<W1I;F%T87)I
M;R!N;R!C86UP;R!087)A.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FIS.C(Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&%T(&QE87-T(&]N92!F:6QE('1O(&%T=&%C:"XB"FUS9W-T<B`B4')I;65I
M<F\@97-P96-I9FEQ=64@;R!A<G%U:79O('%U92!V86D@86-H96=A<BXB"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@96YA8FQE9"!I
M;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-86EL;&]G+G!H<#HQ,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(EEO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N(@IM
M<V=S='(@(E)E9&ER96-C:6]N87(@97-T82!M96YS87AE(@H*(SH@;&EB+TUA
M:6QL;V<N<&AP.C$T,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S+B(*;7-G<W1R(")2961I
M<F5C8VEO;F%R(&5S=&$@;65N<V%X92(*"B,Z(&QI8B]&;VQD97(N<&AP.C4P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R:6)E
M9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS
M9W-T<B`B3F]N(&9O:2!S=6)S8W)I=&\@82!<(B5S7"(N($5S=&$@9F]I(&$@
M<F5S<&]S=&$@9&\@<V5R=FED;W(B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E
M9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*
M;7-G<W1R(").;VX@9F]I(&1A9&\@9&4@8F%I>&$@9&4@7"(E<UPB+B!%<W1A
M(&9O:2!A(')E<W!O<W1A(&1O('-E<G9I9&]R(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F
M=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")&;VD@<W5B<V-R
M:71O(&-O<G)E8W1A;65N=&4@82!<(B5S7"(B"@HC.B!L:6(O1F]L9&5R+G!H
M<#HU-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U
M;&QY('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R(")&;VD@9&%D
M;R!D92!B86EX82!C;W)R96-T86UE;G1E(&1E(%PB)7-<(B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHY.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE
M(@IM<V=S='(@(DYO;64@8V]M<&QE=&\Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C4P"FUS9VED(")9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S$@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<V"FUS9VED(")9;W5R(%!R:79A=&4@
M2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<Q"B,L(&9U>GIY"FUS9VED(")9
M;W5R(%!U8FQI8R!+97DB"FUS9W-T<B`B3F]M92!C;VUP;&5T;SHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"B,L(&9U>GIY"FUS9VED(")9;W5R
M(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S
M='(@(B(*(D\@96YD97)E>F\@<75E('9A:2!E;7!R96=A<B!N;R!C86UP;R!<
M(E)E<W!O;F1E<B`M85PB("A<(E)E<&QY+51O7"(I.B`\:3XB"B(H;W!C:6]N
M86PI/"]I/B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#D*;7-G
M:60@(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L
M96-T+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!A8V-O=6YT<SHB"FUS
M9W-T<B`B07,@<_IA<R!I9&5N=&ED861E<SHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI
M;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB
M"FUS9W-T<B`B(@HB3R!S974@;F%V96=A9&]R(&YO;B!A9&UI=&4@82!O<&-I
M\VX@9&4@:6UP<F5S:?-N+B!0<F5S:6]N92!#;VYT<F]L+T]P8VGS;B`K("(*
M(E`@<&%R82!I;7!R:6UI<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M
M97-S86=E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N8W)Y
M<'1S96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T:6]N
M(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB"FUS
M9W-T<B`B3R!C87)T869O;"!<(B5S7"(@9F]I(&5L:6UI;F%D;R!C;W)R96-T
M86UE;G1E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@
M(EEO=7(@<VEG;F%T=7)E.B(*;7-G<W1R(")3:6YA='5R83HB"@HC.B!M97-S
M86=E+G!H<#HR.#@@8V]M<&]S92YP:'`Z,3(X-"!M86EL8F]X+G!H<#HU-#D@
M;&EB+T-O;7!O<V4N<&AP.C@Q.`IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S
M='(@(EM396X@87-U;G1O72(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(P-0HC+"!F=7IZ>0IM<V=I9"`B7T)C8R(*;7-G<W1R(")#0T\B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*(RP@9G5Z>GD*;7-G
M:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B3&ES=&$@;F5G<F$B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-30*(RP@9G5Z>GD*;7-G:60@
M(E]#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*(RP@9G5Z
M>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B16QI;6EN87(B"@HC.B!L:6(O
M24U0+G!H<#HY-SD*(RP@9G5Z>GD*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@
M(D-A<G1A9F]L97,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHX,0HC+"!F=7IZ>0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@(DED96YT
M:61A9&4B"@HC.B!L:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G
M<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#(P"B,L(&9U>GIY"FUS9VED(")?
M3&]G(&]U="(*;7-G<W1R(")096-H87(@82!S97-I\VXB"@HC.B!M97-S86=E
M+G!H<#HS.#0*(RP@9G5Z>GD*;7-G:60@(E]-97-S86=E(%-O=7)C92(*;7-G
M<W1R(")#\V1I9V\@9F]N=&4@9&$@;65N<V%X92(*"B,Z(&QI8B])35`N<&AP
M.CDW-@HC+"!F=7IZ>0IM<V=I9"`B7TYE=R!-97-S86=E(@IM<V=S='(@(DUE
M;G-A>&5S(&YO=F%S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")?4')I;G0B"FUS9W-T<B`B
M26UP<FEM:7(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@Y"FUS9VED(")?
M4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-#$X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")?4F5F<F5S:"`E<R(*;7-G<W1R(")!
M8W1U86QI>F%R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E]297!L>2(*;7-G<W1R(")297-P
M;VYD97(B"@HC.B!L:6(O24U0+G!H<#HY.#$*(RP@9G5Z>GD*;7-G:60@(E]3
M96%R8V@B"FUS9W-T<B`B0G5S8V%R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#,Q"B,L(&9U>GIY"FUS9VED(")?4V5N9"!-97-S86=E(@IM<V=S='(@(D5N
M=FEA<B!A(&UE;G-A>&4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")?5&AR96%D(@IM<V=S
M='(@(D;M;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Q
M-@HC+"!F=7IZ>0IM<V=I9"`B7U1O(@IM<V=S='(@(E!A<F$B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B
M7U5N9&5L971E(@IM<V=S='(@(E)E8W5P97)A<B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B
M7U9I97<@5&AR96%D(@IM<V=S='(@(D;M;R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3<V"FUS9VED(")A9&1R97-S964@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#0P"B,L(&9U>GIY
M"FUS9VED(")A='1A8VAM96YT(@IM<V=S='(@(D%C;VUP8?%A<B!U;B!A<G%U
M:79O(@H*(SH@=FEE=RYP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(F%T=&%C:&UE
M;G1S+GII<"(*;7-G<W1R(")!;F5X;W,B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU,3,*;7-G:60@(F)Y=&5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR,#`*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T
M<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W,@IM
M<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$V-`IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C`*;7-G:60@(F-O
M;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$Y-@IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38X"FUS9VED(")D871A
M(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,C(T"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB
M"FUS9W-T<B`B9&4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@P"FUS9VED(")H
M;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,C`T"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C$X.`IM<V=I9"`B:6YT97)N86P@<V]F='=A
M<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(Y('!G<"YP:'`Z
M-CD*;7-G:60@(FME>2(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HQ-C$*
M(RP@9G5Z>GD*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R(")#86EX82!D
M92!C;W)R96\B"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H
M<#HT-C8*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T<B`B3F]M92(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N
M92(*;7-G<W1R(")N:6YG^FXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*;7-G<W1R(")O=2(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HR,38*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,3(*;7-G:60@(G)E;6]T92!E
M<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3@T"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B
M<W!E;&QI;F<@97)R;W(B"FUS9W-T<B`B97)R;R!D92!O<G1O9W)A9NUA(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S
M<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B97)R;W,@9&4@;W)T;V=R86;M82(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E
M;2!E<G)O<B(*;7-G<W1R(")E<G)O(&1E(&]R=&]G<F%F[6$B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,C`X"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G
M<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B
M>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B3&ES=&$@;F5G<F$B"@HC.B!L:6(O
M1FEL=&5R+G!H<#HV,0IM<V=I9"`B>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+W!O+V-A7T53+G!O````````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#,V-3(R-@`Q,#0Q-S,V,C<V-``P,3<Q-38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R!)35`@0V%T
M86QA;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#,@06YG96QS
M($=U:6UE<N`*(R!!;F=E;',@1W5I;65RX"`\06YG96QS+D=U:6UE<F%`=6%B
M+F5S/BP@,C`P,RX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M
M5F5R<VEO;CH@2&]R9&4@,BXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,RTP,BTQ."`P.3HS.2LP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($%N9V5L
M<R!'=6EM97+@(#Q!;F=E;',N1W5I;65R84!U86(N97,^7&XB"B),86YG=6%G
M92U496%M.B!#871A;&%N(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-
M12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY
M"FUS9VED("(@("`@("!#8SH@(@IM<V=S='(@(B`@("!097(@83H@(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0Q-0IM<V=I9"`B("`@("`@5&\Z("(*;7-G<W1R
M("(@("`@4&5R(&$Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#,*;7-G:60@
M(B`@("!$871E.B`B"FUS9W-T<B`B("`@1&%T83H@(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C0P-@IM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R("(@("`@("!$
M93H@(@H*(SH@;6%I;&)O>"YP:'`Z-#(R('1E;7!L871E<R]F;VQD97)S+VAE
M860N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3(*;7-G:60@(B!3
M=6)J96-T.B`B"FUS9W-T<B`B($%S<W5M<'1E.B`B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S`*;7-G:60@(B!I;B`B"FUS9W-T<B`B
M(&$@(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHQ,@IM<V=I9"`B(R(*;7-G<W1R("(C(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B`O("4N,F9-
M0B`@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ-3$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D($UE<W-A9V5S(@IM<V=S='(@
M(B5D(&1E("5D($UI<W-A=&=E<R(*"B,Z(&UA:6QB;W@N<&AP.C$W-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N
M(&1E;&5T960N(@IM<V=S='(@(E9I<W5A;&ET>F%R(&5L(&UI<W-A=&=E('%U
M86X@96QS(&9I;'1R97,@:&%G:6X@97-T870@87!L:6-A=',N(@H*(SH@;&EB
M+U-P86TN<&AP.C$W.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D%Q=65S
M="!M:7-S871G92!H82!E<W1A="!R97!O<G1A="!C;VT@<W!A;2!A;6(@96P@
M=F]S=')E(&%D;6EN:7-T<F%D;W(@9&5L("(*(G-I<W1E;6$N(@H*(SH@;&EB
M+U-P86TN<&AP.C$U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G
M<W1R("(B"B)!<75E<W0@;6ES<V%T9V4@:&$@97-T870@<F5P;W)T870@8V]M
M('-P86T@86UB(&5L('9O<W1R92!A9&UI;FES=')A9&]R(&1E;"`B"B)S:7-T
M96UA+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S
M<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M(D%Q=65S="!M:7-S871G92!H82!E<W1A="!R97!O<G1A="!C;VT@<W!A;2!A
M;6(@96P@=F]S=')E(&%D;6EN:7-T<F%D;W(@9&5L("(*(G-I<W1E;6$N(@H*
M(SH@;&EB+U-P86TN<&AP.C$U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM
M<V=S='(@(B(*(D%Q=65S="!M:7-S871G92!H82!E<W1A="!R97!O<G1A="!C
M;VT@<W!A;2!A;6(@96P@=F]S=')E(&%D;6EN:7-T<F%D;W(@9&5L("(*(G-I
M<W1E;6$N(@H*(SH@;6%I;&)O>"YP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D('1O("5D(&]F("5D($UE<W-A9V5S(@IM<V=S='(@(B5D(&%L("5D
M(&1E("5D($UI<W-A=&=E<R(*"B,Z(&UA:6QB;W@N<&AP.C8T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@
M9F]L9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@:F$@97AI<W1E
M:7@N($QA(&-A<G!E=&$@)7,@;F\@:&$@97-T870@<F5N;VUE;F%D82XB"@HC
M.B!L:6(O365S<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I
M;%]M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD
M97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*
M;7-G<W1R("),82!C87)P971A("5S(&5S(')E;F]M96YA(&$@<')I;F-I<&D@
M9&4@;65S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@
M=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H
M87,@=&5N=&%T:79E;'D@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!<(B5S7"(N(@IM<V=S='(@(DQA(&-A<G!E=&$@7"(E<UPB(&AA(&5S
M=&%T(')E;F]M96YA9&$@<V%T:7-F86-T\G)I86UE;G0@82!<(B5S7"(N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!W:7-H97,@=&\@86UM96YD("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T
M97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+B(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HR.#4@;65S<V%G92YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?=&]P+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@
M*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P
M.V1E)FYB<W`[)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$S,PIM<V=I9"`B*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@
M=&\@;F5X="!S8W)E96XN*2(*;7-G<W1R("(H07!L:6-A<B!E;',@8V%N=FES
M(&D@<&%S<V%R(&$@;&$@<&%N=&%L;&$@<V5G_&5N="XI(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@
M86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN
M*2(*;7-G<W1R("(H4F5B=71J87(@=&]T<R!E;',@8V%N=FES(&D@=&]R;F%R
M(&$@;&$@<&%N=&%L;&$@9&4@<F5D86-C:?,N*2(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*$A434PI(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I
M9"`B*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG+G!H<#HR
M.#`*;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F
M=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("`B"B)#
M:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L
M:65D+BDB"FUS9W-T<B`B(@HB*%1O<FYA<B!A(&QA('!A;G1A;&QA(&1E(')E
M9&%C8VGS(&1E<W!RZ7,@9"=A<&QI8V%R('1O=',@96P@8V%N=FES(&9E=',@
M9FEN<R`B"B)A<77M+B!%;',@8V%N=FES(&$@;&$@<&%N=&%L;&$@86-T=6%L
M($Y/('-E<F%N(&%P;&EC871S+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"B,L
M(&9U>GIY"FUS9VED("(B"B(H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG
M(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92`B
M"B)C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T
M<B`B(@HB*%1O<FYA<B!A(&QA('!A;G1A;&QA(&1E(')E9&%C8VGS(&1E<W!R
MZ7,@9"=A<&QI8V%R('1O=',@96P@8V%N=FES(&9E=',@9FEN<R`B"B)A<77M
M+B!%;',@8V%N=FES(&$@;&$@<&%N=&%L;&$@86-T=6%L($Y/('-E<F%N(&%P
M;&EC871S+BDB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*B(*;7-G
M<W1R("(J($%F97)G:7(@87%U97-T<R!F96YT(&-L:6,@82!/2R`J(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,#8*;7-G:60@(BH@
M4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@(BH@4VD@=7,@
M<&QA=2P@<V5L96-C:6]N974@;&$@861R9>=A*&-E<RDJ(@H*(SH@;6%I;&)O
M>"YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B3&$@:61E;G1I=&%T(%PB)7-<(B!H82!E<W1A
M="!E;&EM:6YA9&$N(@H*(SH@;&EB+U-P86TN<&AP.C$X,`HC+"!F=7IZ>0IM
M<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M
M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D%Q
M=65S="!M:7-S871G92!H82!E<W1A="!R97!O<G1A="!C;VT@<W!A;2!A;6(@
M96P@=F]S=')E(&%D;6EN:7-T<F%D;W(@9&5L("(*(G-I<W1E;6$N(@H*(SH@
M;&EB+U-P86TN<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA
M<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(B"B)!<75E
M<W0@;6ES<V%T9V4@:&$@97-T870@<F5P;W)T870@8V]M('-P86T@86UB(&5L
M('9O<W1R92!A9&UI;FES=')A9&]R(&1E;"`B"B)S:7-T96UA+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-S(*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(D%Q=65S="!M:7-S871G92!H82!E<W1A="!R
M97!O<G1A="!C;VT@<W!A;2!A;6(@96P@=F]S=')E(&%D;6EN:7-T<F%D;W(@
M9&5L("(*(G-I<W1E;6$N(@H*(SH@;&EB+U-P86TN<&AP.C$U,@HC+"!F=7IZ
M>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN
M(@IM<V=S='(@(B(*(D%Q=65S="!M:7-S871G92!H82!E<W1A="!R97!O<G1A
M="!C;VT@<W!A;2!A;6(@96P@=F]S=')E(&%D;6EN:7-T<F%D;W(@9&5L("(*
M(G-I<W1E;6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q.0HC+"!F
M=7IZ>0IM<V=I9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B0V%RX&-T97)S
M($5S<&5C:6%L<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C(*(RP@
M9G5Z>GD*;7-G:60@(C$P,#`@8VAA<F%C=&5R<R(*;7-G<W1R(")#87+@8W1E
M<G,@17-P96-I86QS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,`HC
M+"!F=7IZ>0IM<V=I9"`B,C4P(&-H87)A8W1E<G,B"FUS9W-T<B`B0V%RX&-T
M97)S($5S<&5C:6%L<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C$*
M(RP@9G5Z>GD*;7-G:60@(C4P,"!C:&%R86-T97)S(@IM<V=S='(@(D-A<N!C
M=&5R<R!%<W!E8VEA;',B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B02!L87)G92!I;6%G92!N86UE
M9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4P"FUS9VED
M("(B"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@
M82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE("(*(G)E8VEP:65N="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4*
M;7-G:60@(D%.1"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3DP"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W"FUS9VED(")!8V-E<'0@
M<F5Q=65S="!A;F0@861D(&ET('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3,*;7-G:60@(D%C8V5P
M=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-3<*;7-G:60@(D%C8V5P=&5D.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(D%C8V]U
M;G0G<R!N86UE.B(*;7-G<W1R(").;VT@9&4@;&$@:61E;G1I=&%T.B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C`@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<S,`HC+"!F=7IZ>0IM<V=I9"`B06-T:6]N<R(*;7-G<W1R
M(")!8V-I\R(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(P,"!L:6(O34E-
M12](96%D97)S+G!H<#HR,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%D9"`E<R!T;R!M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B069E9VER(&$@
M;&$@3&QI8G)E=&$@9"=A9')E8V5S("@E<RDB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*(RP@9G5Z>GD*;7-G:60@(D%D9"!S
M;W5R8V4B"FUS9W-T<B`B869E9VER(&9O;G0B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*
M;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z
M(&-O;7!O<V4N<&AP.C$R-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R(")3)VAA
M(&%D:G5N=&%T('5N(&%R>&EU+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.3@*;7-G:60@(B(*(D%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y
M('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D
M97(@(@HB;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I
M;VXN<&AP.C8R"B,L(&9U>GIY"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T
M:6]N(&1E=&%I;',B"FUS9W-T<B`B26YF;W)M86-I\R!097)S;VYA;"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDS"FUS9VED(")!9&1I=&EO
M;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I
M=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM<V=I
M9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@
M8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N=&%C=',N<&AP
M.C@U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M
M<&]S92]R961I<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R("),;&EB<F5T82!D)T%D<F5C97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S
M='(@(DQL:6)R971A(&0G061R96-E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.#D*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A
M9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N
M97<@(@HB;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L
M>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@
M96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")!;&PB"FUS9W-T<B`B5&]T<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*;7-G:60@
M(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W
M:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G
M<W1R("(B"B)4;W1S(&5L<R!M:7-S871G97,@9&4@;&$@8V%R<&5T82AE<RD@
M<V5G_&5N="AS*2!E<R!D97-C87)R96=A<F%N(&5N('5N87)X:74@(@HB34)/
M6#H@(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP
M.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y
M;W5R(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@
M<&5R;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB5&]T<R!E;',@
M;6ES<V%T9V5S(&1E(&QA('9O<W1R82!C87)P971A7"(E<UPB(&%M8B!MZ7,@
M9&4@)7,@9&EE<R`B"B)D)V%N=&EG=6ET870@<V5R86X@96QI;6EN871S('!E
M<FUA;F5N=&UE;G0N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E
M7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP.C4Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E('1H
M86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@(B(*
M(E1O=&5S(&QE<R!C87)P971E<R!S96YT+6UA:6P@86UB(&WI<R!D92`E<R!M
M97-O<R!D)V%N=&EG=6ET870@<V5R86X@(@HB96QI;6EN861E<RXB"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T
M960N(@IM<V=S='(@(B(*(E1O=&5S(&QE<R!C87)P971E<R!S96YT+6UA:6P@
M86UB(&WI<R!D92`E<R!M97-O<R!D)V%N=&EG=6ET870@<V5R86X@(@HB96QI
M;6EN861E<RXB"@HC.B!A8VPN<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!;&P@<FEG:'1S(&]N(&9O;&1E<B!<(B5S7"(@<W5C8V5S<V9U
M;&QY(')E;6]V960@9F]R('5S97(@7"(E<UPB+B(*;7-G<W1R("),82!C87)P
M971A(%PB)7-<(B!H82!E<W1A="!R96YO;65N861A('-A=&ES9F%C=/)R:6%M
M96YT(&$@7"(E<UPB+B(*"B,Z(&QI8B]A<&DN<&AP.C<V"FUS9VED(")!;&QO
M=R!&;VQD97(@0W)E871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U;&5S
M('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$P"FUS9VED(")!
M;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<R(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU.#0*;7-G:60@(D%L=V%Y<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-34W"B,L(&9U>GIY"FUS9VED(")!;'=A>7,@
M<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(")3)VAA(&%D:G5N=&%T('5N(&%R
M>&EU+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HU,#4*;7-G:60@(B(*(D%N(&5R
M<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T
M86-H;65N="X@5&AE($E-05`@<V5R=F5R("(*(G-A:60Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")!;B!U
M;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N
M;W1E+B(*;7-G<W1R(")3)VAA('!R;V1U:70@=6X@97)R;W(@9&5S8V]N96=U
M="!A;"!A9F5G:7(@96P@;F]U(')E9VES=')E+B(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HS.#<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C
M=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(E,G
M:&$@<')O9'5I="!U;B!E<G)O<B!D97-C;VYE9W5T(&%L(&%F96=I<B!E;"!N
M;W4@<F5G:7-T<F4N(@H*(SH@;65S<V%G92YP:'`Z-3`P(&UA:6QB;W@N<&AP
M.C<Q-"!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.CD*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,U"B,Z('1E;7!L871E<R]M86EL8F]X+VQE
M9V5N9"YI;F,Z-@IM<V=I9"`B06YS=V5R960B"FUS9W-T<B`B0V]N=&5S=&%T
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B06YS
M=V5R960@;65S<V%G97,B"FUS9W-T<B`B36ES<V%T9V5S(&-O;G1E<W1A=',B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@9G5Z>GD*
M;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B07!L:6-A<B!&:6QT<F5S
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!<'!L>2!&:6QT97)S('1O("5S(@IM<V=S
M='(@(D%P;&EC87(@1FEL=')E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S
M('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`B07!L:6-A<B!R96=L97,@9&4@
M9FEL=')A="!A(&PG:6YI8VEA<B!L82!S97-S:?,N(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L>2!F
M:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/R(*;7-G
M<W1R(")!<&QI8V%R(')E9VQE<R!D92!F:6QT<F%T('%U86X@<F5F<F5S<75E
M=2!L82!B^G-T:6$N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR
M-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@9G5Z>GD*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y
M/R(*;7-G<W1R("*_17-TX"!S96=U<B!Q=64@9&5S:71J82!F97(@86EX\C\B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE
M;F1E9"$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_(@IM<V=S='(@
M(K]%<W3@('-E9W5R('%U92!D97-I=&IA(&9E<B!A:7CR/R(*"B,Z(&UE<W-A
M9V4N<&AP.C0P-R!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV
M.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9
M(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`BOT5S=.`@<V5G=7(@
M<75E(&1E<VET:F$@96QI;6EN87(@4$5234%.14Y414U%3E1A<75E<W1S(&UI
M<W-A=&=E<S\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U
M>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y4
M3%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`BOT5S=.`@<V5G
M=7(@<75E(&1E<VET:F$@96QI;6EN87(@4$5234%.14Y414U%3E1A<75E<W1S
M(&UI<W-A=&=E<S\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H
M:7,@9F]L9&5R/R(*;7-G<W1R("*_17-TX"!S96=U<B!Q=64@9&5S:71J82!B
M=6ED87(@87%U97-T82!C87)P971A/R(*"B,Z(&QI8B])35`N<&AP.CDW,PHC
M+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y
M('EO=7(@<W!A;2!F;VQD97(_(@IM<V=S='(@(K]%<W3@('-E9W5R('%U92!D
M97-I=&IA(&)U:61A<B!A<75E<W1A(&-A<G!E=&$_(@H*(SH@;&EB+TE-4"YP
M:'`Z.38V"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(K]%<W3@('-E
M9W5R('%U92!D97-I=&IA(&)U:61A<B!A<75E<W1A(&-A<G!E=&$_(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T
M92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`BOT5S=.`@<V5G=7(@<75E(&1E
M<VET:F$@96QI;6EN87(@4$5234%.14Y414U%3E1A<75E<W1S(&UI<W-A=&=E
M<S\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHX,"!T
M96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW.0HC+"!F=7IZ>0IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE
M<W-A9V4@87,@:6YN;V-E;G0_(@IM<V=S='(@(K]%<W3@('-E9W5R('%U92!D
M97-I=&IA(&)U:61A<B!A<75E<W1A(&-A<G!E=&$_(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-S4@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-S0*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S('-P86T_(@IM
M<V=S='(@(K]%<W3@('-E9W5R('%U92!D97-I=&IA(&)U:61A<B!A<75E<W1A
M(&-A<G!E=&$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I
M9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(E!E<B!(;W)A(&0G07)R:6)A9&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E;F1I
M;F<B"FUS9W-T<B`B07-C96YD96YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4W,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@S"FUS9VED(")!<VLB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-3$Y"FUS9VED(")!='1A8V@B"FUS9W-T<B`B061J=6YT87(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S4*(RP@9G5Z>GD*;7-G:60@
M(D%T=&%C:"!&:6QE<R(*;7-G<W1R(")!9&IU;G1A<B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U-@IM<V=I9"`B071T86-H(&$@8V]P
M>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.0HC+"!F
M=7IZ>0IM<V=I9"`B071T86-H960@1FEL93HB"FUS9W-T<B`B061J=6YT87(B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#4Q(&QI8B]#;VUP;W-E+G!H<#HU,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB071T86-H960@9FEL92!<(B5S7"(@
M97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@
M871T86-H960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HS-S8*;7-G:60@(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE
M;F1A<B!R97%U97-T('EO=2!S96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C$V('1E;7!L871E<R]C;VUP;W-E+V%T
M=&%C:&UE;G1S+FEN8SHQ-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU,#8@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3<*
M;7-G:60@(D%T=&%C:&UE;G0B"FUS9W-T<B`B061J=6YT87(@87)X:74B"@HC
M.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*;7-G:60@
M(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<S"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ,#<S"FUS9VED(")!='1A8VAM96YT<R(*;7-G<W1R
M(")!9&IU;G1A<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#(*
M(RP@9G5Z>GD*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")!9&IU;G1A<B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"B,L(&9U
M>GIY"FUS9VED(")!='1E;G1I;VXB"FUS9W-T<B`B06-C:?,B"@HC.B!L:6(O
M075T:"]I;7`N<&AP.C0T"FUS9VED(")!=71H7VEM<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C0P"FUS9VED("(B"B)!=71O;6%T:6-A;&QY('-H
M;W<@:6UA9V5S(&EN($A434P@;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES
M(&EN(&UY("(*(F%D9')E<W-B;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3@*(RP@9G5Z>GD*;7-G:60@
M(D%V86EL86)L92!!9&1R97-S(&)O;VMS.B(*;7-G<W1R("),;&EB<F5T97,@
M9"=A9')E8V5S(&1I<W!O;FEB;&5S.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,C8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A8U]K('1O("5S(@IM
M<V=S='(@(E1O<FYA<B!A("5S(@H*(SH@=&AR96%D+G!H<#HQ,S<@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")"86-K('1O("5S(@IM<V=S='(@(E1O<FYA<B!A("5S(@H*
M(SH@=&AR96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S
M<V%G92!6:65W($EN9&5X(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,R
M"FUS9VED(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W)E8V]M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C
M8R(*;7-G<W1R(")"8V,B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HQ-C$*;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A
M='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM<V=S
M='(@(DQL:7-T82!N96=R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M,CD*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S
M<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/R(*;7-G<W1R("(B
M"@HC.B!L:6(O4V5A<F-H+G!H<#HT,@IM<V=I9"`B0F]D>2(*;7-G<W1R(")4
M97AT(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B
M0F]T:"(*;7-G<W1R(")!;6)D\W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C@W"FUS9VED(")";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F
M($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,C<R"FUS9VED(")#7VAA<G-E="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(D-A;&5N9&%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C`Q"FUS
M9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ.3D*
M;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R
M=F5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I86PN
M<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA
M>2`M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E
M(&EN('1H92!C=7)R96YT("(*(FUA:6QB;W@N(@IM<V=S='(@(B(*"B,Z(&9O
M;&1E<G,N<&AP.C(X-"!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(U-0HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(Q('1E;7!L
M871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.0HC.B!T96UP;&%T97,O
M<VUI;64O<&%S<W!H<F%S92YI;F,Z,C$@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C@V"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHQ,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8V"FUS9VED(")#86YC96PB"FUS
M9W-T<B`B0V%N8V5LMVQA<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S-0HC
M.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#
M86YC96P@365S<V%G92(*;7-G<W1R(")#86YC96RW;&%R($UI<W-A=&=E(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")#86YC96QL:6YG('1H:7,@
M;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S
M+B(*;7-G<W1R("(B"B)#86YC96RW;&%N="!A<75E<W0@;6ES<V%T9V4@<F5B
M=71J87)E=2!P97)M86YE;G1E;65N="!E;"!S974@8V]N=&EN9W5T+B(*"B,Z
M(&UE<W-A9V4N<&AP.C(V-2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C(R,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U
M(&QI8B]396%R8V@N<&AP.C,P"FUS9VED(")#8R(*;7-G<W1R(")#8R(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G:60@(B(*(D-E<G1I
M9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I
M<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P,0HC+"!F=7IZ>0IM<V=I
M9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(E!E<G-O;F%L(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED(")#:&%N9V4B"FUS
M9W-T<B`B0V%N=FEA<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R(")#86YV:6%R('1O
M=&5S(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDR"B,L(&9U>GIY"FUS
M9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S='(@(D-R96%R($-A<G!E=&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS9VED("(B"B)#:&%N9V4@
M9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U
M('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A<F4@<V]R
M=&5D+B(*;7-G<W1R("(B"B)#86YV:6%R(&]P8VEO;G,@9&4@=FES=6%L:71Z
M86-I\R!T86QS(&-O;2!Q=6%N=',@;6ES<V%T9V5S('9E=7)E('!E<B!PX&=I
M;F$@(@HB:2!E;"!C<FET97)I(&1E(&-L87-S:69I8V%C:?,@9&5L<R!M:7-S
M871G97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY
M"FUS9VED(")#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG
M<RXB"FUS9W-T<B`B0V%N=FEA<B!L97,@8V]N9FEG=7)A8VEO;G,@9&5L('-E
M<G9I9&]R(&1E(&-O<G)E=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I
M9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD("(*
M(G)E<&QY('1O('EO=7(@96UA:6PN(@IM<V=S='(@(B(*(D-A;G9I87(@96P@
M;F]M+"!L)V%D<F7G82!E;&5C='+R;FEC82P@:2!L82!S:6=N871U<F$L('%U
M92!E;',@8V]N=&%C=&5S("(*(G9E=65N('%U86X@;&QE9V5I>&5N(&D@<F5S
M<&]N96X@96QS('9O<W1R97,@;6ES<V%T9V5S+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,C0*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,34*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T
M<B`B17AA;6EN87(@0V%R<&5T82AE<RD@<&5R($-O<G)E=2!.;W4B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO
M3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC
M.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O
M(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0V,PHC+"!F=7IZ>0IM<V=I9"`B0VAE8VL@<W!E;&QI;F<@
M8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R(")(:2!H82!H86=U
M="!U;B!E<G)O<B!A;"!E;G9I87(@96P@=F]S=')E(&UI<W-A=&=E.B`E<R(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G:60@(D-H
M;V]S92!!8W1I;VXZ(@IM<V=S='(@(D5S8V]L;&ER($%C8VGS.B(*"B,Z(&-O
M;F9I9R]S97)V97)S+G!H<"YD:7-T.C$X,@HC+"!F=7IZ>0IM<V=I9"`B0VAO
M;W-E(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@(D-A;G9I87(@;&5S(&-O;F9I
M9W5R86-I;VYS(&1E;"!S97)V:61O<B!D92!C;W)R974N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR,3<*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D
M9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M,S$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@
M(D5S8V]L;&ER($%C8VGS.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C,T.0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('1H92!A9&1R
M97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E<W-E<RXB"FUS9W-T
M<B`B17-C;VQL:74@;&$@;&QI8G)E=&$@9"=A8W)E8V5S(&$@=71I;&ET>F%R
M('%U86X@869E9VEU(&%D<F5C97,N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,CDS"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=&AE
M(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD
M:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB17-C;VQL:74@;"=O<F1R92!D
M92!L97,@;&QI8G)E=&5S(&0G861R96-E<R!A(&)U<V-A<B!Q=6%N(&5X<&%N
M9&EU(&%D<F5C97,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@
M=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N
M('9I97<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL
M;V%D('1H92!I;6%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z
M,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O("5S
M(&UA;F%G96UE;G0@<&%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0VQI8VL@)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<N(@IM<V=S='(@(E)E9&%C=&%R(&UI<W-A=&=E<R!E;B!U;F$@9FEN
M97-T<F$@87!A<G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M,38S"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@82!T
M:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S
M97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(E)E9&%C=&%R(&UI<W-A=&=E<R!E
M;B!U;F$@9FEN97-T<F$@87!A<G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E
M;&%T960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A
M=&4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M
M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,R,0HC+"!F=7IZ>0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO
M=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL
M(&9I96QD<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(D9E=2!C;&EC:R!A
M;"!D86UU;G0@9"=U;F$@9&4@;&5S('9O<W1R97,@;&QI8G)E=&5S(&0G861R
M96-E<R!S96QE8V-I;VYA9&5S(&D@(@HB9&5S<'+I<R!S96QE8V-I;VYE=2!E
M;',@8V%M<',@<&5L<R!Q=64@9&5S:71J974@8G5S8V%R+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C$W,0IM<V=I9"`B0VQI8VL@=&\@4V%V92!0
M1U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(P,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O
M9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.34P"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@
M861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N
M9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3$*
M;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@
M;65S<V%G92!T;R!B92!R96%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO9F5T8VAM86EL+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B0VQO
M<V4B"FUS9W-T<B`B3F]U(@H*(SH@8V]M<&]S92YP:'`Z.#(X(&-O;7!O<V4N
M<&AP.C$Q-#@*;7-G:60@(D-L;W-E('1H:7,@=VEN9&]W(@IM<V=S='(@(B(*
M"B,Z(&9O;&1E<G,N<&AP.C0R.0IM<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G
M<W1R(")#87)P971A(%1A;F-A;F1A(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"B,L
M(&9U>GIY"FUS9VED(")#;VQL87!S92(*;7-G<W1R(")#;VRW;&%P<V%R(%1O
M=&5S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G
M:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R(")#;VRW;&%P<V%R(%1O=&5S(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O
M;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S='(@(D-O;+=L87!S87(@5&]T97,@
M;&5S($-A<G!E=&5S(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS9VED(")#;VQL
M87!S92!&;VQD97(B"FUS9W-T<B`B0V]LMVQA<'-A<B!#87)P971A(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C4Q"FUS9VED(")#;VQO
M<B!);F1I8V%T;W(Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-CD*(RP@9G5Z>GD*;7-G:60@(D-O;7!L
M971E9"(*;7-G<W1R(").;W4B"@HC.B!C;VUP;W-E+G!H<#HX,C<@8V]M<&]S
M92YP:'`Z,3$T-PHC+"!F=7IZ>0IM<V=I9"`B0V]M<&]S92!A;F]T:&5R(&UE
M<W-A9V4B"FUS9W-T<B`B4F5D86-T87(@=6X@;6ES<V%T9V4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#,T"B,L(&9U>GIY"FUS9VED(")#;VUP;W-E
M(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")2961A
M8W1A<B!M:7-S871G97,@96X@=6YA(&9I;F5S=')A(&%P87)T+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S
M<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R
M('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE
M<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-PHC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)E(&UA
M:6P@<')E=FEE=R!O<'1I;VYS+B(*;7-G<W1R(")#86YV:6%R(&QE<R!C;VYF
M:6=U<F%C:6]N<R!D96P@<V5R=FED;W(@9&4@8V]R<F5U+B(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z,S<P"FUS9VED(")#;VYN96-T:6]N(&1R;W!P960@
M8GD@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,C,T"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F86EL
M960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E
M<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%,O34E-12!S=7!P;W)T(&9O
M<B`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,0IM<V=I9"`B0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S
M('-E87)C:&EN9RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED("(B"B)#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B
M92!C:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y
M;W4@(@HB=VAE;B!I="!A<G)I=F5S+B(*;7-G<W1R("(B"B)296=U;&%R('%U
M86X@97,@=F5R:69I8V%RX"!P97(@8V]R<F5U(&YO=2!I+"!S:2!N;W1I9FEC
M87(@;R!N;R!Q=6%N(&5S(')E8FEN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.38*;7-G:60@(D-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT
M;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EA<B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0HC+"!F=7IZ>0IM<V=I
M9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T<B`B0G5I9&%R(&QA(&-A<G!E=&$@
M4&%P97)E<F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-C,*;7-G:60@(D-O<G)E8W0B"FUS9W-T<B`B0V]R<F5G:7(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,30P"FUS9VED(")#;W)R96-T
M960@5&5X="(*;7-G<W1R(")497AT($-O<G)E9VET(@H*(SH@;&EB+TE-05`O
M0VQI96YT+G!H<#HS.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S(@IM
M<V=S='(@(DYO(',G:&%N('!O9W5T(&5L:6UI;F%R(&UI<W-A=&=E<R!D92`E
M<SH@)7,B"@HC.B!A='1A8VAM96YT+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E('1H92!61E,@8F%C:V5N9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S86=E<R!F<F]M
M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DYO(',G:&%N('!O
M9W5T(&5L:6UI;F%R(&UI<W-A=&=E<R!D92`E<SH@)7,B"@HC.B!L:6(O4V5S
M<VEO;BYP:'`Z,S$X"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@97AE8W5T
M92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R(")/<&5R86-I;VYS
M(&1E($UA;G1E;FEM96YT(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HU.`IM<V=I9"`B0V]U;&0@;F]T
M(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H
M:79E+B(*;7-G<W1R("(B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<S"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R
M;VT@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z,S$T
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,`IM
M<V=I9"`B0W)E871E(@IM<V=S='(@(D-R96%R(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E<B(*;7-G
M<W1R(")#<F5A<B!#87)P971A(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$S-PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E($ME>7,B"FUS9W-T<B`B0W)E
M87(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,30*(RP@9G5Z
M>GD*;7-G:60@(D-R96%T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")#<F5A
M<B!#87)P971A(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E
M;&5C="YI;F,Z,C8*;7-G:60@(D-R96%T92!A($YE=R!!8V-O=6YT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHQ,B!T
M96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*(RP@9G5Z>GD*;7-G
M:60@(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R(")#<F5A<B!U
M;F$@;F]V82!C87)P971A('!E<B!A(&QA(%!A<&5R97)A(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S
M+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F
M=',@9F]L9&5R(@IM<V=S='(@(D-R96%R('5N82!N;W9A(&-A<G!E=&$@9"=E
M<V)O<G)A;GES(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T
M+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0R
M"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R
M(")#<F5A<B!U;F$@;F]V82!C87)P971A(&1E(&-O<G)E=2!E;G9I870B"@HC
M.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C$R('1E;7!L871E
M<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE
M=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B0W)E87(@=6YA(&YO=F$@8V%R<&5T
M82!P97(@82!L82!087!E<F5R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C@*;7-G:60@(B(*(D-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G
M86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R
M<RP@(@HB86YD(&1E;&5T92!S<&%M+B(*;7-G<W1R("(B"B)#<F5A<B!R96=L
M97,@9&4@9FEL=')A="!P97(@;W)G86YI='IA<B!E;"!C;W)R974@96YT<F%N
M="P@8VQA<W-I9FEC87(M;&\@96X@(@HB8V%R<&5T97,@:2!E;&EM:6YA<B!S
M<&%M+B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-`HC
M+"!F=7IZ>0IM<V=I9"`B0W)E871E(&YE=R!S=&%T:6]N97)Y(@IM<V=S='(@
M(D-R96%R('5N82!N;W9A(&-A<G!E=&$@9&4@8V]R<F5U(&5N=FEA="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*;7-G:60@(D-R96%T92!S=&%T
M:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-U
M<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#4*;7-G:60@(D-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@
M9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*(RP@9G5Z>GD*;7-G:60@
M(D-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"XB"FUS9W-T<B`B4&5R<V]N
M86QI='IA<B!L82!T<F%M97-A(&1E(&-O<G)E=2!I(&]N(&1E<V%R(&5L<R!E
M<V)O<G)A;GES+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!E<G-O;F%L:71Z87(@;&5S('1A<W%U
M97,@82!E>&5C=71A<B!A;"!I;FEC:6%R('-E<W-I\R!E;B`E<RXB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$W"B,L(&9U
M>GIY"FUS9VED(")$871?92(*;7-G<W1R(")$871A(@H*(SH@;65S<V%G92YP
M:'`Z,C8R('1H<F5A9"YP:'`Z,30X"FUS9VED(")$871E(@IM<V=S='(@(D1A
M=&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4W"B,L(&9U>GIY
M"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")%;&EM:6YA=',B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,C8S"FUS9VED(")$96-L:6YE9#H@(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*(RP@9G5Z
M>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B16QI;6EN87(B"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z,3@*;7-G:60@
M(D1E9F%U;'0@4V5A<F-H($9I96QD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,C,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET
M97)I83HB"FUS9W-T<B`B0W)I=&5R:2!D92!C;&%S<VEF:6-A8VGS('!E<B!D
M969E8W1E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S,*;7-G:60@
M(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(D]R9')E(&1E
M(&-L87-I9FEC86-I\R!P97(@9&5F96-T93HB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S8U"B,L(&9U>GIY"FUS9VED(")$96QE9V%T960B"FUS
M9W-T<B`B16QI;6EN871S(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(T-"!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHX('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C(X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM
M<V=I9"`B1&5L971E(@IM<V=S='(@(D5L:6UI;F%R(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME
M>7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G<W1R(")%;&EM:6YA
M<B!#87)P971A*&5S*2(*"B,Z(&9O;&1E<G,N<&AP.C(X-0HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B16QI;6EN
M87(@0V%R<&5T82AE<RDB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!3=&%T:6]N97)Y(@IM
M<V=S='(@(D5L:6UI;F%R($-A<G!E=&$H97,I(@H*(SH@9F]L9&5R<RYP:'`Z
M-#$Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD97(B"FUS
M9W-T<B`B16QI;6EN87(@0V%R<&5T82AE<RDB"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-#,*;7-G:60@(D1E;&5T92!F971C:&5D(&UE
M<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8R.`IM<V=I9"`B1&5L971E(&9R;VT@
M;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V.`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&]L9"!L:6YK960@871T
M86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")%;&EM
M:6YA<B!L97,@8V%R<&5T97,@<V5N="UM86EL(&$@<')I;F-I<&D@9&4@;65S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`HC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@
M;V8@;6]N=&@_(@IM<V=S='(@(D5L:6UI;F%R(&QE<R!C87)P971E<R!S96YT
M+6UA:6P@82!P<FEN8VEP:2!D92!M97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C$W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<W!A;2!M97-S86=E
M<R(*;7-G<W1R(")%;&EM:6YA<B!M:7-S871G97,B"@HC.B!M97-S86=E+G!H
M<#HU,#,@;6%I;&)O>"YP:'`Z-S0P('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,C`*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS."!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C@*;7-G:60@(D1E;&5T960B
M"FUS9W-T<B`B16QI;6EN871S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHV,PIM<V=I9"`B1&5L971E9"!M97-S86=E<R(*;7-G<W1R(")-:7-S
M871G97,@96QI;6EN871S(@H*(SH@8V]M<&]S92YP:'`Z,S`W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB
M)7-<(BXB"FUS9W-T<B`B4R=H82!E;&EM:6YA="!U;B!A<GAI=2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG(&%N9"!-
M;W9I;F<@365S<V%G97,B"FUS9W-T<B`B16QI;6EN86YT(&D@;6]V96YT(&UI
M<W-A=&=E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3(*;7-G
M:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-30P"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3,R"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(D1E<V-E
M;F1E;G0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z
M,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V.0HC+"!F=7IZ>0IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B3W!C:6]N<R!D92!L)U5S=6%R:2(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW-PIM<V=I9"`B1&5T86EL<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C<W"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B"FUS9W-T
M<B`BOT%T96YU87(@<VEG;F%T=7)E<S\B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")6
M:7-U86QI='IA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-SD*;7-G
M:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S
M86=E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V
M"FUS9VED(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"B,L(&9U>GIY"FUS9VED
M(")$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_(@IM
M<V=S='(@(DUO<W1R87(@9FEN97-T<F$@9&4@;F]T:69I8V%C:?,@9&4@8V]R
M<F5U(&YO=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4X"FUS9VED
M(")$:7-P;&%Y('1H92!<(D5M<'1Y(%-P86U<(B!L:6YK(&EN('1H92!M96YU
M8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4P
M"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T
M:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")$:7-P;W-I=&EO
M;B(*;7-G<W1R(")/<&-I;VYS(&1E(%9I<W5A;&ET>F%C:?,B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C
M:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ-@IM<V=I9"`B1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA
M:6PB"FUS9W-T<B`B3F\@17AA;6EN87(@0V%R<&5T82AE<RD@<&5R($-O<G)E
M=2!.;W4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34R"FUS9VED(")$
M;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`W-0IM<V=I9"`B1&\@>6]U('=A
M;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`BOT1E<VET:F5U(&]B
M<FER(&%Q=65S=&$@8V%R<&5T83\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(S,@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z,3(V"FUS9VED(")$;VYE(@IM<V=S='(@(D%C86)A<B(*"B,Z(&QI
M8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3(*;7-G:60@(D1O=VYL;V%D
M($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,`IM<V=I9"`B1&]W
M;FQO860@1F]L9&5R*',I(@IM<V=S='(@(D1E<V-A<G)E9V%R($-A<G!E=&$H
M97,I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=
M(@IM<V=S='(@(D1E<V-A<G)E9V%R($-A<G!E=&$H97,I(@H*(SH@;&EB+TU)
M344O0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&
M;W)M870B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N
M<&AP.C<Q.2!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S='(@(D5S8F]R<F%N
M>2(*"B,Z(&9O;&1E<G,N<&AP.C,Y,@HC+"!F=7IZ>0IM<V=I9"`B1')A9G0@
M9F]L9&5R(@IM<V=S='(@(D-A<G!E=&$@9"=E<V)O<G)A;GES.B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS9VED(")$<F%F
M=',@9F]L9&5R.B(*;7-G<W1R(")#87)P971A(&0G97-B;W)R86YY<SHB"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`X"B,L(&9U>GIY"FUS9VED(")%
M+6UA:6P@061D<F5S<R(*;7-G<W1R(")!9')EYV$@16QE8W1R\FYI8V$B"@HC
M.B!L:6(O36%I;&)O>"YP:'`Z,S`Y"FUS9VED(")%3D0B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2
M.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHQ.0IM<V=I9"`B161I="(*;7-G<W1R(")%9&ET87(B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G
M:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(DQL:7-T82!N96=R82(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I
M9"`B161I="!&:6QT97)S(@IM<V=S='(@(D9I;'1R97,@9&4@0V]R<F5U(@H*
M(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN
M8SHQ-@IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@
M)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(D5D
M:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B161I=&%R(')E9VQE<R!D92!F
M:6QT<F%T(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$S"FUS
M9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(@IM<V=S='(@(D5D:71A<B!R
M96=L97,@9&4@9FEL=')A="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-C$*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG
M(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B161I="!Y
M;W5R('=H:71E;&ES="(*;7-G<W1R(")%9&ET87(@<F5G;&5S(&1E(&9I;'1R
M870B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S.0IM
M<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")!9')EYV$@16QE8W1R\FYI
M8V$B"@HC.B!L:6(O365S<V%G92YP:'`Z-C4W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G
M<W1R(")3)VAA;B!A;&QI8F5R870@=&]T<R!E;',@;6ES<V%T9V5S(&1E("5S
M+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED
M(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B0G5I9&%R($-A<G!E=&$H97,I
M(@H*(SH@9F]L9&5R<RYP:'`Z,C@V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!3
M96QE8W1E9"!&;VQD97)S(@IM<V=S='(@(D)U:61A<B!#87)P971A*&5S*2(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")%
M;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`B0G5I9&%R(&QA(&-A<G!E=&$@
M4&%P97)E<F$B"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@
M(D5M<'1Y(%]3<&%M(@IM<V=S='(@(D)U:61A<B!087!E<F5R82(*"B,Z(&QI
M8B])35`N<&AP.CDV-@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@7U1R87-H(@IM
M<V=S='(@(D)U:61A<B!087!E<F5R82(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED(")%
M;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,2!T96UP;&%T97,O<VUI;64O;F]T86-T
M:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3$*;7-G
M:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-#(*;7-G:60@(D5N8W)?
M>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Q-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4W"FUS
M9VED(")%;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,X-`IM
M<V=I9"`B16YD(&9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(D9I(&1E;"!M
M:7-S871G92!R965N=FEA="(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-#$*(RP@
M9G5Z>GD*;7-G:60@(D5N9"!M97-S86=E(@IM<V=S='(@(DUI<W-A=&=E<R!!
M;G1I8W,B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(DUI
M<W-A=&=E(')E96YV:6%T(&1E("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N
M=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-P86US96QE8W0N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N
M86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R("));G1R;V1U
M[W4@96P@;F]M(&1E(&QA(&YO=F$@8V%R<&5T82!D92!087!E<F5R82(*"B,Z
M('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S
M='(@(DEN=')O9'7O=2!E;"!N;VT@9&4@;&$@;F]V82!C87)P971A(&0G97-B
M;W)R86YY<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI
M;F,Z,C,*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT
M(&UA:6P@9F]L9&5R(@IM<V=S='(@(DEN=')O9'7O=2!E;"!N;VT@9&4@;&$@
M;F]V82!C87)P971A(&1E(&-O<G)E=2!E;G9I870B"@HC.B!T96UP;&%T97,O
M<')E9G,O=')A<VAS96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B26YT<F]D=>]U
M(&5L(&YO;2!D92!L82!N;W9A(&-A<G!E=&$@9&4@4&%P97)E<F$B"@HC.B!L
M:6(O4V5A<F-H+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B16YT:7)E($UE<W-A
M9V4B"FUS9W-T<B`B4F5D:7)I9VER($UI<W-A=&=E(@H*(SH@;65S<V%G92YP
M:'`Z,3DT(&-O;7!O<V4N<&AP.C$Q,S0@=&AR96%D+G!H<#HW,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("(B"B)%
M;"!R96=I<W1R92!<(B5S7"(@:&$@97-T870@869E9VET('-A=&ES9F%C=/)R
M:6%M96YT(&$@;&$@;&QI8G)E=&$@9"=A9')E8V5S(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S8@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,S@V"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<R(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B17)R;W(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0U
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C;VYN96-T:6YG('1O($E-
M05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R97!L>3H@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M,#$*(RP@9G5Z>GD*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D
M+B(*;7-G<W1R("),82!C87)P971A(%PB)7-<(B!H82!E<W1A="!E;&EM:6YA
M9&$@<V%T:7-F86-T\G)I86UE;G0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")#861A
M(#$U(&UI;G5T<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-SD*;7-G
M:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=O;G,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q"FUS9VED(")%=F5R>2`U
M(&UI;G5T97,B"FUS9W-T<B`B0V%D82`U(&UI;G5T<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.#,*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G
M<W1R(")#861A(&UI=&IA(&AO<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S@P"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B0V%D82!M:6YU
M="(*"B,Z(&9O;&1E<G,N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B17AP86YD
M(@IM<V=S='(@(D5X<&%N9&ER("(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A;F0@06QL(@IM<V=S='(@(D5X<&%N
M9&ER("(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS
M9VED(")%>'!A;F0@06QL($9O;&1E<G,B"FUS9W-T<B`B17AP86YD:7(@5&]T
M97,@;&5S($-A<G!E=&5S(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED(")%
M>'!A;F0@1F]L9&5R(@IM<V=S='(@(D5X<&%N9&ER($-A<G!E=&$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#`@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C4S"FUS9VED(")%>'!A;F0@3F%M97,B"FUS
M9W-T<B`B17AP86YD:7(@3F]M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#8S"FUS9VED(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN
M9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.#`*(RP@9G5Z>GD*;7-G
M:60@(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@
M:6X@=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T<B`B17AP86YD:7(@;"?@<F)R
M92!S96YC97(@<&5R(&1E9F5C=&4@96X@;&$@=FES=&$@9&4@8V%R<&5T97,N
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E
M8W0N:6YC.C$P,0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@
M(D5X<&%N9&ER("(*"B,Z(&QI8B])35`N<&AP.CDX-"!L:6(O24U0+G!H<#HY
M.#8*(RP@9G5Z>GD*;7-G:60@(D9?971C:"!-86EL(@IM<V=S='(@(DYO=2!#
M;W)R974B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z
M,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`HC+"!F=7IZ>0IM<V=I9"`B
M1F5T8V@@36%I;"(*;7-G<W1R(").;W4@0V]R<F5U(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@V.0HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@36%I;"!I
M;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B4F5D86-T87(@;6ES<V%T
M9V5S(&5N('5N82!F:6YE<W1R82!A<&%R="XB"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-#8*(RP@9G5Z>GD*;7-G:60@(D9E=&-H(&UE
M<W-A9V5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`B07!L:6-A<B!R96=L
M97,@9&4@9FEL=')A="!A(&PG:6YI8VEA<B!L82!S97-S:?,N(@H*(SH@;&EB
M+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&971C:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,B"FUS9W-T<B`B4R=H86X@
M86QL:6)E<F%T('1O=',@96QS(&UI<W-A=&=E<R!D92`E<RXB"@HC.B!L:6(O
M1F5T8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B36ES<V%T9V4@
M<F5E;G9I870@9&4@)7,B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#4@;&EB
M+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP.C(X.0IM<V=I
M9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"YP
M:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")&971C:&UA:6PZ(&YO(&YE=R!M97-S
M86=E<RXB"FUS9W-T<B`B5&5N:74@)7,@;6ES<V%T9V5S(&YO=7,N(@H*(SH@
M;&EB+TE-4"YP:'`Z.3DP"B,L(&9U>GIY"FUS9VED(")&:5]L=&5R<R(*;7-G
M<W1R(")&:6QT<F5S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-3`R('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C@R"B,L
M(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(D9I;'1R97,B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D9I
M;'1E<B!/<'1I;VYS(@IM<V=S='(@(D%L=')E<R!/<&-I;VYS(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D9I
M;'1E<B!3971T:6YG<R(*;7-G<W1R(")296=L97,@9&4@1FEL=')A="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#`*(RP@9G5Z>GD*;7-G:60@(D9I
M;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`B
M1FEL=')A<B!C;VYT:6YG=70@;V)S8^D@96X@96P@;6ES<V%T9V4N(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B1FEL
M=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(D9I
M;'1E<G,B"FUS9W-T<B`B1FEL=')E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+VYO=&%C=&EV92YI;F,Z,PIM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*;7-G
M:60@(D9I;F0B"FUS9W-T<B`B5')O8F%R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDP-0HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E
M(@IM<V=S='(@(E!R:6UE<F$@4.!G:6YA(@H*(SH@;6%I;&)O>"YP:'`Z,S0U
M"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(E!R:6UE<F$@4.!G:6YA(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"B,L(&9U>GIY"FUS9VED
M(")&;U]R=V%R9"(*;7-G<W1R(")2965N=FEA<B(*"B,Z(&9O;&1E<G,N<&AP
M.C(V-B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HU
M"FUS9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R
M("(B"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O;&1E<G,O:&5A
M9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N
M:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN
M8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R(").879E9V%D
M;W(@9&4@0V%R<&5T97,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PHC
M+"!F=7IZ>0IM<V=I9"`B1F]L9&5R(%-U;6UA<GDB"FUS9W-T<B`B1F5B<F5R
M(@H*(SH@86-L+G!H<#HR-`IM<V=I9"`B1F]L9&5R('-H87)I;F<@:7,@;F]T
M(&5N86)L960N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C8R"FUS9VED
M(")&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38Y"FUS9VED(")&;W)M870@;V8@;65S
M<V%G92!D871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S86=E<R!D
M871E9"!T;V1A>2(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HW.#`@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")&;W)W87)D(@IM
M<V=S='(@(E)E96YV:6%R(@H*(SH@8V]M<&]S92YP:'`Z-S8U"FUS9VED(")&
M;W)W87)D.B(*;7-G<W1R(")2965N=FEA<B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS-CD*(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S
M='(@(D9I(&1E;"!M:7-S871G92!R965N=FEA="(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A
M9V4@9G)O;2`E<R(*;7-G<W1R(")-:7-S871G92!R965N=FEA="!D92`E<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*(RP@9G5Z>GD*;7-G
M:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VGS
M(&1E;"!397)V:61O<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT
M.30*;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@4F5Q
M=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#`Q"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C(W"B,L(&9U>GIY"FUS9VED(")&<F]?;2(*;7-G<W1R(")$92(*"B,Z(&UE
M<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T.2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I9"`B
M1G)O;2(*;7-G<W1R(")$92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,3@*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R(")$)T%D<F7G82!%;&5C
M='+R;FEC82(*"B,Z(&-O;7!O<V4N<&AP.C<W-R!C;VUP;W-E+G!H<#HW.#$*
M;7-G:60@(D9W9#HB"FUS9W-T<B`B1G=D.B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M.30*(RP@9G5Z>GD*;7-G:60@(D9W9#H@(@IM<V=S='(@(D9W9#HB"@HC.B!C
M;VUP;W-E+G!H<#HQ,CDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&
M=V0Z("5U($9O<G=A<F1E9"!-97-S86=E<R(*;7-G<W1R(")&:2!D96P@;6ES
M<V%T9V4@<F5E;G9I870B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*(RP@9G5Z>GD*;7-G
M:60@(D=E;F5R86P@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS(&1E(&PG57-U
M87)I(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,W"FUS
M9VED(")'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Q"FUS
M9VED(")';R(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$S-@HC+"!F=7IZ
M>0IM<V=I9"`B1V\@=&\@365S<V%G92(*;7-G<W1R(")-27-S871G92!396?\
M96YT(@H*(SH@;&EB+TE-4"YP:'`Z-#DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")';R!T;R!A9&1R97-S(&)O;VL@96YT<GD@;V8@7"(E<UPB(@IM
M<V=S='(@(D%F96=I<B!A(&QA($QL:6)R971A(&0G861R96-E<R`H)7,I(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@86-C
M97-S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-B!L:6(O1FEL=&5R
M+G!H<#HQ,#4@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(SH@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$P-`HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ
M-C,@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC.B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP
M:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(SH@;&EB+TU)
M344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(P
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM<V=I9"`B2$5212(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-PHC.B!L:6(O34E-12]6
M:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*
M(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I;VX@;V8@365S
M<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S
M+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@=&AE
M(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8X"FUS9VED(")(:61D96XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PHC+"!F=7IZ>0IM
M<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(E!E<B!397'\
MZ&YC:6$B"@HC.B!M86EL8F]X+G!H<#HS-C<*;7-G:60@(DAI9&4@1&5L971E
M9"(*;7-G<W1R(")/8W5L=&%R($5L:6UI;F%T<R(*"B,Z(&9O;&1E<G,N<&AP
M.C(Y.`IM<V=I9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`B3V-U;'1A
M<B!$97-U8G-C<FET<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(Y-`IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H
M<#HR.3<@;6%I;&)O>"YP:'`Z-S(T('1E;7!L871E<R]M86EL8F]X+VQE9V5N
M9"YI;F,Z,3(*;7-G:60@(DAI9V@@4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDS"FUS9VED(")(:6=H
M97-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#@*
M;7-G:60@(DAO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`T"B,L
M(&9U>GIY"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E9"!L:6YE<R!I
M;B!A(')E<&QY(@IM<V=S='(@(E!R969I>"!P97(@8VET87(@;&5S(&SM;FEE
M<R!D96P@;6ES<V%T9V4@9&4@<F5S<&]S=&$Z(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T
M96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HS.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!397)V97(@8VQO
M<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-33"(*
M;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I
M9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38W"FUS
M9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-C@*;7-G:60@(DE-05`@<V5R=F5R
M(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C4@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C0Y"FUS9VED("))34%0+U!/4#,@36%I;"!3
M97)V97)S(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C@V-@IM<V=I9"`B
M24Y"3U@B"FUS9W-T<B`B24Y"3U@B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V
M92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ
M,3(*(RP@9G5Z>GD*;7-G:60@(DEF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A
M9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(2(*;7-G<W1R("*A
M5&]T<R!E;',@;6ES<V%T9V5S(&1E(&QA(&-A<G!E=&$H97,I(&5S('!E<F1R
M86XA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@R"FUS
M9VED("))9VYO<F4B"FUS9W-T<B`B26=N;W)A<B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G
M<W1R("))9VYO<F%R(%1O=&5S(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S
M879E:6UA9V4N:6YC.C@*;7-G:60@(DEM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C`*(RP@9G5Z>GD*;7-G:60@
M(DEM<&]R="(*;7-G<W1R("));7!O<G1A;G0B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R("))
M;7!O<G1A;G0B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y"B,L(&9U
M>GIY"FUS9VED("));7!O<G0@2V5Y<&%I<B(*;7-G<W1R("));7!O<G1A;G0B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PHC+"!F=7IZ
M>0IM<V=I9"`B26UP;W)T($UE<W-A9V5S(@IM<V=S='(@(DUI<W-A=&=E<R!I
M;7!O<G1A;G1S(@H*(SH@<&=P+G!H<#HT,@IM<V=I9"`B26UP;W)T(%!'4"!+
M97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY
M,0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,30*;7-G:60@
M(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O
M<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!0
M97)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C0R"FUS9VED("));7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R
M="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)
M344@2V5Y(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ-@IM<V=I9"`B26UP
M;W)T(%,O34E-12!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@;6)O>"!&:6QE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O
M;&1E<B`E<RXB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`R(&UA:6QB
M;W@N<&AP.C<S-"!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,S"B,Z('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z-PIM<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(DEM
M<&]R=&%N="(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-#<*;7-G
M:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(")-:7-S871G97,@:6UP
M;W)T86YT<R(*"B,Z(&9O;&1E<G,N<&AP.C$V-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E<RXB"FUS
M9W-T<B`B4R=H86X@86QL:6)E<F%T('1O=',@96QS(&UI<W-A=&=E<R!D92`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS9VED("))
M;B!0<F]C97-S(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,X-"!L:6(O
M1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-4"YP:'`Z
M,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4<F5E+G!H
M<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.3(*(RP@9G5Z>GD*;7-G:60@(DEN8VQU9&4@82!B<FEE
M9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`B
MOTEN8VQO=7)E(&UI<W-A=&=E(&]R:6=I;F%L(&$@;&$@<F5S<&]S=&$_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O
M<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(K]);F-L;W5R
M92!M:7-S871G92!O<FEG:6YA;"!A(&QA(')E<W!O<W1A/R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G<W1R
M("))9VYO<F%R(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(DEN9F]R;6%T:6]N(&]N
M(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R
M"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN
M8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#<*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3@*(RP@9G5Z>GD*;7-G
M:60@(DEN;&EN92(*;7-G<W1R(")C87`B"@HC.B!T96UP;&%T97,O<VUI;64O
M:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I9FEC871E($AE
M<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>2!(
M97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI
M;F,Z,3`*;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2!(
M97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI
M;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,@IM<V=I9"`B
M26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*
M;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O>"YP:'`Z-C(V
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS9W-T<B`B061R
M9>=A($5L96-T<O)N:6-A(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HS
M,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B"FUS9W-T<B`B(@H*
M(SH@8V]M<&]S92YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L
M:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@<VUI;64N<&AP.C@R('!G<"YP:'`Z,38*;7-G:60@(DEN=F%L:60@
M:V5Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3DV"FUS9VED("));G9A;&ED
M('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@<&=P
M+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K
M97DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM
M<V=I9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@
M=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I
M<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O
M;B!T:&ES('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHS-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,SD*;7-G:60@
M(B(*(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA=F4@;F\@
M861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@(@HB8V]N=&%C=',N
M(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S$X"FUS9VED(")+97D@<W5C8V5S
M<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$V"FUS9VED("),
M86YG=6%G92(*;7-G<W1R("))9&EO;6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3`V"B,L(&9U>GIY"FUS9VED("),87-T($UA:6QB;W@@4&%G92(*
M;7-G<W1R(")$87)R97)A(%#@9VEN82(*"B,Z(&UA:6QB;W@N<&AP.C,U.`IM
M<V=I9"`B3&%S="!086=E(@IM<V=S='(@(D1A<G)E<F$@4.!G:6YA(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@Y"B,L(&9U>GIY"FUS
M9VED("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R(")!9&IU;G1A<B(*"B,Z
M(&%T=&%C:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED
M("),:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O
M;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@
M9&ES86)L960L('EO=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@
M>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8X-0IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@
M2&5A9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS
M9W-T<B`B0OIS=&EA(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W
M-`HC+"!F=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B06-C:?,B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R-0IM<V=I9"`B3&]G(&EN
M(@IM<V=S='(@(D5N=')A<B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O("5S(@IM<V=S='(@
M(D5N=')A<B!A("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M,S<*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(D5N=')A<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B3&]G:6X@5&%S:W,B
M"FUS9W-T<B`B5&%S<75E<R!D)TEN:6-I(&1E(%-E<W-I\R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-@IM<V=I9"`B3&]W(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X+G!H<#HW,C<@=&5M
M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B3&]W(%!R:6]R
M:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(Y-PIM<V=I9"`B3&]W97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@(DUA
M8VEN=&]S:"!&:6QE(@IM<V=S='(@(D9I;'1R97,@9&4@0V]R<F5U(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L(&9U>GIY"FUS
M9VED(")-86EL(@IM<V=S='(@(D+Z<W1I82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-@HC+"!F=7IZ>0IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G
M<W1R(")&:6QT<F5S(&1E($-O<G)E=2(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9')I=F5R7W-E;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y
M<&4@=&\@8V]N;F5C="!T;SHB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M-#`R"FUS9VED(")-86EL8F]X(@IM<V=S='(@(D+Z<W1I82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@9G5Z>GD*;7-G:60@(DUA:6QB;W@@
M86YD($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N<R!D
M92!6:7-U86QI='IA8VGS(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A
M<R!3965N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C$Y"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@
M87,@56YS965N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,P"FUS9VED(")-87)K(&%S.B(*;7-G<W1R(")-87)C87(@8V]M.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G:60@(DUA<FL@9&EF
M9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R
M<S\B"FUS9W-T<B`BOTUA<F-A<B!D:69E<F5N=',@;FEV96QL<R!D92!Q=6]T
M82!A;6(@9&EF97)E;G1S(&-O;&]R<S\B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E
M;C\@*$E-05`@;VYL>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U.`IM<V=I9"`B36%R:R!S:6UP;&4@;6%R:W5P/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@
M(DUA=&-H($%L;"!1=65R:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:&5A9&5R+FEN8SHT,@IM<V=I9"`B36%T8V@@06YY(%%U97)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q
M,PHC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!!='1A8VAM96YT(%-I>F4B"FUS
M9W-T<B`B061J=6YT87(@87)X:74B"@HC.B!L:6(O87!I+G!H<#HW.0IM<V=I
M9"`B36%X:6UU;2!.=6UB97(@;V8@1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.30*;7-G:60@(DUA>&EM
M=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X.0IM<V=I9"`B
M36%X:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B
M365E=&EN9R!#86YC96QL871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!)
M;F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VGS(&1E;"!397)V:61O<B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I
M;F<@4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8Q-PIM<V=I9"`B365E=&EN9R!297!L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DX"FUS9VED(")-965T:6YG
M(%5P9&%T92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C`S"FUS9VED(")-965T:6YG(%5P9&%T92!297%U97-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,*(RP@9G5Z>GD*
M;7-G:60@(DUE;G4@1F]L9&5R($QI<W0B"FUS9W-T<B`B3V)R:7(@0V%R<&5T
M82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,S$*;7-G:60@(DUE<W-A9V4B"FUS
M9W-T<B`B36ES<V%T9V4B"@HC.B!C;VUP;W-E+G!H<#HU-C`@8V]M<&]S92YP
M:'`Z-3@W(&-O;7!O<V4N<&AP.C8T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S:71I;VXB"FUS9W-T<B`B4F5D86-T
M87(@36ES<V%T9V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$W"FUS
M9VED(")-97-S86=E($1A=&4B"FUS9W-T<B`B4&5R($1A=&$@9&5L($UI<W-A
M=&=E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`S"B,L(&9U>GIY"FUS9VED(")-
M97-S86=E($]P=&EO;G,B"FUS9W-T<B`B36ES<V%T9V5S(&$B"@HC.B!S96%R
M8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T<B`B0V5R
M8V$@9&4@36ES<V%T9V5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR
M,0IM<V=I9"`B365S<V%G92!3:7IE(@IM<V=S='(@(E!E<B!486UA;GD@9&5L
M($UI<W-A=&=E(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS9VED(")-97-S86=E
M(%-O=7)C92(*;7-G<W1R(")&;VYT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8V"FUS9VED(")-97-S86=E(%9I97=I;F<B"FUS9W-T<B`B4')E<V5N
M=&%C:?,@9&4@36ES<V%T9V5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHV"FUS9VED(")-97-S86=E(&9L86=S(@IM<V=S='(@(D)A;F1E<F5S
M(&1E;"!M:7-S871G92(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M.#,*;7-G:60@(DUE<W-A9V4@9F]L9&5R<R(*;7-G<W1R(")#87)P971E<R!D
M96P@36ES<V%T9V4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B
M0V%R<&5T97,@9&5L($UI<W-A=&=E(@H*(SH@;6%I;&)O>"YP:'`Z-C8W"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R
M(")3)VAA(&5L:6UI;F%T('5N(&%R>&EU+B(*"B,Z(&UA:6QB;W@N<&AP.C8U
M.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T
M<B`B0V%M<',@9&5L(&UI<W-A=&=E(@H*(SH@;6%I;&)O>"YP:'`Z-C4S"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G<W1R(")#86UP
M<R!D96P@;6ES<V%T9V4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI
M;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R
M(")097(@1&%T82!D96P@36ES<V%T9V4B"@HC.B!C;VUP;W-E+G!H<#HX,C0@
M8V]M<&]S92YP:'`Z.#,X"B,L(&9U>GIY"FUS9VED(")-97-S86=E(')E9&ER
M96-T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")-:7-S871G92!E;G9I870@
M<V%T:7-F86-T\G)I86UE;G0L('!E<O(@;F\@:&$@97-T870@9&5S870@82(*
M"B,Z(&-O;7!O<V4N<&AP.C$P.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V960@
M=&\@)7,B"FUS9W-T<B`B36ES<V%T9V4@96YV:6%T('-A=&ES9F%C=/)R:6%M
M96YT+"!P97+R(&YO(&AA(&5S=&%T(&1E<V%T(&$B"@HC.B!C;VUP;W-E+G!H
M<#HQ,30S(&-O;7!O<V4N<&AP.C$Q-3@*(RP@9G5Z>GD*;7-G:60@(DUE<W-A
M9V4@<V5N="!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DUI<W-A=&=E(&5N=FEA
M="!S871I<V9A8W3R<FEA;65N="P@<&5R\B!N;R!H82!E<W1A="!D97-A="!A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,0IM<V=I9"`B365S<V%G
M97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`B36ES
M<V%T9V5S('!E<B!PX&=I;F$@86P@;&QI<W1A="!D92!L82!B^G-T:6$N(@H*
M(SH@;6%I;&)O>"YP:'`Z,S(R"FUS9VED(")-97-S86=E<R!T;R(*;7-G<W1R
M(")-:7-S871G97,@82(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM
M<V=I9"`B36]D:69Y(@IM<V=S='(@(DUO9&EF:6-A<B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM
M<V=I9"`B36]V92(*;7-G<W1R(")-;W5R92(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,Q-@HC+"!F=7IZ>0IM<V=I9"`B36]V92!D
M;W=N(@IM<V=S='(@(FUO=7)E(&%B86EX(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Q.`IM<V=I9"`B36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@
M9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@(G-E;&5C8VEO;F%R(&-A
M<G!E=&$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M,30*(RP@9G5Z>GD*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B;6]U<F4@86UU
M;G0B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$R-PIM
M<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@(B(*"B,Z('1H
M<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(DUU
M;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R(")0<F5S96YT86-I\R!D92!-
M:7-S871G97,B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E
M;&5C="YI;F,Z-0IM<V=I9"`B3D].12(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED(").
M3U1%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@
M(DYA;64B"FUS9W-T<B`B3F]M(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA
M;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W.`HC+"!F=7IZ>0IM<V=I
M9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(D%C8VGS(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S@*;7-G:60@(DYE=F5R(@IM<V=S
M='(@(DUA:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C`*(RP@9G5Z
M>GD*;7-G:60@(DYE=F5R('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B4R=H
M82!E;&EM:6YA="!U;B!A<GAI=2XB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`B3F]U(@H*(SH@;&EB+TE-4"YP
M:'`Z-38S"B,L(&9U>GIY"FUS9VED(").97<@1F]L9&5R(@IM<V=S='(@(D]B
M<FER($-A<G!E=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#@*;7-G
M:60@(DYE=R!-86EL(@IM<V=S='(@(DYO=2!#;W)R974B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z
M,S,*(RP@9G5Z>GD*;7-G:60@(DYE=R!-97-S86=E(@IM<V=S='(@(DU)<W-A
M=&=E(%-E9_QE;G0B"@HC.B!M86EL8F]X+G!H<#HW-S8@;&EB+TU)344O2&5A
M9&5R<RYP:'`Z,3DR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@
M365S<V%G92!T;R`E<R(*;7-G<W1R(")-27-S871G97,@3F]U<R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E
M<R(*;7-G<W1R(")-27-S871G97,@3F]U<R(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(DYE>'0B"FUS9W-T<B`B4VEG
M_&5N="(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G92(*;7-G<W1R(")-27-S871G92!3
M96?\96YT(@H*(SH@;6%I;&)O>"YP:'`Z,S4V"FUS9VED(").97AT(%!A9V4B
M"FUS9W-T<B`B4.!G:6YA(%-E9_QE;G0B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW-PIM
M<V=I9"`B3F\B"FUS9W-T<B`B3F\B"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED
M(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y
M<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Y
M"FUS9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@;6%I
M;&)O>"YP:'`Z,S<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!-
M97-S86=E<R(*;7-G<W1R(")-27-S871G97,@3F]U<R(*"B,Z('!G<"YP:'`Z
M,3,W"FUS9VED(").;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHX-`IM<V=I9"`B
M3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N="(*;7-G<W1R("(B"@HC
M.B!L:6(O36%I;&)O>"YP:'`Z,S(Y"B,L(&9U>GIY"FUS9VED(").;R!0<F5V
M:65W(%1E>'0B"FUS9W-T<B`B5&5X="!#;W)R96=I="(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O
M=6YD(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O
M34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O=&YE9BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DYO(&%T
M=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R(")!9&IU;G1A<B(*"B,Z(&QI8B]#
M<GEP="]334E-12YP:'`Z,30P"FUS9VED(").;R!E;6%I;"!I;F9O<FUA=&EO
M;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+B(*;7-G<W1R("(B"@HC.B!A
M8VPN<&AP.C<R(&%C;"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E
M<B!S96QE8W1E9"XB"FUS9W-T<B`B;F\@<R=H82!S96QE8V-I;VYA="!C87`@
M8V%R<&5T82(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#$*;7-G:60@
M(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M86EL+B(*
M;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR,3@@;&EB+T9O;&1E<BYP:'`Z
M-3`P(&QI8B]&;VQD97(N<&AP.C4U,`IM<V=I9"`B3F\@9F]L9&5R<R!W97)E
M('-P96-I9FEE9"(*;7-G<W1R(").;R!S)VAA;B!E<W!E8VEF:6-A="!C87)P
M971E<R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#<*(RP@9G5Z>GD*
M;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`B
M36ES<V%T9V5S($YO(&5L:6UI;F%T<R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!U;G-E
M96X@;65S<V%G97,B"FUS9W-T<B`B36ES<V%T9V5S($YO(&5L:6UI;F%T<R(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,C4*(RP@9G5Z>GD*;7-G:60@(DYO(&UE
M<W-A9V4@8F]D>2!T97AT(@IM<V=S='(@(FUO=7)E(&UI<W-A=&=E(&$B"@HC
M.B!L:6(O36%I;&)O>"YP:'`Z,S<Q"B,L(&9U>GIY"FUS9VED(").;R!M97-S
M86=E<R!M871C:&5D('EO=7(@<V5A<F-H+B(*;7-G<W1R(").;R!H:2!H82!M
M:7-S871G97,@<75E(&-O:6YC:61E:7AI;B!A;6(@;&$@=F]S=')A(&-E<F-A
M(@H*(SH@<&=P+G!H<#HQ.#D*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P<FEV
M871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ-C4*
M;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C`Q"FUS9VED(").;R!P97)S;VYA
M;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!S<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").;R!S<&5L;&-H96-K:6YG('!R
M;V=R86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(").;R!S<&5L;&EN9R!E<G)O
M<G,B"FUS9W-T<B`B3F\@:&D@:&$@97)R;W)S(&0G;W)T;V=R869I82(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#`*;7-G:60@(DYO
M('-U9V=E<W1I;VYS(@IM<V=S='(@(DYO(&AI(&AA('-U9V=E<FEM96YT<R(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-38T"FUS9VED(").;R!S=7!P;W)T
M960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-C@@86-L+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B3F\@=7-E<B!S<&5C:69I960N(@IM<V=S='(@(DYO(',G:&%N
M(&5S<&5C:69I8V%T(&-A<G!E=&5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<P.0IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,`HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS-2!T96UP;&%T97,O<')E9G,O<W!A;7-E
M;&5C="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM
M<V=I9"`B3F]N92(*;7-G<W1R(")#87`B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR.34*;7-G:60@(DYO<FUA;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S
M='(@(DYO($5L:6UI;F%T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHQ,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C(S"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#(*;7-G:60@
M(DYO="!$<F%F="(*;7-G<W1R(").;R!%<V)O<G)A;GDB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,T"FUS9VED(").;W0@26UP;W)T86YT(@IM<V=S='(@(DYO($EM
M<&]R=&%N="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*
M;7-G:60@(DYO="!097)S;VYA;"(*;7-G<W1R(").;R!097)S;VYA;"(*"B,Z
M(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S
M-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@
M<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T
M<B`B36ES<V%T9V5S($YO(&5L:6UI;F%T<R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A;G0@;65S<V%G97,B
M"FUS9W-T<B`B36ES<V%T9V5S($YO(&EM<&]R=&%N=',B"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C<Q"FUS9VED(").
M;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I;64B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q-@HC+"!F=7IZ>0IM<V=I9"`B
M3F]T:&EN9R(*;7-G<W1R(")-:7-S871G92!C:71A="!P97(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<W"B,L(&9U>GIY"FUS9VED(").=6UB97(@
M;V8@;6]N=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D
M96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R(").;VUB<F4@9&4@8V%R<&5T97,@
M<V5N="UM86EL(&$@;6%N=&5N:7(@<VD@<R=E;&EM:6YE;B!M96YS=6%L;65N
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*(RP@9G5Z>GD*;7-G
M:60@(DYU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I
M9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R(").;VUB<F4@9&4@8V%R<&5T
M97,@<V5N="UM86EL(&$@;6%N=&5N:7(@<VD@<R=E;&EM:6YE;B!M96YS=6%L
M;65N="(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-3(*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<S,PIM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-2!T96UP;&%T97,O<VUI;64O
M:6UP;W)T7VME>2YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHT.`IM<V=I9"`B3U(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@
M(DUI<W-A=&=E<R!!;G1I8W,B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D
M96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N(@IM<V=S='(@(E!U<F=A;G0@
M8V%R<&5T97,@<V5N="UM86EL(&%N=&EG=65S+B(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HR-0IM<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET
M:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHW.0HC+"!F=7IZ>0IM<V=I
M9"`B3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@=&AI
M<R!A8W1I;VXN(@IM<V=S='(@(E-E;&5C8VEO;F5U('5N82!S;VQA(&-A<G!E
M=&$@<&5R(&$@87%U97-T82!O<&5R86-I\R(*"B,Z('1E;7!L871E<R]M96YU
M+FEN8SHQ,"!T96UP;&%T97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@
M(D]P96X@1F]?;&1E<B(*;7-G<W1R(")/8G)I<B!#87)P971A(@H*(SH@9F]L
M9&5R<RYP:'`Z-#(W"B,L(&9U>GIY"FUS9VED(")/<&5N960@1F]L9&5R(@IM
M<V=S='(@(D]B<FER($-A<G!E=&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S`U"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G<W1R
M("(B"@HC.B!F971C:&UA:6PN<&AP.C,S('1E;7!L871E<R]F971C:&UA:6PO
M=&]P+FEN8SHS"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN
M8SHV"B,L(&9U>GIY"FUS9VED(")/=&AE<B!-86EL($%C8V]U;G1S(@IM<V=S
M='(@(D%L=')E<R!/<&-I;VYS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B06QT<F5S($]P
M8VEO;G,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,0IM<V=I
M9"`B3W5T8F]U;F0@4V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,38U"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR.3`*;7-G:60@(E!'4"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*(RP@9G5Z>GD*
M;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B0V%N8V5LMVQA
M<B!-:7-S871G92(*"B,Z(&-O;7!O<V4N<&AP.C,U.`HC+"!F=7IZ>0IM<V=I
M9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`B17)R;W(B"@HC.B!C;VUP;W-E+G!H
M<#HS,S<*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P
M97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,@HC+"!F=7IZ>0IM<V=I9"`B4$=0($]P=&EO;G,B
M"FUS9W-T<B`B3W!C:6]N<R(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!0
M87-S<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R
M="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"FUS9VED(")01U`@
M4'5B;&EC($ME>2!497AT(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,30Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@
M7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B
M3&$@8V%R<&5T82!<(B5S7"(@:&$@97-T870@8W)E861A('-A=&ES9F%C=/)R
M:6%M96YT+B(*"B,Z('!G<"YP:'`Z,C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B3&$@8V%R<&5T82!<(B5S7"(@:&$@
M97-T870@96QI;6EN861A('-A=&ES9F%C=/)R:6%M96YT+B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHQ-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES
M="YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B4$=0(%-I9VX@365S<V%G92(*;7-G
M<W1R(")%;G9I87(@36ES<V%T9V4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M;F-R>7!T7VQI<W0N:6YC.CD*;7-G:60@(E!'4"!3:6=N+T5N8W)Y<'0@365S
M<V%G92(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C(P,@HC+"!F=7IZ>0IM<V=I
M9"`B4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T
M<B`B3&$@<VEG;F%T=7)A(',G:&$@<F5E;7!L8>=A="!S871I<V9A8W3R<FEA
M;65N="XB"@HC.B!P9W`N<&AP.C$W-PIM<V=I9"`B4$=0('!U8FQI8R!K97D@
M<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4$=0('-U<'!O<G0@:7,@9&ES
M86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(P.`IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@
M;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E
M(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDU"FUS9VED("(B"B)01U`@<W5P
M<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I
M<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q
M=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W
M<V5R(&ES(&-U<G)E;G1L>2`B"B)S970@=&\@9&ES86)L92!P;W!U<"!W:6YD
M;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE
M(%!'4"`B"B)F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#4*;7-G:60@
M(E!/4#,B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M,#`*;7-G:60@(E!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T
M<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3<*;7-G:60@(E!/
M4#,@;W9E<B!34TPB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ,C,*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E
M<G1I9FEC871E*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$V.0IM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$Q"FUS
M9VED(")03U`S+"!N;R!43%,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")086=E
M("5D(&]F("5D(@IM<V=S='(@(E#@9VEN82`E9"!D92`E9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,#,*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER
M<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H('1H92!,87-T(%5N<V5E
M;B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S='(@(E!A<G0H<RDB
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS9VED(")087-S<&AR
M87-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*
M;7-G:60@(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R("(B"@HC.B!S;6EM
M92YP:'`Z,C,U('!G<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")087-S<&AR
M87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`B36ES<V%T9V4@
M96YV:6%T('-A=&ES9F%C=/)R:6%M96YT+"!P97+R(&YO(&AA(&5S=&%T(&1E
M<V%T(&$B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3@@
M=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHR.0IM<V=I9"`B4&%S<W!H
M<F%S93HB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,3(*;7-G:60@(E!A<W-P
M:')A<V5S(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*(SH@<&=P+G!H
M<#HQ,30*;7-G:60@(E!A<W-P:')A<V5S(&1O(&YO="!M871C:"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C`@=&5M
M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<Q"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3DR"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")#
M;VYT<F%S96YY82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHT.`HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R
M871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")296%L:71Z87(@;W!E<F%C:6]N
M<R!D92!M86YT96YI;65N="!A;"!I;FEC:6%R('-E<W-I\R(*"B,Z(&%C;"YP
M:'`Z-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES
M('5S97(@8V%N(&YO="!B92!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HT.3,@;6%I;&)O>"YP:'`Z-S`S('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHQ,`IM<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`B4&5R<V]N86PB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O;F%L($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:?,@4&5R<V]N86PB"@HC.B!P9W`N
M<&AP.C$R,`IM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,C<*;7-G
M:60@(E!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")097)S;VYA;"!3
M+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S='(@(B(*
M"B,Z('-M:6UE+G!H<#HQ,S(*;7-G:60@(E!E<G-O;F%L(%,O34E-12!K97ES
M(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(R"FUS9VED(")0;&%C92!Y;W5R('-I9VYA='5R
M92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_(@IM<V=S='(@(B(*(K]6
M;VQE=2!#;VRW;&]C87(@;&$@=F]S=')A('-I9VYA='5R82!A8F%N<R!D96QS
M(&UI<W-A=&=E<R!D92!R97-P;W-T82!I(&5L<R`B"B)R965N=FEA;65N=',_
M(@H*(SH@8V]M<&]S92YP:'`Z,C4T"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO
M;B!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.3D*;7-G:60@(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4
M:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D
M("(*(G-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N
M9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@
M<&QU9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A
M<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R
M('1H92!N97<@9F]L9&5R.B(*;7-G<W1R(")3:2!U<R!P;&%U+"!I;G1R;V1U
M[W4@96P@;F]M(&1E(&QA(&YO=F$@8V%R<&5T83HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$P,B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE
M(&]F('1H92!N97<@9F]L9&5R.B(*;7-G<W1R(")3:2!U<R!P;&%U+"!I;G1R
M;V1U[W4@96P@;F]M(&1E(&QA(&YO=F$@8V%R<&5T83HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-PIM<V=I9"`B4&QE87-E(&5N
M=&5R('1H92!N97<@;F%M93HB"FUS9W-T<B`B26YT<F]D=>]U(&5L(&YO=2`@
M;F]M.B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N
M965D('1O("(*(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S
M97-S:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H
M<F%S92YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N
M=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME
M>2X@66]U('=I;&P@;VYL>2!N965D("(*(G1O(&5N=&5R('1H:7,@<&%S<W!H
M<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!R96-O
M;7!O<V4N<&AP.CDW"FUS9VED("(B"B)0;&5A<V4@;&]G(&EN(&%G86EN('1O
M(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/
M5"!U<VEN9R`B"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S
M86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O("(*(FQO
M9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@
M:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA8VMI;F<@>6]U<B!S
M97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<Q
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D
M+B(*;7-G<W1R(")&86-I;&ET974@96P@=F]S=')E(&YO;2!D)W5S=6%R:2!I
M(&-O;G1R87-E;GEA(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV
M-PHC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M92XB"FUS9W-T<B`B1F%C:6QI=&5U(&5L('9O<W1R92!N;VT@9"=U<W5A<FD@
M:2!C;VYT<F%S96YY82(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O24U0+G!H
M<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A
M;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B4VD@=7,@<&QA=2P@<F5S;VQE=2!L
M97,@861R96-E<R!E;&5C='+R;FEQ=65S(&%M8FEG_&5S(&\@:6YVX&QI9&5S
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*
M(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD
M('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y
M;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B4V5L96-C:6]N974@
M=6YA(&-A<G!E=&$@86)A;G,@9&4@<F5A;&ET>F%R(&-A<"!A8V-I\RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`R"B,L(&9U>GIY"FUS9VED
M(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W
M+B(*;7-G<W1R(")396QE8V-I;VYE=2!C;VT@82!M[6YI;2!U;F$@8V%R<&5T
M82!P97(@82!R96%L:71Z87(@;&$@8V5R8V$N(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]J879A<V-R:7!T+FEN8SHT,0IM<V=I9"`B4&QE87-E('-E;&5C="!A
M="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"XB"FUS9W-T<B`B4V5L96-C
M:6]N974@8V]M(&$@;>UN:6T@=6YA(&-A<G!E=&$@<&5R(&$@<F5A;&ET>F%R
M(&QA(&-E<F-A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O
M<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B4V5L96-C:6]N974@=6YA('-O
M;&$@8V%R<&5T82!P97(@82!A<75E<W1A(&]P97)A8VGS(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"B,L(&9U>GIY"FUS9VED(")0
M;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z
M(@IM<V=S='(@(E-I('5S('!L874L('-E;&5C8VEO;F5U(&\@961I=&5U(&$@
M8V]N=&EN=6%C:?,@9&4Z(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*
M;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q-`HC+"!F=7IZ>0IM<V=I9"`B4')E8V5D92!Y
M;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R(")0
M<F5C961I=2!L82!V;W-T<F$@<VEG;F%T=7)A(&%M8B!G=6EO;G,@*"<M+2`G
M*2(*"B,Z('-M:6UE+G!H<#HR-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N
M<&AP.C0P"B,L(&9U>GIY"FUS9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L
M;'D@=7!D871E9"XB"FUS9W-T<B`B3&$@8V%R<&5T82!<(B5S7"(@:&$@97-T
M870@8W)E861A('-A=&ES9F%C=/)R:6%M96YT+B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"B,L(&9U>GIY"FUS9VED(")0<F5V
M:65W(@IM<V=S='(@(E#@9VEN82!!;G1E<FEO<B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G:60@(E!R979I;W5S
M($UE<W-A9V4B"FUS9W-T<B`B36ES<V%T9V4@06YT97)I;W(B"@HC.B!M86EL
M8F]X+G!H<#HS-#<*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS9W-T<B`B4.!G
M:6YA($%N=&5R:6]R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C,S"FUS9VED(")0<FEN="(*;7-G<W1R("));7!R:6UI<B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X"B,L(&9U>GIY
M"FUS9VED(")0<FEO<FET>2(*;7-G<W1R("));7!R:6UI<B(*"B,Z('1E;7!L
M871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I9"`B4')I=F%T92!+
M97D@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4U.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N
M="!I<R!S96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE
M(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS
M9VED(")0<F]T;V-O;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T-R>7!T+U!'4"YP
M:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA
M<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M7V1E;&5T960N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!U<E]G92!$96QE=&5D
M(@IM<V=S='(@(D)U:61A<B!087!E<F5R82(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?
M9&5L971E9"YI;F,Z.`IM<V=I9"`B4'5R9V4@1&5L971E9"(*;7-G<W1R(")"
M=6ED87(@4&%P97)E<F$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHR-`HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@1F]L9&5R*',I(@IM<V=S
M='(@(D5L:6UI;F%R($-A<G!E=&$H97,I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G
M<W1R(")097)I;V1I8VET870@9&5L(&)U:61A="!D92!L82!087!E<F5R83HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`U"B,L(&9U>GIY"FUS9VED
M(")0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T
M:&ES(&%M;W5N="!O9B!D87ES+B(*;7-G<W1R("(B"B)"=6ED87(@96QS(&UI
M<W-A=&=E<R!A(&QA(&-A<&5T82!087!E<F5R82!Q=64@<VEG=6EN(&WI<R!A
M;G1I8W,@<75E(&%Q=65S=&$@(@HB<75A;G1I=&%T(&1E(&1I97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"B,L(&9U>GIY"FUS9VED(")0=7)G
M92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS9W-T<B`B
M0G5I9&%R(&UI<W-A=&=E(&%N=&EC(&$@;&$@8V%R<&5T82!087!E<F5R82(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S86=E
M<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B0G5I9&%N="`E9"!M:7-S
M871G92AE<RD@9&4@;&$@8V%R<&5T82!087!E<F5R82XB"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C,*(RP@9G5Z>GD*;7-G
M:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G
M<W1R(")"=6ED86YT("5D(&UI<W-A=&=E*&5S*2!D92!L82!C87)P971A(%!A
M<&5R97)A+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F
M34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q
M=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S
M.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A
M('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B475O
M=&EN9R`E9CHB"FUS9W-T<B`B36ES<V%T9V4@8VET870@<&5R(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@V"FUS9VED(")295]Q=65S
M="!$96QI=F5R>2!#;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+U-E
M87)C:"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S
M='(@(E)E8G5T(&5L(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3@*(RP@9G5Z>GD*
M;7-G:60@(E)E8V5I=F5D(%-I;F-E(@IM<V=S='(@(E)E8G5T(&5L(@H*(SH@
M;&EB+U-E87)C:"YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E)E8V5I=F5D(%5N
M=&EL(@IM<V=S='(@(E)E8G5T(&5L(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")2961I<F5C
M7W0B"FUS9W-T<B`B4F5D:7)I9VER(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C="(*;7-G<W1R
M(")2961I<FEG:7(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI
M;F,Z,3$P"FUS9VED(")2961I<F5C="!-97-S86=E(@IM<V=S='(@(E)E9&ER
M:6=I<B!-:7-S871G92(*"B,Z(&-O;7!O<V4N<&AP.C<X-PIM<V=I9"`B4F5D
M:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S='(@(E)E9&ER:6=I<B!A<75E<W0@
M;6ES<V%T9V4B"@HC.B!C;VUP;W-E+G!H<#HX-#<*;7-G:60@(E)E9&ER96-T
M:6YG(&9A:6QE9"XB"FUS9W-T<B`B16P@<F5D:7)E8V-I;VYA;65N="!H82!F
M86QL870N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@S
M"FUS9VED(")2969R97-H(@IM<V=S='(@(E)E9G)E<V-A<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E<V@@1F]L9&5R(%9I
M97=S.B(*;7-G<W1R(")2969R97-C87(@5FES=&5S(&1E($-A<G!E=&$B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY('1E;7!L871E<R]M86EL
M8F]X+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S
M='(@(E)E8V%R<F5G87(@5FES=&$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H
M96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R(")296-A<G)E
M9V%R(%9I<W1A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R-B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30U"FUS9VED(")296UE;6)E<B!T
M:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<Y"FUS9VED(")296UE;6)E<B!T:&4@;&%S
M="!V:65W(@IM<V=S='(@(E)E8V]R9&%R(&QA(&1A<G)E<F$@=FES=&$B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]T92!-86EL8F]X.B(*;7-G<W1R(")"^G-T:6$B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&
M:65L9"!&<F]M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*(RP@9G5Z>GD*;7-G:60@(E)E;6]V
M92!S;W5R8V4B"FUS9W-T<B`B=')E=7)E(&9O;G0B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED(")296YA;64@
M1F]L9&5R*',I(@IM<V=S='(@(E)E;F]M96YA<B!#87)P971A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5N86UE
M('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G
M<W1R(")296YO;65N87(@;&$@8V%R<&5T82!S96YT+6UA:6P@82!P<FEN8VEP
M:2!D92!M97,B"@HC.B!L:6(O1F]L9&5R+G!H<#HT-34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL960N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB2&$@9F%L
M;&%T(&%L(')E;F]M96YA<B!<(B5S7"(@82!<(B5S7"(N($%I>/(@Z7,@96P@
M<75E(&AA(&1I="!E;"!S97)V:61O<B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;%]Y
M('1O($QI<W0B"FUS9W-T<B`B4F5S<&]N9')E(&$@5&]T<R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@
M=VET:#HB"FUS9W-T<B`B4F5E;7!L8>=A<B!A;6(Z(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM
M<V=S='(@(E)E<W!O;F1R92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HS,3$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P.0HC+"!F=7IZ>0IM
M<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B4F5S<&]N9')E+6$B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@
M(E)E<&QY('1O($%L;"(*;7-G<W1R(")297-P;VYD<F4@82!4;W1S(@H*(SH@
M8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L>2!T;R!!;&PZ(@IM<V=S='(@
M(E)E<W!O;F1R92!A(%1O=',Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!,
M:7-T(@IM<V=S='(@(E)E<W!O;F1R92!A(%1O=',B"@HC.B!C;VUP;W-E+G!H
M<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O($QI<W0Z(@IM<V=S='(@
M(E)E<W!O;F1R92!A(%1O=',Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!?
M06QL(@IM<V=S='(@(E)E<W!O;F1R92!A(%1O=',B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3(X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,S<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-PIM<V=I9"`B4F5P
M;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-0IM<V=I9"`B4F5P;'D@=VET
M:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E<&QY('=I
M=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@;65S<V%G92YP:'`Z,C8W"B,L(&9U>GIY"FUS9VED(")297!L>2U4
M;R(*;7-G<W1R(")297-P;VYD<F4M03H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0P.0IM<V=I9"`B4F5P;'DM5&\Z("(*;7-G<W1R(")297-P;VYD<F4M03H@
M(@H*(SH@8V]M<&]S92YP:'`Z-S,Q"FUS9VED(")297!L>3HB"FUS9W-T<B`B
M4F5S<&]N9')E.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR-@HC
M+"!F=7IZ>0IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S='(@(E)E
M<&]R=&%R(&-O;2!3<&%M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C,U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C(S"FUS9VED(")297!O<G0@87,@4W!A;2(*;7-G<W1R(")297!O<G1A<B!C
M;VT@4W!A;2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X
M,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS
M9W-T<B`B4V]LMVQI8VET87(@07;M<R!D92!296)U9&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y(&-O
M;F9I<FUA=&EO;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4W,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S
M/R(*;7-G<W1R(")3;VRW;&EC:71A<B!!=NUS(&1E(%)E8G5D82(*"B,Z(&UA
M:6QB;W@N<&AP.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-CDW"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP;&%T97,O<V5A
M<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V
M,0IM<V=I9"`B4F5S970B"FUS9W-T<B`B3F5T96IA<B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,34*;7-G:60@(E)E<W!O;F1E;G0@4W1A='5S
M(%5P9&%T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHS,`IM<V=I9"`B4F5S=6UE(@IM<V=S='(@(E)E
M<')E;F1R92(*"B,Z(')E8V]M<&]S92YP:'`Z.3@*;7-G:60@(E)E<W5M92!Y
M;W5R('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")2971U<FX@=&\@7")-
M97-S86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`B4F5D86-T87(@36ES<V%T
M9V4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,@IM<V=I9"`B
M4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO=&%C
M=&EV92YI;F,Z,C(*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#$@
M=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,30*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z
M,34*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,3<S"B,L(&9U>GIY"FUS9VED(")2971U<FX@=&\@3W!T:6]N
M<R(*;7-G<W1R(")/<&-I;VYS(&1E(&PG57-U87)I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Q.`IM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL
M8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN
M9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*(K]4;W)N87(@86P@;&QI<W1A(&1E
M(&QA(&+Z<W1I82!D97-P<NES(&0G96QI;6EN87(L(&UO=7)E(&\@8V]P:6%R
M('5N("(*(FUI<W-A=&=E/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV.#@*;7-G:60@(E)O;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HQ-#(@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR
M,S<*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3D*;7-G:60@(E,O
M34E-12(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T
M7VQI<W0N:6YC.C$R"FUS9VED(")3+TU)344@16YC<GEP="!-97-S86=E(@IM
M<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C,Y-`IM<V=I9"`B4R]-24U%($5R
M<F]R.B`B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,S<S"FUS9VED(")3
M+TU)344@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I
M=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3$*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!/<'1I;VYS(@IM<V=S='(@
M(D]P8VEO;G,B"@HC.B!S;6EM92YP:'`Z-#D*;7-G:60@(E,O34E-12!087-S
M<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-30*;7-G:60@(E,O34E-12!097)S;VYA;"!+97EP86ER('-U
M<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(B(*"B,Z('-M:6UE+G!H<#HQ-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E
M<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("),82!C87)P971A(%PB)7-<(B!H
M82!E<W1A="!E;&EM:6YA9&$@<V%T:7-F86-T\G)I86UE;G0N(@H*(SH@<VUI
M;64N<&AP.C$V,@IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U
M;&QY(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C$P"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C(Q,0IM<V=I9"`B4R]-24U%(%!U8FQI8R]0
M<FEV871E($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"B,L
M(&9U>GIY"FUS9VED(")3+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(D5N
M=FEA<B!-:7-S871G92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?
M;&ES="YI;F,Z,30*;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN
M8SHT"FUS9VED(")3+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES
M('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR-#$*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R
M96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@
M(@HB9&5C<GEP=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C$W,PIM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T
M(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A
M9V4@8V%N(&YO="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@
M<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U
M<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-
M12!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@
M($EF('EO=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B
M;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN
M9R!O<B!E;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R
M:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C`U"FUS9VED(")33510(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(U-0HC+"!F=7IZ>0IM<V=I9"`B
M4U]U8FIE8W0B"FUS9W-T<B`B07-S=6UP=&4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS-C,*(RP@9G5Z>GD*;7-G:60@(E-A7W9E(&$@
M8V]P>2!I;B`B"FUS9W-T<B`B1&5S87(@8_)P:6$@82`B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*(RP@9G5Z>GD*;7-G
M:60@(E-A7W9E(&%S(@IM<V=S='(@(D1E<V%R(&-O;2(*"B,Z('-E87)C:"YP
M:'`Z,S$V('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-PHC+"!F
M=7IZ>0IM<V=I9"`B4V%V92(*;7-G<W1R(")$97-A<B!C;VTB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S@*;7-G:60@(E-A=F4@071T
M86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PIM<V=I9"`B4V%V
M92!$<F%F="(*;7-G<W1R(")$97-A<B!%<V)O<G)A;GDB"@HC.B!S879E:6UA
M9V4N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")3879E($EM86=E(@IM<V=S='(@
M(D1E<V%R(&-O;2(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,#0*;7-G
M:60@(E-A=F4@26UA9V4@:6X@1V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-3D@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z
M,3(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T.`HC.B!T96UP;&%T97,O<&=P
M+VYO=&%C=&EV92YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E-A=F4@3W!T:6]N
M<R(*;7-G<W1R(")/<&-I;VYS(&1E(&PG57-U87)I(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"FUS9VED(")3879E(%-T871I;VYE
M<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,S"B,L(&9U
M>GIY"FUS9VED(")3879E(%]$<F%F="(*;7-G<W1R(")$97-A<B!%<V)O<G)A
M;GDB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T<B`B1&5S87(@8V]M(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@
M=6YS965N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`W,@IM<V=I9"`B4V%V92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@
M=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@
M87,@82!V:7)T=6%L(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S,`HC+"!F=7IZ>0IM<V=I9"`B4V%V92!S96YT(&UA
M:6P_(@IM<V=S='(@(D1E<V%R(&-O<G)E=2!E;G9I870B"@HC.B!C;VUP;W-E
M+G!H<#HQ,C(W"B,L('!H<"UF;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A
M9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*
M;7-G<W1R(")(82!F86QL870@86P@9&5S87(@;"=E<V)O<G)A;GDN($%I>/(@
MZ7,@96P@<75E(&AA(&1I="!E;"!S97)V:61O<CH@)7,B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y.2!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C$Q"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP
M.C0Q"FUS9VED(")396%R8V@B"FUS9W-T<B`B0V5R8V%R(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VAE
M861E<BYI;F,Z,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-E87)C
M:"`E<R(*;7-G<W1R(")#97)C87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(P"B,L(&9U>GIY"FUS9VED(")396%R8V@@3W!T:6]N<R(*;7-G<W1R
M(")/<&-I;VYS(&1E(&PG57-U87)I(@H*(SH@<V5A<F-H+G!H<#HR-C4*;7-G
M:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(E)E<W5L=&%T<R!D92!L82!#
M97)C82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,30@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,0IM<V=I9"`B4V5E;B(*;7-G
M<W1R(")6:7-T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHY
M"FUS9VED(")396QE8W0B"FUS9W-T<B`B4V5L96-C:6]N87(B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-S`*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!!;F]T:&5R($%C8V]U;G0B"FUS9W-T<B`B5')E=7)E('-E;&5C
M8VGS(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C8VEO;F5U
M('5N82!I9&5N=&ET870B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@
M(E-E;&5C8VEO;F%R('1O=',B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHS,3<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('-T871I;VYE
M<GDZ(@IM<V=S='(@(E1R975R92!S96QE8V-I\R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S4*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A9&1R97-S
M(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D
M9')E<W-E<RXB"FUS9W-T<B`B(@HB4V5L96-C:6]N974@;&$@<')O8V5DZ&YC
M:6$@9&4@;&5S(&QL:6)R971E<R!D)V%D<F5C97,@<&5R(&%F96=I<B!I(&-E
M<F-A<B`B"B)A9')E8V5S(&1E(&-O<G)E=2XB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E-E
M;&5C8VEO;F%R('1O=',B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHS,C,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9FEE;&1S
M('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@
M(B(*(D5S8V]L;&EU(&PG;W)D<F4@9&4@;&5S(&QL:6)R971E<R!D)V%D<F5C
M97,@82!B=7-C87(@<75A;B!E>'!A;F1I=2!A9')E8V5S+B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R(")4<F5U<F4@<V5L
M96-C:?,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@Y"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R(")4<F5U<F4@<V5L96-C:?,B"@HC.B!T
M96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B4V5L
M96-T('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C(Q"FUS9VED(")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y
M"B,L(&9U>GIY"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G
M<W1R("),;&EB<F5T97,@9"=!9')E8V5S('-E;&5C8VEO;F%D97,Z(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")396YD($ME>2!T;R!0
M=6)L:6,@2V5Y<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,#0*(RP@9G5Z>GD*;7-G:60@(E-E;F0@3&%T97-T($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:?,@9&5L(%-E<G9I9&]R(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"FUS9VED(")396YD($UE<W-A9V4B
M"FUS9W-T<B`B16YV:6%R($UI<W-A=&=E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<P,PIM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U
M97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP
M:'`Z,SDW"B,L(&9U>GIY"FUS9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S
M='(@(D-A<G!E=&$@9&4@8V]R<F5U<R!E;G9I871S.B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,S@*;7-G:60@(E-E;G0@;6%I
M;"!F;VQD97(Z(@IM<V=S='(@(D-A<G!E=&$@9&4@8V]R<F5U<R!E;G9I871S
M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS9W-T<B`B4V5R=FED;W(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E
M<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C
M:?,@9&5L(%-E<G9I9&]R(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")397)V97(Z(@IM<V=S='(@(E-E
M<G9I9&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3
M970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E
M(&%N9"!D96QE=&4@;65S<V%G97,N(@IM<V=S='(@(B(*(D5S=&%B;&EU('!R
M969E<NAN8VEE<R!D96P@<75E(&AA(&1E('-U8V-E:7(@<75A;B!M;W9E=2!I
M(&5L:6UI;F5U(&UI<W-A=&=E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3(Y"FUS9VED(")3970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@
M8V]M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S$*(RP@9G5Z>GD*;7-G:60@(E-H87)E($9O;&1E<G,B
M"FUS9W-T<B`B0V%R<&5T97,B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M.#8*(RP@9G5Z>GD*;7-G:60@(E-H87)E(&UA:6P@9F]L9&5R<R(*;7-G<W1R
M(")#87)P971A(&1E(&-O<G)E=7,@96YV:6%T<SHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S
M('=I=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-CD*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@
M;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_
M($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H
M;V]S92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<*
M;7-G:60@(E-H;W5L9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S
M(&)E('-C86YN960@9F]R(%!'4"!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$S"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O
M<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS
M9W-T<B`BOU,G:&$@9&4@=&%N8V%R(&QA(&9I;F5S=')A(&1E(')E9&%C8VGS
M(&1E<W!RZ7,@9&4@9&5S87(@=6X@97-B;W)R86YY/R(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC
M(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U
M;'0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M.3(*(RP@9G5Z>GD*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`B
M0V]LMVQA<'-A<B!4;W1E<R!L97,@0V%R<&5T97,B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHV-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R
M<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HS-C4*;7-G:60@(E-H;W<@
M1&5L971E9"(*;7-G<W1R(")-;W-T<F%R($5L:6UI;F%T<R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET
M960@2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H
M96%D97)S+FEN8SHW,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!-86EL:6YG($QI
M<W0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I\R!097)S;VYA;"(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G
M:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B4W5B
M<V-R:75R92=S(&$@;&$@0V%R<&5T82AE<RDB"@HC.B!F;VQD97)S+G!H<#HR
M.3@*;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D(@IM<V=S='(@(DUO<W1R87(@
M1&5S=6)S8W)I=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`X"FUS
M9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG(&]F(&%T=&%C
M:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#`R"B,L(&9U>GIY"FUS9VED(")3:&]W(&QE9V5N
M9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R(")-;W-T<F%R(&QL96=E
M;F1A(&5N(&5L(&QL:7-T870@9&4@;&$@8OIS=&EA+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-#`*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R('5N
M<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT
M:7!S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<W
M"FUS9VED(")3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B
M87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY
M-0IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHU-`IM<V=I9"`B4VAO=R!T:&4@9FEL
M=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HR.`IM<V=I9"`B4VAO=R!T;W1A;"!N=6UB97(@
M;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C8V"FUS9VED(")3:&]W;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0R"B,L(&9U
M>GIY"FUS9VED(")3:5]Z92(*;7-G<W1R(")486UA;GDB"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")3:6=N
M960B"FUS9W-T<B`B5&%M86YY(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%M86YY(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM
M<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,38*;7-G:60@(E-O<G0@
M8GD@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($9R
M;VT@061D<F5S<R(*;7-G<W1R(")$)T%D<F7G82!%;&5C='+R;FEC82(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*(RP@
M9G5Z>GD*;7-G:60@(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(E!E
M<B!486UA;GD@9&5L($UI<W-A=&=E(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B
M>2!3=6)J96-T(@IM<V=S='(@(E-E;G-E($%S<W5M<'1E(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,0HC+"!F=7IZ>0IM
M<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B4V5Q_.AN8VEA(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,0HC+"!F
M=7IZ>0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S(@IM<V=S='(@(D0G061R
M9>=A($5L96-T<O)N:6-A(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE
M8W0N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T
M<B`B0V%R<&5T82!087!E<F5R83HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G
M<W1R(")#87+@8W1E<G,@17-P96-I86QS(@H*(SH@<V5A<F-H+G!H<#HQ,S,*
M;7-G:60@(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;B!N;W0@8F4@961I
M=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHS-#,*;7-G:60@(E-P96QL($-H96-K(@IM<V=S='(@(D-O<G)E8V-I
M\R!D)T]R=&]G<F%F:6$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-#8*;7-G:60@(E-P96QL($-H96-K97(B"FUS9W-T<B`B0V]R<F5C
M=&]R(&0G3W)T;V=R869I82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-38*
M;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@(E)E=FES:?,@
M9"=O<G1O9W)A9FEA(&-O;7!L971A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0W,0IM<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE
M;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T<B`B17)R;W)S(&0G;W)T;V=R869I
M82!P97(@<&%N=&%L;&$@9'5R86YT(&QA(')E=FES:?,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4Q,B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C4R"FUS9VED(")3=&%R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHS,3$*;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T
M:6]N97)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHR.`IM<V=I9"`B4W1A=&EO;F5R>2!T>7!E.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S,*
M;7-G:60@(E-T871I;VYE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")3
M=')I<"!!='1A8VAM96YT(@IM<V=S='(@(D%D:G5N=&%R(&%R>&EU(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S,@IM<V=I9"`B4W1R:7`@;&EN96)R
M96%K<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHS-PHC+"!F=7IZ>0IM<V=I9"`B4W5B7VIE8W0B"FUS
M9W-T<B`B07-S=6UP=&4B"@HC.B!M97-S86=E+G!H<#HR-C@@=&AR96%D+G!H
M<#HQ-3`@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L
M:6(O4V5A<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")!<W-U
M;7!T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C`*;7-G:60@(E-U
M8FIE8W0@1FEE;&0B"FUS9W-T<B`B4&5R($%S<W5M<'1E(@H*(SH@<V5A<F-H
M+G!H<#HS,3@@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C$X
M"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,"!T96UP;&%T
M97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")3=6)M
M:70B"FUS9W-T<B`B07-S=6UP=&4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*
M;7-G<W1R(")3=6)S8W)I=7)E)W,@82!L82!#87)P971A*&5S*2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@P(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C,X.0HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX-PIM
M<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+(>&ET(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G
M<W1R(")3=6=G97)I;65N=',B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C8R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(E-U
M;6UA<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#`P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,PIM
M<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W
M:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O
M('!L86EN('1E>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#$Y"B,L(&9U>GIY"FUS9VED(")4
M95]X="(*;7-G<W1R(")497AT(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C(V.0IM<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,0IM<V=I9"`B5&5N=&%T:79E;'D@
M06-C97!T(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<V,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N
M="YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5R;7,@;V8@4V5R=FEC
M92!F:6QE(&YO="!S<&5C:69I960@:6X@8V]N9BYP:'`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,P"FUS9VED(")4
M97AT(@IM<V=S='(@(E1E>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.34T"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H
M;W5L9"!B92!L:6YK960Z(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z-3,R"FUS9VED("(B"B)4:&4@24U!4"!S97)V97(@9&]E<R!N;W0@
M87!P96%R('1O('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"`B
M"B)S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE
M9&]U8FQE+G!H<#HT,0IM<V=I9"`B5&AE($UA8VEN=&]S:"!R97-O=7)C92!F
M;W)K(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L
M92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($UA8VEN=&]S:"!R
M97-O=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+B(*;7-G<W1R("(B
M"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("),82!I9&5N=&ET870@7"(E<UPB(&AA(&5S=&%T(&5L:6UI
M;F%D82XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!S
M879E9"XB"FUS9W-T<B`B3&$@:61E;G1I=&%T(%PB)7-<(B!H82!E<W1A="!D
M97-A9&$N(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A
M8VAM96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV.0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@
M:7,@:6YV86QI9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S
M92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E
M="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT
M,@IM<V=I9"`B5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A
M<F4@8F5L;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@
M<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(DQA*&5S*2!C87)P971A*&5S
M*2!<(B5S7"(@<V5RX"AN*2!R96YO;65N861A*&5S*2!A(%PB)7-<(BXB"@HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3`W"FUS9VED("(B"B)4:&4@8W5R
M<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R
M(&-O=6QD(&YO="!B92!R971R:65V960B"FUS9W-T<B`B(@H*(SH@8V]M<&]S
M92YP:'`Z,3(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9')A9G0@:&%S
M(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F;VQD97(N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,SD*;7-G:60@(E1H92!E
M=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X
M<&%N9&5D+B(*;7-G<W1R("),82!I9&5N=&ET870@7"(E<UPB(&AA(&5S=&%T
M(&5L:6UI;F%D82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B
M"FUS9W-T<B`B3&$@8V%R<&5T82!<(B5S7"(@:F$@97AI<W1E:7@B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN
M(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O8FQE;7,N(%!L96%S92!S
M964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3&$@
M8V%R<&5T82!<(B5S7"(@8V]N=.D@8V%RX&-T97)S(&ELMVQE9V%L<R!E;B!E
M;"!S974@;F]M+B!!:7CR('!O="!C875S87(@("(*(G!R;V)L96UE<RX@4VD@
M=7,@<&QA=2P@8V]N=&%C=&5U(&PG861M:6YI<W1R861O<B!D96P@<VES=&5M
M82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&-R96%T960@8G5T('EO=2!W97)E
M(&YO="!S=6)S8W)I8F5D('1O(&ET+B(*;7-G<W1R("),82!C87)P971A(%PB
M)7-<(B!H82!E<W1A="!C<F5A9&$@<&5R\B!N;R!H:2!H974@97-T870@<W5B
M<V-R:70N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!D96QE=&5D(&)U="!Y;W4@
M=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N(@IM<V=S='(@(DQA(&-A
M<G!E=&$@7"(E<UPB(&AA(&5S=&%T(&5L:6UI;F%D82!P97+R(&YO(&AI(&AE
M=2!E<W1A="!D97-U8G-C<FET+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,T,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T
M(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B(@HB3&$@8V%R<&5T82!<(B5S7"(@;F\@:&$@97-T870@8W)E861A+B!!
M:7CR(.ES(&5L('%U92!H82!D:70@96P@<V5R=FED;W(B"@HC.B!L:6(O1F]L
M9&5R+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<
M(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED(@IM<V=S='(@(DQA(&-A<G!E=&$@7"(E<UPB(&YO(&AA(&5S=&%T
M(&5L:6UI;F%D82X@06EX\B#I('%U92!H82!D:70@96P@<V5R=FED;W(B"@HC
M.B!L:6(O1F]L9&5R+G!H<#HS-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+B(*;7-G
M<W1R("),82!C87)P971A(%PB)7-<(B!H82!E<W1A="!C<F5A9&$@<V%T:7-F
M86-T\G)I86UE;G0N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L
M;'D@9&5L971E9"XB"FUS9W-T<B`B3&$@8V%R<&5T82!<(B5S7"(@:&$@97-T
M870@96QI;6EN861A('-A=&ES9F%C=/)R:6%M96YT+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C0U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@7"(E<UPB+B(*;7-G
M<W1R("),82!C87)P971A(%PB)7-<(B!H82!E<W1A="!R96YO;65N861A('-A
M=&ES9F%C=/)R:6%M96YT(&$@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]T;F5F+G!H<#HY,@IM<V=I9"`B5&AE(&9O;&QO=VEN9R!F:6QE<R!W97)E
M(&%T=&%C:&5D('1O('1H:7,@<&%R=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]S879E:6UA9V5?=VEN+FIS.C$R"FUS9VED
M("(B"B)4:&4@:6UA9V4@<V%V92!W:6YD;W<@8V%N(&YO="!B92!O<&5N960N
M(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B`B"B)T;R!B;&]C
M:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:'1M;"YP:'`Z.3<*;7-G:60@(B(*(E1H92!I;6%G97,@=VEL;"!B92!D
M:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U
M<B`B"B)A9&1R97-S8F]O:RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z-S4*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE
M<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0IM<V=I
M9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN
M9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H92!M86EL('-E<G9E<B!G
M96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.B(*;7-G<W1R("(B"@HC
M.B!L:6(O365S<V%G92YP:'`Z-C4Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R
M("),82!C87)P971A(%PB)7-<(B!J82!E>&ES=&5I>"(*"B,Z(&QI8B]&971C
M:&UA:6PN<&AP.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G
M92!<(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H
M('-I>F4@;&EM:70N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3`S"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G
M92!B96EN9R!C;VUP;W-E9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N(@IM
M<V=S='(@(D5L(&UI<W-A=&=E('%U92!E<W1A=F5U(')E9&%C=&%N="!S)VAA
M('1A;F-A="X@4V]R=&EN="XB"@HC.B!M97-S86=E+G!H<#HQ-#@*(RP@9G5Z
M>GD*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(DQA(&ED96YT:71A="!<(B5S7"(@:&$@97-T870@96QI;6EN861A+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(DQA
M(&ED96YT:71A="!<(B5S7"(@:&$@97-T870@9&5S861A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN
M:G,Z,3`@=&5M<&QA=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@
M(B(*(E1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E
M<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P
M;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT
M(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@
M(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M
M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O>FEP+G!H<#HV-`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@
M;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H;65N="XB"FUS9W-T<B`B(@H*
M(SH@;65S<V%G92YP:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S
M86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N
M('EO=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@
M=&\@<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4
M:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@
M;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U
M<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R("),82!S:6=N871U
M<F$@;F\@:&$@<&]G=70@Z7-S97(@<F5E;7!L8>=A9&$N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#(*;7-G:60@(E1H92!S:6=N871U
M<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"XB"FUS9W-T<B`B3&$@<VEG
M;F%T=7)A(',G:&$@<F5E;7!L8>=A="!S871I<V9A8W3R<FEA;65N="XB"@HC
M.B!A='1A8VAM96YT+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!S=&%T:6]N97)Y+G!H
M<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE
M<GD@7"(E<UPB(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R("),82!I9&5N=&ET
M870@7"(E<UPB(&AA(&5S=&%T(&1E<V%D82XB"@HC.B!S=&%T:6]N97)Y+G!H
M<#HV,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE
M<GD@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DQA(&ED96YT
M:71A="!<(B5S7"(@:&$@97-T870@96QI;6EN861A+B(*"B,Z('-T871I;VYE
M<GDN<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A
M=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@=7!D871E9"XB"FUS9W-T<B`B3&$@
M:61E;G1I=&%T(%PB)7-<(B!H82!E<W1A="!E;&EM:6YA9&$N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$V.0IM<V=I9"`B5&AE('1A<VL@:&%S
M(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*(RP@9G5Z>GD*;7-G:60@
M(E1H92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(F5L:6UI;F%R(&UI
M<W-A=&=E(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N
M(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.#`*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE
M9"!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H
M92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L
M(&9U>GIY"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM
M<V=S='(@(E)E9&ER:6=I<B!A<75E<W0@;6ES<V%T9V4B"@HC.B!L:6(O34E-
M12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W
M960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ-30*(RP@9G5Z>GD*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(DQA
M('-I9VYA='5R82!S)VAA(')E96UP;&'G870@<V%T:7-F86-T\G)I86UE;G0N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM<V=I
M9"`B5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+V5M<'1Y7VUA:6QB;W@N:6YC.C,*;7-G:60@(E1H97)E(&%R92!N
M;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N(@IM<V=S='(@(DYO(&AI(&AA
M(&UI<W-A=&=E<R!E;B!A<75E<W1A(&+Z<W1I82XB"@HC.B!T:')E860N<&AP
M.C$P.0IM<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-C$R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(B(*(DAI(&AA(&AA9W5T('5N('!R;V)L96UA(&%L(&)U:61A<B`E
M<RX@06EX\B#I<R!E;"!Q=64@:&$@9&ET(&5L('-E<G9I9&]R(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@HB2&D@:&$@:&%G=70@=6X@
M<')O8FQE;6$@86QB=6ED87(@;&$@8OIS=&EA+B!!:7CR(.ES(&5L('%U92!H
M82!D:70@96P@<V5R=FED;W(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C(Q"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O
M>"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)(
M:2!H82!H86=U="!U;B!P<F]B;&5M82!A;&)U:61A<B!L82!B^G-T:6$N($%I
M>/(@Z7,@96P@<75E(&AA(&1I="!E;"!S97)V:61O<B(*"B,Z(&QI8B]-97-S
M86=E+G!H<#HY,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@
M=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM
M<V=S='(@(B(*(DA)(&AA(&AA9W5T('5N(&5R<F]R(&%L(&-O<&EA<B!M:7-S
M871G97,@82!<(B5S7"(N($%I>/(@Z7,@<75E(&5L('%U92!H82!D:70@(@HB
M96P@<V5R=FED;W(B"@HC.B!L:6(O365S<V%G92YP:'`Z,3DX(&QI8B]-97-S
M86=E+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B!<
M(B5S7"(N(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B(@HB2&D@:&$@:&%G=70@=6X@97)R;W(@86P@96QI;6EN87(@;6ES<V%T
M9V5S(&1E(&QA(&-A<G!E=&$@7"(E<UPB+B!!:7CR(.ES(&5L("(*(G%U92!H
M82!D:70@96P@<V5R=FED;W(B"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)(:2!H82!H86=U
M="!U;B!E<G)O<B!A;"!E;&EM:6YA<B!E;',@;6ES<V%T9V5S(&1E(&QA(&-A
M<G!E=&$@7"(E<UPB+B!!:7CR(.ES("(*(F5L('%U92!H82!D:70@96P@<V5R
M=FED;W(B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S
M<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S
M='(@(B(*(DAI(&AA(&AA9W5T('5N(&5R<F]R(&%L(&5L:6UI;F%R(&UI<W-A
M=&=E<RX@06EX\B#I<R!E;"!Q=64@:&$@9&ET(&5L('-E<G9I9&]R(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.CDY"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V
M96YT.B`E<RXB"FUS9W-T<B`B2&D@:&$@:&%G=70@=6X@97)R;W(@86P@=FES
M=6%L:71Z87(@96P@;6ES<V%T9V4@<V]LMVQI8VET870N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR:6-H
M960N<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")(:2!H82!H86=U="!U;B!E
M<G)O<B!A;"!V:7-U86QI='IA<B!A<75E<W1A('!A<G0@9&5L(&UI<W-A=&=E
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4T-2!L:6(O365S<V%G92YP:'`Z-3@U
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!F
M;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)(:2!H82!H
M86=U="!U;B!E<G)O<B!A;"!M87)C87(@;6ES<V%T9V5S(&$@;&$@8V%R<&5T
M82!<(B5S7"(N($%I>/(@Z7,@96P@<75E("(*(FAA(&1I=&5L('-E<G9I9&]R
M(@H*(SH@9F]L9&5R<RYP:'`Z,38U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R
M(")(:2!H82!H86=U="!U;B!E<G)O<B!A;"!D97-A<B!L)V5S8F]R<F%N>2XB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3,V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(DAI(&AA(&AA9W5T('5N(&5R<F]R
M(&%L('9I<W5A;&ET>F%R(&5L(&UI<W-A=&=E('-O;+=L:6-I=&%T+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-C8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M('1A<VLZ("5S+B(*;7-G<W1R(")(:2!H82!H86=U="!U;B!E<G)O<B!A;"!V
M:7-U86QI='IA<B!E;"!M:7-S871G92!S;VRW;&EC:71A="XB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F
M<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R(")(:2!H82!H86=U
M="!U;B!E<G)O<B!A;"!E;G9I87(@96P@=F]S=')E(&UI<W-A=&=E.B`E<R(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F
M<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R
M=F5R('-A:60B"FUS9W-T<B`B(@HB2&D@:&$@:&%G=70@=6X@97)R;W(@86P@
M;6]U<F4@;6ES<V%T9V5S(&$@7"(E<UPB+B!!:7CR(.ES(&5L('%U92!H82!D
M:70@96P@(@HB<V5R=FED;W(B"@HC.B!C;VUP;W-E+G!H<#HQ,C0T"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S
M<V%G92!A<R!A(&1R869T+B(*;7-G<W1R(")(:2!H82!H86=U="!U;B!E<G)O
M<B!A;"!V:7-U86QI='IA<B!A<75E<W1A('!A<G0@9&5L(&UI<W-A=&=E(@H*
M(SH@8V]M<&]S92YP:'`Z,3`P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM<V=S
M='(@(DAI(&AA(&AA9W5T('5N(&5R<F]R(&%L(&5N=FEA<B!E;"!V;W-T<F4@
M;6ES<V%T9V4Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(DAI(&AA(&AA
M9W5T('5N(&5R<F]R(&%L(&5N=FEA<B!E;"!V;W-T<F4@;6ES<V%T9V4Z("5S
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU.0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0B
M"FUS9W-T<B`B2&D@:&$@:&%G=70@=6X@97)R;W(@86P@=FES=6%L:71Z87(@
M87%U97-T82!P87)T(&1E;"!M:7-S871G92(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HY-PIM<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM
M86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.CDP"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G
M92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A
M<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y
M('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P-"!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3$X"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#,@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-PHC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,3<S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,30*
M;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T
M('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S
M;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B
M"FUS9W-T<B`B06EX\B!P;W0@=&%R9&%R('5N82!M:6-A+B"_17-TX',@<V5G
M=7(@<75E(&1E<VET:F$@8V]N=&EN=6%R/R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT
M86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C0Q,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E
M(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L
M;'D@<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$T"FUS9VED(")4:&ES(&UE<W-A9V4@
M8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E
M9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN
M<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F
M;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q-0IM<V=I9"`B(@HB
M5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'
M4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,S4P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN
M9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4:&ES(&UE<W-A9V4@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F;W)M870N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-2!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*;7-G:60@(E1H:7,@;65S<V%G
M92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30S"FUS9VED(")4
M:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-
M24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S.`IM<V=I9"`B5&AI
M<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#$@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,CDQ"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S
M(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G92!T;R(*;7-G<W1R(")!
M<75E<W0@;6ES<V%T9V4@82(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H:7,@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P
M.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R(")(974@9&4@8W)I9&%R
M(&%Q=65S=&$@9FEN97-T<F$@9&5S(&1E(&QA(&9I;F5S=')A(&1E(')E9&%C
M8VGS(@H*(SH@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A
M9"!$:7-P;&%Y(@IM<V=S='(@(E9I<W5A;&ET>F%R(@H*(SH@=&AR96%D+G!H
M<#HW-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(R"FUS9VED(")4:')E860@
M5FEE=R(*;7-G<W1R(")097(@4V5Q_.AN8VEA(@H*(SH@;65S<V%G92YP:'`Z
M,C8T(&UA:6QB;W@N<&AP.C8P-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C(Q.0HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C(R('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC
M.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R
M8V@N<&AP.C(V"FUS9VED(")4;R(*;7-G<W1R(")097(@82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,3D*(RP@9G5Z>GD*;7-G:60@(E1O($%D9')E
M<W,B"FUS9W-T<B`B1"=!9')EYV$@16QE8W1R\FYI8V$B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O('-E
M;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4
M;R!U<V4@82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A
M('9E<G-I;VX@;V8@4$A0(#4N,"XV(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3<W"B,L(&9U
M>GIY"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*;7-G<W1R(")!
M9&IU;G1A<B(*"B,Z(&9O;&1E<G,N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B
M5')A<V@@9F]L9&5R(@IM<V=S='(@(D-A<G!E=&$@4&%P97)E<F$Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A
M<V@@9F]L9&5R.B(*;7-G<W1R(")#87)P971A(%!A<&5R97)A.B(*"B,Z(&QI
M8B]1=6]T82]C>7)U<RYP:'`Z-C4@;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z
M-SD@;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1=6]T82]L;V=F
M:6QE+G!H<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A
M+VUD865M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O
M=&$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N
M86YS=V5R960B"FUS9W-T<B`B4V5N<V4@<F5S<&]N9')E(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M97-S
M86=E<R(*;7-G<W1R(")-:7-S871G97,@<V5N<V4@<F5S<&]N9')E(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C0@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@(E5N9&5L971E(@IM
M<V=S='(@(E)E8W5P97)A<B(*"B,Z(&UA:6QB;W@N<&AP.C4X.2!M86EL8F]X
M+G!H<#HV,#(@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$R"FUS9VED(")5;F1I
M<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(D1E<W1I;F%T87)I<R!$97-C
M;VYE9W5T(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0T-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z
M("5S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V-0IM<V=I9"`B56YK
M;F]W;B!$871E(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!4"!R97-P;VYS
M92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,S4*;7-G:60@
M(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HV
M,3@*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@
M(D1E<W1I;F%T87)I<R!$97-C;VYE9W5T(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@
M(E5N;&]A9"!087-S<&AR87-E(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R
M969S+G!H<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")396YS92!N;VTB
M"@HC.B!M97-S86=E+G!H<#HT.3D@;6%I;&)O>"YP:'`Z-S`X('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHU"FUS
M9VED(")5;G-E96XB"FUS9W-T<B`B3F\@=FES="(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C$R"FUS9VED(")5;G-U8G-C<FEB92!F<F]M
M($9O;&1E<BAS*2(*;7-G<W1R(")$97-U8G-C<FEU<F4G<R!D92!L82AE<RD@
M0V%R<&5T82AE<RDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU.#0*;7-G:60@(E5P9&%T92!!='1A8VAM96YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C`*;7-G
M:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-3@@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*;7-G
M:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(E5T:6QI='IA<B!686QO
M<B!097(@1&5F96-T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-38*
M(RP@9G5Z>GD*;7-G:60@(E5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS
M/R(*;7-G<W1R(")5=&EL:71A<B!S=6)S8W)I<&-I;VYS(&$@8V%R<&5T97,@
M24U!4"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,S4*(RP@9G5Z>GD*
M;7-G:60@(E5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\B"FUS9W-T<B`B0G5I
M9&%R(&QA(&-A<G!E=&$@4&%P97)E<F$B"@HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,30R"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(DYO;2!D
M)U5S=6%R:2(*"B,Z(&%C;"YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB57-E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I
M960@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-S<*;7-G:60@(E5S97)N
M86UE(@IM<V=S='(@(DYO;2!D)U5S=6%R:2(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z
M(@IM<V=S='(@(DYO;2!D)U5S=6%R:2(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-PHC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")6:65W(@IM<V=S='(@
M(E9E=7)E("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z.3(@;&EB
M+TU)344O5FEE=V5R+W1N968N<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(@IM<V=S='(@(E9E=7)E("5S(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(RP@9G5Z>GD*
M;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W
M(@IM<V=S='(@(E)E9&%C=&%R(&UI<W-A=&=E<R!E;B!U;F$@9FEN97-T<F$@
M87!A<G0N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C@*
M(RP@9G5Z>GD*;7-G:60@(E9I97<@365S<V%G97,B"FUS9W-T<B`B34ES<V%T
M9V5S($YO=7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R!097)S;VYA;"!0
M<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE
M=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I
M9"`B5FEE=R!4:')E860B"FUS9W-T<B`B4V5Q_.AN8VEA(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$V-0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GD*;7-G
M:60@(E9I97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G
M<W1R(")2961A8W1A<B!M:7-S871G97,@96X@=6YA(&9I;F5S=')A(&%P87)T
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!F=7IZ
M>0IM<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM
M<V=S='(@(E)E9&%C=&%R(&UI<W-A=&=E<R!E;B!U;F$@9FEN97-T<F$@87!A
M<G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B
M5FEE=R!E=F5N="(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS.#`@;6%I
M;&)O>"YP:'`Z-3,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(E9E=7)E(&UI<W-A=&=E<R!A(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM
M<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ
M(@IM<V=S='(@(E9I<W1A(&\@8OIS=&EA(&$@9&5S<&QE9V%R(&1E<W!RZ7,@
M9"=I;FEC:6%R(&QA('-E<W-I\SHB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,3<P"B,L(&9U>GIY"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B
M5F5U<F4@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`Q"B,L
M(&9U>GIY"FUS9VED(")6:65W('1H92!);6%G97,B"FUS9W-T<B`B5F5U<F4@
M;6ES<V%T9V5S(&$B"@HC.B!S96%R8V@N<&AP.C(V,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5FER='5A;"!&;VQD97(@7"(E<UPB(&-R96%T960@
M<W5C8V5S9G5L;'DN(@IM<V=S='(@(DQA(&-A<G!E=&$@7"(E<UPB(&AA(&5S
M=&%T(&5L:6UI;F%D82!S871I<V9A8W3R<FEA;65N="XB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$Q,2!L:6(O24U!4"]4<F5E+G!H<#HQ,S@@
M;&EB+TE-05`O5')E92YP:'`Z,34Q"B,Z(&QI8B])34%0+U1R964N<&AP.C$U
M,R!L:6(O24U!4"]4<F5E+G!H<#HQ-3<@;&EB+TE-05`O5')E92YP:'`Z,34X
M"B,Z(&QI8B])34%0+U1R964N<&AP.C,V.2!L:6(O24U!4"]4<F5E+G!H<#HS
M.3,@;&EB+TE-05`O5')E92YP:'`Z-#,S"B,L(&9U>GIY"FUS9VED(")6:7)T
M=6%L($9O;&1E<G,B"FUS9W-T<B`B0W)E87(@0V%R<&5T82(*"B,Z('-E87)C
M:"YP:'`Z,C0U"FUS9VED(")6:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA
M8F5L+B(*;7-G<W1R("(B"@HC.B!L:6(O5D9O;&1E<BYP:'`Z,3<U(&QI8B]6
M1F]L9&5R+G!H<#HQ.#`*;7-G:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`B
M(@H*(SH@9F]L9&5R<RYP:'`Z-#$V"FUS9VED(")6:7)T=6%L($E.0D]8($9O
M;&1E<B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HT-3(@;&EB+U9&;VQD
M97(N<&AP.C$Q-"!L:6(O5D9O;&1E<BYP:'`Z,3$Y"FUS9VED(")6:7)T=6%L
M(%1R87-H(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q,PHC+"!F=7IZ
M>0IM<V=I9"`B5FER='5A;"!4<F%S:"!&;VQD97(B"FUS9W-T<B`B0G5I9&%R
M(&QA(&-A<G!E=&$@4&%P97)E<F$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$S,PIM<V=I9"`B5FER='5A;"!F;VQD97(@;&%B96PB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S0*;7-G:60@
M(E=A<FYI;F<B"FUS9W-T<B`B07;M<R(*"B,Z(&QO9VEN+G!H<#HQ,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")"96YV
M:6YG=71S(&$@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$Y"FUS
M9VED("(B"B)7:&%T('-H;W5L9"!W92!D;R!W:71H('-P86T@;65S<V%G97,@
M869T97(@=&AE>2!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2`B"B)O<B!I
M;FYO8V5N=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<R-PHC+"!F=7IZ>0IM<V=I9"`B(@HB5VAE;B!D96QE=&EN9R!M97-S86=E
M<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E860@;V8@
M;6%R:VEN9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM<V=S='(@(B(*(E%U86X@
M96QI;6EN974@;6ES<V%T9V5S+"!E;',@:&5U(&1E(&UO=7)E(&$@;&$@4&%P
M97)E<F$@96X@;&QO8R!D92!M87)C87(M(@HB;&]S(&-O;2!E;&EM:6YA=',N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-PIM<V=I9"`B5VAE;B!O
M<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A;G0@
M=&\@<W1A<G0@;VX_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-C$*;7-G:60@(E=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD
M('=E('-A=F4@871T86-H;65N="!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(V"FUS9VED("(B"B)7:&5N('-E;F1I;F<@
M;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U
M;&0@=V4@87!P96YD('1O("(*(G5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA
M:6P@861D<F5S<V5S('=I=&AO=70@7")`7"(I/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E=H:71E;&ES="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW.`IM<V=I9"`B665S(@IM<V=S
M='(@(E/M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO
M9VEN+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!A8F]U="!T;R!F
M971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N="AS*3HB"FUS
M9W-T<B`B17-T974@:6YT96YT86YT(&5L:6UI;F%R(&QE<R!C87)P971E<R!S
M96?\96YT<SHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I
M<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U(&%R92!A='1E;7!T
M:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R(")%<W1E=2!I;G1E;G1A
M;G0@96QI;6EN87(@;&5S(&-A<G!E=&5S('-E9_QE;G1S.B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.CD*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@=&AE(&9O;&QO
M=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(D5S=&5U(&EN=&5N=&%N="!E;&EM
M:6YA<B!L97,@8V%R<&5T97,@<V5G_&5N=',Z(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z,3DR"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&-O<'EI
M;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B17-T974@<F5N
M;VUE;F%N="!L82!C87)P971A.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$P,@IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U
M8BUF;VQD97(@=&\@(@IM<V=S='(@(D5S=&5U(&-R96%N="!U;F$@<W5B+6-A
M<G!E=&$@82`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$P-`IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD
M97(N(@IM<V=S='(@(D5S=&5U(&-R96%N="!U;F$@8V%R<&5T82!D92!N:79E
M;&P@<W5P97)I;W(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(P"B,L(&9U>GIY
M"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!F;VQD97)S
M+B(*;7-G<W1R(")%<W1E=2!C<F5A;G0@=6YA(&-A<G!E=&$@9&4@;FEV96QL
M('-U<&5R:6]R+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S4*;7-G:60@(EEO=2!A<F4@<F5N86UI
M;F<@=&AE(&9O;&1E<CH@(@IM<V=S='(@(D5S=&5U(')E;F]M96YA;G0@;&$@
M8V%R<&5T83H@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M
M(%PB)7-<(BXB"FUS9W-T<B`B2&5U(&5S=&%T(&1E<W5B<V-R:70@<V%T:7-F
M86-T\G)I86UE;G0@9&4@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C,U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!C
M86X@=7-E('1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&EN('1H92!S=&%T
M:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@(@HB8W5R<F5N="!M97-S86=E(&-O
M;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T=7)E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HS-`IM<V=I
M9"`B(@HB66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I
M8V4@86=R965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"`B"B)T;R!L
M;V=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V
M.0IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E
M(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!L:6(O36%I
M;&QO9RYP:'`Z,3(Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D
M960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP
M:65N=',Z("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M;&5R="YI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N
M97<@;65S<V%G97,N(@IM<V=S='(@(E1E;FEU("5S(&UI<W-A=&=E<R!N;W5S
M+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED(")9
M;W4@:&%V92`Q(&YE=R!M97-S86=E+B(*;7-G<W1R(")496YI=2`Q(&UI<W-A
M=&=E(&YO=2XB"@HC.B!C;VUP;W-E+G!H<#HT.30*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!H879E(&%L<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T
M<B`B5&5N:74@,2!M:7-S871G92!N;W4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O871T86-H;65N=',N:G,Z,3$U"FUS9VED("(B"B)9;W4@:&%V92!A="!L
M96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@
M=7!L;V%D('EE="X@07)E("(*(GEO=2!S=7)E('EO=2!W86YT('1O('-E;F0@
M=&AI<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N=',_(@IM<V=S
M='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-S0*;7-G:60@(EEO=2!H879E(&YE
M=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R(")496YI
M=2!C;W)R974@;F]U(&$@;&$@8V%R<&5T82!S96?\96YT.B(*"B,Z(&QI8B])
M35`N<&AP.C$P-SD*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`B5&5N:74@8V]R<F5U(&YO=2!A
M(&QE<R!C87)P971E<R!S96?\96YT<SHB"@HC.B!C;VUP;W-E+G!H<#HQ-3,*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R
M96-I<&EE;G0N(@IM<V=S='(@(DAE=2!D92!T96YI<BP@86P@;65N>7,L('5N
M(&1E<W1I;F%T87)I(&5N(&5L(&-A;7`@4$52($$Z(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,S`R"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T
M:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE
M=R!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HR-#D*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W
M('1H:7,@(@HB;65S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]J879A<V-R:7!T+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A
M<V-R:7!T+FEN8SHR,#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E
M="!M86EL8F]X(&9I<G-T+B(*;7-G<W1R(")0<FEM97(@:&5U(&1E('-E;&5C
M8VEO;F%R('5N82!B^G-T:6$@9&4@9&5S=.TN(@H*(SH@9F5T8VAM86EL<')E
M9G,N<&AP.C@U"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")(974@9&4@<V5L96-C
M:6]N87(@=6YA(&ED96YT:71A="!A(&5L:6UI;F%R+B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z.#$*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R(")0<FEM97(@:&5U(&1E
M('-E;&5C8VEO;F%R('5N82!A9')EYV$N(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N
M:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M
M97-S86=E(&9I<G-T+B(*;7-G<W1R(")0<FEM97(@:&5U(&1E('-E;&5C8VEO
M;F%R+"!A;"!M96YY<RP@=6X@;6ES<V%T9V4N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@<F5C:7!I96YT+B(*;7-G<W1R(")(974@9"=E<W!E8VEF:6-A<B!U;B!D
M97-T:6YA=&%R:2!E;B!E;"!C86UP(%!%4B!!.B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C(Y"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!F:6QE('1O(&%T=&%C:"XB"FUS
M9W-T<B`B4')I;65R(&AE=2!D)V5S<&5C:69I8V%R(&PG87)X:74@<75E('9O
M;&5U(&%D:G5N=&%R+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@;F5E9"!T;R!H879E
M(%PB)7-<(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$S-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(')E9&ER96-T960@=&AI<R!M97-S86=E
M('1O("5S(&]N("4E<RXB"FUS9W-T<B`B4F5D:7)I9VER(&%Q=65S="!M:7-S
M871G92(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EEO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E
M<RXB"FUS9W-T<B`B4F5D:7)I9VER(&%Q=65S="!M:7-S871G92(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R
M92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B3F\@:&5U(&5S=&%T('-U8G-C<FET(&$@
M7"(E<UPB+B!!:7CR(.ES(&5L('%U92!H82!D:70@96P@<V5R=FED;W(B"@HC
M.B!L:6(O1F]L9&5R+G!H<#HU-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W
M:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(").;R!H974@97-T870@9&5S
M=6)S8W)I="!D92!<(B5S7"(N($%I>/(@Z7,@96P@<75E(&AA(&1I="!E;"!S
M97)V:61O<B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4Q,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R!<
M(B5S7"(B"FUS9W-T<B`B2&5U(&5S=&%T('-U8G-C<FET('-A=&ES9F%C=/)R
M:6%M96YT(&$@7"(E<UPB(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-38R"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C
M<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B2&5U(&5S=&%T(&1E<W5B<V-R
M:70@<V%T:7-F86-T\G)I86UE;G0@9&4@7"(E<UPB(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.CDX"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`B16P@=F]S=')E(&YO;6-O;7!L970Z(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C4P"FUS9VED(")9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+
M97ES(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-S$@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<V"FUS9VED(")9;W5R(%!R:79A
M=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<Q"B,L(&9U>GIY"FUS9VED
M(")9;W5R(%!U8FQI8R!+97DB"FUS9W-T<B`B16P@=F]S=')E(&YO;6-O;7!L
M970Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V-0HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!297!L>2UT;SH@861D<F5S<SH@/&5M/BAO<'1I;VYA;"D\
M+V5M/B(*;7-G<W1R("),82!V;W-T<F$@861R9>=A(&5L96-T<O)N:6-A(%PB
M4F5S<&]N9')E+6%<(CH@/&D^*&]P8VEO;F%L*3PO:3XB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-12!0=6)L
M:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S='(@(DQE<R!V;W-T<F5S(&ED
M96YT:71A=',Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PIM<V=I
M9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N
M=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDR"B,L(&9U>GIY
M"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@
M9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(B(*(D5L('9O
M<W1R92!N879E9V%D;W(@;F\@861M970@;"=O<&-I\R!D)VEM<')E<W-I\RX@
M4')E<W-I;VYE=2!#;VYT<F]L+T]P8VGS("L@(@HB4"!P97(@:6UP<FEM:7(N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D
M969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS
M9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I
M;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")9;W5R(&UE<W-A9V4@=V%S
M('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(DQA(&-A<G!E=&$@
M7"(E<UPB(&AA(&5S=&%T(&5L:6UI;F%D82!S871I<V9A8W3R<FEA;65N="XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I
M9VYA='5R93HB"FUS9W-T<B`B3&$@=F]S=')A('-I9VYA='5R83HB"@HC.B!M
M97-S86=E+G!H<#HR.#@@8V]M<&]S92YP:'`Z,3(X-"!M86EL8F]X+G!H<#HU
M-#D@;&EB+T-O;7!O<V4N<&AP.C@Q.`IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM
M<V=S='(@(EM396YS92!!<W-U;7!T95TB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR,#4*(RP@9G5Z>GD*;7-G:60@(E]"8V,B"FUS9W-T
M<B`B0F-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"B,L(&9U
M>GIY"FUS9VED(")?0FQA8VML:7-T(@IM<V=S='(@(DQL:7-T82!N96=R82(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$U-`HC+"!F=7IZ
M>0IM<V=I9"`B7T-C(@IM<V=S='(@(D-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ
M,`HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")%;&EM:6YA<B(*
M"B,Z(&QI8B])35`N<&AP.CDW.0HC+"!F=7IZ>0IM<V=I9"`B7T9O;&1E<G,B
M"FUS9W-T<B`B0V%R<&5T97,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@
M(DED96YT:71A="(*"B,Z(&QI8B])35`N<&AP.CDV,0IM<V=I9"`B7TEN8F]X
M(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P,C`*(RP@9G5Z>GD*;7-G
M:60@(E],;V<@;W5T(@IM<V=S='(@(E-O<G1I<B!D92!L82!S97-S:?,B"@HC
M.B!M97-S86=E+G!H<#HS.#0*(RP@9G5Z>GD*;7-G:60@(E]-97-S86=E(%-O
M=7)C92(*;7-G<W1R(")&;VYT(@H*(SH@;&EB+TE-4"YP:'`Z.3<V"B,L(&9U
M>GIY"FUS9VED(")?3F5W($UE<W-A9V4B"FUS9W-T<B`B34ES<V%T9V5S($YO
M=7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,S,*(RP@9G5Z>GD*;7-G:60@(E]0<FEN="(*;7-G<W1R("));7!R:6UI<B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.#D*;7-G:60@(E]0<FEO<FET>2(*
M;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@(E)E9G)E<V-A<B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"B,L
M(&9U>GIY"FUS9VED(")?4F5P;'DB"FUS9W-T<B`B4F5S<&]N9')E(@H*(SH@
M;&EB+TE-4"YP:'`Z.3@Q"B,L(&9U>GIY"FUS9VED(")?4V5A<F-H(@IM<V=S
M='(@(D-E<F-A<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0HC+"!F=7IZ
M>0IM<V=I9"`B7U-E;F0@365S<V%G92(*;7-G<W1R(")%;G9I87(@36ES<V%T
M9V4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C,R"B,L(&9U>GIY"FUS9VED(")?5&AR96%D(@IM<V=S='(@(E-E<?SH;F-I
M82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Q-@HC+"!F
M=7IZ>0IM<V=I9"`B7U1O(@IM<V=S='(@(E!E<B!A(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E]5;F1E
M;&5T92(*;7-G<W1R(")296-U<&5R87(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(E]6:65W
M(%1H<F5A9"(*;7-G<W1R(")397'\Z&YC:6$B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C$W-@IM<V=I9"`B861D<F5S<V5E('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0T,`HC+"!F=7IZ
M>0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R(")!9&IU;G1A<B!A<GAI=2(*
M"B,Z('9I97<N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")A='1A8VAM96YT<RYZ
M:7`B"FUS9W-T<B`B061J=6YT87(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU,3,*;7-G:60@(F)Y=&5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HR,#`*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T
M(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W,@IM<V=I
M9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C$V-`IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C`*;7-G:60@(F-O;F9I
M9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C$Y-@IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G
M<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38X"FUS9VED(")D871A(&9O
M<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(T
M"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS
M9W-T<B`B9&4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@P"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,C`T"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$X.`IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(Y('!G<"YP:'`Z-CD*
M;7-G:60@(FME>2(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HQ-C$*(RP@
M9G5Z>GD*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R(")"^G-T:6$B"@HC
M.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*(RP@9G5Z
M>GD*;7-G:60@(FYA;64B"FUS9W-T<B`B3F]M(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C<V"FUS9VED(")N;VYE(@IM<V=S='(@(F-A
M<"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G
M:60@(F]R(@IM<V=S='(@(F\B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$V"FUS
M9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,C$R"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-`IM<V=I9"`B<V5R
M=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R(@IM
M<V=S='(@(F5R<F]R(&0G;W)T;V=R869I82(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W)S(@IM
M<V=S='(@(F5R<F]R<R!D)V]R=&]G<F%F:6$B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3DR"B,L(&9U>GIY"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B
M97)R;W(@9"=O<G1O9W)A9FEA(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P.`IM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I
M;'1E<BYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM
M<V=S='(@(DQL:7-T82!N96=R82(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS
M9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R("(B"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O<&\O8G-?0D$N<&\`````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S<W,38S`#$P-#$W,S8R-S8T
M`#`Q-S$U-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C('1R86YS;&%T:6]N(&]F(&EM<"UB<RYP;R!T;R!";W-N:6%N"B,@
M0F]S;FEA;B!T<F%N<VQA=&EO;G,@9F]R(&EM<"!P86-K86=E+@HC($-O<'ER
M:6=H="`H0RD@,C`P,R!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I
M<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(&EM<"!P
M86-K86=E+@HC($%U=&]M871I8V%L;'D@9V5N97)A=&5D+"`R,#`S+@HC($%L
M96X@4V%R:VEN;W9I8R`\86QE;D!L:6YU>"YO<F<N8F$^+"`R,#`U+@HC(%9E
M9')A;B!,:G5B;W9I8R`\=FQJ=6)O=FEC0'-M87)T;F5T+F)A/BP@,C`P-2X*
M(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@:6UP
M+6)S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-RTP,2`Q,SHR."LP
M,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%9E9')A;B!,:G5B;W9I8R`\=FQJ
M=6)O=FEC0'-M87)T;F5T+F)A/EQN(@HB3&%N9W5A9V4M5&5A;3H@0F]S;FEA
M;B`\;&]K86Q`;&EN=7@N;W)G+F)A/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U
M.2TR7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)8
M+4=E;F5R871O<CH@2T)A8F5L(#$N,3!<;B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HT,3@*(RP@9G5Z>GD*;7-G:60@(B`@("`@($-C.B`B"FUS9W-T<B`B("`@
M("!:83H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q-0IM<V=I9"`B("`@("`@
M5&\Z("(*;7-G<W1R("(@("`@(%IA.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M-#`S"FUS9VED("(@("`@1&%T93H@(@IM<V=S='(@(B`@($1A='5M.B`B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z-#`V"FUS9VED("(@("`@1G)O;3H@(@IM<V=S
M='(@(B`@("`@($]D.B`B"@HC.B!M86EL8F]X+G!H<#HT,C(@=&5M<&QA=&5S
M+V9O;&1E<G,O:&5A9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C
M8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q
M,@IM<V=I9"`B(%-U8FIE8W0Z("(*;7-G<W1R("(@5&5M83H@(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<P"FUS9VED("(@:6X@(@IM
M<V=S='(@(B!U("(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T<B`B(R(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@
M+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B`O("4N,F9-0B`@
M*"4N,F8E)2DB"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T<B`B3F5M82!P;W)U:V$B
M"@HC.B!M86EL8F]X+G!H<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")/
M8G)I<V%N;R!J92`E9"!P;W)U:V$N(@H*(SH@;&EB+U-P86TN<&AP.C$W.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E9"!M97-S86=E<R!H879E(&)E96X@
M<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B)60@<&]R=6MA(&IE('!R:6IA=FQJ96YO(&1A(&YI
M<W4@<W!A;2!A9&UI;FES=')A=&]R=2!S:7-T96UA+B(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(E9"!P;W)U
M:V$@:F4@<')I:F%V;&IE;F\@9&$@;FES=2!S<&%M+B(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B)60@<&]R=6MA(&IE('!R:6IA=FQJ96YO(&MA
M;R!S<&%M(&%D;6EN:7-T<F%T;W)U('-I<W1E;6$N(@H*(SH@;&EB+U-P86TN
M<&AP.C$U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E
M(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`B)60@<&]R=6MA(&IE
M('!R:6IA=FQJ96YO(&MA;R!S<&%M+B(*"B,Z(&UA:6QB;W@N<&AP.C,W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*
M;7-G<W1R(")0;W)U:V4@)60@9&\@)60@;V0@=6MU<&YO("5D(@H*(SH@;6%I
M;&)O>"YP:'`Z-C0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S
M='(@(B5S($M"(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E
M;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M
M960N(@IM<V=S='(@(B5S('9EYB!P;W-T;VII+B!);64@)7,@9F]L9&5R82!N
M:6IE('!R;VUJ96YJ96YO+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B)7,@;F4@:7IG;&5D82!K86\@9&]Z
M=F]L:F5N('1I<"!S86YD=>AE=&$N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R
M="!O9B!T:&4@;6]N=&@N(@IM<V=S='(@(DEM92`E<R!F;VQD97)A(&IE('!R
M;VUJ96YJ96YO('!OZ&5T:V]M(&UJ97-E8V$N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@
M86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C
M86YC96QL960@)7,N(@IM<V=S='(@(DEM92!F;VQD97)A(%PB)7-<(B!J92!U
M<W!J9;EN;R!P<F]M:F5N:F5N;R!U(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!D96-L:6YE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C0Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE
M9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E
M<RXB"FUS9W-T<B`B57-M:F5R:2!O=G4@<&]R=6MU(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0X,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B3V1G;W9O<FD@=')AOF5N;VT@<VQO8F]D86XO>F%U>F5T(&EN9F]R
M;6%C:6IO;2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U
M<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(D]D9V]V;W)I('1R
M8;YE;F]M('-L;V)O9&%N+WIA=7IE="!I;F9O<FUA8VEJ;VTN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB
M"FUS9W-T<B`B26UE(&9O;&1E<F$@7"(E<UPB(&IE('5S<&IEN6YO('!R;VUJ
M96YJ96YO('4@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N
M9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y
M;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S
M('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RXB
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C@U(&UE<W-A9V4N<&AP.C(Y
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7W1O<"YI;F,Z,3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I(@IM<V=S
M='(@(B5S.B`E<R`H)60F;F)S<#MO9"9N8G-P.R5D*2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(BA!<'!L>2!T:&5S
M92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BDB"FUS9W-T<B`B
M*%!R:6UJ96YI(&]V92!I>FUJ96YE(&D@:61I(&YA('-L:F5D9>9I(&5K<F%N
M+BDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P"FUS
M9VED("(H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C
M;VUP;W-E('-C<F5E;BXI(@IM<V=S='(@(BA/9&)A8VD@<W9E(&EZ;6IE;F4@
M:2!V<F%T:2!S92!N82!E:W)A;B!Z82!P:7-A;FIE+BDB"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*
M;7-G:60@(BA0;&%I;B!497AT*2(*;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP
M:'`Z,C@P"FUS9VED("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E
M;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@
M(@HB0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@
M87!P;&EE9"XI(@IM<V=S='(@(B(*(BA6<F%T:2!S92!N82!E:W)A;B!Z82!P
M:7-A;FIE('!O<VQI:F4@<')I;65N92!S=FEH(&EZ;6IE;F$@9&\@<V%D82X@
M27IM:F5N92`B"B)N82!T<F5N=71N;VT@96MR86YU($Y%QD4@8FET:2!A:W1I
M=FER86YE+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"FUS9VED("(B"B(H4V5N
M9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU
M<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W:6QL
M($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*%!ON6%L:FD@<&]R=6MU
M(&YA:V]N(&%P;&EC:7)A;FIA('-V:6@@;F%P<F%V;&IE;FEH(&EZ;6IE;F$N
M("!)>FUJ96YE(&YA("(*(G1R96YU=&YO;2!E:W)A;G4@3D7&12!B:71I(&%K
M=&EV:7)A;F4N*2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C(W"FUS9VED("(J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J(@IM
M<V=S='(@(BH@1&]D86H@;W9E(&MA9"!K;&EK;F6Y(&YA($]+("HB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0
M;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS9W-T<B`B*B!-;VQI;2!I
M>F%B97)I=&4@861R97-E("HB"@HC.B!M86EL8F]X+G!H<#HQ-S0*(RP@9G5Z
M>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("))9&5N=&ET970@7"(E<UPB(&IE(&]B<FES86XN(@H*(SH@;&EB+U-P86TN
M<&AP.C$X,`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(C$@<&]R=6MA(&IE('!R:6IA=FQJ96YA(&1A(&YI:F4@<W!A;2!A9&UI
M;FES=')A=&]R=2!S:7-T96UA+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C`*;7-G
M:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB
M"FUS9W-T<B`B,2!P;W)U:V$@:F4@<')I:F%V;&IE;F\@9&$@;FEJ92!S<&%M
M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S(*;7-G:60@(C$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(C$@<&]R=6MA(&IE('!R:6IA=FQJ96YO(&MA;R!S
M<&%M(&%D;6EN:7-T<F%T;W)U('-I<W1E;6$N(@H*(SH@;&EB+U-P86TN<&AP
M.C$U,@IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P
M86TN(@IM<V=S='(@(C$@<&]R=6MA(&IE('!R:6IA=FQJ96YO(&MA;R!S<&%M
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*;7-G:60@(C$P,"!C
M:&%R86-T97)S(@IM<V=S='(@(C$P,"!Z;F%K;W9A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R,@IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S
M='(@(C$P,#`@>FYA:V]V82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,C`*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(C(U,"!Z;F%K;W9A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,0IM<V=I9"`B-3`P(&-H
M87)A8W1E<G,B"FUS9W-T<B`B-3`P('IN86MO=F$B"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B02!L
M87)G92!I;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I
M;VXN<&AP.C4P"FUS9VED("(B"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H
M87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE
M("(*(G)E8VEP:65N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]F:65L9',N:6YC.C4*;7-G:60@(D%.1"(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3DP"FUS9VED(")!8V-E<'0@<F5Q=65S
M="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W
M"FUS9VED(")!8V-E<'0@<F5Q=65S="!A;F0@861D(&ET('1O(&UY(&-A;&5N
M9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M-3,*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HR-3<*;7-G:60@(D%C8V5P=&5D.B`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*;7-G:60@
M(D%C8V]U;G0G<R!N86UE.B(*;7-G<W1R("));64@:V]R:7-N:>AK;V<@<F'H
M=6YA.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C`@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<S,`IM<V=I9"`B06-T:6]N<R(*;7-G<W1R
M(")!:V-I:F4B"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)
M344O2&5A9&5R<RYP:'`Z,C`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@)7,@=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@(D1O9&%J('4@
M:6UE;FEK("@E<RDB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHS,#,*;7-G:60@(D%D9"!S;W5R8V4B"FUS9W-T<B`B1&]D86H@:7IV
M;W(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<W(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A
M;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB(&%S(&%N(&%T=&%C:&UE;G0N
M(@IM<V=S='(@(D1O9&%N(%PB)7-<(B!K86\@<')I;&]G+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.3@*(RP@9G5Z>GD*;7-G:60@(B(*(D%D9&ET
M:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO
M<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@;&EN92D\
M+V5M/B(*;7-G<W1R("(B"B)$;V1A=&YA('!O;&IA('IA9VQA=FQJ82!Z82!P
M<FEK87HZ(#QI/BAN:6IE(&]B879E>FYO+"!U;F5S:71E('-V86MO('!O;&IE
M("(*(FAE861E<F$@:V]J92"^96QI=&4@=FED:F5T:2!U(&YO=FD@<F5D*3PO
M:3XB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(DUO9W7F92!J92!P<FEK87IA=&D@
M9&]D871N92!I;F9O<FUA8VEJ92`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HV,@IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA
M=&EO;B!D971A:6QS(@IM<V=S='(@(D1O9&%T;F4@:6YF;W)M86-I:F4B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`B1&]D871N92!I;F9O<FUA
M8VEJ92!O('!O<G5C:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D
M971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(DUO9W7F92!J92!P
M<FEK87IA=&D@9&]D871N92!I;F9O<FUA8VEJ92!O('!O<G5C:2`E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T<B`B1&]D871N92!I
M;F9O<FUA8VEJ92!O(&=R9;EC:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO
M;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*
M;7-G<W1R(")-;V=UYF4@:F4@<')I:V%Z871I(&1O9&%T;F4@:6YF;W)M86-I
M:F4@;R!P;W)U8VD@)7,N(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("));65N:6LB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"FUS9VED(")!9&1R97-S
M($)O;VMS(@IM<V=S='(@(DEM96YI8VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3@Y"B,L(&9U>GIY"FUS9VED("(B"B)!9&1R97-S97,@=&\@0D-#
M(&%L;"!M97-S86=E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R
M97-S(&]N(&$@;F5W("(*(FQI;F4I/"]E;3XB"FUS9W-T<B`B(@HB061R97-E
M(&MO:FEM82!T<F5B82!S;&%T:2!K;W!I:G4@<&]R=6MA.B`@/&D^*&YI:F4@
M;V)A=F5Z;F\L('5N97-I=&4@<W9A:W4@(@HB861R97-U('4@;F]V;VT@<F5D
M=2D\+VD^(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,0HC+"!F=7IZ
M>0IM<V=I9"`B(@HB061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H
M:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D
M<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(D%D<F5S92!E
M:W-P;&EC:71N;R!V97IA;F4@>F$@;W9A:B!I9&5N=&ET970Z("`\:3XH;FEJ
M92!O8F%V97IN;RP@=6YE<VET92`B"B)S=F%K=2!A9')E<W4@=2!N;W9O;2!R
M961U*3PO:3XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$P
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C,*;7-G:60@(D%L;"(*;7-G<W1R
M(")3=F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S
M"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD
M97(H<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@(@HB9FEL
M93HB"FUS9W-T<B`B(@HB4W9E('!O<G5K92!U('-L:F5D9>9I;2!F;VQD97)I
M;6$@YF4@8FET:2!D;W=N;&]A9&]V86YE('4@:F5D;G4@34)/6"!D871O=&5K
M=3HB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('EO
M=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P
M97)M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R("(B"B)3=F4@<&]R=6ME
M('4@=F&Y96T@7"(E<UPB(&9O;&1E<G4@<W1A<FEJ92!O9"`E<R!D86YA(.9E
M(&)I=&D@>F%U=FEJ96L@(@HB;V)R:7-A;F4N(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP.C4Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A
M8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T
M960N(@IM<V=S='(@(B(*(E-V:2!F;VQD97)I('!O<VQA;F4@<&^Y=&4@<W1A
M<FEJ:2!V:;EE(&]D("5S(&UJ97-E8VDL(.9E(&)I=&D@;V)R:7-A;FDN(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H
M;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D
M96QE=&5D+B(*;7-G<W1R("(B"B)3=FD@9F]L9&5R:2!P;W-L86YE('!ON71E
M('-T87)I:FD@=FFY92!O9"`E<R!M:F5S96-I+"#F92!B:71I(&]B<FES86YI
M+B(*"B,Z(&%C;"YP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L;'D@<F5M
M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(DEM92!F;VQD97)A(%PB
M)7-<(B!J92!U<W!J9;EN;R!P<F]M:F5N:F5N;R!U(%PB)7-<(BXB"@HC.B!L
M:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L9&5R($-R96%T:6]N/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#@*
M;7-G:60@(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N
M>2!M86EL8F]X/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O86QT
M97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B06QT97)N871I=F4@<&%R=',@9F]R
M('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4W,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@T"FUS9VED(")!
M;'=A>7,B"FUS9W-T<B`B579I:F5K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4U-PIM<V=I9"`B06QW87ES('-A=F4@871T86-H;65N=',B"FUS9W-T
M<B`B579I:F5K('IA<&%M=&D@<')I;&]G92(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HU,#4*;7-G:60@(B(*(D%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP
M=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE($E-05`@<V5R=F5R
M("(*(G-A:60Z("(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X
M"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI
M;&4@8W)E871I;F<@=&AE(&YE=R!N;W1E+B(*;7-G<W1R(")0<FEL:6MO;2!D
M;V1A=F%N:F$@;F]V;V<@>F%P:7-A(&IA=FEL82!S92!N97!O>FYA=&$@9W)E
MN6MA+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#<*(RP@9G5Z>GD*;7-G:60@
M(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@
M;F5W('1A<VLN(@IM<V=S='(@(E!R:6QI:V]M(&1O9&%V86YJ82!N;W9O9R!Z
M87!I<V$@:F%V:6QA('-E(&YE<&]Z;F%T82!G<F6Y:V$N(@H*(SH@;65S<V%G
M92YP:'`Z-3`P(&UA:6QB;W@N<&AP.C<Q-"!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,U"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-@IM<V=I9"`B06YS=V5R
M960B"FUS9W-T<B`B3V1G;W9O<F5N82(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@
M(D]D9V]V;W)E;F4@<&]R=6ME(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A
M9&5R+FEN8SHW"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(E!R:6UJ
M96YI(&9I;'1E<F4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07!P;'D@1FEL=&5R<R!T;R`E<R(*
M;7-G<W1R(")0<FEM:F5N:2!F:6QT97)E(&YA("5S(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS9VED(")!<'!L>2!F:6QT97(@<G5L
M97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")0<FEM96YI(&9I;'1E<B!P
M<F%V:6QA(&YA:V]N('!R:6IA=FQJ:79A;FIA/R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL
M=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS9W-T
M<B`B4')I;65N:2!F:6QT97(@<')A=FEL82!K861A('-E(&&^=7)I<F$@:6YB
M;W@_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(*;7-G<W1R(")$82!L:2!S
M=&4@<VEG=7)N:2!D82"^96QI=&4@;V)R:7-A=&D@;W9A:B!J879N:2!K;&IU
MZ#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHX-0HC+"!F=7IZ>0IM<V=I9"`B(@HB07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES
M($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(D1A(&QI('-T92!S:6=U<FYI
M(&1A(+YE;&ET92!O8G)I<V%T:2!O=F%J(&IA=FYI(&ML:G7H/R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&1O('1H:7,_(@IM<V=S='(@(D1A(&QI('-T92!S:6=U<FYI(&1A(+YE
M;&ET92!O=F\@=7)A9&ET:3\B"@HC.B!M97-S86=E+G!H<#HT,#<@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S
M<V%G97,_(@IM<V=S='(@(D1A(&QI('-T92!S:6=U<FYI(&1A(+YE;&ET92!O
M8G)I<V%T:2!O=F4@<&]R=6ME/R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H
M<#HR,34*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT/R(*;7-G<W1R
M(")$82!L:2!S=&4@<VEG=7)N:2!D82"^96QI=&4@;V)R:7-A=&D@;W9E('!O
M<G5K93\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L
M9&5R/R(*;7-G<W1R(")$82!L:2!S=&4@<VEG=7)N:2!D82"^96QI=&4@:7-P
M<F%Z;FET:2!O=F%J(&9O;&1E<C\B"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@
M9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y
M;W5R('-P86T@9F]L9&5R/R(*;7-G<W1R(")$82!L:2!S=&4@<VEG=7)N:2!D
M82"^96QI=&4@:7-P<F%Z;FET:2!F;VQD97(@2V]R<&$_(@H*(SH@;&EB+TE-
M4"YP:'`Z.38V"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP
M='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(D1A(&QI('-T92!S:6=U
M<FYI(&1A(+YE;&ET92!I<W!R87IN:71I(&9O;&1E<B!+;W)P83\B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE
M<W-A9V5S/R(*;7-G<W1R(")$82!L:2!S=&4@<VEG=7)N:2!D82"^96QI=&4@
M>F%U=FEJ96L@;V)R:7-A=&D@;W9E('!O<G5K93\B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]J879A<V-R:7!T+FEN8SHX,"!T96UP;&%T97,O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8SHW.0HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_
M(@IM<V=S='(@(D1A(&QI('-T92!S:6=U<FYI(&1A(+YE;&ET92!O8G)I<V%T
M:2!O=F4@<&]R=6ME/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I
M<'0N:6YC.C<U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T
M"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P
M;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*;7-G<W1R(")$82!L:2!S=&4@
M<VEG=7)N:2!D82"^96QI=&4@;V)R:7-A=&D@;W9E('!O<G5K93\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$V"FUS9VED(")!<G)I=F%L(%1I;64B
M"FUS9W-T<B`B5G)I:F5M92!P<FES=&EZ86YJ82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,S$*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")287-T
M=>9I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B4&ET86HB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3D*;7-G:60@(D%T
M=&%C:"(*;7-G<W1R("):86MAZ&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT-S4*(RP@9G5Z>GD*;7-G:60@(D%T=&%C:"!&:6QE<R(*
M;7-G<W1R(")0<FEL;WII(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#4V"FUS9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U
M8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O=&YE9BYP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")!='1A
M8VAE9"!&:6QE.B(*;7-G<W1R(")0<FEL;WII(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C0U,2!L:6(O0V]M<&]S92YP:'`Z-3,V"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C
M:&UE;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S<V"FUS9VED(")!
M='1A8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@
M<V5N="XB"FUS9W-T<B`B6F%K8>AE;B!J92!O9&=O=F]R(&YA(&MA;&5N9&%R
M<VMI('IA:'1J978@:V]J:2!S=&4@<&]S;&%L:2XB"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C$V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHQ-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU,#8@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3<*;7-G
M:60@(D%T=&%C:&UE;G0B"FUS9W-T<B`B4')I;&]G(@H*(SH@8V]M<&]S92YP
M:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")!='1A8VAM96YT
M('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W,PHC.B!L:6(O0V]M<&]S92YP
M:'`Z,3`W,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`B4')I;&]Z:2(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#(*(RP@9G5Z>GD*;7-G
M:60@(D%T=&5N9&5E<R(*;7-G<W1R(")0<FEL;WII(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D%T
M=&5N=&EO;B(*;7-G<W1R(")!:V-I:F$B"@HC.B!L:6(O075T:"]I;7`N<&AP
M.C0T"FUS9VED(")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0P"FUS9VED("(B"B)!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN
M($A434P@;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*(F%D
M9')E<W-B;V]K/R(*;7-G<W1R("(B"B)!=71O;6%T<VMI('!R:6MAOFD@<VQI
M:V4@=2!(5$U,('!O<G5K86UA('IA(&MO:F4@:F4@<&^Y:6QJ86QA8R!U(&UO
M;2`B"B)A9')E<V%R=3\B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHR.3@*(RP@9G5Z>GD*;7-G:60@(D%V86EL86)L92!!9&1R97-S
M(&)O;VMS.B(*;7-G<W1R(").82!R87-P;VQA9V%N:G4@<W4@<VQJ961EYFD@
M:6UE;FEC:3HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S$Y"FUS
M9VED(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M
M870*;7-G:60@(D)A8U]K('1O("5S(@IM<V=S='(@(E].87IA9"!U("5S(@H*
M(SH@=&AR96%D+G!H<#HQ,S<@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"86-K('1O("5S
M(@IM<V=S='(@(DYA>F%D('4@)7,B"@HC.B!T:')E860N<&AP.C$S-`IM<V=I
M9"`B0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@B"FUS9W-T
M<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D
M($1I<W!L87DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS
M.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U
M97-T+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HR-C8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M,C(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L:6(O
M4V5A<F-H+G!H<#HS-`IM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B
M0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I
M;VX@;65S<V%G92XB"FUS9W-T<B`B57-M:F5R:2!O=G4@<&]R=6MU(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED(")";&%C:VQI<W0B
M"FUS9W-T<B`B0W)N82!L:7-T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,CD*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N
M;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/R(*;7-G<W1R
M(")";&]K:7)A:B!S;&EK92!U($A434P@<&]R=6MA;6$@;W-I;2!A:V\@<W4@
M<W!E8VEF:>AN;R!Z871R8;YE;F4_(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(*
M;7-G:60@(D)O9'DB"FUS9W-T<B`B5&EJ96QO(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")/8F$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@W"FUS9VED(")";W1H($AE861E
M<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B22!U('IA
M9VQA=FQJ=2!I('4@=&5K<W1U('!O<G5K92(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(W,@IM<V=I9"`B0U]H87)S970B"FUS9W-T<B`B
M7TMO9&YI(')A<W!O<F5D(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C,V"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O
M('1H92!R96UO=&4@;6%I;"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@
M=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)#86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S
M('!A<G1S(&]F('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL
M8F]X+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G
M92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S
M<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHV-@HC+"!F=7IZ>0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(E!R;VUJ96YI
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,U"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHQ,3$*;7-G:60@(D-A;F-E;"!-97-S86=E(@IM
M<V=S='(@(D]D=7-T86YI(&]D('-L86YJ82(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:G,Z-@IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M
M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,C8U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,34@
M;&EB+U-E87)C:"YP:'`Z,S`*;7-G:60@(D-C(@IM<V=S='(@(D-C(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,PIM<V=I9"`B(@HB0V5R=&EF
M:6-A=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES
M(&YO="!E;F%B;&5D(&]N('1H:7,@(@HB<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Q"B,L(&9U>GIY"FUS9VED
M(")#:&%I<B!097)S;VXB"FUS9W-T<B`B3&GH;F$B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R
M(")0<F]M:F5N:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R(")0<F]M:F5N:2!S=F4B
M"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@
M(D-H86YG92!&;VQD97(B"FUS9W-T<B`B2W)E:7)A:B!F;VQD97(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS9VED("(B"B)#:&%N9V4@9&ES
M<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E
M92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A<F4@<V]R=&5D
M+B(*;7-G<W1R("(B"B)0<F]M:6IE;FET92!O<&-I:F4@<')I:V%Z82!K86\@
MN71O('-U(&)R;VH@<&]R=6MA(&YA('-T<F%N:2!I;&D@;F'H:6X@(@HB<V]R
M=&ER86YJ82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*;7-G:60@
M(D-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+B(*;7-G
M<W1R(")0<F]M:6IE;FET92!P87)A;65T<F4@;6%I;"!S97)V97)A(&D@9F]L
M9&5R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB
M0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@
M<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U
M<B!E;6%I;"XB"FUS9W-T<B`B(@HB4')O;6EJ96YI=&4@:6UE+"!A9')E<W4@
M:2!P;W1P:7,@:V]J92#F92!D<G5G:2!V:61J971I(&MA9&$@Z&ET86IU(&D@
M(@HB;V1G;W9A<F%J=2!N82!V8;D@92UM86EL+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,C0*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB
M"FUS9W-T<B`B0G)O:B!P<FEK87IA;FEH('IN86MO=F$Z(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,34*;7-G:60@(D-H96-K($9O;&1E
M<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B4')O=FIE<FD@;F]V=2!P;[ET
M=2!U(&9O;&1E<FEM82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHW
M-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP;&%T97,O9F5T
M8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K(&%L;"!M86EL
M('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.B(*;7-G<W1R
M("))>F%B97)I=&4@;6%I;"!S97)V97(@<V$@:V]J96<@OF5L:71E('!R975Z
M971I('!ON71U.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*;7-G
M:60@(D-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B
M"FUS9W-T<B`B4')O=FIE<FD@<')A=F]P:7,@<')I:F4@<VQA;FIA('!O<G5K
M93\B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT"FUS9VED
M(")#:&]O<V4@06-T:6]N.B(*;7-G<W1R("))>F%B97)I=&4@86MC:6IU.B(*
M"B,Z(&-O;F9I9R]S97)V97)S+G!H<"YD:7-T.C$X,@IM<V=I9"`B0VAO;W-E
M(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@(DEZ86)E<FET92!M86EL('-E<G9E
M<CHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,C4@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,38V"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(Q-PHC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E
M(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z(@IM
M<V=S='(@(DEZ86)E<FET92!I;&D@<')O;6EJ96YI=&4@=2!P;VQJ=2!D97-N
M;SHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(Q(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,S$*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ
M(@IM<V=S='(@(DEZ86)E<FET92!A:V-I:G4Z(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"FUS9VED(")#:&]O<V4@=&AE(&%D
M9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+B(*;7-G
M<W1R("(B"B))>F%B97)I=&4@(&EM96YI:R!K;VII(.9E('-E(&MO<FES=&ET
M:2!P<FEL:6MO;2!D;V1A=F%N:F$@;F]V:6@@861R97-A+B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PIM<V=I9"`B0VAO;W-E
M('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X
M<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(DEZ86)E<FD@<F5D;W-L:6IE
M9"!Z82!P<F5T<F%G=2!I;65N:6MA('IA('!R;[EI<FEV86YJ92!A9')E<V$N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I
M;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G
M92XB"FUS9W-T<B`B2VQI:VYI=&4@;F$@)7,@9&$@9&]W;FQO861U:F5T92!S
M;&EK=2XB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@
M<&%G92XB"FUS9W-T<B`B1FEL=&5R:3H@)7,@<W1R86YI8V$@>F$@=7)E\&EV
M86YJ92(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@2%1-3"!C
M;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")+<F5I<F%J
M('!O<G5K=2!U('IA<V5B;F]M('!R;WIO<G4_(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,38S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&EC:R`E<R!T;R!V:65W(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N
M(@IM<V=S='(@(DML:6MN:71E(&YA("5S(&1A(&1O=VYL;V%D=6IE=&4@<VQI
M:W4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T
M=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(DMR96ER
M86H@<&]R=6MU('4@>F%S96)N;VT@<')O>F]R=3\B"@HC.B!L:6(O34E-12]6
M:65W97(O<F5L871E9"YP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P
M87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")+<F5I<F%J('!O
M<G5K=2!U('IA<V5B;F]M('!R;WIO<G4_(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VAT;6PN<&AP.CDU"B,L(&9U>GIY"FUS9VED(")#;&EC:R!H97)E('1O(%-(
M3U<@=&AE($EM86=E<R(*;7-G<W1R(")+;&EK;FET92!N82`E<R!D82!D;W=N
M;&]A9'5J971E('-L:6MU+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C,R,0HC+"!F=7IZ>0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE
M(&]F('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE
M8W0@86QL(&9I96QD<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(DML:6MN
M:2!N82!J961A;B!O9"!O9&%B<F%N:6@@861R97-A<F$@82!Z871I;2!O9&%B
M97)I('!O;&IA('!O(&MO:FEM(.9E('-E("(*(G9RN6ET:2!P<F5T<F%G82XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S$*;7-G:60@(D-L:6-K
M('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VLB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@=&\@4V%V92!3+TU)344@8V5R
M=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,`IM<V=I9"`B0VQI8VMI
M;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@
M=&\@=&AE('-E;F1E<B(*;7-G<W1R(")+;&EK86YJ96T@;F$@861R97-U('!R
M879I('-E(&YO=F$@<&]R=6MA('IA('!ON6EL:F%O8V$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D
M<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R
M(")+;&EK86YJ96T@;F$@861R97-U(&]T=F%R82!S92!P;W)U:V$@>F$@Z&ET
M86YJ92(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR
M.`IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B6F%T=F]R:2(*"B,Z(&-O;7!O<V4N
M<&AP.C@R."!C;VUP;W-E+G!H<#HQ,30X"FUS9VED(")#;&]S92!T:&ES('=I
M;F1O=R(*;7-G<W1R("):871V;W)I(&]V86H@<')O>F]R(@H*(SH@9F]L9&5R
M<RYP:'`Z-#(Y"FUS9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(EIA='9O
M<F5N(&9O;&1E<B(*"B,Z(&9O;&1E<G,N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I
M9"`B0V]L;&%P<V4B"FUS9W-T<B`B4VMU<&D@<W9E(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*
M;7-G<W1R(")3:W5P:2!S=F4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T
M<B`B4VMU<&D@<W9E(&9O;&1E<F4B"@HC.B!F;VQD97)S+G!H<#HT-#D*;7-G
M:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R(")3:W5P:2!F;VQD97(B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O
M;&]R($EN9&EC871O<CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ,#,*(RP@9G5Z>GD*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B
M3F]V82!P;W)U:V$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8Y
M"B,L(&9U>GIY"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B3F]V82!P;W)U
M:V$B"@HC.B!C;VUP;W-E+G!H<#HX,C<@8V]M<&]S92YP:'`Z,3$T-PIM<V=I
M9"`B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B"FUS9W-T<B`B3F%P:;EI(&YO
M=G4@<&]R=6MU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-`IM<V=I
M9"`B0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS
M9W-T<B`B4&FY:2!P;W)U:V4@=2!Z87-E8FYO;2!P<F]Z;W)U/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S
M<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R
M('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@HB2V]R:7-T
M:2!(5$U,(&]P8VEJ92!Z82!P:7-A;F4@<&]R=6MA("AA:V\@<')E9VQE9&YI
M:R!P;V1ROF%V82!T=2!M;V=UYFYO<W0I/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-PIM<V=I9"`B0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@
M9&ES<&QA>65D+B(*;7-G<W1R(")0;V1E<VET92!P<FEK87H@<&]R=6MA+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B0V]N9FEG=7)E
M(&UA:6P@<')E=FEE=R!O<'1I;VYS+B(*;7-G<W1R(")0;V1E<VET92!O<&-I
M:F4@<')E9VQE9&$@<&]R=6ME+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M,S<P"FUS9VED(")#;VYN96-T:6]N(&1R;W!P960@8GD@24U!4"!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C,T"FUS
M9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F86EL960B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B4&]D
M97-I=&4@4$=0('!O9'*Y:W4@>F$@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%,O34E-
M12!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B4&]D97-I=&4@4R]-24U%('!O
M9'*Y:W4@>F$@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM
M<V=I9"`B0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E
M87)C:&EN9RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@Y"FUS9VED("(B"B)#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C
M:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@
M(@HB=VAE;B!I="!A<G)I=F5S+B(*;7-G<W1R(")0;V1E<VET92!K861A(.9E
M('-E('9RN6ET:2!P<F]V:F5R82!P<FES=&EG;&4@<&^Y=&4N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8Y-@IM<V=I9"`B0V]N=F5R="!T97AT=6%L
M(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R(")0<F5T
M=F]R:2!T96MS='5A;&YE('-M86IL:6IE('4@9W)A9FGH:V4_(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@
M(DMO<&ER86HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G
M:60@(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@(DMO<&ER86H@=2!F;VQD97(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-C,*;7-G:60@
M(D-O<G)E8W0B"FUS9W-T<B`B27-P<F%V:2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ-#`*;7-G:60@(D-O<G)E8W1E9"!497AT(@IM
M<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C,X,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-O;7!L971E(')E<75E<W0N(%)E87-O;B!':79E;CH@)7,B"FUS9W-T<B`B
M3F4@;6]G=2!N87!R879I=&D@5D93(&)A8VME;F0Z("5S(@H*(SH@871T86-H
M;65N="YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R
M96%T92!T:&4@5D93(&)A8VME;F0Z("5S(@IM<V=S='(@(DYE(&UO9W4@;F%P
M<F%V:71I(%9&4R!B86-K96YD.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S
M86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DYE
M(&UO9W4@;V)R:7-A=&D@<&]R=6ME(&]D("5S+B!0;W)U:V$@<V5R=F5R83H@
M)7,B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,S$X"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G
M<W1R(")397)V:7-N92!O<&5R86-I:F4B"@HC.B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U
M97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#
M;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@
M6FEP(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]397-S:6]N+G!H<#HR
M-S,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!N86UE<W!A8V4@:6YF;W)M
M871I;VX@9G)O;2!)34%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<V5A<F-H
M+G!H<#HS,30@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E
M;7!L871E<R]A8VPO86-L+FEN8SHS.0HC.B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z,38P"B,L(&9U>GIY"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B2W)E:7)A
M:B!F;VQD97(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHV
M"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@(DMR96ER86H@9F]L9&5R
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PHC+"!F=7IZ>0IM<V=I
M9"`B0W)E871E($ME>7,B"FUS9W-T<B`B2W)E:7)A:B!F;VQD97(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@
M(D-R96%T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")+<F5I<F%J(&9O;&1E
M<B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC
M.C(V"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G
M<W1R(")/<W1A;&D@92UM86EL(')AZ'5N:2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S<&%M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE=R!3<&%M(&9O
M;&1E<B(*;7-G<W1R(")+<F5I<F%J(&YO=FD@9F]L9&5R('IA(&MO<G!U(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA
M=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A
M(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(DYA<')A=FD@;F]V:2!F;VQD
M97(@>F$@;F%C<G1E(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L
M96-T+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC
M.C0R"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G
M<W1R(")+<F5I<F%J(&YO=FD@9F]L9&5R('IA('!O<VQA;G4@<&^Y='4B"@HC
M.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C$R('1E;7!L871E
M<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE
M=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B2W)E:7)A:B!N;W9I(&9O;&1E<B!Z
M82!K;W)P=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C@*;7-G:60@
M(B(*(D-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I
M;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@(@HB86YD(&1E
M;&5T92!S<&%M+B(*;7-G<W1R("(B"B)5<F5D:71E('!R879I;&$@9FEL=')I
M<F%N:F$@<&]M;^9U(&MO:FEH(&%U=&]M871S:VD@;W)G86YI>G5J971E('!R
M:7-T:6=L92`B"B)P;W)U:V4L('-O<G1I<F%T92!I:"!U(&9O;&1E<F4@:2!B
M<FFY971E(&YEOF5L:F5N=2!P;[ET=2XB"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!N97<@
M<W1A=&EO;F5R>2(*;7-G<W1R(")+<F5I<F%J(&YO=FD@9F]L9&5R('IA('!O
M<VQA;G4@<&^Y='4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS
M9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G<W1R(")4
M<F5N=71N:2!P<FES='5P("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P-0IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M
M86EL(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(E!O9&5S:71E(&1O
M8F%V;&IA;FIE('!ON71E('-A(&4M;6%I;"!R8>AU;F$@;F$@9')U9VEM('-E
M<G9E<FEM82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0IM<V=I9"`B
M0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R(")/9')E9&ET
M92!K86MO(+EA;&IE=&4@<&^Y='4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B4&]D97-I=&4@>F%D
M871K92!K;VII(.9E('-E(&EZ=G*Y879A=&D@;F%K;VX@<W9A:V4@<')I:F%V
M92!N82`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C$W"FUS9VED(")$871?92(*;7-G<W1R(")$871?=6TB"@HC.B!M
M97-S86=E+G!H<#HR-C(@=&AR96%D+G!H<#HQ-#@*;7-G:60@(D1A=&4B"FUS
M9W-T<B`B1&%T=6TB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4W
M"B,L(&9U>GIY"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")/8G)I<V%N82(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C,*(RP@9G5Z>GD*;7-G
M:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B3V)R:7-A;F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3,W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(D]B<FFY:2(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A
M<F-H<V5L96-T+FEN8SHQ.`IM<V=I9"`B1&5F875L="!396%R8V@@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,PIM<V=I
M9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")$969A=6QT
M(&MR:71E<FEJ('IA('-O<G1I<F%N:F4Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDS,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB
M"FUS9W-T<B`B1&5F875L="!P<F%V86,@<V]R=&ER86YJ83HB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S8U"B,L(&9U>GIY"FUS9VED(")$96QE
M9V%T960B"FUS9W-T<B`B3V)R:7-A;F$B"@HC.B!F;VQD97)S+G!H<#HT,3D@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B3V)R:;EI(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0
M=6)L:6,@2V5Y(@IM<V=S='(@(B(*(E9AN64@:6UE(&D@<')E>FEM93H@/&D^
M*&]V86H@<&]D871A:R!V:61E(&1R=6=I(&MA9&$@Z&ET86IU('9AN64@<&]R
M=6ME*3PO:3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B1&5L971E($-U<G)E;G0@
M2V5Y<R(*;7-G<W1R(")/8G)IN6D@=')E;G5T;F4@:VQJ=>AE=F4B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHY"FUS9VED(")$96QE=&4@
M1F]L9&5R*',I(@IM<V=S='(@(D]B<FFY:2!F;VQD97)E(@H*(SH@9F]L9&5R
M<RYP:'`Z,C@U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L
M9&5R<R(*;7-G<W1R(")/8G)IN6D@9F]L9&5R92(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(%-T871I;VYE<GDB"FUS9W-T<B`B3V)R:;EI('9I<G1U86QN:2!F;VQD97(B
M"@HC.B!F;VQD97)S+G!H<#HT,3D*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O
M;&1E<B(*;7-G<W1R(")/8G)IN6D@=FER='5A;&YI(&9O;&1E<B(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PHC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R
M/R(*;7-G<W1R(")/8G)I<V%N92!S=F4@<&]R=6ME(&EZ("5S+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M
M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-C@*;7-G:60@(D1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S
M(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B3V)R:;EI('-T87)E
M(&QI;FMO=F%N92!P<FEL;V=E('!OZ&5T:V]M('-V86MO9R!M:F5S96-A/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3`*;7-G:60@(D1E;&5T92!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*
M;7-G<W1R(")/8G)IN6D@<W1A<F4@9F]L9&5R92!P;W-L86YE('!ON71E('!O
M8V5T:V]M('-V86MO9R!M:F5S96-A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV,3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S
M(@IM<V=S='(@(D]B<FES86YE('!O<G5K92(*"B,Z(&UE<W-A9V4N<&AP.C4P
M,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,X('1E;7!L
M871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L971E9"(*;7-G
M<W1R(")/8G)I<V%N82(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B3V)R:7-A;F4@
M<&]R=6ME(@H*(SH@8V]M<&]S92YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB)7-<(BXB"FUS
M9W-T<B`B4')I;&]G(&IE(&]B<FES86XN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S
M(@IM<V=S='(@(D)R:7-A;FIE(&D@<')E8F%C:79A;FIE('!O<G5K82(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3(*;7-G:60@(D1E;GD@<F5Q
M=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-30P"B,L(&9U>GIY"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B(*;7-G<W1R(")/9&=O=F]R:2!T<F&^96YO;2!S;&]B
M;V1A;B]Z875Z970@:6YF;W)M86-I:F]M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,S(*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B3W!A9&%J
M=>9I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(Q
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(DMO<FES;FGH:V4@;W!C:6IE(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W
M"FUS9VED(")$971A:6QS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-S<*;7-G:60@(D1I;2!S:6=N871U<F5S/R(*;7-G<W1R("):
M871A;6YI('!O='!I<V4_(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR,S8*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B4')I:V&^:2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-SD*;7-G:60@(D1I<W!L87D@
M8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R
M(")0<FEK8;YI('!O='9R9'4@;F%K;VX@<VQA;FIA('!O<G5K93\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED(")$:7-P;&%Y(&EN($)O
M9'D@;V8@365S<V%G92(*;7-G<W1R(")0<FEK8;YI('4@=&EJ96QU('!O<G5K
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3(*;7-G:60@(D1I<W!L
M87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\B"FUS9W-T<B`B
M4')I:V&^:2!P;W`M=7`@<&]R=6MU('!R:7-T:6=L92!P;[ET93\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4X"B,L(&9U>GIY"FUS9VED(")$:7-P
M;&%Y('1H92!<(D5M<'1Y(%-P86U<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*
M;7-G<W1R(")0<FEK8;YI(&QI;FL@)TES<')A>FYI(&MO<G!U)R!U(&UE;FEJ
M=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4P"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@
M;65N=6)A<C\B"FUS9W-T<B`B4')I:V&^:2!L:6YK("=)<W!R87IN:2!K;W)P
M=2<@=2!M96YI:G4_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R
M(")/<&-I:F4@<')I:V%Z82(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA=&-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$V"FUS9VED(")$;R!.;W0@
M0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G<W1R(").92!P<F]V
M:F5R879A:B!N;W9U('!ON71U('4@9F]L9&5R:6UA(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E;F5R871E(&$@;&EN
M:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(DYE;6]J(&=E;F5R:7-A
M=&D@;&EN:R!U(&MO;&]N:2!0;[EI;&IA;V-A(@H*(SH@;&EB+TE-4"YP:'`Z
M,3`W-0HC+"!F=7IZ>0IM<V=I9"`B1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T
M(&9O;&1E<C\B"FUS9W-T<B`B1&$@;&D@<W1E('-I9W5R;FD@9&$@OF5L:71E
M(&ES<')A>FYI=&D@;W9A:B!F;VQD97(_(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,S(*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@
M4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$R-@HC+"!F=7IZ>0IM<V=I9"`B1&]N92(*;7-G<W1R(").
M:6IE9&YA(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C$Y,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA="(*;7-G
M<W1R(")$;W=N;&]A9"`E<R!U("YZ:7`@9F]R;6%T=2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VAE861E<G,N:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@
M071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB"FUS9W-T<B`B1&]W;FQO860@
M<W9I:"!P<FEL;V=A("AU("YZ:7`@9F]R;6%T=2DB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHR,`IM<V=I9"`B1&]W;FQO860@1F]L9&5R
M*',I(@IM<V=S='(@(D1O=VYL;V%D=6H@9F]L9&5R92(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")$;W=N;&]A9"!&;VQD
M97(H<RD@6RYZ:7`@9F]R;6%T72(*;7-G<W1R(")$;W=N;&]A9'5J(&9O;&1E
M<F4@6RYZ:7`@9F]R;6%T72(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ
M.3(*;7-G:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(D1O
M=VYL;V%D=6H@=2`N>FEP(&9O<FUA='4B"@HC.B!M97-S86=E+G!H<#HU,#$@
M;6%I;&)O>"YP:'`Z-S$Y('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR
M,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0Q"B,Z('1E;7!L871E
M<R]M86EL8F]X+VQE9V5N9"YI;F,Z.0IM<V=I9"`B1')A9G0B"FUS9W-T<B`B
M3F%C<G0B"@HC.B!F;VQD97)S+G!H<#HS.3(*;7-G:60@(D1R869T(&9O;&1E
M<B(*;7-G<W1R(")&;VQD97(@>F$@;F%C<G1E(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD97(Z
M(@IM<V=S='(@(D9O;&1E<B!N97IA=G*Y96YE('!O<G5K93HB"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3`X"B,L(&9U>GIY"FUS9VED(")%+6UA:6P@
M061D<F5S<R(*;7-G<W1R(")%;6%I;"!A9')E<V$B"@HC.B!L:6(O36%I;&)O
M>"YP:'`Z,S`Y"FUS9VED(")%3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D524D]2.B!9
M;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B
M1F]L9&5R(%PB)7-<(B!J92!U<W!J9;EN;R!O8G)I<V%N+B(*"B,Z(&9O;&1E
M<G,N<&AP.C0R,"!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,3D*
M;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C$X"FUS9VED(")%9&ET($)L86-K;&ES="(*;7-G<W1R("))
M>FUI:F5N:2!C<FYU(&QI<W1U(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C$S"FUS9VED(")%9&ET($9I;'1E<G,B"FUS9W-T<B`B27IM:6IE
M;FD@9FEL=&5R92(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<V5A
M<F-H+VAE861E<BYI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(D5D:70@5FER='5A
M;"!&;VQD97(B"FUS9W-T<B`B5FER='5A;&YI(&9O;&1E<FDB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"FUS
M9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R("))>FUI:F5N:2!B:6IE;'4@
M;&ES='4B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*;7-G
M:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B27IM:F5N:71E('9A
MN74@8W)N=2!L:7-T=2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHQ,PIM<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(*;7-G<W1R("))
M>FUJ96YI(&9I;'1E<B!P<F%V:6QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@V,0IM<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E
M<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B(@HB27IM:6IE
M;FET92!P;W-T879K92!Z82!P<FES='5P86YJ92!E+6UA:6P@<F'H=6YI;6$@
M;F$@9')U9VEM('-E<G9E<FEM82XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T
M<B`B27IM:F5N:71E('9AN74@8FEJ96QU(&QI<W1U(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,SD*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`B16UA:6P@861R97-A(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C8U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B16UP=&EE9"!A;&P@
M;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T<B`B3V)R:7-A;F4@<W9E('!O<G5K
M92!I>B`E<RXB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR
M,@IM<V=I9"`B16UP='D@1F]L9&5R*',I(@IM<V=S='(@(DES<')A>FYI(&9O
M;&1E<F4B"@HC.B!F;VQD97)S+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@(D5M
M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B27-P<F%Z;FD@9F]L9&5R
M92(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"FUS9VED
M(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`B27-P<F%Z;FD@9F]L9&5R
M($MO<G!A(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")%
M;7!T>2!?4W!A;2(*;7-G<W1R("))<W!R87IN:2!?:V]R<'4B"@HC.B!L:6(O
M24U0+G!H<#HY-C8*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R("))<W!R
M87IN:2!?:V]R<'4B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,2!T96UP
M;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%!'4"!F
M=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")5:VQJ=>AI(%!'4"!F=6YK8VEO;F%L
M;F]S=#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$@=&5M<&QA
M=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%,O34E-
M12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")5:VQJ=>AI(%,O34E-12!F=6YK
M8VEO;F%L;F]S=#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS
M9VED(")%;F%B;&4@;65S<V%G92!P<F5V:65W<S\B"FUS9W-T<B`B56ML:G7H
M:2!S8;YE=&ME('!O<G5K82!U(&QI<W1I/R(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0T,@IM<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N
M<R(*;7-G<W1R(")/<&-I:F4@N5]I9G)O=F%N:F$B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3$W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-3<*;7-G:60@(D5N9"(*;7-G<W1R(")+<F%J(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C,X-`IM<V=I9"`B16YD(&9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@
M(DMR86H@<')O<VQI:F7P96YE('!O<G5K92(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS-#$*;7-G:60@(D5N9"!M97-S86=E(@IM<V=S='(@(DMR86H@<&]R=6ME
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(DMR86H@<&]R=6ME(&]D
M("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS
M9W-T<B`B56YE<VET92!F<F%Z=2(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M
M<V5L96-T+FEN8SHY"B,L(&9U>GIY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B56YE<VET92!I;64@
M>F$@=F&Y(&YO=FD@9F]L9&5R('IA('-M9>9E(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@
M9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T<B`B56YE<VET92!I
M;64@>F$@=F&Y(&YO=FD@9F]L9&5R('IA(&YA8W)T92(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@(D5N=&5R('1H
M92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@
M(E5N97-I=&4@:6UE('IA('9AN2!N;W9I(&9O;&1E<B!Z82!P;W-L86YU('!O
MN71U(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHY"FUS
M9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R
M(@IM<V=S='(@(E5N97-I=&4@:6UE('IA('9AN2!N;W9I(&9O;&1E<B!Z82!S
M;67F92(*"B,Z(&QI8B]396%R8V@N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")%
M;G1I<F4@365S<V%G92(*;7-G<W1R(")5<VUJ97)I('!O<G5K=2(*"B,Z(&UE
M<W-A9V4N<&AP.C$Y-"!C;VUP;W-E+G!H<#HQ,3,T('1H<F5A9"YP:'`Z-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")<(B5S
M7"(@:F4@=7-P:F6Y;F\@9&]D86X@=2!A9')E<V%R(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S8@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,S@V"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<R(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B1W)EN6MA(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT
M-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8V]N;F5C=&EN9R!T;R!)
M34%0('-E<G9E<BX@)7,@.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C,P.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#`W"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ
M("5S+B(*;7-G<W1R(")'<F6Y:V$@<')I('-L86YJ=2!O9&=O=F]R83H@)7,B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`Q"B,L(&9U>GIY"FUS
M9VED(")%=F5N="!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B1F]L
M9&5R(%PB)7-<(B!J92!U<W!J9;EN;R!O8G)I<V%N+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.#(*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS
M9W-T<B`B4W9A:VEH(#$U(&UI;G5T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B4W9A
M:VEH(#,P('-E:W5N9&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q
M"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B4W9A:VEH(#4@;6EN
M=71A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,PIM<V=I9"`B179E
M<GD@:&%L9B!H;W5R(@IM<V=S='(@(E-V86MI:"!P;VQA('-A=&$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@P"FUS9VED(")%=F5R>2!M:6YU=&4B
M"FUS9W-T<B`B4W9A:VD@;6EN=70B"@HC.B!F;VQD97)S+G!H<#HT-3<*(RP@
M9G5Z>GD*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")0<F^Y:7)I('-V92(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A
M;F0@06QL(@IM<V=S='(@(E!R;[EI<FD@<W9E(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R
M<R(*;7-G<W1R(")0<F^Y:7)I('-V92!F;VQD97)E(@H*(SH@9F]L9&5R<RYP
M:'`Z-#4W"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(E!R;[EI<FD@
M9F]L9&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P
M('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP
M86YD($YA;65S(@IM<V=S='(@(E!R;[EI<FD@:6UE;F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`V,PIM<V=I9"`B17AP86YD(&YA;65S(&EN('1H
M92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H92!B86-K9W)O
M=6YD/R(*;7-G<W1R(")!=71O;6%T<VMI(')AN6ER:2!I;65N82!U('!R;WIO
M<G4@>F$@<V%S=&%V;&IA;FIE('!O<G5K93\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3@P"FUS9VED(")%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@
M=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_(@IM<V=S='(@
M(D%U=&]M871S:VD@<F&Y:7)I(&-I:F5L;R!S=&%B;&\@=2!P<FEK87IU(&9O
M;&1E<F$_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C$P,0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(E!R
M;[EI<G5J96TB"@HC.B!L:6(O24U0+G!H<#HY.#0@;&EB+TE-4"YP:'`Z.3@V
M"B,L(&9U>GIY"FUS9VED(")&7V5T8V@@36%I;"(*;7-G<W1R(")$;V)A=FD@
M<&^Y='4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z
M,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B1F5T8V@@36%I
M;"(*;7-G<W1R(")$;V)A=FD@<&^Y='4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#8Y"FUS9VED(")&971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN
M9&]W/R(*;7-G<W1R(")3:VEN:2!P;W)U:V4@=2!Z87-E8FYO;2!P<F]Z;W)U
M/R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT-@HC+"!F
M=7IZ>0IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N/R(*
M;7-G<W1R(")0<FEM96YI(&9I;'1E<B!P<F%V:6QA(&YA:V]N('!R:6IA=FQJ
M:79A;FIA/R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S
M(@IM<V=S='(@(D]B<FES86YE('-V92!P;W)U:V4@:7H@)7,N(@H*(SH@;&EB
M+T9E=&-H;6%I;"YP:'`Z,C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(D]B<FES86YE
M('-V92!P;W)U:V4@:7H@)7,N(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@U
M(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL+G!H<#HR.#D*
M(RP@9G5Z>GD*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(D1O8F%V:2!P
M;[ET=2(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I
M9"`B1F5T8VAM86EL.B!N;R!N97<@;65S<V%G97,N(@IM<V=S='(@(B`M("1N
M;2!N;W9I:"!P;W)U:V$B"@HC.B!L:6(O24U0+G!H<#HY.3`*;7-G:60@(D9I
M7VQT97)S(@IM<V=S='(@(D9I7VQT97)I(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3`R('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FIS.C@R"FUS9VED(")&:6QE(@IM<V=S='(@(D1A=&]T96MA(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"FUS9VED(")&:6QT97(@
M3W!T:6]N<R(*;7-G<W1R(")/<&-I:F4@9FEL=&5R82(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHY"FUS9VED(")&:6QT97(@4V5T=&EN9W,B
M"FUS9W-T<B`B4')A=FEL82!F:6QT97)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8P,`IM<V=I9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@
M<')O9F%N:71Y/R(*;7-G<W1R(")&:6QT<FER86H@<&]R=6ME(&YE<&^^96QJ
M;F]G('-A9'*^86IA/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV
M92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N
M('1H:7,@<WES=&5M+B(*;7-G<W1R(")0;V1RN6MA('IA(&9I;'1E<F4@:F4@
M:7-K;&IUZ&5N82!N82!O=F]M('-I<W1E;74N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-PIM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT97)I
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHS"FUS9VED
M(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B1FEL=&5R:2!.25-5(&%K
M=&EV;FDB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E(@IM<V=S='(@(D9I
M;'1E<FDZ("5S('-T<F%N:6-A('IA('5R9?!I=F%N:F4B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN9"(*;7-G
M<W1R(")4<F&^:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*;7-G
M:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")0<G9A('-T<F%N82!S
M86YD=>AE=&$B"@HC.B!M86EL8F]X+G!H<#HS-#4*;7-G:60@(D9I<G-T(%!A
M9V4B"FUS9W-T<B`B4')V82!S=')A;F$B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,C$*;7-G:60@(D9O7W)W87)D(@IM<V=S='(@(E!?<F]S;&EJ
M961I(@H*(SH@9F]L9&5R<RYP:'`Z,C8V('1E;7!L871E<R]F;VQD97)S+V9O
M;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G:60@(D9O;&1E<B!!8W1I;VYS("T@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,P,R!T
M96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY"B,Z('1E;7!L871E<R]P<F5F
M<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z-@HC.B!T96UP;&%T97,O<')E9G,O
M:6YI=&EA;'!A9V5S96QE8W0N:6YC.C$P"FUS9VED(")&;VQD97(@3F%V:6=A
M=&]R(@IM<V=S='(@(E!R96=L960@9F]L9&5R82(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HS"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R(")3
M8;YE=&%K(&9O;&1E<F$B"@HC.B!A8VPN<&AP.C(T"FUS9VED(")&;VQD97(@
M<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R
M<RYP:'`Z-C(*;7-G:60@(D9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-CD*;7-G:60@
M(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@
M9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@(D9O<FUA="!D871U
M;6$@<&]R=6MA('4@<V%N9'7H971U('IA('!O<G5K92!P<FES=&EG;&4@9&%N
M87,B"@HC.B!C;VUP;W-E+G!H<#HW.#`@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$U"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C(Q"FUS9VED(")&;W)W87)D(@IM<V=S='(@(E!R;W-L:6IE9&DB
M"@HC.B!C;VUP;W-E+G!H<#HW-C4*;7-G:60@(D9O<G=A<F0Z(@IM<V=S='(@
M(E!R;W-L:6IE9&DZ(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,V.0HC+"!F=7IZ
M>0IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B2W)A:B!P<F]S
M;&EJ961J96YE('!O<G5K92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<R(*
M;7-G<W1R(")0<F]S;&EJ961J96YA('!O<G5K82!O9"`E<R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*(RP@9G5Z>GD*;7-G:60@(D9R964O
M0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VEJ92!S97)V:7-A
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y-`IM<V=I9"`B1G)E
M92]"=7-Y(%)E<&QY(@IM<V=S='(@(D]D9V]V;W(@<VQO8F]D86XO>F%U>F5T
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`HC+"!F=7IZ>0IM
M<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B3V1G;W9O<B!S;&]B
M;V1A;B]Z875Z970B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Q
M"B,L(&9U>GIY"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*
M;7-G<W1R(")/9&=O=F]R('-L;V)O9&%N+WIA=7IE="(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R;U]M
M(@IM<V=S='(@(E]/9"(*"B,Z(&UE<W-A9V4N<&AP.C(V,R!T:')E860N<&AP
M.C$T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O
M4V5A<F-H+G!H<#HR,@IM<V=I9"`B1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D<F5S<R(*
M;7-G<W1R(")!9')E<V$@<')I;6%O8V$B"@HC.B!C;VUP;W-E+G!H<#HW-S<@
M8V]M<&]S92YP:'`Z-S@Q"FUS9VED(")&=V0Z(@IM<V=S='(@(D9W9#HB"@HC
M.B!C;VUP;W-E+G!H<#HQ,CDT"B,L(&9U>GIY"FUS9VED(")&=V0Z("(*;7-G
M<W1R(")&=V0Z(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1G=D.B`E=2!&;W)W87)D960@365S<V%G97,B"FUS
M9W-T<B`B2W)A:B!P<F]S;&EJ961J96YE('!O<G5K92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.`IM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S='(@(D]PN71E(&]P
M8VEJ92(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS-PIM
M<V=I9"`B1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,0IM
M<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S8*;7-G:60@
M(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B261I(&YA('!O<G5K=2(*"B,Z(&QI
M8B])35`N<&AP.C0Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1V\@
M=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R(")$;V1A
M:B!U(&EM96YI:R`H)7,I(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S
M-0IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(D1A:B!P<FES='5P(@H*
M(SH@;65S<V%G92YP:'`Z-30V(&QI8B]&:6QT97(N<&AP.C$P-2!L:6(O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HY-0HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ,#(@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,R!L:6(O34E-12]6:65W
M97(O:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I
M;VXN<&AP.C8R(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X
M"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.2!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C0Q.`HC.B!L:6(O34E-12]6:65W97(O87!P;&5D
M;W5B;&4N<&AP.C0Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PHC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C`@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z,3(W"FUS9VED(")(15)%(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,2!L:6(O34E-12]6:65W
M97(O:'1M;"YP:'`Z,3$W"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H
M<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HR
M-38*(RP@9G5Z>GD*;7-G:60@(DA434P@5F5R<VEO;B!O9B!-97-S86=E(@IM
M<V=S='(@(DEZ=F]R;FD@:V]D('!O<G5K92(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VAE861E<G,N:6YC.C4X"FUS9VED(")(96%D97)S(@IM<V=S='(@(EIA
M9VQA=FQJ92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z
M-0IM<V=I9"`B2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP;W-I
M;F<Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C@*
M;7-G:60@(DAI9&1E;B(*;7-G<W1R(")3:W)I=F5N;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-C<*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE
M=R(*;7-G<W1R(")3:W)I=F5N;R!U('!R:6MA>G4@=&]K82!T96UE(@H*(SH@
M;6%I;&)O>"YP:'`Z,S8W"FUS9VED(")(:61E($1E;&5T960B"FUS9W-T<B`B
M4V%K<FEJ(&]B<FES86YE(@H*(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")(
M:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")386MR:6H@;F5U<&ES86YE(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDT"FUS9VED(")(
M:6=H(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y-R!M86EL8F]X+G!H
M<#HW,C0@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,@IM<V=I9"`B
M2&EG:"!0<FEO<FET>2(*;7-G<W1R(")6:7-O:R!P<FEO<FET970B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE
M<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X.`IM
M<V=I9"`B2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_
M(@IM<V=S='(@(DMA:V\@OF5L:71E('!R:6MA>F%T:2!P<FEL;V=E/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*;7-G:60@(DAO=R!T;R!A='1R
M:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`B2V]J:2!P
M<F5F:6MS(&MO<FES=&ET:2!Z82!C:71I<F%N92!L:6YI:F4@=2!O9&=O=F]R
M=2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3,T"FUS9VED("))34%0
M(@IM<V=S='(@(DE-05`B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R
M.0IM<V=I9"`B24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R
M("))34%0("AA=71O;6%T<VMI('!R97!O>FYA:B!P<F]T;VMO;"DB"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P
M;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,38V(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))
M34%0(&]V97(@4U-,(@IM<V=S='(@(DE-05`@;W9E<B!34TPB"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I9"`B24U!4"!O=F5R(%-33"`H
M<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(DE-05`@;W9E<B!3
M4TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,38W"FUS9VED("))34%0(&]V97(@4U-,("AS96QF
M+7-I9VYE9"DB"FUS9W-T<B`B24U!4"!P<F5K;R!34TP@*'-E;&8M<VEG;F5D
M*2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S8X"FUS9VED("))34%0('-E
M<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38U(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,30P"FUS9VED("))34%0+"!N;R!43%,B"FUS9W-T<B`B24U!4"P@
M8F5Z(%1,4R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z-#D*;7-G:60@
M(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B24U!4"]03U`S(&UA
M:6P@<V5R=F5R:2(*"B,Z(&QI8B])35`N<&AP.C@V-@IM<V=I9"`B24Y"3U@B
M"FUS9W-T<B`B4T%.1%7(12(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#$Q
M"FUS9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@;75S="!H879E('1H
M92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,@IM
M<V=I9"`B268@>6]U(&-O;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE(&9O
M;&1E<BAS*2!W:6QL(&)E(&QO<W0A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,@IM<V=I9"`B26=N;W)E(@IM<V=S
M='(@(DEG;F]R:;EI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C@S"FUS9VED("))9VYO<F4@06QL(@IM<V=S='(@(DEG;F]R:;EI('-V
M92(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHX"FUS
M9VED("));6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I
M;7!O<G0N:6YC.C(P"B,L(&9U>GIY"FUS9VED("));7!O<G0B"FUS9W-T<B`B
M5F&^;F$B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#4@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-0HC+"!F=7IZ>0IM<V=I
M9"`B26UP;W)T($ME>2(*;7-G<W1R(")68;YN82(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,SD*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!+97EP86ER
M(@IM<V=S='(@(E9AOFYA(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,C<*;7-G:60@(DEM<&]R="!-97-S86=E<R(*;7-G<W1R("));7!O
M<G1U:B!P;W)U:V4B"@HC.B!P9W`N<&AP.C0R"B,L(&9U>GIY"FUS9VED("))
M;7!O<G0@4$=0($ME>2(*;7-G<W1R(")68;YN82(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z.3$*;7-G:60@(DEM<&]R="!097)S;VYA;"!#97)T
M:69I8V%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K
M97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@
M2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI
M;F,Z.0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT
M"FUS9VED("));7!O<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0P('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T
M(%!U8FQI8R!+97DB"FUS9W-T<B`B(@HB5F&Y92!I;64@:2!P<F5Z:6UE.B`\
M:3XH;W9A:B!P;V1A=&%K('9I9&4@9')U9VD@:V%D82#H:71A:G4@=F&Y92!P
M;W)U:V4I/"]I/B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M-`HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!U8FQI8R!01U`@2V5Y(@IM<V=S
M='(@(B(*(E9AN64@:6UE(&D@<')E>FEM93H@/&D^*&]V86H@<&]D871A:R!V
M:61E(&1R=6=I(&MA9&$@Z&ET86IU('9AN64@<&]R=6ME*3PO:3XB"@HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`HC+"!F=7IZ>0IM<V=I
M9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(B(*(E9AN64@
M:6UE(&D@<')E>FEM93H@/&D^*&]V86H@<&]D871A:R!V:61E(&1R=6=I(&MA
M9&$@Z&ET86IU('9AN64@<&]R=6ME*3PO:3XB"@HC.B!S;6EM92YP:'`Z,38*
M(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@(E9A
MOFYA(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHY"B,L(&9U
M>GIY"FUS9VED("));7!O<G0@;6)O>"!&:6QE(@IM<V=S='(@(E9AOFYA(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHQ-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S
M+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU,#(@;6%I;&)O>"YP:'`Z
M-S,T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-PHC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$V('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHW"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`B5F&^;F$B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A
M;G0@;65S<V%G97,B"FUS9W-T<B`B5F&^;F4@<&]R=6ME(@H*(SH@9F]L9&5R
M<RYP:'`Z,38W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E
M9"`E9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R(")/8G)I<V%N92!S=F4@
M<&]R=6ME(&EZ("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M-S,*;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP
M:'`Z,S@T(&QI8B]&;VQD97(N<&AP.C@V(&QI8B]&;VQD97(N<&AP.C(Q-"!L
M:6(O24U0+G!H<#HS,3,*(SH@;&EB+TE-05`O5')E92YP:'`Z,3$T(&QI8B])
M34%0+U1R964N<&AP.C(Q.0IM<V=I9"`B26YB;W@B"FUS9W-T<B`B4V%N9'7H
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3(*;7-G:60@(DEN8VQU
M9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\B
M"FUS9W-T<B`B56ML:G7H:2!S8;YE=&%K('4@>F%G;&%V;&IU(&]D9V]V;W)A
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#<*;7-G:60@(DEN8VQU
M9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/R(*;7-G<W1R(")0<FEL
M;[YI(&]R:6=I;F%L;G4@<&]R=6MU('4@;V1G;W9O<G4_(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z,3,P"B,L(&9U>GIY"FUS9VED("));F9O(@IM<V=S='(@
M(DEG;F]R:;EI(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DEN9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B
M(@HB5F&Y92!I;64@:2!P<F5Z:6UE.B`\:3XH;W9A:B!P;V1A=&%K('9I9&4@
M9')U9VD@:V%D82#H:71A:G4@=F&Y92!P;W)U:V4I/"]I/B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R
M<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G
M:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY.`HC+"!F=7IZ>0IM<V=I9"`B
M26YL:6YE(@IM<V=S='(@(FYO;F4B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP
M;W)T7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I9FEC871E($AE<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ
M-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>2!(97)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M,3`*;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2!(97)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,@IM<V=I9"`B26YV
M86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*;7-G
M<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O>"YP:'`Z-C(V"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS9W-T<B`B16UA:6P@
M861R97-A(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HS,#<*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B"FUS9W-T<B`B561A
M;&IE;F\@<V%N9'7H93HB"@HC.B!C;VUP;W-E+G!H<#HQ-3@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@8VAA<F%C=&5R(&EN(&4M;6%I
M;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@
M96UA:6P@861R97-I+B(*"B,Z('-M:6UE+G!H<#HX,B!P9W`N<&AP.C$V"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&ME>2(*;7-G<W1R(")%;6%I;"!A9')E
M<V$B"@HC.B!P9W`N<&AP.C$Y-@IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!0
M1U`@<')I=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3<Q"FUS
M9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R"FUS9VED
M("));G9E<G0B"FUS9W-T<B`B26YV97)T=6HB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I
M9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@=&\@
M8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N
M;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T
M:&ES('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHS-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,SD*;7-G:60@(B(*
M(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA=F4@;F\@861D
M<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@(@HB8V]N=&%C=',N(@IM
M<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S$X"FUS9VED(")+97D@<W5C8V5S<V9U
M;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$V"FUS9VED("),86YG
M=6%G92(*;7-G<W1R(")*97II:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,#8*;7-G:60@(DQA<W0@36%I;&)O>"!086=E(@IM<V=S='(@(EIA9&YJ
M82!S=')A;F$@<V%N9'7H971A(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED
M("),87-T(%!A9V4B"FUS9W-T<B`B6F%D;FIA('-T<F%N82(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X.0IM<V=I9"`B3&E?;FL@071T
M86-H;65N=',B"FUS9W-T<B`B3&E?;FMU:B!P<FEL;V=E(@H*(SH@871T86-H
M;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C$P-C,*(RP@9G5Z>GD*;7-G
M:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R
M(")0<FEL;WII(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$P.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.#(*;7-G:60@(B(*(DQI
M<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R
M965N/R`H:68@9&ES86)L960L('EO=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A
M8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B
M(@HB27-P:;EI('-V92!K;VYT86MT92!P<FEL:6MO;2!O='9A<F%N:F$@96MR
M86YA(&MO;G1A:V%T83\@*$%K;R!J92!O=F$@;W!C:6IA("(*(FES:VQJ=>AE
M;F$L('9I9&IEYC]T92!S86UO(&MO;G1A:W1E(&MO:F4@=')AOFET92DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@U"FUS9VED("),:7-T:6YG(&EN
M('1H92!(96%D97(B"FUS9W-T<B`B4W!I<V%K('!R:6QO9V$@=2!Z86=L879L
M:G4@<&]R=6ME(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C,P"FUS9VED("),;V-A;"!-86EL8F]X.B(*;7-G<W1R("),;VMA;&YO('-A
M;F1UZ&4Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`HC+"!F
M=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B06MC:6IA(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C4*;7-G:60@(DQO9R!I;B(*;7-G
M<W1R(")+<F5N:2(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O("5S(@IM<V=S='(@(E!R:6IA
M=FD@<V4@;F$@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S
M-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B3&]G:6X@>F%D86-I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R("),;V=I;B!Z861A8VDB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHR.38*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC
M.B!M97-S86=E+G!H<#HR.3D@;6%I;&)O>"YP:'`Z-S(W('1E;7!L871E<R]M
M86EL8F]X+VQE9V5N9"YI;F,Z,3,*;7-G:60@(DQO=R!0<FEO<FET>2(*;7-G
M<W1R(").:7IA:R!P<FEO<FET970B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHR.3<*;7-G:60@(DQO=V5S="(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0T"B,L(&9U>GIY"FUS
M9VED(")-86-I;G1O<V@@1FEL92(*;7-G<W1R(")&:6QT97)I('!ON71E(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"FUS9VED(")-
M86EL(@IM<V=S='(@(E!ON71A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDV"FUS9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(E!R96=L960@<&^Y
M=&4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM
M<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I;&)O>"(*
M;7-G<W1R(")386YD=>AE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,0IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T:6]N<R(*
M;7-G<W1R(")/<&-I:F4@<')I:V%Z82!S86YD=>AE=&$@:2!F;VQD97)A(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA
M<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@(D]Z
M;F'H:2!S=F4@<&]R=6ME(&MA;R!P<F_H:71A;F4B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B36%R:R!!;&P@365S<V%G
M97,@:6X@1F]L9&5R(&%S(%5N<V5E;B(*;7-G<W1R(")/>FYAZ&D@<W9E('!O
M<G5K92!K86\@;F5P<F_H:71A;F4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C4@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS,`IM<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`B3V)I;&IEOFD@:V%O
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G:60@(DUA<FL@
M9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O
M;&]R<S\B"FUS9W-T<B`B3WIN8>AI(')A>FQIZ&ET92!N:79O92!C:71I<F%N
M:F$@<F%Z;&GH:71I;2!B;VIA;6$_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E96X_
M("A)34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T<B`B
M3V)O:FD@<&]S96)N92!O>FYA:V4_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C0V"FUS9VED(")-871C:"!!;&P@475E<FEE<R(*;7-G<W1R
M("):86AT:6IE=F%J('-V92!U<VQO=F4B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R
M(")":6QO(&MO:FD@=7-L;W8B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHU,3,*;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM
M<V=S='(@(DUA:W-I;6%L;F$@=F5L:>AI;F$@<')I;&]G82(*"B,Z(&QI8B]A
M<&DN<&AP.C<Y"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!&;VQD97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y
M-`HC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@871T86-H;65N
M=',@<F5A8VAE9"XB"FUS9W-T<B`B36%K<VEM86QN82!V96QIZ&EN82!P<FEL
M;V=A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@Y"B,L
M(&9U>GIY"FUS9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R
M96%C:&5D+B(*;7-G<W1R(")-86MS:6UA;&YA('9E;&GH:6YA('!R:6QO9V$B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(V"B,L(&9U>GIY"FUS
M9VED(")-965T:6YG($-A;F-E;&QA=&EO;B(*;7-G<W1R("));F9O<FUA8VEJ
M92!S97)V:7-A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-0HC
M+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R("))
M;F9O<FUA8VEJ92!S97)V:7-A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4X-0HC+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!0<F]P;W-A;"(*;7-G
M<W1R(")/9&=O=F]R('IA('-A<W1A;F%K(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8Q-PIM<V=I9"`B365E=&EN9R!297!L>2(*;7-G<W1R(")/
M9&=O=F]R('IA('-A<W1A;F%K(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T
M<B`B3V1G;W9O<B!Z82!S87-T86YA:R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,#,*;7-G:60@(DUE971I;F<@57!D871E(%)E<75E<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,PHC+"!F
M=7IZ>0IM<V=I9"`B365N=2!&;VQD97(@3&ES="(*;7-G<W1R(")/='9O<FD@
M9F]L9&5R(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S<V%G
M92(*;7-G<W1R(")0;W)U:V$B"@HC.B!C;VUP;W-E+G!H<#HU-C`@8V]M<&]S
M92YP:'`Z-3@W(&-O;7!O<V4N<&AP.C8T,2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S:71I;VXB"FUS9W-T<B`B3F]V
M82!P;W)U:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$W"FUS9VED
M(")-97-S86=E($1A=&4B"FUS9W-T<B`B1&%T=6T@<&]R=6ME(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`S"FUS9VED(")-97-S86=E($]P=&EO;G,B"FUS9W-T
M<B`B3W!C:6IE('!O<G5K82(*"B,Z('-E87)C:"YP:'`Z,S$R"FUS9VED(")-
M97-S86=E(%-E87)C:"(*;7-G<W1R(")0<F5T<F&^:79A;FIE('!O<G5K92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C$*;7-G:60@(DUE<W-A9V4@
M4VEZ92(*;7-G<W1R(")696QIZ&EN82!P;W)U:V4B"@HC.B!M97-S86=E+G!H
M<#HS.#0*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(DEZ=F]R;FD@
M:V]D('!O<G5K92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I
M9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@(E!R96=L961A=F%N:F4@<&]R
M=6ME(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-
M97-S86=E(&9L86=S(@IM<V=S='(@(D]Z;F%K92!P;W)U:V$B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E(&9O;&1E
M<G,B"FUS9W-T<B`B1F]L9&5R:2!P;W)U:V$B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R
M;VT@)7,B"FUS9W-T<B`B1F]L9&5R:2!P;W)U:V$B"@HC.B!M86EL8F]X+G!H
M<#HV-C<*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C:&UE;G1S
M(@IM<V=S='(@(E5S;&]V:2!P<F5T<F%G92(*"B,Z(&UA:6QB;W@N<&AP.C8U
M.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T
M<B`B4&]L:F$@<&]R=6ME(@H*(SH@;6%I;&)O>"YP:'`Z-C4S"B,L(&9U>GIY
M"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G<W1R(")0;VQJ82!P;W)U
M:V4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S,*;7-G:60@
M(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R(")5<VQO=FD@<')E=')A9V4B"@HC
M.B!C;VUP;W-E+G!H<#HX,C0@8V]M<&]S92YP:'`Z.#,X"FUS9VED(")-97-S
M86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")0;W)U:V$@
M=7-P:F6Y;F\@=7-M:F5R96YA(@H*(SH@8V]M<&]S92YP:'`Z,3`X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B
M=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@(E!O<G5K82!U<W!J9;EN;R!P
M;W-L86YA+"!A;&D@;FEJ92!S;FEM;&IE;F$@=2`E<R(*"B,Z(&-O;7!O<V4N
M<&AP.C$Q-#,@8V]M<&]S92YP:'`Z,3$U.`IM<V=I9"`B365S<V%G92!S96YT
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&]R=6MA('5S<&IEN6YO('!O<VQA
M;F$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,0IM<V=I9"`B365S
M<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`B
M4&]R=6MA('!O('-T<F%N:2!K;V0@<')I:V%Z82!S86YD=>AE=&$N(@H*(SH@
M;6%I;&)O>"YP:'`Z,S(R"FUS9VED(")-97-S86=E<R!T;R(*;7-G<W1R(")0
M;W)U:V4@=2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0HC+"!F=7IZ
M>0IM<V=I9"`B36]D:69Y(@IM<V=S='(@(E1I:F5L;R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM
M<V=I9"`B36]V92(*;7-G<W1R(")0<F5B86-I(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S$V"B,L(&9U>GIY"FUS9VED(")-;W9E
M(&1O=VXB"FUS9W-T<B`B<&]M:F5R:2!N:;YE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8Q.`IM<V=I9"`B36]V92!S<&%M(&UE<W-A9V5S('1O('-P
M86T@9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*(RP@9G5Z
M>GD*;7-G:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@(F]D86)E<FD@9F]L
M9&5R(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$T
M"B,L(&9U>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@(G!O;6IE<FD@=FFY
M92(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(W"FUS
M9VED(")-=6QT:7!A<G0O86QT97)N871I=F4B"FUS9W-T<B`B(@H*(SH@=&AR
M96%D+G!H<#HW-B!T:')E860N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B375L
M=&EP;&4@365S<V%G92!6:65W(@IM<V=S='(@(E!R96=L961A=F%N:F4@<&]R
M=6ME(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N
M:6YC.C4*;7-G:60@(DY/3D4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C0X('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I9"`B3D]412(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(S."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(").86UE
M(@IM<V=S='(@(DEM92(*"B,Z('!G<"YP:'`Z,3$P"FUS9VED(").86UE(&%N
M9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-S@*(RP@9G5Z>GD*;7-G:60@(DYE
M961S($%C=&EO;B(*;7-G<W1R(")!:V-I:F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3<P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#(*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<W.`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B
M3FEK861A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`IM<V=I9"`B
M3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(").:6MA9"!N92!P86UT
M:2!P<FEL;V=E(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R-`IM<V=I
M9"`B3F5W(@IM<V=S='(@(DYO=F\B"@HC.B!L:6(O24U0+G!H<#HU-C,*;7-G
M:60@(DYE=R!&;VQD97(B"FUS9W-T<B`B3F]V:2!F;VQD97(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#@*;7-G:60@(DYE=R!-86EL(@IM<V=S='(@
M(DYO=F$@<&^Y=&$B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3D@;&EB
M+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(DYE
M=R!-97-S86=E(@IM<V=S='(@(E-L:F5D9>9A('!O<G5K82(*"B,Z(&UA:6QB
M;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@
M(DYO=F4@<&]R=6ME(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ
M.0IM<V=I9"`B3F5W(&UE<W-A9V5S(@IM<V=S='(@(DYO=F4@<&]R=6ME(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PHC+"!F=7IZ
M>0IM<V=I9"`B3F5X="(*;7-G<W1R(")496MS="(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@365S
M<V%G92(*;7-G<W1R(")3;&IE9&7F82!P;W)U:V$B"@HC.B!M86EL8F]X+G!H
M<#HS-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(")3;&IE9&7F82!S=')A
M;F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#(@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDW-PIM<V=I9"`B3F\B"FUS9W-T<B`B3F4B
M"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED(").;R!#97)T:69I8V%T92!F;W5N
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI
M<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T<B`B0F5Z(+EI
M9G)O=F%N:F$B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3D*;7-G:60@
M(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H
M<#HS-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B"FUS9W-T
M<B`B3F5M82!P;W)U:V$B"@HC.B!P9W`N<&AP.C$S-PHC+"!F=7IZ>0IM<V=I
M9"`B3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(E!'4"!T
M96MS="!J879N;V<@:VQJ=>AA(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHX-`IM<V=I9"`B3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N
M="(*;7-G<W1R("(B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S(Y"B,L(&9U>GIY
M"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`B4')E=&AO9&YA('-T
M<F%N82(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,34*(RP@9G5Z
M>GD*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(B(*(E9A
MN64@:6UE(&D@<')E>FEM93H@/&D^*&]V86H@<&]D871A:R!V:61E(&1R=6=I
M(&MA9&$@Z&ET86IU('9AN64@<&]R=6ME*3PO:3XB"@HC.B!S;6EM92YP:'`Z
M,34Q"FUS9VED(").;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDP"B,L(&9U
M>GIY"FUS9VED(").;R!A='1A8VAM96YT<R!F;W5N9"XB"FUS9W-T<B`B4')I
M;&]Z:2(*"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"FUS9VED(").;R!E
M;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+B(*
M;7-G<W1R("(B"@HC.B!A8VPN<&AP.C<R(&%C;"YP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(DYO(&9O;&1E<B!S96QE8W1E9"XB"FUS9W-T<B`B;FEJ961A;B!F
M;VQD97(@;FEJ92!I>F%B<F%N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$T,0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@
M;F5W(&UA:6PN(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C(Q."!L:6(O
M1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED(").;R!F
M;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(DYI:F5D86X@9F]L9&5R
M(&YI:F4@<W!E8VEF:6-I<F%N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$T-PHC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S
M86=E<R(*;7-G<W1R(").96]B<FES86YE('!O<G5K92(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@
M=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`B3F5O8G)I<V%N92!P;W)U
M:V4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(U"FUS9VED(").;R!M97-S86=E
M(&)O9'D@=&5X="(*;7-G<W1R(")0;W)U:V$@;F5M82!T96MS=&$B"@HC.B!L
M:6(O36%I;&)O>"YP:'`Z,S<Q"B,L(&9U>GIY"FUS9VED(").;R!M97-S86=E
M<R!M871C:&5D('EO=7(@<V5A<F-H+B(*;7-G<W1R(").:6IE9&YA('!O<G5K
M82!N92!O9&=O=F%R82!P;W-T879L:F5N;VT@=7!I='4B"@HC.B!P9W`N<&AP
M.C$X.0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R
M=&5D+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$V-0IM<V=I9"`B3F\@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z
M('-M:6UE+G!H<#HR,#$*;7-G:60@(DYO('!E<G-O;F%L(%,O34E-12!C97)T
M:69I8V%T97,@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG+G!H
M<#HR,C`*;7-G:60@(DYO('-P96QL8VAE8VMI;F<@<')O9W)A;2!C;VYF:6=U
M<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-#@*;7-G:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(").
M:6IE9&YA(&=R86UA=&EC:V$@9W)EN6MA(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS
M9W-T<B`B3F5M82!G<F6Y:V4B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4V
M-`IM<V=I9"`B3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T
M:&]D(&-O=6QD(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C8X
M(&%C;"YP:'`Z.30*;7-G:60@(DYO('5S97(@<W!E8VEF:65D+B(*;7-G<W1R
M(").:6IE(&YA=F5D96X@:V]R:7-N:6LN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<P.0IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@=&5M<&QA
M=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,`HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-2!T96UP;&%T97,O<')E9G,O<W!A
M;7-E;&5C="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V
M-`IM<V=I9"`B3F]N92(*;7-G<W1R(").:6IE9&YA(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDU"FUS9VED(").;W)M86PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,2!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Y"FUS9VED(").;W0@1&5L971E
M9"(*;7-G<W1R(").96]B<FES86YA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHQ,B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C(S"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#(*
M;7-G:60@(DYO="!$<F%F="(*;7-G<W1R(").:6IE(&YA8W)T(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHS-`IM<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R(").
M979AOFYA(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM
M<V=I9"`B3F]T(%!E<G-O;F%L(@IM<V=S='(@(DYI:F4@;&GH;F$B"@HC.B!L
M:6(O0W)Y<'0O4$=0+G!H<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@
M;&EB+T-R>7!T+U--24U%+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A;&ED('!U
M8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-C<*;7-G:60@(DYO="!D96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@
M(DYE;V)R:7-A;F4@<&]R=6ME(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHU,0IM<V=I9"`B3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R
M(").979AOFYE('!O<G5K92(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E
M=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A
M;B!T86ME('-O;64@=&EM92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C$V"FUS9VED(").;W1H:6YG(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DYU;6)E<B!O9B!M;VYT
M:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG
M(&UO;G1H;'DN(@IM<V=S='(@(B(*(D)R;VH@;6IE<V5C:2!K;VQI:V\@=')E
M8F$@Z'5V871I('-T87)E(&QI;FMO=F%N92!P<FEL;V=E('4@<VQUZ&%J=2!M
M:F5S9>AN;V<@(@HB8G)I<V%N:F$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,U.0IM<V=I9"`B3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(D)R
M;VH@<W1A<FEH(&9O;&1E<F$@<&]S;&%N92!P;[ET92!K;VII(&-E('-E('-A
M8W5V871I(&%K;R!S92!B<FFY=2!M:F5S96-N;RXB"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-"!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-34R"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S,*;7-G
M:60@(D]+(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.0HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$U"FUS9VED
M(")/;&0@;65S<V%G97,B"FUS9W-T<B`B4W1A<F4@<&]R=6ME(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP
M.C4R"FUS9VED(")/;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D
M+B(*;7-G<W1R(")"<FFY96T@<W1A<F4@9F]L9&5R92!P;W-L86YE('!ON71E
M+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-0HC+"!F=7IZ>0IM<V=I
M9"`B3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E860@;65S<V%G97,@
M:6X@=&AE;3\B"FUS9W-T<B`B3F5O8G)I<V%N92!P;W)U:V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"FUS9VED(")/;FQY(&]N
M92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$P('1E;7!L871E
M<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E;B!&;U]L9&5R(@IM
M<V=S='(@(D]T=F]R:2!F;VQD97(B"@HC.B!F;VQD97)S+G!H<#HT,C<*;7-G
M:60@(D]P96YE9"!&;VQD97(B"FUS9W-T<B`B3W1V;W)E;FD@9F]L9&5R(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P-0IM<V=I9"`B3W!T:6]N
M86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL+G!H<#HS
M,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H97(@36%I;"!!
M8V-O=6YT<R(*;7-G<W1R(")/<W1A;&D@92UM86EL(')AZ'5N:2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I;VYS
M(@IM<V=S='(@(D]S=&%L92!O<&-I:F4B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(P,0IM<V=I9"`B3W5T8F]U;F0@4V5R=F5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,38U"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3`*;7-G:60@(E!'
M4"(*;7-G<W1R(")01U`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T
M7VQI<W0N:6YC.C<*;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS9W-T
M<B`B4$=0(+EI9G)O=F%N:F4@<&]R=6ME(@H*(SH@8V]M<&]S92YP:'`Z,S4X
M"FUS9VED(")01U`@17)R;W(Z("(*;7-G<W1R(")01U`@9W)EN6MA.B(*"B,Z
M(&-O;7!O<V4N<&AP.C,S-PIM<V=I9"`B4$=0($5R<F]R.B!.965D('!A<W-P
M:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R(")01U`@
M9W)EN6MA.B!0;W1R96)N82!J92!F<F%Z82!Z82!L:>AN:2!P<FEV871N:2!K
M;&IUZ"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")0
M1U`@3W!T:6]N<R(*;7-G<W1R(")01U`@;W!C:6IE(@H*(SH@<&=P+G!H<#HS
M,`IM<V=I9"`B4$=0(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`B4$=0('5N
M;W,@9G)A>F4B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G:60@
M(E!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(E!O9'*Y:V$@>F$@4$=0(&QI
MZ&YE(&ML:G7H979E('IA:'1I:F5V82!S:6=U<FYU('=E8B!K;VYE:V-I:G4N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"FUS9VED(")01U`@
M4'5B;&EC($ME>2!497AT(@IM<V=S='(@(E!'4"!T96MS="!J879N;V<@:VQJ
M=>AA(@H*(SH@<&=P+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0
M(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@
M861D960N(@IM<V=S='(@(E!'4"!J879N:2!K;&IUZ"!Z82!<(B5S("@E<RE<
M(B!J92!U<W!J9;EN;R!D;V1A;BXB"@HC.B!P9W`N<&AP.C(T-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S
M=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B4$=0(&IA=FYI(&ML:G7H
M('IA(%PB)7-<(B!J92!U<W!J9;EN;R!O8G)I<V%N+B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM
M<V=S='(@(E!'4"!J879N:2!P<FEV:F5S86LB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*;7-G:60@(E!'4"!3:6=N($UE<W-A
M9V4B"FUS9W-T<B`B4$=0('!O='!I<VEV86YJ92!P;W)U:V$B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.CD*;7-G:60@(E!'4"!3
M:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")01U`@<&]T<&FY:2^Y:69R
M=6H@<&]R=6MU(@H*(SH@<&=P+G!H<#HR,#(*;7-G:60@(E!'4"!P<FEV871E
M(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E!'4"!P<FEV871N
M:2!K;&IUZ"!J92!U<W!J9;EN;R!D;V1A;BXB"@HC.B!P9W`N<&AP.C$W-PIM
M<V=I9"`B4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G
M<W1R(")01U`@:F%V;FD@:VQJ=>@@:F4@=7-P:F6Y;F\@9&]D86XN(@H*(SH@
M=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P
M;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")01U`@
M<&]D<KEK82!J92!I<VML:G7H96YA(&YA(&]V;VT@<VES=&5M=2XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#@*;7-G:60@(B(*(E!'4"!S=7!P
M;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I
M9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*(E!'4"!P;V1RN6MA('1R96YU=&YO(&YI:F4@86MT:79N82!T86MO(&1A
M('-E(&1I9VET86QN:2!P;W1P:7,@;F4@;6^^92`B"B)P<F]V:F5R:71I+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I9"`B(@HB4$=0
M('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A
M9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB4$=0
M('!O9'*Y:V$@=')E;G5T;F\@;FEJ92!A:W1I=FYA('1A:V\@9&$@<V4@<&]R
M=6MA(&YE(&UOOF4@9&6Y:69R;W9A=&DN(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(*;7-G:60@(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S('!O<'5P
M('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R
M96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU
M<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H92!01U`@(@HB9F5A
M='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM<V=S
M='(@(E!/4#,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I
M9"`B4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R(")03U`S
M("AA=71O;6%T<VMI('!R97!O>FYA:B!P<F]T;VMO;&4I(@H*(SH@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HQ,3<*;7-G:60@(E!/4#,@;W9E<B!34TPB"FUS
M9W-T<B`B4$]0,R!O=F5R(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,3(S"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T
M:69I8V%T92DB"FUS9W-T<B`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@
M8V5R=&EF:6-A=&4I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-CD*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R
M(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C$Q,0IM<V=I9"`B4$]0,RP@;F\@5$Q3(@IM<V=S='(@
M(E!/4#,L(&)E>B!43%,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N
M:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS
M9W-T<B`B4W1R86YI8V$@)60@;V0@)60B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3`S"FUS9VED(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-
M97-S86=E(@IM<V=S='(@(E-T<F%N:6-A('-A('!R=F]M(&YE<')OZ&ET86YO
M;2!P;W)U:V]M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-`IM<V=I
M9"`B4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@
M(E-T<F%N:6-A('-A('IA9&YJ;VT@;F5P<F_H:71A;F]M('!O<G5K;VTB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R
M="AS*2(*;7-G<W1R(")$:6\@*&1I:F5L;W9I*2(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,C,*(RP@9G5Z>GD*;7-G:60@(E!A<W-P:')A<V4B"FUS
M9W-T<B`B56YE<VET92!F<F%Z=2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ,C@*(RP@9G5Z>GD*;7-G:60@(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G
M<W1R(")01U`@=6YO<R!F<F%Z92(*"B,Z('-M:6UE+G!H<#HR,S4@<&=P+G!H
M<#HS,3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY
M('5N;&]A9&5D+B(*;7-G<W1R(")01U`@<')I=F%T;FD@:VQJ=>@@:F4@=7-P
M:F6Y;F\@9&]D86XN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N
M:6YC.C$X('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,CD*(RP@9G5Z
M>GD*;7-G:60@(E!A<W-P:')A<V4Z(@IM<V=S='(@(E5N97-I=&4@9G)A>G4B
M"@HC.B!P9W`N<&AP.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B
M92!E;7!T>2(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$Q-`IM<V=I9"`B4&%S
M<W!H<F%S97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP
M;W)T7VME>2YI;F,Z-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M.3(*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(JEI9G)A(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"FUS9VED(")097)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(DEZ=G*Y
M:2!S97)V:7-N92!O<&5R86-I:F4@<')I:F4@;&]G:7)A;FIA/R(*"B,Z(&%C
M;"YP:'`Z-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T
M:&ES('5S97(@8V%N(&YO="!B92!C:&%N9V5D+B(*;7-G<W1R(")$;WIV;VQE
M('IA(&]V;V<@:V]R:7-N:6MA('-E(&YE(&UO9W4@;6EJ96YJ871I+B(*"B,Z
M(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HW,#,@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E
M;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R("),:>AN82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-`IM<V=I9"`B4&5R<V]N86P@26YF
M;W)M871I;VXB"FUS9W-T<B`B3W-O8FYE+TQIZ&YE(&EN9F]R;6%C:6IE(@H*
M(SH@<&=P+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L(%!'4"!K
M97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E!O<G5K
M82!U<W!J9;EN;R!U<VUJ97)E;F$B"@HC.B!P9W`N<&AP.C$R-PHC+"!F=7IZ
M>0IM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(E!O<G5K82!U<W!J9;EN;R!U<VUJ97)E;F$B"@HC.B!S
M;6EM92YP:'`Z,C`W"FUS9VED(")097)S;VYA;"!3+TU)344@8V5R=&EF:6-A
M=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ
M,S(*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L(%,O34E-12!K97ES(&1E;&5T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")0;W)U:V$@=7-P:F6Y;F\@=7-M
M:F5R96YA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B
M4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A
M<F1S/R(*;7-G<W1R(")$;V1A:B!M;VH@<&]T<&ES('!R:6IE(&]D9V]V;W)A
M(&D@<')O<VQI:F7P96YI:"!P;W)U:V$_(@H*(SH@8V]M<&]S92YP:'`Z,C4T
M"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S='(@
M(DEZ=F]R;FD@:V]D('!O<G5K92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.3D*;7-G:60@(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES
M(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D("(*
M(G-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-
M86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@<&QU
M9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R
M:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ
M.3(*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@9F]L9&5R.B(*;7-G<W1R(")5;F5S:71E(&EM92!Z82!V8;D@;F]V
M:2!F;VQD97(@>F$@<VUEYF4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F
M;VQD97)S+FIS.C$P,B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F
M('1H92!N97<@9F]L9&5R.B(*;7-G<W1R(")5;F5S:71E(&EM92!Z82!V8;D@
M;F]V:2!F;VQD97(@>F$@<VUEYF4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$S-PIM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N97<@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E
M+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@
M=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@
M=VEL;"!O;FQY(&YE960@=&\@(@HB96YT97(@=&AI<R!P87-S<&AR87-E(&]N
M8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%
M('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@(@HB=&\@96YT97(@
M=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@
M(B(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G:60@(B(*(E!L96%S92!L;V<@
M:6X@86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF
M('EO=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M
M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA
M=F4@=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@
M=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C
M:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN
M8V]N=F5N:65N8V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-S$*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O
M<F0N(@IM<V=S='(@(DUO;&EM(&YA=F5D:71E('9AN74@N6EF<G4N(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PIM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B36]L:6T@;F%V961I=&4@
M=F&Y92!K;W)I<VYIZ&MO(&EM92XB"@HC.B!C;VUP;W-E+G!H<#HQ,#8@;&EB
M+TE-4"YP:'`Z-#4Y"FUS9VED(")0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@
M;W(@:6YV86QI9"!A9&1R97-S97,N(@IM<V=S='(@(DUO;&EM('1E('!O<')A
M=FD@9'9O<VUI<VQE;F4@;V1N;W-N;R!I;G9A;&ED;F4@861R97-E+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(*(RP@9G5Z>GD*;7-G:60@
M(B(*(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@
M86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E
M;&]W+B(*;7-G<W1R(")-;VQI;2!I>F%B97)I=&4@86MC:6IU(&YA(&UE;FEJ
M=2!I<W!O9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@
M<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B36]L:6T@:7IA8F5R:71E
M(&YE:VD@9F]L9&5R('!R:6IE(&EZ=G*Y879A;FIA(&%K8VEJ82XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`R"FUS9VED(")0;&5A<V4@<V5L
M96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R(")-
M;VQI;2!I>F%B97)I=&4@86MC:6IU(&YA(&UE;FEJ=2!I<W!O9"XB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC.C0Q"B,L(&9U>GIY"FUS
M9VED(")0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A
M<F-H+B(*;7-G<W1R(")-;W)A=&4@;F%V97-T:2!B87(@:F5D;F]G('!R:6UA
M;V-A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3(*
M(RP@9G5Z>GD*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R
M(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B36]L:6T@:7IA8F5R:71E
M(&YE:VD@9F]L9&5R('!R:6IE(&EZ=G*Y879A;FIA(&%K8VEJ82XB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-S,*;7-G:60@(E!L96%S
M92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS
M9W-T<B`B27IA8F5R:71E(&EL:2!P<F]M:6IE;FET92!U('!O;&IU(&1E<VYO
M.B(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD:7-T.C0Q"FUS9VED(")0;W=E<F5D
M(&)Y($AO<F1E(@IM<V=S='(@(E!O=V5R960@8GD@2&]R9&4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C$T"FUS9VED(")0<F5C961E('EO=7(@<VEG
M;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_(@IM<V=S='(@(DES<')E9"!P
M;W1P:7-A(&1O9&%J(&-R=&EC92`H)RTM("<I/R(*"B,Z('-M:6UE+G!H<#HR
M-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"B,L(&9U>GIY"FUS
M9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T
M<B`B1F]L9&5R(%PB)7-<(B!J92!U<W!J9;EN;R!K<F5I<F%N+B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"B,L(&9U>GIY"FUS
M9VED(")0<F5V:65W(@IM<V=S='(@(E!R971H;V1N82!S=')A;F$B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(X"FUS9VED
M(")0<F5V:6]U<R!-97-S86=E(@IM<V=S='(@(E!R971H;V1N82!P;W)U:V$B
M"@HC.B!M86EL8F]X+G!H<#HS-#<*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS
M9W-T<B`B4')E=&AO9&YA('-T<F%N82(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B4')I;G0B"FUS9W-T<B`B
M3V2Y=&%M<&%J(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z
M,S@*;7-G:60@(E!R:6]R:71Y(@IM<V=S='(@(E!R:6]R:71E="(*"B,Z('1E
M;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I9"`B4')I=F%T
M92!+97D@4&%S<W=O<F0B"FUS9W-T<B`BJ6EF<F$@<')I=F%T;F]G(&ML:G7H
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP
M="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T
M;R!.3R(*;7-G<W1R(")0:71A:B!P<FEL:6MO;2!S;&%N:F$@<')I;&]G83L@
M<&]D<F%Z=6UI:F5V86YI(&]D9V]V;W(@:F4@3D4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-34X"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453(@IM<V=S='(@(E!I
M=&%J('!R:6QI:V]M('-L86YJ82!P<FEL;V=A.R!P;V1R87IU;6EJ979A;FD@
M;V1G;W9O<B!J92!$02(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM<V=S='(@(E!R;W1O:V]L.B(*
M"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0R.0IM<V=I9"`B4'5B;&EC(%!'4"!K
M97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)?
M9V4@1&5L971E9"(*;7-G<W1R(")?27IB86-I(&]B<FES86YE(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)G92!$96QE=&5D
M(@IM<V=S='(@(DEZ8F%C:2!O8G)I<V%N92(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C(T"FUS9VED(")0=7)G92!&;VQD97(H<RDB"FUS
M9W-T<B`B27IB86-I(&]B<FES86YE('!O<G5K92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.38*;7-G:60@(E!U<F=E(%1R87-H(&AO=R!O9G1E;CHB
M"FUS9W-T<B`B2V]L:6MO(.AE<W1O(&)R:7-A=&D@<&]R=6ME(&EZ(&MO<G!E
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E
M(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO
M=6YT(&]F(&1A>7,N(@IM<V=S='(@(D]B<FFY:2!P;W)U:V4@=2!F;VQD97)U
M(&MO<G!A('-T87)I:F4@;V0@;W9O9R!B<F]J82!D86YA+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(E!U<F=E(&]L9"!M97-S86=E
M<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R("))<W!R87IN:2!S=&%R
M92!P;W)U:V4@=2!D:7)E:W1O<FEJ=2!+;W)P83\B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F
M;VQD97(N(@IM<V=S='(@(DEZ8F%C=6IE;2`E9"!P;W)U:W4O82!I>B!F;VQD
M97)A(&MO<G!A+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R
M87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@
M9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(DEZ8F%C=6IE;2`E9"!P;W)U
M:W4O82!I>B!F;VQD97)A(&MO<G!A+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q
M=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S
M.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(E-L;V)O9&%N
M('!R;W-T;W(Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"@HC.B!T96UP
M;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250B"FUS9W-T<B`B4VQO
M8F]D86X@<')O<W1O<CH@)2XR9DU"("\@3D5/1U)!3DG(14Y/(@H*(SH@=&5M
M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")1=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM<V=S='(@(E-L;V)O9&%N('!R
M;W-T;W(Z($Y%3T=204Y)R$5.3R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T
M<B`B0VET:7)A;2`E9CHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHS.#8*;7-G:60@(E)E7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")47W)AOFD@<&]T=G)D=2!P<FEJ96UA(@H*(SH@;&EB+U-E
M87)C:"YP:'`Z-3`*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@(E!R:6UL
M:F5N82!N82(*"B,Z(&QI8B]396%R8V@N<&AP.C4X"FUS9VED(")296-E:79E
M9"!3:6YC92(*;7-G<W1R(")0<FEM;&IE;F$@;F%K;VXB"@HC.B!L:6(O4V5A
M<F-H+G!H<#HU-`IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`B4')I
M;6QJ96YA('!R:6IE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B57-M:F5R
M7VDB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(E5S;6IE<FDB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I<F5C
M="!-97-S86=E(@IM<V=S='(@(E5S;6IE<FD@<&]R=6MU(@H*(SH@8V]M<&]S
M92YP:'`Z-S@W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T
M<B`B57-M:F5R:2!O=G4@<&]R=6MU(@H*(SH@8V]M<&]S92YP:'`Z.#0W"FUS
M9VED(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(E5S;6IE<F5N:F4@
M;FEJ92!U<W!J96QO+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C4X,PIM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")!OG5R:7)A:B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E<V@@1F]L
M9&5R(%9I97=S.B(*;7-G<W1R(")!OG5R:7)A:B!P<FEK87H@9F]L9&5R83HB
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY('1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM
M<V=S='(@(D&^=7)I<F%J('!R:6MA>B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VAE860N:6YC.C,*;7-G:60@(E)E;&]A9"!6:65W(@IM<V=S='(@(D&^=7)I
M<F%J('!R:6MA>B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C8@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0HC+"!F=7IZ>0IM<V=I9"`B
M4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M3V1G;W9O<FD@=')AOF5N;VT@<VQO8F]D86XO>F%U>F5T(&EN9F]R;6%C:6IO
M;2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<Y"FUS9VED(")296UE
M;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S='(@(EIA<&%M=&D@>F%D;FII('!R
M:6MA>B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PIM
M<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(E5D86QJ96YO('-A;F1U
MZ&4Z(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C0Q"FUS9VED
M(")296UO=F4@1FEE;&0@1G)O;2!396%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`U"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@<V]U<F-E(@IM<V=S='(@(FEZ8F%C:2!I>G9O<B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E;F%M
M92!&;VQD97(H<RDB"FUS9W-T<B`B4')O;6IE;FD@:6UE(&9O;&1E<F$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")296YA;64@<V5N
M="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@
M(E!R;VUJ96YI(&EM92!F;VQD97)A('!O<VQA;F4@<&^Y=&4@<&_H971K;VT@
M<W9A:V]G(&UJ97-E8V$_(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#4U"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E;F%M:6YG(%PB)7-<(B!T;R!<(B5S7"(@9F%I
M;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(E!R
M;VUJ96YA(&EM96YA(&YI:F4@=7-P:F5L82!<(B5S7"(@=2!<(B5S7"(N($]V
M;R!J92!P;W)U:V$@<V5R=F5R82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS
M9W-T<B`B3V1G;W9O7W)I(&YA(&QI<W1U(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G
M<W1R("):86UJ96YI('-A.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L>2(*;7-G<W1R(")/9&=O=F]R
M:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0P.0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T
M<B`B3V1G;W9O<B!J92!P;W-L86XN(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!!;&PB"FUS
M9W-T<B`B3V1G;W9O<FD@<W9I;6$B"@HC.B!C;VUP;W-E+G!H<#HW,S,*;7-G
M:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B3V1G;W9O<FD@<W9I;6$Z(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$P"FUS
M9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@(D]D9V]V;W)I(&YA(&QI<W1U
M(@H*(SH@8V]M<&]S92YP:'`Z-S,U"FUS9VED(")297!L>2!T;R!,:7-T.B(*
M;7-G<W1R(")/9&=O=F]R:2!N82!L:7-T=3HB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O(%]!
M;&PB"FUS9W-T<B`B3V1G;W9O<FD@7W-V:6UA(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,W
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E<&QY
M('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(D]D9V]V;W)I
M('!O<G5K;VT@3FEJ92!P;V1ROF%N;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU,S4*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N
M97AT(#(@;6]N=&AS+B(*;7-G<W1R(")/9&=O=F]R:2!P;W)U:V]M('-L;V)O
M9&%N+WIA=7IE="!Z82!N87)E9&YA(#(@;6IE<V5C82XB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3,T"FUS9VED(")297!L>2!W:71H(')E<75E
M<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(D]D9V]V;W)I
M('1R8;YE;F]M('-L;V)O9&%N+WIA=7IE="!I;F9O<FUA8VEJ;VTN(@H*(SH@
M;65S<V%G92YP:'`Z,C8W"FUS9VED(")297!L>2U4;R(*;7-G<W1R(")/9&=O
M=F]R:2UN82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#D*;7-G:60@(E)E<&QY
M+51O.B`B"FUS9W-T<B`B3V1G;W9O<FDM3F$Z("(*"B,Z(&-O;7!O<V4N<&AP
M.C<S,0IM<V=I9"`B4F5P;'DZ(@IM<V=S='(@(D]D9V]V;W)I.B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR-@IM<V=I9"`B4F5P;W)T(&%S($EN
M;F]C96YT(@IM<V=S='(@(E!R:6IA=FD@:V%O(&YE+7-P86TB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3<&%M
M(@IM<V=S='(@(E!R:6IA=FD@:V%O('-P86TB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS.#,*;7-G:60@(E)E<75E<W0@82!?4F5A9"!2
M96-E:7!T(@IM<V=S='(@(E1R8;YI(%]P;W1V<F1U(.AI=&%N:F$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E;&EV
M97)Y(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B1&$@=')AOFEM('!O='9R9'4@
M<')I:F5M83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S"FUS9VED
M(")297%U97-T(')E860@<F5C96EP=',_(@IM<V=S='(@(D1A('1R8;YI;2!P
M;W1V<F1U(.AI=&%N:F$@<&]R=6ME/R(*"B,Z(&UA:6QB;W@N<&AP.C$X.0IM
M<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+B(*;7-G<W1R(")4
M<F&^96YA('!O<G5K82!N:6IE('!R;VYA\&5N82XB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-CDW"B,L(&9U>GIY"FUS9VED(")297%U:7)E9"!0
M87)T:6-I<&%N="(*;7-G<W1R(")$82!T<F&^:6T@<&]T=G)D=2#H:71A;FIA
M('!O<G5K93\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$V,0IM<V=I9"`B4F5S970B"FUS9W-T<B`B4&]N:;ET:2(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,34*;7-G:60@(E)E<W!O
M;F1E;G0@4W1A='5S(%5P9&%T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,`IM<V=I9"`B4F5S=6UE
M(@IM<V=S='(@(DYA<W1A=FDB"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED
M(")297-U;64@>6]U<B!S97-S:6]N(@IM<V=S='(@(DYA<W1A=FET92!V8;EU
M('-E<VEJ=2(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT
M-`HC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#;VUP;W-I
M=&EO;EPB(@IM<V=S='(@(DYO=F$@<&]R=6MA(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O
M=6YT7W-E;&5C="YI;F,Z,S(*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL
M(@IM<V=S='(@(DYA>F%D(&YA(%9A;FIS:V4@<F'H=6YE(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO
M=&%C=&EV92YI;F,Z,C(*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ
M,#$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,30*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI
M;F,Z,34*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,3<S"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G
M<W1R(").87IA9"!N82!O<&-I:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S$X"FUS9VED("(B"B)2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN
M9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G
M93\B"FUS9W-T<B`B(@HB5G)A=&D@<V4@;F$@<')I:V%Z('-A;F1UZ&5T82!N
M86MO;B!B<FES86YJ82P@<')E8F%C:79A;FIA+"!I;&D@:V]P:7)A;FIA("(*
M(G!O<G5K93\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS
M9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS9VED(")3+TU)344B"FUS
M9W-T<B`B4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L
M:7-T+FEN8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G
M<W1R(")3+TU)344@N6EF<G5J('!O<G5K=2(*"B,Z(&-O;7!O<V4N<&AP.C,Y
M-`HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B4$=0
M(&=R9;EK83HB"@HC.B!C;VUP;W-E+G!H<#HS-S,*(RP@9G5Z>GD*;7-G:60@
M(E,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P
M<FEV871E(&ME>2XB"FUS9W-T<B`B4$=0(&=R9;EK83H@4&]T<F5B;F$@:F4@
M9G)A>F$@>F$@;&GH;FD@<')I=F%T;FD@:VQJ=>@N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U,0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS9W-T
M<B`B4R]-24U%(&]P8VEJ92(*"B,Z('-M:6UE+G!H<#HT.0HC+"!F=7IZ>0IM
M<V=I9"`B4R]-24U%(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`B4$=0('5N
M;W,@9G)A>F4B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C4T"B,L
M(&9U>GIY"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T
M(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")0
M;V1RN6MA('IA(%!'4"!L:>AN92!K;&IUZ&5V92!Z86AT:6IE=F$@<VEG=7)N
M=2!W96(@:V]N96MC:6IU+B(*"B,Z('-M:6UE+G!H<#HQ-#`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S
M7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")&;VQD97(@
M7"(E<UPB(&IE('5S<&IEN6YO(&]B<FES86XN(@H*(SH@<VUI;64N<&AP.C$V
M,@HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U
M;&QY(&%D9&5D+B(*;7-G<W1R(")01U`@:F%V;FD@:VQJ=>@@:F4@=7-P:F6Y
M;F\@9&]D86XN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`HC
M+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@
M(E!'4"!J879N:2!P<FEV:F5S86LB"@HC.B!S;6EM92YP:'`Z,C$Q"B,L(&9U
M>GIY"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C
M97-S9G5L;'D@861D960N(@IM<V=S='(@(E!'4"!P<FEV871N:2!K;&IUZ"!J
M92!U<W!J9;EN;R!D;V1A;BXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R
M>7!T7VQI<W0N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")3+TU)344@4VEG;B!-
M97-S86=E(@IM<V=S='(@(E,O34E-12"Y:69R=6H@<&]R=6MU(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ-`HC+"!F=7IZ>0IM
M<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(E,O
M34E-12"Y:69R=6H@<&]R=6MU(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C
M=&EV92YI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@
M9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(E!'4"!P;V1RN6MA
M(&IE(&ES:VQJ=>AE;F$@;F$@;W9O;2!S:7-T96UU+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"B,L(&9U>GIY"FUS9VED("(B"B)3+TU)
M344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE
M<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E9"XB"FUS9W-T<B`B
M(@HB4$=0('!O9'*Y:V$@=')E;G5T;F\@;FEJ92!A:W1I=FYA('1A:V\@9&$@
M<V4@<&]R=6MA(&YE(&UOOF4@9&6Y:69R;W9A=&DN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-S,*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T
M(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I9VYE
M9"!M97-S86=E(&-A;B!N;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T-@HC+"!F=7IZ>0IM
M<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE
M(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@HB4$=0('!O9'*Y:V$@=')E;G5T;F\@;FEJ92!A:W1I
M=FYA('1A:V\@9&$@<V4@9&EG:71A;&YI('!O='!I<R!N92!M;[YE("(*(G!R
M;W9J97)I=&DN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S
M('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY
M('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG
M92!T:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S
M('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P-0IM<V=I9"`B4TU44"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-34*;7-G
M:60@(E-?=6)J96-T(@IM<V=S='(@(E1?96UA(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,S8S"FUS9VED(")385]V92!A(&-O<'D@:6X@
M(@IM<V=S='(@(E-AZ'5?=F%J(&MO<&EJ=2!U("(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%?=F4@87,B
M"FUS9W-T<B`B7U-AZ'5V86H@:V%O(@H*(SH@<V5A<F-H+G!H<#HS,38@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W"B,L(&9U>GIY"FUS9VED
M(")3879E(@IM<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE;G1S
M('=I=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@(E-A=F4@1')A9G0B
M"FUS9W-T<B`B4V'H=79A:B!K86\@;F%C<G0B"@HC.B!S879E:6UA9V4N<&AP
M.C0R"B,L(&9U>GIY"FUS9VED(")3879E($EM86=E(@IM<V=S='(@(E-AZ'5V
M86H@:V%O(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(P-`IM<V=I9"`B
M4V%V92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O;F]T
M86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E-N
M:6UI(&]P8VEJ92(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHT,`HC+"!F=7IZ>0IM<V=I9"`B4V%V92!3=&%T:6]N97)Y(@IM<V=S='(@
M(E-N:6UI(&]P8VEJ92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PIM<V=I
M9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B4V'H=79A:B!K86\@7VYA8W)T(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS
M9VED(")3879E(&%S(@IM<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@=6YS
M965N/R(*;7-G<W1R("+(=79A:B!N86-R=&4@:V%O(&YE<')OZ&ET86YE/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<R"FUS9VED(")3879E(')E
M8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S
M(&)O;VL_(@IM<V=S='(@(D%U=&]M871S:VD@<&%M=&D@<')I;6%T96QJ92!P
M;W)U:V4@=2!G;&%V;F]M(&%D<F5S87)U/R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z,3(W"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U
M86P@9F]L9&5R/R(*;7-G<W1R("):87!A;71I('!R971R86=U(&MA;R!V:7)T
M=6%L;FD@9F]L9&5R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*
M;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R(")38>AU=F%J('!O<VQA
M;G4@<&^Y='4_(@H*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B3FEJ92!U<W!J96QO('-P
M8;EA=F%N:F4@;F%C<G1A+B!/=F\@:F4@<&]R=6MA('-E<G9E<F$Z("5S(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA
M=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F
M;VQD97)S+G!H<#HT,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E1R8;YI(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$X('1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A
M<F-H("5S(@IM<V=S='(@(E1R8;YI("5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS
M9W-T<B`B4VYI;6D@;W!C:6IE(@H*(SH@<V5A<F-H+G!H<#HR-C4*;7-G:60@
M(E-E87)C:"!297-U;'1S(@IM<V=S='(@(E)E>G5L=&%T:2!P<F5T<F%G92(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,30@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHS,0IM<V=I9"`B4V5E;B(*;7-G<W1R(")0
M<F_H:71A;F$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*
M;7-G:60@(E-E;&5C="(*;7-G<W1R(")/9&%B97)I(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<P"FUS9VED(")396QE8W0@06YO=&AE
M<B!!8V-O=6YT(@IM<V=S='(@(DEZ86)E<FET92!K;W)I<VYIZ&MI(')AZ'5N
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(D]D86)E<FD@:61E;G1I
M=&5T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P"FUS9VED
M(")396QE8W0@82!F:65L9"(*;7-G<W1R("))>F%B97)I=&4@<&]L:F4B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@(D]D86)E<FD@
M:61E;G1I=&5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I
M9"`B4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD
M('-E87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R("))>F%B97)I=&4@
M:7IV;W)E(&EM96YI:V$@>F$@9&]D879A;FIE(&D@<')E=')AOFEV86YJ92!A
M9')E<V$N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R(")/9&%B97)I('-V92(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L96-T
M(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E
M<RXB"FUS9W-T<B`B27IA8F5R:71E('!O;&IA(&MO:F$@=')E8F$@<')E=')A
MOFET:2!P<FEL:6MO;2!P<FEK87IA(&%D<F5S82XB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T
M(&%N(&%C8V]U;G0B"FUS9W-T<B`B27IA8F5R:71E(&MO<FES;FGH:VD@<F'H
M=6XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@Y"FUS9VED(")3
M96QE8W0@;F]N92(*;7-G<W1R(")/9&%B97)I(&YI:F5D86XB"@HC.B!T96UP
M;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B4V5L96-T
M('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C(Q
M"FUS9VED(")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"B,L
M(&9U>GIY"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G<W1R
M(")/9&%B97)I(&%D<F5S87)E.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`T"B,L(&9U
M>GIY"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R("))
M;F9O<FUA8VEJ92!S97)V:7-A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q
M"FUS9VED(")396YD($UE<W-A9V4B"FUS9W-T<B`B4&^Y86QJ:2!P;W)U:W4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S`S"B,L(&9U>GIY"FUS9VED
M(")396YD(')E860@<F5C96EP="!W:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N
M9&5R/R(*;7-G<W1R("*I86QJ:2!-1$X@:V%D82!T;R!T<F&^:2!P;[EI;&IA
M;&%C/R(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PHC+"!F=7IZ>0IM<V=I9"`B4V5N
M="!M86EL(&9O;&1E<B(*;7-G<W1R(")&;VQD97(@<&]S;&%N92!P;[ET93HB
M"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,X"FUS
M9VED(")396YT(&UA:6P@9F]L9&5R.B(*;7-G<W1R(")&;VQD97(@<&]S;&%N
M92!P;[ET93HB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S,B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$T-@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$U,PIM<V=I9"`B4V5R=F5R(@IM<V=S='(@(E-E<G9E
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PIM<V=I9"`B4V5R=F5R
M(&%N9"!&;VQD97(@26YF;W)M871I;VXB"FUS9W-T<B`B4V5R=F5R(&D@9F]L
M9&5R:2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,PHC
M+"!F=7IZ>0IM<V=I9"`B4V5R=F5R.B(*;7-G<W1R(")397)V97(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F97)E;F-E
M<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M
M97-S86=E<RXB"FUS9W-T<B`B(@HB4&]D97-I=&4@;W!C:6IE('4@:V]J:6UA
M(.9E('-E(&1E9FEN:6YI<V%T:2!A:V-I:F4@;F%K;VX@<')E;6IEN71A;FIA
M(&D@(@HB8G)I<V%N:F$@<&]R=6MA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE
M;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(E!O9&5S:2!8+5!R:6]R
M:71Y('!O;&IE('4@>F%G;&%V;&IU('!R:6QI:V]M('!I<V%N:F$@<&]R=6MA
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@
M1F]L9&5R<R(*;7-G<W1R(")$:6IE;&IE;FIE(&9O;&1E<F$B"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z.#8*;7-G:60@(E-H87)E(&UA:6P@9F]L9&5R
M<R(*;7-G<W1R(")$:6IE;&IE;F4@9F]L9&5R82!P;[ET92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O
M;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`B4F%Z;6IE;FIU:G1E
M('9AN64@92UM86EL(&9O;&1E<F4@<V$@9')U9VEM(&MO<FES;FEC:6UA+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*;7-G:60@(B(*(E-H;W5L
M9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED
M9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL>2!W
M:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B(@HB1&$@;&D@YF4@=F5L
M:6MI(&MO;6%D:2!C:71I<F%N;V<@=&5K<W1A(&)I=&D@875T;VUA='-K:2!S
M86MR:79E;FD@:6QI("(*(G!R:6MA>F%N:3\@3W9O('-E(&UOOF4@;&%K;R!P
M<F]M:6IE;FET:2!K861A('IAOF5L:71E+B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I
M;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B4VAO=6QD
M('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@
M9')A9G0_(@IM<V=S='(@(D1A(&QI('IA='9O<FET:2!P<F]Z;W(@>F$@<&ES
M86YJ92!N;W9E('!O<G5K92!N86MO;B!S<&&Y879A;FIA(&YA8W)T83\B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I9"`B4VAO=6QD('EO=7(@
M4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E
M<R!B>2!D969A=6QT/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.CDR"B,L(&9U>GIY"FUS9VED(")3:&]W($%L;"!&;VQD97)S
M(@IM<V=S='(@(E-K=7!I('-V92!F;VQD97)E(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:&5A9&5R<RYI;F,Z-C<*;7-G:60@(E-H;W<@06QL($AE861E<G,B
M"FUS9W-T<B`B4')I:V&^:2!S=F$@<&]L:F$B"@HC.B!M86EL8F]X+G!H<#HS
M-C4*;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R(")0<FEK8;YI(&]B<FES
M86YE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*;7-G
M:60@(E-H;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(E!R:6MAOFD@<V%M
M;R!N96MA('!O;&IA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-S`*(RP@9G5Z>GD*;7-G:60@(E-H;W<@36%I;&EN9R!,:7-T($EN9F]R
M;6%T:6]N(@IM<V=S='(@(D]S;V)N92],:>AN92!I;F9O<FUA8VEJ92(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B4')I:F%V
M:2!S92!N82!&;VQD97(H92DB"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@
M(E-H;W<@56YS=6)S8W)I8F5D(@IM<V=S='(@(E!R:6MAOFD@;F5P<FEJ879L
M:F5N92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#@*;7-G:60@(E-H
M;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@871T86-H;65N=',@
M9G)O;2!M97-S86=E<S\B"FUS9W-T<B`B4')I:V&^:2!I:V]N=2!K;VIA(&]M
M;V=UYG5J92!B<FES86YJ92!P<FEL;V=A(&EZ('!O<G5K93\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`P,@IM<V=I9"`B4VAO=R!L96=E;F0@:6X@
M=&AE(&UA:6QB;W@@=FEE=S\B"FUS9W-T<B`B4')I:V&^:2!L96=E;F1U('4@
M<')I:V%Z=2!S86YD=>AE=&$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@T,`IM<V=I9"`B4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE<W-A9V5S
M(&]N;'D_(@IM<V=S='(@(E!R:6MAOFD@<V&^971K92!S86UO('IA(&YE<')O
MZ&ET86YE('!O<G5K93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0X
M"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R(")0
M<FEK8;YI('-AOF5T:V4@=2!O8FQAZ&GF:6UA/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-S<*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O
M;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B4')I:V&^:2!I:V]N=2!Z82!6
M86YJ<VME(')AZ'5N92!U(&UE;FEJ=3\B"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE($EM86=E<R(*
M;7-G<W1R(")0<FEK87H@<&]R=6MA('4@(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F:6QT97(@:6-O;B!O
M;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B4')I:V&^:2!I:V]N=2!F:6QT97)A
M('4@;65N:6IU/R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR.`IM<V=I
M9"`B4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8V"FUS9VED(")3
M:&]W;B(*;7-G<W1R(")0<FEK87IA;F\B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C0R"FUS9VED(")3:5]Z92(*;7-G<W1R
M(")?5F5L:>AI;F$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC
M.C$W"FUS9VED(")3:6=N960B"FUS9W-T<B`B4&]T<&ES86YA(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*;7-G:60@(E-I>F4B
M"FUS9W-T<B`B5F5L:>AI;F$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($%R
M<FEV86PB"FUS9W-T<B`B5&]K('1E;64B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")3;W)T
M(&)Y($1A=&4B"FUS9W-T<B`B5&]K('1E;64B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(V"FUS9VED(")3;W)T(&)Y($9R
M;VT@061D<F5S<R(*;7-G<W1R(")3;W)T:7)A:B!P;R!A9')E<VD@<&^Y:6QJ
M86]C82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z-#$*;7-G:60@(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(E-O
M<G1I<F%J('!O('9E;&GH:6YI('!O<G5K92(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S8*;7-G:60@(E-O<G0@8GD@4W5B
M:F5C="(*;7-G<W1R(")3;W)T:7)A:B!P;R!T96UI(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,0IM<V=I9"`B4V]R="!B
M>2!4:')E860B"FUS9W-T<B`B5&]K('1E;64B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q"FUS9VED(")3;W)T(&)Y(%1O
M($%D9')E<W,B"FUS9W-T<B`B4V]R=&ER86H@<&\@861R97-I('!R:6UA;V-A
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S"FUS9VED
M(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`B1F]L9&5R('IA('-P86TZ(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0V"FUS9VED(")3<&5C
M:6%L($-H87)A8W1E<G,B"FUS9W-T<B`B4W!E8VEJ86QN:2!K87)A:W1E<FDB
M"@HC.B!S96%R8V@N<&AP.C$S,PIM<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O
M;&1E<G,@8V%N(&YO="!B92!E9&ET960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T,PIM<V=I9"`B4W!E;&P@0VAE
M8VLB"FUS9W-T<B`B4')O=FIE<F$@<')A=F]P:7-A(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")3<&5L;"!#:&5C:V5R
M(@IM<V=S='(@(E!R;W9J97)A('!R879O<&ES82(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S
M='(@(E!R;W9J97)A('!R879O<&ES82!G;W1O=F$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#<Q"FUS9VED(")3<&5L;&EN9R!E<G)O<G,@<&5R('-C
M<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R(")"<F]J(&=R9;EA
M:V$@<&\@96MR86YU('!R:6QI:V]M('!R;W9J97)E('!R879O<&ES83\B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$R(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-3(*;7-G:60@(E-T87)T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G
M:60@(E-T871I;VYE<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y
M<&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*
M;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T<B`B4')I;&]G(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S,@IM<V=I9"`B4W1R:7`@;&EN96)R
M96%K<S\B"FUS9W-T<B`B56ML;VYI(&YO=F4@<F5D;W9E/R(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*;7-G:60@(E-U
M8E]J96-T(@IM<V=S='(@(E1E7VUA(@H*(SH@;65S<V%G92YP:'`Z,C8X('1H
M<F5A9"YP:'`Z,34P('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z
M,C4*(SH@;&EB+U-E87)C:"YP:'`Z,S@*;7-G:60@(E-U8FIE8W0B"FUS9W-T
M<B`B5&5M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C`*;7-G:60@
M(E-U8FIE8W0@1FEE;&0B"FUS9W-T<B`B4&]L:F4@=&5M92(*"B,Z('-E87)C
M:"YP:'`Z,S$X('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ
M.`HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C`@=&5M<&QA
M=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,0IM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(E!ON6%L:FDB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R(")0
M<FEJ879I('-E(&YA($9O;&1E<BAE*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,S@P(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X.0HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R(")5<W!J9;EN;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHX-@IM<V=I9"`B4W5G9V5S=&EO;G,B"FUS9W-T<B`B4')I:F5D
M;&]Z:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C(@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8V-`HC+"!F=7IZ>0IM<V=I9"`B4W5M;6%R
M>2(*;7-G<W1R(")38;YE=&%K(&9O;&1E<F$B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#`S"FUS9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P
M-`IM<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED
M(")3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,3D*;7-G:60@
M(E1E7WAT(@IM<V=S='(@(E1E7VMS="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HR-CD*;7-G:60@(E1E;G1A=&EV93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A=&EV
M96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E
M96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E<FUS(&]F(%-E
M<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,`HC+"!F
M=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R(")495]K<W0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN(&]F
M('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@(DMO;&]N
M82!0;[EI;&IA;V-A('1R96)A(&)I=&D@;&EN:R!N83HB"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4S,@IM<V=I9"`B(@HB5&AE($E-05`@<V5R=F5R(&1O
M97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A=&EO;B!M
M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S
M;W5R8V4@9F]R:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P
M;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!-86-I
M;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RXB"FUS
M9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<(B!J92!O8G)I<V%N
M+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HW-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R("))9&5N=&ET970@7"(E<UPB(&IE('-AZ'5V86XN(@H*(SH@
M871T86-H;65N="YP:'`Z-#,*(RP@9G5Z>GD*;7-G:60@(E1H92!A='1A8VAM
M96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(E!R:6QO>FDB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-CD*;7-G:60@(E1H92!C86QE;F1A<B!D
M871A(&ES(&EN=F%L:60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I9"`B(@HB5&AE(&-O
M;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V
M92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP
M:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I
M;&4@87)E(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I(%PB)7-<(B!W:6QL
M(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")4<F5N=71N;R!I;64@
M9F]L9&5R82!<(B5S7"(@YF4@8FET:2!P<F]M:6IE;FIE;F\@=2!<(B5S7"(N
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE
M(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O
M;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM<V=S='(@(B(*(DYI<V%M
M(&UO9V%O(&1O8F%V:71I(&QI<W1U(&MO<FES;FEK82!K;VII(&EM86IU('!R
M879O('!R:7-T=7!A(&]V;VT@9F]L9&5R=2(*"B,Z(&-O;7!O<V4N<&AP.C$R
M,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!D<F%F="!H87,@
M8F5E;B!S879E9"!T;R!T:&4@7"(E<UPB(&9O;&1E<BXB"FUS9W-T<B`B261E
M;G1I=&5T(%PB)7-<(B!J92!S8>AU=F%N+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ,SD*;7-G:60@(E1H92!E=F5N="!W87,@861D960@=&\@
M>6]U<B!C86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O97AP86YD+FEN8SHY"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L
M9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L
M9&5R(%PB)7-<(B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(")&;VQD97(@7"(E
M<UPB('9EYB!P;W-T;VII(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS
M(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E
M("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(D9O;&1E<B!<(B5S7"(@<V%D<KYI(&EL96=A
M;&YE(&MA<F%K=&5R92!U(&EM96YU+B!+86\@=&%K878@;6^^92!B:71I("(*
M(G!R;V)L96UA=&GH86XN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4V"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D
M(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B
M1F]L9&5R(%PB)7-<(B!J92!K<F5I<F%N(&%L:2!N:7-T92!P<FEJ879L:F5N
M:2!N82!N:F5G82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T
M('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B
M1F]L9&5R(%PB)7-<(B!J92!O8G)I<V%N(&%L:2!N:7-T92!O9&IA=FQJ96YI
M('-A(&ES=&]G+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,T,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T(&-R96%T960N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B1F]L9&5R
M(%PB)7-<(B!N:6IE(&MR96ER86XN($]V;R!J92!P;W)U:V$@<V5R=F5R82(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B1F]L9&5R(%PB)7-<(B!N:6IE
M(&]B<FES86XN($]V;R!J92!P;W)U:V$@<V5R=F5R82(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N(@IM<V=S='(@(D9O;&1E
M<B!<(B5S7"(@:F4@=7-P:F6Y;F\@:W)E:7)A;BXB"@HC.B!L:6(O1F]L9&5R
M+G!H<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")&;VQD97(@
M7"(E<UPB(&IE('5S<&IEN6YO(&]B<FES86XN(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@
M(DEM92!F;VQD97)A(%PB)7-<(B!J92!U<W!J9;EN;R!P<F]M:F5N:F5N;R!U
M(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G
M:60@(E1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES
M('!A<G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?<V%V96EM86=E7W=I;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE(&EM86=E('-A
M=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E
M('-E="!Y;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"B,L
M(&9U>GIY"FUS9VED("(B"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D
M(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@(@HB861D
M<F5S<V)O;VLN(@IM<V=S='(@(B(*(D%U=&]M871S:VD@<')I:V&^:2!S;&EK
M92!U($A434P@<&]R=6MA;6$@>F$@:V]J92!J92!P;[EI;&IA;&%C('4@;6]M
M("(*(F%D<F5S87)U/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<U"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL
M;W=I;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3$*;7-G:60@(E1H92!M86EL('-E
M<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE
M<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.CDP"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F
M;VQL;W=I;F<@;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C8U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UA:6QB
M;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B)7,@:F4@=F7F('!R
M87IA;BXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B
M>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PHC+"!F=7IZ
M>0IM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@
M8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("))9&5N=&ET970@7"(E<UPB(&IE
M(&]B<FES86XN(@H*(SH@;65S<V%G92YP:'`Z,30X"B,L(&9U>GIY"FUS9VED
M(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N
M=&ET970@7"(E<UPB(&IE(&]B<FES86XN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,SDS"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!H87,@
M8F5E;B!V97)I9FEE9"XB"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<(B!J92!S
M8>AU=F%N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E
M;B!V97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T<B`B261E;G1I=&5T(%PB
M)7-<(B!J92!S8>AU=F%N+B(*"B,Z('1E;7!L871E<R]S;6EM92]O<&5N7W-M
M:6UE7W=I;BYJ<SHQ,"!T96UP;&%T97,O<&=P+V]P96Y?<&=P7W=I;BYJ<SHQ
M,`IM<V=I9"`B(@HB5&AE('!A<W-P:')A<V4@=VEN9&]W(&-A;B=T(&)E(&]P
M96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*
M(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y(&-A;B!B92!V:65W960@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HV
M,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8T"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I
M;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM96YT+B(*;7-G
M<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S=&EN
M9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("(*(F9R;VT@
M>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S92!C
M;&EC:R`E<R!T;R!S96YD('1H92`B"B)N;W1I9FEC871I;VX@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-CD*
M;7-G:60@(E1H92!S97)V97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H
M=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P-`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N(@IM<V=S='(@(D9O
M;&1E<B!<(B5S7"(@:F4@=7-P:F6Y;F\@:W)E:7)A;BXB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P,@HC+"!F=7IZ>0IM<V=I9"`B5&AE
M('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R
M(")&;VQD97(@7"(E<UPB(&IE('5S<&IEN6YO(&MR96ER86XN(@H*(SH@871T
M86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB
M)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<
M(B!J92!S8>AU=F%N+B(*"B,Z('-T871I;VYE<GDN<&AP.C8S"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<(B!J92!O
M8G)I<V%N+B(*"B,Z('-T871I;VYE<GDN<&AP.C@W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@
M=7!D871E9"XB"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<(B!J92!O8G)I<V%N
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-CD*(RP@9G5Z>GD*
M;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI
M<W0N(@IM<V=S='(@(DED96YT:71E="!<(B5S7"(@:F4@<V'H=79A;BXB"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY-0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4B"FUS9W-T<B`B;V)R:;EI('!O
M<G5K=2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G
M92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")O8G)IN6D@<&]R=6MU(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#`*(RP@9G5Z>GD*;7-G
M:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(@IM<V=S='(@
M(E5S;6IE<FD@;W9U('!O<G5K=2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*
M;7-G<W1R(")5<VUJ97)I(&]V=2!P;W)U:W4B"@HC.B!L:6(O34E-12]6:65W
M97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E
M>'0@;V8@=&AE('-E;G0@;65S<V%G92(*;7-G<W1R(")5<VUJ97)I(&]V=2!P
M;W)U:W4B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M('-E;G0@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")5<VUJ
M97)I(&]V=2!P;W)U:W4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,34T"B,L(&9U>GIY"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R(")&;VQD
M97(@7"(E<UPB(&IE('5S<&IEN6YO(&MR96ER86XN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM<V=I9"`B5&AE<F4@87)E(&YO
M(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V5M<'1Y7VUA
M:6QB;W@N:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T
M:&ES(&UA:6QB;W@N(@IM<V=S='(@(DYE;6$@<&]R=6MA('4@;W9O;2!M86EL
M8F]X+74N(@H*(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES(&YO
M('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8Q,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(").87-T86\@:F4@<')O8FQE
M;2!S82#H:;GF96YJ96T@)7,N($]V;R!J92!P;W)U:V$@<V5R=F5R82(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HV-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X
M+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DYA<W1A;R!J92!P<F]B
M;&5M('-A(.AIN>9E;FIE;2!M86EL8F]X+6$N($]V;R!J92!P;W)U:V$@<V5R
M=F5R83H@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z-C(Q"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(").87-T86\@:F4@<')O
M8FQE;2!S82#H:;GF96YJ96T@;6%I;&)O>"UA+B!/=F\@:F4@<&]R=6MA('-E
M<G9E<F$B"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE
M<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H
M92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)$97-I;&$@<V4@9W)EN6MA
M('1O:V]M(&MO<&ER86YJ82!P;W)U:V$@=2!<(B5S7"(N($]V;R!J92!P;W)U
M:V$@<V5R=F5R82(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ.3@@;&EB+TUE<W-A
M9V4N<&AP.C(Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R(%PB
M)7-<(BX@5&AI<R!I<R!W:&%T("(*(G1H92!S97)V97(@<V%I9"(*;7-G<W1R
M("(B"B)$97-I;&$@<V4@9W)EN6MA('1O:V]M(&)R:7-A;FIA('!O<G5K82!I
M>B!F;VQD97)A(%PB)7-<(BX@3W9O(&IE('!O<G5K82`B"B)S97)V97)A(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE
M(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A
M:60B"FUS9W-T<B`B(@HB1&5S:6QA('-E(&=R9;EK82!T;VMO;2!B<FES86YJ
M82!P;W)U:V$@:7H@9F]L9&5R82!<(B5S7"(N($]V;R!J92!P;W)U:V$@(@HB
M<V5R=F5R82(*"B,Z(&QI8B]-97-S86=E+G!H<#HR,3$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS
M9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!B<FES86YJ82!P;W)U:V$N
M($]V;R!J92!P;W)U:V$@<V5R=F5R82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HY.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@
M(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@Z&ET86YJ82!O9&%B<F%N92!P;W)U
M:V4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-
M12]6:65W97(O96YR:6-H960N<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")$
M97-I;&$@<V4@9W)EN6MA('1O:V]M('!R:6MA>F$@;W9O9R!D:6IE;&$@<&]R
M=6ME(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4T-2!L:6(O365S<V%G92YP:'`Z
M-3@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI
M<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)$97-I
M;&$@<V4@9W)EN6MA('1O:V]M(&UA<FMI<F%N:F$@<&]R=6MA('4@7"(E<UPB
M+B!/=F\@:F4@<&]R=6MA('-E<G9E<F$B"@HC.B!F;VQD97)S+G!H<#HQ-C4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@)7,N(@IM<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K
M;VT@<W!AN6%V86YJ82!N97IA=G*Y96YE('!O<G5K92XB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@
M)7,N(@IM<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@Z&ET86YJ82!O
M9&%B<F%N92!P;W)U:V4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$V-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(D1E<VEL
M82!S92!G<F6Y:V$@=&]K;VT@Z&ET86YJ82!O9&%B<F%N92!P;W)U:V4N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U
M<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`B1&5S
M:6QA('-E(&=R9;EK82!T;VMO;2#H:71A;FIA(&]D86)R86YE('!O<G5K92XB
M"@HC.B!L:6(O365S<V%G92YP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@
M9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E
M<G9E<B!S86ED(@IM<V=S='(@(B(*(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@
M<')E8F%C:79A;FIA('!O<G5K82!U(%PB)7-<(BX@3W9O(&IE('!O<G5K82!S
M97)V97)A(@H*(SH@8V]M<&]S92YP:'`Z,3(T-`HC+"!F=7IZ>0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE<W-A9V4@87,@82!D
M<F%F="XB"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!P<FEK87IA
M(&]V;V<@9&EJ96QA('!O<G5K92(*"B,Z(&-O;7!O<V4N<&AP.C$P,#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@
M>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R(")$97-I;&$@<V4@9W)EN6MA('1O
M:V]M('-L86YJ82!P;W)U:V4Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@
M(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<VQA;FIA('!O<G5K93H@)7,B"@HC
M.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4Y"B,L(&9U>GIY"FUS9VED
M(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R="(*;7-G
M<W1R(")$97-I;&$@<V4@9W)EN6MA('1O:V]M('!R:6MA>F$@;W9O9R!D:6IE
M;&$@<&]R=6ME(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"B,L
M(&9U>GIY"FUS9VED(")4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M
M8F5D9&5D(&EN(&ET+B(*;7-G<W1R("))9&5N=&ET970@7"(E<UPB(&IE(&]B
M<FES86XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP"FUS9VED
M("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN
M(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED
M(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$P-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$X"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ-#,@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$U-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<S(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HS,30*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-SD@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I
M9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`HC
M+"!F=7IZ>0IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B1&$@;&D@
M4TE'55).3R"^96QI=&4@;F%S=&%V:71I/R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT
M86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C0Q,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E
M(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L
M;'D@<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$T"FUS9VED(")4:&ES(&UE<W-A9V4@
M8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E
M9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN
M<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F
M;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q-0IM<V=I9"`B(@HB
M5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'
M4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G<W1R(")/=F$@<&]R
M=6MA(&YE(&EZ9VQE9&$@:V%O(&ES<')A=FYA(%!'4""Y:69R;W9A;F$@<&]R
M=6MA+B!'<F6Y:V$Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(T
M,"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS-3`*(RP@9G5Z>GD*;7-G:60@
M(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE
M(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U
M*2XB"FUS9W-T<B`B3W9A('!O<G5K82!N92!I>F=L961A(&MA;R!I<W!R879N
M82!01U`@N6EF<F]V86YA('!O<G5K82X@1W)EN6MA.B`B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$W,`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!M
M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3
M+TU)344@9F]R;6%T+B(*;7-G<W1R(")/=F$@<&]R=6MA(&YE(&EZ9VQE9&$@
M:V%O(&ES<')A=FYA(%!'4""Y:69R;W9A;F$@<&]R=6MA+B!'<F6Y:V$Z("(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HT,38*(RP@9G5Z>GD*;7-G:60@(E1H:7,@;65S<V%G92!H
M87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N(@IM<V=S='(@(DED
M96YT:71E="!<(B5S7"(@:F4@;V)R:7-A;BXB"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B5&AI<R!M97-S86=E
M(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12XB"FUS9W-T
M<B`B261E;G1I=&5T(%PB)7-<(B!J92!O8G)I<V%N+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,3,Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@
M96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(DED96YT:71E="!<(B5S
M7"(@:F4@;V)R:7-A;BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M,#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED
M(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*
M;7-G<W1R("))9&5N=&ET970@7"(E<UPB(&IE(&]B<FES86XN(@H*(SH@;65S
M<V%G92YP:'`Z,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T<B`B
M3W9A('!O<G5K82!U(@H*(SH@86-L+G!H<#HT-@IM<V=I9"`B5&AI<R!S97)V
M97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y"FUS
M9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S
M92!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,34R"B,L(&9U
M>GIY"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G<W1R(")0<FEK8;YI(@H*
M(SH@=&AR96%D+G!H<#HW-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(R"FUS
M9VED(")4:')E860@5FEE=R(*;7-G<W1R(")0<FEK87H@<&\@=&]K=2!T96UE
M(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP.C8P-B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E<R]C;VUP;W-E
M+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O
M<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS9VED(")4;R(*;7-G<W1R
M("):82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3D*;7-G:60@(E1O
M($%D9')E<W,B"FUS9W-T<B`B061R97-A('!ON6EL:F%O8V$B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O
M('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM
M<V=S='(@(B(*(D1A(&)I<W1E(&EZ86)R86QI('9IN64@;V0@:F5D;F]G('!O
M;&IA+"!D<KYI=&4@=&EP:W4@0V]N=')O;"`H4$,I(&]D;F]S;F\@(@HB0V]M
M;6%N9"`H36%C*2!P<FEL:6MO;2!K;&EK86YJ82XB"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C$S-`IM<V=I9"`B(@HB5&\@=7-E(&$@5$Q3(&-O;FYE8W1I
M;VXL('EO=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C`N
M-B!O<B`B"B)H:6=H97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C4W-PHC+"!F=7IZ>0IM<V=I9"`B5&]T86P@071T
M86-H;65N=',@4VEZ93HB"FUS9W-T<B`B4')I;&]Z:2(*"B,Z(&9O;&1E<G,N
M<&AP.C,X.`IM<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(D9O;&1E<B!Z
M82!S;67F93HB"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC
M.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM<V=S='(@(D9O;&1E<B!K;W)P
M83HB"@HC.B!L:6(O475O=&$O8WER=7,N<&AP.C8U(&QI8B]1=6]T82]M97)C
M=7)Y,S(N<&AP.C<Y(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC.B!L:6(O
M475O=&$O;&]G9FEL92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP.C4S
M(&QI8B]1=6]T82]M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O(')E
M=')I979E('%U;W1A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,V
M"FUS9VED(")5;F%N<W=E<F5D(@IM<V=S='(@(DYE;V1G;W9O<F5N82(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@(E5N86YS=V5R
M960@;65S<V%G97,B"FUS9W-T<B`B3F5O9&=O=F]R96YE('!O<G5K92(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T92(*
M;7-G<W1R(")6<F%T:2!O8G)I<V%N92(*"B,Z(&UA:6QB;W@N<&AP.C4X.2!M
M86EL8F]X+G!H<#HV,#(@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$R"FUS9VED
M(")5;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(E!R:6UA;V-I('-U
M('-K<FEV96YI(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0T-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y
M<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V-0HC+"!F=7IZ
M>0IM<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@(DYE('!R:6MA>F%N:2!P
M<FEM86]C:2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,SDU"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N:VYO=VX@24U!4"!R97-P;VYS92!F<F]M('1H92!S
M97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,S4*(RP@9G5Z>GD*;7-G:60@(E5N
M:VYO=VX@365E=&EN9R(*;7-G<W1R(").92!P<FEK87IA;FD@<')I;6%O8VDB
M"@HC.B!M86EL8F]X+G!H<#HV,3@*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@
M4F5C:7!I96YT(@IM<V=S='(@(DYE('!R:6MA>F%N:2!P<FEM86]C:2(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*
M;7-G<W1R(")5;F5S:71E(&9R87IU(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP
M.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@(D)E>FEM96YI(@H*(SH@;65S
M<V%G92YP:'`Z-#DY(&UA:6QB;W@N<&AP.C<P."!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,R
M"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-0IM<V=I9"`B56YS
M965N(@IM<V=S='(@(DYE<')OZ&ET86YA(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,3(*;7-G:60@(E5N<W5B<V-R:6)E(&9R;VT@1F]L
M9&5R*',I(@IM<V=S='(@(D]D:F%V:2!S92!S82!&;VQD97)A(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@T"B,L(&9U>GIY"FUS9VED
M(")5<&1A=&4@071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O
M<FUA8VEJ92!S97)V:7-A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8R,`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU."!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"B,L(&9U>GIY"FUS9VED(")5
M<&QO860B"FUS9W-T<B`B0;YU<FER86H@<')I:V%Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U
M;'0@5F%L=64B"FUS9W-T<B`B2V]R:7-T:2!D969A=6QT('9R:6IE9&YO<W0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED(")5<V4@24U!
M4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T<B`B2V]R:7-T:2!)34%0
M(&9O;&1E<B!P<FEJ879U/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M,S4*(RP@9G5Z>GD*;7-G:60@(E5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\B
M"FUS9W-T<B`B5FER='5A;&YI(&9O;&1E<FDB"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,30R"FUS9VED(")5<V5R(@IM<V=S='(@(DMO<FES;FEK(@H*
M(SH@86-L+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M57-E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@
M<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B2V]R:7-N
M:6MU("<E<R<@<W4@=7-P:F6Y;F\@9&%T82!P<F%V82!N82!F;VQD97(@)R5S
M)RXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-PIM<V=I9"`B
M57-E<FYA;64B"FUS9W-T<B`B2V]R:7-N:>AK;R!I;64B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3<*;7-G:60@(E5S97)N86UE.B(*
M;7-G<W1R(")+;W)I<VYIZ&MO(&EM93HB"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,C<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B5FEE=R(*;7-G<W1R
M(")0<FEK87H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HY,B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3`X"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,B"FUS9W-T<B`B4')I:V%Z("5S(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,@4'5B;&EC($ME
M>2(*;7-G<W1R("(B"B)68;EE(&EM92!I('!R97II;64Z(#QI/BAO=F%J('!O
M9&%T86L@=FED92!D<G5G:2!K861A(.AI=&%J=2!V8;EE('!O<G5K92D\+VD^
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC+"!F=7IZ>0IM
M<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B
M"FUS9W-T<B`B2W)E:7)A:B!P;W)U:W4@=2!Z87-E8FYO;2!P<F]Z;W)U/R(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X"B,L(&9U>GIY
M"FUS9VED(")6:65W($UE<W-A9V5S(@IM<V=S='(@(DYO=F4@<&]R=6ME(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+97DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R("(B"B)68;EE(&EM92!I('!R
M97II;64Z(#QI/BAO=F%J('!O9&%T86L@=FED92!D<G5G:2!K861A(.AI=&%J
M=2!V8;EE('!O<G5K92D\+VD^(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R
M(")6:61I(.AI=&%V=2!T96UU(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V-0HC+"!F
M=7IZ>0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B5FED:2#H:71A
M=G4@=&5M=2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X"B,L
M(&9U>GIY"FUS9VED(")6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<B"FUS9W-T<B`B2W)E:7)A:B!P;W)U:W4@=2!Z87-E8FYO;2!P<F]Z
M;W)U/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!F
M=7IZ>0IM<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W
M(@IM<V=S='(@(DMR96ER86H@<&]R=6MU('4@>F%S96)N;VT@<')O>F]R=3\B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30P"B,L(&9U>GIY"FUS
M9VED(")6:65W(&5V96YT(@IM<V=S='(@(E!R:6MA>B`E<R(*"B,Z(&9O;&1E
M<G,N<&AP.C,X,"!M86EL8F]X+G!H<#HU,S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E9I97<@;65S<V%G97,@:6X@)7,B"FUS9W-T<B`B4')I:V%Z
M('!O<G5K82!U("(*"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E
M;&5C="YI;F,Z,C,*;7-G:60@(E9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN.B(*;7-G<W1R(")0<FEK87H@:6QI('-A;F1UZ&4@:V]J
M92#F92!S92!P<FEK87IA=&D@;F%K;VX@<')I:F%V93HB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3<P"B,L(&9U>GIY"FUS9VED(")6:65W('1A
M<VLB"FUS9W-T<B`B4')I:V%Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM
M<V=S='(@(E!R:6MA>B!P;W)U:V$@=2`B"@HC.B!S96%R8V@N<&AP.C(V,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FER='5A;"!&;VQD97(@7"(E
M<UPB(&-R96%T960@<W5C8V5S9G5L;'DN(@IM<V=S='(@(D9O;&1E<B!<(B5S
M7"(@:F4@=7-P:F6Y;F\@;V)R:7-A;BXB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C$Q,2!L:6(O24U!4"]4<F5E+G!H<#HQ,S@@;&EB+TE-05`O
M5')E92YP:'`Z,34Q"B,Z(&QI8B])34%0+U1R964N<&AP.C$U,R!L:6(O24U!
M4"]4<F5E+G!H<#HQ-3<@;&EB+TE-05`O5')E92YP:'`Z,34X"B,Z(&QI8B])
M34%0+U1R964N<&AP.C,V.2!L:6(O24U!4"]4<F5E+G!H<#HS.3,@;&EB+TE-
M05`O5')E92YP:'`Z-#,S"FUS9VED(")6:7)T=6%L($9O;&1E<G,B"FUS9W-T
M<B`B5FER='5A;&YI(&9O;&1E<FDB"@HC.B!S96%R8V@N<&AP.C(T-0IM<V=I
M9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB"FUS9W-T<B`B
M6F$@=FER='5A;&YI(&9O;&1E<B!J92!O8F%V97IN82!O>FYA:V$N(@H*(SH@
M;&EB+U9&;VQD97(N<&AP.C$W-2!L:6(O5D9O;&1E<BYP:'`Z,3@P"FUS9VED
M(")6:7)T=6%L($E.0D]8(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q
M-@HC+"!F=7IZ>0IM<V=I9"`B5FER='5A;"!)3D)/6"!&;VQD97(B"FUS9W-T
M<B`B5FER='5A;&YI(&9O;&1E<FDB"@HC.B!M86EL8F]X+G!H<#HT-3(@;&EB
M+U9&;VQD97(N<&AP.C$Q-"!L:6(O5D9O;&1E<BYP:'`Z,3$Y"B,L(&9U>GIY
M"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(E9I<G1U86QN:2!F;VQD
M97)I(@H*(SH@9F]L9&5R<RYP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")6:7)T
M=6%L(%1R87-H($9O;&1E<B(*;7-G<W1R(")6:7)T=6%L;FD@9F]L9&5R:2(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3,S"FUS9VED(")6:7)T
M=6%L(&9O;&1E<B!L86)E;"(*;7-G<W1R(")/>FYA:V$@=FER='5A;&YO9R!F
M;VQD97)A(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S0*(RP@
M9G5Z>GD*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B4')ON6ER=6IE;2(*"B,Z
M(&QO9VEN+G!H<#HQ,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T
M;R`E<R(*;7-G<W1R(")$;V)R;R!D;[EL:2!N82`E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,3D*(RP@9G5Z>GD*;7-G:60@(B(*(E=H870@<VAO
M=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G<W1R
M(")/8G)IN6D@<&]R=6MU(&YA:V]N('!R:6IA=FQJ:79A;FIA(&MA;R!S<&%M
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,C<*;7-G:60@(B(*(E=H
M96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H
M(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE=&5D
M/R(*;7-G<W1R("(B"B)0<FEL:6MO;2!B<FES86YJ82!P;W)U:V$L(&1A(&QI
M(&1A(&EH('!R96)A8VEM('4@9F]L9&5R($MO<G!A('5M:F5S=&\@9&$@:6@@
M(@HB;WIN8>AI;2!K86\@;V)R:7-A;F4_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDP-PIM<V=I9"`B5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L
M('=H:6-H('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_(@IM<V=S='(@
M(E!R:6QI:V]M(&]T=F%R86YJ82!S86YD=>AIYF$L(&YA(&MO:F]J('-T<F%N
M:6-I(+YE;&ET92!P;^AE=&D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@
M<V%V92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(E!R:6QI:V]M('-N:6UA
M;FIA('!O<VQA;F4@<&^Y=&4L('1R96)A;6\@;&D@<&%M=&ET:2!I('!R:6QO
M9V4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB
M5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA
M="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A
M9&1R97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED
M(")7:&ET96QI<W0B"FUS9W-T<B`B0FEJ96QA(&QI<W1A(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-S@*;7-G:60@(EEE<R(*;7-G<W1R(")$82(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-3@*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@
M9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(E!O9&5S:71E(&1O8F%V
M;&IA;FIE('!ON71E('-A(&4M;6%I;"!R8>AU;F$@;F$@9')U9VEM('-E<G9E
M<FEM82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH
M=&UL.C$P"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E
M(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F;VQD
M97(B"B(H<RDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O
M;&1E<G-?8V]N9FER;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN
M9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B66]U
M(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R"FUS
M9VED(")9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*
M;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L
M9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ,S4*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@
M9G)O;2!<(B5S7"(N(@IM<V=S='(@(E5S<&IEN6YO('-T92!O9&IA=FQJ96YI
M('-A(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@8V%N('5S92!T:&4@
M9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT
M.B`E8R!F;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F
M;W(@=&AE('-I9VYA='5R92XB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D
M:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N
M="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-CD*;7-G:60@(EEO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@
M=&AI<R!F;VQD97(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$R
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O<G=A<F1E9"!T
M:&ES(&UE<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C:7!I96YT
M<SH@)7,N(@IM<V=S='(@(E5S;6IE<FEL:2!S=&4@;W9U('!O<G5K=2!N82`E
M<R`M("4E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE
M<W-A9V5S+B(*;7-G<W1R("(@+2`D;FT@;F]V:6@@<&]R=6MA(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(B`M("1N;2!N;W9A('!O
M<G5K82(*"B,Z(&-O;7!O<V4N<&AP.C0Y-`HC+"!F=7IZ>0IM<V=I9"`B66]U
M(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E+B(*;7-G<W1R("(@
M+2`D;FT@;F]V82!P;W)U:V$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYJ<SHQ,34*;7-G:60@(B(*(EEO=2!H879E(&%T(&QE87-T(&]N
M92!A='1A8VAM96YT('-E;&5C=&5D('1H870@>6]U(&1I9&XG="!U<&QO860@
M>65T+B!!<F4@(@HB>6]U('-U<F4@>6]U('=A;G0@=&\@<V5N9"!T:&ES(&UE
M<W-A9V4@=VET:&]U="!T:&5S92!A='1A8VAM96YT<S\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TE-4"YP:'`Z,3`W-`IM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@
M:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z(@IM<V=S='(@(B(*"B,Z(&QI8B])
M35`N<&AP.C$P-SD*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z
M,34S"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S="!O
M;F4@<F5C:7!I96YT+B(*;7-G<W1R(")-;W)A=&4@;F%V97-T:2!B87(@:F5D
M;F]G('!R:6UA;V-A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,P
M,@IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R
M('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Y"FUS
M9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U
M<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI
M;F,Z-C0@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O
M>"!F:7)S="XB"FUS9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K
M;VII(+YE;&ET92!B<FES871I+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX
M-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`B36]R871E(&]D86)R871I(&MO<FES;FGH:VD@<F'H
M=6X@:V]J:2"^96QI=&4@8G)I<V%T:2XB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C@Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S
M96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B36]R871E(&]D86)R
M871I(&ED96YT:71E="!K;VII(+YE;&ET92!B<FES871I+B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8R('1E;7!L871E<R]M86EL
M8F]X+VIA=F%S8W)I<'0N:6YC.C(P.`HC.B!T96UP;&%T97,O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8SHR-C,*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A="!L96%S="!O;F4@;65S<V%G92!F:7)S="XB"FUS9W-T<B`B36]R
M871E(&YA=F5S=&D@8F%R(&IE9&YO9R!P<FEM86]C82XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!R96-I<&EE;G0N(@IM<V=S='(@(DUO<F%T92!N
M879E<W1I(&)A<B!J961N;V<@<')I;6%O8V$N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:G,Z,CD*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I;&4@=&\@871T86-H+B(*;7-G
M<W1R(")-;W)A=&4@;F%V97-T:2!B87(@:F5D;F]G('!R:6UA;V-A+B(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@96YA
M8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@(E-E
M<G9I<VYE(&]P97)A8VEJ92(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(')E9&ER96-T960@=&AI<R!M97-S86=E
M('1O("5S(&]N("4E<RXB"FUS9W-T<B`B57-M:F5R:6QI('-T92!O=G4@<&]R
M=6MU(&YA("5S("T@)25S+B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!R97!L:65D('1O('1H:7,@
M;65S<V%G92!O;B`E<RXB"FUS9W-T<B`B57-M:F5R:2!O=G4@<&]R=6MU(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z-3`W"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R92!I<R!W:&%T
M('1H92!S97)V97(@<V%I9"(*;7-G<W1R(").:7-T92!P<FEJ879L:F5N:2!N
M82!<(B5S7"(N($]V;R!J92!P;W)U:V$@<V5R=F5R82(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@
M=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(DYI<W1E(&]D:F%V;&IE;FD@<V$@7"(E<UPB
M+B!/=F\@:F4@<&]R=6MA('-E<G9E<F$B"@HC.B!L:6(O1F]L9&5R+G!H<#HU
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY
M('-U8G-C<FEB960@=&\@7"(E<UPB(@IM<V=S='(@(E5S<&IEN6YO('-T92!P
M<FEJ879L:F5N:2!N82!<(B5S7"(B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('5N
M<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R(")5<W!J9;EN;R!S=&4@
M;V1J879L:F5N:2!S82!<(B5S7"(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z.3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("(B"B)6
M8;EE(&EM92!I('!R97II;64Z(#QI/BAO=F%J('!O9&%T86L@=FED92!D<G5G
M:2!K861A(.AI=&%J=2!V8;EE('!O<G5K92D\+VD^(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C4P"B,L(&9U>GIY"FUS9VED(")9;W5R(%!'4"!0=6)L
M:6,O4')I=F%T92!+97ES(@IM<V=S='(@(B(*(E9AN64@:6UE(&D@<')E>FEM
M93H@/&D^*&]V86H@<&]D871A:R!V:61E(&1R=6=I(&MA9&$@Z&ET86IU('9A
MN64@<&]R=6ME*3PO:3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C<Q('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!0<FEV871E($ME>2(*;7-G<W1R("(B"B)68;EE(&EM92!I('!R97II
M;64Z(#QI/BAO=F%J('!O9&%T86L@=FED92!D<G5G:2!K861A(.AI=&%J=2!V
M8;EE('!O<G5K92D\+VD^(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHV-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S$*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@4'5B;&EC($ME>2(*;7-G<W1R("(B"B)68;EE(&EM92!I('!R97II
M;64Z(#QI/BAO=F%J('!O9&%T86L@=FED92!D<G5G:2!K861A(.AI=&%J=2!V
M8;EE('!O<G5K92D\+VD^(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V
M-0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!297!L>2UT;SH@861D<F5S<SH@/&5M
M/BAO<'1I;VYA;"D\+V5M/B(*;7-G<W1R(")68;EA(%)E<&QY+71O.B!A9')E
M<V$Z(#QI/BAN:6IE(&]B879E>FYO*3PO:3XB"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-12!0=6)L:6,O4')I
M=F%T92!#97)T:69I8V%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@86-C;W5N=',Z(@IM<V=S='(@(E9AN6D@:61E;G1I=&5T:3HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<S"B,L(&9U>GIY"FUS9VED("(B
M"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@
M96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB
M5F&Y92!A;'1E<FYA=&EV;F4@861R97-E.B`\:3XH;FEJ92!O8F%V97IN;RP@
M=6YE<VET92!S=F%K=2!A9')E<W4@=2!N;W9O;2`B"B)R961U*3PO:3XB"@HC
M.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY,@HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L
M87D@;V8@=&AI<R!I;6%G92!T>7!E+B(*;7-G<W1R(")68;D@8G)O=W-E<B!N
M96UA(&UO9W7F;F]S="!D82!D:7)E:W1N;R!P<FEK87IJ92!S;&EK92!O=F]G
M('1I<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,Y"FUS9VED(")9
M;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS
M9W-T<B`B56]B:>AA:F5N:2!K;V1N:2!R87-P;W)E9"!Z82!S;&%N:F4@<&]R
M=6MA.B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ
M"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E
M;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(E5O8FGH86IE;FD@;65T;V0@N6EF
M<F]V86YJ82!P;W)U:V$@<')I;&EK;VT@<VQA;FIA.B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")9;W5R(&UE
M<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(D9O
M;&1E<B!<(B5S7"(@:F4@=7-P:F6Y;F\@;V)R:7-A;BXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS
M9W-T<B`B5F&Y('!O='!I<SHB"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S
M92YP:'`Z,3(X-"!M86EL8F]X+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q
M.`IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM"97H@=&5M95TB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*;7-G:60@(E]"
M8V,B"FUS9W-T<B`B7T)C8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHQ-@IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R(")?0W)N82!L:7-T82(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$U-`IM<V=I9"`B
M7T-C(@IM<V=S='(@(E]#8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*;7-G:60@
M(E]$96QE=&4B"FUS9W-T<B`B3U]B<FFY:2(*"B,Z(&QI8B])35`N<&AP.CDW
M.0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`B7T9O;&1E<FDB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,0IM<V=I9"`B7TED96YT:71Y
M(@IM<V=S='(@(E])9&5N=&ET970B"@HC.B!L:6(O24U0+G!H<#HY-C$*;7-G
M:60@(E]);F)O>"(*;7-G<W1R(")?4V%N9'7H92(*"B,Z(&QI8B])35`N<&AP
M.C$P,C`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E])>FQA>B(*"B,Z(&UE
M<W-A9V4N<&AP.C,X-`IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@
M(E])>G9O<FYI(&MO9"!P;W)U:V4B"@HC.B!L:6(O24U0+G!H<#HY-S8*(RP@
M9G5Z>GD*;7-G:60@(E].97<@365S<V%G92(*;7-G<W1R(").;W9E('!O<G5K
M92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS
M,PIM<V=I9"`B7U!R:6YT(@IM<V=S='(@(D]DN5]T86UP86HB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,C@Y"B,L(&9U>GIY"FUS9VED(")?4')I;W)I='DB
M"FUS9W-T<B`B4')I;W)I=&5T(@H*(SH@;6%I;&)O>"YP:'`Z-#$X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")?4F5F<F5S:"`E<R(*;7-G<W1R(")!
MOG5R:7)A:B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHX"FUS9VED(")?4F5P;'DB"FUS9W-T<B`B7T]D9V]V;W)I(@H*(SH@
M;&EB+TE-4"YP:'`Z.3@Q"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E]4<F&^
M:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0IM<V=I9"`B7U-E;F0@365S
M<V%G92(*;7-G<W1R(")?4&^Y86QJ:2!P;W)U:W4B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,R"FUS9VED(")?5&AR96%D
M(@IM<V=S='(@(E]4;VL@=&5M92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C$Q-@IM<V=I9"`B7U1O(@IM<V=S='(@(E]:82(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")?56YD96QE
M=&4B"FUS9W-T<B`B7U9R871I(&]B<FES86YE(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")?5FEE=R!4:')E
M860B"FUS9W-T<B`B7U9I9&D@Z&ET879U('1E;74B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B
M7T)I:F5L82!L:7-T82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S8*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HT-#`*(RP@9G5Z>GD*;7-G:60@(F%T=&%C:&UE;G0B"FUS9W-T<B`B
M4')I;&]G(@H*(SH@=FEE=RYP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(F%T=&%C
M:&UE;G1S+GII<"(*;7-G<W1R(")0<FEL;WII(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B>71E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`P"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M-S(*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ-C0*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(P"FUS9VED
M(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ.38*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V.`IM<V=I9"`B
M9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(R-`IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")F
M<F]M(@IM<V=S='(@(F]D(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X,`IM<V=I
M9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C(P-`IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#@*;7-G:60@(FEN=&5R;F%L('-O
M9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N
M<&AP.C8Y"FUS9VED(")K97DB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M,38Q"FUS9VED(")M86EL8F]X(&9I;&4B"FUS9W-T<B`B;6%I;&)O>"!D871O
M=&5K82(*"B,Z(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP.C0V
M-@IM<V=I9"`B;F%M92(*;7-G<W1R(")I;64B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`B;FFY
M=&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS
M9VED(")O<B(*;7-G<W1R(")I;&DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$V
M"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,C$R"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C
M;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-`IM<V=I9"`B
M<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R
M(@IM<V=S='(@(G!R879O<&ES;F$@9W)EN6MA(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<G,B
M"FUS9W-T<B`B<')A=F]P:7-N92!G<F6Y:V4B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3DR"B,L(&9U>GIY"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B
M<')A=F]P:7-N82!G<F6Y:V$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`X"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL
M=&5R+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS
M9W-T<B`B0W)N82!L:7-T82(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED
M(")Y;W5R('=H:71E;&ES="(*;7-G<W1R(")V8;EA(&)I:F5L82!L:7-T82(*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+VED7TE$+G!O````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,V,#,W,P`Q,#0Q-S,V
M,C<V-``P,3<Q-3(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!33TU%($1%4T-225!4259%(%1)5$Q%+@HC($-O<'ER:6=H
M="`H0RD@645!4B!42$4@4$%#2T%'12=3($-/4%E224=(5"!(3TQ$15(*(R!4
M:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS
M92!A<R!T:&4@4$%#2T%'12!P86-K86=E+@HC($9)4E-4($%55$A/4B`\14U!
M24Q`041$4D534SXL(%E%05(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($E-4"!V,RXR+C)<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`T+3`Q+3`Y(#$S.C4V*S`W,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@4VQA;6EN(#QS;&%M:6Y`=6YE:BYA8RYI9#Y<;B(*(DQA;F=U86=E+51E
M86TZ(%505"!422!53D5*(#QU<'1T:4!U;F5J+F%C+FED/EQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS
M9VED("(@("`@("!#8SH@(@IM<V=S='(@(B`@("`@($ME<&%D83H@(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0Q-0IM<V=I9"`B("`@("`@5&\Z("(*;7-G<W1R
M("(@("`@("!+97!A9&$Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#,*;7-G
M:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@(%1A;F=G86PZ("(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HT,#8*;7-G:60@(B`@("!&<F]M.B`B"FUS9W-T<B`B
M("`@($1A<FDZ("(*"B,Z(&UA:6QB;W@N<&AP.C0R,B!T96UP;&%T97,O9F]L
M9&5R<R]H96%D+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S
M:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$R"FUS
M9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(B!097)I:&%L.B`B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S`*;7-G:60@(B!I;B`B"FUS
M9W-T<B`B('!A9&$@(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*;7-G<W1R("(C(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-
M0B`O("4N,F9-0B`@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H
M<#HQ-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D($UE<W-A9V5S
M(@IM<V=S='(@(B5D(&1A<FD@)60@4&5S86XB"@HC.B!M86EL8F]X+G!H<#HQ
M-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA
M=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")097-A;B!I;FD@<W5D86@@9&EL
M87!O<FMA;B!S96)A9V%I('-P86TN(@H*(SH@;&EB+U-P86TN<&AP.C$W.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E!E<V%N(&EN:2!S=61A:"!D:6QA
M<&]R:V%N('-E8F%G86D@<W!A;2!K97!A9&$@861M:6YI<W1R871O<B!S:7-T
M96T@86YD82XB"@HC.B!L:6(O4W!A;2YP:'`Z,34X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86TN(@IM<V=S='(@(E!E<V%N(&EN:2!S=61A:"!D:6QA<&]R
M:V%N('-E8F%G86D@<W!A;2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@
M<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"B)097-A;B!I;FD@<W5D86@@9&EL87!O<FMA;B!S96)A
M9V%I('-P86T@:V5P861A(&%D;6EN:7-T<F%T;W(@<VES=&5M(&%N9&$N(@H*
M(SH@;&EB+U-P86TN<&AP.C$U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM
M<V=S='(@(E!E<V%N(&EN:2!S=61A:"!D:6QA<&]R:V%N('-E8F%G86D@<W!A
M;2XB"@HC.B!M86EL8F]X+G!H<#HS-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@=&\@)60@;V8@)60@365S<V%G97,B"FUS9W-T<B`B)60@:V4@)60@9&%R
M:2`E9"!097-A;B(*"B,Z(&UA:6QB;W@N<&AP.C8T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R
M('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@<W5D86@@861A+B!.86UA
M(&9O;&1E<B`E<R!A;F1A('1I9&%K(&)E<G5B86@N(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C8T.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!M86EL8F]X+B(*;7-G<W1R("(E<R!T:61A
M:R!M=6YC=6P@<V5B86=A:2!M86EL8F]X('EA;F<@8F5N87(N(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9O;&1E<B!B96EN9R!R96YA
M;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N(@IM<V=S='(@(DYA;6$@
M9F]L9&5R("5S('-E9&%N9R!D:75B86@@<&%D82!A=V%L(&)U;&%N+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C(U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M(&1E8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D
M('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@=&5N=&%T:79E
M;'D@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@
M>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N
M(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@<W5D86@@9&EU8F%H(&YA;6$@:V4@
M7"(E<UPB(&1E;F=A;B!S=6MS97,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Y-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@
M86UM96YD("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3<T"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!M
M86ME('EO=2!A=V%R92!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W
M:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T
M("5S+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR.#4@;65S<V%G92YP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?=&]P+FEN8SHQ,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"DB
M"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B*$%P<&QY
M('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*;7-G
M<W1R("(H3&%K=6MA;B!P97)U8F%H86X@9&%N('!I;F1A:"!K92!L87EA<B!B
M97)I:W5T;GEA+BDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3(P"FUS9VED("(H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N
M('1O('1H92!C;VUP;W-E('-C<F5E;BXI(@IM<V=S='(@(BA!8F%I:V%N('-E
M;75A('!E<G5B86AA;B!D86X@:V5M8F%L:2!K92!L87EA<B!P96YG:7)I;6%N
M+BDB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G
M:60@(BA(5$U,*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!497AT*2(*;7-G<W1R("(B
M"@HC.B!S<&5L;&EN9RYP:'`Z,C@P"FUS9VED("(B"B(H4F5T=7)N('1O('1H
M92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M
M861E('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E
M96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BA+96UB86QI
M(&ME(&QA>6%R('!E;F=I<FEM86X@<V5T96QA:"!M96QA:W5K86X@<V5M=6$@
M<&5R=6)A:&%N+B!097)U8F%H86X@(@HB<&%D82!L87EA<B!I;FD@=&ED86L@
M86MA;B!D:6QA:W5K86XN*2(*"B,Z('-P96QL:6YG+G!H<#HR-S<*(RP@9G5Z
M>GD*;7-G:60@(B(*(BA396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL
M(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE("(*(F-U
M<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B
M"B(H2V5M8F%L:2!K92!L87EA<B!P96YG:7)I;6%N('-E=&5L86@@;65L86MU
M:V%N('-E;75A('!E<G5B86AA;BX@4&5R=6)A:&%N("(*(G!A9&$@;&%Y87(@
M:6YI('1I9&%K(&%K86X@9&EL86MU:V%N+BDB"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J(%1A;6)A:"!D96YG86X@:VQI:R!/
M2R`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,#8*
M;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@
M(BH@4VEL86MA;B!P:6QI:"!A;&%M870@*B(*"B,Z(&UA:6QB;W@N<&AP.C$W
M-`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(E!E<V%N(&EN:2!S=61A:"!D:6QA<&]R:V%N('-E8F%G86D@
M<W!A;2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3@P"B,L(&9U>GIY"FUS9VED("(Q
M(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U
M<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB4&5S86X@:6YI
M('-U9&%H(&1I;&%P;W)K86X@<V5B86=A:2!S<&%M(&ME<&%D82!A9&UI;FES
M=')A=&]R('-I<W1E;2!A;F1A+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C`*(RP@
M9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2XB"FUS9W-T<B`B4&5S86X@:6YI('-U9&%H(&1I;&%P;W)K86X@
M<V5B86=A:2!S<&%M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S(*(RP@9G5Z>GD*
M;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E!E<V%N
M(&EN:2!S=61A:"!D:6QA<&]R:V%N('-E8F%G86D@<W!A;2!K97!A9&$@861M
M:6YI<W1R871O<B!S:7-T96T@86YD82XB"@HC.B!L:6(O4W!A;2YP:'`Z,34R
M"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@
M87,@<W!A;2XB"FUS9W-T<B`B4&5S86X@:6YI('-U9&%H(&1I;&%P;W)K86X@
M<V5B86=A:2!S<&%M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*
M(RP@9G5Z>GD*;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(DMA<F%K
M=&5R(%-P97-I86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(R"B,L
M(&9U>GIY"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B2V%R86MT
M97(@4W!E<VEA;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C`*(RP@
M9G5Z>GD*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(DMA<F%K=&5R
M(%-P97-I86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(Q"B,L(&9U
M>GIY"FUS9VED("(U,#`@8VAA<F%C=&5R<R(*;7-G<W1R(")+87)A:W1E<B!3
M<&5S:6%L(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38R"B,L
M('!H<"UF;W)M870*;7-G:60@(D$@;&%R9V4@:6UA9V4@;F%M960@)7,@:7,@
M871T86-H960@=&\@=&AI<R!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M
M97-S86=E('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N
M(&YO=&EF:6-A=&EO;B!F<F]M('1H92`B"B)R96-I<&EE;G0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!
M3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y
M,`IM<V=I9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4X-PIM<V=I9"`B06-C97!T(')E<75E<W0@
M86YD(&%D9"!I="!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S4S"FUS9VED(")!8V-E<'1E9"(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4W"FUS9VED
M(")!8V-E<'1E9#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHW"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT)W,@;F%M
M93HB"FUS9W-T<B`B3F%M82!);F1E;G1I=&%S(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4R,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,P
M"B,L(&9U>GIY"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(D%K<VDB"@HC.B!L
M:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)344O2&5A9&5R<RYP:'`Z
M,C`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,@=&\@;7D@
M061D<F5S<R!";V]K(@IM<V=S='(@(E1A;6)A:&MA;B!K92!"=6MU($%L86UA
M="`H)7,I(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S`S"B,L(&9U>GIY"FUS9VED(")!9&0@<V]U<F-E(@IM<V=S='(@(G1A;6)A
M:&MA;B!S=6UB97(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<W
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D9"!T:&ES
M('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!A
M<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R(")!='1A8VAM96YT(&1I=&%M8F%H
M:V%N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3@*;7-G:60@(B(*
M(D%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@
M;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO
M;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L(&9U
M>GIY"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS
M9W-T<B`B26YF;W)M87-I(%!R:6)A9&DB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I
M;',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E
M=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S
M<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET
M:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(&-A;B!B92!V:65W960@)7,N
M(@IM<V=S='(@(B(*"B,Z(&-O;G1A8W1S+G!H<#HX-2!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$X,`HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS,SD@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C4R"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B0G5K=2!!;&%M870B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED
M(")!9&1R97-S($)O;VMS(@IM<V=S='(@(D)U:W4@06QA;6%T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I9"`B(@HB061D<F5S<V5S('1O
M($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@
M861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#$*;7-G:60@(B(*(D%D9')E<W-E
M<R!T;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES(&ED96YT:71Y.B`\96T^*&]P
M=&EO;F%L+"!E;G1E<B!E86-H("(*(F%D9')E<W,@;VX@82!N97<@;&EN92D\
M+V5M/B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C,*;7-G:60@(D%L;"(*
M;7-G<W1R(")396UU82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3,*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W
M:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/
M6"`B"B)F:6QE.B(*;7-G<W1R(")396UU82!P97-A;B!D86QA;2!F;VQD97(@
M8F5R:6MU="!A:V%N(&1I9&]W;FQO860@<&%D82!S871U(&9I;&4@34)/6#H@
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R
M(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R
M;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB4V5M=6$@<&5S86X@
M9&%L86T@9F]L9&5R(%PB)7-<(B!Y86YG(&QE8FEH(&1A<FD@)7,@:&%R:2!A
M:V%N(&1I:&%P=7,@<V5C87)A("(*(G!E<FUA;F5N+B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK960@
M871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D
M96QE=&5D+B(*;7-G<W1R(")396UU82!F;VQD97(@<V5N="UM86EL(&QA;6$@
M>6%N9R!L96)I:"!D87)I("5S(&)U;&%N(&%K86X@9&EH87!U<RXB"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T
M960N(@IM<V=S='(@(E-E;75A(&9O;&1E<B!S96YT+6UA:6P@;&%M82!Y86YG
M(&QE8FEH(&1A<FD@)7,@8G5L86X@86MA;B!D:6AA<'5S+B(*"B,Z(&%C;"YP
M:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%L;"!R:6=H=',@
M;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E
M<B!<(B5S7"(N(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@<W5D86@@9&EU8F%H
M(&YA;6$@:V4@7"(E<UPB(&1E;F=A;B!S=6MS97,N(@H*(SH@;&EB+V%P:2YP
M:'`Z-S8*;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A=&EO;C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0X"FUS9VED(")!
M;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O
M>#\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E
M+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E
M8W1I;VXZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-S(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X-`IM<V=I9"`B06QW87ES(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3<*(RP@9G5Z
M>GD*;7-G:60@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(D%T
M=&%C:&UE;G0@9&ET86UB86AK86XN(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4P
M-0IM<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG
M('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@(@HB
M<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#@*(RP@
M9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C
M<F5A=&EN9R!T:&4@;F5W(&YO=&4N(@IM<V=S='(@(DME<V%L86AA;B!A;F5H
M('1E<FIA9&D@<&%D82!P96YA;6)A:&%N(&5N=')I(&)A<G4N(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C,X-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RXB"FUS
M9W-T<B`B2V5S86QA:&%N(&%N96@@=&5R:F%D:2!P861A('!E;F%M8F%H86X@
M96YT<FD@8F%R=2XB"@HC.B!M97-S86=E+G!H<#HU,#`@;6%I;&)O>"YP:'`Z
M-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z.0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R(")*87=A8B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D
M(&UE<W-A9V5S(@IM<V=S='(@(DIA=V%B('!E<V%N(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY"FUS9VED(")!<'!L>2!&
M:6QT97)S(@IM<V=S='(@(D%K=&EF:V%N($9I;'1E<B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VAE861E<BYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B07!P;'D@1FEL=&5R<R!T;R`E<R(*;7-G<W1R(")!:W1I9FMA;B!&
M:6QT97(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S8*;7-G
M:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S
M='(@(DQA:W5K86X@871U<F%N(&9I;'1E<B!P861A('-A870@;&]G:6X_(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0R"B,L(&9U>GIY"FUS
M9VED(")!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES
M<&QA>65D/R(*;7-G<W1R("),86MU:V%N(&%T=7)A;B!F:6QT97(@:V5T:6MA
M(&UA:6QB;W@@9&EB=6MA('5L86YG/R(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L(&9U>GIY
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@
M<'5B;&EC(&ME>3\B"FUS9W-T<B`B06YD82!Y86MI;B!I;F=I;B!M96QA:W5K
M86X@:6YI/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4
M(')E8V]M;65N9&5D(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ
M<SHV"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\B
M"FUS9W-T<B`B06YD82!Y86MI;B!I;F=I;B!M96QA:W5K86X@:6YI/R(*"B,Z
M(&UE<W-A9V4N<&AP.C0P-R!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHV.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!
M3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`B06YD82!Y
M86MI;B!I;F=I;B!M96YG:&%P=7,@<&5S86XM<&5S86X@:6YI('-E8V%R82!0
M15)-04Y%3C\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U
M>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y4
M3%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B06YD82!Y86MI
M;B!I;F=I;B!M96YG:&%P=7,@<&5S86XM<&5S86X@:6YI('-E8V%R82!015)-
M04Y%3C\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L
M9&5R/R(*;7-G<W1R(")!;F1A('EA:VEN(&EN9VEN(&UE;F=O<V]N9VMA;B!F
M;VQD97(@:6YI/R(*"B,Z(&QI8B])35`N<&AP.CDW,PHC+"!F=7IZ>0IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@<W!A;2!F
M;VQD97(_(@IM<V=S='(@(D%N9&$@>6%K:6X@:6YG:6X@;65N9V]S;VYG:V%N
M(&9O;&1E<B!T<F%S:"!I;FD_(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F
M;VQD97(_(@IM<V=S='(@(D%N9&$@>6%K:6X@:6YG:6X@;65N9V]S;VYG:V%N
M(&9O;&1E<B!T<F%S:"!I;FD_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS
M9W-T<B`B06YD82!Y86MI;B!I;F=I;B!M96YG:&%P=7,@<&5S86XM<&5S86X@
M:6YI('-E8V%R82!015)-04Y%3C\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHX,"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHW.0HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_(@IM<V=S='(@
M(D%N9&$@>6%K:6X@:6YG:6X@;65N9V]S;VYG:V%N(&9O;&1E<B!I;FD_(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-S4@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*(RP@9G5Z>GD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E
M(&%S('-P86T_(@IM<V=S='(@(D%N9&$@>6%K:6X@:6YG:6X@;65N9V]S;VYG
M:V%N(&9O;&1E<B!I;FD_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ
M-@IM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(E=A:W1U($ME9&%T86YG
M86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E
M;F1I;F<B"FUS9W-T<B`B57)U=&%N(&UE;F%I:R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,PIM<V=I
M9"`B07-K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4Q.0IM<V=I9"`B071T86-H(@IM<V=S='(@(DQA;7!I<FMA;B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W-0HC+"!F=7IZ
M>0IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S='(@(DQA;7!I<F%N+6QA;7!I
M<F%N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#4V"FUS
M9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@
M>6]U<B!M97-S86=E/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")!='1A8VAE9"!&:6QE.B(*
M;7-G<W1R("),86UP:7)K86XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#4Q(&QI
M8B]#;VUP;W-E+G!H<#HU,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB071T
M86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE
M(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S8*;7-G:60@(D%T=&%C:&5D(&ES
M(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$V('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-`HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#8@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:G,Z.3<*;7-G:60@(D%T=&%C:&UE;G0B"FUS9W-T<B`B
M3&%M<&ER86XB"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H
M<#HT-C8*;7-G:60@(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T
M=&%C:&UE;G0@='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#<S"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#<S"FUS9VED(")!='1A8VAM
M96YT<R(*;7-G<W1R("),86UP:7)A;BUL86UP:7)A;B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV.#(*(RP@9G5Z>GD*;7-G:60@(D%T=&5N9&5E
M<R(*;7-G<W1R("),86UP:7)A;BUL86UP:7)A;B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!='1E
M;G1I;VXB"FUS9W-T<B`B06MS:2(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*
M;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-#`*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-
M3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S
M<V)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B079A:6QA8FQE($%D9')E
M<W,@8F]O:W,Z(@IM<V=S='(@(D)U:W4@86QA;6%T('EA;F<@=&5R<V5D:6$Z
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q.0IM<V=I9"`B07=A
M:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`B2V5M8F%L:2!K92`E<R(*
M"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E
M<R(*;7-G<W1R(")+96UB86QI(&ME("5S(@H*(SH@=&AR96%D+G!H<#HQ,S0*
M;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN9&5X(@IM
M<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,R"FUS9VED(")"86-K('1O(%1H
M<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP
M:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M960@
M<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@
M;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G<W1R(")"8V,B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W
M(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(D)L86-K;&ES="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,CD*;7-G:60@(D)L;V-K(&EM86=E
M<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L
M;'D@<F5Q=65S=&5D/R(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HT
M,@IM<V=I9"`B0F]D>2(*;7-G<W1R(")";V1Y(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")+961U86YY
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#<*;7-G:60@(D)O=&@@
M2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(*;7-G:60@
M(D-?:&%R<V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE
M;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N;W0@8V]N;F5C
M="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C;VYN
M96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O
M9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@(@HB
M;6%I;&)O>"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C@T('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4U"B,Z('1E;7!L871E<R]F
M;VQD97)S+VEM<&]R="YI;F,Z,C$@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E
M:6UA9V4N:6YC.C$Y"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN
M8SHR,2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#8*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,"!T96UP;&%T97,O<&=P
M+W!A<W-P:')A<V4N:6YC.C,R"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-C8*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")"871A;&MA;B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<Q('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0S-0HC.B!T96UP;&%T97,O8V]M<&]S92]R
M961I<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@365S<V%G92(*;7-G<W1R
M(")"871A;&MA;B!097-A;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I
M9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D
M:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS9W-T<B`B365M8F%T86QK86X@<&5S
M86X@:6YI(&%K86X@;65N9V%B86EK86X@:7-I;GEA('-E8V%R82!P97)M86YE
M;BXB"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E
M+FEN8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM<V=I9"`B0V,B"FUS9W-T<B`B
M0V,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDS"FUS9VED("(B
M"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U
M<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R`B"B)S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#$*(RP@9G5Z
M>GD*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R(")0<FEB861I(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED(")#:&%N
M9V4B"FUS9W-T<B`B56)A:"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R(")58F%H(%-E
M;75A(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDR"B,L(&9U>GIY"FUS
M9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S='(@(D)U870@1F]L9&5R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I
M<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S
M964@;VX@96%C:"!P86=E(&%N9"`B"B)H;W<@;65S<V%G97,@87)E('-O<G1E
M9"XB"FUS9W-T<B`B(@HB56)A:"!P:6QI:&%N('1A;7!I;&%N('-E<&5R=&D@
M8F%N>6%K;GEA('!E<V%N('EA;F<@86YD82!L:6AA="!P861A(&UA<VEN9RTB
M"B)M87-I;F<@:&%L86UA;B!D86X@8F%G86EM86YA('!E<V%N+7!E<V%N(&1I
M=7)U=&MA;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*(RP@9G5Z
M>GD*;7-G:60@(D-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I
M;F=S+B(*;7-G<W1R(")58F%H('!E;F=A='5R86X@;6%I;"!S97)V97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@(B(*(D-H86YG92!T
M:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD("(*(G)E<&QY('1O('EO=7(@96UA:6PN
M(@IM<V=S='(@(B(*(E5B86@@;F%M82P@86QA;6%T+"!D86X@=&%N9&%T86YG
M86X@>6%N9R!D:6QI:&%T(&]R86YG(&ME=&EK82!M96UB86-A(&1A;B`B"B)M
M96UB86QA<R!E;6%I;"!A;F1A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,C0*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,34*;7-G:60@
M(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B0V5K($9O
M;&1E<B!U;G1U:R!-86EL($)A<G4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,3`@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(Q"FUS9VED(")#:&5C:R!A
M;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O;3HB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V,PHC+"!F
M=7IZ>0IM<V=I9"`B0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M
M97-S86=E/R(*;7-G<W1R(")!9&$@:V5S86QA:&%N('-A870@;65N9VER:6T@
M<&5S86X@86YD83H@)7,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHT"FUS9VED(")#:&]O<V4@06-T:6]N.B(*;7-G<W1R(")0:6QI:"!!
M:W-I.B(*"B,Z(&-O;F9I9R]S97)V97)S+G!H<"YD:7-T.C$X,@IM<V=I9"`B
M0VAO;W-E(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@(E!I;&EH(&UA:6P@<V5R
M=F5R.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C$W"FUS9VED(")#:&]O<V4@82!M871C
M:"!O<B!E9&ET('1H92!A9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,2!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S,Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@
M86-T:6]N.B(*;7-G<W1R(")0:6QI:"!!:W-I.B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,T.0HC+"!F=7IZ>0IM<V=I9"`B0VAO
M;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E
M<W-E<RXB"FUS9W-T<B`B4&EL:6@@8G5K=2!A;&%M870@>6%N9R!D:6=U;F%K
M86X@:V5T:6MA(&UE;F%M8F%H(&%L86UA="XB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHR.3,*(RP@9G5Z>GD*;7-G:60@(D-H;V]S
M92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E
M>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R(")0:6QI:"!U<G5T86X@9&%R
M:2!B=6MU(&%L86UA="!Y86YG(&1I8V%R:2!K971I:V$@;65N9V5M8F%N9VMA
M;B!A;&%M870N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE
M(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I
M97<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D
M('1H92!I;6%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O("5S(&UA
M;F%G96UE;G0@<&%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M8FYA
M:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<N(@IM<V=S='(@(DMI<FEM('!E<V%N('!A9&$@=VEN9&]W('1E
M<G!I<V%H/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L
M=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDU"FUS9VED
M(")#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM86=E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*(RP@9G5Z
M>GD*;7-G:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D
M9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB
M<V5A<F-H+B(*;7-G<W1R("(B"B)+;&EK('!A9&$@<V%L86@@<V%T=2!B=6MU
M(&%L86UA="!P:6QI:&%N(&%N9&$@:V5M=61I86X@<&EL:6@@<V5M=6$@9FEE
M;&0@(@HB=6YT=6L@;65N8V%R:2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-S$*;7-G:60@(D-L:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@
M:6X@>6]U<B!!9&1R97-S(&)O;VLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDU,`IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C
M;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#;&EC:VEN
M9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@
M<F5A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,C@*(RP@9G5Z>GD*;7-G:60@(D-L;W-E(@IM<V=S='(@(DMI
M<FEM(@H*(SH@8V]M<&]S92YP:'`Z.#(X(&-O;7!O<V4N<&AP.C$Q-#@*;7-G
M:60@(D-L;W-E('1H:7,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C0R.0IM<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G<W1R(")&;VQD97(@
M5&5R='5T=7`B"@HC.B!F;VQD97)S+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@
M(D-O;&QA<'-E(@IM<V=S='(@(DAA<'5S(%-E;75A(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*
M;7-G<W1R(")(87!U<R!396UU82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C,Y"FUS9VED(")#;VQL87!S92!!;&P@1F]L9&5R<R(*;7-G
M<W1R(")(87!U<R!396UU82!&;VQD97(B"@HC.B!F;VQD97)S+G!H<#HT-#D*
M;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R(")(87!U<R!&;VQD97(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@
M(D-O;&]R($EN9&EC871O<CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,#,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]M<&QE=&5D(@IM<V=S='(@(DMI<FEM(@H*(SH@8V]M<&]S92YP:'`Z.#(W
M(&-O;7!O<V4N<&AP.C$Q-#<*(RP@9G5Z>GD*;7-G:60@(D-O;7!O<V4@86YO
M=&AE<B!M97-S86=E(@IM<V=S='(@(DMI<FEM('-E8G5A:"!P97-A;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S0*;7-G:60@(D-O;7!O<V4@;65S
M<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(DMI<FEM('!E
M<V%N('!A9&$@=VEN9&]W('1E<G!I<V%H/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET:"!A
M;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H
M92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D
M:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-PHC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O
M<'1I;VYS+B(*;7-G<W1R(")58F%H('!E;F=A='5R86X@;6%I;"!S97)V97(B
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM<V=I9"`B0V]N;F5C=&EO
M;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S
M97)V97(@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P
M<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3+TU)344@
M<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T
M;R!M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M
M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T
M;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB
M2V]N=')O;"!J:6MA(&UA:6P@8F%R=2!A:V%N(&1I8V5K+"!D86X@87!A:V%H
M(&UE;6)E<FD@=&%H=2!A;F1A(&%T874@=&ED86L@(@HB:FEK82!M86EL(&1A
M=&%N9RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CDV"FUS9VED(")#
M;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN=&\@9W)A<&AI8V%L(&]N97,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM
M<V=I9"`B0V]P>2(*;7-G<W1R(")#;W!Y(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C4Q"B,L(&9U>GIY"FUS9VED(")#;W!Y('1O(&9O;&1E<B(*
M;7-G<W1R(")+;W-O;F=K86X@9F]L9&5R(%1R87-H(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S
M='(@(D)E;F%R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`B5&5K<R!"96YA
M<B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S="X@4F5A
M<V]N($=I=F5N.B`E<R(*;7-G<W1R(")4:61A:R!B:7-A(&UE;F=H87!U<R!P
M97-A;B!D87)I("5S.B`E<R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K
M96YD.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C0P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&UE
M<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B
M5&ED86L@8FES82!M96YG:&%P=7,@<&5S86X@9&%R:2`E<SH@)7,B"@HC.B!L
M:6(O4V5S<VEO;BYP:'`Z,S$X"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R(")/<&5R
M87-I(%!E<F%W871A;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HU
M-`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE
M(&9R;VT@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO="!E
M>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@87)C:&EV
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(W,PIM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M
M($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C,Q-"!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C,Y"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C`*;7-G
M:60@(D-R96%T92(*;7-G<W1R(")"=6%T(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E<B(*;7-G<W1R
M(")"=6%T($9O;&1E<B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*
M(RP@9G5Z>GD*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(D)U870B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,30*(RP@9G5Z>GD*;7-G
M:60@(D-R96%T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")"=6%T($9O;&1E
M<B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC
M.C(V"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S
M+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")#<F5A
M=&4@82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B0G5A="!F;VQD97(@=')A
M<V@@8F%R=2(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC
M.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(T"FUS9VED
M(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R(")"=6%T(&9O
M;&1E<B!D<F%F=',@8F%R=2(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I
M;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T
M+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(B
M"FUS9W-T<B`B0G5A="!F;VQD97(@<V5N="!M86EL(&)A<G4B"@HC.B!T96UP
M;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F
M<R]T<F%S:'-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!T<F%S
M:"!F;VQD97(B"FUS9W-T<B`B0G5A="!F;VQD97(@=')A<V@@8F%R=2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C@*;7-G:60@(B(*(D-R96%T92!F
M:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL
M+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@(@HB86YD(&1E;&5T92!S<&%M+B(*
M;7-G<W1R("(B"B)"=6%T(&%T=7)A;B!F:6QT97(@=6YT=6L@;65N9V%T=7(@
M<&5S86X@;6%S=6L@86YD82P@=7)U=&MA;B!K92!F;VQD97(L(&1A;B`B"B)H
M87!U<R!S<&%M+B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&YE=R!S=&%T:6]N97)Y(@IM
M<V=S='(@(D)U870@9F]L9&5R('-E;G0@;6%I;"!B87)U(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0T.0IM<V=I9"`B0W)E871E('-T871I;VYE<GD@
M86YD(&9O<FT@<F5S<&]N<V5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A
M8V-E<W,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-0IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN
M9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B0W5S=&]M
M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R(")!='5R(&)A9V%I;6%N
M82!A;F1A(&MI<FEM(&UA:6P@9&%N(&1I;6%N82!D<F%F=',@9&ES:6UP86XN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B071U<B!T=6=A<R!Y86YG(&1I:F%L86YK86X@<V%A="!L
M;V=O;B!P861A("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(D1A=%]E(@IM<V=S='(@
M(E1A;F=G86PB"@HC.B!M97-S86=E+G!H<#HR-C(@=&AR96%D+G!H<#HQ-#@*
M;7-G:60@(D1A=&4B"FUS9W-T<B`B5&%N9V=A;"(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW-3<*(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D(@IM
M<V=S='(@(D1I:&%P=7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,C8S"FUS9VED(")$96-L:6YE9#H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`B2&%P=7,B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C
M:'-E;&5C="YI;F,Z,3@*;7-G:60@(D1E9F%U;'0@4V5A<F-H($9I96QD(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C,*;7-G:60@
M(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`B2W)I=&5R:6$@
M=7)U=&%N('EA;F<@9&5F875L="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,S,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S
M='(@(D%R86@@=7)U=&%N('EA;F<@9&5F875L="(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW-C4*(RP@9G5Z>GD*;7-G:60@(D1E;&5G871E9"(*
M;7-G<W1R(")$:6AA<'5S(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(T-"!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHX('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C(X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM
M<V=I9"`B1&5L971E(@IM<V=S='(@(DAA<'5S(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME>7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G<W1R(")(87!U<R!&;VQD
M97(B"@HC.B!F;VQD97)S+G!H<#HR.#4*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(DAA<'5S($9O;&1E<B(*"B,Z
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E(%-T871I;VYE<GDB"FUS9W-T<B`B2&%P=7,@1F]L9&5R
M(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M5FER='5A;"!&;VQD97(B"FUS9W-T<B`B2&%P=7,@1F]L9&5R(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@
M9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E
M;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!O;&0@
M;&EN:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS
M9W-T<B`B2&%P=7,@9F]L9&5R('-E;G0M;6%I;"!L86UA('!A9&$@87=A;"!B
M=6QA;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4P"FUS9VED(")$
M96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M
M;VYT:#\B"FUS9W-T<B`B2&%P=7,@9F]L9&5R('-E;G0M;6%I;"!L86UA('!A
M9&$@87=A;"!B=6QA;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<W!A;2!M97-S86=E<R(*;7-G<W1R
M(")(87!U<R!P97-A;B(*"B,Z(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H
M<#HW-#`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X
M+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R(")$:6AA<'5S
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B1&5L
M971E9"!M97-S86=E<R(*;7-G<W1R(")097-A;B!T97)H87!U<R(*"B,Z(&-O
M;7!O<V4N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E9"!T:&4@871T86-H;65N="!<(B5S7"(N(@IM<V=S='(@(DAA<'5S(&QA
M;7!I<F%N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B
M1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<R(*;7-G<W1R(")-96YG:&%P
M=7,@9&%N($UE;6EN9&%H(%!E<V%N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#`*;7-G:60@(D1E;GD@<F5Q
M=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S(*;7-G:60@(D1E<V-E;F1I;F<B
M"FUS9W-T<B`B57)U="!M96YU<G5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:6YC.C(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-CD*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(E!I;&EH
M86X@4&5M86MA:2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B1&5T86EL<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<W"FUS9VED(")$:6T@<VEG;F%T
M=7)E<S\B"FUS9W-T<B`B1&EM('1A;F1A=&%N9V%N/R(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$:7-P;&%Y(@IM
M<V=S='(@(E1A;7!I;&MA;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-SD*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R
M('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("(B"B)486UP:6QK86X@:V]N
M9FER;6%S:2!S971E;&%H(&UE;F=I<FEM('!E<V%N/R`H:&%N>6$@:FEK82!T
M:61A:R!M96YG9W5N86MA;B`B"B)W:6YD;W<@<&5N9VER:6UA;B!P;W`M=7`I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-@IM<V=I9"`B1&ES<&QA
M>2!I;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Y,@IM<V=I9"`B1&ES<&QA>2!P;W`M=7`@;F]T:69I
M8V%T:6]N(&]F(&YE=R!M86EL/R(*;7-G<W1R(")486UP:6QK86X@<&5M8F5R
M:71A:'5A;B!P;W`M=7`@9&%R:2!M86EL(&)A<G4_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3
M<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%
M;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS9W-T<B`B4&EL:6AA;B!486UP
M:6QA;B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I
M9"`B1&\@3D]4(&UA=&-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C$V"FUS9VED(")$;R!.;W0@0VAE8VL@1F]L9&5R
M*',I(&9O<B!.97<@36%I;"(*;7-G<W1R(")*86YG86X@5&%N9&%I($9O;&1E
M<B!U;G1U:R!-86EL($)A<G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.34R"FUS9VED(")$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M
M.B!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`W-0IM<V=I
M9"`B1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`B
M07!A:V%H(&%N9&$@:6YG:6X@;65M8G5K82!F;VQD97(@:71U/R(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,R"FUS9VED(")$;VXG="!H879E
M(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C8*;7-G:60@(D1O;F4B"FUS9W-T
M<B`B4W5D86@B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"B,L('!H
M<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R
M"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL
M92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,C`*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R(")$;W=N
M;&]A9"!&;VQD97(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHR,0HC+"!F=7IZ>0IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(%LN>FEP
M(&9O<FUA=%TB"FUS9W-T<B`B1&]W;FQO860@1F]L9&5R(@H*(SH@;&EB+TU)
M344O0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&
M;W)M870B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N
M<&AP.C<Q.2!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S='(@(D1R869T(@H*
M(SH@9F]L9&5R<RYP:'`Z,SDR"B,L(&9U>GIY"FUS9VED(")$<F%F="!F;VQD
M97(B"FUS9W-T<B`B1F]L9&5R(&1R869T<R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS9VED(")$<F%F=',@9F]L9&5R.B(*
M;7-G<W1R(")&;VQD97(@9')A9G1S(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$P.`HC+"!F=7IZ>0IM<V=I9"`B12UM86EL($%D9')E<W,B"FUS9W-T
M<B`B06QA;6%T($5M86EL(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,P.0IM<V=I
M9"`B14Y$(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C<T"FUS9VED(")%4E)/4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B
M92!D96QI=F5R960N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,3D*;7-G:60@(D5D:70B
M"FUS9W-T<B`B161I="(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B161I="!";&%C:VQI<W0B"FUS9W-T<B`B
M0FQA8VML:7-T(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")%9&ET($9I;'1E<G,B"FUS9W-T<B`B1FEL=&5R
M($UA:6PB"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C$V"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B!$969I;FET
M:6]N(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM
M<V=S='(@(E=H:71E;&ES="(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*
M;7-G<W1R(")%9&ET(&%T=7)A;B!F:6QT97(B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@<G5L
M97,B"FUS9W-T<B`B161I="!A='5R86X@9FEL=&5R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@V,0IM<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S
M(&9O<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"B,L(&9U>GIY
M"FUS9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(D5D:70@871U
M<F%N(&9I;'1E<B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%L86UA="!%
M;6%I;"(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM
M<V=S='(@(DMO<V]N9VMA;B!S96UU82!P97-A;B!D87)I("5S+B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&
M;VQD97(H<RDB"FUS9W-T<B`B2V]S;VYG:V%N($9O;&1E<B(*"B,Z(&9O;&1E
M<G,N<&AP.C(X-@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@4V5L96-T960@1F]L
M9&5R<R(*;7-G<W1R(")+;W-O;F=K86X@1F]L9&5R(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y(%1R87-H(&9O
M;&1E<B(*;7-G<W1R(")+;W-O;F=K86X@9F]L9&5R(%1R87-H(@H*(SH@;&EB
M+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")%;7!T>2!?4W!A;2(*;7-G
M<W1R(")+;W-O;F=K86X@5')A<V@B"@HC.B!L:6(O24U0+G!H<#HY-C8*(RP@
M9G5Z>GD*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R(")+;W-O;F=K86X@
M5')A<V@B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,2!T96UP;&%T97,O
M<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%!'4"!F=6YC=&EO
M;F%L:71Y/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B
M16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS9VED(")%;F%B;&4@;65S<V%G
M92!P<F5V:65W<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#0R"FUS9VED(")%;F-R7WEP=&EO;B!/<'1I;VYS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3<@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8U-PIM<V=I9"`B16YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#0*;7-G:60@(D5N9"!F;W)W87)D
M960@;65S<V%G92(*;7-G<W1R(")!:VAI<B!P97-A;B!Y86YG(&1I=&5R=7-K
M86XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0Q"B,L(&9U>GIY"FUS9VED(")%
M;F0@;65S<V%G92(*;7-G<W1R(")097-A;B!,86UA(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C,S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B16YD(&UE
M<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")497)U<VMA;B!P97-A;B!D87)I("5S
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.CD*(RP@
M9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!3<&%M
M(&9O;&1E<B(*;7-G<W1R(")-87-U:VMA;B!N86UA('5N='5K(&9O;&1E<B!T
M<F%S:"!B87)U(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T
M<R!F;VQD97(B"FUS9W-T<B`B36%S=6MK86X@;F%M82!U;G1U:R!F;VQD97(@
M9')A9G1S(&)A<G4B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE
M8W0N:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")-87-U:VMA;B!N86UA('5N='5K
M(&9O;&1E<B!S96YT(&UA:6P@8F%R=2(*"B,Z('1E;7!L871E<R]P<F5F<R]T
M<F%S:'-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO
M=7(@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R(")-87-U:VMA;B!N86UA('5N
M='5K(&9O;&1E<B!T<F%S:"!B87)U(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*
M(RP@9G5Z>GD*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(D%R86AK
M86X@4&5S86XB"@HC.B!M97-S86=E+G!H<#HQ.30@8V]M<&]S92YP:'`Z,3$S
M-"!T:')E860N<&AP.C<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M;G1R>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D
M<F5S<R!B;V]K(@IM<V=S='(@(D5N=')I(%PB)7-<(B!T96QA:"!D:71A;6)A
M:&MA;B!K92!B=6MU(&%L86UA="!D96YG86X@<W5K<V5S(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,C$*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S8@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,S@V"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C<R(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I9"`B
M17)R;W(B"FUS9W-T<B`B4V%L86@B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C;VYN96-T:6YG('1O
M($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R97!L
M>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE
M=&5D+B(*;7-G<W1R(")&;VQD97(@7"(E<UPB('-U9&%H(&1I:&%P=7,@9&5N
M9V%N('-U:W-E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@R"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(E-E=&EA<"`Q-2!M96YI
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-SD*;7-G:60@(D5V97)Y
M(#,P('-E8V]N9',B"FUS9W-T<B`B4V5T:6%P(#,P(&1E=&EK(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I9"`B179E<GD@-2!M:6YU=&5S
M(@IM<V=S='(@(E-E=&EA<"`U(&UE;FET(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<X,PIM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(E-E
M=&EA<"!S971E;F=A:"!J86TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S@P"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B4V5T:6%P(&UE;FET
M(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")%>'!A;F0B
M"FUS9W-T<B`B2V5M8F%N9VMA;B!396UU82(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A;F0@06QL(@IM<V=S='(@
M(DME;6)A;F=K86X@4V5M=6$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@
M(DME;6)A;F=K86X@4V5M=6$@1F]L9&5R(@H*(SH@9F]L9&5R<RYP:'`Z-#4W
M"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(DME;6)A;F=K86X@1F]L
M9&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD
M($YA;65S(@IM<V=S='(@(DME;6)A;F=K86X@3F%M82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#8S"FUS9VED(")%>'!A;F0@;F%M97,@:6X@=&AE
M(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U
M;F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.#`*
M;7-G:60@(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U
M;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T<B`B2V5M8F%N9VMA;B!S
M96QU<G5H(&AI<F%R:VD@9F]L9&5R('-E8V%R82!D969A=6QT('!A9&$@=&%M
M<&EL86X@9F]L9&5R/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C$T-"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ.30*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C0U('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHQ,#$*(RP@9G5Z>GD*;7-G:60@(D5X<&%N
M9&EN9R(*;7-G<W1R(")+96UB86YG:V%N(%-E;75A(@H*(SH@;&EB+TE-4"YP
M:'`Z.3@T(&QI8B])35`N<&AP.CDX-@HC+"!F=7IZ>0IM<V=I9"`B1E]E=&-H
M($UA:6PB"FUS9W-T<B`B36%I;"!"87)U(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]F971C:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#0*(RP@9G5Z>GD*;7-G:60@(D9E=&-H($UA:6PB"FUS9W-T<B`B36%I;"!"
M87)U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V.0HC+"!F=7IZ>0IM
M<V=I9"`B1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T
M<B`B2VER:6T@<&5S86X@<&%D82!W:6YD;W<@=&5R<&ES86@_(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0V"B,L(&9U>GIY"FUS9VED
M(")&971C:"!M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(DQA
M:W5K86X@871U<F%N(&9I;'1E<B!P861A('-A870@;&]G:6X_(@H*(SH@;&EB
M+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&971C:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,B"FUS9W-T<B`B2V]S;VYG
M:V%N('-E;75A('!E<V%N(&1A<FD@)7,N(@H*(SH@;&EB+T9E=&-H;6%I;"YP
M:'`Z,C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D(#$@
M;65S<V%G92!F<F]M("5S(@IM<V=S='(@(E1E<G5S:V%N('!E<V%N(&1A<FD@
M)7,B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP
M:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP.C(X.0IM<V=I9"`B1F5T8VAM86EL
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"B,L(&9U
M>GIY"FUS9VED(")&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS9W-T
M<B`B06YD82!P=6YY82`E<R!P97-A;B!B87)U+B(*"B,Z(&QI8B])35`N<&AP
M.CDY,`HC+"!F=7IZ>0IM<V=I9"`B1FE?;'1E<G,B"FUS9W-T<B`B1FEL=&5R
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`R('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C@R"B,L(&9U>GIY"FUS9VED
M(")&:6QE(@IM<V=S='(@(D9I;'1E<B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B1FEL=&5R($]P=&EO;G,B
M"FUS9W-T<B`B4&EL:6AA;B!,86EN(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D9I;'1E<B!3971T:6YG<R(*
M;7-G<W1R(")!='5R86X@1FEL=&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8P,`IM<V=I9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O
M9F%N:71Y/R(*;7-G<W1R(")&:6QT97(@:7-I('!E<V%N('5N='5K('!R;V9A
M;FET>3\B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$Q
M"FUS9VED(")&:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y
M<W1E;2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-PIM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT97(B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C,*;7-G:60@(D9I;'1E<G,@3D]4
M($%C=&EV92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3@V"FUS9VED(")&:6YD(@IM<V=S='(@(D-A<FDB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3`U"B,L(&9U>GIY"FUS9VED(")&:7)S="!-86EL
M8F]X(%!A9V4B"FUS9W-T<B`B2&%L86UA;B!097)T86UA(@H*(SH@;6%I;&)O
M>"YP:'`Z,S0U"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(DAA;&%M86X@
M4&5R=&%M82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0HC+"!F
M=7IZ>0IM<V=I9"`B1F]?<G=A<F0B"FUS9W-T<B`B5&5R=7-K86XB"@HC.B!F
M;VQD97)S+G!H<#HR-C8@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF
M:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I
M;VXB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S`S('1E;7!L871E<R]F
M;VQD97)S+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP
M86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G
M97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T
M<B`B3F%V:6=A=&]R($9O;&1E<B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HS"B,L(&9U>GIY"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R(")0
M96)R=6%R:2(*"B,Z(&%C;"YP:'`Z,C0*;7-G:60@(D9O;&1E<B!S:&%R:6YG
M(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HV
M,@IM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B1F]R;6%T
M(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S
M<V%G97,@9&%T960@=&]D87DB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z
M-S@P('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R
M=V%R9"(*;7-G<W1R(")497)U<VMA;B(*"B,Z(&-O;7!O<V4N<&AP.C<V-0IM
M<V=I9"`B1F]R=V%R9#HB"FUS9W-T<B`B5&5R=7-K86XZ(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C,V.0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A
M9V4B"FUS9W-T<B`B06MH:7(@<&5S86X@>6%N9R!D:71E<G5S:V%N(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;W)W
M87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(E1E<G5S:V%N('!E<V%N
M(&1A<FD@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@S"B,L
M(&9U>GIY"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B
M26YF;W)M87-I(%-E<G9E<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.30*;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@
M4F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#`Q"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C(W"B,L(&9U>GIY"FUS9VED(")&<F]?;2(*;7-G<W1R(")$87)I(@H*
M(SH@;65S<V%G92YP:'`Z,C8S('1H<F5A9"YP:'`Z,30Y('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.CDY"B,Z(&QI8B]396%R8V@N<&AP.C(R"FUS
M9VED(")&<F]M(@IM<V=S='(@(D1A<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3$X"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`B1&%R:2!!
M;&%M870B"@HC.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP:'`Z-S@Q"FUS
M9VED(")&=V0Z(@IM<V=S='(@(D9W9#HB"@HC.B!C;VUP;W-E+G!H<#HQ,CDT
M"B,L(&9U>GIY"FUS9VED(")&=V0Z("(*;7-G<W1R(")&=V0Z(@H*(SH@8V]M
M<&]S92YP:'`Z,3(Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1G=D
M.B`E=2!&;W)W87)D960@365S<V%G97,B"FUS9W-T<B`B06MH:7(@<&5S86X@
M>6%N9R!D:71E<G5S:V%N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"B,L(&9U>GIY"FUS
M9VED(")'96YE<F%L($]P=&EO;G,B"FUS9W-T<B`B4&EL:6AA;B!096UA:V%I
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,W"FUS9VED
M(")'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Q"FUS9VED
M(")';R(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$S-@HC+"!F=7IZ>0IM
M<V=I9"`B1V\@=&\@365S<V%G92(*;7-G<W1R(")097-A;B!"97)I:W5T;GEA
M(@H*(SH@;&EB+TE-4"YP:'`Z-#DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")';R!T;R!A9&1R97-S(&)O;VL@96YT<GD@;V8@7"(E<UPB(@IM<V=S
M='(@(E1A;6)A:&MA;B!K92!"=6MU($%L86UA="`H)7,I(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-B!L:6(O1FEL=&5R+G!H<#HQ,#4@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,3`R(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$P-`HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC.B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HV.`HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(SH@;&EB+TU)344O5FEE=V5R
M+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ
M-S,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM<V=I9"`B2$5212(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S$@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$Q-PHC.B!L:6(O34E-12]6:65W97(O<F5L
M871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@8V]M<&]S
M92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I;VX@;V8@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU.`IM
M<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@=&AE(&UE<W-A9V4@
M>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C8X"FUS9VED(")(:61D96XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PHC+"!F=7IZ>0IM<V=I9"`B2&ED
M9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(DQI:&%T(%1H<F5A9"(*"B,Z
M(&UA:6QB;W@N<&AP.C,V-PIM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@
M(E-E;6)U;GEI:V%N('EA;F<@1&EH87!U<R(*"B,Z(&9O;&1E<G,N<&AP.C(Y
M.`IM<V=I9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`B4V5M8G5N>6EK
M86X@=&ED86L@;&%N9V=A;F%N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z(&UE<W-A
M9V4N<&AP.C(Y-R!M86EL8F]X+G!H<#HW,C0@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ,@IM<V=I9"`B2&EG:"!0<FEO<FET>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@
M(DAI9VAE<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8X.`IM<V=I9"`B2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H
M;65N=',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,#0*(RP@9G5Z>GD*;7-G:60@(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI
M;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`B0F%G86EM86YA(&)A<FES(&1I<')E
M9FEK(&1A;&%M(&)A;&%S86XZ(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O
M8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!397)V97(@8VQO<V5D('1H92!C
M;VYN96-T:6]N+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-33"(*;7-G<W1R("(B
M"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I9"`B24U!4"!O
M=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38W"FUS9VED("))34%0
M(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HS-C@*;7-G:60@(DE-05`@<V5R=F5R(&-L;W-E9"!T
M:&4@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ-C4@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-#`*;7-G
M:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C0Y"FUS9VED("))34%0+U!/4#,@36%I;"!397)V97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C@V-@IM<V=I9"`B24Y"3U@B"FUS
M9W-T<B`B24Y"3U@B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I
M9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0
M(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3(*(RP@9G5Z
M>GD*;7-G:60@(DEF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H
M92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(2(*;7-G<W1R(")396UU82!P97-A
M;B!D86QA;2!F;VQD97(@:71U(&%K86X@:&EL86YG(2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,@IM<V=I9"`B26=N;W)E(@IM<V=S
M='(@(D%B86EK86XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z.#,*;7-G:60@(DEG;F]R92!!;&PB"FUS9W-T<B`B06)A:6MA;B!396UU
M82(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHX"FUS
M9VED("));6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I
M;7!O<G0N:6YC.C(P"B,L(&9U>GIY"FUS9VED("));7!O<G0B"FUS9W-T<B`B
M4&5N=&EN9R(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX
M-2!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8U"B,L(&9U>GIY"FUS
M9VED("));7!O<G0@2V5Y(@IM<V=S='(@(E!E;G1I;F<B"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3,Y"B,L(&9U>GIY"FUS9VED("));7!O<G0@2V5Y
M<&%I<B(*;7-G<W1R(")096YT:6YG(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,C<*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!-97-S86=E
M<R(*;7-G<W1R(")097-A;B!P96YT:6YG(@H*(SH@<&=P+G!H<#HT,@IM<V=I
M9"`B26UP;W)T(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I
M9FEC871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+
M97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0*
M;7-G:60@(DEM<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#`@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS9VED("));7!O<G0@4'5B;&EC($ME
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC
M.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I9"`B26UP
M;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H
M<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+97DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@
M;6)O>"!&:6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM
M<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T(&UB;W@@
M9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`B(@H*(SH@;65S<V%G
M92YP:'`Z-3`R(&UA:6QB;W@N<&AP.C<S-"!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,S"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM<V=I9"`B26UP;W)T
M86YT(@IM<V=S='(@(E!E;G1I;F<B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B
M4&5S86X@<&5N=&EN9R(*"B,Z(&9O;&1E<G,N<&AP.C$V-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E
M<RXB"FUS9W-T<B`B2V]S;VYG:V%N('-E;75A('!E<V%N(&1A<FD@)7,N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,PIM<V=I9"`B26X@4')O
M8V5S<R(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS.#0@;&EB+T9O;&1E
M<BYP:'`Z.#8@;&EB+T9O;&1E<BYP:'`Z,C$T(&QI8B])35`N<&AP.C,Q,PHC
M.B!L:6(O24U!4"]4<F5E+G!H<#HQ,30@;&EB+TE-05`O5')E92YP:'`Z,C$Y
M"FUS9VED("));F)O>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DR"B,L(&9U>GIY"FUS9VED("));F-L=61E(&$@8G)I968@<W5M
M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM<V=S='(@(DUA<W5K
M:V%N('!E<V%N(&%S;&D@<&%D82!B86QA<V%N/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.#<*;7-G:60@(DEN8VQU9&4@;W)I9VEN86P@;65S<V%G
M92!I;B!A(')E<&QY/R(*;7-G<W1R(")-87-U:VMA;B!P97-A;B!A<VQI('!A
M9&$@8F%L87-A;C\B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HV,2!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,S`*(RP@9G5Z
M>GD*;7-G:60@(DEN9F\B"FUS9W-T<B`B06)A:6MA;B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W
M"B,L('!H<"UF;W)M870*;7-G:60@(DEN9F]R;6%T:6]N(&]N("5S(%!U8FQI
M8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W
M"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0<FEV871E($ME>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B26YF;W)M871I;VX@;VX@
M4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,34@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-3`W"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FIS.CDX"B,L(&9U>GIY"FUS9VED("));FQI;F4B"FUS9W-T<B`B=&ED
M86L@861A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.CD*
M;7-G:60@(DEN<V5R="!#97)T:69I8V%T92!(97)E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,34*;7-G:60@(DEN<V5R
M="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$P"FUS9VED("));G-E
M<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4*;7-G:60@(DEN<V5R
M="!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT,3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E
M;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`B(@H*(SH@;6%I
M;&)O>"YP:'`Z-3@T(&UA:6QB;W@N<&AP.C8R-@HC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!!9&1R97-S(@IM<V=S='(@(D%L86UA="!%;6%I;"(*"B,Z(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(%)E;6]T
M92!-86EL8F]X(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$U.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!C:&%R86-T97(@:6X@
M92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R(")+87)A:W1E<B!S86QA:"!P
M861A(&%L86UA="!E+6UA:6PN(@H*(SH@<VUI;64N<&AP.C@R('!G<"YP:'`Z
M,38*;7-G:60@(DEN=F%L:60@:V5Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z
M,3DV"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB
M"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G
M:60@(DM"(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M,3,*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$S-PIM<V=I9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y
M('1A:V4@82!L;VYG('1I;64@=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W:71H
M(&ME>2`B"B)G96YE<F%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C,U('1E;7!L871E<R]P9W`O<&=P+FEN8SHS-PIM
M<V=I9"`B2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A
M9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS-R!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,SD*;7-G:60@(B(*(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL
M86)L92X@66]U(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D
M('EO=7(@(@HB8V]N=&%C=',N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S$X
M"FUS9VED(")+97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C$V"FUS9VED("),86YG=6%G92(*;7-G<W1R(")"86AA<V$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`V"B,L(&9U>GIY"FUS9VED("),
M87-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")(86QA;6%N(%1E<F%K:&ER(@H*
M(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`B
M2&%L86UA;B!497)A:VAI<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,X.0HC+"!F=7IZ>0IM<V=I9"`B3&E?;FL@071T86-H;65N=',B
M"FUS9W-T<B`B3&%M<&ER86XM;&%M<&ER86XB"@HC.B!A='1A8VAM96YT+G!H
M<#HS-"!L:6(O0V]M<&]S92YP:'`Z,3`V,PIM<V=I9"`B3&EN:V5D(&%T=&%C
M:&UE;G1S(&%R92!F;W)B:61D96XN(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ,#@P"B,L('!H<"UF;W)M870*;7-G:60@(DQI;FMS('=I;&P@
M97AP:7)E(&]N("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#@R"FUS9VED("(B"B),:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO
M861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@
M=VEL;"`B"B)O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R
M(&5X<&QI8VET;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.#4*;7-G:60@(DQI<W1I;F<@:6X@=&AE($AE861E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S`*(RP@
M9G5Z>GD*;7-G:60@(DQO8V%L($UA:6QB;W@Z(@IM<V=S='(@(DUA:6QB;W@B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C<T"B,L(&9U>GIY"FUS
M9VED("),;V-A=&EO;B(*;7-G<W1R(")!:W-I(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,C4*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")-87-U
M:R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&]G(&EN('1O("5S(@IM<V=S='(@(DUA<W5K('!A9&$@)7,B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S-PHC+"!F=7IZ>0IM
M<V=I9"`B3&]G:6XB"FUS9W-T<B`B36%S=6LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(DQO9VEN
M(%1U9V%S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDV
M"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,CDY(&UA
M:6QB;W@N<&AP.C<R-R!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$S
M"FUS9VED("),;W<@4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`HC
M+"!F=7IZ>0IM<V=I9"`B36%C:6YT;W-H($9I;&4B"FUS9W-T<B`B1FEL=&5R
M($UA:6PB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*
M(RP@9G5Z>GD*;7-G:60@(DUA:6PB"FUS9W-T<B`B36%I;&)O>"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@HC+"!F=7IZ>0IM<V=I9"`B36%I;"!0
M<F5V:65W<R(*;7-G<W1R(")&:6QT97(@36%I;"(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R
M=F5R('1Y<&4@=&\@8V]N;F5C="!T;SHB"FUS9W-T<B`B(@H*(SH@9F]L9&5R
M<RYP:'`Z-#`R"FUS9VED(")-86EL8F]X(@IM<V=S='(@(DUA:6QB;W@B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L(&9U>GIY"FUS9VED(")-
M86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E!I
M;&EH86X@5&%M<&EL86XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S
M(%-E96XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A
M<R!5;G-E96XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM<V=S='(@(E1A;F1A:2!S96)A9V%I
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G:60@(DUA<FL@
M9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O
M;&]R<S\B"FUS9W-T<B`B5&%N9&%I('!E<F)E9&%A;B!T:6YG:V%T(&1E;F=A
M;B!W87)N82!Y86YG(&)E<F)E9&$_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E96X_
M("A)34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0V"FUS9VED(")-
M871C:"!!;&P@475E<FEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3,*
M(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM<V=S
M='(@(DQA;7!I<F%N(@H*(SH@;&EB+V%P:2YP:'`Z-SD*;7-G:60@(DUA>&EM
M=6T@3G5M8F5R(&]F($9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DT"FUS9VED(")-87AI;75M(&YU;6)E
M<B!O9B!A='1A8VAM96YT<R!R96%C:&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.#D*;7-G:60@(DUA>&EM=6T@
M=&]T86P@871T86-H;65N="!S:7IE(')E86-H960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C8*;7-G:60@(DUE971I;F<@
M0V%N8V5L;&%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU-S4*(RP@9G5Z>GD*;7-G:60@(DUE971I;F<@26YF;W)M871I
M;VXB"FUS9W-T<B`B26YF;W)M87-I(%-E<G9E<B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I
M9"`B365E=&EN9R!297!L>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3DX"FUS9VED(")-965T:6YG(%5P9&%T92(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`S"FUS9VED(")-
M965T:6YG(%5P9&%T92!297%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]T<F5E7V9O;&1E<G,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@1F]L
M9&5R($QI<W0B"FUS9W-T<B`B0G5K82!&;VQD97(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,S,Q"FUS9VED(")-97-S86=E(@IM<V=S='(@(E!E<V%N(@H*(SH@
M8V]M<&]S92YP:'`Z-38P(&-O;7!O<V4N<&AP.C4X-R!C;VUP;W-E+G!H<#HV
M-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P"FUS9VED(")-97-S86=E($-O
M;7!O<VET:6]N(@IM<V=S='(@(E!E;F=I<FEM86X@4&5S86XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3$W"FUS9VED(")-97-S86=E($1A=&4B"FUS
M9W-T<B`B5&%N9V=A;"!097-A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PHC
M+"!F=7IZ>0IM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(E!E<V%N
M(&ME(@H*(SH@<V5A<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@4V5A<F-H
M(@IM<V=S='(@(D-A<FD@4&5S86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`B56MU<F%N(%!E
M<V%N(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS9VED(")-97-S86=E(%-O=7)C
M92(*;7-G<W1R(")3=6UB97(@4&5S86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C8*;7-G:60@(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R("),:6AA
M="!097-A;B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-@IM<V=I
M9"`B365S<V%G92!F;&%G<R(*;7-G<W1R(")&;&%G('!E<V%N(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD
M97)S(@IM<V=S='(@(D9O;&1E<B!097-A;B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@9G)O
M;2`E<R(*;7-G<W1R(")&;VQD97(@4&5S86XB"@HC.B!M86EL8F]X+G!H<#HV
M-C<*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C:&UE;G1S(@IM
M<V=S='(@(DAA<'5S(&QA;7!I<F%N+B(*"B,Z(&UA:6QB;W@N<&AP.C8U.`HC
M+"!F=7IZ>0IM<V=I9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T<B`B
M1FEE;&0@<&5S86XB"@HC.B!M86EL8F]X+G!H<#HV-3,*(RP@9G5Z>GD*;7-G
M:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(D9I96QD('!E<V%N(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C,S"B,L(&9U>GIY"FUS
M9VED(")-97-S86=E(&UA=&-H97,B"FUS9W-T<B`B5&%N9V=A;"!097-A;B(*
M"B,Z(&-O;7!O<V4N<&AP.C@R-"!C;VUP;W-E+G!H<#HX,S@*(RP@9G5Z>GD*
M;7-G:60@(DUE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(E!E<V%N(&1I:VER:6T@9&5N9V%N('-U:W-E<R(*"B,Z(&-O;7!O<V4N
M<&AP.C$P.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@
M<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V960@=&\@)7,B"FUS9W-T
M<B`B4&5S86X@9&EK:7)I;2!D96YG86X@<W5K<V5S+"!T87!I('1I9&%K(&1I
M<VEM<&%N(@H*(SH@8V]M<&]S92YP:'`Z,3$T,R!C;VUP;W-E+G!H<#HQ,34X
M"B,L(&9U>GIY"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R(")097-A;B!D:6MI<FEM(&1E;F=A;B!S=6MS97,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.30Q"FUS9VED(")-97-S86=E<R!P97(@<&%G
M92!I;B!T:&4@;6%I;&)O>"!V:65W+B(*;7-G<W1R(")097-A;B!P97(@:&%L
M86UA;B!P861A('1A;7!I;&%N(&UA:6QB;W@N(@H*(SH@;6%I;&)O>"YP:'`Z
M,S(R"FUS9VED(")-97-S86=E<R!T;R(*;7-G<W1R(")097-A;B!K92(*"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I9"`B36]D:69Y(@IM<V=S
M='(@(E5B86@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.C$R
M"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@861D<F5S<R!F
M;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4B"FUS9W-T<B`B4&EN
M9&%H(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$V
M"B,L(&9U>GIY"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B='5R=6XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$X"FUS9VED(")-;W9E('-P86T@
M;65S<V%G97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S
M('1O($E.0D]8(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHU,`HC+"!F=7IZ>0IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T
M<B`B<&EL:6@@9F]L9&5R(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S$T"B,L(&9U>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@
M(FYA:6LB"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$R
M-PHC+"!F=7IZ>0IM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S
M='(@(D%L=&5R;F%T:68B"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z
M,34R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!-97-S86=E(%9I97<B"FUS
M9W-T<B`B3&EH870@4&5S86XB"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L
M='-E87)C:'-E;&5C="YI;F,Z-0IM<V=I9"`B3D].12(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M"FUS9VED(").3U1%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M.#@*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%M82(*"B,Z('!G<"YP:'`Z,3$P
M"FUS9VED(").86UE(&%N9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-S@*(RP@
M9G5Z>GD*;7-G:60@(DYE961S($%C=&EO;B(*;7-G<W1R(")!:W-I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S@*;7-G:60@(DYE
M=F5R(@IM<V=S='(@(E1I9&%K('!E<FYA:"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-C`*(RP@9G5Z>GD*;7-G:60@(DYE=F5R('-A=F4@871T86-H
M;65N=',B"FUS9W-T<B`B2&%P=7,@;&%M<&ER86XN(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C$R-`IM<V=I9"`B3F5W(@IM<V=S='(@(D)A<G4B"@HC
M.B!L:6(O24U0+G!H<#HU-C,*;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T<B`B
M1F]L9&5R($)A<G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#@*;7-G
M:60@(DYE=R!-86EL(@IM<V=S='(@(DUA:6P@0F%R=2(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ.2!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS
M,PHC+"!F=7IZ>0IM<V=I9"`B3F5W($UE<W-A9V4B"FUS9W-T<B`B4&5S86X@
M0F5R:6MU=&YY82(*"B,Z(&UA:6QB;W@N<&AP.C<W-B!L:6(O34E-12](96%D
M97)S+G!H<#HQ.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-
M97-S86=E('1O("5S(@IM<V=S='(@(E!E<V%N(&)A<G4B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$Y"FUS9VED(").97<@;65S<V%G97,B"FUS
M9W-T<B`B4&5S86X@8F%R=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHQ,S,*;7-G:60@(DYE>'0B"FUS9W-T<B`B0F5R:6MU=&YY82(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*
M;7-G:60@(DYE>'0@365S<V%G92(*;7-G<W1R(")097-A;B!"97)I:W5T;GEA
M(@H*(SH@;6%I;&)O>"YP:'`Z,S4V"FUS9VED(").97AT(%!A9V4B"FUS9W-T
M<B`B2&%L86T@0F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS9VED
M(").;R(*;7-G<W1R(")4:61A:R(*"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@
M(DYO($-E<G1I9FEC871E(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP
M=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3D*
M;7-G:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!M86EL
M8F]X+G!H<#HS-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO($UE
M<W-A9V5S(@IM<V=S='(@(E!E<V%N(&)A<G4B"@HC.B!P9W`N<&AP.C$S-PIM
M<V=I9"`B3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E
M<G-O;F%L($-E<G1I9FEC871E(%!R97-E;G0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TUA:6QB;W@N<&AP.C,R.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!4
M97AT(@IM<V=S='(@(E1E:W,@0F5N87(B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C$U"FUS9VED(").;R!0=6)L:6,@2V5Y<R!&;W5N9"(*;7-G
M<W1R("(B"@HC.B!S;6EM92YP:'`Z,34Q"FUS9VED(").;R!3+TU)344@<'5B
M;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.CDP"B,L(&9U>GIY"FUS9VED(").;R!A='1A8VAM96YT
M<R!F;W5N9"XB"FUS9W-T<B`B3&%M<&ER86XM;&%M<&ER86XB"@HC.B!L:6(O
M0W)Y<'0O4TU)344N<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I
M;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@
M86-L+G!H<#HW,B!A8VPN<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;R!F;VQD
M97(@<V5L96-T960N(@IM<V=S='(@(G1I9&%K(&%D82!F;VQD97(@>6%N9R!D
M:7!I;&EH(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T,0IM<V=I9"`B
M3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM
M<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C(Q."!L:6(O1F]L9&5R+G!H<#HU
M,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED(").;R!F;VQD97)S('=E<F4@
M<W!E8VEF:65D(@IM<V=S='(@(E1I9&%K(&%D82!F;VQD97(@>6%N9R!T97)S
M<&5S:69I:V%S:2(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#<*(RP@
M9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS
M9W-T<B`B4&5S86X@=&ED86L@=&5R:&%P=7,B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,30T"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@
M=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(E!E<V%N('1I9&%K('1E<FAA<'5S
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R-0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M;65S<V%G92!B;V1Y('1E>'0B"FUS9W-T<B`B<&EN9&%H('!E<V%N(&ME(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,W,0HC+"!F=7IZ>0IM<V=I9"`B3F\@;65S
M<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B5&ED86L@861A
M('!E<V%N('EA;F<@86YD82!C87)I(@H*(SH@<&=P+G!H<#HQ.#D*;7-G:60@
M(DYO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@<&=P+G!H<#HQ-C4*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P
M=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z
M,C`Q"FUS9VED(").;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP:'`Z,C(P"FUS9VED
M(").;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS
M9VED(").;R!S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B5&ED86L@861A(&ME
M<V%L86AA;B!P96YG96IA86XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G<W1R(")4
M:61A:R!A9&$@<V%R86XB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4V-`IM
M<V=I9"`B3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T:&]D
M(&-O=6QD(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C8X(&%C
M;"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO('5S97(@<W!E8VEF:65D+B(*
M;7-G<W1R(")4:61A:R!A9&$@9F]L9&5R('EA;F<@=&5R<W!E<VEF:6MA<VDB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Y"FUS9VED(").;VX@
M4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ,2!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N
M:6YC.C0P"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,U
M('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(").;VYE(@IM<V=S='(@(E1I
M9&%K(&%D82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y
M-0IM<V=I9"`B3F]R;6%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHS.0IM<V=I9"`B3F]T($1E;&5T960B"FUS9W-T<B`B5&ED86L@1&EH87!U
M<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@1')A9G0B"FUS
M9W-T<B`B0G5K86X@1')A9G0B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,T"FUS9VED
M(").;W0@26UP;W)T86YT(@IM<V=S='(@(E1I9&%K(%!E;G1I;F<B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS9VED(").;W0@4&5R
M<V]N86PB"FUS9W-T<B`B5&ED86L@4')I8F%D:2(*"B,Z(&QI8B]#<GEP="]0
M1U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S-"!L:6(O0W)Y<'0O
M4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV-PIM
M<V=I9"`B3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B4&5S86X@=&ED
M86L@=&5R:&%P=7,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q
M"FUS9VED(").;W0@:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(E!E<V%N
M('1I9&%K('!E;G1I;F<B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C
M:&UA:6Q?;&]G:6XN<&AP.C<Q"FUS9VED(").;W1E('1H870@=&AI<R!C86X@
M=&%K92!S;VUE('1I;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Q-@HC+"!F=7IZ>0IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R(")1
M=6]T:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PHC+"!F=7IZ
M>0IM<V=I9"`B3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@
M871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B2G5M
M;&%H(&9O;&1E<B!S96YT+6UA:6P@;&%M82!Y86YG('1E=&%P(&%D82!J:6MA
M(&1I:&%P=7,@8G5L86YA;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S4Y"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O
M(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B2G5M;&%H(&9O
M;&1E<B!S96YT+6UA:6P@;&%M82!Y86YG('1E=&%P(&%D82!J:6MA(&1I:&%P
M=7,@8G5L86YA;BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C(U-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW,S,*;7-G:60@(D]+(@IM<V=S='(@(D]+
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S
M+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0Y"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z-#@*;7-G:60@(D]2(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z,34*;7-G:60@(D]L9"!M97-S86=E<R(*
M;7-G<W1R(")097-A;B!,86UA(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C4R"FUS9VED(")/;&0@<V5N
M="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D+B(*;7-G<W1R(")&;VQD97(@
M<V5N="UM86EL(&QA;6$@<V5D86YG(&1I8G5A;F<N(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(U"FUS9VED(")/;FQY(&1I<W!L87D@9F]L9&5R<R!W
M:71H('5N<F5A9"!M97-S86=E<R!I;B!T:&5M/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"B,L(&9U>GIY"FUS
M9VED(")/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T
M:&ES(&%C=&EO;BXB"FUS9W-T<B`B4&EL:6@@:&%N>6$@<V%T=2!F;VQD97(@
M=6YT=6L@;W!E<F%S:2!I;FDN(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$P
M('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E;B!&
M;U]L9&5R(@IM<V=S='(@(D)U:V$@1F]L9&5R(@H*(SH@9F]L9&5R<RYP:'`Z
M-#(W"B,L(&9U>GIY"FUS9VED(")/<&5N960@1F]L9&5R(@IM<V=S='(@(D)U
M:V$@1F]L9&5R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P-0IM
M<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@9F5T
M8VAM86EL+G!H<#HS,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC
M.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@HC+"!F=7IZ
M>0IM<V=I9"`B3W1H97(@36%I;"!!8V-O=6YT<R(*;7-G<W1R(")0:6QI:&%N
M($QA:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,`IM<V=I9"`B
M3W1H97(@3W!T:6]N<R(*;7-G<W1R(")0:6QI:&%N($QA:6XB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,0IM<V=I9"`B3W5T8F]U;F0@4V5R
M=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI
M;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M.3`*;7-G:60@(E!'4"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E;F-R>7!T7VQI<W0N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(E!'4"!%;F-R
M>7!T($UE<W-A9V4B"FUS9W-T<B`B0F%T86QK86X@4&5S86XB"@HC.B!C;VUP
M;W-E+G!H<#HS-3@*(RP@9G5Z>GD*;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S
M='(@(E-A;&%H(@H*(SH@8V]M<&]S92YP:'`Z,S,W"FUS9VED(")01U`@17)R
M;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*(RP@
M9G5Z>GD*;7-G:60@(E!'4"!/<'1I;VYS(@IM<V=S='(@(E!I;&EH86XB"@HC
M.B!P9W`N<&AP.C,P"FUS9VED(")01U`@4&%S<W!H<F%S92!);G!U="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'
M4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C$W,PIM<V=I9"`B4$=0(%!U8FQI8R!+97D@5&5X="(*;7-G
M<W1R("(B"@HC.B!P9W`N<&AP.C$T.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C
M97-S9G5L;'D@861D960N(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@<W5D86@@
M9&EB=6%T(&1E;F=A;B!S=6MS97,N(@H*(SH@<&=P+G!H<#HR-#4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S
M7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")&;VQD97(@
M7"(E<UPB('-U9&%H(&1I:&%P=7,@9&5N9V%N('-U:W-E<RXB"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,30*;7-G:60@(E!'4"!0=6)L:6,@2V5Y<FEN
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI
M<W0N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!'4"!3:6=N($UE<W-A9V4B"FUS
M9W-T<B`B2VER:6T@4&5S86XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R
M>7!T7VQI<W0N:6YC.CD*;7-G:60@(E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C(P,@HC+"!F=7IZ>0IM<V=I9"`B
M4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B
M5&%N9&%T86YG86X@<W5D86@@9&EG86YT:2!D96YG86X@<W5K<V5S+B(*"B,Z
M('!G<"YP:'`Z,3<W"FUS9VED(")01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L
M;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O;F]T86-T
M:79E+FEN8SHT"FUS9VED(")01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T
M:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,C`X"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE
M('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR.34*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO
M="!C=7)R96YT;'D@86-T:79E('-O('1H92!M97-S86=E(&ES('5N86)L92!T
M;R!B92!D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR"FUS9VED("(B"B)01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U
M<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R
M<F5N=&QY("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M
M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@4$=0("(*(F9E
M871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G
M<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B
M4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-3
M3"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM
M<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38Y
M"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L
M(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B
M"FUS9W-T<B`B2&%L86UA;B`E9"!D87)I("5D(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP,PIM<V=I9"`B4&%G92!W:71H('1H92!&:7)S="!5;G-E
M96X@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3`T"FUS9VED(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`B0F%G:6%N(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$R,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")0
M87-S<&AR87-E("A!9V%I;BDB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(S
M-2!P9W`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W!H<F%S92!S=6-C
M97-S9G5L;'D@=6YL;V%D960N(@IM<V=S='(@(E!E<V%N(&1I:VER:6T@9&5N
M9V%N('-U:W-E<RP@=&%P:2!T:61A:R!D:7-I;7!A;B(*"B,Z('1E;7!L871E
M<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A<W-P
M:')A<V4N:6YC.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R("(B"@HC
M.B!P9W`N<&AP.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B92!E
M;7!T>2(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$Q-`IM<V=I9"`B4&%S<W!H
M<F%S97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3(*
M;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"FUS9VED(")097)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(DQA:W5K
M86X@;W!E<F%S:2!P97)A=V%T86X@<&%D82!L;V=I;C\B"@HC.B!A8VPN<&AP
M.C<V(&%C;"YP:'`Z,3`R"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U
M<V5R(&-A;B!N;W0@8F4@8VAA;F=E9"XB"FUS9W-T<B`B(@H*(SH@;65S<V%G
M92YP:'`Z-#DS(&UA:6QB;W@N<&AP.C<P,R!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(T"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M,3`*;7-G:60@(E!E<G-O;F%L(@IM<V=S='(@(E!R:6)A9&DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DEN9F]R;6%S:2!0<FEB861I(@H*(SH@<&=P+G!H<#HQ
M,C`*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R
M871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E!E<V%N(&1I:VER:6T@9&5N
M9V%N('-U:W-E<R(*"B,Z('!G<"YP:'`Z,3(W"B,L(&9U>GIY"FUS9VED(")0
M97)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B4&5S86X@9&EK:7)I;2!D96YG86X@<W5K<V5S(@H*(SH@<VUI;64N<&AP
M.C(P-PIM<V=I9"`B4&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@
M:6UP;W)T960Z("(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED
M(")097)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I
M9"`B4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O
M<G=A<F1S/R(*;7-G<W1R("),971A:VMA;B!T86YD871A;F=A;B!A;F1A('-E
M8F5L=6T@;65M8F%L87,@9&%N(&UE;F5R=7-K86X_(@H*(SH@8V]M<&]S92YP
M:'`Z,C4T"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3D*;7-G:60@
M(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO
M=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D("(*(G-O=6YD(&9I;&5S
M+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE
M<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@<&QU9VEN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T
M96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.B(*;7-G<W1R
M(")-87-U:VMA;B!N86UA('5N='5K(&9O;&1E<B!B87)U.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R('1E;7!L871E<R]J879A
M<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")0;&5A<V4@96YT97(@=&AE
M(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(DUA<W5K:V%N(&YA
M;6$@9&%R:2!F;VQD97(@8F%R=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$S-PIM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N97<@
M;F%M93HB"FUS9W-T<B`B36%S=6MK86X@;F%M82!B87)U.B(*"B,Z('1E;7!L
M871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'
M4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O("(*(F5N=&5R
M('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL
M>2!N965D("(*(G1O(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E
M<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!R96-O;7!O<V4N<&AP.CDW"FUS
M9VED("(B"B)0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I
M;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R`B"B)C;V]K
M:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W
M:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O("(*(FQO9R!I;B!A9V%I;B!I;B!Y
M;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A
M8VME<G,@9G)O;2`B"B)H:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A
M<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<Q"B,L(&9U>GIY"FUS9VED
M(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D+B(*;7-G<W1R(")"97)I
M:V%N('5S97)N86UE(&1A;B!P87-S=V]R9"!A;F1A(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B0F5R:6MA;B!U<V5R;F%M
M92!D86X@<&%S<W=O<F0@86YD82(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O
M24U0+G!H<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O
M<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B0F5T=6QK86X@86QA;6%T
M('EA;F<@<F%N8W4@9&%N('1I9&%K(&)E;F%R+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C8Q"FUS9VED(")0;&5A
M<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T
M:6]N<RXB"FUS9W-T<B`B4&EL:6@@<V5B=6%H(&9O;&1E<B!S96)E;'5M(&UE
M;&%K=6MA;B!A:W-I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,#(*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N(@IM<V=S='(@(E!I;&EH('-E9&EK:71N>6$@
M<V%T=2!F;VQD97(@=6YT=6L@<&5N8V%R:6%N+B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@
M870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(E!I;&EH
M('-E9&EK:71N>6$@<V%T=2!F;VQD97(@=6YT=6L@<&5N8V%R:6%N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L
M96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO
M;BXB"FUS9W-T<B`B4&EL:6@@:&%N>6$@<V%T=2!F;VQD97(@=6YT=6L@;W!E
M<F%S:2!I;FDN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C<S"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@
M=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E!I;&EH(&%T874@961I
M="!T97!A="!B97)I:W5T;GEA.B(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD:7-T
M.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,30*(RP@9G5Z>GD*;7-G:60@(E!R96-E
M9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T
M<B`B07=A;&D@=&%N9&%T86YG86X@86YD82!D96YG86X@9&%S:"`H)RTM("<I
M(@H*(SH@<VUI;64N<&AP.C(T,2!P9W`N<&AP.C(U-R!F:6QT97)P<F5F<RYP
M:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!R969E<F5N8V5S('-U8V-E<W-F=6QL
M>2!U<&1A=&5D+B(*;7-G<W1R(")&;VQD97(@7"(E<UPB('-U9&%H(&1I8G5A
M="!D96YG86X@<W5K<V5S+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHS"B,L(&9U>GIY"FUS9VED(")0<F5V:65W(@IM<V=S='(@
M(DAA;&%M86X@4V5B96QU;6YY82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G:60@(E!R979I;W5S($UE<W-A9V4B
M"FUS9W-T<B`B4&5S86X@4V5B96QU;6YY82(*"B,Z(&UA:6QB;W@N<&AP.C,T
M-PIM<V=I9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R(")(86QA;6%N(%-E8F5L
M=6UN>6$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@(D-E=&%K(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(E!R
M:6]R:71Y(@IM<V=S='(@(D-E=&%K(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C<V"FUS9VED(")0<FEV871E($ME>2!087-S=V]R9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34Y"FUS9VED
M(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E
M9F%U;'0@=&\@3D\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4U.`IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N
M="!I<R!S96YT.R!D969A=6QT('1O(%E%4R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3`*;7-G:60@(E!R;W1O8V]L
M.B(*;7-G<W1R("(B"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HT,CD*;7-G:60@
M(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O<G0@:&%S(&)E96X@9&ES86)L
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z
M.`HC+"!F=7IZ>0IM<V=I9"`B4'5R7V=E($1E;&5T960B"FUS9W-T<B`B0G5A
M;F<@>6%N9R!$:6AA<'5S(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN
M8SHX"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(D)U86YG('EA;F<@
M1&EH87!U<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(T
M"B,L(&9U>GIY"FUS9VED(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B2&%P
M=7,@1F]L9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-@IM<V=I
M9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G<W1R(")"=6%N9R!4<F%S
M:"!S96QA;6$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-0IM<V=I
M9"`B4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@
M=&AI<R!A;6]U;G0@;V8@9&%Y<RXB"FUS9W-T<B`B0G5A;F<@<&5S86X@;&%M
M82!D86QA;2!F;VQD97(@5')A<V@@>6%N9R!L96)I:"!D87)I(&IU;6QA:"!J
M871A:"!H87)I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*(RP@
M9G5Z>GD*;7-G:60@(E!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@
M9F]L9&5R/R(*;7-G<W1R(")"=6%N9R!P97-A;B!L86UA(&1A;&%M(&9O;&1E
M<B!4<F%S:#\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S
M:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!U<F=I;F<@
M)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(B5D('!E
M<V%N('-E9&%N9R!D:6)U86YG(&1A<FD@9F]L9&5R(%1R87-H+B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV,PHC+"!F=7IZ
M>0IM<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N
M(@IM<V=S='(@(B5D('!E<V%N('-E9&%N9R!D:6)U86YG(&1A<FD@9F]L9&5R
M(%1R87-H+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F
M34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q
M=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S
M.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A
M('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B475O
M=&EN9R`E9CHB"FUS9W-T<B`B475O=&EN9R(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B4F5?<75E<W0@1&5L:79E<GD@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP.C4P
M"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!/;B(*;7-G<W1R(")$:71E<FEM
M82!P861A(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@
M(E)E8V5I=F5D(%-I;F-E(@IM<V=S='(@(D1I=&5R:6UA('!A9&$B"@HC.B!L
M:6(O4V5A<F-H+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4F5C96EV960@56YT
M:6PB"FUS9W-T<B`B1&ET97)I;6$@<&%D82(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5D
M:7)E8U]T(@IM<V=S='(@(D%R86AK86XB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,38*;7-G:60@(E)E9&ER96-T(@IM<V=S
M='(@(D%R86AK86XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI
M;F,Z,3$P"FUS9VED(")2961I<F5C="!-97-S86=E(@IM<V=S='(@(D%R86AK
M86X@4&5S86XB"@HC.B!C;VUP;W-E+G!H<#HW.#<*;7-G:60@(E)E9&ER96-T
M('1H:7,@;65S<V%G92(*;7-G<W1R(")!<F%H:V%N('!E<V%N(&EN:2(*"B,Z
M(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*
M;7-G<W1R(")096YG87)A:&%N(&=A9V%L(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3@S"FUS9VED(")2969R97-H(@IM<V=S='(@(E1A
M;7!I;"!5;&%N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G
M:60@(E)E9G)E<V@@1F]L9&5R(%9I97=S.B(*;7-G<W1R(")486UP:6P@56QA
M;F<@1F]L9&5R.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD@
M=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHT"B,L(&9U>GIY"FUS9VED
M(")296QO860B"FUS9W-T<B`B5&%M<&EL($QA9VDB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]H96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R
M(")486UP:6P@3&%G:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,C8@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM<V=I9"`B4F5M96UB
M97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW.0IM<V=I9"`B4F5M96UB97(@=&AE
M(&QA<W0@=FEE=R(*;7-G<W1R("));F=A="!T86UP:6QA;B!T97)A:VAI<B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(DUA:6QB;W@B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V
M92!&:65L9"!&<F]M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!S;W5R8V4B"FUS9W-T<B`B:&%P=7,@<W5M8F5R(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B4F5N
M86UE($9O;&1E<BAS*2(*;7-G<W1R(")58F%H($YA;6$@1F]L9&5R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5N86UE('-E;G0M
M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")5
M8F%H(&YA;6$@9F]L9&5R('-E;G0M;6%I;"!P861A(&%W86P@8G5L86X_(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z-#4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")296YA;6EN9R!<(B5S7"(@=&\@7"(E<UPB(&9A:6QE9"X@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")097)U8F%H86X@;F%M
M82!<(B5S7"(@:V4@7"(E<UPB(&=A9V%L+B!)='5L86@@>6%N9R!D:6MA=&%K
M86X@<V5R=F5R+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS
M9W-T<B`B0F%L87,@:V4@4V5M=6$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")297!L86-E('=I=&@Z(@IM<V=S='(@
M(D=A;G1I(&1E;F=A;CHB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`B0F%L87,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$Q(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT,#D*(RP@9G5Z>GD*;7-G:60@(E)E<&QY(%-E;G0N(@IM
M<V=S='(@(D)A;&%S+6ME<&%D82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL(@IM<V=S
M='(@(D)A;&%S(&ME(%-E;75A(@H*(SH@8V]M<&]S92YP:'`Z-S,S"FUS9VED
M(")297!L>2!T;R!!;&PZ(@IM<V=S='(@(D)A;&%S(&ME(%-E;75A.B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F
M=7IZ>0IM<V=I9"`B4F5P;'D@=&\@3&ES="(*;7-G<W1R(")"86QA<R!K92!3
M96UU82(*"B,Z(&-O;7!O<V4N<&AP.C<S-0HC+"!F=7IZ>0IM<V=I9"`B4F5P
M;'D@=&\@3&ES=#HB"FUS9W-T<B`B0F%L87,@:V4@4V5M=6$Z(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"B,L(&9U>GIY
M"FUS9VED(")297!L>2!T;R!?06QL(@IM<V=S='(@(D)A;&%S(&ME(%-E;75A
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3,W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU-#<*;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S4*
M;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,T
M"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`B0F%L87,M2V5P861A.B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT,#D*;7-G:60@(E)E<&QY+51O.B`B"FUS9W-T
M<B`B0F%L87,M2V5P861A.B(*"B,Z(&-O;7!O<V4N<&AP.C<S,0IM<V=I9"`B
M4F5P;'DZ(@IM<V=S='(@(D)A;&%S.B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT
M(@IM<V=S='(@(DQA<&]R:V%N('-E8F%G86D@4W!A;2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS-2!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHR,PIM<V=I9"`B4F5P;W)T(&%S(%-P86TB"FUS
M9W-T<B`B3&%P;W)K86X@<V5B86=A:2!3<&%M(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,S@S"B,L(&9U>GIY"FUS9VED(")297%U97-T
M(&$@7U)E860@4F5C96EP="(*;7-G<W1R(")-:6YT82!486YD82!497)I;6$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T
M(&1E;&EV97)Y(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4W,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!R
M96%D(')E8V5I<'1S/R(*;7-G<W1R(")-:6YT82!486YD82!497)I;6$B"@HC
M.B!M86EL8F]X+G!H<#HQ.#D*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8Y-PIM<V=I9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-#,@=&5M<&QA=&5S
M+W-E87)C:"]H96%D97(N:6YC.C(V"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHQ-C$*;7-G:60@(E)E<V5T(@IM<V=S='(@(E)E<V5T(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$Q-0IM<V=I9"`B4F5S<&]N9&5N="!3=&%T
M=7,@57!D871E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T<B`B
M56QA;F=I(@H*(SH@<F5C;VUP;W-E+G!H<#HY.`IM<V=I9"`B4F5S=6UE('EO
M=7(@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!<(DUE
M<W-A9V4@0V]M<&]S:71I;VY<(B(*;7-G<W1R(")096YG:7)I;6%N(%!E<V%N
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHS
M,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-CD*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,S(*;7-G:60@(E)E
M='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHV,"!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I
M=F4N:6YC.C(R"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`Q('1E
M;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$T"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ-#D@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C(@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$W,PHC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B
M"FUS9W-T<B`B4&EL:6AA;B!096UA:V%I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<Q.`IM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X(&QI
M<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE
M<W-A9V4_(@IM<V=S='(@(B(*(DME;6)A;&D@:V4@;6%I;&)O>"!S971E;&%H
M('!E;F=H87!U<V%N+"!P96UI;F1A:&%N(&1A;B!P96YG8V]P>6%N('!E<V%N
M/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(E)O
M;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ
M-#(@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S<*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HT,3D*;7-G:60@(E,O34E-12(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$R"FUS
M9VED(")3+TU)344@16YC<GEP="!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O
M;7!O<V4N<&AP.C,Y-`IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z,S<S"FUS9VED(")3+TU)344@17)R;W(Z($YE
M960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3$*(RP@9G5Z>GD*
M;7-G:60@(E,O34E-12!/<'1I;VYS(@IM<V=S='(@(E!I;&EH86XB"@HC.B!S
M;6EM92YP:'`Z-#D*;7-G:60@(E,O34E-12!087-S<&AR87-E($EN<'5T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-30*;7-G
M:60@(E,O34E-12!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@
M82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z('-M:6UE
M+G!H<#HQ-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E,O34E-12!0
M=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D
M+B(*;7-G<W1R(")&;VQD97(@7"(E<UPB('-U9&%H(&1I:&%P=7,@9&5N9V%N
M('-U:W-E<RXB"@HC.B!S;6EM92YP:'`Z,38R"FUS9VED(")3+TU)344@4'5B
M;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`*;7-G:60@(E,O34E-12!0=6)L
M:6,@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C$Q"FUS9VED
M(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@
M861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y
M<'1?;&ES="YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!3:6=N($UE
M<W-A9V4B"FUS9W-T<B`B2VER:6T@4&5S86XB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$T"FUS9VED(")3+TU)344@4VEG;B]%
M;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES
M86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"FUS9VED("(B"B)3+TU)344@<W5P<&]R
M="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@
M=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S,*;7-G:60@(B(*(E,O34E-12!S
M=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES
M('-I9VYE9"!M97-S86=E(&-A;B!N;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T-@IM<V=I
M9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I
M9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S
M('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY
M('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG
M92!T:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S
M('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P-0IM<V=I9"`B4TU44"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-34*(RP@
M9G5Z>GD*;7-G:60@(E-?=6)J96-T(@IM<V=S='(@(E!E<FEH86PB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-C,*(RP@9G5Z>GD*;7-G
M:60@(E-A7W9E(&$@8V]P>2!I;B`B"FUS9W-T<B`B4VEM<&%N(&-O<'D@9&%L
M86T@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C,R"B,L(&9U>GIY"FUS9VED(")385]V92!A<R(*;7-G<W1R(")3:6UP86X@
M<V5B86=A:2(*"B,Z('-E87)C:"YP:'`Z,S$V('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B4V%V92(*;7-G<W1R
M(")3:6UP86X@<V5B86=A:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4S.`IM<V=I9"`B4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A
M9V4@:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#,S"FUS9VED(")3879E($1R869T(@IM<V=S='(@(E-I
M;7!A;B!$<F%F="(*"B,Z('-A=F5I;6%G92YP:'`Z-#(*(RP@9G5Z>GD*;7-G
M:60@(E-A=F4@26UA9V4B"FUS9W-T<B`B4VEM<&%N('-E8F%G86DB"@HC.B!L
M:6(O34E-12]#;VYT96YT<RYP:'`Z,C`T"FUS9VED(")3879E($EM86=E(&EN
M($=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C4Y('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`P"B,Z('1E
M;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$R('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-#@*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B4&EL:6AA
M;B!096UA:V%I(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C0P"FUS9VED(")3879E(%-T871I;VYE<GDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#,S"B,L(&9U>GIY"FUS9VED(")3879E(%]$<F%F
M="(*;7-G<W1R(")3:6UP86X@1')A9G0B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T
M<B`B4VEM<&%N('-E8F%G86DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(Q"FUS9VED(")3879E(&1R869T<R!A<R!U;G-E96X_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<R"FUS9VED(")3879E(')E
M8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S
M(&)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,3(W"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"B,L
M(&9U>GIY"FUS9VED(")3879E('-E;G0@;6%I;#\B"FUS9W-T<B`B4VEM<&%N
M(&UA:6P@>6%N9R!D:6MI<FEM(@H*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B4&5N>6EM
M<&%N86X@9')A9G0@9V%G86PN($EN:2!Y86YG(&1I:V%T86MA;B!S97)V97(Z
M("5S(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3D@
M=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O0FQO8VLO
M=')E95]F;VQD97)S+G!H<#HT,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(D-A
M<FDB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA
M=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4V5A<F-H("5S(@IM<V=S='(@(D-A<FDB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(P"B,L(&9U>GIY"FUS9VED(")396%R8V@@3W!T
M:6]N<R(*;7-G<W1R(")0:6QI:&%N(%!E;6%K86DB"@HC.B!S96%R8V@N<&AP
M.C(V-0IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B2&%S:6P@4&5N
M8V%R:6%N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM
M<V=S='(@(D1I;&EH870B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.CD*;7-G:60@(E-E;&5C="(*;7-G<W1R(")0:6QI:"(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW,`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G<W1R(")0:6QI:"!T:61A:R!A
M9&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4&EL:6@@:61E;G1I
M=&%S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R(")0:6QI:"!S96UU
M82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PHC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B4&EL
M:6@@=&ED86L@861A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O
M<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R
M(")0:6QI:"!S=6UB97(@8G5K=2!A;&%M870@=6YT=6L@<&5N86UB86AA;B!D
M86X@<&5N8V%R:6%N(&%L86UA="XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E!I;&EH('-E
M;75A(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(S
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&9I96QD<R!T;R!S96%R8V@@
M=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R(")0:6QI:"!U<G5T
M86X@9&%R:2!B=6MU(&%L86UA="!Y86YG(&1I8V%R:2!K971I:V$@;65N9V5M
M8F%N9VMA;B!A;&%M870N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O
M=6YT7W-E;&5C="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A
M8V-O=6YT(@IM<V=S='(@(E!I;&EH('1I9&%K(&%D82(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S
M='(@(E!I;&EH('1I9&%K(&%D82(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O
M<V%V96EM86=E+FEN8SHY"FUS9VED(")396QE8W0@=&AE(&=A;&QE<GD@=&\@
M<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T
M:&4@;6%I;"!S97)V97(@='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C=&5D($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(D)U:W4@06QA;6%T('EA
M;F<@1&EP:6QI:"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I
M9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`T"B,L(&9U>GIY"FUS9VED
M(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA<VD@
M4V5R=F5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"FUS9VED(")396YD
M($UE<W-A9V4B"FUS9W-T<B`B2VER:6T@4&5S86XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S`S"FUS9VED(")396YD(')E860@<F5C96EP="!W:&5N
M(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HS.3<*(RP@9G5Z>GD*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(B
M"FUS9W-T<B`B1F]L9&5R('-E;G0@;6%I;#HB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,X"FUS9VED(")396YT(&UA:6P@9F]L
M9&5R.B(*;7-G<W1R(")&;VQD97(@<V5N="!M86EL.B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,3,R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,30V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,34S"FUS9VED
M(")397)V97(B"FUS9W-T<B`B4V5R=F5R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(S"B,L(&9U>GIY"FUS9VED(")397)V97(@86YD($9O;&1E<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA<VD@4V5R=F5R(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(S"B,L(&9U>GIY"FUS9VED
M(")397)V97(Z(@IM<V=S='(@(E-E<G9E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,`IM<V=I9"`B4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA
M<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+B(*;7-G
M<W1R("(B"B)3970@<')E9F5R96YC92!A<&$@>6%N9R!T97)J861I(&II:V$@
M86YD82!M96UI;F1A:"!D86X@;65N9VAA<'5S('!E<V%N+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET
M>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0HC+"!F=7IZ>0IM<V=I9"`B
M4VAA<F4@1F]L9&5R<R(*;7-G<W1R(")&;VQD97(B"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z.#8*(RP@9G5Z>GD*;7-G:60@(E-H87)E(&UA:6P@9F]L
M9&5R<R(*;7-G<W1R(")&;VQD97(@<V5N="!M86EL.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E
M<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8V.0IM<V=I9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K
M<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L
M=#\@270@8V%N(&)E("(*(G1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@
M8VAO;W-E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-PIM<V=I9"`B4VAO=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G
M97,@8F4@<V-A;FYE9"!F;W(@4$=0(&1A=&$_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M
M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*
M;7-G<W1R(")(87)U<VMA:"!W:6YD;W<@<&5N9VER:6UA;B!D:71U='5P('-E
M=&5L86@@;65N>6EM<&%N(&1R869T/R(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B
M92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`B2&%P=7,@4V5M
M=6$@1F]L9&5R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z
M-C<*;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B(@H*(SH@;6%I
M;&)O>"YP:'`Z,S8U"FUS9VED(")3:&]W($1E;&5T960B"FUS9W-T<B`B5'5N
M:G5K:V%N('EA;F<@1&EH87!U<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW,`HC
M+"!F=7IZ>0IM<V=I9"`B4VAO=R!-86EL:6YG($QI<W0@26YF;W)M871I;VXB
M"FUS9W-T<B`B26YF;W)M87-I(%!R:6)A9&DB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.CDR"B,L(&9U>GIY"FUS9VED(")3:&]W($]N;'D@4W5B
M<V-R:6)E9"!&;VQD97)S(@IM<V=S='(@(E-U8G-C<FEB92!K92!&;VQD97(B
M"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D
M(@IM<V=S='(@(E1U;FIU:VMA;B!T:61A:R!L86YG9V%N86XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C`X"FUS9VED(")3:&]W(&%N(&EC;VX@=&\@
M86QL;W<@<W1R:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`R"FUS
M9VED(")3:&]W(&QE9V5N9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R
M(")4=6YJ=6MK86X@;&5G96YD82!P861A('1A;7!I;&%N(&UA:6QB;W@_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T,`IM<V=I9"`B4VAO=R!P<F5V
M:65W<R!F;W(@=6YR96%D(&UE<W-A9V5S(&]N;'D_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#@*;7-G:60@(E-H;W<@<')E=FEE
M=W,@:6X@=&]O;'1I<',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-S<*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O
M;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VAT;6PN<&AP.CDU"FUS9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4T"FUS9VED(")3
M:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(X"B,L(&9U>GIY"FUS9VED
M(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S
M='(@(E!A=&@@:V4@9F]L9&5R(&UA:6P@86YD83HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C8V"FUS9VED(")3:&]W;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0R"B,L(&9U
M>GIY"FUS9VED(")3:5]Z92(*;7-G<W1R(")5:W5R86XB"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")3:6=N
M960B"FUS9W-T<B`B56MU<F%N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B56MU<F%N(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM
M<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,38*;7-G:60@(E-O<G0@
M8GD@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($9R
M;VT@061D<F5S<R(*;7-G<W1R(")$87)I($%L86UA="(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*(RP@9G5Z>GD*;7-G
M:60@(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(E5K=7)A;B!097-A
M;B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,S8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R(")4
M:61A:R!A9&$@4&5R:6AA;"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@5&AR
M96%D(@IM<V=S='(@(E1H<F5A9"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@
M5&\@061D<F5S<R(*;7-G<W1R(")$87)I($%L86UA="(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B4W!A
M;2!F;VQD97(Z(@IM<V=S='(@(D9O;&1E<B!4<F%S:#HB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA
M<F%C=&5R<R(*;7-G<W1R(")+87)A:W1E<B!3<&5S:6%L(@H*(SH@<V5A<F-H
M+G!H<#HQ,S,*;7-G:60@(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;B!N
M;W0@8F4@961I=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS-#,*;7-G:60@(E-P96QL($-H96-K(@IM<V=S='(@
M(D-E:R!%:F%A;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHT-@IM<V=I9"`B4W!E;&P@0VAE8VME<B(*;7-G<W1R(")096YG96-E:R!%
M:F%A;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT."!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@(E-P96QL
M(&-H96-K(&-O;7!L971E(@IM<V=S='(@(D-E:R!E:F%A;B!S96QE<V%I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W,0IM<V=I9"`B4W!E;&QI;F<@
M97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T
M<B`B16IA(&ME<V%L86AA;B!P97(@;&%Y87(@:FEK82!M96YG96-E:R!E:F%A
M;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3(@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8U,@IM<V=I9"`B4W1A<G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.CD@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$Q"FUS9VED(")3=&%T:6]N97)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR
M-@IM<V=I9"`B4W1A=&EO;F5R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C@*;7-G:60@(E-T871I;VYE
M<GD@='EP93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C,S"FUS9VED(")3=&%T:6]N97)Y.B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")3=&%T=7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(Q-0HC+"!F
M=7IZ>0IM<V=I9"`B4W1R:7`@071T86-H;65N="(*;7-G<W1R("),86UP:7)A
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G:60@(E-T<FEP
M(&QI;F5B<F5A:W,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-U8E]J
M96-T(@IM<V=S='(@(E!E<FEH86PB"@HC.B!M97-S86=E+G!H<#HR-C@@=&AR
M96%D+G!H<#HQ-3`@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR
M-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R
M(")097)I:&%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I
M9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R(")&:65L9"!097)I:&%L(@H*(SH@
M<V5A<F-H+G!H<#HS,3@@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N
M:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,"!T
M96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"B,L(&9U>GIY"FUS9VED
M(")3=6)M:70B"FUS9W-T<B`B4&5R:6AA;"(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R
M*',I(@IM<V=S='(@(E-U8G-C<FEB92!K92!&;VQD97(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C,X,"!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HS.#D*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`B4W5K<V5S(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G<W1R
M(")387)A;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C(@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B4W5M;6%R>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#`@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`S"FUS9VED(")3=VET
M8V@@0V]M<&]S:71I;VX@365T:&]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O($A4
M34P@8V]M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@=&\@<&QA:6X@=&5X
M="!C;VUP;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,3D*(RP@9G5Z>GD*;7-G:60@(E1E7WAT(@IM<V=S
M='(@(E1E:W,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8Y"B,L
M(&9U>GIY"FUS9VED(")496YT871I=F4Z("(*;7-G<W1R(")!;'1E<FYA=&EF
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,0IM<V=I9"`B5&5N
M=&%T:79E;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<V,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C
M97!T960B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S
M7V%G<F5E;65N="YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5R;7,@
M;V8@4V5R=FEC92!F:6QE(&YO="!S<&5C:69I960@:6X@8V]N9BYP:'`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,P
M"FUS9VED(")497AT(@IM<V=S='(@(E1E:W,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.34T"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M
M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@(B(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z-3,R"FUS9VED("(B"B)4:&4@24U!4"!S97)V97(@
M9&]E<R!N;W0@87!P96%R('1O('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N
M(&UE=&AO9"`B"B)S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T
M96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0IM<V=I9"`B5&AE($UA8VEN=&]S:"!R
M97-O=7)C92!F;W)K(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A
M<'!L961O=6)L92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($UA
M8VEN=&]S:"!R97-O=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+B(*
M;7-G<W1R("(B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET87,@7"(E<UPB('-U9&%H(&1I
M:&%P=7,N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(DED96YT:71A<R!<(B5S7"(@<W5D86@@9&ES:6UP
M86XN(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM
M96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV.0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@
M:6YV86QI9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W
M:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y
M;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,@IM
M<V=I9"`B5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@
M8F5L;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E
M;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N
M86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@>6%N9R!B
M97)L86MU(&%K86X@9&EU8F%H(&YA;6$@:V4@7"(E<UPB+B(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ,#<*;7-G:60@(B(*(E1H92!C=7)R96YT(&QI
M<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@
M;F]T(&)E(')E=')I979E9"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ
M,C,V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S
M879E9"!T;R!T:&4@7"(E<UPB(&9O;&1E<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$S.0IM<V=I9"`B5&AE(&5V96YT('=A
M<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.CD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N
M(@IM<V=S='(@(DED96YT:71A<R!<(B5S7"(@<W5D86@@9&EH87!U<RXB"@HC
M.B!L:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B1F]L9&5R
M(%PB)7-<(B!S=61A:"!A9&$B"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I
M;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U
M<V4@(@HB<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@HB1F]L9&5R(%PB)7-<(B!B97)I<VD@:V%R
M86MT97(@:6QE9V%L('!A9&$@;F%M86YY82X@26YI(&UU;F=K:6X@;65N:F%D
M:2`B"B)M87-A;&%H+B!3:6QA:V%N('1A;GEA('!A9&$@861M:6YI<W1R871O
M<B!S:7-T96T@86YD82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&-R96%T960@
M8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+B(*;7-G<W1R(")&
M;VQD97(@7"(E<UPB('-U9&%H(&1I8G5A="!T971A<&D@86YD82!T:61A:R!M
M96QA;F=G86X@<&%D86YY82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T
M960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS
M9W-T<B`B1F]L9&5R(%PB)7-<(B!S=61A:"!D:6AA<'5S('1E=&%P:2!A;F1A
M('1I9&%K('1I9&%K(&UE;&%N9V=A;B!D87)I;GEA+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`B1F]L9&5R(%PB)7-<(B!S=61A:"!D:6)U870N($EN
M:2!Y86YG(&1I:V%T86MA;B!S97)V97(B"@HC.B!L:6(O1F]L9&5R+G!H<#HR
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(D9O;&1E<B!<(B5S7"(@=&ED86L@9&EH87!U<RX@26YI('EA;F<@
M9&EK871A:V%N('-E<G9E<B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S
M<V9U;&QY(&-R96%T960N(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@<W5D86@@
M9&EB=6%T(&1E;F=A;B!S=6MS97,N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S
M=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B1F]L9&5R(%PB)7-<(B!S
M=61A:"!D:6AA<'5S(&1E;F=A;B!S=6MS97,N(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@
M(D9O;&1E<B!<(B5S7"(@<W5D86@@9&EU8F%H(&YA;6$@:V4@7"(E<UPB(&1E
M;F=A;B!S=6MS97,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDR
M"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@
M=&AI<R!P87)T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7W-A=F5I;6%G95]W:6XN:G,Z,3(*;7-G:60@(B(*(E1H92!I;6%G
M92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@
M:&%V92!S970@>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I;F1O
M=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY
M-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A
M=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B
M;V]K+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L
M;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"FUS9VED(")4:&4@;6%I;"!S
M97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M
M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HV-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!M86EL
M8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(B5S('-U9&%H(&MO
M<V]N9RXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B
M>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PHC+"!F=7IZ
M>0IM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@
M8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")097-A;B!Y86YG('-E9&%N9R!D
M:6MI<FEM('-U9&%H(&1I='5T=7`N($ME;'5A<BXB"@HC.B!M97-S86=E+G!H
M<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(DED96YT:71A<R!<(B5S7"(@<W5D86@@9&EH87!U
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3,*(RP@9G5Z>GD*
M;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G<W1R
M(")097-A;B!I;FD@<W5D86@@9&EL87!O<FMA;B!S96)A9V%I('-P86TN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D
M+B!396YD97(Z("5S+B(*;7-G<W1R(")097-A;B!I;FD@<W5D86@@9&EL87!O
M<FMA;B!S96)A9V%I('-P86TN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+V]P96Y?
M<VUI;65?=VEN+FIS.C$P('1E;7!L871E<R]P9W`O;W!E;E]P9W!?=VEN+FIS
M.C$P"FUS9VED("(B"B)4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@
M;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@
M(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E
M9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C8P"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@
M:6X@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G:60@(E1H92!R97%U97-T960@
M9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N(@IM
M<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T
M:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@(@HB9G)O
M;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E
M(&-L:6-K("5S('1O('-E;F0@=&AE("(*(FYO=&EF:6-A=&EO;B!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HV
M.0IM<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E871E(&$@
M=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`T"B,L(&9U>GIY"FUS9VED(")4
M:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"XB"FUS9W-T<B`B
M5&%N9&%T86YG86X@=&ED86L@9&%P870@9&EG86YT:2XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P,@IM<V=I9"`B5&AE('-I9VYA='5R
M92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R(")486YD871A
M;F=A;B!S=61A:"!D:6=A;G1I(&1E;F=A;B!S=6MS97,N(@H*(SH@871T86-H
M;65N="YP:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<
M(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T<B`B261E;G1I=&%S(%PB)7-<(B!S
M=61A:"!D:7-I;7!A;BXB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED96YT:71A<R!<(B5S7"(@<W5D
M86@@9&EH87!U<RXB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B
M965N('5P9&%T960N(@IM<V=S='(@(DED96YT:71A<R!<(B5S7"(@<W5D86@@
M9&EH87!U<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38Y"FUS
M9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY
M-0HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4B"FUS
M9W-T<B`B:&%P=7,@<&5S86XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@
M;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HX,`IM<V=I9"`B5&AE('1E>'0@;V8@
M=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT
M(&UE<W-A9V4B"FUS9W-T<B`B07)A:&MA;B!P97-A;B!I;FDB"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@
M(E1A;F1A=&%N9V%N('-U9&%H(&1I9V%N=&D@9&5N9V%N('-U:W-E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4
M:&5R92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O96UP='E?;6%I;&)O>"YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE
M<W-A9V5S(&EN('1H:7,@;6%I;&)O>"XB"FUS9W-T<B`B5&ED86L@861A('!E
M<V%N(&1A;&%M(&UA:6QB;W@@:6YI+B(*"B,Z('1H<F5A9"YP:'`Z,3`Y"FUS
M9VED(")4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I
M;F<@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B
M061A(&UA<V%L86@@97AP=6YG:6YG("5S+B!);FD@>6%N9R!D:6MA=&%K86X@
M<V5R=F5R(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@
M=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B061A
M(&UA<V%L86@@97AP=6YG:6YG(&UA:6QB;W@N($EN:2!Y86YG(&1I:V%T86MA
M;B!S97)V97(Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8R,0IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B061A(&UA<V%L
M86@@97AP=6YG:6YG(&UA:6QB;W@N($EN:2!Y86YG(&1I:V%T86MA;B!S97)V
M97(B"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A
M9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B
M"B)S97)V97(@<V%I9"(*;7-G<W1R(")!9&$@:V5S86QA:&%N('-A870@;65N
M9V-O<'D@<&5S86X@:V4@7"(E<UPB+B!);FD@>6%N9R!D:6MA=&%K86X@<V5R
M=F5R(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Y."!L:6(O365S<V%G92YP:'`Z
M,C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4
M:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(B(*(D%D
M82!K97-A;&%H86X@<V%A="!M96YG:&%P=7,@<&5S86X@9&%R:2!F;VQD97(@
M7"(E<UPB+B!);FD@>6%N9R!D:6MA=&%K86X@(@HB<V5R=F5R(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E
M<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS
M9W-T<B`B061A(&ME<V%L86AA;B!M96YG8V]P>2!P97-A;B!K92!<(B5S7"(N
M($EN:2!Y86YG(&1I:V%T86MA;B!S97)V97(B"@HC.B!L:6(O365S<V%G92YP
M:'`Z,C$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(D%D82!K97-A;&%H86X@<V%A="!M
M96YG:&%P=7,@<&5S86XN($EN:2!Y86YG(&1I:V%T86MA;B!S97)V97(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z.3D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&4@
M979E;G0Z("5S+B(*;7-G<W1R(")!9&$@:V5S86QA:&%N('-A870@;65L:6AA
M="!P97-A;B!Y86YG(&1I;6EN=&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L
M86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR:6-H960N<&AP.C,W"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R(")!9&$@:V5S86QA:&%N('-A870@;65N86UP:6QK
M86X@8F%G:6%N('!E<V%N(&EN:2(*"B,Z(&QI8B]-97-S86=E+G!H<#HU-#4@
M;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O
M;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B
M"FUS9W-T<B`B(@HB061A(&ME<V%L86AA;B!S86%T(&UE;69L86<@<&5S86X@
M9&%R:2!F;VQD97(@7"(E<UPB+B!);FD@>6%N9R!D:6MA=&%K86X@(@HB<V5R
M=F5R(@H*(SH@9F]L9&5R<RYP:'`Z,38U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G
M<W1R(")!9&$@:V5S86QA:&%N('-A870@;65N>6EM<&%N(&1R869T+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&5V96YT.B`E<RXB"FUS9W-T<B`B061A(&ME<V%L86AA;B!S86%T(&UE;&EH
M870@<&5S86X@>6%N9R!D:6UI;G1A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-C8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R
M(")!9&$@:V5S86QA:&%N('-A870@;65L:6AA="!P97-A;B!Y86YG(&1I;6EN
M=&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T
M<B`B061A(&ME<V%L86AA;B!S86%T(&UE;F=I<FEM('!E<V%N(&%N9&$Z("5S
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S
M(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S
M97)V97(@<V%I9"(*;7-G<W1R(")!9&$@:V5S86QA:&%N('-A870@;65M:6YD
M86@@<&5S86X@:V4@7"(E<UPB+B!);FD@>6%N9R!D:6MA=&%K86X@<V5R=F5R
M(@H*(SH@8V]M<&]S92YP:'`Z,3(T-`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE<W-A9V4@87,@82!D<F%F="XB
M"FUS9W-T<B`B061A(&ME<V%L86AA;B!S86%T(&UE;F%M<&EL:V%N(&)A9VEA
M;B!P97-A;B!I;FDB"@HC.B!C;VUP;W-E+G!H<#HQ,#`V"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S
M<V%G93H@)7,B"FUS9W-T<B`B061A(&ME<V%L86AA;B!S86%T(&UE;F=I<FEM
M('!E<V%N(&%N9&$Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(D%D82!K
M97-A;&%H86X@<V%A="!M96YG:7)I;2!P97-A;B!A;F1A.B`E<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!N;R!T97AT(&EN('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@
M(D%D82!K97-A;&%H86X@<V%A="!M96YA;7!I;&MA;B!B86=I86X@<&5S86X@
M:6YI(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"B,L(&9U>GIY
M"FUS9VED(")4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D
M(&EN(&ET+B(*;7-G<W1R(")097-A;B!I;FD@<W5D86@@9&EL87!O<FMA;B!S
M96)A9V%I('-P86TN(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP
M"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D
M9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V
M"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T
M:&4@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$P-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$X"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#,@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$U-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<S(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,30*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q
M.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B26YI(&UU;F=K
M:6X@8G5T=6@@=V%K='4N($%N9&$@>6%K:6X@:6YG:6X@;65L86YJ=71K86X_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,`IM<V=I
M9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$P"FUS
M9VED("(B"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T
M:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,30*
M;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H
M870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,`IM<V=I9"`B(@HB
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN
M9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B`B"B)T:&ES(&UE<W-A9V4@
M:7,@=6YK;F]W;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,S$U"B,L(&9U>GIY"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M97-S
M86=E+B!%<G)O<CH@(@IM<V=S='(@(B5S('1I9&%K(&UU;F-U;"!S96)A9V%I
M(&UA:6QB;W@@>6%N9R!B96YA<BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HR-#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S4P"FUS9VED("(B
M"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C
M;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P
M"FUS9VED(")4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN
M('1H92!C;W)R96-T(%,O34E-12!F;W)M870N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HT,38*(RP@9G5Z>GD*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E
M;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N(@IM<V=S='(@(E!E<V%N(&EN
M:2!S=61A:"!D:6QA<&]R:V%N('-E8F%G86D@<W!A;2XB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B5&AI<R!M
M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12XB
M"FUS9W-T<B`B4&5S86X@:6YI('-U9&%H(&1I;&%P;W)K86X@<V5B86=A:2!S
M<&%M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3,Y(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")4:&ES
M(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S
M='(@(E!E<V%N(&EN:2!S=61A:"!D:6QA<&]R:V%N('-E8F%G86D@<W!A;2XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#$@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")4:&ES(&UE<W-A9V4@
M:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R(")097-A;B!I
M;FD@<W5D86@@9&EL87!O<FMA;B!S96)A9V%I('-P86TN(@H*(SH@;65S<V%G
M92YP:'`Z,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T<B`B4&5S
M86X@:6YI(&ME<&%D82(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H:7,@<V5R
M=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P.0HC
M+"!F=7IZ>0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R(")7:6YD;W<@:6YI(&AA<G5S
M(&1I<&%N9V=I;"!D87)I('=I;F1O=R!P96YG:7)I;6%N(@H*(SH@=&AR96%D
M+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM<V=S
M='(@(E1A;7!I;&MA;B(*"B,Z('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDR,@IM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B3&EH
M870@5&AR96%D(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP.C8P
M-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S
M92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS9VED(")4
M;R(*;7-G<W1R(")+97!A9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3$Y"B,L(&9U>GIY"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(D1A<FD@
M06QA;6%T(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE
M("(*(F-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C$S-`IM<V=I9"`B(@HB5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO
M=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C`N-B!O<B`B
M"B)H:6=H97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4W-PHC+"!F=7IZ>0IM<V=I9"`B5&]T86P@071T86-H;65N
M=',@4VEZ93HB"FUS9W-T<B`B3&%M<&ER86XM;&%M<&ER86XB"@HC.B!F;VQD
M97)S+G!H<#HS.#@*(RP@9G5Z>GD*;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G
M<W1R(")&;VQD97(@5')A<V@Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H
M<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A<V@@9F]L9&5R.B(*;7-G<W1R(")&
M;VQD97(@5')A<V@Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV-2!L:6(O
M475O=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N9"YP:'`Z
M-S(*(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T82]C;W5R
M:65R+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*;7-G:60@(E5N
M86)L92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R(")4:61A:R!D
M:6IA=V%B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I
M9"`B56YA;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")097-A;B!T:61A:R!D
M:6IA=V%B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@
M(E5N9&5L971E(@IM<V=S='(@(E1I9&%K(&1I:&%P=7,B"@HC.B!M86EL8F]X
M+G!H<#HU.#D@;6%I;&)O>"YP:'`Z-C`R(&QI8B]-24U%+TAE861E<G,N<&AP
M.C(Q,@IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I96YT<R(*;7-G<W1R(")0
M96YE<FEM82!R86AA<VEA(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT
M(&]F('1Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V-0IM
M<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!
M4"!R97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,S4*;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R("(B"@HC.B!M86EL
M8F]X+G!H<#HV,3@*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT
M(@IM<V=S='(@(E!E;F5R:6UA(')A:&%S:6$B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I
M9"`B56YL;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL
M<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E1I9&%K(&1I
M;F%M86DB"@HC.B!M97-S86=E+G!H<#HT.3D@;6%I;&)O>"YP:'`Z-S`X('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$U('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,S(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHU"FUS9VED(")5;G-E96XB"FUS9W-T<B`B5&ED86L@9&EL:6AA="(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$R"FUS9VED(")5;G-U
M8G-C<FEB92!F<F]M($9O;&1E<BAS*2(*;7-G<W1R(")4:61A:R!L86YG9V%N
M86X@9&%R:2!&;VQD97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU.#0*;7-G:60@(E5P9&%T92!!='1A8VAM96YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C`*
M;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-3@@=&5M<&QA=&5S
M+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*
M;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(D=U;F%K86X@3FEL
M86D@1&5F875L="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-38*;7-G
M:60@(E5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/R(*;7-G<W1R(")'
M=6YA:V%N(&9O;&1E<B!)34%0(&QA;F=G86YA;C\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S,U"B,L(&9U>GIY"FUS9VED(")5<V4@5FER='5A;"!4
M<F%S:"!&;VQD97(_(@IM<V=S='(@(DMO<V]N9VMA;B!F;VQD97(@5')A<V@B
M"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,30R"B,L(&9U>GIY"FUS9VED
M(")5<V5R(@IM<V=S='(@(E5S97)N86UE(@H*(SH@86-L+G!H<#HX-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C97-S9G5L;'D@
M9VEV96X@=&AE('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C$W-PIM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B57-E<FYA;64B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3<*(RP@9G5Z>GD*;7-G
M:60@(E5S97)N86UE.B(*;7-G<W1R(")5<V5R;F%M92(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHV.`HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHR-PHC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")6:65W
M(@IM<V=S='(@(DQI:&%T("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP
M:'`Z.3(@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(DQI:&%T("5S(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R!0=6)L:6,@2V5Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*
M(RP@9G5Z>GD*;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W(@IM<V=S='(@(DMI<FEM('!E<V%N('!A9&$@=VEN9&]W('1E
M<G!I<V%H/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X
M"B,L(&9U>GIY"FUS9VED(")6:65W($UE<W-A9V5S(@IM<V=S='(@(E!E<V%N
M(&)A<G4B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R!097)S;VYA;"!0<FEV
M871E($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE=R!0
M97)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B
M5FEE=R!4:')E860B"FUS9W-T<B`B5&AR96%D(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V-0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GD*;7-G:60@(E9I
M97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")+
M:7)I;2!P97-A;B!P861A('=I;F1O=R!T97)P:7-A:#\B"@HC.B!L:6(O34E-
M12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")+:7)I;2!P
M97-A;B!P861A('=I;F1O=R!T97)P:7-A:#\B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,30P"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(B(*
M"B,Z(&9O;&1E<G,N<&AP.C,X,"!M86EL8F]X+G!H<#HU,S0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E9I97<@;65S<V%G97,@:6X@)7,B"FUS9W-T
M<B`B3&EH870@<&5S86X@9&%L86T@(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN
M:71I86QP86=E<V5L96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X
M('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S='(@(DQI:&%T(&%T874@
M=&%M<&EL:V%N(&UA:6QB;W@@<V5T96QA:"!L;V=I;CHB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3<P"B,L(&9U>GIY"FUS9VED(")6:65W('1A
M<VLB"FUS9W-T<B`B3&EH870@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")6:65W('1H92!);6%G97,B"FUS
M9W-T<B`B3&EH870@<&5S86X@9&%L86T@(@H*(SH@<V5A<F-H+G!H<#HR-C,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB
M)7-<(B!C<F5A=&5D('-U8V-E<V9U;&QY+B(*;7-G<W1R(")&;VQD97(@7"(E
M<UPB('-U9&%H(&1I:&%P=7,@9&5N9V%N('-U:W-E<RXB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$Q,2!L:6(O24U!4"]4<F5E+G!H<#HQ,S@@
M;&EB+TE-05`O5')E92YP:'`Z,34Q"B,Z(&QI8B])34%0+U1R964N<&AP.C$U
M,R!L:6(O24U!4"]4<F5E+G!H<#HQ-3<@;&EB+TE-05`O5')E92YP:'`Z,34X
M"B,Z(&QI8B])34%0+U1R964N<&AP.C,V.2!L:6(O24U!4"]4<F5E+G!H<#HS
M.3,@;&EB+TE-05`O5')E92YP:'`Z-#,S"B,L(&9U>GIY"FUS9VED(")6:7)T
M=6%L($9O;&1E<G,B"FUS9W-T<B`B0G5A="!&;VQD97(B"@HC.B!S96%R8V@N
M<&AP.C(T-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E
M;"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&;VQD97(N<&AP.C$W-2!L:6(O5D9O
M;&1E<BYP:'`Z,3@P"FUS9VED(")6:7)T=6%L($E.0D]8(@IM<V=S='(@(B(*
M"B,Z(&9O;&1E<G,N<&AP.C0Q-@IM<V=I9"`B5FER='5A;"!)3D)/6"!&;VQD
M97(B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-#4R(&QI8B]61F]L9&5R
M+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0IM<V=I9"`B5FER='5A;"!4
M<F%S:"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,3,*(RP@9G5Z>GD*
M;7-G:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(DMO<V]N9VMA
M;B!F;VQD97(@5')A<V@B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C$S,PIM<V=I9"`B5FER='5A;"!F;VQD97(@;&%B96PB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S0*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`B4&5R:6YG871A;B(*"B,Z(&QO9VEN+G!H<#HQ,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")396QA
M;6%T($1A=&%N9R!D:2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M,3D*;7-G:60@(B(*(E=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S
M86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*
M(F]R(&EN;F]C96YT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S(W"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M
M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K
M:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HB2FEK82!P97-A
M;B!D:6AA<'5S+"!P:6YD86AK86X@;65R96MA(&ME(&9O;&1E<B!4<F%S:"!A
M;F1A(&1A<FEP861A(&UE;F%N9&%I("(*(FUE<F5K82!D96YG86X@=&5R:&%P
M=7,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-PIM<V=I9"`B5VAE
M;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A
M;G0@=&\@<W1A<G0@;VX_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-C$*;7-G:60@(E=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO
M=6QD('=E('-A=F4@871T86-H;65N="!D871A/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(V"FUS9VED("(B"B)7:&5N('-E;F1I
M;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S
M:&]U;&0@=V4@87!P96YD('1O("(*(G5N<75A;&EF:65D(&%D9')E<W-E<R`H
M96UA:6P@861D<F5S<V5S('=I=&AO=70@7")`7"(I/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E=H:71E;&ES
M="(*;7-G<W1R(")7:&ET96QI<W0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW.`IM<V=I
M9"`B665S(@IM<V=S='(@(EEA(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M9F5T8VAM86EL7VQO9VEN+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R
M92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C
M;W5N="AS*3HB"FUS9W-T<B`B06YD82!S961A;F<@;65N8V]B82!M96YG:&%P
M=7,@9F]L9&5R(&)E<FEK=70@:6YI.B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P"B,L(&9U>GIY"FUS9VED("(B"B)9
M;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT
M86EN960@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@
M(D%N9&$@<V5D86YG(&UE;F-O8F$@;65N9VAA<'5S(&9O;&1E<B!B97)I:W5T
M(&EN:3HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN
M:'1M;#HY"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&%T=&5M<'1I;F<@=&\@
M9&5L971E('1H92!F;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G<W1R(")!;F1A
M('-E9&%N9R!M96YC;V)A(&UE;F=H87!U<R!F;VQD97(@8F5R:6MU="!I;FDZ
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@
M87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B
M06YD82!S961A;F<@;65N9V-O<'DO;65M:6YD86@@:V4@9F]L9&5R(&)A<G4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#(*;7-G
M:60@(EEO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O("(*;7-G<W1R
M(")!;F1A('-E9&%N9R!M96UB=6%T('-U8BUF;VQD97(@:V4@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(EEO=2!A
M<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R(")!;F1A
M('-E9&%N9R!M96UB=6%T(&9O;&1E<B!T:6YG:V%T+6%T87,N(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,S(P"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!F;VQD97)S+B(*;7-G<W1R(")!;F1A('-E9&%N
M9R!M96UB=6%T(&9O;&1E<B!T:6YG:V%T+6%T87,N(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z,S(W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-0IM
M<V=I9"`B66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B`B"FUS9W-T<B`B
M06YD82!S961A;F<@;65N9W5B86@@;F%M82!F;VQD97(Z("(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D%N
M9&$@<W5D86@@=&ED86LM;&%N9V=A;F%N(&1A<FD@7"(E<UPB(&1E;F=A;B!S
M=6MS97,B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@=&AE(&9O;&QO
M=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X=#H@)6,@
M9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R('1H
M92!S:6=N871U<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W1O<U]A9W)E96UE;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED(&YO
M="!A9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O
M('EO=2!W97)E(&YO="!A;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Y"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@
M9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O<G=A<F1E9"!T:&ES(&UE<W-A9V4@
M;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!H879E("5S(&YE=R!M97-S86=E<RXB"FUS
M9W-T<B`B06YD82!P=6YY82`E<R!P97-A;B!B87)U+B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED(")9;W4@:&%V92`Q(&YE=R!M
M97-S86=E+B(*;7-G<W1R(")!;F1A('!U;GEA(#$@<&5S86X@8F%R=2XB"@HC
M.B!C;VUP;W-E+G!H<#HT.30*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&%L
M<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T<B`B06YD82!P=6YY
M82`Q('!E<V%N(&)A<G4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:G,Z,3$U"FUS9VED("(B"B)9;W4@:&%V92!A="!L96%S="!O;F4@
M871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@=7!L;V%D('EE
M="X@07)E("(*(GEO=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI<R!M97-S
M86=E('=I=&AO=70@=&AE<V4@871T86-H;65N=',_(@IM<V=S='(@(B(*"B,Z
M(&QI8B])35`N<&AP.C$P-S0*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN
M('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R(")!;F1A('!U;GEA(&UA
M:6P@9&%L86T@9F]L9&5R(&)E<FEK=70@:6YI.B(*"B,Z(&QI8B])35`N<&AP
M.C$P-SD*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I
M;F<@9F]L9&5R<SHB"FUS9W-T<B`B06YD82!P=6YY82!M86EL(&1A;&%M(&9O
M;&1E<BUF;VQD97(@8F5R:6MU="!I;FDZ(@H*(SH@8V]M<&]S92YP:'`Z,34S
M"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@
M<F5C:7!I96YT+B(*;7-G<W1R(")!;F1A(&AA<G5S('!U;GEA('!A;&EN9R!S
M961I:VET;GEA('-A='4@<&5N97)I;6$N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,S`R"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES
M(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR-#D*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@
M(@HB;65S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHR,#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL
M8F]X(&9I<G-T+B(*;7-G<W1R(")!;F1A(&AA<G5S(&UE;6EL:6@@;6%I;&)O
M>"!T87)G970@9'5L=2XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#4*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E
M(&1E;&5T960N(@IM<V=S='(@(D%N9&$@:&%R=7,@;65M:6QI:"!I9&5N=&ET
M87,@>6%N9R!A:V%N(&1I:&%P=7,N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHX,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D
M9')E<W,@9FER<W0N(@IM<V=S='(@(D%N9&$@:&%R=7,@;65M:6QI:"!A;&%M
M870@9'5L=2XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHV,B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#@*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8S"FUS9VED(")9
M;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM
M<V=S='(@(D%N9&$@:&%R=7,@;65M:6QI:"!D=6QU('!A;&EN9R!S961I:VET
M;GEA('-A='4@<&5S86XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z,3,*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!R96-I<&EE;G0N
M(@IM<V=S='(@(D%N9&$@:&%R=7,@;65N<W!E<VEF:6MA<VD@<&5N97)I;6$N
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,CD*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I
M;&4@=&\@871T86-H+B(*;7-G<W1R(")!;F1A(&AA<G5S(&UE;G-P97-I9FEK
M87-I(&1U;'4@9FEL92!Y86YG(&%K86X@9&EL86UP:7)K86XN(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N86)L960@:6X@>6]U
M<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I
M;&QO9RYP:'`Z,3,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+B(*;7-G<W1R
M(")!<F%H:V%N('!E<V%N(&EN:2(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!R97!L:65D('1O('1H
M:7,@;65S<V%G92!O;B`E<RXB"FUS9W-T<B`B07)A:&MA;B!P97-A;B!I;FDB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HU,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@7"(E<UPB+B!(97)E(&ES('=H
M870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(D%N9&$@=&ED86L@;&%N9V=A
M;F%N(&ME(%PB)7-<(BX@26YI('EA;F<@9&EK871A:V%N('-E<G9E<B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H
M870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(D%N9&$@=&ED86L@=&ED86LM
M;&%N9V=A;F%N(&1A<FD@7"(E<UPB+B!);FD@>6%N9R!D:6MA=&%K86X@<V5R
M=F5R(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<
M(B(*;7-G<W1R(")!;F1A('-U9&%H(&QA;F=G86YA;B!K92!<(B5S7"(@9&5N
M9V%N('-U:W-E<R(*"B,Z(&QI8B]&;VQD97(N<&AP.C4V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D
M(&9R;VT@7"(E<UPB(@IM<V=S='(@(D%N9&$@<W5D86@@=&ED86LM;&%N9V=A
M;F%N(&1A<FD@7"(E<UPB(&1E;F=A;B!S=6MS97,B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z.3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G
M<W1R(").86UA(&QE;F=K87`@86YD83HB"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-3`*;7-G:60@(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+
M97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV
M-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@4'5B;&EC($ME>2(*;7-G<W1R(").86UA(&QE;F=K87`@86YD83HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"B,L(&9U>GIY"FUS9VED(")9
M;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM
M<V=S='(@(D)A;&%S86X@:V5P861A($%N9&$Z(&%L86UA=#H@/&D^*'!I;&EH
M86XI/"]I/B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#D*;7-G
M:60@(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L
M96-T+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!A8V-O=6YT<SHB"FUS
M9W-T<B`B261E;G1I=&%S(&%N9&$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$W,PIM<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH
M;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO
M96T^(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.CDR"B,L(&9U>GIY"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S
M='(@(D)R;W=S97(@86YD82!T:61A:R!M96YD=6MU;F<@<&5N86UP:6QA;B!I
M;FQI;F4@9&%R:2!J96YI<R!G86UB87(@:6YI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D969A=6QT(&-H87)S970@9F]R
M('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@
M96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@Y"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI
M=F5R960N(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@<W5D86@@9&EH87!U<R!D
M96YG86X@<W5K<V5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*
M;7-G:60@(EEO=7(@<VEG;F%T=7)E.B(*;7-G<W1R(")486YD871A;F=A;B!!
M;F1A(@H*(SH@;65S<V%G92YP:'`Z,C@X(&-O;7!O<V4N<&AP.C$R.#0@;6%I
M;&)O>"YP:'`Z-30Y(&QI8B]#;VUP;W-E+G!H<#HX,3@*;7-G:60@(EM.;R!3
M=6)J96-T72(*;7-G<W1R(");5&ED86L@861A(%!E<FEH86Q=(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,L(&9U>GIY"FUS9VED
M(")?0F-C(@IM<V=S='(@(D)C8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R(")"
M;&%C:VQI<W0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ
M-30*(RP@9G5Z>GD*;7-G:60@(E]#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B
M2&%P=7,B"@HC.B!L:6(O24U0+G!H<#HY-SD*(RP@9G5Z>GD*;7-G:60@(E]&
M;VQD97)S(@IM<V=S='(@(D9O;&1E<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C@Q"B,L(&9U>GIY"FUS9VED(")?261E;G1I='DB"FUS
M9W-T<B`B261E;G1I=&%S(@H*(SH@;&EB+TE-4"YP:'`Z.38Q"FUS9VED(")?
M26YB;W@B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`R,`HC+"!F=7IZ
M>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B2V5L=6%R(@H*(SH@;65S<V%G
M92YP:'`Z,S@T"B,L(&9U>GIY"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS
M9W-T<B`B4W5M8F5R(%!E<V%N(@H*(SH@;&EB+TE-4"YP:'`Z.3<V"B,L(&9U
M>GIY"FUS9VED(")?3F5W($UE<W-A9V4B"FUS9W-T<B`B4&5S86X@8F%R=2(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PHC
M+"!F=7IZ>0IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(D-E=&%K(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(X.0IM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@
M(B(*"B,Z(&UA:6QB;W@N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B7U)E9G)E<V@@)7,B"FUS9W-T<B`B5&%M<&EL(%5L86YG(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*(RP@9G5Z
M>GD*;7-G:60@(E]297!L>2(*;7-G<W1R(")"86QA<R(*"B,Z(&QI8B])35`N
M<&AP.CDX,0HC+"!F=7IZ>0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")#87)I
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"B,L(&9U>GIY"FUS9VED(")?
M4V5N9"!-97-S86=E(@IM<V=S='(@(DMI<FEM(%!E<V%N(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,@HC+"!F=7IZ>0IM
M<V=I9"`B7U1H<F5A9"(*;7-G<W1R(")4:')E860B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*(RP@9G5Z>GD*;7-G:60@(E]4;R(*
M;7-G<W1R(")+97!A9&$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B7U5N9&5L971E(@IM<V=S='(@(E1I
M9&%K(&1I:&%P=7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(E]6:65W(%1H<F5A9"(*;7-G
M<W1R(")4:')E860B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*
M(RP@9G5Z>GD*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B5VAI=&5L:7-T
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W-@IM<V=I9"`B861D<F5S<V5E('5N
M:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0T,`HC+"!F
M=7IZ>0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R("),86UP:7)A;B(*"B,Z
M('9I97<N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")A='1A8VAM96YT<RYZ:7`B
M"FUS9W-T<B`B3&%M<&ER86XM;&%M<&ER86XB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU,3,*;7-G:60@(F)Y=&5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#`*;7-G:60@(F-A;FYO="!C<F5A=&4@
M;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W
M,@IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$V-`IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C`*;7-G:60@
M(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C$Y-@IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38X"FUS9VED(")D
M871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,C(T"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R
M;VTB"FUS9W-T<B`B9&%R:2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#`*;7-G
M:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR,#0*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@X"FUS9VED(")I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,CD@<&=P
M+G!H<#HV.0IM<V=I9"`B:V5Y(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP
M.C$V,0HC+"!F=7IZ>0IM<V=I9"`B;6%I;&)O>"!F:6QE(@IM<V=S='(@(DUA
M:6QB;W@B"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT
M-C8*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T<B`B3F%M82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*
M;7-G<W1R(")T:61A:R!A9&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*;7-G<W1R(")A=&%U(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C(Q-@IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q,@IM<V=I9"`B<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ.#0*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED
M(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R(")K97-A;&%H86X@96IA86XB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P
M96QL:6YG(&5R<F]R<R(*;7-G<W1R(")K97-A;&%H86XM:V5S86QA:&%N(&5J
M86%N(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(FME<V%L86AA;B!E:F%A;B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HR,#@*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C4Q"B,L(&9U>GIY"FUS9VED
M(")Y;W5R(&)L86-K;&ES="(*;7-G<W1R(")";&%C:VQI<W0B"@HC.B!L:6(O
M1FEL=&5R+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B>6]U<B!W:&ET96QI<W0B
M"FUS9W-T<B`B5VAI=&5L:7-T(@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R]R
M;U]23RYP;P``````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`S-34R,S0`,3`T,3<S-C(W-C0`,#$W,C(R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@24U0(%)O;6%N:6%N('1R
M86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,B!(;W)D92!0<F]J96-T
M+@HC($-O<FYE;&EU($U54T%4(#QC;75S871`:V5Y<WES+G)O/BP@,C`P,BX*
M(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U0
M(#,N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R
M*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#@M,#$@,3(Z-38Z
M*S`R.C`P7&XB"B),87-T+51R86YS;&%T;W(Z($-O<FYE;&EU($U54T%4(#QC
M;75S871`:V5Y<WES+G)O/EQN(@HB3&%N9W5A9V4M5&5A;3H@4F]M86YI86X@
M/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U
M.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@("`@("!#
M8SH@(@IM<V=S='(@(B`@("`@($-A=')E.B`B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z-#$U"FUS9VED("(@("`@("!4;SH@(@IM<V=S='(@(B`@("`@($-A=')E
M.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@1&%T93H@
M(@IM<V=S='(@(B`@("!$871A.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`V
M"FUS9VED("(@("`@1G)O;3H@(@IM<V=S='(@(B`@("!$92!L83H@(@H*(SH@
M;6%I;&)O>"YP:'`Z-#(R('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3(*;7-G:60@(B!3=6)J96-T.B`B
M"FUS9W-T<B`B(%-U8FEE8W0Z("(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHW,`IM<V=I9"`B(&EN("(*;7-G<W1R("(@:6X@(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,@IM<V=I
M9"`B(R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E
M*2(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T<B`B)60@9&EN("5D
M($UE<V%J92(*"B,Z(&UA:6QB;W@N<&AP.C$W-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(&1E;&5T960N(@IM
M<V=S='(@(D%F:7-E87IA('5N(&UE<V%J(&QA(&%P;&EC87)E82!F:6QT<F5L
M;W(N(@H*(SH@;&EB+U-P86TN<&AP.C$W.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(D%C97-T(&UE<V%J(&$@9F]S="!R87!O<G1A="!!9&UI;FES=')A=&]R
M=6QU:2!C82!F:6EN9"!.961O<FET+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B06-E<W0@;65S
M86H@82!F;W-T(')A<&]R=&%T($%D;6EN:7-T<F%T;W)U;'5I(&-A(&9I:6YD
M($YE9&]R:70N(@H*(SH@;&EB+U-P86TN<&AP.C$W,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D
M(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B06-E<W0@;65S86H@82!F;W-T(')A<&]R=&%T($%D;6EN:7-T<F%T;W)U
M;'5I(&-A(&9I:6YD($YE9&]R:70N(@H*(SH@;&EB+U-P86TN<&AP.C$U,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(D%C97-T(&UE<V%J(&$@
M9F]S="!R87!O<G1A="!!9&UI;FES=')A=&]R=6QU:2!C82!F:6EN9"!.961O
M<FET+B(*"B,Z(&UA:6QB;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"`M("5D(&1I
M;B`E9"!-97-A:F4B"@HC.B!M86EL8F]X+G!H<#HV-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E
M<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@(B5S(&5X:7-T82X@1&ER96-T
M;W)U;"`E<R!N=2!A('!U='5T(&9I(')E9&5N=6UI="XB"@HC.B!L:6(O365S
M<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B5S(&YU
M('!A<F4@<V$@9FEE(&\@8V%S=71A('!O<W1A;&$@=F%L:61A+B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H
M<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@8F5I;F<@<F5N
M86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G<W1R(")$:7)E
M8W1O<G5L("5S('9A(&9I(')E9&5N=6UI="X@26YC97!U="!D92!L=6YA+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C(U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L
M:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I
M;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@=&5N=&%T
M:79E;'D@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S
M=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!<(B5S
M7"(N(@IM<V=S='(@(D1I<F5C=&]R=6P@7"(E<UPB(&$@9F]S="!R961E;G5M
M:70@8W4@<W5C8V5S(&-A(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T
M;R!A;6UE;F0@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O
M(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O
M=70@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(X-2!M97-S86=E
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC.C$S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3,S"FUS9VED("(H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T
M;R!N97AT('-C<F5E;BXI(@IM<V=S='(@(BA!<&QI8V$@;6]D:69I8V%R:6QE
M('-I(&UE<F=I(&UA:2!D97!A<G1E+BDB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED("(H1&ES8V%R9"!A;&P@8VAA;F=E
M<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI(@IM<V=S='(@
M(BA296YU;G1A(&QA(&UO9&EF:6-A<FDN($EN87!O:2!L82!F97)E87-T<F$@
M9&4@365S86H@3F]U+BDB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!497AT
M*2(*;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP:'`Z,C@P"FUS9VED("(B"B(H
M4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A
M;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O;B!T:&4@
M8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@
M(B(*(D%P;&EC82!S8VAI;6)A<FEL92!D92!P:6YA(&%C=6T@<VD@:6YT;V%R
M8V4M=&4@;&$@9F5R96%S=')A(&1E($UE<V%J($YO=2XB"B)38VAI;6)A<FEL
M92!D92!P92!P86=I;F$@8W5R96YT82!.52!V;W(@9FD@87!L:6-A=&4N(@H*
M(SH@<W!E;&QI;F<N<&AP.C(W-PHC+"!F=7IZ>0IM<V=I9"`B(@HB*%-E;F0@
M;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@
M9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E96X@=VEL;"!.
M3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(D%P;&EC82!S8VAI;6)A<FEL
M92!D92!P:6YA(&%C=6T@<VD@:6YT;V%R8V4M=&4@;&$@9F5R96%S=')A(&1E
M($UE<V%J($YO=2XB"B)38VAI;6)A<FEL92!D92!P92!P86=I;F$@8W5R96YT
M82!.52!V;W(@9FD@87!L:6-A=&4N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@(BH@061D('1H97-E(&)Y(&-L:6-K
M:6YG($]+("HB"FUS9W-T<B`B*B!!9&%U9V$@87-T96$@87!A<VEN9"!/2R`J
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,#8*;7-G
M:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@(BH@
M5&4@<F]G(&%L96=E(&%D<F5S*&$O96QE*2`J(@H*(SH@;6%I;&)O>"YP:'`Z
M,3<T"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B261E;G1I=&%T96$@7"(E<UPB(&$@9F]S="!S=&5A<G-A
M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*(RP@9G5Z>GD*;7-G:60@(C$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")!8V5S="!M97-A:B!A(&9O
M<W0@<F%P;W)T870@061M:6YI<W1R871O<G5L=6D@8V$@9FEI;F0@3F5D;W)I
M="XB"@HC.B!L:6(O4W!A;2YP:'`Z,38P"B,L(&9U>GIY"FUS9VED("(Q(&UE
M<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@
M(D%C97-T(&UE<V%J(&$@9F]S="!R87!O<G1A="!!9&UI;FES=')A=&]R=6QU
M:2!C82!F:6EN9"!.961O<FET+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S(*(RP@
M9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S
M<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D%C
M97-T(&UE<V%J(&$@9F]S="!R87!O<G1A="!!9&UI;FES=')A=&]R=6QU:2!C
M82!F:6EN9"!.961O<FET+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*(RP@9G5Z
M>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M+B(*;7-G<W1R(")!8V5S="!M97-A:B!A(&9O<W0@<F%P;W)T870@061M:6YI
M<W1R871O<G5L=6D@8V$@9FEI;F0@3F5D;W)I="XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#$Y"B,L(&9U>GIY"FUS9VED("(Q,#`@8VAA<F%C=&5R
M<R(*;7-G<W1R(")#87)A8W1E<F4@4W!E8VEA;&4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#(R"B,L(&9U>GIY"FUS9VED("(Q,#`P(&-H87)A8W1E
M<G,B"FUS9W-T<B`B0V%R86-T97)E(%-P96-I86QE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R,`HC+"!F=7IZ>0IM<V=I9"`B,C4P(&-H87)A8W1E
M<G,B"FUS9W-T<B`B0V%R86-T97)E(%-P96-I86QE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R,0HC+"!F=7IZ>0IM<V=I9"`B-3`P(&-H87)A8W1E
M<G,B"FUS9W-T<B`B0V%R86-T97)E(%-P96-I86QE(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z,38R"B,L('!H<"UF;W)M870*;7-G:60@(D$@
M;&%R9V4@:6UA9V4@;F%M960@)7,@:7,@871T86-H960@=&\@=&AI<R!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T
M:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M97-S86=E('EO=2!H879E('-E;G0@
M:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H
M92`B"B)R96-I<&EE;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!3D0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,`IM<V=I9"`B06-C97!T(')E<75E
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X
M-PIM<V=I9"`B06-C97!T(')E<75E<W0@86YD(&%D9"!I="!T;R!M>2!C86QE
M;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S4S"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,C4W"FUS9VED(")!8V-E<'1E9#H@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"B,L(&9U
M>GIY"FUS9VED(")!8V-O=6YT)W,@;F%M93HB"FUS9W-T<B`B3G5M96QE($ED
M96YT:71A=&EI.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C`@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,`HC+"!F=7IZ>0IM<V=I9"`B
M06-T:6]N<R(*;7-G<W1R(")!8W1I=6YE82(*"B,Z(&QI8B]-24U%+TAE861E
M<G,N<&AP.C(P,"!L:6(O34E-12](96%D97)S+G!H<#HR,#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%D9"`E<R!T;R!M>2!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B061A=6=A(&QA($%G96YD82`H)7,I(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`S"FUS9VED(")!9&0@<V]U<F-E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S<@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X.`IM<V=I9"`B061D('1H:7,@
M=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3(U
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB(&%S
M(&%N(&%T=&%C:&UE;G0N(@IM<V=S='(@(D%D875G82!U;B!A=&%S86UE;G0N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D
M:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\96T^
M*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE
M*3PO96T^(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@
M:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@9G5Z>GD*
M;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<R(*;7-G<W1R
M(")$871E(%!E<G-O;F%L92(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.CDS"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C
M86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R
M<F]R(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M
M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3(*;7-G
M:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9V5N9&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O
M;VMS(@IM<V=S='(@(D%G96YD82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.#D*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A9V5S
M.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@
M(@HB;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T
M:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C
M:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")!;&PB"FUS9W-T<B`B5&]A=&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S"FUS9VED("(B
M"B)!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL
M;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@(@HB9FEL93HB"FUS9W-T
M<B`B(@HB5&]A=&4@;65S86IE;&4@9&EN(&1I<F5C=&\H<G5L+V%R96QE*2!U
M<FUA=&\H<B]A<F4I('9O<B!F:2!S86QV871E(&EN='(M=6X@(@HB9FES:65R
M($U"3U@Z(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I
M;B!Y;W5R(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@
M8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB5&]A=&4@
M;65S86IE;&4@9&EN(&1I<F5C=&]R=6P@7"(E<UPB+"!M86D@=F5C:&D@9&4@
M)7,@>FEL92!V;W(@9FD@(@HB<W1E<G-E9&5F:6YI=&EV+B(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H
M<#HU.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK
M960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B
M92!D96QE=&5D+B(*;7-G<W1R("(B"B)4;V%T92!D:7)E8W1O87)E;&4@8W4@
M;65S86IE+71R:6UI<V4@;6%I('9E8VAI(&1E("5S(&QU;FD@=F]R(&9I('-T
M97)S92XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA
M:6Q?;6]N=&AL>2YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L
M9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W
M:6QL(&)E(&1E;&5T960N(@IM<V=S='(@(B(*(E1O871E(&1I<F5C=&]A<F5L
M92!C=2!M97-A:F4M=')I;6ES92!M86D@=F5C:&D@9&4@)7,@;'5N:2!V;W(@
M9FD@<W1E<G-E+B(*"B,Z(&%C;"YP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S
M9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(D1I<F5C
M=&]R=6P@7"(E<UPB(&$@9F]S="!R961E;G5M:70@8W4@<W5C8V5S(&-A(%PB
M)7-<(BXB"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L9&5R
M($-R96%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z-#@*;7-G:60@(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A
M<'!L:65D(&EN(&%N>2!M86EL8F]X/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B06QT97)N871I
M=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4W,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3@T"FUS9VED(")!;'=A>7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4U-PHC+"!F=7IZ>0IM<V=I9"`B06QW87ES('-A=F4@871T
M86-H;65N=',B"FUS9W-T<B`B061A=6=A('5N(&%T87-A;65N="XB"@HC.B!L
M:6(O365S<V%G92YP:'`Z-3`U"FUS9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D
M('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H
M92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O
M<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T92XB"FUS9W-T
M<B`B17)O87)E(&1E(&YA='5R82!N96-U;F]S8W5T82$@061A=6=A<F5A(&YU
M(&$@<F5U<VET+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#<*(RP@9G5Z>GD*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN
M9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(D5R;V%R92!D92!N871U<F$@;F5C
M=6YO<V-U=&$A($%D875G87)E82!N=2!A(')E=7-I="XB"@HC.B!M97-S86=E
M+G!H<#HU,#`@;6%I;&)O>"YP:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E
M9"(*;7-G<W1R(")#=2!287-P=6YS(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHS,0IM<V=I9"`B06YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B
M365S86IE(&-U(%)A<W!U;G,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T
M<B`B07!L:6-A(&9I;'1R96QE('!E(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<'!L
M>2!&:6QT97)S('1O("5S(@IM<V=S='(@(D%P;&EC82!F:6QT<F5L92!P92(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS-@HC+"!F=7IZ>0IM
M<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\B"FUS
M9W-T<B`B07!L:6-A(&9I;'1R96QE(&QA($-O;F5C=&%R92XB"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(D%P
M<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_
M(@IM<V=S='(@(D%P;&EC82!F:6QT<F5L92!L82!296EN<')O<W!A=&%R92XB
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(E-I
M9W5R('9R96D@<V$@9F%C:6$@87-T82`_(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@
M(B(*(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP
M86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD960A*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!D;R!T:&ES/R(*;7-G<W1R(")3:6=U<B!V<F5I('-A(&9A8VEA
M(&%S=&$@/R(*"B,Z(&UE<W-A9V4N<&AP.C0P-R!T96UP;&%T97,O;6%I;&)O
M>"]J879A<V-R:7!T+FEN8SHV.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS
M9W-T<B`B4VEG=7(@=G)E:2!S82!S=&5R9VD@9&5F:6YI=&EV(&%C97-T92!M
M97-A:F4@/R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z
M>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,
M62!D96QE=&4@=&AI<R!A='1A8VAM96YT/R(*;7-G<W1R(")3:6=U<B!V<F5I
M('-A('-T97)G:2!D969I;FET:78@86-E<W1E(&UE<V%J92`_(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`B
M4VEG=7(@=G)E:2!S82!G;VQE<W1I(&%C97-T(&1I<F5C=&]R(#\B"@HC.B!L
M:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@9F]L9&5R/R(*;7-G<W1R(")3
M:6=U<B!V<F5I('-A(&=O;&5S=&D@1W5N;VEU;"`_(@H*(SH@;&EB+TE-4"YP
M:'`Z.38V"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@
M>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(E-I9W5R('9R96D@<V$@9V]L
M97-T:2!'=6YO:75L(#\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHX"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R
M(")3:6=U<B!V<F5I('-A('-T97)G:2!D969I;FET:78@86-E<W1E(&UE<V%J
M92`_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@
M=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*(RP@9G5Z>GD*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M
M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R(")3:6=U<B!V<F5I('-A(&=O
M;&5S=&D@86-E<W0@9&ER96-T;W(@/R(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I
M<'0N:6YC.C<T"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*;7-G<W1R(")3
M:6=U<B!V<F5I('-A(&=O;&5S=&D@86-E<W0@9&ER96-T;W(@/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,38*;7-G:60@(D%R<FEV86P@5&EM92(*
M;7-G<W1R(")/<F$@<V]S:7)I:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,S$*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")#<F5S8V%T;W(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU.#,*;7-G:60@(D%S:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU,3D*;7-G:60@(D%T=&%C:"(*;7-G<W1R
M(")!=&%S96%Z82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0W-0HC+"!F=7IZ>0IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S='(@(D%T
M87-A;65N=&4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M-38*;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME
M>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]T;F5F+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(D%T=&%C:&5D($9I
M;&4Z(@IM<V=S='(@(D%T87-E87IA(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0U
M,2!L:6(O0V]M<&]S92YP:'`Z-3,V"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@
M<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S<V"FUS9VED(")!='1A8VAE
M9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ
M-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,30*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`V('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FIS.CDW"FUS9VED(")!='1A8VAM96YT(@IM<V=S
M='(@(D%T87-A;65N="(*"B,Z(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A
M9V4N<&AP.C0V-@IM<V=I9"`B071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN
M86P@871T86-H;65N="!T>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT-S,*(SH@;&EB+T-O;7!O<V4N<&AP.C$P-S,*;7-G:60@(D%T
M=&%C:&UE;G1S(@IM<V=S='(@(D%T87-A;65N=&4B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C@R"B,L(&9U>GIY"FUS9VED(")!='1E;F1E97,B
M"FUS9W-T<B`B071A<V%M96YT92(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I
M9FEC871I;VXN<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!='1E;G1I;VXB"FUS
M9W-T<B`B06-T:75N96$B"@HC.B!L:6(O075T:"]I;7`N<&AP.C0T"FUS9VED
M(")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0P"FUS
M9VED("(B"B)!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A434P@;65S
M<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*(F%D9')E<W-B;V]K
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHR.3@*(RP@9G5Z>GD*;7-G:60@(D%V86EL86)L92!!9&1R97-S(&)O
M;VMS.B(*;7-G<W1R(")!9V5N9&4@9&ES<&]N:6)I;&4Z(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<Q.0IM<V=I9"`B07=A:71I;F<@4F5S<&]N
M<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHR-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%C
M7VL@=&\@)7,B"FUS9W-T<B`B26YA<&]I(&QA("5S(@H*(SH@=&AR96%D+G!H
M<#HQ,S<@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"86-K('1O("5S(@IM<V=S='(@(DEN
M87!O:2!L82`E<R(*"B,Z('1H<F5A9"YP:'`Z,3,T"FUS9VED(")"86-K('1O
M($UU;'1I<&QE($UE<W-A9V4@5FEE=R!);F1E>"(*;7-G<W1R("(B"@HC.B!T
M:')E860N<&AP.C$S,@IM<V=I9"`B0F%C:R!T;R!4:')E860@1&ES<&QA>2(*
M;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,X-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")"860@;W(@;6%L9F]R;65D(')E<75E<W0N(%-E<G9E
M<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V
M-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,@HC.B!T96UP
M;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(P(&QI8B]396%R8V@N<&AP
M.C,T"FUS9VED(")"8V,B"FUS9W-T<B`B0V]P:64@(S(B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES('1H92!R
M87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I
M9"`B0FQA8VML:7-T(@IM<V=S='(@(DQI<W1A($YE86=R82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV,CD*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(
M5$U,(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q
M=65S=&5D/R(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HT,@IM<V=I
M9"`B0F]D>2(*;7-G<W1R(")#;W)P($UE<V%J(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")!;6EN9&]U
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#<*;7-G:60@(D)O=&@@
M2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(*;7-G:60@
M(D-?:&%R<V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE
M;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N;W0@8V]N;F5C
M="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C;VYN
M96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O
M9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@(@HB
M;6%I;&)O>"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C@T('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4U"B,Z('1E;7!L871E<R]F
M;VQD97)S+VEM<&]R="YI;F,Z,C$@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E
M:6UA9V4N:6YC.C$Y"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN
M8SHR,2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#8*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,"!T96UP;&%T97,O<&=P
M+W!A<W-P:')A<V4N:6YC.C,R"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-C8*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")296YU;G1A(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#,U"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHQ,3$*;7-G:60@(D-A;F-E;"!-97-S86=E(@IM<V=S='(@
M(E)E;G5N=&$@3&$@365S86HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G
M:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@
M9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(D1A8V$@<F5N=6YT:2!L
M82!A8V5S="!287-P=6YS+"!C;VYT:6YU='5L(&QU:2!S92!V82!P:65R9&4N
M(@H*(SH@;65S<V%G92YP:'`Z,C8U('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI
M;F,Z,34@;&EB+U-E87)C:"YP:'`Z,S`*;7-G:60@(D-C(@IM<V=S='(@(D-O
M<&EE(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,PIM<V=I9"`B
M(@HB0V5R=&EF:6-A=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@
M=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@(@HB<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Q"FUS9VED
M(")#:&%I<B!097)S;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B4V-H
M:6UB82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,0IM
M<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R(")38VAI;6)A(%1O="(*"B,Z('1E
M;7!L871E<R]A8VPO86-L+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E
M($9O;&1E<B(*;7-G<W1R(")#<F5A>F$@1&ER96-T;W(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$R"FUS9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O
M<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E
M86-H('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G
M<W1R(")/<'1I=6YI(&1E(&=E;G5L(&-I=&4@;65S86IE('9E>FD@<&4@;R!P
M86=I;F$@<VD@8W5M('-I;G0@96QE('-O<G1A=&4N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@;6%I;"!S
M97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS9W-T<B`B4V-I;6)A(&]P
M=&EU;FEL92!R969E<FET;V%R92!L82!S97)V97)U;"!D92!M86EL+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB
M"FUS9W-T<B`B4W!E8VEF:6-A(&YU;65L92P@861R97-A('-I('-E;6YA='5R
M82!C87)E('9O<B!A<&%R96$@:6X@365S86IU;"!T874N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@R-`IM<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P
M;&%Y.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHQ-0IM<V=I9"`B0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*
M;7-G<W1R(")697)I9FEC82!D86-A('-I;G0@;65S86IE(&YO:2!I;B!$:7)E
M8W1O*'(O87)E*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHW-0IM
M<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP;&%T97,O9F5T8VAM
M86EL+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K(&%L;"!M86EL('-E
M<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8S"FUS9VED(")#:&5C:R!S
M<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G:60@(D-H
M;V]S92!!8W1I;VXZ(@IM<V=S='(@(D%L96=E($%C=&EU;F5A.B(*"B,Z(&-O
M;F9I9R]S97)V97)S+G!H<"YD:7-T.C$X,@HC+"!F=7IZ>0IM<V=I9"`B0VAO
M;W-E(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@(E-C:6UB82!O<'1I=6YI;&4@
M<F5F97)I=&]A<F4@;&$@<V5R=F5R=6P@9&4@;6%I;"XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,C4@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,38V"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(Q-PIM<V=I9"`B0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D
M<F5S<R!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S
M,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%C=&EO;CHB"FUS9W-T<B`B
M06QE9V4@06-T:75N96$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S0Y"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=&AE(&%D9')E
M<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+B(*;7-G<W1R
M(")!;&%G92!A9V5N9&$@:6X@8V%R92!S92!V;W(@861A=6=A(&%D<F5S96QE
M(&YO:2XB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR
M.3,*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@;W)D97(@;V8@861D<F5S
M<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*
M;7-G<W1R(")!;&%G92!O<F1I;F5A(&1E(&-A=71A<F4@:6X@86=E;F1E+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R`E<R!T;R!C;VYV97)T('1H92!I;6%G92!F:6QE
M(&EN=&\@82!F;W)M870@>6]U<B!B<F]W<V5R(&-A;B!V:65W+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@:6UA9V4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M96YT('!A
M9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ
M,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I
M97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R
M(")#;VUP=6YE($UE<V%J($YO=2!I;B!F97)E87-T<F$@<V5P87)A=&$N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI
M<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S
M('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N
M(@IM<V=S='(@(D-O;7!U;F4@365S86H@3F]U(&EN(&9E<F5A<W1R82!S97!A
M<F%T82XB"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I
M<&%R="]R96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B
M0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(Q"B,L(&9U>GIY
M"FUS9VED("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R
M97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S('1O("(*(G-E
M87)C:"XB"FUS9W-T<B`B(@HB1F$@0VQI8VL@<&4@=6YA(&1I;B!A9V5N9&4@
M<VD@<V5L96-T96%Z82!T;V%T92!C:6UP=7)I;&4@:6X@8V%R92!V<F5I('-A
M("(*(F-A=71I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,0IM
M<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D
M9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R!T;R!3879E
M(%,O34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O
M:R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34P"FUS
M9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N
M97<@;65S<V%G92!T;R!T:&4@<V5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-3$*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A
M9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR
M.`HC+"!F=7IZ>0IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B365S86H@3F]U(@H*
M(SH@8V]M<&]S92YP:'`Z.#(X(&-O;7!O<V4N<&AP.C$Q-#@*;7-G:60@(D-L
M;W-E('1H:7,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0R
M.0IM<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G<W1R(")$:7)E8W1O<B!);F-H
M:7,B"@HC.B!F;VQD97)S+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(D-O;&QA
M<'-E(@IM<V=S='(@(E)E<W1R:6YG92!T;W0B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL(@IM<V=S
M='(@(E)E<W1R:6YG92!T;W0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T
M<B`B4F5S=')I;F=E('1O871E(&1I<F5C=&]A<F5L92XB"@HC.B!F;VQD97)S
M+G!H<#HT-#D*;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R(")297-T
M<FEN9V4@9&ER96-T;W)U;"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@26YD:6-A=&]R.B`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P,PIM<V=I9"`B0V]M;65N
M="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8Y
M"B,L(&9U>GIY"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B365S86H@3F]U
M(@H*(SH@8V]M<&]S92YP:'`Z.#(W(&-O;7!O<V4N<&AP.C$Q-#<*(RP@9G5Z
M>GD*;7-G:60@(D-O;7!O<V4@86YO=&AE<B!M97-S86=E(@IM<V=S='(@(E1R
M:6UI=&4@=6X@365S86H@3F]U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0S-`HC+"!F=7IZ>0IM<V=I9"`B0V]M<&]S92!M97-S86=E<R!I;B!A('-E
M<&%R871E('=I;F1O=S\B"FUS9W-T<B`B0V]M<'5N92!-97-A:B!.;W4@:6X@
M9F5R96%S=')A('-E<&%R871A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,
M($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92`B"B)F
M96%T=7)E*3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y
M960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PHC
M+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS
M+B(*;7-G<W1R(")38VEM8F$@;W!T:75N:6QE(')E9F5R:71O87)E(&QA('-E
M<G9E<G5L(&1E(&UA:6PN(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*
M;7-G:60@(D-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@
M(D-O;FYE8W1I;VX@=&\@<V5R=F5R(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P
M=&EO;G,@<F5L871I;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O
M;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@
M=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV
M97,N(@IM<V=S='(@(B(*(D-O;G1R;VQE87IA(&-I;F0@<V4@=F5R:69I8V$@
M9&%C82!S:6YT(&UE<V%J92!N;VD@<VD@9&%C82!V96D@9FD@<V%U(&YU("(*
M(F%N=6YT870@;&$@<V]S:7)E82!L;W(N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Y-@IM<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I
M;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:6%Z
M82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0HC+"!F=7IZ>0IM
M<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T<B`B1V]L97-T92!'=6YO:75L
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED
M(")#;W)R96-T(@IM<V=S='(@(D-O<F5C="(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ-#`*;7-G:60@(D-O<G)E8W1E9"!497AT(@IM
M<V=S='(@(E1E>'0@0V]R96-T870B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,X,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O
M;7!L971E(')E<75E<W0N(%)E87-O;B!':79E;CH@)7,B"FUS9W-T<B`B3G4@
M86T@<'5T=70@<W1E<F=E(&UE<V%J96QE(&1E(&QA("5S.B`E<R(*"B,Z(&%T
M=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O365S<V%G92YP:'`Z-C0P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V
M97(@<V%I9#H@)7,B"FUS9W-T<B`B3G4@86T@<'5T=70@<W1E<F=E(&UE<V%J
M96QE(&1E(&QA("5S.B`E<R(*"B,Z(&QI8B]397-S:6]N+G!H<#HS,3@*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!E>&5C=71E(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,N(@IM<V=S='(@(D]P97)A=&EU;FD@9&4@365N=&5N86YT82(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HU-`IM<V=I9"`B0V]U;&0@
M;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.
M148@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U
M97-T960@9FEL92!F<F]M('1H92!::7`@87)C:&EV92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+U-E<W-I;VXN<&AP.C(W,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C,Q-"!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C,Y"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C`*;7-G:60@(D-R96%T92(*;7-G
M<W1R(")#<F5A>F$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHV"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@(D-R96%Z82!$:7)E
M8W1O<B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*(RP@9G5Z>GD*
M;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(D-R96%Z82(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B0W)E
M871E(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(D-R96%Z82!$:7)E8W1O<B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V
M"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R
M969S+W-P86US96QE8W0N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@
M82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B0W)E87IA(&1I<F5C=&]R(&YO
M=2!P96YT<G4@1W5N;VDB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L
M96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR
M-`IM<V=I9"`B0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T<B`B
M0W)E87IA(&1I<F5C=&]R(&YO=2!P96YT<G4@0VEO<FYE(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR-B!T96UP;&%T97,O<')E
M9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0R"FUS9VED(")#<F5A=&4@82!N97<@
M<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")#<F5A>F$@9&ER96-T;W(@;F]U
M('!E;G1R=2!-97-A:F4M5')I;6ES92(*"B,Z('1E;7!L871E<R]P<F5F<R]T
M<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T
M+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*;7-G
M<W1R(")#<F5A>F$@9&ER96-T;W(@;F]U('!E;G1R=2!'=6YO:2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C@*;7-G:60@(B(*(D-R96%T92!F:6QT
M97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S
M;W)T(&ET(&EN=&\@9F]L9&5R<RP@(@HB86YD(&1E;&5T92!S<&%M+B(*;7-G
M<W1R("(B"B)#<F5A>F$@9FEL=')E('!E;G1R=2!O<F=A;FEZ87)E82!M97-A
M:F5L;W(@<')I;6ET92P@<V]R=&%R96$@;&]R(&EN("(*(F1I<F5C=&]A<F4@
M<VD@<W1E<F=E<F5A(&-E;&]R(&YE9&]R:71E+B(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E
M(&YE=R!S=&%T:6]N97)Y(@IM<V=S='(@(D-R96%Z82!D:7)E8W1O<B!N;W4@
M<&5N=')U($UE<V%J92U4<FEM:7-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T.0IM<V=I9"`B0W)E871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S
M<&]N<V5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A8V-E<W,@=&\@)7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I
M9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@
M;W1H97(@86-C;W5N=',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B0W5S=&]M:7IE(&AO=R!Y;W4@
M<V5N9"!M86EL+B(*;7-G<W1R(")!;&5G92!C=6T@=')I;6ET:2!M97-A:F5L
M92!S:2!U;F1E('9O<B!F:2!S86QV871E($-I;W)N96QE+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(D%L96=E(&]P97)A=&EU;FEL92!E>&5C=71A=&4@;&$@8V]N96-T87)E82!L
M82`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C$W"B,L(&9U>GIY"FUS9VED(")$871?92(*;7-G<W1R(")$871A(@H*
M(SH@;65S<V%G92YP:'`Z,C8R('1H<F5A9"YP:'`Z,30X"FUS9VED(")$871E
M(@IM<V=S='(@(D1A=&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S4W"B,L(&9U>GIY"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")3=&5R<V4B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8S"FUS9VED(")$96-L
M:6YE9#H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4W1E<F=E(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C$X
M"FUS9VED(")$969A=6QT(%-E87)C:"!&:65L9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(S"FUS9VED(")$969A=6QT('-O<G1I
M;F<@8W)I=&5R:6$Z(@IM<V=S='(@(D-R:71E<FEU(&EM<&QI8VET(&1E('-O
M<G1A<F4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,PIM<V=I9"`B
M1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B1&ER96-T:64@
M:6UP;&EC:71A(&1E('-O<G1A<F4Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<V-0HC+"!F=7IZ>0IM<V=I9"`B1&5L96=A=&5D(@IM<V=S='(@
M(E-T97)S92(*"B,Z(&9O;&1E<G,N<&AP.C0Q.2!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR-#0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z."!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FEN8SHR.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D1E
M;&5T92(*;7-G<W1R(")3=&5R9V4B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@)7,@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHX-0IM<V=I9"`B1&5L971E($-U<G)E;G0@2V5Y<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHY"FUS9VED
M(")$96QE=&4@1F]L9&5R*',I(@IM<V=S='(@(E-T97)G92!$:7)E8W1O*')U
M;"]A<F5L92DB"@HC.B!F;VQD97)S+G!H<#HR.#4*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(E-T97)G92!$:7)E
M8W1O*')U;"]A<F5L92DB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!3=&%T:6]N97)Y(@IM
M<V=S='(@(E-T97)G92!$:7)E8W1O*')U;"]A<F5L92DB"@HC.B!F;VQD97)S
M+G!H<#HT,3D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E
M<B(*;7-G<W1R(")3=&5R9V4@1&ER96-T;RAR=6PO87)E;&4I(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@
M9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E
M;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!O;&0@
M;&EN:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS
M9W-T<B`B4W1E<F=E(&1I<F5C=&]A<F5L92!C=2!-97-A:F4M5')I;6ES92!L
M82!I;F-E<'5T(&1E(&QU;F$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,U,`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&]L9"!S96YT+6UA:6P@9F]L
M9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(E-T97)G92!D
M:7)E8W1O87)E;&4@8W4@365S86IE+51R:6UI<V4@;&$@:6YC97!U="!D92!L
M=6YA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3<*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM<V=S='(@(E-T97)G92!M
M97-A:F5L92(*"B,Z(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N
M9"YI;F,Z.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R(")3=&5R<V4B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE
M<W-A9V5S(@IM<V=S='(@(DUE<V%J92!3=&5R<V4B"@HC.B!C;VUP;W-E+G!H
M<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@=&AE
M(&%T=&%C:&UE;G0@7"(E<UPB+B(*;7-G<W1R(")3=&5R9V4@=6X@871A<V%M
M96YT+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B1&5L
M971I;F<@86YD($UO=FEN9R!-97-S86=E<R(*;7-G<W1R(")/<'1I=6YI($UU
M=&%R92P@0V]P:65R92P@4W1E<F=E<F4@;65S86IE+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.3(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30P"FUS9VED
M(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,R"FUS9VED(")$
M97-C96YD:6YG(@IM<V=S='(@(D1E<V-R97-C871O<B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C8Y"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S<*;7-G:60@(D1E=&%I;',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8W-PIM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM<V=S='(@
M(D1I;2!S:6=N871U<F5S("T@9&4@=')A9'5S(#\B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G
M<W1R(")!9FES96%Z82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-SD*
M;7-G:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M
M97-S86=E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C@V"FUS9VED(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_
M(@IM<V=S='(@(D%N=6YT82UM82!C:6YD(&%M(&UE<V%J92!N;VDN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES<&QA>2!T:&4@
M7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES<&QA
M>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS9W-T<B`B3W!T
M:75N:2!D92!A9FES87)E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C(V"FUS9VED(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#
M:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(DYU('9E<FEF
M:6-A(&1A8V$@<VEN="!M97-A:F4@;F]I(&EN($1I<F5C=&\H<B]A<F4I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E
M;F5R871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(B(*
M"B,Z(&QI8B])35`N<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P
M96X@=&AA="!F;VQD97(_(@IM<V=S='(@(E9R96D@<V$@9&5S8VAI>FD@86-E
M;"!$:7)E8W1O<B`_(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M,S(*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R
M-@IM<V=I9"`B1&]N92(*;7-G<W1R(")'871A(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E
M<R!I;B`N>FEP($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]H96%D97)S+FEN8SHU,@IM<V=I9"`B1&]W;FQO860@06QL($%T=&%C
M:&UE;G1S("AI;B`N>FEP(&9I;&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS9VED(")$;W=N;&]A9"!&;VQD
M97(H<RDB"FUS9W-T<B`B4V%L=F5A>F$@1&ER96-T;RAR=6PO87)E;&4I(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*(RP@9G5Z>GD*
M;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=(@IM<V=S
M='(@(E-A;'9E87IA($1I<F5C=&\H<G5L+V%R96QE*2(*"B,Z(&QI8B]-24U%
M+T-O;G1E;G1S+G!H<#HQ.3(*;7-G:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R
M;6%T(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,2!M86EL8F]X+G!H
M<#HW,3D@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(R('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHY"FUS9VED(")$<F%F="(*;7-G<W1R(")#:6]R;F4B"@HC
M.B!F;VQD97)S+G!H<#HS.3(*(RP@9G5Z>GD*;7-G:60@(D1R869T(&9O;&1E
M<B(*;7-G<W1R(")$:7)E8W1O<B!C=2!#:6]R;F4Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD
M97(Z(@IM<V=S='(@(D1I<F5C=&]R(&-U($-I;W)N93HB"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3`X"B,L(&9U>GIY"FUS9VED(")%+6UA:6P@061D
M<F5S<R(*;7-G<W1R(")!9')E<V$@9&4@16UA:6PB"@HC.B!L:6(O36%I;&)O
M>"YP:'`Z,S`Y"FUS9VED(")%3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2.B!9;W5R(&UE<W-A
M9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ
M.0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(D5D:70@0FQA8VML:7-T
M(@IM<V=S='(@(DQI<W1A($YE86=R82(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B161I="!&:6QT97)S(@IM
M<V=S='(@(D9I;'1R92!-97-A:F4B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$V"FUS9VED(")%9&ET(%9I<G1U
M86P@1F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE
M861E<BYI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L
M($9O;&1E<B!$969I;FET:6]N(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L
M:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*;7-G
M<W1R(")38VAI;6)A(%)E9W5L:6QE(&1E($9I;'1R87)E(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$S"FUS9VED(")%9&ET('EO=7(@9FEL
M=&5R(')U;&5S(@IM<V=S='(@(E-C:&EM8F$@4F5G=6QI;&4@9&4@1FEL=')A
M<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8Q"FUS9VED(")%9&ET
M('EO=7(@<')E9F5R96YC97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C
M8V]U;G1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(D5D:70@>6]U<B!W:&ET96QI<W0B
M"FUS9W-T<B`B4V-H:6UB82!296=U;&EL92!D92!&:6QT<F%R92(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,Y"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!D92!%;6%I;"(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HV-3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5M
M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(D%U(&9O<W0@
M<W1E<G-E('1O871E(&UE<V%J96QE(&1I;B`E<RXB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHR,@IM<V=I9"`B16UP='D@1F]L9&5R*',I
M(@IM<V=S='(@(D=O;&5S=&4@1&ER96-T;RAR=6PO87)E;&4I(@H*(SH@9F]L
M9&5R<RYP:'`Z,C@V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!396QE8W1E9"!&
M;VQD97)S(@IM<V=S='(@(D=O;&5S=&4@1&ER96-T;RAR=6PO87)E;&4I(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M
M<'1Y(%1R87-H(&9O;&1E<B(*;7-G<W1R(")';VQE<W1E($=U;F]I=6PB"@HC
M.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%]3<&%M
M(@IM<V=S='(@(D=O;&5S=&4@1W5N;VEU;"(*"B,Z(&QI8B])35`N<&AP.CDV
M-@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@7U1R87-H(@IM<V=S='(@(D=O;&5S
M=&4@1W5N;VEU;"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ('1E;7!L
M871E<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4$=0(&9U
M;F-T:6]N86QI='D_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHV"FUS
M9VED(")%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3$*;7-G:60@(D5N86)L92!M
M97-S86=E('!R979I97=S/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT-#(*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO
M;G,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q
M-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4W"FUS9VED(")%;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,X-`HC+"!F=7IZ>0IM<V=I
M9"`B16YD(&9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(D-O<&EE($UE<V%J
M('1R:6UI<V$@9&4@)7,B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0Q"B,L(&9U
M>GIY"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R(")-97-A:F4@5F5C:&DB
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(D-O<&EE($UE
M<V%J('1R:6UI<V$@9&4@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B16YT97(@
M4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A
M;7-E;&5C="YI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B16YT97(@=&AE(&YA;64@
M9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(DEN=')O9'4@;G5M
M96QE(&YO=6QU:2!$:7)E8W1O<B!'=6YO:2`B"@HC.B!T96UP;&%T97,O<')E
M9G,O9F]L9&5R<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R("));G1R;V1U(&YU
M;65L92!N;W5L=6D@9&ER96-T;W(@8W4@0VEO<FYE(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR,PIM<V=I9"`B16YT97(@=&AE
M(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B
M26YT<F]D=2!N=6UE;&4@;F]U;'5I(&1I<F5C=&]R(&-U($UE<V%J92U4<FEM
M:7-E(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHY"FUS
M9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R
M(@IM<V=S='(@(DEN=')O9'4@;G5M96QE(&YO=6QU:2!$:7)E8W1O<B!'=6YO
M:2`B"@HC.B!L:6(O4V5A<F-H+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B16YT
M:7)E($UE<W-A9V4B"FUS9W-T<B`B4F5D:7)E8W1E87IA(@H*(SH@;65S<V%G
M92YP:'`Z,3DT(&-O;7!O<V4N<&AP.C$Q,S0@=&AR96%D+G!H<#HW,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!
M9')E<V$@7"(E<UPB(&$@9F]S="!A9&%U9V%T82!C=2!S=6-C97,@;&$@06=E
M;F1A+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X-@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R;V%R92(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z-#4T"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S(#H@)7,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,#D@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B179E;G0@
M<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(D1I<F5C=&]R=6P@7"(E
M<UPB(&$@9F]S="!S=&5R<R!C=2!S=6-C97,N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R
M("),82`Q-2!M:6YU=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<Y
M"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DQA(#,P('-E8W5N
M9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q"FUS9VED(")%=F5R
M>2`U(&UI;G5T97,B"FUS9W-T<B`B3&$@-2!M:6YU=&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S@S"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS
M9W-T<B`B3&$@,2\R(&]R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("));B!F:65C87)E(&UI
M;G5T(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B1&5S9F%S;V%R82!4;W0B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R
M(")$97-F87-O87)A(%1O="(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C,X"FUS9VED(")%>'!A;F0@06QL($9O;&1E<G,B"FUS9W-T<B`B
M1&5S9F%S;V%R82!4;V%T92!$:7)E8W1O87)E;&4B"@HC.B!F;VQD97)S+G!H
M<#HT-3<*;7-G:60@(D5X<&%N9"!&;VQD97(B"FUS9W-T<B`B1&5S9F%S;V%R
M82!$:7)E8W1O<G5L(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,PIM<V=I
M9"`B17AP86YD($YA;65S(@IM<V=S='(@(D-O;7!L971E87IA(&%D<F5S82!D
M:6X@06=E;F1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-C,*;7-G
M:60@(D5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA
M=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDX,`HC+"!F=7IZ>0IM<V=I9"`B17AP86YD
M('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L
M9&5R<R!V:65W/R(*;7-G<W1R(")$97-F87-O87)A($%R8F]R96QE(&1E($1I
M<F5C=&]A<F4@:6X@9F5R96%S=')A(&1E($1I<F5C=&]A<F4N(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$P
M,0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(D1E<V9A<V]A
M<F$@5&]T(@H*(SH@;&EB+TE-4"YP:'`Z.3@T(&QI8B])35`N<&AP.CDX-@HC
M+"!F=7IZ>0IM<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T<B`B365S86IE($YO
M:2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"B,L(&9U>GIY"FUS9VED(")&971C
M:"!-86EL(@IM<V=S='(@(DUE<V%J92!.;VDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#8Y"B,L(&9U>GIY"FUS9VED(")&971C:"!-86EL(&EN(&$@
M<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")#;VUP=6YE($UE<V%J($YO=2!I
M;B!F97)E87-T<F$@<V5P87)A=&$N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C0V"B,L(&9U>GIY"FUS9VED(")&971C:"!M97-S86=E
M<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(D%P;&EC82!F:6QT<F5L92!L
M82!#;VYE8W1A<F4N(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D("5D(&UE<W-A9V5S(&9R
M;VT@)7,B"FUS9W-T<B`B074@9F]S="!S=&5R<V4@=&]A=&4@;65S86IE;&4@
M9&EN("5S+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*
M;7-G<W1R(")#;W!I92!-97-A:B!T<FEM:7-A(&1E("5S(@H*(SH@;&EB+T9E
M=&-H;6%I;"YP:'`Z,C@U(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T
M8VAM86EL+G!H<#HR.#D*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B1F5T
M8VAM86EL.B!N;R!N97<@;65S<V%G97,N(@IM<V=S='(@(B`M("1N;2!M97-A
M:F4@;F]I(@H*(SH@;&EB+TE-4"YP:'`Z.3DP"B,L(&9U>GIY"FUS9VED(")&
M:5]L=&5R<R(*;7-G<W1R(")&:6QT<F4B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B1FEL=')E
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"B,L(&9U>GIY
M"FUS9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(")!;'1E($]P=&EU;FDB
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0HC+"!F=7IZ>0IM
M<V=I9"`B1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(E)E9W5L:2!D92!&:6QT
M<F%R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#`*(RP@9G5Z>GD*
M;7-G:60@(D9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B
M"FUS9W-T<B`B06-T:79E87IA(&9I;'1R=2!C=79I;G1E(&-E;GIU<F%T92`A
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHQ,0IM<V=I
M9"`B1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')E(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O;F]T86-T:79E+FEN8SHS"FUS9VED(")&:6QT97)S($Y/5"!!8W1I
M=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`U"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X
M-@IM<V=I9"`B1FEN9"(*;7-G<W1R(")'87-E<W1E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP-0HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@36%I;&)O
M>"!086=E(@IM<V=S='(@(E!R:6UA(%!A9VEN82(*"B,Z(&UA:6QB;W@N<&AP
M.C,T-0IM<V=I9"`B1FER<W0@4&%G92(*;7-G<W1R(")0<FEM82!086=I;F$B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G
M:60@(D9O7W)W87)D(@IM<V=S='(@(E1R:6UI=&4@0V]P:64B"@HC.B!F;VQD
M97)S+G!H<#HR-C8@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M
M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S`S('1E;7!L871E<R]F;VQD
M97)S+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E
M<V5L96-T+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E
M;&5C="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T<B`B
M1&ER96-T;V%R92(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"B,L(&9U
M>GIY"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R(")&96)R=6%R:64B
M"@HC.B!A8VPN<&AP.C(T"FUS9VED(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@
M96YA8FQE9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-C(*;7-G:60@
M(D9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-CD*;7-G:60@(D9O<FUA="!O9B!M97-S
M86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A
M=&5D('1O9&%Y(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C<X,"!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A<F0B"FUS
M9W-T<B`B5')I;6ET92!#;W!I92(*"B,Z(&-O;7!O<V4N<&AP.C<V-0IM<V=I
M9"`B1F]R=V%R9#HB"FUS9W-T<B`B5')I;6ET92!#;W!I92(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HS-CD*(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1E9"!M97-S
M86=E(@IM<V=S='(@(D-O<&EE($UE<V%J('1R:6UI<V$@9&4@)7,B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D9O<G=A
M<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B0V]P:64@365S86H@=')I
M;6ES82!D92`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*
M(RP@9G5Z>GD*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R
M(")/<'1I=6YI(%-E<G9E<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.30*;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@
M4F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#`Q"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C(W"B,L(&9U>GIY"FUS9VED(")&<F]?;2(*;7-G<W1R(")$92!L82(*
M"B,Z(&UE<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T.2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM
M<V=I9"`B1G)O;2(*;7-G<W1R(")$92!L82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R(")%>'!E
M9&ET;W(B"@HC.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP:'`Z-S@Q"B,L
M(&9U>GIY"FUS9VED(")&=V0Z(@IM<V=S='(@(E1R:6UI=&4@0V]P:64B"@HC
M.B!C;VUP;W-E+G!H<#HQ,CDT"B,L(&9U>GIY"FUS9VED(")&=V0Z("(*;7-G
M<W1R(")4<FEM:71E($-O<&EE(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1G=D.B`E=2!&;W)W87)D960@365S
M<V%G97,B"FUS9W-T<B`B0V]P:64@365S86H@=')I;6ES82!D92`E<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.`HC+"!F=7IZ>0IM<V=I9"`B1V5N97)A;"!/<'1I;VYS
M(@IM<V=S='(@(D%L=&4@3W!T:75N:2(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHS-PIM<V=I9"`B1V5T(&]N;'D@;F5W(&UE<W-A9V5S
M/R`H24U!4"!O;FQY*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHS,0IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@=&AR
M96%D+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(D=O('1O($UE<W-A9V4B"FUS
M9W-T<B`B365S86IU;"!5<FUA=&]R(@H*(SH@;&EB+TE-4"YP:'`Z-#DX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")';R!T;R!A9&1R97-S(&)O;VL@
M96YT<GD@;V8@7"(E<UPB(@IM<V=S='(@(D%D875G82!L82!!9V5N9&$@*"5S
M*2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,S4*;7-G:60@(D=R86YT
M(&%C8V5S<R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-#8@;&EB+T9I
M;'1E<BYP:'`Z,3`U(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P,B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HQ,#0*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,38S(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(SH@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T
M960N<&AP.C<Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X"B,Z(&QI
M8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,3<S"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$R,"!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%
M4D4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C,Q(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,3<*(SH@;&EB+TU)
M344O5FEE=V5R+W)E;&%T960N<&AP.C@P"FUS9VED(")(5$U,(@IM<V=S='(@
M(B(*"B,Z(&-O;7!O<V4N<&AP.C(U-@IM<V=I9"`B2%1-3"!697)S:6]N(&]F
M($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A
M9&5R<RYI;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES
M('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V.`IM<V=I9"`B2&ED9&5N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C<*;7-G:60@
M(DAI9&1E;B!I;B!4:')E860@5FEE=R(*;7-G<W1R("(B"@HC.B!M86EL8F]X
M+G!H<#HS-C<*;7-G:60@(DAI9&4@1&5L971E9"(*;7-G<W1R(")!<V-U;F1E
M($UE<V%J92U3=&5R<V4B"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(DAI
M9&4@56YS=6)S8W)I8F5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(Y-`IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC
M.B!M97-S86=E+G!H<#HR.3<@;6%I;&)O>"YP:'`Z-S(T('1E;7!L871E<R]M
M86EL8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI9V@@4')I;W)I='DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDS
M"FUS9VED(")(:6=H97-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV.#@*;7-G:60@(DAO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y
M(&%T=&%C:&UE;G1S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U
M;W1E9"!L:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(D-I=&%T96QE(&1I;B!-
M97-A:G5L+5)A<W!U;B!V;W(@9FD@;6%R8V%T92!C=3HB"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C$S-`IM<V=I9"`B24U!4"(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H075T
M;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E
M<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38V
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V97(@
M4U-,(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,34R
M"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T
M92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-C<*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R
M("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!4"!S
M97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-
M86EL(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.#8V"FUS
M9VED("))3D)/6"(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V
M92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ
M,3(*(RP@9G5Z>GD*;7-G:60@(DEF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A
M9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(2(*;7-G<W1R(")4
M;V%T92!M97-A:F5L92!D:6X@9&ER96-T;RAR+V%R92D@<V4@=F]R('!I97)D
M92$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#(*;7-G
M:60@(DEG;F]R92(*;7-G<W1R("))9VYO<F$B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z.#,*;7-G:60@(DEG;F]R92!!;&PB"FUS9W-T
M<B`B26=N;W)A('1O="(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM
M86=E+FEN8SHX"FUS9VED("));6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P"B,L(&9U>GIY"FUS9VED("));7!O
M<G0B"FUS9W-T<B`B26UP;W)T86YT92(*"B,Z('1E;7!L871E<R]S;6EM92]I
M;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC
M.C8U"B,L(&9U>GIY"FUS9VED("));7!O<G0@2V5Y(@IM<V=S='(@(DEM<&]R
M=&%N=&4B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y"B,L(&9U>GIY
M"FUS9VED("));7!O<G0@2V5Y<&%I<B(*;7-G<W1R("));7!O<G1A;G1E(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C<*(RP@9G5Z>GD*
M;7-G:60@(DEM<&]R="!-97-S86=E<R(*;7-G<W1R(")-97-A:F4@26UP;W)T
M86YT92(*"B,Z('!G<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3$*;7-G
M:60@(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("));7!O
M<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26UP;W)T(%!E
M<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4&5R<V]N
M86P@4R]-24U%($-E<G1I9FEC871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O<&=P+FEN8SHT
M,@IM<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4'5B
M;&EC(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@4R]-24U%($ME
M>2(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3
M+TU)344@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM
M<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@
M)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,B!M86EL8F]X+G!H
M<#HW,S0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHW
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,38@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP;&%T97,O;6%I;&)O>"]L
M96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R("));7!O<G1A
M;G1E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B
M26UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(DUE<V%J92!);7!O<G1A;G1E
M(@H*(SH@9F]L9&5R<RYP:'`Z,38W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R(")!
M=2!F;W-T('-T97)S92!T;V%T92!M97-A:F5L92!D:6X@)7,N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,PIM<V=I9"`B26X@4')O8V5S<R(*
M;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS.#0@;&EB+T9O;&1E<BYP:'`Z
M.#8@;&EB+T9O;&1E<BYP:'`Z,C$T(&QI8B])35`N<&AP.C,Q,PHC.B!L:6(O
M24U!4"]4<F5E+G!H<#HQ,30@;&EB+TE-05`O5')E92YP:'`Z,C$Y"FUS9VED
M("));F)O>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#DR"B,L(&9U>GIY"FUS9VED("));F-L=61E(&$@8G)I968@<W5M;6%R>2!O
M9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM<V=S='(@(DEN8VQU9&4@;65S
M86IU;"!O<FEG:6YA;"!I;B!R87-P=6YS+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.#<*;7-G:60@(DEN8VQU9&4@;W)I9VEN86P@;65S<V%G92!I
M;B!A(')E<&QY/R(*;7-G<W1R("));F-L=61E(&UE<V%J=6P@;W)I9VEN86P@
M:6X@<F%S<'5N<RXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HV,2!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,S`*(RP@9G5Z
M>GD*;7-G:60@(DEN9F\B"FUS9W-T<B`B26=N;W)A(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC
M($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*
M;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!0
M97)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU,#<*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:G,Z.3@*;7-G:60@(DEN;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I
M9FEC871E($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A=&4@
M4$=0($ME>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z,3`*;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@
M4$=0($ME>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q
M,@IM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M
M<&]N96YT+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O
M>"YP:'`Z-C(V"B,L(&9U>GIY"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS
M9W-T<B`B061R97-A(&1E($5M86EL(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B"FUS9W-T
M<B`B(@H*(SH@8V]M<&]S92YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@
M(DEN=F%L:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@<VUI;64N<&AP.C@R('!G<"YP:'`Z,38*;7-G:60@(DEN
M=F%L:60@:V5Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3DV"FUS9VED("))
M;G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*
M(SH@<&=P+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!U
M8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME
M>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$S-PIM<V=I9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG
M('1I;64@=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE
M<F%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C,U('1E;7!L871E<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM
M<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA
M8FQE9"!O;B!T:&ES('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHS-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,SD*
M;7-G:60@(B(*(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA
M=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@(@HB8V]N
M=&%C=',N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S$X"FUS9VED(")+97D@
M<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$V"FUS
M9VED("),86YG=6%G92(*;7-G<W1R("),:6UB82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,#8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@36%I;&)O>"!0
M86=E(@IM<V=S='(@(E5L=&EM82!086=I;F$B"@HC.B!M86EL8F]X+G!H<#HS
M-3@*;7-G:60@(DQA<W0@4&%G92(*;7-G<W1R(")5;'1I;6$@4&%G:6YA(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@Y"B,L(&9U>GIY
M"FUS9VED("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R(")!=&%S86UE;G1E
M(@H*(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C$P-C,*
M;7-G:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3`X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("),:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X,@IM<V=I9"`B(@HB3&ES="!A
M;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E96X_
M("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@(@HB;VYL>2!S964@8V]N=&%C=',@
M=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@U"FUS9VED("),:7-T:6YG(&EN
M('1H92!(96%D97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C,P"B,L(&9U>GIY"FUS9VED("),;V-A;"!-86EL8F]X
M.B(*;7-G<W1R(")#87-U=&$@9&4@365S86IE(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8W-`HC+"!F=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B06-T:75N96$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(R-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D-O;F5C=&%R92(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&]G(&EN('1O("5S(@IM<V=S='(@(D-O;F5C=&%R92!L82`E<R(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,W"B,L(&9U>GIY"FUS9VED("),
M;V=I;B(*;7-G<W1R(")#;VYE8W1A<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(D%C=&EU;FD@
M;&$@0V]N96-T87)E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,CDV"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z
M,CDY(&UA:6QB;W@N<&AP.C<R-R!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N
M:6YC.C$S"FUS9VED("),;W<@4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H
M<#HT-`HC+"!F=7IZ>0IM<V=I9"`B36%C:6YT;W-H($9I;&4B"FUS9W-T<B`B
M1FEL=')E($UE<V%J92(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E
M+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B36%I;"(*;7-G<W1R(")#87-U=&$@
M9&4@365S86IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"B,L(&9U
M>GIY"FUS9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(D9I;'1R92!-97-A
M:F4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM
M<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I;&)O>"(*
M;7-G<W1R(")#87-U=&$@9&4@365S86IE(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R
M($1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")/<'1I=6YI(&1E(&%F:7-A<F4B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B
M36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%-E96XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@
M(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S`*;7-G:60@(DUA
M<FL@87,Z(@IM<V=S='(@(DUA<F-H96%Z83HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C4P"FUS9VED(")-87)K(&1I9F9E<F5N="!L979E;',@;V8@
M<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_(@IM<V=S='(@(DUA<F-H
M96%Z82!D:69E<FET92!N:79E;&4@9&4@8VET87)E(&-U(&1I9F5R:71E(&-U
M;&]R:2XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*
M;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U.`IM<V=I9"`B
M36%R:R!S:6UP;&4@;6%R:W5P/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@(DUA=&-H($%L;"!1=65R:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT
M,@IM<V=I9"`B36%T8V@@06YY(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PHC+"!F=7IZ>0IM<V=I9"`B
M36%X:6UU;2!!='1A8VAM96YT(%-I>F4B"FUS9W-T<B`B071A<V%M96YT(@H*
M(SH@;&EB+V%P:2YP:'`Z-SD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($9O
M;&1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#DT"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT
M<R!R96%C:&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT.#D*;7-G:60@(DUA>&EM=6T@=&]T86P@871T86-H;65N
M="!S:7IE(')E86-H960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,C8*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S4*(RP@
M9G5Z>GD*;7-G:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`B3W!T
M:75N:2!397)V97(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@U
M"FUS9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,3<*;7-G:60@(DUE971I;F<@4F5P;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y.`IM
M<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8P,PIM<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q
M=65S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H
M<#HS"B,L(&9U>GIY"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@
M(D1E<V-H:61E(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S
M<V%G92(*;7-G<W1R(")-97-A:B(*"B,Z(&-O;7!O<V4N<&AP.C4V,"!C;VUP
M;W-E+G!H<#HU.#<@8V]M<&]S92YP:'`Z-C0Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO;B(*;7-G<W1R(")#
M;VUP=6YE($UE<V%J($YO=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,3<*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G<W1R(")$871A(%-O<VER:6DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#D@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#<@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DUE<W-A
M9V4@3W!T:6]N<R(*;7-G<W1R(")-97-A:BAU;"]E;&4I(&EN(@H*(SH@<V5A
M<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@4V5A<F-H(@IM<V=S='(@(D-A
M=71A($UE<V%J=6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS
M9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`B36%R:6UE($UE<V%J(@H*(SH@
M;65S<V%G92YP:'`Z,S@T"FUS9VED(")-97-S86=E(%-O=7)C92(*;7-G<W1R
M(")3=7)S82!-97-A:G5L=6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C8*;7-G:60@(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R(")&:6QT<F%R92!#
M;VYT:6YU="(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-@IM<V=I
M9"`B365S<V%G92!F;&%G<R(*;7-G<W1R(")-87)C871E(&-A(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD
M97)S(@IM<V=S='(@(DEN($1I<F5C=&]A<F5L92(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@
M9G)O;2`E<R(*;7-G<W1R("));B!$:7)E8W1O87)E;&4B"@HC.B!M86EL8F]X
M+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C:&UE
M;G1S(@IM<V=S='(@(E-T97)G92!U;B!A=&%S86UE;G0N(@H*(SH@;6%I;&)O
M>"YP:'`Z-C4X"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E
M9"(*;7-G<W1R(")#:6UP=7)I;&4@365S86IU;'5I(@H*(SH@;6%I;&)O>"YP
M:'`Z-C4S"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G
M<W1R(")#:6UP=7)I;&4@365S86IU;'5I(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]H96%D97(N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&UA=&-H
M97,B"FUS9W-T<B`B1&%T82!3;W-I<FEI(@H*(SH@8V]M<&]S92YP:'`Z.#(T
M(&-O;7!O<V4N<&AP.C@S.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!R961I
M<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B365S86H@=')I;6ES(&-U
M('-U8V-E<R!D87(@;F5S86QV870@:6XB"@HC.B!C;VUP;W-E+G!H<#HQ,#@T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@<W5C
M8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@(DUE<V%J
M('1R:6UI<R!C=2!S=6-C97,@9&%R(&YE<V%L=F%T(&EN(@H*(SH@8V]M<&]S
M92YP:'`Z,3$T,R!C;VUP;W-E+G!H<#HQ,34X"B,L(&9U>GIY"FUS9VED(")-
M97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")-97-A:B!T<FEM
M:7,@8W4@<W5C8V5S(&1A<B!N97-A;'9A="!I;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H
M92!M86EL8F]X('9I97<N(@IM<V=S='(@(FUE<V%J92!P92!O('!A9VEN82XB
M"@HC.B!M86EL8F]X+G!H<#HS,C(*;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S
M='(@(DUE<V%J*'5L+V5L92D@:6XB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z,CD*;7-G:60@(DUO9&EF>2(*;7-G<W1R(")-;V1I9FEC82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHU,`IM<V=I9"`B36]V92(*;7-G<W1R(")-=71A(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$V"B,L(&9U>GIY"FUS9VED(")-
M;W9E(&1O=VXB"FUS9W-T<B`B36%I($IO<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV,3@*;7-G:60@(DUO=F4@<W!A;2!M97-S86=E<R!T;R!S<&%M
M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@24Y"3U@B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"B,L(&9U>GIY
M"FUS9VED(")-;W9E('1O(&9O;&1E<B(*;7-G<W1R(")A;&5G92!U;F1E(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$T"B,L(&9U
M>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@(DUA:2!3=7,B"@HC.B!L:6(O
M34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$R-PIM<V=I9"`B375L=&EP
M87)T+V%L=&5R;F%T:79E(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z-S8@
M=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(DUU;'1I<&QE($UE<W-A
M9V4@5FEE=R(*;7-G<W1R(")&:6QT<F%R92!#;VYT:6YU="(*"B,Z('1E;7!L
M871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHU"FUS9VED(").
M3TY%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHT."!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S@@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B3F%M92(*;7-G<W1R(").=6UE
M(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A
M;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<W.`HC+"!F=7IZ>0IM<V=I9"`B3F5E9',@06-T:6]N(@IM
M<V=S='(@(D%C=&EU;F5A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W
M,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@R"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-S@*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI8VEO9&%T82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C`*(RP@9G5Z>GD*;7-G:60@
M(DYE=F5R('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B4W1E<F=E('5N(&%T
M87-A;65N="XB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED
M(").97<B"FUS9W-T<B`B3F]I(@H*(SH@;&EB+TE-4"YP:'`Z-38S"B,L(&9U
M>GIY"FUS9VED(").97<@1F]L9&5R(@IM<V=S='(@(D1E<V-H:61E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@36%I;"(*;7-G
M<W1R(")-97-A:F4@3F]I(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y
M(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED
M(").97<@365S<V%G92(*;7-G<W1R(")-97-A:G5L(%5R;6%T;W(B"@HC.B!M
M86EL8F]X+G!H<#HW-S8@;&EB+TU)344O2&5A9&5R<RYP:'`Z,3DR"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G
M<W1R(")-97-A:F4@3F]I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHQ.0IM<V=I9"`B3F5W(&UE<W-A9V5S(@IM<V=S='(@(DUE<V%J92!.;VDB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S"FUS9VED
M(").97AT(@IM<V=S='(@(E5R;6%T;W)U;"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G
M92(*;7-G<W1R(")-97-A:G5L(%5R;6%T;W(B"@HC.B!M86EL8F]X+G!H<#HS
M-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(")086=I;F$@57)M871O87)E
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30R(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-S<*;7-G:60@(DYO(@IM<V=S='(@(DYU(@H*
M(SH@<VUI;64N<&AP.C(R-@IM<V=I9"`B3F\@0V5R=&EF:6-A=&4@9F]U;F0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T
M+FEN8SHU"FUS9VED(").;R!%;F-R>7!T:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I;B!+97ER
M:6YG(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C,W-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B"FUS9W-T<B`B365S86IE
M($YO:2(*"B,Z('!G<"YP:'`Z,3,W"FUS9VED(").;R!01U`@<'5B;&EC(&ME
M>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHX-`IM<V=I9"`B3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E
M<V5N="(*;7-G<W1R("(B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S(Y"B,L(&9U
M>GIY"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`B5&5X="!#;W)E
M8W1A="(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G:60@
M(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H
M<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3`*(RP@
M9G5Z>GD*;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R(")!
M=&%S86UE;G1E(@H*(SH@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#`*;7-G:60@
M(DYO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K
M97DN(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-S(@86-L+G!H<#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@9F]L9&5R('-E;&5C=&5D+B(*;7-G<W1R(").=2!S
M+6$@<W!E8VEF:6-A="!D:7)E8W1O<G5L(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$T,0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME
M9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C(Q
M."!L:6(O1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED
M(").;R!F;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(DYU(',M82!S
M<&5C:69I8V%T(&1I<F5C=&]R=6PB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,30W"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@;F5W(&UE
M<W-A9V5S(@IM<V=S='(@(DUE<V%J92!.97-T97)S92(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@
M=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`B365S86IE($YE<W1E<G-E
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R-0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M;65S<V%G92!B;V1Y('1E>'0B"FUS9W-T<B`B;75T82!M97-A:G5L(&EN(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,W,0HC+"!F=7IZ>0IM<V=I9"`B3F\@;65S
M<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B3G4@874@9F]S
M="!G87-I=&4@;65S86IE(&-O<F5S<'5N>F%T;V%R92(*"B,Z('!G<"YP:'`Z
M,3@Y"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T
M960N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,38U"FUS9VED(").;R!P97)S
M;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@
M<VUI;64N<&AP.C(P,0IM<V=I9"`B3F\@<&5R<V]N86P@4R]-24U%(&-E<G1I
M9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N<&AP
M.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@(DYU
M(&5X:7-T82!G<F5S96QI(&1E('-C<FEE<F4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*
M;7-G<W1R(").=2!E>&ES=&$@<W5G97-T:6DB"@HC.B!L:6(O24U!4"]#;&EE
M;G0N<&AP.C4V-`IM<V=I9"`B3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC
M871I;VX@;65T:&]D(&-O=6QD(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A
M8VPN<&AP.C8X(&%C;"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO('5S97(@
M<W!E8VEF:65D+B(*;7-G<W1R(").=2!S+6$@<W!E8VEF:6-A="!D:7)E8W1O
M<G5L(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P.0IM<V=I9"`B
M3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,3$@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L
M96-T+FEN8SHT,`HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS-2!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B3F]N92(*;7-G<W1R
M(").:6-I(%5N82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y-0IM<V=I9"`B3F]R;6%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS.0IM<V=I9"`B3F]T($1E;&5T960B"FUS9W-T<B`B3F5S=&5R<V4B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$R
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM<V=S
M='(@(D-U<F%T92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$W"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@(DYO="!)
M;7!O<G1A;G0B"FUS9W-T<B`B3F5I;7!O<G1A;G1E(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T(%!E<G-O;F%L(@IM
M<V=S='(@(DYE(%!E<G-O;F%L(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z,3,Y
M(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP="]334E-12YP:'`Z
M,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED(").;W0@
M9&5L971E9"!M97-S86=E<R(*;7-G<W1R(")-97-A:F4@3F5S=&5R<V4B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED(").;W0@:6UP
M;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(DUE<V%J92!.96EM<&]R=&%N=&4B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP
M.C<Q"FUS9VED(").;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I;64B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q-@HC+"!F
M=7IZ>0IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R(")#:71A="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S<*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O
M9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E
M;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(F1I<F5C=&]A<F4@8W4@365S86IE
M+51R:6UI<V4@<V4@=F]R('!A<W1R82!L82!I;F-E<'5T=6P@;'5N:6DN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U.0HC+"!F=7IZ>0IM<V=I9"`B
M3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E
M;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(F1I<F5C=&]A<F4@8W4@365S86IE
M+51R:6UI<V4@<V4@=F]R('!A<W1R82!L82!I;F-E<'5T=6P@;'5N:6DN(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-30@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4U,@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S,S"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V9I96QD<RYI;F,Z-2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT.`IM
M<V=I9"`B3U(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@(DUE<V%J92!6
M96-H:2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I
M;%]M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S
M(&)E:6YG('!U<F=E9"XB"FUS9W-T<B`B1&ER96-T;W)U;"!D92!-97-A:F4M
M5')I;6ES92!V96-H:2!A(&9O<W0@9V]L:70N(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C(U"FUS9VED(")/;FQY(&1I<W!L87D@9F]L9&5R<R!W:71H
M('5N<F5A9"!M97-S86=E<R!I;B!T:&5M/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"B,L(&9U>GIY"FUS9VED
M(")/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES
M(&%C=&EO;BXB"FUS9W-T<B`B5&4@<F]G(&%L96=E('5N('-I;F=U<B!D:7)E
M8W1O<B!P96YT<G4@86-E87-T82!A8W1I=6YE+B(*"B,Z('1E;7!L871E<R]M
M96YU+FEN8SHQ,"!T96UP;&%T97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G
M:60@(D]P96X@1F]?;&1E<B(*;7-G<W1R(")$97-C:&ED92(*"B,Z(&9O;&1E
M<G,N<&AP.C0R-PHC+"!F=7IZ>0IM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G
M<W1R(")$97-C:&ED92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M,#4*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z
M(&9E=&-H;6%I;"YP:'`Z,S,@=&5M<&QA=&5S+V9E=&-H;6%I;"]T;W`N:6YC
M.C,*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C8*(RP@
M9G5Z>GD*;7-G:60@(D]T:&5R($UA:6P@06-C;W5N=',B"FUS9W-T<B`B06QT
M92!/<'1I=6YI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G
M:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B06QT92!/<'1I=6YI(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#$*;7-G:60@(D]U=&)O=6YD
M(%-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A
M<V4N:6YC.C$V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,CDP"FUS9VED(")01U`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHW"B,L(&9U>GIY"FUS9VED(")01U`@
M16YC<GEP="!-97-S86=E(@IM<V=S='(@(E)E;G5N=&$@3&$@365S86HB"@HC
M.B!C;VUP;W-E+G!H<#HS-3@*(RP@9G5Z>GD*;7-G:60@(E!'4"!%<G)O<CH@
M(@IM<V=S='(@(D5R;V%R92(*"B,Z(&-O;7!O<V4N<&AP.C,S-PIM<V=I9"`B
M4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A
M=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"B,L(&9U>GIY"FUS9VED(")01U`@3W!T:6]N<R(*;7-G<W1R(")/<'1I
M=6YI(@H*(SH@<&=P+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A<V4@26YP
M=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4U"FUS
M9VED(")01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HQ-S,*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E
M>'0B"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ-#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S("@E<RE<(B!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")$:7)E8W1O<G5L(%PB
M)7-<(B!A(&9O<W0@8W)E870@8W4@<W5C8V5S+B(*"B,Z('!G<"YP:'`Z,C0U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F
M;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B
M1&ER96-T;W)U;"!<(B5S7"(@82!F;W-T('-T97)S(&-U('-U8V-E<RXB"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R
M>7!T7VQI<W0N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!'4"!3:6=N($UE<W-A
M9V4B"FUS9W-T<B`B5')I;6ET92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N
M8W)Y<'1?;&ES="YI;F,Z.0IM<V=I9"`B4$=0(%-I9VXO16YC<GEP="!-97-S
M86=E(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,C`R"FUS9VED(")01U`@<')I
M=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!P
M9W`N<&AP.C$W-PIM<V=I9"`B4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY
M(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV
M92YI;F,Z-`IM<V=I9"`B4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI
M<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(P.`IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L
M>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T
M;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,CDU"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@
M8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@
M8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,@IM<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@
M=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E
M;G1L>2`B"B)S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S
M="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F96%T
M=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G:60@(E!/
M4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3<*;7-G:60@(E!/4#,@;W9E<B!34TPB
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,C,*;7-G
M:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V.0IM
M<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$Q"FUS9VED(")03U`S+"!N
M;R!43%,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")086=E("5D(&]F("5D(@IM
M<V=S='(@(E!A9VEN82`E9"!D:6X@)60B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3`S"FUS9VED(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-
M97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,#0*;7-G:60@(E!A9V4@=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHT
M,PIM<V=I9"`B4&%R="AS*2(*;7-G<W1R(")!=&%S86UE;G0H92DB"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS9VED(")087-S<&AR87-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@
M(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z
M,C,U('!G<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")087-S<&AR87-E('-U
M8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`B365S86H@=')I;6ES(&-U
M('-U8V-E<R!D87(@;F5S86QV870@:6XB"@HC.B!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN
M8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`B(@H*(SH@<&=P+G!H
M<#HQ,3(*;7-G:60@(E!A<W-P:')A<V5S(&-A;B!N;W0@8F4@96UP='DB"FUS
M9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,30*;7-G:60@(E!A<W-P:')A<V5S(&1O
M(&YO="!M871C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,C`@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC
M.C<Q"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3DR"FUS9VED(")0
M87-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(E!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B17AE8W5T
M82!O<&5R871I=6YI(&1E(&UE;G1E;F%N=&$@;&$@0V]N96-T87)E+B(*"B,Z
M(&%C;"YP:'`Z-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E<FUI<W-I;VYS(&9O
M<B!T:&ES('5S97(@8V%N(&YO="!B92!C:&%N9V5D+B(*;7-G<W1R("(B"@HC
M.B!M97-S86=E+G!H<#HT.3,@;6%I;&)O>"YP:'`Z-S`S('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`B
M3F4@4&5R<V]N86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D1A=&4@4&5R<V]N
M86QE(@H*(SH@<&=P+G!H<#HQ,C`*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP
M86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z('!G
M<"YP:'`Z,3(W"FUS9VED(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(P-PIM<V=I
M9"`B4&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z
M("(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S;VYA
M;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA8V4@
M>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/R(*
M;7-G<W1R(")0;&%S96%Z82!S96UN871U<F$@:6YA:6YT96$@<F%S<'5N<W5R
M:6QO<BXB"@HC.B!C;VUP;W-E+G!H<#HR-30*;7-G:60@(E!L86EN=&5X="!6
M97)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<Y.0IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O;B!N97<@;6%I
M;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O<G0@96UB
M961D960@(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I;F1O
M=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL("(*(G)E<75I
M<F4@82!P;'5G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I
M<'0N:6YC.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(DEN=')O9'4@;G5M96QE
M(&YO=6QU:2!D:7)E8W1O<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F
M;VQD97)S+FIS.C$P,B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$P-`IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@
M9F]L9&5R.B(*;7-G<W1R("));G1R;V1U(&YU;65L92!N;W5L=6D@9&ER96-T
M;W(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S<*
M;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@(E1E
M(')O9R!I;G1R;V1U(&YO=6P@;G5M93HB"@HC.B!T96UP;&%T97,O<&=P+W!A
M<W-P:')A<V4N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S
M92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K
M97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R`B"B)E;G1E<B!T:&ES('!A<W-P
M:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U
M<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T
M;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@<F5C;VUP;W-E+G!H<#HY-PIM<V=I9"`B(@HB4&QE
M87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S
M<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U
M(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U
M('=I;&P@:&%V92!T;R`B"B)L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I
M;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@
M(@HB:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O
M<B!A;GD@:6YC;VYV96YI96YC92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!P87-S=V]R9"XB"FUS9W-T<B`B5&4@<F]G(&EN=')O9'4@
M;G5M96QE(&1E(%5T:6QI>F%T;W(@<VD@4&%R;VQA+B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(E1E(')O9R!I;G1R;V1U
M(&YU;65L92!D92!5=&EL:7IA=&]R('-I(%!A<F]L82XB"@HC.B!C;VUP;W-E
M+G!H<#HQ,#8@;&EB+TE-4"YP:'`Z-#4Y"FUS9VED(")0;&5A<V4@<F5S;VQV
M92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N(@IM<V=S='(@(E9A
M(')O9R!S82!V97)I9FEC871I(&%D<F5S96QE(&EN=')O9'5S92X@3G4@<&%R
M('-A(&9I92!C;W)E8W1E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-#(*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I
M;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H
M92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]F;VQD97)S+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@
M9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T
M<B`B5&4@<F]G(&%L96=E('5N(&1I<F5C=&]R(&EN86EN=&4@9&4@82!S<&5C
M:69I8V$@86-T:75N96$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4P,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('-E;&5C="!A;B!A8W1I;VX@
M9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T<B`B5&4@<F]G(&%L96=E(&-E
M;"!P=71I;B!U;B!D:7)E8W1O<B!D92!C875T87)E+B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE
M8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(E1E
M(')O9R!A;&5G92!C96P@<'5T:6X@=6X@9&ER96-T;W(@9&4@8V%U=&%R92XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS9VED
M(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R
M871I;VXN(@IM<V=S='(@(E1E(')O9R!A;&5G92!U;B!S:6YG=7(@9&ER96-T
M;W(@<&5N=')U(&%C96%S=&$@86-T:75N92XB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]R961I<F5C="YI;F,Z-S,*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!S
M96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T
M<B`B5&4@<F]G(&%L96=E(&-E;"!P=71I;B!U;B!D:7)E8W1O<B!D92!C875T
M87)E+B(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD:7-T.C0Q"FUS9VED(")0;W=E
M<F5D(&)Y($AO<F1E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,30*(RP@9G5Z>GD*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U
M<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B1&5S<&%R=&4@<V5M
M;F%T=7)A('!R:6X@*"<M+2`G*2(*"B,Z('-M:6UE+G!H<#HR-#$@<&=P+G!H
M<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"B,L(&9U>GIY"FUS9VED(")0<F5F
M97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B1&ER96-T
M;W)U;"!<(B5S7"(@82!F;W-T(&-R96%T(&-U('-U8V-E<RXB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PHC+"!F=7IZ>0IM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R(")086=I;F$@4')E8V5D96YT82(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G:60@
M(E!R979I;W5S($UE<W-A9V4B"FUS9W-T<B`B365S86IU;"!0<F5C961E;G0B
M"@HC.B!M86EL8F]X+G!H<#HS-#<*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS
M9W-T<B`B4&%G:6YA(%!R96-E9&5N=&$B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@
M(E1I<&%R97-T92(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC
M.C,X"B,L(&9U>GIY"FUS9VED(")0<FEO<FET>2(*;7-G<W1R(")4:7!A<F5S
M=&4B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S8*;7-G
M:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE
M(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X"FUS9VED(")0<F]M
M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@
M=&\@6453(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#<GEP="]01U`N<&AP.C0R.0IM<V=I9"`B4'5B;&EC(%!'4"!K97ES97)V
M97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"B,L(&9U>GIY"FUS9VED(")0
M=7)?9V4@1&5L971E9"(*;7-G<W1R(")3=&5R9V4@9&4@5&]T(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)G92!$96QE=&5D
M(@IM<V=S='(@(E-T97)G92!D92!4;W0B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHR-`HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@1F]L9&5R
M*',I(@IM<V=S='(@(E-T97)G92!$:7)E8W1O*')U;"]A<F5L92DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"FUS9VED(")0=7)G92!4<F%S:"!H
M;W<@;V9T96XZ(@IM<V=S='(@(D=O;&5S=&4@1W5N;VEU;"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,#4*(RP@9G5Z>GD*;7-G:60@(E!U<F=E(&UE
M<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT
M(&]F(&1A>7,N(@IM<V=S='(@(E-T97)G92!M97-A:F5L92!D:6X@9&ER96-T
M;W)U;"!'=6YO:2!M86D@=F5C:&D@9&4@86-E<W0@;G5M87(@9&4@>FEL92XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"B,L(&9U>GIY"FUS9VED
M(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS
M9W-T<B`B4W1E<F=E(&UE<V%J96QE('9E8VAI(&1I;B!D:7)E8W1O<G5L($=U
M;F]I("AD969I;FET:78I+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U
M<F=E7W1R87-H+G!H<#HV-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4'5R9VEN9R`E9"!M97-S86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T
M<B`B1V]L:6T@)60@;65S86HH92D@9&EN($=U;F]I+B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I
M9"`B4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S
M='(@(D=O;&EM("5D(&UE<V%J*&4I(&1I;B!'=6YO:2XB"@HC.B!T96UP;&%T
M97,O<75O=&$O<75O=&$N:6YC.C$W"B,L('!H<"UF;W)M870*;7-G:60@(E%U
M;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(D-I
M=&%T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@V"FUS
M9VED(")295]Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E)E8V5I
M=F5D($]N(@IM<V=S='(@(E!R:6UI=&4@<&4B"@HC.B!L:6(O4V5A<F-H+G!H
M<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`B
M4')I;6ET92!P92(*"B,Z(&QI8B]396%R8V@N<&AP.C4T"B,L(&9U>GIY"FUS
M9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R(")0<FEM:71E('!E(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"B,L(&9U
M>GIY"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B4F5D:7)E8W1E87IA(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS
M9VED(")2961I<F5C="(*;7-G<W1R(")2961I<F5C=&5A>F$B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I<F5C
M="!-97-S86=E(@IM<V=S='(@(E)E9&ER96-T96%Z82(*"B,Z(&-O;7!O<V4N
M<&AP.C<X-PIM<V=I9"`B4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S='(@
M(E)E9&ER96-T96%Z82!A8V5S="!M97-A:B(*"B,Z(&-O;7!O<V4N<&AP.C@T
M-PIM<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*;7-G<W1R(")2961I<F5C
M=&%R96$@82!E<W5A="XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU.#,*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B4F5I;7!R;W-P871E
M87IA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X-`IM<V=I9"`B4F5F
M<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(E)E:6UP<F]S<&%T96%Z82!F
M97)E87-T<F$@8W4@9&ER96-T;V%R93HB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]H96%D+FEN8SHY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-`HC
M+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E)E:6YC87)C82!F97)E
M87-T<F$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHS"FUS9VED
M(")296QO860@5FEE=R(*;7-G<W1R(")296EN8V%R8V$@9F5R96%S=')A(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R-B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-30U"FUS9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3<Y"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S
M='(@(E5L=&EM82!S=&%R92(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM
M<V=S='(@(D-A<W5T82!D92!-97-A:F4B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M(%-E87)C
M:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHS,#4*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T
M<B`B4W1E<F=E(&-E;&4@<V5L96-T871E(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B4F5N86UE($9O;&1E
M<BAS*2(*;7-G<W1R(")2961E;G5M97-T92!$:7)E8W1O<G5L(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5N86UE
M('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G
M<W1R(")2961E;G5M97-T92!D:7)E8W1O<G5L(&-U($UE<V%J92U4<FEM:7-E
M(&QA(&EN8V5P=71U;"!L=6YI:2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT-34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB)7-<
M(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B4F5D96YU;6ER96$@;'5I(%PB)7-<(B!I;B!<(B5S7"(@82!E<W5A="X@
M26%T82!C92!A('II<R!S97)V97)U;#HB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E)E<&Q?
M>2!T;R!,:7-T(@IM<V=S='(@(E)A<W!U;F1E(&QA(%1O=&DB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")297!L86-E
M('=I=&@Z(@IM<V=S='(@(DEN;&]C=6EE<W1E(&-U.B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L>2(*
M;7-G<W1R(")287-P=6YD92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HS,3$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P.0HC+"!F=7IZ>0IM
M<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B4F%S<'5N9&4@;&$B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@
M(E)E<&QY('1O($%L;"(*;7-G<W1R(")287-P=6YD92!L82!4;W1I(@H*(SH@
M8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L>2!T;R!!;&PZ(@IM<V=S='(@
M(E)A<W!U;F1E(&QA(%1O=&DZ(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!,
M:7-T(@IM<V=S='(@(E)A<W!U;F1E(&QA(%1O=&DB"@HC.B!C;VUP;W-E+G!H
M<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O($QI<W0Z(@IM<V=S='(@
M(E)A<W!U;F1E(&QA(%1O=&DZ(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!?
M06QL(@IM<V=S='(@(E)A<W!U;F1E(&QA(%1O=&DB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3(X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,S<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-PIM<V=I9"`B4F5P
M;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-0IM<V=I9"`B4F5P;'D@=VET
M:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E<&QY('=I
M=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@;65S<V%G92YP:'`Z,C8W"B,L(&9U>GIY"FUS9VED(")297!L>2U4
M;R(*;7-G<W1R(")287-P=6YS+4-A=')E.B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HT,#D*;7-G:60@(E)E<&QY+51O.B`B"FUS9W-T<B`B4F%S<'5N<RU#871R
M93HB"@HC.B!C;VUP;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*;7-G<W1R
M(")287-P=6YD93HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C8*
M(RP@9G5Z>GD*;7-G:60@(E)E<&]R="!A<R!);FYO8V5N="(*;7-G<W1R(")2
M87!O<G1E87IA(&-A($YE9&]R:70B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(E)A<&]R
M=&5A>F$@8V$@3F5D;W)I="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,X,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E
M8V5I<'0B"FUS9W-T<B`B0V5R92!#;VYF:7)M87)E(&1E(%!R:6UI<F4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E
M;&EV97)Y(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4W,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!R96%D
M(')E8V5I<'1S/R(*;7-G<W1R(")#97)E($-O;F9I<FUA<F4@9&4@4')I;6ER
M92(*"B,Z(&UA:6QB;W@N<&AP.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A
M9V4@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-CDW"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$V,0IM<V=I9"`B4F5S970B"FUS9W-T<B`B4W1E<F=E(%1O="(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,34*;7-G:60@(E)E<W!O
M;F1E;G0@4W1A='5S(%5P9&%T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,`HC+"!F=7IZ>0IM<V=I
M9"`B4F5S=6UE(@IM<V=S='(@(E-T97)G92!4;W0B"@HC.B!R96-O;7!O<V4N
M<&AP.CDX"FUS9VED(")297-U;64@>6]U<B!S97-S:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT-`HC+"!F=7IZ
M>0IM<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM
M<V=S='(@(D-O;7!U;F4@365S86H@3F]U(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]D<FEV97)?<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT
M7W-E;&5C="YI;F,Z,S(*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHV,"!T
M96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C(R"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,3`Q('1E;7!L871E<R]S;6EM92]N;W1A8W1I
M=F4N:6YC.C$T"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-#D@=&5M<&QA
M=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U"B,Z('1E;7!L871E<R]A8VPO86-L
M+FEN8SHQ-C(@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$W,PHC+"!F=7IZ>0IM
M<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B06QT92!/<'1I=6YI
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q.`IM<V=I9"`B(@HB4F5T
M=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO
M=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*(DEN=&]A
M<F-E+71E(&QA(&QI<W1A(&1E(&UE<V%J92!D=7!A('-T97)G97)E82P@;75T
M87)E82!S874@8V]P:65R96$@=6YU:2`B"B)M97-A:BXB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")2;VQE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30R(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#$Y"FUS9VED(")3+TU)344B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,@IM<V=I9"`B4R]-24U%($5N
M8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS.30*
M;7-G:60@(E,O34E-12!%<G)O<CH@(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N
M<&AP.C,W,PIM<V=I9"`B4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@
M9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34Q"B,L(&9U>GIY"FUS9VED(")3+TU)344@
M3W!T:6]N<R(*;7-G<W1R(")/<'1I=6YI(@H*(SH@<VUI;64N<&AP.C0Y"FUS
M9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R
M<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,30P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B1&ER
M96-T;W)U;"!<(B5S7"(@82!F;W-T('-T97)S(&-U('-U8V-E<RXB"@HC.B!S
M;6EM92YP:'`Z,38R"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S
M9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,3`*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G
M<W1R("(B"@HC.B!S;6EM92YP:'`Z,C$Q"FUS9VED(")3+TU)344@4'5B;&EC
M+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*
M(RP@9G5Z>GD*;7-G:60@(E,O34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B
M5')I;6ET92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI
M;F,Z,30*;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHT"FUS
M9VED(")3+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR
M-#$*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@
M96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@(@HB9&5C
M<GEP=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C$W,PIM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L
M960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N
M(&YO="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R
M="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@
M=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P
M;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO
M=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P
M=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E
M;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R
M96-T;'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C`U"FUS9VED(")33510(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(U-0HC+"!F=7IZ>0IM<V=I9"`B4U]U8FIE
M8W0B"FUS9W-T<B`B4W5B:65C="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,V,PHC+"!F=7IZ>0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN
M("(*;7-G<W1R(")386QV96%Z82!O(&-O<&EE(&EN("(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@HC+"!F=7IZ>0IM<V=I
M9"`B4V%?=F4@87,B"FUS9W-T<B`B4V%L=F5A>F$@8V$B"@HC.B!S96%R8V@N
M<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*(RP@
M9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`B4V%L=F5A>F$@8V$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S@*;7-G:60@(E-A=F4@
M071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PIM<V=I9"`B
M4V%V92!$<F%F="(*;7-G<W1R(")386QV96%Z82!#:6]R;F$B"@HC.B!S879E
M:6UA9V4N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")3879E($EM86=E(@IM<V=S
M='(@(E-A;'9E87IA(&-A(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(P
M-`IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E
M+FEN8SHQ,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4V%V92!/
M<'1I;VYS(@IM<V=S='(@(D]P=&EU;FDB"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z-#`*;7-G:60@(E-A=F4@4W1A=&EO;F5R>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*(RP@9G5Z>GD*;7-G
M:60@(E-A=F4@7T1R869T(@IM<V=S='(@(E-A;'9E87IA($-I;W)N82(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I
M9"`B4V%V92!A<R(*;7-G<W1R(")386QV96%Z82!C82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E
M;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-S(*
M;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D
M969A=6QT(&%D9')E<W,@8F]O:S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHQ,C<*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@
M=FER='5A;"!F;VQD97(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,S`*(RP@9G5Z>GD*;7-G:60@(E-A=F4@<V5N="!M86EL/R(*
M;7-G<W1R(")386QV96%Z82!-97-A:BU4<FEM:7,B"@HC.B!C;VUP;W-E+G!H
M<#HQ,C(W"B,L('!H<"UF;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@
M9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G
M<W1R(")386QV87)E82!#:6]R;F5I(&$@97-U870N($EA=&$@8V4@82!S<'5S
M('-E<G9E<G5L.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3DY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@
M;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*
M;7-G<W1R(")#875T87)E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N
M:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-E87)C:"`E<R(*;7-G<W1R(")#875T
M87)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,`HC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`B06QT92!/<'1I=6YI(@H*
M(SH@<V5A<F-H+G!H<#HR-C4*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S
M='(@(E)E>G5L=&%T92!#875T87)E(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ-"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Q
M"FUS9VED(")3965N(@IM<V=S='(@(D-I=&ET92(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z.0IM<V=I9"`B4V5L96-T(@IM<V=S='(@(E-E
M;&5C=&5A>F$B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M-S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!!;F]T:&5R($%C8V]U;G0B"FUS
M9W-T<B`B4V5L96-T96%Z82!.:6UI8R(*"B,Z('1E;7!L871E<R]S96%R8V@O
M9FEE;&1S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*
M;7-G<W1R(")396QE8W1E87IA(&\@:61E;G1I=&%T92(*"B,Z('1E;7!L871E
M<R]S96%R8V@O9FEE;&1S+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&$@9FEE;&0B"FUS9W-T<B`B4V5L96-T96%Z82!4;W0B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@(E-E;&5C=&5A>F$@3FEM:6,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@
M<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S='(@(D%L96=E($%G96YD
M96QE('!E;G1R=2!A9')E<V4N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHX.`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")396QE8W1E87IA
M(%1O="(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H
M('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B06QA9V4@;W)D
M:6YE82!D92!C875T87)E(&EN(&%G96YD92XB"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B4V5L96-T96%Z82!.:6UI8R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(E-E;&5C=&5A>F$@3FEM:6,B"@HC.B!T96UP;&%T
M97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B4V5L96-T('1H
M92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C(Q"FUS
M9VED(")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"B,L(&9U
M>GIY"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G<W1R(")!
M9V5N9&4@<V5L96-T871E(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R
M"FUS9VED(")396YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#0*(RP@9G5Z>GD*
M;7-G:60@(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(D]P=&EU
M;FD@4V5R=F5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"FUS9VED(")3
M96YD($UE<W-A9V4B"FUS9W-T<B`B5')I;6ET92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW,#,*;7-G:60@(E-E;F0@<F5A9"!R96-E:7!T('=H96X@
M<F5Q=65S=&5D(&)Y('1H92!S96YD97(_(@IM<V=S='(@(B(*"B,Z(&9O;&1E
M<G,N<&AP.C,Y-PHC+"!F=7IZ>0IM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*
M;7-G<W1R(")$:7)E8W1O<B!-97-A:F4M5')I;6ES93HB"@HC.B!T96UP;&%T
M97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,X"FUS9VED(")396YT(&UA
M:6P@9F]L9&5R.B(*;7-G<W1R(")$:7)E8W1O<B!-97-A:F4M5')I;6ES93HB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$T-@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$U,PHC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(@IM<V=S='(@(DYI8VEO
M9&%T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VXB"FUS9W-T<B`B
M3W!T:75N:2!397)V97(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B3FEC
M:6]D871A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3
M970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E
M(&%N9"!D96QE=&4@;65S<V%G97,N(@IM<V=S='(@(D%L96=E(&-E('-E(&EN
M=&EM<&QA(&%T=6YC:2!C:6YD(&UU=&DL(&-O<&EE>FD@<V%U('-T97)G:2!M
M97-A:F4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R.0IM<V=I9"`B
M4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN9R!M97-S
M86=E<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q
M"B,L(&9U>GIY"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(D1I<F5C
M=&]A<F4B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.#8*(RP@9G5Z>GD*
M;7-G:60@(E-H87)E(&UA:6P@9F]L9&5R<R(*;7-G<W1R(")$:7)E8W1O<B!-
M97-A:F4M5')I;6ES93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*
M;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E
M<G,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*
M;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@
M8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T
M;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T
M:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R
M(%!'4"!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$S"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L
M;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`B26YC:&ED96T@
M9F5R96%S=')A(&1E(&-O;7!U;F5R92!-97-A:B!.;W4@;&$@<V%L=F%R96$@
M8VEO<FYE:2XB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I9"`B
M4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@
M>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"B,L(&9U>GIY"FUS9VED(")3:&]W
M($%L;"!&;VQD97)S(@IM<V=S='(@(E)E<W1R:6YG92!T;V%T92!D:7)E8W1O
M87)E;&4N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C<*
M;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B(@H*(SH@;6%I;&)O
M>"YP:'`Z,S8U"FUS9VED(")3:&]W($1E;&5T960B"FUS9W-T<B`B07)A=&$@
M365S86IE(%-T97)S92(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW,`HC+"!F=7IZ
M>0IM<V=I9"`B4VAO=R!-86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T
M<B`B1&%T92!097)S;VYA;&4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.CDR"B,L(&9U>GIY"FUS9VED(")3:&]W($]N;'D@4W5B<V-R:6)E9"!&
M;VQD97)S(@IM<V=S='(@(E-U8G-C<FEE(&QA($1I<F5C=&\H<B]A<F4I(@H*
M(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`X"FUS9VED
M(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG(&]F(&%T=&%C:&UE
M;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#`R"B,L(&9U>GIY"FUS9VED(")3:&]W(&QE9V5N9"!I
M;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R(")!9FES96%Z82!,96=E;F1A
M(&EN(&QI<W1A(&1E(&UE<V%J92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#0P"FUS9VED(")3:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G
M97,@;VYL>3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@T.`IM<V=I9"`B4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W-PIM<V=I9"`B4VAO
M=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@(E-H
M;W<@=&AE($EM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z-30*;7-G:60@(E-H;W<@=&AE(&9I;'1E<B!I8V]N(&]N
M('1H92!M96YU8F%R/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,C@*;7-G:60@(E-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN
M(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8V-@IM<V=I9"`B4VAO=VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B
M4VE?>F4B"FUS9W-T<B`B36%R:6UE(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B4VEG;F5D(@IM<V=S='(@
M(DUA<FEM92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN
M8SHS"FUS9VED(")3:7IE(@IM<V=S='(@(DUA<FEM92(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3$*;7-G:60@(E-O<G0@
M8GD@07)R:79A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C$V"FUS9VED(")3;W)T(&)Y($1A=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!&<F]M($%D9')E<W,B
M"FUS9W-T<B`B17AP961I=&]R(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHT,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!-
M97-S86=E(%-I>F4B"FUS9W-T<B`B36%R:6UE($UE<V%J(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-@HC+"!F=7IZ>0IM
M<V=I9"`B4V]R="!B>2!3=6)J96-T(@IM<V=S='(@(D9A<F$@4W5B:65C="(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S$*
M;7-G:60@(E-O<G0@8GD@5&AR96%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G
M:60@(E-O<G0@8GD@5&\@061D<F5S<R(*;7-G<W1R(")%>'!E9&ET;W(B"@HC
M.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C,*(RP@9G5Z>GD*
M;7-G:60@(E-P86T@9F]L9&5R.B(*;7-G<W1R(")'=6YO:3HB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R<R(*;7-G<W1R(")#87)A8W1E<F4@4W!E8VEA;&4B"@HC.B!S
M96%R8V@N<&AP.C$S,PIM<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@
M8V%N(&YO="!B92!E9&ET960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,T,PIM<V=I9"`B4W!E;&P@0VAE8VLB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V
M"B,L(&9U>GIY"FUS9VED(")3<&5L;"!#:&5C:V5R(@IM<V=S='(@(D-A<F%C
M=&5R92!3<&5C:6%L92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-38*;7-G
M:60@(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@(E-P96QL:6YG(&5R<F]R<R!P
M97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N(@IM<V=S='(@(F=R97-E
M;&D@9&4@;W)T;V=R869I92!P92!P86=I;F$N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4Q,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4R
M"FUS9VED(")3=&%R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS,3$*;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T:6]N97)Y
M(&YA;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHR.`IM<V=I9"`B4W1A=&EO;F5R>2!T>7!E.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S,*;7-G:60@
M(E-T871I;VYE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV.#@*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")3=')I<"!!
M='1A8VAM96YT(@IM<V=S='(@(D%T87-A;65N="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(E-U8FEE
M8W0B"@HC.B!M97-S86=E+G!H<#HR-C@@=&AR96%D+G!H<#HQ-3`@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H
M<#HS.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")3=6)I96-T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B4W5B:F5C="!&:65L9"(*
M;7-G<W1R(")3=6)I96-T=6PB"@HC.B!S96%R8V@N<&AP.C,Q."!T96UP;&%T
M97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3@*(SH@=&5M<&QA=&5S+W-M
M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S
M92YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(E-U8FUI="(*;7-G<W1R(")3=6)I
M96-T(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3$*;7-G
M:60@(E-U8G-C<FEB92!T;R!&;VQD97(H<RDB"FUS9W-T<B`B4W5B<V-R:64@
M;&$@1&ER96-T;RAR+V%R92DB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C,X,"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.#D*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@(E-U8V-E<W,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@V"FUS
M9VED(")3=6=G97-T:6]N<R(*;7-G<W1R(")3=6=E<W1I:2(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV-C(@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8V-`IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#`@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#`S"FUS9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T
M:&]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T
M"FUS9VED(")3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,3D*
M(RP@9G5Z>GD*;7-G:60@(E1E7WAT(@IM<V=S='(@(E1E>'1U;"(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-CD*;7-G:60@(E1E;G1A=&EV93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*
M;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*;7-G:60@(E1E;G1A
M=&EV96QY($%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O
M;F8N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT=6PB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED(")4:&4@1G)O;3H@8V]L
M=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3,R"FUS9VED("(B"B)4:&4@
M24U!4"!S97)V97(@9&]E<R!N;W0@87!P96%R('1O('-U<'!O<G0@=&AE(&%U
M=&AE;G1I8V%T:6]N(&UE=&AO9"`B"B)S96QE8W1E9"X@4&QE87-E(&-O;G1A
M8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0IM<V=I9"`B5&AE
M($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(&-A;B!B92!D;W=N
M;&]A9&5D("5S+B(*;7-G<W1R("(B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z
M.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET871E82!<
M(B5S7"(@82!F;W-T('-T96%R<V$N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP
M.C<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<
M(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(DED96YT:71A=&5A(%PB
M)7-<(B!A(&9O<W0@<V%L=F%T82XB"@HC.B!A='1A8VAM96YT+G!H<#HT,PIM
M<V=I9"`B5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y"FUS9VED(")4:&4@
M8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V]M<&]S95]W:6XN:G,Z,S<*;7-G:60@
M(B(*(E1H92!C;VUP;W-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA
M<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U
M<"!W:6YD;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P
M;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N=',@;V8@=&AE($UA
M8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C@W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C=7)R96YT(&9O;&1E<BAS*2!<
M(B5S7"(@=VEL;"!B92!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B1&ER
M96-T;RAR=6PO87)E;&4I(&-U<F5N="AE*2!<(B5S7"(@=F]R(&9I(')E9&5N
M=6UI=&4@8V$@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ
M,#<*;7-G:60@(B(*(E1H92!C=7)R96YT(&QI<W0@;V8@=7-E<G,@=VET:"!A
M8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E=')I979E9"(*
M;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C,V"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@7"(E<UPB
M(&9O;&1E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C$S.0IM<V=I9"`B5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A
M;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E>'!A
M;F0N:6YC.CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L
M9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@(DED96YT:71A
M=&5A(%PB)7-<(B!A(&9O<W0@<W1E87)S82XB"@HC.B!L:6(O1F]L9&5R+G!H
M<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@
M86QR96%D>2!E>&ES=',B"FUS9W-T<B`B1&ER96-T;W)U;"!<(B5S7"(@97AI
M<W1A(&1E:F$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS(&EL;&5G
M86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E("(*(G!R
M;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(D1I<F5C=&]R=6P@7"(E<UPB(&-O;G1I;F4@8V%R86-T
M97)E(&YE<&5R;6ES92!I;B!N=6UE;&4@<V%U+B!!<B!P=71E82!C<F5A("(*
M(G!R;V)L96UE+B!#;VYT86-T96%Z82UL('!E($%D;6EN:7-T<F%T;W(B"@HC
M.B!L:6(O1F]L9&5R+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9O;&1E<B!<(B5S7"(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S
M=6)S8W)I8F5D('1O(&ET+B(*;7-G<W1R(")$:7)E8W1O<G5L(%PB)7-<(B!A
M(&9O<W0@8W)E870@9&%R('1U(&YU(&%I('-U8G-C<FES(&QA(&5L+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9F]L9&5R(%PB)7-<(B!W87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N
M<W5B<V-R:6)E9"!F<F]M(&ET+B(*;7-G<W1R(")$:7)E8W1O<G5L(%PB)7-<
M(B!A(&9O<W0@<W1E<G,@9&%R('1U(&YU(&%I(&%N=6QA="!S=6)S8W)I97)E
M82!L82!E;"XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS-#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!C<F5A=&5D+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(D1I<F5C=&]R
M=6P@7"(E<UPB(&YU(&$@9F]S="!C<F5A="X@26%T82!C92!A('-P=7,@<V5R
M=F5R=6PZ(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C8U"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@9&5L971E9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")$:7)E8W1O<G5L
M(%PB)7-<(B!N=2!A(&9O<W0@<W1E<G,N($EA=&$@8V4@82!S<'5S('-E<G9E
M<G5L.B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T
M960N(@IM<V=S='(@(D1I<F5C=&]R=6P@7"(E<UPB(&$@9F]S="!C<F5A="!C
M=2!S=6-C97,N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@
M9&5L971E9"XB"FUS9W-T<B`B1&ER96-T;W)U;"!<(B5S7"(@82!F;W-T('-T
M97)S(&-U('-U8V-E<RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HT-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B1&ER96-T;W)U;"!<
M(B5S7"(@82!F;W-T(')E9&5N=6UI="!C=2!S=6-C97,@8V$@7"(E<UPB+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY,@IM<V=I9"`B5&AE(&9O
M;&QO=VEN9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R=#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]S879E:6UA
M9V5?=VEN+FIS.C$R"FUS9VED("(B"B)4:&4@:6UA9V4@<V%V92!W:6YD;W<@
M8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@
M8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3<*;7-G:60@(B(*(E1H
M92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R
M(&ES('!R97-E;G0@:6X@>6]U<B`B"B)A9&1R97-S8F]O:RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S4*;7-G:60@(E1H
M92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M
M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HU,0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E
M9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@
M(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S
M86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C4Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;6%I;&)O>"`E<R!I<R!A;')E
M861Y(&5M<'1Y+B(*;7-G<W1R("(E<R!E<W1E(&1E:F$@9V]L+B(*"B,Z(&QI
M8B]&971C:&UA:6PN<&AP.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S
M(&9E=&-H('-I>F4@;&EM:70N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`S"FUS9VED(")4:&4@;65S<V%G92!B
M96EN9R!C;VUP;W-E9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&%T
M96$@7"(E<UPB(&$@9F]S="!S=&5A<G-A+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S
M(&)E96X@=F5R:69I960N(@IM<V=S='(@(DED96YT:71A=&5A(%PB)7-<(B!A
M(&9O<W0@<V%L=F%T82XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C,X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E
M;B!V97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+V]P96Y?<VUI;65?=VEN+FIS.C$P('1E;7!L871E<R]P9W`O
M;W!E;E]P9W!?=VEN+FIS.C$P"FUS9VED("(B"B)4:&4@<&%S<W!H<F%S92!W
M:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y
M;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+
M97D@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W1N968N<&AP.C8P"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@
M9&]E<R!N;W0@97AI<W0@:6X@=&AE($U3+51.148@871T86-H;65N="XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G:60@
M(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP
M(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@;65S
M<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I
M9FEC871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@
M;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE("(*(FYO=&EF
M:6-A=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HV.0IM<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B
M;&4@=&\@8W)E871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`T"FUS
M9VED(")4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#(*
M(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL
M>2!R97!L86-E9"XB"FUS9W-T<B`B1&ER96-T;W)U;"!<(B5S7"(@82!F;W-T
M(&-R96%T(&-U('-U8V-E<RXB"@HC.B!A='1A8VAM96YT+G!H<#HU.0IM<V=I
M9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M("(B"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&%D9&5D
M+B(*;7-G<W1R("))9&5N=&ET871E82!<(B5S7"(@82!F;W-T('-A;'9A=&$N
M(@H*(SH@<W1A=&EO;F5R>2YP:'`Z-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("))9&5N=&ET871E82!<(B5S7"(@82!F;W-T('-T96%R<V$N
M(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A=&5D
M+B(*;7-G<W1R("))9&5N=&ET871E82!<(B5S7"(@82!F;W-T('-T96%R<V$N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V.0IM<V=I9"`B5&AE
M('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*(RP@9G5Z
M>GD*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(G-T
M97)G92!M97-A:G5L(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A
M9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z.#`*;7-G:60@(E1H92!T97AT(&]F('1H92!R
M971U<FYE9"!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT
M(&]F('1H92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP
M.C8X"B,L(&9U>GIY"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S
M86=E(@IM<V=S='(@(E)E9&ER96-T96%Z82!A8V5S="!M97-A:B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$U-`IM<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM<V=I9"`B5&AE
M<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V5M<'1Y7VUA:6QB;W@N:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!M97-S
M86=E<R!I;B!T:&ES(&UA:6QB;W@N(@IM<V=S='(@(DYU(&5X:7-T82!-97-A
M:F4@:6X@86-E87-T82!C87-U=&$@<&]S=&%L82XB"@HC.B!T:')E860N<&AP
M.C$P.0IM<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-C$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9"(*;7-G<W1R(")$:7)E8W1O<G5L(%PB)7-<(B!N=2!A(&9O<W0@8W)E
M870N($EA=&$@8V4@82!S<'5S('-E<G9E<G5L.B(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HV-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8R,0HC+"!F=7IZ
M>0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA
M:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B
M1&ER96-T;W)U;"!<(B5S7"(@;G4@82!F;W-T('-T97)S+B!)871A(&-E(&$@
M<W!U<R!S97)V97)U;#HB"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C
M;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R(")2961E;G5M:7)E
M82!L=6D@7"(E<UPB(&EN(%PB)7-<(B!A(&5S=6%T+B!)871A(&-E(&$@>FES
M('-E<G9E<G5L.B(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ.3@@;&EB+TUE<W-A
M9V4N<&AP.C(Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O
M;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R('-A:60B
M"FUS9W-T<B`B1&ER96-T;W)U;"!<(B5S7"(@;G4@82!F;W-T('-T97)S+B!)
M871A(&-E(&$@<W!U<R!S97)V97)U;#HB"@HC.B!L:6(O365S<V%G92YP:'`Z
M,C<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S
M7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B
M1&ER96-T;W)U;"!<(B5S7"(@;G4@82!F;W-T('-T97)S+B!)871A(&-E(&$@
M<W!U<R!S97)V97)U;#HB"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("5S(@IM<V=S='(@(D1I<F5C=&]R=6P@7"(E<UPB(&YU(&$@9F]S="!S=&5R
M<RX@26%T82!C92!A('-P=7,@<V5R=F5R=6PZ(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I
M97=E<B]E;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES
M(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(D1I<F5C=&]R
M=6P@7"(E<UPB(&YU(&$@9F]S="!C<F5A="X@26%T82!C92!A('-P=7,@<V5R
M=F5R=6PZ(@H*(SH@9F]L9&5R<RYP:'`Z,38U"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M979E;G0Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,38V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S
M86=E+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T
M;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS
M9W-T<B`B4F5D96YU;6ER96$@;'5I(%PB)7-<(B!I;B!<(B5S7"(@82!E<W5A
M="X@26%T82!C92!A('II<R!S97)V97)U;#HB"@HC.B!C;VUP;W-E+G!H<#HQ
M,C0T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S
M<V%G92!A<R!A(&1R869T+B(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ
M,#`V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S
M96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU.0HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E
M('!A<G0B"FUS9W-T<B`B3G4@97AI<W1A($UE<V%J92!I;B!A8V5A<W1A(&-A
M<W5T82!P;W-T86QA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY
M-PIM<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E
M9"!I;B!I="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.CDP"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S
M(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B
M"B)T:&ES.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,38V"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE
M9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$P-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$X
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#,@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$U-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3<S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,30*;7-G:60@(E1H:7,@
M86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE
M;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B06-E
M87-T82!O<&5R871I=6YE(&5S=&4@9&4@9'5R871A+B!%<W1I('-I9W5R(&-A
M('9R96D@<V$@8V]N=&EN=6D@/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L
M961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A
M($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C0Q,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A
M:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L;'D@<VEG
M;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z-#$T"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I
M;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@
M4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!M86EL
M(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M870@
M;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q-0HC+"!F=7IZ>0IM<V=I9"`B
M(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G<W1R("(E<R!N
M=2!P87)E('-A(&9I92!O(&-A<W5T82!P;W-T86QA('9A;&ED82XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,S4P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN
M9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4:&ES(&UE<W-A9V4@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F;W)M870N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-2!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*;7-G:60@(E1H:7,@;65S<V%G
M92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30S"FUS9VED(")4
M:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-
M24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S.`IM<V=I9"`B5&AI
M<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#$@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,CDQ"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S
M(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G92!T;R(*;7-G<W1R(")-
M97-A:G5L(&EN(@H*(SH@86-L+G!H<#HT-@IM<V=I9"`B5&AI<R!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W
M:6YD;W<N(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,34R"B,L(&9U>GIY
M"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G<W1R(")!9FES96%Z82(*"B,Z
M('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,@HC+"!F
M=7IZ>0IM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B4F5I;F-A<F-A(&9E
M<F5A<W1R82(*"B,Z(&UE<W-A9V4N<&AP.C(V-"!M86EL8F]X+G!H<#HV,#8@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,3D*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H+G!H<#HR-@IM<V=I9"`B5&\B
M"FUS9W-T<B`B0V%T<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$Y
M"B,L(&9U>GIY"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(D5X<&5D:71O
M<B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C
M;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HQ
M,S0*;7-G:60@(B(*(E1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S
M="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@-2XP+C8@;W(@(@HB:&EG
M:&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU-S<*(RP@9G5Z>GD*;7-G:60@(E1O=&%L($%T=&%C:&UE;G1S(%-I
M>F4Z(@IM<V=S='(@(D%T87-A;65N=&4B"@HC.B!F;VQD97)S+G!H<#HS.#@*
M(RP@9G5Z>GD*;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G<W1R(")'=6YO:3HB
M"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED
M(")4<F%S:"!F;VQD97(Z(@IM<V=S='(@(D=U;F]I.B(*"B,Z(&QI8B]1=6]T
M82]C>7)U<RYP:'`Z-C4@;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z-SD@;&EB
M+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1=6]T82]L;V=F:6QE+G!H
M<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+VUD865M
M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS=V5R
M960B"FUS9W-T<B`B1F%R82!287-P=6YS(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M97-S86=E<R(*;7-G
M<W1R(")-97-A:F4@9F%R82!287-P=6YS(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,3,*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(E)E8W5P97)E
M87IA(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y(&UA:6QB;W@N<&AP.C8P,B!L:6(O
M34E-12](96%D97)S+G!H<#HR,3(*;7-G:60@(E5N9&ES8VQO<V5D(%)E8VEP
M:65N=',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT
M(&]F('1Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V-0IM
M<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!
M4"!R97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,S4*;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R("(B"@HC.B!M86EL
M8F]X+G!H<#HV,3@*;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<W"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*;7-G
M<W1R("(B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-C4*(RP@9G5Z>GD*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z(&UE<W-A9V4N
M<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*
M;7-G<W1R(").96-I=&ET92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O
M;&1E<BAS*2(*;7-G<W1R(")3=6)S8W)I92!L82!$:7)E8W1O*'(O87)E*2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X-`IM<V=I9"`B
M57!D871E($%T=&%C:&UE;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R,`IM<V=I9"`B57!D871E(')E
M<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C4V"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U
M;'0@5F%L=64B"FUS9W-T<B`B1F]L;W-E<W1E(%9A;&]A<F5A($EM<&QI8VET
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-38*;7-G:60@(E5S92!)
M34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/R(*;7-G<W1R(")3=6)S8W)I92!L
M82!D:7)E8W1O87)E($E-05`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<S-0HC+"!F=7IZ>0IM<V=I9"`B57-E(%9I<G1U86P@5')A<V@@1F]L9&5R
M/R(*;7-G<W1R(")';VQE<W1E($=U;F]I=6PB"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,30R"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(E5T
M:6QI>F%T;W(B"@HC.B!A8VPN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E8VEF
M:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<W"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB
M"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-PHC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<W"FUS9VED(")6:65W(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]Z:7`N<&AP.CDR(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H
M<#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(%!U
M8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@
M82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B0V]M<'5N92!-97-A:B!.;W4@
M:6X@9F5R96%S=')A('-E<&%R871A+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C(X"B,L(&9U>GIY"FUS9VED(")6:65W($UE<W-A9V5S
M(@IM<V=S='(@(DUE<V%J92!.;VDB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE
M=R!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM
M<V=I9"`B5FEE=R!4:')E860B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V-0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GD*;7-G:60@(E9I
M97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")#
M;VUP=6YE($UE<V%J($YO=2!I;B!F97)E87-T<F$@<V5P87)A=&$N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L(&9U>GIY"FUS9VED
M(")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B
M0V]M<'5N92!-97-A:B!.;W4@:6X@9F5R96%S=')A('-E<&%R871A+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#`*;7-G:60@(E9I97<@979E
M;G0B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S@P(&UA:6QB;W@N<&AP
M.C4S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!M97-S86=E
M<R!I;B`E<R(*;7-G<W1R(")-97-A:F4@3F]I(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M
M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S='(@(DQA(&-O
M;F5C=&%R92!A9FES96%Z83HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3<P"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!T
M:&4@26UA9V5S(@IM<V=S='(@(E-T97)G92!M97-A:F5L92(*"B,Z('-E87)C
M:"YP:'`Z,C8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L
M($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`B
M1&ER96-T;W)U;"!<(B5S7"(@82!F;W-T('-T97)S(&-U('-U8V-E<RXB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Q,2!L:6(O24U!4"]4<F5E
M+G!H<#HQ,S@@;&EB+TE-05`O5')E92YP:'`Z,34Q"B,Z(&QI8B])34%0+U1R
M964N<&AP.C$U,R!L:6(O24U!4"]4<F5E+G!H<#HQ-3<@;&EB+TE-05`O5')E
M92YP:'`Z,34X"B,Z(&QI8B])34%0+U1R964N<&AP.C,V.2!L:6(O24U!4"]4
M<F5E+G!H<#HS.3,@;&EB+TE-05`O5')E92YP:'`Z-#,S"B,L(&9U>GIY"FUS
M9VED(")6:7)T=6%L($9O;&1E<G,B"FUS9W-T<B`B0W)E87IA($1I<F5C=&]R
M(@H*(SH@<V5A<F-H+G!H<#HR-#4*;7-G:60@(E9I<G1U86P@1F]L9&5R<R!R
M97%U:7)E(&$@;&%B96PN(@IM<V=S='(@(B(*"B,Z(&QI8B]61F]L9&5R+G!H
M<#HQ-S4@;&EB+U9&;VQD97(N<&AP.C$X,`IM<V=I9"`B5FER='5A;"!)3D)/
M6"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,38*;7-G:60@(E9I<G1U
M86P@24Y"3U@@1F]L9&5R(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C0U
M,B!L:6(O5D9O;&1E<BYP:'`Z,3$T(&QI8B]61F]L9&5R+G!H<#HQ,3D*;7-G
M:60@(E9I<G1U86P@5')A<V@B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M-#$S"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L(%1R87-H($9O;&1E<B(*;7-G
M<W1R(")';VQE<W1E($=U;F]I=6PB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$S,PIM<V=I9"`B5FER='5A;"!F;VQD97(@;&%B96PB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S0*;7-G:60@
M(E=A<FYI;F<B"FUS9W-T<B`B071E;G1I92(*"B,Z(&QO9VEN+G!H<#HQ,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")"
M:6YE(&%I('9E;FET(&EN('-I<W1E;75L("5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8Q.0IM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET
M:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D
M(&%S('-P86T@(@HB;W(@:6YN;V-E;G0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW,C<*(RP@9G5Z>GD*;7-G:60@(B(*(E=H96X@
M9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O
M;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE=&5D/R(*
M;7-G<W1R("(B"B)#:6YD('-T97)G:2!U;B!M97-A:BP@;75T82UL(&EN($=U
M;F]I(&EN(&QO8R!S82UL(&UA<F-H97II(&-A(&9I:6YD('-T97)S+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(E=H96X@;W!E;FEN
M9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T
M87)T(&]N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S
M879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@
M;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E
M(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D
M9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7:&ET96QI<W0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30Q(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@(EEE<R(*;7-G<W1R(")$
M82(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP
M:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@
M96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@
M(D1I<F5C=&]R=6P@=7)M871O<B!V82!F:2!S=&5R<SHB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM
M<V=I9"`B(@HB66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S
M<V%G97,@8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I
M+B(*;7-G<W1R(")$:7)E8W1O<G5L('5R;6%T;W(@=F$@9FD@<W1E<G,Z(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ.0HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!T
M:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2XB"FUS9W-T<B`B1&ER96-T;W)U;"!U
M<FUA=&]R('9A(&9I('-T97)S.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA
M=F%S8W)I<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N
M:6YC.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!C;W!Y:6YG+VUO=FEN
M9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S='(@(E)E9&5N=6UE<W1E(&1I<F5C
M=&]R=6PZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,3`R"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B
M"FUS9W-T<B`B0W)E87)E('-U8F1I<F5C=&]R(&QA("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")9;W4@87)E(&-R
M96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BXB"FUS9W-T<B`B0W)E87)E(&1I
M<F5C=&]R(&EN(')A9&%C:6YA+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R,`HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M9F]L9&5R<RXB"FUS9W-T<B`B0W)E87)E(&1I<F5C=&]R(&EN(')A9&%C:6YA
M+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ,S4*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O
M;&1E<CH@(@IM<V=S='(@(E)E9&5N=6UE<W1E(&1I<F5C=&]R=6PZ("(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,U"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@<&QA
M8V5H;VQD97)S(&EN('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@
M(@HB8W5R<F5N="!M97-S86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T
M=7)E+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R964@
M=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@=V5R
M92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C$V.0IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T
M;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+B(*;7-G
M<W1R("(@+2`D;FT@;65S86IE(&YO:2(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%L97)T+FEN8SHS"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92`Q(&YE=R!M
M97-S86=E+B(*;7-G<W1R("(@+2`D;FT@;65S86H@;F]U(@H*(SH@8V]M<&]S
M92YP:'`Z-#DT"FUS9VED(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T
M:&ES('!A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T
M=&%C:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA=F4@870@;&5A<W0@
M;VYE(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T('5P;&]A
M9"!Y970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD('1H:7,@
M;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S/R(*;7-G<W1R("(B
M"@HC.B!L:6(O24U0+G!H<#HQ,#<T"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V
M92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`B
M1&ER96-T;W)U;"!U<FUA=&]R('9A(&9I('-T97)S.B(*"B,Z(&QI8B])35`N
M<&AP.C$P-SD*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN
M('1H92!F;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`B1&ER96-T;W)U;"!U
M<FUA=&]R('9A(&9I('-T97)S.B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PIM<V=I
M9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S`R"FUS9VED
M("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!0
M1U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#D*;7-G:60@(B(*
M(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-
M12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHV-"!T
M96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+B(*;7-G<W1R
M("(B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#4*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z.#$*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8S"B,L(&9U>GIY"FUS9VED(")9
M;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM
M<V=S='(@(E1E(')O9R!A;&5G92!C96P@<'5T:6X@=6X@9&ER96-T;W(@9&4@
M8V%U=&%R92XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z
M,3,*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!R96-I<&EE;G0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C(Y
M"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N
M92!F:6QE('1O(&%T=&%C:"XB"FUS9W-T<B`B5&4@<F]G(&%L96=E(&-E;"!P
M=71I;B!U;B!D:7)E8W1O<B!D92!C875T87)E+B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@;F5E9"!T;R!H879E(%PB)7-<(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E
M;F%N8V4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP
M.C$S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E9&ER96-T
M960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T<B`B4F5D:7)E
M8W1E87IA(&%C97-T(&UE<V%J(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$T,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI
M<R!M97-S86=E(&]N("5S+B(*;7-G<W1R(")2961I<F5C=&5A>F$@86-E<W0@
M;65S86HB"@HC.B!L:6(O1F]L9&5R+G!H<#HU,#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EEO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(%PB)7-<
M(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")2961E
M;G5M:7)E82!L=6D@7"(E<UPB(&EN(%PB)7-<(B!A(&5S=6%T+B!)871A(&-E
M(&$@>FES('-E<G9E<G5L.B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R
M:6)E9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I
M9"(*;7-G<W1R(")$:7)E8W1O<G5L(%PB)7-<(B!N=2!A(&9O<W0@8W)E870N
M($EA=&$@8V4@82!S<'5S('-E<G9E<G5L.B(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C4Q,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C
M8V5S<V9U;&QY('-U8G-C<FEB960@=&\@7"(E<UPB(@IM<V=S='(@(D1I<F5C
M=&]R=6P@7"(E<UPB(&$@9F]S="!R961E;G5M:70@8W4@<W5C8V5S(&-A(%PB
M)7-<(BXB"@HC.B!L:6(O1F]L9&5R+G!H<#HU-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M.3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(").=6UE;&4@
M8V]M<&QE=#HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G:60@
M(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4'5B;&EC($ME>2(*
M;7-G<W1R(").=6UE;&4@8V]M<&QE=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,38U"B,L(&9U>GIY"FUS9VED(")9;W5R(%)E<&QY+71O.B!A9&1R
M97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S='(@(E)A<W!U;F1E(&QA
M.B`\:3XH;W!T:6]N86PI/"]I/B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-#D*;7-G:60@(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E
M<G1I9FEC871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V%C8V]U;G1?<V5L96-T+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!A
M8V-O=6YT<SHB"FUS9W-T<B`B261E;G1I=&%T:3HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E
M<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W
M(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.3(*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U
M<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ
M"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E
M;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")9;W5R(&UE<W-A9V4@
M=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(D1I<F5C=&]R
M=6P@7"(E<UPB(&$@9F]S="!S=&5R<R!C=2!S=6-C97,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P-@IM<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM
M<V=S='(@(E-E;6YA='5R83HB"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S
M92YP:'`Z,3(X-"!M86EL8F]X+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q
M.`IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM&87)A(%-U8FEE8W1=
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,L(&9U
M>GIY"FUS9VED(")?0F-C(@IM<V=S='(@(D-O<&EE(",R(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")?0FQA8VML
M:7-T(@IM<V=S='(@(DQI<W1A($YE86=R82(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C$U-`HC+"!F=7IZ>0IM<V=I9"`B7T-C(@IM<V=S
M='(@(D-O<&EE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I
M9"`B7T1E;&5T92(*;7-G<W1R(")3=&5R9V4B"@HC.B!L:6(O24U0+G!H<#HY
M-SD*(RP@9G5Z>GD*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@(D1I<F5C=&]A
M<F4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,0HC+"!F
M=7IZ>0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@(DED96YT:71A=&4B"@HC
M.B!L:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G<W1R("(B"@HC
M.B!L:6(O24U0+G!H<#HQ,#(P"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U="(*
M;7-G<W1R(")$96-O;F5C=&%R92(*"B,Z(&UE<W-A9V4N<&AP.C,X-`HC+"!F
M=7IZ>0IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(E-U<G-A($UE
M<V%J=6QU:2(*"B,Z(&QI8B])35`N<&AP.CDW-@HC+"!F=7IZ>0IM<V=I9"`B
M7TYE=R!-97-S86=E(@IM<V=S='(@(DUE<V%J92!.;VDB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*(RP@9G5Z>GD*;7-G
M:60@(E]0<FEN="(*;7-G<W1R(")4:7!A<F5S=&4B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,C@Y"FUS9VED(")?4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@
M;6%I;&)O>"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")?
M4F5F<F5S:"`E<R(*;7-G<W1R(")296EM<')O<W!A=&5A>F$B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM
M<V=I9"`B7U)E<&QY(@IM<V=S='(@(E)A<W!U;F1E(@H*(SH@;&EB+TE-4"YP
M:'`Z.3@Q"B,L(&9U>GIY"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(D-A=71A
M<F4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S$*(RP@9G5Z>GD*;7-G:60@
M(E]396YD($UE<W-A9V4B"FUS9W-T<B`B5')I;6ET92(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S(*(RP@9G5Z>GD*;7-G
M:60@(E]4:')E860B"FUS9W-T<B`B3F5C:71I=&4B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*(RP@9G5Z>GD*;7-G:60@(E]4;R(*
M;7-G<W1R(")#871R92(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$S"B,L(&9U>GIY"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`B4F5C
M=7!E<F5A>F$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,3@*;7-G:60@(E]6:65W(%1H<F5A9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W-@IM<V=I9"`B861D
M<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0T,`HC+"!F=7IZ>0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R(")!=&%S
M86UE;G0B"@HC.B!V:65W+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B871T86-H
M;65N=',N>FEP(@IM<V=S='(@(D%T87-A;65N=&4B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU,3,*;7-G:60@(F)Y=&5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#`*;7-G:60@(F-A;FYO="!C<F5A
M=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C$W,@IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$V-`IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C`*;7-G
M:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$Y-@IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES
M<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38X"FUS9VED
M(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,C(T"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@
M(F9R;VTB"FUS9W-T<B`B9&4@;&$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@P
M"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,C`T"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X.`IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(Y
M('!G<"YP:'`Z-CD*;7-G:60@(FME>2(*;7-G<W1R("(B"@HC.B!F;VQD97)S
M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R
M(")#87-U=&$@9&4@365S86IE(@H*(SH@8V]M<&]S92YP:'`Z,3`V-R!L:6(O
M365S<V%G92YP:'`Z-#8V"B,L(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@
M(DYU;64B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S8*
M(RP@9G5Z>GD*;7-G:60@(FYO;F4B"FUS9W-T<B`B1V%T82(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(F]R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,38*;7-G:60@(G!E<FUI<W-I
M;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,3(*
M;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3@T"FUS9VED(")S97)V:6-E('5N879A:6QA
M8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS9W-T
M<B`B3G4@97AI<W1A(&=R97-E;&D@9&4@<V-R:65R92(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B<W!E
M;&QI;F<@97)R;W)S(@IM<V=S='(@(DYU(&5X:7-T82!G<F5S96QI(&1E('-C
M<FEE<F4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DR"FUS9VED(")S>7-T96T@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P.`IM<V=I
M9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E
M<BYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM<V=S
M='(@(DQI<W1A($YE86=R82(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED
M(")Y;W5R('=H:71E;&ES="(*;7-G<W1R("(B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O<&\O<VM?4TLN<&\`````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P-#(P-#,P`#$P-#$W,S8R-S8T`#`Q-S(P,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C($E-
M4"!3;&]V86L@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`R($QE
M;R!-<F%F:V\@/&QE;T!O96PN<VL^("AO<FEG:6YA;"!T<F%N<VQA=&]R*0HC
M("A#*2`R,#`R+"`R,#`S($EV86X@3F]R:7,@/'9I>$!V87IK82YS:SX*(PIM
M<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U0(#0N
M,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`Q+3`V(#(R.C`P*S`Q
M,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#$M,S`@,C$Z,C8K,#$P
M,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!)=F%N($YO<FES(#QV:7A`=F%Z:V$N
M<VL^7&XB"B),86YG=6%G92U496%M.B!3;&]V86L@/'9I>$!V87IK82YS:SY<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@(#@M8FET7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#(Y
M"FUS9VED("(@("`@("!#8SH@(@IM<V=S='(@(B`@($OS<&EA.B`B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z-#(V"FUS9VED("(@("`@("!4;SH@(@IM<V=S='(@
M(B`@("`@("!0<F4Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,30*;7-G:60@
M(B`@("!$871E.B`B"FUS9W-T<B`B("`@("!$X71U;3H@(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0Q-PIM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R("(@("`@
M("`@($]D.B`B"@HC.B!M86EL8F]X+G!H<#HT,#4@=&5M<&QA=&5S+V9O;&1E
M<G,O:&5A9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME
M>2`E<RDB"FUS9W-T<B`B("A+;.%V97-O=N$@<VMR871K82`E<RDB"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z-#(S"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@
M(B`@(%!R961M970Z("(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHW,`IM<V=I9"`B(&EN("(*;7-G<W1R("(@=B`B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM
M<V=S='(@(B,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G
M<W1R("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@H*(SH@=&AR96%D+G!H
M<#HQ-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T
M<B`B)60@<W!RX78B"@HC.B!M86EL8F]X+G!H<#HQ-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(&1E;&5T960N(@IM<V=S
M='(@(E-P<N%V>2`H)60I(&)O;&D@=GEM87IA;NDN(@H*(SH@;&EB+U-P86TN
M<&AP.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E9"!M97-S86=E<R!H
M879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB4W!RX79Y("@E9"D@8F]L:2!O
M:&SA<V5NZ2!6X;EM=2!S<'+A=F-O=FD@86MO(&)EOF[A("AN:64@;F5V>;YI
M861A;N$I('!ON71A+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M+B(*;7-G<W1R(")3<'+A=GD@*"5D*2!B;VQI(&]H;.%S96[I
M(&%K;R!B9;YNX2`H;FEE(&YE=GF^:6%D86[A*2!P;[ET82XB"@HC.B!L:6(O
M4W!A;2YP:'`Z,3@W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E-P<N%V>2`H)60I(&)O;&D@;WIN
M8>AE;ND@>F$@;F5V>;YI861A;OH@<&^Y='4@*%-004TI(&$@>F%S;&%NZ2!6
MX;EM=2`B"B)S<'+A=F-O=FDN(@H*(SH@;&EB+U-P86TN<&AP.C$V-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T
M960@87,@<W!A;2XB"FUS9W-T<B`B4W!RX79Y("@E9"D@8F]L:2!O>FYAZ&5N
MZ2!Z82!N979YOFEA9&%N^B!P;[ET=2`H4U!!32DN(@H*(SH@;6%I;&)O>"YP
M:'`Z,S4U"B,L('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D($UE
M<W-A9V5S(@IM<V=S='(@(E-P<N%V>2`E9"!AOB`E9"!Z("5D('-P<N%V(@H*
M(SH@;6%I;&)O>"YP:'`Z-C(X"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"
M(@IM<V=S='(@(B5S($M"(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N
M86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T
M(')E;F%M960N(@IM<V=S='(@(B5S('6^(&5X:7-T=6IE+B!6X;D@<')I9>AI
M;F]K("5S(&YE8F]L('!R96UE;F]V86[]+B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HV-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B)7,@<')A=F1E<&]D
M;V)N92!N:64@:F4@<&QA=&[A('-C:'+A;FMA+B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T
M:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G<W1R(")0<FEEZ&EN;VL@)7,@
M8G5D92!P<F5M96YO=F%N_2!N82!Z8>AI871K=2!M97-I86-A+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R("(E<R!A:V-E<'1O=F%L+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"!<(B5S7"(N(@IM<V=S='(@(B5S
M('IR=;EI;"!<(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@9&5C;&EN960N(@IM
M<V=S='(@(B5S(&]D;6EE=&]L+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@
M=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B)7,@;V1P;W9E9&%L
M*&$I(&YA('!OOFEA9&%V:W4@>FESNV]V86YI82!Z86YE<'+A>F1N96YO<W1I
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@
M=&\@7"(E<UPB+B(*;7-G<W1R("(E<R!O9'!O=F5D86P@;F$@<&]Z=F%N:64@
M;F$@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S
M>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@5N%M('!O<VQA;"!I;F9O<FWA
M8VEU(&\@>F%N97!RX7ID;F5N;W-T:2XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT
M871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@<')E9&)EOFYE(&%K8V5P
M=&]V86PN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I
M;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@<&^^861U:F4@:6YF;W)MX6-I=2!O
M(%9AN65J('IA;F5P<N%Z9&YE;F]S=&DN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4X,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T
M<R!Y;W5R('!R97-E;F-E(&%T(%PB)7-<(BXB"FUS9W-T<B`B)7,@=GF^861U
M:F4@5F&Y=2!P<NUT;VUN;W.[(&YA(%PB)7-<(BXB"@HC.B!L:6(O365S<V%G
M92YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@7"(E<UPB+B(*;7-G<W1R(")0<FED86YI92`E<R!D
M;R!<(B5S7"(@8F]L;R#Z<W!EN6[I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O
M(&%M;65N9"!<(B5S7"(N(@IM<V=S='(@(B5S(&)Y('+A9"!U<')A=FEL(%PB
M)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O
M9B!<(B5S7"(N(@IM<V=S='(@(B5S(&)Y(%;A<R!RX60@=7!O>F]R;FEL(&YA
M(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DV"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L
M871E<W0@:6YF;W)M871I;VX@86)O=70@7"(E<UPB+B(*;7-G<W1R("(E<R!B
M>2!RX60@9&]S=&%L(&YA:FYO=KEI92!I;F9O<FWA8VEE(&\@7"(E<UPB+B(*
M"B,Z(&UE<W-A9V4N<&AP.C(X-2!M97-S86=E+G!H<#HR.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC.C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*2(*;7-G<W1R("(E
M<SH@)7,@*"5D)FYB<W`[>B9N8G-P.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N
M9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BDB"FUS9W-T<B`B*%!O='9R
M9&F[('1I971O('IM96YY(&$@<&]K<F'H;W9ANR!N87-L961U:OIC;W4@;V)R
M87IO=FMO=2XI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T
M;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("(H6G)UN6F[(':Y971K
M>2!Z;65N>2!A('9RX71INR!S82!K('#M<V%N:74@<W!RX79Y+BDB"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA(5$U,
M*2(*;7-G<W1R("(H2%1-3"DB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!497AT*2(*;7-G<W1R("(H26)A
M('1E>'0I(@H*(SH@<W!E;&QI;F<N<&AP.C(W.0IM<V=I9"`B(@HB*%)E='5R
M;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H
M86YG97,@;6%D92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U<G)E
M;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H
M3N%V<F%T(&L@<.US86YI=2!S<'+A=GD@<&\@87!L:6MO=F%N[2!VN65T:_UC
M:"!D;W1E<F%JN>UC:"!Z;6EE;BX@6FUE;GD@;F$@(@HB86MT=>%L;F5J(&]B
M<F%Z;W9K92!.14)51-H@87!L:6MO=F%NZ2XI(@H*(SH@<W!E;&QI;F<N<&AP
M.C(W-@IM<V=I9"`B(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A
M;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB
M8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@
M(B(*(BA/9&]S;&&[('-P<N%V=2!P;R!A<&QI:V]V86[M(':Y971K_6-H(&1O
M=&5R86JY[6-H('IM:65N+B!:;65N>2!N82!A:W1UX6QN96H@(@HB;V)R87IO
M=FME($Y%0E5$VB!A<&QI:V]V86[I+BDB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI
M8VMI;F<@3TL@*B(*;7-G<W1R("(J(%!R:61A:G1E(&ML:6MN=73M;2!N82!/
M2R`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,#8*
M;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@
M(BH@4')O<^UM('9Y8F5R=&4@861R97-U*'DI("HB"@HC.B!M86EL8F]X+G!H
M<#HQ-S(*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("(Q('-P<N%V82!B;VQA('9Y;6%Z86[A+B(*"B,Z(&QI8B]3<&%M+G!H
M<#HQ.3<*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B(Q('-P<N%V82!B;VQA(&]H;.%S96[A(%;AN6UU('-Y<W3I;6]VZ6UU
M('-P<N%V8V]V:2!A:V\@;F]R;>%L;F$@*&YI92`B"B)N979YOFEA9&%NX2D@
M<&^Y=&$N(@H*(SH@;&EB+U-P86TN<&AP.C$W-PIM<V=I9"`B,2!M97-S86=E
M(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(Q('-P
M<N%V82!B;VQA(&]H;.%S96[A(&%K;R!B9;YNX2`H;FEE(&YE=GF^:6%D86[A
M*2!P;[ET82XB"@HC.B!L:6(O4W!A;2YP:'`Z,3@Y"FUS9VED("(Q(&UE<W-A
M9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)*961N82!S<'+A=F$@8F]L82!O
M>FYAZ&5NX2!Z82!N979YOFEA9&%N^B!P;[ET=2`H4U!!32D@82!Z87-L86[A
M(%;AN6UU("(*(G-P<N%V8V]V:2XB"@HC.B!L:6(O4W!A;2YP:'`Z,38Y"FUS
M9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS
M9W-T<B`B2F5D;F$@<W!RX79A(&)O;&$@;WIN8>AE;N$@>F$@;F5V>;YI861A
M;OH@<&^Y='4@*%-004TI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,#<*;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(C$P,"!Z;F%K;W8B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$P"FUS9VED("(Q,#`P(&-H
M87)A8W1E<G,B"FUS9W-T<B`B,3`P,"!Z;F%K;W8B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#`X"FUS9VED("(R-3`@8VAA<F%C=&5R<R(*;7-G<W1R
M("(R-3`@>FYA:V]V(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P.0IM
M<V=I9"`B-3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B-3`P('IN86MO=B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O
M('1H:7,@;65S<V%G92XB"FUS9W-T<B`B2R!T96IT;R!S<'+A=F4@:F4@<')I
M<&]J96[]('9EM6O](&]B<N%Z;VL@<&]M96YO=F%N_2`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M
M97-S86=E('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N
M(&YO=&EF:6-A=&EO;B!F<F]M('1H92`B"B)R96-I<&EE;G0N(@IM<V=S='(@
M(E-P<N%V82P@:W1O<OH@<W1E('!O<VQA;&DL('-P]'-O8FEL82!Z87-L86YI
M92!P;W1V<F1E;FEA(&]D('!R[6IE;6-U+B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!3D0B"FUS9W-T<B`B02!:P5)/5D72
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X,@IM<V=I9"`B06-C
M97!T(&%N9"!A9&0@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B4')I:F&[(&$@
M<')I9&&[(&1O(&WT:FAO(&MA;&5N9.%R82(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.#4*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S='(@
M(E!R:6IANR!P;[YI861A=FMU(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<T-@IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B4')I:F%TX2(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3@*;7-G:60@(D%C8V5P=&5D
M.B`B"FUS9W-T<B`B4')I:F%TX3H@(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C8V]U;G0G<R!N86UE.B(*;7-G<W1R
M(").X7IO=B#ZZ'1U.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,C(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<R-0IM<V=I9"`B06-T:6]N
M<R(*;7-G<W1R(")!:V-I92(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C$Y
M,B!L:6(O34E-12](96%D97)S+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D("5S('1O(&UY($%D9')E<W,@0F]O:R(*;7-G<W1R(")0<FED8;L@
M)7,@9&\@;?1J:&\@861R97/A<F$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,#,*;7-G:60@(D%D9"!S;W5R8V4B"FUS9W-T<B`B
M4')I9&&[('ID<F]J(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W
M,PIM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B4')I
M9&&[(&1O(&WT:FAO(&MA;&5N9.%R82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU.#,*;7-G:60@(D%D9"!T;R!M>2!C86QE;F1A<B(*;7-G<W1R
M(")0<FED8;L@9&\@;?1J:&\@:V%L96YDX7)A(@H*(SH@8V]M<&]S92YP:'`Z
M-3@X"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A
M='1A8VAM96YT+B(*;7-G<W1R(")0<NUL;VAA(%PB)7-<(B!B;VQA('!R:7!O
M:F5NX2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3@*;7-G:60@(B(*
M(D%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@
M;&EN92D\+V5M/B(*;7-G<W1R("(B"B+/86RY:64@:&QA=FGH:WD@>F]B<F%Z
M;W9A;ND@<')I('!R97IE<F%N[3H@/&5M/BAV;VQI=&6U;NDL('IA9&%J=&4@
M:V&^9/H@(@HB:&QA=FGH:W4@;F$@;F]V;VT@<FEA9&MU*3PO96T^(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("+/86RY:64@:6YF;W)MX6-I92!M]+YU(&)YNR!Z
M;V)R87IE;ND@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C(*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL
M<R(*;7-G<W1R("+/86RY:64@<&]D<F]B;F]S=&DB"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I;VYA;"!M97-S86=E
M(&1E=&%I;',B"FUS9W-T<B`BSV%LN6EE(&1E=&%I;'D@<W!RX79Y(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E
M9"`E<RXB"FUS9W-T<B`BSV%LN6EE(&1E=&%I;'D@<W!RX79Y(&WTOG4@8GF[
M('IO8G)A>F5NZ2`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HW.`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B
M"FUS9W-T<B`BSV%LN6EE(&1E=&%I;'D@8VAY8F]V96H@<W!RX79Y(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`BSV%LN6EE(&1E=&%I;'D@8VAY8F]V96H@
M<W!RX79Y(&WTOG4@8GF[('IO8G)A>F5NZ2`E<RXB"@HC.B!C;VYT86-T<RYP
M:'`Z.#4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHU,@IM<V=I9"`B061D<F5S<R!";V]K(@IM
M<V=S='(@(D%D<F5SX7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T
M"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(D%D<F5SX7)E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I9"`B(@HB061D<F5S<V5S
M('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A
M8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM<V=S='(@(B(*
M(D%D<F5S>2P@;F$@:W1O<ND@<V$@;6%J^B!P;W-I96QANR!S:W)Y=.D@:_-P
M:64@*$)#0RD@=KEE=&O]8V@@<W!RX78Z(#QE;3XB"B(H=F]L:71EM6[I+"!Z
M861A:G1E(&MAOF3Z(&%D<F5S=2!N82!N;W9O;2!R:6%D:W4I/"]E;3XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S
M97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO
M<'1I;VYA;"P@96YT97(@96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I
M/"]E;3XB"FUS9W-T<B`B(@HB061R97-Y+"!K=&]RZ2!S82!M86KZ(&5X<&QI
M8VET;F4@>G9I87IANR!S('1O=71O(&ED96YT:71O=3H@/&5M/BAV;VQI=&6U
M;NDL("(*(GIA9&%J=&4@:V&^9/H@861R97-U(&YA(&YO=F]M(')I861K=2D\
M+V5M/B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3`@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@Q,0IM<V=I9"`B06QL(@IM<V=S='(@(E:Y
M971K>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*
M;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E
M<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE
M.B(*;7-G<W1R("(B"B)6N65T:WD@<W!RX79Y('8@;F%S;&5D=6KZ8VEC:"!P
M<FEEZ&EN:V]C:"!S82!S=&EA:&YU(&1O(&IE9&[I:&\@<_IB;W)U($U"3U@Z
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R
M(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R
M;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB5KEE=&MY('-P<N%V
M>2!V;R!68;EO;2!P<FEEZ&EN:W4@7"(E<UPB('-T87*Y:64@86MO("5S(&1N
M[2!B=63Z('1R=F%L92`B"B)V>6UA>F%NZ2XB"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]D96QE=&5?871T86-H;65N='-?;6]N=&AL>2YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK960@871T86-H;65N=',@
M;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G
M<W1R("(B"B)6N65T:WD@<W1A<ND@;F%L:6YK;W9A;ND@<'+M;&]H>2!S=&%R
MN6EE(&%K;R`E<R!M97-I86-O=B!B=63Z('9Y;6%Z86[I+B(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E;G0M;6%I;"!F;VQD
M97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB
M"FUS9W-T<B`B(@HB5KEE=&MY('!R:67H:6YK>2!O9&]S;&%N96H@<&^Y='D@
M<W1A<KEI92!A:V\@)7,@;65S:6%C;W8@8G5D^B!V>6UA>F%NZ2XB"@HC.B!A
M8VPN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!R:6=H=',@;VX@
M9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B!<
M(B5S7"(N(@IM<V=S='(@(B(*(E:Y971K>2!P<N%V82!P<F4@<')I9>AI;F]K
M(%PB)7-<(B!P;&%T;ND@<')E('!O=;[M=F%T9;5A(%PB)7-<(B!B;VQI(/IS
M<&6Y;F4@(@HB;V1S='+A;F5NZ2XB"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I
M9"`B06QL;W<@1F]L9&5R($-R96%T:6]N/R(*;7-G<W1R(")0;W9O;&F[('9Y
M=';A<F%N:64@<')I9>AI;FMO=C\B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z-#@*;7-G:60@(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A
M<'!L:65D(&EN(&%N>2!M86EL8F]X/R(*;7-G<W1R(")0;W9O;&F[(&%P;&EK
M;W9A;FEE(&9I;'1R;W9A8^UC:"!P<F%V:61I96P@;F$@M75B;W9OM6[Z('-C
M:'+A;FMU/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z
M,3$P"FUS9VED(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N
M.B(*;7-G<W1R(")!;'1E<FYA=.UV;F4@Z&%S=&D@<')E('3Z=&\@<V5K8VEU
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S(*;7-G:60@(D%L=V%Y
M<R(*;7-G<W1R(")6OF1Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U
M-PIM<V=I9"`B06QW87ES('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B5KYD
M>2!U:VQA9&&[('!R[6QO:'DB"@HC.B!L:6(O365S<V%G92YP:'`Z-3$U"FUS
M9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@
M<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED
M.B`B"FUS9W-T<B`B4')I('!O:W5S92!O(&]D<W1RX6YE;FEE('!R[6QO:'D@
M;F%S=&%L82!C:'EB82X@24U!4"!S97)V97(Z(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C,Y.`IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE
M(&-R96%T:6YG('1H92!N97<@;F]T92XB"FUS9W-T<B`B4')I('9Y=';A<F%N
M[2!N;W9E:B!P;WINX6UK>2!S82!V>7-K>71L82!N97INX6UA(&-H>6)A+B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HS.3<*;7-G:60@(D%N('5N:VYO=VX@97)R
M;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S
M='(@(E!R:2!V>71VX7)A;NT@;F]V96H@^FQO:'D@<V$@=GES:WET;&$@;F5Z
M;N%M82!C:'EB82XB"@HC.B!M97-S86=E+G!H<#HT.38@;6%I;&)O>"YP:'`Z
M-S`Q('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z.0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R("):;V1P;W9E9&%N
MZ2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@(D%N
M<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(EIO9'!O=F5D86[I('-P<N%V>2(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PIM<V=I9"`B07!P
M;'D@1FEL=&5R<R(*;7-G<W1R(")!<&QI:V]V8;L@9FEL=')E(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`B07!L:6MO=F&[(&9I
M;'1R92!N82`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS
M-@IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\B
M"FUS9W-T<B`B07!L:6MO=F&[(&9I;'1R;W9A8VEE('!R879I9&SA('!R:2!P
M<FEH;.%S96[M/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT
M,@IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES
M(&1I<W!L87EE9#\B"FUS9W-T<B`B(@HB07!L:6MO=F&[(&9I;'1R;W9A8VEE
M('!R879I9&SA('!R:2!O8FYO=F5N[2!Z;V)R87IE;FEA('-C:'+A;FMY('!R
M:6IA=/UC:"`B"B)S<'+A=C\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C$T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L
M971E('1H:7,@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;C\B"FUS9W-T<B`B
M3F%O>F%J(&-H8V5T92!V>6UA>F&[('3Z=&\@9&5F:6[M8VEU('9I<G1UX6QN
M96AO('!R:67H:6YK83\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM<V=I9"`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S
M='(@(DYA;WIA:B!C:&-E=&4@=GEM87IANR!T96YT;R!V97)E:F[](&NU^N@_
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z.#4*;7-G:60@(B(*(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM
M96YD960A*2(*;7-G<W1R(").86]Z86H@8VAC971E('9Y;6%Z8;L@=&5N=&\@
M5N&Y(&NU^NAO=OT@<.%R/R`H3F5O9'!O<OKH86UE(2DB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FIS.C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D
M;R!T:&ES/R(*;7-G<W1R(").86]Z86H@=&\@8VAC971E('5R;V)INS\B"@HC
M.B!M97-S86=E+G!H<#HT,#$@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-
M04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(E5RZ&ET
M92!C:&-E=&4@3D%44E9!3$\@=GEM87IANR!T:65T;R!S<'+A=GD_(@H*(SH@
M;&EB+TU)344O0V]N=&5N=',N<&AP.C(R,@IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE
M;G0_(@IM<V=S='(@(E5RZ&ET92!C:&-E=&4@3D%44E9!3$\@=GEM87IANR!T
M^G1O('!R[6QO:'4_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T
M:&ES(&9O;&1E<C\B"FUS9W-T<B`B57+H:71E(&-H8V5T92!V>7!RX7ID;FF[
M('1E;G1O('!R:67H:6YO:S\B"@HC.B!L:6(O24U0+G!H<#HY-38*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@9F]L
M9&5R/R(*;7-G<W1R(")5<NAI=&4@8VAC971E('9Y<'+A>F1N:;L@<')I9>AI
M;F]K('-O('-P86UO;3\B"@HC.B!L:6(O24U0+G!H<#HY-#D*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E
M<C\B"FUS9W-T<B`B57+H:71E(&-H8V5T92!V>7!RX7ID;FF[(%;AN2!+]+D_
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`IM<V=I9"`B
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T
M:&5S92!M97-S86=E<S\B"FUS9W-T<B`B57+H:71E(&-H8V5T92!V>6UA>F&[
M('1I971O('-P<N%V>2`_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C
M<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M-SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI
M<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R(")5<NAI=&4@8VAC971E
M(&]H;.%S:;L@=/IT;R!S<'+A=G4@86MO(&YEN6MO9&[Z/R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E<R]M86EL
M8F]X+VIA=F%S8W)I<'0N:6YC.C<T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*;7-G<W1R
M(")5<NAI=&4@8VAC971E(&]H;.%S:;L@=/IT;R!S<'+A=G4@86MO(&YE=GF^
M:6%D86[Z('!ON71U("AS<&%M*3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3`T"FUS9VED(")!<G)I=F%L(%1I;64B"FUS9W-T<B`BR&%S(&1O<G7H
M96YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3D*;7-G:60@(D%S
M8V5N9&EN9R(*;7-G<W1R(")6>F]S='5P;F4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3<Q"FUS9VED(")!<VLB"FUS9W-T<B`B4W#]=&&[('-A(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#8Y"FUS9VED(")!
M='1A8V@@1FEL97,B"FUS9W-T<B`B4')I<&]J:;L@<_IB;W)Y(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#4P"FUS9VED(")!='1A8V@@
M82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E
M/R(*;7-G<W1R(")6;&^^:;L@5N&Y('9E<F5J;OT@:[7ZZ"!D;R!S<'+A=GD_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$Q,0IM<V=I9"`B071T
M86-H960@1FEL93HB"FUS9W-T<B`B4')I<&]J96[]('/Z8F]R.B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HT-C(@;&EB+T-O;7!O<V4N<&AP.C4U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S
M('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE
M9"XB"FUS9W-T<B`B(@HB4')I<&]J96[]('/Z8F]R(%PB)7-<(B!P<F5K<F'H
M=6IE(&QI;6ET(&YA('9EM6MO<[L@<'+M;&]H>2X@4_IB;W(@3D5"3TP@(@HB
M<')I<&]J96[]+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S<*
M;7-G:60@(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U
M97-T('EO=2!S96YT+B(*;7-G<W1R(")6('!R[6QO:&4@:F4@;V1P;W9E[R!N
M82!68;EU(&MA;&5N9.%R;W;Z('!OOFEA9&%V:W4N(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;&5G96YD+FEN8SHQ-B!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYI;F,Z,30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#DW('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C4U"FUS
M9VED(")!='1A8VAM96YT(@IM<V=S='(@(E!R[6QO:&$B"@HC.B!A='1A8VAM
M96YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!='1A8VAM96YT("5S
M(&1E;&5T960N(@IM<V=S='(@(E!R[6QO:&$@)7,@8F]L82!V>6UA>F%NX2XB
M"@HC.B!C;VUP;W-E+G!H<#HQ,#DW(&QI8B]-97-S86=E+G!H<#HT-S8*;7-G
M:60@(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@
M='EP92(*;7-G<W1R(")0<NUL;VAA(&)O;&$@;V1S='+A;F5NX3H@</1V;V1N
M_2!T>7`@<'+M;&]H>2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-C<*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$P.3,*;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S
M='(@(E!R[6QO:'DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C<X
M"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`BVNAA<W1N[6-I(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*;7-G:60@(D%T=&5N
M=&EO;B(*;7-G<W1R(")0;WIO<B(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*
M;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UP.B!P;[YA9&]V86[I(')O>KGM<F5N
M:64@24U!4"!N96)O;&\@;N%J9&5NZ2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C(X"FUS9VED("(B"B)!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S
M(&EN($A434P@;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*
M(F%D9')E<W-B;V]K/R(*;7-G<W1R("):;V)R87IINR!O8G+A>FMY('8@2%1-
M3"!S<'+A=F%C:"P@86L@:F4@;V1O<VEE;&%T9;4@=B!M;VIO;2!A9')E<^%R
M:3\B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3@*
M;7-G:60@(D%V86EL86)L92!!9&1R97-S(&)O;VMS.B(*;7-G<W1R(")$;W-T
M=7!NZ2!A9')E<^%R93HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S$T"FUS9VED(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R("+(86OA('-A
M(&YA(&]D<&]V9>\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8U]K('1O("5S
M(@IM<V=S='(@(E]3<.2[(&YA("5S(@H*(SH@=&AR96%D+G!H<#HQ,S8@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")"86-K('1O("5S(@IM<V=S='(@(E-PY+L@;F$@)7,B
M"@HC.B!T:')E860N<&AP.C$S,PIM<V=I9"`B0F%C:R!T;R!-=6QT:7!L92!-
M97-S86=E(%9I97<@26YD97@B"FUS9W-T<B`B4W#DNR!N82!Z;V)R87IE;FEE
M('9I86-E<OUC:"!S<'+A=B(*"B,Z('1H<F5A9"YP:'`Z,3,Q"FUS9VED(")"
M86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!O<B!M
M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T
M<B`B6FSA(&%L96)O('IL92!F;W)M=6QO=F%NX2!P;[YI861A=FMA+B!397)V
M97(@;V1P;W9E9&%L.B`E<R(*"B,Z(&UE<W-A9V4N<&AP.C(V-B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,@HC.B!T96UP;&%T97,O8V]M
M<&]S92]R96-O;7!O<V4N:6YC.C(P(&QI8B]396%R8V@N<&AP.C,T"FUS9VED
M(")"8V,B"FUS9W-T<B`B0F-C(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z,38Q"FUS9VED(")"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE
M('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+B(*;7-G<W1R(").:;ZY:64@
M:F4@</1V;V1N_2!T97AT('-P<N%V>2!O('-T879E+B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@
M(LAI97)N82!L:7-T:6YA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q
M-PIM<V=I9"`B0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S
M('1H97D@87)E('-P96-I9FEC86QL>2!R97%U97-T960_(@IM<V=S='(@(EIA
M8FQO:V]V8;L@;V)RX7IK>2!V($A434P@<W!RX79A8V@@8;X@9&\@97AP;&EC
M:71NZ6AO('9YOFEA9&%N:6$_(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(*;7-G
M:60@(D)O9'DB"FUS9W-T<B`B5&5L;R(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,C,@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS.0HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4U('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-S$*;7-G:60@(D)O=&@B"FUS9W-T<B`B3V)E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8W-0IM<V=I9"`B0F]T:"!(96%D97(@3&ES
M=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(DAL879IZ&MY(&$@
M=&5L;R!S<'+A=GDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHR-S(*;7-G:60@(D-?:&%R<V5T(@IM<V=S='(@(EI?;F%K;W;A('-A9&$B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(DMA;&5N9.%R(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M
M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-P;VII
MNR!S;R!V>F1I86QE;OUM(&UA:6QO=OUM('-E<G9E<F]M+B(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@
M=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@<W!O:FF[('-O('9Z9&EA;&5N_6T@;6%I;&]V_6T@<V5R=F5R;VTZ
M("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY
M("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N
M="`B"B)M86EL8F]X+B(*;7-G<W1R("(B"B).96UOOFYO('IO8G)A>FF[("T@
M=B!T96IT;R!S8VARX6YK92!J92!I8F$@<')V_6-H("5S('H@)7,@Z&%S=.T@
M<W!RX79Y+B(*"B,Z(&9O;&1E<G,N<&AP.C(V,R!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(U-0HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O
M<G0N:6YC.C(Q('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ
M.0HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C$@=&5M<&QA
M=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@V"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E
M+FEN8SHS,@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8V"FUS
M9VED(")#86YC96PB"FUS9W-T<B`B6G)UN6F[(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#(Y"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ
M,3$*;7-G:60@(D-A;F-E;"!-97-S86=E(@IM<V=S='(@(EIR=;EINR!S<'+A
M=G4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G:60@(D-A;F-E;&QI;F<@
M=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N
M=&5N=',N(@IM<V=S='(@(EIR=;EE;NUM('-P<N%V>2!N871R=F%L;R!Z<G6Y
M[71E(&IE:B!O8G-A:"XB"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5C;VUP;W-E+FEN8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM<V=I9"`B
M0V,B"FUS9W-T<B`B0V,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V86EL
M86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R`B"B)S
M97)V97(N(@IM<V=S='(@(B(*(DEM<&]R="!C97)T:69I:^%T;W8@;FEE(&IE
M(&1O<W1U<&[]+B!.86ARX79A;FEE('/Z8F]R;W8@;FEE(&IE(&YA('1O;71O
M("(*(G-E<G9E<FD@<&]V;VQE;NDN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8Y-@IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(E9E9/IC
M:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I
M9"`B0VAA;F=E(@IM<V=S='(@(EIM96YINR(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R
M("):;65N:;L@=KEE=&MY(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDR
M"FUS9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S='(@(EIM96YINR!P<FEEZ&EN
M;VLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS9VED("(B"B)#
M:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G
M97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A
M<F4@<V]R=&5D+B(*;7-G<W1R("(B"B):;65N82!N87-T879E;NT@>F]B<F%Z
M96YI82P@<&_H970@<W!RX78@(&YA(&MAOF1E:B!S=')A;F4@82!S</1S;V(@
M=')I961E;FEA("(*(G-P<N%V+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-`IM<V=I9"`B0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T
M=&EN9W,N(@IM<V=S='(@(EIM96YA(&YA<W1A=F5N[2!6X;EH;R!M86EL;W;I
M:&\@<V5R=F5R82!A('!R:67H:6YK;W8N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L
M(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"`B"B)R97!L>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B).87-T
M879E;FEE(&UE;F$L(&%D<F5S>2!A('-I9VYA=/IR>2P@:W1O<ND@<V$@>F]B
M<F%Z=6KZ('9O(%9A;6D@;F%P[7-A;OUC:"`B"B)S<'+A=F%C:"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$R"FUS9VED(")#:&%R86-T97)S('1O
M(&1I<W!L87DZ(@IM<V=S='(@(E!OZ&5T('IN86MO=B!N82!Z;V)R87IE;FEE
M.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED
M(")#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(DMO;G1R
M;VQA(&YO=F5J('!ON71Y('8@<')I9>AI;FMO8V@B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G
M<W1R("):8;EK<G1N^KL@7W:Y971K>2^^:6%D;F4B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]F971C:&UA:6PN:6YC.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V
M97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B6F&Y
M:W)T;FET92!VN65T:WD@;6%I;&]VZ2!S97)V97)Y+"!Z(&MT;W+]8V@@8VAC
M971E('.[86AO=F&[('!ON71U.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-C,*;7-G:60@(D-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@
M;65S<V%G93\B"FUS9W-T<B`B4VMO;G1R;VQO=F&[('!R879O<&ES('!R960@
M;V1O<VQA;NUM('-P<N%V>3\B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHT"FUS9VED(")#:&]O<V4@06-T:6]N.B(*;7-G<W1R(")6>6)E
M<G1E(&%K8VEU.B(*"B,Z(&-O;F9I9R]S97)V97)S+G!H<"YD:7-T.C$W.0IM
M<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@(E9Y8F5R=&4@
M;6%I;&]V_2!S97)V97(Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$V-@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,3<*;7-G:60@(D-H
M;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT
M.B(*;7-G<W1R(")0<F]S[6T@=GEB97)T92!A;&5B;R!U<')A=G1E(&%D<F5S
M=2!V('!R:65S=&]R92!V<')A=F\Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,S0Y"FUS9VED(")#:&]O<V4@=&AE(&%D9')E<W,@
M8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+B(*;7-G<W1R(")6
M>6)E<G1E(&%D<F5SX7(L(&MT;W+]('-A('!O=;YI:F4@<')I('!R:63A=F%N
M[2!N;W;]8V@@861R:65S+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C(Y,PIM<V=I9"`B0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R
M97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N
M(@IM<V=S='(@(B(*(E9Y8F5R=&4@<&]R861I92P@=B!A:V]M('-A(&)U9/H@
M<')E:+5A9.%V8;L@861R97/A<F4@<')I(&1O<.7R86[M(&%D<FEE<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I
M;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RXB"FUS9W-T<B`B
M(@HB2VQI:VYI=&4@)7,@<')E(&MO;G9E<GII=2!O8G+A>FMU(&1O(&9O<FWA
M='4L(&MT;W+]('!O9'!O<G5J92!6X;D@<')E:&QI861AZ"XB"@HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+B(*;7-G<W1R(")+
M;&EK;FET92`E<R!P<F4@<W1I86AN=71I92!O8G+A>FMU+B(*"B,Z(&QI8B]&
M:6QT97(N<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!G;R!T;R`E<R!M86YA9V5M96YT('!A9V4N(@IM<V=S='(@(DML:6MN:71E
M("5S('!R92!S='+A;FMU(&%D;6EN:7-T<N%C:64@)7,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I
M;F1O=RXB"FUS9W-T<B`B2VQI:VYI=&4@)7,@<')E('IO8G)A>F5N:64@2%1-
M3"!O8G-A:'4@=B!S86UO<W1A=&YO;2!O:VYE+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C$V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC
M:R`E<R!T;R!V:65W(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S
M='(@(DML:6MN:71E("5S('!R92!Z;V)R87IE;FEE('IM96ZY96YE:B!K\W!I
M92!O8G+A>FMU+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T
M=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(DML:6MN
M:71E("5S('!R92!Z;V)R87IE;FEE('!R[6QO:'D@=B!S86UO<W1A=&YO;2!O
M:VYE+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP
M87)T+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T
M<B`B2VQI:VYI=&4@)7,@<')E('IO8G)A>F5N:64@;75L=&EP87)T+W)E;&%T
M960@Z&%S=&D@=B!S86UO<W1A=&YO;2!O:VYE+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HY.`IM<V=I9"`B0VQI8VL@:&5R92!T;R!32$]7('1H
M92!);6%G97,B"FUS9W-T<B`B2VQI:VYI=&4@<V5M('!R92!:3T)205I%3DE%
M(&]B<N%Z:V]V(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,S(Q"FUS9VED("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E
M9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S('1O
M("(*(G-E87)C:"XB"FUS9W-T<B`B(@HB2VQI:VYI=&4@;F$@:F5D96X@>B!6
M8;EI8V@@=GEB<F%N_6-H(&%D<F5SX7)O=B!A('!O=&]M(&]Z;F'H=&4@<&]L
M:6$L(&MT;W+I("(*(F-H8V5T92!P<F5HM6%DX79ANRXB"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HQ-S`*;7-G:60@(D-L:6-K('1O(%-A=F4@4$=0
M(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VLB"FUS9W-T<B`B2VQI
M:VYI=&4@<')E('5L;[YE;FEE('9E<F5J;NEH;R!01U`@:[7ZZ&$@9&\@5N%S
M:&\@861R97/A<F$B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(P
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R!T;R!3879E(%,O34E-12!C
M97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")+;&EK;FET92!P<F4@=6QOOF5N:64@4R]-24U%(&-E<G1I9FEKX71U("5S
M(&1O(%;AN6AO(&%D<F5SX7)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDS.`IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP
M;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G<W1R(")+;&EK
M;G5T[6T@;F$@861R97-U('IAZ&YE=&4@<.US8;L@;F]V^B!S<'+A=G4@;V1O
M<VEE;&%T9;5O=FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Y"FUS
M9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE
M<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R(")+;&EK;G5T[6T@;F$@861R97-U
M('-A(&]T=F]R[2!S<'+A=F$B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E
M=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S='(@(EIA='9O<FF[
M(@H*(SH@8V]M<&]S92YP:'`Z-#$W"FUS9VED(")#;&]S92!T:&ES('=I;F1O
M=R(*;7-G<W1R("):871V;W)INR!O:VYO(@H*(SH@9F]L9&5R<RYP:'`Z-#`X
M"FUS9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(EIA='9O<F5N_2!P<FEE
MZ&EN;VLB"@HC.B!F;VQD97)S+G!H<#HT,C@*;7-G:60@(D-O;&QA<'-E(@IM
M<V=S='(@(EIB86QINR(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C,Y"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T<B`B6F)A;&F[(':Y
M971K;R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Y"FUS
M9VED(")#;VQL87!S92!!;&P@1F]L9&5R<R(*;7-G<W1R("):8F%L:;L@=KEE
M=&MY('!R:67H:6YK>2(*"B,Z(&9O;&1E<G,N<&AP.C0R.`IM<V=I9"`B0V]L
M;&%P<V4@1F]L9&5R(@IM<V=S='(@(EIB86QINR!P<FEEZ&EN;VLB"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R
M($EN9&EC871O<CH@(@IM<V=S='(@(E5KX;YK82!F87)B>3HB"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM<V=S='(@
M(DMO;65N=.%R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V,@IM
M<V=I9"`B0V]M<&QE=&5D(@IM<V=S='(@(DAO=&]V;R(*"B,Z(&-O;7!O<V4N
M<&AP.C0Q-@IM<V=I9"`B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B"FUS9W-T
M<B`B4.US8;L@[V%LN6EU('-P<N%V=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,S0*;7-G:60@(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T
M92!W:6YD;W<_(@IM<V=S='(@(E#M<V&[('-P<N%V>2!V(&YO=F]M(&]K;F4_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,PIM<V=I9"`B(@HB0V]M
M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF
M(&)R;W=S97(@<W5P<&]R=',@=&AE("(*(F9E871U<F4I/R(*;7-G<W1R("(B
M"B)0[7-ANR!S<'+A=GD@N71A;F1A<F1N92!V($A434P@1U5)("AA:R!P<F5H
M;&EA9&'H('!O9'!O<G5J92!T^G1O('9L87-T;F]SNRD_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE<W-A
M9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S='(@(DYA<W1A=F5N:64@<W#T<V]B
M('IO8G)A>F5N:6$@<W!RX78N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDW"FUS9VED(")#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N(@IM
M<V=S='(@(DYA<W1A=F5N:64@>F]B<F%Z96YI82!U:^&^;VL@<W!RX78N(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G:60@(D-O;FYE8W1I;VX@
M9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T<B`B24U!4"!S97)V97(@
M=6MO;NAI;"!S<&]J96YI92XB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S
M='(@(E-P;VIE;FEE('-O('-E<G9E<F]M('IL>6AA;&\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R
M;VP@4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R(").87-T879E;FEE('!O
M9'!O<GD@4$=0('!R92!A<&QI:^%C:74@)7,N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%,O
M34E-12!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B3F%S=&%V96YI92!P;V1P
M;W)Y(%,O34E-12!P<F4@87!L:6OA8VEU("5S+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN
M9R!T;R!M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(DYA<W1A=FF[(&UO
MOFYO<W1I('!R92!HM6%D86YI92!S<'+A=BXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O;G1R;VP@=VAE;B!N97<@;6%I;"!W
M:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T
M:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV97,N(@IM<V=S='(@(B(*(DYA<W1A
M=F5N:6$L(&MT;W+I('5RZ'5J^BP@:V5D>2!S82!B=63Z(&MO;G1R;VQO=F&[
M(&YO=ND@<W!RX79Y(&$@Z&D@<V$@(@HB>F]B<F%Z[2!I;F9O<FWA8VEA(&\@
M<'+M8VAO9&4@;F]V96H@<W!RX79Y+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.#0*;7-G:60@(D-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT
M;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T<B`B4VMO;G9E<G1O=F&[('1E>'1O
M=ND@96UO=&EK;VYY(&YA(&=R869I8VOI/R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHU,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")3:V]P[7)O=F&[
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y
M('1O(&9O;&1E<B(*;7-G<W1R(")3:V]P[7)O=F&[(&1O('!R:67H:6YK82(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHV,PIM<V=I9"`B
M0V]R<F5C="(*;7-G<W1R(")/<')A=FF[(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS
M9W-T<B`B3W!R879E;OT@=&5X="(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M,S@R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VUP;&5T92!R
M97%U97-T+B!296%S;VX@1VEV96XZ("5S(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@9&]K;V[H:;L@<&^^:6%D879K=2X@1/1V;V0Z("5S(@H*(SH@871T86-H
M;65N="YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R
M96%T92!T:&4@5D93(&)A8VME;F0Z("5S(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@=GET=F]R:;L@5D93(&)A8VME;F0Z("5S(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C8T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B3F5M;[YN;R!V>6UA>F&[('-P<N%V>2!Z("5S.B`E<R(*"B,Z(&QI8B]3
M97-S:6]N+G!H<#HS,C(*;7-G:60@(D-O=6QD(&YO="!E>&5C=71E(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@(DYE;6^^;F\@=GEK;VYANR!O
M<&5RX6-I92#Z9'*^8GDN(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R(").96UO
MOFYO('9Y8G)ANR!P;[YA9&]V86[]('/Z8F]R('H@<'+M;&]H>2!-4RU43D5&
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L
M9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP
M(&%R8VAI=F4N(@IM<V=S='(@(DYE;6^^;F\@=GEB<F&[('!OOF%D;W9A;OT@
M<_IB;W(@>F\@6FEP(&%R8VCM=G4N(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@<V5C
M=7)E(&-O;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O<FF[(&)E>G!EZ&[I('-P;VIE
M;FEE(',@24U!4"!S97)V97)O;2X@)7,@.B`E<RXB"@HC.B!L:6(O4V5S<VEO
M;BYP:'`Z,C<R"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E
M(&EN9F]R;6%T:6]N(&9R;VT@24U!4"!S97)V97(N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@>NUS:V&[(&EN9F]R;>%C:74@;R!M96YN_6-H(&]B;&%S=&EA
M8V@@>B!)34%0('-E<G9E<F$N(@H*(SH@<V5A<F-H+G!H<#HS,30@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L
M+FEN8SHS.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B5GET=F]R:;LB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHV"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@
M(E9Y='9O<FF[('!R:67H:6YO:R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ,S<*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(E9Y='9O<FF[(&NU
M^NAE(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$T"FUS9VED
M(")#<F5A=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B5GET=F]R:;L@=FER
M='7A;&YY('!R:67H:6YO:R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C
M;W5N=%]S96QE8W0N:6YC.C(V"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N
M="(*;7-G<W1R(")6>71V;W)INR!N;W;](/KH970B"@HC.B!T96UP;&%T97,O
M<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@4W!A;2!F;VQD97(B
M"FUS9W-T<B`B5GET=F]R:;L@;F]V_2!P<FEEZ&EN;VL@<W!A;74B"@HC.B!T
M96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O
M<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W
M(&1R869T<R!F;VQD97(B"FUS9W-T<B`B5GET=F]R:;L@;F]V_2!P<FEEZ&EN
M;VL@:V]N8V5P=&]V(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L
M96-T+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC
M.C0R"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G
M<W1R(")6>71V;W)INR!N;W;]('!R:67H:6YO:R!O9&]S;&%N96H@<&^Y='DB
M"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C$R('1E;7!L
M871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A
M(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B5GET=F]R:;L@;F]V_2!O9'!A
M9&MO=OT@:_2Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R.`IM<V=I
M9"`B(@HB0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R
M(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"`B"B)A;F0@
M9&5L971E('-P86TN(@IM<V=S='(@(B(*(E9Y=';A<F%N:64@<')A=FED:65L
M(&YA('5S<&]R:6%D86YI92!68;EE:B!P<FEC:.%D>F%J^F-E:B!P;[ET>2P@
M:F5J("(*(G1R:65D96YI92!D;R!P<FEEZ&EN:V]V(&$@;6%Z86YI92!N979Y
MOFEA9&%N96H@<&^Y='DN(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C$T"FUS9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T
M<B`B5GET=F]R:;L@;F]V^B"Y86)L\VYU(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T.0IM<V=I9"`B0W)E871E('-T871I;VYE<GD@86YD(&9O<FT@
M<F5S<&]N<V5S+B(*;7-G<W1R(")6>71V;W)INR"Y86)L\VYU(&$@;V1P;W9E
M9&4N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(D%K='7A
M;&YY('!R[7-T=7`@9&\@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA
M:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`B3F%S=&%V96YI92#Z
MZ'1O=B!P<F4@<[MA:&]V86YI92!P;[ET>2!Z(&EN_6-H(/KH=&]V+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0IM<V=I9"`B0W5S=&]M:7IE(&AO
M=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R(").87-T879E;FEE(&]D;W-I96QA
M;FEA('!ON71Y+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N(@IM<V=S='(@(DYA<W1A=F5N:64@^FQO:"P@:W1O<ND@
M<V$@<W#ZN;MA:OH@<')I('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S+B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*
M;7-G:60@(D1A=%]E(@IM<V=S='(@(D3A=%]U;2(*"B,Z(&UE<W-A9V4N<&AP
M.C(V,B!T:')E860N<&AP.C$T-PIM<V=I9"`B1&%T92(*;7-G<W1R(")$X71U
M;2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3`*;7-G:60@(D1E
M8VQI;F5D(@IM<V=S='(@(D]D;6EE=&YU=.DB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,C8T"FUS9VED(")$96-L:6YE9#H@(@IM<V=S='(@(D]D
M;6EE=&YU=.DZ("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*;7-G
M:60@(D1E9F%U;'0B"FUS9W-T<B`B4')E9&YA<W1A=F5NZ2(*"B,Z('1E;7!L
M871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHQ.`IM<V=I9"`B
M1&5F875L="!396%R8V@@1FEE;&0B"FUS9W-T<B`B4')E9&YA<W1A=F5NZ2!P
M;VQE(&BU861A;FEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ,0IM
M<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")0<F5D
M;F%S=&%V96[I(&MR:73I<FEU;2!T<FEE9&5N:6$Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR,0IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C
M=&EO;CHB"FUS9W-T<B`B4')E9&YA<W1A=F5N_2!S;65R('1R:65D96YI83HB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4X"FUS9VED(")$96QE
M9V%T960B"FUS9W-T<B`B4')I9&5L:;LB"@HC.B!F;VQD97)S+G!H<#HS.3@@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B5GEM87IANR(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0=6)L:6,@
M2V5Y(@IM<V=S='(@(E9Y;6%Z8;L@)7,@=F5R96IN_2!KM?KH(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME>7,B"FUS9W-T<B`B6FUA
M>F&[(&%K='7A;&YE(&NU^NAE(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G<W1R(")6
M>6UA>F&[('!R:67H:6YO:R`H<')I9>AI;FMY*2(*"B,Z(&9O;&1E<G,N<&AP
M.C(V-`IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B
M5GEM87IANR!V>6)R86[I('!R:67H:6YK>2(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHT,@IM<V=I9"`B1&5L971E(%-T871I;VYE<GDB
M"FUS9W-T<B`B5GEM87IANR"Y86)L\VYU(@H*(SH@9F]L9&5R<RYP:'`Z,SDX
M"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B5GEM87IA
MNR!V:7)T=>%L;GD@<')I9>AI;F]K(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@5FER
M='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B5GEM87IA
MNR!D969I;NUC:74@=FER='7A;&YE:&\@<')I9>AI;FMU('!R92`E<R(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L
M971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G
M<W1R(")6>6UA>F&[('-T:6%H;G5TZ2!S<'+A=GD@>F\@=GID:6%L96[I:&\@
M<V5R=F5R83\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$Y"FUS
M9VED(")$96QE=&4@9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R(")/9'-T<N%N
M:;L@>B!M]&IH;R!K86QE;F3A<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8X"FUS9VED(")$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A
M="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(E9Y;6%Z8;L@<W1A<ND@
M;F%L:6YK;W9A;ND@<'+M;&]H>2!N82!Z8>AI871K=2!M97-I86-A/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3`*;7-G:60@(D1E;&5T92!O;&0@
M<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G
M<W1R(")6>6UA>F&[('-T87+I('!R:67H:6YK>2!O9&]S;&%N96H@<&^Y='D@
M;F$@>F'H:6%T:W4@;65S:6%C83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C`U"FUS9VED(")$96QE=&4@<W!A;2!M97-S86=E<R(*;7-G<W1R(")6
M>6UA>F&[('-P<N%V>2!S;R!S<&%M;VTB"@HC.B!M97-S86=E+G!H<#HT.3D@
M;6%I;&)O>"YP:'`Z-S(W('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,C`*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS."!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C@*;7-G:60@(D1E;&5T960B"FUS9W-T
M<B`B5GEM87IA;NDB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8S
M"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(E9Y;6%Z86[I('-P
M<N%V>2(*"B,Z(&-O;7!O<V4N<&AP.C4V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB)7-<(BXB"FUS9W-T<B`B4'+M
M;&]H82!<(B5S7"(@8F]L82!V>6UA>F%NX2XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG(&%N9"!-;W9I;F<@365S<V%G
M97,B"FUS9W-T<B`B5GEM87KA=F%N:64@82!P<F5S^G9A;FEE('-P<N%V(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-PIM<V=I9"`B1&5N>2!R
M97%U97-T(@IM<V=S='(@(EIA;6EE=&YUNR!P;[YI861A=FMU(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4T,@IM<V=I9"`B1&5N>2!R97%U97-T
M(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T<B`B6F%M:65T;G6[
M('!OOFEA9&%V:W4@;F$@>FES=&5N:64@>F%N97!RX7ID;F5N;W-T:2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C`*;7-G:60@(D1E<V-E;F1I;F<B
M"FUS9W-T<B`B6F]S='5P;F4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-@IM
M<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&]P:7,B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@
M(D1E=&%I;',B"FUS9W-T<B`B4&]D<F]B;F]S=&DB"@HC.B!C;VUP;W-E+G!H
M<#HU.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ED(&YO="!A='1A8V@@7"(E
M<UPB(&%S('1H92!F:6QE('=A<R!E;7!T>2XB"FUS9W-T<B`B4_IB;W(@7"(E
M<UPB(&YE8F]L('!R:7!O:F5N_2P@;&5B;R!B;VP@<'+A>F1N>2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8U"FUS9VED(")$:6T@<VEG;F%T=7)E
M<S\B"FUS9W-T<B`B6F]B<F%Z;W9ANR!S:6=N873Z<GD@;65N96H@=OUR87IN
M93\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM
M<V=I9"`B1&ES<&QA>2(*;7-G<W1R(").87-T879E;FEE('IO8G)A>F5N:6$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Y"FUS9VED(")$:7-P;&%Y
M(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T
M<B`B6F]B<F%Z:;L@<&]T=G)D96YI92!P;R!O9&]S;&%N[2!S<'+A=GD_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W-`IM<V=I9"`B1&ES<&QA>2!I
M;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B6F]B<F%Z:;L@=B!T96QE('-P
M<N%V>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D1I
M<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\B"FUS9W-T
M<B`B6F]B<F%Z:;L@;WINX6UE;FEE(&\@<')I:F%T[2!N;W9E:B!S<'+A=GD_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T-@IM<V=I9"`B1&ES<&QA
M>2!T:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS
M9W-T<B`B6F]B<F%Z:;L@;&EN:W4@7")/9'-T<N%N:;L@<W!A;5PB('8@;65N
M=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,X"FUS9VED(")$:7-P
M;&%Y('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`B6F]B<F%Z:;L@;&EN:W4@7")6>7!RX7ID;FF[($]D<&%D:V]V
M_2!K]+E<(B!V(&UE;G4_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC.C$Q"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R(")0;W6^
M:71I92(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I
M9"`B1&\@3D]4(&UA=&-H(@IM<V=S='(@(DYE=GEH;W9U:F4B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B1&\@3F]T($-H
M96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B3F5K;VYT<F]L
M;W9ANR!P<FEEZ&EN:WD@;F$@;F]V^B!P;[ET=2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-#`*;7-G:60@(D1O(&YO="!G96YE<F%T92!A(&QI;FL@
M:6X@=&AE($9R;VTZ(&-O;'5M;B(*;7-G<W1R(").979Y=';A<F&[(&QI;FMU
M('IO('-TY7!C82!/9#HB"@HC.B!L:6(O24U0+G!H<#HQ,#4W"FUS9VED(")$
M;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/R(*;7-G<W1R(")#:&-E
M=&4@;W1V;W)INR!T96X@<')I9>AI;F]K/R(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C,Q"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_
M(%-I9VX@=7`N(@IM<V=S='(@(DYE;>%T92!EN71E(/KH970_(%IA<F5G:7-T
M<G5J=&4@<V$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$R-@IM<V=I9"`B1&]N92(*;7-G<W1R(")(;W1O=F\B"@HC.B!L:6(O34E-
M12]#;VYT96YT<RYP:'`Z,3DY"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL
M;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(E-T:6%H;G6[("5S('9O
M(&9O<FWA=&4@+GII<"(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ
M:7`@9FEL92DB"FUS9W-T<B`B4W1I86AN=;L@=KEE=&MY('!R[6QO:'D@*&9O
M<FWA="`N>FEP*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C(P"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RDB"FUS9W-T<B`B4W1I86AN
M=;L@<')I9>AI;F]K("AP<FEEZ&EN:WDI(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;
M+GII<"!F;W)M871=(@IM<V=S='(@(E-T:6%H;G6[('!R:67H:6YO:R`H<')I
M9>AI;FMY*2!;9F]R;>%T("YZ:7!=(@H*(SH@;&EB+TU)344O0V]N=&5N=',N
M<&AP.C$Y.0IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M870B"FUS9W-T
M<B`B4W1I86AN=;L@=F\@9F]R;>%T92`N>FEP(@H*(SH@;65S<V%G92YP:'`Z
M-#DW(&UA:6QB;W@N<&AP.C<P-B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S
M='(@(DMO;F-E<'0B"@HC.B!F;VQD97)S+G!H<#HS-S$*;7-G:60@(D1R869T
M(&9O;&1E<B(*;7-G<W1R(")0<FEEZ&EN;VL@:V]N8V5P=&]V(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T
M<R!F;VQD97(Z(@IM<V=S='(@(E!R:67H:6YO:R!K;VYC97!T;W8Z(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I9"`B12UM86EL($%D9')E
M<W,B"FUS9W-T<B`B12UM86EL;W;A(&%D<F5S82(*"B,Z(&QI8B]-86EL8F]X
M+G!H<#HS,3D*;7-G:60@(D5.1"(*;7-G<W1R(")+3TY)14,B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HW-`IM<V=I9"`B15)23U(Z(%EO=7(@
M;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D+B(*;7-G<W1R(")#2%E"
M03H@5F&Y=2!S<'+A=G4@;F5B;VQO(&UOOF[I(&1O<G7H:;LB"@HC.B!F;VQD
M97)S+G!H<#HS.3D@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$Y
M"FUS9VED(")%9&ET(@IM<V=S='(@(E5P<F%V:;LB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM
M<V=S='(@(E5P<F%V:;L@Z&EE<FYU(&QI<W1I;G4B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G
M<W1R(")5<')A=FF[('!ON71O=ND@9FEL=')E(@H*(SH@9F]L9&5R<RYP:'`Z
M,SDY('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-@IM<V=I9"`B161I
M="!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")5<')A=FF[('9I<G1UX6QN>2!P
M<FEEZ&EN;VLB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F
M:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B57!R879INR!D969I;NUC:74@=FER
M='7A;&YE:&\@<')I9>AI;FMU('!R92`E<R(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHR,PIM<V=I9"`B161I="!7:&ET96QI<W0B"FUS9W-T
M<B`B57!R879INR!B:65L=2!L:7-T:6YU(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET('EO=7(@8FQA8VML:7-T(@IM
M<V=S='(@(E5P<F%V:;L@Z&EE<FYU(&QI<W1I;G4B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@
M<G5L97,B"FUS9W-T<B`B57!R879INR!F:6QT<F]V86-I92!P<F%V:61LX2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#D*;7-G:60@(D5D:70@>6]U
M<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N
M=',N(@IM<V=S='(@(E5P<F%V:;L@;F%S=&%V96YI82!P<F4@<'+M<W1U<"!K
M(&EN_6T@92UM86EL;W;];2#ZZ'1O;2XB"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS
M9W-T<B`B57!R879INR!B:65L=2!L:7-T:6YU(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHR,SD*;7-G:60@(D5M86EL($%D9')E<W,B
M"FUS9W-T<B`B12UM86EL;W;A(&%D<F5S82(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B16UP=&EE9"!A;&P@;65S<V%G
M97,@9G)O;2`E<RXB"FUS9W-T<B`B5GEM87IA;ND@=KEE=&MY('-P<N%V>2!Z
M("5S+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS
M9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B5GEP<N%Z9&YINR!P<FEE
MZ&EN;VL@*'!R:67H:6YK>2DB"@HC.B!F;VQD97)S+G!H<#HR-C4*;7-G:60@
M(D5M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B5GEP<N%Z9&YINR!V
M>6)R86[I('!R:67H:6YK>2(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C,Y"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`B
M5GEP<N%Z9&YINR!/9'!A9&MO=OT@:_2Y(@H*(SH@;&EB+TE-4"YP:'`Z.34V
M"FUS9VED(")%;7!T>2!?4W!A;2(*;7-G<W1R(")/9'-T<N%N:;L@7W-P86TB
M"@HC.B!L:6(O24U0+G!H<#HY-#D*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G
M<W1R(")6>7!RX7ID;FF[($]D<&%D:V]V_2!?:_2Y(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C8*
M;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B4&]V
M;VQINR!P<N%C=2!S(%!'4#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B
M16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")0;W9O;&F[
M('!RX6-U(',@4R]-24U%/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.3D*;7-G:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G<W1R(")0
M;W9O;&F[('IO8G)A>F]V86YI92!U:^&^;VL@<W!RX78_(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,V"FUS9VED(")%;F-R7WEP=&EO
M;B!/<'1I;VYS(@IM<V=S='(@(DYA<W1A=F5N:6$@N6E?9G)O=F%N:6$B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$X"FUS9VED(")%;F-R
M>7!T960B"FUS9W-T<B`B6F&Y:69R;W9A;NDB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3$V(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3@*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U,2!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C4S"FUS9VED(")%;F0B"FUS9W-T<B`B2V]N:65C(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C,Y-0IM<V=I9"`B16YD(&9O<G=A<F1E9"!M
M97-S86=E(@IM<V=S='(@(DMO;FEE8R!P<F5P;W-L86YE:B!S<'+A=GDB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,S4R"FUS9VED(")%;F0@;65S<V%G92(*;7-G
M<W1R(")+;VYI96,@<W!RX79Y(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S
M='(@(DMO;FEE8R!S<'+A=GD@;V0@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B
M16YT97(@4&%S<W!H<F%S92(*;7-G<W1R("):861A:G1E(&AE<VQO('!R92!K
MM?KH(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.CD*;7-G
M:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<B(*
M;7-G<W1R("):861A:G1E(&UE;F\@<')E(%;AN2!N;W;]('!R:67H:6YO:R!S
M;R!S<&%M;VTB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN
M8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S
M(&9O;&1E<B(*;7-G<W1R("):861A:G1E(&UE;F\@<')E(%;AN2!N;W;]('!R
M:67H:6YO:R!K;VYC97!T;W8B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA
M:6QS96QE8W0N:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("):861A:G1E(&UE;F\@
M<')E(%;AN2!N;W;]('!R:67H:6YO:R!O9&]S;&%N96H@<&^Y='DB"@HC.B!T
M96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R
M('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B
M6F%D86IT92!M96YO('!R92!6X;D@;F]V_2!O9'!A9&MO=OT@:_2Y(@H*(SH@
M;&EB+U-E87)C:"YP:'`Z-#8*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S
M='(@(D-E;.$@<W!RX79A(@H*(SH@;65S<V%G92YP:'`Z,3DT(&-O;7!O<V4N
M<&AP.C$Q-C0@=&AR96%D+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;G1R>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D
M<F5S<R!B;V]K(@IM<V=S='(@(E!O;&^^:V$@7"(E<UPB(&)O;&$@^G-P9;EN
M92!V;&^^96[A(&1O(&%D<F5SX7)A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HS.#$@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,SDP"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T
M<B`B0VAY8F$B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0S,2!L:6(O24U!
M4"]#;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C
M;VYN96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R(")#
M:'EB82!P<FD@<')I<.%J86YI('-A(&L@24U!4"!S97)V97)U+B`E<R`Z("5S
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3`@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`B0VAY8F$@<')I(&]D;W-I
M96QA;NT@;V1P;W9E9&4Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,#(*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*
M;7-G<W1R(")59&%L;W.[(&)O;&$@^G-P9;EN92!V>6UA>F%NX2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<P"FUS9VED(")%=F5R>2`Q-2!M:6YU
M=&5S(@IM<V=S='(@(DMAOF3]8V@@,34@;6EN^G0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S8W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(DMAOF3]8V@@,S`@<V5K^FYD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<V.0IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DMAOF3]
M8V@@-2!M:6[Z="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S$*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")+8;YD^B!P;VP@:&]D:6YU
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V.`IM<V=I9"`B179E<GD@
M;6EN=71E(@IM<V=S='(@(DMAOF3Z(&UI;OIT=2(*"B,Z(&9O;&1E<G,N<&AP
M.C0S-@IM<V=I9"`B17AP86YD(@IM<V=S='(@(E)O>F)A;&F[(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!
M;&PB"FUS9W-T<B`B4F]Z8F%L:;L@=KEE=&MO(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R
M<R(*;7-G<W1R(")2;WIB86QINR!VN65T:WD@<')I9>AI;FMY(@H*(SH@9F]L
M9&5R<RYP:'`Z-#,V"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(E)O
M>F)A;&F[('!R:67H:6YO:R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,T,"!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3,*
M;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R(")$;W!L;FF[(&UE;N$O861R
M97-Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-3$*;7-G:60@(D5X
M<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL
M>2!I;B!T:&4@8F%C:V=R;W5N9#\B"FUS9W-T<B`B1&]P;&YINR!M96[A('8@
M;VMN92!N82!P[7-A;FEE('-P<N%V>2!A=71O;6%T:6-K>2!N82!P;WIA9.T_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV.`IM<V=I9"`B17AP86YD
M('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L
M9&5R<R!V:65W/R(*;7-G<W1R("));7!L:6-I=&YE(')O>F)A;&F[(&-E;/T@
M<W1R;VT@<')I9>AI;FMO=B!V('IO>FYA;64@<')I9>AI;FMO=C\B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(T-2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z
M,3`Q"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T<B`B4F]B>F&U=6IE('-A(@H*
M(SH@;&EB+TE-4"YP:'`Z.38W(&QI8B])35`N<&AP.CDV.0IM<V=I9"`B1E]E
M=&-H($UA:6PB"FUS9W-T<B`B4U]T:6%H;G6[('!ON71U(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#0*;7-G:60@(D9E=&-H($UA:6PB"FUS9W-T<B`B4W1I86AN
M=;L@<&^Y='4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4W"FUS9VED
M(")&971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")3
M=&EA:&YUNR!P;[ET=2!V(&YO=F]M(&]K;F4_(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C0V"FUS9VED(")&971C:"!M97-S86=E<R!U
M<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(E-T:6%H;G6[('-P<N%V>2!P<FD@
M<')I:&SA<V5N[3\B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S(@IM
M<V=S='(@(E-T:6%H;G5T_6-H("5D('-P<N%V('H@)7,B"@HC.B!L:6(O1F5T
M8VAM86EL+G!H<#HR.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q
M(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")3=&EA:&YU=.$@,2!S<'+A=F$@
M>B`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL
M+G!H<#HR.#D@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"FUS9VED(")&971C:&UA
M:6PZ("(*;7-G<W1R(")&971C:&UA:6PZ(@H*(SH@;&EB+T9E=&-H;6%I;"YP
M:'`Z,CDS"FUS9VED(")&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS
M9W-T<B`B1F5T8VAM86EL.B"^:6%D;F4@;F]VZ2!S<'+A=GDN(@H*(SH@;&EB
M+TE-4"YP:'`Z.3<S"FUS9VED(")&:5]L=&5R<R(*;7-G<W1R(")&:5]L=')E
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DS('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C0P"FUS9VED(")&:6QE(@IM
M<V=S='(@(E/Z8F]R(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C,Q"FUS9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(").87-T879E;FEA
M(&9I;'1R;W8B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0IM
M<V=I9"`B1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(DYA<W1A=F5N:6$@9FEL
M=')O=B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#@*;7-G:60@(D9I
M;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`B
M3V1S='+A;FF[('IO('-P<N%V>2!N863A=FMY(&$@;F5S;'6Y;ND@=OUR87IY
M/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,3$*;7-G
M:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M
M+B(*;7-G<W1R(").82!T;VUT;R!S>7-TZ6UE(&IE('!O9'!O<F$@9FEL=')O
M=B!Z86OA>F%NX2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS
M9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R92(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+VYO=&%C=&EV92YI;F,Z,PIM<V=I9"`B1FEL=&5R<R!.3U0@06-T
M:79E(@IM<V=S='(@(D9I;'1R92!N:64@<_H@86MT:79O=F%NZ2(*"B,Z(&QI
M8B]&:6QT97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97)S
M.B`E<R!M86YA9V5M96YT('!A9V4B"FUS9W-T<B`B1FEL=')E.B!S='+A;FMA
M(&YA('-P<N%V=2`E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3@V"FUS9VED(")&:6YD(@IM<V=S='(@(DBU861ANR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.3,*;7-G:60@(D9I<G-T($UA:6QB;W@@
M4&%G92(*;7-G<W1R(")0<G;A('-T<N%N:V$@<V-H<N%N:WDB"@HC.B!M86EL
M8F]X+G!H<#HS,C<*;7-G:60@(D9I<G-T(%!A9V4B"FUS9W-T<B`B4')VX2!S
M='+A;FMA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED
M(")&;U]R=V%R9"(*;7-G<W1R(")07W)E<&]S;&&[(@H*(SH@9F]L9&5R<RYP
M:'`Z,C0U('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL
M.C4*;7-G:60@(D9O;&1E<B!!8W1I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S
M='(@(D%K8VEE(',@<')I9>AI;FMA;6D@+2!P;W1V<F1E;FEE(@H*(SH@9F]L
M9&5R<RYP:'`Z,C@R('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD*(SH@
M=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHV"B,Z('1E
M;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@
M(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T<B`B4W!RX79A('!R:67H:6YK;W8B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PIM<V=I9"`B1F]L9&5R(%-U
M;6UA<GDB"FUS9W-T<B`B26YF;W)MX6-I92!O('!R:67H:6YK=2(*"B,Z(&%C
M;"YP:'`Z,C,*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D
M+B(*;7-G<W1R("):9&EEM6%N:64@<')I9>AI;FMO=B!N:64@:F4@<&]V;VQE
M;NDN(@H*(SH@9F]L9&5R<RYP:'`Z-#<*;7-G:60@(D9O;&1E<B!U<V4@:7,@
M;F]T(&5N86)L960N(@IM<V=S='(@(E!O=;YI=&EE('!R:67H:6YK;W8@;FEE
M(&IE('!O=F]L96[I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3<*
M;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X
M('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@(D9O<FWA
M="!DX71U;74@>F]B<F%Z96[]8V@@<W!RX78@<')E('-P<N%V>2!D871O=F%N
MZ2!D;F5S(@H*(SH@8V]M<&]S92YP:'`Z.#$X('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")0<F5P;W-L
M8;LB"@HC.B!C;VUP;W-E+G!H<#HX,#,*;7-G:60@(D9O<G=A<F0Z(@IM<V=S
M='(@(E!R97!O<VQANSHB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S@P"FUS9VED
M(")&;W)W87)D960@;65S<V%G92(*;7-G<W1R(")0<F5P;W-L86[A('-P<N%V
M82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")0<F5P;W-L
M86[A('-P<N%V82!O9"`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT,#(*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S
M='(@(D]D<&]V9>\@;F$@OFEA9&]SNR!O('II<W1E;FEE('IA;F5P<N%Z9&YE
M;F]S=&D@*%A86"DB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE
M861E<G,N:6YC.C(W"FUS9VED(")&<F]?;2(*;7-G<W1R(")?3V0B"@HC.B!M
M97-S86=E+G!H<#HR-C,@=&AR96%D+G!H<#HQ-#@@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z.3D*(SH@;&EB+U-E87)C:"YP:'`Z,C(*;7-G:60@
M(D9R;VTB"FUS9W-T<B`B3V0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`V"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`B4W!I871OZ&[A(&%D
M<F5S82(*"B,Z(&-O;7!O<V4N<&AP.C@Q-2!C;VUP;W-E+G!H<#HX,3D*;7-G
M:60@(D9W9#HB"FUS9W-T<B`B1G=D.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.38*
M;7-G:60@(D9W9#H@(@IM<V=S='(@(D9W9#HB"@HC.B!C;VUP;W-E+G!H<#HQ
M,CDX"B,L('!H<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R=V%R9&5D($UE
M<W-A9V5S(@IM<V=S='(@(D9W9#H@)74@<')E<&]S;&%N_6-H('-P<N%V(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS9W-T
M<B`B5KEE;V)E8V[I(&YA<W1A=F5N:6$B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M97-S86=E
M<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B4W1I86AN=;L@:6)A(&YO=ND@<W!R
MX79Y("AI8F$@24U!4"DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHS,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34T"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW,C@*;7-G:60@(D=O(@IM<V=S='(@(D]D
M;W-L8;LB"@HC.B!T:')E860N<&AP.C$S-0IM<V=I9"`B1V\@=&\@365S<V%G
M92(*;7-G<W1R(")0<F5J<[L@;F$@<W!RX79U(@H*(SH@;&EB+TE-4"YP:'`Z
M-3`Y"B,L('!H<"UF;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O:R!E
M;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B4')E:G.[(&1O(&%D<F5SX7)A(&YA
M('!O;&^^:W4@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S
M-@IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(E5M;[YN:;L@<'+M<W1U
M<"(*"B,Z(&UE<W-A9V4N<&AP.C4T,B!L:6(O1FEL=&5R+G!H<#HQ,#4@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$Q,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ
M,3,*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,3D*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-C@*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"B,Z(&QI8B]-24U%+U9I97=E<B]A
M<'!L961O=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<R
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%4D4B"FUS9W-T<B`B5%4B
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S$@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$R,`HC.B!L:6(O34E-12]6:65W97(O<F5L
M871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z(&-O
M;7!O<V4N<&AP.C(V,`IM<V=I9"`B2%1-3"!697)S:6]N(&]F($UE<W-A9V4B
M"FUS9W-T<B`B2%1-3"!V97)Z:6$@<W!RX79Y(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M2&QA=FGH:WDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC
M.C4*;7-G:60@(DAE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S
M:6YG.B(*;7-G<W1R(")4=2!J92!S<'+A=F$L(&MT;W+Z('-T92!P[7-A;&DZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U-@IM<V=I9"`B2&ED9&5N
M(@IM<V=S='(@(E-K<GETZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-34*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE=R(*;7-G<W1R(")3:W)Y
M=.D@=B!Z;V)R87IE;NT@=FSA:VEE;B(*"B,Z(&UA:6QB;W@N<&AP.C,T.0IM
M<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@(E-K<GF[('9Y;6%Z86[I(@H*
M(SH@9F]L9&5R<RYP:'`Z,C<W"FUS9VED(")(:61E(%5N<W5B<V-R:6)E9"(*
M;7-G<W1R(")3:W)YNR!N97!R:6ALX7-E;NDB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B"FUS9W-T<B`B5GES
M;VOA(@H*(SH@;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N<&AP.C<Q,2!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H(%!R:6]R
M:71Y(@IM<V=S='(@(E9Y<V]KX2!P<FEO<FET82(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,PIM<V=I9"`B2&EG:&5S="(*;7-G<W1R
M(").86IV>;FY:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<V"FUS
M9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B
M"FUS9W-T<B`B06MO('-A(&UA:OH@>F]B<F%Z:;L@<'+M;&]H>3\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`T"FUS9VED(")(;W<@=&\@871T<FEB
M=71E('%U;W1E9"!L:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(D%K;R!O>FYA
MZ&F[(&-I=&]V86[I(')I861K>2!V(&]D<&]V961I(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T<B`B24U!4"(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(Y"FUS9VED("))34%0("A!
M=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(DE-05`@*$%U=&]M871I
M8VMY(&1E=&5K;W9ANR!P<F]T;VMO;'DI(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HS.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!397)V97(@8VQO
M<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G
M<W1R("))34%0('-E<G9E<B!U:V]NZ&EL('-P;VIE;FEE+B!397)V97(@;V1P
M;W9E9&%L.B`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38U
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V97(@
M4U-,(@IM<V=S='(@(DE-05`@8V5Z(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,34R"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE
M9"!C97)T:69I8V%T92DB"FUS9W-T<B`B24U!4"!C97H@4U-,("AC97)T:69I
M:^%T('!O9'#M<V%N_2!S86W];2!S96)O=2DB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$V-@IM<V=I9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS
M:6=N960I(@IM<V=S='(@(DE-05`@8V5Z(%-33"`H8V5R=&EF:6OA="!P;V1P
M[7-A;OT@<V%M_6T@<V5B;W4I(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS
M-C@*;7-G:60@(DE-05`@<V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B24U!4"!S97)V97(@=6MO;NAI;"!S<&]J96YI92XB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-"!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(DE-05`L
M(&)E>B!43%,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C0Y"FUS9VED
M("))34%0+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@(DE-05`O4$]0,R!E
M+6UA:6QO=ND@<V5R=F5R>2(*"B,Z(&QI8B])35`N<&AP.C@S-PIM<V=I9"`B
M24Y"3U@B"FUS9W-T<B`B4')I:F%TZ2!S<'+A=GDB"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U
M(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB
M"FUS9W-T<B`B06L@<&]UONUV871E(%-33"!A;&5B;R!43%,L(&UU<^UT92!N
M86AR8;L@4$A0(')O>KGM<F5N:64@;W!E;G-S;"XB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,@IM<V=I9"`B268@>6]U
M(&-O;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL
M(&)E(&QO<W0A(@IM<V=S='(@(B(*(D%K(&)U9&5T92!P;VMR8>AO=F&[+"!V
MN65T:WD@<W!RX79Y('8@<')I9>AI;FMU*'!R:67H:6YK;V-H*2!B=63Z('-T
M<F%T96[I(2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX
M,@IM<V=I9"`B26=N;W)E(@IM<V=S='(@(FEG;F]R;W9ANR(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L
M;"(*;7-G<W1R("))9VYO<F]V8;L@=KEE=&MY(@H*(SH@=&5M<&QA=&5S+W-A
M=F5I;6%G92]S879E:6UA9V4N:6YC.C@*;7-G:60@(DEM86=E(@IM<V=S='(@
M(D]B<N%Z;VLB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P
M"FUS9VED("));7!O<G0B"FUS9W-T<B`B26UP;W)T(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O:6UP;W)T
M7VME>2YI;F,Z-C4*;7-G:60@(DEM<&]R="!+97DB"FUS9W-T<B`B26UP;W)T
M;W9ANR!KM?KH(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S.0IM<V=I
M9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`B26UP;W)T;W9ANR!KM?KH;W;]
M('#A<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(W"FUS
M9VED("));7!O<G0@365S<V%G97,B"FUS9W-T<B`B26UP;W)T;W9ANR!S<'+A
M=GDB"@HC.B!P9W`N<&AP.C0Q"FUS9VED("));7!O<G0@4$=0($ME>2(*;7-G
M<W1R("));7!O<G1O=F&[(%!'4"!KM?KH(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHY,0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC
M871E(@IM<V=S='(@(DEM<&]R=&]V8;L@;W-O8F[](&-E<G1I9FEKX70B"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("));7!O
M<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@(DEM<&]R=&]V
M8;L@;W-O8F[]('!R:7;A=&YY(%!'4"!KM?KH(@H*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B
M;&EC(%!'4"!+97DB"FUS9W-T<B`B26UP;W)T;W9ANR!O<V]B;OT@=F5R96IN
M_2!01U`@:[7ZZ"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHT"FUS9VED("));7!O<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E
M<R(*;7-G<W1R("));7!O<G1O=F&[(&]S;V)NZ2!3+TU)344@8V5R=&EF:6OA
M='DB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHT,@IM<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS
M9W-T<B`B26UP;W)T;W9ANR!V97)E:F[](&NU^N@B"@HC.B!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0
M($ME>2(*;7-G<W1R("));7!O<G1O=F&[('9E<F5J;OT@4$=0(&NU^N@B"@HC
M.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I9"`B26UP
M;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(DEM<&]R=&]V8;L@=F5R
M96IN_2!3+TU)344@:[7ZZ"(*"B,Z('-M:6UE+G!H<#HQ-@IM<V=I9"`B26UP
M;W)T(%,O34E-12!+97DB"FUS9W-T<B`B26UP;W)T;W9ANR!3+TU)344@:[7Z
MZ"(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B
M26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R("));7!O<G1O=F&[('/Z8F]R(&UB
M;W@B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD
M97(@)7,N(@IM<V=S='(@(DEM<&]R=&]V8;L@<_IB;W(@;6)O>"`E<R!D;R!P
M<FEEZ&EN:V$@)7,N(@H*(SH@;65S<V%G92YP:'`Z-#DX(&UA:6QB;W@N<&AP
M.C<R,2!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C<*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,S"B,Z('1E;7!L871E<R]M86EL8F]X+VQE
M9V5N9"YI;F,Z-PIM<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(D3T;&6^:73I
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B26UP
M;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(D3T;&6^:73I('-P<N%V>2(*"B,Z
M(&9O;&1E<G,N<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E
M9"`E9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("));7!O<G1O=F%N_6-H
M("5D('-P<N%V('H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<V-@IM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R(")3<')A8_IV82!S82(*
M"B,Z(&9O;&1E<G,N<&AP.C,V,R!L:6(O1F]L9&5R+G!H<#HX-B!L:6(O1F]L
M9&5R+G!H<#HR,3(@;&EB+TE-4"YP:'`Z,S$S"B,Z(&QI8B])34%0+U1R964N
M<&AP.C$P.2!L:6(O24U!4"]4<F5E+G!H<#HR,30*;7-G:60@(DEN8F]X(@IM
M<V=S='(@(E!R:6IA=.D@<W!RX79Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0Y,@IM<V=I9"`B26YC;'5D92!A(&)R:65F('-U;6UA<GD@;V8@=&AE
M(&AE861E<B!I;B!A(')E<&QY/R(*;7-G<W1R(")6;&^^:;L@9&\@;V1P;W9E
M9&4@;F%J9/1L9;YI=&5JN6EE(&AL879IZ&MY('#T=F]D;F5J('-P<N%V>3\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W"FUS9VED("));F-L=61E
M(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B"FUS9W-T<B`B5FQOOFF[
M('#T=F]D;OH@<W!RX79U(&1O(&]D<&]V961E/R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C$S,`IM<V=I9"`B26YF;R(*;7-G<W1R("));F9O(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@
M4'5B;&EC($ME>2(*;7-G<W1R("));F9O<FWA8VEE(&\@)7,@=F5R96IN;VT@
M:[7ZZ&DB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(DEN
M9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(DEN
M9F]R;>%C:64@;R!O<V]B;F]M('!R:7;A=&YO;2!KM?KH:2(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y
M(@IM<V=S='(@(DEN9F]R;>%C:64@;R!O<V]B;F]M('9E<F5J;F]M(&NU^NAI
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y.`HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYJ<SHU-@IM<V=I9"`B26YL:6YE(@IM<V=S
M='(@(E8@=&5L92!S<'+A=GDB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I9FEC871E($AE<F4B"FUS
M9W-T<B`B4V5M('9L;[YT92!C97)T:69I:^%T(@H*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R
M:79A=&4@4$=0($ME>2!(97)E(@IM<V=S='(@(E1U('9L;[YT92!O<V]B;OT@
M<')I=N%T;GD@4$=0(&NU^N@B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K
M97DN:6YC.C$P"FUS9VED("));G-E<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+
M97D@2&5R92(*;7-G<W1R(")4=2!V;&^^=&4@;W-O8F[]('9E<F5J;OT@4$=0
M(&NU^N@B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4*;7-G
M:60@(DEN<V5R="!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(E1U('9L
M;[YT92!V97)E:F[](%!'4"!KM?KH(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C0Q,PIM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R
M('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R(")0<F4@=&5N=&\@:V]M<&]N96YT
M(&)O;&$@=GEB<F%NX2!N97!L871NX2!A:V-I82XB"@HC.B!M86EL8F]X+G!H
M<#HU-S(@;6%I;&)O>"YP:'`Z-C$T"FUS9VED("));G9A;&ED($%D9')E<W,B
M"FUS9W-T<B`B3F5P;&%T;N$@861R97-A(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B"FUS
M9W-T<B`B3F5P;&%T;N$@=GID:6%L96[A('-C:'+A;FMA+B(*"B,Z(&-O;7!O
M<V4N<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A
M8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N(@IM<V=S='(@(DYE<&QA=&[]
M('IN86L@=B!E+6UA:6QO=F5J(&%D<F5S93H@)7,N(@H*(SH@<VUI;64N<&AP
M.C<X('!G<"YP:'`Z,38*;7-G:60@(DEN=F%L:60@:V5Y(@IM<V=S='(@(DYE
M<&QA=&[](&NU^N@B"@HC.B!P9W`N<&AP.C$Y,@IM<V=I9"`B26YV86QI9"!P
M97)S;VYA;"!01U`@<')I=F%T92!K97DN(@IM<V=S='(@(DYE<&QA=&[](&]S
M;V)N_2!01U`@<')I=N%T;GD@:[7ZZ"XB"@HC.B!P9W`N<&AP.C$V-PIM<V=I
M9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T<B`B
M3F5P;&%T;OT@;W-O8F[](%!'4"!V97)E:F[](&NU^N@N(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B26YV97)T(@IM<V=S
M='(@(DEN=F5R=&]V8;LB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU.#@*;7-G:60@(DM"(@IM<V=S='(@(DM"(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")$
MY;YK82!KM?KH82(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*;7-G
M:60@(B(*(DME>2!G96YE<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE('1O
M(&-O;7!L971E+B`@0V]N=&EN=64@=VET:"!K97D@(@HB9V5N97)A=&EO;C\B
M"FUS9W-T<B`B1V5N97)O=F%N:64@:[7ZZ&$@;?2^92!T<G9ANR!D;&AO+B`@
M4&]K<F'H;W9ANR!V(&=E;F5R;W9A;NT@:[7ZZ&$_(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHS-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,S<*
M;7-G:60@(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO
M860@:7,@;F]T(&5N86)L960@;VX@=&AI<R!S97)V97(N(@IM<V=S='(@(B(*
M(DEM<&]R="!KM?KH;W8@;FEE(&IE(&1O<W1U<&[]+B!.86ARX79A;FEE('/Z
M8F]R;W8@;FEE(&IE(&YA('1O;71O('-E<G9E<FD@(@HB<&]V;VQE;NDN(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS-R!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,SD*;7-G:60@(B(*(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL
M86)L92X@66]U(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D
M('EO=7(@(@HB8V]N=&%C=',N(@IM<V=S='(@(B(*(DEM<&]R="!KM?KH;W8@
M;FEE(&IE(&1O<W1U<&[]+B!.96WA=&4@9&5F:6YO=F%N_2!A9')E<^%R(&YA
M('!R:63A=F%N:64@(@HB:V]N=&%K=&]V+B(*"B,Z('!G<"YP:'`Z,S$T"FUS
M9VED(")+97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(@IM<V=S='(@(DNU^N@@8F]L(/IS<&6Y;F4@;V1O<VQA;OT@;F$@
M<V5R=F5R('9E<F5J;OUC:"!KM?KH;W8N(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,34*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DIA>GEK
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y-`IM<V=I9"`B3&%S="!-
M86EL8F]X(%!A9V4B"FUS9W-T<B`B4&]S;&5D;N$@<W1RX6YK82!S8VARX6YK
M>2(*"B,Z(&UA:6QB;W@N<&AP.C,T,`IM<V=I9"`B3&%S="!086=E(@IM<V=S
M='(@(E!O<VQE9&[A('-T<N%N:V$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU-#8*;7-G:60@(DQI;FL@071T86-H;65N=',_(@IM<V=S
M='(@(DYA;&EN:V]V8;L@<'+M;&]H>3\B"@HC.B!A='1A8VAM96YT+G!H<#HS
M-"!L:6(O0V]M<&]S92YP:'`Z,3`X,PIM<V=I9"`B3&EN:V5D(&%T=&%C:&UE
M;G1S(&%R92!F;W)B:61D96XN(@IM<V=S='(@(DYA;&EN:V]V86[I('!R[6QO
M:'D@<_H@>F%KX7IA;NDN(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Q,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,B"FUS
M9W-T<B`B4&QA=&YO<[L@;&EN:65K('9Y<'*Y[2`E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#<P"FUS9VED("(B"B),:7-T(&%L;"!C;VYT86-T
M<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B
M;&5D+"!Y;W4@=VEL;"`B"B)O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S
M96%R8V@@9F]R(&5X<&QI8VET;'DI(@IM<V=S='(@(B(*(EIO8G)A>FF[(':Y
M971K>2!K;VYT86MT>2!P<FD@;F%H<N%V86[M(&]B<F%Z;W9K>2!S(&MO;G1A
M:W1M:3\@*$%K(&IE("(*(GIA:^%Z86[I('5V:63M=&4@:6)A(&MO;G1A:W1Y
M+"!K=&]RZ2!S=&4@97AP;&EC:71N92!V>6BU863A=F%L:2DN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8W,PIM<V=I9"`B3&ES=&EN9R!I;B!T:&4@
M2&5A9&5R(@IM<V=S='(@(EIO>FYA;2!V(&AL879IZ&ME(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P"FUS9VED("),;V-A;"!-86EL
M8F]X.B(*;7-G<W1R("),;VOA;&YA('-C:'+A;FMA.B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-S$*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@
M(E5M:65S=&YE;FEE(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M,C0*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")0<FEH;.%S96YI92(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&]G(&EN('1O("5S(@IM<V=S='(@(E!R:6ALX7-INR!S82!N82`E<R(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,X"FUS9VED("),;V=I;B(*
M;7-G<W1R(")0<FEH;.%S96YI92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BVFQO:'D@<')I('!R
M:6ALX7-E;NTB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M.38*;7-G:60@(DQO=R(*;7-G<W1R(").[7IK82(*"B,Z(&UE<W-A9V4N<&AP
M.C(Y.2!M86EL8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHQ,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(D[M>FMA('!R
M:6]R:71A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW
M"FUS9VED("),;W=E<W0B"FUS9W-T<B`B3F%J;FF^N6EA(@H*(SH@;&EB+TU)
M344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`IM<V=I9"`B36%C:6YT;W-H
M($9I;&4B"FUS9W-T<B`B4_IB;W(@36%C:6YT;W-H(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"FUS9VED(")-86EL(@IM<V=S='(@
M(E!ON71A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")-
M86EL(%!R979I97=S(@IM<V=S='(@(E5KX;YK>2!S<'+A=B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,38*;7-G:60@(DUA
M:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SHB"FUS9W-T<B`B5'EP(&UA
M:6QO=NEH;R!S97)V97)A(&YA('!R:7!O:F5N:64Z(@H*(SH@9F]L9&5R<RYP
M:'`Z,S8W(&9O;&1E<G,N<&AP.C,X,0IM<V=I9"`B36%I;&)O>"(*;7-G<W1R
M(")38VARX6YK82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*;7-G
M:60@(DUA:6QB;W@@86YD($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T
M<B`B3F%S=&%V96YI92!Z;V)R87IE;FEA('-C:'+A;F]K(&$@<')I9>AI;FMO
M=B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X"FUS9VED
M(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G<W1R
M(")/>FYAZ&F[(':Y971K>2!S<'+A=GD@=B!P<FEEZ&EN:W4@86MO('!R9>CM
M=&%NZ2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS
M9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM
M<V=S='(@(D]Z;F'H:;L@=KEE=&MY('-P<N%V>2!V('!R:67H:6YK=2!A:V\@
M;F5P<F7H[71A;NDB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C4@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,`IM
M<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`B3WIN8>AINR!A:V\Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8S.`IM<V=I9"`B36%R:R!D:69F97)E;G0@
M;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/R(*;7-G
M<W1R(")2;WIL:;EO=F&[('9N;W)E;ND@8VETX71Y('+T>FYY;6D@9F%R8F%M
M:3\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*;7-G
M:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS9W-T
M<B`B3WIN8>AINR!S<'+A=GD@86MO('!R9>CM=&%NZ3\@*&EB82!)34%0*2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-#8*;7-G:60@(DUA<FL@<VEM
M<&QE(&UA<FMU<#\B"FUS9W-T<B`B3WIN8>AINR!J961N;V1U8VCI(&9O<FWA
M=&]V86YI93\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#8*
M;7-G:60@(DUA=&-H($%L;"!1=65R:65S(@IM<V=S='(@(E9Y:&]V=6IE(':Y
M971K_6T@<&^^:6%D879KX6TB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R(")6>6AO
M=G5J92"U=6)O=F^U;F5J('!OOFEA9&%V:V4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU,#0*;7-G:60@(DUA>&EM=6T@071T86-H;65N
M="!3:7IE(@IM<V=S='(@(DUA>&EMX6QN82!V9;5K;W.[('!R[6QO:'DB"@HC
M.B!L:6(O87!I+G!H<#HW.0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@1F]L
M9&5R<R(*;7-G<W1R(")-87AI;>%L;GD@<&_H970@<')I9>AI;FMO=B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X-@IM<V=I9"`B36%X
M:6UU;2!N=6UB97(@;V8@871T86-H;65N=',@<F5A8VAE9"XB"FUS9W-T<B`B
M0F]L(&1O<VEA:&YU=/T@;6%X:6WA;&YY('!OZ&5T('!R[6QO:"XB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.#(*;7-G:60@(DUA>&EM
M=6T@=&]T86P@871T86-H;65N="!S:7IE(')E86-H960N(@IM<V=S='(@(D)O
M;&$@9&]S:6%H;G5TX2!M87AI;>%L;F$@8V5L:V]VX2!V9;5K;W.[('!R[6QO
M:"XB"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS"FUS9VED(")-
M96YU($9O;&1E<B!,:7-T(@IM<V=S='(@(EIO>FYA;2!P<FEEZ&EN:V]V(&UE
M;G4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0R"FUS9VED(")-97-S86=E(@IM
M<V=S='(@(E-P<N%V82(*"B,Z(&-O;7!O<V4N<&AP.C4Y-B!C;VUP;W-E+G!H
M<#HV,C,@8V]M<&]S92YP:'`Z-C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO;B(*;7-G<W1R(")0[7-A;FEE
M('-P<N%V>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*;7-G:60@
M(DUE<W-A9V4@1&%T92(*;7-G<W1R(")$X71U;2!S<'+A=GDB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#<@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#,*;7-G:60@(DUE<W-A9V4@3W!T:6]N<R(*;7-G<W1R
M(").87-T879E;FEA('-P<N%V(@H*(SH@<V5A<F-H+G!H<#HS,3(*;7-G:60@
M(DUE<W-A9V4@4V5A<F-H(@IM<V=S='(@(E9Y:+5A9&%N:64@<W!RX79Y(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP.0IM<V=I9"`B365S<V%G92!3
M:7IE(@IM<V=S='(@(E9EM6MO<[L@<W!RX79Y(@H*(SH@;65S<V%G92YP:'`Z
M,S@T"FUS9VED(")-97-S86=E(%-O=7)C92(*;7-G<W1R("):9')O:F]V_2!T
M97AT('-P<N%V>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I
M9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@(EIO8G)A>F5N:64@<W!RX79Y
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-97-S
M86=E(&9L86=S(@IM<V=S='(@(E!R[7IN86MY('-P<N%V>2(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z.#,*;7-G:60@(DUE<W-A9V4@9F]L9&5R
M<R(*;7-G<W1R(")0<FEEZ&EN:WD@<W!RX78B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@9G)O;2`E<R(*
M;7-G<W1R(")3<'+A=F$@;V0@)7,B"@HC.B!M86EL8F]X+G!H<#HV-34*;7-G
M:60@(DUE<W-A9V4@:&%S(&%T=&%C:&UE;G1S(@IM<V=S='(@(E-P<N%V82!M
MX2!P<NUL;VAY(@H*(SH@;6%I;&)O>"YP:'`Z-C0V"FUS9VED(")-97-S86=E
M(&ES(&5N8W)Y<'1E9"(*;7-G<W1R(")3<'+A=F$@:F4@>F&Y:69R;W9A;N$B
M"@HC.B!M86EL8F]X+G!H<#HV-#$*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D
M(@IM<V=S='(@(E-P<N%V82!J92!P;V1P[7-A;N$B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z,S,*;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*
M;7-G<W1R(")3<'+A=F$@=GEH;W9U:F4B"@HC.B!C;VUP;W-E+G!H<#HX-C(@
M8V]M<&]S92YP:'`Z.#8Y"FUS9VED(")-97-S86=E(')E9&ER96-T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R(")3<'+A=F$@8F]L82#Z<W!EN6YE('!R97-M
M97)O=F%NX2(*"B,Z(&-O;7!O<V4N<&AP.C$Q,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E
M9"!T;R`E<R(*;7-G<W1R(")3<'+A=F$@8F]L82#Z<W!EN6YE(&]D;W-L86[A
M+"!A;&4@;FEE('5L;[YE;N$@9&\@)7,B"@HC.B!C;VUP;W-E+G!H<#HQ,3<S
M(&-O;7!O<V4N<&AP.C$Q.#$*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(E-P<N%V82!B;VQA(/IS<&6Y;F4@;V1O<VQA;N$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR.0IM<V=I9"`B365S<V%G
M97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`B4W!R
MX78@;F$@<W1RX6YK=2!V('IO>FYA;64@<W!RX78B"@HC.B!M86EL8F]X+G!H
M<#HS,#@*;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S='(@(E-P<N%V>2!D;R(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I9"`B36]D:69Y(@IM
M<V=S='(@(E5P<F%V:;LB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E>'!A;F0N
M:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@861D
M<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R(")0<F4@<&]L
M92!<(B5S7"(@<V$@;F&Y;&D@=FEA8V5RZ2!A9')E<WDN(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E(@IM<V=S='(@(E!R
M97-U;OJ[(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S$V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B4')E<W5N^KL@;FF^N6EE
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P-@IM<V=I9"`B36]V92!S
M<&%M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S
M86=E<R!T;R!)3D)/6"(*;7-G<W1R(")0<F5S=6[ZNR!S<&%M(&1O('!R:67H
M:6YK82!S<&%M;W8@82!N9;EK;V1NZ2!S<'+A=GD@9&\@<')I:F%T96H@<&^Y
M='DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO
M=F4@=&\@9F]L9&5R(@IM<V=S='(@(E!R97-U;OJ[(&1O('!R:67H:6YK82(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-`IM<V=I
M9"`B36]V92!U<"(*;7-G<W1R(")0<F5S=6[ZNR!V>;FY:64B"@HC.B!L:6(O
M34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$R-PIM<V=I9"`B375L=&EP
M87)T+V%L=&5R;F%T:79E(@IM<V=S='(@(E9I86-E<F\@Z&%S=.TO86QT97)N
M873M=GDB"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z,34Q"FUS9VED
M(")-=6QT:7!L92!-97-S86=E(%9I97<B"FUS9W-T<B`B6F]B<F%Z96YI92!V
M:6%C97+]8V@@<W!RX78B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E
M87)C:'-E;&5C="YI;F,Z-0IM<V=I9"`B3D].12(*;7-G<W1R("*N24%$3D4B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR"FUS9VED(").3U1%(@IM<V=S='(@(E!/6D[!34M!(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S@@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8X,PIM<V=I9"`B3F%M92(*;7-G<W1R(")-96YO(@H*(SH@
M<&=P+G!H<#HQ,#8*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;FYO="!B
M92!E;7!T>2(*;7-G<W1R(")-96YO(&$O86QE8F\@92UM86EL;W;A(&%D<F5S
M82!N96WTOG4@8GF[('!RX7ID;F4B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S<Q"FUS9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`B5GF^861U
M:F4@86MC:74B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-C8*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI
M:V1Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`IM<V=I9"`B3F5V
M97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(").:6MD>2!N975K;&%D8;L@
M<'+M;&]H>2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,C0*;7-G:60@
M(DYE=R(*;7-G<W1R(").;W;I(@H*(SH@;&EB+TE-4"YP:'`Z-3<T"FUS9VED
M(").97<@1F]L9&5R(@IM<V=S='(@(DYO=OT@<')I9>AI;F]K(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@36%I;"(*;7-G<W1R
M(").;W;A('!ON71A(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(Q(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HR,@HC.B!L:6(O0FQO8VLO=')E95]F;VQD
M97)S+G!H<#HS-PIM<V=I9"`B3F5W($UE<W-A9V4B"FUS9W-T<B`B3F]VX2!S
M<'+A=F$B"@HC.B!M86EL8F]X+G!H<#HW-C,@;&EB+TU)344O2&5A9&5R<RYP
M:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S
M(@IM<V=S='(@(DYO=N$@<W!RX79A('!R92`E<R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R
M(").;W;I('-P<N%V>2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHQ,S,*;7-G:60@(DYE>'0B"FUS9W-T<B`BSV%L96HB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S"FUS9VED(").
M97AT($UE<W-A9V4B"FUS9W-T<B`BSV%LN6EA('-P<N%V82(*"B,Z(&UA:6QB
M;W@N<&AP.C,S.`IM<V=I9"`B3F5X="!086=E(@IM<V=S='(@(L]A;+EI82!S
M=')A;F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S<@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-34P"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-C4*;7-G:60@(DYO(@IM<V=S='(@(DYI92(*"B,Z
M('-M:6UE+G!H<#HR,C(*;7-G:60@(DYO($-E<G1I9FEC871E(&9O=6YD(@IM
M<V=S='(@(JYI861E;B!C97)T:69I:^%T(&YE8F]L(&[A:F1E;OTB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO
M($5N8W)Y<'1I;VXB"FUS9W-T<B`B0F5Z(+EI9G)O=F%N:6$B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3D*;7-G:60@(DYO($ME>7,@:6X@2V5Y<FEN
M9R(*;7-G<W1R(")$871A8N%Z82!KM?KH;W8@:F4@<'+A>F1N82(*"B,Z(&UA
M:6QB;W@N<&AP.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E
M<R(*;7-G<W1R("*N:6%D;F4@<W!RX79Y(@H*(SH@<&=P+G!H<#HQ,S,*;7-G
M:60@(DYO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(").96)O
M;"!I;7!O<G1O=F%N_2"^:6%D96X@=F5R96IN_2!01U`@:[7ZZ"XB"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S;VYA
M;"!#97)T:69I8V%T92!0<F5S96YT(@IM<V=S='(@(DYI92!J92!P<NUT;VUN
M_2"^:6%D96X@;W-O8F[](&-E<G1I9FEKX70B"@HC.B!L:6(O36%I;&)O>"YP
M:'`Z,S,V"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`B0F5Z('5K
MX;YK>2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G:60@
M(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(DYE8F]L:2!NX6ID96[I
M(+YI861N92!V97)E:F[I(&NU^NAE(@H*(SH@<VUI;64N<&AP.C$T-PIM<V=I
M9"`B3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DYE
M8F]L(&EM<&]R=&]V86[](+YI861E;B!V97)E:F[](%,O34E-12!KM?KH+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY,@IM<V=I9"`B3F\@871T
M86-H;65N=',@9F]U;F0N(@IM<V=S='(@(DYE8F]L:2!NX6ID96[I(+YI861N
M92!P<NUL;VAY+B(*"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"FUS9VED
M(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@
M:V5Y+B(*;7-G<W1R(")6;R!V97)E:FYO;2!KM?KH:2!N:64@:F4@OFEA9&YA
M(&EN9F]R;>%C:6$@;R!E+6UA:6QO=F5J(&%D<F5S92XB"@HC.B!A8VPN<&AP
M.C<Q(&%C;"YP:'`Z.3<*;7-G:60@(DYO(&9O;&1E<B!S96QE8W1E9"XB"FUS
M9W-T<B`BKFEA9&5N('!R:67H:6YO:R!N:64@:F4@;WIN8>AE;OTN(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T-@IM<V=I9"`B3F\@9F]L9&5R<R!A
M<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(JYI861N
M92!P<FEEZ&EN:WD@<V$@;F5K;VYT<F]L=6KZ(&YA(';]<VMY="!N;W9E:B!P
M;[ET>2XB"@HC.B!F;VQD97)S+G!H<#HQ.3<@;&EB+T9O;&1E<BYP:'`Z-3`X
M(&QI8B]&;VQD97(N<&AP.C4U.`IM<V=I9"`B3F\@9F]L9&5R<R!W97)E('-P
M96-I9FEE9"(*;7-G<W1R(").96)O;&D@N7!E8VEF:6MO=F%NZ2!P<FEEZ&EN
M:WDB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,34R"FUS9VED(").;R!F
M;VQD97)S('=I=&@@;F5W(&UE<W-A9V5S(@IM<V=S='(@(E8@OFEA9&YO;2!P
M<FEEZ&EN:W4@;FEE('/Z(&YO=ND@<W!RX79Y(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$T.0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M
M97-S86=E<R(*;7-G<W1R(")6(+YI861N;VT@<')I9>AI;FMU(&YI92!S^B!N
M97!R9>CM=&%NZ2!S<'+A=GDB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,V"FUS
M9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R("*N:6%D96X@=&5X
M="!V('1E;&4@<W!RX79Y(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,X,`IM<V=I
M9"`B3F\@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B
MKFEA9&YA('-P<N%V82!N979Y:&]V=6IE(%;AN6UU('IA9&%N:74N(@H*(SH@
M<&=P+G!H<#HQ.#4*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME
M>2!I;7!O<G1E9"XB"FUS9W-T<B`B3F5B;VP@:6UP;W)T;W9A;OT@OFEA9&5N
M('!R:7;A=&YY(%!'4"!KM?KH+B(*"B,Z('!G<"YP:'`Z,38Q"FUS9VED(").
M;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B
M3F5B;VP@:6UP;W)T;W9A;OT@OFEA9&5N('9E<F5J;OT@4$=0(&NU^N@N(@H*
M(SH@<VUI;64N<&AP.C$Y-PIM<V=I9"`B3F\@<&5R<V]N86P@4R]-24U%(&-E
M<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B3F5B;VQI(&EM<&]R=&]V
M86[I(+YI861N92!O<V]B;ND@4R]-24U%(&-E<G1I9FEKX71Y+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0V(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C(Y.0IM<V=I9"`B(@HB3F\@<&5R<V]N86P@<')I=F%T92!K97D@
M97AI<W1S('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T
M960N(@IM<V=S='(@(DYE97AI<W1U:F4@OFEA9&5N('!R:7;A=&YY(&NU^N@L
M('1A:[YE('-P<N%V=2!N96UOOFYO(&1EN6EF<F]V8;LN(@H*(SH@<W!E;&QI
M;F<N<&AP.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O
M;F9I9W5R960N(@IM<V=S='(@(DYE8F]L(&YA<W1A=F5N_2"^:6%D96X@<')O
M9W)A;2!N82!K;VYT<F]L=2!P<F%V;W!I<W4N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(").;R!S<&5L;&EN9R!E<G)O
M<G,B"FUS9W-T<B`BKFEA9&YE(&-H>6)Y('!R879O<&ES=2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#`*;7-G:60@(DYO('-U9V=E
M<W1I;VYS(@IM<V=S='(@(JYI861N92!NX79R:'DB"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C4W,`IM<V=I9"`B3F\@<W5P<&]R=&5D($E-05`@875T:&5N
M=&EC871I;VX@;65T:&]D(&-O=6QD(&)E(&9O=6YD+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A(&[A:G.[(+YI861N=2!P;V1P;W)O=F%N^B!M973S9'4@24U!
M4"!A=71E;G1I9FEKX6-I92XB"@HC.B!A8VPN<&AP.C8W(&%C;"YP:'`Z.3,*
M;7-G:60@(DYO('5S97(@<W!E8VEF:65D+B(*;7-G<W1R(").96)O;""Y<&5C
M:69I:V]V86[]('!O=;[M=F%T9;4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<P-`IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(DYI
M92!J92#ZZ&%S=&[M:R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,3$@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*(SH@
M=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,"!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-0HC.B!T96UP;&%T97,O<')E
M9G,O<W!A;7-E;&5C="YI;F,Z,C0@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L
M96-T+FEN8SHR-`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Q"FUS
M9VED(").;VYE(@IM<V=S='(@(JYI861N92(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(Y-0IM<V=I9"`B3F]R;6%L(@IM<V=S='(@(DYO
M<FWA;&YA(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,2!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Y"FUS9VED(").;W0@1&5L
M971E9"(*;7-G<W1R(").979Y;6%Z86[I(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(S"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M-#(*;7-G:60@(DYO="!$<F%F="(*;7-G<W1R(").:64@:F4@:V]N8V5P="(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z."!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$W"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@(DYO="!);7!O<G1A;G0B"FUS
M9W-T<B`B3F5D]&QEOFETZ2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,C4*;7-G:60@(DYO="!097)S;VYA;"(*;7-G<W1R(").:64@:F4@
M;W-O8F[I(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z,3,Y(&QI8B]#<GEP="]3
M34E-12YP:'`Z,3,T(&QI8B]#<GEP="]334E-12YP:'`Z,30Y"FUS9VED(").
M;W0@82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G<W1R(").97!L871N_2!V97)E
M:F[](&NU^N@N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV-PIM
M<V=I9"`B3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B3F5V>6UA>F%N
MZ2!S<'+A=GDB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS
M9VED(").;W0@:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(DYE9/1L9;YI
M=.D@<W!RX79Y(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL
M7VQO9VEN+G!H<#HW,0IM<V=I9"`B3F]T92!T:&%T('1H:7,@8V%N('1A:V4@
M<V]M92!T:6UE(@IM<V=S='(@(DWTOF4@=&\@8VAV[;5U('1R=F&[+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#0*;7-G:60@(DYO=&AI;F<B"FUS
M9W-T<B`B3FGH(@H*(SH@871T86-H;65N="YP:'`Z.#D*;7-G:60@(DYO=&EF
M:6-A=&EO;CH@3&EN:V5D(&%T=&%C:&UE;G0@9&]W;FQO861E9"(*;7-G<W1R
M(")5<&]Z;W)N96YI93H@;F%L:6YK;W9A;N$@<'+M;&]H82!B;VQA('-T:6%H
M;G5TX2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DYU
M;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S
M(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(E!OZ&5T(&UE<VEA
M8V]V+"!P;^AA<R!K=&]R_6-H('-A(&UA:OH@<&]N96-H8;L@<W1A<ND@;F%L
M:6YK;W9A;ND@<'+M;&]H>2!P<FD@(@HB;65S8>AN;VT@;6%Z86[M+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*;7-G:60@(DYU;6)E<B!O9B!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT
M:&QY+B(*;7-G<W1R("(B"B)0;^AE="!S=&%R_6-H('!R:67H:6YK;W8@;V1O
M<VQA;F5J('!ON71Y+"!K=&]RZ2!S82!M86KZ('!O;F5C:&&[('!R:2`B"B)M
M97-AZ&YO;2!M87IA;NTN(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR-30*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C0Y"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M-#@*;7-G:60@(D]2(@IM<V=S='(@(D%,14)/(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@
M(E-T87+I('-P<N%V>2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T
M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I
M;"!F;VQD97)S(&)E:6YG('!U<F=E9"XB"FUS9W-T<B`B4W1A<ND@<')I9>AI
M;FMY(&]D;W-L86[]8V@@<W!RX78@<V$@=GEM87KA=F%J^BXB"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,C@*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD
M97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(EIO
M8G)A>FF[(&QE;B!P<FEEZ&EN:WD@<R!N97!R9>CM=&%N_6UI('-P<N%V86UI
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-SD*;7-G
M:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H
M:7,@86-T:6]N+B(*;7-G<W1R(")0<F4@=/IT;R!A:V-I=2!B>2!M86P@8GF[
M('9Y8G)A=/T@:6)A(&IE9&5N('!R:67H:6YO:RXB"@HC.B!T96UP;&%T97,O
M;65N=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"FUS9VED(")/<&5N
M($9O7VQD97(B"FUS9W-T<B`B3W1V;W)INR!?<')I9>AI;F]K(@H*(SH@9F]L
M9&5R<RYP:'`Z-#`V"FUS9VED(")/<&5N960@1F]L9&5R(@IM<V=S='(@(D]T
M=F]R96[]('!R:67H:6YO:R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW,#`*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM<V=S='(@(DYE
M<&]V:6YN_2#ZZ&%S=&[M:R(*"B,Z(&9E=&-H;6%I;"YP:'`Z-#,@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]T;W`N:6YC.C,*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]F971C:&UA:6PN:6YC.C8*;7-G:60@(D]T:&5R($UA:6P@06-C;W5N=',B
M"FUS9W-T<B`B26[I('!ON71O=ND@^NAT>2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(DEN
MZ2!N87-T879E;FEA(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M,#`*;7-G:60@(D]U=&)O=6YD(%-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C$V-`HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#,@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,C@Y"FUS9VED(")01U`B"FUS9W-T<B`B
M4$=0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHW
M"FUS9VED(")01U`@16YC<GEP="!-97-S86=E(@IM<V=S='(@(EIAN6EF<F]V
M8;L@<W!RX79U('!O;6]C;W4@4$=0(@H*(SH@8V]M<&]S92YP:'`Z,S,U"FUS
M9VED(")01U`@17)R;W(Z("(*;7-G<W1R(")#:'EB82!01U`Z("(*"B,Z(&-O
M;7!O<V4N<&AP.C,Q-`IM<V=I9"`B4$=0($5R<F]R.B!.965D('!A<W-P:')A
M<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R(")#:'EB82!0
M1U`Z('!R92!O<V]B;OT@<')I=N%T;GD@:[7ZZ"!T<F5B82!Z861ANR!H97-L
M;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")01U`@
M3W!T:6]N<R(*;7-G<W1R(").87-T879E;FEA(%!'4"(*"B,Z('!G<"YP:'`Z
M,S`*;7-G:60@(E!'4"!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(EIA9.%V
M86YI92!H97-L82!P<F4@4$=0(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C4U"FUS9VED(")01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I
M<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B)0<F4@
M<&]D<&]R=2!O<V]B;NEH;R!KM?KH;W;I:&\@<.%R=2!01U`@;75S[71E(&UA
MNR!B97IP9>ANZ2!P<FEP;VIE;FEE("(*(BAH='1P<RDN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,3<R"FUS9VED(")01U`@4'5B;&EC($ME>2!4
M97AT(@IM<V=S='(@(E1E>'0@4$=0('9E<F5J;NEH;R!KM?KH82(*"B,Z('!G
M<"YP:'`Z,30U"B,L('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y
M(&9O<B!<(B5S("@E<RE<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G
M<W1R(")697)E:F[](%!'4"!KM?KH('!R92!<(B5S("@E<RE<(B!B;VP@^G-P
M9;EN92!P<FED86[]+B(*"B,Z('!G<"YP:'`Z,C0Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!D96QE=&5D+B(*;7-G<W1R(")697)E:F[](%!'4"!KM?KH('!R92!<
M(B5S7"(@8F]L(/IS<&6Y;F4@=GEM87IA;OTN(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T
M<B`B1&%T86+A>F$@=F5R96IN_6-H(%!'4"!KM?KH;W8B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*;7-G:60@(E!'4"!3:6=N
M($UE<W-A9V4B"FUS9W-T<B`B4&]D<.US8;L@<W!RX79U('!O;6]C;W4@4$=0
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"FUS
M9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B4&]D<.US
M8;LO>F&Y:69R;W9ANR!S<'+A=G4@<&]M;V-O=2!01U`B"@HC.B!P9W`N<&AP
M.C$Y.`IM<V=I9"`B4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E
M9"XB"FUS9W-T<B`B4')I=N%T;GD@4$=0(&NU^N@@8F]L(/IS<&6Y;F4@<')I
M9&%N_2XB"@HC.B!P9W`N<&AP.C$W,PIM<V=I9"`B4$=0('!U8FQI8R!K97D@
M<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")697)E:F[](%!'4"!KM?KH
M(&)O;"#Z<W!EN6YE('!R:61A;OTN(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A
M8W1I=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N
M('1H:7,@<WES=&5M+B(*;7-G<W1R(").82!T;VUT;R!S>7-TZ6UE(&IE('!O
M9'!O<F$@4$=0('IA:^%Z86[A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(P-PIM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L
M>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T
M;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB4&]D<&]R82!01U`@;FEE
M(&IE(&UO;65N=.%L;F4@86MT:79O=F%NX2P@=&%KOF4@;F5M;[YN;R!O=F5R
M:;L@9&EG:73A;&YY("(*(G!O9'!I<RXB"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR.30*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R
M96YT;'D@86-T:79E('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D
M96-R>7!T960N(@IM<V=S='(@(B(*(E!O9'!O<F$@4$=0(&YI92!J92!M;VUE
M;G3A;&YE(&%K=&EV;W9A;N$L('1A:[YE(&YE;6^^;F\@9&6Y:69R;W9ANR!S
M<'+A=G4N(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(B(*
M(E!'4"!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E
M9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@(@HB<V5T('1O(&1I
M<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T
M=&EN9R!O<B!E;'-E('1H92!01U`@(@HB9F5A='5R97,@=VEL;"!N;W0@=V]R
M:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(E!O9'!O<F$@4$=0('9YOF%D=6IE
M('!O=;YI=&EE('9Y<VMA:V]V86/M8V@@;VMI96XN($%K(%;AN2!P<F5H;&EA
M9&'H("(*(FUO;65N=.%L;F4@8FQO:W5J92!V>7-K86MO=F%C:64@;VMNX2P@
M;75S[71E('1O=&\@;F%S=&%V96YI92!Z;65N:;LL(&EN86L@(@HB;F5B=61E
M(%!'4"!F=6YG;W9ANR!S<'+A=FYE+B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM<V=S='(@(E!/4#,B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T;R!$971E
M8W0@4')O=&]C;VQS*2(*;7-G<W1R(")03U`S("A!=71O;6%T:6-K>2!D971E
M:V]V8;L@<')O=&]K;VQY*2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,3$W"FUS9VED(")03U`S(&]V97(@4U-,(@IM<V=S='(@(E!/4#,@8V5Z(%-3
M3"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(S"FUS9VED(")03U`S
M(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B
M4$]0,R!C97H@4U-,("AC97)T:69I:^%T('!O9'#M<V%N_2!S86W];2!S96)O
M=2DB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V.`IM<V=I9"`B
M4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I(@IM<V=S='(@(E!/4#,@8V5Z
M(%-33"`H8V5R=&EF:6OA="!P;V1P[7-A;OT@<V%M_6T@<V5B;W4I(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,
M4R(*;7-G<W1R(")03U`S+"!B97H@5$Q3(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED(")086=E("5D
M(&]F("5D(@IM<V=S='(@(E-T<F%N82`E9"!Z("5D(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@Y,0IM<V=I9"`B4&%G92!W:71H('1H92!&:7)S="!5
M;G-E96X@365S<V%G92(*;7-G<W1R(")3='+A;FMA(',@<')V;W4@;F5P<F7H
M[71A;F]U('-P<N%V;W4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DR
M"FUS9VED(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B"FUS
M9W-T<B`B4W1RX6YK82!S('!O<VQE9&YO=2!N97!R9>CM=&%N;W4@<W!RX79O
M=2(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C0S"FUS9VED
M(")087)T*',I(@IM<V=S='(@(LAA<[LH:2DB"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,3(S"FUS9VED(")087-S<&AR87-E(@IM<V=S='(@(DAE<VQO
M('!R92!KM?KH(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R.`IM<V=I
M9"`B4&%S<W!H<F%S92`H06=A:6XI(@IM<V=S='(@(DAE<VQO('!R92!KM?KH
M("AZ;F]V=2DB"@HC.B!S;6EM92YP:'`Z,C,Q('!G<"YP:'`Z,S`V"FUS9VED
M(")087-S<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`B
M2&5S;&\@8F]L;R#Z<W!EN6YE(&]D<W1RX6YE;ND@>B!P86WD=&DN(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$X('1E;7!L871E<R]P
M9W`O<&%S<W!H<F%S92YI;F,Z,CD*;7-G:60@(E!A<W-P:')A<V4Z(@IM<V=S
M='(@(DAE<VQO('!R92!KM?KH.B(*"B,Z('!G<"YP:'`Z,3`X"FUS9VED(")0
M87-S<&AR87-E<R!C86YN;W0@8F4@96UP='DB"FUS9W-T<B`B2&5S;.$@<')E
M(&NU^NAE(&YE;?2^=2!B>;L@<'+A>F1N92(*"B,Z('!G<"YP:'`Z,3$P"FUS
M9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B2&5S;.$@
M;FEE('/Z(')O=FYA:^DB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,C`@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<Q"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3DQ"FUS9VED(")087-S=V]R
M9"(*;7-G<W1R(")(97-L;R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT.`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")6>6MO;F&[(&]P97+A8VEE(/ID<KYB
M>2!P<FD@<')I:&SA<V5N[3\B"@HC.B!A8VPN<&AP.C<U(&%C;"YP:'`Z,3`Q
M"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R(&-A;FYO="!B92!C
M:&%N9V5D+B(*;7-G<W1R(")0<N%V82!P<F4@=&]H=&\@<&]UONUV871EM6$@
M;F5M;[YN;R!Z;65N:;LN(@H*(SH@;65S<V%G92YP:'`Z-#@V(&UA:6QB;W@N
M<&AP.C8Y,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(T"B,Z('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3`*;7-G:60@(E!E<G-O;F%L
M(@IM<V=S='(@(D]S;V)NZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B3W-O8F[I
M(&EN9F]R;>%C:64B"@HC.B!P9W`N<&AP.C$Q-@IM<V=I9"`B4&5R<V]N86P@
M4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M3W-O8F[](%!'4"!KM?KH;W;]('#A<B!B;VP@^G-P9;EN92!V>6=E;F5R;W9A
M;OTN(@H*(SH@<&=P+G!H<#HQ,C,*;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES
M(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")/<V]B;ND@4$=0(&NU
M^NAE(&)O;&D@^G-P9;EN92!V>6UA>F%NZ2XB"@HC.B!S;6EM92YP:'`Z,C`S
M"FUS9VED(")097)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O
M<G1E9#H@(@IM<V=S='(@(D]S;V)NZ2!3+TU)344@8V5R=&EF:6OA='D@3D5"
M3TQ)(&EM<&]R=&]V86[I.B`B"@HC.B!S;6EM92YP:'`Z,3(X"FUS9VED(")0
M97)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B3W-O8F[I(%,O34E-12!KM?KH92!B;VQI(/IS<&6Y;F4@=GEM87IA
M;NDN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA
M8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S
M/R(*;7-G<W1R(")6:VQA9&&[(%9AN74@<VEG;F%T^G)U('!R960@;V1P;W9E
M9&4@82!P<F5P;W-L86[Z('!ON71U/R(*"B,Z(&-O;7!O<V4N<&AP.C(U.`IM
M<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R("):
M;V)R87IINR!T97AT;W;Z('9E<GII=2!S<'+A=GDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@W"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M
M86EL/R`@5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E
M;6)E9&1E9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN
M9&]W<R!A;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q
M=6ER92!A('!L=6=I;BXB"FUS9W-T<B`B(@HB4')E:')ANR!Z=G5K('!R:2!P
M<NUC:&]D92!N;W9E:B!P;[ET>3\@(%1O=&\@=GF^861U:F4@<&]D<&]R=2!6
MX;EH;R`B"B)P<F5H;&EA9&'H82!P<F4@=FQOOF5NZ2!Z=G5K;W;I('/Z8F]R
M>2X@($YA('!L871F;W)MX6-H(%=I;F1O=W,@82!-86,@<_H@=&\@(@HB=&%K
M;65R(':Y971K>2P@;F$@:6[]8V@@<&QA=&9O<FWA8V@@8G5D971E('!O=')E
M8F]V8;L@<&QU9VEN+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I
M<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y
M,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD
M97(Z(@IM<V=S='(@(EIA9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO=OT@<')I
M9>AI;F]K.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,3`R('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED
M(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM
M<V=S='(@(EIA9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO=OT@<')I9>AI;F]K
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,W"FUS
M9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.B(*;7-G<W1R("):861A
M:G1E('!R;W/M;2!N;W;I(&UE;F\Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S
M<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@
M96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y
M+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB96YT97(@=&AI<R!P87-S<&AR
M87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*(EIA9&%J=&4@
M<')O<^UM(&AE<VQO('!R92!6X;D@<')I=N%T;GD@4$=0(&NU^N@N($AE<VQO
M(&UU<^UT92!Z861ANR!I8F$@<F%Z(&$@(@HB<&QA=.T@<&_H87,@8V5L96H@
M<F5LX6-I92`E<RXB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI
M;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H
M92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U
M('=I;&P@;VYL>2!N965D("(*(G1O(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O
M;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"B):861A:G1E('!R;W/M
M;2!H97-L;R!P<F4@5N&Y('!R:7;A=&YY(%,O34E-12!KM?KH+B!(97-L;R!M
M=7/M=&4@>F%D8;L@:6)A("(*(G)A>B!A('!L873M('!OZ&%S(&-E;&5J(')E
M;.%C:64@)7,N(@H*(SH@<F5C;VUP;W-E+G!H<#HY-@IM<V=I9"`B(@HB4&QE
M87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S
M<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U
M(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U
M('=I;&P@:&%V92!T;R`B"B)L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I
M;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@
M(@HB:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O
M<B!A;GD@:6YC;VYV96YI96YC92XB"FUS9W-T<B`B(@HB4')O<^UM('!R:6AL
MX7-T92!S82!Z;F]V=2P@86L@8VAC971E('!O:W)AZ&]V8;L@=B!P[7-A;NT@
M<W!RX79Y+B!!:R`B"B).15!/5:[-5D%412!C;V]K:65S($$@<.VY971E('-P
M<N%V>2!V;R!V>7-K86MO=F%C[6-H(&]K;N%C:"P@8G5D971E('-A("(*(FUU
M<VEENR!Z;F]V=2!P<FEH;.%S:;L@86H@9&\@:&QA=F[I:&\@;VMN82X@5&]T
M;R!S;/J^:2!N82!O8VAR86YU('!R960@(@HB^G1OZ&[M:VUI+"!K=&]R[2!B
M>2!Z;F5UOFEL:2!I9&5N=&EF:6MAZ&[I(.CM<VQO(%9AN65J(')E;.%C:64N
M(,]A:W5J96UE('IA("(*(G!O8VAO<&5N:64N(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW,0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P
M87-S=V]R9"XB"FUS9W-T<B`B4')O<^UM('IA9&%J=&4@<W9O:F4@:&5S;&\B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8W"FUS9VED(")0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE+B(*;7-G<W1R(")0<F]S[6T@>F%D
M86IT92!S=F]J92!P;W6^[79A=&6U<VOI(&UE;F\B"@HC.B!C;VUP;W-E+G!H
M<#HQ,#8@;&EB+TE-4"YP:'`Z-#<P"FUS9VED(")0;&5A<V4@<F5S;VQV92!A
M;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N(@IM<V=S='(@(E!R;W/M
M;2!R;WIL^KET:;L@;F5J961N;WIN8>ANZ2!A(&YE<&QA=&[I(&%D<F5S>2XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C8Q"FUS9VED
M(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A
M;GD@86-T:6]N<RXB"FUS9W-T<B`B4')E9"!V>6MO;F%N[6T@86MC:64@=GEB
M97)T92!P<F]S[6T@<')I9>AI;F]K+B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@870@;&5A
M<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(E!R;W/M;2!V>6)E
M<G1E(&%S<&_R(&IE9&5N('!R:67H:6YO:R!N82!HM6%D86YI92XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS9VED(")0;&5A
M<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN
M(@IM<V=S='(@(E!R;W/M;2!V>6)E<G1E(&EB82!J961E;B!P<FEEZ&EN;VL@
M<')E('3Z=&\@;W!E<N%C:74N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C<S"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@
M=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E!R;W/M;2!O>FYAZ'1E
M(&%L96)O('5P<F%V=&4@=B!P<FEE<W1O<F4@=G!R879O.B(*"B,Z(&-O;F9I
M9R]M;W1D+G!H<"YD:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM
M<V=S='(@(E!O=V5R960@8GD@2&]R9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$T"FUS9VED(")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@
M9&%S:&5S("@G+2T@)RD_(@IM<V=S='(@(D]D9&5L:;L@<VEG;F%T^G)U(&]D
M('-P<N%V>2!P;VULZ&MA;6D@*"<M+2`G*3\B"@HC.B!S;6EM92YP:'`Z,C,W
M('!G<"YP:'`Z,C4S(&9I;'1E<G!R969S+G!H<#HT,`IM<V=I9"`B4')E9F5R
M96YC97,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S='(@(DYA<W1A=F5N
M:6$@8F]L:2#Z<W!EN6YE(&%K='5A;&EZ;W9A;NDN(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*;7-G:60@(E!R979I97<B"FUS
M9W-T<B`B56OAOFMA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@365S<V%G92(*;7-G<W1R
M(")0<F5D8VCA9'IA:OIC82!S<'+A=F$B"@HC.B!M86EL8F]X+G!H<#HS,CD*
M;7-G:60@(E!R979I;W5S(%!A9V4B"FUS9W-T<B`B4')E9&-HX61Z86KZ8V$@
M<W1RX6YK82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHS,PIM<V=I9"`B4')I;G0B"FUS9W-T<B`B5&QAZ&F[(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*;7-G:60@(E!R:6]R:71Y
M(@IM<V=S='(@(E!R:6]R:71A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C<V"FUS9VED(")0<FEV871E($ME>2!087-S=V]R9"(*;7-G
M<W1R(")(97-L;R!K('!R:7;A=&YE;74@:[7ZZ'4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-34Y"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B"FUS9W-T<B`B4/UT
M8;L@<V$@>F%K8;YD_6T@<')I('!O<VEE;&%N[2!P<NUL;VAY.R"Y=&%N9&%R
M9&YE($Y)12(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@
M(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F
M875L="!T;R!915,B"FUS9W-T<B`B4/UT8;L@<V$@>F%K8;YD_6T@<')I('!O
M<VEE;&%N[2!P<NUL;VAY.R"Y=&%N9&%R9&YE(,%.3R(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM
M<V=S='(@(E!R;W1O:V]L.B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0S,`IM
M<V=I9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D
M:7-A8FQE9"XB"FUS9W-T<B`B4&]D<&]R82!01U`@:[7ZZ&]V_6-H('-E<G9E
M<F]V(&)O;&$@>F%KX7IA;N$N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D
M+FEN8SHW"FUS9VED(")0=7)?9V4@1&5L971E9"(*;7-G<W1R(")/7V1S='+A
M;FF[('9Y;6%Z86[I(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHW
M"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(D]D<W1RX6YINR!V>6UA
M>F%NZ2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(T"FUS
M9VED(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B5GEP<N%Z9&YINR!P<FEE
MZ&EN;VL@*'!R:67H:6YK>2DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(D%K
M;R#H87-T;R!V>7!RX7ID;FF[($OTN3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#`U"FUS9VED(")0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F;VQD
M97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*;7-G<W1R(")/
M9'-T<N%N:;L@>B!+;[EA('-P<N%V>2!S=&%RN6EE(&%K;R!T96YT;R!P;^AE
M="!D;NTN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B
M4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_(@IM<V=S
M='(@(D]D<W1RX6YINR!S=&%RZ2!S<'+A=GD@>B!+;[EA/R(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L
M9&5R+B(*;7-G<W1R(")/9'-T<F'R=6IE;2`E9"!S<'+A=B!Z($MON6$N(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8S"FUS
M9VED(")0=7)G:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS
M9W-T<B`B3V1S=')A\G5J96T@,2!S<'+A=G4@>B!+;[EA+B(*"B,Z('1E;7!L
M871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S
M='(@(E-T878@:W;S='DZ("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"@HC
M.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250B"FUS9W-T
M<B`B4W1A=B!K=O-T>3H@)2XR9DU"("\@0D5:($]"345$6D5.24$B"@HC.B!T
M96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G
M:60@(E%U;W1A('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B4W1A=B!K=O-T
M>3H@0D5:($]"345$6D5.24$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3`P"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@
M(D-I=.%T("5F.B(*"B,Z(&QI8B]396%R8V@N<&AP.C4P"FUS9VED(")296-E
M:79E9"!/;B(*;7-G<W1R(")0<FEJ873I(&3R82(*"B,Z(&QI8B]396%R8V@N
M<&AP.C4X"FUS9VED(")296-E:79E9"!3:6YC92(*;7-G<W1R(")0<FEJ873I
M(&]D(@H*(SH@;&EB+U-E87)C:"YP:'`Z-30*;7-G:60@(E)E8V5I=F5D(%5N
M=&EL(@IM<V=S='(@(E!R:6IA=.D@9&\B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,38*;7-G:60@(E)E9&ER96-?="(*;7-G
M<W1R(")0<F5?<VUE<F]V8;LB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(E!R
M97-M97)O=F&[(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C$Q,`IM<V=I9"`B4F5D:7)E8W0@365S<V%G92(*;7-G<W1R(")0<F5S;65R
M;W9ANR!S<'+A=G4B"@HC.B!C;VUP;W-E+G!H<#HX,C4*;7-G:60@(E)E9&ER
M96-T('1H:7,@;65S<V%G92(*;7-G<W1R(")0<F5S;65R;W9ANR!T^G1O('-P
M<N%V=2(*"B,Z(&-O;7!O<V4N<&AP.C@W.`IM<V=I9"`B4F5D:7)E8W1I;F<@
M9F%I;&5D+B(*;7-G<W1R(")0<F5S;65R;W9A;FEE('IL>6AA;&\N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W,@IM<V=I9"`B4F5F<F5S:"!&;VQD
M97(@5FEE=W,Z(@IM<V=S='(@(D]B;F]V:;L@>F]B<F%Z96YI92!P<FEEZ&EN
M:V]V.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA
M=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHT"FUS9VED(")296QO860B"FUS9W-T
M<B`B3V)N;W9INR(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C,*
M;7-G:60@(E)E;&]A9"!6:65W(@IM<V=S='(@(D]B;F]V:;L@>F]B<F%Z96YI
M92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4T-PIM<V=I9"`B4F5M96UB97(@=&AE(&9R964O
M8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B<&%MY'1ANR!S:2!I;F9O<FWA
M8VEE(&\@>F%N97!RX7ID;F5N;W-T:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.38W"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S
M='(@(E!A;>1T8;L@<VD@<&]S;&5D;ND@>F]B<F%Z96YI92(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PIM<V=I9"`B4F5M;W1E($UA
M:6QB;W@Z(@IM<V=S='(@(E9Z9&EA;&5NX2!S8VARX6YK83HB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L
M9"!&<F]M(%-E87)C:"(*;7-G<W1R(")/9'-T<N%N:;L@<&]L92!Z('!R96BU
M863A=F%N:6$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS,#4*;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T<B`B3V1O8G)ANR!Z
M9')O:B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*;7-G
M:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T<B`B4')E;65N;W9ANR!P<FEE
MZ&EN;VLH<')I9>AI;FMY*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$*;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN
M9R!O9B!M;VYT:#\B"FUS9W-T<B`B4')E;65N;W9ANR!P<FEEZ&EN;VL@;V1O
M<VQA;F5J('!ON71Y(&YA('IAZ&EA=&MU(&UE<VEA8V$_(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG(%PB
M)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED(@IM<V=S='(@(E!R96UE;F]V86YI92!<(B5S7"(@;F$@7"(E<UPB
M('IL>6AA;&\N("(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS9W-T<B`B3V1P
M;W9E9&&[(&1O(&4M;6%I;&]V96H@7VMO;F9E<F5N8VEE(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W
M:71H.B(*;7-G<W1R(")0<F5P[7-ANR!N83HB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T
M<B`B3V1P;W9E9&&[(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q
M,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$P"FUS9VED(")297!L>2!3
M96YT+B(*;7-G<W1R(")/9'!O=F7O(&)O;&$@;V1O<VQA;N$N(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")2
M97!L>2!T;R!!;&PB"FUS9W-T<B`B3V1P;W9E9&&[(':Y971K_6TB"@HC.B!C
M;VUP;W-E+G!H<#HW-CD*;7-G:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B
M3V1P;W9E9&&[(':Y971K_6TZ(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$P"FUS9VED(")297!L>2!T;R!,:7-T(@IM<V=S
M='(@(D]D<&]V961ANR!D;R!E+6UA:6QO=F5J(&MO;F9E<F5N8VEE(@H*(SH@
M8V]M<&]S92YP:'`Z-S<Q"FUS9VED(")297!L>2!T;R!,:7-T.B(*;7-G<W1R
M(")/9'!O=F5D8;L@9&\@92UM86EL;W9E:B!K;VYF97)E;F-I93HB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@
M(E)E<&QY('1O(%]!;&PB"FUS9W-T<B`B3V1P;W9E9&&[(%]VN65T:_UM(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S,"!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3,Y"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M-#D*;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM
M<V=S='(@(D]D<&]V961ANR!S;R!S<'+A=F]U.B!.97!O9'!O<F]V86[I(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-PIM<V=I9"`B4F5P;'D@
M=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(D]D
M<&]V961ANR!S<'+A=F]U(&\@>F%N97!RX7ID;F5N;W-T:2!N82!N87-L961U
M:OIC92`R(&UE<VEA8V4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4S-@IM<V=I9"`B4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R(")/9'!O=F5D8;L@<W!RX79O=2!S('!OOF%D
M;W9A;F]U(&EN9F]R;>%C:6]U(&\@>F%N97!RX7ID;F5N;W-T:2XB"@HC.B!M
M97-S86=E+G!H<#HR-C<*;7-G:60@(E)E<&QY+51O(@IM<V=S='(@(D]D<&]V
M961ANR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,C`*;7-G:60@(E)E<&QY+51O
M.B`B"FUS9W-T<B`B3V1P;W9E9&&[.B`B"@HC.B!C;VUP;W-E+G!H<#HW-C<*
M;7-G:60@(E)E<&QY.B(*;7-G<W1R(")/9'!O=F5D8;LZ(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E
M;G0B"FUS9W-T<B`B3VALX7-INR!A:V\@;F6Y:V]D;OH@<&^Y='4B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3
M<&%M(@IM<V=S='(@(D]H;.%S:;L@86MO(&YE=GF^:6%D86[Z('!ON71U(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@S"FUS9VED(")2
M97%U97-T(&$@7U)E860@4F5C96EP="(*;7-G<W1R(")6>;YI861ANR!S:2!S
M<'+A=G4@;R!P7W)EZ.UT86[M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4W,PIM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G<W1R(")6
M>;YA9&]V8;L@<W!RX79U(&\@<')EZ.UT86[M/R(*"B,Z(&UA:6QB;W@N<&AP
M.C$X-PIM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+B(*;7-G
M<W1R(")0;[YA9&]V86[A('-P<N%V82!N96)O;&$@;N%J9&5NX2XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDR"FUS9VED(")297%U:7)E9"!0
M87)T:6-I<&%N="(*;7-G<W1R(")0;[YA9&]V86[](/KH87-T;NUK(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-#,@=&5M<&QA=&5S+W-E87)C
M:"]H96%D97(N:6YC.C(V"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C(*
M;7-G:60@(E)E<V5T(@IM<V=S='(@(E9Y;6%Z8;L@9F]R;75LX7(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$V"FUS9VED(")297-P;VYD96YT
M(%-T871U<R!5<&1A=&5D+B(*;7-G<W1R(")3=&%V(/KH87-T;NUK82!B;VP@
M86MT=6%L:7IO=F%N_2XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R(")/8FYO=FF[
M(@H*(SH@<F5C;VUP;W-E+G!H<#HY-PIM<V=I9"`B4F5S=6UE('EO=7(@<V5S
M<VEO;B(*;7-G<W1R(")0;VMR8>AO=F&[('8@<F5LX6-I:2(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT-`IM<V=I9"`B4F5T=7)N('1O
M(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM<V=S='(@(D[A=G)A="!D;R!M
M96YU(%PB4.US86YI92!S<'+A=GE<(B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9')I=F5R7W-E;&5C="YI;F,Z,S$@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C8Y"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S
M96QE8W0N:6YC.C,R"FUS9VED(")2971U<FX@=&\@1F5T8V@@36%I;"(*;7-G
M<W1R(").X79R870@:R!SNV%H;W9A;FEU('!ON71Y(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO=&%C
M=&EV92YI;F,Z,C(*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#$@
M=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z
M,34*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,R!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,3<U"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R
M(").X79R870@;F$@;F%S=&%V96YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW,#8*;7-G:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T
M:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S
M86=E/R(*;7-G<W1R("(B"B)6<N%T:;L@<V$@;F$@>F]Z;F%M('-P<N%V('!O
M('9Y;6%Z86[M+"!P<F5S=6YE(&%L96)O(&MO<.UR;W9A;NT@<W!RX79Y/R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#,*;7-G:60@(E)O;&4B
M"FUS9W-T<B`B4F]L82(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,30R(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z-#(T"FUS9VED(")3+TU)344B"FUS9W-T<B`B
M4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN
M8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("):
M8;EI9G)O=F&[('-P<N%V=2!P;VUO8V]U(%,O34E-12(*"B,Z(&-O;7!O<V4N
M<&AP.C,W,0IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B0VAY8F$@
M4R]-24U%.B`B"@HC.B!C;VUP;W-E+G!H<#HS-3`*;7-G:60@(E,O34E-12!%
M<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME
M>2XB"FUS9W-T<B`B0VAY8F$@4R]-24U%.B!P<F4@;W-O8F[]('!R:7;A=&YY
M(&NU^N@@=')E8F$@>F%D8;L@:&5S;&\N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U,0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS9W-T<B`B3F%S
M=&%V96YI82!3+TU)344B"@HC.B!S;6EM92YP:'`Z-#8*;7-G:60@(E,O34E-
M12!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(EIA9.%V86YI92!H97-L82!P
M<F4@4R]-24U%(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM
M<V=I9"`B4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E
M<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@HB4')E('!O
M9'!O<G4@;W-O8F[I:&\@:[7ZZ&]VZ6AO('#A<G4@4R]-24U%(&UU<^UT92!M
M8;L@8F5Z<&7H;ND@<')I<&]J96YI92`B"B(H:'1T<',I+B(*"B,Z('-M:6UE
M+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+
M97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(E9E<F5J;OT@4R]-24U%(&NU^N@@<')E(%PB)7-<(B!B;VP@^G-P9;EN
M92!V>6UA>F%N_2XB"@HC.B!S;6EM92YP:'`Z,34X"FUS9VED(")3+TU)344@
M4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E9E<F5J
M;OT@4R]-24U%(&NU^N@@8F]L(/IS<&6Y;F4@<')I9&%N_2XB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C$P"FUS9VED(")3+TU)344@4'5B;&EC
M($ME>7)I;F<B"FUS9W-T<B`B1&%T86+A>F$@=F5R96IN_6-H(%,O34E-12!K
MM?KH;W8B"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")3+TU)344@4'5B;&EC
M+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(DNU^NAO=OT@<.%R(%,O34E-12!B;VP@^G-P9;EN92!P<FED86[]+B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*;7-G:60@
M(E,O34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B4&]D<.US8;L@<W!RX79U
M('!O;6]C;W4@4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP
M=%]L:7-T+FEN8SHQ-`IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S
M86=E(@IM<V=S='(@(E!O9'#M<V&[+WIAN6EF<F]V8;L@<W!RX79U('!O;6]C
M;W4@4R]-24U%(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z
M-`IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S
M>7-T96TN(@IM<V=S='(@(DYA('1O;71O('-Y<W3I;64@:F4@<&]D<&]R82!3
M+TU)344@:F4@>F%KX7IA;N$N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR-#$*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R
M96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@
M(@HB9&5C<GEP=&5D+B(*;7-G<W1R("(B"B)0;V1P;W)A(%,O34E-12!N:64@
M:F4@;6]M96YTX6QN92!A:W1I=F]V86[A+"!T86N^92!N96UOOFYO(&1EN6EF
M<F]V8;L@<W!RX79U+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,3<S"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S
M;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S<V%G92!C86YN;W0@
M(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R("(B"B)0;V1P;W)A(%,O34E-12!N
M:64@:F4@;6]M96YTX6QN92!A:W1I=F]V86[A+"!T86N^92!O8G-A:"!P;V1P
M[7-A;F5J('-P<N%V>2`B"B)N96UOOFYO('IO8G)A>FF[+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P
M<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@
M:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)0;V1P
M;W)A(%,O34E-12!N:64@:F4@;6]M96YTX6QN92!A:W1I=F]V86[A+"!T86N^
M92!N96UOOFYO(&]V97)INR!D:6=I=.%L;GD@(@HB<&]D<&ES+B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@IM<V=I9"`B(@HB4R]-24U%('-U
M<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@
M>6]U<B!B<F]W<V5R(&ES("(*(F-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P
M;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R
M(&5L<V4@(@HB=&AE(%,O34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@HB4&]D<&]R82!3+TU)344@=GF^861U:F4@
M<&]UOFET:64@=GES:V%K;W9A8^UC:"!O:VEE;BX@($%K(%;AN2!P<F5H;&EA
M9&'H("(*(FUO;65N=.%L;F4@8FQO:W5J92!V>7-K86MO=F%C:64@;VMNX2P@
M;75S[71E('1O=&\@;F%S=&%V96YI92!Z;65N:;LL(&EN86L@(@HB;F5B=61E
M(%,O34E-12!F=6YG;W9ANR!S<'+A=FYE+B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C`T"FUS9VED(")33510(@IM<V=S='(@(E--5%`B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-34*;7-G:60@(E-?
M=6)J96-T(@IM<V=S='(@(E!?<F5D;65T(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S8S"FUS9VED(")385]V92!A(&-O<'D@:6X@(@IM
M<V=S='(@(E5?;&^^:;L@:_-P:74@9&\@(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")385]V92!A<R(*;7-G
M<W1R(")5;&^^:;L@7V%K;R(*"B,Z('-E87)C:"YP:'`Z,S$V('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-PIM<V=I9"`B4V%V92(*;7-G<W1R
M(")5;&^^:;LB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,S,*;7-G:60@(E-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E
M;G0M;6%I;"!F;VQD97(_(@IM<V=S='(@(E5L;[YINR!P<NUL;VAY('-O('-P
M<N%V;W4@9&\@<')I9>AI;FMA(&]D;W-L86YE:B!P;[ET>3\B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,C<*;7-G:60@(E-A=F4@1')A9G0B"FUS9W-T<B`B
M56QOOFF[(&MO;F-E<'0B"@HC.B!S879E:6UA9V4N<&AP.C0R"FUS9VED(")3
M879E($EM86=E(@IM<V=S='(@(E5L;[YINR!O8G+A>F]K(@H*(SH@;&EB+TU)
M344O0V]N=&5N=',N<&AP.C(Q,0IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL
M97)Y(@IM<V=S='(@(E5L;[YINR!O8G+A>F]K(&1O(&=A;.ER:64B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-3D@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI
M;F,Z,3,@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T.`HC.B!T96UP;&%T97,O
M<&=P+VYO=&%C=&EV92YI;F,Z,3,*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G
M<W1R(")5;&^^:;L@;F%S=&%V96YI82(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHT,`IM<V=I9"`B4V%V92!3=&%T:6]N97)Y(@IM<V=S
M='(@(E5L;[YINR"Y86)L\VYU(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(W
M"FUS9VED(")3879E(%]$<F%F="(*;7-G<W1R(")5;&^^:;L@7VMO;F-E<'0B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*
M;7-G:60@(E-A=F4@87,B"FUS9W-T<B`B56QOOFF[(&%K;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N
M<V5E;C\B"FUS9W-T<B`B56QOOFF[(&MO;F-E<'1Y(&%K;R!N97!R9>CM=&%N
MZ3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V,`IM<V=I9"`B4V%V
M92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D
M<F5S<R!B;V]K/R(*;7-G<W1R(")5:VQA9&&[('!R[6IE;6-O=B!A=71O;6%T
M:6-K>2!D;R"Y=&%N9&%R9&[I:&\@861R97/A<F$@:V]N=&%K=&]V/R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(W"FUS9VED(")3879E('-E
M87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/R(*;7-G<W1R(")5;&^^:;L@=GEH
MM6%DX79A;FEE(&%K;R!V:7)T=>%L;GD@<')I9>AI;F]K/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(E-A=F4@<V5N="!M86EL/R(*
M;7-G<W1R(")5;&^^:;L@;V1O<VQA;OH@<&^Y='4_(@H*(SH@8V]M<&]S92YP
M:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879I;F<@=&AE(&1R869T
M(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS
M9W-T<B`B56ML861A;FEE(&MO;F-E<'1U('IL>6AA;&\N($-H>6)A.B`E<R(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L
M871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?
M9F]L9&5R<RYP:'`Z-#4*;7-G:60@(E-E87)C:"(*;7-G<W1R(")0<F5HM6%D
MX79ANR(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ."!T96UP
M;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E-E87)C:"`E<R(*;7-G<W1R(")0<F5HM6%DX79ANR`E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C`*;7-G:60@(E-E87)C:"!/<'1I;VYS
M(@IM<V=S='(@(DYA<W1A=F5N:6$@:+5A9&%N:6$B"@HC.B!S96%R8V@N<&AP
M.C(V-0IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B5OUS;&5D;VL@
M:+5A9&%N:6$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$T
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E96XB
M"FUS9W-T<B`B4')EZ.UT86[I(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHY"FUS9VED(")396QE8W0B"FUS9W-T<B`B5GEB<F&[(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<P"FUS9VED(")396QE
M8W0@06YO=&AE<B!!8V-O=6YT(@IM<V=S='(@(E9Y8F5R=&4@:6[](/KH970B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(E-E
M;&5C="!A(&1A=&4B"FUS9W-T<B`B5GEB97)T92!DX71U;2(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHQ,`IM<V=I9"`B4V5L96-T(&$@9FEE
M;&0B"FUS9W-T<B`B5GEB97)T92!P;VQE(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S$W"FUS9VED(")396QE8W0@82!S=&%T:6]N97)Y
M.B(*;7-G<W1R(")6>6)E<G1E(+EA8FSS;G4Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R
M8V5S(&9O<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+B(*
M;7-G<W1R(").87-T879E;FEE(&%D<F5SX7)O=B!P<F4@<')I9.%V86YI92!A
M('9Y:+5A9.%V86YI92!A9')I97,N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHX.`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")/>FYAZ&F[
M(':Y971K;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC
M.C,R,PIM<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@
M97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B5GEB97)T92!VN65T:WD@
M<&]L:6$L('8@:W1O<OUC:"!S82!MX2!HM6%D8;L@<')I(&1O<.7R86[M(&%D
M<FEE<RXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T
M+FEN8SHR,0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B5GEB
M97)T92#ZZ&5T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B6G)UN6F[(&]Z;F'H96YI92(*
M"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS9VED
M(")396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM
M<V=S='(@(E9Y8F5R=&4@9V%LZ7)I=2P@9&\@:W1O<F5J('-A(&WA('5L;[YI
MNR!O8G+A>F]K+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E
M;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP
M92(*;7-G<W1R(")6>6)E<G1E('1Y<"!E+6UA:6QO=NEH;R!S97)V97)A(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"FUS9VED
M(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G<W1R(")6>6)R86[I(&%D
M<F5SX7)E.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B
M4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R(")/9&]S;&&[
M(&NU^N@@;F$@<V5R=F5R('9E<F5J;OUC:"!KM?KH;W8B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3DW"FUS9VED(")396YD($QA=&5S="!);F9O
M<FUA=&EO;B(*;7-G<W1R(")/9&]S;&&[(&YA:FYO=KEI92!I;F9O<FWA8VEE
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(U"FUS9VED(")396YD($UE<W-A
M9V4B"FUS9W-T<B`B3V1O<VQANR!S<'+A=G4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-CDQ"FUS9VED(")396YD(')E860@<F5C96EP="!W:&5N(')E
M<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R(")/9&]S;&&[(&]Z;N%M
M96YI92!O('!R9>CM=&%N[2P@86L@:&\@=GF^861U:F4@;V1O<VEE;&%T9;4_
M(@H*(SH@9F]L9&5R<RYP:'`Z,S<V"FUS9VED(")396YT(&UA:6P@9F]L9&5R
M(@IM<V=S='(@(E!R:67H:6YO:R!O9&]S;&%N96H@<&^Y='DB"@HC.B!T96UP
M;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,X"FUS9VED(")396YT
M(&UA:6P@9F]L9&5R.B(*;7-G<W1R(")0<FEEZ&EN;VL@;V1O<VQA;F5J('!O
MN71Y.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,S('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,30U"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,34R"FUS9VED(")397)V97(B"FUS9W-T<B`B4V5R=F5R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"FUS9VED(")397)V97(@86YD
M($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FWA8VEE(&\@<V5R
M=F5R:2!A('!R:67H:6YK;V-H(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C(S"FUS9VED(")397)V97(Z(@IM<V=S='(@(E-E<G9E<CHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F
M97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E
M;&5T92!M97-S86=E<RXB"FUS9W-T<B`B3F%S=&%V96YI82!P<F5S^G9A;FEA
M(&$@;6%Z86YI82!S<'+A=BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(Y"FUS9VED(")3970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@8V]M
M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R(").87-T879INR!H;&%V:>AK=2!8
M+5!R:6]R:71Y('!R:2!P[7-A;NT@<W!RX79Y/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G<W1R("):
M9&EEM6&[('!R:67H:6YK>2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX
M-@IM<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(EID:66U8;L@
M<')I9>AI;FMY('!ON71Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R
M"FUS9VED(")3:&%R92!Y;W5R(&UA:6P@9F]L9&5R<R!W:71H(&]T:&5R('5S
M97)S+B(*;7-G<W1R("):9&EEM6&[(%9AN64@<')I9>AI;FMY('!ON71Y(',@
M:6[];6D@<&]UONUV871EM6UI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-3<*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D
M('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B
M92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS
M9W-T<B`B(@HB36%J^B!B>;L@=F6U:^D@8FQO:WD@8VET;W9A;NEH;R!T97AT
M=2"Y=&%N9&%R9&YE('IO8G)A>F5NZ2!A;&5B;R!S:W)Y=.D_("(*(DYA<W1A
M=F5N:64@;?2^92!B>;L@:V5D>6MOM79E:R!J961N;V1U8VAO('!R97!N=73I
M+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW"FUS9VED(")3:&]U;&0@
M=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O
M<B!01U`@9&%T83\B"FUS9W-T<B`B36%J^B!S82!V('1E;&4@<W!RX78@='EP
M=2!T97AT+W!L86EN(&BU861ANR#Z9&%J92!P<F4@4$=0/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S
M92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G
M<W1R(")-X2!S82!O:VYO(&YA('#M<V%N:64@<W!RX79Y('IA='9O<FF[('!O
M('5L;[YE;NT@:V]N8V5P='4@/R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHT"FUS9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B92!A
M='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM<V=S='(@
M(DWA('-A(%;AN2!V97)E:F[](%!'4"!KM?KH('!R:7!O:FF[(&L@<W!RX79A
M;3\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"FUS9VED(")3
M:&]W($%L;"!&;VQD97)S(@IM<V=S='(@(EIO8G)A>FF[(':Y971K>2!P<FEE
MZ&EN:WDB"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV-PIM
M<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R("):;V)R87IINR!VN65T
M:WD@:&QA=FGH:WDB"@HC.B!M86EL8F]X+G!H<#HS-#<*;7-G:60@(E-H;W<@
M1&5L971E9"(*;7-G<W1R(")5:^%Z8;L@=GEM87IA;NDB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D
M($AE861E<G,B"FUS9W-T<B`B6F]B<F%Z:;L@:6)A(&)EOF[I(&AL879IZ&MY
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-S`*;7-G:60@
M(E-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N(@IM<V=S='(@(EIO8G)A
M>FF[(&EN9F]R;>%C:64@;R!E+6UA:6QO=F5J(&MO;F9E<F5N8VEI+B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@3VYL
M>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B6F]B<F%Z:;L@:6)A('!R
M:6ALX7-E;ND@<')I9>AI;FMY(@H*(SH@9F]L9&5R<RYP:'`Z,C<W"FUS9VED
M(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")5:^%Z8;L@;F5P<FEH;.%S
M96[I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y-@IM<V=I9"`B4VAO
M=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F
M<F]M(&UE<W-A9V5S/R(*;7-G<W1R("):;V)R87IINR!I:V]N=2!N82!O9'-T
M<N%N96YI92!P<NUL;V@@>F\@<W!RX78_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDY,`IM<V=I9"`B4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@
M=FEE=S\B"FUS9W-T<B`B6F]B<F%Z:;L@=GES=F5T;&EV:WD@=B!Z;WIN86UE
M('-P<N%V/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C@*;7-G:60@
M(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G
M<W1R("):;V)R87IO=F&[('5KX;YK>2!I8F$@<')E(&YE<')EZ.UT86[I('-P
M<N%V>3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,V"FUS9VED(")3
M:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R("):;V)R87IO=F&[
M('5KX;YK>2!A:V\@<&]P:7-K>3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#8U"FUS9VED(")3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE
M(&UE;G5B87(_(@IM<V=S='(@(EIO8G)A>FF[(&EK;VYU(&YA('.[86AO=F%N
M:64@<&^Y='D@=B!M96YU/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY.`IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM<V=S='(@(EIO8G)A>FF[
M(&]B<N%Z:WDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-30*
M;7-G:60@(E-H;W<@=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/R(*
M;7-G<W1R("):;V)R87IINR!I:V]N=2!F:6QT<F]V('8@;65N=3\B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,S$*;7-G:60@(E-H;W<@=&]T86P@;G5M
M8F5R(&]F(&UA:6QS(&EN(&9O;&1E<C\B"FUS9W-T<B`B6F]B<F%Z:;L@8V5L
M:V]V_2!P;^AE="!S<'+A=B!V('!R:67H:6YK=3\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C4T"FUS9VED(")3:&]W;B(*;7-G<W1R("):;V)R87IE
M;NDB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C0R"FUS9VED(")3:5]Z92(*;7-G<W1R(")69;5K;U]SNR(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*;7-G:60@(E-I9VYE9"(*;7-G
M<W1R(")0;V1P[7-A;NDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")69;5K;W.[(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM<V=I
M9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@(E1R:65D:;L@<&]DM6$@Z&%S
M=2!P<NUC:&]D=2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,38*;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R(")4<FEE
M9&F[('!O9+5A(&3A='5M=2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,C8*;7-G:60@(E-O<G0@8GD@1G)O;2!!9&1R97-S
M(@IM<V=S='(@(E1R:65D:;L@<&]DM6$@861R97-Y(&]D;W-I96QA=&6U82(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*
M;7-G:60@(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(E1R:65D:;L@
M<&]DM6$@=F6U:V]S=&DB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C,V"FUS9VED(")3;W)T(&)Y(%-U8FIE8W0B"FUS9W-T
M<B`B5')I961INR!P;V2U82!P<F5D;65T=2(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S$*;7-G:60@(E-O<G0@8GD@5&AR
M96%D(@IM<V=S='(@(E1R:65D:;L@<&]DM6$@=FSA:VYA(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B4V]R
M="!B>2!4;R!!9&1R97-S(@IM<V=S='(@(E1R:65D:;L@<&]DM6$@861R97-Y
M('!R[6IE;6-U(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC
M.C(S"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`B4')I9>AI;F]K('!R
M92!S<&%M.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T
M-@IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97)S(@IM<V=S='(@(JEP96-IX6QN
M92!Z;F%K>2(*"B,Z('-E87)C:"YP:'`Z,3,S"FUS9VED(")3<&5C:6%L(%9I
M<G1U86P@1F]L9&5R<R!C86YN;W0@8F4@961I=&5D+B(*;7-G<W1R("*I<&5C
M:>%L;F4@=FER='7A;&YE('!R:67H:6YK>2!N96UOOFYO('5P<F%V:;LN(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0S"FUS9VED(")3
M<&5L;"!#:&5C:R(*;7-G<W1R(")+;VYT<F]L82!P<F%V;W!I<W4B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(E-P96QL
M($-H96-K97(B"FUS9W-T<B`B2V]N=')O;&$@<')A=F]P:7-U(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHU-@IM<V=I9"`B4W!E;&P@8VAE8VL@8V]M<&QE
M=&4B"FUS9W-T<B`B2V]N=')O;&$@<')A=F]P:7-U('5K;V[H96[A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W,0IM<V=I9"`B4W!E;&QI;F<@97)R
M;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T<B`B
M4&_H970@8VC]8B!N82!S='+A;FMU('!R:2!K;VYT<F]L92!P<F%V;W!I<W4N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4P-R!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3`Y"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-#(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8T-`IM<V=I9"`B4W1A
M<G0B"FUS9W-T<B`BJ71A<G0B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3$*
M;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`BJ6%B;/-N82(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR-@IM<V=I9"`B4W1A=&EO;F5R
M>2!N86UE.B(*;7-G<W1R(")-96YO(+EA8FSS;GDZ(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y
M<&4Z(@IM<V=S='(@(E1Y<""Y86)L\VYY.B(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T
M<B`BJ6%B;/-N83HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@S
M"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A=B(*"B,Z(&QI8B]-24U%+T-O
M;G1E;G1S+G!H<#HR,C(*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T
M<B`B3V1S='+A;FF[('!R[6QO:'4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#(P"FUS9VED(")3=')I<"!L:6YE8G)E86MS/R(*;7-G<W1R(")/9'-T
M<N%N:;L@:V]N8V4@<FEA9&MO=C\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C,W"FUS9VED(")3=6)?:F5C="(*;7-G<W1R
M(")07W)E9&UE="(*"B,Z(&UE<W-A9V4N<&AP.C(V."!T:')E860N<&AP.C$T
M.2!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(U"B,Z(&QI8B]3
M96%R8V@N<&AP.C,X"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E!R961M970B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`X"FUS9VED(")3=6)J96-T
M($9I96QD(@IM<V=S='(@(E!O;&4@<')E9&UE='4B"@HC.B!S96%R8V@N<&AP
M.C,Q."!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3@*(SH@
M=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E;7!L871E<R]P
M9W`O<&%S<W!H<F%S92YI;F,Z,S$*;7-G:60@(E-U8FUI="(*;7-G<W1R(")/
M9&]S;&&[(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3$*
M;7-G:60@(E-U8G-C<FEB92!T;R!&;VQD97(H<RDB"FUS9W-T<B`B4')I:&SA
M<VF[('-A(&1O('!R:67H:6YK82`H<')I9>AI;FMO=BDB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C,X-2!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HS.3,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`BVG-P96-H(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G<W1R
M(").X79R:'DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4Y(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C$*;7-G:60@(E-U;6UA<GDB"FUS
M9W-T<B`B6FAR;G5T:64B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHS.30@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,SDW"FUS
M9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D(@IM<V=S='(@(E!R97!N
M^KL@<W#T<V]B('#M<V%N:6$@<W!RX78B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS.3@*;7-G:60@(E-W:71C:"!T;R!(5$U,(&-O;7!O
M<VET:6]N(@IM<V=S='(@(E!R97!N^KL@;F$@<.US86YI92!S<'+A=B!V($A4
M34PB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.3@*;7-G
M:60@(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@
M(E!R97!N^KL@;F$@<.US86YI92!O8GGH86IN_6-H('1E>'1O=OUC:"!S<'+A
M=B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Q,PIM<V=I
M9"`B5&5?>'0B"FUS9W-T<B`B5&5?>'0B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,C<P"FUS9VED(")496YT871I=F4Z("(*;7-G<W1R(")0<F5D
M8F6^;F4@86MC97!T;W9A;N$Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU.#8*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM
M<V=S='(@(E!R961B9;YN92!A:V-E<'1O=F&[('!OOFEA9&%V:W4B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4T"FUS9VED(")496YT871I=F5L
M>2!!8V-E<'1E9"(*;7-G<W1R(")0<F5D8F6^;F4@86MC97!T;W9A;N$B"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O9B!397)V:6-E(&9I;&4@;F]T
M('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G<W1R(")0;V1M:65N:WD@<&]U
MOFET:6$@;FEE('/Z(+EP96-I9FEK;W9A;ND@=B!C;VYF+G!H<"(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*
M;7-G<W1R(")497AT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,@IM
M<V=I9"`B5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@
M8F4@;&EN:V5D.B(*;7-G<W1R(")0;VQE($]D.B!V('-P<N%V92!B>2!MX2!B
M>;L@<')E<&]J96[I(',Z(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,S,*
M;7-G:60@(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@
M<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D
M+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"B))34%0('-E<G9E<B!P<F%V9&5P;V1O8FYE(&YE<&]D<&]R
M=6IE('9Y8G)A;OH@875T96YT:69I:V'H;OH@;65T\V1U+B`B"B)+;VYT86MT
M=6IT92!P<F]S[6T@<W9O:FAO(&%D;6EN:7-T<N%T;W)A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I
M;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R(")-86-I;G1O<V@@<F5S;W5R
M8V4@9F]R:R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z
M-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($UA8VEN=&]S:"!R97-O=7)C
M92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+B(*;7-G<W1R(")-86-I;G1O
M<V@@<F5S;W5R8V4@9F]R:R!S82!DX2!S=&EA:&YUNR`E<RXB"@HC.B!F971C
M:&UA:6QP<F5F<RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C
M8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(MKH970@
M7"(E<UPB(&)O;"!V>6UA>F%N_2XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R("+:Z&5T(%PB)7-<(B!B;VP@=6QOOF5N
M_2XB"@HC.B!A='1A8VAM96YT+G!H<#HT,PIM<V=I9"`B5&AE(&%T=&%C:&UE
M;G0@=V%S(&YO="!F;W5N9"XB"FUS9W-T<B`B4'+M;&]H82!N96)O;&$@;N%J
M9&5NX2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S$*;7-G:60@
M(E1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`BVF1A:F4@
M:V%L96YDX7)A('/Z(&YE<&QA=&[I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I9"`B(@HB5&AE(&-O;7!O
M<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S
M970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM
M<V=S='(@(B(*(D]K;F\@;F$@<.US86YI92!S<'+A=GD@<V$@;F5P;V1A<FEL
M;R!O='9O<FF[+B!.96WA=&4@;F%S=&%V96[]('!R96AL:6%D8>@@;F$@(@HB
M8FQO:V]V86YI92!V>7-K86MO=F%C[6-H(&]K:65N/R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT
M<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G<W1R(")/
M8G-A:"!S^F)O<G4@36%C:6YT;W-H(&IE('5V961E;OT@;FF^N6EE+B(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY
M+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8W5R<F5N="!F;VQD
M97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S
M='(@(D%K='7A;&YY('!R:67H:6YO:R`H<')I9>AI;FMY*2!<(B5S7"(@8G5D
M92!P<F5M96YO=F%N_2!N82!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R
M<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T
M<FEE=F5D(@IM<V=S='(@(DYE;6^^;F\@>NUS:V&[('IO>FYA;2!P;W6^[79A
M=&6U;W8@<R!P<NUS='5P;VT@:R!T;VUU=&\@<')I9>AI;FMU(@H*(SH@8V]M
M<&]S92YP:'`Z,3(V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9')A9G0@
M:&%S(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F;VQD97(N(@IM<V=S='(@
M(DMO;F-E<'0@8F]L('5L;[YE;OT@9&\@<')I9>AI;FMA(%PB)7-<(BXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30P"FUS9VED(")4:&4@979E
M;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(E5D86QO
M<[L@8F]L82!P<FED86[A(&1O(%;AN6AO(&MA;&5N9.%R82XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I96QD(%PB)7-<(B!C86XG="!B92!E>'!A;F1E9"XB"FUS9W-T
M<B`B4&]L92!<(B5S7"(@<V$@;F5P;V1A<FEL;R!D;W!L;FF[+B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C,S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L
M9&5R(%PB)7-<(B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(")0<FEEZ&EN;VL@
M7"(E<UPB('6^(&5X:7-T=6IE(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A
M:6YS(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A
M=7-E("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*(E!R:67H:6YO:R!<(B5S7"(@;V)S86AU
M:F4@=B!M96YE(&YE<'+M<'5S=&[I('IN86MY+"#H;R!M]+YE('-P]'-O8FF[
M("(*(G!R;V)LZ6UY+B!0<F]S[6T@:V]N=&%K='5J=&4@<W!RX79C=2!6X;EH
M;R!S>7-TZ6UU+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@8W)E871E9"!B=70@
M>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@:70N(@IM<V=S='(@(E!R:67H
M:6YO:R!<(B5S7"(@8F]L('9Y='9O<F5N_2P@86QE(&YE8F]L:2!S=&4@9&_R
M('!R:6ALX7-E;OTN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!D96QE=&5D(&)U
M="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N(@IM<V=S='(@
M(E!R:67H:6YO:R!<(B5S7"(@8F]L('9Y;6%Z86[]+"!A;&4@;F5B;VQI('-T
M92!Z(&YE:&\@;V1H;.%S96[]+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,T,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T
M(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B4')I9>AI;F]K(%PB)7-<(B!N96)O;"!V>71V;W)E;OTN("(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L
M9&5R(%PB)7-<(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B4')I9>AI;F]K(%PB)7-<(B!N96)O;"!V
M>6UA>F%N_2X@4V5R=F5R(&]D<&]V961A;"(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W
M87,@<W5C8V5S<V9U;&QY(&-R96%T960N(@IM<V=S='(@(E!R:67H:6YO:R!<
M(B5S7"(@8F]L(/IS<&6Y;F4@=GET=F]R96[]+B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C(W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<
M(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(E!R:67H:6YO
M:R!<(B5S7"(@8F]L(/IS<&6Y;F4@=GEM87IA;OTN(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E
M<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S
M='(@(E!R:67H:6YO:R!<(B5S7"(@8F]L(/IS<&6Y;F4@<')E;65N;W9A;OT@
M;F$@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY-`IM
M<V=I9"`B5&AE(&9O;&QO=VEN9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H
M:7,@<&%R=#HB"FUS9W-T<B`B2R!T96IT;R#H87-T:2!B;VQI('!R:7!O:F5N
MZ2!N87-L961U:OIC92!S^F)O<GDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]S879E:6UA9V5?=VEN+FIS.C$R"FUS9VED("(B"B)4:&4@:6UA
M9V4@<V%V92!W:6YD;W<@8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U
M(&AA=F4@<V5T('EO=7(@8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U<"!W:6YD
M;W=S/R(*;7-G<W1R("(B"B)/:VYO(&YA('5L;[YE;FEE(&]B<N%Z:V$@<V$@
M;F5P;V1A<FEL;R!O='9O<FF[+B!.96WA=&4@;F%S=&%V96[]('!R96AL:6%D
M8>@@(@HB;F$@8FQO:V]V86YI92!V>7-K86MO=F%C[6-H(&]K:65N/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G:60@(B(*(E1H92!I
M;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES
M('!R97-E;G0@:6X@>6]U<B`B"B)A9&1R97-S8F]O:RXB"FUS9W-T<B`B3V)R
MX7IK>2!S82!Z;V)R87II82P@<')E=&^^92!O9&]S:65L871EM2!J92!V;R!6
M8;EO;2!A9')E<^%R:2XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L
M;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(DUA:6QO=OT@<V5R=F5R
M('9Y9V5N97)O=F%L(&YA<VQE9'5J^F-E(&-H>6)O=ND@:&SA<V5N:64Z(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3$*;7-G:60@
M(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O
M<FUA=&EO;F%L(&UE<W-A9V4Z(@IM<V=S='(@(DUA:6QO=OT@<V5R=F5R('9Y
M9V5N97)O=F%L(&YA<VQE9'5J^F-E(&EN9F]R;6'H;ND@:&SA<V5N:64Z(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H92!M
M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.B(*
M;7-G<W1R(")-86EL;W;]('-E<G9E<B!V>6=E;F5R;W9A;"!N87-L961O=F[I
M(&ALX7-E;FEE.B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB
M"FUS9W-T<B`B4V-H<N%N:V$@)7,@:F4@=;X@<'+A>F1N82XB"@HC.B!L:6(O
M1F5T8VAM86EL+G!H<#HR-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE
M<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B>71E<RD@97AC965D<R!F
M971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("(B"B)3<'+A=F$@7"(E<UPB(&]D
M(%PB)7-<(B`H)60@8F%J=&]V*2!P<F5K<F_H:6QA(&QI;6ET('9EM6MO<W1I
M(&YA('.[86AO=F%N:64N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ,#,*;7-G:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D
M(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B4W!RX79A+"!N
M82!K=&]R96H@<W1E('!R86-O=F%L:2P@8F]L82!Z871V;W)E;N$N($MO;FEE
M8RXB"@HC.B!M97-S86=E+G!H<#HQ-#@*;7-G:60@(E1H92!M97-S86=E(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-P<N%V82!B;VQA('9Y;6%Z86[A
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y-PIM<V=I9"`B5&AE
M(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(E-P<N%V82!B
M;VQA(&]V97)E;N$N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS
M.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@
M=F5R:69I960N(%-E;F1E<CH@)7,N(@IM<V=S='(@(E-P<N%V82!B;VQA(&]V
M97)E;N$N($]D;W-I96QA=&6U.B`E<RXB"@HC.B!T96UP;&%T97,O<VUI;64O
M;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA=&5S+W!G<"]O<&5N7W!G<%]W
M:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S<&AR87-E('=I;F1O=R!C86XG
M="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E
M<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"B)/:VYO
M(&YA('IA9&%N:64@:&5S;&$@<V$@;F5P;V1A<FEL;R!O='9O<FF[+B!.96WA
M=&4@;F%S=&%V96[]('!R96AL:6%D8>@@;F$@(@HB8FQO:V]V86YI92!V>7-K
M86MO=F%C[6-H(&]K:65N/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<F%W('1E>'0@;V8@=&AE
M(%!'4"!0=6)L:6,@2V5Y(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(E1E
M>'0@=&]H=&\@=F5R96INZ6AO(%!'4"!KM?KH82!M]+YE(&)YNR!Z;V)R87IE
M;OT@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C8P"FUS9VED
M(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE($U3
M+51.148@871T86-H;65N="XB"FUS9W-T<B`B4&^^861O=F%N_2!S^F)O<B!N
M965X:7-T=6IE('8@<'+M;&]H92!-4RU43D5&+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8T"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E
M<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM96YT+B(*;7-G<W1R(")0
M;[YA9&]V86[]('/Z8F]R(&YE97AI<W1U:F4@=B!P<NUL;VAE(%II<"XB"@HC
M.B!M97-S86=E+G!H<#HU-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S=&EN9R!A($UE<W-A
M9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("(*(F9R;VT@>6]U('=H96X@
M>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S92!C;&EC:R`E<R!T
M;R!S96YD('1H92`B"B)N;W1I9FEC871I;VX@;65S<V%G92XB"FUS9W-T<B`B
M(@HB3V1O<VEE;&%T9;4@=&5J=&\@<W!RX79Y('9YOF%D=6IE(&]D(%;A<R!O
M>F[A;65N:64@;R!P<F7H[71A;NT@<W!RX79Y+B`B"B)+;&EK;FET92!P<F]S
M[6T@)7,@<')E(&]D;W-L86YI92!S<'+A=GD@<R!O>F[A;65N[6TN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-C<*;7-G:60@(E1H92!S97)V
M97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES
M(&EM86=E+B(*;7-G<W1R(")397)V97(@;F5M;VAO;"!V>71V;W)INR!Z;65N
MN65N^B!K\W!I=2!T;VAT;R!O8G+A>FMU+B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:G,Z,3`W"FUS9VED(")4:&4@<VEG;F%T=7)E(&-O=6QD
M(&YO="!B92!R97!L86-E9"XB"FUS9W-T<B`B4VEG;F%T^G)U('-A(&YE<&]D
M87)I;&\@;F%H<F%D:;LN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YJ<SHQ,#4*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL
M>2!R97!L86-E9"XB"FUS9W-T<B`B4VEG;F%T^G)A(&)O;&$@^G-P9;EN92!N
M86AR861E;N$N(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S
M<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BJ7!E8VEF
M:6MO=F%N_2!S^F)O<B!N965X:7-T=6IE+B(*"B,Z('-T871I;VYE<GDN<&AP
M.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<
M(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T<B`BJ6%B;/-N82!<(B5S7"(@8F]L
M82!U;&^^96[A+B(*"B,Z('-T871I;VYE<GDN<&AP.C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("*I86)L\VYA(%PB)7-<(B!B;VQA('9Y;6%Z86[A+B(*
M"B,Z('-T871I;VYE<GDN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A=&5D+B(*;7-G<W1R
M("*I86)L\VYA(%PB)7-<(B!B;VQA(&%K='5A;&EZ;W9A;N$N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,`IM<V=I9"`B5&AE('1A<VL@:&%S
M(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`BVFQO:&$@
M8F]L82!P<FED86[A(&1O(%;AN6AO('IO>FYA;74@^FQO:"XB"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HY-0IM<V=I9"`B5&AE('1E>'0@;V8@
M=&AE(&UE<W-A9V4B"FUS9W-T<B`B5&5X="!S<'+A=GDB"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G
M<W1R(")497AT('-P<N%V>2!M]+YE(&)YNR!Z;V)R87IE;OT@)7,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#`*;7-G:60@(E1H92!T97AT
M(&]F('1H92!R971U<FYE9"!M97-S86=E(@IM<V=S='(@(E1E>'0@=G+A=&5N
M96H@<W!RX79Y(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D
M(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B5&5X="!V<N%T
M96YE:B!S<'+A=GD@;?2^92!B>;L@>F]B<F%Z96[]("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@(E1E>'0@;V1O<VQA;F5J
M('-P<N%V>2(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT
M(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B5&5X="!O9&]S
M;&%N96H@<W!RX79Y(&WTOF4@8GF[('IO8G)A>F5N_2`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,34U"FUS9VED(")4:&4@=7-E<B=S(&9R
M964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*
M;7-G<W1R("));F9O<FWA8VEA(&\@>F%N97!RX7ID;F5N;W-T:2!P;W6^[79A
M=&6U82!B;VQA(/IS<&6Y;F4@=6QOOF5NX2XB"@HC.B!L:6(O34E-12]6:65W
M97(O86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT
M97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB
M"FUS9W-T<B`BKFEA9&YE(&%L=&5R;F%T[79N92#H87-T:2!N96UOOFYO('IO
M8G)A>FF[('8@=&5L92!S<'+A=GDN(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M96UP='E?;6%I;&)O>"YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A
M9V5S(&EN('1H:7,@;6%I;&)O>"XB"FUS9W-T<B`B5.%T;R!S8VARX6YK82!J
M92!P<N%Z9&YA+B(*"B,Z('1H<F5A9"YP:'`Z,3`Y"FUS9VED(")4:&5R92!I
M<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S
M='(@(JYI861E;B!T97AT(&YE;6^^;F\@>F]B<F%Z:;L@=B!T96QE('-P<N%V
M>2XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C8P"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X
M+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(E9Y<VMY=&]L('-A('!R
M;V)LZ6T@<')I('9Y;6%ZX79A;NT@<V-H<N%N:WDZ("5S(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB
M)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R
M(")6>7-K>71O;"!S82!P<F]B;.EM('!R:2!K;W#M<F]V86[M('-P<N%V('H@
M7"(E<UPB(&1O(%PB)7-<(CH@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(P,2!L
M:6(O365S<V%G92YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F
M;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED
M(@IM<V=S='(@(E9Y<VMY=&QA('-A(&-H>6)A('!R:2!M87IA;NT@<W!RX78@
M>B!P<FEEZ&EN:V$@7"(E<UPB+B`B"@HC.B!L:6(O365S<V%G92YP:'`Z,C@Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R(")6>7-K>71L82!S
M82!C:'EB82!P<FD@;6%Z86[M('-P<N%V('8@<')I9>AI;FMU(%PB)7-<(BX@
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(E9Y<VMY=&QA
M('-A(&-H>6)A('!R:2!M87IA;NT@<W!RX78Z("5S(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T
M<B`B3F%S=&%L82!C:'EB82!P<FD@=GEM87KA=F%N[2!U9&%L;W-T:3H@)7,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-12]6
M:65W97(O96YR:6-H960N<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(").87-T
M86QA(&-H>6)A('!R:2!Z;V)R87IO=F%N[2!T96IT;R#H87-T:2!S<'+A=GDB
M"@HC.B!L:6(O365S<V%G92YP:'`Z-34U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T
M:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@
M<V%I9"(*;7-G<W1R("(B"B)6>7-K>71L82!S82!C:'EB82!P<FD@;F%S=&%V
M;W9A;NT@<'+M>FYA:V]V('-P<N%V>2!V('!R:67H:6YK=2!<(B5S7"(N("(*
M"B,Z(&9O;&1E<G,N<&AP.C$T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R(").87-T86QA
M(&-H>6)A('!R:2!I;7!O<G1E("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(").87-T
M86QA(&-H>6)A('!R:2!I;7!O<G1E('5D86QO<W1I.B`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,38W"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*
M;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!I;7!O<G1E(/IL;VAY.B`E<RXB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S
M(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(B(*(DYA<W1A
M;&$@8VAY8F$@<')I(&EM<&]R=&4@:6YF;W)MX6-I[2!O('IA;F5P<N%Z9&YE
M;F]S=&D@<&]UONUV871EM6$Z("5S+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HX
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M;6]V:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R(").87-T86QA(&-H
M>6)A('!R:2!P<F5S^G9A;NT@<W!RX78@>B!<(B5S7"(@9&\@7"(E<UPB+B`B
M"@HC.B!C;VUP;W-E+G!H<#HQ,C8X"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T+B(*;7-G<W1R(").
M87-T86QA(&-H>6)A('!R:2!U:VQA9&%N[2!K;VYC97!T=2XB"@HC.B!C;VUP
M;W-E+G!H<#HQ,#,S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS9W-T<B`B0VAY
M8F$@<')I('!O<VEE;&%N[2!S<'+A=GDZ("5S(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B
M3F%S=&%L82!C:'EB82!P<FD@86MT=6%L:7KA8VEI(&]B:F5K='4Z("5S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU.0IM<V=I9"`B5&AE<F4@
M=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B5.%T
M;R#H87.[('-P<N%V>2!N96]B<V%H;W9A;&$@=&5X="(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G:60@(E1H:7,@2%1-3"!M97-S86=E
M(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM<V=S='(@(E3A=&\@2%1-
M3"!S<'+A=F$@;V)S86AU:F4@;V)RX7IK>2XB"@HC.B!L:6(O34E-12]6:65W
M97(O:'1M;"YP:'`Z.3,*;7-G:60@(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA
M<R!I;6%G97,@96UB961D960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A
M<B!L:6ME("(*(G1H:7,Z("(*;7-G<W1R("(B"B)4X71O($A434P@<W!RX79A
M(&]B<V%H=6IE(&]B<N%Z:WDN($)L;VMO=F%NZ2!O8G+A>FMY('-A('IO8G)A
M>FEA('1A:W1O.B`B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C4*
M;7-G:60@(E1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O('1H
M92!M97-S86=E+B(*;7-G<W1R(")496YT;R!V97)E:F[](%!'4"!KM?KH(&)O
M;"!P<FEP;VIE;OT@:R!S<'+A=F4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$Y"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#0@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$U.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<T(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,34*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(E3A=&\@86MC:6$@;FEE(&IE
M('!O9'!O<F]V86[A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M.#`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0R,`IM<V=I9"`B5&AI<R!A
M8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B5.%T;R!A
M:V-I82!EN71E(&YI92!J92!I;7!L96UE;G1O=F%NX2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$T"FUS9VED(")4:&ES(&UA>2!T
M86ME('-O;64@=&EM92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O;G1I
M;G5E/R(*;7-G<W1R(")4;W1O(&WTOF4@8VAV[;5U('1R=F&[+B!.86]Z86H@
M8VAC971E('!O:W)AZ&]V8;L_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE
M9&]U8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@
M36%C:6YT;W-H(&9I;&4N(@IM<V=S='(@(E3A=&\@<W!RX79A(&]B<V%H=6IE
M('/Z8F]R($UA8VEN=&]S:"XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C0Q-0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T
M=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3
M+R(*(DU)344N(@IM<V=S='(@(B(*(E3A=&\@<W!RX79A(&]B<V%H=6IE('!R
M[6QO:'4L(&MT<N$@8F]L82!D:6=I=.%L;F4@<&]D<.US86[A('!O;6]C;W4@
M4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS
M9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T
M(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R(")4X71O
M('-P<N%V82!O8G-A:'5J92!P<NUL;VAU+"!K=&]RX2!B;VQA('IAN6EF<F]V
M86[A('!O;6]C;W4@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C$V,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA
M:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA
M="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T<B`B(@HB
M5.%T;R!S<'+A=F$@;V)S86AU:F4@:6YF;W)MX6-I=2!O('-T879E(&1O<G7H
M96YI82!P;[ET>2P@86QE(&9O<FWA="!S<'+A=GD@(@HB;FEE(&IE('INX6UY
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q.0IM<V=I9"`B(@HB
M5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'
M4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G<W1R(")4X71O('-P
M<N%V82!P<F%V9&5P;V1O8FYE(&YI92!J92!Z8;EI9G)O=F%NX2!01U`N($-H
M>6)A.B`B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,SD@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,S4T"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M
M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(B(*(E3A
M=&\@<W!RX79A('!R879D97!O9&]B;F4@;FEE(&IE('8@<W!RX79N;VT@4$=0
M(&9O<FWA=&4@*'!O9+5A(%)&0R`R,#$U*2XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI<R!M97-S86=E(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R;6%T+B(*
M;7-G<W1R(")4X71O('-P<N%V82!P<F%V9&5P;V1O8FYE(&YI92!J92!V('-P
M<N%V;F]M(%,O34E-12!F;W)MX71E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT,C`*;7-G:60@
M(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!0
M1U`N(@IM<V=S='(@(E3A=&\@<W!RX79A(&)O;&$@9&EG:73A;&YE('!O9'#M
M<V%NX2!P;VUO8V]U(%!'4"XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C$T,PIM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL
M>2!S:6=N960@=FEA(%,O34E-12XB"FUS9W-T<B`B5.%T;R!S<'+A=F$@8F]L
M82!D:6=I=.%L;F4@<&]D<.US86[A('!O;6]C;W4@4R]-24U%+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3,Y(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,C,X"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC
M<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(E3A=&\@<W!RX79A(&)O;&$@
M>F&Y:69R;W9A;N$@<&]M;V-O=2!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,C`P(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,`IM
M<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'
M4"XB"FUS9W-T<B`B5.%T;R!S<'+A=F$@8F]L82!Z8;EI9G)O=F%NX2!P;VUO
M8V]U(%!'4"XB"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S
M<V%G92!T;R(*;7-G<W1R(")4^G1O('-P<N%V=2!D;R(*"B,Z(&%C;"YP:'`Z
M-#4*;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R(")496YT;R!S97)V97(@;F5P;V1P;W)U:F4@
M>F1I9;5A;FEE('!R:67H:6YK;W8N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ,#D*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@
M8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`B5&]T;R!O
M:VYO('-A(&UU<^T@=F]L8;L@>B!O:VYA('!R92!P[7-A;FEE('-P<N%V>2XB
M"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B5&AR96%D($1I
M<W!L87DB"FUS9W-T<B`B3F%S=&%V96YI92!Z;V)R87IE;FEA(@H*(SH@=&AR
M96%D+G!H<#HW-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$P"FUS9VED(")4
M:')E860@5FEE=R(*;7-G<W1R("):;V)R87IINR!V;.%K;F$B"@HC.B!M97-S
M86=E+G!H<#HR-C0@;6%I;&)O>"YP:'`Z-3DT('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C8Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,3`@
M;&EB+U-E87)C:"YP:'`Z,C8*;7-G:60@(E1O(@IM<V=S='(@(E!R92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(E1O($%D9')E<W,B
M"FUS9W-T<B`B061R97-A('!R[6IE;6-U(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-O=7)C97-E;&5C="YI;F,Z,S(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L
M=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#
M;VUM86YD("A-86,I('=H:6QE("(*(F-L:6-K:6YG+B(*;7-G<W1R("(B"B)0
M<F4@=OUB97(@=FEA8V5R_6-H('!O;.T@9'*^=&4@0V]N=')L;"`H4$,I(&%L
M96)O($-O;6UA;F0@*$UA8RD@<&_H87,@(@HB:VQI:V%N:6$N(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HQ,S0*;7-G:60@(B(*(E1O('5S92!A(%1,4R!C
M;VYN96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!0
M2%`@-2XP+C8@;W(@(@HB:&EG:&5R+B(*;7-G<W1R("(B"B)!8GD@<W1E(&UO
M:&QI('!O=;YINR!43%,@<W!O:F5N:64L(&UU<^UT92!P;W6^[79ANR!02%`@
M-2XP+C8@86QE8F\@=GFYN6EE+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4X.`IM<V=I9"`B5&]T86P@071T86-H;65N=',@4VEZ93HB
M"FUS9W-T<B`B0V5L:V]VX2!V9;5K;W.[('!R[6QO:#HB"@HC.B!F;VQD97)S
M+G!H<#HS-C<*;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G<W1R(")/9'!A9&MO
M=OT@:_2Y(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR
M,PIM<V=I9"`B5')A<V@@9F]L9&5R.B(*;7-G<W1R(")/9'!A9&MO=OT@:_2Y
M.B(*"B,Z(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C0@;&EB+U%U;W1A+VUE<F-U
M<GDS,BYP:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1
M=6]T82]L;V=F:6QE+G!H<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@
M;&EB+U%U;W1A+VUD865M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T
M<FEE=F4@<75O=&$B"FUS9W-T<B`B3F5M;[YN;R!Z[7-K8;L@:6YF;W)MX6-I
M=2!O(&MV\W1E(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS
M=V5R960B"FUS9W-T<B`B3F5Z;V1P;W9E9&%NZ2(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@(E5N86YS=V5R960@;65S<V%G97,B
M"FUS9W-T<B`B3F5Z;V1P;W9E9&%NZ2!S<'+A=GDB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-"!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B56YD96QE=&4B"FUS9W-T<B`B3V)N
M;W9INR(*"B,Z(&UA:6QB;W@N<&AP.C4W-R!M86EL8F]X+G!H<#HU.3`@;&EB
M+TU)344O2&5A9&5R<RYP:'`Z,C`T"FUS9VED(")5;F1I<V-L;W-E9"!296-I
M<&EE;G1S(@IM<V=S='(@(DYE>G9E<F5J;F5N[2!P<NUJ96UC;W9I82(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R
M(").96^Y971R96[](&MO;7!O;F5N="!T>7!U.B`E<R(*"B,Z(&UA:6QB;W@N
M<&AP.C4U-PIM<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@(DYE>F[A;7D@
M9.%T=6TB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;FMN;W=N($E-05`@<F5S<&]N<V4@9G)O;2!T:&4@<V5R
M=F5R+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R(").97INX6UA($E-
M05`@;V1P;W9E[R!O9"!S97)V97)A+B!397)V97(@;V1P;W9E9&%L.B`E<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C8*;7-G:60@(E5N:VYO
M=VX@365E=&EN9R(*;7-G<W1R(").97INX6UE('-T<F5T;G5T:64B"@HC.B!M
M86EL8F]X+G!H<#HV,#8*;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S
M='(@(DYE>F[A;7D@<'+M:F5M8V$B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL
M;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`B3V1S='+A;FF[(&AE<VQO('H@<&%M
MY'1I(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D
M(@IM<V=S='(@(DYE<&]M96YO=F%NX2(*"B,Z(&UE<W-A9V4N<&AP.C0Y-2!M
M86EL8F]X+G!H<#HV.34@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,34@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*;7-G<W1R(").
M97!R9>CM=&%NZ2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C$R"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS*2(*;7-G<W1R
M(")/9&ALX7-INR!S82!Z('!R:67H:6YK82`H<')I9>AI;FMO=BDB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3(*;7-G:60@(E5P9&%T
M92(*;7-G<W1R(")!:W1U86QI>N%C:6$B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C$R"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B
M"FUS9W-T<B`B06MT=6%L:7IO=F&[('-T878@^NAA<W1N[6MA(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C4X('1E;7!L871E<R]P9W`O
M:6UP;W)T7VME>2YI;F,Z-38*;7-G:60@(E5P;&]A9"(*;7-G<W1R(").86AR
M8;LB"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0Q
M"FUS9VED(")5<V4@1&5F875L="!686QU92(*;7-G<W1R(")0;W6^:;L@<')E
M9&YA<W1A=F5N^B!H;V1N;W1U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U-@IM<V=I9"`B57-E($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM
M<V=S='(@(E!O=;YINR!P<FEH;.%S96YI92!D;R!P<FEEZ&EN:V]V($E-05`_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<R,PIM<V=I9"`B57-E(%9I
M<G1U86P@5')A<V@@1F]L9&5R/R(*;7-G<W1R(")0;W6^:;L@<')I9>AI;F]K
M('9I<G1UX6QN96AO($MON6$_(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C$T,PIM<V=I9"`B57-E<B(*;7-G<W1R(")0;W6^[79A=&6U(@H*(SH@86-L
M+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)5<V5R(%PB)7-<(B!S
M=6-C97-S9G5L;'D@9VEV96X@=&AE('-P96-I9FEE9"!R:6=H=',@9F]R('1H
M92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"B)0;W6^[79A=&6U;W9I(%PB
M)7-<(B!B;VQI(/IS<&6Y;F4@<')I9&5L96[I('!RX79A('!R92!P<FEEZ&EN
M;VL@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<V
M"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")0<FEH;&%S;W9A8VEE(&UE;F\B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3<*;7-G:60@
M(E5S97)N86UE.B(*;7-G<W1R(")0<FEH;&%S;W9A8VEE(&UE;F\Z(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<B
M"FUS9W-T<B`B6F]B<F%Z:;LB"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H
M<#HY,B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3$P"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B6F]B<F%Z:;L@)7,B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(%!U8FQI8R!+
M97DB"FUS9W-T<B`B6F]B<F%Z:;L@)7,@=F5R96IN_2!KM?KH(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0IM<V=I9"`B5FEE=R!(5$U,(&-O
M;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B6F]B<F%Z:;L@
M2%1-3"!O8G-A:"!V(&YO=F]M(&]K;F4B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHR.`IM<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R
M("):;V)R87IINR!S<'+A=GDB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R!0
M97)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("):;V)R87IINR!O<V]B;OT@
M<')I=N%T;GD@:[7ZZ"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")6:65W(%!E<G-O
M;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B6F]B<F%Z:;L@;W-O8F[]('9E<F5J
M;OT@:[7ZZ"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ.`IM<V=I9"`B5FEE=R!4:')E860B"FUS9W-T<B`B6F]B<F%Z:;L@
M=FSA:VYO(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V-@IM<V=I9"`B5FEE=R!4:'5M
M8FYA:6PB"FUS9W-T<B`B6F]B<F%Z:;L@:6MO;G4B"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C0R,PIM<V=I9"`B5FEE=R!A='1A8VAM96YT(&EN
M(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(EIO8G)A>FF[('!R[6QO:'4@
M=B!N;W9O;2!O:VYE(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP
M.C<Y"FUS9VED(")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B
M"FUS9W-T<B`B6F]B<F%Z:;L@;V)S86@@=B!N;W9O;2!O:VYE(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,0IM<V=I9"`B5FEE=R!E=F5N="(*
M;7-G<W1R("):;V)R87IINR!U9&%L;W.[(@H*(SH@9F]L9&5R<RYP:'`Z,S4Y
M(&UA:6QB;W@N<&AP.C4R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE
M<W-A9V5S(&EN("5S(@IM<V=S='(@(EIO8G)A>FF[('-P<N%V>2!V("5S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM
M<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ
M(@IM<V=S='(@(E!O('!R:6ALX7-E;NT@>F]B<F%Z:;LZ(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$W,0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S
M='(@(EIO8G)A>FF[(/IL;VAU(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$P-`IM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM<V=S='(@(EIO8G)A
M>FF[(&]B<N%Z:WDB"@HC.B!S96%R8V@N<&AP.C(V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F
M=6QL>2XB"FUS9W-T<B`B5FER='7A;&YY('!R:67H:6YO:R!<(B5S7"(@8F]L
M(/IS<&6Y;F4@=GET=F]R96[]+B(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z,3<U
M"FUS9VED(")6:7)T=6%L($9O;&1E<B!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B5FER='7A;&YY('!R:67H:6YO:R!N965X:7-T=6IE+B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])34%0+U1R964N<&AP.C$S
M,R!L:6(O24U!4"]4<F5E+G!H<#HQ-#8*(SH@;&EB+TE-05`O5')E92YP:'`Z
M,30X(&QI8B])34%0+U1R964N<&AP.C$U,B!L:6(O24U!4"]4<F5E+G!H<#HQ
M-3,*(SH@;&EB+TE-05`O5')E92YP:'`Z,S8S(&QI8B])34%0+U1R964N<&AP
M.C,X-R!L:6(O24U!4"]4<F5E+G!H<#HT,C4*;7-G:60@(E9I<G1U86P@1F]L
M9&5R<R(*;7-G<W1R(")6:7)T=>%L;F4@<')I9>AI;FMY(@H*(SH@<V5A<F-H
M+G!H<#HR-#4*;7-G:60@(E9I<G1U86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B
M96PN(@IM<V=S='(@(E9I<G1UX6QN>2!P<FEEZ&EN;VL@<&]T<F5B=6IE('!O
M<&ES;VLN(@H*(SH@;&EB+U9&;VQD97(N<&AP.C$W-B!L:6(O5D9O;&1E<BYP
M:'`Z,3@V"FUS9VED(")6:7)T=6%L($E.0D]8(@IM<V=S='(@(E9I<G1UX6QN
M82!S8VARX6YK82!P<FEJ873]8V@@<W!RX78B"@HC.B!F;VQD97)S+G!H<#HS
M.34*;7-G:60@(E9I<G1U86P@24Y"3U@@1F]L9&5R(@IM<V=S='(@(E9I<G1U
MX6QN>2!P<FEEZ&EN;VL@<')I:F%T_6-H('-P<N%V(@H*(SH@;6%I;&)O>"YP
M:'`Z-#,U(&QI8B]-86EL8F]X+G!H<#HQ-S`@;&EB+U9&;VQD97(N<&AP.C$Q
M,2!L:6(O5D9O;&1E<BYP:'`Z,3(S"FUS9VED(")6:7)T=6%L(%1R87-H(@IM
M<V=S='(@(E9I<G1UX6QN>2!+]+DB"@HC.B!F;VQD97)S+G!H<#HS.3(*;7-G
M:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(E!R:67H:6YO:R!V
M:7)T=>%L;F5H;R!K;[EA(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8S.0IM<V=I
M9"`B5FER='5A;"!4<F%S:"!&;VQD97(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(E!R:67H:6YO:R!V:7)T=>%L;F5H;R!K;[EA(&YE97AI<W1U:F4N(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U
M86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@(E!O<&ES;VL@=FER='7A;&YE:&\@
M<')I9>AI;FMU(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-SD*
M;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B5F%R;W9A;FEE(@H*(SH@;&]G:6XN
M<&AP.C$T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM
M<V=S='(@(E;M=&$@5N%S("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8P-PIM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE
M<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@
M(@HB;W(@:6YN;V-E;G0_(@IM<V=S='(@(B(*(LAO('-A(&WA('5R;V)INR!S
M(&YE=GF^:6%D86YO=2!P;[ET;W4@<&\@:F5J(&]H;.%S96[M(&%K;R!S<&%M
M(&%L96)O("(*(FYEN6MO9&[Z('!ON71U/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW,34*;7-G:60@(B(*(E=H96X@9&5L971I;F<@;65S<V%G97,L
M(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA
M<FMI;F<@(@HB=&AE;2!A<R!D96QE=&5D/R(*;7-G<W1R("(B"B)0<F5S=6[Z
MNR!V>6UA>F%NZ2!S<'+A=GD@9&\@3V1P861K;W;I:&\@:V^Y82!N86UI97-T
M;R!I8V@@;WIN8>AE;FEA('IA("(*(G9Y;6%Z86[I/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.34*;7-G:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M
M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N/R(*
M;7-G<W1R("(B"B).82!K=&]R96H@<W1R86YE(&-H8V5T92!Z8>AANR!P<F5Z
M97)A;FEE('-P<N%V('!R:2!O='9O<F5N[2!N;W9E:B!S8VARX6YK>3\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN
M9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B
M"FUS9W-T<B`B36%J^B!S82!U;&^^:;L@<'+M;&]H>2!P<FD@=6ML861A;NT@
M;V1O<VQA;F5J('!ON71Y/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N9&EN9R!A
M9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E;F0@=&\@(@HB
M=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S97,@=VET:&]U
M="!<(D!<(BD_(@IM<V=S='(@(B(*(E!R:2!P;W-I96QA;NT@<&^Y='D@86QE
M8F\@9&]PY?)A;NT@861R:65S+"!A:^$@9&]MZ6YA('-A(&WA(&1O<&QN:;L@
M>F$@(@HB;F7Z<&QNZ2!A9')E<WD@*&4M;6%I;&]VZ2!A9')E<WD@8F5Z(%PB
M0%PB*3\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@
M(E=H:71E;&ES="(*;7-G<W1R(")":65L82!L:7-T:6YA(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,V('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4T.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38V
M"FUS9VED(")997,B"FUS9W-T<B`BP6YO(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HU.`IM<V=I9"`B66]U(&%R92!A
M8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N
M="AS*3HB"FUS9W-T<B`B0VAY<W3A=&4@<V$@<W1I86AN=;L@<&^Y='4@>B!N
M87-L961U:OIC:6-H(/KH=&]V.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O
M;&1E<G-?8V]N9FER;2YH=&UL.C$P"FUS9VED("(B"B)9;W4@87)E(&%T=&5M
M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE
M(&9O;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@(B(*(D-H>7-TX71E
M('-A('9Y;6%Z8;L@=KEE=&MY('-P<N%V>2!V(&YA<VQE9'5J^F-O;2!P<FEE
MZ&EN:W4@*'!R:67H:6YK;V-H*2XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F
M;VQD97)S7V-O;F9I<FTN:'1M;#HY"FUS9VED(")9;W4@87)E(&%T=&5M<'1I
M;F<@=&\@9&5L971E('1H92!F;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G<W1R
M(")#:'ES=.%T92!S82!V>6UA>F&[(&YA<VQE9'5J^F-I('!R:67H:6YO:R`H
M<')I9>AI;FMY*2XB"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T
M+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*
M;7-G:60@(EEO=2!A<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R
M+B(*;7-G<W1R(")+;W#M<G5J971E+W!R97/Z=F%T92!D;R!N;W;I:&\@<')I
M9>AI;FMA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,3`R"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B
M"FUS9W-T<B`B5GET=N%R871E('!R:67H:6YO:R!V("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")9;W4@87)E(&-R
M96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BXB"FUS9W-T<B`B5GET=N%R871E
M('!R:67H:6YO:R!N86IV>;FY96H@^G)O=FYE+B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C,Q.`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M9F]L9&5R<RXB"FUS9W-T<B`B3F5MX71E(&]P<N%V;F5N:64@;F$@=GET=N%R
M86YI92!P<FEEZ&EN:V]V+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T
M92!M;W)E('1H86X@)60@9F]L9&5R<RXB"FUS9W-T<B`B3F5MX71E(&]P<N%V
M;F5N:64@=GET=F]R:;L@=FEA8R!A:V\@)60@<')I9>AI;FMO=BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-0IM<V=I9"`B66]U
M(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B`B"FUS9W-T<B`B4')E;65N^G9A
M=&4@<')I9>AI;F]K.B`B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@
M=&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@
M=&5X=#H@)6,@9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@
M)7,@9F]R('1H92!S:6=N871U<F4N(@IM<V=S='(@(B(*(E8@=&5X=&4@N6%B
M;/-N>2!M]+YE=&4@<&]UOFF[(&YA<VQE9'5J^F-E(+EP96-IX6QN92!Z;F%K
M>3H@)6,@<')E(&]B<V%H("(*(F%K='7A;&YE:B!S<'+A=GD[("5S('!R92!S
M:6=N873Z<G4N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-38U"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!C86YN;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N
M(@IM<V=S='(@(DYE;?2^971E('-A(&]D:&SA<VF[('H@7"(E<UPB+B(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C,T"FUS
M9VED("(B"B)9;W4@9&ED(&YO="!A9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R
M=FEC92!A9W)E96UE;G0L('-O('EO=2!W97)E(&YO="!A;&QO=V5D("(*(G1O
M(&QO9VEN+B(*;7-G<W1R(").97/Z:&QA<VEL:2!S=&4@<R!P;V1M:65N:V%M
M:2!P;W6^:71I82P@=&%KOF4@<V$@;F5M]+YE=&4@<')I:&SA<VF[+B(*"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S`*;7-G:60@(EEO=2!D;R!N;W0@
M:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD
M97(B"FUS9W-T<B`B3F5MX71E('!RX79O(&YA<W1A=FF[('!R[7-T=7`@:R!T
M;VUU=&\@<')I9>AI;FMU(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$S,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O
M;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T
M<B`B4')E<&]S;&%L:2!S=&4@=/IT;R!S<'+A=G4@)25S(&YA<VQE9&]V;OUM
M('!R[6IE;6-O;3H@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N
M:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE
M<W-A9V5S+B(*;7-G<W1R(")-X71E("5S(&YO=OUC:"!S<'+A=BXB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PIM<V=I9"`B66]U(&AA=F4@
M,2!N97<@;65S<V%G92XB"FUS9W-T<B`B3>%T92`Q(&YO=OH@<W!RX79U+B(*
M"B,Z(&-O;7!O<V4N<&AP.C0X,`IM<V=I9"`B66]U(&AA=F4@86QR96%D>2!S
M=6)M:71T960@=&AI<R!P86=E+B(*;7-G<W1R(")4^G1O('-T<N%N:W4@<W1E
M('6^(&]D;W-L86QI+B(*"B,Z(&QI8B])35`N<&AP.C$P-38*;7-G:60@(EEO
M=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G
M<W1R(")-X71E(&YO=OH@<&^Y='4@=B!N87-L961U:OIC;VT@<')I9>AI;FMU
M.B(*"B,Z(&QI8B])35`N<&AP.C$P-C$*;7-G:60@(EEO=2!H879E(&YE=R!M
M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`B3>%T92!N
M;W;Z('!ON71U('8@;F%S;&5D=6KZ8VEC:"!P<FEEZ&EN:V]C:#HB"@HC.B!C
M;VUP;W-E+G!H<#HQ-3,*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE87-T
M(&]N92!R96-I<&EE;G0N(@IM<V=S='(@(DUU<^UT92!Z861ANR!M8;L@87-P
M;_(@:F5D;NEH;R!P<NUJ96UC=2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HS,#8*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S
M<V%G92(*;7-G<W1R("(B"B).82!Z;V)R87IE;FEE('1E:G1O('-P<N%V>2!M
M=7/M=&4@>F%D8;L@:&5S;&\@<')E(%;AN2!O<V]B;OT@<')I=N%T;GD@4$=0
M("(*(FNU^N@B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(U-`IM
M<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO
M=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R`B"B)M97-S86=E
M(@IM<V=S='(@(B(*(DYA('IO8G)A>F5N:64@=&5J=&\@<W!RX79Y(&UU<^UT
M92!Z861ANR!H97-L;R!P<F4@5N&Y(&]S;V)N_2!P<FEVX71N>2!3+TU)344@
M(@HB:[7ZZ"(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC
M.C8T('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(P,0IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM
M<V=S='(@(DUU<^UT92!N86IP<G8@=GEB<F&[(&-I9;5O=OH@<V-H<N%N:W4N
M(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9;W4@;75S="!S
M96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")-=7/M
M=&4@;WIN8>AINR#ZZ&5T+"!K=&]R_2!MX2!B>;L@=GEM87IA;OTN(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0IM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(DUU<^UT
M92!N86IP<G8@=GEB<F&[(&%D<F5S=2XB"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]J879A<V-R:7!T+FEN8SHV,B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R
M:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z,C8S"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE
M<W-A9V4@9FER<W0N(@IM<V=S='(@(DUU<^UT92!N86IP<G8@=GEB<F&[(&%S
M<&_R(&IE9&YU('-P<N%V=2XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z,3,*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!R96-I<&EE
M;G0N(@IM<V=S='(@(DUU<^UT92!U<NAINR!P<NUJ96UC=2XB"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@96YA8FQE9"!I;B!Y;W5R
M(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@(E8@;F%S=&%V96YI86-H
M(/ID<KYB>2!M=7/M=&4@;6&[('!O=F]L96[I(%PB)7-<(BXB"@HC.B!L:6(O
M36%I;&QO9RYP:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R961I
M<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N(@IM<V=S='(@(E!R
M97-M97)O=F%L:2!S=&4@=/IT;R!S<'+A=G4@)7,@)25S+B(*"B,Z(&QI8B]-
M86EL;&]G+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<&QI
M960@=&\@=&AI<R!M97-S86=E(&]N("5S+B(*;7-G<W1R(")/9'!O=F5D86QI
M('-T92!N82!T^G1O('-P<N%V=2`E<RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HU
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('-U8G-C<FEB
M960@=&\@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(DYE8F]L:2!S=&4@<')I:&SA<V5N_2!D;R!<(B5S7"(N("(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H
M870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(DYE8F]L:2!S=&4@;V1H;.%S
M96[]('H@7"(E<UPB+B`B"@HC.B!L:6(O1F]L9&5R+G!H<#HU,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB
M960@=&\@7"(E<UPB(@IM<V=S='(@(D)O;&D@<W1E(/IS<&6Y;F4@<')I:&SA
M<V5N_2!D;R!<(B5S7"(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3<P"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C
M<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B0F]L:2!S=&4@^G-P9;EN92!O
M9&ALX7-E;OT@>B!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B5F&Y92!C96SI(&UE;F\B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G:60@(EEO=7(@4$=0
M(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B5F&Y92!01U`@:[7ZZ&4B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Q('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW-@IM<V=I9"`B66]U<B!0<FEV871E($ME>2(*;7-G<W1R
M(")6X;D@<')I=N%T;GD@:[7ZZ"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<Q"FUS9VED(")9;W5R
M(%!U8FQI8R!+97DB"FUS9W-T<B`B5N&Y('9E<F5J;OT@:[7ZZ"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C4*;7-G:60@(EEO=7(@4F5P;'DM=&\Z
M(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`B5F&Y82!A
M9')E<V$@<')E(&]D<&]V9>\@*%)E<&QY+71O*3H@/&5M/FYE<&]V:6YNZ2D\
M+V5M/B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#D*;7-G:60@
M(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<R(*;7-G
M<W1R(")68;EE(%,O34E-12!V97)E:F[I+W!R:7;A=&YE(&-E<G1I9FEKX71Y
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z
M,38*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S='(@(E9AN64@^NAT>3HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<S"FUS9VED("(B"B)9;W5R
M(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A
M9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB5F&Y92!A
M;&EA<WDZ(#QE;3XH=F]L:71EM6[I+"!Z861A:G1E(&MAOF3Z(&%D<F5S=2!N
M82!N;W9O;2!R:6%D:W4I/"]E;3XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ,#$*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T
M<B`B5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@<')I86UE('IO8G)A>F5N
M:64@=&]H=&\@='EP=2!O8G+A>FMO=BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N
M9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B5F&Y82!P<F5D;F%S=&%V96[A('IN
M86MO=N$@<V%D82!P<F4@<&]S:65L86YI92!S<'+A=CHB"@HC.B!T96UP;&%T
M97,O<')E9G,O96YC<GEP='-E;&5C="YI;F,Z,0IM<V=I9"`B66]U<B!D969A
M=6QT(&5N8W)Y<'1I;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*
M;7-G<W1R(")6X;D@<')E9&YA<W1A=F5N_2!S</1S;V(@N6EF<F]V86YI82!P
M<F4@<&]S:65L86YI92!S<'+A=CHB"@HC.B!A='1A8VAM96YT+G!H<#HY-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&QI;FME9"!A='1A8VAM96YT
M(&AA<R!B965N(&1O=VYL;V%D960@8GD@870@;&5A<W0@;VYE('5S97(N7&XB
M"B)<;B(*(D%T=&%C:&UE;G0@;F%M93H@)7-<;B(*(D%T=&%C:&UE;G0@9&%T
M93H@)7-<;B(*(EQN(@HB0VQI8VL@;VX@=&AE(&9O;&QO=VEN9R!L:6YK('1O
M('!E<FUA;F5N=&QY(&1E;&5T92!T:&4@871T86-H;65N=#I<;B(*(B5S(@IM
M<V=S='(@(B(*(E9AN6$@;F%L:6YK;W9A;N$@<'+M;&]H82!B;VQA('-T:6%H
M;G5TX2!N86IM96YE:B!J961N_6T@<&]UONUV871EM6]M+EQN(@HB7&XB"B)-
M96YO('!R[6QO:'DZ("5S7&XB"B)$X71U;2!P<NUL;VAY.B`E<UQN(@HB7&XB
M"B)+;&EK;FET92!N82!N87-L961U:OIC=2!L:6YK=2!N82!O9'-T<N%N96YI
M92!P<NUL;VAY.EQN(@HB)7,B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HX.0IM<V=I9"`B66]U<B!M97-S86=E('=A<R!S=6-C97-S9G5L;'D@
M9&5L:79E<F5D+B(*;7-G<W1R(")3<'+A=F$@8F]L82#Z<W!EN6YE(&1O<G7H
M96[A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@(EEO
M=7(@<VEG;F%T=7)E.B(*;7-G<W1R(")68;EA('-I9VYA=/IR83HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z-PIM<V=I
M9"`B6TAI9&4@061D<F5S<V5S72(*;7-G<W1R(");4VMR>;L@861R97-Y72(*
M"B,Z(&UE<W-A9V4N<&AP.C(X."!C;VUP;W-E+G!H<#HQ,C@V(&UA:6QB;W@N
M<&AP.C4S-2!L:6(O0V]M<&]S92YP:'`Z.#,X"FUS9VED(");3F\@4W5B:F5C
M=%TB"FUS9W-T<B`B6ZYI861N>2!P<F5D;65T('-P<N%V>5TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z.`IM<V=I9"`B
M6U-H;W<@061D<F5S<V5S("TB"FUS9W-T<B`B6UIO8G)A>FF[(&%D<F5S>2`M
M(@H*(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(EM3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP:65N='-=(@IM<V=S
M='(@(EM:;V)R87IINR!A9')E<WD@+2`E<R!P<NUJ96UC;W9=(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"FUS9VED(")?0F-C(@IM
M<V=S='(@(E]"8V,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*
M;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`BR&EE<FYA(%]L:7-T:6YA(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,34T"FUS9VED(")?
M0V,B"FUS9W-T<B`B7T-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B
M7T1E;&5T92(*;7-G<W1R(")?5GEM87IANR(*"B,Z(&QI8B])35`N<&AP.CDV
M,@IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`B7U!R:67H:6YK>2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C@Q"FUS9VED(")?261E;G1I
M='DB"FUS9W-T<B`B7TED96YT:71A(@H*(SH@;&EB+TE-4"YP:'`Z.3,Q"FUS
M9VED(")?26YB;W@B"FUS9W-T<B`B7U!R:6IA=.D@<W!RX79Y(@H*(SH@;&EB
M+TE-4"YP:'`Z,3`P,PIM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7T]D:&SA
M<VF[(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS9VED(")?365S<V%G92!3;W5R
M8V4B"FUS9W-T<B`B7UID<F]J;W;]('1E>'0@<W!RX79Y(@H*(SH@;&EB+TE-
M4"YP:'`Z.34Y"FUS9VED(")?3F5W($UE<W-A9V4B"FUS9W-T<B`B7TYO=N$@
M<W!RX79A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C,S"FUS9VED(")?4')I;G0B"FUS9W-T<B`B7U1L8>AINR(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHR.#D*;7-G:60@(E]0<FEO<FET>2(*;7-G<W1R
M(")?4')I;W)I=&$B"@HC.B!M86EL8F]X+G!H<#HT,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7U)E9G)E<V@@)7,B"FUS9W-T<B`B7T]B;F]V:;L@)7,B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I
M9"`B7U)E<&QY(@IM<V=S='(@(E]/9'!O=F5D8;LB"@HC.B!L:6(O24U0+G!H
M<#HY-C0*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B7U!R96BU863A=F&[(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(U"FUS9VED(")?4V5N9"!-97-S86=E
M(@IM<V=S='(@(E]0;W-L8;L@<W!RX79U(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHS,@IM<V=I9"`B7U1H<F5A9"(*;7-G
M<W1R(")?5FSA:VYO(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,3$V"FUS9VED(")?5&\B"FUS9W-T<B`B7U!R92(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")?56YD96QE=&4B"FUS
M9W-T<B`B3V)N;U]V:;LB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,3@*;7-G:60@(E]6:65W(%1H<F5A9"(*;7-G<W1R(")?
M6F]B<F%Z:;L@=FSA:VYO(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C$Y"FUS9VED(")?5VAI=&5L:7-T(@IM<V=S='(@(E]":65L82!L:7-T:6YA
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W-0IM<V=I9"`B861D<F5S<V5E('5N
M:VYO=VXB"FUS9W-T<B`B;F5Z;N%M>2!A9')E<^%T(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C0U,0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R(")P<NUL;VAA
M(@H*(SH@=FEE=RYP:'`Z.3<*;7-G:60@(F%T=&%C:&UE;G1S+GII<"(*;7-G
M<W1R(")A='1A8VAM96YT<RYZ:7`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU,#0*;7-G:60@(F)Y=&5S(@IM<V=S='(@(F)A:G1O=B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3D*;7-G:60@(F-A;FYO="!C<F5A=&4@
M;W5T<'5T(&9I;&4B"FUS9W-T<B`B;F5P;V1A<FEL;R!S82!V>71V;W)INR!S
M^F)O<B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S$*;7-G:60@(F-A;FYO="!O
M<&5N(&EN<'5T(@IM<V=S='(@(FYE<&]D87)I;&\@<V$@;W1V;W)INR!V<W1U
M<"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C,*;7-G:60@(F-O;6UA;F0@;&EN
M92!U<V%G92!E<G)O<B(*;7-G<W1R(")C:'EB;ND@<&]UOFET:64@<'+M:V%Z
M;W;I:&\@<FEA9&MU(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q.0IM<V=I9"`B
M8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")C:'EB82!K;VYF:6=U<N%C
M:64B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DU"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(F-H_6)A(&MR:71I8VMY(&3T
M:V6^:73]('-Y<W3I;6]V_2!S^F)O<B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M-C<*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(F-H>6)A(&3A
M=&]VZ6AO(&9O<FWA='4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(S"FUS9VED
M(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B<&]L;[YK82!N96[A:F1E;N$B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I
M9"`B9G)O;2(*;7-G<W1R(")O9"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-SD*
M;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(FYE;GKA;64@;65N
M;R!H;W-T:71EM6$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`S"FUS9VED(")I
M;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B8VAY8F$@=G-T=7!U+W;]<W1U
M<'4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@W"FUS9VED(")I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<B(*;7-G<W1R(")V;OIT;W)NX2!C:'EB82!S;V9T=NER
M=2(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8X"FUS9VED(")K97DB"FUS
M9W-T<B`B:[7ZZ"(*"B,Z(&9O;&1E<G,N<&AP.C$T,0IM<V=I9"`B;6%I;&)O
M>"!F:6QE(@IM<V=S='(@(G/Z8F]R(',@<&^Y=&]U(@H*(SH@8V]M<&]S92YP
M:'`Z,3`Y-R!L:6(O365S<V%G92YP:'`Z-#<V"FUS9VED(")N86UE(@IM<V=S
M='(@(FUE;F\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`BOFEA9&YE(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B;W(B"FUS9W-T<B`B
M86QE8F\B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$U"FUS9VED(")P97)M:7-S
M:6]N(&1E;FEE9"(*;7-G<W1R(")P<NUS='5P('IA;6EE=&YU=/TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z.`IM<V=I
M9"`B<F5C:7!I96YT<UTB"FUS9W-T<B`B<'+M:F5M8V]V72(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HR,3$*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O
M;"(*;7-G<W1R(")V>F1I86QE;N$@8VAY8F$@<')O=&]K;VQU(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$X,PIM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*
M;7-G<W1R(")S;'6^8F$@;F5D;W-T=7!NX2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS
M9W-T<B`B8VAY8F$@<')A=F]P:7-U(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<G,B"FUS9W-T
M<B`B8VAY8GD@<')A=F]P:7-U(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y,0IM
M<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(G-Y<W3I;6]VX2!C:'EB82(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#<*;7-G:60@(G1E;7!O<F%R>2!F86EL
M=7)E(@IM<V=S='(@(F1OZ&%S;N$@8VAY8F$B"@HC.B!L:6(O1FEL=&5R+G!H
M<#HU,0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B5F&Y82#H:65R
M;F$@;&ES=&EN82(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R
M('=H:71E;&ES="(*;7-G<W1R(")68;EA(&)I96QA(&QI<W1I;F$B"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R\N:'1A8V-E<W,`
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,38`,3`T,3<S-C(W-C0`,#$W-#(Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$1E;GD@9G)O;2!A;&P*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O<&\O;'1?3%0N<&\`````````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#$R,C`R`#$P-#$W,S8R
M-S8T`#`Q-S(P-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````C($QI=&AU86YI86X@=')A;G-L871I;VYS(&9O<B!)35`@<&%C
M:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H
M:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E
M(&%S('1H92!)35`@<&%C:V%G92X*(R!$87)I=7,@36%T=6QI875S:V%S(#QD
M87)I=7-`;&YK+FQT/BP@,C`P,BX*(R!6:6QI=7,@4W5M<VMA<R`\=FEL:75S
M0&QN:RYL=#XL(#(P,#,L(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0
M<F]J96-T+4ED+59E<G-I;VXZ($E-4"`T+C`M8W9S7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-"TQ,2TR.2`Q.#HS."LP,C`P7&XB"B),87-T+51R86YS
M;&%T;W(Z(%9I;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@3&ET:'5A;FEA;B`\=FEL:75S0&QN:RYL=#Y<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM,3-<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3@*(RP@9G5Z
M>GD*;7-G:60@(B`@("`@($-C.B`B"FUS9W-T<B`B("`@("`@2V%M.B`B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z-#$U"FUS9VED("(@("`@("!4;SH@(@IM<V=S
M='(@(B`@("`@($MA;3H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P,PIM<V=I
M9"`B("`@($1A=&4Z("(*;7-G<W1R("(@("`@1&%T83H@(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0P-@IM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R("(@("`@
M3G5O.B`B"@HC.B!M86EL8F]X+G!H<#HT,C(@=&5M<&QA=&5S+V9O;&1E<G,O
M:&5A9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E
M<RDB"FUS9W-T<B`B("A->6=T=6MA<R`E<RDB"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z-#$R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(B!496UA.B`B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S`*;7-G:60@(B!I
M;B`B"FUS9W-T<B`B(&5I;'5TZVIE("(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T<B`B(R(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B4N,F9-
M0B`O("4N,F9-0B`@*"4N,F8E)2DB"@HC.B!T:')E860N<&AP.C$U,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T<B`B
M3&%I\&OX(&[K<F$B"@HC.B!M86EL8F]X+G!H<#HQ-S8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("))\'1R:6YT82`E9"!L86GP:V%S*&%I+"#X*2XB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3<X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE
M<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(E9"!L86GP:V%I*/@I
M(&YU<VGX<W1A(&%D;6EN:7-T<F%T;W)I=6D@:V%I<"!N92!N97!A9V5I9&%U
M:F%M:2`H<W!A;2DN(@H*(SH@;&EB+U-P86TN<&AP.C$U.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@
M;F]T('-P86TN(@IM<V=S='(@(B5D(&QA:?!K86DH^"D@<&%S:V5L8G1I(&YE
M(&YE<&%G96ED875J86UA:7,@*'-P86TI+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N
M(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B)60@;&%I\&MA:2CX*2!N=7-I^'-T82!A9&UI;FES=')A
M=&]R:75I(&MA:7`@;F5P86=E:61A=6IA;6D@*'-P86TI+B(*"B,Z(&QI8B]3
M<&%M+G!H<#HQ-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@
M:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(B5D(&QA:?!K
M86DH^"D@<&%S:V5L8G1I(&YE<&%G96ED875J86UA:7,@*'-P86TI+B(*"B,Z
M(&UA:6QB;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!T;R`E
M9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("),86GP:V%I(&YU;R`E9"!I:VD@
M)60@:?`@)60B"@HC.B!M86EL8F]X+G!H<#HV-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L
M9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@:F%U(&5G>FES='5O
M:F$N($K[<_@@:V%T86QO9V%S("5S(&YE<&5R=F%R9&EN=&%S+B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HV-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B
M4&%N8?!U+"!K860@:V%T86QO9V\@)7,@;NMR82XB"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@
M=&AE('-T87)T(&]F('1H92!M;VYT:"XB"FUS9W-T<B`B)7,@:V%T86QO9V%S
M('!E<G9A9&EN86UA<R!MZVYE<VEO('!R863^:6]J92XB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@<')I:6UT87,N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!H87,@8V%N8V5L;&5D("5S+B(*;7-G<W1R("(E<R!N=71R875KZR`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&AA<R!D96-L:6YE9"XB"FUS9W-T<B`B)7,@8F%I
M9^MS:2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DS"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y
M(')E<75E<W0N(@IM<V=S='(@(B5S(&%T<V%KZR#A('7^:6UT=6UO('7^:VQA
M=7/@+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I
M;VX@=&\@)7,N(@IM<V=S='(@(B5S(&%T<V%KZR#A('!A:W9I971I;>`@X2`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@R"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B5S(&%T<VEU;G3K('7^:6UT=6UO(&EN9F]R;6%C
M:6K@+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S('1E;G1A=&EV96QY(&%C8V5P=&5D+B(*
M;7-G<W1R("(E<R!L86EK:6YA:2!P<FEI;71A<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-#@W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E
M<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(E
M<R!P<F'P;R!J^W/X('7^:6UT=6UO(&EN9F]R;6%C:6IO<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3@T"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N(@IM<V=S='(@(B5S
M('!R8?!O(&IU<R!D86QY=F%U=&D@)7,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C0Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(E/K:VUI;F=A:2!P
M<FEDZW1A<R`E<R#A("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N
M9"`E<RXB"FUS9W-T<B`B)7,@;F]R:2!P87!I;&1Y=&D@)7,N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@
M(B5S(&YO<FD@<')A;F7P=&D@2G5M<R!A<&EE(&%R=.MJ86YTX2`E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M
M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B5S(&YO<FD@9V%U=&D@;F%U:F%U
M<VG@(&EN9F]R;6%C:6K@(&%P:64@)7,N(@H*(SH@;65S<V%G92YP:'`Z,C@U
M(&UE<W-A9V4N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B
M"FUS9W-T<B`B)7,Z("5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7W1O<"YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S("@E9"9N
M8G-P.V]F)FYB<W`[)60I(@IM<V=S='(@(B5S.B`E<R`H)60F;F)S<#MI\"9N
M8G-P.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ
M,S,*;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE
M>'0@<V-R965N+BDB"FUS9W-T<B`B*$%T;&EK=&D@\&EU;W,@<&%K96ET:6UU
M<R!I<B!P97)E:71I('!R:64@:VET;R!L86YG;RXI(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL
M(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*
M;7-G<W1R("(H073P875K=&D@=FES=7,@<&%K96ET:6UU<R!I<B!G<N'^=&D@
MX2!R8?!Y;6\@;&%N9^`N*2(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B*$A434PI(@IM<V=S='(@(DA4
M34PB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G
M:60@(BA0;&%I;B!497AT*2(*;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP:'`Z
M,C@P"FUS9VED("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A
M9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@(@HB
M0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P
M;&EE9"XI(@IM<V=S='(@(B(*(BA'<N'^=&D@X2!R8?!Y;6\@;&%N9^`@<&\@
M=FES^"!P86ME:71I;?@@871L:6MI;6\N(%!A:V5I=&EM86D@97-A;6%M92!L
M86YG92`B"B)N96)U<R!A=&QI:W1I+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W
M"FUS9VED("(B"B(H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C
M:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R
M96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB
M*$GP<VGX<W1I(&QA:?!KX"!P;R!V:7/X('!A:V5I=&EM^"!A=&QI:VEM;RX@
M4&%K96ET:6UA:2!E<V%M86UE(&QA;F=E(&YE8G5S("(*(F%T;&EK=&DN*2(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED
M("(J($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@3F]R
MZV1A;6D@<')I9.MTX2!S<&%U<VMI=&4@3TL@*B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS9VED("(J(%!L96%S92!S96QE
M8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(%!A<VER:6YK:71E(&%D<F5S
MX"AU<RD@*B(*"B,Z(&UA:6QB;W@N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B
M,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DQA:?!K87,@
M:?!T<FEN=&%S+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*;7-G:60@(C$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(Q(&QA:?!K87,@;G5S:?AS
M=&%S(&%D;6EN:7-T<F%T;W)I=6D@:V%I<"!N92!N97!A9V5I9&%U:F%M87,@
M*'-P86TI+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C`*;7-G:60@(C$@;65S<V%G
M92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B,2!L
M86GP:V%S('!A<VME;&)T87,@:V%I<"!N92!N97!A9V5I9&%U:F%M87,@*'-P
M86TI+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S(*;7-G:60@(C$@;65S<V%G92!H
M87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(C$@;&%I\&MA<R!N=7-I^'-T87,@861M:6YI
M<W1R871O<FEU:2!K86EP(&YE<&%G96ED875J86UA<R`H<W!A;2DN(@H*(SH@
M;&EB+U-P86TN<&AP.C$U,@IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E
M<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(C$@;&%I\&MA<R!P87-K96QB=&%S
M(&MA:7`@;F5P86=E:61A=6IA;6%S("AS<&%M*2XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#$Y"FUS9VED("(Q,#`@8VAA<F%C=&5R<R(*;7-G<W1R
M("(Q,#`@<VEM8F]L:?@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(R
M"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B,3`P,"!S:6UB;VQI
M^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C`*;7-G:60@(C(U,"!C
M:&%R86-T97)S(@IM<V=S='(@(C(U,"!S:6UB;VQI^"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,C$*;7-G:60@(C4P,"!C:&%R86-T97)S(@IM<V=S
M='(@(C4P,"!S:6UB;VQI^"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA
M;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B
M4')I92#P:6\@;&%I\&MO('!R:6MA8FEN=&%S(&1I9&5L:7,@<&%V96EK<VSK
M;&ES('!A=F%D:6YI;74@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S
M96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O
M;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G<W1R(")!=.MJ;R!P871V:7)T:6YI
M;6%S+"!K860@861R97-A=&%S(&=A=F\@:OMS^"!L86GP:^`N(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4*;7-G:60@(D%.1"(*;7-G<W1R
M("))4B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3`*;7-G:60@
M(D%C8V5P="!R97%U97-T(@IM<V=S='(@(E!R:6EM=&D@=?YK;&%U<^`B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W"B,L(&9U>GIY"FUS9VED
M(")!8V-E<'0@<F5Q=65S="!A;F0@861D(&ET('1O(&UY(&-A;&5N9&%R(@IM
M<V=S='(@(L%V>6MI<R#A<F'P>71A<R#A(&K[<_@@:V%L96YD;W)I^"XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4S"FUS9VED(")!8V-E<'1E
M9"(*;7-G<W1R(")0<FEI;71A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C(U-PHC+"!F=7IZ>0IM<V=I9"`B06-C97!T960Z("(*;7-G<W1R(")0
M<FEI;71A(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*
M;7-G:60@(D%C8V]U;G0G<R!N86UE.B(*;7-G<W1R(")08?!T;R!DZ_YU=.MS
M('!A=F%D:6YI;6%S.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,C`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,`IM<V=I9"`B06-T:6]N
M<R(*;7-G<W1R(")696EK<VUA:2(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP
M.C(P,"!L:6(O34E-12](96%D97)S+G!H<#HR,#$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%D9"`E<R!T;R!M>2!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B4')I9.MT:2#A(&%D<F5S^"!K;GEG96SF("@E<RDB"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*;7-G:60@(D%D9"!S;W5R
M8V4B"FUS9W-T<B`B4')I9.MT:2#P86QT:6[A(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4W-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@X
M"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("+!<F'P
M>71I('1A:2#A(&UA;F\@:V%L96YD;W)I^"(*"B,Z(&-O;7!O<V4N<&AP.C$R
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB(&%S(&%N(&%T
M=&%C:&UE;G0N(@IM<V=S='(@(D9A:6QA<R!<(B5S7"(@<')I:V%B:6YT87,N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`HC+"!F=7IZ>0IM<V=I
M9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W
M:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B"B)O;B!A
M(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(E!A<&EL9&]M;W,@86YT<F'P
M=.MS.B`\:3XH;F5B^W1I;F$L(&MI96MV:65NX"!A;G1R8?!TYB!R8?!Y:VET
M92!N875J;VIE("(*(F5I;'5TZVIE*3PO:3XB"@HC.B!L:6(O34E-12]6:65W
M97(O;F]T:69I8V%T:6]N+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N(@IM<V=S
M='(@(E!A<&EL9&]M;W,@:6YF;W)M86-I:F]S('!E<OYI^W)A("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"FUS9VED(")!
M9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS9W-T<B`B4&%P:6QD
M;VUA(&EN9F]R;6%C:6IA(&1E=&%L:6%U(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.3,*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D971A
M:6QS(@IM<V=S='(@(E!A<&EL9&]M82!L86GP:V\@:6YF;W)M86-I:F$B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R(")087!I;&1O;6]S(&EN9F]R;6%C:6IO<R!P97+^
M:?MR82`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM
M<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T
M<B`B1&5T86QI(&EN9F]R;6%C:6IA(&%P:64@:VQA:63@(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E
M9"`E<RXB"FUS9W-T<B`B4&%P:6QD;VUO<R!I;F9O<FUA8VEJ;W,@87!I92!K
M;&%I9.`@<&5R_FG[<F$@)7,N(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E
M<_@@:VYY9V5LZR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*;7-G
M:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B061R97/X(&MN>6=E;.MS(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC+"!F=7IZ>0IM<V=I9"`B
M(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N
M86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^
M(@IM<V=S='(@(B(*(D)#0R!A9')E<V%I.B`\:3XH;F5B^W1I;F$L(&MI96MV
M:65NX"!A9')E<^`@<F'P>6MI=&4@;F%U:F]J92!E:6QU=.MJ92D\+VD^(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,0HC+"!F=7IZ>0IM<V=I9"`B
M(@HB061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H:7,@:61E;G1I
M='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D<F5S<R!O;B!A
M(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(E!A\'1O(&%D<F5S86D@<W5S
M:6KF('-U(/!I=6\@87!R8?!U.B`\:3XH;F5B^W1I;F$L(&MI96MV:65NX"!A
M9')E<^`@<F'P>6MI=&4@(@HB;F%U:F]J92!E:6QU=.MJ92DB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,C,*;7-G:60@(D%L;"(*;7-G<W1R(")6:7-KX"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*;7-G:60@(B(*(D%L;"!M
M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O
M=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G<W1R("(B"B)6
M:7-I(&QA:?!K86D@<V5K86[H:6%M92AI=6]S92D@:V%T86QO9V4H=6]S92D@
M8G5S('!E<FME;'1I(.$@=FEE;N`@34)/6"`B"B)F86ELX#HB"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('EO=7(@7"(E<UPB(&9O
M;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2`B
M"B)D96QE=&5D+B(*;7-G<W1R(")6:7-I(&QA:?!K86D@:V%T86QO9V4@7"(E
M<UPB(&ER('-E;F5S;FD@;F5I("5S(&1I96[X(&)U<R!I\'1R:6YT:2XB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?871T86-H;65N='-?;6]N
M=&AL>2YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK
M960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B
M92!D96QE=&5D+B(*;7-G<W1R(")6:7-I('-E;F5S;FD@;F5I("5S(&WK;F5S
M:6%I('-U<VEJYB!P<FEK86)I;G1I(&9A:6QA:2!B=7,@:?!T<FEN=&DN(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H
M;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@<V5N="UM
M86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D
M96QE=&5D+B(*;7-G<W1R(")6:7-I('-E;F5S;FD@;F5I("5S(&WK;F5S:6%I
M('-I^'-T^"!L86GP:_@@:V%T86QO9V%I(&)U<R!I\'1R:6YT:2XB"@HC.B!A
M8VPN<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@<FEG
M:'1S(&]N(&9O;&1E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R
M('5S97(@7"(E<UPB+B(*;7-G<W1R(")6:7-O<R!K871A;&]G;R`G)7,G('1E
M:7/K<R!V87)T;W1O:G5I("<E<R<@:?!T<FEN=&]S+B(*"B,Z(&QI8B]A<&DN
M<&AP.C<V"FUS9VED(")!;&QO=R!&;VQD97(@0W)E871I;VX_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B
M06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB
M;W@_(@IM<V=S='(@(DQE:7-T:2!T86EK>71I(&9I;'1R=7,@8F5T(&MU<FEA
M;64@:V%T86QO9V4_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E
M+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E
M8W1I;VXZ(@IM<V=S='(@(DMI=&]S(&1A;'ES.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-S(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X-`IM<V=I
M9"`B06QW87ES(@IM<V=S='(@(E9I<V%D82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-3<*;7-G:60@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(@IM
M<V=S='(@(E9I<V%D82!I\'-A=6=O=&D@<')I:V%B:6YT=7,@9F%I;'5S(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C4P-0IM<V=I9"`B(@HB06X@97)R;W(@;V-C
M=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT
M+B!4:&4@24U!4"!S97)V97(@(@HB<V%I9#H@(@IM<V=S='(@(DML86ED82!B
M86YD86YT(&GP=&EN=&D@<')I:V%B:6YTX"!F86ELX"X@24U!4"!S97)V97)I
M;R!K;&%I9&$Z(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X.`HC+"!F=7IZ>0IM
M<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG
M('1H92!N97<@;F]T92XB"FUS9W-T<B`B4')I9&5D86YT(&YA=6K@(&1A<F+@
M(.%V>6MO(&ML86ED82XB"@HC.B!L:6(O365S<V%G92YP:'`Z,S@W"FUS9VED
M(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE
M(&YE=R!T87-K+B(*;7-G<W1R(")0<FED961A;G0@;F%U:N`@9&%R8N`@X79Y
M:V\@:VQA:61A+B(*"B,Z(&UE<W-A9V4N<&AP.C4P,"!M86EL8F]X+G!H<#HW
M,30@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHY"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3@@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E
M;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(D%T<V%K>71I(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B06YS=V5R
M960@;65S<V%G97,B"FUS9W-T<B`B071S86MY=&D@;&%I\&MA:2(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B
M07!P;'D@1FEL=&5R<R(*;7-G<W1R(")086YA=61O=&D@9FEL=')U<R!K871A
M;&]G=6DB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B
M"FUS9W-T<B`B4&%N875D;W1I(&9I;'1R=7,@:V%T86QO9W5I(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS9VED(")!<'!L>2!F:6QT
M97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")!<B!F:6QT<G5O
M=&D@;&%I\&MU<R!P<FES:6IU;F=I;6\@;65T=3\B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z-#(*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE
M<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_(@IM<V=S='(@(D%R(&9I
M;'1R=6]T:2!L86GP:W5S(&MI96MV:65NX"!K87)TX"!K86D@<&%R;V1O;6%S
M($E.0D]8/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\B"FUS9W-T<B`B07(@
M=&EK<F%I(&YO<FET92!I\'1R:6YT:2#PX2!V:67PX&KA(')A:W3@/R(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D
M(2DB"FUS9W-T<B`B07(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2!S879O(')A
M:W3X('!O<N`_("A.15)%2T]-14Y$54]*04U!(2DB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FIS.C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T
M:&ES/R(*;7-G<W1R(")!<B!T:6MR86D@;F]R:71E('1A:2!P861A<GET:3\B
M"@HC.B!M97-S86=E+G!H<#HT,#<@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!0
M15)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(D%R
M('1I:W)A:2!N;W)I=&4@2=!44DE.5$D@\&EU;W,@;&%I\&MU<S\B"@HC.B!L
M:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N
M=#\B"FUS9W-T<B`B07(@=&EK<F%I(&YO<FET92!)T%1224Y422!P<FEK86)I
M;G3@(&9A:6S@/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C,Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI
M<R!F;VQD97(_(@IM<V=S='(@(D%R('1I:W)A:2!N;W)I=&4@:?!V86QY=&D@
M\.$@:V%T86QO9^`_(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M
M(&9O;&1E<C\B"FUS9W-T<B`B07(@=&EK<F%I(&YO<FET92!I\'9A;'ET:2#P
M:75K\&QI863K_N8_(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_
M(@IM<V=S='(@(D%R('1I:W)A:2!N;W)I=&4@:?!V86QY=&D@\&EU:_!L:6%D
MZ_[F/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE
M=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(D%R('1I:W)A:2!N;W)I=&4@
M2=!44DE.5$D@\&EU;W,@;&%I\&MU<S\B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]J879A<V-R:7!T+FEN8SHX,"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R
M:7!T+FEN8SHW.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E
M<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_(@IM<V=S='(@(D%R('1I
M:W)A:2!N;W)I=&4@<&%S:V5L8G1I(/#A(&QA:?!KX"!K86EP(&YE(&YE<&%G
M96ED875J86W@/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N
M:6YC.C<U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S
M<V%G92!A<R!S<&%M/R(*;7-G<W1R(")!<B!T:6MR86D@;F]R:71E('!A<VME
M;&)T:2#PX2!L86GP:^`@:V%I<"!N97!A9V5I9&%U:F%MX#\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3$V"FUS9VED(")!<G)I=F%L(%1I;64B"FUS
M9W-T<B`B1V%U=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS
M9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B1&EDZVII;6\@='9A<FMA(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B2VQA=7-T:2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q.0IM<V=I9"`B071T86-H(@IM
M<V=S='(@(E!R:6MA8FEN=&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT-S4*;7-G:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R(")0<FEK
M86)I;G1I(&9A:6QU<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0U-@IM<V=I9"`B071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L
M:6,@:V5Y('1O('EO=7(@;65S<V%G93\B"FUS9W-T<B`B07(@<')I:V%B:6YT
M:2!J^W/X('9I9?#@:N$@4$=0(')A:W3@('!R:64@;&%I\&MO/R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#D*;7-G:60@(D%T=&%C:&5D($9I
M;&4Z(@IM<V=S='(@(E!R:6MA8FEN=&$Z(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0U,2!L:6(O0V]M<&]S92YP:'`Z-3,V"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE
M;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R(")&
M86EL87,@7"(E<UPB('9I<O!Y:F\@;&5I<W1I;N`@9'EDX2X@1F%I;&%S($Y%
M4%))2T%"24Y405,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,W
M-@IM<V=I9"`B071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E
M<75E<W0@>6]U('-E;G0N(@IM<V=S='(@(E!R:6MA8FEN=&%S(&9A:6QA<R!Y
M<F$@871S86MY;6%S(.$@:OMS^"!I0V%L96YD87(@=?YK;&%U<^`N(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-3`V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FIS.CDW"FUS9VED(")!='1A8VAM96YT(@IM<V=S='(@(D9A:6QA<R(*"B,Z
M(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP.C0V-@IM<V=I9"`B
M071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N="!T>7!E
M(@IM<V=S='(@(E!R:6MA8FEN=&%S(&9A:6QA<R!I\'1R:6YT87,Z(&9A:6QO
M('1I<&%S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W,PHC.B!L:6(O0V]M
M<&]S92YP:'`Z,3`W,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`B4')I
M:V%B:6YT:2!F86EL86DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C@R"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B4W5S:6KF(/YM;V[K<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"FUS9VED
M(")!='1E;G1I;VXB"FUS9W-T<B`B1.MM97-I;R(*"B,Z(&QI8B]!=71H+VEM
M<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UP.B!N97)A<W1A<R!R
M96EK86QI;F=A<R!)34%0(&UO9'5L:7,N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8T,`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W(&EM86=E
M<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2`B
M"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@HB075T;VUA=&GP:V%I(')O9'ET
M:2!P879E:6MS;.ML:75S($A434P@;&%I\&MU;W-E+"!J96EG=2!S:75N=.MJ
M87,@>7)A(&UA;F\@(@HB861R97/X(&MN>6=E;.MJ93\B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3@*;7-G:60@(D%V86EL86)L
M92!!9&1R97-S(&)O;VMS.B(*;7-G<W1R(")'86QI;6]S(&%D<F5S^"!K;GEG
M96SK<SHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S$Y"FUS9VED
M(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R("),875K:6%M82!A='-A:WEM
M;R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`B
M1W+A_E]T:2#A("5S(@H*(SH@=&AR96%D+G!H<#HQ,S<@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")"86-K('1O("5S(@IM<V=S='(@(D=RX?YT:2#A("5S(@H*(SH@=&AR
M96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6
M:65W($EN9&5X(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,R"FUS9VED
M(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!O
M<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M
M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G
M<W1R(")"8V,B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*
M;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN
M9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(D1E=&%L=7,@;&%I\&MO('1E
M:W-T87,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@
M(D)L86-K;&ES="(*;7-G<W1R(")";&]K=6]T:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV,CD*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(5$U,(&UE
M<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D
M/R(*;7-G<W1R("(B"B)";&]K=6]T:2!P879E:6MS;.ML:75S($A434P@;&%I
M\&MU;W-E+"!N96)E;G0@8G5V;R!P87)E:6MA;&%U=&$@:VET86EP/R(*"B,Z
M(&QI8B]396%R8V@N<&AP.C0R"FUS9VED(")";V1Y(@IM<V=S='(@(DQA:?!K
M;R!T=7)I;GES(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM
M<V=I9"`B0F]T:"(*;7-G<W1R(")!8G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C@W"FUS9VED(")";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y
M(&]F($UE<W-A9V4B"FUS9W-T<B`B27(@86YT<F'P=.MS(&ER(&QA:?!K;R!T
M96MS=&%S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R
M"FUS9VED(")#7VAA<G-E="(*;7-G<W1R(")+7V]D=6]TZR(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS
M9W-T<B`B2V%L96YD;W)I=7,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I
M;"!S97)V97(N(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@
M;G5T;VQU<VEO('!A\'1O('-E<G9E<FEO+B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E
M;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N
M9W1I('!R:64@;G5T;VQU<VEO('!A\'1O('-E<G9E<FEO.B`B"@HC.B!L:6(O
M34E-12]6:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P
M87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@(@HB;6%I;&)O
M>"XB"FUS9W-T<B`B(@HB3F5P879Y:V\@<&%R;V1Y=&D@\&EO(&QA:?!K;R`M
M(/!I;VIE(&3K_G5TZVIE(')A<W1A('1I:R`E<R!D86QI<R!I\"`E<RXB"@HC
M.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T
M96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M<&QA
M=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM92]I
M;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(DYU=')A=6MT:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S
M-0HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED
M(")#86YC96P@365S<V%G92(*;7-G<W1R(")!='-I<V%K>71I(&QA:?!K;R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES
M(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT
M<RXB"FUS9W-T<B`B071S:7-A:WED86UI(&QA:?!K;R!J^W,@<')A<F%S:71E
M('9I<^`@:F\@='5R:6[A+B(*"B,Z(&UE<W-A9V4N<&AP.C(V-2!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC.B!T96UP;&%T97,O8V]M
M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI8B]396%R8V@N<&AP.C,P"FUS9VED
M(")#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z.3,*;7-G:60@(B(*(D-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A
M:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*
M(G-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<P,0IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(E9A9&]V87,B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#`*;7-G:60@
M(D-H86YG92(*;7-G<W1R(")086ME:7-T:2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R
M(")086ME:7-T:2!V:7-U<R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY
M,@IM<V=I9"`B0VAA;F=E($9O;&1E<B(*;7-G<W1R(")086ME:7-T:2!K871A
M;&]GX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3(*;7-G:60@(B(*
M(D-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S
M86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S
M(&%R92!S;W)T960N(@IM<V=S='(@(B(*(E9A:7ID879I;6\L('1O:VGX(&MA
M:7`L(&MI96L@;&%I\&OX(')O9'ET:2!V:65N86UE(&QA;F=E(&ER(&MA:7`@
M;&%I\&MA:2`B"B)T=7)I(&+[=&D@<W5R^_!I=6]T:2P@;G5S=&%T>6UA:2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*;7-G:60@(D-H86YG92!M
M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+B(*;7-G<W1R(")08?!T
M;R!S97)V97)I;R!I<B!K871A;&]G^"!N=7-T871Y;6%I+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE
M+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N
M('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T
M<B`B(@HB5F%R9&\L(&%D<F5S;R!I<B!P87)A\&\L(&MU<FEU;W,@;6%T>7,@
M_FUO;NMS+"!S:V%I=&%N='ES(&ER(&%T<V%K:6[K:F%N='ES("(*(N$@2OMS
M^"!L86GP:W5S(&YU<W1A='EM86DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@R-`IM<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R
M(")2;V1Y=&DZ(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,34*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T
M<B`B5&EK<FEN=&D@87(@>7)A(&YA=6KX(&QA:?!K^"(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM
M<V=S='(@(E!A7_YY;>MT:2!V:7-U<R]N:65K;R(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K(&%L;"!M86EL('-E<G9E
M<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.B(*;7-G<W1R(")087-I
M<FEN:VET92!S97)V97)I=7,@:?`@:W5R:?@@;F]R:71E('!A:6UT:2!L86GP
M:W5S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*;7-G:60@(D-H
M96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T
M<B`B5&EK<FEN=&D@:VQA:61A<R!P<FEE\"!I\'-I=6[H:6%N="!L86GP:^`_
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I9"`B
M0VAO;W-E($%C=&EO;CHB"FUS9W-T<B`B4&%S:7)I;FMI=&4@=F5I:W-MX#HB
M"@HC.B!C;VYF:6<O<V5R=F5R<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-H;V]S
M92!A(&UA:6P@<V5R=F5R.B(*;7-G<W1R(")087-I<FEN:VET92!P8?!T;R!S
M97)V97+A.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R
M-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C$W"B,L(&9U>GIY"FUS9VED(")#
M:&]O<V4@82!M871C:"!O<B!E9&ET('1H92!A9&1R97-S('1O('1H92!R:6=H
M=#HB"FUS9W-T<B`B4&%S:7)I;FMI=&4@87)B82!R961A9W5O:VET92!L875K
MX"!D9?!I;NMJ93HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(Q
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*;7-G:60@(D-H;V]S92!A
M;B!A8W1I;VXZ(@IM<V=S='(@(E!A<VER:6YK:71E('9E:6MS;>`Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"FUS9VED(")#
M:&]O<V4@=&AE(&%D9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D
M<F5S<V5S+B(*;7-G<W1R(")087-I<FEN:VET92!A9')E<_@@:VYY9V5LYBP@
M:W5R:>`@;F%U9&]S:71E('!R:63K9&%M:2!A9')E<W5S+B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PIM<V=I9"`B0VAO;W-E
M('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X
M<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(E!A<VER:6YK:71E(&%D<F5S
M^"!K;GEG96QI^"!T=F%R:^`L(&YA=61O:F%MX"!A9')E<_@@<&%T:6MR:6YI
M;75I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!C;VYV97)T('1H92!I;6%G
M92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B<F]W<V5R(&-A;B!V:65W+B(*
M;7-G<W1R("(B"B).;W+K9&%M:2!P86ME:7-T:2!P879E:6MS;.MLX2#A(&9O
M<FUA=.`L(&MU<N$@<W5P<F%N=&$@:OMS^"!N87+P>6MLZRP@(@HB<W!A=7-K
M:71E("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I
M;6%G92XB"FUS9W-T<B`B3F]RZV1A;6D@871S:?AS=&D@<&%V96EK<VSK;.$L
M('-P875S:VET92`E<RXB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N
M="!P86=E+B(*;7-G<W1R(")3<&%U<VMI=&4@)7,L(&YO<NMD86UI('!A=&5K
M=&D@X2`E<R!V86QD>6UO('!U<VQA<.$N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS
M9W-T<B`B3F]RZV1A;6D@<&%M871Y=&D@2%1-3"!T=7)I;N$@871S:VER86UE
M(&QA;F=E+"!S<&%U<VMI=&4@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B3F]R
MZV1A;6D@<&%M871Y=&D@;6'^97-NX2!P879E:6MS;.MLX2P@<W!A=7-K:71E
M("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H92!A
M='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(").;W+K
M9&%M:2!P86UA='ET:2!(5$U,('1U<FENX2!A='-K:7)A;64@;&%N9V4L('-P
M875S:VET92`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z
M-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I
M97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@
M=VEN9&]W+B(*;7-G<W1R(").;W+K9&%M:2!P86UA='ET:2!(5$U,('1U<FEN
MX2!A='-K:7)A;64@;&%N9V4L('-P875S:VET92`E<RXB"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/
M5R!T:&4@26UA9V5S(@IM<V=S='(@(E!!4D]$651)('!A=F5I:W-LZVQI=7,B
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*;7-G
M:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@
M8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H
M+B(*;7-G<W1R("(B"B)096QE('!A_GEMZVMI=&4@=FEE;N`@:?`@2OMS^"!A
M9')E<_@@:VYY9V5L:?@L(&\@<&\@=&\@<&%S:7)I;FMI=&4@;&%U:W5S("(*
M(G!A:67P:V%I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,0IM
M<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D
M9')E<W,@8F]O:R(*;7-G<W1R(")3<&%U<VMI=&4@Z&EA(&IE:2!N;W)I=&4@
M:?!S875G;W1I(%!'4"!V:67PX&KA(')A:W3@(&%D<F5S^"!K;GEG96SK:F4B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(P,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF
M:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O;VLB"FUS9W-T<B`B4W!A
M=7-K:71E(.AI82!J96D@;F]R:71E(&GP<V%U9V]T:2!3+TU)344@<V5R=&EF
M:6MA=.`@861R97/X(&MN>6=E;.MJ92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-3`*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@
M8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B"FUS9W-T<B`B
M4&%S<&%U9.8@86YT(&%D<F5S;RP@<W5K=7)S:71E(&YA=6K@(&QA:?!KX"!A
M9')E<V%T=6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED
M(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A
M9V4@=&\@8F4@<F5A9"(*;7-G<W1R(")087-P875DYB!A;G0@861R97-O+"!A
M=&ED87)Y<VET92!L86GP:^`@<VMA:71Y;75I(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]F971C:&UA:6PN:6YC.C(X"FUS9VED(")#;&]S92(*;7-G<W1R
M(")5_F1A<GET:2(*"B,Z(&-O;7!O<V4N<&AP.C@R."!C;VUP;W-E+G!H<#HQ
M,30X"FUS9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R(")5_F1A<GET
M:2#PX2!L86YGX"(*"B,Z(&9O;&1E<G,N<&AP.C0R.0IM<V=I9"`B0VQO<V5D
M($9O;&1E<B(*;7-G<W1R(")5_F1A<GET87,@:V%T86QO9V%S(@H*(SH@9F]L
M9&5R<RYP:'`Z-#0Y"FUS9VED(")#;VQL87!S92(*;7-G<W1R(")3=7-K;&5I
M<W1I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G
M:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R(")3=7-K;&5I<W1I('9I<VO@(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O
M;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S='(@(E-U<VML96ES=&D@=FES=7,@
M:V%T86QO9W5S(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS9VED(")#;VQL87!S
M92!&;VQD97(B"FUS9W-T<B`B4W5S:VQE:7-T:2!K871A;&]GX"(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@
M26YD:6-A=&]R.B`B"FUS9W-T<B`B4W!A;'9O<R!I;F1I:V%T;W)I=7,Z("(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*;7-G:60@(D-O;6UE;G0B
M"FUS9W-T<B`B2V]M96YT87)A<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-CD*;7-G:60@(D-O;7!L971E9"(*;7-G<W1R(")!=&QI:W1A(@H*
M(SH@8V]M<&]S92YP:'`Z.#(W(&-O;7!O<V4N<&AP.C$Q-#<*;7-G:60@(D-O
M;7!O<V4@86YO=&AE<B!M97-S86=E(@IM<V=S='(@(E)A\'ET:2!D87(@=FEE
M;N`@;&%I\&O@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-`IM<V=I
M9"`B0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS
M9W-T<B`B4F'P>71I(&QA:?!K=7,@871S:VER86UE(&QA;F=E/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S
M<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R
M('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B4F'P>71I(&QA
M:?!K=7,@2%1-3"!F;W)M871U("AJ96EG=2!N87+P>6MLZR!P86QA:6MO(/!I
MX"!F=6YK8VEJX"D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS
M9VED(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM
M<V=S='(@(DQA:?!K^"!R;V1Y;6\@;G5S=&%T>6UA:2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D-O;F9I9W5R92!M86EL('!R979I
M97<@;W!T:6]N<RXB"FUS9W-T<B`B2?!A;FMS=&ENZW,@;&%I\&OX('!E<OYI
M^W)O<R!N=7-T871Y;6%I+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S<P
M"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&1R;W!P960@8GD@24U!4"!S
M97)V97(N(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@<V5R
M=F5R:6\B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B
M0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S='(@(DYE<&%V>6MO
M('!R:7-I:G5N9W1I('!R:64@<V5R=F5R:6\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4$=0
M('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(E<R!01U`@<&%L86EK>6UO('9A
M;&1Y;6%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N
M(@IM<V=S='(@(B5S(%,O34E-12!P86QA:6MY;6\@=F%L9'EM87,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM<V=I9"`B0V]N=')O;"!O<'1I
M;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED("(B"B)#;VYT
M<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C:&5C:V5D(&9O<BP@86YD('=H
M971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@(@HB=VAE;B!I="!A<G)I=F5S
M+B(*;7-G<W1R(").875J;R!P8?!T;R!T:6MR:6YI;6\@:7(@<')A;F7P:6WX
M(&%P:64@=&%I(&YU<W1A='EM86DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8Y-@IM<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O
M(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R(")+;VYV97)T=6]T:2!T96MS=&EN
M97,@\'EP<V5NZVQE<R#A(&=R869I;F5S/R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHU,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")+;W!I:G5O=&DB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'D@
M=&\@9F]L9&5R(@IM<V=S='(@(DMO<&EJ=6]T:2#A(&MA=&%L;V?@(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R
M96-T(@IM<V=S='(@(E1A:7-Y=&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z,30P"FUS9VED(")#;W)R96-T960@5&5X="(*;7-G<W1R
M(")486ES>71A<R!T96MS=&%S(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS
M.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VUP
M;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S(@IM<V=S='(@(DYE<&%V
M>6MO('-U:W5R=&D@5D93('!O<VES=&5MZW,Z("5S(@H*(SH@871T86-H;65N
M="YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T
M92!T:&4@5D93(&)A8VME;F0Z("5S(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R
M=&D@5D93('!O<VES=&5MZW,Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&UE<W-A
M9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B3F5P
M879Y:V\@:?!T<FEN=&D@;&%I\&OX(&GP("5S+B!397)V97)I;R!K;&%I9&$Z
M("5S(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C,Q.`IM<V=I9"`B0V]U;&0@;F]T
M(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`B3F5P
M879Y:V\@871L:6MT:2!P<F]F:6QA:W1I:V]S('9E:6MS;?@N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W1N968N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@97AT
M<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A
M8VAM96YT+B(*;7-G<W1R(").97!A=GEK;R!I\&%R8VAY=G5O=&D@;G5R;V1Y
M=&\@9F%I;&\@:?`@35,M5$Y%1B!F;W)M871O+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@
M<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@
M(DYE<&%V>6MO(&GP87)C:'EV=6]T:2!::7`@87)C:'EV;RXB"@HC.B!L:6(O
M4V5S<VEO;BYP:'`Z,C<S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M
M97-P86-E(&EN9F]R;6%T:6]N(&9R;VT@24U!4"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z('-E87)C:"YP:'`Z,S$T('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHV-R!T96UP;&%T97,O86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$V,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(E-U
M:W5R=&DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHV"FUS
M9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@(E-U:W5R=&D@:V%T86QO9^`B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED(")#<F5A=&4@
M2V5Y<R(*;7-G<W1R(")3=6MU<G1I(')A:W1U<R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:&5A9&5R+FEN8SHQ-`IM<V=I9"`B0W)E871E(%9I<G1U86P@1F]L
M9&5R(@IM<V=S='(@(E-U:W5R=&D@=FER='5A;/@@:V%T86QO9^`B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E(&$@3F5W($%C8V]U;G0B"FUS9W-T<B`B2VET
M;W,@<&'P=&\@9.O^=73K<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L
M96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*
M(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G
M<W1R(")3=6MU<G1I(&YA=6K@(/!I=6OP;&EA9.O^YB(*"B,Z('1E;7!L871E
M<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F
M;VQD97)S96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S
M(&9O;&1E<B(*;7-G<W1R(")3=6MU<G1I(&YA=6K@('!A<G5O\&EN:?@@:V%T
M86QO9^`B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC
M.C(V('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#(*;7-G
M:60@(D-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(E-U
M:W5R=&D@;F%U:N`@<VGX<W3X(&QA:?!K^"!K871A;&]GX"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S
M+W1R87-H<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H
M(&9O;&1E<B(*;7-G<W1R(")3=6MU<G1I(&YA=6K@(/!I=6OP;&EA9.O^YB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C@*;7-G:60@(B(*(D-R96%T
M92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M
M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@(@HB86YD(&1E;&5T92!S<&%M
M+B(*;7-G<W1R("(B"B)&:6QT<F%V:6UO('1A:7-Y:VQI^"!S=6MU<FEM87,L
M(&%T96EN86[H:6\@<&'P=&\@='9A<FMY;6%S+"!I\'+[\&EU;VIA;G0@:N$@
M(@HBX2!K871A;&]G=7,@:7(@:?!T<FEN86YT(&YE<&%G96ED875J86UU<RXB
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*(RP@9G5Z
M>GD*;7-G:60@(D-R96%T92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R(")3=6MU
M<G1I(&YA=6K@('-I^'-T^"!L86GP:_@@:V%T86QO9^`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A
M;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C
M8V5S<R!T;R`E<R(*;7-G<W1R(")$86)A<G1I;NMS('1E:7/K<R#A("5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I9"`B0W5S=&]M:7IE
M(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N
M=',N(@IM<V=S='(@(DQA:?!K^"!P8>MM:6UO(&GP(&MI=/@@<&'P=&\@9.O^
M=>AI^"!N=7-T871Y;6%I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,0IM<V=I9"`B0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R
M(")3:75NZ&EA;?@@;&%I\&OX(&YU<W1A='EM86DN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B5F5I
M:W-M^"P@871L:65K86WX('!R:7-I:G5N9W5S('!R:64@)7,L(&YU<W1A='EM
M86DN(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHQ-PIM<V=I9"`B1&%T7V4B"FUS9W-T<B`B1%]A=&$B"@HC.B!M97-S86=E
M+G!H<#HR-C(@=&AR96%D+G!H<#HQ-#@*;7-G:60@(D1A=&4B"FUS9W-T<B`B
M1&%T82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3<*;7-G:60@
M(D1E8VQI;F5D(@IM<V=S='(@(D%T;65S=&%S(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C(V,PHC+"!F=7IZ>0IM<V=I9"`B1&5C;&EN960Z("(*
M;7-G<W1R(")!=&UE<W1A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B2?!T<FEN=&DB
M"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z
M,3@*;7-G:60@(D1E9F%U;'0@4V5A<F-H($9I96QD(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C,*;7-G:60@(D1E9F%U;'0@<V]R
M=&EN9R!C<FET97)I83HB"FUS9W-T<B`B4OOP:75O=&D@<&%G86PZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,PIM<V=I9"`B1&5F875L="!S;W)T
M:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B4OOP:6%V:6UO(&MR>7!T:7,Z(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V-0IM<V=I9"`B1&5L96=A
M=&5D(@IM<V=S='(@(D%T<W1O=F%U:F%M87,B"@HC.B!F;VQD97)S+G!H<#HT
M,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B2?!T<FEN=&DB"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,@4'5B
M;&EC($ME>2(*;7-G<W1R("))\'1R:6YT:2`E<R!V:67PX&KA(')A:W3@(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME>7,B"FUS9W-T
M<B`B2?!T<FEN=&D@9&%B87)T:6YI=7,@<F%K='5S(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS
M*2(*;7-G<W1R("))\'1R:6YT:2!K871A;&]GX"AU<RDB"@HC.B!F;VQD97)S
M+G!H<#HR.#4*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!396QE8W1E9"!&;VQD
M97)S(@IM<V=S='(@(DGP=')I;G1I(&MA=&%L;V?@*'5S*2(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E(%-T871I;VYE<GDB"FUS9W-T<B`B2?!T<FEN=&D@=FER='5A;/@@
M:V%T86QO9^`B"@HC.B!F;VQD97)S+G!H<#HT,3D*;7-G:60@(D1E;&5T92!6
M:7)T=6%L($9O;&1E<B(*;7-G<W1R("))\'1R:6YT:2!V:7)T=6%L^"!K871A
M;&]GX"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM
M<V=I9"`B1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R
M=F5R/R(*;7-G<W1R("))\'1R:6YT:2!P86EM='5S(&QA:?!K=7,@:?`@;G5T
M;VQU<VEO('-E<G9E<FEO/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@
M(DGP=')I;G1I(&GP(&UA;F\@:V%L96YD;W)I875S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B1&5L971E(&]L9"!L:6YK960@871T
M86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R("))\'1R
M:6YT:2!S96YU<R!S=7-I:G5S:75S('!R:6MA8FEN='5S(&9A:6QU<R!MZVYE
M<VEO('!R863^:6]J93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4P
M"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN
M;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B2?!T<FEN=&D@<V5N=7,@<VGX<W3X
M(&QA:?!K^"!K871A;&]G=7,@;>MN97-I;R!P<F%D_FEO:F4_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M('-P86T@;65S<V%G97,B"FUS9W-T<B`B2?!T<FEN=&D@;&%I\&MA:2(*"B,Z
M(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I
M9"`B1&5L971E9"(*;7-G<W1R("))\'1R:6YT:2(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS
M9W-T<B`B2?!T<FEN=&D@;&%I\&MA:2(*"B,Z(&-O;7!O<V4N<&AP.C,P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB
M)7-<(BXB"FUS9W-T<B`B1F%I;&%S(%PB)7-<(B!I\'1R:6YT87,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@
M36]V:6YG($UE<W-A9V5S(@IM<V=S='(@(DQA:?!K^"!T<GEN:6UA<R!I<B!P
M97)KZVQI;6%S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,@IM
M<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(E7^9')A=7-T:2!U_FML875S
MX"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#`*;7-G:60@(D1E
M;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S='(@
M(E7^9')A=7-T:2!U_FML875SX"!DZVP@=?YI;71U;6\@:6YF;W)M86-I:F]S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,@IM<V=I9"`B1&5S8V5N
M9&EN9R(*;7-G<W1R(")-8?[K:FEM;R!T=F%R:V$B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8V.0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B07!R8?!Y
M;6%S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<W"FUS9VED(")$971A:6QS(@IM<V=S='(@(E-M=6QK:6%U(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W-PIM<V=I9"`B1&EM('-I9VYA
M='5R97,_(@IM<V=S='(@(D)L=6MI;G1I('!A<F'P=7,_(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S8*;7-G:60@(D1I<W!L87DB
M"FUS9W-T<B`B4F]D>71I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W
M.0IM<V=I9"`B1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A
M(&UE<W-A9V4_(@IM<V=S='(@(E)O9'ET:2!I\'-I^'-T;R!L86GP:V\@<&%T
M=FER=&EN:6W@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#8*;7-G
M:60@(D1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(E)O9'ET
M:2!L86GP:V\@=&5K<W1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y
M,@IM<V=I9"`B1&ES<&QA>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M
M86EL/R(*;7-G<W1R(")2;V1Y=&D@:?#P;VMA;G3A('!R86YE\&EMX"!A<&EE
M(&=A=73@(&YA=6K@(&QA:?!KX#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S4X"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%-P
M86U<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R(")2;V1Y=&D@)TGP
M=F%L>71I(/!I=6OP;&EA9.O^YB<@;7EG='5KX"!M96YI=3\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S4P"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y
M('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS
M9W-T<B`B4F]D>71I("=)\'9A;'ET:2#P:75K\&QI863K_N8G(&UY9W1U:^`@
M;65N:74_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC
M.C$Q"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R("))\'-I9.MS='EM87,B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O
M($Y/5"!M871C:"(*;7-G<W1R(").14%4251)3DM!(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#:&5C:R!&
M;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(DYE=&EK<FEN=&D@;F%U
M:O@@;&%I\&OX(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,@IM<V=I
M9"`B1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN
M(@IM<V=S='(@(DYE9V5N97)U;W1I(&YU;W)O9&]S(&QA=6ME;'EJ92!.=6\Z
M(@H*(SH@;&EB+TE-4"YP:'`Z,3`W-0IM<V=I9"`B1&\@>6]U('=A;G0@=&\@
M;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`B07(@;F]R:71E(&%T:61A<GET
M:2#PX2!K871A;&]GX#\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(S,@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,3(V"FUS9VED(")$;VYE(@IM<V=S='(@(D%T;&EK=&$B"@HC.B!L:6(O34E-
M12]#;VYT96YT<RYP:'`Z,3DR"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL
M;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(D%T<VES:?AS=&D@)7,@
M+GII<"!F;W)M871U(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-3(*;7-G:60@(D1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII
M<"!F:6QE*2(*;7-G<W1R(")!='-I<VGX<W1I('9I<W5S('!R:6MA8FEN='5S
M(&9A:6QU<R`H+GII<"!F86EL92DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR,`IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S
M='(@(D%T<VES:?AS=&D@:V%T86QO9^`H=7,I(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS
M*2!;+GII<"!F;W)M871=(@IM<V=S='(@(D%T<VES:?AS=&D@:V%T86QO9^`H
M=7,I(%LN>FEP(&9O<FUA=&%S72(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H
M<#HQ.3(*;7-G:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@
M(D%T<VES:?AS=&D@+GII<"!F;W)M871U(@H*(SH@;65S<V%G92YP:'`Z-3`Q
M(&UA:6QB;W@N<&AP.C<Q.2!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S='(@
M(E!A<G5O\&EN:6%I(@H*(SH@9F]L9&5R<RYP:'`Z,SDR"FUS9VED(")$<F%F
M="!F;VQD97(B"FUS9W-T<B`B4&%R=6_P:6YI^"!K871A;&]G87,B"@HC.B!T
M96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I9"`B1')A
M9G1S(&9O;&1E<CHB"FUS9W-T<B`B4&%R=6_P:6YI^"!K871A;&]G87,Z(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I9"`B12UM86EL($%D
M9')E<W,B"FUS9W-T<B`B16PN('!A\'1O(&%D<F5S87,B"@HC.B!L:6(O36%I
M;&)O>"YP:'`Z,S`Y"B,L(&9U>GIY"FUS9VED(")%3D0B"FUS9W-T<B`B25(B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-`IM<V=I9"`B15)2
M3U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D+B(*;7-G
M<W1R(")+3$%)1$$Z($K[<_@@;&%I\&MA<R!N97!A<VEE:^L@861R97-A=&\N
M(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHQ.0IM<V=I9"`B161I="(*;7-G<W1R(")2961A9W5O=&DB"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D:70@
M0FQA8VML:7-T(@IM<V=S='(@(E)E9&%G=6]T:2!J=6]DX&KA('/@<F'PX"(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM<V=I9"`B161I
M="!&:6QT97)S(@IM<V=S='(@(E)E9&%G=6]T:2!F:6QT<G5S(@H*(SH@9F]L
M9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-@IM
M<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")2961A9W5O=&D@
M=FER='5A;/@@:V%T86QO9^`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&
M;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B4F5D86=U;W1I("5S
M('9I<G1U86QA=7,@:V%T86QO9V\@87!R8?!Y;>`B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM
M<V=S='(@(E)E9&%G=6]T:2!B86QTX&KA('/@<F'PX"(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!Y;W5R(&)L86-K
M;&ES="(*;7-G<W1R(")2961A9W5O=&D@:G5O9.!JX2!SX')A\.`B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U
M<B!F:6QT97(@<G5L97,B"FUS9W-T<B`B4F5D86=U;W1I(&9I;'1R879I;6\@
M=&%I<WEK;&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V,0IM<V=I
M9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@
M;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B4F5D86=U;W1I(&MI=/@@96PN('!A
M\'1O(&3K_G7H:?@@;G5S=&%T>6UU<RXB"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS
M9W-T<B`B4F5D86=U;W1I(&)A;'3@:N$@<^!R8?#@(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,SD*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`B16PN('!A\'1O(&%D<F5S87,B"@HC.B!L:6(O365S<V%G
M92YP:'`Z-C4W"B,L('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE
M<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(DMA=&%L;V=A<R`E<R!I\'9A;'ET
M87,N(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C(*;7-G
M:60@(D5M<'1Y($9O;&1E<BAS*2(*;7-G<W1R("))\'9A;'ET:2!K871A;&]G
MX"AU<RDB"@HC.B!F;VQD97)S+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@(D5M
M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B2?!V86QY=&D@:V%T86QO
M9^`H=7,I(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*
M;7-G:60@(D5M<'1Y(%1R87-H(&9O;&1E<B(*;7-G<W1R("))\'9A;'ET:2#P
M:75K\&QI^"!K871A;&]GX"(*"B,Z(&QI8B])35`N<&AP.CDW,PHC+"!F=7IZ
M>0IM<V=I9"`B16UP='D@7U-P86TB"FUS9W-T<B`B2?!?=F%L>71I(/!I=6OP
M;&EA9.O^YB(*"B,Z(&QI8B])35`N<&AP.CDV-@IM<V=I9"`B16UP='D@7U1R
M87-H(@IM<V=S='(@(DGP7W9A;'ET:2#P:75K\&QI863K_N8B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI
M;F,Z-@IM<V=I9"`B16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R
M("+!:G5N9W1I(%!'4"!G86QI;7EB97,_(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHQ('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C8*
M;7-G:60@(D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B
MP6IU;F=T:2!3+TU)344@9V%L:6UY8F5S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,3$*;7-G:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*
M;7-G<W1R("+!:G5N9W1I(&QA:?!K^"!I\&%N:W-T:6[A('!E<OYI^W+K:FEM
MX#\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-#(*;7-G
M:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B2V]?9&%V:6UO('!A
M<F%M971R86DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$W(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3<*;7-G:60@(D5N9"(*;7-G<W1R
M(")086)A:6=A(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,X-`IM<V=I9"`B16YD
M(&9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(E!E<G-I^'-T;R!L86GP:V\@
M<&%B86EG82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-#$*;7-G:60@(D5N9"!M
M97-S86=E(@IM<V=S='(@(DQA:?!K;R!P86)A:6=A(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G92!F
M<F]M("5S(@IM<V=S='(@(DQA:?!K;R!N=6\@)7,@<&%B86EG82(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C<W"FUS9VED(")%;G1E<B!087-S<&AR87-E(@IM<V=S='(@(L%V97-K
M:71E('-L87!TX&K@(&9R87KF(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O
M<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R("+!=F5S:VET92!N875J
M;W,@\&EU:_!L:6%DZ_[K<R!P879A9&EN:6W@(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@
M9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T<B`BP79E<VMI=&4@
M;F%U:F\@<&%R=6_P:6YI^"!K871A;&]G;R!P879A9&EN:6W@(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR,PIM<V=I9"`B16YT
M97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS
M9W-T<B`BP79E<VMI=&4@;F%U:F\@<VGX<W3X(&QA:?!K^"!K871A;&]G;R!P
M879A9&EN:6W@(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN
M8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@
M9F]L9&5R(@IM<V=S='(@(L%V97-K:71E(&YA=6IO<R#P:75K\&QI863K_NMS
M('!A=F%D:6YI;>`B"@HC.B!L:6(O4V5A<F-H+G!H<#HT-@HC+"!F=7IZ>0IM
M<V=I9"`B16YT:7)E($UE<W-A9V4B"FUS9W-T<B`B3G5K<F5I<'1I(&QA:?!K
MX"(*"B,Z(&UE<W-A9V4N<&AP.C$Y-"!C;VUP;W-E+G!H<#HQ,3,T('1H<F5A
M9"YP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G
M<W1R("+!<F'P87,@7"(E<UPB('/K:VUI;F=A:2#A<F'P>71A<R#A(&%D<F5S
M^"!K;GEG96SF(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ."!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HS-S8@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S@V"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T<B`B2VQA:61A(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E<G9E<BX@)7,@.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,P.2!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`W"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R(")+;&%I9&$@
M<VEU;NAI86YT(&%T<V%K>6W@.B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3`Q"FUS9VED(")%=F5N="!S=6-C97-S9G5L;'D@9&5L971E
M9"XB"FUS9W-T<B`BP79Y:VES('/K:VUI;F=A:2!I\'1R:6YT87,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN
M=71E<R(*;7-G<W1R(")+87,@,34@;6EN=>AI^"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T
M<B`B2V%S(#,P('-E:W5N9/YI^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.#$*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")+87,@-2!M
M:6YU=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,PIM<V=I9"`B
M179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(DMA<R`S,"!M:6YUZ&GX(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,`IM<V=I9"`B179E<GD@;6EN=71E
M(@IM<V=S='(@(DMA<R!M:6YU=.8B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G
M:60@(D5X<&%N9"(*;7-G<W1R("))\'-K;&5I<W1I(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS
M9W-T<B`B2?!S:VQE:7-T:2!V:7-KX"(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A;F0@06QL($9O;&1E<G,B"FUS
M9W-T<B`B2?!S:VQE:7-T:2!V:7-U<R!K871A;&]G=7,B"@HC.B!F;VQD97)S
M+G!H<#HT-3<*;7-G:60@(D5X<&%N9"!&;VQD97(B"FUS9W-T<B`B2?!S:VQE
M:7-T:2!K871A;&]GX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,T,"!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3,*;7-G
M:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R(")!9')E<_@@:?!S:VQE:61I;6%S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-C,*;7-G:60@(D5X<&%N
M9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL>2!I
M;B!T:&4@8F%C:V=R;W5N9#\B"FUS9W-T<B`B075T;VUA=&GP:V%I(&GP<VML
M96ES=&D@861R97-U<R!L86GP:V\@<F'P>6UO(&QA;F=E/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.#`*;7-G:60@(D5X<&%N9"!T:&4@96YT:7)E
M(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\B
M"FUS9W-T<B`B2V%T86QO9_@@<^!R8?!E(')O9'ET:2!I\'-K;&5I<W3@(&MA
M=&%L;V?X(&UE9.$_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,30T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0IM<V=I9"`B17AP86YD:6YG(@IM<V=S
M='(@(DGP<VML96ED_FEA;6$B"@HC.B!L:6(O24U0+G!H<#HY.#0@;&EB+TE-
M4"YP:'`Z.3@V"B,L(&9U>GIY"FUS9VED(")&7V5T8V@@36%I;"(*;7-G<W1R
M(")086EM=&D@;&%I\&MU<R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T
M8VAM86EL+FEN8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED
M(")&971C:"!-86EL(@IM<V=S='(@(E!A:6UT:2!L86GP:W5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V.0IM<V=I9"`B1F5T8V@@36%I;"!I;B!A
M('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B4&%I;71I(&QA:?!K=7,@871S
M:VER86UE(&QA;F=E/R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N
M/R(*;7-G<W1R(")086EM=&D@;&%I\&MU<R!P<FES:6IU;F=I;6\@;65T=3\B
M"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@9G)O;2`E<R(*;7-G<W1R
M(")086EM=&$@)60@;&%I\&MA<RAA:2D@:?`@)7,N(@H*(SH@;&EB+T9E=&-H
M;6%I;"YP:'`Z,C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&971C
M:&5D(#$@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(E!A:6UT82`E9"!L86GP
M:V%S*&%I*2!I\"`E<RXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#4@;&EB
M+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP.C(X.0IM<V=I
M9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B4&%I;71I(&QA:?!K86DZ("(*"B,Z
M(&QI8B]&971C:&UA:6PN<&AP.C(Y,0IM<V=I9"`B1F5T8VAM86EL.B!N;R!N
M97<@;65S<V%G97,N(@IM<V=S='(@(E!A:6UT:2!L86GP:V%I.B!NZW)A+B(*
M"B,Z(&QI8B])35`N<&AP.CDY,`IM<V=I9"`B1FE?;'1E<G,B"FUS9W-T<B`B
M7T9I;'1R86DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.#(*;7-G:60@
M(D9I;&4B"FUS9W-T<B`B1F%I;&%S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C,Q"FUS9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(")&
M:6QT<O@@<&%R86UE=')A:2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHY"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`B1FEL='+X
M(&YU<W1A='EM86DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`P"FUS
M9VED(")&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_(@IM
M<V=S='(@(D9I;'1R=6]T:2!N9?!V86YK:75S(&QA:?!K=7,_(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B1FEL=&5R
M('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@
M(D9I;'1R86D@\&EO:F4@<VES=&5M;VIE(&GP:G5N9W1I+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B
M1FEL=')A:2(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z
M,PIM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM<V=S='(@(D9I;'1R86D@
M3D5!2U195MM3(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G92(*;7-G<W1R
M(")&:6QT<F%I.B`E<R!V86QD>6UO('!U<VQA<&ES(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*;7-G:60@(D9I;F0B"FUS9W-T
M<B`B267P:V]T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*;7-G
M:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")0:7)M87-I<R!P8?!T
M;R!DZ_YU=.MS('!U<VQA<&ES(@H*(SH@;6%I;&)O>"YP:'`Z,S0U"FUS9VED
M(")&:7)S="!086=E(@IM<V=S='(@(E!I<FUA<R!P=7-L87!I<R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-2!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]?<G=A<F0B"FUS
M9W-T<B`B7U!E<G-I^'-T:2(*"B,Z(&9O;&1E<G,N<&AP.C(V-B!T96UP;&%T
M97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HU"FUS9VED(")&;VQD
M97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.0HC.B!T
M96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C8*(SH@=&5M
M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHQ,`IM<V=I9"`B
M1F]L9&5R($YA=FEG871O<B(*;7-G<W1R(")+871A;&]G^"!N87+P>6MLZR(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(")&;VQD97(@4W5M
M;6%R>2(*;7-G<W1R(")4<G5M<&%S('1U<FEN>7,B"@HC.B!A8VPN<&AP.C(T
M"FUS9VED(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS9W-T
M<B`B2V%T86QO9_@@9&%L:6II;6%S:7,@:?!J=6YG=&%S+B(*"B,Z(&9O;&1E
M<G,N<&AP.C8R"FUS9VED(")&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D+B(*
M;7-G<W1R(")+871A;&]G86D@:?!J=6YG=&DN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDV.0IM<V=I9"`B1F]R;6%T(&]F(&UE<W-A9V4@9&%T97,@
M:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T960@=&]D87DB
M"FUS9W-T<B`BT&EA;F1I96X@9V%U=/@@;&%I\&OX(&1A=&]S(&9O<FUA=&%S
M(@H*(SH@8V]M<&]S92YP:'`Z-S@P('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")097)S:?AS=&DB"@HC
M.B!C;VUP;W-E+G!H<#HW-C4*;7-G:60@(D9O<G=A<F0Z(@IM<V=S='(@(E!E
M<G-I^'-T:3HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8Y"FUS9VED(")&;W)W
M87)D960@;65S<V%G92(*;7-G<W1R(")097)S:?AS=&%S(&QA:?!K87,B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B4&5R<VGX<W1A<R!L
M86GP:V%S(&YU;R`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT
M.#,*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R(")5_FEM
M='5M;R!I;F9O<FUA8VEJ82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.30*;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R(")!='-A:WEM
M87,@87!I92!U_FEM='5MX"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.#@*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S='(@(E!R8?!Y
M;6%S('7^:6UT=6UO(&EN9F]R;6%C:6IA:2(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT,#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O
M;G-E(@IM<V=S='(@(D%T<V%K>6UA<R!U_FEM='5M;R!I;F9O<FUA8VEJ;W,@
M=?YK;&%U<V%I(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHR-PIM<V=I9"`B1G)O7VTB"FUS9W-T<B`B3E]U;R(*"B,Z(&UE
M<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T.2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I9"`B
M1G)O;2(*;7-G<W1R(").=6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3$X"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`B3G5O(&MO(@H*(SH@
M8V]M<&]S92YP:'`Z-S<W(&-O;7!O<V4N<&AP.C<X,0IM<V=I9"`B1G=D.B(*
M;7-G<W1R(")&=V0Z(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-`IM<V=I9"`B1G=D
M.B`B"FUS9W-T<B`B1G=D.B`B"@HC.B!C;VUP;W-E+G!H<#HQ,CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM
M<V=S='(@(D9W9#H@)74@<&5R<VGX<W1I(&QA:?!K86DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@*;7-G:60@(D=E;F5R86P@3W!T:6]N<R(*;7-G<W1R(")086=R:6YD
M:6YI86D@;G5S=&%T>6UA:2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHS-PIM<V=I9"`B1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!
M4"!O;FQY*2(*;7-G<W1R(")086EM=&D@=&EK(&YA=6IU<R!L86GP:W5S/R`H
M=&EK($E-05`I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,S$*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,V"FUS
M9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@(E)O9'ETX2!L86GP:^`B"@HC
M.B!L:6(O24U0+G!H<#HT.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B
M4')I9.MT:2#A(&%D<F5S^"!K;GEG96SF("@E<RDB"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,3,U"FUS9VED(")'<F%N="!A8V-E<W,B"FUS9W-T<B`B
M4W5T96EK=&D@=&5I<V5S(@H*(SH@;65S<V%G92YP:'`Z-30V(&QI8B]&:6QT
M97(N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC.B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#(@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V,R!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C8X"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D
M+G!H<#HW.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC.B!L:6(O
M34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C$W,PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ
M,C`@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(W"FUS9VED(")(15)%
M(@IM<V=S='(@(LA)02(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,2!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$W"B,Z(&QI8B]-
M24U%+U9I97=E<B]R96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R
M(")(5$U,(@H*(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I
M;VX@;V8@365S<V%G92(*;7-G<W1R("),86GP:V\@2%1-3"!V97)S:6IA(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@(DAE
M861E<G,B"FUS9W-T<B`B06YT<F'P=.MS(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M97-S86=E
M('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B3&%I\&MA<R!K=7+A(')A
M\.MT92!I\'-A=6=O=&%S(.AI83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C8X"FUS9VED(")(:61D96XB"FUS9W-T<B`B4&%S;.MP=&DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8W"FUS9VED(")(:61D96X@:6X@5&AR
M96%D(%9I97<B"FUS9W-T<B`B4&%S;.MP=&D@=F%I>F1U;VIA;G0@9VEJX"`H
M=&AR96%D*2(*"B,Z(&UA:6QB;W@N<&AP.C,V-PIM<V=I9"`B2&ED92!$96QE
M=&5D(@IM<V=S='(@(E!A<VSK<'1I(&GP=')I;G1U<R(*"B,Z(&9O;&1E<G,N
M<&AP.C(Y.`IM<V=I9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`B4&%S
M;.MP=&D@871S:7-A:WET=7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B"FUS9W-T<B`B4W9A<F)U(@H*(SH@
M;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N<&AP.C<R-"!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H(%!R:6]R:71Y(@IM<V=S
M='(@(E-V87)B=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y,PIM<V=I9"`B2&EG:&5S="(*;7-G<W1R("),86)A:2!S=F%R8G4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X"FUS9VED(")(;W<@9&\@>6]U
M('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T<B`B2V%I<"!N
M;W)I=&4@<&5R_FG[<NMT:2!P<FEK86)I;G1U<R!F86EL=7,_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4P-`IM<V=I9"`B2&]W('1O(&%T=')I8G5T
M92!Q=6]T960@;&EN97,@:6X@82!R97!L>2(*;7-G<W1R(")+86EP('!A_GEM
MZW1I(&-I='5O:F%MX"!T96MS=.`@871S86MY;64B"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C$S-`IM<V=I9"`B24U!4"(*;7-G<W1R("))34%0(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-05`@*$%U
M=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B24U!4"`H075T;VUA=&EN
M:7,@<')O=&]K;VQO(&%T<&'^:6YI;6%S*2(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,SDQ"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@4V5R=F5R(&-L
M;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C8@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB
M"FUS9W-T<B`B24U!4"!P97(@4U-,(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ-3(*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E
M<G1I9FEC871E*2(*;7-G<W1R("))34%0('!E<B!34TP@*&)E($-!('-E<G1I
M9FEK871O*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38W"FUS
M9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B24U!
M4"!P97(@4U-,("AB92!#02!P87)A\&\I(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HS-C@*(RP@9G5Z>GD*;7-G:60@(DE-05`@<V5R=F5R(&-L;W-E9"!T
M:&4@8V]N;F5C=&EO;BXB"FUS9W-T<B`B4&'P=&\@<V5R=F5R:6\@<')I<VEJ
M=6YG:6UO('1I<&%S.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,38U(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS9VED("))34%0+"!N
M;R!43%,B"FUS9W-T<B`B24U!4"P@8F4@5$Q3(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HT.0IM<V=I9"`B24U!4"]03U`S($UA:6P@4V5R=F5R<R(*
M;7-G<W1R("))34%0+U!/4#,@<&'P=&\@<V5R=F5R:6%I(@H*(SH@;&EB+TE-
M4"YP:'`Z.#8V"FUS9VED("))3D)/6"(*;7-G<W1R("))3D)/6"(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@;W(@
M5$Q3+"!Y;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD
M97)S7V-O;F9I<FTN:'1M;#HQ,@HC+"!F=7IZ>0IM<V=I9"`B268@>6]U(&-O
M;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E
M(&QO<W0A(@IM<V=S='(@(E9I<VD@;&%I\&MA:2!K871A;&]G92AU;W-E*2!B
M=7,@:?!T<FEN=&DA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T<B`B26=N;W)U;W1I(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@S"FUS9VED("))9VYO
M<F4@06QL(@IM<V=S='(@(DEG;F]R=6]T:2!V:7-U<R(*"B,Z('1E;7!L871E
M<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHX"FUS9VED("));6%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P"FUS
M9VED("));7!O<G0B"FUS9W-T<B`BP6ME;'1I(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+VEM<&]R=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-C4*;7-G:60@(DEM<&]R="!+97DB"FUS9W-T<B`BP6ME;'1I(')A
M:W3@(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S.0IM<V=I9"`B26UP
M;W)T($ME>7!A:7(B"FUS9W-T<B`BP6ME;'1I(')A:W3X('!O<N`B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PHC+"!F=7IZ>0IM<V=I
M9"`B26UP;W)T($UE<W-A9V5S(@IM<V=S='(@(E-V87)B^W,@;&%I\&MA:2(*
M"B,Z('!G<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@
M(L%K96QT:2!01U`@<F%K=.`B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.CDQ"B,L(&9U>GIY"FUS9VED("));7!O<G0@4&5R<V]N86P@0V5R=&EF
M:6-A=&4B"FUS9W-T<B`BP6ME;'1I(&%S;65N:6[A('-E<G1I9FEK873@(@H*
M(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ-`IM<V=I9"`B26UP
M;W)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>2(*;7-G<W1R("+!:V5L=&D@
M87-M96YI;N$@<VQA<'3@:N$@4$=0(')A:W3@(@H*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B
M;&EC(%!'4"!+97DB"FUS9W-T<B`BP6ME;'1I(&%S;65N:6[A('9I9?#@:N$@
M4$=0(')A:W3@(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC
M.C0*;7-G:60@(DEM<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S
M(@IM<V=S='(@(L%K96QT:2!A<VUE;FENX2!3+TU)344@<V5R=&EF:6MA=.`B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHT,@IM<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T
M<B`BP6ME;'1I('9I9?#@:N$@<F%K=.`B"@HC.B!T96UP;&%T97,O<&=P+VEM
M<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2(*
M;7-G<W1R("+!:V5L=&D@=FEE\.!JX2!01U`@<F%K=.`B"@HC.B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I9"`B26UP;W)T(%!U8FQI
M8R!3+TU)344@2V5Y(@IM<V=S='(@(L%K96QT:2!V:67PX&KA(%,O34E-12!R
M86MTX"(*"B,Z('-M:6UE+G!H<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+
M97DB"FUS9W-T<B`BP6ME;'1I(%,O34E-12!R86MTX"(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL
M92(*;7-G<W1R("+!:V5L=&D@;6)O>"!F86ELX"(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`BP6ME
M;'1I(&UB;W@@9F%I;.`@)7,@X2!K871A;&]GX"`E<RXB"@HC.B!M97-S86=E
M+G!H<#HU,#(@;6%I;&)O>"YP:'`Z-S,T('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$V('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHW"FUS9VED("));7!O<G1A
M;G0B"FUS9W-T<B`B4W9A<F+[<R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-#<*;7-G:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(")3
M=F%R8OMS(&QA:?!K86DB"@HC.B!F;VQD97)S+G!H<#HQ-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E<RXB"FUS
M9W-T<B`BP6ME;'1A("5D(&QA:?!K^"!I\"`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S<S"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@
M(D%T;&EE:V%M82(*"B,Z(&9O;&1E<G,N<&AP.C,X-"!L:6(O1F]L9&5R+G!H
M<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-4"YP:'`Z,S$S"B,Z(&QI
M8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4<F5E+G!H<#HR,3D*;7-G
M:60@(DEN8F]X(@IM<V=S='(@(DEN8F]X(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y,@IM<V=I9"`B26YC;'5D92!A(&)R:65F('-U;6UA<GD@;V8@
M=&AE(&AE861E<B!I;B!A(')E<&QY/R(*;7-G<W1R(")!<B!A='-A:V%N="#A
M=&5R<'1I(&QA:?!K;R!P86=R:6YD:6YE<R!A;G1R8?!T97,_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA
M;"!M97-S86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(D%R(&%T<V%K86YT(.%T
M97)P=&D@;&%I\&MO('1E:W-TX#\B"@HC.B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HV,2!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ
M,S`*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;W)M86-I:F$B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0
M=6)L:6,@2V5Y(@IM<V=S='(@(DEN9F]R;6%C:6IA(&%P:64@)7,@=FEE\.!J
MX2!R86MTX"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B
M26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B
M26YF;W)M86-I:F$@87!I92!A<VUE;FENX2!S;&%P=.!JX2!R86MTX"(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L
M:6,@2V5Y(@IM<V=S='(@(DEN9F]R;6%C:6IA(&%P:64@87-M96YI;N$@=FEE
M\.!JX2!R86MTX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FEN8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#<*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3@*;7-G:60@(DEN
M;&EN92(*;7-G<W1R(")+86EP('1E:W-TX"(*"B,Z('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A=&4@
M2&5R92(*;7-G<W1R("+!=&5R<'1I('-E<G1I9FEK873@(.AI82(*"B,Z('1E
M;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,34*;7-G:60@(DEN<V5R="!0
M97)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R92(*;7-G<W1R("+!=&5R<'1I
M(&%S;65N:6[A('-L87!TX&KA(%!'4"!R86MTX"#H:6$B"@HC.B!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C$P"FUS9VED("));G-E<G0@4&5R<V]N
M86P@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("+!=&5R<'1I(&%S;65N
M:6[A('9I9?#@:N$@4$=0(')A:W3@(.AI82(*"B,Z('1E;7!L871E<R]P9W`O
M:6UP;W)T7VME>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y
M($AE<F4B"FUS9W-T<B`BP6ME;'1I('9I9?#@:N$@4$=0(')A:W3@(.AI82(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3(*;7-G:60@(DEN=F%L
M:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T
M<B`B4&%S:7)I;FMT87,@;F5T96ES:6YG87,@=F5I:W-M87,@\&EA;2!K;VUP
M;VYE;G1U:2XB"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O>"YP:'`Z-C(V
M"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS9W-T<B`B3F5T96ES:6YG82!A
M9')E<_@@:VYY9V5LZRXB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C,P
M-PIM<V=I9"`B26YV86QI9"!296UO=&4@36%I;&)O>"(*;7-G<W1R(").971E
M:7-I;F=A(&YU=&]L=7-I('!A\'1O(&3K_G5TZR(*"B,Z(&-O;7!O<V4N<&AP
M.C$U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!C:&%R
M86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R(").96QE:7-T
M:6YA<R!S:6UB;VQI<R!E;"X@<&'P=&\@861R97-E+B(*"B,Z('-M:6UE+G!H
M<#HX,B!P9W`N<&AP.C$V"FUS9VED("));G9A;&ED(&ME>2(*;7-G<W1R(").
M971E:7-I;F=A<R!R86MT87,B"@HC.B!P9W`N<&AP.C$Y-@IM<V=I9"`B26YV
M86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN(@IM<V=S='(@(DYE=&5I
M<VEN9V%S(&%S;65N:6YI<R!01U`@<VQA<'1A<VES(')A:W1A<RXB"@HC.B!P
M9W`N<&AP.C$W,0IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC
M(&ME>2XB"FUS9W-T<B`B3F5T96ES:6YG87,@87-M96YI;FES(%!'4"!V:67P
M87-I<R!R86MT87,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHQ,@IM<V=I9"`B26YV97)T(@IM<V=S='(@(D%P=F5R<W1I(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3<W"FUS9VED(")+0B(*;7-G
M<W1R(")+0B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@
M(DME>2!,96YG=&@B"FUS9W-T<B`B4F%K=&\@:6QG:7,B"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M
M87D@=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I
M=&@@:V5Y("(*(F=E;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W
M"FUS9VED(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L
M;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A
M:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A
M9&0@>6]U<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS
M,3@*;7-G:60@(DME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B4F%K=&%S('/K:VUI;F=A:2!N=7-I^'-T
M87,@X2!V:67P^&KX(')A:W3X('-E<G9E<N$N(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,38*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DMA
M;&)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-@IM<V=I9"`B3&%S
M="!-86EL8F]X(%!A9V4B"FUS9W-T<B`B4&%S:W5T:6YI<R!P8?!T;R!DZ_YU
M=.MS('!U<VQA<&ES(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED("),87-T
M(%!A9V4B"FUS9W-T<B`B4&%S:W5T:6YI<R!P=7-L87!I<R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X.0IM<V=I9"`B3&E?;FL@071T
M86-H;65N=',B"FUS9W-T<B`B4W5S:65T:2!P<FEK86)I;G1U<R!?9F%I;'5S
M(@H*(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C$P-C,*
M;7-G:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G
M<W1R(")3=7-I971I('!R:6MA8FEN=&D@9F%I;&%I(&1R875D_FEA;6DN(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A
M8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES
M86)L960L('EO=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U
M('-E87)C:"!F;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@HB4F]D>71I('9I
M<W5S(&%D<F5S=7,L(&%D<F5S^"!K;GEG96SK:F4_("AJ96EG=2!I\&IU;F=S
M:71E+"!M871Y<VET92!T:6L@(@HB861R97-U<RP@:W5R:?@@:67P:V]J;W1E
M*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#4*;7-G:60@(DQI<W1I
M;F<@:6X@=&AE($AE861E<B(*;7-G<W1R(")!;G1R8?#H:?@@<^!R8?!A<R(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`IM<V=I9"`B
M3&]C86P@36%I;&)O>#HB"FUS9W-T<B`B5FEE=&ENZR!P8?!T;R!DZ_YU=.LZ
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`IM<V=I9"`B3&]C
M871I;VXB"FUS9W-T<B`B5FEE=&$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(E!R:7-I:G5N9W1I
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Q-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),;V<@:6X@=&\@)7,B"FUS9W-T<B`B4')I<VEJ=6YG=&D@<')I
M92`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,W"FUS9VED
M("),;V=I;B(*;7-G<W1R(")0<FES:6IU;F=T:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B4')I
M<VEJ=6YG:6UO(&1A<F)A:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@(DYE<W9A<F)U(@H*(SH@
M;65S<V%G92YP:'`Z,CDY(&UA:6QB;W@N<&AP.C<R-R!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C$S"FUS9VED("),;W<@4')I;W)I='DB"FUS9W-T
M<B`B3F5S=F%R8OMS(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,CDW"FUS9VED("),;W=E<W0B"FUS9W-T<B`B5FES:?!K86D@;F5S=F%R
M8G4B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0T"FUS
M9VED(")-86-I;G1O<V@@1FEL92(*;7-G<W1R(")-86-H:6YT;W-H(&9A:6QA
M<R(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PIM<V=I
M9"`B36%I;"(*;7-G<W1R(")08?!T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-@IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R("))\&%N:W-T
M:6[K(&QA:?!K^"!P97+^:?MR82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M9')I=F5R7W-E;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@
M=&\@8V]N;F5C="!T;SHB"FUS9W-T<B`B4&'P=&\@<V5R=F5R:6\@<')I<VEJ
M=6YG:6UO('1I<&%S.B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I
M;&)O>"(*;7-G<W1R(")+871A;&]G87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$Q"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/
M<'1I;VYS(@IM<V=S='(@(E!A\'1O(&3K_G5TZW,@:7(@:V%T86QO9_@@=F%I
M>F1A=FEM;R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E
M<B!A<R!3965N(@IM<V=S='(@(E!A_GEMZW1I('9I<W5S(&QA:?!K=7,@:V%I
M<"!S:V%I='ET=7,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ.0IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%5N
M<V5E;B(*;7-G<W1R(")08?YY;>MT:2!V:7-U<R!L86GP:W5S(&MA:7`@;F5S
M:V%I='ET=7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C4@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,`IM<V=I
M9"`B36%R:R!A<SHB"FUS9W-T<B`B4&'^>6WK=&D@:V%I<#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C4P"FUS9VED(")-87)K(&1I9F9E<F5N="!L
M979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_(@IM<V=S
M='(@(D-I='5O:F%MX"!T96MS=.`@<W!A;'9I;G1I('-K:7)T:6YG;VUI<R!S
M<&%L=F]M:7,_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI
M(@IM<V=S='(@(E!A_GEMZW1I(&QA:?!K=7,@:V%I<"!S:V%I='ET=7,_("AT
M:6L@24U!4"DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4X"FUS9VED
M(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(E-U_GEMZW1I('!A<')A
M<W1A:3\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G
M:60@(DUA=&-H($%L;"!1=65R:65S(@IM<V=S='(@(D%T:71I;FMA('9I<W5S
M(/YO9/YI=7,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#(*
M;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R(")!=&ET:6YK82!B970@
M:W5RX2#^;V3^X2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4Q,PIM<V=I9"`B36%X:6UU;2!!='1A8VAM96YT(%-I>F4B"FUS9W-T<B`B
M36%K<VEM86QU<R!P<FEK86)I;G3X(&9A:6SX(&1Y9&ES(@H*(SH@;&EB+V%P
M:2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($9O
M;&1E<G,B"FUS9W-T<B`B4&%S:65K=&%S(&UA:W-I;6%L=7,@<')I:V%B:6YT
M^"!F86EL^"!S:V%IZ&EU<RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT.30*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE
M;G1S(')E86-H960N(@IM<V=S='(@(E!A<VEE:W1A<R!M86MS:6UA;'5S('!R
M:6MA8FEN=/@@9F%I;/@@<VMA:>AI=7,N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#@Y"FUS9VED(")-87AI;75M('1O=&%L(&%T=&%C
M:&UE;G0@<VEZ92!R96%C:&5D+B(*;7-G<W1R(")087-I96MT87,@;6%K<VEM
M86QU<R!P<FEK86)I;G3X(&9A:6SX(&1Y9&ES+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV,C8*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N
M(@IM<V=S='(@(E-U<VER:6YK:6UO(&YU=')A=6MI;6%S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4W-0IM<V=I9"`B365E=&EN9R!);F9O<FUA
M=&EO;B(*;7-G<W1R(")3=7-I<FEN:VEM;R!I;F9O<FUA8VEJ82(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I;F<@4')O
M<&]S86PB"FUS9W-T<B`B4W5S:7)I;FMI;6\@<&%S:?ML>6UA<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3<*;7-G:60@(DUE971I;F<@4F5P
M;'DB"FUS9W-T<B`B071S86MY;6%S(&%P:64@<W5S:7)I;FMI;>`B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DX"FUS9VED(")-965T:6YG(%5P
M9&%T92(*;7-G<W1R(")3=7-I<FEN:VEM;R!A=&YA=6II;FEM87,B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`S"FUS9VED(")-965T:6YG(%5P
M9&%T92!297%U97-T(@IM<V=S='(@(E-U<VER:6YK:6UO(&%T;F%U:FEN:6UO
M('7^:VQA=7-A(@H*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,PIM
M<V=I9"`B365N=2!&;VQD97(@3&ES="(*;7-G<W1R(")-96YI=2!K871A;&]G
M^"!SX')A\&%S(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S
M<V%G92(*;7-G<W1R("),86GP:V%S(@H*(SH@8V]M<&]S92YP:'`Z-38P(&-O
M;7!O<V4N<&AP.C4X-R!C;VUP;W-E+G!H<#HV-#$@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P"FUS9VED(")-97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@
M(DQA:?!K;R!R8?!Y;6%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ
M-PIM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(DQA:?!K;R!D871A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`S"FUS9VED(")-97-S86=E($]P=&EO;G,B
M"FUS9W-T<B`B3&%I\&MO(&YU<W1A='EM86DB"@HC.B!S96%R8V@N<&AP.C,Q
M,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T<B`B3&%I\&MO('!A:67P
M:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")-97-S
M86=E(%-I>F4B"FUS9W-T<B`B3&%I\&MO(&1Y9&ES(@H*(SH@;65S<V%G92YP
M:'`Z,S@T"FUS9VED(")-97-S86=E(%-O=7)C92(*;7-G<W1R("),86GP:V\@
M:V]D87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(DUE
M<W-A9V4@5FEE=VEN9R(*;7-G<W1R("),86GP:V\@<&5R_FG[<F$B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G:60@(DUE<W-A9V4@9FQA
M9W,B"FUS9W-T<B`B3&%I\&MO(/YY;>MS(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM<V=S='(@
M(DQA:?!K^"!K871A;&]G86DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("),
M86GP:V%S(&YU;R`E<R(*"B,Z(&UA:6QB;W@N<&AP.C8V-PHC+"!F=7IZ>0IM
M<V=I9"`B365S<V%G92!H87,@871T86-H;65N=',B"FUS9W-T<B`B3&%I\&MA
M<R!A=&ET:6YK82(*"B,Z(&UA:6QB;W@N<&AP.C8U.`HC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T<B`B3&%I\&MO(&QA=6MA
M:2(*"B,Z(&UA:6QB;W@N<&AP.C8U,PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G
M92!I<R!S:6=N960B"FUS9W-T<B`B3&%I\&MO(&QA=6MA:2(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHS,PIM<V=I9"`B365S<V%G92!M871C
M:&5S(@IM<V=S='(@(DQA:?!K87,@871I=&EN:V$B"@HC.B!C;VUP;W-E+G!H
M<#HX,C0@8V]M<&]S92YP:'`Z.#,X"FUS9VED(")-97-S86=E(')E9&ER96-T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("),86GP:V%S('!E<G-I^'-T87,@
M<^MK;6EN9V%I+B(*"B,Z(&-O;7!O<V4N<&AP.C$P.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S
M879E9"!T;R`E<R(*;7-G<W1R("),86GP:V%S(&GP<VGX<W1A<R!SZVMM:6YG
M86DL('1AZ&EA=2!N96GP<V%U9V]T87,@X2`E<R(*"B,Z(&-O;7!O<V4N<&AP
M.C$Q-#,@8V]M<&]S92YP:'`Z,3$U.`IM<V=I9"`B365S<V%G92!S96YT('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B3&%I\&MA<R!I\'-I^'-T87,@<^MK;6EN
M9V%I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE
M<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@
M(DQA:?!K^"!S:V%IZ&EU<R!K871A;&]G;R!P=7-L87!Y:F4N(@H*(SH@;6%I
M;&)O>"YP:'`Z,S(R"FUS9VED(")-97-S86=E<R!T;R(*;7-G<W1R(")L86GP
M:W5S(.$B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,CD*;7-G:60@(DUO
M9&EF>2(*;7-G<W1R(")+96ES=&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M>'!A;F0N:6YC.C$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E
M('1H86X@;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I96QD(%PB)7-<(BXB"FUS
M9W-T<B`B3&%U:W5I("<E<R<@<F%S=&%S(&1A=6=I874@;F5I('9I96YA<R!A
M9')E<V%S+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM<V=I
M9"`B36]V92(*;7-G<W1R(")097)K96QT:2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,Q-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(E!E<FME;'1I(/YE;7EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8Q.`IM<V=I9"`B36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R
M(&%N9"!I;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4@=&\@
M9F]L9&5R(@IM<V=S='(@(E!E<FME;'1I(.$@:V%T86QO9^`B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,30*;7-G:60@(DUO=F4@
M=7`B"FUS9W-T<B`B4&5R:V5L=&D@875K\'1Y;B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(W"FUS9VED(")-=6QT:7!A<G0O86QT
M97)N871I=F4B"FUS9W-T<B`B2VET;W,@9&%L>7,B"@HC.B!T:')E860N<&AP
M.C<V('1H<F5A9"YP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!-
M97-S86=E(%9I97<B"FUS9W-T<B`B3&%I\&MO('!E<OYI^W)A(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C4*(RP@9G5Z
M>GD*;7-G:60@(DY/3D4B"FUS9W-T<B`B4$%35$%"02(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHT."!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/
M5$4B"FUS9W-T<B`B4$%35$%"02(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*
M;7-G:60@(DYA;64B"FUS9W-T<B`B5F%R9&%S(@H*(SH@<&=P+G!H<#HQ,3`*
M;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='DB"FUS
M9W-T<B`B5F%R9&%S(&ER+V%R8F$@96PN('!A\'1O(&%D<F5S87,@;F5G86QI
M(&+[=&D@='7P=&DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<X
M"FUS9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`B4F5I:V%L:6YG87,@=F5I
M:W-M87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W
M.`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3FEE:V%D82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-C`*;7-G:60@(DYE=F5R('-A=F4@871T86-H;65N
M=',B"FUS9W-T<B`B3FEE:V%D82!N96GP<V%U9V]T:2!P<FEK86)I;G3X(&9A
M:6SX(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R-`IM<V=I9"`B3F5W
M(@IM<V=S='(@(DYA=6IA<R(*"B,Z(&QI8B])35`N<&AP.C4V,PIM<V=I9"`B
M3F5W($9O;&1E<B(*;7-G<W1R(").875J87,@:V%T86QO9V%S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@36%I;"(*;7-G<W1R
M(").875J87,@<&'P=&%S(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y
M(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED
M(").97<@365S<V%G92(*;7-G<W1R(")396MA;G1I<R!L86GP:V%S(@H*(SH@
M;6%I;&)O>"YP:'`Z-S<V(&QI8B]-24U%+TAE861E<G,N<&AP.C$Y,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS
M9W-T<B`B3F%U:FD@;&%I\&MA:2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R(").875J:2!L
M86GP:V%I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S
M,PIM<V=I9"`B3F5X="(*;7-G<W1R(")396MA;G1I<R(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@
M365S<V%G92(*;7-G<W1R(")396MA;G1I<R!L86GP:V%S(@H*(SH@;6%I;&)O
M>"YP:'`Z,S4V"FUS9VED(").97AT(%!A9V4B"FUS9W-T<B`B4V5K86YT:7,@
M<'5S;&%P:7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW-PIM<V=I9"`B3F\B"FUS9W-T
M<B`B3F4B"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED(").;R!#97)T:69I8V%T
M92!F;W5N9"(*;7-G<W1R(")397)T:69I:V%T87,@;F5R87-T87,B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO
M($5N8W)Y<'1I;VXB"FUS9W-T<B`B2V]D879I;6\@;NMR82(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I;B!+97ER:6YG
M(@IM<V=S='(@(E-A=6=Y:VQO:F4@;NMR82!R86MT^"(*"B,Z(&UA:6QB;W@N
M<&AP.C,W-0HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*;7-G
M<W1R("),86GP:_@@;NMR82(*"B,Z('!G<"YP:'`Z,3,W"FUS9VED(").;R!0
M1U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B3F7A:V5L=&D@:F]K
M:64@4$=0('9I9?!I96II(')A:W1A:2XB"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S;VYA;"!#97)T:69I8V%T92!0
M<F5S96YT(@IM<V=S='(@(D[K<F$@87-M96YI;FEO('-E<G1I9FEK871O(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,R.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E
M=FEE=R!497AT(@IM<V=S='(@(E!E<OYI^W)A(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHQ-0IM<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B
M"FUS9W-T<B`B3NMR82!V:65T^&KX(')A:W3X(@H*(SH@<VUI;64N<&AP.C$U
M,0IM<V=I9"`B3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S
M='(@(DYEX6ME;'1I(&IO:VEE(%,O34E-12!V:67P:65J:2!R86MT86DN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDP"FUS9VED(").;R!A='1A
M8VAM96YT<R!F;W5N9"XB"FUS9W-T<B`B4')I:V%B:6YT^"!F86EL^"!NZW)A
M+B(*"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"B,L(&9U>GIY"FUS9VED
M(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@
M:V5Y+B(*;7-G<W1R("));F9O<FUA8VEJ82!A<&EE("5S('9I9?#@:N$@<F%K
M=.`B"@HC.B!A8VPN<&AP.C<R(&%C;"YP:'`Z.3@*;7-G:60@(DYO(&9O;&1E
M<B!S96QE8W1E9"XB"FUS9W-T<B`B3F5P87-I<FEN:W1A<R!K871A;&]G87,N
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T,0IM<V=I9"`B3F\@9F]L
M9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@
M(DYE:2!V:65N87,@:V%T86QO9V%S(&YE;G5S=&%T>71A<R!T:6MR:6YT:2!N
M875J=7,@;&%I\&MU<RXB"@HC.B!F;VQD97)S+G!H<#HR,3@@;&EB+T9O;&1E
M<BYP:'`Z-3`P(&QI8B]&;VQD97(N<&AP.C4U,`IM<V=I9"`B3F\@9F]L9&5R
M<R!W97)E('-P96-I9FEE9"(*;7-G<W1R(").96YU<F]D>71A<R!J;VMS(&MA
M=&%L;V=A<R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#<*;7-G:60@
M(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`B3F%U:O@@
M;&%I\&OX(&[K<F$B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30T"FUS
M9VED(").;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S(@IM<V=S='(@
M(DYE<&5R<VMA:71Y=/@@;&%I\&OX(&[K<F$B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S(U"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R("),
M86GP:V4@;NMR82!T=7)I;FEO(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,W,0IM
M<V=I9"`B3F\@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T
M<B`B3F5R87-T87,@;F5I('9I96YA<R!L86GP:V%S(&%T:71I;FMA;G1I<R!J
M^W/X('!A:67P:^`N(@H*(SH@<&=P+G!H<#HQ.#D*;7-G:60@(DYO('!E<G-O
M;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B3F7A:V5L
M=&D@:F]K:64@4$=0('-L87!T:65J:2!R86MT86DN(@H*(SH@<&=P+G!H<#HQ
M-C4*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D
M+B(*;7-G<W1R(").9>%K96QT:2!J;VMI92!01U`@=FEE\&EE:FD@<F%K=&%I
M+B(*"B,Z('-M:6UE+G!H<#HR,#$*;7-G:60@(DYO('!E<G-O;F%L(%,O34E-
M12!C97)T:69I8V%T97,@:6UP;W)T960N(@IM<V=S='(@(DYEX6ME;'1I(&IO
M:VEE(%,O34E-12!S97)T:69I:V%T86DN(@H*(SH@<W!E;&QI;F<N<&AP.C(R
M,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N
M(@IM<V=S='(@(DML86ED^"!T:6MR:6YI;6\@<')O9W)A;6$@;F5S=6MO;F9I
M9_MR=6]T82XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-#@*;7-G:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(")28?!Y8F]S
M(&ML86ED^"!NZW)A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B4&%S:?ML
M>6WX(&[K<F$B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4V-`IM<V=I9"`B
M3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T:&]D(&-O=6QD
M(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C8X(&%C;"YP:'`Z
M.30*;7-G:60@(DYO('5S97(@<W!E8VEF:65D+B(*;7-G<W1R(").97!A<VER
M:6YK=&%S('9A<G1O=&]J87,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<P.0IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(DYE9&%L
M>79I<R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@=&5M
M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,`HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-2!T96UP;&%T97,O<')E9G,O
M<W!A;7-E;&5C="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8V-`IM<V=I9"`B3F]N92(*;7-G<W1R(").:65K;R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-0IM<V=I9"`B3F]R;6%L(@IM<V=S
M='(@(DYO<FUA;'4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G:60@(DYO
M="!$96QE=&5D(@IM<V=S='(@(DYE:?!T<FEN=&DB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$R('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM<V=S='(@(DYE('!A<G5O\&EN
M:6%I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHX('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3<*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-`IM<V=I9"`B3F]T($EM<&]R=&%N
M="(*;7-G<W1R(").97-V87)B^W,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(U"FUS9VED(").;W0@4&5R<V]N86PB"FUS9W-T<B`B3F4@
M87-M96YI;FEA:2(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y
M<'0O4TU)344N<&AP.C$S-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I
M9"`B3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB"FUS9W-T<B`B3F5T:6YK86UA
M<R!V:67P87-I<R!R86MT87,N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B
M3F5I\'1R:6YT:2!L86GP:V%I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHU,0IM<V=I9"`B3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R
M(").97-V87)B^W,@;&%I\&MA:2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES
M(&-A;B!T86ME('-O;64@=&EM92(*;7-G<W1R(")486D@9V%L:2!U_G1R=6MT
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,38*(RP@9G5Z>GD*;7-G
M:60@(DYO=&AI;F<B"FUS9W-T<B`B0VET=6]J86UA.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DYU;6)E<B!O9B!M;VYT:',@=&\@
M:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H
M;'DN(@IM<V=S='(@(B(*(DMI96L@;>MN97-I^"!L86EK>71I('-U<VEJ=7-I
M=7,@<')I:V%B:6YT=7,@9F%I;'5S(&IE:6=U('1R:6YA;6$@:V%S(&WK;F5S
MX2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"FUS9VED(").=6UB
M97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L971I
M;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB4V5N^"!S:?AS=/@@;&%I\&OX(&MA
M=&%L;V?X('-K86GH:75S(&GP<V%U9V]M87,@:F5I('1R:6YA;6$@:V%S(&WK
M;F5SX2XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U
M-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW,S,*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE
M+VEM<&]R=%]K97DN:6YC.C0Y"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-#@*;7-G:60@(D]2(@IM<V=S='(@(D%20D$B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$U"FUS9VED(")/;&0@;65S<V%G97,B"FUS
M9W-T<B`B4V5N:2!L86GP:V%I(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C4R"FUS9VED(")/;&0@<V5N
M="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D+B(*;7-G<W1R(")396YI('-I
M^'-T^"!L86GP:_@@:V%T86QO9V%I(&)U<R!I\'9A;'ET:2XB"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD
M97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(E)O
M9'ET:2!T:6L@:V%T86QO9W5S('-U(&YE<&5R<VMA:71Y=&%I<R!L86GP:V%I
M<S\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"FUS
M9VED(")/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T
M:&ES(&%C=&EO;BXB"FUS9W-T<B`B4&%S:7)I;FMI=&4@=&EK('9I96[@(&MA
M=&%L;V?@(/!I86T@=F5I:W-M=6DN(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC
M.C$P('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E
M;B!&;U]L9&5R(@IM<V=S='(@(D%T:61A<GET:2!K871A;&]GX"(*"B,Z(&9O
M;&1E<G,N<&AP.C0R-PIM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G<W1R(")!
M=&ED87)Y=&%S(&MA=&%L;V=A<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW,#4*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM<V=S='(@
M(E!A9V%L8FEN:6%I(&1A;'EV:6%I(@H*(SH@9F5T8VAM86EL+G!H<#HS,R!T
M96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H97(@36%I;"!!8V-O
M=6YT<R(*;7-G<W1R(")+:71O<R!P8?!T;R!DZ_YU=.MS(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS
M9W-T<B`B2VET:2!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,#$*;7-G:60@(D]U=&)O=6YD(%-E<G9E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP"FUS9VED(")01U`B
M"FUS9W-T<B`B4$=0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L
M:7-T+FEN8SHW"FUS9VED(")01U`@16YC<GEP="!-97-S86=E(@IM<V=S='(@
M(E!'4"!U_FMO9'5O=&DB"@HC.B!C;VUP;W-E+G!H<#HS-3@*;7-G:60@(E!'
M4"!%<G)O<CH@(@IM<V=S='(@(E!'4"!K;&%I9&$Z("(*"B,Z(&-O;7!O<V4N
M<&AP.C,S-PIM<V=I9"`B4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R
M('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R(")01U`@:VQA:61A.B!A
M<VUE;FEN:6%M('-L87!T86T@<F%K='5I(')E:6MA;&EN9V$@<VQA<'1A(&9R
M87KK+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E!'
M4"!/<'1I;VYS(@IM<V=S='(@(E!'4"!N=7-T871Y;6%I(@H*(SH@<&=P+G!H
M<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`B4$=0
M('-L87!T;W,@9G)A>NMS(.%V961I;6%S(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C4U"FUS9VED(")01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T
M(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")0
M1U`@<F%K=/@@<&]R;W,@;W!E<F%C:6IO<R!R96EK86QA=6IA('-A=6=A=7,@
M<')I<VEJ=6YG:6UO+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W
M,PIM<V=I9"`B4$=0(%!U8FQI8R!+97D@5&5X="(*;7-G<W1R(")01U`@=FEE
M\&]J;R!R86MT;R!T96MS=&%S(@H*(SH@<&=P+G!H<#HQ-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A
M<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E!'4"!V:67P87-I<R!R
M86MT87,@7"(E<R`H)7,I7"(@8G5V;R!SZVMM:6YG86D@<')I:G5N9W1A<RXB
M"@HC.B!P9W`N<&AP.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B
M;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB
M"FUS9W-T<B`B4$=0('9I9?!A<VES(')A:W1A<R!<(B5S7"(@8G5V;R!SZVMM
M:6YG86D@:?!T<FEN=&%S+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(E!'4"!V:67P
M^&KX(')A:W3X('-A=6=Y:VQA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC
M<GEP=%]L:7-T+FEN8SHX"FUS9VED(")01U`@4VEG;B!-97-S86=E(@IM<V=S
M='(@(E!'4"!P87-I<F'P>71I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC
M<GEP=%]L:7-T+FEN8SHY"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A
M9V4B"FUS9W-T<B`B4$=0('!A<VER8?!Y=&D@:7(@=?YK;V1U;W1I(@H*(SH@
M<&=P+G!H<#HR,#(*;7-G:60@(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L
M;'D@861D960N(@IM<V=S='(@(E!'4"!S;&%P=&%S:7,@<F%K=&%S('/K:VUI
M;F=A:2!P<FEJ=6YG=&%S+B(*"B,Z('!G<"YP:'`Z,3<W"FUS9VED(")01U`@
M<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E!'4"!V
M:67P87-I<R!R86MT87,@<^MK;6EN9V%I('!R:6IU;F=T87,N(@H*(SH@=&5M
M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")01U`@<&%L
M86EK>6UA<R!I\&IU;F=T87,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,C`X"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY
M(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O
M(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R(")0871I:W)I;G1I('-K86ET;65N
M:6YI;R!P87)A\&\@;F5G86QI;6$L(&YE<R!I\&IU;F=T82!01U`@9V%L:6UY
M8NLN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDU"FUS9VED("(B
M"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@
M;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R(")!
M=&MO9'5O=&D@;&%I\&MO(&YE9V%L:6UA+"!N97,@:?!J=6YG=&$@4$=0(&=A
M;&EM>6+K+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"B,L(&9U>GIY
M"FUS9VED("(B"B)01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S
M('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY("(*
M(G-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG
M92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@4$=0("(*(F9E871U<F5S('=I
M;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)01U`@9V%L:6UY
M8NL@<F5I:V%L875J82!I\/!O:V%NZ&EO(&QA;F=O+B!*96EG=2!J^W/X(&YA
M<O!Y:VSK(&YU<W1A='ET82`B"B)B;&]K=6]T:2!I\/!O:V%NZ&EU<R!L86YG
M=7,L(&K[<R!T=7)I=&4@:?!J=6YG=&D@\&G@(&9U;FMC:6K@+B!0<FEE\&EN
M9W4@(@HB871V96IU(%!'4"!V96EK<R!N971E:7-I;F=A:2(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM<V=S='(@(E!/
M4#,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B4$]0
M,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R(")03U`S("A!=71O
M;6%T:6YI<R!P<F]T;VMO;&\@871P8?YI;FEM87,I(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,3<*;7-G:60@(E!/4#,@;W9E<B!34TPB"FUS9W-T
M<B`B4$]0,R!P97(@4U-,(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M,C,*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC
M871E*2(*;7-G<W1R(")03U`S('!E<B!34TP@*&)E($-!('-E<G1I9FEK871O
M*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")0
M3U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B4$]0,R!P97(@
M4U-,("AB92!#02!P87)A\&\I(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R(")03U`S+"!B92!4
M3%,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`B4'5S;&%P
M:7,@)60@:?`@)60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS
M9VED(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E(@IM<V=S
M='(@(E!U<VQA<&ES('-U('!I<FUA(&YE<&5R<VMA:71Y=&$@_FEN=71E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H
M('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(E!U<VQA<&ES('-U
M('!A<VMU=&EN92!N97!E<G-K86ET>71A(/YI;G5T92(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VAE861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S
M='(@(D1A;&ES*'ES*2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C,*
M;7-G:60@(E!A<W-P:')A<V4B"FUS9W-T<B`B4VQA<'1A(&9R87KK(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R.`IM<V=I9"`B4&%S<W!H<F%S92`H
M06=A:6XI(@IM<V=S='(@(E-L87!T82!F<F%ZZR`H9&%R(&MA<G3@*2(*"B,Z
M('-M:6UE+G!H<#HR,S4@<&=P+G!H<#HS,3`*;7-G:60@(E!A<W-P:')A<V4@
M<W5C8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R(")3;&%P=&$@9G)A>NL@
M<^MK;6EN9V%I(&%T:G5N9W1A+B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S
M<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C(Y
M"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R(")3;&%P=&$@9G)A>NLZ(@H*
M(SH@<&=P+G!H<#HQ,3(*;7-G:60@(E!A<W-P:')A<V5S(&-A;B!N;W0@8F4@
M96UP='DB"FUS9W-T<B`B4VQA<'1A(&9R87KK(&YE9V%L:2!B^W1I('1U\.AI
M82(*"B,Z('!G<"YP:'`Z,3$T"FUS9VED(")087-S<&AR87-E<R!D;R!N;W0@
M;6%T8V@B"FUS9W-T<B`B4VQA<'1O<R!F<F%ZZW,@;F5S=71A;7!A(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$Y,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4VQA<'1A_F]D
M:7,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`B4&%S:7)I;FMT:2!A<B!V>6MD>71I('!R;V9I;&%K=&EK;W,@
M=F5I:W-M=7,@<')I<VEJ=6YG=7,_(@H*(SH@86-L+G!H<#HW-B!A8VPN<&AP
M.C$P,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C86X@;F]T
M(&)E(&-H86YG960N(@IM<V=S='(@(DME:7-T:2!T96ES:?@@\&EA;2!V87)T
M;W1O:G5I(&YE9V%L:6UA+B(*"B,Z(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X
M+G!H<#HW,#,@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA
M;"(*;7-G<W1R(")!<VUE;FEN:6%I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")!
M<VUE;FENZR!I;F9O<FUA8VEJ82(*"B,Z('!G<"YP:'`Z,3(P"FUS9VED(")0
M97)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R(")!<VUE;FENZR!01U`@<F%K=/@@<&]R82!SZVMM:6YG86D@<W5G
M96YE<G5O=&$N(@H*(SH@<&=P+G!H<#HQ,C<*;7-G:60@(E!E<G-O;F%L(%!'
M4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!<VUE;FEN
M:6%I(%!'4"!R86MT86D@<^MK;6EN9V%I(&GP=')I;G1I+B(*"B,Z('-M:6UE
M+G!H<#HR,#<*;7-G:60@(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@
M3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`B07-M96YI;FEA:2!3+TU)344@<V5R
M=&EF:6MA=&%I($Y%P4M%3%1).B`B"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED
M(")097)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B07-M96YI;FEA:2!3+TU)344@<F%K=&%I('/K:VUI;F=A:2!I
M\'1R:6YT:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(R"FUS9VED
M(")0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R
M=V%R9',_(@IM<V=S='(@(E!R:63K=&D@<&%R8?#@('!R:67P('1E:W-TX"!A
M='-A:VENZVIA;G0@:7(@<&5R<VEU;NAI86YT/R(*"B,Z(&-O;7!O<V4N<&AP
M.C(U-`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G92(*;7-G
M<W1R(")496MS=&ENZR!L86GP:V\@=F5R<VEJ82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.3D*;7-G:60@(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA
M:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M
M8F5D9&5D("(*(G-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD
M;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U
M:7)E(&$@<&QU9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R
M:7!T+FEN8SHQ.3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@9F]L9&5R.B(*;7-G<W1R("+!=F5S:VET92!N875J;R!K871A;&]G
M;R!P879A9&EN:6W@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3`R('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T
M"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD
M97(Z(@IM<V=S='(@(L%V97-K:71E(&YA=6IO(&MA=&%L;V=O('!A=F%D:6YI
M;>`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S<*
M;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@(L%V
M97-K:71E(&YA=6K@('9A<F3@.B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H
M<F%S92YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N
M=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2X@
M66]U('=I;&P@;VYL>2!N965D('1O("(*(F5N=&5R('1H:7,@<&%S<W!H<F%S
M92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"B+!=F5S:VET92!0
M1U`@<F%K=&\@<VQA<'3@:N`@9G)A>N8N($K@(')E:6OK<R#A=F5D:6[K=&D@
M=&EK(&MA<G3@('!E<B`E<R`B"B)S97-I:N`N(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@
M<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T
M:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B
M(@HBP79E<VMI=&4@4R]-24U%(')A:W1O('-L87!TX&K@(&9R87KF+B!*X"!R
M96EKZW,@X79E9&ENZW1I('1I:R!K87)TX"!P97(@)7,@(@HB<V5S:6K@+B(*
M"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@
M86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO
M=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S
M:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@
M=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L
M;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN
M9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N
M=F5N:65N8V4N(@IM<V=S='(@(B(*(DYO<NMD86UI('3F<W1I+"!P<FES:6IU
M;FMI=&4@:?`@;F%U:F\N($IE:6=U(&K[<R!.14Y!541/2D%412`G<V%U<V%I
M;NML:?@G("(*(DE2(')A\&]T92!L86GP:W5S(&%T<VMI<F%M92!L86YG92P@
M=&%I<"!P870@='5RZW-I=&4@<')I<VEJ=6YG=&D@:7(@(@HB<&%G<FEN9&EN
M86UE(&QA;F=E+B!486EP(&1A<F]M82P@;F]R:6YT(&%P<V%U9V]T:2!J^W/X
M('-E<VEJ;W,@240@;G5O(&=A;&EM^"`B"B+A<VEL877^ZVQI^"X@071S:7!R
M8?!O;64@=?X@;F5P871O9W5M=7,N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW,0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R
M9"XB"FUS9W-T<B`B3G5R;V1Y:VET92!S879O('-L87!T8?YO9.$N(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PIM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B3G5R;V1Y:VET92!S879O
M('9A<G1O=&]J;R!V87)DX"XB"@HC.B!C;VUP;W-E+G!H<#HQ,#8@;&EB+TE-
M4"YP:'`Z-#4Y"FUS9VED(")0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@
M:6YV86QI9"!A9&1R97-S97,N(@IM<V=S='(@(DGP=&%I<WEK:71E(&YE=&5I
M<VEN9W5S(&%D<F5S=7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8T,@IM<V=I9"`B(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN
M9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE
M("(*(FUE;G4@8F5L;W<N(@IM<V=S='(@(B(*(E!E<G-K86ET>6MI=&4@:6YF
M;W)M86-I:N`@:7(@:?`@_F5M:6%U(&5S86[H:6\@;65N:74@<&%S:7)I;FMI
M=&4@;F]R:6W@("(*(G9E:6MS;>`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9F]L9&5R<RYJ<SHV,0IM<V=I9"`B4&QE87-E('-E;&5C="!A(&9O;&1E
M<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N(@IM<V=S='(@(E!A
M<VER:6YK:71E(&MA=&%L;V?@('!R:67P(&%T;&EK9&%M:2!B96YT(&MO:VEU
M<R!V96EK<VUU<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`R
M"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU
M(&)E;&]W+B(*;7-G<W1R(")087-I<FEN:VET92!V96EK<VW@(&GP(&UE;FEU
M(/YE;6EA=2XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC
M.C0Q"FUS9VED(")0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@
M=&\@<V5A<F-H+B(*;7-G<W1R(")087-I<FEN:VET92!B96YT('9I96[@(&MA
M=&%L;V?@('!A:67P:V%I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L
M9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B4&%S:7)I;FMI=&4@
M=&EK('9I96[@(&MA=&%L;V?@(/!I86T@=F5I:W-M=6DN(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"FUS9VED(")0;&5A<V4@<V5L
M96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@
M(E!A<VER:6YK:71E(&%R8F$@<F5D86=U;VMI=&4@;&%U:^`@9&7P:6[K:F4Z
M(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*;7-G:60@(E!O=V5R960@
M8GD@2&]R9&4B"FUS9W-T<B`B4V5R=F5R>6IE('9E:6MI82!(;W)D92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,30*;7-G:60@(E!R96-E9&4@>6]U
M<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B4')A
M9.MT:2!P87)A\.`@8G+[:_!N96QI86ES("@G+2T@)RD_(@H*(SH@<VUI;64N
M<&AP.C(T,2!P9W`N<&AP.C(U-R!F:6QT97)P<F5F<RYP:'`Z-#`*;7-G:60@
M(E!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(").
M=7-T871Y;6%I('/K:VUI;F=A:2!A=&YA=6II;G1I+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")0<F5V:65W(@IM
M<V=S='(@(E!E<OYI^W)A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@365S<V%G92(*;7-G
M<W1R(")!;FMS=&5S;FES(&QA:?!K87,B"@HC.B!M86EL8F]X+G!H<#HS-#<*
M;7-G:60@(E!R979I;W5S(%!A9V4B"FUS9W-T<B`B06YK<W1E<VYI<R!P=7-L
M87!I<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHS,PIM<V=I9"`B4')I;G0B"FUS9W-T<B`B4W!A=7-D:6YT:2(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X"FUS9VED(")0<FEO<FET
M>2(*;7-G<W1R(")3=F%R8F$B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W
M;W)D(@IM<V=S='(@(DK[<_@@<VQA<'1A<VES(')A:W1A<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE
M(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R
M(")+;&%U<W1I(&MI96MV:65NX"!K87)TX"!K86D@<VEU;NAI86UA<R!P<FEK
M86)I;G1A<R!F86EL87,[('!R861I;FES($Y%(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4U.`IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T
M86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4R(*;7-G<W1R("(B"B)+
M;&%U<W1I(&MI96MV:65NX"!K87)TX"!K86D@<VEU;NAI86UA<R!P<FEK86)I
M;G1A<R!F86EL87,[('!R861I;FES(%1!25`B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z,3`*;7-G:60@(E!R;W1O8V]L.B(*;7-G<W1R
M(")0<F]T;VMO;&%S.B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0R.0IM<V=I
M9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A
M8FQE9"XB"FUS9W-T<B`B5FEE\&]S:6]S(%!'4"!R86MT^"!S875G>6ML;W,@
M<&%L86EK>6UA<R!I\&IU;F=T87,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE
M=&5D+FEN8SHX"FUS9VED(")0=7)?9V4@1&5L971E9"(*;7-G<W1R("))7_!V
M86QY=&D@:?!T<FEN='5S(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN
M8SHX"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(DGP=F%L>71I(&GP
M=')I;G1U<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(T
M"FUS9VED(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B2?!V86QY=&D@:V%T
M86QO9^`H=7,I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-@IM<V=I
M9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G<W1R("+0:75K\&QI863K
M_NMS('9A;'EM;R!D8?YN=6UA<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#`U"FUS9VED(")0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@
M;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*;7-G<W1R("))\'1R
M:6YT:2!L86GP:W5S(&GP(/!I=6OP;&EA9.O^ZW,@<V5N97-N:75S(&YE:2!T
M:65K(&1I96[X+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G
M:60@(E!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*
M;7-G<W1R("))\'1R:6YT:2!S96YU<R!L86GP:W5S(/!I=6OP;&EA9.O^ZVIE
M/R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S
M86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B2?!V86QY=&$@)60@
M;&%I\&OX(&GP(/!I=6OP;&EA9.O^ZW,N(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")0=7)G
M:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B2?!V
M86QY=&$@)60@;&%I\&OX(&GP(/!I=6OP;&EA9.O^ZW,N(@H*(SH@=&5M<&QA
M=&5S+W%U;W1A+W%U;W1A+FEN8SHQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")1
M=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"FUS9W-T
M<B`B3F%U9&]J86UA('9I971A.B`E+C)F34(@:?`@)2XR9DU"("`H)2XR9B4E
M*2(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*
M;7-G<W1R(").875D;VIA;6$@=FEE=&$Z("4N,F9-0B`O($Y%05!224)/5$$B
M"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M
M870*;7-G:60@(E%U;W1A('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B3F%U
M9&]J86UA('9I971A.B!.14%04DE"3U1!(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN
M9R`E9CHB"FUS9W-T<B`B0VET=6]J86UA.B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B4F5?<75E<W0@1&5L:79E<GD@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(E)E:6MA;&%U=&D@<')I<W1A='EM;R!P
M871V:7)T:6YI;6\B"@HC.B!L:6(O4V5A<F-H+G!H<#HU,`IM<V=I9"`B4F5C
M96EV960@3VXB"FUS9W-T<B`B1V%U=&$B"@HC.B!L:6(O4V5A<F-H+G!H<#HU
M.`IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`B1V%U=&$@;G5O(@H*
M(SH@;&EB+U-E87)C:"YP:'`Z-30*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM
M<V=S='(@(D=A=71A(&EK:2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(DYU
M:W)E:7!T:2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8W0B"FUS9W-T<B`B3G5K<F5I<'1I(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,`IM<V=I9"`B
M4F5D:7)E8W0@365S<V%G92(*;7-G<W1R(").=6MR96EP=&D@;&%I\&O@(@H*
M(SH@8V]M<&]S92YP:'`Z-S@W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A
M9V4B"FUS9W-T<B`B3&%I\&MO(&YU:W)E:7!I;6%S(@H*(SH@8V]M<&]S92YP
M:'`Z.#0W"FUS9VED(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(DYU
M:W)E:7!I;6%S(&YE<&%V>6MO+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4X,PIM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")!=&YA=6II
M;G1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X-`IM<V=I9"`B4F5F
M<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(D%T;F%U:FEN=&D@:V%T86QO
M9V\@=F%I>F3@.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD@
M=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHT"B,L(&9U>GIY"FUS9VED
M(")296QO860B"FUS9W-T<B`B071N875J:6YT:2!V86EZ9.`B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]H96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*
M;7-G<W1R(")!=&YA=6II;G1I('9A:7IDX"(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,C8@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM
M<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B4')I<VEM:6YT:2!U_FEM='5M;R!I;F9O<FUA8VEJX"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<Y"FUS9VED(")296UE;6)E<B!T:&4@
M;&%S="!V:65W(@IM<V=S='(@(E!R:7-I;6EN=&D@<&%S:W5T:6[A('9A:7ID
MX"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PIM<V=I
M9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(DYU=&]L=7-I('!A\'1O(&3K
M_G5TZSHB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G
M:60@(E)E;6]V92!&:65L9"!&<F]M(%-E87)C:"(*;7-G<W1R(")08?!A;&EN
M=&D@;&%U:W5S(&GP('!A:67P:V]S(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,S`U"FUS9VED(")296UO=F4@<V]U<F-E(@IM<V=S
M='(@(E!A;F%I:VEN=&D@\&%L=&ENX2(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T
M<B`B4&5R=F%R9&EN=&D@:V%T86QO9^`H=7,I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD97(@
M870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")097)V87)D:6YT:2!S
M:?AS=/@@;&%I\&OX(&MA=&%L;V?@(&WK;F5S:6\@<')A9/YI;VIE/R(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C0U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296YA
M;6EN9R!<(B5S7"(@=&\@7"(E<UPB(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9"(*;7-G<W1R(")097)V861I;FEM87,@:?`@7"(E<UPB
M(.$@7"(E<UPB(&YE<&%V>6MO+B!397)V97)I;R!P<F%N9?!I;6%S('1O:W,B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*
M;7-G:60@(E)E<&Q?>2!T;R!,:7-T(@IM<V=S='(@(D%T<V%K>71I(.$@:V]N
M9F5R96Y?8VEJX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T<B`B4W5K96ES=&D@
M<W4Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C@*;7-G:60@(E)E<&QY(@IM<V=S='(@(D%T<V%K>71I(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C,Q,2!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#`Y"FUS9VED(")297!L>2!396YT+B(*;7-G<W1R(")!='-A:WEM87,@
M:?!S:?AS=&%S+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL(@IM<V=S='(@(D%T<V%K
M>71I('9I<VEE;7,B"@HC.B!C;VUP;W-E+G!H<#HW,S,*;7-G:60@(E)E<&QY
M('1O($%L;#HB"FUS9W-T<B`B071S86MY=&D@=FES:65M<SHB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G:60@(E)E
M<&QY('1O($QI<W0B"FUS9W-T<B`B071S86MY=&D@X2!K;VYF97)E;F-I:N`B
M"@HC.B!C;VUP;W-E+G!H<#HW,S4*;7-G:60@(E)E<&QY('1O($QI<W0Z(@IM
M<V=S='(@(D%T<V%K>71I(.$@:V]N9F5R96YC:6K@.B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@
M=&\@7T%L;"(*;7-G<W1R(")!='-A:WET:2!V:7-I96US(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3,W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@
M(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(D%T
M<V%K>6UO(&QA:?!K;R!T:7!A<R!N97!A;&%I:V]M87,B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3,U"FUS9VED(")297!L>2!W:71H(&9R964O
M8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B071S86MY=&D@<W4@
M=?YI;71U;6\@:6YF;W)M86-I:F$@<V5K86YT:65M<R`R(&WK;F5S:6%M<RXB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,T"FUS9VED(")297!L
M>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(D%T<V%K>71I('-U('7^:6UT=6UO(&EN9F]R;6%C:6IA+B(*"B,Z(&UE
M<W-A9V4N<&AP.C(V-PIM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`B4F5P;'DM
M5&\B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`Y"FUS9VED(")297!L>2U4;SH@
M(@IM<V=S='(@(E)E<&QY+51O.B`B"@HC.B!C;VUP;W-E+G!H<#HW,S$*;7-G
M:60@(E)E<&QY.B(*;7-G<W1R(")!='-A:WEM87,Z(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E;G0B
M"FUS9W-T<B`B3F4@;F5P86=E:61A=6IA;6%S("AS<&%M*2(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS-2!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHR,PIM<V=I9"`B4F5P;W)T(&%S(%-P86TB
M"FUS9W-T<B`B3F5P86=E:61A=6IA;6%S("AS<&%M*2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X,PIM<V=I9"`B4F5Q=65S="!A(%]2
M96%D(%)E8V5I<'0B"FUS9W-T<B`B4F5I:V%L875T:2!P97)S:V%I='EM;R!P
M871V:7)T:6YI;6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS
M9VED(")297%U97-T(&1E;&EV97)Y(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B
M4F5I:V%L875T:2!P<FES=&%T>6UO('!A='9I<G1I;FEM;S\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3<S"FUS9VED(")297%U97-T(')E860@<F5C
M96EP=',_(@IM<V=S='(@(E)E:6MA;&%U=&D@<&5R<VMA:71Y;6\@<&%T=FER
M=&EN:6UO/R(*"B,Z(&UA:6QB;W@N<&AP.C$X.0IM<V=I9"`B4F5Q=65S=&5D
M(&UE<W-A9V4@;F]T(&9O=6YD+B(*;7-G<W1R(").=7)O9'ET87,@;&%I\&MA
M<R!N97)A<W1A<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDW
M"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R(")296EK86QI
M;F=A<R!D86QY=FES(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ
M-#,@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C(V"B,Z('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-C$*;7-G:60@(E)E<V5T(@IM<V=S='(@(DGP=F%L
M>71I(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-0IM<V=I9"`B
M4F5S<&]N9&5N="!3=&%T=7,@57!D871E9"XB"FUS9W-T<B`B071S86MO=F\@
M<W1A='5S87,@871N875J:6YT87,N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T<B`B
M4F5D86=U;W1I(@H*(SH@<F5C;VUP;W-E+G!H<#HY.`IM<V=I9"`B4F5S=6UE
M('EO=7(@<V5S<VEO;B(*;7-G<W1R(")4YG-T:2!J^W/X('-E<VEJX"(*"B,Z
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT-`HC+"!F=7IZ>0IM
M<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM<V=S
M='(@(DQA:?!K;R!R8?!Y;6%S(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D
M<FEV97)?<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C
M="YI;F,Z,S(*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@
M(D=RX?YT:2#A(&QA:?!K^"!P8>MM:6W@(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI
M;F,Z,C(*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#$@=&5M<&QA
M=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,30*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,34*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z,3<S"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")'<N'^
M=&D@X2!N=7-T871Y;75S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q
M.`IM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T
M97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM
M<V=S='(@(D=RX?YT:2#A('!A\'1O(&3K_G5TYB!P;R!L86GP:V\@=')Y;FEM
M;RP@<&5R:^ML:6UO(&%R(&MO<&EJ879I;6\_(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VSK(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,3D*;7-G:60@(E,O34E-12(*;7-G<W1R(")3+TU)344B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$R"FUS9VED(")3+TU)
M344@16YC<GEP="!-97-S86=E(@IM<V=S='(@(E7^:V]D=6]T:2!L86GP:^`@
M4R]-24U%(')A:W1U(@H*(SH@8V]M<&]S92YP:'`Z,SDT"FUS9VED(")3+TU)
M344@17)R;W(Z("(*;7-G<W1R(")3+TU)344@:VQA:61A.B`B"@HC.B!C;VUP
M;W-E+G!H<#HS-S,*;7-G:60@(E,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR
M87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B4R]-24U%
M(&ML86ED83H@87-M96YI;FEA;2!S;&%P=&%M(')A:W1U:2!R96EK86QI;F=A
M('-L87!T82!F<F%ZZRXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q
M"FUS9VED(")3+TU)344@3W!T:6]N<R(*;7-G<W1R(")3+TU)344@;G5S=&%T
M>6UA:2(*"B,Z('-M:6UE+G!H<#HT.0IM<V=I9"`B4R]-24U%(%!A<W-P:')A
M<V4@26YP=70B"FUS9W-T<B`B4R]-24U%('-L87!T;W,@9G)A>NMS(.%V961I
M;6%S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B
M4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B4R]-24U%(')A:W3X('!O
M<F]S(&]P97)A8VEJ;W,@<F5I:V%L875J82!S875G875S('!R:7-I:G5N9VEM
M;RXB"@HC.B!S;6EM92YP:'`Z,30P"B,L('!H<"UF;W)M870*;7-G:60@(E,O
M34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+B(*;7-G<W1R(")3+TU)344@=FEE\&%S:7,@<F%K=&%S(%PB)7-<
M(B!B=79O('/K:VUI;F=A:2!I\'1R:6YT87,N(@H*(SH@<VUI;64N<&AP.C$V
M,@IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D
M+B(*;7-G<W1R(")3+TU)344@=FEE\&%S:7,@<F%K=&%S('/K:VUI;F=A:2!P
M<FEDZW1A<RXB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P"FUS
M9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B4R]-24U%('9I
M9?#X:O@@<F%K=/@@<V%U9WEK;&$B"@HC.B!S;6EM92YP:'`Z,C$Q"FUS9VED
M(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@
M861D960N(@IM<V=S='(@(E,O34E-12!V:67P;VII+W-A=6=I(')A:W3X('!O
M<F$@<^MK;6EN9V%I('!R:6IU;F=T82XB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E;F-R>7!T7VQI<W0N:6YC.C$S"FUS9VED(")3+TU)344@4VEG;B!-97-S
M86=E(@IM<V=S='(@(E,O34E-12!P87-I<F'P>71I(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ-`IM<V=I9"`B4R]-24U%(%-I
M9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(E,O34E-12!P87-I<F'P>71I
M(&ER('7^:V]D=6]T:2(*"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N
M:6YC.C0*;7-G:60@(E,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H
M:7,@<WES=&5M+B(*;7-G<W1R(")3+TU)344@9V%L:6UY8NL@:?!J=6YG=&$N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#$*;7-G:60@(B(*
M(E,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@96YA8FQE9"!S;R!T
M:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@(@HB9&5C<GEP=&5D+B(*;7-G
M<W1R(")!=&MO9'5O=&D@;&%I\&MO(&YE9V%L:6UA+"!N97,@4R]-24U%(&=A
M;&EM>6+K(&GP:G5N9W1A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,3<S"B,L(&9U>GIY"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N
M;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S
M<V%G92!C86X@;F]T("(*(F)E(&1I<W!L87EE9"XB"FUS9W-T<B`B4&%T:6MR
M:6YT:2!S:V%I=&UE;FEN:6\@<&%R8?!O(&YE9V%L:6UA+"!N97,@4R]-24U%
M(&=A;&EM>6+K(&GP:G5N9W1A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA
M8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E
M("(*(G9E<FEF:65D+B(*;7-G<W1R(")0871I:W)I;G1I('-K86ET;65N:6YI
M;R!P87)A\&\@;F5G86QI;6$L(&YE<R!3+TU)344@9V%L:6UY8NL@:?!J=6YG
M=&$N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,L(&9U>GIY
M"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD
M;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N
M=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H
M86YG92!T:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U
M<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)3+TU)
M344@9V%L:6UY8NL@<F5I:V%L875J82!I\/!O:V%NZ&EO(&QA;F=O+B!*96EG
M=2!J^W/X(&YA<O!Y:VSK(&YU<W1A='ET82`B"B)B;&]K=6]T:2!I\/!O:V%N
MZ&EU<R!L86YG=7,L(&K[<R!T=7)I=&4@:?!J=6YG=&D@\&G@(&9U;FMC:6K@
M+B!0<FEE\&EN9W4@(@HB871V96IU(%,O34E-12!V96EK<R!N971E:7-I;F=A
M:2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`U"FUS9VED(")3
M3510(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(U-0IM<V=I9"`B4U]U8FIE8W0B"FUS9W-T<B`B7U1E;6$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-C,*;7-G:60@(E-A7W9E
M(&$@8V]P>2!I;B`B"FUS9W-T<B`B2?!S875?9V]T:2!K;W!I:N`@:V%T86QO
M9V4@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C,R"FUS9VED(")385]V92!A<R(*;7-G<W1R("))\'-A=6=?;W1I(&MA:7`B
M"@HC.B!S96%R8V@N<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-C<*;7-G:60@(E-A=F4B"FUS9W-T<B`B2?!S875G;W1I(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E
M($%T=&%C:&UE;G1S('=I=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R
M/R(*;7-G<W1R("))\'-A=6=O=&D@<')I:V%B:6YT=7,@9F%I;'5S(&MA<G1U
M('-U(&QA:?!K=2!S:?AS=/@@;&%I\&OX(&MA=&%L;V=E/R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0S,PIM<V=I9"`B4V%V92!$<F%F="(*;7-G<W1R("))
M\'-A=6=O=&D@<&%R=6_P:6[A(@H*(SH@<V%V96EM86=E+G!H<#HT,@HC+"!F
M=7IZ>0IM<V=I9"`B4V%V92!);6%G92(*;7-G<W1R("))\'-A=6=O=&D@:V%I
M<"(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,#0*;7-G:60@(E-A=F4@
M26UA9V4@:6X@1V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z-3D@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ
M,#`*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,3(@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$T.`HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV
M92YI;F,Z,3,*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("))\'-A=6=O
M=&D@;G5S=&%T>6UU<R(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B4V%V92!3=&%T:6]N97)Y(@IM<V=S
M='(@(DGP<V%U9V]T:2!N=7-T871Y;75S(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#,S"FUS9VED(")3879E(%]$<F%F="(*;7-G<W1R("))\'-A=6=O=&D@
M7W!A<G5O\&ENX2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHS,@IM<V=I9"`B4V%V92!A<R(*;7-G<W1R("))\'-A=6=O=&D@
M:V%I<"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G:60@(E-A
M=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B2?!S875G;W1I('!A<G5O
M\&ENX2!K86EP(&YE<&5R<VMA:71Y=.`_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-S(*;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A
M;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\B"FUS9W-T<B`B2?!S
M875G;W1I(&=A=NMJ=7,@875T;VUA=&GP:V%I(.$@861R97/X(&MN>6=E;.8_
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,C<*;7-G:60@(E-A
M=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_(@IM<V=S='(@(DGP<V%U
M9V]T:2!P86EE\&MO<R!R97IU;'1A='5S('9I<G1U86QI86UE(&MA=&%L;V=E
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(E-A=F4@
M<V5N="!M86EL/R(*;7-G<W1R("))\'-A=6=O=&D@:?!S:?AS='5S(&QA:?!K
M=7,_(@H*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B2?!S875G;W1I('!A<G5O\&EN:6\@
M;F5P879Y:V\N(%-E<G9E<FEO('!R86YE\&EM87,@=&]K<SH@)7,B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y.2!T96UP;&%T97,O
M;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E
M<G,N<&AP.C0Q"FUS9VED(")396%R8V@B"FUS9W-T<B`B267P:V]T:2(*"B,Z
M('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ."!T96UP;&%T97,O;6%I
M;&)O>"]H96%D97(N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C
M:"`E<R(*;7-G<W1R("))9?!K;W1I(&MA=&%L;V=E("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($]P
M=&EO;G,B"FUS9W-T<B`B2?!S875G;W1I(&YU<W1A='EM=7,B"@HC.B!S96%R
M8V@N<&AP.C(V-0IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B4&%I
M9?!K;W,@<F5Z=6QT871A:2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,30@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,0IM<V=I
M9"`B4V5E;B(*;7-G<W1R(")3:V%I='ET:2(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z.0IM<V=I9"`B4V5L96-T(@IM<V=S='(@(E!A<VER
M:6YK:71E(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<P
M"FUS9VED(")396QE8W0@06YO=&AE<B!!8V-O=6YT(@IM<V=S='(@(E!A<VER
M:6YK:71E(&MI=.`@<^!S:V%I=.`B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z,S8*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4&%S
M:7)I;FMI=&4@9&%TX"(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN
M8SHQ,`IM<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`B4&%S:7)I;FMI
M=&4@;&%U:V5LX2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C,Q-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS
M9W-T<B`B4&%S:7)I;FMI=&4@9&%TX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F
M;W(@861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T
M<B`B4&%S:7)I;FMI=&4@861R97/X(&MN>6=E;.8@861R97/X('!A:67P:V%I
M(&ER('!R:63K:FEM=6DN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHX.`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")08?YY;>MT:2!V:7-K
MX"(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM
M<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD
M:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B4&%S:7)I;FMI=&4@;&%U:V5L:75S
M+"!K=7)I=6]S(&YA=61O<VET92!A9')E<_@@:?!S:VQE:61I;75I+B(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q"FUS
M9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R(")087-I<FEN:VET92!S
MX'-K86ETX"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G
M:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(DYE<&'^>6WK=&D@;FEE:V\B"@HC
M.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B
M4V5L96-T('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N
M:6YC.C(Q"FUS9VED(")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS
M9W-T<B`B4&%S:7)I;FMI=&4@<&'P=&\@<V5R=F5R:6\@=&EPX"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P.0IM<V=I9"`B4V5L
M96-T960@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`B4&%S:7)I;FMT;W,@861R
M97/X(&MN>6=E;.MS.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM
M<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R(").
M=7-I^'-T:2!R86MTX"#A(')A:W3X('-A=6=Y:VS@(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8P-`IM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M
M871I;VXB"FUS9W-T<B`B4VGX<W1I(&YA=6IA=7-IX"!I;F9O<FUA8VEJX"(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0IM<V=I9"`B4V5N9"!-97-S86=E
M(@IM<V=S='(@(E-I^'-T:2!L86GP:^`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S`S"B,L(&9U>GIY"FUS9VED(")396YD(')E860@<F5C96EP="!W
M:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R(")3:?AS=&D@
M341.(&MA:2!S:75N=.MJ87,@=&\@<')A\&\_(@H*(SH@9F]L9&5R<RYP:'`Z
M,SDW"FUS9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(E-I^'-T^"!L
M86GP:_@@:V%T86QO9V%S(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL
M<V5L96-T+FEN8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T
M<B`B4VGX<W3X(&QA:?!K^"!K871A;&]G87,Z(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ,S(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-#8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-3,*;7-G:60@(E-E
M<G9E<B(*;7-G<W1R(")397)V97)I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,PIM<V=I9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VXB
M"FUS9W-T<B`B4V5R=F5R:6\@:7(@:V%T86QO9_@@:6YF;W)M86-I:F$B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E
M<G9E<CHB"FUS9W-T<B`B4V5R=F5R:7,Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@P"FUS9VED(")3970@<')E9F5R96YC97,@9F]R('=H870@:&%P
M<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N(@IM<V=S
M='(@(DMA<R!B=7,@=GEK9&]M82!S=2!J^W/X(&QA:?!K86ES(&MA:2!J:64@
M=')I;F%M:2!A<F)A('!E<FME;&EA;6DN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4R.0IM<V=I9"`B4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W
M:&5N(&-O;7!O<VEN9R!M97-S86=E<S\B"FUS9W-T<B`B07(@;F%U9&]T:2!S
M=F%R8F]S(&%N=')A\'3F('-I=6[H:6%N="!L86GP:W5S/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G
M<W1R(")$86QI;G1I<R!K871A;&]G86ES(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C@V"FUS9VED(")3:&%R92!M86EL(&9O;&1E<G,B"FUS9W-T<B`B
M1&%L:6YT:7,@<&'P=&\@:V%T86QO9V%I<SHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I
M=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@(D1A;&EN=&ES('!A\'1O(&MA=&%L
M;V=A:7,@<W4@:VET86ES('9A<G1O=&]J86ES+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-CD*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@
M;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_
M($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H
M;V]S92XB"FUS9W-T<B`B07(@9&ED96QI(&-I=&%T;W,@8FQO:V%I('-T86YD
M87)T:?!K86D@='5R:2!B^W1I(')O9&]M:2!A<B!P87-LZW!T:3\B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM<V=I9"`B4VAO=6QD('1H92!B;V1Y
M(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@4$=0(&1A
M=&$_(@IM<V=S='(@(D%R(&YO<FET92!L86GP:V\@=&5K<W1E(&EE\&MO=&D@
M4$=0(&EN9F]R;6%C:6IO<S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$S"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E
M9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`B07(@<F'P>6UO(&QA
M;F=A<R!T=7)I('7^<VED87)Y=&D@<&\@<&%R=6_P:6YI;R!I\'-A=6=O:FEM
M;S\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I9"`B4VAO=6QD
M('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M
M97-S86=E<R!B>2!D969A=6QT/R(*;7-G<W1R("(B"B)!<B!N;W)I=&4@<')I
M92!K:65K=FEE;F\@<VEU;NAI86UO(&QA:?!K;R!P<FEK86)I;G1I('-A=F\@
M4$=0('9I9?#@:N$@<F%K=.`_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHY,@IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")2;V1Y
M=&D@=FES=7,@:V%T86QO9W5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A
M9&5R<RYI;F,Z-C<*;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B
M4F]D>71I('9I<V%S(&%N=')A\'1E<R(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM
M<V=I9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(E)O9'ET:2!I\'1R:6YT=7,B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B
M4VAO=R!,:6UI=&5D($AE861E<G,B"FUS9W-T<B`B4F]D>71I('!A9W)I;F1I
M;F5S(&%N=')A\'1E<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C<P"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*
M;7-G<W1R(")2;V1Y=&D@:V]N9F5R96YC:6IO<R!I;F9O<FUA8VEJX"(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@3VYL
M>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B4F]D>71I('1I:R!U_G-I
M<')E;G5M97)U;W1U<R!K871A;&]G=7,B"@HC.B!F;VQD97)S+G!H<#HR.3@*
M;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D(@IM<V=S='(@(E)O9'ET:2!N977^
M<')E;G5M97)U;W1U<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#@*
M;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@871T
M86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`B4F]D>71I('1R>6YI
M;6\@<&EK=&]G<F%MX"!P<FEE(&MI96MV:65N;R!P<FEK86)I;G1O(&9A:6QO
M(&QA:?!K93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P,@IM<V=I
M9"`B4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\B"FUS9W-T<B`B
M3&%I\&OX('/@<F'P92!R;V1Y=&D@<W!A;';X(')E:6OP;65S/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#`*;7-G:60@(E-H;W<@<')E=FEE=W,@
M9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R("))\&%N:W-T:6YI
M<R!P97+^:?MRZVII;6%S('1I:R!N97!E<G-K86ET>71O;7,@_FEN=73K;7,_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T.`IM<V=I9"`B4VAO=R!P
M<F5V:65W<R!I;B!T;V]L=&EP<S\B"FUS9W-T<B`B06QT97)N871Y=G5S(&YA
M=6IO('!A\'1O('!E<OYI^W+K:FEM87,_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@W-PIM<V=I9"`B4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N
M('1H92!M96YU8F%R/R(*;7-G<W1R(")2;V1Y=&D@)U!A:6UT:2!L86GP:W5S
M)R!M>6=T=6O@(&UE;FEU/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY-0IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM<V=S='(@(E!A<F]D>71I
M('!A=F5I:W-LZVQI=7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z-30*;7-G:60@(E-H;W<@=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU
M8F%R/R(*;7-G<W1R(")2;V1Y=&D@9FEL='+X(&UY9W1U:^`@;65N:74_(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(X"FUS9VED(")3:&]W('1O=&%L
M(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(E)O9'ET:2!B
M96YD<N`@;&%I\&OX('-K86GH:?@@:V%T86QO9V4_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8V-@IM<V=I9"`B4VAO=VXB"FUS9W-T<B`B4F]D>71I
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT
M,@IM<V=I9"`B4VE?>F4B"FUS9W-T<B`B1'ED:7,B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C$W"FUS9VED(")3:6=N960B"FUS9W-T<B`B
M4&%S:7)A\'ET:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FEN8SHS"FUS9VED(")3:7IE(@IM<V=S='(@(D1Y9&ES(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM<V=I9"`B4V]R
M="!B>2!!<G)I=F%L(@IM<V=S='(@(E+[\&EU;W1I('!A9V%L(&=A=FEM;R!D
M873@(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM<V=S='(@(E+[\&EU;W1I('!A
M9V%L('!A<F'P>6UO(&1A=.`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C(V"FUS9VED(")3;W)T(&)Y($9R;VT@061D<F5S
M<R(*;7-G<W1R(")2^_!I=6]T:2!P86=A;"!S:75N=.MJX"(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*;7-G:60@(E-O
M<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(E+[\&EU;W1I('!A9V%L(&QA
M:?!K;R!D>63A(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHS-@IM<V=I9"`B4V]R="!B>2!3=6)J96-T(@IM<V=S='(@(E+[
M\&EU;W1I('!A9V%L('!A=F%D:6YI;>`B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"FUS9VED(")3;W)T(&)Y(%1H<F5A
M9"(*;7-G<W1R(")2^_!I=6]T:2!P86=A;"!T96W@(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B4V]R="!B
M>2!4;R!!9&1R97-S(@IM<V=S='(@(E+[\&EU;W1I('!A9V%L(&%D<F5S873@
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S"FUS9VED
M(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`B3F5P86=E:61A=6IA;?@@*'-P86TI
M(&QA:?!K^"!K871A;&]G87,Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S0V"FUS9VED(")3<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T
M<B`B4W!E8VEA;/MS('-I;6)O;&EA:2(*"B,Z('-E87)C:"YP:'`Z,3,S"FUS
M9VED(")3<&5C:6%L(%9I<G1U86P@1F]L9&5R<R!C86X@;F]T(&)E(&5D:71E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,S0S"FUS9VED(")3<&5L;"!#:&5C:R(*;7-G<W1R(")+;&%I9/@@=&EK
M<FEN:6UA<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT
M-@IM<V=I9"`B4W!E;&P@0VAE8VME<B(*;7-G<W1R(")+;&%I9/@@=&EK<FEN
M:6UA<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT."!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@(E-P96QL
M(&-H96-K(&-O;7!L971E(@IM<V=S='(@(DML86ED^"!T:6MR:6YI;6%S(&)A
M:6=T87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Q"FUS9VED(")3
M<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG
M+B(*;7-G<W1R(")+;&%I9/@@<VMA:>AI=7,@<'5S;&%P>6IE(')A\'EB;W,@
M=&EK<FEN:6UO(&UE='4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4Q,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4R"FUS9VED(")3=&%R
M="(*;7-G<W1R(")0<F%DZW1I(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$Q
M"FUS9VED(")3=&%T:6]N97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHR-@IM<V=I9"`B4W1A=&EO;F5R>2!N86UE
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,C@*;7-G:60@(E-T871I;VYE<GD@='EP93HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,S"FUS9VED(")3=&%T
M:6]N97)Y.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C@X"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A='5S87,B"@HC.B!L
M:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")3=')I<"!!='1A8VAM
M96YT(@IM<V=S='(@(DGP=')I;G1I('!R:6MA8FEN=.`@9F%I;.`B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,R"FUS9VED(")3=')I<"!L:6YE8G)E
M86MS/R(*;7-G<W1R("))\'9A;'ET:2!T=?#H:6%S(&5I;'5T97,_(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-PIM<V=I
M9"`B4W5B7VIE8W0B"FUS9W-T<B`B5&5M82(*"B,Z(&UE<W-A9V4N<&AP.C(V
M."!T:')E860N<&AP.C$U,"!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N
M:6YC.C(U"B,Z(&QI8B]396%R8V@N<&AP.C,X"FUS9VED(")3=6)J96-T(@IM
M<V=S='(@(E1E;6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(P"FUS
M9VED(")3=6)J96-T($9I96QD(@IM<V=S='(@(E1E;6]S(&QA=6MA<R(*"B,Z
M('-E87)C:"YP:'`Z,S$X('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E
M+FEN8SHQ.`HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C`@
M=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,0IM<V=I9"`B4W5B;6ET
M(@IM<V=S='(@(L%V97-T:2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R*',I(@IM<V=S
M='(@(E!R96YU;65R=6]T:2!K871A;&]GX"AU<RDB"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C,X,"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS
M.#D*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@(E-U
M8V-E<W,B"FUS9W-T<B`B4^MK;6EN9V$B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S='(@
M(E!A<VG[;'EM86DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8R
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`B5'5R:6YY<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C0P,"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#,*
M;7-G:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B3&%I
M\&MO(')A\'EM;R!B^V1O('!E<FIU;F=I;6%S(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@=&\@2%1-3"!C
M;VUP;W-I=&EO;B(*;7-G<W1R(")097)J=6YG=&D@X2!(5$U,(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@
M=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;B(*;7-G<W1R(")097)J=6YG=&D@
MX2!P87!R87-TX"!T96MS=.`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT,3D*;7-G:60@(E1E7WAT(@IM<V=S='(@(E1?96MS=&%S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I
M9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B3&%I:VEN86D@<')I:6UT87,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DQ"FUS9VED(")496YT871I
M=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G<W1R("),86EK:6YA:2!P<FEI;71I
M('7^:VQA=7/@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V,0IM
M<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B3&%I:VEN86D@
M<')I:6UT87,B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M
M96YT+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O9B!397)V
M:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G<W1R(")2
M96=I<W1R86-I:F]S('/@;'EG;W,@;F5N=7)O9'ET;W,@8V]N9BYP:'`@9F%I
M;&4B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S`*(RP@
M9G5Z>GD*;7-G:60@(E1E>'0B"FUS9W-T<B`B5%]E:W-T87,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN
M(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@(DQA
M:?!K;R!.=6\Z(&QA=6ME;&ES('1U<FD@8OMT:2!S=7-I971A<SHB"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C4S,@IM<V=I9"`B(@HB5&AE($E-05`@<V5R
M=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A
M=&EO;B!M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O
M<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R(")-86-I;G1O8V@@<F5S=7)S86DB
M"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C
M86X@8F4@9&]W;FQO861E9"`E<RXB"FUS9W-T<B`B36%C:6YT;W-H(')E<W5R
M<V%I(&=A;&D@8OMT:2!A='-I^'-T:2!I\"`E<RXB"@HC.B!F971C:&UA:6QP
M<F5F<RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E/@<VMA:71A(%PB
M)7-<(B!I\'1R:6YT82XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R(")3X'-K86ET82!<(B5S7"(@:?!S875G;W1A+B(*
M"B,Z(&%T=&%C:&UE;G0N<&AP.C0S"FUS9VED(")4:&4@871T86-H;65N="!W
M87,@;F]T(&9O=6YD+B(*;7-G<W1R(")0<FEK86)I;G1A<R!F86EL87,@;F5R
M87-T87,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y"B,L(&9U
M>GIY"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S
M='(@(CQB/DMA;&5N9&]R:6%U<R!D=6]M96YY<R!N971E:7-I;F=I/"]B/B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V]M<&]S95]W:6XN:G,Z
M,S<*;7-G:60@(B(*(E1H92!C;VUP;W-E('=I;F1O=R!C86XG="!B92!O<&5N
M960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B
M;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"B).97!A=GEK;R!A=&ED
M87)Y=&D@<F'P>6UO(&QA;F=O+B!'86QB^W0@:OMS^"!N87+P>6MLZR!B;&]K
M=6]J82!N875J=7,@;&%N9W5S/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L
M961O=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C
M:6YT;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G<W1R(")-86-I;G1O<V@@9F%I
M;&\@='5R:6YY<R!I\&3K<W1Y=&%S(&%P8>AI;VIE+B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HX-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E
M<UPB('=I;&P@8F4@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(D5S86UA
M<RAI*2!K871A;&]G87,H86DI(%PB)7-<(B!B=7,@<&5R=F%R9&EN=&%S*&DI
M(.$@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,#<*;7-G
M:60@(B(*(E1H92!C=7)R96YT(&QI<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@
M=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E=')I979E9"(*;7-G<W1R
M(").97!A=GEK;R!G875T:2!V87)T;W1O:O@@=&5I<VGX(/!I86T@:V%T86QO
M9W5I(@H*(SH@8V]M<&]S92YP:'`Z,3(S-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F;VQD
M97(N(@IM<V=S='(@(E!A<G5O\&EN>7,@:?!S875G;W1A<R!K871A;&]G92!<
M(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S.0IM<V=I
M9"`B5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G
M<W1R("+!=GEK:7,@X7)A\'ET87,@X2!J^W/X(&MA;&5N9&]R:?@N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N
M9&5D+B(*;7-G<W1R("),875K87,@)R5S)R!N96=A;&D@8OMT:2!I\'-K;&5I
M<W1A<RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T
M<B`B2V%T86QO9V%S(%PB)7-<(B!J874@96=Z:7-T=6]J82(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@9F]L
M9&5R(%PB)7-<(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S
M(&YA;64N($ET(&UA>2!C875S92`B"B)P<F]B;&5M<RX@4&QE87-E('-E92!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)+871A;&]G
M;R!<(B5S7"(@<&%V861I;FEM92!Y<F$@;F5L96ES=&EN^"!S:6UB;VQI^"X@
M5&%I(&=A;&D@<W5K96QT:2`B"B)N97-K;&%N9'5M^"X@2W)E:7!K:73K<R#A
M('-I<W1E;6]S(&%D;6EN:7-T<F%T;W)I^"XB"@HC.B!L:6(O1F]L9&5R+G!H
M<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@
M=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET
M+B(*;7-G<W1R(")+871A;&]G87,@7"(E<UPB('-U:W5R=&%S+"!T8>AI874@
M;F5A:W1Y=G5O=&%S+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@9&5L971E9"!B
M=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+B(*;7-G<W1R
M(")+871A;&]G87,@7"(E<UPB(&GP=')I;G1A<RP@=&'H:6%U(&II<R!V:7,@
M9&%R('7^<')E;G5M97)U;W1A<RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HS-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO
M="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(DMA=&%L;V=A<R!<(B5S7"(@;F5S=6MU<G1A<RX@4V5R=F5R:6\@<')A
M;F7P:6UA<R!T;VMS(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C8U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T
M(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B2V%T86QO9V%S("<E<R<@;F5I\'1R:6YT87,N(%-E<G9E<FEO('!R86YE
M\&EM87,@=&]K<R(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY
M(&-R96%T960N(@IM<V=S='(@(DMA=&%L;V=A<R!<(B5S7"(@<W5K=7)T87,N
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB
M"FUS9W-T<B`B2V%T86QO9V%S(%PB)7-<(B!I\'1R:6YT87,N(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N
M(@IM<V=S='(@(DMA=&%L;V=A<R!<(B5S7"(@<&5R=F%R9&EN=&%S(.$@7"(E
M<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY,@IM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R
M=#HB"FUS9W-T<B`B4')I92#P:6]S(&1A;&EE<R!P<FEK86)I;G1I(/!I92!F
M86EL86DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]S879E:6UA
M9V5?=VEN+FIS.C$R"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@:6UA9V4@<V%V
M92!W:6YD;W<@8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@
M<V5T('EO=7(@8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/R(*
M;7-G<W1R("(B"B).97!A=GEK;R!A=&ED87)Y=&D@<F'P>6UO(&QA;F=O+B!'
M86QB^W0@:OMS^"!N87+P>6MLZR!B;&]K=6]J82!N875J=7,@;&%N9W5S/R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B(@HB5&AE
M(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@
M:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R(")0
M879E:6MS;.ML:6%I(&)U<R!P87)O9'ET:2P@8F5S('-I=6YTZVIA<R!Y<F$@
M:OMS^"!A9')E<_@@:VYY9V5LZVIE+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D
M('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B4&'P=&\@
M<V5R=F5R:6\@:VQA:61A.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C4Q"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D
M('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.B(*;7-G<W1R
M(")08?!T;R!S97)V97)I;R!I;F9O<FUA8VEJ83HB"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E
M;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(E!A\'1O
M('-E<G9E<FEO(/YI;G5TZSHB"@HC.B!L:6(O365S<V%G92YP:'`Z-C4Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!M86EL8F]X("5S(&ES(&%L<F5A9'D@
M96UP='DN(@IM<V=S='(@(DMA=&%L;V=A<R`E<R!J874@='7PZ&EA<RXB"@HC
M.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B>71E<RD@97AC
M965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("),86GP:V%S(%PB)7-<
M(B!N=6\@7"(E<UPB("@E9"!B86ET86DI('9I<O!Y:F$@<&%I;6%M^"!L86GP
M:_@@9'EDX2XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$P,PIM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E
M96X@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")28?!O;6%S(&QA:?!K87,@
M=?YD87)Y=&%S+B!)\&5I;G4N(@H*(SH@;65S<V%G92YP:'`Z,30X"FUS9VED
M(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),86GP
M:V%S(&GP=')I;G1A<RXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS
M.3,*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G
M<W1R("),86GP:V%S('!A=&EK<FEN=&%S+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,S@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS
M9W-T<B`B3&%I\&MA<R!P871I:W)I;G1A<RXB"@HC.B!T96UP;&%T97,O<VUI
M;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA=&5S+W!G<"]O<&5N7W!G
M<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S<&AR87-E('=I;F1O=R!C
M86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O
M=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"B).
M97!A=GEK;R!A=&ED87)Y=&D@<VQA<'1A_F]D_FEO(&QA;F=O+B!'86QB^W0@
M:OMS^"!N87+P>6MLZR!B;&]K=6]J82!N875J=7,@(@HB;&%N9W5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y(&-A;B!B
M92!V:65W960@)7,N(@IM<V=S='(@(DYE87!D:7)B=&%S(%!'4"!V:67P;VIO
M(')A:W1O('1E:W-T87,@9V%L:2!B^W1I('!E<OYI^W+K=&%S("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E
M<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C
M:&UE;G0N(@IM<V=S='(@(M!I;R!F86EL;R!NZW)A($U3+51.148@<')I:V%B
M:6YT;VIE(&1A;'EJ92XB"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV
M-`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!::7`@871T86-H;65N="XB"FUS9W-T<B`BT&EO<R!B>6QO<R!NZW)A
M(%II<"!A<F-H>79E+B(*"B,Z(&UE<W-A9V4N<&AP.C4T-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R
M97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@
M(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@
M4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE("(*(FYO=&EF:6-A=&EO;B!M
M97-S86=E+B(*;7-G<W1R("(B"B),86GP:V\@<VEU;G3K:F%S(')E:6MA;&%U
M:F$@871S86MY;6\@87!I92!L86GP:V\@9V%V:6W@+"!K86D@=&EK(&KA("(*
M(G!E<G-K86ET>7-I=&4N($YO<NMD86UI('1A:7`@<&%D87)Y=&DL('-P875S
M:VET92`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HV.0HC
M+"!F=7IZ>0IM<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E
M871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(DYO<NMD
M86UI('!A;6%T>71I(&UA_F5S;N$@<&%V96EK<VSK;.$L('-P875S:VET92`E
M<RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P-`IM<V=I
M9"`B5&AE('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N(@IM<V=S
M='(@(DYE<&%V>6MO('!A:V5I<W1I('!A<F'P;RXB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FIS.C$P,@IM<V=I9"`B5&AE('-I9VYA='5R92!W
M87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R(")087)A\&%S('/K
M:VUI;F=A:2!P86ME:7-T87,N(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G
M:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B3G5R;V1Y=&%S(&9A:6QA<R!N965G>FES='5O:F$N(@H*(SH@<W1A=&EO
M;F5R>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S
M=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T<B`B4^!S
M:V%I=&$@7"(E<UPB(&GP<V%U9V]T82XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E/@<VMA:71A(%PB
M)7-<(B!I\'1R:6YT82XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA
M<R!B965N('5P9&%T960N(@IM<V=S='(@(E/@<VMA:71A(%PB)7-<(B!I\'1R
M:6YT82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38Y"FUS9VED
M(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*
M;7-G<W1R(")5_F1U;W1I<R#A<F'P>71A(.$@:OMS^"!D87)B^"!SX')A\.`N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G:60@(E1H
M92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(DQA:?!K;R!T96MS=&%S
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B3&%I\&MO('1E:W-T87,@9V%L:2!B^W1I('!E
M<OYI^W+K=&%S("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C@P"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(*
M;7-G<W1R(")'<F'^:6YT;R!L86GP:V\@=&5K<W1A<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@
M)7,N(@IM<V=S='(@(D=R8?YI;G1O(&QA:?!K;R!T96MS=&%S(&=A;&D@8OMT
M:2!P97+^:?MRZW1A<R`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV.`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S
M<V%G92(*;7-G<W1R(").=7-I^'-T;R!L86GP:V\@=&5K<W1A<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B3G5S:?AS=&\@;&%I\&MO('1E:W-T87,@
M9V%L:2!B^W1I('!E<OYI^W+K=&%S("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ-30*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(E9A
M<G1O=&]J;R!U_FEM='5M;R!I;F9O<FUA8VEJ82!SZVMM:6YG86D@:?!S875G
M;W1A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z.#8*
M;7-G:60@(E1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")+:73X(&1A;&GX+"!K
M=7)I87,@9V%L:6UA(&+[=/@@<F]D>71I('1E:W-T92P@;NMR82XB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS"FUS9VED(")4
M:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*;7-G<W1R
M("+0:6%M92!K871A;&]G92!NZW)A(&QA:?!K^"XB"@HC.B!T:')E860N<&AP
M.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")+:73X(&1A;&GX+"!K
M=7)I87,@9V%L:6UA(&+[=/@@<F]D>71I('1E:W-T92P@;NMR82XB"@HC.B!L
M:6(O365S<V%G92YP:'`Z-C$R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED(@IM<V=S='(@(DYE<&%V>6MO(&GP=F%L>71I("5S+B!3
M97)V97)I;R!P<F%N9?!I;6%S('1O:W,B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-C4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM
M<V=S='(@(DYE<&%V>6MO(&GP=F%L>71I(&MA=&%L;V=O+B!397)V97)I;R!P
M<F%N9?!I;6%S.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,C$*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(DYE<&%V>6MO
M(&GP=F%L>71I(&MA=&%L;V=O+B!397)V97)I;R!P<F%N9?!I;6%S('1O:W,B
M"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G97,@9G)O;2!<
M(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S
M86ED(@IM<V=S='(@(B(*(DML86ED82!K;W!I:G5O:F%N="!L86GP:W5S(&GP
M(%PB)7-<(B#A(%PB)7-<(BX@4V5R=F5R:6\@<')A;F7P:6UA<R!T;VMS(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C$Y."!L:6(O365S<V%G92YP:'`Z,C$S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES
M('=H870@(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(DML86ED82!T<FEN
M86YT(&QA:?!K=7,@:?`@:V%T86QO9V\@7"(E<UPB+B!397)V97)I;R!P<F%N
M9?!I;6%S('1O:W,B"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H
M92`B"B)S97)V97(@<V%I9"(*;7-G<W1R(")+;&%I9&$@=')I;F%N="!L86GP
M:W5S(&MA=&%L;V=E(%PB)7-<(BX@4V5R=F5R:6\@<')A;F7P:6UA<R!T;VMS
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DML86ED82!T
M<FEN86YT(&QA:?!K=7,N(%-E<G9E<FEO(&ML86ED83H@)7,B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM
M<V=S='(@(DML86ED82!I\'1R:6YA;G0@X79Y:^$Z("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P;&%I;BYP:'`Z-3(@;&EB+TU)344O5FEE=V5R+V5N<FEC
M:&5D+G!H<#HS-PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B3F5P879Y:V\@<&%R;V1Y
M=&D@\&EO<R!L86GP:V\@9&%L:65S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4T
M-2!L:6(O365S<V%G92YP:'`Z-3@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@
M9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I
M9"(*;7-G<W1R(")+;&%I9&$@<&'^>6UI;G0@;&%I\&MU<R!K871A;&]G92!<
M(B5S7"(N(%-E<G9E<FEO('!R86YE\&EM87,@=&]K<R(*"B,Z(&9O;&1E<G,N
M<&AP.C$V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R(")+;&%I9&$@X6ME;&EA;G0@)7,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E
M=F5N=#H@)7,N(@IM<V=S='(@(DML86ED82#A:V5L:6%N="#A=GEK:6\@9'5O
M;65N:7,Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-C8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(DML86ED82#A:V5L:6%N="!D
M87)BX#H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R
M(")+;&%I9&$@X6ME;&EA;G0@=F%R=&]T;VIO('7^:6UT=6UO(&EN9F]R;6%C
M:6K@.B`E<RXB"@HC.B!L:6(O365S<V%G92YP:'`Z.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E
M<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB
M<V5R=F5R('-A:60B"FUS9W-T<B`B2VQA:61A('!E<FME;&EA;G0@;&%I\&MU
M<R!I\"!<(B5S7"(@X2!<(B5S7"(N(%-E<G9E<FEO('!R86YE\&EM87,@=&]K
M<R(*"B,Z(&-O;7!O<V4N<&AP.C$R-#0*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N(@IM<V=S='(@
M(DML86ED82!I\'-A=6=A;G0@;&%I\&O@(&MA:7`@<&%R=6_P:6[A+B(*"B,Z
M(&-O;7!O<V4N<&AP.C$P,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R
M(")+;&%I9&$@<VEU;NAI86YT(&QA:?!KX#H@)7,B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R
M(")+;&%I9&$@871N875J:6YA;G0@X79Y:^$Z("5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P;&%I;BYP:'`Z-3D*;7-G:60@(E1H97)E('=A<R!N;R!T97AT
M(&EN('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(M!I;VIE(&QA:?!K;R!D
M86QY:F4@;NMR82!T96MS=&\B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP
M:'`Z.3<*;7-G:60@(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB
M961D960@:6X@:70N(@IM<V=S='(@(M!I86UE($A434P@;&%I\&ME('ER82!P
M879E:6MS;.ML:?@N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP
M"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D
M9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES
M.B`B"FUS9W-T<B`B(@HBT&EA;64@2%1-3"!L86GP:V4@>7)A('!A=F5I:W-L
MZVQI^"X@5?YB;&]K=6]T:2!P879E:6MS;.ML:6%I(')O9&]M:2!K86EP.B`B
M"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C8*;7-G:60@(E1H:7,@
M4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O('1H92!M97-S86=E+B(*
M;7-G<W1R("+0:7,@4$=0('9I9?!A<VES(')A:W1A<R!B=79O('!R:6MA8FEN
M=&%S('!R:64@;&%I\&MO+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ,#0@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q.`HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,30S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ-3<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,R!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,S$T"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")696EK<VUA<R!N97!A;&%I:V]M87,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W.2!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-#$Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@
M>65T(&EM<&QE;65N=&5D+B(*;7-G<W1R("+0:7,@=F5I:W-M87,@9&%R(&YE
M<F5A;&EZ=6]T87,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B5&%I(&=A
M;&D@=?YT<G5K=&DN($%R(&K[<R!T:6MR86D@;F]R:71E('1E<W1I/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H
M:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R
M("),86GP:V%S('1U<FD@<')I:V%B:6YTX"!-86-H:6YT;W-H(&9A:6S@+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$P"B,L(&9U>GIY"FUS
M9VED("(B"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T
M:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB
M"FUS9W-T<B`BT&ES(&QA:?!K87,@>7)A('!A<VER8?!Y=&%S(%,O34E-12!P
M87)A\'4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,30*(RP@
M9G5Z>GD*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM
M96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S
M='(@(M!I<R!L86GP:V%S('ER82!U_FMO9'5O=&%S('-U(%,O34E-12XB"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H
M:7,@;65S<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O
M<FUA=&EO;BP@8G5T('1H92!F;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES
M('5N:VYO=VXN(@IM<V=S='(@(B(*(M!I86UE(&QA:?!K92!Y<F$@:6YF;W)M
M86-I:F$@87!I92!L86GP:_@@<')I<W1A='EMX"P@=&'H:6%U(&YE_FEN;VUA
M<R!J;W,@(@HB9F]R;6%T87,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,S$U"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@
M(@IM<V=S='(@(D%T<F]D;RP@:V%D('1A:2!N971V87)K:6YG87,@4$=0(')A
M:W1U('7^:V]D=6]T87,@;&%I\&MA<RX@2VQA:61A.B`B"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,S4P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B
M"B)21D,@,C`Q-2DN(@IM<V=S='(@(DQA:?!K87,@;F5A=&ET:6YK82!T96ES
M:6YG;R!01U`@4D9#,C`Q-2!F;W)M871O+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4:&ES(&UE<W-A9V4@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F;W)M870N(@IM
M<V=S='(@(DQA:?!K87,@;F5A=&ET:6YK82!T96ES:6YG;R!3+TU)344@9F]R
M;6%T;RXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#4@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z-#$V"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S
M(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G<W1R("+0:7,@
M;&%I\&MA<R!Y<F$@<&%S:7)A\'ET87,@4$=0('!A<F'P=2XB"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C$T,PIM<V=I9"`B5&AI<R!M97-S86=E
M(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12XB"FUS9W-T
M<B`BT&ES(&QA:?!K87,@>7)A('!A<VER8?!Y=&%S(%,O34E-12!P87)A\'4N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ,SD@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@(E1H:7,@;65S<V%G92!H87,@
M8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`BT&ES(&QA:?!K
M87,@>7)A('7^:V]D=6]T87,@<W4@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C(P,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3$*
M;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!0
M1U`N(@IM<V=S='(@(M!I<R!L86GP:V%S('ER82!U_FMO9'5O=&%S('-U(%!'
M4"XB"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G92!T
M;R(*;7-G<W1R("+PX2!L86GP:^`@X2(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@
M(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+B(*;7-G<W1R("+0:7,@<V5R=F5R:7,@;F5P86QA:6MO(&MA=&%L;V?X(&1A
M;&EJ:6UO<VDN(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ,#D*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`BT.$@;&%N9^`@<F5I:VEA(&%T
M:61A<FENZW1I(&GP(&QA:?!K;R!R8?!Y;6\@;&%N9V\N(@H*(SH@=&AR96%D
M+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM<V=S
M='(@(E)O9'ET:2(*"B,Z('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDR,@IM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B1W)U<'5O
M:F%M:2!L86GP:V%I(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP
M.C8P-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L
M871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M
M<&]S92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS9VED
M(")4;R(*;7-G<W1R(")+86TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3$Y"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(D%D<F5S871A<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM<V=I9"`B
M(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#
M;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C;&EC:VEN
M9RXB"FUS9W-T<B`B(@HB3F]RZV1A;6D@<&%S:7)I;FMT:2!K96QE=.`@<F5I
M:_!M:?@L(&QA:6MY:VET92!#;VYT<F]L("A00RD@87)B82!#;VUM86YD("(*
M(BA-86,I(&ML879I\.`L(&ER('!A<VER:6YK:71E('!E;&4N(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HQ,S0*;7-G:60@(B(*(E1O('5S92!A(%1,4R!C
M;VYN96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!0
M2%`@-2XP+C8@;W(@(@HB:&EG:&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(E1O=&%L($%T=&%C
M:&UE;G1S(%-I>F4Z(@IM<V=S='(@(E9I<V%S('!R:6MA8FEN=/@@9F%I;/@@
M9'ED:7,Z(@H*(SH@9F]L9&5R<RYP:'`Z,S@X"FUS9VED(")4<F%S:"!F;VQD
M97(B"FUS9W-T<B`BT&EU:_!L:6%DZ_[K(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W1R87-H<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A<V@@9F]L9&5R.B(*;7-G
M<W1R("+0:75K\&QI863K_NLZ(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV
M-2!L:6(O475O=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N
M9"YP:'`Z-S(*(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T
M82]C;W5R:65R+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*;7-G
M:60@(E5N86)L92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R(").97!A=GEK
M;R!A<'-K86GH:75O=&D@;F%U9&]J86UO<R!V:65T;W,B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R(").96%T<V%K
M>71I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B
M56YA;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(").96%T<V%K>71I(&QA:?!K
M86DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B56YD
M96QE=&4B"FUS9W-T<B`B071S=&%T>71I(&GP=')I;G1U<R(*"B,Z(&UA:6QB
M;W@N<&AP.C4X.2!M86EL8F]X+G!H<#HV,#(@;&EB+TU)344O2&5A9&5R<RYP
M:'`Z,C$R"FUS9VED(")5;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@
M(D%D<F5S871A:2!N97)O9&]M:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O
M;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R(").97!A;&%I:V]M87,@:V]M<&]N
M96YT;R!T:7!A<SH@)7,B"@HC.B!M86EL8F]X+G!H<#HU-C4*;7-G:60@(E5N
M:VYO=VX@1&%T92(*;7-G<W1R(")$871A(&YE_FEN;VUA(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W
M;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O
M;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8S-0IM<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@(DYE_FEN
M;VUA<R!S=7-I<FEN:VEM87,B"@HC.B!M86EL8F]X+G!H<#HV,3@*;7-G:60@
M(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@(DYE_FEN;VUA<R!A9')E<V%T
M87,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P:')A<V4B"FUS
M9W-T<B`B071J=6YG=&D@<VQA<'3@(&9R87KF(@H*(SH@9F5T8VAM86EL<')E
M9G,N<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@(DYEX79A<F1I;G1A
M<R(*"B,Z(&UE<W-A9V4N<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS,@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*
M;7-G:60@(E5N<V5E;B(*;7-G<W1R(").97-K86ET>71I(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3(*;7-G:60@(E5N<W5B<V-R:6)E
M(&9R;VT@1F]L9&5R*',I(@IM<V=S='(@(DYE8F5P<F5N=6UE<G5O=&D@:V%T
M86QO9V\H^"DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M.#0*;7-G:60@(E5P9&%T92!!='1A8VAM96YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(D%T;F%U:FEN=&D@<')I:V%B:6YT=7,@9F%I;'5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8R,`IM<V=I9"`B57!D871E(')E<W!O;F1E
M;G0@<W1A='5S(@IM<V=S='(@(D%T;F%U:FEN=&D@871S86MO=O@@<W1A='5S
MX"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU."!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED(")5<&QO860B"FUS
M9W-T<B`B3G5S:?AS=&DB"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS
M96QE8W0N:6YC.C0Q"FUS9VED(")5<V4@1&5F875L="!686QU92(*;7-G<W1R
M(").875D;W1I('-T86YD87)T:6[F(')E:6OP;>8B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C4V"FUS9VED(")5<V4@24U!4"!F;VQD97(@<W5B<V-R
M:7!T:6]N<S\B"FUS9W-T<B`B3F%U9&]T:2!)34%0(&MA=&%L;V?X('!R96YU
M;65R873@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,S4*(RP@9G5Z
M>GD*;7-G:60@(E5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\B"FUS9W-T<B`B
M5FER='5A;/MS(&MA=&%L;V=A:2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHQ-#(*;7-G:60@(E5S97(B"FUS9W-T<B`B5F%R=&]T;VIA<R(*"B,Z(&%C
M;"YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E5S97(@
M7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E8VEF:65D(')I9VAT
M<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E9A<G1O=&]J=6D@
M)R5S)R!SZVMM:6YG86D@<W5T96EK=&]S('1E:7/K<R!K871A;&]G=6D@)R5S
M)RXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-PIM<V=I9"`B
M57-E<FYA;64B"FUS9W-T<B`B5F%R=&]T;VIO('9A<F1A<R(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ-PIM<V=I9"`B57-E<FYA;64Z
M(@IM<V=S='(@(E9A<G1O=&]J;R!V87)D87,Z(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<B"FUS9W-T<B`B4F]D
M>71I(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z.3(@;&EB+TU)344O
M5FEE=V5R+W1N968N<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M("5S(@IM<V=S='(@(E)O9'ET:2`E<R(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@)7,@4'5B;&EC($ME>2(*;7-G<W1R(")2;V1Y
M=&D@)7,@=FEE\.!JX2!R86MTX"(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL
M+G!H<#HQ,38*;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W(@IM<V=S='(@(E)O9'ET:2!(5$U,('1U<FENX2!A='-K:7)A
M;64@;&%N9V4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR
M.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R(").875J
M:2!L86GP:V%I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@
M4')I=F%T92!+97DB"FUS9W-T<B`B4F]D>71I('-L87!TX&KA(')A:W3@(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S(*;7-G:60@(E9I97<@4&5R<V]N86P@4'5B;&EC($ME>2(*
M;7-G<W1R(")2;V1Y=&D@=FEE\.!JX2!R86MTX"(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B5FEE=R!4:')E
M860B"FUS9W-T<B`B4F]D>71I(&=R=7#F(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M-0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B4F]D>71I('!A=F5I
M:W-LZVQI=7,B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC
M+"!F=7IZ>0IM<V=I9"`B5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@
M=VEN9&]W(@IM<V=S='(@(E)O9'ET:2!(5$U,('1U<FENX2!A='-K:7)A;64@
M;&%N9V4B"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(E9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O
M=R(*;7-G<W1R(")2;V1Y=&D@2%1-3"!T=7)I;N$@871S:VER86UE(&QA;F=E
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B5FEE
M=R!E=F5N="(*;7-G<W1R(")097+^:?MRZW1I(.%V>6OA(@H*(SH@9F]L9&5R
M<RYP:'`Z,S@P(&UA:6QB;W@N<&AP.C4S-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(E!E<OYI^W+K=&D@;&%I
M\&MU<R!K871A;&]G92`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L
M<&%G97-E;&5C="YI;F,Z,C,*;7-G:60@(E9I97<@;W(@;6%I;&)O>"!T;R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN.B(*;7-G<W1R(")0<FES:6IU;F=U<R!R;V1Y
M=&D@\.$@:V%T86QO9^`Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$W,`IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(E!E<OYI^W+K=&D@9&%R
M8N`B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`Q"FUS9VED(")6
M:65W('1H92!);6%G97,B"FUS9W-T<B`B4F]D>71I('!A=F5I:W-LZVQI=7,B
M"@HC.B!S96%R8V@N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T
M=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T
M<B`B5FER='5A;'5S(&MA=&%L;V=A<R!<(B5S7"(@<W5K=7)T87,@<^MK;6EN
M9V%I+B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])
M34%0+U1R964N<&AP.C$S."!L:6(O24U!4"]4<F5E+G!H<#HQ-3$*(SH@;&EB
M+TE-05`O5')E92YP:'`Z,34S(&QI8B])34%0+U1R964N<&AP.C$U-R!L:6(O
M24U!4"]4<F5E+G!H<#HQ-3@*(SH@;&EB+TE-05`O5')E92YP:'`Z,S8Y(&QI
M8B])34%0+U1R964N<&AP.C,Y,R!L:6(O24U!4"]4<F5E+G!H<#HT,S,*;7-G
M:60@(E9I<G1U86P@1F]L9&5R<R(*;7-G<W1R(")6:7)T=6%L^W,@:V%T86QO
M9V%I(@H*(SH@<V5A<F-H+G!H<#HR-#4*(RP@9G5Z>GD*;7-G:60@(E9I<G1U
M86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN(@IM<V=S='(@(E9I<G1U86QA
M=7,@:V%T86QO9V\@<&%V861I;FEM87,B"@HC.B!L:6(O5D9O;&1E<BYP:'`Z
M,3<U(&QI8B]61F]L9&5R+G!H<#HQ.#`*;7-G:60@(E9I<G1U86P@24Y"3U@B
M"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#$V"B,L(&9U>GIY"FUS9VED
M(")6:7)T=6%L($E.0D]8($9O;&1E<B(*;7-G<W1R(")6:7)T=6%L^W,@:V%T
M86QO9V%I(@H*(SH@;6%I;&)O>"YP:'`Z-#4R(&QI8B]61F]L9&5R+G!H<#HQ
M,30@;&EB+U9&;VQD97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5FER='5A
M;"!4<F%S:"(*;7-G<W1R(")6:7)T=6%L^W,@:V%T86QO9V%I(@H*(SH@9F]L
M9&5R<RYP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L(%1R87-H($9O
M;&1E<B(*;7-G<W1R(")6:7)T=6%L^W,@:V%T86QO9V%I(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U86P@9F]L9&5R
M(&QA8F5L(@IM<V=S='(@(E9I<G1U86QA=7,@:V%T86QO9V\@<&%V861I;FEM
M87,B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W-`HC+"!F=7IZ
M>0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("))\'-K;&5I9/YI86UA(@H*(SH@
M;&]G:6XN<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O
M("5S(@IM<V=S='(@(E-V96EK:2!A='9Y:^8@X2`E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,3D*(RP@9G5Z>GD*;7-G:60@(B(*(E=H870@<VAO
M=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G<W1R
M("(B"B))\'1R:6YT:2!L86GP:W5S+"!P;R!T;R!K86D@:FEE(&)U=F\@<&'^
M>6WK=&D@:V%I<"!N97!A9V5I9&%U:F%M:2`H<W!A;2D_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<R-PIM<V=I9"`B(@HB5VAE;B!D96QE=&EN9R!M
M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E
M860@;V8@;6%R:VEN9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM<V=S='(@(B(*
M(DMA:2!L86GP:V%S(&GP=')I;F%M87,L(&II<R!P97)K96QI86UA<R#A(/!I
M=6OP;&EA9.O^YBP@;R!N92#^>6UI;6%S(&MA:7`@(@HB:?!T<FEN=&%S/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(E=H96X@;W!E
M;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O
M('-T87)T(&]N/R(*;7-G<W1R(")+=7+A('!U<VQA<.$@;F]R:71E(&UA='ET
M:2P@871I9&%R:75S('!A\'1O(&3K_G5TYC\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H
M;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B2V%I(&GP
M<V%U9V]M92!I\'-I^'-TX"!L86GP:^`L(&%R(&GP<V%U9V]T:2!I<B!P<FEK
M86)I;G1U<R!F86EL=7,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D
M9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U
M;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T
M(%PB0%PB*3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$Y"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B5FES861A(&QE:7-T
M:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<X"FUS9VED(")997,B"FUS9W-T<B`B5&%I
M<"(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP
M:'`Z-3@*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O
M;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(DK[<R!B86YD
M;W1E('!A:6UT:2!L86GP:W5S(&GP(/!I;W,H:?@I('/@<VMA:71O<RCX*3HB
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ
M,`HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U(&%R92!A='1E;7!T:6YG('1O(&1E
M;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@
M9F]L9&5R(@HB*',I+B(*;7-G<W1R(")*^W,@8F%N9&]T92!I\'1R:6YT:2#P
M:75O<R!K871A;&]G=7,Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R
M<U]C;VYF:7)M+FAT;6PZ.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!A='1E
M;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2XB"FUS
M9W-T<B`B2OMS(&)A;F1O=&4@:?!T<FEN=&D@\&EU;W,@:V%T86QO9W5S.B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L
M871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B66]U(&%R
M92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S='(@(DK[
M<R!K;W!I:G5O:F%T92]P97)K96QI871E(.$@:VETX"!K871A;&]GX"XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P,@IM<V=I9"`B
M66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@(@IM<V=S='(@(DK[
M<R!K=7)I871E('!A:V%T;VQO9^$@:V%T86QO9V4@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(EEO=2!A<F4@8W)E
M871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R(")*^W,@:W5R:6%T
M92!K871A;&]GX"XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N
M(@IM<V=S='(@(DK[<R!K=7)I871E(&MA=&%L;V?@+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L9&5R<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S4*
M;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@(@IM<V=S='(@
M(DK[<R!P97)V87)D:6YA=&4@:V%T86QO9^`Z("(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A;B!N
M;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DK[<R!SZVMM
M:6YG86D@871S:7!R96YU;65R879O=&4@7"(E<UPB(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C,U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&EN
M('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@(@HB8W5R<F5N="!M
M97-S86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T=7)E+B(*;7-G<W1R
M("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H
M<#HS-`IM<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS
M(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E
M9"`B"B)T;R!L;V=I;BXB"FUS9W-T<B`B2OMS(&YE<W5T:6MO=&4@<W4@<F5G
M:7-T<F%C:6IO<R!SX&QY9V]M:7,L('1O9.ML('!R:7-I:G5N9W1I(&YE9V%L
M:71E+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-CD*;7-G:60@(EEO
M=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@
M=&AI<R!F;VQD97(B"FUS9W-T<B`B3F5T=7)I=&4@=&5I<VGX(&ME:7-T:2!T
M96ES:?@@X2#PX2!K871A;&]GX"XB"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S
M86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*
M;7-G<W1R("(E)7,@:OMS('!E<G-I=6YTZW1E(/#A(&QA:?!KX"#P:65M<R!A
M9')E<V%T86US.B`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI
M;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@;65S
M<V%G97,N(@IM<V=S='(@(DK[<R!G879O=&4@)7,@;F%U:G5S(&QA:?!K=7,N
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO
M=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(DK[<R!G879O=&4@,2!N
M875JX"!L86GP:^`N(@H*(SH@8V]M<&]S92YP:'`Z-#DT"B,L(&9U>GIY"FUS
M9VED(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N(@IM
M<V=S='(@(DK[<R!G879O=&4@,2!N875JX"!L86GP:^`N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,3$U"FUS9VED("(B"B)9;W4@
M:&%V92!A="!L96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO
M=2!D:61N)W0@=7!L;V%D('EE="X@07)E("(*(GEO=2!S=7)E('EO=2!W86YT
M('1O('-E;F0@=&AI<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N
M=',_(@IM<V=S='(@(B(*(DK[<R!P87-I<FEN:V]T92!B96YT('9I96[@(&9A
M:6S@+"!K=7)I;R!D87(@;F5P<FEK86)I;F]T92X@07(@=&EK<F%I(&YO<FET
M92`B"B)S:?AS=&D@\.$@;&%I\&O@(&)E(/!I^"!F86EL^#\B"@HC.B!L:6(O
M24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@
M9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`B2OMS('1U<FET92!N875J^"!L
M86GP:_@@\&EA;64@:V%T86QO9V4Z(@H*(SH@;&EB+TE-4"YP:'`Z,3`W.0IM
M<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD
M97)S.B(*;7-G<W1R(")*^W,@='5R:71E(&YA=6KX(&QA:?!K^"#P:75O<V4@
M:V%T86QO9W5O<V4Z(@H*(SH@8V]M<&]S92YP:'`Z,34S"FUS9VED(")9;W4@
M;75S="!E;G1E<B!A="!L96%S="!O;F4@<F5C:7!I96YT+B(*;7-G<W1R(")4
M=7)I=&4@;G5R;V1Y=&D@8F5N="!V:65NX"!G87;K:N`N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,S`R"FUS9VED("(B"B)9;W4@;75S="!E;G1E
M<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@
M=FEE=R!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B(@HB3F]RZV1A;6D@<&5R_FG[
M<NMT:2#PX2!L86GP:^`L(.%V97-K:71E(%!'4"!P<FEV871A=7,@<F%K=&\@
M<VQA<'3@:N`@9G)A>N8B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C(T.0IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@
M9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R`B"B)M
M97-S86=E(@IM<V=S='(@(B(*(DYO<NMD86UI('!E<OYI^W+K=&D@\.$@;&%I
M\&O@+"#A=F5S:VET92!3+TU)344@<')I=F%T875S(')A:W1O('-L87!TX&K@
M(&9R87KF(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z
M-C0@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS9VED
M(")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB"FUS
M9W-T<B`B4')I;6EA=7-I82!R96EK:6$@;G5R;V1Y=&D@:V%T86QO9^`N(@H*
M(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R(").=7)O9'EK
M:71E('/@<VMA:73@+"!K=7)IX"!N;W)I=&4@:?!T<FEN=&DN(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(E9I<_@@<&ER
M;6$@<F5I:VEA(&YU<F]D>71I(&%D<F5SX"XB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP;&%T97,O;6%I;&)O>"]J879A
M<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,C8S"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE
M(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@(E)E:6MI82!P87-I<FEN:W1I(&)E
M;G0@=FEE;N`@;&%I\&O@+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHQ,PIM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N
M="XB"FUS9W-T<B`B4F5I:VEA(&YU<F]D>71I(&=A=NMJX"XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHR.0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A="!L96%S="!O;F4@9FEL92!T;R!A='1A8V@N(@IM<V=S
M='(@(E1U<FET92!P<FEK86)I;G1I(&)E;G0@=FEE;N`@9F%I;.`N(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@;F5E9"!T;R!H879E(%PB)7-<(B!E;F%B
M;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RXB"FUS9W-T<B`B4V%V
M;R!P<F]F:6QA:W1I;FGX('9E:6MS;?@@;G5S=&%T>6UU;W-E('1U<FET92#A
M:G5N9W1I("<E<R<N(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@
M)7,@;VX@)25S+B(*;7-G<W1R(")*^W,@;G5K<F5I<.MT92#PX2!L86GP:^`@
M)7,@)25S+B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S+B(*
M;7-G<W1R(")*^W,@871S86OK=&4@X2#PX2!L86GP:^`@)7,N(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-3`W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E
M(&YO="!S=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R(")*^W,@;F5U_G-I<')E;G5M97)A=F]T92!<
M(B5S7"(N(%-E<G9E<FEO('!R86YE\&EM87,@=&]K<R(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@
M=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(DK[<R!N96%T<VEP<F5N=6UE<F%V;W1E(%PB
M)7-<(BX@4V5R=F5R:6\@<')A;F7P:6UA<R!T;VMS(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E
M<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")*^W,@<^MK
M;6EN9V%I('7^<VEP<F5N=6UE<F%V;W1E(%PB)7-<(B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C
M97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB(@IM<V=S='(@(DK[
M<R!SZVMM:6YG86D@871S:7!R96YU;65R879O=&4@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B2OMS^"!V87)D87,O<&%V87)DZR(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHU,`IM<V=I9"`B66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*
M;7-G<W1R(")*^W/X(%!'4"!V:67P:65J:2]S<&%L=&EE:FD@<F%K=&%I(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B
M2OMS^"!S;&%P=&%S:7,@<F%K=&%S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHV-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S$*;7-G:60@(EEO
M=7(@4'5B;&EC($ME>2(*;7-G<W1R(")*^W/X('9I9?!A<VES(')A:W1A<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C4*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3XB
M"FUS9W-T<B`B4F5P;'DM5&\Z(&%D<F5S87,Z(#QI/BAN96+[=&EN82D\+VD^
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHT.0IM<V=I9"`B66]U
M<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@
M(DK[<_@@4R]-24U%('9I9?!I96II+W-L87!T:65J:2!S97)T:69I:V%T86DB
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHQ
M-@IM<V=I9"`B66]U<B!A8V-O=6YT<SHB"FUS9W-T<B`B2OMS^"!SX'-K86ET
M;W,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PHC+"!F=7IZ>0IM
M<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL
M(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S
M='(@(B(*(DMI=&D@:OMS^"!A9')E<V%I.B`\:3XH;F5B^W1I;F$L(&MI96MV
M:65NX"!A9')E<^`@<F'P>6MI=&4@;F%U:F]J92!E:6QU=.MJ92DB"B(\+VD^
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*;7-G:60@(EEO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F
M('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B2OMS^"!N87+P>6MLZR!N96=A
M;&D@<&%R;V1Y=&D@\&EO('!A=F5I:W-LZVQI;R!L86GP:V\@=&5K<W1E+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,SD*;7-G:60@(EEO=7(@9&5F
M875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G<W1R(")3
M=&%N9&%R=&ENZR!K;V1U;W3K('-I=6[H:6%M:65M<R!L86GP:V%I<SHB"@HC
M.B!T96UP;&%T97,O<')E9G,O96YC<GEP='-E;&5C="YI;F,Z,0IM<V=I9"`B
M66]U<B!D969A=6QT(&5N8W)Y<'1I;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE
M<W-A9V5S.B(*;7-G<W1R(")3=&%N9&%R=&EN:7,@:V]D879I;6\@;65T;V1A
M<R!S:75NZ&EA;6EE;7,@;&%I\&MA:7,Z(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.#D*;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S
M<V9U;&QY(&1E;&EV97)E9"XB"FUS9W-T<B`B3&%I\&MA<R!SZVMM:6YG86D@
M<')I<W1A='ET87,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-@IM
M<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM<V=S='(@(DK[<_@@<&%R8?!A<SHB
M"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S92YP:'`Z,3(X-"!M86EL8F]X
M+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q.`IM<V=I9"`B6TYO(%-U8FIE
M8W1=(@IM<V=S='(@(EMB92!P879A9&EN:6UO72(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(P-0IM<V=I9"`B7T)C8R(*;7-G<W1R(")?
M0F-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED(")?
M0FQA8VML:7-T(@IM<V=S='(@(E]";&]K=6]T:2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C$U-`IM<V=I9"`B7T-C(@IM<V=S='(@(E]#
M8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*;7-G:60@(E]$96QE=&4B"FUS9W-T
M<B`B7TGP=')I;G1I(@H*(SH@;&EB+TE-4"YP:'`Z.3<Y"FUS9VED(")?1F]L
M9&5R<R(*;7-G<W1R(")?2V%T86QO9V%I(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z.#$*;7-G:60@(E])9&5N=&ET>2(*;7-G<W1R(")!
M<%]R8?!A<R(*"B,Z(&QI8B])35`N<&AP.CDV,0IM<V=I9"`B7TEN8F]X(@IM
M<V=S='(@(DEN8F]?>"(*"B,Z(&QI8B])35`N<&AP.C$P,C`*;7-G:60@(E],
M;V<@;W5T(@IM<V=S='(@(D%T<VE?:G5N9W1I(@H*(SH@;65S<V%G92YP:'`Z
M,S@T"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T<B`B3&%I\&MO(&MO
M9&%S(@H*(SH@;&EB+TE-4"YP:'`Z.3<V"B,L(&9U>GIY"FUS9VED(")?3F5W
M($UE<W-A9V4B"FUS9W-T<B`B3F%U:FD@;&%I\&MA:2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B7U!R:6YT
M(@IM<V=S='(@(E]3<&%U<V1I;G1I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C<R('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(X.0IM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(E-?=F%R8F$B"@HC.B!M
M86EL8F]X+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B7U)E9G)E<V@@
M)7,B"FUS9W-T<B`B071N875J:6YT:2`E<R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")?4F5P;'DB"FUS9W-T
M<B`B071S86M?>71I(@H*(SH@;&EB+TE-4"YP:'`Z.3@Q"FUS9VED(")?4V5A
M<F-H(@IM<V=S='(@(DE?9?!K;W1I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#,Q"FUS9VED(")?4V5N9"!-97-S86=E(@IM<V=S='(@(E]3:?AS=&D@;&%I
M\&O@(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHS,@IM<V=I9"`B7U1H<F5A9"(*;7-G<W1R(")'<G5PZW,B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*;7-G:60@(E]4;R(*;7-G
M<W1R(")?2V%M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3,*;7-G:60@(E]5;F1E;&5T92(*;7-G<W1R(")!='-T871Y=&DB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3@*;7-G:60@
M(E]6:65W(%1H<F5A9"(*;7-G<W1R(")2;V1Y=&D@9W)U<.8B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS
M9W-T<B`B5FES861A(%]L96ES=&DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<V
M"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#0P"FUS9VED(")A='1A8VAM96YT(@IM<V=S='(@(F9A
M:6QA<R(*"B,Z('9I97<N<&AP.CDY"FUS9VED(")A='1A8VAM96YT<RYZ:7`B
M"FUS9W-T<B`B<')I:V%B:6YT:5]F86EL86DN>FEP(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B>71E<R(*;7-G<W1R
M(")B86ET86DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`P"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ-S(*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C0*;7-G:60@(F-O;6UA;F0@;&EN
M92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,C(P"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ.38*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F
M:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V
M.`IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C(R-`IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP
M"B,L(&9U>GIY"FUS9VED(")F<F]M(@IM<V=S='(@(DYU;R(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.#`*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#0*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@X
M"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!S;6EM92YP:'`Z,CD@<&=P+G!H<#HV.0IM<V=I9"`B:V5Y(@IM<V=S='(@
M(G)A:W1A<R(*"B,Z(&9O;&1E<G,N<&AP.C$V,0IM<V=I9"`B;6%I;&)O>"!F
M:6QE(@IM<V=S='(@(FMA=&%L;V=O(&9A:6QA<R(*"B,Z(&-O;7!O<V4N<&AP
M.C$P-C<@;&EB+TUE<W-A9V4N<&AP.C0V-@IM<V=I9"`B;F%M92(*;7-G<W1R
M(")V87)D87,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`B;NMR82(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(F]R(@IM<V=S='(@(F%R
M8F$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$V"FUS9VED(")P97)M:7-S:6]N
M(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$R"FUS
M9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$X-`IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R(@IM<V=S='(@(G)A\'EB;W,@
M:VQA:61A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V
M"FUS9VED(")S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B<F'P>6)O<R!K;&%I
M9&]S(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(G)A\'EB;W,@:VQA:61A(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C(P.`IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z-3$*;7-G:60@(GEO=7(@8FQA
M8VML:7-T(@IM<V=S='(@(FK[<_@@:G5O9&%S:7,@<^!R8?!A<R(*"B,Z(&QI
M8B]&:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R
M(")J^W/X(&)A;'1A<VES('/@<F'P87,B"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R]D95]$12YP;P``
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,S8S
M-S,`,3`T,3<S-C(W-C0`,#$W,30V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@24U0($=E<FUA;B!T<F%N<VQA=&EO;@HC
M($-O<'ER:6=H="`H8RD*(R!#87)S=&5N($=U96YT:&5R(#QC9W5E;G1H97)`
M9W5E;G1H97)S+FYE=#XL(#(P,#$N"B,@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SXL(#(P,#$M,C`P-2X*(PHC(&%T=&%C:&UE;G0Z($%N:&%N9PHC
M('-T871I;VYE<GDZ(%9O<FQA9V4H;BD*;7-G:60@(B(*;7-G<W1R("(B"B)0
M<F]J96-T+4ED+59E<G-I;VXZ($E-4"`T+C$M8W9S7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z-#<K,#$P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHU,BLP,3`P7&XB"B),87-T+51R86YS
M;&%T;W(Z($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^7&XB"B),86YG
M=6%G92U496%M.B!'97)M86X@/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#@M8FET7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#(Y"FUS9VED
M("(@("`@("!#8SH@(@IM<V=S='(@(B`@("`@("`@0V,Z("(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HT,C8*;7-G:60@(B`@("`@(%1O.B`B"FUS9W-T<B`B("`@
M("`@("!!;CH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q-`IM<V=I9"`B("`@
M($1A=&4Z("(*;7-G<W1R("(@("`@($1A='5M.B`B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z-#$W"FUS9VED("(@("`@1G)O;3H@(@IM<V=S='(@(B`@("`@("!6
M;VXZ("(*"B,Z(&UA:6QB;W@N<&AP.C0P."!T96UP;&%T97,O9F]L9&5R<R]H
M96%D+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S
M*2(*;7-G<W1R("(@*%IU9W)I9F9S=&%S=&4@)7,I(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C0R,PIM<V=I9"`B(%-U8FIE8W0Z("(*;7-G<W1R("(@("!"971R
M969F.B`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S`*
M;7-G:60@(B!I;B`B"FUS9W-T<B`B(&EN("(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T<B`B
M3G(N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(B4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"FUS9W-T<B`B
M)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*"B,Z('1H<F5A9"YP:'`Z,34V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D($UE<W-A9V5S(@IM<V=S='(@(B5D
M($YA8VAR:6-H=&5N(@H*(SH@;6%I;&)O>"YP:'`Z,3<U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("(E9"!.86-H<FEC:'1E;B!W=7)D96X@9V5L]G-C:'0N(@H*(SH@;&EB
M+U-P86TN<&AP.C$Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E9"!M97-S
M86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB)60@3F%C:')I8VAT
M96X@=W5R9&5N(&)E:2!):')E;2!3>7-T96UA9&UI;FES=')A=&]R(&%L<R!K
M96EN(%-P86T@9V5M96QD970N(@H*(SH@;&EB+U-P86TN<&AP.C$W-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86TN(@IM<V=S='(@(B5D($YA8VAR:6-H=&5N('=U<F1E
M(&%L<R!K96EN(%-P86T@9V5M96QD970N(@H*(SH@;&EB+U-P86TN<&AP.C$X
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@
M<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(E9"!.86-H<FEC:'1E;B!W=7)D96X@8F5I($EH<F5M(%-Y
M<W1E;6%D;6EN:7-T<F%T;W(@86QS(%-P86T@9V5M96QD970N(@H*(SH@;&EB
M+U-P86TN<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E
M<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`B)60@3F%C
M:')I8VAT96X@=W5R9&4@86QS(%-P86T@9V5M96QD970N(@H*(SH@;6%I;&)O
M>"YP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D
M($UE<W-A9V5S(@IM<V=S='(@(B5D(&)I<R`E9"!V;VX@)60@3F%C:')I8VAT
M96XB"@HC.B!M86EL8F]X+G!H<#HV,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S
M:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A
M<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@97AI<W1I97)T(&)E<F5I=',N
M($1E<B!/<F1N97(@)7,@=W5R9&4@;FEC:'0@=6UB96YA;FYT+B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HV.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B
M)7,@:7-T(&%N<V-H96EN96YD(&ME:6X@9_QL=&EG97(@3W)D;F5R;F%M92XB
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E
M:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"XB"FUS9W-T
M<B`B1&5R($]R9&YE<B`E<R!W:7)D('IU;2!-;VYA='-B96=I;FX@=6UB96YA
M;FYT+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R("(E<R!H
M870@>G5G97-T:6UM="XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C$W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@7"(E
M<UPB+B(*;7-G<W1R("(E<R!H870@7"(E<UPB(&%B9V5S86=T+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(E<R!H870@86)G96QE:&YT
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q
M=65S="XB"FUS9W-T<B`B)7,@:&%T(&%U9B!E:6YE($9R96DO1V5B=6-H="U!
M;F9R86=E(&=E86YT=V]R=&5T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@
M=&\@=&AE(&EN=FET871I;VX@=&\@7"(E<UPB+B(*;7-G<W1R("(E<R!H870@
M875F(&1I92!%:6YL861U;F<@>G4@7"(E<UPB(&=E86YT=V]R=&5T+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB
M"FUS9W-T<B`B)7,@:&%T($EH;F5N($9R96DO1V5B=6-H="U);F9O<FUA=&EO
M;F5N(&=E<V-H:6-K="XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A
M8V-E<'1E9"XB"FUS9W-T<B`B)7,@:&%T('9O<FSD=69I9R!Z=6=E<W1I;6UT
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B5S(&)I='1E="!U;2!):')E($9R96DO1V5B=6-H
M="U);F9O<FUA=&EO;F5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P
M<F5S96YC92!A="!<(B5S7"(N(@IM<V=S='(@(B5S(&)I='1E="!U;2!):')E
M($%N=V5S96YH96ET(&)E:2!<(B5S7"(N(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C0V,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B)7,@=W5R9&4@97)F;VQG<F5I
M8V@@>G4@7"(E<UPB(&AI;GIU9V5F_&=T+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S
M('1O(&%M;65N9"!<(B5S7"(N(@IM<V=S='(@(B5S(&WV8VAT92!<(B5S7"(@
MY&YD97)N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E
M(&]F(%PB)7-<(BXB"FUS9W-T<B`B)7,@;?9C:'1E(%-I92!A=68@7"(E<UPB
M(&%U9FUE<FMS86T@;6%C:&5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(')E
M8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="!<(B5S7"(N(@IM
M<V=S='(@(B5S(&WV8VAT92!D:64@;F5U97-T96X@26YF;W)M871I;VYE;B#\
M8F5R(%PB)7-<(B!E<FAA;'1E;BXB"@HC.B!M97-S86=E+G!H<#HR.3(@;65S
M<V%G92YP:'`Z,CDW"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G
M<W1R("(E<SH@)7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?=&]P
M+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D)FYB<W`[
M;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P.W9O;B9N8G-P
M.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*
M;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@
M<V-R965N+BDB"FUS9W-T<B`B*,1N9&5R=6YG96X@86YW96YD96X@=6YD('IU
M<B!NY&-H<W1E;B!396ET92!S<')I;F=E;BXI(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H
M86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G
M<W1R("(B"B(H06QL92#$;F1E<G5N9V5N('9E<G=E<F9E;B!U;F0@>G5R($YA
M8VAR:6-H=&5N97)S=&5L;'5N9R!Z=7+\8VL@<W!R:6YG96XI(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H2%1-3"DB
M"FUS9W-T<B`B*$A434PI(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB"FUS9W-T<B`B*$5I;F9A
M8VAE<B!497AT*2(*"B,Z('-P96QL:6YG+G!H<#HR-SD*;7-G:60@(B(*(BA2
M971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L
M;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("`B"B)#:&%N9V5S(&]N('1H92!C
M=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B
M(@HB*$%L;&4@8FES:&5R:6=E;B#$;F1E<G5N9V5N(&%N=V5N9&5N('5N9"!Z
M=7(@3F%C:')I8VAT96YE<G-T96QL=6YG('IU<OQC:R`B"B)S<')I;F=E;BX@
MQ&YD97)U;F=E;B!A=68@9&EE<V5R(%-E:71E('=E<F1E;B!.24-(5"!A;F=E
M=V5N9&5T+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<V"FUS9VED("(B"B(H4V5N
M9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU
M<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W:6QL
M($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*$%L;&4@8FES:&5R:6=E
M;B#$;F1E<G5N9V5N(&%N=V5N9&5N('5N9"!.86-H<FEC:'0@=F5R<V-H:6-K
M96XN(,1N9&5R=6YG96X@(@HB875F(&1I97-E<B!396ET92!W97)D96X@3DE#
M2%0@86YG97=E;F1E="XI(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR,C<*;7-G:60@(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($]+
M("HB"FUS9W-T<B`B*B!!=68@3TL@:VQI8VME;BP@=6T@075S=V%H;"!H:6YZ
M=7IU9OQG96X@*B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C`V"FUS9VED("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*
M;7-G<W1R("(J($)I='1E($%D<F5S<V4H;BD@875S=^1H;&5N("HB"@HC.B!M
M86EL8F]X+G!H<#HQ-S,*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("(Q($YA8VAR:6-H="!W=7)D92!G96SV<V-H="XB"@HC
M.B!L:6(O4W!A;2YP:'`Z,3DX"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@
M<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@HB,2!.86-H<FEC:'0@=W5R9&4@8F5I($EH<F5M
M(%-Y<W1E;6%D;6EN:7-T<F%T;W(@86QS(&ME:6X@4W!A;2!G96UE;&1E="XB
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E
M96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(C$@3F%C:')I8VAT
M('=U<F1E(&%L<R!K96EN(%-P86T@9V5M96QD970N(@H*(SH@;&EB+U-P86TN
M<&AP.C$Y,`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M,2!.86-H<FEC:'0@=W5R9&4@8F5I($EH<F5M(%-Y<W1E;6%D;6EN:7-T<F%T
M;W(@86QS(%-P86T@9V5M96QD970N(@H*(SH@;&EB+U-P86TN<&AP.C$W,`IM
M<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN(@IM
M<V=S='(@(C$@3F%C:')I8VAT('=U<F1E(&%L<R!3<&%M(&=E;65L9&5T+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#@*;7-G:60@(C$P,"!C:&%R
M86-T97)S(@IM<V=S='(@(C$P,"!:96EC:&5N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@Q,0IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S='(@
M(C$P,#`@6F5I8VAE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#D*
M;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(C(U,"!:96EC:&5N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q,`IM<V=I9"`B-3`P(&-H87)A
M8W1E<G,B"FUS9W-T<B`B-3`P(%IE:6-H96XB"@HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B02!L87)G
M92!I;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N
M(@IM<V=S='(@(B(*(D5I;B!G<F_?97,@0FEL9"!M:70@9&5R($)E>F5I8VAN
M=6YG("5S(&ES="!A;B!D:65S92!.86-H<FEC:'0@86YG96CD;F=T+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4P"FUS9VED("(B
M"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@82!R
M971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE("(*(G)E8VEP:65N="XB"FUS
M9W-T<B`B(@HB16EN92!.86-H<FEC:'0L(&1I92!3:64@=F5R<V-H:6-K="!H
M86)E;BP@9OQH<G1E('IU(&5I;F5R($5M<&9A;F=B97-TY'1I9W5N9R`B"B)V
M;VT@16UP9N1N9V5R+B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN
M8SHU"FUS9VED(")!3D0B"FUS9W-T<B`B54Y$(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4X,@IM<V=I9"`B06-C97!T(&%N9"!A9&0@=&\@;7D@
M8V%L96YD87(B"FUS9W-T<B`B06YF<F%G92!A:WIE<'1I97)E;B!U;F0@>G4@
M;65I;F5M($MA;&5N9&5R(&AI;GIU9OQG96XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3@U"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R
M(")!;F9R86=E(&%K>F5P=&EE<F5N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<T-@IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B06YG96YO;6UE
M;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3@*;7-G:60@(D%C
M8V5P=&5D.B`B"FUS9W-T<B`B06YG96YO;6UE;CH@(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C8V]U;G0G<R!N86UE
M.B(*;7-G<W1R(")+;VYT;VYA;64Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4R,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S(U"FUS9VED
M(")!8W1I;VYS(@IM<V=S='(@(D%K=&EO;F5N(@H*(SH@;&EB+TU)344O2&5A
M9&5R<RYP:'`Z,3DR(&QI8B]-24U%+TAE861E<G,N<&AP.C$Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@)7,@=&\@;7D@061D<F5S<R!";V]K(@IM<V=S
M='(@(B5S('IU(&UE:6YE;2!!9')E<W-B=6-H(&AI;GIU9OQG96XB"@HC.B!T
M96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*;7-G:60@(D%D
M9"!S;W5R8V4B"FUS9W-T<B`B475E;&QE(&AI;GIU9OQG96XB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3<S"FUS9VED(")!9&0@=&AI<R!T;R!M
M>2!C86QE;F1A<B(*;7-G<W1R("):=2!M96EN96T@2V%L96YD97(@:&EN>G5F
M_&=E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#,*;7-G:60@
M(D%D9"!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("):=2!M96EN96T@2V%L96YD
M97(@:&EN>G5F_&=E;B(*"B,Z(&-O;7!O<V4N<&AP.C4Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T86-H;65N="XB"FUS
M9W-T<B`B7"(E<UPB(&%L<R!!;FAA;F<@:&EN>G5G96;\9W0N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D:71I;VYA;"!H
M96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L
M+"!E;G1E<B!E86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM
M<V=S='(@(B(*(DEN(&1E<B!.86-H<FEC:'1E;F%N<VEC:'0@>G5SY'1Z;&EC
M:"!A;GIU>F5I9V5N9&4@2V]P9F5I;G1RY&=E.B`\96T^(@HB*&]P=&EO;F%L
M+"!J961E;B!%:6YT<F%G(&EN(&5I;F5R(&5I9V5N96X@6F5I;&4@96EN=')A
M9V5N*3PO96T^(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA
M=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("):=7/D='IL:6-H92!)
M;F9O<FUA=&EO;F5N(&OV;FYE;B`E<R!E:6YG97-E:&5N('=E<F1E;BXB"@HC
M.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@IM<V=I9"`B
M061D:71I;VYA;"!I;F9O<FUA=&EO;B!D971A:6QS(@IM<V=S='(@(EIU<^1T
M>FQI8VAE($1E=&%I;&EN9F]R;6%T:6]N96XB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E
M=&%I;',B"FUS9W-T<B`B6G5SY'1Z;&EC:&4@3F%C:')I8VAT96YD971A:6QS
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B6G5SY'1Z;&EC:&4@3F%C:')I8VAT96YD
M971A:6QS(&OV;FYE;B`E<R!A;F=E<V-H875T('=E<F1E;BXB"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I;VYA;"!M
M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T<B`B6G5SY'1Z;&EC:&4@1F5H
M;&5R9&5T86EL<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O
M<B!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(EIU<^1T>FQI
M8VAE($9E:&QE<F1E=&%I;',@:_9N;F5N("5S(&%N9V5S8VAA=70@=V5R9&5N
M+B(*"B,Z(&-O;G1A8W1S+G!H<#HX-2!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C$X,`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS,S<@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4R"FUS9VED
M(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S8G5C:"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S0*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS
M9W-T<B`B061R97-S8OQC:&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$X.0IM<V=I9"`B(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z
M(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B
M"B)L:6YE*3PO96T^(@IM<V=S='(@(B(*(D%D<F5S<V5N(&;\<B!"8V,M2V]P
M:65N(&%L;&5R($YA8VAR:6-H=&5N.B`\96T^*&]P=&EO;F%L+"!J961E($%D
M<F5S<V4@:6X@(@HB96EN97(@96EG96YE;B!:96EL92!E:6YT<F%G96XI/"]E
M;3XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!
M9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W
M(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB061R97-S96XL(&1I92!A;B!D:65S
M92!)9&5N=&ETY'0@9V5B=6YD96X@<VEN9#H@/&5M/BAO<'1I;VYA;"P@:F5D
M92!!9')E<W-E("(*(FEN(&5I;F5R(&5I9V5N96X@6F5I;&4@96EN=')A9V5N
M*3PO96T^(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$R"FUS9VED(")!;&PB"FUS9W-T<B`B
M06QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*
M;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E
M<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE
M.B(*;7-G<W1R("(B"B)!;&QE($YA8VAR:6-H=&5N(&EN(&1E;B!F;VQG96YD
M96X@3W)D;F5R;B!W97)D96X@86QS(&5I;F4@34)/6"U$871E:2`B"B)H97)U
M;G1E<F=E;&%D96XZ(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?
M=')A<V@N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S
M86=E<R!I;B!Y;W5R(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES
M('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB
M06QL92!.86-H<FEC:'1E;B!I;2!/<F1N97(@7"(E<UPB+"!D:64@Y&QT97(@
M86QS("5S(%1A9V4@<VEN9"P@=V5R9&5N("(*(F5N9&?\;'1I9R!G96SV<V-H
M="XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?871T86-H;65N
M='-?;6]N=&AL>2YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L
M9"!L:6YK960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@
M=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R(")!;&QE('9E<FQI;FMT92!!;FCD
M;F=E+"!D:64@Y&QT97(@86QS("5S($UO;F%T92!S:6YD+"!W97)D96X@9V5L
M]G-C:'0N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@
M=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("(B"B)!;&QE(&%L=&5N($]R9&YE
M<B!F_'(@9V5S96YD971E($YA8VAR:6-H=&5N+"!D:64@Y&QT97(@86QS("5S
M($UO;F%T92!S:6YD+"`B"B)W97)D96X@9V5L]G-C:'0N(@H*(SH@86-L+G!H
M<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@<FEG:'1S(&]N(&9O;&1E
M<B!<(B5S7"(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@7"(E<UPB
M+B(*;7-G<W1R("(B"B)!;&QE(%)E8VAT92!V;VX@0F5N=71Z97(@7"(E,B1S
M7"(@86T@3W)D;F5R(%PB)3$D<UPB('=U<F1E;B!E<F9O;&=R96EC:"`B"B)E
M;G1F97)N="XB"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L
M9&5R($-R96%T:6]N/R(*;7-G<W1R(")%<G-T96QL96X@=F]N($]R9&YE<FX@
M97)L875B96X_(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0X
M"FUS9VED(")!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A
M;GD@;6%I;&)O>#\B"FUS9W-T<B`B06YW96YD=6YG('9O;B!&:6QT97)R96=E
M;&X@:6X@86QL96X@3W)D;F5R;B!E<FQA=6)E;C\B"@HC.B!L:6(O34E-12]6
M:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B06QT97)N871I=F4@
M<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B06QT97)N871I=F4@
M3F%C:')I8VAT96YT96EL93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3<R"FUS9VED(")!;'=A>7,B"FUS9W-T<B`B26UM97(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-34W"FUS9VED(")!;'=A>7,@<V%V92!A='1A8VAM
M96YT<R(*;7-G<W1R(")!;FCD;F=E(&EM;65R('-P96EC:&5R;B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HU-3$*;7-G:60@(B(*(D%N(&5R<F]R(&]C8W5R960@
M=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE
M($E-05`@<V5R=F5R("(*(G-A:60Z("(*;7-G<W1R("(B"B)"96EM($5N=&9E
M<FYE;B!D97,@06YH86YG<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@
M365L9'5N9R!D97,@16UA:6PM(@HB4V5R=F5R<SH@(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C0S-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H
M:6QE(&-R96%T:6YG('1H92!N97<@;F]T92XB"FUS9W-T<B`B0F5I;2!!;FQE
M9V5N(&1E<B!N975E;B!.;W1I>B!I<W0@96EN('5N8F5K86YN=&5R($9E:&QE
M<B!A=69G971R971E;BXB"@HC.B!L:6(O365S<V%G92YP:'`Z-#,T"FUS9VED
M(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE
M(&YE=R!T87-K+B(*;7-G<W1R(")"96EM($%N;&5G96X@9&5R(&YE=65N($%U
M9F=A8F4@:7-T(&5I;B!U;F)E:V%N;G1E<B!&96AL97(@875F9V5T<F5T96XN
M(@H*(SH@;65S<V%G92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<P."!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,U"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-@IM
M<V=I9"`B06YS=V5R960B"FUS9W-T<B`B0F5A;G1W;W)T970B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS9VED(")!;G-W97)E9"!M97-S
M86=E<R(*;7-G<W1R(")"96%N='=O<G1E=&4@3F%C:')I8VAT96XB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*;7-G:60@(D%P<&QY($9I
M;'1E<G,B"FUS9W-T<B`B1FEL=&5R<F5G96QN(&%N=V5N9&5N(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`B1FEL=&5R<F5G96QN
M(&%U9B`E<R!A;G=E;F1E;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHS-@IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN
M9R!O;C\B"FUS9W-T<B`B1FEL=&5R<F5G96QN(&)E:6T@06YM96QD96X@86YW
M96YD96X_(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0R"FUS
M9VED(")!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES
M<&QA>65D/R(*;7-G<W1R(")&:6QT97)R96=E;&X@:6UM97(@86YW96YD96XL
M('=E;FX@24Y"3U@@86YG97IE:6=T('=I<F0_(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHQ-`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&1E;&5T92!T:&ES(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX_
M(@IM<V=S='(@(B(*(E-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@9&EE(%-U
M8VAK<FET97)I96X@9OQR(&1I97-E;B!6:7)T=65L;&5N($]R9&YE<B`B"B)L
M]G-C:&5N(&WV8VAT96X_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(*;7-G
M<W1R("(B"B)3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I97-E;B#V9F9E
M;G1L:6-H96X@4V-H;/QS<V5L(&SV<V-H96X@;?9C:'1E;C\B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHX-0IM<V=I9"`B(@HB07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T
M92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I(@IM
M<V=S='(@(B(*(E-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@26AR(%-C:&S\
M<W-E;'!A87(@;/9S8VAE;B!W;VQL96X_("A.24-(5"`B"B)E;7!F;VAL96XA
M*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1O('1H:7,_(@IM<V=S='(@(E-I;F0@4VEE('-I8VAE
M<BP@9&%S<R!3:64@9F]R=&9A:')E;B!M]F-H=&5N/R(*"B,Z(&UE<W-A9V4N
M<&AP.C0P."!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV.`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E
M;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`B4VEN9"!3:64@<VEC:&5R
M+"!D87-S(%-I92!D:65S92!.86-H<FEC:'1E;B!%3D1'W$Q424<@;/9S8VAE
M;B!M]F-H=&5N/R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,SD*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE
M=&4@=&AI<R!A='1A8VAM96YT/R(*;7-G<W1R(")3:6YD(%-I92!S:6-H97(L
M(&1A<W,@4VEE(&1I97-E;B!!;FAA;F<@14Y$1]Q,5$E'(&SV<V-H96X@;?9C
M:'1E;C\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L
M9&5R/R(*;7-G<W1R(")3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE(&1I97-E
M;B!/<F1N97(@;&5E<F5N(&WV8VAT96X_(@H*(SH@;&EB+TE-4"YP:'`Z.34Q
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S
M<&%M(&9O;&1E<C\B"FUS9W-T<B`B4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I
M92!D96X@4W!A;2U/<F1N97(@;&5E<F5N(&WV8VAT96X_(@H*(SH@;&EB+TE-
M4"YP:'`Z.30T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP
M='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(E-I;F0@4VEE('-I8VAE
M<BP@9&%S<R!3:64@9&5N(%!A<&EE<FMO<F(@;&5E<F5N(&WV8VAT96X_(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S
M92!M97-S86=E<S\B"FUS9W-T<B`B4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I
M92!D:65S92!.86-H<FEC:'1E;B!E;F1G_&QT:6<@;/9S8VAE;B!M]F-H=&5N
M/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I
M;FYO8V5N=#\B"FUS9W-T<B`B(@HB4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I
M92!D:65S92!.86-H<FEC:'0@86QS(&ME:6X@4W!A;2!M96QD96X@;?9C:'1E
M;C\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHW-2!T
M96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW-`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@
M<W!A;3\B"FUS9W-T<B`B4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D:65S
M92!.86-H<FEC:'0@86QS(%-P86T@;65L9&5N(&WV8VAT96X_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP-0IM<V=I9"`B07)R:79A;"!4:6UE(@IM
M<V=S='(@(D5I;F=A;F=S>F5I="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,C`*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")!=69S=&5I9V5N9"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S$*;7-G:60@(D%S:R(*;7-G
M<W1R(").86-H9G)A9V5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#<P"FUS9VED(")!='1A8V@@1FEL97,B"FUS9W-T<B`B1&%T96EE
M;B!A;FCD;F=E;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0U,0IM<V=I9"`B071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@
M:V5Y('1O('EO=7(@;65S<V%G93\B"FUS9W-T<B`B(@HB16EN92!+;W!I92!)
M:')E<R#V9F9E;G1L:6-H96X@4$=0+5-C:&S\<W-E;',@86X@26AR92!.86-H
M<FEC:'0@86YHY&YG96X_(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C$Q,0IM<V=I9"`B071T86-H960@1FEL93HB"FUS9W-T<B`B06YG96CD;F=T
M92!$871E:3HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#8R(&QI8B]#;VUP;W-E
M+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB071T86-H960@9FEL
M92!<(B5S7"(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@
M1FEL92!.3U0@871T86-H960N(@IM<V=S='(@(B(*(D1I92!$871E:2!<(B5S
M7"(@:&%T(&1I92!E<FQA=6)T92!'<O;?92!F_'(@06YHY&YG92#\8F5R<V-H
M<FET=&5N+B!$:64@1&%T96D@(@HB=W5R9&4@3DE#2%0@86YG96CD;F=T+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S<*;7-G:60@(D%T=&%C
M:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT
M+B(*;7-G<W1R("(B"B));2!!;FAA;F<@9FEN9&5N(%-I92!E:6YE($%N=V]R
M="!A=68@96EN92!497)M:6YA;F9R86=E+"!D:64@4VEE(&=E<W1E;&QT("(*
M(FAA8F5N+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y."!T96UP;&%T97,O8V]M<&]S
M92]A='1A8VAM96YT<RYJ<SHU-0IM<V=I9"`B071T86-H;65N="(*;7-G<W1R
M(")!;FAA;F<B"@HC.B!A='1A8VAM96YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!='1A8VAM96YT("5S(&1E;&5T960N(@IM<V=S='(@(D%N;&%G
M92`E<R!W=7)D92!G96SV<V-H="XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3$R
M-0IM<V=I9"`B071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R(")!;FAA
M;F=S:6YF;W)M871I;VYE;B(*"B,Z(&-O;7!O<V4N<&AP.C$Q,#4@;&EB+TUE
M<W-A9V4N<&AP.C4Q,PIM<V=I9"`B071T86-H;65N="!S=')I<'!E9#H@3W)I
M9VEN86P@871T86-H;65N="!T>7!E(@IM<V=S='(@(D%N:&%N9R!E;G1F97)N
M=#H@16AE;6%L:6=E<B!!;FAA;F=S='EP(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S0W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0V.`HC.B!L:6(O0V]M<&]S92YP:'`Z,3`Y,PIM<V=I9"`B071T86-H
M;65N=',B"FUS9W-T<B`B06YHY&YG92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV-S@*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")496EL;F5H
M;65R(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*
M;7-G:60@(D%T=&5N=&EO;B(*;7-G<W1R(")!8VAT=6YG(@H*(SH@;&EB+T%U
M=&@O:6UP+G!H<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z($1I92!B
M96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E
M;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C(X"FUS9VED("(B"B)!
M=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A434P@;65S<V%G97,@=VAE
M;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*(F%D9')E<W-B;V]K/R(*;7-G<W1R
M("(B"B)!=71O;6%T:7-C:"!":6QD97(@:6X@2%1-3"U.86-H<FEC:'1E;B!A
M;GIE:6=E;BP@=V5N;B!S:6-H(&1E<B!!8G-E;F1E<B!I;2`B"B)!9')E<W-B
M=6-H(&)E9FEN9&5T/R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C(Y.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM
M<V=S='(@(E9E<F;\9V)A<F4@061R97-S8OQC:&5R.B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E
M(@IM<V=S='(@(D%U9B!!;G1W;W)T('=A<G1E;F0B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*
M;7-G:60@(D)A8U]K('1O("5S(@IM<V=S='(@(E]:=7+\8VL@>G4@)7,B"@HC
M.B!T:')E860N<&AP.C$S-R!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8VL@=&\@)7,B
M"FUS9W-T<B`B6G5R_&-K('IU("5S(@H*(SH@=&AR96%D+G!H<#HQ,S0*;7-G
M:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN9&5X(@IM<V=S
M='(@(EIU<OQC:R!Z=6T@3F%C:')I8VAT96YI;F1E>"(*"B,Z('1H<F5A9"YP
M:'`Z,3,R"FUS9VED(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@
M(EIU<OQC:R!Z=7(@5&AE;65N;&ES=&4B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C4W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")"860@;&]G:6X@;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B1F%L<V-H97(@0F5N=71Z97)N86UE(&]D
M97(@4&%S<W=O<G0N(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!3
M97)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R(")5;F?\;'1I9V4@;V1E<B!F
M96AL97)H869T92!!;F9R86=E+B!397)V97)A;G1W;W)T.B`E<R(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z-3<V"B,L('!H<"UF;W)M870*;7-G:60@(D)A
M9"!R97%U97-T.B`E<RXB"FUS9W-T<B`B56YG_&QT:6=E($%N9G)A9V4Z("5S
M+B(*"B,Z(&UE<W-A9V4N<&AP.C(W,R!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(R,@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N
M:6YC.C(P(&QI8B]396%R8V@N<&AP.C8P,0IM<V=I9"`B0F-C(@IM<V=S='(@
M(D)C8R(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM<V=I
M9"`B0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M
M871I;VX@;65S<V%G92XB"FUS9W-T<B`B(@HB56YT96X@8F5F:6YD970@<VEC
M:"!D97(@475E;&QT97AT(&1E<B!.86-H<FEC:'0@;6ET(&1E<B!3=&%T=7-I
M;F9O<FUA=&EO;BXB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*
M;7-G:60@(D)L86-K;&ES="(*;7-G<W1R(")!=7-S8VAL=7-S;&ES=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")";&]C:R!I;6%G
M97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A
M;&QY(')E<75E<W1E9#\B"FUS9W-T<B`B(@HB2V5I;F4@0FEL9&5R(&EN($A-
M5$PM3F%C:')I8VAT96X@86YZ96EG96XL(&%UWV5R('=E;FX@875S9'+\8VML
M:6-H("(*(F%N9V5F;W)D97)T/R(*"B,Z(&QI8B]396%R8V@N<&AP.C8P.0IM
M<V=I9"`B0F]D>2(*;7-G<W1R(")497AT(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")"96ED97,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@T"FUS9VED(")";W1H($AE861E
M<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B26T@3F%C
M:')I8VAT96YK;W!F('5N9"!I;2!.86-H<FEC:'1E;G1E>'0B"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C4P,0IM<V=I9"`B0U)!32U-1#4@;W(@1$E'15-4
M+4U$-2!R97%U:7)E<R!T:&4@075T:%]305-,('!A8VMA9V4@=&\@8F4@:6YS
M=&%L;&5D+B(*;7-G<W1R("(B"B)&_'(@0U)!32U-1#4@;V1E<B!$24=%4U0M
M340U(&UU<W,@9&%S($%U=&A?4T%33"U086ME="!I;G-T86QL:65R="!S96EN
M+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,`IM<V=I
M9"`B0U]H87)S970B"FUS9W-T<B`B7UIE:6-H96YS871Z(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED(")#86QE;F1A<B(*;7-G
M<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C`Q
M"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E
M<G9E<BXB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@16UA:6PM4V5R=F5R(&MA
M;FX@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N+B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE
M(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M
M($5M86EL+5-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;CH@
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@
M)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT
M("(*(FUA:6QB;W@N(@IM<V=S='(@(B(*(D1A<G-T96QL=6YG(&YI8VAT(&WV
M9VQI8V@@+2!N=7(@)7,@=F]N("5S(%1E:6QE;B!D:65S97(@3F%C:')I8VAT
M(&EM("(*(F%K='5E;&QE;B!/<F1N97(@9V5F=6YD96XN(@H*(SH@9F]L9&5R
M<RYP:'`Z,C<P('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4U
M"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C$@=&5M<&QA=&5S
M+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C$Y"B,Z('1E;7!L871E<R]S;6EM
M92]P87-S<&AR87-E+FEN8SHR,2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z.#8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R
M,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,R"B,Z('1E;7!L871E
M<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C8*;7-G:60@(D-A;F-E;"(*;7-G<W1R
M(")!8F)R96-H96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHV.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S`*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,0IM<V=I9"`B0V%N8V5L
M($UE<W-A9V4B"FUS9W-T<B`B3F%C:')I8VAT('9E<G=E<F9E;B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A
M9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS
M9W-T<B`B5V5N;B!3:64@9&EE<V4@3F%C:')I8VAT('9E<G=E<F9E;BP@9V5H
M="!D97(@26YH86QT(&5N9_QL=&EG('9E<FQO<F5N+B(*"B,Z(&UE<W-A9V4N
M<&AP.C(W,B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC
M.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI8B]396%R
M8V@N<&AP.C4Y-PIM<V=I9"`B0V,B"FUS9W-T<B`B0V,B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I
M;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N
M86)L960@;VX@=&AI<R`B"B)S97)V97(N(@IM<V=S='(@(B(*(E-I92!K]FYN
M96X@:V5I;F4@6F5R=&EF:6MA=&4@:6UP;W)T:65R96XL('=E:6P@9&%S($AO
M8VAL861E;B!V;VX@1&%T96EE;B!A=68@(@HB9&EE<V5N(%-E<G9E<B!N:6-H
M="!M]F=L:6-H(&ES="XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-CDV"FUS9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`B0F5S<')E8VAU;F=S
M;&5I=&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P
M"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BQ&YD97)N(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM
M<V=S='(@(D%L;&4@Q&YD97)N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.CDR"FUS9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S='(@(D]R9&YE<B!W96-H
M<V5L;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3(*;7-G:60@(B(*
M(D-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S
M86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S
M(&%R92!S;W)T960N(@IM<V=S='(@(B(*(L1N9&5R;B!3:64@9&EE($5I;G-T
M96QL=6YG96X@9OQR(&1I92!!;GIE:6=E+"!Z+D(N('=I92!V:65L92!.86-H
M<FEC:'1E;B!P<F\@(@HB4V5I=&4@86YG97IE:6=T('=E<F1E;B!U;F0@=V]N
M86-H(&1I92!.86-H<FEC:'1E;B!S;W)T:65R="!W97)D96X@<V]L;&5N+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B0VAA;F=E(&UA
M:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@(L1N9&5R
M;B!3:64@9&EE($5I;G-T96QL=6YG96X@>G4@26AR96T@16UA:6PM4V5R=F5R
M('5N9"!):')E;B!/<F1N97)N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@
M<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B(@HBQ&YD97)N(%-I
M92!D96X@3F%M96XL(&1I92!%;6%I;&%D<F5S<V4@;V1E<B!D:64@4VEG;F%T
M=7(L(&1I92!D:64@16UP9N1N9V5R("(*(DEH<F5R($5M86EL<R!S96AE;BP@
M=V5N;B!D:65S92!):')E($5M86EL<R!L97-E;B!O9&5R(&1A<F%U9B!A;G=O
M<G1E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$S"FUS9VED(")#
M:&%R86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(D%N>G5Z96EG96YD92!:
M96EC:&5N.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$U
M"FUS9VED(")#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@
M(D]R9&YE<B!A=68@;F5U92!.86-H<FEC:'1E;B#\8F5R<'+\9F5N(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C<U"FUS9VED(")#:&5C:R!?06QL
M+TYO;F4B"FUS9W-T<B`B7T%L;&4O2V5I;F4@875S=^1H;&5N(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C$P('1E;7!L871E<R]F
M971C:&UA:6PO9F5T8VAM86EL+FEN8SHR,0IM<V=I9"`B0VAE8VL@86QL(&UA
M:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S
M='(@(B(*(DUA<FMI97)E;B!3:64@86QL92!%;6%I;'-E<G9E<BP@=F]N(&1E
M;F5N(%-I92!%;6%I;',@:&5R=6YT97)L861E;B!M]F-H=&5N.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*;7-G:60@(D-H96-K('-P96QL:6YG
M(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B4F5C:'1S8VAR
M96EB=6YG('9O<B!D96T@5F5R<V5N9&5N('9O;B!.86-H<FEC:'1E;B#\8F5R
M<'+\9F5N/R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*
M;7-G:60@(D-H;V]S92!!8W1I;VXZ(@IM<V=S='(@(D%K=&EO;B!A=7-WY&AL
M96XZ(@H*(SH@8V]N9FEG+W-E<G9E<G,N<&AP+F1I<W0Z,C`R"FUS9VED(")#
M:&]O<V4@82!M86EL('-E<G9E<CHB"FUS9W-T<B`B5^1H;&5N(%-I92!E:6YE
M;B!%;6%I;"U397)V97(Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,3(S('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$V-`HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,34*;7-G:60@(D-H
M;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT
M.B(*;7-G<W1R(")":71T92!WY&AL96X@4VEE(&%U<R!O9&5R(&5D:71I97)E
M;B!3:64@<F5C:'1S.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,T.0IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@
M=7-E('=H96X@861D:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB5^1H;&5N
M(%-I92!D87,@061R97-S8G5C:"!A=7,L('IU(&1E;2!N975E($%D<F5S<V5N
M(&AI;GIU9V5F_&=T('=E<F1E;B`B"B)S;VQL96XN(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"FUS9VED(")#:&]O<V4@=&AE
M(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD
M:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB5^1H;&5N(%-I92!D:64@4F5I
M:&5N9F]L9V4@9&5R($%D<F5S<V+\8VAE<B!A=7,L(&EN(&1E;F5N(&YA8V@@
M3F%M96X@9V5S=6-H="`B"B)W97)D96X@<V]L;"XB"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T
M('EO=7(@8G)O=W-E<B!C86X@=FEE=RXB"FUS9W-T<B`B(@HB2VQI8VME;B!3
M:64@)7,L('5M(&1I92!":6QD9&%T96D@:6X@96EN($9O<FUA="!U;7IU=V%N
M9&5L;BP@9&%S($EH<B!"<F]W<V5R("(*(F1A<G-T96QL96X@:V%N;B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@:6UA9V4N(@IM<V=S
M='(@(DML:6-K96X@4VEE("5S+"!U;2!D87,@0FEL9"!H97)U;G1E<GIU;&%D
M96XN(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3,R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G92XB"FUS
M9W-T<B`B2VQI8VME;B!3:64@)7,L('5M('IU("5S+59E<G=A;'1U;F<@>G4@
M9V5L86YG96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W($A434P@8V]N
M=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B2VQI8VME;B!3
M:64@)7,L('5M(&1E;B!(5$U,+4EN:&%L="!I;B!E:6YE;2!N975E;B!&96YS
M=&5R(&%N>G5Z96EG96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,38T"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@
M82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B2VQI8VME;B!3
M:64@)7,L('5M(&5I;F4@5F]R<V-H874@9&EE<V5S($)I;&1E<R!A;GIU>F5I
M9V5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE
M;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(DML:6-K96X@4VEE
M("5S+"!U;2!D96X@06YH86YG(&EN(&5I;F5M(&YE=65N($9E;G-T97(@86YZ
M=7IE:6=E;BXB"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU
M;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM
M<V=S='(@(B(*(DML:6-K96X@4VEE("5S+"!U;2!D:65S96X@;75L=&EP87)T
M+W)E;&%T960@3F%C:')I8VAT96YT96EL(&EN(&5I;F5M(&YE=65N("(*(D9E
M;G-T97(@86YZ=7IE:6=E;BXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP
M:'`Z.3@*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S(@IM
M<V=S='(@(DAI97(@:VQI8VME;BP@=6T@0FEL9&5R(&%N>G5Z96EG96XB"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*;7-G:60@
M(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O
M:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*
M;7-G<W1R("(B"B)+;&EC:V5N(%-I92!A=68@96EN97,@9&5R(&%U<V=E=^1H
M;'1E;B!!9')E<W-B_&-H97(@=6YD(&UA<FMI97)E;B!3:64@86QL92`B"B)&
M96QD97(L(&1I92!D=7)C:'-U8VAT('=E<F1E;B!S;VQL96XN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<P"FUS9VED(")#;&EC:R!T;R!3879E
M(%!'4"!0=6)L:6,@2V5Y(&EN('EO=7(@061D<F5S<R!B;V]K(@IM<V=S='(@
M(B(*(DAI97(@:VQI8VME;BP@=6T@9&5N(/9F9F5N=&QI8VAE;B!01U`M4V-H
M;/QS<V5L(&EN($EH<F5M($%D<F5S<V)U8V@@>G4@(@HB<W!E:6-H97)N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@
M)7,@:6X@>6]U<B!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@HB2&EE<B!K;&EC
M:V5N+"!U;2!D87,@4R]-24U%+5IE<G1I9FEK870@=F]N("5S(&EN($EH<F5M
M($%D<F5S<V)U8V@@>G4@(@HB<W!E:6-H97)N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDS.0IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@
M=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G
M<W1R("(B"B)+;&EC:R!A=68@9&EE($%D<F5S<V4@]F9F;F5T($9E;G-T97(@
M>G5M($5R<W1E;&QE;B!E:6YE<B!N975E;B!.86-H<FEC:'0@86X@(@HB9&5N
M($%B<V5N9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,`IM<V=I
M9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S
M86=E('1O(&)E(')E860B"FUS9W-T<B`B2VQI8VL@875F(&1I92!!9')E<W-E
M(/9F9FYE="!D:64@3F%C:')I8VAT('IU;2!,97-E;B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR.`IM<V=I9"`B0VQO<V4B"FUS
M9W-T<B`B4V-H;&EEWV5N(@H*(SH@8V]M<&]S92YP:'`Z-#$X"FUS9VED(")#
M;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R(")$:65S97,@1F5N<W1E<B!S8VAL
M:67?96XB"@HC.B!F;VQD97)S+G!H<#HT,3`*;7-G:60@(D-L;W-E9"!&;VQD
M97(B"FUS9W-T<B`B1V5S8VAL;W-S96YE<B!/<F1N97(B"@HC.B!F;VQD97)S
M+G!H<#HT,S`*;7-G:60@(D-O;&QA<'-E(@IM<V=S='(@(E-C:&QI9=]E;B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0P"FUS9VED(")#
M;VQL87!S92!!;&PB"FUS9W-T<B`B06QL92!S7V-H;&EEWV5N(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-#`*;7-G:60@(D-O;&QA<'-E
M($%L;"!&;VQD97)S(@IM<V=S='(@(D%L;&4@3W)D;F5R('-C:&QI9=]E;B(*
M"B,Z(&9O;&1E<G,N<&AP.C0S,`IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM
M<V=S='(@(D]R9&YE<B!S8VAL:67?96XB"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC871O<CH@(@IM
M<V=S='(@(D9A<F)M87)K:65R=6YG.B`B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DMO;6UE;G1A<B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C(*;7-G:60@(D-O;7!L
M971E9"(*;7-G<W1R(")%<FQE9&EG="(*"B,Z(&-O;7!O<V4N<&AP.C0Q-PIM
M<V=I9"`B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B"FUS9W-T<B`B5V5I=&5R
M92!.86-H<FEC:'0@=F5R9F%S<V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0S-`IM<V=I9"`B0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E
M('=I;F1O=S\B"FUS9W-T<B`B3F5U92!.86-H<FEC:'1E;B!I;B!S97!A<F%T
M96T@1F5N<W1E<B!V97)F87-S96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T,PIM<V=I9"`B(@HB0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A4
M34P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE("(*
M(F9E871U<F4I/R(*;7-G<W1R("(B"B).86-H<FEC:'1E;B!S=&%N9&%R9&WD
MWVEG(&UI="!E:6YE;2!765-)5UE'+45D:71O<B!E<G-T96QL96X@*&9A;&QS
M(&1E<B`B"B)"<F]W<V5R(&1I97-E;B!U;G1E<G-T_'1Z="D_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE
M<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S='(@(DQE9V5N(%-I92!F97-T
M+"!W:64@3F%C:')I8VAT96X@86YG97IE:6=T('=E<F1E;BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D-O;F9I9W5R92!M86EL('!R
M979I97<@;W!T:6]N<RXB"FUS9W-T<B`BQ&YD97)N(%-I92!D:64@16EN<W1E
M;&QU;F=E;B!F_'(@9&EE($YA8VAR:6-H=&5N=F]R<V-H874N(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G:60@(D-O;FYE8W1I;VX@9')O<'!E
M9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@24U!
M4"U397)V97(@=6YT97)B<F]C:&5N+B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,C,T"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F86EL960B
M"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@4V5R=F5R(&9E:&QG97-C:&QA9V5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B
M4$=0+55N=&5R<W3\='IU;F<@9OQR("5S(&MO;F9I9W5R:65R96XN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYT<F]L(%,O34E-12!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B4R]-
M24U%+55N=&5R<W3\='IU;F<@9OQR("5S(&MO;F9I9W5R:65R96XN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM<V=I9"`B0V]N=')O;"!O<'1I
M;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RXB"FUS9W-T<B`B
M3F%C:')I8VAT96YS=6-H92!K;VYF:6=U<FEE<F5N+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M
M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T
M;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB
M3&5G96X@4VEE(&9E<W0L('=I92!O9G0@875F(&YE=64@3F%C:')I8VAT96X@
M_&)E<G#\9G0@=V5R9&5N('-O;&PL('5N9"!O8B`B"B)3:64@_&)E<B!N975E
M($YA8VAR:6-H=&5N(&)E;F%C:')I8VAT:6=T('=E<F1E;B!W;VQL96XN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W-`IM<V=I9"`B0V]N=F5R="!T
M97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R
M(")497AT+45M;W1I8V]N<R!I;B!G<F%F:7-C:&4@=6UW86YD96QN/R(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM<V=I9"`B0V]P>2(*;7-G
M<W1R(")?2V]P:65R92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU
M,0IM<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T<B`B2V]P:65R96X@;F%C
M:"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHV,PIM<V=I
M9"`B0V]R<F5C="(*;7-G<W1R(")+;W)R:6=I97)E(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E
M>'0B"FUS9W-T<B`B2V]R<FEG:65R=&5R(%1E>'0B"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C,X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8V]M<&QE=&4@<F5Q=65S="X@4F5A<V]N($=I=F5N.B`E<R(*;7-G<W1R(")!
M;F9R86=E(&MO;FYT92!N:6-H="!A8F=E<V-H;&]S<V5N('=E<F1E;BX@06YG
M96=E8F5N97(@1W)U;F0Z("5S(@H*(SH@871T86-H;65N="YP:'`Z-3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A
M8VME;F0Z("5S(@IM<V=S='(@(D1A<R!61E,M0F%C:V5N9"!K;VYN=&4@;FEC
M:'0@875F9V5R=69E;B!W97)D96XZ("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C8W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&UE
M<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B
M3F%C:')I8VAT96X@:V]N;G1E;B!N:6-H="!A=7,@)7,@9V5L]G-C:'0@=V5R
M9&5N.B`E<R(*"B,Z(&QI8B]397-S:6]N+G!H<#HS,S,*;7-G:60@(D-O=6QD
M(&YO="!E>&5C=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@
M(D1I92!787)T=6YG<V%U9F=A8F5N(&MO;FYT96X@;FEC:'0@9'5R8VAG96;\
M:')T('=E<F1E;BXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-30*
M;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F
M<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*(D1I92!A
M=7-G97?D:&QT92!$871E:2!K;VYN=&4@;FEC:'0@875S(&1E;2!-4RU43D5&
M+4%N:&%N9R!G96QE<V5N('=E<F1E;BXB"@HC.B!L:6(O34E-12]6:65W97(O
M>FEP+G!H<#HU.`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E
M<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H:79E+B(*;7-G<W1R(")$:64@
M875S9V5WY&AL=&4@1&%T96D@:V]N;G1E(&YI8VAT(&%U<R!D96T@6DE0+4%R
M8VAI=B!G96QE<V5N('=E<F1E;BXB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!S96-U
M<F4@8V]N;F5C=&EO;B!T;R!T:&4@24U!4"!S97)V97(N("5S(#H@)7,N(@IM
M<V=S='(@(B(*(E-I8VAE<F4@5F5R8FEN9'5N9R!Z=6T@24U!4"U397)V97(@
M:V%N;B!N:6-H="!H97)G97-T96QL="!W97)D96XN("5S(#H@)7,N(@H*(SH@
M;&EB+U-E<W-I;VXN<&AP.C(X,`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R+B(*;7-G
M<W1R("(B"B)$:64@3F%M97-P86-E+4EN9F]R;6%T:6]N96X@:V]N;G1E;B!N
M:6-H="!V;VT@24U!4"U397)V97(@875S9V5L97-E;B!W97)D96XN(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E<R]A
M8VPO86-L+FEN8SHS.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q"FUS
M9VED(")#<F5A=&4B"FUS9W-T<B`B17)S=&5L;&5N(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E<B(*
M;7-G<W1R(")/<F1N97(@97)S=&5L;&5N(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$S-PIM<V=I9"`B0W)E871E($ME>7,B"FUS9W-T<B`B4V-H;/QS
M<V5L(&5R<W1E;&QE;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N
M=%]S96QE8W0N:6YC.C(V"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*
M;7-G<W1R(")%:6X@;F5U97,@2V]N=&\@86YL96=E;B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A
M;7-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E
M<B(*;7-G<W1R(")%:6YE;B!N975E;B!3<&%M+4]R9&YE<B!A;FQE9V5N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA
M=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A
M(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(D5I;F5N(&YE=65N($]R9&YE
M<B!F_'(@16YT=_QR9F4@86YL96=E;B(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL
M<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@;F5W('-E;G0@;6%I;"!F
M;VQD97(B"FUS9W-T<B`B16EN96X@;F5U96X@3W)D;F5R(&;\<B!G97-E;F1E
M=&4@3F%C:')I8VAT96X@86YL96=E;B(*"B,Z('1E;7!L871E<R]P<F5F<R]T
M<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T
M+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*;7-G
M<W1R(")%:6YE;B!N975E;B!/<F1N97(@9OQR(&1E;B!087!I97)K;W)B(&%N
M;&5G96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B
M"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC
M;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE
M=&4@<W!A;2XB"FUS9W-T<B`B(@HB3&5G96X@4VEE($9I;'1E<G)E9V5L;B!A
M;BP@=6T@26AR92!E:6YG96AE;F1E;B!.86-H<FEC:'1E;B!Z=2!O<F=A;FES
M:65R96XL("(*(FEN($]R9&YE<B!Z=2!S;W)T:65R96X@=6YD(%-P86T@>G4@
M;/9S8VAE;BXB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,30*;7-G:60@(D-R96%T92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R(").975E
M(%9O<FQA9V4@86YL96=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-#D*;7-G:60@(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E
M<RXB"FUS9W-T<B`B17)S=&5L;&5N(%-I92!&;W)M871V;W)L86=E;B!U;F0@
M4W1A;F1A<F1A;G1W;W)T96XN(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S
M(@IM<V=S='(@(D%K='5E;&QE(%)E8VAT92!V;VX@)7,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@
M9F]R(&9E=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T
M<B`B(@HB3&5G96X@4VEE(&1I92!+;VYT96X@9F5S="P@=F]N(&1E;F5N($5M
M86EL<R!E:6YG97-A;6UE;'0@=V5R9&5N('-O;&QE;BXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D-U<W1O;6EZ92!H;W<@>6]U('-E
M;F0@;6%I;"XB"FUS9W-T<B`B3&5G96X@4VEE(&9E<W0L('=I92!.86-H<FEC
M:'1E;B!V97)S96YD970@=V5R9&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*(DQE9V5N(%-I
M92!F97-T+"!W96QC:&4@075F9V%B96X@;F%C:"!D97(@06YM96QD=6YG(&)E
M:2`E<R!E<FQE9&EG="!W97)D96X@(@HB<V]L;&5N+B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*;7-G:60@(D1A=%]E
M(@IM<V=S='(@(D1A=%]U;2(*"B,Z(&UE<W-A9V4N<&AP.C(V.2!T:')E860N
M<&AP.C$U,PIM<V=I9"`B1&%T92(*;7-G<W1R(")$871U;2(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-3`*;7-G:60@(D1E8VQI;F5D(@IM<V=S
M='(@(D%B9V5L96AN="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-C0*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B06)G96QE:&YT.B`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,W"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(E-T86YD87)D(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S
M96%R8VAS96QE8W0N:6YC.C(Q"FUS9VED(")$969A=6QT(%-E87)C:"!&:65L
M9"(*;7-G<W1R(")3=&%N9&%R9'-U8VAF96QD(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ,@IM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA
M.B(*;7-G<W1R(")3;W)T:65R<F5I:&5N9F]L9V4Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR,@IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C
M=&EO;CHB"FUS9W-T<B`B4V]R=&EE<G)I8VAT=6YG.B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW-3@*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R
M(")$96QE9VEE<G0B"@HC.B!F;VQD97)S+G!H<#HT,#`@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS9VED
M(")$96QE=&4B"FUS9W-T<B`B3/9S8VAE;B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@
M(M9F9F5N=&QI8VAE;B!38VAL_'-S96P@)7,@;/9S8VAE;B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C@U"FUS9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(D%K='5E
M;&QE;B!38VAL_'-S96P@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.CD*;7-G:60@(D1E;&5T92!&;VQD97(H<RDB"FUS9W-T
M<B`B3W)D;F5R(&SV<V-H96XB"@HC.B!F;VQD97)S+G!H<#HR-S$*;7-G:60@
M(D1E;&5T92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(D%U<V=E=^1H;'1E
M($]R9&YE<B!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C0R"FUS9VED(")$96QE=&4@4W1A=&EO;F5R>2(*;7-G<W1R(")6
M;W)L86=E(&SV<V-H96XB"@HC.B!F;VQD97)S+G!H<#HT,#`*;7-G:60@(D1E
M;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")6:7)T=65L;&5N($]R9&YE
M<B!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD97(@
M1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B5FER='5E;&QE;B!/<F1N97(@
M)7,@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHT,PIM<V=I9"`B1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO
M=&4@<V5R=F5R/R(*;7-G<W1R(")6;VT@4V5R=F5R(&AE<G5N=&5R9V5L861E
M;F4@3F%C:')I8VAT96X@;/9S8VAE;C\B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C$Y"FUS9VED(")$96QE=&4@9G)O;2!M>2!C86QE;F1A<B(*
M;7-G<W1R(")!=7,@;65I;F5M($MA;&5N9&5R(&5N=&9E<FYE;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(D1E;&5T92!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T
M<B`B06QT92!V97)L:6YK=&4@06YHY&YG92!A;2!-;VYA='-B96=I;FX@;/9S
M8VAE;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4P"FUS9VED(")$
M96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M
M;VYT:#\B"FUS9W-T<B`B06QT92!/<F1N97(@9OQR(&=E<V5N9&5T92!.86-H
M<FEC:'1E;B!A;2!-;VYA='-B96=I;FX@;/9S8VAE;C\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C`U"FUS9VED(")$96QE=&4@<W!A;2!M97-S86=E
M<R(*;7-G<W1R(")3<&%M+4YA8VAR:6-H=&5N(&SV<V-H96XB"@HC.B!M97-S
M86=E+G!H<#HU,#8@;6%I;&)O>"YP:'`Z-S,T('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,C`*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHS."!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C@*;7-G:60@(D1E
M;&5T960B"FUS9W-T<B`B1V5L]G-C:'0B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@
M(D=E;/9S8VAT92!.86-H<FEC:'1E;B(*"B,Z(&-O;7!O<V4N<&AP.C4W,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB
M)7-<(BXB"FUS9W-T<B`B1&5R($%N:&%N9R!<(B5S7"(@=W5R9&4@9V5L]G-C
M:'0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE
M=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S(@IM<V=S='(@(DYA8VAR:6-H=&5N
M(&SV<V-H96X@=6YD('9E<G-C:&EE8F5N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4X-PIM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(D%N
M9G)A9V4@86)L96AN96XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-30R"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;B(*;7-G<W1R(")!;F9R86=E(&;\<B!&<F5I+T=E8G5C:'0M26YF;W)M
M871I;VYE;B!A8FQE:&YE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,C$*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B06)S=&5I9V5N9"(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR,2!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C8V"FUS9VED(")$97-C<FEP=&EO;B(*;7-G
M<W1R(")"97-C:')E:6)U;F<B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C(W('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D1E=&%I;',B"FUS9W-T
M<B`B1&5T86EL<R(*"B,Z(&-O;7!O<V4N<&AP.C4X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$:60@;F]T(&%T=&%C:"!<(B5S7"(@87,@=&AE(&9I;&4@=V%S
M(&5M<'1Y+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@;FEC:'0@86YG96CD;F=T
M+"!W96EL(&1I92!$871E:2!L965R('=A<BXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C8U"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B"FUS9W-T<B`B
M4VEG;F%T=7)E;B!A8F)L96YD96X_(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHR,S8*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B06YZ
M96EG92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-SD*;7-G:60@(D1I
M<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S86=E/R(*
M;7-G<W1R(")"97-TY'1I9W5N9R!N86-H(&1E;2!697)S96YD96X@=F]N($YA
M8VAR:6-H=&5N(&%N>F5I9V5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.#,*;7-G:60@(D1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S
M='(@(D5I;F=E8F5T=&5T(&EM($YA8VAR:6-H=&5N=&5X="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#$*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO
M=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\B"FUS9W-T<B`B075F(&YE=64@3F%C
M:')I8VAT96X@9'5R8V@@4&]P=7`M1F5N<W1E<B!H:6YW96ES96X_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T-PIM<V=I9"`B1&ES<&QA>2!T:&4@
M7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B
M7")3<&%M($SV<V-H96Y<(BU%:6YT<F%G(&EN(&1E<B!-96[\>F5I;&4@86YZ
M96EG96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S.0IM<V=I9"`B
M1&ES<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B
M87(_(@IM<V=S='(@(EPB4&%P:65R:V]R8B!L965R96Y<(BU%:6YT<F%G(&EN
M(&1E<B!-96[\>F5I;&4@86YZ96EG96X_(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O871T86-H;65N=',N:6YC.C$Q"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G
M<W1R(")%:6YB:6YD=6YG(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C(V"FUS9VED(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`B5')I9F9T($Y)
M0TA4('IU(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*
M;7-G:60@(D1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM
M<V=S='(@(D]R9&YE<B!N:6-H="!A=68@;F5U92!.86-H<FEC:'1E;B#\8F5R
M<'+\9F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,0IM<V=I9"`B
M1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM
M<V=S='(@(DME:6X@5F5R=V5I<R!I;B!D97(@5F]N.B!3<&%L=&4@97)Z975G
M96XB"@HC.B!L:6(O24U0+G!H<#HQ,#4U"FUS9VED(")$;R!Y;W4@=V%N="!T
M;R!O<&5N('1H870@9F]L9&5R/R(*;7-G<W1R(")-]F-H=&5N(%-I92!D:65S
M96X@3W)D;F5R(/9F9FYE;C\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(S,0IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+B(*;7-G<W1R(").;V-H(&ME:6YE;B!:=6=A;F<_($AI97(@86YM96QD96XN
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R-@IM<V=I
M9"`B1&]N92(*;7-G<W1R(")&97)T:6<B"@HC.B!L:6(O34E-12]#;VYT96YT
M<RYP:'`Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(&EN
M("YZ:7`@1F]R;6%T(@IM<V=S='(@(B5S(&%L<R!:25`M1&%T96D@:&5R=6YT
M97)L861E;B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R
M"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL
M92DB"FUS9W-T<B`B06QL92!!;FCD;F=E("AA;',@6DE0+41A=&5I*2!H97)U
M;G1E<FQA9&5N(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,C`*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R(")/<F1N97(@
M:&5R=6YT97)L861E;B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C(Q"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T
M72(*;7-G<W1R(")/<F1N97(@:&5R=6YT97)L861E;B`H86QS(%I)4"U$871E
M:2DB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$V"FUS9VED(")$;W=N
M;&]A9"!I;B`N>FEP($9O<FUA="(*;7-G<W1R(")!;',@6DE0+41A=&5I(&AE
M<G5N=&5R;&%D96XB"@HC.B!M97-S86=E+G!H<#HU,#0@;6%I;&)O>"YP:'`Z
M-S$S('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3$*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C0Q"B,Z('1E;7!L871E<R]M86EL8F]X+VQE
M9V5N9"YI;F,Z.0IM<V=I9"`B1')A9G0B"FUS9W-T<B`B16YT=W5R9B(*"B,Z
M(&9O;&1E<G,N<&AP.C,W,PIM<V=I9"`B1')A9G0@9F]L9&5R(@IM<V=S='(@
M(D5N='?\<F9E+4]R9&YE<B(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S
M96QE8W0N:6YC.C(S"FUS9VED(")$<F%F=',@9F]L9&5R.B(*;7-G<W1R(")%
M;G1W_')F92U/<F1N97(Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P
M.`IM<V=I9"`B12UM86EL($%D9')E<W,B"FUS9W-T<B`B16UA:6QA9')E<W-E
M(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,Q-@IM<V=I9"`B14Y$(@IM<V=S='(@
M(D5.1$4B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-`IM<V=I
M9"`B15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D
M+B(*;7-G<W1R(")&14A,15(Z($EH<F4@3F%C:')I8VAT(&MO;FYT92!N:6-H
M="!V97)S8VAI8VMT('=E<F1E;BXB"@HC.B!F;VQD97)S+G!H<#HT,#$@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM
M<V=S='(@(D)E87)B96ET96XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,3@*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(D%U<W-C
M:&QU<W-L:7-T92!B96%R8F5I=&5N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C$S"FUS9VED(")%9&ET($9I;'1E<G,B"FUS9W-T<B`B1FEL
M=&5R(&)E87)B96ET96XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI
M;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ-@IM<V=I9"`B
M161I="!396%R8V@@475E<GDB"FUS9W-T<B`B4W5C:&%N9G)A9V4@8F5A<F)E
M:71E;B(*"B,Z(&9O;&1E<G,N<&AP.C0P,2!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z,3<*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T
M<B`B5FER='5E;&QE;B!/<F1N97(@8F5A<F)E:71E;B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E<R(*;7-G<W1R
M(")6:7)T=65L;&5N($]R9&YE<B`E<R!B96%R8F5I=&5N(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES
M="(*;7-G<W1R(")0;W-I=&EV;&ES=&4@8F5A<F)E:71E;B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!Y;W5R(&)L
M86-K;&ES="(*;7-G<W1R(")!=7-S8VAL=7-S;&ES=&4@8F5A<F)E:71E;B(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM<V=I9"`B161I
M="!Y;W5R(&9I;'1E<B!R=6QE<R(*;7-G<W1R(")&:6QT97)R96=E;&X@8F5A
M<F)E:71E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-3`*;7-G:60@
M(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA
M:6P@86-C;W5N=',N(@IM<V=S='(@(D5I;G-T96QL=6YG96X@9OQR(&1E;B!:
M=6=R:69F(&%U9B!A;F1E<F4@2V]N=&5N(&)E87)B96ET96XN(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET('EO=7(@
M=VAI=&5L:7-T(@IM<V=S='(@(E!O<VET:79L:7-T92!B96%R8F5I=&5N(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,SD*;7-G:60@
M(D5M86EL($%D9')E<W,B"FUS9W-T<B`B16UA:6QA9')E<W-E(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;7!T:65D
M(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R(")!;&QE($YA8VAR:6-H
M=&5N(&%U<R`E<R!G96SV<V-H="XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C8Y
M"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M(%9I<G1U86P@5')A
M<V@@1F]L9&5R+B(*;7-G<W1R(")!;&QE($YA8VAR:6-H=&5N(&%U<R!D96T@
M5FER='5E;&QE;B!087!I97)K;W)B(&=E;/9S8VAT+B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H
M<RDB"FUS9W-T<B`B3W)D;F5R(&QE97)E;B(*"B,Z(&9O;&1E<G,N<&AP.C(W
M,@IM<V=I9"`B16UP='D@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R(")!=7-G
M97?D:&QT92!/<F1N97(@;&5E<F5N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y(%1R87-H(&9O;&1E<B(*;7-G
M<W1R(")087!I97)K;W)B(&QE97)E;B(*"B,Z(&QI8B])35`N<&AP.CDU,0IM
M<V=I9"`B16UP='D@7U-P86TB"FUS9W-T<B`B4W!A;2!L]G-C:&5N(@H*(SH@
M;&EB+TE-4"YP:'`Z.30T"FUS9VED(")%;7!T>2!?5')A<V@B"FUS9W-T<B`B
M4&%P7VEE<FMO<F(@;&5E<F5N(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L
M92!01U`@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B4$=0+49U;FMT:6]N96X@
M86MT:79I97)E;C\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$@
M=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE
M(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")3+TU)344M1G5N:W1I
M;VYE;B!A:W1I=FEE<F5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,#`*;7-G:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G<W1R(").
M86-H<FEC:'1E;G9O<G-C:&%U(&%K=&EV:65R96X_(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,W"FUS9VED(")%;F-R7WEP=&EO;B!/
M<'1I;VYS(@IM<V=S='(@(E]697)S8VAL_'-S96QU;F=S+45I;G-T96QL=6YG
M96XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$X"FUS9VED
M(")%;F-R>7!T960B"FUS9W-T<B`B5F5R<V-H;/QS<V5L="(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU,38@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4Q.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4Q(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV-3,*;7-G:60@(D5N9"(*;7-G<W1R(")%
M;F1E(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,Y-0IM<V=I9"`B16YD(&9O<G=A
M<F1E9"!M97-S86=E(@IM<V=S='(@(D5N9&4@9&5R('=E:71E<F=E;&5I=&5T
M96X@3F%C:')I8VAT(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,U,@IM<V=I9"`B
M16YD(&UE<W-A9V4B"FUS9W-T<B`B16YD92!D97(@3F%C:')I8VAT(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@
M;65S<V%G92!F<F]M("5S(@IM<V=S='(@(D5N9&4@9&5R($YA8VAR:6-H="!V
M;VX@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B16YT97(@4&%S<W!H<F%S92(*
M;7-G<W1R(")087-S=V]R="!E:6YG96)E;B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S<&%M<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@
M>6]U<B!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B1V5B96X@4VEE(&5I;F5N
M($YA;65N(&;\<B!):')E;B!N975E;B!3<&%M+4]R9&YE<B!E:6XB"@HC.B!T
M96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHY"FUS9VED(")%;G1E
M<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R
M(")'96)E;B!3:64@96EN96X@3F%M96X@9OQR($EH<F5N(&YE=65N($5N='?\
M<F9E+4]R9&YE<B!E:6XB"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS
M96QE8W0N:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("(B"B)'96)E;B!3:64@96EN
M96X@3F%M96X@9OQR(&1E;B!/<F1N97(@86XL(&EN(&1E;2!):')E(&=E<V5N
M9&5T96X@3F%C:')I8VAT96X@(@HB9V5S<&5I8VAE<G0@=V5R9&5N('-O;&QE
M;B(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z.0IM<V=I
M9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<B(*
M;7-G<W1R(")'96)E;B!3:64@96EN96X@3F%M96X@9OQR($EH<F5N(&YE=65N
M(%PB4&%P:65R:V]R8EPB+4]R9&YE<B!E:6XB"@HC.B!L:6(O4V5A<F-H+G!H
M<#HV,3,*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(D=E<V%M=&4@
M3F%C:')I8VAT(@H*(SH@;65S<V%G92YP:'`Z,3DT(&-O;7!O<V4N<&AP.C$Q
M-S(@=&AR96%D+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!<
M(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B
M;V]K(@IM<V=S='(@(D1E<B!%:6YT<F%G(%PB)7-<(B!W=7)D92!E<F9O;&=R
M96EC:"!D96T@061R97-S8G5C:"!H:6YZ=6=E9OQG="(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@Q(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C,Y,`HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HW,B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R
M<F]R(@IM<V=S='(@(D9E:&QE<B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M-#,Q(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S(#H@)7,N
M(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M($E-05`M4V5R=F5R(&MA;FX@;FEC
M:'0@:&5R9V5S=&5L;'0@=V5R9&5N+B`E<R`Z("5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HS,3`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY
M.B`E<RXB"FUS9W-T<B`B1F5H;&5R(&)E:6T@5F5R<V5N9&5N(&1E<B!!;G1W
M;W)T.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#(*;7-G
M:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")497)M
M:6X@97)F;VQG<F5I8V@@9V5L]G-C:'0N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<W,0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")!
M;&QE(#$U($UI;G5T96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8X
M"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D%L;&4@,S`@4V5K
M=6YD96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<P"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B06QL92`U($UI;G5T96XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<R"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B06QL92!H86QB92!3='5N9&4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S8Y"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B
M06QL92`V,"!396MU;F1E;B(*"B,Z(&9O;&1E<G,N<&AP.C0S.`IM<V=I9"`B
M17AP86YD(@IM<V=S='(@(E9E<F=R]M]E<FXB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R
M(")!;&QE(/9?9F9N96XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHS.0IM<V=I9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(D%L
M;&4@3W)D;F5R(/9F9FYE;B(*"B,Z(&9O;&1E<G,N<&AP.C0S.`IM<V=I9"`B
M17AP86YD($9O;&1E<B(*;7-G<W1R(")/<F1N97(@]F9F;F5N(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,X('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S
M='(@(DYA;65N('-U8VAE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#4R"FUS9VED(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W
M(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(B(*
M(DYA;65N(&)E:6T@17)S=&5L;&5N(&YE=65R($YA8VAR:6-H=&5N(&%U=&]M
M871I<V-H(&EM($AI;G1E<F=R=6YD("(*(G9E<G9O;&QS=.1N9&EG96X_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B17AP86YD('1H
M92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R
M<R!V:65W/R(*;7-G<W1R("));B!D97(@3W)D;F5R86YS:6-H="!A;&QE($]R
M9&YE<B#V9F9N96X_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,30R('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y,@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#,@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E7V5X<&%N9"YJ<SHT.0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@
M(E-U8VAE(@H*(SH@;&EB+TE-4"YP:'`Z.38R(&QI8B])35`N<&AP.CDV-`IM
M<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T<B`B3F%C:')I8VAT96X@<V%M;65L
M;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED(")&971C:"!-86EL(@IM
M<V=S='(@(DYA8VAR:6-H=&5N('-A;6UE;&XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#4X"FUS9VED(")&971C:"!-86EL(&EN(&$@<V5P87)A=&4@
M=VEN9&]W/R(*;7-G<W1R(").86-H<FEC:'1E;B!I;B!E:6YE;2!N975E;B!&
M96YS=&5R(&5I;G-A;6UE;&X_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C0V"FUS9VED(")&971C:"!M97-S86=E<R!U<&]N(&QO9V=I
M;F<@;VX_(@IM<V=S='(@(DYA8VAR:6-H=&5N(&)E:6T@06YM96QD96X@96EN
M<V%M;65L;C\B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S(@IM<V=S
M='(@(B5D($YA8VAR:6-H=&5N('9O;B`E<R!E:6YG97-A;6UE;'0N(@H*(SH@
M;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L('!H<"UF;W)M870*;7-G:60@(D9E
M=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B,2!.86-H<FEC:'0@
M=F]N("5S(&5I;F=E<V%M;65L="XB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR
M.#<@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y(&QI8B]&971C:&UA:6PN<&AP.C(Y
M,0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B3F%C:')I8VAT96X@<V%M
M;65L;CH@(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDS"FUS9VED(")&971C
M:&UA:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B3F%C:')I8VAT96X@
M<V%M;65L;CH@4VEE(&AA8F5N(&ME:6YE(&YE=64@3F%C:')I8VAT96XN(@H*
M(SH@;&EB+TE-4"YP:'`Z.38X"FUS9VED(")&:5]L=&5R<R(*;7-G<W1R(")?
M1FEL=&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DT
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C0P"FUS9VED(")&
M:6QE(@IM<V=S='(@(D1A=&5I(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C,Q"FUS9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(")&:6QT
M97(M16EN<W1E;&QU;F=E;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHY"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`B1FEL=&5R
M+45I;G-T96QL=6YG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@X
M"FUS9VED(")&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_
M(@IM<V=S='(@(DYA8VAR:6-H=&5N(&YA8V@@=6YE<G?\;G-C:'1E;B!);FAA
M;'1E;B!F:6QT97)N/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV
M92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N
M('1H:7,@<WES=&5M+B(*;7-G<W1R(")$:64@1FEL=&5R+55N=&5R<W3\='IU
M;F<@=W5R9&4@875F(&1I97-E;2!3>7-T96T@9&5A:W1I=FEE<G0N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R(")&:6QT97(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N
M:6YC.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C=&EV92(*;7-G<W1R(")&:6QT
M97(@<VEN9"!.24-(5"!A:W1I=FEE<G0B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N
M="!P86=E(@IM<V=S='(@(D9I;'1E<CH@)7,M5F5R=V%L='5N9R(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS9VED(")&:6YD
M(@IM<V=S='(@(E-U8VAE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y
M-`IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E(@IM<V=S='(@(D5R<W1E($]R
M9&YE<G-E:71E(@H*(SH@;6%I;&)O>"YP:'`Z,S,P"FUS9VED(")&:7)S="!0
M86=E(@IM<V=S='(@(D5R<W1E(%-E:71E(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C(Q"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R(")?5V5I=&5R
M;&5I=&5N(@H*(SH@9F]L9&5R<RYP:'`Z,C4R('1E;7!L871E<R]F;VQD97)S
M+V9O;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G:60@(D9O;&1E<B!!8W1I;VYS
M("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(D]R9&YE<F%K=&EO;F5N("T@0F5S
M=.1T:6=U;F<B"@HC.B!F;VQD97)S+G!H<#HR.#D@=&5M<&QA=&5S+V9O;&1E
M<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S
M96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L
M96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R(")/
M<F1N97(@3F%V:6=A=&EO;B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS
M"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R(")/<F1N97+\8F5R<VEC
M:'0B"@HC.B!A8VPN<&AP.C(S"FUS9VED(")&;VQD97(@<VAA<FEN9R!I<R!N
M;W0@96YA8FQE9"XB"FUS9W-T<B`B1&EE(&=E;65I;G-A;64@3G5T>G5N9R!V
M;VX@3W)D;F5R;B!I<W0@;FEC:'0@;?9G;&EC:"XB"@HC.B!F;VQD97)S+G!H
M<#HT-PIM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T
M<B`B1&EE($)E;G5T>G5N9R!V;VX@3W)D;F5R;B!I<W0@;FEC:'0@86MT:79I
M97)T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3@*;7-G:60@(D9O
M<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R
M(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@(D1A='5M<V9O<FUA="!F
M_'(@3F%C:')I8VAT96X@=F]N(&AE=71E(&EN(&1E<B!/<F1N97)A;G-I8VAT
M(@H*(SH@8V]M<&]S92YP:'`Z.#(P('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")796ET97)L96ET96XB
M"@HC.B!C;VUP;W-E+G!H<#HX,#4*;7-G:60@(D9O<G=A<F0Z(@IM<V=S='(@
M(E=E:71E<FQE:71E;CHB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S@P"FUS9VED
M(")&;W)W87)D960@;65S<V%G92(*;7-G<W1R(")796ET97)G96QE:71E=&4@
M3F%C:')I8VAT(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,W.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@
M(E=E:71E<F=E;&5I=&5T92!.86-H<FEC:'0@=F]N("5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0P,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E
M<W0@4F5S<&]N<V4B"FUS9W-T<B`B06YT=V]R="!A=68@1G)E:2]'96)U8VAT
M+4%N9G)A9V4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C(W"FUS9VED(")&<F]?;2(*;7-G<W1R(")?5F]N(@H*(SH@;65S
M<V%G92YP:'`Z,C<P('1H<F5A9"YP:'`Z,34T('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.CDW"B,Z(&QI8B]396%R8V@N<&AP.C4X.0IM<V=I9"`B
M1G)O;2(*;7-G<W1R(")6;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`W"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`B5F]N($%D<F5S<V4B
M"@HC.B!C;VUP;W-E+G!H<#HX,3<@8V]M<&]S92YP:'`Z.#(Q"FUS9VED(")&
M=V0Z(@IM<V=S='(@(D9W9#HB"@HC.B!C;VUP;W-E+G!H<#HQ,S$Q"FUS9VED
M(")&=V0Z("(*;7-G<W1R(")71SH@(@H*(SH@8V]M<&]S92YP:'`Z,3,Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E
M<R(*;7-G<W1R(")71SH@)74@=V5I=&5R9V5L96ET971E($YA8VAR:6-H=&5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS
M9W-T<B`B06QL9V5M96EN92!%:6YS=&5L;'5N9V5N(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@
M;65S<V%G97,_("A)34%0(&]N;'DI(@IM<V=S='(@(DYU<B!N975E($YA8VAR
M:6-H=&5N(&%B<G5F96X_("AN=7(@24U!4"DB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHS,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-34T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,C@*;7-G:60@(D=O
M(@IM<V=S='(@(DQO<R(*"B,Z('1H<F5A9"YP:'`Z,3,V"FUS9VED(")';R!T
M;R!-97-S86=E(@IM<V=S='(@(EIU(&1I97-E<B!.86-H<FEC:'0B"@HC.B!L
M:6(O24U0+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V\@=&\@861D
M<F5S<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R("):=6T@061R97-S
M8G5C:&5I;G1R86<@=F]N(%PB)7-<(B(*"B,Z('1E;7!L871E<R]A8VPO86-L
M+FEN8SHQ,S8*;7-G:60@(D=R86YT(&%C8V5S<R(*;7-G<W1R("):=6=R:69F
M(&5R;&%U8F5N(@H*(SH@;65S<V%G92YP:'`Z-30Y(&QI8B]&:6QT97(N<&AP
M.C$S,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*(SH@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z,3$Q(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$Q,PHC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C0@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0HC.B!L:6(O34E-12]6:65W
M97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z
M-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C0*(SH@;&EB+TU)344O
M5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-S(*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(P(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM<V=I9"`B2$5212(*;7-G
M<W1R(")(2452(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C,Q(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C`*(SH@;&EB+TU)344O
M5FEE=V5R+W)E;&%T960N<&AP.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(DA4
M34PB"@HC.B!C;VUP;W-E+G!H<#HR-C`*;7-G:60@(DA434P@5F5R<VEO;B!O
M9B!-97-S86=E(@IM<V=S='(@(DA434PM5F5R<VEO;B!D97(@3F%C:')I8VAT
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@
M(DAE861E<G,B"FUS9W-T<B`B2V]P9F5I;G1RY&=E(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M
M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B2&EE<B!F:6YD
M96X@4VEE(&1E;B!497AT(&1E<B!.86-H<FEC:'0L(&1I92!3:64@97)S=&5L
M;'0@:&%B96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U-@IM<V=I
M9"`B2&ED9&5N(@IM<V=S='(@(E9E<G-T96-K="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-34*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE=R(*
M;7-G<W1R(")697)S=&5C:W0@:6X@9&5R(%1H96UE;F%N<VEC:'0B"@HC.B!M
M86EL8F]X+G!H<#HS-3(*;7-G:60@(DAI9&4@1&5L971E9"(*;7-G<W1R(")6
M97)S=&5C:V4@9V5L]G-C:'1E(@H*(SH@9F]L9&5R<RYP:'`Z,C@T"FUS9VED
M(")(:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")?075S9V5B;&5N9&5T92!/
M<F1N97(@=F5R<W1E8VME;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(Y,@IM<V=I9"`B2&EG:"(*;7-G<W1R(")(;V-H(@H*(SH@;65S
M<V%G92YP:'`Z,S`T(&UA:6QB;W@N<&AP.C<Q."!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H(%!R:6]R:71Y(@IM<V=S='(@
M(DAO:&4@4')I;W)I=.1T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,CDQ"FUS9VED(")(:6=H97-T(@IM<V=S='(@(DCV8VAS=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@U"FUS9VED(")(;W<@9&\@>6]U
M('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T<B`B5VEE('-O
M;&QE;B!!;FCD;F=E(&%N9V5Z96EG="!W97)D96X_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P-`IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q=6]T
M960@;&EN97,@:6X@82!R97!L>2(*;7-G<W1R(")7:64@<V]L;&5N(%II=&%T
M86YT=V]R=&5N(&UA<FMI97)T('=E<F1E;C\B"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$S-`IM<V=I9"`B24U!4"(*;7-G<W1R("))34%0(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-05`@*$%U=&\@
M1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B24U!4"`H075T;VUA=&ES8VAE
M(%!R;W1O:V]L;&5R:V5N;G5N9RDB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@
M=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@
M(D1E<B!)34%0+5-E<G9E<B!H870@9&EE(%9E<F)I;F1U;F<@=6YT97)B<F]C
M:&5N+B!397)V97)A;G1W;W)T.B`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,38U(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED
M("))34%0(&]V97(@4U-,(@IM<V=S='(@(DE-05`@_&)E<B!34TPB"@HC.B!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I9"`B24U!4"!O=F5R(%-3
M3"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(DE-05`@_&)E
M<B!34TP@*'-E;&8M<VEG;F5D(%IE<G1I9FEK870I(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHQ-C8*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E
M;&8M<VEG;F5D*2(*;7-G<W1R("))34%0(/QB97(@4U-,("AS96QF+7-I9VYE
M9"DB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!4"!S
M97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R(")$97(@24U!
M4"U397)V97(@:&%T(&1I92!697)B:6YD=6YG('5N=&5R8G)O8VAE;BXB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-"!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(DE-
M05`@;VAN92!43%,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C0Y"FUS
M9VED("))34%0+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@(DE-05`O4$]0
M,R!%;6%I;'-E<G9E<B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#$Q"FUS
M9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@;75S="!H879E('1H92!0
M2%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+B(*;7-G<W1R("(B"B)5;2!3
M4TP@;V1E<B!43%,@8F5N=71Z96X@>G4@:_9N;F5N+"!M=7-S(&1I92!/<&5N
M4U-,+45R=V5I=&5R=6YG(&;\<B!02%`@(@HB9V5L861E;B!S96EN+B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"FUS
M9VED("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L
M9&5R*',I('=I;&P@8F4@;&]S="$B"FUS9W-T<B`B(@HB5V5N;B!3:64@9F]R
M=&9A:')E;BP@=V5R9&5N(&%L;&4@3F%C:')I8VAT96X@:6X@9&5M($]R9&YE
M<B]D96X@3W)D;F5R;B`B"B)E;F1G_&QT:6<@9V5L]G-C:'0A(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@R"FUS9VED("))9VYO<F4B
M"FUS9W-T<B`B26=N;W)I97)E;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G<W1R(")!;&QE
M($EG;F]R:65R96XB"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G
M92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`B0FEL9"(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C`*;7-G:60@(DEM<&]R="(*;7-G
M<W1R("));7!O<G1I97)E;B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHX-2!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8U"FUS
M9VED("));7!O<G0@2V5Y(@IM<V=S='(@(E-C:&S\<W-E;"!I;7!O<G1I97)E
M;B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,SD*;7-G:60@(DEM<&]R
M="!+97EP86ER(@IM<V=S='(@(E-C:&S\<W-E;'!A87(@:6UP;W)T:65R96XB
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PIM<V=I9"`B
M26UP;W)T($UE<W-A9V5S(@IM<V=S='(@(DYA8VAR:6-H=&5N(&EM<&]R=&EE
M<F5N(@H*(SH@<&=P+G!H<#HT,0IM<V=I9"`B26UP;W)T(%!'4"!+97DB"FUS
M9W-T<B`B4$=0+5-C:&S\<W-E;"!I;7!O<G1I97)E;B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z.3$*;7-G:60@(DEM<&]R="!097)S;VYA;"!#
M97)T:69I8V%T92(*;7-G<W1R(")097)S]FYL:6-H97,@6F5R=&EF:6MA="!I
M;7!O<G1I97)E;B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+97DB"FUS
M9W-T<B`B4&5R<_9N;&EC:&5N('!R:79A=&5N(%!'4"U38VAL_'-S96P@:6UP
M;W)T:65R96XB"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.CD*
M;7-G:60@(DEM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G<W1R
M(")097)S]FYL:6-H96X@]F9F96YT;&EC:&5N(%!'4"U38VAL_'-S96P@:6UP
M;W)T:65R96XB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,B
M"FUS9W-T<B`B4&5R<_9N;&EC:&5S(%,O34E-12U:97)T:69I:V%T(&EM<&]R
M=&EE<F5N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHT,"!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-#(*;7-G:60@(DEM<&]R="!0=6)L:6,@2V5Y
M(@IM<V=S='(@(M9F9F5N=&QI8VAE;B!38VAL_'-S96P@:6UP;W)T:65R96XB
M"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM
M<&]R="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("+69F9E;G1L:6-H96X@4$=0
M+5-C:&S\<W-E;"!I;7!O<G1I97)E;B(*"B,Z('1E;7!L871E<R]S;6EM92]I
M;7!O<G1?:V5Y+FEN8SHX"FUS9VED("));7!O<G0@4'5B;&EC(%,O34E-12!+
M97DB"FUS9W-T<B`BUF9F96YT;&EC:&5N(%,O34E-12U38VAL_'-S96P@:6UP
M;W)T:65R96XB"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)
M344@2V5Y(@IM<V=S='(@(E,O34E-12U38VAL_'-S96P@:6UP;W)T:65R96XB
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.CD*;7-G:60@(DEM
M<&]R="!M8F]X($9I;&4B"FUS9W-T<B`B3F%C:')I8VAT96X@:6UP;W)T:65R
M96XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD
M97(@)7,N(@IM<V=S='(@(DUB;W@M1&%T96D@)7,@:6X@9&5N($]R9&YE<B`E
M<R!I;7!O<G1I97)E;BXB"@HC.B!M97-S86=E+G!H<#HU,#4@;6%I;&)O>"YP
M:'`Z-S(X('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$V('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHW"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`B5VEC:'1I
M9R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-#<*;7-G:60@(DEM
M<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(")7:6-H=&EG92!.86-H<FEC:'1E
M;B(*"B,Z(&9O;&1E<G,N<&AP.C$U,0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("(E9"!.86-H
M<FEC:'1E;B!A=7,@)7,@:6UP;W)T:65R="XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S8V"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@(DEN
M($)E87)B96ET=6YG(@H*(SH@9F]L9&5R<RYP:'`Z,S8U('1E;7!L871E<R]P
M<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,30@;&EB+T9O;&1E<BYP:'`Z
M.#4*(SH@;&EB+TE-4"YP:'`Z.#,R(&QI8B])34%0+U1R964N<&AP.C$Q.2!L
M:6(O24U!4"]4<F5E+G!H<#HR,C(*;7-G:60@(DEN8F]X(@IM<V=S='(@(E!O
M<W1E:6YG86YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,@IM<V=I
M9"`B26YC;'5D92!A(&)R:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A
M(')E<&QY/R(*;7-G<W1R(").86-H<FEC:'1E;FMO<&8@:6X@9&EE($%N='=O
M<G0@96EN9OQG96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM
M<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_(@IM
M<V=S='(@(D]R:6=I;F%L;F%C:')I8VAT(&EN(&1I92!!;G1W;W)T(&5I;F;\
M9V5N/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$S,`IM<V=I9"`B26YF;R(*
M;7-G<W1R("));F9O<FUA=&EO;B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M
M870*;7-G:60@(DEN9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97DB"FUS9W-T
M<B`B26YF;W)M871I;VYE;B#\8F5R("5S(/9F9F5N=&QI8VAE;B!38VAL_'-S
M96PB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(DEN9F]R
M;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(DEN9F]R
M;6%T:6]N96X@_&)E<B!D96X@<&5R<_9N;&EC:&5N('!R:79A=&5N(%-C:&S\
M<W-E;"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S
M;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(DEN9F]R;6%T:6]N96X@_&)E<B!D
M96X@<&5R<_9N;&EC:&5N(/9F9F5N=&QI8VAE;B!38VAL_'-S96PB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,34@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DY"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V%T=&%C:&UE;G1S+FIS.C4V"FUS9VED("));FQI;F4B"FUS9W-T<B`B26T@
M5&5X="(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS
M9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("):97)T:69I
M:V%T(&AI97(@96EN9OQG96XB"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K
M97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@
M2V5Y($AE<F4B"FUS9W-T<B`B4&5R<_9N;&EC:&5N('!R:79A=&5N(%!'4"U3
M8VAL_'-S96P@:&EE<B!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z,3`*;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@
M4$=0($ME>2!(97)E(@IM<V=S='(@(E!E<G/V;FQI8VAE;B#V9F9E;G1L:6-H
M96X@4$=0+5-C:&S\<W-E;"!H:65R(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S
M+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED("));G-E<G0@4'5B;&EC(%!'
M4"!+97D@2&5R92(*;7-G<W1R("+69F9E;G1L:6-H96X@4$=0+5-C:&S\<W-E
M;"!H:65R(&5I;F;\9V5N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0Q,PIM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@
M8V]M<&]N96YT+B(*;7-G<W1R(")5;F?\;'1I9V4@06MT:6]N(&;\<B!D:65S
M92!+;VUP;VYE;G1E(&%U<V=E=^1H;'0N(@H*(SH@;6%I;&)O>"YP:'`Z-3<T
M(&UA:6QB;W@N<&AP.C8R,0IM<V=I9"`B26YV86QI9"!!9&1R97-S(@IM<V=S
M='(@(E5N9_QL=&EG92!!9')E<W-E(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B"FUS9W-T
M<B`B56YG_&QT:6=E<R!0;W-T9F%C:"(*"B,Z(&-O;7!O<V4N<&AP.C$U.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA
M:6P@861D<F5S<SH@)7,N(@IM<V=S='(@(E5N9_QL=&EG97,@6F5I8VAE;B!I
M;B!D97(@16UA:6QA9')E<W-E.B`E<RXB"@HC.B!S;6EM92YP:'`Z-S@@<&=P
M+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K97DB"FUS9W-T<B`B56YG_&QT:6=E
M<B!38VAL_'-S96PB"@HC.B!P9W`N<&AP.C$Y,@IM<V=I9"`B26YV86QI9"!P
M97)S;VYA;"!01U`@<')I=F%T92!K97DN(@IM<V=S='(@(E5N9_QL=&EG97(@
M<&5R<_9N;&EC:&5R('!R:79A=&5R(%!'4"U38VAL_'-S96PN(@H*(SH@<&=P
M+G!H<#HQ-C<*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K
M97DN(@IM<V=S='(@(E5N9_QL=&EG97(@<&5R<_9N;&EC:&5R(/9F9F5N=&QI
M8VAE<B!01U`M4V-H;/QS<V5L+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R(")5;6ME:')E;B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Y,0IM<V=I9"`B
M2T(B"FUS9W-T<B`B2T(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3$S
M"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(E-C:&S\<W-E;&SD;F=E(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I9"`B(@HB2V5Y(&=E
M;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@=&\@8V]M<&QE=&4N("!#
M;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*;7-G<W1R("(B"B)$
M:64@17)Z975G=6YG('9O;B!38VAL_'-S96QN(&MA;FX@<V5H<B!L86YG92!D
M875E<FXN(%-C:&S\<W-E;&5R>F5U9W5N9R`B"B)F;W)T<V5T>F5N/R(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C,W"FUS9VED(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N
M($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*
M;7-G<W1R("(B"B)3:64@:_9N;F5N(&ME:6YE(%-C:&S\<W-E;"!I;7!O<G1I
M97)E;BP@=V5I;"!D87,@2&]C:&QA9&5N('9O;B!$871E:65N(&%U9B`B"B)D
M:65S96X@4V5R=F5R(&YI8VAT(&WV9VQI8V@@:7-T+B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,S<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,Y
M"FUS9VED("(B"B)+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H
M879E(&YO(&%D9')E<W,@8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R("(*(F-O
M;G1A8W1S+B(*;7-G<W1R("(B"B)3:64@:_9N;F5N(&ME:6YE(%-C:&S\<W-E
M;"!I;7!O<G1I97)E;BP@=V5I;"!3:64@:V5I;B!!9')E<W-B=6-H(&%N9V5G
M96)E;B`B"B)H86)E;BP@9&%S('IU;2!(:6YZ=6;\9V5N(&YE=65R($MO;G1A
M:W1E('9E<G=E;F1E="!W97)D96X@<V]L;"XB"@HC.B!P9W`N<&AP.C,Q-`IM
M<V=I9"`B2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R("(B"B)$97(@4V-H;/QS<V5L('=U<F1E(&5R9F]L
M9W)E:6-H('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R(&=E<V-H
M:6-K="XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(Q-0IM<V=I
M9"`B3&%N9W5A9V4B"FUS9W-T<B`B4W!R86-H92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.34*;7-G:60@(DQA<W0@36%I;&)O>"!086=E(@IM<V=S
M='(@(DQE='IT92!/<F1N97)S96ET92(*"B,Z(&UA:6QB;W@N<&AP.C,T,PIM
M<V=I9"`B3&%S="!086=E(@IM<V=S='(@(DQE='IT92!396ET92(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T-PIM<V=I9"`B3&EN:R!!
M='1A8VAM96YT<S\B"FUS9W-T<B`B06YHY&YG92!V97)L:6YK96X_(@H*(SH@
M871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C$P.#0*;7-G:60@
M(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R(")6
M97)L:6YK=&4@06YHY&YG92!S:6YD(&1E86MT:79I97)T+B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ,3`P"B,L('!H<"UF;W)M870*;7-G:60@(DQI;FMS('=I
M;&P@97AP:7)E(&]N("5S(@IM<V=S='(@(D1I92!,:6YK<R!S:6YD(&)I<R!Z
M=6T@)7,@9_QL=&EG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-S$*
M;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@
M8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL("(*(F]N
M;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L
M>2DB"FUS9W-T<B`B(@HB06QL92!+;VYT86MT92!B96EM(-9F9FYE;B!D97(@
M2V]N=&%K=&QI<W1E(&%N>F5I9V5N/R`H1F%L;',@9&5A:W1I=FEE<G0L("(*
M(G=E<F1E;B!N=7(@9&EE($MO;G1A:W1E(&%N9V5Z96EG="P@;F%C:"!D96YE
M;B!3:64@875S9'+\8VML:6-H('-U8VAE;BDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C@R"FUS9VED("),:7-T:6YG(&EN('1H92!(96%D97(B"FUS
M9W-T<B`B06QS($QI<W1E(&EM($YA8VAR:6-H=&5N:V]P9B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`IM<V=I9"`B3&]C86P@36%I
M;&)O>#HB"FUS9W-T<B`B3&]K86QE<B!/<F1N97(Z(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8W,0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B
M3W)T(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C0*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R(")!;FUE;&1E;B(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O("5S
M(@IM<V=S='(@(D%N;65L9&5N(&)E:2`E<R(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,3,X"FUS9VED("),;V=I;B(*;7-G<W1R(")!;FUE;&1E
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B3&]G:6X@
M5&%S:W,B"FUS9W-T<B`B06YM96QD96%U9F=A8F5N(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDT"FUS9VED("),;W<B"FUS9W-T<B`B
M3FEE9')I9R(*"B,Z(&UE<W-A9V4N<&AP.C,P-B!M86EL8F]X+G!H<#HW,C$@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B3&]W(%!R
M:6]R:71Y(@IM<V=S='(@(DYI961R:6=E(%!R:6]R:73D="(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-0IM<V=I9"`B3&]W97-T(@IM
M<V=S='(@(DYI961R:6=S=&4B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D
M;W5B;&4N<&AP.C0T"FUS9VED(")-86-I;G1O<V@@1FEL92(*;7-G<W1R(")-
M86-I;G1O<V@M1&%T96DB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S
M92YI;F,Z,3,*;7-G:60@(DUA:6PB"FUS9W-T<B`B5V5B;6%I;"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B36%I;"!0<F5V:65W<R(*
M;7-G<W1R(").86-H<FEC:'1E;G9O<G-C:&%U(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHQ-@IM<V=I9"`B36%I;"!S97)V
M97(@='EP92!T;R!C;VYN96-T('1O.B(*;7-G<W1R("):=2!V97)W96YD96YD
M97(@16UA:6QS97)V97)T>7`Z(@H*(SH@9F]L9&5R<RYP:'`Z,S8Y(&9O;&1E
M<G,N<&AP.C,X,PIM<V=I9"`B36%I;&)O>"(*;7-G<W1R(")/<F1N97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"FUS9VED(")-86EL8F]X(&%N
M9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D%N>F5I9V5E:6YS
M=&5L;'5N9V5N(&;\<B!D:64@3W)D;F5R86YS:6-H="!U;F0@+?QB97)S:6-H
M="(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X"FUS9VED
M(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G<W1R
M(")!;&QE($YA8VAR:6-H=&5N(&EM($]R9&YE<B!A;',@9V5L97-E;B!M87)K
M:65R96XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.0IM
M<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%5N<V5E;B(*
M;7-G<W1R(")!;&QE($YA8VAR:6-H=&5N(&EM($]R9&YE<B!A;',@=6YG96QE
M<V5N(&UA<FMI97)E;B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P
M"FUS9VED(")-87)K(&%S.B(*;7-G<W1R(")-87)K:65R96X@86QS.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,S@*;7-G:60@(DUA<FL@9&EF9F5R
M96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B
M"FUS9W-T<B`B(@HB56YT97)S8VAI961L:6-H92!::71A=&5I;G+\8VMU;F=E
M;B!I;B!U;G1E<G-C:&EE9&QI8VAE;B!&87)B96X@86YZ96EG96X_(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K
M(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI(@IM<V=S='(@(DYA8VAR
M:6-H=&5N(&%L<R!G96QE<V5N(&UA<FMI97)E;C\@*&YU<B!)34%0*2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-#8*;7-G:60@(DUA<FL@<VEM<&QE
M(&UA<FMU<#\B"FUS9W-T<B`B16EN9F%C:&4@075S>F5I8VAN=6YG(&AE<G9O
M<FAE8F5N/R(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT.0IM
M<V=I9"`B36%T8V@@06QL(%%U97)I97,B"FUS9W-T<B`B86QL96X@2W)I=&5R
M:65N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0U"FUS9VED
M(")-871C:"!!;GD@475E<GDB"FUS9W-T<B`B96EN96T@2W)I=&5R:75M(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`U"FUS9VED(")-
M87AI;75M($%T=&%C:&UE;G0@4VEZ92(*;7-G<W1R(")-87AI;6%L92!!;FAA
M;F=G<O;?92(*"B,Z(&QI8B]A<&DN<&AP.C<Y"FUS9VED(")-87AI;75M($YU
M;6)E<B!O9B!&;VQD97)S(@IM<V=S='(@(DUA>&EM86QE($%N>F%H;"!A;B!/
M<F1N97)N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@W
M"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D
M+B(*;7-G<W1R(")-87AI;6%L92!!;GIA:&P@9&5R($%N:.1N9V4@97)R96EC
M:'0N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@S"FUS
M9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*
M;7-G<W1R(")-87AI;6%L92!'97-A;71G<O;?92!D97(@06YHY&YG92!E<G)E
M:6-H="XB"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS"FUS9VED
M(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@(DUE;OPM3W)D;F5R;&ES=&4B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0R"FUS9VED(")-97-S86=E(@IM<V=S
M='(@(DYA8VAR:6-H="(*"B,Z(&-O;7!O<V4N<&AP.C4Y."!C;VUP;W-E+G!H
M<#HV,C4@8V]M<&]S92YP:'`Z-C<Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO;B(*;7-G<W1R(").975E($YA
M8VAR:6-H="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#8*;7-G:60@
M(DUE<W-A9V4@1&%T92(*;7-G<W1R(").86-H<FEC:'1E;B!$871U;2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P,PIM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM
M<V=S='(@(DYA8VAR:6-H=&5N+45I;G-T96QL=6YG96XB"@HC.B!S96%R8V@N
M<&AP.C,P,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T<B`B3F%C:')I
M8VAT96X@4W5C:&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$P"FUS
M9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`B3F%C:')I8VAT96X@1W+VWV4B
M"@HC.B!M97-S86=E+G!H<#HS.3$*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM
M<V=S='(@(E]1=65L;'1E>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C8*;7-G:60@(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R(").86-H<FEC:'1E
M;F%N<VEC:'0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G
M:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`B3F%C:')I8VAT96YS=&%T=7,B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S
M86=E(&9O;&1E<G,B"FUS9W-T<B`B3F%C:')I8VAT96YO<F1N97(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DUE<W-A
M9V4@9G)O;2`E<R(*;7-G<W1R(").86-H<FEC:'0@=F]N("5S(@H*(SH@;6%I
M;&)O>"YP:'`Z-C8R"FUS9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*
M;7-G<W1R(").86-H<FEC:'0@;6ET($%N:.1N9V5N(@H*(SH@;6%I;&)O>"YP
M:'`Z-C4S"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E9"(*;7-G<W1R(")6
M97)S8VAL_'-S96QT92!.86-H<FEC:'0B"@HC.B!M86EL8F]X+G!H<#HV-#@*
M;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(E5N=&5R<V-H<FEE
M8F5N92!.86-H<FEC:'0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI
M;F,Z,S8*;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R(").86-H<FEC
M:'0@96YT<W!R:6-H="(*"B,Z(&-O;7!O<V4N<&AP.C@V-"!C;VUP;W-E+G!H
M<#HX-S$*;7-G:60@(DUE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(DYA8VAR:6-H="!W=7)D92!E<F9O;&=R96EC:"!U;6=E;&5I
M=&5T+B(*"B,Z(&-O;7!O<V4N<&AP.C$Q,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T
M;R`E<R(*;7-G<W1R(").86-H<FEC:'0@=W5R9&4@97)F;VQG<F5I8V@@=F5R
M<V5N9&5T+"!A8F5R(&YI8VAT(&EN("5S(&=E<W!E:6-H97)T(@H*(SH@8V]M
M<&]S92YP:'`Z,3$X,2!C;VUP;W-E+G!H<#HQ,3@Y"FUS9VED(")-97-S86=E
M('-E;G0@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(").86-H<FEC:'0@=W5R9&4@
M97)F;VQG<F5I8V@@=F5R<V5N9&5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,S`*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL
M8F]X('9I97<N(@IM<V=S='(@(DYA8VAR:6-H=&5N('!R;R!396ET92(*"B,Z
M(&UA:6QB;W@N<&AP.C,Q,`IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B
M3F%C:')I8VAT96X@;F%C:"(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR
M.0IM<V=I9"`B36]D:69Y(@IM<V=S='(@(L1N9&5R92(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N
M(@IM<V=S='(@(D5S('=U<F1E(&UE:'(@86QS(&5I;F4@061R97-S92!F_'(@
M9&%S(%PB)7-<(BU&96QD(&=E9G5N9&5N+B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHU,`IM<V=I9"`B36]V92(*;7-G<W1R(")697)S8VAI95]B
M92(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-@IM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(DYA8V@@=6YT96XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C`V"FUS9VED(")-;W9E('-P86T@;65S<V%G
M97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.
M0D]8(@IM<V=S='(@(B(*(E-P86TM3F%C:')I8VAT96X@:6X@9&5N(%-P86TM
M3W)D;F5R('5N9"!.:6-H="U3<&%M+4YA8VAR:6-H=&5N(&EN(&1E;B`B"B)0
M;W-T96EN9V%N9R!V97)S8VAI96)E;B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHU,`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B5F5R
M<V-H:65B96X@;F%C:"(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,Q-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R(").86-H(&]B96XB
M"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$R-PIM<V=I
M9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@(DUU;'1I<&%R="]A
M;'1E<FYA=&EV92(*"B,Z('1H<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3<*
M;7-G:60@(DUU;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R(")!;G-I8VAT
M(&;\<B!M96AR97)E($YA8VAR:6-H=&5N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C@*;7-G:60@(DY/3D4B"FUS9W-T
M<B`B2T5)3B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT
M."!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`B2$E.5T5)4R(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV.#,*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%M
M92(*"B,Z('!G<"YP:'`Z,3`V"FUS9VED(").86UE(&%N9"]O<B!E;6%I;"!C
M86YN;W0@8F4@96UP='DB"FUS9W-T<B`B1&5R($YA;64@=6YD+V]D97(@9&EE
M($5M86EL861R97-S92!D_')F96X@;FEC:'0@;&5E<B!S96EN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,0IM<V=I9"`B3F5E9',@06-T:6]N
M(@IM<V=S='(@(D%K=&EO;B!B96[V=&EG="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-S`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V-PIM<V=I9"`B
M3F5V97(B"FUS9W-T<B`B3FEE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4V,`IM<V=I9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(")!
M;FCD;F=E(&YI92!S<&5I8VAE<FXB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`B3F5U(@H*(SH@;&EB+TE-4"YP
M:'`Z-3DU"FUS9VED(").97<@1F]L9&5R(@IM<V=S='(@(DYE=65R($]R9&YE
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B3F5W($UA
M:6PB"FUS9W-T<B`B3F%C:')I8VAT96YE:6YG86YG(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(Q(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR,@HC.B!L
M:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HT-@IM<V=I9"`B3F5W($UE<W-A
M9V4B"FUS9W-T<B`B3F5U92!.86-H<FEC:'0B"@HC.B!M86EL8F]X+G!H<#HW
M-S`@;&EB+TU)344O2&5A9&5R<RYP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G
M:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(DYE=64@3F%C:')I8VAT
M(&%N("5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ.0IM<V=I
M9"`B3F5W(&UE<W-A9V5S(@IM<V=S='(@(DYE=64@3F%C:')I8VAT96XB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S"FUS9VED(").
M97AT(@IM<V=S='(@(E=E:71E<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G92(*;7-G
M<W1R(").Y&-H<W1E($YA8VAR:6-H="(*"B,Z(&UA:6QB;W@N<&AP.C,T,0IM
M<V=I9"`B3F5X="!086=E(@IM<V=S='(@(E-E:71E('9O<B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4S."!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU-3$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F5I;B(*"B,Z('-M:6UE+G!H<#HR,C(*
M;7-G:60@(DYO($-E<G1I9FEC871E(&9O=6YD(@IM<V=S='(@(DME:6X@6F5R
M=&EF:6MA="!G969U;F1E;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y
M<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO;B(*;7-G<W1R(")+
M96EN92!697)S8VAL_'-S96QU;F<B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3D*;7-G:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R(")+96EN
M92!38VAL_'-S96P@:6T@4V-H;/QS<V5L8G5N9"(*"B,Z(&UA:6QB;W@N<&AP
M.C,V,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*;7-G<W1R
M(")+96EN92!.86-H<FEC:'1E;B(*"B,Z('!G<"YP:'`Z,3,S"FUS9VED(").
M;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B17,@=W5R9&4@
M:V5I;B#V9F9E;G1L:6-H97(@4$=0+5-C:&S\<W-E;"!I;7!O<G1I97)T+B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E
M<G-O;F%L($-E<G1I9FEC871E(%!R97-E;G0B"FUS9W-T<B`B2V5I;B!P97)S
M]FYL:6-H97,@6F5R=&EF:6MA="!V;W)H86YD96XB"@HC.B!L:6(O36%I;&)O
M>"YP:'`Z,S,S"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`B2V5I
M;B!6;W)S8VAA=71E>'0B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C$U"FUS9VED(").;R!0=6)L:6,@2V5Y<R!&;W5N9"(*;7-G<W1R(")+96EN
M92#V9F9E;G1L:6-H96X@4V-H;/QS<V5L(&=E9G5N9&5N(@H*(SH@<VUI;64N
M<&AP.C$T-PIM<V=I9"`B3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N
M(@IM<V=S='(@(D5S('=U<F1E(&ME:6X@]F9F96YT;&EC:&5R(%,O34E-12U3
M8VAL_'-S96P@:6UP;W)T:65R="XB"@HC.B!L:6(O34E-12]6:65W97(O=&YE
M9BYP:'`Z.3(*;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R
M(")+96EN92!!;FCD;F=E(&=E9G5N9&5N+B(*"B,Z(&QI8B]#<GEP="]334E-
M12YP:'`Z,30P"FUS9VED(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D
M(&EN('1H92!P=6)L:6,@:V5Y+B(*;7-G<W1R(")+96EN92!%;6%I;&%D<F5S
M<V4@:6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E;"!G969U;F1E;BXB"@HC.B!A
M8VPN<&AP.C<Q(&%C;"YP:'`Z.3<*;7-G:60@(DYO(&9O;&1E<B!S96QE8W1E
M9"XB"FUS9W-T<B`B2V5I;B!/<F1N97(@875S9V5WY&AL="XB"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,30Y"FUS9VED(").;R!F;VQD97)S(&%R92!B
M96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B17,@=V5R9&5N
M(&ME:6YE($]R9&YE<B!A=68@;F5U92!.86-H<FEC:'1E;B#\8F5R<'+\9G0N
M(@H*(SH@9F]L9&5R<RYP:'`Z,C`Q(&QI8B]&;VQD97(N<&AP.C0V-R!L:6(O
M1F]L9&5R+G!H<#HU,3<*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I
M960B"FUS9W-T<B`B2V5I;B!/<F1N97(@86YG96=E8F5N(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C$U-0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE
M=R!M97-S86=E<R(*;7-G<W1R(")+96EN92!/<F1N97(@;6ET(&YE=65N($YA
M8VAR:6-H=&5N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$U,@IM<V=I
M9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<R(*;7-G<W1R(")+
M96EN92!/<F1N97(@;6ET('5N9V5L97-E;F5N($YA8VAR:6-H=&5N(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,S-@IM<V=I9"`B3F\@;65S<V%G92!B;V1Y('1E
M>'0B"FUS9W-T<B`B2V5I;B!.86-H<FEC:'1E;G1E>'0B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4V.`IM<V=I9"`B3F\@;65S<V%G92!R971U<FYE9"XB
M"FUS9W-T<B`B2V5I;F4@3F%C:')I8VAT(&=E9G5N9&5N+B(*"B,Z(&QI8B]-
M86EL8F]X+G!H<#HS-S4*;7-G:60@(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U
M<B!S96%R8V@N(@IM<V=S='(@(D5S('=U<F1E;B!K96EN92!P87-S96YD96X@
M3F%C:')I8VAT96X@9V5F=6YD96XN(@H*(SH@<&=P+G!H<#HQ.#4*;7-G:60@
M(DYO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B17,@=W5R9&4@:V5I;B!P97)S]FYL:6-H97(@<')I=F%T97(@4$=0+5-C
M:&S\<W-E;"!I;7!O<G1I97)T+B(*"B,Z('!G<"YP:'`Z,38Q"FUS9VED(").
M;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B
M17,@=W5R9&4@:V5I;B!P97)S]FYL:6-H97(@]F9F96YT;&EC:&5R(%!'4"U3
M8VAL_'-S96P@:6UP;W)T:65R="XB"@HC.B!S;6EM92YP:'`Z,3DW"FUS9VED
M(").;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*
M;7-G<W1R(")%<R!W=7)D96X@:V5I;F4@<')I=F%T96X@4R]-24U%+5IE<G1I
M9FEK871E(&EM<&]R=&EE<G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR-#8@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDY"FUS9VED("(B
M"B).;R!P97)S;VYA;"!P<FEV871E(&ME>2!E>&ES=',@<V\@=&AE(&UE<W-A
M9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB4VEE
M(&AA8F5N('IU<B!:96ET(&ME:6YE;B!P<FEV871E;B!38VAL_'-S96PL('-O
M(&1A<W,@9&EE($YA8VAR:6-H="!N:6-H="`B"B)E;G1S8VAL_'-S96QT('=E
M<F1E;B!K86YN+B(*"B,Z('-P96QL:6YG+G!H<#HR,C`*;7-G:60@(DYO('-P
M96QL8VAE8VMI;F<@<')O9W)A;2!C;VYF:6=U<F5D+B(*;7-G<W1R(")%<R!W
M=7)D92!K96EN(%)E8VAT<V-H<F5I8G!R;V=R86UM(&MO;F9I9W5R:65R="XB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G:60@
M(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(")+96EN92!38VAR96EB9F5H
M;&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P,`IM
M<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B2V5I;F4@5F]R<V-H;.1G
M92(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-38P"FUS9VED(").;R!S=7!P
M;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U
M;F0N(@IM<V=S='(@(B(*(D5S('=U<F1E(&ME:6YE('5N=&5R<W3\='IT92!!
M=71H96YT:69I>FEE<G5N9W-M971H;V1E(&;\<B!)34%0(&=E9G5N9&5N+B(*
M"B,Z(&%C;"YP:'`Z-C<@86-L+G!H<#HY,PIM<V=I9"`B3F\@=7-E<B!S<&5C
M:69I960N(@IM<V=S='(@(DME:6X@0F5N=71Z97(@86YG96=E8F5N+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#0*;7-G:60@(DYO;B!087)T
M:6-I<&%N="(*;7-G<W1R(")+96EN(%1E:6QN96AM97(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C$Q('1E;7!L871E<R]P<F5F<R]F;VQD
M97)S96QE8W0N:6YC.C(T"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E
M;&5C="YI;F,Z-#`@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S4*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T('1E;7!L
M871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8V,0IM<V=I9"`B3F]N92(*;7-G<W1R(")+96EN92(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,PIM<V=I9"`B
M3F]R;6%L(@IM<V=S='(@(DYO<FUA;"(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS
M.0IM<V=I9"`B3F]T($1E;&5T960B"FUS9W-T<B`B3FEC:'0@9V5L]G-C:'0B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$R
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM<V=S
M='(@(DME:6X@16YT=W5R9B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@
M(DYO="!);7!O<G1A;G0B"FUS9W-T<B`B3FEC:'0@=VEC:'1I9R(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*;7-G:60@(DYO="!097)S
M;VYA;"(*;7-G<W1R(").:6-H="!P97)S]FYL:6-H(@H*(SH@;&EB+T-R>7!T
M+U!'4"YP:'`Z,3,Y(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP
M="]334E-12YP:'`Z,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y
M+B(*;7-G<W1R(")+96EN(&?\;'1I9V5R(/9F9F5N=&QI8VAE<B!38VAL_'-S
M96PN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV-PIM<V=I9"`B
M3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B3FEC:'0@9V5L]G-C:'1E
M($YA8VAR:6-H=&5N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU
M,0IM<V=I9"`B3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(").:6-H
M="!W:6-H=&EG92!.86-H<FEC:'1E;B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T
M:&ES(&-A;B!T86ME('-O;64@=&EM92(*;7-G<W1R(")"96%C:'1E;B!3:64L
M(&1A<W,@9&EE<V5R(%9O<F=A;F<@96EN:6=E(%IE:70@9&%U97)N(&MA;FXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`T"FUS9VED(").;W1H:6YG
M(@IM<V=S='(@(DYI8VAT<R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C@Y"FUS9VED
M(").;W1I9FEC871I;VXZ($QI;FME9"!A='1A8VAM96YT(&1O=VYL;V%D960B
M"FUS9W-T<B`B2&EN=V5I<SH@5F5R;&EN:W1E<B!!;FAA;F<@:&5R=6YT97)G
M96QA9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B
M3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N
M=',@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB06YZ86AL(&1E
M<B!-;VYA=&4L(&;\<B!D:64@86QT92!V97)L:6YK=&4@06YHY&YG92!A=69G
M96AO8F5N('=E<F1E;B!S;VQL96XL("(*(F9A;&QS(&1I97-E(&UO;F%T;&EC
M:"!G96SV<V-H="!W97)D96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,U.0IM<V=I9"`B3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T
M;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(D%N>F%H
M;"!D97(@3W)D;F5R(&;\<B!G97-E;F1E=&4@3F%C:')I8VAT96XL(&1I92!B
M96D@;6]N871L:6-H97(@3/9S8VAU;F<@(@HB8F5H86QT96X@=V5R9&5N('-O
M;&QE;BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U
M-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+V9I96QD<RYI;F,Z-2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT.`IM<V=I9"`B
M3U(B"FUS9W-T<B`B3T1%4B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,34*;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R(")!;'1E($YA8VAR
M:6-H=&5N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C4R"FUS9VED(")/;&0@<V5N="UM86EL(&9O;&1E
M<G,@8F5I;F<@<'5R9V5D+B(*;7-G<W1R(")/<F1N97(@9OQR(&=E<V5N9&5T
M92!.86-H<FEC:'1E;BP@9&EE(&=E;/9S8VAT('=E<F1E;BXB"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,C@*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD
M97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(DYU
M<B!/<F1N97(L(&1I92!U;F=E;&5S96YE($YA8VAR:6-H=&5N(&5N=&AA;'1E
M;BP@86YZ96EG96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHX,0IM<V=I9"`B3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE
M8W1E9"!F;W(@=&AI<R!A8W1I;VXN(@IM<V=S='(@(D;\<B!D:65S92!!:W1I
M;VX@9&%R9B!N=7(@96EN($]R9&YE<B!A=7-G97?D:&QT('-E:6XN(@H*(SH@
M=&5M<&QA=&5S+VUE;G4N:6YC.C$P('1E;7!L871E<R]M96YU+FEN8SHS,`IM
M<V=I9"`B3W!E;B!&;U]L9&5R(@IM<V=S='(@(D]R7V1N97(@86YZ96EG96XB
M"@HC.B!F;VQD97)S+G!H<#HT,#@*;7-G:60@(D]P96YE9"!&;VQD97(B"FUS
M9W-T<B`B1V7V9F9N971E<B!/<F1N97(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S`P"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G
M<W1R(")/<'1I;VYA;&5R(%1E:6QN96AM97(B"@HC.B!F971C:&UA:6PN<&AP
M.C0S('1E;7!L871E<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHV"FUS9VED(")/=&AE<B!-86EL
M($%C8V]U;G1S(@IM<V=S='(@(D%N9&5R92!%;6%I;&MO;G1E;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I;VYS
M(@IM<V=S='(@(E-O;G-T:6=E($5I;G-T96QL=6YG96XB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(P,`IM<V=I9"`B3W5T8F]U;F0@4V5R=F5R
M(@IM<V=S='(@(E!O<W1A=7-G86YG<RU397)V97(B"@HC.B!T96UP;&%T97,O
M<&=P+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C$V-`HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#,@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,C@Y"FUS9VED(")01U`B"FUS9W-T<B`B4$=0(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHW"FUS9VED
M(")01U`@16YC<GEP="!-97-S86=E(@IM<V=S='(@(E9E<G-C:&S\<W-E;&X@
M*%!'4"DB"@HC.B!C;VUP;W-E+G!H<#HS,S4*;7-G:60@(E!'4"!%<G)O<CH@
M(@IM<V=S='(@(E!'4"U&96AL97(Z("(*"B,Z(&-O;7!O<V4N<&AP.C,Q-`IM
M<V=I9"`B4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L
M('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"B)01U`@1F5H;&5R.B!&_'(@9&5N
M('!E<G/V;FQI8VAE;B!P<FEV871E;B!38VAL_'-S96P@=VER9"!E:6X@4&%S
M<W=O<G0@(@HB8F5N]G1I9W0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B4$=0+45I;G-T96QL
M=6YG96XB"@HC.B!P9W`N<&AP.C,P"FUS9VED(")01U`@4&%S<W!H<F%S92!)
M;G!U="(*;7-G<W1R(")01U`@4&%S<W=O<G1E:6YG86)E(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C4U"FUS9VED(")01U`@4&5R<V]N86P@2V5Y<&%I
M<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R("(B"B)&_'(@9&5N(%IU9W)I9F8@875F(&1A<R!P97)S]FYL:6-H
M92!38VAL_'-S96QP86%R('=I<F0@96EN92!S:6-H97)E("(*(E-E<G9E<G9E
M<F)I;F1U;F<@8F5N]G1I9W0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,3<R"FUS9VED(")01U`@4'5B;&EC($ME>2!497AT(@IM<V=S='(@(E1E
M>'0@9&5S(/9F9F5N=&QI8VAE;B!01U`M4V-H;/QS<V5L<R(*"B,Z('!G<"YP
M:'`Z,30U"B,L('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O
M<B!<(B5S("@E<RE<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R
M("(B"B)$97(@]F9F96YT;&EC:&4@4$=0+5-C:&S\<W-E;"!F_'(@7"(E<R`H
M)7,I7"(@=W5R9&4@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N(@H*(SH@<&=P
M+G!H<#HR-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@
M9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@
M(D1E<B#V9F9E;G1L:6-H92!01U`M4V-H;/QS<V5L(&;\<B!<(B5S7"(@=W5R
M9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B
MUF9F96YT;&EC:&5R(%!'4"U38VAL_'-S96QB=6YD(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHX"FUS9VED(")01U`@4VEG;B!-
M97-S86=E(@IM<V=S='(@(E5N=&5R>F5I8VAN96X@*%!'4"DB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.CD*;7-G:60@(E!'4"!3
M:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")5;G1E<GIE:6-H;F5N('5N
M9"!V97)S8VAL_'-S96QN("A01U`I(@H*(SH@<&=P+G!H<#HQ.3@*;7-G:60@
M(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(D1E<B!P<FEV871E(%!'4"U38VAL_'-S96P@=W5R9&4@97)F;VQG<F5I8V@@
M9V5S<&5I8VAE<G0N(@H*(SH@<&=P+G!H<#HQ-S,*;7-G:60@(E!'4"!P=6)L
M:6,@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B1&5R(/9F9F5N
M=&QI8VAE(%!'4"U38VAL_'-S96P@=W5R9&4@97)F;VQG<F5I8V@@9V5S<&5I
M8VAE<G0N(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C0*;7-G
M:60@(E!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*
M;7-G<W1R(")$:64@4$=0+55N=&5R<W3\='IU;F<@=W5R9&4@875F(&1I97-E
M;2!3>7-T96T@9&5A:W1I=FEE<G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,C`W"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE
M('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)$:64@4$=0+55N=&5R
M<W3\='IU;F<@:7-T('IU<B!:96ET(&1E86MT:79I97)T+"!S;R!D87-S(&1I
M92!D:6=I=&%L92`B"B)5;G1E<G-C:')I9G0@;FEC:'0@_&)E<G!R_&9T('=E
M<F1E;B!K86YN+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-`IM
M<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@
M<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS
M9W-T<B`B(@HB1&EE(%!'4"U5;G1E<G-T_'1Z=6YG(&ES="!Z=7(@6F5I="!D
M96%K=&EV:65R="P@<V\@9&%S<R!D:64@3F%C:')I8VAT(&YI8VAT("(*(F5N
M='-C:&S\<W-E;'0@=V5R9&5N(&MA;FXN(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(*;7-G:60@(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S('!O<'5P
M('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R
M96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU
M<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H92!01U`@(@HB9F5A
M='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(D1I
M92!01U`M56YT97)S=/QZ=6YG(&)E;O9T:6=T(%!O<'5P+49E;G-T97(L('5M
M('IU(&9U;FMT:6]N:65R96XN(%=E;FX@26AR("(*(D)R;W=S97(@>G5R(%IE
M:70@<V\@96EN9V5S=&5L;'0@:7-T+"!D87-S(%!O<&]P+49E;G-T97(@=6YT
M97)D<OQC:W0@=V5R9&5N+"`B"B)M_'-S96X@<VEE(&1I97-E($5I;G-T96QL
M=6YG(.1N9&5R;BP@;V1E<B!D:64@4$=0+49U;FMT:6]N96X@=V5R9&5N(&YI
M8VAT("(*(G)I8VAT:6<@9G5N:W1I;VYI97)E;BXB"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G<W1R(")03U`S(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G:60@(E!/4#,@*$%U
M=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B4$]0,R`H075T;VUA=&ES
M8VAE(%!R;W1O:V]L;&5R:V5N;G5N9RDB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R(")03U`S
M(/QB97(@4U-,(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,C,*;7-G
M:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*
M;7-G<W1R(")03U`S(/QB97(@4U-,("AS96QF+7-I9VYE9"!:97)T:69I:V%T
M*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38X"FUS9VED(")0
M3U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B4$]0,R#\8F5R
M(%-33"`H<V5L9BUS:6=N960I(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R(")03U`S(&]H;F4@
M5$Q3(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHR,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")086=E("5D(&]F("5D(@IM<V=S='(@(E-E:71E
M("5D('9O;B`E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.3(*;7-G
M:60@(E!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4B"FUS9W-T
M<B`B4V5I=&4@;6ET(&1E<B!E<G-T96X@=6YG96QE<V5N96X@3F%C:')I8VAT
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y,PIM<V=I9"`B4&%G92!W
M:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(E-E:71E(&UI
M="!D97(@;&5T>G1E;B!U;F=E;&5S96YE;B!.86-H<FEC:'0B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R="AS*2(*
M;7-G<W1R(")496EL*&4I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R
M,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R(")087-S=V]R="(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@*$%G
M86EN*2(*;7-G<W1R(")087-S=V]R="`H5VEE9&5R:&]L96XI(@H*(SH@<VUI
M;64N<&AP.C(S,2!P9W`N<&AP.C,P-@IM<V=I9"`B4&%S<W!H<F%S92!S=6-C
M97-S9G5L;'D@=6YL;V%D960N(@IM<V=S='(@(D1A<R!087-S=V]R="!W=7)D
M92!F_'(@9&EE<V4@4VET>G5N9R!G96SV<V-H="XB"@HC.B!T96UP;&%T97,O
M<VUI;64O<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S<&AR
M87-E+FEN8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`B4&%S<W=O
M<G0Z(@H*(SH@<&=P+G!H<#HQ,#@*;7-G:60@(E!A<W-P:')A<V5S(&-A;FYO
M="!B92!E;7!T>2(*;7-G<W1R(")087-S=_9R=&5R(&3\<F9E;B!N:6-H="!L
M965R('-E:6XB"@HC.B!P9W`N<&AP.C$Q,`IM<V=I9"`B4&%S<W!H<F%S97,@
M9&\@;F]T(&UA=&-H(@IM<V=S='(@(D1I92!087-S=_9R=&5R('-T:6UM96X@
M;FEC:'0@_&)E<F5I;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S$*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3$*;7-G:60@(E!A<W-W;W)D
M(@IM<V=S='(@(E!A<W-W;W)T(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C0X"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E=A<G1U;F=S87)B96ET96X@;F%C
M:"!D97(@06YM96QD=6YG(&1U<F-H9OQH<F5N/R(*"B,Z(&%C;"YP:'`Z-S4@
M86-L+G!H<#HQ,#$*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@
M8V%N;F]T(&)E(&-H86YG960N(@IM<V=S='(@(D1I92!296-H=&4@9OQR(&1I
M97-E;B!"96YU='IE<B!K]FYN96X@;FEC:'0@9V7D;F1E<G0@=V5R9&5N+B(*
M"B,Z(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HV.3<@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I;&)O>"]L
M96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R(")097)S]FYL
M:6-H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")097)S
M;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")097)S]FYL:6-H92!!;F=A8F5N
M(@H*(SH@<&=P+G!H<#HQ,38*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D1A<R!P97)S]FYL
M:6-H92!01U`M4V-H;/QS<V5L<&%A<B!W=7)D92!E<F9O;&=R96EC:"!E<GIE
M=6=T+B(*"B,Z('!G<"YP:'`Z,3(S"FUS9VED(")097)S;VYA;"!01U`@:V5Y
M<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B1&EE('!E<G/V;FQI
M8VAE;B!01U`M4V-H;/QS<V5L('=U<F1E;B!E<F9O;&=R96EC:"!G96SV<V-H
M="XB"@HC.B!S;6EM92YP:'`Z,C`S"FUS9VED(")097)S;VYA;"!3+TU)344@
M8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S='(@(D5S('=U<F1E
M;B!+14E.12!P97)S]FYL:6-H96X@4R]-24U%+5IE<G1I9FEK871E(&EM<&]R
M=&EE<G0Z("(*"B,Z('-M:6UE+G!H<#HQ,C@*;7-G:60@(E!E<G-O;F%L(%,O
M34E-12!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")$:64@
M<&5R<_9N;&EC:&5N(%,O34E-12U38VAL_'-S96P@=W5R9&5N(&5R9F]L9W)E
M:6-H(&=E;/9S8VAT+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*
M;7-G:60@(E!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N
M9"!F;W)W87)D<S\B"FUS9W-T<B`B4VEG;F%T=7(@=F]R($%N='=O<G1E;B!U
M;F0@=V5I=&5R9V5L96ET971E;B!.86-H<FEC:'1E;B!E:6YF_&=E/R(*"B,Z
M(&-O;7!O<V4N<&AP.C(U.`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@
M365S<V%G92(*;7-G<W1R(")497AT=F5R<VEO;B!D97(@3F%C:')I8VAT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X.`IM<V=I9"`B(@HB4&QA>2!S
M;W5N9"!O;B!N97<@;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R
M('1O('-U<'!O<G0@96UB961D960@(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@
M86QL(&1O(&]N(%=I;F1O=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M
M<R!W:6QL("(*(G)E<75I<F4@82!P;'5G:6XN(@IM<V=S='(@(B(*(D%U9&EO
M<VEG;F%L(&)E:2!N975E;B!.86-H<FEC:'1E;B!A8G-P:65L96X_($1A>G4@
M8F5N]G1I9V5N(%-I92!E:6YE;B`B"B)"<F]W<V5R+"!D97(@96EN9V5B971T
M971E($%U9&EO9&%T96EE;B!U;G1E<G-T_'1Z="X@1F%S="!A;&QE(%=I;F1O
M=W,M('5N9"`B"B)-86,M0G)O=W-E<B!K]FYN96X@9&EE<RP@875F(&%N9&5R
M96X@4&QA='1F;W)M96X@=V5R9&5N('5N=&5R(%5M<W3D;F1E;B`B"B)0;'5G
M:6YS(&)E;O9T:6=T+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I
M<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y
M,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD
M97(Z(@IM<V=S='(@(D)I='1E(&=E8F5N(%-I92!E:6YE;B!.86UE;B!F_'(@
M9&5N(&YE=65N($]R9&YE<B!A;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$P-"!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C$P-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N
M97<@9F]L9&5R.B(*;7-G<W1R(")":71T92!G96)E;B!3:64@9&5N($YA;65N
M(&;\<B!D96X@;F5U96X@3W)D;F5R(&%N.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V9O;&1E<G,N:G,Z,3,Y"FUS9VED(")0;&5A<V4@96YT97(@=&AE
M(&YE=R!N86UE.B(*;7-G<W1R(")":71T92!D96X@;F5U96X@3F%M96X@96EN
M9V5B96XZ(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P
M:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY
M(&YE960@=&\@(@HB96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S
M('-E<W-I;VXN(@IM<V=S='(@(B(*(D)I='1E(&=E8F5N(%-I92!D87,@4&%S
M<W=O<G0@9OQR($EH<F5N('!R:79A=&5N(%!'4"U38VAL_'-S96P@86XN(%-I
M92!M_'-S96X@(@HB9&EE<V5S(%!A<W-W;W)T(&YU<B!E:6YM86P@<')O("5S
M+5-I='IU;F<@86YG96)E;BXB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H
M<F%S92YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N
M=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME
M>2X@66]U('=I;&P@;VYL>2!N965D("(*(G1O(&5N=&5R('1H:7,@<&%S<W!H
M<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"B)":71T92!G
M96)E;B!3:64@9&%S(%!A<W-W;W)T(&;\<B!):')E;B!P<FEV871E;B!3+TU)
M344M4V-H;/QS<V5L(&%N+B!3:64@(@HB;?QS<V5N(&1I97-E<R!087-S=V]R
M="!N=7(@96EN;6%L('!R;R`E<RU3:71Z=6YG(&%N9V5B96XN(@H*(SH@<F5C
M;VUP;W-E+G!H<#HY-@IM<V=I9"`B(@HB4&QE87-E(&QO9R!I;B!A9V%I;B!T
M;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.
M3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S
M<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R`B"B)L
M;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES
M(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@(@HB:&EJ86-K:6YG('EO=7(@
M<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC
M92XB"FUS9W-T<B`B(@HB0FET=&4@;65L9&5N(%-I92!S:6-H('=I961E<B!A
M;BP@=6T@9&%S(%-C:')E:6)E;B!D97(@3F%C:')I8VAT("(*(F9O<G1Z=7-E
M='IE;BX@5V5N;B!3:64@2T5)3D4@0V]O:VEE<R!Z=6QA<W-E;B!53D0@9&EE
M($YA8VAR:6-H="!I;B!E:6YE;2`B"B)E:6=E;F5N($9E;G-T97(@97)S=&5L
M;&5N+"!M_'-S96X@4VEE('-I8V@@875C:"!I;2!(875P=&9E;G-T97(@=VEE
M9&5R("(*(F%N;65L9&5N+B!$:65S(&ES="!N]G1I9RP@=6T@<&]T96YT:65L
M;&4@06YG<F5I9F5R(&1A=F]N(&%B>G5H86QT96X@26AR92`B"B)3:71Z=6YG
M('IU(/QB97)N96AM96XN($)I='1E(&5N='-C:'5L9&EG96X@4VEE(&1I97-E
M(%5N86YN96AM;&EC:&ME:71E;BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<Q"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D
M+B(*;7-G<W1R(")":71T92!G96)E;B!3:64@26AR(%!A<W-W;W)T(&%N+B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C<*;7-G:60@(E!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(D)I='1E(&=E8F5N
M(%-I92!):')E;B!"96YU='IE<FYA;65N(&%N+B(*"B,Z(&-O;7!O<V4N<&AP
M.C$P-B!L:6(O24U0+G!H<#HT-C,*;7-G:60@(E!L96%S92!R97-O;'9E(&%M
M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B0FET=&4@
M;65H<F1E=71I9V4@;V1E<B!U;F?\;'1I9V4@061R97-S96X@:V]R<FEG:65R
M96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHV,PIM
M<V=I9"`B4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O
M<FT@=&AI<R!A8W1I;VXN(@IM<V=S='(@(D)I='1E(&5I;F5N($]R9&YE<B!A
M=7-WY&AL96XL(&)E=F]R(%-I92!D:65S92!!:W1I;VX@9'5R8VAF_&AR96XN
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]J879A<V-R:7!T+FEN8SHT,0IM<V=I
M9"`B4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C
M:"XB"FUS9W-T<B`B0FET=&4@;6EN9&5S=&5N<R!E:6YE;B!/<F1N97(@9OQR
M(&1I92!3=6-H92!A;F=E8F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@
M9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B0FET=&4@;G5R
M(&5I;F5N($]R9&YE<B!F_'(@9&EE<V4@06MT:6]N(&%U<W?D:&QE;BXB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-S,*;7-G:60@(E!L
M96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB
M"FUS9W-T<B`B0FET=&4@=^1H;&5N(%-I92!A=7,@;V1E<B!E9&ET:65R96X@
M4VEE(')E8VAT<SHB"@HC.B!C;VYF:6<O;6]T9"YP:'`N9&ES=#HT,0IM<V=I
M9"`B4&]W97)E9"!B>2!(;W)D92(*;7-G<W1R(")0;W=E<F5D(&)Y($AO<F1E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-`IM<V=I9"`B4')E8V5D
M92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R
M(")3=')I8VAE("@G+2T@)RD@=F]R(&1E<B!3:6=N871U<B!E:6YF_&=E;C\B
M"@HC.B!S;6EM92YP:'`Z,C,W('!G<"YP:'`Z,C4S(&9I;'1E<G!R969S+G!H
M<#HS.0IM<V=I9"`B4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P9&%T960N
M(@IM<V=S='(@(D1I92!%:6YS=&5L;'5N9V5N('=U<F1E;B!E<F9O;&=R96EC
M:"!G97-P96EC:&5R="XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYI;F,Z,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")6;W)S8VAA=2(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*
M;7-G:60@(E!R979I;W5S($UE<W-A9V4B"FUS9W-T<B`B5F]R:&5R:6=E($YA
M8VAR:6-H="(*"B,Z(&UA:6QB;W@N<&AP.C,S,@IM<V=I9"`B4')E=FEO=7,@
M4&%G92(*;7-G<W1R(")396ET92!Z=7+\8VLB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S
M='(@(D1R=6-K96XB"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN
M8SHS.`IM<V=I9"`B4')I;W)I='DB"FUS9W-T<B`B4')I;W)I=.1T(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<V"FUS9VED(")0<FEV
M871E($ME>2!087-S=V]R9"(*;7-G<W1R(")087-S=V]R="!F_'(@<')I=F%T
M96X@4V-H;/QS<V5L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U.0IM
M<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT
M.R!D969A=6QT('1O($Y/(@IM<V=S='(@(DIE9&5S;6%L(&YA8VAF<F%G96X[
M('-T86YD87)D;>3?:6<@3D5)3B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@
M:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B2F5D97-M86P@;F%C
M:&9R86=E;CL@<W1A;F1A<F1MY-]I9R!*02(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM<V=S='(@
M(E!R;W1O:V]L;#HB"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HT,S`*;7-G:60@
M(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O<G0@:&%S(&)E96X@9&ES86)L
M960N(@IM<V=S='(@(B(*(D1I92!5;G1E<G-T_'1Z=6YG(&;\<B#V9F9E;G1L
M:6-H92!01U`M4V-H;/QS<V5L<V5R=F5R(&ES="!D96%K=&EV:65R="!W;W)D
M96XN(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHW"FUS9VED(")0
M=7)?9V4@1&5L971E9"(*;7-G<W1R(")%;F1G_&QT:6<@;/9S8VAE;B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I9"`B4'5R9V4@1&5L
M971E9"(*;7-G<W1R(")%;F1G_&QT:6<@;/9S8VAE;B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(T"FUS9VED(")0=7)G92!&;VQD97(H
M<RDB"FUS9W-T<B`B3W)D;F5R(&%U9G+D=6UE;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.38*;7-G:60@(E!U<F=E(%1R87-H(&AO=R!O9G1E;CHB
M"FUS9W-T<B`B5VEE(&]F="!S;VQL(&1E<B!087!I97)K;W)B(&=E;&5E<G0@
M=V5R9&5N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@
M(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H
M:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@(DYA8VAR:6-H=&5N(&EM(%!A
M<&EE<FMO<F(@;F%C:"!S;R!V:65L96X@5&%G96X@96YD9_QL=&EG(&SV<V-H
M96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B4'5R
M9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_(@IM<V=S='(@
M(D%L=&4@3F%C:')I8VAT96X@:6T@4&%P:65R:V]R8B!E;F1G_&QT:6<@;/9S
M8VAE;C\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S86=E
M<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B)60@3F%C:')I8VAT96X@
M:6T@4&%P:65R:V]R8B!G96SV<V-H="XB"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C,*;7-G:60@(E!U<F=I;F<@,2!M97-S
M86=E(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R("(Q($YA8VAR:6-H="!I
M;2!087!I97)K;W)B(&=E;/9S8VAT+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q
M=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S
M.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(E-P96EC:&5R
M<&QA='HM2V]N=&EN9V5N=#H@)2XR9DU"("\@)2XR9DU"("@E+C)F)24I(@H*
M(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")1=6]T82!S=&%T=7,Z("4N,F9-0B`O($Y/($Q)34E4(@IM<V=S
M='(@(E-P96EC:&5R<&QA='HM2V]N=&EN9V5N=#H@)2XR9DU"("\@2V5I;F4@
M0F5G<F5N>G5N9R(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B!.3R!,24U)5"(*
M;7-G<W1R(")3<&5I8VAE<G!L871Z+4MO;G1I;F=E;G0Z($ME:6YE($)E9W)E
M;GIU;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`P"B,L('!H<"UF
M;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(EII=&%T('9O;B`E
M9CHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR.0IM<V=I
M9"`B4F5B=6EL9"!&;VQD97(@5')E92(*;7-G<W1R(")/<F1N97)B875M(&YE
M=2!A=69B875E;B(*"B,Z(&QI8B]396%R8V@N<&AP.C8Q-PIM<V=I9"`B4F5C
M96EV960@3VXB"FUS9W-T<B`B16UP9F%N9V5N(&%M(@H*(SH@;&EB+U-E87)C
M:"YP:'`Z-C(U"FUS9VED(")296-E:79E9"!3:6YC92(*;7-G<W1R(")%;7!F
M86YG96X@<V5I="(*"B,Z(&QI8B]396%R8V@N<&AP.C8R,0IM<V=I9"`B4F5C
M96EV960@56YT:6PB"FUS9W-T<B`B16UP9F%N9V5N(&)I<R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D
M:7)E8U]T(@IM<V=S='(@(E]5;6QE:71E;B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8W0B"FUS
M9W-T<B`B56UL96ET96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z,3$P"FUS9VED(")2961I<F5C="!-97-S86=E(@IM<V=S='(@(DYA
M8VAR:6-H="!U;6QE:71E;B(*"B,Z(&-O;7!O<V4N<&AP.C@R-PIM<V=I9"`B
M4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S='(@(D1I97-E($YA8VAR:6-H
M="!U;6QE:71E;B(*"B,Z(&-O;7!O<V4N<&AP.C@X,`IM<V=I9"`B4F5D:7)E
M8W1I;F<@9F%I;&5D+B(*;7-G<W1R(")5;6QE:71U;F<@9F5H;&=E<V-H;&%G
M96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W,PIM<V=I9"`B4F5F
M<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(D]R9&YE<OQB97)S:6-H="!A
M:W1U86QI<VEE<F5N.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC
M.CD@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHT"FUS9VED(")296QO
M860B"FUS9W-T<B`B06MT=6%L:7-I97)E;B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+VAE860N:6YC.C,*;7-G:60@(E)E;&]A9"!6:65W(@IM<V=S='(@(D%N
M<VEC:'0@85]K='5A;&ES:65R96XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3(X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@
M(E)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@
M(D9R96DO1V5B=6-H="U);F9O<FUA=&EO;F5N(&UE<FME;BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.38X"FUS9VED(")296UE;6)E<B!T:&4@;&%S
M="!V:65W(@IM<V=S='(@(D1I92!L971Z=&4@06YS:6-H="!M97)K96XB"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E
M;6]T92!-86EL8F]X.B(*;7-G<W1R(")397)V97(M3W)D;F5R.B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I
M96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(D9E;&0@=F]N(&1E<B!3=6-H92!E
M;G1F97)N96XB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS,#4*;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T<B`B475E;&QE(&5N
M=&9E<FYE;B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*
M;7-G:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T<B`B3W)D;F5R('5M8F5N
M96YN96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2
M96YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M(@IM<V=S='(@(D]R9&YE<B!F_'(@9V5S96YD971E($YA8VAR:6-H=&5N(&%M
M($UO;F%T<V)E9VEN;B!U;6)E;F5N;F5N/R(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C0R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296YA;6EN9R!<(B5S7"(@=&\@
M7"(E<UPB(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*
M;7-G<W1R("(B"B)$:64@56UB96YE;FYU;F<@=F]N(%PB)7-<(B!N86-H(%PB
M)7-<(B!I<W0@9F5H;&=E<V-H;&%G96XN($UE;&1U;F<@9&5S($5M86EL+2(*
M(E-E<G9E<G,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,3`*;7-G:60@(E)E<&Q?>2!T;R!,:7-T(@IM<V=S='(@(DQ?:7-T
M92!!;G1W;W)T96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3`U"FUS9VED(")297!L86-E('=I=&@Z(@IM<V=S='(@(F5R<V5T>F5N
M(&1U<F-H.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHX"FUS9VED(")297!L>2(*;7-G<W1R(")!;G1W;W)T96XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$R(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT,3`*;7-G:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@(D%N='=O
M<G0@=F5R<V5N9&5T+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL(@IM<V=S='(@(D%L
M;&5N($%N='=O<G1E;B(*"B,Z(&-O;7!O<V4N<&AP.C<W,0IM<V=I9"`B4F5P
M;'D@=&\@06QL.B(*;7-G<W1R(")!;&QE;B!!;G1W;W)T96XZ(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$P"FUS9VED(")2
M97!L>2!T;R!,:7-T(@IM<V=S='(@(DQI<W1E($%N='=O<G1E;B(*"B,Z(&-O
M;7!O<V4N<&AP.C<W,PIM<V=I9"`B4F5P;'D@=&\@3&ES=#HB"FUS9W-T<B`B
M3&ES=&4@06YT=V]R=&5N.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@7T%L;"(*;7-G<W1R
M(")?06QL96X@06YT=V]R=&5N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4S,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,Y"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU-#D*;7-G:60@(E)E<&QY('=I=&@@3F]T
M(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(DUI="!<(DYI8VAT('5N=&5R
M<W3\='IT7"(M3F%C:')I8VAT(&%N='=O<G1E;BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3,W"FUS9VED(")297!L>2!W:71H(&9R964O8G5S
M>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B36ET($9R96DO1V5B=6-H
M="U);F9O<FUA=&EO;F5N(&;\<B!D:64@;N1C:'-T96X@>G=E:2!-;VYA=&4@
M86YT=V]R=&5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S8*
M;7-G:60@(E)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B36ET(&5R9G)A9W1E;B!&<F5I+T=E8G5C:'0M26YF
M;W)M871I;VYE;B!A;G1W;W)T96XN(@H*(SH@;65S<V%G92YP:'`Z,C<T"FUS
M9VED(")297!L>2U4;R(*;7-G<W1R(")!;G1W;W)T(&%N(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0R,`IM<V=I9"`B4F5P;'DM5&\Z("(*;7-G<W1R(")!;G1W
M;W)T(&%N.B`B"@HC.B!C;VUP;W-E+G!H<#HW-CD*;7-G:60@(E)E<&QY.B(*
M;7-G<W1R(")!;G1W;W)T96XZ(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E;G0B"FUS9W-T<B`B06QS
M(&ME:6X@4W!A;2!M96QD96XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(D%L<R!3<&%M
M(%]M96QD96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M.#0*;7-G:60@(E)E<75E<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(E],
M97-E8F5S=.1T:6=U;F<@86YF;W)D97)N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4W,PIM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G
M<W1R("),97-E8F5S=.1T:6=U;F=E;B!A;F9O<F1E<FX_(@H*(SH@;6%I;&)O
M>"YP:'`Z,3@X"FUS9VED(")297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%N9V5G96)E;F4@3F%C:')I8VAT(&YI8VAT(&=E9G5N9&5N
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.3(*;7-G:60@(E)E
M<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(D5R9F]R9&5R;&EC:&5R(%1E
M:6QN96AM97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,"!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,CD*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$V,@IM<V=I9"`B4F5S970B"FUS9W-T<B`B6G5R_&-K<V5T
M>F5N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-@IM<V=I9"`B
M4F5S<&]N9&5N="!3=&%T=7,@57!D871E9"XB"FUS9W-T<B`B4W1A='5S(&1E
M<R!!;G1W;W)T96YD96X@86MT=6%L:7-I97)T+B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,`IM<V=I9"`B4F5S=6UE(@IM
M<V=S='(@(E]&;W)T9OQH<F5N(@H*(SH@<F5C;VUP;W-E+G!H<#HY-PIM<V=I
M9"`B4F5S=6UE('EO=7(@<V5S<VEO;B(*;7-G<W1R(")7:65D97)H97)S=&5L
M;'5N9R!D97(@4VET>G5N9R(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHT-`IM<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#;VUP;W-I
M=&EO;EPB(@IM<V=S='(@(EIU<OQC:R!Z=2!<(DYE=64@3F%C:')I8VAT7"(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C,Q
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,0IM<V=I9"`B4F5T
M=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`B6G5R_&-K('IU("=.86-H<FEC
M:'1E;B!S86UM96QN)R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHV,"!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C(R"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`Q('1E;7!L871E<R]S;6EM92]N
M;W1A8W1I=F4N:6YC.C$U"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-#D@
M=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ-C,@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$W-0IM<V=I
M9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B6G5R_&-K('IU($5I;G-T
M96QL=6YG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S`W"FUS9VED
M("(B"B)2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE
M=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B
M(@HB3F%C:"!D96T@3/9S8VAE;BP@5F5R<V-H:65B96X@;V1E<B!+;W!I97)E
M;B!V;VX@3F%C:')I8VAT96X@>G5M($]R9&YE<B`B"B)Z=7+\8VMK96AR96X_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,PIM<V=I9"`B4F]L
M92(*;7-G<W1R(")2;VQL92(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(U"FUS9VED(")3+TU)344B"FUS9W-T
M<B`B4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T
M+FEN8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G<W1R
M(")697)S8VAL_'-S96QN("A3+TU)344I(@H*(SH@8V]M<&]S92YP:'`Z,S<Q
M"FUS9VED(")3+TU)344@17)R;W(Z("(*;7-G<W1R(")3+TU)344M1F5H;&5R
M.B`B"@HC.B!C;VUP;W-E+G!H<#HS-3`*;7-G:60@(E,O34E-12!%<G)O<CH@
M3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS
M9W-T<B`B(@HB4R]-24U%($9E:&QE<CH@1OQR(&1E;B!P97)S]FYL:6-H96X@
M<')I=F%T96X@4V-H;/QS<V5L('=I<F0@96EN(%!A<W-W;W)T("(*(F)E;O9T
M:6=T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3$*;7-G:60@(E,O
M34E-12!/<'1I;VYS(@IM<V=S='(@(E,O34E-12U%:6YS=&5L;'5N9V5N(@H*
M(SH@<VUI;64N<&AP.C0V"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U
M="(*;7-G<W1R(")3+TU)344@4&%S<W=O<G1E:6YG86)E(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B4R]-24U%(%!E<G-O;F%L
M($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B(@HB1OQR(&1E;B!:=6=R:69F(&%U9B!D87,@<&5R
M<_9N;&EC:&4@4V-H;/QS<V5L<&%A<B!W:7)D(&5I;F4@<VEC:&5R92`B"B)3
M97)V97)V97)B:6YD=6YG(&)E;O9T:6=T+B(*"B,Z('-M:6UE+G!H<#HQ,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@9F]R(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(B(*(D1E
M<B#V9F9E;G1L:6-H92!3+TU)344M4V-H;/QS<V5L(&;\<B!<(B5S7"(@=W5R
M9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N(@H*(SH@<VUI;64N<&AP.C$U.`IM
M<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*
M;7-G<W1R(")$97(@]F9F96YT;&EC:&4@4R]-24U%+5-C:&S\<W-E;"!W=7)D
M92!E<F9O;&=R96EC:"!G97-P96EC:&5R="XB"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C$P"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B
M"FUS9W-T<B`BUF9F96YT;&EC:&5R(%,O34E-12U38VAL_'-S96QB=6YD(@H*
M(SH@<VUI;64N<&AP.C(P-PIM<V=I9"`B4R]-24U%(%!U8FQI8R]0<FEV871E
M($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")$87,@]F9F
M96YT;&EC:&4O<')I=F%T92!38VAL_'-S96QP86%R('=U<F1E(&5R9F]L9W)E
M:6-H(&=E<W!E:6-H97)T+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y
M<'1?;&ES="YI;F,Z,3,*;7-G:60@(E,O34E-12!3:6=N($UE<W-A9V4B"FUS
M9W-T<B`B56YT97)Z96EC:&YE;B`H4R]-24U%*2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*;7-G:60@(E,O34E-12!3:6=N
M+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")5;G1E<GIE:6-H;F5N('5N9"!V
M97)S8VAL_'-S96QN("A3+TU)344I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO
M=&%C=&EV92YI;F,Z-`IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L
M960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(D1I92!3+TU)344M56YT97)S
M=/QT>G5N9R!W=7)D92!A=68@9&EE<V5M(%-Y<W1E;2!D96%K=&EV:65R="XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB
M4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H
M92!M97-S86=E(&ES('5N86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S
M='(@(B(*(D1I92!3+TU)344M56YT97)S=/QT>G5N9R!I<W0@>G5R(%IE:70@
M9&5A:W1I=FEE<G0L('-O(&1A<W,@9&EE($YA8VAR:6-H="`B"B)N:6-H="!E
M;G1S8VAL_'-S96QT('=E<F1E;B!K86YN+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,3<S"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N
M;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S
M<V%G92!C86YN;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R("(B"B)$:64@
M4R]-24U%+55N=&5R<W3\='IU;F<@:7-T('IU<B!:96ET(&1E86MT:79I97)T
M+"!S;R!D87-S(&1E<B!);FAA;'0@9&EE<V5R("(*(G5N=&5R<V-H<FEE8F5N
M96X@3F%C:')I8VAT(&YI8VAT(&%N9V5Z96EG="!W97)D96X@:V%N;BXB"@HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T-@IM<V=I9"`B(@HB4R]-
M24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG
M;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B
M(@HB1&EE(%,O34E-12U5;G1E<G-T_'1Z=6YG(&ES="!Z=7(@6F5I="!D96%K
M=&EV:65R="P@<V\@9&%S<R!D:64@9&EG:71A;&4@(@HB56YT97)S8VAR:69T
M(&YI8VAT(/QB97)P<OQF="!W97)D96X@:V%N;BXB"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(')E
M<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O
M=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN
M9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E("(*
M(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN
M(@IM<V=S='(@(B(*(D1I92!3+TU)344M56YT97)S=/QZ=6YG(&)E;O9T:6=T
M(%!O<'5P+49E;G-T97(L('5M('IU(&9U;FMT:6]N:65R96XN(%=E;FX@(@HB
M26AR($)R;W=S97(@>G5R(%IE:70@<V\@96EN9V5S=&5L;'0@:7-T+"!D87-S
M(%!O<&]P+49E;G-T97(@=6YT97)D<OQC:W0@(@HB=V5R9&5N+"!M_'-S96X@
M<VEE(&1I97-E($5I;G-T96QL=6YG(.1N9&5R;BP@;V1E<B!D:64@4R]-24U%
M+49U;FMT:6]N96X@(@HB=V5R9&5N(&YI8VAT(')I8VAT:6<@9G5N:W1I;VYI
M97)E;BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P-`IM<V=I
M9"`B4TU44"(*;7-G<W1R(")33510(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C4S"FUS9VED(")37W5B:F5C="(*;7-G<W1R(")"971R
M95]F9B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,V,0IM
M<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R(")?2V]P:64@<W!E:6-H
M97)N(&EN("(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHS,@IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B4W!E:6-H97)N('5N
M=&5R(@H*(SH@<V5A<F-H+G!H<#HS,#0@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C8W"FUS9VED(")3879E(@IM<V=S='(@(E-P96EC:&5R;B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4S-`IM<V=I9"`B
M4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O
M;&1E<C\B"FUS9W-T<B`B(@HB06YHY&YG92!Z=7-A;6UE;B!M:70@3F%C:')I
M8VAT96X@:6T@3W)D;F5R(&;\<B!G97-E;F1E=&4@3F%C:')I8VAT96X@(@HB
M<W!E:6-H97)N/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R.`IM<V=I9"`B
M4V%V92!$<F%F="(*;7-G<W1R(")%;G1W=7)F('-P96EC:&5R;B(*"B,Z('-A
M=F5I;6%G92YP:'`Z-#(*;7-G:60@(E-A=F4@26UA9V4B"FUS9W-T<B`B0FEL
M9"!S<&5I8VAE<FXB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C(X"FUS
M9VED(")3879E($EM86=E(&EN($=A;&QE<GDB"FUS9W-T<B`B0FEL9"!I;B!'
M86QE<FEE('-P96EC:&5R;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHU.2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC.B!T96UP
M;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,R!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,PIM
M<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(D5I;G-T96QL=6YG96X@<W!E
M:6-H97)N(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P
M"FUS9VED(")3879E(%-T871I;VYE<GDB"FUS9W-T<B`B5F]R;&%G92!S<&5I
M8VAE<FXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C@*;7-G:60@(E-A=F4@
M7T1R869T(@IM<V=S='(@(E]%;G1W=7)F('-P96EC:&5R;B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%V
M92!A<R(*;7-G<W1R(")3<&5I8VAE<FX@=6YT97(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(Q"FUS9VED(")3879E(&1R869T<R!A<R!U;G-E96X_
M(@IM<V=S='(@(D5N=_QR9F4@86QS('5N9V5L97-E;B!S<&5I8VAE<FX_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-C$*;7-G:60@(E-A=F4@<F5C
M:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@
M8F]O:S\B"FUS9W-T<B`B16UP9N1N9V5R(&%U=&]M871I<V-H(&EM(%-T86YD
M87)D861R97-S8G5C:"!S<&5I8VAE<FX_(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHQ,C,*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER='5A
M;"!F;VQD97(_(@IM<V=S='(@(E-U8VAE(&%L<R!V:7)T=65L;&5N($]R9&YE
M<B!S<&5I8VAE<FX_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM
M<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(D=E<V5N9&5T92!.86-H
M<FEC:'1E;B!S<&5I8VAE<FX_(@H*(SH@8V]M<&]S92YP:'`Z,3(V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@HB1&5R
M($5N='=U<F8@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX@365L
M9'5N9R!D97,@16UA:6PM4V5R=F5R<SH@)7,B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$Y.2!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C$Q"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C4T"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B4W5C:&4B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VAE861E<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN
M8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@)7,B"FUS9W-T<B`B
M4W5C:&5N(&EN("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,`IM
M<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`B4W5C:&5I;G-T96QL=6YG
M96XB"@HC.B!S96%R8V@N<&AP.C(U.`IM<V=I9"`B4V5A<F-H(%)E<W5L=',B
M"FUS9W-T<B`B4W5C:&5R9V5B;FES<V4B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C$T('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,S$*;7-G:60@(E-E96XB"FUS9W-T<B`B1V5L97-E;B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z.0IM<V=I9"`B4V5L96-T(@IM<V=S='(@
M(D%U<W=A:&PB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M-S`*;7-G:60@(E-E;&5C="!!;F]T:&5R($%C8V]U;G0B"FUS9W-T<B`B06YD
M97)E<R!+;VYT;R!A=7-WY&AL96XB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z,S8*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B1&%T
M=6T@875S=^1H;&5N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC
M.C$P"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R(")7Y&AL96X@4VEE
M(&5I;B!&96QD(&%U<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,Q-0IM<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B
M5F]R;&%G92!A=7-WY&AL96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-0IM<V=I9"`B4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A
M9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R("(B
M"B)7Y&AL96X@4VEE(&1I92!!9')E<W-B_&-H97(@>G5M(%-U8VAE;B!N86-H
M('5N9"!(:6YZ=6;\9V5N('9O;B!N975E;B`B"B)!9')E<W-E;B!A=7,N(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I9"`B4V5L96-T
M(&%L;"(*;7-G<W1R(")!;&QE(&%U<W?D:&QE;B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L96-T(&%L;"!F
M:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS
M9W-T<B`B5^1H;&5N(%-I92!D:64@1F5L9&5R(&%U<RP@:6X@9&5N96X@;F%C
M:"!.86UE;B!G97-U8VAT('=E<F1E;B!S;VQL+B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@
M86X@86-C;W5N="(*;7-G<W1R(")+;VYT;R!A=7-WY&AL96XB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@Y"FUS9VED(")396QE8W0@;F]N92(*
M;7-G<W1R(")+96EN96X@875S=^1H;&5N(@H*(SH@=&5M<&QA=&5S+W-A=F5I
M;6%G92]S879E:6UA9V4N:6YC.CD*;7-G:60@(E-E;&5C="!T:&4@9V%L;&5R
M>2!T;R!S879E('1H92!I;6%G92!I;BXB"FUS9W-T<B`B5^1H;&5N(%-I92!D
M:64@1V%L97)I92P@:6X@9&5R(&1A<R!":6QD(&=E<W!E:6-H97)T('=E<F1E
M;B!S;VQL(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T
M+FEN8SHR,0IM<V=I9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM
M<V=S='(@(E?D:&QE;B!3:64@9&5N(%-E<G9E<G1Y<"!A=7,B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*;7-G:60@(E-E;&5C
M=&5D($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(D%U<V=E=^1H;'1E($%D<F5S
M<V+\8VAE<CHB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@
M(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`B4V-H;/QS
M<V5L('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('-C:&EC:V5N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PIM<V=I9"`B4V5N
M9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T<B`B06MT=65L;&4@26YF;W)M
M871I;VYE;B!V97)S96YD96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHV-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C8*
M;7-G:60@(E-E;F0@365S<V%G92(*;7-G<W1R(")396YD96XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$R-@IM<V=I9"`B4V5N9"!M97-S
M86=E('=I=&AO=70@82!3=6)J96-T/R(*;7-G<W1R(")$:64@3F%C:')I8VAT
M(&]H;F4@96EN($)E=')E9F8@=F5R<V-H:6-K96X_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8Y,@IM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE
M;B!R97%U97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B3&5S96)E<W3D
M=&EG=6YG('-C:&EC:V5N+"!W96YN('9O;2!!8G-E;F1E<B!G97?\;G-C:'0_
M(@H*(SH@9F]L9&5R<RYP:'`Z,S<X"FUS9VED(")396YT(&UA:6P@9F]L9&5R
M(@IM<V=S='(@(D]R9&YE<B!F_'(@9V5S96YD971E($YA8VAR:6-H=&5N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I
M9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`B3W)D;F5R(&;\<B!G97-E
M;F1E=&4@3F%C:')I8VAT96XZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHQ,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-#4*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-3(*;7-G:60@(E-E<G9E<B(*;7-G
M<W1R(")%;6%I;"U397)V97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C,*;7-G:60@(E-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(D5M86EL+5-E<G9E<BT@=6YD($]R9&YE<BU%:6YS=&5L;'5N9V5N(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(S"FUS9VED(")3
M97)V97(Z(@IM<V=S='(@(E-E<G9E<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P
M96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S86=E<RXB"FUS9W-T
M<B`B(@HB3&5G96X@4VEE(&9E<W0L('=A<R!N86-H(&1E;2!,]G-C:&5N('5N
M9"!697)S8VAI96)E;B!V;VX@3F%C:')I8VAT96X@(@HB<&%S<VEE<F5N('-O
M;&PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R.0IM<V=I9"`B4V5T
M('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN9R!M97-S86=E
M<S\B"FUS9W-T<B`B4')I;W)I=.1T(&)E:6T@17)S=&5L;&5N('9O;B!N975E
M;B!.86-H<FEC:'1E;B!S971Z96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Q"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(D=E;65I;G-A
M;64@3W)D;F5R(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C@V"FUS9VED
M(")3:&%R92!M86EL(&9O;&1E<G,B"FUS9W-T<B`B1V5M96EN<V%M92!/<F1N
M97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E
M('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@
M(E1E:6QE;B!3:64@26AR92!/<F1N97(@;6ET(&%N9&5R96X@0F5N=71Z97)N
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3<*;7-G:60@(B(*(E-H
M;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@
M:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL
M>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B(@HB4V]L;&5N(&=R
M]M]E<F4@06)S8VAN:71T92!Z:71I97)T96X@5&5X=&5S('-T86YD87)D;>3?
M:6<@86YG97IE:6=T(&]D97(@(@HB=F5R<W1E8VMT('=E<F1E;C\@4VEE(&OV
M;FYE;B!D:64@06YS:6-H="!I;2!497AT('5M<V-H86QT96XL(&5G86P@=V5L
M8VAE("(*(D5I;G-T96QL=6YG(%-I92!WY&AL96XN(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D>2!O9B!T97AT
M+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D871A/R(*;7-G
M<W1R(")3;VQL(&EM($EN:&%L="!V;VX@5&5X=&YA8VAR:6-H=&5N(&YA8V@@
M4$=0+41A=&5N(&=E<W5C:'0@=V5R9&5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@
M8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R("(B"B)3
M;VQL(&1A<R!.86-H<FEC:'1E;F9E;G-T97(@;F%C:"!D96T@4W!E:6-H97)N
M(&5I;F5S($5N='=U<F9E<R!G97-C:&QO<W-E;B`B"B)W97)D96X_(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0*;7-G:60@(E-H;W5L9"!Y;W5R(%!'
M4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@
M8GD@9&5F875L=#\B"FUS9W-T<B`B(@HB4V]L;"!):'(@]F9F96YT;&EC:&5R
M(%!'4"U38VAL_'-S96P@<W1A;F1A<F1MY-]I9R!A;B!):')E($YA8VAR:6-H
M=&5N("(*(F%N9V5HY&YG="!W97)D96X_(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHY,@IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R
M(")!;&QE($]R9&YE<B!A;GIE:6=E;B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VAE861E<G,N:6YC.C8W"FUS9VED(")3:&]W($%L;"!(96%D97)S(@IM<V=S
M='(@(D%L;&4B"@HC.B!M86EL8F]X+G!H<#HS-3`*;7-G:60@(E-H;W<@1&5L
M971E9"(*;7-G<W1R("):96EG92!G96SV<V-H=&4B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D($AE
M861E<G,B"FUS9W-T<B`B16EN9F%C:"(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VAE861E<G,N:6YC.C<P"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O
M<FUA=&EO;B(*;7-G<W1R(")-86EL:6YG;&ES=&4B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.CDR"FUS9VED(")3:&]W($]N;'D@4W5B<V-R:6)E
M9"!&;VQD97)S(@IM<V=S='(@(DYU<B!E:6YG96)L96YD971E($]R9&YE<B!A
M;GIE:6=E;B(*"B,Z(&9O;&1E<G,N<&AP.C(X-`IM<V=I9"`B4VAO=R!5;G-U
M8G-C<FEB960B"FUS9W-T<B`B075S9V5?8FQE;F1E=&4@3W)D;F5R(&%N>F5I
M9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y-@IM<V=I9"`B4VAO
M=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F
M<F]M(&UE<W-A9V5S/R(*;7-G<W1R(")3>6UB;VP@>G5M($5N=&9E<FYE;B!V
M;VX@06YHY&YG96X@96EN97(@3F%C:')I8VAT(&%N>F5I9V5N/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.3$*;7-G:60@(E-H;W<@;&5G96YD(&EN
M('1H92!M86EL8F]X('9I97<_(@IM<V=S='(@(D9A<F)L96=E;F1E(&EN(&1E
M<B!/<F1N97)A;G-I8VAT(&%N>F5I9V5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,CD*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M
M97-S86=E<R!O;FQY/R(*;7-G<W1R(")6;W)S8VAA=2!N=7(@9OQR('5N9V5L
M97-E;F4@3F%C:')I8VAT96X@86YZ96EG96X_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@S-PIM<V=I9"`B4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP
M<S\B"FUS9W-T<B`B5F]R<V-H874@:6X@96EN96T@5&]O;'1I<"!A;GIE:6=E
M;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8V"FUS9VED(")3:&]W
M('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@
M(EPB2V]N=&5N7"(M4WEM8F]L(&EN(&1E<B!-96[\>F5I;&4@86YZ96EG96X_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDX"FUS9VED(")3:&]W
M('1H92!);6%G97,B"FUS9W-T<B`B0FEL9&5R(&%N>F5I9V5N(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F
M:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B1FEL=&5R<WEM
M8F]L(&EN(&1E<B!-96[\>F5I;&4@86YZ96EG96X_(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C,Q"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M
M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(D=E<V%M='IA:&P@9&5R($YA8VAR
M:6-H=&5N(&EM($]R9&YE<B!A;GIE:6=E;C\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C4T"FUS9VED(")3:&]W;B(*;7-G<W1R(")!;F=E>F5I9W0B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0R
M"FUS9VED(")3:5]Z92(*;7-G<W1R(")?1W+VWV4B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C$W"FUS9VED(")3:6=N960B"FUS9W-T<B`B
M56YT97)S8VAR:65B96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")'<O;?92(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3$*;7-G:60@
M(E-O<G0@8GD@07)R:79A;"(*;7-G<W1R(")3;W)T:65R96X@;F%C:"!!;FMU
M;F9T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM<V=S='(@(E-O<G1I97)E;B!N
M86-H($1A='5M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHR-@IM<V=I9"`B4V]R="!B>2!&<F]M($%D9')E<W,B"FUS9W-T
M<B`B4V]R=&EE<F5N(&YA8V@@06)S96YD97(B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0Q"FUS9VED(")3;W)T(&)Y($UE
M<W-A9V4@4VEZ92(*;7-G<W1R(")3;W)T:65R96X@;F%C:"!'<O;?92(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S8*;7-G
M:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R(")3;W)T:65R96X@;F%C:"!"
M971R969F(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHS,0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B4V]R=&EE
M<F5N(&YA8V@@5&AE;6$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C(Q"FUS9VED(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS
M9W-T<B`B4V]R=&EE<F5N(&YA8V@@16UP9N1N9V5R(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-P86US96QE8W0N:6YC.C(S"FUS9VED(")3<&%M(&9O;&1E<CHB
M"FUS9W-T<B`B4W!A;2U/<F1N97(Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,S0T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<G,B"FUS
M9W-T<B`B4V]N9&5R>F5I8VAE;B(*"B,Z('-E87)C:"YP:'`Z,3,W"FUS9VED
M(")3<&5C:6%L(%9I<G1U86P@1F]L9&5R<R!C86YN;W0@8F4@961I=&5D+B(*
M;7-G<W1R(")6:7)T=65L;&4@4W!E>FEA;&]R9&YE<B!K]FYN96X@;FEC:'0@
M8F5A<F)E:71E="!W97)D96XN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S0Q"FUS9VED(")3<&5L;"!#:&5C:R(*;7-G<W1R(")296-H
M='-C:')E:6)U;F<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-#8*;7-G:60@(E-P96QL($-H96-K97(B"FUS9W-T<B`B4F5C:'1S8VAR
M96EB<'+\9G5N9R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@
M(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@(E)E8VAT<V-H<F5I8G!R
M_&9U;F<@8F5E;F1E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*
M;7-G:60@(E-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@
M8VAE8VMI;F<N(@IM<V=S='(@(E)E8VAT<V-H<F5I8F9E:&QE<B!P<F\@4V5I
M=&4@8F5I(&1E<B!296-H='-C:')E:6)P<OQF=6YG+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,#<@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4P.0HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C0R(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-#0*;7-G:60@(E-T87)T(@IM<V=S='(@(D)E
M9VEN;B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHY('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P.0IM<V=I9"`B4W1A=&EO
M;F5R>2(*;7-G<W1R(")6;W)L86=E;B(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHR-@IM<V=I9"`B4W1A=&EO;F5R>2!N86UE.B(*;7-G
M<W1R(")6;W)L86=E;FYA;64Z(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@
M(E9O<FQA9V5N='EP.B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B5F]R;&%G93HB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@S"FUS9VED(")3=&%T
M=7,B"FUS9W-T<B`B4W1A='5S(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP
M.C(S.0IM<V=I9"`B4W1R:7`@071T86-H;65N="(*;7-G<W1R(")!;FAA;F<@
M96YT9F5R;F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,0IM<V=I
M9"`B4W1R:7`@;&EN96)R96%K<S\B"FUS9W-T<B`B6F5I;&5N_&UB<OQC:&4@
M96YT9F5R;F5N/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,S<*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(D)E=%]R969F
M(@H*(SH@;65S<V%G92YP:'`Z,C<U('1H<F5A9"YP:'`Z,34U('1E;7!L871E
M<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C4*(SH@;&EB+U-E87)C:"YP:'`Z
M-C`U"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D)E=')E9F8B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3`Y"FUS9VED(")3=6)J96-T($9I96QD(@IM
M<V=S='(@(D)E=')E9F9Z96EL92(*"B,Z('-E87)C:"YP:'`Z,S`V('1E;7!L
M871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.`HC.B!T96UP;&%T97,O
M<VUI;64O<&%S<W!H<F%S92YI;F,Z,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR
M87-E+FEN8SHS,0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(D%B<V-H:6-K96XB
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B
M4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R(")/<F1N97(@96EN8FQE
M;F1E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@U(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")%<F9O;&<B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U
M9V=E<W1I;VYS(@IM<V=S='(@(E9O<G-C:&SD9V4B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C4Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-C$*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B6G5S86UM96YF87-S=6YG(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,SDU('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Y.`IM<V=I9"`B4W=I=&-H($-O;7!O
M<VET:6]N($UE=&AO9"(*;7-G<W1R(")%9&ET:65R;6]D=7,@=6US8VAA;'1E
M;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Y.0IM<V=I
M9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I;VXB"FUS9W-T<B`B6G5M($A4
M34PM36]D=7,@=V5C:'-E;&XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHS.3D*;7-G:60@(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O
M<VET:6]N(@IM<V=S='(@(EIU;2!497AT+4UO9'5S('=E8VAS96QN(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#$T"FUS9VED(")495]X
M="(*;7-G<W1R(")?5&5X="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HR-S`*;7-G:60@(E1E;G1A=&EV93H@(@IM<V=S='(@(E5N=&5R(%9O<F)E
M:&%L=#H@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-@IM<V=I
M9"`B5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`B06YF<F%G
M92!V;W)LY'5F:6<@86YN96AM96XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S4T"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R
M(")6;W)LY'5F:6<@86YG96YO;6UE;B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N
M<&AP(@IM<V=S='(@(D1I92!.=71Z=6YG<V)E9&EN9W5N9V5N('=U<F1E;B!I
M;B!C;VYF+G!H<"!N:6-H="!A;F=E9V5B96XN(@H*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C,P"FUS9VED(")497AT(@IM<V=S='(@(E1E
M>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30S"FUS9VED(")4:&4@
M1G)O;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z
M(@IM<V=S='(@(D1I92!6;VXZ(%-P86QT92!D97(@3F%C:')I8VAT('-O;&P@
M<V\@=F5R;&EN:W0@=V5R9&5N.B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M-3(U"FUS9VED("(B"B)4:&4@24U!4"!S97)V97(@9&]E<R!N;W0@87!P96%R
M('1O('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"`B"B)S96QE
M8W1E9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB1&5R($E-05`M4V5R=F5R('-C:&5I;G0@9&EE(&%U
M<V=E=^1H;'1E($%N;65L9&5M971H;V1E(&YI8VAT('IU("(*(G5N=&5R<W3\
M='IE;BX@0FET=&4@:V]N=&%K=&EE<F5N(%-I92!):')E;B!3>7-T96UA9&UI
M;FES=')A=&]R+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP
M:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G
M<W1R(")$:64@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO
M861E9"`E<RXB"FUS9W-T<B`B1&EE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K
M(&MA;FX@)7,@:&5R=6YT97)G96QA9&5N('=E<F1E;BXB"@HC.B!F971C:&UA
M:6QP<F5F<RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U
M;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D1A<R!+;VYT
M;R!<(B5S7"(@=W5R9&4@9V5L]G-C:'0N(@H*(SH@9F5T8VAM86EL<')E9G,N
M<&AP.C<T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<
M(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B1&%S($MO;G1O(%PB)7-<(B!W
M=7)D92!G97-P96EC:&5R="XB"@HC.B!A='1A8VAM96YT+G!H<#HT,PIM<V=I
M9"`B5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N9"XB"FUS9W-T<B`B1&5R
M($%N:&%N9R!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S$*;7-G:60@(E1H92!C86QE;F1A<B!D871A(&ES
M(&EN=F%L:60B"FUS9W-T<B`B1&EE($MA;&5N9&5R9&%T96X@<VEN9"!U;F?\
M;'1I9R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#(*
M;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E
M(&)E;&]W+B(*;7-G<W1R(")$97(@26YH86QT(&1E<B!-86-I;G1O<VAD871E
M:2!B969I;F1E="!S:6-H('5N=&5N+B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HX-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@
M8F4@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(D1I92!A:W1U96QL96X@
M3W)D;F5R(%PB)7-<(B!W97)D96X@;F%C:"!<(B5S7"(@=6UB96YA;FYT+B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,#<*;7-G:60@(B(*(E1H92!C
M=7)R96YT(&QI<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD
M97(@8V]U;&0@;F]T(&)E(')E=')I979E9"(*;7-G<W1R("(B"B)$:64@86MT
M=65L;&4@3&ES=&4@9&5R($)E;G5T>F5R+"!D:64@6G5G<FEF9B!A=68@9&EE
M<V5N($]R9&YE<B!H86)E;BP@:V]N;G1E("(*(FYI8VAT(&%U<V=E;&5S96X@
M=V5R9&5N(@H*(SH@8V]M<&]S92YP:'`Z,3(W,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F
M;VQD97(N(@IM<V=S='(@(D1E<B!%;G1W=7)F('=U<F1E(&EM($]R9&YE<B!<
M(B5S7"(@9V5S<&5I8VAE<G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C$T,`IM<V=I9"`B5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A
M;&5N9&%R+B(*;7-G<W1R(")$97(@5&5R;6EN('=U<F1E($EH<F5M($MA;&5N
M9&5R(&AI;GIU9V5F_&=T+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N
M9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEE;&0@7"(E<UPB
M(&-A;B=T(&)E(&5X<&%N9&5D+B(*;7-G<W1R(")$87,@7"(E<UPB+49E;&0@
M:V]N;G1E(&YI8VAT('9E<G9O;&QS=.1N9&EG="!W97)D96XN(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D1E<B!/<F1N97(@
M7"(E<UPB(&5X:7-T:65R="!B97)E:71S(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,34P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB
M(&-O;G1A:6YS(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@
M;6%Y(&-A=7-E("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D1E<B!.86UE(&1E<R!/<F1N
M97)S(%PB)7-<(B!E;G1HY&QT('5N9_QL=&EG92!:96EC:&5N+"!W87,@>G4@
M4')O8FQE;65N("(*(F;\:')E;B!K]FYN=&4N($)I='1E('=E;F1E;B!3:64@
M<VEC:"!A;B!):')E;B!3>7-T96TM061M:6YI<W1R871O<BXB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I
M8F5D('1O(&ET+B(*;7-G<W1R(")$97(@3W)D;F5R(%PB)7-<(B!W=7)D92!E
M<G-T96QL="P@86)E<B!N;V-H(&YI8VAT(&5I;F=E8FQE;F1E="XB"@HC.B!L
M:6(O1F]L9&5R+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O
M;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U
M8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B1&5R($]R9&YE<B!<(B5S7"(@
M=W5R9&4@9V5L]G-C:'0L(&%B97(@;F]C:"!N:6-H="!A=7-G96)L96YD970N
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)$97(@3W)D;F5R(%PB
M)7-<(B!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N+B!-96QD=6YG(&1E
M<R!%;6%I;"U397)V97)S(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C(R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@9&5L
M971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B
M"B)$97(@3W)D;F5R(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N+B!-96QD=6YG(&1E<R!%;6%I;"U397)V97)S.B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N(@IM<V=S='(@(D1E<B!/
M<F1N97(@7"(E<UPB('=U<F1E(&5R9F]L9W)E:6-H(&5R<W1E;&QT+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(D1E<B!/<F1N97(@7"(E<UPB('=U<F1E(&5R9F]L9W)E:6-H(&=E;/9S
M8VAT+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M
M960@=&\@7"(E<UPB+B(*;7-G<W1R(")$97(@3W)D;F5R(%PB)7-<(B!W=7)D
M92!E<F9O;&=R96EC:"!N86-H(%PB)7-<(B!U;6)E;F%N;G0N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W1N968N<&AP.CDT"FUS9VED(")4:&4@9F]L;&]W:6YG
M(&9I;&5S('=E<F4@871T86-H960@=&\@=&AI<R!P87)T.B(*;7-G<W1R(")&
M;VQG96YD92!$871E:65N('=A<F5N(&%N(&1I97-E;B!496EL(&%N9V5HY&YG
M=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P;W!U<"YJ<SHU.0IM<V=I
M9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D
M+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@(@HB=&\@8FQO
M8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB1&%S($1I86QO9V9E;G-T
M97(@>G5M(%-P96EC:&5R;B!D97,@0FEL9&5S(&MO;FYT92!N:6-H="!G9?9F
M9FYE="!W97)D96XN("(*(E9I96QL96EC:'0@:&%B96X@4VEE($EH<F5N($)R
M;W=S97(@<V\@96EN9V5S=&5L;'0L(&1A<W,@97(@4&]P=7`M1F5N<W1E<B`B
M"B)B;&]C:VEE<G0_(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P
M,`IM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A
M=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B
M;V]K+B(*;7-G<W1R("(B"B)$:64@0FEL9&5R('=E<F1E;B!A;F=E>F5I9W0L
M('=E:6P@<VEC:"!D97(@06)S96YD97(@:6X@26AR96T@061R97-S8G5C:"`B
M"B)B969I;F1E="XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW
M-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W
M:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(D1E<B!%;6%I;"U397)V97(@
M:&%T(&9O;&=E;F1E($9E:&QE<FUE;&1U;F<@97)Z975G=#HB"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0IM<V=I9"`B5&AE(&UA
M:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N
M86P@;65S<V%G93HB"FUS9W-T<B`B1&5R($5M86EL+5-E<G9E<B!H870@9F]L
M9V5N9&4@3F%C:')I8VAT(&=E;F5R:65R=#HB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R
M871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(D1E<B!%;6%I
M;"U397)V97(@:&%T(&9O;&=E;F1E($YA8VAR:6-H="!E<GIE=6=T.B(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B1&5R($]R
M9&YE<B`E<R!I<W0@8F5R96ET<R!L965R+B(*"B,Z(&QI8B]&971C:&UA:6PN
M<&AP.C(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!<(B5S
M7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@
M;&EM:70N(@IM<V=S='(@(B(*(D1I92!.86-H<FEC:'0@7"(E<UPB('9O;B!<
M(B5S7"(@*"5D($)Y=&5S*2#\8F5R<V-H<F5I=&5T(&1I92!M87AI;6%L92!'
M<O;?92`B"B)F_'(@:&5R=6YT97)Z=6QA9&5N92!.86-H<FEC:'1E;BXB"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PIM<V=I9"`B
M5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%
M>&ET:6YG+B(*;7-G<W1R(")$:64@3F%C:')I8VAT+"!D:64@97)S=&5L;'0@
M=W5R9&4L(&ES="!G97-C:&QO<W-E;B!W;W)D96XN($%B8G)U8V@N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,C8*;7-G:60@(E1H92!M
M97-S86=E(&1O97,@;F]T(&AA=F4@82!3=6)J96-T(&5N=&5R960N(@IM<V=S
M='(@(E-I92!H86)E;B!F_'(@9&EE<V4@3F%C:')I8VAT(&ME:6YE;B!"971R
M969F(&%N9V5G96)E;BXB"@HC.B!M97-S86=E+G!H<#HQ-#@*;7-G:60@(E1H
M92!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D1I92!.86-H
M<FEC:'0@=W5R9&4@9V5L]G-C:'0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,SDW"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE
M9"XB"FUS9W-T<B`B1&EE($YA8VAR:6-H="!W=7)D92#\8F5R<'+\9G0@=6YD
M(&)E<W3D=&EG="XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,Y
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V
M97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T<B`B1&EE($YA8VAR:6-H="!W
M=7)D92#\8F5R<'+\9G0@=6YD(&)E<W3D=&EG="X@06)S96YD97(Z("5S+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*(D1E<B!1=65L;'1E>'0@9&5S
M(/9F9F5N=&QI8VAE;B!01U`M4V-H;/QS<V5L<R!K86YN("5S(&5I;F=E<V5H
M96X@=V5R9&5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HV,`IM
M<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H
M92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(D1I92!A=7-G97?D:&QT
M92!$871E:2!E>&ES=&EE<G0@;FEC:'0@:6X@9&5M($U3+51.148M06YH86YG
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"FUS9VED(")4:&4@
M<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A
M8VAM96YT+B(*;7-G<W1R(")$:64@875S9V5WY&AL=&4@1&%T96D@97AI<W1I
M97)T(&YI8VAT(&EN(&1E;2!:25`M06YH86YG+B(*"B,Z(&UE<W-A9V4N<&AP
M.C4U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R(&]F('1H
M:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D
M('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE("(*
M(FYO=&EF:6-A=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"B)$97(@06)S96YD
M97(@9&EE<V5R($YA8VAR:6-H="!M]F-H=&4@9V5R;F4@96EN92!%;7!F86YG
M<V)E<W3D=&EG=6YG("(*(F5R:&%L=&5N+"!W96YN(%-I92!D:65S92!.86-H
M<FEC:'0@9V5L97-E;B!H86)E;BX@0FET=&4@:VQI8VME;B!3:64@)7,L('5M
M("(*(F1I92!"97-TY'1I9W5N9R!Z=7+\8VL@>G4@<V-H:6-K96XN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-C<*;7-G:60@(E1H92!S97)V
M97(@=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES
M(&EM86=E+B(*;7-G<W1R(")$97(@4V5R=F5R(&MO;FYT92!K96EN92!6;W)S
M8VAA=2!D:65S97,@0FEL9&5S('IU(&5R>F5U9V5N+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:G,Z.3`*;7-G:60@(E1H92!S:6=N871U<F4@
M8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R(")$:64@4VEG;F%T=7(@
M:V]N;G1E(&YI8VAT(&5R<V5T>G0@=V5R9&5N+B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:G,Z.#@*;7-G:60@(E1H92!S:6=N871U<F4@=V%S
M('-U8V-E<W-F=6QL>2!R97!L86-E9"XB"FUS9W-T<B`B1&EE(%-I9VYA='5R
M('=U<F1E(&5R9F]L9W)E:6-H(&5R<V5T>G0N(@H*(SH@871T86-H;65N="YP
M:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B1&EE(&%N9V5G96)E;F4@1&%T96D@97AI<W1I97)T(&YI
M8VAT+B(*"B,Z('-T871I;VYE<GDN<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS
M9W-T<B`B1&EE(%9O<FQA9V4@7"(E<UPB('=U<F1E(&AI;GIU9V5F_&=T+B(*
M"B,Z('-T871I;VYE<GDN<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(")$:64@5F]R;&%G92!<(B5S7"(@=W5R9&4@9V5L]G-C:'0N(@H*(SH@<W1A
M=&EO;F5R>2YP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I
M;VYE<GD@7"(E<UPB(&AA<R!B965N('5P9&%T960N(@IM<V=S='(@(D1I92!6
M;W)L86=E(%PB)7-<(B!W=7)D92!A:W1U86QI<VEE<G0N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$W,`IM<V=I9"`B5&AE('1A<VL@:&%S(&)E
M96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B1&EE($%U9F=A
M8F4@=W5R9&4@26AR97(@075F9V%B96YL:7-T92!H:6YZ=6=E9OQG="XB"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY-0IM<V=I9"`B5&AE('1E
M>'0@;V8@=&AE(&UE<W-A9V4B"FUS9W-T<B`B1&5R($YA8VAR:6-H=&5N=&5X
M="(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(D1E<B!.86-H<FEC:'1E;G1E>'0@:V%N;B`E
M<R!E:6YG97-E:&5N('=E<F1E;BXB"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HX,`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE
M<W-A9V4B"FUS9W-T<B`B1&5R(%1E>'0@9&5R(&%B9V5W:65S96YE;B!.86-H
M<FEC:'0B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S
M<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")$97(@5&5X="!D97(@
M>G5R_&-K9V5W:65S96YE;B!.86-H<FEC:'0@:V%N;B`E<R!E:6YG97-E:&5N
M('=E<F1E;BXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H
M<#HV.`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92(*;7-G
M<W1R(")$97(@5&5X="!D97(@9V5S96YD971E;B!.86-H<FEC:'0B"@HC.B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B
M92!V:65W960@)7,N(@IM<V=S='(@(D1E<B!497AT(&1E<B!V97)S8VAI8VMT
M96X@3F%C:')I8VAT(&MA;FX@)7,@96EN9V5S96AE;B!W97)D96XN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-0IM<V=I9"`B5&AE('5S97(G
M<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E
M9"XB"FUS9W-T<B`B(@HB1&EE($9R96DO1V5B=6-H="U);F9O<FUA=&EO;B!D
M97,@0F5N=71Z97)S('=U<F1E(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z.#8*;7-G:60@
M(E1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"B)%<R!G:6)T(&ME:6YE(&%L
M=&5R;F%T:79E;B!.86-H<FEC:'1E;G1E:6QE+"!D:64@86YG97IE:6=T('=E
M<F1E;B!K]FYN96XN(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I
M;&)O>"YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H
M:7,@;6%I;&)O>"XB"FUS9W-T<B`B26X@9&EE<V5M($]R9&YE<B!S:6YD(&ME
M:6YE($YA8VAR:6-H=&5N('9O<FAA;F1E;B(*"B,Z('1H<F5A9"YP:'`Z,3$P
M"FUS9VED(")4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(D5S(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@
M3F%C:')I8VAT96YT96EL92XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C@Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG
M:6YG('1H92!M86EL8F]X+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@
M(B(*(D)E:6T@96YD9_QL=&EG96X@3/9S8VAE;B!D97(@3F%C:')I8VAT96X@
M:6T@9&EE<V5M($]R9&YE<B!I<W0@96EN($9E:&QE<B`B"B)A=69G971R971E
M;BX@365L9'5N9R!D97,@16UA:6PM4V5R=F5R<SH@)7,B"@HC.B!L:6(O365S
M<V%G92YP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB
M)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R
M("(B"B)"96EM($MO<&EE<F5N('9O;B!.86-H<FEC:'1E;B!N86-H(%PB)7-<
M(B!N86-H(%PB)7-<(B!I<W0@96EN($9E:&QE<B`B"B)A=69G971R971E;BX@
M365L9'5N9R!D97,@16UA:6PM4V5R=F5R<R(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HR,C8@;&EB+TUE<W-A9V4N<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@9G)O
M;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T("(*(G1H92!S97)V
M97(@<V%I9"(*;7-G<W1R("(B"B)"96EM($SV<V-H96X@=F]N($YA8VAR:6-H
M=&5N(&EM($]R9&YE<B!<(B5S7"(@:7-T(&5I;B!&96AL97(@875F9V5T<F5T
M96XN("(*(DUE;&1U;F<@9&5S($5M86EL+5-E<G9E<G,B"@HC.B!L:6(O365S
M<V%G92YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB
M)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R
M("(B"B)"96EM($SV<V-H96X@=F]N($YA8VAR:6-H=&5N(&EM($]R9&YE<B!<
M(B5S7"(@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN("(*(DUE;&1U;F<@
M9&5S($5M86EL+5-E<G9E<G,B"@HC.B!L:6(O365S<V%G92YP:'`Z,C0R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B
M"FUS9W-T<B`B(@HB0F5I;2!,]G-C:&5N('9O;B!.86-H<FEC:'1E;B!I<W0@
M96EN($9E:&QE<B!A=69G971R971E;BX@365L9'5N9R!D97,@16UA:6PM(@HB
M4V5R=F5R<SH@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")"96EM($SV<V-H96X@9&5S
M(%1E<FUI;G,@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XZ("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3(@;&EB+TU)344O5FEE=V5R
M+V5N<FEC:&5D+G!H<#HS-PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B0F5I;2!!;GIE
M:6=E;B!D:65S97,@3F%C:')I8VAT96YT96EL<R!I<W0@96EN($9E:&QE<B!A
M=69G971R971E;BXB"@HC.B!L:6(O365S<V%G92YP:'`Z-3DQ"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M
M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H
M92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)"96EM($UA<FMI97)E;B!V
M;VX@3F%C:')I8VAT96X@:6T@3W)D;F5R(%PB)7-<(B!I<W0@96EN($9E:&QE
M<B!A=69G971R971E;BX@(@HB365L9'5N9R!D97,@16UA:6PM4V5R=F5R<R(*
M"B,Z(&9O;&1E<G,N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R(")"96EM($EM
M<&]R=&EE<F5N('9O;B`E<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BXB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3,W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V
M96YT.B`E<RXB"FUS9W-T<B`B0F5I;2!);7!O<G1I97)E;B!D97,@5&5R;6EN
M<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;CH@)7,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS
M9W-T<B`B0F5I;2!);7!O<G1I97)E;B!D97(@075F9V%B92!I<W0@96EN($9E
M:&QE<B!A=69G971R971E;CH@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ
M("5S+B(*;7-G<W1R("(B"B)"96EM($EM<&]R=&EE<F5N(&1E<B!&<F5I+T=E
M8G5C:'0M26YF;W)M871I;VYE;B!I<W0@96EN($9E:&QE<B!A=69G971R971E
M;CH@)2(*(G,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$P-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A
M9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B
M"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)"96EM(%9E<G-C:&EE8F5N(&1E
M<B!.86-H<FEC:'1E;B!V;VX@7"(E<UPB(&YA8V@@7"(E<UPB(&ES="!E:6X@
M1F5H;&5R("(*(F%U9F=E=')E=&5N+B!-96QD=6YG(&1E<R!%;6%I;"U397)V
M97)S(@H*(SH@8V]M<&]S92YP:'`Z,3(X,`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R('-A=FEN9R!T:&ES(&UE<W-A9V4@87,@82!D<F%F="XB"FUS9W-T
M<B`B(@HB0F5I;2!3<&5I8VAE<FX@9&EE<V5R($YA8VAR:6-H="!A;',@16YT
M=W5R9B!I<W0@96EN($9E:&QE<B!A=69G971R971E;BXB"@HC.B!C;VUP;W-E
M+G!H<#HQ,#,Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS9W-T<B`B0F5I;2!6
M97)S96YD96X@9&5R($YA8VAR:6-H="!I<W0@96EN($9E:&QE<B!A=69G971R
M971E;CH@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")"96EM($%K='5A;&ES:65R96X@
M9&5S(%1E<FUI;G,@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XZ("5S+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G:60@(E1H:7,@
M2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM<V=S
M='(@(DEN(&1I97-E($A434PM3F%C:')I8VAT('=U<F1E;B!":6QD97(@96EN
M9V5B971T970N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDS"FUS
M9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D
M(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES.B`B
M"FUS9W-T<B`B(@HB26X@9&EE<V4@2%1-3"U.86-H<FEC:'0@=W5R9&5N($)I
M;&1E<B!E:6YG96)E='1E="X@0FQO8VMI97)T92!":6QD97(@(@HB97)S8VAE
M:6YE;B!S;SH@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U"FUS
M9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@
M;65S<V%G92XB"FUS9W-T<B`B1&EE<V5R(/9F9F5N=&QI8VAE(%!'4"U38VAL
M_'-S96P@=W5R9&4@86X@9&EE($YA8VAR:6-H="!A;F=E:.1N9W0N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P-2!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3$Y"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#0@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U.`HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,3<T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,34*
M;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(D1I97-E($%K=&EO;B!W:7)D(&YI8VAT('5N=&5R<W3\='IT+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ.#`@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C0R,`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B1&EE<V4@06MT:6]N(&ES="!N;V-H(&YI8VAT
M(&EM<&QE;65N=&EE<G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B(@HB
M1&EE<V5R(%9O<F=A;F<@:V%N;B!E:6YE(%=E:6QE(&1A=65R;BX@4VEN9"!3
M:64@<VEC:&5R+"!D87-S(%-I92!F;W)T9F%H<F5N("(*(G=O;&QE;C\B"@HC
M.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED(")4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS9W-T
M<B`B1&EE<V4@3F%C:')I8VAT(&5N=&CD;'0@96EN92!-86-I;G1O<V@M1&%T
M96DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,38*;7-G:60@
M(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@
M:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R\B"B)-24U%+B(*;7-G
M<W1R("(B"B)$:65S92!.86-H<FEC:'0@96YT:.1L="!E:6YE;B!!;FAA;F<L
M(&1E<B!M:70@4R]-24U%(&1I9VET86P@=6YT97)S8VAR:65B96X@(@HB=W5R
M9&4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C`*;7-G:60@
M(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S
M(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(B(*(D1I97-E
M($YA8VAR:6-H="!E;G1HY&QT(&5I;F5N($%N:&%N9RP@9&5R(&UI="!3+TU)
M344@=F5R<V-H;/QS<V5L="!W=7)D92XB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN
M<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F
M;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@
M(B(*(D1I97-E($YA8VAR:6-H="!E;G1HY&QT(%-T871U<VEN9F]R;6%T:6]N
M96X@>G5R($%U<VQI969E<G5N9R!E:6YE<B!%;6%I;"`B"B)A8F5R(&EN(&5I
M;F5M('5N8F5K86YN=&5N($9O<FUA="XB"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HS,3D*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R
M<F]R.B`B"FUS9W-T<B`B(@HB1&EE<R!S8VAE:6YT(&ME:6YE(&?\;'1I9V4@
M4$=0+79E<G-C:&S\<W-E;'1E($YA8VAR:6-H="!Z=2!S96EN+B!&96AL97(Z
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C,Y(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C,U-`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T("AA
M8V-O<F1I;F<@=&\@(@HB4D9#(#(P,34I+B(*;7-G<W1R("(B"B)$:65S92!.
M86-H<FEC:'0@:7-T(&%N<V-H96EN96YD(&YI8VAT(&EM(&MO<G)E:W1E;B!0
M1U`M1F]R;6%T("AN86-H(%)&0R`B"B(R,#$U*2XB"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI<R!M97-S86=E(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R;6%T
M+B(*;7-G<W1R(")$:65S92!.86-H<FEC:'0@<V-H96EN="!N:6-H="!I;2!K
M;W)R96MT96X@4R]-24U%+49O<FUA="!Z=2!S96EN+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT
M,C`*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG
M;F5D('9I82!01U`N(@IM<V=S='(@(D1I97-E($YA8VAR:6-H="!W=7)D92!M
M:70@4$=0(&1I9VET86P@=6YT97)S8VAR:65B96XN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S<V%G92!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM<V=S='(@(D1I
M97-E($YA8VAR:6-H="!W=7)D92!M:70@4R]-24U%(&1I9VET86P@=6YT97)S
M8VAR:65B96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ,SD@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@(E1H:7,@;65S
M<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B
M1&EE<V4@3F%C:')I8VAT('=U<F1E(&UI="!3+TU)344@=F5R<V-H;/QS<V5L
M="XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#`@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,CDP"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E
M96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R(")$:65S92!.86-H<FEC
M:'0@=W5R9&4@;6ET(%!'4"!V97)S8VAL_'-S96QT+B(*"B,Z(&UE<W-A9V4N
M<&AP.C(Q,`IM<V=I9"`B5&AI<R!M97-S86=E('1O(@IM<V=S='(@(F1I97-E
M($YA8VAR:6-H="!N86-H(@H*(SH@86-L+G!H<#HT-0IM<V=I9"`B5&AI<R!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S
M='(@(D1I97-E<B!397)V97(@=6YT97)S=/QT>G0@:V5I;F4@9V5M96EN<V%M
M96X@3W)D;F5R+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3`Y"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&$@8V]M<&]S92!W:6YD;W<N(@IM<V=S='(@(D1I97-E<R!&96YS=&5R(&UU
M<W,@=F]M($9E;G-T97(@9OQR(&YE=64@3F%C:')I8VAT96X@9V7V9F9N970@
M=V5R9&5N+B(*"B,Z('1H<F5A9"YP:'`Z,34W"FUS9VED(")4:')E860@1&ES
M<&QA>2(*;7-G<W1R(")4:&5M96YL:7-T92(*"B,Z('1H<F5A9"YP:'`Z-S8@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ,0IM<V=I9"`B5&AR96%D(%9I97<B
M"FUS9W-T<B`B5&AE;65N86YS:6-H="(*"B,Z(&UE<W-A9V4N<&AP.C(W,2!M
M86EL8F]X+G!H<#HV,#$@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHR,B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H+G!H
M<#HU.3,*;7-G:60@(E1O(@IM<V=S='(@(D%N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP.`IM<V=I9"`B5&\@061D<F5S<R(*;7-G<W1R(")%;7!F
MY&YG97)A9')E<W-E(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C
M="YI;F,Z,S(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M('=H:6QE("(*(F-L:6-K:6YG+B(*;7-G<W1R("(B"B)(86QT96X@4VEE(&)E
M:6T@2VQI8VME;B!3=')G("A00RD@8GIW+B!#;VUM86YD("A-86,I(&=E9'+\
M8VMT+"!U;2!M96AR97)E("(*(D5I;G1RY&=E(&%U<WIU=^1H;&5N+B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@82!4
M3%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@
M;V8@4$A0(#4N,2XP(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B(@HB56T@96EN
M92!43%,M5F5R8FEN9'5N9R!B96YU='IE;B!Z=2!K]FYN96XL(&W\<W-E;B!3
M:64@4$A0(%9E<G-I;VX@-2XQ+C`@;V1E<B`B"B)H]FAE<B!E:6YS971Z96XN
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3DQ"FUS9VED
M(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*;7-G<W1R(")'97-A;71G<O;?
M92!D97(@06YHY&YG93HB"@HC.B!F;VQD97)S+G!H<#HS-CD*;7-G:60@(E1R
M87-H(&9O;&1E<B(*;7-G<W1R(")<(E!A<&EE<FMO<F)<(BU/<F1N97(B"@HC
M.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4
M<F%S:"!F;VQD97(Z(@IM<V=S='(@(EPB4&%P:65R:V]R8EPB+4]R9&YE<CHB
M"@HC.B!L:6(O475O=&$O8WER=7,N<&AP.C8T(&QI8B]1=6]T82]M97)C=7)Y
M,S(N<&AP.C<Y(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,0HC.B!L:6(O475O
M=&$O;&]G9FEL92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP.C4S(&QI
M8B]1=6]T82]M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O(')E=')I
M979E('%U;W1A(@IM<V=S='(@(E-P96EC:&5R<&QA='HM2V]N=&EN9V5N="!K
M;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R(").:6-H="!B96%N='=O
M<G1E="(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@
M(E5N86YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B3FEC:'0@8F5A;G1W;W)T
M971E($YA8VAR:6-H=&5N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3,*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(E=I961E<FAE<G-T96QL96XB
M"@HC.B!M86EL8F]X+G!H<#HU-SD@;6%I;&)O>"YP:'`Z-3DW(&QI8B]-24U%
M+TAE861E<G,N<&AP.C(P-`IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I96YT
M<R(*;7-G<W1R(")5;F)E:V%N;G1E($5M<&;D;F=E<B(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z-34V"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O($%55$A%3E1)0T%412!C;VUM86YD+B(*;7-G<W1R(")5
M;F5R=V%R=&5T92!!;G1W;W)T(&1E<R!397)V97)S(&%U9B!!551(14Y424-!
M5$4@2V]M;6%N9&\N(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,C`*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\@1&EG97-T
M+4U$-2!R97-P;VYS92XB"FUS9W-T<B`B56YE<G=A<G1E=&4@06YT=V]R="!D
M97,@4V5R=F5R<R!A=68@1&EG97-T+4U$-2!!;F9R86=E+B(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z-3,V"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O($Q/1TE.(&-O;6UA;F0N(@IM<V=S='(@(E5N97)W
M87)T971E($%N='=O<G0@9&5S(%-E<G9E<G,@875F($Q/1TE.($MO;6UA;F1O
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*
M;7-G<W1R(").:6-H="!V97)A<F)E:71E=&4@2V]M<&]N96YT92!D97,@5'EP
M<SH@)7,B"@HC.B!M86EL8F]X+G!H<#HU-3<*;7-G:60@(E5N:VYO=VX@1&%T
M92(*;7-G<W1R(")5;F)E:V%N;G1E<R!$871U;2(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!
M4"!R97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z
M("5S(@IM<V=S='(@(E5N8F5K86YN=&4@24U!4"U!;G1W;W)T(&1E<R!397)V
M97)S+B!397)V97)A;G1W;W)T.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,C8*;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R(")5
M;F)E:V%N;G1E($)E<W!R96-H=6YG(@H*(SH@;6%I;&)O>"YP:'`Z-C$S"FUS
M9VED(")5;FMN;W=N(%)E8VEP:65N="(*;7-G<W1R(")5;F)E:V%N;G1E<B!%
M;7!FY&YG97(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P:')A
M<V4B"FUS9W-T<B`B4&%S<W=O<G0@7")V97)G97-S96Y<(B(*"B,Z(&9E=&-H
M;6%I;'!R969S+G!H<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")5;F)E
M;F%N;G0B"@HC.B!M97-S86=E+G!H<#HU,#(@;6%I;&)O>"YP:'`Z-S`R('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$U('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,S(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHU"FUS9VED(")5;G-E96XB"FUS9W-T<B`B3FEC:'0@9V5L97-E;B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$R"FUS9VED(")5;G-U
M8G-C<FEB92!F<F]M($9O;&1E<BAS*2(*;7-G<W1R(")/<F1N97(@875S8FQE
M;F1E;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PIM
M<V=I9"`B57!D871E(@IM<V=S='(@(D%K='5A;&ES:65R=6YG(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q,@IM<V=I9"`B57!D871E(')E<W!O
M;F1E;G0@<W1A='5S(@IM<V=S='(@(E-T871U<R!D97(@5&5I;&YE:&UE<B!A
M:W1U86QI<VEE<F5N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN
M:6YC.C4X('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-38*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R(")(;V-H;&%D96XB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0Q"FUS9VED(")5<V4@1&5F875L="!6
M86QU92(*;7-G<W1R(")3=&%N9&%R9'=E<G0@=F5R=V5N9&5N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B57-E($E-05`@9F]L9&5R
M('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(DE-05`@3W)D;F5R86)O;FYE;65N
M="!B96YU='IE;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(T"FUS
M9VED(")5<V4@5FER='5A;"!4<F%S:"!&;VQD97(_(@IM<V=S='(@(E9I<G1U
M96QL96X@4&%P:65R:V]R8B!B96YU='IE;C\B"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,30S"FUS9VED(")5<V5R(@IM<V=S='(@(D)E;G5T>F5R(@H*
M(SH@86-L+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)5<V5R(%PB
M)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE('-P96-I9FEE9"!R:6=H=',@
M9F]R('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"B)$96T@0F5N=71Z
M97(@7"(E<UPB('=U<F1E;B!E<F9O;&=R96EC:"!D:64@86YG96=E8F5N96X@
M4F5C:'1E(&;\<B!D96X@3W)D;F5R("(*(EPB)7-<(B!Z=6=E=VEE<V5N+B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<V"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R(")"96YU='IE<FYA;64B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z,3<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M(")"96YU='IE<FYA;64Z(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S<*;7-G:60@(E9I97<B"FUS9W-T<B`B06YZ96EG96XB"@HC.B!L
M:6(O34E-12]6:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE
M9BYP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`B)7,@86YZ96EG96XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(%!U8FQI8R!+97DB"FUS9W-T<B`BUF9F96YT;&EC:&5N
M("5S(%-C:&S\<W-E;"!A;GIE:6=E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,3D*;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W(@IM<V=S='(@(DA434PM26YH86QT(&EN(&5I;F5M(&YE
M=65N($9E;G-T97(@86YZ96EG96XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHR.`IM<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R(").
M86-H<FEC:'1E;B!A;E]Z96EG96XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE
M=R!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R(")097)S]FYL:6-H96X@
M<')I=F%T96X@4V-H;/QS<V5L(&%N>F5I9V5N(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G
M:60@(E9I97<@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R(")097)S]FYL
M:6-H96X@]F9F96YT;&EC:&5N(%-C:&S\<W-E;"!A;GIE:6=E;B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B
M5FEE=R!4:')E860B"FUS9W-T<B`B5&AE;6$@06YZ96EG96XB"@HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,38V"FUS9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R(")6
M;W)S8VAA=2!A;GIE:6=E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#(T"FUS9VED(")6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<B"FUS9W-T<B`B06YH86YG(&EN(&5I;F5M(&YE=65N($9E;G-T97(@
M86YZ96EG96XB"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*
M;7-G:60@(E9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G
M<W1R("));FAA;'0@:6X@96EN96T@;F5U96X@1F5N<W1E<B!A;GIE:6=E;B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#$*;7-G:60@(E9I97<@
M979E;G0B"FUS9W-T<B`B5&5R;6EN(&%N>F5I9V5N(@H*(SH@9F]L9&5R<RYP
M:'`Z,S8Q(&UA:6QB;W@N<&AP.C4R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(DYA8VAR:6-H=&5N(&EN("5S
M(&%N>F5I9V5N(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L
M96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@
M869T97(@;&]G:6XZ(@IM<V=S='(@(D%N<VEC:'0@;V1E<B!/<F1N97(L(&1E
M<B!N86-H(&1E<B!!;FUE;&1U;F<@86YG97IE:6=T('=E<F1E;B!S;VQL.B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S$*;7-G:60@(E9I97<@
M=&%S:R(*;7-G<W1R(")!=69G86)E(&%N>F5I9V5N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C$P-`IM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM
M<V=S='(@(D)I;&1E<B!A;GIE:6=E;B(*"B,Z('-E87)C:"YP:'`Z,C4U"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<(B!C<F5A
M=&5D('-U8V-E<V9U;&QY+B(*;7-G<W1R(")6:7)T=65L;&5R($]R9&YE<B!<
M(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@97)S=&5L;'0N(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHQ,3(@;&EB+TE-05`O5')E92YP:'`Z,30Q
M(&QI8B])34%0+U1R964N<&AP.C$U-`HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ
M-38@;&EB+TE-05`O5')E92YP:'`Z,38P(&QI8B])34%0+U1R964N<&AP.C$V
M,0HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-S$@;&EB+TE-05`O5')E92YP:'`Z
M,SDU(&QI8B])34%0+U1R964N<&AP.C0S,PIM<V=I9"`B5FER='5A;"!&;VQD
M97)S(@IM<V=S='(@(E9I<G1U96QL92!/<F1N97(B"@HC.B!S96%R8V@N<&AP
M.C(T-PIM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB
M"FUS9W-T<B`B5FER='5E;&QE($]R9&YE<B!M_'-S96X@96EN96X@3F%M96X@
M:&%B96XN(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(P"FUS9VED(")6:7)T=6%L
M($E.0D]8(@IM<V=S='(@(E9I<G1U96QL97(@4&]S=&5I;F=A;F<B"@HC.B!F
M;VQD97)S+G!H<#HS.3<*;7-G:60@(E9I<G1U86P@24Y"3U@@1F]L9&5R(@IM
M<V=S='(@(E9I<G1U96QL97(@4&]S=&5I;F=A;F=S;W)D;F5R(@H*(SH@;&EB
M+TUA:6QB;W@N<&AP.C$W,2!L:6(O4V5A<F-H+G!H<#HS-C8*;7-G:60@(E9I
M<G1U86P@5')A<V@B"FUS9W-T<B`B5FER='5E;&QE<B!087!I97)K;W)B(@H*
M(SH@9F]L9&5R<RYP:'`Z,SDT"FUS9VED(")6:7)T=6%L(%1R87-H($9O;&1E
M<B(*;7-G<W1R(")6:7)T=65L;&5R(%!A<&EE<FMO<F(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$R.0IM<V=I9"`B5FER='5A;"!F;VQD97(@
M;&%B96PB"FUS9W-T<B`B3F%M92!D97,@=FER='5E;&QE;B!/<F1N97)S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-SD*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`B5V%R;G5N9R(*"B,Z(&QO9VEN+G!H<#HQ-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")7:6QL:V]M
M;65N(&)E:2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#<*;7-G
M:60@(B(*(E=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A
M9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN
M;F]C96YT/R(*;7-G<W1R("(B"B)787,@<V]L;"!M:70@3F%C:')I8VAT96X@
M9V5S8VAE:&5N+"!N86-H9&5M('-I92!A;',@4W!A;2!O9&5R(&ME:6X@4W!A
M;2`B"B)G96UE;&1E="!W;W)D96X@<VEN9#\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S$V"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S
M+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M
M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HB0F5I;2!,
M]G-C:&5N('9O;B!.86-H<FEC:'1E;B!D:65S92!I;B!D96X@4&%P:65R:V]R
M8B!V97)S8VAI96)E;BP@86YS=&%T="`B"B)S:64@86QS(&=E;/9S8VAT('IU
M(&UA<FMI97)E;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DV"FUS
M9VED(")7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D
M;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\B"FUS9W-T<B`B(@HB5V5N;B!3:64@
M96EN96X@3W)D;F5R(/9F9FYE;BP@=V5L8VAE(%-E:71E('-O;&P@>G5E<G-T
M(&%N9V5Z96EG="!W97)D96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@
M<V%V92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(B(*(E-O;&QE;B!!;FCD
M;F=E(&UI=&=E<W!E:6-H97)T('=E<F1E;BP@=V5N;B!G97-E;F1E=&4@3F%C
M:')I8VAT96X@9V5S<&5I8VAE<G0@(@HB=V5R9&5N/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN9R!M86EL
M(&]R(&5X<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W
M92!A<'!E;F0@=&\@(@HB=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A
M9&1R97-S97,@=VET:&]U="!<(D!<(BD_(@IM<V=S='(@(B(*(E=E;&-H92!$
M;VUA:6X@<V]L;"!B96EM(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!O
M9&5R(%-U8VAE;B!V;VX@061R97-S96X@(@HB86X@=6YV;VQL<W3D;F1I9V4@
M061R97-S96X@*&]H;F4@7")`7"(M6F5I8VAE;BD@9V5HY&YG="!W97)D96X_
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7:&ET
M96QI<W0B"FUS9W-T<B`B4&]S:71I=FQI<W1E(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3,W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4U,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38W"FUS9VED
M(")997,B"FUS9W-T<B`B2F$B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F
M971C:&UA:6Q?;&]G:6XN<&AP.C4X"FUS9VED(")9;W4@87)E(&%B;W5T('1O
M(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O=6YT*',I.B(*
M;7-G<W1R(")3:64@<VEN9"!I;2!"96=R:69F($YA8VAR:6-H=&5N('9O;B!F
M;VQG96YD96X@2V]N=&5N(&5I;GIU<V%M;65L;CHB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`IM<V=I9"`B(@HB66]U
M(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I
M;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R(")3
M:64@=F5R<W5C:&5N(&%L;&4@3F%C:')I8VAT96X@:6X@9F]L9V5N9&5N($]R
M9&YE<B!Z=2!L]G-C:&5N+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E
M<G-?8V]N9FER;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T
M;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(E-I
M92!V97)S=6-H96X@9F]L9V5N9&4@3W)D;F5R('IU(&SV<V-H96XN(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O
M<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B4VEE(&MO
M<&EE<F5N+W9E<G-C:&EE8F5N('IU(&5I;F5M(&YE=65N($]R9&YE<BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B
M66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@(@IM<V=S='(@(E-I
M92!E<GIE=6=E;B!E:6YE;B!5;G1E<F]R9&YE<B!V;VX@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#8*;7-G:60@(EEO=2!A<F4@
M8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R(")3:64@97)Z
M975G96X@96EN96X@2&%U<'1O<F1N97(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,C<V"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!F;VQD
M97)S+B(*;7-G<W1R(")3:64@9/QR9F5N(&ME:6YE($]R9&YE<B!E<G-T96QL
M96XN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!F;VQD97)S+B(*;7-G<W1R(")3:64@9/QR9F5N(&YI8VAT(&UE:'(@86QS
M("5D($]R9&YE<B!E<G-T96QL96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9F]L9&5R<RYJ<SHQ,S<*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE
M(&9O;&1E<CH@(@IM<V=S='(@(E-I92!B96YE;FYE;B!F;VQG96YD96X@3W)D
M;F5R('5M.B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@8V%N('5S92!T:&4@9F]L
M;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E
M8R!F;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@
M=&AE('-I9VYA='5R92XB"FUS9W-T<B`B(@HB4VEE(&OV;FYE;B!F;VQG96YD
M92!0;&%T>FAA;'1E<B!I;2!6;W)L86=E;G1E>'0@=F5R=V5N9&5N.B`E8R!F
M_'(@9&5N("(*(F%K='5E;&QE;B!.86-H<FEC:'1E;G1E>'0[("5S(&;\<B!D
M:64@4VEG;F%T=7(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!C86YN;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(E-I92!K]FYN96X@7"(E<UPB(&YI8VAT(&%U<V)L96YD
M96XN(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP
M:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M
M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W
M960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*(E-I92!H86)E;B!D96X@0F5N
M=71Z=6YG<V)E9&EN9W5N9V5N(&YI8VAT('IU9V5S=&EM;70@=6YD(&3\<F9E
M;B!S:6-H("(*(F1E<W=E9V5N(&YI8VAT(&%N;65L9&5N+B(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ-S`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS
M9W-T<B`B(@HB4VEE(&AA8F5N('-E;&)S="!N:6-H="!G96[\9V5N9"!296-H
M=&4L('5M(&1I92!296-H=&4@9OQR(&1I97-E;B!/<F1N97(@>G4@(@HBY&YD
M97)N+B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&9O<G=A<F1E9"!T:&ES(&UE<W-A9V4@;VX@)25S('1O('1H
M92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N(@IM<V=S='(@(B(*(E-I92!H
M86)E;B!D:65S92!.86-H<FEC:'0@86T@)25S(&%N(&9O;&=E;F1E($5M<&;D
M;F=E<B!W96ET97)G96QE:71E=#H@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86QE<G0N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&AA=F4@
M)7,@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")3:64@:&%B96X@)7,@;F5U92!.
M86-H<FEC:'1E;BXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z
M,PIM<V=I9"`B66]U(&AA=F4@,2!N97<@;65S<V%G92XB"FUS9W-T<B`B4VEE
M(&AA8F5N(#$@;F5U92!.86-H<FEC:'0N(@H*(SH@8V]M<&]S92YP:'`Z-#@R
M"FUS9VED(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N
M(@IM<V=S='(@(E-I92!H86)E;B!D:65S92!396ET92!B97)E:71S(&%B9V5S
M8VAI8VMT+B(*"B,Z(&QI8B])35`N<&AP.C$P-30*;7-G:60@(EEO=2!H879E
M(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R(")3
M:64@:&%B96X@;F5U92!.86-H<FEC:'1E;B!I;B!D96T@9F]L9V5N9&5N($]R
M9&YE<CHB"@HC.B!L:6(O24U0+G!H<#HQ,#4Y"FUS9VED(")9;W4@:&%V92!N
M97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(E-I
M92!H86)E;B!N975E($YA8VAR:6-H=&5N(&EN(&1E;B!F;VQG96YD96X@3W)D
M;F5R;CHB"@HC.B!C;VUP;W-E+G!H<#HQ-3,*;7-G:60@(EEO=2!M=7-T(&5N
M=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N(@IM<V=S='(@(E-I92!M_'-S
M96X@;6EN9&5S=&5N<R!E:6YE;B!%;7!FY&YG97(@86YG96)E;BXB"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HS,#8*;7-G:60@(B(*(EEO=2!M=7-T
M(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME
M>2!T;R!V:65W('1H:7,@;65S<V%G92(*;7-G<W1R("(B"B)3:64@;?QS<V5N
M(&1A<R!087-S=V]R="!F_'(@26AR96X@<')I=F%T96X@4$=0+5-C:&S\<W-E
M;"!A;F=E8F5N+"!U;2!D:65S92`B"B).86-H<FEC:'0@;&5S96X@>G4@:_9N
M;F5N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-30*;7-G:60@
M(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O
M34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*;7-G
M<W1R("(B"B)3:64@;?QS<V5N(&1A<R!087-S=V]R="!F_'(@26AR96X@<')I
M=F%T96X@4R]-24U%+5-C:&S\<W-E;"!A;F=E8F5N+"!U;2`B"B)D:65S92!.
M86-H<FEC:'0@;&5S96X@>G4@:_9N;F5N(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O:F%V87-C<FEP="YI;F,Z-C0@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,C`Q"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@
M;6%I;&)O>"!F:7)S="XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E<G-T(&5I;F5N
M(%II96QO<F1N97(@86YG96)E;BXB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z
M.#4*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(E-I92!M_'-S96X@97)S="!D87,@>G4@;/9S8VAE
M;F1E($MO;G1O(&%U<W?D:&QE;BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C@Q"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D
M<F5S<R!F:7)S="XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E<G-T(&5I;F4@061R
M97-S92!A=7-WY&AL96XN(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V,PIM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I
M<G-T+B(*;7-G<W1R(")3:64@;?QS<V5N(&5R<W0@;6EN9&5S=&5N<R!E:6YE
M($YA8VAR:6-H="!A=7-WY&AL96XN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C
M:7!I96YT+B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;F5N($5M<&;D;F=E<B!A
M;F=E8F5N+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@;F5E9"!T;R!H879E(%PB)7-<
M(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RXB"FUS9W-T
M<B`B4VEE(&W\<W-E;B!<(B5S7"(@:6X@26AR96X@5V%R='5N9W-E:6YS=&5L
M;'5N9V5N(&%K=&EV:65R96XN(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$S.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A
M9V4@=&\@)7,@;VX@)25S+B(*;7-G<W1R(")3:64@:&%B96X@9&EE<V4@3F%C
M:')I8VAT(&%M("4E<R!N86-H("5S('5M9V5L96ET970N(@H*(SH@;&EB+TUA
M:6QL;V<N<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5P;&EE
M9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM<V=S='(@(E-I92!H86)E;B!A
M=68@9&EE<V4@3F%C:')I8VAT(&%M("5S(&=E86YT=V]R=&5T+B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R
M92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB0F5I;2!%:6YB;&5N9&5N(&1E<R!/
M<F1N97)S(%PB)7-<(B!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@365L
M9'5N9R!D97,@(@HB16UA:6PM4V5R=F5R<R(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C4R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@=6YS=6)S
M8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(B(*(D1E<B!/<F1N97(@7"(E<UPB('=U<F1E(&YI8VAT
M(&%U<V=E8FQE;F1E="X@1&EE($UE;&1U;F<@9&5S($5M86EL+5-E<G9E<G,B
M"@HC.B!L:6(O1F]L9&5R+G!H<#HT-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@7"(E<UPB(@IM
M<V=S='(@(D1E<B!/<F1N97(@7"(E<UPB('=U<F1E(&5R9F]L9W)E:6-H(&5I
M;F=E8FQE;F1E="XB"@HC.B!L:6(O1F]L9&5R+G!H<#HU,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E
M9"!F<F]M(%PB)7-<(B(*;7-G<W1R(")$97(@3W)D;F5R(%PB)7-<(B!W=7)D
M92!E<F9O;&=R96EC:"!A=7-G96)L96YD970N(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B26AR($YA
M;64B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G:60@(EEO=7(@
M4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B26AR92#V9F9E;G1L
M:6-H96XO<')I=F%T96X@4$=0+5-C:&S\<W-E;"(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-S$@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<V"FUS
M9VED(")9;W5R(%!R:79A=&4@2V5Y(@IM<V=S='(@(DEH<B!P<FEV871E<B!3
M8VAL_'-S96PB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW,0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y
M(@IM<V=S='(@(DEH<B#V9F9E;G1L:6-H97(@4V-H;/QS<V5L(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$V-0IM<V=I9"`B66]U<B!297!L>2UT;SH@
M861D<F5S<SH@/&5M/BAO<'1I;VYA;"D\+V5M/B(*;7-G<W1R(")):')E("9Q
M=6]T.T%N='=O<G0@86XZ)G%U;W0[($%D<F5S<V4Z(#QE;3XH;W!T:6]N86PI
M/"]E;3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS9VED
M(")9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS
M9W-T<B`B26AR92#V9F9E;G1L:6-H96XO<')I=F%T96X@4R]-24U%+5IE<G1I
M9FEK871E(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C
M="YI;F,Z,38*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S='(@(DEH<F4@
M2V]N=&5N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S,*;7-G:60@
M(B(*(EEO=7(@86QI87,@861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E
M<B!E86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B
M"B)):')E($%L:6%S+4%D<F5S<V5N.B`\96T^*&]P=&EO;F%L+"!J961E($%D
M<F5S<V4@:6X@96EN97(@96EG96YE;B!:96EL92`B"B)E:6YT<F%G96XI/"]E
M;3XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#$*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y
M(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B26AR($)R;W=S97(@:V%N
M;B!D:65S96X@0FEL9'1Y<"!N:6-H="!D:7)E:W0@86YZ96EG96XN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D969A=6QT
M(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(DEH<B!3
M=&%N9&%R9'IE:6-H96YS871Z(&)E:6T@17)S=&5L;&5N('9O;B!N975E;B!.
M86-H<FEC:'1E;CHB"@HC.B!T96UP;&%T97,O<')E9G,O96YC<GEP='-E;&5C
M="YI;F,Z,0IM<V=I9"`B66]U<B!D969A=6QT(&5N8W)Y<'1I;VX@;65T:&]D
M(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G<W1R("(B"B)):')E(%-T86YD
M87)D+59E<G-C:&S\<W-E;'5N9W-M971H;V1E(&)E:6T@5F5R<V-H:6-K96X@
M=F]N($YA8VAR:6-H=&5N.B(*"B,Z(&%T=&%C:&UE;G0N<&AP.CDT"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@;&EN:V5D(&%T=&%C:&UE;G0@:&%S
M(&)E96X@9&]W;FQO861E9"!B>2!A="!L96%S="!O;F4@=7-E<BY<;B(*(EQN
M(@HB071T86-H;65N="!N86UE.B`E<UQN(@HB071T86-H;65N="!D871E.B`E
M<UQN(@HB7&XB"B)#;&EC:R!O;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@<&5R
M;6%N96YT;'D@9&5L971E('1H92!A='1A8VAM96YT.EQN(@HB)7,B"FUS9W-T
M<B`B(@HB26AR('9E<FQI;FMT97(@06YH86YG('=U<F1E('9O;B!M:6YD97-T
M96YS(&5I;F5R(%!E<G-O;B!H97)U;G1E<F=E;&%D96XN7&XB"B)<;B(*(DYA
M;64@9&5S($%N:&%N9W,Z("5S7&XB"B)$871U;2!D97,@06YH86YG<SH@)7-<
M;B(*(EQN(@HB2VQI8VME;B!3:64@875F(&1E;B!F;VQG96YD96X@3&EN:RP@
M=6T@9&5N($%N:&%N9R!E;F1G_&QT:6<@>G4@;/9S8VAE;CI<;B(*(B5S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*;7-G:60@(EEO=7(@
M;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB"FUS9W-T<B`B
M26AR92!.86-H<FEC:'0@=W5R9&4@97)F;VQG<F5I8V@@=F5R<V-H:6-K="XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I
M9VYA='5R93HB"FUS9W-T<B`B26AR92!3:6=N871U<CHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z-PIM<V=I9"`B6TAI
M9&4@061D<F5S<V5S72(*;7-G<W1R(");061R97-S96X@=F5R<W1E8VME;ETB
M"@HC.B!M97-S86=E+G!H<#HR.34@8V]M<&]S92YP:'`Z,3,P,2!M86EL8F]X
M+G!H<#HU,S4@;&EB+T-O;7!O<V4N<&AP.C@S.`IM<V=I9"`B6TYO(%-U8FIE
M8W1=(@IM<V=S='(@(EM+96EN($)E=')E9F9=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O861D<F5S<V5S0FQO8VMS+FIS.C@*;7-G:60@(EM3:&]W($%D
M9')E<W-E<R`M(@IM<V=S='(@(EM!9')E<W-E;B!A;GIE:6=E;B`M(@H*(SH@
M;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@
M(EM3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP:65N='-=(@IM<V=S='(@(EM!
M9')E<W-E;B!A;GIE:6=E;B`M("5S($5M<&;D;F=E<ETB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#,*;7-G:60@(E]"8V,B"FUS9W-T
M<B`B7T)C8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I
M9"`B7T)L86-K;&ES="(*;7-G<W1R(")!=7-S7V-H;'5S<VQI<W1E(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,34R"FUS9VED(")?0V,B
M"FUS9W-T<B`B7T-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B7T1E
M;&5T92(*;7-G<W1R(")?3/9S8VAE;B(*"B,Z(&QI8B])35`N<&AP.CDU-PIM
M<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`B7T]R9&YE<B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<Y"FUS9VED(")?261E;G1I='DB"FUS
M9W-T<B`B7TED96YT:73D="(*"B,Z(&QI8B])35`N<&AP.CDR-@IM<V=I9"`B
M7TEN8F]X(@IM<V=S='(@(E]0;W-T96EN9V%N9R(*"B,Z(&QI8B])35`N<&AP
M.CDY.`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B06)?;65L9&5N(@H*(SH@
M;65S<V%G92YP:'`Z,SDQ"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T
M<B`B7U%U96QL=&5X="(*"B,Z(&QI8B])35`N<&AP.CDU-`IM<V=I9"`B7TYE
M=R!-97-S86=E(@IM<V=S='(@(E].975E($YA8VAR:6-H="(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B7U!R
M:6YT(@IM<V=S='(@(D1?<G5C:V5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C<P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(X-PIM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(E]0<FEO<FETY'0B"@HC
M.B!M86EL8F]X+G!H<#HT,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7U)E9G)E
M<V@@)7,B"FUS9W-T<B`B05]K='5A;&ES:65R92`E<R(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")?4F5P;'DB
M"FUS9W-T<B`B06Y?='=O<G1E;B(*"B,Z(&QI8B])35`N<&AP.CDU.0IM<V=I
M9"`B7U-E87)C:"(*;7-G<W1R(")?4W5C:&4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHV-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT,C8*;7-G:60@(E]396YD($UE<W-A9V4B"FUS9W-T<B`B7U-E;F1E
M;B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,S(*;7-G:60@(E]4:')E860B"FUS9W-T<B`B7U1H96UA(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3$T"FUS9VED(")?5&\B"FUS9W-T
M<B`B7T%N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*
M;7-G:60@(E]5;F1E;&5T92(*;7-G<W1R(")77VEE9&5R:&5R<W1E;&QE;B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM
M<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S='(@(E1H96UA($%N>F5I7V=E;B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B7U=H:71E
M;&ES="(*;7-G<W1R(")0;W-I=&EV;&ES=&4B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3<U"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")!9')E
M<W-A="!U;F)E:V%N;G0B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#4Q"FUS9VED
M(")A='1A8VAM96YT(@IM<V=S='(@(D%N:&%N9R(*"B,Z('9I97<N<&AP.CDW
M"FUS9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B86YH865N9V4N>FEP
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`U"FUS9VED
M(")B>71E<R(*;7-G<W1R(")">71E<R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M.3D*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B
M075S9V%B961A=&5I(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96XB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3<Q"FUS9VED(")C86YN;W0@;W!E;B!I;G!U
M="(*;7-G<W1R(")%:6YG86)E(&MA;FX@;FEC:'0@9V7V9F9N970@=V5R9&5N
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V,PIM<V=I9"`B8V]M;6%N9"!L:6YE
M('5S86=E(&5R<F]R(@IM<V=S='(@(E5N9_QL=&EG92!"96YU='IU;F<@9&5R
M($MO;6UA;F1O>F5I;&4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$Y"FUS9VED
M(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(DMO;F9I9W5R871I;VYS
M9F5H;&5R(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y-0IM<V=I9"`B8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")+<FET:7-C:&4@4WES
M=&5M9&%T96D@9F5H;'0B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38W"FUS9VED
M(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")$871E;F9O<FUA=&9E:&QE
M<B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C,*;7-G:60@(F5N=')Y(&YO="!F
M;W5N9"(*;7-G<W1R(")%:6YT<F%G(&YI8VAT(&=E9G5N9&5N(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB
M"FUS9W-T<B`B=F]N(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W.0IM<V=I9"`B
M:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B2&]S=&YA;64@=6YB96MA;FYT
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P,PIM<V=I9"`B:6YP=70O;W5T<'5T
M(&5R<F]R(@IM<V=S='(@(D5I;BTO075S9V%B969E:&QE<B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.#<*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R
M(@IM<V=S='(@(DEN=&5R;F5R(%-O9G1W87)E9F5H;&5R(@H*(SH@<VUI;64N
M<&AP.C(Y('!G<"YP:'`Z-C@*;7-G:60@(FME>2(*;7-G<W1R(")38VAL_'-S
M96PB"@HC.B!F;VQD97)S+G!H<#HQ-#4*;7-G:60@(FUA:6QB;W@@9FEL92(*
M;7-G<W1R(")/<F1N97)D871E:2(*"B,Z(&-O;7!O<V4N<&AP.C$Q,#4@;&EB
M+TUE<W-A9V4N<&AP.C4Q,PIM<V=I9"`B;F%M92(*;7-G<W1R(").86UE(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<V"FUS9VED(")N
M;VYE(@IM<V=S='(@(FME:6YE(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A
M8V-O=6YT7W-E;&5C="YI;F,Z,C4*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$P-0IM<V=I9"`B;W(B"FUS9W-T<B`B;V1E<B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HR,34*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM
M<V=S='(@(EIU9W)I9F8@=F5R=V5I9V5R="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V%D9')E<W-E<T)L;V-K<RYJ<SHX"FUS9VED(")R96-I<&EE;G1S
M72(*;7-G<W1R(")%;7!FY&YG97)=(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q
M,0IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(E)E
M;6]T969E:&QE<B!I;2!0<F]T;VMO;&PB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,3@S"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(E-E<G9I
M8V4@;FEC:'0@=F5R9OQG8F%R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R(")2
M96-H='-C:')E:6)F96AL97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(")2
M96-H='-C:')E:6)F96AL97(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DQ"FUS
M9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B4WES=&5M9F5H;&5R(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C(P-PIM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B
M"FUS9W-T<B`B5F]R_&)E<F=E:&5N9&5R($9E:&QE<B(*"B,Z(&QI8B]&:6QT
M97(N<&AP.C<Y"FUS9VED(")Y;W5R(&)L86-K;&ES="(*;7-G<W1R(")):')E
M<B!!=7-S8VAL=7-S;&ES=&4B"@HC.B!L:6(O1FEL=&5R+G!H<#HX.0IM<V=I
M9"`B>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B26AR97(@4&]S:71I=FQI<W1E
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R]N;%].3"YP;P``````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,C$P-#$`,3`T,3<S
M-C(W-C0`,#$W,3<R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@24U0($1U=&-H('1R86YS;&%T:6]N+@HC($-O<'ER:6=H
M="`H0RD@,C`P,2!*86X@2W5I<&5R<RX*(R!*86X@2W5I<&5R<R`\:G)K=6EP
M97)S0&QA=7=E<G-C;VQL96=E+FYL/BP@,C`P,2X*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U0(#0N,"UC=G-<;B(*(E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)0
M3U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)0
M3RU2979I<VEO;BU$871E.B`R,#`T+3$R+3`W(#$R.C4U*S`Q,#!<;B(*(DQA
M<W0M5')A;G-L871O<CH@2F%N($MU:7!E<G,@/&IR:W5I<&5R<T!L875W97)S
M8V]L;&5G92YN;#Y<;B(*(DQA;F=U86=E+51E86TZ($1U=&-H(#QI,3AN0&QI
M<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z("(*;7-G
M<W1R("(@("`@("!!86XZ("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,34*;7-G
M:60@(B`@("`@(%1O.B`B"FUS9W-T<B`B("`@("`@06%N.B`B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@1&%T93H@(@IM<V=S='(@(B`@
M("!$871U;3H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P-@IM<V=I9"`B("`@
M($9R;VTZ("(*;7-G<W1R("(@("`@("!686XZ("(*"B,Z(&UA:6QB;W@N<&AP
M.C0R,B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%-N96QT;V5T
M<R`E<RDB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$R"FUS9VED("(@4W5B:F5C
M=#H@(@IM<V=S='(@(B!/;F1E<G=E<G`Z("(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I9"`B(&EN("(*;7-G<W1R("(@:6X@
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ
M,@IM<V=I9"`B(R(*;7-G<W1R("(C(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B`O("4N,F9-0B`@
M*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"("\@)2XR9DU"("@E+C)F)24I(@H*
M(SH@=&AR96%D+G!H<#HQ-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5D($UE<W-A9V5S(@IM<V=S='(@(D=E96X@8F5R:6-H=&5N(@H*(SH@;6%I
M;&)O>"YP:'`Z,3<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M
M97-S86=E<R!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B)60@8F5R:6-H
M=&5N('II:FX@=F5R=VEJ9&5R9"XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(E9"!B97)I8VAT96X@>FEJ;B!A86X@=7<@<WES=&5E
M;6)E:&5E<F1E<B!G97)A<'!O<G1E97)D(&%L<R!G965N('-P86TN(@H*(SH@
M;&EB+U-P86TN<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S
M86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@
M(B5D(&)E<FEC:'1E;B!Z:6IN(&=E<F%P<&]R=&5E<F0@86QS(&=E96X@<W!A
M;2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B5D(&)E<FEC:'1E
M;B!Z:6IN(&%A;B!U=R!S>7-T965M8F5H965R9&5R(&=E<F%P<&]R=&5E<F0@
M86QS('-P86TN(@H*(SH@;&EB+U-P86TN<&AP.C$U,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A
M;2XB"FUS9W-T<B`B)60@8F5R:6-H=&5N('II:FX@9V5R87!P;W)T965R9"!A
M;',@<W!A;2XB"@HC.B!M86EL8F]X+G!H<#HS-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60@=&\@)60@;V8@)60@365S<V%G97,B"FUS9W-T<B`B)60@=&\@
M)60@=F%N("5D(&)E<FEC:'1E;B(*"B,Z(&UA:6QB;W@N<&AP.C8T,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H
M<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RX@
M66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA;65D+B(*;7-G<W1R("(E<R!B
M97-T86%T(')E961S+B!5=R`E<R!M87`@:7,@;FEE="!H97)N;V5M9"XB"@HC
M.B!L:6(O365S<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S
M='(@(B5S(&QI:FMT(&YI970@965N(&=E;&1I9V4@;6%I;&)O>"!T92!Z:6IN
M+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@
M8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G
M<W1R("(E<R!M87`@>F%L('=O<F1E;B!H97)N;V5M9"!A86X@:&5T(&)E9VEN
M('9A;B!D92!M86%N9"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,C4V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!A8V-E<'1E9"XB"FUS
M9W-T<B`B)7,@:&5E9G0@9V5A8V-E<'1E97)D+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B)7,@:&5E9G0@)7,@869G97IE9V0N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!H87,@9&5C;&EN960N(@IM<V=S='(@(B5S(&ES(&%F
M9V5N;VUE;BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DS"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B
M=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S(&AE969T(&=E86YT=V]O<F0@;W`@
M965N('9R:6HO8F5Z970@=F5R>F]E:RXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C$V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L
M:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E<R!H965F
M="!G96%N='=O;W)D(&]P(&1E('5I=&YO9&EG:6YG('9O;W(@)7,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(E<R!H965F="!U('9R:6HO8F5Z970@:6YF;W)M871I92!T;V5G
M97IO;F1E;BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E
M9"XB"FUS9W-T<B`B)7,@:7,@=F]O<FQO<&EG(&=E86-C97!T965R9"XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(E<R!V<F%A9W0@=7<@=G)I:B]B97IE="!I;F9O<FUA=&EE
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB
M"FUS9W-T<B`B)7,@=G)A86=T('5W(&%A;G=E>FEG:&5I9"!B:6H@)7,N(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N(@IM
M<V=S='(@(B5S(&UE="!S=6-C97,@=&]E9V5V;V5G9"!A86X@)7,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!W:7-H97,@=&\@86UM96YD("5S+B(*;7-G<W1R("(E<R!W96YS
M="`E<R!I;B!T92!B<F5N9V5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA
M:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(E<R!W96YS="!U(&]P(&1E
M(&AO;V=T92!T92!B<F5N9V5N('9A;B`E<RXB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE
M<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N
M(@IM<V=S='(@(B5S('=E;G-T(&1E(&QA871S=&4@:6YF;W)M871I92!T92!O
M;G1V86YG96X@;W9E<B`E<RXB"@HC.B!M97-S86=E+G!H<#HR.#4@;65S<V%G
M92YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R
M("(E<SH@)7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?=&]P+FEN
M8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D)FYB<W`[;V8F
M;F)S<#LE9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P.W9A;B9N8G-P.R5D
M*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G
M:60@(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R
M965N+BDB"FUS9W-T<B`B*$)E=F5S=&EG(&1E>F4@=VEJ>FEG:6YG96X@96X@
M9V$@;F%A<B!H970@=F]L9V5N9&4@<V-H97)M+BDB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED("(H1&ES8V%R9"!A;&P@
M8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI(@IM
M<V=S='(@(BA-86%K(&%L;&4@=VEJ>FEG:6YG96X@;VYG961A86X@96X@9V$@
M=&5R=6<@;F%A<B!<(DYI975W(&)E<FEC:'1<(BXI(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED("(H2%1-
M3"DB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHQ-@IM<V=I9"`B*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z
M('-P96QL:6YG+G!H<#HR.#`*;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O
M;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@
M=&AU<R!F87(N("`B"B)#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W
M:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*$=A('1E<G5G(&YA
M87(@7").:65U=R!B97)I8VAT7"(@;F$@8F5V97-T:6=I;F<@=F%N(&%L;&4L
M('1O="!D=7,@=F5R+"`B"B)A86YG96)R86-H=&4@=VEJ>FEG:6YG96XN(%9E
M<F%N9&5R:6YG96X@;W`@:&5T(&AU:61I9V4@<V-H97)M('=O<F1E;B!.2454
M("(*(F1O;W)G979O97)D+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"FUS9VED
M("(B"B(H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S
M(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C
M<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*%9E<GIE
M;F0@8F5R:6-H="!N82!U:71V;V5R:6YG('9A;B!A;&QE('=I:GII9VEN9V5N
M('1O="!N=2!T;V4N("(*(E9E<F%N9&5R:6YG96X@;W`@:&5T(&AU:61I9V4@
M<V-H97)M('=O<F1E;B!.2454(&1O;W)G979O97)D+BDB"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE
M<V4@8GD@8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J(%1O979O96=E;BP@:VQI
M:R!O<"!/2R`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM
M<V=S='(@(BH@4V5L96-T965R(&%D<F5S*'-E;BDL(&$N=2YB+B`J(@H*(SH@
M;6%I;&)O>"YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B2&5T(&)E<FEC:'0@:7,@=F5R=VEJ
M9&5R9"XB"@HC.B!L:6(O4W!A;2YP:'`Z,3@P"FUS9VED("(Q(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B,2!B97)I8VAT(&ES(&%A;B!U=R!S
M>7-T965M8F5H965R9&5R(&=E<F%P<&]R=&5E<F0@86QS(&=E96X@<W!A;2XB
M"@HC.B!L:6(O4W!A;2YP:'`Z,38P"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E
M96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(C$@8F5R:6-H="!I
M<R!G97)A<'!O<G1E97)D(&%L<R!G965N('-P86TN(@H*(SH@;&EB+U-P86TN
M<&AP.C$W,@IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M,2!B97)I8VAT(&ES(&%A;B!U=R!S>7-T965M8F5H965R9&5R(&=E<F%P<&]R
M=&5E<F0@86QS('-P86TN(@H*(SH@;&EB+U-P86TN<&AP.C$U,@IM<V=I9"`B
M,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@
M(C$@8F5R:6-H="!I<R!G97)A<'!O<G1E97)D(&%L<R!S<&%M+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*;7-G:60@(C$P,"!C:&%R86-T97)S
M(@IM<V=S='(@(C$P,"!K87)A:W1E<G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#(R"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B,3`P
M,"!K87)A:W1E<G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(P"FUS
M9VED("(R-3`@8VAA<F%C=&5R<R(*;7-G<W1R("(R-3`@:V%R86MT97)S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,0IM<V=I9"`B-3`P(&-H87)A
M8W1E<G,B"FUS9W-T<B`B-3`P(&MA<F%K=&5R<R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA
M<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G
M92XB"FUS9W-T<B`B165N(&=R;W1E(&%F8F5E;&1I;F<@)7,@:7,@9V5K;W!P
M96QD(&UE="!D:70@8F5R:6-H="XB"@HC.B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M97-S86=E('EO=2!H879E
M('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F
M<F]M('1H92`B"B)R96-I<&EE;G0N(@IM<V=S='(@(B(*(D5E;B!D;V]R('4@
M=F5R<W1U=7)D(&)E<FEC:'0@:&5E9G0@9V5R97-U;'1E97)D(&EN(&5E;B!O
M;G1V86YG<W1B979E<W1I9VEN9R`B"B)V86X@9&4@;VYT=F%N9V5R+B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!3D0B"FUS
M9W-T<B`B14XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DP"FUS
M9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")697)Z;V5K(&%C8V5P=&5R
M96XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W"B,L(&9U>GIY
M"FUS9VED(")!8V-E<'0@<F5Q=65S="!A;F0@861D(&ET('1O(&UY(&-A;&5N
M9&%R(@IM<V=S='(@(D1E(&=E8F5U<G1E;FES(&ES(&%A;B!U=R!A9V5N9&$@
M=&]E9V5V;V5G9"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4S
M"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R(")'96%C8V5P=&5E<F0B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4W"B,L(&9U>GIY"FUS9VED(")!
M8V-E<'1E9#H@(@IM<V=S='(@(D=E86-C97!T965R9"(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT)W,@;F%M
M93HB"FUS9W-T<B`B06-C;W5N=&YA86TZ(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4R,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,P"FUS
M9VED(")!8W1I;VYS(@IM<V=S='(@(D)E=V5R:VEN9V5N(@H*(SH@;&EB+TU)
M344O2&5A9&5R<RYP:'`Z,C`P(&QI8B]-24U%+TAE861E<G,N<&AP.C(P,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D("5S('1O(&UY($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")6;V5G('1O92!A86X@861R97-B;V5K("@E<RDB
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*;7-G
M:60@(D%D9"!S;W5R8V4B"FUS9W-T<B`B0G)O;B!T;V5V;V5G96XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU.#@*;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM
M<V=S='(@(D1I="!A86X@;6EJ;B!A9V5N9&$@=&]E=F]E9V5N(@H*(SH@8V]M
M<&]S92YP:'`Z,3(U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S
M7"(@87,@86X@871T86-H;65N="XB"FUS9W-T<B`B7"(E<UPB(&%L<R!B:6IL
M86=E('1O96=E=F]E9V0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M.`HC+"!F=7IZ>0IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I
M<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H
M(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(D5X
M=')A(&MO<'!E;B!T;VYE;B!B:6H@=V5E<F=A=F4Z(#QI/BAO<'1I;VYE96PL
M(&5L:V4@:V]P(&]P(&5E;B!N:65U=V4@<F5G96P@(@HB:6YV;V5R96XI/"]I
M/B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N
M(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B17AT<F$@:6YF;W)M871I92!K86X@
M=V]R9&5N(&)E:V5K96X@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C(*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@
M9&5T86EL<R(*;7-G<W1R(")%>'1R82!I;F9O<FUA=&EE9&5T86EL<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDS"FUS9VED(")!9&1I=&EO
M;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G<W1R(")%>'1R82!B97)I8VAT9&5T
M86EL<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDR"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(D5X=')A(&)E<FEC:'1D971A:6QS
M(&MU;FYE;B!B96ME:V5N('=O<F1E;B`E<RXB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R
M<F]R(&1E=&%I;',B"FUS9W-T<B`B17AT<F$@8F5R:6-H=&9O=71D971A:6QS
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@
M8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B17AT<F$@8F5R:6-H=&9O=71D
M971A:6QS(&MU;FYE;B!B96ME:V5N('=O<F1E;B`E<RXB"@HC.B!C;VYT86-T
M<RYP:'`Z.#4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,@IM<V=I9"`B061D<F5S<R!";V]K
M(@IM<V=S='(@(D%D<F5S8F]E:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S0*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B061R97-B;V5K
M96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Y"B,L(&9U>GIY"FUS
M9VED("(B"B)!9&1R97-S97,@=&\@0D-#(&%L;"!M97-S86=E<SH@/&5M/BAO
M<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W("(*(FQI;F4I
M/"]E;3XB"FUS9W-T<B`B(@HB061R97-S96X@;F%A<B!"0T,@86QL92!B97)I
M8VAT96XZ(#QI/BAO<'1I;VYE96PL(&5L:R!A9')E<R!O<"!E96X@;FEE=7=E
M("(*(G)E9V5L(&EN=F]E<F5N*3PO:3XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3@Q"B,L(&9U>GIY"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP
M;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@
M96YT97(@96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS
M9W-T<B`B(@HB061R97-S96X@=V5L:V4@97AP;&EC:65T(&%A;B!D97IE(&ED
M96YT:71E:70@9V5K;W!P96QD('=O<F1E;CH@/&D^(@HB*&]P=&EO;F5E;"P@
M96QK(&%D<F5S(&]P(&5E;B!N:65U=V4@<F5G96P@:6YV;V5R96XI/"]I/B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3`@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R,PIM<V=I9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S"FUS9VED("(B
M"B)!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL
M;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@(@HB9FEL93HB"FUS9W-T
M<B`B(@HB06QL92!B97)I8VAT96X@:6X@9&4@=F]L9V5N9&4@;6%P*'!E;BD@
M=V]R9&5N(&=E9&]W;FQO860@;F%A<B#IZ6X@34)/6"`B"B)B97-T86YD.B(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HX,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@>6]U<B!<
M(B5S7"(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA
M;F5N=&QY("(*(F1E;&5T960N(@IM<V=S='(@(B(*(D%L;&4@8F5R:6-H=&5N
M(&EN('5W(%PB)7-<(B!M87`L(&]U9&5R(&1A;B`E<R!D86=E;BP@>G5L;&5N
M(&1E9FEN:71I968@(@HB=V]R9&5N('9E<G=I:F1E<F0N(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP
M.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T=&%C
M:&UE;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E
M9"XB"FUS9W-T<B`B(@HB06QL92!O=61E(&=E:V]P<&5L9&4@8FEJ;&%G96XL
M(&]U9&5R(&1A;B`E<R!M86%N9&5N+"!Z=6QL96X@=V]R9&5N("(*(G9E<G=I
M:F1E<F0N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@
M=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("(B"B)!;&QE(&]U9&4@7")/551"
M3UA<(B!M87!P96XL(&]U9&5R(&1A;B`E<R!M86%N9&5N+"!Z=6QL96X@=V]R
M9&5N('9E<G=I:F1E<F0N(@H*(SH@86-L+G!H<#HX-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B06QL(')I9VAT<R!O;B!F;VQD97(@7"(E<UPB('-U
M8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U<V5R(%PB)7-<(BXB"FUS9W-T<B`B
M(@HB06QL92!R96-H=&5N(&]P(&UA<"`G)7,G('9O;W(@9V5B<G5I:V5R("<E
M<R<@=V5R9&5N(&UE="!S=6-C97,@=F5R=VEJ9&5R9"XB"@HC.B!L:6(O87!I
M+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L9&5R($-R96%T:6]N/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#@*;7-G:60@
M(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M86EL
M8F]X/R(*;7-G<W1R(")4;V5P87-S96X@=F%N(&9I;'1E<G)E9V5L<R!O<"!E
M;&ME(&UA:6QB;W@@=&]E<W1A86X_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L
M=&5R;F%T:79E+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E('!A<G1S(&9O
M<B!T:&ES('-E8W1I;VXZ(@IM<V=S='(@(D%L=&5R;F%T:65V92!O;F1E<F1E
M;&5N('9O;W(@9&5Z92!S96-T:64Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4W,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@T"FUS9VED(")!;'=A
M>7,B"FUS9W-T<B`B06QT:6ID(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4U-PIM<V=I9"`B06QW87ES('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B
M06QT:6ID(&)I:FQA9V5N(&]P<VQA86XB"@HC.B!L:6(O365S<V%G92YP:'`Z
M-3`U"FUS9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I
M;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B`B
M"B)S86ED.B`B"FUS9W-T<B`B(@HB165N(&9O=70@8FEJ(&1E('!O9VEN9R!O
M;2!D92!B:6IL86=E('1E('-T<FEP<&5N+B!$92!)34%0('-E<G9E<B!M96QD
M=#HB"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE
M=R!N;W1E+B(*;7-G<W1R(")%96X@;VYB96ME;F1E(&9O=70@;W!G971R961E
M;B!B:6H@:&5T(&UA:V5N('9A;B!D92!N:65U=V4@=&%A:RXB"@HC.B!L:6(O
M365S<V%G92YP:'`Z,S@W"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R
M960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+B(*;7-G<W1R(")%96X@
M;VYB96ME;F1E(&9O=70@;W!G971R961E;B!B:6H@:&5T(&UA:V5N('9A;B!D
M92!N:65U=V4@=&%A:RXB"@HC.B!M97-S86=E+G!H<#HU,#`@;6%I;&)O>"YP
M:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R(")"96%N='=O
M;W)D(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B
M06YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B0F5A;G1W;V]R9&4@8F5R:6-H
M=&5N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"FUS9VED
M(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(D9I;'1E<G,@=&]E<&%S<V5N(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`B1FEL=&5R
M<R!T;V5P87-S96X@;W`@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,S8*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I
M;F<@;VX_(@IM<V=S='(@(D9I;'1E<G)E9V5L<R!T;V5P87-S96X@8FEJ(&%A
M;FUE;&1I;F<_(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0R
M"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@
M9&ES<&QA>65D/R(*;7-G<W1R(")&:6QT97)R96=E;',@=&]E<&%S<V5N('=A
M;FYE97(@24Y"3U@@=V]R9'0@=V5E<F=E9V5V96X_(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P
M=6)L:6,@:V5Y/R(*;7-G<W1R(")7965T('4@>F5K97(@9&%T('4@9&5Z92!O
M<&5N8F%R92!S;&5U=&5L('=I;'0@=F5R=VEJ9&5R96X_(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M.#4*;7-G:60@(B(*(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@
M>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD960A*2(*;7-G
M<W1R("(B"B)7965T('4@>F5K97(@9&%T('4@=7<@<VQE=71E;'!A87(@=VEL
M="!V97)W:6ID97)E;C\@*$1I="!W;W)D="!.2454("(*(F%A;F)E=F]L96XA
M*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&1O('1H:7,_(@IM<V=S='(@(E=E970@=2!Z96ME<B!D
M870@=2!D:70@=VEL="!D;V5N/R(*"B,Z(&UE<W-A9V4N<&AP.C0P-R!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV.`IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M
M97-S86=E<S\B"FUS9W-T<B`B5V5E="!U('IE:V5R(&1A="!U(&1E>F4@8F5R
M:6-H=&5N($1%1DE.251)148@=VEL="!V97)W:6ID97)E;C\B"@HC.B!L:6(O
M34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B
M"FUS9W-T<B`B5V5E="!U('IE:V5R(&1A="!U(&1E>F4@8FEJ;&%G92!$149)
M3DE4245&('=I;'0@=F5R=VEJ9&5R96X_(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`B5V5E="!U('IE:V5R
M(&1A="!U(&1E>F4@;6%P('=I;'0@;&5E9VUA:V5N/R(*"B,Z(&QI8B])35`N
M<&AP.CDW,PHC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&5M<'1Y('EO=7(@<W!A;2!F;VQD97(_(@IM<V=S='(@(E=E970@=2!Z
M96ME<B!D870@=2!U=R!P<G5L;&5N8F%K('=I;'0@;&5E9VUA:V5N/R(*"B,Z
M(&QI8B])35`N<&AP.CDV-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/R(*;7-G<W1R(")7965T('4@
M>F5K97(@9&%T('4@=7<@<')U;&QE;F)A:R!W:6QT(&QE96=M86ME;C\B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E
M(&UE<W-A9V5S/R(*;7-G<W1R(")7965T('4@>F5K97(@9&%T('4@9&5Z92!B
M97)I8VAT96X@1$5&24Y)5$E%1B!W:6QT('9E<G=I:F1E<F5N/R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\B
M"FUS9W-T<B`B5V5E="!U('IE:V5R(&1A="!U(&1I="!B97)I8VAT(&%L<R!O
M;G-C:'5L9&EG('=I;'0@<F%P<&]R=&5R96X_(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:F%V87-C<FEP="YI;F,Z-S4@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z-S0*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!R97!O<G0@=&AI<R!M97-S86=E(&%S('-P86T_(@IM<V=S='(@(E=E970@
M=2!Z96ME<B!D870@=2!D:70@8F5R:6-H="!A;',@<W!A;2!W:6QT(')A<'!O
M<G1E<F5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,38*;7-G:60@
M(D%R<FEV86P@5&EM92(*;7-G<W1R(")!86YK;VUS='1I:F0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T
M<B`B5&]E;F5M96YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B
M5G)A9V5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$Y
M"FUS9VED(")!='1A8V@B"FUS9W-T<B`B5&]E=F]E9V5N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<U"FUS9VED(")!='1A8V@@1FEL
M97,B"FUS9W-T<B`B5&]E9V5V;V5G9&4@8F5S=&%N9&5N.B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U-@IM<V=I9"`B071T86-H(&$@
M8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\B
M"FUS9W-T<B`B165N(&MO<&EE('9A;B!U=R!O<&5N8F%R92!01U`@<VQE=71E
M;"!A86X@=7<@8F5R:6-H="!T;V5V;V5G96X_(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.C$P.0IM<V=I9"`B071T86-H960@1FEL93HB"FUS9W-T
M<B`B5&]E9V5V;V5G9"!B97-T86YD.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT
M-3$@;&EB+T-O;7!O<V4N<&AP.C4S-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A8VAM96YT
M('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T<B`B(@HB
M5&]E9V5V;V5G9"!B97-T86YD(%PB)7-<(B!O=F5R<V-H<FEJ9'0@9&4@;6%X
M:6UU;2!B:6IL86=E9W)O;W1T92X@0F5S=&%N9"!I<R`B"B).2454('1O96=E
M=F]E9V0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,W-@IM<V=I
M9"`B071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@
M>6]U('-E;G0N(@IM<V=S='(@(D5E;B!A;G1W;V]R9"!O<"!E96XL(&1O;W(@
M=2!G97IO;F1E;B!A9V5N9&%V97)Z;V5K+"!I<R!T;V5G979O96=D+B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4P-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT
M<RYJ<SHY-PIM<V=I9"`B071T86-H;65N="(*;7-G<W1R(")":6IL86=E(@H*
M(SH@8V]M<&]S92YP:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED
M(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y
M<&4B"FUS9W-T<B`B0FEJ;&%G92!G97-T<FEP=#H@;W)I9VEN965L(&)I:FQA
M9V5T>7!E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W,PHC.B!L:6(O0V]M
M<&]S92YP:'`Z,3`W,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`B0FEJ
M;&%G96XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@R"FUS9VED
M(")!='1E;F1E97,B"FUS9W-T<B`B06%N=V5Z:6=E;B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"FUS9VED(")!='1E;G1I;VXB
M"FUS9W-T<B`B06%N9&%C:'0B"@HC.B!L:6(O075T:"]I;7`N<&AP.C0T"FUS
M9VED(")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VEM<#H@5F5R96ES=&4@24U!4"!E>'1E;G1I
M92!N:65T(&=E=F]N9&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-#`*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-
M3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S
M<V)O;VL_(@IM<V=S='(@(B(*(D%U=&]M871I<V-H(&%F8F5E;&1I;F=E;B!I
M;B!(5$U,(&)E<FEC:'1E;B!W965R9V5V96XL('=A;FYE97(@9&4@869Z96YD
M97(@(@HB>FEC:"!I;B!M:6IN(&%D<F5S8F]E:R!B979I;F1T/R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y.`IM<V=I9"`B079A
M:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(D)E<V-H:6MB87)E(&%D
M<F5S8F]E:V5N.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,3D*
M;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@(DEN(&%F=V%C:'1I
M;F<@=F%N(&%N='=O;W)D(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"86-?:R!T
M;R`E<R(*;7-G<W1R(")?5&5R=6<@;F%A<B`E<R(*"B,Z('1H<F5A9"YP:'`Z
M,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R(")497)U
M9R!N86%R("5S(@H*(SH@=&AR96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@
M375L=&EP;&4@365S<V%G92!6:65W($EN9&5X(@IM<V=S='(@(B(*"B,Z('1H
M<F5A9"YP:'`Z,3,R"FUS9VED(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R
M(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8V
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z
M,S0*;7-G:60@(D)C8R(*;7-G<W1R(")"8V,B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X
M="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@
M(DAI97)O;F1E<B!S=&%A="!D92!R=7=E('1E:W-T('9A;B!H970@<W1A='5S
M:6YF;W)M871I96)E<FEC:'0N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$V"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`B6G=A<G1E(&QI:G-T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8R.0IM<V=I9"`B0FQO8VL@
M:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I
M9FEC86QL>2!R97%U97-T960_(@IM<V=S='(@(B(*(D)L;VMK965R(&%F8F5E
M;&1I;F=E;B!I;B!(5$U,(&)E<FEC:'1E;BP@=&5N>FEJ(&1E>F4@<W!E8VEF
M:65K(&%A;F=E=G)A86=D("(*(G=O<F1E;C\B"@HC.B!L:6(O4V5A<F-H+G!H
M<#HT,@IM<V=I9"`B0F]D>2(*;7-G<W1R(")";V1Y(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")"96ED
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#<*;7-G:60@(D)O=&@@
M2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R("):
M;W=E;"!I;B!H96%D97(@86QS(&EN(&)O9'D@=F%N(&)E<FEC:'0@=V5E<F=E
M=F5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R"FUS
M9VED(")#7VAA<G-E="(*;7-G<W1R(")+87)A:U]T97)S970B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(D-A;&5N9&%R(@IM
M<V=S='(@(D%G96YD82(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C`Q
M"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E
M<G9E<BXB"FUS9W-T<B`B2V%N(&YI970@=F5R8FEN9&5N(&UE="!D92!M86EL
M<V5R=F5R(&]P(&%F<W1A;F0N(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ.3D*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA
M:6P@<V5R=F5R.B`B"FUS9W-T<B`B2V%N(&YI970@=F5R8FEN9&5N(&UE="!D
M92!M86EL<V5R=F5R(&]P(&%F<W1A;F0Z("(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#86X@
M;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H
M:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R
M("(B"B)+86X@;FEE="!W965R9V5V96X@+2!A;&QE96X@)7,@=F%N("5S(&]N
M9&5R9&5L96X@=F%N(&1I="!B97)I8VAT(&EN(&1E("(*(FAU:61I9V4@;6%I
M;&)O>"!G979O;F1E;BXB"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G
M92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S
M<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHV-@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%F8G)E:V5N(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#,U"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHQ,3$*;7-G:60@(D-A;F-E;"!-97-S86=E(@IM<V=S='(@(D)E
M<FEC:'0@869B<F5K96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G:60@
M(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES
M8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(D)I:B!A9F)R96ME;B!V86X@
M9&ET(&)E<FEC:'0L(&=A870@9&4@:6YH;W5D(&1E9FEN:71I968@=F5R;&]R
M96XN(@H*(SH@;65S<V%G92YP:'`Z,C8U('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S
M92YI;F,Z,34@;&EB+U-E87)C:"YP:'`Z,S`*;7-G:60@(D-C(@IM<V=S='(@
M(D-C(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,PIM<V=I9"`B
M(@HB0V5R=&EF:6-A=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@
M=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@(@HB<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Q"FUS9VED
M(")#:&%I<B!097)S;VXB"FUS9W-T<B`B5F]O<GII='1E<B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(E=I:GII9V5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(E=I:GII9R!A
M;&QE<R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B0VAA
M;F=E($9O;&1E<B(*;7-G<W1R(")7:6IZ:6<@;6%P(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T
M:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C
M:"!P86=E(&%N9"`B"B)H;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T
M<B`B(@HB5VEJ>FEG('=E97)G879E;W!T:65S+"!Z;V%L<R!H;V5V965L(&)E
M<FEC:'1E;B!P97(@<&%G:6YA('=O<F1E;B!A9F=E8F5E;&0@(@HB96X@:&]E
M(&1E(&)E<FEC:'1E;B!W;W)D96X@9V5S;W)T965R9"XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C0*;7-G:60@(D-H86YG92!M86EL('-E<G9E<B!A
M;F0@9F]L9&5R('-E='1I;F=S+B(*;7-G<W1R(")7:6IZ:6<@=7<@;6%I;'-E
M<G9E<BT@96X@;6%P:6YS=&5L;&EN9V5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A9&1R97-S
M+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B(@HB5VEJ
M>FEG(&1E(&YA86TL(&%D<F5S(&5N(&]N9&5R=&5K96YI;F<@9&EE(&UE;B!Z
M:65T(&)I:B!H970@;&5Z96X@96X@(@HB8F5A;G1W;V]R9&5N('9A;B!U=R!E
M+6UA:6PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R-`IM<V=I9"`B
M0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")7965R('1E(&=E=F5N
M(&MA<F%K=&5R<SHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ-0IM<V=I9"`B0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G
M<W1R(")#;VYT<F]L965R(&UA<"AP96XI(&]P(&YI975W92!M86EL(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C<U"FUS9VED(")#:&5C:R!?06QL
M+TYO;F4B"FUS9W-T<B`B0V]N=')O;&5E<B!?06QL97,O1V5E;B(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP;&%T97,O
M9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K(&%L;"!M
M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.B(*;7-G
M<W1R(")#;VYT<F]L965R(&%L;&4@;6%I;'-E<G9E<G,L('=A87)V86X@=2!M
M86EL('=I;'0@;W!H86QE;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#8S"FUS9VED(")#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE
M<W-A9V4_(@IM<V=S='(@(E-P96QL:6YG<V-O;G1R;VQE('9O;W(@=F5R<W1U
M<F5N('9A;B!E96X@8F5R:6-H=#\B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHT"FUS9VED(")#:&]O<V4@06-T:6]N.B(*;7-G<W1R(")+
M:65S(&)E=V5R:VEN9SHB"@HC.B!C;VYF:6<O<V5R=F5R<RYP:'`N9&ES=#HQ
M.#(*;7-G:60@(D-H;V]S92!A(&UA:6P@<V5R=F5R.B(*;7-G<W1R(")+:65S
M(&5E;B!M86EL<V5R=F5R.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C$R-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-C8*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C$W"B,L(&9U>GIY
M"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E9&ET('1H92!A9&1R97-S('1O
M('1H92!R:6=H=#HB"FUS9W-T<B`B4V5L96-T965R(&]F(&)E=V5R:R!I;B!H
M970@=F%K(&%A;B!D92!R96-H=&5R:V%N=#HB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*
M;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(DMI97,@965N(&)E
M=V5R:VEN9SHB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS-#D*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W
M:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(DMI97,@:&5T(&%D<F5S
M8F]E:R!V;V]R(&AE="!T;V5V;V5G96X@=F%N(&%D<F5S<V5N+B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PIM<V=I9"`B0VAO
M;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N
M(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(B(*(DMI97,@9&4@=F]L
M9V]R9&4@=F%N(&%D<F5S8F]E:V5N(&]M('1E(&1O;W)Z;V5K96X@="YB+G8N
M(&YA86US=6ET8G)E:61I;F<N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O
M;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S
M97(@8V%N('9I97<N(@IM<V=S='(@(B(*(DML:6L@;W`@)7,@;VT@9&4@869B
M965L9&EN9R!T92!C;VYV97)T97)E;B!N86%R(&5E;B!F;W)M86%T('=A="!U
M=R!B<F]W<V5R("(*(FMA;B!W965R9V5V96XN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+B(*;7-G<W1R(")+;&EK("5S(&]M
M(&1E(&%F8F5E;&1I;F<@=&4@9&]W;FQO861E;BXB"@HC.B!L:6(O1FEL=&5R
M+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@
M=&\@)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R(")+;&EK("5S(&]M(&YA
M87(@9&4@)7,@8F5H965R<&%G:6YA('1E(&=A86XN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC
M:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O
M=RXB"FUS9W-T<B`B2VQI:R`E<R!O;2!(5$U,(&EN:&]U9"!I;B!E96X@87!A
M<G0@<V-H97)M('1E(&)E:VEJ:V5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!V:65W(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(DML
M:6L@;W`@)7,@;VT@965N('1H=6UB;F%I;"!V86X@9&5Z92!A9F)E96QD:6YG
M('=E97(@=&4@9V5V96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T
M:&4@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B
M2VQI:R`E<R!O;2!D92!B:6IL86=E(&EN(&5E;B!A<&%R="!S8VAE<FT@=&4@
M8F5K:6IK96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W
M('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I
M;F1O=RXB"FUS9W-T<B`B2VQI:R`E<R!O;2!D92!B:6IL86=E(&EN(&5E;B!A
M<&%R="!S8VAE<FT@=&4@8F5K:6IK96XN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VAT;6PN<&AP.CDU"FUS9VED(")#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM
M86=E<R(*;7-G<W1R(")+;&EK(&AI97(@;VT@9&4@869B965L9&EN9V5N('=E
M97(@=&4@9V5V96XB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHS,C$*;7-G:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C
M=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@
M=&\@(@HB<V5A<F-H+B(*;7-G<W1R("(B"B)+;&EK(&]P(.GI;B!V86X@=7<@
M9V5S96QE8W1E97)D92!A9')E<V)O96ME;B!E;B!S96QE8W1E97(@9&%A<FYA
M(&%L;&4@=F5L9&5N("(*(G=E;&ME(&1O;W)Z;V-H="!D:65N96X@=&4@=V]R
M9&5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,0IM<V=I9"`B
M0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@
M8F]O:R(*;7-G<W1R(")+;&EK(&]M(&1E(&]P96YB87)E(%!'4"!S;&5U=&5L
M(&EN('5W(&%D<F5S8F]E:R!O<"!T92!S;&%A;B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K
M('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D
M<F5S<R!";V]K(@IM<V=S='(@(DML:6L@;VT@:&5T(%,O34E-12!C97)T:69I
M8V%A="!V86X@)7,@:6X@=7<@861R97-B;V5K(&]P('1E('-L86%N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,`IM<V=I9"`B0VQI8VMI;F<@;VX@
M=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE
M('-E;F1E<B(*;7-G<W1R(")+;&EK:V5N(&]P(&AE="!A9')E<R!Z86P@965N
M(&YI975W(&)E<FEC:'0@;6%K96X@=F]O<B!D92!A9GIE;F1E<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3$*;7-G:60@(D-L:6-K:6YG(&]N('1H
M92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D(@IM
M<V=S='(@(DML:6MK96X@;W`@:&5T(&%D<F5S('IA;"!H970@8F5R:6-H="!O
M<&5N96X@;VT@=&4@;&5Z96XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E
M=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S='(@(E-L=6ET96XB
M"@HC.B!C;VUP;W-E+G!H<#HX,C@@8V]M<&]S92YP:'`Z,3$T.`IM<V=I9"`B
M0VQO<V4@=&AI<R!W:6YD;W<B"FUS9W-T<B`B4VQU:70@9&ET('9E;G-T97(B
M"@HC.B!F;VQD97)S+G!H<#HT,CD*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS
M9W-T<B`B1V5S;&]T96X@;6%P(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS9VED
M(")#;VQL87!S92(*;7-G<W1R("));FML87!P96XB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL(@IM
M<V=S='(@(D%L;&5S(&EN:VQA<'!E;B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")#;VQL87!S92!!;&P@1F]L9&5R<R(*
M;7-G<W1R(")!;&QE(&UA<'!E;B!I;FML87!P96XB"@HC.B!F;VQD97)S+G!H
M<#HT-#D*;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R(")-87`@:6YK
M;&%P<&5N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C4Q
M"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R(")+;&5U<FEN9&EC
M871O<CH@(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P,PIM<V=I9"`B
M0V]M;65N="(*;7-G<W1R(")/<&UE<FMI;F<B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S8Y"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B069G
M97)O;F0B"@HC.B!C;VUP;W-E+G!H<#HX,C<@8V]M<&]S92YP:'`Z,3$T-PIM
M<V=I9"`B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B"FUS9W-T<B`B36%A:R!E
M96X@86YD97(@8F5R:6-H="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,S0*;7-G:60@(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD
M;W<_(@IM<V=S='(@(DUA86L@965N(&YI975W(&)E<FEC:'0@:6X@965N(&%P
M87)T('-C:&5R;3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0S"FUS
M9VED("(B"B)#;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@
M9&5F875L="`H:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_
M(@IM<V=S='(@(B(*(DUA86L@8F5R:6-H=&5N(&TN8BYV+B!E96X@2%1-3"!G
M96)R=6EK97)S:6YT97)F86-E("AW86YN965R(&1E(&)R;W=S97(@9&ET("(*
M(F]N9&5R<W1E=6YT*3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<*
M;7-G:60@(D-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I<W!L87EE9"XB
M"FUS9W-T<B`B26YS=&5L;&5N(&AO92!B97)I8VAT96X@=V]R9&5N('=E97)G
M96=E=F5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B
M0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+B(*;7-G<W1R(")-86EL
M<')E=FEE=V]P=&EE<R!I;G-T96QL96XN(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HS-S`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9')O<'!E9"!B
M>2!)34%0('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9&EN9R!M970@9&4@<V5R
M=F5R(&UI<VQU:W0B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S='(@(E9E
M<F)I;F1I;F<@;65T(&1E('-E<G9E<B!M:7-L=6MT(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L
M(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B0F5H965R(%!'4"!O;F1E
M<G-T975N:6YG('9A;B`E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34R"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4R]-24U%('-U<'!O
M<G0@9F]R("5S+B(*;7-G<W1R(")"96AE97(@4R]-24U%(&]N9&5R<W1E=6YI
M;F<@=F%N("5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G
M:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S96%R
M8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE
M8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U("(*
M(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB0F5P86%L('=A;FYE97(@
M9V5C;VYT<F]L965R9"!W;W)D="!O<"!N:65U=V4@;6%I;"!E;B!O9B!U('9A
M;B!D92!A86YK;VUS="`B"B)H:65R=F%N+"!W96P@;V8@;FEE="!V86X@;W`@
M9&4@:&]O9W1E(&=E8G)A8VAT('=I;"!W;W)D96XN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8Y-@IM<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M;W1I
M8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R(")#;VYV97)T965R
M('1E:W-T(&5M;W1I8V]N<R!N86%R(&=R869I<V-H92!E;6]T:6-O;G,_(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM
M<V=S='(@(DMO<&GK<F5N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C4Q"FUS9VED(")#;W!Y('1O(&9O;&1E<B(*;7-G<W1R(")+;W!I965R(&YA
M87(@;6%P(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S
M"FUS9VED(")#;W)R96-T(@IM<V=S='(@(D-O<G)I9V5R96XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,30P"FUS9VED(")#;W)R96-T
M960@5&5X="(*;7-G<W1R(")'96-O<G)I9V5E<F1E('1E:W-T(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ
M("5S(@IM<V=S='(@(DMO;B!H970@5D93(&)A8VME;F0@)7,@;FEE="!M86ME
M;B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G<W1R
M(")+;VX@:&5T(%9&4R!B86-K96YD("5S(&YI970@;6%K96XB"@HC.B!L:6(O
M365S<V%G92YP:'`Z-C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E
M<R(*;7-G<W1R(")+;VX@8F5R:6-H=&5N(&EN("5S(&YI970@=F5R=VEJ9&5R
M96XN($1E('-E<G9E<B!M96QD=#H@)7,B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z
M,S$X"FUS9VED(")#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R
M871I;VYS+B(*;7-G<W1R(")+;VX@;VYD97)H;W5D<W=E<FMZ86%M:&5D96X@
M;FEE="!U:71V;V5R96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R(")+;VX@
M:&5T(&=E=V5N<W1E(&)E<W1A;F0@;FEE="!U:70@9&4@35,M5$Y%1B!B:6IL
M86=E(&AA;&5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS
M9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O
M;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@(DMO;B!H970@9V5W96YS=&4@
M8F5S=&%N9"!N:65T('5I="!H970@>FEP+6)E<W1A;F0@:&%L96XN(@H*(SH@
M;&EB+U-E<W-I;VXN<&AP.C(W,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!S96%R8V@N<&AP.C,Q-"!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C,Y"B,Z('1E
M;7!L871E<R]A8VPO86-L+FEN8SHQ-C`*;7-G:60@(D-R96%T92(*;7-G<W1R
M(")-86ME;B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C8*
M;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T<B`B36%A:R!M87`B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED(")#<F5A=&4@2V5Y<R(*
M;7-G<W1R(")3;&5U=&5L<R!M86ME;B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M:&5A9&5R+FEN8SHQ-`IM<V=I9"`B0W)E871E(%9I<G1U86P@1F]L9&5R(@IM
M<V=S='(@(DUA86L@=FER='5E;&4@;6%P(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(D-R
M96%T92!A($YE=R!!8V-O=6YT(@IM<V=S='(@(D%N9&5R92!M86EL86-C;W5N
M=',B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M
M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,L(&9U>GIY"FUS9VED
M(")#<F5A=&4@82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B36%A:R!E96X@
M;FEE=7=E('!R=6QL96YB86LB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R
M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN
M8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T
M<B`B36%A:R!E96X@;FEE=7=E(&ML861M87`B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(V('1E;7!L871E<R]P<F5F<R]S96YT
M;6%I;'-E;&5C="YI;F,Z-#(*;7-G:60@(D-R96%T92!A(&YE=R!S96YT(&UA
M:6P@9F]L9&5R(@IM<V=S='(@(DUA86L@965N(&YI975W92!/551"3U@B"@HC
M.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C$R('1E;7!L871E
M<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE
M=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B36%A:R!E96X@;FEE=7=E('!R=6QL
M96YB86LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B
M"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC
M;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE
M=&4@<W!A;2XB"FUS9W-T<B`B(@HB36%A:R!F:6QT97)R96=E;',@;VT@=7<@
M:6YK;VUE;F1E(&UA:6P@=&4@;W)G86YI<V5R96XL(&(N=BX@<V]R=&5R96X@
M;F%A<B`B"B)M87!P96XL(&]F(&AE="!V97)W:6ID97)E;B!V86X@<W!A;2XB
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*(RP@9G5Z
M>GD*;7-G:60@(D-R96%T92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R(")-86%K
M(&5E;B!N:65U=V4@3U540D]8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T.0IM<V=I9"`B0W)E871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N
M<V5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A8V-E<W,@=&\@)7,B"FUS
M9W-T<B`B2'5I9&EG92!T;V5G86YG('1O="`E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#4*;7-G:60@(D-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@
M9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(*;7-G<W1R("))
M;G-T96QL96X@=F%N(&%C8V]U;G1S('9O;W(@:&5T(&]P:&%L96X@=F%N(&UA
M:6P@=F%N(&%N9&5R92!A8V-O=6YT<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$*;7-G:60@(D-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"XB
M"FUS9W-T<B`B06%N<&%S<V5N(&AO92!U=R!M86EL('=O<F1T('9E<GIO;F1E
M;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+B(*;7-G<W1R(")!86YP87-S96X@=F%N('1A:V5N('1I:F1E;G,@86%N
M;65L9&EN9R!B:6H@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHQ-PIM<V=I9"`B1&%T7V4B"FUS9W-T<B`B7T1A='5M
M(@H*(SH@;65S<V%G92YP:'`Z,C8R('1H<F5A9"YP:'`Z,30X"FUS9VED(")$
M871E(@IM<V=S='(@(D1A='5M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<U-PIM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B069G96YO;65N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,PHC+"!F=7IZ>0IM<V=I
M9"`B1&5C;&EN960Z("(*;7-G<W1R(")!9F=E;F]M96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3,W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(E9E<G=I:F1E<F5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U
M;'1S96%R8VAS96QE8W0N:6YC.C$X"FUS9VED(")$969A=6QT(%-E87)C:"!&
M:65L9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(S
M"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(E-T
M86YD86%R9"!S;W)T965R8W)I=&5R:6$Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDS,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB
M"FUS9W-T<B`B4W1A;F1A87)D('-O<G1E97)V;VQG;W)D93HB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S8U"FUS9VED(")$96QE9V%T960B"FUS
M9W-T<B`B3W9E<F=E9')A9V5N(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(T-"!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHX('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:6YC.C(X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PIM<V=I9"`B1&5L971E(@IM<V=S='(@(E9E<G=I:F1E<F5N(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+
M97DB"FUS9W-T<B`B3W!E;F)A<F4@<VQE=71E;"`E<R!V97)W:6ID97)E;B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C@U"FUS9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S
M='(@(DAU:61I9V4@<VQE=71E;',@=F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHY"FUS9VED(")$96QE=&4@1F]L9&5R
M*',I(@IM<V=S='(@(E9E<G=I:F1E<B!M87`H<&5N*2(*"B,Z(&9O;&1E<G,N
M<&AP.C(X-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E
M<G,B"FUS9W-T<B`B5F5R=VEJ9&5R(&UA<"AP96XI(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@4W1A=&EO;F5R>2(*;7-G<W1R(")697)W:6ID97(@=FER='5E;&4@;6%P
M(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y"FUS9VED(")$96QE=&4@5FER='5A;"!&
M;VQD97(B"FUS9W-T<B`B5F5R=VEJ9&5R('9I<G1U96QE(&UA<"(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L971E
M(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G<W1R
M(")697)W:6ID97(@;W!G96AA86QD92!B97)I8VAT96X@=F%N(&1E('-E<G9E
M<B!O<"!A9G-T86YD/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(E9E
M<G=I:F1E<B!U:70@;6EJ;B!A9V5N9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8X"FUS9VED(")$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(E9E<G=I:F1E<B!O
M=61E(&=E:V]P<&5L9&4@8FEJ;&%G96X@86%N(&AE="!B96=I;B!V86X@9&4@
M;6%A;F0_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B
M1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@
M;6]N=&@_(@IM<V=S='(@(E9E<G=I:F1E<B!O=61E(%PB3U540D]87"(@;6%P
M<&5N(&%A;B!H970@8F5G:6X@=F%N(&1E(&UA86YD/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M
M(&UE<W-A9V5S(@IM<V=S='(@(E9E<G=I:F1E<F1E(&)E<FEC:'1E;B(*"B,Z
M(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I
M9"`B1&5L971E9"(*;7-G<W1R(")697)W:6ID97)D(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B1&5L971E9"!M97-S86=E<R(*
M;7-G<W1R(")697)W:6ID97)D92!B97)I8VAT96XB"@HC.B!C;VUP;W-E+G!H
M<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@871T86-H
M;65N="!<(B5S7"(N(@IM<V=S='(@(D)I:FQA9V4@7"(E<UPB(&ES('9E<G=I
M:F1E<F0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$
M96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S(@IM<V=S='(@(E9E<G=I:F1E
M<F5N(&5N('9E<G!L86%T<V5N('9A;B!B97)I8VAT96XB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3DR"FUS9VED(")$96YY(')E<75E<W0B"FUS
M9W-T<B`B5V5I9V5R('9E<GIO96LB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-30P"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B(*;7-G<W1R(")796EG97(@=F5R>F]E:R!V;V]R('9R:6HO
M8F5Z970@:6YF;W)M871I92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,S(*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B069N96UE;F0B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8V.0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B0F5S8VAR:6IV:6YG(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHR-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")$971A:6QS(@IM<V=S='(@
M(D1E=&%I;',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<W"FUS9VED
M(")$:6T@<VEG;F%T=7)E<S\B"FUS9W-T<B`B1&EM(&]N9&5R=&5K96YI;F=E
M;C\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM
M<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")7965R9V5V96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#<Y"FUS9VED(")$:7-P;&%Y(&-O;F9I<FUA=&EO
M;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B0F5V97-T:6=I
M;F<@=V5E<F=E=F5N(&YA('9E<G-T=7)E;B!V86X@965N(&)E<FEC:'0_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-@IM<V=I9"`B1&ES<&QA>2!I
M;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B5V5E<F=E=F5N(&EN(&)O9'D@
M=F%N(&)E<FEC:'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"FUS
M9VED(")$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_
M(@IM<V=S='(@(E=E97)G979E;B!V86X@<&]P+75P(&YO=&EF:6-A=&EE('9A
M;B!N:65U=V4@;6%I;#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4X
M"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%-P86U<(B!L
M:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R(")7965R9V5V96X@=F%N("=0
M<G5L;&5N8F%K(&QE9V5N)R!I;B!D92!M96YU8F%L:S\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S4P"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y('1H
M92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T
M<B`B5V5E<F=E=F5N('9A;B`G4')U;&QE;F)A:R!L96=E;B<@:6X@9&4@;65N
M=6)A;&L_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC
M.C$Q"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R(")6;V]R8F5R96ED:6YG
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C(V"FUS9VED(")$
M;R!.3U0@;6%T8V@B"FUS9W-T<B`B2V]M="!.2454(&]V97)E96XB"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B1&\@3F]T
M($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B0V]N=')O
M;&5E<B!M87`H<&5N*2!N:65T(&]P(&YI975W92!M86EL(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E;F5R871E(&$@
M;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(DUA86L@9V5E;B!L
M:6YK(&EN(%9A;CH@:V]L;VTB"@HC.B!L:6(O24U0+G!H<#HQ,#<U"FUS9VED
M(")$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/R(*;7-G<W1R(")7
M:6QT('4@9&5Z92!M87`@;W!E;F5N/R(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C,R"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I
M9VX@=7`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHQ,C8*;7-G:60@(D1O;F4B"FUS9W-T<B`B56ET9V5V;V5R9"(*
M"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B1&]W
M;FQO860@)7,@:6X@+GII<"!F;W)M86%T(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O:&5A9&5R<RYI;F,Z-3(*;7-G:60@(D1O=VYL;V%D($%L;"!!='1A8VAM
M96YT<R`H:6X@+GII<"!F:6QE*2(*;7-G<W1R(")$;W=N;&]A9"!A;&QE(&)I
M:FQA9V5N("AI;B`N>FEP(&)E<W1A;F0I(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,C`*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*
M;7-G<W1R(")$;W=N;&]A9"!M87`H<&5N*2(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RD@
M6RYZ:7`@9F]R;6%T72(*;7-G<W1R(")$;W=N;&]A9"!M87`H<&5N*2!;+GII
M<"!F;W)M86%T72(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*;7-G
M:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(D1O=VYL;V%D
M(&EN("YZ:7`@9F]R;6%A="(*"B,Z(&UE<W-A9V4N<&AP.C4P,2!M86EL8F]X
M+G!H<#HW,3D@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHQ,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(R('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;&5G96YD+FEN8SHY"FUS9VED(")$<F%F="(*;7-G<W1R(")+;&%D(@H*
M(SH@9F]L9&5R<RYP:'`Z,SDR"FUS9VED(")$<F%F="!F;VQD97(B"FUS9W-T
M<B`B2VQA9&UA<"(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N
M:6YC.C(S"FUS9VED(")$<F%F=',@9F]L9&5R.B(*;7-G<W1R(")+;&%D;6%P
M.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#@*;7-G:60@(D4M;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D4M;6%I;&%D<F5S(@H*(SH@;&EB+TUA:6QB
M;W@N<&AP.C,P.0HC+"!F=7IZ>0IM<V=I9"`B14Y$(@IM<V=S='(@(D5.(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2
M.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T
M<B`B1D]55#H@57<@8F5R:6-H="!K;VX@;FEE="!W;W)D96X@869G96QE=F5R
M9"XB"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S='(@(D)E=V5R:V5N(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET
M($)L86-K;&ES="(*;7-G<W1R("):=V%R=&4@;&EJ<W0@8F5W97)K96XB"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@
M1FEL=&5R<R(*;7-G<W1R(")-86EL9FEL=&5R<R!B97=E<FME;B(*"B,Z(&9O
M;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,38*
M;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B0F5W97)K('9I
M<G1U96QE(&UA<"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B!$
M969I;FET:6]N(&9O<B`E<R(*;7-G<W1R(")"97=E<FMT('9I<G1U96QE(&UA
M<"!D969I;FET:64@=F]O<B`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHR,PIM<V=I9"`B161I="!7:&ET96QI<W0B"FUS9W-T<B`B5VET
M=&4@;&EJ<W0@8F5W97)K96XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,3@*;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B
M57<@>G=A<G1E(&QI:G-T(&)E=V5R:V5N(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C$S"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S
M(@IM<V=S='(@(E5W(&9I;'1E<G)E9V5L<R!B97=E<FME;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-C$*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E
M;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S
M='(@(E5W('9O;W)K975R<VEN<W1E;&QI;F=E;B!V;V]R(&%N9&5R92!M86EL
M86-C;W5N=',@:6YS=&5L;&5N+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHR,PIM<V=I9"`B161I="!Y;W5R('=H:71E;&ES="(*;7-G<W1R
M(")5=R!W:71T92!L:6IS="!B97=E<FME;B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(D4M;6%I;&%D<F5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M
M("5S+B(*;7-G<W1R(")!;&QE(&)E<FEC:'1E;B!U:70@)7,@>FEJ;B!V97)W
M:6ID97)D+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R
M"FUS9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B36%P*'!E;BD@;&5E
M9VUA:V5N(@H*(SH@9F]L9&5R<RYP:'`Z,C@V"B,L(&9U>GIY"FUS9VED(")%
M;7!T>2!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(DUA<"AP96XI(&QE96=M
M86ME;B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"FUS
M9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`B4')U;&QE;F)A:R!L
M965G;6%K96XB"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@
M(D5M<'1Y(%]3<&%M(@IM<V=S='(@(E!R=6QL96Y?8F%K(&QE96=M86ME;B(*
M"B,Z(&QI8B])35`N<&AP.CDV-@IM<V=I9"`B16UP='D@7U1R87-H(@IM<V=S
M='(@(E!R=6QL96Y?8F%K(&QE96=M86ME;B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED
M(")%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(E!'4"!F=6YC
M=&EO;F%L:71E:70@:6YS8VAA:V5L96X_(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHQ('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C8*
M;7-G:60@(D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B
M4R]-24U%(&9U;F-T:6]N86QI=&5I="!I;G-C:&%K96QE;C\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS9VED(")%;F%B;&4@;65S<V%G92!P
M<F5V:65W<S\B"FUS9W-T<B`B0F5R:6-H='!R979I97=S(&%C=&EV97)E;C\B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-#(*;7-G:60@
M(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B0V]D97)?:6YG<V]P=&EE
M<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3<@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8U-PIM<V=I9"`B16YD(@IM<V=S='(@(D5I;F1E
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,X-`IM<V=I9"`B16YD(&9O<G=A<F1E
M9"!M97-S86=E(@IM<V=S='(@(D5I;F1E(&1O;W)G97-T=75R9"!B97)I8VAT
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,T,0IM<V=I9"`B16YD(&UE<W-A9V4B
M"FUS9W-T<B`B16EN9&4@8F5R:6-H="(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YD(&UE<W-A9V4@9G)O;2`E<R(*
M;7-G<W1R(")%:6YD92!B97)I8VAT('9A;B`E<R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS
M9VED(")%;G1E<B!087-S<&AR87-E(@IM<V=S='(@(E=A8VAT=V]O<F1R96=E
M;"!I;G9O97)E;B(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN
M8SHY"B,L(&9U>GIY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B1V5E9B!D92!N86%M('9A;B!U=R!N
M:65U=V4@<')U;&QE;F)A:R(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S
M96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE
M=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(D=E968@9&4@;F%A;2!V86X@=7<@
M;FEE=7=E(&ML861M87`B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS
M96QE8W0N:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")'965F(&1E(&YA86T@=F%N
M('5W(&YI975W92!/551"3U@B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS
M96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE
M=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B1V5E9B!D92!N86%M('9A;B!U=R!N
M:65U=V4@<')U;&QE;F)A:R(*"B,Z(&QI8B]396%R8V@N<&AP.C0V"B,L(&9U
M>GIY"FUS9VED(")%;G1I<F4@365S<V%G92(*;7-G<W1R(")"97)I8VAT(&]M
M;&5I9&5N(@H*(SH@;65S<V%G92YP:'`Z,3DT(&-O;7!O<V4N<&AP.C$Q,S0@
M=&AR96%D+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!<(B5S
M7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K
M(@IM<V=S='(@(DEN=F]E<B!<(B5S7"(@;65T('-U8V-E<R!A86X@:&5T(&%D
M<F5S8F]E:R!T;V5G979O96=D(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HS-S8@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,S@V"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T<B`B
M1F]U="(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S
M(#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HS,#D@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`B
M1F]U="!B:6H@=F5R>F5N9&5N('9A;B!A;G1W;V]R9#H@)7,N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,0IM<V=I9"`B179E;G0@<W5C8V5S
M<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(D=E8F5U<G1E;FES(&UE="!S=6-C
M97,@=F5R=VEJ9&5R9"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@R
M"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D5L:V4@,34@;6EN
M=71E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-SD*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B16QK92`S,"!S96-O;F1E;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#$*;7-G:60@(D5V97)Y(#4@;6EN
M=71E<R(*;7-G<W1R(")%;&ME(#4@;6EN=71E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.#,*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R
M(")%;&L@:&%L9B!U=7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@P
M"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B16QK92!M:6YU=70B"@HC
M.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")5:71K
M;&%P<&5N(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*
M;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`B06QL97,@=6ET:VQA<'!E;B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%
M>'!A;F0@06QL($9O;&1E<G,B"FUS9W-T<B`B06QL92!M87!P96X@=6ET:VQA
M<'!E;B(*"B,Z(&9O;&1E<G,N<&AP.C0U-PIM<V=I9"`B17AP86YD($9O;&1E
M<B(*;7-G<W1R(")-87`@=6ET:VQA<'!E;B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,T,"!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z-3,*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R(").86%M<W5I
M=&)R96ED:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-C,*;7-G
M:60@(D5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA
M=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\B"FUS9W-T<B`B(@HB3F%A;7-U
M:71B<F5I9&EN9R!I;B!H970@7").:65U=R!B97)I8VAT7"(@<V-H97)M(&%U
M=&]M871I<V-H+"!O<"!D92`B"B)A8VAT97)G<F]N9"P@=6ET=F]E<F5N/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.#`*;7-G:60@(D5X<&%N9"!T
M:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E
M<G,@=FEE=S\B"FUS9W-T<B`B4W1A;F1A87)D(&1E(&-O;7!L971E('1R964@
M=6ET:VQA<'!E;B!I;B!D92!M87!W965R9V%V93\B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(T-2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3`Q"FUS9VED
M(")%>'!A;F1I;F<B"FUS9W-T<B`B56ET:VQA<'!E;B`N+BXB"@HC.B!L:6(O
M24U0+G!H<#HY.#0@;&EB+TE-4"YP:'`Z.3@V"B,L(&9U>GIY"FUS9VED(")&
M7V5T8V@@36%I;"(*;7-G<W1R(")-86EL(&]P:&%L96XB"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-`IM<V=I9"`B1F5T8V@@36%I;"(*;7-G<W1R(")-86EL(&]P
M:&%L96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8Y"FUS9VED(")&
M971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")-86EL
M(&]P:&%L96X@:6X@965N(&%P87)T('-C:&5R;3\B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-#8*;7-G:60@(D9E=&-H(&UE<W-A9V5S
M('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`B0F5R:6-H=&5N(&]P:&%L96X@
M8FEJ(&%A;FUE;&1I;F<_(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D("5D(&UE<W-A9V5S
M(&9R;VT@)7,B"FUS9W-T<B`B)60@8F5R:6-H="AE;BD@=F%N("5S(&]P9V5H
M86%L9"XB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS
M9W-T<B`B)60@8F5R:6-H="AE;BD@=F%N("5S(&]P9V5H86%L9"XB"@HC.B!L
M:6(O1F5T8VAM86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI
M8B]&971C:&UA:6PN<&AP.C(X.0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T
M<B`B06YD97)E(%!/4#,O24U!4"!A8V-O=6YT<SH@(@H*(SH@;&EB+T9E=&-H
M;6%I;"YP:'`Z,CDQ"FUS9VED(")&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E
M<RXB"FUS9W-T<B`B1F5T8VAM86EL.B!G965N(&YI975W92!B97)I8VAT96XN
M(@H*(SH@;&EB+TE-4"YP:'`Z.3DP"FUS9VED(")&:5]L=&5R<R(*;7-G<W1R
M(")&:5]L=&5R<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4P,B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHX,@IM<V=I
M9"`B1FEL92(*;7-G<W1R(")"97-T86YD(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C,Q"FUS9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R
M(")&:6QT97)O<'1I97,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z.0IM<V=I9"`B1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(D9I;'1E<FEN
M<W1E;&QI;F=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#`*;7-G
M:60@(D9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS
M9W-T<B`B0F5R:6-H="!F:6QT97)E;B!O<"!A86YS=&]O=&=E=F5N9&4@:6YH
M;W5D/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,3$*
M;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES
M=&5M+B(*;7-G<W1R(")&:6QT97(@;VYD97)S=&5U;FEN9R!I<R!U:71G97-C
M:&%K96QD(&]P(&1I="!S>7-T965M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C<*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=&5R<R(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,PIM<V=I9"`B1FEL
M=&5R<R!.3U0@06-T:79E(@IM<V=S='(@(D9I;'1E<G,@3DE%5"!A8W1I968B
M"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E(@IM<V=S='(@(D9I;'1E<G,Z
M("5S(&)E:&5E<G!A9VEN82(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,3@V"FUS9VED(")&:6YD(@IM<V=S='(@(E9I;F1E;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*;7-G:60@(D9I<G-T($UA:6QB
M;W@@4&%G92(*;7-G<W1R(")%97)S=&4@;6%I;&)O>'!A9VEN82(*"B,Z(&UA
M:6QB;W@N<&AP.C,T-0IM<V=I9"`B1FER<W0@4&%G92(*;7-G<W1R(")%97)S
M=&4@<&%G:6YA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS
M9VED(")&;U]R=V%R9"(*;7-G<W1R(")$;V]R7W-T=7)E;B(*"B,Z(&9O;&1E
M<G,N<&AP.C(V-B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN
M:'1M;#HU"FUS9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O;&1E
M<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S
M96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L
M96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R(")-
M87!N879I9V%T;W(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PIM<V=I
M9"`B1F]L9&5R(%-U;6UA<GDB"FUS9W-T<B`B36%P<&5N<V%M96YV871T:6YG
M(@H*(SH@86-L+G!H<#HR-`IM<V=I9"`B1F]L9&5R('-H87)I;F<@:7,@;F]T
M(&5N86)L960N(@IM<V=S='(@(D1E;&5N('9A;B!M87!P96X@:7,@;FEE="!I
M;F=E<V-H86ME;&0N(@H*(SH@9F]L9&5R<RYP:'`Z-C(*;7-G:60@(D9O;&1E
M<B!U<V4@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(D=E8G)U:6L@=F%N(&UA
M<'!E;B!I<R!N:65T(&EN9V5S8VAA:V5L9"XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.38Y"FUS9VED(")&;W)M870@;V8@;65S<V%G92!D871E<R!I
M;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A>2(*
M;7-G<W1R("(B"B)&;W)M86%T('9A;B!B97)I8VAT9&%T82!I;B!D92!M86EL
M8F]X=V5E<F=A=F4@=F]O<B!B97)I8VAT96X@;65T(&1E(&1A='5M("(*(G9A
M;B!V86YD86%G(@H*(SH@8V]M<&]S92YP:'`Z-S@P('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")$;V]R
M<W1U<F5N(@H*(SH@8V]M<&]S92YP:'`Z-S8U"FUS9VED(")&;W)W87)D.B(*
M;7-G<W1R(")$;V]R<W1U<F5N.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-CD*
M;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(D1O;W)G97-T=75R
M9"!B97)I8VAT(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")&;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@
M(D1O;W)G97-T=75R9"!B97)I8VAT('9A;B`E<R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT.#,*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO
M;B(*;7-G<W1R(")6<FEJ+T)E>F5T(&EN9F]R;6%T:64B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#DT"FUS9VED(")&<F5E+T)U<WD@4F5P;'DB
M"FUS9W-T<B`B5G)I:B]"97IE="!A;G1W;V]R9"(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT.#@*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM
M<V=S='(@(E9R:6HO0F5Z970@=F5R>F]E:R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT,#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O
M;G-E(@IM<V=S='(@(E9R:6HO0F5Z970@=F5R>F]E:R!A;G1W;V]R9"(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G
M:60@(D9R;U]M(@IM<V=S='(@(E]686XB"@HC.B!M97-S86=E+G!H<#HR-C,@
M=&AR96%D+G!H<#HQ-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M.3D*(SH@;&EB+U-E87)C:"YP:'`Z,C(*;7-G:60@(D9R;VTB"FUS9W-T<B`B
M5F%N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ.`IM<V=I9"`B1G)O
M;2!!9&1R97-S(@IM<V=S='(@(D%F>F5N9&5R(@H*(SH@8V]M<&]S92YP:'`Z
M-S<W(&-O;7!O<V4N<&AP.C<X,0IM<V=I9"`B1G=D.B(*;7-G<W1R(")&=V0Z
M(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-`IM<V=I9"`B1G=D.B`B"FUS9W-T<B`B
M1G=D.B`B"@HC.B!C;VUP;W-E+G!H<#HQ,CDV"B,L('!H<"UF;W)M870*;7-G
M:60@(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(D9W9#H@
M)74@9&]O<F=E<W1U=7)D92!B97)I8VAT96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*
M;7-G:60@(D=E;F5R86P@3W!T:6]N<R(*;7-G<W1R(")!;&=E;65N92!O<'1I
M97,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S<*;7-G
M:60@(D=E="!O;FQY(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2DB"FUS9W-T
M<B`B06QL965N(&YI975W92!B97)I8VAT96X@;W!H86QE;C\@*&%L;&5E;B!)
M34%0*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Q"FUS
M9VED(")';R(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$S-@IM<V=I9"`B
M1V\@=&\@365S<V%G92(*;7-G<W1R(")'82!N86%R(&)E<FEC:'0B"@HC.B!L
M:6(O24U0+G!H<#HT.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=O
M('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B5F]E
M9R!T;V4@86%N(&%D<F5S8F]E:R`H)7,I(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(E1O96=A
M;F<@=&]E:V5N;F5N(@H*(SH@;65S<V%G92YP:'`Z-30V(&QI8B]&:6QT97(N
M<&AP.C$P-2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#(@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M,R!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8R(&QI8B]-24U%+U9I97=E<B]N;W1I
M9FEC871I;VXN<&AP.C8X"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H
M<#HW.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C$W,PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C`@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(W"FUS9VED(")(15)%(@IM
M<V=S='(@(DA)15(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-PHC.B!L:6(O34E-
M12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B
M2%1-3"(*"B,Z(&-O;7!O<V4N<&AP.C(U-@IM<V=I9"`B2%1-3"!697)S:6]N
M(&]F($UE<W-A9V4B"FUS9W-T<B`B2%1-3"!V97)S:64@=F%N(&)E<FEC:'0B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU.`IM<V=I9"`B
M2&5A9&5R<R(*;7-G<W1R(")(96%D97)S(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M97-S86=E
M('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B2&EE<B!I<R!H970@8F5R
M:6-H="!D870@=2!A86X@:&5T(&UA:V5N('=A<SHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C8X"FUS9VED(")(:61D96XB"FUS9W-T<B`B5F5R8F]R
M9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PIM<V=I9"`B2&ED
M9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(E9E<F)O<F=E;B!I;B!T:')E
M861W965R9V%V92(*"B,Z(&UA:6QB;W@N<&AP.C,V-PIM<V=I9"`B2&ED92!$
M96QE=&5D(@IM<V=S='(@(E9E<F)E<F<@=F5R=VEJ9&5R9"(*"B,Z(&9O;&1E
M<G,N<&AP.C(Y.`IM<V=I9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`B
M5F5R8F5R9R!U:71G97-C:')E=F5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S='(@(DAO;V<B"@HC
M.B!M97-S86=E+G!H<#HR.3<@;6%I;&)O>"YP:'`Z-S(T('1E;7!L871E<R]M
M86EL8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI9V@@4')I;W)I='DB"FUS
M9W-T<B`B2&]G92!P<FEO<FET96ET(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,CDS"FUS9VED(")(:6=H97-T(@IM<V=S='(@(DAO;V=S
M=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X"FUS9VED(")(;W<@
M9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T<B`B
M2&]E('=I;'0@=2!B:6IL86=E;B!W965R9V5V96X_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P-`IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q=6]T
M960@;&EN97,@:6X@82!R97!L>2(*;7-G<W1R(")!='1R:6)U=70@=F]O<B!C
M:71A=&5N(&EN(&5E;B!A;G1W;V]R9"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,3,T"FUS9VED("))34%0(@IM<V=S='(@(DE-05`B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H075T;R!$971E
M8W0@4')O=&]C;VQS*2(*;7-G<W1R("))34%0("A!=71O($1E=&5C="!0<F]T
M;V-O;',I(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!397)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N
M+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$V-B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-33"(*;7-G<W1R("))34%0('9I82!3
M4TPB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I9"`B24U!
M4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@
M(DE-05`@=FEA(%-33"`H>F5L9B!O;F1E<G1E:V5N9"DB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$V-PIM<V=I9"`B24U!4"!O=F5R(%-33"`H
M<V5L9BUS:6=N960I(@IM<V=S='(@(DE-05`@=FEA(%-33"`H>F5L9B!O;F1E
M<G1E:V5N9"DB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`HC+"!F=7IZ
M>0IM<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*
M;7-G<W1R(")-86EL<V5R=F5R='EP92!W86%R;65E('9E<F)I;F1I;F<@9V5M
M86%K="!W;W)D=#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V
M-2!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@
M5$Q3(@IM<V=S='(@(DE-05`L(&=E96X@5$Q3(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HT.0IM<V=I9"`B24U!4"]03U`S($UA:6P@4V5R=F5R<R(*
M;7-G<W1R("))34%0+U!/4#,@;6%I;'-E<G9E<G,B"@HC.B!L:6(O24U0+G!H
M<#HX-C8*;7-G:60@(DE.0D]8(@IM<V=S='(@(DE.0D]8(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HT,3$*;7-G:60@(DEF('5S:6YG(%-33"!O<B!43%,L
M('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L(&5X=&5N<VEO;B!L;V%D
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?
M8V]N9FER;2YH=&UL.C$R"B,L(&9U>GIY"FUS9VED("))9B!Y;W4@8V]N=&EN
M=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S
M="$B"FUS9W-T<B`B06QL92!B97)I8VAT96X@:6X@9&4@;6%P*'!E;BD@>G5L
M;&5N('9E<FQO<F5N(&=A86XA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T<B`B3F5G97)E;B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B
M26=N;W)E($%L;"(*;7-G<W1R(").96=E97(@86QL97,B"@HC.B!T96UP;&%T
M97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,`IM
M<V=I9"`B26UP;W)T(@IM<V=S='(@(DEM<&]R=&5R96XB"@HC.B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHV-0IM<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R(")3;&5U
M=&5L(&EM<&]R=&5R96XB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y
M"FUS9VED("));7!O<G0@2V5Y<&%I<B(*;7-G<W1R(")3;&5U=&5L<&%A<B!I
M;7!O<G1E<F5N(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,C<*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!-97-S86=E<R(*;7-G<W1R(")"
M96QA;F=R:6IK92!B97)I8VAT96XB"@HC.B!P9W`N<&AP.C0R"FUS9VED("))
M;7!O<G0@4$=0($ME>2(*;7-G<W1R(")01U`@<VQE=71E;"!I;7!O<G1E<F5N
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0HC+"!F=7IZ>0IM
M<V=I9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@(E!E
M<G-O;VYL:6IK(&-E<G1I9FEC86%T(&EM<&]R=&5R96XB"@HC.B!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N
M86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@(E!E<G-O;VYL:6IK92!P<FEV
M92!01U`@<VQE=71E;"!I;7!O<G1E<F5N(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC
M(%!'4"!+97DB"FUS9W-T<B`B4&5R<V]O;FQI:FME(&]P96YB87)E(%!'4"!S
M;&5U=&5L(&EM<&]R=&5R96XB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T
M:69I8V%T97,B"FUS9W-T<B`B4&5R<V]O;FQI:FL@4R]-24U%(&-E<G1I9FEC
M86%T(&EM<&]R=&5R96XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C0P('1E;7!L871E<R]P9W`O<&=P+FEN8SHT,@IM<V=I9"`B26UP;W)T(%!U
M8FQI8R!+97DB"FUS9W-T<B`B3W!E;F)A<F4@<VQE=71E;"!I;7!O<G1E<F5N
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("))
M;7!O<G0@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B3W!E;F)A<F4@4$=0('-L
M975T96P@:6UP;W)T97)E;B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHX"FUS9VED("));7!O<G0@4'5B;&EC(%,O34E-12!+97DB"FUS
M9W-T<B`B3W!E;F)A<F4@4R]-24U%('-L975T96P@:6UP;W)T97)E;B(*"B,Z
M('-M:6UE+G!H<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+97DB"FUS9W-T
M<B`B4R]-24U%('-L975T96P@:6UP;W)T97)E;B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*
M;7-G<W1R(")-8F]X(&)E<W1A;F0@:6UP;W)T97)E;B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`B
M36)O>"!B97-T86YD("5S(&EN(&UA<"`E<R!I;7!O<G1E<F5N+B(*"B,Z(&UE
M<W-A9V4N<&AP.C4P,B!M86EL8F]X+G!H<#HW,S0@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS
M,PHC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM
M<&]R=&%N="(*;7-G<W1R(")"96QA;F=R:6IK(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT(&UE<W-A9V5S(@IM
M<V=S='(@(D)E;&%N9W)I:FME(&)E<FEC:'1E;B(*"B,Z(&9O;&1E<G,N<&AP
M.C$V-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"`E9"!M97-S86=E
M<R!F<F]M("5S+B(*;7-G<W1R("(E9"!B97)I8VAT96X@=6ET("5S(&=E:6UP
M;W)T965R9"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS
M9VED("));B!0<F]C97-S(@IM<V=S='(@(DEN(&)E:&%N9&5L:6YG(@H*(SH@
M9F]L9&5R<RYP:'`Z,S@T(&QI8B]&;VQD97(N<&AP.C@V(&QI8B]&;VQD97(N
M<&AP.C(Q-"!L:6(O24U0+G!H<#HS,3,*(SH@;&EB+TE-05`O5')E92YP:'`Z
M,3$T(&QI8B])34%0+U1R964N<&AP.C(Q.0IM<V=I9"`B26YB;W@B"FUS9W-T
M<B`B26YB;W@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR"FUS9VED
M("));F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@
M<F5P;'D_(@IM<V=S='(@(DMO<G1E('-A;65N=F%T=&EN9R!V86X@9&4@:&5A
M9&5R(&)I:G9O96=E;B!I;B!E96X@86YT=V]O<F0_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S
M86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(D]R:6=I;F5E;"!B97)I8VAT(&)I
M:G9O96=E;B!I;B!E96X@86YT=V]O<F0_(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R+W-T871U<RYP
M:'`Z,3,P"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L
M:6,@2V5Y(@IM<V=S='(@(DEN9F]R;6%T:64@;W9E<B!O<&5N8F%R92!S;&5U
M=&5L("5S(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED("))
M;F9O<FUA=&EO;B!O;B!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("))
M;F9O<FUA=&EE(&]V97(@<&5R<V]O;FQI:FME('!R:79E('-L975T96PB"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW,@IM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B
M;&EC($ME>2(*;7-G<W1R("));F9O<FUA=&EE(&]V97(@<&5R<V]O;FQI:FME
M(&]P96YB87)E('-L975T96PB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYI;F,Z,34@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-3`W"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDX"FUS
M9VED("));FQI;F4B"FUS9W-T<B`B26YL:6YE(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+VEM<&]R=%]K97DN:6YC.CD*;7-G:60@(DEN<V5R="!#97)T:69I8V%T
M92!(97)E(@IM<V=S='(@(D-E<G1I9FEC86%T(&AI97(@:6YV;V5G96XB"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED("));G-E
M<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T<B`B4&5R
M<V]O;FQI:FME('!R:79E(%!'4"!S;&5U=&5L('1O979O96=E;B(*"B,Z('1E
M;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,3`*;7-G:60@(DEN<V5R="!0
M97)S;VYA;"!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(E!E<G-O;VYL
M:6IK92!O<&5N8F%R92!01U`@<VQE=71E;"!T;V5V;V5G96XB"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4*;7-G:60@(DEN<V5R="!0=6)L
M:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(D]P96YB87)E(%!'4"!S;&5U=&5L
M('1O979O96=E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3(*
M;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O
M;F5N="XB"FUS9W-T<B`B3VYG96QD:6=E(&)E=V5R:VEN9R!G97-E;&5C=&5E
M<F0@=F]O<B!D:70@;VYD97)D965L+B(*"B,Z(&UA:6QB;W@N<&AP.C4X-"!M
M86EL8F]X+G!H<#HV,C8*;7-G:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R
M(")/;F=E;&1I9R!A9')E<R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,S`W"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM<V=S='(@(D]N
M9V5L9&EG92!M86EL8F]X(&]P(&%F<W1A;F0B"@HC.B!C;VUP;W-E+G!H<#HQ
M-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!C:&%R86-T97(@:6X@
M92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R(")/;F=E;&1I9R!K87)A:W1E
M<B!I;B!E+6UA:6QA9')E<SH@)7,N(@H*(SH@<VUI;64N<&AP.C@R('!G<"YP
M:'`Z,38*;7-G:60@(DEN=F%L:60@:V5Y(@IM<V=S='(@(D]N9V5L9&EG92!S
M;&5U=&5L(@H*(SH@<&=P+G!H<#HQ.38*;7-G:60@(DEN=F%L:60@<&5R<V]N
M86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R(")/;F=E;&1I9V4@<&5R<V]O
M;FQI:FME('!R:79E(%!'4"!S;&5U=&5L+B(*"B,Z('!G<"YP:'`Z,3<Q"FUS
M9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y+B(*;7-G<W1R
M(")/;F=E;&1I9V4@<&5R<V]O;FQI:FME(&]P96YB87)E(%!'4"!S;&5U=&5L
M+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3(*;7-G:60@
M(DEN=F5R="(*;7-G<W1R("));G9E<G1E<F5N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3<W"FUS9VED(")+0B(*;7-G<W1R(")+0B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B4VQE=71E;&QE;F=T92(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ,S<*;7-G:60@(B(*(DME>2!G96YE<F%T:6]N(&UA>2!T86ME
M(&$@;&]N9R!T:6UE('1O(&-O;7!L971E+B`@0V]N=&EN=64@=VET:"!K97D@
M(@HB9V5N97)A=&EO;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHS-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,S<*;7-G:60@
M(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@
M;F]T(&5N86)L960@;VX@=&AI<R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S<@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C,Y"FUS9VED("(B"B)+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N
M(%EO=2!H879E(&YO(&%D9')E<W,@8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R
M("(*(F-O;G1A8W1S+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C,Q.`IM<V=I
M9"`B2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R(")3;&5U=&5L(&UE="!S=6-C97,@;F%A<B!D92!O<&5N
M8F%R92!S;&5U=&5L<V5E<G9E<B!V97)S='5U<F0N(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,38*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(E1A86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`V"FUS9VED("),
M87-T($UA:6QB;W@@4&%G92(*;7-G<W1R("),86%T<W1E(&UA:6QB;WAP86=I
M;F$B"@HC.B!M86EL8F]X+G!H<#HS-3@*;7-G:60@(DQA<W0@4&%G92(*;7-G
M<W1R("),86%T<W1E('!A9VEN82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,X.0IM<V=I9"`B3&E?;FL@071T86-H;65N=',B"FUS9W-T
M<B`B2V]P<&5?;"!B:6IL86=E;B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C,T(&QI
M8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED("),:6YK960@871T86-H;65N=',@
M87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B1V5K;W!P96QD92!B:6IL86=E;B!Z
M:6IN(&YI970@=&]E9V5S=&%A;BXB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3`X
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:6YK<R!W:6QL(&5X<&ER92!O;B`E
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X,@IM
M<V=I9"`B(@HB3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C
M;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@(@HB;VYL
M>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY
M*2(*;7-G<W1R("(B"B)!;&QE(&%D<F5S<V5N('=E97)G979E;B!B:6H@:&5T
M(&QA9&5N('9A;B!H970@861R97-S8VAE<FT_("A786YN965R(&1I="!I<R`B
M"B)U:71G97-C:&%K96QD+"!Z:64@=2!A;&QE96X@:&5T(&%D<F5S('=A87(@
M=2!S<&5C:6%A;"!N86%R('IO96MT*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.#4*;7-G:60@(DQI<W1I;F<@:6X@=&AE($AE861E<B(*;7-G<W1R
M(")7965R9V5V96X@:6X@9&4@:&5A9&5R(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C,P"FUS9VED("),;V-A;"!-86EL8F]X.B(*;7-G
M<W1R("),;VMA;&4@;6%I;&)O>#HB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C<T"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),;V-A=&EE(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C4*;7-G:60@(DQO9R!I
M;B(*;7-G<W1R(")!86YM96QD96XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G
M<W1R(")!86YM96QD96X@8FEJ("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,S<*;7-G:60@(DQO9VEN(@IM<V=S='(@(D%A;FUE;&1E;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B3&]G:6X@5&%S
M:W,B"FUS9W-T<B`B06%N;65L9'1A:V5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,CDV"FUS9VED("),;W<B"FUS9W-T<B`B3&%A9R(*
M"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X+G!H<#HW,C<@=&5M<&QA=&5S
M+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM
M<V=S='(@(DQA9V4@<')I;W)I=&5I="(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(Y-PIM<V=I9"`B3&]W97-T(@IM<V=S='(@(DQA86=S
M=&4B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0T"FUS
M9VED(")-86-I;G1O<V@@1FEL92(*;7-G<W1R(")-86-I;G1O<VAB97-T86YD
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"FUS9VED
M(")-86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-@IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R(")-86EL<')E
M=FEE=W,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N
M:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z
M(@IM<V=S='(@(DUA:6QS97)V97)T>7!E('=A87)M964@=F5R8FEN9&EN9R!G
M96UA86MT('=O<F1T.B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I
M;&)O>"(*;7-G<W1R(")-86EL8F]X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,0IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T
M:6]N<R(*;7-G<W1R(")-86EL8F]X+2!M87!W965R9V%V96]P=&EE<R(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X"FUS9VED(")-87)K
M($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G<W1R(")-87)K
M965R(&%L;&4@8F5R:6-H=&5N(&EN(&UA<"!A;',@1V5Z:65N(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL
M($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T<B`B36%R:V5E
M<B!A;&QE(&)E<FEC:'1E;B!I;B!M87`@86QS($]N9V5Z:65N(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHU('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM<V=S
M='(@(DUA<FME97(@86QS.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I
M=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`B36%R:V5E<B!V97)S8VAI
M;&QE;F1E(&-I=&%A=&YI=F5A=7,@;65T('9E<G-C:&EL;&5N9&4@:VQE=7)E
M;C\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*;7-G
M:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS9W-T
M<B`B36%R:V5E<B!B97)I8VAT96X@86QS(&=E>FEE;C\@*&%L;&5E;B!)34%0
M*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3@*;7-G:60@(DUA<FL@
M<VEM<&QE(&UA<FMU<#\B"FUS9W-T<B`B165N=F]U9&EG92!O<&UA86L@;6%R
M:V5R96X_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0V"FUS
M9VED(")-871C:"!!;&P@475E<FEE<R(*;7-G<W1R(")/=F5R965N:V]M96YD
M(&UE="!A;&QE('%U97)I97,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R(")/=F5R
M965N:V]M96YD(&UE="!E;&ME('%U97)Y(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")-87AI;75M($%T=&%C:&UE;G0@
M4VEZ92(*;7-G<W1R(")-87AI;75M(&)I:FQA9V5G<F]O='1E(@H*(SH@;&EB
M+V%P:2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F
M($9O;&1E<G,B"FUS9W-T<B`B36%X:6UU;2!A86YT86P@8FEJ;&%G96X@8F5R
M96EK="XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.30*
M;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N
M(@IM<V=S='(@(DUA>&EM=6T@86%N=&%L(&)I:FQA9V5N(&)E<F5I:W0N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@Y"FUS9VED(")-
M87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*;7-G<W1R
M(")-87AI;75M('1O=&%L92!B:6IL86=E9W)O;W1T92!B97)E:6MT+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C8*;7-G:60@(DUE971I;F<@
M0V%N8V5L;&%T:6]N(@IM<V=S='(@(E9E<F=A9&5R:6YG<V%F>F5G9VEN9R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S4*;7-G:60@(DUE971I
M;F<@26YF;W)M871I;VXB"FUS9W-T<B`B5F5R9V%D97)I;F=S:6YF;W)M871I
M92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE
M971I;F<@4')O<&]S86PB"FUS9W-T<B`B5F5R9V%D97)I;F=S=F]O<G-T96PB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W"FUS9VED(")-965T
M:6YG(%)E<&QY(@IM<V=S='(@(E9E<F=A9&5R:6YG<V%N='=O;W)D(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y.`IM<V=I9"`B365E=&EN9R!5
M<&1A=&4B"FUS9W-T<B`B5F5R9V%D97)I;F=S=7!D871E(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8P,PIM<V=I9"`B365E=&EN9R!5<&1A=&4@
M4F5Q=65S="(*;7-G<W1R(")697)G861E<FEN9W-U<&1A=&5V97)Z;V5K(@H*
M(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,PIM<V=I9"`B365N=2!&
M;VQD97(@3&ES="(*;7-G<W1R(")-96YU(&UA<'!E;FQI:G-T(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")"97)I
M8VAT(@H*(SH@8V]M<&]S92YP:'`Z-38P(&-O;7!O<V4N<&AP.C4X-R!C;VUP
M;W-E+G!H<#HV-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P"FUS9VED(")-
M97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@(D)E<FEC:'1S86UE;G-T96QL
M:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S
M<V%G92!$871E(@IM<V=S='(@(D)E<FEC:'1D871U;2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P,PIM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(D)E
M<FEC:'1O<'1I97,B"@HC.B!S96%R8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G
M92!396%R8V@B"FUS9W-T<B`B0F5R:6-H="!Z;V5K96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T
M<B`B0F5R:6-H=&=R;V]T=&4B"@HC.B!M97-S86=E+G!H<#HS.#0*;7-G:60@
M(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(D)E<FEC:'1S;W5R8V4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(DUE<W-A9V4@5FEE=VEN
M9R(*;7-G<W1R(")"97)I8VAT(&)E:VEJ:V5N(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHV"FUS9VED(")-97-S86=E(&9L86=S(@IM<V=S='(@
M(D)E<FEC:'1M87)K97)I;F=E;B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z.#,*;7-G:60@(DUE<W-A9V4@9F]L9&5R<R(*;7-G<W1R(")"97)I
M8VAT;6%P<&5N(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B0F5R:6-H="!V
M86X@)7,B"@HC.B!M86EL8F]X+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@:&%S(&%T=&%C:&UE;G1S(@IM<V=S='(@(D)E<FEC:'0@:V]M="!O
M=F5R965N(&UE="(*"B,Z(&UA:6QB;W@N<&AP.C8U.`HC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T<B`B0F5R:6-H='9E;&1E
M;B(*"B,Z(&UA:6QB;W@N<&AP.C8U,PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G
M92!I<R!S:6=N960B"FUS9W-T<B`B0F5R:6-H='9E;&1E;B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHS,PIM<V=I9"`B365S<V%G92!M871C
M:&5S(@IM<V=S='(@(D)E<FEC:'0@:V]M="!O=F5R965N(&UE="(*"B,Z(&-O
M;7!O<V4N<&AP.C@R-"!C;VUP;W-E+G!H<#HX,S@*;7-G:60@(DUE<W-A9V4@
M<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D)E<FEC:'0@;65T
M('-U8V-E<R!O;6=E;&5I9"XB"@HC.B!C;VUP;W-E+G!H<#HQ,#@T"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U
M="!N;W0@<V%V960@=&\@)7,B"FUS9W-T<B`B0F5R:6-H="!M970@<W5C8V5S
M('9E<G-T=75R9"P@;6%A<B!N:65T(&]P9V5S;&%G96X@:6X@)7,B"@HC.B!C
M;VUP;W-E+G!H<#HQ,30S(&-O;7!O<V4N<&AP.C$Q-3@*;7-G:60@(DUE<W-A
M9V4@<V5N="!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D)E<FEC:'0@;65T('-U
M8V-E<R!V97)S='5U<F0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT
M,0IM<V=I9"`B365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE
M=RXB"FUS9W-T<B`B0F5R:6-H=&5N('!E<B!P86=I;F$@:6X@9&4@;6%I;&)O
M>'=E97)G879E+B(*"B,Z(&UA:6QB;W@N<&AP.C,R,@IM<V=I9"`B365S<V%G
M97,@=&\B"FUS9W-T<B`B0F5R:6-H=&5N(&YA87(B"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,CD*;7-G:60@(DUO9&EF>2(*;7-G<W1R(")7:6IZ:6=E
M;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@861D<F5S<R!F
M;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R(")-965R(&1A;B#IZ6X@
M861R97,@9V5V;VYD96X@=F]O<B!V96QD("<E<R<N(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E(@IM<V=S='(@(E9E<G!L
M86%T<V5N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S$V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B3F%A<B!B96YE9&5N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.`IM<V=I9"`B36]V92!S<&%M
M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E
M<R!T;R!)3D)/6"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z-3`*;7-G:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@(E9E<G!L
M86%T<R!N86%R(&UA<"(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,Q-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R(").86%R(&)O=F5N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G
M:60@(DUU;'1I<&%R="]A;'1E<FYA=&EV92(*;7-G<W1R(")-=6QT:7!A<G0O
M86QT97)N871I=F4B"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z,34R
M"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!-97-S86=E(%9I97<B"FUS9W-T
M<B`B0F5R:6-H="!B96MI:FME;B(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A
M=6QT<V5A<F-H<V5L96-T+FEN8SHU"B,L(&9U>GIY"FUS9VED(").3TY%(@IM
M<V=S='(@(D]034522TE.1R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT."!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`B3U!-
M15)+24Y'(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M,S@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B3F%M92(*
M;7-G<W1R(").86%M(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD
M+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B3F%A;2!E;B]O
M9B!E;6%I;&%D<F5S(&MA;B!N:65T(&QE96<@>FEJ;B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW-S@*;7-G:60@(DYE961S($%C=&EO;B(*;7-G
M<W1R(")(86YD96QI;F<@;F]D:6<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3<P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<W.`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3F]O:70B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38P"FUS9VED(").979E<B!S
M879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(DYO;VET(&)I:FQA9V5N(&]P<VQA
M86XB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B
M"FUS9W-T<B`B3FEE=7<B"@HC.B!L:6(O24U0+G!H<#HU-C,*;7-G:60@(DYE
M=R!&;VQD97(B"FUS9W-T<B`B3FEE=7=E(&UA<"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.`IM<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`B3FEE=7=E
M(&UA:6PB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K
M+W1R965?9F]L9&5R<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(DYE=R!-97-S
M86=E(@IM<V=S='(@(E9O;&=E;F0@8F5R:6-H="(*"B,Z(&UA:6QB;W@N<&AP
M.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(DYI975W
M92!B97)I8VAT96XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Y
M"FUS9VED(").97<@;65S<V%G97,B"FUS9W-T<B`B3FEE=7=E(&)E<FEC:'1E
M;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B5F]L9V5N9&4B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S"FUS9VED(").97AT($UE<W-A
M9V4B"FUS9W-T<B`B5F]L9V5N9"!B97)I8VAT(@H*(SH@;6%I;&)O>"YP:'`Z
M,S4V"FUS9VED(").97AT(%!A9V4B"FUS9W-T<B`B5F]L9V5N9&4@<&%G:6YA
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30R(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-S<*;7-G:60@(DYO(@IM<V=S='(@(DYE92(*
M"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO($-E<G1I9FEC871E(&9O=6YD
M(@IM<V=S='(@(D=E96X@8V5R=&EF:6-A870@9V5V;VYD96XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N
M8W)Y<'1I;VXB"FUS9W-T<B`B1V5E;B!C;V1E<FEN9R(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I;B!+97ER:6YG(@IM
M<V=S='(@(D=E96X@<VQE=71E;',@:6X@<VQE=71E;')I;F<B"@HC.B!M86EL
M8F]X+G!H<#HS-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B
M"FUS9W-T<B`B1V5E;B!B97)I8VAT96XB"@HC.B!P9W`N<&AP.C$S-PIM<V=I
M9"`B3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(D=E96X@
M;W!E;F)A<F4@<VQE=71E;',@9V5I;7!O<G1E97)D+B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I
M9FEC871E(%!R97-E;G0B"FUS9W-T<B`B1V5E;B!P97)S;V]N;&EJ:R!C97)T
M:69I8V%A="!A86YW97II9R(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,CD*(RP@
M9G5Z>GD*;7-G:60@(DYO(%!R979I97<@5&5X="(*;7-G<W1R(")"96]O<F1E
M;&5N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ-0IM<V=I9"`B
M3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS9W-T<B`B1V5E;B!O<&5N8F%R92!S
M;&5U=&5L(&=E=F]N9&5N(@H*(SH@<VUI;64N<&AP.C$U,0IM<V=I9"`B3F\@
M4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(D=E96X@;W!E
M;F)A<F4@4R]-24U%('-L975T96P@9V5I;7!O<G1E97)D+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]T;F5F+G!H<#HY,`IM<V=I9"`B3F\@871T86-H;65N=',@
M9F]U;F0N(@IM<V=S='(@(D=E96X@8FEJ;&%G96X@9V5V;VYD96XN(@H*(SH@
M;&EB+T-R>7!T+U--24U%+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(DYO(&5M
M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K97DN(@IM
M<V=S='(@(DEN9F]R;6%T:64@;W9E<B!O<&5N8F%R92!S;&5U=&5L("5S(@H*
M(SH@86-L+G!H<#HW,B!A8VPN<&AP.CDX"FUS9VED(").;R!F;VQD97(@<V5L
M96-T960N(@IM<V=S='(@(D=E96X@;6%P(&=E<V5L96-T965R9"XB"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD97)S(&%R
M92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B17(@=V]R
M9&5N(&=E96X@;6%P<&5N(&=E8V]N=')O;&5E<F0@;W`@;FEE=7=E(&UA:6PN
M(@H*(SH@9F]L9&5R<RYP:'`Z,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L:6(O
M1F]L9&5R+G!H<#HU-3`*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I
M960B"FUS9W-T<B`B1V5E;B!M87!P96X@;W!G96=E=F5N(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C$T-PIM<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE
M=R!M97-S86=E<R(*;7-G<W1R(")'965N(&UA<'!E;B!M970@;FEE=7=E(&)E
M<FEC:'1E;B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#0*;7-G:60@
M(DYO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`B1V5E
M;B!M87!P96X@;65T(&]N9V5Z:65N92!B97)I8VAT96XB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S(U"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G
M<W1R(")'965N(&)E<FEC:'1B;V1Y=&5K<W0B"@HC.B!L:6(O36%I;&)O>"YP
M:'`Z,S<Q"FUS9VED(").;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H
M+B(*;7-G<W1R(")'965N(&)E<FEC:'1E;B!D:64@86%N('5W('IO96MC<FET
M97)I82!V;VQD;V5N+B(*"B,Z('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P97)S
M;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N(@IM<V=S='(@(D=E96X@
M<&5R<V]O;FQI:FME('!R:79E(%!'4"!S;&5U=&5L(&=E:6UP;W)T965R9"XB
M"@HC.B!P9W`N<&AP.C$V-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI
M8R!K97D@:6UP;W)T960N(@IM<V=S='(@(D=E96X@<&5R<V]O;FQI:FME(&]P
M96YB87)E(%!'4"!S;&5U=&5L(&=E:6UP;W)T965R9"XB"@HC.B!S;6EM92YP
M:'`Z,C`Q"FUS9VED(").;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S
M(&EM<&]R=&5D+B(*;7-G<W1R(")'965N('!E<G-O;VYL:6IK(%,O34E-12!C
M97)T:69I8V%A="!G96EM<&]R=&5E<F0N(@H*(SH@<W!E;&QI;F<N<&AP.C(R
M,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N
M(@IM<V=S='(@(D=E96X@<W!E;&QI;F=S8V]N=')O;&5P<F]G<F%M;6$@9V5C
M;VYF:6=U<F5E<F0N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C0X"FUS9VED(").;R!S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B1V5E
M;B!S<&5L9F]U=&5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B1V5E;B!S
M=6=G97-T:65S(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-C0*;7-G:60@
M(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!C;W5L
M9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HV."!A8VPN<&AP
M.CDT"FUS9VED(").;R!U<V5R('-P96-I9FEE9"XB"FUS9W-T<B`B1V5E;B!G
M96)R=6EK97(@;W!G96=E=F5N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<P.0IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(D=E96X@
M9&5E;&YE;65R(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M,2!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,U('1E;7!L871E<R]P
M<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C8T"FUS9VED(").;VYE(@IM<V=S='(@(D=E96XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.34*;7-G:60@(DYO<FUA;"(*
M;7-G<W1R(").;W)M86%L(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Y"FUS9VED
M(").;W0@1&5L971E9"(*;7-G<W1R(").:65T('9E<G=I:F1E<F0B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$R('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM<V=S='(@(DYI
M970@:VQA9"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$W"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@(DYO="!);7!O
M<G1A;G0B"FUS9W-T<B`B3FEE="!B96QA;F=R:6IK(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T(%!E<G-O;F%L(@IM
M<V=S='(@(DYI970@<&5R<V]O;FQI:FLB"@HC.B!L:6(O0W)Y<'0O4$=0+G!H
M<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@;&EB+T-R>7!T+U--24U%
M+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A;&ED('!U8FQI8R!K97DN(@IM<V=S
M='(@(D]N9V5L9&EG92!O<&5N8F%R92!S;&5U=&5L+B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z-C<*;7-G:60@(DYO="!D96QE=&5D(&UE<W-A
M9V5S(@IM<V=S='(@(DYI970@=F5R=VEJ9&5R9&4@8F5R:6-H=&5N(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B3F]T(&EM<&]R
M=&%N="!M97-S86=E<R(*;7-G<W1R(").:65T(&)E;&%N9W)I:FME(&)E<FEC
M:'1E;B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I
M;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@
M=&EM92(*;7-G<W1R(")-97)K(&]P(&1A="!D:70@96YI9V4@=&EJ9"!K86X@
M9'5R96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$V"FUS9VED(").
M;W1H:6YG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S<*;7-G:60@(DYU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D
M(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*
M(D%A;G1A;"!M86%N9&5N+"!W96QK92!O=61E(&=E:V]P<&5L9&4@8FEJ;&%G
M96X@8F5W86%R9"!M;V5T96X@=V]R9&5N(&)I:B`B"B)M86%N9&5L:6IK<V4@
M;W!R=6EM:6YG+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*;7-G
M:60@(DYU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I
M9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R("(B"B)!86YT86P@;W5D92!<
M(D]55$)/6%PB(&UA<'!E;BP@=V5L:V4@8F5W86%R9"!W;W)D96X@8FEJ(&UA
M86YD96QI:FMS92`B"B)O<')U:6UI;F<N(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR-30@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4U,@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,S"FUS9VED(")/
M2R(*;7-G<W1R(")/2R(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN
M8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.0HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*;7-G<W1R
M(")/1B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,34*;7-G:60@
M(D]L9"!M97-S86=E<R(*;7-G<W1R(")/=61E(&)E<FEC:'1E;B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H
M<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E
M9"XB"FUS9W-T<B`B3W5D92!<(D]55$)/6%PB(&UA<'!E;B!W;W)D96X@=F5R
M=VEJ9&5R9"XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@
M(D]N;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN
M('1H96T_(@IM<V=S='(@(D%L;&5E;B!M87!P96X@;65T(&]N9V5L97IE;B!B
M97)I8VAT96X@=V5E<F=E=F5N/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z-SD*;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@
M8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R(")6;V]R(&1E
M>F4@8F5W97)K:6YG(&UA9R!S;&5C:'1S(.GI;B!M87`@9V5S96QE8W1E97)D
M('=O<F1E;BXB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,3`@=&5M<&QA=&5S
M+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")/<&5N($9O7VQD97(B"FUS
M9W-T<B`B36%P(&]P96YE;B(*"B,Z(&9O;&1E<G,N<&AP.C0R-PIM<V=I9"`B
M3W!E;F5D($9O;&1E<B(*;7-G<W1R(")'96]P96YD92!M87`B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S`U"FUS9VED(")/<'1I;VYA;"!087)T
M:6-I<&%N="(*;7-G<W1R(")%>'1R82!D965L;F5M97(B"@HC.B!F971C:&UA
M:6PN<&AP.C,S('1E;7!L871E<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHV"FUS9VED(")/=&AE
M<B!-86EL($%C8V]U;G1S(@IM<V=S='(@(D%N9&5R92!M86EL86-C;W5N=',B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,`IM<V=I9"`B3W1H97(@
M3W!T:6]N<R(*;7-G<W1R(")!;F1E<F4@;W!T:65S(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,#$*;7-G:60@(D]U=&)O=6YD(%-E<G9E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP"FUS
M9VED(")01U`B"FUS9W-T<B`B4$=0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M96YC<GEP=%]L:7-T+FEN8SHW"FUS9VED(")01U`@16YC<GEP="!-97-S86=E
M(@IM<V=S='(@(D)E<FEC:'0@4$=0(&-O9&5R96XB"@HC.B!C;VUP;W-E+G!H
M<#HS-3@*;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S='(@(E!'4"!F;W5T.B`B
M"@HC.B!C;VUP;W-E+G!H<#HS,S<*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P
M87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B
M4$=0(&9O=70Z('=A8VAT=V]O<F1R96=E;"!V97)E:7-T('9O;W(@<&5R<V]O
M;FQI:FME('!R:79E('-L975T96PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B4$=0(&]P=&EE
M<R(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!087-S<&AR87-E($EN<'5T
M(@IM<V=S='(@(E!'4"!W86-H='=O;W)D<F5G96P@:6YV;V5R(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C4U"FUS9VED(")01U`@4&5R<V]N86P@2V5Y
M<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R("(B"B)097)S;V]N;&EJ:V4@4$=0('-L975T96QP86%R(&]N
M9&5R<W1E=6YI;F<@=F5R96ES="!E96X@8F5V96EL:6=D92`B"B)W96)V97)B
M:6YD:6YG+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PIM<V=I
M9"`B4$=0(%!U8FQI8R!+97D@5&5X="(*;7-G<W1R(")/<&5N8F%R92!01U`@
M<VQE=71E;'1E:W-T(@H*(SH@<&=P+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C
M97-S9G5L;'D@861D960N(@IM<V=S='(@(D]P96YB87)E(%!'4"!S;&5U=&5L
M('9O;W(@7"(E<R`H)7,I7"(@=V5R9"!M970@<W5C8V5S('1O96=E=F]E9V0N
M(@H*(SH@<&=P+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U
M8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N
M(@IM<V=S='(@(D]P96YB87)E(%!'4"!S;&5U=&5L('9O;W(@7"(E<UPB('=E
M<F0@;65T('-U8V-E<R!V97)W:6ID97)D+B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@
M(D]P96YB87)E(%!'4"!S;&5U=&5L<FEN9R(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`IM<V=I9"`B4$=0(%-I9VX@365S<V%G
M92(*;7-G<W1R(")"97)I8VAT(%!'4"!O;F1E<G1E:V5N96XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.CD*;7-G:60@(E!'4"!3
M:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")"97)I8VAT(%!'4"!O;F1E
M<G1E:V5N96XO8V]D97)E;B(*"B,Z('!G<"YP:'`Z,C`R"FUS9VED(")01U`@
M<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")0<FEV
M92!01U`@<VQE=71E;"!M970@<W5C8V5S('1O96=E=F]E9V0N(@H*(SH@<&=P
M+G!H<#HQ-S<*;7-G:60@(E!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F=6QL>2!A
M9&1E9"XB"FUS9W-T<B`B3W!E;F)A<F4@4$=0('-L975T96P@;65T('-U8V-E
M<R!T;V5G979O96=D+B(*"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN
M8SHT"FUS9VED(")01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y
M<W1E;2XB"FUS9W-T<B`B4$=0(&]N9&5R<W1E=6YI;F<@:7,@;FEE="!I;F=E
M<V-H86ME;&0@;W`@9&ET('-Y<W1E96TN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,C`X"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R
M<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA
M8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)01U`@;VYD97)S
M=&5U;FEN9R!I<R!M;VUE;G1E96P@;FEE="!A8W1I968L(&1E(&1I9VET86QE
M(&AA;F1T96ME;FEN9R!K86X@9'5S("(*(FYI970@9V5V97)I9FEE97)D('=O
M<F1E;BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.34*;7-G:60@
M(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H
M92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N(@IM<V=S='(@
M(B(*(E!'4"!O;F1E<G-T975N:6YG(&ES(&UO;65N=&5E;"!N:65T(&%C=&EE
M9BP@:&5T(&)E<FEC:'0@:V%N(&1U<R!N:65T("(*(F=E9&5C;V1E97)D('=O
M<F1E;BXB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@HC+"!F=7IZ>0IM
M<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T
M;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2`B"B)S
M970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@
M=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F96%T=7)E<R!W:6QL
M(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4$=0(&]N9&5R<W1E
M=6YI;F<@=F5R96ES="!H970@9V5B<G5I:R!V86X@<&]P=7`@<V-H97)M96XN
M(%=A;FYE97(@=7<@8G)O=W-E<B`B"B)M;VUE;G1E96P@:7,@:6YG97-T96QD
M(&]P(&AE="!N:65T('1O97-T86%N('9A;B!P;W!U<"!S8VAE<FUE;BP@9&EE
M;G0@=2!D:70@(@HB=&4@=VEJ>FEG96XL(&]M9&%T(&%N9&5R<R!D92!01U`@
M;6]G96QI:FMH961E;B!N:65T(&=O960@>G5L;&5N('=E<FME;BXB"@HC.B!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G<W1R
M(")03U`S(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G:60@
M(E!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B4$]0,R`H
M075T;R!$971E8W0@4')O=&]C;VQS*2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,3$W"FUS9VED(")03U`S(&]V97(@4U-,(@IM<V=S='(@(E!/4#,@
M=FEA(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(S"FUS9VED
M(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS
M9W-T<B`B4$]0,R!V:6$@4U-,("AZ96QF(&]N9&5R=&5K96YD(&-E<G1I9FEC
M86%T*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED
M(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B4$]0,R!V
M:6$@4U-,("AZ96QF(&]N9&5R=&5K96YD*2(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3$Q"FUS9VED(")03U`S+"!N;R!43%,B"FUS9W-T<B`B4$]0
M,RP@9V5E;B!43%,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC
M.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS9W-T
M<B`B4&%G:6YA("5D('9A;B`E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,#,*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A
M9V4B"FUS9W-T<B`B4&%G:6YA(&UE="!E97)S=&4@;VYG97II96X@8F5R:6-H
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#0*;7-G:60@(E!A9V4@
M=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G92(*;7-G<W1R(")086=I;F$@
M;65T(&QA871S=&4@;VYG97II96X@8F5R:6-H="(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VAE861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S='(@
M(D]N9&5R9&5L96XB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS
M9VED(")087-S<&AR87-E(@IM<V=S='(@(E=A8VAT=V]O<F1R96=E;"(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@
M*$%G86EN*2(*;7-G<W1R(")786-H='=O;W)D<F5G96P@*&]P;FEE=7<I(@H*
M(SH@<VUI;64N<&AP.C(S-2!P9W`N<&AP.C,Q,`IM<V=I9"`B4&%S<W!H<F%S
M92!S=6-C97-S9G5L;'D@=6YL;V%D960N(@IM<V=S='(@(E=A8VAT=V]O<F1R
M96=E;"!M970@<W5C8V5S(&=E;&]S="XB"@HC.B!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN
M8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`B5V%C:'1W;V]R9')E
M9V5L.B(*"B,Z('!G<"YP:'`Z,3$R"FUS9VED(")087-S<&AR87-E<R!C86X@
M;F]T(&)E(&5M<'1Y(@IM<V=S='(@(E=A8VAT=V]O<F1R96=E;',@:W5N;F5N
M(&YI970@;&5E9R!Z:6IN(@H*(SH@<&=P+G!H<#HQ,30*;7-G:60@(E!A<W-P
M:')A<V5S(&1O(&YO="!M871C:"(*;7-G<W1R(")786-H='=O;W)D<F5G96QS
M(&MO;65N(&YI970@;W9E<F5E;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3(*;7-G:60@(E!A
M<W-W;W)D(@IM<V=S='(@(E=A8VAT=V]O<F0B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B3VYD97)H;W5D<W=E
M<FMZ86%M:&5D96X@=6ET=F]E<F5N(&)I:B!A86YM96QD:6YG/R(*"B,Z(&%C
M;"YP:'`Z-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T
M:&ES('5S97(@8V%N(&YO="!B92!C:&%N9V5D+B(*;7-G<W1R(")296-H=&5N
M('9O;W(@9&5Z92!G96)R=6EK97(@:W5N;F5N(&YI970@=V]R9&5N(&=E=VEJ
M>FEG9"XB"@HC.B!M97-S86=E+G!H<#HT.3,@;6%I;&)O>"YP:'`Z-S`S('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;&5G96YD+FEN8SHQ,`IM<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`B
M4&5R<V]O;FQI:FLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(E!E<G-O;VYL:6IK
M92!I;F9O<FUA=&EE(@H*(SH@<&=P+G!H<#HQ,C`*;7-G:60@(E!E<G-O;F%L
M(%!'4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(E!E<G-O;VYL:6IK(%!'4"!S;&5U=&5L<&%A<B!M970@<W5C8V5S(&=E9V5N
M97)E97)D+B(*"B,Z('!G<"YP:'`Z,3(W"FUS9VED(")097)S;VYA;"!01U`@
M:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&5R<V]O;FQI
M:FME(%!'4"!S;&5U=&5L<R!M970@<W5C8V5S('9E<G=I:F1E<F0N(@H*(SH@
M<VUI;64N<&AP.C(P-PIM<V=I9"`B4&5R<V]N86P@4R]-24U%(&-E<G1I9FEC
M871E<R!.3U0@:6UP;W)T960Z("(*;7-G<W1R(")097)S;V]N;&EJ:R!3+TU)
M344@8V5R=&EF:6-A870@3DE%5"!G96EM<&]R=&5E<F0Z("(*"B,Z('-M:6UE
M+G!H<#HQ,S(*;7-G:60@(E!E<G-O;F%L(%,O34E-12!K97ES(&1E;&5T960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")097)S;V]N;&EJ:V4@4R]-24U%('-L
M975T96QS(&UE="!S=6-C97,@=F5R=VEJ9&5R9"XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C(R"FUS9VED(")0;&%C92!Y;W5R('-I9VYA='5R92!B
M969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_(@IM<V=S='(@(E!L86%T<R!U
M=R!O;F1E<G1E:V5N:6YG('9O;W(@86YT=V]O<F1E;B!E;B!D;V]R9V5S='5U
M<F1E(&)E<FEC:'1E;C\B"@HC.B!C;VUP;W-E+G!H<#HR-30*;7-G:60@(E!L
M86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B4&QA='1E+71E
M:W-T=F5R<VEE('9A;B!B97)I8VAT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<Y.0IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O;B!N97<@;6%I;#\@(%1H
M:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O<G0@96UB961D960@
M(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I;F1O=W,@86YD
M($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL("(*(G)E<75I<F4@82!P
M;'5G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S
M8W)I<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC
M.C$Y,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F
M;VQD97(Z(@IM<V=S='(@(D=E968@965N(&YA86T@=F]O<B!D92!N:65U=V4@
M;6%P+"!A+G4N8BXZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ,#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*
M;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E
M<CHB"FUS9W-T<B`B1V5E9B!D92!N86%M('9A;B!D92!N:65U=V4@;6%P+"!A
M+G4N8BXZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ
M,S<*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@
M(D=E968@9&4@;FEE=7=E(&YA86TL(&$N=2YB+CHB"@HC.B!T96UP;&%T97,O
M<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I
M=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R`B"B)E;G1E<B!T:&ES
M('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HB
M1V5E9B!D92!W86-H='=O;W)D<F5G96P@=F%N('5W('!R:79E(%!'4"!S;&5U
M=&5L+"!A+G4N8BX@52!H;V5F="!D:70@<VQE8VAT("(*(F5E;FUA86P@<&5R
M("5S('-E<W-I92!O<"!T92!G979E;BXB"@HC.B!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE
M87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV
M871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D("(*(G1O(&5N=&5R('1H:7,@
M<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"B)'
M965F(&1E('=A8VAT=V]O<F1R96=E;"!V86X@=7<@<')I=F4@4R]-24U%('-L
M975T96PL(&$N=2YB+B!5(&AO969T(&1I="`B"B)S;&5C:'0@965N;6%A;"!P
M97(@)7,@<V5S<VEE(&]P('1E(&=E=F5N+B(*"B,Z(')E8V]M<&]S92YP:'`Z
M.3<*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O
M;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*
M(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O
M<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN
M(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P
M(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N
M(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@
M(B(*(DUE;&1T('4@;W!N:65U=R!A86X@;VT@=F5R9&5R('1E(&=A86X@;65T
M(&AE="!M86ME;B!V86X@=7<@8F5R:6-H="X@5V%N;F5E<B`B"B)U($=%14X@
M8V]O:VEE<R!G96)R=6EK="!%3B!U(&)E<FEC:'1E;B!I;B!E96X@<&]P=7`@
M<V-H97)M(&UA86MT+"!D:65N="!U("(*(G1E=F5N<R!A86X@=&4@;65L9&5N
M(&EN('5W(&AO;V9D<V-H97)M+B!$:70@:7,@;VT@=&4@=F]O<FMO;65N(&1A
M="`B"B)A86YV86QL97)S('5W('-E<W-I92!)1"!O=F5R;F5M96XN($]N>F4@
M97AC=7-E<R!V;V]R(&AE="!O;F=E;6%K+B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-S$*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S
M<W=O<F0N(@IM<V=S='(@(D=E968@=7<@=V%C:'1W;V]R9"P@82YU+F(N(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PIM<V=I9"`B4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B1V5E9B!U=R!G96)R
M=6EK97)S;F%A;2P@82YU+F(N(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])
M35`N<&AP.C0U.0IM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R
M(&EN=F%L:60@861D<F5S<V5S+B(*;7-G<W1R(")(97)S=&5L(&1U8F)E;'II
M;FYI9V4@;V8@;VYG96QD:6=E(&%D<F5S<V5N+"!A+G4N8BXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C0R"FUS9VED("(B"B)0;&5A<V4@<F5V
M:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C
M="!A;B!A8W1I;VX@9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B
M(@HB0F5K:6IK(&1E('9O;&=E;F1E(&EN9F]R;6%T:64@82YU+F(N(&5N('-E
M;&5C=&5E<B!D86%R;F$@965N(&)E=V5R:VEN9R!U:70@(@HB:&5T(&]N9&5R
M<W1A86YD92!M96YU+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z-C$*;7-G:60@(E!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E
M('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS+B(*;7-G<W1R(")396QE8W1E97(@
M965N(&UA<"!V;V]R9&%T('4@965N(&)E=V5R:VEN9R!U:71V;V5R="P@82YU
M+F(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4P,@IM<V=I9"`B
M4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB
M"FUS9W-T<B`B4V5L96-T965R(&5E;B!B97=E<FMI;F<@=6ET(&AE="!O;F1E
M<G-T86%N9&4@;65N=2P@82YU+F(N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]J
M879A<V-R:7!T+FEN8SHT,0IM<V=I9"`B4&QE87-E('-E;&5C="!A="!L96%S
M="!O;F4@9F]L9&5R('1O('-E87)C:"XB"FUS9W-T<B`B4V5L96-T965R('1E
M;FUI;G-T92#IZ6X@;6%P(&]M('1E(&1O;W)Z;V5K96XL(&$N=2YB+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L
M96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO
M;BXB"FUS9W-T<B`B4V5L96-T965R('-L96-H=',@Z>EN(&UA<"!V;V]R(&1E
M>F4@8F5W97)K:6YG+"!A+G4N8BXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R
M961I<F5C="YI;F,Z-S,*;7-G:60@(E!L96%S92!S96QE8W0@;W(@961I="!I
M;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T<B`B4V5L96-T965R(&]F
M(&)E=V5R:R!I;B!H970@=F%K(&%A;B!D92!R96-H=&5R:V%N=#HB"@HC.B!C
M;VYF:6<O;6]T9"YP:'`N9&ES=#HT,0IM<V=I9"`B4&]W97)E9"!B>2!(;W)D
M92(*;7-G<W1R(")0;W=E<F5D(&)Y($AO<F1E(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Q-`IM<V=I9"`B4')E8V5D92!Y;W5R('-I9VYA='5R92!W
M:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R(")/;F1E<G1E:V5N:6YG('9O
M;W)A9F=A86X@;65T('-T<F5E<&IE<R`H)RTM("<I/R(*"B,Z('-M:6UE+G!H
M<#HR-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"FUS9VED(")0
M<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B5F]O
M<FME=7)S:6YS=&5L;&EN9V5N(&UE="!S=6-C97,@8FEJ9V5W97)K="XB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B
M4')E=FEE=R(*;7-G<W1R(")"96]O<F1E;&5N(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@
M365S<V%G92(*;7-G<W1R(")6;W)I9R!B97)I8VAT(@H*(SH@;6%I;&)O>"YP
M:'`Z,S0W"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(E9O<FEG92!P
M86=I;F$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@(D%F9')U:VME;B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X"FUS9VED(")0<FEO<FET
M>2(*;7-G<W1R(")0<FEO<FET96ET(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C<V"FUS9VED(")0<FEV871E($ME>2!087-S=V]R9"(*
M;7-G<W1R(")0<FEV92!S;&5U=&5L('=A8VAT=V]O<F0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-34Y"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A
M;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B"FUS9W-T<B`B
M16QK92!K965R('9R86=E;B!W86YN965R(&5E;B!B:6IL86=E('=O<F1T('9E
M<GIO;F1E;CL@<W1A;F1A87)D(&]P($Y%12(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C
M:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B16QK92!K
M965R('9R86=E;B!W86YN965R(&5E;B!B:6IL86=E('=O<F1T('9E<GIO;F1E
M;CL@<W1A;F1A87)D(&]P($I!(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C$P"FUS9VED(")0<F]T;V-O;#HB"FUS9W-T<B`B4')O=&]C
M;VPZ(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y"FUS9VED(")0=6)L:6,@
M4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G
M<W1R(")/<&5N8F%R92!01U`@<VQE=71E;'-E<G9E<B!I<R!U:71G97-C:&%K
M96QD+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z.`IM<V=I9"`B
M4'5R7V=E($1E;&5T960B"FUS9W-T<B`B7U=I<R!V97)W:6ID97)D(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)G92!$96QE
M=&5D(@IM<V=S='(@(E=I<R!V97)W:6ID97)D(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,C0*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*
M;7-G<W1R(")-87`H<&5N*2!L96=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.38*;7-G:60@(E!U<F=E(%1R87-H(&AO=R!O9G1E;CHB"FUS9W-T
M<B`B2&]E('9A86L@<')U;&QE;F)A:R!L96=E;CHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#`U"FUS9VED(")0=7)G92!M97-S86=E<R!I;B!4<F%S
M:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*;7-G
M<W1R(")697)W:6ID97(@8F5R:6-H=&5N(&EN(&1E('!R=6QL96YB86L@;W5D
M97(@9&%N(&1I="!A86YT86P@9&%G96XN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X-@IM<V=I9"`B4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4
M<F%S:"!F;VQD97(_(@IM<V=S='(@(E9E<G=I:F1E<B!O=61E(&)E<FEC:'1E
M;B!U:70@9&4@<')U;&QE;F)A:S\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S
M:R]P=7)G95]T<F%S:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N(@IM
M<V=S='(@(E9E<G=I:F1E<B`E9"!B97)I8VAT96X@=6ET(&1E('!R=6QL96YB
M86LN(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP
M.C8S"B,L(&9U>GIY"FUS9VED(")0=7)G:6YG(#$@;65S<V%G92!F<F]M(%1R
M87-H(&9O;&1E<BXB"FUS9W-T<B`B5F5R=VEJ9&5R("5D(&)E<FEC:'1E;B!U
M:70@9&4@<')U;&QE;F)A:RXB"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N
M:6YC.C$W"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR
M9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R(")1=6]T82!S=&%T=7,Z
M("4N,F9-0B`O("4N,F9-0B`H)2XR9B4E*2(*"B,Z('1E;7!L871E<R]Q=6]T
M82]Q=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A
M='5S.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R(")1=6]T82!S=&%T=7,Z
M("4N,F9-0B`O($=%14X@3$E-2454(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U
M;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z
M($Y/($Q)34E4(@IM<V=S='(@(E%U;W1A('-T871U<SH@1T5%3B!,24U)150B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")1=6]T:6YG("5F.B(*;7-G<W1R(")#:71E<F5N("4E
M9CHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#8*;7-G
M:60@(E)E7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(*;7-G<W1R(")6
M97)?>F]E:R!A9FQE=F5R:6YG<V)E=F5S=&EG:6YG(@H*(SH@;&EB+U-E87)C
M:"YP:'`Z-3`*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@(D]N='9A;F=E
M;B!O<"(*"B,Z(&QI8B]396%R8V@N<&AP.C4X"FUS9VED(")296-E:79E9"!3
M:6YC92(*;7-G<W1R(")/;G1V86YG96X@<VEN9',B"@HC.B!L:6(O4V5A<F-H
M+G!H<#HU-`IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`B3VYT=F%N
M9V5N('1O="(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(D]M7VQE:61E;B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM
M<V=I9"`B4F5D:7)E8W0B"FUS9W-T<B`B3VUL96ED96XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I<F5C="!-
M97-S86=E(@IM<V=S='(@(D)E<FEC:'0@;VUL96ED96XB"@HC.B!C;VUP;W-E
M+G!H<#HW.#<*;7-G:60@(E)E9&ER96-T('1H:7,@;65S<V%G92(*;7-G<W1R
M(")$:70@8F5R:6-H="!O;6QE:61E;B(*"B,Z(&-O;7!O<V4N<&AP.C@T-PIM
M<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*;7-G<W1R(")/;6QE:61E;B!M
M:7-L=6MT+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X
M,PIM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")697)V97)S96XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S@T"FUS9VED(")2969R97-H($9O;&1E<B!6
M:65W<SHB"FUS9W-T<B`B5F5R=F5R<R!M87!W965R9V%V97,Z(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.2!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C0*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")697)N:65U=V5N
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L
M;V%D(%9I97<B"FUS9W-T<B`B5V5E<F=A=F4@=F5R;FEE=7=E;B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C8@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4T-0IM<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B3VYT:&]U9'0@9&4@=G)I:B]B97IE="!I;F9O
M<FUA=&EE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-SD*;7-G:60@
M(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS9W-T<B`B3VYT:&]U9'0@9&4@
M;&%A='-T92!W965R9V%V92(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHR-PIM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(DUA
M:6QB;W@@;W`@869S=&%N9#HB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD
M<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M(%-E87)C:"(*;7-G
M<W1R(")697)W:6ID97(@=F5L9"!U:70@>F]E:V5N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`U"FUS9VED(")296UO=F4@<V]U
M<F-E(@IM<V=S='(@(D)R;VX@=F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHX"FUS9VED(")296YA;64@1F]L9&5R*',I
M(@IM<V=S='(@(DAE<FYO96T@;6%P*'!E;BDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0Q"FUS9VED(")296YA;64@<V5N="UM86EL(&9O;&1E<B!A
M="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(DAE<FYO96T@3U540D]8
M(&UA<"!A86X@:&5T(&)E9VEN('9A;B!D92!M86%N9#\B"@HC.B!L:6(O1F]L
M9&5R+G!H<#HT-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E
M<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`B2&5R;F]E;65N('9A;B!<(B5S7"(@=&]T(%PB)7-<
M(B!M:7-L=6MT+B!$:70@:7,@=V%T(&1E('-E<G9E<B!M96QD="(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B
M4F5P;%]Y('1O($QI<W0B"FUS9W-T<B`B0F5A;G1?=V]O<F0@;6%I;&EN9VQI
M<W0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS
M9VED(")297!L86-E('=I=&@Z(@IM<V=S='(@(E9E<G9A;F<@9&]O<CHB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I
M9"`B4F5P;'DB"FUS9W-T<B`B0F5A;G1W;V]R9&5N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C,Q,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#`Y"FUS9VED(")297!L>2!396YT+B(*;7-G<W1R(")!;G1W;V]R9"!V97)Z
M;VYD96XN(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$S"FUS9VED(")297!L>2!T;R!!;&PB"FUS9W-T<B`B0F5A;G1W;V]R
M9"!A;&QE;B(*"B,Z(&-O;7!O<V4N<&AP.C<S,PIM<V=I9"`B4F5P;'D@=&\@
M06QL.B(*;7-G<W1R(")"96%N='=O;W)D(&%L;&5N.B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;'D@
M=&\@3&ES="(*;7-G<W1R(")"96%N='=O;W)D(&UA:6QI;F=L:7-T(@H*(SH@
M8V]M<&]S92YP:'`Z-S,U"FUS9VED(")297!L>2!T;R!,:7-T.B(*;7-G<W1R
M(")"96%N='=O;W)D(&UA:6QI;F=L:7-T.B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@7T%L
M;"(*;7-G<W1R(")"96%N='=O;W)D(%]A;&QE;B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S
M-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED(")297!L
M>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R(")!;G1W;V]R
M9"!M970@3FEE="!/;F1E<G-T975N9"!"97)I8VAT(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4S-0IM<V=I9"`B4F5P;'D@=VET:"!F<F5E+V)U
M<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(D%N='=O;W)D(&UE="!V
M<FEJ+V)E>F5T('9O;W(@9&4@=F]L9V5N9&4@,B!M86%N9&5N+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E<&QY('=I=&@@
M<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B06YT
M=V]O<F0@;65T(&=E=G)A86=D92!V<FEJ+V)E>F5T(&EN9F]R;6%T:64N(@H*
M(SH@;65S<V%G92YP:'`Z,C8W"FUS9VED(")297!L>2U4;R(*;7-G<W1R(")!
M;G1W;V]R9&5N(&%A;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#D*;7-G:60@
M(E)E<&QY+51O.B`B"FUS9W-T<B`B06YT=V]O<F1E;B!A86XZ(@H*(SH@8V]M
M<&]S92YP:'`Z-S,Q"FUS9VED(")297!L>3HB"FUS9W-T<B`B0F5A;G1W;V]R
M9&5N.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR-@IM<V=I9"`B
M4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S='(@(E)A<'!O<G1E97(@86QS(&]N
M<V-H=6QD:6<B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*;7-G
M:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(E)A<'!O<G1E97(@86QS('-P
M86TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#,*;7-G
M:60@(E)E<75E<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(E9E<GIO96L@
M965N(&QE97,@7V]N='9A;F=S=&)E=F5S=&EG:6YG(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4X-0IM<V=I9"`B4F5Q=65S="!D96QI=F5R>2!C;VYF
M:7)M871I;VX_(@IM<V=S='(@(E9E<GIO96L@869L979E<FEN9W-B979E<W1I
M9VEN9S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S"FUS9VED(")2
M97%U97-T(')E860@<F5C96EP=',_(@IM<V=S='(@(E9E<GIO96L@;&5E<R!O
M;G1V86YG<W1B979E<W1I;F=E;C\B"@HC.B!M86EL8F]X+G!H<#HQ.#D*;7-G
M:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"XB"FUS9W-T<B`B1V5V
M<F%A9V1E(&)E<FEC:'0@;FEE="!G979O;F1E;BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-CDW"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N
M="(*;7-G<W1R(")697)E:7-T92!D965L;F5M97(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI
M;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,0IM<V=I9"`B4F5S
M970B"FUS9W-T<B`B2&5R<W1E;&QE;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ,34*;7-G:60@(E)E<W!O;F1E;G0@4W1A='5S(%5P9&%T960N
M(@IM<V=S='(@(E-T871U<R!V86X@8F5A;G1W;V]R9&5R(&=E=7!D871E+B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,`IM
M<V=I9"`B4F5S=6UE(@IM<V=S='(@(E9E<G9O;&=E;B(*"B,Z(')E8V]M<&]S
M92YP:'`Z.3@*;7-G:60@(E)E<W5M92!Y;W5R('-E<W-I;VXB"FUS9W-T<B`B
M5F5R=F]L9R!U=R!S97-S:64B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!<(DUE<W-A
M9V4@0V]M<&]S:71I;VY<(B(*;7-G<W1R(")"97)I8VAT<V%M96YS=&5L;&EN
M9R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z
M,S$@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8Y"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C,R"FUS9VED(")2
M971U<FX@=&\@1F5T8V@@36%I;"(*;7-G<W1R(")497)U9R!N86%R(&%N9&5R
M92!03U`S+TE-05`@86-C;W5N=',B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHR
M,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP;&%T97,O
M<VUI;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L871E<R]A8VPO86-L+FEN8SHQ
M-S,*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E1E<G5G(&YA
M87(@;W!T:65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q.`IM<V=I
M9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L
M971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S='(@
M(B(*(E1E<G5G(&YA87(@9&4@;6%I;&)O>&QI:G-T(&YA('9E<G=I:F1E<F5N
M+"!V97)P;&%A='-E;B!O9B!K;W!IZW)E;B!V86X@965N("(*(F)E<FEC:'0_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4F]L
M92(*;7-G<W1R(")2;VPB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C$T,B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S-PHC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C0Q.0IM<V=I9"`B4R]-24U%(@IM<V=S='(@
M(E,O34E-12(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI
M;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B
M0F5R:6-H="!3+TU)344@8V]D97)E;B(*"B,Z(&-O;7!O<V4N<&AP.C,Y-`IM
M<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B4R]-24U%($9O=70Z("(*
M"B,Z(&-O;7!O<V4N<&AP.C,W,PIM<V=I9"`B4R]-24U%($5R<F]R.B!.965D
M('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R
M(")3+TU)344@9F]U=#H@=V%C:'1W;V]R9')E9V5L('9E<F5I<W0@=F]O<B!P
M97)S;V]N;&EJ:V4@<')I=F4@<VQE=71E;"XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34Q"FUS9VED(")3+TU)344@3W!T:6]N<R(*;7-G<W1R(")3
M+TU)344@;W!T:65S(@H*(SH@<VUI;64N<&AP.C0Y"FUS9VED(")3+TU)344@
M4&%S<W!H<F%S92!);G!U="(*;7-G<W1R(")3+TU)344@=V%C:'1W;V]R9')E
M9V5L(&EN=F]E<B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-30*
M;7-G:60@(E,O34E-12!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER
M97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*(E!E<G-O
M;VYL:6IK92!3+TU)344@<VQE=71E;'!A87(@;VYD97)S=&5U;FEN9R!V97)E
M:7-T(&5E;B!B979E:6QI9V1E("(*(G=E8G9E<F)I;F1I;F<N(@H*(SH@<VUI
M;64N<&AP.C$T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC
M($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS
M9W-T<B`B3W!E;F)A<F4@4R]-24U%('-L975T96P@=F]O<B!<(B5S7"(@=V5R
M9"!M970@<W5C8V5S('9E<G=I:F1E<F0N(@H*(SH@<VUI;64N<&AP.C$V,@IM
M<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*
M;7-G<W1R(")/<&5N8F%R92!3+TU)344@<VQE=71E;"!M970@<W5C8V5S('1O
M96=E=F]E9V0N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM
M<V=I9"`B4R]-24U%(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(D]P96YB87)E
M(%,O34E-12!S;&5U=&5L<FEN9R(*"B,Z('-M:6UE+G!H<#HR,3$*;7-G:60@
M(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A
M9&1E9"XB"FUS9W-T<B`B3W!E;F)A87(O<')I=F4@4R]-24U%('-L975T96QP
M86%R(&UE="!S=6-C97,@=&]E9V5V;V5G9"XB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"FUS9VED(")3+TU)344@4VEG;B!-
M97-S86=E(@IM<V=S='(@(D)E<FEC:'0@4R]-24U%(&]N9&5R=&5K96YE;B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*;7-G
M:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")"97)I
M8VAT(%,O34E-12!O;F1E<G1E:V5N96XO8V]D97)E;B(*"B,Z('1E;7!L871E
M<R]S;6EM92]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E,O34E-12!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")3+TU)344@
M;VYD97)S=&5U;FEN9R!I<R!N:65T(&EN9V5S8VAA:V5L9"!O<"!D:70@<WES
M=&5E;2XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I
M9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D
M('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92`B"B)D96-R>7!T960N
M(@IM<V=S='(@(B(*(E,O34E-12!O;F1E<G-T975N:6YG(&ES(&UO;65N=&5E
M;"!N:65T(&%C=&EE9BP@:&5T(&)E<FEC:'0@:V%N(&1U<R!N:65T("(*(F=E
M9&5C;V1E97)D('=O<F1E;BXB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@
M;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE
M<W-A9V4@8V%N(&YO="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(B(*(E,O
M34E-12!O;F1E<G-T975N:6YG(&ES(&YI970@86-T:65F+"!D92!D:6=I=&%L
M92!H86YD=&5K96YI;F<@:V%N(&1U<R!N:65T("(*(F=E=F5R:69I965R9"!W
M;W)D96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*;7-G
M:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D
M:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(B(*(E,O34E-12!O;F1E<G-T975N:6YG(&ES(&YI970@86-T
M:65F+"!D92!D:6=I=&%L92!H86YD=&5K96YI;F<@:V%N(&1U<R!N:65T("(*
M(F=E=F5R:69I965R9"!W;W)D96XN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR"B,L(&9U>GIY"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!R
M97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R
M;W=S97(@:7,@(@HB8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I
M;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92`B
M"B)T:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY
M+B(*;7-G<W1R("(B"B)3+TU)344@;VYD97)S=&5U;FEN9R!V97)E:7-T(&AE
M="!G96)R=6EK('9A;B!P;W!U<"!S8VAE<FUE;BX@5V%N;F5E<B!U=R`B"B)B
M<F]W<V5R(&UO;65N=&5E;"!I<R!I;F=E<W1E;&0@;W`@:&5T(&YI970@=&]E
M<W1A86X@=F%N('!O<'5P('-C:&5R;65N+"`B"B)D:65N="!U(&1I="!T92!W
M:6IZ:6=E;BP@;VUD870@86YD97)S(&1E(%,O34E-12!M;V=E;&EJ:VAE9&5N
M(&YI970@9V]E9"`B"B)Z=6QL96X@=V5R:V5N+B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C`U"FUS9VED(")33510(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(U-0IM<V=I9"`B4U]U
M8FIE8W0B"FUS9W-T<B`B3VYD97)W95]R<"(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,V,PIM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*
M;7-G<W1R(")"95]W86%R(&5E;B!K;W!I92!I;B`B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A7W9E(&%S
M(@IM<V=S='(@(D]P7W-L86%N(&%L<R(*"B,Z('-E87)C:"YP:'`Z,S$V('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-PIM<V=I9"`B4V%V92(*
M;7-G<W1R(")/<'-L86%N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE;G1S('=I=&@@;65S<V%G
M92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R(")":6IL86=E;B!S86UE
M;B!M970@8F5R:6-H="!O<'-L86%N(&EN(&]U=&)O>"!M87`_(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#,S"FUS9VED(")3879E($1R869T(@IM<V=S='(@
M(D]P<VQA86X@86QS(&ML860B"@HC.B!S879E:6UA9V4N<&AP.C0R"B,L(&9U
M>GIY"FUS9VED(")3879E($EM86=E(@IM<V=S='(@(D]P<VQA86X@86QS(@H*
M(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(P-`IM<V=I9"`B4V%V92!);6%G
M92!I;B!'86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC
M.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN
M8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(D]P=&EE<R!O<'-L
M86%N(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"B,L
M(&9U>GIY"FUS9VED(")3879E(%-T871I;VYE<GDB"FUS9W-T<B`B3W!T:65S
M(&]P<VQA86XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV
M.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@(E-A
M=F4@7T1R869T(@IM<V=S='(@(D]P<VQA86X@86QS(%]K;&%D(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")3
M879E(&%S(@IM<V=S='(@(D]P<VQA86X@86QS(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*
M;7-G<W1R(")+;&%D(&]P<VQA86X@86QS(&]N9V5Z:65N/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#<R"FUS9VED(")3879E(')E8VEP:65N=',@
M875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_(@IM
M<V=S='(@(D]N='9A;F=E<G,@875T;VUA=&ES8V@@:6X@<W1A;F1A87)D(&%D
M<F5S8F]E:R!O<'-L86%N/R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,3(W"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R
M/R(*;7-G<W1R("):;V5K;W!D<F%C:'0@8F5W87)E;B!A;',@=FER='5E;&4@
M;6%P/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(E-A
M=F4@<V5N="!M86EL/R(*;7-G<W1R(")"97=A87(@=F5R>F]N9&5N(&UA:6P_
M(@H*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@)7,B"FUS9W-T<B`B0F5W87)E;B!V86X@:VQA9"!M:7-L=6MT
M+B!$92!S97)V97(@;65L9'0Z("5S(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN
M8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HT,0IM<V=I9"`B
M4V5A<F-H(@IM<V=S='(@(EIO96ME;B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M:&5A9&5R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:"`E<R(*;7-G<W1R("(E<R!D
M;V]R>F]E:V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,`HC+"!F
M=7IZ>0IM<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`B3W!T:65S(&]P
M<VQA86XB"@HC.B!S96%R8V@N<&AP.C(V-0IM<V=I9"`B4V5A<F-H(%)E<W5L
M=',B"FUS9W-T<B`B6F]E:W)E<W5L=&%T96XB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C$T('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S$*;7-G:60@(E-E96XB"FUS9W-T<B`B1V5Z:65N(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHY"FUS9VED(")396QE8W0B"FUS9W-T
M<B`B4V5L96-T97)E;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G<W1R
M(")396QE8W1E97(@965N(&%N9&5R92!A8V-O=6YT(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED(")396QE8W0@82!D871E(@IM
M<V=S='(@(E-E;&5C=&5E<B!E96X@9&%T=6TB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+V9I96QD<RYI;F,Z,3`*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S
M='(@(E-E;&5C=&5E<B!E96X@=F5L9"(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,Q-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@<W1A
M=&EO;F5R>3HB"FUS9W-T<B`B4V5L96-T965R(&5E;B!D871U;2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!A9&1R97-S
M(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D
M9')E<W-E<RXB"FUS9W-T<B`B4V5L96-T965R(&%D<F5S8F]E:V)R;VYN96X@
M=F]O<B!T;V5V;V5G96X@96X@>F]E:V5N('9A;B!A9')E<W-E;BXB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL
M(@IM<V=S='(@(E-E;&5C=&5E<B!A;&QE<R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L96-T(&%L;"!F:65L
M9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T
M<B`B4V5L96-T965R(&%L;&4@=F5L9&5N(&]M('1E(&1O;W)Z;V5K96X@="YB
M+G8N(&YA86US=6ET8G)E:61I;F<N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!A;B!A8V-O
M=6YT(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@86-C;W5N="(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM
M<V=S='(@(E-E;&5C=&5E<B!N:65T<R(*"B,Z('1E;7!L871E<R]S879E:6UA
M9V4O<V%V96EM86=E+FEN8SHY"FUS9VED(")396QE8W0@=&AE(&=A;&QE<GD@
M=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C
M="!T:&4@;6%I;"!S97)V97(@='EP92(*;7-G<W1R(")396QE8W1E97(@:&5T
M(&UA:6QS97)V97)T>7!E(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S`Y"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*
M;7-G<W1R(")'97-E;&5C=&5E<F1E(&%D<F5S8F]E:V5N.B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC
M($ME>7-E<G9E<B(*;7-G<W1R(")697)Z96YD('-L975T96P@;F%A<B!O<&5N
M8F%R92!S;&5U=&5L<V5R=F5R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8P-`IM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T
M<B`B5F5R>F5N9"!L86%T<W1E(&EN9F]R;6%T:64B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT,S$*;7-G:60@(E-E;F0@365S<V%G92(*;7-G<W1R(")697)Z
M96YD(&)E<FEC:'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S`S"B,L
M(&9U>GIY"FUS9VED(")396YD(')E860@<F5C96EP="!W:&5N(')E<75E<W1E
M9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R(")697)Z96YD(&]N='9A;F=S=&)E
M=F5S=&EG:6YG('=A;FYE97(@9V5V<F%A9V0@9&]O<B!D92!A9GIE;F1E<C\B
M"@HC.B!F;VQD97)S+G!H<#HS.3<*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(B
M"FUS9W-T<B`B3U540D]8(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL
M<V5L96-T+FEN8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T
M<B`B3U540D]8.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS9W-T<B`B4V5R
M=F5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"FUS9VED(")397)V
M97(@86YD($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G<W1R(")397)V97(M(&5N
M(&UA<&EN9F]R;6%T:64B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,C,*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B4V5R=F5R.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,`IM<V=I9"`B4V5T('!R969E<F5N
M8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E
M(&UE<W-A9V5S+B(*;7-G<W1R("(B"B)6;V]R:V5U<G-I;G-T96QL:6YG96X@
M=F]O<B!H970@=F5R<&QA871S96X@96X@=F5R=VEJ9&5R96X@=F%N(&)E<FEC
M:'1E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3
M970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A
M9V5S/R(*;7-G<W1R("));G-T96QL96X@=F%N(&1E(%@M4')I;W)I='D@:&5A
M9&5R(&)I:B!H970@;6%K96X@=F%N(&)E<FEC:'1E;C\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(E-H87)E($9O;&1E<G,B"FUS9W-T
M<B`B36%P<&5N(&1E;&5N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C@V
M"FUS9VED(")3:&%R92!M86EL(&9O;&1E<G,B"FUS9W-T<B`B36%I;&UA<'!E
M;B!D96QE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B
M4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS
M9W-T<B`B1&5E;"!U=R!M86EL;6%P<&5N(&UE="!A;F1E<F4@9V5B<G5I:V5R
M<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8Y"FUS9VED("(B"B)3
M:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT(&)E('-H;W=N(&]R
M(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@(@HB=&]G9VQE9"!E87-I
M;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N(@IM<V=S='(@(B(*(D1I96YE;B!G
M<F]T92!B;&]K:V5N(&%A;F=E:&%A;&1E('1E:W-T('-T86YD86%R9"!W965R
M9V5G979E;B!O9B!V97)B;W)G96X@=&4@(@HB=V]R9&5N/R!(970@:V%N(&5E
M;G9O=61I9R!O;6=E<V-H86ME;&0@=V]R9&5N+"!W96QK92!U(&]O:R!K:65S
M="XB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM<V=I9"`B4VAO=6QD
M('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F
M;W(@4$=0(&1A=&$_(@IM<V=S='(@(E=I;'0@=2!D92!B;V1Y('9A;B!T97AT
M+W!L86EN(&)E<FEC:'1E;B!S8V%N;F5N(&]P(%!'4"!D871A/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M
M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*
M;7-G<W1R("(B"B)$:65N="!H970@7").:65U=R!B97)I8VAT7"(@<V-H97)M
M(&=E<VQO=&5N('1E('=O<F1E;B!N82!O<'-L86%N('9A;B!K;&%D/R(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U<B!0
M1U`@<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S
M(&)Y(&1E9F%U;'0_(@IM<V=S='(@(B(*(D1I96YT('5W(&]P96YB87)E(%!'
M4"!S;&5U=&5L('-T86YD86%R9"!A86X@=7<@8F5R:6-H=&5N('1O96=E=F]E
M9V0@=&4@(@HB=V]R9&5N/R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z.3(*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`B06QL92!M
M87!P96X@=V5E<F=E=F5N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R
M<RYI;F,Z-C<*;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B06QL
M92!H96%D97)S('=E97)G979E;B(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM<V=I
M9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(E1O;VX@=F5R=VEJ9&5R9"(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED(")3:&]W
M($QI;6ET960@2&5A9&5R<R(*;7-G<W1R(")"97!E<FMT92!H96%D97)S('=E
M97)G979E;B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P
M"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R
M(")-86EL:6YG;&ES="!I;F9O<FUA=&EE('=E97)G979E;B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@3VYL>2!3=6)S
M8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B06QL965N(&EN9V5S8VAR979E;B!M
M87!P96X@=V5E<F=E=F5N(@H*(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")3
M:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")4;V]N('5I=&=E<V-H<F5V96XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`X"FUS9VED(")3:&]W(&%N
M(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@
M;65S<V%G97,_(@IM<V=S='(@(E!I8W1O9W)A;2!V;V]R(&AE="!V97)W:6ID
M97)E;B!V86X@8F5R:6-H=&)I:FQA9V5N('=E97)G979E;C\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`P,@IM<V=I9"`B4VAO=R!L96=E;F0@:6X@
M=&AE(&UA:6QB;W@@=FEE=S\B"FUS9W-T<B`B3&5G96YD82!W965R9V5V96X@
M:6X@9&4@;6%I;&)O>'=E97)G879E/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-#`*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S
M86=E<R!O;FQY/R(*;7-G<W1R(")!;&QE96X@<')E=FEE=W,@=V5E<F=E=F5N
M('9A;B!O;F=E;&5Z96X@8F5R:6-H=&5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-#@*;7-G:60@(E-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_
M(@IM<V=S='(@(E!R979I97=S(&EN('1O;VQT:7!S('=E97)G979E;C\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<W"FUS9VED(")3:&]W('1H92!&
M971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(DUA:6P@
M;W!H86QE;B!P:6-T;V=R86T@=V5E<F=E=F5N(&]P(&1E(&UE;G5B86QK/R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B4VAO=R!T
M:&4@26UA9V5S(@IM<V=S='(@(D1E(&%F8F5E;&1I;F=E;B!W965R9V5V96XB
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-30*;7-G:60@(E-H
M;W<@=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R(")&
M:6QT97(@<&EC=&]G<F%M('=E97)G979E;B!O<"!D92!M96YU8F%L:S\B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C@*;7-G:60@(E-H;W<@=&]T86P@
M;G5M8F5R(&]F(&UA:6QS(&EN(&9O;&1E<C\B"FUS9W-T<B`B5&]T86%L(&%A
M;G1A;"!M86EL<R!I;B!M87`@=V5E<F=E=F5N/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-C8*;7-G:60@(E-H;W=N(@IM<V=S='(@(E=E97)G96=E
M=F5N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHT,@IM<V=I9"`B4VE?>F4B"FUS9W-T<B`B7T=R;V]T=&4B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$W"FUS9VED(")3:6=N960B"FUS
M9W-T<B`B3VYD97)T96ME;F0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")'<F]O='1E(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM
M<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@(E-O<G1E<F5N(&]P(&%A
M;FMO;7-T=&EJ9"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,38*;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R(")3;W)T
M97)E;B!O<"!D871U;2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,C8*;7-G:60@(E-O<G0@8GD@1G)O;2!!9&1R97-S(@IM
M<V=S='(@(E-O<G1E<F5N(&]P(&%F>F5N9&5R(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT,0IM<V=I9"`B4V]R="!B>2!-
M97-S86=E(%-I>F4B"FUS9W-T<B`B4V]R=&5R96X@;W`@8F5R:6-H=&=R;V]T
M=&4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C,V"FUS9VED(")3;W)T(&)Y(%-U8FIE8W0B"FUS9W-T<B`B4V]R=&5R96X@
M;W`@;VYD97)W97)P(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHS,0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B
M4V]R=&5R96X@;W`@=&AR96%D(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S
M(@IM<V=S='(@(E-O<G1E<F5N(&]P(&=E861R97-S965R9&4B"@HC.B!T96UP
M;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C,*;7-G:60@(E-P86T@9F]L
M9&5R.B(*;7-G<W1R(")3<&%M(&UA<#HB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*
M;7-G<W1R(")3<&5C:6%L92!K87)A:W1E<G,B"@HC.B!S96%R8V@N<&AP.C$S
M,PIM<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N(&YO="!B92!E
M9&ET960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,T,PIM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`B4W!E;&QI
M;F=S8V]N=')O;&4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-#8*;7-G:60@(E-P96QL($-H96-K97(B"FUS9W-T<B`B4W!E;&QI;F=S
M8V]N=')O;&4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-#@@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS9VED(")3
M<&5L;"!C:&5C:R!C;VUP;&5T92(*;7-G<W1R(")3<&5L;&EN9W-C;VYT<F]L
M92!C;VUP;&5E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G
M:60@(E-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE
M8VMI;F<N(@IM<V=S='(@(E-P96QF;W5T96X@<&5R('!A9VEN82!T:6ID96YS
M('-P96QL:6YG<V-O;G1R;VQE+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,3(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U,@IM<V=I9"`B
M4W1A<G0B"FUS9W-T<B`B4W1A<G0B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M,3$*;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T:6]N97)Y(&YA
M;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHR.`IM<V=I9"`B4W1A=&EO;F5R>2!T>7!E.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S,*;7-G:60@(E-T
M871I;VYE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV.#@*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!L
M:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")3=')I<"!!='1A8VAM
M96YT(@IM<V=S='(@(D)I:FQA9V4@<W1R:7!P96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#,R"FUS9VED(")3=')I<"!L:6YE8G)E86MS/R(*;7-G
M<W1R(")296=E;&5I;F1E;B!V97)W:6ID97)E;C\B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,W"FUS9VED(")3=6)?:F5C
M="(*;7-G<W1R(")/;F1E7W)W97)P(@H*(SH@;65S<V%G92YP:'`Z,C8X('1H
M<F5A9"YP:'`Z,34P('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z
M,C4*(SH@;&EB+U-E87)C:"YP:'`Z,S@*;7-G:60@(E-U8FIE8W0B"FUS9W-T
M<B`B3VYD97)W97)P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM
M<V=I9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R(")/;F1E<G=E<G!V96QD(@H*
M(SH@<V5A<F-H+G!H<#HS,3@@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA
M9V4N:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR
M,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"FUS9VED(")3=6)M
M:70B"FUS9W-T<B`B0F5V97-T:6=E;B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R*',I
M(@IM<V=S='(@(DEN<V-H<FEJ=F5N('9A;B!M87`H<&5N*2(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@P(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C,X.0HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX-PIM<V=I
M9"`B4W5C8V5S<R(*;7-G<W1R(")3=6-C97,B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S
M='(@(E-U9V=E<W1I97,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C8R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(E-U;6UA
M<GDB"FUS9W-T<B`B4V%M96YV871T:6YG(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#`P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0P,PIM<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G
M<W1R(")/;7-C:&%K96QE;B!V86X@8V]M<&]S:71I96UE=&AO9&4B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C
M:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(D]M<V-H86ME;&5N(&YA
M87(@2%1-3"!C;VUP;W-I=&EE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP
M;W-I=&EO;B(*;7-G<W1R(")/;7-C:&%K96QE;B!N86%R('!L871T92!T96MS
M="!C;VUP;W-I=&EE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#$Y"FUS9VED(")495]X="(*;7-G<W1R(")47V5K<W0B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")496YT
M871I=F4Z("(*;7-G<W1R(")6;V]R;&]P:6<@9V5A8V-E<'1E97)D(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,0IM<V=I9"`B5&5N=&%T:79E
M;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`B5F5R>F]E:R!V;V]R;&]P:6<@
M86-C97!T97)E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*
M;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@(E9O;W)L;W!I
M9R!G96%C8V5P=&5E<F0B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O
M9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G
M<W1R(")'96)R=6EK97)S;W9E<F5E;FMO;7-T(&YI970@;W!G96=E=F5N(&EN
M(&-O;F8N<&AP(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C,P"B,L(&9U>GIY"FUS9VED(")497AT(@IM<V=S='(@(E1?96MS="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-30*;7-G:60@(E1H92!&<F]M.B!C
M;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#HB"FUS9W-T
M<B`B1&4@5F%N.B!K;VQO;2!V86X@:&5T(&)E<FEC:'0@9&EE;G0@9V5L:6YK
M="!T92!W;W)D96XZ(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,S(*;7-G
M:60@(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P
M<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0
M;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q
M"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B
M2&5T($UA8VEN=&]S:"!B<F]N<')O8V5S(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N
M(@IM<V=S='(@(DAE="!-86-I;G1O<V@@8G)O;G!R;V-E<R!K86X@=V]R9&5N
M(&=E9&]W;FQO860@)7,N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")$92!A8V-O=6YT(%PB)7-<(B!I<R!V97)W
M:6ID97)D+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HW-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@<V%V960N
M(@IM<V=S='(@(D1E(&%C8V]U;G0@7"(E<UPB(&ES(&]P9V5S;&%G96XN(@H*
M(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT('=A
M<R!N;W0@9F]U;F0N(@IM<V=S='(@(D1E(&)I:FQA9V4@:7,@;FEE="!G979O
M;F1E;BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CD*(RP@9G5Z
M>GD*;7-G:60@(E1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T
M<B`B/&(^1&4@86=E;F1A9&%T82!I<R!O;F=E;&1I9SPO8CXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED
M("(B"B)4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H
M87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P
M=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB2&5T(%PB3FEE=7<@8F5R:6-H=%PB
M('-C:&5R;2!K86X@;FEE="!W;W)D96X@9V5O<&5N9"X@36ES<V-H:65N(&AE
M969T('4@=7<@(@HB8G)O=W-E<B!I;F=E<W1E;&0@;VT@<&]P=7`@<V-H97)M
M96X@=&4@8FQO:VME<F5N/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O
M=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT
M;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G<W1R(")$92!I;FAO=60@=F%N(&AE
M="!-86-I;G1O<VAB97-T86YD('-T86%T(&AI97)O;F1E<BXB"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z
M.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I
M(%PB)7-<(B!W:6QL(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")$
M92!H=6ED:6=E(&UA<"AP96XI(%PB)7-<(B!Z=6QL96X@=V]R9&5N(&AE<FYO
M96UD('1O="!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P
M-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C
M8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM
M<V=S='(@(B(*(D1E(&AU:61I9V4@;&EJ<W0@;65T(&=E8G)U:6ME<G,@;65T
M('1O96=A;F<@;W`@9&5Z92!M87`@:V]N(&YI970@=V]R9&5N("(*(F]P9V5H
M86%L9"(*"B,Z(&-O;7!O<V4N<&AP.C$R,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92!<(B5S7"(@9F]L
M9&5R+B(*;7-G<W1R(")(970@:VQA9"!I<R!O<&=E<VQA9V5N(&EN(&1E(%PB
M)7-<(B!M87`N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S.0IM
M<V=I9"`B5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*
M;7-G<W1R(")$92!G96)E=7)T96YI<R!I<R!A86X@=7<@86=E;F1A('1O96=E
M=F]E9V0N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEE;&0@7"(E<UPB(&-A
M;B=T(&)E(&5X<&%N9&5D+B(*;7-G<W1R(")(970@=F5L9"`G)7,G(&MA;B!N
M:65T('=O<F1E;B!U:71G96ML87!T+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!A;')E
M861Y(&5X:7-T<R(*;7-G<W1R(")$92!M87`@7"(E<UPB(&)E<W1A870@86PB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T
M97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O8FQE;7,N(%!L
M96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@HB1&4@;6%P;F%A;2!<(B5S7"(@8F5V870@;VYG96QD:6=E(&MA<F%K=&5R
M<RX@1&ET('IO=2!P<F]B;&5M96X@:W5N;F5N("(*(G9E<F]O<GIA:V5N+B!.
M965M(&-O;G1A8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(L(&$N=2YB
M+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@
M;F]T('-U8G-C<FEB960@=&\@:70N(@IM<V=S='(@(D1E(&UA<"!<(B5S7"(@
M=V5R9"!A86YG96UA86MT(&UA87(@=2!H965F="!D97IE(&YI970@:6YG97-C
M:')E=F5N+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@9&5L971E9"!B=70@>6]U
M('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+B(*;7-G<W1R(")$92!M
M87`@7"(E<UPB('=E<F0@=F5R=VEJ9&5R9"P@;6%A<B!U(&AE969T(&1E>F4@
M;FEE="!U:71G97-C:')E=F5N+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,T,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T
M(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B1&4@;6%P(%PB)7-<(B!W97)D(&YI970@86%N9V5M86%K="X@1&4@<V5R
M=F5R(&UE;&1T(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C8U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T(&1E
M;&5T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B
M1&4@;6%P("<E<R<@=V5R9"!N:65T('9E<G=I:F1E<F0N($1E('-E<G9E<B!M
M96QD="(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T
M960N(@IM<V=S='(@(D1E(&UA<"!<(B5S7"(@=V5R9"!M970@<W5C8V5S(&%A
M;F=E;6%A:W0N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@
M9&5L971E9"XB"FUS9W-T<B`B1&4@;6%P(%PB)7-<(B!W97)D(&UE="!S=6-C
M97,@=F5R=VEJ9&5R9"XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B1&4@;6%P(%PB)7-<
M(B!W97)D(&UE="!S=6-C97,@:&5R;F]E;60@=&]T(%PB)7-<(BXB"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I
M;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@
M(D1E('9O;&=E;F1E(&)E<W1A;F1E;B!W87)E;B!G96MO<'!E;&0@86%N(&1I
M="!O;F1E<F1E96PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]S
M879E:6UA9V5?=VEN+FIS.C$R"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@:6UA
M9V4@<V%V92!W:6YD;W<@8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U
M(&AA=F4@<V5T('EO=7(@8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U<"!W:6YD
M;W=S/R(*;7-G<W1R("(B"B)(970@7").:65U=R!B97)I8VAT7"(@<V-H97)M
M(&MA;B!N:65T('=O<F1E;B!G96]P96YD+B!-:7-S8VAI96X@:&5E9G0@=2!U
M=R`B"B)B<F]W<V5R(&EN9V5S=&5L9"!O;2!P;W!U<"!S8VAE<FUE;B!T92!B
M;&]K:V5R96X_(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"FUS
M9VED("(B"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@
M=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN
M(@IM<V=S='(@(B(*(D1E(&%F8F5E;&1I;F=E;B!W;W)D96X@=V5E<F=E=F5N
M+"!O;61A="!D92!A9GIE;F1E<B!Z:6-H(&EN('5W(&%D<F5S8F]E:R`B"B)B
M979I;F1T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS
M9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@
M97)R;W(@;65S<V%G93HB"FUS9W-T<B`B1&4@;6%I;'-E<G9E<B!G96YE<F5E
M<F1E(&AE="!V;VQG96YD92!F;W5T8F5R:6-H=#HB"@HC.B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0IM<V=I9"`B5&AE(&UA:6P@<V5R
M=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S
M<V%G93HB"FUS9W-T<B`B1&4@;6%I;'-E<G9E<B!G96YE<F5E<F1E(&AE="!V
M;VQG96YD92!I;F9O<FUA=&EE8F5R:6-H=#HB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R
M871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(D1E(&UA:6QS
M97)V97(@9V5N97)E97)D92!H970@=F]L9V5N9&4@8F5R:6-H=#HB"@HC.B!L
M:6(O365S<V%G92YP:'`Z-C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M
M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(D1E(&UA:6QB
M;W@@)7,@:7,@86P@;&5E9RXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@
M7"(E<UPB("@E9"!B>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI;6ET+B(*
M;7-G<W1R("(B"B)(970@8F5R:6-H="!<(B5S7"(@=F%N(%PB)7-<(B`H)60@
M8GET97,I(&]V97)S8VAR:6ID="!D92!O<&AA86QG<F]O='1E("(*(FQI;6EE
M="XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PIM
M<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO
M<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")(970@8F5W97)K=&4@8F5R:6-H="!I
M<R!A9F=E<VQO=&5N+B!!9G-L=6ET96XN(@H*(SH@;65S<V%G92YP:'`Z,30X
M"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(")(970@8F5R:6-H="!I<R!V97)W:6ID97)D+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C,Y,PIM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@
M=F5R:69I960N(@IM<V=S='(@(DAE="!B97)I8VAT(&ES(&=E=F5R:69I965R
M9"XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"X@
M4V5N9&5R.B`E<RXB"FUS9W-T<B`B2&5T(&)E<FEC:'0@:7,@9V5V97)I9FEE
M97)D+B!!9GIE;F1E<CH@)7,N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+V]P96Y?
M<VUI;65?=VEN+FIS.C$P('1E;7!L871E<R]P9W`O;W!E;E]P9W!?=VEN+FIS
M.C$P"FUS9VED("(B"B)4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@
M;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@
M(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB2&5T('=A8VAT
M=V]O<F0@<V-H97)M(&MA;B!N:65T('=O<F1E;B!G96]P96YD+B!-:7-S8VAI
M96X@:&5E9G0@=2!U=R!B<F]W<V5R("(*(FEN9V5S=&5L9"!O;2!P;W!U<"!S
M8VAE<FUE;B!T92!B;&]K:V5R96X_(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!R87<@=&5X="!O
M9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T
M<B`B1&4@<G5W92!T96MS="!V86X@9&4@;W!E;F)A<F4@4$=0('-L975T96P@
M:V%N('=O<F1E;B!B96ME:V5N("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T
M;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T
M(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(DAE
M="!G979R86%G9&4@8F5S=&%N9"!B97-T86%T(&YI970@:6X@9&4@35,M5$Y%
M1B!B:6IL86=E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"FUS
M9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE
M(%II<"!A='1A8VAM96YT+B(*;7-G<W1R(")(970@9V5V<F%A9V1E(&)E<W1A
M;F0@8F5S=&%A="!N:65T(&EN(&1E(%II<"!B:6IL86=E+B(*"B,Z(&UE<W-A
M9V4N<&AP.C4T-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R
M(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V
M92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@
M=&AE("(*(FYO=&EF:6-A=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"B)$92!A
M9GIE;F1E<B!V86X@9&ET(&)E<FEC:'0@=G)A86=T('4@;VT@965N(&]N='9A
M;F=S=&)E=F5S=&EG:6YG+"!W86YN965R('4@(@HB9&ET(&)E<FEC:'0@:&5E
M9G0@9V5L97IE;BX@2VQI:R!O<"`E<R!O;2!D92!O;G1V86YG<W1B979E<W1I
M9VEN9R!T92`B"B)V97)Z96YD96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(E1H92!S97)V97(@=V%S(&YO
M="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*
M;7-G<W1R(")+;&EK(&]P("5S(&]M(&5E;B!T:'5M8FYA:6P@=F%N(&1E>F4@
M869B965L9&EN9R!W965R('1E(&=E=F5N+B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:G,Z,3`T"FUS9VED(")4:&4@<VEG;F%T=7)E(&-O=6QD
M(&YO="!B92!R97!L86-E9"XB"FUS9W-T<B`B1&4@;VYD97)T96ME;FEN9R!K
M;VX@;FEE="!W;W)D96X@=F5R=F%N9V5N+B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:G,Z,3`R"FUS9VED(")4:&4@<VEG;F%T=7)E('=A<R!S
M=6-C97-S9G5L;'D@<F5P;&%C960N(@IM<V=S='(@(D1E(&]N9&5R=&5K96YI
M;F<@:7,@;65T('-U8V-E<R!V97)V86YG96XN(@H*(SH@871T86-H;65N="YP
M:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B2&5T(&]P9V5G979E;B!B97-T86YD(&)E<W1A870@;FEE
M="XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&%D9&5D
M+B(*;7-G<W1R(")$92!A8V-O=6YT(%PB)7-<(B!I<R!O<&=E<VQA9V5N+B(*
M"B,Z('-T871I;VYE<GDN<&AP.C8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B1&4@86-C;W5N="!<(B5S7"(@:7,@=F5R=VEJ9&5R9"XB"@HC
M.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N('5P9&%T960N(@IM
M<V=S='(@(D1E(&%C8V]U;G0@7"(E<UPB(&ES('9E<G=I:F1E<F0N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V.0IM<V=I9"`B5&AE('1A<VL@
M:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B1&4@
M=&%A:R!I<R!A86X@=7<@=&%A:VQI:G-T('1O96=E=F]E9V0N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G:60@(E1H92!T97AT(&]F
M('1H92!M97-S86=E(@IM<V=S='(@(D1E('1E:W-T('9A;B!H970@8F5R:6-H
M="(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(D1E('1E:W-T('9A;B!H970@8F5R:6-H="!K
M86X@=V]R9&5N(&)E:V5K96X@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z.#`*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M
M97-S86=E(@IM<V=S='(@(D1E('1E:W-T('9A;B!H970@9V5R971O=7)N965R
M9"!B97)I8VAT(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D
M(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B1&4@=&5K<W0@
M=F%N(&AE="!G97)E=&]U<FYE97)D(&)E<FEC:'0@:V%N('=O<F1E;B!B96ME
M:V5N("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP
M.C8X"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S
M='(@(D1E('1E:W-T('9A;B!H970@=F5R>F]N9&5N(&)E<FEC:'0B"@HC.B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B
M92!V:65W960@)7,N(@IM<V=S='(@(D1E('1E:W-T('9A;B!H970@=F5R>F]N
M9&5N(&)E<FEC:'0@:V%N('=O<F1E;B!B96ME:V5N("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ-30*;7-G:60@(E1H92!U<V5R)W,@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM
M<V=S='(@(D1E('9R:6HO8F5Z970@:6YF;W)M871I92!V86X@9&4@9V5B<G5I
M:V5R(&ES(&UE="!S=6-C97,@;W!G97-L86=E;BXB"@HC.B!L:6(O34E-12]6
M:65W97(O86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@
M86QT97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92XB"FUS9W-T<B`B(@HB17(@>FEJ;B!G965N(&%L=&5R;F%T:65V92!O;F1E
M<F1E;&5N(&1I92!I;FQI;F4@=V5E<F=E9V5V96X@:W5N;F5N('=O<F1E;BXB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS"FUS
M9VED(")4:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*
M;7-G<W1R(")%<B!Z:6IN(&=E96X@8F5R:6-H=&5N(&EN(&1E>F4@;6%I;&)O
M>"XB"@HC.B!T:')E860N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G
M<W1R("(B"B)%<B!Z:6IN(&=E96X@86QT97)N871I979E(&]N9&5R9&5L96X@
M9&EE(&EN;&EN92!W965R9V5G979E;B!K=6YN96X@=V]R9&5N+B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HV,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B165N(&9O=70@8FEJ(&AE="!S8VAR87!P
M96X@=F%N("5S+B!$92!S97)V97(@;65L9'0B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@<V5R=F5R('-A:60Z("5S
M(@IM<V=S='(@(D5E;B!F;W5T(&)I:B!H970@=6ET=VES<V5N('9A;B!D92!M
M86EL8F]X+B!$92!S97)V97(@;65L9'0Z("5S(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C8R,0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@
M=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS
M9W-T<B`B165N(&9O=70@8FEJ(&AE="!U:71W:7-S96X@=F%N(&1E(&UA:6QB
M;W@N($1E('-E<G9E<B!M96QD="(*"B,Z(&QI8B]-97-S86=E+G!H<#HY,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@8V]P
M>6EN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@
M=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB165N(&9O=70@
M8FEJ(&AE="!K;W!IZW)E;B!V86X@8F5R:6-H=&5N('9A;B!<(B5S7"(@;F%A
M<B!<(B5S7"(N($1E('-E<G9E<B`B"B)M96QD="(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HQ.3@@;&EB+TUE<W-A9V4N<&AP.C(Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@
M9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T("(*(G1H92!S
M97)V97(@<V%I9"(*;7-G<W1R("(B"B)%96X@9F]U="!B:6H@:&5T('9E<G=I
M:F1E<F5N('9A;B!B97)I8VAT96X@=6ET(&1E(&UA<"!<(B5S7"(N($1E('-E
M<G9E<B!M96QD="(*"B,Z(&QI8B]-97-S86=E+G!H<#HR-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE
M<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE
M("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(D5E;B!F;W5T(&)I:B!H970@
M=F5R=VEJ9&5R96X@=F%N(&)E<FEC:'1E;B!I;B!D92!M87`@7"(E<UPB+B!$
M92!S97)V97(@;65L9'0B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS
M9W-T<B`B165N(&9O=70@8FEJ(&AE="!V97)W:6ID97)E;B!V86X@8F5R:6-H
M=&5N+B!$92!S97)V97(@;65L9'0Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")%96X@
M9F]U="!B:6H@:&5T('9E<G=I:F1E<F5N('9A;B!D92!G96)E=7)T96YI<SH@
M)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-
M12]6:65W97(O96YR:6-H960N<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")%
M96X@9F]U="!B:6H@:&5T(&)E:VEJ:V5N('9A;B!D:70@8F5R:6-H=&]N9&5R
M9&5E;"(*"B,Z(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A9V4N<&AP
M.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H
M:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB165N
M(&9O=70@8FEJ(&AE="!M87)K97)E;B!V86X@8F5R:6-H=&5N(&EN(&1E(&UA
M<"!<(B5S7"(N($1E('-E<G9E<B!M96QD="(*"B,Z(&9O;&1E<G,N<&AP.C$V
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG("5S+B(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R
M96X@=F%N("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T
M(&EM<&]R=&5R96X@=F%N(&1E(&=E8F5U<G1E;FES.B`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,38V"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*
M;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R96X@=F%N(&1E('1A
M86LZ("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`B
M(@HB165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!V<FEJ+V)E>F5T
M(&EN9F]R;6%T:64@=F%N(&1E(&=E8G)U:6ME<CH@)7,N(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E
M<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@
M(B(*(D5E;B!F;W5T(&)I:B!H970@=F5R<&QA871S96X@=F%N(&)E<FEC:'1E
M;B!V86X@7"(E<UPB(&YA87(@7"(E<UPB+B!$92!S97)V97(@(@HB;65L9'0B
M"@HC.B!C;VUP;W-E+G!H<#HQ,C0T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T+B(*;7-G<W1R(")%
M96X@9F]U="!B:6H@:&5T(&]P<VQA86X@=F%N(&1I="!B97)I8VAT(&%L<R!K
M;&%D+B(*"B,Z(&-O;7!O<V4N<&AP.C$P,#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E
M<R(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T('9E<GIE;F1E;B!V86X@=7<@
M8F5R:6-H=#H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")%96X@9F]U="!M970@:&5T
M(&)I:G=E<FME;B!V86X@9&4@9V5B975R=&5N:7,Z("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*;7-G:60@(E1H97)E('=A<R!N;R!T
M97AT(&EN('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D5R('-T;VYD(&=E
M96X@=&5K<W0@:6X@9&ET(&)E<FEC:'1O;F1E<F1E96PB"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z.3<*;7-G:60@(E1H:7,@2%1-3"!M97-S86=E
M(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM<V=S='(@(D1I="!(5$U,
M(&)E<FEC:'0@8F5V870@869B965L9&EN9V5N+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HY,`IM<V=I9"`B(@HB5&AI<R!(5$U,(&UE<W-A9V4@
M:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P
M96%R(&QI:V4@(@HB=&AI<SH@(@IM<V=S='(@(B(*(D1I="!(5$U,(&)E<FEC
M:'0@8F5V870@869B965L9&EN9V5N+B!'96)L;VMK965R9&4@869B965L9&EN
M9V5N('9E<G-C:&EJ;F5N("(*(F%L<R!V;VQG=#H@(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y
M('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B1&5Z92!O
M<&5N8F%R92!01U`@<VQE=71E;"!I<R!G96MO<'!E;&0@;65T(&AE="!B97)I
M8VAT+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#0@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$Q.`HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,30S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3<*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,R!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,S$T"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D
M+B(*;7-G<W1R(")$97IE(&)E=V5R:VEN9R!W;W)D="!N:65T(&]N9&5R<W1E
M=6YD+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@
M;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B1&5Z92!B97=E<FMI;F<@
M:7,@;F]G(&YI970@=F%N('1O97!A<W-I;F<N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S
M;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B
M"FUS9W-T<B`B1&ET(&MA;B!E;FEG92!T:6ID(&1U<F5N+B!7965T('4@>F5K
M97(@9&%T('4@=F5R9&5R('=I;'0@9V%A;C\B"@HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N
M=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS9W-T<B`B1&ET(&)E<FEC:'0@
M8F5V870@965N($UA8VEN=&]S:&)E<W1A;F0N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HT,3`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT
M86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I
M9VYE9"!V:6$@4R\B"B)-24U%+B(*;7-G<W1R(")$:70@8F5R:6-H="!B979A
M="!E96X@8FEJ;&%G92!D:64@9&EG:71A86P@=FEA(%,O34E-12!I<R!O;F1E
M<G1E:V5N9"XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q-`IM
M<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA
M="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B1&ET
M(&)E<FEC:'0@8F5V870@965N(&)I:FQA9V4@9&EE('9I82!3+TU)344@:7,@
M9V5C;V1E97)D+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V
M,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E
M<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B`B"B)T
M:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T<B`B(@HB1&ET(&)E<FEC
M:'0@8F5V870@869L979E<FEN9W-S=&%T=7-I;F9O<FUA=&EE+"!M86%R(&AE
M="!F;W)M86%T('9A;B!D:70@(@HB8F5R:6-H="!I<R!O;F)E:V5N9"XB"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,34*;7-G:60@(B(*(E1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC
M<GEP=&5D(&UE<W-A9V4N($5R<F]R.B`B"FUS9W-T<B`B(@HB1&ET(&)E<FEC
M:'0@;&EJ:W0@;FEE="!H970@965N(&=E;&1I9R!01U`@9V5C;V1E97)D(&)E
M<FEC:'0@=&4@>FEJ;BX@1F]U=#H@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,C0P(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,U,`IM<V=I9"`B
M(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@
M8V]R<F5C="!01U`@9F]R;6%T("AA8V-O<F1I;F<@=&\@(@HB4D9#(#(P,34I
M+B(*;7-G<W1R("(B"B)$:70@8F5R:6-H="!L:6IK="!N:65T(&AE="!J=6ES
M=&4@4$=0(&9O<FUA870@=&4@:&5B8F5N("AV;VQG96YS(%)&0R`R,#$U*2XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI
M<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C
M="!3+TU)344@9F]R;6%T+B(*;7-G<W1R(")$:70@8F5R:6-H="!L:6IK="!N
M:65T(&AE="!J=6ES=&4@4R]-24U%(&9O<FUA870@=&4@:&5B8F5N+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HT,38*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I
M=&%L;'D@<VEG;F5D('9I82!01U`N(@IM<V=S='(@(DAE="!V;VQG96YD92!B
M97)I8VAT(&ES(&1I9VET86%L(&]N9&5R=&5K96YD('9I82!01U`N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S
M<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM
M<V=S='(@(DAE="!V;VQG96YD92!B97)I8VAT(&ES(&1I9VET86%L(&]N9&5R
M=&5K96YD('9I82!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HQ,SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@
M(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB
M"FUS9W-T<B`B1&ET(&)E<FEC:'0@:7,@9V5C;V1E97)D(&UE="!3+TU)344N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`Q(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C(Y,0IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N
M(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`B1&ET(&)E<FEC:'0@:7,@
M9V5C;V1E97)D(&UE="!01U`N(@H*(SH@;65S<V%G92YP:'`Z,C$Q"FUS9VED
M(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T<B`B1&ET(&)E<FEC:'0@;F%A<B(*
M"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$97IE('-E<G9E<B!O
M;F1E<G-T975N="!G965N(&1E;&EN9R!V86X@;6%P<&5N+B(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y"FUS9VED(")4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N(@IM
M<V=S='(@(B(*(D1I="!S8VAE<FT@9&EE;G0@86%N9V5R;V5P96X@=&4@=V]R
M9&5N('9A;G5I="!H970@;FEE=7<@8F5R:6-H="!S8VAE<FTN(@H*(SH@=&AR
M96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM
M<V=S='(@(E=E97)G979E;B(*"B,Z('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR,@IM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B
M5&AR96%D=V5E<F=A=F4B"@HC.B!M97-S86=E+G!H<#HR-C0@;6%I;&)O>"YP
M:'`Z-C`V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C$Y"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C(@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C8Q"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W)E8V]M<&]S92YI;F,Z,3`@;&EB+U-E87)C:"YP:'`Z,C8*;7-G
M:60@(E1O(@IM<V=S='(@(D%A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,3D*;7-G:60@(E1O($%D9')E<W,B"FUS9W-T<B`B1V5A9')E<W-E97)D
M92(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C
M;&EC:VEN9RXB"FUS9W-T<B`B(@HB3VT@;65E<F1E<F4@=F5L9&5N('1E('-E
M;&5C=&5R96XL(&AO=60@9&4@0V]N=')O;"`H4$,I(&]F($-O;6UA;F0@*$UA
M8RD@(@HB=&]E=',@:6YG961R=6MT('1I:F1E;G,@:VQI:VME;BXB"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C$S-`IM<V=I9"`B(@HB5&\@=7-E(&$@5$Q3
M(&-O;FYE8W1I;VXL('EO=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F
M(%!(4"`U+C`N-B!O<B`B"B)H:6=H97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B5&]T86P@071T
M86-H;65N=',@4VEZ93HB"FUS9W-T<B`B5&]T86QE(&)I:FQA9V5G<F]O='1E
M.B(*"B,Z(&9O;&1E<G,N<&AP.C,X.`IM<V=I9"`B5')A<V@@9F]L9&5R(@IM
M<V=S='(@(E!R=6QL96YB86LB"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS
M96QE8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM<V=S='(@(E!R
M=6QL96YB86LZ(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV-2!L:6(O475O
M=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N9"YP:'`Z-S(*
M(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T82]C;W5R:65R
M+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*;7-G:60@(E5N86)L
M92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R(").:65T(&EN('-T86%T(&]M
M('%U;W1A(&]P('1E(&AA;&5N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G
M:60@(E5N86YS=V5R960B"FUS9W-T<B`B3VYB96%N='=O;W)D(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M
M97-S86=E<R(*;7-G<W1R(")/;F)E86YT=V]O<F1E(&)E<FEC:'1E;B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T92(*
M;7-G<W1R(")497)U9VAA;&5N(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y(&UA:6QB
M;W@N<&AP.C8P,B!L:6(O34E-12](96%D97)S+G!H<#HR,3(*;7-G:60@(E5N
M9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`B3VYB96ME;F1E(&]N='9A
M;F=E<G,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#0W"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@
M)7,B"FUS9W-T<B`B3FEE="!V97)W97)K="!O;F1E<F1E96P@=F%N('1Y<&4Z
M("5S(@H*(SH@;6%I;&)O>"YP:'`Z-38U"FUS9VED(")5;FMN;W=N($1A=&4B
M"FUS9W-T<B`B3VYB96ME;F1E(&1A='5M(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E
M<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8S-0IM
M<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@(D]N8F5K96YD92!V97)G
M861E<FEN9R(*"B,Z(&UA:6QB;W@N<&AP.C8Q.`IM<V=I9"`B56YK;F]W;B!2
M96-I<&EE;G0B"FUS9W-T<B`B3VYB96ME;F1E(&]N='9A;F=E<B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C<W"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*;7-G<W1R(")786-H
M='=O;W)D<F5G96P@;&]S<V5N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(D]N8F5N;V5M9"(*"B,Z(&UE<W-A
M9V4N<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E
M;B(*;7-G<W1R(")/;F=E>FEE;B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C$R"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS
M*2(*;7-G<W1R(")5:71S8VAR:6IV96X@=F%N(&UA<"AP96XI(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@T"FUS9VED(")5<&1A=&4@
M071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R(")":6IL86=E:6YF;W)M
M871I92!B:6IW97)K96XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C(P"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B
M0F5A;G1W;V]R9&5R<W1A='5S(&)I:G=E<FME;B(*"B,Z('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K
M97DN:6YC.C4V"FUS9VED(")5<&QO860B"FUS9W-T<B`B57!L;V%D(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B
M57-E($1E9F%U;'0@5F%L=64B"FUS9W-T<B`B1V5B<G5I:R!S=&%N9&%A<F1W
M86%R9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED(")5
M<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T<B`B24U!4"!M
M87!I;G-C:')I:G9I;F=E;B!G96)R=6EK96X_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<S-0HC+"!F=7IZ>0IM<V=I9"`B57-E(%9I<G1U86P@5')A
M<V@@1F]L9&5R/R(*;7-G<W1R(")6:7)T=65L92!M87!P96XB"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,30R"FUS9VED(")5<V5R(@IM<V=S='(@(D=E
M8G)U:6ME<B(*"B,Z(&%C;"YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@
M<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(B(*(D=E8G)U:6ME<B`G)7,G(&UE="!S=6-C97,@9&4@;W!G96=E=F5N
M(')E8VAT96X@=&]E9V5K96YD('9O;W(@9&4@;6%P("<E<R<N(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-S<*;7-G:60@(E5S97)N86UE(@IM
M<V=S='(@(D=E8G)U:6ME<G-N86%M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B1V5B
M<G5I:V5R<VYA86TZ(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR
M-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S<*;7-G:60@(E9I97<B"FUS9W-T<B`B0F5K:6IK96XB"@HC.B!L:6(O
M34E-12]6:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B
M)7,@8F5K:6IK96XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B)7,@;W!E;F)A<F4@<VQE
M=71E;"!B96MI:FME;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ
M,38*;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN
M9&]W(@IM<V=S='(@(DA434P@:6YH;W5D(&EN(&5E;B!A<&%R="!S8VAE<FT@
M8F5K:6IK96XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR
M.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R(").:65U
M=V4@8F5R:6-H=&5N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW
M,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N
M86P@4')I=F%T92!+97DB"FUS9W-T<B`B4&5R<V]O;FQI:FME('!R:79E('-L
M975T96P@8F5K:6IK96XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE=R!097)S
M;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!E<G-O;VYL:6IK92!O<&5N8F%R
M92!S;&5U=&5L(&)E:VEJ:V5N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R
M(")4:')E860@8F5K:6IK96XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38U"FUS9VED
M(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R(")"96MI:FL@=&AU;6)N86EL(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*;7-G:60@(E9I97<@
M871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")":6IL
M86=E(&EN(&5E;B!A<&%R="!S8VAE<FT@8F5K:6IK96XB"@HC.B!L:6(O34E-
M12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")(5$U,(&EN
M:&]U9"!I;B!E96X@87!A<G0@<V-H97)M(&)E:VEJ:V5N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B5FEE=R!E=F5N="(*;7-G
M<W1R(")"96MI:FL@9V5B975R=&5N:7,B"@HC.B!F;VQD97)S+G!H<#HS.#`@
M;6%I;&)O>"YP:'`Z-3,T"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@;65S
M<V%G97,@:6X@)7,B"FUS9W-T<B`B0F5K:6IK(&)E<FEC:'1E;B!I;B`E<R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,C,*
M;7-G:60@(E9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M.B(*;7-G<W1R(")7965R9V%V92!V86X@;6%I;&)O>"!N82!A86YM96QD:6YG
M.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S`*;7-G:60@(E9I
M97<@=&%S:R(*;7-G<W1R(")"96MI:FL@=&%A:R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HQ,#$*;7-G:60@(E9I97<@=&AE($EM86=E<R(*;7-G
M<W1R(")"96MI:FL@9&4@8F5R:6-H=&5N(@H*(SH@<V5A<F-H+G!H<#HR-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FER='5A;"!&;VQD97(@7"(E<UPB(&-R
M96%T960@<W5C8V5S9G5L;'DN(@IM<V=S='(@(D1E('9I<G1U96QE(&UA<"!<
M(B5S7"(@=V5R9"!M970@<W5C8V5S(&%A;F=E;6%A:W0N(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E92YP:'`Z,3,X
M(&QI8B])34%0+U1R964N<&AP.C$U,0HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ
M-3,@;&EB+TE-05`O5')E92YP:'`Z,34W(&QI8B])34%0+U1R964N<&AP.C$U
M.`HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-CD@;&EB+TE-05`O5')E92YP:'`Z
M,SDS(&QI8B])34%0+U1R964N<&AP.C0S,PIM<V=I9"`B5FER='5A;"!&;VQD
M97)S(@IM<V=S='(@(E9I<G1U96QE(&UA<'!E;B(*"B,Z('-E87)C:"YP:'`Z
M,C0U"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A
M(&QA8F5L+B(*;7-G<W1R(").86%M('9O;W(@=FER='5E;&4@;6%P(@H*(SH@
M;&EB+U9&;VQD97(N<&AP.C$W-2!L:6(O5D9O;&1E<BYP:'`Z,3@P"FUS9VED
M(")6:7)T=6%L($E.0D]8(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q
M-@HC+"!F=7IZ>0IM<V=I9"`B5FER='5A;"!)3D)/6"!&;VQD97(B"FUS9W-T
M<B`B5FER='5E;&4@;6%P<&5N(@H*(SH@;6%I;&)O>"YP:'`Z-#4R(&QI8B]6
M1F]L9&5R+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0HC+"!F=7IZ>0IM
M<V=I9"`B5FER='5A;"!4<F%S:"(*;7-G<W1R(")6:7)T=65L92!M87!P96XB
M"@HC.B!F;VQD97)S+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(E9I<G1U86P@
M5')A<V@@1F]L9&5R(@IM<V=S='(@(E9I<G1U96QE(&UA<'!E;B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3,S"FUS9VED(")6:7)T=6%L(&9O
M;&1E<B!L86)E;"(*;7-G<W1R(").86%M('9O;W(@=FER='5E;&4@;6%P(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S0*(RP@9G5Z>GD*;7-G
M:60@(E=A<FYI;F<B"FUS9W-T<B`B56ET:VQA<'!E;B`N+BXB"@HC.B!L;V=I
M;BYP:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B
M"FUS9W-T<B`B5V5L:V]M(&)I:B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV,3D*(RP@9G5Z>GD*;7-G:60@(B(*(E=H870@<VAO=6QD('=E(&1O
M('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O
M<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G<W1R(")697)W:6ID
M97(@<W!A;6)E<FEC:'1E;B!N861A="!D97IE(&%L<R!S<&%M('II:FX@9V5R
M87!P;W)T965R9#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(W"FUS
M9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@
M>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H96T@
M87,@9&5L971E9#\B"FUS9W-T<B`B(@HB5F5R<&QA871S('9E<G=I:F1E<F1E
M(&)E<FEC:'1E;B!N86%R(&1E('!R=6QL96YB86LL(&DN<"YV+B!D97IE(&%L
M<R`B"B)V97)W:6ID97)D('1E(&UA<FME<F5N/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,#<*;7-G:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL
M8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N/R(*;7-G
M<W1R(")/<"!W96QK92!P86=I;F$L(&)I:B!O<&5N96X@=F%N(&5E;B!N:65U
M=V4@;6%I;&)O>"P@=VEL="!U(&)E9VEN;F5N/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-C$*;7-G:60@(E=H96X@<V%V:6YG('-E;G0M;6%I;"P@
M<VAO=6QD('=E('-A=F4@871T86-H;65N="!D871A/R(*;7-G<W1R("(B"B)$
M:65N="!B:6H@;W!S;&%A;B!V86X@=F5R>F]N9&5N(&UA:6PL(&)I:FQA9V5D
M871A(&]P9V5S;&%G96X@=&4@=V]R9&5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN9R!M86EL(&]R(&5X
M<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E
M;F0@=&\@(@HB=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S
M97,@=VET:&]U="!<(D!<(BD_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@(E=I
M='1E(&QI:G-T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@(EEE<R(*;7-G
M<W1R(")*82(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L
M;V=I;BYP:'`Z-3@*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA
M:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(E4@
M9V%A="!E+6UA:6P@=F%N(&1E('9O;&=E;F1E(&%C8V]U;G0H<RD@;W!H86QE
M;CHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M
M;#HQ,`HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U(&%R92!A='1E;7!T:6YG('1O
M(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I
M;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R(")5('!R;V)E97)T(&1E('9O;&=E
M;F1E(&UA<'!E;B!T92!V97)W:6ID97)E;CHB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HY"B,L(&9U>GIY"FUS9VED(")9
M;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F;VQL;W=I;F<@9F]L
M9&5R*',I+B(*;7-G<W1R(")5('!R;V)E97)T(&1E('9O;&=E;F1E(&UA<'!E
M;B!T92!V97)W:6ID97)E;CHB"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A
M<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHQ.3(*;7-G:60@(EEO=2!A<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@
M9F]L9&5R+B(*;7-G<W1R(")5(&MO<&EE97)T+W9E<G!L86%T<W0@;F%A<B!E
M96X@;FEE=7=E(&UA<"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$P,@IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD
M97(@=&\@(@IM<V=S='(@(E4@;6%A:W0@965N('-U8FUA<"!I;B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B66]U
M(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N(@IM<V=S='(@(E4@
M;6%A:W0@965N(&AO;V9D;6%P+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R,`HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M9F]L9&5R<RXB"FUS9W-T<B`B52!M86%K="!E96X@:&]O9F1M87`N(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,S(W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C$S-0IM<V=I9"`B66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B`B
M"FUS9W-T<B`B52!H97)N;V5M="!D92!M87`Z("(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A;B!N
M;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(E4@:&5E9G0@
M7"(E<UPB(&UE="!S=6-C97,@=6ET9V5S8VAR979E;B(*"B,Z('1E;7!L871E
M<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I
M;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*(F-U<G)E;G0@
M;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP
M:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M
M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W
M960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*(E4@8F5N="!N:65T(&%K:V]O
M<F0@9V5G86%N(&UE="!D92!G96)R=6EK97)S;W9E<F5E;FMO;7-T+"!D=7,@
M:7,@:&5T('4@;FEE="`B"B)T;V5G97-T86%N(&]M(&%A;B!T92!M96QD96XN
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V.0IM<V=I9"`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES
M(&9O;&1E<B(*;7-G<W1R(")5(&AE969T(&=E96X@<F5C:'1E;B!O;2!D92!T
M;V5G86YG(&]P(&1E>F4@;6%P('1E('=I:GII9V5N(@H*(SH@;&EB+TUA:6QL
M;V<N<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9F]R=V%R9&5D
M('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE
M;G1S.B`E<RXB"FUS9W-T<B`B(@HB52!H965F="!D:70@8F5R:6-H="!D;V]R
M9V5S='5U<F0@;W`@)25S+"!N86%R(&1E('9O;&=E;F1E(&]N='9A;F=E<G,Z
M("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!H879E("5S(&YE=R!M97-S86=E<RXB"FUS
M9W-T<B`B52!H965F="`E<R!N:65U=V4@8F5R:6-H=&5N+B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED(")9;W4@:&%V92`Q(&YE
M=R!M97-S86=E+B(*;7-G<W1R(")5(&AE969T(#$@;FEE=7<@8F5R:6-H="XB
M"@HC.B!C;VUP;W-E+G!H<#HT.30*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E
M(&%L<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T<B`B52!H965F
M="`Q(&YI975W(&)E<FEC:'0N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:G,Z,3$U"FUS9VED("(B"B)9;W4@:&%V92!A="!L96%S="!O
M;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@=7!L;V%D
M('EE="X@07)E("(*(GEO=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI<R!M
M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N=',_(@IM<V=S='(@(B(*
M(E4@:&5E9G0@=&5N;6EN<W1E(.GI;B!B:6IL86=E(&=E<V5L96-T965R9"!D
M870@=2!N;V<@;FEE="!H965F="!G975P;&]A9"X@(@HB5V5E="!U('IE:V5R
M(&1A="!U(&1I="!B97)I8VAT('=I;'0@=F5R>F5N9&5N('IO;F1E<B!D97IE
M(&)I:FQA9V5N/R(*"B,Z(&QI8B])35`N<&AP.C$P-S0*;7-G:60@(EEO=2!H
M879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R
M(")5(&AE969T(&YI975W92!M86EL(&EN(&1E('9O;&=E;F1E(&UA<#HB"@HC
M.B!L:6(O24U0+G!H<#HQ,#<Y"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I
M;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(E4@:&5E9G0@;FEE
M=7=E(&UA:6P@:6X@9&4@=F]L9V5N9&4@;6%P<&5N.B(*"B,Z(&-O;7!O<V4N
M<&AP.C$U,PIM<V=I9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E
M8VEP:65N="XB"FUS9W-T<B`B52!D:65N="!T96YM:6YS=&4@Z>EN(&]N='9A
M;F=E<B!O<"!T92!G979E;BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HS,#(*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E
M(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G
M92(*;7-G<W1R("(B"B)5(&1I96YT(&1E('=A8VAT=V]O<F1R96=E;"!V86X@
M=7<@<')I=F4@4$=0('-L975T96P@:6X@=&4@=F]E<F5N+"!O;2!D:70@(@HB
M8F5R:6-H="!T92!K=6YN96X@8F5K:6IK96XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C(T.0IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE
M('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I
M97<@=&AI<R`B"B)M97-S86=E(@IM<V=S='(@(B(*(E4@9&EE;G0@9&4@=V%C
M:'1W;V]R9')E9V5L('9A;B!U=R!P<FEV92!3+TU)344@<VQE=71E;"!I;B!T
M92!V;V5R96XL(&]M(&1I="`B"B)B97)I8VAT('1E(&MU;FYE;B!B96MI:FME
M;B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C8T('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(P,0IM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM<V=S='(@
M(E4@9&EE;G0@965R<W0@965N(&1O96QM86EL8F]X(&]P('1E(&=E=F5N+B(*
M"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX-0IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B52!D:65N
M="!E96X@86-C;W5N="!T92!S96QE8W1E<F5N('=E;&ME('4@=VEL="!V97)W
M:6ID97)E;BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C@Q"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB
M"FUS9W-T<B`B52!D:65N="!E97)S="!E96X@861R97,@=&4@<V5L96-T97)E
M;BXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T
M96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8S"FUS9VED(")9;W4@;75S
M="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@
M(E4@9&EE;G0@965R<W0@=&5N;6EN<W1E(.GI;B!B97)I8VAT('1E('-E;&5C
M=&5R96XN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G<W1R
M(")5(&1I96YT(&5E;B!O;G1V86YG97(@;W`@=&4@9V5V96XN(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,CD*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I;&4@=&\@871T86-H+B(*;7-G
M<W1R(")3<&5C:69I8V5E<B!T96YM:6YS=&4@Z>EN(&)E<W1A;F0@;VT@=&4@
M:V]P<&5L96XL(&$N=2YB+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE
M960@=&\@:&%V92!<(B5S7"(@96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E
M(&]P=&EO;G,N(@IM<V=S='(@(E4@9&EE;G0@)R5S)R!I;F=E<V-H86ME;&0@
M=&4@:&5B8F5N(&EN('5W(&]N9&5R:&]U9'-O<'1I97,N(@H*(SH@;&EB+TUA
M:6QL;V<N<&AP.C$S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5D:7)E
M8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+B(*;7-G<W1R(")5(&AE
M969T(&1I="!B97)I8VAT(&1O;W)G97-T=75R9"!N86%R("5S(&]P("4E<RXB
M"@HC.B!L:6(O36%I;&QO9RYP:'`Z,30Q"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RXB"FUS9W-T<B`B
M52!H965F="!D:70@8F5R:6-H="!B96%N='=O;W)D(&]P("5S+B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R
M92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B52!H965F="!<(B5S7"(@;FEE="!I;F=E
M<V-H<F5V96XN($1E('-E<G9E<B!M96QD="(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C4U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@=6YS=6)S
M8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(E4@:&5E9G0@7"(E<UPB(&YI970@=6ET9V5S8VAR979E
M;BX@1&4@<V5R=F5R(&UE;&1T(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3$P"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S
M8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")5(&AE969T(%PB)7-<(B!M970@
M<W5C8V5S(&EN9V5S8VAR979E;B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4V,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS
M=6)S8W)I8F5D(&9R;VT@7"(E<UPB(@IM<V=S='(@(E4@:&5E9G0@7"(E<UPB
M(&UE="!S=6-C97,@=6ET9V5S8VAR979E;B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHY.`IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E5W(&YA86TZ
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4P"FUS9VED(")9;W5R(%!'
M4"!0=6)L:6,O4')I=F%T92!+97ES(@IM<V=S='(@(E5W(&]P96YB87)E+W!R
M:79E(%!'4"!S;&5U=&5L<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-S$@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<V"FUS9VED(")9;W5R(%!R
M:79A=&4@2V5Y(@IM<V=S='(@(E5W('!R:79E('-L975T96PB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW,0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y(@IM<V=S='(@(E5W(&]P96YB
M87)E('-L975T96PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"B,L
M(&9U>GIY"FUS9VED(")9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P
M=&EO;F%L*3PO96T^(@IM<V=S='(@(E5W($%N='=O;W)D(&%A;CH@861R97,Z
M(#QI/BAO<'1I;VYA;"D\+VD^(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHT.0IM<V=I9"`B66]U<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R
M=&EF:6-A=&5S(@IM<V=S='(@(E5W(&]P96YB87)E+W!R:79E(%,O34E-12!C
M97)T:69I8V%T96XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?
M<V5L96-T+FEN8SHQ-@IM<V=I9"`B66]U<B!A8V-O=6YT<SHB"FUS9W-T<B`B
M57<@86-C;W5N=',Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PHC
M+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH
M;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO
M96T^(@IM<V=S='(@(B(*(E5W(&%L:6%S(&%D<F5S<V5N.B`\:3XH;W!T:6]N
M965L+"!E;&L@861R97,@;W`@965N(&YI975W92!R96=E;"!I;G9O97)E;BD\
M+VD^(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y
M(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B57<@8G)O=W-E<B!O;F1E
M<G-T975N="!G965N(&EN;&EN92!W965R9V%V92!V86X@9&ET(&%F8F5E;&1I
M;F=S='EP92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,Y"FUS9VED
M(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SHB
M"FUS9W-T<B`B57<@<W1A;F1A87)D(&MA<F%K=&5R<V5T('9O;W(@:&5T('9E
M<GIE;F1E;B!V86X@8F5R:6-H=&5N.B(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP
M=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(E5W
M('-T86YD86%R9"!V97)S;&5U=&5L:6YG<VUE=&AO9&4@=F]O<B!H970@=F5R
M>F5N9&5N('9A;B!B97)I8VAT96XZ(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z.#D*;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U
M;&QY(&1E;&EV97)E9"XB"FUS9W-T<B`B57<@8F5R:6-H="!W97)D(&UE="!S
M=6-C97,@869G96QE=F5R9"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS9W-T<B`B57<@;VYD97)T
M96ME;FEN9SHB"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S92YP:'`Z,3(X
M-"!M86EL8F]X+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q.`IM<V=I9"`B
M6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM'965N(&]N9&5R=V5R<%TB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*;7-G:60@(E]"8V,B
M"FUS9W-T<B`B7T)C8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ
M-@IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R("):7W=A<G1E(&QI:G-T(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,34T"FUS9VED(")?
M0V,B"FUS9W-T<B`B7T-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B
M7T1E;&5T92(*;7-G<W1R(")697)?=VEJ9&5R96XB"@HC.B!L:6(O24U0+G!H
M<#HY-SD*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@(E]-87!P96XB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,0IM<V=I9"`B7TED96YT
M:71Y(@IM<V=S='(@(E])9&5N=&ET96ET(@H*(SH@;&EB+TE-4"YP:'`Z.38Q
M"FUS9VED(")?26YB;W@B"FUS9W-T<B`B7TEN8F]X(@H*(SH@;&EB+TE-4"YP
M:'`Z,3`R,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7T%F;65L9&5N(@H*
M(SH@;65S<V%G92YP:'`Z,S@T"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS
M9W-T<B`B7T)E<FEC:'1S;W5R8V4B"@HC.B!L:6(O24U0+G!H<#HY-S8*(RP@
M9G5Z>GD*;7-G:60@(E].97<@365S<V%G92(*;7-G<W1R(").:65U=V4@8F5R
M:6-H=&5N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C,S"FUS9VED(")?4')I;G0B"FUS9W-T<B`B05]F9')U:VME;B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.#D*;7-G:60@(E]0<FEO<FET>2(*;7-G
M<W1R(")?4')I;W)I=&5I="(*"B,Z(&UA:6QB;W@N<&AP.C0Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")?4F5F<F5S:"`E<R(*;7-G<W1R(")?5F5R=F5R<R`E
M<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX
M"FUS9VED(")?4F5P;'DB"FUS9W-T<B`B7T)E86YT=V]O<F1E;B(*"B,Z(&QI
M8B])35`N<&AP.CDX,0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?6F]E:V5N
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"FUS9VED(")?4V5N9"!-97-S
M86=E(@IM<V=S='(@(E]697)Z96YD(&)E<FEC:'0B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,R"FUS9VED(")?5&AR96%D
M(@IM<V=S='(@(E]4:')E860B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHQ,38*;7-G:60@(E]4;R(*;7-G<W1R(")?06%N(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@(E]5;F1E;&5T
M92(*;7-G<W1R(")?5&5R=6=H86QE;B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B7U9I97<@5&AR96%D(@IM
M<V=S='(@(E]4:')E860@8F5K:6IK96XB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B5VET=&4@
M;&E?:G-T(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W-@IM<V=I9"`B861D<F5S
M<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0T
M,`IM<V=I9"`B871T86-H;65N="(*;7-G<W1R(")B:6IL86=E(@H*(SH@=FEE
M=RYP:'`Z.3D*;7-G:60@(F%T=&%C:&UE;G1S+GII<"(*;7-G<W1R(")B:6IL
M86=E;BYZ:7`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,3,*;7-G:60@(F)Y=&5S(@IM<V=S='(@(F)Y=&5S(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C(P,`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<R"FUS9VED(")C86YN
M;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,38T"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(R,`IM<V=I9"`B8V]N9FEG=7)A=&EO
M;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DV"FUS
M9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C@*;7-G:60@(F1A=&$@9F]R;6%T(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C0*;7-G:60@
M(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B9G)O;2(*;7-G<W1R(")V
M86XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@P"FUS9VED(")H;W-T(&YA;64@
M=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`T"FUS
M9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$X.`IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(Y('!G<"YP:'`Z-CD*;7-G:60@
M(FME>2(*;7-G<W1R(")S;&5U=&5L(@H*(SH@9F]L9&5R<RYP:'`Z,38Q"FUS
M9VED(")M86EL8F]X(&9I;&4B"FUS9W-T<B`B36%I;&)O>&)E<W1A;F0B"@HC
M.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*;7-G:60@
M(FYA;64B"FUS9W-T<B`B;F%A;2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*;7-G<W1R(")G965N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B;W(B
M"FUS9W-T<B`B;V8B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$V"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,C$R"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-`IM<V=I9"`B<V5R=FEC92!U
M;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R(@IM<V=S='(@
M(G-P96QF;W5T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B<W!E;&9O=71E
M;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(G-Y
M<W1E;2!E<G)O<B(*;7-G<W1R(")S<&5L9F]U="(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HR,#@*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&:6QT97(N<&AP.C4Q"FUS9VED(")Y;W5R(&)L86-K;&ES="(*
M;7-G<W1R(")U=R!Z=V%R=&4@;&EJ<W0B"@HC.B!L:6(O1FEL=&5R+G!H<#HV
M,0IM<V=I9"`B>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B=7<@=VET=&4@;&EJ
M<W0B"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O<&\O:F%?2E`N<&\`````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S<W,S$U`#$P-#$W,S8R-S8T
M`#`Q-S$W,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C($IA<&%N97-E('1R86YS;&%T:6]N(&9O<B!)35`N"B,@0V]P>7)I
M9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES
M=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@24U0('!A
M8VMA9V4N"B,@2&ER;VUI($MI;75R82`\:&ER;VUI0'1A8RYT<W5K=6)A+F%C
M+FIP/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!)35`@-"XP+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`U+3`Q+3$S
M(#`X.C`P*S`Y,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2&ER;VUI($MI;75R
M82`\:&ER;VUI0'1A8RYT<W5K=6)A+F%C+FIP/EQN(@HB3&%N9W5A9V4M5&5A
M;3H@2F%P86YE<V4@/$Q,0&QI+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]4TA)1E1?
M2DE37&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@("`@("!#
M8SH@(@IM<V=S='(@(B`@B+:0YH%&(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q
M-0IM<V=I9"`B("`@("`@5&\Z("(*;7-G<W1R("(@((BVD.:!1B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HT,#,*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B
M(""3^I5T@48B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`V"FUS9VED("(@("`@
M1G)O;3H@(@IM<V=S='(@(HVWCV^0;(%&(@H*(SH@;6%I;&)O>"YP:'`Z-#(R
M('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HT,3(*;7-G:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B("",CY:\
M@48B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S`*;7-G
M:60@(B!I;B`B"FUS9W-T<B`B("`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@(B,B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T
M:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M365S<V%G97,B"FUS9W-T<B`BBOF1MH+,@X&!6X.+(@H*(SH@;6%I;&)O>"YP
M:'`Z,3<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E
M<R!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B)60@C,*"S(.!@V*#6H%;
M@U>"\(WMCYR"M8+<@K6"O8%"(@H*(SH@;&EB+U-P86TN<&AP.C$W.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E9"!M97-S86=E<R!H879E(&)E96X@<F5P
M;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B)60@C,*"S(.!@V*#6H%;@U>"S5-004V"Q8+(@J*"QHK'
MEYV.TH+)E?&-D(*S@NJ"W(*U@KV!0B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E
M<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(E9"",PH+,@X&#8H-:@5N#
M5X+-4U!!38+%@LB"HH+&E?&-D(*S@NJ"W(*U@KV!0B(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B)60@C,*"S(.!@V*#6H%;@U>"S5-004V"Q8*@
M@NF"QHK'EYV.TH+)E?&-D(*S@NJ"W(*U@KV!0B(*"B,Z(&QI8B]3<&%M+G!H
M<#HQ-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(B5D((S"@LR#@8-B@UJ!
M6X-7@LU34$%-@L6"H(+I@L:5\8V0@K."ZH+<@K6"O8%"(@H*(SH@;6%I;&)O
M>"YP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D
M($UE<W-A9V5S(@IM<V=S='(@(B`E9"`M("5D("\@)60@DLHB"@HC.B!M86EL
M8F]X+G!H<#HV-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T
M<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL
M7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A
M9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N(@IM
M<V=S='(@(B5S((+-@K>"Q8+)D;:-W8*U@MR"MX%")7,@@W2#2(.+@U^"S):\
MD4^"S97/C5B"LX+J@MR"N8+Q@L6"M8*]@4(B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B5S((+-D+."M8*B
MC&".KH+,@X&!6X.+@WN#8H-.@UB"Q8+-@J""Z(+<@KF"\8%"(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9O;&1E<B!B96EN9R!R96YA
M;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N(@IM<V=S='(@(B5S((-T
M@TB#BX-?@LR6O)%/@LV!09:(C(Z"S(^)@M^"R97/C5B"LX+J@MR"MX%"(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B5S((+-CO.7G8*S
M@NJ"W(*U@KV!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS
M9W-T<B`B)7,@@K."\8+-("5S((+P@TR#@X.3@UJ#BX*U@MR"M8*]@4(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&AA<R!D96-L:6YE9"XB"FUS9W-T<B`B)7,@@K."\8+-CJN1
MWH*U@MR"M8*]@4(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DS
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E
M92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S((*S@O&"JI=<DNB/[I7Q@LR7
M=HN!@LF5U).:@K6"W(*U@KV!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@
M=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@(B5S((*S@O&"JB`E
M<R""UH+,C[61TH+)E=2038*U@MR"M8*]@4(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-#@R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!S
M96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S((*S
M@O&"JI=<DNB/[I7Q@O"1EX+!@L2"JX+<@K6"O8%"(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H
M87,@=&5N=&%T:79E;'D@86-C97!T960N(@IM<V=S='(@(B5S((*S@O&"JHF\
MCO.1^(*U@MR"M8*]@4(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#@W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(E<R""LX+Q@JJ"H(+(@KV"
MS)=<DNB/[I7Q@O"7=HN!@K6"Q(*B@MR"MX%"(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U
M97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(E<R""LX+Q@LV"
MH(+(@KV"JB`E<R""R8]OD,B"MX+I@K&"QH+PEW:+@8*U@L2"HH+<@K>!0B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HT,30*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@7"(E<UPB+B(*
M;7-G<W1R("(E<R""S2`E<R""R9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S('=I<VAE<R!T;R!A;6UE;F0@)7,N(@IM<V=S='(@(B5S((*S@O&"JB`E
M<R""S(G\DNB"\(KSEEV"M8+$@J*"W(*W@4(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3<T"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE
M<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RXB"FUS9W-T<B`B)7,@@K."\8+-
M@J""R(*]@JH@)7,@@O"/LY)M@K>"Z8*Q@L:"\(KSEEV"M8+$@J*"W(*W@4(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF
M;W)M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B5S((*S@O&"JB`E<R""R8+"
M@J*"Q(+,C<605H_NE?&"\(KSEEV"M8+$@J*"W(*W@4(B"@HC.B!M97-S86=E
M+G!H<#HR.#4@;65S<V%G92YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?=&]P+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D
M)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7,Z)7,@*"5D)FYB<W`[+R9N
M8G-P.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ
M,S,*;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE
M>'0@<V-R965N+BDB"FUS9W-T<B`B@6F5SXU8@O"32Y=P@K6"Q(%!CI^"S(GF
MELJ"UHC:DZZ"M8+<@K>!0H%J(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@86YD
M(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("*!:97/
MC5B"\)1PBOR"M8+$@4&#@8%;@XN-[)"LB>:6RH+6EM^"Z(+<@K>!0H%J(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H
M2%1-3"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB"FUS9W-T<B`B(@H*(SH@
M<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E='5R;B!T;R!T:&4@8V]M
M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T
M:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I
M;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("*!:9%3@L2"S)7/C5B"\)1J
MBOR"M8+$@X&!6X.+C>R0K(GFELJ"R9;?@NF!0H%J(@H*(SH@<W!E;&QI;F<N
M<&AP.C(W-PIM<V=I9"`B(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN
M9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@
M(@HB8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S
M='(@(H%ID5."Q(+,E<^-6(+PE&J*_(*U@L21EY!-@K>"Z8%"@6HB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!
M9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J($]+@O"#3H.*
M@V*#3H*U@L22QXG!@K6"W(*W("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E
M<W,H97,I("HB"FUS9W-T<B`B*B"#08-H@XR#6(+PD4F1\(*U@L2)NH*S@J(@
M*B(*"B,Z(&UA:6QB;W@N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S
M86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B5D((S"@LR#@8-B@UJ!
M6X-7@O"-[8^<@K6"W(*U@KV!0B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*;7-G
M:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T
M;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*"4(+"@LR#
M@8-B@UJ!6X-7@JI34$%-@L6"R(*B@L:"M8+$@U:#6(-E@X"*QY>=CM*"R97Q
MC9""LX+J@MR"M8*]@4(B"@HC.B!L:6(O4W!A;2YP:'`Z,38P"FUS9VED("(Q
M(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S
M='(@(H)0@L*"S(.!@V*#6H%;@U>"JE-004V"Q8+(@J*"QH*U@L25\8V0@K."
MZH+<@K6"O8%"(@H*(SH@;&EB+U-P86TN<&AP.C$W,@IM<V=I9"`B,2!M97-S
M86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B@E""PH+,@X&#8H-:@5N#5X*J4U!!
M38+&@K6"Q(-6@UB#98.`BL>7G8[2@LF5\8V0@K."ZH+<@K6"O8%"(@H*(SH@
M;&EB+U-P86TN<&AP.C$U,@IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E
M<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(H)0@L*"S(.!@V*#6H%;@U>"JE-0
M04V"QH*U@L25\8V0@K."ZH+<@K6"O8%"(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Q.0IM<V=I9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B,3`P
M()6VCIHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(R"FUS9VED("(Q
M,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B,3`P,""5MHZ:(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@R,`IM<V=I9"`B,C4P(&-H87)A8W1E<G,B"FUS
M9W-T<B`B,C4P()6VCIHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(Q
M"FUS9VED("(U,#`@8VAA<F%C=&5R<R(*;7-G<W1R("(U,#`@E;:.FB(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O
M('1H:7,@;65S<V%G92XB"FUS9W-T<B`BD>6"JX+(B>:1G"`E<R""JI-9E72"
MLX+J@L2"HH+<@K>!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I
M;VXN<&AP.C4P"FUS9VED("(B"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H
M87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE
M("(*(G)E8VEP:65N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]F:65L9',N:6YC.C4*;7-G:60@(D%.1"(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3DP"FUS9VED(")!8V-E<'0@<F5Q=65S
M="(*;7-G<W1R("*7=HN!@O".\Y'X@K>"Z2(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.#<*(RP@9G5Z>GD*;7-G:60@(D%C8V5P="!R97%U97-T
M(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B@T.#>(.3@V>"
MS9=<DNB57(+)DL>)P8*S@NJ"W(*U@KV!0B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW-3,*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(H[SD?B-
MSX+=(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-PHC+"!F=7IZ
M>0IM<V=I9"`B06-C97!T960Z("(*;7-G<W1R("*.\Y'XC<^"W2(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT
M)W,@;F%M93HB"FUS9W-T<B`B@T&#2H-%@Y.#9Y:\@48B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3(P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW,S`*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`BCXB2=2(*"B,Z(&QI8B]-
M24U%+TAE861E<G,N<&AP.C(P,"!L:6(O34E-12](96%D97)S+G!H<#HR,#$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"`E<R!T;R!M>2!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B@T&#:(.,@UB2H(+)DL>)P8%I)7.!:B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P,PIM<V=I9"`B
M061D('-O=7)C92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@
M(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(HZ$@LR77)+HE5R"
MR9+'B<&"MX+I(@H*(SH@8V]M<&]S92YP:'`Z,3(U-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T86-H;65N="XB"FUS9W-T
M<B`B7"(E<UPB((+PDUF5=(*U@MR"M8*]@4(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DX"B,L(&9U>GIY"FUS9VED("(B"B)!9&1I=&EO;F%L(&AE
M861E<G,@=&\@9&ES<&QA>2!W:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL
M(&5N=&5R(&5A8V@@:&5A9&5R("(*(F]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS
M9W-T<B`BC^V"R95<CJ:"MX+I@W>#8H-?.B"!:8-)@W:#5H.'@Y.!0H)0C7."
MR8)0@L*"S(-W@V*#7X+PCG>2Z(%J(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I
M;VYA;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B
M"@HC(&US9W-T<B`BC,*0;(-!@VB#C(-8DJ`B"B,Z(&QI8B]-24U%+U9I97=E
M<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L(&9U>GIY"FUS9VED(")!9&1I=&EO
M;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS9W-T<B`BC,*0;(_NE?$B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,PHC+"!F=7IZ>0IM<V=I
M9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`B@X&#8H-:
M@5N#5X+,@W:#C(-R@X6!6X+PCF>7<(*U@MR"MX*I@4@B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM
M<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I
M;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N=&%C=',N
M<&AP.C@U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*
M;7-G<W1R("*#08-H@XR#6)*@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-`IM<V=I9"`B061D<F5S<R!";V]K<R(*;7-G<W1R("*#08-H@XR#6)*@
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T
M:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO
M96T^(@IM<V=S='(@(H_M@LE"0T."Q9&7@NF#08-H@XR#6#J!:8-)@W:#5H.'
M@Y.!0H)0C7."R8)0@T&#:(.,@UB"\(YWDNB!:B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.#$*(RP@9G5Z>GD*;7-G:60@(B(*(D%D9')E<W-E<R!T
M;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES(&ED96YT:71Y.B`\96T^*&]P=&EO
M;F%L+"!E;G1E<B!E86-H("(*(F%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M
M/B(*;7-G<W1R("*"L8+,($E$((+)F$&,BX*S@KF"Z8-!@VB#C(-8.H%I@TF#
M=H-6@X>#DX%"@E"-<X+)@E"#08-H@XR#6(+PCG>2Z(%J(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#(S"FUS9VED(")!;&PB"FUS9W-T<B`B@K>"UX+$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,PIM<V=I9"`B(@HB06QL(&UE
M<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W
M;FQO861E9"!I;G1O(&]N92!-0D]8("(*(F9I;&4Z(@IM<V=S='(@(B(*(HZ?
M@LR#=(-(@XN#7Y/@@LR#@8-B@UJ!6X-7@LV"MX+7@L0@,2""PH+,($U"3U@@
M@W2#0(-#@XN"R8-?@T6#DX.-@5N#:(*S@NJ"W"(*(H*W@4(B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('EO=7(@7"(E<UPB(&9O
M;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2`B
M"B)D96QE=&5D+B(*;7-G<W1R("(B"B*-[)"L@K6"Q(*I@N<@)3(D<R"3^HC(
MC^.,;X+!@KV!;5PB)3$D<UPB@6Z#=(-(@XN#7Y/@@LR#@8-B@UJ!6X-7@LV"
MMX+7@L2-[8^<(@HB@K."ZH+<@K>!0B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@
M(B5S@Y:,CHC(C^.,;XG?@K6"O8S#@J*#BH.3@TZ,7I-9E72"S9%3@L2-[8^<
M@K."ZH+<@K>!0B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S
M96YT;6%I;%]M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@
M;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`BC>R0K(*U@L2"J8+G)7.#
MEHR.B,B/XXQO@L&"O9&7D$V-5(*F@W2#2(.+@U^"S9%3@L2-[8^<@K."ZH+<
M@K>!0B(*"B,Z(&%C;"YP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L;'D@
M<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B"#=(-(
M@XN#7X+,EKR13X*J(%PB)7-<(B""R97/C5B"LX+J@MR"M8*]@4(B"@HC.B!L
M:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L9&5R($-R96%T:6]N/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#@*
M;7-G:60@(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N
M>2!M86EL8F]X/R(*;7-G<W1R("*#=(-"@XN#7H.+@5N#BX+P@L>"S(.!@5N#
MBX-[@V*#3H-8@L6"X)-+EW""Q8*K@NF"YH*D@LF"M8+<@K>"J8%((@H*(SH@
M;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,3`*;7-G:60@(D%L
M=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S(@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4X-`IM<V=I9"`B06QW87ES(@IM<V=S='(@(H_M@LDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34W"FUS9VED(")!;'=A>7,@<V%V92!A
M='1A8VAM96YT<R(*;7-G<W1R("*3695T@LV/[8+)E=N1MH*W@NDB"@HC.B!L
M:6(O365S<V%G92YP:'`Z-3`U"FUS9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D
M('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H
M92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`BDUF5=(+PC>V/G(*W
M@NF-VX+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0DE-05"#5(%;@V^"J8+G@LR)
MGI.:.B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#@*(RP@9G5Z>GD*;7-G:60@
M(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@
M;F5W(&YO=&4N(@IM<V=S='(@(I!6BTN#7H-8@TZ-[)"LDH:"R8RTB/:5<Y:^
M@LR#1X.)@5N"JI2MD+:"M8+<@K6"O8%"(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C,X-PIM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R
M96%T:6YG('1H92!N97<@=&%S:RXB"FUS9W-T<B`BD%:+2X->@UB#3HWLD*R2
MAH+)C+2(]I5SEKZ"S(-'@XF!6X*JE*V0MH*U@MR"M8*]@4(B"@HC.B!M97-S
M86=E+G!H<#HU,#`@;6%I;&)O>"YP:'`Z-S$T('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHV"FUS9VED(")!;G-W
M97)E9"(*;7-G<W1R("*5U)!-C<^"W2(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@
M(I74D$V-SX+=@X&!6X.+(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHW"B,L(&9U>GIY"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@
M(H-T@T*#BX->@O"32Y=P(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<'!L>2!&:6QT
M97)S('1O("5S(@IM<V=S='(@(H-T@T*#BX->@O"32Y=P(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS9VED(")!<'!L>2!F:6QT97(@
M<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R("*#C8-/@T.#DXZ>@LF#
M=(-"@XN#7H.+@5N#BX+PDTN7<(*U@MR"MX*I@4@B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z-#(*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE
M<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_(@IM<V=S='(@(DE.0D]8
M@O"57(ZF@K>"Z9-X@LF#=(-"@XN#7H+PDTN7<(*U@MR"MX*I@4@B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T
M92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(I9[DY:"R8*Q@LR,]HI*C*Z"
M\(_!BXZ"M8+<@K>"J8%((@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(B(*(D%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI
M<R!I<R!.3U0@<F5C;VUM96YD960A*2(*;7-G<W1R("*6>Y.6@LF"L8+,C*Z#
M>8-!@O"/P8N.@K6"W(*W@JF!2(%I@JB*J8+?@K6"W(*Y@O&!28%J(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@9&\@=&AI<S\B"FUS9W-T<B`BEGN3EH+)CL"-<X*U@L2"HH*B@L6"
MMX*I@4@B"@HC.B!M97-S86=E+G!H<#HT,#<@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S
M='(@(I9[DY:"R8*Q@NJ"YX+,@X&#8H-:@5N#5X+PBJZ14X+)C>V/G(*U@L2"
MHH*B@L6"MX*I@4@B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L
M971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`BEGN3EH+)@K&"ZH+G@LR3
M695T@O"*KI%3@LF-[8^<@K6"Q(*B@J*"Q8*W@JF!2"(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@96UP='D@=&AI<R!F;VQD97(_(@IM<V=S='(@(I9[DY:"
MR8*Q@LR#=(-(@XN#7X+PB_."R8*U@L2"HH*B@L6"MX*I@4@B"@HC.B!L:6(O
M24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@9F]L9&5R/R(*;7-G<W1R("*6>Y.6
M@LF#4X-^E*""\(OS@LF"M8+$@J*"HH+%@K>"J8%((@H*(SH@;&EB+TE-4"YP
M:'`Z.38V"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@
M>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(I9[DY:"R8-3@WZ4H(+PB_."
MR8*U@L2"HH*B@L6"MX*I@4@B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHX"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R
M;6%N96YT;'D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("*6>Y.6
M@LF"L8+J@N>"S(.!@V*#6H%;@U>"\(JND5."R8_!BXZ"M8+$@N""HH*B@L6"
MMX*I@4@B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHX
M,"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW.0IM<V=I9"`B
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@
M87,@:6YN;V-E;G0_(@IM<V=S='(@(I9[DY:"R8*Q@LR#@8-B@UJ!6X-7@O"6
MLXI1@L:5\8V0@K6"Q(+@@J*"HH+%@K>"J8%((@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:F%V87-C<FEP="YI;F,Z-S4@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z-S0*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!R97!O<G0@=&AI<R!M97-S86=E(&%S('-P86T_(@IM<V=S='(@(I9[DY:"
MR8*Q@LR#@8-B@UJ!6X-7@O!34$%-@L:5\8V0@K6"Q(+@@J*"HH+%@K>"J8%(
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I9"`B07)R:79A
M;"!4:6UE(@IM<V=S='(@(I.>DH6.GHK4(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDS,0IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(H^XCX<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU.#,*;7-G:60@(D%S:R(*;7-G<W1R("*0<8++@NDB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3D*;7-G:60@(D%T=&%C:"(*
M;7-G<W1R("*3695T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#<U"FUS9VED(")!='1A8V@@1FEL97,B"FUS9W-T<B`BDUF5=(-T@T"#
M0X.+(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#4V"FUS
M9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@
M>6]U<B!M97-S86=E/R(*;7-G<W1R("*"H(+(@KV"S"!01U`@C/:*2HRN@O"3
M695T@K6"W(*W@JF!2"(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ
M,#D*;7-G:60@(D%T=&%C:&5D($9I;&4Z(@IM<V=S='(@(I-9E72#=(-`@T.#
MBX%&(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0U,2!L:6(O0V]M<&]S92YP:'`Z
M-3,V"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%T=&%C:&5D(&9I;&4@7"(E
M<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I;&4@
M3D]4(&%T=&%C:&5D+B(*;7-G<W1R("*3695T@W2#0(-#@XL@7"(E<UPB((+,
M@U2#0X-9@JJ1Y8*K@K>"K(+<@K>!0I-9E72"LX+J@MR"N8+Q@4(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S<V"FUS9VED(")!='1A8VAE9"!I
M<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N="XB"FUS
M9W-T<B`BDUF5=(-T@T"#0X.+@LV"H(+(@KV"JI&7@L&"O9=<DNB57)=VBX&"
MUH+,E=2038+%@K>!0B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI
M;F,Z,38@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY-PIM<V=I9"`B071T86-H;65N="(*
M;7-G<W1R("*3695T(@H*(SH@8V]M<&]S92YP:'`Z,3`V-R!L:6(O365S<V%G
M92YP:'`Z-#8V"FUS9VED(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA
M;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T<B`BDUF5=(+PCN:"Z(^<@JN"W(*U
M@KTZ()-9E72"S(Q>(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,S0Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W,PHC.B!L
M:6(O0V]M<&]S92YP:'`Z,3`W,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T
M<B`BDUF5="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#(*;7-G
M:60@(D%T=&5N9&5E<R(*;7-G<W1R("*.48G!CM(B"@HC.B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PIM<V=I9"`B071T96YT:6]N(@IM
M<V=S='(@(I*-B-,B"@HC.B!L:6(O075T:"]I;7`N<&AP.C0T"FUS9VED(")!
M=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VEM<#H@E4N7=H+(($E-05`@BF>2HX*JC*F"PH*I@NB"
MW(*Y@O&!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-#`*;7-G:60@
M(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E
M<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM
M<V=S='(@(H-!@VB#C(-8DJ""R9-OF%Z"LX+J@L2"HH+ID&R"J8+G@LP@2%1-
M3""#@8-#@XN"S8GFD9R"\)5<CJ:"M8+<@K>"J8%((@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDX"FUS9VED(")!=F%I;&%B;&4@
M061D<F5S<R!B;V]K<SHB"FUS9W-T<B`BCF>7<(G"E%R"R(-!@VB#C(-8DJ"!
M1B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@(D%W
M86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@(HF>DYJ1TH*_(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")"86-?:R!T;R`E<R(*;7-G<W1R(")?2R5S((+)EM^"Z2(*
M"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E
M<R(*;7-G<W1R("(E<R""R9;?@NDB"@HC.B!T:')E860N<&AP.C$S-`IM<V=I
M9"`B0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@B"FUS9W-T
M<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D
M($1I<W!L87DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS
M.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U
M97-T+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HR-C8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M,C(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L:6(O
M4V5A<F-H+G!H<#HS-`IM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM<V=I9"`B0F5L;W<@:7,@
M=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`B@W6#B8-B@TZ#BH-8@V<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C(Y"FUS9VED(")";&]C:R!I;6%G
M97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A
M;&QY(')E<75E<W1E9#\B"FUS9W-T<B`B2%1-3(.!@5N#BY*&@LR)YI&<@LV.
M=XZF@K>"Z8+<@L657(ZF@K6"R(*B@N:"I(+)@K6"W(*W@JF!2"(*"B,Z(&QI
M8B]396%R8V@N<&AP.C0R"FUS9VED(")";V1Y(@IM<V=S='(@(I9[E;8B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C(S('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z,SD*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU
M-2!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C<Q"FUS9VED(")";W1H(@IM
M<V=S='(@(I>\E?LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@W"FUS
M9VED(")";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4B
M"FUS9W-T<B`B@W>#8H-?E92"QI9[E;:"R95<CJ8B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(*;7-G:60@(D-?:&%R<V5T(@IM<V=S
M='(@(E](E;:.FH-:@V*#9R(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BEUR2Z)5<(@H*(R!M
M<V=S='(@(H-*@XR#DX-?(@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(P
M,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S
M97)V97(N(@IM<V=S='(@(H.*@X*!6X-G@LR#@8-#@XN#5(%;@V^"R9#:D;&"
MQ8*K@MR"N8+Q@4(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Y.0IM
M<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V
M97(Z("(*;7-G<W1R("*#BH."@5N#9X+,@X&#0X.+@U2!6X-O@LF0VI&Q@L6"
MJX+<@KF"\3H@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O
M=6YD(&]N;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H
M92!C=7)R96YT("(*(FUA:6QB;W@N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C(X-"!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-0HC
M.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(Q('1E;7!L871E<R]S
M879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.0HC.B!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,C$@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN
M:6YC.C@V"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`@
M=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,@HC.B!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C8V"FUS9VED(")#86YC96PB"FUS9W-T<B`B
M@TR#@X.3@UJ#BR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S-0HC.B!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@
M365S<V%G92(*;7-G<W1R("*#@8-B@UJ!6X-7@LR#3(.#@Y.#6H.+(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")#86YC96QL:6YG('1H:7,@;65S
M<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+B(*
M;7-G<W1R("*#@8-B@UJ!6X-7@O"#3(.#@Y.#6H.+@K>"Z8+&@4&3X)=E@LV1
M4X+$E'"*_(*S@NJ"W(*W@4(B"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5C;VUP;W-E+FEN8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM<V=I
M9"`B0V,B"FUS9W-T<B`B0V,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V
M86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R`B
M"B)S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW,#$*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R("*+8Y*W(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED(")#
M:&%N9V4B"FUS9W-T<B`BE<^-6"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R("*"MX+7
M@L25SXU8(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDR"FUS9VED(")#
M:&%N9V4@1F]L9&5R(@IM<V=S='(@(H-T@TB#BX-?E<^-6"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3(*;7-G:60@(B(*(D-H86YG92!D:7-P;&%Y
M(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N
M(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S(&%R92!S;W)T960N(@IM
M<V=S='(@(B(*(HIE@WF!6X-7@LF57(ZF@K."ZH+I@X&#8H-:@5N#5X+,D)2"
MXH.!@V*#6H%;@U>"S)7`@M>5^X+(@L>"\)7/C5B"M8+<@K>!0B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B0VAA;F=E(&UA:6P@<V5R
M=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@(H.!@5N#BX-4@5N#
M;X+B@W2#2(.+@U^"S)#=DNB"\)7/C5B"M8+<@K>!0B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A
M9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B
M@X&!6X.+@LF57(ZF@K."ZH+I@J""R(*]@LR6O)%/@4&#08-H@XR#6(%!CY"6
MO(+PE<^-6(*U@MR"MX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R
M-`IM<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("*57(ZF
M@K>"Z96VCIJ!1B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C$U"FUS9VED(")#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S
M='(@(H-T@TB#BX-?D^""S)!6DH6#@8%;@XN"\(IME$8B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI
M;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(Q"FUS
M9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E=&-H
M(&UA:6P@9G)O;3HB"FUS9W-T<B`B@X&!6X.+@O".YI.^@K>"Z8-4@5N#;X+P
MD4F1\(%&(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V,PIM<V=I9"`B
M0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G
M<W1R("*1EY!-@K>"Z9%/@LF#6(-Y@XN#8(-&@V*#3H*U@MR"MX*I@4@B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT"FUS9VED(")#:&]O
M<V4@06-T:6]N.B(*;7-G<W1R("*/B))U@O"129'P@48B"@HC.B!C;VYF:6<O
M<V5R=F5R<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-H;V]S92!A(&UA:6P@<V5R
M=F5R.B(*;7-G<W1R("*#@8%;@XN#5(%;@V^"\)%)D?"!1B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C$W"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E9&ET('1H92!A
M9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4R,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S,Q"FUS9VED(")#:&]O<V4@86X@86-T:6]N.B(*;7-G<W1R("*/B))U@O"1
M29'P@48B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M-#D*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N
M(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(H-!@VB#C(-8@LR2QXG!CIZ"
MR8YG@J2#08-H@XR#6)*@@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3,*;7-G:60@(D-H;V]S
M92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E
M>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("*#08-H@XR#6(+PDU>*2H*W
M@NF-VX+)C)^-]8*W@NF#08-H@XR#6)*@@LR/AX^8@O".=Y+H@K6"Q(*M@KZ"
MLX*B@4(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA
M9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RXB
M"FUS9W-T<B`B)7,@@O"#3H.*@V*#3H*W@NF"QHGFD9R"\(-U@XF#18-5@L65
M7(ZFB<*47(+(C&".KH+)E<^*MX*U@MR"MX%"(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+B(*;7-G<W1R("(E<R""\(-.@XJ#
M8H-.@K>"Z8+&B>:1G(+P@U^#18.3@XV!6X-H@K6"W(*W@4(B"@HC.B!L:6(O
M1FEL=&5R+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@
M=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R("(E<R""\(-.
M@XJ#8H-.@K>"Z8+&)7.*QY>=@WF!6X-7@LF(VI.N@K6"W(*W@4(B"@HC.B!L
M:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W+B(*;7-G<W1R("(E<R""\(-.@XJ#8H-.@K>"Z8+&2%1-3(+P
ME<J#18-#@Y.#:(%;@LF57(ZF@K6"W(*W@4(B"@HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R
M("(E<R""\(-.@XJ#8H-.@K>"Z8+&B>:1G(+,@U2#@(-L@T.#BX+PE5R.IH*U
M@MR"MX%"(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE
M(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(B5S
M((+P@TZ#BH-B@TZ"MX+I@L9(5$U,@O"5RH-%@T.#DX-H@5N"R95<CJ:"M8+<
M@K>!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES
M(&UU;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N
M(@IM<V=S='(@(B5S((+P@TZ#BH-B@TZ"MX+I@L9(5$U,@O"5RH-%@T.#DX-H
M@5N"R95<CJ:"M8+<@K>!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY-0IM<V=I9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,B"FUS
M9W-T<B`B@K&"L8+P@TZ#BH-B@TZ"MX+I@L:)YI&<@O"57(ZF@K6"W(*W@4(B
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*;7-G
M:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@
M8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H
M+B(*;7-G<W1R("(B"B*.=Y+H@K6"O8-!@VB#C(-8DJ""S"`Q((+"@O"#3H.*
M@V*#3H*U@L2"J8+G@4&,GXWU@K>"Z8-T@T*!6X.+@VB"\(*W@M>"Q(YWDNB"
MM2(*(H+$@JV"OH*S@J*!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C$W,0IM<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y
M;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R("*#3H.*@V*#3H*W@NF"QB!01U`@
MC/:*2HRN@O"#08-H@XR#6)*@@LF5VY&V@K6"W(*W(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B@TZ#BH-B@TZ"MX+I@L8@)7,@@LP@4R]-
M24U%((_8EKZ/D8+P@J""R(*]@LR#08-H@XR#6)*@@LF5VY&V@K6"W(*W(@H*
M(R!M<V=I9"`B0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@:6X@
M>6]U<B!!9&1R97-S(&)O;VLB"B,@;7-G<W1R("*#3H.*@V*#3H*W@NF"QB!3
M+TU)344@C]B6OH^1@O""H(+(@KV"S(-!@VB#C(-8DJ""R97;D;:"M8+<@K<B
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3`*;7-G:60@(D-L:6-K:6YG
M(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O
M('1H92!S96YD97(B"FUS9W-T<B`B@T&#:(.,@UB"\(-.@XJ#8H-.@K>"Z8+&
MD9>038[2@M:"S)!6BTN#@8%;@XN"\(WLD*R"M8+<@K<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D
M<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R
M("*#08-H@XR#6(+P@TZ#BH-B@TZ"MX+I@L:#@8-B@UJ!6X-7@O"57(ZF@K6"
MW(*W(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(X
M"FUS9VED(")#;&]S92(*;7-G<W1R("*5PH*V@NDB"@HC.B!C;VUP;W-E+G!H
M<#HX,C@@8V]M<&]S92YP:'`Z,3$T.`IM<V=I9"`B0VQO<V4@=&AI<R!W:6YD
M;W<B"FUS9W-T<B`B@K&"S(-%@T.#DX-H@O"5PH*V@NDB"@HC.B!F;VQD97)S
M+G!H<#HT,CD*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS9W-T<B`BE<*"MH+$
M@J*"Z8-T@TB#BX-?(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS9VED(")#;VQL
M87!S92(*;7-G<W1R("*"O8*]@MXB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL(@IM<V=S='(@(H*W
M@M>"Q(+P@KV"O8+>(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S='(@(H*W
M@M>"Q(+,@W2#2(.+@U^"\(*]@KV"WB(*"B,Z(&9O;&1E<G,N<&AP.C0T.0IM
M<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM<V=S='(@(H-T@TB#BX-?@O""O8*]
M@MXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G
M:60@(D-O;&]R($EN9&EC871O<CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,#,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B@U*#
M@8.3@V<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8Y"FUS9VED
M(")#;VUP;&5T960B"FUS9W-T<B`BBJZ7N2(*"B,Z(&-O;7!O<V4N<&AP.C@R
M-R!C;VUP;W-E+G!H<#HQ,30W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S
M<V%G92(*;7-G<W1R("*5RH+,@X&!6X.+@O"-[)"L(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0S-`IM<V=I9"`B0V]M<&]S92!M97-S86=E<R!I;B!A
M('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`BE<J"S(-%@T*#DX-H@T6"Q9!6
MBTN#@8%;@XN"\(WLD*R"M8+<@K>"J8%((@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T,PIM<V=I9"`B(@HB0V]M<&]S92!M97-S86=E<R!W:71H(&%N
M($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE
M("(*(F9E871U<F4I/R(*;7-G<W1R("*#@8%;@XN-[)"L@O!(5$U,@X*!6X-H
M@LF"M8+<@K>"J8%I@W6#B8-%@U6"JH-4@WR!6X-G@K>"Z8+(@N>!:H%((@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@
M:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S='(@(H.!@V*#6H%;
M@U>"\(+'@J257(ZF@K>"Z8*I@O"0W9+H@K6"W(*W@4(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D-O;F9I9W5R92!M86EL('!R979I
M97<@;W!T:6]N<RXB"FUS9W-T<B`B@X&#0X.+@LR#=H.,@W*#A8%;@TF#=H-6
M@X>#DX+PD-V2Z(*U@MR"MX%"(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS
M-S`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0
M('-E<G9E<BXB"FUS9W-T<B`B@U2!6X-O@M:"S)#:D;&.N)1S(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@(D-O;FYE8W1I;VX@=&\@
M<V5R=F5R(&9A:6QE9"(*;7-G<W1R("*#5(%;@V^"UH+,D-J1L8ZXE',B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(E<R""
MS"!01U`@@U2#?(%;@V>"\)#=DNB"M8+<@K>!0B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3
M+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B5S((+,(%,O34E-12"#
M5(-\@5N#9X+PD-V2Z(*U@MR"MX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,0IM<V=I9"`B0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE
M<W-A9V5S('-E87)C:&EN9RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@Y"FUS9VED("(B"B)#;VYT<F]L('=H96X@;F5W(&UA:6P@
M=VEL;"!B92!C:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO
M=&EF>2!Y;W4@(@HB=VAE;B!I="!A<G)I=F5S+B(*;7-G<W1R("*05I*%@X&!
M6X.+@O")O8Z>BFV41H*W@NF"J8%!D%:2A8.!@5N#BX+PDLJ2;8*W@NF"J8+'
M@J2"J8+PD-V2Z(*U@MR"MX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8Y-@IM<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R
M87!H:6-A;"!O;F5S/R(*;7-G<W1R("**1Y6VCIJ"\(-!@T.#4H.3@LF5SXU8
M@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM
M<V=I9"`B0V]P>2(*;7-G<W1R("*#4H-S@5LB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@
M(H-T@TB#BX-?@5N"R8-2@W.!6R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G<W1R("*/0Y"S(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B
M0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`BCT.0LXW/@MV#98-,@UB#9R(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S
M(@IM<V=S='(@(B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C0P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E
M<RX@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("(E<R""S(.!@V*#6H%;
M@U>"S8WMCYR"Q8*K@MR"N8+Q@4*#5(%;@V^"J8+G@LR)GI.:@48@)7,B"@HC
M.B!L:6(O4V5S<VEO;BYP:'`Z,S$X"FUS9VED(")#;W5L9"!N;W0@97AE8W5T
M92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R("*5VX[GC>R+QH+P
MCL"-<X+%@JN"W(*Y@O&!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H
M<#HU-`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F
M:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B35,M
M5$Y%1B"3695T@JF"YY=VBX&"LX+J@KV#=(-`@T.#BX+PCN:"Z(]O@KF"W(*Y
M@O&"Q8*U@KV!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS
M9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O
M;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@(EII<""/D8S)@JF"YX-T@T"#
M0X.+@O".YH+HCV^"N8+<@KF"\8+%@K6"O8%"(@H*(SH@;&EB+U-E<W-I;VXN
M<&AP.C(W,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I
M;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!S
M96%R8V@N<&AP.C,Q-"!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M-C<@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C,Y"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHQ-C`*;7-G:60@(D-R96%T92(*;7-G<W1R("*-[)"L(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E
M($9O;&1E<B(*;7-G<W1R("*#=(-(@XN#7X+PC>R0K"(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,S<*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!+97ES
M(@IM<V=S='(@(HWLD*PB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI
M;F,Z,30*;7-G:60@(D-R96%T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("*)
MO)%Z@W2#2(.+@U^"\(WLD*PB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C
M8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W($%C8V]U
M;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N
M:6YC.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@
M(H-3@WZ4H(-T@TB#BX-?@O"05HM+C>R0K"(*"B,Z('1E;7!L871E<R]P<F5F
M<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S
M96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E
M<B(*;7-G<W1R("*)NH^1@JN#=(-(@XN#7X+PD%:+2XWLD*PB"@HC.B!T96UP
M;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(V('1E;7!L871E<R]P
M<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#(*;7-G:60@(D-R96%T92!A(&YE
M=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(I&7D$V-5(*F@W2#2(.+@U^"
M\)!6BTN-[)"L(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN
M8SHQ,B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS9VED
M(")#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(H-3@WZ4H(-T
M@TB#BX-?@O"05HM+C>R0K"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C@*;7-G:60@(B(*(D-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI
M>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@
M(@HB86YD(&1E;&5T92!S<&%M+B(*;7-G<W1R("(B"B*.\Y!-@X&!6X.+@O"#
M=(-(@XN#7X+)D%6"Z)6J@J^"O8+H@4%34$%-((.!@5N#BX+PC>V/G(*W@NF#
M=(-"@XN#7H.+@5N#BX+PC>R0K"(*(H*U@MR"MX%"(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A
M=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`BD9>038U4@J:#=(-(@XN#7X+P
MD%:+2XWLD*PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED
M(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A8V-E<W,@=&\@)7,B"FUS9W-T
M<B`B@T&#3H-:@UB"\(N6B<(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA
M:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`BD;R"S(-4@5N#;X*I
M@N>#@8%;@XN"\([FD[Z"MX+I@KV"WX+,D-V2Z(+P@K6"W(*W@4(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D-U<W1O;6EZ92!H;W<@
M>6]U('-E;F0@;6%I;"XB"FUS9W-T<B`B@X&!6X.+@LR1EY!-@O"#2H-8@UZ#
M?8-#@UF"M8+<@K>!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B5S@LF#C8-/@TF#DX*U@KV"QH*K
M@LF.P(US@K>"Z8->@UB#3H+P@TJ#6(->@WV#0X-9@K6"W(*W@4(B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$W"FUS9VED
M(")$871?92(*;7-G<W1R(")?19/ZE70B"@HC.B!M97-S86=E+G!H<#HR-C(@
M=&AR96%D+G!H<#HQ-#@*;7-G:60@(D1A=&4B"FUS9W-T<B`BD_J5="(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3<*;7-G:60@(D1E8VQI;F5D
M(@IM<V=S='(@(H[3D.*-SX+=(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C(V,PHC+"!F=7IZ>0IM<V=I9"`B1&5C;&EN960Z("(*;7-G<W1R("*.
MTY#BC<^"W2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*(RP@9G5Z
M>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BC>V/G"(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHQ.`IM<V=I9"`B1&5F
M875L="!396%R8V@@1FEE;&0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDR,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA
M.B(*;7-G<W1R("*#9H-T@TB#BX-G@LR#7(%;@V>*[H^`@48B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3,S"FUS9VED(")$969A=6QT('-O<G1I;F<@
M9&ER96-T:6]N.B(*;7-G<W1R("*#9H-T@TB#BX-G@LR#7(%;@V>5^XS\@48B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U"FUS9VED(")$96QE
M9V%T960B"FUS9W-T<B`BB,^40XW/@MTB"@HC.B!F;VQD97)S+G!H<#HT,3D@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`BC>V/G"(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,@4'5B
M;&EC($ME>2(*;7-G<W1R("(E<R""S(SVBDJ,KH+PE5R.IB(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C@U"FUS9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G:60@(D1E;&5T
M92!&;VQD97(H<RDB"FUS9W-T<B`B@W2#2(.+@U^"\(WMCYPB"@HC.B!F;VQD
M97)S+G!H<#HR.#4*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!396QE8W1E9"!&
M;VQD97)S(@IM<V=S='(@(H-T@TB#BX-?@O"-[8^<(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@4W1A=&EO;F5R>2(*;7-G<W1R("*)O)%Z@W2#2(.+@U^"\(WMCYPB"@HC
M.B!F;VQD97)S+G!H<#HT,3D*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E
M<B(*;7-G<W1R("*)O)%Z@W2#2(.+@U^"\(WMCYPB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-#,*;7-G:60@(D1E;&5T92!F971C:&5D
M(&UE<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\B"FUS9W-T<B`B@XJ#@H%;
M@V>#5(%;@V^"J8+GCN:"Z(V>@MV-SX+=@LR#@8-B@UJ!6X-7@O"-[8^<@K6"
MW(*W@JF!2"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G
M:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(I=<DNB57(*I
M@N>-[8^<(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B
M1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG(&]F
M(&UO;G1H/R(*;7-G<W1R("*,PX*B@XJ#DX-.C%Z3695T@O",CH+,CXF"WX+)
MC>V/G(*U@MR"MX*I@4@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4P
M"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN
M;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BBOF1MH+,D9>038U4@J:#=(-(@XN#
M7X+PC(Z"S(^)@M^"R8WMCYR"M8+<@K>"J8%((@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-P86T@;65S
M<V%G97,B"FUS9W-T<B`BC>V/G(*S@NJ"O8.!@5N#BR(*"B,Z(&UE<W-A9V4N
M<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,X
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L971E
M9"(*;7-G<W1R("*-[8^<C<\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(HWMCYR"
MLX+J@KV#@8%;@XLB"@HC.B!C;VUP;W-E+G!H<#HS,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!T:&4@871T86-H;65N="!<(B5S7"(N(@IM<V=S
M='(@(I-9E70@7"(E<UPB((+PC>V/G(*U@MR"M8*]@4(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG(&%N9"!-;W9I;F<@
M365S<V%G97,B"FUS9W-T<B`B@X&!6X.+@LR-[8^<@L:(VI.N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T
M(@IM<V=S='(@(I=VBX&"\(N1E-N"MX+I(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4T,`IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U
M<WD@:6YF;W)M871I;VXB"FUS9W-T<B`BEUR2Z(_NE?&"S)=VBX&"\(N1E-N"
MMX+I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,@IM<V=I9"`B1&5S
M8V5N9&EN9R(*;7-G<W1R("*-?H^'(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:6YC.C(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-CD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(I#@EKXB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G
M:60@(D1E=&%I;',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8W-PIM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM<V=S='(@(H^0EKR"
M\)26@JV57(ZF@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(I5<CJ8B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Y"FUS9VED(")$:7-P;&%Y
M(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T
M<B`BD9>038SC@LF*;91&B>:6RH+PE5R.IH*U@MR"MX*I@4@B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED(")$:7-P;&%Y(&EN($)O9'D@
M;V8@365S<V%G92(*;7-G<W1R("*6>Y6V@LF57(ZF(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Y,@IM<V=I9"`B1&ES<&QA>2!P;W`M=7`@;F]T:69I
M8V%T:6]N(&]F(&YE=R!M86EL/R(*;7-G<W1R("*05I*%@X&!6X.+DYZ2A8Z>
M@LF#?(-B@W:#08-B@W:"Q9+*DFV"M8+<@K>"J8%((@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<U.`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!T:&4@
M7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B
M@X&#:H.%@5N#;X%;@LF!=8-3@WZ4H)"TD7R!=H+PE5R.IH*U@MR"MX*I@4@B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4P"B,L(&9U>GIY"FUS9VED
M(")$:7-P;&%Y('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@;65N
M=6)A<C\B"FUS9W-T<B`B@X&#:H.%@5N#;X%;@LF!=8-3@WZ4H)"TD7R!=H+P
ME5R.IH*U@MR"MX*I@4@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYI;F,Z,3$*;7-G:60@(D1I<W!O<VET:6]N(@IM<V=S='(@(HQ@CJXB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O
M($Y/5"!M871C:"(*;7-G<W1R("*(ZI)V@K6"R(*B(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#:&5C:R!&
M;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(H-T@TB#BX-?D^""S)!6
MDH6#@8%;@XN"\(IME$:"M8+(@J(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.34R"FUS9VED(")$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&
M<F]M.B!C;VQU;6XB"FUS9W-T<B`BB;V"X(.*@Y.#3H*U@LB"HB(*"B,Z(&QI
M8B])35`N<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA
M="!F;VQD97(_(@IM<V=S='(@(H-T@TB#BX-?@O"*2H*K@MR"MX*I@4@B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(S,@IM<V=I9"`B1&]N)W0@
M:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(V"FUS9VED(")$;VYE(@IM
M<V=S='(@(H])E[DB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"B,L
M('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T
M(@IM<V=S='(@(B5S((+P('II<"",8(ZN@L6#7X-%@Y.#C8%;@V@B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU,@IM<V=I9"`B1&]W;FQO
M860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I(@IM<V=S='(@(I-9
ME72"\)%3@L2#7X-%@Y.#C8%;@VB!:2YZ:7`@@W2#0(-#@XN"Q8%J(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C`*;7-G:60@(D1O=VYL
M;V%D($9O;&1E<BAS*2(*;7-G<W1R("*#=(-(@XN#7X+P@U^#18.3@XV!6X-H
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*;7-G:60@
M(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=(@IM<V=S='(@(H-T
M@TB#BX-?@O"#7X-%@Y.#C8%;@VB!:7II<"",8(ZN@6HB"@HC.B!L:6(O34E-
M12]#;VYT96YT<RYP:'`Z,3DR"FUS9VED(")$;W=N;&]A9"!I;B`N>FEP($9O
M<FUA="(*;7-G<W1R(")Z:7`@C&".KH+%@U^#18.3@XV!6X-H(@H*(SH@;65S
M<V%G92YP:'`Z-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT
M,0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R
M869T(@IM<V=S='(@(HFZCY&"JR(*"B,Z(&9O;&1E<G,N<&AP.C,Y,@IM<V=I
M9"`B1')A9G0@9F]L9&5R(@IM<V=S='(@(HFZCY&"JX-T@TB#BX-?(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R
M869T<R!F;VQD97(Z(@IM<V=S='(@(HFZCY&"JX-T@TB#BX-?(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I9"`B12UM86EL($%D9')E<W,B
M"FUS9W-T<B`B@X&!6X.+@T&#:(.,@U@B"@HC.B!L:6(O36%I;&)O>"YP:'`Z
M,S`Y"FUS9VED(")%3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2.B!9;W5R(&UE<W-A9V4@8V]U
M;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP
M:'`Z-#(P('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ.0IM<V=I
M9"`B161I="(*;7-G<W1R("*5TH]7(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C$X"FUS9VED(")%9&ET($)L86-K;&ES="(*;7-G<W1R("*#
M=8.)@V*#3H.*@UB#9X+PE=*/5R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHQ,PIM<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(H-T@T*#
MBX->@XN!6X.+@O"5TH]7(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E
M<R]S96%R8V@O:&5A9&5R+FEN8SHQ-@IM<V=I9"`B161I="!6:7)T=6%L($9O
M;&1E<B(*;7-G<W1R("*)O)%Z@W2#2(.+@U^"\)72CU<B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T
M<B`B)7,@EW""S(F\D7J#=(-(@XN#7X+PE=*/5R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHR,PIM<V=I9"`B161I="!7:&ET96QI<W0B"FUS
M9W-T<B`B@WJ#CX-#@V>#BH-8@V>"\)72CU<B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B
M"FUS9W-T<B`B@W6#B8-B@TZ#BH-8@V>"\)72CU<B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@
M<G5L97,B"FUS9W-T<B`B@W2#0H.+@UZ#BX%;@XN"\)72CU<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#8Q"FUS9VED(")%9&ET('EO=7(@<')E9F5R
M96YC97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+B(*;7-G
M<W1R("*1O(+,@U2!6X-O@LR#08-*@T6#DX-G@O"0W9+H@K6"Q(FZ@K."HH%"
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"FUS9VED(")%
M9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(H-Z@X^#0X-G@XJ#6(-G@O"5
MTH]7(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,SD*
M;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B@X&!6X.+@T&#:(.,@U@B
M"@HC.B!L:6(O365S<V%G92YP:'`Z-C4W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R
M("(E9(+,@X&!6X.+@O`E<X*I@N>#0X.3@WR!6X-G@K6"W(*U@KV!0B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T
M>2!&;VQD97(H<RDB"FUS9W-T<B`B@W2#2(.+@U^"\(OS@LF"MX+I(@H*(SH@
M9F]L9&5R<RYP:'`Z,C@V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!396QE8W1E
M9"!&;VQD97)S(@IM<V=S='(@(H-T@TB#BX-?@O"+\X+)@K>"Z2(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")%;7!T>2!4
M<F%S:"!F;VQD97(B"FUS9W-T<B`B@U.#?I2@@O"+\X+)@K>"Z2(*"B,Z(&QI
M8B])35`N<&AP.CDW,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@7U-P86TB"FUS
M9W-T<B`B7U2#4X-^E*"0M)%\(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED
M(")%;7!T>2!?5')A<V@B"FUS9W-T<B`B7U2#4X-^E*"0M)%\(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N
M:6YC.C8*;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\B"FUS9W-T
M<B`B4$=0((+PCF>7<(*U@MR"MX*I@4@B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM
M<V=I9"`B16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")3
M+TU)344@@O".9Y=P@K6"W(*W@JF!2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,3$*;7-G:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G
M<W1R("*#@8-B@UJ!6X-7@LR#=H.,@W*#A8%;@O".9Y=P@K6"W(*W@JF!2"(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0T,@IM<V=I9"`B
M16YC<E]Y<'1I;VX@3W!T:6]N<R(*;7-G<W1R(")?68C#C8:#28-V@U:#AX.3
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q-R!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C4W"FUS9VED(")%;F0B"FUS9W-T<B`BCTF7N2(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#0*;7-G:60@(D5N9"!F;W)W87)D960@
M;65S<V%G92(*;7-G<W1R("*379&7@X&!6X.+@LV(R(_C@L6"MR(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS-#$*(RP@9G5Z>GD*;7-G:60@(D5N9"!M97-S86=E
M(@IM<V=S='(@(HKYD;:"S(.!@5N#BR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5N9"!M97-S86=E(&9R
M;VT@)7,B"FUS9W-T<B`B)7,@@JF"YX+,@X&#8H-:@5N#5R(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<W"FUS9VED(")%;G1E<B!087-S<&AR87-E(@IM<V=S='(@(H-P@UB#=(.,
M@5N#68+PD_R7S2(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN
M8SHY"B,L(&9U>GIY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@4W!A;2!F;VQD97(B"FUS9W-T<B`BD%:"M8*B@U.#?I2@@W2#2(.+@U^"
MS):\D4^"\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O
M<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(I!6@K6"HHFZCY&"
MJX-T@TB#BX-?@LR6O)%/@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(S"FUS9VED(")%;G1E
M<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G
M<W1R("*05H*U@J*1EY!-C52"IH-T@TB#BX-?@LR6O)%/@O".=Y+H@K6"Q(*M
M@KZ"LX*B@4(B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC
M.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F
M;VQD97(B"FUS9W-T<B`BD%:"M8*B@U.#?I2@@W2#2(.+@U^"S):\D4^"\(YW
MDNB"M8+$@JV"OH*S@J*!0B(*"B,@;7-G<W1R("*#BH-?@T.#C(-.@V<B"B,Z
M(&QI8B]396%R8V@N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")%;G1I<F4@365S
M<V%G92(*;7-G<W1R("*#@8%;@XN"\(*[@LR"W(+<DUV1EX*W@NDB"@HC.B!M
M97-S86=E+G!H<#HQ.30@8V]M<&]S92YP:'`Z,3$S-"!T:')E860N<&AP.C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(%PB)7-<(B!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B7"(E
M<UPB((+&@J*"I(-'@Y.#9X.*@JJ#08-H@XR#6)*@@LF2QXG!@K."ZH+<@K6"
MO8%"(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ."!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HS-S8@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S@V"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T<B`B@T>#B8%;(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HT-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E<G9E<BX@)7,@.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,P.2!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#`W"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R("*5U)!-@T>#B8%;@48@
M)7.!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#$*;7-G:60@
M(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("*#0X-X@Y.#
M9X+-C>V/G(*S@NJ"W(*U@KV!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.#(*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B,34@E:J6
MB"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-SD*;7-G:60@(D5V97)Y
M(#,P('-E8V]N9',B"FUS9W-T<B`B,S`@E6*6B"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.#$*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R
M("(U()6JEH@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@S"FUS9VED
M(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B,S`@E:J6B"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R("(Q()6JEH@B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X<&%N
M9"(*;7-G<W1R("*35XI*(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`B@K>"UX+$@O"3
M5XI*(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G
M:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R("*"MX+7@L2"S(-T@TB#
MBX-?@O"35XI*(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED(")%>'!A;F0@
M1F]L9&5R(@IM<V=S='(@(H-T@TB#BX-?@O"35XI*(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(I:\
MD4^"\)-7BDHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V,PIM<V=I
M9"`B17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T
M:6-A;&QY(&EN('1H92!B86-K9W)O=6YD/R(*;7-G<W1R("*#@8%;@XN-[)"L
MCIZ"R9:\D4^"S)-7BDJ"S8ZIDZZ"Q8US@J*"W(*W@JF!2"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.#`*;7-G:60@(D5X<&%N9"!T:&4@96YT:7)E
M(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\B
M"FUS9W-T<B`B@W2#2(.+@U^"S(-F@W2#2(.+@V>57(ZF@L6#=(-(@XN#7X-C
M@XJ!6Y%3D<R"\)-7BDJ"M8+<@K>"J8%((@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,30T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C$Y-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0IM<V=I9"`B17AP
M86YD:6YG(@IM<V=S='(@(I-7BDJ2AB(*"B,Z(&QI8B])35`N<&AP.CDX-"!L
M:6(O24U0+G!H<#HY.#8*(RP@9G5Z>GD*;7-G:60@(D9?971C:"!-86EL(@IM
M<V=S='(@(H.!@5N#BX+,CN:"Z(V>@MTB"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V9E=&-H;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-`IM<V=I9"`B1F5T8V@@36%I;"(*;7-G<W1R("*#@8%;@XN"S([F@NB-GH+=
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V.0IM<V=I9"`B1F5T8V@@
M36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`BE<J#18-#@Y.#
M:(%;@L6.YH+HC9Z"W8+P@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O
M;B!L;V=G:6YG(&]N/R(*;7-G<W1R("*#C8-/@T.#DXZ>@LF#@8%;@XN"\([F
M@NB-GH+=@MR"MX*I@4@B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@
M9G)O;2`E<R(*;7-G<W1R("(E9""2RH+,@X&!6X.+@O`@)7,@@JF"YX[F@NB-
MGH+=@MR"M8*](@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S
M(@IM<V=S='(@(B5D()+*@LR#@8%;@XN"\"`E<R""J8+GCN:"Z(V>@MV"W(*U
M@KTB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP
M:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!F=7IZ>0IM<V=I9"`B
M1F5T8VAM86EL.B`B"FUS9W-T<B`B@X&!6X.+@LR.YH+HC9Z"W2(*"B,Z(&QI
M8B]&971C:&UA:6PN<&AP.C(Y,0IM<V=I9"`B1F5T8VAM86EL.B!N;R!N97<@
M;65S<V%G97,N(@IM<V=S='(@(D9E=&-H;6%I;#H@D%:2A8.!@5N#BX+(@K6!
M0B(*"B,Z(&QI8B])35`N<&AP.CDY,`IM<V=I9"`B1FE?;'1E<G,B"FUS9W-T
M<B`B7TR#=(-"@XN#7B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C4P,B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHX,@IM
M<V=I9"`B1FEL92(*;7-G<W1R("*#=(-`@T.#BR(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHS,0IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS
M9W-T<B`B@W2#0H.+@UZ#28-V@U:#AX.3(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.CD*;7-G:60@(D9I;'1E<B!3971T:6YG<R(*;7-G<W1R
M("*#=(-"@XN#7I#=DN@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`P
M"FUS9VED(")&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_
M(@IM<V=S='(@(I5SDTN0V(+(@X&!6X.+D^"798+P@W2#0H.+@UZ"M8+<@K>"
MJ8%((@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHQ,0IM
M<V=I9"`B1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T
M96TN(@IM<V=S='(@(H-T@T*#BX->@LV"L8+,@U:#6(-E@X""Q8+-EK.,^(+)
M@LB"P8+$@J*"W(*W@4(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W
M"FUS9VED(")&:6QT97)S(@IM<V=S='(@(H-T@T*#BX->(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHS"FUS9VED(")&:6QT97)S($Y/
M5"!!8W1I=F4B"FUS9W-T<B`B@W2#0H.+@UZ"S9:SC/@B"@HC.B!L:6(O1FEL
M=&5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@
M;6%N86=E;65N="!P86=E(@IM<V=S='(@(H-T@T*#BX->@4:!0"5S((K'EYV#
M>8%;@U<B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X
M-@IM<V=I9"`B1FEN9"(*;7-G<W1R("*,GXWU(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP-0IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E(@IM<V=S
M='(@(H.!@5N#BX-[@V*#3H-8@LR-Q8^)@LR#>8%;@U<B"@HC.B!M86EL8F]X
M+G!H<#HS-#4*;7-G:60@(D9I<G-T(%!A9V4B"FUS9W-T<B`BC<6/B8+,@WF!
M6X-7(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")&
M;U]R=V%R9"(*;7-G<W1R(")?4I-=D9<B"@HC.B!F;VQD97)S+G!H<#HR-C8@
M=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ-0IM<V=I
M9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*
M(SH@9F]L9&5R<RYP:'`Z,S`S('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC
M.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHV
M"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,3`*
M;7-G:60@(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T<B`B@W2#2(.+@U^1@(WL
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D9O;&1E<B!3
M=6UM87)Y(@IM<V=S='(@(H-T@TB#BX-?BE27=B(*"B,Z(&%C;"YP:'`Z,C0*
M;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R
M("*+I)=,@W2#2(.+@U^"S8YGEW"5<XG"@4(B"@HC.B!F;VQD97)S+G!H<#HV
M,@IM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B
MBZ273(-T@TB#BX-?CF>7<(G"E%R!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-CD*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H
M92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S
M='(@(H.!@5N#BX-[@V*#3H-8E5R.IH+)@JB"KX+IC:&3^H+,@X&#8H-:@5N#
M5X+,CIZ*U)5<CJ:,8(ZN(@H*(SH@8V]M<&]S92YP:'`Z-S@P('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R
M("*379&7(@H*(SH@8V]M<&]S92YP:'`Z-S8U"FUS9VED(")&;W)W87)D.B(*
M;7-G<W1R("*379&7.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-CD*;7-G:60@
M(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(I-=D9>"LX+J@KV#@8%;@XLB
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@
M(D9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B)7,@@JF"YY-=
MD9>"LX+J@KV#@8%;@XLB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#@S"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`BEUR2
MZ(_NE?$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DT"FUS9VED
M(")&<F5E+T)U<WD@4F5P;'DB"FUS9W-T<B`BEUR2Z(_NE?&)GI.:(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`IM<V=I9"`B1G)E92]"=7-Y
M(%)E<75E<W0B"FUS9W-T<B`BEUR2Z(_NE?&7=HN!(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0P,0IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0@
M4F5S<&]N<V4B"FUS9W-T<B`BEUR2Z(_NE?&7=HN!B9Z3FB(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R
M;U]M(@IM<V=S='(@(E]-C;>/;Y!L(@H*(SH@;65S<V%G92YP:'`Z,C8S('1H
M<F5A9"YP:'`Z,30Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.CDY
M"B,Z(&QI8B]396%R8V@N<&AP.C(R"B,L(&9U>GIY"FUS9VED(")&<F]M(@IM
M<V=S='(@(E]-C;>/;Y!L(@H*(R!M<V=S='(@(HVWCV^0;"(*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDQ.`IM<V=I9"`B1G)O;2!!9&1R97-S(@IM<V=S
M='(@(I&7D$V,LX-!@VB#C(-8(@H*(SH@8V]M<&]S92YP:'`Z-S<W(&-O;7!O
M<V4N<&AP.C<X,0IM<V=I9"`B1G=D.B(*;7-G<W1R("*379&7@48B"@HC.B!C
M;VUP;W-E+G!H<#HQ,CDT"FUS9VED(")&=V0Z("(*;7-G<W1R("*379&7.B`B
M"@HC.B!C;VUP;W-E+G!H<#HQ,CDV"B,L('!H<"UF;W)M870*;7-G:60@(D9W
M9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(I-=D9<Z("5U()+*
M@LR379&7@K."ZH*]@X&!6X.+(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")'
M96YE<F%L($]P=&EO;G,B"FUS9W-T<B`BB.J4RI-)@TF#=H-6@X>#DR(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS-PIM<V=I9"`B1V5T
M(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*2(*;7-G<W1R("*05I*%
M@X&!6X.+@LR"W8[F@NB-GH+=@6E)34%0((-4@5N#;X+,@MV!:B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Q"FUS9VED(")';R(*;7-G
M<W1R("(B"@HC.B!T:')E860N<&AP.C$S-@HC+"!F=7IZ>0IM<V=I9"`B1V\@
M=&\@365S<V%G92(*;7-G<W1R("*.GX+,@X&!6X.+(@H*(SH@;&EB+TE-4"YP
M:'`Z-#DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")';R!T;R!A9&1R
M97-S(&)O;VL@96YT<GD@;V8@7"(E<UPB(@IM<V=S='(@(H-!@VB#C(-8DJ""
MR9+'B<&!:25S@6HB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3,U"FUS
M9VED(")'<F%N="!A8V-E<W,B"FUS9W-T<B`B@T&#3H-:@UB"\(N6B<(B"@HC
M.B!M97-S86=E+G!H<#HU-#8@;&EB+T9I;'1E<BYP:'`Z,3`U(&QI8B]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.CDU"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$P,B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,38*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*
M(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z-#$X"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O
M=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%4D4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,Q(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,3<*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP
M.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C(U
M-@IM<V=I9"`B2%1-3"!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B2%1-
M3"",8(ZN(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`B@W>#8H-?(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M
M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B@K&"ZH*JC>R0
MK)*&@LR#@8%;@XN"Q8*W@48B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C8X"FUS9VED(")(:61D96XB"FUS9W-T<B`BB4*"MR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-C<*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE
M=R(*;7-G<W1R("*#6(.,@V*#:)5<CJ:"Q8+-B4*"MR(*"B,Z(&UA:6QB;W@N
M<&AP.C,V-PIM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@(HWMCYR-SX+=
M@O"4\95<CJ8B"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(DAI9&4@56YS
M=6)S8W)I8F5D(@IM<V=S='(@(I3QC7>3QX[2@O"4\95<CJ8B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B"FUS
M9W-T<B`BC8(B"@HC.B!M97-S86=E+G!H<#HR.3<@;6%I;&)O>"YP:'`Z-S(T
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI9V@@
M4')I;W)I='DB"FUS9W-T<B`BET20YI-XC8(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T<B`B
MC<6-@B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#@*;7-G:60@(DAO
M=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/R(*;7-G<W1R
M("*3695T@O""QX*DE5R.IH*U@MR"MX*I@4@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`T"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E9"!L
M:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(I74D$V.GH+,B/B7<(OE(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-
M05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B24U!4(%ICJF3
MKI2[E<J!:B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,SDQ"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO
M;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C8@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-3(*;7-G:60@(DE-05`@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-PIM<V=I9"`B24U!4"!O=F5R(%-3
M3"`H<V5L9BUS:6=N960I(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,S8X"B,L(&9U>GIY"FUS9VED("))34%0('-E<G9E<B!C;&]S960@
M=&AE(&-O;FYE8W1I;VXN(@IM<V=S='(@(I#:D;&"MX+I@X&!6X.+@U2!6X-O
M@LR.[9?>@48B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z-#D*;7-G
M:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TE-4"YP:'`Z.#8V"FUS9VED("))3D)/6"(*;7-G<W1R("(B"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,
M4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO
M861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R
M<U]C;VYF:7)M+FAT;6PZ,3(*(RP@9G5Z>GD*;7-G:60@(DEF('EO=2!C;VYT
M:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L
M;W-T(2(*;7-G<W1R("*#=(-(@XN#7Y/@@LR#@8%;@XN"S8*W@M>"Q)1JBOR"
MLX+J@MR"MX%)(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C@R"FUS9VED("))9VYO<F4B"FUS9W-T<B`BEK..BR(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*
M;7-G<W1R("*"MX+7@L26LXZ+(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S
M879E:6UA9V4N:6YC.C@*;7-G:60@(DEM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C`*;7-G:60@(DEM<&]R="(*
M;7-G<W1R("*#0X.3@WR!6X-G(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C4*
M;7-G:60@(DEM<&]R="!+97DB"FUS9W-T<B`BC*Z"S(-#@Y.#?(%;@V<B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y"FUS9VED("));7!O<G0@2V5Y
M<&%I<B(*;7-G<W1R("*,KH-Y@T&"S(-#@Y.#?(%;@V<B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B26UP
M;W)T($UE<W-A9V5S(@IM<V=S='(@(H]DEW:"R(.!@5N#BR(*"B,Z('!G<"YP
M:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@(E!'4"",KH+,
M@T.#DX-\@5N#9R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3$*
M(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*
M;7-G<W1R("*,PI!L@LR/V):^CY&"\(-#@Y.#?(%;@V<B"@HC.B!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N
M86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@(HS"D&R"S"!01U`@E.F6IXRN
M@O"#0X.3@WR!6X-G(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB"FUS
M9W-T<B`BC,*0;(+,(%!'4"",]HI*C*Z"\(-#@Y.#?(%;@V<B"@HC.B!T96UP
M;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!E
M<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,B"FUS9W-T<B`BC,*0;(+,(%,O
M34E-12"/V):^CY&"\(-#@Y.#?(%;@V<B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O<&=P+FEN8SHT,@IM<V=I9"`B
M26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`BC/:*2HRN@LR#0X.3@WR!6X-G
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("))
M;7!O<G0@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B4$=0((SVBDJ,KH+,@T.#
MDX-\@5N#9R(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX
M"FUS9VED("));7!O<G0@4'5B;&EC(%,O34E-12!+97DB"FUS9W-T<B`B4R]-
M24U%((SVBDJ,KH+,@T.#DX-\@5N#9R(*"B,Z('-M:6UE+G!H<#HQ-@IM<V=I
M9"`B26UP;W)T(%,O34E-12!+97DB"FUS9W-T<B`B4R]-24T@C*Z"S(-#@Y.#
M?(%;@V<B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.CD*;7-G
M:60@(DEM<&]R="!M8F]X($9I;&4B"FUS9W-T<B`B34)/6(Q@CJZ"S(-T@T"#
M0X.+@O"#0X.3@WR!6X-G(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T
M+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@;6)O>"!F:6QE
M("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G<W1R(")-0D]8C&".KH+,@W2#0(-#
M@XLE<X+P)7."R8-#@Y.#?(%;@V<B"@HC.B!M97-S86=E+G!H<#HU,#(@;6%I
M;&)O>"YP:'`Z-S,T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$V('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;&5G96YD+FEN8SHW"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`B
MCV27=B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-#<*;7-G:60@
M(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R("*/9)=V@LB#@8%;@XLB"@HC
M.B!F;VQD97)S+G!H<#HQ-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M960@)60@;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T<B`B)62"S(.!@5N#BX+P
M)7."J8+G@T.#DX-\@5N#9X*U@MR"M8*]@4(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S<S"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@(H^(
MEYV2AB(*"B,Z(&9O;&1E<G,N<&AP.C,X-"!L:6(O1F]L9&5R+G!H<#HX-B!L
M:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-4"YP:'`Z,S$S"B,Z(&QI8B])34%0
M+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4<F5E+G!H<#HR,3D*;7-G:60@(DEN
M8F]X(@IM<V=S='(@(DE.0D]8(@H*(R!C;W5R:65R+6EM87`@@O".9X+!@L2"
MHH+IC^J-APHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR"FUS9VED("))
M;F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P
M;'D_(@IM<V=S='(@(I74D$V.GH+)@W>#8H-?@LR(ZI64@O"5=(G!@K6"W(*W
M@JF!2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#<*;7-G:60@(DEN
M8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/R(*;7-G<W1R("*5
MU)!-CIZ"R8RS@LR#@8%;@XN"\(CXEW""M8+<@K>"J8%((@H*(SH@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z,3,P"FUS9VED("));F9O(@IM<V=S='(@(H_NE?$B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26YF;W)M
M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*;7-G<W1R("*,]HI*C*Z"S(-#@Y.#
M?(%;@V<B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*(RP@9G5Z>GD*
M;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM
M<V=S='(@(HS"D&R"S"!01U`@E.F6IXRN@O"#0X.3@WR!6X-G(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S(*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L
M(%!U8FQI8R!+97DB"FUS9W-T<B`BC,*0;(+,(%!'4"",]HI*C*Z"\(-#@Y.#
M?(%;@V<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z
M,34@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`W"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDX"B,L(&9U>GIY"FUS9VED
M("));FQI;F4B"FUS9W-T<B`B@LB"M2(*"B,Z('1E;7!L871E<R]S;6EM92]I
M;7!O<G1?:V5Y+FEN8SHY"B,L(&9U>GIY"FUS9VED("));G-E<G0@0V5R=&EF
M:6-A=&4@2&5R92(*;7-G<W1R("*,PI!L@LR/V):^CY&"JI=>@J:"YX+J@L2"
MHH+<@KF"\2(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,34*
M(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!097)S;VYA;"!0<FEV871E(%!'4"!+
M97D@2&5R92(*;7-G<W1R("*,PI!L@LP@4$=0()3IEJ>,KH+P@T.#DX-\@5N#
M9R(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,3`*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2!(97)E
M(@IM<V=S='(@(HS"D&R"S"!01U`@C/:*2HRN@O"#0X.3@WR!6X-G(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"B,L(&9U>GIY"FUS9VED
M("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R(")01U`@C/:*
M2HRN@LR#0X.3@WR!6X-G(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0Q,@IM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@
M8V]M<&]N96YT+B(*;7-G<W1R("*5<Y"S@LB/B))U@O"129'P@K6"W(*U@KV!
M0B(*"B,Z(&UA:6QB;W@N<&AP.C4X-"!M86EL8F]X+G!H<#HV,C8*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R("*#@8%;@XN#08-H
M@XR#6"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,S`W"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM<V=S='(@(H.*@X*!
M6X-G@LR#@8%;@XN#>X-B@TZ#6):\@48B"@HC.B!C;VUP;W-E+G!H<#HQ-3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@8VAA<F%C=&5R
M(&EN(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B@X&!6X.+@T&#:(.,
M@UB"R95SD+."R)6VCIJ"JHK<@MR"ZH+$@J*"W(*W@4(B"@HC.B!S;6EM92YP
M:'`Z.#(@<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K97DB"FUS9W-T<B`B
ME7.0LX+(C*XB"@HC.B!P9W`N<&AP.C$Y-@IM<V=I9"`B26YV86QI9"!P97)S
M;VYA;"!01U`@<')I=F%T92!K97DN(@IM<V=S='(@(I5SD+."R"!01U`@E.F6
MIXRN@L6"MX%"(@H*(SH@<&=P+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@<&5R
M<V]N86P@4$=0('!U8FQI8R!K97DN(@IM<V=S='(@(I5SD+."R"!01U`@C/:*
M2HRN@L6"MX%"(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M,@IM<V=I9"`B26YV97)T(@IM<V=S='(@(I2]DUTB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`BC*Z"S)*W@K,B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO
M;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E
M;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED(")+97D@
M:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E
M;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P+FEN8SHS
M.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@
M:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C
M;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME
M>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`BC*Z"S8SVBDJ,KH-4@5N#;X+)D9>"YX+J@MR"M8*]@4(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(Q-@IM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`BC+Z,ZI#=DN@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3`V"FUS9VED("),87-T($UA:6QB;W@@4&%G92(*;7-G<W1R("*#@8%;
M@XN#>X-B@TZ#6(+,C<6,XX+,@WF!6X-7(@H*(SH@;6%I;&)O>"YP:'`Z,S4X
M"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`BC<6,XX+,@WF!6X-7(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@Y"FUS9VED("),:5]N
M:R!!='1A8VAM96YT<R(*;7-G<W1R(")?3H.*@Y.#3HQ>DUF5="(*"B,Z(&%T
M=&%C:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED("),
M:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B@XJ#
MDX-.C%Z3695T@LV.9Y=P@L6"JX+<@KF"\8%"(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL;"!E>'!I
M<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN
M9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL
M("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP
M;&EC:71L>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8X-0IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A9&5R(@IM<V=S='(@(H-W
M@V*#7Y64@LF(ZI>7E5R.IB(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHS,`IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`B@XV!
M6X-*@XN"S(.!@5N#BX-[@V*#3H-8EKR!1B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-S0*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(H_JCXHB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R-0IM<V=I9"`B3&]G
M(&EN(@IM<V=S='(@(H.-@T^#0X.3(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("),;V<@:6X@=&\@)7,B"FUS
M9W-T<B`B)7,@@LF#C8-/@T.#DR(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3,W"FUS9VED("),;V=I;B(*;7-G<W1R("*#C8-/@T.#DR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B3&]G:6X@5&%S:W,B
M"FUS9W-T<B`B@XV#3X-#@Y.#7H-8@TXB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR.38*;7-G:60@(DQO=R(*;7-G<W1R("*2X2(*"B,Z
M(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X+G!H<#HW,C<@=&5M<&QA=&5S+VUA
M:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S
M='(@(I+AET20YI-X(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,CDW"FUS9VED("),;W=E<W0B"FUS9W-T<B`BC<62X2(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@
M(DUA8VEN=&]S:"!&:6QE(@IM<V=S='(@(I-9E72#=(-`@T.#BR(*"B,Z('1E
M;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I
M9"`B36%I;"(*;7-G<W1R("*#@8%;@XN#>X-B@TZ#6"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM
M<V=S='(@(I#:D;&"MX+I@X&!6X.+@U2!6X-O@LR.[9?>@48B"@HC.B!F;VQD
M97)S+G!H<#HT,#(*;7-G:60@(DUA:6QB;W@B"FUS9W-T<B`B@X&!6X.+@WN#
M8H-.@U@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"FUS9VED(")-
M86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(H.!
M@5N#BX-[@V*#3H-8@L:#=(-(@XN#7X+,E5R.IH-)@W:#5H.'@Y,B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!
M;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%-E96XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@
M06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHU('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S`*;7-G:60@(DUA<FL@87,Z
M(@IM<V=S='(@(HCS@O"5=(*O@NF!1B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T
M:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`BB/B7<)64E:J"
M\)7*@LR01H+%E5R.IH*U@MR"MX*I@4@B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E
M;C\@*$E-05`@;VYL>2DB"FUS9W-T<B`BBOF3QX+)@K6"W(*W@JF!2(%I24U!
M4(-4@5N#;X+,@MV!:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3@*
M;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T<B`BD;Z.FH%!B;J0
M_(%!CLZ1S(+PDE"/@X+)E5R.IH*U@MR"MX*I@4@B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@(DUA=&-H($%L;"!1=65R:65S
M(@IM<V=S='(@(I%3@L2"JHCJDG:"MX+I(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]H96%D97(N:6YC.C0R"FUS9VED(")-871C:"!!;GD@475E<GDB"FUS9W-T
M<B`B@L>"ZH*I@JJ(ZI)V@K>"Z2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4Q,PIM<V=I9"`B36%X:6UU;2!!='1A8VAM96YT(%-I>F4B
M"FUS9W-T<B`BC<61Y9-9E72#5(-#@UDB"@HC.B!L:6(O87!I+G!H<#HW.0HC
M+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@1F]L9&5R<R(*;7-G
M<W1R("*3695TD)2"S(_CC,""R9)"@K6"W(*U@KV!0B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-`IM<V=I9"`B36%X:6UU;2!N=6UB
M97(@;V8@871T86-H;65N=',@<F5A8VAE9"XB"FUS9W-T<B`BDUF5=)"4@LR/
MXXS`@LF20H*U@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT.#D*;7-G:60@(DUA>&EM=6T@=&]T86P@871T86-H;65N="!S
M:7IE(')E86-H960N(@IM<V=S='(@(I-9E72#5(-#@UF"S(_CC,""R9)"@K6"
MW(*U@KV!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C8*;7-G
M:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@(HGOBV."S([FC\&"
MM2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S4*;7-G:60@(DUE
M971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`BB>^+8X+,C^Z5\2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I;F<@4')O
M<&]S86PB"FUS9W-T<B`BB>^+8X+,DO&(Q"(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,3<*;7-G:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B
MB>^+8X+,E=2.EB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3@*
M;7-G:60@(DUE971I;F<@57!D871E(@IM<V=S='(@(HGOBV."S)7/C5@B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`S"FUS9VED(")-965T:6YG
M(%5P9&%T92!297%U97-T(@IM<V=S='(@(HGOBV.5SXU8@LR7=HN!(@H*(SH@
M;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B
M365N=2!&;VQD97(@3&ES="(*;7-G<W1R("*#=(-(@XN#7Y%)D?`B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S,Q"FUS9VED(")-97-S86=E(@IM<V=S='(@(H.!
M@5N#BR(*"B,Z(&-O;7!O<V4N<&AP.C4V,"!C;VUP;W-E+G!H<#HU.#<@8V]M
M<&]S92YP:'`Z-C0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B
M365S<V%G92!#;VUP;W-I=&EO;B(*;7-G<W1R("*#@8%;@XN-[)"L(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E
M(@IM<V=S='(@(H.!@5N#BX+,D_J5="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M,PIM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(H.!@V*#6H%;@U>#
M28-V@U:#AX.3(@H*(SH@<V5A<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@
M4V5A<F-H(@IM<V=S='(@(H.!@5N#BX+,C)^-]2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,C$*;7-G:60@(DUE<W-A9V4@4VEZ92(*;7-G<W1R("*#
M@8%;@XN#5(-#@UDB"@HC.B!M97-S86=E+G!H<#HS.#0*;7-G:60@(DUE<W-A
M9V4@4V]U<F-E(@IM<V=S='(@(H.!@5N#BX-<@5N#6"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G92!6:65W:6YG(@IM<V=S
M='(@(H.!@5N#BY5<CJ8B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`B@X&!6X.+@W2#B8-/
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX,PIM<V=I9"`B365S
M<V%G92!F;VQD97)S(@IM<V=S='(@(H.!@5N#BX-T@TB#BX-?(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E
M(&9R;VT@)7,B"FUS9W-T<B`B)7,@@JF"YX+,@X&#8H-:@5N#5R(*"B,Z(&UA
M:6QB;W@N<&AP.C8V-PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!H87,@871T
M86-H;65N=',B"FUS9W-T<B`BB.J2=H_PC(\B"@HC.B!M86EL8F]X+G!H<#HV
M-3@*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@96YC<GEP=&5D(@IM<V=S
M='(@(H.!@5N#BX-T@T*!6X.+@V@B"@HC.B!M86EL8F]X+G!H<#HV-3,*(RP@
M9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(H.!@5N#
MBX-T@T*!6X.+@V@B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z
M,S,*;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R("*(ZI)VC_",CR(*
M"B,Z(&-O;7!O<V4N<&AP.C@R-"!C;VUP;W-E+G!H<#HX,S@*;7-G:60@(DUE
M<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(H.!@V*#
M6H%;@U>"S9-=D9>"LX+J@MR"M8*]@4(B"@HC.B!C;VUP;W-E+G!H<#HQ,#@T
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L
M;'DL(&)U="!N;W0@<V%V960@=&\@)7,B"FUS9W-T<B`B@X&#8H-:@5N#5X+-
MD9>038*S@NJ"W(*U@KV"JH%!)7,@@LF5VY&V@K."ZH+$@J*"W(*Y@O$B"@HC
M.B!C;VUP;W-E+G!H<#HQ,30S(&-O;7!O<V4N<&AP.C$Q-3@*;7-G:60@(DUE
M<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN(@IM<V=S='(@(H.!@V*#6H%;@U>"
MS)&7D$V0K(SW(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,0IM<V=I
M9"`B365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB"FUS
M9W-T<B`B@X&!6X.+@WN#8H-.@UB57(ZF@LR*98-Y@5N#5X+)E5R.IH*S@NJ"
MZ8.!@5N#BY"4(@H*(SH@;6%I;&)O>"YP:'`Z,S(R"FUS9VED(")-97-S86=E
M<R!T;R(*;7-G<W1R("*#@8%;@XN"S(C:DZZ0YB(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHR.0IM<V=I9"`B36]D:69Y(@IM<V=S='(@(H]#D+,B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.C$R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")-;W)E('1H86X@;VYE(&%D9')E<W,@9F]U;F0@
M9F]R(&9I96QD(%PB)7-<(BXB"FUS9W-T<B`B)R5S)X+)@E""PHC(C^."S(-!
M@VB#C(-8@JJ"H(+H@MR"MX%"(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C4P"FUS9VED(")-;W9E(@IM<V=S='(@(HC:DZXB"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,38*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R("*)NH+6B-J3KB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,3@*;7-G:60@(DUO=F4@<W!A;2!M97-S86=E<R!T;R!S<&%M(&9O;&1E
M<B!A;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@24Y"3U@B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E('1O
M(&9O;&1E<B(*;7-G<W1R("*#=(-(@XN#7X+)B-J3KB(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-`IM<V=I9"`B36]V92!U<"(*
M;7-G<W1R("*/XX+6B-J3KB(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA
M=&EV92YP:'`Z,3(W"FUS9VED(")-=6QT:7!A<G0O86QT97)N871I=F4B"FUS
M9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HW-B!T:')E860N<&AP.C$U,@HC+"!F
M=7IZ>0IM<V=I9"`B375L=&EP;&4@365S<V%G92!6:65W(@IM<V=S='(@(H.!
M@5N#BY5<CJ8B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E
M;&5C="YI;F,Z-0IM<V=I9"`B3D].12(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED(").
M3U1%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@
M(DYA;64B"FUS9W-T<B`BEKR13R(*"B,Z('!G<"YP:'`Z,3$P"FUS9VED(").
M86UE(&%N9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-S@*;7-G:60@(DYE961S
M($%C=&EO;B(*;7-G<W1R("*/B))U@JJ52Y=V@L6"MR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-S`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<X"FUS9VED(").979E<B(*;7-G
M<W1R("*"R(*U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`IM<V=I
M9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R("*3695T@LV5VY&V
M@K6"R(*B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R-`IM<V=I9"`B
M3F5W(@IM<V=S='(@(I!6BTLB"@HC.B!L:6(O24U0+G!H<#HU-C,*;7-G:60@
M(DYE=R!&;VQD97(B"FUS9W-T<B`BD%:+2X-T@TB#BX-?(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@36%I;"(*;7-G<W1R("*0
M5I*%@X&!6X.+(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y(&QI8B]"
M;&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(").97<@
M365S<V%G92(*;7-G<W1R("*.GX+,@X&!6X.+(@H*(SH@;6%I;&)O>"YP:'`Z
M-S<V(&QI8B]-24U%+TAE861E<G,N<&AP.C$Y,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BD%:+2X.!
M@5N#BR(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@
M(DYE=R!M97-S86=E<R(*;7-G<W1R("*05HM+@X&!6X.+(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B3F5X="(*;7-G
M<W1R("*.GX+6(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHS,PIM<V=I9"`B3F5X="!-97-S86=E(@IM<V=S='(@(HZ?@LR#
M@8%;@XLB"@HC.B!M86EL8F]X+G!H<#HS-38*;7-G:60@(DYE>'0@4&%G92(*
M;7-G<W1R("*.GX+,@WF!6X-7(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-30R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S<*;7-G:60@
M(DYO(@IM<V=S='(@(H+(@K4B"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED(").
M;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R("*/V):^CY&"JHRIE72"J8+H
M@MR"N8+Q(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN
M8SHU"FUS9VED(").;R!%;F-R>7!T:6]N(@IM<V=S='(@(HC#C8:)NX*U@LB"
MHB(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y
M<R!I;B!+97ER:6YG(@IM<V=S='(@(HRN@XJ#DX-/@LV+\X+%@K<B"@HC.B!M
M86EL8F]X+G!H<#HS-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO
M($UE<W-A9V5S(@IM<V=S='(@(I!6BTN#@8%;@XLB"@HC.B!P9W`N<&AP.C$S
M-PHC+"!F=7IZ>0IM<V=I9"`B3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N
M(@IM<V=S='(@(E,O34E-12",]HI*C*Z"S8-#@Y.#?(%;@V>"LX+J@MR"N8+Q
M@L6"M8*]@4(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C@T"FUS
M9VED(").;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT(@IM<V=S='(@
M(HS"D&R"S(_8EKZ/D8*JEUZ"IH+G@NJ"Q(*B@MR"N8+Q(@H*(SH@;&EB+TUA
M:6QB;W@N<&AP.C,R.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT
M(@IM<V=S='(@(H]#D+.-SX+=@V6#3(-8@V<B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C$U"FUS9VED(").;R!0=6)L:6,@2V5Y<R!&;W5N9"(*
M;7-G<W1R("*,]HI*C*Z"JH*@@NB"W(*Y@O$B"@HC.B!S;6EM92YP:'`Z,34Q
M"FUS9VED(").;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B4R]-24U%((SVBDJ,KH+-@T.#DX-\@5N#9X*S@NJ"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY,`IM<V=I9"`B3F\@
M871T86-H;65N=',@9F]U;F0N(@IM<V=S='(@(I-9E72"JH*@@NB"W(*Y@O&!
M0B(*"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"FUS9VED(").;R!E;6%I
M;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+B(*;7-G
M<W1R("(B"@HC.B!A8VPN<&AP.C<R(&%C;"YP:'`Z.3@*;7-G:60@(DYO(&9O
M;&1E<B!S96QE8W1E9"XB"FUS9W-T<B`B@W2#2(.+@U^"JI%)D?""LX+J@L2"
MHH+<@KF"\8%"(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T,0IM<V=I
M9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN
M(@IM<V=S='(@(I!6DH6#@8%;@XN"\(-@@T:#8H-.@K>"Z8-T@TB#BX-?@JJ.
M=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9O;&1E<G,N<&AP.C(Q."!L:6(O
M1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED(").;R!F
M;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(H-T@TB#BX-?@JJ.=Y+H
M@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M-#<*(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G
M97,B"FUS9W-T<B`BC>V/G(*S@NJ"Q(*B@LB"HH.!@5N#BR(*"B,Z(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E
M<G,@=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`BC>V/G(*S@NJ"Q(*B
M@LB"HH.!@5N#BR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,C4*;7-G:60@(DYO
M(&UE<W-A9V4@8F]D>2!T97AT(@IM<V=S='(@(I9[E;:"R(*U(@H*(SH@;&EB
M+TUA:6QB;W@N<&AP.C,W,0IM<V=I9"`B3F\@;65S<V%G97,@;6%T8VAE9"!Y
M;W5R('-E87)C:"XB"FUS9W-T<B`BC)^-]8_PC(^"R8CJDG:"MX+I@X&#8H-:
M@5N#5X+-C*F"PH*I@NB"W(*Y@O&"Q8*U@KV!0B(*"B,Z('!G<"YP:'`Z,3@Y
M"B,L(&9U>GIY"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@
M:6UP;W)T960N(@IM<V=S='(@(I5SD+."R"!01U`@E.F6IXRN@L6"MX%"(@H*
M(SH@<&=P+G!H<#HQ-C4*(RP@9G5Z>GD*;7-G:60@(DYO('!E<G-O;F%L(%!'
M4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("*5<Y"S@L@@4$=0((SV
MBDJ,KH+%@K>!0B(*"B,Z('-M:6UE+G!H<#HR,#$*(RP@9G5Z>GD*;7-G:60@
M(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP;W)T960N(@IM
M<V=S='(@(HS"D&R"S"!3+TU)344@C]B6OH^1@O"#0X.3@WR!6X-G(@H*(SH@
M<W!E;&QI;F<N<&AP.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G
M<F%M(&-O;F9I9W5R960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S
M(@IM<V=S='(@(H-8@WF#BX-'@XF!6X+(@K4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*
M;7-G<W1R("*,\Y7B@LB"M2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-38T
M"FUS9VED(").;R!S=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H
M;V0@8V]U;&0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-C@@
M86-L+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<B!S<&5C:69I960N
M(@IM<V=S='(@(H-T@TB#BX-?@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#D*;7-G:60@(DYO;B!087)T
M:6-I<&%N="(*;7-G<W1R("*.48G!CM*(R(I/(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHQ,2!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS
M96QE8W0N:6YC.C0P"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,U('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(").;VYE(@IM<V=S
M='(@(H+(@K4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M.34*;7-G:60@(DYO<FUA;"(*;7-G<W1R("*2RH_M(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,Y"FUS9VED(").;W0@1&5L971E9"(*;7-G<W1R("*-[8^<@K."
MZH+$@J*"R(*B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHQ,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(S"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#(*;7-G:60@(DYO="!$
M<F%F="(*;7-G<W1R("*)NH^1@JN"Q8+(@J(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,T"FUS9VED(").;W0@26UP;W)T86YT(@IM<V=S='(@(H]DEW:"Q8+(@J(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS9VED(").
M;W0@4&5R<V]N86PB"FUS9W-T<B`BC,*0;)-)@L6"R(*B(@H*(SH@;&EB+T-R
M>7!T+U!'4"YP:'`Z,3,Y(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#
M<GEP="]334E-12YP:'`Z,30Y"B,L(&9U>GIY"FUS9VED(").;W0@82!V86QI
M9"!P=6)L:6,@:V5Y+B(*;7-G<W1R("*5<Y"S@L@@4$=0((SVBDJ,KH+%@K>!
M0B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-C<*;7-G:60@(DYO
M="!D96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(HWMCYR"LX+J@L2"HH+(@J*#
M@8%;@XLB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED
M(").;W0@:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(H]DEW:"Q8+(@J*#
M@8%;@XLB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G
M:6XN<&AP.C<Q"FUS9VED(").;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE
M('1I;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q
M-@HC+"!F=7IZ>0IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R("*(^)=P(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B3G5M8F5R(&]F(&UO
M;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L971I
M;F<@;6]N=&AL>2XB"FUS9W-T<B`BC,."HH.*@Y.#3HQ>DUF5=(+PC>V/G(*W
M@NF/ZHV'@4&5VY&V@K>"Z8R.D)0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S4Y"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S
M('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`BEHB,CHWM
MCYR"MX+IC^J-AX+)E=N1MH*U@L2"J(*K@KV"HHKYD;:"S(%MD9>038U4@J:!
M;H-T@TB#BX-?@LR0E"(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C4T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-3(*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,PIM<V=I9"`B3TLB"FUS9W-T<B`B
M3TLB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-2!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHT.`IM<V=I9"`B3U(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S
M(@IM<V=S='(@(HKYD;:"S(.!@5N#BR(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD
M('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"XB"FUS9W-T<B`BC,."
MHH%MD9>038U4@J:!;H-T@TB#BX-?@LR/P8N.DH:!0B(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E<G,@
M=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHW.0HC+"!F=7IZ>0IM
M<V=I9"`B3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@
M=&AI<R!A8W1I;VXN(@IM<V=S='(@(H*Q@LR1@(WL@O"-<X*D@W2#2(.+@U^"
M\"`Q((+"@KZ"KY%)@O&"Q8*M@KZ"LX*B@4(B"@HC.B!T96UP;&%T97,O;65N
M=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED
M(")/<&5N($9O7VQD97(B"FUS9W-T<B`B@W2#2(.+@U^129'P(@H*(SH@9F]L
M9&5R<RYP:'`Z-#(W"B,L(&9U>GIY"FUS9VED(")/<&5N960@1F]L9&5R(@IM
M<V=S='(@(H-T@TB#BX-?D4F1\"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW,#4*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM<V=S='(@
M(I1#B-."S(Y1B<&.TB(*"B,Z(&9E=&-H;6%I;"YP:'`Z,S,@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]T;W`N:6YC.C,*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F
M971C:&UA:6PN:6YC.C8*(RP@9G5Z>GD*;7-G:60@(D]T:&5R($UA:6P@06-C
M;W5N=',B"FUS9W-T<B`B@KN"S)&\@LR#28-V@U:#AX.3(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS
M9W-T<B`B@KN"S)&\@LR#28-V@U:#AX.3(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,#$*;7-G:60@(D]U=&)O=6YD(%-E<G9E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP"FUS9VED(")0
M1U`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L
M:7-T+FEN8SHW"FUS9VED(")01U`@16YC<GEP="!-97-S86=E(@IM<V=S='(@
M(E!'4""(PXV&B;LB"@HC.B!C;VUP;W-E+G!H<#HS-3@*;7-G:60@(E!'4"!%
M<G)O<CH@(@IM<V=S='(@(E!'4""#1X.)@5LZ("(*"B,Z(&-O;7!O<V4N<&AP
M.C,S-PIM<V=I9"`B4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E
M<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R(")01U`@@T>#B8%;.B"4Z9:G
MC*Z"S(-P@UB#=(.,@5N#68*JE4N7=H+%@K>!0B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E!'4"!/<'1I;VYS(@IM<V=S='(@(E!'
M4""#28-V@U:#AX.3(@H*(SH@<&=P+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P
M:')A<V4@26YP=70B"FUS9W-T<B`B4$=0((-P@UB#=(.,@5N#68+,D_R7S2(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O
M;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B4$=0((S"D&R,KH+,@U2#?(%;@V>"R8+-B,"1
M4X+(('=E8B"0VI&Q@JJ52Y=V@L6"MX%"(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED(")01U`@4'5B;&EC($ME>2!4
M97AT(@IM<V=S='(@(E!'4"",]HI*C*Z#BH.3@T\B"@HC.B!P9W`N<&AP.C$T
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@
M9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S
M='(@(EPB)7-<(B"#=(-(@XN#7X*JC>R0K(*S@NJ"W(*U@KV!0B(*"B,Z('!G
M<"YP:'`Z,C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B
M;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB
M"FUS9W-T<B`B7"(E<UPB((-T@TB#BX-?@JJ-[8^<@K."ZH+<@K6"O8%"(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC
M($ME>7)I;F<B"FUS9W-T<B`B4$=0((SVBDJ,KH.*@Y.#3R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`IM<V=I9"`B4$=0(%-I
M9VX@365S<V%G92(*;7-G<W1R(")01U`@CY"6O"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.0IM<V=I9"`B4$=0(%-I9VXO16YC
M<GEP="!-97-S86=E(@IM<V=S='(@(E!'4""39(YQCY"6O(%>B,.-AHF[(@H*
M(SH@<&=P+G!H<#HR,#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!P<FEV871E(&ME
M>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E,O34E-12""S(SVBDJ,
MKH%>E.F6IXRN@LR#>8-!@LV2QXG!@K."ZH+<@K6"O8%"(@H*(SH@<&=P+G!H
M<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(E!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F
M=6QL>2!A9&1E9"XB"FUS9W-T<B`B4R]-24U%((+,C/:*2HRN@5Z4Z9:GC*Z"
MS(-Y@T&"S9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O<&=P+VYO
M=&%C=&EV92YI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B4$=0('-U<'!O<G0@:7,@
M9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(H*Q@LR#5H-8@V6#
M@(+%@LT@4R]-24U%((+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\8%"(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`X"FUS9VED("(B"B)01U`@<W5P
M<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S
M:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M("(B"B)01U`@@LR#5(-\@5N#9X+-C+N-W9:SC/B"R8+(@L&"Q(*B@MR"MX+,
M@L6!09-DCG&/D):\@LR,GX_8@LV"Q8*K@MR"N8+Q@4(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HR.34*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES
M(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!M97-S86=E(&ES('5N86)L
M92!T;R!B92!D96-R>7!T960N(@IM<V=S='(@(E!'4"""S(-4@WR!6X-G@LV,
MNXW=EK.,^(+)@LB"P8+$@J*"W(*W@LR"Q8%!E9R-AH+-@L6"JX+<@KF"\8%"
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*(RP@9G5Z>GD*;7-G:60@
M(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@
M=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@(@HB<V5T('1O
M(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@
M<V5T=&EN9R!O<B!E;'-E('1H92!01U`@(@HB9F5A='5R97,@=VEL;"!N;W0@
M=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(E!'4"""S(-4@WR!6X-G@LF"
MS8-\@V*#=H-!@V*#=H%%@T6#0X.3@VB!6X*JE4N7=H+%@K>!0H*HCF>"HH+,
M@W6#B8-%@U6"JH-\@V(B"B*#=H-!@V*#=H+PB]:.?H+)@K6"Q(*@@NF"R(+G
M@4%01U`@BT"47(+-D+."M8*MDZZ-[(*U@MR"N8+Q@4(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T
M;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R(")03U`S@6F.J9.NE+N5RH%J
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3<*;7-G:60@(E!/4#,@
M;W9E<B!34TPB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,C,*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I
M9FEC871E*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$V.0IM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$Q"FUS9VED
M(")03U`S+"!N;R!43%,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")086=E("5D
M(&]F("5D(@IM<V=S='(@(B5D((%>("5D((-Y@5N#5R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,#,*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER<W0@
M56YS965N($UE<W-A9V4B"FUS9W-T<B`BC<6/B8+,EJ*3QX.!@V*#6H%;@U>"
M\(K<@MZ#>8%;@U<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`T"FUS
M9VED(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B"FUS9W-T
M<B`BC<6,XX+,EJ*3QX.!@V*#6H%;@U>"\(K<@MZ#>8%;@U<B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R="AS*2(*
M;7-G<W1R("*#<(%;@V<B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S
M"B,L(&9U>GIY"FUS9VED(")087-S<&AR87-E(@IM<V=S='(@(H-P@UB#=(.,
M@5N#68+PD_R7S2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*(RP@
M9G5Z>GD*;7-G:60@(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R(")01U`@
M@W"#6(-T@XR!6X-9@LR3_)?-(@H*(SH@<VUI;64N<&AP.C(S-2!P9W`N<&AP
M.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@
M=6YL;V%D960N(@IM<V=S='(@(B5S((+-("5S((+)DL>)P8*S@NJ"W(*U@KV!
M0B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ."!T96UP
M;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C(Y"B,L(&9U>GIY"FUS9VED(")0
M87-S<&AR87-E.B(*;7-G<W1R("*#<(-8@W2#C(%;@UF"\)/\E\TB"@HC.B!P
M9W`N<&AP.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B92!E;7!T
M>2(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$Q-`IM<V=I9"`B4&%S<W!H<F%S
M97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3(*;7-G
M:60@(E!A<W-W;W)D(@IM<V=S='(@(H-P@UB#CX%;@V@B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B@XV#3X-#
M@Y..GH+)@O"5VX[GC>R+QH+PCL"-<X*U@MR"MX*I@4@B"@HC.B!A8VPN<&AP
M.C<V(&%C;"YP:'`Z,3`R"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U
M<V5R(&-A;B!N;W0@8F4@8VAA;F=E9"XB"FUS9W-T<B`B@K&"S(.&@5N#58+,
M@T&#3H-:@UB,H(+-E<^-6(+%@JN"W(*Y@O&!0B(*"B,Z(&UE<W-A9V4N<&AP
M.C0Y,R!M86EL8F]X+G!H<#HW,#,@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$P"FUS
M9VED(")097)S;VYA;"(*;7-G<W1R("*.J96JB+8B"@HC(&US9W-T<B`BC,*0
M;(-!@VB#C(-8DJ`B"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-`IM<V=I
M9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`BC,*0;(_NE?$B"@HC
M.B!P9W`N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86P@4$=0(&ME
M>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B@X&#8H-:
M@5N#5X+-DUV1EX*S@NJ"W(*U@KV!0B(*"B,Z('!G<"YP:'`Z,3(W"B,L(&9U
M>GIY"FUS9VED(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B@X&#8H-:@5N#5X+-DUV1EX*S@NJ"W(*U@KV!0B(*
M"B,Z('-M:6UE+G!H<#HR,#<*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L(%,O
M34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`BC,*0
M;(+,(%,O34E-12"/V):^CY&"\(-#@Y.#?(%;@V<B"@HC.B!S;6EM92YP:'`Z
M,3,R"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!3+TU)344@:V5Y<R!D96QE
M=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B@X&#8H-:@5N#5X+-DUV1EX*S
M@NJ"W(*U@KV!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G
M:60@(E!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F
M;W)W87)D<S\B"FUS9W-T<B`BE=2038+<@KV"S9-=D9>"MX+ID4^"R8^0EKR"
M\)+'B<&"M8+<@K>"J8%((@H*(SH@8V]M<&]S92YP:'`Z,C4T"B,L(&9U>GIY
M"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S='(@
M(DA434P@C&".KB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3D*;7-G
M:60@(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S
M('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D("(*(G-O=6YD(&9I
M;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O
M=&AE<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@<&QU9VEN+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU
M-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.B(*;7-G
M<W1R("*05HM+@W2#2(.+@U^"S):\D4^"\)/\E\V"M8+$@JV"OH*S@J*!1B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")0;&5A<V4@
M96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(I!6
MBTN#=(-(@XN#7X+,EKR13X+PD_R7S8*U@L2"K8*^@K."HH%&(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S<*;7-G:60@(E!L96%S
M92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@(I!6@K6"HI:\D4^"\(YW
MDNB"M8+$@JV"OH*S@J*!1B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S
M92YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R
M('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2X@66]U
M('=I;&P@;VYL>2!N965D('1O("(*(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O
M;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-
M12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D("(*(G1O(&5N=&5R
M('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R
M("(B"@HC.B!R96-O;7!O<V4N<&AP.CDW"FUS9VED("(B"B)0;&5A<V4@;&]G
M(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)
M9B!Y;W4@87)E($Y/5"!U<VEN9R`B"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O
M;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H
M879E('1O("(*(FQO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S
M('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA
M8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I
M;F-O;G9E;FEE;F-E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C<Q"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W
M;W)D+B(*;7-G<W1R("*#<(-8@X^!6X-H@O"+3)/\@K6"Q(*M@KZ"LX*B@4(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8W"FUS9VED(")0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE+B(*;7-G<W1R("*#AH%;@U66O(+P
MBTR3_(*U@L2"K8*^@K."HH%"(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])
M35`N<&AP.C0U.0IM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R
M(&EN=F%L:60@861D<F5S<V5S+B(*;7-G<W1R("*"H(*B@MR"HH+(((%I@MR"
MO8+-EK.,^(+(@6H@@T&#:(.,@UB"\(]#D+."M8+$@JV"OH*S@J*!0B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*(E!L96%S
M92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@
M<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G
M<W1R("*(R(FZ@LR3X)=E@O"*;91&@K6"O8+,@K^!08C(B;J"S(.!@VJ#A8%;
M@JF"YX^(DG6"\)%)D?""M8+$B;J"LX*B@4(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]F;VQD97)S+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@
M9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T
M<B`BD8"-[(+PCL"-<X*W@NF13X+)@W2#2(.+@U^"\)%)@O&"Q8*M@KZ"LX*B
M@4(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`R"B,L(&9U>GIY
M"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU
M(&)E;&]W+B(*;7-G<W1R("*(R(FZ@LR3X)=E@O"*;91&@K6"O8+,@K^!08C(
MB;J"S(.!@VJ#A8%;@JF"YX^(DG6"\)%)D?""M8+$B;J"LX*B@4(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC.C0Q"FUS9VED(")0;&5A
M<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+B(*;7-G
M<W1R("*,GXWU@K>"Z8-T@TB#BX-?@O`@,2""PHC(C^.128+Q@L6"K8*^@K."
MHH%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,@IM
M<V=I9"`B4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H:7,@
M;W!E<F%T:6]N+B(*;7-G<W1R("*"L8+,D8"-[(+PC7."I(-T@TB#BX-?@O`@
M,2""PH*^@J^128+Q@L6"K8*^@K."HH%"(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5D:7)E8W0N:6YC.C<S"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L
M96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@
M(HZ?@O"129'P@MR"O8+-E=*/5X*U@L2"K8*^@K."HH%&(@H*(SH@8V]N9FEG
M+VUO=&0N<&AP+F1I<W0Z-#$*;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-`IM<V=I9"`B
M4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*
M;7-G<W1R("*/D):\@LR13X+)@LV#7X-B@U:#A8%I)RTM(">!:H+PE72"KX+<
M@K>"J8%((@H*(SH@<VUI;64N<&AP.C(T,2!P9W`N<&AP.C(U-R!F:6QT97)P
M<F5F<RYP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!R969E<F5N8V5S('-U8V-E
M<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R("*#0X-X@Y.#9X+-C>V/G(*S@NJ"
MW(*U@KV!0B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN
M8SHS"B,L(&9U>GIY"FUS9VED(")0<F5V:65W(@IM<V=S='(@(I%/@LR#>8%;
M@U<B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C(X"FUS9VED(")0<F5V:6]U<R!-97-S86=E(@IM<V=S='(@(I%/@LR#@8%;
M@XLB"@HC.B!M86EL8F]X+G!H<#HS-#<*;7-G:60@(E!R979I;W5S(%!A9V4B
M"FUS9W-T<B`BD4^"S(-Y@5N#5R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B4')I;G0B"FUS9W-T<B`BB/.-
M_"(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X"FUS9VED
M(")0<FEO<FET>2(*;7-G<W1R("*71)#FDW@B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(E!R:79A=&4@
M2V5Y(%!A<W-W;W)D(@IM<V=S='(@(H*@@LB"O8+,E.F6IXRN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4U.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I
M;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/(@IM<V=S
M='(@(I-9E72"\)&7D$V"M8*]CIZ"S9!Q@LN"Z8%'@V:#=(-(@XN#9TY/(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U.`IM<V=I9"`B4')O;7!T(&5V
M97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%
M4R(*;7-G<W1R("*3695T@O"1EY!-@K6"O8Z>@LV0<8++@NF!1X-F@W2#2(.+
M@V=915,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3`*
M;7-G:60@(E!R;W1O8V]L.B(*;7-G<W1R("*#=H.-@V>#4H.+@48B"@HC.B!L
M:6(O0W)Y<'0O4$=0+G!H<#HT,CD*;7-G:60@(E!U8FQI8R!01U`@:V5Y<V5R
M=F5R('-U<'!O<G0@:&%S(&)E96X@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z.`IM<V=I9"`B4'5R7V=E($1E
M;&5T960B"FUS9W-T<B`B7T>#4X-^E*""\(OS@LF"MX+I(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)G92!$96QE=&5D(@IM
M<V=S='(@(H-3@WZ4H(+PB_."R8*W@NDB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHR-`HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@1F]L9&5R
M*',I(@IM<V=S='(@(HNDETR#=(-(@XN#7R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.38*;7-G:60@(E!U<F=E(%1R87-H(&AO=R!O9G1E;CHB"FUS
M9W-T<B`B@U.#?I2@@O"+\X+)@K>"Z95PDWB!1B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H
M(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S
M='(@(H-3@WZ4H(-T@TB#BX-?D^""S(.!@5N#BX+PB_."R8*W@NF"W(+%@LR3
M^I"4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B4'5R
M9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_(@IM<V=S='(@
M(H-3@WZ4H)/@@LR,PX*B@X&!6X.+@O"/P8N.@K6"W(*W@JF!2"(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S86=E<R!F<F]M
M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B@U.#?I2@@W2#2(.+@U^"J8+G)622
MRH+,@X&!6X.+@O"-[8^<@K6"W(*U@KTB"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E!U<F=I
M;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R("*#4X-^
ME*"#=(-(@XN#7X*I@N<E9)+*@LR#@8%;@XN"\(WMCYR"M8+<@K6"O2(*"B,Z
M('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.
M3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N
M:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@3D\@
M3$E-250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS
M9W-T<B`BB/B7<"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C,X-@IM<V=I9"`B4F5?<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(E]1E'J20HIME$:"\)=VBX$B"@HC.B!L:6(O4V5A<F-H+G!H<#HU
M,`IM<V=I9"`B4F5C96EV960@3VXB"FUS9W-T<B`B(@H*(SH@;&EB+U-E87)C
M:"YP:'`Z-3@*;7-G:60@(E)E8V5I=F5D(%-I;F-E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]396%R8V@N<&AP.C4T"FUS9VED(")296-E:79E9"!5;G1I;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,38*;7-G:60@(E)E9&ER96-?="(*;7-G<W1R(")?5(*[@LR"W(+<DUV1
MER(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ
M-@IM<V=I9"`B4F5D:7)E8W0B"FUS9W-T<B`B@KN"S(+<@MR379&7(@H*(R!M
M<V=S='(@(H.*@U^#0X.,@TZ#9R(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C$Q,`IM<V=I9"`B4F5D:7)E8W0@365S<V%G92(*;7-G<W1R
M("*#@8%;@XN"\(*[@LR"W(+<DUV1EX*W@NDB"@HC(&US9W-T<B`B@X&!6X.+
M@O"#BH-?@T.#C(-.@V>"MX+I(@HC.B!C;VUP;W-E+G!H<#HW.#<*;7-G:60@
M(E)E9&ER96-T('1H:7,@;65S<V%G92(*;7-G<W1R("*"L8+,@X&!6X.+@O""
MNX+,@MR"W)-=D9>"MX+I(@H*(R!M<V=S='(@(H*Q@LR#@8%;@XN"\(.*@U^#
M0X.,@TZ#9X*W@NDB"B,Z(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E
M8W1I;F<@9F%I;&5D+B(*;7-G<W1R("*379&7@L6"JX+<@KF"\8+%@K6"O8%"
M(@H*(R!M<V=S='(@(H.*@U^#0X.,@TZ#9X+%@JN"W(*Y@O&"Q8*U@KV!0B(*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@S"FUS9VED(")2
M969R97-H(@IM<V=S='(@(HW$E5R.IB(*"B,@;7-G<W1R("*#BH-T@XR#8H-6
M@X4B"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E
M<V@@1F]L9&5R(%9I97=S.B(*;7-G<W1R("*#=(-(@XN#7Y5<CJ:"S(.*@W2#
MC(-B@U:#A3HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY('1E
M;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM<V=I9"`B
M4F5L;V%D(@IM<V=S='(@(I5<CJ:"\(.*@XV!6X-H(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I97<B"FUS9W-T
M<B`BE5R.IH+P@XJ#C8%;@V@B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3(V(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#4*;7-G:60@(E)E
M;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(I=<
MDNB/[I7Q@O"+3(FO@K>"Z8%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDW.0IM<V=I9"`B4F5M96UB97(@=&AE(&QA<W0@=FEE=R(*;7-G<W1R("*-
MQ8SC@LR57(ZF@O"+3(FO(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C(W"FUS9VED(")296UO=&4@36%I;&)O>#HB"FUS9W-T<B`B@XJ#
M@H%;@V>"S(.!@5N#BX-[@V*#3H-8EKR!1B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I96QD($9R;VT@4V5A
M<F-H(@IM<V=S='(@(HR?C?6"J8+GCYR*3X*W@NDB"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*;7-G:60@(E)E;6]V92!S;W5R
M8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z.`IM<V=I9"`B4F5N86UE($9O;&1E<BAS*2(*;7-G<W1R("*#=(-(@XN#
M7Y:\@O"5SXU8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I
M9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/R(*;7-G<W1R("*1EY!-C52"IH-T@TB#BX-?@LR6O)%/@O"6B(R.@LR/
MB8+?@LF5SXU8@K6"W(*W@JF!2"(*"B,Z(&QI8B]&;VQD97(N<&AP.C0U-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296YA;6EN9R!<(B5S7"(@=&\@7"(E<UPB
M(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R
M(")<(B5S7"(@@O`@7"(E<UPB((+)E<^-6(+%@JN"W(*Y@O&"Q8*U@KV!0H-4
M@5N#;X+,@T>#B8%;.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS9W-T<B`B
M7UF#BH-8@V>"R974D$TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z,3`U"FUS9VED(")297!L86-E('=I=&@Z(@IM<V=S='(@(HZ?@L:2
M=8JW@48B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`BE=2032(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0P.0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`BE=2038JNE[F!0B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM
M<V=I9"`B4F5P;'D@=&\@06QL(@IM<V=S='(@(I%3B/6"R974D$TB"@HC.B!C
M;VUP;W-E+G!H<#HW,S,*;7-G:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B
MD5.(]8+)E=2038%&(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C$P"FUS9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@(H.*
M@UB#9X+)E=2032(*"B,Z(&-O;7!O<V4N<&AP.C<S-0IM<V=I9"`B4F5P;'D@
M=&\@3&ES=#HB"FUS9W-T<B`B@XJ#6(-G@LF5U)!-@48B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY
M('1O(%]!;&PB"FUS9W-T<B`B7T&14XCU@LF5U)!-(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3,W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E
M<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(H-4@WR!
M6X-GBD^"S(.!@V*#6H%;@U>"Q974D$TB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3,U"FUS9VED(")297!L>2!W:71H(&9R964O8G5S>2!F;W(@
M;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B,H.6C(Z5JH+,EUR2Z(_NE?&5=(*K
M@L65U)!-(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-`IM<V=I
M9"`B4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("*7=HN!@K."ZH*]EUR2Z(_NE?&"Q974D$TB"@HC.B!M97-S
M86=E+G!H<#HR-C<*(RP@9G5Z>GD*;7-G:60@(E)E<&QY+51O(@IM<V=S='(@
M(B`@E=2038%&(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P.0IM<V=I9"`B4F5P
M;'DM5&\Z("(*;7-G<W1R("(@()74D$V!1B(*"B,Z(&-O;7!O<V4N<&AP.C<S
M,0IM<V=I9"`B4F5P;'DZ(@IM<V=S='(@(I74D$TZ(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")297!O<G0@87,@
M26YN;V-E;G0B"FUS9W-T<B`B4U!!38+&@K6"Q(.,@WR!6X-G(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,U('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(S"FUS9VED(")297!O<G0@87,@4W!A
M;2(*;7-G<W1R(")34$%-@L:"M8+$@XR#?(%;@V<B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS.#,*;7-G:60@(E)E<75E<W0@82!?4F5A
M9"!296-E:7!T(@IM<V=S='(@(E]2BDJ5E8IME$:"\)=VBX$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y
M(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`BE'J20HIME$:"\)=VBX&"M8+<@K>"
MJ8%((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,PIM<V=I9"`B4F5Q
M=65S="!R96%D(')E8V5I<'1S/R(*;7-G<W1R("**2I65BFV41H+PEW:+@8*U
M@MR"MX*I@4@B"@HC.B!M86EL8F]X+G!H<#HQ.#D*;7-G:60@(E)E<75E<W1E
M9"!M97-S86=E(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8Y-PIM<V=I9"`B4F5Q=6ER960@4&%R=&EC:7!A
M;G0B"FUS9W-T<B`BE4N0>XY1B<&.TB(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,30S('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHR-@HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q"FUS9VED(")297-E="(*;7-G
M<W1R("*#BH-:@V*#9R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M,34*;7-G:60@(E)E<W!O;F1E;G0@4W1A='5S(%5P9&%T960N(@IM<V=S='(@
M(HGQDYJ.TH+,C_.+M8+PC5B05H*U@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*
M;7-G<W1R("*-Q(I*(@H*(SH@<F5C;VUP;W-E+G!H<#HY.`IM<V=I9"`B4F5S
M=6UE('EO=7(@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T
M;R!<(DUE<W-A9V4@0V]M<&]S:71I;VY<(B(*;7-G<W1R("*#@8%;@XN-[)"L
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHS
M,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-CD*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,S(*(RP@9G5Z>GD*
M;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@(H.!@5N#BX+,
MCN:"Z(V>@MTB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@
M=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHR,@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP;&%T97,O<VUI;64O;F]T86-T
M:79E+FEN8SHQ-`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L
M871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,38R('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S,*;7-G:60@(E)E
M='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(H-)@W:#5H.'@Y."R9;?@NDB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S$X"FUS9VED("(B"B)2971U<FX@
M=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG
M+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B(@HB@X&#8H-:@5N#
M5X+PC>V/G(%!B-J3KH%!@U*#<X%;@K6"O8SC@4&#@8%;@XN#>X-B@TZ#6(.*
M@UB#9X+)EM^"Z(+<@K>"J8%((@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8X.`IM<V=I9"`B4F]L92(*;7-G<W1R("*6\(J$(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3D*(RP@
M9G5Z>GD*;7-G:60@(E,O34E-12(*;7-G<W1R(")3+TU)344@@LR#28-V@U:#
MAX.3(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ
M,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")3+TU)
M344@B,.-AHF[(@H*(SH@8V]M<&]S92YP:'`Z,SDT"FUS9VED(")3+TU)344@
M17)R;W(Z("(*;7-G<W1R(")3+TU)344@@T>#B8%;.B`B"@HC.B!C;VUP;W-E
M+G!H<#HS-S,*;7-G:60@(E,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR87-E
M(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B4R]-24U%((-'
M@XF!6SH@E.F6IXRN@LR#<(-8@W2#C(%;@UF"JI5+EW:"Q8*W@4(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"FUS9VED(")3+TU)344@3W!T:6]N
M<R(*;7-G<W1R(")3+TU)344@@LR#28-V@U:#AX.3(@H*(SH@<VUI;64N<&AP
M.C0Y"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R(")3
M+TU)344@@LR#<(-8@W2#C(%;@UF"\)/\E\TB"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y<&%I
M<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R(")3+TU)344@C,*0;(RN@LR#5(-\@5N#9X+)@LV(P)%3@L@@=V5B
M()#:D;&"JI5+EW:"Q8*W@4(B"@HC.B!S;6EM92YP:'`Z,30P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@7"(E
M<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B7"(E<UPB
M((-T@TB#BX-?@JJ-[8^<@K."ZH+<@K6"O8%"(@H*(SH@<VUI;64N<&AP.C$V
M,@HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U
M;&QY(&%D9&5D+B(*;7-G<W1R(")3+TU)344@@LR,]HI*C*Z!7I3IEJ>,KH+,
M@WF#08+-DL>)P8*S@NJ"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,3`*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G
M<W1R(")3+TU)344@C/:*2HRN@XJ#DX-/(@H*(SH@<VUI;64N<&AP.C(Q,0IM
M<V=I9"`B4R]-24U%(%!U8FQI8R]0<FEV871E($ME>7!A:7(@<W5C8V5S<V9U
M;&QY(&%D9&5D+B(*;7-G<W1R(")3+TU)344@@LR,]HI*C*Z!7I3IEJ>,KH+,
M@WF#08+-DL>)P8*S@NJ"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V5N8W)Y<'1?;&ES="YI;F,Z,3,*;7-G:60@(E,O34E-12!3:6=N($UE<W-A
M9V4B"FUS9W-T<B`B4R]-24U%((^0EKPB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E;F-R>7!T7VQI<W0N:6YC.C$T"FUS9VED(")3+TU)344@4VEG;B]%;F-R
M>7!T($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%((^0EKR!7HC#C8:)NR(*"B,Z
M('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E,O34E-
M12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R
M("*"L8+,@U:#6(-E@X""Q8+-(%,O34E-12""S8-4@WR!6X-G@K."ZH+$@J*"
MW(*Y@O&!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L
M960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E
M9"XB"FUS9W-T<B`B(@HB4R]-24U%((-4@WR!6X-G@LV,NXW=EK.,^(+)@LB"
MP8+$@J*"Z8*]@M^!08.!@V*#6H%;@U>"S)6<C8:/B)>=@JJ"Q8*K@MR"N8+Q
M@4(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PHC+"!F=7IZ
M>0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@
M=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO="`B
M"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(B(*(E,O34E-12"#5(-\@5N#9X+-
MC+N-W9:SC/B"R8+(@L&"Q(*B@NF"O8+?@4&39(YQCY"6O(+,C)^/V(+-@L6"
MJX+<@KF"\8%"(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*
M;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H
M92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*(E,O34E-12"#5(-\@5N#9X+-C+N-W9:SC/B"R8+(
M@L&"Q(*B@NF"O8+?@4&39(YQCY"6O(+,C)^/V(+-@L6"JX+<@KF"\8%"(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,L(&9U>GIY"FUS9VED
M("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O
M(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY('-E
M="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T
M:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S('=I
M;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)3+TU)344@@LR#
M5(-\@5N#9X+)@LV#?(-B@W:#08-B@W:!18-%@T.#DX-H@5N"JI5+EW:"Q8*W
M@4*"J(YG@J*"S(-U@XF#18-5@JHB"B*#?(-B@W:#08-B@W:"\(O6CGZ"R8*U
M@L2"H(+I@LB"YX%!4R]-24U%((M`E%R"S9"S@K6"K9.NC>R"M8+<@KF"\8%"
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#4*;7-G:60@(E--
M5%`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,C4U"B,L(&9U>GIY"FUS9VED(")37W5B:F5C="(*;7-G<W1R("*,CY:\
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S8S"FUS9VED
M(")385]V92!A(&-O<'D@:6X@(@IM<V=S='(@(E]6CI^"S(_JCXJ"R8-2@W.!
M6X+PE=N1MB`B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S(*;7-G:60@(E-A7W9E(&%S(@IM<V=S='(@(E]6E=N1MB(*"B,Z
M('-E87)C:"YP:'`Z,S$V('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHV-PIM<V=I9"`B4V%V92(*;7-G<W1R("*5VY&V(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE
M;G1S('=I=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R
M("*3695T@N"#@8-B@UJ!6X-7@L:+I(+)D9>038U4@J:#=(-(@XN#7X+)E=N1
MMH*U@MR"MX*I@4@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHV.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@
M(E-A=F4@1')A9G0B"FUS9W-T<B`BB;J/D8*K@O"5VY&V(@H*(SH@<V%V96EM
M86=E+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B4V%V92!);6%G92(*;7-G<W1R
M("*6O)%/@O"5=(*O@L25VY&V(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP
M.C(P-`IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T
M:79E+FEN8SHQ,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L
M871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS
M(@IM<V=S='(@(H-)@W:#5H.'@Y."\)7;D;8B"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(E-A=F4@4W1A
M=&EO;F5R>2(*;7-G<W1R("*#28-V@U:#AX.3@O"5VY&V(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#,S"FUS9VED(")3879E(%]$<F%F="(*;7-G<W1R(")?
M1(FZCY&"JX+PE=N1MB(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%V92!A<R(*;7-G<W1R("*6O)%/@O"5
M=(*O@L25VY&V(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,0IM<V=I
M9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R("*)NH^1@JN"\):B
MD\>"QH*U@L25VY&V@K6"W(*W@JF!2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#<R"FUS9VED(")3879E(')E8VEP:65N=',@875T;VUA=&EC86QL
M>2!T;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_(@IM<V=S='(@(H[SD$V.
MTH+PCJF3KI-)@LF#9H-T@TB#BX-G@LR#08-H@XR#6)*@@LF2QXG!@K6"W(*W
M@JF!2"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(W"FUS9VED
M(")3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/R(*;7-G<W1R("*,
MGXWUC(N)RH+PB;R1>H-T@TB#BX-?@LF5VY&V@K6"W(*W@JF!2"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(E-A=F4@<V5N="!M86EL
M/R(*;7-G<W1R("*1EY!-@X&!6X.+@LR-5(*F@O"5VY&V@K6"W(*W@JF!2"(*
M"B,Z(&-O;7!O<V4N<&AP.C$R,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("5S(@IM<V=S='(@(HFZCY&"JX+PE=N1MH+%@JN"W(*Y@O&"Q8*U
M@KV!0H-4@5N#;X*I@N>"S(F>DYJ!1B5S(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HT,0IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(HR?C?4B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@)7,B"FUS9W-T<B`BC)^-
M]2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C`*(RP@9G5Z>GD*
M;7-G:60@(E-E87)C:"!/<'1I;VYS(@IM<V=S='(@(H-)@W:#5H.'@Y."\)7;
MD;8B"@HC.B!S96%R8V@N<&AP.C(V-0IM<V=I9"`B4V5A<F-H(%)E<W5L=',B
M"FUS9W-T<B`BC)^-]8R+B<HB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$T('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G
M:60@(E-E96XB"FUS9W-T<B`BBOF3QR(*"B,@;7-G<W1R("*57(ZFC<^"W2(*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHY"FUS9VED(")396QE
M8W0B"FUS9W-T<B`BD4F1\"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G
M<W1R("*#08-*@T6#DX-G@O"129'P(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F
M:65L9',N:6YC.C,V"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(I/Z
ME72"\)%)D?`B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,3`*
M;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(H-T@T*!6X.+@VB"\)%)
MD?`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@(I/Z
ME72"\)%)D?`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED
M(")396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@
M<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S='(@(H-!@VB#C(-8@LR2
MQXG!@N*,GXWU@O"-<X*D@T&#:(.,@UB2H(+,@UR!6X-8@O"128+Q@L6"K8*^
M@K."HH%"(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R("*"MX+7@L2"\)%)D?`B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N(@IM<V=S='(@(H-!@VB#C(-8@O"35XI*@K>"Z8W;@LF,
MGXWU@K>"Z8-!@VB#C(-8DJ""S(^'CYB"\(YWDNB"M8+$@JV"OH*S@J*!0B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q
M"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R("*#08-*@T6#DX-G
M@O"129'P(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I
M9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B@L>"ZH+@D4F1\(*U@LB"HB(*"B,Z
M('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS9VED(")3
M96QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI
M;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP92(*;7-G
M<W1R("*#@8%;@XN#5(%;@V^"S([ME]Z"\)%)D?`B"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*;7-G:60@(E-E;&5C=&5D($%D
M9')E<W,@8F]O:W,Z(@IM<V=S='(@(I%)@LZ"ZH+$@J*"Z8-!@VB#C(-8DJ"!
M1B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B4V5N9"!+
M97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C`T"FUS9VED(")396YD($QA=&5S="!);F9O
M<FUA=&EO;B(*;7-G<W1R("*-Q9!6@LR/[I7Q@O"1EX+I(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#,Q"FUS9VED(")396YD($UE<W-A9V4B"FUS9W-T<B`B
M@X&!6X.+@LR1EY!-(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P,PHC
M+"!F=7IZ>0IM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T
M960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`BD9>038[2@LF7=HN!@K."ZH*]
M@N=-1$Z"\)&7D$V"M8+<@K>"J8%((@H*(SH@9F]L9&5R<RYP:'`Z,SDW"FUS
M9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(I&7D$V-5(*F@W2#2(.+
M@U\B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,X
M"FUS9VED(")396YT(&UA:6P@9F]L9&5R.B(*;7-G<W1R("*1EY!-C52"IH-T
M@TB#BX-?@48B"@HC(&US9W-T<B`BD9>038-[@V*#3H-8@W2#2(.+@U^!1B(*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S(@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ-#8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ-3,*;7-G:60@(E-E<G9E<B(*;7-G<W1R("*#5(%;@V\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,*;7-G:60@(E-E<G9E<B!A;F0@1F]L9&5R
M($EN9F]R;6%T:6]N(@IM<V=S='(@(H-4@5N#;X+&@W2#2(.+@U^"S(_NE?$B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@
M(E-E<G9E<CHB"FUS9W-T<B`B@U2!6X-O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,`IM<V=I9"`B4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA
M<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+B(*;7-G
M<W1R("*#@8%;@XN"\(C:DZZ!08WMCYR"M8*]C^J-AX+,CXB2=8+)BM:"MX+I
MD-V2Z(+PCG>2Z(*U@L2"K8*^@K."HH%"(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4R.0IM<V=I9"`B4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W
M:&5N(&-O;7!O<VEN9R!M97-S86=E<S\B"FUS9W-T<B`BD%:+2XWLD*R.GH-W
M@V*#7X+)6"U0<FEO<FET>8+PE72"KX+<@K>"J8%((@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Q"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@
M(HNDETR#=(-(@XN#7R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@IM
M<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(HNDETR#@8-#@XN#
M=(-(@XN#7R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B
M4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS
M9W-T<B`B@J""R(*]@LR#@8-#@XN#=(-(@XN#7X+PD;R"S(.&@5N#58+&BZ27
M3(*U@MR"MX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V.0IM<V=I
M9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S
M:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E("(*(G1O9V=L
M960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+B(*;7-G<W1R("*2MX*B
MB/B7<(+PE5R.IH*U@MR"MX*I@4B)0H*U@MR"MX*I@4@@B;V.GH+%@N"*R))0
M@LF5SXU8@L6"JX+<@K>!0B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E
M<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\B"FUS9W-T<B`B@X&!6X.+@LR6
M>Y6V@O`@4$=0((+%C)^/V(*U@MR"MX*I@4@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$S"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W
M(&)E(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`BB;J/
MD8*K@LR5VY&VC..!08.!@5N#BXWLD*R#18-"@Y.#:(-%@O"5PH*V@MR"MX*I
M@4@B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I9"`B4VAO=6QD
M('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M
M97-S86=E<R!B>2!D969A=6QT/R(*;7-G<W1R("*#9H-T@TB#BX-G@L4@4$=0
M((SVBDJ,KH+P@X&!6X.+@LF3695T@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B
M"FUS9W-T<B`BD5.#=(-(@XN#7Y5<CJ8B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]H96%D97)S+FEN8SHV-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G
M<W1R("*#=X-B@U^"\)%3@L257(ZF(@H*(SH@;6%I;&)O>"YP:'`Z,S8U"FUS
M9VED(")3:&]W($1E;&5T960B"FUS9W-T<B`BC>V/G(W/@MV"\)5<CJ8B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO
M=R!,:6UI=&5D($AE861E<G,B"FUS9W-T<B`B@W>#8H-?@LR(ZI64@KZ"KX+P
ME5R.IB(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P"FUS
M9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R("*#
M@8-#@XJ#DX-/@XJ#6(-G@LR/[I7Q@O"57(ZF(@H*(R!M<V=S='(@(I+QCV\B
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G
M:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B@W2#
M2(.+@U^"\(UWD\<B"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(E-H;W<@
M56YS=6)S8W)I8F5D(@IM<V=S='(@(I3QC7>3QX+(@N""S(+PE5R.IB(*"B,@
M;7-G<W1R("*4\8UWD\>.TH+PE5R.IB(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8P.`IM<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN
M9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*;7-G<W1R("*3695T
M@O"-[8^<@K>"Z8*]@M^"S(-!@T.#4H.3@O"57(ZF@K6"W(*W@JF!2"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`R"FUS9VED(")3:&]W(&QE9V5N
M9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R("*#@8%;@XN(ZI>7E5R.
MIH+,B;J"R9#@EKZ!:9:BD\>!0974D$V-SR`N+BZ!:H+PE72)P8*U@MR"MX*I
M@4@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0P"FUS9VED(")3:&]W
M('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T.`IM<V=I9"`B4VAO=R!P
M<F5V:65W<R!I;B!T;V]L=&EP<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@W-PIM<V=I9"`B4VAO=R!T:&4@1F5T8V@@36%I;"!I
M8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R("*#@8-J@X6!6X-O@5N"R8.!
M@T.#BX[F@NB-GH+=@LR#08-#@U*#DX+PE5R.IH*U@MR"MX*I@4@B"@HC.B!L
M:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(E-H
M;W<@=&AE($EM86=E<R(*;7-G<W1R("*)YI&<@O"57(ZF(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4T"B,L(&9U>GIY"FUS9VED(")3:&]W
M('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B@X&#
M:H.%@5N#;X%;@LF#@8-#@XN.YH+HC9Z"W8+,@T&#0X-2@Y."\)5<CJ:"M8+<
M@K>"J8%((@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(X"FUS9VED(")3
M:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C8*;7-G:60@(E-H;W=N
M(@IM<V=S='(@(I5<CJ8B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C0R"FUS9VED(")3:5]Z92(*;7-G<W1R(")?6H-4@T.#
M62(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*;7-G:60@
M(E-I9VYE9"(*;7-G<W1R("*/D):\E70B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R("*#5(-#
M@UDB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C$Q"FUS9VED(")3;W)T(&)Y($%R<FEV86PB"FUS9W-T<B`BDYZ2A8Z>BM2/
MAR(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,38*;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R("*3^I5TCX<B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(V"FUS9VED
M(")3;W)T(&)Y($9R;VT@061D<F5S<R(*;7-G<W1R("*1EY!-C+.#08-H@XR#
M6(^'(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHT,0IM<V=I9"`B4V]R="!B>2!-97-S86=E(%-I>F4B"FUS9W-T<B`B@U2#
M0X-9CX<B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C,V"FUS9VED(")3;W)T(&)Y(%-U8FIE8W0B"FUS9W-T<B`B@U2#=8-7
M@T:#3H-GCX<B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C,Q"FUS9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R("*#6(.,
M@V*#:(^'(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHR,0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S(@IM<V=S='(@(H-!
M@VB#C(-8CX<B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z
M,C,*;7-G:60@(E-P86T@9F]L9&5R.B(*;7-G<W1R(")34$%-@X&#0X.+EW"#
M=(-(@XN#7R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T
M-@HC+"!F=7IZ>0IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97)S(@IM<V=S='(@
M(E],D\&.ZI6VCIHB"@HC.B!S96%R8V@N<&AP.C$S,PIM<V=I9"`B4W!E8VEA
M;"!6:7)T=6%L($9O;&1E<G,@8V%N(&YO="!B92!E9&ET960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T,PHC+"!F
M=7IZ>0IM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`B7TN#6(-Y@XN#8(-&
M@V*#3B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM
M<V=I9"`B4W!E;&P@0VAE8VME<B(*;7-G<W1R("*#6(-Y@XN#8(-&@V*#2H%;
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU-@IM<V=I9"`B4W!E;&P@8VAE
M8VL@8V]M<&QE=&4B"FUS9W-T<B`B@UB#>8.+@V"#1H-B@TZ*KI>Y(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W,0IM<V=I9"`B4W!E;&QI;F<@97)R
M;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T<B`B
M@UB#>8.+@V"#1H-B@TZ.GH+)E5R.IH*W@NF#1X.)@5N0E"(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU,3(@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8U,@IM<V=I9"`B4W1A<G0B"FUS9W-T<B`BBDJ.;B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@
M(E-T871I;VYE<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(H_SD=0B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")3
M=')I<"!!='1A8VAM96YT(@IM<V=S='(@(I-9E72"\(^<BXXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#,R"FUS9VED(")3=')I<"!L:6YE8G)E86MS
M/R(*;7-G<W1R("*)_(US@O"/G(N.@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*;7-G:60@(E-U8E]J
M96-T(@IM<V=S='(@(E]*C(^6O"(*"B,Z(&UE<W-A9V4N<&AP.C(V."!T:')E
M860N<&AP.C$U,"!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(U
M"B,Z(&QI8B]396%R8V@N<&AP.C,X"FUS9VED(")3=6)J96-T(@IM<V=S='(@
M(HR/EKPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(P"FUS9VED(")3
M=6)J96-T($9I96QD(@IM<V=S='(@(HR/EKR7DR(*"B,@;7-G<W1R("*,CY:\
M@W2#0H%;@XN#:"(*(SH@<V5A<F-H+G!H<#HS,3@@=&5M<&QA=&5S+W-A=F5I
M;6%G92]S879E:6UA9V4N:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S
M<&AR87-E+FEN8SHR,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q
M"FUS9VED(")3=6)M:70B"FUS9W-T<B`BCL"-<R(*"B,@;7-G<W1R("*2\8]O
M(@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B
M4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R("*#=(-(@XN#7X+PC7>3
MQR(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@P(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C,X.0HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("*0K(SW(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T
M:6]N<R(*;7-G<W1R("*2\8C$(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8V,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(")3
M=6UM87)Y(@IM<V=S='(@(HI4EW8B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#`S"FUS9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D(@IM<V=S='(@
M(I72CU>#@H%;@VB"S)#8D=:"IB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I
M;VXB"FUS9W-T<B`B2%1-3""5TH]7@X*!6X-H@LF0V)'6@J:"Z2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H
M('1O('!L86EN('1E>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`B@V6#3(-8@V>5
MTH]7@X*!6X-H@LF0V)'6@J:"Z2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0Q.0IM<V=I9"`B5&5?>'0B"FUS9W-T<B`B7UB6>Y6V(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I
M9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`BB;R.\Y'X(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4Y,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T
M(')E<75E<W0B"FUS9W-T<B`BEW:+@8+PB;R.\Y'X@K>"Z2(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV96QY($%C
M8V5P=&5D(@IM<V=S='(@(HF\CO.1^"(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N
M<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R(")?6)9[E;8B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED(")4:&4@1G)O
M;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM
M<V=S='(@(H.!@V*#6H%;@U>"S"!&<F]M.B"7DX+&@XJ#DX-.@K>"Z8+,@LTZ
M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,S(*;7-G:60@(B(*(E1H92!)
M34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@875T
M:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C
M="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"FUS9VED(")4:&4@
M36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL
M;V%D960@)7,N(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(EPB)7-<(B"#=(-(@XN#
M7X*JC>V/G(*S@NJ"W(*U@KV!0B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HW
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E
M<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("*#@8-B@UJ!6X-7@LV,GX_8
M@K."ZH+<@K6"O8%"(@H*(SH@871T86-H;65N="YP:'`Z-#,*(RP@9G5Z>GD*
M;7-G:60@(E1H92!A='1A8VAM96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(I-9E72"JH*@@NB"W(*Y@O&!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@
M:6YV86QI9"(*;7-G<W1R("(\8CZ77)+HE5R"S(-F@5N#7H*JE7.0LX+%@K<\
M+V(^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C;VUP;W-E7W=I
M;BYJ<SHS-PIM<V=I9"`B(@HB5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E
M(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O
M("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*(H.!@5N#BXWL
MD*R#18-#@Y.#:(%;@JJ*2H*O@MR"N8+Q@4*#=8.)@T6#58+%@WR#8H-V@T&#
M8H-V@T6#0X.3@VB!6X+P@W6#C8-B@TXB"B*"M8+$@J*"W(*Y@O&"J8%((@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,@IM<V=I9"`B
M5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S
M96YT;6%I;%]M;VYT:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T
M;R!<(B5S7"(N(@IM<V=S='(@(HR[C=V"S(-T@TB#BX-?(%PB)7-<(B""S2!<
M(B5S7"(@@L:"HH*DEKR13X+)E<^-6(*S@NJ"W(*W@4(B"@HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,3`W"FUS9VED("(B"B)4:&4@8W5R<F5N="!L:7-T
M(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO
M="!B92!R971R:65V960B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3(S
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B
M965N('-A=F5D('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R("*#7H-8
M@TZ"S8*@@LB"O8+,@UZ#6(-.E5R"R9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3,Y"FUS9VED(")4:&4@979E;G0@
M=V%S(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(H-#@WB#DX-G
M@LV77)+HE5R"R9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E>'!A;F0N:6YC.CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@
M(H^0EKR"\))UBK>"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!L:6(O1F]L9&5R
M+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B7"(E<UPB((+&@J*"I):\D4^"
MS(-T@TB#BX-?@LV*^8+)D;:-W8*U@L2"HH+<@K>!0B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@9F]L9&5R
M(%PB)7-<(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA
M;64N($ET(&UA>2!C875S92`B"B)P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)<(B5S7"(@@W2#
M2(.+@U^"S):\D4^"R8+-@4&.9X*F@LB"HI6VCIJ"JHK<@MR"ZH+$@J*"W(*W
M@4*6XI'H@LR0MH*V@NF)PI1<D*N"JB(*(H*@@NB"W(*W@LR"Q8%!@U:#6(-E
M@X"*QY>=CM*"R8*RBFV41H*M@KZ"LX*B@4(B"@HC.B!L:6(O1F]L9&5R+G!H
M<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@
M=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET
M+B(*;7-G<W1R(")<(B5S7"(@@W2#2(.+@U^"JHWLD*R"LX+J@MR"M8*]@JJ!
M08*Q@LR#=(-(@XN#7X+PC7>3QX*U@L2"HH+<@KF"\8%"(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I
M8F5D(&9R;VT@:70N(@IM<V=S='(@(B(*(EPB)7-<(B"#=(-(@XN#7X*JC>V/
MG(*S@NJ"W(*U@KV"JH%!@K&"S(-T@TB#BX-?@LR-=Y/'@O"2AHY^@K6"Q(*B
M@MR"N8+Q@4(B"@HC.B!L:6(O1F]L9&5R+G!H<#HS-#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!C<F5A=&5D+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(EPB)7-<(B"#
M=(-(@XN#7X+PC>R0K(+%@JN"W(*Y@O&"Q8*U@KV!0H-4@5N#;X*I@N>"S(F>
MDYHZ(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C8U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T(&1E;&5T960N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B@W2#2(.+
M@U^!0"<E<R<@@LV-[8^<@K."ZH+<@KF"\8%"@U2!6X-O@LR)GI.:(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,S4Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T
M<B`B7"(E<UPB((-T@TB#BX-?@JJ-[)"L@K."ZH+<@K6"O8%"(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B
M7"(E<UPB((-T@TB#BX-?@JJ-[8^<@K."ZH+<@K6"O8%"(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N(@IM
M<V=S='(@(EPB)7-<(B"#=(-(@XN#7X+,EKR13X*J(%PB)7-<(B""R97/C5B"
MLX+J@MR"M8*]@4(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*
M;7-G:60@(E1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T
M:&ES('!A<G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?<V%V96EM86=E7W=I;BYJ<SHQ,@HC+"!F=7IZ>0IM<V=I9"`B(@HB
M5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H
M87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P
M=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB@X&!6X.+C>R0K(-%@T.#DX-H@5N"
MJHI*@J^"W(*Y@O&!0H-U@XF#18-5@L6#?(-B@W:#08-B@W:#18-#@Y.#:(%;
M@O"#=8.-@V*#3B(*(H*U@L2"HH+<@KF"\8*I@4@B"@HC.B!L:6(O34E-12]6
M:65W97(O:'1M;"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(B(*(E1H92!I;6%G
M97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S92!T:&4@<V5N9&5R(&ES('!R
M97-E;G0@:6X@>6]U<B`B"B)A9&1R97-S8F]O:RXB"FUS9W-T<B`B@T&#:(.,
M@UB2H(+)DV^87H*S@NJ"Q(*B@NF0;(*I@N>"S"!(5$U,((.!@T.#BX+-B>:1
MG(+PE5R.IH*U@MR"MX*I@4@B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"FUS9VED(")4:&4@;6%I
M;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA
M;"!M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T
M:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S
M86=E+G!H<#HV-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!M
M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(EPB)7-<(B""
MQH*B@J26O)%/@LR#=(-(@XN#7X+-BOF"R9&VC=V"M8+$@J*"W(*W@4(B"@HC
M.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B>71E<RD@97AC
M965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PIM<V=I9"`B5&AE(&UE<W-A
M9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG+B(*
M;7-G<W1R("*-[)"LDH:"S(.!@V*#6H%;@U>"S97"@K:"YX+J@MR"M8*]@4*/
M29>Y@K6"W(*W@4(B"@HC.B!M97-S86=E+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G
M:60@(E1H92!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(H.!
M@V*#6H%;@U>"S8R?C]B"LX+J@MR"M8*]@4(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HS.3,*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E
M<FEF:65D+B(*;7-G<W1R("*#@8-B@UJ!6X-7@LV,GX_8@K."ZH+<@K6"O8%"
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF
M:65D+B!396YD97(Z("5S+B(*;7-G<W1R("*#@8-B@UJ!6X-7@LV,GX_8@K."
MZH+<@K6"O8%"(@H*(SH@=&5M<&QA=&5S+W-M:6UE+V]P96Y?<VUI;65?=VEN
M+FIS.C$P('1E;7!L871E<R]P9W`O;W!E;E]P9W!?=VEN+FIS.C$P"B,L(&9U
M>GIY"FUS9VED("(B"B)4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@
M;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@
M(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB@X&!6X.+C>R0
MK(-%@T.#DX-H@5N"JHI*@J^"W(*Y@O&!0H-U@XF#18-5@L6#?(-B@W:#08-B
M@W:#18-#@Y.#:(%;@O"#=8.-@V*#3B(*(H*U@L2"HH+<@KF"\8*I@4@B"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(')A=R!T97AT(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@
M8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(E1H92!R97%U97-T960@9FEL
M92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*
M;7-G<W1R(")-4RU43D5&()-9E72"J8+GEW:+@8*S@NJ"O8-T@T"#0X.+@O".
MYH+HCV^"N8+<@KF"\8+%@K6"O8%"(@H*(SH@;&EB+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C0*;7-G:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E
M>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C4T-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N
M9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@
M:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E
M;F0@=&AE("(*(FYO=&EF:6-A=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HV.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E871E(&$@=&AU;6)N
M86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(B5S((+P@TZ#BH-B@TZ"MX+I
M@L:)YI&<@LR#5(.`@VR#0X.+@O"57(ZF@K6"W(*W@4(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P-`IM<V=I9"`B5&AE('-I9VYA='5R
M92!C;W5L9"!N;W0@8F4@<F5P;&%C960N(@IM<V=S='(@(H^0EKR"\))UBK>"
MQ8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FIS.C$P,@IM<V=I9"`B5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U
M;&QY(')E<&QA8V5D+B(*;7-G<W1R("*/D):\@LV2=8JW@K."ZH+<@K6"O8%"
M(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@
M9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@<W1A=&EO;F5R
M>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T
M:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T<B`B@X&#8H-:
M@5N#5X+-C)^/V(*S@NJ"W(*U@KV!0B(*"B,Z('-T871I;VYE<GDN<&AP.C8S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B7"(E<UPB((-T@TB#
MBX-?@JJ-[8^<@K."ZH+<@K6"O8%"(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA
M<R!B965N('5P9&%T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ-CD*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D
M('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(H->@UB#3H+-@J""R(*]@LR#
M7H-8@TZ57(+)DL>)P8*S@NJ"W(*U@KV!0B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")4:&4@=&5X="!O9B!T
M:&4@;65S<V%G92(*;7-G<W1R("*6>Y6V@JJ+\X+%@K<B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B@X&#8H-:@5N#5X+-C)^/V(*S@NJ"W(*U@KV!0B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M('-E;G0@;65S<V%G92(*;7-G<W1R("*6>Y6V@JJ+\X+%@K<B"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-30*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(I=<DNB/[I7Q
M@LV5VY&V@K."ZH+<@K6"O8%"(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R
M;F%T:79E+G!H<#HX-@IM<V=I9"`B5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V5M<'1Y7VUA:6QB;W@N:6YC.C,*
M;7-G:60@(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N
M(@IM<V=S='(@(H*Q@LR#@8%;@XN#>X-B@TZ#6(+)@LV#@8%;@XN"S8*@@NB"
MW(*Y@O&!0B(*"B,Z('1H<F5A9"YP:'`Z,3`Y"FUS9VED(")4:&5R92!I<R!N
M;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B)7,@@LR-[8^<DH:"R9;B
MD>B"JI2MD+:"M8+<@K6"O8%"@U2!6X-O@JF"YX+,B9Z3FH%&(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E
M<B!S86ED.B`E<R(*;7-G<W1R("*#@8%;@XN#>X-B@TZ#6(+,C>V/G)*&@LF6
MXI'H@JJ4K9"V@K6"W(*U@KV!0H-4@5N#;X*I@N>"S(F>DYJ!1B`E<R(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HV,C$*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(H.!@5N#BX-[@V*#3H-8@LR-[8^<DH:"R9;B
MD>B"JI2MD+:"M8+<@K6"O8%"@U2!6X-O@JF"YX+,B9Z3FH%&(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O
M(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G
M<W1R(")<(B5S7"(@@O`@7"(E<UPB((+)@U*#<X%;DH:"R8-'@XF!6X*JE*V0
MMH*U@MR"M8*]@4*#5(%;@V^"J8+G@LR)GI.:@48@(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C$Y."!L:6(O365S<V%G92YP:'`Z,C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE
M('-E<G9E<B!S86ED(@IM<V=S='(@(B(*(EPB)7-<(B"#=(-(@XN#7X*I@N>#
M@8-B@UJ!6X-7@O"-[8^<DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4*#5(%;
M@V^"J8+G@LR)GB(*(I.:@48B"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)<(B5S7"(@@W2#
M2(.+@U^3X(+,@X&#8H-:@5N#5X+PC>V/G)*&@LF#1X.)@5N"JI2MD+:"M8+<
M@K6"O8%"@U2!6X-O@JF"YX+,B9XB"B*3FH%&(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C(Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("5S(@IM<V=S='(@(H.!@V*#6H%;@U>-[8^<@T>#B8%;@JJ4K9"V
M@K6"W(*U@KV!0H-4@5N#;X*I@N>"S(F>DYJ!1B`E<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T
M<B`B@T.#>(.3@V>-[8^<DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@48E<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3(@;&EB+TU)344O5FEE
M=V5R+V5N<FEC:&5D+G!H<#HS-PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B@X&#8H-:
M@5N#5X-P@5N#9X+,E5R.IH+%@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0B(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9FQA9V=I
M;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA
M="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B@W2#2(.+@U\@)7,@@L6#
M1X.)@5N"JI2MD+:"M8+<@K6"O8%"@U2!6X-O@JF"YX+,B9Z3FH%&("(*"B,Z
M(&9O;&1E<G,N<&AP.C$V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R("(E<R""\(-#@Y.#
M?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G
M<W1R("*#0X-X@Y.#9X+P@T.#DX-\@5N#9Y*&@LF#1X.)@5N"JI2MD+:"M8+<
M@K6"O8%&)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38V"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R("*#7H-8@TZ"\(-#@Y.#?(%;@V>2
MAH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!1B5S(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M
M871I;VXZ("5S+B(*;7-G<W1R("*77)+HC^Z5\8+P@T.#DX-\@5N#9Y*&@LF#
M1X.)@5N"JI2MD+:"M8+<@K6"O8%&)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&UO=FEN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@
M:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B7"(E<UPB((+P
M(%PB)7-<(B""R8C:DZZ2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0H-4@5N#
M;X*I@N>"S(F>DYJ!1B`B"@HC.B!C;VUP;W-E+G!H<#HQ,C0T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R
M869T+B(*;7-G<W1R("*)NH^1@JN"S)7;D;:2AH+)@T>#B8%;@JJ4K9"V@K6"
MW(*U@KV!0B(*"B,Z(&-O;7!O<V4N<&AP.C$P,#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S86=E
M.B`E<R(*;7-G<W1R("*#@8%;@XN"S)&7D$V2AH+)@T>#B8%;@JJ4K9"V@K6"
MW(*U@KTZ("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B@T.#>(.3@V>"S(U8D%:2AH+)
M@T>#B8%;@JJ4K9"V@K6"W(*U@KV!1B5S(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!L86EN+G!H<#HU.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI
M<R!M97-S86=E('!A<G0B"FUS9W-T<B`BEGN5MH*JB_."Q8*W(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"B,L(&9U>GIY"FUS9VED(")4:&ES
M($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B(*;7-G
M<W1R("*"L8+,@X&#8H-:@5N#5X+-(%!'4"""Q8C#C8:)NX*S@NJ"Q(*B@MR"
MMR(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY,`IM<V=I9"`B(@HB
M5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@
M0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@(@HB=&AI<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-@HC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE
M(&UE<W-A9V4N(@IM<V=S='(@(I'E@JN"R(GFD9P@)7,@@JJ3695T@K."ZH+$
M@J*"W(*W@4(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`T(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3@*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$T,R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34W"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S,@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C,Q-`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O
M<G1E9"XB"FUS9W-T<B`B@K&"S(^(DG6"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y
M@O&!0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@
M;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B@K&"S(^(DG6"S8+<@KZ.
MP)&5@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,30*;7-G:60@(E1H:7,@;6%Y('1A:V4@<V]M92!T:6UE
M+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_(@IM<V=S='(@
M(H*Q@LR1@(WL@LF"S8Z>BM2"JH*I@JF"Z(+<@K>!0I&`C>R"\)&Q@J^"W(*W
M@JF!2"(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*
M;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q
M,`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N
M(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I
M82!3+R(*(DU)344N(@IM<V=S='(@(H*Q@LR#@8-B@UJ!6X-7@LT@4R]-24U%
M((+%CY"6O(*S@NJ"Q(*B@MR"MX%"(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HT,30*(RP@9G5Z>GD*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT
M86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I
M82!3+TU)344N(@IM<V=S='(@(H*Q@LR#@8-B@UJ!6X-7@LT@4R]-24U%((+%
MB,.-AHF[@K."ZH+$@J*"W(*W@4(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!M
M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M
M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q-0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G<W1R("(E
M<R""S9"S@K6"HHQ@CJZ"S(.!@5N#BX-[@V*#3H-8@L6"S8*@@NB"W(*Y@O&!
M0B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(T,"!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HS-3`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H
M86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S`*;7-G:60@(E1H:7,@;65S<V%G
M92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%
M(&9O<FUA="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,C`U(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C0Q-@IM<V=I9"`B5&AI
M<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"XB
M"FUS9W-T<B`B@K&"S(.!@V*#6H%;@U>"S2!01U`@@L6/D):\@K."ZH+$@J*"
MW(*W@4(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T,PIM<V=I
M9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA
M(%,O34E-12XB"FUS9W-T<B`B@K&"S(.!@V*#6H%;@U>"S2!3+TU)344@@L6/
MD):\@K."ZH+$@J*"W(*W@4(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S.`IM<V=I9"`B
M5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*
M;7-G<W1R("*"L8+,@X&#8H-:@5N#5X+-(%,O34E-12""Q8C#C8:)NX*S@NJ"
MQ(*B@MR"MX%"(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`Q(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,0IM<V=I9"`B5&AI<R!M97-S86=E
M(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`B@K&"S(.!
M@V*#6H%;@U>"S2!01U`@@L6(PXV&B;N"LX+J@L2"HH+<@K<B"@HC.B!M97-S
M86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G92!T;R(*;7-G<W1R("*"
ML8+,@X&!6X.+(@H*(SH@86-L+G!H<#HT-@IM<V=I9"`B5&AI<R!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W
M:6YD;W<N(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,34R"B,L(&9U>GIY
M"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G<W1R("*57(ZF(@H*(SH@=&AR
M96%D+G!H<#HW-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(R"FUS9VED(")4
M:')E860@5FEE=R(*;7-G<W1R("*#6(.,@V*#:)5<CJ8B"@HC.B!M97-S86=E
M+G!H<#HR-C0@;6%I;&)O>"YP:'`Z-C`V('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C8Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,3`@;&EB
M+U-E87)C:"YP:'`Z,C8*;7-G:60@(E1O(@IM<V=S='(@(E1O(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDQ.0IM<V=I9"`B5&\@061D<F5S<R(*;7-G
M<W1R("*(MI#F(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,S(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H
M:6QE("(*(F-L:6-K:6YG+B(*;7-G<W1R("(B"B*5H9"4@LR-@);:@O"129'P
M@K>"Z8+)@LV!05!#@L6"S4-O;G1R;VR#3(-#@4%-86."R(+G0V]M;6%N9(-,
M@T."\(F?@K6"R(*J@N>#3B(*(H.*@V*#3H*U@MR"MX%"(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HQ,S0*;7-G:60@(B(*(E1O('5S92!A(%1,4R!C;VYN
M96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@
M-2XP+C8@;W(@(@HB:&EG:&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(E1O=&%L($%T=&%C:&UE
M;G1S(%-I>F4Z(@IM<V=S='(@(HV'C':"S)-9E72#5(-#@UDZ(@H*(SH@9F]L
M9&5R<RYP:'`Z,S@X"FUS9VED(")4<F%S:"!F;VQD97(B"FUS9W-T<B`B@U.#
M?I2@@W2#2(.+@U\B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N
M:6YC.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM<V=S='(@(H-3@WZ4H(-T
M@TB#BX-?@48B"@HC.B!L:6(O475O=&$O8WER=7,N<&AP.C8U(&QI8B]1=6]T
M82]M97)C=7)Y,S(N<&AP.C<Y(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC
M.B!L:6(O475O=&$O;&]G9FEL92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N
M<&AP.C4S(&QI8B]1=6]T82]M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE
M('1O(')E=')I979E('%U;W1A(@IM<V=S='(@(H-.@TB!6X->@JJ.YI.^@L6"
MJX+<@KF"\2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ.0HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,V"FUS9VED(")5;F%N<W=E
M<F5D(@IM<V=S='(@(I:BE=2032(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z,S4*;7-G:60@(E5N86YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B
MEJ*5U)!-@X&!6X.+(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*
M;7-G:60@(E5N9&5L971E(@IM<V=S='(@(HWMCYR.YH+HC\&"M2(*"B,Z(&UA
M:6QB;W@N<&AP.C4X.2!M86EL8F]X+G!H<#HV,#(@;&EB+TU)344O2&5A9&5R
M<RYP:'`Z,C$R"FUS9VED(")5;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S
M='(@(I3QC/:*2H+,B+:0YB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N
M="!O9B!T>7!E.B`E<R(*;7-G<W1R("*(M8*F@LB"HH-F@5N#7H+%@K>!1B5S
M(@H*(SH@;6%I;&)O>"YP:'`Z-38U"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N
M($1A=&4B"FUS9W-T<B`BE7.6OH+(B>^+8R(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!4"!R
M97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,S4*
M;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R("*5<Y:^@LB)[XMC(@H*
M(SH@;6%I;&)O>"YP:'`Z-C$X"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(%)E
M8VEP:65N="(*;7-G<W1R("*5<Y:^@LB)[XMC(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*(RP@
M9G5Z>GD*;7-G:60@(E5N;&]A9"!087-S<&AR87-E(@IM<V=S='(@(H-P@UB#
M=(.,@5N#68+PD_R7S2(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HV-0IM<V=I
M9"`B56YN86UE9"(*;7-G<W1R("*6O)%/@LB"M2(*"B,Z(&UE<W-A9V4N<&AP
M.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*;7-G
M<W1R("*6HI/'(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,3(*;7-G:60@(E5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I(@IM<V=S='(@
M(H-T@TB#BX-?@LR-=Y/'DH:.?B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4X-`HC+"!F=7IZ>0IM<V=I9"`B57!D871E($%T=&%C:&UE
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`BC<605H+,C^Z5\8+PD9>"Z2(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C`*;7-G:60@(E5P9&%T92!R
M97-P;VYD96YT('-T871U<R(*;7-G<W1R("*)\9.:CM*"S(_SB[6"\(U8D%8B
M"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-3@@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z
M-#$*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(H-F@W2#2(.+
M@V>"\(YGEW`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED
M(")5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T<B`B24U!
M4""#=(-(@XN#7X+PC7>3QX%>E/&-=Y/'@L6129'P@K6"W(*W@JF!2"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,S4*(RP@9G5Z>GD*;7-G:60@(E5S
M92!6:7)T=6%L(%1R87-H($9O;&1E<C\B"FUS9W-T<B`BB;R1>H-T@TB#BX-?
M(@H*(R!M<V=S='(@(DE-05`@@W2#2(.+@U^-=Y/'@O"7F)=P@K>"Z2(*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$T,@IM<V=I9"`B57-E<B(*;7-G<W1R
M("*#AH%;@U4B"@HC.B!A8VPN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E8VEF
M:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<W"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R("*#AH%;@U66O"(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHQ-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(H.&
M@5N#59:\@48B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M-PIM<V=I9"`B5FEE=R(*;7-G<W1R("*57(ZF(@H*(SH@;&EB+TU)344O5FEE
M=V5R+WII<"YP:'`Z.3(@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B5S((+PE5R.
MIB(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,@
M4'5B;&EC($ME>2(*;7-G<W1R("(E<R""S(SVBDJ,KH+PE5R.IB(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*;7-G:60@(E9I97<@2%1-3"!C
M;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(DA434R"S)/@
MEV6"\)7*@LR#18-#@Y.#:(%;@LF57(ZF(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,C@*(RP@9G5Z>GD*;7-G:60@(E9I97<@365S<V%G
M97,B"FUS9W-T<B`BD%:+2X.!@5N#BR(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6
M:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(HS"D&R"S)3IEJ>,
MKH+PE5R.IB(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")6:65W(%!E<G-O;F%L(%!U
M8FQI8R!+97DB"FUS9W-T<B`BC,*0;(+,C/:*2HRN@O"57(ZF(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")6
M:65W(%1H<F5A9"(*;7-G<W1R("*#6(.,@V*#:)5<CJ8B"@HC.B!L:6(O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,38U"FUS9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R("*#5(.`
M@VR#0X.+E5R.IB(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X
M"B,L(&9U>GIY"FUS9VED(")6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<B"FUS9W-T<B`B2%1-3(+,D^"798+PE<J"S(-%@T.#DX-H@5N"
MR95<CJ8B"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(E9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O
M=R(*;7-G<W1R(")(5$U,@LR3X)=E@O"5RH+,@T6#0X.3@VB!6X+)E5R.IB(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#`*;7-G:60@(E9I97<@
M979E;G0B"FUS9W-T<B`B@T.#>(.3@V>"\)5<CJ8B"@HC.B!F;VQD97)S+G!H
M<#HS.#`@;6%I;&)O>"YP:'`Z-3,T"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@;65S<V%G97,@:6X@)7,B"FUS9W-T<B`B)7,@DH:"S(.!@V*#6H%;@U>"
M\)5<CJ8B"@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N
M:6YC.C(S"FUS9VED(")6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E
M<B!L;V=I;CHB"FUS9W-T<B`B@XV#3X-#@Y.,XX+,E5R.IH%&(@H*(R!M<V=S
M='(@(H.-@T^#0X.3C.."R95<CJ:"MX+I@X&!6X.+@WN#8H-.@UB"W(*]@LV5
M7(ZFB>:6RB(*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,`IM<V=I
M9"`B5FEE=R!T87-K(@IM<V=S='(@(H->@UB#3I5<CJ8B"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3`Q"FUS9VED(")6:65W('1H92!);6%G97,B
M"FUS9W-T<B`BB>:1G(+PE5R.IB(*"B,Z('-E87)C:"YP:'`Z,C8S"B,L('!H
M<"UF;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<(B!C<F5A=&5D
M('-U8V-E<V9U;&QY+B(*;7-G<W1R("*)O)%Z@W2#2(.+@U\@7"(E<UPB((*J
MC>R0K(*S@NJ"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,3$Q(&QI8B])34%0+U1R964N<&AP.C$S."!L:6(O24U!4"]4<F5E+G!H
M<#HQ-3$*(SH@;&EB+TE-05`O5')E92YP:'`Z,34S(&QI8B])34%0+U1R964N
M<&AP.C$U-R!L:6(O24U!4"]4<F5E+G!H<#HQ-3@*(SH@;&EB+TE-05`O5')E
M92YP:'`Z,S8Y(&QI8B])34%0+U1R964N<&AP.C,Y,R!L:6(O24U!4"]4<F5E
M+G!H<#HT,S,*;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*;7-G<W1R("*)O)%Z
M@W2#2(.+@U\B"@HC.B!S96%R8V@N<&AP.C(T-0HC+"!F=7IZ>0IM<V=I9"`B
M5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB"FUS9W-T<B`BB;R1
M>H-T@TB#BX-?@LR#B8-X@XLB"@HC.B!L:6(O5D9O;&1E<BYP:'`Z,3<U(&QI
M8B]61F]L9&5R+G!H<#HQ.#`*;7-G:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#$V"B,L(&9U>GIY"FUS9VED(")6:7)T
M=6%L($E.0D]8($9O;&1E<B(*;7-G<W1R("*)O)%Z@W2#2(.+@U\B"@HC.B!M
M86EL8F]X+G!H<#HT-3(@;&EB+U9&;VQD97(N<&AP.C$Q-"!L:6(O5D9O;&1E
M<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S
M='(@(HF\D7J#=(-(@XN#7R(*"B,Z(&9O;&1E<G,N<&AP.C0Q,PHC+"!F=7IZ
M>0IM<V=I9"`B5FER='5A;"!4<F%S:"!&;VQD97(B"FUS9W-T<B`BB;R1>H-T
M@TB#BX-?(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G
M:60@(E9I<G1U86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@(HF\D7J#=(-(@XN#
M7X+,@XF#>(.+(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S0*
M(RP@9G5Z>GD*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BDU>*2I*&(@H*(SH@
M;&]G:6XN<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O
M("5S(@IM<V=S='(@(B5S((+6@N:"I(*Q@KLB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C$Y"B,L(&9U>GIY"FUS9VED("(B"B)7:&%T('-H;W5L9"!W
M92!D;R!W:71H('-P86T@;65S<V%G97,@869T97(@=&AE>2!H879E(&)E96X@
M<F5P;W)T960@87,@<W!A;2`B"B)O<B!I;FYO8V5N=#\B"FUS9W-T<B`B4U!!
M32"5\8V0C<^"W8+,@X&#8H-:@5N#5X+PC>V/G(*U@MR"MX*I@4@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(W"FUS9VED("(B"B)7:&5N(&1E;&5T
M:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@
M:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T
M<B`B(@HB@X&#8H-:@5N#5X+,C>V/G(+-@4&-[8^<@L:"HH*DB/."\)5T@J^"
MZ8+,@L6"S8+(@JV!08-3@WZ4H(-T@TB#BX-?@LF(VI.N@K6"W"(*(H*W@JF!
M2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(E=H96X@
M;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT
M('1O('-T87)T(&]N/R(*;7-G<W1R("*#@8%;@XN#>X-B@TZ#6(+PBDJ"HH*]
MCIZ!08+'@LR#>8%;@U>"J8+GE5R.IH*U@MR"MX*I@4@B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA
M:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B
MD9>038U4@J:"\)7;D;:"MX+IC=N!09-9E72"X)7;D;:"M8+<@K>"J8%((@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE;B!S
M96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA
M:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R97-S
M97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7:&ET
M96QI<W0B"FUS9W-T<B`B@WJ#CX-#@V>#BH-8@V<B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDW.`IM<V=I9"`B665S(@IM<V=S='(@(H+-@J(B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C4X"B,L(&9U>GIY"FUS
M9VED(")9;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O
M;&QO=VEN9R!A8V-O=6YT*',I.B(*;7-G<W1R("*1O(+,@U2!6X-O@JF"YX.!
M@5N#BX+PCN:3OH*W@NF"O8+?@LR0W9+H@O""M8+<@K>!0B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P"B,L(&9U>GIY
M"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M
M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H
M<RDN(@IM<V=S='(@(HZ?@LR#=(-(@XN#7X+PC>V/G(*U@N:"I(+&@K6"Q(*B
M@MR"MX%&(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M
M+FAT;6PZ.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!A='1E;7!T:6YG('1O
M(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2XB"FUS9W-T<B`BCI^"
MS(-T@TB#BX-?@O"-[8^<@K6"YH*D@L:"M8+$@J*"W(*W@48B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@(EEO=2!A<F4@8V]P>6EN
M9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+B(*;7-G<W1R("*05H*U@J*#=(-(
M@XN#7X+)@U*#<X%;@5Z(VI.N@K6"YH*D@L:"M8+$@J*"W(*W@4(B"@HC(&US
M9W-T<B`B@W2#2(.+@U^"S):\D4^"\)7/C5B"M8+$@J*"W(*W@48B"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R"FUS9VED(")9;W4@
M87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`BCI^"S(-T
M@TB#BX-?@LR#5(-U@W2#2(.+@U^"\(WLD*R"M8+$@J*"W(*W@48B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B66]U
M(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N(@IM<V=S='(@(HW%
MC^.(RH+,@W2#2(.+@U^"\(WLD*R"M8+F@J2"QH*U@L2"HH+<@K>!0B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C,R,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@9F]L9&5R<RXB"FUS9W-T<B`BC<6/XXC*
M@LR#=(-(@XN#7X+PC>R0K(*U@N:"I(+&@K6"Q(*B@MR"MX%"(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,S(W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*
M;7-G<W1R("(B"@HC(&US9W-T<B`BCI^"S(-T@TB#BX-?@LR#5(-U@W2#2(.+
M@U^"\(WLD*R"M8+$@J*"W(*W@48B"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F
M;VQD97(Z("(*;7-G<W1R("*#=(-(@XN#7X+,EKR13X+PE<^-6(*U@L2"HH+<
M@K>!1B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(EPB)7-<(B""S(UWD\>"\)*&CGZ"M8+<@K6"O8%"(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,U"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@<&QA
M8V5H;VQD97)S(&EN('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@
M(@HB8W5R<F5N="!M97-S86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T
M=7)E+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R964@
M=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@=V5R
M92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C$V.0IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B(*
M;7-G<W1R("*"H(+(@KV"R8+-@K&"S(-T@TB#BX-?@O"5SXU8@K>"Z8-!@TZ#
M6H-8C*""JH*@@NB"W(*Y@O$B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S86=E
M(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@;65S<V%G97,N(@IM
M<V=S='(@(I!6DH6#@8%;@XN"JB`E<R"2RH*@@NB"W(*W@4(B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PIM<V=I9"`B66]U(&AA=F4@,2!N
M97<@;65S<V%G92XB"FUS9W-T<B`BD%:2A8.!@5N#BX*J(#$@DLJ"H(+H@MR"
MMX%"(@H*(SH@8V]M<&]S92YP:'`Z-#DT"B,L(&9U>GIY"FUS9VED(")9;W4@
M:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N(@IM<V=S='(@(I!6
MDH6#@8%;@XN"JB`Q()+*@J""Z(+<@K>!0B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA=F4@870@
M;&5A<W0@;VYE(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T
M('5P;&]A9"!Y970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD
M('1H:7,@;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S/R(*;7-G
M<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@:&%V92!N
M97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`BCI^"
MS(-T@TB#BX-?@LF05I*%@X&!6X.+@JJ"H(+H@MR"MSHB"@HC.B!L:6(O24U0
M+G!H<#HQ,#<Y"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L
M;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(H*Q@NJ"YX+,@W2#2(.+@U^"R9!6
MDH6#@8%;@XN"JH*@@NB"W(*W@48B"@HC(&US9W-T<B`BCI^"S(-T@TB#BX-?
M@LF05I*%@X&!6X.+@JJ"H(+H@MR"MSHB"B,Z(&-O;7!O<V4N<&AP.C$U,PIM
M<V=I9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB
M"FUS9W-T<B`B,2"0;(C(C^."S(BVD.:"\(YWDNB"M8+$@JV"OH*S@J*!0B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,P,@IM<V=I9"`B(@HB66]U
M(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A
M=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Y"FUS9VED("(B"B)9;W4@;75S
M="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T
M92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-C0@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS9VED(")9;W4@;75S="!S
M96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB"FUS9W-T<B`BEMJ328+,
M@X&!6X.+@WN#8H-.@UB"\(W%CXF"R9%)@O&"Q8*M@KZ"LX*B@4(B"@HC.B!F
M971C:&UA:6QP<F5F<RYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S='(@(C$@
M@L*(R(_C@LR#@8%;@XN"\(W%CXF"R9%)@O&"Q8*M@KZ"LX*B@4(B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C@Q"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B@T&#:(.,
M@UB"\(W%CXF"R9%)@O&"Q8*M@KZ"LX*B@4(B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP;&%T97,O;6%I;&)O>"]J879A
M<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,C8S"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE
M(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@(C$@@L*(R(_C@LR#@8%;@XN"\(W%
MCXF"R9%)@O&"Q8*M@KZ"LX*B@4(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R
M961I<F5C="YI;F,Z,3,*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!R96-I
M<&EE;G0N(@IM<V=S='(@(HBVD.:"\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C(Y"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!F:6QE('1O
M(&%T=&%C:"XB"FUS9W-T<B`B,2""PHC(C^."S(.!@5N#BX+PC<6/B8+)D4F"
M\8+%@JV"OH*S@J*!0B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@
M=&\@:&%V92!<(B5S7"(@96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P
M=&EO;G,N(@IM<V=S='(@(H-)@W:#5H.'@Y."S"`G)7,G((+PETR,^(+)@K>"
MZ8*Q@L:!0B(*"B,@;7-G<W1R("*#@8%;@XN"\(.*@U^#0X.,@TZ#9X*W@NDB
M"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EEO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E
M)7,N(@IM<V=S='(@(H*Q@LR#@8%;@XN"\(*[@LR"W(+<DUV1EX*W@NDB"@HC
M(&US9W-T<B`B@X&!6X.+@O"#BH-?@T.#C(-.@V>"MX+I(@HC.B!L:6(O36%I
M;&QO9RYP:'`Z,30Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM<V=S='(@(H*Q@LR#
M@8%;@XN"\(*[@LR"W(+<DUV1EX*W@NDB"@HC.B!L:6(O1F]L9&5R+G!H<#HU
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('-U8G-C<FEB
M960@=&\@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(EPB)7-<(B""\(UWD\>"M8+$@J*"W(*Y@O&!0H-4@5N#;X*I@N>"
MS(F>DYJ!1B`B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<
M(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")<(B5S
M7"(@@LR-=Y/'@O"2AHY^@K6"Q(*B@MR"N8+Q@4*#5(%;@V^"J8+G@LR)GI.:
M@48@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<
M(B(*;7-G<W1R(")<(B5S7"(@@LR-=Y/'@O"*2HYN@K6"W(*U@KV!0B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB(@IM
M<V=S='(@(EPB)7-<(B""S(UWD\>"\)*&CGZ"M8+<@K6"O8%"(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"B,L(&9U>GIY"FUS9VED(")9;W5R($YA
M;64B"FUS9W-T<B`BEKR13R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU
M,`IM<V=I9"`B66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*;7-G<W1R
M("*"H(+(@KV"S"!01U`@C/:*2HRN@L:4Z9:GC*XB"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C<Q('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-@IM
M<V=I9"`B66]U<B!0<FEV871E($ME>2(*;7-G<W1R("*"H(+(@KV"S)3IEJ>,
MKB(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C<@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<Q"FUS9VED(")9;W5R(%!U8FQI8R!+97DB"FUS9W-T
M<B`B@J""R(*]@LR,]HI*C*XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,38U"B,L(&9U>GIY"FUS9VED(")9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\
M96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S='(@(I74D$V0YH+&@K6"Q)5<CJ:"
MLX+J@NF#08-H@XR#6(%&/&D^@6F/R)>JB<*!:CPO:3XB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C0Y"B,L(&9U>GIY"FUS9VED(")9;W5R(%,O
M34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS9W-T<B`B@J""
MR(*]@LP@4R]-24U%((SVBDJ,KH+&E.F6IXRN(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*;7-G:60@(EEO=7(@86-C
M;W5N=',Z(@IM<V=S='(@(H*@@LB"O8+,@T&#2H-%@Y.#9R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-S,*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@
M86QI87,@861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D
M9')E<W,@;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("*"H(+(@KV"S)7*
MEKR#08-H@XR#6#J!:8-)@W:#5H.'@Y.!0H)0C7."R8)0@T&#:(.,@UB"\(YW
MDNB!:B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDR"FUS9VED
M(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA
M>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(B(*(H*HCF>"HH+,@W6#
MB8-%@U6"Q8+-@K&"S([ME]Z"S(GFD9R"S(-#@Y.#B8-#@Y.57(ZF@O"#5(-\
M@5N#9X*U@L2"HH+<@KF"\2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,SD*;7-G:60@(EEO=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE
M<W-A9V5S.B(*;7-G<W1R("*1EY!-CIZ"S(-F@W2#2(.+@V>5MHZ:@UJ#8H-G
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS
M9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I
M;F<@;65S<V%G97,Z(@IM<V=S='(@(I&7D$V.GH+,@V:#=(-(@XN#9X+,B,.-
MAI7[ED`Z(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E
M;&EV97)E9"XB"FUS9W-T<B`B7"(E<UPB((-T@TB#BX-?@JJ-[8^<@K."ZH+<
M@K6"O8%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-@IM<V=I9"`B
M66]U<B!S:6=N871U<F4Z(@IM<V=S='(@(H^0EKPZ(@H*(SH@;65S<V%G92YP
M:'`Z,C@X(&-O;7!O<V4N<&AP.C$R.#0@;6%I;&)O>"YP:'`Z-30Y(&QI8B]#
M;VUP;W-E+G!H<#HX,3@*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");
MC(^6O(+(@K5=(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,C`U"FUS9VED(")?0F-C(@IM<V=S='(@(E]"8V,B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B
M7T*#=8.)@V*#3H.*@UB#9R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C$U-`IM<V=I9"`B7T-C(@IM<V=S='(@(E]#8R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,3`*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B7T2-[8^<(@H*
M(SH@;&EB+TE-4"YP:'`Z.3<Y"FUS9VED(")?1F]L9&5R<R(*;7-G<W1R(")?
M1H-T@TB#BX-?(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M.#$*;7-G:60@(E])9&5N=&ET>2(*;7-G<W1R(")?240B"@HC.B!L:6(O24U0
M+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G<W1R(")?24Y"3U@B"@HC.B!L
M:6(O24U0+G!H<#HQ,#(P"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?3(.-
M@T^#08-%@V<B"@HC.B!M97-S86=E+G!H<#HS.#0*;7-G:60@(E]-97-S86=E
M(%-O=7)C92(*;7-G<W1R(")?38RTE;8B"@HC.B!L:6(O24U0+G!H<#HY-S8*
M(RP@9G5Z>GD*;7-G:60@(E].97<@365S<V%G92(*;7-G<W1R("*05HM+@X&!
M6X.+(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C,S"FUS9VED(")?4')I;G0B"FUS9W-T<B`B7U"(\XW\(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(X.0IM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(E]0
MET20YI-X(@H*(SH@;6%I;&)O>"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(E]2969R97-H("5S(@IM<V=S='(@(E]2C<257(ZF)7,B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B7U)E
M<&QY(@IM<V=S='(@(E]2E=2032(*"B,Z(&QI8B])35`N<&AP.CDX,0IM<V=I
M9"`B7U-E87)C:"(*;7-G<W1R(")?4XR?C?4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT,S$*;7-G:60@(E]396YD($UE<W-A9V4B"FUS9W-T<B`B7U.1EY!-
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS
M,@IM<V=I9"`B7U1H<F5A9"(*;7-G<W1R(")?5(-8@XR#8H-H(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3$V"FUS9VED(")?5&\B"FUS
M9W-T<B`B7U1O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3,*;7-G:60@(E]5;F1E;&5T92(*;7-G<W1R(")?58WMCYR.YH_!(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED
M(")?5FEE=R!4:')E860B"FUS9W-T<B`B7U:#6(.,@V*#:)5<CJ8B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B
M"FUS9W-T<B`B7U>#>H./@T.#9X.*@UB#9R(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ-S8*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT-#`*;7-G:60@(F%T=&%C:&UE;G0B"FUS9W-T
M<B`BDUF5="(*"B,Z('9I97<N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")A='1A
M8VAM96YT<RYZ:7`B"FUS9W-T<B`BDUF5="(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C4Q,PIM<V=I9"`B8GET97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C(P,`IM<V=I9"`B8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<R
M"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,38T"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(R,`IM<V=I9"`B
M8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,3DV"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C@*;7-G:60@(F1A
M=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,C0*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`HC+"!F=7IZ>0IM
M<V=I9"`B9G)O;2(*;7-G<W1R(")?38VWCV^0;"(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ.#`*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#0*;7-G:60@(FEN<'5T+V]U='!U="!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@X"FUS9VED
M(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!S;6EM
M92YP:'`Z,CD@<&=P+G!H<#HV.0IM<V=I9"`B:V5Y(@IM<V=S='(@(B(*"B,Z
M(&9O;&1E<G,N<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B;6%I;&)O>"!F:6QE
M(@IM<V=S='(@(H.!@5N#BX-[@V*#3H-8(@H*(SH@8V]M<&]S92YP:'`Z,3`V
M-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")N86UE(@IM<V=S='(@(I:\
MD4\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S8*;7-G
M:60@(FYO;F4B"FUS9W-T<B`B@LB"M2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(F]R(@IM<V=S='(@(H+<@KV"S2(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,38*;7-G:60@(G!E<FUI<W-I;VX@9&5N
M:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,3(*;7-G:60@
M(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,3@T"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT
M-@IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS9W-T<B`B@UB#>8.+@T>#B8%;
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED
M(")S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B@UB#>8.+@T>#B8%;(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B<WES=&5M(&5R
M<F]R(@IM<V=S='(@(H-8@WF#BX-'@XF!6R(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,#@*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&:6QT97(N<&AP.C4Q"FUS9VED(")Y;W5R(&)L86-K;&ES="(*;7-G
M<W1R("*#=8.)@V*#3H.*@UB#9R(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS
M9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R("*#>H./@T.#9X.*@UB#9R(*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+VES7TE3+G!O````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,T,#4U-0`Q,#0Q-S,V
M,C<V-``P,3<R,3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R#-<VQE;G-K82!F>7)I<B!)35`@-"XP+C0*(R!#;W!Y<FEG
M:'0@*$,I(#(P,#(@2&]R9&4@4')O:F5C="X*(PIM<V=I9"`B(@IM<V=S='(@
M(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U0(#0N,"XT7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#(M,#$M,3`@,3DZ,#`K,#$P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-2TQ,2TQ.2`R,#HS,RLP,#`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($)J;W)N($1A=FED<W-O;B`\8FIO<W-I0'-N97)P82YI<SY<
M;B(*(DQA;F=U86=E+51E86TZ($EC96QA;F1I8R`\<W5P<&]R=$!S;F5R<&$N
M:7,^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR
M-C4@;&EB+T-O;7!O<V4N<&AP.C,Q-PIM<V=I9"`B("`@("`@5&\Z("(*;7-G
M<W1R("(@("`@("!4:6PZ("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR-3,@;&EB
M+T-O;7!O<V4N<&AP.C,P-0IM<V=I9"`B("`@($1A=&4Z("(*;7-G<W1R("(@
M("!$86=S+CH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(U-B!L:6(O0V]M<&]S
M92YP:'`Z,S`X"FUS9VED("(@("`@1G)O;3H@(@IM<V=S='(@(B`@("`@1G+A
M.B`B"@HC.B!M86EL8F]X+G!H<#HT,#8@=&5M<&QA=&5S+V9O;&1E<G,O:&5A
M9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(V,B!L:6(O0V]M<&]S
M92YP:'`Z,S$T"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(B!%9FYI<VSM
M;F$Z("(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW-`IM
M<V=I9"`B(&EN("(*;7-G<W1R("(@[2`B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z
M(&UA:6QB;W@N<&AP.C$Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S
M86=E<R!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B)60@<VME>71U;2!H
M969U<B!V97)I\"!E>71T+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)60@;65S<V%G97,@:&%V92!B965N(')E<&]R
M=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(E1I;&MY;FYI;F<@=6T@)60@<VME>71I(&UE<FMT('-E
M;2!E:VMI(')U<VQP\W-T=7(@:&5F=7(@=F5R:?`@<V5N9"`B"B)K97)F:7-U
M;7-J\VXN(@H*(SH@;&EB+U-P86TN<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P
M86TN(@IM<V=S='(@(E1I;&MY;FYI;F<@=6T@)60@<VME>71I(&UE<FMT('-E
M;2!E:VMI(')U<VQP\W-T=7(@:&5F=7(@=F5R:?`@<V5N9"XB"@HC.B!L:6(O
M4W!A;2YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E1I;&MY;FYI;F<@=6T@)60@<VME
M>71I(&UE<FMT('-E;2!R=7-L</-S='5R(&AE9G5R('9E<FGP('-E;F0@:V5R
M9FES=6US:O-N+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P
M86TN(@IM<V=S='(@(E1I;&MY;FYI;F<@=6T@)60@<VME>71I(&UE<FMT('-E
M;2!R=7-L</-S='5R(&AE9G5R('9E<FGP('-E;F0N(@H*(SH@;6%I;&)O>"YP
M:'`Z,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D($UE
M<W-A9V5S(@IM<V=S='(@(B5D('1I;"`E9"!A9B`E9"!S:V5Y='5M(@H*(SH@
M;6%I;&)O>"YP:'`Z-C$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM
M<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(%!'4"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!S;6EM92YP
M:'`Z,C4T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%,O34E-12!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R
M96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N
M;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@97(@;OH@_F5G87(@=&EL+B!-87!P
M86X@)7,@=F%R(&5K:VD@96YD=7)N969N9"XB"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C$R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@8F5I;F<@<F5N86UE
M9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G<W1R(")-87!P86X@
M)7,@=F5R\'5R('5M;F5F;F0@[2!U<'!H869I(&AV97)S(&WA;F'P87(N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B)7,@:&5F=7(@:6CF='0@
M=FGP("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(E
M<R!H969U<B!H869N8?`N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!A
M(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C$V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E
M<R!H969U<B!S=F%R8?`@8F_P:6YU('1I;"`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-#@R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S('1E;G1A=&EV96QY(&%C8V5P=&5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(E<R#S<VMA<B!E9G1I<B!U<'!L_7-I;F=U;2!U
M;2!H=F]R="#^^B!E<G0@=FGP;.%T:6YN+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S
M=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O("5S+B(*;7-G<W1R("(E<R!V87(@8N9T="#M
M("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@
M=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RXB"FUS9W-T<B`B(@H*
M(SH@;65S<V%G92YP:'`Z,C8Y(&UE<W-A9V4N<&AP.C(W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7W1O<"YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I(@IM<V=S='(@(B5S.B`E<R`H
M)60F;F)S<#MA9B9N8G-P.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHQ-#`*;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N
M9"!M;W9E('1O(&YE>'0@<V-R965N+BDB"FUS9W-T<B`B*%-A;?YY:VMJ82!B
M<F5Y=&EN9V%R(&]G(&9A<F$@[2!NYG-T82!G;'5G9V$N*2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C<*;7-G:60@(BA$:7-C87)D
M(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N
M+BDB"FUS9W-T<B`B*$AU;F1S82!A;&QA<B!B<F5Y=&EN9V%R(&]G(&9A<F$@
M=&EL(&)A:V$@[2!A\"!S:W)I9F$@<VME>71I+BDB"@HC.B!S<&5L;&EN9RYP
M:'`Z,C@P"FUS9VED("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E
M;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@
M(@HB0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@
M87!P;&EE9"XI(@IM<V=S='(@(B(*(BA&87)A('1I;"!B86MA(.T@8?`@<VMR
M:69A('-K97ET:2!E9G1I<B!A\"!H869A('9I<W1A\"!B<F5Y=&EN9V%R('-E
M;2!G97+P87(@(@HB:&%F82!V97)I\"!H:6YG8?`@=&EL+B!"<F5Y=&EN9V%R
M('-E;2!E:VMI(&AA9F$@=F5R:?`@<VMRX?!A<B!V97+P82!E:VMI("(*(F=E
M>6UD87(N*2(*"B,Z('-P96QL:6YG+G!H<#HR-S<*;7-G:60@(B(*(BA396YD
M(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S
M(&9A<BX@($-H86YG97,@;VX@=&AE("(*(F-U<G)E;G0@<V-R965N('=I;&P@
M3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J($+F='1U(/YE<W-U;2!V:?`@;67P
M(/YV[2!A\"!S;65L;&$@X2!/2R`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R
M97-S*&5S*2`J(@IM<V=S='(@(BH@5F5L9'4@;F5T9O9N9R`J(@H*(SH@;6%I
M;&)O>"YP:'`Z,3DT"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B16EN=2!S:V5Y=&D@=F%R(&5Y='0N(@H*(SH@;&EB+U-P
M86TN<&AP.C$X,`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D
M(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*(E1I;&MY;FYI;F<@=6T@96ET="!S:V5Y=&D@<V5M(&5K:VD@
M<G5S;'#S<W1U<B!H969U<B!V97)I\"!S96YD(&ME<F9I<W5M<VKS;BXB"@HC
M.B!L:6(O4W!A;2YP:'`Z,38P"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@
M<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(E1I;&MY;FYI;F<@=6T@
M96ET="!S:V5Y=&D@<V5M(')U<VQP\W-T=7(@:&5F=7(@=F5R:?`@<V5N9"XB
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<R"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E
M96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"B)4:6QK>6YN:6YG('5M(&5I='0@<VME>71I('-E
M;2!R=7-L</-S='5R(&AE9G5R('9E<FGP('-E;F0@:V5R9FES=6US:O-N+B(*
M"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*;7-G:60@(C$@;65S<V%G92!H87,@8F5E
M;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R(")4:6QK>6YN:6YG('5M(&5I
M='0@<VME>71I('-E;2!R=7-L</-S='5R(&AE9G5R('9E<FGP('-E;F0N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X.`IM<V=I9"`B,3`P(&-H87)A
M8W1E<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y
M,0IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#D*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3`*;7-G:60@
M(C4P,"!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E
M(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB
M"FUS9W-T<B`B4W3S<B!M>6YD(&YE9FYD("5S(&5R(&AE;F=D('9I\"#^971T
M82!S:V5Y=&DN(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R
M97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB
M<F5C:7!I96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z-0IM<V=I9"`B04Y$(@IM<V=S='(@(D]'(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4Y,`IM<V=I9"`B06-C97!T(')E<75E<W0B
M"FUS9W-T<B`B4V%M_GEK:VIA(&)E:?!N:2(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.#<*;7-G:60@(D%C8V5P="!R97%U97-T(&%N9"!A9&0@
M:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<U,PIM<V=I9"`B06-C97!T960B"FUS9W-T<B`B4V%M
M_GEK:W0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4W"FUS9VED
M(")!8V-E<'1E9#H@(@IM<V=S='(@(E-A;?YY:VMT.B`B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-PIM<V=I9"`B06-C;W5N="=S(&YA
M;64Z(@IM<V=S='(@(DYO=&%N9&%N869N.B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,C`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,`IM
M<V=I9"`B06-T:6]N<R(*;7-G<W1R(")!\&=E<O!I<B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P,PIM<V=I9"`B061D('-O=7)C
M92(*;7-G<W1R(")BYG1A('9I\"!H86YD<FET:2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU-S<@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X
M.`IM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C`P(&QI8B]-24U%+TAE861E<G,N
M<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&\@061D<F5S<R!B
M;V]K("@E<RDB"FUS9W-T<B`B0N9T82#M(&YE=&9A;F=A8O-K("@E<RDB"@HC
M.B!C;VUP;W-E+G!H<#HQ,3DQ"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D
M(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R(")6:?!H96YG:6YU
M(%PB)7-<(B!BYG1T('9I\"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3DP"FUS9VED("(B"B)!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES<&QA>2!W
M:&5N('9I97=I;F<Z(#QI/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@
M(@HB;VX@82!N97<@;&EN92D\+VD^(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-C(*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<R(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,PIM
M<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A
M:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E
M<G)O<B!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z
M(&-O;G1A8W1S+G!H<#HY,"!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$X,`HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-34@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,P"FUS9VED(")!9&1R
M97-S($)O;VLB"FUS9W-T<B`B3F5T9F%N9V%B\VLB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@
M(DYE=&9A;F=A8N9K=7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q
M"FUS9VED("(B"B)!9&1R97-S97,@=&\@0D-#(&%L;"!M97-S86=E<SH@/&D^
M*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@(@HB;&EN
M92D\+VD^(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-S,*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!E>'!L:6-I=&QY('1I92!T;R!T
M:&ES(&ED96YT:71Y.B`\:3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D
M<F5S<R!O;B!A(&YE=R!L:6YE*3PO:3XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-SDR"FUS9VED(")!;&PB"FUS9W-T<B`BUFQL('-K97ET:2(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C4*;7-G:60@(B(*(D%L
M;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E
M(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G<W1R("(B
M"B+6;&P@<VME>71I(.T@_F5S<V%R:2!M]G!P=2`O(/YE<W-U;2!M]G!P=6YU
M;2!V97+P82!G97EM9"#M('-T86MR:2!-0D]8('-K<N$Z(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R(%PB)7-<(B!F;VQD
M97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB
M9&5L971E9"XB"FUS9W-T<B`BUFQL=6T@<VME>71U;2#M(&WV<'!U;FYI(%PB
M)7-<(B!S96T@97)U(&5L9')I(&5N("5S(&1A9V$@=F5R\'5R(&5Y='0N(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO
M;G1H;'DN<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@
M8F4@9&5L971E9"XB"FUS9W-T<B`B(@HBUFQL=6T@96QD<FD@<VME>71U;2!S
M96T@_OH@:&5F=7(@<V5N="!F<N$@_NER+"!O9R!E<G4@96QD<FD@96X@)7,@
M;>%N8?!A("(*(G9E<O!U<B!E>71T+B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA
M;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`BUFQL
M=6T@<V5N="UM86EL(&WV<'!U;2!S96T@97)U(&5L9')I(&5N("5S(&WA;F'P
M82!V97+P=7(@97ET="XB"@HC.B!A8VPN<&AP.C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L
M;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU-0IM<V=I9"`B06QL;W<@9FEL
M=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$P
M"FUS9VED(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38U(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-S<*;7-G:60@(D%L=V%Y<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34P"FUS9VED(")!;'=A>7,@
M<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(")!;'1A9B!G97EM82!V:?!H96YG
M:2XB"@HC.B!L:6(O365S<V%G92YP:'`Z-#8X"FUS9VED("(B"B)!;B!E<G)O
M<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C
M:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C,V-`IM<V=I9"`B06X@=6YK;F]W;B!E<G)O
M<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RXB"FUS9W-T
M<B`BT_YE:VMT('9I;&QA(&MO;2!U<'`@_F5G87(@<F5Y;G0@=F%R(&'P(&9R
M86UK=N9M82!S:W+A;FEN9W5N82XB"@HC.B!M97-S86=E+G!H<#HT.#0@;6%I
M;&)O>"YP:'`Z-CDS('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHY"FUS9VED(")!;G-W97)E9"(*;7-G<W1R(")3
M=F%R8?`B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS9VED
M(")!;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")3:V5Y=&D@<V5M(&+Z:?`@
M97(@8?`@<W9A<F$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC
M.C<*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B5FER:VIA('/M=7(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07!P;'D@1FEL=&5R<R!T;R`E<R(*;7-G<W1R(")6:7)K
M:F$@<^UU<B!F>7)I<B`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHT,PIM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN
M9R!O;C\B"FUS9W-T<B`B5FER:VIA('/M=7(@_F5G87(@_OH@=&5N9VES="XB
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#D*;7-G:60@(D%P
M<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_
M(@IM<V=S='(@(E9I<FMJ82!S[75R(/YE9V%R($E.0D]8(&5R('5P<&;F<G0N
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDS('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-C4*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(*;7-G<W1R(")%<G0@_OH@=FES
M<R!U;2!A\"#^^B!V:6QJ:7(@9V5R82#^971T83\B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,38Y('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3(X
M"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO
M=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D(2DB"FUS9W-T
M<B`B17)T(/[Z('9I<W,@=6T@8?`@_OH@=FEL:FER(&=E<F$@_F5T=&$_(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHV('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHU"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@9&\@=&AI<S\B"FUS9W-T<B`B17)T(/[Z('9I<W,@=6T@8?`@
M_OH@=FEL:FER(&=E<F$@_F5T=&$_(@H*(SH@;65S<V%G92YP:'`Z,SDQ('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8X"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H97-E
M(&UE<W-A9V5S/R(*;7-G<W1R(")%<G0@_OH@=FES<R!U;2!A\"#^^B!V:6QJ
M:7(@14Y$04Y,14=!(&5Y\&$@_F5S<W5M('-K97ET=6T_(@H*(SH@;&EB+TU)
M344O0V]N=&5N=',N<&AP.C(P,@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_(@IM
M<V=S='(@(D5R="#^^B!V:7-S('5M(&'P(/[Z('9I;&II<B!%3D1!3DQ%1T$@
M97GP82#^97-S=6T@=FGP:&5N9VIU;3\B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&5M<'1Y('1H:7,@9F]L9&5R/R(*;7-G<W1R(")%<G0@_OH@=FES<R!U
M;2!A\"#^^B!V:6QJ:7(@=.9M82#^97-S82!M]G!P=3\B"@HC.B!L:6(O24U0
M+G!H<#HY,S$*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T
M>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`B17)T(/[Z('9I<W,@=6T@
M8?`@_OH@=FEL:FER('3F;6$@<G5S;&%K]G)F=6YA/R(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_
M(@IM<V=S='(@(D5R="#^^B!V:7-S('5M(&'P(/[Z('9I;&II<B!%3D1!3DQ%
M1T$@97GP82#^97-S=6T@<VME>71U;3\B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]J879A<V-R:7!T+FEN8SHW.2!T96UP;&%T97,O;65S<V%G92]J879A<V-R
M:7!T+FEN8SHX,`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E
M<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_(@IM<V=S='(@(D5R="#^
M^B!V:7-S('5M(&'P(/[Z('9I;&II<B!T:6QK>6YN82#^971T82!S:V5Y=&D@
M<V5M(&5K:VD@<G5S;'#S<W0_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z-S0@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI
M;F,Z-S4*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@
M=&AI<R!M97-S86=E(&%S('-P86T_(@IM<V=S='(@(D5R="#^^B!V:7-S('5M
M(&'P(/[Z('9I;&II<B!T:6QK>6YN82#^971T82!S:V5Y=&D@<V5M(')U<VQP
M\W-T/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.#<*;7-G:60@(D%R
M<FEV86P@5&EM92(*;7-G<W1R(")+;VUU=.UM:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,#(*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")(YFMK
M86YD:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4W-@IM<V=I9"`B07-K(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P.0IM<V=I9"`B071T86-H
M(@IM<V=S='(@(DAE;F=J82!S:W+A('9I\"(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0V-@IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S
M='(@(D+F=&$@=FGP('9I\&AE;F=J=6TB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT-#<*;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@>6]U
M<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#D*;7-G:60@(D%T=&%C
M:&5D($9I;&4Z(@IM<V=S='(@(E9I\&AE;F=I.B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HS-C(@;&EB+T-O;7!O<V4N<&AP.C0T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A
M8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T
M<B`B5FGP:&5N9VGP(%PB)7-<(B!E<B!O9B!S=/-R="X@4VMRX6EN('9A<B!%
M2TM)('9I\&AE;F=D+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS
M-S8*;7-G:60@(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R
M97%U97-T('EO=2!S96YT+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HW
M,CD@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,30@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#DV"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FIS.CDX"FUS9VED(")!='1A8VAM96YT(@IM<V=S='(@(E9I\&AE
M;F=I(@H*(SH@8V]M<&]S92YP:'`Z,3`P,2!L:6(O365S<V%G92YP:'`Z-#(Y
M"FUS9VED(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM
M96YT('1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0V
M-`HC.B!L:6(O0V]M<&]S92YP:'`Z.3@T"FUS9VED(")!='1A8VAM96YT<R(*
M;7-G<W1R(")6:?!H96YG:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV.#(*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")6:?!S=&%D9&ER(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*;7-G:60@
M(D%T=&5N=&EO;B(*;7-G<W1R(")!=&AU9V'P=2(*"B,Z(&QI8B]!=71H+VEM
M<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV,S0*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G
M97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@
M(@HB861D<F5S<V)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C(Y.`IM<V=I9"`B079A:6QA8FQE($%D9')E
M<W,@8F]O:W,Z(@IM<V=S='(@(E1I;'3F:V%R(&YE=&9A;F=A8N9K=7(Z(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q.0IM<V=I9"`B07=A:71I
M;F<@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M86-?:R!T;R`E<R(*;7-G<W1R(")4:6QB86MA(.T@)7,B"@HC.B!T:')E860N
M<&AP.C@V('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R(")4
M:6QB86MA(.T@)7,B"@HC.B!S96%R8V@N<&AP.C$T-R!M97-S86=E+G!H<#HR
M-3`@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C(*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR,`IM<V=I9"`B0F-C(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM
M<V=I9"`B0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF
M;W)M871I;VX@;65S<V%G92XB"FUS9W-T<B`B2.ER(&'P(&YE\&%N(&5R(&AR
MX7(@=&5X=&D@868@<W3V\'5U<&S]<VEN9V%S:V5Y=&EN=2XB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3D*;7-G:60@(D)L86-K;&ES="(*;7-G
M<W1R(")3=F%R=&QI<W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8R
M,@IM<V=I9"`B0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S
M('1H97D@87)E('-P96-I9FEC86QL>2!R97%U97-T960_(@IM<V=S='(@(B(*
M"B,Z('-E87)C:"YP:'`Z,34U"FUS9VED(")";V1Y(@IM<V=S='(@(DUE9VEN
M;>%L(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B
M0F]T:"(*;7-G<W1R(")"YO!I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8X,0IM<V=I9"`B0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-
M97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(X,PIM<V=I9"`B0U]H87)S970B"FUS9W-T<B`B4W1A9F%S971T
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED(")#
M86QE;F1A<B(*;7-G<W1R(")$86=A=&%L(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M
M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R(")'970@96MK:2!T96YG<W0@</-S
M=/YJ\VYI+B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS9VED
M(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@
M(@IM<V=S='(@(D=A="!E:VMI('1E;F=S="!P\W-T_FKS;FD@X2!F:F%R96YD
M83H@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N
M;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R
M96YT("(*(FUA:6QB;W@N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C(W
M,R!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8V"B,Z('1E;7!L871E
M<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(@=&5M<&QA=&5S+V9O;&1E<G,O:6UP
M;W)T+FEN8SHR,0HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M.#4@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(R"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4U('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ,C<*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")(
MYG1T82!V:?`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z
M,3$V('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<P"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R-@IM<V=I9"`B0V%N8V5L($UE
M<W-A9V4B"FUS9W-T<B`B2.9T=&$@=FGP('-K97ET:2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-0IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL
M;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS9W-T<B`B
M168@_OH@:.9T=&ER('9I\"#^X2!E<B#V;&QU(&5F;FD@<VME>71I<VEN<R!F
M87)G8?`N(@H*(SH@<V5A<F-H+G!H<#HQ-#,@;65S<V%G92YP:'`Z,C0Y('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,34*;7-G:60@(D-C(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#$*;7-G:60@(D-H
M86ER(%!E<G-O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z.#8*;7-G:60@(D-H86YG92(*;7-G<W1R(")"<F5Y=&$B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#<*;7-G:60@
M(D-H86YG92!!;&PB"FUS9W-T<B`B0G)E>71A(/9L;'5M(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.CDW('1E;7!L871E<R]A8VPO86-L+FEN8SHY.`IM
M<V=I9"`B0VAA;F=E($9O;&1E<B(*;7-G<W1R(")3:VEP=&$@=6T@;?9P<'4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"FUS9VED("(B"B)#:&%N
M9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@
M>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A<F4@
M<V]R=&5D+B(*;7-G<W1R("(B"B)(Z7(@9V5T=7(@_OH@8G)E>71T(/YV[2#A
M(&AV8?!A(&CA='0@<VME>71U;2!E<B!R8?!A\"!U<'`@;V<@:'9E<G-U(&UA
M<F=A<B`B"B)S:V5Y=&%L[6YU<B!S:N%S="#M(&AV97)J=6T@9VQU9V=A+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B0VAA;F=E(&UA
M:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@(D)R97ET
M82!P\W-T_FKS;G,@;V<@;?9P<'5S=&EL;&EN9W5M+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A
M9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B
M(@HB2.ER(&=E='5R(/[Z(&)R97ET="#^=NT@:'9A\&$@;F%F;BP@;F5T9F%N
M9R!O9R!S:V5Y=&ES8F]T;B!K96UU<B!F<F%M(.T@(@HB<VME>71U;2#^[6YU
M;2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDS"FUS9VED(")#:&%R
M86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C$S"FUS9VED(")#:&5C:R!&;VQD97(H<RD@
M9F]R($YE=R!-86EL(@IM<V=S='(@(DAV8?!A(&WV<'!U<B#A(&'P(&%T:'5G
M82!M9?`@;OUJ86X@</-S="#M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHW,2!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHR"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C$T"FUS9VED(")#
M:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@
M9G)O;3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U
M-`IM<V=I9"`B0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M97-S
M86=E/R(*;7-G<W1R(")!=&AU9V$@<W1A9G-E=&YI;F=U(&9Y<FER('-E;F1I
M;F=U/R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G
M:60@(D-H;V]S92!!8W1I;VXZ(@IM<V=S='(@(E9E;&1U(&'P9V5R\#HB"@HC
M.B!C;VYF:6<O<V5R=F5R<RYP:'`N9&ES=#HQ.34*;7-G:60@(D-H;V]S92!A
M(&UA:6P@<V5R=F5R.B(*;7-G<W1R(")696QD=2!P\W-T_FKS;CHB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,C<@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,3<W"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(R.`IM<V=I9"`B0VAO;W-E(&$@;6%T8V@@;W(@961I="!T
M:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E9E;&1U(&7P82!B
M<F5Y='1U('1I;"!HYF=R:3HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*;7-G:60@(D-H
M;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(E9E;&1U(&'P9V5R\#HB"@HC.B!T
M96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*;7-G:60@(D-H
M;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R
M97-S97,N(@IM<V=S='(@(E9E;&1U(&YE=&9A;F=A8O-K('-E;2#A(&'P(&YO
M=&$@_F5G87(@;OUJ=6T@;F5T9O9N9W5M(&5R(&+F='0@=FGP+B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PIM<V=I9"`B0VAO
M;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N
M(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(B(*(E9E;&1U('5P<'+V
M\'5N(&YE=&9A;F=A8O-K82!S96T@X2!A\"!L96ET82#M+"#^96=A<B!L96ET
M8?`@97(@8?`@;F5T9O9N9W5M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!C
M;VYV97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B<F]W
M<V5R(&-A;B!V:65W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!D;W=N;&]A9"!T:&4@:6UA9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT
M97(N<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G
M;R!T;R`E<R!M86YA9V5M96YT('!A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQI8VL@)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<N(@IM<V=S='(@(E-M96QL=2#A("5S('1I;"!A\"!S:V_P82!(5$U,
M(&EN;FEH86QD(.T@<^ER(&=L=6=G82XB"@HC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@
M=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R(")3
M;65L;'1U("5S('1I;"!A\"!S:V_P82!H86YA('-E;2!S;>%M>6YD+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#`W"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S
M97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(E-M96QL='4@X2`E<R!T:6P@8?`@
M<VMO\&$@=FGP:&5N9VD@[2!SZ7(@9VQU9V=A+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]R96QA=&5D+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC
M:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A
M('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B4VUE;&QT=2#A("5S('1I;"!A
M\"!S:V_P82#^96YN86X@:&QU=&$@[2!SZ7(@9VQU9V=A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,#0*;7-G:60@(D-L:6-K(&AE<F4@=&\@
M2$E$12!T:&4@26UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,#@*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@
M26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C,R,0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO=7(@
M<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I
M96QD<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(E-M96QL='4@X2!E:6YA
M(&%F(';V;&1U;2!N971F86YG86+S:W5M(&]G('9E;&1U(/[A(')E:71I('-E
M;2#A(&'P(&QE:71A(.TN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,3<Q"FUS9VED(")#;&EC:R!T;R!3879E(%!'4"!0=6)L:6,@2V5Y(&EN('EO
M=7(@061D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,3DQ"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K('1O
M(%-A=F4@4R]-24U%(&-E<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S
M<R!";V]K(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,C$*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S
M92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,@IM<V=I9"`B0VQI8VMI;F<@;VX@
M=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN
M:6YC.C,P"FUS9VED(")#;&]S92(*;7-G<W1R("),;VMA(@H*(SH@8V]M<&]S
M92YP:'`Z-S<U(&-O;7!O<V4N<&AP.C$P.#(*;7-G:60@(D-L;W-E('1H:7,@
M=VEN9&]W(@IM<V=S='(@(DQO:V$@_F5S<W5M(&=L=6=G82(*"B,Z(&9O;&1E
M<G,N<&AP.C0Q-@IM<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G<W1R("),;VMU
M\"!M87!P82(*"B,Z(&9O;&1E<G,N<&AP.C0S-@IM<V=I9"`B0V]L;&%P<V4B
M"FUS9W-T<B`B3&]K82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C,T"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T<B`B3&]K82#V;&QU
M;2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,T"FUS9VED
M(")#;VQL87!S92!!;&P@1F]L9&5R<R(*;7-G<W1R("),;VMA(/9L;'5M(&WV
M<'!U;2(*"B,Z(&9O;&1E<G,N<&AP.C0S-@IM<V=I9"`B0V]L;&%P<V4@1F]L
M9&5R(@IM<V=S='(@(DQO:V$@;?9P<'4B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC871O<CH@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ.3$*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`B071H=6=A<V5M9"(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW-CD*;7-G:60@(D-O;7!L971E9"(*;7-G<W1R("),
M;VMI\"(*"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C0R(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HQ.0IM<V=I9"`B0V]M<&]S92(*;7-G<W1R(")3
M96UJ82(*"B,Z(&UA:6QB;W@N<&AP.C<U-B!L:6(O34E-12](96%D97)S+G!H
M<#HQ.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]M<&]S92!-97-S86=E("@E
M<RDB"FUS9W-T<B`B4V5M:F$@<VME>71I("@E<RDB"@HC.B!C;VUP;W-E+G!H
M<#HW-S0@8V]M<&]S92YP:'`Z,3`X,0IM<V=I9"`B0V]M<&]S92!A;F]T:&5R
M(&UE<W-A9V4B"FUS9W-T<B`B4V5M:F$@;OUT="!S:V5Y=&DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S
M(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")396UJ82!S:V5Y=&D@
M[2!SZ7(@9VQU9V=A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*
M;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B
M>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92`B"B)F96%T=7)E
M*3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS
M9VED(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B
M0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+B(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO
M;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!0
M1U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3
M+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M
M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T
M;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB
M4W1J\W)N82!H=F5NYG(@871H=6=A\"!E<B!U;2!P\W-T+"!O9R!H=F5R;FEG
M(.$@8?`@9V5R82!V:?!V87)T('5M(&[]:F%N("(*(G#S<W0N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8Y,0IM<V=I9"`B0V]N=F5R="!T97AT=6%L
M(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D*;7-G:60@(D-O<'DB"FUS
M9W-T<B`B069R:70B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C4Q('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D*
M;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@(D%F<FET82#M(&WV<'!U
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8V"FUS9VED
M(")#;W)R96-T(@IM<V=S='(@(DQE:?!RZ71T82(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#4*;7-G:60@(D-O<G)E8W1E9"!497AT
M(@IM<V=S='(@(DQE:?!RZ71T=7(@=&5X=&DB"@HC.B!A='1A8VAM96YT+G!H
M<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E('1H
M92!61E,@8F%C:V5N9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C8P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B1V%T(&5K:VD@97ET="!S:V5Y='5M(&9RX2`E<SH@)7,B"@HC.B!L:6(O
M4V5S<VEO;BYP:'`Z,CDS"FUS9VED(")#;W5L9"!N;W0@97AE8W5T92!M86EN
M=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R(")'870@96MK:2!F<F%M:W;F
M;70@=FGP:&%L9'-A\&=E<O!I<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F
M+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E
M9"!F:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD
M(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@
M87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS-C$@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C,Y('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-3<*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B0OIA('1I;"(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C4*;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T<B`B
M0OIA('1I;"!M]G!P=2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-3(*
M;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(D+Z82!T:6P@;'EK;&$B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,30*;7-G:60@(D-R96%T
M92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")"^F$@=&EL('/];F1A<FWV<'!U
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z
M,C8*;7-G:60@(D-R96%T92!A($YE=R!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O
M<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!3
M<&%M(&9O;&1E<B(*;7-G<W1R(")"^F$@=&EL(&[]:F$@;?9P<'4@=6YD:7(@
M<G5S;'#S<W0B"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN
M8SHQ,B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR-`IM<V=I
M9"`B0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T<B`B0OIA('1I
M;"!N_6IA(&WV<'!U('5N9&ER('5P<&OV<W0B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(W('1E;7!L871E<R]P<F5F<R]S96YT
M;6%I;'-E;&5C="YI;F,Z-#,*;7-G:60@(D-R96%T92!A(&YE=R!S96YT(&UA
M:6P@9F]L9&5R(@IM<V=S='(@(D+Z82!T:6P@;OUJ82!M]G!P=2!U;F1U<B!S
M96YD('-K97ET:2(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI
M;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR-`IM<V=I
M9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R(")"^F$@=&EL
M(&[]:F$@;?9P<'4@*')U<VQA:_9R9G4I('5N9&ER(&5Y9&0@<VME>71I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,`IM<V=I9"`B(@HB0W)E871E
M(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA
M:6PL('-O<G0@:70@:6YT;R!F;VQD97)S+"`B"B)A;F0@9&5L971E('-P86TN
M(@IM<V=S='(@(B(*(D+Z82!T:6P@<^UU<F5G;'5R('-E;2!S=&KS<FYA(&UE
M\&9E<O`@:6YN:V]M86YD:2!P\W-T<RP@9N9R82!H86YN(.T@(@HB=&EL=&5K
M;F%R(&WV<'!U<B!E\&$@97GP82!R=7-L</-S=&DN(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-U<G)E;G0@
M86-C97-S('1O("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#0*;7-G:60@(D-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI
M;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D-U<W1O;6EZ92!H;W<@
M>6]U('-E;F0@;6%I;"XB"FUS9W-T<B`B4W1I;&QA(&AV97)N:6<@</-S='5R
M(&5R('-E;F1U<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+B(*;7-G<W1R(")3=&EL;&$@8?!G97+P:7(@<V5M(&5R
M=2!F<F%M:W;F;61A<B#^96=A<B#^^B!T96YG:7-T("5S+B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*;7-G:60@(D1A
M=%]E(@IM<V=S='(@(D1A9W,B"@HC.B!M97-S86=E+G!H<#HR-#8@=&AR96%D
M+G!H<#HY,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$86=S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<U-PIM<V=I9"`B1&5C;&EN960B"FUS9W-T
M<B`B2&%F;F'P(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,PIM
M<V=I9"`B1&5C;&EN960Z("(*;7-G<W1R(")(869N8?`Z("(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B
M4VKA;&9G969I\"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.30*;7-G
M:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`B4VKA;&9G
M969I;B!R]O!U;F%R8?!F97+P.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,#0*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S
M='(@(E-JX6QF9V5F:6X@=7!P<O;P=6XZ(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<V-0IM<V=I9"`B1&5L96=A=&5D(@IM<V=S='(@(E+A\'-T
M869A\"(*"B,Z(&9O;&1E<G,N<&AP.C0P-R!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHX"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C$P('1E;7!L871E<R]P9W`O<&=P+FEN8SHY,PHC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z-B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C8U"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,C0T('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*;7-G:60@(D1E;&5T
M92(*;7-G<W1R(")%>?!A(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDS
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B17GP82!O<&EN
M8F5R82!L>6ML:6YU;2`E<R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M-CD@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,C@*;7-G:60@(D1E;&5T
M92!#=7)R96YT($ME>7,B"FUS9W-T<B`B17GP82!V:7)K=6T@;'EK;'5M(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-PIM<V=I9"`B1&5L
M971E($9O;&1E<BAS*2(*;7-G<W1R(")%>?!A(&WV<'!U*&TI(@H*(SH@9F]L
M9&5R<RYP:'`Z,C<T"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R<R(*
M;7-G<W1R(")%>?!A(';V;&1U;2!M]G!P=6TB"@HC.B!F;VQD97)S+G!H<#HT
M,#<*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")%>?!A
M('/];F1A<FWV<'!U(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E
M;6]T92!S97)V97(_(@IM<V=S='(@(DAR96EN<V$@^G0@<_-T="!S:V5Y=&D@
MX2!P\W-T_FKS;FD@X2!F:F%R96YD83\B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C(X"FUS9VED(")$96QE=&4@9G)O;2!M>2!C86QE;F1A<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8R"FUS9VED
M(")$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@
M;V8@;6]N=&@_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#0*;7-G:60@(D1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@
M8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")%>?!A(&?V;6QU;2!M]G!P
M=6T@;67P('-E;F1U;2!P\W-T:2#M('5P<&AA9FD@:'9E<G,@;>%N8?!A<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3(*;7-G:60@(D1E;&5T92!S
M<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S
M('-P86T_(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C0X-R!M86EL8F]X
M+G!H<#HW,3D@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHX"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C`@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHS.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R(")%>71T
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B1&5L
M971E9"!M97-S86=E<R(*;7-G<W1R(")%>61D('-K97ET:2(*"B,Z(&-O;7!O
M<V4N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A
M='1A8VAM96YT(%PB)7-<(BXB"FUS9W-T<B`B17ED9&D@=FGP:&5N9VEN=2!<
M(B5S7"(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$
M96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S(@IM<V=S='(@(D5Y\&EN9R!O
M9R!F;'5T;FEN9W5R('-K97ET82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU.3(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30P"FUS9VED(")$96YY(')E<75E
M<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS9VED(")$97-C96YD:6YG(@IM
M<V=S='(@(DSF:VMA;F1I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC.C(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-CD*;7-G
M:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(DS]<VEN9R(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHY,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30W"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-3$@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHV-0HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$Q,PIM
M<V=I9"`B1&5T86EL<R(*;7-G<W1R(")!=')I\&DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C<Q"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B"FUS9W-T
M<B`B2&%F82!U;F1I<G-K<FEF=&ER(&UE\"!D875F=6T@;&ET/R(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$:7-P
M;&%Y(@IM<V=S='(@(MIT;&ET(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0W,`IM<V=I9"`B1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN
M9R!A(&UE<W-A9V4_(@IM<V=S='(@(E/];F$@<W1A\&9E<W1I;F=U(&'P('-E
M;F1I;F=U(&QO:VEN;FD_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X
M,`IM<V=I9"`B1&ES<&QA>2!I;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V.`IM<V=I9"`B1&ES<&QA
M>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL/R(*;7-G<W1R(")3
M_6YA(%!O<%5P(&=L=6=G82#^96=A<B!N_7(@</-S='5R(&)E<G-T+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,S,*;7-G:60@(D1I<W!L87D@=&AE
M("=%;7!T>2!4<F%S:"<@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$Q"FUS
M9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C:"(*;7-G<W1R
M(")396T@<&%S<V%R(&5K:VD@=FGP(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,30*;7-G:60@(D1O($YO="!#:&5C:R!&;VQD97(H<RD@
M9F]R($YE=R!-86EL(@IM<V=S='(@(D5K:VD@871H=6=A('5M(&[]:F%N('#S
M<W0@[2!M]G!P=2AM*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C,*
M;7-G:60@(D1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#,Q"FUS9VED(")$
M;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/R(*;7-G<W1R(")6:6QT
M=2!O<&YA(/YE<W-A(&WV<'!U/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHQ,S,*;7-G:60@(D1O;F4B"FUS9W-T<B`B3&]K:?`B"@HC
M.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DQ"B,L('!H<"UF;W)M870*;7-G
M:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(E/F:VIA
M("5S('-E;2`N>FEP('-K<N$B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D
M97)S+FEN8SHU,@IM<V=I9"`B1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI
M;B`N>FEP(&9I;&4I(@IM<V=S='(@(E/F:VIA(/9L;"!V:?!H96YG:2`H[2`N
M>FEP('-K<N$I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,3@*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R(")3YFMJ82!M
M]G!P=2AR*2!Y9FER(.$@=FEN;G5S=/;P(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;
M+GII<"!F;W)M871=(@IM<V=S='(@(E/F:VIA(&WV<'!U*'(I(%LN>FEP('-K
M<N%=(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C$Y,0IM<V=I9"`B1&]W
M;FQO860@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B4^9K:F$@<V5M("YZ:7`@
M<VMRX2(*"B,Z(&UE<W-A9V4N<&AP.C0X-2!M86EL8F]X+G!H<#HV.3@@=&5M
M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHY"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHT,0HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$Q"FUS9VED(")$<F%F="(*;7-G<W1R(")5<'!K87-T(@H*(SH@9F]L9&5R
M<RYP:'`Z,S@W"FUS9VED(")$<F%F="!F;VQD97(B"FUS9W-T<B`B36%P<&$@
M9GER:7(@=7!P:_9S=#HB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L
M96-T+FEN8SHR,PIM<V=I9"`B1')A9G1S(&9O;&1E<CHB"FUS9W-T<B`B36%P
M<&$@9GER:7(@=7!P:_9S=#HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,3DV"FUS9VED(")%+6UA:6P@061D<F5S<R(*;7-G<W1R(").971F86YG(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,P,PIM<V=I9"`B14Y$(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED(")%4E)/
M4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N(@IM<V=S
M='(@(E9)3$Q!.B#>8?`@=/-K<W0@96MK:2!A('-E;F1A('-K97ET:?`N(@H*
M(SH@9F]L9&5R<RYP:'`Z-#`X"FUS9VED(")%9&ET(@IM<V=S='(@(D)R97ET
M82(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHR,0IM<V=I9"`B
M161I="!";&%C:VQI<W0B"FUS9W-T<B`B5FEN;F$@[2!S=F%R=&QI<W1A(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$V"FUS9VED(")%9&ET
M($9I;'1E<G,B"FUS9W-T<B`B5FEN;F$@[2!S[75M(&9Y<FER('#S<W0B"@HC
M.B!F;VQD97)S+G!H<#HT,#@@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC
M.C$V"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*;7-G:60@
M(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B0G)E>71A('/];F1A<FWV
M<'!U(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I
M;VX@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHR-@IM<V=I9"`B161I="!7:&ET96QI<W0B"FUS9W-T<B`B5FEN
M;F$@[2!H=NUT;&ES=&$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z,C$*;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B5FEN
M;F$@[2#^[6YU;2!S=F%R=&QI<W1A(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C$V"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(@IM
M<V=S='(@(D)R97ET82#^[6YU;2!S[75R96=L=6TB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#,P"FUS9VED(")%9&ET('EO=7(@<')E9F5R96YC97,@
M9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C8*;7-G:60@(D5D
M:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B5FEN;F$@[2#^[6YU;2!H=NUT
M;&ES=&$B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S
M.0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(").971F86YG(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%;7!T
M:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("+6;&P@<VME>71I
M(&9RX2`E<R!H<F5I;G-U\"#Z="XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR,`IM<V=I9"`B16UP='D@1F]L9&5R*',I(@IM<V=S='(@
M(E3F;6$@;?9P<'4H<BDB"@HC.B!F;VQD97)S+G!H<#HR-S4*;7-G:60@(D5M
M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B5.9M82!V86QD87(@;?9P
M<'5R(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G
M:60@(D5M<'1Y(%1R87-H(&9O;&1E<B(*;7-G<W1R(")4YFUA(')U<VQA:_9R
M9G5M]G!P=2(*"B,Z(&QI8B])35`N<&AP.CDS,0IM<V=I9"`B16UP='D@7U1R
M87-H(@IM<V=S='(@(E3F;6$@<G5S;&WV<'!U(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(P('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-@IM
M<V=I9"`B16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(P"FUS9VED(")%;F%B;&4@4R]-24U%(&9U;F-T
M:6]N86QI='D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.#`*;7-G:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G<W1R
M(")6:7)K:F$@9F]R<VMO\'5N('-K97ET83\B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO
M;G,B"FUS9W-T<B`B1'5L:_/P=6YA<G9A;&MO<W1I<B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,3<@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8U-PIM<V=I9"`B16YD(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS,S`*;7-G:60@(D5N9"!F;W)W87)D960@;65S<V%G92(*;7-G<W1R("),
M:OIK82!F<F%M<V5N9'4@<VME>71I(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(W
M,0IM<V=I9"`B16YD(&UE<W-A9V4B"FUS9W-T<B`B3&KZ:V$@<VME>71I(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C(V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(D5N9&$@9G)A;7-E;G0@<VME
M>71I(&9RX2`E<R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-3$@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,3<*;7-G:60@(D5N=&5R(%!A<W-P
M:')A<V4B"FUS9W-T<B`B4VMRX?!U(&EN;B!L>6MI;&OS\&$B"@HC.B!T96UP
M;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE
M(&YA;64@9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(E-LX?!U
M(&EN;B!N869N(.$@;OUJ=2!M]G!P=6YN:2!F>7)I<B!R=7-L</-S="(*"B,Z
M('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S
M='(@(E-LX?!U(&EN;B!N869N(.$@;OUJ=2!M]G!P=6YN:2!F>7)I<B!U<'!K
M]G-T(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR
M-`IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I
M;"!F;VQD97(B"FUS9W-T<B`B4VSA\'4@:6YN(&YA9FX@X2!N_6IU(&WV<'!U
M;FYI(&9Y<FER('-E;F0@<VME>71I(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R
M87-H<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(E-LX?!U(&EN;B!N869N(.$@
M;OUJ=2!M]G!P=6YN:2`H<G5S;&%K]G)F=2D@9GER:7(@97ED9"!S:V5Y=&DB
M"@HC.B!S96%R8V@N<&AP.C$U.0IM<V=I9"`B16YT:7)E($UE<W-A9V4B"FUS
M9W-T<B`B4VME>71I(.T@:&5I;&0@<VEN;FDB"@HC.B!M97-S86=E+G!H<#HQ
M-S@@8V]M<&]S92YP:'`Z,3`V."!T:')E860N<&AP.C,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D5N=')Y(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3F5T9F%N9VGP(%PB)7-<
M(B!V87(@<VMRX?`@[2!N971F86YG86+S:VEN82(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHX-"!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C4X"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X-B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HW,@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ
M-C,@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-C4*;7-G:60@(D5R<F]R
M(@IM<V=S='(@(E9I;&QA(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C,P.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`W"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`Q"FUS9VED(")%=F5N
M="!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B5FGP8G5R\&EN=6T@
M=F%R(&5Y='0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`IM<V=I
M9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("+!(&MO<G1E<G,@9G)E<W1I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U-0IM<V=I9"`B179E<GD@
M,S`@<V5C;VYD<R(*;7-G<W1R("+!(#,P('-E:RX@9G)E<W1I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<U-PIM<V=I9"`B179E<GD@-2!M:6YU=&5S
M(@IM<V=S='(@(L$@9FEM;2!M[6[Z=&YA(&9R97-T:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-3D*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G
M<W1R("+!(&CA;&9T[6UA(&9R97-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-38*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("+!(&WM;OIT
M=2!F<F5S=&DB"@HC.B!F;VQD97)S+G!H<#HT-#4*;7-G:60@(D5X<&%N9"(*
M;7-G<W1R(")/<&YA(&%L;&%R(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,S,*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`B3W!N82!A
M;&QA<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,S"FUS
M9VED(")%>'!A;F0@06QL($9O;&1E<G,B"FUS9W-T<B`B3W!N82!A;&QA<B!M
M]G!P=7(B"@HC.B!F;VQD97)S+G!H<#HT-#4*;7-G:60@(D5X<&%N9"!&;VQD
M97(B"FUS9W-T<B`B3W!N82!M]G!P=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W)E9&ER96-T+FEN8SHU-B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS,S$*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R(")/<&YA(&YA9FYA
M<VMRX2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#(Q"FUS9VED(")%
M>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L
M;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-3$*;7-G:60@(D5X<&%N9"!T:&4@96YT:7)E(&9O
M;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\B"FUS
M9W-T<B`B3W!N82!A;&QT(&WV<'!U='+I\"!S:N%L9F=E9FGP(.T@;?9P<'5H
M86TN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$P-"!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-34*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(U-@IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(D]P;F$@
M86QL87(B"@HC.B!L:6(O24U0+G!H<#HY-#`@;&EB+TE-4"YP:'`Z.30R"FUS
M9VED(")&7V5T8V@@36%I;"(*;7-G<W1R(")3YFMJ82!P\W-T(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(Y(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#,*;7-G:60@(D9E=&-H($UA:6PB"FUS9W-T<B`B4^9K
M:F$@</-S="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,SD*;7-G:60@
M(D9E=&-H($UA:6P@:6X@82!S97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(E/F
M:VIA('-K97ET:2#M('/I<B!G;'5G9V$_(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C0V"FUS9VED(")&971C:"!M97-S86=E<R!U<&]N
M(&QO9V=I;F<@;VX_(@IM<V=S='(@(E/F:VIA('-K97ET:2#^96=A<B#^^B!T
M96YG:7-T/R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&971C:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,B"FUS9W-T
M<B`B4_-T=&D@)60@<VME>71I(&9RX2`E<R(*"B,Z(&QI8B]&971C:&UA:6PN
M<&AP.C(X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D(#$@;65S<V%G
M92!F<F]M("5S(@IM<V=S='(@(E/S='1I(&5I='0@<VME>71I(&9RX2`E<R(*
M"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-2!L:6(O1F5T8VAM86EL+G!H<#HR
M.#<@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"FUS9VED(")&971C:&UA:6PZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*;7-G:60@(D9E
M=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R("+>^B#A='0@96YG
M:6X@;OT@<VME>71I+B(*"B,Z(&QI8B])35`N<&AP.CDT-@IM<V=I9"`B1FE?
M;'1E<G,B"FUS9W-T<B`B4^UU<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0Y,B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ
M<SHX,PIM<V=I9"`B1FEL92(*;7-G<W1R(")3:W+A(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C,U"FUS9VED(")&:6QT97(@3W!T:6]N<R(*
M;7-G<W1R(")3[75V86QK;W-T:7(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z.`IM<V=I9"`B1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(E/M
M=7-T:6QL:6YG87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3DT"FUS
M9VED(")&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_(@IM
M<V=S='(@(E/M82!S:V5Y=&D@9V%G;G9A<G0@<G5D9&%L96=U(&]R\&%L86=I
M/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z.`IM<V=I
M9"`B1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3D*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B4^UU<B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+VYO=&%C=&EV92YI;F,Z,@IM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E
M(@IM<V=S='(@(E/M=7(@14M+22!V:7)K87(B"@HC.B!L:6(O1FEL=&5R+G!H
M<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E
M;65N="!P86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3@V"FUS9VED(")&:6YD(@IM<V=S='(@(D9I;FYA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W-@IM<V=I9"`B1FER<W0@36%I
M;&)O>"!086=E(@IM<V=S='(@(D9Y<G-T82!S[?!A(@H*(SH@;6%I;&)O>"YP
M:'`Z,S0Q"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(D9Y<G-T82!S[?!A
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U"FUS9VED(")&;U]R
M=V%R9"(*;7-G<W1R("+!9G)A;7-E;F1A(@H*(SH@9F]L9&5R<RYP:'`Z,C4U
M('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G
M:60@(D9O;&1E<B!!8W1I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9O;&1E<G,N<&AP.C(Y,B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN
M8SHY"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z
M-@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C$P
M"FUS9VED(")&;VQD97(@3F%V:6=A=&]R(@IM<V=S='(@(DWV<'!U=NUS:7(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-0IM<V=I9"`B1F]L
M9&5R(%!R969I>"(*;7-G<W1R(")&;W)S:V5Y=&D@9GER:7(@;?9P<'5R(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D9O;&1E<B!3=6UM
M87)Y(@IM<V=S='(@(DWV<'!U>69I<FQI="(*"B,Z(&%C;"YP:'`Z,C0*;7-G
M:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R("(B
M"@HC.B!F;VQD97)S+G!H<#HU,@IM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@
M96YA8FQE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDT,`IM<V=I9"`B1F]R;6%T(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA
M:6QB;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T960@=&]D87DB"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z-S(W('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C(Q"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R("+!9G)A;7-E;F1A(@H*
M(SH@8V]M<&]S92YP:'`Z-S$R"FUS9VED(")&;W)W87)D.B(*;7-G<W1R("+!
M9G)A;7-E;F1A.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR.3D*;7-G:60@(D9O
M<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(L%F<F%M<V5N="!S:V5Y=&DB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,CDW"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`BP69R86US96YT('-K
M97ET:2!F<N$@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@S
M"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y-`IM<V=I9"`B1G)E92]"=7-Y
M(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.#@*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*;7-G:60@(D9R964O0G5S
M>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R;U]M(@IM
M<V=S='(@(D9RX2(*"B,Z('-E87)C:"YP:'`Z,3,U(&UE<W-A9V4N<&AP.C(T
M-R!T:')E860N<&AP.CDS"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.CDX"FUS9VED(")&<F]M(@IM<V=S='(@(D9RX2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.#D*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R
M(")396YD86YD86YE=&9A;F<B"@HC.B!C;VUP;W-E+G!H<#HW,C0@8V]M<&]S
M92YP:'`Z-S(X"FUS9VED(")&=V0Z(@IM<V=S='(@(L%F<F%M<RXZ(@H*(SH@
M8V]M<&]S92YP:'`Z,3(R.0IM<V=I9"`B1G=D.B`B"FUS9W-T<B`BP69R86US
M+CHB"@HC.B!C;VUP;W-E+G!H<#HQ,C,Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(D9R86US+CH@
M)74@9G)A;7-E;F0@<VME>71I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")'
M96YE<F%L($]P=&EO;G,B"FUS9W-T<B`B5F%L:V]S=&ER(&YO=&%N9&$B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@(D=E
M="!O;FQY(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B4^9K
M:F$@8F%R82!N_2!S:V5Y=&D_("A)34%0*2(*"B,Z('1H<F5A9"YP:'`Z.#4*
M;7-G:60@(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B3W!N82!S:V5Y=&DB"@HC
M.B!L:6(O24U0+G!H<#HU-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V\@=&\@
M861D<F5S<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R(")&87)A(.T@
M;F5T9F%N9V%B\VMA<G-K<N%N:6YG=2!F>7)I<B!<(B5S7"(B"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,3,U"FUS9VED(")'<F%N="!A8V-E<W,B"FUS
M9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-3,P(&QI8B]&:6QT97(N<&AP.C$P
M-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE
M=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.CDU"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P,B!L:6(O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C@*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(SH@;&EB+TU)344O5FEE=V5R
M+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HQ,C`*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(W(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#`W"FUS9VED(")(15)%(@IM<V=S='(@
M(FCI<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HX,"!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3(Y"FUS9VED(")(5$U,(@IM<V=S='(@
M(B(*"B,Z(&-O;7!O<V4N<&AP.C(R.0IM<V=I9"`B2%1-3"!697)S:6]N(&]F
M($UE<W-A9V4B"FUS9W-T<B`B2%1-3"#Z=&?A9F$@<VME>71I<R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4X"FUS9VED(")(96%D97)S
M(@IM<V=S='(@(DAA=7-A<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M
M<&]S92YI;F,Z-0IM<V=I9"`B2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R
M92!C;VUP;W-I;F<Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-C(*;7-G:60@(DAI9&1E;B(*;7-G<W1R(")&86QI\"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C$*;7-G:60@(DAI9&1E;B!I;B!4:')E
M860@5FEE=R(*;7-G<W1R(")&86QI\"#M(&5F;FES_G+A\'-H86TB"@HC.B!M
M86EL8F]X+G!H<#HS-C,*;7-G:60@(DAI9&4@1&5L971E9"(*;7-G<W1R(")&
M96QA(&5Y9&0@<VME>71I(@H*(SH@9F]L9&5R<RYP:'`Z,C@W"FUS9VED(")(
M:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")&96QA(/-V:7)K82AR*2!L[6YU
M*'(I(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P-`IM<V=I9"`B
M2&ED92!T:&4@26UA9V5S(@IM<V=S='(@(D9E;&$@;7EN9&ER;F%R(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S`U"FUS9VED(")(:6=H
M(@IM<V=S='(@(DCA<B(*"B,Z(&UE<W-A9V4N<&AP.C(X,2!M86EL8F]X+G!H
M<#HW,#,@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,@IM<V=I9"`B
M2&EG:"!0<FEO<FET>2(*;7-G<W1R(")(X7(@9F]R9V%N9W5R(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S`T"FUS9VED(")(:6=H97-T
M(@IM<V=S='(@(DCF<W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X
M,@IM<V=I9"`B2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N
M=',_(@IM<V=S='(@(DAV<FYI9R!V:6QT=2!S_6YA('9I\&AE;F=I/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.38*;7-G:60@(DAO=R!T;R!A='1R
M:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`B2'9E<FYI
M9R#A(&'P(&UE<FMJ82!T97AT82!S96T@97(@=F5R:?`@8?`@=NUS82#M(.T@
M<W9A<FDZ(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*;7-G:60@
M(DE-05`B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C,@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB"FUS
M9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-3(*;7-G:60@
M(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-`IM<V=I
M9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38R(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,30P"FUS9VED("))34%0+"!N;R!43%,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HT.0IM<V=I9"`B24U!4"]03U`S
M($UA:6P@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HX.#8*
M;7-G:60@(DE.0D]8(@IM<V=S='(@(DEN;F)O>"(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"FUS9VED("))9B!Y;W4@
M8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@
M8F4@;&]S="$B"FUS9W-T<B`BUFQL=6T@<VME>71U;2#M(&WV<'!U;FYI+VWV
M<'!U;G5M('9E<O!U<B!E>71T(2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHX.`IM<V=I9"`B26=N;W)E(@IM<V=S='(@(DAU;F1S82(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX.0IM<V=I9"`B
M26=N;W)E($%L;"(*;7-G<W1R(")(=6YD<V$@86QL="(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+VEM<&]R="YI;F,Z,C`*;7-G:60@(DEM<&]R="(*;7-G<W1R
M(")&;'ET:F$@:6YN(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHV-2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#0*;7-G:60@
M(DEM<&]R="!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(U-`IM<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C4*;7-G:60@(DEM<&]R
M="!-97-S86=E<R(*;7-G<W1R(")&;'ET:F$@:6YN('-K97ET:2(*"B,Z('!G
M<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,30X"FUS9VED("));7!O<G0@
M4&5R<V]N86P@0V5R=&EF:6-A=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O:6UP;W)T7VME>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA
M;"!0<FEV871E(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B
M;&EC(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!097)S;VYA;"!3+TU)344@
M0V5R=&EF:6-A=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,#<@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.0IM<V=I9"`B
M26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC(%!'4"!+
M97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN
M:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@4R]-24U%($ME>2(*;7-G<W1R
M("(B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@2V5Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z
M.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R(")&;'ET:F$@:6YN
M(&UB;W@@<VMRX2(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T(&UB;W@@9FEL92`E<R!I
M;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`B1FQY=&IA(&EN;B!M8F]X('-K<N%N
M82`E<R#M(&WV<'!U;F$@)7,N(@H*(SH@;65S<V%G92YP:'`Z-#@V(&UA:6QB
M;W@N<&AP.C<Q,R!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C<*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C,S"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z-PIM<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(L%R
M[?!A;F1I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHT-PIM<V=I
M9"`B26UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(L%R[?!A;F1I('-K97ET
M:2(*"B,Z(&9O;&1E<G,N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("(E9"!S:V5Y
M=&D@9G+A("5S(&EN;G-E='0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<W,PIM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HS-SD@;&EB+T9O;&1E<BYP:'`Z,C(W(&QI8B])35`N<&AP.C,U
M."!L:6(O24U!4"]4<F5E+G!H<#HQ,#4*(SH@;&EB+TE-05`O5')E92YP:'`Z
M,C`T"FUS9VED("));F)O>"(*;7-G<W1R("));FYB;W@B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#@T"FUS9VED("));F-L=61E(&$@8G)I968@<W5M
M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S@*;7-G:60@(DEN8VQU9&4@;W)I
M9VEN86P@;65S<V%G92!I;B!A(')E<&QY/R(*;7-G<W1R("+!(&'P('/];F$@
M969N:2!U<'!R=6YA;&5G82!B<NEF<VEN<R#M('-V87)I/R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C$S,`IM<V=I9"`B26YF;R(*;7-G<W1R(")5<'!L+B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHY,R!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C8U"B,L('!H<"UF;W)M870*;7-G:60@(DEN9F]R;6%T:6]N
M(&]N("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$U,0IM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@
M4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$T-R!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$Q,PIM<V=I9"`B
M26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,34@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DW"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDY"FUS9VED("));FQI;F4B"FUS9W-T
M<B`B4VME>71T(&EN;B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y
M+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED
M("));G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I
M9"`B26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED
M("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C
M=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*
M"B,Z(&UA:6QB;W@N<&AP.C4V,R!M86EL8F]X+G!H<#HV,#4*;7-G:60@(DEN
M=F%L:60@061D<F5S<R(*;7-G<W1R("+39VEL="!N971F86YG(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E
M($UA:6QB;W@B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DEN=F%L:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A
M9&1R97-S.B`E<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ-B!S;6EM92YP
M:'`Z.#(*;7-G:60@(DEN=F%L:60@:V5Y(@IM<V=S='(@(M-G:6QD=7(@;'EK
M:6QL(@H*(SH@<&=P+G!H<#HQ.38*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@
M4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$W,0IM
M<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I
M9"`B26YV97)T(@IM<V=S='(@(E9I\'-N^FGP(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-38W"FUS9VED(")+0B(*;7-G<W1R(")+0B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR,#$*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(U,@IM
M<V=I9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@
M=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N
M/R(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C,Q.`IM<V=I9"`B2V5Y('-U8V-E
M<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y.0IM<V=I9"`B
M3&%N9W5A9V4B"FUS9W-T<B`B5'5N9W5MX6PB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#<W"FUS9VED("),87-T($UA:6QB;W@@4&%G92(*;7-G<W1R
M(")S[?!A<W1A(&)L<RXB"@HC.B!M86EL8F]X+G!H<#HS-30*;7-G:60@(DQA
M<W0@4&%G92(*;7-G<W1R(")S[?!A<W1A(&)L<RXB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS.#`*;7-G:60@(DQI7VYK($%T=&%C:&UE
M;G1S(@IM<V=S='(@(E1E;F=J82!V:?!H96YG:2!M9?`@=F5F<VSS\"(*"B,Z
M(&%T=&%C:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HY-S0*;7-G:60@
M(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R(")%
M:VMI(&5R(&CF9W0@8?`@=&5N9VIA('9I\&AE;F=I(&UE\"!V969S;//P(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.CDY,0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R(")496YG;&%R(/-G:6QD
M:7(@_F%N;B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0P"FUS
M9VED("(B"B),:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O
M;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"`B"B)O;FQY
M('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-SD*;7-G
M:60@(DQI<W1I;F<@:6X@=&AE($AE861E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S`*;7-G:60@(DQO8V%L($UA
M:6QB;W@Z(@IM<V=S='(@(E#S<W1M87!P82(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-S0*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E-T8?!S
M971N:6YG(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#<*;7-G
M:60@(DQO9R!I;B(*;7-G<W1R(")496YG:F%S="(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O
M("5S(@IM<V=S='(@(E1E;F=J87-T("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,S8*;7-G:60@(DQO9VEN(@IM<V=S='(@(E1E;F=J87-T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R(")697)K969N:2!V:?`@=&5N9VEN9W4B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,#<*;7-G:60@(DQO=R(*;7-G
M<W1R("),X6=U<B(*"B,Z(&UE<W-A9V4N<&AP.C(X,R!M86EL8F]X+G!H<#HW
M,#8@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B3&]W
M(%!R:6]R:71Y(@IM<V=S='(@(DSA9W5R(&9O<F=A;F=U<B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P.`IM<V=I9"`B3&]W97-T(@IM
M<V=S='(@(DSF9W-T:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L
M92YP:'`Z-#0*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM<V=S='(@(DUA8VEN
M=&]S:"!S:W+A(@H*(SH@<&=P+G!H<#HS,S(@<VUI;64N<&AP.C(U-"!T96UP
M;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*;7-G:60@(DUA:6PB"FUS
M9W-T<B`B4/-S='5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU"FUS
M9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(D9O<G-K;_!U;B!P\W-T<R(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,38*
M;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SHB"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,SDW"FUS9VED(")-86EL8F]X(@IM<V=S
M='(@(E#S<W1M87!P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*
M;7-G:60@(DUA:6QB;W@@86YD($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS
M9W-T<B`BVG1L:71S<W1I;&QI;F=A<B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C$V"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&
M;VQD97(@87,@4V5E;B(*;7-G<W1R(")-97)K:F$@]FQL('-K97ET:2#M(&WV
M<'!U('-E;2!L97-I;B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C$W"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@
M56YS965N(@IM<V=S='(@(DUE<FMJ82#V;&P@<VME>71I(.T@;?9P<'4@<V5M
M(/-L97-I;B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S`@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHU"FUS9VED
M(")-87)K(&%S.B(*;7-G<W1R(")M97)K:F$@<V5M.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-#0*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L
M<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`B
MP2!A\"!M97)K:F$@96QD<FD@=&EL=FET;F%N:7(@[2!T97AT82!M9?`@;6ES
M;75N86YD:2!L:71U;3\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@
M;VYL>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U
M,@IM<V=I9"`B36%R:R!S:6UP;&4@;6%R:W5P/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@(DUA=&-H($%L
M;"!1=65R:65S(@IM<V=S='(@(D%L;'0@_F%R9B!A\"!P87-S82(*"B,Z('1E
M;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT,@IM<V=I9"`B36%T8V@@06YY
M(%%U97)Y(@IM<V=S='(@(D5I='1H=F'P(/YA<F8@8?`@<&%S<V$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#,*;7-G:60@(DUA>&EM
M=6T@071T86-H;65N="!3:7IE(@IM<V=S='(@(DCA;6%R:W-S=.9R\"!V:?!H
M96YG:7,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.#0*
M;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N
M(@IM<V=S='(@(DCA;6%R:W-F:O9L9&$@=FGP:&5N9VIA(&[A\"XB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-SD*;7-G:60@(DUA>&EM
M=6T@=&]T86P@871T86-H;65N="!S:7IE(')E86-H960N(@IM<V=S='(@(E9I
M\&AE;F=I(&5R(&]F('-T\W)T(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8R-@IM<V=I9"`B365E=&EN9R!#86YC96QL871I;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-0IM<V=I9"`B365E
M=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3@U"FUS9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3<*;7-G:60@
M(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Y.`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,PIM<V=I9"`B365E
M=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=')E95]F;VQD97)S+G!H<#HS"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR-#8*;7-G:60@(DUE<W-A
M9V4B"FUS9W-T<B`B4VME>71I(@H*(SH@8V]M<&]S92YP:'`Z-3`W(&-O;7!O
M<V4N<&AP.C4S-"!C;VUP;W-E+G!H<#HU.#@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4P"FUS9VED(")-97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@(E-E
M;6IA(&[]='0@<VME>71I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X
M.`IM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(D1A9W,N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`R"FUS9VED(")-97-S86=E($]P=&EO;G,B"FUS9W-T
M<B`B5F%L:V]S=&ER('-K97ET82(*"B,Z('-E87)C:"YP:'`Z,S4Y"FUS9VED
M(")-97-S86=E(%-E87)C:"(*;7-G<W1R("),96ET82#M('-K97ET=6TB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DR"FUS9VED(")-97-S86=E(%-I
M>F4B"FUS9W-T<B`B4W3F<O`@<VME>71I<R(*"B,Z(&UE<W-A9V4N<&AP.C,V
M.`IM<V=I9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`B2&%N9')I="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G92!6:65W
M:6YG(@IM<V=S='(@(E-K;_!A('-K97ET:2(*"B,Z('1E;7!L871E<R]S96%R
M8V@O:&5A9&5R+FEN8SHU-0IM<V=I9"`B365S<V%G92!F:65L9',B"FUS9W-T
M<B`B4W;F\&DB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G
M:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`B1FSV9V<B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E(&9O;&1E<G,B
M"FUS9W-T<B`B3?9P<'5R(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B4VME
M>71I(&9RX2`E<R(*"B,Z(&UA:6QB;W@N<&AP.C8T-@IM<V=I9"`B365S<V%G
M92!H87,@871T86-H;65N=',B"FUS9W-T<B`B4VME>71I\"!E<B!M9?`@=FGP
M:&5N9VIU;2(*"B,Z(&UA:6QB;W@N<&AP.C8S-PIM<V=I9"`B365S<V%G92!I
M<R!E;F-R>7!T960B"FUS9W-T<B`B4VME>71I\"!E<B!D=6QR:71A\"(*"B,Z
M(&UA:6QB;W@N<&AP.C8S,@IM<V=I9"`B365S<V%G92!I<R!S:6=N960B"FUS
M9W-T<B`B4VME>71I\"!E<B!U;F1I<G)I=&'P(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C,S"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS
M9W-T<B`B3&5I=&%R<VMI;'ER\&DB"@HC.B!C;VUP;W-E+G!H<#HW-S$@8V]M
M<&]S92YP:'`Z-S@U"FUS9VED(")-97-S86=E(')E9&ER96-T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,#$X"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U
M="!N;W0@<V%V960@=&\@)7,B"FUS9W-T<B`B4VME>71I\"!V87(@<V5N="P@
M96X@96MK:2!V87(@:.9G="!A\"!G97EM82#^8?`@[2`E<R(*"B,Z(&-O;7!O
M<V4N<&AP.C$P-S<@8V]M<&]S92YP:'`Z,3`Y,@IM<V=I9"`B365S<V%G92!S
M96YT('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4VME>71I\"!V87(@<V5N="XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$R"FUS9VED(")-97-S86=E
M<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W+B(*;7-G<W1R(")&:O9L
M9&D@<VME>71A;.UN82#A(&)L<RX@[2!S:V_P=6X@</-S=&CS;&9S+B(*"B,Z
M(&UA:6QB;W@N<&AP.C,Q.`IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B
M4VME>71I('1I;"(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I
M9"`B36]D:69Y(@IM<V=S='(@(D)R97ET82(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!T
M:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N(@IM<V=S
M='(@(D9L96ER:2!E;B!E:71T(&YE=&9A;F<@9F%N;G-T(&9Y<FER('-VYO!I
M\"!<(B5S7"(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3@*;7-G
M:60@(DUO=F4B"FUS9W-T<B`B1FQY=&IA(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-O=7)C97-E;&5C="YI;F,Z,S$V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T
M<B`B9N9R82!N:?!U<B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z-3`@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M.`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B9N9R82#M(&WV<'!U
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$T"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(F;F<F$@=7!P(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A
M;'1E<FYA=&EV92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C0@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-`HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(DY/5$4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S@@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B3F%M92(*;7-G
M<W1R(").869N(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD+V]R
M(&5M86EL(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B3F%F;B!O9R]E\&$@
M;F5T9F%N9R!MX2!E:VMI('9A;G1A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<W.`IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C,@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4W-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4T"FUS9VED(").
M979E<B(*;7-G<W1R(")!;&1R96DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-34S"FUS9VED(").979E<B!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@
M(D%L9')E:2!G97EM82!V:?!H96YG:2XB"@HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,3(V"FUS9VED(").97<B"FUS9W-T<B`B3OUT="(*"B,Z(&QI8B])
M35`N<&AP.C8Q-0IM<V=I9"`B3F5W($9O;&1E<B(*;7-G<W1R(")._2!M87!P
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B3F5W($UA
M:6PB"FUS9W-T<B`B3OUR('#S<W1U<B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R(")._2!S
M:V5Y=&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,30P
M"FUS9VED(").97AT(@IM<V=S='(@(D[F<W1A(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHS,PIM<V=I9"`B3F5X="!-97-S
M86=E(@IM<V=S='(@(D[F<W1A('-K97ET:2(*"B,Z(&UA:6QB;W@N<&AP.C,U
M,@IM<V=I9"`B3F5X="!086=E(@IM<V=S='(@(D[F<W1A('/M\&$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S(@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDT.`IM<V=I9"`B3F\B"FUS9W-T<B`B3F5I(@H*(SH@<VUI
M;64N<&AP.C(R-@IM<V=I9"`B3F\@0V5R=&EF:6-A=&4@9F]U;F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHU
M"FUS9VED(").;R!%;F-R>7!T:6]N(@IM<V=S='(@(D5N9VEN(&1U;&OS\'5N
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@P"FUS9VED(").;R!+97ES
M(&EN($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DYO($UE<W-A9V5S(@IM<V=S='(@(D5N9VEN
M('-K97ET:2(*"B,Z('!G<"YP:'`Z,3,W"FUS9VED(").;R!01U`@<'5B;&EC
M(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHQ-#`*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC871E
M(%!R97-E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,R,PIM
M<V=I9"`B3F\@4')E=FEE=R!497AT(@IM<V=S='(@(D5N9VEN;B!F;W)S:V_P
M=6YA<G1E>'1I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM
M<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS9W-T<B`B16YG:7(@;W!I
M;F)E<FER(&1U;')I='5N87)L>6ML87(@9G5N9'5S="(*"B,Z('-M:6UE+G!H
M<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3`*;7-G
M:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R(")%;F=I;B!V:?!H
M96YG:2!F=6YD=7-T+B(*"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"FUS
M9VED(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L
M:6,@:V5Y+B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C<R(&%C;"YP:'`Z.3@*
M;7-G:60@(DYO(&9O;&1E<B!S96QE8W1E9"XB"FUS9W-T<B`B96YG:6X@;6%P
M<&$@=F%L:6XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3,P"FUS9VED
M(").;R!F;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB
M"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C`W(&QI8B]&;VQD97(N<&AP
M.C0X,"!L:6(O1F]L9&5R+G!H<#HU,S`*;7-G:60@(DYO(&9O;&1E<G,@=V5R
M92!S<&5C:69I960B"FUS9W-T<B`B16YG:6X@;6%P<&$@=F%R('1I;&=R96EN
M9"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,S8*;7-G:60@(DYO(&9O
M;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`B16YG87(@;?9P<'5R
M(&UE\"!N_6IU;2!S:V5Y='5M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$S,PIM<V=I9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<R(*
M;7-G<W1R(")%;F=A<B!M]G!P=7(@;67P(/-L97-N=6T@<VME>71U;2(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR-#`*;7-G:60@(DYO(&UE<W-A9V4@8F]D>2!T
M97AT(@IM<V=S='(@(D5N9VEN;B!T97AT:2!S:V5Y=&DB"@HC.B!L:6(O36%I
M;&)O>"YP:'`Z,S8U"FUS9VED(").;R!M97-S86=E<R!M871C:&5D('EO=7(@
M<V5A<F-H+B(*;7-G<W1R("),96ET:6X@8F%R(&5K:VD@X7)A;F=U<B(*"B,Z
M('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K
M97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,38U"FUS9VED
M(").;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C(P,0IM<V=I9"`B3F\@<&5R<V]N86P@4R]-
M24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<W!E
M;&QI;F<N<&AP.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M
M(&-O;F9I9W5R960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHU,`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM
M<V=S='(@(D5N9V%R('-T869S971N:6YG87)V:6QL=7(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`V"FUS9VED(").;R!S=6=G97-T
M:6]N<R(*;7-G<W1R(")%;F=A<B!T:6QL]F=U<B(*"B,Z(&%C;"YP:'`Z-C@@
M86-L+G!H<#HY-`IM<V=I9"`B3F\@=7-E<B!S<&5C:69I960N(@IM<V=S='(@
M(D5N9VEN;B!N;W1A;F1I('1I;&=R96EN9'5R+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW,#D*;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Q('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,U"B,Z('1E;7!L871E
M<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-"!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C0Q"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-C0*;7-G:60@(DYO;F4B"FUS9W-T<B`B16YG:6XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,#8*;7-G:60@(DYO<FUA;"(*;7-G
M<W1R(")696YJ=6QE9W0B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G:60@
M(DYO="!$96QE=&5D(@IM<V=S='(@(D5K:VD@97ET="(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHT,@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C$R"FUS9VED(").;W0@1')A9G0B"FUS9W-T<B`B16MK:2!U<'!K
M87-T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-R!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,T"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z.`IM<V=I9"`B3F]T($EM<&]R=&%N
M="(*;7-G<W1R(")%:VMI(.%R[?!A;F1I(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T(%!E<G-O;F%L(@IM<V=S='(@
M(D5K:VD@<&5R<_-N=6QE9W0B"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HQ,SD@
M;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@;&EB+T-R>7!T+U--24U%+G!H<#HQ
M-#D*;7-G:60@(DYO="!A('9A;&ED('!U8FQI8R!K97DN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-C<*;7-G:60@(DYO="!D
M96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(D5K:VD@97ED9"!S:V5Y=&DB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED(").;W0@:6UP
M;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(D5K:VD@X7+M\&%N9&D@<VME>71I
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H
M<#HW,0IM<V=I9"`B3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*;7-G
M:60@(DYU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C
M:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(D%L9'5R
M(.T@;>%N=?!U;2!F>7)I<B!V:?!T96YG9&%R('9E9G-L\_!I<BP@<V5M('-K
M=6QU(&=E>6UA<W0L(/YE9V%R("(*(FWA;F'P87)L96<@=&EL=&5K="!E<B!G
M97+P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PIM<V=I9"`B3G5M
M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T
M:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(D9J]FQD:2!A9B!M]G!P=6T@9GER
M:7(@<V5N9"!S:V5Y=&DL('-E;2!S:W5L=2!G97EM87-T+"#^96=A<B!MX6YA
M\&%R;&5G("(*(G1I;'1E:W0@97(@9V5R\"(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C4T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU-3(*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,PIM<V=I9"`B
M3TLB"FUS9W-T<B`BS2!L86=I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L
M9',N:6YC.C4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT.`HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-#<*;7-G:60@(D]2(@IM
M<V=S='(@(D7002(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,34*
M;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R(")']FUU;"!S:V5Y=&DB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL
M>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P
M=7)G960N(@IM<V=S='(@(D?V;6QU;2!S:V5Y='5M(&5Y='0N+BXB"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C<*;7-G:60@(D]N;'D@9&ES<&QA>2!F
M;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@
M(D5I;G5N9VES('/];F$@;?9P<'5R('-E;2!I;FYI:&%L9&$@\VQE<VEN('-K
M97ET:3\B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R:7!T+FEN8SHW
M,0IM<V=I9"`B3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F
M;W(@=&AI<R!A8W1I;VXN(@IM<V=S='(@(MYA\"!E<B!E:6YU;F=I<R!HYF=T
M(&'P('9E:F$@96EN82!M]G!P=2!F>7)I<B#^97-S82!A\&=E<O`N(@H*(SH@
M=&5M<&QA=&5S+VUE;G4N:6YC.C<@=&5M<&QA=&5S+VUE;G4N:6YC.C(W"FUS
M9VED(")/<&5?;B!&;VQD97(B"FUS9W-T<B`B3W!N82!M]G!P=2(*"B,Z('1E
M;7!L871E<R]M96YU+FEN8SHR,PIM<V=I9"`B3W!E;B!&;VQD97(B"FUS9W-T
M<B`B3W!N82!M]G!P=2(*"B,Z(&9O;&1E<G,N<&AP.C0Q-`IM<V=I9"`B3W!E
M;F5D($9O;&1E<B(*;7-G<W1R(")/<&EN(&UA<'!A(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<P-0IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A
M;G0B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL+G!H<#HS,R!T96UP;&%T97,O
M9F5T8VAM86EL+W1O<"YI;F,Z,@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E
M=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H97(@36%I;"!!8V-O=6YT<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3@*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#(*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B0?!R
M87(@<W1I;&QI;F=A<B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI
M;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M.3`*;7-G:60@(E!'4"(*;7-G<W1R(")01U`B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*;7-G:60@(E!'4"!%;F-R>7!T($UE
M<W-A9V4B"FUS9W-T<B`B1'5L:_/P82!S:V5Y=&D@;67P(%!'4"(*"B,Z(&-O
M;7!O<V4N<&AP.C,S,0IM<V=I9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`B4$=0
M('9I;&QA(@H*(SH@8V]M<&]S92YP:'`Z,S$P"FUS9VED(")01U`@17)R;W(Z
M($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM
M<V=S='(@(E!'4"!V:6QL83H@5F%N=&%R(&QY:VEL:_/P82!F>7)I<B!P97)S
M\VYU;&5G86X@;'EK:6PN(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N
M:6YC.C8*;7-G:60@(E!'4"!.3U0@06-T:79E(@IM<V=S='(@(E!'4"!E<B!E
M:VMI('9I<FMT(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C8@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-`IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T
M<B`B4$=0('9A;&MO<W1I<B(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!0
M87-S<&AR87-E($EN<'5T(@IM<V=S='(@(E!'4"!L>6MI;&OS\&DB"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")01U`@4&5R<V]N86P@
M2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ
M-S,*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E>'0B"FUS9W-T<B`B(@H*(SH@
M<&=P+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+
M97D@9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM
M<V=S='(@(B(*"B,Z('!G<"YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+B(*;7-G<W1R(")/<&EN8F5R82!01U`@;'EK;&EN=6T@9GER:7(@
M7"(E<UPB('9A<B!E>71T+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`IM<V=I9"`B4$=0
M(%-I9VX@365S<V%G92(*;7-G<W1R(")5;F1I<G)I=&$@;67P(%!'4"(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.0IM<V=I9"`B
M4$=0(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(E5N9&ER<FET82]D
M=6QR:71A(&UE\"!01U`B"@HC.B!P9W`N<&AP.C(P,@IM<V=I9"`B4$=0('!R
M:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@
M<&=P+G!H<#HQ-S<*;7-G:60@(E!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F=6QL
M>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I
M=F4N:6YC.C$Q"FUS9VED(")01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T
M:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,C`X"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE
M('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR.34*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO
M="!C=7)R96YT;'D@86-T:79E('-O('1H92!M97-S86=E(&ES('5N86)L92!T
M;R!B92!D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR-`IM<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P
M=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U
M<G)E;G1L>2`B"B)S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@
M;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F
M96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G
M<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B
M4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-3
M3"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM
M<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38V
M"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L
M(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B
M"FUS9W-T<B`B0FQS+B`E9"!A9B`E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-S0*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE
M<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W
M-0IM<V=I9"`B4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C0S
M"FUS9VED(")087)T*',I(@IM<V=S='(@(DAL=71A<B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHR,3$*;7-G:60@(E!A<W-P:')A<V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q-@IM<V=I9"`B4&%S<W!H
M<F%S92`H06=A:6XI(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S$P('-M:6UE
M+G!H<#HR,S4*;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A
M9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N
M:6YC.C(Y('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ.0IM<V=I
M9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,3(*;7-G
M:60@(E!A<W-P:')A<V5S(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*
M(SH@<&=P+G!H<#HQ,30*;7-G:60@(E!A<W-P:')A<V5S(&1O(&YO="!M871C
M:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y
M,R!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-CD*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R("),>6MI;&]R\"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT.`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")&<F%M:W;F;6$@=FGP:&%L9'-A\&=E
M<O!I<B!V:?`@=&5N9VEN9W4B"@HC.B!A8VPN<&AP.C<V(&%C;"YP:'`Z,3`R
M"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R(&-A;B!N;W0@8F4@
M8VAA;F=E9"XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-#<W(&UA:6QB
M;W@N<&AP.C8X,B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$P"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*;7-G:60@(E!E<G-O
M;F%L(@IM<V=S='(@(E1I;"!M[6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(E5P
M<&S]<VEN9V%R('5M(&YO=&%N9&$B"@HC.B!P9W`N<&AP.C$R,`IM<V=I9"`B
M4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,C<*;7-G:60@(E!E<G-O;F%L(%!'
M4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!S
M;6EM92YP:'`Z,C`W"FUS9VED(")097)S;VYA;"!3+TU)344@8V5R=&EF:6-A
M=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ
M,S(*;7-G:60@(E!E<G-O;F%L(%,O34E-12!K97ES(&1E;&5T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C$T"FUS9VED(")0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE
M<R!A;F0@9F]R=V%R9',_(@IM<V=S='(@(E-E=&IA('5N9&ER<VMR:69T('5N
M9&ER('-V87(@;V<@X69R86US96YD:6YG87(_(@H*(SH@8V]M<&]S92YP:'`Z
M,C(W"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y
M,B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S
M='(@(E-LX?!U(&EN;B!N_71T(&WV<'!U;F%F;CHB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]J879A<V-R:7!T+FEN8SHY-"!T96UP;&%T97,O9F]L9&5R<R]J
M879A<V-R:7!T+FEN8SHY-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE
M(&]F('1H92!N97<@9F]L9&5R.B(*;7-G<W1R(")3;.'P=2!I;FX@;OUT="!M
M]G!P=6YA9FXZ(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:F%V87-C<FEP="YI
M;F,Z,3(Y"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.B(*;7-G
M<W1R(")3;.'P=2!I;FX@;OUJ82!N869N:?`Z(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P87-S<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0
M;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A
M=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB96YT97(@=&AI<R!P
M87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R
M('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@
M(@HB=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G:60@(B(*
M(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN9R!Y;W5R
M(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI97,@04Y$
M('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I;F1O=W,L
M('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO=7(@;6%I
M;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C:V5R<R!F
M<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO9VEZ
M92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(*;7-G:60@(E!L96%S92!P<F]V:61E
M('EO=7(@<&%S<W=O<F0N(@IM<V=S='(@(E-LX?!U(&EN;B!L>6MI;&]R\"#^
M:71T+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C@*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(E-LX?!U
M(&EN;B!N;W1A;F1A;F%F;B#^:71T+B(*"B,Z(&-O;7!O<V4N<&AP.C<Y(&QI
M8B])35`N<&AP.C4P.0IM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S
M(&]R(&EN=F%L:60@861D<F5S<V5S+B(*;7-G<W1R("),96GP<NET='4@:'5G
M<V%N;&5G87(@=FET;&5Y<W5R(.T@;F5T9F%N9VD@9?!A(&YE=&;V;F=U;2XB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C0R"FUS9VED("(B"B)0
M;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T
M:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:F%V87-C<FEP="YI
M;F,Z-3,*;7-G:60@(E!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO
M=2!P97)F;W)M(&%N>2!A8W1I;VYS+B(*;7-G<W1R("+>^B#^87)F="!A\"!V
M96QJ82!M]G!P=2#A\'5R(&5N(/[Z(&=E='5R(&AA9FGP(&'P<F%R(&'P9V5R
M\&ER+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#(*;7-G:60@
M(E!L96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N
M(@IM<V=S='(@(E9E;&1U(&'P9V5R\"!A9B!V86QM>6YD:6YN:2!HZ7(@8?`@
M;F7P86XN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]J879A<V-R:7!T+FEN8SHT
M,0IM<V=I9"`B4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O
M('-E87)C:"XB"FUS9W-T<B`B5F5L9'4@82YM+FL@96EN82!M]G!P=2!T:6P@
M8?`@;&5I=&$@[2XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R:7!T
M+FEN8SHT"FUS9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F
M;W(@=&AI<R!O<&5R871I;VXN(@IM<V=S='(@(MYA\"!E<B!E:6YU;F=I<R!H
MYF=T(&'P('9E:F$@96EN82!M]G!P=2!F>7)I<B#^97-S82!A\&=E<O`N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<V"FUS9VED(")0
M;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z
M(@IM<V=S='(@(E9E;&1U(&7P82!B<F5Y='1U('1I;"!HYF=R:3HB"@HC.B!C
M;VYF:6<O;6]T9"YP:'`N9&ES=#HT,0IM<V=I9"`B4&]W97)E9"!B>2!(;W)D
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`V"FUS
M9VED(")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@
M)RD_(@IM<V=S='(@(E-E=&IA('-K:6QM97)K:2`H)RTM("<I(&]F86X@=FGP
M('5N9&ER<VMR:69T(@H*(SH@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP
M.C0P('-M:6UE+G!H<#HR-#$*;7-G:60@(E!R969E<F5N8V5S('-U8V-E<W-F
M=6QL>2!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")&
M;W)S:V_P82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,C@*;7-G:60@(E!R979I;W5S($UE<W-A9V4B"FUS9W-T<B`B1GER
M<F$@<VME>71I(@H*(SH@;6%I;&)O>"YP:'`Z,S0S"FUS9VED(")0<F5V:6]U
M<R!086=E(@IM<V=S='(@(D9Y<G)I(&)L8?!S[?!A(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,Q"FUS9VED(")0<FEN="(*
M;7-G<W1R(")0<F5N=&$B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S
M+FEN8SHS.`IM<V=I9"`B4')I;W)I='DB"FUS9W-T<B`B1F]R9V%N9W5R(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<T"FUS9VED(")0
M<FEV871E($ME>2!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-34R"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U,0IM<V=I9"`B4')O;7!T(&5V
M97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%
M4R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z,3`*;7-G:60@(E!R;W1O8V]L.B(*;7-G<W1R("(B"@HC.B!L:6(O0W)Y
M<'0O4$=0+G!H<#HT,CD*;7-G:60@(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U
M<'!O<G0@:&%S(&)E96X@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z."!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS-@IM<V=I9"`B4'5R7V=E($1E;&5T960B
M"FUS9W-T<B`B1FIA<FSF9VIA(&5Y9&0B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS7V1E;&5T960N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,S8*;7-G:60@(E!U<F=E($1E;&5T960B"FUS9W-T<B`B1FIA
M<FSF9VIA(&5Y9&0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHR,@IM<V=I9"`B4'5R9V4@1F]L9&5R*',I(@IM<V=S='(@(D5Y\&$@;?9P
M<'4H;2DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")0
M=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(DAV97)S=2!O9G0@X2!A
M\"!TYFUA(')U<VQA9O9T=6YA.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.3D*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O
M;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@(D5Y\&$@
M<VME>71U;2#M(')U<VQA:_9R9G4@<V5M(&5R=2!E;&1R:2#M(&3V9W5M(&5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B4'5R9V4@
M;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_(@IM<V=S='(@(D9J
M87)LYF=J82!G]FUU;"!S:V5Y=&D@[2!R=7-L86OV<F9U/R(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L
M9&5R+B(*;7-G<W1R(")&:F%R;.9G:2`E9"!S:V5Y=&D@^G(@<G5S;&%K]G)F
M=6YN:2XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z-C0*;7-G:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L
M9&5R+B(*;7-G<W1R(")&:F%R;.9G:2!E:71T('-K97ET:2#Z<B!R=7-L86OV
M<F9U;FYI+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F
M34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q
M=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S
M.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A
M('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B2W;S=&DZ(--T86MM87)K8?!U
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T<B`B5NUS82!T:6P@)68Z(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S<W"FUS9VED(")2
M95]Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VXB"FUS9W-T<B`BTW-K82!E
M9G1I<B!S=&'P9F5S=&EN9W4@X2!A9FAE;F1I;F=U(@H*(SH@<V5A<F-H+G!H
M<#HQ-C,*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@(DWS='1E:VGP(/YA
M;FXZ(@H*(SH@<V5A<F-H+G!H<#HQ-S$*;7-G:60@(E)E8V5I=F5D(%-I;F-E
M(@IM<V=S='(@(DWS='1E:VGP('/M\&%N.B(*"B,Z('-E87)C:"YP:'`Z,38W
M"FUS9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R(")-\W1T96MI\"#^86YG
M8?`@=&EL.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(D5N9'5R=NUS82(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM
M<V=I9"`B4F5D:7)E8W0B"FUS9W-T<B`B16YD=7)V[7-A(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q-0IM<V=I9"`B4F5D:7)E8W0@
M365S<V%G92(*;7-G<W1R(")%;F1U<G;M<V$@<VME>71I(@H*(SH@8V]M<&]S
M92YP:'`Z-S,T"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T
M<B`B16YD=7)V[7-A(/YE<W-U('-K97ET:2(*"B,Z(&-O;7!O<V4N<&AP.C<Y
M-`IM<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*;7-G<W1R(")%;F1U<G;M
M<W5N(&UI<VAE<'!A\&ES="XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHU-S,*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B16YD=7)H;&'P
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-C`*;7-G:60@(E)E9G)E
M<V@@1F]L9&5R(%9I97=S.B(*;7-G<W1R(")%;F1U<FAL8?!A(&WV<'!U:&%M
M.B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-"!T96UP;&%T
M97,O9F]L9&5R<R]H96%D+FEN8SHY"FUS9VED(")296QO860B"FUS9W-T<B`B
M16YD=7)H;&'P82(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C,*
M;7-G:60@(E)E;&]A9"!6:65W(@IM<V=S='(@(D5N9'5R:&QA\&$@:&%M(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R-B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-30U"FUS9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.34P"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S
M='(@(DUU;F$@<^WP87-T82!H86TB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*;7-G<W1R
M(")0\W-T:/-L9B#A(&9J87)E;F1A.B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I96QD($9R;VT@4V5A<F-H
M(@IM<V=S='(@(D5K:VD@;F]T82!S=N;P:2#M(&QE:70B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*;7-G:60@(E)E;6]V92!S
M;W5R8V4B"FUS9W-T<B`B9FIA<FSF9VIA(&AA;F1R:70B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHV"FUS9VED(")296YA;64@1F]L9&5R
M*',I(@IM<V=S='(@(D5N9'5R;F5F;F$@;?9P<'4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,U"FUS9VED(")296YA;64@<V5N="UM86EL(&9O;&1E
M<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(D5N9'5R;F5F;F$@
M;?9P<'4@;67P('-E;F1U;2!S:V5Y='5M(.T@8GER:G5N(&AV97)S(&WA;F'P
M87(B"@HC.B!L:6(O1F]L9&5R+G!H<#HT-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB16YD=7)N969N:6YG
M(/IR(&YA9FYI;G4@7"(E<UPB(.T@7"(E<UPB(&UI<VAE<'!N8?!I<W0N($YE
M=/YJ\VYN:6YN(&MO;2!M9?`@(@HB969T:7)F87)A;F1I('9I;&QU(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$P"FUS9VED
M(")297!L7WD@=&\@3&ES="(*;7-G<W1R(")3=F%R82#V;&QU;2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,3$*;7-G:60@(E)E<&QA
M8V4@=VET:#HB"FUS9W-T<B`B4VMI<'1A(/IT(&9Y<FER.B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L
M>2(*;7-G<W1R(")3=F%R82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HS,3$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P.0IM<V=I9"`B4F5P
M;'D@4V5N="XB"FUS9W-T<B`B4W9A<B!S96YT+B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@
M06QL(@IM<V=S='(@(E-V87)A(/9L;'5M(@H*(SH@8V]M<&]S92YP:'`Z-C@P
M"FUS9VED(")297!L>2!T;R!!;&PZ(@IM<V=S='(@(E-V87)A(/9L;'5M.B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM
M<V=I9"`B4F5P;'D@=&\@3&ES="(*;7-G<W1R(")3=F%R82#A(&QI<W1A(@H*
M(SH@8V]M<&]S92YP:'`Z-C@R"FUS9VED(")297!L>2!T;R!,:7-T.B(*;7-G
M<W1R(")3=F%R82#A(&QI<W1A.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@7T%L;"(*;7-G
M<W1R(")3=F%R82#V;&QU;2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU,C@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-PHC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED(")297!L>2!W:71H($YO="!3
M=7!P;W)T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3,U"FUS9VED(")297!L>2!W:71H(&9R964O8G5S>2!F
M;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4S-`IM<V=I9"`B4F5P;'D@=VET:"!R97%U97-T960@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!M97-S86=E
M+G!H<#HR-3$*;7-G:60@(E)E<&QY+51O(@IM<V=S='(@(E-V87)A+51I;"(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HR-3D@;&EB+T-O;7!O<V4N<&AP.C,Q,0IM
M<V=I9"`B4F5P;'DM5&\Z("(*;7-G<W1R(")3=F%R82U4:6PZ("(*"B,Z(&-O
M;7!O<V4N<&AP.C8W.`IM<V=I9"`B4F5P;'DZ(@IM<V=S='(@(E-V87(Z(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C8@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,V"FUS9VED(")297!O<G0@
M87,@26YN;V-E;G0B"FUS9W-T<B`B5&EL:WEN;F$@<V5M(&5K:VD@<G5S;'#S
M<W0B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR-"!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E)E
M<&]R="!A<R!3<&%M(@IM<V=S='(@(E1I;&MY;FYA('-E;2!R=7-L</-S="`H
M4U!!32DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-S0*
M;7-G:60@(E)E<75E<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(M-S:V$@
M969T:7(@:W9I='1U;B!F>7)I<B!M\W1T]FMU(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4W.`IM<V=I9"`B4F5Q=65S="!D96QI=F5R>2!C;VYF:7)M
M871I;VX_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-C8*;7-G:60@(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T<B`BTW-K
M82!E9G1I<B!K=FET='5N(&9Y<FER(&WS='3V:W4B"@HC.B!M86EL8F]X+G!H
M<#HR,#0*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-PIM<V=I
M9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$U."!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI
M;F,Z,C8*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-#,*;7-G:60@
M(E)E<V5T(@IM<V=S='(@(D5N9'5R<V5T:F$B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,3$U"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A
M=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,C@*;7-G:60@(E)E<W5M92(*;7-G<W1R(")(86QD82#A
M9G)A;2(*"B,Z(')E8V]M<&]S92YP:'`Z.3@*;7-G:60@(E)E<W5M92!Y;W5R
M('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D
M<FEV97)?<V5L96-T+FEN8SHS,0HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C
M8V]U;G1?<V5L96-T+FEN8SHS,B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-CD*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-3D@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$V.0HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C8X('1E
M;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHS,PHC.B!T96UP;&%T97,O9FEL
M=&5R<R]N;W1A8W1I=F4N:6YC.C$S('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHW,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHS,R!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$U.`IM<V=I9"`B4F5T=7)N('1O
M($]P=&EO;G,B"FUS9W-T<B`B5F%L:V]S=&ER(&YO=&%N9&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S$T"FUS9VED("(B"B)2971U<FX@=&\@=&AE
M(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C
M;W!Y:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B(@HBP2!A\"!F87)A('1I;"!B
M86MA(.T@</-S=&CS;&9A;&ES=&$@969T:7(@8?`@<VME>71U;2!E<B!E>71T
M+"#^874@9FQU='0@9?!A("(*(F%F<FET=?`_(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4F]L92(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$S,2!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C(R-@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0P
M.`IM<V=I9"`B4R]-24U%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T
M($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%(&1U;&OS\&$@<VME>71I(@H*(SH@
M8V]M<&]S92YP:'`Z,S8W"FUS9VED(")3+TU)344@17)R;W(Z("(*;7-G<W1R
M(")3+TU)344@=FEL;&$Z("(*"B,Z(&-O;7!O<V4N<&AP.C,T-@IM<V=I9"`B
M4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R
M:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O;F]T
M86-T:79E+FEN8SHV"FUS9VED(")3+TU)344@3D]4($%C=&EV92(*;7-G<W1R
M(")3+TU)344@97(@96MK:2!V:7)K="(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")3
M+TU)344@3W!T:6]N<R(*;7-G<W1R(")3+TU)344@=F%L<W1I;&QI;F=A<B(*
M"B,Z('-M:6UE+G!H<#HT.0IM<V=I9"`B4R]-24U%(%!A<W-P:')A<V4@26YP
M=70B"FUS9W-T<B`B4R]-24U%(&QY:VEL:_/P:2(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,3`P"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y
M<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,30P"B,L('!H<"UF;W)M870*
M;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E
M<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,38R
M"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#4*
M;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!S
M;6EM92YP:'`Z,C$Q"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y
M<&%I<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*;7-G:60@(E,O34E-
M12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%('5N9&ER<FET82!S:V5Y
M=&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$T
M"FUS9VED(")3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B
M4R]-24U%(&1U;')I=&$@<VME>71I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO
M=&%C=&EV92YI;F,Z,3$*;7-G:60@(E,O34E-12!S=7!P;W)T(&ES(&1I<V%B
M;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")3+TU)344@<W1U\&UI;F=U
M<B!E<B#S=FER:W5R(.$@_F5S<W4@:V5R9FDN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HR,S`*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES
M(&YO="!C=7)R96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B
M;&4@=&\@8F4@(@HB9&5C<GEP=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$V,@IM<V=I9"`B(@HB4R]-24U%('-U<'!O
M<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG
M;F5D(&UE<W-A9V4@8V%N(&YO="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3,U"FUS9VED("(B
M"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A
M;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(T"FUS9VED
M("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O
M(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY('-E
M="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T
M:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S('=I
M;&P@;F]T('=O<FL@8V]R<F5C=&QY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(V-@IM<V=I9"`B4U]U8FIE8W0B"FUS
M9W-T<B`B169N:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C,U-`IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R(")6:7-T82!A
M9G)I="#M("(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHS,`IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B5FES=&$@<V5M(@H*
M(SH@<V5A<F-H+G!H<#HS-C,@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C8W"FUS9VED(")3879E(@IM<V=S='(@(E9I<W1A(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3(X"FUS9VED(")3879E($%T=&%C
M:&UE;G1S('=I=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV."!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C0*;7-G:60@(E-A=F4@
M1')A9G0B"FUS9W-T<B`B5FES=&$@=7!P:V%S="(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHV-"!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,C,*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C8Y('1E;7!L871E<R]S
M;6EM92]N;W1A8W1I=F4N:6YC.C(S"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,S<*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")686QK;W-T
M:7(@=FGP('9I<W1U;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C8X('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R-`IM<V=I
M9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B5FES=&$@=7!P:V%S="(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,`IM<V=I9"`B
M4V%V92!A<R(*;7-G<W1R(")6:7-T82!S96TB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$S"FUS9VED(")3879E(&1R869T<R!A<R!U;G-E96X_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#,P"FUS9VED
M(")3879E(')E8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L
M="!A9&1R97-S(&)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z,3(W"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U
M86P@9F]L9&5R/R(*;7-G<W1R(")'97EM82!L96ET('-E;2!S_6YD87)M]G!P
M=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(S"FUS9VED(")3879E
M('-E;G0@;6%I;#\B"FUS9W-T<B`B5FES=&$@<V5N9"!S:V5Y=&D_(@H*(SH@
M8V]M<&]S92YP:'`Z,3$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879I;F<@
M=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@)7,B"FUS9W-T<B`B(@HB5FES='5N('5P<&MA<W1S:6YS(&UI<W3S:W-T
M+B!.973^:O-N;FEN;B!K;VT@;67P(&5F=&ER9F%R86YD:2!V:6QL=3H@)7,B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY"B,Z(&QI8B]";&]C:R]T<F5E
M7V9O;&1E<G,N<&AP.C4P"FUS9VED(")396%R8V@B"FUS9W-T<B`B3&5I=&$B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S
M+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0IM<V=I9"`B4V5A<F-H("5S(@IM<V=S
M='(@(DQE:71A(.T@)7,B"@HC.B!S96%R8V@N<&AP.C,Q-@IM<V=I9"`B4V5A
M<F-H(%)E<W5L=',B"FUS9W-T<B`B3FGP=7)S=&'P82!L96ET87(B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$T('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E96XB"FUS9W-T<B`B3&5S:?`B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*;7-G:60@(E-E
M;&5C="(*;7-G<W1R(")696QJ82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*
M;7-G<W1R(")696QD=2!A;FYA;B!A\&=A;F<B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T
M<B`B5F5L9'4@9&5G<V5T;FEN9W4B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z,3`*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(E9E
M;&1U(')E:70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED
M(")396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@
M<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S='(@(E9E;&1U(&YE=&9A
M;F=A8O-K*&+F:W5R*2!F>7)I<B!V:?!BYG1U<B!O9R!L96ET87)M]F=U;&5I
M:V$N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I9"`B
M4V5L96-T(&%L;"(*;7-G<W1R(")696QJ82!A;&QT(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(S"FUS9VED(")396QE8W0@86QL
M(&9I96QD<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*
M;7-G<W1R("(B"B)696QD=2!R96ET:2#M(&YE=&9A;F=A8O-K('-E;2#A(&'P
M(&QE:71A(.TL(/YE9V%R(&QE:71A\"!E<B!A\"!N971F]FYG=6TN(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C$*;7-G
M:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@(E9E;&1U(&'P9V%N9R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(E9E;&IA(&5K:V5R="(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T
M:&4@;6%I;"!S97)V97(@='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*;7-G:60@(E-E;&5C=&5D($%D
M9')E<W,@8F]O:W,Z(@IM<V=S='(@(E9A;&1A<B!N971F86YG86+F:W5R.B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-#<*;7-G:60@(E-E;F0@2V5Y
M('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8P-`IM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-C8@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(R"FUS
M9VED(")396YD($UE<W-A9V4B"FUS9W-T<B`B4V5N9&$@<VME>71I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y.`IM<V=I9"`B4V5N9"!R96%D(')E
M8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B
M(@H*(SH@9F]L9&5R<RYP:'`Z,SDR"FUS9VED(")396YT(&UA:6P@9F]L9&5R
M(@IM<V=S='(@(DUA<'!A(&9Y<FER('-E;F0@<VME>71I.B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,SD*;7-G:60@(E-E;G0@
M;6%I;"!F;VQD97(Z(@IM<V=S='(@(DUA<'!A(&9Y<FER('-E;F0@<VME>71I
M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,30U"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,34R"FUS9VED(")397)V97(B"FUS9W-T<B`B3F5T_FKS;FXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*;7-G:60@(E-E<G9E<B!A;F0@
M1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHR,PIM<V=I9"`B4V5R=F5R.B(*;7-G<W1R
M(")0\W-T_FKS;FXZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS
M9VED(")3970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO
M=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N(@IM<V=S='(@(E-T:6QL82!F
M;W)S:W)I9G0@=6T@:'9A\"!G97)I<W0L(/YE9V%R('-K97ET:2!E<B!E>71T
M(&7P82#^8?`@9FQU='0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R
M,@IM<V=I9"`B4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O
M<VEN9R!M97-S86=E<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Q"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@IM<V=I9"`B4VAA<F4@;6%I;"!F
M;VQD97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U
M<V5R<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V
M,PIM<V=I9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X
M="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E("(*
M(G1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3(*;7-G:60@(E-H;W5L
M9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@
M9F]R(%!'4"!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3`U"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E
M(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`B(@HBP2!A
M\"!L;VMA(&=L=6=G86YU;2!S96T@;OT@<VME>71I(&5R=2!S86UI;B#M(&5F
M=&ER(&'P('5P<&MA<W0@97(@=FES=&'P/R(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHT,`IM<V=I9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@
M=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"FUS
M9VED(")3:&]W($%L;"!&;VQD97)S(@IM<V=S='(@(E/];F$@86QL87(@;?9P
M<'5R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C<*;7-G
M:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B4_UN82!A;&QA(&AA=7-A
M(@H*(SH@;6%I;&)O>"YP:'`Z,S8Q"FUS9VED(")3:&]W($1E;&5T960B"FUS
M9W-T<B`B4_UN82!E>61D('-K97ET:2(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VAE861E<G,N:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET960@2&5A9&5R<R(*
M;7-G<W1R(")3_6YA(&5I;G5N9VES(&AE;'-T=2!H875S82(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P"FUS9VED(")3:&]W($UA:6QI
M;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R(")3_6YA('5P<&PN('5M('#S
M<W1L:7-T82(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G
M:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B(@H*
M(SH@9F]L9&5R<RYP:'`Z,C@W"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*
M;7-G<W1R(")3_6YA(/-V:7)K82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,#,*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@
M;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW-`IM<V=I9"`B4VAO=R!L96=E;F0@
M:6X@=&AE(&UA:6QB;W@@=FEE=S\B"FUS9W-T<B`B4_UN82!TX6MN(.T@</-S
M=&WV<'!U:&%M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#D*;7-G
M:60@(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$W"FUS9VED
M(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('1H92!&971C
M:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#@*;7-G:60@(E-H;W<@=&AE($EM
M86=E<R(*;7-G<W1R(")3_6YA(&UY;F1I<FYA<B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHV,0IM<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC
M;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HS,`IM<V=I9"`B4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I
M;',@:6X@9F]L9&5R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C8P"FUS9VED(")3:&]W;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0R"FUS9VED(")3:5]Z
M92(*;7-G<W1R(")3=.9R\"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C$S"FUS9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*;7-G
M:60@(E-I9VYE9"(*;7-G<W1R(")5;F1I<G)I=&'P(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS9W-T
M<B`B4W3F<O`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C@Q"FUS9VED(")3;W)T($1I<F5C=&EO;B(*;7-G<W1R(")2]O!U
M;F%RX71T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHQ,0IM<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@(D9L;VMK
M82!E9G1I<B!K;VUU=.UM82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,38*;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R
M(")&;&]K:V$@969T:7(@9&%G<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C(V"FUS9VED(")3;W)T(&)Y($9R;VT@061D
M<F5S<R(*;7-G<W1R(")&;&]K:V$@969T:7(@<V5N9&%N9&%N971F86YG:2(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*
M;7-G:60@(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(D9L;VMK82!E
M9G1I<B!S=.9R\"!S:V5Y=&ES(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHS-@IM<V=I9"`B4V]R="!B>2!3=6)J96-T(@IM
M<V=S='(@(D9L;VMK82!E9G1I<B!E9FYI<VSM;G4B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"FUS9VED(")3;W)T(&)Y
M(%1H<F5A9"(*;7-G<W1R(")&;&]K:V$@969T:7(@969N:7/^<N;P:2(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C$*;7-G
M:60@(E-O<G0@8GD@5&\@061D<F5S<R(*;7-G<W1R(")&;&]K:V$@969T:7(@
M=FGP=&%K86YD86YE=&9A;F=I(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.C(S"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`B4G5S
M;'#S<W1M87!P83HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS,S<*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G<W1R(")3Z7)T
MX6MN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,T"FUS
M9VED(")3<&5L;"!#:&5C:R(*;7-G<W1R(")0<O-F87)K87)L97-T=7(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G:60@(E-P
M96QL($-H96-K97(B"FUS9W-T<B`B4'+S9F%R:V%L97-A<FDB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-3`@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C4X"FUS9VED(")3<&5L;"!C:&5C:R!C;VUP;&5T
M92(*;7-G<W1R(")0<O-F87)K87)L97-T<FD@;&]K:?`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#8R"FUS9VED(")3<&5L;&EN9R!E<G)O<G,@<&5R
M('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R(")&:O9L9&D@
M=FEL;&YA('!R+B!G;'5G9V$@_F5G87(@<'+S9F%R:V%L97-T=7(@97(@:V5Y
M<O!U<BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$R(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV-3(*;7-G:60@(E-T87)T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(E-T
M871U<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C`R
M"FUS9VED(")3=')I<"!!='1A8VAM96YT(@IM<V=S='(@(D5Y\&$@=FGP:&5N
M9VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`Q"FUS9VED(")3=')I
M<"!L:6YE8G)E86MS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C,W"FUS9VED(")3=6)?:F5C="(*;7-G
M<W1R(")%9FYI(@H*(SH@<V5A<F-H+G!H<#HQ-3$@;65S<V%G92YP:'`Z,C4R
M('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C4*;7-G:60@(E-U
M8FIE8W0B"FUS9W-T<B`B169N:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.3$*;7-G:60@(E-U8FIE8W0@1FEE;&0B"FUS9W-T<B`B169N:7-L[6YA
M(@H*(SH@<V5A<F-H+G!H<#HS-C4@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E
M+FEN8SHS,0HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C$*
M;7-G:60@(E-U8FUI="(*;7-G<W1R("+!9G)A;2(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G:60@(E-U8G-C<FEB92!T;R!&;VQD
M97(H<RDB"FUS9W-T<B`B5FER:VIA(&WV<'!U*'(I(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,S@Y(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C@W"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S8Y"FUS9VED(")3
M=6-C97-S(@IM<V=S='(@(D9R86UK=N9M="(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHY,@IM<V=I9"`B4W5G9V5S=&EO;G,B"FUS9W-T
M<B`B5&EL;/9G=7(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8R
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`B4V%M86YT96MT(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,SDQ('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Y
M-`IM<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.34*;7-G:60@
M(E-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(E-K:7!T82#M
M($A434P@<FET:6PB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS.34*;7-G:60@(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N
M(@IM<V=S='(@(E-K:7!T82#M('1E>'1A<FET:6PB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,3`*;7-G:60@(E1E7WAT(@IM<V=S='(@
M(E1E>'1I(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.0IM<V=I
M9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Y,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T(')E<75E
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V
M,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B(@H*(SH@
M;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&5R;7,@;V8@4V5R=FEC92!F:6QE(&YO="!S
M<&5C:69I960@:6X@8V]N9BYP:'`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR-0IM<V=I9"`B5&AE($9R;VTZ(&-O;'5M;B!O9B!T
M:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"FUS9VED(")4:&4@
M36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL
M;V%D960@)7,N(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX
M,0IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(D'P9V%N9VEN=6T@7"(E<UPB(&AE9G5R('9E<FGP(&5Y='0N
M(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`B0?!G86YG=7)I;FX@(%PB)7-<(B!H969U<B!V97)I\"!V:7-T8?!U<BXB
M"@HC.B!L:6(O1FEL=&5R+G!H<#HY-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@861D<F5S<R!<(B5S7"(@:&%S(&)E96X@861D960@=&\@)7,N(@IM<V=S
M='(@(DYE=&9A;F=I;G4@(%PB)7-<(B!H969U<B!V97)I\"!BYG1T(.T@)7,N
M(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT
M('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(E9I\&AE;F=I\"!F86YN<W0@96MK
M:2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CD*;7-G:60@(E1H
M92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I
M9"`B(@HB5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R
M:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O
M<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A
M<'!L961O=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@
M36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I
M(%PB)7-<(B!W:6QL(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")4
M:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T
M;R!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$Q,@IM<V=I
M9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T
M;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM<V=S='(@
M(B(*"B,Z(&-O;7!O<V4N<&AP.C$Q-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92!<(B5S7"(@9F]L9&5R
M+B(*;7-G<W1R(")5<'!K87-T:?`@:&5F=7(@=F5R:?`@=FES=&'P(.T@7"(E
M<UPB(&WV<'!U;FYI+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M,SD*;7-G:60@(E1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN
M8SHY"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L9"!<(B5S7"(@8V%N
M)W0@8F4@97AP86YD960N(@IM<V=S='(@(D5K:VD@=/-K<W0@8?`@9GEL;&$@
M<VKA;&9V:7)K="#M('-VYO!I\"!<(B5S7"(N(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z,S(X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DUA<'!A;B!<(B5S7"(@97(@;OH@
M_F5G87(@=&EL(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,3<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS(&EL;&5G
M86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E("(*(G!R
M;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(DUA<'!A;B!<(B5S7"(@97(@;67P('/I<G3A:VX@9?!A
M(.US;&5N<VMA('-T869I(.T@;F%F;FEN=2X@WF5T=&$@9V5T=7(@;&5I='0@
M(@HB=&EL('9A;F1A;>%L82!S96T@_F%R9B!A\"!L97ES82!M9?`@8?!S=&_P
M(/YJ\VYU<W1U8?!I;&$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S0W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D
M(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B
M36%P<&%N(%PB)7-<(B!V87(@8OII;B!T:6P@96X@97(@96MK:2!V:7)K+B(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9F]L9&5R(%PB)7-<(B!W87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T
M('5N<W5B<V-R:6)E9"!F<F]M(&ET+B(*;7-G<W1R(")-]G!P=6YN:2!<(B5S
M7"(@=F%R(&5Y='0L(&5N(&CZ;B!V87(@=FER:RXB"@HC.B!L:6(O1F]L9&5R
M+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(B(*(DUA<'!A;B!<(B5S7"(@=F%R(&5K:VD@8OII;B!T
M:6PN(%9I;&QU=&EL:WEN;FEN9R!N973^:O-N<VEN<R!F>6QG:7(@:.ER(.$@
M(@HB969T:7(B"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(B(*(DWV<'!U
M;FYI(%PB)7-<(B!V87(@96MK:2!E>71T+B!6:6QL=71I;&MY;FYI;F<@;F5T
M_FKS;G-I;G,@9GEL9VER(&CI<B#A(&5F=&ER(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B36%P<&%N(%PB
M)7-<(B!V87(@8OII;B!T:6PN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C@X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C
M97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B3?9P<'5N;FD@7"(E<UPB('9A
M<B!E>71T+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0S.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E
M;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R(")-87!P86X@7"(E<UPB('9A<B!E
M;F1U<FYE9FYD(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE
M9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HY-@IM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I
M<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R
M("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R
M871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"FUS9VED
M(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF
M;W)M871I;VYA;"!M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E
M;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HV,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B36%P<&%N
M(%PB)7-<(B!E<B!N^B#^96=A<B!T\VTB"@HC.B!L:6(O1F5T8VAM86EL+G!H
M<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A9V4@7"(E<UPB
M(&9R;VT@7"(E<UPB("@E9"!B>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI
M;6ET+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C$P,PIM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@
M:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")3:V5Y=&EN=2!S
M96T@=F5R:?`@=F%R(&'P('-E;6IA(&AE9G5R('9E<FGP(&QO:V'P+B(*"B,Z
M(&UE<W-A9V4N<&AP.C$T,@IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B4VME>71I;G4@:&5F=7(@=F5R:?`@97ET="XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3,*;7-G:60@(E1H92!M
M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G<W1R(")3:V5Y=&GP(&AE
M9G5R('9E<FGP('-A;FYP<O-F8?`N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HS-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A9V4@
M:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@)7,N(@IM<V=S='(@(E-K97ET
M:?`@:&5F=7(@=F5R:?`@<V%N;G!R\V9A\"X@4V5N9&%N9&DZ("5S+B(*"B,Z
M('1E;7!L871E<R]P9W`O;W!E;E]P9W!?=VEN+FIS.C$P('1E;7!L871E<R]S
M;6EM92]O<&5N7W-M:6UE7W=I;BYJ<SHQ,`IM<V=I9"`B(@HB5&AE('!A<W-P
M:')A<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V
M92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0
M=6)L:6,@2V5Y(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E
M9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE
M;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T
M"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@
M=&AE(%II<"!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H
M<#HU,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('-E;F1E<B!O9B!T
M:&ES(&UE<W-A9V4@:7,@<F5Q=65S=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N("(*(F9R;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A
M9"!T:&ES(&UE<W-A9V4N(%!L96%S92!C;&EC:R`E<R!T;R!S96YD('1H92`B
M"B)N;W1I9FEC871I;VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z-CD*;7-G:60@(E1H92!S97)V97(@=V%S
M(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS
M.C$P-`IM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C
M960N(@IM<V=S='(@(D5K:VD@=F%R(&CF9W0@8?`@<VMI<'1A('5M('5N9&ER
M<VMR:69T+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`R
M"FUS9VED(")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C
M960N(@IM<V=S='(@(E5N9&ER<VMR:69T(&AE9G5R('9E<FGP(&)R97ET="XB
M"@HC.B!A='1A8VAM96YT+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F
M:6QE(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,38Y"FUS9VED(")4:&4@=&%S:R!H87,@8F5E;B!A
M9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R(")697)K969N:6YU(%PB
M)7-<(B!H969U<B!V97)I\"!BYG1T('9I\"!V97)K969N86QI<W1A;FXN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G:60@(E1H92!T
M97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(E1E>'1I('-K97ET:7-I;G,B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HX,`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A
M9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R
M;F5D(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*;7-G:60@(E1H
M92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92!C86X@8F4@
M=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,34T"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA
M=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R
M92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M96UP='E?;6%I;&)O>"YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A
M9V5S(&EN('1H:7,@;6%I;&)O>"XB"FUS9W-T<B`BWF'P(&5R=2!E;F=I;B!S
M:V5Y=&D@[2#^97-S=2!P\W-T:/-L9FDN(@H*(SH@=&AR96%D+G!H<#HV.0IM
M<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-3<U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG
M:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(B(*(E9A;F1A;>%L(&MO;2!U<'`@=FGP('3F;6EN9W4@X2`E<RX@5FEL;'5T
M:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@X2`B"B)E9G1I<B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P
M<"!V:?`@=.9M:6YG=2!P\W-T:/-L9G,N(%9I;&QU=&EL:WEN;FEN9R!N973^
M:O-N<VEN<R!F>6QG:7(@(@HB:.ER(.$@969T:7(Z("5S(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C4X-`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U
M;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60B"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P<"!V:?`@=.9M:6YG=2!P
M\W-T:/-L9G,N(%9I;&QU=&EL:WEN;FEN9R!N973^:O-N<VEN<R!F>6QG:7(@
M(@HB:.ER(.$@969T:7(B"@HC.B!L:6(O365S<V%G92YP:'`Z.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@
M;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@
M=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E9A;F1A;>%L(&MO;2!U
M<'`@=FGP(&%F<FET=6X@9G+A(%PB)7-<(B!T:6P@(%PB)7-<(BX@5FEL;'5T
M:6QK>6YN:6YG("(*(FYE=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@X2!E9G1I<B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HR,#`@;&EB+TUE<W-A9V4N<&AP.C(Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T("(*(G1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)6:6QL82!K
M;VT@=7!P(/YE9V%R(.%T=&D@8?`@97GP82!S:V5Y='5M(/IR(&WV<'!U;FYI
M(%PB)7-<(BX@5FEL;'5T:6QK>6YN:6YG("(*(FYE=/YJ\VYS:6YS(&9Y;&=I
M<B!HZ7(@X2!E9G1I<B(*"B,Z(&QI8B]-97-S86=E+G!H<#HR-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG
M(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@
M=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E9I;&QA(&MO;2!U<'`@
M_F5G87(@X71T:2!A\"!E>?!A('-K97ET=6T@[2!M]G!P=6YN:2!<(B5S7"(N
M(%9I;&QU=&EL:WEN;FEN9R`B"B)N973^:O-N<VEN<R!F>6QG:7(@:.ER(.$@
M969T:7(B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@HB
M5FEL;&$@:V]M('5P<"#^96=A<B#A='1I(&'P(&5Y\&$@<VME>71U;2X@5FEL
M;'5T:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B`B"B)HZ7(@X2!E9G1I
M<CH@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H
M92!E=F5N=#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M;&%I;BYP:'`Z-3(@;&EB+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS-PIM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B5FEL;&$@:V]M('5P<"!V:?`@8FER=&EN9W4@
M_F5S<V$@:&QU=&$@<VME>71I<VEN<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HU
M,#@@;&EB+TUE<W-A9V4N<&AP.C4T.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE
M(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A
M:60B"FUS9W-T<B`B(@HB5FEL;&$@:V]M('5P<"#^96=A<B#A='1I(&'P(&UE
M<FMJ82!S:V5Y=&D@[2!M]G!P=6YN:2!<(B5S7"(N(%9I;&QU=&EL:WEN;FEN
M9R`B"B)N973^:O-N<VEN<R!F>6QG:7(@:.ER(.$@969T:7(B"@HC.B!F;VQD
M97)S+G!H<#HQ-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R`E<RXB"FUS9W-T<B`B5FEL;&$@:V]M('5P<"!V
M:?`@8?`@9FQY=&IA(&EN;B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,3,V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F
M<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R
M=F5R('-A:60B"FUS9W-T<B`B(@HB5FEL;&$@:V]M('5P<"#^96=A<B#A='1I
M(&'P(&;F<F$@<VME>71I(&9RX2!<(B5S7"(@=&EL(%PB)7-<(BX@(@HB5FEL
M;'5T:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@X2!E9G1I<B(*
M"B,Z(&-O;7!O<V4N<&AP.C$Q-SD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N(@IM<V=S='(@(E9I
M;&QA(&MO;2!U<'`@=FGP('9I<W1U;B#^97-S82!S:V5Y=&ES('-E;2!U<'!K
M87-T<RXB"@HC.B!C;VUP;W-E+G!H<#HY-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E
M<R(*;7-G<W1R(")%:VMI('3S:W-T(&'P('-E;F1A('-K97ET:?`Z("5S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT
M.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H
M<#HU.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E
M('!A<G0B"FUS9W-T<B`BWF'P('9A<B!E;F=I;B!T97AT:2#M(/YE<W-U;2!H
M;'5T82!S:V5Y=&ES:6YS(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.CDT"FUS9VED(")4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D
M9&5D(&EN(&ET+B(*;7-G<W1R("+>971T82!(5$U,('-K97ET:2!E<B!I;FEH
M96QD=7(@;7EN9&ER+BXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M.3`*;7-G:60@(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB
M961D960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L:6ME("(*(G1H
M:7,Z("(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ
M-C8*;7-G:60@(E1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O
M('1H92!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3`T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3@*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,R!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,34W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S,@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q-`IM<V=I9"`B5&AI<R!A8W1I
M;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$W.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#$Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R:7!T
M+FEN8SHV"FUS9VED(")4:&ES(&UA>2!T86ME('-O;64@=&EM92X@07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(&-O;G1I;G5E/R(*;7-G<W1R("(B"B+>971T
M82!GYG1I('1E:VGP(&YO:VMU<FX@=.UM82X@17)T(/[Z('9I<W,@=6T@8?`@
M_OH@=FEL:FER(&AA;&1A(.%F<F%M/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A
M<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN
M<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C,Y.0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O
M;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L;'D@
M<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z-#`S"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N
M=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V
M:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!M
M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M
M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q-0IM<V=I9"`B(@HB5&AI
M<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E
M;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,S4P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T
M;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,34Y"FUS9VED(")4:&ES(&UE<W-A9V4@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F;W)M870N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-2!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HT,38*;7-G:60@(E1H:7,@;65S<V%G92!H
M87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N(@IM<V=S='(@(MYE
M='1A('-K97ET:2!E<B!M9?`@4$=0(')A9G+F;F$@=6YD:7)S:W)I9G0N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ,S(*;7-G:60@(E1H:7,@
M;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N
M(@IM<V=S='(@(MYE='1A('-K97ET:2!E<B!M9?`@4R]-24U%(')A9G+F;F$@
M=6YD:7)S:W)I9G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ
M,C@@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,C<*;7-G:60@(E1H:7,@
M;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T
M<B`BWF5T=&$@<VME>71I(&5R(&1U;')I=&'P(&UE\"!3+TU)344N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`Q(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C(Y,0IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y
M<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`BWF5T=&$@<VME>71I(&5R(&1U;')I
M=&'P(&UE\"!01U`N(@H*(SH@;65S<V%G92YP:'`Z,3DU"FUS9VED(")4:&ES
M(&UE<W-A9V4@=&\B"FUS9W-T<B`BWF5T=&$@<VME>71I('1I;"(*"B,Z(&%C
M;"YP:'`Z-#8*;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$P.0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R("(B
M"B+>97-S:2!G;'5G9VD@_F%R9B!A\"!V97)A(';M<W5N(&9RX2!G;'5G9V%N
M=6T@_F%R('-E;2!N_2!S:V5Y=&D@97)U('-A;6EN+B(*"B,Z('1H<F5A9"YP
M:'`Z-#0@=&5M<&QA=&5S+W1H<F5A9"]T;W`N:6YC.C,@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@Y,PIM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B169N
M:7/^<N'P<VAA;75R(@H*(SH@<V5A<F-H+G!H<#HQ,SD@;65S<V%G92YP:'`Z
M,C0X(&UA:6QB;W@N<&AP.C4X-0HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C(R"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C$Y('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z
M,3`*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C8T"FUS9VED
M(")4;R(*;7-G<W1R(")4:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#DP"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(DWS='3V:W5N971F86YG
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(V"FUS
M9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE("(*(F-L
M:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHU-C<*;7-G:60@(E1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z(@IM
M<V=S='(@(DAE:6QD87)S=.9R\"!V:?!H96YG:F$Z(@H*(SH@9F]L9&5R<RYP
M:'`Z,S@S"FUS9VED(")4<F%S:"!F;VQD97(B"FUS9W-T<B`B4G5S;&%K87)F
M82(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C,*;7-G
M:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`B4G5S;&%K87)F83HB"@HC.B!L
M:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV
M-2!L:6(O475O=&$O;&]G9FEL92YP:'`Z.#@*(SH@;&EB+U%U;W1A+V-O;6UA
M;F0N<&AP.C<R(&QI8B]1=6]T82]M9&%E;6]N+G!H<#HT.`HC.B!L:6(O475O
M=&$O;65R8W5R>3,R+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(')E=')I979E
M('%U;W1A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P"FUS9VED
M(")5;F%N<W=E<F5D(@IM<V=S='(@(M-S=F%R8?`B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S
M(@IM<V=S='(@(M-S=O9R=?`@<VME>71I(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,3,@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C0*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(D5N9'5R=F5K
M:F$B"@HC.B!M86EL8F]X+G!H<#HU-C@@;6%I;&)O>"YP:'`Z-3@Q(&QI8B]-
M24U%+TAE861E<G,N<&AP.C(Q,@IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I
M96YT<R(*;7-G<W1R(")-\W1T86ME;F1U<B!S96T@96MK:2!S:N%S="(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R
M("(B"@HC.B!M86EL8F]X+G!H<#HU-#0*;7-G:60@(E5N:VYO=VX@1&%T92(*
M;7-G<W1R("+3_F5K:W0@9&%G<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C,U"FUS9VED(")5;FMN;W=N($UE971I;F<B"FUS9W-T<B`B(@H*
M(SH@;6%I;&)O>"YP:'`Z-3DW"FUS9VED(")5;FMN;W=N(%)E8VEP:65N="(*
M;7-G<W1R("+3_F5K:W1U<B!M\W1T86MA;F1I(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$U,2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$Q-PIM
M<V=I9"`B56YL;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@9F5T8VAM
M86EL<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@(M-N969N
M="(*"B,Z(&UE<W-A9V4N<&AP.C0X,R!M86EL8F]X+G!H<#HV.#<@=&5M<&QA
M=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHU"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS
M,@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C8*
M;7-G:60@(E5N<V5E;B(*;7-G<W1R("+3;&5S:?`B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B56YS=6)S8W)I8F4@9G)O
M;2!&;VQD97(H<RDB"FUS9W-T<B`B069V:7)K:F$@;?9P<'4H<BDB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S0*;7-G:60@(E5P9&%T
M92!!='1A8VAM96YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E5P<&;F<F$@=7!P
M;"X@=6T@=FGP:&5N9VDB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C(P"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-38*;7-G:60@(E5P;&]A9"(*;7-G
M<W1R("));FYS96YD82(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E
M;&5C="YI;F,Z-#(*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@
M(DYO=&$@<VKA;&9G969I\"!G:6QD:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-3`*;7-G:60@(E5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS
M/R(*;7-G<W1R(").;W1A('9I<FMA<B!)34%0(&WV<'!U<B(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ-#`*;7-G:60@(E5S97(B"FUS9W-T<B`B3F]T
M86YD:2(*"B,Z(&%C;"YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M57-E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@
M<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.#$*;7-G:60@(E5S97)N86UE
M(@IM<V=S='(@(DYO=&%N9&%N869N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B3F]T
M86YD86YA9FXZ(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDS('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHQ-#<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$U,2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8U"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,3$S('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,3$W"FUS9VED(")6:65W(@IM<V=S='(@(E-K;_!A(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W1N968N<&AP.C$P."!L:6(O34E-12]6:65W97(O>FEP+G!H
M<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E/]
M;F$@)7,B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.3,@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHV-0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B:5-K;_!A(&]P:6YB97)A;B!L>6MI
M;"!F>7)I<B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C@*
M;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W
M(@IM<V=S='(@(E-K;_!A($A434PM969N:2#M('/I<B!G;'5G9V$N(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$U,2!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C$Q-PIM<V=I9"`B5FEE=R!097)S;VYA;"!0<FEV871E($ME>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30W('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,3$S"FUS9VED(")6:65W(%!E<G-O;F%L
M(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$W"FUS9VED(")6:65W(%1H<F5A9"(*;7-G
M<W1R(")3:V_P82!E9FYI<_YRX?`B"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38U"FUS
M9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R(")3:V_P82!S;>%M>6YD(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,#<*;7-G:60@(E9I97<@
M871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")K;_!A
M('9I\&AE;F=I(.T@<^ER(&=L=6=G82XB"@HC.B!L:6(O34E-12]6:65W97(O
M<F5L871E9"YP:'`Z-SD*;7-G:60@(E9I97<@8V]N=&5N="!I;B!A('-E<&%R
M871E('=I;F1O=R(*;7-G<W1R(")3:V_P82!I;FYI:&%L9"#M('/I<B!G;'5G
M9V$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B
M5FEE=R!E=F5N="(*;7-G<W1R(")3_6YA(&%T8G5R\"(*"B,Z(&UA:6QB;W@N
M<&AP.C4Q,R!F;VQD97)S+G!H<#HS-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G<W1R(")3_6YA('-K97ET:2#M("5S
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR
M-@IM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G
M:6XZ(@IM<V=S='(@(DUA<'!A(&7P82!H86UU<B!S96T@X2!A\"!S_6YA(.T@
M=7!P:&%F:3HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<P"FUS
M9VED(")6:65W('1A<VLB"FUS9W-T<B`B4_UN82!V97)K969N:2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,3,*;7-G:60@(E9I97<@=&AE($EM
M86=E<R(*;7-G<W1R(")3:V_P82!M>6YD:7)N87(B"@HC.B!S96%R8V@N<&AP
M.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S
M7"(@8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`B4_UN9&%R;6%P<&%N
M(%PB)7-<(B!V87(@<W1O9FYU\"XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$Q,2!L:6(O24U!4"]4<F5E+G!H<#HQ,CD@;&EB+TE-05`O5')E
M92YP:'`Z,30R"B,Z(&QI8B])34%0+U1R964N<&AP.C$T-"!L:6(O24U!4"]4
M<F5E+G!H<#HQ-#@@;&EB+TE-05`O5')E92YP:'`Z,30Y"B,Z(&QI8B])34%0
M+U1R964N<&AP.C,U-"!L:6(O24U!4"]4<F5E+G!H<#HS-S@@;&EB+TE-05`O
M5')E92YP:'`Z-#$X"FUS9VED(")6:7)T=6%L($9O;&1E<G,B"FUS9W-T<B`B
M4_UN9&%R;?9P<'5R(@H*(SH@<V5A<F-H+G!H<#HR.38*;7-G:60@(E9I<G1U
M86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN(@IM<V=S='(@(E/];F1A<FWV
M<'!U<B#^=7)F82!A=?!K96YN:2XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$S,PIM<V=I9"`B5FER='5A;"!F;VQD97(@;&%B96PB"FUS9W-T
M<B`B077P:V5N;FD@<_UN9&%R;?9P<'4B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C,V,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!\';V<G5N
M(@H*(SH@;&]G:6XN<&AP.C$S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(E9E;&MO;6EN*&XI(.T@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S(T"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG
M(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS
M=&5A9"!O9B!M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W.`IM<V=I9"`B5VAE;B!O
M<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A;G0@
M=&\@<W1A<G0@;VX_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-30*;7-G:60@(E=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD
M('=E('-A=F4@871T86-H;65N="!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(Q"FUS9VED("(B"B)7:&5N('-E;F1I;F<@
M;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U
M;&0@=V4@87!P96YD('1O("(*(G5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA
M:6P@861D<F5S<V5S('=I=&AO=70@7")`7"(I/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.2!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C(*;7-G:60@(E=H:71E;&ES="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"FUS9VED
M(")7<F%P('1E>'0@870@=&AI<R!M86YY(&-H87)A8W1E<G,N(@IM<V=S='(@
M(D;F<F$@8F5N9&EL('-JX69K<F%F82#M(&[F<W1U(&SM;G4@_F5G87(@_F5S
M<W5M('-T869A9FKV;&1A(&5R(&[A\"XB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT.0IM
M<V=I9"`B665S(@IM<V=S='(@(DKA(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HU.`IM<V=I9"`B66]U(&%R92!A8F]U
M="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N="AS
M*3HB"FUS9W-T<B`BWOH@97)T('5M(/YA\"!B:6P@8?`@<^9K:F$@</-S="!F
M>7)I<B!E9G1I<F9A<F%N9&D@8?!G86YG83HB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`IM<V=I9"`B(@HB66]U(&%R
M92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D
M(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R("+>^B!E
M<G0@=6T@_F'P(&)I;"!A\"!E>?!A(/9L;'5M('-K97ET=6T@[2!E9G1I<F9A
M<F%N9&D@;?9P<'4H;2DZ(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R
M<U]C;VYF:7)M+FAT;6PZ.0IM<V=I9"`B66]U(&%R92!A='1E;7!T:6YG('1O
M(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2XB"FUS9W-T<B`BWOH@
M97)T('5M(/YA\"!B:6P@8?`@97GP82!E9G1I<F9A<F%N9&D@;?9P<'!U*&TI
M.B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,B!T
M96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-0IM<V=I9"`B66]U
M(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S='(@
M(M[Z(&5R="!A\"!A9G)I=&$O9N9R82#M(&[]:F$@;?9P<'4N(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:F%V87-C<FEP="YI;F,Z.30*;7-G:60@(EEO=2!A
M<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O("(*;7-G<W1R("+>^B!E<G0@
M=6T@_F'P(&)I;"!A\"!B^F$@=&EL('5N9&ER;?9P<'4@[2`B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]J879A<V-R:7!T+FEN8SHY-@IM<V=I9"`B66]U(&%R
M92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N(@IM<V=S='(@(M[Z(&5R
M="!A\"!B^F$@=&EL(&[]:F$@8?!A;&WV<'!U+EQ<;E-LX?!U(&EN;B!N869N
M(&WV<'!U;FYA<CI<7&XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R
M:7!T+FEN8SHQ,C<*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E
M<CH@(@IM<V=S='(@(M[Z(&5R="!A\"!E;F1U<FYE9FYA(&WV<'!U;F$Z("(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C4S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B
MWOH@9V5T=7(@96MK:2!A9G1E;F=T(&9RX2!<(B5S7"(B"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB
M66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R
M965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V-0IM<V=I
M9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S
M<R!T;R!T:&ES(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP
M:'`Z,3(Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI
M<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z
M("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI
M;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@;65S
M<V%G97,N(@IM<V=S='(@(M[Z(.%T="`E<R!N_2!S:V5Y=&DN(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H879E(#$@
M;F5W(&UE<W-A9V4N(@IM<V=S='(@(M[Z(.%T="`Q(&[]='0@<VME>71I+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C$Q-@IM<V=I
M9"`B(@HB66]U(&AA=F4@870@;&5A<W0@;VYE(&%T=&%C:&UE;G0@<V5L96-T
M960@=&AA="!Y;W4@9&ED;B=T('5P;&]A9"!Y970N($%R92`B"B)Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!S96YD('1H:7,@;65S<V%G92!W:71H;W5T('1H97-E
M(&%T=&%C:&UE;G1S/R(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#,P
M"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<CHB"FUS9W-T<B`BWOH@X71T(&[]:F%N('#S<W0@[2!M]G!P=6YN:3I<
M7&XB"@HC.B!L:6(O24U0+G!H<#HQ,#,U"FUS9VED(")9;W4@:&%V92!N97<@
M;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(M[Z(.%T
M="!N_6IA;B!P\W-T(.T@_F5S<W5M(&WV<'!U;3I<7&XB"@HC.B!C;VUP;W-E
M+G!H<#HQ,C8*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R
M96-I<&EE;G0N(@IM<V=S='(@(MYA\"#^87)F(&'P('1I;&=R96EN82!A+FTN
M:RX@96EN;B!V:?!T86MA;F1A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C,P,@IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A
M<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S
M86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,C,X"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F
M;W(@>6]U<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE
M<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,C`Q('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC
M.C8T"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F
M:7)S="XB"FUS9W-T<B`BWOH@_F%R9G0@8?`@=F5L:F$@[2!H=F'P82!M]G!P
M=2!P\W-T=7)I;FX@X2!A\"!F87)A(&9Y<G-T+B(*"B,Z(&9E=&-H;6%I;'!R
M969S+G!H<#HX-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@
M=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B5F5L9'4@:'9A\&$@8?!G86YG:2#^
M^B!V:6QT(&5Y\&$N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHX,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER
M<W0N(@IM<V=S='(@(M[Z(/YA<F9T(&'P('9E;&IA(&YE=&9A;F<@9GER<W0N
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E
M<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R(")6
M96QD=2!A+FTN:RX@96ET="!S:V5Y=&D@9GER<W0N(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@<F5C:7!I96YT+B(*;7-G<W1R(")4:6QG<F5I;F1U('9I\'1A:V%N
M9&$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,CD*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I;&4@=&\@
M871T86-H+B(*;7-G<W1R("+>^B#^87)F="!F>7)S="!A\"!V96QJ82!V:?!H
M96YG:?`N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB
M(&5N86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R
M("(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,W"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N
M(@IM<V=S='(@(M[Z(&5N9'5R=NUS8?!I<B#^97-S=2!S:V5Y=&D@=&EL("5S
M(/YA;FX@)25S+B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S
M+B(*;7-G<W1R("+>^B!S=F%R8?!I<B#^97-S=2!S:V5Y=&D@_F%N;B`E<RXB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@7"(E<UPB+B!(97)E(&ES('=H
M870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(EPB)7-<(B!V87(@96MK:2!G
M97+P('9I<FLN($CI<B!E<B!T:6QK>6YN:6YG:6X@<V5M(&MO;2!F<N$@;F5T
M_FKS;FEN=6TB"@HC.B!L:6(O1F]L9&5R+G!H<#HU,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<
M(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)<
M(B5S7"(@=F%R(&5K:VD@9V5R\"#S=FER:RX@2.ER(&5R('1I;&MY;FYI;F=I
M;B!S96T@:V]M(&9RX2!N973^:O-N:6YU;2(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C0Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L
M;'D@<W5B<V-R:6)E9"!T;R!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB('9A<B!G
M97+P('9I<FLB"@HC.B!L:6(O1F]L9&5R+G!H<#HU-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F
M<F]M(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@=F%R(&=E<O`@\W9I<FLB"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3@V"FUS9VED(")9;W5R($YA;64B
M"FUS9W-T<B`B1G5L;'0@;F%F;B#^:71T.B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ,3D*;7-G:60@(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME
M>7,B"FUS9W-T<B`B4$=0(&]P:6YB97)I<B]E:6YK82!L>6ML87(B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,34P('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,3$V"FUS9VED(")9;W5R(%!R:79A=&4@2V5Y(@IM<V=S='(@(D5I
M;FMA(&1U;')I='5N87)L>6MI;&P@_FEN;B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-#8@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,3(*;7-G
M:60@(EEO=7(@4'5B;&EC($ME>2(*;7-G<W1R(")/<&EN8F5R(&1U;')I='5N
M87)L>6MI;&P@_FEN;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3<*
M;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QI/BAO<'1I;VYA;"D\
M+VD^(@IM<V=S='(@(B(*(E-V87)N971F86YG(/YI='0@968@86YN8?`@96X@
M9G5L;'0@;F5T9F%N9R`H4F5P;'DM=&\Z*2`\:3XH=F%L9G)JX6QS="D\+VD^
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B66]U
M<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC
M.C$V"FUS9VED(")9;W5R(&%C8V]U;G1S.B(*;7-G<W1R(")!\&=A;F=A<B#^
M[6YI<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"FUS9VED("(B
M"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&D^*&]P=&EO;F%L+"!E;G1E<B!E
M86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+VD^(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDR"FUS9VED(")9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES
M(&EM86=E('1Y<&4N(@IM<V=S='(@(E9E9G-K;V%R:2#^:6YN('-T>?!U<B!E
M:VMI(&)I<G1I;F=U(.$@_F5S<V%R<FD@9V5R\"!M>6YD87(N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S,@IM<V=I9"`B66]U<B!D969A=6QT(&-H
M87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(E-JX6QF9V5F
M:?`@<W1A9F%S971T(.T@<V5N9'5M('-K97ET=6TZ(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F875L
M="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS
M9W-T<B`B4VKA;&9V86QI;B!D=6QK\_!U;F%R8?!F97+P(&9Y<FER('-E;F0@
M<VME>71I.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@Y"FUS
M9VED(")9;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N
M(@IM<V=S='(@(E-K97ET:?`@=F%R('-E;G0N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y.`IM<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM<V=S='(@
M(E5N9&ER<VMR:69T(/[M;CHB"@HC.B!M97-S86=E+G!H<#HR-S(@;6%I;&)O
M>"YP:'`Z-3(X(&-O;7!O<V4N<&AP.C$R,3D@;&EB+T-O;7!O<V4N<&AP.C<R
M.0IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM%:VME<G0@969N:5TB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,38*;7-G:60@
M(E]"8V,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,38@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$Y"FUS9VED(")?0FQA8VML:7-T(@IM<V=S='(@(E-V87)T;&ES=&DB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-C4*;7-G:60@(E]#
M8R(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HY,S,*;7-G:60@(E]#;VUP
M;W-E(@IM<V=S='(@(E-E;6IA(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-@IM<V=I
M9"`B7T1E;&5T92(*;7-G<W1R(")%>?!A(@H*(SH@;&EB+TE-4"YP:'`Z.3,U
M"FUS9VED(")?1F]L9&5R<R(*;7-G<W1R(")-]G!P=7(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,`IM<V=I9"`B7TED96YT:71Y(@IM
M<V=S='(@(D%U\&ME;FYI(@H*(SH@;&EB+TE-4"YP:'`Z.3(V"FUS9VED(")?
M26YB;W@B"FUS9W-T<B`B26YN8F]X(@H*(SH@;&EB+TE-4"YP:'`Z.3<V"FUS
M9VED(")?3&]G(&]U="(*;7-G<W1R("+:='-K<N$B"@HC.B!M97-S86=E+G!H
M<#HS-C@*;7-G:60@(E]-97-S86=E(%-O=7)C92(*;7-G<W1R(")(86YD<FET
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,Q
M"FUS9VED(")?4')I;G0B"FUS9W-T<B`B4')E;G1A(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@S('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,P,`IM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(D9O<F=A
M;F=U<B(*"B,Z(&UA:6QB;W@N<&AP.C0P,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")?4F5F<F5S:"`E<R(*;7-G<W1R(")%;F1U<FAL8?!A("5S(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@(E]2
M97!L>2(*;7-G<W1R(")3=F%R82(*"B,Z(&QI8B])35`N<&AP.CDS-PIM<V=I
M9"`B7U-E87)C:"(*;7-G<W1R("),96ET82(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C8V('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0R,@IM<V=I9"`B7U-E;F0@365S<V%G92(*;7-G<W1R(")396YD82!S
M:V5Y=&DB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C,R"FUS9VED(")?5&AR96%D(@IM<V=S='(@(D5F;FES_G+A\'5R(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3$U"FUS9VED(")?
M5&\B"FUS9W-T<B`B5&EL(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,3,*;7-G:60@(E]5;F1E;&5T92(*;7-G<W1R(")%;F1U<G9E:VIA
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$W
M"FUS9VED(")?5FEE=R!4:')E860B"FUS9W-T<B`B4VMO\&$@969N:7/^<N'P
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(R"FUS9VED(")?5VAI
M=&5L:7-T(@IM<V=S='(@(DAV[71L:7-T:2(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS-3$*;7-G:60@(F%T=&%C:&UE;G0B"FUS9W-T<B`B5FGP:&5N9VDB"@HC
M.B!V:65W+G!H<#HY.0IM<V=I9"`B871T86-H;65N=',N>FEP(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P,PIM<V=I
M9"`B8GET97,B"FUS9W-T<B`B8N9T:2(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")F<F]M(@IM<V=S='(@(F9RX2(*
M"B,Z('!G<"YP:'`Z-CD@<VUI;64N<&AP.C(Y"FUS9VED(")K97DB"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,34Q"FUS9VED(")M86EL8F]X(&9I;&4B
M"FUS9W-T<B`B4/-S=&UA<'!A(@H*(SH@8V]M<&]S92YP:'`Z,3`P,2!L:6(O
M365S<V%G92YP:'`Z-#(Y"FUS9VED(")N86UE(@IM<V=S='(@(DYA9FXB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#`*;7-G:60@(FYO
M;F4B"FUS9W-T<B`B96YG:6YN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C$Q,0IM<V=I9"`B;W(B"FUS9W-T<B`B9?!A(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(")S<&5L;&EN
M9R!E<G)O<B(*;7-G<W1R(")S=&%F<V5T;FEN9V%R=FEL;&$B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G:60@(G-P96QL:6YG
M(&5R<F]R<R(*;7-G<W1R(")S=&%F<V5T;FEN9V%R=FEL;'5R(@H*(SH@;&EB
M+T9I;'1E<BYP:'`Z-3$*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM<V=S='(@
M(E-V87)T;&ES=&D@_FEN;B(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED
M(")Y;W5R('=H:71E;&ES="(*;7-G<W1R(")(=NUT;&ES=&D@_FEN;B(*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O<&\O<VQ?
M4TDN<&\`````````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P-#$R-3$P`#$P-#$W,S8R-S8T`#`Q-S(P,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C(%-L;W9E;FEA;B!T<F%N<VQA
M=&EO;B!O9B!);7`*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C
M=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L
M:6-E;G-E(&%S('1H92!);7`@<&%C:V%G92X*(R!-871I8R!$;VQA<B`\<VUE
M<VYI0&UE9&EU;2YS:3X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@($EM<"!(,R`H-"XP+C$I7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-2TP,BTR,2`Q-3HR-2LP,3`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($UA=&EC($1O;&%R(#QS;65S;FE`;65D:75M+G-I/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@4VQO=F5NN>AI;F%<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM
M,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z
M("(*;7-G<W1R("(@("`@("!:83H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q
M-0IM<V=I9"`B("`@("`@5&\Z("(*;7-G<W1R("(@("`@("!:83H@(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0P,PIM<V=I9"`B("`@($1A=&4Z("(*;7-G<W1R
M("(@("!$871U;3H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P-@IM<V=I9"`B
M("`@($9R;VTZ("(*;7-G<W1R("(@("`@("!/9#H@(@H*(SH@;6%I;&)O>"YP
M:'`Z-#(R('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H0FQIOFYJ
M:6-A("5S*2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3(*;7-G:60@(B!3=6)J
M96-T.B`B"FUS9W-T<B`B("!:861E=F$Z("(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I9"`B(&EN("(*;7-G<W1R("(@=B`B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$R
M"FUS9VED("(C(@IM<V=S='(@(B,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H
M)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@H*
M(SH@=&AR96%D+G!H<#HQ-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5D($UE<W-A9V5S(@IM<V=S='(@(DYI('-P;W)OZ&EL(@H*(SH@;6%I;&)O
M>"YP:'`Z,3<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S
M86=E<R!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B)60@<W!O<F_H:6P@
M:F4@8FEL;R!I>F)R:7-A;FEH+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)60@;65S<V%G97,@:&%V92!B965N(')E
M<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B5D('-P;W)OZ&EL(&IE(&)I;&\@=F&Y96UU('-K<F)N
M:6MU('!R:6IA=FQJ96YI:"!K;W0@>F&^96QE;F$@92UP;[ET82XB"@HC.B!L
M:6(O4W!A;2YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A
M9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B
M)60@<W!O<F_H:6P@:F4@8FEL;R!P<FEJ879L:F5N:6@@:V]T('IAOF5L96YA
M(&4M<&^Y=&$N(@H*(SH@;&EB+U-P86TN<&AP.C$W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A
M;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B(E
M9"!S<&]R;^AI;"!J92!B:6QO('9AN65M=2!S:W)B;FEK=2!P<FEJ879L:F5N
M:6@@:V]T(&YE>F&^96QE;F$@92UP;[ET82XB"@HC.B!L:6(O4W!A;2YP:'`Z
M,34P"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E
M;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("(E9"!S<&]R;^AI;"!J92!B
M:6QO('!R:6IA=FQJ96YI:"!K;W0@;F5Z8;YE;&5N82!E+7!ON71A+B(*"B,Z
M(&UA:6QB;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!T;R`E
M9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"!D;R`E9"!O9"`E9"!S<&]R
M;^AI;"(*"B,Z(&UA:6QB;W@N<&AP.C8T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@
M=V%S(&YO="!R96YA;65D+B(*;7-G<W1R("(E<R"^92!O8G-T86IA+B!68;EA
M(&UA<&$@)7,@;FD@8FEL82!P<F5I;65N;W9A;F$N(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C8T.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!M86EL8F]X+B(*;7-G<W1R("(E<R!N:2!V
M96QJ879E;B!N86)I<F%L;FEK+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@
M;V8@=&AE(&UO;G1H+B(*;7-G<W1R(")-87!A("5S(&)O('!R96EM96YO=F%N
M82!N82!Z8>AE=&MU(&UE<V5C82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!A8V-E<'1E
M9"XB"FUS9W-T<B`B)7,@:F4@<W!R96IE;"XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C(U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C
M86YC96QL960@)7,N(@IM<V=S='(@(B5S(&IE('!R96ML:6-A;"`E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&AA<R!D96-L:6YE9"XB"FUS9W-T<B`B)7,@:F4@;V1K;&]N
M:6PN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R
M97%U97-T+B(*;7-G<W1R("(E<R!J92!O9&=O=F]R:6P@;F$@>F%H=&5V;R!P
M<F]S="]Z87-E9&5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE
M(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@(B5S(&IE(&]D9V]V;W)I;"!N
M82!P;W9A8FEL;R!N82`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#@R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S('9A;2!J92!P;W-L
M86P@:6YF;W)M86-I:F\@<')O<W0O>F%S961E;BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@:F4@;VML979A
M:F_H92!S<')E:F5L+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT
M.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(&IE('IA:'1E=F%L('9A
MN6\@:6YF;W)M86-I:F\@<')O<W0O>F%S961E;BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3@T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E
M<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N(@IM<V=S='(@(B5S('IA:'1E
M=F$@=F&Y;R!P<FES;W1N;W-T('!R:2`E<RXB"@HC.B!L:6(O365S<V%G92YP
M:'`Z-#$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B)7,@:F4@8FEL
M('5S<&6Y;F\@9&]D86X@:R`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!A
M;6UE;F0@)7,N(@IM<V=S='(@(B5S(+YE;&D@<&]P<F%V:71I("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G
M<W1R("(E<R!V87,@OF5L:2!O<&]Z;W)I=&D@;F$@)7,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B
M;W5T("5S+B(*;7-G<W1R("(E<R"^96QI('!R96IE=&D@;F%J;F]V96JY92!I
M;F9O<FUA8VEJ92!O("5S+B(*"B,Z(&UE<W-A9V4N<&AP.C(X-2!M97-S86=E
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B5S.B`E<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC
M.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N
M8G-P.R5D*2(*;7-G<W1R("(E<SH@)7,@*"5D)FYB<W`[;V0F;F)S<#LE9"DB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S"FUS9VED
M("(H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C<F5E
M;BXI(@IM<V=S='(@(BA5<&]R86)I('1E('-P<F5M96UB92!I;B!N861A;&IU
M:BXI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM
M<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@
M8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("(H3W9ROFD@=G-E('-P<F5M96UB
M92!I;B!S92!V<FYI(&YA('-E<W1A=FQJ86YJ92!S<&]R;^AI;&$N*2(*"B,Z
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@HC+"!F=7IZ>0IM
M<V=I9"`B*$A434PI(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!497AT*2(*;7-G
M<W1R("(B"@HC.B!S<&5L;&EN9RYP:'`Z,C@P"FUS9VED("(B"B(H4F5T=7)N
M('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA
M;F=E<R!M861E('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O;B!T:&4@8W5R<F5N
M="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BA5
M<&]R86)I('9S92!D;W-E9&%N:F4@<W!R96UE;6)E;6)E(&EN('-E('9R;FD@
M;F$@<V5S=&%V;&IA;F4@<W!O<F_H:6QA+B`B"B)3<')E;65M8F4@;F$@=')E
M;G5T;F5M('IA<VQO;G4@3D4@0D]$3R!U<&]R86)L:F5N92XI(@H*(SH@<W!E
M;&QI;F<N<&AP.C(W-PIM<V=I9"`B(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A
M<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O
M;B!T:&4@(@HB8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI
M(@IM<V=S='(@(B(*(BA5<&]R86)I('9S92!D;W-E9&%N:F4@<W!R96UE;6)E
M(&EN('!ON6QJ:2!S<&]R;^AI;&\N(%-P<F5M96UB92!N82!T<F5N=71N96T@
M(@HB>F%S;&]N=2!.12!"3T1/('5P;W)A8FQJ96YE+BDB"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE
M<V4@8GD@8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J($1O9&%J(',@:VQI:V]M
M(&YA(%8@<F5D=2`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J
M(@IM<V=S='(@(BH@4')O<VEM(&EZ8F5R:71E(&YA<VQO=BAE*2`J(@H*(SH@
M;6%I;&)O>"YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4W!O<F_H:6QO(&IE(&)I;&\@<&]B
M<FES86YO+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*;7-G:60@(C$@;65S<V%G
M92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(Q('-P;W)OZ&EL;R!J92!B:6QO
M('9AN65M=2!S:W)B;FEK=2!P<FEJ879L:F5N;R!K;W0@>F&^96QE;F$@92UP
M;[ET82XB"@HC.B!L:6(O4W!A;2YP:'`Z,38P"FUS9VED("(Q(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(C$@<W!O
M<F_H:6QO(&IE(&)I;&\@<')I:F%V;&IE;F\@:V]T('IAOF5L96YA(&4M<&^Y
M=&$N(@H*(SH@;&EB+U-P86TN<&AP.C$W,@IM<V=I9"`B,2!M97-S86=E(&AA
M<R!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@HB,2!S<&]R;^AI;&\@:F4@8FEL;R!V8;EE
M;74@<VMR8FYI:W4@<')I:F%V;&IE;F\@:V]T(&YE>F&^96QE;F$@92UP;[ET
M82XB"@HC.B!L:6(O4W!A;2YP:'`Z,34R"FUS9VED("(Q(&UE<W-A9V4@:&%S
M(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`B,2!S<&]R;^AI;&\@
M:F4@8FEL;R!P<FEJ879L:F5N;R!K;W0@;F5Z8;YE;&5N82!E+7!ON71A+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*;7-G:60@(C$P,"!C:&%R
M86-T97)S(@IM<V=S='(@(C$P,"!Z;F%K;W8B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#(R"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B
M,3`P,"!Z;F%K;W8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(P"FUS
M9VED("(R-3`@8VAA<F%C=&5R<R(*;7-G<W1R("(R-3`@>FYA:V]V(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,0IM<V=I9"`B-3`P(&-H87)A8W1E
M<G,B"FUS9W-T<B`B-3`P('IN86MO=B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM
M86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS
M9W-T<B`B5&5M=2!S<&]R;^AI;'4@:F4@<')I<&5T82!V96QI:V$@<VQI:V$@
M>B!I;65N;VT@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA
M<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@
M(@HB<F5C:7!I96YT+B(*;7-G<W1R("(B"B)3<&]R;^AI;&\L(&MI('-T92!G
M82!P;W-L86QI+"!J92!B:6QO('9Z<F]K('IA(&]B=F5S=&EL;RP@=G)N:F5N
M;R!S('-T<F%N:2`B"B)P<F5J96UN:6MA+B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!3D0B"FUS9W-T<B`B24XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DP"FUS9VED(")!8V-E<'0@<F5Q
M=65S="(*;7-G<W1R(")3<')E:FUI('IA:'1E=F\B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3@W"B,L(&9U>GIY"FUS9VED(")!8V-E<'0@<F5Q
M=65S="!A;F0@861D(&ET('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(D1O9V]D
M96L@:F4@8FEL(&1O9&%N(&YA('9AN2!K;VQE9&%R+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW-3,*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@
M(E-P<F5J971O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-PHC
M+"!F=7IZ>0IM<V=I9"`B06-C97!T960Z("(*;7-G<W1R(")3<')E:F5T;R(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"FUS9VED(")!
M8V-O=6YT)W,@;F%M93HB"FUS9W-T<B`B26UE(')AZ'5N83HB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3(P(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW,S`*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B1&5J86YJ82(*"B,Z
M(&QI8B]-24U%+TAE861E<G,N<&AP.C(P,"!L:6(O34E-12](96%D97)S+G!H
M<#HR,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"`E<R!T;R!M
M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B1&]D86H@=B!!9')E<V%R("@E<RDB
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*;7-G
M:60@(D%D9"!S;W5R8V4B"FUS9W-T<B`B1&]D86H@=FER(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4W-R!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3@X"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R
M(")$;V1A:B!V(&UO:B!K;VQE9&%R(@H*(SH@8V]M<&]S92YP:'`Z,3(U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T86-H
M;65N="XB"FUS9W-T<B`B1&]D86P@7"(E<UPB(&MO="!P<FEP;VYK;RXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DX"B,L(&9U>GIY"FUS9VED("(B
M"B)!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES<&QA>2!W:&5N('9I97=I;F<Z
M(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@:&5A9&5R("(*(F]N(&$@;F5W
M(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB4')I:V%Z(&1O9&%T;FEH('9R<W1I
M8R!G;&%V92!P<FD@<')E9VQE9&]V86YJ=3H@/&D^*'!O(+YE;&II+"!D;V1A
M:G1E('9S86MO("(*(G9R<W1I8V\@9VQA=F4@=B!S=F]J;R!V<G-T:6-O*3PO
M:3XB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(D1O9&%T;F4@:6YF;W)M86-I:F4@
M<V\@;F$@=F]L:F\@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A
M=&EO;BYP:'`Z-C(*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T
M86EL<R(*;7-G<W1R(")$;V1A=&YE('!O9')O8FYO<W1I(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z.3,*;7-G:60@(D%D9&ET:6]N86P@;65S
M<V%G92!D971A:6QS(@IM<V=S='(@(D1O9&%T;F4@<&]D<F]B;F]S=&D@;R!S
M<&]R;^AI;'4B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL
M<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")$;V1A=&YE('!O9')O8FYO
M<W1I(&\@<W!O<F_H:6QU('-O(&YA('9O;&IO("5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C<X"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A
M9V4@97)R;W(@9&5T86EL<R(*;7-G<W1R(")$;V1A=&YE('!O9')O8FYO<W1I
M(&\@;F%P86MI(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R
M(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B1&]D871N92!P
M;V1R;V)N;W-T:2!O(&YA<&%K:2!S;R!N82!V;VQJ;R`E<RXB"@HC.B!C;VYT
M86-T<RYP:'`Z.#4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M.#`*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L
M871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,@IM<V=I9"`B061D<F5S<R!"
M;V]K(@IM<V=S='(@(D%D<F5S87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,T"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(D%D<F5S87)J
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*(RP@9G5Z>GD*;7-G
M:60@(B(*(D%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P
M=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@(@HB;&EN92D\
M+V5M/B(*;7-G<W1R("(B"B)"2TL@;F%S;&]V:2!Z82!V<V$@<W!O<F_H:6QA
M.B`\:3XH<&\@OF5L:FDL(&1O9&%J=&4@=G-A:R!N87-L;W8@=B!S=F]J;R`B
M"B)V<G-T:6-O*3PO:3XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q
M"B,L(&9U>GIY"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T
M:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C
M:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB
M3F%S;&]V:2P@:VD@;F%J('-E(&EZ<F5C;F\@=F6^96IO(',@=&\@:61E;G1I
M=&5T;SH@/&D^*'!O(+YE;&II+"!D;V1A:G1E("(*(G9S86L@;F%S;&]V('8@
M<W9O:F\@=G)S=&EC;RD\+VD^(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")!
M;&PB"FUS9W-T<B`B5G-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ,PIM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-
M0D]8("(*(F9I;&4Z(@IM<V=S='(@(E9S82!S<&]R;^AI;&$@=B!N87-L961N
M:FEH(&UA<&%H(&)O9&\@<W1R;FIE;F$@=B!E;B!-0D]8(&YA8FER86QN:6LZ
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R
M(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R
M;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB5G-A('-P;W)OZ&EL
M82!V('9AN6D@;6%P:2!<(B5S7"(L(&MI('-O('-T87)E:KEA(&]D("5S(&1N
M:2!B;V1O('1R86IN;R`@(@HB<&]B<FES86YA+B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM
M<V=S='(@(E9S92!P<FEP;VYK92P@<W1A<F5JN64@;V0@)7,@;65S96-E=B!B
M;V1O('!O8G)I<V%N92XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE
M=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N
M=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@(E9S92!M87!E(',@
M<&]S;&%N;R!P;[ET;R!S=&%R96JY92!O9"`E<R!M97-E8V5V(&)O9&\@<&]B
M<FES86YE+B(*"B,Z(&%C;"YP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L
M;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(E9S92!P<F%V
M:6-E('IA(&UA<&\@)R5S)R!S;R!B:6QE('5S<&6Y;F\@;V1V>F5T92!U<&]R
M86)N:6MU("<E<R<N(@H*(SH@;&EB+V%P:2YP:'`Z-S8*;7-G:60@(D%L;&]W
M($9O;&1E<B!#<F5A=&EO;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<')E9G,N:6YC.C0X"FUS9VED(")!;&QO=R!F:6QT97(@<G5L97,@
M=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O>#\B"FUS9W-T<B`B4V4@;&%H
M:V\@<')A=FEL82!Z82!F:6QT<FER86YJ92!U<&]R86)I:F\@;F$@:V%T97)E
M;6MO;&D@;F%B:7)A;&YI:W4_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R
M;F%T:79E+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T
M:&ES('-E8W1I;VXZ(@IM<V=S='(@(D%L=&5R;F%T:79N:2!D96QI('IA('1A
M(&]D<V5K.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S(@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4X-`IM<V=I9"`B06QW87ES(@IM<V=S='(@(E9E
M9&YO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U-PIM<V=I9"`B06QW
M87ES('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B5F5D;F\@<VAR86YI('!R
M:7!O;FME(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4P-0IM<V=I9"`B(@HB06X@
M97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-T<FEP('1H92!A
M='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@(@HB<V%I9#H@(@IM<V=S='(@
M(B(*(E!R:2!O9'-T<F%N:F5V86YJ=2!P<FEP;VYK92!S<&]R;^AI;"!J92!P
M<FFY;&\@9&\@;F%P86ME+B!)34%0('-T<F6^;FEK(&IE("(*(FIA=FEL.B`B
M"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")!;B!U
M;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N
M;W1E+B(*;7-G<W1R(")0<FD@9&]D86IA;FIU(&YO=F5G82!O<')A=FEL82!J
M92!P<FFY;&\@9&\@;F5Z;F%N92!N87!A:V4N(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C,X-PIM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE
M(&-R96%T:6YG('1H92!N97<@=&%S:RXB"FUS9W-T<B`B4')I(&1O9&%J86YJ
M=2!N;W9E9V$@;W!R879I;&$@:F4@<')IN6QO(&1O(&YE>FYA;F4@;F%P86ME
M+B(*"B,Z(&UE<W-A9V4N<&AP.C4P,"!M86EL8F]X+G!H<#HW,30@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHY"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS-0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C8*
M;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(D]D9V]V;W)J96YO(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B06YS=V5R960@;65S
M<V%G97,B"FUS9W-T<B`B3V1G;W9O<FIE;F$@<W!O<F_H:6QA(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"FUS9VED(")!<'!L>2!&:6QT
M97)S(@IM<V=S='(@(E5P;W)A8FD@9FEL=')E(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%P<&QY
M($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`B57!O<F%B:2!F:6QT<F4@;F$@)7,B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S8*;7-G:60@(D%P
M<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(E5P
M;W)A8FEM('!R879I;&$@9FEL=')I<F%N:F$@;V(@<')I:F%V:3\B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#(*;7-G:60@(D%P<&QY(&9I
M;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_(@IM<V=S
M='(@(E5P;W)A8FEM('!R879I;&$@9FEL=')I<F%N:F$@;V(@<')I:V%Z=2!)
M3D)/6#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHR-PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&1E;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(D%L:2!S
M=&4@<')E<')IZ&%N:2P@9&$@OF5L:71E('!O8G)I<V%T:2!T82!J879N:2!K
M;&IUZ#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R
M96-O;6UE;F1E9"$I(@IM<V=S='(@(B(*(D%L:2!S=&4@<')E<')IZ&%N:2P@
M9&$@OF5L:71E('!O8G)I<V%T:2!S=F]J('!A<B!K;&IUZ&5V/R`H3DD@<')I
M<&]R;^AE;F\A*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN
M8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_(@IM<V=S='(@(E-T92!P
M<F5P<FGH86YI+"!D82"^96QI=&4@:7IV<KEI=&D@9&5J86YJ93\B"@HC.B!M
M97-S86=E+G!H<#HT,#<@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%
M3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(E-T92!P<F5P
M<FGH86YI+"!D82"^96QI=&4@5%)!2DY/('IB<FES871I('1A('-P;W)OZ&EL
M83\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@
M871T86-H;65N=#\B"FUS9W-T<B`B4W1E('!R97!R:>AA;FDL(&1A(+YE;&ET
M92!44D%*3D\@>F)R:7-A=&D@=&\@<')I<&]N:V\_(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`B4W1E('!R
M97!R:>AA;FDL(&1A(+YE;&ET92!I>G!R87IN:71I('1O(&UA<&\_(@H*(SH@
M;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`B
M4W1E('!R97!R:>AA;FDL(&1A(+YE;&ET92!I>G!R87IN:71I('-V;VIO(&UA
M<&\@<R!S;65T;6D_(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_
M(@IM<V=S='(@(E-T92!P<F5P<FGH86YI+"!D82"^96QI=&4@:7IP<F%Z;FET
M:2!S=F]J;R!M87!O(',@<VUE=&UI/R(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!P97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@
M(E-T92!P<F5P<FGH86YI+"!D82"^96QI=&4@=')A:FYO('!O8G)I<V%T:2!T
M82!S<&]R;^AI;&$_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP
M="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M
M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R(")3=&4@<')E<')IZ&%N:2P@
M9&$@OF5L:71E('!R:6IA=FET:2!T;R!S<&]R;^AI;&\@:V]T('IAOF5L96YO
M/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S
M<&%M/R(*;7-G<W1R(")3=&4@<')E<')IZ&%N:2P@9&$@OF5L:71E('!R:6IA
M=FET:2!T;R!S<&]R;^AI;&\@:V]T(&YE>F&^96QE;F\_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S
M='(@(LAA<R!P<FEH;V1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS
M,0IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(DYA<F&Y=6IOZ"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S$@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4X,PIM<V=I9"`B07-K(@IM<V=S='(@(E9P<F&Y86HB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3D*;7-G:60@(D%T=&%C:"(*;7-G
M<W1R(")0<FEP;FDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHT-S4*;7-G:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R(")0<FEP;FD@9&%T
M;W1E:V4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-38*
M;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T
M;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@(E!R:7!N96T@:7IV;V0@=F&Y96=A
M(&IA=FYE9V$@4$=0(&ML:G7H82!K('-P;W)OZ&EL=3\B"@HC.B!L:6(O34E-
M12]6:65W97(O=&YE9BYP:'`Z,3`Y"FUS9VED(")!='1A8VAE9"!&:6QE.B(*
M;7-G<W1R(")0<FEP;VYK83HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#4Q(&QI
M8B]#;VUP;W-E+G!H<#HU,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB071T
M86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE
M(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(@IM<V=S='(@(B(*(E!R:7!O
M;FMA(%PB)7-<(B!P<F5S96=A(&]M96II=&5V('9E;&EK;W-T:2!Z82!P<FEP
M;VYK92X@1&%T;W1E:V$@3DD@0DE,02`B"B)P<FEP971A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HS-S8*;7-G:60@(D%T=&%C:&5D(&ES(&$@
M<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+B(*;7-G<W1R
M(")0<FEP970@:F4@;V1G;W9O<B!N82!P;W-L86YO('IA:'1E=F\@:V]L961A
M<FIA+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHY-PIM<V=I9"`B071T86-H;65N="(*;7-G<W1R(")0
M<FEP;VYK82(*"B,Z(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP
M.C0V-@IM<V=I9"`B071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T
M86-H;65N="!T>7!E(@IM<V=S='(@(E!R:7!O;FMA(&]D<W1R86YJ96YA.B!6
M<G-T82!P<FEP;VYK92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S,*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$P-S,*;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S
M='(@(E!R:7!O;FME(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X
M,@IM<V=I9"`B071T96YD965S(@IM<V=S='(@(E5D96QEOF5N8VDB"@HC.B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PIM<V=I9"`B071T
M96YT:6]N(@IM<V=S='(@(E!O>F]R(@H*(SH@;&EB+T%U=&@O:6UP+G!H<#HT
M-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z(%IA:'1E=F%N($E-05`@9&]D
M871E:R!N:2!B:6P@;F%J9&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-#`*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@
M2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D
M<F5S<V)O;VL_(@IM<V=S='(@(B(*(D%V=&]M871IZ&YO('!R:6MAOF5M('-L
M:6ME('8@2%1-3"!S<&]R;^AI;&EH+"!K861A<B!J92!P;[EI;&IA=&5L:B!V
M(&UO:F5M("(*(F%D<F5S87)J=3\B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHR.3@*;7-G:60@(D%V86EL86)L92!!9&1R97-S(&)O
M;VMS.B(*;7-G<W1R(")!9')E<V%R:FDL(&MI('-O(&YA('9O;&IO.B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET:6YG
M(%)E<W!O;G-E(@IM<V=S='(@(LAA:V%J;^@@;V1Z:78B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M
M870*;7-G:60@(D)A8U]K('1O("5S(@IM<V=S='(@(DYA>F%J(%]N82`E<R(*
M"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E
M<R(*;7-G<W1R(").87IA:B!N82`E<R(*"B,Z('1H<F5A9"YP:'`Z,3,T"FUS
M9VED(")"86-K('1O($UU;'1I<&QE($UE<W-A9V4@5FEE=R!);F1E>"(*;7-G
M<W1R("(B"@HC.B!T:')E860N<&AP.C$S,@IM<V=I9"`B0F%C:R!T;R!4:')E
M860@1&ES<&QA>2(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")"860@;W(@;6%L9F]R;65D(')E
M<75E<W0N(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C(V-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(R,@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(P(&QI
M8B]396%R8V@N<&AP.C,T"FUS9VED(")"8V,B"FUS9W-T<B`B0FMK(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38Q"FUS9VED(")"96QO=R!I
M<R!T:&4@<F%W('1E>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S
M86=E+B(*;7-G<W1R(")3<&]D86H@:F4@<W5R;W9O(&)E<V5D:6QO('!O<F_H
M:6QA(&\@<W1A='5S=2XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,38*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R(")";&%C:VQI<W0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C(Y"FUS9VED(")";&]C:R!I;6%G97,@
M:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY
M(')E<75E<W1E9#\B"FUS9W-T<B`B3F4@<')I:V&^96T@<VQI:R!V($A434P@
M<W!O<F_H:6QI:"!R87IE;B#H92!S;R!I>G)E8VYO('IA:'1E=F%N93\B"@HC
M.B!L:6(O4V5A<F-H+G!H<#HT,@IM<V=I9"`B0F]D>2(*;7-G<W1R(")496QO
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T
M:"(*;7-G<W1R(")/8F]J92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.#<*;7-G:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S
M<V%G92(*;7-G<W1R(")/8F]J92`M('-E>FYA;2!G;&%V92!I;B!T96QO('-P
M;W)OZ&EL82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W
M,@IM<V=I9"`B0U]H87)S970B"FUS9W-T<B`B2V]?9&YA('1A8F5L82(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD
M87(B"FUS9W-T<B`B2V]L961A<B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,C`Q"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M
M86EL('-E<G9E<BXB"FUS9W-T<B`B4&]V97IA=F$@;F$@;V1D86QJ96X@<&^Y
M=&YI('-T<F6^;FEK(&YI('5S<&5L82XB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO
M=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R(")0;W9E>F%V82!N82!O9&1A;&IE
M;B!P;[ET;FD@<W1R9;YN:6L@;FD@=7-P96QA.B`B"@HC.B!L:6(O34E-12]6
M:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O
M9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@(@HB;6%I;&)O>"XB"FUS
M9W-T<B`B(@HB4')I:V%Z(&YI(&UO9V_H("T@=B!T<F5N=71N96T@;F%B:7)A
M;&YI:W4@:F4@8FEL;R!N86ID96YI:"!S86UO("5S(&]D("5S("(*(F1E;&]V
M('1E9V$@<W!O<F_H:6QA+B(*"B,Z(&9O;&1E<G,N<&AP.C(X-"!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-0HC.B!T96UP;&%T97,O9F]L
M9&5R<R]I;7!O<G0N:6YC.C(Q('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM
M86=E+FEN8SHQ.0HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z
M,C$@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@V"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`@=&5M<&QA=&5S+W!G<"]P
M87-S<&AR87-E+FEN8SHS,@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C8V"FUS9VED(")#86YC96PB"FUS9W-T<B`B4')E:VQIZ&DB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHW,2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,S4*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C$Q,0IM<V=I9"`B0V%N8V5L($UE<W-A9V4B"FUS9W-T<B`B
M4')E:VQIZ&D@<W!O<F_H:6QO(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS
M9VED(")#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA;F5N=&QY
M(&1I<V-A<F0@:71S(&-O;G1E;G1S+B(*;7-G<W1R(")0<F5K;&EC('1E9V$@
M<W!O<F_H:6QA(&)O('1R86IN;R!Z879R9V5L('9S96)I;F\N(@H*(SH@;65S
M<V%G92YP:'`Z,C8U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,34@;&EB
M+U-E87)C:"YP:'`Z,S`*;7-G:60@(D-C(@IM<V=S='(@(DMK(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,PIM<V=I9"`B(@HB0V5R=&EF:6-A
M=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO
M="!E;F%B;&5D(&]N('1H:7,@(@HB<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Q"FUS9VED(")#:&%I<B!097)S
M;VXB"FUS9W-T<B`B4')E9'-E9'5J;^AA(&]S96)A(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED(")#:&%N9V4B"FUS9W-T
M<B`B4W!R96UE;FDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z.#$*;7-G:60@(D-H86YG92!!;&PB"FUS9W-T<B`B4W!R96UE;FD@=G-E
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDR"FUS9VED(")#:&%N9V4@
M1F]L9&5R(@IM<V=S='(@(E-P<F5M96YI(&UA<&\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$R"FUS9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I
M;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H
M('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R
M("(B"B).87-T879I(&UOOFYO<W1I('!R:6MA>F$L(+ET979I;&\@<W!O<F_H
M:6P@<')I:V%Z86YI:"!N82!E;FD@<W1R86YI(&EN("(*(FUOOFYO<W1I(')A
M>G9RN>AA;FIA('-P;W)OZ&EL+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-`IM<V=I9"`B0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T
M=&EN9W,N(@IM<V=S='(@(DYA<W1A=FD@<&^Y=&YI('-T<F6^;FEK(&EN(&UO
MOFYO<W1I(&UA<&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U"FUS
M9VED("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U
M<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"`B"B)R97!L
M>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B).87-T879I(&EM92P@;F%S
M;&]V(&EN('!O9'!I<RP@:VD@9V$@<')E:F5M;FEK:2!S<&]R;^AI;"!V:61I
M:F\L(&MO(&)E<F5J;R`B"B)I;B!O9&=O=F%R:F%J;R!N82!V8;EO(&4M<&^Y
M=&\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R-`IM<V=I9"`B0VAA
M<F%C=&5R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R(")0<FEK87H@>FYA:V]V.B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#
M:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(E!O9VQE:B!Z
M82!.;W9A('-P;W)OZ&EL82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(D]Z;F'H:2!?
M5G-E+TYO8F5N96=A(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA
M:6PN:6YC.C$P('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR
M,0IM<V=I9"`B0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F
M971C:"!M86EL(&9R;VTZ(@IM<V=S='(@(D]Z;F'H:71E('9S92!S=')EOFYI
M:V4L(',@:V%T97)I:""^96QI=&4@<')E;F5S=&D@92UP;[ET;SHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8S"FUS9VED(")#:&5C:R!S<&5L;&EN
M9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(E!R979E<FEM
M(.AR:V]V86YJ92!P<F5D96X@<&^Y;&IE;2!S<&]R;^AI;&\_(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I9"`B0VAO;W-E($%C
M=&EO;CHB"FUS9W-T<B`B27IB97)I=&4@9&5J86YJ93HB"@HC.B!C;VYF:6<O
M<V5R=F5R<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-H;V]S92!A(&UA:6P@<V5R
M=F5R.B(*;7-G<W1R("))>F)E<FET92!P;[ET;FD@<W1R9;YN:6LZ(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHR,3<*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A(&UA=&-H
M(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R(")0
M<F]S:6T@:7IB97)I=&4@86QI('5R961I=&4@=B!O8G)A>F-U(&YA(&1E<VYI
M.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C$@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<S,0IM<V=I9"`B0VAO;W-E(&%N(&%C=&EO;CHB
M"FUS9W-T<B`B27IB97)I=&4@9&5J86YJ93HB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*;7-G:60@(D-H;V]S92!T:&4@861D
M<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S
M='(@(DEZ8F5R:71E(&%D<F5S87(L(&MI(&=A('5P;W)A8FEM('IA(&1O9&%J
M86YJ92!N87-L;W9O=BXB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHR.3,*;7-G:60@(D-H;V]S92!T:&4@;W)D97(@;V8@861D<F5S
M<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*
M;7-G<W1R("))>F)E<FET92!V<G-T;FD@<F5D(&ES:V%N:F$@<&\@861R97-A
M<FII:"P@:V\@<F%ZN6ER:F%M(&YA<VQO=F4N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K
M("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y
M;W5R(&)R;W=S97(@8V%N('9I97<N(@IM<V=S='(@(B(*(DML:6MN:71E("5S
M('IA('!R971V;W)B;R!S;&EK92!V(&]B;&EK;R!K:2!J;R!V8;D@8G)S:V%L
M;FEK('IN82!P<FEK87IA=&DN(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9&]W
M;FQO860@=&AE(&EM86=E+B(*;7-G<W1R(")+;&EK;FET92`E<R!D82!S:2!P
M<F5N97-E=&4@<VQI:V\N(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE
M;G0@<&%G92XB"FUS9W-T<B`B2VQI:VYI=&4@)7,@>F$@<W1R86X@>F$@=7!R
M879L:F%N:F4@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W($A434P@
M8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B2VQI:VYI
M=&4@)7,@>F$@<')I:V%Z($A434P@=G-E8FEN92!V(&QOZ&5N96T@;VMN=2XB
M"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T
M:&ES(&EM86=E+B(*;7-G<W1R(")+;&EK;FET92`E<R!Z82!P<FEK87H@<VQI
MZ&EC92!T92!S;&EK92XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H
M92!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")+
M;&EK;FET92`E<R!Z82!P<FEK87H@<')I<&]N:V4@=B!L;^AE;F5M(&]K;G4N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H:7,@;75L
M=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS
M9W-T<B`B2VQI:VYI=&4@)7,@>F$@<')I:V%Z('!R:7!O;FME('8@;&_H96YE
M;2!O:VYU+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I
M9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,B"FUS9W-T<B`B2VQI
M:VYI=&4@>F$@4%))2T%:('-L:6LB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,C$*;7-G:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y
M;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L
M;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*;7-G<W1R("(B"B)+;&EK;FET92!N
M82!I>F)R86YE(&%D<F5S87)J92P@;F%T;R!P82!I>F)E<FET92!V<V$@<&]L
M:F$L('!O(&MA=&5R:6@@;F%J("(*(G!O=&5K82!I<VMA;FIE+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,0IM<V=I9"`B0VQI8VL@=&\@4V%V
M92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R
M(")+;&EK;FET92!Z82!S:')A;FET978@:F%V;F5G82!02%`@:VQJ=>AA('8@
M=F&Y($%D<F5S87(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(P
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R!T;R!3879E(%,O34E-12!C
M97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")+;&EK;FET92!Z82!S:')A;FET978@)7,@4R]-24U%('!O=')D:6QA('8@
M=F&Y($%D<F5S87(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,`IM
M<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@
M;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G<W1R(")+;&EK(&YA(&YA
M<VQO=B!B;R!O9'!R;"!S97-T879L:F%N:F4@;F]V96=A('-P;W)OZ&EL82!P
M;[EI;&IA=&5L:G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q"FUS
M9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE
M<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R(")+;&EK(&YA(&YA<VQO=B!B;R!O
M9'!R;"!S<&]R;^AI;&\@>F$@8G)A;FIE(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]F971C:&UA:6PN:6YC.C(X"FUS9VED(")#;&]S92(*;7-G<W1R("):
M87!R:2(*"B,Z(&-O;7!O<V4N<&AP.C@R."!C;VUP;W-E+G!H<#HQ,30X"FUS
M9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R("):87!R:2!T;R!O:VYO
M(@H*(SH@9F]L9&5R<RYP:'`Z-#(Y"FUS9VED(")#;&]S960@1F]L9&5R(@IM
M<V=S='(@(EIA<')I(&UA<&\B"@HC.B!F;VQD97)S+G!H<#HT-#D*;7-G:60@
M(D-O;&QA<'-E(@IM<V=S='(@(E-K<NAI(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R
M(")3:W+H:2!V<V4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T<B`B4VMR
MZ&D@=G-E(&UA<&4B"@HC.B!F;VQD97)S+G!H<#HT-#D*;7-G:60@(D-O;&QA
M<'-E($9O;&1E<B(*;7-G<W1R(")3:W+H:2!M87!O(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C4Q"FUS9VED(")#;VQO<B!);F1I8V%T
M;W(Z("(*;7-G<W1R(")0;VMA>F%T96QJ(&)A<G9E.B`B"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DMO
M;65N=&%R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V.0IM<V=I
M9"`B0V]M<&QE=&5D(@IM<V=S='(@(DMO;NAA;F\B"@HC.B!C;VUP;W-E+G!H
M<#HX,C<@8V]M<&]S92YP:'`Z,3$T-PIM<V=I9"`B0V]M<&]S92!A;F]T:&5R
M(&UE<W-A9V4B"FUS9W-T<B`B4V5S=&%V:2"Y92!E;F\@<W!O<F_H:6QO(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-`IM<V=I9"`B0V]M<&]S92!M
M97-S86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B4V5S=&%V
M;&IA:B!S<&]R;^AI;&$@=B!L;^AE;F5M(&]K;G4_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0T,PIM<V=I9"`B(@HB0V]M<&]S92!M97-S86=E<R!W
M:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R
M=',@=&AE("(*(F9E871U<F4I/R(*;7-G<W1R("(B"B)0<FEV>F5T;R!S97-T
M879L:F%J('-P;W)OZ&EL82!S($A434P@=7!O<F%B;FFY:VEM('9M97-N:6MO
M;2`HZ&4@8G)S:V%L;FEK("(*(G!O9'!I<F$@=&\@;6^^;F]S="D_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W
M(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S='(@(DYA<W1A=FD@<')I
M:V%Z('-P;W)OZ&EL+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+B(*;7-G<W1R
M(").87-T879I('!R961O9VQE9"!S<&]R;^AI;"XB"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C,W,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!D<F]P
M<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R(")0;W9E>F%V82!S('-T<F6^
M;FEK;VT@;FD@=7-P96QA(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR
M,S0*;7-G:60@(D-O;FYE8W1I;VX@=&\@<V5R=F5R(&9A:6QE9"(*;7-G<W1R
M(")0;W9E>F%V82!S('-T<F6^;FEK;VT@;FD@=7-P96QA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT
M<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B57!R879L:F%N:F4@
M<R!01U`@<&]D<&]R;R!Z82`E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4R]-24U%('-U
M<'!O<G0@9F]R("5S+B(*;7-G<W1R(")5<')A=FQJ86YJ92!S(%,O34E-12!P
M;V1P;W)O('IA("5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*
M;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S
M96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@
M8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U
M("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB3F%S=&%V:2!P<F5V
M97)J86YJ92!N;W9E('!ON71E(&EN(&YAZ&EN(&]B=F6YZ&%N:F$L(&MA9&%R
M('!R:7-P92!N;W9O("(*(G-P;W)OZ&EL;RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-CDV"FUS9VED(")#;VYV97)T('1E>'1U86P@96UO=&EC;VYS
M(&EN=&\@9W)A<&AI8V%L(&]N97,_(@IM<V=S='(@(E!R971V;W)I;2!T96MS
M=&]V;F4@<VUEN6ME('8@9W)A9FGH;F4_(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&ER86HB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'D@=&\@
M9F]L9&5R(@IM<V=S='(@(DMO<&ER86H@=B!M87!O(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S
M='(@(E!O<')A=FDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,30P"FUS9VED(")#;W)R96-T960@5&5X="(*;7-G<W1R(")0;W!R879L
M:F5N;R!B97-E9&EL;R(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@
M<F5Q=65S="X@4F5A<V]N($=I=F5N.B`E<R(*;7-G<W1R(")61E,@:')B=&5N
M:6-E(&YI(&)I;&\@;6]G;^AE(&EZ9&5L871I.B`E<R(*"B,Z(&%T=&%C:&UE
M;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A
M=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G<W1R(")61E,@:')B=&5N:6-E
M(&YI(&)I;&\@;6]G;^AE(&EZ9&5L871I.B`E<R(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HV-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!M97-S86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S
M='(@(E-P;W)OZ&EL82!N:2!B:6QO(&UO9V_H92!P;V)R:7-A=&D@:7H@)7,N
M($YA<&%K83H@)7,B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,S$X"FUS9VED(")#
M;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G
M<W1R(")6>F1ROF5V86YJ82!N:2!B:6QO(&UO9V_H92!Z86=N871I+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T
M(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.148@
M871T86-H;65N="XB"FUS9W-T<B`BKF5L:F5N92!D871O=&5K92!N:2!B:6QO
M(&UO9V_H92!I>G9L9>AI(&EZ($U3+51.148@<')I<&]N:V4N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO="!E>'1R
M86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@87)C:&EV92XB
M"FUS9W-T<B`BKF5L:F5N92!D871O=&5K92!N:2!B:6QO(&UO9V_H92!I>G9L
M9>AI(&EZ(%II<"!P<FEP;VYK92XB"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<S
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T
M:6]N(&9R;VT@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP
M:'`Z,S$T('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C$V,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(E5S='9A<FDB"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHV"FUS9VED(")#<F5A=&4@1F]L
M9&5R(@IM<V=S='(@(E5S='9A<FD@;6%P;R(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ,S<*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(E5S='9A
M<FD@:VQJ=>AE(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$T
M"FUS9VED(")#<F5A=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B57-T=F%R
M:2!N879I9&5Z;F\@;6%P;R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C
M;W5N=%]S96QE8W0N:6YC.C(V"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!.
M97<@06-C;W5N="(*;7-G<W1R(")$<G5G:2!R8>AU;FD@>F$@12UP;[ET;R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHQ,B!T96UP;&%T
M97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-R
M96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R(")5<W1V87)I(&YO=F\@
M;6%P;R!Z82!S;65T:2(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE
M8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(T
M"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R(")5
M<W1V87)I(&YO=F\@;6%P;R!Z82!O<VYU=&ME(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-E;G1M86EL<V5L96-T+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C0R"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M
M86EL(&9O;&1E<B(*;7-G<W1R(")5<W1V87)I(&YO=F\@;6%P;R!Z82!P;W-L
M86YO('!ON71O(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN
M8SHQ,B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS9VED
M(")#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(E5S='9A<FD@
M;F]V;R!M87!O('IA('-M971I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R.`IM<V=I9"`B(@HB0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T;R!O<F=A
M;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F;VQD97)S
M+"`B"B)A;F0@9&5L971E('-P86TN(@IM<V=S='(@(B(*(DYA<W1A=FET978@
M<')A=FEL(&9I;'1R:7)A;FIA('IA(&]R9V%N:7II<F%N:F4@=F&Y92!P<FEH
M86IA:F_H92!E+7!ON71E+"`B"B)S;W)T:7)A;FIE('8@;6%P92!I;B!B<FES
M86YJ92!N97IAOF5L96YE(&4M<&^Y=&4N(@H*(SH@=&5M<&QA=&5S+W-T871I
M;VYE<GDO<')E9G,N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@;F5W
M('-T871I;VYE<GDB"FUS9W-T<B`B57-T=F%R:2!N;W9O(&UA<&\@>F$@<&]S
M;&%N;R!P;[ET;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*;7-G
M:60@(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(E1R
M96YU=&5N(&1O<W1O<"!D;R`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#4*;7-G:60@(D-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@
M;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(*;7-G<W1R(").87-T879I(')A
MZ'5N92!Z82!S;F5M86YJ92!P;[ET92!Z(&1R=6=I:"!R8>AU;F]V+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0IM<V=I9"`B0W5S=&]M:7IE(&AO
M=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R(").87-T879I='9E(&YAZ&EN82!P
M;[EI;&IA;FIA(&4M<&^Y=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B3F%S=&%V:2!O<')A=FEL
M82P@:VD@<V4@>F&^96YE:F\@;V(@<')I:F%V:2!V("5S+B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*;7-G:60@(D1A
M=%]E(@IM<V=S='(@(D1A='5?;2(*"B,Z(&UE<W-A9V4N<&AP.C(V,B!T:')E
M860N<&AP.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R(")$871U;2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3<*;7-G:60@(D1E8VQI;F5D(@IM
M<V=S='(@(EIA=G)N:F5N;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HR-C,*(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B6F%V
M<FYJ96YO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ
M>0IM<V=I9"`B1&5F875L="(*;7-G<W1R("))>F)R:;EI(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C$X"FUS9VED(")$
M969A=6QT(%-E87)C:"!&:65L9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3(S"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R
M:6$Z(@IM<V=S='(@(E!R:79Z971A(')A>G9R<W1I=&5V.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,S,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D
M:7)E8W1I;VXZ(@IM<V=S='(@(E!R:79Z971A('-M97(@<F%Z=G)S=&ET=F4Z
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V-0IM<V=I9"`B1&5L
M96=A=&5D(@IM<V=S='(@(D1E;&5G:7)A;F\B"@HC.B!F;VQD97)S+G!H<#HT
M,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B27IB<FFY:2(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0=6)L
M:6,@2V5Y(@IM<V=S='(@(DEZ8G)IN6D@)7,@:F%V;FD@:VQJ=>@B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHX-0IM<V=I9"`B1&5L971E($-U<G)E;G0@2V5Y<R(*;7-G<W1R("))
M>F)R:;EI('1R96YU=&YE(&ML:G7H92(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.CD*;7-G:60@(D1E;&5T92!&;VQD97(H<RDB"FUS9W-T
M<B`B27IB<FFY:2!M87!O*&4I(@H*(SH@9F]L9&5R<RYP:'`Z,C@U"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R("))
M>F)R:;EI(&UA<&\H92DB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!3=&%T:6]N97)Y(@IM
M<V=S='(@(DEZ8G)IN6D@;F%V:61E>FYO(&UA<&\B"@HC.B!F;VQD97)S+G!H
M<#HT,3D*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("))
M>F)R:;EI(&YA=FED97IN;R!M87!O(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE9"!M97-S86=E
M<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@(DEZ8G)IN65M('!O<VYE
M=&$@<W!O<F_H:6QA('H@;V1D86QJ96YE9V$@<W1R9;YN:6MA/R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M
M(&UY(&-A;&5N9&%R(@IM<V=S='(@(DEZ8G)IN6D@:7H@;6]J96=A(&MO;&5D
M87)J82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(D1E
M;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M
M;VYT:#\B"FUS9W-T<B`B4&]B<FFY96T@<W1A<F4@<')I<&]N:V4@;F$@>F'H
M971K=2!M97-E8V$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM
M<V=I9"`B1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI
M;F<@;V8@;6]N=&@_(@IM<V=S='(@(E!O8G)IN65M('-T87)E(&UA<&4@<R!P
M;W-L86YO(&4M<&^Y=&\@;F$@>F'H971K=2!M97-E8V$_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-P
M86T@;65S<V%G97,B"FUS9W-T<B`B4&]B<FES86YA('-P;W)OZ&EL82(*"B,Z
M(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I
M9"`B1&5L971E9"(*;7-G<W1R(")0;V)R:7-A;F\B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM
M<V=S='(@(E!O8G)I<V%N82!S<&]R;^AI;&$B"@HC.B!C;VUP;W-E+G!H<#HS
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@871T86-H;65N
M="!<(B5S7"(N(@IM<V=S='(@(E!O8G)IN6D@<')I<&]N:V\@7"(E<UPB+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B1&5L971I;F<@
M86YD($UO=FEN9R!-97-S86=E<R(*;7-G<W1R(")"<FES86YJ92!I;B!P<F5M
M:6MA;FIE('-P;W)OZ&EL(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(EIA=G)N:2!Z86AT
M979O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T,`IM<V=I9"`B
M1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T
M<B`B6F%V<FYI('IA:'1E=F\@>F$@:6YF;W)M86-I:F\@<')O<W0O>F%S961E
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S(*;7-G:60@(D1E<V-E
M;F1I;F<B"FUS9W-T<B`B4&%D86IOZ"(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V%T=&%C:&UE;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C8Y"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")/<&ES(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS
M9VED(")$971A:6QS(@IM<V=S='(@(E!O9')O8FYO<W1I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8W-PIM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM
M<V=S='(@(EIA;65G;&EM('!O9'!I<V4_(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR,S8*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B
M4')I:V%Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W.0IM<V=I9"`B
M1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_
M(@IM<V=S='(@(E!R:6MAOF5M('!O=')D:71E=B!O('!O<VQA;F5M('-P;W)O
MZ&EL=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED(")$
M:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R(")0<FEK8;YI('8@
M=&5L97-U('-P;W)OZ&EL82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.3(*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@
M;6%I;#\B"FUS9W-T<B`B4')I:V&^96T@;VME;F-E('H@;V)V97-T:6QO;2!O
M(&YO=FD@<&^Y=&D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`HC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@;&EN
M:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B4')I:V&^96T@<&]V97IA=F\@
M)U-P<F%Z;FD@<VUE=&DG('8@;65N=6IU/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-3`*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP
M='D@5')A<VA<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R(")0<FEK
M8;YE;2!P;W9E>F%V;R`G4W!R87IN:2!S;65T:2<@=B!M96YU:G4_(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$Q"FUS9VED(")$
M:7-P;W-I=&EO;B(*;7-G<W1R(")$:7-P;WII8VEJ82(*"B,Z('1E;7!L871E
M<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA=&-H(@IM
M<V=S='(@(E-E($Y%('5J96UA(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R
M($YE=R!-86EL(@IM<V=S='(@(DYE('!R979E<FIA:B!M87`H92D@>F$@;F]V
M;R!E+7!ON71O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,@IM<V=I
M9"`B1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN
M(@IM<V=S='(@(DYE('5S='9A<FD@<&]V97IA=F4@>B!/9#H@<W1O;'!C82(*
M"B,Z(&QI8B])35`N<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P
M96X@=&AA="!F;VQD97(_(@IM<V=S='(@(D%L:2"^96QI=&4@;V1P<F5T:2!T
M;R!M87!O/R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,R"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C8*;7-G
M:60@(D1O;F4B"FUS9W-T<B`B2V]NZ&%N;R(*"B,Z(&QI8B]-24U%+T-O;G1E
M;G1S+G!H<#HQ.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,@
M:6X@+GII<"!&;W)M870B"FUS9W-T<B`B4')E;F5S:2`E<R!V("YZ:7`@;V)L
M:6MI(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3(*;7-G
M:60@(D1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*2(*
M;7-G<W1R(")0<F5S;F5M:2!V<V4@4')I<&]N:V4@*'8@+GII<"!D871O=&5K
M:2DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,`IM<V=I
M9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S='(@(E!R97-N96UI($UA<&\H
M92DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,0IM<V=I
M9"`B1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%TB"FUS9W-T<B`B
M4')E<VYE;6D@36%P;RAE*2!;+GII<"!O8FQI:V%=(@H*(SH@;&EB+TU)344O
M0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M
M870B"FUS9W-T<B`B4')E<VYE;6D@=B`N>FEP(&]B;&EK:2(*"B,Z(&UE<W-A
M9V4N<&AP.C4P,2!M86EL8F]X+G!H<#HW,3D@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHQ,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHY"FUS9VED(")$<F%F
M="(*;7-G<W1R(")/<VYU=&5K(@H*(SH@9F]L9&5R<RYP:'`Z,SDR"FUS9VED
M(")$<F%F="!F;VQD97(B"FUS9W-T<B`B36%P82!Z(&]S;G5T:VDB"@HC.B!T
M96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I9"`B1')A
M9G1S(&9O;&1E<CHB"FUS9W-T<B`B36%P82!Z(&]S;G5T:VDZ(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I9"`B12UM86EL($%D9')E<W,B
M"FUS9W-T<B`B12UP;[ET;FD@;F%S;&]V(@H*(SH@;&EB+TUA:6QB;W@N<&AP
M.C,P.0HC+"!F=7IZ>0IM<V=I9"`B14Y$(@IM<V=S='(@(DE.(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2.B!9;W5R
M(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B3D%0
M04M!.B!68;EE9V$@<W!O<F_H:6QA(&YI(&)I;&\@;6]G;^AE(&1O<W1A=FET
M:2XB"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S='(@(E5R961I(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET($)L
M86-K;&ES="(*;7-G<W1R(")5<F5D:2!";&%C:VQI<W0B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@1FEL=&5R<R(*
M;7-G<W1R(")5<F5D:2!&:6QT<F4B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$V"FUS9VED(")%9&ET(%9I<G1U
M86P@1F]L9&5R(@IM<V=S='(@(E5R961I($YA=FED97IN92!M87!E(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S
M(@IM<V=S='(@(E5R961I(&1E9FEN:6-I:F\@;F%V:61E>FYI:"!M87`@>F$@
M)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@
M(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(E5R961I(%=H:71E;&ES="(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!Y
M;W5R(&)L86-K;&ES="(*;7-G<W1R(")5<F5D:71E('-V;VH@8FQA8VML:7-T
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$S"FUS9VED(")%
M9&ET('EO=7(@9FEL=&5R(')U;&5S(@IM<V=S='(@(E5R961I=&4@<W9O:F$@
M<')A=FEL82!F:6QT<FER86YJ82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-C$*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S
M:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(E5R961I=&4@<W9O
M:F4@;F%S=&%V:71V92!Z82!D;W-T;W`@9&\@9')U9VEH('!ON71N:6@@;F%S
M;&]V;W8N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"FUS
M9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(E5R961I=&4@<W9O
M:B!W:&ET96QI<W0B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C(S.0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%+7!ON71N
M:2!N87-L;W8B"@HC.B!L:6(O365S<V%G92YP:'`Z-C4W"B,L('!H<"UF;W)M
M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S
M='(@(DEZ<')A>FYI;"!V<V$@<W!O<F_H:6QA(&EZ("5S(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D5M<'1Y($9O;&1E
M<BAS*2(*;7-G<W1R("))>G!R87IN:2!M87!O*&4I(@H*(SH@9F]L9&5R<RYP
M:'`Z,C@V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD97)S
M(@IM<V=S='(@(DEZ<')A>FYI(&UA<&\H92DB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@9F]L9&5R
M(@IM<V=S='(@(DEZ<')A>FYI(&UA<&\@<R!S;65T;6DB"@HC.B!L:6(O24U0
M+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%]3<&%M(@IM<V=S='(@
M(DEZ<')A>FYI(%]3;65T:2(*"B,Z(&QI8B])35`N<&AP.CDV-@IM<V=I9"`B
M16UP='D@7U1R87-H(@IM<V=S='(@(DEZ<')A>FYI(%]3;65T:2(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ('1E;7!L871E<R]P9W`O;F]T86-T:79E
M+FEN8SHV"FUS9VED(")%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S
M='(@(D]M;V=OZ&EM(%!'4#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B
M16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")/;6]G;^AI
M;2!3+TU)344_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q,0IM<V=I
M9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_(@IM<V=S='(@(D]M;V=OZ&D@
M<')E9&]G;&5D('-P;W)OZ&EL(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#0R"FUS9VED(")%;F-R7WEP=&EO;B!/<'1I;VYS(@IM<V=S
M='(@(DUOOFYO<W1I(*EI9G)I<F%N7VIA(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Q-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4W"FUS
M9VED(")%;F0B"FUS9W-T<B`B2V]N96,B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,S@T"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B2V]N
M96,@<&]S<F5D;W9A;F5G82!S<&]R;^AI;&$B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S0Q"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R(")+;VYE8R!S<&]R
M;^AI;&$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D5N9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B2V]N96,@<W!O
M<F_H:6QA(&]D("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW
M,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P
M:')A<V4B"FUS9W-T<B`B5G!IN6ET92!S=&%V96L@>F$@9V5S;&\B"@HC.B!T
M96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z.0HC+"!F=7IZ>0IM<V=I
M9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM
M<V=S='(@(E9P:;EI=&4@:6UE('9AN64@;F]V92!M87!E('IA('-M971I(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B
M16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS
M9W-T<B`B5G!IN6ET92!I;64@=F&Y92!N;W9E(&UA<&4@>B!O<VYU=&MI(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR,PIM<V=I
M9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD
M97(B"FUS9W-T<B`B5G!IN6ET92!I;64@=F&Y92!N;W9E(&UA<&4@<R!P;W-L
M86YO('!ON71O(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN
M8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@
M9F]L9&5R(@IM<V=S='(@(E9P:;EI=&4@:6UE('9AN64@;F]V92!M87!E('IA
M('-M971I(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@
M(D5N=&ER92!-97-S86=E(@IM<V=S='(@(E!R975S;65R:2!S<&]R;^AI;&\B
M"@HC.B!M97-S86=E+G!H<#HQ.30@8V]M<&]S92YP:'`Z,3$S-"!T:')E860N
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(%PB)7-<(B!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B5G!I<R!<(B5S7"(@:F4@8FEL('5S<&6Y;F\@9&]D86X@=B!!9')E<V%R
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ."!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS
M-S8@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S@V"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T<B`B3F%P86MA(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HT-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M8V]N;F5C=&EN9R!T;R!)34%0('-E<G9E<BX@)7,@.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,P.2!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-#`W"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R(").87!A:V$@<')I('!ON6EL
M:F%N:G4@;V1G;W9O<F$Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,#$*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*
M;7-G<W1R(")$;V=O9&5K('5S<&6Y;F\@:7IB<FES86XN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R(")6<V%K:6@@,34@;6EN=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S<Y"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(E9S
M86MI:"`S,"!S96MU;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q
M"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B5G-A:VEH(#4@;6EN
M=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@S"FUS9VED(")%=F5R
M>2!H86QF(&AO=7(B"FUS9W-T<B`B5G-A:V4@<&]L('5R92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R(")6<V%K;R!M:6YU=&\B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R(")287JY:7)I(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`B
M4F%ZN6ER:2!V<V4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHS.`IM<V=I9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(E)A>KEI
M<FD@=G-E(&UA<&4B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X<&%N
M9"!&;VQD97(B"FUS9W-T<B`B4F%ZN6ER:2!M87!O(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(E)A
M>KEI<FD@:6UE;F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V,PIM
M<V=I9"`B17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O
M;6%T:6-A;&QY(&EN('1H92!B86-K9W)O=6YD/R(*;7-G<W1R(")0<FD@;VMN
M=2!Z82!S97-T879L:F%N92!A=G1O;6%T:>AN;R!R87JY:7)I(&EM96YA('8@
M;WIA9&IU+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.#`*;7-G:60@
M(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@
M=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T<B`B4F%ZN6ER:6T@8V5L;W1N;R!D
M<F5V;R!P<FD@<&]G;&5D=2!M87`_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,30T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C$Y-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0IM<V=I9"`B17AP86YD
M:6YG(@IM<V=S='(@(E)A>KEI<F%N:F4B"@HC.B!L:6(O24U0+G!H<#HY.#0@
M;&EB+TE-4"YP:'`Z.3@V"B,L(&9U>GIY"FUS9VED(")&7V5T8V@@36%I;"(*
M;7-G<W1R(")&971C:"!-86EL(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F
M971C:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G
M:60@(D9E=&-H($UA:6PB"FUS9W-T<B`B1F5T8V@@36%I;"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-CD*;7-G:60@(D9E=&-H($UA:6P@:6X@82!S
M97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(D9E=&-H($UA:6P@=B!L;^AE;F5M
M(&]K;G4_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0V
M"FUS9VED(")&971C:"!M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S
M='(@(E!R96YE<V5M('-P;W)OZ&EL82!O8B!P<FEJ879I/R(*"B,Z(&QI8B]&
M971C:&UA:6PN<&AP.C(X.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S(@IM<V=S='(@(E!R97-N96P@
M)60@<W!O<F_H:6P@>B`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@
M9G)O;2`E<R(*;7-G<W1R(")0<F5S;F5L("5D('-P;W)OZ&EL('H@)7,B"@HC
M.B!L:6(O1F5T8VAM86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W
M(&QI8B]&971C:&UA:6PN<&AP.C(X.0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS
M9W-T<B`B1F5T8VAM86EL.B`B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*
M;7-G:60@(D9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")&
M971C:&UA:6PZ(&YI(&YO=FEH('-P;W)OZ&EL+B(*"B,Z(&QI8B])35`N<&AP
M.CDY,`IM<V=I9"`B1FE?;'1E<G,B"FUS9W-T<B`B1FE?;'1R:2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P,B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYJ<SHX,@IM<V=I9"`B1FEL92(*;7-G<W1R(")$
M871O=&5K82(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS,0IM
M<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B36^^;F]S=&D@1FEL=')O
M=B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHY"FUS9VED(")&
M:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`B3F%S=&%V:71V92!&:6QT<F]V(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P,`IM<V=I9"`B1FEL=&5R(&UE
M<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R(")&:6QT<FER
M86T@=G-E8FEN;R!S<&]R;^AI;"!Z82!V=6QG87)N92!B97-E9&4_(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B1FEL
M=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S
M='(@(E!O9'!O<F$@9FEL=')O;2!J92!N82!T96T@<VES=&5M=2!O;F5M;V=O
MZ&5N82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&
M:6QT97)S(@IM<V=S='(@(D9I;'1R:2(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+VYO=&%C=&EV92YI;F,Z,PIM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM
M<V=S='(@(D9I;'1R:2!.25-/(&%K=&EV;FDB"@HC.B!L:6(O1FEL=&5R+G!H
M<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E
M;65N="!P86=E(@IM<V=S='(@(D9I;'1R:3H@)7,@<W1R86X@>F$@=7!R879L
M:F%N:F4B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X
M-@IM<V=I9"`B1FEN9"(*;7-G<W1R(").86ID:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,#4*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G
M<W1R(")0<G9A('-T<F%N(&YA8FER86QN:6MA(@H*(SH@;6%I;&)O>"YP:'`Z
M,S0U"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(E!R=F$@<W1R86XB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O7W)W87)D
M(@IM<V=S='(@(DYA<%]R96HB"@HC.B!F;VQD97)S+G!H<#HR-C8@=&5M<&QA
M=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ-0IM<V=I9"`B1F]L
M9&5R($%C=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z,S`S('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD*(SH@
M=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHV"B,Z('1E
M;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@
M(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T<B`B4')E;6EK86YJ92!P;R!-87!A
M:"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(")&;VQD97(@
M4W5M;6%R>2(*;7-G<W1R(")/<&ES($UA<&4B"@HC.B!A8VPN<&AP.C(T"FUS
M9VED(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B
M36%P92!V('-K=7!N:2!R86)I(&YI<V\@;VUO9V_H96YE+B(*"B,Z(&9O;&1E
M<G,N<&AP.C8R"FUS9VED(")&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D+B(*
M;7-G<W1R(")5<&]R86)A(&UA<"!N:2!O;6]G;^AE;F$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B1F]R;6%T(&]F(&UE<W-A9V4@
M9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T960@
M=&]D87DB"FUS9W-T<B`B3V)L:6MA(&1A='5M;W8@>F$@9&%N8;EN:F$@<W!O
M<F_H:6QA('8@<&]G;&5D=2!N86)I<F%L;FEK82(*"B,Z(&-O;7!O<V4N<&AP
M.C<X,"!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O
M<G=A<F0B"FUS9W-T<B`B4&]S<F5D=6HB"@HC.B!C;VUP;W-E+G!H<#HW-C4*
M;7-G:60@(D9O<G=A<F0Z(@IM<V=S='(@(E!O<W)E9'5J.B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HS-CD*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S
M='(@(E!O<W)E9&]V86YO('-P;W)OZ&EL;R(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4@
M9G)O;2`E<R(*;7-G<W1R(")0;W-R961O=F%N;R!S<&]R;^AI;&\@;V0@)7,B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@S"FUS9VED(")&<F5E
M+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I:F$@4')O<W0O
M6F%S961E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.30*;7-G
M:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R(")/9&=O=F]R(%!R;W-T+UIA
M<V5D96XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@X"FUS9VED
M(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R("):86AT979A(%!R;W-T+UIA
M<V5D96XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Q"FUS9VED
M(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R(")/9&=O=F]R
M(&YA('IA:'1E=F\@4')O<W0O6F%S961E;B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R;U]M(@IM<V=S
M='(@(D]?9"(*"B,Z(&UE<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T.2!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H
M+G!H<#HR,@IM<V=I9"`B1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R
M(")/9"!N87-L;W8B"@HC.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP:'`Z
M-S@Q"FUS9VED(")&=V0Z(@IM<V=S='(@(D9W9#HB"@HC.B!C;VUP;W-E+G!H
M<#HQ,CDT"FUS9VED(")&=V0Z("(*;7-G<W1R(")&=V0Z(@H*(SH@8V]M<&]S
M92YP:'`Z,3(Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O<G=A
M<F1E9"!-97-S86=E<R(*;7-G<W1R(")&=V0Z("5U(%!O<W)E9&]V86YI:"!S
M<&]R;^AI;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1V5N97)A;"!/<'1I
M;VYS(@IM<V=S='(@(E-P;&^Y;F4@36^^;F]S=&DB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M
M97-S86=E<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B4')E;F5S96T@<V%M;R!N
M;W9A('-P;W)OZ&EL83\@*'-A;6\@24U!4"DB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHS,0IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@
M=&AR96%D+G!H<#HQ,S8*;7-G:60@(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B
M4&]J9&D@;F$@<W!O<F_H:6QO(@H*(SH@;&EB+TE-4"YP:'`Z-#DX"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")';R!T;R!A9&1R97-S(&)O;VL@96YT
M<GD@;V8@7"(E<UPB(@IM<V=S='(@(D1O9&%J('8@061R97-A<B`H)7,I(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@86-C
M97-S(@IM<V=S='(@(D]D;V)R:2!D;W-T;W`B"@HC.B!M97-S86=E+G!H<#HU
M-#8@;&EB+T9I;'1E<BYP:'`Z,3`U(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.CDU"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P,B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*
M(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(SH@;&EB+TU)344O5FEE
M=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M-#$X"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C<*
M;7-G:60@(DA%4D4B"FUS9W-T<B`B5%5+04HB"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$Q-PHC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@
M(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z(&-O;7!O<V4N<&AP.C(U-@IM<V=I
M9"`B2%1-3"!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B2%1-3"!R87IL
M:>AI8V$@<W!O<F_H:6QA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R
M<RYI;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B5G)S=&EC92!G;&%V
M92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z-0IM<V=I
M9"`B2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP;W-I;F<Z(@IM
M<V=S='(@(E1U:V%J(&IE('-P;W)OZ&EL;RP@:VD@<W1E(&=A('-E<W1A=FQJ
M86QI.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C@*;7-G:60@(DAI
M9&1E;B(*;7-G<W1R(")3:W)I=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C8W"FUS9VED(")(:61D96X@:6X@5&AR96%D(%9I97<B"FUS9W-T<B`B
M4VMR:71O('8@<&]G;&5D=2!0;V=O=F]R82(*"B,Z(&UA:6QB;W@N<&AP.C,V
M-PIM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@(E-K<FEJ($EZ8G)I<V%N
M82(*"B,Z(&9O;&1E<G,N<&AP.C(Y.`IM<V=I9"`B2&ED92!5;G-U8G-C<FEB
M960B"FUS9W-T<B`B4VMR:6H@3F5N87)OZ&5N92(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-`IM<V=I9"`B2&EG:"(*;7-G<W1R(")6
M:7-O:V$B"@HC.B!M97-S86=E+G!H<#HR.3<@;6%I;&)O>"YP:'`Z-S(T('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI9V@@4')I
M;W)I='DB"FUS9W-T<B`B5FES;VMA('!R:6]R:71I=&$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS
M9W-T<B`B3F%J=FFY:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X
M"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT
M<S\B"FUS9W-T<B`B2V%K;R"^96QI=&4@<')I:V%Z871I('!R:7!O;FME/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*;7-G:60@(DAO=R!T;R!A
M='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`B2V%K
M;R!P;VYA>F]R:6T@8VET:7)A;F4@=G)S=&EC92!V(&]D9V]V;W)U(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T
M<B`B24U!4"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(Y"FUS9VED
M("))34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(DE-05`@
M*'IA>FYA:B!P<F]T;VMO;"DB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@=&AE
M(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38V(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V97(@4U-,(@IM<V=S='(@
M(DE-05`@<')E:V\@4U-,(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M-3(*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC
M871E*2(*;7-G<W1R("))34%0('!R96MO(%-33"`H<V%M;RUP;V1P:7-A;F\@
M<&]T<F1I;&\I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C<*
M;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R("))
M34%0('!R96MO(%-33"`H<V%M;RUP;V1P:7-A;BDB"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C,V.`HC+"!F=7IZ>0IM<V=I9"`B24U!4"!S97)V97(@8VQO
M<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R(")4:7`@<W1R9;YN:6MA('IA
M('!O=F5Z879O.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38U
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS9VED("))34%0+"!N;R!4
M3%,B"FUS9W-T<B`B24U!4"P@8G)E>B!43%,B"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C0Y"FUS9VED("))34%0+U!/4#,@36%I;"!397)V97)S(@IM
M<V=S='(@(DE-05`O4$]0,R!0;[ET;FD@4W1R9;YN:6MI(@H*(SH@;&EB+TE-
M4"YP:'`Z.#8V"FUS9VED("))3D)/6"(*;7-G<W1R("))3D)/6"(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@;W(@
M5$Q3+"!Y;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD
M97)S7V-O;F9I<FTN:'1M;#HQ,@HC+"!F=7IZ>0IM<V=I9"`B268@>6]U(&-O
M;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E
M(&QO<W0A(@IM<V=S='(@(E9S82!S<&]R;^AI;&$@=B!M87!I*&%H*2!B;V1O
M(&EZ9W5B;&IE;F$A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T<B`B4')E>G)I(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@S"FUS9VED("))9VYO<F4@
M06QL(@IM<V=S='(@(E!R97IR:2!V<V4B"@HC.B!T96UP;&%T97,O<V%V96EM
M86=E+W-A=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,`IM<V=I9"`B26UP
M;W)T(@IM<V=S='(@(E5V;WII(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C4*
M;7-G:60@(DEM<&]R="!+97DB"FUS9W-T<B`B579O>FD@:VQJ=>@B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y"FUS9VED("));7!O<G0@2V5Y<&%I
M<B(*;7-G<W1R(")5=F]Z:2!P87(@:VQJ=>AE=B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C(W"B,L(&9U>GIY"FUS9VED("));7!O<G0@
M365S<V%G97,B"FUS9W-T<B`B4&]M96UB;F$@<W!O<F_H:6QA(@H*(SH@<&=P
M+G!H<#HT,@IM<V=I9"`B26UP;W)T(%!'4"!+97DB"FUS9W-T<B`B579O>FD@
M4$=0(&ML:G7H(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0HC
M+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E(@IM
M<V=S='(@(E5V;WII($]S96)N82!P;W1R9&EL82(*"B,Z('1E;7!L871E<R]P
M9W`O:6UP;W)T7VME>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0
M<FEV871E(%!'4"!+97DB"FUS9W-T<B`B579O>FD@;W-E8FYI(%IA<V5B;FD@
M4$=0(&ML:G7H(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHY
M"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB"FUS9W-T
M<B`B579O>FD@;W-E8FYI($IA=FYI(%!'4"!K;&IUZ"(*"B,Z('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4&5R<V]N
M86P@4R]-24U%($-E<G1I9FEC871E<R(*;7-G<W1R(")5=F]Z:2!O<V5B;F\@
M4R]-24U%('!O=')D:6QO(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHT,"!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#(*;7-G:60@(DEM<&]R="!0
M=6)L:6,@2V5Y(@IM<V=S='(@(E5V;WII($IA=FYI(&ML:G7H(@H*(SH@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4'5B
M;&EC(%!'4"!+97DB"FUS9W-T<B`B579O>FD@2F%V;FD@4$=0(&ML:G7H(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@*;7-G:60@(DEM
M<&]R="!0=6)L:6,@4R]-24U%($ME>2(*;7-G<W1R(")5=F]Z:2!*879N:2!3
M+TU)344@:VQJ=>@B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3
M+TU)344@2V5Y(@IM<V=S='(@(E5V;WII(%,O34E-12!K;&IUZ"(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB
M;W@@1FEL92(*;7-G<W1R(")5=F]Z:2!M8F]X(&1A=&]T96MO(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G
M<W1R(")5=F]Z:2!M8F]X(&1A=&]T96MO("5S('8@;6%P;R`E<RXB"@HC.B!M
M97-S86=E+G!H<#HU,#(@;6%I;&)O>"YP:'`Z-S,T('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-PHC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C$V('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,S,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHW"FUS9VED("))
M;7!O<G1A;G0B"FUS9W-T<B`B4&]M96UB;F\B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@;65S<V%G97,B"FUS
M9W-T<B`B4&]M96UB;F$@<W!O<F_H:6QA(@H*(SH@9F]L9&5R<RYP:'`Z,38W
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S(&9R
M;VT@)7,N(@IM<V=S='(@(E5V;WII;"`E9"!S<&]R;^AI;"!I>B`E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS9VED("));B!0<F]C
M97-S(@IM<V=S='(@(E8@=&5K=2(*"B,Z(&9O;&1E<G,N<&AP.C,X-"!L:6(O
M1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-4"YP:'`Z
M,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4<F5E+G!H
M<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(DEN8F]X(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Y,@IM<V=I9"`B26YC;'5D92!A(&)R:65F('-U
M;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A(')E<&QY/R(*;7-G<W1R(")6:VQJ
M=>AI;2!K<F%T96L@<&]V>F5T96L@9VQA=F4@=B!O9&=O=F]R/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#<*;7-G:60@(DEN8VQU9&4@;W)I9VEN
M86P@;65S<V%G92!I;B!A(')E<&QY/R(*;7-G<W1R(")6:VQJ=>AI;2!I>G9O
M<FYO('-P;W)OZ&EL;R!V(&]D9V]V;W(_(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R+W-T871U<RYP
M:'`Z,3,P"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L
M:6,@2V5Y(@IM<V=S='(@(DEN9F]R;6%C:6IE(&\@)7,@2F%V;F5M(&ML:G7H
M=2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M
M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B26YF;W)M
M86-I:F4@;R!O<V5B;F5M(%IA<V5B;F5M(&ML:G7H=2(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R
M"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(DEN9F]R;6%C:6IE(&\@;W-E8FYE;2!*879N96T@:VQJ=>AU(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYJ<SHY.`IM<V=I9"`B26YL:6YE(@IM<V=S='(@
M(EIN;W1R86HB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M.0IM<V=I9"`B26YS97)T($-E<G1I9FEC871E($AE<F4B"FUS9W-T<B`B5'5K
M86H@=G-T879I(%!O=')D:6QO(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?
M:V5Y+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A=&4@4$=0
M($ME>2!(97)E(@IM<V=S='(@(E1U:V%J('9S=&%V:2!O<V5B;FD@6F%S96)E
M;B!01U`@:VQJ=>@B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC
M.C$P"FUS9VED("));G-E<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D@2&5R
M92(*;7-G<W1R(")4=6MA:B!V<W1A=FD@;W-E8FYI($IA=FYI(%!'4"!K;&IU
MZ"(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-0IM<V=I9"`B
M26YS97)T(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B5'5K86H@=G-T
M879I($IA=FYI(%!'4"!K;&IUZ"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT,3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T
M:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`B6F$@=&\@:V]M<&]N96YT;R!J92!B
M:6QO(&EZ8G)A;F\@;F5P<F%V:6QN;R!D96IA;FIE(@H*(SH@;6%I;&)O>"YP
M:'`Z-3@T(&UA:6QB;W@N<&AP.C8R-@IM<V=I9"`B26YV86QI9"!!9&1R97-S
M(@IM<V=S='(@(DYE<')A=FEL96X@3F%S;&]V(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B
M"FUS9W-T<B`B3F5P<F%V:6QE;B!O9&1A;&IE;B!N86)I<F%L;FEK(@H*(SH@
M8V]M<&]S92YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@
M8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B3F5V
M96QJ879E;B!Z;F%K('8@92UP;[ET;F5M(&YA<VQO=G4Z("5S(@H*(SH@<VUI
M;64N<&AP.C@R('!G<"YP:'`Z,38*;7-G:60@(DEN=F%L:60@:V5Y(@IM<V=S
M='(@(DYE=F5L:F%V96X@:VQJ=>@B"@HC.B!P9W`N<&AP.C$Y-@IM<V=I9"`B
M26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN(@IM<V=S='(@(DYE
M=F5L:F%V96X@;W-E8FYI(%!'4"!Z87-E8FYI(&ML:G7H+B(*"B,Z('!G<"YP
M:'`Z,3<Q"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y
M+B(*;7-G<W1R(").979E;&IA=F5N(&]S96)N:2!01U`@:F%V;FD@:VQJ=>@N
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B
M26YV97)T(@IM<V=S='(@(D]B<FYI(&EZ8F]R(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3<W"FUS9VED(")+0B(*;7-G<W1R(")+0B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B1&]LOFEN82!K;&IUZ&$B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K
M92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y
M("(*(F=E;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED
M(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES
M(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE
M+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U
M<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G
M:60@(DME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B2VQJ=>@@=7-P9;EN;R!P;W-L86X@;F$@:F%V;FD@
M<W1R9;YN:6L@<R!K;&IUZ&DN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,38*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DIE>FEK(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-@IM<V=I9"`B3&%S="!-86EL8F]X
M(%!A9V4B"FUS9W-T<B`B6F%D;FIA('-T<F%N(&YA8FER86QN:6MA(@H*(SH@
M;6%I;&)O>"YP:'`Z,S4X"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`B6F%D
M;FIA('-T<F%N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,S@Y"FUS9VED("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R(")0;W9EOFD@
M4')I<&]?;FME(@H*(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N
M<&AP.C$P-C,*;7-G:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED
M9&5N+B(*;7-G<W1R(")0;W9E>F%N92!P<FEP;VYK92!N:7-O(&1O=F]L:F5N
M92XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3`X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("),:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X,@IM<V=I9"`B(@HB3&ES="!A;&P@
M8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI
M9B!D:7-A8FQE9"P@>6]U('=I;&P@(@HB;VYL>2!S964@8V]N=&%C=',@=&AA
M="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*2(*;7-G<W1R("(B"B)0<FEK
M8;YE;2!V<V4@<W1I:V4L(&MO(&YA;&%G86T@>F%S;&]N(',@<W1I:VD_("CH
M92!J92!M;[YN;W-T(&]N96UO9V_H96YA("(*(F)O<W1E=FED96QI('-A;6\@
M<W1I:V4L(&MI(&II:"!S86UI(&EZ<F5C;F\@:;GH971E*2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV.#4*;7-G:60@(DQI<W1I;F<@:6X@=&AE($AE
M861E<B(*;7-G<W1R(")397IN86T@=B!G;&%V:2(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHS,`IM<V=I9"`B3&]C86P@36%I;&)O>#HB
M"FUS9W-T<B`B3&]K86QN:2!.86)I<F%L;FEK.B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-S0*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DQO
M:V%C:6IA(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C4*;7-G
M:60@(DQO9R!I;B(*;7-G<W1R(")0<FEJ879A(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("),;V<@:6X@=&\@
M)7,B"FUS9W-T<B`B4')I:F%V82!V("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,S<*;7-G:60@(DQO9VEN(@IM<V=S='(@(E!R:6IA=F$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(DQO9VEN(%1A
M<VMS(@IM<V=S='(@(D]P<F%V:6QA(&]B('!R:6IA=FDB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.38*;7-G:60@(DQO=R(*;7-G<W1R
M(").:7IK82(*"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X+G!H<#HW,C<@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B3&]W(%!R
M:6]R:71Y(@IM<V=S='(@(DYI>FMA(%!R:6]R:71E=&$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3<*;7-G:60@(DQO=V5S="(*;7-G
M<W1R(").86IN:;YJ82(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L
M92YP:'`Z-#0*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM<V=S='(@(DUA8VEN
M=&]S:"!$871O=&5K82(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E
M+FEN8SHQ,PIM<V=I9"`B36%I;"(*;7-G<W1R(")0;[ET82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G
M<W1R(")0<F5D;V=L960@4&^Y=&4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V1R:79E<E]S96QE8W0N:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E
M('1O(&-O;FYE8W0@=&\Z(@IM<V=S='(@(E1I<"!S=')EOFYI:V$@>F$@<&]V
M97IA=F\Z(@H*(SH@9F]L9&5R<RYP:'`Z-#`R"FUS9VED(")-86EL8F]X(@IM
M<V=S='(@(DYA8FER86QN:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$Q"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS
M(@IM<V=S='(@(DUOOFYO<W1I('!R:6MA>F$@3F%B:7)A;&YI:V]V(&EN($UA
M<"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X"FUS9VED
M(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G<W1R
M(")/>FYAZ&D@=G-A('-P;W)OZ&EL82!V(&UA<&D@:V]T(%9I9&5N82(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")-87)K
M($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM<V=S='(@(D]Z
M;F'H:2!V<V$@<W!O<F_H:6QA('8@;6%P:2!K;W0@3F4M=FED96YA(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHU('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM
M<V=S='(@(D]Z;F'H:2!K;W0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8U,`IM<V=I9"`B36%R:R!D:69F97)E;G0@;&5V96QS(&]F('%U;W1I;F<@
M=VET:"!D:69F97)E;G0@8V]L;W)S/R(*;7-G<W1R(")/>FYAZ&EM(')A>FQI
MZ&YE(&YI=F]J92!C:71I<F%N:F$@>B!R87IL:>AN:6UI(&)A<G9A;6D_(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-
M87)K(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI(@IM<V=S='(@(D]Z
M;F'H:6T@<W!O<F_H:6QA(&MO="!V:61E;F$_("AS86UO($E-05`I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U.`IM<V=I9"`B36%R:R!S:6UP;&4@
M;6%R:W5P/R(*;7-G<W1R(")/>FYAZ&EM('!R97!R;W-T;R!O8FQI:V]V86YJ
M93\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@
M(DUA=&-H($%L;"!1=65R:65S(@IM<V=S='(@(E!R:6MAOFD@=G-E('!O:7IV
M961B92(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT,@IM<V=I
M9"`B36%T8V@@06YY(%%U97)Y(@IM<V=S='(@(E!R:6MAOFD@:V%T97)O:V]L
M:2!P;VEZ=F5D8F\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU,3,*;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM<V=S='(@
M(DYA:G9EZ&IA('9E;&EK;W-T('!R:7!O;FME(@H*(SH@;&EB+V%P:2YP:'`Z
M-SD*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B
M"FUS9W-T<B`B3F%J=F7H:F4@N71E=FEL;R!P<FEP;VYK(&1O<V6^96YO+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-`IM<V=I9"`B
M36%X:6UU;2!N=6UB97(@;V8@871T86-H;65N=',@<F5A8VAE9"XB"FUS9W-T
M<B`B3F%J=F7H:F4@N71E=FEL;R!P<FEP;VYK(&1O<V6^96YO+B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X.0IM<V=I9"`B36%X:6UU
M;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE9"XB"FUS9W-T<B`B3F%J
M=F7H:F$@<VMU<&YA('9E;&EK;W-T('!R:7!O;FL@9&]S9;YE;F$N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B365E=&EN9R!#
M86YC96QL871I;VXB"FUS9W-T<B`B3V1P;W9E9"!S97-T86YK82(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S4*;7-G:60@(DUE971I;F<@26YF
M;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I:F4@;R!S97-T86YK=2(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I;F<@
M4')O<&]S86PB"FUS9W-T<B`B4')E9&QO9R!Z82!S97-T86YE:R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3<*;7-G:60@(DUE971I;F<@4F5P
M;'DB"FUS9W-T<B`B3V1G;W9O<B!O('-E<W1A;FMU(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4Y.`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS
M9W-T<B`B3F]V92!I;F9O<FUA8VEJ92!O('-E<W1A;FMU(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8P,PIM<V=I9"`B365E=&EN9R!5<&1A=&4@
M4F5Q=65S="(*;7-G<W1R("):86AT979A('!O(&YO=FEH(&EN9F]R;6%C:6IA
M:"!O('-E<W1A;FMU(@H*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z
M,PIM<V=I9"`B365N=2!&;VQD97(@3&ES="(*;7-G<W1R(")-96YU('-E>FYA
M;6$@36%P(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S<V%G
M92(*;7-G<W1R(")3<&]R;^AI;&\B"@HC.B!C;VUP;W-E+G!H<#HU-C`@8V]M
M<&]S92YP:'`Z-3@W(&-O;7!O<V4N<&AP.C8T,2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S:71I;VXB"FUS9W-T<B`B
M4V5T879L:F%N:F4@4W!O<F_H:6QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(D1A='5M(%-P
M;W)OZ&EL82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PIM<V=I9"`B365S<V%G
M92!/<'1I;VYS(@IM<V=S='(@(DUOOFYO<W1I(%-P;W)OZ&EL82(*"B,Z('-E
M87)C:"YP:'`Z,S$R"FUS9VED(")-97-S86=E(%-E87)C:"(*;7-G<W1R("))
M<VMA;FIE(%-P;W)OZ&EL82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,C$*;7-G:60@(DUE<W-A9V4@4VEZ92(*;7-G<W1R(")696QI:V]S="!3<&]R
M;^AI;&$B"@HC.B!M97-S86=E+G!H<#HS.#0*;7-G:60@(DUE<W-A9V4@4V]U
M<F-E(@IM<V=S='(@(DEZ=F]R;F$@:V]D82!3<&]R;^AI;&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(DUE<W-A9V4@5FEE=VEN9R(*
M;7-G<W1R(")0<F5G;&5D(%-P;W)OZ&EL82(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z-@IM<V=I9"`B365S<V%G92!F;&%G<R(*;7-G<W1R(")/
M>FYA:V4@4W!O<F_H:6QA(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM<V=S='(@(DUA<&4@<W!O
M<F_H:6PB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")3<&]R;^AI;&\@;V0@
M)7,B"@HC.B!M86EL8F]X+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(DUE<W-A
M9V4@:&%S(&%T=&%C:&UE;G1S(@IM<V=S='(@(E5J96UA;FIE('-P;W)OZ&EL
M82(*"B,Z(&UA:6QB;W@N<&AP.C8U.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G
M92!I<R!E;F-R>7!T960B"FUS9W-T<B`B4&]L:F$@4W!O<F_H:6QA(@H*(SH@
M;6%I;&)O>"YP:'`Z-C4S"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES('-I
M9VYE9"(*;7-G<W1R(")0;VQJ82!3<&]R;^AI;&$B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z,S,*;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*
M;7-G<W1R(")5:F5M86YJ92!S<&]R;^AI;&$B"@HC.B!C;VUP;W-E+G!H<#HX
M,C0@8V]M<&]S92YP:'`Z.#,X"FUS9VED(")-97-S86=E(')E9&ER96-T960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")3<&]R;^AI;&\@=7-P9;EN;R!P<F5U
M<VUE<FIE;F\N(@H*(SH@8V]M<&]S92YP:'`Z,3`X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A
M=F5D('1O("5S(@IM<V=S='(@(E-P;W)OZ&EL;R!U<W!EN6YO('!O<VQA;F\L
M('9E;F1A<B!N:2!B:6QO('-H<F%N:F5N;R!V("5S(@H*(SH@8V]M<&]S92YP
M:'`Z,3$T,R!C;VUP;W-E+G!H<#HQ,34X"FUS9VED(")-97-S86=E('-E;G0@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")3<&]R;^AI;&\@=7-P9;EN;R!P;W-L
M86YO+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE
M<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@
M(E-P;W)OZ&EL(&YA('-T<F%N('8@<&]G;&5D=2!N86)I<F%L;FEK82XB"@HC
M.B!M86EL8F]X+G!H<#HS,C(*;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S='(@
M(E-P;W)OZ&EL82!Z82(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM
M<V=I9"`B36]D:69Y(@IM<V=S='(@(E-P<F5M96YI(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O97AP86YD+FEN8SHQ,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<
M(B5S7"(N(@IM<V=S='(@(EIA('!O;&IE("<E<R<@:F4@8FEL(&YA:F1E;B!V
M9>@@:V]T(&5N(&YA<VQO=BXB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z-3`*;7-G:60@(DUO=F4B"FUS9W-T<B`B4')E;6%K;FDB"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,38*;7-G:60@(DUO=F4@
M9&]W;B(*;7-G<W1R(")0<F5M86MN:2!D;VPB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C$X"FUS9VED(")-;W9E('-P86T@;65S<V%G97,@=&\@<W!A
M;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM<V=I9"`B
M36]V92!T;R!F;VQD97(B"FUS9W-T<B`B4')E;6%K;FD@=B!M87!O(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$T"FUS9VED(")-
M;W9E('5P(@IM<V=S='(@(E!R96UA:VYI(&=O<B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(W"FUS9VED(")-=6QT:7!A<G0O86QT
M97)N871I=F4B"FUS9W-T<B`B5F7H9&5L;F\O86QT97)N871I=FYO(@H*(SH@
M=&AR96%D+G!H<#HW-B!T:')E860N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B
M375L=&EP;&4@365S<V%G92!6:65W(@IM<V=S='(@(E!R96=L960@4W!O<F_H
M:6QA(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N
M:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DY/3D4B"FUS9W-T<B`B0D5,1:Y+02(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT."!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`B0D5,1:Y+02(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV.#@*;7-G:60@(DYA;64B"FUS9W-T<B`B26UE(@H*(SH@<&=P
M+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@
M96UP='DB"FUS9W-T<B`B26UE(&EN+V%L:2!E+7!ON71A(&YE('-M971A(&)I
M=&D@<')A>FYA(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W.`IM
M<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(E!O=')E8G5J92!U:W)E<"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S`@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4X,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<X"FUS9VED
M(").979E<B(*;7-G<W1R(").:6MO;&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-38P"FUS9VED(").979E<B!S879E(&%T=&%C:&UE;G1S(@IM<V=S
M='(@(DYI:V]L:2!N92!S:')A;FD@<')I<&]N:R(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ,C0*;7-G:60@(DYE=R(*;7-G<W1R(").;W8B"@HC.B!L
M:6(O24U0+G!H<#HU-C,*;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T<B`B3F]V
M82!M87!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").
M97<@36%I;"(*;7-G<W1R(").;W9A($4M<&^Y=&$B"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,S,*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!-97-S86=E(@IM<V=S='(@(DYA<VQE9&YJ
M92!S<&]R;^AI;&\B"@HC.B!M86EL8F]X+G!H<#HW-S8@;&EB+TU)344O2&5A
M9&5R<RYP:'`Z,3DR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@
M365S<V%G92!T;R`E<R(*;7-G<W1R(").;W9A('-P;W)OZ&EL82(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E
M<R(*;7-G<W1R(").;W9A('-P;W)OZ&EL82(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(DYE>'0B"FUS9W-T<B`B3F%P
M<F5J(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHS,PIM<V=I9"`B3F5X="!-97-S86=E(@IM<V=S='(@(DYA<VQE9&YJ92!S
M<&]R;^AI;&\B"@HC.B!M86EL8F]X+G!H<#HS-38*;7-G:60@(DYE>'0@4&%G
M92(*;7-G<W1R(").87-L961N:F$@<W1R86XB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW
M-PIM<V=I9"`B3F\B"FUS9W-T<B`B3F4B"@HC.B!S;6EM92YP:'`Z,C(V"FUS
M9VED(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R(").:2!P;W1R9&EL
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHU"FUS
M9VED(").;R!%;F-R>7!T:6]N(@IM<V=S='(@(D)R97H@N6EF<FER86YJ82(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I
M;B!+97ER:6YG(@IM<V=S='(@(DYI(&ML:G7H978B"@HC.B!M86EL8F]X+G!H
M<#HS-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B"FUS9W-T
M<B`B3FD@<W!O<F_H:6PB"@HC.B!P9W`N<&AP.C$S-PIM<V=I9"`B3F\@4$=0
M('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DYO8F5N(&IA=FYI(%!'
M4"!K;&IUZ"!N:2!B:6P@=79OOF5N+B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC871E(%!R
M97-E;G0B"FUS9W-T<B`B3FD@;W-E8FYI:"!P;W1R9&EL(@H*(SH@;&EB+TUA
M:6QB;W@N<&AP.C,R.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT
M(@IM<V=S='(@(E!R961O9VQE9"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,34*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@
M(DYI(&IA=FYI:"!K;&IUZ&5V(@H*(SH@<VUI;64N<&AP.C$U,0IM<V=I9"`B
M3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DYO8F5N
M(&IA=FYI(%,O34E-12!K;&IUZ"!N:2!B:6P@=79OOF5N+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]T;F5F+G!H<#HY,`IM<V=I9"`B3F\@871T86-H;65N=',@
M9F]U;F0N(@IM<V=S='(@(DYI('!R:7!O;FLN(@H*(SH@;&EB+T-R>7!T+U--
M24U%+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(DYO(&5M86EL(&EN9F]R;6%T
M:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K97DN(@IM<V=S='(@(DEN9F]R
M;6%C:6IE(&\@)7,@2F%V;F5M(&ML:G7H=2(*"B,Z(&%C;"YP:'`Z-S(@86-L
M+G!H<#HY.`IM<V=I9"`B3F\@9F]L9&5R('-E;&5C=&5D+B(*;7-G<W1R(").
M;V)E;F$@;6%P82!N:2!I>F)R86YA+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ-#$*;7-G:60@(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@
M9F]R(&YE=R!M86EL+B(*;7-G<W1R(").;V)E;F4@;6%P92!S92!N92!P<F5V
M97)J82!Z82!N;W9O('!ON71O+B(*"B,Z(&9O;&1E<G,N<&AP.C(Q."!L:6(O
M1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED(").;R!F
M;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(DYO8F5N82!M87!A(&YI
M(&)I;&$@<&]D86YA(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T-PIM
M<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<R(*;7-G<W1R(").
M;V)E;F$@;6%P82!N92!V<V5B=6IE(&YO=FEH('-P;W)OZ&EL(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C$T-`IM<V=I9"`B3F\@9F]L9&5R<R!W:71H
M('5N<V5E;B!M97-S86=E<R(*;7-G<W1R(").;V)E;F$@;6%P82!N92!V<V5B
M=6IE(&YE=FED96YI:"!S<&]R;^AI;"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M,C4*;7-G:60@(DYO(&UE<W-A9V4@8F]D>2!T97AT(@IM<V=S='(@(E1E;&\@
M<W!O<F_H:6QA(&YE('9S96)U:F4@8F5S961I;&$B"@HC.B!L:6(O36%I;&)O
M>"YP:'`Z,S<Q"FUS9VED(").;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A
M<F-H+B(*;7-G<W1R(").;V)E;F\@<W!O<F_H:6QO('-E(&YE('5J96UA('H@
M:7-K86YI;6D@<&]G;VII+B(*"B,Z('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P
M97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N(@IM<V=S='(@(DYO
M8F5N(&]S96)N:2!:87-E8FYI(%!'4"!K;&IUZ"!N:2!B:6P@=79OOF5N+B(*
M"B,Z('!G<"YP:'`Z,38U"FUS9VED(").;R!P97)S;VYA;"!01U`@<'5B;&EC
M(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B3F]B96X@;W-E8FYI($IA=FYI(%!'
M4"!K;&IUZ"!N:2!B:6P@=79OOF5N+B(*"B,Z('-M:6UE+G!H<#HR,#$*;7-G
M:60@(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP;W)T960N
M(@IM<V=S='(@(DYO8F5N;R!O<V5B;F\@4R]-24U%('!O=')D:6QO(&YI(&)I
M;&\@=79OOF5N;RXB"@HC.B!S<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").;R!S
M<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`B3F]B
M96X@<')O9W)A;2!Z82!P<F5V97)J86YJ92#H<FMO=F%N:F$@;FD@8FEL(&MO
M;F9I9W5R:7)A;BXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-#@*;7-G:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(").:2#H
M<FMO=F%L;FEH(&YA<&%K(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B3FD@
M<')E9&QO9V]V(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-C0*;7-G:60@
M(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!C;W5L
M9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HV."!A8VPN<&AP
M.CDT"FUS9VED(").;R!U<V5R('-P96-I9FEE9"XB"FUS9W-T<B`B57!O<F%B
M;FEK(&YI(&)I;"!P;V1A;BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S`Y"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`B3FD@=61E
M;&6^96YE8R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@
M=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,`HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-2!T96UP;&%T97,O<')E
M9G,O<W!A;7-E;&5C="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8V-`IM<V=I9"`B3F]N92(*;7-G<W1R(").;V)E;F5G82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-0IM<V=I9"`B3F]R;6%L
M(@IM<V=S='(@(DYA=F%D;F$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G
M:60@(DYO="!$96QE=&5D(@IM<V=S='(@(DYI('!O8G)I<V%N;R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3(@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@1')A9G0B"FUS9W-T<B`B3FD@
M3W-N=71E:R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$W"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@(DYO="!);7!O
M<G1A;G0B"FUS9W-T<B`B3F5P;VUE;6)N;R(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,C4*;7-G:60@(DYO="!097)S;VYA;"(*;7-G<W1R
M(").:2!/<V5B;F\B"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HQ,SD@;&EB+T-R
M>7!T+U--24U%+G!H<#HQ,S0@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#D*;7-G
M:60@(DYO="!A('9A;&ED('!U8FQI8R!K97DN(@IM<V=S='(@(DYI('9E;&IA
M=F5N(&IA=FYI(&ML:G7H+B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z-C<*;7-G:60@(DYO="!D96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(DYI
M<V\@:7IB<FES86YA('-P;W)OZ&EL82(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A;G0@;65S<V%G97,B"FUS
M9W-T<B`B3FES;R!P;VUE;6)N82!S<&]R;^AI;&$B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C<Q"FUS9VED(").;W1E
M('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I;64B"FUS9W-T<B`B1&5J86YJ
M92!L86AK;R!T<F%J82!D86QJ(.AA<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C$V"FUS9VED(").;W1H:6YG(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DYU;6)E<B!O9B!M;VYT:',@
M=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO
M;G1H;'DN(@IM<V=S='(@(JET979I;"!M97-E8V5V('!R961E;B!P;V)R:;EE
M;2!S=&%R92!P<FEP;VYK92P@Z&4@:FEH(&)R:;EE;2!M97-EZ&YO+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*;7-G:60@(DYU;6)E<B!O9B!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT
M:&QY+B(*;7-G<W1R("(B"B*I=&5V:6P@;65S96-E=B!P<F5D96X@<&]B<FFY
M96T@;6%P92!S('!O<VQA;F\@<&^Y=&\L(.AE(&II:"!B<FFY96T@;65S9>AN
M;RXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-"!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW,S,*;7-G:60@(D]+(@IM<V=S='(@(E8@<F5D=2(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHT.0HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K
M97DN:6YC.C0X"FUS9VED(")/4B(*;7-G<W1R(")!3$DB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$U"FUS9VED(")/;&0@;65S<V%G97,B"FUS
M9W-T<B`B4W1A<F$@<W!O<F_H:6QA(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C4R"FUS9VED(")/;&0@
M<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D+B(*;7-G<W1R(")3=&%R
M92!M87!E(',@<&]S;&%N;R!P;[ET;R!S92!B<FFY96IO+B(*"B,Z(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E
M<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T<B`B4')I
M:V&^96T@<V%M;R!M87!E('H@;F5P<F5B<F%N:6UI('-P;W)OZ&EL:3\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"FUS9VED(")/
M;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C
M=&EO;BXB"FUS9W-T<B`B6F$@=&\@9&5J86YJ92!J92!L86AK;R!I>F)R86YA
M('-A;6\@96YA(&UA<&$N(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$P('1E
M;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E;B!&;U]L
M9&5R(@IM<V=S='(@(D]D<')I($UA<&\B"@HC.B!F;VQD97)S+G!H<#HT,C<*
M;7-G:60@(D]P96YE9"!&;VQD97(B"FUS9W-T<B`B3V1P<G1A($UA<&$B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`U"FUS9VED(")/<'1I;VYA
M;"!087)T:6-I<&%N="(*;7-G<W1R(")0;V=O:FYI('5D96QEOF5N96,B"@HC
M.B!F971C:&UA:6PN<&AP.C,S('1E;7!L871E<R]F971C:&UA:6PO=&]P+FEN
M8SHS"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHV"FUS
M9VED(")/=&AE<B!-86EL($%C8V]U;G1S(@IM<V=S='(@(D1R=6=I(')AZ'5N
M:2!Z82!%+7!ON71O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3`*
M;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B1')U9V4@;6^^;F]S=&DB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,0IM<V=I9"`B3W5T
M8F]U;F0@4V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&%S
M<W!H<F%S92YI;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR.3`*;7-G:60@(E!'4"(*;7-G<W1R(")01U`B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*;7-G:60@(E!'4"!%
M;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B4$=0(+EI9G)I<F%J('-P;W)OZ&EL
M;R(*"B,Z(&-O;7!O<V4N<&AP.C,U.`IM<V=I9"`B4$=0($5R<F]R.B`B"FUS
M9W-T<B`B4$=0($YA<&%K83H@(@H*(SH@8V]M<&]S92YP:'`Z,S,W"FUS9VED
M(")01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I
M=F%T92!K97DN(@IM<V=S='(@(E!'4"!.87!A:V$Z(%!O=')E8G5J96T@9V5S
M;&\@>F$@;W-E8FYI('IA<V5B;FD@:VQJ=>@N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B4$=0
M($UOOFYO<W1I(@H*(SH@<&=P+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A
M<V4@26YP=70B"FUS9W-T<B`B5G!I<R!01U`@9V5S;&$B"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA;"!+97EP86ER
M('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(E!O9'!O<F$@;W-E8FYE;74@<&%R=2!01U`@:VQJ=>AE=B!Z86AT
M979A('9A<FYO('-P;&5T;F\@<&]V97IA=F\N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,3<S"FUS9VED(")01U`@4'5B;&EC($ME>2!497AT(@IM
M<V=S='(@(D)E<V5D:6QO($IA=FYE9V$@4$=0(&ML:G7H82(*"B,Z('!G<"YP
M:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O
M<B!<(B5S("@E<RE<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R
M(")*879N:2!01U`@:VQJ=>@@>F$@7"(E<R`H)7,I7"(@:F4@8FEL('5S<&6Y
M;F\@9&]D86XN(@H*(SH@<&=P+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY
M(&1E;&5T960N(@IM<V=S='(@(DIA=FYI(%!'4"!K;&IUZ"!Z82!<(B5S7"(@
M:F4@8FEL('5S<&6Y;F\@:7IB<FES86XN(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B
M3V)E<V5K('H@:F%V;FEM:2!01U`@:VQJ=>AI(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHX"FUS9VED(")01U`@4VEG;B!-97-S
M86=E(@IM<V=S='(@(E!'4"!0;V1P:;EI('-P;W)OZ&EL;R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.0IM<V=I9"`B4$=0(%-I
M9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(E!'4"!0;V1P:;EI+ZEI9G)I
M<F%J('-P;W)OZ&EL;R(*"B,Z('!G<"YP:'`Z,C`R"FUS9VED(")01U`@<')I
M=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")01U`@>F%S
M96)N:2!K;&IUZ"!U<W!EN6YO(&1O9&%N+B(*"B,Z('!G<"YP:'`Z,3<W"FUS
M9VED(")01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S
M='(@(E!'4"!J879N:2!K;&IUZ"!U<W!EN6YO(&1O9&%N+B(*"B,Z('1E;7!L
M871E<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")01U`@<W5P<&]R="!I
M<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B4&]D<&]R82!0
M1U`@:F4@;F$@=&5M('-I<W1E;74@;VYE;6]G;^AE;F$N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,C`X"FUS9VED("(B"B)01U`@<W5P<&]R="!I
M<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U
M<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)0
M1U`@<&]D<&]R82!T<F5N=71N;R!N:2!O;6]G;^AE;F$L('IA=&\@9&EG:71A
M;&YE9V$@<&]D<&ES82!N:2!B:6QO(&UO9V_H92`B"B)O=F5R:71I+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I9"`B(@HB4$=0('-U
M<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@
M:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB4$=0('!O
M9'!O<F$@=')E;G5T;F\@;FD@;VUO9V_H96YA+"!Z871O('-P;W)OZ&EL82!N
M:2!B:6QO(&UO9V_H92!D9;EI9G)I<F%T:2XB"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,@HC+"!F=7IZ>0IM<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q
M=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W
M<V5R(&ES(&-U<G)E;G1L>2`B"B)S970@=&\@9&ES86)L92!P;W!U<"!W:6YD
M;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE
M(%!'4"`B"B)F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS
M9W-T<B`B(@HB4$=0('!O9'!O<F$@>F%H=&5V82!U<&]R86)O('!O<'5P(&]K
M96XN(,AE(&II:"!V8;D@8G)S:V%L;FEK('1R96YU=&YO(&YE("(*(F]M;V=O
MZ&$@;6]R871E('1O(&YA<W1A=FET978@<W!R96UE;FET:2!I;B!J:6@@;VUO
M9V_H:71I+B!6(&YA<W!R;W1N96T@(@HB<')I;65R=2!01U`@;6^^;F]S=&D@
M;F4@8F]D;R!P<F%V:6QN;R!D96QO=F%L92(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM<V=S='(@(E!/4#,B"@HC.B!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T;R!$
M971E8W0@4')O=&]C;VQS*2(*;7-G<W1R(")03U`S("AS86UO9&5J;F\@>F%Z
M;F%J*2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$W"FUS9VED(")0
M3U`S(&]V97(@4U-,(@IM<V=S='(@(E!/4#,@<')E:V\@4U-,(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,C,*;7-G:60@(E!/4#,@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R(")03U`S('!R96MO
M(%-33"`H<V%M;RUP;V1P:7-A;F\@<&]T<F1I;&\I(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHQ-CD*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E
M;&8M<VEG;F5D*2(*;7-G<W1R(")03U`S('!R96MO(%-33"`H<V%M;RUP;V1P
M:7-A;BDB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q,0IM<V=I9"`B
M4$]0,RP@;F\@5$Q3(@IM<V=S='(@(E!/4#,L(&)R97H@5$Q3(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")086=E("5D(&]F("5D(@IM<V=S='(@(E-T<F%N("5D(&]D("5D(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP,PIM<V=I9"`B4&%G92!W:71H
M('1H92!&:7)S="!5;G-E96X@365S<V%G92(*;7-G<W1R(")3=')A;B!S('!R
M=FEM($YE+79I9&5N:6T@<W!O<F_H:6QO;2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,#0*;7-G:60@(E!A9V4@=VET:"!T:&4@3&%S="!5;G-E96X@
M365S<V%G92(*;7-G<W1R(")3=')A;B!Z('IA9&YJ:6T@3F4M=FED96YI;2!S
M<&]R;^AI;&]M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z
M-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`B1&5L*&DI(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$R,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R
M(")'97-L;R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@
M(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R(")'97-L;R`H<&]N;W9N;RDB
M"@HC.B!S;6EM92YP:'`Z,C,U('!G<"YP:'`Z,S$P"FUS9VED(")087-S<&AR
M87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`B1V5S;&\@=7-P
M9;EN;R!O9'-T<F%N:F5N;RXB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H
M<F%S92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHR.0IM
M<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`B1V5S;&\Z(@H*(SH@<&=P+G!H
M<#HQ,3(*;7-G:60@(E!A<W-P:')A<V5S(&-A;B!N;W0@8F4@96UP='DB"FUS
M9W-T<B`B1V5S;&\@;F4@<VUE(&)I=&D@<')A>FYO(@H*(SH@<&=P+G!H<#HQ
M,30*;7-G:60@(E!A<W-P:')A<V5S(&1O(&YO="!M871C:"(*;7-G<W1R(")'
M97-L:2!S92!N92!U:F5M871A(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C(P('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW
M,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y,@IM<V=I9"`B4&%S
M<W=O<F0B"FUS9W-T<B`B1V5S;&\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B27IV961E;2!V>F1ROF5V86YJ
M92!O8B!P<FEJ879I/R(*"B,Z(&%C;"YP:'`Z-S8@86-L+G!H<#HQ,#(*;7-G
M:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N(&YO="!B92!C:&%N
M9V5D+B(*;7-G<W1R(")0<F%V:6,@>F$@=&5G82!U<&]R86)N:6MA(&YI(&UO
M9V_H92!S<')E;6EN:F%T:2XB"@HC.B!M97-S86=E+G!H<#HT.3,@;6%I;&)O
M>"YP:'`Z-S`S('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,`IM<V=I9"`B4&5R<V]N
M86PB"FUS9W-T<B`B3W-E8FYO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")/<V5B
M;F4@26YF;W)M86-I:F4B"@HC.B!P9W`N<&AP.C$R,`IM<V=I9"`B4&5R<V]N
M86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B3W-E8F5N('!A<B!01U`@:VQJ=>AE=B!U<W!EN6YO(&=E;F5R:7)A;BXB
M"@HC.B!P9W`N<&AP.C$R-PIM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7,@9&5L
M971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D]S96)E;B!P87(@4$=0(&ML
M:G7H978@=7-P9;EN;R!I>F)R:7-A;BXB"@HC.B!S;6EM92YP:'`Z,C`W"FUS
M9VED(")097)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E
M9#H@(@IM<V=S='(@(D]S96)N;R!3+TU)344@<&]T<F1I;&\@3DD@0DE,3R!U
M=F^^96YO.B`B"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S;VYA;"!3
M+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B3W-E
M8FYI(%,O34E-12!K;&IUZ&D@=7-P9;EN;R!I>F)R:7-A;FDN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA8V4@>6]U<B!S:6=N
M871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/R(*;7-G<W1R(")0
M<FEK8;YE;2!V8;D@<&]D<&ES('!R960@<&]S<F5D;W9A;FEM:2!S<&]R;^AI
M;&D@:6X@;V1G;W9O<FD_(@H*(SH@8V]M<&]S92YP:'`Z,C4T"FUS9VED(")0
M;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S='(@(E-P;W)OZ&EL
M;R!V(&YA=F%D;F5M(&)E<V5D:6QU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<Y.0IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O;B!N97<@;6%I;#\@(%1H
M:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O<G0@96UB961D960@
M(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I;F1O=W,@86YD
M($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL("(*(G)E<75I<F4@82!P
M;'5G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S
M8W)I<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC
M.C$Y,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F
M;VQD97(Z(@IM<V=S='(@(E!R;W-I;2!V<&FY:71E(&EM92!Z82!N;W9O(&UA
M<&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#(@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(E!L
M96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T
M<B`B4')O<VEM('9P:;EI=&4@:6UE(&YO=F4@;6%P93HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-PIM<V=I9"`B4&QE87-E(&5N
M=&5R('1H92!N97<@;F%M93HB"FUS9W-T<B`B4')O<VEM('9P:;EI=&4@;F]V
M;R!I;64Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P
M:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY
M(&YE960@=&\@(@HB96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S
M('-E<W-I;VXN(@IM<V=S='(@(B(*(E!R;W-I;2!V<&FY:71E(&=E<VQO('IA
M('9AN2!Z87-E8FYI(%!'4"!K;&IUZ"X@5&\@9V5S;&\@8F]S=&4@;6]R86QI
M('9P:7-A=&D@(@HB<V%M;R!E;FMR870@=B!V<V%K:2`E<R!S96II+B(*"B,Z
M('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R
M('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@
M(@HB=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I
M;VXN(@IM<V=S='(@(B(*(E!R;W-I;2!V<&FY:71E(&=E<VQO('IA('9AN2!3
M+TU)344@>F%S96)N:2!K;&IUZ"X@5&\@9V5S;&\@8F]S=&4@;6]R86QI("(*
M(G9P:7-A=&D@<V%M;R!E;FMR870@=B!V<V%K:2`E<R!S96II+B(*"B,Z(')E
M8V]M<&]S92YP:'`Z.3<*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@
M=&\@<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@
M3D]4('5S:6YG("(*(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE
M<W-A9V5S(&EN('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB
M;&]G(&EN(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI
M<R!I<R!T;R!K965P(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R
M('-E<W-I;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N
M8V4N(@IM<V=S='(@(B(*(EIA(&YA9&%L:F5V86YJ92!S97-T879L:F%N:F$@
M=F&Y96=A('-P;W)OZ&EL82!S92!P<F]S:6T@<&]N;W9N;R!P<FEJ879I=&4N
M("(*(LAE(&YE('5P;W)A8FQJ871E('!IN6MO=&MO=B!)3B#H92!S97-T879L
M:F%T92!S<&]R;^AI;&$@=B!P;W!U<"!O:VYI:"P@<V4@(@HB8F]S=&4@;6]R
M86QI('!O;F]V;F\@<')I:F%V:71I('1U9&D@=B!V8;EE;2!G;&%V;F5M(&]K
M;G4N(%1I('5K<F5P:2!S;R!Z871O+"`B"B)D82!B:2!N87!A9&%L8V5M('!R
M97!R9>AI;&D@=6=R86)I=&5V($E$('-E:F4N($]P<F%V:>AU:F5M;R!S92!Z
M82`B"B)N97!R:6IE=&YO<W0N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"XB
M"FUS9W-T<B`B4')O<VEM('9P:;EI=&4@<W9O:F4@9V5S;&\N(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B4')O<VEM('9P:;EI=&4@<W9O
M:F4@=7!O<F%B;FFY:V\@:6UE+B(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O
M24U0+G!H<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O
M<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B4')O<VEM('!O<')A=FET
M92!D=F]U;6YE(&%L:2!N979E;&IA=FYE(&YA<VQO=F4N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8T,@IM<V=I9"`B(@HB4&QE87-E(')E=FEE
M=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@
M86X@86-T:6]N(&9R;VT@=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S='(@(B(*
M(E!R;W-I;2!P;V=L96IT92!N87-L961N:F4@:6YF;W)M86-I:F4@:6X@:7IB
M97)I=&4@9&5J86YJ92!I>B!S<&]D;FIE9V$@(@HB;65N=6IA+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C$*;7-G:60@(E!L96%S
M92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I
M;VYS+B(*;7-G<W1R(")0<F]S:6T@:7IB97)I=&4@;6%P;RP@<')E9&5N(&EZ
M8F5R:71E(&1E:F%N:F4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4P,@IM<V=I9"`B4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@
M;65N=2!B96QO=RXB"FUS9W-T<B`B4')O<VEM(&EZ8F5R:71E(&1E:F%N:F4@
M:7H@<W!O9&YJ96=A(&UE;G5J82XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VIA
M=F%S8W)I<'0N:6YC.C0Q"FUS9VED(")0;&5A<V4@<V5L96-T(&%T(&QE87-T
M(&]N92!F;VQD97(@=&\@<V5A<F-H+B(*;7-G<W1R("):82!I<VMA;FIE(&EZ
M8F5R:71E('9S86H@96YO(&UA<&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9F]L9&5R<RYJ<SHQ,@IM<V=I9"`B4&QE87-E('-E;&5C="!O;FQY(&]N
M92!F;VQD97(@9F]R('1H:7,@;W!E<F%T:6]N+B(*;7-G<W1R("):82!T;R!O
M<')E86-I:F\@<')O<VEM(&EZ8F5R:71E('-M86\@96YO(&UA<&\N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"FUS9VED(")0;&5A
M<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM
M<V=S='(@(E!R;W-I;2!I>F)E<FET92!A;&D@=7)E9&ET92!V(&]B<F%Z8W4@
M;F$@9&5S;FDZ(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*;7-G:60@
M(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B4&]W97)E9"!B>2!(;W)D92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,30*;7-G:60@(E!R96-E9&4@
M>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B
M4')E9'!IN65M('9AN2!P;V1P:7,@<R!P;VUIN6QJ86II("@G+2T@)RD_(@H*
M(SH@<VUI;64N<&AP.C(T,2!P9W`N<&AP.C(U-R!F:6QT97)P<F5F<RYP:'`Z
M-#`*;7-G:60@(E!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*
M;7-G<W1R(").87-T879I='9E('5S<&6Y;F\@<&]S;V1O8FQJ96YE+B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")0
M<F5V:65W(@IM<V=S='(@(E!R961O9VQE9"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G:60@(E!R979I;W5S($UE
M<W-A9V4B"FUS9W-T<B`B4')E:KEN:F4@<W!O<F_H:6QO(@H*(SH@;6%I;&)O
M>"YP:'`Z,S0W"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(E!R96JY
M;FIA('-T<F%N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C,S"FUS9VED(")0<FEN="(*;7-G<W1R(").871I<VYI(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*;7-G:60@(E!R:6]R
M:71Y(@IM<V=S='(@(E!R:6]R:71E=&$B"@HC.B!T96UP;&%T97,O<VUI;64O
M:6UP;W)T7VME>2YI;F,Z-S8*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D
M(@IM<V=S='(@(D=E<VQO('IA<V5B;F5G82!K;&IUZ&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-34Y"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A
M;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B"FUS9W-T<B`B
M5G!R8;EA;2!V<V%K:>@@:V\@:F4@<&]S;&%N82!P<FEP;VYK83L@<')I=GIE
M=&\@:F4@3D4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X"FUS9VED
M(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E
M9F%U;'0@=&\@6453(@IM<V=S='(@(E9P<F&Y86T@=G-A:VGH(&MO(&IE('!O
M<VQA;F$@<')I<&]N:V$[('!R:79Z971O(&IE($1!(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0<F]T;V-O;#HB"FUS
M9W-T<B`B4')O=&]K;VPZ(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y"FUS
M9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I
M<V%B;&5D+B(*;7-G<W1R(")0;V1P;W)A(&IA=FYE;74@4$=0('-T<F6^;FEK
M=2!J92!B:6QA(&]N96UO9V_H96YA+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L
M971E9"YI;F,Z.`IM<V=I9"`B4'5R7V=E($1E;&5T960B"FUS9W-T<B`B27IB
M7W)IN6D@27IB<FES86YA(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN
M8SHX"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(DEZ8G)IN6D@27IB
M<FES86YA(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C0*
M;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R("))>F)R:;EI(&EZ8G)I
M<V%N82!S<&]R;^AI;&$@:7H@;6%P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G<W1R
M(")+86MO('!O9V]S=&\@:7IB<FFY96T@4VUE=&DZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0P-0IM<V=I9"`B4'5R9V4@;65S<V%G97,@:6X@5')A
M<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RXB"FUS
M9W-T<B`B4&]B<FFY96T@<W!O<F_H:6QA(&EZ(%-M971I+"!K:2!S;R!S=&%R
M96JY82!O9#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED
M(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS
M9W-T<B`B4&]B<FFY96T@<W1A<F$@<W!O<F_H:6QA(&EZ(%-M971I/R(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S86=E<R!F
M<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B0G)IN65M("5D('-P;W)OZ&EL
M(&EZ(%-M971I+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R
M87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@
M9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(D)R:;EE;2`E9"!S<&]R;^AI
M;"!I>B!3;65T:2XB"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C$W
M"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@
M)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R(")3=&%N:F4@:W9O=&4Z("4N,F9-
M0B`O("4N,F9-0B`@*"4N,F8E)2DB"@HC.B!T96UP;&%T97,O<75O=&$O<75O
M=&$N:6YC.C(Q"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@
M)2XR9DU"("\@3D\@3$E-250B"FUS9W-T<B`B4W1A;FIE(&MV;W1E.B`E+C)F
M34(@+R!.22!/345*251612(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI
M;F,Z,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B!.3R!,
M24U)5"(*;7-G<W1R(")3=&%N:F4@:W9O=&4Z($Y)($]-14I)5%9%(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T<B`B0VET:7)A;2`E)68Z(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@V"FUS9VED(")2
M95]Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VXB"FUS9W-T<B`B6F%H=&5?
M=F%M('!O=')D:71E=B!D;W-T879E(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3`*
M;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@(E!R96IE=&\@;F$B"@HC.B!L
M:6(O4V5A<F-H+G!H<#HU.`IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T
M<B`B4')E:F5T;R!O9"(*"B,Z(&QI8B]396%R8V@N<&AP.C4T"FUS9VED(")2
M96-E:79E9"!5;G1I;"(*;7-G<W1R(")0<F5J971O(&1O(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I
M<F5C7W0B"FUS9W-T<B`B4')E7W5S;65R:2(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8W0B"FUS
M9W-T<B`B4')E=7-M97)I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E
M8W0N:6YC.C$Q,`IM<V=I9"`B4F5D:7)E8W0@365S<V%G92(*;7-G<W1R(")0
M<F5U<VUE<FD@<W!O<F_H:6QO(@H*(SH@8V]M<&]S92YP:'`Z-S@W"FUS9VED
M(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B4')E=7-M97)I('1O
M('-P;W)OZ&EL;R(*"B,Z(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E
M8W1I;F<@9F%I;&5D+B(*;7-G<W1R(")0<F5U<VUE<FET978@<W!O9&QE=&5L
M82XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU.#,*;7-G
M:60@(E)E9G)E<V@B"FUS9W-T<B`B3W-V9;YI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<X-`IM<V=I9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM
M<V=S='(@(D]S=F6^:2!P;V=L960@;6%P.B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHT
M"FUS9VED(")296QO860B"FUS9W-T<B`B4&]N;W9N;R!N86QOOFDB"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHS"FUS9VED(")296QO860@5FEE
M=R(*;7-G<W1R(")/<W9EOFD@<&]G;&5D(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4R-B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30U"FUS
M9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G
M<W1R("):87!O;6YI('-I(&EN9F]R;6%C:6IO('!R;W-T+WIA<V5D96XN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW.0IM<V=I9"`B4F5M96UB97(@
M=&AE(&QA<W0@=FEE=R(*;7-G<W1R("):87!O;6YI('-I('IA9&YJ:2!P;V=L
M960B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*;7-G
M:60@(E)E;6]T92!-86EL8F]X.B(*;7-G<W1R(")/9&1A;&IE;B!.86)I<F%L
M;FEK.B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I
M9"`B4F5M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(D]D<W1R86YI
M('!O;&IE(&EZ(&ES:V%N:F$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,#4*;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T<B`B
M3V1S=')A;FD@:7IV;W)N;R!K;V1O(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5N86UE($9O;&1E<BAS*2(*;7-G<W1R
M(")0<F5I;65N=6H@;6%P;RAE*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$*;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN
M;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B4')E:6UE;G5J96T@;6%P;R!S('!O
M<VQA;F\@<&^Y=&\@;F$@>F'H971K=2!M97-E8V$_(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-#4U"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG(%PB)7-<
M(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(E!R96EM96YO=F%N:F4@7"(E<UPB('8@7"(E<UPB(&YI
M('5S<&5L;RX@4W1R9;YN:6L@:F4@:F%V:6PB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G:60@(E)E<&Q?>2!T;R!,
M:7-T(@IM<V=S='(@(D]?9&=O=F]R:2!N82!,:7-T;R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET
M:#HB"FUS9W-T<B`B6F%M96YJ86H@>CHB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`B
M3V1G;W9O<FDB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$Q(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#D*;7-G:60@(E)E<&QY(%-E;G0N
M(@IM<V=S='(@(D]D9V]V;W(@<&]S;&%N+B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL
M(@IM<V=S='(@(D]D9V]V;W)I('9S96TB"@HC.B!C;VUP;W-E+G!H<#HW,S,*
M;7-G:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B3V1G;W9O<FD@=G-E;3HB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*
M;7-G:60@(E)E<&QY('1O($QI<W0B"FUS9W-T<B`B3V1G;W9O<FD@;F$@3&ES
M=&\B"@HC.B!C;VUP;W-E+G!H<#HW,S4*;7-G:60@(E)E<&QY('1O($QI<W0Z
M(@IM<V=S='(@(D]D9V]V;W)I(&YA($QI<W1O.B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@
M7T%L;"(*;7-G<W1R(")/9&=O=F]R:2!V7W-E;2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S
M-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED(")297!L
M>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R(")/9&=O=F]R
M:2!S('-P;W)OZ&EL;VT@3FD@<&]D<')T;R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,S4*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O
M<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R(")/9&=O=F]R:2!Z(&EN9F]R;6%C
M:6IO('!R;W-T+WIA<V5D96X@>F$@;F%S;&5D;FIE(#(@;65S96-A+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E<&QY('=I
M=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M3V1G;W9O<FD@>B!Z86AT979A;F\@:6YF;W)M86-I:F\@<')O<W0O>F%S961E
M;BXB"@HC.B!M97-S86=E+G!H<#HR-C<*;7-G:60@(E)E<&QY+51O(@IM<V=S
M='(@(D]D9V]V;W)I+4YA(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P.0IM<V=I
M9"`B4F5P;'DM5&\Z("(*;7-G<W1R(")/9&=O=F]R:2U.83HB"@HC.B!C;VUP
M;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*;7-G<W1R(")/9&=O=F]R:3HB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S@@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C8*;7-G:60@(E)E<&]R
M="!A<R!);FYO8V5N="(*;7-G<W1R(")0<FEJ879I(&MO="!:8;YE;&5N;R(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS-2!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,PIM<V=I9"`B4F5P;W)T
M(&%S(%-P86TB"FUS9W-T<B`B4')I:F%V:2!K;W0@3F5Z8;YE;&5N;R(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X,PIM<V=I9"`B4F5Q
M=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`B6F%H=&5V86H@<&]T<F1I
M;&\@;R!?4')E:F5M=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#4*
M;7-G:60@(E)E<75E<W0@9&5L:79E<GD@8V]N9FER;6%T:6]N/R(*;7-G<W1R
M("):86AT979A;2!P;W1R9&EL;R!O(&1O<W1A=FD_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4W,PIM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S
M/R(*;7-G<W1R("):86AT979A;2!P;W1R9&EL82!O('!R96IE;74_(@H*(SH@
M;6%I;&)O>"YP:'`Z,3@Y"FUS9VED(")297%U97-T960@;65S<V%G92!N;W0@
M9F]U;F0N(@IM<V=S='(@(EIA:'1E=F%N;R!S<&]R;^AI;&\@;FD@8FEL;R!N
M86ID96YO+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.3<*;7-G
M:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(E!O=')E8F5N('5D
M96QEOF5N96,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$V,0IM<V=I9"`B4F5S970B"FUS9W-T<B`B4&]N87-T879I
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-0IM<V=I9"`B4F5S
M<&]N9&5N="!3=&%T=7,@57!D871E9"XB"FUS9W-T<B`B4W1A;FIE(&1O<&ES
M;FEK82!P;W-O9&]B;&IE;F\N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T<B`B3F%D
M86QJ=6HB"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")297-U;64@>6]U
M<B!S97-S:6]N(@IM<V=S='(@(DYA9&%L:G5J('-E:F\B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(E)E
M='5R;B!T;R!<(DUE<W-A9V4@0V]M<&]S:71I;VY<(B(*;7-G<W1R(")3971A
M=FQJ86YJ92!3<&]R;^AI;&$B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R
M:79E<E]S96QE8W0N:6YC.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHV.0HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T
M+FEN8SHS,@IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`B
M5G)N:2!S92!N82!&971C:"!-86EL(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z
M,C(*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#$@=&5M<&QA=&5S
M+W-M:6UE+VYO=&%C=&EV92YI;F,Z,30*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M,3<S"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(").87IA:B!N
M82!M;[YN;W-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,3@*;7-G
M:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E
M;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/R(*;7-G<W1R
M("(B"B)392!V<FYE;2!N82!S97IN86T@;F%B:7)A;&YI:V$@<&\@8G)I<V%N
M:G4L('!R96UI:V%N:G4@86QI(&MO<&ER86YJ=2`B"B)S<&]R;^AI;&$_(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4F]L92(*
M;7-G<W1R(")6;&]G82(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,30R(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS9VED(")3+TU)344B"FUS9W-T<B`B
M4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN
M8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("*I
M:69R:7)A:B!S<&]R;^AI;&\@<R!3+TU)344B"@HC.B!C;VUP;W-E+G!H<#HS
M.30*;7-G:60@(E,O34E-12!%<G)O<CH@(@IM<V=S='(@(E,O34E-12!.87!A
M:V$Z("(*"B,Z(&-O;7!O<V4N<&AP.C,W,PIM<V=I9"`B4R]-24U%($5R<F]R
M.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*
M;7-G<W1R(")3+TU)344@3F%P86MA.B!:82!O<V5B;FD@>F%S96)N:2!K;&IU
MZ"!J92!P;W1R96)N;R!G97-L;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34Q"FUS9VED(")3+TU)344@3W!T:6]N<R(*;7-G<W1R(")3+TU)344@
M36^^;F]S=&DB"@HC.B!S;6EM92YP:'`Z-#D*;7-G:60@(E,O34E-12!087-S
M<&AR87-E($EN<'5T(@IM<V=S='(@(E9N;W,@4R]-24U%(&=E<VQA(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B4R]-24U%(%!E
M<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`B4R]-24U%('IA<V5B;FD@<&%R(&ML:G7H
M978@>F%H=&5V82!V87)N;R!S<&QE=&YO('!O=F5Z879O+B(*"B,Z('-M:6UE
M+G!H<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+
M97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(E,O34E-12!J879N:2!K;&IUZ"!Z82!<(B5S7"(@=7-P9;EN;R!I>F)R
M:7-A;BXB"@HC.B!S;6EM92YP:'`Z,38R"FUS9VED(")3+TU)344@4'5B;&EC
M($ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E,O34E-12!J879N
M:2!K;&IUZ"!U<W!EN6YO(&1O9&%N+B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,3`*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G
M<W1R(")3+TU)344@;V)E<V5K('IA(&IA=FYE(&ML:G7H92(*"B,Z('-M:6UE
M+G!H<#HR,3$*;7-G:60@(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER
M('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B4R]-24U%($IA=FYI+UIA
M<V5B;FD@<&%R(&ML:G7H978@=7-P9;EN;R!D;V1A;BXB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"FUS9VED(")3+TU)344@
M4VEG;B!-97-S86=E(@IM<V=S='(@(E!O9'!IN6D@<W!O<F_H:6QO(',@4R]-
M24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ
M-`IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@
M(E!O9'!IN6DOJ6EF<FER86H@<W!O<F_H:6QO(',@4R]-24U%(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4R]-24U%('-U
M<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(E!O
M9'!O<F$@4R]-24U%(&IE(&YA('1E;2!S:7-T96UU(&]N96UO9V_H96YA+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"FUS9VED("(B"B)3
M+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE
M(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E9"XB"FUS9W-T
M<B`B(@HB4&]D<&]R82!3+TU)344@=')E;G5T;F\@;FD@;VUO9V_H96YA+"!Z
M871O('-P;W)OZ&EL82!N:2!B:6QO(&UO9V_H92`B"B)D9;EI9G)I<F%T:2XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PIM<V=I9"`B(@HB
M4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S
M(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO="`B"B)B92!D:7-P;&%Y
M960N(@IM<V=S='(@(B(*(E!O9'!O<F$@4R]-24U%(&YI(&]M;V=OZ&5N82P@
M>F%T;R!V<V5B:6YE('1E9V$@<&]D<&ES86YE9V$@<W!O<F_H:6QA(&YI("(*
M(FUO9V_H92!P<FEK87IA=&DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B
M;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@
M(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E!O9'!O<F$@4R]-24U%(&YI(&]M
M;V=OZ&5N82P@>F%T;R!T96=A(&1I9VET86QN96=A('!O9'!I<V$@;FD@;6]G
M;^AE(&]V97)I=&DN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR
M"B,L(&9U>GIY"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P
M;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@
M(@HB8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO
M=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-
M24U%(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"B)0;V1P;W)A(%,O34E-12!Z86AT979A('5P;W)A8F\@<&]P=7`@;VME
M;BX@R&4@:F4@=F&Y(&)R<VMA;&YI:R!T<F5N=71N;R`B"B)N87-T879L:F5N
M('1A:V\@9&$@;F4@<&]D<&ER82!P;W!U<"!O:V5N+"!M;W)A=&4@=&\@;F%S
M=&%V:71E=B!S<')E;65N:71I+B!6("(*(FYA<W!R;W1N96T@<')I;65R=2!3
M+TU)344@<&]D<&]R82!N92!B;R!P<F%V:6QN;R!D96QO=F%L82(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`U"FUS9VED(")33510(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(U-0IM
M<V=I9"`B4U]U8FIE8W0B"FUS9W-T<B`B6F%D95]V82(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,V,PIM<V=I9"`B4V%?=F4@82!C;W!Y
M(&EN("(*;7-G<W1R(")3:')A7VYI(&MO<&EJ;R!V(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")385]V92!A
M<R(*;7-G<W1R(")3:')A7VYI(&MO="(*"B,Z('-E87)C:"YP:'`Z,S$V('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-PIM<V=I9"`B4V%V92(*
M;7-G<W1R(")3:')A;FDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU,S@*;7-G:60@(E-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E
M(&EN('-E;G0M;6%I;"!F;VQD97(_(@IM<V=S='(@(E-H<F%N:6T@4')I<&]N
M:V4@<VMU<&%J(',@<W!O<F_H:6QO;2!M960@<&]S;&%N;R!P;[ET;S\B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@(E-A=F4@1')A9G0B"FUS
M9W-T<B`B4VAR86YI($]S;G5T96LB"@HC.B!S879E:6UA9V4N<&AP.C0R"B,L
M(&9U>GIY"FUS9VED(")3879E($EM86=E(@IM<V=S='(@(E-H<F%N:2!K;W0B
M"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C`T"FUS9VED(")3879E($EM
M86=E(&EN($=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C4Y('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`P
M"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ-#@*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N
M:6YC.C$S"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B4VAR86YI($UO
MOFYO<W1I(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P
M"B,L(&9U>GIY"FUS9VED(")3879E(%-T871I;VYE<GDB"FUS9W-T<B`B4VAR
M86YI($UOOFYO<W1I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,S"FUS9VED
M(")3879E(%]$<F%F="(*;7-G<W1R(")3:')A;FD@7T]S;G5T96LB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@
M(E-A=F4@87,B"FUS9W-T<B`B4VAR86YI(&MO="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B
M"FUS9W-T<B`B4VAR86YI;2!O<VYU=&ME(&MO="!N979I9&5N93\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W,@IM<V=I9"`B4V%V92!R96-I<&EE
M;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K
M/R(*;7-G<W1R(")!=G1O;6%T:>AN;R!S:')A;FEM('!R96IE;6YI:V4@=B!P
M<FEV>F5T(&%D<F5S87(_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHQ,C<*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_
M(@IM<V=S='(@(E-H<F%N:6T@:7-K86YJ92!K;W0@;F%V:61E>FYO(&UA<&\_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B4V%V92!S
M96YT(&UA:6P_(@IM<V=S='(@(E-H<F%N:6T@<&]S;&%N;R!P;[ET;S\B"@HC
M.B!C;VUP;W-E+G!H<#HQ,C(W"B,L('!H<"UF;W)M870*;7-G:60@(E-A=FEN
M9R!T:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`E<R(*;7-G<W1R(")3:')A;FIE=F%N:F4@;W-N=71K82!S<&]D;&5T
M96QO+B!3=')EOFYI:R!J92!J879I;#H@)7,B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$Y.2!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C$Q"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C0Q"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B2;GH:2(*"B,Z('1E;7!L871E<R]S96%R
M8V@O:&5A9&5R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC
M.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:"`E<R(*;7-G<W1R("))
MN>AI("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,`HC+"!F=7IZ
M>0IM<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`B4VAR86YI($UOOFYO
M<W1I(@H*(SH@<V5A<F-H+G!H<#HR-C4*;7-G:60@(E-E87)C:"!297-U;'1S
M(@IM<V=S='(@(E)E>G5L=&%T:2!)<VMA;FIA(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,Q"FUS9VED(")3965N(@IM<V=S='(@(E9I9&5N82(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z.0IM<V=I9"`B4V5L96-T(@IM<V=S
M='(@(DEZ8F5R:2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G<W1R("))
M>F)E<FD@9')U9R!R8>AU;B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHS-@IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("))>F)E<FD@
M9&%T=6TB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,3`*;7-G
M:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(DEZ8F5R:2!P;VQJ92(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PHC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B27IB97)I(&1A
M='5M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L
M96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E87)C
M:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R("))>F)E<FET92!!9')E<V%R
M:F4@>F$@9&]D86IA;FIE(&EN(&ES:V%N:F4@;F%S;&]V;W8B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL(@IM
M<V=S='(@(DEZ8F5R:2!V<V4B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,C,*;7-G:60@(E-E;&5C="!A;&P@9FEE;&1S('1O('-E
M87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(DEZ8F5R
M:2!V<V$@<&]L:F$@>F$@:7-K86YJ92P@:V\@<F%ZN6ER:F&Y(&YA<VQO=F4B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR
M,0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B27IB97)I(')A
MZ'5N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I9"`B
M4V5L96-T(&YO;F4B"FUS9W-T<B`B3F4@:7IB97)I(&YO8F5N92(*"B,Z('1E
M;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS9VED(")396QE
M8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z
M,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP92(*;7-G<W1R
M("))>F)E<FET92!V<G-T;R!P;[ET;F5G82!S=')EOFYI:V$B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*;7-G:60@(E-E;&5C
M=&5D($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(DEZ8G)A;FD@061R97-A<FII
M.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B4V5N9"!+
M97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R(")0;[EL:FD@2VQJ=>@@
M;F$@:F%V;FD@<W1R9;YN:6L@<R!K;&IUZ&DB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C`T"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO
M;B(*;7-G<W1R(")0;[EL:FD@;F%J;F]V96JY92!I;F9O<FUA8VEJ92(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0IM<V=I9"`B4V5N9"!-97-S86=E(@IM
M<V=S='(@(E!ON6QJ:2!S<&]R;^AI;&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S`S"B,L(&9U>GIY"FUS9VED(")396YD(')E860@<F5C96EP="!W
M:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R(")0;[EL:F5M
M($U$3BP@:V\@9V$@<&^Y:6QJ871E;&H@>F%H=&5V83\B"@HC.B!F;VQD97)S
M+G!H<#HS.3<*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B36%P
M82!S('!O<VQA;F\@<&^Y=&\B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA
M:6QS96QE8W0N:6YC.C,X"FUS9VED(")396YT(&UA:6P@9F]L9&5R.B(*;7-G
M<W1R(")-87!A(',@<&]S;&%N;R!P;[ET;SHB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$S,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$T
M-@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$U,PIM<V=I9"`B4V5R
M=F5R(@IM<V=S='(@(E-T<F6^;FEK(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S"FUS9VED(")397)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO;B(*
M;7-G<W1R("));F9O<FUA8VEJ92!O(%-T<F6^;FEK:6@@:6X@36%P86@B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E
M<G9E<CHB"FUS9W-T<B`B4W1R9;YN:6LZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@P"FUS9VED(")3970@<')E9F5R96YC97,@9F]R('=H870@:&%P
M<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N(@IM<V=S
M='(@(DYA<W1A=FD@:V%J('-E('IG;V1I+"!K;R!P<F5M:6MA=&4@86QI(&)R
M:;EE=&4@<W!O<F_H:6QA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP
M;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(DYA<W1A=FD@=G)S=&EC;R!G;&%V
M92!8+5!R:6]R:71Y('!R:2!S97-T879L:F%N:G4@<W!O<F_H:6P_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED(")3:&%R92!&;VQD97)S
M(@IM<V=S='(@(E-K=7!N82!R86)A($UA<"(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHX-@IM<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@
M(E-K=7!N82!R86)A(&UA<"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U
M<V5R<RXB"FUS9W-T<B`B3VUO9V_H:71E('-K=7!N;R!R86)O('-V;VII:"!P
M;[ET;FEH(&UA<"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8Y"FUS
M9VED("(B"B)3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT(&)E
M('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@(@HB=&]G
M9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N(@IM<V=S='(@(B(*
M(DYA:B!B;V1O('9E;&EK:2!O9'-E:VD@8VET:7)A;F5G82!B97-E9&EL82!P
M<FEV>F5T;R!P<FEK87IA;FD@86QI('-K<FET:3\@(@HB3F%S=&%V:71E=B!J
M92!M;V=OZ&4@<')E<')O<W1O('!R96ML87!L:F%T:2XB"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-PIM<V=I9"`B4VAO=6QD('1H92!B;V1Y(&]F('1E
M>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@4$=0(&1A=&$_(@IM
M<V=S='(@(DYA:B!V('1E;&5S=2!T97AT+W!L86EN('-P;W)OZ&EL(&FYZ&5M
M(%!'4"!P;V1A=&ME/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3,*
M;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F
M=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R("(B"B).86H@<V4@<&\@<VAR
M86YJ979A;FIU('-P;W)OZ&EL82!M960@;W-N=71K92!O:VYO('IA('-E<W1A
M=FQJ86YJ92!Z87!R93\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM
M<V=I9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H
M960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*;7-G<W1R(").86H@
M<V4@=F&Y(&IA=FYI(%!'4"!K;&IUZ"!P<FEV>F5T;R!P<FEP;F4@<W!O<F_H
M:6QO;3\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"FUS9VED
M(")3:&]W($%L;"!&;VQD97)S(@IM<V=S='(@(E!R:6MAOFD@=G-E(&UA<&4B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV-PIM<V=I9"`B
M4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R(")0<FEK8;YI('9S92!V<G-T:6-E
M(&=L879E(@H*(SH@;6%I;&)O>"YP:'`Z,S8U"FUS9VED(")3:&]W($1E;&5T
M960B"FUS9W-T<B`B4')I:V&^:2!P;V)R:7-A;F4B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D($AE
M861E<G,B"FUS9W-T<B`B4VMR86JY86X@<')I:V%Z('9R<W1I8R!G;&%V92(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P"FUS9VED(")3
M:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R(")0<FEK8;YI
M('!O9&%T:V4@;R!M86EL:6YG+6QI<W1I(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHY,@IM<V=I9"`B4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L
M9&5R<R(*;7-G<W1R(")0<FEK8;YI('-A;6\@;F%R;^AE;F4@;6%P92(*"B,Z
M(&9O;&1E<G,N<&AP.C(Y.`IM<V=I9"`B4VAO=R!5;G-U8G-C<FEB960B"FUS
M9W-T<B`B4')I:V&^:2!.96YA<F_H96YE(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8P.`IM<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP
M<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*;7-G<W1R(")0
M<FEK8;YE;2!I:V]N;RP@:VD@9&]V;VQJ=6IE(&)R:7-A;FIE('!R:7!O;FL@
M:7H@<W!O<F_H:6P_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,#(*
M;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S
M='(@(E!R:6MAOF5M(&QE9V5N9&\@=B!P;V=L961U(&YA8FER86QN:6MA/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#`*;7-G:60@(E-H;W<@<')E
M=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R(")0<FEK
M8;YE;2!P<F5D;V=L960@<V%M;R!Z82!N97!R96)R86YA('-P;W)OZ&EL83\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('!R
M979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R(")0<FEK8;YE;2!P<F5D;V=L
M961E(&]B('!R96AO9'4@;6FY:V4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@W-PIM<V=I9"`B4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H
M92!M96YU8F%R/R(*;7-G<W1R(")0<FEK8;YE;2!I:V]N;R!&971C:"!-86EL
M/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B4VAO
M=R!T:&4@26UA9V5S(@IM<V=S='(@(E!O:V&^:2!3;&EK92(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHU-`IM<V=I9"`B4VAO=R!T:&4@9FEL
M=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(E!R:6MAOF5M(&EK
M;VYO($9I;'1E<C\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C@*;7-G
M:60@(E-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O;&1E<C\B"FUS
M9W-T<B`B4')I:V&^96T@<VMU<&YO(+ET979I;&\@<W!O<F_H:6P@=B!M87!I
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C8*;7-G:60@(E-H;W=N
M(@IM<V=S='(@(E!R:6MA>F%N;R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z-#(*;7-G:60@(E-I7WIE(@IM<V=S='(@(E9E
M;&EK;U]S="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*
M;7-G:60@(E-I9VYE9"(*;7-G<W1R(")0;V1P:7-A;F\B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G
M<W1R(")696QI:V]S="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,3$*;7-G:60@(E-O<G0@8GD@07)R:79A;"(*;7-G<W1R
M(")287IV<G-T:2!P;R!0<FEH;V1U(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM
M<V=S='(@(E)A>G9R<W1I('!O($1A='5M=2(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C8*;7-G:60@(E-O<G0@8GD@1G)O
M;2!!9&1R97-S(@IM<V=S='(@(E)A>G9R<W1I('!O($]D(&YA<VQO=G4B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0Q"FUS
M9VED(")3;W)T(&)Y($UE<W-A9V4@4VEZ92(*;7-G<W1R(")287IV<G-T:2!P
M;R!696QI:V]S=&D@<W!O<F_H:6QA(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHS-@IM<V=I9"`B4V]R="!B>2!3=6)J96-T
M(@IM<V=S='(@(E)A>G9R<W1I('!O(%IA9&5V:2(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S$*;7-G:60@(E-O<G0@8GD@
M5&AR96%D(@IM<V=S='(@(E)A>G9R<W1I('!O(%!O9V]V;W)U(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B
M4V]R="!B>2!4;R!!9&1R97-S(@IM<V=S='(@(E)A>G9R<W1I('!O(%IA(&YA
M<VQO=G4B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C,*
M;7-G:60@(E-P86T@9F]L9&5R.B(*;7-G<W1R(")-87!A('H@;F5Z8;YE;&5N
M;R!P;[ET;SHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G<W1R(")0;W-E8FYI
M('IN86MI(@H*(SH@<V5A<F-H+G!H<#HQ,S,*;7-G:60@(E-P96-I86P@5FER
M='5A;"!&;VQD97)S(&-A;B!N;W0@8F4@961I=&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#,*;7-G:60@(E-P
M96QL($-H96-K(@IM<V=S='(@(E!R979E<FD@Z')K;W9A;FIE(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")3<&5L;"!#
M:&5C:V5R(@IM<V=S='(@(LAR:V]V86YJ92(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@
M(E!R979E<FIA;FIE(.AR:V]V86YJ82!K;V[H86YO(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0W,0IM<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S
M8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T<B`BR')K;W9A;&YI
M:"!N87!A:R!N82!Z87-L;VX@<')I('!R96=L961O=F%N:G4@Z')K;W9A;FIA
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3(@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8U,@IM<V=I9"`B4W1A<G0B"FUS9W-T<B`B6F'H
M;FDB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z.2!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3$*;7-G:60@(E-T871I;VYE
M<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C(V"FUS9VED(")3=&%T:6]N97)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR.`IM<V=I9"`B4W1A
M=&EO;F5R>2!T>7!E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z,S,*;7-G:60@(E-T871I;VYE<GDZ(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(E-T
M871U<R(*;7-G<W1R(")3=&%N:F4B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP
M:'`Z,C$U"FUS9VED(")3=')I<"!!='1A8VAM96YT(@IM<V=S='(@(D]D<W1R
M86YI(%!R:7!O;FMO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S,@IM
M<V=I9"`B4W1R:7`@;&EN96)R96%K<S\B"FUS9W-T<B`B3V1S=')A;FEM('!R
M96QO;64@=G)S=&EC/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,S<*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(EIA9&5?
M=F$B"@HC.B!M97-S86=E+G!H<#HR-C@@=&AR96%D+G!H<#HQ-3`@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H
M<#HS.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("):861E=F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(P"FUS9VED(")3=6)J96-T($9I96QD(@IM
M<V=S='(@(E!O;&IE('H@6F%D979O(@H*(SH@<V5A<F-H+G!H<#HS,3@@=&5M
M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C$X"B,Z('1E;7!L871E
M<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,"!T96UP;&%T97,O<&=P+W!A<W-P
M:')A<V4N:6YC.C,Q"FUS9VED(")3=6)M:70B"FUS9W-T<B`B4&^Y;&II(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3$*;7-G:60@(E-U
M8G-C<FEB92!T;R!&;VQD97(H<RDB"FUS9W-T<B`B3F%R;^AI('-E(&YA($UA
M<&\H92DB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X,"!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HS.#D*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z.#<*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B57-P96QO(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3
M=6=G97-T:6]N<R(*;7-G<W1R(")0<F5D;&]G:2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-C(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V
M-`IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")0;W9Z971E:R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,"!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,#,*;7-G:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-
M971H;V0B"FUS9W-T<B`B4')E:VQO<"!M960@;F'H:6YO;2!S97-T879L:F%N
M:F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G
M:60@(E-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(E!R96ML
M;W!I('8@2%1-3"!N8>AI;B!S97-T879L:F%N:F$B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!P;&%I
M;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@(E!R96ML;W!I('8@=&5K<W1O
M=FYI(&YAZ&EN('-E<W1A=FQJ86YJ82(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0Q.0IM<V=I9"`B5&5?>'0B"FUS9W-T<B`B0F5S95]D
M:6QO(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.0HC+"!F=7IZ
M>0IM<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B3VML979A:F_H92!3<')E
M:F5T;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@
M(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(D]K;&5V86IO
MZ&4@4W!R96IM:2!Z86AT979O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<V,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B
M3VML979A:F_H92!3<')E:F5T;R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E
M<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP
M(@IM<V=S='(@(D1A=&]T96MA(',@4&]G;VII('5P;W)A8F4@;FD@<&]D86YA
M('8@8V]N9BYP:'`B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,S`*(RP@9G5Z>GD*;7-G:60@(E1E>'0B"FUS9W-T<B`B0F5S95]D:6QO
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU-`IM<V=I9"`B5&AE($9R
M;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.B(*
M;7-G<W1R(")0;W9E>F%V82!V('-T;VQP8W4@3V0Z(&YA:B!K8;YE(&YA.B(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3,R"FUS9VED("(B"B)4:&4@24U!
M4"!S97)V97(@9&]E<R!N;W0@87!P96%R('1O('-U<'!O<G0@=&AE(&%U=&AE
M;G1I8V%T:6]N(&UE=&AO9"`B"B)S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@
M>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0IM<V=I9"`B5&AE($UA
M8VEN=&]S:"!R97-O=7)C92!F;W)K(@IM<V=S='(@(DUA8VEN=&]S:"!R97-U
M<G-I(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O
M<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(DUA8VEN=&]S:"!R
M97-U<G-E(&QA:&MO(&1O8FET92!Z("5S+B(*"B,Z(&9E=&-H;6%I;'!R969S
M+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4F'H=6X@7"(E<UPB(&IE
M(&)I;"!P;V)R:7-A;BXB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R(")28>AU;B!<(B5S7"(@:F4@8FEL('-H<F%N:F5N
M+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C0S"FUS9VED(")4:&4@871T86-H;65N
M="!W87,@;F]T(&9O=6YD+B(*;7-G<W1R(")0<FEP;VYK92!N:2!M;V=OZ&4@
M;F%J=&DN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y"B,L(&9U
M>GIY"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S
M='(@(CQB/E!O9&%T:VD@=B!K;VQE9&%R:G4@;FES;R!V96QJ879N:3PO8CXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-O;7!O<V5?=VEN+FIS
M.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@;W!E
M;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB
M8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB3VMN82!Z82!S97-T
M879L:F%N:F4@<W!O<F_H:6P@;FD@;6]G;^AE(&]D<')E=&DN($UO9V_H92!I
M;6%T92!V(&)R<VMA;&YI:W4@(@HB;VYE;6]G;^AE;F$@<&]P=7`@;VMN83\B
M"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED
M(")4:&4@8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO
M=RXB"FUS9W-T<B`B5G-E8FEN82!-86-I;G1O<V@@9&%T;W1E:V4@:F4@<')I
M:V%Z86YA('-P;V1A:BXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA
M;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M
M960@=&\@7"(E<UPB+B(*;7-G<W1R(")4<F5N=71N82!M87!A(%PB)7-<(B!B
M;R!P<F5I;65N;W9A;F$@=B!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R
M<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T
M<FEE=F5D(@IM<V=S='(@(B(*(E1R96YU=&YE9V$@<V5Z;F%M82!U<&]R86)N
M:6MO=B!Z(&1O<W1O<&]M(&1O('1E(&UA<&4@;FD@;6]G;^AE('!R96)R871I
M(@H*(SH@8V]M<&]S92YP:'`Z,3(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F;VQD97(N
M(@IM<V=S='(@(D]S;G5T96L@:F4@8FEL('-H<F%N:F5N('8@;6%P;R!<(B5S
M7"(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S.0IM<V=I9"`B
M5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G<W1R
M(")$;V=O9&5K(&IE(&)I;"!D;V1A;B!N82!V8;D@:V]L961A<BXB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.CD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD
M960N(@IM<V=S='(@(E!O;&IA("<E<R<@;FD@;6]G;^AE(')A>KEI<FET:2XB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B36%P
M82!<(B5S7"(@OF4@;V)S=&%J82(*"B,Z(&QI8B]&;VQD97(N<&AP.C$V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@9F]L9&5R(%PB)7-<(B!C;VYT
M86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C
M875S92`B"B)P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("(B"B)-87!A(%PB)7-<(B!V<V5B=6IE('8@
M<W9O:F5M(&EM96YU(&YE=F5L:F%V;F4@>FYA:V4N(%1O(&QA:&MO('!O=GIR
M;^AI("(*(G1EOF%V92X@4')O<VEM(&MO;G1A:W1I<F%J=&4@<W9O:F5G82!S
M:W)B;FEK82!S:7-T96UA+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@8W)E871E
M9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@:70N(@IM<V=S='(@
M(DUA<&$@7"(E<UPB(&IE(&)I;&$@=7-T=F%R:F5N82P@=F5N9&%R(&YA;FIO
M(&YI<W1E(&YA<F_H96YI+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@9&5L971E
M9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(&ET+B(*;7-G
M<W1R(")-87!A(%PB)7-<(B!J92!B:6QA(&EZ8G)I<V%N82P@=F5N9&%R('-E
M(&]D(&YJ92!N:7-T92!O9&IA=FEL:2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(DUA<&4@7"(E<UPB(&YI(&)I;&\@;6]G;^AE('5S='9A<FET:2X@
M4W1R9;YN:6L@:F4@:F%V:6PB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A
M<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*
M;7-G<W1R(")-87!A("<E<R<@;FD@8FEL82!I>F)R:7-A;F$N(%-T<F6^;FEK
M(&IE(&IA=FEL(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@
M8W)E871E9"XB"FUS9W-T<B`B36%P82!<(B5S7"(@:F4@8FEL82!U<W!EN6YO
M('5S='9A<FIE;F$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L
M;'D@9&5L971E9"XB"FUS9W-T<B`B36%P82!<(B5S7"(@:F4@8FEL82!U<W!E
MN6YO(&EZ8G)I<V%N82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B36%P82!<(B5S7"(@
M:F4@8FEL82!U<W!EN6YO('!R96EM96YO=F%N82!V(%PB)7-<(BXB"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I
M;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@
M(DYA<VQE9&YJ92!D871O=&5K92!S;R!B:6QE('!R:7!E=&4@=&5M(&1E;'4Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]S879E:6UA9V5?=VEN
M+FIS.C$R"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@:6UA9V4@<V%V92!W:6YD
M;W<@8V%N(&YO="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO
M=7(@8G)O=W-E<B`B"B)T;R!B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R
M("(B"B)/:VYA('IA('-E<W1A=FQJ86YJ92!S<&]R;^AI;"!N:2!M;V=OZ&4@
M;V1P<F5T:2X@36]G;^AE(&EM871E('8@8G)S:V%L;FEK=2`B"B)O;F5M;V=O
MZ&5N82!P;W!U<"!O:VYA/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B
M96-A=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E
M<W-B;V]K+B(*;7-G<W1R(")3;&EK92!B;V1O('!R:6MA>F%N92P@:V5R(&IE
M('!ON6EL:F%T96QJ('!R:7-O=&5N('8@=F&Y96T@861R97-A<FIU+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I
M;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G
M93HB"FUS9W-T<B`B4&^Y=&YI('-T<F6^;FEK(&IE(&IA=FEL(&YA<VQE9&YJ
M;R!N87!A:V\Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-3$*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O
M;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z(@IM<V=S='(@(E!ON71N
M:2!S=')EOFYI:R!J92!J879I;"!N87-L961N:F\@:6YF;W)M86-I:F\Z(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H92!M
M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.B(*
M;7-G<W1R(")0;[ET;FD@<W1R9;YN:6L@:F4@:F%V:6PZ(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C8U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;6%I;&)O
M>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R(").86)I<F%L;FEK("5S
M(&IE(+YE('!R87IE;BXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E
M<UPB("@E9"!B>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G
M<W1R(")3<&]R;^AI;&\@7"(E<UPB(&EZ(%PB)7-<(B`H)60@8GET;W8I('!R
M97-E9V$@;VUE:FET978N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ,#,*;7-G:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D
M(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B4W!O<F_H:6QO
M+"!K:2!S=&4@9V$@<V5S=&%V;&IA;&D@<V4@:F4@>F%P<FQO+B(*"B,Z(&UE
M<W-A9V4N<&AP.C$T.`IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B4W!O<F_H:6QO(&IE(&)I;&\@<&]B<FES86YO+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,PIM<V=I9"`B5&AE(&UE
M<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(E-P;W)OZ&EL;R!J
M92!B:6QO(&]V97)J96YO+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA<R!B
M965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R(")3<&]R;^AI;&\@
M:F4@8FEL;R!O=F5R:F5N;RX@4&^Y:6QJ871E;&HZ("5S+B(*"B,Z('1E;7!L
M871E<R]S;6EM92]O<&5N7W-M:6UE7W=I;BYJ<SHQ,"!T96UP;&%T97,O<&=P
M+V]P96Y?<&=P7W=I;BYJ<SHQ,`IM<V=I9"`B(@HB5&AE('!A<W-P:')A<V4@
M=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@
M>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S
M='(@(B(*(D]K;F$@>F$@9V5S;&\@;FD@;6]G;^AE(&]D<')E=&DN($UO<F1A
M(&IE('9AN2!B<G-K86QN:6L@;F%S=&%V;&IE;B!T86MO+"!D82`B"B)N92!D
M;W9O;&IU:F4@<&]P=7`@;VME;C\B"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F
M('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M(")3=7)O=F\@8F5S961I;&\@2F%V;F5G82!01U`@:VQJ=>AA(&IE(&UO9V_H
M92!V:61E=&D@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C8P
M"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@
M=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B6F%H=&5V86YA(&1A
M=&]T96MA(&YE(&]B<W1A:F$@=B!-4RU43D5&('!R:7!O;FMI+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"FUS9VED(")4:&4@<F5Q=65S=&5D
M(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM96YT+B(*
M;7-G<W1R("):86AT979A;F$@9&%T;W1E:V$@;F4@;V)S=&%J82!V(%II<"!P
M<FEP;VYK:2XB"@HC.B!M97-S86=E+G!H<#HU-#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S
M=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("(*(F9R
M;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S
M92!C;&EC:R`E<R!T;R!S96YD('1H92`B"B)N;W1I9FEC871I;VX@;65S<V%G
M92XB"FUS9W-T<B`B(@HB4&^Y:6QJ871E;&H@<W!O<F_H:6QA(&IE('IA:'1E
M=F%L($]B=F5S=&EL;R!O(&1I<W!O>FEC:6II('-P;W)OZ&EL82P@:V\@(@HB
M8F]S=&4@<')E8G)A;&D@=&\@<W!O<F_H:6QO+B!0<F]S:6T@:VQI:VYI=&4@
M)7,@>F$@<&^Y:6QJ86YJ92!/8G9E<W1I;&$N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(E1H92!S97)V97(@
M=V%S(&YO="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM
M86=E+B(*;7-G<W1R(")+;&EK;FET92`E<R!Z82!P<FEK87H@<VQIZ&EC92!T
M92!S;&EK92XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P
M-`IM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N
M(@IM<V=S='(@(E!O9'!I<V$@;FD@8FEL;R!M;V=OZ&4@>F%M96YJ871I+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`R"FUS9VED(")4
M:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N(@IM<V=S
M='(@(E!O9'!I<R!J92!B:6P@=7-P9;EN;R!Z86UE;FIA;BXB"@HC.B!A='1A
M8VAM96YT+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R(").879E9&5N82!D871O=&5K82!N92!O8G-T
M86IA+B(*"B,Z('-T871I;VYE<GDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@861D
M960N(@IM<V=S='(@(E)AZ'5N(%PB)7-<(B!J92!B:6P@<VAR86YJ96XN(@H*
M(SH@<W1A=&EO;F5R>2YP:'`Z-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R(")28>AU;B!<(B5S7"(@:F4@8FEL('!O8G)I<V%N+B(*"B,Z('-T
M871I;VYE<GDN<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@=7!D871E9"XB"FUS9W-T
M<B`B4F'H=6X@7"(E<UPB(&IE(&)I;"!P;V)R:7-A;BXB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,38Y"FUS9VED(")4:&4@=&%S:R!H87,@8F5E
M;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R(")/<')A=FEL;R!J
M92!B:6QO(&1O9&%N;R!N82!V8;D@<V5Z;F%M(&]P<F%V:6PN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G:60@(E1H92!T97AT(&]F
M('1H92!M97-S86=E(@IM<V=S='(@(D)E<V5D:6QO('-P;W)OZ&EL82(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W960@
M)7,N(@IM<V=S='(@(D)E<V5D:6QO('-P;W)OZ&EL82!J92!M;V=OZ&4@=FED
M971I("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R
M(")"97-E9&EL;R!V<FYJ96YE9V$@<W!O<F_H:6QA(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B0F5S961I;&\@=G)N:F5N96=A('-P;W)OZ&EL82!J92!M
M;V=OZ&4@=FED971I("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C8X"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S
M86=E(@IM<V=S='(@(D)E<V5D:6QO('!O<VQA;F5G82!S<&]R;^AI;&$B"@HC
M.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(D)E<V5D:6QO('!O<VQA;F5G82!S
M<&]R;^AI;&$@:F4@;6]G;^AE('9I9&5T:2`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,34T"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R
M(")5<&]R86)N:6MO=F$@:6YF;W)M86-I:F$@<')O<W0O>F%S961E;B!J92!B
M:6QA('5S<&6Y;F\@<VAR86YJ96YA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A
M;'1E<FYA=&EV92YP:'`Z.#8*;7-G:60@(E1H97)E(&%R92!N;R!A;'1E<FYA
M=&EV92!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G
M<W1R("(B"B).:2!A;'1E<FYA=&EV;FEH(&1E;&]V('-P;W)OZ&EL82P@:VD@
M8FD@:FEH(&)I;&\@;6]G;^AE('!R:6MA>F%T:2!V(&]K=FER:G4N(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z,PIM<V=I9"`B
M5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"XB"FUS9W-T
M<B`B5B!T96T@;F%B:7)A;&YI:W4@;FD@<W!O<F_H:6PN(@H*(SH@=&AR96%D
M+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&ES(&YO('1E>'0@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@HB3FD@86QT
M97)N871I=FYI:"!D96QO=B!S<&]R;^AI;&$L(&MI(&)I(&II:"!B:6QO(&UO
M9V_H92!P<FEK87IA=&D@=B!O:W9I<FIU+B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HV,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!E>'!U;F=I;F<@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B
M"FUS9W-T<B`B4')I('!R87IN96YJ=2`E<R!J92!P<FFY;&\@9&\@;F%P86ME
M+B!3=')EOFYI:R!J92!J879I;"(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U
M;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B4')I('!R87IN96YJ=2!N86)I<F%L;FEK82!J92!P<FFY;&\@9&\@;F%P
M86ME+B!3=')EOFYI:R!J92!J879I;#H@)7,B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C(Q"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T
M:&4@;6%I;&)O>"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G
M<W1R(")0<FD@<')A>FYE;FIU(&YA8FER86QN:6MA(&IE('!R:;EL;R!D;R!N
M87!A:V4N(%-T<F6^;FEK(&IE(&IA=FEL(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI
M<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)0<FD@
M:V]P:7)A;FIU('-P;W)OZ&EL(&EZ(%PB)7-<(B!V(%PB)7-<(B!J92!P<FFY
M;&\@9&\@;F%P86ME+B!3=')EOFYI:R!J92`B"B)J879L:2(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HQ.3@@;&EB+TUE<W-A9V4N<&AP.C(Q,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S
M<V%G97,@9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T("(*
M(G1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)0<FD@8G)I<V%N:G4@<W!O
M<F_H:6P@:7H@;6%P92!<(B5S7"(@:F4@<')IN6QO(&1O(&YA<&%K92X@4W1R
M9;YN:6L@:F4@:F%V:6PB"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)0<FD@8G)I<V%N:G4@
M<W!O<F_H:6P@=B!M87!I(%PB)7-<(B!J92!P<FFY;&\@9&\@;F%P86ME+B!3
M=')EOFYI:R!J92!J879I;"`B"B)N87!A:V\B"@HC.B!L:6(O365S<V%G92YP
M:'`Z,C$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D96QE=&EN9R!M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@)7,B"FUS9W-T<B`B4')I(&)R:7-A;FIU('-P;W)OZ&EL(&IE('!R
M:;EL;R!D;R!N87!A:V4N(%-T<F6^;FEK(&IE(&IA=FEL.B`E<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB
M"FUS9W-T<B`B4')I(&)R:7-A;FIU(&1O9V]D:V$@:F4@<')IN6QO(&1O(&YA
M<&%K93H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU,B!L
M:6(O34E-12]6:65W97(O96YR:6-H960N<&AP.C,W"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G
M<W1R(")0<FD@<')I:V%Z;W9A;FIU('1E9V$@9&5L82!S<&]R;^AI;&$@:F4@
M<')IN6QO(&1O(&YA<&%K92XB"@HC.B!L:6(O365S<V%G92YP:'`Z-30U(&QI
M8B]-97-S86=E+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD
M97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM
M<V=S='(@(B(*(E!R:2!O>FYAZ&5V86YJ=2!S<&]R;^AI;"!V(&UA<&D@7"(E
M<UPB(&IE('!R:;EL;R!D;R!N87!A:V4N(%-T<F6^;FEK(&IE("(*(FIA=FEL
M;F%P86MO(@H*(SH@9F]L9&5R<RYP:'`Z,38U"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N(@IM<V=S='(@
M(E!R:2!U=F&^86YJ=2`E<R!J92!P<FFY;&\@9&\@;F%P86ME+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S
M+B(*;7-G<W1R(")0<FD@=79AOF%N:G4@9&]G;V1K82!J92!P<FFY;&\@9&\@
M;F%P86ME.B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38V
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R(")0<FD@=79AOF%N:G4@;W!R
M879I;&$@:F4@<')IN6QO(&1O(&YA<&%K93H@)7,B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O
M<FUA=&EO;CH@)7,N(@IM<V=S='(@(B(*(E!R:2!U=F&^86YJ=2!U<&]R86)N
M:6MO=F4@:6YF;W)M86-I:F4@<')O<W0O>F%S961E;B!J92!P<FFY;&\@9&\@
M;F%P86ME.B`E<RXB"@HC.B!L:6(O365S<V%G92YP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S
M86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@
M(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB4')I('!R96UI:V%N:G4@<W!O
M<F_H:6P@:7H@7"(E<UPB('8@7"(E<UPB(&IE('!R:;EL;R!D;R!N87!A:V4N
M(%-T<F6^;FEK(&IE("(*(FIA=FEL(&YA<&%K;R(*"B,Z(&-O;7!O<V4N<&AP
M.C$R-#0*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M
M97-S86=E(&%S(&$@9')A9G0N(@IM<V=S='(@(E!R:2!S:')A;FIE=F%N:G4@
M<W!O<F_H:6QA(&MO="!O<VYU=&5K(&IE('!R:;EL;R!D;R!N87!A:V4N(@H*
M(SH@8V]M<&]S92YP:'`Z,3`P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM<V=S
M='(@(E!R:2!P;[EI;&IA;FIU('9AN65G82!S<&]R;^AI;&$@:F4@<')IN6QO
M(&1O(&YA<&%K93H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")0<FD@;W-V9;YE=F%N
M:G4@9&]G;V1K82!J92!P<FFY;&\@9&\@;F%P86ME.B`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O<&QA:6XN<&AP.C4Y"FUS9VED(")4:&5R92!W87,@;F\@
M=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")6('1E;2!D96QU
M('-P;W)OZ&EL82!N:2!B:6QO(&)E<V5D:6QA(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VAT;6PN<&AP.CDW"FUS9VED(")4:&ES($A434P@;65S<V%G92!H87,@
M:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B(*;7-G<W1R(")4;R!(5$U,('-P;W)O
MZ&EL;R!I;6$@=F=N97ID96YE('-L:6ME+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HY,`IM<V=I9"`B(@HB5&AI<R!(5$U,(&UE<W-A9V4@:&%S
M(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R
M(&QI:V4@(@HB=&AI<SH@(@IM<V=S='(@(B(*(E1O($A434P@<W!O<F_H:6QO
M(&EM82!V9VYE>F1E;F4@<VQI:V4N($)L;VMI<F%N92!S;&EK92!S;R!P<FEK
M87IA;F4@=&%K;SH@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V
M"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T
M:&4@;65S<V%G92XB"FUS9W-T<B`B5&$@2F%V;FD@4$=0(&ML:G7H(&IE(&)I
M;"!P<FEP970@<W!O<F_H:6QU+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,#0@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q.`HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,30S(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-3<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,R!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,S$T"FUS9VED(")4:&ES(&%C=&EO;B!I
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")4;R!D96IA;FIE(&YI('!O9'!R
M=&\N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W.2!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#$Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N
M;W0@>65T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")4;R!D96IA;FIE(+EE(&YI
M(&EM<&QE;65N=&ER86YO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,30*;7-G:60@(E1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_(@IM<V=S='(@(B(*
M(E1O(&1E:F%N:F4@;&%H:V\@=')A:F$@9&%L:B#H87-A+B!3=&4@<')E<')I
MZ&%N:2!D82"^96QI=&4@;F%D86QJ979A=&D_(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%P<&QE9&]U8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E(&-O
M;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N(@IM<V=S='(@(E1O('-P;W)OZ&EL
M;R!V<V5B=6IE($UA8VEN=&]S:"!D871O=&5K;RXB"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C0Q,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O
M;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D:6=I=&%L;'D@
M<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(B(*(E-P;W)OZ&EL;R!V
M<V5B=6IE('!R:7!O;FMO+"!K:2!J92!B:6QA(&1I9VET86QN;R!P;V1P:7-A
M;F$@<')E:V\@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#$T"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H
M;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G
M<W1R(")4;R!S<&]R;^AI;&\@=G-E8G5J92!P<FEP;VYK;RP@:VD@:F4@8FEL
M82"Y:69R:7)A;F$@<')E:V\@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C$V,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A
M:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE
M(&9O<FUA="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T
M<B`B(@HB5&\@<W!O<F_H:6QO('9S96)U:F4@<&]R;^AI;&\@;R!D;W-T879I
M('-P;W)OZ&EL82P@9F]R;6%T('1E9V$@<W!O<F_H:6QA('!A("(*(FIE(&YE
M>FYA;BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,34*;7-G:60@
M(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R<F]R.B`B"FUS9W-T<B`B5&\@
M<W!O<F_H:6QO(&YI('9E;&IA=FYO(%!'4""Y:69R:7)A;F\@<W!O<F_H:6QO
M+B!.87!A:V$Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(T,"!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HS-3`*;7-G:60@(B(*(E1H:7,@;65S
M<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0
M(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T<B`B
M5&\@<W!O<F_H:6QO(&_H:71N;R!N:2!V('!R879I;&YI(%!'4"!O8FQI:VD@
M*&=L961E(&YA(%)&0R`R,#$U*2XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C$W,`IM<V=I9"`B5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R;6%T+B(*;7-G<W1R
M(")4;R!S<&]R;^AI;&\@;^AI=&YO(&YI('8@<')A=FEL;FD@4R]-24U%(&]B
M;&EK:2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#4@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z-#$V"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S
M(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G<W1R(")4;R!S
M<&]R;^AI;&\@:F4@8FEL;R!D:6=I=&%L;F\@<&]D<&ES86YO('!R96MO(%!'
M4"XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T,PIM<V=I9"`B
M5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O
M34E-12XB"FUS9W-T<B`B5&\@<W!O<F_H:6QO(&IE(&)I;&\@9&EG:71A;&YO
M('!O9'!I<V%N;R!P<F5K;R!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HQ,SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*
M;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O
M34E-12XB"FUS9W-T<B`B5&\@<W!O<F_H:6QO(&IE(&)I;&\@N6EF<FER86YO
M('!R96MO(%,O34E-12XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M,#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDQ"FUS9VED(")4:&ES(&UE
M<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R(")4
M;R!S<&]R;^AI;&\@:F4@8FEL;R"Y:69R:7)A;F\@<')E:V\@4$=0+B(*"B,Z
M(&UE<W-A9V4N<&AP.C(Q,0IM<V=I9"`B5&AI<R!M97-S86=E('1O(@IM<V=S
M='(@(E1O('-P;W)OZ&EL;R!K(@H*(SH@86-L+G!H<#HT-@IM<V=I9"`B5&AI
M<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM
M<V=S='(@(E-T<F6^;FEK(&YE('!O9'!I<F$@<VMU<&YE(')A8F4@;6%P+B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W
M:6YD;W<N(@IM<V=S='(@(E1O(&]K;F\@;6]R871E(&]D<')E=&D@:7H@;VMN
M82!Z82!S97-T879L:F%N:F4@<W!O<F_H:6QA+B(*"B,Z('1H<F5A9"YP:'`Z
M,34R"B,L(&9U>GIY"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G<W1R(")0
M<FEK87HB"@HC.B!T:')E860N<&AP.C<V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,C(*;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@(E!O9VQE9"!P;V=O
M=F]R82(*"B,Z(&UE<W-A9V4N<&AP.C(V-"!M86EL8F]X+G!H<#HV,#8@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,3D*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,B!T96UP;&%T97,O8V]M
M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C
M;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H+G!H<#HR-@IM<V=I9"`B5&\B"FUS
M9W-T<B`B6F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$Y"FUS9VED
M(")4;R!!9&1R97-S(@IM<V=S='(@(EIA($YA<VQO=B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM<V=I9"`B(@HB5&\@<V5L
M96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A0
M0RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C;&EC:VEN9RXB"FUS9W-T
M<B`B(@HB6F$@:7IB:7)O('9EZ&EH('!O;&HL(&1ROFET92!T:7!K;R!#;VYT
M<F]L("A00RD@86QI($-O;6UA;F0@*$UA8RD@;65D=&5M(&MO("(*(FML:6MA
M=&4@;F$@<&]L:F$N(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HQ,S0*;7-G
M:60@(B(*(E1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B92!R
M=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@-2XP+C8@;W(@(@HB:&EG:&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M-S<*;7-G:60@(E1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z(@IM<V=S='(@(E-K
M=7!N82!V96QI:V]S="!0<FEP;VYK.B(*"B,Z(&9O;&1E<G,N<&AP.C,X.`IM
M<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(DUA<&$@<R!S;65T;6DB"@HC
M.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4
M<F%S:"!F;VQD97(Z(@IM<V=S='(@(DUA<&$@<R!S;65T;6DB"@HC.B!L:6(O
M475O=&$O8WER=7,N<&AP.C8U(&QI8B]1=6]T82]M97)C=7)Y,S(N<&AP.C<Y
M(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC.B!L:6(O475O=&$O;&]G9FEL
M92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP.C4S(&QI8B]1=6]T82]M
M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O(')E=')I979E('%U;W1A
M(@IM<V=S='(@(DYI(&)I;&\@;6]G;^AE('!R96)R871I(&MV;W1E(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,"!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS=V5R960B"FUS9W-T<B`B
M3F5O9&=O=F]R:F5N;R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M,S4*;7-G:60@(E5N86YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B3F5O9&=O
M=F]R:F5N82!S<&]R;^AI;&$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHQ,PIM<V=I9"`B56YD96QE=&4B"FUS9W-T<B`B3F4@:7IB<FFY:2(*"B,Z
M(&UA:6QB;W@N<&AP.C4X.2!M86EL8F]X+G!H<#HV,#(@;&EB+TU)344O2&5A
M9&5R<RYP:'`Z,C$R"FUS9VED(")5;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM
M<V=S='(@(E-K<FET:2!0<F5J96UN:6MI(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@
M8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(DYE;V)R879N879A;F$@
M:V]M<&]N96YT82!T:7!A.B`E<R(*"B,Z(&UA:6QB;W@N<&AP.C4V-0IM<V=I
M9"`B56YK;F]W;B!$871E(@IM<V=S='(@(DYE>FYA;B!D871U;2(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M:VYO=VX@24U!4"!R97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!2
M97-P;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,S4*;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R(").
M97IN86X@<V5S=&%N96LB"@HC.B!M86EL8F]X+G!H<#HV,3@*;7-G:60@(E5N
M:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@(DYE>FYA;B!0<F5J96UN:6LB"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`B
M3V1N86QOOFD@9V5S;&\B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-C4*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`B3F5I;65N;W9A;B(*"B,Z(&UE<W-A9V4N
M<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*
M;7-G<W1R(").979I9&5N;R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C$R"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS*2(*
M;7-G<W1R(")/9&IA=FD@<V4@;V0@36%P*&4I(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3@T"FUS9VED(")5<&1A=&4@071T86-H;65N
M="!);F9O<FUA=&EO;B(*;7-G<W1R(")/<W9EOFD@:6YF;W)M86-I:F4@;R!P
M<FEP;VYK:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C`*;7-G
M:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R(")/<W9EOFD@
M<W1A;FIE(&1O<&ES;FEK82(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS
M9VED(")5<&QO860B"FUS9W-T<B`B4&]S;F5M:2!N82!S=')EOFYI:R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*;7-G:60@
M(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(E5P;W)A8FD@<')I=GIE=&\@
M=G)E9&YO<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED
M(")5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T<B`B57!O
M<F%B;&IA;2!N87)OZ&%N:F4@;F$@24U!4"!M87!E/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW,S4*(RP@9G5Z>GD*;7-G:60@(E5S92!6:7)T=6%L
M(%1R87-H($9O;&1E<C\B"FUS9W-T<B`B3F%V:61E>FYE($UA<&4B"@HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,30R"FUS9VED(")5<V5R(@IM<V=S='(@
M(E5P;W)A8FYI:R(*"B,Z(&%C;"YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T
M:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(E5P;W)A8FYI:R`G)7,G(&IE('5S<&6Y;F\@;F%S=&%V:6P@:6UE
M;F]V86YE('!R879I8V4@>F$@;6%P;R`G)7,G+B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3<W"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")5
M<&]R86)N:;EK;R!I;64B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,3<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")5<&]R86)N:;EK
M;R!I;64Z(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*
M;7-G:60@(E9I97<B"FUS9W-T<B`B4')I:V&^:2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]Z:7`N<&AP.CDR(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")0<FEK8;YI
M("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(E!R:6MAOFD@)7,@2F%V;FD@:VQJ=>@B
M"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"FUS9VED(")6:65W
M($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")0
M<FEK8;YI($A434P@=G-E8FEN;R!V(&QOZ&5N96T@;VMN=2(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X"B,L(&9U>GIY"FUS9VED(")6
M:65W($UE<W-A9V5S(@IM<V=S='(@(DYO=F$@<W!O<F_H:6QA(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T
M<B`B4')I:V&^:2!O<V5B;FD@6F%S96)N:2!K;&IUZ"(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R
M"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B4')I
M:V&^:2!O<V5B;FD@2F%V;FD@:VQJ=>@B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3@*;7-G:60@(E9I97<@5&AR96%D(@IM
M<V=S='(@(E!R:6MAOFD@<&]G;W9O<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$V,R!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C4*
M;7-G:60@(E9I97<@5&AU;6)N86EL(@IM<V=S='(@(E!R:6MAOFD@<VQIZ&EC
M;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X"FUS9VED(")6
M:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B
M4')I:V&^:2!P<FEP;VYK;R!V(&QOZ&5N96T@;VMN=2(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!C
M;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(E!R:6MAOFD@
M2%1-3"!V<V5B:6YO('8@;&_H96YE;2!O:VYU(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R(")0
M<FEK8;YI(&1O9V]D96LB"@HC.B!F;VQD97)S+G!H<#HS.#`@;6%I;&)O>"YP
M:'`Z-3,T"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@;65S<V%G97,@:6X@
M)7,B"FUS9W-T<B`B4')I:V&^:2!S<&]R;^AI;&$@=B`E<R(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,C,*;7-G:60@(E9I
M97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.B(*;7-G<W1R
M(")0;V=L960@86QI(&YA8FER86QN:6LL(&MI(&=A('!R:6MAOF5M('!O('!R
M:6IA=FDZ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,`IM<V=I
M9"`B5FEE=R!T87-K(@IM<V=S='(@(E!R:6MAOFD@;W!R879I;&\B"@HC.B!L
M:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`Q"FUS9VED(")6:65W('1H92!)
M;6%G97,B"FUS9W-T<B`B4')I:V&^:2!S;&EK92(*"B,Z('-E87)C:"YP:'`Z
M,C8S"B,L('!H<"UF;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<
M(B!C<F5A=&5D('-U8V-E<V9U;&QY+B(*;7-G<W1R(").879I9&5Z;F$@;6%P
M82!<(B5S7"(@=7-P9;EN;R!U<W1V87)J96YA+B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])34%0+U1R964N<&AP.C$S."!L:6(O
M24U!4"]4<F5E+G!H<#HQ-3$*(SH@;&EB+TE-05`O5')E92YP:'`Z,34S(&QI
M8B])34%0+U1R964N<&AP.C$U-R!L:6(O24U!4"]4<F5E+G!H<#HQ-3@*(SH@
M;&EB+TE-05`O5')E92YP:'`Z,S8Y(&QI8B])34%0+U1R964N<&AP.C,Y,R!L
M:6(O24U!4"]4<F5E+G!H<#HT,S,*;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*
M;7-G<W1R(").879I9&5Z;F4@36%P92(*"B,Z('-E87)C:"YP:'`Z,C0U"B,L
M(&9U>GIY"FUS9VED(")6:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA8F5L
M+B(*;7-G<W1R(")/>FYA:V$@;F%V:61E>FYE(&UA<&4B"@HC.B!L:6(O5D9O
M;&1E<BYP:'`Z,3<U(&QI8B]61F]L9&5R+G!H<#HQ.#`*;7-G:60@(E9I<G1U
M86P@24Y"3U@B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#$V"B,L(&9U
M>GIY"FUS9VED(")6:7)T=6%L($E.0D]8($9O;&1E<B(*;7-G<W1R(").879I
M9&5Z;F4@36%P92(*"B,Z(&UA:6QB;W@N<&AP.C0U,B!L:6(O5D9O;&1E<BYP
M:'`Z,3$T(&QI8B]61F]L9&5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(E9I
M<G1U86P@5')A<V@B"FUS9W-T<B`B3F%V:61E>FYE($UA<&4B"@HC.B!F;VQD
M97)S+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(E9I<G1U86P@5')A<V@@1F]L
M9&5R(@IM<V=S='(@(DYA=FED97IN92!-87!E(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U86P@9F]L9&5R(&QA8F5L
M(@IM<V=S='(@(D]Z;F%K82!N879I9&5Z;F4@;6%P92(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,S<T"B,L(&9U>GIY"FUS9VED(")787)N:6YG
M(@IM<V=S='(@(E)A>KEI<F%N:F4B"@HC.B!L;V=I;BYP:'`Z,3,X"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B1&]B<F]D
M;[EL:2!V("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.0HC+"!F
M=7IZ>0IM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE
M<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@
M(@HB;W(@:6YN;V-E;G0_(@IM<V=S='(@(E!O8G)IN65M(&YE>F&^96QE;F$@
M<W!O<F_H:6QA(&MO('-O(&)I;&$@<')I:F%V;&IE;F$_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<R-PIM<V=I9"`B(@HB5VAE;B!D96QE=&EN9R!M
M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E
M860@;V8@;6%R:VEN9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM<V=S='(@(B(*
M(DMO(&)R:;EE;2!S<&]R;^AI;&$L(&II:"!P<F5M86MN96T@=B!M87!O(%-M
M971I+"!N86UE<W1O(&1A(&II:"!O>FYAZ&EM(&MO="`B"B)P;V)R:7-A;F4_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-PIM<V=I9"`B5VAE;B!O
M<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U('=A;G0@
M=&\@<W1A<G0@;VX_(@IM<V=S='(@(DMO('!R:6MA>G5J96T@;F]V(&YA8FER
M86QN:6LL(&YA(&MA=&5R:2!S=')A;FD@;F%J('IAZ&YE;3\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT
M+6UA:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T
M<B`B2V\@<VAR86YJ=6IE;2!P;W-L86YO(&4M<&^Y=&\L(&YA:B!S:')A;FEM
M('!R:7!O;FME/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C8*;7-G
M:60@(B(*(E=H96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N9&EN9R!A9&1R97-S
M97,L('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E;F0@=&\@(@HB=6YQ=6%L
M:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S97,@=VET:&]U="!<(D!<
M(BD_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ
M.0IM<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@(E=H:71E;&ES="(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3<X"FUS9VED(")997,B"FUS9W-T<B`B1&$B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C4X"FUS9VED
M(")9;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO
M=VEN9R!A8V-O=6YT*',I.B(*;7-G<W1R(")0<F5S;F5L:2!S:2!B;W-T92!E
M+7!ON71O('H@;F%S;&5D;FII:"!R8>AU;F]V.B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P"B,L(&9U>GIY"FUS9VED
M("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E
M<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM
M<V=S='(@(DEZ8G)I<V%L:2!B;W-T92!N87-L961N:F4@;6%P93HB"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HY"B,L(&9U
M>GIY"FUS9VED(")9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F
M;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G<W1R("))>F)R:7-A;&D@8F]S=&4@
M;F%S;&5D;FIE(&UA<&4Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C
M<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M,3DR"FUS9VED(")9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O
M;&1E<BXB"FUS9W-T<B`B2V]P:7)A=&4O<')E;6EK871E('8@;F]V;R!M87!O
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R"FUS
M9VED(")9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T
M<B`B57-T=F%R:F%T92!P;V0M;6%P;R!Z82`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B66]U(&%R92!C<F5A=&EN
M9R!A('1O<"UL979E;"!F;VQD97(N(@IM<V=S='(@(E5S='9A<FIA=&4@;6%P
M;RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@
M(E5S='9A<FIA=&4@;6%P;RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E
M(')E;F%M:6YG('1H92!F;VQD97(Z("(*;7-G<W1R(")0<F5I;65N;W9A;&D@
M8F]S=&4@;6%P;SH@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N(&YO="!U;G-U8G-C<FEB92!F
M<F]M(%PB)7-<(BXB"FUS9W-T<B`B57-P9;EN;R!S=&4@<V4@;V1J879I;&D@
M;V0@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C,U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!C86X@=7-E('1H92!F
M;VQL;W=I;F<@<&QA8V5H;VQD97)S(&EN('1H92!S=&%T:6]N97)Y('1E>'0Z
M("5C(&9O<B!T:&4@(@HB8W5R<F5N="!M97-S86=E(&-O;G1E;G0[("5S(&9O
M<B!T:&4@<VEG;F%T=7)E+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB66]U(&1I
M9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT
M+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB"FUS9W-T
M<B`B(@HB3FES=&4@<V4@<W1R:6YJ86QI(',@4')A=FEL:2!5<&]R86)E+"!Z
M871O('9A;2!P<FEJ879A(&YI(&)I;&$@9&]V;VQJ96YA+B(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ-CD*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS
M9W-T<B`B3FEM871E(&1O=F]L:F5N:F$@>F$@<W!R96UI;FIA;F4@9&]S=&]P
M82!D;R!T92!M87!E(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E
M)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T<B`B
M)25S('-T92!P;W-R961O=F%L:2!S<&]R;^AI;&\@<')E:F5M;FEK;VTZ("5S
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+B(*;7-G<W1R
M("));6%T92`E<R!N;W9I:"!S<&]R;^AI;"XB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A;&5R="YI;F,Z,PIM<V=I9"`B66]U(&AA=F4@,2!N97<@;65S<V%G
M92XB"FUS9W-T<B`B26UA=&4@,2!N;W9O('-P;W)OZ&EL;RXB"@HC.B!C;VUP
M;W-E+G!H<#HT.30*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&%L<F5A9'D@
M<W5B;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T<B`B26UA=&4@,2!N;W9O('-P
M;W)OZ&EL;RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ
M<SHQ,34*;7-G:60@(B(*(EEO=2!H879E(&%T(&QE87-T(&]N92!A='1A8VAM
M96YT('-E;&5C=&5D('1H870@>6]U(&1I9&XG="!U<&QO860@>65T+B!!<F4@
M(@HB>6]U('-U<F4@>6]U('=A;G0@=&\@<V5N9"!T:&ES(&UE<W-A9V4@=VET
M:&]U="!T:&5S92!A='1A8VAM96YT<S\B"FUS9W-T<B`B(@HB27IB<F%N;R!I
M;6%T;R!V<V%J(&5N;R!P<FEP;VYK;RP@:VD@:F4@N64@;FES=&4@<')E<VYE
M;&D@;F$@<W1R9;YN:6LN(%-T92`B"B)P<F5P<FGH86YI+"!D82"^96QI=&4@
M<&]S;&%T:2!S<&]R;^AI;&\@8G)E>B!T92!P<FEP;VYK93\B"@HC.B!L:6(O
M24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@
M9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`B3F]V82!S<&]R;^AI;&$@:6UA
M=&4@=B!N87-L961N:FEH(&UA<&%H.B(*"B,Z(&QI8B])35`N<&AP.C$P-SD*
M;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L
M9&5R<SHB"FUS9W-T<B`B3F]V82!S<&]R;^AI;&$@:6UA=&4@=B!N87-L961N
M:FEH(&UA<&%H.B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PIM<V=I9"`B66]U(&UU
M<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS9W-T<B`B5G!I
M<V%T:2!M;W)A=&4@=G-A:B!E;F5G82!P<F5J96UN:6MA+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,P,@IM<V=I9"`B(@HB66]U(&UU<W0@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O
M('9I97<@=&AI<R!M97-S86=E(@IM<V=S='(@(B(*(LAE(+YE;&ET92!V:61E
M=&D@<W!O<F_H:6QO+"!M;W)A=&4@=G!I<V%T:2!G97-L;R!Z82!S=F]J('IA
M<V5B;FD@4$=0(&ML:G7H(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HR-#D*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E
M(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB
M;65S<V%G92(*;7-G<W1R("(B"B+(92"^96QI=&4@=FED971I('-P;W)OZ&EL
M;RP@;6]R871E('9P:7-A=&D@9V5S;&\@>F$@<W9O:B!Z87-E8FYI(%,O34E-
M12!K;&IUZ"(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC
M.C8T('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(P,0IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM
M<V=S='(@(DYA:G!R96H@;6]R871E(&EZ8G)A=&D@8VEL:FYI(&YA8FER86QN
M:6LN(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9;W4@;75S
M="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R("))
M>F)R871I(&UO<F%T92!R8>AU;BP@:VD@9V$@OF5L:71E(&EZ8G)I<V%T:2XB
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C@Q"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B
M3F%J<')E:B!M;W)A=&4@:7IB<F%T:2!N87-L;W8N(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T
M(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R(").86IP<F5J(&UO<F%T92!I
M>F)R871I('9S86H@96YO('-P;W)OZ&EL;RXB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]R961I<F5C="YI;F,Z,3,*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!R96-I<&EE;G0N(@IM<V=S='(@(D1O;&_H:71I(&UO<F%T92!P<F5J96UN
M:6MA+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C(Y
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!F:6QE('1O
M(&%T=&%C:"XB"FUS9W-T<B`B27IB<F%T:2!M;W)A=&4@=G-A:B!E;F\@9&%T
M;W1E:V\L(&MI(&IO(+YE;&ET92!P<FEP971I+B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@96YA8FQE9"!I;B!Y;W5R
M(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@(E8@;6^^;F]S=&EH('9Z
M9'*^979A;FIA(&UO<F%T92!O;6]G;^AI=&D@)R5S)RXB"@HC.B!L:6(O36%I
M;&QO9RYP:'`Z,3,W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R961I<F5C
M=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N(@IM<V=S='(@(E-P;W)O
MZ&EL;R!S=&4@<')E=7-M97)I;&D@<R`E<R!N82`E)7,N(@H*(SH@;&EB+TUA
M:6QL;V<N<&AP.C$T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5P;&EE
M9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM<V=S='(@(DYA('-P;W)OZ&EL
M;R!S=&4@;V1G;W9O<FEL:2`E<RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HU,#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('-U8G-C<FEB960@
M=&\@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(DYA(%PB)7-<(B!N:7-T92!B:6QI(&YA<F_H96YI+B!3=')EOFYI:R!J
M92!J879I;"(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB
M+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(D]D(%PB
M)7-<(B!S92"Y92!N:7-T92!O9&IA=FEL:2X@4W1R9;YN:6L@:F4@:F%V:6PB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HU,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@7"(E<UPB(@IM
M<V=S='(@(E5S<&6Y;F\@<W1E('-E(&YA<F_H:6QI(&YA(%PB)7-<(B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB(@IM
M<V=S='(@(E5S<&6Y;F\@<W1E('-E(&]D:F%V:6QI(&]D(%PB)7-<(B(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHY.`IM<V=I9"`B66]U<B!.86UE(@IM
M<V=S='(@(E9AN64@:6UE(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4P
M"FUS9VED(")9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES(@IM<V=S='(@
M(E9AN6D@2F%V;FDO6F%S96)N:2!01U`@:VQJ=>AI(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*
M;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B5F&Y('IA<V5B;FD@
M:VQJ=>@B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW,0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y(@IM
M<V=S='(@(E9AN2!J879N:2!K;&IUZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-C4*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E
M<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`B5F&Y($]D9V]V;W)I
M+6YA.B!N87-L;W8Z(#QI/BAO<&-I:G-K;RD\+VD^(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHT.0IM<V=I9"`B66]U<B!3+TU)344@4'5B;&EC
M+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@(E9AN6$@2F%V;F$O6F%S
M96)N82!3+TU)344@<&]T<F1I;&$B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V%C8V]U;G1?<V5L96-T+FEN8SHQ-@IM<V=I9"`B66]U<B!A8V-O=6YT<SHB
M"FUS9W-T<B`B5F&Y:2!R8>AU;FDZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$W,PHC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S
M97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE
M=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(E9AN6D@9')U9VD@;F%S;&]V:3H@
M/&D^*&]P8VEJ<VMO+"!V<&FY:71E('9S86L@;F%S;&]V('8@<W9O:F\@=G)S
M=&\I/"]I/B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDR"FUS
M9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES
M<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(E9AN2!B<G-K86QN
M:6L@;F4@<&]D<&ER82!P<FEK87H@=&4@=G)S=&4@<VQI:R!V(&]K=FER:G4N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D
M969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@
M(E9AN6$@<')I=GIE=&$@:V]D;F$@=&%B96QA('IA('!ON6EL:F%N:F4@<W!O
M<F_H:6PZ(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC
M.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@
M<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B5F&Y('!R:79Z970@;F'H:6X@
MN6EF<FER86YJ82!Z82!P;[EI;&IA;FIE('-P;W)OZ&EL.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C@Y"FUS9VED(")9;W5R(&UE<W-A9V4@
M=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(E9AN64@<W!O
M<F_H:6QO(&IE(&)I;&\@=7-P9;EN;R!D;W-T879L:F5N;RXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB
M"FUS9W-T<B`B5F&Y('!O9'!I<SHB"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M
M<&]S92YP:'`Z,3(X-"!M86EL8F]X+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP
M.C@Q.`IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM"<F5Z(%IA9&5V
M95TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*;7-G
M:60@(E]"8V,B"FUS9W-T<B`B7T)K:R(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ-@IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R(")?0FQA8VML
M:7-T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,34T"FUS
M9VED(")?0V,B"FUS9W-T<B`B7TMK(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`IM
M<V=I9"`B7T1E;&5T92(*;7-G<W1R(")?27IB<FFY:2(*"B,Z(&QI8B])35`N
M<&AP.CDW.0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`B7TUA<&4B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,0IM<V=I9"`B7TED96YT
M:71Y(@IM<V=S='(@(E])9&5N=&ET971A(@H*(SH@;&EB+TE-4"YP:'`Z.38Q
M"FUS9VED(")?26YB;W@B"FUS9W-T<B`B7TEN8F]X(@H*(SH@;&EB+TE-4"YP
M:'`Z,3`R,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7T]D:F%V82(*"B,Z
M(&UE<W-A9V4N<&AP.C,X-`IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S
M='(@(E])>G9O<FYA(&MO9&$@<W!O<F_H:6QA(@H*(SH@;&EB+TE-4"YP:'`Z
M.3<V"B,L(&9U>GIY"FUS9VED(")?3F5W($UE<W-A9V4B"FUS9W-T<B`B3F]V
M82!S<&]R;^AI;&$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S,*;7-G:60@(E]0<FEN="(*;7-G<W1R(")?3F%T:7-N:2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.#D*;7-G:60@(E]0<FEO<FET>2(*
M;7-G<W1R(")?4')I;W)I=&5T82(*"B,Z(&UA:6QB;W@N<&AP.C0Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")?4F5F<F5S:"`E<R(*;7-G<W1R(")?3W-V9;YI
M("5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C@*;7-G:60@(E]297!L>2(*;7-G<W1R(")?3V1G;W9O<FDB"@HC.B!L:6(O
M24U0+G!H<#HY.#$*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B7TFYZ&DB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,S$*;7-G:60@(E]396YD($UE<W-A9V4B
M"FUS9W-T<B`B7U!ON6QJ:2!3<&]R;^AI;&\B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,R"FUS9VED(")?5&AR96%D(@IM
M<V=S='(@(E]0;V=O=F]R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,3$V"FUS9VED(")?5&\B"FUS9W-T<B`B7UIA(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@(E]5;F1E;&5T92(*
M;7-G<W1R(")?3F4@:7IB<FFY:2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S
M='(@(E]0;V=L96H@4&]G;W9O<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R(")?5VAI=&5L:7-T
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W-@IM<V=I9"`B861D<F5S<V5E('5N
M:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0T,`IM<V=I
M9"`B871T86-H;65N="(*;7-G<W1R(")P<FEP;VYK82(*"B,Z('9I97<N<&AP
M.CDY"FUS9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B<')I<&]N:V4N
M>FEP(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS
M9VED(")B>71E<R(*;7-G<W1R(")B>71O=B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,#`*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W,@IM<V=I9"`B8V%N;F]T(&]P
M96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V-`IM
M<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR,C`*;7-G:60@(F-O;F9I9W5R871I;VX@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y-@IM<V=I9"`B
M8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,38X"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(T"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS9W-T<B`B;V0B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3@P"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`T"FUS9VED(")I
M;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$X.`IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C(Y('!G<"YP:'`Z-CD*;7-G:60@(FME>2(*
M;7-G<W1R(")K;&IUZ"(*"B,Z(&9O;&1E<G,N<&AP.C$V,0IM<V=I9"`B;6%I
M;&)O>"!F:6QE(@IM<V=S='(@(FYA8FER86QN:6LB"@HC.B!C;VUP;W-E+G!H
M<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*;7-G:60@(FYA;64B"FUS9W-T
M<B`B:6UE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<V
M"FUS9VED(")N;VYE(@IM<V=S='(@(FYO8F5N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B;W(B"FUS9W-T<B`B86QI
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q-@IM<V=I9"`B<&5R;6ES<VEO;B!D
M96YI960B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q,@IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ.#0*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R("+H<FMO=F%L;F$@
M;F%P86MA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V
M"FUS9VED(")S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`BZ')K;W9A;&YE(&YA
M<&%K92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3(*(RP@9G5Z>GD*;7-G:60@
M(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("+H<FMO=F%L;F$@;F%P86MA(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C(P.`IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z-3$*;7-G:60@(GEO=7(@
M8FQA8VML:7-T(@IM<V=S='(@(G9AN6$@8FQA8VML:7-T82(*"B,Z(&QI8B]&
M:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R(")V
M8;EA('=H:71E;&ES=&$B"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]P;R]B9U]"1RYP;P``````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`S-S0S-S(`,3`T,3<S-C(W-C0`,#$W,30V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@0G5L9V%R
M:6%N('1R86YS;&%T:6]N<R!F;W(@26UP('!A8VMA9V4N"B,@0V]P>7)I9VAT
M("A#*2`R,#`R($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I
M8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@26UP('!A8VMA
M9V4N"B,@36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^("!A
M;F0*(R!!=&%N87,@4W1O>6%N;W8@/&-H86]S0'!Z;VYL:6YE+FYE=#XL(#(P
M,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M($EM<"`T+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTQ,2TQ
M-"`P,#HS."TP-#`P7&XB"B),87-T+51R86YS;&%T;W(Z($UI<F]S;&%V(%!E
M;F1E=B`\;6ER;T!C>6)E<G-H861E+G5S/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M0D<@:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0U`Q,C4Q
M7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@("`@("!#8SH@
M(@IM<V=S='(@(B`@("`@(,3N.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$U
M"FUS9VED("(@("`@("!4;SH@(@IM<V=S='(@(B`@("`@(,3N.B`B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@1&%T93H@(@IM<V=S='(@
M(B`@("#$X/+@.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`V"FUS9VED("(@
M("`@1G)O;3H@(@IM<V=S='(@(B`@("`@(,[R.B`B"@HC.B!M86EL8F]X+G!H
M<#HT,C(@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C0Q,@IM<V=I9"`B(%-U8FIE8W0Z("(*;7-G<W1R("(@
M("`@TN7LX#H@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C<P"FUS9VED("(@:6X@(@IM<V=S='(@(B#B("(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T
M<B`B(R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HV.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*
M;7-G<W1R("+*XN[RX"#Q\N#R\_$Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2DB"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)60@365S<V%G97,B"FUS9W-T<B`B)60@[O(@)60@[^CQ[.`B"@HC
M.B!M86EL8F]X+G!H<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+/Z/'L
M[O+N(.'E^.4@[_#NXN7PY>WN+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("+2[N+@(._H\>SN(.'E^.4@Z.?O\.#RY>WN
M(.K@\NX@T>_@["#D[B#1Z/'RY>SMZ/\@P.3LZ.WH\?+PX/+N\"XB"@HC.B!L
M:6(O4W!A;2YP:'`Z,34X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM
M<V=S='(@(M+NXN`@[^CQ[.X@X>7XY2#PY>/H\?+PZ/#@[>X@ZN#R[B#Q[^#L
M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(M+NXN`@
M[^CQ[.X@X>7XY2#HY^_PX/+E[>X@ZN#R[B#1[^#L(.3N(-'H\?+E[.WH_R#`
MY.SH[>CQ\O#@\N[P+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O
M<G1E9"!A<R!S<&%M+B(*;7-G<W1R("+2[N+@(._H\>SN(.'E^.4@\.7CZ/'R
M\.CPX.WN(.K@\NX@\>_@["XB"@HC.B!M86EL8F]X+G!H<#HS-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@=&\@)60@;V8@)60@365S<V%G97,B"FUS9W-T
M<B`B)60@Y.X@)60@[O(@)60@[^CQ[.`B"@HC.B!M86EL8F]X+G!H<#HV-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL
M>2YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES
M=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B
M)7,@XN7WY2#Q^OGE\?+B\^+@+B#"X/C@\N`@[^#OZN`@)7,@[>4@X>7XY2#O
M\.7H[.7M\^+@[>`N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!M86EL8F]X+B(*;7-G<W1R("(E<R#MY2#E(.+@Z^CD[>`@[^[YY>WQZN`@
MZO/RZ/\N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9O
M;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N
M(@IM<V=S='(@(L_@[^K@("5S(.'E^.4@[_#EZ.SE[?/BX.W@(.(@[>#WX.ON
M\NX@[>`@[.7QY?;@+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET
M871I;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@
M>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!H87,@=&5N=&%T:79E;'D@86-C97!T960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC
M92!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(L_@[^K@\N`@7"(E<UPB(.'E
M^.4@\_'OY?CM[B#O\.7H[.7M\^+@[>`@[>`@7"(E<UPB+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=VES:&5S('1O(&%M;65N9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O
M<FUA=&EO;B!A8F]U="`E<RXB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z
M,C@U(&UE<W-A9V4N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@
M)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7W1O<"YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S("@E
M9"9N8G-P.V]F)FYB<W`[)60I(@IM<V=S='(@(B5S.B`E<R`H)60F;F)S<#ON
M\B9N8G-P.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHQ,S,*;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O
M(&YE>'0@<V-R965N+BDB"FUS9W-T<B`B*,_PZ.ONYN@@\N7GZ"#O\.[LY>WH
M(.@@[_#NY/KKYN@@ZOKL(/'KY>3BX/GH_R#EZO#@[2XI(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@
M86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN
M*2(*;7-G<W1R("+.\NK@YN@@XO'H]^KH(._P[NSE[>@@Z"#QY2#B^O#MZ"#J
M^NP@Y>KPX.W@(%PBS>#OZ/CH7"(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I
M;B!497AT*2(*;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP:'`Z,C@P"FUS9VED
M("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L
M>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O
M;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM
M<V=S='(@(B(*(BC"^O#MZ"#QY2#J^NP@Y>KPX.W@(%PBS>#OZ/CH7"(@\>OE
MY"#JX/+N(._PZ.ONYNCX(.+QZ/?JZ"#O\.[LY>WH(.3N(/+SZBXB"B+/\.[L
MY>WH\N4@XB#RY>KS^>C_(.7J\.#M(,W?S,`@Y.`@X?KDX/(@[_#HZ^[FY>WH
M+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"B,L(&9U>GIY"FUS9VED("(B"B(H
M4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@
M=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W
M:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*,+Z\.WH(/'E(.KZ
M["#EZO#@[>`@7"+-X._H^.A<(B#QZ^7D(.K@\NX@[_#HZ^[FZ/@@XO'H]^KH
M(._P[NSE[>@@Y.X@\O/J+B(*(L_P[NSE[>CRY2#B(/+EZO/YZ/\@Y>KPX.T@
MS=_,P"#DX"#A^N3@\B#O\.CK[N;E[>@N*2(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D9"!T:&5S92!B>2!C
M;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@Q.[AX.+H(/+EY^@@\2!<(L[*7"(@
M*B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS
M9VED("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J
M(,SNZ_\@Z.?AY?#E\N4@X.3PY?$HZ"D@*B(*"B,Z(&UA:6QB;W@N<&AP.C$W
M-`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(L_H\>SN\NX@X>7XY2#O\.[BY?#E[>XN(@H*(SH@;&EB+U-P
M86TN<&AP.C$X,`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N
M(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(M+NXN`@[^CQ[.X@X>7XY2#HY^_PX/+E[>X@ZN#R
M[B#1[^#L(.3N(-'H\?+E[.WH_R#`Y.SH[>CQ\O#@\N[P+B(*"B,Z(&QI8B]3
M<&%M+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E
M;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`BTN[BX"#OZ/'L[B#A
MY?CE(/#EX^CQ\O#H\.#M[B#JX/+N(/'OX.PN(@H*(SH@;&EB+U-P86TN<&AP
M.C$W,@HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R
M=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`BTN[BX"#OZ/'L[B#AY?CE(.CG[_#@\N7M[B#JX/+N(-'OX.P@Y.X@
MT>CQ\N7L[>C_(,#D[.CMZ/'R\.#R[O`N(@H*(SH@;&EB+U-P86TN<&AP.C$U
M,@HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D
M(&%S('-P86TN(@IM<V=S='(@(M+NXN`@[^CQ[.X@X>7XY2#PY>/H\?+PZ/#@
M[>X@ZN#R[B#Q[^#L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*
M(RP@9G5Z>GD*;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(M'OY?;H
MX.OMZ"#QZ.SB[NOH(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,@HC
M+"!F=7IZ>0IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S='(@(M'OY?;H
MX.OMZ"#QZ.SB[NOH(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,`HC
M+"!F=7IZ>0IM<V=I9"`B,C4P(&-H87)A8W1E<G,B"FUS9W-T<B`BT>_E]NC@
MZ^WH(/'H[.+NZ^@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(Q"B,L
M(&9U>GIY"FUS9VED("(U,#`@8VAA<F%C=&5R<R(*;7-G<W1R("+1[^7VZ.#K
M[>@@\>CLXN[KZ"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B02!L87)G92!I;6%G92!N
M86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N(@IM<V=S='(@
M(M+NY^@@4$=0(._SX>OH]^7M(.KK_O<@X>7XY2#O\.CJ\.7OY>T@ZOKL(._H
M\>SN\NXN(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z
M-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U
M;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C
M:7!I96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD
M<RYI;F,Z-0IM<V=I9"`B04Y$(@IM<V=S='(@(N@B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3DP"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W"FUS9VED
M(")!8V-E<'0@<F5Q=65S="!A;F0@861D(&ET('1O(&UY(&-A;&5N9&%R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3,*;7-G
M:60@(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HR-3<*;7-G:60@(D%C8V5P=&5D.B`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C8V]U
M;G0G<R!N86UE.B(*;7-G<W1R("+([.4@[>`@[^[YX/+@.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU,C`@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<S,`HC+"!F=7IZ>0IM<V=I9"`B06-T:6]N<R(*;7-G<W1R("+$Y>GQ
M\N+HY2(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(P,"!L:6(O34E-12](
M96%D97)S+G!H<#HR,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D
M9"`E<R!T;R!M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`BQ.[AX.+H(.KZ["#@
MY/#E\>W@(.KMZ./@("@E<RDB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,#,*(RP@9G5Z>GD*;7-G:60@(D%D9"!S;W5R8V4B"FUS
M9W-T<B`BY.[AX.+H(/'N\/$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D
M9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N
M<&AP.C$R-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB
M)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("+$[N'@XN7M("5S(.K@
M\NX@[_#HZO#E[^7M(/3@Z>LN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y.`IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@
M=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E
M<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I
M;VX@9&5T86EL<R(*;7-G<W1R("+/Y?#Q[NW@Z^W@(.CM].[P[.#VZ/\B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G
M:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS
M(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;G1A8W1S+G!H
M<#HX-2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X,`HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,SD@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C4R"FUS9VED(")!9&1R97-S($)O;VLB"FUS
M9W-T<B`BP.3PY?'E[2#AY>OEYNWHZB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S0*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`BP.3PY?'M
MZ"#J[>CCZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*;7-G:60@
M(B(*(D%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO
M;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@(@HB;&EN92D\+V5M
M/B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"FUS
M9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I
M9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"`B"B)A9&1R97-S
M(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#(S"FUS9VED(")!;&PB"FUS9W-T<B`BPO'H]^KH(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,PIM<V=I9"`B(@HB06QL(&UE<W-A
M9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO
M861E9"!I;G1O(&]N92!-0D]8("(*(F9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@>6]U<B!<(B5S7"(@
M9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY
M("(*(F1E;&5T960N(@IM<V=S='(@(B(*(L+QZ/?JZ"#OZ/'LX"#B^N(@PN#X
MX/+@(%PB)7-<(B#OX._JX"#O[BWQ\N#PZ"#N\B`E<R#D[>@@^>4@X?KDX/(@
MZ.?R\.CRZ"$B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?871T
M86-H;65N='-?;6]N=&AL>2YP:'`Z-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E
M<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B(@HBPO'H
M]^KH(._@[^KH(%PBR.?O\.#RY>WH(._H\>S@7"(@[^XM\?+@\.@@[O(@)7,@
M[.7QY?;@(/GE(.'ZY.#R(.CG\O#H\N@A(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF
M;W)M870*;7-G:60@(D%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T
M:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("(B
M"B+"\>CWZN@@[^#OZN@@7"+(Y^_PX/+E[>@@[^CQ[.!<(B#O[BWQ\N#PZ"#N
M\B`E<R#LY?'E]N`@^>4@X?KDX/(@Z.?R\.CRZ"$B"@HC.B!A8VPN<&AP.C@U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@<FEG:'1S(&]N(&9O
M;&1E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@7"(E
M<UPB+B(*;7-G<W1R("+/X._JX/+@(%PB)7-<(B#AY?CE(//Q[^7X[>X@[_#E
MZ.SE[?/BX.W@(.W@(%PB)7-<(BXB"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I
M9"`B06QL;W<@1F]L9&5R($-R96%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#@*;7-G:60@(D%L;&]W(&9I;'1E
M<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/R(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM
M<V=I9"`B06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS
M9W-T<B`BP.ORY?#MX/+HXNWH(/?@\?+H(.?@(/+@Y^@@\>7J]NC_.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S(@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4X-`IM<V=I9"`B06QW87ES(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-3<*(RP@9G5Z>GD*;7-G:60@(D%L=V%Y<R!S879E
M(&%T=&%C:&UE;G1S(@IM<V=S='(@(L3NX>#BY>T@)7,@ZN#R[B#O\.CJ\.7O
MY>T@].#IZRXB"@HC.B!L:6(O365S<V%G92YP:'`Z-3`U"B,L(&9U>GIY"FUS
M9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@
M<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED
M.B`B"FUS9W-T<B`BP_#E^.K@(._PZ"#O\.7CZ^7FY.#MY2#MX"#OZ/'LX"#N
M\B#Q^O#B^O#@(2`B"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY
M"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I
M;F<@=&AE(&YE=R!N;W1E+B(*;7-G<W1R("+-Y>CGXN7Q\NW@(./PY?CJX"#O
M\.@@Y.[AX.+_[>4@[>`@[>[B(.?@[^CQ+B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HS.#<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E
M9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(LWEZ.?B
MY?'R[>`@X_#E^.K@(._PZ"#D[N'@XO_MY2#MX"#M[N(@Y^#OZ/$N(@H*(SH@
M;65S<V%G92YP:'`Z-3`P(&UA:6QB;W@N<&AP.C<Q-"!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,U"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-@IM<V=I9"`B
M06YS=V5R960B"FUS9W-T<B`BT2#N\N/NXN[P(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B06YS=V5R960@;65S<V%G97,B"FUS
M9W-T<B`BS^CQ[.`@\2#N\N/NXN[P(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHW"B,L(&9U>GIY"FUS9VED(")!<'!L>2!&:6QT97)S(@IM
M<V=S='(@(L_PZ.ONYN@@].CK\O#H\N4B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%P
M<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`BS_#HZ^[FZ"#TZ.OR\.CRY2(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS-@IM<V=I9"`B07!P
M;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`BQ.`@
M\>4@[_#HZ^#CX/(@Z^@@].CK\O#H\N4@\>OEY"#B]>[D/R(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B07!P
M;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B
M"FUS9W-T<B`BQ.`@\>4@[_#HZ^#CX/(@Z^@@].CK\O#H\N4L(.KNX^#R[B#Q
MY2#N[_#E\>W_XN`@[^[YY>WQZN#RX"#J\_+H_S\B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES('!U
M8FQI8R!K97D_(@IM<V=S='(@(M'HX_/P[>@@Z^@@\?+E+"#WY2#H\>K@\N4@
MY.`@Z.?R\.CE\N4@\N[GZ"#O\^'KZ/?E[2#JZ_[W/R(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U
M"B,L(&9U>GIY"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D
M(2DB"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQZN#RY2#DX"#HY_+P
MZ.7RY2#R[N?H(._SX>OH]^7M(.KK_O<_(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ
M<SHV"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&\@=&AI<S\B"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQZN#RY2#D
MX"#HY_+PZ.7RY2#R[N?H(._SX>OH]^7M(.KK_O<_(@H*(SH@;65S<V%G92YP
M:'`Z-#`W('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8X"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L
M971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("+1Z./S\.WH(.OH(/'RY2P@
M]^4@Z/'JX/+E(.3@(.CG\O#HY?+E(/+EY^@@[^CQ[.`@*.WEXOKGXO#@\NCL
M[BD_(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(Q-0HC+"!F=7IZ>0IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E
M;&5T92!T:&ES(&%T=&%C:&UE;G0_(@IM<V=S='(@(M'HX_/P[>@@Z^@@\?+E
M+"#WY2#H\>K@\N4@Y.`@Z.?R\.CE\N4@\N7GZ"#OZ/'LX"`H[>7B^N?B\.#R
MZ.SN*3\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0HC
M+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y
M('1H:7,@9F]L9&5R/R(*;7-G<W1R("+1Z./S\.WH(.OH(/'RY2P@]^4@Z/'J
MX/+E(.3@(.CG[_#@Y^WH\N4@ZN[X]^7R[C\B"@HC.B!L:6(O24U0+G!H<#HY
M-S,*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E
M;7!T>2!Y;W5R('-P86T@9F]L9&5R/R(*;7-G<W1R("+1Z./S\.WH(.OH(/'R
MY2P@]^4@Z/'JX/+E(.3@(.CG[_#@Y^WH\N4@ZN[X]^7R[C\B"@HC.B!L:6(O
M24U0+G!H<#HY-C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E
M;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q
M\N4L(/?E(.CQZN#RY2#DX"#HY^_PX.?MZ/+E(.KN^/?E\NX_(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T
M:&5S92!M97-S86=E<S\B"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQ
MZN#RY2#DX"#HY_+PZ.7RY2#RY>?H(._H\>S@("CMY>+ZY^+PX/+H[.XI/R(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E;7!L
M871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"B,L(&9U>GIY"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G
M92!A<R!I;FYO8V5N=#\B"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQ
MZN#RY2#DX"#HY_+PZ.7RY2#RY>?H(._H\>S@("CMY>+ZY^+PX/+H[.XI/R(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L
M871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"B,L(&9U>GIY"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G
M92!A<R!S<&%M/R(*;7-G<W1R("+1Z./S\.WH(.OH(/'RY2P@]^4@Z/'JX/+E
M(.3@(.CG\O#HY?+E(/+EY^@@[^CQ[.`@*.WEXOKGXO#@\NCL[BD_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I9"`B07)R:79A;"!4:6UE
M(@IM<V=S='(@(L+PY>SE(.W@(._PZ/'RZ./@[>4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`BS>#P
MX/'RXN#YZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S$@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4X,PIM<V=I9"`B07-K(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q.0HC+"!F=7IZ>0IM
M<V=I9"`B071T86-H(@IM<V=S='(@(L_PZ.KPY>_E[2#TX.GK(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<U"B,L(&9U>GIY"FUS9VED
M(")!='1A8V@@1FEL97,B"FUS9W-T<B`BS_#HZO#E[^7M(/3@Z>LZ(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#4V"FUS9VED(")!='1A
M8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S
M86=E/R(*;7-G<W1R("+$X"#QY2#D[N'@XO\@Z^@@PN#XZ/_R(._SX>OH]^7M
M(%!'4"#JZ_[W(.KZ["#OZ/'L[O+N(,+H/R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]T;F5F+G!H<#HQ,#D*;7-G:60@(D%T=&%C:&5D($9I;&4Z(@IM<V=S='(@
M(L_PZ.KPY>_E[2#TX.GK.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-3$@;&EB
M+T-O;7!O<V4N<&AP.C4S-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!='1A
M8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A8VAM96YT('-I>F4@
M;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C,W-@IM<V=I9"`B071T86-H960@:7,@
M82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHY-PIM<V=I9"`B071T86-H;65N="(*;7-G<W1R("+/
M\.CJ\.7OY>T@].#IZR(*"B,Z(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A
M9V4N<&AP.C0V-@IM<V=I9"`B071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN
M86P@871T86-H;65N="!T>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT-S,*(SH@;&EB+T-O;7!O<V4N<&AP.C$P-S,*;7-G:60@(D%T
M=&%C:&UE;G1S(@IM<V=S='(@(L_PZ.KPY>_E[>@@].#IZ^[BY2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#(*(RP@9G5Z>GD*;7-G:60@(D%T
M=&5N9&5E<R(*;7-G<W1R("+/\.CJ\.7OY>WH(/3@Z>ONXN4B"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PHC+"!F=7IZ>0IM<V=I
M9"`B071T96YT:6]N(@IM<V=S='(@(L3EZ?'RXNCE(@H*(SH@;&EB+T%U=&@O
M:6UP+G!H<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8T,`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W(&EM
M86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M
M>2`B"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,CDX"FUS9VED(")!=F%I;&%B;&4@061D
M<F5S<R!B;V]K<SHB"FUS9W-T<B`BS>#KZ/?MZ"#@Y/#E\>WH(.KMZ./H.B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET
M:6YG(%)E<W!O;G-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D)A8U]K('1O("5S(@IM<V=S='(@(L[A\.#R[>X@XB`E<R(*"B,Z
M('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*
M;7-G<W1R("+.X?#@\NWN(.(@)7,B"@HC.B!T:')E860N<&AP.C$S-`IM<V=I
M9"`B0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@B"FUS9W-T
M<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D
M($1I<W!L87DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS
M.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U
M97-T+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HR-C8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M,C(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L:6(O
M4V5A<F-H+G!H<#HS-`IM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM<V=I9"`B0F5L;W<@:7,@
M=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`BU^7PY>T@\>_H\?KJ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8R.0IM<V=I9"`B0FQO8VL@:6UA9V5S
M(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I9FEC86QL
M>2!R97%U97-T960_(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP.C0R
M"FUS9VED(")";V1Y(@IM<V=S='(@(M+_Z^XB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C(S('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,SD*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU-2!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C<Q"FUS9VED(")";W1H(@IM<V=S='(@(L3BX/+@(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-PIM<V=I9"`B0F]T:"!(96%D
M97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(M+_Z^[R
M[B#MX"#OZ/'L[O+N(.@@:&5A9&5R<R`B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR-S(*;7-G:60@(D-?:&%R<V5T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L
M96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR
M,#$*(RP@9G5Z>GD*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M
M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R("+#\.7XZN`@[_#H(/'B^O#GXN#M
MY2#Q(.SEZ>L@\?KPXOKPX"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,3DY"B,L(&9U>GIY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E
M;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(L/PY?CJX"#O\.@@\>+Z\.?B
MX.WE(/$@[.7IZR#Q^O#B^O#@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I
M86PN<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES
M<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S
M86=E(&EN('1H92!C=7)R96YT("(*(FUA:6QB;W@N(@IM<V=S='(@(B(*"B,Z
M(&9O;&1E<G,N<&AP.C(X-"!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C(U-0HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(Q('1E
M;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.0HC.B!T96UP;&%T
M97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C$@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C@V"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHQ,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,@HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8V"B,L(&9U>GIY"FUS9VED
M(")#86YC96PB"FUS9W-T<B`BS_#N[.7MZ"(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0S-0HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q
M"B,L(&9U>GIY"FUS9VED(")#86YC96P@365S<V%G92(*;7-G<W1R("+(Y_+P
MZ.D@[^CQ[.XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z
M-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G:60@(D-A;F-E
M;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I
M=',@8V]N=&5N=',N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-2!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC.B!T96UP;&%T
M97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI8B]396%R8V@N<&AP.C,P
M"FUS9VED(")#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z.3,*;7-G:60@(B(*(D-E<G1I9FEC871E(&EM<&]R="!I<R!N
M;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T
M:&ES("(*(G-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<P,0HC+"!F=7IZ>0IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM
M<V=S='(@(L_E\/'N[>#K[>@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R("+/\.[LY>WH(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#
M:&%N9V4@06QL(@IM<V=S='(@(L_P[NSE[>@@XO'H]^KH(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.CDR"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@1F]L
M9&5R(@IM<V=S='(@(M'ZY^3@Z2#OX._JX"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(D-H86YG92!D:7-P;&%Y
M(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N
M(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S(&%R92!S;W)T960N(@IM
M<V=S='(@(B(*(M'L_^W@(.W@(.3H\>_KY>D@[N_VZ.CRY2P@ZN#R[B#VXN7R
M[>`@\?7E[.`L(.KNZ^KN(._H\>S@(.3@(/'E(.+HYN3@\B#B^N(@(@HBXO'_
MZN`@\?+PX.WH]N`@Z"#JX.H@Y.`@\>4@\>[P\NCPX/(@[^CQ[.#RX"XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@(D-H
M86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+B(*;7-G<W1R
M("+/\.[L_^W@(.W@(.W@\?+P[NGJZ/+E(.?@(.SEZ>L@\?KPXOKP+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB
M"FUS9W-T<B`B(@HBS_#N[.7MY?+E(.CLY?+N+"#@Y/#E\>`@Z"#O[N3OZ/'@
M+"#J[NCR[B#O[NOS]^#RY>OH\N4@^>4@XNCFY.#R+"#J[N/@\NX@(@HB]^7R
MX/(@Z"#N\N/NXN#P__(@[>`@[^CQ[.[R[B#"Z"XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#(T"FUS9VED(")#:&%R86-T97)S('1O(&1I<W!L87DZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C$U"FUS9VED(")#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S
M='(@(L_P[N+E\.@@[^#OZN#RX"CH\N4I(.?@(.WNXN@@[^CQ[.`B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO
M3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC
M.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O
M(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0V,PHC+"!F=7IZ>0IM<V=I9"`B0VAE8VL@<W!E;&QI;F<@
M8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("+$X"#QY2#O[NK@
MY^+@(.OH(._N\N+Z\.;DY>WHY2#QZ^7D(.CG[_#@^>#MY2#MX"#OZ/'L[C\B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT"FUS9VED(")#
M:&]O<V4@06-T:6]N.B(*;7-G<W1R("+(Y^'E\.@@Y.7I\?+BZ.4Z(@H*(SH@
M8V]N9FEG+W-E<G9E<G,N<&AP+F1I<W0Z,3@R"FUS9VED(")#:&]O<V4@82!M
M86EL('-E<G9E<CHB"FUS9W-T<B`BR.?AY?#E\N4@[.7IZR#Q^O#B^O`Z(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR,3<*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D
M:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW,S$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ
M(@IM<V=S='(@(LCGX>7PZ"#DY>GQ\N+HY3HB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*;7-G:60@(D-H;V]S92!T:&4@861D
M<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S
M='(@(LCGX>7PY?+E(.KN_R#@Y/#E\>W@(.KMZ./@(.3@(/'E(.CG[^[KY^+@
M(._PZ"#D[N'@XO_MY2#MX"#@Y/#E\2XB"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHR.3,*;7-G:60@(D-H;V]S92!T:&4@;W)D97(@
M;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D
M<F5S<V5S+B(*;7-G<W1R("(B"B+(Y^'E\.7RY2#PY>3@(.W@(/+Z\/'E[>4@
M[>`@X.3PY?'MZ/+E(.KMZ./H+"#O\.@@[O+J\.CBX.WE\NX@[>`@X.3PY?'H
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!C;VYV97)T('1H92!I;6%G92!F
M:6QE(&EN=&\@82!F;W)M870@>6]U<B!B<F]W<V5R(&-A;B!V:65W+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@:6UA
M9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M96YT
M('!A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HQ,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!(
M5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W(&$@=&AU;6)N86EL(&]F('1H
M:7,@:6UA9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E
M<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W
M+B(*;7-G<W1R("+$X"#QY2#OZ/C@\B#KZ"#OZ/'LX/+@(.(@[O+DY>OE[2#O
M\.[G[O#E]C\B"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU
M;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I
M9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(Q"FUS9VED
M("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O
M;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S('1O("(*(G-E87)C:"XB
M"FUS9W-T<B`B(@HBRNOHZNWE\N4@[>`@Y>3MX"#N\B#HY^'PX.WH\N4@X.3P
MY?'MZ"#J[>CCZ"#H(/'KY>0@\N[BX"#HY^'E\.7RY2#B\>CWZN@@(@HB[^[K
MY?+@(.?@(/+Z\/'E[>4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,3<Q"FUS9VED(")#;&EC:R!T;R!3879E(%!'4"!0=6)L:6,@2V5Y(&EN('EO
M=7(@061D<F5S<R!B;V]K(@IM<V=S='(@(B(*(LKKZ.KMY?+E+"#GX"#DX"#G
MX._H^.7RY2#"X/CH__(@[_/AZ^CWY>T@4$=0(.KK_O<@XB#@Y/#E\>W@\N`@
M\>@@ZNWHX^`N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,#(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-
M24U%(&-E<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K(@IM
M<V=S='(@(B(*(LKKZ.KMY?+E+"#GX"#DX"#GX._H^.7RY2#"X/CH__(@[_/A
MZ^CWY>T@4$=0(.KK_O<@XB#@Y/#E\>W@\N`@\>@@ZNWHX^`N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDU,`IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE
M(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E
M;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q
M"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE
M(&UE<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C@*(RP@9G5Z>GD*;7-G:60@(D-L
M;W-E(@IM<V=S='(@(LW@[^CXZ"(*"B,Z(&-O;7!O<V4N<&AP.C@R."!C;VUP
M;W-E+G!H<#HQ,30X"FUS9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R
M("+'X/+B[O#H(._P[N?N\.7VX"(*"B,Z(&9O;&1E<G,N<&AP.C0R.0IM<V=I
M9"`B0VQO<V5D($9O;&1E<B(*;7-G<W1R("+'X/+B[O#E[>`@[^#OZN`B"@HC
M.B!F;VQD97)S+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E(@IM
M<V=S='(@(M'ZX>7PZ"#B\>CWZN@B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL(@IM<V=S='(@(M'Z
MX>7PZ"#B\>CWZN@B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T<B`BT?KA
MY?#H(.+QZ/?JZ"#OX._JZ"(*"B,Z(&9O;&1E<G,N<&AP.C0T.0IM<V=I9"`B
M0V]L;&%P<V4@1F]L9&5R(@IM<V=S='(@(M'ZX>7PZ"#OX._JX"(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@
M26YD:6-A=&]R.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$P,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("+J[NSE[?+@\"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-CD*(RP@9G5Z>GD*;7-G:60@
M(D-O;7!L971E9"(*;7-G<W1R("+J[NSE[?+@\"(*"B,Z(&-O;7!O<V4N<&AP
M.C@R-R!C;VUP;W-E+G!H<#HQ,30W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@
M;65S<V%G92(*;7-G<W1R("+-X._H^.@@Y/#SX^X@[^CQ[.XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S
M(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R("+$X"#QY2#OZ/C@\B#K
MZ"#OZ/'LX/+@(.(@[O+DY>OE[2#O\.[G[O#E]C\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#0S"B,L(&9U>GIY"FUS9VED("(B"B)#;VUP;W-E(&UE
M<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H:68@8G)O=W-E
M<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_(@IM<V=S='(@(L3@(/'E(._H
M^.#R(.OH(._H\>S@\N`@XB!(5$U,(/#EY.#J\N[P("A)12`U+C4K(/'@[.XI
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-PIM<V=I9"`B0V]N9FEG
M=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*(RP@9G5Z>GD*;7-G:60@(D-O
M;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB"FUS9W-T<B`BS_#N[/_M
MX"#MX"#MX/'R\.[IZNCRY2#GX"#LY>GK(/'Z\.+Z\"XB"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C,W,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!D
M<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R("+#\.7XZN`@[_#H(/'B
M^O#GXN#MY2#Q^O$@\?KPXOKP+B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,C,T"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F86EL960B"FUS
M9W-T<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(/'Z\.+Z\"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("+*[NWR\.[K
M(.W@(%!'4"#O[N3D\/KFZN#RX"#GX"`E<RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4R]-
M24U%('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("+*[NWR\.[K(.W@(%,O34E-
M12#O[N3D\/KFZN#RX"#GX"`E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P=&EO;G,@<F5L871I;F<@=&\@;65S
M<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O;G1R;VP@=VAE;B!N97<@;6%I;"!W
M:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T
M:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV97,N(@IM<V=S='(@(B(*(LKN[?+P
M[NOH\.`@ZN[CX"#DX"#QY2#O\.[BY?#_XN`@Y^`@[>[BX"#O[OG@(.@@Y.#K
MZ"#DX"#A^N3E\N4@\^+EY.[LY>WH+"`B"B+J[N/@\NX@\O\@\>4@[^[K\_?H
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.38*;7-G:60@(D-O;G9E
M<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED
M(")#;W!Y(@IM<V=S='(@(LKN[^CPX.DB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM
M<V=S='(@(LCG[_#@Y^WH(.KN^/?E\NXB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z-C,*;7-G:60@(D-O<G)E8W0B"FUS9W-T<B`BRN[P
MZ./H\.#I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T
M,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`BRN[PZ./H\.#M(/+E
MZO'R(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E87-O;B!'
M:79E;CH@)7,B"FUS9W-T<B`B(@H*(SH@871T86-H;65N="YP:'`Z-3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A
M8VME;F0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S86=E
M<R!F<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@Z.?R\.CBX.WE\NX@[>`@[^CQ[.`@[O(@)7,N(-'Z\.+Z\.`@ZN#G
MX#H@)7,B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,S$X"FUS9VED(")#;W5L9"!N
M;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(.CG[_KK[>7MZ.4@[>`@7"+.[^7PX/;HZ"#O[B#NX?'K\^;B
MX.WE\NY<(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HU-`IM<V=I
M9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@
M=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`BP_#E^.K@(._PZ"#H
MY^+KZ/?@[>7R[B#MX"#O\.CJX/?E[>C_(/3@Z>L@[O(@35,M5$Y%1BXB"@HC
M.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HU.`IM<V=I9"`B0V]U;&0@;F]T
M(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H
M:79E+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CGXNOH]^#MY?+N(.W@(/3@Z>L@
M[O(@6FEP(.#P]>CBX"XB"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<S"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R
M;VT@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z,S$T
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,`HC
M+"!F=7IZ>0IM<V=I9"`B0W)E871E(@IM<V=S='(@(M'ZY^3@Z2#OX._JX"(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C8*;7-G:60@(D-R
M96%T92!&;VQD97(B"FUS9W-T<B`BT?KGY.#I(._@[^K@(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$S-PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E($ME
M>7,B"FUS9W-T<B`BU^#Q\N7M(.KK_O<B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!6:7)T=6%L
M($9O;&1E<B(*;7-G<W1R("+1^N?DX.D@[^#OZN`B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E
M(&$@3F5W($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-P86US96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T
M+FEN8SHR-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L
M9&5R(@IM<V=S='(@(M'ZY^3@Z2#M[N+@(._@[^K@(%PBRN[X]^5<(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E
M<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N
M97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R("+1^N?DX.D@[>[BX"#OX._JX"!<
M(M?E\.WNXNA<(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C
M="YI;F,Z,C8@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT
M,@IM<V=I9"`B0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T
M<B`BT?KGY.#I(.WNXN`@[^#OZN`@7"+(Y^_PX/+E[>A<(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S
M+W1R87-H<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H
M(&9O;&1E<B(*;7-G<W1R("+1^N?DX.D@[>[BX"#OX._JX"!<(LKN^/?E7"(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B"B)#<F5A
M=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@
M;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE=&4@<W!A
M;2XB"FUS9W-T<B`B(@HBT?KGY.#I(._PX.+HZ^`@Y^`@].CK\O#H\.#MY2#H
M(.[PX^#MZ.?@]NC_(.W@(.CDXN#YX/+@(._N^>`L(/'N\/+H\.#MY?+N(.D@
MXB`B"B+OX._JZ/+E(.@@Z.?R\.CBX.WE(.W@(/'OX.PB"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(D-R
M96%T92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R("+1^N?DX.D@[>[BX"#OX._J
MX"!<(LCG[_#@\N7MZ%PB(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M.0IM<V=I9"`B0W)E871E('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A8V-E<W,@=&\@)7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0HC+"!F=7IZ>0IM
M<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R
M;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(LCG\N7CZ__MY2#MX"#O[OG@
M(.[R(.3P\^/H(%!/4#,O24U!4"#Q^O#B^O#H+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B0W5S=&]M:7IE(&AO=R!Y
M;W4@<V5N9"!M86EL+B(*;7-G<W1R("+.[_#EY.7KZ"#MX/?H[>`L(._N(.KN
MZ?+N(.CG[_#@^>#X(._N^>`@Z"#J^N3E(/'@(/?E\.WNXNCRY2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G
M<W1R("+.[_#EY.7KZ"#GX.3@]^CRY2#GX"#HY^_ZZ^WE[>CE(/'KY>0@XO7N
MY"#B("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(D1A=%]E(@IM<V=S='(@(L3@\N`B
M"@HC.B!M97-S86=E+G!H<#HR-C(@=&AR96%D+G!H<#HQ-#@*;7-G:60@(D1A
M=&4B"FUS9W-T<B`BQ.#RX"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW-3<*(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(LCG\O#H
M\N@B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8S"FUS9VED(")$
M96-L:6YE9#H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BR.?R\.CI
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC
M.C$X"FUS9VED(")$969A=6QT(%-E87)C:"!&:65L9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(S"FUS9VED(")$969A=6QT('-O
M<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(LKPZ/+E\.CH(.?@(/'N\/+H\.#M
MY2#O[B#O[N3PX.?AZ/#@[>4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDS,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T
M<B`BS^[Q[NK@(.W@(/'N\/+H\.#MY2#O[B#O[N3PX.?AZ/#@[>4Z(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V-0HC+"!F=7IZ>0IM<V=I9"`B
M1&5L96=A=&5D(@IM<V=S='(@(LCG\O#H\N@B"@HC.B!F;VQD97)S+G!H<#HT
M,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`BR.?R\.CI(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI
M8R!+97DB"FUS9W-T<B`BR.?R\.CI("5S(._SX>OH]^7M(.KK_O<B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHX-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-U<G)E;G0@2V5Y<R(*
M;7-G<W1R("+(Y_+PZ.D@)7,@[_/AZ^CWY>T@ZNO^]R(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G:60@(D1E;&5T92!&;VQD97(H
M<RDB"FUS9W-T<B`BR.?R\.CI(._@[^K@*.@I(@H*(SH@9F]L9&5R<RYP:'`Z
M,C@U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R<R(*
M;7-G<W1R("+(Y_+PZ.D@[^#OZN`HZ"DB"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!3=&%T
M:6]N97)Y(@IM<V=S='(@(LCG\O#HZ2#OX._JX"CH*2(*"B,Z(&9O;&1E<G,N
M<&AP.C0Q.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L9&5R
M(@IM<V=S='(@(LCG\O#HZ2#OX._JX"CH*2(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&9E
M=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G<W1R("+(
MY_+PZ.D@Z.?RY>/KY>WH\N4@[^CQ[.`@[O(@\?KPXOKPX"(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY
M(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-C@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!O;&0@;&EN:V5D(&%T=&%C
M:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B(@HBQ.`@
M\>4@Z.?R\.CBX/(@Z^@@\?+@\.CRY2#OX._JZ"!<(LCG[_#@\N7MX"#O[OG@
M7"(@XB#MX/?@Z^[R[B#MX"#LY?'E]N`_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,U,`IM<V=I9"`B1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(B(*(L3@(/'E(.CG
M\O#HXN#R(.OH(/'RX/#H\N4@[^#OZN@@7"+(Y^_PX/+E[>`@[^[YX%PB(.(@
M[>#WX.ON\NX@[>`@[.7QY?;@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM
M<V=S='(@(LCG\O#HZ2#OZ/'LX"(*"B,Z(&UE<W-A9V4N<&AP.C4P,R!M86EL
M8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,X('1E;7!L871E<R]M
M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R("+(
MY_+PZ/+H(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I
M9"`B1&5L971E9"!M97-S86=E<R(*;7-G<W1R("+(Y_+PZ/+H(._H\>S@(@H*
M(SH@8V]M<&]S92YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB)7-<(BXB"FUS9W-T<B`BR.?R
M\.CI(._PZ.KPY>_E[>C_\B#TX.GK("5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.0IM<V=I9"`B1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E
M<R(*;7-G<W1R("+(Y_+PZ.+@[>4@Z"#O\.7LY?'RXN#MY2#MX"#OZ/'LX"(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3(*;7-G:60@(D1E;GD@
M<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-30P"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3,R"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(LW@[.#K_^+@^>@B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8V.0HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I
M<'1I;VXB"FUS9W-T<B`BT.#G[^[K[N;E[>CE(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")$971A
M:6QS(@IM<V=S='(@(L3E\N#IZ^@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C<W"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B"FUS9W-T<B`BQ.`@\>4@
MY^#L^N/K_^+@\B#KZ"#O[N3OZ/'H\N4_(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR,S8*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B
MS^[JX.;H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W.0IM<V=I9"`B
M1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_
M(@IM<V=S='(@(L3@(/'E(._NZN#GXN`@Z^@@[^[RXOKPYN3E[>CE(/'KY>0@
MZ.?O\.#YX.WE(.W@(._H\>SN/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.#8*;7-G:60@(D1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S
M='(@(L_NZN#FZ"#B(/'ZY/KPYN#MZ.7R[B#MX"#OZ/'L[O+N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y,@IM<V=I9"`B1&ES<&QA>2!P;W`M=7`@
M;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL/R(*;7-G<W1R("+$X"#QY2#O[NK@
MY^+@(.OH('!O<"UU<"#SXN7D[NS_XN#MY2#GX"#M[N+@(._N^>`_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`HC+"!F=7IZ>0IM<V=I9"`B1&ES
M<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`BQ.`@\>4@[^[JX.?BX"#KZ"!<(LCG[_#@Y^WH(.KN^/?E\NY<
M(B#B(.SE[?X@Z^7M\N#RX#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S4P"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%1R87-H
M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`BQ.`@\>4@[^[JX.?B
MX"#KZ"!<(LCG[_#@Y^WH(.KN^/?E\NY<(B#B(.SE[?X@Z^7M\N#RX#\B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,3$*;7-G:60@
M(D1I<W!O<VET:6]N(@IM<V=S='(@(M#@Y^_NZ^[FY>WHY2(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA=&-H
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C$V"FUS9VED(")$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I
M;"(*;7-G<W1R("+-Y2#O\.[BY?#_XN#I(._@[^K@*.@I(.?@(.WNXN`@[^[Y
MX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3(*;7-G:60@(D1O(&YO
M="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!L:6(O24U0+G!H<#HQ,#<U"FUS9VED(")$;R!Y;W4@=V%N="!T
M;R!O<&5N('1H870@9F]L9&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(S,@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O
M=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3(V"B,L(&9U>GIY"FUS9VED(")$;VYE(@IM<V=S
M='(@(LW_[.`B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"B,L('!H
M<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R
M"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL
M92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,C`*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R("+(Y_+E
MX^OH(._@[^K@*.@I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII
M<"!F;W)M871=(@IM<V=S='(@(LCG\N7CZ^@@[^#OZN`HZ"DB"@HC.B!L:6(O
M34E-12]#;VYT96YT<RYP:'`Z,3DR"FUS9VED(")$;W=N;&]A9"!I;B`N>FEP
M($9O<FUA="(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU,#$@;6%I;&)O
M>"YP:'`Z-S$Y('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z,3$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0Q"B,Z('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z.0IM<V=I9"`B1')A9G0B"FUS9W-T<B`BU^7P[>[B
MX"(*"B,Z(&9O;&1E<G,N<&AP.C,Y,@HC+"!F=7IZ>0IM<V=I9"`B1')A9G0@
M9F]L9&5R(@IM<V=S='(@(L_@[^K@(%PBU^7P[>[BZ%PB.B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS9VED(")$<F%F=',@
M9F]L9&5R.B(*;7-G<W1R("+/X._JX"!<(M?E\.WNXNA<(CHB"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3`X"FUS9VED(")%+6UA:6P@061D<F5S<R(*
M;7-G<W1R(")%+4UA:6P@X.3PY?$B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S`Y
M"B,L(&9U>GIY"FUS9VED(")%3D0B"FUS9W-T<B`BZ"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED(")%4E)/4CH@66]U<B!M97-S
M86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N(@IM<V=S='(@(B(*"B,Z(&9O
M;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,3D*;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")%9&ET($)L86-K;&ES
M="(*;7-G<W1R("+7Y?#E[2#Q[^CQ^NHB"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(D5D:70@1FEL=&5R<R(*
M;7-G<W1R("+/[OG@(-3HZ_+PZ"(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,38*;7-G:60@(D5D:70@5FER='5A
M;"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A
M9&5R+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@
M1F]L9&5R($1E9FEN:71I;VX@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHR,PIM<V=I9"`B161I="!7:&ET96QI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C$X"B,L(&9U>GIY"FUS9VED(")%9&ET('EO=7(@8FQA8VML:7-T(@IM<V=S
M='(@(M#EY.#J]NC_(.W@(._PX.+HZ^#RX"#GX"#TZ.OR\.CPX.WE(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$S"FUS9VED(")%9&ET('EO
M=7(@9FEL=&5R(')U;&5S(@IM<V=S='(@(M#EY.#J]NC_(.W@(._PX.+HZ^#R
MX"#GX"#TZ.OR\.CPX.WE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V
M,0IM<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@
M;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")%9&ET('EO
M=7(@=VAI=&5L:7-T(@IM<V=S='(@(M#EY.#J]NC_(.W@(._PX.+HZ^#RX"#G
MX"#TZ.OR\.CPX.WE(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,SD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`BQ6UA:6P@
MX.3PY?$B"@HC.B!L:6(O365S<V%G92YP:'`Z-C4W"B,L('!H<"UF;W)M870*
M;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@
M(L?@Z^CWY>WH(.'_]>`@XO'H]^KH(._H\>S@(.[R("5S+B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD
M97(H<RDB"FUS9W-T<B`BR.?O\.#G[>@@[^#OZN`HZ"DB"@HC.B!F;VQD97)S
M+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O;&1E
M<G,B"FUS9W-T<B`BR.?O\.#G[>@@[^#OZN`HZ"DB"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@9F]L
M9&5R(@IM<V=S='(@(LCG[_#@Y^WH(.KN^/?E\NXB"@HC.B!L:6(O24U0+G!H
M<#HY-S,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%]3<&%M(@IM<V=S='(@(LCG
M[_#@Y^WH(.KN^/?E\NXB"@HC.B!L:6(O24U0+G!H<#HY-C8*(RP@9G5Z>GD*
M;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R("+(Y^_PX.?MZ"#J[OCWY?+N
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$@=&5M<&QA=&5S+W!G<"]N
M;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET
M>3\B"FUS9W-T<B`BQ.`@\>4@\.#G\.7XZ"#KZ"!01U`@]//MZO;H[NW@Z^WN
M\?+RX#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$@=&5M<&QA
M=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%,O34E-
M12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("+$X"#QY2#PX.?PY?CH(.OH(%,O
M34E-12#T\^WJ]NCN[>#K[>[Q\O+@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,3$*(RP@9G5Z>GD*;7-G:60@(D5N86)L92!M97-S86=E('!R979I
M97=S/R(*;7-G<W1R("+*\.#I(.W@(._H\>SN\NX@[O(@)7,B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-#(*(RP@9G5Z>GD*;7-G:60@
M(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`BP>7G(.KPZ._RZ/#@[>4B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$W(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-3<*;7-G:60@(D5N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S@T"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A
M9V4B"FUS9W-T<B`BRO#@Z2#MX"#O\.7O\.#RY>WN\NX@[^CQ[.XB"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S0Q"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R
M("+*\.#I(.W@(._H\>SN\NXB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D5N9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T
M<B`BRO#@Z2#MX"#OZ/'L[O+N(.[R("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@
M(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`BPOKBY>3E\N4@ZNO^]^[BX"#T
M\.#GX"(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHY"FUS
M9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@
M;F5W(&1R869T<R!F;VQD97(B"FUS9W-T<B`BT?KGY.#I(.WNXN`@[^#OZN`@
M7"+7Y?#M[N+H7"(B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE
M8W0N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@
M>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("+1^N?DX.D@[>[B
MX"#OX._JX"!<(LCG[_#@\N7MZ%PB(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R
M87-H<V5L96-T+FEN8SHY"B,L(&9U>GIY"FUS9VED(")%;G1E<B!T:&4@;F%M
M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(M'ZY^3@Z2#M
M[N+@(._@[^K@(%PBRN[X]^5<(B(*"B,Z(&QI8B]396%R8V@N<&AP.C0V"B,L
M(&9U>GIY"FUS9VED(")%;G1I<F4@365S<V%G92(*;7-G<W1R("+*\.CO\NCP
MX.WE(.W@(._H\>SN(@H*(SH@;65S<V%G92YP:'`Z,3DT(&-O;7!O<V4N<&AP
M.C$Q,S0@=&AR96%D+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R
M>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S
M<R!B;V]K(@IM<V=S='(@(L?@[^CQX"!<(B5S7"(@X>7XY2#S\>_E^.WN(.3N
MX>#BY>T@ZOKL(.#D\.7Q[>#RX"#J[>CCX"(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C,X-@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(L/PY?CJX"(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S
M97)V97(N("5S(#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HS,#D@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,0HC
M+"!F=7IZ>0IM<V=I9"`B179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM
M<V=S='(@(LW@\?+P[NGJZ/+E(.'_]>`@[N'M[N+E[>@@\_'OY?CM[BXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@R"FUS9VED(")%=F5R>2`Q-2!M
M:6YU=&5S(@IM<V=S='(@(L+QY>KH(#$U(.SH[?/RZ"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS
M9W-T<B`BPO'EZN@@,S`@\>7J\^WDZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.#$*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("+"\>7J
MZ"`U(.SH[?/RZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#,*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+-X"#B\>7JZ"#O[NONXNCM
M(/?@\2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D5V
M97)Y(&UI;G5T92(*;7-G<W1R("+"\?_JX"#LZ.WS\N`B"@HC.B!F;VQD97)S
M+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"(*;7-G<W1R("+0X.?R
MXN[PZ"#B\>CWZN@B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHS.`IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R("+0X.?RXN[PZ"#B\>CW
MZN@B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.`IM<V=I
M9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(M#@Y_+B[O#H(.+QZ/?J
MZ"#OX._JZ"(*"B,Z(&9O;&1E<G,N<&AP.C0U-PIM<V=I9"`B17AP86YD($9O
M;&1E<B(*;7-G<W1R("+0X.?RXN[PZ"#OX._JX"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,T,"!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-3,*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R("+$[N_H
M^.@@Z.SE[>#RX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8S"FUS
M9VED(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M
M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(L3@(/'E(.3N
M[^CQXN#R(.OH(.#B\N[LX/+H]^WN(.CLY>W@\N`@[_#H(._H\>#MY2#MX"#M
M[N+N(._H\>SN/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.#`*;7-G
M:60@(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@
M:6X@=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T<B`BQ.`@\>4@[O+BX/#_(.OH
M(/;_Z^[R[B#D^O#B[B#B(.CGX^OEY"!<(L_@[^KH7"(@[^X@[^[D\.#GX>CP
MX.WE/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$T-"!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ.30*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C0U('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHQ,#$*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9&EN9R(*;7-G
M<W1R("+.\N+@\/_MY2XN+B(*"B,Z(&QI8B])35`N<&AP.CDX-"!L:6(O24U0
M+G!H<#HY.#8*(RP@9G5Z>GD*;7-G:60@(D9?971C:"!-86EL(@IM<V=S='(@
M(L3P\^/@(._N^>`B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I
M;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B1F5T
M8V@@36%I;"(*;7-G<W1R("+$\//CX"#O[OG@(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@V.0IM<V=I9"`B1F5T8V@@36%I;"!I;B!A('-E<&%R871E
M('=I;F1O=S\B"FUS9W-T<B`BQ.`@\>4@Z.?RY>/K_R#KZ"#O[OG@\N`@XB#N
M\N3EZ^7M(._P[N?N\.7V/R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O
M;B!L;V=G:6YG(&]N/R(*;7-G<W1R("+$X"#QY2#O\.CKX./@\B#KZ"#TZ.OR
M\.CRY2#QZ^7D(.+U[N0_(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D("5D(&UE<W-A9V5S
M(&9R;VT@)7,B"FUS9W-T<B`BR.SO[O#RZ/#@[>@@X?_UX"`E9"#OZ/'LX"#N
M\B`E<RXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS
M9W-T<B`BRO#@Z2#MX"#OZ/'L[O+N(.[R("5S(@H*(SH@;&EB+T9E=&-H;6%I
M;"YP:'`Z,C@U(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL
M+G!H<#HR.#D*(RP@9G5Z>GD*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@
M(L3P\^/@(._N^>`B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@9G5Z
M>GD*;7-G:60@(D9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R
M("(@+2`D;FT@[>[BZ"#OZ/'LX"(*"B,Z(&QI8B])35`N<&AP.CDY,`HC+"!F
M=7IZ>0IM<V=I9"`B1FE?;'1E<G,B"FUS9W-T<B`BU.CK\OKP(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`R('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FIS.C@R"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM
M<V=S='(@(M3HZ_+Z\"(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHS,0HC+"!F=7IZ>0IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B
MQ/#SX^@@SN_VZ.@B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M.0HC+"!F=7IZ>0IM<V=I9"`B1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(L_P
MX.+HZ^`@Y^`@].CK\O#H\.#MY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,#`*;7-G:60@(D9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A
M;FET>3\B"FUS9W-T<B`BQ.`@\>4@].CK\O#H\.`@Z^@@\?KD^O#FX.WHY?+N
M(.W@(._H\>S@\N`@Y^`@\//CX/+MZ#\B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]N;W1A8W1I=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")&:6QT97(@<W5P
M<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`BT>CQ
M\N7LX/+@(.4@\2#HY^KK_O?E[>`@4$=0(._NY.3P^N;JX"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S='(@
M(M3HZ_+Z\"(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z
M,PHC+"!F=7IZ>0IM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM<V=S='(@
M(E!'4"#-Q2#%(.#J\NCBY>TB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3@V"FUS9VED(")&:6YD(@IM<V=S='(@(M+Z\/'H(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP-0HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@36%I
M;&)O>"!086=E(@IM<V=S='(@(L_Z\.+@(/'R\.#MZ/;@(@H*(SH@;6%I;&)O
M>"YP:'`Z,S0U"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(L_Z\.+@(/'R
M\.#MZ/;@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"B,L(&9U
M>GIY"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R("+/\.7O\.#RZ"(*"B,Z(&9O
M;&1E<G,N<&AP.C(V-B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I
M<FTN:'1M;#HU"FUS9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O
M;&1E<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A
M9V5S96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E
M<V5L96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R
M("+-X.+HX^#R[O`@[>`@[^#OZNCRY2(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HS"B,L(&9U>GIY"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R
M("+4Y>+P\^#PZ"(*"B,Z(&%C;"YP:'`Z,C0*;7-G:60@(D9O;&1E<B!S:&%R
M:6YG(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HV,@IM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B1F]R
M;6%T(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@
M;65S<V%G97,@9&%T960@=&]D87DB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP
M:'`Z-S@P('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ
M-0HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B
M1F]R=V%R9"(*;7-G<W1R("+/\.7O\.#RZ"(*"B,Z(&-O;7!O<V4N<&AP.C<V
M-0IM<V=I9"`B1F]R=V%R9#HB"FUS9W-T<B`BS_#E[_#@\N@Z(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C,V.0IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4B"FUS
M9W-T<B`BS_#E[_#@\N7M[B#OZ/'L[B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4@9G)O
M;2`E<R(*;7-G<W1R("+/\.7O\.#RY>WN(._H\>SN(.[R("5S(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,PHC+"!F=7IZ>0IM<V=I9"`B1G)E
M92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@T?KP
MXOKPX"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.30*;7-G:60@
M(D9R964O0G5S>2!297!L>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Q"FUS9VED
M(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(W"B,L(&9U
M>GIY"FUS9VED(")&<F]?;2(*;7-G<W1R("+.\B(*"B,Z(&UE<W-A9V4N<&AP
M.C(V,R!T:')E860N<&AP.C$T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I9"`B1G)O;2(*;7-G
M<W1R("+.\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3@*;7-G:60@
M(D9R;VT@061D<F5S<R(*;7-G<W1R("+.\B#@Y/#E\2(*"B,Z(&-O;7!O<V4N
M<&AP.C<W-R!C;VUP;W-E+G!H<#HW.#$*;7-G:60@(D9W9#HB"FUS9W-T<B`B
M1G=D.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.30*;7-G:60@(D9W9#H@(@IM<V=S
M='(@(D9W9#H@(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E<R(*;7-G<W1R(")&
M=V0Z("5U(,_PY>_PX/+E[>X@[^CQ[.XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*(RP@
M9G5Z>GD*;7-G:60@(D=E;F5R86P@3W!T:6]N<R(*;7-G<W1R("+/[O+PY>'H
M\N7K\>KH(.[O]NCH(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C,W"B,L(&9U>GIY"FUS9VED(")'970@;VYL>2!N97<@;65S<V%G97,_
M("A)34%0(&]N;'DI(@IM<V=S='(@(LCG\N7CZ^@@\>#L[B#M[N+H\N4@[^CQ
M[.`@*/'@[.X@Y^`@24U!4"DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHS,0IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H
M<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B
MT>OEY.+@^>X@[^CQ[.XB"@HC.B!L:6(O24U0+G!H<#HT.3@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O
M9B!<(B5S7"(B"FUS9W-T<B`BQ.[AX.+H(.KZ["#@Y/#E\>W@(.KMZ./@("@E
M<RDB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3,U"FUS9VED(")'<F%N
M="!A8V-E<W,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-30V(&QI8B]&
M:6QT97(N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC
M.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#(@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C$V,R!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R(&QI8B]-24U%+U9I97=E
M<B]N;W1I9FEC871I;VXN<&AP.C8X"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA
M=&5D+G!H<#HW.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC.B!L
M:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C$W,PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HQ,C`@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(W"FUS9VED(")(
M15)%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,2!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$W"B,Z(&QI8B]-
M24U%+U9I97=E<B]R96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R
M("(B"@HC.B!C;VUP;W-E+G!H<#HR-38*;7-G:60@(DA434P@5F5R<VEO;B!O
M9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C4X"FUS9VED(")(96%D97)S(@IM<V=S='(@(L?@X^O@XNWH
M(/?@\?+H(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU
M"FUS9VED(")(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O<VEN
M9SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V.`IM
M<V=I9"`B2&ED9&5N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-C<*(RP@9G5Z>GD*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE
M=R(*;7-G<W1R("+(Y^/KY>0@[^X@\>SH\>ONXN@@[>CXZN@B"@HC.B!M86EL
M8F]X+G!H<#HS-C<*;7-G:60@(DAI9&4@1&5L971E9"(*;7-G<W1R("+1ZO#H
MZ2#HY_+PZ/+H\N4B"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(DAI9&4@
M56YS=6)S8W)I8F5D(@IM<V=S='(@(M'J\.CI(.WEX.'N[>CPX.WH\N4B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI
M9V@B"FUS9W-T<B`BP?KPY^XB"@HC.B!M97-S86=E+G!H<#HR.3<@;6%I;&)O
M>"YP:'`Z-S(T('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3(*;7-G
M:60@(DAI9V@@4')I;W)I='DB"FUS9W-T<B`BP?KPY^`@[^[YX"(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,PIM<V=I9"`B2&EG:&5S
M="(*;7-G<W1R("+%ZO'O\.7Q[>XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C@X"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A
M8VAM96YT<S\B"FUS9W-T<B`BRN#J(.CQZN#RY2#DX"#QY2#O[NK@Y^+@\B#O
M\.CJ\.7OY>WH\N4@].#IZ^[BY3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E
M9"!L:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(LK@ZOKB(.3@(.4@[_#E].CJ
M\>`@[_#EY"#KZ.WHZ/+E(.(@[^CQ[.[R[B#N\N/NXN[P.B(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,3,T"FUS9VED("))34%0(@IM<V=S='(@(DE-
M05`B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!
M4"`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD
M960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,38V(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0
M(&]V97(@4U-,(@IM<V=S='(@(DE-05`@XOKP]?,@4U-,(@H*(SH@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(DE-05`@;W9E
M<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("))34%0
M(.+Z\/7S(%-33"`H\>#L[N_NY._H\>#M*2(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,38W"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I
M9VYE9"DB"FUS9W-T<B`B24U!4"#B^O#U\R!34TP@*/'@[.[O[N3OZ/'@[2DB
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!4"!S97)V
M97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(DE-05`L(.'E
MYR!43%,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C0Y"FUS9VED("))
M34%0+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N
M<&AP.C@V-@IM<V=I9"`B24Y"3U@B"FUS9W-T<B`B24Y"3U@B"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,
M4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO
M861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R
M<U]C;VYF:7)M+FAT;6PZ,3(*;7-G:60@(DEF('EO=2!C;VYT:6YU92P@86QL
M(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#(*
M;7-G:60@(DEG;F]R92(*;7-G<W1R("+(X^WN\.CPX.DB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#,*;7-G:60@(DEG;F]R92!!;&PB
M"FUS9W-T<B`BR./M[O#H\.#I(.+QZ/?JZ"(*"B,Z('1E;7!L871E<R]S879E
M:6UA9V4O<V%V96EM86=E+FEN8SHX"FUS9VED("));6%G92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P"B,L(&9U>GIY
M"FUS9VED("));7!O<G0B"FUS9W-T<B`BPN#F[>@B"@HC.B!T96UP;&%T97,O
M<VUI;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?
M:V5Y+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R
M("+([._N\/(@[>`@4$=0(.KK_O<B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3,Y"B,L(&9U>GIY"FUS9VED("));7!O<G0@2V5Y<&%I<B(*;7-G<W1R
M("+([._N\/(@[>`@4$=0(.KK_O<B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($UE<W-A9V5S
M(@IM<V=S='(@(L+@YNWN(._H\>SN(@H*(SH@<&=P+G!H<#HT,@IM<V=I9"`B
M26UP;W)T(%!'4"!+97DB"FUS9W-T<B`BR.SO[O#R(.W@(%!'4"#JZ_[W(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0HC+"!F=7IZ>0IM<V=I
M9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@(LCL[^[P
M\B#MX"#KZ/?E[2#WX/'RY>T@4$=0(.KK_O<B"@HC.B!T96UP;&%T97,O<&=P
M+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N86P@4')I
M=F%T92!01U`@2V5Y(@IM<V=S='(@(LCL[^[P\B#MX"#KZ/?E[2#WX/'RY>T@
M4$=0(.KK_O<B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.CD*
M;7-G:60@(DEM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G<W1R
M("+([._N\/(@[>`@[^7P\>[MX.OE[2#O\^'KZ/?E[2!01U`@ZNO^]R(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT"B,L(&9U>GIY"FUS
M9VED("));7!O<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<R(*;7-G
M<W1R("+([._N\/(@[>`@[^7P\>[MX.OE[2#O\^'KZ/?E[2!3+TU)344@ZNO^
M]R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#`@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C0R"B,L(&9U>GIY"FUS9VED("));7!O<G0@4'5B;&EC
M($ME>2(*;7-G<W1R("+([._N\/(@[>`@[_/AZ^CWY>T@4$=0(.KK_O<B"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R
M="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("+([._N\/(@[>`@[_/AZ^CWY>T@
M4$=0(.KK_O<B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z
M.`HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM
M<V=S='(@(LCL[^[P\B#MX"#OY?#Q[NW@Z^7M(._SX>OH]^7M(%,O34E-12#J
MZ_[W(@H*(SH@<VUI;64N<&AP.C$V"FUS9VED("));7!O<G0@4R]-24U%($ME
M>2(*;7-G<W1R("+([._N\/(@[>`@4R]-24U%(.KK_O<B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]I;7!O<G0N:6YC.CD*;7-G:60@(DEM<&]R="!M8F]X($9I
M;&4B"FUS9W-T<B`BR.SO[O#R(.W@(&UB;W@@].#IZR(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`B
M(@H*(SH@;65S<V%G92YP:'`Z-3`R(&UA:6QB;W@N<&AP.C<S-"!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,S"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM
M<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(L+@YNWH(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT(&UE<W-A9V5S
M(@IM<V=S='(@(L+@YNWN(._H\>SN(@H*(SH@9F]L9&5R<RYP:'`Z,38W"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@
M)7,N(@IM<V=S='(@(LCL[^[P\NCPX.WH(.'_]>`@)60@[^CQ[.`@[O(@)7,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,PIM<V=I9"`B26X@
M4')O8V5S<R(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS.#0@;&EB+T9O
M;&1E<BYP:'`Z.#8@;&EB+T9O;&1E<BYP:'`Z,C$T(&QI8B])35`N<&AP.C,Q
M,PHC.B!L:6(O24U!4"]4<F5E+G!H<#HQ,30@;&EB+TE-05`O5')E92YP:'`Z
M,C$Y"FUS9VED("));F)O>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DR"FUS9VED("));F-L=61E(&$@8G)I968@<W5M;6%R>2!O
M9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM<V=S='(@(L3@(/'E(.+JZ_[W
MXN`@Z^@@ZO#@\NKN(.[A[N'YY>WHY2#N\B!H96%D97)S(.(@[O+C[N+N\.`_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D
M92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(L3@(/'E
M(.+JZ_[WZ"#KZ"#H(.[PZ./H[>#K[>[R[B#OZ/'L[B#B(.[RX^[B[O#@/R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B26YF
M;R(*;7-G<W1R("+(X^WN\.CPX.DB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y(@IM<V=S
M='(@(LCM].[P[.#VZ/\@Y^`@)7,@[_/AZ^CWY>T@ZNO^]R(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R
M<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`BR.WT[O#LX/;H_R#GX"#OY?#Q
M[NW@Z^WH_R#WX/'RY>T@ZNO^]R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED("));F9O
M<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(LCM].[P
M[.#VZ/\@Y^`@[^7P\>[MX.OMZ/\@[_/AZ^CWY>T@ZNO^]R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU,#<*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:G,Z.3@*;7-G:60@(DEN;&EN92(*;7-G<W1R("+"(/#EY.`B
M"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.0HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T($-E<G1I9FEC871E($AE<F4B"FUS9W-T<B`BPNSZ
MZNWE\N4@ZNO^]^`@\O/J(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>2!(97)E(@IM<V=S='(@(LCL[^[P\B#MX"#KZ/?E[2#WX/'R
MY>T@4$=0(.KK_O<B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC
M.C$P"B,L(&9U>GIY"FUS9VED("));G-E<G0@4&5R<V]N86P@4'5B;&EC(%!'
M4"!+97D@2&5R92(*;7-G<W1R("+([._N\/(@[>`@[^7P\>[MX.OE[2#O\^'K
MZ/?E[2!01U`@ZNO^]R(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE
M<F4B"FUS9W-T<B`BR.SO[O#R(.W@(._SX>OH]^7M(%!'4"#JZ_[W(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,@IM<V=I9"`B26YV86QI9"!!
M8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R("(B
M"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O>"YP:'`Z-C(V"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS9W-T<B`BQ6UA:6P@X.3PY?$B
M"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C,P-PIM<V=I9"`B26YV86QI
M9"!296UO=&4@36%I;&)O>"(*;7-G<W1R("+-Y>+@Z^CD[>`@[O+DX.OE]^7M
MX"`H[>7K[NK@Z^W@*2#O[OEE[?'JX"#J\_+H_R(*"B,Z(&-O;7!O<V4N<&AP
M.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I
M;B!E+6UA:6P@861D<F5S<SH@)7,N(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H
M<#HX,B!P9W`N<&AP.C$V"FUS9VED("));G9A;&ED(&ME>2(*;7-G<W1R("+-
MY>+@Z^CDY>T@ZNO^]R(*"B,Z('!G<"YP:'`Z,3DV"FUS9VED("));G9A;&ED
M('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS9W-T<B`BS>7BX.OHY.7M
M(._E\/'N[>#KY>T@4$=0(/?@\?+E[2#JZ_[W+B(*"B,Z('!G<"YP:'`Z,3<Q
M"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y+B(*;7-G
M<W1R("+-Y>+@Z^CDY>T@[^7P\>[MX.OE[2!01U`@[_/AZ^CWY>T@ZNO^]RXB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R"FUS9VED("))
M;G9E<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-3<W"FUS9VED(")+0B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3$S"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(L3Z
MZ^;H[>`@[>`@ZNO^]^`B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W
M"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM
M92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E;F5R871I
M;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED(")+97D@:6UP;W)T
M(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D
M(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P+FEN8SHS.0IM<V=I
M9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N
M;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C;VYT86-T
M<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME>2!S=6-C
M97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`BRNO^]^`@X>7XY2#HY^_PX/+E[2#S\>_E^.WN(.(@[_/AZ^CW[>C_(.KK
M_O?Q^O#B^O`N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,38*
M;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(L7GZ.HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3`V"B,L(&9U>GIY"FUS9VED("),87-T($UA:6QB;W@@
M4&%G92(*;7-G<W1R("+/[O'KY>3MX"#Q\O#@[>CVX"(*"B,Z(&UA:6QB;W@N
M<&AP.C,U.`IM<V=I9"`B3&%S="!086=E(@IM<V=S='(@(L_N\>OEY.W@(/'R
M\.#MZ/;@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@Y
M"B,L(&9U>GIY"FUS9VED("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R("+/
M\.CJ\.7OY>WH(/3@Z>ONXN4B"@HC.B!A='1A8VAM96YT+G!H<#HS-"!L:6(O
M0V]M<&]S92YP:'`Z,3`V,PHC+"!F=7IZ>0IM<V=I9"`B3&EN:V5D(&%T=&%C
M:&UE;G1S(&%R92!F;W)B:61D96XN(@IM<V=S='(@(LW_[.`@[>#LY?#E[>@@
M[_#HZO#E[^7MZ"#TX.GK[N+E+B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DQI;FMS('=I;&P@97AP:7)E(&]N("5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@R"FUS
M9VED("(B"B),:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O
M;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"`B"B)O;FQY
M('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI
M(@IM<V=S='(@(B(*(L3@(/'E(._NZN#GXN#R(.OH(.+QZ/?JZ"#J[NWRX.KR
MZ"P@ZN[CX/+N(/'E(.?@\.7FY.`@Y>KPX.W@(/$@ZN[M\N#J\N@_("C@ZNX@
M(@HBY2#GX.'PX.WE[>XL(/GE(.+HYN3@\N4@\>#L[B#J[NWRX.KRZ/+E(.KN
MZ/+N(/'RY2#R^O#QZ.OH*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.#4*;7-G:60@(DQI<W1I;F<@:6X@=&AE($AE861E<B(*;7-G<W1R("+1[^CQ
M^NH@XB#GX./KX.+HY?+N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C,P"FUS9VED("),;V-A;"!-86EL8F]X.B(*;7-G<W1R("++[NK@
MZ^W@(._N^>`Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`HC
M+"!F=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BQ.7I\?+BZ.4B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R-0HC+"!F=7IZ>0IM<V=I
M9"`B3&]G(&EN(@IM<V=S='(@(L+U[N0@XB`E<R(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O
M("5S(@IM<V=S='(@(L+U[N0@XB`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3,W"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("+'
MX.3@]^@@[_#H(.+U[N0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*
M;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(L?@Y.#WZ"#O\.@@XO7NY"(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-@IM<V=I9"`B
M3&]W(@IM<V=S='(@(L[AZ.KM[N+E[>WN(@H*(SH@;65S<V%G92YP:'`Z,CDY
M(&UA:6QB;W@N<&AP.C<R-R!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC
M.C$S"FUS9VED("),;W<@4')I;W)I='DB"FUS9W-T<B`BT>O@X2#O\.CN\.CR
MY?(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3<*;7-G
M:60@(DQO=V5S="(*;7-G<W1R("+!Y><@[_#H[O#H\N7R(@H*(SH@;&EB+TU)
M344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`HC+"!F=7IZ>0IM<V=I9"`B
M36%C:6YT;W-H($9I;&4B"FUS9W-T<B`BS^[YX"#4Z.OR\.@B"@HC.B!T96UP
M;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*;7-G:60@(DUA:6PB"FUS
M9W-T<B`BS^[YX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R("+/[OG@(-3HZ_+P
MZ"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z
M,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SHB"FUS
M9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#`R"FUS9VED(")-86EL8F]X(@IM
M<V=S='(@(L_N^>7M\>K@(.KS\NC_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R("+$Z/'OZ^7I(,[O]NCH(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL
M($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")-87)K($%L
M;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-2!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-87)K(&%S.B(*
M;7-G<W1R("+,X/#JZ/#@Z2#JX/+N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T
M:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`BQ.`@\>4@[.#P
MZNCPX/(@Z^@@\.#GZ^CW[>CRY2#MZ.+@(.W@(.[RX^[B[O#H(/$@\.#GZ^CW
M[>@@]N+E\N[BY3\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-#`*(RP@9G5Z>GD*;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@
M*$E-05`@;VYL>2DB"FUS9W-T<B`BS.#PZNCPX.D@[^CQ[.#RX"#JX/+N(._P
MY>/KY>3@[>@@*/'@[.X@Y^`@24U!4"DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C4X"FUS9VED(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT-@IM<V=I9"`B
M36%T8V@@06QL(%%U97)I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C0R"FUS9VED(")-871C:"!!;GD@475E<GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S
M"B,L(&9U>GIY"FUS9VED(")-87AI;75M($%T=&%C:&UE;G0@4VEZ92(*;7-G
M<W1R("+/\.CJ\.7OY>T@].#IZR(*"B,Z(&QI8B]A<&DN<&AP.C<Y"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!&;VQD97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-`IM<V=I9"`B36%X:6UU
M;2!N=6UB97(@;V8@871T86-H;65N=',@<F5A8VAE9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@Y"FUS9VED(")-
M87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(V"FUS9VED(")-
M965T:6YG($-A;F-E;&QA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3<U"B,L(&9U>GIY"FUS9VED(")-965T:6YG($EN
M9F]R;6%T:6]N(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@T?KPXOKPX"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I;F<@
M4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8Q-PIM<V=I9"`B365E=&EN9R!297!L>2(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DX"FUS9VED(")-965T:6YG(%5P
M9&%T92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C`S"FUS9VED(")-965T:6YG(%5P9&%T92!297%U97-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,*(RP@9G5Z>GD*;7-G
M:60@(DUE;G4@1F]L9&5R($QI<W0B"FUS9W-T<B`BSO+B[O#H(._@[^K@(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S<V%G92(*;7-G<W1R
M("+/Z/'L[B(*"B,Z(&-O;7!O<V4N<&AP.C4V,"!C;VUP;W-E+G!H<#HU.#<@
M8V]M<&]S92YP:'`Z-C0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`IM<V=I
M9"`B365S<V%G92!#;VUP;W-I=&EO;B(*;7-G<W1R("+-X._H\>+@[>4@[>`@
M[^CQ[.XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$W"FUS9VED(")-
M97-S86=E($1A=&4B"FUS9W-T<B`BQ.#RX"#MX"#OZ/'L[O+N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`S"B,L(&9U>GIY"FUS9VED(")-97-S86=E($]P=&EO
M;G,B"FUS9W-T<B`B[^CQ[.#RX"#B(@H*(SH@<V5A<F-H+G!H<#HS,3(*;7-G
M:60@(DUE<W-A9V4@4V5A<F-H(@IM<V=S='(@(M+Z\/'E[>4@[>`@[^CQ[.XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")-97-S86=E
M(%-I>F4B"FUS9W-T<B`BT.#G[.7P(.W@(._H\>SN\NXB"@HC.B!M97-S86=E
M+G!H<#HS.#0*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(O'N\/$@
MZN[D(.W@(._H\>SN\NXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*
M;7-G:60@(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R("+/\.7CZ^7D(.W@(._H
M\>SN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-
M97-S86=E(&9L86=S(@IM<V=S='(@(M3KX./NXN4@[>`@[^CQ[.[R[B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#,*;7-G:60@(DUE<W-A9V4@
M9F]L9&5R<R(*;7-G<W1R("+/X._JZ"#GX"#OZ/'LX"(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B365S<V%G92!F<F]M
M("5S(@IM<V=S='(@(L_H\>SN(.[R("5S(@H*(SH@;6%I;&)O>"YP:'`Z-C8W
M"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G
M<W1R("+(Y_+PZ.D@[_#HZO#E[^7MZ/_R(/3@Z>L@)7,N(@H*(SH@;6%I;&)O
M>"YP:'`Z-C4X"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E
M9"(*;7-G<W1R("+/[NOE\N`@[>`@[^CQ[.[R[B(*"B,Z(&UA:6QB;W@N<&AP
M.C8U,PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!I<R!S:6=N960B"FUS9W-T
M<B`BS^[KY?+@(.W@(._H\>SN\NXB"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*
M;7-G<W1R("+$X/+@(.W@(._H\>SN\NXB"@HC.B!C;VUP;W-E+G!H<#HX,C0@
M8V]M<&]S92YP:'`Z.#,X"B,L(&9U>GIY"FUS9VED(")-97-S86=E(')E9&ER
M96-T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+/Z/'L[O+N(.'E^.4@Z.?O
M\.#RY>WN(//Q[^7X[>XN(@H*(SH@8V]M<&]S92YP:'`Z,3`X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@
M;F]T('-A=F5D('1O("5S(@IM<V=S='(@(L_H\>SN\NX@X>7XY2#HY^_PX/+E
M[>X@\_'OY?CM[BP@[>X@[>4@X>7XY2#GX._H\>#M[B#B("5S(@H*(SH@8V]M
M<&]S92YP:'`Z,3$T,R!C;VUP;W-E+G!H<#HQ,34X"FUS9VED(")-97-S86=E
M('-E;G0@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+/Z/'L[O+N(.'E^.4@Z.?O
M\.#RY>WN(//Q[^7X[>XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT
M,0IM<V=I9"`B365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE
M=RXB"FUS9W-T<B`BS^CQ[.`@XB#Q\O#@[>CVX"#GX"#O[OGE[?'JX/+@(.KS
M\NC_+B(*"B,Z(&UA:6QB;W@N<&AP.C,R,@IM<V=I9"`B365S<V%G97,@=&\B
M"FUS9W-T<B`B[^CQ[.#RX"#B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C(Y"B,L(&9U>GIY"FUS9VED(")-;V1I9GDB"FUS9W-T<B`BTO_K[B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L
M9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHU,`IM<V=I9"`B36]V92(*;7-G<W1R("+/\.7LY?'RZ"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-@HC+"!F=7IZ>0IM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(NW@(.3NZ_,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C$X"FUS9VED(")-;W9E('-P86T@;65S<V%G97,@
M=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`HC
M+"!F=7IZ>0IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`BZ.?AY?#H
M(._@[^K@(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S$T"B,L(&9U>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@(NW@(./N\.4B
M"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$R-PIM<V=I
M9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@(B(*"B,Z('1H<F5A
M9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(DUU;'1I
M<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R("+/\.7CZ^7D(.W@(._H\>SN(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C4*
M;7-G:60@(DY/3D4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C0X('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I9"`B3D]412(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S."!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(").86UE(@IM<V=S
M='(@(LCLY2(*"B,Z('!G<"YP:'`Z,3$P"FUS9VED(").86UE(&%N9"]O<B!E
M;6%I;"!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(LCLY2#H+^CKZ"!E;6%I
M;"#MY2#L[N/@\B#DX"#QX"#O\.#G[>@B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S<X"B,L(&9U>GIY"FUS9VED(").965D<R!!8W1I;VXB"FUS
M9W-T<B`BQ.7I\?+BZ.4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<W.`IM<V=I9"`B3F5V97(B"FUS9W-T<B`BS>CJ[N/@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`HC+"!F=7IZ>0IM<V=I9"`B3F5V
M97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R("+(Y_+PZ.D@[_#HZO#E[^7M
MZ/_R(/3@Z>L@)7,N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R-`IM
M<V=I9"`B3F5W(@IM<V=S='(@(LWNXN@B"@HC.B!L:6(O24U0+G!H<#HU-C,*
M;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T<B`BS>[BX"#OX._JX"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B3F5W($UA:6PB"FUS9W-T
M<B`BS>[BX"#O[OG@(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y(&QI
M8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(").
M97<@365S<V%G92(*;7-G<W1R("+1Z^7DXN#Y[B#OZ/'L[B(*"B,Z(&UA:6QB
M;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@
M(LWNXN@@[^CQ[.`B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Y
M"FUS9VED(").97<@;65S<V%G97,B"FUS9W-T<B`BS>[BZ"#OZ/'LX"(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*(RP@9G5Z>GD*
M;7-G:60@(DYE>'0B"FUS9W-T<B`BTN7J\?(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S"FUS9VED(").97AT($UE<W-A
M9V4B"FUS9W-T<B`BT>OEY.+@^>X@[^CQ[.XB"@HC.B!M86EL8F]X+G!H<#HS
M-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R("+1Z^7DXN#YX"#Q\O#@[>CV
MX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS9VED(").;R(*;7-G<W1R("+-Y2(*
M"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO($-E<G1I9FEC871E(&9O=6YD
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES
M="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO;B(*;7-G<W1R("+!Y><@ZO#H
M[_+H\.#MY2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B
M3F\@2V5Y<R!I;B!+97ER:6YG(@IM<V=S='(@(LW_[.`@ZNO^]^[BY2#B(/'O
MZ/'ZZN`B"@HC.B!M86EL8F]X+G!H<#HS-S4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DYO($UE<W-A9V5S(@IM<V=S='(@(LWNXN@@[^CQ[.`B"@HC
M.B!P9W`N<&AP.C$S-PIM<V=I9"`B3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T
M960N(@IM<V=S='(@(LW_[.`@Z.SO[O#RZ/#@[2!01U`@[_/AZ^CWY>T@ZNO^
M]RXB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C@T"B,L(&9U>GIY
M"FUS9VED(").;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT(@IM<V=S
M='(@(LCL[^[P\B#MX"#KZ/?E[2#WX/'RY>T@4$=0(.KK_O<B"@HC.B!L:6(O
M36%I;&)O>"YP:'`Z,S(Y"B,L(&9U>GIY"FUS9VED(").;R!0<F5V:65W(%1E
M>'0B"FUS9W-T<B`BRN[PZ./H\.#M(/+EZO'R(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B3F\@4'5B;&EC($ME
M>7,@1F]U;F0B"FUS9W-T<B`BPN#XZ/_R(._SX>OH]^7M(.KK_O<B"@HC.B!S
M;6EM92YP:'`Z,34Q"B,L(&9U>GIY"FUS9VED(").;R!3+TU)344@<'5B;&EC
M(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`BS>4@X>7XY2#H[._N\/+H\.#M(._E
M\/'N[>#KY>T@4R]-24U%(._SX>OH]^7M(.KK_O<N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W1N968N<&AP.CDP"FUS9VED(").;R!A='1A8VAM96YT<R!F;W5N
M9"XB"FUS9W-T<B`BS?_LX"#MX.SE\.7MZ"#O\.CJ\.7OY>WH(/3@Z>ONXN4N
M(@H*(SH@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@
M(DYO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K
M97DN(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@)7,@[_/AZ^CWY>T@ZNO^]R(*
M"B,Z(&%C;"YP:'`Z-S(@86-L+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M9F]L9&5R('-E;&5C=&5D+B(*;7-G<W1R("+-_^S@(.CGX?#@[>`@[^#OZN`B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD
M97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B
M(@H*(SH@9F]L9&5R<RYP:'`Z,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L:6(O
M1F]L9&5R+G!H<#HU-3`*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I
M960B"FUS9W-T<B`BS>4@X?_UX"#HY^'PX.WH(._@[^KH(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C$T-PHC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R
M<R!W:71H(&YE=R!M97-S86=E<R(*;7-G<W1R("+-Y>CG\O#H\N@@[^CQ[.`B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30T"B,L(&9U>GIY"FUS9VED
M(").;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(LWE
MZ.?R\.CRZ"#OZ/'LX"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,C4*;7-G:60@
M(DYO(&UE<W-A9V4@8F]D>2!T97AT(@IM<V=S='(@(LW_[.`@\N7J\?(@XB#R
M_^ON\NX@[>`@[^CQ[.[R[B(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS-S$*;7-G
M:60@(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N(@IM<V=S='(@
M(LW_[.`@[^CQ[.`@[O+C[N+@\/_YZ"#MX"#R^O#QY>WE\NXN(@H*(SH@<&=P
M+G!H<#HQ.#D*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I
M;7!O<G1E9"XB"FUS9W-T<B`BS>4@X>7XY2#H[._N\/+H\.#M(._E\/'N[>#K
MY>T@4$=0(/?@\?+E[2#JZ_[W+B(*"B,Z('!G<"YP:'`Z,38U"FUS9VED(").
M;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B
MS>4@X>7XY2#H[._N\/+H\.#M(._E\/'N[>#KY>T@4$=0(._SX>OH]^7M(.KK
M_O<N(@H*(SH@<VUI;64N<&AP.C(P,0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&5R
M<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B
MS>4@X>7XY2#H[._N\/+H\.#M(._E\/'N[>#KY>T@4R]-24U%(/?@\?+E[2#J
MZ_[W+B(*"B,Z('-P96QL:6YG+G!H<#HR,C`*;7-G:60@(DYO('-P96QL8VAE
M8VMI;F<@<')O9W)A;2!C;VYF:6=U<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G:60@(DYO('-P96QL
M:6YG(&5R<F]R<R(*;7-G<W1R("+-_^S@(._PX.+N[^CQ[>@@X_#E^.KH(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P,`IM<V=I9"`B
M3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`BS?_LX"#O\.7DZ^[FY>WH_R(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-38T"FUS9VED(").;R!S=7!P;W)T960@
M24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-C@@86-L+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@=7-E<B!S<&5C:69I960N(@IM<V=S='(@(LW_[.`@Y^#DX.3E
M[2#RY>KQ\B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#D*;7-G
M:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C$Q('1E;7!L871E<R]P<F5F<R]S96YT;6%I
M;'-E;&5C="YI;F,Z-#`*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C
M="YI;F,Z,S4@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(DYO;F4B"FUS
M9W-T<B`BS?_LX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y-0IM<V=I9"`B3F]R;6%L(@IM<V=S='(@(LWN\.S@Z^WN(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C,Y"FUS9VED(").;W0@1&5L971E9"(*;7-G<W1R("+-
MY>CG\O#H\N@B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R
M869T(@IM<V=S='(@(LWE+??E\.WNXN@B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,T
M"FUS9VED(").;W0@26UP;W)T86YT(@IM<V=S='(@(LS@Z^[BX.;MZ"(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*;7-G:60@(DYO="!0
M97)S;VYA;"(*;7-G<W1R("+-Y2WKZ/?MZ"(*"B,Z(&QI8B]#<GEP="]01U`N
M<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S-"!L:6(O0W)Y<'0O4TU)
M344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB"FUS
M9W-T<B`BS>7BX.OHY.7M(._SX>OH]^7M(.KK_O<N(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T960@;65S<V%G
M97,B"FUS9W-T<B`BS>7HY_+PZ/+H(._H\>S@(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B3F]T(&EM<&]R=&%N="!M97-S86=E
M<R(*;7-G<W1R("+,X.ONXN#F[>@@[^CQ[.`B"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C<Q"FUS9VED(").;W1E('1H
M870@=&AI<R!C86X@=&%K92!S;VUE('1I;64B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8Q-@HC+"!F=7IZ>0IM<V=I9"`B3F]T:&EN
M9R(*;7-G<W1R("+.\N/NXN[P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W-PHC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P
M(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2XB
M"FUS9W-T<B`B(@HBP?#NZ2#MX"#Q\N#PZ/+E(._@[^KH(%PBR.?O\.#RY>W@
M(._N^>!<(B#GX"#Q^O7PX.WE[>CE+"#@ZNX@\>4@\O#H__(@[.7QY??M[BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"FUS9VED(").=6UB97(@
M;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@
M;6]N=&AL>2XB"FUS9W-T<B`B(@HBP?#NZ2#MX"#Q\N#PZ/+E(._@[^KH(%PB
MR.?O\.#RY>W@(._N^>!<(B#GX"#Q^O7PX.WE[>CE+"#@ZNX@\>4@\O#H__(@
M[.7QY??M[BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(U-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,S,*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHT.0HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K
M97DN:6YC.C0X"FUS9VED(")/4B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C$U"FUS9VED(")/;&0@;65S<V%G97,B"FUS9W-T
M<B`BT?+@\.@@[^CQ[.`B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE
M=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT+6UA
M:6P@9F]L9&5R<R!B96EN9R!P=7)G960N(@IM<V=S='(@(M'RX/#H(._@[^KH
M(%PBR.?O\.#RY>W@(._N^>!<(BP@ZN[I\NX@\>4@Y^#KZ/?@XN#R+B(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B3VYL>2!D:7-P;&%Y
M(&9O;&1E<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHW.0IM
M<V=I9"`B3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@
M=&AI<R!A8W1I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M96YU+FEN
M8SHQ,"!T96UP;&%T97,O;65N=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@(D]P
M96X@1F]?;&1E<B(*;7-G<W1R("+.\N+N\.@@[^#OZN`B"@HC.B!F;VQD97)S
M+G!H<#HT,C<*(RP@9G5Z>GD*;7-G:60@(D]P96YE9"!&;VQD97(B"FUS9W-T
M<B`BSO+B[O#H(._@[^K@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<P-0IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*
M(SH@9F5T8VAM86EL+G!H<#HS,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI
M;F,Z,PHC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@HC
M+"!F=7IZ>0IM<V=I9"`B3W1H97(@36%I;"!!8V-O=6YT<R(*;7-G<W1R("+$
M\//CZ"#.[_;HZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS
M9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(L3P\^/H(,[O]NCH(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#$*;7-G:60@(D]U=&)O=6YD
M(%-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A
M<V4N:6YC.C$V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,CDP"FUS9VED(")01U`B"FUS9W-T<B`B4$=0(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHW"B,L(&9U>GIY"FUS9VED(")0
M1U`@16YC<GEP="!-97-S86=E(@IM<V=S='(@(L_NY._H^.@OZO#H[_+H\.#I
M(._H\>SN(/$@4$=0(@H*(SH@8V]M<&]S92YP:'`Z,S4X"B,L(&9U>GIY"FUS
M9VED(")01U`@17)R;W(Z("(*;7-G<W1R(")01U`@X_#E^.K@.B`E<R(*"B,Z
M(&-O;7!O<V4N<&AP.C,S-PIM<V=I9"`B4$=0($5R<F]R.B!.965D('!A<W-P
M:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R(")01U`@
MP_#E^.K@.B#-Y>[A]>[DZ.S@(.4@ZNO^]^[BX"#T\.#GX"#GX"#WX/'RY>T@
MZNO^]RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")0
M1U`@3W!T:6]N<R(*;7-G<W1R(")01U`@SN_VZ.@B"@HC.B!P9W`N<&AP.C,P
M"FUS9VED(")01U`@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("+"^N+EY.7R
MY2!01U`@ZNO^]^[BX"#T\.#GX"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHU-0IM<V=I9"`B4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U
M:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B4$=0(._E
M\/'N[>#K[>`@ZNO^]^[BX"#DXN[IZN`@Z.?H\>KBX"#J\.CO\NCPX.W@('=E
M8B#B\/KGZN`N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,L
M(&9U>GIY"FUS9VED(")01U`@4'5B;&EC($ME>2!497AT(@IM<V=S='(@(E!'
M4"#/\^'KZ/?E[2#JZ_[W(@H*(SH@<&=P+G!H<#HQ-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A<R!S
M=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E!'4"#O\^'KZ/?E[2#JZ_[W
M(.?@(%PB)7,@*"5S*5PB(.'E^.4@\_'OY?CM[B#D[N'@XN7M+B(*"B,Z('!G
M<"YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y
M(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R
M(")01U`@[_/AZ^CWY>T@ZNO^]R#GX"!<(B5S7"(@X>7XY2#S\>_E^.WN(.CG
M\O#H\BXB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")01U`@[_/AZ^CWY>T@\>_H\?KJ
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHX"FUS
M9VED(")01U`@4VEG;B!-97-S86=E(@IM<V=S='(@(L_NY._H^.@@\2!01U`@
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"FUS
M9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`BS^[D[^CX
MZ"_J\.CO\NCPX.D@[^CQ[.X@\2!01U`B"@HC.B!P9W`N<&AP.C(P,@HC+"!F
M=7IZ>0IM<V=I9"`B4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E
M9"XB"FUS9W-T<B`B4$=0(.3B[NGJX"#O\^'KZ/?E[2_WX/'RY>T@ZNO^]R#A
MY?CE(//Q[^7X[>X@Y.[AX.+E[>`N(@H*(SH@<&=P+G!H<#HQ-S<*(RP@9G5Z
M>GD*;7-G:60@(E!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB
M"FUS9W-T<B`B4$=0(.3B[NGJX"#O\^'KZ/?E[2_WX/'RY>T@ZNO^]R#AY?CE
M(//Q[^7X[>X@Y.[AX.+E[>`N(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I
M=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H
M:7,@<WES=&5M+B(*;7-G<W1R("+1Z/'RY>S@\N`@Y2#Q(.CGZNO^]^7MX"!0
M1U`@[^[DY/#ZYNK@+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P
M.`IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I
M=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B
M"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB4$=0(._NY.3P^N;JX/+@(.WE(.4@
MX.KRZ.+MX"#H(/;H]/#NXNC_\B#O[N3OZ/$@[>4@[.[FY2#DX"#A^N3E(._P
M[N+E\.7M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I
M9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@
M=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T
M<B`B4$=0(._NY.3P^N;JX/+@(.WE(.4@X.KRZ.+MX"#H(._H\>SN\NX@[>4@
M[.[FY2#DX"#A^N3E(.3EZO#H[_+H\.#M[BXB"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,@IM<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P
M=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U
M<G)E;G1L>2`B"B)S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@
M;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F
M96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B"FUS
M9W-T<B`B4$]0,R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`P"FUS
M9VED(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED
M(")03U`S(&]V97(@4U-,(@IM<V=S='(@(DE-05`@XOKP]?,@4U-,(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,C,*(RP@9G5Z>GD*;7-G:60@(E!/
M4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R
M(")03U`S(.+Z\/7S(%-33"`H\>#L[N_NY._H\>#M*2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")03U`S(&]V97(@4U-,("AS
M96QF+7-I9VYE9"DB"FUS9W-T<B`B4$]0,R#B^O#U\R!34TP@*/'@[.[O[N3O
MZ/'@[2DB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q,0IM<V=I9"`B
M4$]0,RP@;F\@5$Q3(@IM<V=S='(@(E!/4#,L(.'EYR!43%,B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`B\?+PX.WH]N`@)60@[O(@)60B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS9VED(")086=E('=I
M=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#0*;7-G:60@(E!A9V4@=VET:"!T:&4@
M3&%S="!5;G-E96X@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R="AS*2(*;7-G<W1R
M("+7X/'R*.@I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R,PIM<V=I
M9"`B4&%S<W!H<F%S92(*;7-G<W1R("+*Z_[W[N+@(/3PX.?@(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$R.`IM<V=I9"`B4&%S<W!H<F%S92`H06=A
M:6XI(@IM<V=S='(@(LKK_O?NXN`@]/#@Y^`@*.[R[>[B[BDB"@HC.B!S;6EM
M92YP:'`Z,C,U('!G<"YP:'`Z,S$P"FUS9VED(")087-S<&AR87-E('-U8V-E
M<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`BRNO^]^[BX/+@(/3PX.?@(.'E
M^.4@\_'OY?CM[B#O\.7LX/7MX/+@+B(*"B,Z('1E;7!L871E<R]S;6EM92]P
M87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC
M.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R("+*Z_[W[N+@(/3PX.?@
M.B(*"B,Z('!G<"YP:'`Z,3$R"FUS9VED(")087-S<&AR87-E<R!C86X@;F]T
M(&)E(&5M<'1Y(@IM<V=S='(@(LKK_O?NXN#RX"#T\.#GX"#MY2#L[N;E(.3@
M(.4@[_#@Y^W@(@H*(SH@<&=P+G!H<#HQ,30*;7-G:60@(E!A<W-P:')A<V5S
M(&1O(&YO="!M871C:"(*;7-G<W1R("+*Z_[W[N+@\N`@]/#@Y^`@[>4@\?KB
M[^#DX"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,"!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S$*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHQ.3(*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@
M(L_@\.[KX"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT
M.`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN/R(*;7-G<W1R("+$X"#QY2#HY^+Z\/CBX/(@Z^@@[N'QZ_/FXN#YZ/+E
M(.[OY?#@]NCH(._PZ"#"]>[D/R(*"B,Z(&%C;"YP:'`Z-S8@86-L+G!H<#HQ
M,#(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N(&YO="!B
M92!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HT.3,@;6%I
M;&)O>"YP:'`Z-S`S('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,`IM<V=I9"`B4&5R
M<V]N86PB"FUS9W-T<B`BS^7P\>[MX.OMZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T
M<B`BS^7P\>[MX.OMX"#H[?3N\.S@]NC_(@H*(SH@<&=P+G!H<#HQ,C`*;7-G
M:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(L_E\/'N[>#K[>`@4$=0(.KK_O?NXN`@Y.+NZ>K@(.'E
M^.4@\_'OY?CM[B#CY>WE\.CPX.W@+B(*"B,Z('!G<"YP:'`Z,3(W"FUS9VED
M(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`BS^7P\>[MX.OMZ"!01U`@ZNO^]^[BY2#A__7@(//Q[^7X[>X@Z.?R
M\.CRZ"XB"@HC.B!S;6EM92YP:'`Z,C`W"B,L(&9U>GIY"FUS9VED(")097)S
M;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S
M='(@(LWE(.'E^.4@Z.SO[O#RZ/#@[2#OY?#Q[NW@Z^7M(%,O34E-12#WX/'R
MY>T@ZNO^]RXB"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S;VYA;"!3
M+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BS^7P
M\>[MX.OMZ"!3+TU)344@ZNO^]^[BY2#A__7@(//Q[^7X[>X@Z.?R\.CRZ"XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(R"FUS9VED(")0;&%C92!Y
M;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_(@IM
M<V=S='(@(L3@(/'E(/'KX./@(.OH(.+@^.C_\B#O[N3OZ/$@[_#EY.@@[O+C
M[N+N\"#H(._PY>_PX/G@[>4_(@H*(SH@8V]M<&]S92YP:'`Z,C4T"B,L(&9U
M>GIY"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S
M='(@(L_NZN#FZ"#B(/'ZY/KPYN#MZ.7R[B#MX"#OZ/'L[O+N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y.0IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O
M;B!N97<@;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U
M<'!O<G0@96UB961D960@(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O
M(&]N(%=I;F1O=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL
M("(*(G)E<75I<F4@82!P;'5G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X
M+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA
M;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,W"FUS9VED(")0;&5A<V4@96YT
M97(@=&AE(&YE=R!N86UE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P
M+W!A<W-P:')A<V4N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L
M96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T
M92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R`B"B)E;G1E<B!T:&ES('!A
M<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HBS.[K
M_RP@XOKBY>3E\N4@ZNO^]^[BX"#T\.#GX"#GX"#"X/CH__(@4$=0(/?@\?+E
M[2#JZ_[W+B#-Y>[A]>[DZ.SN(.4@Y.`@(@HBXOKBY>3E\N4@\N#GZ"#T\.#G
MX"#BY>3M^N8@Y^`@)7,@\>7QZ/\N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A
M<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S
M92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T
M92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES('!A
M<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HBS.[K
M_RP@XOKBY>3E\N4@ZNO^]^[BX"#T\.#GX"#GX"#"X/CH__(@4R]-24U%(/?@
M\?+E[2#JZ_[W+B#-Y>[A]>[DZ.SN(.4@Y.`@(@HBXOKBY>3E\N4@\N#GZ"#T
M\.#GX"#BY>3M^N8@Y^`@)7,@\>7QZ/\N(@H*(SH@<F5C;VUP;W-E+G!H<#HY
M-PIM<V=I9"`B(@HB4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M
M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@(@HB
M8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P
M=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R`B"B)L;V<@:6X@86=A:6X@
M:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@
M871T86-K97)S(&9R;VT@(@HB:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@
M5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,0IM<V=I9"`B4&QE
M87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z
M,3`V(&QI8B])35`N<&AP.C0U.0IM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB
M:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+B(*;7-G<W1R("+,[NO_+"#J
M[O#HX^CPX.GRY2#MY>+@Z^CD[>CRY2#HZ^@@X>7G\>SH\>OE[>@@X.3PY?'H
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*
M(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD
M('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y
M;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4P,@IM<V=I9"`B4&QE87-E('-E;&5C="!A
M;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]J879A<V-R:7!T+FEN8SHT,0IM<V=I9"`B4&QE
M87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ
M,@IM<V=I9"`B4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD97(@9F]R('1H
M:7,@;W!E<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z-S,*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!S96QE
M8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T<B`B
MS.[K_RP@Z.?AY?#E\N4@Z.OH(/#EY.#J\NCPX.GRY3HB"@HC.B!C;VYF:6<O
M;6]T9"YP:'`N9&ES=#HT,0IM<V=I9"`B4&]W97)E9"!B>2!(;W)D92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$T"B,L(&9U>GIY
M"FUS9VED(")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G
M+2T@)RD_(@IM<V=S='(@(L_PY>3U[N;DX.GRY2#O[N3OZ/'@(/'H(/$@\NCP
MY?+@("@G+2T@)RDB"@HC.B!S;6EM92YP:'`Z,C0Q('!G<"YP:'`Z,C4W(&9I
M;'1E<G!R969S+G!H<#HT,`IM<V=I9"`B4')E9F5R96YC97,@<W5C8V5S<V9U
M;&QY('5P9&%T960N(@IM<V=S='(@(LW@\?+P[NGJZ/+E(.'_]>`@[N'M[N+E
M[>@@\_'OY?CM[BXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT
M<RYI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B4')E=FEE=R(*;7-G<W1R("+/\.7D
MZ/CMX"#Q\O#@[>CVX"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,C@*;7-G:60@(E!R979I;W5S($UE<W-A9V4B"FUS9W-T
M<B`BS_#EY.CX[>X@[^CQ[.XB"@HC.B!M86EL8F]X+G!H<#HS-#<*;7-G:60@
M(E!R979I;W5S(%!A9V4B"FUS9W-T<B`BS_#EY.CX[>`@\?+PX.WH]N`B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*;7-G
M:60@(E!R:6YT(@IM<V=S='(@(L[R[^7WX/+@Z2(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VAE861E<G,N:6YC.C,X"FUS9VED(")0<FEO<FET>2(*;7-G<W1R
M("+/\.CN\.CRY?(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM
M<V=S='(@(M?@\?+E[2#JZ_[W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4U.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I
M<R!S96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N
M(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED
M(")0<F]T;V-O;#HB"FUS9W-T<B`BS_#N\N[J[NLZ(@H*(SH@;&EB+T-R>7!T
M+U!'4"YP:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P
M;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R("+/[N3D\/KFZN#RX"#G
MX"!01U`@ZNO^]^[B(/'Z\.+Z\"#AY?CE(.?@X?#@[>7MX"XB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS7V1E;&5T960N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!U<E]G
M92!$96QE=&5D(@IM<V=S='(@(L?@Z^CWZ"#HY_+PZ/+H\N4B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS7V1E;&5T960N:6YC.C@*;7-G:60@(E!U<F=E($1E;&5T960B
M"FUS9W-T<B`BQ^#KZ/?H(.CG\O#H\NCRY2(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")0=7)G92!&;VQD
M97(H<RDB"FUS9W-T<B`BR.?R\.CI(._@[^K@*.@I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N
M.B(*;7-G<W1R("+*[NOJ[B#WY?'R[B#DX"#QY2#HY^_PX.?BX"#J[OCWY?+N
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E
M(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO
M=6YT(&]F(&1A>7,N(@IM<V=S='(@(LCG]^CQ\N@@[^CQ[.#RX"#N\B#J[OCW
MY?+N+"#J[NCR[B#QX"#O[BWQ\N#PZ"#N\B#R[NOJ[N+@(.3MZ"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"B,L(&9U>GIY"FUS9VED(")0=7)G
M92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS9W-T<B`B
MQ.`@\>4@Y^#KZ/?@XN#R(.OH(/'RX/#H\N4@[^CQ[.`@XB#J[OCWY?+N/R(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S86=E
M<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`BQ^#KZ/?@XN#MY2#MX"`E
M9"#OZ/'L[BC@*2#N\B#J[OCWY?+N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<'5R9V5?=')A<V@N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")0=7)G:6YG
M(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`BQ^#KZ/?@
MXN#MY2#MX"`E9"#OZ/'L[BC@*2#N\B#J[OCWY?+N(@H*(SH@=&5M<&QA=&5S
M+W%U;W1A+W%U;W1A+FEN8SHQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T
M82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"FUS9W-T<B`B
MRN+N\N`@\?+@\O/Q.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@H*(SH@
M=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*
M;7-G<W1R("+*XN[RX"#Q\N#R\_$Z(,'%QR#+R,S(TB(*"B,Z('1E;7!L871E
M<R]Q=6]T82]Q=6]T82YI;F,Z,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O
M=&$@<W1A='5S.B!.3R!,24U)5"(*;7-G<W1R("+*XN[RX"#Q\N#R\_$Z(,'%
MQR#+R,S(TB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(L[R
MX^[B[O`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#8*
M;7-G:60@(E)E7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4F5C
M96EV960@3VXB"FUS9W-T<B`BS^[K\_?E[>X@[>`B"@HC.B!L:6(O4V5A<F-H
M+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T
M<B`BS^[K\_?E[>X@[>`B"@HC.B!L:6(O4V5A<F-H+G!H<#HU-`HC+"!F=7IZ
M>0IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`BS^[K\_?E[>X@[>`B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,38*
M(RP@9G5Z>GD*;7-G:60@(E)E9&ER96-?="(*;7-G<W1R("+/\.7MX/'N]^@B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,38*
M;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(L_PY>W@\>[WZ"(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*(RP@9G5Z>GD*;7-G:60@
M(E)E9&ER96-T($UE<W-A9V4B"FUS9W-T<B`BS_#E[>#Q[O?H(/+NXN`@[^CQ
M[.XB"@HC.B!C;VUP;W-E+G!H<#HW.#<*;7-G:60@(E)E9&ER96-T('1H:7,@
M;65S<V%G92(*;7-G<W1R("+/\.7MX/'N]^@@\N[BX"#OZ/'L[B(*"B,Z(&-O
M;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*;7-G
M<W1R("+/\.7MX/'N]^+@[>7R[B#QY2#O\.[BX.OH(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@S"FUS9VED(")2969R97-H(@IM<V=S
M='(@(L[O\.7Q[>@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@T"FUS
M9VED(")2969R97-H($9O;&1E<B!6:65W<SHB"FUS9W-T<B`BSN_PY?'M_^+@
MZ2#HY^/KY>3H\N4@[>`@[^#OZNCRY2(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHT"B,L
M(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`BS_#EY^#PY>3H(.CGX^OE
MY.`B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHS"FUS9VED(")2
M96QO860@5FEE=R(*;7-G<W1R("+/\.7GX/#EY.@@Z.?CZ^7DX"(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C8@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4T-0IM<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDW.0IM<V=I9"`B4F5M96UB97(@=&AE(&QA<W0@=FEE=R(*;7-G<W1R("+'
MX._N[.WH(._N\>OEY.WH_R#HY^/KY>0B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*;7-G
M<W1R("+/[OGE[?'JX"#J\_+H_SHB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M(%-E87)C:"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS,#4*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T<B`B
M[_#E[.#U[>@@\>[P\>`B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHX"FUS9VED(")296YA;64@1F]L9&5R*',I(@IM<V=S='(@(L_PY>CL
MY>WSXN#I(._@[^K@*.@I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG
M(&]F(&UO;G1H/R(*;7-G<W1R("+$X"#QY2#O\.7H[.7M\^+@(.OH(%PBR.?O
M\.#RY>W@(._N^>!<(B#OX._JX"#B(.W@]^#K[O+N(.W@(.SE\>7VX#\B"@HC
M.B!L:6(O1F]L9&5R+G!H<#HT-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N
M86UI;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BS_#EZ.SE[?/BX.WE\NX@[>`@7"(E
M<UPB(.(@7"(E<UPB(/'E(._P[N+@Z^@N(,7R[B#JX.KB[B#JX.?@(/'Z\.+Z
M\.`B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,3`*(RP@9G5Z>GD*;7-G:60@(E)E<&Q?>2!T;R!,:7-T(@IM<V=S='(@(L[R
MX^[B[O`@Y.X@\>_H\?KJX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T<B`BQ^#L
MY>WH(/$Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S='(@(L[RX^[B[O`B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,S$Q(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT,#D*(RP@9G5Z>GD*;7-G:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@
M(L[RX^[B[O`B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R("+.\N/NXN[P
M(.3N(.+QZ/?JZ"(*"B,Z(&-O;7!O<V4N<&AP.C<S,PIM<V=I9"`B4F5P;'D@
M=&\@06QL.B(*;7-G<W1R("+.\N/NXN[P(.3N(.+QZ/?JZ#HB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G:60@(E)E
M<&QY('1O($QI<W0B"FUS9W-T<B`BSO+C[N+N\"#D[B#Q[^CQ^NK@(@H*(SH@
M8V]M<&]S92YP:'`Z-S,U"FUS9VED(")297!L>2!T;R!,:7-T.B(*;7-G<W1R
M("+.\N/NXN[P(.3N(/'OZ/'ZZN`Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")297!L>2!T
M;R!?06QL(@IM<V=S='(@(L[RX^[B[O`@Y.X@XO'H]^KH(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3,W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@
M(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S4*;7-G:60@(E)E<&QY
M('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,T"FUS9VED(")297!L
M>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-PIM<V=I9"`B4F5P;'DM5&\B"FUS
M9W-T<B`BSO+C[N+N\"W$[B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#D*;7-G
M:60@(E)E<&QY+51O.B`B"FUS9W-T<B`BSO+C[N+N\"W$[CHB"@HC.B!C;VUP
M;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*;7-G<W1R("+.\N/NXN[P.B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS."!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR-@HC+"!F=7IZ>0IM<V=I
M9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S='(@(M#@[^[P\B#GX"#1[^#L
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,U
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(S"FUS9VED(")297!O
M<G0@87,@4W!A;2(*;7-G<W1R("+0X._N\/(@Y^`@T>_@["(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X,PHC+"!F=7IZ>0IM<V=I9"`B
M4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`BR.?H\>K@Z2#O[O+B
M^O#FY.7MZ.4@Y^`@[^[K\_?@XN#MY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU.#4*;7-G:60@(E)E<75E<W0@9&5L:79E<GD@8V]N9FER;6%T:6]N
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S"B,L
M(&9U>GIY"FUS9VED(")297%U97-T(')E860@<F5C96EP=',_(@IM<V=S='(@
M(LCGZ/'JX.D@[^[RXOKPYN3E[>CE(.?@(._NZ_/WX.+@[>4B"@HC.B!M86EL
M8F]X+G!H<#HQ.#D*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y
M-PIM<V=I9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-#,@=&5M<&QA=&5S+W-E87)C
M:"]H96%D97(N:6YC.C(V"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C$*
M(RP@9G5Z>GD*;7-G:60@(E)E<V5T(@IM<V=S='(@(L_NY.WNXN@B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$U"FUS9VED(")297-P;VYD96YT
M(%-T871U<R!5<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G
M<W1R("+/[N3M[N+H(@H*(SH@<F5C;VUP;W-E+G!H<#HY.`IM<V=I9"`B4F5S
M=6UE('EO=7(@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T
M;R!<(DUE<W-A9V4@0V]M<&]S:71I;VY<(B(*;7-G<W1R("+-X._H\>+@[>4@
M[>`@[^CQ[.XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE
M8W0N:6YC.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,@HC
M+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`B
MQ/#SX^`@[^[YX"(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHV
M,"!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C(R"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,3`Q('1E;7!L871E<R]S;6EM92]N;W1A
M8W1I=F4N:6YC.C$T"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-#D@=&5M
M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHQ-C(@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$W,PHC+"!F=7IZ
M>0IM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`BS^[R\.7AZ/+E
MZ_'JZ"#N[_;HZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,3@*;7-G
M:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E
M;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/R(*;7-G<W1R
M("(B"B+"^O#MZ"#QY2#J^NP@[^[YY>WQZN#RX"#J\_+H_R#QZ^7D(.CG\O#H
MXN#MY2P@[.7Q\N7MY2#HZ^@@ZN[OZ/#@[>4@[>`@[^CQ[.XN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4F]L92(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T,B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(S-PHC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C0Q.0IM<V=I9"`B4R]-24U%(@IM<V=S='(@(E,O34E-12(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3(*(RP@9G5Z
M>GD*;7-G:60@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`BRO#H
M[_+H\.#MY2#MX"#OZ/'L[B(*"B,Z(&-O;7!O<V4N<&AP.C,Y-`HC+"!F=7IZ
M>0IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B4R]-24U%(@H*(SH@
M8V]M<&]S92YP:'`Z,S<S"B,L(&9U>GIY"FUS9VED(")3+TU)344@17)R;W(Z
M($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM
M<V=S='(@(E!'4"##\.7XZN`Z(,WE[N'U[N3H[.`@Y2#JZ_[W[N+@(/3PX.?@
M(.?@(/?@\?+E[2#JZ_[W+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-3$*;7-G:60@(E,O34E-12!/<'1I;VYS(@IM<V=S='(@(E,O34E-12#.[_;H
MZ"(*"B,Z('-M:6UE+G!H<#HT.0IM<V=I9"`B4R]-24U%(%!A<W-P:')A<V4@
M26YP=70B"FUS9W-T<B`BPOKBY>3E\N4@4R]-24U%(.KK_O?NXN`@]/#@Y^`B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)
M344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B)3+TU)344@[^[DY/#ZYNK@
M\N`@Y^`@[^7P\>[MX.OMX"#JZ_[W[N+@(.3B[NGJX"#HY^CQZN+@(.KPZ._R
MZ/#@[>`@=V5B("(*(N+P^N?JX"XB"@HC.B!S;6EM92YP:'`Z,30P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B4$=0
M(._SX>OH]^7M(.KK_O<@Y^`@7"(E<UPB(.'E^.4@\_'OY?CM[B#HY_+PZ/(N
M(@H*(SH@<VUI;64N<&AP.C$V,@HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%!U
M8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")3+TU)344@
MY.+NZ>K@(._SX>OH]^7M+_?@\?+E[2#JZ_[W(.'E^.4@\_'OY?CM[B#D[N'@
MXN7MX"XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P"B,L(&9U
M>GIY"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B4$=0
M(._SX>OH]^7M(/'OZ/'ZZB(*"B,Z('-M:6UE+G!H<#HR,3$*;7-G:60@(E,O
M34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E
M9"XB"FUS9W-T<B`B4R]-24U%(.3B[NGJX"#O\^'KZ/?E[2_WX/'RY>T@ZNO^
M]R#AY?CE(//Q[^7X[>X@Y.[AX.+E[>`N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%
M(%-I9VX@365S<V%G92(*;7-G<W1R("+/[N3OZ/CH(/$@4$=0("(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*(RP@9G5Z>GD*
M;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R("+/
M[N3OZ/CH+^KPZ._RZ/#@Z2#OZ/'L[B#Q(%!'4"(*"B,Z('1E;7!L871E<R]S
M;6EM92]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E,O34E-12!S=7!P;W)T(&ES
M(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("+1Z/'RY>S@\N`@
MY2#Q(.CGZNO^]^7MX"!3+TU)344@[^[DY/#ZYNK@+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"B,L(&9U>GIY"FUS9VED("(B"B)3+TU)
M344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE
M<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E9"XB"FUS9W-T<B`B
M(@HB4R]-24U%(._NY.3P^N;JX/+@(.WE(.4@X.KRZ.+MX"#H(._H\>SN\NX@
M[>4@[.[FY2#DX"#A^N3E(.3EZO#H[_+H\.#M[BXB"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B(@HB4R]-24U%
M('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H
M:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO="`B"B)B92!D:7-P;&%Y960N(@IM
M<V=S='(@(B(*(E,O34E-12#O[N3D\/KFZN#RX"#MY2#E(.#J\NCB[>`@Z"#O
MZ/'L[O+N(.WE(.SNYN4@Y.`@X?KDY2#DY>KPZ._RZ/#@[>XN(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(B(*
M(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L
M('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S
M='(@(B(*(E!'4"#O[N3D\/KFZN#RX"#MY2#E(.#J\NCB[>`@Z"#VZ/3P[N+H
M__(@[^[D[^CQ(.WE(.SNYN4@Y.`@X?KDY2#O\.[BY?#E[2XB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P
M;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO
M=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P
M=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E
M;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R
M96-T;'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C`U"FUS9VED(")33510(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(U-0HC+"!F=7IZ>0IM<V=I9"`B4U]U8FIE
M8W0B"FUS9W-T<B`BTN7LX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,V,PHC+"!F=7IZ>0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*
M;7-G<W1R("+'X._H^.@@ZN[OZ.4@XB`B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(E-A7W9E
M(&%S(@IM<V=S='(@(L?@[^CXZ"#JX/+N(@H*(SH@<V5A<F-H+G!H<#HS,38@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W"B,L(&9U>GIY"FUS
M9VED(")3879E(@IM<V=S='(@(L?@[^CXZ"#JX/+N(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE
M;G1S('=I=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*(RP@9G5Z>GD*;7-G:60@
M(E-A=F4@1')A9G0B"FUS9W-T<B`BQ^#OZ/CH(.K@\NXB"@HC.B!S879E:6UA
M9V4N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")3879E($EM86=E(@IM<V=S='(@
M(L?@[^CXZ"#JX/+N(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(P-`IM
M<V=I9"`B4V%V92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN
M8SHQ,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P
M9W`O;F]T86-T:79E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4V%V92!/<'1I
M;VYS(@IM<V=S='(@(L_N\O#EX>CRY>OQZN@@[N_VZ.@B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#`*;7-G:60@(E-A=F4@4W1A=&EO
M;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*(RP@
M9G5Z>GD*;7-G:60@(E-A=F4@7T1R869T(@IM<V=S='(@(L?@[^CXZ"#JX/+N
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R
M"FUS9VED(")3879E(&%S(@IM<V=S='(@(L?@[^CXZ"#JX/+N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@
M=6YS965N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`W,@IM<V=I9"`B4V%V92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@
M=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@
M87,@82!V:7)T=6%L(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S,`HC+"!F=7IZ>0IM<V=I9"`B4V%V92!S96YT(&UA
M:6P_(@IM<V=S='(@(L?@[^CQXN#I(.CG[_#@\N7MX/+@(._N^>`@XB(*"B,Z
M(&-O;7!O<V4N<&AP.C$R,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V:6YG
M('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("5S(@IM<V=S='(@(L?@[^CQX"#MX"#WY?#M[N+@\N`@\>4@[_#NXN#K
MZ"X@Q?+N(.K@ZN+N(.K@Y^`@\?KPXOKPX#H@)7,B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y.2!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C$Q"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C0Q
M"FUS9VED(")396%R8V@B"FUS9W-T<B`BTOKP\>@B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHQ,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S
M(@IM<V=S='(@(M+Z\/'H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`BS^[R
M\.7AZ/+EZ_'JZ"#N[_;HZ"(*"B,Z('-E87)C:"YP:'`Z,C8U"FUS9VED(")3
M96%R8V@@4F5S=6QT<R(*;7-G<W1R("+0Y>?SZ_+@\N@@[O(@\OKP\>7MY?+N
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM<V=S='(@
M(L_PY>/KY>3@[>@B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.CD*;7-G:60@(E-E;&5C="(*;7-G<W1R("+(Y^'E\.@B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-S`*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!!;F]T:&5R($%C8V]U;G0B"FUS9W-T<B`BR.?AY?#E\N4@[^[YX"(*
M"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("+(Y^'E\.7RY2#O[OG@(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R("+(Y^'E\.@@XO'H]^KH(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$W"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@82!S=&%T:6]N97)Y.B(*;7-G<W1R("+(Y^'E\.7R
MY2#O[OG@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B
M4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E
M87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R("+(Y^'E\.7RY2#@Y/#E
M\>W@(.KMZ./@(.?@(.3NX>#B_^WE(.@@\OKP\>7MY2#MX"#@Y/#E\>@N(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I9"`B4V5L96-T
M(&%L;"(*;7-G<W1R("+(Y^'E\.@@XO'H]^KH(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S(S"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@86QL(&9I96QD<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S
M<V5S+B(*;7-G<W1R("(B"B+(Y^'E\.7RY2#PY>3@(.W@(/+Z\/'E[>4@[>`@
MX.3PY?'MZ/+E(.KMZ./H+"#O\.@@[O+J\.CBX.WE\NX@[>`@X.3PY?'H+B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q
M"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R("+(Y^'E\.7RY2#O
M[OG@(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I9"`B
M4V5L96-T(&YO;F4B"FUS9W-T<B`BS>4@Z.?AZ/#@Z2#MZ/GN(@H*(SH@=&5M
M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.CD*;7-G:60@(E-E;&5C
M="!T:&4@9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHR
M,0IM<V=I9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P.0IM
M<V=I9"`B4V5L96-T960@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`BR.?A\.#M
MX"#@Y/#E\>W@(.KMZ./@.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R
M("+(Y^_PX/+H(.KK_O<@XB#O\^'KZ/?MZ/\@ZNO^]_'Z\.+Z\"(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#0*(RP@9G5Z>GD*;7-G:60@(E-E
M;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@
MT?KPXOKPX"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0HC+"!F=7IZ>0IM
M<V=I9"`B4V5N9"!-97-S86=E(@IM<V=S='(@(LKPX.D@[>`@[^CQ[.[R[B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,#,*;7-G:60@(E-E;F0@<F5A
M9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD97(_(@IM<V=S
M='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PHC+"!F=7IZ>0IM<V=I9"`B4V5N
M="!M86EL(&9O;&1E<B(*;7-G<W1R("+/X._JX"!<(LCG[_#@\N7MX"#O[OG@
M7"(Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS
M.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`BS^#OZN`@7"+(
MY^_PX/+E[>`@[^[YX%PB.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,3,R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS9W-T
M<B`BT?KPXOKP(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"B,L(&9U
M>GIY"FUS9VED(")397)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G
M<W1R("+([?3N\.S@]NC_(.?@(-'Z\.+Z\.`B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B
MT?KPXOKP.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,`IM<V=I9"`B
M4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V
M92!A;F0@9&5L971E(&UE<W-A9V5S+B(*;7-G<W1R("+-X/'R\.[I(.K@ZN+N
M(.3@(/'E(/'K\_?BX"P@ZN[CX/+N(._PY>SE\?+H^"#HZ^@@Z.?R\.CE^"#O
MZ/'L[BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3
M970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A
M9V5S/R(*;7-G<W1R("+$X"#QY2#GX.3@XN`@Z^@@6"U0<FEO<FET>2#GX./K
MX.+MX"#WX/'R(._PZ"#OZ/'@[>4@[>`@[^CQ[.X_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Q"B,L(&9U>GIY"FUS9VED(")3:&%R92!&;VQD97)S
M(@IM<V=S='(@(L_@[^KH(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C@V
M"B,L(&9U>GIY"FUS9VED(")3:&%R92!M86EL(&9O;&1E<G,B"FUS9W-T<B`B
MS^#OZN`@7"+(Y^_PX/+E[>`@[^[YX%PB.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET
M:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V.0IM<V=I9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q
M=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@
M8V%N(&)E("(*(G1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM<V=I
M9"`B4VAO=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@
M<V-A;FYE9"!F;W(@4$=0(&1A=&$_(@IM<V=S='(@(B(*(M+P_^'BX"#KZ"#D
MX"#QY2#O\.[BY?#_XN`@\?KD^O#FX.WHY?+N(.W@(.[AZ.KM[N+E[>@@\N7J
M\?+NXN@@[^CQ[.`@Y^`@4$=0("(*(N3@[>WH/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD
M;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R("+2
M\/_AXN`@Z^@@[_#NY^[PY?;@(%PBS>#OZ/CH7"(@Y.`@\>4@Y^#RXN[PZ"#Q
MZ^7D(.?@[^CQ(.W@(/?E\.WNXN#RX"XB"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-`IM<V=I9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@
M8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*;7-G
M<W1R("(B"B+$X"#A^N3E(.OH(._PZ.KPY>__[2#"X/CH__(@[_/AZ^CWY>T@
M4$=0(.KK_O<@ZOKL(._H\>S@\N`@PN@L(._N("(*(N_NY/#@Y^'H\.#MY3\B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"B,L(&9U>GIY"FUS
M9VED(")3:&]W($%L;"!&;VQD97)S(@IM<V=S='(@(L_NZN#FZ"#B\>CWZN@@
MY^#CZ^#B[>@@]^#Q\N@B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S
M+FEN8SHV-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R("+/[NK@
MYN@@XO'H]^KH(.?@X^O@XNWH(/?@\?+H(@H*(SH@;6%I;&)O>"YP:'`Z,S8U
M"FUS9VED(")3:&]W($1E;&5T960B"FUS9W-T<B`BS^[JX.;H(.CG\O#H\NCR
MY2(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED
M(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R("+/[NK@YN@@\>#L[B#H
MY^'PX.WH(.?@X^O@XNWH(/?@\?+H(2(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VAE861E<G,N:6YC.C<P"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O
M<FUA=&EO;B(*;7-G<W1R("+/[NK@YN@@Z.WT[O#LX/;H_R#GX"!-86EL:6YG
M($QI<W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"B,L(&9U
M>GIY"FUS9VED(")3:&]W($]N;'D@4W5B<V-R:6)E9"!&;VQD97)S(@IM<V=S
M='(@(L#A[NWH\.#MY2#GX"#OX._JX"CH*2(*"B,Z(&9O;&1E<G,N<&AP.C(Y
M.`IM<V=I9"`B4VAO=R!5;G-U8G-C<FEB960B"FUS9W-T<B`BS^[JX.;H(.WE
MX.'N[>CPX.WH\N4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`X"FUS
M9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG(&]F(&%T=&%C
M:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#`R"FUS9VED(")3:&]W(&QE9V5N9"!I;B!T:&4@
M;6%I;&)O>"!V:65W/R(*;7-G<W1R("+$X"#QY2#O[NK@Y^+@(.OH(.OEX^7M
MY.`@XB#O[OGE[?'JX/+@(.KS\NC_/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-#`*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S
M86=E<R!O;FQY/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#0X"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<W"FUS9VED(")3
M:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S
M='(@(L3@(/'E(._NZN#GXN`@Z^@@7"+$\//CZ"#O[OGH7"(@Z.KN[>`@XB#L
MY>W^(.OE[?+@\N`_(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDU
M"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`BS^[J
MX.;H(/'@[.X@Z.?A\.#MZ"#GX./KX.+MZ"#WX/'RZ"$B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]P<F5F<RYI;F,Z-30*(RP@9G5Z>GD*;7-G:60@(E-H;W<@
M=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R("+$X"#Q
MY2#O[NK@Y^+@(.OH(%PBQ/#SX^@@[^[YZ%PB(.CJ[NW@(.(@[.7M_B#KY>WR
MX/+@/R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR.`IM<V=I9"`B4VAO
M=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8V"B,L(&9U>GIY"FUS9VED
M(")3:&]W;B(*;7-G<W1R(")"<F]W;B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(E-I7WIE
M(@IM<V=S='(@(M#@Y^SE\"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N
M9"YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(E-I9VYE9"(*;7-G<W1R("+0X.?L
MY?`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM
M<V=I9"`B4VEZ92(*;7-G<W1R("+0X.?LY?`B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3;W)T(&)Y($%R
M<FEV86PB"FUS9W-T<B`BT>[P\NCPX.D@[^X@[^[K\_?@XN#MY2(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,38*;7-G:60@
M(E-O<G0@8GD@1&%T92(*;7-G<W1R("+1[O#RZ/#@Z2#O[B#DX/+@(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR-@IM<V=I
M9"`B4V]R="!B>2!&<F]M($%D9')E<W,B"FUS9W-T<B`BT>[P\NCPX.D@[^X@
M7"+.\EPB(.#D\.7Q(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHT,0IM<V=I9"`B4V]R="!B>2!-97-S86=E(%-I>F4B"FUS
M9W-T<B`BT>[P\NCPX.D@[^X@\.#G[.7P(.W@(._H\>SN\NXB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,V"FUS9VED(")3
M;W)T(&)Y(%-U8FIE8W0B"FUS9W-T<B`BT>[P\NCPX.D@[^X@\N7LX"(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S$*;7-G
M:60@(E-O<G0@8GD@5&AR96%D(@IM<V=S='(@(M'N\/+H\.#I(._N(.WH^.KH
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR
M,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S(@IM<V=S='(@
M(M'N\/+H\.#I(._N(%PBSO)<(B#@Y/#E\2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S<&%M<V5L96-T+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B4W!A;2!F;VQD
M97(Z(@IM<V=S='(@(L_@[^K@(%PBRN[X]^5<(CHB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R<R(*;7-G<W1R("+1[^7VZ.#K[>@@\>CLXN[KZ"(*"B,Z('-E87)C:"YP
M:'`Z,3,S"FUS9VED(")3<&5C:6%L(%9I<G1U86P@1F]L9&5R<R!C86X@;F]T
M(&)E(&5D:71E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,S0S"FUS9VED(")3<&5L;"!#:&5C:R(*;7-G<W1R("+/
M\.#B[N_H\2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT
M-@IM<V=I9"`B4W!E;&P@0VAE8VME<B(*;7-G<W1R("+/\.[BY?#JX"#MX"#O
M\.#B[N_H\>`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-#@@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS9VED(")3
M<&5L;"!C:&5C:R!C;VUP;&5T92(*;7-G<W1R("+/\.#B[N_H\>`@X>7XY2#O
M\.[BY?#E[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@
M(E-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI
M;F<N(@IM<V=S='(@(L_PX.+N[^CQ[>@@X_#E^.KH(.(@\?+PX.WH]N`@[_#H
M(._P[N+E\.K@(.?@(._PX.+N[^CQ+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU,3(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U,@HC+"!F
M=7IZ>0IM<V=I9"`B4W1A<G0B"FUS9W-T<B`BT?+@\O/Q(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.CD@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,S$Q"FUS9VED(")3=&%T:6]N97)Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR-@IM<V=I9"`B
M4W1A=&EO;F5R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z,C@*;7-G:60@(E-T871I;VYE<GD@='EP93HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C,S"FUS9VED(")3=&%T:6]N97)Y.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B
MT?+@\O/Q(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(Q-0HC+"!F=7IZ
M>0IM<V=I9"`B4W1R:7`@071T86-H;65N="(*;7-G<W1R("+/\.CJ\.7OY>T@
M].#IZR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G:60@(E-T
M<FEP(&QI;F5B<F5A:W,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-U
M8E]J96-T(@IM<V=S='(@(M+E[.`B"@HC.B!M97-S86=E+G!H<#HR-C@@=&AR
M96%D+G!H<#HQ-3`@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR
M-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R
M("+2Y>S@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B
M4W5B:F5C="!&:65L9"(*;7-G<W1R("+2Y>S@(.W@(._H\>SN\NXB"@HC.B!S
M96%R8V@N<&AP.C,Q."!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI
M;F,Z,3@*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@
M(E-U8FUI="(*;7-G<W1R("+2Y>S@(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,3$*;7-G:60@(E-U8G-C<FEB92!T;R!&;VQD97(H<RDB
M"FUS9W-T<B`BP.'N[>CPX.WE(.?@(._@[^K@*.@I(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HS.#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@W"FUS9VED(")3
M=6-C97-S(@IM<V=S='(@(M/Q[^7U(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G<W1R("+/
M\.7D[^[K[N;E[>C_(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V
M,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0P,"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#,*;7-G:60@
M(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@
M=&\@2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!P;&%I
M;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0Q.0HC+"!F=7IZ>0IM<V=I9"`B5&5?>'0B
M"FUS9W-T<B`BTN7J\?(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,C8Y"FUS9VED(")496YT871I=F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3DQ"FUS9VED(")496YT871I=F5L>2!!8V-E
M<'0@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S8Q"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R
M("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O9B!397)V:6-E(&9I
M;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G<W1R("+4X.GK(.?@
M(%PBT_'K[N+H_R#MX"#S\>OSX^#RX%PB(.WE(.4@Y^#DX.3E[2#B(&-O;F8N
M<&AP(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,P"FUS
M9VED(")497AT(@IM<V=S='(@(M+EZO'R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDU-`IM<V=I9"`B5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S
M<V%G92!S:&]U;&0@8F4@;&EN:V5D.B(*;7-G<W1R("(B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4S,@IM<V=I9"`B(@HB5&AE($E-05`@<V5R=F5R(&1O
M97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A=&EO;B!M
M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S
M;W5R8V4@9F]R:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P
M;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!-86-I
M;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RXB"FUS
M9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("+/[OG@\N`@7"(E<UPB(.'E^.4@[_#E[.#U[>#RX"XB"@HC
M.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("+/
M[OG@\N`@7"(E<UPB(.'E^.4@Y^#OZ/'@[>`N(@H*(SH@871T86-H;65N="YP
M:'`Z-#,*(RP@9G5Z>GD*;7-G:60@(E1H92!A='1A8VAM96YT('=A<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(LW_[.`@[>#LY?#E[>@@[_#HZO#E[^7MZ"#TX.GK
M[N+E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.0IM<V=I9"`B
M5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-O;7!O<V5?=VEN+FIS.C,W"FUS
M9VED("(B"B)4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!0
M97)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@
M<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%P<&QE9&]U8FQE+G!H<#HT,@IM<V=I9"`B5&AE(&-O;G1E;G1S(&]F('1H
M92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H
M<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8W5R<F5N="!F;VQD97(H
M<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@
M(M+EZO/YX/+@(._@[^K@*.@I(%PB)7-<(B#YY2#A^N3E(._PY>CLY>WSXN#M
MX"#MX"!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P-PIM
M<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S
M<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM<V=S
M='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92!<(B5S7"(@9F]L
M9&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3,Y"B,L(&9U>GIY"FUS9VED(")4:&4@979E;G0@=V%S(&%D9&5D('1O('EO
M=7(@8V%L96YD87(N(@IM<V=S='(@(L#D\.7QX"`G)7,G(.'E^.4@Y.[AX.+E
M[2#J^NP@PN#XZ/_R(%PB]^7PY>T@\>_H\?KJ7"(N(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*;7-G
M<W1R("+(Y.7M\NCW[>[Q\O+@(%PB)7-<(B#AY?CE(.CG\O#H\N`N(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,S,W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M;VQD97(@7"(E<UPB(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(L_@[^K@\N`@
M7"(E<UPB(.+E]^4@\?KYY?'RXO/BX"(*"B,Z(&QI8B]&;VQD97(N<&AP.C$V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@9F]L9&5R(%PB)7-<(B!C
M;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA
M>2!C875S92`B"B)P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+([.7R[B#MX"#OX._JX/+@(%PB
M)7-<(B#Q^N3Z\.;@(.WEZN[PY>KR[>@@\>CLXN[KZ"X@TN[BX"#L[N;E(.3@
M(.3NXN7DY2#D[B`B"B+O\.[AZ^7LZ"X@S.[K_R#J[NWQ\^ORZ/#@Z?+E(/'E
M(/'Z\2#1Z/'RY>SMZ/\@P.3LZ.WH\?+PX/+N\"XB"@HC.B!L:6(O1F]L9&5R
M+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O
M(&ET+B(*;7-G<W1R("+/X._JX/+@(%PB)7-<(B#AY?CE(/'ZY^3@Y.7MX"P@
M[>X@PNCE(.WE(/'RY2#@X>[MZ/#@[>@@Y^`@[>7_+B`B"@HC.B!L:6(O1F]L
M9&5R+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<
M(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB
M960@9G)O;2!I="XB"FUS9W-T<B`BS^#OZN#RX"!<(B5S7"(@X>7XY2#HY_+P
MZ/+@+"#M[B#"Z.4@XO'E(.[YY2#Q\N4@8>#A[NWH\.#MZ"#GX"#MY?\N(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F;VQD97(@7"(E<UPB('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9"(*;7-G<W1R("+/X._JX/+@(%PB)7-<(B#MY2#A
MY?CE(/'ZY^3@Y.7MX"X@Q?+N(.K@ZN+@(.4@[_#H]^CMX/+@(/'O[O#EY"#Q
M^O#B^O#@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C8U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T(&1E;&5T
M960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BS^#O
MZN#RX"`G)7,G(.WE(.'E^.4@Z.?R\.CRX"X@Q?+N(.K@ZN+N(.K@Y^`@\?KP
MXOKPX"(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T
M960N(@IM<V=S='(@(L_@[^K@\N`@7"(E<UPB(.'E^.4@\?KGY.#DY>W@(//Q
M[^7X[>XN("(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E
M;&5T960N(@IM<V=S='(@(L_@[^K@\N`@7"(E<UPB(.'E^.4@Z.?R\.CRX"#S
M\>_E^.WN+B`B"@HC.B!L:6(O1F]L9&5R+G!H<#HT-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!R
M96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`BS^#OZN#RX"!<(B5S7"(@X>7X
MY2#S\>_E^.WN(._PY>CLY>WSXN#MX"#MX"!<(B5S7"(N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W1N968N<&AP.CDR"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I
M;&5S('=E<F4@871T86-H960@=&\@=&AI<R!P87)T.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7W-A=F5I;6%G95]W:6XN:G,Z
M,3(*;7-G:60@(B(*(E1H92!I;6%G92!S879E('=I;F1O=R!C86X@;F]T(&)E
M(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R("(*
M(G1O(&)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W
M:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@:7,@<')E<V5N
M="!I;B!Y;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R
M=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP
M.C4Q"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL
M;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@
M<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T
M<B`BS^[YY>WQZN#RX"#J\_+H_R`E<R#E(.+E]^4@[O+B[O#E[>`N(@H*(SH@
M;&EB+T9E=&-H;6%I;"YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B`H)60@8GET97,I(&5X8V5E
M9',@9F5T8V@@<VEZ92!L:6UI="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,#,*(RP@9G5Z>GD*;7-G:60@(E1H
M92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@17AI
M=&EN9RXB"FUS9W-T<B`BS^CQ[.[R[B#AY?CE(._P[N+E\.7M[BXB"@HC.B!M
M97-S86=E+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E1H92!M97-S86=E(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(L_H\>SN\NX@X>7XY2#O\.[BY?#E
M[>XN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDS"FUS9VED(")4
M:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"XB"FUS9W-T<B`BS^CQ[.[R
M[B#AY?CE(._P[N+E\.7M[BXB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C,X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A
M9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@)7,N(@IM<V=S='(@(L_H
M\>SN\NX@X>7XY2#O\.[BY?#E[>XN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+V]P
M96Y?<VUI;65?=VEN+FIS.C$P('1E;7!L871E<R]P9W`O;W!E;E]P9W!?=VEN
M+FIS.C$P"FUS9VED("(B"B)4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@
M8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@
M=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N
M<&AP.C8P"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI
M<W0@:6X@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`BR.?H\>K@
M[>C_(._PZ.KPY>_E[2#TX.GK(.WE(.4@[O+J\.CR(.(@35,M5$Y%1BXB"@HC
M.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`IM<V=I9"`B5&AE(')E<75E
M<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H;65N
M="XB"FUS9W-T<B`BR.?H\>K@[>C_(/3@Z>L@[>4@\?KYY?'RXO/BX"#B(%II
M<"#O\.CJ\.7OY>WH_R#TX.GK+B(*"B,Z(&UE<W-A9V4N<&AP.C4T-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G
M92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC
M871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S
M<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE("(*(FYO=&EF:6-A
M=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HV.0IM<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@
M=&\@8W)E871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`T"FUS9VED
M(")4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#(*(RP@
M9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R
M97!L86-E9"XB"FUS9W-T<B`BS^#OZN#RX"!<(B5S7"(@X>7XY2#Q^N?DX.3E
M[>`@\_'OY?CM[BX@(@H*(SH@871T86-H;65N="YP:'`Z-3D*(RP@9G5Z>GD*
M;7-G:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`BR.?H\>K@[>C_(/3@Z>L@[>4@\?KYY?'RXO/BX"#B(%II<"#O\.CJ
M\.7OY>WH_R#TX.GK+B(*"B,Z('-T871I;VYE<GDN<&AP.C@T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S
M(&)E96X@861D960N(@IM<V=S='(@(L_N^>#RX"!<(B5S7"(@X>7XY2#GX._H
M\>#MX"XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(L_N^>#RX"!<(B5S7"(@X>7XY2#O\.7LX/7MX/+@
M+B(*"B,Z('-T871I;VYE<GDN<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@=7!D871E
M9"XB"FUS9W-T<B`BS^[YX/+@(%PB)7-<(B#AY?CE(._PY>S@]>W@\N`N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB
M"FUS9W-T<B`BP.3PY?'@("<E<R<@X>7XY2#D[N'@XN7M(.KZ["#"X/CH__(@
M7"+WY?#E[2#Q[^CQ^NI<(BXB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A
M9V4B"FUS9W-T<B`BS_#E[>#Q[O?H(/+NXN`@[^CQ[.XB"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`BS^CQ[.[R[B#AY?CE(._P[N+E\.7M[BXB"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HX,`IM<V=I9"`B5&AE('1E>'0@;V8@
M=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT
M(&UE<W-A9V4B"FUS9W-T<B`BS_#E[>#Q[O?H(/+NXN`@[^CQ[.XB"@HC.B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B
M92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-30*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z.#8*;7-G:60@(E1H
M97)E(&%R92!N;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+B(*;7-G<W1R("+-_^S@(.#K\N7P[>#RZ.+MZ"#DXN[I
MZN@L(.KNZ/+N(.3@(.'ZY.#R(._NZN#GX.WH(.(@Z^CMZ/_RX"XB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS"FUS9VED(")4
M:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*;7-G<W1R
M("+-_^S@(._H\>S@(.(@\N#GZ"#O[OGE[?'JX"#J\_+H_RXB"@HC.B!T:')E
M860N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("+-_^S@(.#K
M\N7P[>#RZ.+MZ"#DXN[IZN@L(.KNZ/+N(.3@(.'ZY.#R(._NZN#GX.WH(.(@
MZ^CMZ/_RX"XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C$R"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(LCLX/CE(._P
M[N'KY>P@[_#H(.?@Z^CWX.+@[>7R[B#MX"`E<RX@Q?+N(.K@ZN+@(.4@[_#H
M]^CMX/+@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I
M;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H
M(.?@Z^CWX.+@[>4@[>`@[^[YY>WQZN`@ZO/RZ/\N(,7R[B#JX.KB[B#JX.?@
M(/'Z\.+Z\.`Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8R,0IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BR.S@^.4@[_#N
MX>OE["#O\.@@Y^#KZ/?@XN#MY?+N(.W@(._N^>7M\>K@\N`@ZO/RZ/\N(,_P
MZ/?H[>#RX"#E(@H*(SH@;&EB+TUE<W-A9V4N<&AP.CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A
M9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B
M"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B+#\.7XZN`@[_#H(.KN[^CPX.WE
M\NX@[>`@[^CQ[.`@[O(@7"(E<UPB(.(@7"(E<UPB+B#%\NX@ZN#JXNX@ZN#G
MX"#Q^O#B^O#@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Y."!L:6(O365S<V%G
M92YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@7"(E
M<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(B(*(L/PY?CJX"#O\.@@Z.?R\.CBX.WE\NX@[>`@[^CQ[.#RX"#N\B#OX._J
MX"!<(B5S7"(N(-'O[O#EY"#Q^O#B^O#@(._PZ/?H[>#RX"`B"B+GX"#R[N+@
M(.4B"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!I
M;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V
M97(@<V%I9"(*;7-G<W1R("(B"B+#\.7XZN`@[_#H(.CG\O#HXN#MY2#MX"#O
MZ/'LX"#B(._@[^K@(%PB)7-<(BX@S_#H]^CMX/+@(/'O[O#EY"#Q^O#B^O#@
M(.4B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`BP_#E^.K@
M(._PZ"#HY_+PZ.+@[>4@[>`@[^CQ[.`N(,7R[B#JX.KB[B#JX.?@(/'Z\.+Z
M\.`Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.CDY"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`BP_#E^.K@(._PZ"#O\.7C
MZ^7DX"#MX"#O[NCQZN#M[O+N(._H\>SN+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P;&%I;BYP:'`Z-3(@;&EB+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS
M-PIM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0B"FUS9W-T<B`BP_#E^.K@(._PZ"#O[NK@Y^+@[>4@[>`@
M\N#GZ"#WX/'R(.[R(._H\>SN\NXB"@HC.B!L:6(O365S<V%G92YP:'`Z-30U
M(&QI8B]-97-S86=E+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F
M;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED
M(@IM<V=S='(@(B(*(L/PY?CJX"#O\.@@\_'RX.WNXO_BX.WE(.W@(/3KX./N
MXN4@XB#OX._JX"!<(B5S7"(N(,_PZ/?H[>#RX"#Q[^[PY>0@\?KPXOKPX"#E
M(@H*(SH@9F]L9&5R<RYP:'`Z,38U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@Z.SO[O#RZ/#@[>4@[>`@Y.#M[>CRY3H@)7,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$S-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z
M("5S+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\NCPX.WE(.W@(.3@[>WH
M\N4Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-C8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CL
M[^[P\NCPX.WE(.W@(.3@[>WH\N4Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.SO[O#RZ/#@
M[>4@[>`@Y.#M[>CRY3H@)7,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I
M;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#E
M[.7Q\N+@[>4@[>`@7"(E<UPB(.(@7"(E<UPB+B#%\NX@ZN#JXNX@ZN#GX"#Q
M^O#B^O#@+B(*"B,Z(&-O;7!O<V4N<&AP.C$R-#0*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@Y^#OZ/'@(.W@(/+NXN`@[^CQ[.X@ZN#R[B#W
MY?#M[N+@+B(*"B,Z(&-O;7!O<V4N<&AP.C$P,#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S86=E
M.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(.CG[_#@^>#MY?+N(.W@(._H\>SN
M\NXZ("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.SO
M[O#RZ/#@[>4@[>`@Y.#M[>CRY3H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!L86EN+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E
M>'0@:6X@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`BP_#E^.K@(._PZ"#O
M[NK@Y^+@[>4@[>`@\N#GZ"#WX/'R(.[R(._H\>SN\NXB"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(E1H:7,@2%1-
M3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM<V=S='(@
M(M+NXN`@[^CQ[.X@X>7XY2#J\.CO\NCPX.WN(/$@4$=0+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HY,`IM<V=I9"`B(@HB5&AI<R!(5$U,(&UE
M<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G
M97,@87!P96%R(&QI:V4@(@HB=&AI<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C$V-@IM<V=I9"`B5&AI<R!01U`@4'5B;&EC
M($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N(@IM<V=S='(@(M+N
MY^@@4$=0(._SX>OH]^7M(.KK_O<@X>7XY2#O\.CJ\.7OY>T@ZOKL(._H\>SN
M\NXN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P-"!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3$X"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-#,@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-PHC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,3<S(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HS,30*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I
M;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M
M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C
M;VYT:6YU93\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE
M9&]U8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@
M36%C:6YT;W-H(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z-#$P"B,L(&9U>GIY"FUS9VED("(B"B)4:&ES(&UE<W-A
M9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET
M86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS9W-T<B`BTN[BX"#OZ/'L
M[B#AY?CE(/;H]/#NXNX@[^[D[^CQX.WN(/?PY><@4R]-24U%+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$T"B,L(&9U>GIY"FUS9VED(")4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B
M965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R("+2[N+@(._H\>SN
M(.'E^.4@]NCT\.[B[B#O[N3OZ/'@[>X@]_#EYR!3+TU)344N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B"B)4:&ES(&UE
M<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M871I
M;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G92!I<R!U;FMN
M;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS
M,34*(RP@9G5Z>GD*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R
M<F]R.B`B"FUS9W-T<B`BTN[BX"#OZ/'L[B#MY2#E(.(@ZN[PY>KRY>T@4$=0
M(/3N\.S@\B`H\?KNX?#@Y^WN(%)&0R`R,#$U*2XB"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S4P
M"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B"B)2
M1D,@,C`Q-2DN(@IM<V=S='(@(M+NXN`@[^CQ[.X@[>4@Y2#B(.KN\.7J\N7M
M(%!'4"#T[O#LX/(@*/'Z[N'PX.?M[B!21D,@,C`Q-2DN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-S`*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@
M4R]-24U%(&9O<FUA="XB"FUS9W-T<B`BTN[BX"#OZ/'L[B#MY2#E(.(@ZN[P
MY>KRY>T@4R]-24U%(/3N\.S@\B`H\?KNX?#@Y^WN(%)&0R`R,#$U*2XB"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#4@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z-#$V"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG
M:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G<W1R("+2[N+@(._H\>SN(.'E
M^.4@]NCT\.[B[B#O[N3OZ/'@[>X@]_#EYR!01U`N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S<V%G92!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM<V=S='(@(M+N
MXN`@[^CQ[.X@X>7XY2#VZ/3P[N+N(._NY._H\>#M[B#W\.7G(%,O34E-12XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!M97-S
M86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R("+2
M[N+@(._H\>SN(.'E^.4@ZO#H[_+H\.#M[B#Q(%!'4"XB"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HR,#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,CDQ"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I
M=&@@4$=0+B(*;7-G<W1R("+2[N+@(._H\>SN(.'E^.4@ZO#H[_+H\.#M[B#Q
M(%!'4"XB"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G
M92!T;R(*;7-G<W1R("+2[N+@(._H\>SN(.(B"@HC.B!A8VPN<&AP.C0V"FUS
M9VED(")4:&ES('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ,#D*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@=&AR96%D
M+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM<V=S
M='(@(L_NZN#FZ"(*"B,Z('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDR,@IM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`BR.?CZ^7D
M(._N(/'LZ/'K[N+H(.WH^.KH(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB
M;W@N<&AP.C8P-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q
M.0HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R
M('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T
M97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V
M"FUS9VED(")4;R(*;7-G<W1R("+$[B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,3D*(RP@9G5Z>GD*;7-G:60@(E1O($%D9')E<W,B"FUS9W-T<B`B
MSO(@X.3PY?$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI
M;&4@(@HB8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@82!43%,@8V]N;F5C=&EO;BP@
M>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@;V8@4$A0(#4N,"XV(&]R
M("(*(FAI9VAE<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-3<W"B,L(&9U>GIY"FUS9VED(")4;W1A;"!!='1A8VAM
M96YT<R!3:7IE.B(*;7-G<W1R("+/\.CJ\.7OY>WH(/3@Z>ONXN4B"@HC.B!F
M;VQD97)S+G!H<#HS.#@*(RP@9G5Z>GD*;7-G:60@(E1R87-H(&9O;&1E<B(*
M;7-G<W1R("+/X._JX"!<(LKN^/?E7"(Z(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W1R87-H<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A<V@@9F]L9&5R.B(*;7-G
M<W1R("+/X._JX"!<(LKN^/?E7"(Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H
M<#HV-2!L:6(O475O=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M
M;6%N9"YP:'`Z-S(*(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1
M=6]T82]C;W5R:65R+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*
M;7-G:60@(E5N86)L92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R("+#\.7X
MZN`@[_#H(._P[N+E\.K@\N`@Y^`@ZN+N\N`B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R("+!Y><@[O+C[N+N\"(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@(E5N86YS
M=V5R960@;65S<V%G97,B"FUS9W-T<B`BS^CQ[.`@X>7G(.[RX^[B[O`B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-"!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B56YD96QE=&4B
M"FUS9W-T<B`BPOKG\?+@[>[BZ"(*"B,Z(&UA:6QB;W@N<&AP.C4X.2!M86EL
M8F]X+G!H<#HV,#(@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$R"FUS9VED(")5
M;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(LWEZ.?BY?'R[>@@S^[K
M\_?@\N7KZ"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E
M.B`E<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU-C4*;7-G:60@(E5N
M:VYO=VX@1&%T92(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N($E-05`@<F5S<&]N
M<V4@9G)O;2!T:&4@<V5R=F5R+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C,U"FUS9VED
M(")5;FMN;W=N($UE971I;F<B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z
M-C$X"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(%)E8VEP:65N="(*;7-G<W1R
M("+-Y>CGXN7Q\NWH(,_NZ_/WX/+EZ^@B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B
M56YL;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`BS_#E[.#UXN#MY2#MX"#JZ_[W
M[N+@(/3PX.?@(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5
M;FYA;65D(@IM<V=S='(@(L'EY^CLY>WMZ"(*"B,Z(&UE<W-A9V4N<&AP.C0Y
M.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*;7-G<W1R
M("+-Y>_PY>/KY>3@[>@B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RDB"FUS
M9W-T<B`BSO+OZ/CH(.[R(._@[^K@*.@I(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3@T"FUS9VED(")5<&1A=&4@071T86-H;65N="!)
M;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C(P"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C4X
M('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-38*;7-G:60@(E5P;&]A
M9"(*;7-G<W1R("+(Y^_PX/+H(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M
M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U;'0@5F%L=64B"FUS
M9W-T<B`BR.?O[NOGXN#I(._NY/#@Y^'H\.#YX/+@(/'E(/'R[NGM[O'R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B57-E($E-05`@
M9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(L3@(/'E(.CG[^[KY^+@
M\B#KZ"!)34%0(.#A[NW@[.7M\N@@Y^`@[^#OZN@_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<S-0HC+"!F=7IZ>0IM<V=I9"`B57-E(%9I<G1U86P@
M5')A<V@@1F]L9&5R/R(*;7-G<W1R("+(Y^_PX.?MZ"#J[OCWY?+N(@H*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$T,@HC+"!F=7IZ>0IM<V=I9"`B57-E
M<B(*;7-G<W1R("+([.4B"@HC.B!A8VPN<&AP.C@W"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@
M<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<W"FUS9VED
M(")5<V5R;F%M92(*;7-G<W1R("+([.4B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z,3<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+(
M[.4Z(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G
M:60@(E9I97<B"FUS9W-T<B`BPNCF(@H*(SH@;&EB+TU)344O5FEE=V5R+WII
M<"YP:'`Z.3(@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(LCGX^OEY"`E<R(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,@4'5B;&EC
M($ME>2(*;7-G<W1R("+"Z.8@)7,@[_/AZ^CWY>T@ZNO^]R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(L3@
M(/'E(.CG\N7CZ_\@Z^@@[^[YX/+@(.(@[O+DY>OE[2#O\.[G[O#E]C\B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR.`HC+"!F=7IZ>0IM
M<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R("+-[N+H(._H\>S@(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+97DB"FUS
M9W-T<B`BPNCF(._E\/'N[>#KY>T@]^#Q\N7M(.KK_O<B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(L+H
MYB#OY?#Q[NW@Z^7M(._SX>OH]^7M(.KK_O<B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(E9I
M97<@5&AR96%D(@IM<V=S='(@(M'LZ/'K[N+H(.WH^.KH(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$V-0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GD*;7-G
M:60@(E9I97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G
M<W1R("+$X"#QY2#HY_+EX^O_(.OH(._N^>#RX"#B(.[RY.7KY>T@[_#NY^[P
MY?8_(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L(&9U
M>GIY"FUS9VED(")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B
M"FUS9W-T<B`BQ.`@\>4@Z.?RY>/K_R#KZ"#O[OG@\N`@XB#N\N3EZ^7M(._P
M[N?N\.7V/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#`*;7-G
M:60@(E9I97<@979E;G0B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S@P
M(&UA:6QB;W@N<&AP.C4S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G<W1R("+/[NK@YN@@[^CQ[.`@XB`B
M"@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C(S
M"FUS9VED(")6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I
M;CHB"FUS9W-T<B`BR.?CZ^7D(.CKZ"#O[OGE[?'JX"#J\_+H_R#DX"#A^N3E
M(.W@(.7J\.#MX"#QZ^7D(.+U[N0Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$W,`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@
M(LCGX^OEY"`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#$*
M(RP@9G5Z>GD*;7-G:60@(E9I97<@=&AE($EM86=E<R(*;7-G<W1R("+/[NK@
MYN@@[^CQ[.`@XB`B"@HC.B!S96%R8V@N<&AP.C(V,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5FER='5A;"!&;VQD97(@7"(E<UPB(&-R96%T960@
M<W5C8V5S9G5L;'DN(@IM<V=S='(@(L_@[^K@\N`@7"(E<UPB(.'E^.4@Z.?R
M\.CRX"#S\>_E^.WN+B`B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C$Q,2!L:6(O24U!4"]4<F5E+G!H<#HQ,S@@;&EB+TE-05`O5')E92YP:'`Z
M,34Q"B,Z(&QI8B])34%0+U1R964N<&AP.C$U,R!L:6(O24U!4"]4<F5E+G!H
M<#HQ-3<@;&EB+TE-05`O5')E92YP:'`Z,34X"B,Z(&QI8B])34%0+U1R964N
M<&AP.C,V.2!L:6(O24U!4"]4<F5E+G!H<#HS.3,@;&EB+TE-05`O5')E92YP
M:'`Z-#,S"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L($9O;&1E<G,B"FUS9W-T
M<B`BT?KGY.#I(._@[^K@(@H*(SH@<V5A<F-H+G!H<#HR-#4*;7-G:60@(E9I
M<G1U86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]61F]L9&5R+G!H<#HQ-S4@;&EB+U9&;VQD97(N<&AP.C$X,`IM<V=I
M9"`B5FER='5A;"!)3D)/6"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT
M,38*;7-G:60@(E9I<G1U86P@24Y"3U@@1F]L9&5R(@IM<V=S='(@(B(*"B,Z
M(&UA:6QB;W@N<&AP.C0U,B!L:6(O5D9O;&1E<BYP:'`Z,3$T(&QI8B]61F]L
M9&5R+G!H<#HQ,3D*;7-G:60@(E9I<G1U86P@5')A<V@B"FUS9W-T<B`B(@H*
M(SH@9F]L9&5R<RYP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L(%1R
M87-H($9O;&1E<B(*;7-G<W1R("+(Y^_PX.?MZ"#J[OCWY?+N(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U86P@9F]L
M9&5R(&QA8F5L(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,S<T"FUS9VED(")787)N:6YG(@IM<V=S='(@(B(*"B,Z(&QO9VEN
M+G!H<#HQ,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R("+$[N'PY2#$[OCKZ"#B("5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Q.0IM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S
M<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S
M('-P86T@(@HB;W(@:6YN;V-E;G0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW,C<*;7-G:60@(B(*(E=H96X@9&5L971I;F<@;65S
M<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D
M(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE=&5D/R(*;7-G<W1R("(B"B+/
M\.@@Z.?R\.CBX.WE(.W@(._H\>S@+"#DX"#QY2#O\.7LY?'RXN#R(.OH(.(@
MZN[X]^7R[B#B[.7Q\NX@Y.`@\>4@[.#PZNCPX/(@(@HBZN#R[B#HY_+PZ/+H
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(E=H96X@
M;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT
M('1O('-T87)T(&]N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L
M9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG
M(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO
M=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R97-S97,@*&5M
M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7:&ET96QI<W0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@(EEE<R(*;7-G
M<W1R("+$X"(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L
M;V=I;BYP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@
M9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM
M<V=S='(@(LCG\N7CZ__MY2#MX"#O[OG@(.[R(.3P\^/H(%!/4#,O24U!4"#Q
M^O#B^O#H+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER
M;2YH=&UL.C$P"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L
M971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F
M;VQD97(B"B(H<RDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V9O;&1E<G-?8V]N9FER;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T96UP
M=&EN9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U
M('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B
M66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R
M"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ
M,#0*;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*;7-G:60@(EEO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ,S4*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O
M;&1E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I
M8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(L'_]?+E(.[R[^CQX.T@\_'OY?CM
M[B#N\B!<(B5S7"(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@=&AE
M(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X
M=#H@)6,@9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@
M9F]R('1H92!S:6=N871U<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@
M9&ED(&YO="!A9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE
M;G0L('-O('EO=2!W97)E(&YO="!A;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Y"FUS9VED(")9
M;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O
M('1H:7,@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O<G=A<F1E9"!T:&ES(&UE
M<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@
M;65S<V%G97,N(@IM<V=S='(@(B`M("1N;2#M[N+H(._H\>S@(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(B`M("1N;2#M[N+N(._H
M\>SN(@H*(SH@8V]M<&]S92YP:'`Z-#DT"FUS9VED(")9;W4@:&%V92!A;')E
M861Y('-U8FUI='1E9"!T:&ES('!A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U
M(&AA=F4@870@;&5A<W0@;VYE(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y
M;W4@9&ED;B=T('5P;&]A9"!Y970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!S96YD('1H:7,@;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE
M;G1S/R(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#<T"FUS9VED(")9
M;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`W.0IM<V=I9"`B66]U(&AA=F4@
M;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.B(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HQ-3,*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N(@IM<V=S='(@(M+P_^'B
MX"#DX"#H[.#RY2#O[NWE(.7DZ.T@[^[K\_?@\N7K+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C,P,@IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@
M=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I
M97<@=&AI<R!M97-S86=E(@IM<V=S='(@(B(*(M+P_^'BX"#DX"#B^N+EY.7R
MY2#JZ_[W[N+@\N`@]/#@Y^`@[>`@PN#XZ/\@4$=0(/?@\?+E[2#JZ_[W(.?@
M(.3@(.+HY.CRY2`B"B+R[N+@(._H\>SN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HR-#D*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W
M('1H:7,@(@HB;65S<V%G92(*;7-G<W1R("(B"B+2\/_AXN`@Y.`@XOKBY>3E
M\N4@ZNO^]^[BX/+@(/3PX.?@(.W@(,+@^.C_(%,O34E-12#WX/'RY>T@ZNO^
M]R#GX"#DX"#BZ.3H\N4@(@HB\N[BX"#OZ/'L[B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VIA=F%S8W)I<'0N:6YC.C8T('1E;7!L871E<R]M86EL8F]X+VIA
M=F%S8W)I<'0N:6YC.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM<V=S='(@(M+P_^'BX"#D
MX"#HY^'E\.7RY2#O[OG@+"#J[O_R[B#DX"#A^N3E(.CG\O#H\N`N(@H*(SH@
M9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9;W4@;75S="!S96QE8W0@
M86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+2\/_AXN`@Y.`@
MZ.?AY?#E\N4@[^[YX"P@ZN[_\NX@Y.`@X?KDY2#HY_+PZ/+@+B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z.#$*(RP@9G5Z>GD*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R
M("+2\/_AXN`@Y.`@Z.?AY?#E\N4@[^[YX"P@ZN[_\NX@Y.`@X?KDY2#HY_+P
MZ/+@+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8R
M('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(P.`HC.B!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR-C,*(RP@9G5Z>GD*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G92!F:7)S
M="XB"FUS9W-T<B`BTO#_X>+@(.3@(.CLX/+E(._N[>4@Y>3H[2#O[NOS]^#R
MY>LN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*
M;7-G<W1R("+2\/_AXN`@Y.`@Z.S@\N4@[^[MY2#EY.CM(._NZ_/WX/+EZRXB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHR.0HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@9FEL
M92!T;R!A='1A8V@N(@IM<V=S='(@(M+P_^'BX"#DX"#H[.#RY2#O[NWE(.7D
MZ.T@[^[K\_?@\N7K+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@
M=&\@:&%V92!<(B5S7"(@96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P
M=&EO;G,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?O^NOMY>WHY2#MX"!<(L[O
MY?#@]NCH(._N(.[A\>OSYN+@[>7R[EPB(@H*(SH@;&EB+TUA:6QL;V<N<&AP
M.C$S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E9&ER96-T
M960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T<B`BS_#E[>#Q
M[O?H(/+NXN`@[^CQ[.XB"@HC.B!L:6(O36%I;&QO9RYP:'`Z,30Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5P;&EE9"!T;R!T:&ES(&UE
M<W-A9V4@;VX@)7,N(@IM<V=S='(@(L_PY>W@\>[WZ"#R[N+@(._H\>SN(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z-3`W"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R92!I<R!W:&%T
M('1H92!S97)V97(@<V%I9"(*;7-G<W1R("+-Y2#A__7RY2#@X>[MZ/#@[2#G
MX"!<(B5S7"(N(,7R[B#JX.KBX"#E(._PZ/?H[>#RX"(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@
M=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(LWE(.'_]?+E(.[R[^CQX.T@[O(@7"(E<UPB
M+B#%\NX@ZN#JXN`@Y2#O\.CWZ.W@\N`@\>_N\.7D(/'Z\.+Z\.`B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HU,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E
M<F4@<W5C8V5S<V9U;&QY('-U8G-C<FEB960@=&\@7"(E<UPB(@IM<V=S='(@
M(L'_]?+E(.#A[NWH\.#M(//Q[^7X[>X@Y^`@7"(E<UPB(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-38R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U
M8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B
MP?_U\N4@[O+OZ/'@[2#S\>_E^.WN(.[R(%PB)7-<(B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHY.`IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(L+@
M^.7R[B#H[.4B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G:60@
M(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`BPN#XZ/+E
M(%!'4"#O\^'KZ/?E[2_WX/'RY>T@ZNO^]^[BY2(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-S$@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<V"FUS
M9VED(")9;W5R(%!R:79A=&4@2V5Y(@IM<V=S='(@(L+@^.C_\B#WX/'RY>T@
MZNO^]R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C<@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<Q"FUS9VED(")9;W5R(%!U8FQI8R!+97DB"FUS
M9W-T<B`BPN#XZ/_R(._SX>OH]^7M(.KK_O<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,38U"B,L(&9U>GIY"FUS9VED(")9;W5R(%)E<&QY+71O.B!A
M9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S='(@(L+@^.C_\B#.
M\N/NXN[PX"WMX#H@X.3PY?$Z(#QI/BAO<'1I;VYA;"D\+VD^(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHT.0HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@
M(L+@^.CRY2!3+TU)344@[_/AZ^CWY>TO]^#Q\N7M(.KK_O?NXN4B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHQ-@IM<V=I
M9"`B66]U<B!A8V-O=6YT<SHB"FUS9W-T<B`BPN#XZ/+E(._N^>@Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PIM<V=I9"`B(@HB66]U<B!A;&EA
M<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S
M<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES
M(&EM86=E('1Y<&4N(@IM<V=S='(@(L+@^.C_\B!B<F]W<V5R(.WE(._NY/KP
MYN`@\.7D[N+N(._NZN#GXN#MY2#MX"#R[N?H(/+H[R#TX.GK(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D969A=6QT(&-H
M87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R
M(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G
M97,Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C@Y"B,L(&9U>GIY"FUS9VED(")9;W5R(&UE<W-A9V4@=V%S('-U8V-E<W-F
M=6QL>2!D96QI=F5R960N(@IM<V=S='(@(L_@[^K@\N`@7"(E<UPB(.'E^.4@
MZ.?R\.CRX"#S\>_E^.WN+B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS9W-T<B`BPN#XZ/_R(._N
MY._H\3HB"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S92YP:'`Z,3(X-"!M
M86EL8F]X+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q.`IM<V=I9"`B6TYO
M(%-U8FIE8W1=(@IM<V=S='(@(EO-_^S@(-+E[.!=(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,L(&9U>GIY"FUS9VED(")?0F-C
M(@IM<V=S='(@(D)C8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ
M-@HC+"!F=7IZ>0IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R("+7Y?#E[2#Q
M[^CQ^NHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-30*
M(RP@9G5Z>GD*;7-G:60@(E]#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`BR.?R
M\.CI(@H*(SH@;&EB+TE-4"YP:'`Z.3<Y"B,L(&9U>GIY"FUS9VED(")?1F]L
M9&5R<R(*;7-G<W1R("+/X._JZ"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C@Q"B,L(&9U>GIY"FUS9VED(")?261E;G1I='DB"FUS9W-T
M<B`BR.3E[?+H]^WN\?(B"@HC.B!L:6(O24U0+G!H<#HY-C$*;7-G:60@(E])
M;F)O>"(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#(P"B,L(&9U>GIY
M"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("+(Y_7NY"(*"B,Z(&UE<W-A9V4N
M<&AP.C,X-`HC+"!F=7IZ>0IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S
M='(@(O'N\/$@ZN[D(.W@(._H\>SN\NXB"@HC.B!L:6(O24U0+G!H<#HY-S8*
M(RP@9G5Z>GD*;7-G:60@(E].97<@365S<V%G92(*;7-G<W1R("+-[N+H(._H
M\>S@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C,S"B,L(&9U>GIY"FUS9VED(")?4')I;G0B"FUS9W-T<B`BSO+OY??@\N#I
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(X.0HC+"!F=7IZ>0IM<V=I9"`B
M7U!R:6]R:71Y(@IM<V=S='(@(L_PZ.[PZ/+E\B(*"B,Z(&UA:6QB;W@N<&AP
M.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7U)E9G)E<V@@)7,B
M"FUS9W-T<B`BSN_PY?'MZ"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED(")?4F5P;'DB"FUS9W-T
M<B`BSO+C[N+N\"(*"B,Z(&QI8B])35`N<&AP.CDX,0HC+"!F=7IZ>0IM<V=I
M9"`B7U-E87)C:"(*;7-G<W1R("+2^O#QZ"(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0S,0HC+"!F=7IZ>0IM<V=I9"`B7U-E;F0@365S<V%G92(*;7-G<W1R
M("+*\.#I(.W@(._H\>SN\NXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")?5&AR96%D(@IM
M<V=S='(@(M'LZ/'K[N+H(.WH^.KH(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,3$V"B,L(&9U>GIY"FUS9VED(")?5&\B"FUS9W-T<B`B
MQ.XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PHC+"!F
M=7IZ>0IM<V=I9"`B7U5N9&5L971E(@IM<V=S='(@(L+ZY_'RX.WNXN@B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3@*(RP@
M9G5Z>GD*;7-G:60@(E]6:65W(%1H<F5A9"(*;7-G<W1R("+1[.CQZ^[BZ"#M
MZ/CJZ"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B
M7U=H:71E;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<V
M"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#0P"B,L(&9U>GIY"FUS9VED(")A='1A8VAM96YT(@IM
M<V=S='(@(L_PZ.KPY>_E[2#TX.GK(@H*(SH@=FEE=RYP:'`Z.3D*(RP@9G5Z
M>GD*;7-G:60@(F%T=&%C:&UE;G1S+GII<"(*;7-G<W1R("+/\.CJ\.7OY>WH
M(/3@Z>ONXN4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,3,*;7-G:60@(F)Y=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,#`*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W,@IM<V=I9"`B8V%N;F]T(&]P
M96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V-`IM
M<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR,C`*;7-G:60@(F-O;F9I9W5R871I;VX@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y-@IM<V=I9"`B
M8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,38X"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(T"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS9W-T<B`B[O(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3@P"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`T"FUS9VED(")I
M;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$X.`IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C(Y('!G<"YP:'`Z-CD*;7-G:60@(FME>2(*
M;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@
M(FUA:6QB;W@@9FEL92(*;7-G<W1R("+/[OGE[?'JX"#J\_+H_R(*"B,Z(&-O
M;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP.C0V-@HC+"!F=7IZ>0IM
M<V=I9"`B;F%M92(*;7-G<W1R("+([.4B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`B[?_LX"(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@
M(F]R(@IM<V=S='(@(NCKZ"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,38*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR,3(*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@T"FUS9VED(")S97)V
M:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS
M9W-T<B`B[_#@XN[OZ/'MX"#C\.7XZN`B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R<R(*;7-G
M<W1R("+O\.#B[N_H\>WH(./PY?CJZ"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M.3(*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("+O\.#B
M[N_H\>W@(./PY?CJX"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#@*;7-G:60@
M(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N
M<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")Y;W5R(&)L86-K;&ES="(*;7-G<W1R
M("+7Y?#E[2#Q[^CQ^NHB"@HC.B!L:6(O1FEL=&5R+G!H<#HV,0IM<V=I9"`B
M>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B(@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O<&\O9G)?1E(N<&\`````````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P-#,U,S(W`#$P-#$W,S8R-S8T`#`Q-S(P,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C('1R86YS;&%T
M:6]N(&]F(&9R7T92+G!O('1O($9R96YC:`HC('1R86YS;&%T:6]N(&]F(&9R
M7T92+G!O('1O(&9R86[G86ES"B,@24U0(#0N,2!&<F5N8V@@=')A;G-L871I
M;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$L(#(P,#(@5&AE($AO<F1E(%!R;VIE
M8W0*(R!0:65R<F4@3&%C:&%N8V4@/'!L0'!I97)R96QA8VAA;F-E+FYE=#X@
M970@0F5N;VET(%-T+4%N9'+I("AB96Y`8F5N;VET<W0M86YD<F4N;F5T*2P@
M,C`P,RP@,C`P-"X*(R!#:')I<W1O<&AE(%)U96QL92`\>'1O9D!X=&]F+F-O
M;3XL(#(P,#$N"B,@1G)E9&5R:6,@5')U9&5A=2`\9G1R=61E875`8V%M+F]R
M9SXL(#(P,#$N"B,@5&AI97)R>2!4:&]M87,@/'1H:65R<GE`<&]M<&\N;F5T
M/BP@,C`P,BP@,C`P,RP@,C`P-2P@,C`P-BX*(R!"96YO:70@4W0M06YD<ND@
M/&)E;D!B96YO:71S="UA;F1R92YN970^+"`R,#`T+@IM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@9G)?1E)<;B(*(E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E
M871I;VXM1&%T93H@,C`P-BTP,2TP-R`Q-3HU-RLP,3`P7&XB"B)03RU2979I
M<VEO;BU$871E.B`R,#`V+3`S+3`Q(#`Y.C4X*S`Q,#!<;B(*(DQA<W0M5')A
M;G-L871O<CH@5&AI97)R>2!4:&]M87,@/'1H:65R<GE`<&]M<&\N;F5T/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@1G)E;F-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L
M<STR.R!P;'5R86P]*&X@/B`Q*3M<;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT
M,CD*;7-G:60@(B`@("`@($-C.B`B"FUS9W-T<B`B("`@("!#8Z`Z("(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT,C8*;7-G:60@(B`@("`@(%1O.B`B"FUS9W-T
M<B`B("`@("`@P*`Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,30*;7-G:60@
M(B`@("!$871E.B`B"FUS9W-T<B`B("`@($1A=&6@.B`B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z-#$W"FUS9VED("(@("`@1G)O;3H@(@IM<V=S='(@(B`@("`@
M1&6@.B`B"@HC.B!M86EL8F]X+G!H<#HT,#4@=&5M<&QA=&5S+V9O;&1E<G,O
M:&5A9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E
M<RDB"FUS9W-T<B`B*%1O=6-H92!D)V%C8^AS(')A<&ED92`E<RDB"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z-#(S"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@
M(B!/8FIE=*`Z("(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHW,`IM<V=I9"`B(&EN("(*;7-G<W1R("(@9&%N<R`B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM
M<V=S='(@(DXF;W)D;3LB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E
M*2(*;7-G<W1R("(E+C)FH$UO("\@)2XR9J!-;R`@*"4N,F8E)2DB"@HC.B!T
M:')E860N<&AP.C$U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!-97-S86=E
M<R(*;7-G<W1R("(E9"!M97-S86=E<R(*"B,Z(&UA:6QB;W@N<&AP.C$W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B)60@;65S<V%G97,@;VYT(.ETZ2!S=7!P<FEMZ2AS
M*2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A
M;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B(E
M9"!M97-S86=E<R!N)V%Y86YT('!A<R#I=.D@8V]N<VEDZ7+I<R!C;VUM92!D
M97,@<&]U<G)I96QS(&]N="#I=.D@<F%P<&]R=.ES("(*(N`@=F]T<F4@861M
M:6YI<W1R871E=7(@<WES=.AM92XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O
M<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B)60@;65S<V%G97,@;VYT(.ET
MZ2!I9&5N=&EF:>ES(&-O;6UE(&XGZ71A;G0@<&%S(&1E<R!P;W5R<FEE;',N
M(@H*(SH@;&EB+U-P86TN<&AP.C$X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B(E9"!M97-S86=E
M<R!C;VYS:63I<NES(&-O;6UE(&1E<R!P;W5R<FEE;',@;VYT(.ETZ2!R87!P
M;W)TZ7,@X"!V;W1R92`B"B)A9&UI;FES=')A=&5U<B!S>7-TZ&UE+B(*"B,Z
M(&QI8B]3<&%M+G!H<#HQ-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S
M<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(B5D
M(&UE<W-A9V5S(&]N="#I=.D@:61E;G1I9FGI<R!C;VUM92!P;W5R<FEE;',N
M(@H*(SH@;6%I;&)O>"YP:'`Z,S4U"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M('1O("5D(&]F("5D($UE<W-A9V5S(@IM<V=S='(@(DUE<W-A9V5S("5D(.`@
M)60@<W5R("5D(@H*(SH@;6%I;&)O>"YP:'`Z-C(X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($M"(@IM<V=S='(@(B5SH$MO(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O
M;&1E<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@(B5S(&5X:7-T92!DZ6K@
M+B!6;W1R92!D;W-S:65R("5S(&XG82!P87,@Z73I(')E;F]M;>DN(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8U-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!M86EL8F]X+B(*;7-G<W1R
M("(E<R!N92!S96UB;&4@<&%S(.IT<F4@=6YE(&)O[G1E('9A;&ED92XB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL
M>2YP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E:6YG
M(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"XB"FUS9W-T<B`B
M3&4@9&]S<VEE<B`E<R!A(.ETZ2!R96YO;6WI(&%U(&3I8G5T(&1U(&UO:7,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B5S(&$@86-C
M97!TZ2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@7"(E<UPB+B(*;7-G
M<W1R("(E<R!A(&%N;G5LZ2"KH"5SH+LN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@9&5C
M;&EN960N(@IM<V=S='(@(B5S(&$@<F5F=7/I+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B)7,@
M82!RZ7!O;F1U(.`@=6YE(')E<77J=&4@<W5R('-E<R!D:7-P;VYI8FEL:73I
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N
M('1O(%PB)7-<(BXB"FUS9W-T<B`B)7,@82!RZ7!O;F1U(.`@;"=I;G9I=&%T
M:6]N(&1E(*N@)7.@NRXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#@S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S('9O=7,@82!E;G9O>>D@
M<V5S(&1I<W!O;FEB:6QI=.ES+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('1E;G1A=&EV
M96QY(&%C8V5P=&5D+B(*;7-G<W1R("(E<R!A(.ETZ2!A8V-E<'3I('-O=7,@
M<NES97)V97,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S
M>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@9&5M86YD92!V;W,@9&ES<&]N
M:6)I;&ETZ7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E
M(&%T(%PB)7-<(BXB"FUS9W-T<B`B)7,@<NEC;&%M92!V;W1R92!P<NES96YC
M92#@(*N@)7.@NRXB"@HC.B!L:6(O365S<V%G92YP:'`Z-#(T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@7"(E
M<UPB+B(*;7-G<W1R("*KH"5SH+L@82!B:65N(.ETZ2!A:F]U=.D@X""KH"5S
MH+LN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@86UM96YD(%PB)7-<(BXB"FUS
M9W-T<B`B)7,@<V]U:&%I=&4@8V]M<&SI=&5R(*N@)7.@NRXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B!<(B5S7"(N(@IM<V=S
M='(@(B5S('-O=6AA:71E('9O=7,@:6YF;W)M97(@9&4@JZ`E<Z"[+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA
M=&EO;B!A8F]U="!<(B5S7"(N(@IM<V=S='(@(B5S('-O=6AA:71E(')E8V5V
M;VER(&QE<R!D97)N:>AR97,@:6YF;W)M871I;VYS('-U<B"KH"5SH+LN(@H*
M(SH@;65S<V%G92YP:'`Z,C@U(&UE<W-A9V4N<&AP.C(Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7.@.B`E<R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC.C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*2(*;7-G<W1R("(E
M<Z`Z("5S("@E9"9N8G-P.V1E)FYB<W`[)60I(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B*$%P<&QY('1H97-E(&-H
M86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*;7-G<W1R("(H07!P
M;&EQ=65R(&-E<R!C:&%N9V5M96YT<R!E="!P;W5R<W5I=G)E(.`@;"?I8W)A
M;B!S=6EV86YT+BDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3(P"FUS9VED("(H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N
M('1O('1H92!C;VUP;W-E('-C<F5E;BXI(@IM<V=S='(@(BA!;FYU;&5R(&QE
M<R!C:&%N9V5M96YT<R!E="!R979E;FER(.`@;"?I8W)A;B!D92!RZ61A8W1I
M;VXI(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS
M9VED("(H2%1-3"DB"FUS9W-T<B`B*$A434PB"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!497AT*2(*;7-G
M<W1R("(H5&5X=&4@8G)U="DB"@HC.B!S<&5L;&EN9RYP:'`Z,C<Y"FUS9VED
M("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L
M>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O
M;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM
M<V=S='(@(B(*(BA2979E;FER(.`@;"?I8W)A;B!D92!RZ61A8W1I;VX@87!R
MZ',@879O:7(@87!P;&EQ=>D@=&]U=&5S(&QE<R`B"B)M;V1I9FEC871I;VYS
M+B!,97,@8VAA;F=E;65N=',@96X@8V]U<G,@;F4@<V5R;VYT(%!!4R!A<'!L
M:7%UZ7,N*2(*"B,Z('-P96QL:6YG+G!H<#HR-S8*;7-G:60@(B(*(BA396YD
M(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S
M(&9A<BX@($-H86YG97,@;VX@=&AE("(*(F-U<G)E;G0@<V-R965N('=I;&P@
M3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H4F5V96YI<B#@(&PGZ6-R
M86X@9&4@<NED86-T:6]N(&%P<NAS(&%V;VER(&%P<&QI<77I('1O=71E<R!L
M97,@(@HB;6]D:69I8V%T:6]N<RX@3&5S(&-H86YG96UE;G1S(&5N(&-O=7)S
M(&YE('-E<F]N="!005,@87!P;&EQ=>ES+BDB"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J($QE<R!A:F]U=&5R(&5N(&-L:7%U
M86YT('-U<B!/2R`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J
M(@IM<V=S='(@(BH@5F5U:6QL97H@<^EL96-T:6]N;F5R('5N92AD97,I(&%D
M<F5S<V4H<RD@*B(*"B,Z(&UA:6QB;W@N<&AP.C$W,@IM<V=I9"`B,2!M97-S
M86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(C$@;65S<V%G92!A(.ET
MZ2!S=7!P<FEMZ2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3DW"FUS9VED("(Q(&UE
M<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB56X@;65S<V%G92!A
M(.ETZ2!R87!P;W)TZ2#@('9O=')E(&%D;6EN:7-T<F%T975R('-Y<W3H;64@
M8V]M;64@;B?I=&%N="!P87,@(@HB=6X@<&]U<G)I96PN(@H*(SH@;&EB+U-P
M86TN<&AP.C$W-PIM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D
M(&%S(&YO="!S<&%M+B(*;7-G<W1R("(Q(&UE<W-A9V4@82#I=.D@:61E;G1I
M9FGI(&-O;6UE(&XGZ71A;G0@<&%S('5N('!O=7)R:65L+B(*"B,Z(&QI8B]3
M<&%M+G!H<#HQ.#D*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(E5N(&UE<W-A9V4@82#I=.D@<F%P<&]R=.D@X"!V;W1R92!A9&UI
M;FES=')A=&5U<B!S>7-TZ&UE(&-O;6UE(.ET86YT('5N("(*(G!O=7)R:65L
M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-CD*;7-G:60@(C$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("(Q(&UE<W-A9V4@82#I
M=.D@:61E;G1I9FGI(&-O;6UE('!O=7)R:65L+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,#<*;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@
M(C$P,"!C87)A8W3H<F5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q
M,`IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S='(@(C$P,#`@8V%R86-T
MZ')E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#@*;7-G:60@(C(U
M,"!C:&%R86-T97)S(@IM<V=S='(@(C(U,"!C87)A8W3H<F5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@P.0IM<V=I9"`B-3`P(&-H87)A8W1E<G,B
M"FUS9W-T<B`B-3`P(&-A<F%C=.AR97,B"@HC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B02!L87)G92!I
M;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N(@IM
M<V=S='(@(E5N92!I;6%G92!D92!G<F%N9&4@=&%I;&QE(&YO;6WI92`E<R!E
M<W0@:F]I;G1E(.`@8V4@;65S<V%G92XB"@HC.B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M97-S86=E('EO=2!H
M879E('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO
M;B!F<F]M('1H92`B"B)R96-I<&EE;G0N(@IM<V=S='(@(B(*(E5N(&UE<W-A
M9V4@<75E('9O=7,@879E>B!E;G9O>>D@82!P<F]V;W%UZ2!U;F4@;F]T:69I
M8V%T:6]N(&5N(')E=&]U<B!D=2`B"B)D97-T:6YA=&%I<F4N(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4*;7-G:60@(D%.1"(*;7-G<W1R
M(")%5"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#(*;7-G:60@
M(D%C8V5P="!A;F0@861D('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(D%C8V5P
M=&5R(&5T(&%J;W5T97(@X"!M;VX@86=E;F1A+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S
M='(@(D%C8V5P=&5R(&QA(')E<77J=&4B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S0V"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R(")!8V-E<'3I
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U.`IM<V=I9"`B06-C
M97!T960Z("(*;7-G<W1R(")!8V-E<'3IH#H@(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C8V]U;G0G<R!N86UE.B(*
M;7-G<W1R(").;VT@9'4@8V]M<'1EH#HB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3(R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,C4*;7-G
M:60@(D%C=&EO;G,B"FUS9W-T<B`B06-T:6]N<R(*"B,Z(&QI8B]-24U%+TAE
M861E<G,N<&AP.C$Y,B!L:6(O34E-12](96%D97)S+G!H<#HQ.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D("5S('1O(&UY($%D9')E<W,@0F]O:R(*;7-G
M<W1R(")!:F]U=&5R("5S(.`@;6]N(&-A<FYE="!D)V%D<F5S<V5S(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`S"FUS9VED(")!
M9&0@<V]U<F-E(@IM<V=S='(@(D%J;W5T97(@=6YE('-O=7)C92(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S,*;7-G:60@(D%D9"!T:&ES('1O
M(&UY(&-A;&5N9&%R(@IM<V=S='(@(L`@86IO=71E<B#@(&UO;B!A9V5N9&$B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@S"FUS9VED(")!9&0@
M=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B06IO=71E<B#@(&UO;B!A9V5N9&$B
M"@HC.B!C;VUP;W-E+G!H<#HU.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M960@7"(E<UPB(&%S(&%N(&%T=&%C:&UE;G0N(@IM<V=S='(@(JN@)7.@NR!A
M:F]U=.D@96X@<&GH8V4@:F]I;G1E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.3@*;7-G:60@(B(*(D%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P
M;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H
M96%D97(@(@HB;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"B)%;BUT
MZG1E<R!A9&1I=&EO;FYE;',@X"!A9F9I8VAE<CH@/&5M/BAO<'1I;VYN96PL
M(&5N=')E>B!C:&%Q=64@96XM=.IT92!S=7(@("(*(G5N92!N;W5V96QL92!L
M:6=N92D\+V5M/BXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R
M;6%T:6]N(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(E5N92!I;F9O<FUA
M=&EO;B!C;VUP;.EM96YT86ER92!P975T(.IT<F4@8V]N<W5L=.EE("5S+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"FUS9VED
M(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS9W-T<B`B1.ET
M86EL<R!I;F9O<FUA=&EF<R!C;VUP;.EM96YT86ER97,B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I;VYA;"!M97-S
M86=E(&1E=&%I;',B"FUS9W-T<B`B1.ET86EL<R!C;VUP;.EM96YT86ER97,@
M<W5R(&QE(&UE<W-A9V4B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@
M9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")$97,@9.ET86EL
M<R!C;VUP;.EM96YT86ER97,@<&5U=F5N="#J=')E(&-O;G-U;'3I<R`E<RXB
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D
M:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T<B`B1.ET86EL
M<R!C;VUP;.EM96YT86ER97,@9'4@;65S<V%G92!D)V5R<F5U<B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(B(*(D1E<R!DZ71A:6QS(&-O;7!LZ6UE;G1A
M:7)E<R!A=2!M97-S86=E(&0G97)R975R('!E=79E;G0@ZG1R92!C;VYS=6QT
MZ7,@)7,N(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3(*
M;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")#87)N970@9"=A9')E<W-E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*;7-G:60@(D%D9')E
M<W,@0F]O:W,B"FUS9W-T<B`B0V%R;F5T<R!D)V%D<F5S<V5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I9"`B(@HB061D<F5S<V5S('1O
M($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@
M861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM<V=S='(@(B(*(D%D
M<F5S<V5R(&5N($-C:2!T;W5S(&QE<R!M97-S86=E<Z`Z(#QE;3XH;W!T:6]N
M;F5L+"!E;G1R97H@8VAA<75E(&%D<F5S<V4@(@HB<W5R("!U;F4@;F]U=F5L
M;&4@;&EG;F4I/"]E;3XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B(@HB061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H
M:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D
M<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(D%D<F5S<V5S
M(.`@871T86-H97(@97AP;&EC:71E;65N="#@(&-E='1E(&ED96YT:73IH#H@
M/&5M/BAO<'1I;VYN96PZ(&5N=')E<B`B"B)C:&%Q=64@861R97-S92!S=7(@
M=6YE(&YO=79E;&QE(&QI9VYE*3PO96T^(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS
M9VED(")!;&PB"FUS9W-T<B`B5&]U="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3,*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T
M:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT
M;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G<W1R("(B"B)4;W5S(&QE<R!M97-S
M86=E<R!D92!C92AS*2!D;W-S:65R*',I('-E<F]N="!TZ6SI8VAA<F?I<R!D
M86YS('5N(&9I8VAI97(@(@HB34)/6*`Z(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R(%PB)7-<(B!F;VQD97(@;VQD97(@
M=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"XB
M"FUS9W-T<B`B(@HB5&]U<R!L97,@;65S<V%G97,@9&4@=F]T<F4@9&]S<VEE
M<B"KH"5SH+L@<75I(&]N="!P;'5S(&1E(*N@)7.@NR!J;W5R<R`B"B)S97)O
M;G0@969F86/I<RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?
M871T86-H;65N='-?;6]N=&AL>2YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B06QL(&]L9"!L:6YK960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO
M;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("(B"B)4;W5S('9O
M<R!D;W-S:65R<R!D)V%N8VEE;G,@;65S<V%G97,@96YV;WGI<R!D97!U:7,@
M<&QU<R!D92`E<R!M;VES('-E<F]N="`B"B)E9F9A8^ES+B(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E;G0M;6%I;"!F;VQD
M97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB
M"FUS9W-T<B`B(@HB5&]U<R!V;W,@9&]S<VEE<G,@9"=A;F-I96YS(&UE<W-A
M9V5S(&5N=F]YZ7,@9&5P=6ES('!L=7,@9&4@)7,@;6]I<R!S97)O;G0@(@HB
M969F86/I<RXB"@HC.B!A8VPN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L;'D@<F5M
M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(B(*(E1O=7,@;&5S(&1R
M;VET<R!S=7(@;&4@9&]S<VEE<B"KH"5SH+L@;VYT(&)I96X@Z73I(')E=&ER
MZ7,@<&]U<B`B"B)L)W5T:6QI<V%T975R(*N@)7.@NRXB"@HC.B!L:6(O87!I
M+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L9&5R($-R96%T:6]N/R(*;7-G<W1R
M(")!=71O<FES97(@;&$@8W+I871I;VX@9&4@9&]S<VEE<G.@/R(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL
M=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S
M='(@(B(*(D%U=&]R:7-E<B!L97,@<NAG;&5S(&1E(&9I;'1R86=E(.`@<R=A
M<'!L:7%U97(@X"!N)VEM<&]R=&4@<75E;&QE(&)O[G1E(&1E("(*(F-O=7)R
M:65LH#\B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q
M,`IM<V=I9"`B06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB
M"FUS9W-T<B`B4&%R=&EE<R!A;'1E<FYA=&EV97,@<&]U<B!C971T92!S96-T
M:6]NH#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<R"FUS9VED(")!
M;'=A>7,B"FUS9W-T<B`B5&]U:F]U<G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-34W"FUS9VED(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(*;7-G
M<W1R(")4;W5J;W5R<R!E;G)E9VES=')E<B!L97,@<&GH8V5S(&IO:6YT97,B
M"@HC.B!L:6(O365S<V%G92YP:'`Z-3$U"FUS9VED("(B"B)!;B!E<G)O<B!O
M8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE
M;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B(@HB56YE
M(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1U(')E=')A:70@9&4@;&$@
M<&GH8V4@:F]I;G1E+B!,92!S97)V975R("(*(DE-05`@82!RZ7!O;F1UH#H@
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,Y.`IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T92XB"FUS
M9W-T<B`B(@HB56YE(&5R<F5U<B!I;F-O;FYU92!E<W0@<W5R=F5N=64@<&5N
M9&%N="!L82!C<NEA=&EO;B!D92!L82!N;W5V96QL92!N;W1E+B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HS.3<*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C
M=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(B(*
M(E5N92!E<G)E=7(@:6YC;VYN=64@97-T('-U<G9E;G5E('!E;F1A;G0@;&$@
M8W+I871I;VX@9&4@;&$@;F]U=F5L;&4@=.)C:&4N(@H*(SH@;65S<V%G92YP
M:'`Z-#DV(&UA:6QB;W@N<&AP.C<P,2!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,U"B,Z('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-@IM<V=I9"`B06YS=V5R960B
M"FUS9W-T<B`B4NEP;VYD=2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(DUE<W-A
M9V5S('+I<&]N9'5S(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN
M8SHW"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(D%P<&QI<75E<B!L
M97,@9FEL=')E<R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<'!L>2!&:6QT97)S('1O("5S(@IM
M<V=S='(@(D%P<&QI<75E<B!L97,@9FEL=')E<R!S=7(@)7,B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S8*;7-G:60@(D%P<&QY(&9I;'1E
M<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(D%P<&QI<75E<B!C
M97,@9FEL=')E<R!L;W)S(&1E(&QA(&-O;FYE>&EO;J`_(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0R"FUS9VED(")!<'!L>2!F:6QT97(@
M<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/R(*;7-G<W1R(")!
M<'!L:7%U97(@;&5S(&9I;'1R97,@X"!C:&%Q=64@869F:6-H86=E(&1E($)O
M[G1E(&1E('+I8V5P=&EO;J`_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A
M9&5R+FEN8SHQ-`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E
M;&5T92!T:&ES(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX_(@IM<V=S='(@
M(B(*(LIT97,M=F]U<R!C97)T86EN(&1E('9O=6QO:7(@<W5P<')I;65R(&-E
M='1E(&3I9FEN:71I;VX@9&4@<NEP97)T;VER92`B"B)V:7)T=65LH#\B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR-PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E
M;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(LIT97,M=F]U<R!C97)T
M86EN(&1E('9O=6QO:7(@<W5P<')I;65R(&-E='1E(&-L968@<'5B;&EQ=66@
M/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M
M;65N9&5D(2DB"FUS9W-T<B`B(@HBRG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U
M;&]I<B!DZ71R=6ER92!C971T92!P86ER92!D92!C;&5F<Z`_("AC92!N)V5S
M="!P87,@(@HB<F5C;VUM86YDZ:`A*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z
M-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_(@IM
M<V=S='(@(LIT97,M=F]U<R!C97)T86EN(&1E('9O=6QO:7(@9F%I<F4@YV&@
M/R(*"B,Z(&UE<W-A9V4N<&AP.C0P,2!T96UP;&%T97,O;6%I;&)O>"]J879A
M<V-R:7!T+FEN8SHV.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`B
MRG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!S=7!P<FEM97(@9.EF:6YI
M=&EV96UE;G0@8V5S(&UE<W-A9V5SH#\B"@HC.B!L:6(O34E-12]#;VYT96YT
M<RYP:'`Z,C(R"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$52
M34%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B(@HB
MRG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!S=7!P<FEM97(@9.EF:6YI
M=&EV96UE;G0@8V5T=&4@<&GH8V4@:F]I;G1EH#\B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/R(*;7-G<W1R("+*=&5S+79O
M=7,@8V5R=&%I;B!D92!V;W5L;VER('9I9&5R(&-E(&1O<W-I97*@/R(*"B,Z
M(&QI8B])35`N<&AP.CDU-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&5M<'1Y('EO=7(@<W!A;2!F;VQD97(_(@IM<V=S='(@(LIT97,M=F]U
M<R!C97)T86EN(&1E('9O=6QO:7(@=FED97(@=F]T<F4@9&]S<VEE<B!D92!P
M;W5R<FEE;'.@/R(*"B,Z(&QI8B])35`N<&AP.CDT.0IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R/R(*
M;7-G<W1R("+*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER('9I9&5R('9O
M=')E(&-O<F)E:6QL9:`_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E<FUA
M;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`BRG1E<RUV
M;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(&-E<R!M97-S86=E<R!D
MZ69I;FET:79E;65N=*`_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C
M<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M-SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI
M<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R("+*=&5S+79O=7,@8V5R
M=&%I;B!D92!V;W5L;VER(&3I8VQA<F5R(&-E(&UE<W-A9V4@8V]M;64@;.EG
M:71I;66@/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC
M.C<U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G
M92!A<R!S<&%M/R(*;7-G<W1R("+*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L
M;VER(')A<'!O<G1E<B!C92!M97-S86=E(&-O;6UE(&1U('!O=7)R:65LH#\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`T"FUS9VED(")!<G)I=F%L
M(%1I;64B"FUS9W-T<B`B2&5U<F4@9&4@<NEC97!T:6]N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDQ.0IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@
M(D-R;VES<V%N="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S$*;7-G
M:60@(D%S:R(*;7-G<W1R(")$96UA;F1E<B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0V.0IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S
M='(@(DIO:6YD<F4@;&5S(&9I8VAI97)S(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#4P"FUS9VED(")!='1A8V@@82!C;W!Y(&]F('EO
M=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R(")*
M;VEN9')E('5N92!C;W!I92!D92!V;W1R92!C;&5F(%!'4"!P=6)L:7%U92#@
M('9O=')E(&UE<W-A9V6@/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H
M<#HQ,3$*;7-G:60@(D%T=&%C:&5D($9I;&4Z(@IM<V=S='(@(E!IZ&-E(&IO
M:6YT9:`Z(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0V,B!L:6(O0V]M<&]S92YP
M:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%T=&%C:&5D(&9I;&4@
M7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I
M;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("(B"B),82!P:>AC92!J;VEN=&4@
MJZ`E<Z"[(&3I<&%S<V4@;&5S(&QI;6ET97,@9&4@=&%I;&QE+B!&:6-H:65R
M($Y/3B!A='1A8VCI+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS
M-S<*;7-G:60@(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R
M97%U97-T('EO=2!S96YT+B(*;7-G<W1R(")#:2UJ;VEN="!U;F4@<NEP;VYS
M92#@('5N92!R97%UZG1E('9E<G,@=6X@86=E;F1A+B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C$T"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0Y-R!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHU-0IM
M<V=I9"`B071T86-H;65N="(*;7-G<W1R(")0:>AC92!J;VEN=&4B"@HC.B!A
M='1A8VAM96YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!='1A8VAM
M96YT("5S(&1E;&5T960N(@IM<V=S='(@(E!IZ&-E(&IO:6YT92`E<R!S=7!P
M<FEMZ64N(@H*(SH@8V]M<&]S92YP:'`Z,3`Y-R!L:6(O365S<V%G92YP:'`Z
M-#<V"FUS9VED(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A
M8VAM96YT('1Y<&4B"FUS9W-T<B`B4&GH8V4@:F]I;G1E(')E=&ERZ66@.B!T
M>7!E(&0G;W)I9VEN92!D92!L82!P:>AC92!J;VEN=&4B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#D@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#8W"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#DS"FUS9VED
M(")!='1A8VAM96YT<R(*;7-G<W1R(")0:>AC97,@:F]I;G1E<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-S@*;7-G:60@(D%T=&5N9&5E<R(*
M;7-G<W1R(")0<NES96YT<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C4S"FUS9VED(")!='1E;G1I;VXB"FUS9W-T<B`B071T96YT
M:6]N(@H*(SH@;&EB+T%U=&@O:6UP+G!H<#HT-`IM<V=I9"`B075T:%]I;7`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]I;7"@.B!E>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,C@*;7-G:60@(B(*(D%U
M=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N
M('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM<V=S='(@
M(B(*(D%F9FEC:&5R(&%U=&]M871I<75E;65N="!L97,@:6UA9V5S(&1E<R!M
M97-S86=E<R!E;B!(5$U,(&QO<G-Q=64@(@HB;"=E>'#I9&ET975R(&5S="!D
M86YS(&UO;B!C87)N970@9"=A9')E<W-E<Z`_(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,CDX"FUS9VED(")!=F%I;&%B;&4@061D
M<F5S<R!B;V]K<SHB"FUS9W-T<B`B0V%R;F5T<R!D)V%D<F5S<V5S(&1I<W!O
M;FEB;&5SH#HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S$T"FUS
M9VED(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R(")%;B!A='1E;G1E(&0G
M=6YE('+I<&]N<V4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8U]K('1O("5S
M(@IM<V=S='(@(E)E7W9E;FER(.`@)7,B"@HC.B!T:')E860N<&AP.C$S-B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H
M<"UF;W)M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B4F5V96YI<B#@
M("5S(@H*(SH@=&AR96%D+G!H<#HQ,S,*;7-G:60@(D)A8VL@=&\@375L=&EP
M;&4@365S<V%G92!6:65W($EN9&5X(@IM<V=S='(@(E)E=&]U<B#@(&PG:6YD
M97@@9&4@<'+I<V5N=&%T:6]N(&1E<R!M97-S86=E<R!M=6QT:7!L97,B"@HC
M.B!T:')E860N<&AP.C$S,0IM<V=I9"`B0F%C:R!T;R!4:')E860@1&ES<&QA
M>2(*;7-G<W1R(")2971O=7(@X"!L)V%F9FEC:&%G92!P87(@9FEL<R(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@
M)7,B"FUS9W-T<B`B4F5Q=>IT92!M875V86ES92!O=2!M86P@9F]R;>EE+B!,
M92!S97)V975R(&$@<NEP;VYD=:`Z("5S(@H*(SH@;65S<V%G92YP:'`Z,C8V
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z
M,S0*;7-G:60@(D)C8R(*;7-G<W1R(")#8VDB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X
M="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@
M(D-I+61E<W-O=7,@;&4@=&5X=&4@8G)U="#@('!R;W!O<R!D97,@:6YF;W)M
M871I;VYS(&1U(&UE<W-A9V4N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$V"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`B3&ES=&4@;F]I<F4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")";&]C:R!I
M;6%G97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF
M:6-A;&QY(')E<75E<W1E9#\B"FUS9W-T<B`B0FQO<75E<B!L97,@:6UA9V5S
M(&1E<R!M97-S86=E<R!E;B!(5$U,('-A=68@9&5M86YD92!E>'!L:6-I=&6@
M/R(*"B,Z(&QI8B]396%R8V@N<&AP.C0R"FUS9VED(")";V1Y(@IM<V=S='(@
M(D-O<G!S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I
M9"`B0F]T:"(*;7-G<W1R("),97,@9&5U>"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-S4*;7-G:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O
M9'D@;V8@365S<V%G92(*;7-G<W1R(")3:6UU;'1A;NEM96YT(&1A;G,@;&$@
M;&ES=&4@9&5S(&5N+73J=&5S(&5T(&1A;G,@;&4@8V]R<',@9'4@;65S<V%G
M92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,@IM<V=I
M9"`B0U]H87)S970B"FUS9W-T<B`B7TIE=2!D92!C87)A8W3H<F5S(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")!9V5N9&$B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I
M;"!S97)V97(N(@IM<V=S='(@(D-O;FYE>&EO;B!A=2!S97)V975R(&1E(&-O
M=7)R:65L(&1I<W1A;G0@:6UP;W-S:6)L92XB"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R
M96UO=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R(")#;VYN97AI;VX@874@<V5R
M=F5U<B!D92!C;W5R<FEE;"!D:7-T86YT(&EM<&]S<VEB;&6@.B`B"@HC.B!L
M:6(O34E-12]6:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E
M<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@(@HB;6%I
M;&)O>"XB"FUS9W-T<B`B(@HB3F4@<&5U="!A9F9I8VAE<B`M('1R;W5VZ2!S
M975L96UE;G0@)7,@<&%R=&EE<R!D92`E<R!D92!C92!M97-S86=E(&1A;G,@
M;&$@(@HB<'+I<V5N=&4@8F_N=&4@9&4@8V]U<G)I96QS+B(*"B,Z(&9O;&1E
M<G,N<&AP.C(V,R!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U
M-0HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(Q('1E;7!L871E
M<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.0HC.B!T96UP;&%T97,O<VUI
M;64O<&%S<W!H<F%S92YI;F,Z,C$@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K
M97DN:6YC.C@V"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ
M,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,@HC.B!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C8V"FUS9VED(")#86YC96PB"FUS9W-T
M<B`B06YN=6QE<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R.0HC.B!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@
M365S<V%G92(*;7-G<W1R(")!;FYU;&5R(&QE(&UE<W-A9V4B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FIS.C8*;7-G:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E
M('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S
M='(@(DPG86YN=6QA=&EO;B!D=2!M97-S86=E(&5N=')A[FYE<F$@;&$@<&5R
M=&4@9.EF:6YI=&EV92!D92!S;VX@8V]N=&5N=2XB"@HC.B!M97-S86=E+G!H
M<#HR-C4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C$*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ-2!L:6(O4V5A<F-H
M+G!H<#HS,`IM<V=I9"`B0V,B"FUS9W-T<B`B0V,B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I;7!O
M<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L
M960@;VX@=&AI<R`B"B)S97)V97(N(@IM<V=S='(@(B(*(DPG:6UP;W)T871I
M;VX@9&4@8V5R=&EF:6-A=',@;B=E<W0@<&%S(&1I<W!O;FEB;&4N($]N(&YE
M('!E=70@<&%S(&5N=F]Y97(@9&4@(@HB9FEC:&EE<B!S=7(@8V4@<V5R=F5U
M<BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDV"FUS9VED(")#
M:&%I<B!097)S;VXB"FUS9W-T<B`B06YI;6%T975R(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED(")#:&%N9V4B"FUS9W-T
M<B`B36]D:69I97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z.#$*;7-G:60@(D-H86YG92!!;&PB"FUS9W-T<B`B0VAA;F=E<B!T;W5T
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDR"FUS9VED(")#:&%N9V4@
M1F]L9&5R(@IM<V=S='(@(D-H86YG97(@9&4@9&]S<VEE<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3(*;7-G:60@(B(*(D-H86YG92!D:7-P;&%Y
M(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N
M(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S(&%R92!S;W)T960N(@IM
M<V=S='(@(B(*(D-H86YG97(@;&5S('!RZ6;I<F5N8V5S(&0G869F:6-H86=E
M('1E;&QE<R!Q=64@;&4@=&CH;64L(&QE(&YO;6)R92!D92`B"B)M97-S86=E
M<R!A9F9I8VCI<R!P87(@<&%G92!E="!C;VUM96YT(&EL<R!S;VYT('1R:>ES
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B0VAA;F=E
M(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@(DUO
M9&EF:65R(&QA(&-O;F9I9W5R871I;VX@9'4@<V5R=F5U<B!D92!C;W5R<FEE
M;"!E="!D97,@9&]S<VEE<G,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S
M:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"`B
M"B)R97!L>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B)#:&%N9V5R(&QE
M(&YO;2P@;"=A9')E<W-E(&5T(&QA('-I9VYA='5R92!Q=64@;&5S('!E<G-O
M;FYE<R!V;VEE;G0@<75A;F0@(@HB96QL97,@;&ES96YT(&5T('+I<&]N9&5N
M="#@('9O<R!M97-S86=E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#$R"FUS9VED(")#:&%R86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(D-A
M<F%C=.AR97,@X"!A9F9I8VAE<J`Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,34*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W
M($UA:6PB"FUS9W-T<B`B5NER:69I97(@;&5S(&YO=79E875X(&UE<W-A9V5S
M(&1U*&1E<RD@9&]S<VEE<BAS*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(E;I<FEF
M:65R(%]4;W5T+U)I96XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC
M.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O
M(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B5NER:69I97H@=&]U<R!L97,@
M<V5R=F5U<G,@9&]N="!V;W5S('9O=6QE>B!RZ6-U<.ER97(@;&4@8V]U<G)I
M97*@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*;7-G:60@(D-H
M96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T
M<B`B5NER:69I97(@;"=O<G1H;V=R87!H92!A=F%N="!L)V5N=F]I(&0G=6X@
M;65S<V%G9:`_(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M-`IM<V=I9"`B0VAO;W-E($%C=&EO;CHB"FUS9W-T<B`B0VAO:7-I<B!L)V%C
M=&EO;J`Z(@H*(SH@8V]N9FEG+W-E<G9E<G,N<&AP+F1I<W0Z,3<Y"FUS9VED
M(")#:&]O<V4@82!M86EL('-E<G9E<CHB"FUS9W-T<B`B0VAO:7-I<B!U;B!S
M97)V975R(&1E(&-O=7)R:65LH#HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHQ,C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,38V"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Q-PIM<V=I
M9"`B0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@
M<FEG:'0Z(@IM<V=S='(@(E/I;&5C=&EO;FYE<B!U;F4@8V]R<F5S<&]N9&%N
M8V4@;W4@Z61I=&5R(&PG861R97-S92#@(&1R;VET9:`Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"FUS9VED(")#:&]O<V4@
M=&AE(&%D9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S
M+B(*;7-G<W1R("(B"B)#:&]I<VES<V5Z(&QE(&-A<FYE="!D)V%D<F5S<V5S
M(.`@=71I;&ES97(@;&]R<W%U92!V;W5S(&%J;W5T97H@9&5S(&%D<F5S<V5S
M+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PIM
M<V=I9"`B0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E
M87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(B(*(D-H
M;VES:7-S97H@;"=O<F1R92!D92!R96-H97)C:&4@9&5S(&-A<FYE=',@9"=A
M9')E<W-E<R!L;W)S(&1U(&3I=F5L;W!P96UE;G0@(@HB9&5S(&YO;7,N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3$U"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@
M:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N(@IM<V=S='(@
M(B(*(D-L:7%U97(@<W5R("5S('!O=7(@8V]N=F5R=&ER(&PG:6UA9V4@9&%N
M<R!U;B!F;W)M870@<75E('9O=')E(&YA=FEG871E=7(@(@HB<&5U="!L:7)E
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@:6UA9V4N
M(@IM<V=S='(@(D-L:7%U97(@)7,@<&]U<B!TZ6SI8VAA<F=E<B!L)VEM86=E
M+B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M96YT('!A9V4N(@IM<V=S
M='(@(D-L:7%U97(@)7,@<&]U<B!V;W5S(')E;F1R92#@(&QA('!A9V4@9&4@
M9V5S=&EO;B!D92`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M,3$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@2%1-
M3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")#;&EQ
M=65R('-U<B`E<R!P;W5R('9I<W5A;&ES97(@;&4@8V]N=&5N=2!(5$U,(&1A
M;G,@=6YE(&%U=')E(&9E;NIT<F4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,38T"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B0VQI
M<75E<B`E<R!P;W5R('9O:7(@=6YE(.ET:7%U971T92!D92!C971T92!I;6%G
M92XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0R,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT
M(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")#;&EQ=65R('-U<B`E
M<R!P;W5R('9I<W5A;&ES97(@;&$@<&GH8V4@:F]I;G1E(&1A;G,@=6YE(&%U
M=')E(&9E;NIT<F4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP
M.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AI
M<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W
M+B(*;7-G<W1R(")#;&EQ=65R('-U<B`E<R!P;W5R('9I<W5A;&ES97(@8V5T
M=&4@<&%R=&EE(&1A;G,@=6YE(&%U=')E(&9E;NIT<F4N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.CDX"FUS9VED(")#;&EC:R!H97)E('1O(%-(
M3U<@=&AE($EM86=E<R(*;7-G<W1R(")#;&EQ=65R(&EC:2!P;W5R($U/3E12
M15(@;&5S(&EM86=E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,R,0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L
M96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD
M<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(D-H;VES:7-S97H@=6X@9&4@
M=F]S(&-A<FYE=',@9"=A9')E<W-E<R!E="!E;G-U:71E('/I;&5C=&EO;FYE
M>B!T;W5S(&QE<R`B"B)C:&%M<',@X"!R96-H97)C:&5R+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C$W,`IM<V=I9"`B0VQI8VL@=&\@4V%V92!0
M1U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R("(B
M"B)#;&EQ=65R('!O=7(@96YR96=I<W1R97(@;&$@8VQE9B!01U`@<'5B;&EQ
M=64@9&%N<R!V;W1R92!C87)N970@9"=A9')E<W-E<R(*"B,@<&AP+69O<FUA
M=`HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(P,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O
M9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"B)#;&EQ=65R
M('!O=7(@96YR96=I<W1R97(@;&4@8V5R=&EF:6-A="!3+TU)344@9&4@)7,@
M9&%N<R!V;W1R92!C87)N970@(@HB9"=A9')E<W-E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,S@*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R
M97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B
M"FUS9W-T<B`B0VQI<75E<B!S=7(@;"=A9')E<W-E(&-O;7!O<V5R82!U;B!N
M;W5V96%U(&UE<W-A9V4@X"!L)V5X<.ED:71E=7(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3,Y"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S
M<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R(")#
M;&EQ=65R('-U<B!L)V%D<F5S<V4@;W5V<FER82!L92!M97-S86=E('!O=7(@
M;&$@;&5C='5R92(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL
M+FEN8SHR.`IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B1F5R;65R(@H*(SH@8V]M
M<&]S92YP:'`Z-#$W"FUS9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R
M(")&97)M97(@8V5T=&4@9F5NZG1R92(*"B,Z(&9O;&1E<G,N<&AP.C0P.`IM
M<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G<W1R(")$;W-S:65R(&9E<FWI(@H*
M(SH@9F]L9&5R<RYP:'`Z-#(X"FUS9VED(")#;VQL87!S92(*;7-G<W1R(")2
MZ61U:7)E(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*
M;7-G:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R(")2Z61U:7)E('1O=70B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L
M;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T<B`B4NED=6ER92!T;W5S(&QE<R!D
M;W-S:65R<R(*"B,Z(&9O;&1E<G,N<&AP.C0R.`IM<V=I9"`B0V]L;&%P<V4@
M1F]L9&5R(@IM<V=S='(@(E+I9'5I<F4@;&4@9&]S<VEE<B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@26YD
M:6-A=&]R.B`B"FUS9W-T<B`B26YD:6-A=&5U<B!D92!C;W5L975RH#H@(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P,PIM<V=I9"`B0V]M;65N="(*
M;7-G<W1R(")#;VUM96YT86ER92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-C(*;7-G:60@(D-O;7!L971E9"(*;7-G<W1R(")497)M:6[I(@H*
M(SH@8V]M<&]S92YP:'`Z-#$V"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S
M<V%G92(*;7-G<W1R(")2Z61I9V5R('5N(&%U=')E(&UE<W-A9V4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP;W-E(&UE<W-A
M9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")2Z61I9V5R(&QE
M<R!M97-S86=E<R!D86YS('5N92!F96[J=')E('/I<&%RZ66@/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S
M<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R
M('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@HB0V]M<&]S
M97(@;&5S(&UE<W-A9V5S(&%V96,@=6YE(&EN=&5R9F%C92!E;B!(5$U,('!A
M<B!DZ69A=70@*'-I(&QE("(*(FYA=FEG871E=7(@<W5P<&]R=&4@8V5T=&4@
M;W!T:6]N*:`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED
M(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S
M='(@(D-O;F9I9W5R97(@;"=A9F9I8VAA9V4@9&5S(&UE<W-A9V5S+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B0V]N9FEG=7)E(&UA
M:6P@<')E=FEE=R!O<'1I;VYS+B(*;7-G<W1R(")#;VYF:6=U<F5R(&QE<R!O
M<'1I;VYS(&1E('!RZ2UV:7-U86QI<V%T:6]N(&1U(&-O=7)R:65R+B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,S<P"FUS9VED(")#;VYN96-T:6]N(&1R
M;W!P960@8GD@24U!4"!S97)V97(N(@IM<V=S='(@(D-O;FYE>&EO;B!R;VUP
M=64@<&%R(&QE('-E<G9E=7(@24U!4"XB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D
M(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B1V5S
M=&EO;B!D=2!S=7!P;W)T(&1E(%!'4"!D86YS("5S+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O
M;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(D=E<W1I;VX@9'4@
M<W5P<&]R="!D92!3+TU)344@9&%N<R`E<RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P=&EO;G,@<F5L871I;F<@
M=&\@;65S<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R(")#;VYT<O1L92!D97,@
M;W!T:6]N<R!D92!R96-H97)C:&4@9&5S(&UE<W-A9V5S+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE
M=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO
M="!T;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B
M(@HB4NEG;&5R(&QA(';I<FEF:6-A=&EO;B!D92!L)V%R<FEVZ64@9&4@;F]U
M=F5A=7@@;65S<V%G97,L(&5T(',G:6P@9F%U="!O=2`B"B)N;VX@=F]U<R!E
M;B!A=F5R=&ER+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#0*;7-G
M:60@(D-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@
M;VYE<S\B"FUS9W-T<B`B0V]N=F5R=&ER(&QE<R#I;6]T:6/T;F5S('1E>'1U
M96QS(&5N(&=R87!H:7%U9:`_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EE<B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM<V=I9"`B0V]P>2!T;R!F;VQD97(B
M"FUS9W-T<B`B0V]P:65R('9E<G,@;&4@9&]S<VEE<B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G
M<W1R(")#;W)R:6=E<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHQ-#`*;7-G:60@(D-O<G)E8W1E9"!497AT(@IM<V=S='(@(E1E>'1E
M(&-O<G)I9^DB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,X,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S="X@4F5A
M<V]N($=I=F5N.B`E<R(*;7-G<W1R("));7!O<W-I8FQE(&1E('1E<FUI;F5R
M(&QA(')E<77J=&4N(%)A:7-O;B#I=F]Q=>EEH#H@)7,B"@HC.B!A='1A8VAM
M96YT+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E
M871E('1H92!61E,@8F%C:V5N9#H@)7,B"FUS9W-T<B`B26UP;W-S:6)L92!D
M92!C<NEE<B!U;B!D;W)S86P@5D93H#H@)7,B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C0W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R
M("));7!O<W-I8FQE(&1E('-U<'!R:6UE<B!D97,@;65S<V%G97,@9&4@)7,N
M($QE('-E<G9E=7(@82!RZ7!O;F1UH#H@)7,B"@HC.B!L:6(O4V5S<VEO;BYP
M:'`Z,S(R"FUS9VED(")#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O
M<&5R871I;VYS+B(*;7-G<W1R("));7!O<W-I8FQE(&0G97CI8W5T97(@;&5S
M(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@
M<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*
M;7-G<W1R("(B"B));7!O<W-I8FQE(&0G97AT<F%I<F4@;&4@9FEC:&EE<B!D
M96UA;F3I(&1E(&QA('!IZ&-E(&IO:6YT92!A=2!F;W)M870@35,M(@HB5$Y%
M1BXB"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HU.`IM<V=I9"`B0V]U
M;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II
M<"!A<F-H:79E+B(*;7-G<W1R("));7!O<W-I8FQE(&0G97AT<F%I<F4@;&4@
M9FEC:&EE<B!D96UA;F3I(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE+B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N('-E8W5R92!C;VYN96-T:6]N('1O('1H92!)34%0
M('-E<G9E<BX@)7,@.B`E<RXB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D)V]U
M=G)I<B!U;F4@8V]N;F5X:6]N('/I8W5R:7/I92!S=7(@;&4@<V5R=F5U<B!)
M34%0+B`E<Z`Z("5S+B(*"B,Z(&QI8B]397-S:6]N+G!H<#HR-S(*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!N86UE<W!A8V4@:6YF;W)M871I;VX@9G)O
M;2!)34%0('-E<G9E<BXB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D92!RZ6-U
M<.ER97(@;&5S(&EN9F]R;6%T:6]N<R!D92!N;VUM86=E(.`@<&%R=&ER(&1U
M('-E<G9E=7(@24U!4"XB"@HC.B!S96%R8V@N<&AP.C,Q-"!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,SD@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,0HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*;7-G:60@(D-R96%T
M92(*;7-G<W1R(")#<NEE<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C8*;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T<B`B0W+I97(@
M=6X@9&]S<VEE<B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*;7-G
M:60@(D-R96%T92!+97ES(@IM<V=S='(@(D-RZ65R(&1E<R!C;&5F<R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-`IM<V=I9"`B0W)E871E
M(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(D-RZ65R('5N(&1O<W-I97(@=FER
M='5E;"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N
M:6YC.C(V"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R(")#
M<NEE<B!U;B!N;W5V96%U(&-O;7!T92(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M<&%M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R
M(")#<NEE<B!U;B!N;W5V96%U(&1O<W-I97(@<&]U<B!L97,@<&]U<G)I96QS
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M
M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T
M92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(D-RZ65R('5N(&YO=79E
M874@9&]S<VEE<B!D92!B<F]U:6QL;VYS(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-E;G1M86EL<V5L96-T+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N=&UA
M:6QS96QE8W0N:6YC.C0R"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M86EL
M(&9O;&1E<B(*;7-G<W1R(")#<NEE<B!U;B!N;W5V96%U(&1O<W-I97(@9&4@
M;65S<V%G97,@96YV;WGI<R(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E
M;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR
M-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R(")#
M<NEE<B!U;F4@;F]U=F5L;&4@8V]R8F5I;&QE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R.`IM<V=I9"`B(@HB0W)E871E(&9I;'1E<FEN9R!R=6QE
M<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT
M;R!F;VQD97)S+"`B"B)A;F0@9&5L971E('-P86TN(@IM<V=S='(@(B(*(D-R
MZ65R(&1E<R!RZ&=L97,@9&4@9FEL=')A9V4@<&]U<B!O<F=A;FES97(@=F]S
M(&%R<FEVZ65S(&1E(&UE<W-A9V5S+"!L97,@(@HB=')I97(@9&%N<R!D97,@
M9&]S<VEE<G,L(&5T(.EL:6UI;F5R(&QE<R!P;W5R<FEE;',N(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"FUS9VED(")#<F5A=&4@
M;F5W('-T871I;VYE<GDB"FUS9W-T<B`B0W+I97(@=6YE(&YO=79E;&QE('!A
M<&5T97)I92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*;7-G:60@
M(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB"FUS9W-T
M<B`B0W+I97(@=6YE('!A<&5T97)I92!E="!D97,@9F]R;75L86ER97,@9&4@
M<NEP;VYS92XB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A8V-E<W,@=&\@)7,B"FUS9W-T<B`B
M06-CZ',@8V]U<F%N="#@("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P-0IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M
M86EL(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(B(*(E!E<G-O;FYA
M;&ES97(@;&5S(&-O;7!T97,@<&]U<B!L82!RZ6-U<.ER871I;VX@9&4@8V]U
M<G)I97(@9&5P=6ES(&0G875T<F5S("(*(F-O;7!T97,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED(")#=7-T;VUI>F4@:&]W('EO=2!S
M96YD(&UA:6PN(@IM<V=S='(@(D3I9FEN:7(@8V]M;65N="!V;W5S(&5N=F]Y
M97H@9&5S(&UE<W-A9V5S("XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")$Z69I;FER(&QE<R!TXF-H
M97,@X"!E9F9E8W1U97(@;&]R<R!D92!L82!C;VYN97AI;VX@X"`E<RXB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$W"FUS
M9VED(")$871?92(*;7-G<W1R(")?1&%T92(*"B,Z(&UE<W-A9V4N<&AP.C(V
M,B!T:')E860N<&AP.C$T-PIM<V=I9"`B1&%T92(*;7-G<W1R(")$871E(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U,`IM<V=I9"`B1&5C;&EN
M960B"FUS9W-T<B`B1.EC;&ENZ2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-C0*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B1.EC;&ENZ:`Z
M("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`B1.EF875T(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U
M;'1S96%R8VAS96QE8W0N:6YC.C$X"FUS9VED(")$969A=6QT(%-E87)C:"!&
M:65L9"(*;7-G<W1R(")#:&%M<"!D92!R96-H97)C:&4@<&%R(&3I9F%U="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3$*;7-G:60@(D1E9F%U;'0@
M<V]R=&EN9R!C<FET97)I83HB"FUS9W-T<B`B0W)I=.AR92!D92!T<FD@<&%R
M(&3I9F%U=*`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I
M9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B3W)D<F4@
M9&4@=')I('!A<B!DZ69A=72@.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-3@*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R(")$Z6SI9W7I(@H*
M(SH@9F]L9&5R<RYP:'`Z,SDX('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C0T"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHV('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHR-0HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT
M<RYI;F,Z,C@@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM<V=I9"`B1&5L971E(@IM<V=S
M='(@(E-U<'!R:6UE<B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(E-U<'!R:6UE<B!L
M82!C;&5F('!U8FQI<75E("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T
M92!#=7)R96YT($ME>7,B"FUS9W-T<B`B4W5P<')I;65R(&QE<R!C;&5F<R!C
M;W5R86YT97,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHY
M"FUS9VED(")$96QE=&4@1F]L9&5R*',I(@IM<V=S='(@(D3I=')U:7)E(&QE
M*',I(&1O<W-I97(H<RDB"@HC.B!F;VQD97)S+G!H<#HR-C0*;7-G:60@(D1E
M;&5T92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(E-U<'!R:6UE<B!L97,@
M9&]S<VEE<G,@<^EL96-T:6]N;NES(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C0R"FUS9VED(")$96QE=&4@4W1A=&EO;F5R>2(*;7-G
M<W1R(")3=7!P<FEM97(@;&$@<&%P971E<FEE(@H*(SH@9F]L9&5R<RYP:'`Z
M,SDX"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B1.ET
M<G5I<F4@;&4@9&]S<VEE<B!V:7)T=65L(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B4W5P
M<')I;65R(&QA(&3I9FEN:71I;VX@9'4@9&]S<VEE<B!V:7)T=65L('!O=7(@
M)7,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#,*;7-G
M:60@(D1E;&5T92!F971C:&5D(&UE<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E
M<C\B"FUS9W-T<B`B4W5P<')I;65R(&QE<R!M97-S86=E<R!R86UE;NES(&1U
M('-E<G9E=7(@9&ES=&%N=*`_(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8Q.0IM<V=I9"`B1&5L971E(&9R;VT@;7D@8V%L96YD87(B"FUS9W-T
M<B`B4W5P<')I;65R(&1E(&UO;B!A9V5N9&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8X"FUS9VED(")$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM
M96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(D5F9F%C97(@
M;&5S(&%N8VEE;FYE<R!P:>AC97,@:F]I;G1E<R!L:>EE<R!A=2!DZ6)U="!D
M=2!M;VESH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4P"FUS9VED
M(")$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O
M9B!M;VYT:#\B"FUS9W-T<B`B169F86-E<B!L97,@9&]S<VEE<G,@9&5S(&%N
M8VEE;G,@;65S<V%G97,@96YV;WGI<R!A=2!DZ6)U="!D=2!M;VESH#\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`U"FUS9VED(")$96QE=&4@<W!A
M;2!M97-S86=E<R(*;7-G<W1R(")3=7!P<FEM97(@;&5S('!O=7)R:65L<R(*
M"B,Z(&UE<W-A9V4N<&AP.C0Y.2!M86EL8F]X+G!H<#HW,C<@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM
M<V=I9"`B1&5L971E9"(*;7-G<W1R(")3=7!P<FEMZ2(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B
M"FUS9W-T<B`B365S<V%G97,@<W5P<')I;>ES(@H*(SH@8V]M<&]S92YP:'`Z
M-38X"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@=&AE(&%T=&%C:&UE
M;G0@7"(E<UPB+B(*;7-G<W1R(")$Z71R=6ER92!L82!P:>AC92!J;VEN=&4@
MJZ`E<Z"[+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B
M1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<R(*;7-G<W1R(")$Z7!L86-E
M;65N="!E="!D97-T<G5C=&EO;B!D92!M97-S86=E<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G
M<W1R(")2969U<V5R(&QA(')E<77J=&4B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-30R"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B(*;7-G<W1R(")2969U<V5R(&QA(')E<77J=&4@<W5R
M(&QE<R!D:7-P;VYI8FEL:73I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,C`*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B1.EC<F]I<W-A;G0B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-@IM<V=I9"`B1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B1&5S8W)I<'1I;VXB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D1E=&%I;',B"FUS
M9W-T<B`B1.ET86EL<R(*"B,Z(&-O;7!O<V4N<&AP.C4X,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$:60@;F]T(&%T=&%C:"!<(B5S7"(@87,@=&AE(&9I;&4@
M=V%S(&5M<'1Y+B(*;7-G<W1R(")0:>AC92!J;VEN=&4@JZ`E<Z"[(&YO;B!A
M='1A8VCI92!C87(@;&4@9FEC:&EE<B#I=&%I="!V:61E+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-C4*;7-G:60@(D1I;2!S:6=N871U<F5S/R(*
M;7-G<W1R(")%<W1O;7!E<B!L97,@<VEG;F%T=7)E<Z`_(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S8*;7-G:60@(D1I<W!L87DB
M"FUS9W-T<B`B069F:6-H86=E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0W.0IM<V=I9"`B1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN
M9R!A(&UE<W-A9V4_(@IM<V=S='(@(D%F9FEC:&5R('5N92!C;VYF:7)M871I
M;VX@87!RZ',@;"=E;G9O:2!D)W5N(&UE<W-A9V6@/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-S0*;7-G:60@(D1I<W!L87D@:6X@0F]D>2!O9B!-
M97-S86=E(@IM<V=S='(@(D%F9FEC:&5R(&1A;G,@;&4@8V]R<',@9'4@;65S
M<V%G92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D1I
M<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\B"FUS9W-T
M<B`B(@HB069F:6-H97(@=6YE(&YO=&EF:6-A=&EO;B!D92!N;W5V96%U(&-O
M=7)R:65R(&1A;G,@=6YE(&)O[G1E('-U<F=I<W-A;G1EH#\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S0V"FUS9VED(")$:7-P;&%Y('1H92!<(D5M
M<'1Y(%-P86U<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R(")!9F9I
M8VAE<B!L92!L:65N(*N@5FED97(@;&5S('!O=7)R:65L<Z"[(&1A;G,@;&$@
M8F%R<F4@9&4@;65N=:`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S
M.`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@
M=&AE(&UE;G5B87(_(@IM<V=S='(@(D%F9FEC:&5R(&QE(&QI96X@JZ!6:61E
M<B!L82!C;W)B96EL;&6@NR!D86YS(&QA(&)A<G)E(&1E(&UE;G6@/R(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0IM<V=I9"`B
M1&ES<&]S:71I;VXB"FUS9W-T<B`B1&ES<&]S:71I;VXB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C:"(*
M;7-G<W1R(").92!C;W)R97-P;VYD96YT('!A<R(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C$V"FUS9VED(")$;R!.;W0@0VAE8VL@1F]L
M9&5R*',I(&9O<B!.97<@36%I;"(*;7-G<W1R(").92!P87,@=NER:69I97(@
M;&5S(&YO=79E875X(&UE<W-A9V5S(&1E<R!D;W-S:65R<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-#`*;7-G:60@(D1O(&YO="!G96YE<F%T92!A
M(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;B(*;7-G<W1R(").92!P87,@9^EN
MZ7)E<B!U;B!L:65N(&1A;G,@;&$@8V]L;VYN92"KH$1EH+LB"@HC.B!L:6(O
M24U0+G!H<#HQ,#4W"FUS9VED(")$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@
M9F]L9&5R/R(*;7-G<W1R(")6;W5L97HM=F]U<R!O=79R:7(@8V4@9&]S<VEE
M<J`_(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,S$*;7-G:60@
M(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B5F]U
M<R!N)V%V97H@<&%S(&1E(&-O;7!T9:`_($5N<F5G:7-T<F5Z+79O=7,N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B
M1&]N92(*;7-G<W1R(")497)M:6[I(@H*(SH@;&EB+TU)344O0V]N=&5N=',N
M<&AP.C$Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R!I;B`N
M>FEP($9O<FUA="(*;7-G<W1R(")4Z6SI8VAA<F=E<B`E<R!A=2!F;W)M870@
M+GII<"(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R"FUS
M9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB
M"FUS9W-T<B`B5.ELZ6-H87)G97(@=&]U=&5S(&QE<R!P:>AC97,@:F]I;G1E
M<R`H96X@9F]R;6%T("YZ:7`I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,C`*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R
M(")4Z6SI8VAA<F=E<B!U;BAD97,I(&1O<W-I97(H<RDB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1&]W;FQO860@1F]L
M9&5R*',I(%LN>FEP(&9O<FUA=%TB"FUS9W-T<B`B5.ELZ6-H87)G97(@=6XH
M9&5S*2!D;W-S:65R*',I(%MF;W)M870@+GII<%TB"@HC.B!L:6(O34E-12]#
M;VYT96YT<RYP:'`Z,3DY"FUS9VED(")$;W=N;&]A9"!I;B`N>FEP($9O<FUA
M="(*;7-G<W1R(")4Z6SI8VAA<F=E<B!A=2!F;W)M870@+GII<"(*"B,Z(&UE
M<W-A9V4N<&AP.C0Y-R!M86EL8F]X+G!H<#HW,#8@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,0HC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C(R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M-#$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHY"FUS9VED(")$
M<F%F="(*;7-G<W1R(")"<F]U:6QL;VXB"@HC.B!F;VQD97)S+G!H<#HS-S$*
M;7-G:60@(D1R869T(&9O;&1E<B(*;7-G<W1R(")$;W-S:65R(&1E(&)R;W5I
M;&QO;G,B"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR
M,PIM<V=I9"`B1')A9G1S(&9O;&1E<CHB"FUS9W-T<B`B1&]S<VEE<B!D92!B
M<F]U:6QL;VYSH#HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`X"FUS
M9VED(")%+6UA:6P@061D<F5S<R(*;7-G<W1R(")!9')E<W-E(.EL96-T<F]N
M:7%U92(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,3D*;7-G:60@(D5.1"(*;7-G
M<W1R(")&24XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-`IM
M<V=I9"`B15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E
M<F5D+B(*;7-G<W1R(")%4E)%55*@.B!V;W1R92!M97-S86=E(&XG82!P87,@
M<'4@ZG1R92!DZ6QI=G+I+B(*"B,Z(&9O;&1E<G,N<&AP.C,Y.2!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,3D*;7-G:60@(D5D:70B"FUS9W-T
M<B`B36]D:69I97(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,3@*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(LED:71E<B!L82!L
M:7-T92!N;VER92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ
M,PIM<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(LED:71E<B!L97,@9FEL
M=')E<R(*"B,Z(&9O;&1E<G,N<&AP.C,Y.2!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z,38*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T
M<B`B36]D:69I97(@9&]S<VEE<B!V:7)T=65L(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R("5S(@IM<V=S='(@(DUO
M9&EF:65R(&QA(&3I9FEN:71I;VX@9'4@9&]S<VEE<B!V:7)T=65L('!O=7(@
M)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@
M(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(LED:71E<B!L82!L:7-T92!B;&%N
M8VAE(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS9VED
M(")%9&ET('EO=7(@8FQA8VML:7-T(@IM<V=S='(@(LED:71E<B!V;W1R92!L
M:7-T92!N;VER92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ
M,PIM<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(*;7-G<W1R("+)9&ET
M97(@=F]S('+H9VQE<R!D92!F:6QT<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#0Y"FUS9VED(")%9&ET('EO=7(@<')E9F5R96YC97,@9F]R(&%C
M8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+B(*;7-G<W1R("+)9&ET97(@
M=F]S('!RZ6;I<F5N8V5S('!O=7(@86-CZ61E<B#@(&0G875T<F5S(&-O;7!T
M97,@9&4@8V]U<G)I97(N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C(S"FUS9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(LED
M:71E<B!V;W1R92!L:7-T92!B;&%N8VAE(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR,SD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS
M9W-T<B`B061R97-S92#I;&5C=')O;FEQ=64B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A
M9V5S(&9R;VT@)7,N(@IM<V=S='(@(D5F9F%C96UE;G0@9&4@=&]U<R!L97,@
M;65S<V%G97,@9&4@)7,N(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,C(*;7-G:60@(D5M<'1Y($9O;&1E<BAS*2(*;7-G<W1R(")6:61E
M<B!L92AS*2!D;W-S:65R*',I(@H*(SH@9F]L9&5R<RYP:'`Z,C8U"FUS9VED
M(")%;7!T>2!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(E9I9&5R(&QE<R!D
M;W-S:65R<R!SZ6QE8W1I;VYNZ7,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@9F]L9&5R(@IM<V=S
M='(@(E9I9&5R(&QA(&-O<F)E:6QL92(*"B,Z(&QI8B])35`N<&AP.CDU-@IM
M<V=I9"`B16UP='D@7U-P86TB"FUS9W-T<B`B5FED97(@;&4@7W-P86TB"@HC
M.B!L:6(O24U0+G!H<#HY-#D*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R
M(")6:61E<B!L82!?8V]R8F5I;&QE(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N
M86)L92!01U`@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B06-T:79E<B!L97,@
M9F]N8W1I;VYN86QI=.ES(&1E(%!'4*`_(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHQ('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C8*
M;7-G:60@(D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B
M06-T:79E<B!L97,@9F]N8W1I;VYN86QI=.ES(&1E(%,O34E-1:`_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y.0IM<V=I9"`B16YA8FQE(&UE<W-A
M9V4@<')E=FEE=W,_(@IM<V=S='(@(D%C=&EV97(@;&$@<'+I+79I<W5A;&ES
M871I;VX@9&5S(&UE<W-A9V5SH#\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,S8*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS
M9W-T<B`B3U]P=&EO;G,@9&4@8VAI9F9R96UE;G0B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C$X"FUS9VED(")%;F-R>7!T960B"FUS9W-T
M<B`B0VAI9F9RZ2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,38@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q.`HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C4Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3,*
M;7-G:60@(D5N9"(*;7-G<W1R(")&:6XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,SDU"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B1FEN
M(&1U(&UE<W-A9V4@=')A;G-FZ7+I(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,U
M,@IM<V=I9"`B16YD(&UE<W-A9V4B"FUS9W-T<B`B1FEN(&1U(&UE<W-A9V4B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@
M(D5N9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B1FEN(&1U(&UE<W-A9V4@
M9&4@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B16YT97(@4&%S<W!H<F%S92(*
M;7-G<W1R(")%;G1R97H@;&$@<&AR87-E('-E8W+H=&4B"@HC.B!T96UP;&%T
M97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA
M;64@9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(D5N=')E>B!L
M92!N;VT@9&4@=F]T<F4@;F]U=F5A=2!D;W-S:65R(&1E('!O=7)R:65L<R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@
M(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM
M<V=S='(@(D5N=')E>B!L92!N;VT@9'4@;F]U=F5A=2!D;W-S:65R(&1E(&)R
M;W5I;&QO;G,B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N
M:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N
M="!M86EL(&9O;&1E<B(*;7-G<W1R(")%;G1R97H@;&4@;F]M(&1U(&YO=79E
M874@9&]S<VEE<B!D92!M97-S86=E<R!E;G9O>>ES(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W1R87-H<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M
M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(D5N=')E>B!L
M92!N;VT@9&4@=F]T<F4@;F]U=F5L;&4@8V]R8F5I;&QE(@H*(SH@;&EB+U-E
M87)C:"YP:'`Z-#8*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(DUE
M<W-A9V4@8V]M<&QE="(*"B,Z(&-O;7!O<V4N<&AP.C$Q-C0@;65S<V%G92YP
M:'`Z,3DT('1H<F5A9"YP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT
M<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E
M<W,@8F]O:R(*;7-G<W1R(")!:F]U="!RZ75S<VD@9&4@JZ`E<Z"[(&1A;G,@
M;&4@8V%R;F5T(&0G861R97-S97,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C$X('1E;7!L871E<R]P9W`O<&=P+FEN8SHR,0HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C,X,2!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HS.3`*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S(@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z,38S"FUS9VED(")%<G)O<B(*;7-G<W1R
M(")%<G)E=7(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0S,2!L:6(O24U!
M4"]#;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C
M;VYN96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R(")%
M<G)E=7(@9&4@8V]N;F5X:6]N(&%U('-E<G9E=7(@24U!4"X@)7.@.B`E<RXB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$P(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(D5R<F5U<B!L;W)S(&1E(&PG
M96YV;VD@9&4@;&$@<NEP;VYS9:`Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ,#(*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE
M=&5D+B(*;7-G<W1R("),)^EVZ6YE;65N="!A(.ETZ2!E9F9A8^D@879E8R!S
M=6-CZ',N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W,`IM<V=I9"`B
M179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")4;W5T97,@;&5S(#$U(&UI;G5T
M97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8W"FUS9VED(")%=F5R
M>2`S,"!S96-O;F1S(@IM<V=S='(@(E1O=71E<R!L97,@,S`@<V5C;VYD97,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8Y"FUS9VED(")%=F5R>2`U
M(&UI;G5T97,B"FUS9W-T<B`B5&]U=&5S(&QE<R`U(&UI;G5T97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<Q"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B5&]U=&5S(&QE<R!D96UI+6AE=7)E<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-C@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R(")4;W5T97,@;&5S(&UI;G5T97,B"@HC.B!F;VQD97)S+G!H<#HT,S8*
M;7-G:60@(D5X<&%N9"(*;7-G<W1R(")$Z79E;&]P<&5R(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB
M"FUS9W-T<B`B1.EV96QO<'!E<B!T;W5T(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*
M;7-G<W1R(")$Z79E;&]P<&5R('1O=7,@;&5S(&1O<W-I97)S(@H*(SH@9F]L
M9&5R<RYP:'`Z-#,V"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(D3I
M=F5L;W!P97(@;&4@9&]S<VEE<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,T,"!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z
M-3,*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R(")$Z79E;&]P<&5R(&QE
M<R!N;VUS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-3$*;7-G:60@
M(D5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC
M86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\B"FUS9W-T<B`B(@HB1.EV96QO<'!E
M<B!L97,@;F]M<R!D86YS(&QA(&9E;NIT<F4@9&4@<NED86-T:6]N(&%U=&]M
M871I<75E;65N="!E;B!A<G)IZ')E+2(*(G!L86Z@/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-C@*;7-G:60@(D5X<&%N9"!T:&4@96YT:7)E(&9O
M;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\B"FUS
M9W-T<B`B1.EV96QO<'!E<B!L82!L:7-T92!D97,@9&]S<VEE<G,@<&%R(&3I
M9F%U=*`_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C$P,0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(D3I
M=F5L;W!P96UE;G0N+BX@(@H*(SH@;&EB+TE-4"YP:'`Z.38W(&QI8B])35`N
M<&AP.CDV.0IM<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T<B`B4NEC=7#I<F%T
M:6]N(&1U(&-O=7)R:5]E<B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T
M8VAM86EL+FEN8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED
M(")&971C:"!-86EL(@IM<V=S='(@(E+I8W5PZ7)A=&EO;B!D=2!C;W5R<FEE
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-3<*;7-G:60@(D9E=&-H
M($UA:6P@:6X@82!S97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(E+I8W5PZ7)A
M=&EO;B!D=2!C;W5R<FEE<B!D86YS('5N92!F96[J=')E('/I<&%RZ66@/R(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT-@IM<V=I9"`B
M1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")287!A
M=')I97(@;&5S(&UE<W-A9V5S(&QO<G,@9&4@;&$@8V]N;F5X:6]NH#\B"@HC
M.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S(@IM<V=S='(@(B5D(&UE<W-A
M9V5S(')A<&%T<FGI<R#@('!A<G1I<B!D92`E<R(*"B,Z(&QI8B]&971C:&UA
M:6PN<&AP.C(X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D(#$@;65S
M<V%G92!F<F]M("5S(@IM<V=S='(@(C$@;65S<V%G92!R87!A=')IZ2#@('!A
M<G1I<B!D92`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T
M8VAM86EL+G!H<#HR.#D@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"FUS9VED(")&
M971C:&UA:6PZ("(*;7-G<W1R(")2Z6-U<.ER871I;VX@9'4@8V]U<G)I97*@
M.B`B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3,*;7-G:60@(D9E=&-H;6%I
M;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")&971C:&UA:6R@.B!P87,@
M9&4@;F]U=F5A=7@@;65S<V%G97,N(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"FUS
M9VED(")&:5]L=&5R<R(*;7-G<W1R(")&:5]L=')E<R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y,R!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHT,`IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6-H:65R
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"FUS9VED(")&
M:6QT97(@3W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS(&1E(&9I;'1R86=E(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.CD*;7-G:60@(D9I;'1E
M<B!3971T:6YG<R(*;7-G<W1R(")2Z&=L97,@9&4@9FEL=')E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#@*;7-G:60@(D9I;'1E<B!M97-S86=E
M(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`B1FEL=')E<B!L92!C
M;VYT96YU(&1E<R!M97-S86=E<Z`_(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B1FEL=&5R('-U<'!O<G0@:7,@9&ES
M86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(DQE('-U<'!O<G0@9'4@
M9FEL=')A9V4@97-T(&3I<V%C=&EVZ2!S=7(@8V4@<WES=.AM92XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S
M='(@(D9I;'1R97,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N
M:6YC.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C=&EV92(*;7-G<W1R(")&:6QT
M<F5S($Y/3B!A8W1I9G,B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E(@IM
M<V=S='(@(D9I;'1R97.@.B!P86=E(&1E(&=E<W1I;VX@)7,B"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN9"(*
M;7-G<W1R(")#:&5R8VAE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M.3,*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")0<F5M:>AR
M92!P86=E(&1E(&QA(&)O[G1E(@H*(SH@;6%I;&)O>"YP:'`Z,S(W"FUS9VED
M(")&:7)S="!086=E(@IM<V=S='(@(E!R96UIZ')E('!A9V4B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O7W)W87)D(@IM<V=S
M='(@(E1?<F%N<V9E<G0B"@HC.B!F;VQD97)S+G!H<#HR-#4@=&5M<&QA=&5S
M+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R
M($%C=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B06-T:6]N('-U<B!L
M97,@9&]S<VEE<G,@+2!#;VYF:7)M871I;VXB"@HC.B!F;VQD97)S+G!H<#HR
M.#(@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O
M<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R
M969S+VEN:71I86QP86=E<V5L96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA
M=FEG871O<B(*;7-G<W1R(")%>'!L;W)A=&5U<B!D97,@9&]S<VEE<G,B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,PIM<V=I9"`B1F]L9&5R(%-U;6UA
M<GDB"FUS9W-T<B`B4V]M;6%I<F4@9'4@9&]S<VEE<B(*"B,Z(&%C;"YP:'`Z
M,C,*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+B(*;7-G
M<W1R("),92!P87)T86=E(&1E<R!D;W-S:65R<R!N)V5S="!P87,@86-T:7;I
M+B(*"B,Z(&9O;&1E<G,N<&AP.C0W"FUS9VED(")&;VQD97(@=7-E(&ES(&YO
M="!E;F%B;&5D+B(*;7-G<W1R("),)W5T:6QI<V%T:6]N(&1E<R!D;W-S:65R
M<R!N)V5S="!P87,@86-T:7;I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-3<*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M
M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@
M(B(*(DQE(&9O<FUA="!D92!L82!D871E(&1A;G,@;&$@=G5E(&1E(&)O[G1E
M(&%U>"!L971T<F5S('!O=7(@9&5S(&UE<W-A9V5S("(*(F1A=.ES(&0G875J
M;W5R9"=H=6DB"@HC.B!C;VUP;W-E+G!H<#HX,3@@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")&;W)W87)D(@IM<V=S='(@(E1R86YS
M9F5R="(*"B,Z(&-O;7!O<V4N<&AP.C@P,PIM<V=I9"`B1F]R=V%R9#HB"FUS
M9W-T<B`B5')A;G-F97)TH#HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S@P"FUS
M9VED(")&;W)W87)D960@;65S<V%G92(*;7-G<W1R(")-97-S86=E('1R86YS
M9NERZ2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")-97-S
M86=E('1R86YS9NERZ2!D92`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT,#(*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM
M<V=S='(@(E+I<&]N<V4@X"!L82!R97%UZG1E('-U<B!L97,@9&ES<&]N:6)I
M;&ETZ7,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C(W"FUS9VED(")&<F]?;2(*;7-G<W1R(")$7V4B"@HC.B!M97-S86=E
M+G!H<#HR-C,@=&AR96%D+G!H<#HQ-#@@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z.3D*(SH@;&EB+U-E87)C:"YP:'`Z,C(*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B1&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`V"FUS
M9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`B1&4@;"=A9')E<W-E(@H*(SH@
M8V]M<&]S92YP:'`Z.#$U(&-O;7!O<V4N<&AP.C@Q.0IM<V=I9"`B1G=D.B(*
M;7-G<W1R(")4<F%N<RXZ(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-@IM<V=I9"`B
M1G=D.B`B"FUS9W-T<B`B5')A;G,N.B`B"@HC.B!C;VUP;W-E+G!H<#HQ,CDX
M"B,L('!H<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A
M9V5S(@IM<V=S='(@(E1R86YS+CH@)74@;65S<V%G97,@=')A;G-FZ7+I<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.`IM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S
M='(@(D]P=&EO;G,@9^ENZ7)A;&5S(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@;65S<V%G97,_
M("A)34%0(&]N;'DI(@IM<V=S='(@(DYE(')E8V5V;VER('%U92!L97,@;F]U
M=F5A=7@@;65S<V%G97.@/R`H24U!4"!S975L96UE;G0I(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S$@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4U-`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S(X"FUS
M9VED(")';R(*;7-G<W1R(")!;&QE<B(*"B,Z('1H<F5A9"YP:'`Z,3,U"FUS
M9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@(D%L;&5R(&%U(&UE<W-A9V4B
M"@HC.B!L:6(O24U0+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V\@
M=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R(")!;&QE
M<B#@(&QA(&9I8VAE(&1U(&-A<FYE="!D)V%D<F5S<V5S(&1E(*N@)7.@NR(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,S8*;7-G:60@(D=R86YT(&%C
M8V5S<R(*;7-G<W1R(")!8V-O<F1E<B!L)V%C8^AS(@H*(SH@;65S<V%G92YP
M:'`Z-30R(&QI8B]&:6QT97(N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ,#0*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3$Q
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$Q,PHC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$Q.0HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-
M12]6:65W97(O<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HT,C,*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT
M,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S(*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$R-PIM<V=I9"`B2$5212(*;7-G<W1R("))0TDB"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$R,`HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G
M:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z(&-O;7!O<V4N<&AP.C(V,`IM
M<V=I9"`B2%1-3"!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B5F5R<VEO
M;B!(5$U,(&1U(&UE<W-A9V4B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D
M97)S+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")%;BUTZG1E<R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z-0IM<V=I9"`B
M2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP;W-I;F<Z(@IM<V=S
M='(@(E9O:6-I(&QE(&UE<W-A9V4@<75E('9O=7,@Z71I97H@96X@=')A:6X@
M9&4@<NED:6=E<J`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U-@IM
M<V=I9"`B2&ED9&5N(@IM<V=S='(@(D-A8VCI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8U-0IM<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM
M<V=S='(@(D-A8VCI(&1A;G,@;&$@=G5E(&%V96,@;&5S(&5N9FEL861E<R(*
M"B,Z(&UA:6QB;W@N<&AP.C,T.0IM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S
M='(@(D-A8VAE<B!L97,@;65S<V%G97,@969F86/I<R(*"B,Z(&9O;&1E<G,N
M<&AP.C(W-PIM<V=I9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`B4V]U
M<V-R:71S('-E=6QE;65N="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(Y-`IM<V=I9"`B2&EG:"(*;7-G<W1R(")(875T92(*"B,Z(&UE
M<W-A9V4N<&AP.C(Y-R!M86EL8F]X+G!H<#HW,3$@=&5M<&QA=&5S+VUA:6QB
M;W@O;&5G96YD+FEN8SHQ,@IM<V=I9"`B2&EG:"!0<FEO<FET>2(*;7-G<W1R
M(")0<FEO<FETZ2#I;&5VZ64B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T<B`B3&$@<&QU<R#I
M;&5VZ64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<V"FUS9VED(")(
M;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T
M<B`B0V]M;65N="!V;W5L97HM=F]U<R!A9F9I8VAE<B!L97,@<&GH8V5S(&IO
M:6YT97.@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*;7-G:60@
M(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS
M9W-T<B`B0V]M;65N="!A='1R:6)U97(@;&5S(&-I=&%T:6]N<R!D86YS('5N
M92!RZ7!O;G-E(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*;7-G
M:60@(DE-05`B"FUS9W-T<B`B24U!4"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,3(Y"FUS9VED("))34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I
M(@IM<V=S='(@(DE-05`@*&3I=&5C=&5R(&%U=&]M871I<75E;65N="!L97,@
M<')O=&]C;VQE<RDB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE
M8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(DQE('-E<G9E
M=7(@24U!4"!A(&9E<FWI(&QA(&-O;FYE>&EO;BX@3&4@<V5R=F5U<B!A('+I
M<&]N9'6@.B`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38U
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V97(@
M4U-,(@IM<V=S='(@(DE-05`@<W5R(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,34R"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE
M9"!C97)T:69I8V%T92DB"FUS9W-T<B`B24U!4"!S=7(@4U-,("AC97)T:69I
M8V%T(&UA:7-O;BD@(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-C8*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R
M("))34%0('-U<B!34TP@*&-E<G1I9FEC870@;6%I<V]N*2(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z,S8X"FUS9VED("))34%0('-E<G9E<B!C;&]S960@
M=&AE(&-O;FYE8W1I;VXN(@IM<V=S='(@(DQE('-E<G9E=7(@24U!4"!A(&9E
M<FWI(&QA(&-O;FYE>&EO;BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$V-"!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!
M4"P@;F\@5$Q3(@IM<V=S='(@(DE-05`L('-A;G,@5$Q3(@H*(SH@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HT.0IM<V=I9"`B24U!4"]03U`S($UA:6P@4V5R
M=F5R<R(*;7-G<W1R(")397)V975R<R!D92!C;W5R<FEE<B!)34%0+U!/4#,B
M"@HC.B!L:6(O24U0+G!H<#HX,S<*;7-G:60@(DE.0D]8(@IM<V=S='(@(D)O
M[G1E(&1E('+I8V5P=&EO;B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#$Q
M"FUS9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@;75S="!H879E('1H
M92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+B(*;7-G<W1R("(B"B)0
M;W5R('5T:6QI<V5R(%-33"!O=2!43%,L('9O=7,@9&5V97H@879O:7(@8VAA
M<F?I(&PG97AT96YS:6]N($]P96Y34TP@9&4@4$A0+B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"FUS9VED("))9B!Y
M;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I
M;&P@8F4@;&]S="$B"FUS9W-T<B`B(@HB4VD@=F]U<R!C;VYT:6YU97HL('1O
M=7,@;&5S(&UE<W-A9V5S(&1E(&-E*',I(&1O<W-I97(H<RD@<V5R;VYT('!E
M<F1U<Z`A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@R
M"FUS9VED("))9VYO<F4B"FUS9W-T<B`B26=N;W)E<B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*
M;7-G<W1R("))9VYO<F5R('1O=70B"@HC.B!T96UP;&%T97,O<V%V96EM86=E
M+W-A=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`B26UA9V4B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P"FUS9VED("))
M;7!O<G0B"FUS9W-T<B`B26UP;W)T97(B"@HC.B!T96UP;&%T97,O<VUI;64O
M:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHV-0IM<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R("));7!O<G1E<B!L82!C
M;&5F(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S.0IM<V=I9"`B26UP
M;W)T($ME>7!A:7(B"FUS9W-T<B`B26UP;W)T97(@;&$@<&%I<F4@9&4@8VQE
M9G,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PIM<V=I
M9"`B26UP;W)T($UE<W-A9V5S(@IM<V=S='(@(DEM<&]R=&5R(&QE<R!M97-S
M86=E<R(*"B,Z('!G<"YP:'`Z-#$*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM
M<V=S='(@(DEM<&]R=&5R(&QA(&-L968@4$=0(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L($-E<G1I
M9FEC871E(@IM<V=S='(@(DEM<&]R=&5R(&QE(&-E<G1I9FEC870@<&5R<V]N
M;F5L(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ-`IM<V=I
M9"`B26UP;W)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>2(*;7-G<W1R("))
M;7!O<G1E<B!L82!C;&5F('!R:7;I92!P97)S;VYN96QL92`H4$=0*2(*"B,Z
M('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26UP;W)T
M(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(DEM<&]R=&5R(&QA
M(&-L968@<'5B;&EQ=64@<&5R<V]N;F5L;&4@*%!'4"DB"@HC.B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!E<G-O
M;F%L(%,O34E-12!#97)T:69I8V%T97,B"FUS9W-T<B`B26UP;W)T97(@;&5S
M(&-E<G1I9FEC871S(%,O34E-12!P97)S;VYN96QS(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHT,"!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#(*
M;7-G:60@(DEM<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(DEM<&]R=&5R(&QA
M(&-L968@<'5B;&EQ=64B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("))
M;7!O<G1E<B!L82!C;&5F('!U8FQI<75E(%!'4"(*"B,Z('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHX"FUS9VED("));7!O<G0@4'5B;&EC(%,O
M34E-12!+97DB"FUS9W-T<B`B26UP;W)T97(@;&$@8VQE9B!P=6)L:7%U92!3
M+TU)344B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@
M2V5Y(@IM<V=S='(@(DEM<&]R=&5R(&QA(&-L968@4R]-24U%(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@;6)O
M>"!&:6QE(@IM<V=S='(@(DEM<&]R=&5R('5N(&9I8VAI97(@;6)O>"(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB
M"FUS9W-T<B`B26UP;W)T97(@=6X@9FEC:&EE<B!M8F]X("5S(&1A;G,@;&4@
M<NEP97)T;VER92`E<RXB"@HC.B!M97-S86=E+G!H<#HT.3@@;6%I;&)O>"YP
M:'`Z-S(Q('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$V('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHW"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`B2&%U=&4@
M:6UP;W)T86YC92(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-#<*
M;7-G:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(")-97-S86=E<R!I
M;7!O<G1A;G1S(@H*(SH@9F]L9&5R<RYP:'`Z,30W"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@
M(B5D(&UE<W-A9V5S(&EM<&]R=.ES(.`@<&%R=&ER(&1E("5S+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C8*;7-G:60@(DEN(%!R;V-E<W,B
M"FUS9W-T<B`B16X@8V]U<G,B"@HC.B!F;VQD97)S+G!H<#HS-C,@;&EB+TE-
M4"YP:'`Z,S$S(&QI8B]&;VQD97(N<&AP.C@V(&QI8B]&;VQD97(N<&AP.C(Q
M,@HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ,#D@;&EB+TE-05`O5')E92YP:'`Z
M,C$T"FUS9VED("));F)O>"(*;7-G<W1R(")";^YT92!D92!RZ6-E<'1I;VXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR"FUS9VED("));F-L=61E
M(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM
M<V=S='(@(DEN8VQU<F4@=6X@8G)E9B!R87!P96P@9&5S(&5N+73J=&5S(&1A
M;G,@;&5S('+I<&]N<V5SH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#@W"FUS9VED("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L
M>3\B"FUS9W-T<B`B26YC;'5R92!L92!M97-S86=E(&0G;W)I9VEN92!D86YS
M(&QE<R!RZ7!O;G-E<Z`_(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A
M=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3,P"FUS
M9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y(@IM
M<V=S='(@(DEN9F]R;6%T:6]N('-U<B!L82!C;&5F('!U8FQI<75E("5S(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED("));F9O<FUA=&EO
M;B!O;B!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("));F9O<FUA=&EO
M;B!S=7(@;&$@8VQE9B!P<FEVZ64@<&5R<V]N;F5L;&4B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC($ME>2(*
M;7-G<W1R("));F9O<FUA=&EO;B!S=7(@;&$@8VQE9B!P=6)L:7%U92!P97)S
M;VYN96QL92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN
M8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.3@*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z-38*;7-G:60@(DEN;&EN
M92(*;7-G<W1R("));F-O<G!O<NEE(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.CD*;7-G:60@(DEN<V5R="!#97)T:69I8V%T92!(97)E
M(@IM<V=S='(@(DEN<^ER97(@;&4@8V5R=&EF:6-A="!I8VDB"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R
M<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T<B`B26YSZ7)E<B!L
M82!C;&5F('!R:7;I92!P97)S;VYN96QL92`H4$=0*2!I8VDB"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$P"FUS9VED("));G-E<G0@4&5R
M<V]N86P@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("));G/I<F5R(&QA
M(&-L968@<'5B;&EQ=64@<&5R<V]N;F5L;&4@*%!'4"D@:6-I(@H*(SH@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED("));G-E<G0@4'5B
M;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("));G/I<F5R(&QA(&-L968@<'5B
M;&EQ=64@4$=0(&EC:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT
M,3,*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O
M;7!O;F5N="XB"FUS9W-T<B`B4^EL96-T:6]N(&0G=6YE(&%C=&EO;B!I;G9A
M;&ED92!P;W5R(&-E(&-O;7!O<V%N="XB"@HC.B!M86EL8F]X+G!H<#HU-S(@
M;6%I;&)O>"YP:'`Z-C$T"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS9W-T
M<B`B061R97-S92!I;G9A;&ED92(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,S`W"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM<V=S='(@
M(D)O[G1E(&1I<W1A;G1E(&EN=F%L:61E(@H*(SH@8V]M<&]S92YP:'`Z,34X
M"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@8VAA<F%C=&5R(&EN(&4M
M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B0V%R86-TZ')E(&EN=F%L:61E
M(&1A;G,@;"=A9')E<W-E(&1E(&-O=7)R:65LH#H@)7,N(@H*(SH@<VUI;64N
M<&AP.C<X('!G<"YP:'`Z,38*;7-G:60@(DEN=F%L:60@:V5Y(@IM<V=S='(@
M(D-L968@:6YV86QI9&4B"@HC.B!P9W`N<&AP.C$Y,@IM<V=I9"`B26YV86QI
M9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN(@IM<V=S='(@(D-L968@<')I
M=NEE(%!'4"!P97)S;VYN96QL92!I;G9A;&ED92XB"@HC.B!P9W`N<&AP.C$V
M-PIM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS
M9W-T<B`B0VQE9B!P=6)L:7%U92!01U`@<&5R<V]N;F5L;&4@:6YV86QI9&4N
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B
M26YV97)T(@IM<V=S='(@(DEN=F5R<V5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3@X"FUS9VED(")+0B(*;7-G<W1R(")+;R(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B3&]N9W5E=7(@9&4@;&$@8VQE9B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,S<*;7-G:60@(B(*(DME>2!G96YE<F%T:6]N(&UA>2!T
M86ME(&$@;&]N9R!T:6UE('1O(&-O;7!L971E+B`@0V]N=&EN=64@=VET:"!K
M97D@(@HB9V5N97)A=&EO;C\B"FUS9W-T<B`B(@HB1^ENZ7)E<B!L82!C;&5F
M('!E=70@ZG1R92!A<W-E>B!L;VYG+B!#;VYT:6YU97(@;&$@9^ENZ7)A=&EO
M;B!D92!L82!C;&5FH#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C,U('1E;7!L871E<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R
M="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE
M9"!O;B!T:&ES('-E<G9E<BXB"FUS9W-T<B`B(@HB26UP;W)T871I;VX@9&4@
M;&$@8VQE9B!N;VX@9&ES<&]N:6)L92X@3VX@;F4@<&5U="!P87,@9.EP;W-E
M<B!D92!F:6-H:65R('-U<B`B"B)C92!S97)V975R+B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,S<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,Y
M"FUS9VED("(B"B)+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H
M879E(&YO(&%D9')E<W,@8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R("(*(F-O
M;G1A8W1S+B(*;7-G<W1R("(B"B));7!O<G1A=&EO;B!D92!L82!C;&5F(&YO
M;B!D:7-P;VYI8FQE+B!6;W5S(&XG879E>B!P87,@9.EF:6YI(&1E(&-A<FYE
M="`B"B)D)V%D<F5S<V5S(&_Y(&%J;W5T97(@=F]S(&-O;G1A8W1S+B(*"B,Z
M('!G<"YP:'`Z,S$T"FUS9VED(")+97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(DQA(&-L968@82!B:65N
M(.ETZ2!E;G9O>>EE(&%U('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$U"FUS9VED("),86YG=6%G
M92(*;7-G<W1R("),86YG=64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#DT"FUS9VED("),87-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")$97)N:>AR
M92!P86=E(&1E(&QA(&)O[G1E(@H*(SH@;6%I;&)O>"YP:'`Z,S0P"FUS9VED
M("),87-T(%!A9V4B"FUS9W-T<B`B1&5R;FGH<F4@<&%G92(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T-@IM<V=I9"`B3&EN:R!!='1A
M8VAM96YT<S\B"FUS9W-T<B`B3&EE<B!L97,@<&GH8V5S(&IO:6YT97.@/R(*
M"B,Z(&%T=&%C:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#@S"FUS
M9VED("),:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T
M<B`B3&5S('!IZ&-E<R!J;VEN=&5S(&QIZ65S(&YE('-O;G0@<&%S('!E<FUI
M<V5S+B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,3`P"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI;FMS('=I;&P@97AP:7)E(&]N("5S(@IM<V=S='(@(DQE<R!L
M:65N<R!E>'!I<F5R;VYT(&QE("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-S`*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A
M9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W
M:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@
M97AP;&EC:71L>2DB"FUS9W-T<B`B(@HB3&ES=&5R('1O=7,@;&5S(&-O;G1A
M8W1S(&%U(&-H87)G96UE;G0@9&4@;"?I8W)A;B!D97,@8V]N=&%C='.@/R`H
M<VD@(@HB9.ES86-T:7;I+"!V;W5S(&YE('9E<G)E>B!Q=64@;&5S(&-O;G1A
M8W1S(&5X<&QI8VET96UE;G0@9&5M86YDZ7,I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8W,PIM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A9&5R(@IM
M<V=S='(@(DQI<W1E(&1A;G,@;&5S(&5N+73J=&5S(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P"FUS9VED("),;V-A;"!-86EL8F]X
M.B(*;7-G<W1R(")";^YT92!L;V-A;&6@.B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-S$*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DQI974B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R-`IM<V=I9"`B3&]G
M(&EN(@IM<V=S='(@(D-O;FYE>&EO;B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O("5S(@IM
M<V=S='(@(D-O;FYE>&EO;B#@("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,S@*;7-G:60@(DQO9VEN(@IM<V=S='(@(DYO;2!D)W5T:6QI
M<V%T975R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED("),
M;V=I;B!487-K<R(*;7-G<W1R(")4XF-H97,@9&4@8V]N;F5X:6]N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDV"FUS9VED("),;W<B
M"FUS9W-T<B`B1F%I8FQE(@H*(SH@;65S<V%G92YP:'`Z,CDY(&UA:6QB;W@N
M<&AP.C<Q-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$S"FUS9VED
M("),;W<@4')I;W)I='DB"FUS9W-T<B`B4')I;W)I=.D@9F%I8FQE(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E
M<W0B"FUS9W-T<B`B3&$@<&QU<R!B87-S92(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#0*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM
M<V=S='(@(D9I8VAI97(@36%C:6YT;W-H(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W!A<W-P:')A<V4N:6YC.C$S"FUS9VED(")-86EL(@IM<V=S='(@(D-O=7)R
M:65R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")-86EL
M(%!R979I97=S(@IM<V=S='(@(E!RZ2UV:7-U86QI<V%T:6]N<R!D=2!C;W5R
M<FEE<B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI
M;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SHB
M"FUS9W-T<B`B5'EP92!D92!S97)V975R(&%U<75E;"!S92!C;VYN96-T97*@
M.B(*"B,Z(&9O;&1E<G,N<&AP.C,V-R!F;VQD97)S+G!H<#HS.#$*;7-G:60@
M(DUA:6QB;W@B"FUS9W-T<B`B0F_N=&4@9&4@8V]U<G)I97(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"FUS9VED(")-86EL8F]X(&%N9"!&;VQD
M97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P=&EO;G,@9"=A9F9I8VAA
M9V4@<&]U<B!L97,@8F_N=&5S(&1E(&-O=7)R:65R(&5T(&QE<R!D;W-S:65R
M<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X"FUS9VED
M(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G<W1R
M(")-87)Q=65R('1O=7,@;&5S(&UE<W-A9V5S(&1U(&1O<W-I97(@8V]M;64@
M;'5S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G
M:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS
M9W-T<B`B36%R<75E<B!T;W5S(&QE<R!M97-S86=E<R!D=2!D;W-S:65R(&-O
M;6UE(&YO;BUL=7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C4@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,`IM
M<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`B36%R<75E<B!C;VUM9:`Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8S.`IM<V=I9"`B36%R:R!D:69F97)E
M;G0@;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/R(*
M;7-G<W1R(")$:7-T:6YG=65R(&QE<R!N:79E875X(&1E(&-I=&%T:6]N<R!P
M87(@9&5S(&-O=6QE=7)S(&1I9F;I<F5N=&5SH#\B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G97,@
M87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS9W-T<B`B36%R<75E<B!L97,@;65S
M<V%G97,@8V]M;64@;'5SH#\@*$E-05`@<V5U;&5M96YT*2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-#8*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU
M<#\B"FUS9W-T<B`B36%R<75E<B!A=F5C('5N92#I=&EQ=65T=&4@<VEM<&QE
MH#\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@
M(DUA=&-H($%L;"!1=65R:65S(@IM<V=S='(@(D-O<G)E<W!O;F0@X"!T;W5T
M97,@;&5S(')E<77J=&5S(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N
M:6YC.C0R"FUS9VED(")-871C:"!!;GD@475E<GDB"FUS9W-T<B`B0V]R<F5S
M<&]N9"#@(&XG:6UP;W)T92!Q=65L;&4@9&5S(')E<77J=&5S(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`T"FUS9VED(")-87AI;75M
M($%T=&%C:&UE;G0@4VEZ92(*;7-G<W1R(")486EL;&4@;6%X:6UA;&4@9&4@
M;&$@<&GH8V4@:F]I;G1E(@H*(SH@;&EB+V%P:2YP:'`Z-SD*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B"FUS9W-T<B`B3F]M8G)E(&UA>&EM
M86P@9&4@9&]S<VEE<G,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT.#8*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S
M(')E86-H960N(@IM<V=S='(@(DYO;6)R92!M87AI;6%L(&1E('!IZ&-E<R!J
M;VEN=&5S(&%T=&5I;G0N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#@R"FUS9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ
M92!R96%C:&5D+B(*;7-G<W1R(")486EL;&4@;6%X:6UA;&4@=&]T86QE(&1E
M<R!P:>AC97,@:F]I;G1E<R!A='1E:6YT92XB"@HC.B!L:6(O0FQO8VLO=')E
M95]F;VQD97)S+G!H<#HS"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S
M='(@(DUE;G4@;&ES=&4@9&4@9&]S<VEE<G,B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S0R"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE<W-A9V4B"@HC.B!C
M;VUP;W-E+G!H<#HU.38@8V]M<&]S92YP:'`Z-C(S(&-O;7!O<V4N<&AP.C8W
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M
M<&]S:71I;VXB"FUS9W-T<B`B4NED86-T:6]N(&1E(&UE<W-A9V4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`U"FUS9VED(")-97-S86=E($1A=&4B
M"FUS9W-T<B`B1&%T92!D=2!M97-S86=E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`S"FUS9VED(")-97-S86=E($]P=&EO;G,B"FUS9W-T<B`B3W!T:6]N<R!D
M=2!M97-S86=E(@H*(SH@<V5A<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@
M4V5A<F-H(@IM<V=S='(@(E)E8VAE<F-H97(@=6X@;65S<V%G92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#D*;7-G:60@(DUE<W-A9V4@4VEZ92(*
M;7-G<W1R(")486EL;&4@9'4@;65S<V%G92(*"B,Z(&UE<W-A9V4N<&AP.C,X
M-`IM<V=I9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`B4V]U<F-E(&1U(&UE
M<W-A9V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(DUE
M<W-A9V4@5FEE=VEN9R(*;7-G<W1R(")#;VYS=6QT871I;VX@9'4@;65S<V%G
M92(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-@IM<V=I9"`B365S
M<V%G92!F;&%G<R(*;7-G<W1R("+)=&EQ=65T=&5S(&1U(&UE<W-A9V4B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E
M(&9O;&1E<G,B"FUS9W-T<B`B1&]S<VEE<G,@9'4@;65S<V%G92(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B365S<V%G
M92!F<F]M("5S(@IM<V=S='(@(DUE<W-A9V4@9&4@)7,B"@HC.B!M86EL8F]X
M+G!H<#HV-34*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C:&UE;G1S(@IM<V=S
M='(@(DQE(&UE<W-A9V4@82!D97,@<&GH8V5S(&IO:6YT97,B"@HC.B!M86EL
M8F]X+G!H<#HV-#8*;7-G:60@(DUE<W-A9V4@:7,@96YC<GEP=&5D(@IM<V=S
M='(@(DQE(&UE<W-A9V4@97-T(&-H:69F<NDB"@HC.B!M86EL8F]X+G!H<#HV
M-#$*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(DQE(&UE<W-A
M9V4@97-T('-I9V[I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC
M.C,S"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS9W-T<B`B3&4@;65S<V%G
M92!C;W)R97-P;VYD(@H*(SH@8V]M<&]S92YP:'`Z.#8R(&-O;7!O<V4N<&AP
M.C@V.0IM<V=I9"`B365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B3&4@;65S<V%G92!A(&)I96X@Z73I(')E9&ER:6?I+B(*"B,Z
M(&-O;7!O<V4N<&AP.C$Q,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B365S<V%G
M92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<R(*;7-G
M<W1R(")-97-S86=E(&)I96X@96YV;WGI+"!M86ES(&YO;B!E;G)E9VES='+I
M(&1A;G,@)7,B"@HC.B!C;VUP;W-E+G!H<#HQ,3<S(&-O;7!O<V4N<&AP.C$Q
M.#$*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(DQE(&UE<W-A9V4@82!B:65N(.ETZ2!E;G9O>>DN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR.0IM<V=I9"`B365S<V%G97,@<&5R('!A9V4@:6X@
M=&AE(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`B365S<V%G97,@<&%R('!A9V4@
M;&]R<R!D92!L)V%F9FEC:&%G92!D92!L82!B;^YT92XB"@HC.B!M86EL8F]X
M+G!H<#HS,#@*;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S='(@(DUE<W-A9V5S
M(.`B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,CD*;7-G:60@(DUO9&EF
M>2(*;7-G<W1R(")-;V1I9FEE<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X
M<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!T:&%N(&]N
M92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N(@IM<V=S='(@(E!L
M=7-I975R<R!A9')E<W-E<R!C;W)R97-P;VYD96YT(&%U(&-H86UP(*N@)7.@
MNRXB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO
M=F4B"FUS9W-T<B`B1.EP;&%C97(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,38*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")6
M97)S(&QE(&)A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#8*;7-G
M:60@(DUO=F4@<W!A;2!M97-S86=E<R!T;R!S<&%M(&9O;&1E<B!A;F0@:6YN
M;V-E;G0@;65S<V%G97,@=&\@24Y"3U@B"FUS9W-T<B`B(@HB1.EP;&%C97(@
M;&5S('!O=7)R:65L<R!V97)S(&QE(&1O<W-I97(@9&4@<W!A;2!E="!L97,@
M;65S<V%G97,@;.EG:71I;65S("(*(G9E<G,@;&$@8F_N=&4@9&4@<NEC97!T
M:6]N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-
M;W9E('1O(&9O;&1E<B(*;7-G<W1R(")697)S(&QE(&1O<W-I97(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,30*;7-G:60@(DUO
M=F4@=7`B"FUS9W-T<B`B5F5R<R!L92!H875T(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E
M<FYA=&EV92(*;7-G<W1R(")-=6QT:7!A<G0O06QT97)N871I=F4B"@HC.B!T
M:')E860N<&AP.C<V('1H<F5A9"YP:'`Z,34Q"FUS9VED(")-=6QT:7!L92!-
M97-S86=E(%9I97<B"FUS9W-T<B`B069F:6-H86=E(&1E<R!M97-S86=E<R!M
M=6QT:7!L97,B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E
M;&5C="YI;F,Z-0IM<V=I9"`B3D].12(*;7-G<W1R(")!54-53B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-#@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G
M:60@(DY/5$4B"FUS9W-T<B`B3D]412(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M.#,*;7-G:60@(DYA;64B"FUS9W-T<B`B3F]M(@H*(SH@<&=P+G!H<#HQ,#8*
M;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;FYO="!B92!E;7!T>2(*;7-G
M<W1R("),92!N;VT@970O;W4@;"=A9')E<W-E(&YE('!E=79E;G0@<&%S(.IT
M<F4@=FED97,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<Q"FUS
M9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`B071T96YT92!D)V%C=&EO;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S`@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<V-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B2F%M86ES(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`IM<V=I9"`B3F5V97(@<V%V92!A
M='1A8VAM96YT<R(*;7-G<W1R(").92!J86UA:7,@96YR96=I<W1R97(@;&5S
M('!IZ&-E<R!J;VEN=&5S(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R
M-`IM<V=I9"`B3F5W(@IM<V=S='(@(DYO=79E874B"@HC.B!L:6(O24U0+G!H
M<#HU-S0*;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T<B`B3F]U=F5A=2!D;W-S
M:65R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@
M36%I;"(*;7-G<W1R(").;W5V96%U(&-O=7)R:65R(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(Q(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR,@HC.B!L
M:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS-PIM<V=I9"`B3F5W($UE<W-A
M9V4B"FUS9W-T<B`B3F]U=F5A=2!M97-S86=E(@H*(SH@;6%I;&)O>"YP:'`Z
M-S8S(&QI8B]-24U%+TAE861E<G,N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R(").;W5V96%U(&UE<W-A
M9V4@<&]U<B`E<R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3D*
M;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R(").;W5V96%U>"!M97-S86=E
M<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B4W5I=F%N="(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G
M92(*;7-G<W1R(")-97-S86=E('-U:79A;G0B"@HC.B!M86EL8F]X+G!H<#HS
M,S@*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(")086=E('-U:79A;G1E(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,W('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4U,`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.38U"FUS9VED(").;R(*;7-G<W1R(").;VXB"@HC.B!S;6EM92YP
M:'`Z,C(R"FUS9VED(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R(")!
M=6-U;B!C97)T:69I8V%T('1R;W5VZ2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO;B(*;7-G
M<W1R(")!=6-U;B!C:&EF9G)E;65N="(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I;B!+97ER:6YG(@IM<V=S='(@(D%U
M8W5N92!C;&5F(&1A;G,@;"=A;FYE874B"@HC.B!M86EL8F]X+G!H<#HS-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B"FUS9W-T<B`B4&%S
M(&1E(&UE<W-A9V5S(@H*(SH@<&=P+G!H<#HQ,S,*;7-G:60@(DYO(%!'4"!P
M=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(")!=6-U;F4@8VQE9B!P=6)L
M:7%U92!01U`@;B=A(.ETZ2!I;7!O<G3I92XB"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S;VYA;"!#97)T:69I8V%T
M92!0<F5S96YT(@IM<V=S='(@(E!A<R!D92!C97)T:69I8V%T('!E<G-O;FYE
M;"!P<NES96YT(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,S-@IM<V=I9"`B3F\@
M4')E=FEE=R!497AT(@IM<V=S='(@(E!A<R!D92!P<NDM=FES=6%L:7-A=&EO
M;B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G:60@(DYO
M(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(D%U8W5N92!C;&5F('!U8FQI
M<75E('1R;W5VZ64B"@HC.B!S;6EM92YP:'`Z,30W"FUS9VED(").;R!3+TU)
M344@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B075C=6YE(&-L968@
M<'5B;&EQ=64@4R]-24U%(&EM<&]R=.EE+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]T;F5F+G!H<#HY,@IM<V=I9"`B3F\@871T86-H;65N=',@9F]U;F0N(@IM
M<V=S='(@(D%U8W5N92!P:>AC92!J;VEN=&4@=')O=7;I92XB"@HC.B!L:6(O
M0W)Y<'0O4TU)344N<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I
M;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B075C=6YE
M(&EN9F]R;6%T:6]N('-U<B!L)V%D<F5S<V4@9&%N<R!L82!C;&5F('!U8FQI
M<75E+B(*"B,Z(&%C;"YP:'`Z-S$@86-L+G!H<#HY-PIM<V=I9"`B3F\@9F]L
M9&5R('-E;&5C=&5D+B(*;7-G<W1R(")!=6-U;B!D;W-S:65R(&XG82#I=.D@
M<^EL96-T:6]N;NDN(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T-@IM
M<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA
M:6PN(@IM<V=S='(@(D%U8W5N(&1O<W-I97(@;B=E<W0@=NER:69IZ2!P;W5R
M(&QE<R!N;W5V96%U>"!M97-S86=E<RXB"@HC.B!F;VQD97)S+G!H<#HQ.3<@
M;&EB+T9O;&1E<BYP:'`Z-3`X(&QI8B]&;VQD97(N<&AP.C4U.`IM<V=I9"`B
M3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9"(*;7-G<W1R(")!=6-U;B!D;W-S
M:65R('-PZ6-I9FGI(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$U,@IM
M<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<R(*;7-G<W1R(")!
M=6-U;B!D;W-S:65R(&%V96,@9&4@;F]U=F5A=7@@;65S<V%G97,B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30Y"FUS9VED(").;R!F;VQD97)S('=I
M=&@@=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(D%U8W5N(&1O<W-I97(@879E
M8R!D97,@;65S<V%G97,@;F]N+6QU<R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M,S8*;7-G:60@(DYO(&UE<W-A9V4@8F]D>2!T97AT(@IM<V=S='(@(E!A<R!D
M92!T97AT92!D86YS(&QE(&-O<G!S(&1U(&UE<W-A9V4B"@HC.B!L:6(O36%I
M;&)O>"YP:'`Z,S@P"FUS9VED(").;R!M97-S86=E<R!M871C:&5D('EO=7(@
M<V5A<F-H+B(*;7-G<W1R(")!=6-U;B!M97-S86=E(&YE(&-O<G)E<W!O;F0@
MX"!V;W1R92!R96-H97)C:&4N(@H*(SH@<&=P+G!H<#HQ.#4*;7-G:60@(DYO
M('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B
M075C=6YE(&-L968@<')I=NEE(%!'4"!N)V$@Z73I(&EM<&]R=.EE+B(*"B,Z
M('!G<"YP:'`Z,38Q"FUS9VED(").;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME
M>2!I;7!O<G1E9"XB"FUS9W-T<B`B075C=6YE(&-L968@<'5B;&EQ=64@4$=0
M(&XG82#I=.D@:6UP;W)TZ64N(@H*(SH@<VUI;64N<&AP.C$Y-PIM<V=I9"`B
M3F\@<&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS
M9W-T<B`B075C=6X@8V5R=&EF:6-A="!P97)S;VYN96P@4R]-24U%(&EM<&]R
M=.DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#8@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,CDY"FUS9VED("(B"B).;R!P97)S;VYA;"!P
M<FEV871E(&ME>2!E>&ES=',@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O
M(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB26P@;B=E>&ES=&4@875C=6YE
M(&-L968@<')I=NEE+"!E="!L92!M97-S86=E(&YE('!E=70@9&]N8R!P87,@
MZG1R92`B"B)DZ6-H:69F<NDN(@H*(SH@<W!E;&QI;F<N<&AP.C(R,`IM<V=I
M9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N(@IM<V=S
M='(@(D%U8W5N(';I<FEF:6-A=&5U<B!D)V]R=&AO9W)A<&AE(&-O;F9I9W5R
MZ2XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G
M:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(")!=6-U;F4@97)R975R
M(&0G;W)T:&]G<F%P:&4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G<W1R(")!=6-U
M;F4@<W5G9V5S=&EO;B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3<P"FUS
M9VED(").;R!S=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@
M8V]U;&0@8F4@9F]U;F0N(@IM<V=S='(@(D%U8W5N92!MZ71H;V1E(&0G875T
M:&5N=&EF:6-A=&EO;B!)34%0('-U<'!O<G3I92!N)V$@Z73I('1R;W5VZ64N
M(@H*(SH@86-L+G!H<#HV-R!A8VPN<&AP.CDS"FUS9VED(").;R!U<V5R('-P
M96-I9FEE9"XB"FUS9W-T<B`B075C=6X@=71I;&ES871E=7(@<W#I8VEF:>DN
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P-`IM<V=I9"`B3F]N
M(%!A<G1I8VEP86YT(@IM<V=S='(@(DYO;BUP87)T:6-I<&%N="(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@=&5M<&QA=&5S+W!R969S
M+V9O;&1E<G-E;&5C="YI;F,Z,C0*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M
M86EL<V5L96-T+FEN8SHT,"!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHS-0HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0@
M=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR-`HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C8Q"FUS9VED(").;VYE(@IM<V=S='(@(D%U
M8W5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDU"FUS
M9VED(").;W)M86PB"FUS9W-T<B`B3F]R;6%L(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,Y"FUS9VED(").;W0@1&5L971E9"(*;7-G<W1R(").;VX@<W5P<')I
M;>DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM
M<V=S='(@(DXG97-T('!A<R!U;B!B<F]U:6QL;VXB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,T"FUS9VED(").;W0@26UP;W)T86YT(@IM<V=S='(@(E!E=2!I;7!O
M<G1A;G0B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS
M9VED(").;W0@4&5R<V]N86PB"FUS9W-T<B`B3F]N('!E<G-O;FYE;"(*"B,Z
M(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S
M-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@
M<'5B;&EC(&ME>2XB"FUS9W-T<B`B0VQE9B!P=6)L:7%U92!I;G9A;&ED92XB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED(").;W0@
M9&5L971E9"!M97-S86=E<R(*;7-G<W1R(")-97-S86=E<R!N;VXM<W5P<')I
M;>ES(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B
M3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(")-97-S86=E<R!P974@
M:6UP;W)T86YT<R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I
M;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME
M('-O;64@=&EM92(*;7-G<W1R(").;W1E>B!Q=64@8V5L82!P975T('!R96YD
M<F4@=6X@8V5R=&%I;B!T96UP<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,#0*;7-G:60@(DYO=&AI;F<B"FUS9W-T<B`B4FEE;B(*"B,Z(&%T=&%C
M:&UE;G0N<&AP.C@Y"FUS9VED(").;W1I9FEC871I;VXZ($QI;FME9"!A='1A
M8VAM96YT(&1O=VYL;V%D960B"FUS9W-T<B`B3F]T:69I8V%T:6]NH#H@;&5S
M('!IZ&-E<R!J;VEN=&5S(&QIZ65S(&]N="#I=.D@=.ELZ6-H87)GZ65S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B3G5M8F5R(&]F
M(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L
M971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB3F]M8G)E(&1E(&UO:7,@<&]U
M<B!G87)D97(@9&4@=FEE=7@@871T86-H96UE;G1S(&QIZ7,@<VD@<W5P<')I
M;>ES("(*(FUE;G-U96QL96UE;G0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,U.0IM<V=I9"`B3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(DYO
M;6)R92!D92!D;W-S:65R<R!D92!M97-S86=E<R!E;G9O>>ES(.`@9V%R9&5R
M(',G:6QS('-O;G0@969F86/I<R`B"B)M96YS=65L;&5M96YT+B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T"FUS9VED(")/2R(*
M;7-G<W1R(")/2R(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.0HC.B!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*;7-G<W1R(")/
M52(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,34*;7-G:60@(D]L
M9"!M97-S86=E<R(*;7-G<W1R(")!;F-I96YS(&UE<W-A9V5S(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP
M.C4R"FUS9VED(")/;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D
M+B(*;7-G<W1R("),97,@9&]S<VEE<G,@9"=A;F-I96YS(&UE<W-A9V5S(&5N
M=F]YZ7,@<V]N="!E;B!C;W5R<R!D)V5F9F%C96UE;G0N(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C(X"FUS9VED(")/;FQY(&1I<W!L87D@9F]L9&5R
M<R!W:71H('5N<F5A9"!M97-S86=E<R!I;B!T:&5M/R(*;7-G<W1R(")!9F9I
M8VAE<B!L97,@9&]S<VEE<G,@879E8R!D97,@;65S<V%G97,@;F]N+6QU<R!S
M975L96UE;G2@/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z-SD*;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T
M960@9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R(")6;W5S(&YE('!O=79E>B!S
MZ6QE8W1I;VYN97(@<74G=6X@<V5U;"!D;W-S:65R('!O=7(@8V5T=&4@86-T
M:6]N+B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ,"!T96UP;&%T97,O;65N
M=2YI;F,Z,S`*;7-G:60@(D]P96X@1F]?;&1E<B(*;7-G<W1R(")/=79R:7(@
M7VQE(&1O<W-I97(B"@HC.B!F;VQD97)S+G!H<#HT,#8*;7-G:60@(D]P96YE
M9"!&;VQD97(B"FUS9W-T<B`B1&]S<VEE<B!O=79E<G0B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S`P"FUS9VED(")/<'1I;VYA;"!087)T:6-I
M<&%N="(*;7-G<W1R(")087)T:6-I<&%N="!F86-U;'1A=&EF(@H*(SH@9F5T
M8VAM86EL+G!H<#HT,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC
M.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B
M3W1H97(@36%I;"!!8V-O=6YT<R(*;7-G<W1R(")!=71R97,@8V]M<'1E<R!D
M92!C;W5R<FEE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS
M9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D%U=')E<R!O<'1I;VYS(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#`*;7-G:60@(D]U=&)O
M=6YD(%-E<G9E<B(*;7-G<W1R(")397)V975R(&1I<W1A;G0B"@HC.B!T96UP
M;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C$V-`HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#,@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,C@Y"FUS9VED(")01U`B"FUS9W-T<B`B
M4$=0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHW
M"FUS9VED(")01U`@16YC<GEP="!-97-S86=E(@IM<V=S='(@(D-H:69F<F5R
M(&QE(&UE<W-A9V4@879E8R!01U`B"@HC.B!C;VUP;W-E+G!H<#HS,S4*;7-G
M:60@(E!'4"!%<G)O<CH@(@IM<V=S='(@(D5R<F5U<B!01U"@.B`B"@HC.B!C
M;VUP;W-E+G!H<#HS,30*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR
M87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@HB17)R
M975R(%!'4*`Z(&QA('!H<F%S92!S96-RZ'1E(&5S="!NZ6-E<W-A:7)E('!O
M=7(@;&$@8VQE9B!P<FEVZ64@(@HB<&5R<V]N;F5L;&4N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T
M<B`B3W!T:6]N<R!D92!01U`B"@HC.B!P9W`N<&AP.C,P"FUS9VED(")01U`@
M4&%S<W!H<F%S92!);G!U="(*;7-G<W1R(")%;G1RZ64@9&4@;&$@<&AR87-E
M('-E8W+H=&4@4$=0(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4U"FUS
M9VED(")01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B),92!S=7!P;W)T
M(&1E(&QA('!A:7)E(&1E(&-L969S('!E<G-O;FYE;&QE<R!R97%U:65R="!U
M;F4@8V]N;F5X:6]N(&%U('=E8B`B"B)SZ6-U<FESZ64N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,3<R"FUS9VED(")01U`@4'5B;&EC($ME>2!4
M97AT(@IM<V=S='(@(E1E>'1E(&1E(&QA(&-LZ2!P=6)L:7%U92!01U`B"@HC
M.B!P9W`N<&AP.C$T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC
M($ME>2!F;W(@7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB
M"FUS9W-T<B`B3&$@8VQE9B!P=6)L:7%U92!01U`@9&4@JZ`E<R`H)7,IH+L@
M82!B:65N(.ETZ2!A:F]U=.EE+B(*"B,Z('!G<"YP:'`Z,C0Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U
M8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("),82!C;&5F('!U8FQI<75E
M(%!'4"!D92"KH"5SH+L@82!B:65N(.ETZ2!S=7!P<FEMZ64N(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I
M;F<B"FUS9W-T<B`B06YN96%U(&1E(&-L969S('!U8FQI<75E<R!01U`B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*;7-G:60@
M(E!'4"!3:6=N($UE<W-A9V4B"FUS9W-T<B`B4VEG;F5R(&QE(&UE<W-A9V4@
M879E8R!01U`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N
M:6YC.CD*;7-G:60@(E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R
M(")3:6=N97(O8VAI9F9R97(@;&4@;65S<V%G92!A=F5C(%!'4"(*"B,Z('!G
M<"YP:'`Z,3DX"FUS9VED(")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY
M(&%D9&5D+B(*;7-G<W1R("),82!C;&5F(%!'4"!P<FEVZ64@82!B:65N(.ET
MZ2!A:F]U=.EE+B(*"B,Z('!G<"YP:'`Z,3<S"FUS9VED(")01U`@<'5B;&EC
M(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(DQA(&-L968@4$=0
M('!U8FQI<75E(&$@8FEE;B#I=.D@86IO=73I92XB"@HC.B!T96UP;&%T97,O
M<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4$=0('-U<'!O<G0@:7,@9&ES
M86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(DQE('-U<'!O<G0@9&4@
M4$=0(&5S="!DZ7-A8W1I=ND@<W5R(&-E('-Y<W3H;64N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,C`W"FUS9VED("(B"B)01U`@<W5P<&]R="!I
M<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U
M<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B),
M92!S=7!P;W)T(&1E(%!'4"!N)V5S="!P87,@86-T:68@86-T=65L;&5M96YT
M+"!E="!L82!S:6=N871U<F4@;G5MZ7)I<75E("(*(FXG82!D;VYC('!A<R#I
M=.D@=NER:69IZ64N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDT
M"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV
M92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*
M;7-G<W1R("(B"B),92!S=7!P;W)T(&1E(%!'4"!N)V5S="!P87,@86-T:68@
M86-T=65L;&5M96YT+"!E="!L92!M97-S86=E(&YE('!E=70@9&]N8R`B"B)P
M87,@ZG1R92!DZ6-H:69F<NDN(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C(*;7-G:60@(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O
M=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@
M(@HB<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA
M;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H92!01U`@(@HB9F5A='5R97,@
M=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(E!'4"!U=&EL
M:7-E(&1E<R!F96[J=')E<R!S=7)G:7-S86YT97,N(%-I(&-E='1E(&9O;F-T
M:6]N(&5S="!DZ7-A8W1I=NEE(&1A;G,@(@HB=F]T<F4@;F%V:6=A=&5U<BP@
M:6P@9F%U="!L)V%C=&EV97(L('-A;G,@<75O:2!01U`@;F4@9F]N8W1I;VYN
M97)A('!A<R`B"B)C;W)R96-T96UE;G0N(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B"FUS9W-T<B`B4$]0,R(*"B,Z(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`P"FUS9VED(")03U`S("A!=71O($1E
M=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(E!/4#,@*&3I=&5C=&5R(&%U=&]M
M871I<75E;65N="!L97,@<')O=&]C;VQE<RDB"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R(")0
M3U`S('-U<B!34TPB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM
M<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I
M(@IM<V=S='(@(E!/4#,@<W5R(%-33"`H8V5R=&EF:6-A="!M86ES;VXI("(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38X"FUS9VED(")03U`S
M(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B4$]0,R!S=7(@4U-,
M("AC97)T:69I8V%T(&UA:7-O;BDB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$Q,0IM<V=I9"`B4$]0,RP@;F\@5$Q3(@IM<V=S='(@(E!/4#,L('-A
M;G,@5$Q3(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHR,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")086=E("5D(&]F("5D(@IM<V=S='(@(E!A
M9V4@)60@9&4@)60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DQ"FUS
M9VED(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E(@IM<V=S
M='(@(E!A9V4@879E8R!L92!P<F5M:65R(&UE<W-A9V4@;F]N(&QU(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y,@IM<V=I9"`B4&%G92!W:71H('1H
M92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(E!A9V4@879E8R!L92!D
M97)N:65R(&UE<W-A9V4@;F]N(&QU(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`B4&%R=&EE
M*',I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R,PIM<V=I9"`B4&%S
M<W!H<F%S92(*;7-G<W1R(")0:')A<V4@<V5C<NAT92(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@*$%G86EN*2(*
M;7-G<W1R(")0:')A<V4@<V5C<NAT92`HX"!N;W5V96%U*2(*"B,Z('-M:6UE
M+G!H<#HR,S$@<&=P+G!H<#HS,#8*;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S
M<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R("),82!P:')A<V4@<V5C<NAT92!A
M(&)I96X@Z73I(&3I8VAA<F?I92XB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S
M<W!H<F%S92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHR
M.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`B4&AR87-E('-E8W+H=&6@
M.B(*"B,Z('!G<"YP:'`Z,3`X"FUS9VED(")087-S<&AR87-E<R!C86YN;W0@
M8F4@96UP='DB"FUS9W-T<B`B3&$@<&AR87-E('-E8W+H=&4@;F4@9&]I="!P
M87,@ZG1R92!V:61E(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(E!A<W-P:')A
M<V5S(&1O(&YO="!M871C:"(*;7-G<W1R("),97,@<&AR87-E<R!S96-RZ'1E
M<R!D:69FZ')E;G0B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z-S$@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3$*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R(")-;W0@9&4@<&%S<V4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B17CI8W5T:6]N(&1E<R!O<.ER
M871I;VYS(&1E(&UA:6YT96YA;F-E(.`@;&$@8V]N;F5X:6]NH#\B"@HC.B!A
M8VPN<&AP.C<U(&%C;"YP:'`Z,3`Q"FUS9VED(")097)M:7-S:6]N<R!F;W(@
M=&AI<R!U<V5R(&-A;FYO="!B92!C:&%N9V5D+B(*;7-G<W1R(")-;V1I9FEC
M871I;VX@:6UP;W-S:6)L92!D97,@<&5R;6ES<VEO;G,@9&4@8V5T('5T:6QI
M<V%T975R+B(*"B,Z(&UE<W-A9V4N<&AP.C0X-B!M86EL8F]X+G!H<#HV.3`@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R
M(")097)S;VYN96PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D1O;F[I97,@<&5R
M<V]N;F5L;&5S(@H*(SH@<&=P+G!H<#HQ,38*;7-G:60@(E!E<G-O;F%L(%!'
M4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E9O
M=')E('!A:7)E(&1E(&-L969S(%!'4"!P97)S;VYN96QL92!A(&)I96X@Z73I
M(&?I;NERZ64N(@H*(SH@<&=P+G!H<#HQ,C,*;7-G:60@(E!E<G-O;F%L(%!'
M4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")6;W,@8VQE
M9G,@4$=0('!E<G-O;FYE;&QE<R!O;G0@8FEE;B#I=.D@969F86/I97,N(@H*
M(SH@<VUI;64N<&AP.C(P,PIM<V=I9"`B4&5R<V]N86P@4R]-24U%(&-E<G1I
M9FEC871E<R!.3U0@:6UP;W)T960Z("(*;7-G<W1R(")#97)T:69I8V%T<R!P
M97)S;VYN96QS(%,O34E-12!.3TX@:6UP;W)TZ7.@.B`B"@HC.B!S;6EM92YP
M:'`Z,3(X"FUS9VED(")097)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B5F]S(&-L969S(%,O34E-12!P97)S;VYN
M96QL97,@;VYT(&)I96X@Z73I(&5F9F%CZ65S+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L86-E('EO=7(@<VEG;F%T=7)E(&)E
M9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\B"FUS9W-T<B`B4&QA8V5R('9O
M=')E('-I9VYA='5R92!A=2!DZ6)U="!D97,@<NEP;VYS97,@970@9&5S('1R
M86YS9F5R='.@/R(*"B,Z(&-O;7!O<V4N<&AP.C(U.`IM<V=I9"`B4&QA:6YT
M97AT(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R(")697)S:6]N('1E>'1E
M(&)R=70@9'4@;65S<V%G92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.#<*;7-G:60@(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E
M<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D("(*(G-O
M=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L
M(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@<&QU9VEN
M+B(*;7-G<W1R("(B"B).;W1I9FEC871I;VX@<V]N;W)E(&1E(&-O=7)R:65R
MH#\@0V5L82!S=7!P;W-E('%U92!V;W1R92!N879I9V%T975R('-U<'!O<G1E
M("(*(FPG:6YC;W)P;W)A=&EO;B!D92!F:6-H:65R<R!S;VYS+B!#)V5S="!L
M92!C87,@9&4@;&$@<&QU<&%R="!S;W5S(%=I;F1O=W,@;W4@(@HB36%C+"!M
M86ES('-U<B!D)V%U=')E<R!P;&%T97,M9F]R;65S('5N92!E>'1E;G-I;VX@
M<&5U="#J=')E(&[I8V5S<V%I<F4N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,3DR"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&9O;&1E<CHB"FUS9W-T<B`B5F5U:6QL97H@96YT<F5R('5N(&YO;2!P
M;W5R(&QE(&YO=79E874@9&]S<VEE<J`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9F]L9&5R<RYJ<SHQ,#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ,#0*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T
M:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B5F5U:6QL97H@96YT<F5R(&QE(&YO
M;2!D=2!N;W5V96%U(&1O<W-I97*@.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3,W"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YE
M=R!N86UE.B(*;7-G<W1R(")6975I;&QE>B!E;G1R97(@;&4@;F]U=F5A=2!N
M;VV@.B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N
M965D('1O("(*(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S
M97-S:6]N+B(*;7-G<W1R("(B"B)6975I;&QE>B!E;G1R97(@;&$@<&AR87-E
M('-E8W+H=&4@<&]U<B!V;W1R92!C;&5F(%!'4"!P<FEVZ64N($EL(&YE(&9A
M=61R82`B"B)E;G1R97(@8V5T=&4@<&AR87-E('-E8W+H=&4@<74G=6YE('-E
M=6QE(&9O:7,@<&%R('-E<W-I;VX@)7,N(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L
M96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I
M=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES
M('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HB
M5F5U:6QL97H@96YT<F5R(&QA('!H<F%S92!S96-RZ'1E('!O=7(@=F]T<F4@
M8VQE9B!3+TU)344@<')I=NEE+B!);"!N92`B"B)F875D<F$@96YT<F5R(&-E
M='1E('!H<F%S92!S96-RZ'1E('%U)W5N92!S975L92!F;VES('!A<B!S97-S
M:6]N("5S+B(*"B,Z(')E8V]M<&]S92YP:'`Z.38*;7-G:60@(B(*(E!L96%S
M92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A
M9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI97,@04Y$('EO=2!A
M<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I;F1O=W,L('EO=2!W
M:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD
M;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C:V5R<R!F<F]M("(*
M(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@
M86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@(B(*(E9E=6EL;&5Z('9O=7,@
M<F5C;VYN96-T97(@<&]U<B!P;W5R<W5I=G)E(&QA('+I9&%C=&EO;B!D92!V
M;W1R92!M97-S86=E+B!3:2`B"B)V;W5S(&XG=71I;&ES97H@4$%3(&QE<R!C
M;V]K:65S($54('-I('9O=7,@<NED:6=E>B!L97,@;65S<V%G97,@9&%N<R!U
M;F4@(@HB9F5NZG1R92#@('!A<G0L('9O=7,@9&5V<F5Z(&%U<W-I('9O=7,@
M<F5C;VYN96-T97(@9&%N<R!V;W1R92!F96[J=')E("(*(G!R:6YC:7!A;&4N
M($-E8VD@<&5R;65T(&0G96UPZF-H97(@;"=U=&EL:7-A=&EO;B!D92!V;W1R
M92!I9&5N=&EF:6%N="!D92`B"B)S97-S:6]N('!A<B!D)^EV96YT=65L<R!I
M;G1R=7,L(&5T(&YE('!E=70@<&%S(.IT<F4@Z79I=.DN(%9E=6EL;&5Z(&YO
M=7,@(@HB97AC=7-E<B!D92!C92!DZ7-A9W+I;65N="X@(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHW,0IM<V=I9"`B4&QE87-E('!R;W9I9&4@
M>6]U<B!P87-S=V]R9"XB"FUS9W-T<B`B5F5U:6QL97H@<V%I<VER('9O=')E
M(&UO="!D92!P87-S92XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C8W"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE+B(*;7-G
M<W1R(")6975I;&QE>B!S86ES:7(@=F]T<F4@;F]M(&0G=71I;&ES871E=7(N
M(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])35`N<&AP.C0W,`IM<V=I9"`B
M4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S
M+B(*;7-G<W1R(")6975I;&QE>B!C;W)R:6=E<B!L97,@861R97-S97,@86UB
M:6=UZW,@;W4@:6YV86QI9&5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z-C$*;7-G:60@(E!L96%S92!S96QE8W0@82!F;VQD97(@
M8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS+B(*;7-G<W1R(")6975I
M;&QE>B!SZ6QE8W1I;VYN97(@=6X@9&]S<VEE<B!A=F%N="!D)V%C8V]M<&QI
M<B!U;F4@86-T:6]N+B(*"B,Z('1E;7!L871E<R]S96%R8V@O:F%V87-C<FEP
M="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O
M;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(E9E=6EL;&5Z('/I;&5C=&EO;FYE
M<B!A=2!M;VEN<R!U;B!D;W-S:65R(&1E(')E8VAE<F-H92XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS9VED(")0;&5A<V4@
M<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN(@IM
M<V=S='(@(E9E=6EL;&5Z('/I;&5C=&EO;FYE<B!U;B!D;W-S:65R('5N:7%U
M92!P;W5R(&-E='1E(&]PZ7)A=&EO;BXB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z-S,*;7-G:60@(E!L96%S92!S96QE8W0@;W(@961I
M="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T<B`B5F5U:6QL97H@
M<^EL96-T:6]N;F5R(&]U(.ED:71E<B!D86YS(&QA(&)O[G1E(.`@9')O:71E
MH#HB"@HC.B!C;VYF:6<O;6]T9"YP:'`N9&ES=#HT,0IM<V=I9"`B4&]W97)E
M9"!B>2!(;W)D92(*;7-G<W1R(")0<F]P=6QSZ2!P87(@2&]R9&4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$T"FUS9VED(")0<F5C961E('EO=7(@
M<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_(@IM<V=S='(@(D9A:7)E
M('!RZ6/I9&5R('9O=')E('-I9VYA='5R92!D92!T:7)E=',@*"<M+2`G*:`_
M(@H*(SH@<VUI;64N<&AP.C(S-R!P9W`N<&AP.C(U,R!F:6QT97)P<F5F<RYP
M:'`Z-#`*;7-G:60@(E!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D
M+B(*;7-G<W1R("),97,@<'+I9NER96YC97,@;VYT(&)I96X@Z73I(&UI<V5S
M(.`@:F]U<BXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI
M;F,Z,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")0<NDM=FES=6%L:7-A=&EO
M;B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,C@*;7-G:60@(E!R979I;W5S($UE<W-A9V4B"FUS9W-T<B`B365S<V%G92!P
M<NECZ61E;G0B"@HC.B!M86EL8F]X+G!H<#HS,CD*;7-G:60@(E!R979I;W5S
M(%!A9V4B"FUS9W-T<B`B4&%G92!P<NECZ61E;G1E(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")0<FEN="(*
M;7-G<W1R("));7!R:6UE<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E
M<G,N:6YC.C,X"FUS9VED(")0<FEO<FET>2(*;7-G<W1R(")0<FEO<FETZ2(*
M"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I9"`B
M4')I=F%T92!+97D@4&%S<W=O<F0B"FUS9W-T<B`B36]T(&1E('!A<W-E(&1E
M(&QA(&-L968@<')I=NEE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U
M.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S
M96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@(D1E;6%N9&5R(&-H87%U92!F
M;VES('%U)W5N92!P:>AC92!J;VEN=&4@97-T(&5N=F]YZ66@.R!.3TX@<&%R
M(&3I9F%U="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@
M(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F
M875L="!T;R!915,B"FUS9W-T<B`B1&5M86YD97(@8VAA<75E(&9O:7,@<74G
M=6YE('!IZ&-E(&IO:6YT92!E<W0@96YV;WGI9:`[($]522!P87(@9.EF875T
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED
M(")0<F]T;V-O;#HB"FUS9W-T<B`B4')O=&]C;VQEH#HB"@HC.B!L:6(O0W)Y
M<'0O4$=0+G!H<#HT,S`*;7-G:60@(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U
M<'!O<G0@:&%S(&)E96X@9&ES86)L960N(@IM<V=S='(@(DQE('-U<'!O<G0@
M9'4@<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@82#I=.D@9.ES86-T:7;I+B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I9"`B4'5R7V=E
M($1E;&5T960B"FUS9W-T<B`B4'5R7V=E(&5F9F5C='7I92(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I9"`B4'5R9V4@1&5L971E9"(*
M;7-G<W1R(")0=7)G97(@;&5S(.ELZ6UE;G1S(&5F9F%CZ7,B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-`IM<V=I9"`B4'5R9V4@1F]L
M9&5R*',I(@IM<V=S='(@(E9I9&5R(&QE*',I(&1O<W-I97(H<RDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"FUS9VED(")0=7)G92!4<F%S:"!H
M;W<@;V9T96XZ(@IM<V=S='(@(D9RZ7%U96YC92!D)V5F9F%C96UE;G0@9'4@
M8V]N=&5N=2!D92!L82!C;W)B96EL;&6@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O
M;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@
M(D5F9F%C97(@;&5S(&UE<W-A9V5S(&1E(&QA(&-O<F)E:6QL92!A=2!D96S@
M(&1E('1A;G0@9&4@:F]U<G,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-@IM<V=I9"`B4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F
M;VQD97(_(@IM<V=S='(@(D5F9F%C97(@;&5S(&%N8VEE;G,@;65S<V%G97,@
M9&4@;&$@8V]R8F5I;&QEH#\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P
M=7)G95]T<F%S:"YP:'`Z-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN
M9R`E9"!M97-S86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B169F
M86-E;65N="!D92`E9"!M97-S86=E(&1E(&QA(&-O<F)E:6QL92XB"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C,*;7-G:60@
M(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R
M(")%9F9A8V5M96YT(&1E(#$@;65S<V%G92!D92!L82!C;W)B96EL;&4N(@H*
M(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHQ-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E
M)2DB"FUS9W-T<B`BR71A="!D=2!Q=6]T8:`Z("4N,F:@36\@+R`E+C)FH$UO
M("`H)2XR9B4E*2(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.
M3R!,24U)5"(*;7-G<W1R("+)=&%T(&1U('%U;W1AH#H@)2XR9J!-;R`O875C
M=6YE(&QI;6ET92(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B!.3R!,24U)5"(*
M;7-G<W1R("+)=&%T(&1U('%U;W1AH#H@875C=6YE(&QI;6ET92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M475O=&EN9R`E9CHB"FUS9W-T<B`B)68@82#I8W)I=*`Z(@H*(SH@;&EB+U-E
M87)C:"YP:'`Z-3`*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@(E)EYW4@
M;&4@(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3@*;7-G:60@(E)E8V5I=F5D(%-I
M;F-E(@IM<V=S='(@(E)EYW4@9&5P=6ES(@H*(SH@;&EB+U-E87)C:"YP:'`Z
M-30*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM<V=S='(@(E)EYW4@9&5P=6ES
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B4F5D:7)I7V=E<B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B
M4F5D:7)E8W0B"FUS9W-T<B`B4F5D:7)I9V5R(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,`IM<V=I9"`B4F5D:7)E8W0@365S<V%G
M92(*;7-G<W1R(")2961I<FEG97(@;&4@;65S<V%G92(*"B,Z(&-O;7!O<V4N
M<&AP.C@R-0IM<V=I9"`B4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S='(@
M(E)E9&ER:6=E<B!C92!M97-S86=E(@H*(SH@8V]M<&]S92YP:'`Z.#<X"FUS
M9VED(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(DQA(')E9&ER96-T
M:6]N(&$@Z6-H;W7I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S(*
M;7-G:60@(E)E9G)E<V@@1F]L9&5R(%9I97=S.B(*;7-G<W1R(")2869R8>YC
M:&ER(&PG869F:6-H86=E(&1E<R!D;W-S:65R<Z`Z(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O:&5A9"YI;F,Z.2!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N
M:6YC.C0*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")2869R8>YC:&ER(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I
M97<B"FUS9W-T<B`B4F5C:&%R9V5R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED
M(")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M(")392!S;W5V96YI<B!D97,@9&ES<&]N:6)I;&ETZ7,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDV-PIM<V=I9"`B4F5M96UB97(@=&AE(&QA<W0@
M=FEE=R(*;7-G<W1R(")392!S;W5V96YI<B!D=2!D97)N:65R(&%F9FEC:&%G
M92(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PIM<V=I
M9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(D)O[G1E(&1I<W1A;G1EH#HB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E
M;6]V92!&:65L9"!&<F]M(%-E87)C:"(*;7-G<W1R(")%;FQE=F5R(&QE(&-H
M86UP(%)E8VAE<F-H92(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,P-0IM<V=I9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R(")2971I
M<F5R(&QA('-O=7)C92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C@*;7-G:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T<B`B4F5N;VUM
M97(@;&4H<RD@9&]S<VEE<BAS*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$*;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN
M;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B4F5N;VUM97(@;&4@9&]S<VEE<B!D
M97,@;65S<V%G97,@96YV;WGI<R!A=2!DZ6)U="!D=2!M;VESH#\B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI
M;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB3&4@8VAA;F=E;65N="!D92!N;VT@
M9&4@JZ`E<Z"[(&5N(*N@)7.@NR!A(.EC:&]UZ2X@3&4@<V5R=F5U<B!A('+I
M<&]N9'4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,3`*;7-G:60@(E)E<&Q?>2!T;R!,:7-T(@IM<V=S='(@(E+I<%]O;F1R
M92#@(&QA(&QI<W1E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G<W1R(")296UP;&%C
M97(@<&%RH#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`B4NEP;VYD<F4B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$R(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT,3`*;7-G:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@(E+I<&]N
M<V4@96YV;WGI92XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R(")2Z7!O
M;F1R92#@('1O=7,B"@HC.B!C;VUP;W-E+G!H<#HW-CD*;7-G:60@(E)E<&QY
M('1O($%L;#HB"FUS9W-T<B`B4NEP;VYD<F4@X"!T;W5SH#HB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G:60@(E)E
M<&QY('1O($QI<W0B"FUS9W-T<B`B4NEP;VYD<F4@X"!L82!L:7-T92(*"B,Z
M(&-O;7!O<V4N<&AP.C<W,0IM<V=I9"`B4F5P;'D@=&\@3&ES=#HB"FUS9W-T
M<B`B4NEP;VYD<F4@X"!L82!L:7-T9:`Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!?06QL
M(@IM<V=S='(@(E+I<&]N9')E(.`@7W1O=7,B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3,P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,SD*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T.0IM<V=I9"`B4F5P;'D@
M=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B4F5N=F]Y97(@
M=6X@;65S<V%G92"KH$YO;B!S=7!P;W)TZ:"[(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4S-PIM<V=I9"`B4F5P;'D@=VET:"!F<F5E+V)U<WD@
M9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(E+I<&]N9')E(&%V96,@;&5S
M(&1I<W!O;FEB:6QI=.ES(&1E<R`R('!R;V-H86EN<R!M;VES+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S8*;7-G:60@(E)E<&QY('=I=&@@
M<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B4NEP
M;VYD<F4@879E8R!L97,@9&ES<&]N:6)I;&ETZ7,@9&5M86YDZ65S+B(*"B,Z
M(&UE<W-A9V4N<&AP.C(V-PIM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`B4NEP
M;VYD<F4@X"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,C`*;7-G:60@(E)E<&QY
M+51O.B`B"FUS9W-T<B`B4NEP;VYD<F4@X*`Z("(*"B,Z(&-O;7!O<V4N<&AP
M.C<V-PIM<V=I9"`B4F5P;'DZ(@IM<V=S='(@(E+I<&]N9')EH#HB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S@@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C8*;7-G:60@(E)E<&]R="!A<R!)
M;FYO8V5N="(*;7-G<W1R(")$Z6-L87)E<B!LZ6=I=&EM92(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS-2!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHR,PIM<V=I9"`B4F5P;W)T(&%S(%-P86TB
M"FUS9W-T<B`B1.EC;&%R97(@8V]M;64@<&]U<G)I96PB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#,*;7-G:60@(E)E<75E<W0@82!?
M4F5A9"!296-E:7!T(@IM<V=S='(@(D1E;6%N9&5R('5N(&%C8W5SZ2!D92!?
M;&5C='5R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S,*;7-G:60@
M(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T<B`B1&5M86YD97(@9&5S
M(&%C8W5SZ7,@9&4@;&5C='5R9:`_(@H*(SH@;6%I;&)O>"YP:'`Z,3@W"FUS
M9VED(")297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N(@IM<V=S='(@(DUE
M<W-A9V4@9&5M86YDZ2!N;VX@=')O=7;I+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV.3(*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM
M<V=S='(@(E!A<G1I8VEP86YT(&EN9&ES<&5N<V%B;&4B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,@IM<V=I9"`B
M4F5S970B"FUS9W-T<B`B4L!:(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C$Q-@IM<V=I9"`B4F5S<&]N9&5N="!3=&%T=7,@57!D871E9"XB"FUS
M9W-T<B`B3&4@<W1A='5T(&1U(&-O<G)E<W!O;F1A;G0@82#I=.D@;6]D:69I
MZ2XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R(")297!R96YD<F4B"@HC.B!R96-O
M;7!O<V4N<&AP.CDW"FUS9VED(")297-U;64@>6]U<B!S97-S:6]N(@IM<V=S
M='(@(E)E<')E;F1R92!V;W1R92!S97-S:6]N(@H*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C0T"FUS9VED(")2971U<FX@=&\@7")-97-S
M86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`B4F5T;W5R('9E<G,@;&$@JZ!2
MZ61A8W1I;VX@9&4@;65S<V%G9:"[(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]D<FEV97)?<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E
M;&5C="YI;F,Z,S(*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S
M='(@(E)E=&]U<B!V97)S(&QA('+I8W5PZ7)A=&EO;B!D=2!C;W5R<FEE<B(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHV,"!T96UP;&%T97,O
M9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C(R"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,3`Q('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$U
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C,@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$W-0HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L
M871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0IM<V=I9"`B4F5T=7)N('1O($]P
M=&EO;G,B"FUS9W-T<B`B4F5T;W5R(&%U>"!O<'1I;VYS(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<P-@IM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M
M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P
M>6EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*(E)E=&]U<FYE<B!A=2!C;VYT
M96YU(&1E('9O=')E(&)O[G1E(&1E('+I8V5P=&EO;B!A<'+H<R!A=F]I<B!E
M9F9A8^DL("(*(F3I<&QA8^DL(&]U(&-O<&GI('5N(&UE<W-A9V6@/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#,*;7-G:60@(E)O;&4B"FUS
M9W-T<B`B4O1L92(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30R
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z-#(T"FUS9VED(")3+TU)344B"FUS9W-T<B`B4R]-
M24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ
M,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")#:&EF
M9G)E<B!L92!M97-S86=E(&5N(%,O34E-12(*"B,Z(&-O;7!O<V4N<&AP.C,W
M,0IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B17)R975R(%,O34E-
M1:`Z("(*"B,Z(&-O;7!O<V4N<&AP.C,U,`IM<V=I9"`B4R]-24U%($5R<F]R
M.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*
M;7-G<W1R("(B"B)%<G)E=7(@4R]-24U%H#H@;&$@<&AR87-E('-E8W+H=&4@
M97-T(&[I8V5S<V%I<F4@<&]U<B!L82!C;&5F('!R:7;I92`B"B)P97)S;VYN
M96QL92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"FUS9VED(")3
M+TU)344@3W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS(%,O34E-12(*"B,Z('-M
M:6UE+G!H<#HT-@IM<V=I9"`B4R]-24U%(%!A<W-P:')A<V4@26YP=70B"FUS
M9W-T<B`B16YT<NEE(&1E(&QA('!H<F%S92!S96-RZ'1E(%,O34E-12(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-30*;7-G:60@(E,O34E-12!0
M97)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*(DQE('-U<'!O<G0@9&4@;&$@<&%I
M<F4@9&4@8VQE9G,@4R]-24U%('!E<G-O;FYE;&QE<R!R97%U:65R="!U;F4@
M8V]N;F5X:6]N("(*(F%U('=E8B!SZ6-U<FESZ64N(@H*(SH@<VUI;64N<&AP
M.C$S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F
M;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B
M3&$@8VQE9B!P=6)L:7%U92!3+TU)344@9&4@JZ`E<Z"[(&$@8FEE;B#I=.D@
M<W5P<')I;>EE+B(*"B,Z('-M:6UE+G!H<#HQ-3@*;7-G:60@(E,O34E-12!0
M=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B3&$@8VSI
M('!U8FQI<75E(%,O34E-12!A(&)I96X@Z73I(&%J;W5TZ64N(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U8FQI
M8R!+97ER:6YG(@IM<V=S='(@(D%N;F5A=2!D92!C;&5F<R!P=6)L:7%U97,@
M4R]-24U%(@H*(SH@<VUI;64N<&AP.C(P-PIM<V=I9"`B4R]-24U%(%!U8FQI
M8R]0<FEV871E($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R
M("),82!P86ER92!D92!C;&5F<R!3+TU)344@<'5B;&EQ=64O<')I=NEE(&$@
M8FEE;B#I=.D@86IO=73I92XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R
M>7!T7VQI<W0N:6YC.C$S"FUS9VED(")3+TU)344@4VEG;B!-97-S86=E(@IM
M<V=S='(@(E-I9VYE<B!L92!M97-S86=E(&5N(%,O34E-12(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*;7-G:60@(E,O34E-
M12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")3:6=N97(O8VAI9F9R
M97(@;&4@;65S<V%G92!E;B!3+TU)344B"@HC.B!T96UP;&%T97,O<VUI;64O
M;F]T86-T:79E+FEN8SHT"FUS9VED(")3+TU)344@<W5P<&]R="!I<R!D:7-A
M8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B3&4@<W5P<&]R="!D92!3
M+TU)344@97-T(&3I<V%C=&EVZ2!S=7(@8V4@<WES=.AM92XB"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U
M<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E
M(&ES('5N86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(B(*(DQE
M('-U<'!O<G0@9&4@4R]-24U%(&XG97-T('!A<R!A8W1I9B!A8W1U96QL96UE
M;G0L(&5T(&QE(&UE<W-A9V4@;F4@<&5U="`B"B)D;VYC('!A<R#J=')E(&3I
M8VAI9F9RZ2XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PIM
M<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE
M(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N;F]T("(*(F)E
M(&1I<W!L87EE9"XB"FUS9W-T<B`B(@HB3&4@<W5P<&]R="!D92!3+TU)344@
M;B=E<W0@<&%S(&%C=&EVZ2P@970@;&4@8V]N=&5N=2!D92!C92!M97-S86=E
M('-I9V[I(&YE("(*(G!E=70@9&]N8R!P87,@ZG1R92!A9F9I8VCI+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)
M344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N
M871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B
M"B),92!S=7!P;W)T(&1E(%!'4"!N)V5S="!P87,@86-T:68@86-T=65L;&5M
M96YT+"!E="!L82!S:6=N871U<F4@;G5MZ7)I<75E(&YE("(*(G!E=70@9&]N
M8R!P87,@ZG1R92!VZ7)I9FGI92XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(')E<75I<F5S('!O
M<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R`B
M"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U
M(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E("(*(G1H92!3+TU)
M344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@
M(B(*(DQE('-U<'!O<G0@4R]-24U%('5T:6QI<V4@9&5S(&9E;NIT<F5S('-U
M<F=I<W-A;G1E<RX@4VD@8V5T=&4@9F]N8W1I;VX@97-T("(*(F3I<V%C=&EV
MZ64@9&%N<R!V;W1R92!N879I9V%T975R+"!I;"!F875T(&PG86-T:79E<BP@
M<V%N<R!Q=6]I(%,O34E-12!N92`B"B)F;VYC=&EO;FYE<F$@<&%S(&-O<G)E
M8W1E;65N="XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P-`IM
M<V=I9"`B4TU44"(*;7-G<W1R(")33510(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,C4U"FUS9VED(")37W5B:F5C="(*;7-G<W1R(")3
M7W5J970B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-C,*
M;7-G:60@(E-A7W9E(&$@8V]P>2!I;B`B"FUS9W-T<B`B16YR95]G:7-T<F5R
M('5N92!C;W!I92!D86YS("(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B16Y?
M<F5G:7-T<F5R('-O=7,B"@HC.B!S96%R8V@N<&AP.C,Q-B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*;7-G:60@(E-A=F4B"FUS9W-T<B`B
M16YR96=I<W1R97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU,S,*;7-G:60@(E-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN
M('-E;G0M;6%I;"!F;VQD97(_(@IM<V=S='(@(B(*(E-A=79E9V%R9&5R(&QE
M<R!P:>AC97,@:F]I;G1E<R!A=F5C(&QE(&UE<W-A9V4@9&%N<R!L92!D;W-S
M:65R(&-O=7)R:65R("(*(F5N=F]YZ:`_(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#(W"FUS9VED(")3879E($1R869T(@IM<V=S='(@(D5N<F5G:7-T<F5R
M(&QE(&)R;W5I;&QO;B(*"B,Z('-A=F5I;6%G92YP:'`Z-#(*;7-G:60@(E-A
M=F4@26UA9V4B"FUS9W-T<B`B16YR96=I<W1R97(@;"=I;6%G92(*"B,Z(&QI
M8B]-24U%+T-O;G1E;G1S+G!H<#HR,3$*;7-G:60@(E-A=F4@26UA9V4@:6X@
M1V%L;&5R>2(*;7-G<W1R(")%;G)E9VES=')E<B!L)VEM86=E(&1A;G,@;&$@
M9V%L97)I92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI
M;64O;F]T86-T:79E+FEN8SHQ,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X
M"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V
M92!/<'1I;VYS(@IM<V=S='(@(D5N<F5G:7-T<F5R(&QE<R!O<'1I;VYS(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"FUS9VED(")3
M879E(%-T871I;VYE<GDB"FUS9W-T<B`B16YR96=I<W1R97(@;&$@<&%P971E
M<FEE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(W"FUS9VED(")3879E(%]$
M<F%F="(*;7-G<W1R(")%;G)E9VES=')E<B!L92!?8G)O=6EL;&]N(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED
M(")3879E(&%S(@IM<V=S='(@(D5N<F5G:7-T<F5R('-O=7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3(Q"FUS9VED(")3879E(&1R869T<R!A<R!U
M;G-E96X_(@IM<V=S='(@(D5N<F5G:7-T<F5R(&QE<R!B<F]U:6QL;VYS(&5N
M('1A;G0@<75E(&YO;BUL=7.@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#8P"FUS9VED(")3879E(')E8VEP:65N=',@875T;VUA=&EC86QL>2!T
M;R!T:&4@9&5F875L="!A9&1R97-S(&)O;VL_(@IM<V=S='(@(B(*(D5N<F5G
M:7-T<F5R(&QE<R!A9')E<W-E<R!A=71O;6%T:7%U96UE;G0@9&%N<R!L92!C
M87)N970@9"=A9')E<W-E<R!P87(@(@HB9.EF875TH#\B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@87,@
M82!V:7)T=6%L(&9O;&1E<C\B"FUS9W-T<B`B16YR96=I<W1R97(@;&$@<F5C
M:&5R8VAE(&-O;6UE(&1O<W-I97(@=FER='5E;*`_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S
M='(@(D5N<F5G:7-T<F5R(&QE(&-O=7)R:65R(&5N=F]YZ:`_(@H*(SH@8V]M
M<&]S92YP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879I;F<@=&AE
M(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M)7,B"FUS9W-T<B`B3"=E;G)E9VES=')E;65N="!D=2!B<F]U:6QL;VX@82#I
M8VAO=>DN($QE('-E<G9E=7(@82!RZ7!O;F1UH#H@)7,@(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H
M<#HT-0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E)E8VAE<F-H92(*"B,Z('1E
M;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:"`E
M<R(*;7-G<W1R(")296-H97)C:&4@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(P"FUS9VED(")396%R8V@@3W!T:6]N<R(*;7-G<W1R(")/<'1I
M;VYS(&1E(')E8VAE<F-H92(*"B,Z('-E87)C:"YP:'`Z,C8U"FUS9VED(")3
M96%R8V@@4F5S=6QT<R(*;7-G<W1R(")2Z7-U;'1A=',@9&4@;&$@<F5C:&5R
M8VAE(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM<V=S
M='(@(D]U=F5R="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M.0IM<V=I9"`B4V5L96-T(@IM<V=S='(@(E/I;&5C=&EO;FYE<B(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW,`IM<V=I9"`B4V5L96-T
M($%N;W1H97(@06-C;W5N="(*;7-G<W1R(")3Z6QE8W1I;VYN97H@=6X@875T
M<F4@8V]M<'1E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V
M"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!U
M;F4@9&%T92(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHQ,`IM
M<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`B0VAO:7-I<W-E>B!U;B!C
M:&%M<"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PIM
M<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B4^EL96-T:6]N
M;F5Z('5N92!P87!E=&5R:66@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S4*;7-G:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@
M861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`B
M(@HB4^EL96-T:6]N;F5Z(&QE<R!C87)N971S(&0G861R97-S97,@X"!U=&EL
M:7-E<B!P;W5R(&PG86IO=70@;W4@;&$@<F5C:&5R8VAE("(*(F0G861R97-S
M97,N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I9"`B
M4V5L96-T(&%L;"(*;7-G<W1R(")4;W5T('/I;&5C=&EO;FYE<B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L
M96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E
M<W-E<RXB"FUS9W-T<B`B(@HB4^EL96-T:6]N;F5R('1O=7,@;&5S(&-H86UP
M<R!L;W)S(&0G=6YE(')E8VAE<F-H92!P;W5R(&3I=F5L;W!P97(@=6YE("(*
M(F%D<F5S<V4N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E
M;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@
M(E/I;&5C=&EO;FYE>B!U;B!C;VUP=&4B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C@Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")!=6-U
M;B(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS
M9VED(")396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN
M(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L82!G86QE<FEE(&1A;G,@;&%Q=65L
M;&4@<V%U=F5Z(&PG:6UA9V4N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D
M<FEV97)?<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T('1H92!M86EL('-E
M<G9E<B!T>7!E(@IM<V=S='(@(E/I;&5C=&EO;FYE<B!L92!T>7!E(&1E('-E
M<G9E=7(@9&4@8V]U<G)I97(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,#D*;7-G:60@(E-E;&5C=&5D($%D9')E<W,@8F]O:W,Z
M(@IM<V=S='(@(D-A<FYE=',@9"=A9')E<W-E<R!SZ6QE8W1I;VYNZ7.@.B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B4V5N9"!+97D@
M=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R(")%;G9O>65R(&QA(&-L968@
M874@<V5R=F5U<B!P=6)L:6,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3DW"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R
M(")%;G9O>65R(&PG:6YF;W)M871I;VX@;&$@<&QU<R!RZ6-E;G1E(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#(U"FUS9VED(")396YD($UE<W-A9V4B"FUS
M9W-T<B`B16YV;WEE<B!L92!M97-S86=E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Y,0IM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U
M97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B16YV;WEE<B!U;B!A=FES
M(&1E('+I8V5P=&EO;B!S)VEL(&5S="!D96UA;F3I('!A<B!L)V5X<.ED:71E
M=7*@/R(*"B,Z(&9O;&1E<G,N<&AP.C,W-@IM<V=I9"`B4V5N="!M86EL(&9O
M;&1E<B(*;7-G<W1R(")$;W-S:65R(&1U(&-O=7)R:65R(&5N=F]YZ2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,S@*;7-G:60@
M(E-E;G0@;6%I;"!F;VQD97(Z(@IM<V=S='(@(D1O<W-I97(@9'4@8V]U<G)I
M97(@96YV;WGIH#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S
M,R!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$T-0HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$U,@IM<V=I9"`B4V5R=F5R(@IM<V=S='(@(E-E
M<G9E=7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*;7-G:60@(E-E
M<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%T
M:6]N(&1U('-E<G9E=7(@970@9'4@9&]S<VEE<B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHR,PIM<V=I9"`B4V5R=F5R.B(*;7-G<W1R
M(")397)V975RH#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G
M:60@(E-E="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U
M(&UO=F4@86YD(&1E;&5T92!M97-S86=E<RXB"FUS9W-T<B`B(@HB0VAO:7-I
M<B!L97,@<'+I9NER96YC97,@<&]U<B!L97,@9.EP;&%C96UE;G1S(&5T(&QA
M(&1E<W1R=6-T:6]N(&1E<R!M97-S86=E<RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3(Y"FUS9VED(")3970@=&AE(%@M4')I;W)I='D@:&5A9&5R
M('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R(")$Z69I;FER(&PG
M96XM=.IT92!8+5!R:6]R:71Y(&QO<G,@9&4@;&$@<NED86-T:6]N(&1E<R!M
M97-S86=E<Z`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED
M(")3:&%R92!&;VQD97)S(@IM<V=S='(@(E!A<G1A9V5R(&QE<R!D;W-S:65R
M<R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@IM<V=I9"`B4VAA<F4@
M;6%I;"!F;VQD97)S(@IM<V=S='(@(E!A<G1A9V5R(&QE<R!D;W-S:65R<R!D
M92!C;W5R<FEE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I
M9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB
M"FUS9W-T<B`B4&%R=&%G97(@=F]S(&1O<W-I97)S(&1E(&-O=7)R:65R(&%V
M96,@9"=A=71R97,@=71I;&ES871E=7)S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-3<*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@
M<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET
M(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S
M92XB"FUS9W-T<B`B(@HB3&5S(&=R86YD<R!B;&]C<R!D92!T97AT92!C:73I
M(&1E=G)A:65N="UI;',@ZG1R92!M;VYT<NES(&]U(&-A8VCI<R!P87(@(@HB
M9.EF875TH#\@5F]U<R!P;W5V97H@8F%S8W5L97(@9F%C:6QE;65N="!V97)S
M(&-E;'5I('%U92!V;W5S(&3I<VER97HN(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN
M(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D871A/R(*;7-G<W1R("(B
M"B)6;W5L97HM=F]U<R!R96-H97)C:&5R(&1E<R!D;VYNZ65S(%!'4"!D86YS
M(&QE(&-O<G!S(&1E<R!M97-S86=E<R!T97AT=65L<Z`_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B4VAO=6QD('1H92!C;VUP;W-E
M('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_(@IM<V=S
M='(@(B(*(D9A=70M:6P@9F5R;65R(&QA(&9E;NIT<F4@9&4@<NED86-T:6]N
M(&%P<NAS(&PG96YR96=I<W1R96UE;G0@9"=U;B`B"B)B<F]U:6QL;VZ@/R(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U
M<B!01U`@<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A
M9V5S(&)Y(&1E9F%U;'0_(@IM<V=S='(@(B(*(E9O=6QE>BUV;W5S(&IO:6YD
M<F4@=F]T<F4@8VQE9B!P=6)L:7%U92!01U`@X"!V;W,@;65S<V%G97,@<&%R
M(&3I9F%U=*`_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@IM
M<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")-;VYT<F5R('1O=7,@
M;&5S(&1O<W-I97)S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-C<*;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B36]N=')E
M<B!T;W5T97,@;&5S(&5N+73J=&5S(@H*(SH@;6%I;&)O>"YP:'`Z,S0W"FUS
M9VED(")3:&]W($1E;&5T960B"FUS9W-T<B`B36]N=')E<B!L97,@;65S<V%G
M97,@969F86/I<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC
M.C8Q"FUS9VED(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R(").92!M
M;VYT<F5R('%U92!L97,@96XM=.IT97,@<')I;F-I<&%L97,B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW,`IM<V=I9"`B4VAO=R!-86EL
M:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T<B`B36]N=')E<B!L97,@:6YF
M;W)M871I;VYS('-U<B!L82!L:7-T92!D92!D:69F=7-I;VXB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"FUS9VED(")3:&]W($]N;'D@4W5B
M<V-R:6)E9"!&;VQD97)S(@IM<V=S='(@(DUO;G1R97(@<V5U;&5M96YT(&QE
M<R!D;W-S:65R<R!A=7AQ=65L<R!V;W5S(.IT97,@86)O;F[I<R(*"B,Z(&9O
M;&1E<G,N<&AP.C(W-PIM<V=I9"`B4VAO=R!5;G-U8G-C<FEB960B"FUS9W-T
M<B`B36]N=')E<B!T;W5S(&QE<R!D;W-S:65R<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU.38*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S
M=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T
M<B`B(@HB36]N=')E<B!U;F4@:6/T;F4@<&5R;65T=&%N="!D92!DZ71A8VAE
M<B!L97,@<&GH8V5S(&IO:6YT97,@9&5S(&UE<W-A9V5SH#\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3DP"FUS9VED(")3:&]W(&QE9V5N9"!I;B!T
M:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R(")-;VYT<F5R(&QA(&SI9V5N9&4@
M9&%N<R!L82!V=64@9&4@;&$@8F_N=&6@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,C@*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M
M97-S86=E<R!O;FQY/R(*;7-G<W1R(").92!P<NDM=FES=6%L:7-E<B!Q=64@
M;&5S(&UE<W-A9V5S(&YO;B!O=79E<G1SH#\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#,V"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S
M/R(*;7-G<W1R(")-;VYT<F5R(&QE<R!P<NDM=FES=6%L:7-A=&EO;G,@9&%N
M<R!L97,@8G5L;&5S(&0G86ED9:`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@V-0IM<V=I9"`B4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H
M92!M96YU8F%R/R(*;7-G<W1R(")-;VYT<F5R(&PG:6/T;F4@9&4@<NEC=7#I
M<F%T:6]N(&1U(&-O=7)R:65R(&1A;G,@;&$@8F%R<F4@9&4@;65N=:`_(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDX"FUS9VED(")3:&]W('1H
M92!);6%G97,B"FUS9W-T<B`B36]N=')E<B!L97,@:6UA9V5S(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F
M:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B069F:6-H97(@
M;"=I8_1N92!D=2!F:6QT<F%G92!D86YS(&QA(&)A<G)E(&1E(&UE;G6@/R(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS,0IM<V=I9"`B4VAO=R!T;W1A
M;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G<W1R(")!9F9I8VAE
M<B!L92!N;VUB<F4@=&]T86P@9&4@;65S<V%G97,@9&%N<R!L92!D;W-S:65R
MH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4T"FUS9VED(")3:&]W
M;B(*;7-G<W1R(")!9F9I8VCI(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHT,@IM<V=I9"`B4VE?>F4B"FUS9W-T<B`B7U1A
M:6QL92(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*;7-G
M:60@(E-I9VYE9"(*;7-G<W1R(")3:6=NZ2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")3:7IE(@IM<V=S='(@(E1A
M:6QL92(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,3$*;7-G:60@(E-O<G0@8GD@07)R:79A;"(*;7-G<W1R(")4<FD@<V5L
M;VX@;"=A<G)I=NEE(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM<V=S='(@(E1R
M:2!S96QO;B!L82!D871E(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHR-@IM<V=I9"`B4V]R="!B>2!&<F]M($%D9')E<W,B
M"FUS9W-T<B`B5')I('-E;&]N(&PG861R97-S92!D92!L)V5X<.ED:71E=7(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0Q
M"FUS9VED(")3;W)T(&)Y($UE<W-A9V4@4VEZ92(*;7-G<W1R(")4<FD@<V5L
M;VX@;&$@=&%I;&QE(&1U(&UE<W-A9V4B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C,V"FUS9VED(")3;W)T(&)Y(%-U8FIE
M8W0B"FUS9W-T<B`B5')I('-E;&]N(&QE('-U:F5T(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,0IM<V=I9"`B4V]R="!B
M>2!4:')E860B"FUS9W-T<B`B5')I('!A<B!F:6P@9&4@9&ES8W5S<VEO;B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C$*
M;7-G:60@(E-O<G0@8GD@5&\@061D<F5S<R(*;7-G<W1R(")4<FD@<V5L;VX@
M;"=A9')E<W-E(&1U(&1E<W1I;F%T86ER92(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S<&%M<V5L96-T+FEN8SHR,PIM<V=I9"`B4W!A;2!F;VQD97(Z(@IM<V=S
M='(@(D1O<W-I97(@9&4@<&]U<G)I96QSH#HB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M<R(*;7-G<W1R(")#87)A8W3H<F5S('-PZ6-I875X(@H*(SH@<V5A<F-H+G!H
M<#HQ,S,*;7-G:60@(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;FYO="!B
M92!E9&ET960N(@IM<V=S='(@(DQE<R!D;W-S:65R<R!V:7)T=65L<R!S<.EC
M:6%U>"!N92!P975V96YT('!A<R#J=')E(.ED:73I<RXB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#,*;7-G:60@(E-P96QL($-H96-K
M(@IM<V=S='(@(E;I<FEF:6-A=&EO;B!D92!L)V]R=&AO9W)A<&AE(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")3<&5L
M;"!#:&5C:V5R(@IM<V=S='(@(E;I<FEF:6-A=&5U<B!D)V]R=&AO9W)A<&AE
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU-@IM<V=I9"`B4W!E;&P@8VAE
M8VL@8V]M<&QE=&4B"FUS9W-T<B`B5NER:69I8V%T:6]N(&1E(&PG;W)T:&]G
M<F%P:&4@=&5R;6ENZ64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Q
M"FUS9VED(")3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL
M(&-H96-K:6YG+B(*;7-G<W1R(")%<G)E=7)S(&0G;W)T:&]G<F%P:&4@<&%R
M(.EC<F%N(&QO<G,@9&4@;&$@8V]R<F5C=&EO;BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3`W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,#D*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8T,B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C0T"FUS9VED(")3=&%R="(*;7-G<W1R(")$Z6)U
M="(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHY('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R
M>2(*;7-G<W1R(")087!E=&5R:64B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@;F%M93HB"FUS9W-T
M<B`B3F]M(&1E(&QA('!A<&5T97)I9:`Z(@H*(SH@=&5M<&QA=&5S+W-T871I
M;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM
M<V=S='(@(E1Y<&4@9&4@<&%P971E<FEEH#HB"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z,S,*;7-G:60@(E-T871I;VYE<GDZ(@IM<V=S
M='(@(E!A<&5T97)I9:`Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8X,PIM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U="(*"B,Z(&QI8B]-
M24U%+T-O;G1E;G1S+G!H<#HR,C(*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B
M"FUS9W-T<B`B4F5T:7)E<B!L82!P:>AC92!J;VEN=&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#(P"FUS9VED(")3=')I<"!L:6YE8G)E86MS/R(*
M;7-G<W1R(")3=7!P<FEM97(@;&5S('-A=71S(&1E(&QI9VYEH#\B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,W"FUS9VED
M(")3=6)?:F5C="(*;7-G<W1R(")3=5]J970B"@HC.B!M97-S86=E+G!H<#HR
M-C@@=&AR96%D+G!H<#HQ-#D@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E
M+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*
M;7-G<W1R(")3=6IE="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#@*
M;7-G:60@(E-U8FIE8W0@1FEE;&0B"FUS9W-T<B`B0VAA;7`@<W5J970B"@HC
M.B!S96%R8V@N<&AP.C,Q."!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G
M92YI;F,Z,3@*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P
M('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S$*;7-G:60@(E-U8FUI
M="(*;7-G<W1R(")%;G9O>65R(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,3$*;7-G:60@(E-U8G-C<FEB92!T;R!&;VQD97(H<RDB"FUS
M9W-T<B`B4R=A8F]N;F5R(&%U*'@I(&1O<W-I97(H<RDB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C,X-2!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HS.3,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`B4NEU<W-I(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G<W1R
M(")3=6=G97-T:6]N<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-3D@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V,0IM<V=I9"`B4W5M;6%R
M>2(*;7-G<W1R(")3;VUM86ER92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,Y-"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M.3<*;7-G:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B
M0F%S8W5L97(@;&5S(&WI=&AO9&5S(&1E('+I9&%C=&EO;B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Y.`IM<V=I9"`B4W=I=&-H('1O
M($A434P@8V]M<&]S:71I;VXB"FUS9W-T<B`B0F%S8W5L97(@=F5R<R!L82!R
MZ61A8W1I;VX@96X@2%1-3"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,Y.`IM<V=I9"`B4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S
M:71I;VXB"FUS9W-T<B`B0F%S8W5L97(@=F5R<R!L82!RZ61A8W1I;VX@96X@
M=&5X=&4@8G)U="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0Q,PIM<V=I9"`B5&5?>'0B"FUS9W-T<B`B5&5?>'1E(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C(W,`IM<V=I9"`B5&5N=&%T:79E.B`B"FUS
M9W-T<B`B5&5N=&%T:79EH#H@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4X-@IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0B"FUS
M9W-T<B`B1&5M86YD92!A8V-E<'3I92!M86ES(.`@8V]N9FER;65R(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U-`IM<V=I9"`B5&5N=&%T:79E
M;'D@06-C97!T960B"FUS9W-T<B`B06-C97!TZ2!M86ES(.`@8V]N9FER;65R
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5R;7,@;V8@4V5R=FEC92!F:6QE
M(&YO="!S<&5C:69I960@:6X@8V]N9BYP:'`B"FUS9W-T<B`B3&5S(&-O;F1I
M=&EO;G,@9"=U=&EL:7-A=&EO;B!N92!S;VYT('!A<R!I;F1I<77I97,@9&%N
M<R!C;VYF+G!H<"(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-#(*;7-G:60@(E1H92!&<F]M.B!C;VQU;6X@;V8@
M=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#HB"FUS9W-T<B`B3&$@8V]L
M;VYN92"KH$1E(#J@NR!D92!C92!M97-S86=E(&1E=G)A:70@ZG1R92!L:>EE
MH#HB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4S,PIM<V=I9"`B(@HB5&AE
M($E-05`@<V5R=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A
M=71H96YT:6-A=&EO;B!M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT
M86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DQE
M('-E<G9E=7(@24U!4"!N92!S96UB;&4@<&%S('-U<'!O<G1E<B!L82!MZ71H
M;V1E(&0G875T:&5N=&EF:6-A=&EO;B`B"B)C:&]I<VEE+B!6975I;&QE>B!C
M;VYT86-T97(@;"=A9&UI;FES=')A=&5U<B!D92!V;W1R92!S>7-TZ&UE+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@
M(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R("),82!P86QE
M='1E(&1E(')E<W-O=7)C97,@36%C:6YT;W-H(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@
M)7,N(@IM<V=S='(@(DQE<R!R97-S;W5R8V5S($UA8VEN=&]S:"!P975V96YT
M(.IT<F4@=.ELZ6-H87)GZ65S("5S+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H
M<#HX,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B3&4@8V]M<'1E(*N@)7.@NR!A
M(.ETZ2!S=7!P<FEMZ2XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R("),92!C;VUP=&4@JZ`E<Z"[(&$@Z73I(&5N<F5G
M:7-T<NDN(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A
M8VAM96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(DQA('!IZ&-E(&IO:6YT
M92!N)V$@<&%S(.ETZ2!T<F]U=NEE+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW,0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI
M9"(*;7-G<W1R("),97,@9&]N;NEE<R!D=2!C86QE;F1R:65R('-O;G0@:6YV
M86QI9&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C;VUP;W-E
M7W=I;BYJ<SHS-PIM<V=I9"`B(@HB5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T
M(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R
M('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*(DQA(&9E
M;NIT<F4@9&4@8V]M<&]S:71I;VX@9&4@;65S<V%G92!N92!P975T(.IT<F4@
M;W5V97)T92X@17-T+6EL('!O<W-I8FQE("(*(G%U92!V;W5S(&%Y97H@86-T
M:7;I(&QE(&)L;V-A9V4@9&4@9F5NZG1R97,@<W5R9VES<V%N=&5SH#\B"@HC
M.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4
M:&4@8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB
M"FUS9W-T<B`B3&4@8V]N=&5N=2!D=2!F:6-H:65R($UA8VEN=&]S:"!E<W0@
M8VDM9&5S<V]U<RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?
M<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&-U<G)E;G0@9F]L9&5R*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M960@
M=&\@7"(E<UPB+B(*;7-G<W1R("),92!D;W-S:65R(&-O=7)A;G0@JZ`E<Z"[
M('-E<F$@<F5N;VUMZ2!E;B"KH"5SH+LN(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R
M<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T
M<FEE=F5D(@IM<V=S='(@(B(*(DQE8W1U<F4@:6UP;W-S:6)L92!D92!L82!L
M:7-T92!D97,@=71I;&ES871E=7)S('%U:2!O;G0@86-CZ',@X"!C92!D;W-S
M:65R(@H*(SH@8V]M<&]S92YP:'`Z,3(V,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F;VQD
M97(N(@IM<V=S='(@(DQE(&)R;W5I;&QO;B!A(.ETZ2!E;G)E9VES='+I(&1A
M;G,@;&4@9&]S<VEE<B"KH"5SH+LN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$T,`IM<V=I9"`B5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R
M(&-A;&5N9&%R+B(*;7-G<W1R(")#970@Z7;I;F5M96YT(&$@8FEE;B#I=.D@
M86IO=73I(.`@=F]T<F4@86=E;F1A+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V5X<&%N9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEE;&0@
M7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*;7-G<W1R("),92!C:&%M<""K
MH"5SH+L@;F4@<&5U="!P87,@ZG1R92!DZ79E;&]P<.DN(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,S,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DQE(&1O<W-I97(@JZ`E
M<Z"[(&5X:7-T92!DZ6K@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS
M(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E
M("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(DQE(&YO;2!D=2!D;W-S:65R(*N@)7.@NR!C
M;VYT:65N="!D97,@8V%R86-TZ')E<R!I;&SI9V%U>"X@0V5L82!P;W5R<F%I
M="`B"B+I=F5N='5E;&QE;65N="!C875S97(@9&5S('!R;V)LZ&UE<RX@5F5U
M:6QL97H@8V]N=&%C=&5R('9O=')E(&%D;6EN:7-T<F%T975R("(*(G-Y<W3H
M;64N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R
M92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B3&4@9&]S<VEE<B"K
MH"5SH+L@82#I=.D@8W+IZ2P@;6%I<R!V;W5S(&XG>2!A=F5Z('!A<R!S;W5S
M8W)I="XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W
M97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B(@HB3&4@
M9&]S<VEE<B"KH"5SH+L@82#I=.D@<W5P<')I;>DL(&UA:7,@=F]U<R!N)V5N
M(&XG879E>B!P87,@Z73I(&3I<V%B;VYNZ2XB"@HC.B!L:6(O1F]L9&5R+G!H
M<#HS-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M(@IM<V=S='(@(B!,92!D;W-S:65R(*N@)7.@NR!N)V$@<&%S(.ETZ2!C<NGI
M+B!,92!S97)V975R(&$@<NEP;VYD=2(*"B,Z(&QI8B]&;VQD97(N<&AP.C(V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@
M;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS
M9W-T<B`B3&4@9&]S<VEE<B"KH"5SH+L@;B=A('!A<R#I=.D@<W5P<')I;>DN
M($QE('-E<G9E=7(@82!RZ7!O;F1U(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S
M=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B3&4@9&]S<VEE<B"KH"5S
MH+L@82!B:65N(.ETZ2!C<NGI+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C
M8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(DQE(&1O<W-I97(@JZ`E<Z"[
M(&$@8FEE;B#I=.D@9.ET<G5I="XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U
M8V-E<W-F=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B3&4@9&]S
M<VEE<B"KH"5SH+L@82!B:65N(.ETZ2!R96YO;6WI(&5N(*N@)7.@NRXB"@HC
M.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.30*;7-G:60@(E1H92!F;VQL
M;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S
M='(@(DQE<R!F:6-H:65R<R!S=6EV86YT<R!S;VYT(&%T=&%C:.ES(.`@8V5T
M=&4@<&%R=&EEH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7W-A
M=F5I;6%G95]W:6XN:G,Z,3(*;7-G:60@(B(*(E1H92!I;6%G92!S879E('=I
M;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@
M>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S
M='(@(B(*(DQA(&9E;NIT<F4@9&4@<V%U=F5G87)D92!D97,@:6UA9V5S(&YE
M('!E=70@ZG1R92!O=79E<G1E+B!%<W0M:6P@<&]S<VEB;&4@(@HB<75E('9O
M=7,@87EE>B!A8W1I=ND@;&4@8FQO8V%G92!D97,@9F5NZG1R97,@<W5R9VES
M<V%N=&5SH#\B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`P"FUS
M9VED("(B"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@
M=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN
M(@IM<V=S='(@(B(*(DQE<R!I;6%G97,@<V5R;VYT(&%F9FEC:.EE<R!P87)C
M92!Q=64@;"=E>'#I9&ET975R(&5S="!D86YS('9O=')E(&-A<FYE="`B"B)D
M)V%D<F5S<V5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U
M"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I
M;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B3&4@<V5R=F5U<B!D92!C;W5R
M<FEE;"!A(&?I;NERZ2!C92!M97-S86=E(&0G97)R975RH#HB"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0IM<V=I9"`B5&AE(&UA
M:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N
M86P@;65S<V%G93HB"FUS9W-T<B`B3&4@<V5R=F5U<B!D92!C;W5R<FEE;"!A
M(&?I;NERZ2!C92!M97-S86=E(&EN9F]R;6%T:6:@.B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.CDP"FUS9VED(")4:&4@;6%I;"!S97)V97(@
M9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93HB"FUS9W-T<B`B3&4@
M<V5R=F5U<B!D92!C;W5R<FEE;"!A(&?I;NERZ2!C92!M97-S86=EH#HB"@HC
M.B!L:6(O365S<V%G92YP:'`Z-C4X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(DQA(&)O
M[G1E("5S(&5S="!DZ6K@('9I9&4N(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z
M,C0W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(%PB)7-<(B!F
M<F]M(%PB)7-<(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI
M="XB"FUS9W-T<B`B3&4@;65S<V%G92"K)7,@NV1E(*LE<[L@*"5D(&]C=&5T
M<RD@9.EP87-S92!L82!L:6UI=&4@<&5R;6ES92XB"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PIM<V=I9"`B5&AE(&UE<W-A9V4@
M8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG+B(*;7-G
M<W1R("),92!M97-S86=E(&5N(&-O=7)S(&1E('+I9&%C=&EO;B!A(.ETZ2!F
M97)MZ2X@4V]R=&EE+B(*"B,Z(&UE<W-A9V4N<&AP.C$T.`IM<V=I9"`B5&AE
M(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B3&4@;65S<V%G
M92!A(.ETZ2!S=7!P<FEMZ2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HS.3<*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*
M;7-G<W1R("),92!M97-S86=E(&$@Z73I(';I<FEF:>DN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HS.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@)7,N(@IM
M<V=S='(@(DQE(&UE<W-A9V4@82#I=.D@=NER:69IZ2X@17APZ61I=&5U<J`Z
M("5S+B(*"B,Z('1E;7!L871E<R]S;6EM92]O<&5N7W-M:6UE7W=I;BYJ<SHQ
M,"!T96UP;&%T97,O<&=P+V]P96Y?<&=P7W=I;BYJ<SHQ,`IM<V=I9"`B(@HB
M5&AE('!A<W-P:')A<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P
M<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P
M('=I;F1O=W,_(@IM<V=S='(@(B(*(DQA(&9E;NIT<F4@9'4@;6]T(&1E('!A
M<W-E(&YE('!E=70@<&%S(',G;W5V<FER+B!%<W0M:6P@<&]S<VEB;&4@<75E
M('9O=7,@(@HB87EE>B!A8W1I=ND@;&$@9F]N8W1I;VX@9&4@8FQO8V%G92!D
M97,@9F5NZG1R97,@<W5R9VES<V%N=&5SH#\B"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T
M97AT(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*
M;7-G<W1R("),92!T97AT92!B<G5T(&1E(&QA(&-L968@4$=0('!E=70@ZG1R
M92!C;VYS=6QTZ2`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z
M-C`*;7-G:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I
M;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("),92!F:6-H:65R
M(&1E;6%N9.D@;F4@<V4@=')O=79E('!A<R!D86YS(&QA('!IZ&-E(&IO:6YT
M92!-4RU43D5&+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"FUS
M9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE
M(%II<"!A='1A8VAM96YT+B(*;7-G<W1R("),92!F:6-H:65R(&1E;6%N9.D@
M;F4@<V4@=')O=79E('!A<R!D86YS(&QA('!IZ&-E(&IO:6YT92!C;VUP<F5S
M<^EE+B(*"B,Z(&UE<W-A9V4N<&AP.C4T,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG
M(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@(@HB9G)O;2!Y
M;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L
M:6-K("5S('1O('-E;F0@=&AE("(*(FYO=&EF:6-A=&EO;B!M97-S86=E+B(*
M;7-G<W1R("(B"B),)V5X<.ED:71E=7(@9&4@8V4@;65S<V%G92!V;W5S(&1E
M;6%N9&4@=6X@879I<R!D92!L:79R86ES;VX@*$U$3BD@;&]R<W%U92`B"B)V
M;W5S(&%U<F5Z(&QU(&-E(&UE<W-A9V4N(%-64"!C;&EQ=65Z("5S('!O=7(@
M96YV;WEE<B!L)V%V:7,@9&4@;&EV<F%I<V]N+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C8W"FUS9VED(")4:&4@<V5R=F5R('=A<R!N;W0@
M86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS
M9W-T<B`B3&4@<V5R=F5U<B!N)V$@<&%S('!U(&-RZ65R('5N92!V:6=N971T
M92#@('!A<G1I<B!D92!C971T92!I;6%G92XB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FIS.C$P-PIM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L
M9"!N;W0@8F4@<F5P;&%C960N(@IM<V=S='(@(DQA('-I9VYA='5R92!N)V$@
M<'4@ZG1R92!R96UP;&%CZ64N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YJ<SHQ,#4*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F
M=6QL>2!R97!L86-E9"XB"FUS9W-T<B`B3&$@<VEG;F%T=7)E(&$@8FEE;B#I
M=.D@<F5M<&QA8^EE+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4Y"FUS9VED(")4
M:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DQE
M(&9I8VAI97(@9&5M86YDZ2!N)V5X:7-T92!P87,N(@H*(SH@<W1A=&EO;F5R
M>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@
M7"(E<UPB(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R("),82!P87!E=&5R:64@
MJZ`E<Z"[(&$@Z73I(&5N<F5G:7-T<NEE+B(*"B,Z('-T871I;VYE<GDN<&AP
M.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),82!P87!E=&5R:64@JZ`E
M<Z"[(&$@Z73I('-U<'!R:6WI92XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S
M(&)E96X@=7!D871E9"XB"FUS9W-T<B`B3&$@<&%P971E<FEE(*N@)7.@NR!A
M(.ETZ2!M:7-E(.`@:F]U<BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3<P"FUS9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R
M('1A<VML:7-T+B(*;7-G<W1R(")#971T92!TXF-H92!A(&)I96X@Z73I(&%J
M;W5TZ64@X"!V;W1R92!L:7-T92XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HY-0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4B"FUS
M9W-T<B`B5&5X=&4@9'4@;65S<V%G92(*"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F
M('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(DQE('1E
M>'1E(&1U(&UE<W-A9V4@<&5U="#J=')E(&-O;G-U;'3I("5S+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X="!O
M9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R(")497AT92!D=2!M97-S
M86=E(')E=&]U<F[I(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R
M;F5D(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B3&4@=&5X
M=&4@9'4@;65S<V%G92!R971O=7)NZ2!P975T(.IT<F4@8V]N<W5L=.D@)7,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*;7-G
M:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4B"FUS9W-T<B`B3&4@
M=&5X=&4@9'4@;65S<V%G92!E;G9O>>DB"@HC.B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM
M<V=S='(@(DQE('1E>'1E(&1U(&UE<W-A9V4@96YV;WGI('!E=70@ZG1R92!C
M;VYS=6QTZ2`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34U
M"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@
M<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R("),97,@9&ES<&]N:6)I;&ET
MZ7,@9&4@;"=U=&EL:7-A=&5U<B!O;G0@8FEE;B#I=.D@96YR96=I<W1RZ65S
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z.#8*;7-G
M:60@(E1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")!=6-U;F4@<&%R=&EE(&%L
M=&5R;F%T:79E(&YE('!E=70@ZG1R92!A9F9I8VCI92!E;B!L:6=N92XB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS"FUS9VED
M(")4:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*;7-G
M<W1R("));"!N)WD@82!A=6-U;B!M97-S86=E(&1A;G,@8V5T=&4@8F_N=&4N
M(@H*(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES(&YO('1E>'0@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B075C=6X@
M=&5X=&4@;F4@<&5U="#J=')E(&%F9FEC:.D@96X@;&EG;F4N(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E
M<B!S86ED.B`E<R(*;7-G<W1R(")5;F4@97)R975R(&5S="!S=7)V96YU92!E
M;B!V:61A;G0@;&$@8F_N=&4N($QE('-E<G9E=7(@82!RZ7!O;F1UH#H@)7,B
M"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G97,@9G)O;2!<
M(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S
M86ED(@IM<V=S='(@(B(*(DEL('D@82!E=2!U;F4@97)R975R(&QO<G,@9&4@
M;&$@8V]P:64@9&5S(&UE<W-A9V5S(&1E(*N@)7.@NR!V97)S(*N@)7.@NRX@
M3&4@(@HB<V5R=F5U<B!A('+I<&]N9'4B"@HC.B!L:6(O365S<V%G92YP:'`Z
M,C`Q(&QI8B]-97-S86=E+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@
M=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`B(@HB26P@>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D
M92!L82!D97-T<G5C=&EO;B!D97,@;65S<V%G97,@9'4@9&]S<VEE<B"KH"5S
MH+LN("(*(DQE('-E<G9E=7(@82!RZ7!O;F1U(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C(X,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB
M26P@>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D92!L82!D97-T<G5C=&EO;B!D
M97,@;65S<V%G97,@9&%N<R!L92!D;W-S:65R(*N@)2(*(G.@NRX@3&4@<V5R
M=F5U<B!A('+I<&]N9'4B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS
M9W-T<B`B(@HB56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L82!D
M97-T<G5C=&EO;B!D97,@;65S<V%G97,N($QE('-E<G9E=7(@82`B"B)RZ7!O
M;F1UH#H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`P"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")5;F4@97)R975R(&5S="!A<'!A
M<G5E(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;"?I=NEN96UE;G2@.B`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%
M+U9I97=E<B]E;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E5N
M92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=A9F9I8VAA9V4@9&4@
M8V5T=&4@<&%R=&EE(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4U-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@
M;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T
M:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB56YE(&5R<F5U<B!E<W0@
M<W5R=F5N=64@;&]R<R!D=2!C:&%N9V5M96YT(&0GZ71A="!D97,@;65S<V%G
M97,@9&%N<R!L92`B"B)D;W-S:65R(*N@)7.@NRX@3&4@<V5R=F5U<B!A('+I
M<&]N9'4B"@HC.B!F;VQD97)S+G!H<#HQ-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RXB"FUS9W-T<B`B
M56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)VEM<&]R=&%T:6]N
M(&1E("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")5;F4@97)R975R(&5S="!A<'!A
M<G5E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D92!L)^EVZ6YE;65N=*`Z("5S
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M=&%S:SH@)7,N(@IM<V=S='(@(E5N92!E<G)E=7(@97-T(&%P<&%R=64@;&]R
M<R!D92!L)VEM<&]R=&%T:6]N(&1E(&-E='1E('3B8VAEH#H@)7,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E
M+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R("(B"B)5;F4@97)R975R
M(&5S="!S=7)V96YU92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I
M97,@:4-A;&5N9&%RH#H@)7,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I
M;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@
M97-T('-U<G9E;G5E(&QO<G,@9'4@9.EP;&%C96UE;G0@9&5S(&UE<W-A9V5S
M(&1E(*N@)7.@NR!V97)S(*N@)2(*(G.@NRX@3&4@<V5R=F5U<B!A('+I<&]N
M9'4B"@HC.B!C;VUP;W-E+G!H<#HQ,C8X"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@<V%V:6YG('1H:7,@;65S<V%G92!A<R!A(&1R869T+B(*;7-G<W1R
M(")5;F4@97)R975R(&5S="!S=7)V96YU92!L;W)S(&1E(&PG96YR96=I<W1R
M96UE;G0@9'4@8G)O=6EL;&]N+B(*"B,Z(&-O;7!O<V4N<&AP.C$P,S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@
M>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R(")5;F4@97)R975R(&5S="!S=7)V
M96YU92!L;W)S(&1E(&PG96YV;VD@9'4@;65S<V%G9:`Z("5S(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RXB
M"FUS9W-T<B`B56YE(&5R<F5U<B!E<W0@87!P87)U92!L;W)S(&1E(&QA(&UI
M<V4@X"!J;W5R(&1E(&PGZ7;I;F5M96YTH#H@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!L86EN+G!H<#HU.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@
M:6X@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B0V5T=&4@<&%R=&EE(&YE
M(&-O;G1E;F%I="!A=6-U;B!T97AT92(*"B,Z(&QI8B]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,#`*;7-G:60@(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G
M97,@96UB961D960@:6X@:70N(@IM<V=S='(@(D-E(&UE<W-A9V4@2%1-3"!C
M;VUP;W)T92!D97,@:6UA9V5S(&EM8G)I<77I97,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.CDS"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G
M92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A
M<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T<B`B(@HB0V4@;65S<V%G92!(
M5$U,(&-O;7!O<G1E(&1E<R!I;6%G97,@:6UB<FEQ=>EE<RX@3&5S(&EM86=E
M<R!B;&]Q=>EE<R`B"B)A<'!A<F%I<W-E;G0@8V]M;64@<W5I=*`Z("(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-0IM<V=I9"`B5&AI<R!01U`@
M4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N(@IM<V=S
M='(@(D-E='1E(&-L968@4$=0('!U8FQI<75E(&$@Z73I(&IO:6YT92!A=2!M
M97-S86=E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#4@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q.0HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,30T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3@*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W-"!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,S$U"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(")#971T92!A8W1I;VX@;B=E<W0@<&%S('!R:7-E(&5N
M(&-O;7!T92XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3@P(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,C`*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(D-E='1E(&%C=&EO
M;B!N)V5S="!P87,@96YC;W)E(&EM<&SI;65N=.EE+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,30*;7-G:60@(E1H:7,@;6%Y('1A
M:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN
M=64_(@IM<V=S='(@(B(*(D-E='1E(&]PZ7)A=&EO;B!P975T('!R96YD<F4@
M=6X@<&5U(&1E('1E;7!S+B#*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER
M("(*(F-O;G1I;G5E<J`_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U
M8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@36%C
M:6YT;W-H(&9I;&4N(@IM<V=S='(@(D-E(&UE<W-A9V4@8V]N=&EE;G0@=6X@
M9FEC:&EE<B!-86-I;G1O<V@N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HT,34*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A
M='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@
M4R\B"B)-24U%+B(*;7-G<W1R("(B"B)#92!M97-S86=E(&-O;G1I96YT('5N
M92!P:>AC92!J;VEN=&4@<75I(&$@Z73I('-I9V[I92!N=6WI<FEQ=65M96YT
M('9I82!3+R(*(DU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,3D*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM
M96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S
M='(@(D-E(&UE<W-A9V4@8V]N=&EE;G0@=6YE('!IZ&-E(&IO:6YT92!Q=6D@
M82#I=.D@8VAI9F9RZ2!V:6$@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C$V,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A
M:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE
M(&9O<FUA="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T
M<B`B(@HB0V4@;65S<V%G92!C;VYT:65N="!L97,@:6YF;W)M871I;VYS(.`@
M<')O<&]S(&1E(&PGZ71A="!D)V5N=F]I(&1U(&-O=7)R:65L+"`B"B)M86ES
M(&QE(&9O<FUA="!D92!C92!M97-S86=E(&5S="!I;F-O;FYU+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q.0IM<V=I9"`B(@HB5&AI<R!M97-S
M86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T
M960@;65S<V%G92X@17)R;W(Z("(*;7-G<W1R(")#92!M97-S86=E(&YE('-E
M;6)L92!P87,@ZG1R92!U;B!M97-S86=E(&-H:69F<ND@4$=0('9A;&ED92X@
M17)R975RH#H@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C,Y(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C,U-`IM<V=I9"`B(@HB5&AI<R!M97-S
M86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@
M9F]R;6%T("AA8V-O<F1I;F<@=&\@(@HB4D9#(#(P,34I+B(*;7-G<W1R("(B
M"B)#92!M97-S86=E(&YE('-E;6)L92!P87,@ZG1R92!A=2!F;W)M870@4$=0
M(&-O<G)E8W0@*'-E;&]N(&QA(%)&0R`R,#$U*2XB"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI<R!M97-S86=E(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R;6%T
M+B(*;7-G<W1R(")#92!M97-S86=E(&YE('-E;6)L92!P87,@ZG1R92!D86YS
M('5N(&9O<FUA="!3+TU)344@8V]R<F5C="XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z-#(P"FUS
M9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V
M:6$@4$=0+B(*;7-G<W1R(")#92!M97-S86=E(&$@Z73I('-I9V[I(&YU;>ER
M:7%U96UE;G0@874@9F]R;6%T(%!'4"XB"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C$T,PIM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I
M9VET86QL>2!S:6=N960@=FEA(%,O34E-12XB"FUS9W-T<B`B0V4@;65S<V%G
M92!A(.ETZ2!S:6=NZ2!N=6WI<FEQ=65M96YT(&%U(&9O<FUA="!3+TU)344N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ,SD@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@(E1H:7,@;65S<V%G92!H87,@
M8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B0V4@;65S<V%G
M92!A(.ETZ2!C:&EF9G+I(&%U(&9O<FUA="!3+TU)344N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,C`P(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(Y,`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W
M:71H(%!'4"XB"FUS9W-T<B`B0V4@;65S<V%G92!A(.ETZ2!C:&EF9G+I(&%V
M96,@4$=0+B(*"B,Z(&UE<W-A9V4N<&AP.C(Q,0IM<V=I9"`B5&AI<R!M97-S
M86=E('1O(@IM<V=S='(@(D-E(&UE<W-A9V4@X"(*"B,Z(&%C;"YP:'`Z-#4*
M;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F
M;VQD97)S+B(*;7-G<W1R(")#92!S97)V975R(&YE('-U<'!O<G1E('!A<R!L
M92!P87)T86=E(&1E<R!D;W-S:65R<RXB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$P.0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R(")#971T
M92!F96[J=')E(&1O:70@ZG1R92!A<'!E;.EE(&1E<'5I<R!L82!F96[J=')E
M(&1E('+I9&%C=&EO;BXB"@HC.B!T:')E860N<&AP.C$U,0IM<V=I9"`B5&AR
M96%D($1I<W!L87DB"FUS9W-T<B`B069F:6-H86=E(&1E<R!E;F9I;&%D97,B
M"@HC.B!T:')E860N<&AP.C<V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3`*
M;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@(E9U92!A=F5C(&QE<R!E;F9I
M;&%D97,B"@HC.B!M97-S86=E+G!H<#HR-C0@;6%I;&)O>"YP:'`Z-3DT('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C8Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M8V]M<&]S92YI;F,Z,3`@;&EB+U-E87)C:"YP:'`Z,C8*;7-G:60@(E1O(@IM
M<V=S='(@(L`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS9VED
M(")4;R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@9'4@9&5S=&EN871A:7)E
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(V"FUS
M9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE("(*(F-L
M:6-K:6YG+B(*;7-G<W1R("(B"B)0;W5R('/I;&5C=&EO;FYE<B!P;'5S:65U
M<G,@:71E;7,@X"!L82!F;VES+"!M86EN=&5N97H@96YF;VYCZ2!L92!B;W5T
M;VX@(@HBJZ!#=')LH+L@*%!#*2!O=2!#;VUM86YD("A-86,I(&5T(&-L:7%U
M97HN(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HQ,S0*;7-G:60@(B(*(E1O
M('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@
M=F5R<VEO;B!O9B!02%`@-2XP+C8@;W(@(@HB:&EG:&5R+B(*;7-G<W1R("(B
M"B)0;W5R('5T:6QI<V5R('5N92!C;VYN97AI;VX@5$Q3+"!V;W5S(&1E=F5Z
M(&%V;VER('5N92!V97)S:6]N(#4N,"XV(&]U("(*(G-U<.ER:65U<F4@9&4@
M4$A0+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X.`IM
M<V=I9"`B5&]T86P@071T86-H;65N=',@4VEZ93HB"FUS9W-T<B`B5&%I;&QE
M('1O=&%L92!D97,@<&GH8V5S(&IO:6YT97.@.B(*"B,Z(&9O;&1E<G,N<&AP
M.C,V-PIM<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(D-O<F)E:6QL92(*
M"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C,*;7-G:60@
M(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`B0V]R8F5I;&QEH#HB"@HC.B!L:6(O
M475O=&$O8WER=7,N<&AP.C8T(&QI8B]1=6]T82]M97)C=7)Y,S(N<&AP.C<Y
M(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC.B!L:6(O475O=&$O;&]G9FEL
M92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP.C4S(&QI8B]1=6]T82]M
M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O(')E=')I979E('%U;W1A
M(@IM<V=S='(@(E+I8W5PZ7)A=&EO;B!D=2!Q=6]T82!I;7!O<W-I8FQE(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,"!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS=V5R960B"FUS9W-T
M<B`B4V%N<R!RZ7!O;G-E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")-97-S
M86=E<R!S86YS('+I<&]N<V5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,3,*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(E)E<W1A=7)E<B(*"B,Z
M(&UA:6QB;W@N<&AP.C4W-R!M86EL8F]X+G!H<#HU.3`@;&EB+TU)344O2&5A
M9&5R<RYP:'`Z,C`T"FUS9VED(")5;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM
M<V=S='(@(D1E<W1I;F%T86ER97,@8V%C:.ES(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L
M960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(E!A<R!D92!P<FES
M92!E;B!C;VUP=&4@9'4@8V]M<&]S86YT(&1E('1Y<&6@.B`E<R(*"B,Z(&UA
M:6QB;W@N<&AP.C4U-PIM<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@(D1A
M=&4@:6YC;VYN=64B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N($E-05`@<F5S<&]N<V4@9G)O;2!T
M:&4@<V5R=F5R+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R(")2Z7!O
M;G-E($E-05`@:6YC;VYN=64@9'4@<V5R=F5U<BX@3&4@<V5R=F5U<B!A('+I
M<&]N9'6@.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C8*
M;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R(")2Z75N:6]N(&EN8V]N
M;G5E(@H*(SH@;6%I;&)O>"YP:'`Z-C`V"FUS9VED(")5;FMN;W=N(%)E8VEP
M:65N="(*;7-G<W1R(")$97-T:6YA=&%I<F4@:6YC;VYN=2(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<W"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*;7-G<W1R(")%9F9A8V5R
M(&QA('!H<F%S92!S96-RZ'1E(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E-A;G,@;F]M(@H*(SH@;65S<V%G
M92YP:'`Z-#DU(&UA:6QB;W@N<&AP.C8Y-2!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,R"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-0IM<V=I9"`B56YS965N
M(@IM<V=S='(@(DYO;B!V=2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C$R"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS*2(*
M;7-G<W1R(")392!DZ7-A8F]N;F5R(&1E*',I(&1O<W-I97(H<RDB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3(*;7-G:60@(E5P9&%T
M92(*;7-G<W1R(")-;V1I9FEE<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV,3(*;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G
M<W1R(")-;V1I9FEE<B!L92!S=&%T=70@9'4@8V]R<F5S<&]N9&%N="(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU."!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED(")5<&QO860B"FUS9W-T<B`B
M0VAA<F=E<B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI
M;F,Z-#$*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(E5T:6QI
M<V5R(&QA('9A;&5U<B!P87(@9.EF875T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(U-@IM<V=I9"`B57-E($E-05`@9F]L9&5R('-U8G-C<FEP=&EO
M;G,_(@IM<V=S='(@(E5T:6QI<V5R(&QE<R!A8F]N;F5M96YT<R!A=7@@9&]S
M<VEE<G,@24U!4*`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<R,PIM
M<V=I9"`B57-E(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*;7-G<W1R(")5=&EL
M:7-E<B!L92!D;W-S:65R('9I<G1U96P@9&4@8V]R8F5I;&QEH#\B"@HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,30S"FUS9VED(")5<V5R(@IM<V=S='(@
M(E5T:6QI<V%T975R(@H*(SH@86-L+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE('-P
M96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("(B"B),97,@9')O:71S('-PZ6-I9FGI<R!O;G0@8FEE;B#I=.D@871T<FEB
M=>ES(.`@;"=U=&EL:7-A=&5U<B"KH"5SH+L@<&]U<B!L92`B"B)D;W-S:65R
M(*N@)7.@NRXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B3F]M(&0G=71I;&ES871E=7(B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3<*;7-G:60@(E5S
M97)N86UE.B(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<J`Z(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C8X"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<B"FUS
M9W-T<B`B5F]I<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.CDR(&QI
M8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R(")6;VER("5S(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@
M(E9O:7(@;&$@8VQE9B!P=6)L:7%U92`E<R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,3D*;7-G:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@
M<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(E9O:7(@;&4@8V]N=&5N=2!(5$U,
M(&1A;G,@=6YE(&9E;NIT<F4@<^EP87+I92(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C(X"FUS9VED(")6:65W($UE<W-A9V5S(@IM<V=S
M='(@(E9O:7(@;&5S(&UE<W-A9V5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I
M97<@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B5F]I<B!L82!C;&5F
M('!R:7;I92!P97)S;VYN96QL92(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")6:65W
M(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B5F]I<B!L82!C;&5F('!U
M8FQI<75E('!E<G-O;FYE;&QE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R
M(")6;VER(&QE<R!%;F9I;&%D97,B"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38V"FUS
M9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R(")6;VER(.ET:7%U971T92(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"FUS9VED(")6:65W
M(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B5F]I
M<B!L82!P:>AC92!J;VEN=&4@9&%N<R!U;F4@9F5NZG1R92!SZ7!A<NEE(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"FUS9VED(")6:65W
M(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B5F]I<B!L
M92!C;VYT96YU(&1A;G,@=6YE(&9E;NIT<F4@<^EP87+I92(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ-#$*;7-G:60@(E9I97<@979E;G0B"FUS
M9W-T<B`B5F]I<B!L97,@Z7;I;F5M96YT<R(*"B,Z(&9O;&1E<G,N<&AP.C,U
M.2!M86EL8F]X+G!H<#HU,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!M
M97-S86=E<R!I;B`E<R(*;7-G<W1R(")6;VER(&QE<R!M97-S86=E<R!D86YS
M("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN
M8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@
M;&]G:6XZ(@IM<V=S='(@(E9U92!O=2!B;^YT92#@(&%F9FEC:&5R(&%P<NAS
M(&QA(&-O;FYE>&EO;J`Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$W,0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(E9O:7(@;&$@=.)C:&4B
M"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`T"FUS9VED(")6:65W
M('1H92!);6%G97,B"FUS9W-T<B`B5F]I<B!L97,@:6UA9V5S(@H*(SH@<V5A
M<F-H+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FER='5A;"!&;VQD
M97(@7"(E<UPB(&-R96%T960@<W5C8V5S9G5L;'DN(@IM<V=S='(@(DQE(&1O
M<W-I97(@=FER='5E;*N@)7.@NR!A(.ETZ2!C<NGI(&%V96,@<W5C8^AS+B(*
M"B,Z(&QI8B]!=71H+VEM<"YP:'`Z,3<U"FUS9VED(")6:7)T=6%L($9O;&1E
M<B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&]S<VEE<B!V:7)T=65L(&EN
M97AI<W1A;G0N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@
M;&EB+TE-05`O5')E92YP:'`Z,3,S(&QI8B])34%0+U1R964N<&AP.C$T-@HC
M.B!L:6(O24U!4"]4<F5E+G!H<#HQ-#@@;&EB+TE-05`O5')E92YP:'`Z,34R
M(&QI8B])34%0+U1R964N<&AP.C$U,PHC.B!L:6(O24U!4"]4<F5E+G!H<#HS
M-C,@;&EB+TE-05`O5')E92YP:'`Z,S@W(&QI8B])34%0+U1R964N<&AP.C0R
M-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(@IM<V=S='(@(D1O<W-I97)S('9I
M<G1U96QS(@H*(SH@<V5A<F-H+G!H<#HR-#4*;7-G:60@(E9I<G1U86P@1F]L
M9&5R<R!R97%U:7)E(&$@;&%B96PN(@IM<V=S='(@(E5N92#I=&EQ=65T=&4@
M97-T(&]B;&EG871O:7)E('!O=7(@;&5S(&1O<W-I97)S('9I<G1U96QS+B(*
M"B,Z(&QI8B]61F]L9&5R+G!H<#HQ-S8@;&EB+U9&;VQD97(N<&AP.C$X-@IM
M<V=I9"`B5FER='5A;"!)3D)/6"(*;7-G<W1R(")";^YT92!D92!RZ6-E<'1I
M;VX@=FER='5E;&QE(@H*(SH@9F]L9&5R<RYP:'`Z,SDU"FUS9VED(")6:7)T
M=6%L($E.0D]8($9O;&1E<B(*;7-G<W1R(")$;W-S:65R(&1E('+I8V5P=&EO
M;B!V:7)T=65L(@H*(SH@;6%I;&)O>"YP:'`Z-#,U(&QI8B]-86EL8F]X+G!H
M<#HQ-S`@;&EB+U9&;VQD97(N<&AP.C$Q,2!L:6(O5D9O;&1E<BYP:'`Z,3(S
M"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(D-O<F)E:6QL92!V:7)T
M=65L;&4B"@HC.B!F;VQD97)S+G!H<#HS.3(*;7-G:60@(E9I<G1U86P@5')A
M<V@@1F]L9&5R(@IM<V=S='(@(D1O<W-I97(@9&4@8V]R8F5I;&QE('9I<G1U
M96PB"@HC.B!L:6(O365S<V%G92YP:'`Z-C,Y"FUS9VED(")6:7)T=6%L(%1R
M87-H($9O;&1E<B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&]S<VEE<B!D
M92!C;W)B96EL;&4@=FER='5E;"!I;F5X:7-T86YT+B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z,3,S"FUS9VED(")6:7)T=6%L(&9O;&1E<B!L
M86)E;"(*;7-G<W1R(").;VT@9'4@9&]S<VEE<B!V:7)T=65L(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-SD*;7-G:60@(E=A<FYI;F<B"FUS
M9W-T<B`B071T96YT:6]N(@H*(SH@;&]G:6XN<&AP.C$T.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D)I96YV96YU92#@
M("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P-PIM<V=I9"`B(@HB
M5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H
M97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@(@HB;W(@:6YN;V-E;G0_
M(@IM<V=S='(@(B(*(E%U92!F86ER92!D97,@<&]U<G)I96QS(&%P<NAS('%U
M)VEL<R!A:65N="#I=.D@9.EC;&%RZ7,@<&]U<G)I96P@;W4@(@HB;.EG:71I
M;66@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,34*;7-G:60@(B(*
M(E=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R
M87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE
M=&5D/R(*;7-G<W1R("(B"B)1=6%N9"!V;W5S(&3I=')U:7-E>B!D97,@;65S
M<V%G97,L(&QE<R!DZ7!L86-E<B!D86YS('9O=')E(&-O<F)E:6QL92!A=2!L
M:65U("(*(F1E(&QE<R!M87)Q=65R(&-O;6UE(&3I=')U:71SH#\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DU"FUS9VED(")7:&5N(&]P96YI;F<@
M82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R
M="!O;C\B"FUS9W-T<B`B475E;&QE('!A9V4@9&4@9.EM87)R86=E(.`@;"=O
M=79E<G1U<F4@9"=U;F4@;F]U=F5L;&4@8F_N=&6@/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-C$*;7-G:60@(E=H96X@<V%V:6YG('-E;G0M;6%I
M;"P@<VAO=6QD('=E('-A=F4@871T86-H;65N="!D871A/R(*;7-G<W1R("(B
M"B),;W)S<75E(&PG;VX@96YR96=I<W1R92!L92!C;W5R<FEE<B!E;G9O>>DL
M(&1O:70M;VX@96YR96=I<W1R97(@;&5S('!IZ&-E<R`B"B)J;VEN=&5S(#\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(V"FUS9VED("(B"B)7:&5N
M('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O
M;6%I;B!S:&]U;&0@=V4@87!P96YD('1O("(*(G5N<75A;&EF:65D(&%D9')E
M<W-E<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@7")`7"(I/R(*;7-G<W1R
M("(B"B),;W)S(&1E(&PG96YV;VD@9'4@8V]U<G)I97(@;W4@9&4@;"=E>'!A
M;G-I;VX@9&5S(&%D<F5S<V5S+"!Q=65L(&1O;6%I;F4@(@HB86IO=71E<B!A
M=7@@861R97-S97,@;F]N+7%U86QI9FGI97,@*&%D<F5S<V5S('-A;G,@JZ!`
MH+LIH#\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@
M(E=H:71E;&ES="(*;7-G<W1R("),:7-T92!B;&%N8VAE(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,V('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4T.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38V
M"FUS9VED(")997,B"FUS9W-T<B`B3W5I(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HU.`IM<V=I9"`B66]U(&%R92!A
M8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N
M="AS*3HB"FUS9W-T<B`B5F]U<R!A;&QE>B!R87!A=')I97(@;&4@8V]U<G)I
M97(@9&5S(&-O;7!T97,@<W5I=F%N='.@.B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P"FUS9VED("(B"B)9;W4@87)E
M(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@
M:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@(E9O=7,@
M86QL97H@9.ET<G5I<F4@=&]U<R!L97,@;65S<V%G97,@9'4H9&5S*2!D;W-S
M:65R*',I('-U:79A;G0H<RF@.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O
M;&1E<G-?8V]N9FER;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN
M9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@
M(E9O=7,@86QL97H@9.ET<G5I<F4@;&4H<RD@9&]S<VEE<BAS*2!S=6EV86YT
M*',IH#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU
M-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@
M(EEO=2!A<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+B(*;7-G
M<W1R(")6;W5S(&%L;&5R(&-O<&EE<B]DZ7!L86-E<B!V97)S('5N(&YO=79E
M874@9&]S<VEE<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C$P,@IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@
M=&\@(@IM<V=S='(@(E9O=7,@86QL97H@8W+I97(@=6X@<V]U<RUD;W-S:65R
M(&1E("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T
M"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BXB
M"FUS9W-T<B`B5F]U<R!A;&QE>B!C<NEE<B!U;B!D;W-S:65R(&%U(&YI=F5A
M=2!S=7#I<FEE=7(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S$X"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!F;VQD97)S+B(*;7-G<W1R
M(")6;W5S(&XGZG1E<R!P87,@875T;W)I<^D@X"!C<NEE<B!D97,@9&]S<VEE
M<G,N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(U"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!F;VQD97)S+B(*;7-G<W1R(")6;W5S(&XGZG1E<R!P87,@875T;W)I<^D@
MX"!C<NEE<B!P;'5S(&1E("5D(&1O<W-I97)S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E(')E;F%M
M:6YG('1H92!F;VQD97(Z("(*;7-G<W1R(")6;W5S(&%L;&5Z(')E;F]M;65R
M(&QE(&1O<W-I97*@.B`B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@
M=&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@
M=&5X=#H@)6,@9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@
M)7,@9F]R('1H92!S:6=N871U<F4N(@IM<V=S='(@(B(*(E9O=7,@<&]U=F5Z
M('5T:6QI<V5R(&QE<R!C;VYT96YE=7)S('-U:79A;G1S(&1A;G,@;&4@=&5X
M=&4@9&4@;&$@<&%P971E<FEEH#H@(@HB)6,@<&]U<B!L92!C;VYT96YU(&1U
M(&UE<W-A9V4@8V]U<F%N=*`[("5S('!O=7(@;&$@<VEG;F%T=7)E+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")6;W5S
M(&YE('!O=79E>B!P87,@=F]U<R!DZ7-A8F]N;F5R(&1E(*N@)7.@NRXB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HS-`IM
M<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E
M<G9I8V4@86=R965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"`B"B)T
M;R!L;V=I;BXB"FUS9W-T<B`B(@HB5F]U<R!N)^ET:65Z('!A<R!D)V%C8V]R
M9"!S=7(@;&5S('1E<FUE<R!D92!L)V%C8V]R9"!D92!S97)V:6-E+"!V;W5S
M(&XG879E>B`B"B)D;VYC('!A<R!L82!P97)M:7-S:6]N(&1E('9O=7,@8V]N
M;F5C=&5Z+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S`*;7-G:60@
M(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@
M=&\@=&AI<R!F;VQD97(B"FUS9W-T<B`B5F]U<R!N)V%V97H@<&%S(&PG875T
M;W)I<V%T:6]N(&1E(&UO9&EF:65R(&PG86-CZ',@X"!C92!D;W-S:65R(@H*
M(SH@;&EB+TUA:6QL;V<N<&AP.C$S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO
M=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T<B`B5F]U<R!T<F%N<V;I<F5Z
M(&-E(&UE<W-A9V4@X"`E)7,@9&%N<R!L92!RZ7!E<G1O:7)E("5S+B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!H879E("5S(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B5F]U
M<R!A=F5Z("5S(&YO=79E875X(&UE<W-A9V5S+B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED(")9;W4@:&%V92`Q(&YE=R!M97-S
M86=E+B(*;7-G<W1R(")6;W5S(&%V97H@,2!N;W5V96%U(&UE<W-A9V4N(@H*
M(SH@8V]M<&]S92YP:'`Z-#@P"FUS9VED(")9;W4@:&%V92!A;')E861Y('-U
M8FUI='1E9"!T:&ES('!A9V4N(@IM<V=S='(@(E9O=7,@879E>B!DZ6K@(&5N
M=F]YZ2!C971T92!P86=E+B(*"B,Z(&QI8B])35`N<&AP.C$P-38*;7-G:60@
M(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*
M;7-G<W1R(")6;W5S(&%V97H@9'4@;F]U=F5A=2!C;W5R<FEE<B!D86YS(&QE
M(&1O<W-I97(@<W5I=F%N=*`Z(@H*(SH@;&EB+TE-4"YP:'`Z,3`V,0IM<V=I
M9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S
M.B(*;7-G<W1R(")6;W5S(&%V97H@9'4@;F]U=F5A=2!C;W5R<FEE<B!D86YS
M(&QE<R!D;W-S:65R<R!S=6EV86YT<Z`Z(@H*(SH@8V]M<&]S92YP:'`Z,34S
M"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@<F5C:7!I96YT
M+B(*;7-G<W1R(")6;W5S(&1E=F5Z(&%V;VER(&%U(&UO:6YS('5N(&1E<W1I
M;F%T86ER92XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,#8*;7-G
M:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G92(*;7-G<W1R
M("(B"B)6;W5S(&1E=F5Z(&5N=')E<B!L82!P:')A<V4@<V5C<NAT92!P;W5R
M('9O=')E(&-L968@4$=0('!R:7;I92!A9FEN(&1E('9O:7(@(@HB8V4@;65S
M<V%G92(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C4T"FUS9VED
M("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3
M+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS
M9W-T<B`B(@HB5F]U<R!D979E>B!E;G1R97(@;&$@<&AR87-E('-E8W+H=&4@
M<&]U<B!V;W1R92!C;&5F(%,O34E-12!P<FEVZ64@869I;B!D92`B"B)V;VER
M(&-E(&UE<W-A9V4B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T
M+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T
M+B(*;7-G<W1R(")6;W5S(&1E=F5Z(&0G86)O<F0@<^EL96-T:6]N;F5R('5N
M92!B;^YT92XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#4*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S
M='(@(E9O=7,@9&5V97H@<^EL96-T:6]N;F5R('5N(&-O;7!T92#@('-U<'!R
M:6UE<BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C@Q
M"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS
M9W-T<B`B5F]U<R!D979E>B!D)V%B;W)D('/I;&5C=&EO;FYE<B!U;F4@861R
M97-S92XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV
M,B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#@*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8S"FUS9VED(")9;W4@
M;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM<V=S
M='(@(E9O=7,@9&5V97H@<^EL96-T:6]N;F5R(&%U(&UO:6YS('5N(&UE<W-A
M9V4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G<W1R(")6
M;W5S(&1E=F5Z(&-H;VES:7(@=6X@9&5S=&EN871A:7)E+B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@;F5E9"!T;R!H879E(%PB)7-<(B!E;F%B;&5D(&EN('EO=7(@
M;6%I;G1E;F%N8V4@;W!T:6]N<RXB"FUS9W-T<B`B3F]T9:`Z(*N@)7.@NR!D
M;VET(.IT<F4@86-T:7;I(&1A;G,@=F]S(&]P=&EO;G,@9&4@;6%I;G1E;F%N
M8V4N(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S
M+B(*;7-G<W1R(")6;W5S(&%V97H@<F5D:7)I9^D@8V4@;65S<V%G92!V97)S
M("5S(&1A;G,@)25S+B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N
M("5S+B(*;7-G<W1R(")6;W5S(&%V97H@<NEP;VYD=2#@(&-E(&UE<W-A9V4@
M;&4@)7,N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3$U"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R
M92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)5;F4@97)R
M975R(&5S="!S=7)V96YU92!L;W)S(&1E(&QA('-O=7-C<FEP=&EO;B#@(*N@
M)7.@NRX@3&4@<V5R=F5U<B!A("(*(G+I<&]N9'4B"@HC.B!L:6(O1F]L9&5R
M+G!H<#HU-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N
M<W5B<V-R:6)E9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V
M97(@<V%I9"(*;7-G<W1R(")6;W5S(&XG879E>B!P87,@Z73I(&3I<V%B;VYN
MZ2!D92"KH"5SH+LN($QE('-E<G9E=7(@82!RZ7!O;F1U(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U
M8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")6;W5S
M(&%V97H@8FEE;B#I=.D@86)O;F[I(.`@JZ`E<Z"[(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-3<P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E
M<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B5F]U
M<R!A=F5Z(&)I96X@Z73I(&3I<V%B;VYNZ2!D92"KH"5SH+LB"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z.3@*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R
M(")6;W1R92!N;VTB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G
M:60@(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B5F]S
M(&-L969S(%!'4"!P=6)L:7%U92]P<FEVZ64B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C<Q('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-@IM<V=I
M9"`B66]U<B!0<FEV871E($ME>2(*;7-G<W1R(")6;W1R92!C;&5F('!R:7;I
M92(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C<@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<Q"FUS9VED(")9;W5R(%!U8FQI8R!+97DB"FUS9W-T
M<B`B5F]T<F4@8VQE9B!P=6)L:7%U92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-C4*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH
M;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`B5F]T<F4@861R97-S92!D92!RZ7!O
M;G-EH#H@/&5M/BAO<'1I;VYN96QL92D\+V5M/B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-#D*;7-G:60@(EEO=7(@4R]-24U%(%!U8FQI8R]0
M<FEV871E($-E<G1I9FEC871E<R(*;7-G<W1R(")6;W,@8V5R=&EF:6-A=',@
M4R]-24U%('!U8FQI8R]P<FEVZ2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M86-C;W5N=%]S96QE8W0N:6YC.C$V"FUS9VED(")9;W5R(&%C8V]U;G1S.B(*
M;7-G<W1R(")6;W,@8V]M<'1E<Z`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$W,PIM<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH
M;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO
M96T^(@IM<V=S='(@(B(*(E9O<R!A9')E<W-E<R!A;'1E<FYA=&EV97.@.B`\
M96T^*&]P=&EO;FYE;"P@96YT<F5Z(&-H87%U92!A9')E<W-E('-U<B!U;F4@
M(@HB;F]U=F5L;&4@;&EG;F4I/"]E;3XN("(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$P,0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G92!T>7!E+B(*
M;7-G<W1R("(B"B)6;W1R92!N879I9V%T975R(&YE('-U<'!O<G1E('!A<R!L
M)V%F9FEC:&%G92!E;B!L:6=N92!D97,@:6UA9V5S(&1E(&-E('1Y<&4N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D969A
M=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(E9O
M=')E(&5N8V]D86=E('!A<B!DZ69A=70@<&]U<B!L)V5N=F]I(&1E<R!M97-S
M86=E<Z`Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC
M.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@
M<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B5F]T<F4@;>ET:&]D92!D92!C
M:&EF9G)E;65N="!P87(@9.EF875T('!O=7(@;"=E;G9O:2!D97,@;65S<V%G
M97.@.B(*"B,Z(&%T=&%C:&UE;G0N<&AP.CDT"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@;&EN:V5D(&%T=&%C:&UE;G0@:&%S(&)E96X@9&]W;FQO
M861E9"!B>2!A="!L96%S="!O;F4@=7-E<BY<;B(*(EQN(@HB071T86-H;65N
M="!N86UE.B`E<UQN(@HB071T86-H;65N="!D871E.B`E<UQN(@HB7&XB"B)#
M;&EC:R!O;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@<&5R;6%N96YT;'D@9&5L
M971E('1H92!A='1A8VAM96YT.EQN(@HB)7,B"FUS9W-T<B`B(@HB5F]T<F4@
M<&GH8V4@:F]I;G1E(&QIZ64@82#I=.D@=.ELZ6-H87)GZ64@<&%R(&%U(&UO
M:6YS('5N92!P97)S;VYN92Y<;B(*(EQN(@HB3F]M(&1E(&QA('!IZ&-E(&IO
M:6YT9:`Z("5S7&XB"B)$871E(&1E(&QA('!IZ&-E(&IO:6YT9:`Z("5S7&XB
M"B)<;B(*(D-L:7%U97H@<W5R(&QE(&QI96X@<W5I=F%N="!P;W5R('-U<'!R
M:6UE<B!DZ69I;FET:79E;65N="!C971T92!P:>AC92`B"B)J;VEN=&6@.EQN
M(@HB)7,B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX.0IM<V=I
M9"`B66]U<B!M97-S86=E('=A<R!S=6-C97-S9G5L;'D@9&5L:79E<F5D+B(*
M;7-G<W1R(")6;W1R92!M97-S86=E(&$@8FEE;B#I=.D@9&ES=')I8G7I+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@(EEO=7(@<VEG
M;F%T=7)E.B(*;7-G<W1R(")6;W1R92!S:6=N871U<F6@.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V%D9')E<W-E<T)L;V-K<RYJ<SHW"FUS9VED(");
M2&ED92!!9&1R97-S97-=(@IM<V=S='(@(EM#86-H97(@;&5S(&%D<F5S<V5S
M72(*"B,Z(&-O;7!O<V4N<&AP.C$R.#8@;65S<V%G92YP:'`Z,C@X(&UA:6QB
M;W@N<&AP.C4S-2!L:6(O0V]M<&]S92YP:'`Z.#,X"FUS9VED(");3F\@4W5B
M:F5C=%TB"FUS9W-T<B`B6U!A<R!D92!S=6IE=%TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z.`IM<V=I9"`B6U-H;W<@
M061D<F5S<V5S("TB"FUS9W-T<B`B6TUO;G1R97(@;&5S(&%D<F5S<V5S("TB
M"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@861D<F5S<V5S("T@)7,@<F5C:7!I96YT<UTB"FUS9W-T
M<B`B6TUO;G1R97(@;&5S(&%D<F5S<V5S("T@)7,@9&5S=&EN871A:7)E<UTB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*;7-G:60@
M(E]"8V,B"FUS9W-T<B`B0V-?:2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHQ-@IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R("),:7-T92!?;F]I
M<F4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-30*;7-G
M:60@(E]#8R(*;7-G<W1R(")?0V,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHX"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"FUS
M9VED(")?1&5L971E(@IM<V=S='(@(E]3=7!P<FEM97(B"@HC.B!L:6(O24U0
M+G!H<#HY-C(*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@(D1?;W-S:65R<R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C@Q"FUS9VED(")?
M261E;G1I='DB"FUS9W-T<B`B261E7VYT:73I(@H*(SH@;&EB+TE-4"YP:'`Z
M.3,Q"FUS9VED(")?26YB;W@B"FUS9W-T<B`B0F_N=&4@9&4@<NEC97!T7VEO
M;B(*"B,Z(&QI8B])35`N<&AP.C$P,#,*;7-G:60@(E],;V<@;W5T(@IM<V=S
M='(@(D3I8V]N;F5?>&EO;B(*"B,Z(&UE<W-A9V4N<&AP.C,X-`IM<V=I9"`B
M7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(E-O=7)C92!D=2!?;65S<V%G92(*
M"B,Z(&QI8B])35`N<&AP.CDU.0IM<V=I9"`B7TYE=R!-97-S86=E(@IM<V=S
M='(@(E].;W5V96%U(&UE<W-A9V4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E]0<FEN="(*;7-G<W1R("))
M;5]P<FEM97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@Y"FUS9VED(")?
M4')I;W)I='DB"FUS9W-T<B`B7U!R:6]R:73I(@H*(SH@;6%I;&)O>"YP:'`Z
M-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@
M(E]2869R8>YC:&ER("5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C@*;7-G:60@(E]297!L>2(*;7-G<W1R(")?4NEP;VYD
M<F4B"@HC.B!L:6(O24U0+G!H<#HY-C0*;7-G:60@(E]396%R8V@B"FUS9W-T
M<B`B4F5C7VAE<F-H92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R-0IM<V=I
M9"`B7U-E;F0@365S<V%G92(*;7-G<W1R(")%;G9O7WEE<B!L92!M97-S86=E
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS
M,@IM<V=I9"`B7U1H<F5A9"(*;7-G<W1R(")%;F9I7VQA9&4B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*;7-G:60@(E]4;R(*;7-G
M<W1R(")?02(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S
M"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`B4F5S=&%?=7)E<B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B
M7U9I97<@5&AR96%D(@IM<V=S='(@(E]6;VER(&QE<R!%;F9I;&%D97,B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI
M<W0B"FUS9W-T<B`B3&E?<W1E(&)L86YC:&4B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3<U"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")D97-T
M:6YA=&%I<F4@:6YC;VYN=2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-3$*;7-G
M:60@(F%T=&%C:&UE;G0B"FUS9W-T<B`B<&GH8V4@:F]I;G1E(@H*(SH@=FEE
M=RYP:'`Z.3<*;7-G:60@(F%T=&%C:&UE;G1S+GII<"(*;7-G<W1R(")P:>AC
M92!J;VEN=&4N>FEP(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-3`T"FUS9VED(")B>71E<R(*;7-G<W1R(")O8W1E=',B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,3DY"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F
M:6QE(@IM<V=S='(@(FEM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!D
M92!S;W)T:64B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<Q"FUS9VED(")C86YN
M;W0@;W!E;B!I;G!U="(*;7-G<W1R(")I;7!O<W-I8FQE(&0G;W5V<FER(&PG
M96YT<NEE(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V,PIM<V=I9"`B8V]M;6%N
M9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(F5R<F5U<B!D)W5T:6QI<V%T
M:6]N(&1E(&QA(&QI9VYE(&1E(&-O;6UA;F1E(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(Q.0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")E
M<G)E=7(@9&4@8V]N9FEG=7)A=&EO;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M.34*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T
M<B`B86)S96YC92!C<FET:7%U92!D)W5N(&9I8VAI97(@<WES=.AM92(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ-C<*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R
M(@IM<V=S='(@(F5R<F5U<B!D92!F;W)M870@9&4@9&]N;NEE(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C(R,PIM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S
M='(@(F5N='+I92!N;VX@=')O=7;I(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS9W-T<B`B9&4B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3<Y"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R(")N;VT@9"=H]'1E(&EN8V]N;G4B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,C`S"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B
M97)R975R(&0G96YT<NEE+W-O<G1I92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M.#<*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(F5R
M<F5U<B!L;V=I8VEE;&QE(&EN=&5R;F4B"@HC.B!S;6EM92YP:'`Z,CD@<&=P
M+G!H<#HV.`IM<V=I9"`B:V5Y(@IM<V=S='(@(F-L968B"@HC.B!F;VQD97)S
M+G!H<#HQ-#$*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R(")F:6-H:65R
M(&1E(&)O[G1E(&1E(&-O=7)R:65R(@H*(SH@8V]M<&]S92YP:'`Z,3`Y-R!L
M:6(O365S<V%G92YP:'`Z-#<V"FUS9VED(")N86UE(@IM<V=S='(@(FYO;2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW-@IM<V=I9"`B
M;F]N92(*;7-G<W1R(")A=6-U;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHQ,#4*;7-G:60@(F]R(@IM<V=S='(@(F]U(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C(Q-0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS
M9W-T<B`B<&5R;6ES<VEO;B!R969U<^EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O861D<F5S<V5S0FQO8VMS+FIS.C@*;7-G:60@(G)E8VEP:65N='-=
M(@IM<V=S='(@(F1E<W1I;F%T86ER97-=(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C(Q,0IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@
M(F5R<F5U<B!D:7-T86YT92!D86YS(&QE('!R;W1O8V]L92(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.#,*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS
M9W-T<B`B<V5R=FEC92!N;VX@9&ES<&]N:6)L92(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W(B
M"FUS9W-T<B`B97)R975R(&0G;W)T:&]G<F%P:&4B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R
M<R(*;7-G<W1R(")E<G)E=7)S(&0G;W)T:&]G<F%P:&4B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3DQ"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B97)R
M975R('-Y<W3H;64B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`W"FUS9VED(")T
M96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("+I8VAE8R!T96UP;W)A:7)E(@H*
M(SH@;&EB+T9I;'1E<BYP:'`Z-3$*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM
M<V=S='(@(G9O=')E(&QI<W1E(&YO:7)E(@H*(SH@;&EB+T9I;'1E<BYP:'`Z
M-C$*;7-G:60@(GEO=7(@=VAI=&5L:7-T(@IM<V=S='(@(G9O=')E(&QI<W1E
M(&)L86YC:&4B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+W1H7U1(+G!O````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,U,C`W-0`Q,#0Q-S,V
M,C<V-``P,3<R,3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!4:&%I('1R86YS;&%T:6]N<R!F;W(@26UP('!A8VMA9V4N
M"B,@0V]P>7)I9VAT("A#*2`R,#`S($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I
M;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T
M:&4@26UP('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P
M,#,N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M($EM<"`S+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q
M-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`S+3`R+3`X(#$U
M.C0U*S`W,#!<;B(*(DQA<W0M5')A;G-L871O<CH@4W5R87-A:R!3<FES87=A
M;B`\<W5R87-A:T!R:7)C+F%C+G1H/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X
M;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]5$E3+38R,%QN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z("(*;7-G
M<W1R("(@("`@(""VUJ<Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,34*;7-G
M:60@(B`@("`@(%1O.B`B"FUS9W-T<B`B("`@("`@MM:G.B`B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@1&%T93H@(@IM<V=S='(@(B`@
M("#'T;FWU>@Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#8*;7-G:60@(B`@
M("!&<F]M.B`B"FUS9W-T<B`B("`@(*C2H3H@(@H*(SH@;6%I;&)O>"YP:'`Z
M-#(R('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HT,3(*;7-G:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B(.##
MU^C-ISH@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<P
M"FUS9VED("(@:6X@(@IM<V=S='(@(B#CN2`B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@
M(B,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B
M"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)60@365S<V%G97,B"FUS9W-T<B`B)60@J-*A("5D(*+IS:3'TL$B"@HC
M.B!M86EL8F]X+G!H<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+ARK2G
MHNG-I,?2P;?5Z*'#S:?AQ>G'(@H*(SH@;&EB+U-P86TN<&AP.C$W.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(J+IS:3'TL&YU>GDM.FVV:'#TL*GTKG'Z-+@
MN^>YH=+#P[JAQ[GDN\+1I[S9Z;39X<7#T+JZHLVGI-BSX<7IQR(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D
M(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS
M9W-T<B`BHNG-I,?2P;G5Z>2TZ;;9H</2PJ?2N<?HTN"[Y[FATL/#NJ''N>2[
MPM&GO-GIM-GAQ</0NKJBS:>DV+/AQ>G'(@H*(SH@;&EB+U-P86TN<&AP.C$W
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`BHNG-I,?2P;G5Z>2TZ;;9H</2PJ?2N<?HTN"[
MY[FATL/#NJ''N>2[PM&GO-GIM-GAQ</0NKJBS:>DV+/AQ>G'(@H*(SH@;&EB
M+U-P86TN<&AP.C$U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@
M(J+IS:3'TL&YU>GDM.FVV:'#TL*GTKG'Z-+@N^>YH=+#P[JAQ[GDN\+1I[S9
MZ;39X<7#T+JZHLVGI-BSX<7IQR(*"B,Z(&UA:6QB;W@N<&AP.C,W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G
M<W1R("(E9""VUJ<@)60@J-*A("5D(*+IS:3'TL$B"@HC.B!M86EL8F]X+G!H
M<#HV-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H
M;'DN<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI
M<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@
M(B5S(,'5S<+9Z.'%Z<<@XK_%X+3-P^P@)7,@J-:GY,'HMMFAX+O%U>C"N:K7
MZ,TB"@HC.B!L:6(O365S<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S
M96YT;6%I;%]M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO
M;G1H+B(*;7-G<W1R("+BO\7@M,W#["`E<R"HT+;9H>"[Q=7HPKFJU^C-M]BA
MYB"UZ;G@M-?-N2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I
M;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!H87,@=&5N=&%T:79E;'D@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A
M="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(N*_Q>"TS</L(%PB)7-<(B#DM.FV
MV:'@N\75Z,*YJM?HS>"[Y[D@7"(E<UPB(.##U<*ZP^G-PN'%Z<<B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S('=I<VAE<R!T;R!A;6UE;F0@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@
M:6YF;W)M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N
M<&AP.C(X-2!M97-S86=E+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]T;W`N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F
M;F)S<#MO9B9N8G-P.R5D*2(*;7-G<W1R("(E<SH@)7,@*"5D)FYB<W`[J-*A
M)FYB<W`[)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$S,PIM<V=I9"`B*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@
M;F5X="!S8W)E96XN*2(*;7-G<W1R("(HNM&YM]:AI,?2P>"[Q=7HPKGAN\6G
MX<7IQ^2[PM&GR[GITK7HS>2[*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHQ,C`*;7-G:60@(BA$:7-C87)D(&%L;"!C:&%N9V5S(&%N
M9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BDB"FUS9W-T<B`B*,*A
MX,74H:'2P^"[Q=7HPKGAN\6GM]'II\O!M.'%T*'%T;K*V>C+N>G2J,W@HM7"
MN:BTR\'2PB(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ
M-@IM<V=I9"`B*$A434PI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*%!L86EN(%1E>'0I(@IM<V=S
M='(@(B(*"B,Z('-P96QL:6YG+G!H<#HR.#`*;7-G:60@(B(*(BA2971U<FX@
M=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N
M9V5S(&UA9&4@=&AU<R!F87(N("`B"B)#:&%N9V5S(&]N('1H92!C=7)R96YT
M('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*+K1
MN;?6H>"IOM+0H=+#X+O%U>C"N>&[Q:>WU>B\Z-*YP=+AQ>G'X<70H<71NLK9
MZ,NYZ=*HS>"BU<*YJ+3+P=+"("(*(J3'TL'@N\75Z,*YX;O%I[?5Z."AU+2B
MUNFYX[G+N>G2J,VYU>FHT.3!Z+;9H;K1N;?6H2DB"@HC.B!S<&5L;&EN9RYP
M:'`Z,C<W"B,L(&9U>GIY"FUS9VED("(B"B(H4V5N9"!M97-S86=E(&%F=&5R
M(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S
M(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D
M+BDB"FUS9W-T<B`B(@HB*+K1N;?6H>"IOM+0H=+#X+O%U>C"N>&[Q:>WU>B\
MZ-*YP=+AQ>G'X<70H<71NLK9Z,NYZ=*HS>"BU<*YJ+3+P=+"("(*(J3'TL'@
MN\75Z,*YX;O%I[?5Z."AU+2BUNFYX[G+N>G2J,VYU>FHT.3!Z+;9H;K1N;?6
MH2DB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM
M<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J
M(."^U.C!JM?HS;7HS>2[N=7IXK3"I,74H;?5Z+O8Z,$@3TL@*B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS9VED("(J(%!L
M96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(*'#V+/2X,77
MS:&JU^C-M]7HM>G-IZ'2PR`J(@H*(SH@;6%I;&)O>"YP:'`Z,3<T"B,L(&9U
M>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`BX,VAQ=&AR;/L(%PB)7-<(B#DM.FVV:'%NN'%Z<<B"@HC.B!L:6(O4W!A
M;2YP:'`Z,3@P"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@
M<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`BHNG-I,?2P;G5Z>2TZ;;9H</2PJ?2N<?HTN"[Y[FA
MTL/#NJ''N>2[PM&GO-GIM-GAQ</0NKJBS:>DV+/AQ>G'(@H*(SH@;&EB+U-P
M86TN<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N
M(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("*BZ<VDQ]+!N=7IY+3I
MMMFAP]+"I]*YQ^C2X+OGN:'2P\.ZH<>YY+O"T:>\V>FTV>'%P]"ZNJ+-IZ38
ML^'%Z<<B"@HC.B!L:6(O4W!A;2YP:'`Z,3<R"B,L(&9U>GIY"FUS9VED("(Q
M(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*BZ<VDQ]+!N=7IY+3IMMFA
MP]+"I]*YQ^C2X+OGN:'2P\.ZH<>YY+O"T:>\V>FTV>'%P]"ZNJ+-IZ38L^'%
MZ<<B"@HC.B!L:6(O4W!A;2YP:'`Z,34R"B,L(&9U>GIY"FUS9VED("(Q(&UE
M<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`BHNG-
MI,?2P;G5Z>2TZ;;9H</2PJ?2N<?HTN"[Y[FATL/#NJ''N>2[PM&GO-GIM-GA
MQ</0NKJBS:>DV+/AQ>G'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q
M.0HC+"!F=7IZ>0IM<V=I9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`BS=&A
MHL/0OM3@R,DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(R"B,L(&9U
M>GIY"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`BS=&AHL/0OM3@
MR,DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(P"B,L(&9U>GIY"FUS
M9VED("(R-3`@8VAA<F%C=&5R<R(*;7-G<W1R("+-T:&BP]"^U.#(R2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C$*(RP@9G5Z>GD*;7-G:60@(C4P
M,"!C:&%R86-T97)S(@IM<V=S='(@(LW1H:+#T+[4X,C)(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z,38R"B,L('!H<"UF;W)M870*;7-G:60@
M(D$@;&%R9V4@:6UA9V4@;F%M960@)7,@:7,@871T86-H960@=&\@=&AI<R!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M97-S86=E('EO=2!H879E('-E
M;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M
M('1H92`B"B)R96-I<&EE;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!3D0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,`IM<V=I9"`B06-C97!T(')E
M<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4X-PIM<V=I9"`B06-C97!T(')E<75E<W0@86YD(&%D9"!I="!T;R!M>2!C
M86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S4S"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,C4W"FUS9VED(")!8V-E<'1E9#H@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"B,L
M(&9U>GIY"FUS9VED(")!8V-O=6YT)W,@;F%M93HB"FUS9W-T<B`BJM?HS>##
MU<*AX,VAQ=&AR;/L(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R
M,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,P"B,L(&9U>GIY"FUS9VED
M(")!8W1I;VYS(@IM<V=S='(@(J'2PZ'#T+?3(@H*(SH@;&EB+TU)344O2&5A
M9&5R<RYP:'`Z,C`P(&QI8B]-24U%+TAE861E<G,N<&AP.C(P,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B061D("5S('1O(&UY($%D9')E<W,@0F]O
M:R(*;7-G<W1R("+@OM3HP<6GX[FWU>BUU+2UZ,T@*"5S*2(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P,PHC+"!F=7IZ>0IM<V=I
M9"`B061D('-O=7)C92(*;7-G<W1R("+@OM3HP>'+Q>BG(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4W-R!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3@X"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R
M("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T86-H;65N="XB"FUS9W-T
M<B`BX;FZX,VARM+#(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`IM
M<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V
M:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B"B)O
M;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z
M-C(*(RP@9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T
M86EL<R(*;7-G<W1R("*BZ<W!V<7*Z,>YM=''(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z.3,*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G
M92!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<X"FUS9VED(")!9&1I=&EO;F%L
M(&UE<W-A9V4@97)R;W(@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D
M("5S+B(*;7-G<W1R("(B"@HC.B!C;VYT86-T<RYP:'`Z.#4@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T
M+FEN8SHU,@IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(K?5Z+74M+7H
MS2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G
M:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`BM]7HM=2TM>C-(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I9"`B(@HB061D<F5S<V5S('1O
M($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@
M861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#$*;7-G:60@(B(*(D%D9')E<W-E
M<R!T;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES(&ED96YT:71Y.B`\96T^*&]P
M=&EO;F%L+"!E;G1E<B!E86-H("(*(F%D9')E<W,@;VX@82!N97<@;&EN92D\
M+V5M/B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C,*;7-G:60@(D%L;"(*
M;7-G<W1R("*WT>FGR\&T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ,PIM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-
M0D]8("(*(F9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W!U<F=E7W1R87-H+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!;&P@;65S<V%G97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H
M86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N(@IM
M<V=S='(@(JBTR\'2PK?5Z*3ITJ?-PMGHX[GBO\7@M,W#["!<(B5S7"(@N=*Y
MH<?HTB`E<R#'T;D@J-"VV:'%NLW"Z-*GMM+'PR(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK960@871T
M86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE
M=&5D+B(*;7-G<W1R("+%NN*_Q>"TS</LJ+3+P=+"HM+-S:&WU>C!U<W2PMBY
MTKFAQ^C2("5S(."TU\VY(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L
M971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO
M;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("+%NN*_Q>"TS</L
MJ+3+P=+"HM+-S:&WU>C!U<W2PMBYTKFAQ^C2("5S(."TU\VY(@H*(SH@86-L
M+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(')I9VAT
M<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U
M<V5R(%PB)7-<(BXB"FUS9W-T<B`BXK_%X+3-P^P@7"(E<UPB(.2TZ;;9H>"[
MQ=7HPKFJU^C-X+OGN2!<(B5S7"(@X,/5PKK#Z<W"X<7IQR(*"B,Z(&QI8B]A
M<&DN<&AP.C<V"FUS9VED(")!;&QO=R!&;VQD97(@0W)E871I;VX_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I
M9"`B06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA
M:6QB;W@_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA
M=&EV92YP:'`Z,3$P"FUS9VED(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI
M<R!S96-T:6]N.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3<R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#0*;7-G:60@(D%L=V%Y
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34W"B,L
M(&9U>GIY"FUS9VED(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R
M("+AN;K@S:'*TL,B"@HC.B!L:6(O365S<V%G92YP:'`Z-3`U"FUS9VED("(B
M"B)!;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@
M=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I
M9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H
M92!N97<@;F]T92XB"FUS9W-T<B`BX*'4M*3'TL&\U+2^Q=*TP]#+Q^C2IZ'2
MP^"^U.C!JM?HS2(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#<*(RP@9G5Z>GD*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN
M9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(N"AU+2DQ]+!O-2TOL72M,/0R\?H
MTJ>ATL/@OM3HP:K7Z,TB"@HC.B!M97-S86=E+G!H<#HU,#`@;6%I;&)O>"YP
M:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R("*US;KAQ>G'
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B06YS
M=V5R960@;65S<V%G97,B"FUS9W-T<B`BHNG-I,?2P;?5Z+7-NJ'%T;KAQ>G'
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY
M"FUS9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(N.JZ;71QZ'#S:>AT;HB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T
M<B`BXZKIM=''H</-IZ'1NB(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P
M;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`BXZKIM=''H</-I^#!U^C-Q:>ZT;FW
MUJ'@HNG2(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0R"B,L
M(&9U>GIY"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"
M3U@@:7,@9&ES<&QA>65D/R(*;7-G<W1R("+CJNFUT<>AP\VGX,'7Z,VUV>GD
MN\/)L]7"[+;9H</5X+_#JB(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L(&9U>GIY"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC
M(&ME>3\B"FUS9W-T<B`BI-BSM>G-IZ'2P\6ZHNG-I,?2P>#+Q>C2N=7IS<+H
MTJ>VTL?#R\/7S>3!Z#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES
M(&ES($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:G,Z-@HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&1O('1H:7,_(@IM<V=S='(@(J38L[7IS:>ATL/%NJ+IS:3'TL&W
MT>FGR\&TX[GBO\7@M,W#[+;1IZ+"T,O#U\WDP>@_(@H*(SH@;65S<V%G92YP
M:'`Z-#`W('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8X"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L
M971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("*DV+.UZ<VGH=+#Q;JBZ<VD
MQ]+!X,O%Z-*YU>G-PNC2I[;2Q\/+P]?-Y,'H/R(*"B,Z(&QI8B]-24U%+T-O
M;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT
M/R(*;7-G<W1R("*DV+.UZ<VGH=+#Q;JBZ<VDQ]+!X,O%Z-*YU>G-PNC2I[;2
MQ\/+P]?-Y,'H/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C,Y"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M96UP='D@=&AI<R!F;VQD97(_(@IM<V=S='(@(J38L[7IS:>ATL/%NJ+IS:3'
MTL&WT>FGR\&TX[GBO\7@M,W#[+;1IZ+"T,O#U\WDP>@_(@H*(SH@;&EB+TE-
M4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`BI-BSM>G-
MIZ'2P\6ZHNG-I,?2P;?1Z:?+P;3CN>*_Q>"TS</LMM&GHL+0R\/7S>3!Z#\B
M"@HC.B!L:6(O24U0+G!H<#HY-C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`BI-BS
MM>G-IZ'2P\6ZHNG-I,?2P;?1Z:?+P;3CN>*_Q>"TS</LMM&GHL+0R\/7S>3!
MZ#\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,L(&9U
M>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT
M;'D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("*DV+.UZ<VGH=+#
MQ;JBZ<VDQ]+!X,O%Z-*YU>G-PNC2I[;2Q\/+P]?-Y,'H/R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E;7!L871E<R]M86EL
M8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO
M8V5N=#\B"FUS9W-T<B`BI-BSM>G-IZ'2P\6ZHNG-I,?2P>#+Q>C2N=7IS<+H
MTJ>VTL?#R\/7S>3!Z#\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R
M:7!T+FEN8SHW-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW
M-`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E
M<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\B"FUS9W-T<B`BI-BSM>G-IZ'2
MP\6ZHNG-I,?2P>#+Q>C2N=7IS<+HTJ>VTL?#R\/7S>3!Z#\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3$V"FUS9VED(")!<G)I=F%L(%1I;64B"FUS
M9W-T<B`BX,?%TK?5Z.2TZ</1NB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,S$*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R("+@P]7"IZC2H<NYZ=+D
MN\O%T:<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<Q(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU.#,*;7-G:60@(D%S:R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3D*(RP@9G5Z>GD*;7-G
M:60@(D%T=&%C:"(*;7-G<W1R("+@S:'*TL/AN;HB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT-S4*(RP@9G5Z>GD*;7-G:60@(D%T=&%C
M:"!&:6QE<R(*;7-G<W1R("+@S:'*TL/AN;HB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT-38*;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@
M>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#D*;7-G:60@(D%T
M=&%C:&5D($9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT
M-3$@;&EB+T-O;7!O<V4N<&AP.C4S-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A8VAM96YT
M('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,W-@IM<V=I9"`B071T86-H
M960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M,38@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYJ<SHY-PIM<V=I9"`B071T86-H;65N="(*;7-G
M<W1R("+@S:'*TL/AN;HB"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S
M86=E+G!H<#HT-C8*;7-G:60@(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I
M;F%L(&%T=&%C:&UE;G0@='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#<S"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#<S"FUS9VED(")!
M='1A8VAM96YT<R(*;7-G<W1R("+@S:'*TL/AN;HB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C@R"B,L(&9U>GIY"FUS9VED(")!='1E;F1E97,B
M"FUS9W-T<B`BX,VARM+#X;FZ(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D%T=&5N=&EO;B(*;7-G
M<W1R("*ATL.AP]"WTR(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*;7-G:60@
M(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-#`*;7-G
M:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S
M86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O
M:W,Z(@IM<V=S='(@(K?5Z+74M+7HS;?5Z+ZZ.B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,C8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A8U]K('1O
M("5S(@IM<V=S='(@(J'%T;KDN\K9Z"`E<R(*"B,Z('1H<F5A9"YP:'`Z,3,W
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R("*AQ=&ZY+O*
MV>@@)7,B"@HC.B!T:')E860N<&AP.C$S-`IM<V=I9"`B0F%C:R!T;R!-=6QT
M:7!L92!-97-S86=E(%9I97<@26YD97@B"FUS9W-T<B`B(@H*(SH@=&AR96%D
M+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D($1I<W!L87DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S
M<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR-C8@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C(*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L:6(O4V5A<F-H+G!H<#HS-`IM
M<V=I9"`B0F-C(@IM<V=S='(@(LK3X+G2J^C-N;;6IR(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM<V=I9"`B0F5L;W<@:7,@=&AE(')A
M=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED
M(")";&%C:VQI<W0B"FUS9W-T<B`BNM&MJM6TTR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV,CD*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(5$U,(&UE
M<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D
M/R(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HT,@IM<V=I9"`B0F]D
M>2(*;7-G<W1R("+@N=?IS<O2(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R("*WT>FGRLVGN\/0X,"W(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-PIM<V=I9"`B0F]T:"!(96%D
M97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,@IM<V=I9"`B0U]H
M87)S970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C,V"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O
M('1H92!R96UO=&4@;6%I;"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@
M=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)#86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S
M('!A<G1S(&]F('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL
M8F]X+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G
M92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S
M<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN
M8SHV-@HC+"!F=7IZ>0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(N"[Q=7HPKGA
MN\6G(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,U"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3$*(RP@9G5Z>GD*;7-G:60@(D-A;F-E
M;"!-97-S86=E(@IM<V=S='(@(J+IS:3'TL&UZ,WDNR(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL
M;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS9W-T<B`B
M(@H*(SH@;65S<V%G92YP:'`Z,C8U('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI
M;F,Z,34@;&EB+U-E87)C:"YP:'`Z,S`*;7-G:60@(D-C(@IM<V=S='(@(LK3
MX+G2MM:G(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,PIM<V=I
M9"`B(@HB0V5R=&EF:6-A=&4@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I
M;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@(@HB<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Q"B,L
M(&9U>GIY"FUS9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`BRNC'N;71QR(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(N"[Q=7HPKGAN\6G(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S
M='(@(N"[Q=7HPKGAN\6GM]'II\O!M"(*"B,Z('1E;7!L871E<R]A8VPO86-L
M+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E($9O;&1E<B(*;7-G<W1R
M("+*P^G2I^*_Q>"TS</L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO
M=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"`B"B)H
M;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`BX+O%U>C"N;71Q^#%
MU\VAX[FATL/ARK2GO,4@X*KHN2"HT[G'N:BTR\'2PK7HS<NYZ=+AQ="ATL.H
MT;3@P]7"IZBTR\'2PB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`HC
M+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@
M<V5T=&EN9W,N(@IM<V=S='(@(N"[Q=7HPKFATL.UT>FGI.C2X*3#U^C-I[K#
MU*'2P^#!Q2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B
M(@HB0VAA;F=E('1H92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@
M>6]U<B!E;6%I;"XB"FUS9W-T<B`BX+O%U>C"N:K7Z,TL(+?5Z,W"V>@@X<70
MQ=+"X*OGN;?5Z,KHI^2[OL/IS<&AT;K-U>#!Q2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,C0*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,34*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T
M<B`BRM/#QZBHM,O!TL+CR\'H(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C<U"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C$P('1E;7!L871E
M<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR,0IM<V=I9"`B0VAE8VL@86QL
M(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*(RP@9G5Z
M>GD*;7-G:60@(D-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S
M<V%G93\B"FUS9W-T<B`BX*'4M*+IS;S4M+[%TK3CN:'2P\KHIZ+IS:3'TL&B
MS:>DV+,Z("5S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M-`IM<V=I9"`B0VAO;W-E($%C=&EO;CHB"FUS9W-T<B`BX,77S:&ATL.AP]"W
MTSHB"@HC.B!C;VYF:6<O<V5R=F5R<RYP:'`N9&ES=#HQ.#(*(RP@9G5Z>GD*
M;7-G:60@(D-H;V]S92!A(&UA:6P@<V5R=F5R.B(*;7-G<W1R("+@N\75Z,*Y
MH=+#M='IIZ3HTN"DP]?HS:>ZP]2ATL/@P<4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHQ,C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,38V"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Q
M-PIM<V=I9"`B0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T
M;R!T:&4@<FEG:'0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,0HC+"!F
M=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%C=&EO;CHB"FUS9W-T<B`BX,77S:&A
MTL.AP]"WTSHB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS-#D*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K
M('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(N#%U\VA
MM]7HM=2TM>C-M]7HM>G-IZ'2P^.JZ>.YH=+#X+[4Z,'#TL*JU^C-(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"B,L(&9U>GIY
M"FUS9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@
M<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`BH=/+
MN;3%T[31NJ+-I[?5Z+74M+7HS;?5Z+7IS:>ATL/CR^FDZ;G+TN.YHK/0M].A
MTL/@M=3!X+7GP:K7Z,TB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N=F5R
M="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C
M86X@=FEE=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9&]W
M;FQO860@=&AE(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H
M<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@=&\@
M)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:'1M;"YP:'`Z,3$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E
M('=I;F1O=RXB"FUS9W-T<B`BRL/ITJ>BZ<VDQ]+!X[G+N>G2M>C2I^/+P>@B
M"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T
M:&ES(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O
M=RXB"FUS9W-T<B`BRL/ITJ>BZ<VDQ]+!X[G+N>G2M>C2I^/+P>@B"@HC.B!L
M:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D
M('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B0VQI8VL@:&5R92!T
M;R!32$]7('1H92!);6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S(Q"B,L(&9U>GIY"FUS9VED("(B"B)#
M;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N
M9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S('1O("(*(G-E87)C:"XB"FUS9W-T
M<B`BI,74H<K!V+3#TL*JU^C-M]7HM>G-IZ'2PR#AQ>G'X,77S:'@HK6BZ<VD
MQ]+!M]7HM>G-IZ'2PZ3IN<O2(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,3<Q"FUS9VED(")#;&EC:R!T;R!3879E(%!'4"!0=6)L:6,@2V5Y(&EN
M('EO=7(@061D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K
M('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D
M<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-3`*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M
M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,0IM<V=I9"`B0VQI8VMI;F<@
M;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E
M860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA
M:6PN:6YC.C(X"B,L(&9U>GIY"FUS9VED(")#;&]S92(*;7-G<W1R("+*P^G2
MIR(*"B,Z(&-O;7!O<V4N<&AP.C@R."!C;VUP;W-E+G!H<#HQ,30X"FUS9VED
M(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HT,CD*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS9W-T<B`BN]2TXK_%X+3-
MP^PB"@HC.B!F;VQD97)S+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(D-O;&QA
M<'-E(@IM<V=S='(@(L+8NK?1Z:?+P;0B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL(@IM<V=S='(@
M(L+8NK?1Z:?+P;0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T<B`BPMBZ
MXK_%X+3-P^RWT>FGR\&T(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS9VED(")#
M;VQL87!S92!&;VQD97(B"FUS9W-T<B`BPMBZXK_%X+3-P^PB"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN
M9&EC871O<CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ,#,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<V.0HC+"!F=7IZ>0IM<V=I9"`B0V]M<&QE=&5D
M(@IM<V=S='(@(LK#Z=*G(@H*(SH@8V]M<&]S92YP:'`Z.#(W(&-O;7!O<V4N
M<&AP.C$Q-#<*(RP@9G5Z>GD*;7-G:60@(D-O;7!O<V4@86YO=&AE<B!M97-S
M86=E(@IM<V=S='(@(LK#Z=*GHNG-I,?2P>/+P>@B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#,T"B,L(&9U>GIY"FUS9VED(")#;VUP;W-E(&UE<W-A
M9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R("+*P^G2IZ+IS:3'
MTL'CN<NYZ=*UZ-*GX\O!Z"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,($=5
M22!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92`B"B)F96%T
M=7)E*3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W
M"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R92!D:7-P;&%Y960N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PHC+"!F
M=7IZ>0IM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+B(*
M;7-G<W1R("+@N\75Z,*YH=+#M='IIZ3HTN"DP]?HS:>ZP]2ATL/@P<4B"@HC
M.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM<V=I9"`B0V]N;F5C=&EO;B!D
M<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V
M97(@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R
M="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3+TU)344@<W5P
M<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M
M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL
M('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N
M;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`BI,>ZI-C!
MH=+#M</'J,K-NJBTR\'2PN/+P>CAQ="ATL/@M=?-N>#!U^C-P=6HM,O!TL+C
MR\'H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y-@IM<V=I9"`B0V]N
M=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G
M:60@(D-O<'DB"FUS9W-T<B`BRM/@N=(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM
M<V=S='(@(L7ITJ?BO\7@M,W#[+;1IZ+"T"(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G<W1R("*V
MV:&UZ<VG(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T
M,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`BHNG-I,?2P;?5Z.&A
MZ>2BX<7IQR(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S
M="X@4F5A<V]N($=I=F5N.B`E<R(*;7-G<W1R("+DP>C*TL'2P[;%NJ+IS:3'
MTL&HTJ$@)7,Z("5S(@H*(SH@871T86-H;65N="YP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-#`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@;65S<V%G
M97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("+DP>C*
MTL'2P[;%NJ+IS:3'TL&HTJ$@)7,Z("5S(@H*(SH@;&EB+U-E<W-I;VXN<&AP
M.C,Q.`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`BH=+#M-/@N=2YH=+#NM/#V*?#
MT:')TB(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HU-`IM<V=I9"`B
M0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE
M($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H
M92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@87)C:&EV92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(W,PIM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C,Q-"!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C,Y"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C`*(RP@9G5Z>GD*;7-G
M:60@(D-R96%T92(*;7-G<W1R("+*P^G2I^*_Q>"TS</L(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E
M<B(*;7-G<W1R("+*P^G2I^*_Q>"TS</L(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$S-PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E($ME>7,B"FUS9W-T
M<B`BRL/ITJ?BO\7@M,W#["(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(%9I<G1U86P@1F]L9&5R
M(@IM<V=S='(@(LK#Z=*GXK_%X+3-P^PB"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W
M($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(@IM
M<V=S='(@(LK#Z=*GXK_%X+3-P^RVT:>BPM`B"@HC.B!T96UP;&%T97,O<')E
M9G,O9F]L9&5R<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O9F]L9&5R
M<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W(&1R869T<R!F;VQD
M97(B"FUS9W-T<B`BRL/ITJ?BO\7@M,W#[.&ZNL/HTJ<B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(V('1E;7!L871E<R]P<F5F
M<R]S96YT;6%I;'-E;&5C="YI;F,Z-#(*;7-G:60@(D-R96%T92!A(&YE=R!S
M96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(LK#Z=*GXK_%X+3-P^RHM,O!TL*W
MU>C*Z*?AQ>G'(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN
M8SHQ,B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS9VED
M(")#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(LK#Z=*GXK_%
MX+3-P^RVT:>BPM`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X"FUS
M9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO
M=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*(F%N
M9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`BRL/ITJ>UT<>AP\VGX+[7Z,VHT;2A
MTL.HM,O!TL*BTN"BZ=(L(*C1M."AY[K%I^*_Q>"TS</L(.'%T,6ZJ+3+P=+"
MHL+0(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"B,L
M(&9U>GIY"FUS9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`B
MRL/ITJ?BO\7@M,W#[*BTR\'2PK?5Z,KHI^'%Z<<B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#0Y"FUS9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@
M9F]R;2!R97-P;VYS97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C8V5S
M<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA
M:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q"B,L(&9U>GIY"FUS9VED(")#=7-T;VUI>F4@
M:&]W('EO=2!S96YD(&UA:6PN(@IM<V=S='(@(J'3R[FTQ=&AR;/0H=+#RNBG
MJ+3+P=+"X<70H=+#NM&YM]:AX;JZP^C2IR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(J'3R[FTI]*Y
MM]7HM>G-IZ'2P^/+Z</1N>#!U^C-Q:>JU^C-X*+ITLK9Z"`E<R(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*(RP@9G5Z
M>GD*;7-G:60@(D1A=%]E(@IM<V=S='(@(L?1N;?5Z"(*"B,Z(&UE<W-A9V4N
M<&AP.C(V,B!T:')E860N<&AP.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R("+'
MT;FWU>@B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4W"B,L(&9U
M>GIY"FUS9VED(")$96-L:6YE9"(*;7-G<W1R("+%NN'%Z<<B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,C8S"FUS9VED(")$96-L:6YE9#H@(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*(RP@9G5Z
M>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BQ;HB"@HC.B!T96UP;&%T97,O
M<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z,3@*;7-G:60@(D1E9F%U
M;'0@4V5A<F-H($9I96QD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,C,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB
M"FUS9W-T<B`BX*?7Z,VYY**ATL.HT;3@P]7"I^*TPKO#U,+2PCHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,S"FUS9VED(")$969A=6QT('-O<G1I
M;F<@9&ER96-T:6]N.B(*;7-G<W1R("*WU,BWTJ>ATL.HT;3@P]7"I^*TPKO#
MU,+2PCHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U"B,L(&9U
M>GIY"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`BQ;KAQ>G'(@H*(SH@9F]L
M9&5R<RYP:'`Z-#$Y('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV
M.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(T-"!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C$P"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(X"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHR-PIM<V=I9"`B1&5L971E(@IM<V=S='(@(L6Z
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S
M(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E
M;&5T92!#=7)R96YT($ME>7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*
M;7-G<W1R("+%NN*_Q>"TS</L(@H*(SH@9F]L9&5R<RYP:'`Z,C@U"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R("+%
MNN*_Q>"TS</L(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C0R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4W1A=&EO;F5R>2(*;7-G<W1R
M("+%NN*_Q>"TS</L(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`BQ;KBO\7@M,W#
M["(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I
M9"`B1&5L971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R
M/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(X
M"FUS9VED(")$96QE=&4@9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@
M;6]N=&@_(@IM<V=S='(@(L6ZXK_%X+3-P^RHM,O!TL*BTLW-H;?8H>8@M>FY
MX+37S;DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4P"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN
M;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BQ;KBO\7@M,W#[*BTR\'2PJ+2S<VA
MM]BAYB"UZ;G@M-?-N2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3<*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM<V=S='(@
M(L6ZJ+3+P=+"(@H*(SH@;65S<V%G92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<T
M,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(P"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHX"FUS9VED(")$96QE=&5D(@IM<V=S='(@(L6ZX<7IQR(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-C,*;7-G:60@(D1E;&5T960@
M;65S<V%G97,B"FUS9W-T<B`BHNG-I,?2P;?5Z+;9H<6Z(@H*(SH@8V]M<&]S
M92YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D
M('1H92!A='1A8VAM96YT(%PB)7-<(BXB"FUS9W-T<B`BQ;K@S:'*TL/AN;HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG
M(&%N9"!-;W9I;F<@365S<V%G97,B"FUS9W-T<B`BH=+#Q;KAQ=#@I,77Z,VY
MPNG2PJBTR\'2PB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3(*
M;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-30P"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R
M964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3,R"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(N##
MU<*GJ-*AR\71I^2[R[GITB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Y"B,L
M(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("*UT<?@Q=?-H>"A
MU>C"QZ'1NKS9Z>.JZ2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B1&5T86EL<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<W"FUS9VED(")$:6T@<VEG
M;F%T=7)E<S\B"FUS9W-T<B`BX<JTI\72PN"KY[FTZ<?"RM7-Z,VY/R(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$
M:7-P;&%Y(@IM<V=S='(@(N'*M*>\Q2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-SD*;7-G:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E
M;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C@V"FUS9VED(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"B,L
M(&9U>GIY"FUS9VED(")$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@
M;F5W(&UA:6P_(@IM<V=S='(@(N'*M*>UT<?@M=?-N>#!U^C-P=6HM,O!TL+C
MR\'H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES
M<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I
M9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE
M;G5B87(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS
M9W-T<B`BM=''X,77S:&ATL/ARK2GO,4B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C:"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B
M1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B
MY,'HM>G-IZ'2P[7#QZC*S;JHM,O!TL+CR\'H(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I
M;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP
M.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD97(_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,R
M"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C8*
M(RP@9G5Z>GD*;7-G:60@(D1O;F4B"FUS9W-T<B`BY,'HX,77S:$B"@HC.B!L
M:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"B,L('!H<"UF;W)M870*;7-G:60@
M(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R"FUS9VED(")$;W=N;&]A
M9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C`*;7-G:60@(D1O
M=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R("*TTL>Y[.++Q;3BO\7@M,W#["(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(Q"B,L(&9U>GIY
M"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(*;7-G
M<W1R("*TTL>Y[.++Q;3BO\7@M,W#["(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S
M+G!H<#HQ.3(*;7-G:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,2!M86EL8F]X+G!H<#HW,3D@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,0HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(R('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z-#$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHY"FUS9VED(")$<F%F="(*;7-G<W1R("+ANKK#Z-*G(@H*(SH@9F]L9&5R
M<RYP:'`Z,SDR"B,L(&9U>GIY"FUS9VED(")$<F%F="!F;VQD97(B"FUS9W-T
M<B`BXK_%X+3-P^SANKK#Z-*G(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD97(Z(@IM<V=S='(@
M(N*_Q>"TS</LX;JZP^C2IR(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M,#@*(RP@9G5Z>GD*;7-G:60@(D4M;6%I;"!!9&1R97-S(@IM<V=S='(@(K?5
MZ,W"V>C-U>#!Q2(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,#D*;7-G:60@(D5.
M1"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW
M-`IM<V=I9"`B15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L
M:79E<F5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ.`HC+"!F
M=7IZ>0IM<V=I9"`B161I="!";&%C:VQI<W0B"FUS9W-T<B`BNM&MJM6TTR(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PHC+"!F=7IZ>0IM
M<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(K71QZ'#S:>HM,O!TL(B"@HC
M.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC
M.C$V"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B161I
M="!Y;W5R(&)L86-K;&ES="(*;7-G<W1R("+AH>GDHK71QZ'#S:<B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U
M<B!F:6QT97(@<G5L97,B"FUS9W-T<B`BX:'IY**UT<>AP\VG(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V,0IM<V=I9"`B161I="!Y;W5R('!R969E
M<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"B,L
M(&9U>GIY"FUS9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(N&A
MZ>2BM=''H</-IR(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(K?5Z,W"V>C-
MU>#!Q2(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM
M<V=S='(@(L6ZJ+3+P=+"M]'II\O!M*C2H2`E<R(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H<RDB
M"FUS9W-T<B`BQ>G2I^*_Q>"TS</L(@H*(SH@9F]L9&5R<RYP:'`Z,C@V"B,L
M(&9U>GIY"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@
M(L7ITJ?BO\7@M,W#["(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C,Y"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`BQ>G2
MI^*_Q>"TS</LMM&GHL+0(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY
M"FUS9VED(")%;7!T>2!?4W!A;2(*;7-G<W1R("+%Z=*GMM&GHL+0(@H*(SH@
M;&EB+TE-4"YP:'`Z.38V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!?5')A<V@B
M"FUS9W-T<B`BQ>G2I[;1IZ+"T"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B
M;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E
M+FEN8SHV"FUS9VED(")%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3$*;7-G:60@
M(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-#(*;7-G:60@(D5N8W)?>7!T
M:6]N($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Q-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4W"FUS9VED
M(")%;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,X-`IM<V=I
M9"`B16YD(&9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(JBZH=+#RNBGM>C-
MHNG-I,?2P2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-#$*(RP@9G5Z>GD*;7-G
M:60@(D5N9"!M97-S86=E(@IM<V=S='(@(J+IS:3'TL'@H>C2(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C,S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M16YD(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("*BZ<VDQ]+!M]7HRNBGM>C-
MP=*HTJ$@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B16YT97(@4&%S<W!H<F%S
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI
M;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P86T@
M9F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S
M96QE8W0N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O
M<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(LK#Z=*GXK_%X+3-
MP^SANKK#Z-*G(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T
M+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO
M=7(@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`BRL/ITJ?BO\7@M,W#
M[*BTR\'2PK?5Z,KHI^'%Z<<B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS
M96QE8W0N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O
M<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`BRL/ITJ?BO\7@M,W#
M[+;1IZ+"T"(*"B,Z(&QI8B]396%R8V@N<&AP.C0V"B,L(&9U>GIY"FUS9VED
M(")%;G1I<F4@365S<V%G92(*;7-G<W1R("*BZ<VDQ]+!M>C-Y+LB"@HC.B!M
M97-S86=E+G!H<#HQ.30@8V]M<&]S92YP:'`Z,3$S-"!T:')E860N<&AP.C<Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K(@IM<V=S
M='(@(EPB)7-<(B"VV:'@OM3HP>"UU,'%I^.YM]7HM=2TM>C-X,/5PKK#Z<W"
MX<7IQR(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X-@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@(KS4M+[%TK0B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!C;VYN96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D5V96YT
M('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("+BO\7@M,W#["!<(B5S
M7"(@Y+3IMMFAQ;K@P]7"NL/IS<+AQ>G'(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("*W
MV*$@,34@N=*WU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-SD*;7-G
M:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BM]BA(#,P(,?4N=*WU2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#$*;7-G:60@(D5V97)Y(#4@
M;6EN=71E<R(*;7-G<W1R("*WV*$@-2"YTK?5(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<X,PIM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@
M(K?8H:3#UNBGJM'HQ^+!IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("*WV*&YTK?5(@H*(SH@
M9F]L9&5R<RYP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")%>'!A;F0B"FUS9W-T
M<B`BHL+2PK?1Z:?+P;0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R("*BPM+"M]'II\O!
MM"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED
M(")%>'!A;F0@06QL($9O;&1E<G,B"FUS9W-T<B`BHL+2PN*_Q>"TS</LM]'I
MI\O!M"(*"B,Z(&9O;&1E<G,N<&AP.C0U-PIM<V=I9"`B17AP86YD($9O;&1E
M<B(*;7-G<W1R("*BPM+"XK_%X+3-P^PB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C4S"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T<B`BX+74P:K7Z,TB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V,PIM<V=I9"`B17AP86YD
M(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN
M('1H92!B86-K9W)O=6YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3@P"B,L(&9U>GIY"FUS9VED(")%>'!A;F0@=&AE(&5N=&ER
M92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_
M(@IM<V=S='(@(J'3R[FTX\OIHL+2PN*DPZ?*P^G2I^*_Q>"TS</LM]'II\O!
MM.#!U^C-S<+9Z..YP=C!P<VGP]+"H=+#XK_%X+3-P^PB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(T-2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3`Q"B,L
M(&9U>GIY"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T<B`BHL+2PK?1Z:?+P;0B
M"@HC.B!L:6(O24U0+G!H<#HY.#0@;&EB+TE-4"YP:'`Z.3@V"B,L(&9U>GIY
M"FUS9VED(")&7V5T8V@@36%I;"(*;7-G<W1R("*HM,O!TL+CR\'H(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D9E=&-H($UA:6PB
M"FUS9W-T<B`BJ+3+P=+"X\O!Z"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-CD*(RP@9G5Z>GD*;7-G:60@(D9E=&-H($UA:6P@:6X@82!S97!A<F%T
M92!W:6YD;W<_(@IM<V=S='(@(LK#Z=*GHNG-I,?2P>.YR[GITK7HTJ?CR\'H
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0V"B,L(&9U
M>GIY"FUS9VED(")&971C:"!M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_(@IM
M<V=S='(@(N.JZ;71QZ'#S:?@P=?HS<6GNM&YM]:AX*+ITB(*"B,Z(&QI8B]&
M971C:&UA:6PN<&AP.C(X.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S(@IM<V=S='(@(L6ZJ+3+P=+"
MM]'II\O!M*C2H2`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O
M;2`E<R(*;7-G<W1R("*BZ<VDQ]+!M]7HRNBGM>C-P=*HTJ$@)7,B"@HC.B!L
M:6(O1F5T8VAM86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI
M8B]&971C:&UA:6PN<&AP.C(X.0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED
M(")&971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B("T@)&YM
M(*+IS:3'TL'CR\'H(@H*(SH@;&EB+TE-4"YP:'`Z.3DP"B,L(&9U>GIY"FUS
M9VED(")&:5]L=&5R<R(*;7-G<W1R("*UT<>AP\VG(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`R('1E;7!L871E<R]C;VUP;W-E+V%T
M=&%C:&UE;G1S+FIS.C@R"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@
M(K71QZ'#S:<B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S$*
M(RP@9G5Z>GD*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S='(@(K71Q^#%
MU\VAS=?HN2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHY"B,L
M(&9U>GIY"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`BH:^ATL.A
MP\VG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P,`HC+"!F=7IZ>0IM
M<V=I9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*
M;7-G<W1R("*AP\VGHNG-I,?2P;?5Z.3!Z.#+P=+0RL$B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$Q"FUS9VED(")&:6QT97(@<W5P
M<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B1FEL=&5R<R(*
M;7-G<W1R("*UT<>AP\VG(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T
M:79E+FEN8SHS"FUS9VED(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@
M(D9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN
M9"(*;7-G<W1R("*DZ;G+TB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,#4*(RP@9G5Z>GD*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R
M("++N>G2X<.A(@H*(SH@;6%I;&)O>"YP:'`Z,S0U"FUS9VED(")&:7)S="!0
M86=E(@IM<V=S='(@(LNYZ=+APZ$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D9O7W)W87)D(@IM<V=S='(@(LKH
MI[7HS2(*"B,Z(&9O;&1E<G,N<&AP.C(V-B!T96UP;&%T97,O9F]L9&5R<R]F
M;VQD97)S7V-O;F9I<FTN:'1M;#HU"FUS9VED(")&;VQD97(@06-T:6]N<R`M
M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS,#,@
M=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E
M9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S
M+VEN:71I86QP86=E<V5L96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG
M871O<B(*;7-G<W1R("*UT<>YT[?2I^*_Q>"TS</L(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D9O;&1E<B!3=6UM87)Y
M(@IM<V=S='(@(J'8P<#2OM&YN.SHZ"(*"B,Z(&%C;"YP:'`Z,C0*;7-G:60@
M(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R("(B"@HC
M.B!F;VQD97)S+G!H<#HV,@IM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA
M8FQE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M.0IM<V=I9"`B1F]R;6%T(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB
M;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T960@=&]D87DB"FUS9W-T<B`B(@H*
M(SH@8V]M<&]S92YP:'`Z-S@P('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R("+*Z*>UZ,TB"@HC.B!C;VUP
M;W-E+G!H<#HW-C4*;7-G:60@(D9O<G=A<F0Z(@IM<V=S='(@(LKHI[7HS3HB
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8Y"B,L(&9U>GIY"FUS9VED(")&;W)W
M87)D960@;65S<V%G92(*;7-G<W1R("*HNJ'2P\KHI[7HS:+IS:3'TL$B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`BHNG-I,?2P;?5Z,KH
MI[7HS<'2J-*A("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X
M,PHC+"!F=7IZ>0IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S
M='(@(J+IS<'9Q>"DP]?HS:>ZP]2ATL,B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#DT"FUS9VED(")&<F5E+T)U<WD@4F5P;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`IM<V=I9"`B1G)E
M92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0P,0IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N
M<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B1G)O7VTB"FUS9W-T<B`B
MJ-*A(@H*(SH@;65S<V%G92YP:'`Z,C8S('1H<F5A9"YP:'`Z,30Y('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.CDY"B,Z(&QI8B]396%R8V@N<&AP
M.C(R"FUS9VED(")&<F]M(@IM<V=S='(@(JC2H2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R("*W
MU>C-PMGHO-GIRNBG(@H*(SH@8V]M<&]S92YP:'`Z-S<W(&-O;7!O<V4N<&AP
M.C<X,0IM<V=I9"`B1G=D.B(*;7-G<W1R("+*Z*>UZ,TZ(@H*(SH@8V]M<&]S
M92YP:'`Z,3(Y-`HC+"!F=7IZ>0IM<V=I9"`B1G=D.B`B"FUS9W-T<B`BRNBG
MM>C-.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.38*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@
M(JBZH=+#RNBGM>C-HNG-I,?2P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`HC+"!F=7IZ
M>0IM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S='(@(K71Q^#%U\VAX*'5
MZ,+'H=&ZO-GIXZKI(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N
M;'DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C,Q"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$S
M-@HC+"!F=7IZ>0IM<V=I9"`B1V\@=&\@365S<V%G92(*;7-G<W1R("*BZ<VD
MQ]+!M>C-Y+LB"@HC.B!L:6(O24U0+G!H<#HT.3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S
M7"(B"FUS9W-T<B`BX+[4Z,'%I^.YM]7HM=2TM>C-("@E<RDB"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,3,U"FUS9VED(")'<F%N="!A8V-E<W,B"FUS
M9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-30V(&QI8B]&:6QT97(N<&AP.C$P
M-2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ,#(@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,R!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C8R(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I
M;VXN<&AP.C8X"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.2!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C$W,PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C`@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z,3(W"FUS9VED(")(15)%(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,2!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3$W"B,Z(&QI8B]-24U%+U9I97=E<B]R
M96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!C;VUP
M;W-E+G!H<#HR-38*;7-G:60@(DA434P@5F5R<VEO;B!O9B!-97-S86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4X
M"FUS9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W)E8V]M<&]S92YI;F,Z-0IM<V=I9"`B2&5R92!I<R!T:&4@;65S<V%G
M92!Y;W4@=V5R92!C;VUP;W-I;F<Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-C@*;7-G:60@(DAI9&1E;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8W"B,L(&9U>GIY"FUS9VED(")(
M:61D96X@:6X@5&AR96%D(%9I97<B"FUS9W-T<B`BP=C!P<VGX+?#M"(*"B,Z
M(&UA:6QB;W@N<&AP.C,V-PIM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@
M(JOHS;FWU>C%NN'%Z<<B"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(DAI
M9&4@56YS=6)S8W)I8F5D(@IM<V=S='(@(JOHS;FWU>C@Q=2AXZKIY+OAQ>G'
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDT"FUS9VED
M(")(:6=H(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y-R!M86EL8F]X
M+G!H<#HW,C0@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,@IM<V=I
M9"`B2&EG:"!0<FEO<FET>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X.`IM<V=I9"`B2&]W(&1O
M('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@
M(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS
M9W-T<B`BH=+#X+74P:+IS:3'TL'+N>G2NL/#M]&THNG-I,?2P>.YH=+#M<VZ
MH<71NCHB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$S-`IM<V=I9"`B
M24U!4"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R
M.0IM<V=I9"`B24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R
M("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E
M<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,38V(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V
M"FUS9VED("))34%0(&]V97(@4U-,(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C
M:&UA:6PO:6UA<"YP:'`Z,34R"FUS9VED("))34%0(&]V97(@4U-,("AS96QF
M+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHQ-C<*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E
M;&8M<VEG;F5D*2(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,V.`IM<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V
M-2!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@
M5$Q3(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z-#D*
M;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TE-4"YP:'`Z.#8V"FUS9VED("))3D)/6"(*;7-G<W1R("*UV>FBTN"B
MZ=(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I9"`B268@=7-I
M;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS<VP@
M97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3(*;7-G:60@(DEF('EO=2!C
M;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B
M92!L;W-T(2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G<W1R("+%T.#'Z;DB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#,*;7-G:60@(DEG
M;F]R92!!;&PB"FUS9W-T<B`BQ=#@Q^FYM]'II\O!M"(*"B,Z('1E;7!L871E
M<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHX"FUS9VED("));6%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P"B,L
M(&9U>GIY"FUS9VED("));7!O<G0B"FUS9W-T<B`BRM.DT:TB"@HC.B!T96UP
M;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($ME>2(*
M;7-G<W1R("+*TZ31K2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,SD*
M(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!+97EP86ER(@IM<V=S='(@(LK3I-&M
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C<*(RP@9G5Z
M>GD*;7-G:60@(DEM<&]R="!-97-S86=E<R(*;7-G<W1R("*BZ<VDQ]+!RM.D
MT:TB"@HC.B!P9W`N<&AP.C0R"FUS9VED("));7!O<G0@4$=0($ME>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDQ"FUS9VED
M("));7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ-`IM<V=I9"`B26UP;W)T
M(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.CD*;7-G:60@(DEM<&]R="!097)S
M;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L
M(%,O34E-12!#97)T:69I8V%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHT,"!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#(*
M;7-G:60@(DEM<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!U8FQI
M8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHX"FUS9VED("));7!O<G0@4'5B;&EC(%,O34E-12!+97DB
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$V"FUS9VED("));7!O<G0@4R]-
M24U%($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O
M<G0N:6YC.CD*;7-G:60@(DEM<&]R="!M8F]X($9I;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHQ-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S
M+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU,#(@;6%I;&)O>"YP:'`Z
M-S,T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-PHC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$V('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHW"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`BRM.DT:TB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A
M;G0@;65S<V%G97,B"FUS9W-T<B`BHNG-I,?2P<K3I-&M(@H*(SH@9F]L9&5R
M<RYP:'`Z,38W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E
M9"`E9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("+%NJBTR\'2PK?1Z:?+
MP;2HTJ$@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS
M9VED("));B!0<F]C97-S(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,X
M-"!L:6(O1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-
M4"YP:'`Z,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4
M<F5E+G!H<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.3(*(RP@9G5Z>GD*;7-G:60@(DEN8VQU9&4@
M82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\B"FUS
M9W-T<B`BX;FZHNG-I,?2P;7IN:FZT;KDNZ'1NJ'2P[7-NJ'%T;K+P]?-Y,'H
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#<*;7-G:60@(DEN8VQU
M9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/R(*;7-G<W1R("+AN;JB
MZ<VDQ]+!M>FYJ;K1NN2[H=&ZH=+#M<VZH<71NLO#U\WDP>@_(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,3,P"B,L(&9U>GIY"FUS9VED("));F9O(@IM<V=S
M='(@(L70X,?IN2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@
M(DEN9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED("));F9O<FUA=&EO;B!O
M;B!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC($ME>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI
M;F,Z,34@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`W"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDX"B,L(&9U>GIY"FUS
M9VED("));FQI;F4B"FUS9W-T<B`BY,'HP=4B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I9FEC871E
M($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME
M>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z,3`*;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME
M>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,@IM<V=I
M9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT
M+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O>"YP:'`Z
M-C(V"B,L(&9U>GIY"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS9W-T<B`B
MM]7HS<+9Z,W5X,'%(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HS,#<*
M;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B"FUS9W-T<B`B(@H*(SH@
M8V]M<&]S92YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@
M8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B(@H*
M(SH@<VUI;64N<&AP.C@R('!G<"YP:'`Z,38*;7-G:60@(DEN=F%L:60@:V5Y
M(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3DV"FUS9VED("));G9A;&ED('!E
M<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H
M<#HQ-S$*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I
M9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@=&\@
M8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N
M;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T
M:&ES('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHS-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,SD*;7-G:60@(B(*
M(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA=F4@;F\@861D
M<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@(@HB8V]N=&%C=',N(@IM
M<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S$X"FUS9VED(")+97D@<W5C8V5S<V9U
M;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$V"FUS9VED("),86YG
M=6%G92(*;7-G<W1R("+`TLG2(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDP-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!-86EL8F]X(%!A9V4B"FUS9W-T
M<B`BR[GITLK8M+?ITL(B"@HC.B!M86EL8F]X+G!H<#HS-3@*;7-G:60@(DQA
M<W0@4&%G92(*;7-G<W1R("++N>G2RMBTM^G2PB(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,X.0HC+"!F=7IZ>0IM<V=I9"`B3&E?;FL@
M071T86-H;65N=',B"FUS9W-T<B`BX,VARM+#X;FZ(@H*(SH@871T86-H;65N
M="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C$P-C,*;7-G:60@(DQI;FME9"!A
M='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,3`X,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:6YK<R!W
M:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`X,@IM<V=I9"`B(@HB3&ES="!A;&P@8V]N=&%C=',@=VAE
M;B!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@
M>6]U('=I;&P@(@HB;VYL>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H
M(&9O<B!E>'!L:6-I=&QY*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C@U"FUS9VED("),:7-T:6YG(&EN('1H92!(96%D97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P
M"B,L(&9U>GIY"FUS9VED("),;V-A;"!-86EL8F]X.B(*;7-G<W1R("*UV>GD
MN\/)L]7"["(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-S0*(RP@
M9G5Z>GD*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(J'2PZ'#T+?3(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C4*(RP@9G5Z>GD*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R("+%I[K1N;?6H>"BZ=(@)7,B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(DQO9R!I
M;B!T;R`E<R(*;7-G<W1R("+%I[K1N;?6H>"BZ=(@)7,B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$S-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB
M"FUS9W-T<B`BI]*YX[FBL]#%IZK7Z,W@HNG2(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("*GTKGC
MN:*ST,6GJM?HS>"BZ=(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR.38*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H
M<#HR.3D@;6%I;&)O>"YP:'`Z-S(W('1E;7!L871E<R]M86EL8F]X+VQE9V5N
M9"YI;F,Z,3,*;7-G:60@(DQO=R!0<FEO<FET>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3<*;7-G:60@(DQO=V5S
M="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N
M<&AP.C0T"B,L(&9U>GIY"FUS9VED(")-86-I;G1O<V@@1FEL92(*;7-G<W1R
M("*UT<>AP\VGJ+3+P=+"(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A
M<V4N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")-86EL(@IM<V=S='(@(K79Z>2[
MP\FSU<+L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"B,L(&9U>GIY
M"FUS9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(K71QZ'#S:>HM,O!TL(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C$V
M"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM<V=S
M='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I;&)O>"(*;7-G
M<W1R("*UV>GDN\/)L]7"["(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,3$*(RP@9G5Z>GD*;7-G:60@(DUA:6QB;W@@86YD($9O;&1E<B!$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`BM=''X,77S:&ATL/ARK2GO,4B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@
M365S<V%G97,@:6X@1F]L9&5R(&%S(%-E96XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL
M($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHU('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM
M<V=S='(@(J'3R[FTX\OIX+OGN2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG
M('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`BH=/+N;3*U>/+Z>&U
MH;7HTJ>AT;G*T\O#T;KAM>C%T,/0M-&ZHLVGH=+#S>G2I\W4I\O#U\WDP>@B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*;7-G:60@
M(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U.`IM<V=I9"`B36%R:R!S
M:6UP;&4@;6%R:W5P/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z-#8*;7-G:60@(DUA=&-H($%L;"!1=65R:65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT,@IM<V=I
M9"`B36%T8V@@06YY(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PHC+"!F=7IZ>0IM<V=I9"`B36%X:6UU
M;2!!='1A8VAM96YT(%-I>F4B"FUS9W-T<B`BX,VARM+#X;FZ(@H*(SH@;&EB
M+V%P:2YP:'`Z-SD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#DT"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C
M:&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT.#D*;7-G:60@(DUA>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE
M(')E86-H960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV,C8*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S4*(RP@9G5Z>GD*
M;7-G:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`BHNG-P=G%X*3#
MU^C-I[K#U*'2PR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*
M;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I9"`B365E=&EN9R!297!L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DX"FUS
M9VED(")-965T:6YG(%5P9&%T92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C`S"FUS9VED(")-965T:6YG(%5P9&%T92!297%U
M97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP
M.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@1F]L9&5R($QI<W0B"FUS9W-T<B`B
MX+O4M.*_Q>"TS</L(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B
M365S<V%G92(*;7-G<W1R("*BZ<VDQ]+!(@H*(SH@8V]M<&]S92YP:'`Z-38P
M(&-O;7!O<V4N<&AP.C4X-R!C;VUP;W-E+G!H<#HV-#$@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P"FUS9VED(")-97-S86=E($-O;7!O<VET:6]N(@IM<V=S
M='(@(N"BU<*YHNG-I,?2P>/+P>@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$W"FUS9VED(")-97-S86=E($1A=&4B"FUS9W-T<B`BQ]&YM]7HHLVG
MHNG-I,?2P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PHC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(J+IS:3'TL'DN\+1IR(*"B,Z
M('-E87)C:"YP:'`Z,S$R"FUS9VED(")-97-S86=E(%-E87)C:"(*;7-G<W1R
M("*DZ;G+TJ+IS:3'TL$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(Q
M"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`BHKG2M*+-IZ+IS:3'TL$B
M"@HC.B!M97-S86=E+G!H<#HS.#0*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM
M<V=S='(@(K7IN:FZT;JBZ<VDQ]+!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8V"FUS9VED(")-97-S86=E(%9I97=I;F<B"FUS9W-T<B`BH=+#X<JT
MIZ+IS:3'TL$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G
M:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`BM=''NNBGJM7IHNG-I,?2P2(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#,*;7-G:60@(DUE<W-A
M9V4@9F]L9&5R<R(*;7-G<W1R("+BO\7@M,W#["(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@
M9G)O;2`E<R(*;7-G<W1R("+BO\7@M,W#["(*"B,Z(&UA:6QB;W@N<&AP.C8V
M-PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!H87,@871T86-H;65N=',B"FUS
M9W-T<B`BQ;K@S:'*TL/AN;HB"@HC.B!M86EL8F]X+G!H<#HV-3@*(RP@9G5Z
M>GD*;7-G:60@(DUE<W-A9V4@:7,@96YC<GEP=&5D(@IM<V=S='(@(N"BM:+I
MS:3'TL$B"@HC.B!M86EL8F]X+G!H<#HV-3,*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(N"BM:+IS:3'TL$B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@;6%T8VAE<R(*;7-G<W1R("+'T;FWU>BBS:>BZ<VDQ]+!(@H*(SH@
M8V]M<&]S92YP:'`Z.#(T(&-O;7!O<V4N<&AP.C@S.`IM<V=I9"`B365S<V%G
M92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@8V]M
M<&]S92YP:'`Z,3`X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365S
M<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<R(*
M;7-G<W1R("*DV+/DM.G@P]7"H>.JZ2!<(B5S7"(@X,/5PKK#Z<W"X<7IQR(*
M"B,Z(&-O;7!O<V4N<&AP.C$Q-#,@8V]M<&]S92YP:'`Z,3$U.`IM<V=I9"`B
M365S<V%G92!S96YT('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDT,0IM<V=I9"`B365S<V%G97,@<&5R('!A
M9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`BJ-.YQ[FBZ<VDQ]+!
MM>C-R[GITN.YP=C!P<VGM=GIY+O#R;/5PNPB"@HC.B!M86EL8F]X+G!H<#HS
M,C(*;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S='(@(J+IS:3'TL'DN\+1IR(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0HC+"!F=7IZ>0IM<V=I9"`B
M36]D:69Y(@IM<V=S='(@(N"YU^G-R](B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E>'!A;F0N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA
M;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO
M=F4B"FUS9W-T<B`BPNG2PB(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C,Q-@HC+"!F=7IZ>0IM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(L+ITL+%IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3@*;7-G
M:60@(DUO=F4@<W!A;2!M97-S86=E<R!T;R!S<&%M(&9O;&1E<B!A;F0@:6YN
M;V-E;G0@;65S<V%G97,@=&\@24Y"3U@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C4P"B,L(&9U>GIY"FUS9VED(")-;W9E('1O
M(&9O;&1E<B(*;7-G<W1R("+@Q=?-H>*_Q>"TS</L(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$T"B,L(&9U>GIY"FUS9VED(")-
M;W9E('5P(@IM<V=S='(@(L+ITL*BUNFY(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E<FYA
M=&EV92(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z
M,34R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!-97-S86=E(%9I97<B"FUS
M9W-T<B`BH=+#X<JTIZ+IS:3'TL$B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F
M875L='-E87)C:'-E;&5C="YI;F,Z-0IM<V=I9"`B3D].12(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR"FUS9VED(").3U1%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV.#@*;7-G:60@(DYA;64B"FUS9W-T<B`BJM?HS2(*"B,Z('!G<"YP:'`Z
M,3$P"FUS9VED(").86UE(&%N9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-S@*
M(RP@9G5Z>GD*;7-G:60@(DYE961S($%C=&EO;B(*;7-G<W1R("*ATL.AP]"W
MTR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4X,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<X"FUS
M9VED(").979E<B(*;7-G<W1R("+DP>C@Q=?-H2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-C`*(RP@9G5Z>GD*;7-G:60@(DYE=F5R('-A=F4@871T
M86-H;65N=',B"FUS9W-T<B`BQ;K@S:'*TL/AN;HB"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`BX\O!Z"(*"B,Z
M(&QI8B])35`N<&AP.C4V,PHC+"!F=7IZ>0IM<V=I9"`B3F5W($9O;&1E<B(*
M;7-G<W1R("+@N]2TXK_%X+3-P^PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#@*;7-G:60@(DYE=R!-86EL(@IM<V=S='(@(JBTR\'2PN/+P>@B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K+W1R965?9F]L
M9&5R<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(DYE=R!-97-S86=E(@IM<V=S
M='(@(J+IS:3'TL&UZ,WDNR(*"B,Z(&UA:6QB;W@N<&AP.C<W-B!L:6(O34E-
M12](96%D97)S+G!H<#HQ.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(J+IS:3'TL'CR\'H(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ.0IM<V=I9"`B3F5W(&UE<W-A
M9V5S(@IM<V=S='(@(J+IS:3'TL'CR\'H(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C$S,PHC+"!F=7IZ>0IM<V=I9"`B3F5X="(*;7-G
M<W1R("+!U:33Q^C2(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHS,PIM<V=I9"`B3F5X="!-97-S86=E(@IM<V=S='(@(J+I
MS:3'TL&UZ,WDNR(*"B,Z(&UA:6QB;W@N<&AP.C,U-@IM<V=I9"`B3F5X="!0
M86=E(@IM<V=S='(@(LNYZ=*UZ,WDNR(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS
M9VED(").;R(*;7-G<W1R("+DP>@B"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED
M(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y
M<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Y
M"FUS9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@;6%I
M;&)O>"YP:'`Z,S<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!-
M97-S86=E<R(*;7-G<W1R("*BZ<VDQ]+!X\O!Z"(*"B,Z('!G<"YP:'`Z,3,W
M"FUS9VED(").;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHX-`IM<V=I9"`B3F\@
M4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N="(*;7-G<W1R("(B"@HC.B!L
M:6(O36%I;&)O>"YP:'`Z,S(Y"B,L(&9U>GIY"FUS9VED(").;R!0<F5V:65W
M(%1E>'0B"FUS9W-T<B`BHNG-I,?2P;?5Z.&AZ>2BX<7IQR(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G:60@(DYO(%!U8FQI8R!+97ES
M($9O=6YD(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO
M(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DYO
M(&%T=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R("+@S:'*TL/AN;HB"@HC.B!L
M:6(O0W)Y<'0O4TU)344N<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M
M871I;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*
M(SH@86-L+G!H<#HW,B!A8VPN<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;R!F
M;VQD97(@<V5L96-T960N(@IM<V=S='(@(N3!Z.2TZ>#%U\VAXK_%X+3-P^SD
MQ^DB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F
M;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L
M:6(O1F]L9&5R+G!H<#HU-3`*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C
M:69I960B"FUS9W-T<B`BH</8L]+#T+K8XK_%X+3-P^RWU>BUZ<VGH=+#(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T-PHC+"!F=7IZ>0IM<V=I9"`B
M3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<R(*;7-G<W1R("+DP>CCJNBB
MZ<VDQ]+!M]7HMMFAQ;HB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30T
M"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A
M9V5S(@IM<V=S='(@(N3!Z..JZ*+IS:3'TL&WU>BVV:'%NB(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HS,C4*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@8F]D
M>2!T97AT(@IM<V=S='(@(L+ITL*BZ<VDQ]+!Y+LB"@HC.B!L:6(O36%I;&)O
M>"YP:'`Z,S<Q"B,L(&9U>GIY"FUS9VED(").;R!M97-S86=E<R!M871C:&5D
M('EO=7(@<V5A<F-H+B(*;7-G<W1R("+DP>C!U:+IS:3'TL'CM+7#IZ'1NJ'2
MPZ3IN<O2HLVGI-BS(@H*(SH@<&=P+G!H<#HQ.#D*;7-G:60@(DYO('!E<G-O
M;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@
M<&=P+G!H<#HQ-C4*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y
M(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C`Q"FUS9VED
M(").;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").;R!S<&5L
M;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(").;R!S
M<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`BY,'HOKJDT[?5Z,K0H;2\U+0B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`P"FUS9VED(").
M;R!S=6=G97-T:6]N<R(*;7-G<W1R("+DP>C!U:33X;G0N=,B"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C4V-`IM<V=I9"`B3F\@<W5P<&]R=&5D($E-05`@
M875T:&5N=&EC871I;VX@;65T:&]D(&-O=6QD(&)E(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!A8VPN<&AP.C8X(&%C;"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DYO('5S97(@<W!E8VEF:65D+B(*;7-G<W1R("*AP]BSTL/0NMCBO\7@M,W#
M[+?5Z+7IS:>ATL,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Y
M"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,2!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C0P"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C,U('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M-`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(").;VYE
M(@IM<V=S='(@(N3!Z.#%U\VA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDU"FUS9VED(").;W)M86PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C,Y"FUS9VED(").;W0@1&5L971E9"(*;7-G<W1R("+D
MP>BVV:'%NB(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@1')A
M9G0B"FUS9W-T<B`BY,'HXZKHX;JZP^C2IR(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,S0*;7-G:60@(DYO="!);7!O<G1A;G0B"FUS9W-T<B`BY,'HXZKHHNG-I,?2
MP<K3I-&M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM
M<V=I9"`B3F]T(%!E<G-O;F%L(@IM<V=S='(@(N3!Z..JZ*+IS:3'TL'*Z,>Y
MM=''(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z,3,Y(&QI8B]#<GEP="]334E-
M12YP:'`Z,3,T(&QI8B]#<GEP="]334E-12YP:'`Z,30Y"FUS9VED(").;W0@
M82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED(").;W0@9&5L971E9"!M97-S86=E
M<R(*;7-G<W1R("+DP>CCJNBBZ<VDQ]+!M]7HMMFAQ;HB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED(").;W0@:6UP;W)T86YT(&UE
M<W-A9V5S(@IM<V=S='(@(N3!Z..JZ*+IS:3'TL'*TZ31K2(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@
M(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$V"B,L(&9U>GIY"FUS9VED
M(").;W1H:6YG(@IM<V=S='(@(LWITJ?-U*<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<W"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@;6]N=&AS
M('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE=&EN9R!M
M;VYT:&QY+B(*;7-G<W1R("*HT[G'N>*_Q>"TS</LJ+3+P=+"HM+-S:&WU>BU
MZ<VGH=+#X*'GNN3'Z2#+TJ&WTZ'2P\6ZM]3II^"[Y[G#TL+@M-?-N2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*(RP@9G5Z>GD*;7-G:60@(DYU
M;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE
M=&EN9R!M;VYT:&QY+B(*;7-G<W1R("*HT[G'N>*_Q>"TS</LJ+3+P=+"HM+-
MS:&WU>BUZ<VGH=+#X*'GNN3'Z2#+TJ&WTZ'2P\6ZM]3II^"[Y[G#TL+@M-?-
MN2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-3(*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<S,PIM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C0Y"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M-#@*;7-G:60@(D]2(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,34*;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R("*BZ<VD
MQ]+!X*'HTB(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT
M;6%I;%]M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD
M97)S(&)E:6YG('!U<F=E9"XB"FUS9W-T<B`BH=/%T:>ATZC1M.*_Q>"TS</L
MJ+3+P=+"HM+-S:&BS:?@M-?-N:'HS;GF(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C(U"FUS9VED(")/;FQY(&1I<W!L87D@9F]L9&5R<R!W:71H('5N
M<F5A9"!M97-S86=E<R!I;B!T:&5M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"FUS9VED(")/;FQY(&]N92!F
M;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$P('1E;7!L871E<R]M
M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E;B!&;U]L9&5R(@IM<V=S
M='(@(N"[U+3BO\7@M,W#["(*"B,Z(&9O;&1E<G,N<&AP.C0R-PHC+"!F=7IZ
M>0IM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G<W1R("+@N]2TXK_%X+3-P^PB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`U"FUS9VED(")/<'1I
M;VYA;"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!F971C:&UA:6PN<&AP
M.C,S('1E;7!L871E<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHV"B,L(&9U>GIY"FUS9VED(")/
M=&AE<B!-86EL($%C8V]U;G1S(@IM<V=S='(@(K71Q^#%U\VAS=?HN2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I
M;VYS(@IM<V=S='(@(K71Q^#%U\VAS=?HN2(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C`Q"FUS9VED(")/=71B;W5N9"!397)V97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ-B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HQ-C4*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,C`T(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,`IM<V=I9"`B
M4$=0(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?
M;&ES="YI;F,Z-PIM<V=I9"`B4$=0($5N8W)Y<'0@365S<V%G92(*;7-G<W1R
M("(B"@HC.B!C;VUP;W-E+G!H<#HS-3@*(RP@9G5Z>GD*;7-G:60@(E!'4"!%
M<G)O<CH@(@IM<V=S='(@(KS4M+[%TK0B"@HC.B!C;VUP;W-E+G!H<#HS,S<*
M;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA
M;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$T,@HC+"!F=7IZ>0IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T
M<B`BM=''X,77S:$B"@HC.B!P9W`N<&AP.C,P"FUS9VED(")01U`@4&%S<W!H
M<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-34*;7-G:60@(E!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q
M=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PIM<V=I9"`B4$=0(%!U8FQI
M8R!+97D@5&5X="(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$T.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@
M*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(N*_Q>"T
MS</L(%PB)7-<(B#DM.FVV:'*P^G2IZ+6Z;G@P]7"NL/IS<+AQ>G'(@H*(SH@
M<&=P+G!H<#HR-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!'4"!0
M=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D
M+B(*;7-G<W1R("+BO\7@M,W#["!<(B5S7"(@Y+3IMMFAQ;K@P]7"NL/IS<+A
MQ>G'(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T"FUS9VED(")01U`@
M4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHX"B,L(&9U>GIY"FUS9VED(")01U`@4VEG
M;B!-97-S86=E(@IM<V=S='(@(J+IS:3'TL&WU>CAQ>G'(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"FUS9VED(")01U`@4VEG
M;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HR,#(*
M;7-G:60@(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM
M<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3<W"FUS9VED(")01U`@<'5B;&EC(&ME
M>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")01U`@<W5P<&]R="!I<R!D
M:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,C`X"FUS9VED("(B"B)01U`@<W5P<&]R="!I
M<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U
M<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.34*;7-G:60@(B(*(E!'4"!S
M=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!M97-S86=E
M(&ES('5N86)L92!T;R!B92!D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED("(B"B)01U`@<W5P<&]R="!R
M97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R
M;W=S97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I
M;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T
M:&4@4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*
M;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I
M9"`B4$]0,R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C$P,`IM<V=I9"`B4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G
M<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q-PIM<V=I9"`B
M4$]0,R!O=F5R(%-33"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@
M8V5R=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,38Y"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE
M9"DB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3$*
M;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(E!A
M9V4@)60@;V8@)60B"FUS9W-T<B`BR[GITK?5Z"`E9""HTJ$@)60B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS9VED(")086=E('=I=&@@=&AE
M($9I<G-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,#0*;7-G:60@(E!A9V4@=VET:"!T:&4@3&%S="!5
M;G-E96X@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R="AS*2(*;7-G<W1R("+*Z,>Y
MN\/0H<VZ(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R,PIM<V=I9"`B
M4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!9V%I;BDB"FUS9W-T<B`B(@H*
M(SH@<VUI;64N<&AP.C(S-2!P9W`N<&AP.C,Q,`IM<V=I9"`B4&%S<W!H<F%S
M92!S=6-C97-S9G5L;'D@=6YL;V%D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A
M<W-P:')A<V4N:6YC.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R("(B
M"@HC.B!P9W`N<&AP.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B
M92!E;7!T>2(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$Q-`IM<V=I9"`B4&%S
M<W!H<F%S97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP
M;W)T7VME>2YI;F,Z-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M.3(*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(L/+T<J\Z-*Y(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L(&9U>GIY"FUS9VED
M(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM
M<V=S='(@(K33X+G4N:'2P[K3P]BGP]&AR=+#T+JZX[FBL]#%IZK7Z,W@HNG2
M(@H*(SH@86-L+G!H<#HW-B!A8VPN<&AP.C$P,@IM<V=I9"`B4&5R;6ES<VEO
M;G,@9F]R('1H:7,@=7-E<B!C86X@;F]T(&)E(&-H86YG960N(@IM<V=S='(@
M(B(*"B,Z(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HW,#,@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R("+*Z,>Y
MM=''(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")097)S
M;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("*BZ<W!V<7*Z,>YM=''(@H*(SH@
M<&=P+G!H<#HQ,C`*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R
M871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3(W
M"FUS9VED(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(P-PIM<V=I9"`B4&5R<V]N
M86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z("(*;7-G<W1R
M("(B"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S;VYA;"!3+TU)344@
M:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA8V4@>6]U<B!S:6=N
M871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/R(*;7-G<W1R("+@
MM=3!Q=+"X*OGN:+-IZ38L^.YH=+#M<VZH<71NN'%T,KHI[7HS3\B"@HC.B!C
M;VUP;W-E+G!H<#HR-30*;7-G:60@(E!L86EN=&5X="!697)S:6]N(&]F($UE
M<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y
M.0IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O;B!N97<@;6%I;#\@(%1H:7,@<F5Q
M=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O<G0@96UB961D960@(@HB<V]U
M;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I;F1O=W,@86YD($UA8RP@
M8G5T(&]T:&5R('!L871F;W)M<R!W:6QL("(*(G)E<75I<F4@82!P;'5G:6XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N
M:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3`R('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS
M9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3,W"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H
M<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@
M;F5E9"!T;R`B"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@
M<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P
M:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E
M;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K
M97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES('!A<W-P
M:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@<F5C
M;VUP;W-E+G!H<#HY-PIM<V=I9"`B(@HB4&QE87-E(&QO9R!I;B!A9V%I;B!T
M;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.
M3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S
M<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R`B"B)L
M;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES
M(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@(@HB:&EJ86-K:6YG('EO=7(@
M<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M,0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PIM<V=I9"`B
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@
M8V]M<&]S92YP:'`Z,3`V(&QI8B])35`N<&AP.C0U.0IM<V=I9"`B4&QE87-E
M(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+B(*;7-G
M<W1R("*AP]BSTK7#QZC*S;JWU>C-PMGHJ^G3R\/7S;[4P;[LO-2T(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8T,@IM<V=I9"`B(@HB4&QE87-E
M(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S
M96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C$*
M;7-G:60@(E!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F
M;W)M(&%N>2!A8W1I;VYS+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3`R"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO
M;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC.C0Q"FUS9VED(")0;&5A<V4@<V5L
M96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS9VED
M(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHW,PHC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('-E;&5C="!O<B!E
M9&ET(&EN('1H92!B;W@@=&\@=&AE(')I9VAT.B(*;7-G<W1R("*AP]BSTN#%
MU\VAR\/7S>&AZ>2BM>C-Y+LZ(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z
M-#$*;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q-`HC+"!F=7IZ>0IM<V=I9"`B4')E8V5D
M92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R
M("+@M=3!HM6T("@G+2TG*2#DQ^FBZ=+'R[GITL72PN"KY[FBS:>DV+,B"@HC
M.B!S;6EM92YP:'`Z,C0Q('!G<"YP:'`Z,C4W(&9I;'1E<G!R969S+G!H<#HT
M,`HC+"!F=7IZ>0IM<V=I9"`B4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P
M9&%T960N(@IM<V=S='(@(N*_Q>"TS</L(%PB)7-<(B#DM.FVV:'*P^G2IZ+6
MZ;G@P]7"NL/IS<+AQ>G'(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS9W-T<B`B
MR[GITK?5Z.'%Z<<B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U<R!-97-S86=E(@IM<V=S='(@
M(J+IS:3'TL&WU>CAQ>G'(@H*(SH@;6%I;&)O>"YP:'`Z,S0W"FUS9VED(")0
M<F5V:6]U<R!086=E(@IM<V=S='(@(LNYZ=*WU>CAQ>G'(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")0<FEN
M="(*;7-G<W1R("*^U,&^["(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E
M<G,N:6YC.C,X"B,L(&9U>GIY"FUS9VED(")0<FEO<FET>2(*;7-G<W1R("*^
MU,&^["(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM
M<V=I9"`B4')I=F%T92!+97D@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4U.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I
M;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R
M;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L
M="!T;R!915,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C$P"FUS9VED(")0<F]T;V-O;#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E
M<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC.C@*(RP@9G5Z>GD*;7-G:60@
M(E!U<E]G92!$96QE=&5D(@IM<V=S='(@(L6ZXK3"MM+'PR(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G-?9&5L971E9"YI;F,Z.`IM<V=I9"`B4'5R9V4@1&5L971E9"(*
M;7-G<W1R("+%NN*TPK;2Q\,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHR-`HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@1F]L9&5R*',I(@IM
M<V=S='(@(L6ZXK_%X+3-P^PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(J3'
MTL&VU>CCN:'2PZ'3J-&TMM&GHL+0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0P-0HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@;65S<V%G97,@:6X@5')A
M<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RXB"FUS
M9W-T<B`BJ-.YQ[G'T;FWU>C@H>>ZHNG-I,?2P>3'Z>.YXK_%X+3-P^RVT:>B
MPM"AZ,VYH=+#H=.HT;0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V
M"B,L(&9U>GIY"FUS9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R
M87-H(&9O;&1E<C\B"FUS9W-T<B`BH=.HT;2BZ<VDQ]+!X*'HTN.YXK_%X+3-
MP^RVT:>BPM`B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S
M:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!U<F=I;F<@
M)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(J'3J-&T
M("5D(*+IS:3'TL'-S:&HTJ'BO\7@M,W#[+;1IZ+"T"(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I
M9"`B4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S
M='(@(J'3J-&T("5D(*+IS:3'TL'-S:&HTJ'BO\7@M,W#[+;1IZ+"T"(*"B,Z
M('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.
M3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N
M:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@3D\@
M3$E-250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS
M9W-T<B`BS>G2I\W4IR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,X-@IM<V=I9"`B4F5?<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP.C4P"B,L(&9U>GIY"FUS
M9VED(")296-E:79E9"!/;B(*;7-G<W1R("+DM.G#T;K@P=?HS2(*"B,Z(&QI
M8B]396%R8V@N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!3:6YC
M92(*;7-G<W1R("+DM.G#T;K@P=?HS2(*"B,Z(&QI8B]396%R8V@N<&AP.C4T
M"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R("+DM.G#
MT;K@P=?HS2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(N"[
MQ=7HPKG@RNFYM]*G(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C="(*;7-G<W1R("+@N\75Z,*Y
MX,KIN;?2IR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ
M,3`*(RP@9G5Z>GD*;7-G:60@(E)E9&ER96-T($UE<W-A9V4B"FUS9W-T<B`B
MX+O%U>C"N>#*Z;FWTJ>BZ<VDQ]+!N=7I(@H*(SH@8V]M<&]S92YP:'`Z-S@W
M"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T<B`BX+O%U>C"
MN>#*Z;FWTJ>BZ<VDQ]+!N=7I(@H*(SH@8V]M<&]S92YP:'`Z.#0W"FUS9VED
M(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(J'2P^"[U>C"N>#*Z;FW
MTJ?%Z<'@R\7'(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-3@S"FUS9VED(")2969R97-H(@IM<V=S='(@(L/5X+_#JB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E<V@@1F]L9&5R(%9I
M97=S.B(*;7-G<W1R("+#U>"_PZK!V,'!S:?BO\7@M,W#["(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA:6QB;W@O:&5A
M9&5R+FEN8SHT"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`BP]7B
MR\6TP=C!P<VG(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM
M<V=I9"`B4F5L;V%D(%9I97<B"FUS9W-T<B`BP]7BR\6TP=C!P<VG(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R-B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-30U"FUS9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3<Y"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S='(@
M(JBTJ-/!V,'!S:?%Z-+*V+0B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z,C<*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*
M;7-G<W1R("*UV>GDN\/)L]7"["(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE
M;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC
M.C,P-0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R("*Y
MT^'+Q>BGHNG-P=G%S<VA(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B4F5N86UE($9O;&1E<BAS*2(*;7-G
M<W1R("+@N\75Z,*YJM?HS>*_Q>"TS</L(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F
M;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R("+@N\75Z,*Y
MJM?HS>*_Q>"TS</LJ+3+P=+"HM+-S:&WV*'F(+7IN>"TU\VY(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-#4U"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG
M(%PB)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(J'2P^"[Q=7HPKFJU^C-J-*A(%PB)7-<(B#@
MN^>Y(%PB)7-<(B#%Z<'@R\7'(."DP]?HS:>ZP]2ATL/#TL*GTKG'Z-(B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*(RP@
M9G5Z>GD*;7-G:60@(E)E<&Q?>2!T;R!,:7-T(@IM<V=S='(@(K7-NJ'%T;JW
MT>FGR\&T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P
M-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G<W1R("+AM[FWU>BTZ<?".B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS
M9VED(")297!L>2(*;7-G<W1R("*US;JAQ=&Z(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C,Q,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Y
M"B,L(&9U>GIY"FUS9VED(")297!L>2!396YT+B(*;7-G<W1R("*US;JAQ=&Z
MY+O"T:<B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R("*US;JAQ=&ZM]'I
MI\O!M"(*"B,Z(&-O;7!O<V4N<&AP.C<S,PIM<V=I9"`B4F5P;'D@=&\@06QL
M.B(*;7-G<W1R("*US;JAQ=&ZM]'II\O!M#HB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E)E
M<&QY('1O($QI<W0B"FUS9W-T<B`BM<VZH<71NK?1Z:?+P;0B"@HC.B!C;VUP
M;W-E+G!H<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O($QI<W0Z(@IM
M<V=S='(@(K7-NJ'%T;JWT>FGR\&T.B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@
M=&\@7T%L;"(*;7-G<W1R("*US;JAQ=&ZM]'II\O!M"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4S-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED(")2
M97!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,U"FUS9VED(")297!L>2!W
M:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-`IM<V=I9"`B4F5P;'D@
M=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!M97-S86=E+G!H<#HR-C<*(RP@9G5Z>GD*;7-G:60@(E)E<&QY
M+51O(@IM<V=S='(@(K7-NJ'%T;KDN\+1ISHB"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z-#`Y"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(K7-NJ'%T;KDN\+1
MISHB"@HC.B!C;VUP;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*;7-G<W1R
M("*US;JAQ=&Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(V"B,L
M(&9U>GIY"FUS9VED(")297!O<G0@87,@26YN;V-E;G0B"FUS9W-T<B`BP]+"
MI]*YQ^C2X+OGN2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHS-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,PIM
M<V=I9"`B4F5P;W)T(&%S(%-P86TB"FUS9W-T<B`BP]+"I]*YQ^C2X+OGN2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X,PHC+"!F=7IZ
M>0IM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`BP^G-
MIZ+-X[JUS;K#T;HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS
M9VED(")297%U97-T(&1E;&EV97)Y(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,PHC+"!F=7IZ>0IM<V=I
M9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G<W1R("+#Z<VGHLWCNK7-
MNL/1NB(*"B,Z(&UA:6QB;W@N<&AP.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE
M<W-A9V4@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-CDW"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$V,0HC+"!F=7IZ>0IM<V=I9"`B4F5S970B"FUS9W-T<B`B
MM].UZ,TB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$U"FUS9VED
M(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@
M(E)E<W5M92(*;7-G<W1R("*WT[7HS2(*"B,Z(')E8V]M<&]S92YP:'`Z.3@*
M;7-G:60@(E)E<W5M92!Y;W5R('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0T"B,L(&9U>GIY"FUS9VED
M(")2971U<FX@=&\@7")-97-S86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`B
MX*+5PKFBZ<VDQ]+!X\O!Z"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I
M=F5R7W-E;&5C="YI;F,Z,S$@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C8Y"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N
M:6YC.C,R"FUS9VED(")2971U<FX@=&\@1F5T8V@@36%I;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S
M+V9I;'1E<G,O;F]T86-T:79E+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C$P,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ
M-`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O
M;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S,*(RP@9G5Z>GD*;7-G:60@(E)E
M='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(K71Q^#%U\VAX*'5Z,+'H=&ZO-GI
MXZKI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q.`IM<V=I9"`B(@HB
M4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L
M(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(K7IS:>A
MTL.AQ=&ZRMGHP]+"H=+#M=GIY+O#R;/5PNS+Q=&GJ-*AM].ATL/%NBP@PNG2
MPB#+P]?-RM/@N=*BZ<VDQ]+!R\/7S>3!Z#\B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C@X"FUS9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y
M"FUS9VED(")3+TU)344B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@
M365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS.30*;7-G:60@
M(E,O34E-12!%<G)O<CH@(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C,W
M,PIM<V=I9"`B4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E
M<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34Q"B,L(&9U>GIY"FUS9VED(")3+TU)344@3W!T:6]N
M<R(*;7-G<W1R("*UT<?@Q=?-H2(*"B,Z('-M:6UE+G!H<#HT.0IM<V=I9"`B
M4R]-24U%(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B4R]-24U%(%!E<G-O;F%L
M($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$T,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@9F]R(%PB)7-<
M(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(N*_Q>"TS</L
M(%PB)7-<(B#DM.FVV:'%NN##U<*ZP^G-PN'%Z<<B"@HC.B!S;6EM92YP:'`Z
M,38R"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,3`*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R("(B"@HC
M.B!S;6EM92YP:'`Z,C$Q"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A=&4@
M2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*;7-G:60@(E,O
M34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ-`IM<V=I9"`B4R]-24U%(%-I9VXO
M16YC<GEP="!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E,O34E-12!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U<'!O
M<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES
M('5N86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<S"FUS9VED("(B"B)3+TU)344@
M<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI
M<R!S:6=N960@;65S<V%G92!C86X@;F]T("(*(F)E(&1I<W!L87EE9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*;7-G
M:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D
M:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@IM
M<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W
M<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES("(*(F-U<G)E;G1L
M>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N
M9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@(@HB=&AE(%,O34E-12!F96%T=7)E
M<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#4*;7-G:60@(E--5%`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4U"B,L
M(&9U>GIY"FUS9VED(")37W5B:F5C="(*;7-G<W1R("*JU^C-X,/7Z,VG(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S8S"B,L(&9U>GIY
M"FUS9VED(")385]V92!A(&-O<'D@:6X@(@IM<V=S='(@(KK1N;?6H<K3X+G2
MX[DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,S(*(RP@9G5Z>GD*;7-G:60@(E-A7W9E(&%S(@IM<V=S='(@(KK1N;?6H>"[
MY[DB"@HC.B!S96%R8V@N<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`BNM&Y
MM]:AX+OGN2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4S
M.`IM<V=I9"`B4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N
M="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#,S"B,L(&9U>GIY"FUS9VED(")3879E($1R869T(@IM<V=S='(@(KK1
MN;?6H>"[Y[DB"@HC.B!S879E:6UA9V4N<&AP.C0R"B,L(&9U>GIY"FUS9VED
M(")3879E($EM86=E(@IM<V=S='(@(KK1N;?6H>"[Y[DB"@HC.B!L:6(O34E-
M12]#;VYT96YT<RYP:'`Z,C`T"FUS9VED(")3879E($EM86=E(&EN($=A;&QE
M<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C4Y('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`P"B,Z('1E;7!L871E
M<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ-#@*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$S"B,L(&9U
M>GIY"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BM=''X,77S:'@H=7H
MPL>AT;J\V>GCJNDB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z-#`*;7-G:60@(E-A=F4@4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,S,*(RP@9G5Z>GD*;7-G:60@(E-A=F4@7T1R
M869T(@IM<V=S='(@(KK1N;?6H>"[Y[DB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T
M<B`BNM&YM]:AX+OGN2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*
M;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-S(*;7-G:60@(E-A=F4@<F5C:7!I
M96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O
M:S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ
M,C<*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*(RP@9G5Z
M>GD*;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R("*ZT;FWUJ&HM,O!
MTL*BTLW-H2(*"B,Z(&-O;7!O<V4N<&AP.C$R,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(J'2P[K1N;?6H>&ZNL/HTJ?%
MZ<'@R\7'(."DP]?HS:>ZP]2ATL/#TL*GTKG'Z-(Z("5S(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H
M<#HT,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(J3IN<O2(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VAE
M861E<BYI;F,Z,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-E87)C
M:"`E<R(*;7-G<W1R("*DZ;G+TB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!/<'1I;VYS(@IM<V=S='(@
M(K71Q^#%U\VAX*'5Z,+'H=&ZO-GIXZKI(@H*(SH@<V5A<F-H+G!H<#HR-C4*
M;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(KS%H=+#I.FYR](B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$T('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E96XB"FUS9W-T<B`BS>C2
MN>'%Z<<B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*;7-G
M:60@(E-E;&5C="(*;7-G<W1R("+@Q=?-H2(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHW,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($%N
M;W1H97(@06-C;W5N="(*;7-G<W1R("+DP>C@Q=?-H>#%PB(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&$@9&%T92(*;7-G<W1R("+@Q=?-H>#-H<71H<FS[.CHZ.CHZ.CHZ.CH
MZ.CHZ.CH(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R("+@Q=?-H;?1
MZ:?+P;0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@
M(N3!Z.#%U\VAX,7"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O
M<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R
M("+@Q=?-H>'+Q>BGM]7HM=2TM>C-X+[7Z,VWTZ'2P^"^U.C!X<70I.FYR]+#
MTL*JU^C-(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R("+@Q=?-H;?1Z:?+P;0B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N(@IM<V=S='(@(J'3R[FTQ=.TT;JBS:>WU>BUU+2UZ,VW
MU>BUZ<VGH=+#X\OII.FYR]+CN:*ST+?3H=+#X+74P>"UY\&JU^C-(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@(N3!Z.#%
MU\VAX,7"(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I
M9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`BY,'HX,77S:'@Q<(B"@HC.B!T96UP
M;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B4V5L96-T
M('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C(Q
M"FUS9VED(")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"B,L
M(&9U>GIY"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G<W1R
M("*WU>BUU+2UZ,VWU>C@Q=?-H3HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S(*;7-G:60@(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P-`HC+"!F
M=7IZ>0IM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T<B`B
MHNG-P=G%X*3#U^C-I[K#U*'2PR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S
M,0HC+"!F=7IZ>0IM<V=I9"`B4V5N9"!-97-S86=E(@IM<V=S='(@(J+IS:3'
MTL&UZ,WDNR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,#,*;7-G:60@
M(E-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD
M97(_(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PHC+"!F=7IZ>0IM
M<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("+BO\7@M,W#[*BTR\'2
MPJ+2S<VA(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN
M8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`BXK_%X+3-
MP^RHM,O!TL*BTLW-H2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3,R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS9W-T<B`B
MX*3#U^C-I[K#U*'2PR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC
M+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VXB
M"FUS9W-T<B`BHNG-P=G%X*3#U^C-I[K#U*'2PR(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R
M.B(*;7-G<W1R("+@I,/7Z,VGNL/4H=+#(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@P"FUS9VED(")3970@<')E9F5R96YC97,@9F]R('=H870@:&%P
M<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N(@IM<V=S
M='(@(J'3R[FTI.C2H=+#H</0M]/@P=?HS;?3H=+#PNG2PN'%T,6ZHNG-I,?2
MP2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T
M:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0HC+"!F
M=7IZ>0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G<W1R("+BO\7@M,W#["(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B
M4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(N*_Q>"TS</LJ+3+P=+"HM+-
MS:$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E
M('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*;7-G:60@(B(*(E-H
M;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@
M:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL
M>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D>2!O9B!T
M97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D871A/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$S"FUS9VED
M(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S
M879I;F<@82!D<F%F=#\B"FUS9W-T<B`BM>G-IZ'2P^/+Z;O4M,NYZ=*UZ-*G
MX*+5PKFHM,O!TL++Q=&GJ-*ANM&YM]:AX;JZP^C2I\O#U\WDP>@_(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0*;7-G:60@(E-H;W5L9"!Y;W5R(%!'
M4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@
M8GD@9&5F875L=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*
M;7-G<W1R("+"V+KBO\7@M,W#[+?1Z:?+P;0B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]H96%D97)S+FEN8SHV-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*
M;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HS-C4*;7-G:60@(E-H;W<@1&5L
M971E9"(*;7-G<W1R("+ARK2GM]7HMMFAQ;HB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D($AE861E
M<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-S`*(RP@9G5Z>GD*;7-G:60@(E-H;W<@36%I;&EN9R!,:7-T($EN9F]R
M;6%T:6]N(@IM<V=S='(@(J+IS<'9Q<KHQ[FUT<<B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.CDR"B,L(&9U>GIY"FUS9VED(")3:&]W($]N;'D@
M4W5B<V-R:6)E9"!&;VQD97)S(@IM<V=S='(@(N#%U\VAXZKII]*YXK_%X+3-
MP^PB"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(E-H;W<@56YS=6)S8W)I
M8F5D(@IM<V=S='(@(N'*M*>WU>C@Q=2AXZKIY+OAQ>G'(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8P.`IM<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L
M;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P,@HC+"!F
M=7IZ>0IM<V=I9"`B4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\B
M"FUS9W-T<B`BX<JTIZ33S;C4NM+"RM&MQ=&AR;/LX[G!V,'!S:>UV>GDN\/)
ML]7"["(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#`*;7-G:60@(E-H
M;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W
M('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#<W"FUS9VED(")3:&]W('1H92!&971C:"!-86EL
M(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU-`IM
M<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR.`IM<V=I9"`B
M4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8V"FUS9VED(")3:&]W
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE
M861E<G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")3:5]Z92(*;7-G<W1R("*B
MN=*T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-PHC+"!F
M=7IZ>0IM<V=I9"`B4VEG;F5D(@IM<V=S='(@(J*YTK0B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G
M<W1R("*BN=*T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHQ,0IM<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,38*
M;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(V"B,L(&9U>GIY"FUS9VED
M(")3;W)T(&)Y($9R;VT@061D<F5S<R(*;7-G<W1R("*WU>C-PMGHO-GIRNBG
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT
M,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!-97-S86=E(%-I>F4B"FUS9W-T
M<B`BHKG2M*+-IZ+IS:3'TL$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y(%-U
M8FIE8W0B"FUS9W-T<B`BY,'HP=6JU^C-X,/7Z,VG(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,0HC+"!F=7IZ>0IM<V=I
M9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`BX+?#M"(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G
M:60@(E-O<G0@8GD@5&\@061D<F5S<R(*;7-G<W1R("*WU>C-PMGHO-GIRNBG
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S"B,L(&9U
M>GIY"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`BXK_%X+3-P^RVT:>B
MPM`Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0V"FUS
M9VED(")3<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T<B`BS=&AHL/0OM3@R,DB
M"@HC.B!S96%R8V@N<&AP.C$S,PIM<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O
M;&1E<G,@8V%N(&YO="!B92!E9&ET960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T,PIM<V=I9"`B4W!E;&P@0VAE
M8VLB"FUS9W-T<B`BM</'J*33RM"AM"(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B4W!E;&P@0VAE8VME<B(*;7-G<W1R
M("*UT<>UP\>HI-/*T*&T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C0X('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU-@IM
M<V=I9"`B4W!E;&P@8VAE8VL@8V]M<&QE=&4B"FUS9W-T<B`BM</'J*33RM"A
MM.##U<*ZP^G-PN'%Z<<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Q
M"FUS9VED(")3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL
M(&-H96-K:6YG+B(*;7-G<W1R("*HT[G'N:3'TL&\U+2^Q=*TM]7HX<JTI^.Y
MR[G6Z*?+N>G2J,VBL]"WTZ'2P[7#QZBDT\K0H;0B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3$R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-3(*;7-G:60@(E-T87)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE
M<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I
M9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(E-T<FEP
M($%T=&%C:&UE;G0B"FUS9W-T<B`BX,VARM+#X;FZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@S,@IM<V=I9"`B4W1R:7`@;&EN96)R96%K<S\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHS-PHC+"!F=7IZ>0IM<V=I9"`B4W5B7VIE8W0B"FUS9W-T<B`BJM?H
MS>##U^C-IR(*"B,Z(&UE<W-A9V4N<&AP.C(V."!T:')E860N<&AP.C$U,"!T
M96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(U"B,Z(&QI8B]396%R
M8V@N<&AP.C,X"FUS9VED(")3=6)J96-T(@IM<V=S='(@(JK7Z,W@P]?HS:<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(P"FUS9VED(")3=6)J96-T
M($9I96QD(@IM<V=S='(@(N"BM:+IS:3'TL&JU^C-X,/7Z,VG(@H*(SH@<V5A
M<F-H+G!H<#HS,3@@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC
M.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,"!T96UP
M;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")3
M=6)M:70B"FUS9W-T<B`BJM?HS>##U^C-IR(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R
M*',I(@IM<V=S='(@(N#%U\VAXZKII]*YXK_%X+3-P^PB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C,X,"!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HS.#D*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`BRM/@P^>H(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G<W1R
M("*DT^&YT+G3(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V,B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(")3=6UM87)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P
M,"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#,*;7-G:60@(E-W
M:71C:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@=&\@
M2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!P;&%I;B!T
M97AT(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0Q.0HC+"!F=7IZ>0IM<V=I9"`B5&5?>'0B"FUS
M9W-T<B`BP=6DT\?HTB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-CD*;7-G:60@(E1E;G1A=&EV93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P
M="!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL
M92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*
M;7-G<W1R("+!U:33Q^C2(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU
M-`IM<V=I9"`B5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U
M;&0@8F4@;&EN:V5D.B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C4S,@IM<V=I9"`B(@HB5&AE($E-05`@<V5R=F5R(&1O97,@;F]T(&%P
M<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A=&EO;B!M971H;V0@(@HB
M<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O
M=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R
M:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N
M<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S
M;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RXB"FUS9W-T<B`B(@H*
M(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`BX,VAQ=&AR;/L(%PB)7-<(B#DM.FVV:'%NN'%Z<<B"@HC.B!F
M971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`BX,VAQ=&AR;/L(%PB)7-<(B#DM.FVV:&ZT;FWUJ'AQ>G'(@H*(SH@871T
M86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT('=A<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV.0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-O;7!O<V5?
M=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@
M8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@
M=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,@IM<V=I9"`B5&AE(&-O
M;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I
M;%]M;VYT:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@8W5R
M<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N86UE9"!T;R!<(B5S
M7"(N(@IM<V=S='(@(N*_Q>"TS</LN]&HJ-BZT;D@7"(E<UPB(*C0MMFAX+O%
MU>C"N:K7Z,W@N^>Y(%PB)7-<(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHQ,#<*;7-G:60@(B(*(E1H92!C=7)R96YT(&QI<W0@;V8@=7-E<G,@=VET
M:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E=')I979E
M9"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C,V"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@7"(E
M<UPB(&9O;&1E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$S.0IM<V=I9"`B5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R
M(&-A;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M>'!A;F0N:6YC.CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F
M:65L9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@(N#-H<71
MH<FS["!<(B5S7"(@Y+3IMMFAQ;KAQ>G'(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,S,W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(N*_Q>"TS</L(%PB)7-<(B#!U<W"V>CA
MQ>G'(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS(&EL;&5G86P@8VAA
M<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E("(*(G!R;V)L96US
M+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(N*_Q>"TS</L(%PB)7-<(B#!U;71Q\W1H<G#M]7HY,'HMMFAM>G-
MI\W"V>CCN:K7Z,T@J];HI\W2J+?3X\OIX*'4M+O1K<O2Y+3I("(*(J'#V+/2
MM=2TM>C-O-GIM-GAQ=##T+JZHLVGI-BS(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A
M<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB
M"FUS9W-T<B`BXK_%X+3-P^P@7"(E<UPB(.2TZ;;9H<K#Z=*GHM;IN>'%Z<<@
MX;7HPM&GY,'HY+3IX,/5PJ'CJNDB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E
M;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB
M"FUS9W-T<B`BXK_%X+3-P^P@7"(E<UPB(.2TZ;;9H<6ZY+O-S:'AQ>G'(.&U
MZ*38L\+1I^3!Z.2TZ>#%U*'CJNDB"@HC.B!L:6(O1F]L9&5R+G!H<#HS-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO
M="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(N3!Z,K2P=+#MLK#Z=*GXK_%X+3-P^P@7"(E<UPB(.2TZ2#@I,/7Z,VG
MNL/4H=+#P]+"I]*YQ^C2(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C8U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@9&5L
M971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("+D
MP>C*TL'2P[;%NN*_Q>"TS</L(%PB)7-<(B#DM.D@X*3#U^C-I[K#U*'2P\/2
MPJ?2N<?HTB(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R
M96%T960N(@IM<V=S='(@(N*_Q>"TS</L(%PB)7-<(B#DM.FVV:'*P^G2IZ+6
MZ;G@P]7"NL/IS<+AQ>G'(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@9&5L971E9"XB"FUS9W-T<B`BXK_%X+3-P^P@7"(E<UPB(.2TZ;;9
MH<6ZX,/5PKK#Z<W"X<7IQR(*"B,Z(&QI8B]&;VQD97(N<&AP.C0U,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S
M<V9U;&QY(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("+BO\7@M,W#["!<
M(B5S7"(@Y+3IMMFAX+O%U>C"N:K7Z,W@N^>Y(%PB)7-<(B#@P]7"NL/IS<+A
MQ>G'(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDR"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@=&AI<R!P87)T
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7W-A
M=F5I;6%G95]W:6XN:G,Z,3(*;7-G:60@(B(*(E1H92!I;6%G92!S879E('=I
M;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@
M>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B
M(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S
M96YD97(@:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-0IM<V=I
M9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R
M<F]R(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C4Q"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N
M97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,`IM
M<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG
M(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!M86EL8F]X("5S(&ES
M(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(N*_Q>"TS</L(%PB)7-<(B#!U<W"
MV>CAQ>G'(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B`H)60@
M8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,#,*;7-G:60@
M(E1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@
M17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,30X"B,L(&9U
M>GIY"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("+@S:'%T:')L^P@7"(E<UPB(.2TZ;;9H<6ZX<7IQR(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B5&AE(&UE
M<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(N#-H<71H<FS["!<
M(B5S7"(@Y+3IMMFANM&YM]:AX<7IQR(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E
M(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA
M=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S
M<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA
M=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S
M/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F('1H92!01U`@
M4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@(E1H92!R97%U97-T
M960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM
M96YT+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV
M-`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!::7`@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP
M:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@
M=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E
M860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@
M(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4:&4@<V5R=F5R('=A
M<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ
M<SHQ,#0*;7-G:60@(E1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA
M8V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FIS.C$P,@HC+"!F=7IZ>0IM<V=I9"`B5&AE('-I9VYA='5R92!W87,@<W5C
M8V5S<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R("+BO\7@M,W#["!<(B5S7"(@
MY+3IMMFARL/ITJ>BUNFYX,/5PKK#Z<W"X<7IQR(*"B,Z(&%T=&%C:&UE;G0N
M<&AP.C4Y"FUS9VED(")4:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(B(*"B,Z('-T871I;VYE<GDN<&AP.C@T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S
M(&)E96X@861D960N(@IM<V=S='(@(N#-H<71H<FS["!<(B5S7"(@Y+3IMMFA
MNM&YM]:AX<7IQR(*"B,Z('-T871I;VYE<GDN<&AP.C8S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`BX,VAQ=&AR;/L(%PB)7-<(B#DM.FVV:'%
MNN'%Z<<B"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N('5P
M9&%T960N(@IM<V=S='(@(N#-H<71H<FS["!<(B5S7"(@Y+3IMMFAQ;KAQ>G'
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V.0IM<V=I9"`B5&AE
M('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*(RP@9G5Z
M>GD*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(L6Z
MHNG-I,?2P2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N
M960@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T
M:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92(*
M;7-G<W1R("+@N\75Z,*YX,KIN;?2IZ+IS:3'TL&YU>DB"@HC.B!L:6(O34E-
M12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W
M960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ-30*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z.#8*;7-G:60@(E1H97)E(&%R
M92!N;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]E;7!T
M>5]M86EL8F]X+FEN8SHS"FUS9VED(")4:&5R92!A<F4@;F\@;65S<V%G97,@
M:6X@=&AI<R!M86EL8F]X+B(*;7-G<W1R("+DP>C!U:+IS:3'TL'CN;79Z>2[
MP\FSU<+LN=7I(@H*(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES
M(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8Q,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("+@H=2THNG-O-2TOL72
MM..YH=+#Q;H@)7,@X*3#U^C-I[K#U*'2P\/2PJ?2N<?HTB(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HV-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@
M<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(N"AU+2BZ<V\U+2^Q=*TX[FATL/%
MNK79Z>2[P\FSU<+L(."DP]?HS:>ZP]2ATL/#TL*GTKG'Z-(Z("5S(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8R,0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60B"FUS9W-T<B`BX*'4M*+IS;S4M+[%TK3CN:'2P\6ZM=GIY+O#
MR;/5PNP@X*3#U^C-I[K#U*'2P\/2PJ?2N<?HTB(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HY,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@
M7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S
M='(@(N"AU+2BZ<V\U+2^Q=*TX[FATL/*T^"YTJ+IS:3'TL'DN\+1IR!<(B5S
M7"(@X*3#U^C-I[K#U*'2P^&HZ:?'Z-(B"@HC.B!L:6(O365S<V%G92YP:'`Z
M,3DX(&QI8B]-97-S86=E+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@
M=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`BX*'4M*+IS;S4M+[%TK3CN:'2P\6ZHNG-I,?2P:C2
MH>*_Q>"TS</L(%PB)7-<(B#@I,/7Z,VGNL/4H=+#P]+"I]*YQ^C2(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O
M;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B
M"FUS9W-T<B`BX*'4M*+IS;S4M+[%TK3CN:'2P\6ZHNG-I,?2P>.YXK_%X+3-
MP^P@7"(E<UPB(."DP]?HS:>ZP]2ATL/#TL*GTKG'Z-(B"@HC.B!L:6(O365S
M<V%G92YP:'`Z,C$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(N"AU+2BZ<V\U+2^Q=*T
MX[FATL/%NJ+IS:3'TL$@X*3#U^C-I[K#U*'2P\/2PJ?2N<?HTB(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HY.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N
M=#H@)7,N(@IM<V=S='(@(N"AU+2BZ<V\U+2^Q=*TX[FATL/ARK2GHNG-I,?2
MP;?5Z,/0NM@B"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI
M8B]-24U%+U9I97=E<B]E;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S
M='(@(N"AU+2BZ<V\U+2^Q=*TX[FATL/ARK2GRNC'N;G5Z:+-IZ+IS:3'TL$B
M"@HC.B!L:6(O365S<V%G92YP:'`Z-30U(&QI8B]-97-S86=E+G!H<#HU.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&9L
M86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES
M('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(N"AU+2BZ<V\U+2^
MQ=*TX[FATL.ZZ*>JU>FBZ<VDQ]+!X[GBO\7@M,W#["!<(B5S7"(@X*3#U^C-
MI[K#U*'2P\/2PJ?2N<?HTB(*"B,Z(&9O;&1E<G,N<&AP.C$V-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R`E<RXB"FUS9W-T<B`BX*'4M*+IS;S4M+[%TK3CN:'2P[K1N;?6H>&Z
MNL/HTJ<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3,V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(N"AU+2BZ<V\U+2^Q=*T
MX[FATL/ARK2GHNG-I,?2P;?5Z,/0NM@B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,38V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS9W-T
M<B`BX*'4M*+IS;S4M+[%TK3CN:'2P^'*M*>BZ<VDQ]+!M]7HP]"ZV"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E
M<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(N"AU+2B
MZ<V\U+2^Q=*TX[FATL/*Z*>BZ<VDQ]+!HLVGI-BS.B`E<R(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M(%PB)7-<
M(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B
M"FUS9W-T<B`BX*'4M*+IS;S4M+[%TK3CN:'2P\+ITL*BZ<VDQ]+!Y+L@7"(E
M<UPB(."DP]?HS:>ZP]2ATL/#TL*GTKG'Z-(B"@HC.B!C;VUP;W-E+G!H<#HQ
M,C0T"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG
M('1H:7,@;65S<V%G92!A<R!A(&1R869T+B(*;7-G<W1R("+@H=2THNG-O-2T
MOL72M..YH=+#X<JTI\KHQ[FYU>FBS:>BZ<VDQ]+!(@H*(SH@8V]M<&]S92YP
M:'`Z,3`P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM<V=S='(@(N"AU+2BZ<V\
MU+2^Q=*TX[FATL/*Z*>BZ<VDQ]+!HLVGI-BS.B`E<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S
M+B(*;7-G<W1R("+@H=2THNG-O-2TOL72M..YH=+#RNBGHNG-I,?2P:+-IZ38
MLSH@)7,B"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4Y"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@
M<&%R="(*;7-G<W1R("+@H=2THNG-O-2TOL72M..YH=+#X<JTI\KHQ[FYU>FB
MS:>BZ<VDQ]+!(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"FUS
M9VED(")4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN
M(&ET+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M.3`*;7-G:60@(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB
M961D960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L:6ME("(*(G1H
M:7,Z("(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ
M-C8*;7-G:60@(E1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O
M('1H92!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3`T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3@*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,R!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,34W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S,@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q-`IM<V=I9"`B5&AI<R!A8W1I
M;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$W.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#$Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C$T"FUS9VED(")4:&ES(&UA>2!T86ME('-O;64@=&EM92X@07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(&-O;G1I;G5E/R(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED(")4:&ES
M(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3`*;7-G:60@(B(*
M(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S
M(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R\B"B)-24U%+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q-`IM<V=I9"`B
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@
M8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B"B)4:&ES(&UE
M<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M871I
M;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G92!I<R!U;FMN
M;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS
M,34*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R<F]R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C0P(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,U,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R
M;6%T("AA8V-O<F1I;F<@=&\@(@HB4D9#(#(P,34I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI<R!M
M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3
M+TU)344@9F]R;6%T+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR,#4@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z-#$V"FUS9VED
M(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@
M4$=0+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C$T,PIM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S
M:6=N960@=FEA(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HQ,SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR
M,S@*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA
M(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,C`Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,0IM<V=I9"`B5&AI
M<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T
M<B`B(@H*(SH@;65S<V%G92YP:'`Z,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@
M=&\B"FUS9W-T<B`BHNG-I,?2P;G5Z>2[PM&G(@H*(SH@86-L+G!H<#HT-@IM
M<V=I9"`B5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,3`Y"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z('1H<F5A
M9"YP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G
M<W1R("+ARK2GO,4B"@HC.B!T:')E860N<&AP.C<V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,C(*;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@(L'8P<'-
MI^"WP[0B"@HC.B!M97-S86=E+G!H<#HR-C0@;6%I;&)O>"YP:'`Z-C`V('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C8Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M8V]M<&]S92YI;F,Z,3`@;&EB+U-E87)C:"YP:'`Z,C8*;7-G:60@(E1O(@IM
M<V=S='(@(K;6IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3D*(RP@
M9G5Z>GD*;7-G:60@(E1O($%D9')E<W,B"FUS9W-T<B`BM]7HS<+9Z+S9Z<KH
MIR(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C
M;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HQ
M,S0*;7-G:60@(B(*(E1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S
M="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@-2XP+C8@;W(@(@HB:&EG
M:&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU-S<*(RP@9G5Z>GD*;7-G:60@(E1O=&%L($%T=&%C:&UE;G1S(%-I
M>F4Z(@IM<V=S='(@(N#-H<K2P^&YNB(*"B,Z(&9O;&1E<G,N<&AP.C,X.`HC
M+"!F=7IZ>0IM<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(N*_Q>"TS</L
MMM&GHL+0.B(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z
M,C,*;7-G:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`BXK_%X+3-P^RVT:>B
MPM`Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV-2!L:6(O475O=&$O;65R
M8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N9"YP:'`Z-S(*(SH@;&EB
M+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T82]C;W5R:65R+G!H<#HU
M,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*;7-G:60@(E5N86)L92!T;R!R
M971R:65V92!Q=6]T82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS
M-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R("+DP>CDM.FUS;JAQ=&Z(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA;G-W
M97)E9"!M97-S86=E<R(*;7-G<W1R("*BZ<VDQ]+!M]7HY,'HY+3IM<VZH<71
MNB(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E
M;&5T92(*;7-G<W1R("*AV>FDU[DB"@HC.B!M86EL8F]X+G!H<#HU.#D@;6%I
M;&)O>"YP:'`Z-C`R(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q,@IM<V=I9"`B
M56YD:7-C;&]S960@4F5C:7!I96YT<R(*;7-G<W1R("*\V>G#T;JWU>CDP>C@
MN]2TX+S"(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0T-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z
M("5S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V-0IM<V=I9"`B56YK
M;F]W;B!$871E(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!4"!R97-P;VYS
M92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,S4*;7-G:60@
M(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HV
M,3@*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@
M(KS9Z</1NK?5Z.3!Z."[U+3@O,(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL
M;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N
M<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@(N3!Z,'5JM?HS2(*"B,Z
M(&UE<W-A9V4N<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHS,@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@
M(E5N<V5E;B(*;7-G<W1R("+"T:?DP>CDM.G@N]2T(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3(*;7-G:60@(E5N<W5B<V-R:6)E(&9R
M;VT@1F]L9&5R*',I(@IM<V=S='(@(N#%U*'CJNGBO\7@M,W#["(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X-`IM<V=I9"`B57!D871E
M($%T=&%C:&UE;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8R,`IM<V=I9"`B57!D871E(')E<W!O;F1E
M;G0@<W1A='5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V
M"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U;'0@5F%L
M=64B"FUS9W-T<B`BXZKII.C2XK3"N\/4PM+"(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(U-@HC+"!F=7IZ>0IM<V=I9"`B57-E($E-05`@9F]L9&5R
M('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(N.JZ:'2P^##U<*AXZKIXK_%X+3-
MP^RBS:?DS>'!OB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,S4*(RP@
M9G5Z>GD*;7-G:60@(E5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\B"FUS9W-T
M<B`BQ>G2I^*_Q>"TS</LMM&GHL+0(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$T,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("*JU^C-O-GI
MXZKI(@H*(SH@86-L+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)5
M<V5R(%PB)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE('-P96-I9FEE9"!R
M:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-PIM<V=I9"`B57-E<FYA;64B
M"FUS9W-T<B`BJM?HS;S9Z>.JZ2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S
M='(@(JK7Z,V\V>GCJNDB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B5FEE=R(*;7-G<W1R("+ARK2G("5S
M(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z.3(@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S
M(@IM<V=S='(@(N'*M*<@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE
M=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B
MRL/ITJ>BZ<VDQ]+!X[G+N>G2M>C2I^/+P>@B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!-97-S
M86=E<R(*;7-G<W1R("*BZ<VDQ]+!X\O!Z"(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED
M(")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C<R"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$X"B,L(&9U>GIY"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R("+@M\.T
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.C$V-0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*
M(RP@9G5Z>GD*;7-G:60@(E9I97<@871T86-H;65N="!I;B!A('-E<&%R871E
M('=I;F1O=R(*;7-G<W1R("+*P^G2IZ+IS:3'TL'CN<NYZ=*UZ-*GX\O!Z"(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!F=7IZ>0IM
M<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S
M='(@(LK#Z=*GHNG-I,?2P>.YR[GITK7HTJ?CR\'H(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R
M("(B"@HC.B!F;VQD97)S+G!H<#HS.#`@;6%I;&)O>"YP:'`Z-3,T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S(@IM
M<V=S='(@(N'*M*>BZ<VDQ]+!X[DB"@HC.B!T96UP;&%T97,O<')E9G,O:6YI
M=&EA;'!A9V5S96QE8W0N:6YC.C(S"FUS9VED(")6:65W(&]R(&UA:6QB;W@@
M=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CHB"FUS9W-T<B`BP=C!P<VGR\/7S;79
MZ>2[P\FSU<+LM]7HM>G-IZ'2P^/+Z>'*M*?+Q=&GJ-*AQ:>JU^C-X*+ITCHB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<P"B,L(&9U>GIY"FUS
M9VED(")6:65W('1A<VLB"FUS9W-T<B`BX<JTIR`E<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(E9I97<@=&AE
M($EM86=E<R(*;7-G<W1R("+ARK2GHNG-I,?2P>.Y(@H*(SH@<V5A<F-H+G!H
M<#HR-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I<G1U86P@1F]L
M9&5R(%PB)7-<(B!C<F5A=&5D('-U8V-E<V9U;&QY+B(*;7-G<W1R("+BO\7@
MM,W#["!<(B5S7"(@Y+3IMMFAQ;K@P]7"NL/IS<+AQ>G'(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E92YP:'`Z,3,X
M(&QI8B])34%0+U1R964N<&AP.C$U,0HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ
M-3,@;&EB+TE-05`O5')E92YP:'`Z,34W(&QI8B])34%0+U1R964N<&AP.C$U
M.`HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-CD@;&EB+TE-05`O5')E92YP:'`Z
M,SDS(&QI8B])34%0+U1R964N<&AP.C0S,PHC+"!F=7IZ>0IM<V=I9"`B5FER
M='5A;"!&;VQD97)S(@IM<V=S='(@(LK#Z=*GXK_%X+3-P^PB"@HC.B!S96%R
M8V@N<&AP.C(T-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L
M86)E;"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&;VQD97(N<&AP.C$W-2!L:6(O
M5D9O;&1E<BYP:'`Z,3@P"FUS9VED(")6:7)T=6%L($E.0D]8(@IM<V=S='(@
M(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q-@IM<V=I9"`B5FER='5A;"!)3D)/6"!&
M;VQD97(B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-#4R(&QI8B]61F]L
M9&5R+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0IM<V=I9"`B5FER='5A
M;"!4<F%S:"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,3,*(RP@9G5Z
M>GD*;7-G:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(L7ITJ?B
MO\7@M,W#[+;1IZ+"T"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M,3,S"FUS9VED(")6:7)T=6%L(&9O;&1E<B!L86)E;"(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W-`IM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R("*DT^"UU\VY(@H*(SH@;&]G:6XN<&AP.C$S.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(L+4N;35M>G-
MN</1NLK9Z"`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3D*;7-G
M:60@(B(*(E=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A
M9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN
M;F]C96YT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S(W"B,L(&9U>GIY"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S
M+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M
M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HBX,'7Z,VU
MZ<VGH=+#Q;JBZ<VDQ]+!(./+Z<+ITL*BZ<VDQ]+!N='IN>8@Y+O"T:?BO\7@
MM,W#[+;1IZ+"T"#AM[FATL.AT\NYM./+Z>"[Y[FBZ<VDQ]+!M]7HMMFAQ;HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS9VED(")7:&5N(&]P
M96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T
M;R!S=&%R="!O;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@
M=V4@<V%V92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN9R!M
M86EL(&]R(&5X<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L
M9"!W92!A<'!E;F0@=&\@(@HB=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I
M;"!A9&1R97-S97,@=VET:&]U="!<(D!<(BD_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B5VAI=&5L:7-T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<X"FUS9VED(")997,B"FUS9W-T
M<B`BXZKH(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO
M9VEN+G!H<#HU.`IM<V=I9"`B66]U(&%R92!A8F]U="!T;R!F971C:"!E;6%I
M;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N="AS*3HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3`*
M;7-G:60@(B(*(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE
M<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<B(*(BAS
M*2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C
M;VYF:7)M+FAT;6PZ.0IM<V=I9"`B66]U(&%R92!A='1E;7!T:6YG('1O(&1E
M;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O
M<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#(*;7-G:60@(EEO
M=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B
M66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R,`IM<V=I9"`B66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,S(W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$S-0IM<V=I9"`B66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M(%PB
M)7-<(BXB"FUS9W-T<B`BI-BSY+3IX,74H>.JZ2!<(B5S7"(@X,/5PKK#Z<W"
MX<7IQR(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@8V%N('5S92!T:&4@9F]L;&]W
M:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F
M;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE
M('-I9VYA='5R92XB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO=&]S7V%G<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T
M(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@
M>6]U('=E<F4@;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-CD*;7-G:60@(EEO=2!D;R!N
M;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F
M;VQD97(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O
M;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!H879E("5S(&YE=R!M97-S86=E
M<RXB"FUS9W-T<B`B("T@)&YM(*+IS:3'TL'CR\'H(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E
M(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(B`M("1N;2"BZ<VDQ]+!X\O!Z"(*
M"B,Z(&-O;7!O<V4N<&AP.C0Y-`IM<V=I9"`B66]U(&AA=F4@86QR96%D>2!S
M=6)M:71T960@=&AI<R!P86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYJ<SHQ,34*;7-G:60@(B(*(EEO=2!H879E
M(&%T(&QE87-T(&]N92!A='1A8VAM96YT('-E;&5C=&5D('1H870@>6]U(&1I
M9&XG="!U<&QO860@>65T+B!!<F4@(@HB>6]U('-U<F4@>6]U('=A;G0@=&\@
M<V5N9"!T:&ES(&UE<W-A9V4@=VET:&]U="!T:&5S92!A='1A8VAM96YT<S\B
M"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`W-`IM<V=I9"`B66]U(&AA
M=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B])35`N<&AP.C$P-SD*;7-G:60@(EEO=2!H879E(&YE=R!M
M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`B(@H*(SH@
M8V]M<&]S92YP:'`Z,34S"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!E;G1E
M<B!A="!L96%S="!O;F4@<F5C:7!I96YT+B(*;7-G<W1R("*UZ<VGH=/+N;3C
MR^G!U:K7Z,V\V>G#T;K-PNC2I[GIS<++N=;HIZK7Z,TB"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HS,#(*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R
M('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V
M:65W('1H:7,@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C(T.0IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE
M('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I
M97<@=&AI<R`B"B)M97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VIA=F%S8W)I<'0N:6YC.C8T('1E;7!L871E<R]M86EL8F]X+VIA
M=F%S8W)I<'0N:6YC.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM<V=S='(@(J38L[7IS:?@
MQ=?-H>#-H<71H<FS[+?5Z+7IS:>ATL.HT,6ZX,K5PJ'HS;DB"@HC.B!F971C
M:&UA:6QP<F5F<RYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S='(@(J38L[7I
MS:?@Q=?-H>#-H<71H<FS[+?5Z+7IS:>ATL.HT,6ZX,K5PJ'HS;DB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C@Q"B,L(&9U>GIY"FUS
M9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T
M<B`BI-BSM>G-I^#%U\VAX,VAQ=&AR;/LM]7HM>G-IZ'2PZC0Q;K@RM7"H>C-
MN2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8R('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(P.`HC.B!T96UP;&%T
M97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR-C,*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S<V%G92!F:7)S="XB
M"FUS9W-T<B`BM>G-IZ'3R[FTX\OIP=6JU^C-O-GIP]&ZS<+HTJ>YZ<W"R[G6
MZ*>JU^C-(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT
M+B(*;7-G<W1R("*UZ<VGH=/+N;3CR^G!U:K7Z,V\V>G#T;K-PNC2I[GIS<++
MN=;HIZK7Z,TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ
M<SHR.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A="!L96%S
M="!O;F4@9FEL92!T;R!A='1A8V@N(@IM<V=S='(@(K7IS:>AT\NYM./+Z<'5
MJM?HS;S9Z</1NLW"Z-*GN>G-PLNYUNBGJM?HS2(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@;F5E9"!T;R!H879E(%PB)7-<(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E
M;F%N8V4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP
M.C$S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E9&ER96-T
M960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T<B`BX+O%U>C"
MN>#*Z;FWTJ>BZ<VDQ]+!N=7I(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$T,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI
M<R!M97-S86=E(&]N("5S+B(*;7-G<W1R("+@N\75Z,*YX,KIN;?2IZ+IS:3'
MTL&YU>DB"@HC.B!L:6(O1F]L9&5R+G!H<#HU,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@7"(E<UPB+B!(97)E
M(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(J38L\+1I^3!Z.2T
MZ>##U<*AXZKI(%PB)7-<(B#@I,/7Z,VGNL/4H=+#P]+"I]*YQ^C2(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z-34Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W
M97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(N($AE<F4@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BI-BSPM&GY,'HY+3IX,74H>.J
MZ2!<(B5S7"(@X*3#U^C-I[K#U*'2P\/2PJ?2N<?HTB(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C
M97-S9G5L;'D@<W5B<V-R:6)E9"!T;R!<(B5S7"(B"FUS9W-T<B`BI-BSY+3I
MX,/5PJ'CJND@7"(E<UPB(.##U<*ZP^G-PN'%Z<<B"@HC.B!L:6(O1F]L9&5R
M+G!H<#HU-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S
M<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R("*DV+/D
MM.G@Q=2AXZKI(%PB)7-<(B#@P]7"NL/IS<+AQ>G'(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.CDX"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`BJM?HS>"UY\&BS:>DV+,B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-3`*;7-G:60@(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M4'5B;&EC($ME>2(*;7-G<W1R("*JU^C-X+7GP:+-IZ38LR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-C4*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4F5P
M;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`B
MM]7HS<+9Z""WU>BUU+2UZ,VAQ=&Z.B"BS:>DV+,Z(#QI/BBVZ=*UZ<VGH=+#
M*3PO:3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS9VED
M(")9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C
M="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S
M='(@(N#-H<71H<FS[*+-IZ38LSHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO
M<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E
M;3XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M.3(*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN
M92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D969A=6QT
M(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9
M;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S
M<V%G97,Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")9;W5R(&UE<W-A9V4@=V%S('-U8V-E
M<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(N*_Q>"TS</L(%PB)7-<(B#D
MM.FVV:'%NN##U<*ZP^G-PN'%Z<<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS9W-T<B`BQ=+"X*OG
MN:+-IZ38LSHB"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S92YP:'`Z,3(X
M-"!M86EL8F]X+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q.`IM<V=I9"`B
M6TYO(%-U8FIE8W1=(@IM<V=S='(@(EODP>C!U:K7Z,W@P]?HS:==(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,L(&9U>GIY"FUS
M9VED(")?0F-C(@IM<V=S='(@(LK3X+G2J^C-N;;6IR(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B7T)L86-K;&ES
M="(*;7-G<W1R("*ZT:VJU;33(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,34T"B,L(&9U>GIY"FUS9VED(")?0V,B"FUS9W-T<B`BRM/@
MN=*VUJ<B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")?
M1&5L971E(@IM<V=S='(@(L6Z(@H*(SH@;&EB+TE-4"YP:'`Z.3<Y"B,L(&9U
M>GIY"FUS9VED(")?1F]L9&5R<R(*;7-G<W1R("+BO\7@M,W#["(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C@Q"B,L(&9U>GIY"FUS9VED
M(")?261E;G1I='DB"FUS9W-T<B`BX,VAQ=&AR;/L(@H*(SH@;&EB+TE-4"YP
M:'`Z.38Q"FUS9VED(")?26YB;W@B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP
M:'`Z,3`R,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BQ:>Z
MT;FWUJ'-S:$B"@HC.B!M97-S86=E+G!H<#HS.#0*(RP@9G5Z>GD*;7-G:60@
M(E]-97-S86=E(%-O=7)C92(*;7-G<W1R("*UZ;FINM&ZHNG-I,?2P2(*"B,Z
M(&QI8B])35`N<&AP.CDW-@HC+"!F=7IZ>0IM<V=I9"`B7TYE=R!-97-S86=E
M(@IM<V=S='(@(J+IS:3'TL'CR\'H(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")?4')I;G0B
M"FUS9W-T<B`BOM3!ONPB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@Y"FUS
M9VED(")?4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-#$X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")?4F5F<F5S:"`E<R(*;7-G
M<W1R("+#U>"_PZHB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B7U)E<&QY(@IM<V=S='(@(K7-
MNJ'%T;HB"@HC.B!L:6(O24U0+G!H<#HY.#$*(RP@9G5Z>GD*;7-G:60@(E]3
M96%R8V@B"FUS9W-T<B`BI.FYR](B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M,S$*(RP@9G5Z>GD*;7-G:60@(E]396YD($UE<W-A9V4B"FUS9W-T<B`BHNG-
MI,?2P;7HS>2[(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHS,@HC+"!F=7IZ>0IM<V=I9"`B7U1H<F5A9"(*;7-G<W1R("+@
MM\.T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3$V"B,L
M(&9U>GIY"FUS9VED(")?5&\B"FUS9W-T<B`BMM:G(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E]5;F1E
M;&5T92(*;7-G<W1R("*AV>FDU[DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(E]6:65W(%1H
M<F5A9"(*;7-G<W1R("+@M\.T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$Y"FUS9VED(")?5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ-S8*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-#`*(RP@9G5Z>GD*;7-G:60@
M(F%T=&%C:&UE;G0B"FUS9W-T<B`BX,VARM+#X;FZ(@H*(SH@=FEE=RYP:'`Z
M.3D*(RP@9G5Z>GD*;7-G:60@(F%T=&%C:&UE;G1S+GII<"(*;7-G<W1R("+@
MS:'*TL/AN;HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,3,*;7-G:60@(F)Y=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,#`*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W,@IM<V=I9"`B8V%N;F]T(&]P
M96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V-`IM
M<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR,C`*;7-G:60@(F-O;F9I9W5R871I;VX@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y-@IM<V=I9"`B
M8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,38X"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(T"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS9W-T<B`BJ-*A(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C$X,`IM<V=I9"`B:&]S="!N86UE('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P-`IM<V=I9"`B
M:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ.#@*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8Y"FUS9VED(")K97DB
M"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,38Q"B,L(&9U>GIY"FUS9VED
M(")M86EL8F]X(&9I;&4B"FUS9W-T<B`BM=GIY+O#R;/5PNPB"@HC.B!C;VUP
M;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*(RP@9G5Z>GD*;7-G
M:60@(FYA;64B"FUS9W-T<B`BJM?HS2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*;7-G<W1R("+DP>C!U2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@
M(F]R(@IM<V=S='(@(LO#U\TB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$V"FUS
M9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,C$R"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-`IM<V=I9"`B<V5R
M=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R(@IM
M<V=S='(@(LK0H;2DT[S4M"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@(LK0
MH;2DT[S4M"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3(*(RP@9G5Z>GD*;7-G
M:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("+*T*&TI-.\U+0B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,C`X"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G
M<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B
M>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`BNM&MJM6TTR(*"B,Z(&QI8B]&:6QT
M97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R("(B"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R]A<E]/32YP;P``````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S-30P,3,`
M,3`T,3<S-C(W-C0`,#$W,3<Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@24U0(#,N,BXQ($%R86)I8R!T<F%N<VQA=&EO
M;@HC($-O<'ER:6=H="`H0RD@,C`P,R!W86)H;W-T:6YG+F-O;2`\861M:6Y`
M=V%B:&]S=&EN9RYC;VT^"B,@5V5B($%D=F%N8V5D($)U<VEN97-S($AO<W1I
M;F<@/&%D;6EN0'=A8FAO<W1I;F<N8V]M/BP@,C`P,0HC(%-A965D(#QA9&UI
M;D!W86)H;W-T:6YG+F-O;3XL(#(P,#(L(#(P,#,*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U0('8S+C(N,5QN(@HB4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#,M,#0M,C$@,C,Z,C4K,#$P,%QN(@HB3&%S
M="U4<F%N<VQA=&]R.B!!3"!(;W-N:2`\861M:6Y`=V%B:&]S=&EN9RYC;VT^
M7&XB"B),86YG=6%G92U496%M.B!!<F%B:6,@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]H=&UL.R!C:&%R<V5T/4-0,3(U-EQN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q.`HC
M+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z("(*;7-G<W1R("(@("`@("#'X>R@
M.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$U"FUS9VED("(@("`@("!4;SH@
M(@IM<V=S='(@(B`@("`@(,?A[*`Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT
M,#,*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@Q^'*Q]'MSJ`Z("(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#8*;7-G:60@(B`@("!&<F]M.B`B"FUS
M9W-T<B`B("`@("#CY*`Z("(*"B,Z(&UA:6QB;W@N<&AP.C0R,B!T96UP;&%T
M97,O9F]L9&5R<R]H96%D+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M-#$R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(B`@Q^'CYM;FVJ`Z("(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I9"`B
M(&EN("(*;7-G<W1R("(@W>T@(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S
M<V%G95]H96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*;7-G<W1R("+1WN,B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T
M:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M365S<V%G97,B"FUS9W-T<B`B)60@X^0@)60@T=/'X<DB"@HC.B!M86EL8F]X
M+G!H<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A
M9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+*XR#'X=O'P2#'X>7F
M[<D@7"(E<UPB(,CDS,?-+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E
M;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("+*XR#*WL_MXR#*WM'MT2#(Y=#E(,?AT=/'X<D@
MW]'3Q^')(-OMT2#CT=OFR"#(Y<<@Q^'L(.//[=$@Q^'DV<?C+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D
M(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS
M9W-T<B`BRN,@RM[/[>,@RM[1[=$@R.70Y2#'X='3Q^')(-_1T\?AR2#;[=$@
MX]';YL@@R.7'(,?A["#CS^W1(,?AY-G'XRXB"@HC.B!L:6(O4W!A;2YP:'`Z
M,3<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H
M879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("+*XR#*WL_MXR#*WM'MT2#(Y=#E(,?AT=/'
MX<D@W]'3Q^')(-OMT2#CT=OFR"#(Y<<@Q^'L(.//[=$@Q^'DV<?C+B(*"B,Z
M(&QI8B]3<&%M+G!H<#HQ-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G
M<W1R("+*XR#*WL_MXR#*WM'MT2#(Y=#E(,?AT=/'X<D@W]'3Q^')(-OMT2#C
MT=OFR"#(Y<<@Q^'L(.//[=$@Q^'DV<?C+B(*"B,Z(&UA:6QB;W@N<&AP.C,W
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!T;R`E9"!O9B`E9"!-97-S86=E
M<R(*;7-G<W1R("(E9"#'X>P@)60@X^0@)60@T=/'X<DB"@HC.B!M86EL8F]X
M+G!H<#HV-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO
M;G1H;'DN<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@
M97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N(@IM<V=S
M='(@(B5S(./FS.;/R2#CT\C>QRX@X\SASR`E<R#AXR#MRN,@RMOM[='E+B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS
M9W-T<B`B)7,@X<<@[=GET2#'Y.4@VN3FQ^0@R-'MS^T@U<?AS2XB"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP
M:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E:6YG(')E
M;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"XB"FUS9W-T<B`BRN,@
MRMOM[=$@Q]/CQ\$@("5S(./,X<\@VN3/(,C/Q^W)(,?AU.71+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C(U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!C86YC96QL960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&1E
M8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O
M(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@=&5N=&%T:79E;'D@
M86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U
M<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N(@IM
M<V=S='(@(LKC(,?:Q\_)(,K3X^W)(,?AX\SASR!<(B5S7"(@Q^'L(%PB)7-<
M(BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DW"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!A;6UE;F0@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`R
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H
M92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B(*"B,Z
M(&UE<W-A9V4N<&AP.C(X-2!M97-S86=E+G!H<#HR.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]T;W`N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*2(*;7-G<W1R("(E<SH@)7,@*"5D
M)FYB<W`[9&4F;F)S<#LE9"DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3,S"FUS9VED("(H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@
M;6]V92!T;R!N97AT('-C<F5E;BXI(@IM<V=S='(@(BC8R-X@Y=#E(,?ARMOM
M[=''RB#FQ^3*WN$@Q^'L(,?AU,?4R2#'X<K'X>W)+BDB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED("(H1&ES8V%R9"!A
M;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI
M(@IM<V=S='(@(BC>XR#(Q^';Q\$@S./MVB#'X<K;[>W1Q\H@YMK/(,?A["#4
MQ]3)(,?AQ]'3Q^$I(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C$V"FUS9VED("(H2%1-3"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB
M"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E
M='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL
M(&-H86YG97,@;6%D92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U
M<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B
M"B(HVL\@Q^'L(-3'U,D@Q^''T=/'X2#(VL\@RMC([=X@S./MVB#'X<K;[>W1
MQ\H@Q^'CS]',R2#-RNP@Q^'"Y"X@X>0@[<KC(,K8R.W>("(*(L?ARMOM[=''
MRB#:X>P@Q^'4Q]3)(,?AS<?A[<DN*2(*"B,Z('-P96QL:6YG+G!H<#HR-S<*
M(RP@9G5Z>GD*;7-G:60@(B(*(BA396YD(&UE<W-A9V4@869T97(@87!P;'EI
M;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE
M("(*(F-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G
M<W1R("(B"B(HVL\@Q^'L(-3'U,D@Q^''T=/'X2#(VL\@RMC([=X@S./MVB#'
MX<K;[>W1Q\H@Q^'CS]',R2#-RNP@Q^'"Y"X@X>0@[<KC(,K8R.W>("(*(L?A
MRMOM[=''RB#:X>P@Q^'4Q]3)(,?AS<?A[<DN*2(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D9"!T:&5S92!B
M>2!C;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@Q];=(.70Y2#(Q^'6V]@@VN'L
M(-+1(.3:XR`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM
M<V=S='(@(BH@[=',["#'SLKMQ]$@Q^':Y.;'Y"`H(,?AVN3'YNWD("D@+B`J
M(@H*(SH@;6%I;&)O>"YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A
M9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BRN,@Q^';Q\$@Q^'EYNW)
M(%PB)7-<(B#(Y,S'S2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3@P"B,L(&9U>GIY
M"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P
M86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`BRN,@
MRM[/[>,@RM[1[=$@R.70Y2#'X='3Q^')(-_1T\?AR2#;[=$@X]';YL@@R.7'
M(,?A["#CS^W1(,?AY-G'XRXB"@HC.B!L:6(O4W!A;2YP:'`Z,38P"B,L(&9U
M>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T
M('-P86TN(@IM<V=S='(@(LKC(,K>S^WC(,K>T>W1(,CET.4@Q^'1T\?AR2#?
MT=/'X<D@V^W1(./1V^;((,CEQR#'X>P@X\_MT2#'X>39Q^,N(@H*(SH@;&EB
M+U-P86TN<&AP.C$W,@HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B
M965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`BRN,@RM[/[>,@RM[1[=$@R.70Y2#'X='3Q^')(-_1
MT\?AR2#;[=$@X]';YL@@R.7'(,?A["#CS^W1(,?AY-G'XRXB"@HC.B!L:6(O
M4W!A;2YP:'`Z,34R"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E
M96X@<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`BRN,@RM[/[>,@RM[1[=$@
MR.70Y2#'X='3Q^')(-_1T\?AR2#;[=$@X]';YL@@R.7'(,?A["#CS^W1(,?A
MY-G'XRXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Y"B,L(&9U>GIY
M"FUS9VED("(Q,#`@8VAA<F%C=&5R<R(*;7-G<W1R("+1X^;2(,['U<DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(R"B,L(&9U>GIY"FUS9VED("(Q
M,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`BT>/FTB#.Q]7)(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@R,`HC+"!F=7IZ>0IM<V=I9"`B,C4P(&-H87)A
M8W1E<G,B"FUS9W-T<B`BT>/FTB#.Q]7)(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@R,0HC+"!F=7IZ>0IM<V=I9"`B-3`P(&-H87)A8W1E<G,B"FUS
M9W-T<B`BT>/FTB#.Q]7)(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,38R"B,L('!H<"UF;W)M870*;7-G:60@(D$@;&%R9V4@:6UA9V4@;F%M
M960@)7,@:7,@871T86-H960@=&\@=&AI<R!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,`IM<V=I
M9"`B(@HB02!M97-S86=E('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D(&EN
M(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H92`B"B)R96-I<&EE;G0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU
M"FUS9VED(")!3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Y,`IM<V=I9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-PIM<V=I9"`B06-C97!T
M(')E<75E<W0@86YD(&%D9"!I="!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4S"FUS9VED(")!8V-E
M<'1E9"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,C4W"FUS9VED(")!8V-E<'1E9#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"B,L(&9U>GIY"FUS9VED(")!8V-O
M=6YT)W,@;F%M93HB"FUS9W-T<B`BP]/CQ\$@Q^'EYNW'RB`Z(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,"!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S,P"B,L(&9U>GIY"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(L7,
MT<?!(@H*(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C`P(&QI8B]-24U%+TAE
M861E<G,N<&AP.C(P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M("5S('1O(&UY($%D9')E<W,@0F]O:R(*;7-G<W1R("+'UMT@Q^'L(-/,X2#'
MX=KDQ^;MY"`H)7,I(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C
M="YI;F,Z,S`S"B,L(&9U>GIY"FUS9VED(")!9&0@<V]U<F-E(@IM<V=S='(@
M(L?6W2#'X>/5S]$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<W
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D9"!T:&ES
M('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!A
M<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("+'UMT@X]'=WL?*+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3@*;7-G:60@(B(*(D%D9&ET:6]N86P@
M:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA
M;"P@96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@;&EN92D\+V5M/B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H
M<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T
M:6]N(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L(&9U>GIY"FUS9VED(")!
M9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS9W-T<B`BX]KAYN/'
MRB#4SM7MR2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDS"FUS
M9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HW.`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I
M;',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R
M<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M8V]N=&%C=',N<&AP.C@U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,S.2!T
M96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E
M<W,@0F]O:R(*;7-G<W1R("+3S.$@Q^':Y,?F[>0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VMS
M(@IM<V=S='(@(M/,X2#'X=KDQ^;MY"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.#D*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A
M9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N
M97<@(@HB;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L
M>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@
M96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")!;&PB"FUS9W-T<B`BQ^',X^W:
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,PIM<V=I
M9"`B(@HB06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I
M('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8("(*(F9I;&4Z(@IM
M<V=S='(@(B(*(LSC[=H@Q^'1T\?&X2#'X>/FS.;/R2#=[2#'X>/,X<\@*,?A
MX\SAS\?**2#'X<K'X>W)(-/FW2#MRN,@RLWC[>'EQR#=[2#5Y,_FWB`B"B+F
MQ\W/(,?AU>3/YMZ@.B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E
M7W1R87-H+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S
M<V%G97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y
M<R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N(@IM<V=S='(@(M_A
M(,?AT=/'QN$@W>T@X\SASR!<(B5S7"(@Q^''WL_C(./D("5S(.WFXR#3YMT@
M[<KC(,C4W^$@S\?&X\?AV\?$Y<<N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP.C4Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM
M<V=S='(@(M_A(./,X<_'RB#'X='3Q\;A(,?AX]'3X<D@Q^''WL_C(./D("`E
M<R#4Y=''(-/FW2#*X=OL("(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E
M;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M
M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`BW^$@X\SAS\?*
M(,?AT=/'QN$@Q^'CT=/AR2#'X<?>S^,@X^0@("5S(-3ET<<@T^;=(,KAV^P@
M(@H*(SH@86-L+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M06QL(')I9VAT<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO
M=F5D(&9O<B!U<V5R(%PB)7-<(BXB"FUS9W-T<B`BRN,@Q]K'S\D@RM/C[<D@
MQ^'CS.'/(%PB)7-<(B#'X>P@7"(E<UPB+B(*"B,Z(&QI8B]A<&DN<&AP.C<V
M"FUS9VED(")!;&QO=R!&;VQD97(@0W)E871I;VX_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@
M9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z
M,3$P"FUS9VED(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<R(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#0*;7-G:60@(D%L=V%Y<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34W"B,L(&9U>GIY"FUS
M9VED(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R("+'UMT@X]'=
MWL?*+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HU,#4*;7-G:60@(B(*(D%N(&5R
M<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T
M86-H;65N="X@5&AE($E-05`@<V5R=F5R("(*(G-A:60Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")!;B!U
M;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!N
M;W1E+B(*;7-G<W1R("+.V,,@V^W1(./:T>;=(,?+Y,?!(,?6Q]W)(,?AX\_.
MX<?*(,?AS,_MS\DN(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X-PHC+"!F=7IZ
M>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T
M:6YG('1H92!N97<@=&%S:RXB"FUS9W-T<B`BSMC#(-OMT2#CVM'FW2#'R^3'
MP2#'UL?=R2#'X>//SN''RB#'X<S/[<_)+B(*"B,Z(&UE<W-A9V4N<&AP.C4P
M,"!M86EL8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHY"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D(@IM<V=S
M='(@(LKC(,?AT<\@VN'MY<<B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C,Q"FUS9VED(")!;G-W97)E9"!M97-S86=E<R(*;7-G<W1R("+'X='3
MQ\;A(,?ARNT@RN,@Q^'1SR#:X>WEQR(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VAE861E<BYI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B07!P;'D@1FEL=&5R<R(*
M;7-G<W1R("+>XR#(RMC([=X@Q^'CT=3-Q\H@VN'L(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!<'!L>2!&:6QT97)S('1O("5S(@IM<V=S='(@(M[C(,C*V,CMWB#'
MX>/1U,W'RB#:X>PB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,S8*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_
M(@IM<V=S='(@(B#>XR#(RMC([=X@Q^'CT=3-Q\H@Q\ODQ\$@Q^'/SN;A(+\B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#(*(RP@9G5Z>GD*
M;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D
M:7-P;&%Y960_(@IM<V=S='(@(M[C(,C*V,CMWB#'X>/1U,W'RB#'R^3'P2#'
MY-K'U"#'X=7DS^;>(,?AR-'MS^TB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!F=7IZ>0IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES('!U
M8FQI8R!K97D_(@IM<V=S='(@(N7A(,?DRB#FQ\O>(./D(,?DWR#*T>W/(-W:
MX2#0X=\@OR(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4
M(')E8V]M;65N9&5D(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ
M<SHV"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\B
M"FUS9W-T<B`BY>$@Q^3*(.;'R]X@X^0@Q^3?(,K1[<\@W=KA(-#AWR"_(@H*
M(SH@;65S<V%G92YP:'`Z-#`W('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I
M<'0N:6YC.C8X"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$52
M34%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("+EX2#'
MY,H@YL?+WB#CY"#1V\C*WR#=[2#'X=O'P2#ET.4@Q^'1T\?&X2#(U-_A(.3E
MQ\;M(+\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U>GIY
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@
M9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`BY>$@Q^3*(.;'R]X@
MX^0@T=O(RM\@W>T@Q^';Q\$@Y=#E(,?AT=/'QN$@R-3?X2#DY<?&[2"_(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS
M9W-T<B`BY>$@Q^3*(.;'R]X@X^0@T=O(RM\@W>T@Q]W1Q]L@Y=#'(,?AX\SA
MSR"_(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B
M"FUS9W-T<B`BY>$@Q^3*(.;'R]X@X^0@T=O(RM\@W>T@Q]W1Q]L@X\SASR#3
MX<D@Q^'CY>/AQ\H@OR(*"B,Z(&QI8B])35`N<&AP.CDV-@IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R
M/R(*;7-G<W1R("+EX2#'Y,H@YL?+WB#CY"#1V\C*WR#=[2#'W=''VR#CS.'/
M(-/AR2#'X>/EX^''RB"_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T
M<B`BY>$@Q^3*(.;'R]X@X^0@T=O(RM\@W>T@Q^';Q\$@Y=#E(,?AT=/'QN$@
MR-3?X2#DY<?&[2"_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP
M="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*
M(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O
M<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R("+EX2#'Y,H@
MYL?+WB#CY"#1V\C*WR#=[2#'W=''VR#ET,<@Q^'CS.'/(+\B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHW-2!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHW-`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A
M;3\B"FUS9W-T<B`BY>$@Q^3*(.;'R]X@X^0@T=O(RM\@W>T@Q]W1Q]L@Y=#'
M(,?AX\SASR"_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I
M9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(N;>RB#'X>;5YN$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T
M<B`BRM7'VL_M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$Y"FUS9VED(")!
M='1A8V@B"FUS9W-T<B`BQ]'=Q]XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT-S4*(RP@9G5Z>GD*;7-G:60@(D%T=&%C:"!&:6QE<R(*
M;7-G<W1R("+CT=W>Q\HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT-38*;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B
M;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]T;F5F+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(D%T=&%C
M:&5D($9I;&4Z(@IM<V=S='(@(L?1W<?>(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0U,2!L:6(O0V]M<&]S92YP:'`Z-3,V"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE
M;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S<V"FUS9VED(")!='1A
M8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHQ-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,30*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`V('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDW"FUS9VED(")!='1A8VAM96YT(@IM
M<V=S='(@(N/1W=XB"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E
M+G!H<#HT-C8*;7-G:60@(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L
M(&%T=&%C:&UE;G0@='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#<S"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#<S"FUS9VED(")!='1A
M8VAM96YT<R(*;7-G<W1R("+CT=W>Q\HB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C@R"B,L(&9U>GIY"FUS9VED(")!='1E;F1E97,B"FUS9W-T
M<B`BX]'=WL?*(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D%T=&5N=&EO;B(*;7-G<W1R("+%S-''
MP2(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!2
M97%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-#`*;7-G:60@(B(*(D%U=&]M
M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H
M92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y.`HC+"!F
M=7IZ>0IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@
M(M/,X<?*(,?ATN;'T2#'X>/*YMW1R2`Z(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<Q.0IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHR-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B
M"FUS9W-T<B`BQ^':YL_)(,?A["`E<R(*"B,Z('1H<F5A9"YP:'`Z,3,W('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R("+'X=KFS\D@Q^'L
M("5S(@H*(SH@=&AR96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L=&EP
M;&4@365S<V%G92!6:65W($EN9&5X(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP
M:'`Z,3,R"FUS9VED(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF;W)M870*
M;7-G:60@(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O
M;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8V('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z,S0*;7-G
M:60@(D)C8R(*;7-G<W1R("+CT=W>(./.W>TB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X
M="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR
M,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B0FQA
M8VML:7-T(@IM<V=S='(@(L?AWL?&X\D@Q^'3YL_'P2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,CD*;7-G:60@(D)L;V-K(&EM86=E<R!I;B!(5$U,
M(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@<F5Q=65S
M=&5D/R(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HT,@IM<V=I9"`B
M0F]D>2(*;7-G<W1R("+'X>35(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R("+'X<?+Y,?D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8X-PIM<V=I9"`B0F]T:"!(96%D97(@3&ES
M=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,@HC+"!F=7IZ>0IM<V=I9"`B
M0U]H87)S970B"FUS9W-T<B`BRM'C[=(@34%#(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]F:65L9',N:6YC.C,V"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("(B
M"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(P,0IM<V=I9"`B0V%N(&YO
M="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@
M;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P87)T:6%L+G!H<#HU,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O
M;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S<V%G92!I;B!T:&4@8W5R
M<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR
M.#0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V96EM
M86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P
M:')A<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX
M-@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L
M871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(L?AV\?!
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,U"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHQ,3$*;7-G:60@(D-A;F-E;"!-97-S86=E(@IM
M<V=S='(@(L?AV\?!(,?AT=/'X<DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R
M961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*
M;7-G:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT
M;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(L?AV\?!(.70Y2#'
MX='3Q^')(-/FW2#MQ,_M(,KAWL?&[<<@Q^'L(,K/X^W1(./-RN;MQ\KEQRXB
M"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN
M8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM<V=I9"`B0V,B"FUS9W-T<B`BY-/.
MR2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G:60@(B(*
M(D-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P
M;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P,0HC+"!F=7IZ
M>0IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(M3.U>TB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*
M;7-G<W1R("+*V^WMT2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R("+*V^WMT2#'X<SC
M[=HB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.3(*(RP@9G5Z>GD*;7-G
M:60@(D-H86YG92!&;VQD97(B"FUS9W-T<B`BQ>34Q\$@X\SASR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3(*;7-G:60@(B(*(D-H86YG92!D:7-P
M;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E
M(&]N(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S(&%R92!S;W)T960N
M(@IM<V=S='(@(B(*(LK;[>W1(,[MQ]''RB#'X=K1UB#CR^$@VL_/(,?AT=/'
MQN$@Q^'CVM'FULD@W>T@W^$@U=W-R2#F("#?[=WMR2#=Y='3R2`B"B+'X='3
MQ\;A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`HC+"!F=7IZ>0IM
M<V=I9"`B0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N
M(@IM<V=S='(@(LK;[>W1(-;FQ\C8(./2YL\@Q^'(T>W/(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$U"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64L
M(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"`B"B)R97!L>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R
M("(B"B+*V^WMT2#'X<?3XZ$@Q^':Y.;'Y""A(.8@Q^'*YM[MVB#'X=#M(.W1
MQ^4@Q^''U,['U2#:Y,_CQR#MWM''YN0@YB`@[='/YN0@VN'L("(*(M'3Q\;A
MWRXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(T"FUS9VED(")#:&%R
M86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#:&5C:R!&;VQD97(H<RD@
M9F]R($YE=R!-86EL(@IM<V=S='(@(L?AR,W+(-WM(,?AX\SASR`HQ^'CS.'/
MQ\HI(-KD(-'3Q\;A(,S/[<_)+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP;&%T
M97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K(&%L
M;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8S"B,L(&9U
M>GIY"FUS9VED(")#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE
M<W-A9V4_(@IM<V=S='(@(N7DQ^'?(,[8PR#=[2#'T=/'X2#1T\?ARM^@.B`E
M<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G:60@
M(D-H;V]S92!!8W1I;VXZ(@IM<V=S='(@(L?.RM$@Q<S1Q\$@.B(*"B,Z(&-O
M;F9I9R]S97)V97)S+G!H<"YD:7-T.C$X,@IM<V=I9"`B0VAO;W-E(&$@;6%I
M;"!S97)V97(Z(@IM<V=S='(@(L?.RM$@X]+FSR#'X<C1[<\@.B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,C$W"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E9&ET('1H
M92!A9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4R,2!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S,Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@86-T:6]N.B(*;7-G
M<W1R("+'SLK1(,7,T<?!(#HB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS-#D*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@861D
M<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S
M='(@(L?.RM$@T\SA(,?AVN3'YNWD("XB"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHR.3,*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T
M:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A
M;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("+'SLK1(,?ARM'*[<@@Q^'0[2#*
MT>W/(,?D(.W*XR#'X<C-RR#(Y2#:Y,\@W<K-(-/,X<?*(,?AVN3'YNWD+B`B
M"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL
M92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9&]W;FQO860@=&AE(&EM86=E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P
M86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M,3$V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@2%1-
M3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES
M(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@
M=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=RXB
M"FUS9W-T<B`BQ]'3X2#1T\?AR2#=[2#DQ]W0R2#,S^W/R2"_(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P
M87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@=&\@
M4TA/5R!T:&4@26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,R,0HC+"!F=7IZ>0IM<V=I9"`B(@HB0VQI
M8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@
M=&AE;B!S96QE8W0@86QL(&9I96QD<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@
M(L?DWM$@VN'L(.;'S<_'(./D(-/,X<?*(-+FQ]'?(,?AX\[*Q]')(,OC(,?.
MRM$@S./MVB#'X<W>YN$@(.'AR,W++B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C$W,0IM<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME
M>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R
M($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.34P"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL
M(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3$*;7-G:60@(D-L:6-K
M:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B
M92!R96%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T
M8VAM86EL+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B
MQ='3Q^$B"@HC.B!C;VUP;W-E+G!H<#HX,C@@8V]M<&]S92YP:'`Z,3$T.`IM
M<V=I9"`B0VQO<V4@=&AI<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9F]L9&5R
M<RYP:'`Z-#(Y"FUS9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(N/,X<\@
MX]OAWB(*"B,Z(&9O;&1E<G,N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B0V]L
M;&%P<V4B"FUS9W-T<B`BV.T@Q^',X^W:(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R
M("+8[2#'X<SC[=HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T<B`BV.T@
MS./MVB#'X>/,X<_'RB(*"B,Z(&9O;&1E<G,N<&AP.C0T.0IM<V=I9"`B0V]L
M;&%P<V4@1F]L9&5R(@IM<V=S='(@(MCM(./,X<\B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC871O
M<CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<V.0HC+"!F=7IZ>0IM<V=I9"`B0V]M<&QE=&5D(@IM<V=S
M='(@(L71T\?A(@H*(SH@8V]M<&]S92YP:'`Z.#(W(&-O;7!O<V4N<&AP.C$Q
M-#<*(RP@9G5Z>GD*;7-G:60@(D-O;7!O<V4@86YO=&AE<B!M97-S86=E(@IM
M<V=S='(@(L?1T\?A(-'3Q^')(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0S-`IM<V=I9"`B0V]M<&]S92!M97-S86=E<R!I;B!A('-E<&%R871E('=I
M;F1O=S\B"FUS9W-T<B`BQ]'3X2#1T\?AR2#=[2#DQ]W0R2#,S^W/R2"_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,PIM<V=I9"`B(@HB0V]M<&]S
M92!M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R
M;W=S97(@<W5P<&]R=',@=&AE("(*(F9E871U<F4I/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<*;7-G:60@(D-O;F9I9W5R92!H
M;W<@;65S<V%G97,@87)E(&1I<W!L87EE9"XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDW"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U
M<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N(@IM<V=S='(@(LK;[>W1(-;FQ\C8
M(./2YL\@Q^'(T>W/(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G
M:60@(D-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@(D-O
M;FYE8W1I;VX@=&\@<V5R=F5R(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P=&EO
M;G,@<F5L871I;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O;G1R
M;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE
M=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV97,N
M(@IM<V=S='(@(B(*(L?ARLW?XR#=[2#FWLH@Q^'(S<L@VN0@T=/'QN$@S,_M
MS\D@H2#FY>$@[<KC(,KDR.WEWR#'XR#AQR`@VN3/(.;5X2#1T\?&X2`B"B+,
MS^W/R2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CDV"FUS9VED(")#
M;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN=&\@9W)A<&AI8V%L(&]N97,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM
M<V=I9"`B0V]P>2(*;7-G<W1R("+DT\XB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM
M<V=S='(@(N/,X<\@T^')(./EX^''RB#=Q]';R2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G<W1R
M("+5S>W-(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T
M,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`BQ^'DU2#'X>/5S<TB
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,X,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E87-O
M;B!':79E;CH@)7,B"FUS9W-T<B`BRMK0T2#'X=O'P2#'X='3Q\;A(./D("5S
MH#H@)7,B"@HC.B!A='1A8VAM96YT+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E('1H92!61E,@8F%C:V5N9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S86=E<R!F<F]M
M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(LK:T-$@Q^';Q\$@
MQ^'1T\?&X2#CY"`E<Z`Z("5S(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C,Q.`HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<RXB"FUS9W-T<B`BVN/A[<?*(,?AU>W'Y,DB"@HC.B!L:6(O
M34E-12]6:65W97(O=&YE9BYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!E>'1R
M86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C
M:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP
M.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M97-S:6]N+G!H<#HR-S,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!N86UE
M<W!A8V4@:6YF;W)M871I;VX@9G)O;2!)34%0('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@<V5A<F-H+G!H<#HS,30@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L+FEN8SHS.0HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,38P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BQ>34
MQ\$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHV"FUS9VED
M(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@(L7DU,?!(./,X<\B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3,W"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@
M2V5Y<R(*;7-G<W1R("+%Y-3'P2(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A
M9&5R+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(%9I<G1U86P@1F]L
M9&5R(@IM<V=S='(@(L7DU,?!(./,X<\B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W
M($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(@IM
M<V=S='(@(L?DU,?!(./,X<\@X^7CX<?*(,S/[<\B"@HC.B!T96UP;&%T97,O
M<')E9G,O9F]L9&5R<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O9F]L
M9&5R<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W(&1R869T<R!F
M;VQD97(B"FUS9W-T<B`BQ^34Q\$@X\SASR#CT^;/Q\H@S,_MSR(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@
M;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`BQ>34Q\$@X\SASR#1T\?&
MX2#CT=/AR2#,S^W/(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T
M+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS
M9VED(")#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(L?DU,?!
M(./,X<\@X^7CX<?*(,S/[<\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(X"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N
M:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L
M("(*(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`B(@HBQ>34Q\$@WN;'VL\@
MW>'*T<D@X<K1RNW((,?AR-'MSR#'X>;'T<\@H2#*U>3MW>7'(-WM(,?AX\SA
MS\?*("#FQ^';Q\$@Q^'(T>W/("(*(L?AV^W1(./1V^;(+B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B
M0W)E871E(&YE=R!S=&%T:6]N97)Y(@IM<V=S='(@(L7DU,?!(./,X<\@T=/'
MQN$@X]'3X<D@S,_MSR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*
M;7-G:60@(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4*;7-G:60@(D-U<W1O
M;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C
M8V]U;G1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$*(RP@9G5Z>GD*;7-G:60@(D-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I
M;"XB"FUS9W-T<B`BULC8(-_MW>W)(,?1T\?AWR#'X='3Q\;A(.;'[>0@[<KC
M(,W=V2#'X>/3YL_'RB`N("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(M;(V"#CY<?C(.'?[2#*VN/A
M(-KDSR#'X<_.YN$@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B1&%T7V4B"FUS9W-T
M<B`BQ^'*Q]'MSB(*"B,Z(&UE<W-A9V4N<&AP.C(V,B!T:')E860N<&AP.C$T
M.`IM<V=I9"`B1&%T92(*;7-G<W1R("+'X<K'T>W.(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<U-PHC+"!F=7IZ>0IM<V=I9"`B1&5C;&EN960B
M"FUS9W-T<B`BX^';[2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G
M<W1R("+'X=O'P2(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H
M<V5L96-T+FEN8SHQ.`IM<V=I9"`B1&5F875L="!396%R8V@@1FEE;&0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,PIM<V=I9"`B
M1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R("+5[=O)(,?AW>71
MT\D@Q^''W<K1Q];MR:`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS
M,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B
MQ\K,Q^4@Q^'=Y='3R2#'X<?=RM''UNV@.B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW-C4*(RP@9G5Z>GD*;7-G:60@(D1E;&5G871E9"(*;7-G
M<W1R("+CX=OM(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(T-"!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:6YC.C(X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PIM<V=I9"`B
M1&5L971E(@IM<V=S='(@(L?AV\?!(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME>7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.0IM<V=I
M9"`B1&5L971E($9O;&1E<BAS*2(*;7-G<W1R("+'X=O'P2#CS.'/("@@X\SA
MS\?*("DB"@HC.B!F;VQD97)S+G!H<#HR.#4*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(L?AV\?!(./,X<\@*"#C
MS.'/Q\H@*2(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT
M,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%-T871I;VYE<GDB"FUS9W-T<B`B
MQ^';Q\$@X\SASR`H(./,X<_'RB`I(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B
MQ^';Q\$@X\SASR`H(./,X<_'RB`I(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE9"!M97-S86=E
M<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A
M;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-C@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE
M;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BS=#=(./,X<\@
MQ^'1T\?&X2#'X>/1T^')(,?AWL_MXR#=[2#(S\?MR2#'X=3ET2"_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B1&5L971E(&]L9"!S
M96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S
M='(@(LW0W2#CS.'/(,?AT=/'QN$@Q^'CT=/AR2#'X=[/[>,@W>T@R,_'[<D@
MQ^'4Y=$@OR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3<*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM<V=S='(@(L?AV\?!
M(-'3Q\;A(@H*(SH@;65S<V%G92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<T,"!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(P"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHX"FUS9VED(")$96QE=&5D(@IM<V=S='(@(N/AV^TB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A
M9V5S(@IM<V=S='(@(M'3Q\;A(./-T.;=R2(*"B,Z(&-O;7!O<V4N<&AP.C,P
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@871T
M86-H;65N="!<(B5S7"(N(@IM<V=S='(@(N/1W=['RB#CS=#FW<DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG(&%N9"!-
M;W9I;F<@365S<V%G97,B"FUS9W-T<B`BQ^';Q\$@YLK;[>W1(./FWMH@T=/'
MQN$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DR"FUS9VED(")$
M96YY(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4T,`IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@
M:6YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDS,@IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("+*Y,?2X>TB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8V.0HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I
M<'1I;VXB"FUS9W-T<B`BSNW'T<?*(,?AX]/*SL_C(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")$
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-S<*;7-G:60@(D1I;2!S:6=N871U<F5S/R(*;7-G<W1R("+*VLKMXR#'X<KF
MQ][MVB"_(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M,S8*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`BVMS1UB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-SD*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@8V]N
M9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("(B
M"B+:T=8@T=/'X<D@RL??[<\@R-K/(,?1T\?A(-'3Q^')(+\@*"#=WM@@VN3/
M(-K/XR#'T\K.S\?C(.3'W=#)(./DR,O>R2#AQ]'3Q^$@(@HBQ^'1T\?AR2`I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-@IM<V=I9"`B1&ES<&QA
M>2!I;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Y,@IM<V=I9"`B1&ES<&QA>2!P;W`M=7`@;F]T:69I
M8V%T:6]N(&]F(&YE=R!M86EL/R(*;7-G<W1R("+:T=8@T=/'X<D@X^3(R][)
M(.'AQ]KAQ^,@VN0@YM7FX2#1T\?AR2#,S^W/R2"_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3
M<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%
M;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS9W-T<B`BVM'6(,?ASNW'T<?*
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C(V"FUS9VED(")$
M;R!.3U0@;6%T8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#:&5C:R!&;VQD97(H<RD@
M9F]R($YE=R!-86EL(@IM<V=S='(@(N''(,K>XR#(Q^'(S<L@W>T@Q^'CS.'/
M("C'X>/,X<_'RBD@VN0@Q^'1T\?&X2#'X<S/[<_)(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E;F5R871E(&$@;&EN
M:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N
M<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD
M97(_(@IM<V=S='(@(N7A(,K1[<\@W<K-(-#AWR#'X>/,X<\@OR(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,R"FUS9VED(")$;VXG="!H879E
M(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C8*;7-G:60@(D1O;F4B"FUS9W-T
M<B`BRN,B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"B,L('!H<"UF
M;W)M870*;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R"FUS
M9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,C`*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R("+*S>/MX2#'
MX>/,X<\@*"#'X>/,X<_'RB`I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS
M*2!;+GII<"!F;W)M871=(@IM<V=S='(@(LK-X^WA(,?AX\SASR`H(,?AX\SA
MS\?*("DB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"FUS9VED(")$
M;W=N;&]A9"!I;B`N>FEP($9O<FUA="(*;7-G<W1R("(B"@HC.B!M97-S86=E
M+G!H<#HU,#$@;6%I;&)O>"YP:'`Z-S$Y('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHR,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0Q"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.0IM<V=I9"`B1')A9G0B
M"FUS9W-T<B`BX]/FS\DB"@HC.B!F;VQD97)S+G!H<#HS.3(*(RP@9G5Z>GD*
M;7-G:60@(D1R869T(&9O;&1E<B(*;7-G<W1R("+CS.'/(,?AX]/FS\?*H#HB
M"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I
M9"`B1')A9G1S(&9O;&1E<CHB"FUS9W-T<B`BX\SASR#'X>/3YL_'RJ`Z(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`HC+"!F=7IZ>0IM<V=I9"`B
M12UM86EL($%D9')E<W,B"FUS9W-T<B`BVN3FQ^0@Q^'(T>W/(,?AQ^'?RM'F
MY.TB"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S`Y"FUS9VED(")%3D0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@
M(D524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB
M"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHQ.0IM<V=I9"`B161I="(*;7-G<W1R("+*S='M
MT2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ.`HC+"!F=7IZ
M>0IM<V=I9"`B161I="!";&%C:VQI<W0B"FUS9W-T<B`BQ^'>Q\;CR2#'X=/F
MS\?!(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$S"B,L(&9U
M>GIY"FUS9VED(")%9&ET($9I;'1E<G,B"FUS9W-T<B`BX]'4S<?*(,?AR-'M
MSR(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z,38*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@
M9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHR,PIM<V=I9"`B161I="!7:&ET96QI<W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"B,L(&9U>GIY"FUS9VED
M(")%9&ET('EO=7(@8FQA8VML:7-T(@IM<V=S='(@(LK-T>W1(-[FQ]K/(,?A
MW>'*T<DB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G
M:60@(D5D:70@>6]U<B!F:6QT97(@<G5L97,B"FUS9W-T<B`BRLW1[=$@WN;'
MVL\@Q^'=X<K1R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-C$*;7-G
M:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R
M(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B161I="!Y;W5R('=H
M:71E;&ES="(*;7-G<W1R("+*S='MT2#>YL?:SR#'X=WARM')(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,SD*;7-G:60@(D5M86EL
M($%D9')E<W,B"FUS9W-T<B`BVN3FQ^0@Q^'(T>W/(,?AQ^'?RM'FY.TB"@HC
M.B!L:6(O365S<V%G92YP:'`Z-C4W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("+*
MXR#-T-T@S./MVB#'X='3Q\;A(./D("5S+B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H<RDB"FUS
M9W-T<B`BX\SASR`H(./,X<_'RBD@W<?1V\DB"@HC.B!F;VQD97)S+G!H<#HR
M.#8*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS
M9W-T<B`BX\SASR`H(./,X<_'RBD@W<?1V\DB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@9F]L9&5R
M(@IM<V=S='(@(N/,X<\@T^')(./EX^''RB#=Q]';R2(*"B,Z(&QI8B])35`N
M<&AP.CDW,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@7U-P86TB"FUS9W-T<B`B
MT^')(-W'T=O)(@H*(SH@;&EB+TE-4"YP:'`Z.38V"B,L(&9U>GIY"FUS9VED
M(")%;7!T>2!?5')A<V@B"FUS9W-T<B`BT^')(-W'T=O)(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC
M.C8*;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ('1E;7!L871E<R]S
M;6EM92]N;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L92!3+TU)344@9G5N
M8W1I;VYA;&ET>3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Q,0IM<V=I9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0T,@IM
M<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3$W(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV-3<*;7-G:60@(D5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,S@T"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T
M<B`BQ^3EQ\$@Q^'1T\?&X2#'X>/-YN')(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C,T,0HC+"!F=7IZ>0IM<V=I9"`B16YD(&UE<W-A9V4B"FUS9W-T<B`BQ^'1
MT\?&X2#'X=[/[>/)(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B16YD(&UE<W-A9V4@9G)O;2`E<R(*;7-G
M<W1R("+1T\?AR2#CS>;AR2#CY"`E<R(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")%
M;G1E<B!087-S<&AR87-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S<&%M<V5L96-T+FEN8SHY"B,L(&9U>GIY"FUS9VED(")%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`BQ\_.X2#'
MT^,@X\SASR#3X<D@Q^'CY>/AQ\H@Q^',S^W/(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@
M9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T<B`BQ\_.X2#'T^,@
MX\SASR#'X>/3YL_'RB#'X<S/[<\B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@
M>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("+'S\[A(,?3XR#C
MS.'/(,?AT=/'QN$@Q^'CT=/AR2#'X<S/[<\B"@HC.B!T96UP;&%T97,O<')E
M9G,O=')A<VAS96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O
M<B!Y;W5R(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`BQ\_.X2#'T^,@X\SA
MSR#3X<D@Q^'CY>/AQ\H@Q^',S^W/(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*
M(RP@9G5Z>GD*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(L?:Q\_)
M(,KFS.WE(-'3Q^')(@H*(SH@;65S<V%G92YP:'`Z,3DT(&-O;7!O<V4N<&AP
M.C$Q,S0@=&AR96%D+G!H<#HW,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("+*XR#'S\['X2#'X=/,X2!<(B5S7"(@
MR.3,Q\T@W>T@T\SA(,?AVN3'YNWD(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HS-S8@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,S@V"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T
M<B`BSMC#(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E<G9E<BX@
M)7,@.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C,P.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`Q"B,L(&9U>GIY
M"FUS9VED(")%=F5N="!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B
MRN,@Q^';Q\$@Q^'CS.'/(%PB)7-<(B#(Y,S'S2XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@R"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S
M='(@(M_A(#$U(,_>[=[)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W
M.0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("+?X2`S,"#+Q^3M
MR2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#$*;7-G:60@(D5V97)Y
M(#4@;6EN=71E<R(*;7-G<W1R("+?X2`U(,_>Q\;>(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<X,PIM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S
M='(@(M_A(.35W2#3Q]K)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X
M,`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(M_A(,_>[=[)(@H*(SH@
M9F]L9&5R<RYP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")%>'!A;F0B"FUS9W-T
M<B`BR-/8(,?AW^$B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHS.`IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R("+(T]@@Q^'?X2(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A
M;F0@06QL($9O;&1E<G,B"FUS9W-T<B`BR-/8(,SC[=H@Q^'CS.'/Q\HB"@HC
M.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X<&%N9"!&;VQD97(B"FUS9W-T
M<B`BR-/8(./,X<\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4S"FUS9VED
M(")%>'!A;F0@3F%M97,B"FUS9W-T<B`BR-/8(,?AQ]/CQ\$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`V,PIM<V=I9"`B17AP86YD(&YA;65S(&EN
M('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H92!B86-K
M9W)O=6YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3@P"FUS9VED(")%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D
M969A=6QT(&EN('1H92!F;VQD97)S('9I97<_(@IM<V=S='(@(LC3V"#4S-')
M(,?AX\SAS\?*(,?AS<?A[<D@R-3?X2#'W<K1Q];M(,?+Y,?!(-K1UB#'X>/,
MX<_'RB"_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C$P,0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD:6YG(@IM
M<V=S='(@(LC3V"#'X=_A(@H*(SH@;&EB+TE-4"YP:'`Z.3@T(&QI8B])35`N
M<&AP.CDX-@HC+"!F=7IZ>0IM<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T<B`B
MR-'MSR#,S^W/(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN
M:6YC.C(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*(RP@9G5Z>GD*;7-G
M:60@(D9E=&-H($UA:6PB"FUS9W-T<B`BR-'MSR#,S^W/(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@V.0HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@36%I
M;"!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`BQ]'3X2#1T\?AR2#=
M[2#DQ]W0R2#,S^W/R2"_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C0V"B,L(&9U>GIY"FUS9VED(")&971C:"!M97-S86=E<R!U<&]N
M(&QO9V=I;F<@;VX_(@IM<V=S='(@(B#>XR#(RMC([=X@Q^'CT=3-Q\H@Q\OD
MQ\$@Q^'/SN;A(+\B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@9G)O
M;2`E<R(*;7-G<W1R("+*XR#-T-T@S./MVB#'X='3Q\;A(./D("5S+B(*"B,Z
M(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("+1T\?A
MR2#CS>;AR2#CY"`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-2!L:6(O
M1F5T8VAM86EL+G!H<#HR.#<@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"FUS9VED
M(")&971C:&UA:6PZ("(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+G!H
M<#HR.3$*(RP@9G5Z>GD*;7-G:60@(D9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A
M9V5S+B(*;7-G<W1R("+*YLS/(.'/[=\@)7,@T=/'X<D@S,_MS\DN(@H*(SH@
M;&EB+TE-4"YP:'`Z.3DP"B,L(&9U>GIY"FUS9VED(")&:5]L=&5R<R(*;7-G
M<W1R("+'X>/1U,W'RB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C4P,B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHX,@HC
M+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R("+'X>/1U,W'RB(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B
M1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`BSNW'T<?*(,?.T>PB"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M=&5R(%-E='1I;F=S(@IM<V=S='(@(M[FQ]K/(,?AX]'4S2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV,#`*;7-G:60@(D9I;'1E<B!M97-S86=E(&-O
M;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`BRM'4[<T@Q^'CS<KF[<?*
M(,?AX<?'SN''WNW)(.'AT=/'QN$@OR(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+VYO=&%C=&EV92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S='(@(L?A
MX]'4S<?*(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHS
M"FUS9VED(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T9I;'1E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<G,Z
M("5S(&UA;F%G96UE;G0@<&%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN9"(*;7-G<W1R
M("+,SR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*(RP@9G5Z>GD*
M;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R("+'X=7=S<D@Q^''
MYN'L(@H*(SH@;6%I;&)O>"YP:'`Z,S0U"FUS9VED(")&:7)S="!086=E(@IM
M<V=S='(@(L?AU=W-R2#'X<?FX>PB"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D9O7W)W87)D(@IM<V=S='(@(LK-
MYNWA(@H*(SH@9F]L9&5R<RYP:'`Z,C8V('1E;7!L871E<R]F;VQD97)S+V9O
M;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G:60@(D9O;&1E<B!!8W1I;VYS("T@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,P,R!T
M96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY"B,Z('1E;7!L871E<R]P<F5F
M<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z-@HC.B!T96UP;&%T97,O<')E9G,O
M:6YI=&EA;'!A9V5S96QE8W0N:6YC.C$P"FUS9VED(")&;VQD97(@3F%V:6=A
M=&]R(@IM<V=S='(@(N/3RM_4W2#'X>/,X<\B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B1F]L9&5R(%-U;6UA<GDB"FUS
M9W-T<B`BW<C1Q^W1(@H*(SH@86-L+G!H<#HR-`IM<V=I9"`B1F]L9&5R('-H
M87)I;F<@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C8R"FUS9VED(")&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38Y"FUS9VED(")&
M;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O
M<B!M97-S86=E<R!D871E9"!T;V1A>2(*;7-G<W1R("(B"@HC.B!C;VUP;W-E
M+G!H<#HW.#`@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$U"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED
M(")&;W)W87)D(@IM<V=S='(@(LK-YNWA(@H*(SH@8V]M<&]S92YP:'`Z-S8U
M"FUS9VED(")&;W)W87)D.B(*;7-G<W1R("+*S>;MX:`Z(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C,V.0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A
M9V4B"FUS9W-T<B`BQ^3EQ\$@Q^'1T\?&X2#'X>/-YN')(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;W)W87)D960@
M;65S<V%G92!F<F]M("5S(@IM<V=S='(@(M'3Q^')(./-YN')(./D("5S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,PHC+"!F=7IZ>0IM<V=I
M9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(N/:X>;CQ\H@Q^'C
MTN;/(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y-`IM<V=I9"`B
M1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT.#@*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*;7-G:60@
M(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*(RP@9G5Z
M>GD*;7-G:60@(D9R;U]M(@IM<V=S='(@(N/D(@H*(SH@;65S<V%G92YP:'`Z
M,C8S('1H<F5A9"YP:'`Z,30Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.CDY"B,Z(&QI8B]396%R8V@N<&AP.C(R"FUS9VED(")&<F]M(@IM<V=S
M='(@(N/D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ.`IM<V=I9"`B
M1G)O;2!!9&1R97-S(@IM<V=S='(@(N/D(,?AVN3FQ^0B"@HC.B!C;VUP;W-E
M+G!H<#HW-S<@8V]M<&]S92YP:'`Z-S@Q"FUS9VED(")&=V0Z(@IM<V=S='(@
M(N/-YN$Z(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-`HC+"!F=7IZ>0IM<V=I9"`B
M1G=D.B`B"FUS9W-T<B`BX\WFX3HB"@HC.B!C;VUP;W-E+G!H<#HQ,CDV"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O<G=A<F1E9"!-
M97-S86=E<R(*;7-G<W1R("+'Y.7'P2#'X='3Q\;A(,?AX\WFX<DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@*(RP@9G5Z>GD*;7-G:60@(D=E;F5R86P@3W!T:6]N<R(*
M;7-G<W1R("+.[<?1Q\H@Q^'CT\K.S^,B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M97-S86=E
M<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z('1H
M<F5A9"YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")';R!T;R!-97-S86=E(@IM
M<V=S='(@(L?AT=/'X<D@Q^'*Q^'MR2(*"B,Z(&QI8B])35`N<&AP.C0Y.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1V\@=&\@861D<F5S<R!B;V]K
M(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R("+'UMT@Q^'L(-/,X2#'X=KDQ^;M
MY"`H)7,I(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B
M1W)A;G0@86-C97-S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-B!L
M:6(O1FEL=&5R+G!H<#HQ,#4@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M.34*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R(&QI8B]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC.B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6:65W97(O
M<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM<V=I
M9"`B2$5212(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-PHC.B!L
M:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS
M9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I
M;VX@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]H96%D97)S+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE
M<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8X"FUS9VED(")(:61D
M96XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PHC
M+"!F=7IZ>0IM<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@
M(MK1UB#*T^'3X>TB"@HC.B!M86EL8F]X+G!H<#HS-C<*;7-G:60@(DAI9&4@
M1&5L971E9"(*;7-G<W1R("+'SMW'P2#'X>/AV^TB"@HC.B!F;VQD97)S+G!H
M<#HR.3@*;7-G:60@(DAI9&4@56YS=6)S8W)I8F5D(@IM<V=S='(@(L?.W<?!
M(,?AV^W1(./4RM'?(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP
M.C(Y-R!M86EL8F]X+G!H<#HW,C0@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHQ,@IM<V=I9"`B2&EG:"!0<FEO<FET>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE
M<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X.`IM
M<V=I9"`B2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*(RP@
M9G5Z>GD*;7-G:60@(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI;F5S(&EN
M(&$@<F5P;'DB"FUS9W-T<B`B(,K-S^W/(,C'S\;)(,?AQ]/8T2#'X>/>RLC3
MR2#=[2#'X='/H#HB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$S-`IM
M<V=I9"`B24U!4"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$R.0IM<V=I9"`B24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*2(*
M;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I
M;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,38V(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,30V"FUS9VED("))34%0(&]V97(@4U-,(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,34R"FUS9VED("))34%0(&]V97(@4U-,
M("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C<*;7-G:60@(DE-05`@;W9E<B!3
M4TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE
M;G0N<&AP.C,V.`IM<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN
M96-T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$V-2!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!
M4"P@;F\@5$Q3(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-4"YP:'`Z.#8V"FUS9VED("))3D)/6"(*;7-G<W1R("+'
MX>;'T<\B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I9"`B268@
M=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS
M<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3(*(RP@9G5Z>GD*;7-G
M:60@(DEF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD
M97(H<RD@=VEL;"!B92!L;W-T(2(*;7-G<W1R("+,X^W:(,?AT=/'QN$@W>T@
MQ^'CS.'/("C'X>/,X<_'RBD@T^;=(,K=WL^@(2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHX,@IM<V=I9"`B26=N;W)E(@IM<V=S='(@
M(LK,Q^7A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@S
M"FUS9VED("))9VYO<F4@06QL(@IM<V=S='(@(LK,Q^7A(,?AW^$B"@HC.B!T
M96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN
M8SHR,`HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T(@IM<V=S='(@(N/EXR(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C8U"B,L(&9U>GIY"FUS9VED("));7!O<G0@
M2V5Y(@IM<V=S='(@(N/EXR(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M,SD*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!+97EP86ER(@IM<V=S='(@(N/E
MXR(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(W"B,L(&9U
M>GIY"FUS9VED("));7!O<G0@365S<V%G97,B"FUS9W-T<B`BT=/'QN$@X^7C
MR2(*"B,Z('!G<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3$*;7-G:60@
M(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@
M4&5R<V]N86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26UP;W)T(%!E<G-O
M;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4&5R<V]N86P@
M4R]-24U%($-E<G1I9FEC871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O<&=P+FEN8SHT,@IM
M<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC
M(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@4R]-24U%($ME>2(*
M;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)
M344@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R
M="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N
M(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,B!M86EL8F]X+G!H<#HW
M,S0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E
M;F0N:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R("+CY>,B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@
M;65S<V%G97,B"FUS9W-T<B`BT=/'QN$@X^7CR2(*"B,Z(&9O;&1E<G,N<&AP
M.C$V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@)60@
M;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T<B`BRN,@S=#=(,SC[=H@Q^'1T\?&
MX2#CY"`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS
M9VED("));B!0<F]C97-S(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,X
M-"!L:6(O1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-
M4"YP:'`Z,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4
M<F5E+G!H<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.3(*(RP@9G5Z>GD*;7-G:60@(DEN8VQU9&4@
M82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\B"FUS
M9W-T<B`BQ]'=Q]X@Q^'1T\?&X2#'X<?5X>W)(-KDSR#'X='/(+\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W"FUS9VED("));F-L=61E(&]R:6=I
M;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B"FUS9W-T<B`BQ]'=Q]X@Q^'1T\?&
MX2#'X<?5X>W)(-KDSR#'X='/(+\B"@HC.B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HV,2!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ
M,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F\B"FUS9W-T<B`BRLS'Y>$B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T
M92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN9F]R;6%T
M:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHY.`HC+"!F=7IZ>0IM<V=I9"`B26YL:6YE(@IM<V=S
M='(@(N''(-3MP2(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED("))
M;G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B
M26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED("))
M;G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO
M;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*"B,Z
M(&UA:6QB;W@N<&AP.C4X-"!M86EL8F]X+G!H<#HV,C8*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R("+:Y.;'Y"#'X<C1[<\@Q^''
MX=_*T>;D[2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM<V=S='(@(B(*"B,Z(&-O;7!O
M<V4N<&AP.C$U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI
M9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R("+-
MT>;=(-OMT2#CWLCFX<D@W>T@VN3FQ^0@Q^'(T>W/(,?AQ^'?RM'FY.TN(@H*
M(SH@<VUI;64N<&AP.C@R('!G<"YP:'`Z,38*;7-G:60@(DEN=F%L:60@:V5Y
M(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3DV"FUS9VED("));G9A;&ED('!E
M<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H
M<#HQ-S$*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I
M9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@=&\@
M8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N
M;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T
M:&ES('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHS-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,SD*;7-G:60@(B(*
M(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA=F4@;F\@861D
M<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@(@HB8V]N=&%C=',N(@IM
M<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S$X"FUS9VED(")+97D@<W5C8V5S<V9U
M;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$V"FUS9VED("),86YG
M=6%G92(*;7-G<W1R("+'X>';R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,#8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@36%I;&)O>"!086=E(@IM<V=S
M='(@(L+.T2#5W<W)(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED("),87-T
M(%!A9V4B"FUS9W-T<B`BPL[1(-7=S<DB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS.#D*(RP@9G5Z>GD*;7-G:60@(DQI7VYK($%T=&%C
M:&UE;G1S(@IM<V=S='(@(N/1W=['RB(*"B,Z(&%T=&%C:&UE;G0N<&AP.C,T
M(&QI8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED("),:6YK960@871T86-H;65N
M=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL;"!E>'!I
M<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN
M9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL
M("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP
M;&EC:71L>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8X-0IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A9&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`HC+"!F=7IZ
M>0IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`BU>3/YMX@Q^'(T>W/
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`HC+"!F=7IZ>0IM
M<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BQ<S1Q\$B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(L_.
MYN$B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3$U"B,L('!H<"UF;W)M
M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G<W1R("+/SN;A(,?A["`E<R(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,W"B,L(&9U>GIY"FUS
M9VED("),;V=I;B(*;7-G<W1R("+/SN;A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("+CY<?C(,?A
MS\[FX2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-@IM
M<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL
M8F]X+G!H<#HW,C<@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM
M<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-PIM<V=I9"`B3&]W97-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#0*(RP@
M9G5Z>GD*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM<V=S='(@(N/1U,W'RB#'
MX<C1[<\B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*
M(RP@9G5Z>GD*;7-G:60@(DUA:6PB"FUS9W-T<B`BU>3/YMX@Q^'(T>W/(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"B,L(&9U>GIY"FUS9VED(")-
M86EL(%!R979I97=S(@IM<V=S='(@(N/1U,W'RB#'X<C1[<\B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C$V"FUS9VED(")-
M86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM<V=S='(@(B(*"B,Z
M(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I;&)O>"(*;7-G<W1R("+5Y,_F
MWB#'X<C1[<\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L(&9U
M>GIY"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS
M(@IM<V=S='(@(MK1UB#'X<[MQ]''RB(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C$X"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&
M;VQD97(@87,@4V5E;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@
M1F]L9&5R(&%S(%5N<V5E;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C4@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHS,`IM<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`BVN'CY2#?
MW*`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U,`IM<V=I9"`B36%R
M:R!D:69F97)E;G0@;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@
M8V]L;W)S/R(*;7-G<W1R("+:X>,@Q^'CT\KF[<?*(,?AX\[*X=W)(./D(,?A
MQ][*R,?3Q\H@R,?AYL?D(./.RN'=R2"_(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E
M96X_("A)34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0V"FUS9VED
M(")-871C:"!!;&P@475E<FEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,3,*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM
M<V=S='(@(N/1W=XB"@HC.B!L:6(O87!I+G!H<#HW.0IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT.30*;7-G:60@(DUA>&EM=6T@;G5M8F5R
M(&]F(&%T=&%C:&UE;G1S(')E86-H960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X.0IM<V=I9"`B36%X:6UU;2!T
M;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B365E=&EN9R!#
M86YC96QL871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!);F9O<FUA=&EO
M;B(*;7-G<W1R("+CVN'FX\?*(,?AX]+FSR(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I9"`B
M365E=&EN9R!297!L>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3DX"FUS9VED(")-965T:6YG(%5P9&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`S"FUS9VED(")-965T
M:6YG(%5P9&%T92!297%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T
M<F5E7V9O;&1E<G,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@1F]L9&5R
M($QI<W0B"FUS9W-T<B`BX\SASR#CW<KFS2(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS,S$*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BT=/'X<DB"@HC.B!C;VUP
M;W-E+G!H<#HU-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O<V4N<&AP.C8T,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S
M:71I;VXB"FUS9W-T<B`BR.3MR2#'X='3Q^')(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(LK'
MT>W.(,?AT=/'X<DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#D@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDU(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#,*(RP@9G5Z>GD*
M;7-G:60@(DUE<W-A9V4@3W!T:6]N<R(*;7-G<W1R("+1T\?&X2#'X>PB"@HC
M.B!S96%R8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T
M<B`BR,W+(,?AT=/'X<DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(Q
M"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`BS<SC(,?AT=/'X<DB"@HC
M.B!M97-S86=E+G!H<#HS.#0*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM<V=S
M='(@(N/?YN3'RB#'X='3Q^')(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8V"FUS9VED(")-97-S86=E(%9I97=I;F<B"FUS9W-T<B`BVM'6(,?AT=/'
MX<DB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G:60@(DUE
M<W-A9V4@9FQA9W,B"FUS9W-T<B`BQ]KAQ^,@Q^'1T\?AR2(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z.#,*;7-G:60@(DUE<W-A9V4@9F]L9&5R
M<R(*;7-G<W1R("+CS.'/Q\H@Q^'1T\?AR2(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@9G)O
M;2`E<R(*;7-G<W1R("+CS.'/Q\H@Q^'1T\?AR2(*"B,Z(&UA:6QB;W@N<&AP
M.C8V-PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!H87,@871T86-H;65N=',B
M"FUS9W-T<B`BX]'=WL?*(./-T.;=R2(*"B,Z(&UA:6QB;W@N<&AP.C8U.`HC
M+"!F=7IZ>0IM<V=I9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T<B`B
MS=[FX2#'X='3Q^')(@H*(SH@;6%I;&)O>"YP:'`Z-C4S"B,L(&9U>GIY"FUS
M9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G<W1R("+-WN;A(,?AT=/'X<DB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S,*(RP@9G5Z>GD*
M;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R("+*Q]'MSB#'X='3Q^')
M(@H*(SH@8V]M<&]S92YP:'`Z.#(T(&-O;7!O<V4N<&AP.C@S.`HC+"!F=7IZ
M>0IM<V=I9"`B365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`BRN,@Q]'3Q^$@Q^'1T\?AR2#(Y,S'S2XB"@HC.B!C;VUP;W-E+G!H
M<#HQ,#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E
M;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@
M(LKC(,?1T\?A(,?AT=/'X<D@R.3,Q\TN(@H*(SH@8V]M<&]S92YP:'`Z,3$T
M,R!C;VUP;W-E+G!H<#HQ,34X"B,L(&9U>GIY"FUS9VED(")-97-S86=E('-E
M;G0@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+*XR#'T=/'X2#'X='3Q^')(,CD
MS,?-+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE
M<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@
M(M'3Q^')(.'?X2#5W<W)(,?+Y,?!(-K1UB#5Y,_FWB#'X='3Q\;A+B(*"B,Z
M(&UA:6QB;W@N<&AP.C,R,@IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B
MT=/'QN$@Q^'L(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C(Y"FUS9VED
M(")-;V1I9GDB"FUS9W-T<B`BRMK/[>$B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E>'!A;F0N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA
M;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO
M=F4B"FUS9W-T<B`BQ^3*WN$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,38*(RP@9G5Z>GD*;7-G:60@(DUO=F4@9&]W;B(*;7-G
M<W1R("+'Y,K>X2#'X>P@Q^''T]WA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8Q.`IM<V=I9"`B36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@9F]L
M9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*(RP@9G5Z>GD*;7-G
M:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@(L?.RM$@X\SASR(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-`HC+"!F=7IZ>0IM
M<V=I9"`B36]V92!U<"(*;7-G<W1R("+'Y,K>X2#'X>P@Q^''VN'L(@H*(SH@
M;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU
M;'1I<&%R="]A;'1E<FYA=&EV92(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP
M.C<V('1H<F5A9"YP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!-
M97-S86=E(%9I97<B"FUS9W-T<B`BVM'6(,?AT=/'X<DB"@HC.B!T96UP;&%T
M97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z-0IM<V=I9"`B3D].
M12(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-#@@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHR"FUS9VED(").3U1%(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(DYA;64B"FUS9W-T<B`BQ^''T^,B
M"@HC.B!P9W`N<&AP.C$Q,`IM<V=I9"`B3F%M92!A;F0O;W(@96UA:6P@8V%N
M(&YO="!B92!E;7!T>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S<X"B,L(&9U>GIY"FUS9VED(").965D<R!!8W1I;VXB"FUS
M9W-T<B`BQ<S1Q\$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<W.`IM<V=I9"`B3F5V97(B"FUS9W-T<B`BX]CAWL<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-38P"B,L(&9U>GIY"FUS9VED(").979E<B!S
M879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(N/1W=['RB#CS=#FW<DB"@HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`B
MS,_MSR(*"B,Z(&QI8B])35`N<&AP.C4V,PIM<V=I9"`B3F5W($9O;&1E<B(*
M;7-G<W1R("+CS.'/(,S/[<\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#@*;7-G:60@(DYE=R!-86EL(@IM<V=S='(@(LC1[<\@S,_MSR(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ.2!L:6(O0FQO8VLO=')E95]F;VQD97)S
M+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B3F5W($UE<W-A9V4B"FUS9W-T<B`B
MQ^'1T\?AR2#'X<K'X>W)(@H*(SH@;6%I;&)O>"YP:'`Z-S<V(&QI8B]-24U%
M+TAE861E<G,N<&AP.C$Y,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BT=/'QN$@S,_MS\DB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Y"FUS9VED(").97<@;65S<V%G
M97,B"FUS9W-T<B`BT=/'QN$@S,_MS\DB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z,3,S"FUS9VED(").97AT(@IM<V=S='(@(L?ARL?A
M[2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,S,*;7-G:60@(DYE>'0@365S<V%G92(*;7-G<W1R("+'X='3Q^')(,?ARL?A
M[<DB"@HC.B!M86EL8F]X+G!H<#HS-38*;7-G:60@(DYE>'0@4&%G92(*;7-G
M<W1R("+'X=7=S<D@Q^'*Q^'MR2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS9VED
M(").;R(*;7-G<W1R("+AQR(*"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO
M($-E<G1I9FEC871E(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3D*;7-G
M:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X
M+G!H<#HS-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO($UE<W-A
M9V5S(@IM<V=S='(@(M'3Q\;A(,S/[<_)(@H*(SH@<&=P+G!H<#HQ,S<*;7-G
M:60@(DYO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S
M;VYA;"!#97)T:69I8V%T92!0<F5S96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M86EL8F]X+G!H<#HS,CD*(RP@9G5Z>GD*;7-G:60@(DYO(%!R979I97<@5&5X
M="(*;7-G<W1R("+'X>35(,?AX]7-S2(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,34*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S
M='(@(B(*"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L
M:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O=&YE9BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DYO(&%T=&%C:&UE;G1S
M(&9O=6YD+B(*;7-G<W1R("+CT=W>Q\HB"@HC.B!L:6(O0W)Y<'0O4TU)344N
M<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I;VX@;&]C871E9"!I
M;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HW,B!A
M8VPN<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97(@<V5L96-T960N
M(@IM<V=S='(@(N'C(.W*XR#'SLKMQ]$@X\SASR(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HQ-#$*;7-G:60@(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H
M96-K960@9F]R(&YE=R!M86EL+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HR,3@@;&EB+T9O;&1E<BYP:'`Z-3`P(&QI8B]&;VQD97(N<&AP.C4U,`IM
M<V=I9"`B3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9"(*;7-G<W1R("+AXR#M
MRN,@RLW/[<\@X\SASR(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#<*
M(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B
M"FUS9W-T<B`BX>W3RB#1T\?&X2#CX=OMR2(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!U
M;G-E96X@;65S<V%G97,B"FUS9W-T<B`BX>W3RB#1T\?&X2#CX=OMR2(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HS,C4*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A
M9V4@8F]D>2!T97AT(@IM<V=S='(@(L?DWN$@Q^'1T\?&X2#'X>PB"@HC.B!L
M:6(O36%I;&)O>"YP:'`Z,S<Q"B,L(&9U>GIY"FUS9VED(").;R!M97-S86=E
M<R!M871C:&5D('EO=7(@<V5A<F-H+B(*;7-G<W1R("+AQR#*YLS/(-'3Q\;A
M(./8Q\C>R2#AR,W+WR(*"B,Z('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P97)S
M;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z
M('!G<"YP:'`Z,38U"FUS9VED(").;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME
M>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(P,0IM<V=I
M9"`B3F\@<&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(R,`IM<V=I9"`B3F\@<W!E
M;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N(@IM<V=S='(@(N'C(.W*
MXR#*VM'MW2#(T>3'X\P@RL_>[=X@Q^/AQ\;M+B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R
M;W)S(@IM<V=S='(@(N''(,KFS,\@Q\[8Q\$@Q^/AQ\;MR2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#`*;7-G:60@(DYO('-U9V=E
M<W1I;VYS(@IM<V=S='(@(N''(,KFS,\@Q][*T<?-Q\HB"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4V-`IM<V=I9"`B3F\@<W5P<&]R=&5D($E-05`@875T
M:&5N=&EC871I;VX@;65T:&]D(&-O=6QD(&)E(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!A8VPN<&AP.C8X(&%C;"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO
M('5S97(@<W!E8VEF:65D+B(*;7-G<W1R("+AXR#MRN,@RLW/[<\@X\SASR(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#D*;7-G:60@(DYO;B!0
M87)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C$Q('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI
M;F,Z-#`*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S4@
M=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(DYO;F4B"FUS9W-T<B`BX<<@
MU.W!(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDU"FUS
M9VED(").;W)M86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Y
M"FUS9VED(").;W0@1&5L971E9"(*;7-G<W1R("+AXR#MRN,@Q^''X=O'P2(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3(@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@1')A9G0B"FUS9W-T
M<B`BX<<@RN;,SR#CT^;/R2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@
M(DYO="!);7!O<G1A;G0B"FUS9W-T<B`BX>W3RB#CY>/E(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T(%!E<G-O;F%L
M(@IM<V=S='(@(N'MT\H@U,[5[>4B"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HQ
M,SD@;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@;&EB+T-R>7!T+U--24U%+G!H
M<#HQ-#D*;7-G:60@(DYO="!A('9A;&ED('!U8FQI8R!K97DN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-C<*;7-G:60@(DYO
M="!D96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(N'MT\H@T=/'QN$@X^';[<DB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED(").;W0@
M:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(N'MT\H@T=/'QN$@X^7CR2(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z
M-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$V"B,L(&9U
M>GIY"FUS9VED(").;W1H:6YG(@IM<V=S='(@(L7>RLC'TR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S<*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O
M9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E
M;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(MK/SR#CS.'/Q\H@Q^'1T\?&
MX2#'X>/1T^')(,?AWL_MX\D@Q^'*[2#MS,@@Q\C>Q\3EQR#=[2#-Q^$@Q^''
MX=O'P2`@(,?AU.71[2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y
M"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME
M97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HBVL_/(./,X<_'
MRB#'X='3Q\;A(,?AX]'3X<D@Q^'>S^WCR2#'X<KM(.W,R"#'R-['Q.7'(-WM
M(,W'X2#'X<?AV\?!("`@Q^'4Y='M+B(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C4T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M-3(*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,PIM<V=I9"`B3TLB
M"FUS9W-T<B`BX^;'W=XB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z-2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT.`IM<V=I9"`B3U(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-0IM<V=I9"`B
M3VQD(&UE<W-A9V5S(@IM<V=S='(@(L?AT=/'QN$@Q^'>S^WCR2(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H
M<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E
M9"XB"FUS9W-T<B`BRN,@Q^'*SN'5(./D(./,X<_'RB#'X='3Q\;A(,?AX]'3
MX<D@Q^'>S^WCR2XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G
M:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S
M(&EN('1H96T_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&9O;&1E
M<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R
M("+'X=',Q\$@Q\[*[<?1(./,X<\@YL?-SR#=WM@@X>70Y2#'X=KCX>W)+B(*
M"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ,"!T96UP;&%T97,O;65N=2YI;F,Z
M,S`*(RP@9G5Z>GD*;7-G:60@(D]P96X@1F]?;&1E<B(*;7-G<W1R("+CS.'/
M(./=RN;-(@H*(SH@9F]L9&5R<RYP:'`Z-#(W"B,L(&9U>GIY"FUS9VED(")/
M<&5N960@1F]L9&5R(@IM<V=S='(@(N/,X<\@X]W*YLTB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S`U"FUS9VED(")/<'1I;VYA;"!087)T:6-I
M<&%N="(*;7-G<W1R("(B"@HC.B!F971C:&UA:6PN<&AP.C,S('1E;7!L871E
M<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M9F5T8VAM86EL+FEN8SHV"B,L(&9U>GIY"FUS9VED(")/=&AE<B!-86EL($%C
M8V]U;G1S(@IM<V=S='(@(L[MQ]''RB#'SM'L(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-3`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B
MSNW'T<?*(,?.T>PB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P
M,0IM<V=I9"`B3W5T8F]U;F0@4V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,38U"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR.3`*;7-G:60@(E!'4"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*(RP@
M9G5Z>GD*;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`BQ^';
MQ\$@Q^'1T\?AR2(*"B,Z(&-O;7!O<V4N<&AP.C,U.`HC+"!F=7IZ>0IM<V=I
M9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`BSMC#(@H*(SH@8V]M<&]S92YP:'`Z
M,S,W"FUS9VED(")01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R
M<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!/<'1I;VYS(@IM
M<V=S='(@(L[MQ]''RB(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!087-S
M<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R
M97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"FUS9VED(")01U`@4'5B
M;&EC($ME>2!497AT(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,30Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E
M<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`BRN,@
MQ^34Q\$@Q^'CS.'/(%PB)7-<(B#(Y,S'S2XB"@HC.B!P9W`N<&AP.C(T-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R
M(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(LKC
M(,?AV\?!(,?AX\SASR!<(B5S7"(@R.3,Q\TN(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHX
M"B,L(&9U>GIY"FUS9VED(")01U`@4VEG;B!-97-S86=E(@IM<V=S='(@(L?1
MT^$@T=/'X<DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N
M:6YC.CD*;7-G:60@(E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R
M("(B"@HC.B!P9W`N<&AP.C(P,@HC+"!F=7IZ>0IM<V=I9"`B4$=0('!R:79A
M=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`BRN,@RMOM[=$@
MQ^'*YM[MVB#(Y,S'S2XB"@HC.B!P9W`N<&AP.C$W-PIM<V=I9"`B4$=0('!U
M8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4$=0('-U<'!O
M<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P.`IM<V=I9"`B(@HB4$=0('-U
M<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@
M<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDU"FUS9VED("(B
M"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@
M;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I9"`B(@HB4$=0('-U
M<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@
M>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2`B"B)S970@=&\@9&ES86)L92!P
M;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R
M(&5L<V4@=&AE(%!'4"`B"B)F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E
M8W1L>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M,#4*;7-G:60@(E!/4#,B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HQ,#`*;7-G:60@(E!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L
M<RDB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3<*
M;7-G:60@(E!/4#,@;W9E<B!34TPB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,C,*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M
M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$V.0IM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L
M9BUS:6=N960I(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,3$Q"FUS9VED(")03U`S+"!N;R!43%,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")086=E("5D(&]F("5D(@IM<V=S='(@(L?AU=W-R2`E9"#CY"`E9"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#,*;7-G:60@(E!A9V4@=VET
M:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H('1H92!,
M87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VAE861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S='(@
M(LS2P2`HQ\S2Q\$I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R,PIM
M<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!9V%I;BDB"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C(S-2!P9W`N<&AP.C,Q,`HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@=6YL;V%D960N(@IM<V=S
M='(@(LKC(,K;[>W1(,?ARN;>[=H@R.3,Q\TN(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W!A<W-P:')A<V4N:6YC.C$X('1E;7!L871E<R]P9W`O<&%S<W!H<F%S
M92YI;F,Z,CD*;7-G:60@(E!A<W-P:')A<V4Z(@IM<V=S='(@(B(*"B,Z('!G
M<"YP:'`Z,3$R"FUS9VED(")087-S<&AR87-E<R!C86X@;F]T(&)E(&5M<'1Y
M(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$T"FUS9VED(")087-S<&AR87-E
M<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y
M+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y,@IM<V=I
M9"`B4&%S<W=O<F0B"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BRMW:[>$@
MVN/A[<?*(,?AU>W'Y,D@VN3/(,?AS\[FX2"_(@H*(SH@86-L+G!H<#HW-B!A
M8VPN<&AP.C$P,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C
M86X@;F]T(&)E(&-H86YG960N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP
M.C0Y,R!M86EL8F]X+G!H<#HW,#,@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$P"FUS
M9VED(")097)S;VYA;"(*;7-G<W1R("+4SM7M(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G
M<W1R("+CVN'FX\?*(-3.U>W)(@H*(SH@<&=P+G!H<#HQ,C`*(RP@9G5Z>GD*
M;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(LKC(,?1T\?A(,?AT=/'X<D@R.3,Q\TN(@H*(SH@
M<&=P+G!H<#HQ,C<*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES
M(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+*XR#'T=/'X2#'X='3
MQ^')(,CDS,?-+B(*"B,Z('-M:6UE+G!H<#HR,#<*;7-G:60@(E!E<G-O;F%L
M(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`B
M(@H*(SH@<VUI;64N<&AP.C$S,@IM<V=I9"`B4&5R<V]N86P@4R]-24U%(&ME
M>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L86-E('EO=7(@<VEG;F%T
M=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\B"FUS9W-T<B`BYM;:
M(,KFWNW:WR#>R.$@Q^'1S^;/(.8@Q^'*S>;MX<?*(+\B"@HC.B!C;VUP;W-E
M+G!H<#HR-30*;7-G:60@(E!L86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y.0IM<V=I
M9"`B(@HB4&QA>2!S;W5N9"!O;B!N97<@;6%I;#\@(%1H:7,@<F5Q=6ER97,@
M>6]U<B!B<F]W<V5R('1O('-U<'!O<G0@96UB961D960@(@HB<V]U;F0@9FEL
M97,N("!!;&UO<W0@86QL(&1O(&]N(%=I;F1O=W,@86YD($UA8RP@8G5T(&]T
M:&5R('!L871F;W)M<R!W:6QL("(*(G)E<75I<F4@82!P;'5G:6XN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U
M('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S
M='(@(NW1S.P@Q\_.Q^$@Q]/C(.'AX\SASR#'X<S/[<^@.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R('1E;7!L871E<R]J879A
M<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")0;&5A<V4@96YT97(@=&AE
M(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(NW1S.P@Q\_.Q^$@
MQ]/C(,?AX\SASR#'X<S/[<^@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3,W"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N
M86UE.B(*;7-G<W1R("+MT<SL(,?/SL?A(,?AQ]/C(,?AS,_MSZ`Z(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO
M=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB
M96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A
M<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL
M;"!O;FQY(&YE960@(@HB=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@
M<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z(')E8V]M<&]S92YP:'`Z
M.3<*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O
M;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*
M(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O
M<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN
M(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P
M(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N
M(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S$*(RP@9G5Z>GD*
M;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S='(@
M(NW1S.P@RN;=[=$@Q]/C(,?AX]/*SL_C(.;?X>/)(,?AX]'FT2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(NW1S.P@RN;=
M[=$@Q]/C(,?AX]/*SL_C(.;?X>/)(,?AX]'FT2(*"B,Z(&-O;7!O<V4N<&AP
M.C$P-B!L:6(O24U0+G!H<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M
M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B[=',["#-
MX2#'X<?ARLC'TR##YB#:S^,@U>''S>W)(,?AVN3'YNWD("XB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C0R"FUS9VED("(B"B)0;&5A<V4@<F5V
M:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C
M="!A;B!A8W1I;VX@9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHV,0IM<V=I
M9"`B4&QE87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@
M86YY(&%C=&EO;G,N(@IM<V=S='(@(L?AT<S'P2#'SNW'T2#CS.'/(-[(X2#'
MX=31YMH@W>T@Q^T@Q\S1Q\$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4P,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('-E;&5C="!A;B!A8W1I
M;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T<B`BQ^'1S,?!(,?.RNW'
MT2#CS.'/(.;'S<\@VN'L(,?AQ][A(.'AR,W++B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@
M870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(L?AT<S'
MP2#'SLKMQ]$@X\SASR#FQ\W/(-KA["#'X<?>X2#AX<C-RRXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS9VED(")0;&5A<V4@
M<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN(@IM
M<V=S='(@(L?AT<S'P2#'SLKMQ]$@X\SASR#FQ\W/(-W>V"#AY=#E(,?AVN/A
M[<DN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"B,L
M(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O
M>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(NW1S.P@Q\[*[<?1(,?F(,K-T>W1
M(.35(-7-[<V@.B(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD:7-T.C0Q"FUS9VED
M(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,30*(RP@9G5Z>GD*;7-G:60@(E!R96-E9&4@>6]U<B!S
M:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`BQ]/*Y>$@
MRN;>[=K?(,C4T=@@*"<M+2`G*2(*"B,Z('-M:6UE+G!H<#HR-#$@<&=P+G!H
M<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"B,L(&9U>GIY"FUS9VED(")0<F5F
M97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`BRN,@Q^34
MQ\$@Q^'CS.'/(%PB)7-<(B#(Y,S'S2XB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]A='1A8VAM96YT<RYI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B4')E=FEE=R(*
M;7-G<W1R("+'X=7=S<D@Q^'3Q\C>R2(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G:60@(E!R979I;W5S($UE<W-A
M9V4B"FUS9W-T<B`BQ^'1T\?AR2#'X=/'R-[)(@H*(SH@;6%I;&)O>"YP:'`Z
M,S0W"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(L?AU=W-R2#'X=/'
MR-[)(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C,S"FUS9VED(")0<FEN="(*;7-G<W1R("+8R,?:R2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VAE861E<G,N:6YC.C,X"B,L(&9U>GIY"FUS9VED(")0<FEO
M<FET>2(*;7-G<W1R("+8R,?:R2(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHW-@IM<V=I9"`B4')I=F%T92!+97D@4&%S<W=O<F0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U.0IM<V=I9"`B
M4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A
M=6QT('1O($Y/(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@
M:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0<F]T;V-O;#HB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y"FUS9VED(")0
M=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC.C@*
M(RP@9G5Z>GD*;7-G:60@(E!U<E]G92!$96QE=&5D(@IM<V=S='(@(LK.X=4@
MX^0@Q^'CX=OM(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS
M9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(LK.X=4@X^0@Q^'CX=OM(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C0*(RP@9G5Z>GD*
M;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R("+'X=O'P2#CS.'/("@@
MX\SAS\?*("DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"FUS9VED
M(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(N39W2#3X<D@Q^'C
MY>/AQ\H@W^$@W<K1R:`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P
M-0IM<V=I9"`B4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R
M('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RXB"FUS9W-T<B`BS=#=(,?AT=/'
MQN$@W>T@X\SASR#3X<D@Q^'CY>/AQ\H@Q^''WL_C(./D(.70QR#'X=K/SR#C
MY"#'X<?MQ^,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@HC+"!F
M=7IZ>0IM<V=I9"`B4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F
M;VQD97(_(@IM<V=S='(@(LW0W2#'X='3Q\;A(,?AWL_MX\D@X^0@X\SASR#3
MX<D@Q^'CY>/AQ\J_(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?
M=')A<V@N<&AP.C8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")0=7)G
M:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R("+-
MT-T@)60@T=/'X<D@*-'3Q\;A*2#CY"#CS.'/(-/AR2#'X>/EX^''RBXB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C,*(RP@
M9G5Z>GD*;7-G:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@5')A<V@@9F]L
M9&5R+B(*;7-G<W1R("+-T-T@)60@T=/'X<D@*-'3Q\;A*2#CY"#CS.'/(-/A
MR2#'X>/EX^''RBXB"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C$W
M"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@
M)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<75O
M=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T
M871U<SH@)2XR9DU"("\@3D\@3$E-250B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1
M=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E%U;W1I;F<@)68Z(@IM<V=S='(@(L7>RLC'TR(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B4F5?<75E<W0@1&5L:79E
M<GD@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP
M.C4P"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!/;B(*;7-G<W1R("+'T\KA
MX\H@W>TB"@HC.B!L:6(O4V5A<F-H+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B
M4F5C96EV960@4VEN8V4B"FUS9W-T<B`BQ]/*X>/*(-WM(@H*(SH@;&EB+U-E
M87)C:"YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM
M<V=S='(@(L?3RN'CRB#=[2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5D:7)E8U]T(@IM
M<V=S='(@(L?:Q\_)(,KFS.WE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C="(*;7-G<W1R("+'
MVL?/R2#*YLSMY2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN
M8SHQ,3`*;7-G:60@(E)E9&ER96-T($UE<W-A9V4B"FUS9W-T<B`BQ]K'S\D@
MRN;,[>4@T=/'X<DB"@HC.B!C;VUP;W-E+G!H<#HW.#<*;7-G:60@(E)E9&ER
M96-T('1H:7,@;65S<V%G92(*;7-G<W1R("+'VL?/R2#*YLSMY2#ET.4@Q^'1
MT\?AR2(*"B,Z(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E8W1I;F<@
M9F%I;&5D+B(*;7-G<W1R("+-WN$@Q]K'S\D@Q^'*YLSMY2XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU.#,*;7-G:60@(E)E9G)E<V@B
M"FUS9W-T<B`BQ^3:Q]0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@T
M"FUS9VED(")2969R97-H($9O;&1E<B!6:65W<SHB"FUS9W-T<B`BQ^3:Q]0@
MVM'6(,?AX\SAS\?*H#HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN
M8SHY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-`HC+"!F=7IZ>0IM
M<V=I9"`B4F5L;V%D(@IM<V=S='(@(L?:Q\_)(,K-X^WA(,?AVM'6(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I
M97<B"FUS9W-T<B`BQ]K'S\D@RLWC[>$@Q^':T=8B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3(V(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M-#4*;7-G:60@(E)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-SD*;7-G
M:60@(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS9W-T<B`BRM#?T2#"SM$@
MVM'6(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(W"B,L
M(&9U>GIY"FUS9VED(")296UO=&4@36%I;&)O>#HB"FUS9W-T<B`BU>3/YMX@
MQ^'(T>W/(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C0Q"FUS
M9VED(")296UO=F4@1FEE;&0@1G)O;2!396%R8V@B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`U"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@<V]U<F-E(@IM<V=S='(@(L?2Q^')(,?AX]7/T2(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*(RP@9G5Z>GD*
M;7-G:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T<B`BQ]K'S\D@RM/C[<D@
MQ^'CS.'/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B
M4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H
M/R(*;7-G<W1R("+'VL?/R2#*T^/MR2#CS.'/(,?AT=/'QN$@Q^'CT=/AR2#=
M[2#(S\?MR2#'X=3ET;\B"@HC.B!L:6(O1F]L9&5R+G!H<#HT-34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL
M960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BQ]K'
MS\D@RM/C[<D@7"(E<UPB(,?A["!<(B5S7"(@S=[A+B#ET,<@X\<@WL?AY2#'
MX>/2YL^@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$P"B,L(&9U>GIY"FUS9VED(")297!L7WD@=&\@3&ES="(*;7-G<W1R
M("+'X='/(-KA["#'X=_A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G<W1R("+'T\K(
MS^'E(,C<H#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`BQ^'1SR(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0P.0HC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B
MQ^'1SR#:X>PB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R("+'X='/(-KA
M["#'X=_A(@H*(SH@8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L>2!T;R!!
M;&PZ(@IM<V=S='(@(L?AT<\@VN'L(,?AW^$@.B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B
M4F5P;'D@=&\@3&ES="(*;7-G<W1R("+'X='/(-KA["#'X=_A(@H*(SH@8V]M
M<&]S92YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!,:7-T.B(*
M;7-G<W1R("+'X='/(-KA["#'X=_A(#HB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E<&QY
M('1O(%]!;&PB"FUS9W-T<B`BQ^'1SR#:X>P@Q^'?X2(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4S-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED(")2
M97!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,U"FUS9VED(")297!L>2!W
M:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-`IM<V=I9"`B4F5P;'D@
M=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!M97-S86=E+G!H<#HR-C<*(RP@9G5Z>GD*;7-G:60@(E)E<&QY
M+51O(@IM<V=S='(@(L?AT<\@VN'LH#HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M-#`Y"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(L?AT<\@VN'LH#HB"@HC
M.B!C;VUP;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*;7-G<W1R("+'X='/
MH#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,S@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C8*(RP@9G5Z>GD*
M;7-G:60@(E)E<&]R="!A<R!);FYO8V5N="(*;7-G<W1R("+'R.';(-KD(-'3
MQ^')(-OMT2#CT=OFR,DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,C,*;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(L?(X=L@VN0@T=/'
MX<D@V^W1(./1V^;(R2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,X,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E8V5I
M<'0B"FUS9W-T<B`BQ]CAR"#FU>$@WM''P<DB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y(&-O;F9I<FUA
M=&EO;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W
M,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G
M<W1R("+'V.'((.;5X2#>T<?!R2(*"B,Z(&UA:6QB;W@N<&AP.C$X.0IM<V=I
M9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDW"FUS9VED(")297%U:7)E
M9"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C$T,R!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,0IM<V=I9"`B4F5S970B"FUS
M9W-T<B`BQ]/*VL?/R2#'X<?=RM''UNTB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3$U"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R("+'T\K#Y-TB"@HC
M.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")297-U;64@>6]U<B!S97-S:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHT-`HC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#;VUP
M;W-I=&EO;EPB(@IM<V=S='(@(LCD[<D@Q^'1T\?AR2(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,S$@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C8Y"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M86-C;W5N=%]S96QE8W0N:6YC.C,R"FUS9VED(")2971U<FX@=&\@1F5T8V@@
M36%I;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHR,@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP;&%T97,O<VUI;64O
M;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30Y
M('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,38R('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S,*(RP@
M9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(L[MQ]''
MRB#'X>/3RL[/XR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,3@*;7-G
M:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E
M;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/R(*;7-G<W1R
M("+'T<S:(,?A["#:T=8@U>3'S^W>(,?AR-'MSR#(VL\@Q^';Q\$@RLWF[>$@
MQ^8@Y-/.("#1T\?AR2"_(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8X.`IM<V=I9"`B4F]L92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C$T,B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S
M-PHC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.0IM<V=I9"`B4R]-
M24U%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?
M;&ES="YI;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,SDT"FUS9VED(")3+TU)344@17)R
M;W(Z("(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS-S,*;7-G:60@(E,O
M34E-12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV
M871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U,0HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS9W-T<B`B
MSNW'T<?*(@H*(SH@<VUI;64N<&AP.C0Y"FUS9VED(")3+TU)344@4&%S<W!H
M<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P
M;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R
M("(B"@HC.B!S;6EM92YP:'`Z,30P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S
M9G5L;'D@9&5L971E9"XB"FUS9W-T<B`BRN,@Q^';Q\$@Q^'CS.'/(%PB)7-<
M(B#(Y,S'S2XB"@HC.B!S;6EM92YP:'`Z,38R"FUS9VED(")3+TU)344@4'5B
M;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`*;7-G:60@(E,O34E-12!0=6)L
M:6,@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C$Q"FUS9VED
M(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@
M861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y
M<'1?;&ES="YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!3:6=N($UE
M<W-A9V4B"FUS9W-T<B`BQ]'3X2#1T\?AR2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*;7-G:60@(E,O34E-12!3:6=N+T5N
M8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O
M;F]T86-T:79E+FEN8SHT"FUS9VED(")3+TU)344@<W5P<&]R="!I<R!D:7-A
M8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HR-#$*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T
M(&ES(&YO="!C=7)R96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U
M;F%B;&4@=&\@8F4@(@HB9&5C<GEP=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PIM<V=I9"`B(@HB4R]-24U%('-U
M<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@
M<VEG;F5D(&UE<W-A9V4@8V%N(&YO="`B"B)B92!D:7-P;&%Y960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED
M("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG
M:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*;7-G
M:60@(B(*(E,O34E-12!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@
M=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@
M<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E
M('1H:7,@<V5T=&EN9R!O<B!E;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@
M=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`U"FUS9VED(")33510(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(U-0HC+"!F
M=7IZ>0IM<V=I9"`B4U]U8FIE8W0B"FUS9W-T<B`BQ^'CYM;FVB(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,V,PHC+"!F=7IZ>0IM<V=I
M9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R("+'S=W9(.33SLD@W>T@(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"B,L
M(&9U>GIY"FUS9VED(")385]V92!A<R(*;7-G<W1R("+-W=D@W]PB"@HC.B!S
M96%R8V@N<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M-C<*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`BS=W9(-_<(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E
M($%T=&%C:&UE;G1S('=I=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHV.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@
M(E-A=F4@1')A9G0B"FUS9W-T<B`BS=W9(./3YL_)(@H*(SH@<V%V96EM86=E
M+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B4V%V92!);6%G92(*;7-G<W1R("+-
MW=D@W]PB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C`T"FUS9VED(")3
M879E($EM86=E(&EN($=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C4Y('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,3`P"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$R('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ-#@*(SH@=&5M<&QA=&5S+W!G<"]N;W1A
M8W1I=F4N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")3879E($]P=&EO;G,B"FUS
M9W-T<B`BSNW'T<?*(,?AX]/*SL_C(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C0P"FUS9VED(")3879E(%-T871I;VYE<GDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,S"B,L(&9U>GIY"FUS9VED
M(")3879E(%]$<F%F="(*;7-G<W1R("+-W=D@X]/FS\DB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@
M87,B"FUS9W-T<B`BS=W9(-_<(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W,@IM<V=I9"`B4V%V92!R
M96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S
M<R!B;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E
M<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`HC
M+"!F=7IZ>0IM<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(LW=V2#'
MX='3Q^')(,?AX]'3X<DB"@HC.B!C;VUP;W-E+G!H<#HQ,C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("+-W=D@S=[A(,?A
MX]/FS\DN(.70QR#CQR#>Q^'E(,?AX]+FSZ`Z("5S("(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M86EL8F]X
M+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z
M-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R("+(S<LB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHQ,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S
M(@IM<V=S='(@(LC-RR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C`*
M(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!/<'1I;VYS(@IM<V=S='(@(L[MQ]''
MRB#'X>/3RL[/XR(*"B,Z('-E87)C:"YP:'`Z,C8U"FUS9VED(")396%R8V@@
M4F5S=6QT<R(*;7-G<W1R("+DRL?&S"#'X<C-RR(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,30@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS,0IM<V=I9"`B4V5E;B(*;7-G<W1R("+DV=$B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.CD*;7-G:60@(E-E;&5C="(*;7-G<W1R
M("+'SLK1(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<P
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@06YO=&AE<B!!8V-O=6YT(@IM<V=S
M='(@(L?.RM$@X<<@U.W!(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C,V"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(L?.RM$@Y>;MY2`B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z
M,3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(L?.
MRM$@Q^'?X2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q
M-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T
M<B`BQ\[*T2#AQR#4[<$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@
M9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S
M='(@(L?.RL0@X]7/T2#3S.$@Q^':Y,?F[>0@X<?6Q]W)(.;'X<C-RR`@W>T@
MQ^':Y,?F[>0N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM
M<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("+'SLK1(,?AW^$B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N(@IM<V=S='(@(L?.RM$@Q^'*T<KMR"#'X=#M(,K1[<\@
MQ^0@[<KC(,?AR,W+(,CE(-KDSR#=RLT@T\SAQ\H@Q^':Y,?F[>0N("(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R("+'SLK1
M(.''(-3MP2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G
M:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(L?.RM$@X<<@U.W!(@H*(SH@=&5M
M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.CD*;7-G:60@(E-E;&5C
M="!T:&4@9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHR
M,0IM<V=I9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P.0HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T960@061D<F5S<R!B;V]K<SHB"FUS9W-T
M<B`BT\SAQ\H@Q^':Y,?F[>0@Q^'CSLK'T<F@.B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E
M<G9E<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C`T"B,L(&9U>GIY"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*
M;7-G<W1R("+CVN'FX\?*(,?AX]+FSR(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0S,0IM<V=I9"`B4V5N9"!-97-S86=E(@IM<V=S='(@(L?1T^$@T=/'X<DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S`S"FUS9VED(")396YD(')E
M860@<F5C96EP="!W:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G
M<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS.3<*(RP@9G5Z>GD*;7-G:60@(E-E
M;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`BX\SASR#'X='3Q\;A(,?AX]'3X<F@
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,S@*
M;7-G:60@(E-E;G0@;6%I;"!F;VQD97(Z(@IM<V=S='(@(N/,X<\@Q^'1T\?&
MX2#'X>/1T^')H#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S
M,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$T-@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$U,PIM<V=I9"`B4V5R=F5R(@IM<V=S='(@(L?A
MX]+FSR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VXB"FUS9W-T<B`B
MX]KAYN/'RB#'X>/2YL\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`BQ^'C
MTN;/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@
M<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N
M9"!D96QE=&4@;65S<V%G97,N(@IM<V=S='(@(M;(V"#'X<?/Q\$@X>/'(-/M
MS<_+(-KDS^/'(,K>YN,@R.3>X2#'YB#'X=O'P2`@Q^'1T\?&X2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3970@=&AE(%@M4')I
M;W)I='D@:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*(RP@9G5Z>GD*;7-G
M:60@(E-H87)E($9O;&1E<G,B"FUS9W-T<B`BX\SAS\?*(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C@V"B,L(&9U>GIY"FUS9VED(")3:&%R92!M86EL
M(&9O;&1E<G,B"FUS9W-T<B`BX\SASR#'X='3Q\;A(,?AX]'3X<F@.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M
M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V.0IM<V=I9"`B(@HB4VAO=6QD(&QA
M<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@
M8GD@9&5F875L=#\@270@8V%N(&)E("(*(G1O9V=L960@96%S:6QY('=H:6-H
M979E<B!Y;W4@8VAO;W-E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-PIM<V=I9"`B4VAO=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA
M:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@4$=0(&1A=&$_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L
M9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A
M(&1R869T/R(*;7-G<W1R("+EX2#MS,@@Q]OAQ]X@Y,?=T,D@Q]'3Q^$@Q^'1
MT\?&X2#(VL\@S=W9(,?AX]/FS\?*(+\B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-`IM<V=I9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@
M8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"B,L(&9U
M>GIY"FUS9VED(")3:&]W($%L;"!&;VQD97)S(@IM<V=S='(@(MCM(,SC[=H@
MQ^'CS.'/Q\HB"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV
M-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!M86EL
M8F]X+G!H<#HS-C4*;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R("+:T=8@
MQ^'CX=OM(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*
M;7-G:60@(E-H;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P"B,L(&9U>GIY"FUS9VED
M(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R("+CVN'F
MX\?*(-3.U>W)(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@HC
M+"!F=7IZ>0IM<V=I9"`B4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<R(*
M;7-G<W1R("+'X<?4RM''WR#=[2#'X>/,X<\@*"#'X>/,X<_'RB`I(@H*(SH@
M9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G
M<W1R("+:T=8@V^W1(,?AX]3*T=\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C`X"FUS9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG
M(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`R"FUS9VED(")3:&]W(&QE9V5N
M9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R("+%V>7'T2#.X=WMQ\H@
MQ\O*Q\$@VM'6(-7DS^;>(,?AR-'MSR"_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@T,`IM<V=I9"`B4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE
M<W-A9V5S(&]N;'D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-#@*;7-G:60@(E-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-S<*;7-G:60@
M(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDU"FUS9VED
M(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F:6QT97(@:6-O
M;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C(X"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL
M<R!I;B!F;VQD97(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-C8*;7-G:60@(E-H;W=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G
M:60@(E-I7WIE(@IM<V=S='(@(LW,XR(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VQE9V5N9"YI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(E-I9VYE9"(*;7-G<W1R
M("+-S.,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z
M,PIM<V=I9"`B4VEZ92(*;7-G<W1R("+-S.,B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3;W)T(&)Y($%R
M<FEV86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,C8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@1G)O;2!!9&1R97-S(@IM<V=S
M='(@(N/D(,?AVN3FQ^0B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C0Q"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($UE<W-A
M9V4@4VEZ92(*;7-G<W1R("+-S.,@Q^'1T\?AR2(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@
M(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R("+AQR#MYLS/(./FUN;:(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,0HC+"!F
M=7IZ>0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`BT^'3X<DB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q"B,L
M(&9U>GIY"FUS9VED(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`BX^0@
MQ^':Y.;'Y"(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M,PHC+"!F=7IZ>0IM<V=I9"`B4W!A;2!F;VQD97(Z(@IM<V=S='(@(M/AR2#'
MX>/EX^''RJ`Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,S0V"FUS9VED(")3<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T<B`BT>/FTB#.
MQ]7)(@H*(SH@<V5A<F-H+G!H<#HQ,S,*;7-G:60@(E-P96-I86P@5FER='5A
M;"!&;VQD97)S(&-A;B!N;W0@8F4@961I=&5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#,*;7-G:60@(E-P96QL
M($-H96-K(@IM<V=S='(@(LK/WNW>(,7CX<?&[2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B4W!E;&P@0VAE8VME<B(*
M;7-G<W1R("+CS][>(,?CX<?&[2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@(L?AQ^3*
MY<?!(./D(,?ARL_>[=X@Q^''X^''QNTB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#<Q"FUS9VED(")3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W
M:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R("+:S\\@Q^''SMC'P2#'X<?C
MX<?&[<D@X=_A(-3'U,D@Q\ODQ\$@Q^'*S][MWB#'X<?CX<?&[2XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$R(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV-3(*;7-G:60@(E-T87)T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@
M(E-T871I;VYE<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*;7-G
M:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T<B`BX]'=WB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A:W,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@
M(L?AX^;6YMHB"@HC.B!M97-S86=E+G!H<#HR-C@@=&AR96%D+G!H<#HQ-3`@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A
M<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+'X>/FUN;:(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B4W5B:F5C="!&
M:65L9"(*;7-G<W1R("+-WN$@Q^'CYM;FVB(*"B,Z('-E87)C:"YP:'`Z,S$X
M('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.`HC.B!T96UP
M;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C`@=&5M<&QA=&5S+W!G<"]P
M87-S<&AR87-E+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(L?AX^;6YMHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R("+'
MX<?4RM''WR#=[2#'X>/,X<\@*"#'X>/,X<_'RB`I(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HS.#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@W"FUS9VED(")3
M=6-C97-S(@IM<V=S='(@(N3,Q\TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S='(@(N/>
MRM'-Q\HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8R(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`P('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,PIM<V=I9"`B4W=I=&-H
M($-O;7!O<VET:6]N($UE=&AO9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!(5$U,
M(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O('!L86EN('1E>'0@
M8V]M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#$Y"B,L(&9U>GIY"FUS9VED(")495]X="(*;7-G<W1R
M("+DU2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-CD*;7-G:60@
M(E1E;G1A=&EV93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*
M;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E
M8VEF:65D(&EN(&-O;F8N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R("+D
MU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-30*;7-G:60@(E1H92!&
M<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#HB
M"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,S(*;7-G:60@
M(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R
M="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A
M<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"FUS
M9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N
M(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R
M969S+G!H<#HX,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C
M8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(LKC(,?A
MV\?!(,?AY>;MR2!<(B5S7"(@R.3,Q\TN(@H*(SH@9F5T8VAM86EL<')E9G,N
M<&AP.C<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N
M="!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(LKC(,W=V2#'X>7F
M[<D@7"(E<UPB(,CDS,?-+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C0S"FUS9VED
M(")4:&4@871T86-H;65N="!W87,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CD*;7-G:60@(E1H92!C86QE
M;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I9"`B(@HB
M5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y
M;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I
M;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O
M=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT
M;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I(%PB)7-<
M(B!W:6QL(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("+3YMT@[<KC
M(,K;[>W1(,?3X\?!(,?AX\SASR`HQ^'CS.'/Q\HI(,?AS<?A[<D@7"(E<UPB
M(,?A["!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P-PIM
M<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S
M<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM<V=S
M='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92!<(B5S7"(@9F]L
M9&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3,Y"FUS9VED(")4:&4@979E;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L96YD
M87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI
M;F,Z.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I96QD(%PB
M)7-<(B!C86XG="!B92!E>'!A;F1E9"XB"FUS9W-T<B`BRN,@Q^';Q\$@Q^'E
MYNW)(%PB)7-<(B#(Y,S'S2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E
M>&ES=',B"FUS9W-T<B`BQ^'CS.'/(%PB)7-<(B#CYLSFSR#CT\C>QR(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@9F]L9&5R(%PB)7-<(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@
M:6X@:71S(&YA;64N($ET(&UA>2!C875S92`B"B)P<F]B;&5M<RX@4&QE87-E
M('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+'
MX>/,X<\@7"(E<UPB(.W,RN;M(-KA["#1X^;2(-OMT2#CWLCFX<D@W>T@Q]/C
MY2X@WL\@[<3/[2#0X=\@Q^'L(./4Q]_A("(*(L?AT<S'P2#CT<?,VLD@X\_M
MT2#'X>39Q^,N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4V"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y
M;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`BRN,@Q^34
MQ\$@Q^'CS.'/(%PB)7-<(B#FX=_D(.'C(.W*XR#'U-''W]\@R.4N(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M;VQD97(@7"(E<UPB('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS
M=6)S8W)I8F5D(&9R;VT@:70N(@IM<V=S='(@(LKC(,?AV\?!(,?AX\SASR!<
M(B5S7"(@YN'?Y"#AXR#MRN,@Q^';Q\$@Q]3*T<??WR#(Y2XB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(N'C(.W*XR#'Y-3'P2#'X>/,X<\@7"(E<UPB
M("X@Y=#'(./'(,?=Q\\@R.4@Q^'CTN;/H"(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W
M87,@;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B
M"FUS9W-T<B`BX>,@[<KC(,?AV\?!(,?AX\SASR!<(B5S7"(@+B#ET,<@X\<@
MQ]W'SR#(Y2#'X>/2YL\B"@HC.B!L:6(O1F]L9&5R+G!H<#HS-3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!C<F5A=&5D+B(*;7-G<W1R("+*XR#'Y-3'P2#'X>/,X<\@7"(E<UPB
M(,CDS,?-+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E
M;&5T960N(@IM<V=S='(@(LKC(,?AV\?!(,?AX\SASR!<(B5S7"(@R.3,Q\TN
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T
M;R!<(B5S7"(N(@IM<V=S='(@(LKC(,?:Q\_)(,K3X^W)(,?AX\SASR!<(B5S
M7"(@Q^'L(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z
M.3(*;7-G:60@(E1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T
M;R!T:&ES('!A<G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?<V%V96EM86=E7W=I;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE(&EM
M86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO
M=2!H879E('-E="!Y;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN
M9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.CDW"FUS9VED("(B"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E
M8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@(@HB861D<F5S
M<V)O;VLN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C<U"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F
M;VQL;W=I;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3$*;7-G:60@(E1H92!M86EL
M('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L
M(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.CDP"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H
M92!F;VQL;W=I;F<@;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C8U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UA
M:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B)7,@W<?1VR#C
MT\C>QRXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B
M>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PHC+"!F=7IZ
M>0IM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@
M8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("+*XR#'V^''WB#'X='3Q^')(,?A
MS,?1[2#'Y-3'Q.7'+B`@S,?1[2#'X<[1YLPN(@H*(SH@;65S<V%G92YP:'`Z
M,30X"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("+*XR#'X=O'P2#'X>7F[<D@7"(E<UPB(,CDS,?-+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(LKC
M(,W=V2#'X>7F[<D@7"(E<UPB(,CDS,?-+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S
M86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M
M<&QA=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P
M87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U
M(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD
M;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F('1H92!0
M1U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@(E1H92!R97%U
M97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A
M8VAM96YT+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H
M<#HV-`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T
M(&EN('1H92!::7`@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;65S<V%G
M92YP:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@
M;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E
M(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T
M:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4:&4@<V5R=F5R
M('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I
M;6%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@8V]U;&0@
M;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R("+*VM#1(,K;[>W1(,?ARN;>[=HN
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#(*;7-G:60@
M(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"XB"FUS
M9W-T<B`BRN,@RMOM[=$@Q^'*YM[MVB#(Y,S'S2XB"@HC.B!A='1A8VAM96YT
M+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R("(B"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA
M<R!B965N(&%D9&5D+B(*;7-G<W1R("+*XR#-W=D@Q^'EYNW)(%PB)7-<(B#(
MY,S'S2XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(LKC(,?AV\?!(,?AY>;MR2!<(B5S7"(@R.3,Q\TN
M(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A=&5D
M+B(*;7-G<W1R("+*XR#'X=O'P2#'X>7F[<D@7"(E<UPB(,CDS,?-+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-CD*;7-G:60@(E1H92!T87-K
M(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDU"B,L(&9U>GIY"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92(*;7-G<W1R("+'X=O'P2#1
MT\?AR2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A;B!B
M92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@
M;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@
M<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!F
M=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92(*;7-G
M<W1R("+'VL?/R2#*YLSMY2#ET.4@Q^'1T\?AR2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U
M-`HC+"!F=7IZ>0IM<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T<B`BRN,@RMOM
M[=$@Q^'*YM[MVB#(Y,S'S2XB"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N
M871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I=F4@
M<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z,PIM
M<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"XB
M"FUS9W-T<B`BX<<@RN;,SR#1T\?&X2#=[2#5Y,_FWB#'X<C1[<\N(@H*(SH@
M=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES(&YO('1E>'0@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C8Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9"(*;7-G<W1R("+EY,?AWR#CU-_AR2#DVMCA("5S+B#ET,<@X\<@
MQ]W'SR#(Y2#'X>/2YL\@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E
M>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS
M9W-T<B`BY>3'X=\@X]3?X<D@RMK8X2#5Y,_FWB#'X<C1[<\N(.70QR#CQR#'
MW<?/(,CE(,?AX]+FSZ`Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8R,0IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB
M;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BY>3'
MX=\@X]3?X<D@RMK8X2#5Y,_FWB#'X<C1[<\N(.70QR#CQR#'W<?/(,CE(,?A
MX]+FSZ`B"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE
M<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H
M92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+EY,?AWR#.V,<@W>T@Y-/.(,?A
MT=/'QN$@Q^'L("!<(B5S7"(N(.70QR#CQR#'W<?/(,CE(,?AX]+FSR(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HQ.3@@;&EB+TUE<W-A9V4N<&AP.C(Q,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T("(*(G1H92!S97)V97(@<V%I9"(*;7-G<W1R("+EY,?AWR#.V,,@W>T@
MQ^';Q\$@Q^'1T\?&X2#CY"#'X>/,X<\@(%PB)7-<(BX@Y=#'(./'(,?=Q\\@
MR.4@Q^'CTN;/(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(W-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S
M<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@
M(@HB<V5R=F5R('-A:60B"FUS9W-T<B`BY>3'X=\@SMC#(-WM(,?AV\?!(,?A
MT=/'QN$@W>T@Q^'CS.'/("!<(B5S7"(N(.70QR#CQR#'W<?/("#(Y2#'X>/2
MYL\B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G
M97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@
M(N7DQ^'?(,[8PR#=[2#'X=O'P2#'X='3Q\;A+B#ET,<@X\<@Q]W'SR#(Y2#'
MX>/2YL^@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.CDY"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`BY>3'X=\@SMC'(-WM(-K1
MUB#'X='3Q^')(,?AX]CAYLC)+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I
M;BYP:'`Z-3(@;&EB+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS-PIM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E
M('!A<G0B"FUS9W-T<B`BY>3'X=\@SMC#(-WM(-K1UB#ET,<@Q^',TL$@X^0@
MQ^'1T\?AR2(*"B,Z(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A9V4N
M<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`BY>3'
MX=\@SMC#(-WM(,K:X>WC(,?AT=/'QN$@W>T@Q^'CS.'/(%PB)7-<(BX@Y=#'
M(./'(,?=Q\\@(,CE(,?AX]+FSZ`B"@HC.B!F;VQD97)S+G!H<#HQ-C4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@)7,N(@IM<V=S='(@(L[8PR#=[2#-W=D@X]/FS\DN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M979E;G0Z("5S+B(*;7-G<W1R("+EY,?AWR#.V,<@W>T@VM'6(,?AT=/'X<D@
MQ^'CV.'FR,DN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(N7DQ^'?(,[8QR#=
M[2#:T=8@Q^'1T\?AR2#'X>/8X>;(R2XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF
M;W)M871I;VXZ("5S+B(*;7-G<W1R("+EY,?AWR#.V,,@W>T@Q]'3Q^$@T=/'
MX<K?H#H@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z.#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@
M;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@
M=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(N7DQ^'?(,[8PR#=[2#DWN$@
MQ^'1T\?&X2#'X>P@(%PB)7-<(BX@Y=#'(./'(,?=Q\\@R.4@Q^'CTN;/H"(*
M"B,Z(&-O;7!O<V4N<&AP.C$R-#0*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N(@IM
M<V=S='(@(N7DQ^'?(,[8PR#=[2#:T=8@Y=#'(,?AS-+!(./D(,?AT=/'X<DB
M"@HC.B!C;VUP;W-E+G!H<#HQ,#`V"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS
M9W-T<B`BY>3'X=\@SMC#(-WM(,?1T\?A(-'3Q^'*WZ`Z("5S(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N
M=#H@)7,N(@IM<V=S='(@(N7DQ^'?(,[8PR#=[2#'T=/'X2#1T\?ARM^@.B`E
M<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E('=A<R!N;R!T97AT(&EN('1H:7,@;65S<V%G92!P87)T
M(@IM<V=S='(@(N7DQ^'?(,[8PR#=[2#:T=8@Y=#'(,?AS-+!(./D(,?AT=/'
MX<DB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3<*;7-G:60@(E1H
M:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY,`IM<V=I
M9"`B(@HB5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I
M;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@(@HB=&AI<SH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-@IM<V=I
M9"`B5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ,#0@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q.`HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,30S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ-3<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,R!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,S$T"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3<Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3D*;7-G
M:60@(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,30*
M;7-G:60@(E1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@8V]N=&EN=64_(@IM<V=S='(@(M[/(.W3RMO1WB#ET,<@
MR-K6(,?AYM[*+B`@Y>$@Q^3*(./*Q]_/(./D(-';R,K?(-WM(,?AQ]/*X]''
MT;\B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS
M9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3`*
M;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT
M('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R\B"B)-24U%
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q
M-`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@
M=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B
M"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@
M:6YF;W)M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G
M92!I<R!U;FMN;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HS,34*(RP@9G5Z>GD*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE
M<W-A9V4N($5R<F]R.B`B"FUS9W-T<B`B)7,@X<<@[=GET2#'Y.4@VN3FQ^0@
MR-'MS^T@U<?AS2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR-#`@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S4P"FUS9VED("(B"B)4:&ES(&UE
M<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'
M4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4
M:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R
M96-T(%,O34E-12!F;W)M870N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*
M;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D
M('9I82!01U`N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,30S"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A
M;&QY('-I9VYE9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C(S.`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E
M9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR,#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDQ"FUS9VED
M(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*
M;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S
M<V%G92!T;R(*;7-G<W1R("+ET.4@Q^'1T\?AR2#'X>PB"@HC.B!A8VPN<&AP
M.C0V"FUS9VED(")4:&ES('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I
M;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHQ,#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T
M<B`B[<S((.3/Q\$@Y=#E(,?AY,?=T,D@X^0@Y,?=T,D@Q^34Q\$@Q^'1T\?&
MX2(*"B,Z('1H<F5A9"YP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")4:')E860@
M1&ES<&QA>2(*;7-G<W1R("+:W-'6(@H*(SH@=&AR96%D+G!H<#HW-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(R"FUS9VED(")4:')E860@5FEE=R(*;7-G
M<W1R("+:T=8@RM/AT^'M(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N
M<&AP.C8P-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O
M8V]M<&]S92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS
M9VED(")4;R(*;7-G<W1R("+'X>PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$Y"B,L(&9U>GIY"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(N/D
M(,?AVN3FQ^0B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI
M;&4@(@HB8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@82!43%,@8V]N;F5C=&EO;BP@
M>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@;V8@4$A0(#4N,"XV(&]R
M("(*(FAI9VAE<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-3<W"B,L(&9U>GIY"FUS9VED(")4;W1A;"!!='1A8VAM
M96YT<R!3:7IE.B(*;7-G<W1R("+CT=W>Q\HB"@HC.B!F;VQD97)S+G!H<#HS
M.#@*(RP@9G5Z>GD*;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G<W1R("+3X<D@
MQ^'CY>/AQ\J@.B(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI
M;F,Z,C,*;7-G:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`BT^')(,?AX^7C
MX<?*H#HB"@HC.B!L:6(O475O=&$O8WER=7,N<&AP.C8U(&QI8B]1=6]T82]M
M97)C=7)Y,S(N<&AP.C<Y(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC.B!L
M:6(O475O=&$O;&]G9FEL92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP
M.C4S(&QI8B]1=6]T82]M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O
M(')E=')I979E('%U;W1A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,V"FUS9VED(")5;F%N<W=E<F5D(@IM<V=S='(@(N'C(.W1SR#:X>WEQR(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@(E5N86YS
M=V5R960@;65S<V%G97,B"FUS9W-T<B`BT=/'QN$@X>,@[<KC(,?AT<\@VN'M
MY<<B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B56YD
M96QE=&4B"FUS9W-T<B`BRM''S-H@VN0@Q^''X=O'P2(*"B,Z(&UA:6QB;W@N
M<&AP.C4X.2!M86EL8F]X+G!H<#HV,#(@;&EB+TU)344O2&5A9&5R<RYP:'`Z
M,C$R"FUS9VED(")5;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(N/3
MRN'C[>0@X\[=[>WD(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F
M('1Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V-0IM<V=I
M9"`B56YK;F]W;B!$871E(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!4"!R
M97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,S4*
M;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X
M+G!H<#HV,3@*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@4F5C:7!I96YT(@IM
M<V=S='(@(N/3RN'C[>0@X\[=[>WD(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E5N
M;&]A9"!087-S<&AR87-E(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S
M+G!H<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+AXR#*T^/L(@H*(SH@
M;65S<V%G92YP:'`Z-#DY(&UA:6QB;W@N<&AP.C<P."!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,R"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-0IM<V=I9"`B
M56YS965N(@IM<V=S='(@(N'C(,K1["(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C$R"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O;&1E
M<BAS*2(*;7-G<W1R("+'X=O'P2#'X<?4RM''WR#CY"#CS.'/("CCS.'/Q\HI
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@T"FUS9VED
M(")5<&1A=&4@071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(P"FUS9VED(")5<&1A=&4@
M<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+VEM<&]R=%]K97DN:6YC.C4X('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-38*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0Q"FUS9VED(")5<V4@1&5F
M875L="!686QU92(*;7-G<W1R("+'T\K.S^,@Q^'>[>/)(,?AQ]W*T<?6[<DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED(")5<V4@24U!
M4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T<B`BQ]/*SL_C(,?4RM''
MW\?*(./,X<\@PNT@Q^,@P^T@R.V_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<S-0HC+"!F=7IZ>0IM<V=I9"`B57-E(%9I<G1U86P@5')A<V@@1F]L
M9&5R/R(*;7-G<W1R("+CS.'/(-/AR2#CY>/AQ\H@W<?1V\DB"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,30R"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM
M<V=S='(@(L?3XR#'X>/3RL[/XR(*"B,Z(&%C;"YP:'`Z.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB57-E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(&=I=F5N
M('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-S<*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(L?3XR#'X>/3RL[/XR(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I
M9"`B57-E<FYA;64Z(@IM<V=S='(@(L?3XR#'X>/3RL[/XR(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHV.`HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHR-PHC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")6
M:65W(@IM<V=S='(@(MK1UB`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N
M<&AP.CDR(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("+:T=8@)7,B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(%!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC
M+"!F=7IZ>0IM<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<B"FUS9W-T<B`BQ]'3X2#1T\?AR2#=[2#DQ]W0R2#,S^W/R2"_
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C@*(RP@9G5Z
M>GD*;7-G:60@(E9I97<@365S<V%G97,B"FUS9W-T<B`BT=/'QN$@S,_MS\DB
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R!097)S;VYA;"!0<FEV871E($ME
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE=R!097)S;VYA
M;"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!4
M:')E860B"FUS9W-T<B`BT^'3X<DB"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38U"FUS
M9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!A='1A
M8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(L?1T^$@T=/'
MX<D@W>T@Y,?=T,D@S,_MS\D@OR(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA
M=&5D+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@
M<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(L?1T^$@T=/'X<D@W>T@Y,?=T,D@
MS,_MS\D@OR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#`*;7-G
M:60@(E9I97<@979E;G0B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S@P
M(&UA:6QB;W@N<&AP.C4S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G<W1R("+:T=8@Q^'1T\?&X2#=[2`B
M"@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C(S
M"FUS9VED(")6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I
M;CHB"FUS9W-T<B`BX]GET2#'YB#5Y,_FWB#(T>W/(.'AQ]GEQ]$@R-K/(,?A
MS\[FX:`Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,`HC+"!F
M=7IZ>0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(MK1UB`E<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(E9I
M97<@=&AE($EM86=E<R(*;7-G<W1R("+:T=8@Q^'1T\?&X2#=[2`B"@HC.B!S
M96%R8V@N<&AP.C(V,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FER
M='5A;"!&;VQD97(@7"(E<UPB(&-R96%T960@<W5C8V5S9G5L;'DN(@IM<V=S
M='(@(LKC(,?AV\?!(,?AX\SASR!<(B5S7"(@R.3,Q\TN(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E92YP:'`Z,3,X
M(&QI8B])34%0+U1R964N<&AP.C$U,0HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ
M-3,@;&EB+TE-05`O5')E92YP:'`Z,34W(&QI8B])34%0+U1R964N<&AP.C$U
M.`HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-CD@;&EB+TE-05`O5')E92YP:'`Z
M,SDS(&QI8B])34%0+U1R964N<&AP.C0S,PHC+"!F=7IZ>0IM<V=I9"`B5FER
M='5A;"!&;VQD97)S(@IM<V=S='(@(L7DU,?!(./,X<\B"@HC.B!S96%R8V@N
M<&AP.C(T-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E
M;"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&;VQD97(N<&AP.C$W-2!L:6(O5D9O
M;&1E<BYP:'`Z,3@P"FUS9VED(")6:7)T=6%L($E.0D]8(@IM<V=S='(@(B(*
M"B,Z(&9O;&1E<G,N<&AP.C0Q-@IM<V=I9"`B5FER='5A;"!)3D)/6"!&;VQD
M97(B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-#4R(&QI8B]61F]L9&5R
M+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0IM<V=I9"`B5FER='5A;"!4
M<F%S:"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,3,*(RP@9G5Z>GD*
M;7-G:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(N/,X<\@T^')
M(./EX^''RB#=Q]';R2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M,3,S"FUS9VED(")6:7)T=6%L(&9O;&1E<B!L86)E;"(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W-`IM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R("+*S=#MT2(*"B,Z(&QO9VEN+G!H<#HQ,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+CT<W(QR#(WR#=
M[2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3D*;7-G:60@(B(*
M(E=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T
M:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(W"FUS
M9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@
M>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H96T@
M87,@9&5L971E9#\B"FUS9W-T<B`B(@HBVN3/(,?AV\?!(-'3Q\;A(*$@WN,@
MR.3>X>7'(,?A["#CS.'/(-/AR2#'X>/EX^''RB#(S^''(./D(,K:X>WCY>0@
MW]'3Q\;A("(*(N/AV^W)(+\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`W"FUS9VED(")7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@
M<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@
M<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C8*;7-G:60@
M(B(*(E=H96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N9&EN9R!A9&1R97-S97,L
M('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E;F0@=&\@(@HB=6YQ=6%L:69I
M960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S97,@=VET:&]U="!<(D!<(BD_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM
M<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C4T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<X
M"FUS9VED(")997,B"FUS9W-T<B`BY-KC(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&%R92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I
M;F<@86-C;W5N="AS*3HB"FUS9W-T<B`BQ^3?(,K-Q^;A(,?AV\?!(,?AX\SA
MS\?*(,?ARL?A[<F@.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?
M8V]N9FER;2YH=&UL.C$P"B,L(&9U>GIY"FUS9VED("(B"B)9;W4@87)E(&%T
M=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@
M=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@(L?DWR#*S<?F
MX2#'X=O'P2#'X>/,X<_'RB#'X<K'X>W)H#HB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HY"B,L(&9U>GIY"FUS9VED(")9
M;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F;VQL;W=I;F<@9F]L
M9&5R*',I+B(*;7-G<W1R("+'Y-\@RLW'YN$@Q^';Q\$@Q^'CS.'/Q\H@Q^'*
MQ^'MR:`Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z
M-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED
M(")9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS
M9W-T<B`BQ^3?(,KDT\XORN3>X2#'X>P@X\SASR#,S^W/+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R"FUS9VED(")9;W4@87)E
M(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`BQ^3?(,K6[=T@
MX\SASR#=T=KM(,?A["`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$P-`IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E
M;"!F;VQD97(N(@IM<V=S='(@(L?DWR#*Y-3MP2#CS.'/(,?3Q]/M+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C,R,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@9F]L9&5R<RXB"FUS9W-T<B`BQ^3?(,KD
MU.W!(./,X<\@Q]/'T^TN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(W"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-0IM<V=I9"`B66]U(&%R92!R
M96YA;6EN9R!T:&4@9F]L9&5R.B`B"FUS9W-T<B`BQ^3?(,K:[<\@RM/C[<D@
MQ^'CS.'/H#H@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M
M(%PB)7-<(BXB"FUS9W-T<B`BRN,@Q^';Q\$@Q]3*T<??WR#(Y,S'S2#CY"!<
M(B5S7"(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@=&AE(&9O;&QO
M=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X=#H@)6,@
M9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R('1H
M92!S:6=N871U<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W1O<U]A9W)E96UE;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED(&YO
M="!A9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O
M('EO=2!W97)E(&YO="!A;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Y"FUS9VED(")9;W4@9&\@
M;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@
M9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O<G=A<F1E9"!T:&ES(&UE<W-A9V4@
M;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!H879E("5S(&YE=R!M97-S86=E<RXB"FUS
M9W-T<B`BRN;,SR#AS^W?("5S(-'3Q^')(,S/[<_)+B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED(")9;W4@:&%V92`Q(&YE=R!M
M97-S86=E+B(*;7-G<W1R("+AS^W?(-'3Q^')(.;'S<_)(,S/[<_)+B(*"B,Z
M(&-O;7!O<V4N<&AP.C0Y-`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@86QR
M96%D>2!S=6)M:71T960@=&AI<R!P86=E+B(*;7-G<W1R("+AS^W?(-'3Q^')
M(.;'S<_)(,S/[<_)+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA=F4@870@;&5A<W0@;VYE(&%T
M=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T('5P;&]A9"!Y970N
M($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD('1H:7,@;65S<V%G
M92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S/R(*;7-G<W1R("(B"@HC.B!L
M:6(O24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T
M:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`BX<_MWR#(T>W/(,S/[<\@
MW>T@Q^'CS.'/(,?ARL?A[:`Z(@H*(SH@;&EB+TE-4"YP:'`Z,3`W.0IM<V=I
M9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S
M.B(*;7-G<W1R("+AS^W?(,C1[<\@S,_MSR#=[2#'X>/,X<_'RB#'X<K'X>W)
MH#HB"@HC.B!C;VUP;W-E+G!H<#HQ-3,*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N(@IM<V=S='(@(NW,
MR"#'Y"#MW^;D(.'/[=\@X]/*WLCA(.;'S<\@VN'L("#'X<?>X2XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HS,#(*;7-G:60@(B(*(EEO=2!M=7-T
M(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME
M>2!T;R!V:65W('1H:7,@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(T.0IM<V=I9"`B(@HB66]U(&UU<W0@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y
M('1O('9I97<@=&AI<R`B"B)M97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C8T('1E;7!L871E<R]M86EL
M8F]X+VIA=F%S8W)I<'0N:6YC.C(P,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T
M(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM<V=S='(@(NW,R"#'Y"#*SLK'
MT2#5Y,_FWB#'X<C1[<\@Q^'ES]T@Q^;AQRXB"@HC.B!F971C:&UA:6QP<F5F
M<RYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A
M8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S='(@(NW,R"#'Y"#*SLK'T2#E
MYNW)(.'MRN,@Q^';Q\3EQRXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C@Q"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S
M<R!F:7)S="XB"FUS9W-T<B`B[<S((,?D(,K.RL?1(-KDYL?D(,?FX<<N(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R("+MS,@@
MQ^0@RL[*Q]$@T=/'X<D@YL?-S\D@VN'L(,?AQ][A+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,PIM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!A(')E8VEP:65N="XB"FUS9W-T<B`B[<S((,K-S^W/(./3RN'C+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C(Y"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!F:6QE
M('1O(&%T=&%C:"XB"FUS9W-T<B`B[<S((,?FX<<@RLW/[<\@Q^'CX=T@Q^'C
MT<?/(,?AT=W'WN4N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C0X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@
M7"(E<UPB(&5N86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@
M=&\@)7,@;VX@)25S+B(*;7-G<W1R("+'VL?/R2#*YLSMY2#ET.4@Q^'1T\?A
MR2(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EEO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RXB
M"FUS9W-T<B`BQ]K'S\D@RN;,[>4@Y=#E(,?AT=/'X<DB"@HC.B!L:6(O1F]L
M9&5R+G!H<#HU,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T
M('-U8G-C<FEB960@=&\@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E
M<B!S86ED(@IM<V=S='(@(N'C(,K?Y"#CU,K1W\<@R-P@7"(E<UPB+B#ET,<@
MX\<@Q]W'SR#(Y2#'X>/2YL^@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34Y"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E(&YO="!U;G-U8G-C<FEB960@
M9G)O;2!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS
M9W-T<B`BX>,@[<KC(,?AV\?!(,?4RM''W]\@X^0@(%PB)7-<(BX@(.70QR#C
MQR#'W<?/(,CE(,?AX]+FSZ`B"@HC.B!L:6(O1F]L9&5R+G!H<#HU,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('-U8G-C
M<FEB960@=&\@7"(E<UPB(@IM<V=S='(@(LKC(,?4T<??WR#(Y,S'S2#=[2`@
M7"(E<UPB(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-38R"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O
M;2!<(B5S7"(B"FUS9W-T<B`BRN,@Q^';Q\$@Q]3*T<??WR#(Y,S'S2#CY"!<
M(B5S7"(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.3@*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("+'T^/?(,?AW\?CX:`Z(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4P"FUS9VED(")9;W5R(%!'4"!0=6)L
M:6,O4')I=F%T92!+97ES(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-S$@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<V"FUS9VED
M(")9;W5R(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<Q"B,L
M(&9U>GIY"FUS9VED(")9;W5R(%!U8FQI8R!+97DB"FUS9W-T<B`BQ]/CWR#'
MX=_'X^&@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C4*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N
M86PI/"]E;3XB"FUS9W-T<B`BVN3FQ^0@.B#'X='/(,?A[*`Z(#QI/BC'SLKM
MQ]'M*3PO:3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS
M9VED(")9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E
M;&5C="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM
M<V=S='(@(N7F[<?*WZ`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W
M,PIM<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N
M86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDR"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I
M;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(N''
M(.W/VN,@X\K5W<W?(,?AVM'6(,?AS\?.X>T@X>70QR#'X>3FVB#CY"#'X=7F
MT2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,SD*;7-G:60@(EEO=7(@
M9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O96YC<GEP='-E;&5C="YI;F,Z,0IM
M<V=I9"`B66]U<B!D969A=6QT(&5N8W)Y<'1I;VX@;65T:&]D(&9O<B!S96YD
M:6YG(&UE<W-A9V5S.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!M97-S86=E('=A
M<R!S=6-C97-S9G5L;'D@9&5L:79E<F5D+B(*;7-G<W1R("+*XR#'X=O'P2#'
MX>/,X<\@7"(E<UPB(,CDS,?-+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,#8*;7-G:60@(EEO=7(@<VEG;F%T=7)E.B(*;7-G<W1R("+*YM[MVM^@
M.B(*"B,Z(&UE<W-A9V4N<&AP.C(X."!C;VUP;W-E+G!H<#HQ,C@T(&UA:6QB
M;W@N<&AP.C4T.2!L:6(O0V]M<&]S92YP:'`Z.#$X"FUS9VED(");3F\@4W5B
M:F5C=%TB"FUS9W-T<B`B6^''(.WFS,\@X^;6YMI=(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,L(&9U>GIY"FUS9VED(")?0F-C
M(@IM<V=S='(@(N/1W=X@X\[=[2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R("+'
MX=['QN/)(,?AT^;/Q\$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHQ-30*(RP@9G5Z>GD*;7-G:60@(E]#8R(*;7-G<W1R("+DT\[)(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92(*
M;7-G<W1R("+'X=O'P2(*"B,Z(&QI8B])35`N<&AP.CDW.0HC+"!F=7IZ>0IM
M<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`BX\SAS\?*(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z.#$*(RP@9G5Z>GD*;7-G:60@(E])9&5N
M=&ET>2(*;7-G<W1R("+EYNW)(@H*(SH@;&EB+TE-4"YP:'`Z.38Q"FUS9VED
M(")?26YB;W@B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`R,`HC+"!F
M=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BSM'FS"(*"B,Z(&UE<W-A
M9V4N<&AP.C,X-`HC+"!F=7IZ>0IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM
M<V=S='(@(N/?YN3'RB#'X='3Q^')(@H*(SH@;&EB+TE-4"YP:'`Z.3<V"B,L
M(&9U>GIY"FUS9VED(")?3F5W($UE<W-A9V4B"FUS9W-T<B`BT=/'QN$@S,_M
MS\DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,S,*(RP@9G5Z>GD*;7-G:60@(E]0<FEN="(*;7-G<W1R("+8R,?:R2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.#D*;7-G:60@(E]0<FEO<FET>2(*;7-G
M<W1R("(B"@HC.B!M86EL8F]X+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@(L?DVL?4(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*(RP@9G5Z>GD*
M;7-G:60@(E]297!L>2(*;7-G<W1R("+'X='/(@H*(SH@;&EB+TE-4"YP:'`Z
M.3@Q"B,L(&9U>GIY"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(LC-RR(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0HC+"!F=7IZ>0IM<V=I9"`B7U-E;F0@
M365S<V%G92(*;7-G<W1R("+'T=/A(-'3Q^')(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,@HC+"!F=7IZ>0IM<V=I9"`B
M7U1H<F5A9"(*;7-G<W1R("+3X=/AR2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B7U1O(@IM<V=S='(@
M(L?A["(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"B,L
M(&9U>GIY"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`BRM''S-H@VN0@Q^''
MX=O'P2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S='(@(M/A
MT^')(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")?
M5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S8*
M;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HT-#`*(RP@9G5Z>GD*;7-G:60@(F%T=&%C:&UE;G0B"FUS
M9W-T<B`BX]'=WB(*"B,Z('9I97<N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")A
M='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`BX]'=WL?*(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B>71E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`P"FUS9VED(")C86YN;W0@8W)E
M871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ-S(*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ-C0*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G
M92!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(P"FUS
M9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.38*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI
M<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V.`IM<V=I
M9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C(R-`IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED
M(")F<F]M(@IM<V=S='(@(N/D(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X,`IM
M<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C(P-`IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#@*;7-G:60@(FEN=&5R;F%L
M('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR.2!P
M9W`N<&AP.C8Y"FUS9VED(")K97DB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP
M:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")M86EL8F]X(&9I;&4B"FUS9W-T<B`B
MU>3/YMX@Q^'(T>W/(@H*(SH@8V]M<&]S92YP:'`Z,3`V-R!L:6(O365S<V%G
M92YP:'`Z-#8V"B,L(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@(L?AQ]/C
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<V"FUS9VED
M(")N;VYE(@IM<V=S='(@(N''(-3MP2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(F]R(@IM<V=S='(@(L/F(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C(Q-@IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q,@IM<V=I9"`B<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ.#0*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS
M9VED(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R("+.V,,@Q^/AQ\;M(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L
M;&EN9R!E<G)O<G,B"FUS9W-T<B`BQ\[8Q\$@Q^/AQ\;MR2(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R("+.V,,@Q^/AQ\;M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P.`IM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I
M;'1E<BYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM
M<V=S='(@(L?AWL?&X\D@Q^'3YL_'P2(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q
M"FUS9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R("(B"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+V%R7U-9+G!O````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,U,S4V-P`Q,#0Q
M-S,V,C<V-``P,3<R,C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!)35`@,RXR+C$@07)A8FEC('1R86YS;&%T:6]N"B,@
M0V]P>7)I9VAT("A#*2`R,#`S(%!L871I;G5M($EN8RX@/'!L0'1I;G5M+FEN
M9F\^"B,@0W5S=&]M(%=E8B!!<'!L:6-A=&EO;G,@/&AT='`Z+R]P;&%T:6YU
M;2US>2YC;VT^"B,@4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;2`\9&5V=&5A
M;4!P;&%T:6YU;2US>2YN970^"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($E-4"!V,RXR+C%<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`S+3`T+3,P(#$R.C`P*S`R,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;2`\9&5V=&5A;4!P;&%T:6YU
M;2US>2YN970^7&XB"B),86YG=6%G92U496%M.B!!<F%B:6,@/&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E
M;G0M5'EP93H@=&5X="]H=&UL.R!C:&%R<V5T/4-0,3(U-EQN(@HB0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z("(*;7-G<W1R("(@
M("`@("#%X>R@.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$U"FUS9VED("(@
M("`@("!4;SH@(@IM<V=S='(@(B`@("`@(,7A[*`Z("(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HT,#,*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@Q^'*
MQ]'MSCH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P-@IM<V=I9"`B("`@($9R
M;VTZ("(*;7-G<W1R("(@("`@(./DH#H@(@H*(SH@;6%I;&)O>"YP:'`Z-#(R
M('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HT,3(*;7-G:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B("#'X>/F
MUN;:H#H@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<P
M"FUS9VED("(@:6X@(@IM<V=S='(@(B#=[2`B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@
M(M'>XR(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HV.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@
M(B(*"B,Z('1H<F5A9"YP:'`Z,34Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!-97-S86=E<R(*;7-G<W1R("(E9"#CY"`E9"#1T\?AR2(*"B,Z
M(&UA:6QB;W@N<&AP.C$W-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M)60@;65S<V%G97,@:&%V92!B965N(&1E;&5T960N(@IM<V=S='(@(LKC(,7A
MV\?!(,?AY>;MR2!<(B5S7"(@R.3,Q\TN(@H*(SH@;&EB+U-P86TN<&AP.C$W
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)60@;65S<V%G97,@
M:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(LKC(,K>S^WC(,K>T>W1(,CET.4@
MQ^'1T\?AR2#?T=/'X<D@V^W1(./1V^;((,CEQR#%X>P@X\_MT2#'X>39Q^,N
M(@H*(SH@;&EB+U-P86TN<&AP.C$U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S
M<&%M+B(*;7-G<W1R("+*XR#*WL_MXR#*WM'MT2#(Y=#E(,?AT=/'X<D@W]'3
MQ^')(-OMT2#CT=OFR"#(Y<<@Q>'L(.//[=$@Q^'DV<?C+B(*"B,Z(&QI8B]3
M<&%M+G!H<#HQ-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE
M<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(LKC(,K>S^WC(,K>T>W1(,CE
MT.4@Q^'1T\?AR2#?T=/'X<D@V^W1(./1V^;((,CEQR#%X>P@X\_MT2#'X>39
MQ^,N(@H*(SH@;&EB+U-P86TN<&AP.C$U,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P
M86TN(@IM<V=S='(@(LKC(,K>S^WC(,K>T>W1(,CET.4@Q^'1T\?AR2#?T=/'
MX<D@V^W1(./1V^;((,CEQR#%X>P@X\_MT2#'X>39Q^,N(@H*(SH@;6%I;&)O
M>"YP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D
M($UE<W-A9V5S(@IM<V=S='(@(B5D(,7A["`E9"#CY"`E9"#1T\?AR2(*"B,Z
M(&UA:6QB;W@N<&AP.C8T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N
M=&UA:6Q?;6]N=&AL>2YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE
M9"XB"FUS9W-T<B`B)7,@X^;,YL_)(./3R-['+B#CS.'/("5S(.'C(.W*XR#*
MV^WMT>4N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!M86EL
M8F]X+B(*;7-G<W1R("(E<R#AQR#MV>71(,?DY2#:Y.;'Y"#(T>W/[2#5Q^'-
M+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@
M8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G
M<W1R("+*XR#*V^WMT2##T^/'P2`@)7,@X\SASR#:Y,\@R,_'[<D@Q^'4Y=$N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!H87,@9&5C;&EN960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E
M<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT
M871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U
M97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O(%PB
M)7-<(BXB"FUS9W-T<B`BRN,@Q=K'S\D@RM/C[<D@Q^'CS.'/(%PB)7-<(B#%
MX>P@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N9"`E<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A
M<F4@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(')E
M8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RXB"FUS9W-T
M<B`B(@H*(SH@;65S<V%G92YP:'`Z,C@U(&UE<W-A9V4N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7W1O<"YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,Z("5S("@E9"9N8G-P.V]F)FYB<W`[)60I(@IM<V=S='(@(B5S
M.B`E<R`H)60F;F)S<#MD929N8G-P.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N
M9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BDB"FUS9W-T<B`B*-C(WB#E
MT.4@Q^'*V^WMT<?*(.;'Y,K>X2#%X>P@Q^'4Q]3)(,?ARL?A[<DN*2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`*;7-G:60@(BA$
M:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@
M<V-R965N+BDB"FUS9W-T<B`B*-[C(,C%X=O'P2#,X^W:(,?ARMOM[=''RB#F
MVL\@Q>'L(-3'U,D@Q^'%T=/'X2DB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I
M;B!497AT*2(*;7-G<W1R("(B"@HC.B!S<&5L;&EN9RYP:'`Z,C@P"FUS9VED
M("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E<B!A<'!L
M>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@(@HB0VAA;F=E<R!O
M;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM
M<V=S='(@(B(*(BC:SR#%X>P@U,?4R2#'X<71T\?A(,C:SR#*V,CMWB#,X^W:
M(,?ARMOM[=''RB#'X>//T<S)(,W*["#'X<+D+B#AY"#MRN,@RMC([=X@(@HB
MQ^'*V^WMT<?*(-KA["#'X=3'U,D@Q^'-Q^'MR2XI(@H*(SH@<W!E;&QI;F<N
M<&AP.C(W-PHC+"!F=7IZ>0IM<V=I9"`B(@HB*%-E;F0@;65S<V%G92!A9G1E
M<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E
M<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE
M9"XI(@IM<V=S='(@(B(*(BC:SR#%X>P@U,?4R2#'X<71T\?A(,C:SR#*V,CM
MWB#,X^W:(,?ARMOM[=''RB#'X>//T<S)(,W*["#'X<+D+B#AY"#MRN,@RMC(
M[=X@(@HBQ^'*V^WMT<?*(-KA["#'X=3'U,D@Q^'-Q^'MR2XI(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@(BH@061D
M('1H97-E(&)Y(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B##UMT@Y=#E(,C'
MX=;;V"#:X>P@TM$@Y-KC("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H
M97,I("HB"FUS9W-T<B`B*B#MT<SL(,?.RNW'T2#'X=KDYL?D("@@Q^':Y,?F
M[>0@*2`N("HB"@HC.B!M86EL8F]X+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@
M(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+*XR#%X=O'
MP2#'X>7F[<D@7"(E<UPB(,CDS,?-+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*
M(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("+*XR#*WL_MXR#*WM'MT2#(Y=#E(,?AT=/'X<D@W]'3Q^')(-OMT2#C
MT=OFR"#(Y<<@Q>'L(.//[=$@Q^'DV<?C+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ
M-C`*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`BRN,@RM[/[>,@RM[1[=$@R.70Y2#'
MX='3Q^')(-_1T\?AR2#;[=$@X]';YL@@R.7'(,7A["#CS^W1(,?AY-G'XRXB
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<R"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A
M9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("+*XR#*WL_MXR#*WM'MT2#(Y=#E(,?A
MT=/'X<D@W]'3Q^')(-OMT2#CT=OFR"#(Y<<@Q>'L(.//[=$@Q^'DV<?C+B(*
M"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G
M92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("+*XR#*WL_M
MXR#*WM'MT2#(Y=#E(,?AT=/'X<D@W]'3Q^')(-OMT2#CT=OFR"#(Y<<@Q>'L
M(.//[=$@Q^'DV<?C+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*
M(RP@9G5Z>GD*;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(M'CYM(@
MSL?5R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C(*(RP@9G5Z>GD*
M;7-G:60@(C$P,#`@8VAA<F%C=&5R<R(*;7-G<W1R("+1X^;2(,['U<DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(P"B,L(&9U>GIY"FUS9VED("(R
M-3`@8VAA<F%C=&5R<R(*;7-G<W1R("+1X^;2(,['U<DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#(Q"B,L(&9U>GIY"FUS9VED("(U,#`@8VAA<F%C
M=&5R<R(*;7-G<W1R("+1X^;2(,['U<DB"@HC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HQ-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B02!L87)G92!I
M;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP
M.C4P"FUS9VED("(B"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H87,@<F5S
M=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE("(*(G)E
M8VEP:65N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L
M9',N:6YC.C4*;7-G:60@(D%.1"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3DP"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W"FUS9VED
M(")!8V-E<'0@<F5Q=65S="!A;F0@861D(&ET('1O(&UY(&-A;&5N9&%R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3,*;7-G
M:60@(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HR-3<*;7-G:60@(D%C8V5P=&5D.B`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*(RP@9G5Z>GD*;7-G
M:60@(D%C8V]U;G0G<R!N86UE.B(*;7-G<W1R("+#T^/'P2#'X>/:T=W'RB`Z
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,"!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S,P"B,L(&9U>GIY"FUS9VED(")!8W1I;VYS(@IM
M<V=S='(@(L7,T<?!(@H*(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C`P(&QI
M8B]-24U%+TAE861E<G,N<&AP.C(P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B061D("5S('1O(&UY($%D9')E<W,@0F]O:R(*;7-G<W1R("+#UMT@
MQ>'L(-/,X2#'X=KDQ^;MY"`H)7,I(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,S`S"B,L(&9U>GIY"FUS9VED(")!9&0@<V]U<F-E
M(@IM<V=S='(@(L/6W2#'X>/5S]$B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@
M(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;7!O
M<V4N<&AP.C$R-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D
M(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("+#UMT@X]'=WL?*
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3@*;7-G:60@(B(*(D%D
M9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M
M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@;&EN
M92D\+V5M/B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L
M(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L(&9U>GIY
M"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS9W-T
M<B`BX]KAYN/'RB#4SM7MR2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.CDS"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C
M86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R
M<F]R(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M
M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3(*;7-G
M:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+3S.$@Q^':Y,?F[>0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED(")!9&1R
M97-S($)O;VMS(@IM<V=S='(@(M/,X2#'X=KDQ^;MY"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.#D*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!"0T,@
M86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E
M<W,@;VX@82!N97<@(@HB;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S97,@=&\@
M97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA
M;"P@96YT97(@96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")!;&PB"FUS9W-T
M<B`BQ^',X^W:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ,PIM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I;F<@
M9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8("(*
M(F9I;&4Z(@IM<V=S='(@(B(*(LSC[=H@Q^'1T\?&X2#'X>/FS.;/R2#=[2#'
MX>/,X<\@*,?AX\SAS\?**2#'X<K'X>W)(-/FW2#MRN,@RLWC[>'EQR#=[2#5
MY,_FWB`B"B+FQ\W/(,?AU>3/YMZ@.B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W!U<F=E7W1R87-H+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!;&P@;65S<V%G97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H
M86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N(@IM
M<V=S='(@(M_A(,?AT=/'QN$@W>T@X\SASR!<(B5S7"(@Q^'#WL_C(./D("5S
M(.WFXR#3YMT@[<KC(,C4W^$@S\?&X\7AV\?$Y<<N(@H*(SH@;&EB+TUA:6YT
M96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP.C4Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A
M='1A8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E
M;&5T960N(@IM<V=S='(@(M_A(./,X<_'RB#'X='3Q\;A(,?AX]'3X<D@Q^'#
MWL_C(./D("`E<R#4Y=''(-/FW2#*X=OL("(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HW,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@
M=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B
MW^$@X\SAS\?*(,?AT=/'QN$@Q^'CT=/AR2#'X</>S^,@X^0@("5S(-3ET<<@
MT^;=(,KAV^P@(@H*(SH@86-L+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B06QL(')I9VAT<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F
M=6QL>2!R96UO=F5D(&9O<B!U<V5R(%PB)7-<(BXB"FUS9W-T<B`BRN,@Q=K'
MS\D@RM/C[<D@Q^'CS.'/(%PB)7-<(B#%X>P@7"(E<UPB+B(*"B,Z(&QI8B]A
M<&DN<&AP.C<V"FUS9VED(")!;&QO=R!&;VQD97(@0W)E871I;VX_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I
M9"`B06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA
M:6QB;W@_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA
M=&EV92YP:'`Z,3$P"FUS9VED(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI
M<R!S96-T:6]N.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3<R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#0*;7-G:60@(D%L=V%Y
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34W"B,L
M(&9U>GIY"FUS9VED(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R
M("+#UMT@X]'=WL?*+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HU,#4*;7-G:60@
M(B(*(D%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I
M<"!T:&4@871T86-H;65N="X@5&AE($E-05`@<V5R=F5R("(*(G-A:60Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY"FUS
M9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@
M=&AE(&YE=R!N;W1E+B(*;7-G<W1R("+.V,,@V^W1(./:T>;=(,/+Y,?!(,76
MQ]W)(,?AQ<_.Q^''RB#'X<S/[<_)+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS
M.#<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W
M:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(L[8PR#;[=$@
MX]K1YMT@P\ODQ\$@Q=;'W<D@Q^'%S\['X<?*(,?AS,_MS\DN(@H*(SH@;65S
M<V%G92YP:'`Z-3`P(&UA:6QB;W@N<&AP.C<Q-"!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,U
M"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-@IM<V=I9"`B06YS
M=V5R960B"FUS9W-T<B`BRN,@Q^'1SR#:X>WEQR(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM
M<V=S='(@(L?AT=/'QN$@Q^'*[2#*XR#'X='/(-KA[>7'(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY"FUS9VED(")!<'!L
M>2!&:6QT97)S(@IM<V=S='(@(M[C(,C*V,CMWB#'X>/1U,W'RB#:X>PB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`B
MWN,@R,K8R.W>(,?AX]'4S<?*(-KA["(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHS-@IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P;VX@
M;&]G9VEN9R!O;C\B"FUS9W-T<B`B(-[C(,C*V,CMWB#'X>/1U,W'RB##R^3'
MP2#'X<_.YN$@OR(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT
M,@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R
M($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS9W-T<B`BWN,@R,K8R.W>(,?AX]'4
MS<?*(,/+Y,?!(,K-S^W+(,?AU>3/YMX@Q^'(T>W/[2(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W
M"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L
M971E('1H:7,@<'5B;&EC(&ME>3\B"FUS9W-T<B`BRL/?[<\@Q^''T\KCT<?1
M(+\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O
M;6UE;F1E9"$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_(@IM<V=S
M='(@(LK#W^W/(,?AQ]/*X]''T2"_(@H*(SH@;65S<V%G92YP:'`Z-#`W('1E
M;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8X"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H97-E
M(&UE<W-A9V5S/R(*;7-G<W1R("(@RL/?[<\@Q^''T\KCT<?1(.;%X=O'P2#E
MT.4@Q^'1T\?&X2#(U-_A(.3EQ\;M(+\B"@HC.B!L:6(O34E-12]#;VYT96YT
M<RYP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS
M9W-T<B`B(,K#W^W/(,?AQ]/*X]''T2#FQ>';Q\$@Y=#E(,?AT=/'QN$@R-3?
MX2#DY<?&[2"_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES
M(&9O;&1E<C\B"FUS9W-T<B`B(,K#W^W/(,?AQ]/*X]''T2#FQ=W1Q]L@Y=#'
M(,?AX\SASR"_(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O
M;&1E<C\B"FUS9W-T<B`B(,K#W^W/(,?AQ]/*X]''T2#FQ=W1Q]L@X\SASR#3
MX<D@Q^'CY>/AQ\H@OR(*"B,Z(&QI8B])35`N<&AP.CDV-@IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@=')A<V@@9F]L9&5R
M/R(*;7-G<W1R("(@RL/?[<\@Q^''T\KCT<?1(.;%W=''VR#CS.'/(-/AR2#'
MX>/EX^''RB"_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M.`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O('!E
M<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`B(,K#
MW^W/(,?AQ]/*X]''T2#FQ>';Q\$@Y=#E(,?AT=/'QN$@R-3?X2#DY<?&[2"_
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*(RP@9G5Z>GD*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S
M86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R("(@RL/?[<\@Q^''T\KCT<?1(.;%
MW=''VR#ET,<@Q^'CS.'/(+\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A
M<V-R:7!T+FEN8SHW-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHW-`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\B"FUS9W-T<B`B(,K#W^W/
M(,?AQ]/*X]''T2#FQ=W1Q]L@Y=#'(,?AX\SASR"_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDQ-@IM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S='(@
M(N;>RB#'X>;5YN$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS
M9VED(")!<V-E;F1I;F<B"FUS9W-T<B`BRM7'VL_M(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4W,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@S"FUS
M9VED(")!<VLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-3$Y"FUS9VED(")!='1A8V@B"FUS9W-T<B`BQ='=Q]XB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S4*(RP@9G5Z>GD*
M;7-G:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R("+CT=W>Q\HB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-38*;7-G:60@(D%T=&%C:"!A
M(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#D*
M(RP@9G5Z>GD*;7-G:60@(D%T=&%C:&5D($9I;&4Z(@IM<V=S='(@(L71W<?>
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0U,2!L:6(O0V]M<&]S92YP:'`Z-3,V
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%T=&%C:&5D(&9I;&4@7"(E<UPB
M(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4
M(&%T=&%C:&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,S<V"FUS9VED(")!='1A8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L
M96YD87(@<F5Q=65S="!Y;W4@<V5N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYI;F,Z,30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-3`V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDW
M"FUS9VED(")!='1A8VAM96YT(@IM<V=S='(@(N/1W=XB"@HC.B!C;VUP;W-E
M+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*;7-G:60@(D%T=&%C:&UE
M;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#D@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<S"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ,#<S"FUS9VED(")!='1A8VAM96YT<R(*;7-G<W1R("+CT=W>Q\HB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@R"B,L(&9U>GIY"FUS
M9VED(")!='1E;F1E97,B"FUS9W-T<B`BX]'=WL?*(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D%T
M=&5N=&EO;B(*;7-G<W1R("+%S-''P2(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z
M-#0*;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-#`*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@
M2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D
M<F5S<V)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R
M8V5S96QE8W0N:6YC.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B079A:6QA8FQE($%D
M9')E<W,@8F]O:W,Z(@IM<V=S='(@(M/,X<?*(,?ATN;'T2#'X>/*YMW1R2`Z
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q.0IM<V=I9"`B07=A
M:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`BQ^':YL_)(,7A["`E<R(*
M"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E
M<R(*;7-G<W1R("+'X=KFS\D@Q>'L("5S(@H*(SH@=&AR96%D+G!H<#HQ,S0*
M;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN9&5X(@IM
M<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,R"FUS9VED(")"86-K('1O(%1H
M<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP
M:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M960@
M<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@
M;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G<W1R("+CT=W>(./.
MW>TB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@
M(D)E;&]W(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T
M:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(L?AWL?&X\D@
MQ^'3YL_'P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,CD*;7-G:60@
M(D)L;V-K(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R
M92!S<&5C:69I8V%L;'D@<F5Q=65S=&5D/R(*;7-G<W1R("(B"@HC.B!L:6(O
M4V5A<F-H+G!H<#HT,@IM<V=I9"`B0F]D>2(*;7-G<W1R("+'X>35(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G
M<W1R("+'X<?+Y,?D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-PIM
M<V=I9"`B0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(W,@HC+"!F=7IZ>0IM<V=I9"`B0U]H87)S970B"FUS9W-T<B`BRM'C[=(@
M34%#(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED
M(")#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@
M;6%I;"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T
M92!M86EL('-E<G9E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#86X@
M;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H
M:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R
M("(B"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN
M8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@
M=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z
M,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B
M0V%N8V5L(@IM<V=S='(@(L7AV\?!(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-S$@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#,U"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3$*;7-G
M:60@(D-A;F-E;"!-97-S86=E(@IM<V=S='(@(L7AV\?!(,?AT=/'X<DB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FIS.C8*(RP@9G5Z>GD*;7-G:60@(D-A;F-E;&QI
M;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@
M8V]N=&5N=',N(@IM<V=S='(@(L7AV\?!(.70Y2#'X='3Q^')(-/FW2#MQ,_M
M(,KAWL?&[<<@Q>'L(,K/X^W1(./-RN;MQ\KEQRXB"@HC.B!M97-S86=E+G!H
M<#HR-C4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C$*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ-2!L:6(O4V5A<F-H
M+G!H<#HS,`IM<V=I9"`B0V,B"FUS9W-T<B`BY-/.R2(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G:60@(B(*(D-E<G1I9FEC871E(&EM
M<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA
M8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<P,0HC+"!F=7IZ>0IM<V=I9"`B0VAA:7(@
M4&5R<V]N(@IM<V=S='(@(M3.U>TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R("+*V^WMT2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I9"`B
M0VAA;F=E($%L;"(*;7-G<W1R("+*V^WMT2#'X<SC[=HB"@HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!&;VQD
M97(B"FUS9W-T<B`BQ>34Q\$@X\SASR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3(*;7-G:60@(B(*(D-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C
M:"!A<R!H;W<@;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A
M;F0@(@HB:&]W(&UE<W-A9V5S(&%R92!S;W)T960N(@IM<V=S='(@(B(*(LK;
M[>W1(,[MQ]''RB#'X=K1UB#CR^$@VL_/(,?AT=/'QN$@Q^'CVM'FULD@W>T@
MW^$@U=W-R2#F("#?[=WMR2#=Y='3R2`B"B+'X='3Q\;A+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-`HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(&UA
M:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@(LK;[>W1
M(-;FQ\C8(./2YL\@Q^'(T>W/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S
M:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"`B
M"B)R97!L>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R("+*V^WMT2#'X<?3XZ$@
MQ^':Y.;'Y""A(.8@Q^'*YM[MVB#MT<_FY"#:X>P@T=/'QN'?+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C0*;7-G:60@(D-H87)A8W1E<G,@=&\@
M9&ES<&QA>3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,34*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA
M:6PB"FUS9W-T<B`BQ^'(S<L@W>T@Q^'CS.'/("C'X>/,X<_'RBD@VN0@T=/'
MQN$@S,_MS\DN(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C<U"FUS
M9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C$P('1E;7!L871E<R]F971C:&UA
M:6PO9F5T8VAM86EL+FEN8SHR,0IM<V=I9"`B0VAE8VL@86QL(&UA:6P@<V5R
M=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*(RP@9G5Z>GD*;7-G:60@
M(D-H96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS
M9W-T<B`BY>3'X=\@SMC#(-WM(,71T\?A(-'3Q^'*WZ`Z("5S(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I9"`B0VAO;W-E($%C
M=&EO;CHB"FUS9W-T<B`BQ\[*T2#%S-''P2`Z(@H*(SH@8V]N9FEG+W-E<G9E
M<G,N<&AP+F1I<W0Z,3@R"FUS9VED(")#:&]O<V4@82!M86EL('-E<G9E<CHB
M"FUS9W-T<B`BQ\[*T2#CTN;/(,?AR-'MSR`Z(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M,3<*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@
M=&\@=&AE(')I9VAT.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*(RP@
M9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(L?.RM$@
MQ<S1Q\$@.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC
M.C,T.0IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H
M96X@861D:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`BQ\[*T2#3S.$@Q^':Y,?F
M[>0@+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y
M,PIM<V=I9"`B0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O
M('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(L?.
MRM$@Q^'*T<KMR"#'X=#M(,K1[<\@P^0@[<KC(,?AR,W+(,CE(-KDSR#=RLT@
MT\SAQ\H@Q^':Y,?F[>0N("(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!C;VYV
M97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B<F]W<V5R
M(&-A;B!V:65W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!D
M;W=N;&]A9"!T:&4@:6UA9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N
M<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T
M;R`E<R!M86YA9V5M96YT('!A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD
M;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W(&$@
M=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@
M<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R("+#T=/A(-'3Q^')(-WM(.3'W=#)
M(,S/[<_)(+\B"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU
M;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I
M9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(Q"FUS9VED
M("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O
M;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S('1O("(*(G-E87)C:"XB
M"FUS9W-T<B`BQ^3>T2#:X>P@YL?-S\<@X^0@T\SAQ\H@TN;'T=\@Q^'CSLK'
MT<D@R^,@Q\[*T2#,X^W:(,?AS=[FX2`@X>'(S<LN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,3<Q"FUS9VED(")#;&EC:R!T;R!3879E(%!'4"!0
M=6)L:6,@2V5Y(&EN('EO=7(@061D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C`R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC871E(&]F("5S
M(&EN('EO=7(@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-3`*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R
M97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,0IM<V=I
M9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S
M86=E('1O(&)E(')E860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]F971C:&UA:6PN:6YC.C(X"B,L(&9U>GIY"FUS9VED(")#;&]S92(*
M;7-G<W1R("+%T=/'X2(*"B,Z(&-O;7!O<V4N<&AP.C@R."!C;VUP;W-E+G!H
M<#HQ,30X"FUS9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R("(B"@HC
M.B!F;VQD97)S+G!H<#HT,CD*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS9W-T
M<B`BX\SASR#CV^'>(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"B,L(&9U>GIY"FUS
M9VED(")#;VQL87!S92(*;7-G<W1R("+8[2#'X<SC[=HB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL
M(@IM<V=S='(@(MCM(,?AS./MVB(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C,Y"FUS9VED(")#;VQL87!S92!!;&P@1F]L9&5R<R(*;7-G
M<W1R("+8[2#,X^W:(,?AX\SAS\?*(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS
M9VED(")#;VQL87!S92!&;VQD97(B"FUS9W-T<B`BV.T@X\SASR(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@
M26YD:6-A=&]R.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$P,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S8Y"B,L(&9U>GIY"FUS9VED(")#;VUP;&5T
M960B"FUS9W-T<B`BQ='3Q^$B"@HC.B!C;VUP;W-E+G!H<#HX,C<@8V]M<&]S
M92YP:'`Z,3$T-PHC+"!F=7IZ>0IM<V=I9"`B0V]M<&]S92!A;F]T:&5R(&UE
M<W-A9V4B"FUS9W-T<B`BQ='3Q^$@T=/'X<DB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P
M87)A=&4@=VEN9&]W/R(*;7-G<W1R("+#T=/A(-'3Q^')(-WM(.3'W=#)(,S/
M[<_)(+\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0S"FUS9VED("(B
M"B)#;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L
M="`H:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-PIM<V=I9"`B0V]N
M9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*(RP@9G5Z>GD*;7-G:60@
M(D-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB"FUS9W-T<B`BRMOM
M[=$@UN;'R-@@X]+FSR#'X<C1[<\B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,W,`IM<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R
M;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B
M(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L
M(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U("(*(G=H96X@:70@
M87)R:79E<RXB"FUS9W-T<B`B(@HBQ^'*S=_C(-WM(.;>RB#'X<C-RR#:Y"#1
MT\?&X2#,S^W/R2"A(.;EX2#MRN,@RN3([>7?(,/C(.''("#:Y,\@YM7A(-'3
MQ\;A("(*(LS/[<_)+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.38*
M;7-G:60@(D-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC
M86P@;VYE<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@(N33SB(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2!T;R!F
M;VQD97(B"FUS9W-T<B`BX\SASR#3X<D@X^7CX<?*(-W'T=O)(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T
M(@IM<V=S='(@(M7-[<TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z,30P"FUS9VED(")#;W)R96-T960@5&5X="(*;7-G<W1R("+'X>35
M(,?AX]7-S2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S
M="X@4F5A<V]N($=I=F5N.B`E<R(*;7-G<W1R("+*VM#1(,7AV\?!(,?AT=/'
MQN$@X^0@)7.@.B`E<R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD
M.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C0P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&UE<W-A
M9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`BRMK0
MT2#%X=O'P2#'X='3Q\;A(./D("5SH#H@)7,B"@HC.B!L:6(O4V5S<VEO;BYP
M:'`Z,S$X"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@97AE8W5T92!M86EN
M=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R("+:X^'MQ\H@Q^'5[<?DR2(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HU-`IM<V=I9"`B0V]U;&0@
M;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.
M148@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U
M97-T960@9FEL92!F<F]M('1H92!::7`@87)C:&EV92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+U-E<W-I;VXN<&AP.C(W,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C,Q-"!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C,Y"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C`*;7-G:60@(D-R96%T92(*;7-G
M<W1R("+%Y-3'P2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C8*;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T<B`BQ>34Q\$@X\SASR(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*(RP@9G5Z>GD*;7-G:60@
M(D-R96%T92!+97ES(@IM<V=S='(@(L7DU,?!(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@5FER
M='5A;"!&;VQD97(B"FUS9W-T<B`BQ>34Q\$@X\SASR(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"FUS9VED(")#<F5A
M=&4@82!.97<@06-C;W5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US96QE
M8W0N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!N97<@4W!A;2!F
M;VQD97(B"FUS9W-T<B`BQ>34Q\$@X\SASR#CY>/AQ\H@S,_MSR(*"B,Z('1E
M;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P
M<F5F<R]F;VQD97)S96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@
M9')A9G1S(&9O;&1E<B(*;7-G<W1R("+%Y-3'P2#CS.'/(./3YL_'RB#,S^W/
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR-B!T
M96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0R"FUS9VED(")#
M<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("+%Y-3'P2#C
MS.'/(-'3Q\;A(./1T^')(,S/[<\B"@HC.B!T96UP;&%T97,O<')E9G,O=')A
M<VAS96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T
M<B`BQ>34Q\$@X\SASR#CY>/AQ\H@S,_MSR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C@*;7-G:60@(B(*(D-R96%T92!F:6QT97)I;F<@<G5L97,@
M=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@
M9F]L9&5R<RP@(@HB86YD(&1E;&5T92!S<&%M+B(*;7-G<W1R("(B"B+%Y-3'
MP2#>YL?:SR#'Y,K>Q\$@X<K1RNW((,?AR-'MSR#'X>;'T<\@H2#*U>3MW>7'
M(-WM(,?AX\SAS\?*("#FQ>';Q\$@Q^'(T>W/("(*(L?AV^W1(./1V^;(+B(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-`HC+"!F=7IZ
M>0IM<V=I9"`B0W)E871E(&YE=R!S=&%T:6]N97)Y(@IM<V=S='(@(L7DU,?!
M(./,X<\@T=/'QN$@X]'3X<D@S,_MSR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-#D*;7-G:60@(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E
M<W!O;G-E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4*;7-G
M:60@(D-U<W1O;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M
M(&]T:&5R(&%C8V]U;G1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$*(RP@9G5Z>GD*;7-G:60@(D-U<W1O;6EZ92!H;W<@>6]U
M('-E;F0@;6%I;"XB"FUS9W-T<B`BULC8(-_MW>W)(,71T\?AWR#'X='3Q\;A
M(.;#[>0@[<KC(,W=V2#'X>/3YL_'RB`N("(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(M;(V"#CY<?C
M(.'?[2#*VN/A(-KDSR#'X<_.YN$@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B1&%T
M7V4B"FUS9W-T<B`BQ^'*Q]'MSB(*"B,Z(&UE<W-A9V4N<&AP.C(V,B!T:')E
M860N<&AP.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R("+'X<K'T>W.(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5C;&EN960B"FUS9W-T<B`BX^';[2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HR-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F
M875L="(*;7-G<W1R("+%X=O'P2(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A
M=6QT<V5A<F-H<V5L96-T+FEN8SHQ.`IM<V=I9"`B1&5F875L="!396%R8V@@
M1FEE;&0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR
M,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R("+5
M[=O)(,?AW>71T\D@Q^''W<K1Q];MR:`Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDS,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB
M"FUS9W-T<B`BQ\K,Q^4@Q^'=Y='3R2#'X<?=RM''UNV@.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-C4*(RP@9G5Z>GD*;7-G:60@(D1E;&5G
M871E9"(*;7-G<W1R("+CX=OM(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(T-"!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHX('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:6YC.C(X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PIM<V=I9"`B1&5L971E(@IM<V=S='(@(L7AV\?!(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME
M>7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G<W1R("+%X=O'P2#C
MS.'/("@@X\SAS\?*("DB"@HC.B!F;VQD97)S+G!H<#HR.#4*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(L7AV\?!
M(./,X<\@*"#CS.'/Q\H@*2(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%-T871I;VYE<GDB
M"FUS9W-T<B`BQ>';Q\$@X\SASR`H(./,X<_'RB`I(@H*(SH@9F]L9&5R<RYP
M:'`Z-#$Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD97(B
M"FUS9W-T<B`BQ>';Q\$@X\SASR`H(./,X<_'RB`I(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE
M9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F
M<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!O;&0@;&EN:V5D
M(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B
MS=#=(./,X<\@Q^'1T\?&X2#'X>/1T^')(,?AWL_MXR#=[2#(S\?MR2#'X=3E
MT2"_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B1&5L
M971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N
M=&@_(@IM<V=S='(@(LW0W2#CS.'/(,?AT=/'QN$@Q^'CT=/AR2#'X=[/[>,@
MW>T@R,_'[<D@Q^'4Y=$@OR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M,3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM<V=S
M='(@(L7AV\?!(-'3Q\;A(@H*(SH@;65S<V%G92YP:'`Z-3`S(&UA:6QB;W@N
M<&AP.C<T,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(P"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB
M;W@O;&5G96YD+FEN8SHX"FUS9VED(")$96QE=&5D(@IM<V=S='(@(N/AV^TB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8S"FUS9VED(")$96QE
M=&5D(&UE<W-A9V5S(@IM<V=S='(@(M'3Q\;A(./-T.;=R2(*"B,Z(&-O;7!O
M<V4N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M9"!T:&4@871T86-H;65N="!<(B5S7"(N(@IM<V=S='(@(N/1W=['RB#CS=#F
MW<DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T
M:6YG(&%N9"!-;W9I;F<@365S<V%G97,B"FUS9W-T<B`BQ>';Q\$@YLK;[>W1
M(./FWMH@T=/'QN$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DR
M"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4T,`IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDS,@IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("+*
MY,?2X>TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z
M,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V.0HC+"!F=7IZ>0IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BSNW'T<?*(,?AX]/*SL_C(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W
M"FUS9VED(")$971A:6QS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-S<*;7-G:60@(D1I;2!S:6=N871U<F5S/R(*;7-G<W1R("+*
MVLKMXR#'X<KFWNW:(+\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R("+:W-'6(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W.0HC+"!F=7IZ>0IM<V=I9"`B1&ES
M<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_(@IM
M<V=S='(@(B(*(MK1UB#1T\?AR2#*P]_MSR#(VL\@Q='3Q^$@T=/'X<D@OR`H
M(-W>V"#:Y,\@VL_C(,?3RL[/Q^,@Y,?=T,D@X^3(R][)(.'%T=/'X2`B"B+'
MX='3Q^')("DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED
M(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"FUS9VED(")$:7-P;&%Y('!O<"UU
M<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_(@IM<V=S='(@(MK1UB#1T\?A
MR2#CY,C+WLD@X>'%VN''XR#:Y"#FU>;A(-'3Q^')(,S/[<_)(+\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4X"FUS9VED(")$:7-P;&%Y('1H92!<
M(D5M<'1Y(%-P86U<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4P"FUS9VED(")$:7-P;&%Y
M('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R("+:T=8@
MQ^'.[<?1Q\HB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,C8*
M;7-G:60@(D1O($Y/5"!M871C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B1&\@3F]T($-H96-K($9O
M;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`BX<<@RM[C(,C'X<C-RR#=
M[2#'X>/,X<\@*,?AX\SAS\?**2#:Y"#'X='3Q\;A(,?AS,_MS\DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34R"FUS9VED(")$;R!N;W0@9V5N97)A
M=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TE-4"YP:'`Z,3`W-0IM<V=I9"`B1&\@>6]U('=A;G0@=&\@;W!E;B!T
M:&%T(&9O;&1E<C\B"FUS9W-T<B`BY>$@RM'MSR#=RLT@T.'?(,?AX\SASR"_
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,S(*;7-G:60@(D1O
M;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B1&]N
M92(*;7-G<W1R("+*XR(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,@:6X@+GII<"!&;W)M
M870B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-3(*;7-G:60@(D1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII
M<"!F:6QE*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHR,`IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S='(@
M(LK-X^WA(,?AX\SASR`H(,?AX\SAS\?*("DB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B1&]W;FQO860@
M1F]L9&5R*',I(%LN>FEP(&9O<FUA=%TB"FUS9W-T<B`BRLWC[>$@Q^'CS.'/
M("@@Q^'CS.'/Q\H@*2(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*
M;7-G:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(B(*"B,Z
M(&UE<W-A9V4N<&AP.C4P,2!M86EL8F]X+G!H<#HW,3D@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C(R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z-#$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHY"FUS9VED
M(")$<F%F="(*;7-G<W1R("+CT^;/R2(*"B,Z(&9O;&1E<G,N<&AP.C,Y,@HC
M+"!F=7IZ>0IM<V=I9"`B1')A9G0@9F]L9&5R(@IM<V=S='(@(N/,X<\@Q^'C
MT^;/Q\J@.B(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC
M.C(S"FUS9VED(")$<F%F=',@9F]L9&5R.B(*;7-G<W1R("+CS.'/(,?AX]/F
MS\?*H#HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`X"B,L(&9U>GIY
M"FUS9VED(")%+6UA:6P@061D<F5S<R(*;7-G<W1R("+:Y.;'Y"#'X<C1[<\@
MQ^''X=_*T>;D[2(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,#D*;7-G:60@(D5.
M1"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW
M-`IM<V=I9"`B15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L
M:79E<F5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S
M='(@(LK-T>W1(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X
M"B,L(&9U>GIY"FUS9VED(")%9&ET($)L86-K;&ES="(*;7-G<W1R("+'X=['
MQN/)(,?AT^;/Q\$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,3,*(RP@9G5Z>GD*;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R("+CT=3-
MQ\H@Q^'(T>W/(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S96%R
M8V@O:&5A9&5R+FEN8SHQ-@IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F
M:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`BRLW1[=$@
MWN;'VL\@Q^'%Y,K>Q\$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@<G5L97,B"FUS9W-T<B`B
MRLW1[=$@WN;'VL\@Q^'%Y,K>Q\$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#8Q"FUS9VED(")%9&ET('EO=7(@<')E9F5R96YC97,@9F]R(&%C8V5S
M<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(D5D
M:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`BRLW1[=$@WN;'VL\@Q^'%Y,K>
MQ\$B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S.0IM
M<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("+:Y.;'Y"#'X<C1[<\@Q^''
MX=_*T>;D[2(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N
M(@IM<V=S='(@(LKC(,W0W2#,X^W:(,?AT=/'QN$@X^0@)7,N(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D5M<'1Y($9O
M;&1E<BAS*2(*;7-G<W1R("+CS.'/("@@X\SAS\?**2#=Q]';R2(*"B,Z(&9O
M;&1E<G,N<&AP.C(X-@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@4V5L96-T960@
M1F]L9&5R<R(*;7-G<W1R("+CS.'/("@@X\SAS\?**2#=Q]';R2(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")%;7!T>2!4
M<F%S:"!F;VQD97(B"FUS9W-T<B`BX\SASR#3X<D@X^7CX<?*(-W'T=O)(@H*
M(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")%;7!T>2!?4W!A
M;2(*;7-G<W1R("+3X<D@W<?1V\DB"@HC.B!L:6(O24U0+G!H<#HY-C8*(RP@
M9G5Z>GD*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R("+3X<D@W<?1V\DB
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,2!T96UP;&%T97,O<&=P+VYO
M=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$@
M=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE
M(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#$Q"FUS9VED(")%;F%B;&4@;65S<V%G92!P<F5V
M:65W<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#0R"FUS9VED(")%;F-R7WEP=&EO;B!/<'1I;VYS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3<@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8U-PIM<V=I9"`B16YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HS.#0*;7-G:60@(D5N9"!F;W)W87)D960@;65S
M<V%G92(*;7-G<W1R("+%Y.7'P2#'X='3Q\;A(,?AX\WFX<DB"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,S0Q"B,L(&9U>GIY"FUS9VED(")%;F0@;65S<V%G92(*
M;7-G<W1R("+'X='3Q\;A(,?AWL_MX\DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G92!F
M<F]M("5S(@IM<V=S='(@(M'3Q^')(./-YN')(./D("5S(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.CD*(RP@9G5Z>GD*;7-G:60@
M(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<B(*;7-G
M<W1R("+'S\[A(,?3XR#CS.'/(-/AR2#'X>/EX^''RB#'X<S/[<\B"@HC.B!T
M96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHY"FUS9VED(")%;G1E
M<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R
M("+'S\[A(,?3XR#CS.'/(,?AX]/FS\?*(,?AS,_MSR(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@(D5N=&5R('1H
M92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@
M(L?/SN$@Q]/C(./,X<\@Q^'1T\?&X2#'X>/1T^')(,?AS,_MSR(*"B,Z('1E
M;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@
M=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R("+'
MS\[A(,?3XR#CS.'/(-/AR2#'X>/EX^''RB#'X<S/[<\B"@HC.B!L:6(O4V5A
M<F-H+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B16YT:7)E($UE<W-A9V4B"FUS
M9W-T<B`BQ=K'S\D@RN;,[>4@T=/'X<DB"@HC.B!M97-S86=E+G!H<#HQ.30@
M8V]M<&]S92YP:'`Z,3$S-"!T:')E860N<&AP.C<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D5N=')Y(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`BRN,@Q<_.Q^$@Q^'3S.$@7"(E
M<UPB(,CDS,?-(-WM(-/,X2#'X=KDQ^;MY"(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C,X-@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(L[8PR(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V
M97(N("5S(#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HS,#D@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,0HC+"!F
M=7IZ>0IM<V=I9"`B179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(LKC(,7AV\?!(,?AX\SASR!<(B5S7"(@R.3,Q\TN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R("+?X2`Q-2#/WNW>R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BW^$@,S`@
MR\?D[<DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`BW^$@-2#/WL?&WB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#,*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*
M;7-G<W1R("+?X2#DU=T@T\?:R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("+?X2#/WNW>R2(*
M"B,Z(&9O;&1E<G,N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B17AP86YD(@IM
M<V=S='(@(LC3V"#'X=_A(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`BR-/8(,?AW^$B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.`IM<V=I9"`B
M17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(LC3V"#,X^W:(,?AX\SAS\?*
M(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM
M<V=S='(@(LC3V"#CS.'/(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,PIM
M<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(LC3V"#'X</3X\?!(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-C,*;7-G:60@(D5X<&%N9"!N86UE
M<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T:&4@
M8F%C:V=R;W5N9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDX,`IM<V=I9"`B17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@
M8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/R(*;7-G<W1R("+(T]@@
MU,S1R2#'X>/,X<_'RB#'X<W'X>W)(,C4W^$@Q]W*T<?6[2##R^3'P2#:T=8@
MQ^'CS.'/Q\H@OR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C$T-"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ.30*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C0U('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHQ,#$*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9&EN
M9R(*;7-G<W1R("+(T]@@Q^'?X2(*"B,Z(&QI8B])35`N<&AP.CDX-"!L:6(O
M24U0+G!H<#HY.#8*(RP@9G5Z>GD*;7-G:60@(D9?971C:"!-86EL(@IM<V=S
M='(@(LC1[<\@S,_MSR(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM
M86EL+FEN8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"B,L(&9U>GIY
M"FUS9VED(")&971C:"!-86EL(@IM<V=S='(@(LC1[<\@S,_MSR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-CD*(RP@9G5Z>GD*;7-G:60@(D9E=&-H
M($UA:6P@:6X@82!S97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(L/1T^$@T=/'
MX<D@W>T@Y,?=T,D@S,_MS\D@OR(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@;65S<V%G97,@
M=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R("(@WN,@R,K8R.W>(,?AX]'4S<?*
M(,/+Y,?!(,?AS\[FX2"_(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D("5D(&UE<W-A9V5S
M(&9R;VT@)7,B"FUS9W-T<B`BRN,@S=#=(,SC[=H@Q^'1T\?&X2#CY"`E<RXB
M"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B
MT=/'X<D@X\WFX<D@X^0@)7,B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#4@
M;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP.C(X.0IM
M<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I
M;"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")&971C:&UA:6PZ(&YO(&YE=R!M
M97-S86=E<RXB"FUS9W-T<B`BRN;,SR#AS^W?("5S(-'3Q^')(,S/[<_)+B(*
M"B,Z(&QI8B])35`N<&AP.CDY,`HC+"!F=7IZ>0IM<V=I9"`B1FE?;'1E<G,B
M"FUS9W-T<B`BQ^'CT=3-Q\HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHU,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z
M.#(*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`BQ^'CT=3-Q\HB"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S$*(RP@9G5Z>GD*;7-G
M:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S='(@(L[MQ]''RB##SM'L(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.CD*(RP@9G5Z>GD*;7-G:60@
M(D9I;'1E<B!3971T:6YG<R(*;7-G<W1R("+>YL?:SR#'X>/1U,TB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`P"FUS9VED(")&:6QT97(@;65S<V%G
M92!C;VYT96YT(&9O<B!P<F]F86YI='D_(@IM<V=S='(@(LK1U.W-(,?AX\W*
MYNW'RB#'X='3Q\;A(-OMT2#'X</.X<?>[<D@OR(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+VYO=&%C=&EV92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S
M='(@(L?AX]'4S<?*(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E
M+FEN8SHS"FUS9VED(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T9I;'1E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN9"(*
M;7-G<W1R("+,SR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*(RP@
M9G5Z>GD*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R("+'X=7=
MS<D@Q^'#YN'L(@H*(SH@;6%I;&)O>"YP:'`Z,S0U"FUS9VED(")&:7)S="!0
M86=E(@IM<V=S='(@(L?AU=W-R2#'X</FX>PB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D9O7W)W87)D(@IM<V=S
M='(@(LK-YNWA(@H*(SH@9F]L9&5R<RYP:'`Z,C8V('1E;7!L871E<R]F;VQD
M97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G:60@(D9O;&1E<B!!8W1I
M;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP
M.C,P,R!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY"B,Z('1E;7!L871E
M<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z-@HC.B!T96UP;&%T97,O
M<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C$P"FUS9VED(")&;VQD97(@
M3F%V:6=A=&]R(@IM<V=S='(@(N/3RM_4W2#'X>/,X<\B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B1F]L9&5R(%-U;6UA
M<GDB"FUS9W-T<B`BW<C1Q^W1(@H*(SH@86-L+G!H<#HR-`IM<V=I9"`B1F]L
M9&5R('-H87)I;F<@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*"B,Z(&9O
M;&1E<G,N<&AP.C8R"FUS9VED(")&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38Y"FUS
M9VED(")&;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I;&)O>"!V
M:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A>2(*;7-G<W1R("(B"@HC.B!C
M;VUP;W-E+G!H<#HW.#`@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C$U"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q
M"FUS9VED(")&;W)W87)D(@IM<V=S='(@(LK-YNWA(@H*(SH@8V]M<&]S92YP
M:'`Z-S8U"FUS9VED(")&;W)W87)D.B(*;7-G<W1R("+*S>;MX:`Z(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,V.0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9&5D
M(&UE<W-A9V4B"FUS9W-T<B`BQ>3EQ\$@Q^'1T\?&X2#'X>/-YN')(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;W)W
M87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(M'3Q^')(./-YN')(./D
M("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,PHC+"!F=7IZ
M>0IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(N/:X>;C
MQ\H@Q^'CSL_C(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y-`IM
M<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT.#@*;7-G:60@(D9R964O0G5S>2!297%U97-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*
M;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*
M(RP@9G5Z>GD*;7-G:60@(D9R;U]M(@IM<V=S='(@(N/D(@H*(SH@;65S<V%G
M92YP:'`Z,C8S('1H<F5A9"YP:'`Z,30Y('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.CDY"B,Z(&QI8B]396%R8V@N<&AP.C(R"FUS9VED(")&<F]M
M(@IM<V=S='(@(N/D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ.`IM
M<V=I9"`B1G)O;2!!9&1R97-S(@IM<V=S='(@(N/D(,?AVN3FQ^0B"@HC.B!C
M;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP:'`Z-S@Q"FUS9VED(")&=V0Z(@IM
M<V=S='(@(N/-YN$Z(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-`HC+"!F=7IZ>0IM
M<V=I9"`B1G=D.B`B"FUS9W-T<B`BX\WFX3HB"@HC.B!C;VUP;W-E+G!H<#HQ
M,CDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O<G=A
M<F1E9"!-97-S86=E<R(*;7-G<W1R("+%Y.7'P2#'X='3Q\;A(,?AX\WFX<DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@*(RP@9G5Z>GD*;7-G:60@(D=E;F5R86P@3W!T
M:6]N<R(*;7-G<W1R("+.[<?1Q\H@Q^'CT\K.S^,B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M
M97-S86=E<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@(B(*
M"B,Z('1H<F5A9"YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")';R!T;R!-97-S
M86=E(@IM<V=S='(@(L?AT=/'X<D@Q^'*Q^'MR2(*"B,Z(&QI8B])35`N<&AP
M.C0Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1V\@=&\@861D<F5S
M<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R("+#UMT@Q>'L(-/,X2#'
MX=KDQ^;MY"`H)7,I(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM
M<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP
M.C4T-B!L:6(O1FEL=&5R+G!H<#HQ,#4@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z.34*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q
M-@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6
M:65W97(O<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,3@*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R
M-PIM<V=I9"`B2$5212(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q
M-PHC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA4
M34PB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,
M(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G
M:60@(DAE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8X"FUS9VED
M(")(:61D96XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8V-PHC+"!F=7IZ>0IM<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM
M<V=S='(@(MK1UB#*T^'3X>TB"@HC.B!M86EL8F]X+G!H<#HS-C<*;7-G:60@
M(DAI9&4@1&5L971E9"(*;7-G<W1R("+%SMW'P2#'X>/AV^TB"@HC.B!F;VQD
M97)S+G!H<#HR.3@*;7-G:60@(DAI9&4@56YS=6)S8W)I8F5D(@IM<V=S='(@
M(L7.W<?!(,?AV^W1(./4RM'?(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z(&UE<W-A
M9V4N<&AP.C(Y-R!M86EL8F]X+G!H<#HW,C0@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ,@IM<V=I9"`B2&EG:"!0<FEO<FET>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@
M(DAI9VAE<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8X.`IM<V=I9"`B2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H
M;65N=',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,#0*(RP@9G5Z>GD*;7-G:60@(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI
M;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`B(,K-S^W/(,C'S\;)(,?AP]/8T2#'
MX>/>RLC3R2#=[2#'X='/H#HB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C$S-`IM<V=I9"`B24U!4"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H075T;R!$971E8W0@4')O=&]C
M;VQS*2(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@=&AE(&-O
M;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38V(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V97(@4U-,(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,34R"FUS9VED("))34%0(&]V
M97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C<*;7-G:60@(DE-05`@
M;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R("(B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H
M92!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$V-2!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM<V=I
M9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.#8V"FUS9VED("))3D)/6"(*;7-G
M<W1R("+'X>;'T<\B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I
M9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0
M(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3(*(RP@9G5Z
M>GD*;7-G:60@(DEF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H
M92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(2(*;7-G<W1R("+,X^W:(,?AT=/'
MQN$@W>T@Q^'CS.'/("C'X>/,X<_'RBD@T^;=(,K=WL^@(2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,@IM<V=I9"`B26=N;W)E(@IM
M<V=S='(@(LK,Q^7A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C@S"FUS9VED("))9VYO<F4@06QL(@IM<V=S='(@(LK,Q^7A(,?AW^$B
M"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.`IM<V=I
M9"`B26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP
M;W)T+FEN8SHR,`HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T(@IM<V=S='(@(N/E
MXR(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8U"B,L(&9U>GIY"FUS9VED("))
M;7!O<G0@2V5Y(@IM<V=S='(@(N/EXR(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,SD*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!+97EP86ER(@IM<V=S
M='(@(N/EXR(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(W
M"B,L(&9U>GIY"FUS9VED("));7!O<G0@365S<V%G97,B"FUS9W-T<B`BT=/'
MQN$@X^7CR2(*"B,Z('!G<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3$*
M;7-G:60@(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("))
M;7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26UP;W)T
M(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4&5R
M<V]N86P@4R]-24U%($-E<G1I9FEC871E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHT,@IM<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@
M4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+VEM<&]R=%]K97DN:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@4R]-24U%
M($ME>2(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R
M="!3+TU)344@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD
M97(@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,B!M86EL8F]X
M+G!H<#HW,S0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHW"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,38@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R("+CY>,B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O
M<G1A;G0@;65S<V%G97,B"FUS9W-T<B`BT=/'QN$@X^7CR2(*"B,Z(&9O;&1E
M<G,N<&AP.C$V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M960@)60@;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T<B`BRN,@S=#=(,SC[=H@
MQ^'1T\?&X2#CY"`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S<S"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C,X-"!L:6(O1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@
M;&EB+TE-4"YP:'`Z,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O
M24U!4"]4<F5E+G!H<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3(*(RP@9G5Z>GD*;7-G:60@(DEN
M8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L
M>3\B"FUS9W-T<B`BQ='=Q]X@Q^'1T\?&X2#'X</5X>W)(-KDSR#'X='/(+\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W"FUS9VED("));F-L=61E
M(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B"FUS9W-T<B`BQ='=Q]X@
MQ^'1T\?&X2#'X</5X>W)(-KDSR#'X='/(+\B"@HC.B!L:6(O34E-12]6:65W
M97(O;F]T:69I8V%T:6]N+G!H<#HV,2!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F\B"FUS9W-T<B`BRLS'Y>$B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO
M;B!O;B`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@
M4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN
M9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYJ<SHY.`HC+"!F=7IZ>0IM<V=I9"`B26YL:6YE
M(@IM<V=S='(@(N''(-3MP2(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS
M9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM
M<V=I9"`B26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS
M9VED("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED
M($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@
M(B(*"B,Z(&UA:6QB;W@N<&AP.C4X-"!M86EL8F]X+G!H<#HV,C8*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R("+:Y.;'Y"#'X<C1
M[<\@Q^''X=_*T>;D[2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,S`W
M"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM<V=S='(@(B(*"B,Z
M(&-O;7!O<V4N<&AP.C$U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M26YV86QI9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G
M<W1R("+-T>;=(-OMT2#CWLCFX<D@W>T@VN3FQ^0@Q^'(T>W/(,?AQ^'?RM'F
MY.TN(@H*(SH@<VUI;64N<&AP.C@R('!G<"YP:'`Z,38*;7-G:60@(DEN=F%L
M:60@:V5Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3DV"FUS9VED("));G9A
M;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@
M<&=P+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI
M8R!K97DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME>2!,
M96YG=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S
M-PIM<V=I9"`B(@HB2V5Y(&=E;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I
M;64@=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T
M:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C,U('1E;7!L871E<R]P9W`O<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R
M="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE
M9"!O;B!T:&ES('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHS-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,SD*;7-G
M:60@(B(*(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA=F4@
M;F\@861D<F5S<R!B;V]K(&1E9FEN960@=&\@861D('EO=7(@(@HB8V]N=&%C
M=',N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,S$X"FUS9VED(")+97D@<W5C
M8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$V"FUS9VED
M("),86YG=6%G92(*;7-G<W1R("+'X>';R2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,#8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@36%I;&)O>"!086=E
M(@IM<V=S='(@(L+.T2#5W<W)(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED
M("),87-T(%!A9V4B"FUS9W-T<B`BPL[1(-7=S<DB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS.#D*(RP@9G5Z>GD*;7-G:60@(DQI7VYK
M($%T=&%C:&UE;G1S(@IM<V=S='(@(N/1W=['RB(*"B,Z(&%T=&%C:&UE;G0N
M<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED("),:6YK960@871T
M86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL
M;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@
M;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO
M=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F
M;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8X-0IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A9&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`HC
M+"!F=7IZ>0IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`BU>3/YMX@
MQ^'(T>W/(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`HC+"!F
M=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BQ<S1Q\$B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R-0IM<V=I9"`B3&]G(&EN(@IM<V=S
M='(@(L_.YN$B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3$U"B,L('!H
M<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G<W1R("+/SN;A(,7A
M["`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,W"B,L(&9U
M>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("+/SN;A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("+C
MY<?C(,?AS\[FX2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y
M.2!M86EL8F]X+G!H<#HW,C<@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHQ,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-PIM<V=I9"`B3&]W97-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z
M-#0*(RP@9G5Z>GD*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM<V=S='(@(N/1
MU,W'RB#'X<C1[<\B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI
M;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(DUA:6PB"FUS9W-T<B`BU>3/YMX@Q^'(
MT>W/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"B,L(&9U>GIY"FUS
M9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(N/1U,W'RB#'X<C1[<\B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C$V"FUS
M9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM<V=S='(@
M(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I;&)O>"(*;7-G<W1R
M("+5Y,_FWB#'X<C1[<\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q
M"B,L(&9U>GIY"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/
M<'1I;VYS(@IM<V=S='(@(MK1UB#'X<[MQ]''RB(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C$X"FUS9VED(")-87)K($%L;"!-97-S86=E
M<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B36%R:R!!;&P@365S<V%G
M97,@:6X@1F]L9&5R(&%S(%5N<V5E;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C4@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHS,`IM<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`B
MRMKA[>,@W]R@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G
M:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF
M9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`BVN'C(,?AX]/*YNW'RB#'X>/.RN'=
MR2#CY"#'X<?>RLC'T\?*(,C#X>;'Y"#CSLKAW<D@OR(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,`IM<V=I9"`B36%R:R!M97-S86=E
M<R!A<R!S965N/R`H24U!4"!O;FQY*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C4X"FUS9VED(")-87)K('-I;7!L92!M87)K=7`_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT
M-@IM<V=I9"`B36%T8V@@06QL(%%U97)I97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0R"FUS9VED(")-871C:"!!;GD@
M475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-3$S"B,L(&9U>GIY"FUS9VED(")-87AI;75M($%T=&%C:&UE;G0@
M4VEZ92(*;7-G<W1R("+CT=W>(@H*(SH@;&EB+V%P:2YP:'`Z-SD*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DT"FUS9VED(")-87AI;75M
M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.#D*;7-G:60@(DUA
M>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE(')E86-H960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C8*;7-G:60@(DUE
M971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU-S4*(RP@9G5Z>GD*;7-G:60@(DUE971I;F<@26YF
M;W)M871I;VXB"FUS9W-T<B`BX]KAYN/'RB#'X>/.S^,B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3@U"FUS9VED(")-965T:6YG(%!R;W!O<V%L
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3<*
M;7-G:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4Y.`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,PIM<V=I
M9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=')E95]F;VQD97)S+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-96YU
M($9O;&1E<B!,:7-T(@IM<V=S='(@(N/,X<\@X]W*YLTB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S,Q"FUS9VED(")-97-S86=E(@IM<V=S='(@(M'3Q^')(@H*
M(SH@8V]M<&]S92YP:'`Z-38P(&-O;7!O<V4N<&AP.C4X-R!C;VUP;W-E+G!H
M<#HV-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P"FUS9VED(")-97-S86=E
M($-O;7!O<VET:6]N(@IM<V=S='(@(LCD[<D@Q^'1T\?AR2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,3<*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G
M<W1R("+*Q]'MSB#'X='3Q^')(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S@*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`S"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E($]P=&EO;G,B"FUS9W-T<B`BT=/'QN$@
MQ>'L(@H*(SH@<V5A<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@4V5A<F-H
M(@IM<V=S='(@(LC-RR#'X='3Q^')(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDR,0IM<V=I9"`B365S<V%G92!3:7IE(@IM<V=S='(@(LW,XR#'X='3
MQ^')(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS9VED(")-97-S86=E(%-O=7)C
M92(*;7-G<W1R("+CW^;DQ\H@Q^'1T\?AR2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@(MK1
MUB#'X='3Q^')(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS
M9VED(")-97-S86=E(&9L86=S(@IM<V=S='(@(L/:X<?C(,?AT=/'X<DB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E
M(&9O;&1E<G,B"FUS9W-T<B`BX\SAS\?*(,?AT=/'X<DB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-97-S
M86=E(&9R;VT@)7,B"FUS9W-T<B`BX\SAS\?*(,?AT=/'X<DB"@HC.B!M86EL
M8F]X+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C
M:&UE;G1S(@IM<V=S='(@(N/1W=['RB#CS=#FW<DB"@HC.B!M86EL8F]X+G!H
M<#HV-3@*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@96YC<GEP=&5D(@IM
M<V=S='(@(LW>YN$@Q^'1T\?AR2(*"B,Z(&UA:6QB;W@N<&AP.C8U,PHC+"!F
M=7IZ>0IM<V=I9"`B365S<V%G92!I<R!S:6=N960B"FUS9W-T<B`BS=[FX2#'
MX='3Q^')(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C,S"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS9W-T<B`BRL?1[<X@
MQ^'1T\?AR2(*"B,Z(&-O;7!O<V4N<&AP.C@R-"!C;VUP;W-E+G!H<#HX,S@*
M(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(LKC(,71T\?A(,?AT=/'X<D@R.3,Q\TN(@H*(SH@8V]M
M<&]S92YP:'`Z,3`X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365S
M<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<R(*
M;7-G<W1R("+*XR#%T=/'X2#'X='3Q^')(,CDS,?-+B(*"B,Z(&-O;7!O<V4N
M<&AP.C$Q-#,@8V]M<&]S92YP:'`Z,3$U.`HC+"!F=7IZ>0IM<V=I9"`B365S
M<V%G92!S96YT('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BRN,@Q='3Q^$@Q^'1
MT\?AR2#(Y,S'S2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30Q"FUS
M9VED(")-97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V:65W+B(*
M;7-G<W1R("+1T\?AR2#AW^$@U=W-R2##R^3'P2#:T=8@U>3/YMX@Q^'1T\?&
MX2XB"@HC.B!M86EL8F]X+G!H<#HS,C(*;7-G:60@(DUE<W-A9V5S('1O(@IM
M<V=S='(@(M'3Q\;A(,7A["(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR
M.0IM<V=I9"`B36]D:69Y(@IM<V=S='(@(LK:S^WA(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O97AP86YD+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M;W)E('1H86X@;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I96QD(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS
M9VED(")-;W9E(@IM<V=S='(@(L?DRM[A(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-O=7)C97-E;&5C="YI;F,Z,S$V"B,L(&9U>GIY"FUS9VED(")-;W9E(&1O
M=VXB"FUS9W-T<B`BQ^3*WN$@Q>'L(,?AP]/=X2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV,3@*;7-G:60@(DUO=F4@<W!A;2!M97-S86=E<R!T;R!S
M<&%M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@24Y"3U@B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"B,L(&9U
M>GIY"FUS9VED(")-;W9E('1O(&9O;&1E<B(*;7-G<W1R("+'SLK1(./,X<\B
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,30*(RP@
M9G5Z>GD*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BQ^3*WN$@Q>'L(,?AP]KA
M["(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(W"FUS
M9VED(")-=6QT:7!A<G0O86QT97)N871I=F4B"FUS9W-T<B`B(@H*(SH@=&AR
M96%D+G!H<#HW-B!T:')E860N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B375L
M=&EP;&4@365S<V%G92!6:65W(@IM<V=S='(@(MK1UB#'X='3Q^')(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C4*;7-G
M:60@(DY/3D4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C0X('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I9"`B3D]412(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S."!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(").86UE(@IM<V=S='(@
M(L?AQ]/C(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD+V]R(&5M
M86EL(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<W.`HC+"!F=7IZ>0IM<V=I9"`B3F5E9',@06-T
M:6]N(@IM<V=S='(@(L7,T<?!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@R"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-S@*;7-G:60@(DYE=F5R(@IM<V=S='(@(N/8X=['(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`HC+"!F=7IZ>0IM<V=I9"`B
M3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R("+CT=W>Q\H@X\W0YMW)
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R-`IM<V=I9"`B3F5W(@IM
M<V=S='(@(LS/[<\B"@HC.B!L:6(O24U0+G!H<#HU-C,*;7-G:60@(DYE=R!&
M;VQD97(B"FUS9W-T<B`BX\SASR#,S^W/(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@X"FUS9VED(").97<@36%I;"(*;7-G<W1R("+(T>W/(,S/[<\B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K+W1R965?
M9F]L9&5R<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(DYE=R!-97-S86=E(@IM
M<V=S='(@(L?AT=/'X<D@Q^'*Q^'MR2(*"B,Z(&UA:6QB;W@N<&AP.C<W-B!L
M:6(O34E-12](96%D97)S+G!H<#HQ.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(M'3Q\;A(,S/[<_)
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ.0IM<V=I9"`B3F5W
M(&UE<W-A9V5S(@IM<V=S='(@(M'3Q\;A(,S/[<_)(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B3F5X="(*;7-G<W1R
M("+'X<K'X>TB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C,S"FUS9VED(").97AT($UE<W-A9V4B"FUS9W-T<B`BQ^'1T\?A
MR2#'X<K'X>W)(@H*(SH@;6%I;&)O>"YP:'`Z,S4V"FUS9VED(").97AT(%!A
M9V4B"FUS9W-T<B`BQ^'5W<W)(,?ARL?A[<DB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW
M-PIM<V=I9"`B3F\B"FUS9W-T<B`BX<<B"@HC.B!S;6EM92YP:'`Z,C(V"FUS
M9VED(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N
M8W)Y<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$Y"FUS9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@
M;6%I;&)O>"YP:'`Z,S<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").
M;R!-97-S86=E<R(*;7-G<W1R("+1T\?&X2#,S^W/R2(*"B,Z('!G<"YP:'`Z
M,3,W"FUS9VED(").;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHX-`IM<V=I9"`B
M3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N="(*;7-G<W1R("(B"@HC
M.B!L:6(O36%I;&)O>"YP:'`Z,S(Y"B,L(&9U>GIY"FUS9VED(").;R!0<F5V
M:65W(%1E>'0B"FUS9W-T<B`BQ^'DU2#'X>/5S<TB"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C$U"FUS9VED(").;R!0=6)L:6,@2V5Y<R!&;W5N
M9"(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,34Q"FUS9VED(").;R!3+TU)
M344@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W1N968N<&AP.CDP"B,L(&9U>GIY"FUS9VED(").;R!A='1A
M8VAM96YT<R!F;W5N9"XB"FUS9W-T<B`BX]'=WL?*(@H*(SH@;&EB+T-R>7!T
M+U--24U%+G!H<#HQ-#`*;7-G:60@(DYO(&5M86EL(&EN9F]R;6%T:6]N(&QO
M8V%T960@:6X@=&AE('!U8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z(&%C;"YP
M:'`Z-S(@86-L+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R('-E
M;&5C=&5D+B(*;7-G<W1R("+AXR#MRN,@Q\[*[<?1(./,X<\B"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD97)S(&%R92!B
M96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L:6(O1F]L9&5R+G!H
M<#HU-3`*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I960B"FUS9W-T
M<B`BX>,@[<KC(,K-S^W/(./,X<\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,30W"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@;F5W(&UE
M<W-A9V5S(@IM<V=S='(@(N'MT\H@T=/'QN$@X^';[<DB"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,30T"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S
M('=I=&@@=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(N'MT\H@T=/'QN$@X^';
M[<DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(U"B,L(&9U>GIY"FUS9VED(").
M;R!M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R("+'Y-[A(,?AT=/'QN$@Q>'L
M(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,W,0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`BX<<@RN;,
MSR#1T\?&X2#CV,?(WLD@X<C-R]\B"@HC.B!P9W`N<&AP.C$X.0IM<V=I9"`B
M3F\@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R
M("(B"@HC.B!P9W`N<&AP.C$V-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U
M8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR
M,#$*;7-G:60@(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP
M;W)T960N(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG+G!H<#HR,C`*;7-G:60@
M(DYO('-P96QL8VAE8VMI;F<@<')O9W)A;2!C;VYF:6=U<F5D+B(*;7-G<W1R
M("+AXR#MRN,@RMK1[=T@R-'DQ^/,(,K/WNW>(,7CX<?&[2XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G:60@(DYO('-P96QL
M:6YG(&5R<F]R<R(*;7-G<W1R("+AQR#*YLS/(,/.V,?!(,7CX<?&[<DB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`P"FUS9VED(").
M;R!S=6=G97-T:6]N<R(*;7-G<W1R("+AQR#*YLS/(,?>RM''S<?*(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HU-C0*;7-G:60@(DYO('-U<'!O<G1E9"!)
M34%0(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@86-L+G!H<#HV."!A8VPN<&AP.CDT"B,L(&9U>GIY"FUS
M9VED(").;R!U<V5R('-P96-I9FEE9"XB"FUS9W-T<B`BX>,@[<KC(,K-S^W/
M(./,X<\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Y"FUS9VED
M(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHQ,2!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS
M96QE8W0N:6YC.C0P"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,U('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(").;VYE(@IM<V=S
M='(@(N''(-3MP2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y-0IM<V=I9"`B3F]R;6%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS.0IM<V=I9"`B3F]T($1E;&5T960B"FUS9W-T<B`BX>,@[<KC(,?A
MQ>';Q\$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T
M(@IM<V=S='(@(N''(,KFS,\@X]/FS\DB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,T
M"FUS9VED(").;W0@26UP;W)T86YT(@IM<V=S='(@(MOMT2#CY>/)(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T(%!E
M<G-O;F%L(@IM<V=S='(@(N'MT\H@U,[5[>4B"@HC.B!L:6(O0W)Y<'0O4$=0
M+G!H<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@;&EB+T-R>7!T+U--
M24U%+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A;&ED('!U8FQI8R!K97DN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-C<*;7-G
M:60@(DYO="!D96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(N'MT\H@T=/'QN$@
MX^';[<DB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED
M(").;W0@:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(N'MT\H@T=/'QN$@
MX^7CR2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I
M;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@
M=&EM92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$V
M"B,L(&9U>GIY"FUS9VED(").;W1H:6YG(@IM<V=S='(@(L?>RLC'TR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*(RP@9G5Z>GD*;7-G:60@(DYU
M;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S
M(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(MK/SR#CS.'/Q\H@
MQ^'1T\?&X2#'X>/1T^')(,?AWL_MX\D@Q^'*[2#MS,@@Q<C>Q\3EQR#=[2#-
MQ^$@Q^'%X=O'P2`@(,?AU.71[2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S4Y"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S
M('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HBVL_/
M(./,X<_'RB#'X='3Q\;A(,?AX]'3X<D@Q^'>S^WCR2#'X<KM(.W,R"#%R-['
MQ.7'(-WM(,W'X2#'X<7AV\?!("`@Q^'4Y='M+B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU-3(*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,PIM<V=I
M9"`B3TLB"FUS9W-T<B`BX^;'W=XB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z-2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT.`IM<V=I9"`B3U(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-0IM
M<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@(L?AT=/'QN$@Q^'>S^WCR2(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT
M:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG
M('!U<F=E9"XB"FUS9W-T<B`BRN,@Q^'*SN'5(./D(./,X<_'RB#'X='3Q\;A
M(,?AX]'3X<D@Q^'>S^WCR2XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,C4*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE
M<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V9O;&1E<G,N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE
M(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+B(*
M;7-G<W1R("+'X=',Q\$@Q\[*[<?1(./,X<\@YL?-SR#=WM@@X>70Y2#'X=KC
MX>W)+B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ,"!T96UP;&%T97,O;65N
M=2YI;F,Z,S`*(RP@9G5Z>GD*;7-G:60@(D]P96X@1F]?;&1E<B(*;7-G<W1R
M("+CS.'/(./=RN;-(@H*(SH@9F]L9&5R<RYP:'`Z-#(W"B,L(&9U>GIY"FUS
M9VED(")/<&5N960@1F]L9&5R(@IM<V=S='(@(N/,X<\@X]W*YLTB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`U"FUS9VED(")/<'1I;VYA;"!0
M87)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!F971C:&UA:6PN<&AP.C,S('1E
M;7!L871E<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO9F5T8VAM86EL+FEN8SHV"B,L(&9U>GIY"FUS9VED(")/=&AE<B!-
M86EL($%C8V]U;G1S(@IM<V=S='(@(L[MQ]''RB##SM'L(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS
M9W-T<B`BSNW'T<?*(,/.T>PB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(P,0IM<V=I9"`B3W5T8F]U;F0@4V5R=F5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,38U"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P
M-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3`*;7-G:60@(E!'4"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC
M.C<*(RP@9G5Z>GD*;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS9W-T
M<B`BQ>';Q\$@Q^'1T\?AR2(*"B,Z(&-O;7!O<V4N<&AP.C,U.`HC+"!F=7IZ
M>0IM<V=I9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`BSMC#(@H*(SH@8V]M<&]S
M92YP:'`Z,S,W"FUS9VED(")01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F
M;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!/<'1I
M;VYS(@IM<V=S='(@(L[MQ]''RB(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'
M4"!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P
M<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"FUS9VED(")0
M1U`@4'5B;&EC($ME>2!497AT(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,30Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F
M;W(@7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T
M<B`BRN,@Q>34Q\$@Q^'CS.'/(%PB)7-<(B#(Y,S'S2XB"@HC.B!P9W`N<&AP
M.C(T-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+
M97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(LKC(,7AV\?!(,?AX\SASR!<(B5S7"(@R.3,Q\TN(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T
M+FEN8SHX"B,L(&9U>GIY"FUS9VED(")01U`@4VEG;B!-97-S86=E(@IM<V=S
M='(@(L/1T^$@T=/'X<DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T
M7VQI<W0N:6YC.CD*;7-G:60@(E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G92(*
M;7-G<W1R("(B"@HC.B!P9W`N<&AP.C(P,@HC+"!F=7IZ>0IM<V=I9"`B4$=0
M('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`BRN,@
MRMOM[=$@Q^'*YM[MVB#(Y,S'S2XB"@HC.B!P9W`N<&AP.C$W-PIM<V=I9"`B
M4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4$=0
M('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P.`IM<V=I9"`B(@HB
M4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I
M9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDU"FUS
M9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S
M;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I9"`B(@HB
M4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D
M+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2`B"B)S970@=&\@9&ES
M86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T
M:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F96%T=7)E<R!W:6QL(&YO="!W;W)K
M(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ,#4*;7-G:60@(E!/4#,B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,#`*;7-G:60@(E!/4#,@*$%U=&\@1&5T96-T(%!R
M;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,3<*;7-G:60@(E!/4#,@;W9E<B!34TPB"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,C,*;7-G:60@(E!/4#,@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V.0IM<V=I9"`B4$]0,R!O=F5R(%-3
M3"`H<V5L9BUS:6=N960I(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3$Q"FUS9VED(")03U`S+"!N;R!43%,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")086=E("5D(&]F("5D(@IM<V=S='(@(L?AU=W-R2`E9"#C
MY"`E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#,*;7-G:60@(E!A
M9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H
M('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VAE861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM
M<V=S='(@(LS2P2`HP\S2Q\$I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$R,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!9V%I;BDB
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(S-2!P9W`N<&AP.C,Q,`HC+"!F
M=7IZ>0IM<V=I9"`B4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@=6YL;V%D960N
M(@IM<V=S='(@(LKC(,K;[>W1(,?ARN;>[=H@R.3,Q\TN(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$X('1E;7!L871E<R]P9W`O<&%S
M<W!H<F%S92YI;F,Z,CD*;7-G:60@(E!A<W-P:')A<V4Z(@IM<V=S='(@(B(*
M"B,Z('!G<"YP:'`Z,3$R"FUS9VED(")087-S<&AR87-E<R!C86X@;F]T(&)E
M(&5M<'1Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$T"FUS9VED(")087-S
M<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y
M,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B
MRMW:[>$@VN/A[<?*(,?AU>W'Y,D@VN3/(,?AS\[FX2"_(@H*(SH@86-L+G!H
M<#HW-B!A8VPN<&AP.C$P,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R('1H:7,@
M=7-E<B!C86X@;F]T(&)E(&-H86YG960N(@IM<V=S='(@(B(*"B,Z(&UE<W-A
M9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HW,#,@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC
M.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R("+4SM7M(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R("+CVN'FX\?*(-3.U>W)(@H*(SH@<&=P+G!H<#HQ,C`*(RP@
M9G5Z>GD*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(LKC(,71T\?A(,?AT=/'X<D@R.3,Q\TN
M(@H*(SH@<&=P+G!H<#HQ,C<*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L(%!'
M4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+*XR#%T=/'
MX2#'X='3Q^')(,CDS,?-+B(*"B,Z('-M:6UE+G!H<#HR,#<*;7-G:60@(E!E
M<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B"FUS
M9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$S,@IM<V=I9"`B4&5R<V]N86P@4R]-
M24U%(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L86-E('EO=7(@
M<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\B"FUS9W-T
M<B`BQ<_1Q\P@(,KFWNW:WR#>R.$@Q^'1S^;/(.;'X<K-YNWAQ\H@OR(*"B,Z
M(&-O;7!O<V4N<&AP.C(U-`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@
M365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-SDY"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@5&AI<R!R
M97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E9"`B"B)S
M;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A;F0@36%C
M+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q=6ER92!A('!L=6=I
M;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP
M="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR
M"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E
M<CHB"FUS9W-T<B`B[=',["#%S\['X2#'T^,@X>'CS.'/(,?AS,_MSZ`Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#(@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(E!L96%S92!E
M;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B[=',
M["#%S\['X2#'T^,@Q^'CS.'/(,?AS,_MSZ`Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S<*;7-G:60@(E!L96%S92!E;G1E<B!T
M:&4@;F5W(&YA;64Z(@IM<V=S='(@(NW1S.P@Q<_.Q^$@Q^''T^,@Q^',S^W/
MH#HB"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S
M92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E
M9"!T;R`B"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S
M<VEO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A
M<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E
M<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN
M(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES('!A<W-P:')A
M<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@<F5C;VUP
M;W-E+G!H<#HY-PIM<V=I9"`B(@HB4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R
M97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@
M=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G
M97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R`B"B)L;V<@
M:6X@86=A:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES
M('1O(&ME97`@871T86-K97)S(&9R;VT@(@HB:&EJ86-K:6YG('EO=7(@<V5S
M<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,0HC
M+"!F=7IZ>0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"XB
M"FUS9W-T<B`B[=',["#*YMWMT2#'T^,@Q^'CT\K.S^,@YM_AX\D@Q^'CT>;1
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PHC+"!F=7IZ>0IM
M<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B
M[=',["#*YMWMT2#'T^,@Q^'CT\K.S^,@YM_AX\D@Q^'CT>;1(@H*(SH@8V]M
M<&]S92YP:'`Z,3`V(&QI8B])35`N<&AP.C0U.0IM<V=I9"`B4&QE87-E(')E
M<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+B(*;7-G<W1R
M("+MT<SL(,WA(,?AQ^'*R,?3(,/F(-K/XR#5X<?-[<D@Q^':Y,?F[>0@+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*(E!L
M96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H
M96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@
M<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`BQ^'1S,?!(,?.RNW'T2#C
MS.'/(-[(X2#'X=31YMH@W>T@P^T@Q<S1Q\$N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4P,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('-E;&5C
M="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T<B`BQ^'1
MS,?!(,?.RNW'T2#CS.'/(.;'S<\@VN'L(,?AP][A(.'AR,W++B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S
M92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S
M='(@(L?AT<S'P2#'SLKMQ]$@X\SASR#FQ\W/(-KA["#'X</>X2#AX<C-RRXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS9VED
M(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R
M871I;VXN(@IM<V=S='(@(L?AT<S'P2#'SLKMQ]$@X\SASR#FQ\W/(-W>V"#A
MY=#E(,?AVN/A[<DN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C<S"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@
M:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(NW1S.P@Q\[*[<?1
M(,/F(,K-T>W1(.35(-7-[<V@.B(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD:7-T
M.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,30*(RP@9G5Z>GD*;7-G:60@(E!R96-E
M9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T
M<B`BQ]/*Y>$@RN;>[=K?(,C4T=@@*"<M+2`G*2(*"B,Z('-M:6UE+G!H<#HR
M-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"B,L(&9U>GIY"FUS
M9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T
M<B`BRN,@Q>34Q\$@Q^'CS.'/(%PB)7-<(B#(Y,S'S2XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B
M4')E=FEE=R(*;7-G<W1R("+'X=7=S<D@Q^'3Q\C>R2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G:60@(E!R979I
M;W5S($UE<W-A9V4B"FUS9W-T<B`BQ^'1T\?AR2#'X=/'R-[)(@H*(SH@;6%I
M;&)O>"YP:'`Z,S0W"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(L?A
MU=W-R2#'X=/'R-[)(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C,S"FUS9VED(")0<FEN="(*;7-G<W1R("+8R,?:R2(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X"B,L(&9U>GIY"FUS
M9VED(")0<FEO<FET>2(*;7-G<W1R("+8R,?:R2(*"B,Z('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I9"`B4')I=F%T92!+97D@4&%S
M<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U
M.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S
M96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T
M=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0
M<F]T;V-O;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y
M"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N
M(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E;&5T
M960N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!U<E]G92!$96QE=&5D(@IM<V=S
M='(@(LK.X=4@X^0@Q^'CX=OM(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D
M+FEN8SHX"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(LK.X=4@X^0@
MQ^'CX=OM(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C0*
M(RP@9G5Z>GD*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R("+%X=O'
MP2#CS.'/("@@X\SAS\?*("DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(N39
MW2#3X<D@Q^'CY>/AQ\H@W^$@W<K1R:`Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0P-0IM<V=I9"`B4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L
M9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RXB"FUS9W-T<B`B
MS=#=(,?AT=/'QN$@W>T@X\SASR#3X<D@Q^'CY>/AQ\H@Q^'*[2#*T\C>(.70
MQR#'X=K/SR#CY"#'X</MQ^,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-@HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@;VQD(&UE<W-A9V5S(&EN('1H
M92!4<F%S:"!F;VQD97(_(@IM<V=S='(@(LW0W2#'X='3Q\;A(,?AWL_MX\D@
MX^0@X\SASR#3X<D@Q^'CY>/AQ\J_(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<'5R9V5?=')A<V@N<&AP.C8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+B(*
M;7-G<W1R("+-T-T@)60@T=/'X<D@*-'3Q\;A*2#CY"#CS.'/(-/AR2#'X>/E
MX^''RBXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@
M5')A<V@@9F]L9&5R+B(*;7-G<W1R("+-T-T@)60@T=/'X<D@*-'3Q\;A*2#C
MY"#CS.'/(-/AR2#'X>/EX^''RBXB"@HC.B!T96UP;&%T97,O<75O=&$O<75O
M=&$N:6YC.C$W"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@
M)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")1=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(L?>RLC'TR(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B4F5?<75E
M<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M96%R8V@N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!/;B(*;7-G
M<W1R("+'T\KAX\H@W>TB"@HC.B!L:6(O4V5A<F-H+G!H<#HU.`HC+"!F=7IZ
M>0IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`BQ]/*X>/*(-WM(@H*
M(SH@;&EB+U-E87)C:"YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E)E8V5I=F5D
M(%5N=&EL(@IM<V=S='(@(L?3RN'CRB#=[2(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5D
M:7)E8U]T(@IM<V=S='(@(L7:Q\_)(,KFS.WE(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C="(*
M;7-G<W1R("+%VL?/R2#*YLSMY2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E9&ER96-T($UE<W-A9V4B"FUS9W-T
M<B`BQ=K'S\D@RN;,[>4@T=/'X<DB"@HC.B!C;VUP;W-E+G!H<#HW.#<*;7-G
M:60@(E)E9&ER96-T('1H:7,@;65S<V%G92(*;7-G<W1R("+%VL?/R2#*YLSM
MY2#ET.4@Q^'1T\?AR2(*"B,Z(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D
M:7)E8W1I;F<@9F%I;&5D+B(*;7-G<W1R("+-WN$@Q=K'S\D@Q^'*YLSMY2XB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU.#,*;7-G:60@
M(E)E9G)E<V@B"FUS9W-T<B`BRLW/[<LB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S@T"FUS9VED(")2969R97-H($9O;&1E<B!6:65W<SHB"FUS9W-T
M<B`BRLW/[<L@VM'6(,?AX\SAS\?*H#HB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]H96%D+FEN8SHY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-`HC
M+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(L7:Q\_)(,K-X^WA(,?A
MVM'6(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B
M4F5L;V%D(%9I97<B"FUS9W-T<B`BQ=K'S\D@RLWC[>$@Q^':T=8B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(V(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU-#4*;7-G:60@(E)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-SD*;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS9W-T<B`B
MRM#?T2#"SM$@VM'6(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C(W"B,L(&9U>GIY"FUS9VED(")296UO=&4@36%I;&)O>#HB"FUS9W-T
M<B`BU>3/YMX@Q^'(T>W/(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C0Q"FUS9VED(")296UO=F4@1FEE;&0@1G)O;2!396%R8V@B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`U
M"B,L(&9U>GIY"FUS9VED(")296UO=F4@<V]U<F-E(@IM<V=S='(@(L72Q^')
M(,?AX]7/T2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*
M(RP@9G5Z>GD*;7-G:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T<B`BQ=K'
MS\D@RM/C[<D@Q^'CS.'/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG
M(&]F(&UO;G1H/R(*;7-G<W1R("+%VL?/R2#*T^/MR2#CS.'/(,?AT=/'QN$@
MQ^'CT=/AR2#=[2#(S\?MR2#'X=3ET;\B"@HC.B!L:6(O1F]L9&5R+G!H<#HT
M-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB
M)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS
M9W-T<B`BQ=K'S\D@RM/C[<D@7"(E<UPB(,7A["!<(B5S7"(@S=[A+B#ET,<@
MX\<@WL?AY2#'X>/.S^.@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")297!L7WD@=&\@3&ES
M="(*;7-G<W1R("+'X='/(-KA["#'X=_A(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G
M<W1R("+'T\K(S^'E(,C<H#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`BQ^'1SR(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0P.0HC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@4V5N="XB
M"FUS9W-T<B`BQ^'1SR#:X>PB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R
M("+'X='/(-KA["#'X=_A(@H*(SH@8V]M<&]S92YP:'`Z-S,S"FUS9VED(")2
M97!L>2!T;R!!;&PZ(@IM<V=S='(@(L?AT<\@VN'L(,?AW^$@.B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ
M>0IM<V=I9"`B4F5P;'D@=&\@3&ES="(*;7-G<W1R("+'X='/(-KA["#'X=_A
M(@H*(SH@8V]M<&]S92YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED(")297!L>2!T
M;R!,:7-T.B(*;7-G<W1R("+'X='/(-KA["#'X=_A(#HB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G
M:60@(E)E<&QY('1O(%]!;&PB"FUS9W-T<B`BQ^'1SR#:X>P@Q^'?X2(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4S-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W
M"FUS9VED(")297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,U"FUS9VED
M(")297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-`IM<V=I
M9"`B4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR-C<*(RP@9G5Z>GD*;7-G
M:60@(E)E<&QY+51O(@IM<V=S='(@(L?AT<\@VN'LH#HB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z-#`Y"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(L?AT<\@
MVN'LH#HB"@HC.B!C;VUP;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*;7-G
M<W1R("+'X='/H#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C8*
M(RP@9G5Z>GD*;7-G:60@(E)E<&]R="!A<R!);FYO8V5N="(*;7-G<W1R("+'
MR.';(-KD(-'3Q^')(-OMT2#CT=OFR,DB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(L?(
MX=L@VN0@T=/'X<D@V^W1(./1V^;(R2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,X,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!A(%]2
M96%D(%)E8V5I<'0B"FUS9W-T<B`BQ]CAR"#FU>$@WM''P<DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y
M(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4W,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I
M<'1S/R(*;7-G<W1R("+'V.'((.;5X2#>T<?!R2(*"B,Z(&UA:6QB;W@N<&AP
M.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDW"FUS9VED
M(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,0IM<V=I9"`B
M4F5S970B"FUS9W-T<B`BQ]/*VL?/R2#'X<?=RM''UNTB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3$U"FUS9VED(")297-P;VYD96YT(%-T871U
M<R!5<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R("+'
MT\K#Y-TB"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")297-U;64@>6]U
M<B!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O(%PB365S
M<V%G92!#;VUP;W-I=&EO;EPB(@IM<V=S='(@(LCD[<D@Q^'1T\?AR2(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,S$@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8Y"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C,R"FUS9VED(")2971U<FX@
M=&\@1F5T8V@@36%I;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN
M8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP;&%T
M97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L871E<R]A8VPO86-L+FEN
M8SHQ-S,*(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S
M='(@(L[MQ]''RB#'X>/3RL[/XR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW,3@*;7-G:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG
M(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E
M/R(*;7-G<W1R("+'T<S:(,7A["#:T=8@U>3'S^W>(,?AR-'MSR#(VL\@Q>';
MQ\$@RLWF[>$@P^8@Y-/.("#1T\?AR2"_(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8X.`IM<V=I9"`B4F]L92(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C$T,B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C(S-PHC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.0IM
M<V=I9"`B4R]-24U%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V5N8W)Y<'1?;&ES="YI;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T($UE
M<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,SDT"FUS9VED(")3
M+TU)344@17)R;W(Z("(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS-S,*
M;7-G:60@(E,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S
M;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U,0HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($]P=&EO;G,B
M"FUS9W-T<B`BSNW'T<?*(@H*(SH@<VUI;64N<&AP.C0Y"FUS9VED(")3+TU)
M344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y
M<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,30P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A
M<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`BRN,@Q>';Q\$@Q^'C
MS.'/(%PB)7-<(B#(Y,S'S2XB"@HC.B!S;6EM92YP:'`Z,38R"FUS9VED(")3
M+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`*;7-G:60@(E,O
M34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z
M,C$Q"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C
M97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E,O34E-
M12!3:6=N($UE<W-A9V4B"FUS9W-T<B`BP]'3X2#1T\?AR2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*;7-G:60@(E,O34E-
M12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O;F]T86-T:79E+FEN8SHT"FUS9VED(")3+TU)344@<W5P<&]R
M="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#$*;7-G:60@(B(*(E,O34E-
M12!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@96YA8FQE9"!S;R!T:&4@;65S
M<V%G92!I<R!U;F%B;&4@=&\@8F4@(@HB9&5C<GEP=&5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PIM<V=I9"`B(@HB
M4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S
M(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO="`B"B)B92!D:7-P;&%Y
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S
M;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(')E<75I<F5S('!O<'5P
M('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R`B"B)C
M=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU
M<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E("(*(G1H92!3+TU)344@
M9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`U"FUS9VED(")33510
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(U-0HC+"!F=7IZ>0IM<V=I9"`B4U]U8FIE8W0B"FUS9W-T<B`BQ^'CYM;F
MVB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,V,PHC+"!F
M=7IZ>0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R("+'S=W9(.33
MSLD@W>T@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C,R"B,L(&9U>GIY"FUS9VED(")385]V92!A<R(*;7-G<W1R("+-W=D@
MW]PB"@HC.B!S96%R8V@N<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`BS=W9
M(-_<(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,X"FUS
M9VED(")3879E($%T=&%C:&UE;G1S('=I=&@@;65S<V%G92!I;B!S96YT+6UA
M:6P@9F]L9&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M,S,*;7-G:60@(E-A=F4@1')A9G0B"FUS9W-T<B`BS=W9(./3YL_)(@H*(SH@
M<V%V96EM86=E+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B4V%V92!);6%G92(*
M;7-G<W1R("+-W=D@W]PB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C`T
M"FUS9VED(")3879E($EM86=E(&EN($=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4Y('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,3`P"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N
M:6YC.C$R('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-#@*(SH@=&5M<&QA=&5S
M+W!G<"]N;W1A8W1I=F4N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")3879E($]P
M=&EO;G,B"FUS9W-T<B`BSNW'T<?*(,?AX]/*SL_C(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"FUS9VED(")3879E(%-T871I;VYE
M<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,S"B,L(&9U
M>GIY"FUS9VED(")3879E(%]$<F%F="(*;7-G<W1R("+-W=D@X]/FS\DB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G
M:60@(E-A=F4@87,B"FUS9W-T<B`BS=W9(-_<(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W,@IM<V=I
M9"`B4V%V92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U
M;'0@861D<F5S<R!B;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@87,@82!V:7)T
M=6%L(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S,`HC+"!F=7IZ>0IM<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S
M='(@(LW=V2#'X='3Q^')(,?AX]'3X<DB"@HC.B!C;VUP;W-E+G!H<#HQ,C(W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I;&5D
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("+-
MW=D@S=[A(,?AX]/FS\DN(.70QR#CQR#>Q^'E(,?AX\[/XZ`Z("5S("(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E
M<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L
M9&5R<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R("+(S<LB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHQ,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4V5A<F-H("5S(@IM<V=S='(@(LC-RR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!/<'1I;VYS(@IM<V=S
M='(@(L[MQ]''RB#'X>/3RL[/XR(*"B,Z('-E87)C:"YP:'`Z,C8U"FUS9VED
M(")396%R8V@@4F5S=6QT<R(*;7-G<W1R("+DRL?&S"#'X<C-RR(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,30@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHS,0IM<V=I9"`B4V5E;B(*;7-G<W1R("+DV=$B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*;7-G:60@(E-E;&5C
M="(*;7-G<W1R("+'SLK1(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C<P"B,L(&9U>GIY"FUS9VED(")396QE8W0@06YO=&AE<B!!8V-O
M=6YT(@IM<V=S='(@(L?.RM$@X<<@U.W!(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]F:65L9',N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E
M(@IM<V=S='(@(L?.RM$@X]K1W2(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE
M;&1S+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS
M9W-T<B`BQ\[*T2#'X=_A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S$W"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!S=&%T:6]N97)Y
M.B(*;7-G<W1R("+'SLK1(.''(-3MP2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S4*;7-G:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F
M;W(@861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T
M<B`BQ\[*T2#CU<_1(-/,X2#'X=KDQ^;MY"#AQ=;'W<D@YL?AR,W+("#=[2#'
MX=KDQ^;MY"XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS
M9VED(")396QE8W0@86QL(@IM<V=S='(@(L?.RM$@Q^'?X2(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG
M(&%D9')E<W-E<RXB"FUS9W-T<B`BQ\[*T2#'X<K1RNW((,?AT.T@RM'MSR##
MY"#MRN,@Q^'(S<L@R.4@VN3/(-W*S2#3S.''RB#'X=KDQ^;MY"X@(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@(L?.RM$@
MX<<@U.W!(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I
M9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`BQ\[*T2#AQR#4[<$B"@HC.B!T96UP
M;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B4V5L96-T
M('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C(Q
M"FUS9VED(")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"B,L
M(&9U>GIY"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G<W1R
M("+3S.''RB#'X=KDQ^;MY"#'X>/.RL?1R:`Z(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<R"FUS9VED(")396YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R
M=F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,#0*(RP@9G5Z>GD*;7-G:60@(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM
M<V=S='(@(N/:X>;CQ\H@Q^'CSL_C(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#,Q"FUS9VED(")396YD($UE<W-A9V4B"FUS9W-T<B`BP]'3X2#1T\?AR2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,#,*;7-G:60@(E-E;F0@<F5A
M9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD97(_(@IM<V=S
M='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PHC+"!F=7IZ>0IM<V=I9"`B4V5N
M="!M86EL(&9O;&1E<B(*;7-G<W1R("+CS.'/(,?AT=/'QN$@Q^'CT=/AR:`Z
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS.`IM
M<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`BX\SASR#'X='3Q\;A
M(,?AX]'3X<F@.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS9W-T<B`BQ^'C
MSL_C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"B,L(&9U>GIY"FUS
M9VED(")397)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G<W1R("+C
MVN'FX\?*(,?AX\[/XR(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R.B(*;7-G<W1R("+'X>/.
MS^,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P
M<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD
M(&1E;&5T92!M97-S86=E<RXB"FUS9W-T<B`BULC8(,?AP\_'P2#AX\<@T^W-
MS\L@VN3/X\<@RM[FXR#(Y-[A(,/F(,7AV\?!("#'X='3Q\;A+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO
M<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0HC+"!F=7IZ>0IM<V=I
M9"`B4VAA<F4@1F]L9&5R<R(*;7-G<W1R("+CS.'/Q\HB"@HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z.#8*(RP@9G5Z>GD*;7-G:60@(E-H87)E(&UA:6P@
M9F]L9&5R<R(*;7-G<W1R("+CS.'/(,?AT=/'QN$@Q^'CT=/AR:`Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R"FUS9VED(")3:&%R92!Y;W5R(&UA
M:6P@9F]L9&5R<R!W:71H(&]T:&5R('5S97)S+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8Y"FUS9VED("(B"B)3:&]U;&0@;&%R
M9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B
M>2!D969A=6QT/R!)="!C86X@8F4@(@HB=&]G9VQE9"!E87-I;'D@=VAI8VAE
M=F5R('EO=2!C:&]O<V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I
M;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B4VAO=6QD
M('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@
M9')A9G0_(@IM<V=S='(@(N7A(.W,R"#%V^''WB#DQ]W0R2#%T=/'X2#'X='3
MQ\;A(,C:SR#-W=D@Q^'CT^;/Q\H@OR(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B
M92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`BV.T@S./MVB#'
MX>/,X<_'RB(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8W
M"FUS9VED(")3:&]W($%L;"!(96%D97)S(@IM<V=S='(@(B(*"B,Z(&UA:6QB
M;W@N<&AP.C,V-0IM<V=I9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(MK1UB#'
MX>/AV^TB"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV,0IM
M<V=I9"`B4VAO=R!,:6UI=&5D($AE861E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-S`*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T:6]N(@IM<V=S='(@(N/:X>;C
MQ\H@U,[5[<DB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"B,L
M(&9U>GIY"FUS9VED(")3:&]W($]N;'D@4W5B<V-R:6)E9"!&;VQD97)S(@IM
M<V=S='(@(L?AQ]3*T<??(-WM(,?AX\SASR`H(,?AX\SAS\?*("DB"@HC.B!F
M;VQD97)S+G!H<#HR.3@*;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D(@IM<V=S
M='(@(MK1UB#;[=$@Q^'CU,K1WR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV,#@*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@
M;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,#(*;7-G:60@(E-H;W<@;&5G96YD
M(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S='(@(L79Y<?1RMW3[=''RB##
MR^3'P2#:T=8@U>3/YMX@Q^'(T>W/(+\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#0P"FUS9VED(")3:&]W('!R979I97=S(&9O<B!U;G)E860@;65S
M<V%G97,@;VYL>3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@T.`IM<V=I9"`B4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W-PIM<V=I9"`B
M4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H92!M96YU8F%R/R(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@
M(E-H;W<@=&AE($EM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z-30*;7-G:60@(E-H;W<@=&AE(&9I;'1E<B!I8V]N
M(&]N('1H92!M96YU8F%R/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,C@*;7-G:60@(E-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS
M(&EN(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8V-@IM<V=I9"`B4VAO=VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I
M9"`B4VE?>F4B"FUS9W-T<B`BS<SC(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B4VEG;F5D(@IM<V=S='(@
M(LW,XR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS
M"FUS9VED(")3:7IE(@IM<V=S='(@(LW,XR(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3$*;7-G:60@(E-O<G0@8GD@07)R
M:79A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C$V"FUS9VED(")3;W)T(&)Y($1A=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR
M-@HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!&<F]M($%D9')E<W,B"FUS9W-T
M<B`BX^0@Q^':Y.;'Y"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z-#$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@365S<V%G
M92!3:7IE(@IM<V=S='(@(LW,XR#'X='3Q^')(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B
M4V]R="!B>2!3=6)J96-T(@IM<V=S='(@(N''(.WFS,\@X^;6YMHB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"B,L(&9U
M>GIY"FUS9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R("+3X=/AR2(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(E-O<G0@8GD@5&\@061D<F5S<R(*;7-G<W1R("+CY"#'
MX=KDYL?D(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S
M"B,L(&9U>GIY"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`BT^')(,?A
MX^7CX<?*H#HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G<W1R("+1X^;2(,['
MU<DB"@HC.B!S96%R8V@N<&AP.C$S,PIM<V=I9"`B4W!E8VEA;"!6:7)T=6%L
M($9O;&1E<G,@8V%N(&YO="!B92!E9&ET960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T,PIM<V=I9"`B4W!E;&P@
M0VAE8VLB"FUS9W-T<B`BRL_>[=X@Q>/AQ\;M(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")3<&5L;"!#:&5C:V5R(@IM
M<V=S='(@(L?AX\_>WB#'X<7CX<?&[2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@(L?A
MQ^3*Y<?!(./D(,?ARL_>[=X@Q^'%X^''QNTB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#<Q"FUS9VED(")3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E
M;B!W:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R("+:S\\@Q^'#SMC'P2#'
MX<7CX<?&[<D@X=_A(-3'U,D@P\ODQ\$@Q^'*S][MWB#'X<7CX<?&[2XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$R(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-3(*;7-G:60@(E-T87)T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G
M:60@(E-T871I;VYE<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y
M<&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*
M;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T<B`BX]'=WB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A
M:W,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-U8E]J96-T(@IM<V=S
M='(@(L?AX^;6YMHB"@HC.B!M97-S86=E+G!H<#HR-C@@=&AR96%D+G!H<#HQ
M-3`@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O
M4V5A<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+'X>/FUN;:
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B4W5B:F5C
M="!&:65L9"(*;7-G<W1R("+-WN$@Q^'CYM;FVB(*"B,Z('-E87)C:"YP:'`Z
M,S$X('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.`HC.B!T
M96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C`@=&5M<&QA=&5S+W!G
M<"]P87-S<&AR87-E+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B4W5B;6ET(@IM
M<V=S='(@(L?AX^;6YMHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R
M("+'X<?4RM''WR#=[2#'X>/,X<\@*"#'X>/,X<_'RB`I(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HS.#`@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@W"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(N3,Q\TB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S='(@
M(N/>RM'-Q\HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8R(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(E-U;6UA<GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`P
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,PIM<V=I9"`B4W=I
M=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!(
M5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O('!L86EN('1E
M>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#$Y"B,L(&9U>GIY"FUS9VED(")495]X="(*;7-G
M<W1R("+DU2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-CD*;7-G
M:60@(E1E;G1A=&EV93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U
M97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M-C$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@
M<W!E8VEF:65D(&EN(&-O;F8N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R
M("+DU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-30*;7-G:60@(E1H
M92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME
M9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,S(*;7-G
M:60@(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P
M<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0
M;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q
M"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@
M8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I
M;'!R969S+G!H<#HX,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(LKC
M(,7AV\?!(,?AY>;MR2!<(B5S7"(@R.3,Q\TN(@H*(SH@9F5T8VAM86EL<')E
M9G,N<&AP.C<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C
M;W5N="!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(LKC(,W=V2#'
MX>7F[<D@7"(E<UPB(,CDS,?-+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C0S"FUS
M9VED(")4:&4@871T86-H;65N="!W87,@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CD*;7-G:60@(E1H92!C
M86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I9"`B
M(@HB5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P
M<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P
M('=I;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L
M961O=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C
M:6YT;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I(%PB
M)7-<(B!W:6QL(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("+3YMT@
M[<KC(,K;[>W1(,/3X\?!(,?AX\SASR`HQ^'CS.'/Q\HI(,?AS<?A[<D@7"(E
M<UPB(,7A["!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P
M-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C
M8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM
M<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92!<(B5S7"(@
M9F]L9&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3,Y"FUS9VED(")4:&4@979E;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L
M96YD87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N
M9"YI;F,Z.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I96QD
M(%PB)7-<(B!C86XG="!B92!E>'!A;F1E9"XB"FUS9W-T<B`BRN,@Q>';Q\$@
MQ^'EYNW)(%PB)7-<(B#(Y,S'S2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D
M>2!E>&ES=',B"FUS9W-T<B`BQ^'CS.'/(%PB)7-<(B#CYLSFSR#CT\C>QR(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@9F]L9&5R(%PB)7-<(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E
M<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S92`B"B)P<F]B;&5M<RX@4&QE
M87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"B+'X>/,X<\@7"(E<UPB(.W-RN;M(-KA["#1X^;2(-OMT2#CWLCFX<D@W>T@
MQ]/CY2X@WL\@[<3/[2#0X=\@Q>'L(./4Q]_A("(*(L?AT<S'P2#CT<?,VLD@
MX\_MT2#'X>39Q^,N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4V"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U
M="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`BRN,@
MQ>34Q\$@Q^'CS.'/(%PB)7-<(B#FX=_D(.'C(.W*XR#%U-''W]\@R.4N(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F;VQD97(@7"(E<UPB('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@
M=6YS=6)S8W)I8F5D(&9R;VT@:70N(@IM<V=S='(@(LKC(,7AV\?!(,?AX\SA
MSR!<(B5S7"(@YN'?Y"#AXR#MRN,@Q>';Q\$@Q]3*T<??WR#(Y2XB"@HC.B!L
M:6(O1F]L9&5R+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O
M;&1E<B!<(B5S7"(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED(@IM<V=S='(@(N'C(.W*XR#%Y-3'P2#'X>/,X<\@7"(E
M<UPB("X@Y=#'(./'(,/=Q\\@R.4@Q^'CSL_CH"(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<
M(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60B"FUS9W-T<B`BX>,@[<KC(,7AV\?!(,?AX\SASR!<(B5S7"(@+B#ET,<@
MX\<@P]W'SR#(Y2#'X>/.S^,B"@HC.B!L:6(O1F]L9&5R+G!H<#HS-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E
M<W-F=6QL>2!C<F5A=&5D+B(*;7-G<W1R("+*XR#%Y-3'P2#'X>/,X<\@7"(E
M<UPB(,CDS,?-+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY
M(&1E;&5T960N(@IM<V=S='(@(LKC(,7AV\?!(,?AX\SASR!<(B5S7"(@R.3,
MQ\TN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE
M9"!T;R!<(B5S7"(N(@IM<V=S='(@(LKC(,7:Q\_)(,K3X^W)(,?AX\SASR!<
M(B5S7"(@Q>'L(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE
M9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?<V%V96EM86=E7W=I;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE
M(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S
M('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@
M=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.CDW"FUS9VED("(B"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D
M(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@(@HB861D
M<F5S<V)O;VLN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H
M92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3$*;7-G:60@(E1H92!M
M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO
M;F%L(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.CDP"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D
M('1H92!F;VQL;W=I;F<@;65S<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C8U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B)7,@W<?1
MVR#CT\C>QRXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E
M9"!B>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PHC+"!F
M=7IZ>0IM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E
M96X@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("+*XR#%V^''WB#'X='3Q^')
M(,?AS,?1[2#%Y-3'Q.7'+B`@S,?1[2#'X<[1YLPN(@H*(SH@;65S<V%G92YP
M:'`Z,30X"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R("+*XR#%X=O'P2#'X>7F[<D@7"(E<UPB(,CDS,?-
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@
M(LKC(,W=V2#'X>7F[<D@7"(E<UPB(,CDS,?-+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M
M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@
M=&5M<&QA=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H
M92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@
M>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W
M:6YD;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F('1H
M92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@(E1H92!R
M97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A
M='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O>FEP
M+G!H<#HV-`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X
M:7-T(&EN('1H92!::7`@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;65S
M<V%G92YP:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD
M97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H
M879E(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N
M9"!T:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4:&4@<V5R
M=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI
M<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@8V]U
M;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R("+*VM#1(,K;[>W1(,?ARN;>
M[=HN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#(*;7-G
M:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"XB
M"FUS9W-T<B`BRN,@RMOM[=$@Q^'*YM[MVB#(Y,S'S2XB"@HC.B!A='1A8VAM
M96YT+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB
M(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R("+*XR#-W=D@Q^'EYNW)(%PB)7-<
M(B#(Y,S'S2XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(LKC(,7AV\?!(,?AY>;MR2!<(B5S7"(@R.3,
MQ\TN(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A
M=&5D+B(*;7-G<W1R("+*XR#%X=O'P2#'X>7F[<D@7"(E<UPB(,CDS,?-+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-CD*;7-G:60@(E1H92!T
M87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDU"B,L(&9U>GIY
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92(*;7-G<W1R("+%X=O'
MP2#1T\?AR2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N
M960@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T
M:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92(*
M;7-G<W1R("+%VL?/R2#*YLSMY2#ET.4@Q^'1T\?AR2(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E
M9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$U-`HC+"!F=7IZ>0IM<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF
M;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T<B`BRN,@
MRMOM[=$@Q^'*YM[MVB#(Y,S'S2XB"@HC.B!L:6(O34E-12]6:65W97(O86QT
M97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I
M=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z
M,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O
M>"XB"FUS9W-T<B`BX<<@RN;,SR#1T\?&X2#=[2#5Y,_FWB#'X<C1[<\N(@H*
M(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES(&YO('1E>'0@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R("+EY,?AWR#CU-_AR2#DVMCA("5S+B#ET,<@
MX\<@P]W'SR#(Y2#'X>/.S^,@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,B
M"FUS9W-T<B`BY>3'X=\@X]3?X<D@RMK8X2#5Y,_FWB#'X<C1[<\N(.70QR#C
MQR##W<?/(,CE(,?AX\[/XZ`Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8R
M,0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA
M:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B
MY>3'X=\@X]3?X<D@RMK8X2#5Y,_FWB#'X<C1[<\N(.70QR#CQR##W<?/(,CE
M(,?AX\[/XZ`B"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG
M(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+EY,?AWR#.V,<@W>T@Y-/.
M(,?AT=/'QN$@Q>'L("!<(B5S7"(N(.70QR#CQR##W<?/(,CE(,?AX\[/XR(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HQ.3@@;&EB+TUE<W-A9V4N<&AP.C(Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T("(*(G1H92!S97)V97(@<V%I9"(*;7-G<W1R("+EY,?AWR#.V,,@
MW>T@Q>';Q\$@Q^'1T\?&X2#CY"#'X>/,X<\@(%PB)7-<(BX@Y=#'(./'(,/=
MQ\\@R.4@Q^'CSL_C(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(W-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T
M:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`BY>3'X=\@SMC#(-WM(,7AV\?!
M(,?AT=/'QN$@W>T@Q^'CS.'/("!<(B5S7"(N(.70QR#CQR##W<?/("#(Y2#'
MX>/.S^,B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S
M<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S
M='(@(N7DQ^'?(,[8PR#=[2#%X=O'P2#'X='3Q\;A+B#ET,<@X\<@P]W'SR#(
MY2#'X>/.S^.@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.CDY"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`BY>3'X=\@SMC'(-WM
M(-K1UB#'X='3Q^')(,?AX]CAYLC)+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M;&%I;BYP:'`Z-3(@;&EB+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS-PIM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`BY>3'X=\@SMC#(-WM(-K1UB#ET,<@Q^',TL$@
MX^0@Q^'1T\?AR2(*"B,Z(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A
M9V4N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S
M7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B
MY>3'X=\@SMC#(-WM(,K:X>WC(,?AT=/'QN$@W>T@Q^'CS.'/(%PB)7-<(BX@
MY=#'(./'(,/=Q\\@(,CE(,?AX\[/XZ`B"@HC.B!F;VQD97)S+G!H<#HQ-C4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@)7,N(@IM<V=S='(@(L[8PR#=[2#-W=D@X]/FS\DN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@979E;G0Z("5S+B(*;7-G<W1R("+EY,?AWR#.V,<@W>T@VM'6(,?AT=/'
MX<D@Q^'CV.'FR,DN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(N7DQ^'?(,[8
MQR#=[2#:T=8@Q^'1T\?AR2#'X>/8X>;(R2XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@
M:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R("+EY,?AWR#.V,,@W>T@Q='3Q^$@
MT=/'X<K?H#H@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z.#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I
M;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(N7DQ^'?(,[8PR#=[2#D
MWN$@Q^'1T\?&X2#%X>P@(%PB)7-<(BX@Y=#'(./'(,/=Q\\@R.4@Q^'CSL_C
MH"(*"B,Z(&-O;7!O<V4N<&AP.C$R-#0*(RP@9G5Z>GD*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N
M(@IM<V=S='(@(N7DQ^'?(,[8PR#=[2#:T=8@Y=#'(,?AS-+!(./D(,?AT=/'
MX<DB"@HC.B!C;VUP;W-E+G!H<#HQ,#`V"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B
M"FUS9W-T<B`BY>3'X=\@SMC#(-WM(,71T\?A(-'3Q^'*WZ`Z("5S(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E
M=F5N=#H@)7,N(@IM<V=S='(@(N7DQ^'?(,[8PR#=[2#%T=/'X2#1T\?ARM^@
M.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=A<R!N;R!T97AT(&EN('1H:7,@;65S<V%G92!P
M87)T(@IM<V=S='(@(N7DQ^'?(,[8PR#=[2#:T=8@Y=#'(,?AS-+!(./D(,?A
MT=/'X<DB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3<*;7-G:60@
M(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY,`IM
M<V=I9"`B(@HB5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E
M9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@(@HB=&AI<SH@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-@IM
M<V=I9"`B5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,#0@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q.`HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,30S(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-3<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,R!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,S$T"FUS9VED(")4:&ES(&%C=&EO;B!I
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,3<Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3D*
M;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,30*;7-G:60@(E1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_(@IM<V=S='(@(M[/(.W3RMO1WB#E
MT,<@R-K6(,?AYM[*+B`@RL/?[<\@Q^''T\KCT<?1OR(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G
M92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q,`IM<V=I9"`B(@HB5&AI<R!M
M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D
M:6=I=&%L;'D@<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$T"FUS9VED(")4:&ES(&UE
M<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&5N
M8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C
M;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T
M('1H92!F;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q-0HC+"!F
M=7IZ>0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*
M;7-G<W1R("(E<R#AQR#MV>71(,?DY2#:Y.;'Y"#(T>W/[2#5Q^'-+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(T,"!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HS-3`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D
M:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-S`*;7-G:60@(E1H:7,@;65S<V%G92!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA
M="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`U
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C0Q-@IM<V=I9"`B5&AI<R!M97-S
M86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@
M(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3
M+TU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,3,Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,X"FUS9VED(")4
M:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P,2!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR.3$*;7-G:60@(E1H:7,@;65S<V%G92!H
M87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C(Q,0IM<V=I9"`B5&AI<R!M97-S86=E('1O(@IM<V=S='(@
M(N70Y2#'X='3Q^')(,7A["(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H:7,@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P
M.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R("+MS,@@Y,_'P2#ET.4@
MQ^'DQ]W0R2#CY"#DQ]W0R2#%Y-3'P2#'X='3Q\;A(@H*(SH@=&AR96%D+G!H
M<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@
M(MK<T=8B"@HC.B!T:')E860N<&AP.C<V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,C(*;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@(MK1UB#*T^'3X>TB
M"@HC.B!M97-S86=E+G!H<#HR-C0@;6%I;&)O>"YP:'`Z-C`V('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C8Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S
M92YI;F,Z,3`@;&EB+U-E87)C:"YP:'`Z,C8*;7-G:60@(E1O(@IM<V=S='(@
M(L7A["(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3D*(RP@9G5Z>GD*
M;7-G:60@(E1O($%D9')E<W,B"FUS9W-T<B`BX^0@Q^':Y.;'Y"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C;&EC:VEN9RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HQ,S0*;7-G:60@
M(B(*(E1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B92!R=6YN
M:6YG(&$@=F5R<VEO;B!O9B!02%`@-2XP+C8@;W(@(@HB:&EG:&5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*
M(RP@9G5Z>GD*;7-G:60@(E1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z(@IM<V=S
M='(@(N/1W=['RB(*"B,Z(&9O;&1E<G,N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I
M9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(M/AR2#'X>/EX^''RJ`Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A
M<V@@9F]L9&5R.B(*;7-G<W1R("+3X<D@Q^'CY>/AQ\J@.B(*"B,Z(&QI8B]1
M=6]T82]C>7)U<RYP:'`Z-C4@;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z-SD@
M;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1=6]T82]L;V=F:6QE
M+G!H<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+VUD
M865M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS
M=V5R960B"FUS9W-T<B`BX>,@[='/(-KA[>7'(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M97-S86=E<R(*
M;7-G<W1R("+1T\?&X2#AXR#MRN,@Q^'1SR#:X>WEQR(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T92(*;7-G<W1R("+*
MT<?,VB#:Y"#'X<7AV\?!(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y(&UA:6QB;W@N
M<&AP.C8P,B!L:6(O34E-12](96%D97)S+G!H<#HR,3(*;7-G:60@(E5N9&ES
M8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`BX]/*X>/MY"#CSMWM[>0B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#0W"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T
M<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-38U"FUS9VED(")5;FMN;W=N($1A=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE
M('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8S-0IM<V=I9"`B56YK;F]W;B!-
M965T:6YG(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C8Q.`HC+"!F=7IZ
M>0IM<V=I9"`B56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`BX]/*X>/MY"#C
MSMWM[>0B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P:')A<V4B
M"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5
M;FYA;65D(@IM<V=S='(@(N'C(,K3X^PB"@HC.B!M97-S86=E+G!H<#HT.3D@
M;6%I;&)O>"YP:'`Z-S`X('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$U
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S(*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;&5G96YD+FEN8SHU"FUS9VED(")5;G-E96XB"FUS9W-T<B`B
MX>,@RM'L(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3(*
M;7-G:60@(E5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I(@IM<V=S='(@(L7A
MV\?!(,?AQ]3*T<??(./D(./,X<\@*./,X<_'RBDB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU.#0*;7-G:60@(E5P9&%T92!!='1A8VAM
M96YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,C`*;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I9"`B
M57!L;V%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I
M;'-E;&5C="YI;F,Z-#$*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S
M='(@(L?3RL[/XR#'X=[MX\D@Q^''W<K1Q];MR2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-38*;7-G:60@(E5S92!)34%0(&9O;&1E<B!S=6)S8W)I
M<'1I;VYS/R(*;7-G<W1R("+'T\K.S^,@Q]3*T<??Q\H@X\SASR`@24U!4+\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,U"B,L(&9U>GIY"FUS9VED
M(")5<V4@5FER='5A;"!4<F%S:"!&;VQD97(_(@IM<V=S='(@(N/,X<\@T^')
M(./EX^''RB#=Q]';R2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-#(*
M(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`BQ]/C(,?AX]/*SL_C(@H*
M(SH@86-L+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)5<V5R(%PB
M)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE('-P96-I9FEE9"!R:6=H=',@
M9F]R('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$W-PIM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`BQ]/C(,?AX]/*SL_C(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B
MQ]/C(,?AX]/*SL_C(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR
M-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(E9I97<B"FUS9W-T<B`BVM'6("5S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z.3(@;&EB+TU)344O5FEE=V5R
M+W1N968N<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM
M<V=S='(@(MK1UB`E<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3$V"B,L(&9U>GIY"FUS9VED(")6:65W($A4
M34P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R("+#T=/A
M(-'3Q^')(-WM(.3'W=#)(,S/[<_)(+\B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!-97-S86=E
M<R(*;7-G<W1R("+1T\?&X2#,S^W/R2(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6
M:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<R"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X
M"B,L(&9U>GIY"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R("+3X=/AR2(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,R!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ-C4*;7-G:60@(E9I97<@5&AU;6)N86EL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X"B,L
M(&9U>GIY"FUS9VED(")6:65W(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<B"FUS9W-T<B`BP]'3X2#1T\?AR2#=[2#DQ]W0R2#,S^W/R2"_(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L(&9U>GIY"FUS
M9VED(")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T
M<B`BP]'3X2#1T\?AR2#=[2#DQ]W0R2#,S^W/R2"_(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R
M("(B"@HC.B!F;VQD97)S+G!H<#HS.#`@;6%I;&)O>"YP:'`Z-3,T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S(@IM
M<V=S='(@(MK1UB#'X='3Q\;A(-WM("(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M;FET:6%L<&%G97-E;&5C="YI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN.B(*;7-G<W1R("+4
MW^$@(-7DS^;>(,C1[<\@X>'%V>7'T2#(VL\@Q^'/SN;AH#HB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,3<P"B,L(&9U>GIY"FUS9VED(")6:65W
M('1A<VLB"FUS9W-T<B`BVM'6("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM
M<V=S='(@(MK1UB#'X='3Q\;A(-WM("(*"B,Z('-E87)C:"YP:'`Z,C8S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S
M7"(@8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`BRN,@Q>';Q\$@Q^'C
MS.'/(%PB)7-<(B#(Y,S'S2XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C$Q,2!L:6(O24U!4"]4<F5E+G!H<#HQ,S@@;&EB+TE-05`O5')E92YP
M:'`Z,34Q"B,Z(&QI8B])34%0+U1R964N<&AP.C$U,R!L:6(O24U!4"]4<F5E
M+G!H<#HQ-3<@;&EB+TE-05`O5')E92YP:'`Z,34X"B,Z(&QI8B])34%0+U1R
M964N<&AP.C,V.2!L:6(O24U!4"]4<F5E+G!H<#HS.3,@;&EB+TE-05`O5')E
M92YP:'`Z-#,S"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L($9O;&1E<G,B"FUS
M9W-T<B`BQ>34Q\$@X\SASR(*"B,Z('-E87)C:"YP:'`Z,C0U"FUS9VED(")6
M:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA8F5L+B(*;7-G<W1R("(B"@HC
M.B!L:6(O5D9O;&1E<BYP:'`Z,3<U(&QI8B]61F]L9&5R+G!H<#HQ.#`*;7-G
M:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M-#$V"FUS9VED(")6:7)T=6%L($E.0D]8($9O;&1E<B(*;7-G<W1R("(B"@HC
M.B!M86EL8F]X+G!H<#HT-3(@;&EB+U9&;VQD97(N<&AP.C$Q-"!L:6(O5D9O
M;&1E<BYP:'`Z,3$Y"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(B(*
M"B,Z(&9O;&1E<G,N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B5FER='5A;"!4
M<F%S:"!&;VQD97(B"FUS9W-T<B`BX\SASR#3X<D@X^7CX<?*(-W'T=O)(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U
M86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,S<T"FUS9VED(")787)N:6YG(@IM<V=S='(@(LK-T.W1
M(@H*(SH@;&]G:6XN<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(N/1S<C'(,C?(-WM("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8Q.0IM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@
M9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E
M<&]R=&5D(&%S('-P86T@(@HB;W(@:6YN;V-E;G0_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,C<*;7-G:60@(B(*(E=H96X@9&5L
M971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E
M<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE=&5D/R(*;7-G
M<W1R("(B"B+:Y,\@Q>';Q\$@T=/'QN$@H2#>XR#(Y-[AY<<@Q>'L(./,X<\@
MT^')(,?AX^7CX<?*(,C/X<<@X^0@RMKA[>/EY"#?T=/'QN$@(@HBX^';[<D@
MOR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(E=H96X@
M;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT
M('1O('-T87)T(&]N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L
M9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG
M(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO
M=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R97-S97,@*&5M
M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7:&ET96QI<W0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@(EEE<R(*;7-G
M<W1R("+DVN,B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?
M;&]G:6XN<&AP.C4X"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&%B;W5T('1O
M(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O=6YT*',I.B(*
M;7-G<W1R("+'Y-\@RLW'YN$@Q>';Q\$@Q^'CS.'/Q\H@Q^'*Q^'MR:`Z(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3`*
M(RP@9G5Z>GD*;7-G:60@(B(*(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE
M=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<B(*(BAS*2XB"FUS9W-T<B`BQ^3?(,K-Q^;A(,7AV\?!(,?AX\SAS\?*
M(,?ARL?A[<F@.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N
M9FER;2YH=&UL.CD*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN
M9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@
M(L?DWR#*S<?FX2#%X=O'P2#'X>/,X<_'RB#'X<K'X>W)H#HB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@(EEO=2!A<F4@8V]P>6EN
M9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+B(*;7-G<W1R("+'Y-\@RN33SB_*
MY-[A(,7A["#CS.'/(,S/[<\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ,#(*;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!S=6(M
M9F]L9&5R('1O("(*;7-G<W1R("+'Y-\@RM;MW2#CS.'/(-W1VNT@Q>'L("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED
M(")9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BXB"FUS9W-T
M<B`BT^;=("#*Y-3M(./,X<\@P]/'T^TN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,S(P"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!F;VQD97)S+B(*;7-G<W1R("+3YMT@(,KDU.T@X\SASR##T\?3[2XB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&9O
M;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD
M97(Z("(*;7-G<W1R("+'Y-\@RMKMSR#*T^/MR2#'X>/,X<^@.B`B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HU-3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(EEO=2!C86X@;F]T('5N<W5B<V-R:6)E(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M("+*XR#%X=O'P2#'U,K1Q]_?(,CDS,?-(./D(%PB)7-<(B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R
M<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*(F-U<G)E
M;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N
M="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O('1H92!4
M97)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L
M;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ-CD*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S
M:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O
M;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+B(*;7-G<W1R("+*YLS/(.'/[=\@
M)7,@T=/'X<D@S,_MS\DN(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N
M:6YC.C,*;7-G:60@(EEO=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@
M(N'/[=\@T=/'X<D@YL?-S\D@S,_MS\DN(@H*(SH@8V]M<&]S92YP:'`Z-#DT
M"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T
M:&ES('!A9V4N(@IM<V=S='(@(N'/[=\@T=/'X<D@YL?-S\D@S,_MS\DN(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,3$U"FUS9VED
M("(B"B)9;W4@:&%V92!A="!L96%S="!O;F4@871T86-H;65N="!S96QE8W1E
M9"!T:&%T('EO=2!D:61N)W0@=7!L;V%D('EE="X@07)E("(*(GEO=2!S=7)E
M('EO=2!W86YT('1O('-E;F0@=&AI<R!M97-S86=E('=I=&AO=70@=&AE<V4@
M871T86-H;65N=',_(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-S0*
M;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L
M9&5R.B(*;7-G<W1R("+AS^W?(,C1[<\@S,_MSR#=[2#'X>/,X<\@Q^'*Q^'M
MH#HB"@HC.B!L:6(O24U0+G!H<#HQ,#<Y"FUS9VED(")9;W4@:&%V92!N97<@
M;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(N'/[=\@
MR-'MSR#,S^W/(-WM(,?AX\SAS\?*(,?ARL?A[<F@.B(*"B,Z(&-O;7!O<V4N
M<&AP.C$U,PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@96YT97(@870@;&5A
M<W0@;VYE(')E8VEP:65N="XB"FUS9W-T<B`B[<S((,/D(.W?YN0@X<_MWR#C
MT\K>R.$@YL?-SR#:X>P@(,?AP][A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C,P,@IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P
M:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M
M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,C0Y"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S
M92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*
M(FUE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V
M87-C<FEP="YI;F,Z-C0@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z,C`Q"FUS9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O
M>"!F:7)S="XB"FUS9W-T<B`B[<S((,/D(,K.RL?1(-7DS^;>(,?AR-'MSR#'
MX>7/W2##YN''+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX-0HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`B[<S((,/D(,K.RL?1(.7F[<D@X>W*XR#%X=O'Q.7'
M+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z.#$*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R
M("+MS,@@P^0@RL[*Q]$@VN3FQ^0@P^;AQRXB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP;&%T97,O;6%I;&)O>"]J879A
M<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,C8S"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE
M(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@(NW,R"##Y"#*SLK'T2#1T\?AR2#F
MQ\W/R2#:X>P@Q^'#WN$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E
M8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT
M+B(*;7-G<W1R("+MS,@@RLW/[<\@X]/*X>,N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:G,Z,CD*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I;&4@=&\@871T86-H+B(*;7-G
M<W1R("+MS,@@P^;AQR#*S<_MSR#'X>/AW2#'X>/1Q\\@Q='=Q][E+B(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@;F5E9"!T;R!H879E(%PB)7-<(B!E;F%B;&5D(&EN
M('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TUA:6QL;V<N<&AP.C$S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(')E9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS
M9W-T<B`BQ=K'S\D@RN;,[>4@Y=#E(,?AT=/'X<DB"@HC.B!L:6(O36%I;&QO
M9RYP:'`Z,30Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5P
M;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM<V=S='(@(L7:Q\_)(,KF
MS.WE(.70Y2#'X='3Q^')(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3`W"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(%PB
M)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("+A
MXR#*W^0@X]3*T=_'(,C<(%PB)7-<(BX@Y=#'(./'(,/=Q\\@R.4@Q^'CSL_C
MH"(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E
M(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(N'C(.W*XR#%X=O'
MP2#'U,K1Q]_?(./D("!<(B5S7"(N("#ET,<@X\<@P]W'SR#(Y2#'X>/.S^.@
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*
M;7-G<W1R("+*XR#%U-''W]\@R.3,Q\T@W>T@(%PB)7-<(B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C4V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S
M=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB(@IM<V=S='(@
M(LKC(,7AV\?!(,?4RM''W]\@R.3,Q\T@X^0@7"(E<UPB(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.CDX"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B
M"FUS9W-T<B`BQ]/CWR#'X=_'X^&@.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHU,`IM<V=I9"`B66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Q('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW-@IM<V=I9"`B66]U<B!0<FEV871E($ME
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,0HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!0=6)L:6,@2V5Y(@IM<V=S='(@(L?3X]\@Q^'?Q^/AH#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,38U"B,L(&9U>GIY"FUS9VED(")9;W5R(%)E
M<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S='(@
M(MKDYL?D(#H@Q^'1SR#%X>R@.B`\:3XHQ\[*[<?1[2D\+VD^(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHT.0IM<V=I9"`B66]U<B!3+TU)344@
M4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C$V"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&%C8V]U;G1S.B(*;7-G<W1R("+CVM'=Q\K?.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S,*;7-G:60@(B(*(EEO=7(@
M86QI87,@861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D
M9')E<W,@;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@
M=&AI<R!I;6%G92!T>7!E+B(*;7-G<W1R("+AQR#MS]KC(./*U=W-WR#'X=K1
MUB#'X<_'SN'M(.'ET,<@Q^'DYMH@X^0@Q^'5YM$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F
M;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F875L
M="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E
M;&EV97)E9"XB"FUS9W-T<B`BRN,@Q>';Q\$@Q^'CS.'/(%PB)7-<(B#(Y,S'
MS2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R
M('-I9VYA='5R93HB"FUS9W-T<B`BRN;>[=K?H#HB"@HC.B!M97-S86=E+G!H
M<#HR.#@@8V]M<&]S92YP:'`Z,3(X-"!M86EL8F]X+G!H<#HU-#D@;&EB+T-O
M;7!O<V4N<&AP.C@Q.`IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EOA
MQR#MYLS/(./FUN;:72(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(P-0HC+"!F=7IZ>0IM<V=I9"`B7T)C8R(*;7-G<W1R("+CT=W>(./.
MW>TB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*(RP@9G5Z>GD*
M;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`BQ^'>Q\;CR2#'X=/FS\?!(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,34T"B,L(&9U>GIY
M"FUS9VED(")?0V,B"FUS9W-T<B`BY-/.R2(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3`*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`BQ>';Q\$B"@HC
M.B!L:6(O24U0+G!H<#HY-SD*(RP@9G5Z>GD*;7-G:60@(E]&;VQD97)S(@IM
M<V=S='(@(N/,X<_'RB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C@Q"B,L(&9U>GIY"FUS9VED(")?261E;G1I='DB"FUS9W-T<B`BY>;M
MR2(*"B,Z(&QI8B])35`N<&AP.CDV,0IM<V=I9"`B7TEN8F]X(@IM<V=S='(@
M(B(*"B,Z(&QI8B])35`N<&AP.C$P,C`*(RP@9G5Z>GD*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(L[1YLPB"@HC.B!M97-S86=E+G!H<#HS.#0*(RP@9G5Z
M>GD*;7-G:60@(E]-97-S86=E(%-O=7)C92(*;7-G<W1R("+CW^;DQ\H@Q^'1
MT\?AR2(*"B,Z(&QI8B])35`N<&AP.CDW-@HC+"!F=7IZ>0IM<V=I9"`B7TYE
M=R!-97-S86=E(@IM<V=S='(@(M'3Q\;A(,S/[<_)(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"B,L(&9U>GIY"FUS9VED
M(")?4')I;G0B"FUS9W-T<B`BV,C'VLDB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,C@Y"FUS9VED(")?4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@;6%I;&)O
M>"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")?4F5F<F5S
M:"`E<R(*;7-G<W1R("+*S<_MRR(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED(")?4F5P;'DB"FUS
M9W-T<B`BQ^'1SR(*"B,Z(&QI8B])35`N<&AP.CDX,0HC+"!F=7IZ>0IM<V=I
M9"`B7U-E87)C:"(*;7-G<W1R("+(S<LB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHT,S$*(RP@9G5Z>GD*;7-G:60@(E]396YD($UE<W-A9V4B"FUS9W-T<B`B
MP]'3X2#1T\?AR2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(E]4:')E860B"FUS9W-T<B`B
MT^'3X<DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*
M(RP@9G5Z>GD*;7-G:60@(E]4;R(*;7-G<W1R("+%X>PB"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B7U5N
M9&5L971E(@IM<V=S='(@(LK1Q\S:(-KD(,?AQ>';Q\$B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G
M:60@(E]6:65W(%1H<F5A9"(*;7-G<W1R("+3X=/AR2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<V"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#0P"B,L
M(&9U>GIY"FUS9VED(")A='1A8VAM96YT(@IM<V=S='(@(N/1W=XB"@HC.B!V
M:65W+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B871T86-H;65N=',N>FEP(@IM
M<V=S='(@(N/1W=['RB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C4Q,PIM<V=I9"`B8GET97,B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C(P,`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<R"FUS9VED(")C86YN
M;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,38T"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(R,`IM<V=I9"`B8V]N9FEG=7)A=&EO
M;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DV"FUS
M9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C@*;7-G:60@(F1A=&$@9F]R;6%T(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C0*;7-G:60@
M(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B9G)O;2(*;7-G<W1R("+C
MY"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#`*;7-G:60@(FAO<W0@;F%M92!U
M;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#0*;7-G
M:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3@X"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,CD@<&=P+G!H<#HV.0IM<V=I9"`B
M:V5Y(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C$V,0HC+"!F=7IZ>0IM
M<V=I9"`B;6%I;&)O>"!F:6QE(@IM<V=S='(@(M7DS^;>(,?AR-'MSR(*"B,Z
M(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP.C0V-@HC+"!F=7IZ
M>0IM<V=I9"`B;F%M92(*;7-G<W1R("+'X<?3XR(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*;7-G<W1R("+A
MQR#4[<$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U
M"FUS9VED(")O<B(*;7-G<W1R("+#YB(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR
M,38*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HR,3(*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@T"FUS9VED
M(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R
M;W(B"FUS9W-T<B`BSMC#(,7CX<?&[2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W)S(@IM<V=S
M='(@(L/.V,?!(,7CX<?&[<DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DR"B,L
M(&9U>GIY"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`BSMC#(,7CX<?&
M[2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#@*;7-G:60@(G1E;7!O<F%R>2!F
M86EL=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C4Q"B,L(&9U
M>GIY"FUS9VED(")Y;W5R(&)L86-K;&ES="(*;7-G<W1R("+'X=['QN/)(,?A
MT^;/Q\$B"@HC.B!L:6(O1FEL=&5R+G!H<#HV,0IM<V=I9"`B>6]U<B!W:&ET
M96QI<W0B"FUS9W-T<B`B(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+W!O+W5K7U5!+G!O````````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#,U-C,S-0`Q,#0Q-S,V,C<V-``P,3<R,3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R!)35`@56MR
M86EN:6%N($M/23@M52!T<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P
M,B!!;F1R:7D@2V]P>7-T>6%N<VMY+@HC($%N9')I>2!+;W!Y<W1Y86YS:WD@
M/&%N<FE`<&]L>6YE="YL=FEV+G5A/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U0('8S+C%<;B(*(E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`R+3`Q+3`Y(#$Y.C`R*S`R,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@06YD<FEY($MO<'ES='EA;G-K>2`\86YR:4!P;VQY;F5T
M+FQV:78N=6$^7&XB"B),86YG=6%G92U496%M.B!5:W)A:6YI86X@/'=E8FUA
M<W1E<D!P;VQY;F5T+FQV:78N=6$^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4M/23@M55QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HT,3@*;7-G:60@(B`@("`@($-C.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q-0IM<V=I9"`B("`@("`@5&\Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@
M1&%T93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#8*(RP@
M9G5Z>GD*;7-G:60@(B`@("!&<F]M.B`B"FUS9W-T<B`B]Z;$.B(*"B,Z(&UA
M:6QB;W@N<&AP.C0R,B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$R"FUS9VED("(@4W5B:F5C=#H@(@IM
M<V=S='(@(B#TQ<W!.B`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-S`*;7-G:60@(B!I;B`B"FUS9W-T<B`B(-<@(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G
M<W1R("(B"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T<B`B)60@VB`E9"#LR=/4IM<B
M"@HC.B!M86EL8F]X+G!H<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+W
MIL3/PM+!VLG4R2#,R=/4(-"FT\S1(-K/T]3/T]77P<[.T2#&ILS8U-*FURXB
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T
M('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
MX\7*(,S)T]0@T,_7IL3/S<S%SLG*(-/)T]3%S<[/S=4@P<3-ILZFT]32P=3/
MTM4@T<L@T]#!S2XB"@HC.B!L:6(O4W!A;2YP:'`Z,34X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86TN(@IM<V=S='(@(N/%RB#,R=/4(-#/UZ;$S\W,Q<[)
MRB#3R=/4Q<W.S\W5(,'$S:;.IM/4TL'4S]+5(-'+(-/0P<TN(@H*(SH@;&EB
M+U-P86TN<&AP.C$W,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`BX\7*(,S)T]0@T,_7IL3/
MS<S%SLG*(-/)T]3%S<[/S=4@P<3-ILZFT]32P=3/TM4@T<L@T]#!S2XB"@HC
M.B!L:6(O4W!A;2YP:'`Z,34P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS
M9W-T<B`BX\7*(,S)T]0@T,_7IL3/S<S%SLG*(-/)T]3%S<[/S=4@P<3-ILZF
MT]32P=3/TM4@T<L@T]#!S2XB"@HC.B!M86EL8F]X+G!H<#HS-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@=&\@)60@;V8@)60@365S<V%G97,B"FUS9W-T
M<B`B)60@T,\@)60@VB`E9"#LR=/4IM<B"@HC.B!M86EL8F]X+G!H<#HV-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP
M.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B!9
M;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@(B5S(-76
MQ2"FT\[5I"X@]\';P2#0P=#+P2`E<R#.Q2#"U<S!(-#%TL7*S<7.S]?!SL$N
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!M86EL8F]X+B(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N
M=&UA:6Q?;6]N=&AL>2YP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M9F]L9&5R(&)E:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT
M:"XB"FUS9W-T<B`B\,'0R\$@)7,@PM7$Q2#0Q=+%RLW%SL_7P<[!(,[!(-#/
MWL'4R]4@S:;3T</1+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET
M871I;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@
M>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!H87,@=&5N=&%T:79E;'D@86-C97!T960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC
M92!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(O#!T,O!(%PB)7-<(B#5T]"F
MV\[/(-#%TL7*S<7.S]?!SL$@SL$@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES
M:&5S('1O(&%M;65N9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H
M97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO
M;B!A8F]U="`E<RXB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C@U(&UE
M<W-A9V4N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7W1O<"YI;F,Z
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S("@E9"9N8G-P.V]F)FYB
M<W`[)60I(@IM<V=S='(@(B5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@
M(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N
M+BDB"FUS9W-T<B`B*/K!T]3/T]77P=3)(,.F(-K-IL[)(*8@T,72Q<K4R2#.
MP2#.P=/4U=#.R<H@Q<O2P<XN*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHQ,C`*;7-G:60@(BA$:7-C87)D(&%L;"!C:&%N9V5S(&%N
M9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BDB"FUS9W-T<B`B*/>F
MQ,VFSLG4R2##IB#:S:;.R2"F(-#/U\72SM74R=/1(,3/(-/4U\_2Q<[.T2#,
MR=/4P2XI(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V
M"FUS9VED("(H2%1-3"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I
M;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB"FUS9W-T
M<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E='5R;B!T
M;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG
M97,@;6%D92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U<G)E;G0@
M<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H^L'3
MU,_3U=?!U,D@VM+/PLS%SJ8@SL$@P\7*(-[!TR#:S:;.R2"F(-#/U\72SM74
MR=/1(,3/(-/4U\_2Q<[.T2#,R=/4P2X@("(*(OK-IL[)(-4@T,_4S][.S\W5
M(->FR\ZF(.[E(.+UY/7T^"#:P=/4S]//U\'.IBXI(@H*(SH@<W!E;&QI;F<N
M<&AP.C(W-PHC+"!F=7IZ>0IM<V=I9"`B(@HB*%-E;F0@;65S<V%G92!A9G1E
M<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E
M<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE
M9"XI(@IM<V=S='(@(B(*(BCZP=/4S]/5U\'4R2#:TL_"S,7.IB#.P2##Q<H@
MWL'3(-K-IL[)(*8@T,_7Q=+.U=3)T]$@Q,\@T]37S]+%SL[1(,S)T]3!+B`@
M(@HB^LVFSLD@U2#0S]3/WL[/S=4@UZ;+SJ8@[N4@XO7D]?3X(-K!T]3/T\_7
MP<ZF+BDB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R
M-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(P-@IM
M<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS9W-T<B`B
M(@H*(SH@;6%I;&)O>"YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A
M9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BMM#/T]3!T]@@7"(E<UPB
M(-K.R=W%SL\N(@H*(SH@;&EB+U-P86TN<&AP.C$X,`HC+"!F=7IZ>0IM<V=I
M9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(N/%RB#,R=/4
M(-#/UZ;$S\W,Q<[)RB#3R=/4Q<W.S\W5(,'$S:;.IM/4TL'4S]+5(-'+(-/0
MP<TN(@H*(SH@;&EB+U-P86TN<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B,2!M
M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R
M("+CQ<H@S,G3U"#0S]>FQ,_-S,7.R<H@T\G3U,7-SL_-U2#!Q,VFSJ;3U-+!
MU,_2U2#1RR#3T,'-+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S(*(RP@9G5Z>GD*
M;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(N/%RB#,R=/4
M(-#/UZ;$S\W,Q<[)RB#3R=/4Q<W.S\W5(,'$S:;.IM/4TL'4S]+5(-'+(-/0
MP<TN(@H*(SH@;&EB+U-P86TN<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B,2!M
M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(N/%
MRB#,R=/4(-#/UZ;$S\W,Q<[)RB#3R=/4Q<W.S\W5(,'$S:;.IM/4TL'4S]+5
M(-'+(-/0P<TN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q.0HC+"!F
M=7IZ>0IM<V=I9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B\]#%PZ;!S-C.
MIB#3R<W7S\S)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,@HC+"!F
M=7IZ>0IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S='(@(O/0Q<.FP<S8
MSJ8@T\G-U\_,R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C`*(RP@
M9G5Z>GD*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(O/0Q<.FP<S8
MSJ8@T\G-U\_,R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C$*(RP@
M9G5Z>GD*;7-G:60@(C4P,"!C:&%R86-T97)S(@IM<V=S='(@(O/0Q<.FP<S8
MSJ8@T\G-U\_,R2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S
M(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*
M(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E
M='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0IM<V=I
M9"`B04Y$(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.3`*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@(D%C8V5P="!R97%U
M97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U,PIM<V=I9"`B06-C97!T960B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-PIM
M<V=I9"`B06-C97!T960Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="=S
M(&YA;64Z(@IM<V=S='(@(N[!VM?!(*;0S]/4P=.F.B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,C`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<S,`HC+"!F=7IZ>0IM<V=I9"`B06-T:6]N<R(*;7-G<W1R("+OT,72P<.F
MT2(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(P,"!L:6(O34E-12](96%D
M97)S+G!H<#HR,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"`E
M<R!T;R!M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`BY,_$P=3)(,3/(.'$TL73
MSL^G(,O.R<?)("@E<RDB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHS,#,*(RP@9G5Z>GD*;7-G:60@(D%D9"!S;W5R8V4B"FUS9W-T
M<B`BQ,_$P=3)(,36Q=+%S,\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D
M9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N
M<&AP.C$R-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB
M)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("+PTLG+TJ;0S,7.SR#$
MS\3!U,_++B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3@*;7-G:60@
M(B(*(D%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN
M9SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N
M97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I
M=&EO;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L
M(&9U>GIY"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B
M"FUS9W-T<B`B[]//PLG3U,$@ML[&S]+-P<.FT2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.CDS"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@
M9&5T86EL<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A
M9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I;VYA
M;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E
M9"`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z-3(*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R
M("+AQ-+%T\YI(,O.R<?)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-`HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K<R(*;7-G<W1R("+AQ-+%
MT\YI(,O.R<?)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I
M9"`B(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T
M:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO
M96T^(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#$*
M;7-G:60@(B(*(D%D9')E<W-E<R!T;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES
M(&ED96YT:71Y.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H("(*(F%D9')E
M<W,@;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,C,*;7-G:60@(D%L;"(*;7-G<W1R("+7TZ8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$S"FUS9VED("(B"B)!;&P@;65S<V%G
M97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A
M9&5D(&EN=&\@;VYE($U"3U@@(@HB9FEL93HB"FUS9W-T<B`B]].F(,S)T]3)
M(-4@SL'3U-70SLG((-#!T,'((,+5Q-74V"#:P=?!SM3!UL7.IB#7(,_$SLG.
M(,;!RLP@34)/6#H@(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?
M=')A<V@N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S
M86=E<R!I;B!Y;W5R(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES
M('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB
M]]-I(,S)T]3)(-4@]\';:<H@T,'0PVD@7"(E<UPB+"#1RZ8@T]3!TMNF(-K!
M("5S(,3.:=<@PM7$U=38(,[!VL'7UL3)("(*(MK.R=W%SFDN(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN
M<&AP.C4Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI
M;FME9"!A='1A8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL
M(&)E(&1E;&5T960N(@IM<V=S='(@(O?3IB#0P=#+R2#7IL2FT\S!SL^G(-#/
MV]3)+"#1RZ8@T]3!TMNF(-K!("5S(,VFT]'#IM<L(,+5Q-74V"#7R=3%TM2F
M+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E
M;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@
M8F4@9&5L971E9"XB"FUS9W-T<B`B]].F(-#!T,O)(->FQ*;3S,'.SZ<@T,_;
MU,DL(-'+IB#3U,'2VZ8@VL$@)7,@S:;3T<.FURP@PM7$U=38(-?)U,72U*8N
M(@H*(SH@86-L+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M06QL(')I9VAT<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO
M=F5D(&9O<B!U<V5R(%PB)7-<(BXB"FUS9W-T<B`B\,'0R\$@7"(E<UPB(-73
MT*;;SL\@T,72Q<K-Q<[/U\'.P2#.P2!<(B5S7"(N(@H*(SH@;&EB+V%P:2YP
M:'`Z-S8*;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A=&EO;C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0X"FUS9VED(")!
M;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O
M>#\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E
M+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E
M8W1I;VXZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-S(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X-`IM<V=I9"`B06QW87ES(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3<*(RP@9G5Z
M>GD*;7-G:60@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(O#2
MR<O2IM#,Q<[/(,3/Q,'4S\LN(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4P-0IM
M<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O
M('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@(@HB<V%I
M9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#@*(RP@9G5Z
M>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A
M=&EN9R!T:&4@;F5W(&YO=&4N(@IM<V=S='(@(O32P=#)S,'3T2#.Q=>FQ,_-
MP2#0S\W)S,O!(-#2R2#$S\3!SLZF(,[/U\_'SR#:P=#)T]4N(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C,X-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RXB"FUS
M9W-T<B`B]-+!T,G,P=/1(,[%UZ;$S\W!(-#/S<G,R\$@T-+)(,3/Q,'.SJ8@
MSL_7S\?/(-K!T,G3U2XB"@HC.B!M97-S86=E+G!H<#HU,#`@;6%I;&)O>"YP
M:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R("+:)FYB<W`[
MUZ;$T,_7IL3$P"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S$*
M;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(NS)T]3)(-H@UZ;$
MT,_7IL3$P"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PHC
M+"!F=7IZ>0IM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R("+ZP=/4S]/5
MU\'4R2#&ILS8U-+)(-#2R2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07!P;'D@1FEL
M=&5R<R!T;R`E<R(*;7-G<W1R("+ZP=/4S]/5U\'4R2#&ILS8U-+)(-#2R2(*
M"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS-@HC+"!F=7IZ>0IM
M<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P;VX@;&]G9VEN9R!O;C\B"FUS
M9W-T<B`B^L'3U,_3U=?!U,D@QJ;,V-32R2#0TLD@U\C/Q*8B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#(*;7-G:60@(D%P<&QY(&9I;'1E
M<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\B"FUS9W-T<B`B
M]\D@U]#%U\[%SJ8L(-W/(,C/WL74Q2#NX?KA]_;DZ2#7R=3%TM3)(,.F(,S)
MT]3)/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E
M8V]M;65N9&5D(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHV
M"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@
M=&AI<S\B"FUS9W-T<B`B]\D@]_#E]^[E[K8L(-W/(,C/WL74Q2#0TL_$S]?6
MR=3)/R(*"B,Z(&UE<W-A9V4N<&AP.C0P-R!T96UP;&%T97,O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8SHV.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T
M<B`B]\D@U]#%U\[%SJ8L(-W/(,C/WL74Q2#NX?KA]_;DZ2#7R=3%TM3)(,.F
M(,S)T]3)/R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z
M>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,
M62!D96QE=&4@=&AI<R!A='1A8VAM96YT/R(*;7-G<W1R("+WR2#7T,77SL7.
MIBP@W<\@R,_>Q=3%(.[A^N'W]N3I(-?)U,72U,D@PZ8@S,G3U,D_(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*(RP@9G5Z>GD*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E
M<C\B"FUS9W-T<B`B]\D@U]#%U\[%SJ8L(-W/(,C/WL74Q2#NX?KA]_;DZ2#7
MR=3%TM3)(,.F(,S)T]3)/R(*"B,Z(&QI8B])35`N<&AP.CDW,PHC+"!F=7IZ
M>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@
M<W!A;2!F;VQD97(_(@IM<V=S='(@(O?)(-?0Q=?.Q<ZF+"#=SR#(S][%U,4@
M[N'ZX??VY.D@U\G4Q=+4R2##IB#,R=/4R3\B"@HC.B!L:6(O24U0+G!H<#HY
M-C8*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E
M;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`B]\D@U]#%U\[%SJ8L
M(-W/(,C/WL74Q2#NX?KA]_;DZ2#7R=3%TM3)(,.F(,S)T]3)/R(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*(RP@9G5Z>GD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@
M=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(O?)(-?0Q=?.Q<ZF+"#=SR#(S][%
MU,4@[N'ZX??VY.D@U\G4Q=+4R2##IB#,R=/4R3\B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]J879A<V-R:7!T+FEN8SHX,"!T96UP;&%T97,O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8SHW.0HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_
M(@IM<V=S='(@(O?)(-?0Q=?.Q<ZF+"#=SR#(S][%U,4@[N'ZX??VY.D@U\G4
MQ=+4R2##IB#,R=/4R3\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R
M:7!T+FEN8SHW-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW
M-`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E
M<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\B"FUS9W-T<B`B]\D@U]#%U\[%
MSJ8L(-W/(,C/WL74Q2#NX?KA]_;DZ2#7R=3%TM3)(,.F(,S)T]3)/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,38*;7-G:60@(D%R<FEV86P@5&EM
M92(*;7-G<W1R("+^P=,@SL'$R,_$UL7.SM$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B\,\@VM+/
MT]3!SL[`(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$Y"FUS9VED(")!='1A
M8V@B"FUS9W-T<B`B\-+)R]*FT,G4R2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0W-0HC+"!F=7IZ>0IM<V=I9"`B071T86-H($9I;&5S
M(@IM<V=S='(@(N3/Q,'4R\DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT-38*;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@
M<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(D%T
M=&%C:&5D($9I;&4Z(@IM<V=S='(@(O#2R<O2IM#)U,DB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z-#4Q(&QI8B]#;VUP;W-E+G!H<#HU,S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB071T86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@
M871T86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S8*;7-G
M:60@(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T
M('EO=2!S96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L
M96=E;F0N:6YC.C$V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN
M8SHQ-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#8@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3<*;7-G:60@(D%T=&%C
M:&UE;G0B"FUS9W-T<B`BY,_$P=3/RR(*"B,Z(&-O;7!O<V4N<&AP.C$P-C<@
M;&EB+TUE<W-A9V4N<&AP.C0V-@IM<V=I9"`B071T86-H;65N="!S=')I<'!E
M9#H@3W)I9VEN86P@871T86-H;65N="!T>7!E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T.2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT-S,*(SH@;&EB+T-O;7!O<V4N<&AP.C$P-S,*
M;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S='(@(N3/Q,'4R\DB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C@R"B,L(&9U>GIY"FUS9VED(")!='1E
M;F1E97,B"FUS9W-T<B`BY,_$P=3+R2(*"B,Z(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!='1E;G1I;VXB
M"FUS9W-T<B`B[]#%TL'#IM$B"@HC.B!L:6(O075T:"]I;7`N<&AP.C0T"FUS
M9VED(")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0P
M"FUS9VED("(B"B)!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A434P@
M;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*(F%D9')E<W-B
M;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHR.3@*(RP@9G5Z>GD*;7-G:60@(D%V86EL86)L92!!9&1R97-S
M(&)O;VMS.B(*;7-G<W1R("+DS]/4U=#.IB#AQ-+%T\ZF(,O.R<?).B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET:6YG
M(%)E<W!O;G-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D)A8U]K('1O("5S(@IM<V=S='(@(N[!VL'$(,3/("5S(@H*(SH@=&AR
M96%D+G!H<#HQ,S<@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"86-K('1O("5S(@IM<V=S
M='(@(N[!VL'$(,3/("5S(@H*(SH@=&AR96%D+G!H<#HQ,S0*;7-G:60@(D)A
M8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN9&5X(@IM<V=S='(@(B(*
M"B,Z('1H<F5A9"YP:'`Z,3,R"FUS9VED(")"86-K('1O(%1H<F5A9"!$:7-P
M;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L
M('!H<"UF;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@
M4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP
M:'`Z,C8V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(R"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@;&EB+U-E87)C
M:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G<W1R(")"8V,B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES('1H92!R
M87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I
M9"`B0FQA8VML:7-T(@IM<V=S='(@(K;'SL_2U=?!U,DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C(Y"FUS9VED(")";&]C:R!I;6%G97,@:6X@2%1-
M3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E
M<W1E9#\B"FUS9W-T<B`B(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(*;7-G:60@
M(D)O9'DB"FUS9W-T<B`B]*;,SR(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z,C,@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS.0HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4U('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-S$*;7-G:60@(D)O=&@B"FUS9W-T<B`B[\+)Q-?!(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8X-PIM<V=I9"`B0F]T:"!(96%D97(@3&ES
M=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,@IM<V=I9"`B0U]H87)S970B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R
M96UO=&4@;6%I;"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE
M(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P87)T:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#86X@;F]T(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S
M(&]F('1H:7,@;65S<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*
M;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP
M;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z
M,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L
M871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S
M92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM
M<V=I9"`B0V%N8V5L(@IM<V=S='(@(O>FQ,VFSLG4R2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0S-0HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI
M;F,Z,3$Q"FUS9VED(")#86YC96P@365S<V%G92(*;7-G<W1R("+WIL3-IL[)
MU,D@S,G3U"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@HC+"!F=7IZ>0IM<V=I
M9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D
M:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS9W-T<B`B(@HB]Z;$S:;.P2##V,_'
MSR#,R=/4P2#.P=K!U];$R2#:SLG=R=38(,K/Q\\@U\VFT]0N7%QN]\D@U]#%
MU\[%SJ8L(-W/(,C/WL74Q2##Q2`B"B+:TL_"R=3)/R(*"B,Z(&UE<W-A9V4N
M<&AP.C(V-2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC
M.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI8B]396%R
M8V@N<&AP.C,P"FUS9VED(")#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G:60@(B(*(D-E<G1I9FEC871E(&EM
M<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA
M8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<P,0HC+"!F=7IZ>0IM<V=I9"`B0VAA:7(@
M4&5R<V]N(@IM<V=S='(@(M#2R=?!U,ZF(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B^LVF
MSLG4R2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,0IM
M<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R("+ZS:;.R=3)(-?3IB(*"B,Z('1E
M;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B0VAA;F=E($9O;&1E<B(*
M;7-G<W1R("+ZS:;.R=3)(-#!T,O5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H
M(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N
M9"`B"B)H;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`B(@HB]\O!
MUJ;4V"#/T,.FIR#7IL3/PM+!UL7.SM$@+2#+ILS8RZ;3U-@@S,G3U*;7+"#1
MRZ8@UZ;$S\+2P=K)U,D@SL$@T]3/TJ;.R]4L("(*(J8@T-+!U\G,SR#3S]+4
MU=?!SL[1(,S)T]2FURXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*
M(RP@9G5Z>GD*;7-G:60@(D-H86YG92!M86EL('-E<G9E<B!A;F0@9F]L9&5R
M('-E='1I;F=S+B(*;7-G<W1R("+WR\'6IM38(/?!VR#0S]O4S]?)RB#3Q=+7
MQ=(@U,$@IL[&S]+-P<.FP"#0TL\@T,'0R\DN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E
M<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"`B"B)R97!L>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B+W
MR\'6IM38(*;-)]$L(,'$TL73U2#4P2#0IL30R=,L(-'+IB#0S\+!WL'4V"#W
MP=NF(-+%T]#/SL3%SM3)+"#>R=3!P-[)(,'"SR`B"B+7IL30S]>FQ,'`WLD@
MSL$@]\';(,S)T]0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R-`IM
M<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-0IM<V=I9"`B0VAE8VL@
M1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G<W1R("+PS\3)U\G4R=/1(-K!
M(-/7IM;/P"#0S]O4S\`@UR#0P=#+P<@B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,3`@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(Q"FUS9VED(")#:&5C
M:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O
M;3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V,PHC
M+"!F=7IZ>0IM<V=I9"`B0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@
M82!M97-S86=E/R(*;7-G<W1R("+TTL'0R<S!T]$@T,_-R<S+P2#7IL33R<S!
MSL[1(/?!V\_'SR#,R=/4P2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C0*;7-G:60@(D-H;V]S92!!8W1I;VXZ(@IM<V=S='(@(O?)PL72
MIM38(,_0Q=+!PZ;`.B(*"B,Z(&-O;F9I9R]S97)V97)S+G!H<"YD:7-T.C$X
M,@IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C$W"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E9&ET
M('1H92!A9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,2!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S,Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@86-T:6]N.B(*
M;7-G<W1R("+WR<+%TJ;4V"#/T,72P<.FP#HB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*(RP@9G5Z>GD*;7-G:60@(D-H;V]S
M92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S
M97,N(@IM<V=S='(@(O?+P=:FU-@@X<32Q=/.U2#+SLG'U2#$S-$@Q,_$P=?!
MSL[1(,'$TL73+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('1H92!O<F1E<B!O9B!A
M9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S
M97,N(@IM<V=S='(@(O?+P=:FU-@@WL72Q\_7IM/4V"#AQ-+%T\[)R"#+SLG'
M(,3,T2#0S]O5R]4@P<+/(-?3U,'7R\D@ILW%SBXB"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T
M('EO=7(@8G)O=W-E<B!C86X@=FEE=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQI8VL@)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O1FEL=&5R+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B\,G3P=3)(,S)T]3)
M(-<@S\O2Q<W/S=4@UZ;+SJ8N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I
M97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(O#)T\'4R2#,R=/4R2#7
M(,_+TL7-S\W5(->FR\ZF+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D
M+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W
M('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E<&%R871E('=I
M;F1O=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.CDU"FUS9VED(")#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM86=E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M,C$*(RP@9G5Z>GD*;7-G:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E
M;&5C=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L
M9',@=&\@(@HB<V5A<F-H+B(*;7-G<W1R("(B"B+KS,'#SJ;4V"#.P2#/Q,[5
M(-H@]\';R<@@U\G"TL'.R<@@X<32Q=/.R<@@R\[)QR"F(->FQ,VFU-C4Q2#7
MTZ8@T,_,T2#$S-$@(@HBT,_;U<O5+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C$W,0IM<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME
M>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&EC:R!T;R!3879E(%,O34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R
M($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.34P"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL
M(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3$*;7-G:60@(D-L:6-K
M:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B
M92!R96%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T
M8VAM86EL+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B
M[L'0R=/!U,DB"@HC.B!C;VUP;W-E+G!H<#HX,C@@8V]M<&]S92YP:'`Z,3$T
M.`IM<V=I9"`B0VQO<V4@=&AI<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z-#(Y"FUS9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(OK!
MR]+)U,$@T,'0R\$B"@HC.B!F;VQD97)S+G!H<#HT-#D*(RP@9G5Z>GD*;7-G
M:60@(D-O;&QA<'-E(@IM<V=S='(@(OK'S]+.U=3)(-?3:2(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")#;VQL87!S92!!
M;&PB"FUS9W-T<B`B^L?/TL[5U,D@U]-I(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"!&;VQD97)S
M(@IM<V=S='(@(OK'S]+.U=3)(-?3IB#0P=#+R2(*"B,Z(&9O;&1E<G,N<&AP
M.C0T.0IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM<V=S='(@(OK'S]+.U=3)
M(-#!T,O5(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C4Q
M"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-CD*(RP@9G5Z>GD*
M;7-G:60@(D-O;7!L971E9"(*;7-G<W1R("+NP=#)T\'4R2(*"B,Z(&-O;7!O
M<V4N<&AP.C@R-R!C;VUP;W-E+G!H<#HQ,30W"B,L(&9U>GIY"FUS9VED(")#
M;VUP;W-E(&%N;W1H97(@;65S<V%G92(*;7-G<W1R("+NP=#)T\'4R2#,R=/4
MP2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S0*(RP@9G5Z>GD*;7-G
M:60@(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_(@IM
M<V=S='(@(O#)T\'4R2#,R=/4R2#7(,_+TL7-S\W5(->FR\ZF+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S
M<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R
M('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE
M<W-A9V5S(&%R92!D:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE
M=R!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,W,`IM<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R
M;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B
M(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L
M(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U("(*(G=H96X@:70@
M87)R:79E<RXB"FUS9W-T<B`B(@HB]\O!UJ;4V"P@T<L@WL'3U,\@Q,G7R=3)
MT]$@VL$@T]>FUL_`(-#/V]3/P""F(-[)(-#/UZ;$S\W,T=3)(/?!TR#0TL\@
MSL6G+B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CDV"FUS9VED(")#
M;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN=&\@9W)A<&AI8V%L(&]N97,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM
M<V=I9"`B0V]P>2(*;7-G<W1R("+KS]"FP-?!U,DB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O<'D@=&\@9F]L
M9&5R(@IM<V=S='(@(OK'S]+.U=3)(-#!T,O5(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S='(@
M(O#2P=?)S-C.SR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHQ-#`*;7-G:60@(D-O<G)E8W1E9"!497AT(@IM<V=S='(@(O?)T-+!U\S%
MSLG*(-3%R]/4(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E
M87-O;B!':79E;CH@)7,B"FUS9W-T<B`B(@H*(SH@871T86-H;65N="YP:'`Z
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!T:&4@
M5D93(&)A8VME;F0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HV-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<R(*
M;7-G<W1R("(B"B+TTL'0R<S!T]$@T,_-R<S+P2#0TLD@U\G4R=+!SLZF(,S)
MT]2FUR#:(-#!T,O)(%PB)7-<(BX@[]/8(-W/(-/+P=K!UR#3Q=+7Q=(B"@HC
M.B!L:6(O4V5S<VEO;BYP:'`Z,S$X"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R("+P
MTL_&ILS!R]3)WLZF(._0Q=+!PZ:G(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N
M968N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S
M=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HU.`IM<V=I9"`B0V]U
M;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II
M<"!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<S
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T
M:6]N(&9R;VT@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP
M:'`Z,S$T('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C$V,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(O/4U\_2R=3)(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O
M;&1E<B(*;7-G<W1R("+SU-?/TLG4R2#0P=#+U2(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,S<*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!+97ES(@IM
M<V=S='(@(O/4U\_2R=3)(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N
M:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@5FER='5A;"!&;VQD97(B
M"FUS9W-T<B`B\]37S]+)U,D@T,'0R]4B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W
M($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(@IM
M<V=S='(@(O/4U\_2R=3)(,[/U]4@T,'0R]4MT\VFU,[)RR(*"B,Z('1E;7!L
M871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F
M<R]F;VQD97)S96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A
M9G1S(&9O;&1E<B(*;7-G<W1R("+SU-?/TLG4R2#.S]?5(-#!T,O5(-[%TL[%
MU,_+(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR
M-B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0R"FUS9VED
M(")#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("+SU-?/
MTLG4R2#.S]?5(-#!T,O5(->FQ*;3S,'.R<@@S,G3U*;7(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O
M=')A<VAS96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@=')A<V@@
M9F]L9&5R(@IM<V=S='(@(O/4U\_2R=3)(,[/U]4@T,'0R]4MT\VFU,[)RR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C@*;7-G:60@(B(*(D-R96%T
M92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M
M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@(@HB86YD(&1E;&5T92!S<&%M
M+B(*;7-G<W1R("(B"B+SU-?/TLG4R2#0TL'7R<S!(,:FS-C4TM77P<[1T2P@
MW<_"(,_2Q\'.IMK5U\'4R2#WP=O5(-?(IL3.U2#0S]O4U2P@T\_2U-77P=3)
M("(*(J>G(-#/(-#!T,O!R""F(-?)U,G2P=3)(,[%PL'6P<ZF(,S)T]3)("C3
MT,'-*2XB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*
M(RP@9G5Z>GD*;7-G:60@(D-R96%T92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R
M("+SU-?/TLG4R2#.S]?5(-#!T,O5(->FQ*;3S,'.R<@@S,G3U*;7(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T.0IM<V=I9"`B0W)E871E('-T871I
M;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R
M<F5N="!A8V-E<W,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-0IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F
M971C:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B
M0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R("+OTL?!SJ;:
MU<K4Q2#7IL30TL'7S,7.SM$@T,_;U,DL(-?+P=:FU-@L(,O5Q,D@VL'0R=/5
MU\'4R2#>Q=+.Q=3+R2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B[L',P=O4U<K4Q2#:
MP<3!WJ8L(-'+IB#-P<#4V"#7R<O/SM77P=3)T]@@T-+)(-?(S\2F(-<@24U0
M+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,3<*(RP@9G5Z>GD*;7-G:60@(D1A=%]E(@IM<V=S='(@(N3!U,$B"@HC.B!M
M97-S86=E+G!H<#HR-C(@=&AR96%D+G!H<#HQ-#@*;7-G:60@(D1A=&4B"FUS
M9W-T<B`BY,'4P2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3<*
M(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(M?)U,72U*8B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8S"FUS9VED(")$96-L:6YE
M9#H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*
M(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B]\G4Q=+4R2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHQ.`IM
M<V=I9"`B1&5F875L="!396%R8V@@1FEE;&0B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDR,PIM<V=I9"`B1&5F875L="!S;W)T:6YG
M(&-R:71E<FEA.B(*;7-G<W1R("+KTLG4Q=*FRB#3S]+4U=?!SL[1(-K!(-K!
MS<_7WM77P<[.T<TZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,PIM
M<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B[L'0
MTM'-S\L@T\_2U-77P<[.T2#:P2#:P<W/U][5U\'.SM'-.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-C4*(RP@9G5Z>GD*;7-G:60@(D1E;&5G
M871E9"(*;7-G<W1R("+7R=3%TM2F(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(T-"!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHX('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+V-O;7!O
M<V4O871T86-H;65N=',N:6YC.C(X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-PIM<V=I9"`B1&5L971E(@IM<V=S='(@(O?)U,72U,DB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,@4'5B;&EC($ME
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B1&5L971E($-U<G)E
M;G0@2V5Y<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHY"FUS9VED(")$96QE=&4@1F]L9&5R*',I(@IM<V=S='(@(O?)
MU,72U,D@T,'0R]4B"@HC.B!F;VQD97)S+G!H<#HR.#4*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(O?)U,72U,D@
MT,'0R]4B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#(*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!3=&%T:6]N97)Y(@IM<V=S='(@(O?)
MU,72U,D@T,'0R]4B"@HC.B!F;VQD97)S+G!H<#HT,3D*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("+WR=3%TM3)(-#!
MT,O5(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS
M9VED(")$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V
M97(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O
M9B!M;VYT:#\B"FUS9W-T<B`B]\G4R=+!U,D@T]3!TM4@T,'0R]4@UZ;$T-+!
MU\S%SLG((,S)T]2FUR#.P2#0S][!U,O5(,VFT]'#T2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-3`*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!O;&0@
M<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G
M<W1R("+WR=3)TL'4R2#3U,'2U2#0P=#+U2#7IL30TL'7S,7.R<@@S,G3U*;7
M(,[!(-#/WL'4R]4@S:;3T</1(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-P86T@;65S<V%G97,B"FUS
M9W-T<B`B]\G4Q=+4R2#,R=/4R2(*"B,Z(&UE<W-A9V4N<&AP.C4P,R!M86EL
M8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,X('1E;7!L871E<R]M
M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R("+7
MR=3%TM2F(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I
M9"`B1&5L971E9"!M97-S86=E<R(*;7-G<W1R("+WR=3%TM2F(,S)T]3)(@H*
M(SH@8V]M<&]S92YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB)7-<(BXB"FUS9W-T<B`BY,_$
MP=3/RR#7R=3%TM3/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS
M9VED(")$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S(@IM<V=S='(@(O?)
MU,G2P<[.T2#!PL\@T,72Q<[%T\7.SM$@S,G3U*;7(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#`*;7-G:60@
M(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S(*;7-G:60@(D1E
M<V-E;F1I;F<B"FUS9W-T<B`B\,\@T]#!Q,'.SL`B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8V.0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W
M"FUS9VED(")$971A:6QS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-S<*(RP@9G5Z>GD*;7-G:60@(D1I;2!S:6=N871U<F5S/R(*
M;7-G<W1R("+WP=L@T*;$T,G3.B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C,V"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(@IM<V=S
M='(@(N_0PZ:G(->FQ,_"TL'6Q<[.T2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-SD*;7-G:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E
M;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C@V"FUS9VED(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"B,L
M(&9U>GIY"FUS9VED(")$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@
M;F5W(&UA:6P_(@IM<V=S='(@(O#/R\':U=?!U,D@UZ;+S\[%WLO/(-H@T,_7
MIL3/S<S%SL[1S2#0TL\@T]>FUM4@T,_;U-4N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3<&%M
M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T
M>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS9W-T<B`B[]##IJ<@UZ;$S\+2P=;%
MSL[1(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C(V"FUS9VED
M(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#:&5C:R!&;VQD97(H
M<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(N[%(,3)U\G4R=/1(-<@T,'0PZ8@
MVL$@T]>FUL_`(-#/V]3/P"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-3(*;7-G:60@(D1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#<U"B,L(&9U
M>GIY"FUS9VED(")$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/R(*
M;7-G<W1R("+WR2#(S][%U,4@UZ;$R]+)U,D@)7,_(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,S(*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B1&]N92(*;7-G<W1R("+ZTL_"
MS,7.SR(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3(*;7-G
M:60@(D1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR
M,`IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S='(@(OK!U\'.U,'6
MR=3)(/#!T,O5(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,C$*(RP@9G5Z>GD*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F
M;W)M871=(@IM<V=S='(@(OK!U\'.U,'6R=3)(/#!T,O5(@H*(SH@;&EB+TU)
M344O0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&
M;W)M870B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N
M<&AP.C<Q.2!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S='(@(M[%TL[%U,O)
M(@H*(SH@9F]L9&5R<RYP:'`Z,SDR"B,L(&9U>GIY"FUS9VED(")$<F%F="!F
M;VQD97(B"FUS9W-T<B`B\,'0R\$@WL72SL74S\LZ(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD
M97(Z(@IM<V=S='(@(O#!T,O!(-[%TL[%U,_+.B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,#@*(RP@9G5Z>GD*;7-G:60@(D4M;6%I;"!!9&1R97-S
M(@IM<V=S='(@(OK7S]+/U,[1(,'$TL73P2(*"B,Z(&QI8B]-86EL8F]X+G!H
M<#HS,#D*;7-G:60@(D5.1"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HW-`IM<V=I9"`B15)23U(Z(%EO=7(@;65S<V%G92!C
M;W5L9"!N;W0@8F4@9&5L:79E<F5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S
M+G!H<#HT,C`@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$Y"FUS
M9VED(")%9&ET(@IM<V=S='(@(O+%Q,''U=?!U,DB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(D5D:70@0FQA
M8VML:7-T(@IM<V=S='(@(K;'SL_2U=?!U,DB"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(D5D:70@1FEL=&5R
M<R(*;7-G<W1R("+PS]O4S]>F(,:FS-C4TLDB"@HC.B!F;VQD97)S+G!H<#HT
M,C`@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$V"FUS9VED(")%9&ET
M(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VAE861E<BYI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!6
M:7)T=6%L($9O;&1E<B!$969I;FET:6]N(&9O<B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@
M5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES
M="(*;7-G<W1R("+RQ<3!Q]77P=3)(/?!VZ8@IM#/T]3!TZ8B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(D5D
M:70@>6]U<B!F:6QT97(@<G5L97,B"FUS9W-T<B`B\L7$P<?5U\'4R2#0TL'7
MR<S!(,:FS-C4TM77P<[.T2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-C$*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG
M(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B161I="!Y
M;W5R('=H:71E;&ES="(*;7-G<W1R("+RQ<3!Q]77P=3)(/?!VZ8@IM#/T]3!
MTZ8B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S.0HC
M+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("+ZU\_2S]3.
MT2#!Q-+%T\$B"@HC.B!L:6(O365S<V%G92YP:'`Z-C4W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S
M+B(*;7-G<W1R("+PQ=+%T\S!SLG*(,S)T]0@UZ;$("5S(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D5M
M<'1Y($9O;&1E<BAS*2(*;7-G<W1R("+WR=3%TM3)(-#!T,O5(@H*(SH@9F]L
M9&5R<RYP:'`Z,C@V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!396QE8W1E9"!&
M;VQD97)S(@IM<V=S='(@(O?)U,72U,D@T,'0R]4B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0HC+"!F=7IZ>0IM<V=I9"`B16UP='D@
M5')A<V@@9F]L9&5R(@IM<V=S='(@(O/-IM3.R<LZ(@H*(SH@;&EB+TE-4"YP
M:'`Z.3<S"FUS9VED(")%;7!T>2!?4W!A;2(*;7-G<W1R("(B"@HC.B!L:6(O
M24U0+G!H<#HY-C8*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,2!T96UP;&%T97,O<&=P+VYO=&%C
M=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$@=&5M
M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%,O
M34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#$Q"FUS9VED(")%;F%B;&4@;65S<V%G92!P<F5V:65W
M<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#0R"FUS9VED(")%;F-R7WEP=&EO;B!/<'1I;VYS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3<@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8U-PIM<V=I9"`B16YD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS.#0*;7-G:60@(D5N9"!F;W)W87)D960@;65S<V%G
M92(*;7-G<W1R("+KIL[%P]@@T,72Q=/,P<[/Q\\@S,G3U,$B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,S0Q"B,L(&9U>GIY"FUS9VED(")%;F0@;65S<V%G92(*
M;7-G<W1R("+SU,'2IB#,R=/4R2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,SD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5N9"!M97-S86=E(&9R;VT@
M)7,B"FUS9W-T<B`B\,72Q=/,P<[)RB#,R=/4(->FQ"`E<R(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<W"FUS9VED(")%;G1E<B!087-S<&AR87-E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHY"B,L(&9U>GIY"FUS9VED
M(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(B"FUS
M9W-T<B`B]]?%Q*;4V"#.P=K7U2#.S]?/IR#0P=#+R2W3S:;4SLG+P2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S
M='(@(O?7Q<2FU-@@SL':U]4@SL_7SZ<@T,'0R\D@Q,S1(-[%TL[%U,_+(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR,PIM<V=I
M9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD
M97(B"FUS9W-T<B`B]]?%Q*;4V"#.P=K7U2#.S]?/IR#0P=#+R2#$S-$@UZ;$
MIM/,P<[/IR#0S]O4R2(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C
M="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R
M87-H(&9O;&1E<B(*;7-G<W1R("+WU\7$IM38(,[!VM?5(,[/U\^G(-#!T,O)
M+=/-IM3.R<O!(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*(RP@9G5Z>GD*;7-G
M:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(O#%TL7.P=#2P=?)U,D@[,G3
MU"(*"B,Z(&UE<W-A9V4N<&AP.C$Y-"!C;VUP;W-E+G!H<#HQ,3,T('1H<F5A
M9"YP:'`Z-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5N=')Y(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B^L'0R=,@7"(E<UPB(,+5UR#5T]"FV\[/(,3/Q,'.R<H@
MQ,\@P<32Q=/.SZ<@R\[)Q\DB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$X('1E;7!L871E<R]P9W`O<&=P+FEN8SHR,0HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C,W-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS
M.#8*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S(@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z,38S"FUS9VED(")%<G)O<B(*;7-G<W1R("+P
MS\W)S,O!(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E<G9E<BX@
M)7,@.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C,P.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`Q"B,L(&9U>GIY
M"FUS9VED(")%=F5N="!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B
M\,'0R]4@7"(E<UPB(-73T*;;SL\@U\G4Q=+4SRXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@R"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S
M='(@(NO/ULZF(#$U(,C7R<S)SB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BZ\_6SJ8@
M,S`@T\7+U<[$(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I
M9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(NO/ULZF(#4@R-?)S,G.(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,PIM<V=I9"`B179E<GD@:&%L
M9B!H;W5R(@IM<V=S='(@(NO/ULZF(-"FU\?/Q,G.R2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R
M("+]S\C7R<S)SLDB"@HC.B!F;VQD97)S+G!H<#HT-3<*(RP@9G5Z>GD*;7-G
M:60@(D5X<&%N9"(*;7-G<W1R("+RS]K'S]+.U=3)(-?3IB(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A;F0@06QL
M(@IM<V=S='(@(O+/VL?/TL[5U,D@U].F(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*
M;7-G<W1R("+RS]K'S]+.U=3)(-?3IB#0P=#+R2(*"B,Z(&9O;&1E<G,N<&AP
M.C0U-PIM<V=I9"`B17AP86YD($9O;&1E<B(*;7-G<W1R("+RS]K'S]+.U=3)
M(-#!T,O5(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P
M('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP
M86YD($YA;65S(@IM<V=S='(@(O#/V]7+(,'$TL73(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-C,*;7-G:60@(D5X<&%N9"!N86UE<R!I;B!T:&4@
M8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N
M9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX,`HC
M+"!F=7IZ>0IM<V=I9"`B17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@
M8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/R(*;7-G<W1R("+PS\O!
MVM77P=3)(-+/VL?/TL[5U-4@T]32U<O4U=+5(-#!T,_+(-4@UZ;+SJ8@\,'0
MR\DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(T-2!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z,3`Q"B,L(&9U>GIY"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T
M<B`B\L_:Q\_2SM74R2#7TZ8B"@HC.B!L:6(O24U0+G!H<#HY.#0@;&EB+TE-
M4"YP:'`Z.3@V"B,L(&9U>GIY"FUS9VED(")&7V5T8V@@36%I;"(*;7-G<W1R
M("+SUZ;6P2#0S]O4P2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM
M86EL+FEN8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"B,L(&9U>GIY
M"FUS9VED(")&971C:"!-86EL(@IM<V=S='(@(O/7IM;!(-#/V]3!(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V.0HC+"!F=7IZ>0IM<V=I9"`B1F5T
M8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B\,G3P=3)
M(,S)T]3)(-<@S\O2Q<W/S=4@UZ;+SJ8N(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C0V"B,L(&9U>GIY"FUS9VED(")&971C:"!M97-S
M86=E<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(OK!T]3/T]77P=3)(,:F
MS-C4TLD@T-+)(-?(S\2F(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D("5D(&UE<W-A9V5S
M(&9R;VT@)7,B"FUS9W-T<B`B\,72Q=/,P<[)RB#,R=/4(->FQ"`E<R(*"B,Z
M(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("+PQ=+%
MT\S!SLG*(,S)T]0@UZ;$("5S(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@U
M(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL+G!H<#HR.#D*
M;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA
M:6PN<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B1F5T8VAM86EL.B!N;R!N97<@
M;65S<V%G97,N(@IM<V=S='(@(O4@]\'3(*0@)7,@SL_7R<@@S,G3U*;7+B(*
M"B,Z(&QI8B])35`N<&AP.CDY,`HC+"!F=7IZ>0IM<V=I9"`B1FE?;'1E<G,B
M"FUS9W-T<B`BYJ;,V-32R2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4P,B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHX
M,@HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R("+FILS8U-(B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D9I;'1E<B!/<'1I;VYS(@IM<V=S='(@(K;.VZ8@[]##IJ<B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M=&5R(%-E='1I;F=S(@IM<V=S='(@(O#2P=?)S,$@QJ;,V-32U=?!SL[1(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P,`HC+"!F=7IZ>0IM<V=I9"`B
M1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R
M("+FILS8U-+5U\'4R2#,R=/4R2#.Q=#2R=/4S\K.S\?/(-?-IM/4U2XB"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$Q"FUS9VED(")&
M:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B
M1FEL=&5R<R(*;7-G<W1R("+FILS8U-+)(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O;F]T86-T:79E+FEN8SHS"FUS9VED(")&:6QT97)S($Y/5"!!8W1I=F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X-@HC
M+"!F=7IZ>0IM<V=I9"`B1FEN9"(*;7-G<W1R("+PS\S%(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP-0HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@36%I
M;&)O>"!086=E(@IM<V=S='(@(O#%TMO!(-/4S]*FSLO!(@H*(SH@;6%I;&)O
M>"YP:'`Z,S0U"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(O#%TMO!(-/4
MS]*FSLO!(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"B,L(&9U
M>GIY"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R("+PQ=+%T\S!U,DB"@HC.B!F
M;VQD97)S+G!H<#HR-C8@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF
M:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I
M;VXB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S`S('1E;7!L871E<R]F
M;VQD97)S+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP
M86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G
M97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T
M<B`B\,72Q<?,T<0@T,'0S\LB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,PHC+"!F=7IZ>0IM<V=I9"`B1F]L9&5R(%-U;6UA<GDB"FUS9W-T<B`B[,#4
MR<HB"@HC.B!A8VPN<&AP.C(T"FUS9VED(")&;VQD97(@<VAA<FEN9R!I<R!N
M;W0@96YA8FQE9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-C(*;7-G
M:60@(D9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-CD*;7-G:60@(D9O<FUA="!O9B!M
M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S
M(&1A=&5D('1O9&%Y(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C<X,"!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A<F0B
M"FUS9W-T<B`B\,72Q=/,P=3)(@H*(SH@8V]M<&]S92YP:'`Z-S8U"FUS9VED
M(")&;W)W87)D.B(*;7-G<W1R("+PQ=+%T\S!U,DZ(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C,V.0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4B
M"FUS9W-T<B`BZZ;.Q</8(-#%TL73S,'.S\?/(,S)T]3!(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;W)W87)D960@
M;65S<V%G92!F<F]M("5S(@IM<V=S='(@(O#%TL73S,'.R<H@S,G3U"#7IL0@
M)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@S"B,L(&9U>GIY
M"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`BML[&S]+-
MP<.FT2#0TL\@T\72U\72(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0Y-`IM<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#@*;7-G:60@(D9R964O0G5S>2!2
M97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT,#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,C<*(RP@9G5Z>GD*;7-G:60@(D9R;U]M(@IM<V=S='(@(O>FQ"(*"B,Z
M(&UE<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T.2!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I
M9"`B1G)O;2(*;7-G<W1R("+WIL0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$X"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`B^M?/TL_4SM$@
MP<32Q=/!(@H*(SH@8V]M<&]S92YP:'`Z-S<W(&-O;7!O<V4N<&AP.C<X,0HC
M+"!F=7IZ>0IM<V=I9"`B1G=D.B(*;7-G<W1R("+PQ=+%T\S!U,DZ(@H*(SH@
M8V]M<&]S92YP:'`Z,3(Y-`HC+"!F=7IZ>0IM<V=I9"`B1G=D.B`B"FUS9W-T
M<B`B\,72Q=/,P=3).B(*"B,Z(&-O;7!O<V4N<&AP.C$R.38*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S
M(@IM<V=S='(@(NNFSL7#V"#0Q=+%T\S!SL_'SR#,R=/4P2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.`HC+"!F=7IZ>0IM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S
M='(@(K;.VZ8@[]##IJ<B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M97-S86=E<S\@*$E-05`@
M;VYL>2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z
M,3,V"B,L(&9U>GIY"FUS9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@(N[!
MT]35T,[)RB#,R=/4(@H*(SH@;&EB+TE-4"YP:'`Z-#DX"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")';R!T;R!A9&1R97-S(&)O;VL@96YT<GD@;V8@
M7"(E<UPB(@IM<V=S='(@(N3/Q,'4R2#$SR#AQ-+%T\[/IR#+SLG'R2`H)7,I
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@
M86-C97-S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-B!L:6(O1FEL
M=&5R+G!H<#HQ,#4@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$P-`HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ-C,@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC.B!L:6(O34E-
M12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6:65W97(O<F5L871E
M9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM<V=I9"`B2$52
M12(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-PHC.B!L:6(O34E-
M12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I;VX@;V8@
M365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D
M97)S+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@
M=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8X"FUS9VED(")(:61D96XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PIM<V=I9"`B
M2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N
M<&AP.C,V-PIM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@(O/(S]?!U,D@
MU\G4Q=+4IB(*"B,Z(&9O;&1E<G,N<&AP.C(Y.`IM<V=I9"`B2&ED92!5;G-U
M8G-C<FEB960B"FUS9W-T<B`B\\C/U\'4R2#.Q=#%TL7$T,S!WL7.IB(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-`IM<V=I9"`B2&EG
M:"(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR.3<@;6%I;&)O>"YP:'`Z
M-S(T('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI
M9V@@4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,CDS"FUS9VED(")(:6=H97-T(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#@*(RP@9G5Z>GD*;7-G:60@(DAO
M=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C:&UE;G1S/R(*;7-G<W1R
M("+WR2#(S][%U,4@UZ;$R]+)U,D@)7,_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q
M=6]T960@;&EN97,@:6X@82!R97!L>2(*;7-G<W1R("+]SR#3U,'7R=3)(-#%
MTL7$(,/)U,_7P<[)S<D@TM'$R\'-R2#5(->FQ-#/UZ;$ICHB"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$S-`IM<V=I9"`B24U!4"(*;7-G<W1R("(B
M"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H
M075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E
M<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,38V(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V
M97(@4U-,(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,34R"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I
M8V%T92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ-C<*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G
M<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!
M4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0
M,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.#8V
M"FUS9VED("))3D)/6"(*;7-G<W1R("+SR]+)SMC+P2(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y
M;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O
M;F9I<FTN:'1M;#HQ,@IM<V=I9"`B268@>6]U(&-O;G1I;G5E+"!A;&P@;65S
M<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E(&QO<W0A(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,@IM<V=I
M9"`B26=N;W)E(@IM<V=S='(@(K;'SL_2U=?!U,DB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#,*;7-G:60@(DEG;F]R92!!;&PB"FUS
M9W-T<B`BML?.S]+5U\'4R2#7TZ8B"@HC.B!T96UP;&%T97,O<V%V96EM86=E
M+W-A=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,`HC+"!F=7IZ>0IM<V=I
M9"`B26UP;W)T(@IM<V=S='(@(M?!ULS)UZ8B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R("+7
MP=;,R=>F(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S.0HC+"!F=7IZ
M>0IM<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`BU\'6S,G7IB(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(W"B,L(&9U>GIY"FUS
M9VED("));7!O<G0@365S<V%G97,B"FUS9W-T<B`B]\'6S,G7IB#,R=/4R2(*
M"B,Z('!G<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3$*;7-G:60@(DEM
M<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R
M<V]N86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L
M(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4&5R<V]N86P@4R]-
M24U%($-E<G1I9FEC871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O<&=P+FEN8SHT,@IM<V=I
M9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC(%!'
M4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K
M97DN:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@4R]-24U%($ME>2(*;7-G
M<W1R("(B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@
M2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI
M;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N(@IM
M<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,B!M86EL8F]X+G!H<#HW,S0@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N
M:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R("+7P=;,R=>F(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT
M(&UE<W-A9V5S(@IM<V=S='(@(O?!ULS)UZ8@S,G3U,DB"@HC.B!F;VQD97)S
M+G!H<#HQ-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D
M("5D(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(O#%TL73S,'.R<H@S,G3
MU"#7IL0@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS
M9VED("));B!0<F]C97-S(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,X
M-"!L:6(O1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-
M4"YP:'`Z,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4
M<F5E+G!H<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.3(*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S
M=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O
M<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G
M<W1R("*VQ\[/TM77P=3)(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(DEN9F]R;6%T
M:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FEN8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#<*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3@*(RP@9G5Z
M>GD*;7-G:60@(DEN;&EN92(*;7-G<W1R("+6S\3.S\?/(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.CD*;7-G:60@(DEN<V5R="!#97)T
M:69I8V%T92!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z,34*;7-G:60@(DEN<V5R="!097)S;VYA;"!0<FEV871E
M(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM
M<&]R=%]K97DN:6YC.C$P"FUS9VED("));G-E<G0@4&5R<V]N86P@4'5B;&EC
M(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM
M<&]R=%]K97DN:6YC.C4*;7-G:60@(DEN<V5R="!0=6)L:6,@4$=0($ME>2!(
M97)E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT
M,3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O
M;7!O;F5N="XB"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-3@T(&UA:6QB
M;W@N<&AP.C8R-@IM<V=I9"`B26YV86QI9"!!9&1R97-S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,S`W"FUS9VED("));G9A;&ED
M(%)E;6]T92!-86EL8F]X(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$U
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E
M+6UA:6P@861D<F5S<SH@)7,N(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HX
M,B!P9W`N<&AP.C$V"FUS9VED("));G9A;&ED(&ME>2(*;7-G<W1R("(B"@HC
M.B!P9W`N<&AP.C$Y-@IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<')I
M=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3<Q"FUS9VED("))
M;G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R"FUS9VED("));G9E
M<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-3<W"FUS9VED(")+0B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,3$S"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*;7-G:60@(B(*(DME>2!G96YE
M<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE('1O(&-O;7!L971E+B`@0V]N
M=&EN=64@=VET:"!K97D@(@HB9V5N97)A=&EO;C\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS-2!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,S<*;7-G:60@(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@
M1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R!S97)V97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S<@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C,Y"FUS9VED("(B"B)+97D@:6UP;W)T(&ES
M(&YO="!A=F%I;&%B;&4N(%EO=2!H879E(&YO(&%D9')E<W,@8F]O:R!D969I
M;F5D('1O(&%D9"!Y;W5R("(*(F-O;G1A8W1S+B(*;7-G<W1R("(B"@HC.B!P
M9W`N<&AP.C,Q.`IM<V=I9"`B2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(Q-@IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B
M[<_7P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#8*(RP@9G5Z>GD*
M;7-G:60@(DQA<W0@36%I;&)O>"!086=E(@IM<V=S='(@(N_3U,'.SM$@T]3/
MTJ;.R\$B"@HC.B!M86EL8F]X+G!H<#HS-3@*;7-G:60@(DQA<W0@4&%G92(*
M;7-G<W1R("+OT]3!SL[1(-/4S]*FSLO!(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S@Y"B,L(&9U>GIY"FUS9VED("),:5]N:R!!='1A
M8VAM96YT<R(*;7-G<W1R("+DS\3!U,O)(@H*(SH@871T86-H;65N="YP:'`Z
M,S0@;&EB+T-O;7!O<V4N<&AP.C$P-C,*;7-G:60@(DQI;FME9"!A='1A8VAM
M96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,3`X,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:6YK<R!W:6QL(&5X
M<&ER92!O;B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`X,@IM<V=I9"`B(@HB3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D
M:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I
M;&P@(@HB;VYL>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E
M>'!L:6-I=&QY*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C@U"FUS9VED("),:7-T:6YG(&EN('1H92!(96%D97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P"B,L(&9U
M>GIY"FUS9VED("),;V-A;"!-86EL8F]X.B(*;7-G<W1R("+SR]+)SMC+P2(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-S0*(RP@9G5Z>GD*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(N_0Q=+!PZ;1(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,C4*;7-G:60@(DQO9R!I;B(*;7-G<W1R("+W
MUZ;*U,DB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3$U"B,L('!H<"UF
M;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G<W1R("+WUZ;*U,D@Q,\@
M)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S-PHC+"!F=7IZ
M>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B]]>FRM3)(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("+Z
MP<3!WJ8L(-W/(-?)R\_.U<#4V-/1(-#2R2#7R,_$IB(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@
M(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X+G!H<#HW,C<@=&5M<&QA
M=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B3&]W(%!R:6]R:71Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y-PIM<V=I9"`B3&]W97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]A<'!L961O=6)L92YP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@(DUA8VEN
M=&]S:"!&:6QE(@IM<V=S='(@(O#/V]3/UZ8@QJ;,V-32R2(*"B,Z('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B
M36%I;"(*;7-G<W1R("+SR]+)SMC+P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-@HC+"!F=7IZ>0IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R
M("+PS]O4S]>F(,:FS-C4TLDB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R
M:79E<E]S96QE8W0N:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O
M(&-O;FYE8W0@=&\Z(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM
M<V=I9"`B36%I;&)O>"(*;7-G<W1R("+SR]+)SMC+P2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3$*(RP@9G5Z>GD*;7-G:60@(DUA:6QB;W@@86YD
M($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B[]##IJ<@UZ;$S\+2
MP=;%SL[1(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*
M;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y
M"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS
M9VED(")-87)K(&%S.B(*;7-G<W1R("+WIL3-IM3)U,D@T<LZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8U,`IM<V=I9"`B36%R:R!D:69F97)E;G0@
M;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*
M;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U.`IM<V=I9"`B
M36%R:R!S:6UP;&4@;6%R:W5P/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@(DUA=&-H($%L;"!1=65R:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT
M,@IM<V=I9"`B36%T8V@@06YY(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PHC+"!F=7IZ>0IM<V=I9"`B
M36%X:6UU;2!!='1A8VAM96YT(%-I>F4B"FUS9W-T<B`BY,_$P=3/RR(*"B,Z
M(&QI8B]A<&DN<&AP.C<Y"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!&;VQD
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0Y-`IM<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@871T86-H;65N=',@
M<F5A8VAE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#@Y"FUS9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@
M<VEZ92!R96%C:&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C(V"FUS9VED(")-965T:6YG($-A;F-E;&QA=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<U"B,L(&9U
M>GIY"FUS9VED(")-965T:6YG($EN9F]R;6%T:6]N(@IM<V=S='(@(K;.QL_2
MS<'#IM$@T-+/(-/%TM?%TB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#4*;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I9"`B365E=&EN9R!2
M97!L>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3DX"B,L(&9U>GIY"FUS9VED(")-965T:6YG(%5P9&%T92(*;7-G<W1R("+P
MS]+!Q,[)RR#0S][!U,NFU\/`(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8P,PIM<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS"B,L(&9U>GIY
M"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@(O>FQ,O2R=3)(/#!
MT,O5(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S<V%G92(*
M;7-G<W1R("+LR=/4(@H*(SH@8V]M<&]S92YP:'`Z-38P(&-O;7!O<V4N<&AP
M.C4X-R!C;VUP;W-E+G!H<#HV-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M"FUS9VED(")-97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@(O/4U\_2Q<[.
MT2#,R=/4P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3<*;7-G:60@
M(DUE<W-A9V4@1&%T92(*;7-G<W1R("+DP=3!(,S)T]3!(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`S"B,L(&9U>GIY"FUS9VED(")-97-S86=E($]P=&EO;G,B
M"FUS9W-T<B`B[,G3U,D@Q,\B"@HC.B!S96%R8V@N<&AP.C,Q,@IM<V=I9"`B
M365S<V%G92!396%R8V@B"FUS9W-T<B`B\,_;U<L@S,G3U,$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS
M9W-T<B`B[\+3T<<@S,G3U,$B"@HC.B!M97-S86=E+G!H<#HS.#0*;7-G:60@
M(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(O?)R*;$SLG*(-3%R]/4(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED(")-97-S86=E(%9I97=I
M;F<B"FUS9W-T<B`B\,72Q<?,T<0@S,G3U,$B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`B
M]Z;$S:;4R\D@S,G3U,$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C@S"FUS9VED(")-97-S86=E(&9O;&1E<G,B"FUS9W-T<B`B\,'0R\D@S,G3
MU*;7(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B365S<V%G92!F<F]M("5S(@IM<V=S='(@(O#!T,O)(,S)
MT]2FUR(*"B,Z(&UA:6QB;W@N<&AP.C8V-PHC+"!F=7IZ>0IM<V=I9"`B365S
M<V%G92!H87,@871T86-H;65N=',B"FUS9W-T<B`BY,_$P=3/RR#7R=3%TM3/
M(@H*(SH@;6%I;&)O>"YP:'`Z-C4X"B,L(&9U>GIY"FUS9VED(")-97-S86=E
M(&ES(&5N8W)Y<'1E9"(*;7-G<W1R("+PS\S1(,S)T]3!(@H*(SH@;6%I;&)O
M>"YP:'`Z-C4S"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*
M;7-G<W1R("+PS\S1(,S)T]3!(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D
M97(N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS
M9W-T<B`BY,'4P2#,R=/4P2(*"B,Z(&-O;7!O<V4N<&AP.C@R-"!C;VUP;W-E
M+G!H<#HX,S@*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@<F5D:7)E8W1E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(NS)T]0@U=/0IMO.SR#7IL30TL'7S,7.
MR<HL(-3/S=4@SL4@PM7$Q2#:PL72Q=;%SL\@Q,\B"@HC.B!C;VUP;W-E+G!H
M<#HQ,#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E
M;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@
M(NS)T]0@U=/0IMO.SR#7IL30TL'7S,7.R<HL(-3/S=4@SL4@PM7$Q2#:PL72
MQ=;%SL\@Q,\B"@HC.B!C;VUP;W-E+G!H<#HQ,30S(&-O;7!O<V4N<&AP.C$Q
M-3@*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(NS)T]0@U=/0IMO.SR#7IL30TL'7S,7.R<HL(-3/S=4@SL4@
MPM7$Q2#:PL72Q=;%SL\@Q,\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.30Q"FUS9VED(")-97-S86=E<R!P97(@<&%G92!I;B!T:&4@;6%I;&)O>"!V
M:65W+B(*;7-G<W1R("+LR=/4IM<@SL$@T]3/TJ;.R]4@T-+)(-#%TL7'S-'$
MIB#3R]+)SMC+R2XB"@HC.B!M86EL8F]X+G!H<#HS,C(*;7-G:60@(DUE<W-A
M9V5S('1O(@IM<V=S='(@(NS)T]3)(,3/(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB"FUS9W-T<B`B^LVFSLG4R2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L
M9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHU,`IM<V=I9"`B36]V92(*;7-G<W1R("+PQ=+%SL73U,DB"@HC.B!T
M96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,38*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("+0S]/5SM74R2#7SLG:(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.`IM<V=I9"`B36]V92!S<&%M(&UE
M<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T
M;R!)3D)/6"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z-3`*(RP@9G5Z>GD*;7-G:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@
M(M?)PM+!U,D@T,'0R]4B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHS,30*(RP@9G5Z>GD*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
MT,_3U<[5U,D@U]?%TL@B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I
M=F4N<&AP.C$R-PIM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S
M='(@(B(*"B,Z('1H<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z
M>GD*;7-G:60@(DUU;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R("+PQ=+%
MQ\S1Q"#,R=/4P2(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H
M<V5L96-T+FEN8SHU"FUS9VED(").3TY%(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT."!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C(*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@
M(DY/5$4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR,S@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I
M9"`B3F%M92(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$Q,`IM<V=I9"`B3F%M
M92!A;F0O;W(@96UA:6P@8V%N(&YO="!B92!E;7!T>2(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<X"B,L(&9U>GIY"FUS9VED
M(").965D<R!!8W1I;VXB"FUS9W-T<B`B[]#%TL'#IM$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3<P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#(*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W.`IM<V=I9"`B3F5V97(B"FUS
M9W-T<B`B[J;+S\S)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`HC
M+"!F=7IZ>0IM<V=I9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R
M("+DS\3!U,_+(-?)U,72U,\B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M,3(T"FUS9VED(").97<B"FUS9W-T<B`BSL_7IB(*"B,Z(&QI8B])35`N<&AP
M.C4V,PHC+"!F=7IZ>0IM<V=I9"`B3F5W($9O;&1E<B(*;7-G<W1R("+WIL3+
MTLG4R2#PP=#+U2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.`IM<V=I
M9"`B3F5W($UA:6PB"FUS9W-T<B`B\]>FUL$@T,_;U,$B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z
M,S,*(RP@9G5Z>GD*;7-G:60@(DYE=R!-97-S86=E(@IM<V=S='(@(N[!T]35
MT,[)RB#,R=/4(@H*(SH@;6%I;&)O>"YP:'`Z-S<V(&QI8B]-24U%+TAE861E
M<G,N<&AP.C$Y,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE
M<W-A9V4@=&\@)7,B"FUS9W-T<B`B[L_7IB#,R=/4R2(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G
M<W1R("+NS]>F(,S)T]3)(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$S,PIM<V=I9"`B3F5X="(*;7-G<W1R("+NP=/4U=#.R<HB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S"FUS
M9VED(").97AT($UE<W-A9V4B"FUS9W-T<B`B[L'3U-70SLG*(,S)T]0B"@HC
M.B!M86EL8F]X+G!H<#HS-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R("+N
MP=/4U=#.P2#3U,_2IL[+P2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS9VED(").
M;R(*;7-G<W1R("+NIB(*"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO($-E
M<G1I9FEC871E(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3D*;7-G:60@
M(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H
M<#HS-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO($UE<W-A9V5S
M(@IM<V=S='(@(N[/UZ8@S,G3U,DB"@HC.B!P9W`N<&AP.C$S-PIM<V=I9"`B
M3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L
M($-E<G1I9FEC871E(%!R97-E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QB
M;W@N<&AP.C,R.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT(@IM
M<V=S='(@(O?)T-+!U\S%SLG*(-3%R]/4(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHQ-0IM<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS
M9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$U,0IM<V=I9"`B3F\@4R]-24U%('!U
M8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]T;F5F+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B3F\@871T86-H;65N
M=',@9F]U;F0N(@IM<V=S='(@(N3/Q,'4R\DB"@HC.B!L:6(O0W)Y<'0O4TU)
M344N<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I;VX@;&]C871E
M9"!I;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HW
M,B!A8VPN<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97(@<V5L96-T
M960N(@IM<V=S='(@(M;/Q,[!(-#!T,O!(,[%(-?)PM+!SL$B"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD97)S(&%R92!B
M96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L:6(O1F]L9&5R+G!H
M<#HU-3`*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I960B"FUS9W-T
M<B`B]L_$SL$@T,'0R\$@SL4@U\G"TL'.P2(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ-#<*(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N
M97<@;65S<V%G97,B"FUS9W-T<B`B[L4@U\G4Q=+4IB#,R=/4R2(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G:60@(DYO(&9O
M;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`B[L4@U\G4Q=+4
MIB#,R=/4R2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,C4*(RP@9G5Z>GD*;7-G
M:60@(DYO(&UE<W-A9V4@8F]D>2!T97AT(@IM<V=S='(@(M#%TL7.Q=/4R2#,
MR=/4(-<B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S<Q"B,L(&9U>GIY"FUS9VED
M(").;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H+B(*;7-G<W1R("+N
MQ2#:SL'*Q,7.SR#6S\3.S\?/(,S)T]3!(-K!(-?+P=K!SLG-(,O2R=3%TJ:D
MS2(*"B,Z('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I
M=F%T92!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,38U
M"FUS9VED(").;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(P,0IM<V=I9"`B3F\@<&5R<V]N
M86P@4R]-24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@<W!E;&QI;F<N<&AP.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P
M<F]G<F%M(&-O;F9I9W5R960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R
M;W)S(@IM<V=S='(@(N_2QL_'TL'&IM[.R<@@T,_-R<S/RR#.Q2#:SL'*Q,7.
MSR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#`*(RP@
M9G5Z>GD*;7-G:60@(DYO('-U9V=E<W1I;VYS(@IM<V=S='(@(O#2S]#/VLG#
MIJ<B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4V-`IM<V=I9"`B3F\@<W5P
M<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T:&]D(&-O=6QD(&)E(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C8X(&%C;"YP:'`Z.30*(RP@
M9G5Z>GD*;7-G:60@(DYO('5S97(@<W!E8VEF:65D+B(*;7-G<W1R("+VS\3.
MP2#0P=#+P2#.Q2#7R<+2P<[!(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<P.0IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@=&5M<&QA=&5S+W!R
M969S+W-E;G1M86EL<V5L96-T+FEN8SHT,`HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS-2!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I
M9"`B3F]N92(*;7-G<W1R("+6S\3.S\?/(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,CDU"FUS9VED(").;W)M86PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,2!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,Y"FUS9VED(").;W0@1&5L971E9"(*;7-G
M<W1R("+.Q2#7R=3%TM2F(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHQ,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C(S"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#(*;7-G:60@
M(DYO="!$<F%F="(*;7-G<W1R("+.Q2#>Q=+.Q=3+R2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S0*;7-G:60@(DYO="!);7!O<G1A;G0B"FUS9W-T<B`BSL4@U\'6
MS,G7IB(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*;7-G
M:60@(DYO="!097)S;VYA;"(*;7-G<W1R("+.Q2#0TLG7P=3.IB(*"B,Z(&QI
M8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S-"!L
M:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@<'5B
M;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B
M[L4@U\G4Q=+4IB#,R=/4R2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B
M[L4@U\'6S,G7IB#,R=/4R2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E
M=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A
M;B!T86ME('-O;64@=&EM92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C$V"B,L(&9U>GIY"FUS9VED(").;W1H:6YG(@IM<V=S='(@
M(N/)U-7`(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PHC+"!F=7IZ
M>0IM<V=I9"`B3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@
M871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB
MZVG,V,MIT]38(-#!T,_+(-=IQ&G3S,'.SZ<@T,_;U,DL(-'+IB#:PL72IL?!
MU,D@T-+)(,VFT]'>SL_-U2#7R=3)TL'.SJ8B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4Y"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@;VQD('-E
M;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2XB
M"FUS9W-T<B`B(@HBZVG,V,MIT]38(-#!T,_+(-=IQ&G3S,'.SZ<@T,_;U,DL
M(-'+IB#:PL72IL?!U,D@T-+)(,VFT]'>SL_-U2#7R=3)TL'.SJ8B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-"!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW,S,*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHT.0HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED
M(")/4B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C$U"FUS9VED(")/;&0@;65S<V%G97,B"FUS9W-T<B`B\]3!TJ8@S,G3U,DB
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN
M9R!P=7)G960N(@IM<V=S='(@(O/4P=*F(-#!T,O)(->FQ*;3S,'.R<@@S,G3
MU*;7(,+5Q-74V"#/WLG=Q<ZF+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HR-0IM<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E860@
M;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O
M;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I;VXN
M(@IM<V=S='(@(N+5Q-@MS,'3R\$L(-?+P=:FU-@@U*;,V,O)(,_$SM4@T,'0
MR]4@Q,S1(,.FI*<@S]#%TL'#IJ<N(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC
M.C$P('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E
M;B!&;U]L9&5R(@IM<V=S='(@(O>FQ,O2R=3)(/#!T,O5(@H*(SH@9F]L9&5R
M<RYP:'`Z-#(W"B,L(&9U>GIY"FUS9VED(")/<&5N960@1F]L9&5R(@IM<V=S
M='(@(O>FQ,O2R=3)(/#!T,O5(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C<P-0IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B
M(@H*(SH@9F5T8VAM86EL+G!H<#HS,R!T96UP;&%T97,O9F5T8VAM86EL+W1O
M<"YI;F,Z,PHC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z
M-@HC+"!F=7IZ>0IM<V=I9"`B3W1H97(@36%I;"!!8V-O=6YT<R(*;7-G<W1R
M("*VSMNF(._0PZ:G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3`*
M;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`BML[;IB#OT,.FIR(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`Q"FUS9VED(")/=71B;W5N
M9"!397)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR
M87-E+FEN8SHQ-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C4*(SH@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`T(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(Y,`IM<V=I9"`B4$=0(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B4$=0
M($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("+WIL3-IL[)U,D@S,G3U"(*"B,Z
M(&-O;7!O<V4N<&AP.C,U.`HC+"!F=7IZ>0IM<V=I9"`B4$=0($5R<F]R.B`B
M"FUS9W-T<B`B\,_-R<S+P2(*"B,Z(&-O;7!O<V4N<&AP.C,S-PIM<V=I9"`B
M4$=0($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A
M=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"B,L(&9U>GIY"FUS9VED(")01U`@3W!T:6]N<R(*;7-G<W1R("+OT,.F
MIR(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!087-S<&AR87-E($EN<'5T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU-0IM<V=I
M9"`B4$=0(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,3<S"FUS9VED(")01U`@4'5B;&EC($ME>2!497AT
M(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,30Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<R`H)7,I7"(@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B\,'0R]4@7"(E<UPB(-73
MT*;;SL\@T]37S]+%SL\N(@H*(SH@<&=P+G!H<#HR-#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("+PP=#+U2!<(B5S7"(@
MU=/0IMO.SR#7R=3%TM3/+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`HC+"!F=7IZ>0IM
M<V=I9"`B4$=0(%-I9VX@365S<V%G92(*;7-G<W1R("+WIL2FT\S!U,D@[,G3
MU,$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.CD*
M;7-G:60@(E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC
M.B!P9W`N<&AP.C(P,@HC+"!F=7IZ>0IM<V=I9"`B4$=0('!R:79A=&4@:V5Y
M('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B\*;$T,G3(-73T*;;SL\@
MVLVFSL7.R<HN(@H*(SH@<&=P+G!H<#HQ-S<*;7-G:60@(E!'4"!P=6)L:6,@
M:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T(&ES
M(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR,#@*;7-G:60@(B(*(E!'4"!S=7!P;W)T
M(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I9VYA
M='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I9"`B(@HB4$=0
M('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A
M9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(B(*(E!'4"!S=7!P;W)T
M(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@
M8G)O=W-E<B!I<R!C=7)R96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@<&]P=7`@
M=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E
M('1H92!01U`@(@HB9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS
M9VED(")03U`S(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,3`P"FUS9VED(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$W"FUS9VED
M(")03U`S(&]V97(@4U-,(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3(S"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE
M9"!C97)T:69I8V%T92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ-CD*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG
M;F5D*2(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q
M,0IM<V=I9"`B4$]0,RP@;F\@5$Q3(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VAE861E<BYI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4&%G92`E9"!O9B`E9"(*;7-G<W1R("+SU,_2IL[+P2`E9"#:("5D(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP,PIM<V=I9"`B4&%G92!W:71H('1H
M92!&:7)S="!5;G-E96X@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3`T"FUS9VED(")086=E('=I=&@@=&AE($QA<W0@
M56YS965N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`BXLS/
MRRC)*2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C,*;7-G:60@(E!A
M<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$R.`IM<V=I9"`B4&%S<W!H<F%S92`H06=A:6XI(@IM<V=S='(@(B(*"B,Z
M('-M:6UE+G!H<#HR,S4@<&=P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(E!A
M<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R("+LR=/4
M(-73T*;;SL\@UZ;$T-+!U\S%SLG*+"#4S\W5(,[%(,+5Q,4@VL+%TL76Q<[/
M(,3/(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$X('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,CD*;7-G:60@(E!A<W-P:')A
M<V4Z(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$R"FUS9VED(")087-S<&AR
M87-E<R!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z
M,3$T"FUS9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L
M871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$Y,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B\,'2
MS\S8(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L
M(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(N[!S,';U-7*U,4@S]#%TL'#IJ<@S\+3S-7'
MS]?5U\'.SM$@Q,S1(-K!T-73R]4@T-+)(-?(S\2F(-<@24U0+B(*"B,Z(&%C
M;"YP:'`Z-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T
M:&ES('5S97(@8V%N(&YO="!B92!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!M
M97-S86=E+G!H<#HT.3,@;6%I;&)O>"YP:'`Z-S`S('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHQ,`IM<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`BT-+)U\'4SJ8B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(N_3S\+)T]3!(+;.QL_2S<'#IM$B"@HC.B!P
M9W`N<&AP.C$R,`IM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,C<*
M;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")097)S;VYA
M;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S='(@
M(B(*"B,Z('-M:6UE+G!H<#HQ,S(*;7-G:60@(E!E<G-O;F%L(%,O34E-12!K
M97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C(R"FUS9VED(")0;&%C92!Y;W5R('-I9VYA
M='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_(@IM<V=S='(@(O+/
MVLVFW=77P=3)(/?!VR#0IL30R=,@T,72Q<0@P\G4S]?!SLG-R2#,R=/4P<W)
M(-#2R2#7IL30S]>FQ*8_(@H*(SH@8V]M<&]S92YP:'`Z,C4T"FUS9VED(")0
M;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3D*;7-G:60@(B(*(E!L87D@<V]U;F0@
M;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S
M=7!P;W)T(&5M8F5D9&5D("(*(G-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D
M;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL
M;"`B"B)R97%U:7)E(&$@<&QU9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O
M>"]J879A<V-R:7!T+FEN8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.B(*;7-G<W1R(")<7&[B
MU<38+<S!T\O!+"#7U\7$IM38(,[!VM?5(,[/U\^G(-#!T,O).EQ<;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"B,L(&9U>GIY"FUS9VED(")0
M;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S
M='(@(EQ<;N+5Q-@MS,'3R\$L(-?7Q<2FU-@@SL':U]4@SL_7SZ<@T,'0R\DZ
M7%QN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S<*
M;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@(N+5
MQ-@MS,'3R\$L(-?7Q<2FU-@@SL_7U2#.P=K7U3HB"@HC.B!T96UP;&%T97,O
M<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I
M=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R`B"B)E;G1E<B!T:&ES
M('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F
M;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E
M9"`B"B)T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S
M<VEO;BXB"FUS9W-T<B`B(@H*(SH@<F5C;VUP;W-E+G!H<#HY-PIM<V=I9"`B
M(@HB4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG('EO
M=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@=7-I;F<@(@HB8V]O:VEE<R!!
M3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W
M<RP@>6]U('=I;&P@:&%V92!T;R`B"B)L;V<@:6X@86=A:6X@:6X@>6]U<B!M
M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S
M(&9R;VT@(@HB:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G
M:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,0HC+"!F=7IZ>0IM<V=I9"`B4&QE
M87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"XB"FUS9W-T<B`BXM7$V"W,P=/+
MP2P@U\O!UJ;4V"#WP=O5(.[!VM?5(,O/TLG3U-77P=[!(*8@\,'2S\S8(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PHC+"!F=7IZ>0IM<V=I
M9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`BXM7$
MV"W,P=/+P2P@U\O!UJ;4V"#WP=O5(.[!VM?5(,O/TLG3U-77P=[!(*8@\,'2
MS\S8(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])35`N<&AP.C0U.0IM<V=I
M9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S
M<V5S+B(*;7-G<W1R("+BU<38+<S!T\O!+"#0Q=+%UZ;2U,4@IM/4R<[.IM/4
MV"#7R\':P<[)R"#!Q-+%TRXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C0R"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@
M:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T
M:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHV,0IM<V=I9"`B4&QE87-E('-E;&5C="!A
M(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N(@IM<V=S
M='(@(N+5Q-@MS,'3R\$L(-?)PL72IM38(-#!T,O5+"#0Q=+;(,ZFUB#0TL_7
MS\3)U,D@PM7$V"W1RZ8@S]#%TL'#IJ<N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4P,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('-E;&5C="!A
M;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T<B`BXM7$V"W,
MP=/+P2P@U\G"Q=*FU-@@R,_>P2#"(,_$SM4@T,'0R]4@Q,S1(-#/V]7+U2XB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC.C0Q"FUS9VED
M(")0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H
M+B(*;7-G<W1R("+BU<38+<S!T\O!+"#7R<+%TJ;4V"#(S][!(,(@S\3.U2#0
MP=#+U2#$S-$@T,_;U<O5+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L
M9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`BXM7$V"W,P=/+P2P@
MU\O!UJ;4V"#4ILS8R\D@S\3.U2#0P=#+U2#$S-$@PZ:DIR#/T,72P<.FIRXB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-S,*(RP@9G5Z
M>GD*;7-G:60@(E!L96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O
M('1H92!R:6=H=#HB"FUS9W-T<B`BXM7$V"W,P=/+P2P@U\G"Q=*FU-@@P<+/
M(->FQ-+%Q,''U<K4Q2#.P=/4U=#.Q3HB"@HC.B!C;VYF:6<O;6]T9"YP:'`N
M9&ES=#HT,0IM<V=I9"`B4&]W97)E9"!B>2!(;W)D92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$T"B,L(&9U>GIY"FUS9VED(")0
M<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_(@IM
M<V=S='(@(O/4P=?)U,D@T,72Q<0@T*;$T,G3S\T@Q,';S\L@*"<M+2`G*2(*
M"B,Z('-M:6UE+G!H<#HR-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP
M.C0P"B,L(&9U>GIY"FUS9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@
M=7!D871E9"XB"FUS9W-T<B`B\,'0R]4@7"(E<UPB(-73T*;;SL\@T]37S]+%
MSL\N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*
M(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS9W-T<B`B\,_0Q=+%Q,[1(//4
MS]*FSLO!(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@365S<V%G92(*;7-G<W1R("+PS]#%
MTL7$SJ;*(.S)T]0B"@HC.B!M86EL8F]X+G!H<#HS-#<*;7-G:60@(E!R979I
M;W5S(%!A9V4B"FUS9W-T<B`B\,_0Q=+%Q,[1(//4S]*FSLO!(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")0
M<FEN="(*;7-G<W1R("+DTM7+(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A
M9&5R<RYI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(E!R:6]R:71Y(@IM<V=S='(@
M(N32U<LB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S8*
M;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP="!E=F5R>2!T
M:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X"FUS9VED(")0
M<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U
M;'0@=&\@6453(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#<GEP="]01U`N<&AP.C0R.0IM<V=I9"`B4'5B;&EC(%!'4"!K97ES
M97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"B,L(&9U>GIY"FUS9VED
M(")0=7)?9V4@1&5L971E9"(*;7-G<W1R("+ZSLG=R=3)(-?)U,72U*8B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC.C@*;7-G:60@(E!U<F=E($1E
M;&5T960B"FUS9W-T<B`B^L[)W<G4R2#7R=3%TM2F(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!U<F=E
M($9O;&1E<BAS*2(*;7-G<W1R("+WR=3%TM3)(-#!T,O5(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F
M=&5N.B(*;7-G<W1R("+QRR#>P=/4SR#/WLG=P=3)(//-IM3.R<LZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-0HC+"!F=7IZ>0IM<V=I9"`B4'5R
M9V4@;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A
M;6]U;G0@;V8@9&%Y<RXB"FUS9W-T<B`B^L[)W<G4R2#,R=/4R2#7(//-IM3.
MR<O5+"#1RZ8@T]3!TMNF(-K!(-3!R]4@RZ;,V,NFT]38(,2FPB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*(RP@9G5Z>GD*;7-G:60@(E!U<F=E
M(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R("+Z
MSLG=R=3)(-/4P=+)RB#,R=/4(-<@\\VFU,[)R]4B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F
M;VQD97(N(@IM<V=S='(@(OK.R=W)U,D@T]3!TLG*(,S)T]0@UR#SS:;4SLG+
MU2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV
M,PHC+"!F=7IZ>0IM<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4<F%S
M:"!F;VQD97(N(@IM<V=S='(@(OK.R=W)U,D@T]3!TLG*(,S)T]0@UR#SS:;4
MSLG+U2(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@
M("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T
M82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E
M+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<75O
M=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T
M871U<SH@3D\@3$E-250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN
M9R`E9CHB"FUS9W-T<B`BX\G4U<`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS.#8*;7-G:60@(E)E7W%U97-T($1E;&EV97)Y($-O;F9I
M<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HU,`HC+"!F
M=7IZ>0IM<V=I9"`B4F5C96EV960@3VXB"FUS9W-T<B`B[]32R<W!SJ8@USHB
M"@HC.B!L:6(O4V5A<F-H+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4F5C96EV
M960@4VEN8V4B"FUS9W-T<B`B[]32R<W!SJ8@USHB"@HC.B!L:6(O4V5A<F-H
M+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T
M<B`B[]32R<W!SJ8@USHB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E)E9&ER96-?="(*;7-G
M<W1R("+PQ=+%SL'0TL'7R=3)(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C="(*;7-G<W1R("+P
MQ=+%SL'0TL'7R=3)(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C$Q,`IM<V=I9"`B4F5D:7)E8W0@365S<V%G92(*;7-G<W1R("+PQ=+%
MSL'0TL'7R=3)(.S)T]0B"@HC.B!C;VUP;W-E+G!H<#HW.#<*;7-G:60@(E)E
M9&ER96-T('1H:7,@;65S<V%G92(*;7-G<W1R("+PQ=+%SL'0TL'7R=3)(,/%
MRB#LR=/4(@H*(SH@8V]M<&]S92YP:'`Z.#0W"FUS9VED(")2961I<F5C=&EN
M9R!F86EL960N(@IM<V=S='(@(O#%TL7.P=#2P=?,Q<[.T2#.Q=?$P<S%+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X,PIM<V=I9"`B
M4F5F<F5S:"(*;7-G<W1R("+OPL[/U\G4R2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E<V@@1F]L9&5R(%9I97=S.B(*;7-G
M<W1R("+OPL[/U\G4R2#7R<?,T<0@\,'0S\LZ(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O:&5A9"YI;F,Z.2!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC
M.C0*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("+PQ=+%WLG4P=3)
M(->FQ,_"TL'6Q<[.T2(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC
M.C,*;7-G:60@(E)E;&]A9"!6:65W(@IM<V=S='(@(O#%TL7>R=3!U,D@UZ;$
MS\+2P=;%SL[1(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R-B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30U"FUS9VED(")296UE;6)E<B!T
M:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<Y"FUS9VED(")296UE;6)E<B!T:&4@;&%S
M="!V:65W(@IM<V=S='(@(O#!S2?1U,'4R2#/T]3!SLZD(->FQ,_"TL'6Q<[.
MT2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PHC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(O/+TLG.V,O!
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C0Q"FUS9VED(")2
M96UO=F4@1FEE;&0@1G)O;2!396%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`U"B,L(&9U>GIY"FUS9VED
M(")296UO=F4@<V]U<F-E(@IM<V=S='(@(M?)Q,',R=3)(,36Q=+%S,\B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS
M9VED(")296YA;64@1F]L9&5R*',I(@IM<V=S='(@(O#%TL7*S<7.U=?!U,D@
M\,'0R]4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY
M"FUS9VED(")296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@
M;V8@;6]N=&@_(@IM<V=S='(@(O#%TL7*S<7.U=?!U,D@T,'0R]4@UZ;$IM/,
MP<[)R"#,R=/4IM<@SL$@T,_>P=3+U2#-IM/1P]$B"@HC.B!L:6(O1F]L9&5R
M+G!H<#HT-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E<UPB
M('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60B"FUS9W-T<B`B[L4@U\3!S,_3T2#0Q=+%RLW%SM77P=3)(%PB)7-<(B#.
MP2!<(B5S7"(N(._3V"#=SR#3R\':P=<@T\72U\72(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED
M(")297!L7WD@=&\@3&ES="(*;7-G<W1R("+WIL30S]>FT]3)(-?3ILTB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")2
M97!L86-E('=I=&@Z(@IM<V=S='(@(OK!S:;.R=3)(,[!.B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L
M>2(*;7-G<W1R("+WIL30S]>FT]3)(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C,Q,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Y"B,L(&9U
M>GIY"FUS9VED(")297!L>2!396YT+B(*;7-G<W1R("+WIL30S]>FT]3)(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS
M9VED(")297!L>2!T;R!!;&PB"FUS9W-T<B`B]Z;$T,_7IM/4R2#7TZ;-(@H*
M(SH@8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L>2!T;R!!;&PZ(@IM<V=S
M='(@(O>FQ-#/UZ;$V"#7TZ;-.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@=&\@
M3&ES="(*;7-G<W1R("+WIL30S]>FT]3)(-?3ILTB"@HC.B!C;VUP;W-E+G!H
M<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O($QI<W0Z(@IM<V=S='(@
M(O>FQ-#/UZ;$V"#7TZ;-.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@=&\@7T%L
M;"(*;7-G<W1R("+WIL30S]>FT]3)(-?3ILTB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3(X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S<*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-PIM<V=I9"`B4F5P;'D@
M=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-0IM<V=I9"`B4F5P;'D@=VET:"!F
M<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E<&QY('=I=&@@
M<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@;65S<V%G92YP:'`Z,C8W"B,L(&9U>GIY"FUS9VED(")297!L>2U4;R(*
M;7-G<W1R("+WIL30S]>FT]3)(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P.0HC
M+"!F=7IZ>0IM<V=I9"`B4F5P;'DM5&\Z("(*;7-G<W1R("+WIL30S]>FT]3)
M(@H*(SH@8V]M<&]S92YP:'`Z-S,Q"B,L(&9U>GIY"FUS9VED(")297!L>3HB
M"FUS9W-T<B`B]Z;$T,_7IM/4R2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM
M<V=S='(@(N/%RB#,R=/4("T@T]#!S2(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHS-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHR,PIM<V=I9"`B4F5P;W)T(&%S(%-P86TB"FUS9W-T<B`BX\7*
M(,S)T]0@+2#3T,'-(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,S@S"B,L(&9U>GIY"FUS9VED(")297%U97-T(&$@7U)E860@4F5C96EP
M="(*;7-G<W1R("+PIL34U\72Q,G4R2#/U-+)S<'.SM$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y(&-O
M;F9I<FUA=&EO;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4W,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S
M/R(*;7-G<W1R("+PIL34U\72Q,G4R2#/U-+)S<'.SM$B"@HC.B!M86EL8F]X
M+G!H<#HQ.#D*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-PIM
M<V=I9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-#,@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C(V"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C$*;7-G
M:60@(E)E<V5T(@IM<V=S='(@(N_>R=/4R=3)(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$Q-0IM<V=I9"`B4F5S<&]N9&5N="!3=&%T=7,@57!D
M871E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T<B`B\-+/Q,_7
MULG4R2(*"B,Z(')E8V]M<&]S92YP:'`Z.3@*;7-G:60@(E)E<W5M92!Y;W5R
M('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")2971U<FX@=&\@7")-97-S
M86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`B\]37S]+%SL[1(,S)T]3!(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHS,2!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-CD*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,S(*;7-G:60@(E)E='5R
M;B!T;R!&971C:"!-86EL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHV,"!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N
M:6YC.C(R"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`Q('1E;7!L
M871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$T"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-#D@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C(@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$W,PHC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS
M9W-T<B`BML[;IB#OT,.FIR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M,3@*;7-G:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F
M=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/R(*
M;7-G<W1R("(B"B+PS]?%TL[5U,G3T2#$SR#3R]+)SMC+R2#0IM/,T2#7R=3)
MTL'.SM$L(-#%TL7.Q=/%SL[1(,'"SR#+S]"FP-?!SL[1(.S)T]3!/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(E)O;&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HT,3D*;7-G:60@(E,O34E-12(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$R"FUS9VED(")3
M+TU)344@16YC<GEP="!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N
M<&AP.C,Y-`IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T<B`B(@H*(SH@
M8V]M<&]S92YP:'`Z,S<S"FUS9VED(")3+TU)344@17)R;W(Z($YE960@<&%S
M<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3$*(RP@9G5Z>GD*;7-G:60@
M(E,O34E-12!/<'1I;VYS(@IM<V=S='(@(N_0PZ:G(@H*(SH@<VUI;64N<&AP
M.C0Y"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)
M344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,30P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME
M>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T
M<B`B\,'0R]4@7"(E<UPB(-73T*;;SL\@U\G4Q=+4SRXB"@HC.B!S;6EM92YP
M:'`Z,38R"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@
M861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,3`*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R("(B
M"@HC.B!S;6EM92YP:'`Z,C$Q"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A
M=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*(RP@9G5Z
M>GD*;7-G:60@(E,O34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B]Z;$IM/,
MP=3)(.S)T]3!(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T
M+FEN8SHQ-`IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C0*
M;7-G:60@(E,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES
M=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L
M>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92`B"B)D
M96-R>7!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,3<S"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA
M8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S<V%G92!C
M86X@;F]T("(*(F)E(&1I<W!L87EE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S=7!P
M;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I
M<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@IM<V=I9"`B(@HB4R]-24U%('-U
M<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@
M>6]U<B!B<F]W<V5R(&ES("(*(F-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P
M;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R
M(&5L<V4@(@HB=&AE(%,O34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,#4*;7-G:60@(E--5%`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4U"B,L(&9U>GIY"FUS9VED(")37W5B
M:F5C="(*;7-G<W1R("+TQ<W!(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S8S"B,L(&9U>GIY"FUS9VED(")385]V92!A(&-O<'D@:6X@
M(@IM<V=S='(@(OK"Q=+%Q]3)(,O/T*;`(-<@(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")3
M85]V92!A<R(*;7-G<W1R("+ZPL72Q<?4R2(*"B,Z('-E87)C:"YP:'`Z,S$V
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-PHC+"!F=7IZ>0IM
M<V=I9"`B4V%V92(*;7-G<W1R("+ZPL72Q<?4R2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4S.`IM<V=I9"`B4V%V92!!='1A8VAM96YT
M<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,S"FUS9VED(")3879E($1R869T
M(@IM<V=S='(@(OK"Q=+%Q]3)(/[%TL[%U,O5(@H*(SH@<V%V96EM86=E+G!H
M<#HT,@HC+"!F=7IZ>0IM<V=I9"`B4V%V92!);6%G92(*;7-G<W1R("+ZPL72
MQ<?4R2(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,#0*;7-G:60@(E-A
M=F4@26UA9V4@:6X@1V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z-3D@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHQ,#`*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,3(@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$T.`HC.B!T96UP;&%T97,O<&=P+VYO=&%C
M=&EV92YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G
M<W1R("+OT,.FIR(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHT,`IM<V=I9"`B4V%V92!3=&%T:6]N97)Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0S,PHC+"!F=7IZ>0IM<V=I9"`B4V%V92!?1')A
M9G0B"FUS9W-T<B`B^L+%TL7'U,D@_L72SL74R]4B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B
M"FUS9W-T<B`B^L+%TL7'U,DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(Q"FUS9VED(")3879E(&1R869T<R!A<R!U;G-E96X_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<R"FUS9VED(")3879E(')E
M8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S
M(&)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,3(W"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"B,L
M(&9U>GIY"FUS9VED(")3879E('-E;G0@;6%I;#\B"FUS9W-T<B`B^L+%TJ;'
MP=3)(->FQ*;3S,'.U2#0S]O4U2(*"B,Z(&-O;7!O<V4N<&AP.C$R,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(N[%(-?$
MP<S/T]$@VL+%TL7'U,D@WL72SL74R]4N(._3V"#=SR#3R\':P=<@T\72U\72
M.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY
M('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K
M+W1R965?9F]L9&5R<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R("+P
MS]O5RR(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ."!T96UP
M;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")396%R8V@@)7,B"FUS9W-T<B`B\,_;U<LB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(P"B,L(&9U>GIY"FUS9VED(")396%R8V@@
M3W!T:6]N<R(*;7-G<W1R("*VSMNF(._0PZ:G(@H*(SH@<V5A<F-H+G!H<#HR
M-C4*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(O+%VM7,V-3!U,D@
M\,_;U<O5(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM
M<V=S='(@(M#2S][)U,'.IB(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z.0IM<V=I9"`B4V5L96-T(@IM<V=S='(@(O?)PM+!U,DB"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-S`*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!!;F]T:&5R($%C8V]U;G0B"FUS9W-T<B`B[L4@U\G"R=+!
MU,D@UL_$SL_'SR(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS
M-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("+WR<+%
MTJ;4V""FT,_3U,'3V"(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN
M8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`B
M]\G"TL'4R2#7TZ8B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS,3<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('-T871I;VYE<GDZ(@IM
M<V=S='(@(N[%(-?)PLG2P=3)(-;/Q,[/Q\\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,U"B,L(&9U>GIY"FUS9VED(")396QE8W0@861D<F5S<R!B
M;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R
M97-S97,N(@IM<V=S='(@(O?)PL72IM38(,'$TL73SJ8@R\[)Q\D@Q,S1(,3/
MQ,'7P<[.T2"F(-#/V]7+U2#!Q-+%TRXB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(O?)PM+!
MU,D@U].F(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S(S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&9I96QD<R!T;R!S96%R
M8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("+WR\'6IM38
M(-[%TL?/UZ;3U-@@X<32Q=/.R<@@R\[)QR#$S-$@T,_;U<O5(,'"SR#7T]3!
MU\O)(*;-Q<XN(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E
M;&5C="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A8V-O=6YT
M(@IM<V=S='(@(N[%(-?)PLG2P=3)(-;/Q,[/Q\\B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C@Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R
M("+NQ2#7R<+)TL'4R2#6S\3.S\?/(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G
M92]S879E:6UA9V4N:6YC.CD*;7-G:60@(E-E;&5C="!T:&4@9V%L;&5R>2!T
M;R!S879E('1H92!I;6%G92!I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T
M('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P.0HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T960@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`B]\G"TL'.IB#AQ-+%
MT\ZF(,O.R<?).B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I
M9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`T"B,L(&9U>GIY"FUS9VED
M(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R("*VSL;/TLW!PZ;1
M(-#2SR#3Q=+7Q=(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHV-R!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S$*;7-G:60@
M(E-E;F0@365S<V%G92(*;7-G<W1R("+WIL2FT\S!U,D@[,G3U,$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S`S"FUS9VED(")396YD(')E860@<F5C
M96EP="!W:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R("(B
M"@HC.B!F;VQD97)S+G!H<#HS.3<*(RP@9G5Z>GD*;7-G:60@(E-E;G0@;6%I
M;"!F;VQD97(B"FUS9W-T<B`B\,'0R\$@UZ;$IM/,P<[)R"#,R=/4IM<Z(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I
M9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`B\,'0R\$@UZ;$IM/,P<[)
MR"#,R=/4IM<Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S(@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-#8*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ-3,*;7-G:60@(E-E<G9E<B(*;7-G<W1R("+SQ=+7
MQ=(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*(RP@9G5Z>GD*;7-G
M:60@(E-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(K;.
MQL_2S<'#IM$@T-+/(-/%TM?%TB(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R.B(*;7-G<W1R
M("+SQ=+7Q=(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@
M(E-E="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO
M=F4@86YD(&1E;&5T92!M97-S86=E<RXB"FUS9W-T<B`B]\O!UJ;4V"P@W<\@
MS<&D(->FQ,+5U,G3T2#0TLD@T,72Q<[%T\7.SJ8@P<+/(-?)U,G2P<[.IB#,
MR=/4IM<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R.0IM<V=I9"`B
M4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O;7!O<VEN9R!M97-S
M86=E<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q
M"B,L(&9U>GIY"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(OK-IL[)
MU,D@T,'0R]4B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.#8*(RP@9G5Z
M>GD*;7-G:60@(E-H87)E(&UA:6P@9F]L9&5R<R(*;7-G<W1R("+PP=#+P2#7
MIL2FT\S!SLG((,S)T]2FUSHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@
M=7-E<G,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-CD*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E
M>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B
M"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L
M9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@
M9F]R(%!'4"!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$S"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E
M(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`B^L'+TLG7
MP=3)(->FR\[/(//4U\_2Q<[.T2#,R=/4P2#0IM/,T2#:PL72Q=;%SL[1(-[%
MTL[%U,O)/R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHT"FUS9VED(")3
M:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y
M;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@(E-H;W<@
M06QL($9O;&1E<G,B"FUS9W-T<B`B^L?/TL[5U,D@U].F(-#!T,O)(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C<*;7-G:60@(E-H;W<@
M06QL($AE861E<G,B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S8U"FUS
M9VED(")3:&]W($1E;&5T960B"FUS9W-T<B`B\,_+P=K!U,D@U\G4Q=+4IB(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED(")3
M:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHW,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!-
M86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T<B`B[]//PLG3U,$@ML[&
MS]+-P<.FT2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@
M9G5Z>GD*;7-G:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS
M9W-T<B`B\,72Q<30S,'4R=3)(/#!T,O5*,DI(@H*(SH@9F]L9&5R<RYP:'`Z
M,CDX"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R("+PS\O!VL'4
MR2#.Q=#%TL7$T,S!WL7.IB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M,#@*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@
M871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P,#(*(RP@9G5Z>GD*;7-G:60@(E-H;W<@
M;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S='(@(NS)T]2FUR#.
MP2#3U,_2IL[+U2#0TLD@T,72Q<?,T<2F(-/+TLG.V,O)+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-#`*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R
M('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('!R979I97=S(&EN('1O
M;VQT:7!S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#<W"FUS9VED(")3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE
M;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY-0IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU-`IM<V=I9"`B4VAO=R!T:&4@
M9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T
M;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G<W1R("+[S-'(
M(,3/(/?!V\G((-#/V]3/U\G((-#!T,_+.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-C8*;7-G:60@(E-H;W=N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#(*(RP@9G5Z>GD*
M;7-G:60@(E-I7WIE(@IM<V=S='(@(N_"T]''(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;&5G96YD+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B4VEG;F5D(@IM
M<V=S='(@(N_"T]''(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B[\+3T<<B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3
M;W)T(&)Y($%R<FEV86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@1G)O;2!!9&1R
M97-S(@IM<V=S='(@(OK7S]+/U,[1(,'$TL73P2(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*(RP@9G5Z>GD*;7-G:60@
M(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(N_"T]''(,S)T]3!(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-@HC
M+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!3=6)J96-T(@IM<V=S='(@(B#TQ<W!
M.B`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C,Q"FUS9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q"B,L(&9U>GIY
M"FUS9VED(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`B^M?/TL_4SM$@
MP<32Q=/!(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S
M"B,L(&9U>GIY"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`B\\VFU,[)
MRSHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#8*;7-G
M:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G<W1R("+ST,7#IL',V,ZF(-/)
MS=?/S,DB"@HC.B!S96%R8V@N<&AP.C$S,PIM<V=I9"`B4W!E8VEA;"!6:7)T
M=6%L($9O;&1E<G,@8V%N(&YO="!B92!E9&ET960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T,PIM<V=I9"`B4W!E
M;&P@0VAE8VLB"FUS9W-T<B`B\,72Q=>FTLO!(-#2P=?/T,G3U2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B4W!E;&P@
M0VAE8VME<B(*;7-G<W1R("+PTL_'TL'-P2#0Q=+%UZ;2R\D@T-+!U\_0R=/5
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU-@IM<V=I9"`B4W!E;&P@8VAE
M8VL@8V]M<&QE=&4B"FUS9W-T<B`B\,72Q=>FTLO5(-#2P=?/T,G3U2#:P=?%
MTMO%SL\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Q"FUS9VED(")3
M<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG
M+B(*;7-G<W1R("+OTL;/Q]+!QJ;>SLG((-#/S<G,S\L@SL$@Q<O2P<X@T-+)
M(-#%TL77IM+#IBXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$R
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3(*;7-G:60@(E-T87)T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHY
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q,0IM<V=I9"`B4W1A
M=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@;F%M93HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED
M(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I
M9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H
M<#HR,34*(RP@9G5Z>GD*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T
M<B`BY,_$P=3/RR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G
M:60@(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*(RP@9G5Z>GD*;7-G
M:60@(E-U8E]J96-T(@IM<V=S='(@(O3%S<$B"@HC.B!M97-S86=E+G!H<#HR
M-C@@=&AR96%D+G!H<#HQ-3`@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E
M+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*
M;7-G<W1R("+TQ<W!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM
M<V=I9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R("+PS\S%(/3%S<DB"@HC.B!S
M96%R8V@N<&AP.C,Q."!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI
M;F,Z,3@*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@
M(E-U8FUI="(*;7-G<W1R("+TQ<W!(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,3$*;7-G:60@(E-U8G-C<FEB92!T;R!&;VQD97(H<RDB
M"FUS9W-T<B`B\,72Q<30S,'4R=3)(/#!T,O5*,DI(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HS.#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@W"FUS9VED(")3
M=6-C97-S(@IM<V=S='(@(O73T*;;SL\B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S='(@
M(O#2S]#/VLG#IJ<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8R
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#`P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,PIM<V=I9"`B
M4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T
M;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O('!L86EN
M('1E>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#$Y"B,L(&9U>GIY"FUS9VED(")495]X="(*
M;7-G<W1R("+TQ<O3U"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-CD*;7-G:60@(E1E;G1A=&EV93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P
M="!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL
M92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*
M;7-G<W1R("+TQ<O3U"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-30*
M;7-G:60@(E1H92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD
M(&)E(&QI;FME9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HU,S(*;7-G:60@(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E
M87(@=&\@<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E
M;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B
M;&4N<&AP.C0Q"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H
M<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U
M<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9E=&-H;6%I;'!R969S+G!H<#HX,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(K;0S]/4P=/8(%PB)7-<(B#:SLG=Q<[/+B(*"B,Z(&9E=&-H;6%I
M;'!R969S+G!H<#HW-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("*VT,_3
MU,'3V"!<(B5S7"(@VL+%TL76Q<[/+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C0S
M"FUS9VED(")4:&4@871T86-H;65N="!W87,@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CD*;7-G:60@(E1H
M92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I
M9"`B(@HB5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R
M:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O
M<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A
M<'!L961O=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@
M36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z
M.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L9&5R*',I
M(%PB)7-<(B!W:6QL(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("+P
MS]3/WL[!(-#!T,O!*,DI(%PB)7-<(B#"U<3%(-#%TL7*S<7.S]?!SL$@SL$@
M7"(E<UPB+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,#<*;7-G:60@
M(B(*(E1H92!C=7)R96YT(&QI<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@=&\@
M=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E=')I979E9"(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HQ,C,V"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@7"(E<UPB(&9O;&1E<BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S.0IM
M<V=I9"`B5&AE(&5V96YT('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.CD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L9"!<(B5S7"(@
M8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@(K;0S]/4P=/8(%PB)7-<(B#:
MSLG=Q<[/+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!A;')E861Y(&5X:7-T<R(*;7-G
M<W1R("+PP=#+P2!<(B5S7"(@U];%(*;3SM6D(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z,38S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E
M<UPB(&-O;G1A:6YS(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@
M270@;6%Y(&-A=7-E("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(O#!T,O!(%PB)7-<(B#-
MIM/4R=38(,[%Q,_:U\_,Q<ZF(-/)S=?/S,D@UR#.P=K7IBX@X\4@S<_6Q2#3
MT-+)WLG.R=3)("(*(M#2S\+,Q<W)+B#BU<38+<S!T\O!+"#0S]+!Q-C4Q=/1
M(-H@T\G3U,7-SLG-(,'$S:;.IM/4TL'4S]+/S2XB"@HC.B!L:6(O1F]L9&5R
M+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O
M(&ET+B(*;7-G<W1R("+PP=#+U2!<(B5S7"(@T]37S]+%SL\L(,',Q2#WR2"G
MIR#.Q2#0Q=+%Q-#,P=3)S,DN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!D96QE
M=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N(@IM
M<V=S='(@(O#!T,O5(%PB)7-<(B#"U<S/(-K.R=W%SL\L(,',Q2#WR2#.Q2#7
MIL3-IL[)S,D@T,72Q<30S,'4U2#.P2#.Q:<N(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9"(*;7-G<W1R("+PP=#+P2!<(B5S7"(@SL4@PM7,P2#3U-?/TL7.P2X@[]/8
M(-W/(-/+P=K!UR#3Q=+7Q=(B"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D
M96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(O#!T,O!(%PB)7-<(B#.Q2#"U<S!(-K.R=W%SL$N(._3V"#=SR#3R\':P=<@
MT\72U\72(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E
M871E9"XB"FUS9W-T<B`B\,'0R]4@7"(E<UPB(-73T*;;SL\@T]37S]+%SL\N
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB
M"FUS9W-T<B`B\,'0R]4@7"(E<UPB(-73T*;;SL\@U\G4Q=+4SRXB"@HC.B!L
M:6(O1F]L9&5R+G!H<#HT-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O
M;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O(%PB)7-<
M(BXB"FUS9W-T<B`B\,'0R\$@7"(E<UPB(-73T*;;SL\@T,72Q<K-Q<[/U\'.
MP2#.P2!<(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDR
M"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@
M=&AI<R!P87)T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7W-A=F5I;6%G95]W:6XN:G,Z,3(*;7-G:60@(B(*(E1H92!I;6%G
M92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@
M:&%V92!S970@>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I;F1O
M=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY
M-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A
M=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B
M;V]K+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L
M;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4
M:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M
M871I;VYA;"!M97-S86=E.B(*;7-G<W1R("+WR\'6IM38(/?!VR#0S]O4S]?)
MRB#3Q=+7Q=(@U,$@IL[&S]+-P<.FP"#0TL\@T,'0R\DN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H92!M86EL('-E<G9E
M<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.B(*;7-G<W1R("(B
M"@HC.B!L:6(O365S<V%G92YP:'`Z-C4Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G
M<W1R("+PP=#+P2!<(B5S7"(@U];%(*;3SM6D(@H*(SH@;&EB+T9E=&-H;6%I
M;"YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(%PB
M)7-<(B!F<F]M(%PB)7-<(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ
M92!L:6UI="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ,#,*;7-G:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O
M<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,30X"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("*VT,_3U,'3V"!<(B5S7"(@VL[)
MW<7.SRXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3,*(RP@9G5Z
M>GD*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G
M<W1R("*VT,_3U,'3V"!<(B5S7"(@VL+%TL76Q<[/+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z
M,3`@=&5M<&QA=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*
M(E1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA
M<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U
M<"!W:6YD;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F
M('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@(E1H
M92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%
M1B!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M>FEP+G!H<#HV-`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T
M(&5X:7-T(&EN('1H92!::7`@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S
M96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E
M($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO
M=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@
M<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4:&4@
M<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@
M=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@
M8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R("+NQ<W/ULS)U\\@VLVF
MSLG4R2#0IL30R=,N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ
M<SHQ,#(*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL>2!R
M97!L86-E9"XB"FUS9W-T<B`B\*;$T,G3(-73T*;;SL\@VLVFSL7.R<HN(@H*
M(SH@871T86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@9FEL
M92!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@<W1A=&EO;F5R>2YP
M:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N
M97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T<B`BMM#/T]3!T]@@
M7"(E<UPB(-K"Q=+%UL7.SRXB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(K;0S]/4P=/8(%PB)7-<(B#:
MSLG=Q<[/+B(*"B,Z('-T871I;VYE<GDN<&AP.C@W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@
M=7!D871E9"XB"FUS9W-T<B`BMM#/T]3!T]@@7"(E<UPB(-K.R=W%SL\N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V.0IM<V=I9"`B5&AE('1A
M<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*(RP@9G5Z>GD*
M;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(M?)U,72
MU,D@S,G3U"(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N
M960@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T
M:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92(*
M;7-G<W1R("+PQ=+%SL'0TL'7R=3)(,/%RB#LR=/4(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92!C86X@8F4@=FEE=V5D
M("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,34T"B,L(&9U>GIY"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R("+PIL30
MR=,@U=/0IMO.SR#:S:;.Q<[)RBXB"@HC.B!L:6(O34E-12]6:65W97(O86QT
M97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I
M=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z
M,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O
M>"XB"FUS9W-T<B`B[L7-P2#6S\3.S\?/(,S)T]3!(-<@T\O2R<[8PZ8N(@H*
M(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES(&YO('1E>'0@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R("+TTL'0R<S!T]$@T,_-R<S+P2#0TLD@S][)
MW<7.SJ8@)7,N(._3V"#=SR#3R\':P=<@T\72U\72(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C8U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V
M97(@<V%I9#H@)7,B"FUS9W-T<B`B]-+!T,G,P=/1(-#/S<G,R\$@T-+)(,_>
MR=W%SLZF(-/+TLG.V,O)+B#OT]@@W<\@T\O!VL'7(-/%TM?%TB(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HV,C$*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED(@IM<V=S='(@(O32P=#)S,'3T2#0S\W)S,O!(-#2R2#/WLG=Q<[.
MIB#3R]+)SMC+R2X@[]/8(-W/(-/+P=K!UR#3Q=+7Q=(B"@HC.B!L:6(O365S
M<V%G92YP:'`Z.3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB
M('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*
M;7-G<W1R("(B"B+TTL'0R<S!T]$@T,_-R<S+P2#0TLD@R\_0IL#7P<[.IB#,
MR=/4IM<@Q,\@7"(E<UPB+B#OT]@@W<\@T\O!VL'7(-/%TM?%TB(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HQ.3@@;&EB+TUE<W-A9V4N<&AP.C(Q,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M("(*(G1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B+TTL'0R<S!T]$@T,_-
MR<S+P2#0TLD@U\G4R=+!SLZF(,S)T]2FUR#:(-#!T,O)(%PB)7-<(BX@[]/8
M(-W/(-/+P=K!UR#3Q=+7Q=(B"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B+TTL'0R<S!T]$@
MT,_-R<S+P2#0TLD@U\G4R=+!SLZF(,S)T]2FUR#7(-#!T,.F(%PB)7-<(BX@
M[]/8(-W/(-/+P=K!UR#3Q=+7Q=(B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("5S(@IM<V=S='(@(O32P=#)S,'3T2#0S\W)S,O!(-#2R2#7R=3)
MTL'.SJ8@S,G3U*;7+B#OT]@@W<\@T\O!VL'7(-/%TM?%TB(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HY.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@
M)7,N(@IM<V=S='(@(O32P=#)S,'3T2#0S\W)S,O!(->FQ,_"TL'6Q<[.T2#:
MP<W/U\S%SL_'SR#,R=/4P2XB"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN
M<&AP.C4R(&QI8B]-24U%+U9I97=E<B]E;G)I8VAE9"YP:'`Z,S<*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T(@IM<V=S='(@(O32P=#)S,'3T2#0S\W)S,O!(->FQ-/)
MS,'.SM$@]\';S\?/(,S)T]3!(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4T-2!L
M:6(O365S<V%G92YP:'`Z-3@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L
M9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*
M;7-G<W1R("(B"B+TTL'0R<S!T]$@T,_-R<S+P2#0TLD@T,_:SL'>Q<[.IB#,
MR=/4IM<@UR#0P=##IB!<(B5S7"(N(._3V"#=SR#3R\':P=<@T\72U\72(@H*
M(SH@9F]L9&5R<RYP:'`Z,38U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R("+T
MTL'0R<S!T]$@T,_-R<S+P2#:PL72Q=;%SL[1(-[%TL[%U,O)+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V
M96YT.B`E<RXB"FUS9W-T<B`B]-+!T,G,P=/1(-#/S<G,R\$@UZ;$S\+2P=;%
MSL[1(-K!S<_7S,7.S\?/(,S)T]3!+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-C8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R
M("+TTL'0R<S!T]$@T,_-R<S+P2#7IL3/PM+!UL7.SM$@VL'-S]?,Q<[/Q\\@
MS,G3U,$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS
M9W-T<B`B]-+!T,G,P=/1(-#/S<G,R\$@UZ;$S\+2P=;%SL[1(-K!S<_7S,7.
MS\?/(,S)T]3!+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HX-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN
M9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA
M="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB]-+!T,G,P=/1(-#/
MS<G,R\$@T-+)(-#%TL7.Q=/%SLZF(,S)T]2FUR#$SR!<(B5S7"(N(._3V"#=
MSR#3R\':P=<@T\72U\72(@H*(SH@8V]M<&]S92YP:'`Z,3(T-`HC+"!F=7IZ
M>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE<W-A
M9V4@87,@82!D<F%F="XB"FUS9W-T<B`B]-+!T,G,P=/1(-#/S<G,R\$@VL+%
MTL76Q<[.T2#>Q=+.Q=3+R2XB"@HC.B!C;VUP;W-E+G!H<#HQ,#`V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V5N
M9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM<V=S='(@(O32P=#)S,'3T2#0S\W)
MS,O!(->FQ-/)S,'.SM$@]\';S\?/(,S)T]3!(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM
M<V=S='(@(O32P=#)S,'3T2#0S\W)S,O!(->FQ,_"TL'6Q<[.T2#:P<W/U\S%
MSL_'SR#,R=/4P2XB"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R("+TTL'0R<S!T]$@T,_-R<S+P2#7IL33R<S!
MSL[1(/?!V\_'SR#,R=/4P2(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY-PIM<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E
M9&1E9"!I;B!I="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT
M;6PN<&AP.CDP"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA
M9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK
M92`B"B)T:&ES.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,38V"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A
M8VAE9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$P-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3$X"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#,@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$U-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3<S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,30*;7-G:60@(E1H
M:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N
M($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B
MX\4@S<_6Q2#:P<K.T=3)(-32S\C)(-[!T]4N(/[)(/?)(-K'S\3.IB#0TL_$
MS]?6U=?!U,D_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H
M<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@36%C:6YT;W-H
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#$P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T
M86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O
M(@HB34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HT,30*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A
M8VAM96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,`IM
M<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@
M<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B`B"B)T:&ES
M(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,S$U"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M97-S
M86=E+B!%<G)O<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C(T,"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS-3`*;7-G:60@
M(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE
M(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U
M*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ
M-S`*;7-G:60@(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`U(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C0Q-@IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET
M86QL>2!S:6=N960@=FEA(%!'4"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S<V%G92!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3,Y(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,C,X"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E
M96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(P,2!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HR.3$*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@
M=VET:"!01U`N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Q,0IM<V=I
M9"`B5&AI<R!M97-S86=E('1O(@IM<V=S='(@(N/%RB#LR=/4(,3/(@H*(SH@
M86-L+G!H<#HT-@IM<V=I9"`B5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y"FUS9VED(")4:&ES('=I;F1O=R!M
M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W:6YD;W<N(@IM<V=S='(@
M(B(*"B,Z('1H<F5A9"YP:'`Z,34R"FUS9VED(")4:')E860@1&ES<&QA>2(*
M;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C<V(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,C(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@
M(O#%TL7>R=3!U,D@UZ;$S\+2P=;%SL[1(@H*(SH@;65S<V%G92YP:'`Z,C8T
M(&UA:6QB;W@N<&AP.C8P-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C(Q.0HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C(R('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T
M96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N
M<&AP.C(V"FUS9VED(")4;R(*;7-G<W1R("+DSR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,3D*(RP@9G5Z>GD*;7-G:60@(E1O($%D9')E<W,B"FUS
M9W-T<B`B^M?/TL_4SM$@P<32Q=/!(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,S(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP
M;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I('=H:6QE("(*(F-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C$S-`IM<V=I9"`B(@HB5&\@=7-E(&$@5$Q3
M(&-O;FYE8W1I;VXL('EO=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N(&]F
M(%!(4"`U+C`N-B!O<B`B"B)H:6=H97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PHC+"!F=7IZ>0IM<V=I9"`B
M5&]T86P@071T86-H;65N=',@4VEZ93HB"FUS9W-T<B`BY,_$P=3+R2(*"B,Z
M(&9O;&1E<G,N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B5')A<V@@9F]L9&5R
M(@IM<V=S='(@(O/-IM3.R<LZ(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H
M<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A<V@@9F]L9&5R.B(*;7-G<W1R("+S
MS:;4SLG+.B(*"B,Z(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C4@;&EB+U%U;W1A
M+VUE<F-U<GDS,BYP:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z
M(&QI8B]1=6]T82]L;V=F:6QE+G!H<#HX."!L:6(O475O=&$O8V]U<FEE<BYP
M:'`Z-3,@;&EB+U%U;W1A+VUD865M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@
M=&\@<F5T<FEE=F4@<75O=&$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S8*;7-G:60@(E5N86YS=V5R960B"FUS9W-T<B`BPL7:(->FQ-#/UZ;$
MIB(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@(E5N
M86YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B[,G3U,D@PL7:(->FQ-#/UZ;$
MIB(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E
M;&5T92(*;7-G<W1R("+WIL3.S]?)U,DB"@HC.B!M86EL8F]X+G!H<#HU.#D@
M;6%I;&)O>"YP:'`Z-C`R(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q,@IM<V=I
M9"`B56YD:7-C;&]S960@4F5C:7!I96YT<R(*;7-G<W1R("+NQ=?)R]+)U*8@
MS]32R<W5U\'>IB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T
M>7!E.B`E<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU-C4*;7-G:60@
M(E5N:VYO=VX@1&%T92(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N($E-05`@<F5S
M<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B!397)V97(@4F5S<&]N9&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C,U"FUS
M9VED(")5;FMN;W=N($UE971I;F<B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP
M:'`Z-C$X"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(%)E8VEP:65N="(*;7-G
M<W1R("+NQ=?)R]+)U*8@S]32R<W5U\'>IB(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED
M(")5;FQO860@4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!F971C:&UA:6QP
M<F5F<RYP:'`Z-C4*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BXL7:ILW%SLZF
M(@H*(SH@;65S<V%G92YP:'`Z-#DY(&UA:6QB;W@N<&AP.C<P."!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C8*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,R"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-0IM
M<V=I9"`B56YS965N(@IM<V=S='(@(L[%WLG4P<ZF(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3(*;7-G:60@(E5N<W5B<V-R:6)E(&9R
M;VT@1F]L9&5R*',I(@IM<V=S='(@(O>FQ,VFSLG4R2#0Q=+%Q-#,P=35(,[!
M(/#!T,O5(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@T
M"FUS9VED(")5<&1A=&4@071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(P"FUS9VED(")5
M<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C4X('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z-38*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0Q"FUS9VED(")5
M<V4@1&5F875L="!686QU92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C4V"B,L(&9U>GIY"FUS9VED(")5<V4@24U!4"!F;VQD97(@
M<W5B<V-R:7!T:6]N<S\B"FUS9W-T<B`B]\G+S]+)T]3/U]77P=3)(-#%TL7$
MT,S!U-4@SL$@T,'0R\D@24U!4"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW,S4*;7-G:60@(E5S92!6:7)T=6%L(%1R87-H($9O;&1E<C\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$T,@HC+"!F=7IZ>0IM
M<V=I9"`B57-E<B(*;7-G<W1R("+NP=K7P2#+S]+)T]35U\'>P2(*"B,Z(&%C
M;"YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB57-E<B!<(B5S7"(@
M<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ-S<*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(N[!
MVM?!(,O/TLG3U-77P=[!(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B
M[L':U\$@R\_2R=/4U=?!WL$B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,C<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B5FEE=R(*;7-G<W1R("+PQ=+%
MQ\S1SM74R2`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.CDR(&QI
M8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R("+PQ=+%Q\S1SM74R2`E<R(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,@4'5B;&EC($ME>2(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,L
M(&9U>GIY"FUS9VED(")6:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E
M('=I;F1O=R(*;7-G<W1R("+PR=/!U,D@S,G3U,D@UR#/R]+%S<_-U2#7ILO.
MIBXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR.`HC+"!F
M=7IZ>0IM<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R("+NS]>F(,S)T]3)
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+
M97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV
M."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(E9I97<@4&5R<V]N
M86P@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3@*;7-G:60@(E9I97<@5&AR96%D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,R!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C4*;7-G:60@(E9I97<@5&AU
M;6)N86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#$X"B,L(&9U>GIY"FUS9VED(")6:65W(&%T=&%C:&UE;G0@:6X@82!S
M97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B\,G3P=3)(,S)T]3)(-<@S\O2Q<W/
MS=4@UZ;+SJ8N(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y
M"B,L(&9U>GIY"FUS9VED(")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<B"FUS9W-T<B`B\,G3P=3)(,S)T]3)(-<@S\O2Q<W/S=4@UZ;+SJ8N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B5FEE
M=R!E=F5N="(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS.#`@;6%I;&)O
M>"YP:'`Z-3,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE
M<W-A9V5S(&EN("5S(@IM<V=S='(@(O#%TL7'S-'.U=3)(,S)T]3)(-<@(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM
M<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S`*
M(RP@9G5Z>GD*;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R("+PQ=+%Q\S1SM74
MR2`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#$*(RP@9G5Z
M>GD*;7-G:60@(E9I97<@=&AE($EM86=E<R(*;7-G<W1R("+PQ=+%Q\S1SM74
MR2#,R=/4R2#7("(*"B,Z('-E87)C:"YP:'`Z,C8S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S
M=6-C97-F=6QL>2XB"FUS9W-T<B`B\,'0R]4@7"(E<UPB(-73T*;;SL\@U\G4
MQ=+4SRXB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Q,2!L:6(O
M24U!4"]4<F5E+G!H<#HQ,S@@;&EB+TE-05`O5')E92YP:'`Z,34Q"B,Z(&QI
M8B])34%0+U1R964N<&AP.C$U,R!L:6(O24U!4"]4<F5E+G!H<#HQ-3<@;&EB
M+TE-05`O5')E92YP:'`Z,34X"B,Z(&QI8B])34%0+U1R964N<&AP.C,V.2!L
M:6(O24U!4"]4<F5E+G!H<#HS.3,@;&EB+TE-05`O5')E92YP:'`Z-#,S"B,L
M(&9U>GIY"FUS9VED(")6:7)T=6%L($9O;&1E<G,B"FUS9W-T<B`B\]37S]+)
MU,D@T,'0R]4B"@HC.B!S96%R8V@N<&AP.C(T-0IM<V=I9"`B5FER='5A;"!&
M;VQD97)S(')E<75I<F4@82!L86)E;"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&
M;VQD97(N<&AP.C$W-2!L:6(O5D9O;&1E<BYP:'`Z,3@P"FUS9VED(")6:7)T
M=6%L($E.0D]8(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q-@IM<V=I
M9"`B5FER='5A;"!)3D)/6"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@;6%I;&)O
M>"YP:'`Z-#4R(&QI8B]61F]L9&5R+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP
M.C$Q.0IM<V=I9"`B5FER='5A;"!4<F%S:"(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(E9I<G1U86P@5')A<V@@1F]L
M9&5R(@IM<V=S='(@(O/-IM3.R<LZ(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U86P@9F]L9&5R(&QA8F5L(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<T"FUS9VED
M(")787)N:6YG(@IM<V=S='(@(O77P<?!(@H*(SH@;&]G:6XN<&AP.C$S.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(O?!
MTR#7IM3!I"`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3D*;7-G
M:60@(B(*(E=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A
M9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN
M;F]C96YT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S(W"B,L(&9U>GIY"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S
M+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M
M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HB\-+)(-?)
MU,G2P<[.IB#,R=/4IM<@T,72Q<[/T\G4R2"GR"#7(//-IM3.R<LL(,$@SL4@
MUZ;$S:;>P=3)(*?((-'+(-?)U,72U*8N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDP-PIM<V=I9"`B5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L
M('=H:6-H('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C$*;7-G:60@(E=H96X@
M<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD('=E('-A=F4@871T86-H;65N="!D
M871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(V
M"FUS9VED("(B"B)7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D
M<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD('1O("(*(G5N
M<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@
M7")`7"(I/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,3D*;7-G:60@(E=H:71E;&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDW.`IM<V=I9"`B665S(@IM<V=S='(@(O3!RR(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-3@*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@
M9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(O?)(,[!S<''P:34Q=/8
M(-?)U,72U,D@U,'+IB#0P=#+R3HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F
M;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U
M(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I
M;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R("+W
MR2#.P<W!Q\&DU,73V"#7R=3%TM3)(-3!RZ8@T,'0R\DZ(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ.0HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W
M:6YG(&9O;&1E<BAS*2XB"FUS9W-T<B`B]\D@SL'-P<?!I-3%T]@@U\G4Q=+4
MR2#4P<NF(-#!T,O).B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I
M<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y
M,@HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A
M(&YE=R!F;VQD97(N(@IM<V=S='(@(O?)(-#%TL7*S<7.S]?5I-3%(-#!T,O5
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P,@IM
M<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@(@IM<V=S
M='(@(O?)(-/4U\_2P*34Q2#0P=#+U2#7T\72Q<3)SJ8@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R
M("+WR2#3U-?/TL"DU,4@T,'0R]4@U]/%TL7$R<ZF("(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,R,`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(W
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-0IM<V=I9"`B66]U
M(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B`B"FUS9W-T<B`B]\D@T,72Q<K-
MQ<[/U]6DU,4@T,'0R]4Z("(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I
M8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(O?)(->FQ,VFSLG,R2#0Q=+%Q-#,
MP=35(,[!(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@8V%N('5S92!T
M:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T
M97AT.B`E8R!F;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E
M<R!F;W(@=&AE('-I9VYA='5R92XB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT
M96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO
M=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E
M;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-CD*;7-G:60@
M(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@
M=&\@=&AI<R!F;VQD97(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP
M.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9F]R=V%R9&5D('1H:7,@
M;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC
M.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE<W-A
M9V5S+B(*;7-G<W1R("+U(/?!TR"D("5S(,[/U\G((,S)T]2FURXB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PIM<V=I9"`B66]U(&AA=F4@
M,2!N97<@;65S<V%G92XB"FUS9W-T<B`B]2#WP=,@I"`Q(,[/U\G*(,S)T]0N
M(@H*(SH@8V]M<&]S92YP:'`Z-#DT"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V
M92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N(@IM<V=S='(@(O4@]\'3
M(*0@,2#.S]?)RB#,R=/4+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA=F4@870@;&5A<W0@;VYE
M(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T('5P;&]A9"!Y
M970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD('1H:7,@;65S
M<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S/R(*;7-G<W1R("(B"@HC
M.B!L:6(O24U0+G!H<#HQ,#<T"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!N
M97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`B]2#W
MP=,@I"#3UZ;6P2#0S]O4P2#7(-3!R\G((-#!T,O!R#I<7&XB"@HC.B!L:6(O
M24U0+G!H<#HQ,#<Y"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!N97<@;6%I
M;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(O4@]\'3(*0@
MT]>FUL$@T,_;U,$@UR#4P<O)R"#0P=#+P<@Z7%QN(@H*(SH@8V]M<&]S92YP
M:'`Z,34S"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S
M="!O;F4@<F5C:7!I96YT+B(*;7-G<W1R("+WR\'6IM38(,C/WL$@PB#/Q,[/
MQ\\@P<32Q=/!U,$N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S`R
M"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@
M>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#D*;7-G
M:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN
M8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+B(*
M;7-G<W1R("+ST,72V]4@U\O!UJ;4V"#3R]+)SMC+U2#0TLG:SL'>Q<[.T2XB
M"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S
M='(@(O?+P=:FU-@@IM#/T]3!T]@L(-'+U2#3S*;$(-?)U,72U,DN(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S
M='(@(O/0Q=+;U2#7R\'6IM38(-/+TLG.V,O5(-#2R=K.P=[%SL[1+B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8R('1E;7!L871E
M<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(P.`HC.B!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHR-C,*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A="!L96%S="!O;F4@;65S<V%G92!F:7)S="XB"FUS9W-T<B`B\]#%TMO5
M(-?)PL72IM38(,C/WL$@PB#/Q,G.(,S)T]0N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@<F5C:7!I96YT+B(*;7-G<W1R("+WR\'6IM38(,_4TLG-U=?!WL$N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,CD*(RP@9G5Z
M>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I;&4@
M=&\@871T86-H+B(*;7-G<W1R("+ST,72V]4@U\O!UJ;4V"#&P<K,+"#1R\G*
M(-32Q<+!(-#2R<O2IM#)U,DN(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C0X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!N965D('1O
M(&AA=F4@7"(E<UPB(&5N86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I
M;VYS+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE
M<W-A9V4@=&\@)7,@;VX@)25S+B(*;7-G<W1R("+PQ=+%SL'0TL'7R=3)(,/%
MRB#LR=/4(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$T,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N
M("5S+B(*;7-G<W1R("+PQ=+%SL'0TL'7R=3)(,/%RB#LR=/4(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-3`W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E
M(&YO="!S=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R("+WR2#.Q2#0Q=+%Q-#,P=3)S,D@7"(E<UPB
M+B#OT]@@W<\@T\O!VL'7(-/%TM?%TB(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@=6YS=6)S8W)I
M8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED
M(@IM<V=S='(@(O?)(,[%(->FQ,VFSLG,R2#0Q=+%Q-#,P=35(,[!(%PB)7-<
M(BX@[]/8(-W/(-/+P=K!UR#3Q=+7Q=(B"@HC.B!L:6(O1F]L9&5R+G!H<#HU
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY
M('-U8G-C<FEB960@=&\@7"(E<UPB(@IM<V=S='(@(O?)(-73T*;;SL\@T,72
MQ<30S,'4R<S)(%PB)7-<(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S
M8W)I8F5D(&9R;VT@7"(E<UPB(@IM<V=S='(@(O?)(->FQ,VFSLG,R2#0Q=+%
MQ-#,P=35(,[!(%PB)7-<(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHY
M.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(O?!V\4@T,_7
MSL4@ILTGT3HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G:60@
M(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4'5B;&EC($ME>2(*
M;7-G<W1R("+WP=O%(-#/U\[%(*;-)]$Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$V-0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!297!L>2UT;SH@861D
M<F5S<SH@/&5M/BAO<'1I;VYA;"D\+V5M/B(*;7-G<W1R("+WP=O!(-K7S]+/
MU,[1(,'$TL73P3H@/&D^*,_0PZ;/SL',V,[/*3PO:3XB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-12!0=6)L
M:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S='(@(O?!VZ8@IM#/T]3!TZ8Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PIM<V=I9"`B(@HB66]U
M<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@
M861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O
M9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(B(*(O?!VR#"TL_5VL72(,[%
M(-"FQ-32R<W5I"##V,_'SR#-Q=3/Q-4@Q-+5R]4N(.+5Q-@MS,'3R\$L(,[!
MU,G3SJ;4V"!#=')L+R(*(D]P=&EO;B`K(%`L(-W/PB#2S]K$TM7+U=?!U,D@
MP\`@T]3/TJ;.R]4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM
M<V=I9"`B66]U<B!D969A=6QT(&-H87)S970@9F]R('-E;F1I;F<@;65S<V%G
M97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L
M96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H
M;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")9;W5R
M(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@
M(O#!T,O5(%PB)7-<(B#5T]"FV\[/(-?)U,72U,\N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(P-@IM<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM<V=S
M='(@(O?!VR#0IL30R=,Z(@H*(SH@;65S<V%G92YP:'`Z,C@X(&-O;7!O<V4N
M<&AP.C$R.#0@;6%I;&)O>"YP:'`Z-30Y(&QI8B]#;VUP;W-E+G!H<#HX,3@*
M(RP@9G5Z>GD*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");XL7:(-3%
MS<E=(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,L
M(&9U>GIY"FUS9VED(")?0F-C(@IM<V=S='(@(D)C8R(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B7T)L86-K;&ES
M="(*;7-G<W1R("*VQ\[/TM77P=3)(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,34T"B,L(&9U>GIY"FUS9VED(")?0V,B"FUS9W-T<B`B
M0V,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")?1&5L
M971E(@IM<V=S='(@(O?)U,72U,DB"@HC.B!L:6(O24U0+G!H<#HY-SD*(RP@
M9G5Z>GD*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@(O#!T,O)(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.#$*(RP@9G5Z>GD*;7-G:60@
M(E])9&5N=&ET>2(*;7-G<W1R("*VT,_3U,'3IB(*"B,Z(&QI8B])35`N<&AP
M.CDV,0IM<V=I9"`B7TEN8F]X(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP
M.C$P,C`*(RP@9G5Z>GD*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(O?)RM3)
M(@H*(SH@;65S<V%G92YP:'`Z,S@T"B,L(&9U>GIY"FUS9VED(")?365S<V%G
M92!3;W5R8V4B"FUS9W-T<B`B]\G(IL3.R<H@U,7+T]0B"@HC.B!L:6(O24U0
M+G!H<#HY-S8*(RP@9G5Z>GD*;7-G:60@(E].97<@365S<V%G92(*;7-G<W1R
M("+NS]>F(,S)T]3)(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")?4')I;G0B"FUS9W-T<B`B
MY-+5RR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.#D*;7-G:60@(E]0<FEO
M<FET>2(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HT,3@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@(N_"SL_7
MR=3)(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C@*(RP@9G5Z>GD*;7-G:60@(E]297!L>2(*;7-G<W1R("+WIL30S]>FT]3)
M(@H*(SH@;&EB+TE-4"YP:'`Z.3@Q"B,L(&9U>GIY"FUS9VED(")?4V5A<F-H
M(@IM<V=S='(@(O#/V]7+(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"B,L
M(&9U>GIY"FUS9VED(")?4V5N9"!-97-S86=E(@IM<V=S='(@(O>FQ*;3S,'4
MR2#LR=/4P2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(E]4:')E860B"FUS9W-T<B`BSL7>
MR=3!SJ8B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*
M(RP@9G5Z>GD*;7-G:60@(E]4;R(*;7-G<W1R("+DSR(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")?56YD
M96QE=&4B"FUS9W-T<B`B]Z;$SL_7R=3)(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")?5FEE=R!4:')E860B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS
M9VED(")?5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ-S8*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT-#`*(RP@9G5Z>GD*;7-G:60@(F%T=&%C:&UE
M;G0B"FUS9W-T<B`BY,_$P=3/RR(*"B,Z('9I97<N<&AP.CDY"B,L(&9U>GIY
M"FUS9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`BY,_$P=3+R2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PIM<V=I9"`B8GET
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P,`IM<V=I9"`B
M8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,3<R"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G
M<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38T"FUS9VED(")C;VUM86YD
M(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(R,`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DV"FUS9VED(")C<FET:6-A;"!S>7-T
M96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ-C@*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR,C0*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B9G)O;2(*;7-G<W1R("+WIL0B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,3@P"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`T"FUS9VED(")I;G!U
M="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C$X.`IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@<VUI;64N<&AP.C(Y('!G<"YP:'`Z-CD*;7-G:60@(FME>2(*;7-G
M<W1R("(B"@HC.B!F;VQD97)S+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(FUA
M:6QB;W@@9FEL92(*;7-G<W1R("+SR]+)SMC+P2(*"B,Z(&-O;7!O<V4N<&AP
M.C$P-C<@;&EB+TUE<W-A9V4N<&AP.C0V-@HC+"!F=7IZ>0IM<V=I9"`B;F%M
M92(*;7-G<W1R("+BQ=JFS<7.SJ8B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`BUL_$SL_'SR(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@
M(F]R(@IM<V=S='(@(L'"SR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,38*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR,3(*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@T"FUS9VED(")S97)V
M:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS
M9W-T<B`BQ]+!S<'4R=[.P2#0S\W)S,O!(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<G,B"FUS
M9W-T<B`BQ]+!S<'4R=[.R<@@T,_-R<S/RR(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("+'
MTL'-P=3)WL[!(-#/S<G,R\$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`X"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL
M=&5R+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS
M9W-T<B`BML?.S]+5U\'4R2(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED
M(")Y;W5R('=H:71E;&ES="(*;7-G<W1R("(B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+VET7TE4+G!O
M````````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0R
M,#<P,0`Q,#0Q-S,V,C<V-``P,3<R,#(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(R!)=&%L:6%N('1R86YS;&%T:6]N<R!F
M;W(@26UP('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R
M;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A
M;64@;&EC96YS92!A<R!T:&4@26UP('!A8VMA9V4N"B,@075T;VUA=&EC86QL
M>2!G96YE<F%T960L(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($EM<"`T+C`M8W9S7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-2TP,RTP,2`Q,3HQ-RLP,3`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($UA<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O=F%N;T!U;FEB;V-C;VYI
M+FET/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q.`HC
M+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z("(*;7-G<W1R("(@("`@("!!.B`B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$U"FUS9VED("(@("`@("!4;SH@(@IM
M<V=S='(@(B`@("`@($$Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#,*;7-G
M:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@($1A=&$Z("(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HT,#8*;7-G:60@(B`@("!&<F]M.B`B"FUS9W-T<B`B("`@
M($1A.B`B"@HC.B!M86EL8F]X+G!H<#HT,C(@=&5M<&QA=&5S+V9O;&1E<G,O
M:&5A9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E
M<RDB"FUS9W-T<B`B("A#:&EA=F4@06-C97-S;R`E<RDB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z-#$R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(B!/9V=E
M='1O.B`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S`*
M;7-G:60@(B!I;B`B"FUS9W-T<B`B(&EN("(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T<B`B
M(R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HV.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B4N
M,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"@HC.B!T:')E860N<&AP.C$U,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T
M<B`B3F5S<W5N($UE<W-A9V=I;R(*"B,Z(&UA:6QB;W@N<&AP.C$W-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N
M(&1E;&5T960N(@IM<V=S='(@(B5D(&UE<W-A9V=I;RAI*2!S;VYO('-T871I
M(&5L:6UI;F%T:2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(E9"!M97-S86=G:2!S;VYO('-T871I('-E9VYA;&%T:2!C;VUE(&YO
M;BUS<&%M(&%L('1U;R!A;6UI;FES=')A=&]R92XB"@HC.B!L:6(O4W!A;2YP
M:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B)60@;65S<V%G
M9VD@<V]N;R!S=&%T:2!S96=N86QA=&D@8V]M92!N;VXM<W!A;2XB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A
M9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B5D(&UE<W-A9V=I('-O;F\@<W1A
M=&D@<V5G;F%L871I(&-O;64@<W!A;2!A;"!T=6\@86UM:6YI<W1R871O<F4N
M(@H*(SH@;&EB+U-P86TN<&AP.C$U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS9W-T
M<B`B)60@;65S<V%G9VD@<V]N;R!S=&%T:2!S96=N86QA=&D@8V]M92!S<&%M
M+B(*"B,Z(&UA:6QB;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R(")D82`E9"!A("5D(&1I
M("5D($UE<W-A9V=I(@H*(SH@;6%I;&)O>"YP:'`Z-C0P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD
M97(@=V%S(&YO="!R96YA;65D+B(*;7-G<W1R("(E<R!E<VES=&4@9VG@+B!,
M82!C87)T96QL82`E<R!N;VX@Z"!S=&%T82!R:6YO;6EN871A+B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HV-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B
M)7,@;F]N('-E;6)R82!E<W-E<F4@=6YA(&-A<V5L;&$@=F%L:61A+B(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY
M+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@8F5I;F<@
M<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G<W1R("),
M82!C87)T96QL82`E<R!V97)RX"!R:6YO;6EN871A(&%D(&EN:7II;R!M97-E
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R("(E<R!H82!A
M8V-E='1A=&\N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@8V%N8V5L;&5D("5S+B(*;7-G
M<W1R("(E<R!H82!C86YC96QL871O("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&1E
M8VQI;F5D+B(*;7-G<W1R("(E<R!H82!R:69U:71A=&\N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R
M("(E<R!H82!R:7-P;W-T;R!A('5N82!R:6-H:65S=&$@;&EB97)O+V]C8W5P
M871O+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I
M;VX@=&\@)7,N(@IM<V=S='(@(B5S(&AA(')I<W!O<W1O(&%L(&EN=FET;R!A
M("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B)7,@=&D@:&$@;6%N9&%T;R!I;F9O<FUA>FEO
M;FD@;&EB97)O+V]C8W5P871O+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('1E;G1A=&EV
M96QY(&%C8V5P=&5D+B(*;7-G<W1R("(E<R!T96YT871I=FD@86-C971T871I
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B5S(')I8VAI961E(&EN9F]R;6%Z:6]N<VD@<W5L
M('1U;R!L:6)E<F\O;V-C=7!A=&\N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y
M;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(E<R!R:6-H:65D92!L82!T
M=6$@<')E<V5N>F$@82`E<RXB"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B)7,@<W!O<W1A=&\@8V]N('-U
M8V-E<W-O(&$@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@86UM96YD("5S
M+B(*;7-G<W1R("(E<R!V=6]L92!M;V1I9FEC87)E("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(E
M<R!V;W)R96)B92!F87)T:2!P<F5S96YT92!D96P@)7,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B
M;W5T("5S+B(*;7-G<W1R("(E<R!V;W)R96)B92!R:6-E=F5R92!L92!U=&QI
M;64@:6YF;W)M87II;VYI('-U("5S+B(*"B,Z(&UE<W-A9V4N<&AP.C(X-2!M
M97-S86=E+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM
M<V=S='(@(B5S.B`E<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T
M;W`N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S
M<#MO9B9N8G-P.R5D*2(*;7-G<W1R("(E<SH@)7,@*"5D)FYB<W`[9&DF;F)S
M<#LE9"DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S
M"FUS9VED("(H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT
M('-C<F5E;BXI(@IM<V=S='(@(BA%9F9E='1U82!Q=65S=&4@;6]D:69I8VAE
M(&4@<&%S<V$@86QL82!F:6YE<W1R82!S=6-C97-S:79A+BDB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED("(H1&ES8V%R
M9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E
M;BXI(@IM<V=S='(@(BA)9VYO<F$@='5T=&4@;&4@;6]D:69I8VAE(&4@=&]R
M;F$@86QL82!F:6YE<W1R82!#;VUP;VYI($UE<W-A9V=I;RXI(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED
M("(H2%1-3"DB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*%!L86EN(%1E>'0I(@IM<V=S='(@
M(B(*"B,Z('-P96QL:6YG+G!H<#HR.#`*;7-G:60@(B(*(BA2971U<FX@=&\@
M=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S
M(&UA9&4@=&AU<R!F87(N("`B"B)#:&%N9V5S(&]N('1H92!C=7)R96YT('-C
M<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*%1O<FYA
M(&%L;&$@9FEN97-T<F$@0V]M<&]N:2!-97-S86=G:6\@9&]P;R!A=F5R(&%P
M<&QI8V%T;R!T=71T92!L92`B"B)M;V1I9FEC:&4@9F%T=&4@9FEN;W)A+B`@
M3&4@;6]D:69I8VAE(&$@<75E<W1A(&9I;F5S=')A($Y/3B!V97)R86YN;R`B
M"B)E9F9E='1U871E+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"FUS9VED("(B
M"B(H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA
M9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E
M;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*%1O<FYA(&%L
M;&$@9FEN97-T<F$@0V]M<&]N:2!-97-S86=G:6\@9&]P;R!A=F5R(&%P<&QI
M8V%T;R!T=71T92!L92`B"B)M;V1I9FEC:&4@9F%T=&4@9FEN;W)A+B`@3&4@
M;6]D:69I8VAE(&$@<75E<W1A(&9I;F5S=')A($Y/3B!V97)R86YN;R`B"B)E
M9F9E='1U871E+BDB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*B(*
M;7-G<W1R("(J($%G9VEU;F=I;&D@8VQI8V-A;F1O('-U($]+("HB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0
M;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS9W-T<B`B*B!396QE>FEO
M;F$@9VQI(&EN9&ER:7IZ:2`J(@H*(SH@;6%I;&)O>"YP:'`Z,3<T"B,L(&9U
M>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B26P@;65S<V%G9VEO(.@@<W1A=&\@96QI;6EN871O+B(*"B,Z(&QI8B]3
M<&%M+G!H<#HQ.#`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"B(Q(&UE<W-A9V=I;R#H('-T871O('-E9VYA;&%T;R!C;VUE
M(&YO;B!S<&%M(&%L('1U;R!A;6UI;FES=')A=&]R92!D:2!S:7-T96UA+B(*
M"B,Z(&QI8B]3<&%M+G!H<#HQ-C`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E
M;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B,2!M97-S86=G:6\@
MZ"!S=&%T;R!S96=N86QA=&\@8V]M92!N;VX@<W!A;2XB"@HC.B!L:6(O4W!A
M;2YP:'`Z,3<R"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@
M87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B(Q(&UE<W-A9V=I;R#H('-T871O('-E9VYA;&%T;R!C;VUE('-P86T@
M86P@='5O(&%M;6EN:7-T<F%T;W)E(&1I('-I<W1E;6$N(@H*(SH@;&EB+U-P
M86TN<&AP.C$U,@IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D
M(&%S('-P86TN(@IM<V=S='(@(C$@;65S<V%G9VEO(.@@<W1A=&\@<V5G;F%L
M871O(&-O;64@<W!A;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*
M;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(C$P,"!C87)A='1E<FDB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(R"FUS9VED("(Q,#`P(&-H
M87)A8W1E<G,B"FUS9W-T<B`B,3`P,"!C87)A='1E<FDB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#(P"FUS9VED("(R-3`@8VAA<F%C=&5R<R(*;7-G
M<W1R("(R-3`@8V%R871T97)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@R,0IM<V=I9"`B-3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B-3`P(&-A<F%T
M=&5R:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T
M=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B56X@:6UM86=I;F4@
M9W)O<W-A(&YO;6EN871A("5S(.@@86QL96=A=&$@82!Q=65S=&\@;65S<V%G
M9VEO+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4P
M"FUS9VED("(B"B)!(&UE<W-A9V4@>6]U(&AA=F4@<V5N="!H87,@<F5S=6QT
M960@:6X@82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@=&AE("(*(G)E8VEP
M:65N="XB"FUS9W-T<B`B56X@;65S<V%G9VEO(&-H92!H86D@:6YV:6%T;R!H
M82!P<F]D;W1T;R!U;F$@;F]T:69I8V$@9&%L(')I8V5V96YT92XB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0IM<V=I9"`B04Y$(@IM<V=S
M='(@(D4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DP"FUS9VED
M(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")!8V-E='1A(%)I8VAI97-T92(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*(RP@9G5Z>GD*;7-G
M:60@(D%C8V5P="!R97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B
M"FUS9W-T<B`B3"=E=F5N=&\@Z"!S=&%T;R!A9V=I=6YT;R!A;"!T=6\@8V%L
M96YD87)I;RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4S"FUS
M9VED(")!8V-E<'1E9"(*;7-G<W1R(")!8V-E='1A=&\B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,C4W"B,L(&9U>GIY"FUS9VED(")!8V-E<'1E
M9#H@(@IM<V=S='(@(D%C8V5T=&%T;R(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT)W,@;F%M93HB"FUS9W-T
M<B`B3F]M92!D96QL)V%C8V]U;G0Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4R,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,P"FUS9VED
M(")!8W1I;VYS(@IM<V=S='(@(D%Z:6]N:2(*"B,Z(&QI8B]-24U%+TAE861E
M<G,N<&AP.C(P,"!L:6(O34E-12](96%D97)S+G!H<#HR,#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%D9"`E<R!T;R!M>2!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B06=G:75N9VD@86QL82!2=6)R:6-A("@E<RDB"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*;7-G:60@(D%D9"!S
M;W5R8V4B"FUS9W-T<B`B06=G:75N9VD@<V]R9V5N=&4B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#@*;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@
M(D%G9VEU;F=I(&%L(&UI;R!C86QE;F1A<FEO(@H*(SH@8V]M<&]S92YP:'`Z
M,3(U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@
M871T86-H;65N="XB"FUS9W-T<B`B7"(E<UPB(&%G9VEU;G1O(&-O;64@86QL
M96=A=&\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`HC+"!F=7IZ
M>0IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE
M;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B
M"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(DEN=&5S=&%Z:6]N
M:2!A9&1I>FEO;F%L:2!D82!M;W-T<F%R92!I;B!V:7-U86QI>GIA>FEO;F4Z
M(#QI/BAO<'II;VYA;&4L("(*(FEN<V5R:7)E(&]G;FD@:6YT97-T87II;VYE
M(&EN('5N82!N=6]V82!L:6YE82D\+VD^(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M:71I;VYA;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M(")5;'1E<FEO<FD@:6YF;W)M87II;VYI('!O<W-O;F\@97-S97)E('9I<W5A
M;&EZ>F%T92`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN
M<&AP.C8R"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B
M"FUS9W-T<B`B56QT97)I;W)I($EN9F]R;6%Z:6]N:2!097)S;VYA;&4B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`B56QT97)I;W)I(&1E='1A
M9VQI(&1E;"!M97-S86=G:6\B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A
M9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")5;'1E<FEO
M<FD@9&5T=&%G;&D@9&5L(&UE<W-A9V=I;R!P;W-S;VYO(&5S<V5R92!V:7-U
M86QI>GIA=&D@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-S@*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(@IM
M<V=S='(@(E5L=&5R:6]R:2!D971T86=L:2!D96P@;65S<V%G9VEO(&0G97)R
M;W)E(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I
M;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@HB56QT97)I;W)I(&1E
M='1A9VQI(&1E;"!M97-S86=G:6\@9"=E<G)O<F4@<&]S<V]N;R!E<W-E<F4@
M=FES=6%L:7IZ871I("5S(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")2=6)R:6-A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`IM<V=I9"`B061D<F5S
M<R!";V]K<R(*;7-G<W1R(")2=6)R:6-H92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.#D*(RP@9G5Z>GD*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!"
M0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D
M9')E<W,@;VX@82!N97<@(@HB;&EN92D\+V5M/B(*;7-G<W1R("(B"B));G9I
M82!A($)#0R!T=71T:2!I(&UE<W-A9V=I.B`\:3XH;W!Z:6]N86QE+"!I;G-E
M<FES8VD@;V=N:2!I;F1I<FEZ>F\@:6X@=6YA("(*(FYU;W9A(')I9V$I/"]I
M/B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#$*(RP@9G5Z>GD*;7-G
M:60@(B(*(D%D9')E<W-E<R!T;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES(&ED
M96YT:71Y.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H("(*(F%D9')E<W,@
M;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"B));F1I<FEZ>FD@9&$@
M;&5G87)E(&5S<&QI8VET86UE;G1E(&$@<75E<W1A(&ED96YT:73@.B`\:3XH
M;W!Z:6]N86QE+"`B"B)I;G-E<FES8VD@;V=N:2!I;F1I<FEZ>F\@:6X@=6YA
M(&YU;W9A(')I9V$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C,*;7-G:60@(D%L;"(*;7-G
M<W1R(")4=71T:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3,*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG
M(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B
M"B)F:6QE.B(*;7-G<W1R("(B"B)4=71T:2!I(&UE<W-A9V=I(&1E;&QE('-E
M9W5E;G1I(&-A<G1E;&QE('-A<F%N;F\@<V-A<FEC871I(&EN('5N(&9I;&4@
M34)/6#HB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN
M('EO=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B
M92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R("(B"B)4=71T:2!I
M(&UE<W-A9V=I(&YE;&QA(&-A<G1E;&QA(%PB)7-<(BP@<&GY('9E8V-H:2!D
M:2`E<R!G:6]R;FDL('-A<F%N;F\@(@HB96QI;6EN871I('!E<B!S96UP<F4N
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S
M7VUO;G1H;'DN<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@
M;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I
M;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B(@HB5'5T=&4@;&4@8V%R=&5L;&4@
M9&D@4&]S=&$@26YV:6%T82!P:?D@=F5C8VAI92!D:2`E<R!M97-I('-A<F%N
M;F\@8V%N8V5L;&%T92XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE
M=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N
M=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@(B(*(E1U='1E(&QE
M(&-A<G1E;&QE(&1I(%!O<W1A($EN=FEA=&$@<&GY('9E8V-H:64@9&D@)7,@
M;65S:2!S87)A;FYO(&-A;F-E;&QA=&4N(@H*(SH@86-L+G!H<#HX-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(')I9VAT<R!O;B!F;VQD97(@
M7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U<V5R(%PB)7-<(BXB
M"FUS9W-T<B`B(@HB5'5T=&D@:2!D:7)I='1I('-U;&QA(&-A<G1E;&QA("<E
M<R<@<V]N;R!S=&%T:2!R:6UO<W-I('!E<B!L)W5T96YT92`G)7,G(@H*(SH@
M;&EB+V%P:2YP:'`Z-S8*;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A=&EO;C\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0X
M"FUS9VED(")!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A
M;GD@;6%I;&)O>#\B"FUS9W-T<B`B4&5R;65T=&D@87!P;&EC87II;VYE(&9I
M;'1R:2!I;B!O9VYI($-A<V5L;&$B"@HC.B!L:6(O34E-12]6:65W97(O86QT
M97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B06QT97)N871I=F4@<&%R=',@9F]R
M('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B4&%R=&D@86QT97)N871I=F4@<&5R
M('%U97-T82!S97II;VYE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-S(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X-`IM<V=I9"`B06QW87ES(@IM
M<V=S='(@(E-E;7!R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3<*
M;7-G:60@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(E-A;'9A
M('-E;7!R92!G;&D@86QL96=A=&DB"@HC.B!L:6(O365S<V%G92YP:'`Z-3`U
M"FUS9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@
M=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S
M86ED.B`B"FUS9W-T<B`B(@HB17)R;W)E(&1U<F%N=&4@:6P@=&5N=&%T:79O
M(&1I(&]T=&5N97)E(&PG86QL96=A=&\N($EL('-E<G9E<B!)34%0(&AA("(*
M(G)I<W!O<W1O.B`B"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY
M"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I
M;F<@=&AE(&YE=R!N;W1E+B(*;7-G<W1R(")3:2#H('9E<FEF:6-A=&\@=6X@
M97)R;W)E('-C;VYO<V-I=71O(&%G9VEU;F=E;F1O(&QA(&YU;W9A('9O8V4N
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X-PIM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RXB"FUS
M9W-T<B`B4VD@Z"!V97)I9FEC871O('5N(&5R<F]R92!S8V]N;W-C:75T;R!A
M9V=I=6YG96YD;R!L82!N=6]V82!V;V-E+B(*"B,Z(&UE<W-A9V4N<&AP.C4P
M,"!M86EL8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHY"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D(@IM<V=S
M='(@(E)I<W!O<W1O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS
M,0IM<V=I9"`B06YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B365S<V%G9VD@
M82!C=6D@<VD@Z"!R:7-P;W-T;R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE
M861E<BYI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G
M<W1R(")!<'!L:6-A(&D@1FEL=')I(&$B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%P
M<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`B07!P;&EC82!I($9I;'1R:2!A
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS9VED(")!
M<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")!
M<'!L:6-A(&QE(')E9V]L92!D96P@9FEL=')O(&$@:6YI>FEO('-E<W-I;VYE
M+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT,@IM<V=I9"`B
M07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE
M9#\B"FUS9W-T<B`B07!P;&EC82!L92!R96=O;&4@9&5L(&9I;'1R;R!O9VYI
M('9O;'1A(&-H92!)3D)/6"#H(&UO<W1R871O/R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B
M;&EC(&ME>3\B"FUS9W-T<B`B4VEC=7)O(&1I('9O;&5R(&-A;F-E;&QA<F4@
M<75E<W1A(&-H:6%V92!P=6)B;&EC83\B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B
M(@HB07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A
M:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(B(*(E-E
M:2!S:6-U<F\@9&D@=F]L97(@96QI;6EN87)E('%U97-T82!R96=O;&$_("A1
M=65S=&\@3D].(.@@<F%C8V]M86YD871O(2DB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FIS.C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES
M/R(*;7-G<W1R(")396D@<VEC=7)O(&1I('9O;&5R;&\@9F%R93\B"@HC.B!M
M97-S86=E+G!H<#HT,#<@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%
M3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(E-E:2!S:6-U
M<F\@9&D@=F]L97(@8V%N8V5L;&%R92!015(@4T5-4%)%('%U97-T:2!M97-S
M86=G:3\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H
M:7,@871T86-H;65N=#\B"FUS9W-T<B`B4VEC=7)O(&1I('9O;&5R(&-A;F-E
M;&QA<F4@4$5234%.14Y414U%3E1%('%U97-T;R!A;&QE9V%T;S\B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/R(*;7-G<W1R
M(")396D@<VEC=7)O(&1I('9O;&5R('-V=6]T87)E(&EL('%U97-T82!C87)T
M96QL83\B"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@9F]L9&5R
M/R(*;7-G<W1R(")396D@<VEC=7)O(&1I('9O;&5R('-V=6]T87)E(&EL($-E
M<W1I;F\_(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S
M='(@(E-E:2!S:6-U<F\@9&D@=F]L97(@<W9U;W1A<F4@:6P@0V5S=&EN;S\B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H
M97-E(&UE<W-A9V5S/R(*;7-G<W1R(")3:6-U<F\@9&D@=F]L97(@8V%N8V5L
M;&%R92!015)-04Y%3E1%345.5$4@<75E<W1I(&UE<W-A9V=I/R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\B
M"FUS9W-T<B`B4V5I('-I8W5R;R!D:2!V;VQE<B!S96=N86QA<F4@<75E<W1O
M(&UE<W-A9V=I;R!C;VUE(&-O<G)E='1O/R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C<T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*;7-G<W1R(")396D@<VEC
M=7)O(&1I('9O;&5R('-E9VYA;&%R92!Q=65S=&\@;65S<V%G9VEO(&-O;64@
M<W!A;3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$V"FUS9VED(")!
M<G)I=F%L(%1I;64B"FUS9W-T<B`B3W)A<FEO(&1I(&%R<FEV;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S$*;7-G:60@(D%S8V5N9&EN9R(*;7-G
M<W1R(")#<F5S8V5N=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<Q
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#,*;7-G:60@(D%S:R(*;7-G<W1R
M(")#:&EE9&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,3D*;7-G:60@(D%T=&%C:"(*;7-G<W1R(")!;&QE9V$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S4*(RP@9G5Z>GD*;7-G:60@(D%T
M=&%C:"!&:6QE<R(*;7-G<W1R(")&:6QE($%L;&5G871O.B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U-@IM<V=I9"`B071T86-H(&$@
M8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\B
M"FUS9W-T<B`B26YC;'5D:2!C;W!I82!D96QL82!T=6$@8VAI879E('!U8F)L
M:6-A(%!'4"!A;"!M97-S86=G:6\_(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N
M968N<&AP.C$P.0IM<V=I9"`B071T86-H960@1FEL93HB"FUS9W-T<B`B1FEL
M92!!;&QE9V%T;SHB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#4Q(&QI8B]#;VUP
M;W-E+G!H<#HU,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB071T86-H960@
M9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET
M<RX@1FEL92!.3U0@871T86-H960N(@IM<V=S='(@(B(*(DQA(&1I;6%N9&EO
M;F4@9&5L(&9I;&4@86QL96=A=&\@7"(E<UPB(.@@<W5P97)I;W)E(&$@<75E
M;&QA(&-O;G-E;G1I=&$N($9I;&4@(@HB;F]N(&%L;&5G871O+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S8*;7-G:60@(D%T=&%C:&5D(&ES
M(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+B(*;7-G
M<W1R(")!;&QE9V%T;R!U;B!F:6QE(&E#86QE;F1A<B!I;B!R:7-P;W-T82!A
M;&QA('9O<W1R82!R:6-H:65S=&$N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI
M;F,Z,30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`V('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDW"FUS9VED(")!='1A
M8VAM96YT(@IM<V=S='(@(D%L;&5G871O(@H*(SH@8V]M<&]S92YP:'`Z,3`V
M-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")!='1A8VAM96YT('-T<FEP
M<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T<B`B06QL96=A
M=&\@<W1R:7!P871O.B!4:7!O(&]R:6=I;F%L92!D96QL)V%L;&5G871O(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W,PHC.B!L:6(O0V]M<&]S92YP:'`Z
M,3`W,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`B06QL96=A=&DB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@R"FUS9VED(")!='1E;F1E
M97,B"FUS9W-T<B`B4&%R=&5C:7!A;G1I(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-3,*;7-G:60@(D%T=&5N=&EO;B(*;7-G<W1R
M(")!='1E;GII;VYE(@H*(SH@;&EB+T%U=&@O:6UP+G!H<#HT-`IM<V=I9"`B
M075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]I;7`Z($5S=&5N<VEO;F4@24U!4"!2:6-H:65S=&$@
M;F]N('1R;W9A=&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T,`IM
M<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE
M<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2`B"B)A9&1R97-S8F]O
M:S\B"FUS9W-T<B`B(@HB36]S=')A(&EN(&%U=&]M871I8V\@;&4@:6UM86=I
M;FD@;F5I(&UE<W-A9V=I($A434P@<75A;F1O(&EL(&UI='1E;G1E(&4G("(*
M(FYE;&QA(&UI82!R=6)R:6-A/R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R
M8V5S96QE8W0N:6YC.C(Y.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O
M:W,Z(@IM<V=S='(@(E)U8G)I8VAE(&1I<W!O;FEB:6QI.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET:6YG(%)E<W!O
M;G-E(@IM<V=S='(@(DEN(&%T=&5S82!D:2!2:7-P;W-T82(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`B5&]R;F$@82`E<R(*
M"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E
M<R(*;7-G<W1R(")4;W)N82!A("5S(@H*(SH@=&AR96%D+G!H<#HQ,S0*;7-G
M:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN9&5X(@IM<V=S
M='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,R"FUS9VED(")"86-K('1O(%1H<F5A
M9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M,S@W"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M960@<F5Q
M=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;65S
M<V%G92YP:'`Z,C8V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@;&EB
M+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G<W1R(")#8VXB"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES
M('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A
M9V4N(@IM<V=S='(@(E%U:2!S;W1T;R#H(&EL('1E<W1O(&-O;7!L971O(&1E
M;&QO(&UE<W-A9V=I;R!I;F9O<FUA=&EV;RXB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,38*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R("),:7-T
M82!N97)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8R.0IM<V=I9"`B
M0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@87)E
M('-P96-I9FEC86QL>2!R97%U97-T960_(@IM<V=S='(@(B(*(D)L;V-C82!I
M;6UA9VEN:2!N96D@;65S<V%G9VD@2%1-3"!F:6YO(&$@8VAE(&YO;B!S<&5C
M:69I8V%T86UE;G1E(')I8VAI97-T;R(*"B,Z(&QI8B]396%R8V@N<&AP.C0R
M"FUS9VED(")";V1Y(@IM<V=S='(@(D-O<G!O(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")%;G1R86UB
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#<*;7-G:60@(D)O=&@@
M2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R(")3
M:6$@;&ES=&$@9&5L;&4@:6YT97-T87II;VYI(&-H92!D96P@8V]R<&\@9&5L
M($UE<W-A9V=I;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(W,@IM<V=I9"`B0U]H87)S970B"FUS9W-T<B`B0U]O9&EC92!C87)A='1E
M<FDB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R:6\B"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C(P,0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H
M92!R96UO=&4@;6%I;"!S97)V97(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-O
M;FYE='1E<G-I(&%L('-E<G9E<B!D:2!P;W-T82!R96UO=&\N(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ.3D*;7-G:60@(D-A;B!N;W0@8V]N;F5C
M="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B`B"FUS9W-T<B`B26UP;W-S
M:6)I;&4@8V]N;F5T=&5R<VD@86P@<V5R=F5R(&1I('!O<W1A(')E;6]T;SH@
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@
M)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT
M("(*(FUA:6QB;W@N(@IM<V=S='(@(B(*(DEM<&]S<VEB:6QE(%9I<W5A;&EZ
M>F%R92`M('1R;W9A=&\@<V]L;R`E<R!D:2`E<R!P87)T:2!D:2!Q=65S=&\@
M;65S<V%G9VEO("(*(FYE;&QA($-A<V5L;&$@8V]R<F5N=&4B"@HC.B!F;VQD
M97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T
M97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M
M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N8V5L(@IM<V=S
M='(@(D%N;G5L;&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHW,2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S4*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,0IM<V=I9"`B0V%N8V5L
M($UE<W-A9V4B"FUS9W-T<B`B06YN=6QL82!-97-S86=G:6\B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FIS.C8*;7-G:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E
M('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S
M='(@(B(*(D%N;G5L;&%N9&\@<75E<W1O(&UE<W-A9V=I;R!S:2!P97)D97+@
M(&EL('-U;R!C;VYT96YU=&\@9&5F:6YI=&EV86UE;G1E+B(*"B,Z(&UE<W-A
M9V4N<&AP.C(V-2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R
M,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI8B]3
M96%R8V@N<&AP.C,P"FUS9VED(")#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G:60@(B(*(D-E<G1I9FEC871E
M(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@
M96YA8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<P,0IM<V=I9"`B0VAA:7(@4&5R<V]N
M(@IM<V=S='(@(DUO9&5R871O<F4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R(")-;V1I9FEC
M82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I
M9"`B0VAA;F=E($%L;"(*;7-G<W1R(")#86UB:6$@5'5T=&DB"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z.3(*;7-G:60@(D-H86YG92!&;VQD97(B"FUS
M9W-T<B`B0V%M8FEA($-A<G1E;&QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H
M(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N
M9"`B"B)H;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`B(@HB36]D
M:69I8V$@;&4@:6UP;W-T87II;VYI(&1I('9I<W5A;&EZ>F%Z:6]N92!E9"!O
M<F1I;F%M96YT;R!D96D@;65S<V%G9VDN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(T"FUS9VED(")#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E
M<B!S971T:6YG<RXB"FUS9W-T<B`B36]D:69I8V$@;&4@:6UP;W-T87II;VYI
M(&1E;"!S97)V97(@;6%I;"!E(&-A<G1E;&QE+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A9&1R
M97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B(@HB
M36]D:69I8V$@;F]M92P@:6YD:7)I>GIO+"!E(&9I<FUA(&-H92!V97)R86YN
M;R!V:7-U86QI>GIA=&D@9&%L;&4@<&5R<V]N92`B"B)C:&4@;&5G9V]N;R!E
M(')I<W!O;F1O;F\@86D@='5O:2!M97-S86=G:2XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#(T"FUS9VED(")#:&%R86-T97)S('1O(&1I<W!L87DZ
M(@IM<V=S='(@(D-A<F%T=&5R:2!D82!M;W-T<F%R93HB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-0IM<V=I9"`B0VAE8VL@1F]L9&5R
M*',I(&9O<B!.97<@36%I;"(*;7-G<W1R(")#;VYT<F]L;&$@<V4@Z"!A<G)I
M=F%T82!.=6]V82!0;W-T82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(E-E;&5Z:6]N
M82!4=71T:2].97-S=6YO(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C
M:&UA:6PN:6YC.C$P('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN
M8SHR,0IM<V=I9"`B0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T
M;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S='(@(B(*(D-O;G1R;VQL82!T=71T
M:2!I('-E<G9E<B!D:2!P;W-T82!D86D@<75A;&D@=G5O:2!S8V%R:6-A<F4@
M:2!N=6]V:2!M97-S86=G:3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#8S"FUS9VED(")#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE
M<W-A9V4_(@IM<V=S='(@(D-O;G1R;VQL;R!O<G1O9W)A9FEC;R!P<FEM82!D
M:2!M86YD87)E('5N(&UE<W-A9V=I;S\B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHT"FUS9VED(")#:&]O<V4@06-T:6]N.B(*;7-G<W1R
M(")38V5G;&D@07II;VYE.B(*"B,Z(&-O;F9I9R]S97)V97)S+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z(@IM<V=S='(@(E-C
M96=L:2!U;B!S97)V97(@9&D@<&]S=&$Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,3<*
M(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D
M9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R(")396QE>FEO;F$@;R!S8W)I
M=FD@;F5L;&$@8V%S96QL82!A(&1E<W1R83HB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*
M;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(E-E;&5Z:6]N82!U
M;B!A>FEO;F4Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,S0Y"FUS9VED(")#:&]O<V4@=&AE(&%D9')E<W,@8F]O:R!T;R!U<V4@
M=VAE;B!A9&1I;F<@861D<F5S<V5S+B(*;7-G<W1R(")38V5G;&D@;&$@<G5B
M<FEC82!D82!U=&EL:7IZ87)E('%U86YD;R!A9V=I=6YG:2!I;F1I<FEZ>FDN
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"FUS
M9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A
M<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB4V-E
M9VQI(&PG;W)D:6YE(&EN(&-U:2!R:6-E<F-A<F4@;&4@<G5B<FEC:&4@<75A
M;F1O(&5S<&%N9&D@9VQI(&EN9&ER:7IZ:2(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E
M<R!T;R!C;VYV97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U
M<B!B<F]W<V5R(&-A;B!V:65W+B(*;7-G<W1R("(B"B)#;&EC8V$@)7,@<&5R
M(&-O;G9E<G1I<F4@;"=I;6UA9VEN92!I;B!U;B!F;W)M871O(&-O;7!A=&EB
M:6QE(&-O;B!I;"!T=6\@(@HB8G)O=W-E<B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S
M('1O(&1O=VYL;V%D('1H92!I;6%G92XB"FUS9W-T<B`B0VQI8V-A("5S('!E
M<B!S8V%R:6-A<F4@;"=I;6UA9VEN92XB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ
M,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&=O
M('1O("5S(&UA;F%G96UE;G0@<&%G92XB"FUS9W-T<B`B0VQI8V-A("5S('!E
M<B!S8V%R:6-A<F4@;"=I;6UA9VEN92XB"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3$V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G
M<W1R(")#;&EC8V$@)7,@<&5R('9E9&5R92!C;VYT96YU=&\@2%1-3"!I;B!U
M;F$@9FEN97-T<F$@<V5P87)A=&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B:4-L
M:6-C82`E<R!P97(@=F5D97)E(&EL('1H=6UB;F%I;"!D:2!Q=65S=&$@:6UM
M86=I;F4B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@
M871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B0VQI
M8V-A("5S('!E<B!V961E<F4@8V]N=&5N=71O($A434P@:6X@=6YA(&9I;F5S
M=')A('-E<&%R871A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H
M<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@
M=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S97!A<F%T
M92!W:6YD;W<N(@IM<V=S='(@(D-L:6-C82`E<R!P97(@=F5D97)E(&-O;G1E
M;G5T;R!(5$U,(&EN('5N82!F:6YE<W1R82!S97!A<F%T82XB"@HC.B!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@=&\@
M4TA/5R!T:&4@26UA9V5S(@IM<V=S='(@(D-L:6-C82!Q=6D@<&5R($U/4U12
M05)%(&QE(&EM;6%G:6YI(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S(Q"FUS9VED("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S
M96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE
M;&1S('1O("(*(G-E87)C:"XB"FUS9W-T<B`B4V-E9VQI('5N82!D96QL92!T
M=64@<G5B<FEC:&4L(&4@<V5L97II;VYA('1U='1I(&D@8V%M<&D@9&$@<FEC
M97)C87)E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,0IM<V=I
M9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E
M<W,@8F]O:R(*;7-G<W1R(")#;&EC8V$@<&5R('-A;'9A<F4@;&$@8VAI879E
M(%!'4"!N96QL82!T=6$@4G5B<FEC82XB"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C(P,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B0VQI8V-A('!E<B!S86QV87)E(&-E<G1I
M9FEC871O(%,O34E-12!N96QL82!T=6$@<G5B<FEC82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-3`*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R
M97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B
M"FUS9W-T<B`B(@HB0VQI8V-A;F1O('-U;&PG:6YD:7)I>GIO('-I(&-O;7!O
M<G)A('5N(&YU;W9O(&UE<W-A9V=I;R!P97(@:6P@;6ET=&5N=&4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#;&EC:VEN9R!O;B!T
M:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9"(*
M;7-G<W1R(")#;&EC8V%N9&\@<W5L;"=I;F1I<FEZ>F\@<VD@87!R:7+@(&EL
M(&UE<W-A9V=I;R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL
M+FEN8SHR.`IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B0VAI=61I(@H*(SH@8V]M
M<&]S92YP:'`Z.#(X(&-O;7!O<V4N<&AP.C$Q-#@*;7-G:60@(D-L;W-E('1H
M:7,@=VEN9&]W(@IM<V=S='(@(D-H:75D:2!Q=65S=&$@9FEN97-T<F$B"@HC
M.B!F;VQD97)S+G!H<#HT,CD*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS9W-T
M<B`B0V%R=&5L;&$@0VAI=7-A(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS9VED
M(")#;VQL87!S92(*;7-G<W1R(")2:61U8VDB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL(@IM<V=S
M='(@(E)I8VAI=61I('1U='1E(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S
M='(@(E)I8VAI=61I('1U='1E(&QE(&-A<G1E;&QE(@H*(SH@9F]L9&5R<RYP
M:'`Z-#0Y"FUS9VED(")#;VQL87!S92!&;VQD97(B"FUS9W-T<B`B4FEC:&EU
M9&D@8V%R=&5L;&$B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC871O<CH@(@IM<V=S='(@(DEN9&EC
M871O<F4@9&5L($-O;&]R93HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,3`S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;6UE;G1O(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<V.0IM<V=I9"`B0V]M<&QE=&5D(@IM
M<V=S='(@(D-O;7!L971A=&\B"@HC.B!C;VUP;W-E+G!H<#HX,C<@8V]M<&]S
M92YP:'`Z,3$T-PIM<V=I9"`B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B"FUS
M9W-T<B`B0V]M<&]N:2!U;B!A;'1R;R!M97-S86=G:6\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN
M(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")5=&EL:7IZ82!U;F$@;G5O
M=F$@9FEN97-T<F$@<&5R(&-O;7!O<G)E('5N(&UE<W-A9V=I;RXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0S"FUS9VED("(B"B)#;VUP;W-E(&UE
M<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@9&5F875L="`H:68@8G)O=W-E
M<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_(@IM<V=S='(@(B(*(D-O;7!O
M;FD@;65S<V%G9VD@8V]N(&EN=&5R9F%C8VEA($A434P@9&D@9&5F875L="`H
M<V4@:6P@='5O(&)R;W=S97(@<W5P<&]R=&$@(@HB<75E<W1A(&9U;GII;VYE
M*3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<*;7-G:60@(D-O;F9I
M9W5R92!H;W<@;65S<V%G97,@87)E(&1I<W!L87EE9"XB"FUS9W-T<B`B0V]N
M9FEG=7)A(&-O;64@=FES=6%L:7IZ87)E(&D@;65S<V%G9VDN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")#;VYF:6=U<F4@;6%I;"!P
M<F5V:65W(&]P=&EO;G,N(@IM<V=S='(@(D-O;F9I9W5R82!O<'II;VYI(&%N
M=&5P<FEM82!P;W-T82XB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`HC
M+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R
M=F5R+B(*;7-G<W1R(")#;VYN97-S:6]N92!A;"!S97)V97(@9F%L;&ET82(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C,T"FUS9VED(")#;VYN96-T
M:6]N('1O('-E<G9E<B!F86EL960B"FUS9W-T<B`B0V]N;F5S<VEO;F4@86P@
M<V5R=F5R(&9A;&QI=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4$=0('-U<'!O<G0@9F]R
M("5S+B(*;7-G<W1R(")697)I9FEC82!S=7!P;W)T;R!01U`@<&5R("5S+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@
M(D-O;G1R;VQL82!S=7!P;W)T;R!3+TU)344@<&5R("5S+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R
M96QA=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W
M:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R
M(&]R(&YO="!T;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS
M9W-T<B`B1V5S=&ES8VD@:6P@8V]N=')O;&QO(&4@;&$@;F]T:69I8V$@9&5L
M;&$@4&]S=&$@:6X@07)R:79O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.38*;7-G:60@(D-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G
M<F%P:&EC86P@;VYE<S\B"FUS9W-T<B`B0V]N=F5R=&D@16UO=&EC;VX@=&5S
M='5A;&D@:6X@9W)A9FEC:&4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z-3$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:6$B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM
M<V=S='(@(D-O<&EA(&%L;&$@8V%R=&5L;&$B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z-C,*;7-G:60@(D-O<G)E8W0B"FUS9W-T<B`B
M0V]R<F5T=&\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,30P"FUS9VED(")#;W)R96-T960@5&5X="(*;7-G<W1R(")497-T;R!#;W)R
M971T;R(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S="X@
M4F5A<V]N($=I=F5N.B`E<R(*;7-G<W1R(").;VX@<&]S<V\@8W)E87)E(&EL
M(&)A8VME;F0@5D93.B`E<R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K
M96YD.B`E<R(*;7-G<W1R(").;VX@<&]S<V\@8W)E87)E(&EL(&)A8VME;F0@
M5D93.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S86=E<R!F<F]M("5S+B!4
M:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(B(*(DEM<&]S<VEB:6QE(&-A
M;F-E;&QA<F4@;65S<V%G9VD@9&$@)7,N(%%U97-T;R#H(&EL(&UE<W-A9V=I
M;R!D96P@<V5R=F5R.B`E<R(*"B,Z(&QI8B]397-S:6]N+G!H<#HS,3@*;7-G
M:60@(D-O=6QD(&YO="!E>&5C=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5S96=U:7)E(&QE(&]P97)A>FEO;FD@
M9&D@;6%N=71E;GII;VYE+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H
M<#HU-`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F
M:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B26UP
M;W-S:6)I;&4@97-T<F%R<F4@:6P@9FEL92!R:6-H:65S=&\@9&%L;"=A;&QE
M9V%T;R!-4RU43D5&+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X
M"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@
M9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5S
M=')A<G)E(&EL(&9I;&4@<FEC:&EE<W1O(&1A;&PG87)C:&EV:6\@6FEP+B(*
M"B,Z(&QI8B]397-S:6]N+G!H<#HR-S,*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!N86UE<W!A8V4@:6YF;W)M871I;VX@9G)O;2!)34%0('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS,30@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L+FEN8SHS.0HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38P"FUS9VED(")#<F5A=&4B"FUS
M9W-T<B`B0W)E82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C8*;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T<B`B0W)E82!#87)T96QL
M82(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*;7-G:60@(D-R96%T
M92!+97ES(@IM<V=S='(@(D-R96$@0VAI879I(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@5FER
M='5A;"!&;VQD97(B"FUS9W-T<B`B0V%R=&5L;&$@5FER='5A;&4B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E(&$@3F5W($%C8V]U;G0B"FUS9W-T<B`B06QT
M<FD@06-C;W5N="!D:2!0;W-T82(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M
M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z
M,C0*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*
M;7-G<W1R(")#<F5A('5N82!N=6]V82!C87)T96QL82!#97-T:6YO(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S
M+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE
M=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(D-R96$@=6YA(&YU;W9A(&-A<G1E
M;&QA($)O>GIE(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T
M+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0R
M"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R
M(")#<F5A('5N82!N=6]V82!C87)T96QL82!D:2!0;W-T82!);G9I871A(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHQ,B!T96UP;&%T
M97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N
M97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(D-R96$@=6YA(&YU;W9A(&-A<G1E
M;&QA($-E<W1I;F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X"FUS
M9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO
M=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*(F%N
M9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`B(@HB0W)E82!I(&9I;'1R:2!P97(@
M;W)G86YI>GIA<F4@;&$@<&]S=&$@:6X@96YT<F%T82P@9&ES=')I8G5I<FQA
M(&EN(&-A<G1E;&QE+"`B"B)E9"!E;&EM:6YA<F4@;&\@<W!A;6UI;F<N(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"B,L(&9U>GIY
M"FUS9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`B0W)E82!U
M;F$@;G5O=F$@8V%R=&5L;&$@9&D@4&]S=&$@26YV:6%T82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-#D*;7-G:60@(D-R96%T92!S=&%T:6]N97)Y
M(&%N9"!F;W)M(')E<W!O;G-E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-U<G)E;G0@
M86-C97-S('1O("5S(@IM<V=S='(@(D%C8V5S<V\@8V]R<F5N=&4@82`E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4*;7-G:60@(D-U<W1O;6EZ
M92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U
M;G1S+B(*;7-G<W1R(")097)S;VYA;&EZ>F$@86-C;W5N="!P97(@<V-A<FEC
M87)E('!O<W1A(&1A(&%L=')I(&%C8V]U;G0N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4Q"FUS9VED(")#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA
M:6PN(@IM<V=S='(@(E!E<G-O;F%L:7IZ82!C;VUE(&EN=FEI(&QA('!O<W1A
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N(@IM<V=S='(@(DEM<&]S=&$@;&4@;W!E<F%Z:6]N:2!D82!E<V5G=6ER
M92!Q=6%N9&\@96YT<FD@:6X@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHQ-PIM<V=I9"`B1&%T7V4B"FUS9W-T<B`B
M1&%T7V$B"@HC.B!M97-S86=E+G!H<#HR-C(@=&AR96%D+G!H<#HQ-#@*;7-G
M:60@(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW-3<*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(E)I9FEU=&%T
M;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C,*(RP@9G5Z>GD*
M;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B4FEF:75T871O(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L
M="(*;7-G<W1R(")%;&EM:6YA(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U
M;'1S96%R8VAS96QE8W0N:6YC.C$X"FUS9VED(")$969A=6QT(%-E87)C:"!&
M:65L9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(S
M"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(D-R
M:71E<FD@9&D@;W)D:6YA;65N=&\@9&D@9&5F875L=#HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3,S"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER
M96-T:6]N.B(*;7-G<W1R(")$:7)E>FEO;F4@9&D@;W)D:6YA;65N=&\@9&D@
M9&5F875L=#HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U"FUS
M9VED(")$96QE9V%T960B"FUS9W-T<B`B1&5L96=A=&\B"@HC.B!F;VQD97)S
M+G!H<#HT,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B16QI;6EN
M82(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(D5L:6UI;F$@)7,@0VAI879E(%!U8F)L
M:6-A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME>7,B
M"FUS9W-T<B`B16QI;6EN82!#:&EA=FD@071T=6%L:2(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G:60@(D1E;&5T92!&;VQD97(H
M<RDB"FUS9W-T<B`B16QI;6EN82!#87)T96QL82AE*2(*"B,Z(&9O;&1E<G,N
M<&AP.C(X-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E
M<G,B"FUS9W-T<B`B16QI;6EN82!#87)T96QL82AE*2(*"B,Z('1E;7!L871E
M<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B1&5L
M971E(%-T871I;VYE<GDB"FUS9W-T<B`B16QI;6EN82!#87)T96QL82AE*2(*
M"B,Z(&9O;&1E<G,N<&AP.C0Q.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%9I
M<G1U86P@1F]L9&5R(@IM<V=S='(@(D-A<G1E;&QA(%9I<G1U86QE(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE
M=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S
M='(@(D5L:6UI;F$@;65S<V%G9VD@<V-A<FEC871I(&1A;"!S97)V97(@<F5M
M;W1O/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(E)I
M;75O=FD@9&%L(&UI;R!C86QE;F1A<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V.`IM<V=I9"`B1&5L971E(&]L9"!L:6YK960@871T86-H;65N
M=',@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")%;&EM:6YA(&QE
M('9E8V-H:64@8V%R=&5L;&4@9&D@4&]S=&$@26YV:6%T82!A9"!I;FEZ:6\@
M;65S92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4P"FUS9VED(")$
M96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M
M;VYT:#\B"FUS9W-T<B`B16QI;6EN82!L92!V96-C:&EE(&-A<G1E;&QE(&1I
M(%!O<W1A($EN=FEA=&$@860@:6YI>FEO(&UE<V4N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-P86T@
M;65S<V%G97,B"FUS9W-T<B`B365S<V%G9VD@96QI;6EN871I(@H*(SH@;65S
M<V%G92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<T,"!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C(P"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHX"FUS9VED(")$
M96QE=&5D(@IM<V=S='(@(D5L:6UI;F%T;R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS9W-T
M<B`B365S<V%G9VD@96QI;6EN871I(@H*(SH@8V]M<&]S92YP:'`Z,S`W"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@=&AE(&%T=&%C:&UE;G0@7"(E
M<UPB+B(*;7-G<W1R(")!;&QE9V%T;R!<(B5S7"(@96QI;6EN871O+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B1&5L971I;F<@86YD
M($UO=FEN9R!-97-S86=E<R(*;7-G<W1R(")'97-T:6]N92!E(&-A;F-E;&QA
M>FEO;F4@9&5I($UE<W-A9V=I(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(DYE9V$@<FEC
M:&EE<W1A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T,`IM<V=I
M9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VXB"FUS
M9W-T<B`B3F5G82!R:6-H:65S=&$@<&5R(&EN9F]R;6%Z:6]N:2!L:6)E<F\O
M;V-C=7!A=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,R"FUS9VED
M(")$97-C96YD:6YG(@IM<V=S='(@(D1E8W)E<V-E;G1E(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(Q(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-CD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E
M<V-R:7II;VYE(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<W"FUS9VED(")$971A:6QS(@IM<V=S='(@(D1E='1A
M9VQI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W-PIM<V=I9"`B1&EM
M('-I9VYA='5R97,_(@IM<V=S='(@(D1I9F9E<F5N>FEA(&QA(&9I<FUA(&1A
M;"!T97-T;RXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")6:7-U86QI>GIA(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W.0IM<V=I9"`B1&ES<&QA>2!C;VYF
M:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(DUO
M<W1R82!C;VYF97)M82!D;W!O(&EN=FEO(&UE<W-A9V=I;S\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED(")$:7-P;&%Y(&EN($)O9'D@
M;V8@365S<V%G92(*;7-G<W1R(")-;W-T<F$@;F5L($-O<G!O(&1E;"!-97-S
M86=G:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"FUS9VED(")$
M:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_(@IM<V=S
M='(@(DYO=&EF:6-A(&-O;B!U;B!P;W`M=7`@<75A;F1O(&%R<FEV82!.=6]V
M82!0;W-T82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4X"B,L(&9U
M>GIY"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%-P86U<(B!L:6YK(&EN
M('1H92!M96YU8F%R/R(*;7-G<W1R(")-;W-T<F$@:6P@;&EN:R`G4W9U;W1A
M($-E<W1I;F\G(&YE;&QA(&)A<G)A(&UE;G4_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<U,`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!T:&4@7")%
M;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(DUO
M<W1R82!I;"!L:6YK("=3=G5O=&$@0V5S=&EN;R<@;F5L;&$@8F%R<F$@;65N
M=3\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,3$*
M;7-G:60@(D1I<W!O<VET:6]N(@IM<V=S='(@(D1I<W!O<VEZ:6]N92(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4
M(&UA=&-H(@IM<V=S='(@(DYO;B!C;W)R:7-P;VYD92(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$V"FUS9VED(")$;R!.;W0@0VAE8VL@
M1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G<W1R(").;VX@8V]N=')O;&QA
M<F4@;"=A<G)I=F\@9&D@3G5O=F$@4&]S=&$@;F5L;&$@8V%R=&5L;&$H92DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34R"FUS9VED(")$;R!N;W0@
M9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS9W-T<B`B
M3F]N(&=E;F5R87)E('5N(&QI;FL@;F5L;&$@8V]L;VYA($1A.B(*"B,Z(&QI
M8B])35`N<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA
M="!F;VQD97(_(@IM<V=S='(@(E9U;VD@87!R:7)E('%U96QL82!C87)T96QL
M83\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(S,@IM<V=I9"`B
M1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(V"FUS9VED(")$
M;VYE(@IM<V=S='(@(D9A='1O(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP
M.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R!I;B`N>FEP
M($9O<FUA="(*;7-G<W1R(")38V%R:6-A("5S(&EN(&9O<FUA='1O("YZ:7`B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU,@IM<V=I9"`B
M1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I(@IM<V=S
M='(@(E-C87)I8V$@5'5T=&D@9VQI($%L;&5G871I("AI;B!U;B!F:6QE("YZ
M:7`I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C`*;7-G
M:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R(")38V%R:6-A($-A<G1E
M;&QA*&4I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*
M;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=(@IM<V=S
M='(@(E-C87)I8V$@0V%R=&5L;&$H92D@6V9O<FUA='1O("YZ:7!=(@H*(SH@
M;&EB+TU)344O0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@
M+GII<"!&;W)M870B"FUS9W-T<B`B4V-A<FEC82!I;B!F;W)M871T;R`N>FEP
M(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*
M;7-G:60@(D1R869T(@IM<V=S='(@(D)O>GIA(@H*(SH@9F]L9&5R<RYP:'`Z
M,SDR"FUS9VED(")$<F%F="!F;VQD97(B"FUS9W-T<B`B0V%R=&5L;&$@8F]Z
M>F4B"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM
M<V=I9"`B1')A9G1S(&9O;&1E<CHB"FUS9W-T<B`B0V%R=&5L;&$@8F]Z>F4Z
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I9"`B12UM86EL
M($%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO($4M;6%I;"(*"B,Z(&QI8B]-
M86EL8F]X+G!H<#HS,#D*(RP@9G5Z>GD*;7-G:60@(D5.1"(*;7-G<W1R(")%
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@(D52
M4D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS
M9W-T<B`B15)23U)%.B!);7!O<W-I8FEL92!C;VYS96=N87)E(&EL(&UE<W-A
M9V=I;RXB"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!";&%C
M:VQI<W0B"FUS9W-T<B`B36]D:69I8V$@;&$@3&ES=&$@3F5R82(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM<V=I9"`B161I="!&:6QT
M97)S(@IM<V=S='(@(DUO9&EF:6-A($9I;'1R:2(*"B,Z(&9O;&1E<G,N<&AP
M.C0R,"!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,38*(RP@9G5Z>GD*
M;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B0V%R=&5L;&$@
M5FER='5A;&4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F
M:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R
M(")-;V1I9FEC82!L82!,:7-T82!":6%N8V$B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B
M"FUS9W-T<B`B36]D:69I8V$@;&$@='5A(&QI<W1A(&YE<F$B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F
M:6QT97(@<G5L97,B"FUS9W-T<B`B36]D:69I8V$@;&4@='5E(')E9V]L92!D
M:2!F:6QT<F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8Q"FUS9VED
M(")%9&ET('EO=7(@<')E9F5R96YC97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M
M86EL(&%C8V]U;G1S+B(*;7-G<W1R(")-;V1I9FEC82!L92!T=64@<')E9F5R
M96YZ92!P97(@86-C961E<F4@860@86QT<FD@86-C;W5N="!D:2!P;W-T82XB
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D
M:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B36]D:69I8V$@;&$@='5A(&QI
M<W1A(&)I86YC82(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ
M;R!%;6%I;"(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T
M<B`B5'5T=&D@;65S<V%G9VD@96QI;6EN871I(&1A("5S(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D5M<'1Y($9O;&1E
M<BAS*2(*;7-G<W1R(")3=G5O=&$@0V%R=&5L;&$H92DB"@HC.B!F;VQD97)S
M+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O;&1E
M<G,B"FUS9W-T<B`B4W9U;W1A($-A<G1E;&QA*&4I(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y(%1R87-H(&9O
M;&1E<B(*;7-G<W1R(")3=G5O=&$@;&$@8V%R=&5L;&$@0V5S=&EN;R(*"B,Z
M(&QI8B])35`N<&AP.CDW,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@7U-P86TB
M"FUS9W-T<B`B4W9U;W1A(%]#97-T:6YO(@H*(SH@;&EB+TE-4"YP:'`Z.38V
M"FUS9VED(")%;7!T>2!?5')A<V@B"FUS9W-T<B`B4W9U;W1A(%]#97-T:6YO
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$@=&5M<&QA=&5S+W!G<"]N
M;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET
M>3\B"FUS9W-T<B`B06)I;&ET82!&=6YZ:6]N86QI=.`@4$=0/R(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,2!T96UP;&%T97,O<VUI;64O;F]T
M86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI
M='D_(@IM<V=S='(@(D%B:6QI=&$@9G5N>FEO;F%L:73@(%,O34E-13\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS9VED(")%;F%B;&4@;65S
M<V%G92!P<F5V:65W<S\B"FUS9W-T<B`B071T:79A($%N=&5P<FEM82!-97-S
M86=G:3\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-#(*
M;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B3W!Z:6]N:2!#
M<FEP7W1A9V=I;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3<@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U-PIM<V=I9"`B16YD(@IM<V=S
M='(@(D9I;F4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S@T"FUS9VED(")%;F0@
M9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B1FEN92!M97-S86=G:6\@:6YO
M;'1R871O+B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-#$*;7-G:60@(D5N9"!M
M97-S86=E(@IM<V=S='(@(D9);F4@365S<V%G9VEO(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G92!F
M<F]M("5S(@IM<V=S='(@(D9I;F4@;65S<V%G9VEO(&1A("5S(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B26YS97)I
M<V-I(%!A<F]L82!#:&EA=F4B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E
M;&5C="YI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R
M('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(DES97)I<V-I(&EL(&YO
M;64@9&5L;&$@=6YA(&YU;W9A(&-A<G1E;&QA($-E<W1I;F\B"@HC.B!T96UP
M;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T
M:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R("))
M;G-E<FES8VD@:6P@;F]M92!D96QL82!N=6]V82!C87)T96QL82!";WIZ92(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G
M:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L
M9&5R(@IM<V=S='(@(DEN<V5R:7-C:2!I;"!N;VUE(&1E;&QA(&YU;W9A(&-A
M<G1E;&QA(&1I(%!O<W1A($EN=FEA=&$B"@HC.B!T96UP;&%T97,O<')E9G,O
M=')A<VAS96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y
M;W5R(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B27-E<FES8VD@:6P@;F]M
M92!D96QL82!U;F$@;G5O=F$@8V%R=&5L;&$@0V5S=&EN;R(*"B,Z(&QI8B]3
M96%R8V@N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")%;G1I<F4@365S<V%G92(*
M;7-G<W1R(")#;VYS96=N82!I;"!-97-S86=G:6\@860@=6X@86QT<F\@:6YD
M:7)I>GIO+B(*"B,Z(&UE<W-A9V4N<&AP.C$Y-"!C;VUP;W-E+G!H<#HQ,3,T
M('1H<F5A9"YP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E
M<UPB('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O
M:R(*;7-G<W1R("))(&1A=&D@7"(E<UPB('-O;F\@<W1A=&D@86=G:75N=&D@
M86QL82!2=6)R:6-A(&-O;B!S=6-C97-S;R(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C,X-@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(D5R<F]R92(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S
M97)V97(N("5S(#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HS,#D@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB
M"FUS9W-T<B`B17)R;W)E(&YE;&PG:6YV:6\@9&5L;&$@<FES<&]S=&$Z("5S
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#$*(RP@9G5Z>GD*
M;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")%
M=F5N=&\@<FEM;W-S;R!C;VX@<W5C8V5S<V\N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R
M(")/9VYI(#$U(&UI;G5T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B3V=N:2`S,"!S
M96-O;F1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I9"`B
M179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D]G;FD@-2!M:6YU=&DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@S"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B3V=N:2!M97IZ)V]R82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")/9VYI
M(&UI;G5T;R(*"B,Z(&9O;&1E<G,N<&AP.C0U-PIM<V=I9"`B17AP86YD(@IM
M<V=S='(@(D5S<&%N9&DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R(")%<W!A;F1I(%1U
M='1E(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G
M:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R(")%<W!A;F1I(%1U='1E
M(&QE($-A<G1E;&QE(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED(")%>'!A
M;F0@1F]L9&5R(@IM<V=S='(@(D5S<&%N9&D@0V%R=&5L;&$B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#`@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5D:7)E8W0N:6YC.C4S"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T
M<B`B17-P86YD:2!.;VUI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-C,*;7-G:60@(D5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@
M875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\B"FUS9W-T<B`B17-P
M86YD:2!I(&YO;6D@;F5L;&$@9FEN97-T<F$@9&D@8V]M<&]S:7II;VYE(&%U
M=&]M871I8V%M96YT93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@P
M"FUS9VED(")%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D969A
M=6QT(&EN('1H92!F;VQD97)S('9I97<_(@IM<V=S='(@(D5S<&%N9&D@='5T
M=&4@;&4@8V%R=&5L;&4@;F5L;&$@=FES=6%L:7IZ87II;VYE('!R961E9FEN
M:71A+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$T-"!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ.30*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C0U('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHQ,#$*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9&EN9R(*;7-G
M<W1R(")!<&5R='5R82XN+B(*"B,Z(&QI8B])35`N<&AP.CDX-"!L:6(O24U0
M+G!H<#HY.#8*(RP@9G5Z>GD*;7-G:60@(D9?971C:"!-86EL(@IM<V=S='(@
M(E-C87)I8V$@4&]S=&$B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B
M1F5T8V@@36%I;"(*;7-G<W1R(")38V%R:6-A(%!O<W1A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@V.0IM<V=I9"`B1F5T8V@@36%I;"!I;B!A('-E
M<&%R871E('=I;F1O=S\B"FUS9W-T<B`B4V-A<FEC82!M97-S86=G:2!I;B!U
M;F$@9FEN97-T<F$@<V5P87)A=&$_+B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L
M;V=G:6YG(&]N/R(*;7-G<W1R(")38V%R:6-A($UE<W-A9V=I(&%D(&]G;FD@
M86-C97-S;S\B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@9G)O;2`E
M<R(*;7-G<W1R(")38V%R:6-A=&\@)60@;65S<V%G9VD@9&$@)7,B"@HC.B!L
M:6(O1F5T8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B4V-A<FEC
M871O("5D(&UE<W-A9V=I(&1A("5S(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z
M,C@U(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL+G!H<#HR
M.#D*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(E-C87)I8V%M96YT;R!0
M;W-T83HB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@9G5Z>GD*;7-G
M:60@(D9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")(86D@
M)7,@;G5O=FD@;65S<V%G9VDN(@H*(SH@;&EB+TE-4"YP:'`Z.3DP"FUS9VED
M(")&:5]L=&5R<R(*;7-G<W1R(")&:5]L=')I(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3`R('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FIS.C@R"FUS9VED(")&:6QE(@IM<V=S='(@(D9I;&4B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S$*;7-G:60@(D9I;'1E<B!/
M<'1I;VYS(@IM<V=S='(@(D]P>FEO;FD@1FEL=')I(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.CD*;7-G:60@(D9I;'1E<B!3971T:6YG<R(*
M;7-G<W1R("));7!O<W1A>FEO;FD@1FEL=')I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8P,`IM<V=I9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F
M;W(@<')O9F%N:71Y/R(*;7-G<W1R(")#;VYT<F]L;&$@<V4@;F5I(&UE<W-A
M9V=I(&-I('-O;F\@<&%R;VQE(&]F9F5N<VEV92XB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$Q"FUS9VED(")&:6QT97(@<W5P<&]R
M="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B4W5P<&]R
M=&\@9FEL=')I(.@@9&ES86)I;&ET871O('-U('%U97-T;R!S:7-T96UA+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(D9I;'1E<G,B
M"FUS9W-T<B`B1FEL=')I(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T
M:79E+FEN8SHS"FUS9VED(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B
M1FEL=')I($Y/3B!!='1I=FDB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3@V"FUS9VED(")&:6YD(@IM<V=S='(@(E1R;W9A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP-0IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E
M(@IM<V=S='(@(E!R:6UA(%!A9VEN82!D96QL82!-86EL8F]X(@H*(SH@;6%I
M;&)O>"YP:'`Z,S0U"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(E!R:6UA
M(%!A9VEN82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I
M9"`B1F]?<G=A<F0B"FUS9W-T<B`B26Y?;VQT<F$B"@HC.B!F;VQD97)S+G!H
M<#HR-C8@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ
M-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S`S('1E;7!L871E<R]F;VQD97)S+VAE
M860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T
M+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI
M;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T<B`B17-P;&]R
M82!L92!C87)T96QL92(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS
M9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R(")3;VUM87)I;R!#87)T96QL
M82(*"B,Z(&%C;"YP:'`Z,C0*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO
M="!E;F%B;&5D+B(*;7-G<W1R(")#;VYD:79I<VEO;F4@8V%R=&5L;&4@;F]N
M(&%B:6QI=&%T;RXB"@HC.B!F;VQD97)S+G!H<#HV,@IM<V=I9"`B1F]L9&5R
M('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B57-O(&1I(&-A<G1E;&QE
M(&YO;B#H(&%B:6QI=&%T;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.38Y"FUS9VED(")&;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I
M;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A>2(*;7-G<W1R(")&
M;W)M871O(&1E;&QA(&1A=&$@9&5L(&UE<W-A9V=I;R!N96QL82!M86EL8F]X
M('!E<B!I(&UE<W-A9V=I(&1I(&]G9VDB"@HC.B!C;VUP;W-E+G!H<#HW.#`@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")&;W)W87)D
M(@IM<V=S='(@(DEN;VQT<F$B"@HC.B!C;VUP;W-E+G!H<#HW-C4*;7-G:60@
M(D9O<G=A<F0Z(@IM<V=S='(@(DEN;VQT<F$Z(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C,V.0IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B365S
M<V%G9VEO($EN;VQT<F%T;R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<R(*
M;7-G<W1R(")-97-S86=G:6\@:6YO;'1R871O(&1A("5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0X,PIM<V=I9"`B1G)E92]"=7-Y($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%Z:6]N92!,:6)E<F\O3V-C=7!A=&\B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DT"FUS9VED(")&<F5E
M+T)U<WD@4F5P;'DB"FUS9W-T<B`B4FES<&]S=&$@3&EB97)O+T]C8W5P871O
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`IM<V=I9"`B1G)E
M92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B4FEC:&EE<W1A($QI8F5R;R]/8V-U
M<&%T;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*;7-G:60@
M(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(E)I<W!O<W1A
M(&$@<FEC:&EE<W1A($QI8F5R;R]/8V-U<&%T;R(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R;U]M(@IM
M<V=S='(@(D1?82(*"B,Z(&UE<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T
M.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A
M<F-H+G!H<#HR,@IM<V=I9"`B1G)O;2(*;7-G<W1R(")$82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G
M<W1R(")$82!);F1I<FEZ>F\B"@HC.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S
M92YP:'`Z-S@Q"FUS9VED(")&=V0Z(@IM<V=S='(@(DEN;VQT<F\Z(@H*(SH@
M8V]M<&]S92YP:'`Z,3(Y-`IM<V=I9"`B1G=D.B`B"FUS9W-T<B`B1G=D.B`B
M"@HC.B!C;VUP;W-E+G!H<#HQ,CDV"B,L('!H<"UF;W)M870*;7-G:60@(D9W
M9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(D9W9#H@)74@365S
M<V%G9VD@26YO;'1R871I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")'96YE
M<F%L($]P=&EO;G,B"FUS9W-T<B`B3W!Z:6]N:2!'96YE<F%L:2(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS-PIM<V=I9"`B1V5T(&]N
M;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*2(*;7-G<W1R(")/='1I96YI
M('-O;&\@;G5O=FD@;65S<V%G9VD_("AS;VQO($E-05`I(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@
M(B(*"B,Z('1H<F5A9"YP:'`Z,3,V"FUS9VED(")';R!T;R!-97-S86=E(@IM
M<V=S='(@(E9A:2!A;"!-97-S86=G:6\B"@HC.B!L:6(O24U0+G!H<#HT.3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O
M:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B06=G:75N9VD@86QL82!2=6)R
M:6-A("@E<RDB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3,U"FUS9VED
M(")'<F%N="!A8V-E<W,B"FUS9W-T<B`B07-S96=N82!!8V-E<W-O(@H*(SH@
M;65S<V%G92YP:'`Z-30V(&QI8B]&:6QT97(N<&AP.C$P-2!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HY-0HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ,#(@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,Z(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,R!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN
M<&AP.C8R(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,Z
M(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.2!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C0Q.`HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B
M;&4N<&AP.C0Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PHC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C`@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z,3(W"FUS9VED(")(15)%(@IM<V=S='(@(E%522(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,2!L:6(O34E-12]6:65W
M97(O:'1M;"YP:'`Z,3$W"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H
M<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@8V]M<&]S92YP
M:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R
M(")697)S:6]N92!(5$U,(&1E;"!-97-S86=G:6\B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M("));G1E<W1A>FEO;FDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O
M<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@
M8V]M<&]S:6YG.B(*;7-G<W1R(")-97-S86=G:6\@8VAE('-T879I(&-O;7!O
M;F5N9&\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V.`IM<V=I9"`B
M2&ED9&5N(@IM<V=S='(@(DYA<V-O<W1O(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V-PIM<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S
M='(@(DYA<V-O<W1O(&YE;&QA(%9I<W5A;&EZ>F%Z:6]N92!P97(@07)G;VUE
M;G1O(@H*(SH@;6%I;&)O>"YP:'`Z,S8W"FUS9VED(")(:61E($1E;&5T960B
M"FUS9W-T<B`B3F%S8V]N9&D@16QI;6EN871I(@H*(SH@9F]L9&5R<RYP:'`Z
M,CDX"FUS9VED(")(:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")#86YC96QL
M82!N;VX@<V]T=&]S8W)I='1I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S='(@(D%L=&$B"@HC.B!M
M97-S86=E+G!H<#HR.3<@;6%I;&)O>"YP:'`Z-S(T('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI9V@@4')I;W)I='DB"FUS9W-T
M<B`B4')I;W)I=.`@86QT82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(Y,PIM<V=I9"`B2&EG:&5S="(*;7-G<W1R(")!;'1I<W-I;6$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X"FUS9VED(")(;W<@9&\@
M>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T<B`B0V]M
M92!V=6]I(&UO<W1R87)E(&=L:2!A;&QE9V%T:3\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`T"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E
M9"!L:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(D-O;64@871T<FEB=6ER92!L
M92!L:6YE92!C:71A=&4@:6X@=6YA(')I<W!O<W1A(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T<B`B24U!4"(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(Y"FUS9VED("))34%0("A!
M=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(DE-05`@*%!R;W1O8V]L
M($%U=&]M871I8V\I(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B24U!4"!397)V97(@8VQO<V5D('1H92!C;VYN
M96-T:6]N+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-33"(*;7-G<W1R("))34%0
M('9I82!34TPB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I
M9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM
M<V=S='(@(DE-05`@=FEA(%-33"`H8V5R=&9I8V%T;R!A=71O+69I<FUA=&\I
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C<*;7-G:60@(DE-
M05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R("))34%0('9I82!3
M4TP@*&%U=&\M9FER;6%T;RDB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V
M.`HC+"!F=7IZ>0IM<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN
M96-T:6]N+B(*;7-G<W1R(")4:7!O(%-E<G9E<B!D:2!0;W-T82!P97(@:6P@
M8V]L;&5G86UE;G1O.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,38U(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS9VED("))34%0+"!N
M;R!43%,B"FUS9W-T<B`B24U!4"P@<V5N>F$@5$Q3(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HT.0IM<V=I9"`B24U!4"]03U`S($UA:6P@4V5R=F5R
M<R(*;7-G<W1R("))34%0+U!/4#,@4V5R=F5R(&1I(%!O<W1A(@H*(SH@;&EB
M+TE-4"YP:'`Z.#8V"FUS9VED("))3D)/6"(*;7-G<W1R("))3D)/6"(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@
M;W(@5$Q3+"!Y;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I
M;VX@;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F
M;VQD97)S7V-O;F9I<FTN:'1M;#HQ,@HC+"!F=7IZ>0IM<V=I9"`B268@>6]U
M(&-O;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL
M(&)E(&QO<W0A(@IM<V=S='(@(E1U='1I(&D@;65S<V%G9VD@8V]N=&5N=71I
M(&YE;&QA+V4@8V%R=&5L;&$O92!A;F1R86YO('!E<G-I(2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,@IM<V=I9"`B26=N;W)E(@IM
M<V=S='(@(DEG;F]R82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G<W1R("))9VYO<F$@5'5T
M=&DB"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.`IM
M<V=I9"`B26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M:6UP;W)T+FEN8SHR,`IM<V=I9"`B26UP;W)T(@IM<V=S='(@(DEM<&]R=&$B
M"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-0IM<V=I9"`B26UP;W)T($ME>2(*
M;7-G<W1R("));7!O<G1A($-H:6%V92(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,SD*;7-G:60@(DEM<&]R="!+97EP86ER(@IM<V=S='(@(DEM<&]R
M=&$@0VAI879E(%!'4"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C(W"B,L(&9U>GIY"FUS9VED("));7!O<G0@365S<V%G97,B"FUS9W-T
M<B`B365S<V%G9VD@:6UP;W)T86YT:2(*"B,Z('!G<"YP:'`Z-#(*;7-G:60@
M(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@(DEM<&]R=&$@0VAI879E(%!'4"(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3$*(RP@9G5Z>GD*;7-G
M:60@(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G<W1R("));7!O
M<G1A($-H:6%V92!097)S;VYA;&4@4')I=F%T82!01U`B"@HC.B!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N
M86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@(DEM<&]R=&$@0VAI879E(%!E
M<G-O;F%L92!0<FEV871A(%!'4"(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T
M7VME>2YI;F,Z.0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@
M2V5Y(@IM<V=S='(@(DEM<&]R=&$@0VAI879E(%!E<G-O;F%L92!0=6)B;&EC
M82!01U`B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-`HC
M+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%,O34E-12!#97)T:69I
M8V%T97,B"FUS9W-T<B`B26UP;W)T82!#:&EA=F4@4&5R<V]N86QE(%!U8F)L
M:6-A(%,O34E-12(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#`@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS9VED("));7!O<G0@4'5B;&EC
M($ME>2(*;7-G<W1R("));7!O<G1A($-H:6%V92!0=6)B;&EC82(*"B,Z('1E
M;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!U
M8FQI8R!01U`@2V5Y(@IM<V=S='(@(DEM<&]R=&$@0VAI879E(%!U8F)L:6-A
M(%!'4"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX"B,L
M(&9U>GIY"FUS9VED("));7!O<G0@4'5B;&EC(%,O34E-12!+97DB"FUS9W-T
M<B`B26UP;W)T82!#:&EA=F4@4&5R<V]N86QE(%!U8F)L:6-A(%,O34E-12(*
M"B,Z('-M:6UE+G!H<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+97DB"FUS
M9W-T<B`B26UP;W)T82!C:&EA=F4@4R]-24U%(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@;6)O>"!&:6QE(@IM
M<V=S='(@(DEM<&]R=&$@1FEL92!M8F]X(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O:6UP;W)T+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@
M;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G<W1R("));7!O<G1A
M($9I;&4@;6)O>"`E<R!N96QL82!C87)T96QL82`E<RXB"@HC.B!M97-S86=E
M+G!H<#HU,#(@;6%I;&)O>"YP:'`Z-S,T('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$V('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S,*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHW"FUS9VED("));7!O<G1A
M;G0B"FUS9W-T<B`B26UP;W)T86YT92(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-#<*;7-G:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R
M(")-97-S86=G:2!I;7!O<G1A;G1I(@H*(SH@9F]L9&5R<RYP:'`Z,38W"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@
M)7,N(@IM<V=S='(@(DEM<&]R=&%T:2`E9"!M97-S86=G:2!D82`E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS9VED("));B!0<F]C
M97-S(@IM<V=S='(@(DEN(%!R;V-E<W-O(@H*(SH@9F]L9&5R<RYP:'`Z,S@T
M(&QI8B]&;VQD97(N<&AP.C@V(&QI8B]&;VQD97(N<&AP.C(Q-"!L:6(O24U0
M+G!H<#HS,3,*(SH@;&EB+TE-05`O5')E92YP:'`Z,3$T(&QI8B])34%0+U1R
M964N<&AP.C(Q.0IM<V=I9"`B26YB;W@B"FUS9W-T<B`B4&]S=&$@:6X@07)R
M:79O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,@IM<V=I9"`B26YC
M;'5D92!A(&)R:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A(')E<&QY
M/R(*;7-G<W1R("));F-L=61I('5N(&)R979E('-O;6UA<FEO(&1E;&QE(&EN
M=&5S=&%Z:6]N:2!N96QL82!R:7-P;W-T83\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#@W"FUS9VED("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@
M:6X@82!R97!L>3\B"FUS9W-T<B`B26YC;'5D:2!I;"!M97-S86=G:6\@;W)I
M9VEN86QE(&YE;&QA(')I<W!O<W1A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$S,`IM<V=I9"`B26YF;R(*;7-G<W1R("));F9O(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC
M($ME>2(*;7-G<W1R("));F9O<FUA>FEO;FD@<W5L;&$@0VAI879E(%!U8F)L
M:6-A("5S(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED("))
M;F9O<FUA=&EO;B!O;B!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("))
M;F9O<FUA>FEO;FD@<W5L;&$@0VAI879E(%!U8F)L:6-A(%!R:79A=&$B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW,@IM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B
M;&EC($ME>2(*;7-G<W1R("));F9O<FUA>FEO;FD@<W5L;&$@0VAI879E(%!U
M8F)L:6-A(%!E<G-O;F%L92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,#<*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3@*;7-G
M:60@(DEN;&EN92(*;7-G<W1R("));B!L:6YE82(*"B,Z('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHY"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("));G-E<FES8VD@8VAI879E('%U
M:2(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,34*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R
M92(*;7-G<W1R("));7!O<G1A($-H:6%V92!097)S;VYA;&4@4')I=F%T82!0
M1U`B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$P"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D@2&5R
M92(*;7-G<W1R("));7!O<G1A($-H:6%V92!097)S;VYA;&4@4'5B8FQI8V$@
M4$=0(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R
M("));7!O<G1A($-H:6%V92!0=6)B;&EC82!01U`B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE
M8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(D%Z:6]N92!I;G9A
M;&ED82!P97(@<75E<W1O(&-O;7!O;F5N=&4N(@H*(SH@;6%I;&)O>"YP:'`Z
M-3@T(&UA:6QB;W@N<&AP.C8R-@IM<V=I9"`B26YV86QI9"!!9&1R97-S(@IM
M<V=S='(@(DEN9&ER:7IZ;R!);G9A;&ED;R(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM
M<V=S='(@(D-A<V5L;&$@9&D@<&]S=&$@<F5M;W1A(&EN=F%L:61A(@H*(SH@
M8V]M<&]S92YP:'`Z,34X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))
M;G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N(@IM<V=S
M='(@(D-A<F%T=&5R92!N;VX@=F%L:61O(&YE;&PG:6YD:7)I>GIO(&4M;6%I
M;"XB"@HC.B!S;6EM92YP:'`Z.#(@<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI
M9"!K97DB"FUS9W-T<B`B0VAI879E(&EN=F%L:61A(@H*(SH@<&=P+G!H<#HQ
M.38*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y+B(*
M;7-G<W1R(")#:&EA=F4@4')I=F%T82!01U`@<&5R<V]N86QE(&EN=F%L:61A
M+B(*"B,Z('!G<"YP:'`Z,3<Q"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'
M4"!P=6)L:6,@:V5Y+B(*;7-G<W1R(")#:&EA=F4@4'5B8FQI8V$@4$=0('!E
M<G-O;F%L92!I;G9A;&ED82XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$R"FUS9VED("));G9E<G0B"FUS9W-T<B`B26YV97)T82(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B2T(B
M"FUS9W-T<B`B2T(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3$S"FUS
M9VED(")+97D@3&5N9W1H(@IM<V=S='(@(DQU;F=H97IZ82!C:&EA=F4B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N
M97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O
M;G1I;G5E('=I=&@@:V5Y("(*(F=E;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C,W"FUS9VED(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N
M($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I
M<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F
M:6YE9"!T;R!A9&0@>6]U<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@
M<&=P+G!H<#HS,3@*;7-G:60@(DME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B0VAI879E(&EN=FEA=&$@
M8V]N('-U8V-E<W-O(&%L('-E<G9E<B!P=6)B;&EC;RXB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(Q-@IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T
M<B`B3&EN9W5A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-@IM<V=I
M9"`B3&%S="!-86EL8F]X(%!A9V4B"FUS9W-T<B`B56QT:6UA(%!A9VEN82!D
M96QL($-A<G1E;&QA(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED("),87-T
M(%!A9V4B"FUS9W-T<B`B56QT:6UA(%!A9VEN82(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,X.0IM<V=I9"`B3&E?;FL@071T86-H;65N
M=',B"FUS9W-T<B`B0V]L;&5G86UE7VYT;R!!;&QE9V%T:2(*"B,Z(&%T=&%C
M:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED("),:6YK
M960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B26P@8V]L
M;&5G86UE;G1O(&%G;&D@86QL96=A=&D@;F]N(.@@<&5R;65S<V\B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,3`X,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:6YK
M<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`X,@IM<V=I9"`B(@HB3&ES="!A;&P@8V]N=&%C=',@
M=VAE;B!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE
M9"P@>6]U('=I;&P@(@HB;VYL>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A
M<F-H(&9O<B!E>'!L:6-I=&QY*2(*;7-G<W1R("(B"B)#87)I8V$@='5T=&D@
M:2!C;VYT871T:2!Q=6%N9&\@;6]S=')I('-C:&5R;6\@8V]N871T:3\@*'-E
M(&1I<V%B:6QI=&%T;R`B"B)V961R86D@<V]L;R!I(&-O;G1A='1I(&-H92!R
M:6-E<F-H:2!E<W!L:6-I=&%M96YT92DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C@U"FUS9VED("),:7-T:6YG(&EN('1H92!(96%D97(B"FUS9W-T
M<B`B3&ES=&$@;F5L;"=);G1E<W1A>FEO;F4B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z,S`*;7-G:60@(DQO8V%L($UA:6QB;W@Z(@IM
M<V=S='(@(D-A<V5L;&$@9&D@4&]S=&$@;&]C86QE.B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-S0*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@
M(DQU;V=O(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C4*;7-G
M:60@(DQO9R!I;B(*;7-G<W1R(")%;G1R82(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O("5S
M(@IM<V=S='(@(D5N=')A(&EN("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,S<*;7-G:60@(DQO9VEN(@IM<V=S='(@(D5N=')A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!487-K<R(*
M;7-G<W1R(")/<&5R87II;VYI(&1A(&5S96=U:7)E(&$@:6YI>FEO('-E<W-I
M;VYE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDV"FUS
M9VED("),;W<B"FUS9W-T<B`B0F%S<V$B"@HC.B!M97-S86=E+G!H<#HR.3D@
M;6%I;&)O>"YP:'`Z-S(W('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M,3,*;7-G:60@(DQO=R!0<FEO<FET>2(*;7-G<W1R(")0<FEO<FETX"!"87-S
M82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-PIM<V=I
M9"`B3&]W97-T(@IM<V=S='(@(DUI;FEM;R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#0*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM
M<V=S='(@(D9I;&4@36%C:6YT;W-H(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A
M<W-P:')A<V4N:6YC.C$S"FUS9VED(")-86EL(@IM<V=S='(@(E!O<W1A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS9VED(")-86EL(%!R979I
M97=S(@IM<V=S='(@(D%N=&5P<FEM92!D:2!0;W-T82(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@
M<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SHB"FUS9W-T<B`B5&EP;R!397)V
M97(@9&D@4&]S=&$@<&5R(&EL(&-O;&QE9V%M96YT;SHB"@HC.B!F;VQD97)S
M+G!H<#HT,#(*;7-G:60@(DUA:6QB;W@B"FUS9W-T<B`B0V%S96QL82!D:2!0
M;W-T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*;7-G:60@(DUA
M:6QB;W@@86YD($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!Z
M:6]N:2!D:2!6:7-U86QI>GIA>FEO;F4@9&D@0V%R=&5L;&4B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@
M365S<V%G97,@:6X@1F]L9&5R(&%S(%-E96XB"FUS9W-T<B`B0V]N=')A<W-E
M9VYA('1U='1I(&D@;65S<V%G9VD@;F5L;&$@8V%R=&5L;&$@8V]M92!L971T
M:2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS9VED
M(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM<V=S
M='(@(D-O;G1R87-S96=N82!T=71T:2!I(&UE<W-A9V=I(&YE;&QA(&-A<G1E
M;&QA(&-O;64@;F]N(&QE='1I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM<V=S='(@(D-O;G1R87-S96=N82!C
M;VUE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G:60@(DUA
M<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT
M(&-O;&]R<S\B"FUS9W-T<B`B36]S=')A(&D@=F%R:2!L:79E;&QI(&1I(&-I
M=&%Z:6]N92!C;VX@8V]L;W)I(&1I=F5R<VDN(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S
M('-E96X_("A)34%0(&]N;'DI(@IM<V=S='(@(E-E9VYA(&UE<W-A9V=I(&-O
M;64@=FES=&D_("AS;VQO($E-05`I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8U.`IM<V=I9"`B36%R:R!S:6UP;&4@;6%R:W5P/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@(DUA
M=&-H($%L;"!1=65R:65S(@IM<V=S='(@(D-O;6)A8VEA(%1U='1E(&QE($1O
M;6%N9&4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#(*;7-G
M:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R(")#;VUB86-I82!5;F$@1&]M
M86YD82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PIM
M<V=I9"`B36%X:6UU;2!!='1A8VAM96YT(%-I>F4B"FUS9W-T<B`B36%S<VEM
M82!$:6UE;G-I;VYE(&1E9VQI($%L;&5G871I(@H*(SH@;&EB+V%P:2YP:'`Z
M-SD*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B
M"FUS9W-T<B`B26P@;G5M97)O(&UA<W-I;6\@9&D@86QL96=A=&D@Z"!S=&%T
M;R!R86=G:75N=&\N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#DT"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R
M96%C:&5D+B(*;7-G<W1R("));"!N=6UE<F\@;6%S<VEM;R!D:2!A;&QE9V%T
M:2#H('-T871O(')A9V=I=6YT;RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT.#D*;7-G:60@(DUA>&EM=6T@=&]T86P@871T86-H;65N
M="!S:7IE(')E86-H960N(@IM<V=S='(@(DEL('1O=&%L92!M87-S:6UO(&1I
M(&%L;&5G871I(.@@<W1A=&\@<F%G9VEU;G1O+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV,C8*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N
M(@IM<V=S='(@(D-A;F-E;&QA>FEO;F4@4FEU;FEO;F4B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3<U"FUS9VED(")-965T:6YG($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DEN9F]R;6%Z:6]N:2!2:75N:6]N92(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I;F<@4')O<&]S
M86PB"FUS9W-T<B`B4')O<&]S=&$@4FEU;FEO;F4B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C$W"FUS9VED(")-965T:6YG(%)E<&QY(@IM<V=S
M='(@(E)I<W!O<W1A(%)I=6YI;VYE(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Y.`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T<B`B06=G
M:6]R;F%M96YT;R!2:75N:6]N92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV,#,*;7-G:60@(DUE971I;F<@57!D871E(%)E<75E<W0B"FUS9W-T
M<B`B4FEC:&EE<W1A(&%G9VEO<FYA;65N=&\@4FEU;FEO;F4B"@HC.B!L:6(O
M0FQO8VLO=')E95]F;VQD97)S+G!H<#HS"FUS9VED(")-96YU($9O;&1E<B!,
M:7-T(@IM<V=S='(@(DQI<W1A($-A<G1E;&QA(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C,S,0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-97-S86=G:6\B"@HC
M.B!C;VUP;W-E+G!H<#HU-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O<V4N<&AP
M.C8T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@
M0V]M<&]S:71I;VXB"FUS9W-T<B`B0V]M<&]S:7II;VYE($UE<W-A9V=I;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3<*;7-G:60@(DUE<W-A9V4@
M1&%T92(*;7-G<W1R(")$871A($UE<W-A9V=I;R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P,PIM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(D]P>FEO
M;FD@365S<V%G9VDB"@HC.B!S96%R8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G
M92!396%R8V@B"FUS9W-T<B`B4FEC97)C82!-97-S86=G:6\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS
M9W-T<B`B1&EM96YS:6]N92!-97-S86=G:6\B"@HC.B!M97-S86=E+G!H<#HS
M.#0*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(DEN=&5S=&%Z:6]N
M:2!-97-S86=G:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G
M:60@(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R(")6:7-U86QI>GIA>FEO;F4@
M365S<V%G9VEO(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS
M9VED(")-97-S86=E(&9L86=S(@IM<V=S='(@(D-O;G1R87-S96=N:2!D96P@
M;65S<V%G9VEO(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX,PIM
M<V=I9"`B365S<V%G92!F;VQD97)S(@IM<V=S='(@(D-A<G1E;&QE(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")-97-S
M86=E(&9R;VT@)7,B"FUS9W-T<B`B365S<V%G9VEO(&1A("5S(@H*(SH@;6%I
M;&)O>"YP:'`Z-C8W"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&AA<R!A='1A
M8VAM96YT<R(*;7-G<W1R(")-97-S86=G:2!T<F]V871I(@H*(SH@;6%I;&)O
M>"YP:'`Z-C4X"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E
M9"(*;7-G<W1R(")#86UP:2!D96P@;65S<V%G9VEO(@H*(SH@;6%I;&)O>"YP
M:'`Z-C4S"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G
M<W1R(")#86UP:2!D96P@;65S<V%G9VEO(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]H96%D97(N:6YC.C,S"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS9W-T
M<B`B365S<V%G9VD@=')O=F%T:2(*"B,Z(&-O;7!O<V4N<&AP.C@R-"!C;VUP
M;W-E+G!H<#HX,S@*;7-G:60@(DUE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(DUE<W-A9V=I;R!R96EN9&ER:7IZ871O(&-O;B!S
M=6-C97-S;RXB"@HC.B!C;VUP;W-E+G!H<#HQ,#@T"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V
M960@=&\@)7,B"FUS9W-T<B`B365S<V%G9VEO(&EN=FEA=&\@8V]N('-U8V-E
M<W-O+"!M82!N;VX@<V%L=F%T;R!I;B`E<R(*"B,Z(&-O;7!O<V4N<&AP.C$Q
M-#,@8V]M<&]S92YP:'`Z,3$U.`IM<V=I9"`B365S<V%G92!S96YT('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B365S<V%G9VEO(&EN=FEA=&\@8V]N('-U8V-E
M<W-O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE
M<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@
M(DYU;65R;R!D:2!M97-S86=G:2!P97(@<&%G:6YA(&YE;&QA('9I<W5A;&EZ
M>F%Z:6]N92!D96QL82!C87)T96QL82XB"@HC.B!M86EL8F]X+G!H<#HS,C(*
M;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S='(@(DUE<W-A9V=I(&$B"@HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,CD*;7-G:60@(DUO9&EF>2(*;7-G<W1R
M(")-;V1I9FEC82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z
M,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@
M861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R(")0:?D@
M9&D@=6X@:6YD:7)I>GIO('1R;W9A=&\@<&5R(&EL(&-A;7!O("<E<R<N(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E(@IM
M<V=S='(@(E-P;W-T82(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,Q-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(E-P;W-T82!G
M:?DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$X"FUS9VED(")-;W9E
M('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE
M<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHU,`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B
M4W!O<W1A(&%L;&$@8V%R=&5L;&$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,30*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B4W!O
M<W1A('-U(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ
M,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E<FYA=&EV92(*;7-G<W1R(")-=6QT
M:7!A<G0O86QT97)N871I=F4B"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP
M:'`Z,34R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!-97-S86=E(%9I97<B
M"FUS9W-T<B`B5FES=6%L:7IZ87II;VYE($UE<W-A9V=I;R(*"B,Z('1E;7!L
M871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHU"B,L(&9U>GIY
M"FUS9VED(").3TY%(@IM<V=S='(@(DY/5$$B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED(").3U1%(@IM
M<V=S='(@(DY/5$$B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C(S."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(").
M86UE(@IM<V=S='(@(DYO;64B"@HC.B!P9W`N<&AP.C$Q,`IM<V=I9"`B3F%M
M92!A;F0O;W(@96UA:6P@8V%N(&YO="!B92!E;7!T>2(*;7-G<W1R(").;VUE
M(&4O;R!E;6%I;"!N;VX@<&]S<V]N;R!E<W-E<F4@=G5O=&DB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S<X"FUS9VED(").965D<R!!8W1I;VXB
M"FUS9W-T<B`B07II;VYE($YE8V5S<V%R:6$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3<P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#(*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<W.`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B
M36%I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`IM<V=I9"`B3F5V
M97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(")!;&QE9V%T;R!M86D@<V%L
M=F%T:2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,C0*;7-G:60@(DYE
M=R(*;7-G<W1R(").=6]V;R(*"B,Z(&QI8B])35`N<&AP.C4V,PIM<V=I9"`B
M3F5W($9O;&1E<B(*;7-G<W1R(").=6]V82!#87)T96QL82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`B
M3G5O=F$@4&]S=&$B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3D@;&EB
M+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(DYE
M=R!-97-S86=E(@IM<V=S='(@(DUE<W-A9V=I;R!3=6-C97-S:79O(@H*(SH@
M;6%I;&)O>"YP:'`Z-S<V(&QI8B]-24U%+TAE861E<G,N<&AP.C$Y,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS
M9W-T<B`B3G5O=FD@;65S<V%G9VDB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$Y"FUS9VED(").97<@;65S<V%G97,B"FUS9W-T<B`B3G5O=FD@
M;65S<V%G9VDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,3,S"FUS9VED(").97AT(@IM<V=S='(@(E-U8V-E<W-I=F\B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S"FUS9VED(").
M97AT($UE<W-A9V4B"FUS9W-T<B`B365S<V%G9VEO(%-U8V-E<W-I=F\B"@HC
M.B!M86EL8F]X+G!H<#HS-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(")0
M86=I;F$@4W5C8V5S<VEV82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS9VED(").
M;R(*;7-G<W1R(").;R(*"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO($-E
M<G1I9FEC871E(&9O=6YD(@IM<V=S='(@(DYE<W-U;B!C97)T:69I8V%T;R!T
M<F]V871O(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN
M8SHU"FUS9VED(").;R!%;F-R>7!T:6]N(@IM<V=S='(@(DYE<W-U;B!#<FEP
M=&%G9VEO(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Y"FUS9VED(").
M;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B3F5S<W5N82!C:&EA=F4@;F5L
M($ME>7)I;F<B"@HC.B!M86EL8F]X+G!H<#HS-S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@365S<V%G97,B"FUS9W-T<B`B3F5S<W5N($UE<W-A9V=I;R(*
M"B,Z('!G<"YP:'`Z,3,W"FUS9VED(").;R!01U`@<'5B;&EC(&ME>2!I;7!O
M<G1E9"XB"FUS9W-T<B`B3F5S<W5N82!C:&EA=F4@4$=0(&EM<&]R=&%T82XB
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C@T"B,L(&9U>GIY"FUS
M9VED(").;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT(@IM<V=S='(@
M(DYE<W-U;B!C97)T:69I8V%T;R!T<F]V871O(@H*(SH@;&EB+TUA:6QB;W@N
M<&AP.C,R.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT(@IM<V=S
M='(@(D%N=&5P<FEM82(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,34*(RP@9G5Z>GD*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S
M='(@(DQA('1U82!C:&EA=F4@<'5B8FQI8V$B"@HC.B!S;6EM92YP:'`Z,34Q
M"B,L(&9U>GIY"FUS9VED(").;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O<G1E
M9"XB"FUS9W-T<B`B3F5S<W5N82!C:&EA=F4@<'5B8FQI8V$@4R]-24U%(&EM
M<&]R=&%T82XB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3`*;7-G
M:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R(").97-S=6X@06QL
M96=A=&\@5')O=F%T;R(*"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"B,L
M(&9U>GIY"FUS9VED(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN
M('1H92!P=6)L:6,@:V5Y+B(*;7-G<W1R("));F9O<FUA>FEO;FD@<W5L;&$@
M0VAI879E(%!U8F)L:6-A("5S(@H*(SH@86-L+G!H<#HW,B!A8VPN<&AP.CDX
M"FUS9VED(").;R!F;VQD97(@<V5L96-T960N(@IM<V=S='(@(DYE<W-U;F$@
M8V%R=&5L;&$@<V5L97II;VYA=&$N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$T,0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F
M;W(@;F5W(&UA:6PN(@IM<V=S='(@(DYE<W-U;F$@8V%R=&5L;&$@<V5L97II
M;VYA=&$@<&5R(&YU;W9A('!O<W1A+B(*"B,Z(&9O;&1E<G,N<&AP.C(Q."!L
M:6(O1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED(").
M;R!F;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(DYO;B!S;VYO('-T
M871E('-P96-I9FEC871E(&-A<G1E;&QE(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$T-PIM<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E
M<R(*;7-G<W1R(").97-S=6YA(&-A<G1E;&QA(&-O;B!D96D@;G5O=FD@;65S
M<V%G9VDB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30T"FUS9VED(").
M;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(DYE<W-U
M;F$@8V%R=&5L;&$@8V]N(&1E:2!M97-S86=G:2!N;VX@=FES=&DN(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,R-0IM<V=I9"`B3F\@;65S<V%G92!B;V1Y('1E
M>'0B"FUS9W-T<B`B3F5S<W5N('1E<W1O(&1E;"!C;W)P;R!M97-S86=G:6\N
M(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,W,0IM<V=I9"`B3F\@;65S<V%G97,@
M;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B3F5S<W5N(&UE<W-A9V=I
M;R!C;W)R:7-P;VYD96YT92!T<F]V871O+B(*"B,Z('!G<"YP:'`Z,3@Y"FUS
M9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N(@IM
M<V=S='(@(DYE<W-U;F$@8VAI879E('!R:79A=&$@4$=0(&EM<&]R=&%T82XB
M"@HC.B!P9W`N<&AP.C$V-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI
M8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DYE<W-U;F$@8VAI879E('!U8F)L
M:6-A(%!'4"!I;7!O<G1A=&$N(@H*(SH@<VUI;64N<&AP.C(P,0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!I;7!O
M<G1E9"XB"FUS9W-T<B`B3F5S<W5N82!C:&EA=F4@<')I=F%T82!3+TU)344@
M:6UP;W)T871A+B(*"B,Z('-P96QL:6YG+G!H<#HR,C`*;7-G:60@(DYO('-P
M96QL8VAE8VMI;F<@<')O9W)A;2!C;VYF:6=U<F5D+B(*;7-G<W1R(").97-S
M=6X@<')O9W)A;6UA(&1I(&-O;G1R;VQL;R!O<G1O9W)A9FEC;R!C;VYF:6=U
M<F%T;RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*
M;7-G:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(").97-S=6X@97)R
M;W)E(&1I(&]R=&]G<F%F:6$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G<W1R(").
M97-S=6X@<W5G9V5R:6UE;G1O(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU
M-C0*;7-G:60@(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I8V%T:6]N(&UE
M=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HV
M."!A8VPN<&AP.CDT"FUS9VED(").;R!U<V5R('-P96-I9FEE9"XB"FUS9W-T
M<B`B3F5S<W5N('5T96YT92!S<&5C:69I8V%T;RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S`Y"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS
M9W-T<B`B3F]N(%!A<G1E8VEP86YT92(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,3$@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T
M+FEN8SHT,`HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M-2!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B3F]N92(*;7-G<W1R(").
M97-S=6YO(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDU
M"FUS9VED(").;W)M86PB"FUS9W-T<B`B3F]R;6%L92(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS.0IM<V=I9"`B3F]T($1E;&5T960B"FUS9W-T<B`B3F]N($5L
M:6UI;F%T;R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@1')A
M9G0B"FUS9W-T<B`B3F]N($)O>GIA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-`IM
M<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R(").;VX@26UP;W)T86YT92(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*;7-G:60@(DYO
M="!097)S;VYA;"(*;7-G<W1R(").;VX@4&5R<V]N86QE(@H*(SH@;&EB+T-R
M>7!T+U!'4"YP:'`Z,3,Y(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#
M<GEP="]334E-12YP:'`Z,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@
M:V5Y+B(*;7-G<W1R(")#:&EA=F4@<'5B8FQI8V$@;F]N('9A;&ED82XB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED(").;W0@9&5L
M971E9"!M97-S86=E<R(*;7-G<W1R(")-97-S86=G:2!N;VX@96QI;6EN871I
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B3F]T
M(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(")-97-S86=G:2!N;VX@:6UP
M;W)T86YT:2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L
M;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O
M;64@=&EM92(*;7-G<W1R(").;W1A(&-H92!Q=65S=&\@<'5O)R!R:6-H961E
M<F4@=6X@<&\G(&1I('1E;7!O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8Q-@HC+"!F=7IZ>0IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R(")38W)I=F4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED(").=6UB97(@
M;V8@;6]N=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT<R!I9B!D
M96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R("(B"B)1=6%N=&D@;65S:2!C;VYS
M97)V87)E('9E8V-H:2!A;&QE9V%T:2!S92!I;7!O<W1A=&$@96QI;6EN87II
M;VYE(&UE;G-I;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"FUS
M9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@
M:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB3G5M97)O(&1I('9E
M8V-H:64@8V%R=&5L;&4@9&D@4&]S=&$@26YV:6%T82!D82!M86YT96YE<F4@
M<V4@=F5N9V]N;R`B"B)E;&EM:6YA=&4@;65N<VEL;65N=&4N(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-30@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4U,@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S,S"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHT.0HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED
M(")/4B(*;7-G<W1R(")/(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@(E9E8V-H:2!M97-S
M86=G:2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I
M;%]M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S
M(&)E:6YG('!U<F=E9"XB"FUS9W-T<B`B16QI;6EN87II;VYE(&1E;&QE('9E
M8V-H:64@8V%R=&5L;&4@9&D@4&]S=&$@26YV:6%T82XB"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S
M('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(DUO<W1R
M82!S;VQO(&-A<G1E;&QE(&-O;B!M97-S96=G:2!N;VX@;&5T=&D_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHW.0IM<V=I9"`B3VYL
M>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I
M;VXN(@IM<V=S='(@(E-O;&\@=6YA(&-A<G1E;&QA('!U\B!E<W-E<F4@<V5L
M97II;VYA=&\@<&5R('%U97-T82!A>FEO;F4B"@HC.B!T96UP;&%T97,O;65N
M=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED
M(")/<&5N($9O7VQD97(B"FUS9W-T<B`B07!R:2!#87)T96QL82(*"B,Z(&9O
M;&1E<G,N<&AP.C0R-PIM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G<W1R(")#
M87)T96QL82!!<&5R=&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S`U"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G<W1R(")087)T
M96-I<&%N=&4@;W!Z:6]N86QE(@H*(SH@9F5T8VAM86EL+G!H<#HS,R!T96UP
M;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H97(@36%I;"!!8V-O=6YT
M<R(*;7-G<W1R(")!;'1R:2!!8V-O=6YT(&1I(%!O<W1A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS
M9W-T<B`B06QT<F4@3W!Z:6]N:2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C`Q"FUS9VED(")/=71B;W5N9"!397)V97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ-B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HQ-C4*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,C`T(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,`IM<V=I9"`B4$=0(@IM
M<V=S='(@(E!'4"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES
M="YI;F,Z-PIM<V=I9"`B4$=0($5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")#
M<FEP=&$@365S<V%G9VEO(%!'4"(*"B,Z(&-O;7!O<V4N<&AP.C,U.`IM<V=I
M9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`B17)R;W)E(%!'4#H@(@H*(SH@8V]M
M<&]S92YP:'`Z,S,W"FUS9VED(")01U`@17)R;W(Z($YE960@<&%S<W!H<F%S
M92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(B(*(D5R<F]R
M92!01U`Z(.@@;F5C97-S87)I82!U;F$@<&%R;VQA(&-H:6%V92!P97(@;&$@
M8VAI879E('!R:79A=&$@<&5R<V]N86QE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#(*;7-G:60@(E!'4"!/<'1I;VYS(@IM<V=S='(@(D]P>FEO
M;FD@4$=0(@H*(SH@<&=P+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A<V4@
M26YP=70B"FUS9W-T<B`B26YP=70@4&%R;VQA($-H:6%V92!01U`B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA;"!+
M97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I
M;VXN(@IM<V=S='(@(DEL('-U<'!O<G1O(&1E;&QA(&-H:6%V92!01U`@;F5C
M97-S:71A(&1I('5N82!C;VYN97-S:6]N92!S:6-U<F$N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,3<S"FUS9VED(")01U`@4'5B;&EC($ME>2!4
M97AT(@IM<V=S='(@(E1E<W0@0VAI879E(%!'4"!0=6)B;&EC82(*"B,Z('!G
M<"YP:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y
M(&9O<B!<(B5S("@E<RE<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G
M<W1R("),82!C:&EA=F4@4'5B8FQI8V$@4$=0('!E<B!<(B5S("@E<RE<(B#H
M('-T871A(&%G9VEU;G1A(&-O;B!S=6-C97-S;RXB"@HC.B!P9W`N<&AP.C(T
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E
M<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B3&$@0VAI
M879E(%!U8F)L:6-A(%!'4"!P97(@7"(E<UPB(.@@<W1A=&$@96QI;6EN871A
M(&-O;B!S=6-C97-S;RXB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")#:&EA=F4@4'5B
M8FQI8V$@4$=0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T
M+FEN8SHX"FUS9VED(")01U`@4VEG;B!-97-S86=E(@IM<V=S='(@(D9I<FUA
M($UE<W-A9V=I;R!01U`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T
M7VQI<W0N:6YC.CD*;7-G:60@(E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G92(*
M;7-G<W1R(")&:7)M82]#<FEP=&$@;65S<V%G9VEO(%!'4"(*"B,Z('!G<"YP
M:'`Z,C`R"FUS9VED(")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D
M9&5D+B(*;7-G<W1R(")#:&EA=F4@<')I=F%T82!01U`@86=G:75N=&$@8V]N
M('-U8V-E<W-O+B(*"B,Z('!G<"YP:'`Z,3<W"FUS9VED(")01U`@<'5B;&EC
M(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(D-H:6%V92!P=6)B
M;&EC82!01U`@86=G:75N=&$@8V]N('-U8V-E<W-O+B(*"B,Z('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")01U`@<W5P<&]R="!I<R!D
M:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B4W5P<&]R=&\@4$=0
M(&1I<V%B:6QI=&%T;R!S=6P@<VES=&5M82XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HR,#@*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C
M=7)R96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U
M;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(DEL('-U<'!O
M<G1O(%!'4"!N;VX@Z"!A='1I=F\L('!E<B!C=6D@Z"!I;7!O<W-I8FEL92!V
M97)I9FEC87)E(&QA(&9I<FUA("(*(F5L971T<F]N:6-A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I9"`B(@HB4$=0('-U<'!O<G0@
M:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA
M8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB26P@<W5P<&]R=&\@
M4$=0(&YO;B#H(&%T=&EV;RP@<&5R(&-U:2#H(&EM<&]S<VEB:6QE(&1E8W)I
M<'1A<F4@:6P@;65S<V%G9VEO+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR"B,L(&9U>GIY"FUS9VED("(B"B)01U`@<W5P<&]R="!R97%U:7)E<R!P
M;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@
M8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO
M=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@4$=0("(*
M(F9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B
M"B));"!S=7!P;W)T;R!01U`@;F5C97-S:71A(&1I('5T;&EZ>F%R92!F:6YE
M<W1R92!P;W!U<"X@4V4@:6P@='5O(&)R;W=S97(@Z"`B"B)S971T871O('!E
M<B!N;VX@=71I;&EZ>F%R92!F:6YE<W1R92!P;W!U<"P@9&5V:2!M;V1I9FEC
M87)E(&QE(&EM<&]S=&%Z:6]N:2`B"B)D96P@8G)O=W-E<B!O(&QE(&9U;GII
M;VYI(%!'4"!N;VX@9G5N>FEO;F5R86YN;R!C;W)R971T86UE;G1E(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B"FUS9W-T
M<B`B4$]0,R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`P"FUS9VED
M(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(E!/4#,@
M*%!R;W1O8V]L;&\@075T;VUA=&EC;RDB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R(")03U`S
M('9I82!34TPB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM<V=I
M9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM
M<V=S='(@(E!/4#,@=FEA(%-33"`H8V5R=&EF:6-A=&\@875T;RUF:7)M871O
M*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")0
M3U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B4$]0,R!V:6$@
M4U-,("AA=71O+69I<FUA=&\I(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R(")03U`S+"!S96YZ
M82!43%,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`B4&%G
M:6YA("5D(&1I("5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP,PIM
M<V=I9"`B4&%G92!W:71H('1H92!&:7)S="!5;G-E96X@365S<V%G92(*;7-G
M<W1R(")086=I;F$@8V]N(&EL(%!R:6UO($UE<W-A9V=I;R!.;VX@5FES=&\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`T"FUS9VED(")086=E('=I
M=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B4&%G:6YA(&-O
M;B!L)U5L=&EM;R!-97-S86=G:6\@3F]N(%9I<W1O(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T
M<B`B4&%R=&4H:2DB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS
M9VED(")087-S<&AR87-E(@IM<V=S='(@(E!A<F]L82!C:&EA=F4B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!
M9V%I;BDB"FUS9W-T<B`B4&%R;VQA(&-H:6%V92`H86YC;W)A*2(*"B,Z('-M
M:6UE+G!H<#HR,S4@<&=P+G!H<#HS,3`*;7-G:60@(E!A<W-P:')A<V4@<W5C
M8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R(")087)O;&$@8VAI879E('-C
M87)I8V%T82!C;VX@<W5C8V5S<V\N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A
M<W-P:')A<V4N:6YC.C$X('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z
M,CD*;7-G:60@(E!A<W-P:')A<V4Z(@IM<V=S='(@(E!A<F]L82!C:&EA=F4Z
M(@H*(SH@<&=P+G!H<#HQ,3(*;7-G:60@(E!A<W-P:')A<V5S(&-A;B!N;W0@
M8F4@96UP='DB"FUS9W-T<B`B3&4@<&%R;VQE(&-H:6%V92!N;VX@<&]S<V]N
M;R!E<W-E<F4@=G5O=&4B"@HC.B!P9W`N<&AP.C$Q-`IM<V=I9"`B4&%S<W!H
M<F%S97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(DQA('!A<F]L92!C:&EA=F4@
M;F]N(&-O<G)I<W!O;F1O;F\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z,C`@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<Q
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3DR"FUS9VED(")087-S
M=V]R9"(*;7-G<W1R(")087-S=V]R9"(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHT.`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")%<V5G=6D@;&4@;W!E<F%Z
M:6]N:2!D:2!M86YU=&5N>FEO;F4@86P@;&]G:6X_(@H*(SH@86-L+G!H<#HW
M-B!A8VPN<&AP.C$P,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E
M<B!C86X@;F]T(&)E(&-H86YG960N(@IM<V=S='(@(DD@<&5R;65S<VD@<&5R
M('%U97-T;R!U=&5N=&4@;F]N('!O<W-O;F\@97-S97)E(&UO9&EF:6-A=&DN
M(@H*(SH@;65S<V%G92YP:'`Z-#DS(&UA:6QB;W@N<&AP.C<P,R!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C(T"B,Z('1E;7!L871E<R]M86EL8F]X
M+VQE9V5N9"YI;F,Z,3`*;7-G:60@(E!E<G-O;F%L(@IM<V=S='(@(E!E<G-O
M;F%L92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-`IM<V=I9"`B4&5R
M<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87II;VYI(%!E<G-O
M;F%L:2(*"B,Z('!G<"YP:'`Z,3(P"FUS9VED(")097)S;VYA;"!01U`@:V5Y
M<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")#;W!P:6$@
M8VAI879I(%!'4"!G96YE<F%T82!C;VX@<W5C8V5S<V\N(@H*(SH@<&=P+G!H
M<#HQ,C<*;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R(")#:&EA=F4@<&5R<V]N86QE(%!'4"!C86YC96QL
M871A(&-O;B!S=6-C97-S;RXB"@HC.B!S;6EM92YP:'`Z,C`W"B,L(&9U>GIY
M"FUS9VED(")097)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O
M<G1E9#H@(@IM<V=S='(@(DYE<W-U;F$@8VAI879E('!R:79A=&$@4R]-24U%
M(&EM<&]R=&%T82XB"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S;VYA
M;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M0VAI879E('!E<G-O;F%L92!3+TU)344@8V%N8V5L;&%T82!C;VX@<W5C8V5S
M<V\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA
M8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S
M/R(*;7-G<W1R("));G-E<FES8VD@;&$@='5A(&9I<FUA('!R:6UA(&1I(')I
M<W!O<W1E(&4@:6YO;'1R:2XB"@HC.B!C;VUP;W-E+G!H<#HR-30*;7-G:60@
M(E!L86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B36]S=')A
M(%9E<G-I;VYE(%-O;&\@5&5S=&\@9&5L($UE<W-A9V=I;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.3D*;7-G:60@(B(*(E!L87D@<V]U;F0@;VX@
M;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P
M;W)T(&5M8F5D9&5D("(*(G-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O
M;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"`B
M"B)R97%U:7)E(&$@<&QU9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@9F]L9&5R.B(*;7-G<W1R("));G-E<FES8VD@=6X@;F]M
M92!P97(@;&$@;G5O=F$@8V%R=&5L;&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9F]L9&5R<RYJ<SHQ,#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ,#0*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T
M:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B26YS97)I<V-I(&EL(&YO;64@9&5L
M;&$@;G5O=F$@8V%R=&5L;&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ,S<*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA
M;64Z(@IM<V=S='(@(DEN<V5R:7-C:2!I;"!N=6]V;R!N;VUE.B(*"B,Z('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O("(*(F5N
M=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G
M<W1R("(B"B)097(@8V]R=&5S:6$@:6YS97)I<V-I(&QA('!A<W-W;W)D('!E
M<B!L82!T=6$@8VAI879E('!R:79A=&$@4$=0+B!$;W9R86D@(@HB:6YS97)I
M<FQA('-O;&\@=6YA('9O;'1A('!E<B`E<R!S97-S:6]N92XB"@HC.B!T96UP
M;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D("(*(G1O
M(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*
M;7-G<W1R("(B"B)097(@8V]R=&5S:6$@:6YS97)I<V-I(&QA('!A<W-W;W)D
M('!E<B!L82!T=6$@8VAI879E('!R:79A=&$@4R]-24U%+B!$;W9R86D@(@HB
M:6YS97)I<FQA('-O;&\@=6YA('9O;'1A('!E<B`E<R!S97-S:6]N92XB"@HC
M.B!R96-O;7!O<V4N<&AP.CDW"FUS9VED("(B"B)0;&5A<V4@;&]G(&EN(&%G
M86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@
M87)E($Y/5"!U<VEN9R`B"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN
M9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O
M("(*(FQO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN
M(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA8VMI;F<@
M>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E
M;FEE;F-E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C<Q"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D+B(*
M;7-G<W1R("));G-E<FES8VD@;&$@='5A('!A<W-W;W)D+B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-C<*;7-G:60@(E!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(DEN<V5R:7-C:2!I;"!T=6\@;F]M
M92!U=&5N=&4N(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])35`N<&AP.C0U
M.0IM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@
M861D<F5S<V5S+B(*;7-G<W1R(")#;W)R96=G:2!G;&D@:6YD:7)I>GII(&%M
M8FEG=6D@;R!N;VX@=F%L:61I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV-#(*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN
M9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M
M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"B)2:79E9&D@;&4@<V5G
M=65N=&D@:6YF;W)M87II;VYI+"!E('!O:2!S96QE>FEO;F4@=6XG87II;VYE
M(&1A;"!M96YU('%U:2`B"B)S;W1T;R`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L
M9&5R(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B
M4V5L97II;VYA('5N82!C87)T96QL82!P<FEM82!D:2!E<V5G=6ER92!U;F$@
M87II;VYE+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#(*;7-G
M:60@(E!L96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L
M;W<N(@IM<V=S='(@(E-E;&5Z:6]N82!U;B=A>FEO;F4@9&%L(&UE;G4@<75I
M('-O='1O+B(*"B,Z('1E;7!L871E<R]S96%R8V@O:F%V87-C<FEP="YI;F,Z
M-#$*;7-G:60@(E!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T
M;R!S96%R8V@N(@IM<V=S='(@(E-E;&5Z:6]N82!A;&UE;F\@=6YA(&-A<G1E
M;&QA(&EN(&-U:2!C97)C87)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@
M9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B4V5L97II;VYA
M('-O;&\@=6YA(&-A<G1E;&QA('!E<B!Q=65S=&$@;W!E<F%Z:6]N92XB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-S,*;7-G:60@(E!L
M96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB
M"FUS9W-T<B`B4V5L97II;VYA(&\@<V-R:79I(&YE;&QA(&-A<V5L;&$@82!D
M97-T<F$Z(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*;7-G:60@(E!O
M=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Q-`IM<V=I9"`B4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H
M(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R(")&86D@<')E8V5D97)E(&QA('1U
M82!F:7)M82!D82!T<F%T=&EN:2`H)RTM("<I/R(*"B,Z('-M:6UE+G!H<#HR
M-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"FUS9VED(")0<F5F
M97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B4')E9F5R
M96YZ92!A9V=I;W)N871E(&-O;B!S=6-C97-S;RXB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4')E=FEE=R(*;7-G
M<W1R(")!;G1E<')I;6$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U<R!-97-S86=E(@IM<V=S
M='(@(DUE<W-A9V=I;R!0<F5C961E;G1E(@H*(SH@;6%I;&)O>"YP:'`Z,S0W
M"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(E!A9VEN82!0<F5C961E
M;G1E(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C,S"FUS9VED(")0<FEN="(*;7-G<W1R(")3=&%M<&$B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHS.`IM<V=I9"`B4')I;W)I='DB"FUS
M9W-T<B`B4')I;W)I=.`B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D
M(@IM<V=S='(@(DQA('1U82!C:&EA=F4@<')I=F%T82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N
M(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R(")2
M:6-H:65D:2!O9VYI('9O;'1A(&-H92!V:65N92!I;G9I871O('5N(&%L;&5G
M871O.R!D969A=6QT($Y/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U
M.`IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S
M96YT.R!D969A=6QT('1O(%E%4R(*;7-G<W1R(")2:6-H:65D:2!O9VYI('9O
M;'1A(&-H92!V:65N92!I;G9I871O('5N(&%L;&5G871O.R!D969A=6QT(%-)
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED
M(")0<F]T;V-O;#HB"FUS9W-T<B`B4')O=&]C;VQL;SHB"@HC.B!L:6(O0W)Y
M<'0O4$=0+G!H<#HT,CD*;7-G:60@(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U
M<'!O<G0@:&%S(&)E96X@9&ES86)L960N(@IM<V=S='(@(E-U<'!O<G1O('-E
M<G9E<B!P=6)B;&EC;R!01U`@9&ES86)I;&ET871O(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)?9V4@1&5L971E9"(*;7-G
M<W1R(")2:5]M=6]V:2!%;&EM:6YA=&DB"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E
M;&5T960N:6YC.C@*;7-G:60@(E!U<F=E($1E;&5T960B"FUS9W-T<B`B4FEM
M=6]V:2!%;&EM:6YA=&DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHR-`IM<V=I9"`B4'5R9V4@1F]L9&5R*',I(@IM<V=S='(@(E-V=6]T
M82!#87)T96QL82AE*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.38*
M;7-G:60@(E!U<F=E(%1R87-H(&AO=R!O9G1E;CHB"FUS9W-T<B`B3V=N:2!Q
M=6%N=&\@<W9U;W1A<F4@:6P@0V5S=&EN;SHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#`U"FUS9VED(")0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F
M;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*;7-G<W1R
M(")%;&EM:6YA(&D@;65S<V%G9VD@9&%L;&$@8V%R=&5L;&$@0V5S=&EN;R!P
M:?D@=F5C8VAI(&1I(&=I;W)N:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@V"FUS9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H
M(&9O;&1E<C\B"FUS9W-T<B`B16QI;6EN82!V96-C:&D@;65S<V%G9VD@;F5L
M;&$@8V%R=&5L;&$@0V5S=&EN;S\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S
M:R]P=7)G95]T<F%S:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N(@IM
M<V=S='(@(E-T;R!E;&EM:6YA;F1O("5D(&UE<W-A9V=I;RAI*2!D86P@0V5S
M=&EN;RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@
M5')A<V@@9F]L9&5R+B(*;7-G<W1R(")3=&\@96QI;6EN86YD;R`E9"!M97-S
M86=G:6\H:2D@9&%L($-E<W1I;F\N(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U
M;W1A+FEN8SHQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z
M("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"FUS9W-T<B`B4W1A='5S(%%U
M;W1A.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@H*(SH@=&5M<&QA=&5S
M+W%U;W1A+W%U;W1A+FEN8SHR,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R(")3
M=&%T=7,@455O=&$Z($YE<W,@3&EM:71E(@H*(SH@=&5M<&QA=&5S+W%U;W1A
M+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T
M=7,Z($Y/($Q)34E4(@IM<V=S='(@(E-T871U<R!156]T83H@3F5S<R!,:6UI
M=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")1=6]T:6YG("5F.B(*;7-G<W1R(")38W)I=F4B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#8*;7-G:60@
M(E)E7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(*;7-G<W1R(")2:6-H
M:65D:2!U;F$@0V]N9F5R;6$@9&D@0V]N<V5G;F$B"@HC.B!L:6(O4V5A<F-H
M+G!H<#HU,`IM<V=I9"`B4F5C96EV960@3VXB"FUS9W-T<B`B4FEC979U=&\@
M:6PB"@HC.B!L:6(O4V5A<F-H+G!H<#HU.`IM<V=I9"`B4F5C96EV960@4VEN
M8V4B"FUS9W-T<B`B4FEC979U=&\@9&%L(@H*(SH@;&EB+U-E87)C:"YP:'`Z
M-30*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM<V=S='(@(E)I8V5V=71O(%!R
M:6UA(&1E;"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(E)E:6YD:7)I7WIZ
M82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ
M-@IM<V=I9"`B4F5D:7)E8W0B"FUS9W-T<B`B4F5I;F1I<FEZ>F$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I
M<F5C="!-97-S86=E(@IM<V=S='(@(D-O;G-E9VYA(&EL($UE<W-A9V=I;R!A
M9"!U;B!A;'1R;R!I;F1I<FEZ>F\N(@H*(SH@8V]M<&]S92YP:'`Z-S@W"FUS
M9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B0V]N<V5G;F$@
M<75E<W1O($UE<W-A9V=I;R!A9"!U;B!A;'1R;R!I;F1I<FEZ>F\N(@H*(SH@
M8V]M<&]S92YP:'`Z.#0W"FUS9VED(")2961I<F5C=&EN9R!F86EL960N(@IM
M<V=S='(@(DQA(&-O;G-E9VYA(&1E;"!-97-S86=G:6\@860@=6X@86QT<F\@
M:6YD:7)I>GIO(&YO;B!H82!F=6YZ:6]N871O+B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4X,PIM<V=I9"`B4F5F<F5S:"(*;7-G<W1R
M(")!9V=I;W)N82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G
M:60@(E)E9G)E<V@@1F]L9&5R(%9I97=S.B(*;7-G<W1R(")!9V=I;W)N82!L
M)V5L96YC;R!D96QL82!C87)T96QL83HB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]H96%D+FEN8SHY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-`HC
M+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(D%G9VEO<FYA(%9I<W5A
M;&EZ>F%Z:6]N92(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C,*
M;7-G:60@(E)E;&]A9"!6:65W(@IM<V=S='(@(D%G9VEO<FYA(%9I<W5A;&EZ
M>F%Z:6]N92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C8@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM<V=I9"`B4F5M96UB97(@=&AE
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B4FEC;W)D82!L92!I
M;F9O<FUA>FEO;FD@;&EB97)O+V]C8W5P871O+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-SD*;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I97<B
M"FUS9W-T<B`B4FEC;W)D82!L)W5L=&EM82!V:7-U86QI>GIA>FEO;F4B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E
M;6]T92!-86EL8F]X.B(*;7-G<W1R(")#87-E;&QA(&1I(%!O<W1A(')E;6]T
M83HB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@
M(E)E;6]V92!&:65L9"!&<F]M(%-E87)C:"(*;7-G<W1R(")2:6UU;W9I(&EL
M(&-A;7!O(&1A;&QA(')I8V5R8V$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,#4*;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T
M<B`B16QI;6EN82!L82!S;W)G96YT92(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T
M<B`B4FEN;VUI;F$@0V%R=&5L;&$O92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#$*;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E
M9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B4FEN;VUI;F$@;&$@8V%R=&5L
M;&$@9&D@4&]S=&$@26YV:6%T82!A9"!I;FEZ:6\@;65S93\B"@HC.B!L:6(O
M1F]L9&5R+G!H<#HT-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@
M7"(E<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60B"FUS9W-T<B`B(@HB3F]T:69I8V$@9&$@<&%R=&4@9&5L('-E
M<G9E<CH@;F]N(.@@<W1A=&\@<&]S<VEB:6QE(&-A;6)I87)E(&EL(&YO;64@
M("!<(B5S(@HB7"(@8V]N(%PB)7-<(B`N("(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI
M<W0B"FUS9W-T<B`B4FES<&]N9&D@86QL82!,:7-T82(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET
M:#HB"FUS9W-T<B`B4V]S=&ET=6ES8VD@8V]N.B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L>2(*;7-G
M<W1R(")2:7-P;VYD:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS
M,3$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P.0IM<V=I9"`B4F5P;'D@
M4V5N="XB"FUS9W-T<B`B4FES<&]S=&$@26YV:6%T82(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@
M=&\@06QL(@IM<V=S='(@(E)I<W!O;F1I(&$@5'5T=&DB"@HC.B!C;VUP;W-E
M+G!H<#HW,S,*;7-G:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B4FES<&]N
M9&D@82!4=71T:3HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,3`*;7-G:60@(E)E<&QY('1O($QI<W0B"FUS9W-T<B`B4FES
M<&]N9&D@86QL82!,:7-T82(*"B,Z(&-O;7!O<V4N<&AP.C<S-0IM<V=I9"`B
M4F5P;'D@=&\@3&ES=#HB"FUS9W-T<B`B4FES<&]N9&D@86QL82!,:7-T83HB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*
M;7-G:60@(E)E<&QY('1O(%]!;&PB"FUS9W-T<B`B4FES<&]N9&D@82!?5'5T
M=&DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(X(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,S<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4T-PIM<V=I9"`B4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A
M9V4B"FUS9W-T<B`B4FES<&]N9&D@8V]N($UE<W-A9V=I;R!.;VX@4W5P<&]R
M=&%T;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S4*;7-G:60@
M(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G
M<W1R(")2:7-P;VYD:2!C;VX@;&EB97)O+V]C8W5P871O('!E<B!I('!R;W-S
M:6UI(#(@;65S:2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,T
M"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(E)I<W!O;F1I(&-O;B!L92!I;F9O<FUA>FEO;FD@
M;&EB97)O+V]C8W5P871O(')I8VAI97-T92(*"B,Z(&UE<W-A9V4N<&AP.C(V
M-PIM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`B4FES<&]N9&DM02(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HT,#D*;7-G:60@(E)E<&QY+51O.B`B"FUS9W-T<B`B
M4FES<&]N9&DM03H@(@H*(SH@8V]M<&]S92YP:'`Z-S,Q"FUS9VED(")297!L
M>3HB"FUS9W-T<B`B4FES<&]N9&DZ(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E;G0B"FUS9W-T<B`B
M4V5G;F%L82!C;VUE($YO;BU3<&%M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C,U('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C(S"FUS9VED(")297!O<G0@87,@4W!A;2(*;7-G<W1R(")396=N
M86QA(&-O;64@4W!A;2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,X,PIM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T
M<B`B4FEC:&EE9&D@=6YA(%)I8V5V=71A(&1I($QE='1U<F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y
M(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B4FEC:&EE9&D@=6YA(&-O;F9E<FUA
M(&1I(&-O;G-E9VYA/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S,*
M;7-G:60@(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T<B`B4FEC:&EE
M9&D@=6YA(')I8V5V=71A(&1I(&QE='1U<F$_(@H*(SH@;6%I;&)O>"YP:'`Z
M,3@Y"FUS9VED(")297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.3<*;7-G:60@
M(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(E!A<G1E8VEP86YT:2!2
M:6-H:65S=&\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C$V,0IM<V=I9"`B4F5S970B"FUS9W-T<B`B07IZ97)A(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-0IM<V=I9"`B4F5S<&]N
M9&5N="!3=&%T=7,@57!D871E9"XB"FUS9W-T<B`B4W1A=&\@9&5L(%)I<W!O
M;F1E;G1E($%G9VEO<FYA=&\N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T<B`B4F5C
M=7!E<F$B"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")297-U;64@>6]U
M<B!S97-S:6]N(@IM<V=S='(@(D-O;G1I;G5A(&QA('1U82!S97-S:6]N92(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT-`HC+"!F=7IZ
M>0IM<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM
M<V=S='(@(D-O;7!O<VEZ:6]N92!-97-S86=G:6\B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C,Q('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C
M8V]U;G1?<V5L96-T+FEN8SHS,@IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA
M:6PB"FUS9W-T<B`B4FET;W)N82!A(%-C87)I8V$@4&]S=&$B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O
M;F]T86-T:79E+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C$P,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E
M+FEN8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-S,*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM
M<V=S='(@(E1O<FYA(&%L;"=/<'II;VYI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW,3@*;7-G:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L
M:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M
M97-S86=E/R(*;7-G<W1R("(B"B)4;W)N82!A;&PG96QE;F-O(&1E:2!M97-S
M86=G:2!D;W!O(&%V97(@96QI;6EN871O+"!S<&]S=&%T;RP@;R!C;W!I871O
M('5N("(*(FUE<W-A9V=I;RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C@X"FUS9VED(")2;VQE(@IM<V=S='(@(E)U;VQO(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3D*;7-G
M:60@(E,O34E-12(*;7-G<W1R(")3+TU)344B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$R"FUS9VED(")3+TU)344@16YC<GEP
M="!-97-S86=E(@IM<V=S='(@(D-R:7!T82!M97-S86=G:6\@4R]-24U%(@H*
M(SH@8V]M<&]S92YP:'`Z,SDT"B,L(&9U>GIY"FUS9VED(")3+TU)344@17)R
M;W(Z("(*;7-G<W1R(")%<G)O<F4@4$=0.B`B"@HC.B!C;VUP;W-E+G!H<#HS
M-S,*;7-G:60@(E,O34E-12!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P
M97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B17)R;W)E(%,O34E-13H@
MZ"!N96-E<W-A<FEA(&QA('!A<F]L82!C:&EA=F4@<&5R(&QA(&-H:6%V92!P
M<FEV871A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3$*;7-G:60@
M(E,O34E-12!/<'1I;VYS(@IM<V=S='(@(D]P>FEO;FD@4R]-24U%(@H*(SH@
M<VUI;64N<&AP.C0Y"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*
M;7-G<W1R("));G!U="!087)O;&$@8VAI879E(%,O34E-12(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-30*;7-G:60@(E,O34E-12!097)S;VYA
M;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN(@IM<V=S='(@(B(*(DEL('-U<'!O<G1O(&1E;&QA(&-O<'!I82!D
M:2!C:&EA=FD@4R]-24U%(')I8VAI961E('5N82!C;VYN97-S:6]N92!S:6-U
M<F$N(@H*(SH@<VUI;64N<&AP.C$T,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S
M<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(DQA($-H:6%V92!0=6)B;&EC82!0
M1U`@<&5R(%PB)7-<(B#H('-T871A(&5L:6UI;F%T82!C;VX@<W5C8V5S<V\N
M(@H*(SH@<VUI;64N<&AP.C$V,@HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%!U
M8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")#;W!P:6$@
M9&D@8VAI879I('!U8F)L:6-A+W!R:79A=&$@4R]-24U%(&%G9VEU;G1A(&-O
M;B!S=6-C97-S;RXB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P
M"B,L(&9U>GIY"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T
M<B`B0VAI879E(%!U8F)L:6-A(%!'4"(*"B,Z('-M:6UE+G!H<#HR,3$*;7-G
M:60@(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL
M>2!A9&1E9"XB"FUS9W-T<B`B0V]P<&EA(&1I(&-H:6%V:2!P=6)B;&EC82]P
M<FEV871A(%,O34E-12!A9V=I=6YT82!C;VX@<W5C8V5S<V\N(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,PIM<V=I9"`B4R]-
M24U%(%-I9VX@365S<V%G92(*;7-G<W1R(")&:7)M82!-97-S86=G:6\@4R]-
M24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ
M-`IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@
M(D9I<FUA+T-R:7!T82!M97-S86=G:6\@4R]-24U%(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4R]-24U%('-U<'!O<G0@
M:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(DEL('-U<'!O
M<G1O(%,O34E-12#H(&1I<V%B:6QI=&%T;R!S=6P@<VES=&5M82XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%
M('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S
M86=E(&ES('5N86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(B(*
M(DEL('-U<'!O<G1O(%,O34E-12!N;VX@Z"!A8FEL:71A=&\L('!E<G1A;G1O
M(&EL(&UE<W-A9V=I;R!N;VX@<'7R(&5S<V5R92`B"B)D96-R:7!T871O+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<S"B,L(&9U>GIY"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@
M8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S<V%G92!C86X@;F]T("(*(F)E
M(&1I<W!L87EE9"XB"FUS9W-T<B`B(@HB26P@<W5P<&]R=&\@4R]-24U%(&YO
M;B#H(&%B:6QI=&%T;RP@<&5R=&%N=&\@;&$@9FER;6$@9&EG:71A;&4@;F]N
M('!U\B`B"B)E<W-E<F4@=F5R:69I8V%T82XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C$T-@IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@
M;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L
M92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB26P@<W5P<&]R=&\@
M4R]-24U%(&YO;B#H(&%B:6QI=&%T;RP@<&5R=&%N=&\@;&$@9FER;6$@9&EG
M:71A;&4@;F]N('!U\B`B"B)E<W-E<F4@=F5R:69I8V%T82XB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(RP@9G5Z>GD*;7-G:60@(B(*(E,O
M34E-12!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E
M9"X@($EF('EO=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I
M<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T
M=&EN9R!O<B!E;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@
M=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(DEL('-U<'!O<G1O(%!'4"!N
M96-E<W-I=&$@9&D@=71L:7IZ87)E(&9I;F5S=')E('!O<'5P+B!392!I;"!T
M=6\@8G)O=W-E<B#H("(*(G-E='1A=&\@<&5R(&YO;B!U=&EL:7IZ87)E(&9I
M;F5S=')E('!O<'5P+"!D979I(&UO9&EF:6-A<F4@;&4@:6UP;W-T87II;VYI
M("(*(F1E;"!B<F]W<V5R(&\@;&4@9G5N>FEO;FD@4$=0(&YO;B!F=6YZ:6]N
M97)A;FYO(&-O<G)E='1A;65N=&4B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(P-0IM<V=I9"`B4TU44"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-34*;7-G:60@(E-?=6)J96-T(@IM
M<V=S='(@(D]?9V=E='1O(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S8S"FUS9VED(")385]V92!A(&-O<'D@:6X@(@IM<V=S='(@(E-A
M;%]V82!U;F$@8V]P:6$@:6X@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")385]V92!A<R(*;7-G<W1R(")3
M86Q?=F$@8V]N($YO;64B"@HC.B!S96%R8V@N<&AP.C,Q-B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*;7-G:60@(E-A=F4B"FUS9W-T<B`B
M4V%L=F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S@*
M;7-G:60@(E-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M
M;6%I;"!F;VQD97(_(@IM<V=S='(@(E-A;'9A($%L;&5G871I(&-O;B!M97-S
M86=G:6\@;F5L;&$@8V%R=&5L;&$@<V5N="UM86EL(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#,S"FUS9VED(")3879E($1R869T(@IM<V=S='(@(E-A;'9A
M($)O>GIA(@H*(SH@<V%V96EM86=E+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B
M4V%V92!);6%G92(*;7-G<W1R(")386QV82!C;VX@3F]M92(*"B,Z(&QI8B]-
M24U%+T-O;G1E;G1S+G!H<#HR,#0*;7-G:60@(E-A=F4@26UA9V4@:6X@1V%L
M;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z-3D@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#`*(SH@=&5M<&QA
M=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,3(@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$T.`HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,3,*;7-G
M:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")386QV82!/<'II;VYI(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"B,L(&9U>GIY"FUS
M9VED(")3879E(%-T871I;VYE<GDB"FUS9W-T<B`B4V%L=F$@3W!Z:6]N:2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PIM<V=I9"`B4V%V92!?1')A9G0B
M"FUS9W-T<B`B4V%L=F$@;&$@7T)O>GIA(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")3879E(&%S(@IM<V=S
M='(@(E-A;'9A(&-O;B!.;VUE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R(")3
M86QV82!L92!B;WIZ92!C;VUE(&YO;B!V:7-T93\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`W,@IM<V=I9"`B4V%V92!R96-I<&EE;G1S(&%U=&]M
M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K/R(*;7-G<W1R
M(")386QV92!I(&1E<W1I;F%T87)I(&%U=&]M871I8V%M96YT92!A;&QA(')U
M8G)I8V$@9&5F875L=#\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@87,@82!V:7)T=6%L(&9O;&1E<C\B
M"FUS9W-T<B`B4V%L=F$@;&$@<FEC97)C82!C;VUE('5N82!C87)T96QL82!V
M:7)T=6%L93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED
M(")3879E('-E;G0@;6%I;#\B"FUS9W-T<B`B4V%L=F$@<&]S=&$@:6YV:6%T
M83\B"@HC.B!C;VUP;W-E+G!H<#HQ,C(W"B,L('!H<"UF;W)M870*;7-G:60@
M(E-A=FEN9R!T:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`E<R(*;7-G<W1R(").;VX@Z"!S=&%T;R!P;W-S:6)I;&4@
M<V%L=F%R92!L82!B;WIZ82X@0V]D:6-E(&1E;"!S97)V97(Z("5S(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA=&5S
M+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F;VQD
M97)S+G!H<#HT,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E)I0V5R8V$B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R
M8V@@)7,B"FUS9W-T<B`B4FEC97)C82`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!/<'1I;VYS(@IM
M<V=S='(@(E-A;'9A($]P>FEO;FDB"@HC.B!S96%R8V@N<&AP.C(V-0IM<V=I
M9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B4FES=6QT871I(&1E;&QA(%)I
M8V5R8V$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$T('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E96XB"FUS
M9W-T<B`B5FES=&\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.CD*;7-G:60@(E-E;&5C="(*;7-G<W1R(")396QE>FEO;F$B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-S`*;7-G:60@(E-E;&5C="!!
M;F]T:&5R($%C8V]U;G0B"FUS9W-T<B`B4V5L97II;VYA('5N)T%L=')O($%C
M8V]U;G0B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G
M:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L97II;VYA('5N82!D871A
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P"FUS9VED(")3
M96QE8W0@82!F:65L9"(*;7-G<W1R(")396QE>FEO;F$@=6X@8V%M<&\B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@(E-E;&5Z:6]N
M82!U;F$@9&%T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G
M:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N
M9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`B4V5L97II;VYA
M(&QE(&9O;G1I(&1E;&QA(')U8G)I8V$@<&5R(&%G9VEU;F=E<F4@92!C97)C
M87)E(&EN9&ER:7IZ:2XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C@X"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E-E;&5Z:6]N82!T=71T
M;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM
M<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD
M:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB4V-E9VQI(&PG;W)D:6YE(&EN
M(&-U:2!R:6-E<F-A<F4@;&4@<G5B<FEC:&4@<75A;F1O(&5S<&%N9&D@9VQI
M(&EN9&ER:7IZ:2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S
M96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R
M(")396QE>FEO;F$@=6XG86-C;W5N="(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(D1E<V5L
M97II;VYA('1U='1O+B(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM
M86=E+FEN8SHY"FUS9VED(")396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T
M:&4@:6UA9V4@:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I
M;"!S97)V97(@='EP92(*;7-G<W1R(")396QE>FEO;F$@=6X@=&EP;R!D:2!S
M97)V97(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M,#D*;7-G:60@(E-E;&5C=&5D($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(E)U
M8G)I8VAE(%-E;&5Z:6]N871E.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G
M<W1R("));G9I82!C:&EA=F4@86P@<V5R=F5R('!U8F)L:6-O(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8P-`IM<V=I9"`B4V5N9"!,871E<W0@
M26YF;W)M871I;VXB"FUS9W-T<B`B04EN=FEA(%5L=&EM92!);F9O<FUA>FEO
M;FDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S$*;7-G:60@(E-E;F0@365S
M<V%G92(*;7-G<W1R("));G9I82!-97-S86=G:6\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S`S"FUS9VED(")396YD(')E860@<F5C96EP="!W:&5N
M(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HS.3<*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B
M0V%R=&5L;&$@9&D@<&]S=&$@:6YV:6%T82(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S96YT;6%I;'-E;&5C="YI;F,Z,S@*;7-G:60@(E-E;G0@;6%I;"!F;VQD
M97(Z(@IM<V=S='(@(D-A<G1E;&QA(&1I('!O<W1A(&EN=FEA=&$B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S,B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$T-@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$U
M,PIM<V=I9"`B4V5R=F5R(@IM<V=S='(@(E-E<G9E<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,PIM<V=I9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF
M;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87II;VYI('-U;"!397)V97(@92!#
M87)T96QL82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR
M,PIM<V=I9"`B4V5R=F5R.B(*;7-G<W1R(")397)V97(Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@<')E9F5R96YC97,@9F]R
M('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G
M97,N(@IM<V=S='(@(B(*(DEM<&]S=&$@;&4@87II;VYI(&1A(&5S96=U:7)E
M('%U86YD;R!S:2!S<&]S=&%N;R!O(&5L:6UI;F%N;R!I(&UE<W-A9V=I+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@
M6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM
M<V=S='(@(D-O;F9I9W5R82!L)VEN=&5S=&%Z:6]N92!8+5!R:6]R:71Y('%U
M86YD;R!I;G9I:2!M97-S86=G:6\_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Q"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(D-O;F1I=FED
M:2!#87)T96QL92(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@IM<V=I
M9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(D-O;F1I=FED:2!C87)T
M96QL92!D:2!P;W-T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM
M<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R
M<RXB"FUS9W-T<B`B0V]N9&EV:61I(&QA(&-A<G1E;&QA(&1I('!O<W1A(&-O
M;B!A;'1R:2!U=&5N=&DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V
M.0IM<V=I9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X
M="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E("(*
M(G1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM<V=I9"`B4VAO=6QD
M('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F
M;W(@4$=0(&1A=&$_(@IM<V=S='(@(DEL(&-O<G!O(&1E:2!M97-S86=G:2!D
M:2!T97-T;R!D979E(&5S<V5R92!C;VYT<F]L;&%T;R!P97(@9&%T:2!01U`_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B4VAO=6QD
M('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@
M9')A9G0_(@IM<V=S='(@(D-H:75D:2!L82!F:6YE<W1R82!#;VUP;VYI(&1O
M<&\@879E<B!S86QV871O('5N82!";WIZ82XB"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-`IM<V=I9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@
M=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*
M;7-G<W1R("(B"B),82!T=6$@8VAI879E(%!'4"!P=6)B;&EC82!D979E(&5S
M<V5R92!A;&QE9V%T82!A:2!M97-S86=G:2!D:2!D969A=6QT/R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@(E-H
M;W<@06QL($9O;&1E<G,B"FUS9W-T<B`B36]S=')A('1U='1E(&QE($EN=&5S
M=&%Z:6]N:2(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8W
M"FUS9VED(")3:&]W($%L;"!(96%D97)S(@IM<V=S='(@(DUO<W1R82!T=71T
M92!L92!);G1E<W1A>FEO;FDB"@HC.B!M86EL8F]X+G!H<#HS-C4*;7-G:60@
M(E-H;W<@1&5L971E9"(*;7-G<W1R(")-;W-T<F$@16QI;6EN871I(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*;7-G:60@(E-H;W<@
M3&EM:71E9"!(96%D97)S(@IM<V=S='(@(DUO<W1R82!);G1E<W1A>FEO;FD@
M3&EM:71A=&4B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW
M,`IM<V=I9"`B4VAO=R!-86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T
M<B`B36]S=')A($EN9F]M87II;VYI(&1E;&QA($UA:6QI;F<@3&ES="(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B4V]T=&]S
M8W)I=FD@82!#87)T96QL82]E(@H*(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED
M(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")-;W-T<F$@:2!.;VX@<V]T
M=&]S8W)I='1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P.`IM<V=I
M9"`B4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM
M96YT<R!F<F]M(&UE<W-A9V5S/R(*;7-G<W1R(")-;W-T<F$@=6XG:6-O;F$@
M<&5R('!E<FUE='1E<F4@;&\@<W1R:7!P:6YG(&1E9VQI(&%L;&5G871I/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`R"FUS9VED(")3:&]W(&QE
M9V5N9"!I;B!T:&4@;6%I;&)O>"!V:65W/R(*;7-G<W1R(")-;W-T<F$@;&$@
M;&5G96YD82!D96D@8V]L;W)I(&YE;&QA('9I<W5A;&EZ>F%Z:6]N92!D96QL
M82!C87)T96QL82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0P"FUS
M9VED(")3:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\B
M"FUS9W-T<B`B36]S=')A(&%N=&5P<FEM82!S;VQO('!E<B!M97-S86=G:2!N
M;VX@;&5T=&D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T.`IM<V=I
M9"`B4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\B"FUS9W-T<B`B36]S=')A
M('!R979I97<@:6X@=&]O;'1I<',_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@W-PIM<V=I9"`B4VAO=R!T:&4@1F5T8V@@36%I;"!I8V]N(&]N('1H
M92!M96YU8F%R/R(*;7-G<W1R(")-;W-T<F$@;"=I8V]N82!&971C:"!-86EL
M(&YE;&QA(&)A<G)A(&UE;G4_(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.CDU"FUS9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B36]S=')A
M(&QE($EM;6%G:6YI(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C4T"FUS9VED(")3:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A
M<C\B"FUS9W-T<B`B36]S=')A(&PG:6-O;F$@9&D@9FEL=')O(&YE;&QA(&)A
M<G)A(&UE;G4_(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(X"FUS9VED
M(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S
M='(@(DUO<W1R82!I;"!N=6UE<F\@=&]T86QE(&1I(&UE<W-A9VD@;F5L;&$@
M8V%R=&5L;&$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-@IM<V=I
M9"`B4VAO=VXB"FUS9W-T<B`B36]S=')A(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHT,@IM<V=I9"`B4VE?>F4B"FUS9W-T
M<B`B1&E?;65N<VEO;F4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N
M:6YC.C$W"B,L(&9U>GIY"FUS9VED(")3:6=N960B"FUS9W-T<B`B1&EM96YS
M:6]N92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS
M"FUS9VED(")3:7IE(@IM<V=S='(@(D1I;65N<VEO;F4B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3;W)T
M(&)Y($%R<FEV86PB"FUS9W-T<B`B3W)D:6YA('!E<B!!<G)I=F\B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$V"FUS9VED
M(")3;W)T(&)Y($1A=&4B"FUS9W-T<B`B3W)D:6YA('!E<B!$871A(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR-@IM<V=I
M9"`B4V]R="!B>2!&<F]M($%D9')E<W,B"FUS9W-T<B`B3W)D:6YA('!E<B!-
M:71T96YT92(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z-#$*;7-G:60@(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@
M(D]R9&EN82!P97(@1&EM96YS:6]N92!-97-S86=G:6\B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,V"FUS9VED(")3;W)T
M(&)Y(%-U8FIE8W0B"FUS9W-T<B`B3W)D:6YA('!E<B!/9V=E='1O(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,0IM<V=I
M9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B3W)D:6YA('!E<B!4:')E860B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q
M"FUS9VED(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`B3W)D:6YA('!E
M<B!$97-T:6YA=&%R:6\B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z,C,*;7-G:60@(E-P86T@9F]L9&5R.B(*;7-G<W1R(")#87)T96QL
M82!P<&%M.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T
M-@IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97)S(@IM<V=S='(@(D-A<F%T=&5R
M:2!3<&5C:6%L:2(*"B,Z('-E87)C:"YP:'`Z,3,S"FUS9VED(")3<&5C:6%L
M(%9I<G1U86P@1F]L9&5R<R!C86X@;F]T(&)E(&5D:71E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0S"B,L(&9U
M>GIY"FUS9VED(")3<&5L;"!#:&5C:R(*;7-G<W1R(")#;VYT<F]L;&\@3W)T
M;V=R85]F:6-O(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C0V"FUS9VED(")3<&5L;"!#:&5C:V5R(@IM<V=S='(@(D-O;G1R;VQL;R!/
M<G1O9W)A9FEC;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@
M(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@(D-O;G1R;VQL;R!O<G1O
M9W)A9FEC;R!C;VUP;&5T871O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0W,0IM<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S
M<&5L;"!C:&5C:VEN9RXB"FUS9W-T<B`B3G5M97)O(&1I(&5R<F]R:2!O<G1O
M9W)A9FEC:2!P97(@;V=N:2!S8VAE<FUA=&$N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4Q,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4R
M"FUS9VED(")3=&%R="(*;7-G<W1R(")!=G9I;R(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I
M;VYE<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM
M<V=I9"`B4W1A=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871I
M<R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*;7-G:60@(E-T<FEP
M($%T=&%C:&UE;G0B"FUS9W-T<B`B4W1R:7!P82!!;&QE9V%T;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A
M:W,_(@IM<V=S='(@(D5L:6UI;F$@26YT97)R=7II;VYI(&1I($QI;F5A/R(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*
M;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(D]?9V=E='1O(@H*(SH@;65S<V%G
M92YP:'`Z,C8X('1H<F5A9"YP:'`Z,34P('1E;7!L871E<R]C;VUP;W-E+W)E
M8V]M<&]S92YI;F,Z,C4*(SH@;&EB+U-E87)C:"YP:'`Z,S@*;7-G:60@(E-U
M8FIE8W0B"FUS9W-T<B`B3V=G971T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,C`*;7-G:60@(E-U8FIE8W0@1FEE;&0B"FUS9W-T<B`B0V%M<&\@
M3V=G971T;R(*"B,Z('-E87)C:"YP:'`Z,S$X('1E;7!L871E<R]S879E:6UA
M9V4O<V%V96EM86=E+FEN8SHQ.`HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H
M<F%S92YI;F,Z,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,0IM
M<V=I9"`B4W5B;6ET(@IM<V=S='(@(DEN=FEO(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,3$*;7-G:60@(E-U8G-C<FEB92!T;R!&;VQD
M97(H<RDB"FUS9W-T<B`B4V]T=&]S8W)I=FD@82!#87)T96QL82]E(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#`@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@W
M"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U8V-E<W-O(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N
M<R(*;7-G<W1R(")3=6=G97)I;65N=&DB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C8R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G
M:60@(E-U;6UA<GDB"FUS9W-T<B`B0G)E=F4@4FEA<W-U;G1O(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`P('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0P,PIM<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N
M($UE=&AO9"(*;7-G<W1R(")-;V1I9FEC82!-971O9&\@9&D@0V]M<&]S:7II
M;VYE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS
M9VED(")3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R(")686D@
M82!C;VUP;W-I>FEO;F4@2%1-3"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O('!L86EN('1E>'0@8V]M
M<&]S:71I;VXB"FUS9W-T<B`B5F%I(&$@8V]M<&]S:7II;VYE('-O;&\@=&5S
M=&\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,3D*;7-G
M:60@(E1E7WAT(@IM<V=S='(@(E1E7W-T;R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@(E1E;G1A=&EV93H@(@IM
M<V=S='(@(D%C8V5T=&%T;R!P<F]V:7-S;W)I86UE;G1E+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A=&EV96QY($%C
M8V5P="!R97%U97-T(@IM<V=S='(@(E)I8VAI97-T82!D:2!A8V-E='1A>FEO
M;F4@<')O=G9I<V]R:6$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S8Q"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R(")!8V-E
M='1A=&\@<')O=FES<V]R:6%M96YT92XB"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]T;W-?86=R965M96YT+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")497)M<R!O9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF
M+G!H<"(*;7-G<W1R(")&:6QE(&1E:2!497)M:6YI(&0G571I;&EZ>F\@;F]N
M('-P96-I9FEC871O(&EN(&-O;F8N<&AP(@H*(SH@=&5M<&QA=&5S+W-T871I
M;VYE<GDO<')E9G,N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")497AT(@IM<V=S
M='(@(E1E7W-T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-30*;7-G
M:60@(E1H92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E
M(&QI;FME9#HB"FUS9W-T<B`B3&$@8V]L;VYN82!$83H@9&5L(&UE<W-A9V=I
M;R!D979E(&5S<V5R92!C;VQL96=A=&$Z(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HU,S(*;7-G:60@(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A
M<'!E87(@=&\@<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*
M(G-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D
M;W5B;&4N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")4:&4@36%C:6YT;W-H(')E
M<V]U<F-E(&9O<FLB"FUS9W-T<B`B26P@9FEL92!O<FEG:6YA;&4@<'5O)R!E
M<W-E<F4@<V-A<FEC871O("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L
M961O=6)L92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($UA8VEN
M=&]S:"!R97-O=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S+B(*;7-G
M<W1R("));"!F:6QE(&]R:6=I;F%L92!P=6\G(&5S<V5R92!S8V%R:6-A=&\@
M)7,N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("),)R!A8V-O=6YT(%PB)7-<(B#H('-T871O(&5L:6UI;F%T;RXB
M"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R
M("),)V%C8V]U;G0@7"(E<UPB(.@@<W1A=&\@<V%L=F%T;RXB"@HC.B!A='1A
M8VAM96YT+G!H<#HT,PIM<V=I9"`B5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F
M;W5N9"XB"FUS9W-T<B`B3"=A;&QE9V%T;R!N;VX@Z"!S=&%T;R!T<F]V871O
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R("(\
M8CY)(&1A=&D@9&D@8V%L;F5D87)I;R!N;VX@<V]N;R!V86QI9&D\+V(^(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS
M-PIM<V=I9"`B(@HB5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE
M9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L
M;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*(DQA(&9I;F5S=')A(&1I
M(&-O;7!O<VEZ:6]N92!N;VX@<'7R(&5S<V5R92!A<&5R=&$N(%!R;V)A8FEL
M;65N=&4@:6P@='5O("(*(F)R;W=S97(@Z"!I;7!O<W1A=&\@<&5R(&)L;V-C
M87)E(&D@<&]P=7`B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N
M<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S:"!F
M:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B4V5G=6]N;R!S;W1T;R!I(&-O;G1E
M;G5T:2!D96P@9FEL92!-86-I;G1O<V@N(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C@W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!C=7)R96YT(&9O;&1E<BAS*2!<(B5S7"(@=VEL
M;"!B92!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B3&$@8V%R=&5L;&$@
M7"(E<UPB('9E<G+@(')I;F]M:6YA=&$@:6X@7"(E<UPB+B(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ,#<*;7-G:60@(B(*(E1H92!C=7)R96YT(&QI
M<W0@;V8@=7-E<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@
M;F]T(&)E(')E=')I979E9"(*;7-G<W1R("(B"B),82!L:7-T82!D96=L:2!U
M=&5N=&D@8V]N(&%C8V5S<V\@82!Q=65S=&$@8V%R=&5L;&$@;F]N(.@@<W1A
M=&$@;W1T96YU=&$B"@HC.B!C;VUP;W-E+G!H<#HQ,C,V"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@7"(E
M<UPB(&9O;&1E<BXB"FUS9W-T<B`B3&$@8F]Z>F$@Z"!S=&%T82!S86QV871A
M(&YE;&QA(&-A<G1E;&QA(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3,Y"FUS9VED(")4:&4@979E;G0@=V%S(&%D9&5D('1O('EO
M=7(@8V%L96YD87(N(@IM<V=S='(@(DPG979E;G1O(.@@<W1A=&\@86=G:75N
M=&\@86P@='5O(&-A;&5N9&%R:6\N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M97AP86YD+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*;7-G<W1R("));"!C
M86UP;R`G)7,G(&YO;B!P=?(@97-S97)E(&5S<&%N<V\N(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,S,W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DQA(&-A<G1E;&QA(%PB
M)7-<(B!E<VES=&4@9VG@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS
M(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E
M("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(DEL(&YO;64@9&5L;&$@8V%R=&5L;&$@7"(E
M<UPB(&-O;G1I96YE(&-A<F%T=&5R:2!N;VX@=F%L:61I+B!0;W1R96)B92`B
M"B)C875S87)E('!R;V)L96UI+B!#;VYT871T82!L)V%M;6EN:7-T<F%T;W)E
M(&1I('-I<W1E;6$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4V"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U
M="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B3&$@
M8V%R=&5L;&$@7"(E<UPB(.@@<W1A=&$@8W)E871A(&UA(&YO;B#H('-T871A
M('-O='1O<V-R:71T82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@
M8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T
M<B`B(@HB3&$@8V%R=&5L;&$@7"(E<UPB(.@@<W1A=&$@8V%N8V5L;&%T82!M
M82!N;VX@Z"!S=&%T82!A;FYU;&QA=&$@;&$@(@HB<V]T=&]S8W)I>FEO;F4N
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B),82!C87)T96QL82!<
M(B5S7"(@;F]N(.@@<W1A=&$@8W)E871A+B!1=65S=&\@Z"!I;"!M97-S86=G
M:6\@9&5L('-E<G9E<B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(V-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO
M="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(B(*(DQA(&-A<G1E;&QA(%PB)7-<(B!N;VX@Z"!S=&%T82!E;&EM:6YA
M=&$N(%%U97-T;R#H(&EL(&UE<W-A9V=I;R!D96P@<V5R=F5R(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,S4Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B
M3&$@8V%R=&5L;&$@7"(E<UPB(.@@<W1A=&$@8W)E871A(&-O;B!S=6-C97-S
M;RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D
M+B(*;7-G<W1R("),82!C87)T96QL82!<(B5S7"(@Z"!S=&%T82!E;&EM:6YA
M=&$@8V]N('-U8V-E<W-O+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0U,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S
M<V9U;&QY(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("),82!C87)T96QL
M82!<(B5S7"(@Z"!S=&%T82!R:6YO;6EN871A(&EN(%PB)7-<(BXB"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I
M;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?<V%V96EM86=E7W=I
M;BYJ<SHQ,@HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN
M9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y
M;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T
M<B`B(@HB3&$@9FEN97-T<F$@9&D@8V]M<&]S:7II;VYE(&YO;B!P=?(@97-S
M97)E(&%P97)T82X@4')O8F%B:6QM96YT92!I;"!T=6\@(@HB8G)O=W-E<B#H
M(&EM<&]S=&%T;R!P97(@8FQO8V-A<F4@:2!P;W!U<"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL
M(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I
M;B!Y;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R("(B"B),92!I;6UA9VEN
M:2!S87)A;FYO(&UO<W1R871E('!E<F-HZ2!I;"!M:71T96YT92!S:2!T<F]V
M82!N96QL82!T=6$@<G5B<FEC82XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T
M:&4@9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(DEL('-E<G9E
M<B!D:2!P;W-T82!H82!G96YE<F%T;R!I;"!S96=U96YT92!M97-S86=G:6\@
M9&D@97)R;W)E.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN
M<&AP.C4Q"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F
M;VQL;W=I;F<@:6YF;W)M871I;VYA;"!M97-S86=E.B(*;7-G<W1R("));"!S
M97)V97(@9&D@<&]S=&$@:&$@9V5N97)A=&\@:6P@<V5G=65N=&4@;65S<V%G
M9VEO(&1I(&EN9F]R;6%Z:6]N93HB"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T
M:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(DEL('-E<G9E<B!D:2!P
M;W-T82!H82!G96YE<F%T;R!I;"!S96=U96YT92!M97-S86=G:6\Z(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R("),82!C87)T
M96QL82!<(B5S7"(@Z"!G:>`@=G5O=&$N(@H*(SH@;&EB+T9E=&-H;6%I;"YP
M:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(%PB)7-<
M(B!F<F]M(%PB)7-<(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ92!L
M:6UI="XB"FUS9W-T<B`B(@HB26P@;65S<V%G9VEO(%PB)7-<(B!D82!<(B5S
M7"(@*"5D(&)Y=&5S*2!S=7!E<F$@:6P@;&EM:71E(&1I(&1I;65N<VEO;F4B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PIM<V=I
M9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D
M+B!%>&ET:6YG+B(*;7-G<W1R("));"!M97-S86=G:6\@:6X@8V]M<&]S:7II
M;VYE(.@@<W1A=&\@8VAI=7-O+B!);B!U<V-I=&$N(@H*(SH@;65S<V%G92YP
M:'`Z,30X"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("));"!M97-S86=G:6\@Z"!S=&%T;R!E;&EM:6YA=&\N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDS"FUS9VED(")4:&4@;65S<V%G
M92!H87,@8F5E;B!V97)I9FEE9"XB"FUS9W-T<B`B26P@;65S<V%G9VEO(.@@
M<W1A=&\@=F5R:69I8V%T;RXB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C,X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A
M9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@)7,N(@IM<V=S='(@(DEL
M(&UE<W-A9V=I;R#H('-T871O('9E<FEF:6-A=&\N(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+V]P96Y?<VUI;65?=VEN+FIS.C$P('1E;7!L871E<R]P9W`O;W!E
M;E]P9W!?=VEN+FIS.C$P"FUS9VED("(B"B)4:&4@<&%S<W!H<F%S92!W:6YD
M;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R
M(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B
M(@HB3&$@9FEN97-T<F$@9&D@875T96YT:6-A>FEO;F4@;F]N('!U\B!E<W-E
M<F4@87!E<G1A+B!0<F]B86)I;&UE;G1E(&EL('1U;R`B"B)B<F]W<V5R(.@@
M:6UP;W-T871O('!E<B!B;&]C8V%R92!I('!O<'5P(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!R
M87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B26P@=&5S=&\@9&5L;&$@0VAI879E(%!'4"!0=6)B;&EC
M82!P=?(@97-S97)E('9I<W1O("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T
M;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T
M(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(DEL
M(&9I;&4@<FEC:&EE<W1O(&YO;B!E<VES=&4@;F5L;"=A;&5G871O($U3+51.
M148N(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G:60@(E1H
M92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T
M=&%C:&UE;G0N(@IM<V=S='(@(DEL(&9I;&4@<FEC:&EE<W1O(&YO;B!E<VES
M=&4@;F5L;"=A;&QE9V%T;R!Z:7`N(@H*(SH@;65S<V%G92YP:'`Z-30W"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI<R!M97-S
M86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF
M:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M
M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB;F]T:69I
M8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")4:&4@<V5R=F5R('=A
M<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G
M92XB"FUS9W-T<B`B:4-L:6-C82`E<R!P97(@=F5D97)E(&EL('1H=6UB;F%I
M;"!D:2!Q=65S=&$@:6UM86=I;F4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FIS.C$P-`IM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L9"!N;W0@
M8F4@<F5P;&%C960N(@IM<V=S='(@(DYO;B!E<F$@<&]S<VEB:6QE('-O<W1I
M='5I<F4@;&$@9FER;6$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YJ<SHQ,#(*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL
M>2!R97!L86-E9"XB"FUS9W-T<B`B3&$@9FER;6$@Z"!S=&%T82!S;W-T:71U
M:71A(&-O;B!S=6-C97-S;RXB"@HC.B!A='1A8VAM96YT+G!H<#HU.0IM<V=I
M9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M("));"!F:6QE('-P96-I9FEC871O(&YO;B!E<VES=&4N(@H*(SH@<W1A=&EO
M;F5R>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S
M=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T<B`B3"=A
M8V-O=6YT(%PB)7-<(B#H('-T871O('-A;'9A=&\N(@H*(SH@<W1A=&EO;F5R
M>2YP:'`Z-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T
M:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),)R!A
M8V-O=6YT(%PB)7-<(B#H('-T871O(&5L:6UI;F%T;RXB"@HC.B!S=&%T:6]N
M97)Y+G!H<#HX-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T
M871I;VYE<GD@7"(E<UPB(&AA<R!B965N('5P9&%T960N(@IM<V=S='(@(DPG
M(&%C8V]U;G0@7"(E<UPB(.@@<W1A=&\@96QI;6EN871O+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ-CD*;7-G:60@(E1H92!T87-K(&AA<R!B
M965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(DPG871T:79I
M=.`@Z"!S=&%T82!A9V=I=6YT82!N96QL82!T=6$@=&%S:VQI<W0N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G:60@(E1H92!T97AT
M(&]F('1H92!M97-S86=E(@IM<V=S='(@(E1E<W1O(&1E;"!M97-S86=G:6\B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("));"!T97-T;R!D96P@;65S<V%G9VEO('!U;R<@
M97-S97)E('9I<W1O("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C@P"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G
M92(*;7-G<W1R(")497-T;R!D96P@;65S<V%G9VEO(')E<W1I='5I=&\B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@
M8F4@=FEE=V5D("5S+B(*;7-G<W1R("));"!T97-T;R!D96P@;65S<V%G9VEO
M(')E<W1I='5I=&\@<'7R(&5S<V5R92!V:7-T;R`E<RXB"@HC.B!L:6(O34E-
M12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`IM<V=I9"`B5&AE('1E>'0@
M;V8@=&AE('-E;G0@;65S<V%G92(*;7-G<W1R(")497-T;R!D96P@;65S<V%G
M9VEO(&EN=FEA=&\B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@
M<V5N="!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(DEL('1E
M<W1O(&1E;"!M97-S86=G:6\@:6YV:6%T;R!P=?(@97-S97)E('9I<W1O("5S
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-30*;7-G:60@(E1H
M92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL
M>2!S=&]R960N(@IM<V=S='(@(DEN9F]R;6%Z:6]N:2!L:6)E<F\O;V-C=7!A
M=&\@9&5L;"=U=&5N=&4@<V%L=F%T92!C;VX@<W5C8V5S<V\N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM<V=I9"`B5&AE<F4@
M87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(DYO;B!C:2!S;VYO('!O<GII;VYI(&%L=&5R
M;F%T:79E(&-H92!P;W-S;VYO(&5S<V5R92!M;W-T<F%T92!I;FQI;F4N(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z,PIM<V=I
M9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"XB"FUS
M9W-T<B`B3F]N(&-I('-O;F\@;65S<V%G9VD@:6X@<75E<W1A(&-A<V5L;&$@
M9&D@<&]S=&$N(@H*(SH@=&AR96%D+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@
M(E1H97)E(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92XB"FUS9W-T<B`B3F]N(&-I('-O;F\@<&]R>FEO;FD@86QT97)N871I=F4@
M8VAE('!O<W-O;F\@97-S97)E(&UO<W1R871E(&EN;&EN92XB"@HC.B!L:6(O
M365S<V%G92YP:'`Z-C$R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(B(*(E-I(.@@=F5R:69I8V%T;R!U;B!E<G)O
M<F4@;F5L;"=E;&EM:6YA>FEO;F4@9&D@)7,N(%%U97-T;R#H(&EL(&UE<W-A
M9V=I;R!D96P@(@HB<V5R=F5R(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N
M9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R
M("(B"B)3:2#H('9E<FEF:6-A=&\@=6X@97)R;W)E(&YE;&QA(&5L:6UI;F%Z
M:6]N92!D96QL82!C87-E;&QA(&1I('!O<W1A+B!1=65S=&\@(@HBZ"!I;"!M
M97-S86=G:6\@9&5L('-E<G9E<CH@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-C(Q"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@
M;6%I;&)O>"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R
M("(B"B)3:2#H('9E<FEF:6-A=&\@=6X@97)R;W)E(&YE;&QA(&5L:6UI;F%Z
M:6]N92!D96QL82!C87-E;&QA(&1I('!O<W1A+B!1=65S=&\@(@HBZ"!I;"!M
M97-S86=G:6\@9&5L('-E<G9E<B(*"B,Z(&QI8B]-97-S86=E+G!H<#HY,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@8V]P
M>6EN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@
M=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB4VD@Z"!V97)I
M9FEC871O('5N(&5R<F]R92!N96P@8V]P:6%R92!I(&UE<W-A9V=I(&1A(%PB
M)7-<(B!A(%PB)7-<(BX@475E<W1O("(*(N@@:6P@;65S<V%G9VEO(&1E;"!S
M97)V97(B"@HC.B!L:6(O365S<V%G92YP:'`Z,3DX(&QI8B]-97-S86=E+G!H
M<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB
M4VD@Z"!V97)I9FEC871O('5N(&5R<F]R92!N96QL)V5L:6UI;F%Z:6]N92!D
M96D@9FEL97,@9&%L;&$@8V%R=&5L;&$@7"(E<UPB+B`B"B)1=65S=&\@Z"!I
M;"!M97-S86=G:6\@9&5L('-E<G9E<B(*"B,Z(&QI8B]-97-S86=E+G!H<#HR
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES
M(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E-I(.@@
M=F5R:69I8V%T;R!U;B!E<G)O<F4@;F5L(&-A;F-E;&QA<F4@:2!M97-S86=G
M:2!N96QL82!C87)T96QL82!<(B5S7"(N("(*(E%U97-T;R#H(&EL(&UE<W-A
M9V=I;R!D96P@<V5R=F5R(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@
M;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM
M<V=S='(@(B(*(E-I(.@@=F5R:69I8V%T;R!U;B!E<G)O<F4@;F5L(&-A;F-E
M;&QA<F4@:2!M97-S86=G:2X@475E<W1O(.@@:6P@;65S<V%G9VEO("(*(F1E
M;"!S97)V97(Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.CDY
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B17)R;W)E(&YE
M;&PG86=G:6]R;F%M96YT;R!D96QL)V5V96YT;SH@)7,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR:6-H
M960N<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")3:2#H('9E<FEF:6-A=&\@
M=6X@97)R;W)E('9I<W5A;&EZ>F%N9&\@<75E<W1A('!A<G1E(&1E;"!M97-S
M86=G:6\B"@HC.B!L:6(O365S<V%G92YP:'`Z-30U(&QI8B]-97-S86=E+G!H
M<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4
M:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E-I
M(.@@=F5R:69I8V%T;R!U;B!E<G)O<F4@:6UP;W-T86YD;R!I(&9L86=S(&1E
M:2!M97-S86=G:2!N96QL82!C87)T96QL82!<(B5S(@HB7"(N(%%U97-T;R#H
M(&EL(&UE<W-A9V=I;R!D96P@<V5R=F5R(@H*(SH@9F]L9&5R<RYP:'`Z,38U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@)7,N(@IM<V=S='(@(E-I(.@@=F5R:69I8V%T;R!U;B!E<G)O<F4@
M:6UP;W)T86YD;R`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3,V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B17)R;W)E(&YE;&PG
M:6UP;W)T87II;VYE(&1E;&PG979E;G1O.B`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,38V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R
M(")%<G)O<F4@;F5L;"=I;7!O<G1A>FEO;F4@9&5L;"=A='1I=FETX#H@)7,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G
M<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R("(B"B)3:2!E
M)R!V97)I9FEC871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%Z:6]N92!D96QL
M92!I;F9O<FUA>FEO;FD@;&EB97)O+R(*(F]C8W5P871O(&1E;&PG=71E;G1E
M.B`E<RXB"@HC.B!L:6(O365S<V%G92YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F
M<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R
M=F5R('-A:60B"FUS9W-T<B`B(@HB4VD@Z"!V97)I9FEC871O('5N(&5R<F]R
M92!S<&]S=&%N9&\@:2!M97-S86=G:2!D82!<(B5S7"(@82!<(B5S7"(N(%%U
M97-T;R#H("(*(FEL(&UE<W-A9V=I;R!D96P@<V5R=F5R(@H*(SH@8V]M<&]S
M92YP:'`Z,3(T-`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T
M:&ES(&UE<W-A9V4@87,@82!D<F%F="XB"FUS9W-T<B`B4VD@Z"!V97)I9FEC
M871O('5N(&5R<F]R92!S86QV86YD;R!I;"!M97-S86=G:6\@8V]M92!B;WIZ
M82XB"@HC.B!C;VUP;W-E+G!H<#HQ,#`V"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B
M"FUS9W-T<B`B4VD@Z"!V97)I9FEC871O('5N(&5R<F]R92!I;G9I86YD;R!I
M;"!M97-S86=G:6\Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B17)R;W)E(&YE;&PG
M86=G:6]R;F%M96YT;R!D96QL)V5V96YT;SH@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!L86EN+G!H<#HU.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@
M:6X@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B3F]N(&,G97)A('1E<W1O
M(&EN('%U97-T82!P;W)Z:6]N92!D:2!M97-S86=G:6\B"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z.3<*;7-G:60@(E1H:7,@2%1-3"!M97-S86=E
M(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM<V=S='(@(E%U97-T;R!M
M97-S86=G:6\@2%1-3"!H82!L92!I;6UA9VEN:2!I;G-E<FET92!D96YT<F\N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP"FUS9VED("(B"B)4
M:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!"
M;&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T<B`B
M(@HB475E<W1O(&UE<W-A9V=I;R!(5$U,(&AA(&QE(&EM;6%G:6YI(&EN<V5R
M:71E(&1E;G1R;RX@26UM86=I;FD@8FQO8V-A=&4@(@HB87!P86EO;F\@8V]S
M[#H@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED(")4
M:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G
M92XB"FUS9W-T<B`B475E<W1A(&-H:6%V92!P=6)B;&EC82!01U`@Z"!S=&%T
M82!A;&QE9V%T82!A;"!M97-S86=G:6\N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$P-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$X"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#,@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$U-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<S
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,30*;7-G:60@(E1H:7,@86-T
M:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(E%U97-T82!A>FEO;F4@
M;F]N(&4G('-U<'!O<G1A=&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C$W.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$Y"FUS9VED(")4
M:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")1
M=65S=&$@87II;VYE(&YO;B!E)R!A;F-O<F$@:6UP;&5M96YT871A+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,30*;7-G:60@(E1H
M:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@8V]N=&EN=64_(@IM<V=S='(@(E%U97-T;R!P;W1R96)B92!R:6-H:65D
M97)E(&1E;"!T96UP;RX@4V5I('-I8W5R;R!D:2!V;VQE<B!P<F]S96=U:7)E
M/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G
M:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*
M;7-G<W1R(")1=65S=&\@;65S<V%G9VEO(&-O;G1I96YE('5N(&9I;&4@36%C
M:6YT;W-H+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$P"B,L
M(&9U>GIY"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T
M86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O
M(@HB34E-12XB"FUS9W-T<B`B365S<V%G9VEO(&9I<FUA=&\@96QE='1R;VYI
M8V%M96YT92!C;VX@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z-#$T"B,L(&9U>GIY"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I
M;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@
M4R]-24U%+B(*;7-G<W1R(")-97-S86=G:6\@8W)I<'1A=&\@8V]N(%,O34E-
M12XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C`*;7-G:60@
M(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U
M<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M870@;V8@(@HB=&AI<R!M97-S
M86=E(&ES('5N:VYO=VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C,Q-0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@
M17)R;W(Z("(*;7-G<W1R("(B"B)1=65S=&\@;65S<V%G9VEO(&YO;B!A<'!A
M<F4@97-S97)E('5N('9A;&ED;R!M97-S86=G:6\@8W)I<'1A=&\@8V]N(%!'
M4"X@(@HB17)R;W)E.B`B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M-#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S4P"FUS9VED("(B"B)4:&ES
M(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T
M(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S
M='(@(E%U97-T;R!M97-S86=G:6\@;F]N(&%P<&%R92!E<W-E<F4@;F5L(&9O
M<FUA=&\@8V]R<F5T=&\@4$=0+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,3<P"B,L(&9U>GIY"FUS9VED(")4:&ES(&UE<W-A9V4@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F;W)M870N
M(@IM<V=S='(@(E%U97-T;R!M97-S86=G:6\@;F]N(&%P<&%R92!E<W-E<F4@
M;F5L(&9O<FUA=&\@8V]R<F5T=&\@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*
M;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D
M('9I82!01U`N(@IM<V=S='(@(DUE<W-A9V=I;R!F:7)M871O(&5L971T<F]N
M:6-A;65N=&4@8V]N(%!'4"XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C$T,PIM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL
M>2!S:6=N960@=FEA(%,O34E-12XB"FUS9W-T<B`B365S<V%G9VEO(&9I<FUA
M=&\@96QE='1R;VYI8V%M96YT92!C;VX@4R]-24U%+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,3,Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,C,X"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D
M('9I82!3+TU)344N(@IM<V=S='(@(DUE<W-A9V=I;R!C<FEP=&%T;R!C;VX@
M4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P,2!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR.3$*;7-G:60@(E1H:7,@;65S<V%G92!H
M87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N(@IM<V=S='(@(DUE<W-A9V=I
M;R!C<FEP=&%T;R!C;VX@4$=0+B(*"B,Z(&UE<W-A9V4N<&AP.C(Q,0IM<V=I
M9"`B5&AI<R!M97-S86=E('1O(@IM<V=S='(@(E%U97-T;R!M97-S86=G:6\@
M82(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")1=65S=&\@<V5R
M=F5R(&YO;B!S=7!P;W)T82!L82!C;VYD:79I<VEO;F4@9&5L;&4@8V%R=&5L
M;&4N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,#D*
M;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP
M;W-E('=I;F1O=RXB"FUS9W-T<B`B475E<W1A(&9I;F5S=')A(&1E=F4@97-S
M97)E(&-H:6%M871A(&1A('5N82!F:6YE<W1R82!D:2!C;VUP;W-I>FEO;F4N
M(@H*(SH@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A9"!$
M:7-P;&%Y(@IM<V=S='(@(E9I<W5A;&EZ>F$B"@HC.B!T:')E860N<&AP.C<V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C(*;7-G:60@(E1H<F5A9"!6:65W
M(@IM<V=S='(@(E9I<W5A;&EZ>F%Z:6]N92!P97(@07)G;VUE;G1O(@H*(SH@
M;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP.C8P-B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC
M.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS9VED(")4;R(*;7-G<W1R(")!(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ.0IM<V=I9"`B5&\@061D<F5S
M<R(*;7-G<W1R("));F1I<FEZ>F\@02(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M;W5R8V5S96QE8W0N:6YC.C,R-@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I
M<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!W:&EL92`B"B)C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HQ,S0*;7-G:60@(B(*(E1O('5S92!A(%1,
M4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O
M9B!02%`@-2XP+C8@;W(@(@HB:&EG:&5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(E1O=&%L($%T
M=&%C:&UE;G1S(%-I>F4Z(@IM<V=S='(@(D1I;65N<VEO;F4@5&]T86QE($%L
M;&5G871I.B(*"B,Z(&9O;&1E<G,N<&AP.C,X.`IM<V=I9"`B5')A<V@@9F]L
M9&5R(@IM<V=S='(@(D-A<G1E;&QA(&-E<W1I;F\B"@HC.B!T96UP;&%T97,O
M<')E9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z
M(@IM<V=S='(@(D-A<G1E;&QA($-E<W1I;F\Z(@H*(SH@;&EB+U%U;W1A+V-Y
M<G5S+G!H<#HV-2!L:6(O475O=&$O;65R8W5R>3,R+G!H<#HW.2!L:6(O475O
M=&$O8V]M;6%N9"YP:'`Z-S(*(SH@;&EB+U%U;W1A+VQO9V9I;&4N<&AP.C@X
M(&QI8B]1=6]T82]C;W5R:65R+G!H<#HU,R!L:6(O475O=&$O;61A96UO;BYP
M:'`Z-#@*;7-G:60@(E5N86)L92!T;R!R971R:65V92!Q=6]T82(*;7-G<W1R
M("));7!O<W-I8FEL92!O='1E;F5R92!Q=6]T82(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHQ.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,V"FUS9VED(")5;F%N<W=E<F5D(@IM<V=S='(@(DYO;B!2:7-P;W-T
M;R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@(E5N
M86YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B365S<V%G9VD@;F]N(')I<W!O
M<W1I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@(E5N
M9&5L971E(@IM<V=S='(@(E)E8W5P97)A(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y
M(&UA:6QB;W@N<&AP.C8P,B!L:6(O34E-12](96%D97)S+G!H<#HR,3(*;7-G
M:60@(E5N9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`B1&5S=&EN871A
M<FD@;F%S8V]S=&DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#0W
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@
M='EP93H@)7,B"FUS9W-T<B`B0V]M<&]N96YT92!N;VX@9V5S=&ET;R!D96P@
M=&EP;SH@)7,B"@HC.B!M86EL8F]X+G!H<#HU-C4*;7-G:60@(E5N:VYO=VX@
M1&%T92(*;7-G<W1R(")$871A(%-C;VYO<V-I=71A(@H*(SH@;&EB+TE-05`O
M0VQI96YT+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)
M34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8S-0IM<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@(DEN8V]N=')O
M(%-C;VYO<V-I=71O(@H*(SH@;6%I;&)O>"YP:'`Z-C$X"FUS9VED(")5;FMN
M;W=N(%)E8VEP:65N="(*;7-G<W1R(")$97-T:6YA=&%R:6\@4V-O;F]S8VEU
M=&\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P:')A<V4B"FUS
M9W-T<B`B4V-A<FEC82!087-S=V]R9"(*"B,Z(&9E=&-H;6%I;'!R969S+G!H
M<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")396YZ82!N;VUE(@H*(SH@
M;65S<V%G92YP:'`Z-#DY(&UA:6QB;W@N<&AP.C<P."!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,R"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-0IM<V=I9"`B
M56YS965N(@IM<V=S='(@(DYO;B!,971T;R(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C$R"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O
M;&1E<BAS*2(*;7-G<W1R(")!;FYU;&QA('-O='1O<V-R:7II;VYE(&1A;&QA
M(&-A<G1E;&QA*&4I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-3@T"FUS9VED(")5<&1A=&4@071T86-H;65N="!);F9O<FUA=&EO;B(*
M;7-G<W1R(")!9V=I;W)N82!I;F9O<FUA>FEO;FD@<W5L;"=A;&QE9V%T;R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C`*;7-G:60@(E5P9&%T
M92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R(")3=&%T=7,@9&5L(')I<W!O
M;F1E;G1E(&%G9VEO<FYA=&\B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM
M<V=I9"`B57!L;V%D(@IM<V=S='(@(E5P;&]A9"(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*;7-G:60@(E5S92!$969A=6QT
M(%9A;'5E(@IM<V=S='(@(E5T:6QI>GIA(&EL(%9A;&]R92!D:2!$969A=6QT
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B57-E($E-
M05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(E5S82!L82!S;W1T
M;W-C<FEZ:6]N92!D96QL92!C87)T96QL92!)34%0/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW,S4*(RP@9G5Z>GD*;7-G:60@(E5S92!6:7)T=6%L
M(%1R87-H($9O;&1E<C\B"FUS9W-T<B`B0V%R=&5L;&$@5FER='5A;&4B"@HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,30R"FUS9VED(")5<V5R(@IM<V=S
M='(@(E5T96YT92(*"B,Z(&%C;"YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T
M:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(B(*(D%L;"=U=&5N=&4@)R5S)R!S;VYO('-T871I(&-O;F9E<FET
M:2!C;VX@<W5C8V5S<V\@:2!D:7)I='1I('-E9W5E;G1I('!E<B!L82`B"B)C
M87)T96QL82`G)7,G+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3<W"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(").;VUE(%5T96YT92(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ-PIM<V=I9"`B57-E
M<FYA;64Z(@IM<V=S='(@(DYO;64@571E;G1E.B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV
M.`HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR-PHC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6:65W(@IM<V=S='(@(E9I
M<W5A;&EZ>F$B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HY,B!L:6(O
M34E-12]6:65W97(O=&YE9BYP:'`Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@)7,B"FUS9W-T<B`B5FES=6%L:7IZ82`E<R(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,@4'5B;&EC($ME>2(*;7-G
M<W1R(")-;W-T<F$@8VAI879E('!U8F)L:6-A("5S(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C$Q-@IM<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B36]S=')A(&EL(&-O;G1E
M;G5T;R!(5$U,(&EN('5N82!F:6YE<W1R82!S97!A<F%T82(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X"B,L(&9U>GIY"FUS9VED(")6
M:65W($UE<W-A9V5S(@IM<V=S='(@(DYU;W9I(&UE<W-A9V=I(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T
M<B`B36]S=')A(&-H:6%V92!P97)S;VYA;&4@<')I=F%T82(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<R"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B
M36]S=')A(&-H:6%V92!P97)S;VYA;&4@<'5B8FQI8V$B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3@*;7-G:60@(E9I97<@
M5&AR96%D(@IM<V=S='(@(E9E9&D@1&ES8W5S<VEO;F4B"@HC.B!L:6(O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,38U"FUS9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R(")6:7-U
M86QI>GIA(%1H=6UB;F%I;"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#$X"B,L(&9U>GIY"FUS9VED(")6:65W(&%T=&%C:&UE;G0@:6X@82!S
M97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B36]S=')A(&EL(&-O;G1E;G5T;R!(
M5$U,(&EN('5N82!F:6YE<W1R82!S97!A<F%T82(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]R96QA=&5D+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!C;VYT
M96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(DUO<W1R82!I;"!C
M;VYT96YU=&\@2%1-3"!I;B!U;F$@9FEN97-T<F$@<V5P87)A=&$B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30P"FUS9VED(")6:65W(&5V96YT
M(@IM<V=S='(@(E9I<W5A;&EZ>F$@979E;G1O(@H*(SH@9F]L9&5R<RYP:'`Z
M,S@P(&UA:6QB;W@N<&AP.C4S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(E9I<W5A;&EZ>F$@:2!M97-S86=G
M:2!I;B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C
M="YI;F,Z,C,*;7-G:60@(E9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN.B(*;7-G<W1R(")6:7-U86QI>GIA>FEO;F4@;R!C87)T96QL
M82!D82!M;W-T<F%R92!A<'!E;F$@96YT<F%T;SHB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,3<P"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B
M5FES=6%L:7IZ82!A='1I=FETX"(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL
M+G!H<#HQ,#$*;7-G:60@(E9I97<@=&AE($EM86=E<R(*;7-G<W1R(")-;W-T
M<F$@;&4@26UM86=I;FDB"@HC.B!S96%R8V@N<&AP.C(V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C
M97-F=6QL>2XB"FUS9W-T<B`B3&$@0V%R=&5L;&$@5FER='5A;&4@7"(E<UPB
M(.@@<W1A=&$@8W)E871A(&-O;B!S=6-C97-S;RXB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C$Q,2!L:6(O24U!4"]4<F5E+G!H<#HQ,S@@;&EB
M+TE-05`O5')E92YP:'`Z,34Q"B,Z(&QI8B])34%0+U1R964N<&AP.C$U,R!L
M:6(O24U!4"]4<F5E+G!H<#HQ-3<@;&EB+TE-05`O5')E92YP:'`Z,34X"B,Z
M(&QI8B])34%0+U1R964N<&AP.C,V.2!L:6(O24U!4"]4<F5E+G!H<#HS.3,@
M;&EB+TE-05`O5')E92YP:'`Z-#,S"FUS9VED(")6:7)T=6%L($9O;&1E<G,B
M"FUS9W-T<B`B0V%R=&5L;&$@5FER='5A;&4B"@HC.B!S96%R8V@N<&AP.C(T
M-0HC+"!F=7IZ>0IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L
M86)E;"XB"FUS9W-T<B`B3F]M92!D96QL82!C87)T96QL82!V:7)T=6%L92(*
M"B,Z(&QI8B]61F]L9&5R+G!H<#HQ-S4@;&EB+U9&;VQD97(N<&AP.C$X,`IM
M<V=I9"`B5FER='5A;"!)3D)/6"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HT,38*(RP@9G5Z>GD*;7-G:60@(E9I<G1U86P@24Y"3U@@1F]L9&5R(@IM
M<V=S='(@(D-A<G1E;&QA(%9I<G1U86QE(@H*(SH@;6%I;&)O>"YP:'`Z-#4R
M(&QI8B]61F]L9&5R+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0HC+"!F
M=7IZ>0IM<V=I9"`B5FER='5A;"!4<F%S:"(*;7-G<W1R(")#87)T96QL82!6
M:7)T=6%L92(*"B,Z(&9O;&1E<G,N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B
M5FER='5A;"!4<F%S:"!&;VQD97(B"FUS9W-T<B`B0V%R=&5L;&$@5FER='5A
M;&4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$S,PIM<V=I9"`B
M5FER='5A;"!F;VQD97(@;&%B96PB"FUS9W-T<B`B3F]M92!D96QL82!C87)T
M96QL82!V:7)T=6%L92(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,S<T"FUS9VED(")787)N:6YG(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ
M,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R
M(")"96YV96YU=&\@82`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M,3D*(RP@9G5Z>GD*;7-G:60@(B(*(E=H870@<VAO=6QD('=E(&1O('=I=&@@
M<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G<W1R(")%;&EM:6YA(&UE<W-A
M9V=I(%-004T@9&]P;R!C:&4@<75E<W1I('-O;F\@<W1A=&D@<V5G;F%L871I
M(&-O;64@<W!A;3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(W"FUS
M9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@
M>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H96T@
M87,@9&5L971E9#\B"FUS9W-T<B`B(@HB4W!O<W1A(&D@;65S<V%G9VD@8V%N
M8V5L;&%T:2!N96P@0V5S=&EN;R!I;G9E8V4@9&D@8V]N=')A<W-E9VYA<FQI
M(&-O;64@(@HB;65S<V%G9VD@96QI;6EN871I+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,#<*;7-G:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL
M8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7
M:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE
M;G0@9&%T83\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0R-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG
M(&%D9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B
M"B)U;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H
M;W5T(%PB0%PB*3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C$Y"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B3&ES=&$@0FEA
M;F-A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30Q(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@(EEE<R(*;7-G<W1R(")3
M:2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP
M:'`Z-3@*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O
M;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(E-T86D@<&5R
M('-C87)I8V%R92!L82!P;W-T82!D86QL92!S96=U96YT92!C87-E;&QE.B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P
M"B,L(&9U>GIY"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L
M971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F
M;VQD97(B"B(H<RDN(@IM<V=S='(@(E-T86D@8V5R8V%N9&\@9&D@8V%N8V5L
M;&%R92!L92!S96=U96YT:2!C87)T96QL93HB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HY"B,L(&9U>GIY"FUS9VED(")9
M;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F;VQL;W=I;F<@9F]L
M9&5R*',I+B(*;7-G<W1R(")3=&%I(&-E<F-A;F1O(&1I(&-A;F-E;&QA<F4@
M;&4@<V5G=65N=&D@8V%R=&5L;&4Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@
M;F5W(&9O;&1E<BXB"FUS9W-T<B`B4W1A:2!C;VUP:6%N9&\O<W!O<W1A;F1O
M(&%D('5N82!N=6]V82!C87)T96QL82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C$P,@IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A
M('-U8BUF;VQD97(@=&\@(@IM<V=S='(@(E-T86D@8W)E86YD;R!U;F$@<V]T
M=&]C87)T96QL82!D:2`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$P-`IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E
M;"!F;VQD97(N(@IM<V=S='(@(E-T86D@8W)E86YD;R!U;F$@8V%R=&5L;&$@
M9&D@<')I;6\@;&EV96QL;RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O
M;&1E<G,N(@IM<V=S='(@(E-T86D@8W)E86YD;R!U;F$@8V%R=&5L;&$@9&D@
M<')I;6\@;&EV96QL;RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E(')E
M;F%M:6YG('1H92!F;VQD97(Z("(*;7-G<W1R(")3=&%I(')I;F]M:6YA;F1O
M(&QA(&-A<G1E;&QA.B`B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!C86X@;F]T('5N<W5B<V-R:6)E
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")(86D@86YN=6QL871O(&-O;B!S=6-C
M97-S;R!L82!S;W1T;W-C<FEZ:6]N92!D82!<(B5S7"(B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U(&-A;B!U<V4@=&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@
M:6X@=&AE('-T871I;VYE<GD@=&5X=#H@)6,@9F]R('1H92`B"B)C=7)R96YT
M(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R('1H92!S:6=N871U<F4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N
M<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED(&YO="!A9W)E92!T;R!T:&4@5&5R
M;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O('EO=2!W97)E(&YO="!A;&QO
M=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,38Y"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO
M;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R(@IM<V=S='(@(DYO
M;B!H86D@:6P@<&5R;65S<V\@<&5R(&UO9&EF:6-A<F4@9VQI(&%C8V5S<VD@
M82!Q=65S=&$@8V%R=&5L;&$B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S86=E
M(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*;7-G
M<W1R(")(86D@:6YO;'1R871O('%U97-T;R!M97-S86=G:6\@82`E)7,@86D@
M<V5G=65N=&D@9&5S=&EN871A<FDZ("5S+B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%L97)T+FEN8SHS"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!H879E
M("5S(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B2&%I("5S(&YU;W9I(&UE<W-A
M9V=I+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED
M(")9;W4@:&%V92`Q(&YE=R!M97-S86=E+B(*;7-G<W1R(")(86D@=6X@;G5O
M=F\@;65S<V%G9VEO+B(*"B,Z(&-O;7!O<V4N<&AP.C0Y-`HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E+B(*
M;7-G<W1R(")(86D@=6X@;G5O=F\@;65S<V%G9VEO+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA
M=F4@870@;&5A<W0@;VYE(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@
M9&ED;B=T('5P;&]A9"!Y970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!S96YD('1H:7,@;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S
M/R(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@
M:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T
M<B`B2&%I(&YU;W9I(&UE<W-A9V=I(&YE;&QA('-E9W5E;G1E(&-A<G1E;&QA
M.B(*"B,Z(&QI8B])35`N<&AP.C$P-SD*;7-G:60@(EEO=2!H879E(&YE=R!M
M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`B2&%I(&YU
M;W9I(&UE<W-A9V=I(&YE;&QE('-E9W5E;G1I(&-A<G1E;&QE.B(*"B,Z(&-O
M;7!O<V4N<&AP.C$U,PIM<V=I9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@
M;VYE(')E8VEP:65N="XB"FUS9W-T<B`B1&5V:2!I;G-E<FER92!A;&UE;F\@
M=6X@9&5S=&EN871A<FEO+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C,P,@IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@
M9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E
M(@IM<V=S='(@(B(*(D1E=FD@:6YS97)I<F4@;&$@<&%S<W=O<F0@<&5R(&QA
M('1U82!C:&EA=F4@<')I=F%T82!01U`@<&5R('9I<W5A;&EZ>F%R92`B"B)Q
M=65S=&\@;65S<V%G9VEO(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HR-#D*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E
M(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB
M;65S<V%G92(*;7-G<W1R("(B"B)$979I(&EN<V5R:7)E(&QA('!A<W-W;W)D
M('!E<B!L82!T=6$@8VAI879E('!R:79A=&$@4R]-24U%('!E<B!V:7-U86QI
M>GIA<F4@(@HB<75E<W1O(&UE<W-A9V=I;R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VIA=F%S8W)I<'0N:6YC.C8T('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C(P,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T
M(&UA:6QB;W@@9FER<W0N(@IM<V=S='(@(D1E=FD@<')I;6$@<V5L97II;VYA
M<F4@=6YA(&-A<V5L;&$@9&D@9&5S=&EN87II;VYE+B(*"B,Z(&9E=&-H;6%I
M;'!R969S+G!H<#HX-0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U
M;G0@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B1&5V:2!S96QE>FEO;F%R92!U
M;B!A8V-O=6YT(&1A(&5L:6UI;F%R92XB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C@Q"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M861D<F5S<R!F:7)S="XB"FUS9W-T<B`B1&5V:2!P<FEM82!S96QE>FEO;F%R
M92!U;B!I;F1I<FEZ>F\N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V,PIM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I
M<G-T+B(*;7-G<W1R(")$979I('!R:6UA('-P96-I9FEC87)E(&%L;65N;R!U
M;B!M97-S86=G:6\N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*
M;7-G<W1R(")$979I('-P96-I9FEC87)E('5N(&1E<W1I;F%T87)I;RXB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHR.0IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A="!L96%S="!O;F4@9FEL92!T;R!A='1A8V@N
M(@IM<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@86QM96YO('5N(&9I;&4@9&$@
M86QL96=A<F4N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@;F5E9"!T;R!H
M879E(%PB)7-<(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N
M<RXB"FUS9W-T<B`B1&5V:2!A=F5R92`G)7,G(&%B:6QI=&%T;R!N96QL92!T
M=64@;W!Z:6]N:2!D:2!M86YU=&5N>FEO;F4N(@H*(SH@;&EB+TUA:6QL;V<N
M<&AP.C$S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5D:7)E8W1E9"!T
M:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+B(*;7-G<W1R(")(86D@<F5I;F1I
M<FEZ>F%T;R!Q=65S=&\@;65S<V%G9VEO(&$@)7,@:6P@)25S+B(*"B,Z(&QI
M8B]-86EL;&]G+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E
M<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S+B(*;7-G<W1R(")(86D@<FES
M<&]S=&\@82!Q=65S=&\@;65S<V%G9VEO(&EL("5S+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@
M<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`B(@HB3F]T:69I8V$@9&$@<&%R=&4@9&5L('-E<G9E
M<CH@;&$@<V]T=&]S8W)I>FEO;F4@82!<(B5S7"(@3D].(.@@86YD871A(&$@
M8G5O;B`B"B)F:6YE+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@
M7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(B(*(DYO=&EF:6-A(&1A('!A<G1E(&1E;"!S97)V97(Z($YO;B#H('-T871A
M(&%N;G5L;&%T82!L82!S;W1T;W-C<FEZ:6]N92!D82!<(B5S(@HB7"(N("(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C4Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R!<(B5S7"(B"FUS
M9W-T<B`B2&%I('-O='1O<V-R:71T;R!C;VX@<W5C8V5S<V\@7"(E<UPB(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z-38R"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B
M"FUS9W-T<B`B2&%I(&%N;G5L;&%T;R!C;VX@<W5C8V5S<V\@;&$@<V]T=&]S
M8W)I>FEO;F4@9&$@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B26P@='5O(&YO;64B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G:60@(EEO=7(@4$=0(%!U
M8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B3&4@='5E(&-H:6%V:2!0=6)B
M;&EC:&4O4')I=F%T92!01U`B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<Q('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-@IM<V=I9"`B66]U<B!0
M<FEV871E($ME>2(*;7-G<W1R("),82!T=6$@8VAI879E('!R:79A=&$B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW,0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y(@IM<V=S='(@(DQA
M('1U82!C:&EA=F4@<'5B8FQI8V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,38U"B,L(&9U>GIY"FUS9VED(")9;W5R(%)E<&QY+71O.B!A9&1R97-S
M.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S='(@(DEL('1U;R!I;F1I<FEZ
M>F\@7")2:7-P;W-T82UA.EPB.B`\:3XH;W!Z:6]N86QE*3PO:3XB"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0Y"B,L(&9U>GIY"FUS9VED(")9
M;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS9W-T
M<B`B3&4@='5E(&-H:6%V:2!0=6)B;&EC:&4O4')I=F%T92!3+TU)344B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHQ-@IM
M<V=I9"`B66]U<B!A8V-O=6YT<SHB"FUS9W-T<B`B22!T=6]I(&%C8V]U;G0Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PHC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N
M=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@
M(B(*(DEN=FEA(&$@0D-#('1U='1I(&D@;65S<V%G9VDZ(#QI/BAO<'II;VYA
M;&4L(&EN<V5R:7-C:2!O9VYI(&EN9&ER:7IZ;R!I;B!U;F$@(@HB;G5O=F$@
M<FEG82D\+VD^(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*
M;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D
M:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B(@HB26P@='5O
M(&)R;W=S97(@;F]N('-U<'!O<G1A(&QA('9I<W5A;&EZ>F%Z:6]N92!D:2!Q
M=65S=&\@=&EP;R!D:2!I;6UA9VEN92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N
M9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B26P@='5O(&-O9&EC92!C87)A='1E
M<FD@9&D@9&5F875L="!P97(@;"=I;G9I;R!D:2!M97-S86=G:3HB"@HC.B!T
M96UP;&%T97,O<')E9G,O96YC<GEP='-E;&5C="YI;F,Z,0IM<V=I9"`B66]U
M<B!D969A=6QT(&5N8W)Y<'1I;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A
M9V5S.B(*;7-G<W1R("));"!T=6\@;65T;V1O(&1I(&-R:7!T86=G:6\@9&5F
M875L="!P97(@;"=I;G9I;R!D:2!M97-S86=G:3HB"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HX.0IM<V=I9"`B66]U<B!M97-S86=E('=A<R!S
M=6-C97-S9G5L;'D@9&5L:79E<F5D+B(*;7-G<W1R("));"!T=6\@;65S<V%G
M9VEO(&4G('-T871O(&-O;G-E9VYA=&\@8V]N('-U8V-E<W-O+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@(EEO=7(@<VEG;F%T=7)E
M.B(*;7-G<W1R("),82!T=6$@9FER;6$Z(@H*(SH@;65S<V%G92YP:'`Z,C@X
M(&-O;7!O<V4N<&AP.C$R.#0@;6%I;&)O>"YP:'`Z-30Y(&QI8B]#;VUP;W-E
M+G!H<#HX,3@*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");3F5S<W5N
M($]G9V5T=&]=(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,C`U"FUS9VED(")?0F-C(@IM<V=S='(@(E]"8V,B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B
M3&ES=&$@7TYE<F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHQ-30*;7-G:60@(E]#8R(*;7-G<W1R(")#8R(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,3`*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B7T5L:6UI;F$B"@HC.B!L
M:6(O24U0+G!H<#HY-SD*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@(D-A<E]T
M96QL92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C@Q"FUS
M9VED(")?261E;G1I='DB"FUS9W-T<B`B7TED96YT:73@(@H*(SH@;&EB+TE-
M4"YP:'`Z.38Q"FUS9VED(")?26YB;W@B"FUS9W-T<B`B7U!O<W1A(&EN($%R
M<FEV;R(*"B,Z(&QI8B])35`N<&AP.C$P,C`*;7-G:60@(E],;V<@;W5T(@IM
M<V=S='(@(E]&:6YE('-E<W-I;VYE(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS
M9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T<B`B26YT97-T87II;VYI(%]-
M97-S86=G:6\B"@HC.B!L:6(O24U0+G!H<#HY-S8*(RP@9G5Z>GD*;7-G:60@
M(E].97<@365S<V%G92(*;7-G<W1R(").=6]V:2!M97-S86=G:2(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B
M7U!R:6YT(@IM<V=S='(@(E]3=&%M<&$B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHR-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,C@Y"FUS9VED(")?4')I;W)I='DB"FUS9W-T<B`B7U!R:6]R:73@(@H*
M(SH@;6%I;&)O>"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(E]2969R
M97-H("5S(@IM<V=S='(@(E]!9V=I;W)N82`E<R(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")?4F5P;'DB"FUS
M9W-T<B`B7U)I<W!O;F1I(@H*(SH@;&EB+TE-4"YP:'`Z.3@Q"FUS9VED(")?
M4V5A<F-H(@IM<V=S='(@(E]2:6-E<F-A(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#,Q"FUS9VED(")?4V5N9"!-97-S86=E(@IM<V=S='(@(E]);G9I82!-
M97-S86=G:6\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C,R"FUS9VED(")?5&AR96%D(@IM<V=S='(@(E]!<F=O;65N=&\B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*;7-G:60@
M(E]4;R(*;7-G<W1R(")?02(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C$S"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`B7U)E8W5P97)A
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X
M"FUS9VED(")?5FEE=R!4:')E860B"FUS9W-T<B`B7U9I<W5A;&EZ>F$@<&5R
M($%R9V]M96YT;R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM
M<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R("),:7-T82!?0FEA;F-A(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$W-@IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0T,`IM<V=I9"`B871T
M86-H;65N="(*;7-G<W1R(")A;&QE9V%T;R(*"B,Z('9I97<N<&AP.CDY"FUS
M9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B86QL96=A=&DN>FEP(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B
M>71E<R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`P"FUS9VED
M(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ-S(*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C0*;7-G:60@(F-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,C(P"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.38*;7-G:60@(F-R:71I8V%L('-Y
M<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$V.`IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C(R-`IM<V=I9"`B96YT<GD@;F]T(&9O=6YD
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3DP"B,L(&9U>GIY"FUS9VED(")F<F]M(@IM<V=S='(@(D1A(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$X,`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P-`IM<V=I9"`B:6YP
M=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ.#@*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8Y"FUS9VED(")K97DB"FUS
M9W-T<B`B8VAI879E(@H*(SH@9F]L9&5R<RYP:'`Z,38Q"FUS9VED(")M86EL
M8F]X(&9I;&4B"FUS9W-T<B`B1FEL92!D:2!C87-E;&QA(&1I('!O<W1A(@H*
M(SH@8V]M<&]S92YP:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED
M(")N86UE(@IM<V=S='(@(FYO;64B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`B;F5S<W5N;R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@
M(F]R(@IM<V=S='(@(F\B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$V"FUS9VED
M(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,C$R"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-`IM<V=I9"`B<V5R=FEC
M92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R(@IM<V=S
M='(@(F5R<F]R92!D:2!O<G1O9W)A9FEA(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<G,B"FUS
M9W-T<B`B97)R;W)I(&1I(&]R=&]G<F%F:6$B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3DR"B,L(&9U>GIY"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B
M97)R;W)E(&1I(&]R=&]G<F%F:6$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`X
M"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O
M1FEL=&5R+G!H<#HU,0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B
M='5A(&QI<W1A(&EN9&5S:61E<F%T82(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q
M"FUS9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R(")T=6$@;&ES=&$@8V]N
M<V5N=&ET82(*````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O<&\O;6M?34LN<&\`````````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S4W-S8V`#$P-#$W,S8R-S8T`#`Q-S(Q
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M('1R86YS;&%T:6]N(&]F(&UK7TU++G!O('1O($UA8V5D;VYI86X*(R!4:&ES
M(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A
M<R!T:&4@24U0('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`S($5U<F5K
M82!);F9O<FUA=&EK80HC(%-T;VIA;B!097-O=B`\<W-P0&5U<F5K82YC;VTN
M;6L^+"`R,#`S"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ(&UK7TU+7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP-BTR
M-B`Q-#HU,RLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%-T;VIA;B!097-O
M=B`\<W-P0&5U<F5K82YC;VTN;6L^7&XB"B),86YG=6%G92U496%M.B!-86-E
M9&]N:6%N(#QI,3AN0&QI<W0N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)
M4T\M.#@U.2TU7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M7&XB"B)8+4=E;F5R871O<CH@2T)A8F5L(#$N,"XQ7&XB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@("`@("!#8SH@(@IM<V=S
M='(@(B`@("`@(+3>.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$U"FUS9VED
M("(@("`@("!4;SH@(@IM<V=S='(@(B`@("`@(+3>.B`B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@1&%T93H@(@IM<V=S='(@(B`@(""T
MT.+CW#H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P-@IM<V=I9"`B("`@($9R
M;VTZ("(*;7-G<W1R("(@("`@OM0Z("(*"B,Z(&UA:6QB;W@N<&AP.C0R,B!T
M96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z-#$R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(B"]T.';WM(Z
M("(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I
M9"`B(&EN("(*;7-G<W1R("(@TMX@(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T
M:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M365S<V%G97,B"FUS9W-T<B`B)60@WM0@)60@W][@T-K8(@H*(SH@;6%I;&)O
M>"YP:'`Z,3<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S
M86=E<R!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`BO^#8VM#6V"#?WN#0
MVM`@VM[3T"#DV-OBX-CBU2#AU2#?X-C<U=W5XM@N(@H*(SH@;&EB+U-P86TN
M<&AP.C$W.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)60@;65S
M<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(K#4W-C=V.'BX-#BWN#>
MXB#1U>C5(-C7TM7AXM7=(-35VM`@WM+0T"#?WN#0VM`@U2#=U=_>UM7;W=`N
M(@H*(SH@;&EB+U-P86TN<&AP.C$U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S
M<&%M+B(*;7-G<W1R("*PU-S8W=CAXN#0XM[@WN(@T=7HU2#8U]+5X>+5W2#4
MU=K0(-[2T-`@W][@T-K0(-4@W=7?WM;5V]W0+B(*"B,Z(&QI8B]3<&%M+G!H
M<#HQ-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(K#4W-C=V.'BX-#BWN#>XB#1U>C5(-C7
MTM7AXM7=(-35VM`@WM+0T"#?WN#0VM`@U2#=U=_>UM7;W=`N(@H*(SH@;&EB
M+U-P86TN<&AP.C$U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@
M(K#4W-C=V.'BX-#BWN#>XB#1U>C5(-C7TM7AXM7=(-35VM`@WM+0T"#?WN#0
MVM`@U2#=U=_>UM7;W=`N(@H*(SH@;6%I;&)O>"YP:'`Z,S<S"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D($UE<W-A9V5S(@IM<V=S='(@
M(B5D(-3>("5D(-[4("5D(-_>X-#:V"(*"B,Z(&UA:6QB;W@N<&AP.C8T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO
M=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@TM7\
MU2#?WN'BWM@N(++0Z-#BT"`E<R#?T-_:T"#=U2#5(.#5V-S5W>/2T-W0+B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9O
M;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N
M(@IM<V=S='(@(B5S(-4@X-78W-7=X]+0W=`@W=`@W][GU>+>VM[B(-W0(-S5
MX=7FWN(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!H87,@9&5C;&EN960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T
M;R`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0X,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O(%PB)7-<(BXB"FUS9W-T<B`BO]#?VM#BT"!<(B5S7"(@U2#CX=_5Z-W>
M(-_@U=C<U=WCTM#=T"#2WB!<(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Y-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@
M=&\@86UM96YD("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3<T"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T
M;R!M86ME('EO=2!A=V%R92!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B
M;W5T("5S+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR.#4@;65S<V%G
M92YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?=&]P+FEN8SHQ,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE
M9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P.][4)FYB<W`[)60I(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B*$%P
M<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*
M;7-G<W1R("(HO^#8W-7=V"#3V"#?X-[<U=W8XM4@V"#>U-@@W=`@X=O5U-W8
MWN(@W^#>U][@+BDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3(P"FUS9VED("(H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N
M('1O('1H92!C;VUP;W-E('-C<F5E;BXI(@IM<V=S='(@(BB^XN3@V]@@T]@@
MW^#>W-7=V.+5(-@@TN#0XM@@X=4@W=`@P=[AXM#2V"#?X-[7WN#>XBXI(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H
M2%1-3"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB"FUS9W-T<B`B(@H*(SH@
M<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E='5R;B!T;R!T:&4@8V]M
M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T
M:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I
M;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(HLN#0XM@@X=4@W=`@
MP=[AXM#2V"#?X-[7WN#>XB#?WB#?X-C<U=WCTM#ZU2#=T"#AV.+5(-_@WMS5
MW=@@W=#?X-#2U=W8(-3>("(*(N'5T]`N(+_@WMS5W=CBU2#>U"#BU=K>TMW8
MWN(@W^#>U][@(+VUO+`@U-`@T=C4T.(@W^#8W-7=U>+8+BDB"@HC.B!S<&5L
M;&EN9RYP:'`Z,C<W"B,L(&9U>GIY"FUS9VED("(B"B(H4V5N9"!M97-S86=E
M(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#
M:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A
M<'!L:65D+BDB"FUS9W-T<B`B(@HB*++@T.+8(.'5(-W0(,'>X>+0TM@@W^#>
MU][@WN(@W]X@W^#8W-7=X]+0^M4@W=`@X=CBU2#?X-[<U=W8(-W0W^#0TM7=
MV"#4WB`B"B+AU=/0+B"_X-[<U=W8XM4@WM0@XM7:WM+=V-[B(-_@WM?>X""]
MM;RP(-30(-'8U-#B(-_@V-S5W=7BV"XI(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@(BH@061D('1H97-E(&)Y(&-L
M:6-K:6YG($]+("HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R
M97-S*&5S*2`J(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C$W-`HC+"!F
M=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(KC4U=WBV.+5XM[B(%PB)7-<(B#5(-C7T>#8Z-#=+B(*"B,Z(&QI8B]3
M<&%M+G!H<#HQ.#`*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E
M;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("*PU-S8W=CAXN#0XM[@WN(@T=7HU2#8U]+5X>+5
MW2#4U=K0(-[2T-`@W][@T-K0(-4@W=7?WM;5V]W0+B(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`BL-3<V-W8X>+@T.+>X-[B
M(-'5Z-4@V-?2U>'BU=T@U-7:T"#>TM#0(-_>X-#:T"#5(-W5W][6U=O=T"XB
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<R"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A
M9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("*PU-S8W=CAXN#0XM[@WN(@T=7HU2#8
MU]+5X>+5W2#4U=K0(-[2T-`@W][@T-K0(-4@W=7?WM;5V]W0+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@
M8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("*PU-S8W=CAXN#0XM[@
MWN(@T=7HU2#8U]+5X>+5W2#4U=K0(-[2T-`@W][@T-K0(-4@W=7?WM;5V]W0
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*(RP@9G5Z>GD*;7-G
M:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(L'?U>;8^-#;W=@@U]W0YM@B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(R"B,L(&9U>GIY"FUS9VED
M("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`BP=_5YMCXT-O=V"#7W=#FV"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C`*(RP@9G5Z>GD*;7-G:60@
M(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(L'?U>;8^-#;W=@@U]W0YM@B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(Q"B,L(&9U>GIY"FUS9VED("(U
M,#`@8VAA<F%C=&5R<R(*;7-G<W1R("+!W]7FV/C0V]W8(-?=T.;8(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38R"B,L('!H<"UF;W)M870*
M;7-G:60@(D$@;&%R9V4@:6UA9V4@;F%M960@)7,@:7,@871T86-H960@=&\@
M=&AI<R!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M97-S86=E('EO=2!H
M879E('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO
M;B!F<F]M('1H92`B"B)R96-I<&EE;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!3D0B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,`IM<V=I9"`B06-C
M97!T(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4X-PIM<V=I9"`B06-C97!T(')E<75E<W0@86YD(&%D9"!I="!T
M;R!M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S4S"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4W"FUS9VED(")!8V-E<'1E9#H@
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHW"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT)W,@;F%M93HB"FUS9W-T<B`B
MN-S5(-W0(-C4U=WBV.+5XM[B.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,C`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,`HC+"!F=7IZ
M>0IM<V=I9"`B06-T:6]N<R(*;7-G<W1R("*TU?CAXM+8U2(*"B,Z(&QI8B]-
M24U%+TAE861E<G,N<&AP.C(P,"!L:6(O34E-12](96%D97)S+G!H<#HR,#$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"`E<R!T;R!M>2!!9&1R
M97-S($)O;VLB"FUS9W-T<B`BM-[4T-38(-+>(-#4X-7AT.`@*"5S*2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P,PHC+"!F=7IZ
M>0IM<V=I9"`B061D('-O=7)C92(*;7-G<W1R("+4WM30U-@@V-?2WN`B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R
M(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R-38*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT
M+B(*;7-G<W1R("*_X-C:T.?5W2#5(.30^-LN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O
M(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E
M86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@
M:6YF;W)M871I;VX@9&5T86EL<R(*;7-G<W1R("*[V.?=V"#8W>3>X-S0YMC8
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3,*;7-G:60@(D%D
M9&ET:6]N86P@;65S<V%G92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(&-A;B!B92!V:65W960@)7,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<X
M"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T
M86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!C;VYT86-T
M<RYP:'`Z.#4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,@HC+"!F=7IZ>0IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(K#4X-7AT.#8(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-`HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K<R(*
M;7-G<W1R("*PU.#5X=#@V"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.#D*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\
M96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@(@HB
M;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@
M=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"`B
M"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#(S"FUS9VED(")!;&PB"FUS9W-T<B`BP=CBU2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*;7-G:60@(B(*(D%L
M;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E
M(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G<W1R("+!
MV.+5(-_>X-#:V"#>U"#?T-_:T-+0(/S5(-'8U-#B(-_@U>3@V]7=V"#2WB#5
MU-7=($U"3U@@Y-#XVSHB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G
M95]T<F%S:"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE
M<W-A9V5S(&EN('EO=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A
M>7,@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R("(B
M"B+!V.+5(-_>X-#:V"#>U"#2T.C0XM`@7"(E<UPB(-_0W]K0(-_>X>+0X-@@
MWM0@)7,@U-7=WM+8(/S5(-'8U-#B(.;5V][AW=X@(@HBV-?1X-CHT-W8+B(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M
M;VYT:&QY+G!H<#HU.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL
M(&]L9"!L:6YK960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O
M;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("+!V.+5('-E;G0M;6%I;"#?
MT-_:V"#?WN'BT.#8(-[4("5S(-S5X=7FV"#\U2#1V-30XB#8U]'@V.C0W=@N
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO
M;G1H;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@<V5N
M="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B
M92!D96QE=&5D+B(*;7-G<W1R("+!V.+5('-E;G0M;6%I;"#?T-_:V"#?WN'B
MT.#8(-[4("5S(-S5X=7FV"#\U2#1V-30XB#8U]'@V.C0W=@N(@H*(SH@86-L
M+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(')I9VAT
M<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U
M<V5R(%PB)7-<(BXB"FUS9W-T<B`BO]#?VM#BT"!<(B5S7"(@U2#CX=_5Z-W>
M(-_@U=C<U=WCTM#=T"#2WB!<(B5S7"(N(@H*(SH@;&EB+V%P:2YP:'`Z-S8*
M;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A=&EO;C\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0X"FUS9VED(")!;&QO=R!F
M:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O>#\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ
M,3`*;7-G:60@(D%L=&5R;F%T:79E('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S(@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4X-`IM<V=I9"`B06QW87ES(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3<*(RP@9G5Z>GD*;7-G
M:60@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(K_@V-K0Y]7=
M(-4@Y-#XVRXB"@HC.B!L:6(O365S<V%G92YP:'`Z-3`U"FUS9VED("(B"B)!
M;B!E<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE
M(&%T=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B
M06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N
M97<@;F]T92XB"FUS9W-T<B`BP=4@W][XT-+8(-W5U-7DV-W8X-#=T"#3X-7H
MVM`@W^#8(-3>U-#2T/K5(-W>TM`@TN#5U-W>X>(N(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C,X-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O
M8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S:RXB"FUS9W-T<B`B
MP=4@W][XT-+8(-W5U-7DV-W8X-#=T"#3X-7HVM`@W^#8(-3>U-#2T/K5(-W>
MTM`@TN#5U-W>X>(N(@H*(SH@;65S<V%G92YP:'`Z-3`P(&UA:6QB;W@N<&AP
M.C<Q-"!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.CD*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,U"B,Z('1E;7!L871E<R]M86EL8F]X+VQE
M9V5N9"YI;F,Z-@IM<V=I9"`B06YS=V5R960B"FUS9W-T<B`BOM33WM+>X-7=
MV"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@(D%N
M<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(K[4T][2WN#5W=@@W][@T-K8(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY"FUS
M9VED(")!<'!L>2!&:6QT97)S(@IM<V=S='(@(K_@V-S5W=@@Y-C;XN#8(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!<'!L>2!&:6QT97)S('1O("5S(@IM<V=S='(@
M(K_@V-S5W=@@Y-C;XN#8(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C,V"B,L(&9U>GIY"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@=7!O
M;B!L;V=G:6YG(&]N/R(*;7-G<W1R("*_X-C<U=W8(-_@T-+8V]`@W=`@Y-C;
MXN#8X-#ZU2#?X-@@W^#8^-#2X]+0^M4N(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C0R"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@=VAE
M;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-PHC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(&1E;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(K30V]@@X=#:T.+5
M(+J^O+^[M<*]OB#4T"#3V"#8U]'@V.C5XM4@W][@T-K8TM4_(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z.#4*;7-G:60@(B(*(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE
M=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD960A*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z
M-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*(RP@9G5Z>GD*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(*;7-G<W1R
M("*TT-O8(.'BU2#!N+/#P+VX(-35VM`@X=#:T.+5(-30(-_@WM3>V];8XM4_
M(@H*(SH@;65S<V%G92YP:'`Z-#`W('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C8X"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M4$5234%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("*T
MT-O8(.'0VM#BU2"ZOKR_N[7"O;X@U-`@T]@@V-?1X-CHU>+5(-_>X-#:V-+5
M/R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE
M=&4@=&AI<R!A='1A8VAM96YT/R(*;7-G<W1R("*TT-O8(.'0VM#BU2"ZOKR_
MN[7"O;X@U-`@T]@@V-?1X-CHU>+5(-_>X-#:V-+5/R(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"B,L(&9U>GIY"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F;VQD97(_(@IM<V=S
M='(@(K30V]@@X=#:T.+5(+J^O+^[M<*]OB#4T"#3V"#8U]'@V.C5XM4@W][@
MT-K8TM4_(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E
M<C\B"FUS9W-T<B`BM-#;V"#AT-K0XM4@NKZ\O[NUPKV^(-30(-/8(-C7T>#8
MZ-7BU2#?WN#0VMC2U3\B"@HC.B!L:6(O24U0+G!H<#HY-C8*(RP@9G5Z>GD*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R
M87-H(&9O;&1E<C\B"FUS9W-T<B`BM-#;V"#AT-K0XM4@NKZ\O[NUPKV^(-30
M(-/8(-C7T>#8Z-7BU2#?WN#0VMC2U3\B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE<W-A9V5S
M/R(*;7-G<W1R("*TT-O8(.'0VM#BU2"ZOKR_N[7"O;X@U-`@T]@@V-?1X-CH
MU>+5(-_>X-#:V-+5/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I
M<'0N:6YC.C@P('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y
M"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P
M;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\B"FUS9W-T<B`BM-#;V"#A
MT-K0XM4@NKZ\O[NUPKV^(-30(-/8(-C7T>#8Z-7BU2#?WN#0VMC2U3\B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHW-2!T96UP;&%T
M97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW-`HC+"!F=7IZ>0IM<V=I9"`B
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@
M87,@<W!A;3\B"FUS9W-T<B`BM-#;V"#AT-K0XM4@NKZ\O[NUPKV^(-30(-/8
M(-C7T>#8Z-7BU2#?WN#0VMC2U3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$V"FUS9VED(")!<G)I=F%L(%1I;64B"FUS9W-T<B`BLN#5W-4@W=`@
MW^#8X>+8T]WCTM#ZU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S$*
M;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R("+`T.'BU>?:V"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X
M,PIM<V=I9"`B07-K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4Q.0IM<V=I9"`B071T86-H(@IM<V=S='(@(K_@V-K0
MY]@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S4*(RP@
M9G5Z>GD*;7-G:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R("*_X-C:T.?5W=@@
MY-#XV][2V"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U
M-@IM<V=I9"`B071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y
M('1O('EO=7(@;65S<V%G93\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B071T86-H960@1FEL
M93HB"FUS9W-T<B`BO^#8VM#GV"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-3$@
M;&EB+T-O;7!O<V4N<&AP.C4S-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!
M='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A8VAM96YT('-I
M>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,W-@IM<V=I9"`B071T86-H960@
M:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-B!T96UP;&%T97,O8V]M<&]S
M92]A='1A8VAM96YT<RYJ<SHY-PIM<V=I9"`B071T86-H;65N="(*;7-G<W1R
M("*_X-C:T.?5W2#DT/C;(@H*(SH@8V]M<&]S92YP:'`Z,3`V-R!L:6(O365S
M<V%G92YP:'`Z-#8V"FUS9VED(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG
M:6YA;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0W,PHC.B!L:6(O0V]M<&]S92YP:'`Z,3`W,PIM<V=I9"`B
M071T86-H;65N=',B"FUS9W-T<B`BO^#8VM#GU=W8(.30^-O>TM@B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@R"B,L(&9U>GIY"FUS9VED(")!
M='1E;F1E97,B"FUS9W-T<B`BO^#8VM#GU=W8(.30^-O>TM@B"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PHC+"!F=7IZ>0IM<V=I
M9"`B071T96YT:6]N(@IM<V=S='(@(K35^.'BTMC5(@H*(SH@;&EB+T%U=&@O
M:6UP+G!H<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8T,`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W(&EM
M86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M
M>2`B"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,CDX"B,L(&9U>GIY"FUS9VED(")!=F%I
M;&%B;&4@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`BM-[AXM#?W=@@T-3@U>'0
MX-@Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q.0IM<V=I9"`B
M07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`BO=#7T-0@U-X@)7,B
M"@HC.B!T:')E860N<&AP.C$S-R!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8VL@=&\@
M)7,B"FUS9W-T<B`BO=#7T-0@U-X@)7,B"@HC.B!T:')E860N<&AP.C$S-`IM
M<V=I9"`B0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@B"FUS
M9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR
M96%D($1I<W!L87DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HS.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R
M97%U97-T+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!M
M97-S86=E+G!H<#HR-C8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR,C(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L
M:6(O4V5A<F-H+G!H<#HS-`IM<V=I9"`B0F-C(@IM<V=S='(@(KW5TMC4V]C2
MT"#:WM_8^-`B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*
M;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN
M9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(L;@
MW=`@V]CAXM`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C(Y"FUS9VED
M(")";&]C:R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A
M<F4@<W!E8VEF:6-A;&QY(')E<75E<W1E9#\B"FUS9W-T<B`B(@H*(SH@;&EB
M+U-E87)C:"YP:'`Z-#(*;7-G:60@(D)O9'DB"FUS9W-T<B`BPM7;WB(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,C,@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHS.0HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4U
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-S$*;7-G:60@(D)O=&@B"FUS
M9W-T<B`BN"#4TM7BU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#<*
M;7-G:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHR-S(*;7-G:60@(D-?:&%R<V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A
M;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Y.0IM<V=I9"`B
M0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&%R=&EA;"YP:'`Z-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V%N(&YO="!D:7-P;&%Y("T@9F]U
M;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE
M(&-U<G)E;G0@(@HB;6%I;&)O>"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP
M:'`Z,C@T('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4U"B,Z
M('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C$@=&5M<&QA=&5S+W-A
M=F5I;6%G92]S879E:6UA9V4N:6YC.C$Y"B,Z('1E;7!L871E<R]S;6EM92]P
M87-S<&AR87-E+FEN8SHR,2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z.#8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,"!T
M96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,R"B,Z('1E;7!L871E<R]P
M9W`O:6UP;W)T7VME>2YI;F,Z-C8*;7-G:60@(D-A;F-E;"(*;7-G<W1R("*^
MXMK0UM@B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHW,2!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S4*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,0IM<V=I9"`B0V%N8V5L($UE<W-A
M9V4B"FUS9W-T<B`BON+:T-;8(/C0(-_>X-#:T.+0(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YJ<SHV"B,L(&9U>GIY"FUS9VED(")#86YC96QL:6YG('1H:7,@;65S
M<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+B(*
M;7-G<W1R("(B"B+!WB#>XMK0UN/2T/K5(-W0(-_>X-#:T-+0(/C0(-/CT=CB
MU2#8(-W5^-?8W=#BT"#AWM3@Z-C=T"Y<7&ZTT-O8(.'BU2#AV-/CX-W8("(*
M(M35VM`@T]X@X=#:T.+5(.+>T#\B"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM
M<V=I9"`B0V,B"FUS9W-T<B`BNM[?V/C0(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHY,PIM<V=I9"`B(@HB0V5R=&EF:6-A=&4@:6UP;W)T(&ES
M(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N
M('1H:7,@(@HB<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S`Q"B,L(&9U>GIY"FUS9VED(")#:&%I<B!097)S;VXB
M"FUS9W-T<B`BN]CGW=XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R("*_X-[<U=W8(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N
M9V4@06QL(@IM<V=S='(@(K_@WMS5W=@@T]@@X=CBU2(*"B,Z('1E;7!L871E
M<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B0VAA;F=E($9O;&1E<B(*;7-G<W1R
M("*_X-[<U=W8(-_0W]K0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO
M=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"`B"B)H
M;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`B(@HBO^#>W-7=V"#3
MV"#>W^;8V.+5(-?0(-_@V-K0UR#=T"#1X-[XWN(@W=`@W][@T-K8(-_>(.'B
MX-#=T"#8(-_@T-+8V]#BT"#7T"`B"B+AWN#BV.#0^M4N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@;6%I
M;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS9W-T<B`BO^#>W-7=
MV"#3V"#8W>3>X-S0YMC8XM4@U]`@X=7@TM7@WN(@V"#?T-_:T.+0+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB
M"FUS9W-T<B`B(@HBO^#>W-7=V"#3V"#8W-7BWBP@T-3@U>'0XM`@V"#?WN+?
MV.'>XB#HXMX@V^/SU>+>(-/8(-/;U=30T.(@VM[3T"#3V"#GV.+0T.(@V"`B
M"B+>U-/>TM#@T-#B(-W0(.+2WMCBU2#?WN#0VM@N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R-`IM<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P;&%Y
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ-0IM<V=I9"`B0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G
M<W1R("*]T-?=T.?8(-_0W]K0*-@I(-?0(-W>TM`@W][HXM`B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-S4*;7-G:60@(D-H96-K(%]!;&PO3F]N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I
M;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(Q
M"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E
M=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0V,PHC+"!F=7IZ>0IM<V=I9"`B0VAE8VL@<W!E;&QI;F<@8F5F
M;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("*]T.'BT-W0(-/@U>C:
MT"#?X-@@W^#0_-#ZU2#=T"#?WN#0VM#BT"(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C0*;7-G:60@(D-H;V]S92!!8W1I;VXZ(@IM<V=S
M='(@(KC7T=7@V"#4U?CAXM+8U3HB"@HC.B!C;VYF:6<O<V5R=F5R<RYP:'`N
M9&ES=#HQ.#(*;7-G:60@(D-H;V]S92!A(&UA:6P@<V5R=F5R.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,C4@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,38V"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(Q-PIM<V=I9"`B0VAO;W-E(&$@;6%T8V@@
M;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C$@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<S,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%C
M=&EO;CHB"FUS9W-T<B`BN-?1U>#8(-35^.'BTMC5.B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,T.0HC+"!F=7IZ>0IM<V=I9"`B
M0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D
M9')E<W-E<RXB"FUS9W-T<B`BN-?1U>#8(-#4X-7AT.`@U]`@U-[4T-+0^M4@
MW=[2V"#0U.#5X=@N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C
M="YI;F,Z,CDS"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F
M(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E
M<W-E<RXB"FUS9W-T<B`B(@HBN-?1U>#8(-_>(-K>^"#@U=0@U-`@X=4@W^#5
MT=#@X]+0T.(@T-3@U>'0X-CBU2#?X-@@X-#HV.#CTM#ZU2#=T"#0U.#5X=CB
MU2XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@
M9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9&]W;FQO860@=&AE(&EM
M86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N
M="!P86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP
M:'`Z,3$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS
M9W-T<B`BP=[AXM#2X]+0^M4@W=`@W][@T-K8(-+>(-W>TB`HW][AU='5W2D@
MW^#>U][@U>8N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M
M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A
M<F%T92!W:6YD;W<N(@IM<V=S='(@(L'>X>+0TN/2T/K5(-W0(-_>X-#:V"#2
MWB#=WM(@*-_>X=71U=TI(-_@WM?>X-7F+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]R96QA=&5D+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E
M<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E
M<&%R871E('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VAT;6PN<&AP.CDU"FUS9VED(")#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM
M86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHS,C$*(RP@9G5Z>GD*;7-G:60@(B(*(D-L:6-K(&]N(&]N92!O
M9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T
M(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*;7-G<W1R("(B"B*_X-CBV.'=
MU>+5(-W0(-74U=T@WM0@V-?1X-#=V.+5(-#4X-7AT.#8(-@@W][BWM`@V-?1
MU>#5XM4@T]@@W][;V/K0XM`@U]`@(@HBW^#5T=#@X]+0^M4N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<Q"FUS9VED(")#;&EC:R!T;R!3879E
M(%!'4"!0=6)L:6,@2V5Y(&EN('EO=7(@061D<F5S<R!B;V]K(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C`R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC871E
M(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3`*;7-G:60@(D-L:6-K:6YG(&]N('1H
M92!A9&1R97-S('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S
M96YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU
M,0IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H
M92!M97-S86=E('1O(&)E(')E860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(X"B,L(&9U>GIY"FUS9VED(")#
M;&]S92(*;7-G<W1R("+!WN'BT-+8(@H*(SH@8V]M<&]S92YP:'`Z.#(X(&-O
M;7!O<V4N<&AP.C$Q-#@*;7-G:60@(D-L;W-E('1H:7,@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0R.0IM<V=I9"`B0VQO<V5D($9O;&1E
M<B(*;7-G<W1R("*WT.+2WN#5W=`@W]#?VM`B"@HC.B!F;VQD97)S+G!H<#HT
M-#D*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E(@IM<V=S='(@(L'>T=7@V"#3
MV"#AV.+5(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*
M;7-G:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R("+!WM'5X-@@T]@@X=CBU2(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")#
M;VQL87!S92!!;&P@1F]L9&5R<R(*;7-G<W1R("+!WM'5X-@@T]@@X=CBU2#?
MT-_:V"(*"B,Z(&9O;&1E<G,N<&AP.C0T.0IM<V=I9"`B0V]L;&%P<V4@1F]L
M9&5R(@IM<V=S='(@(L'>T=7@V"#?T-_:T"(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@26YD:6-A=&]R.B`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P,PIM<V=I
M9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-S8Y"B,L(&9U>GIY"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B
MP=[AXM#2V"(*"B,Z(&-O;7!O<V4N<&AP.C@R-R!C;VUP;W-E+G!H<#HQ,30W
M"B,L(&9U>GIY"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S<V%G92(*;7-G
M<W1R("+!WN'BT-+8(-_>X-#:T"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,S0*(RP@9G5Z>GD*;7-G:60@(D-O;7!O<V4@;65S<V%G97,@:6X@82!S
M97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(L'>X>+0TN/2T/K5(-W0(-_>X-#:
MV"#2WB#=WM(@*-_>X=71U=TI(-_@WM?>X-7F+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET
M:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S
M('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R
M92!D:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-PIM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS
M+B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM<V=I
M9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N
M;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M=')O;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N
M<R!R96QA=&EN9R!T;R!M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O
M;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T
M:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB
M"FUS9W-T<B`B(@HBNM[=XN#>V]`@W=#4(.3@U=K2U=WBW=[AXB#=T"#?X-[2
MU>#CTM#ZU2#4T-O8(-C<T"#=WM+8(-_>X-#:V"#8(-30V]@@U-`@X=4@(@HB
MTN#HV"#8U]+5X>+CTM#ZU2#7T"#=V-+=WN+>(-_@V.'BV-/=X]+0^M4N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y-@IM<V=I9"`B0V]N=F5R="!T
M97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O
M<'DB"FUS9W-T<B`BNM[?V.#0^"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T
M<B`BP=[1U>#8(-_0W]K0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S='(@(KK>X-73V.#0^"(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#`*;7-G:60@
M(D-O<G)E8W1E9"!497AT(@IM<V=S='(@(KK>X-73V.#0W2#BU=KAXB(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S
M(@IM<V=S='(@(B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C0P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S
M(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@HBO=#A
MXM#=T"#3X-7HVM`@W^#8(-'@V.C5^M4@W=`@W][@T-K8XM4@WM0@W]#?VM#B
MT"!<(B5S7"(N(+[2T"#3WB#2X-#BV"`B"B+AU>#2U>#>XB(*"B,Z(&QI8B]3
M97-S:6]N+G!H<#HS,3@*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!E>&5C
M=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@(K[?U>#0YMC8
M(-?0(-[4X-;CTM#ZU2(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HU
M-`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE
M(&9R;VT@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO="!E
M>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@87)C:&EV
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(W,PIM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M
M($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C,Q-"!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C,Y"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C`*;7-G
M:60@(D-R96%T92(*;7-G<W1R("*ZX-78X-#X(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E<B(*;7-G
M<W1R("*ZX-78X-#X(-_0W]K0(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$S-PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E($ME>7,B"FUS9W-T<B`BNN#5
MV.#0^"(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-`HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(KK@
MU=C@T/@@W]#?VM`B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?
M<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W($%C8V]U;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C$R
M('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC+"!F=7IZ>0IM
M<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(KK@U=C@
MT/@@W=[2T"#?T-_:T"#7T"#>XM_0U-[FV"(*"B,Z('1E;7!L871E<R]P<F5F
M<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S
M96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E
M<B(*;7-G<W1R("*ZX-78X-#X(-W>TM`@W]#?VM`@U]`@W=77T-+@Z-7=V"#?
MWN#0VM@B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC
M.C(V('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#(*;7-G
M:60@(D-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(KK@
MU=C@T/@@W=[2T"#?T-_:T"#7T"#?X-#BU=W8(-_>X-#:V"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S
M+W1R87-H<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H
M(&9O;&1E<B(*;7-G<W1R("*ZX-78X-#X(-W>TM`@W]#?VM`@U]`@WN+?T-3>
MYM@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B"B)#
M<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI
M;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE=&4@
M<W!A;2XB"FUS9W-T<B`B(@HBNN#5V.#0^"#?X-#2V-O0(-?0(.38V^+@V.#0
M^M4@V"#>X-/0W=C7V.#0^M4@W=`@W][@T-K8XM4@Z.+>(.'5(-_@V-S0T.(L
M("(*(N'>X.+8X-#ZU2#=T"#8X>+8XM4@TMX@W]#?VM@@V"#1X-CHU?K5(-W0
M(-W5W][6U=O=V.+5(-_>X-#:V"XB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!N97<@<W1A
M=&EO;F5R>2(*;7-G<W1R("*ZX-78X-#X(-W>TM`@W]#?VM`@U]`@W^#0XM7=
MV"#?WN#0VM@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED
M(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")#=7-T;VUI>F4@
M86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT
M<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"B,L
M(&9U>GIY"FUS9VED(")#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN(@IM
M<V=S='(@(B(*(KC7T=7@V"#:T-K>(-30(.'5(-_@T/S0T.(@W][@T-K8XM4@
MV"#:T-35(/S5(.'5(.?CTM#0XB#=U=?0TN#HU=W8XM4@W][@T-K8+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+B(*;7-G<W1R("*XU]'5X-@@U]#4T.?8(-K>V"#\U2#AU2#8U]+@Z./2
MT-#B(-_@V"#?X-CXT-+CTM#ZU2XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")$871?92(*
M;7-G<W1R("*TT.+CW"(*"B,Z(&UE<W-A9V4N<&AP.C(V,B!T:')E860N<&AP
M.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R("*TT.+CW"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW-3<*(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D
M(@IM<V=S='(@(KC7T>#8Z-#=V"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L
M="(*;7-G<W1R("*XU]'@V.C8(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U
M;'1S96%R8VAS96QE8W0N:6YC.C$X"FUS9VED(")$969A=6QT(%-E87)C:"!&
M:65L9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(S
M"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(L'B
MT-W4T.#4U=T@VN#8XM7@X]P@U]`@X=[@XMC@T/K5.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,S,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E
M8W1I;VXZ(@IM<V=S='(@(L'BT-W4T.#4U=T@X-74WN';U=0@U]`@X=[@XMC@
MT/K5.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C4*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R("*XU]'@V.C0W=@B"@HC.B!F
M;VQD97)S+G!H<#HT,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C8X"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR
M-2!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
MN-?1X-CHV"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS
M9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G:60@(D1E;&5T92!&;VQD
M97(H<RDB"FUS9W-T<B`BN-?1X-CHV"#?T-_:T"C8*2(*"B,Z(&9O;&1E<G,N
M<&AP.C(X-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E
M<G,B"FUS9W-T<B`BN-?1X-CHV"#?T-_:T"C8*2(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(%-T871I;VYE<GDB"FUS9W-T<B`BN-?1X-CHV"#?T-_:T"C8*2(*"B,Z(&9O
M;&1E<G,N<&AP.C0Q.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%9I<G1U86P@
M1F]L9&5R(@IM<V=S='(@(KC7T>#8Z-@@W]#?VM`HV"DB"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#,*;7-G:60@(D1E;&5T92!F971C
M:&5D(&UE<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R.`IM<V=I9"`B1&5L971E
M(&9R;VT@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V.`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&]L9"!L:6YK
M960@871T86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R
M("*XU]'@V.C8(-/8(.'BT.#8XM4@<V5N="UM86EL(-_0W]K8(-W0(-_>Y]7B
MWMK>XB#=T"#<U>'5YM[B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M,`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(KC7T>#8Z-@@T]@@
MX>+0X-CBU2!S96YT+6UA:6P@W]#?VM@@W=`@W][GU>+>VM[B(-W0(-S5X=7F
MWN(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@<W!A;2!M97-S86=E<R(*;7-G<W1R("*XU]'@V.C8(-_>
MX-#:V"(*"B,Z(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI
M;F,Z.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R("*XU]'@V.C0W=@B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8S"FUS9VED(")$96QE=&5D(&UE
M<W-A9V5S(@IM<V=S='(@(KC7T>#8Z-#=V"#?WN#0VM@B"@HC.B!C;VUP;W-E
M+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@
M=&AE(&%T=&%C:&UE;G0@7"(E<UPB+B(*;7-G<W1R("*XU]'@V.C8(-_@V-K0
MY]7=(.30^-LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@
M(D1E;&5T:6YG(&%N9"!-;W9I;F<@365S<V%G97,B"FUS9W-T<B`BL>#8Z-7Z
MU2#8(-_@U=S5X>+CTM#ZU2#?WN#0VM@B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3DR"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T,`IM<V=I9"`B1&5N>2!R
M97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,@IM<V=I9"`B1&5S8V5N9&EN
M9R(*;7-G<W1R("*^W]#ST.?:V"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T
M=&%C:&UE;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Y
M"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D1E
M=&%I;',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W
M-PHC+"!F=7IZ>0IM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM<V=S='(@(K_>
MXM_8X3HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S
M-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R("*_WM35X>/2T/K0
M(-?0(-_@V-K0UR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-SD*;7-G
M:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S
M86=E/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V
M"FUS9VED(")$:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"B,L(&9U>GIY"FUS9VED
M(")$:7-P;&%Y('!O<"UU<"!N;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_(@IM
M<V=S='(@(K_@V-K0UM@@V-?2U>'BX]+0^M4@U]`@W=[2T"#?WN#0VM`N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES<&QA>2!T
M:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES
M<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS9W-T<B`B
MO][4U>'CTM#ZT"#7T"#?X-C:T-<B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B1&\@
M3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`BO=4@
M^-`@W^#>TM7@X]+0^"#?T-_:T.+0(-?0(-W>TM`@W][HXM`B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.34R"FUS9VED(")$;R!N;W0@9V5N97)A=&4@
M82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TE-4"YP:'`Z,3`W-0HC+"!F=7IZ>0IM<V=I9"`B1&\@>6]U('=A;G0@=&\@
M;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`BP=#:T.+5(-O8(-30(/C0(-[B
MTM[@V.+5("5S/R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,R
M"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C8*
M;7-G:60@(D1O;F4B"FUS9W-T<B`BM]#2X.C8(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E
M<R!I;B`N>FEP($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]H96%D97)S+FEN8SHU,@IM<V=I9"`B1&]W;FQO860@06QL($%T=&%C
M:&UE;G1S("AI;B`N>FEP(&9I;&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS9VED(")$;W=N;&]A9"!&;VQD
M97(H<RDB"FUS9W-T<B`BO^#5TM?5W-@@W]#?VM`HV"DB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B1&]W
M;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%TB"FUS9W-T<B`BO^#5TM?5
MW-@@W]#?VM`HV"DB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"FUS
M9VED(")$;W=N;&]A9"!I;B`N>FEP($9O<FUA="(*;7-G<W1R("(B"@HC.B!M
M97-S86=E+G!H<#HU,#$@;6%I;&)O>"YP:'`Z-S$Y('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3$*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHR,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C0Q"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.0IM<V=I9"`B
M1')A9G0B"FUS9W-T<B`BO=77T-+@Z-7=V"(*"B,Z(&9O;&1E<G,N<&AP.C,Y
M,@HC+"!F=7IZ>0IM<V=I9"`B1')A9G0@9F]L9&5R(@IM<V=S='(@(K_0W]K0
M(+W5U]#2X.C5W=@Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C
M="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD97(Z(@IM<V=S='(@(K_0W]K0
M(+W5U]#2X.C5W=@Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`HC
M+"!F=7IZ>0IM<V=I9"`B12UM86EL($%D9')E<W,B"FUS9W-T<B`BOM0@T-3@
MU>'0(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,P.0IM<V=I9"`B14Y$(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED
M(")%4E)/4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N
M(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z,3D*;7-G:60@(D5D:70B"FUS9W-T<B`BP^#5
MU-@B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(L;@W=`@V]CAXM`B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3,*(RP@9G5Z>GD*
M;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R("*_WNCBU=WAVM@@Y-C;XN#8
M(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHQ-@IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F
M;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@
M(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`BP^#5U-@@T]@@V-35W>+8
MXM7BV.+5(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$S"B,L
M(&9U>GIY"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(@IM<V=S='(@
M(L/@U=38(-/8(-S>V.+5(-_@T-+8V]`@U]`@Y-C;XN#8X-#ZU2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-C$*;7-G:60@(D5D:70@>6]U<B!P<F5F
M97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHR,PHC
M+"!F=7IZ>0IM<V=I9"`B161I="!Y;W5R('=H:71E;&ES="(*;7-G<W1R("+#
MX-74V"#3V"#8U-7=XMCBU>+8XM4B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C(S.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R("*^U"#0U.#5X=`B"@HC.B!L:6(O365S<V%G92YP:'`Z-C4W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%;7!T:65D(&%L;"!M97-S
M86=E<R!F<F]M("5S+B(*;7-G<W1R("*_X-7?X-#BU=W0(-_>X-#:T"#>U"`E
M<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"B,L(&9U
M>GIY"FUS9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`BN-?1X-CHV"#?
MT-_:T"C8*2(*"B,Z(&9O;&1E<G,N<&AP.C(X-@HC+"!F=7IZ>0IM<V=I9"`B
M16UP='D@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R("*XU]'@V.C8(-_0W]K0
M*-@I(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*(RP@
M9G5Z>GD*;7-G:60@(D5M<'1Y(%1R87-H(&9O;&1E<B(*;7-G<W1R("*_T-_:
MT""^XM_0U-[:.B(*"B,Z(&QI8B])35`N<&AP.CDW,PIM<V=I9"`B16UP='D@
M7U-P86TB"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")%
M;7!T>2!?5')A<V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N
M86)L92!01U`@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHQ('1E;7!L871E<R]S;6EM92]N;W1A8W1I
M=F4N:6YC.C8*;7-G:60@(D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q,0IM<V=I
M9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0T,@IM<V=I9"`B16YC<E]Y
M<'1I;VX@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3$W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3<*;7-G
M:60@(D5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S@T"FUS
M9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`BM]#2X.C8(/C0
M(-_@U=_@T.+5W=#BT"#?WN#0VM`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0Q
M"B,L(&9U>GIY"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R("+!XM#@V"#?
MWN#0VM@B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(K_@
MU=_@T.+5W=`@W][@T-K0(-[4("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N
M=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-P86US96QE8W0N:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N
M86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R("*RW=7AU>+5
M(-C<U2#7T"#=WM+0XM`@W]#?VM`@U]`@WN+?T-3>YM@B"@HC.B!T96UP;&%T
M97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R("*RW=7A
MU>+5(-C<U2#7T"#=WM+0XM`@W]#?VM`@U]`@W=77T-+@Z-7=V"#?WN#0VM@B
M"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(S"FUS
M9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O
M;&1E<B(*;7-G<W1R("*RW=7AU>+5(-C<U2#7T"#=WM+0XM`@W]#?VM`@U]`@
MW^#0XM7=V"#?WN#0VM@B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE
M8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T
M<F%S:"!F;VQD97(B"FUS9W-T<B`BLMW5X=7BU2#8W-4@U]`@W=[2T.+0(-_0
MW]K0(-?0(-[BW]#4WN;8(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*(RP@9G5Z
M>GD*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(K_@U=W0X=[GV"#?
MWN#0VM`Z(@H*(SH@;65S<V%G92YP:'`Z,3DT(&-O;7!O<V4N<&AP.C$Q,S0@
M=&AR96%D+G!H<#HW,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B16YT
M<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E
M<W,@8F]O:R(*;7-G<W1R("*RW=7AWN(@7"(E<UPB(-4@X^'?U>C=WB#4WM30
MU-7=(-+>(-#4X-7AT.#>XB(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X
M-@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@(K/@
MU>C:T"(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S
M(#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HS,#D@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,0HC+"!F=7IZ>0IM
M<V=I9"`B179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(K_0
MW]K0XM`@7"(E<UPB(-4@X^'?U>C=WB#8U]'@V.C0W=`N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R("+!U=K>V"`Q-2#<V-WCXM@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S<Y"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(L'5
MVM[8(#,P(.'5VN/=U-@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q
M"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`BP=7:WM@@-2#<V-WC
MXM@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@S"FUS9VED(")%=F5R
M>2!H86QF(&AO=7(B"FUS9W-T<B`BP=7:WO@@W][;T"#GT.$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S@P"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`BP=7:WOC0(-S8W>/BT"(*"B,Z(&9O;&1E<G,N<&AP.C0U-PHC+"!F
M=7IZ>0IM<V=I9"`B17AP86YD(@IM<V=S='(@(L#0Z-C@V"#3V"#AV.+5(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X
M<&%N9"!!;&PB"FUS9W-T<B`BP-#HV.#8(-/8(.'8XM4B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"!&
M;VQD97)S(@IM<V=S='(@(L#0Z-C@V"#3V"#AV.+5(-_0W]K8(@H*(SH@9F]L
M9&5R<RYP:'`Z-#4W"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(L#0
MZ-C@V"#DWMO4U>`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4S"FUS9VED
M(")%>'!A;F0@3F%M97,B"FUS9W-T<B`BP-#HV.#8(-C<V/K0(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-C,*;7-G:60@(D5X<&%N9"!N86UE<R!I
M;B!T:&4@8V]M<&]S92!W:6YD;W<@875T;VUA=&EC86QL>2!I;B!T:&4@8F%C
M:V=R;W5N9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDX,`HC+"!F=7IZ>0IM<V=I9"`B17AP86YD('1H92!E;G1I<F4@9F]L9&5R
M('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W/R(*;7-G<W1R
M("+`T.C8X-@@T]X@YM7;WN+>(-3@TMX@WM0@W]#?VM@@W^#8(-_@V-K0UR#=
MT"#?T-_:V.+5+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C$T-"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ.30*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C0U('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHQ,#$*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9&EN
M9R(*;7-G<W1R("+`T.C8X-@@T]@@X=CBU2(*"B,Z(&QI8B])35`N<&AP.CDX
M-"!L:6(O24U0+G!H<#HY.#8*(RP@9G5Z>GD*;7-G:60@(D9?971C:"!-86EL
M(@IM<V=S='(@(KW>TM`@W][@T-K0(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]F971C:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*
M(RP@9G5Z>GD*;7-G:60@(D9E=&-H($UA:6PB"FUS9W-T<B`BO=[2T"#?WN#0
MVM`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8Y"B,L(&9U>GIY"FUS
M9VED(")&971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R
M("+!WN'BT-+CTM#ZU2#=T"#?WN#0VM@@TMX@W=[2("C?WN'5T=7=*2#?X-[7
MWN#5YBXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#8*
M(RP@9G5Z>GD*;7-G:60@(D9E=&-H(&UE<W-A9V5S('5P;VX@;&]G9VEN9R!O
M;C\B"FUS9W-T<B`BO^#8W-7=V"#?X-#2V-O0(-W0(.38V^+@V.#0^M4@W^#8
M(-_@V/C0TN/2T/K5+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F
M<F]M("5S(@IM<V=S='(@(K_@U=_@T.+5W=`@W][@T-K0(-[4("5S(@H*(SH@
M;&EB+T9E=&-H;6%I;"YP:'`Z,C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(K_@U=_@
MT.+5W=`@W][@T-K0(-[4("5S(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@U
M(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL+G!H<#HR.#D*
M;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA
M:6PN<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B1F5T8VAM86EL.B!N;R!N97<@
M;65S<V%G97,N(@IM<V=S='(@(KC<T.+5("5S(-W>TM@@W][@T-K8+B(*"B,Z
M(&QI8B])35`N<&AP.CDY,`HC+"!F=7IZ>0IM<V=I9"`B1FE?;'1E<G,B"FUS
M9W-T<B`BQ-C;XN#8(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-3`R('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C@R"B,L
M(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(L38V^+5X"(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M=&5R($]P=&EO;G,B"FUS9W-T<B`BM.#CT]@@WM_FV-@B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B1FEL=&5R
M(%-E='1I;F=S(@IM<V=S='(@(K_@T-+8V]`@U]`@Y-C;XN#8X-#ZU2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#`*(RP@9G5Z>GD*;7-G:60@(D9I
M;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`B
MQ-C;XN#8X-#X(/C0(.'>U.#6V-W0XM`@W=`@W][@T-K0XM`@X=_>X-74(.'>
MU.#6V-W0+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z
M,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(W"FUS9VED(")&:6QT97)S(@IM<V=S='(@(L38V^+@V"(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,PIM<V=I9"`B1FEL=&5R<R!.
M3U0@06-T:79E(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97)S.B`E<R!M86YA9V5M96YT('!A
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ.#8*(RP@9G5Z>GD*;7-G:60@(D9I;F0B"FUS9W-T<B`BO][;U2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*(RP@9G5Z>GD*;7-G:60@
M(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R("*_X-+0(.'BX-#=T"(*"B,Z
M(&UA:6QB;W@N<&AP.C,T-0IM<V=I9"`B1FER<W0@4&%G92(*;7-G<W1R("*_
MX-+0(.'BX-#=T"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0HC
M+"!F=7IZ>0IM<V=I9"`B1F]?<G=A<F0B"FUS9W-T<B`BO^#5W^#0XM@B"@HC
M.B!F;VQD97)S+G!H<#HR-C8@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C
M;VYF:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S`S('1E;7!L871E
M<R]F;VQD97)S+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I
M86QP86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L
M<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T;W(B"FUS
M9W-T<B`BO=#2V-/0XM[@(-?0(-_0W]K8(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D9O;&1E<B!3=6UM87)Y(@IM<V=S
M='(@(L35TN#CT.#8(@H*(SH@86-L+G!H<#HR-`IM<V=I9"`B1F]L9&5R('-H
M87)I;F<@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C8R"FUS9VED(")&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38Y"FUS9VED(")&
M;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O
M<B!M97-S86=E<R!D871E9"!T;V1A>2(*;7-G<W1R("(B"@HC.B!C;VUP;W-E
M+G!H<#HW.#`@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$U"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED
M(")&;W)W87)D(@IM<V=S='(@(K_@U=_@T.+8(@H*(SH@8V]M<&]S92YP:'`Z
M-S8U"FUS9VED(")&;W)W87)D.B(*;7-G<W1R("*_X-7?X-#BV#HB"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S8Y"B,L(&9U>GIY"FUS9VED(")&;W)W87)D960@
M;65S<V%G92(*;7-G<W1R("*WT-+@Z-@@^-`@W^#5W^#0XM7=T.+0(-_>X-#:
MT"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("*_X-7?X-#B
MU=W0(-_>X-#:T"#>U"`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.#,*(RP@9G5Z>GD*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*
M;7-G<W1R("*XW>3>X-S0YMCXT"#7T"#AU>#2U>#>XB(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT.30*;7-G:60@(D9R964O0G5S>2!297!L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@X"FUS
M9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#`Q"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S
M="!297-P;VYS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C(W"B,L(&9U>GIY"FUS9VED(")&<F]?;2(*
M;7-G<W1R("*^U"(*"B,Z(&UE<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T
M.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A
M<F-H+G!H<#HR,@IM<V=I9"`B1G)O;2(*;7-G<W1R("*^U"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G
M<W1R("*^U"#0U.#5X=`B"@HC.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP
M:'`Z-S@Q"FUS9VED(")&=V0Z(@IM<V=S='(@(K_@U=_@T.+8.B(*"B,Z(&-O
M;7!O<V4N<&AP.C$R.30*(RP@9G5Z>GD*;7-G:60@(D9W9#H@(@IM<V=S='(@
M(K_@U=_@T.+8.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.38*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM
M<V=S='(@(K?0TN#HV"#XT"#?X-7?X-#BU=W0XM`@W][@T-K0(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X"B,L(&9U>GIY"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS
M9W-T<B`BM.#CT]@@WM_FV-@B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M97-S86=E<S\@*$E-
M05`@;VYL>2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP
M:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@
M(L';U=3=T"#?WN#0VM`B"@HC.B!L:6(O24U0+G!H<#HT.3@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O
M9B!<(B5S7"(B"FUS9W-T<B`BM-[4T-38(-+>(-#4X-7AT.`@*"5S*2(*"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,S4*;7-G:60@(D=R86YT(&%C8V5S
M<R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-#8@;&EB+T9I;'1E<BYP
M:'`Z,3`U(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,Z(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C$P,B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ,#0*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S
M(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(SH@;&EB+TU)344O5FEE
M=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C@*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP
M.C<Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,3<S"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R,"!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%4D4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,Q
M(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,3<*(SH@;&EB+TU)344O5FEE
M=V5R+W)E;&%T960N<&AP.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z
M(&-O;7!O<V4N<&AP.C(U-@IM<V=I9"`B2%1-3"!697)S:6]N(&]F($UE<W-A
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M
M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V.`IM<V=I9"`B2&ED9&5N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C<*;7-G:60@(DAI9&1E
M;B!I;B!4:')E860@5FEE=R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HS
M-C<*;7-G:60@(DAI9&4@1&5L971E9"(*;7-G<W1R("+!VN#8^"#3V"#8U]'@
MV.C0W=CBU2(*"B,Z(&9O;&1E<G,N<&AP.C(Y.`IM<V=I9"`B2&ED92!5;G-U
M8G-C<FEB960B"FUS9W-T<B`BP=K@V/@@T]@@W=7?X-72U]7<T-W8XM4B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI
M9V@B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N<&AP
M.C<R-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(
M:6=H(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(Y,PIM<V=I9"`B2&EG:&5S="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X"B,L(&9U>GIY"FUS9VED(")(
M;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T
M<B`BP=#:T.+5(-O8(-30(/C0(-[BTM[@V.+5("5S/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(DAO=R!T;R!A='1R
M:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`BO^#5Y-C:
MX2#?X-74(.;8XMC@T-W8WN(@XM7:X>(@W^#8(-[4T][2WN`Z(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-05`@
M*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HS.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!3
M97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S<&]N9&5D
M.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C$V-B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!4"!O
M=F5R(%-33"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C$U,@IM<V=I9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF
M:6-A=&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,38W"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-C@*;7-G:60@(DE-
M05`@<V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C4@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R("(B
M"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C0Y"FUS9VED("))34%0+U!/
M4#,@36%I;"!397)V97)S(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C@V
M-@IM<V=I9"`B24Y"3U@B"FUS9W-T<B`BP=#=U-#GU2(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y
M;W4@;75S="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O
M;F9I<FTN:'1M;#HQ,@IM<V=I9"`B268@>6]U(&-O;G1I;G5E+"!A;&P@;65S
M<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E(&QO<W0A(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,@IM<V=I
M9"`B26=N;W)E(@IM<V=S='(@(KC3W=[@V.#0^"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G
M<W1R("*XT]W>X-C@T/@@X=4B"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A
M=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,`HC+"!F=7IZ>0IM<V=I9"`B
M26UP;W)T(@IM<V=S='(@(K+0UMW8(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z
M-C4*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!+97DB"FUS9W-T<B`BLM#6W=@B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y"B,L(&9U>GIY"FUS9VED
M("));7!O<G0@2V5Y<&%I<B(*;7-G<W1R("*RT-;=V"(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(W"B,L(&9U>GIY"FUS9VED("));7!O
M<G0@365S<V%G97,B"FUS9W-T<B`BLM#6W=@@W][@T-K8(@H*(SH@<&=P+G!H
M<#HT,@IM<V=I9"`B26UP;W)T(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B26UP;W)T(%!E<G-O
M;F%L($-E<G1I9FEC871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O
M:6UP;W)T7VME>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV
M871E(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'
M4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K
M97DN:6YC.C0*;7-G:60@(DEM<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF
M:6-A=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS9VED("));7!O<G0@
M4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`IM
M<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(B(*"B,Z
M('-M:6UE+G!H<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+97DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED
M("));7!O<G0@;6)O>"!&:6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`B(@H*
M(SH@;65S<V%G92YP:'`Z-3`R(&UA:6QB;W@N<&AP.C<S-"!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,S"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM<V=I
M9"`B26UP;W)T86YT(@IM<V=S='(@(K+0UMW8(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT(&UE<W-A9V5S(@IM
M<V=S='(@(K+0UMW8(-_>X-#:V"(*"B,Z(&9O;&1E<G,N<&AP.C$V-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@
M9G)O;2`E<RXB"FUS9W-T<B`BO^#5W^#0XM7=T"#?WN#0VM`@WM0@)7,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS9VED("));B!0<F]C
M97-S(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,X-"!L:6(O1F]L9&5R
M+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-4"YP:'`Z,S$S"B,Z
M(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4<F5E+G!H<#HR,3D*
M;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3(*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H
M92!H96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S
M86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G<W1R("*XT]W>X-C@
MT/@B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA
M=&EO;B!O;B`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N
M86P@4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@
M(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY.`HC+"!F=7IZ>0IM<V=I9"`B26YL
M:6YE(@IM<V=S='(@(MW8U=3=T"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U
M"FUS9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ
M,`IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU
M"FUS9VED("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$R"FUS9VED("));G9A
M;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S
M='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4X-"!M86EL8F]X+G!H<#HV,C8*;7-G
M:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!296UO=&4@36%I;&)O
M>"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ-3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26YV86QI9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z
M("5S+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z.#(@<&=P+G!H<#HQ-@IM
M<V=I9"`B26YV86QI9"!K97DB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ.38*
M;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G
M<W1R("(B"@HC.B!P9W`N<&AP.C$W,0IM<V=I9"`B26YV86QI9"!P97)S;VYA
M;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B26YV97)T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B
M2T(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q,PIM
M<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K
M92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y
M("(*(F=E;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED
M(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES
M(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE
M+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U
M<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G
M:60@(DME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR,38*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(JC0U]C:(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!-
M86EL8F]X(%!A9V4B"FUS9W-T<B`BO][AV]74W=`@X>+@T-W0(@H*(SH@;6%I
M;&)O>"YP:'`Z,S4X"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`BO][AV]74
MW=`@X>+@T-W0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,S@Y"B,L(&9U>GIY"FUS9VED("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R
M("*_X-C:T.?5W=@@Y-#XV][2V"(*"B,Z(&%T=&%C:&UE;G0N<&AP.C,T(&QI
M8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED("),:6YK960@871T86-H;65N=',@
M87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL;"!E>'!I<F4@
M;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T
M:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL("(*
M(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC
M:71L>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X
M-0IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A9&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`HC+"!F=7IZ>0IM
M<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`BO][HXM7=X=K>(.'0W=30
MY]4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C<T"B,L(&9U>GIY
M"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("*TU?CAXM+8U2(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(U"FUS9VED("),;V<@:6XB"FUS9W-T
M<B`BO^#8^-#2X]+0^M4B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3$U
M"B,L('!H<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G<W1R("*_
MX-CXT-+8(.'5(-+>("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ,S<*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(K_@V/C0TN/2
MT/K5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I
M;B!487-K<R(*;7-G<W1R("*WT-30Y]@@W^#8(-_@V/C0TN/2T/K5(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDV"FUS9VED("),;W<B
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,CDY(&UA:6QB;W@N<&AP.C<R
M-R!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$S"FUS9VED("),;W<@
M4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`HC+"!F=7IZ>0IM<V=I
M9"`B36%C:6YT;W-H($9I;&4B"FUS9W-T<B`BO][HXM7=X=K8(.38V^+@V"(*
M"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!F=7IZ
M>0IM<V=I9"`B36%I;"(*;7-G<W1R("*_WNCBU=WAVMX@X=#=U-#GU2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@HC+"!F=7IZ>0IM<V=I9"`B36%I
M;"!0<F5V:65W<R(*;7-G<W1R("*_WNCBU=WAVM@@Y-C;XN#8(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHQ-@IM<V=I9"`B
M36%I;"!S97)V97(@='EP92!T;R!C;VYN96-T('1O.B(*;7-G<W1R("(B"@HC
M.B!F;VQD97)S+G!H<#HT,#(*;7-G:60@(DUA:6QB;W@B"FUS9W-T<B`BO][H
MXM7=X=K>(.'0W=30Y]4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q
M"B,L(&9U>GIY"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/
M<'1I;VYS(@IM<V=S='(@(K_>U-7AX]+0^M`@U]`@W^#8VM#7(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL
M($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")-87)K($%L
M;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-2!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-87)K(&%S.B(*
M;7-G<W1R("*\T.#:V.#0^"#:T-K>.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T
M:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE
M<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA
M<FMU<#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N
M:6YC.C0V"FUS9VED(")-871C:"!!;&P@475E<FEE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H
M($%N>2!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU,3,*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@071T86-H
M;65N="!3:7IE(@IM<V=S='(@(K_@V-K0Y]7=(.30^-LB"@HC.B!L:6(O87!I
M+G!H<#HW.0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@1F]L9&5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.30*
M;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0X.0IM<V=I9"`B36%X:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A
M8VAE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8R-@IM<V=I9"`B365E=&EN9R!#86YC96QL871I;VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I
M9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R("*XW>3>X-S0YMCXT"#7
MT"#AU>#2U>#>XB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*
M;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I9"`B365E=&EN9R!297!L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DX"B,L
M(&9U>GIY"FUS9VED(")-965T:6YG(%5P9&%T92(*;7-G<W1R("*TT"#7T-_>
MY]W5W-4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`S"FUS9VED
M(")-965T:6YG(%5P9&%T92!297%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@
M1F]L9&5R($QI<W0B"FUS9W-T<B`BON+2WN#8(-_0W]K0(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S<V%G92(*;7-G<W1R("*_WN#0VM`B
M"@HC.B!C;VUP;W-E+G!H<#HU-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O<V4N
M<&AP.C8T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A
M9V4@0V]M<&]S:71I;VXB"FUS9W-T<B`BP=[AXM#2X]+0^M4@W][@T-K0(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$
M871E(@IM<V=S='(@(K30XN/<(-W0(-_>X-#:T"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P,PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S
M='(@(K_>X-#:V"#4WB(*"B,Z('-E87)C:"YP:'`Z,S$R"FUS9VED(")-97-S
M86=E(%-E87)C:"(*;7-G<W1R("*QT.#0^"#?WN#0VM`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T
M<B`BL][;U=S8W=`@W=`@W][@T-K0(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS
M9VED(")-97-S86=E(%-O=7)C92(*;7-G<W1R("*XU]+>X"#=T"#?WN#0VM`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(DUE<W-A9V4@
M5FEE=VEN9R(*;7-G<W1R("*_X-73V]74X]+0^M4@W][@T-K8(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-97-S86=E(&9L86=S
M(@IM<V=S='(@(K#BX-C1X^+8(-W0(-_>X-#:T"(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z.#,*;7-G:60@(DUE<W-A9V4@9F]L9&5R<R(*;7-G
M<W1R("*_T-_:V"#7T"#?WN#0VM@B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B
M"FUS9W-T<B`BO]#?VM@@U]`@W][@T-K8(@H*(SH@;6%I;&)O>"YP:'`Z-C8W
M"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G
M<W1R("*XU]'@V.C8(-_@V-K0Y]7=(.30^-LB"@HC.B!M86EL8F]X+G!H<#HV
M-3@*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@96YC<GEP=&5D(@IM<V=S
M='(@(K_>V]CZT"#=T"#?WN#0VM`B"@HC.B!M86EL8F]X+G!H<#HV-3,*(RP@
M9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(K_>V]CZ
MT"#=T"#?WN#0VM`B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z
M,S,*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R("*T
MT.+CW"#=T"#?WN#0VM`B"@HC.B!C;VUP;W-E+G!H<#HX,C0@8V]M<&]S92YP
M:'`Z.#,X"B,L(&9U>GIY"FUS9VED(")-97-S86=E(')E9&ER96-T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("*_WN#0VM#BT"#5(./AW]7HW=X@W^#0XM7=
MT"P@W=X@W=4@U2#7T.?CTM#=T"#2WB(*"B,Z(&-O;7!O<V4N<&AP.C$P.#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C
M97-S9G5L;'DL(&)U="!N;W0@<V%V960@=&\@)7,B"FUS9W-T<B`BO][@T-K0
MXM`@U2#CX=_5Z-W>(-_@T.+5W=`L(-W>(-W5(-4@U]#GX]+0W=`@TMXB"@HC
M.B!C;VUP;W-E+G!H<#HQ,30S(&-O;7!O<V4N<&AP.C$Q-3@*(RP@9G5Z>GD*
M;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN(@IM<V=S='(@(K_>
MX-#:T.+0(-4@X^'?U>C=WB#?X-#BU=W0+"#=WB#=U2#5(-?0Y^/2T-W0(-+>
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,0IM<V=I9"`B365S<V%G
M97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`BL>#>
M^"#=T"#?WN#0VM@@W]X@X>+@T-W0(-_@V"#?X-C:T-<@W=`@W][HXM7=X=K>
MXMX@X=#=U-#GU2(*"B,Z(&UA:6QB;W@N<&AP.C,R,@IM<V=I9"`B365S<V%G
M97,@=&\B"FUS9W-T<B`BO][@T-K8(-3>(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB"FUS9W-T<B`BO-[4V.38YMC@T/@B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.C$R"B,L('!H<"UF
M;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@
M9FEE;&0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4B"FUS9W-T<B`BO^#5W-7AXM@B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,38*(RP@9G5Z
M>GD*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("+>U-@@U-[;U2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3@*;7-G:60@(DUO=F4@<W!A;2!M97-S
M86=E<R!T;R!S<&%M(&9O;&1E<B!A;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@
M24Y"3U@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C4P"B,L(&9U>GIY"FUS9VED(")-;W9E('1O(&9O;&1E<B(*;7-G<W1R("+8
MU]'5X-@@W]#?VM`B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHS,30*(RP@9G5Z>GD*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BW^#5
MW-7AXM@@T][@U2(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP
M:'`Z,3(W"FUS9VED(")-=6QT:7!A<G0O86QT97)N871I=F4B"FUS9W-T<B`B
M(@H*(SH@=&AR96%D+G!H<#HW-B!T:')E860N<&AP.C$U,@HC+"!F=7IZ>0IM
M<V=I9"`B375L=&EP;&4@365S<V%G92!6:65W(@IM<V=S='(@(K_@U=/;U=3C
MTM#ZU2#?WN#0VM@B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C
M:'-E;&5C="YI;F,Z-0IM<V=I9"`B3D].12(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED
M(").3U1%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G
M:60@(DYA;64B"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA
M;64@86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W.`HC+"!F=7IZ>0IM<V=I
M9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(K35^.'BTMC5(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@R
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S@*;7-G:60@(DYE=F5R(@IM
M<V=S='(@(KW8VM[3T.@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38P
M"B,L(&9U>GIY"FUS9VED(").979E<B!S879E(&%T=&%C:&UE;G1S(@IM<V=S
M='(@(KC7T>#8Z-@@W^#8VM#GU=T@Y-#XVR(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHQ,C0*;7-G:60@(DYE=R(*;7-G<W1R("*]WM(B"@HC.B!L:6(O
M24U0+G!H<#HU-C,*(RP@9G5Z>GD*;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T
M<B`BON+2WN#8(-_0W]K0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X
M"FUS9VED(").97<@36%I;"(*;7-G<W1R("*]WM+0(-_>X-#:T"(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ.2!L:6(O0FQO8VLO=')E95]F;VQD97)S
M+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B3F5W($UE<W-A9V4B"FUS9W-T<B`B
MP=O5U-W0(-_>X-#:T"(*"B,Z(&UA:6QB;W@N<&AP.C<W-B!L:6(O34E-12](
M96%D97)S+G!H<#HQ.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE
M=R!-97-S86=E('1O("5S(@IM<V=S='(@(KW>TM@@W][@T-K8(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ.0IM<V=I9"`B3F5W(&UE<W-A9V5S
M(@IM<V=S='(@(KW>TM@@W][@T-K8(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B3F5X="(*;7-G<W1R("+!V]74W=XB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S
M"FUS9VED(").97AT($UE<W-A9V4B"FUS9W-T<B`BP=O5U-W0(-_>X-#:T"(*
M"B,Z(&UA:6QB;W@N<&AP.C,U-@IM<V=I9"`B3F5X="!086=E(@IM<V=S='(@
M(L';U=3=T"#AXN#0W=`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW-PIM<V=I9"`B3F\B
M"FUS9W-T<B`BO=4B"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED(").;R!#97)T
M:69I8V%T92!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Y"FUS9VED(").
M;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z
M,S<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*
M;7-G<W1R("*]WM+8(-_>X-#:V"(*"B,Z('!G<"YP:'`Z,3,W"FUS9VED(").
M;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHX-`IM<V=I9"`B3F\@4&5R<V]N86P@
M0V5R=&EF:6-A=&4@4')E<V5N="(*;7-G<W1R("(B"@HC.B!L:6(O36%I;&)O
M>"YP:'`Z,S(Y"B,L(&9U>GIY"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS
M9W-T<B`BNM[@U=/8X-#=(.+5VN'B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHQ-0IM<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C$U,0IM<V=I9"`B3F\@4R]-24U%('!U8FQI
M8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]T;F5F+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B3F\@871T86-H;65N=',@
M9F]U;F0N(@IM<V=S='(@(K_@V-K0Y]7=V"#DT/C;WM+8(@H*(SH@;&EB+T-R
M>7!T+U--24U%+G!H<#HQ-#`*;7-G:60@(DYO(&5M86EL(&EN9F]R;6%T:6]N
M(&QO8V%T960@:6X@=&AE('!U8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z(&%C
M;"YP:'`Z-S(@86-L+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R
M('-E;&5C=&5D+B(*;7-G<W1R("+=U2#5(-C7T>#0W=`@W]#?VM`B"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD97)S(&%R
M92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B(@H*(SH@
M9F]L9&5R<RYP:'`Z,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L:6(O1F]L9&5R
M+G!H<#HU-3`*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I960B"FUS
M9W-T<B`BO=4@X=4@W=#2U=35W=@@W]#?VM@B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,30W"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@
M;F5W(&UE<W-A9V5S(@IM<V=S='(@(KW5(-C7T>#8Z-#=V"#?WN#0VM@B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30T"B,L(&9U>GIY"FUS9VED(").
M;R!F;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(KW5(-C7
MT>#8Z-#=V"#?WN#0VM@B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(U"B,L(&9U
M>GIY"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R("+?X-7<
MU>'BV"#?WN#0VM`@TMXB"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S<Q"B,L(&9U
M>GIY"FUS9VED(").;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A<F-H+B(*
M;7-G<W1R("*]U2#5(-_@WMW0^-35W=`@W=CBXR#5U-W0(-_>X-#:T"(*"B,Z
M('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K
M97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,38U"FUS9VED
M(").;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@<VUI;64N<&AP.C(P,0IM<V=I9"`B3F\@<&5R<V]N86P@4R]-
M24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<W!E
M;&QI;F<N<&AP.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M
M(&-O;F9I9W5R960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM
M<V=S='(@(KW5W-`@W^#0TM[?V.'=V"#3X-7HVM@B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`P"B,L(&9U>GIY"FUS9VED(").;R!S
M=6=G97-T:6]N<R(*;7-G<W1R("*_X-74V][7V"(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z-38T"FUS9VED(").;R!S=7!P;W)T960@24U!4"!A=71H96YT
M:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&%C;"YP:'`Z-C@@86-L+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E
M<B!S<&5C:69I960N(@IM<V=S='(@(KW5(.'5(-W0TM74U=W8(-_0W]K8(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P.0IM<V=I9"`B3F]N(%!A
M<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,3$@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN
M8SHT,`HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-2!T
M96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B3F]N92(*;7-G<W1R("*]V-74
MW=`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.34*;7-G
M:60@(DYO<FUA;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*
M;7-G:60@(DYO="!$96QE=&5D(@IM<V=S='(@(KW5(-C7T>#8Z-#=V"(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3(@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@1')A9G0B"FUS9W-T<B`B
MO=4@W=77T-+@Z-7=V"`H1')A9G0I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-`IM
M<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R("*]U=+0UMW8(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T(%!E<G-O
M;F%L(@IM<V=S='(@(KW5(-O8Y]W8(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z
M,3,Y(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP="]334E-12YP
M:'`Z,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED(").
M;W0@9&5L971E9"!M97-S86=E<R(*;7-G<W1R("*]U2#8U]'@V.C0W=@@W][@
MT-K8(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B
M3F]T(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R("*]U=+0UMW8(-_>X-#:
MV"(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP
M:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$V"B,L
M(&9U>GIY"FUS9VED(").;W1H:6YG(@IM<V=S='(@(L;8XM#B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-PHC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R
M(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@
M9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`BL>#>^"#=T"#AXM#@V"!S96YT
M+6UA:6P@W]#?VM@@U-`@X=4@Y^/2T-#B+"#0VMX@X=4@T>#8Z-4@U=3=T.@@
MW-7AU>?=WB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*(RP@9G5Z
M>GD*;7-G:60@(DYU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@
M:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R("*QX-[X(-W0(.'B
MT.#8('-E;G0M;6%I;"#?T-_:V"#4T"#AU2#GX]+0T.(L(-#:WB#AU2#1X-CH
MU2#5U-W0Z"#<U>'5Y]W>(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR-30@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4U,@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,S"FUS9VED(")/2R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-2!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHT.`IM<V=I9"`B3U(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S
M(@IM<V=S='(@(L'BT.#8(-_>X-#:V"(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD
M('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"XB"FUS9W-T<B`BP>+0
MX-CBU2!S96YT+6UA:6P@W]#?VM@@X=4@V.'GV.'BU=W8+B(*"B,Z(&QI8B]"
M;&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E
M<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHW.0HC+"!F=7IZ
M>0IM<V=I9"`B3VYL>2!O;F4@9F]L9&5R('-H;W5L9"!B92!S96QE8W1E9"!F
M;W(@=&AI<R!A8W1I;VXN(@IM<V=S='(@(KC7T=7@V"#AT-S>(-74W=`@W]#?
MVM`@U]`@WM+0T"#>W]7@T.;8^-`N(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC
M.C$P('1E;7!L871E<R]M96YU+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E
M;B!&;U]L9&5R(@IM<V=S='(@(K[BTM[@V"#?T-_:T"(*"B,Z(&9O;&1E<G,N
M<&AP.C0R-PHC+"!F=7IZ>0IM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G<W1R
M("*^XM+>X-@@W]#?VM`B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S`U"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC
M.B!F971C:&UA:6PN<&AP.C,S('1E;7!L871E<R]F971C:&UA:6PO=&]P+FEN
M8SHS"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHV"B,L
M(&9U>GIY"FUS9VED(")/=&AE<B!-86EL($%C8V]U;G1S(@IM<V=S='(@(K3@
MX]/8(-[?YMC8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G
M:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`BM.#CT]@@WM_FV-@B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,0IM<V=I9"`B3W5T8F]U;F0@
M4V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S
M92YI;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HR.3`*;7-G:60@(E!'4"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(E!'4"!%
M;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`BON+:T-;8(/C0(-_>X-#:T.+0(@H*
M(SH@8V]M<&]S92YP:'`Z,S4X"B,L(&9U>GIY"FUS9VED(")01U`@17)R;W(Z
M("(*;7-G<W1R("*SX-7HVM`B"@HC.B!C;VUP;W-E+G!H<#HS,S<*;7-G:60@
M(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV
M871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,@HC+"!F=7IZ>0IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`BOM_F
MV-@B"@HC.B!P9W`N<&AP.C,P"FUS9VED(")01U`@4&%S<W!H<F%S92!);G!U
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G
M:60@(E!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C$W,PIM<V=I9"`B4$=0(%!U8FQI8R!+97D@5&5X
M="(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$T.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A
M<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(K_0W]K0XM`@7"(E<UPB
M(-4@X^'?U>C=WB#:X-78X-#=T"XB"@HC.B!P9W`N<&AP.C(T-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<
M(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(K_0W]K0XM`@
M7"(E<UPB(-4@X^'?U>C=WB#8U]'@V.C0W=`N(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHX
M"B,L(&9U>GIY"FUS9VED(")01U`@4VEG;B!-97-S86=E(@IM<V=S='(@(KCA
MW^#0XM@@W][@T-K0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L
M:7-T+FEN8SHY"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@<&=P+G!H<#HR,#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!P
M<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(K_>XM_8
MX=[B(-4@X^'?U>C=WB#7T-S5W=7B+B(*"B,Z('!G<"YP:'`Z,3<W"FUS9VED
M(")01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")0
M1U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`X"FUS9VED("(B
M"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@
M9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.34*
M;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E
M('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED("(B
M"B)01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S
M960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D
M:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E
M='1I;F<@;W(@96QS92!T:&4@4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O
M<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T;R!$971E8W0@
M4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R("(B"@HC.B!L
M:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R(%-3
M3"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")03U`S(&]V97(@
M4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`BP>+@T-W0("5D
M(-[4("5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP,PIM<V=I9"`B
M4&%G92!W:71H('1H92!&:7)S="!5;G-E96X@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`T"FUS9VED(")086=E('=I
M=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB
M"FUS9W-T<B`BM-7;*-[2V"DB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,3(S"FUS9VED(")087-S<&AR87-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@*$%G86EN*2(*
M;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C,U('!G<"YP:'`Z,S$P"B,L(&9U
M>GIY"FUS9VED(")087-S<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"XB
M"FUS9W-T<B`BO][@T-K0XM`@U2#CX=_5Z-W>(-_@T.+5W=`L(-W>(-W5(-4@
MU]#GX]+0W=`@TMXB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI
M;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHR.0IM<V=I9"`B
M4&%S<W!H<F%S93HB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,3(*;7-G:60@
M(E!A<W-P:')A<V5S(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*(SH@
M<&=P+G!H<#HQ,30*;7-G:60@(E!A<W-P:')A<V5S(&1O(&YO="!M871C:"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M,C`@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<Q"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3DR"FUS9VED(")087-S=V]R9"(*;7-G
M<W1R("*[WM?8W=K0(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C0X"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(KC7T=7@V"#>W]7@T.;8V"#7
MT"#>U.#6X]+0^M4@VM[8(/S5(.'5(-C7TN#HX]+0T.(@W^#8(-_@V/C0TN/2
MT/K5+B(*"B,Z(&%C;"YP:'`Z-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E<FUI
M<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N(&YO="!B92!C:&%N9V5D+B(*;7-G
M<W1R("(B"@HC.B!M97-S86=E+G!H<#HT.3,@;6%I;&)O>"YP:'`Z-S`S('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;&5G96YD+FEN8SHQ,`IM<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`B
MN]CGW=XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E
M<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(KO8Y]W8(-C=Y-[@W-#FV-@B
M"@HC.B!P9W`N<&AP.C$R,`IM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7!A:7(@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H
M<#HQ,C<*;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")0
M97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM
M<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ,S(*;7-G:60@(E!E<G-O;F%L(%,O
M34E-12!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(R"FUS9VED(")0;&%C92!Y;W5R
M('-I9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_(@IM<V=S
M='(@(K+<U>+=V"#?WN+?V.$@W^#5U"#BU=KAXM[B(-W0(-K>^"#AU2#>U-/>
MTM#@T"#8V]@@W^#5W^#0_-`_(@H*(SH@8V]M<&]S92YP:'`Z,C4T"FUS9VED
M(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3D*;7-G:60@(B(*(E!L87D@<V]U
M;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T
M;R!S=7!P;W)T(&5M8F5D9&5D("(*(G-O=6YD(&9I;&5S+B`@06QM;W-T(&%L
M;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@
M=VEL;"`B"B)R97%U:7)E(&$@<&QU9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.B(*;7-G<W1R(")<
M7&ZRW=7AU>+5(-C<U2#=T"#=WM+0XM`@W]#?VM`Z7%QN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#(@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E
M;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B7%QN
MLMW5X=7BU2#8W-4@W=`@W=[2T.+0(-_0W]K0.EQ<;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,W"FUS9VED(")0;&5A<V4@96YT
M97(@=&AE(&YE=R!N86UE.B(*;7-G<W1R("*RW=7AU>+5(-/>(-W>TM[BWB#8
MW-4Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A
M<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE
M960@=&\@(@HB96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E
M<W-I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR
M87-E+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y
M+B!9;W4@=VEL;"!O;FQY(&YE960@(@HB=&\@96YT97(@=&AI<R!P87-S<&AR
M87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z(')E8V]M
M<&]S92YP:'`Z.3<*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@
M<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4
M('5S:6YG("(*(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A
M9V5S(&EN('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G
M(&EN(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I
M<R!T;R!K965P(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E
M<W-I;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S$*
M(RP@9G5Z>GD*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N
M(@IM<V=S='(@(K+5(-S>V]C<U2#=T-+5U-7BU2#2T.C5(-K>X-CAW=CGVMX@
MV-S5(-@@V][7V-W:T"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-C<*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64N(@IM<V=S='(@(K+5(-S>V]C<U2#=T-+5U-7BU2#2T.C5(-K>X-CAW=CG
MVMX@V-S5(-@@V][7V-W:T"(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O24U0
M+G!H<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I
M;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`BP-#7X-7HV"#4TM[AW-CAV]7=
MV"#8V]@@W=72T-O8U-W8(-#4X-7AV"XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C0R"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H92!F;VQL
M;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@
M9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHV,0IM<V=I9"`B4&QE87-E('-E
M;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N
M(@IM<V=S='(@(KC7T=7@V"#?T-_:T"#?X-74(-C7TN#HX]+0^M4@W=`@T=C;
MWB#:WOC0(-#:YMCXT"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3`R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F
M<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R("*XU]'5X-@@T=#@U=P@U=3=
MT"#?T-_:T"#7T"#?X-71T.#CTM#ZU2XB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VIA=F%S8W)I<'0N:6YC.C0Q"FUS9VED(")0;&5A<V4@<V5L96-T(&%T(&QE
M87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+B(*;7-G<W1R("*XU]'5X-@@T=#@
MU=P@U=3=T"#?T-_:T"#7T"#?X-71T.#CTM#ZU2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS9VED(")0;&5A<V4@<V5L96-T
M(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN(@IM<V=S='(@
M(KC7T=7@V"#AT-S>(-74W=`@W]#?VM`@U]`@WM+0T"#>W]7@T.;8^-`N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"B,L(&9U>GIY
M"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T
M:&4@<FEG:'0Z(@IM<V=S='(@(KC7T=7@V"#8V]@@X^#5U-@@X=O5U-W>.B(*
M"B,Z(&-O;F9I9R]M;W1D+G!H<"YD:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y
M($AO<F1E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,30*(RP@9G5Z>GD*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET
M:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`BOM34U=O8(-/>(-_>XM_8X=[B
M(.'>(.;@XM@@*"<M+2`G*2(*"B,Z('-M:6UE+G!H<#HR-#$@<&=P+G!H<#HR
M-3<@9FEL=&5R<')E9G,N<&AP.C0P"B,L(&9U>GIY"FUS9VED(")0<F5F97)E
M;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`BO]#?VM#BT"!<
M(B5S7"(@U2#CX=_5Z-W>(-K@U=C@T-W0+B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FEN8SHS"B,L(&9U>GIY"FUS9VED(")0<F5V:65W
M(@IM<V=S='(@(K_@U>+EWM3=T"#AXN#0W=`B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U<R!-
M97-S86=E(@IM<V=S='(@(K_@U>+EWM3=T"#?WN#0VM`B"@HC.B!M86EL8F]X
M+G!H<#HS-#<*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS9W-T<B`BO^#5XN7>
MU-W0(.'BX-#=T"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHS,PIM<V=I9"`B4')I;G0B"FUS9W-T<B`BO]7GT.+8(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*(RP@9G5Z>GD*;7-G
M:60@(E!R:6]R:71Y(@IM<V=S='(@(K_5Y]#BV"(*"B,Z('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I9"`B4')I=F%T92!+97D@4&%S
M<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U
M.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S
M96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T
M=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0
M<F]T;V-O;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y
M"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N
M(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E;&5T
M960N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!U<E]G92!$96QE=&5D(@IM<V=S
M='(@(K[AXN#0W=@@V-?1X-CHT-W8(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE
M=&5D+FEN8SHX"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(K[AXN#0
MW=@@V-?1X-CHT-W8(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R
M("*XU]'@V.C8(-_0W]K0*-@I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G<W1R("*Z
MWMO:XR#GU>'BWB#4T"#3V"#>XN'BX-#=X]+0W"#8U]'@V.C0W=CBU2#>U"#?
MT-_:T.+0(-?0(-[BW]#4WN;8.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,#4*(RP@9G5Z>GD*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H
M(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S
M='(@(M35W=`@X>+0X-CBU2#?WN#0VM@@WN+AXN#0W=@@T]@@WM0@W]#?VM#B
MT"#7T"#>XM_0U-[FV"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*
M(RP@9G5Z>GD*;7-G:60@(E!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A
M<V@@9F]L9&5R/R(*;7-G<W1R(")0=7)G92!O;&0@;65S<V%G92!I;B!T:&4@
M5')A<V@@9F]L9&5R(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?
M=')A<V@N<&AP.C8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")0=7)G
M:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R("(@
MW][@T-K0*-@I(-[4(-_0W]K0XM`@U]`@WN+?T-3>YM@N(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8S"B,L(&9U>GIY"FUS
M9VED(")0=7)G:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS
M9W-T<B`B(-_>X-#:T"C8*2#>U"#?T-_:T.+0(-?0(-[BW]#4WN;8+B(*"B,Z
M('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.
M3R!,24U)5"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N
M:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@3D\@
M3$E-250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS
M9W-T<B`BQMCBT.(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS.#8*;7-G:60@(E)E7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HU,`HC+"!F=7IZ>0IM<V=I
M9"`B4F5C96EV960@3VXB"FUS9W-T<B`BO^#8W-7=V"#=T#HB"@HC.B!L:6(O
M4V5A<F-H+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4F5C96EV960@4VEN8V4B
M"FUS9W-T<B`BO^#8W-7=V"#=T#HB"@HC.B!L:6(O4V5A<F-H+G!H<#HU-`HC
M+"!F=7IZ>0IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`BO^#8W-7=
MV"#=T#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E)E9&ER96-?="(*;7-G<W1R("*_X-7=
MT.'>Y]@B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(K_@U=W0X=[GV"(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E
M9&ER96-T($UE<W-A9V4B"FUS9W-T<B`BO^#5W=#AWN?8(-_>X-#:T#HB"@HC
M.B!C;VUP;W-E+G!H<#HW.#<*;7-G:60@(E)E9&ER96-T('1H:7,@;65S<V%G
M92(*;7-G<W1R("*_X-7=T.'>Y]@@^-`@W][@T-K0TM`Z(@H*(SH@8V]M<&]S
M92YP:'`Z.#0W"FUS9VED(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@
M(KW5(./AW]7HW=X@W^#5W=#AWN?CTM#ZU2XB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU.#,*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B
MON'2U=;8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X-`IM<V=I9"`B
M4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(K[ATM76V"#?X-C:T-<@
MW=`@W]#?VM@Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.2!T
M96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C0*(RP@9G5Z>GD*;7-G:60@
M(E)E;&]A9"(*;7-G<W1R("*^X=+5UM@@W^#8VM#7(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I97<B"FUS9W-T
M<B`BON'2U=;8(-_@V-K0UR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU,C8@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM<V=I9"`B4F5M
M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW.0IM<V=I9"`B4F5M96UB97(@
M=&AE(&QA<W0@=FEE=R(*;7-G<W1R("*WT-_0W-7BV"#?WN';U=35W2#?X-C:
MT-<B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*;7-G<W1R("*_WNCBU=WA
MVMX@X=#=U-#GU2(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT
M,0IM<V=I9"`B4F5M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R("+>U.'BX-#=V"#8
MU]+>X"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*(RP@
M9G5Z>GD*;7-G:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T<B`BO^#5V-S5
MW>/2T/@@W]#?VM`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L
M(&9U>GIY"FUS9VED(")296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I
M;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(K_@U=C<U=WCTM#X(/C0(-_0W]K0
MXM`@O^#0XM7=V"#=T"#?WN?5XM[:WN(@WM0@W-7AU>;>XB(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C0U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296YA;6EN9R!<
M(B5S7"(@=&\@7"(E<UPB(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9"(*;7-G<W1R("*_X-78W-7=X]+0^M7BWB#=T"!<(B5S7"(@TMX@
M7"(E<UPB(-W5(./AW]70+B"^TM`@T]X@TN#0XM@@X=7@TM7@WN(B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*(RP@9G5Z
M>GD*;7-G:60@(E)E<&Q?>2!T;R!,:7-T(@IM<V=S='(@(K[4T][2WN#8(-W0
M(.'8XM4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U
M"FUS9VED(")297!L86-E('=I=&@Z(@IM<V=S='(@(K?0W-7=V"#AWCHB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I
M9"`B4F5P;'DB"FUS9W-T<B`BOM33WM+>X-@B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,S$Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#D*
M(RP@9G5Z>GD*;7-G:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@(K[4T][2WN#8
M(-W0(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$S"FUS9VED(")297!L>2!T;R!!;&PB"FUS9W-T<B`BOM33WM+>X-@@W=`@
MX=CBU2(*"B,Z(&-O;7!O<V4N<&AP.C<S,PIM<V=I9"`B4F5P;'D@=&\@06QL
M.B(*;7-G<W1R("*^U-/>TM[@V"#=T"#AV.+5.B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B
M4F5P;'D@=&\@3&ES="(*;7-G<W1R("*^U-/>TM[@V"#=T"#AV.+5(@H*(SH@
M8V]M<&]S92YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!,:7-T
M.B(*;7-G<W1R("*^U-/>TM[@V"#=T"#AV.+5.B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B
M4F5P;'D@=&\@7T%L;"(*;7-G<W1R("*^U-/>TM[@V"#=T"#AV.+5(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3,W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*
M;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S4*;7-G:60@
M(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,T"FUS9VED
M(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-PHC+"!F=7IZ>0IM<V=I
M9"`B4F5P;'DM5&\B"FUS9W-T<B`BOM33WM+>X-@@W=`Z("(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HT,#D*;7-G:60@(E)E<&QY+51O.B`B"FUS9W-T<B`BOM33
MWM+>X-@@W=`Z("(*"B,Z(&-O;7!O<V4N<&AP.C<S,0IM<V=I9"`B4F5P;'DZ
M(@IM<V=S='(@(K[4T][2WN#8.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM
M<V=S='(@(K35Y-C=V.#0^"#:T-K>(+W5W][6U=O=T"#?WN#0VM`B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3
M<&%M(@IM<V=S='(@(K35Y-C=V.#0^"#:T-K>(+W5W][6U=O=T"#?WN#0VM`B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#,*(RP@9G5Z
M>GD*;7-G:60@(E)E<75E<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(K_>
MT=#@T/@@W][BTN#4T"#7T"#?X-C<U=W0(-_>X-#:T"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU.#4*;7-G:60@(E)E<75E<W0@9&5L:79E<GD@8V]N
M9FER;6%T:6]N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3<S"B,L(&9U>GIY"FUS9VED(")297%U97-T(')E860@<F5C96EP=',_
M(@IM<V=S='(@(K_>T=#@T/@@W][BTN#4T"#7T"#?X-C<U=W0(-_>X-#:T"(*
M"B,Z(&UA:6QB;W@N<&AP.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-CDW"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP;&%T
M97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$V,0IM<V=I9"`B4F5S970B"FUS9W-T<B`BOM3=WM+>(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-0IM<V=I9"`B4F5S<&]N9&5N="!3
M=&%T=7,@57!D871E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T
M<B`BO^#>U-[;UM@B"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")297-U
M;64@>6]U<B!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O
M(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM<V=S='(@(L'>X>+0TN/2T/K5
M(-_>X-#:T"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C
M="YI;F,Z,S$@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8Y"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C,R"FUS
M9VED(")2971U<FX@=&\@1F5T8V@@36%I;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O
M;F]T86-T:79E+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C$P,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E
M+FEN8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-S,*(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!/
M<'1I;VYS(@IM<V=S='(@(K3@X]/8(-[?YMC8(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<Q.`IM<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X
M(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A
M(&UE<W-A9V4_(@IM<V=S='(@(B(*(K+@T.+8(.'5(-W0(-_>Z.+5W>':WN+>
M(.'0W=30Y]4@W]X@T>#8Z-7ZU2P@W^#5W-7AXN/2T/K5(-C;V"#:WM_8X-#Z
MU2#?WN#0VM@_(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM
M<V=I9"`B4F]L92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C$T,B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S-PHC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.0IM<V=I9"`B4R]-24U%(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI
M;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z,SDT"FUS9VED(")3+TU)344@17)R;W(Z("(*
M;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS-S,*;7-G:60@(E,O34E-12!%
M<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME
M>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,0HC
M+"!F=7IZ>0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS9W-T<B`BOM_FV-@B
M"@HC.B!S;6EM92YP:'`Z-#D*;7-G:60@(E,O34E-12!087-S<&AR87-E($EN
M<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-30*;7-G:60@(E,O34E-12!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q
M=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z
M('-M:6UE+G!H<#HQ-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E,O
M34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+B(*;7-G<W1R("*_T-_:T.+0(%PB)7-<(B#5(./AW]7HW=X@V-?1
MX-CHT-W0+B(*"B,Z('-M:6UE+G!H<#HQ-C(*;7-G:60@(E,O34E-12!0=6)L
M:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U8FQI
M8R!+97ER:6YG(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR,3$*;7-G:60@
M(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A
M9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP
M=%]L:7-T+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%-I9VX@365S
M<V%G92(*;7-G<W1R("*XX=_@T.+8(-_>X-#:T"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*;7-G:60@(E,O34E-12!3:6=N
M+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI
M;64O;F]T86-T:79E+FEN8SHT"FUS9VED(")3+TU)344@<W5P<&]R="!I<R!D
M:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HR-#$*;7-G:60@(B(*(E,O34E-12!S=7!P
M;W)T(&ES(&YO="!C=7)R96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I
M<R!U;F%B;&4@=&\@8F4@(@HB9&5C<GEP=&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PIM<V=I9"`B(@HB4R]-24U%
M('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H
M:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO="`B"B)B92!D:7-P;&%Y960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@
M9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*
M;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O
M=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT
M;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA
M;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E("(*(G1H92!3+TU)344@9F5A='5R
M97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`U"FUS9VED(")33510(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(U-0HC
M+"!F=7IZ>0IM<V=I9"`B4U]U8FIE8W0B"FUS9W-T<B`BPM7<T"(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,V,PHC+"!F=7IZ>0IM<V=I
M9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R("*WT.?CTM#X(-K>W]CXT"#2
MWB`B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,S(*(RP@9G5Z>GD*;7-G:60@(E-A7W9E(&%S(@IM<V=S='(@(K?0Y^/2T/@@
MVM#:WB(*"B,Z('-E87)C:"YP:'`Z,S$V('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B4V%V92(*;7-G<W1R("*W
MT.?CTM#X(-K0VMXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU,S@*;7-G:60@(E-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN
M('-E;G0M;6%I;"!F;VQD97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C0S,PIM<V=I9"`B4V%V92!$<F%F="(*;7-G<W1R("*WT.?CTM#X
M(-W5U]#2X.C5W=`B"@HC.B!S879E:6UA9V4N<&AP.C0R"B,L(&9U>GIY"FUS
M9VED(")3879E($EM86=E(@IM<V=S='(@(K?0Y^/2T/@@VM#:WB(*"B,Z(&QI
M8B]-24U%+T-O;G1E;G1S+G!H<#HR,#0*;7-G:60@(E-A=F4@26UA9V4@:6X@
M1V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z-3D@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#`*(SH@=&5M
M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,3(@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$T.`HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,3,*
M(RP@9G5Z>GD*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("*^W^;8V"(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,`IM<V=I9"`B
M4V%V92!3=&%T:6]N97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0S,PHC+"!F=7IZ>0IM<V=I9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B
MM]#GX]+0^"#=U=?0TN#HU=W0(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")3879E(&%S(@IM<V=S='(@(K?0
MY^/2T/@@VM#:WB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G
M:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-S(*;7-G:60@(E-A=F4@<F5C:7!I96YT
M<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,C<*
M;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*(RP@9G5Z>GD*
M;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R("*WT.?CTM#X(-_@T.+5
MW=`@W][@T-K0(@H*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`BO=7CX=_5Z-W>(-?0Y^/2
MX]+0^M4@TMX@W]#?VM#BT""]U=?0TN#HU=W8+B"^TM`@T]X@TN#0XM@@X=7@
MTM7@WN(Z("5S(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHQ.3D@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O
M0FQO8VLO=')E95]F;VQD97)S+G!H<#HT,0IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(K_@U='0X./2T/@B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI
M;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S(@IM<V=S='(@(K_@U='0
MX./2T/@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(P"B,L(&9U>GIY
M"FUS9VED(")396%R8V@@3W!T:6]N<R(*;7-G<W1R("*TX./3V"#>W^;8V"(*
M"B,Z('-E87)C:"YP:'`Z,C8U"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G
M<W1R("+`U=?CV^+0XM@@WM0@W^#5T=#@X]+0^M7BWB(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,30@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS,0IM<V=I9"`B4V5E;B(*;7-G<W1R("*_X-[GV.+0W=@B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*;7-G:60@(E-E;&5C
M="(*;7-G<W1R("*XU]'5X-@B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!!;F]T:&5R($%C
M8V]U;G0B"FUS9W-T<B`BN-?1U>#8(-W8U=3=WB(*"B,Z('1E;7!L871E<R]S
M96%R8V@O9FEE;&1S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@
M9&%T92(*;7-G<W1R("*XU]'5X-@@V-35W>+8XM7B(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]F:65L9',N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M82!F:65L9"(*;7-G<W1R("*XU]'5X-@@T]@@X=CBU2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PHC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`BN-?1U>#8(-W8U=3=WB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R
M8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`BN-?1U>#8(-C7TM[@(-?0
M(-'0X-#ZU2#8(-3>U-#2T/K5(-#4X-7AV"#2WB#0U.#5X=#@WN(N(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I9"`B4V5L96-T(&%L
M;"(*;7-G<W1R("*XU]'5X-@@T]@@X=CBU2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,R,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E
M<RXB"FUS9W-T<B`B(@HBN-?1U>#8(-_>(-K>^"#@U=0@U-`@X=4@W^#5T=#@
MX]+0T.(@T-3@U>'0X-CBU2#?X-@@X-#HV.#CTM#ZU2#=T"#0U.#5X=CBU2XB
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR
M,0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B
MN-?1U>#8(-W8U=3=WB(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(KC7T=7@V"#=V-74W=XB
M"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I
M9"`B4V5L96-T('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE
M8W0N:6YC.C(Q"FUS9VED(")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,S`Y"B,L(&9U>GIY"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS
M.B(*;7-G<W1R("*XU]'@T-W8(-#4X-7AT.#8.B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E
M<G9E<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C`T"B,L(&9U>GIY"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*
M;7-G<W1R("*XW>3>X-S0YMCXT"#7T"#AU>#2U>#>XB(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0S,0IM<V=I9"`B4V5N9"!-97-S86=E(@IM<V=S='(@(KCA
MW^#0XM@@W][@T-K0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P,PIM
M<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE
M('-E;F1E<C\B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,SDW"B,L(&9U
M>GIY"FUS9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(K_0W]K0(+_@
MT.+5W=@Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN
M8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`BO]#?VM`@
MO^#0XM7=V#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S,B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$T-@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$U,PIM<V=I9"`B4V5R=F5R(@IM<V=S='(@(L'5X-+5
MX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VXB"FUS9W-T<B`BN-WD
MWN#<T.;8^-`@U]`@X=7@TM7@WN(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<CHB"FUS9W-T
M<B`BP=7@TM7@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED
M(")3970@<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M
M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N(@IM<V=S='(@(B(*(KC7T=7@U>+5
M(-_>U-7AX]+0^M`@U]`@WMW0(.CBWB#AU2#AV^/GX]+0(-_@V"#?X-7<U>'B
MX]+0^M4@V"#1X-CHU?K5(-_>X-#:V"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3(Y"FUS9VED(")3970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H
M96X@8V]M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$*(RP@9G5Z>GD*;7-G:60@(E-H87)E($9O;&1E
M<G,B"FUS9W-T<B`BO^#>W-7=V"#?T-_:T"(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S
M(@IM<V=S='(@(K_0W]K0(+_@T.+5W=@Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,R"FUS9VED(")3:&%R92!Y;W5R(&UA:6P@9F]L9&5R<R!W:71H
M(&]T:&5R('5S97)S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C8Y"FUS9VED("(B"B)3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U
M;W1E9"!T97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C
M86X@8F4@(@HB=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW"FUS9VED
M(")3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S
M8V%N;F5D(&9O<B!01U`@9&%T83\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B4VAO=6QD('1H92!C;VUP;W-E('=I
M;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_(@IM<V=S='(@
M(B(*(K30V]@@U-`@T]X@U]#BTM[@T-P@W^#>U][@WN(@P=[AXM#2V"#?WB#7
MT.?CTN/2T/K5(-W0(-_>X-#:T.+0(-+>(+W5U]#2X.C5W=@_(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C0*;7-G:60@(E-H;W5L9"!Y;W5R(%!'4"!P
M=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@
M9&5F875L=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G
M<W1R("+!WM'5X-@@T]@@X=CBU2#?T-_:V"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VAE861E<G,N:6YC.C8W"FUS9VED(")3:&]W($%L;"!(96%D97)S(@IM
M<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM<V=I9"`B4VAO=R!$96QE
M=&5D(@IM<V=S='(@(K_@V-K0UM@@V-?1X-CHT-W8(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*;7-G:60@(E-H;W<@3&EM:71E9"!(
M96%D97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E
M<G,N:6YC.C<P"B,L(&9U>GIY"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!)
M;F9O<FUA=&EO;B(*;7-G<W1R("*[V.?=V"#8W>3>X-S0YMC8(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B4VAO
M=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<R(*;7-G<W1R("*_X-72U]7<V"#?
MT-_:T"C8*2(*"B,Z(&9O;&1E<G,N<&AP.C(Y.`IM<V=I9"`B4VAO=R!5;G-U
M8G-C<FEB960B"FUS9W-T<B`BO^#8VM#6V"#=U=_@U=+7U=S0W=@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`X"FUS9VED(")3:&]W(&%N(&EC;VX@
M=&\@86QL;W<@<W1R:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G
M97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`R
M"B,L(&9U>GIY"FUS9VED(")3:&]W(&QE9V5N9"!I;B!T:&4@;6%I;&)O>"!V
M:65W/R(*;7-G<W1R("*QX-[X(-W0(-_>X-#:V"#?WB#AXN#0W=`@W^#8(-_@
MV-K0UR#=T"#?WNCBU=WAVM[BWB#AT-W4T.?5(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@T,`IM<V=I9"`B4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D
M(&UE<W-A9V5S(&]N;'D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-#@*;7-G:60@(E-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-S<*;7-G
M:60@(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDU"FUS
M9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F:6QT97(@
M:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(X"B,L(&9U>GIY"FUS9VED(")3:&]W('1O=&%L(&YU
M;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(K_0XM7:T"#4WB#2
MT.C8XM4@W][HXM7=X=K8(-_0W]K8.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-C8*;7-G:60@(E-H;W=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G
M:60@(E-I7WIE(@IM<V=S='(@(K/>V]7<V-W0(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;&5G96YD+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B4VEG;F5D(@IM
M<V=S='(@(K/>V]7<V-W0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS9W-T<B`BL][;U=S8W=`B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q"FUS
M9VED(")3;W)T(&)Y($%R<FEV86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B
M>2!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@1G)O
M;2!!9&1R97-S(@IM<V=S='(@(K[4(-#4X-7AT"(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*(RP@9G5Z>GD*;7-G:60@
M(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(K/>V]7<V-W0(-W0(-_>
MX-#:T"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R
M("(@O=#AV][2.B`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE
M861E<G,N:6YC.C,Q"FUS9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q
M"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`B
MOM0@T-3@U>'0(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC
M.C(S"B,L(&9U>GIY"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`BO]#?
MVM`@ON+?T-3>VCHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G<W1R("+!W]7F
MV/C0V]W8(-?=T.;8(@H*(SH@<V5A<F-H+G!H<#HQ,S,*;7-G:60@(E-P96-I
M86P@5FER='5A;"!&;VQD97)S(&-A;B!N;W0@8F4@961I=&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#,*;7-G
M:60@(E-P96QL($-H96-K(@IM<V=S='(@(K_@WM+5X-K0(-W0(-_@T-+>W]CA
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED
M(")3<&5L;"!#:&5C:V5R(@IM<V=S='(@(K_@WM+5X./2T.<@W=`@W^#0TM[?
MV.$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS9VED(")3<&5L;"!C
M:&5C:R!C;VUP;&5T92(*;7-G<W1R("*WT-+@Z-@@W^#>TM7@VM#BT"#=T"#?
MX-#2WM_8X2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@
M(E-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI
M;F<N(@IM<V=S='(@(K_@T-+>W]CAW=@@T^#5Z-K8(-_>(-_@WM?>X"#?X-@@
MW^#>TM7@VM`@W=`@W^#0TM[?V.'>XBXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3$R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3(*;7-G
M:60@(E-T87)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q
M,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@;F%M
M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A
M=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(E-T<FEP($%T=&%C
M:&UE;G0B"FUS9W-T<B`BO^#8VM#GU=T@Y-#XVR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,S<*(RP@9G5Z>GD*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(L+5W-`B
M"@HC.B!M97-S86=E+G!H<#HR-C@@=&AR96%D+G!H<#HQ-3`@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HS
M.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+"U=S0(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R
M("+"U=S0(-W0(-_>X-#:T"(*"B,Z('-E87)C:"YP:'`Z,S$X('1E;7!L871E
M<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.`HC.B!T96UP;&%T97,O<VUI
M;64O<&%S<W!H<F%S92YI;F,Z,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E
M+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(L+5W-`B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B
M4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R("*_X-72U]7<V"#?T-_:
MT"C8*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@P(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,X.0HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+#X=_5Z-W>(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3
M=6=G97-T:6]N<R(*;7-G<W1R("*_X-74V][7V"(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-C(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V
M-`IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#`S"FUS9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P
M-`IM<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED
M(")3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,3D*(RP@9G5Z
M>GD*;7-G:60@(E1E7WAT(@IM<V=S='(@(L+5VN'B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(V.0IM<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,0IM<V=I9"`B
M5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<V,0IM<V=I9"`B5&5N=&%T:79E;'D@
M06-C97!T960B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M=&]S7V%G<F5E;65N="YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5R
M;7,@;V8@4V5R=FEC92!F:6QE(&YO="!S<&5C:69I960@:6X@8V]N9BYP:'`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C,P"FUS9VED(")497AT(@IM<V=S='(@(L+5VN'B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDU-`IM<V=I9"`B5&AE($9R;VTZ(&-O;'5M;B!O9B!T
M:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.B(*;7-G<W1R("(B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C4S,@IM<V=I9"`B(@HB5&AE($E-05`@<V5R
M=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A
M=&EO;B!M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O
M<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`BN-35W>+8XM7BWN(@7"(E<UPB(-4@
MV-?1X-CHT-TN(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E
M96X@<V%V960N(@IM<V=S='(@(KC4U=WBV.+5XM[B(%PB)7-<(B#5(-?0Y^/2
MT-TN(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM
M96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV.0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@
M:6YV86QI9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W
M:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y
M;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,@IM
M<V=I9"`B5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@
M8F5L;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E
M;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N
M86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(K_0W]K0XM`HV.+5*2!<(B5S7"(@
M_-4@T=C4T.(@W^#5V-S5W>/2T-W8(-+>(%PB)7-<(BXB"@HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,3`W"FUS9VED("(B"B)4:&4@8W5R<F5N="!L:7-T
M(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO
M="!B92!R971R:65V960B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3(S
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9')A9G0@:&%S(&)E96X@<V%V
M960@=&\@=&AE(%PB)7-<(B!F;VQD97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,SD*;7-G:60@(E1H92!E=F5N="!W87,@
M861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*
M;7-G<W1R("*XU-7=XMCBU>+>XB!<(B5S7"(@U2#8U]'@V.C0W2XB"@HC.B!L
M:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O
M;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`BO]#?VM#BT"!<
M(B5S7"(@TM7\U2#?WN'BWM@B"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I
M;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U
M<V4@(@HB<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@HBO]#?VM#BT"!<(B5S7"(@X=[4X-;8(-W5
MTM#;V-3=V"#7W=#FV"#2WB#8W-7BWBP@Z.+>(-S>UM4@U-`@W^#5U-C7TMC:
MT"`B"B+?X-[1V]7<V"X@OM'@T.+5XM4@X=4@U-X@TM#HV-[B(.'8X>+5W"#0
MU-S8W=CAXN#0XM[@+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@8W)E871E9"!B
M=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@:70N(@IM<V=S='(@(K_0
MW]K0XM`@7"(E<UPB(-4@VN#5V.#0W=`L(-W>(.'5(./HXM4@^-`@W=7<T.+5
M(-_@U=+7U=S0W=XN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!D96QE=&5D(&)U
M="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N(@IM<V=S='(@
M(K_0W]K0XM`@7"(E<UPB(-4@V-?1X-CHT-W0+"#=WB#AU2#CZ.+5(/C0(-C<
MT.+5(-_@U=+7U=S0W=XN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S0S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@8W)E
M871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("*_
MT-_:T.+0(%PB)7-<(B#=U2#5(-K@U=C@T-W0+B"^TM`@T]X@TN#0XM@@X=7@
MTM7@WN(B"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(K_0W]K0XM`@7"(E
M<UPB(-W5(-4@V-?1X-CHT-W0+B"^TM`@T]X@TN#0XM@@X=7@TM7@WN(B"@HC
M.B!L:6(O1F]L9&5R+G!H<#HS-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+B(*;7-G
M<W1R("*_T-_:T.+0(%PB)7-<(B#5(./AW]7HW=X@VN#5V.#0W=`N(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T
M<B`BO]#?VM#BT"!<(B5S7"(@U2#CX=_5Z-W>(-C7T>#8Z-#=T"XB"@HC.B!L
M:6(O1F]L9&5R+G!H<#HT-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O
M;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O(%PB)7-<
M(BXB"FUS9W-T<B`BO]#?VM#BT"!<(B5S7"(@U2#CX=_5Z-W>(-_@U=C<U=WC
MTM#=T"#2WB!<(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.CDR"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@
M=&\@=&AI<R!P87)T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7W-A=F5I;6%G95]W:6XN:G,Z,3(*;7-G:60@(B(*(E1H92!I
M;6%G92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y
M;W4@:&%V92!S970@>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I
M;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B
M96-A=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D9')E
M<W-B;V]K+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"B,L(&9U>GIY"FUS9VED
M(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF
M;W)M871I;VYA;"!M97-S86=E.B(*;7-G<W1R("*_X-[<U=W8(-/8(-C=Y-[@
MW-#FV-CBU2#7T"#AU>#2U>#>XB#8(-_0W]K0XM`N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H92!M86EL('-E<G9E<B!G
M96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.B(*;7-G<W1R("(B"@HC
M.B!L:6(O365S<V%G92YP:'`Z-C4Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R
M("*_T-_:T.+0(%PB)7-<(B#2U?S5(-_>X>+>V"(*"B,Z(&QI8B]&971C:&UA
M:6PN<&AP.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!<
M(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I
M>F4@;&EM:70N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3`S"FUS9VED(")4:&4@;65S<V%G92!B96EN9R!C;VUP
M;W-E9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z
M(&UE<W-A9V4N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B5&AE(&UE<W-A9V4@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BN-35W>+8XM7BWN(@7"(E<UPB
M(-4@V-?1X-CHT-TN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDS
M"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE
M9"XB"FUS9W-T<B`BN-35W>+8XM7BWN(@7"(E<UPB(-4@U]#GX]+0W2XB"@HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"X@4V5N9&5R
M.B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+V]P96Y?<VUI
M;65?=VEN+FIS.C$P('1E;7!L871E<R]P9W`O;W!E;E]P9W!?=VEN+FIS.C$P
M"FUS9VED("(B"B)4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@;W!E
M;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB
M8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!R
M87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C8P
M"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@
M=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G:60@(E1H92!R97%U97-T960@9FEL
M92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@;65S<V%G92!I<R!R97%U97-T:6YG
M(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX@(@HB9G)O;2!Y
M;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@;65S<V%G92X@4&QE87-E(&-L
M:6-K("5S('1O('-E;F0@=&AE("(*(FYO=&EF:6-A=&EO;B!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HV.0IM
M<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E871E(&$@=&AU
M;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`T"B,L(&9U>GIY"FUS9VED(")4:&4@
M<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"XB"FUS9W-T<B`BO][B
MW]CAWN(@W=4@W-[6U2#4T"#1V-35(-?0W-7=U>(N(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#(*;7-G:60@(E1H92!S:6=N871U<F4@
M=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"XB"FUS9W-T<B`BO][BW]CAWN(@
MU2#CX=_5Z-W>(-?0W-7=U>(N(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G
M:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E
M9"XB"FUS9W-T<B`BN-35W>+8XM7BWN(@7"(E<UPB(-4@U]#GX]+0W2XB"@HC
M.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(KC4U=WBV.+5XM[B(%PB)7-<(B#5(-C7T>#8Z-#=+B(*"B,Z('-T
M871I;VYE<GDN<&AP.C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@=7!D871E9"XB"FUS9W-T
M<B`BN-35W>+8XM7BWN(@7"(E<UPB(-4@V-?1X-CHT-TN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$V.0IM<V=I9"`B5&AE('1A<VL@:&%S(&)E
M96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(E1H
M92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(MC7T>#8Z-@@W][@T-K0
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z.#`*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S
M86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U
M<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L(&9U>GIY
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@
M(K_@U=W0X=[GV"#XT"#?WN#0VM#2T#HB"@HC.B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-30*(RP@
M9G5Z>GD*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(K_>XM_8X=[B(-4@
MX^'?U>C=WB#7T-S5W=7B+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA
M=&EV92YP:'`Z.#8*;7-G:60@(E1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS"FUS
M9VED(")4:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*
M;7-G<W1R("*]U=S0(-_>X-#:V"#2WB#>TM`@W][HXM7=X=K>(.'0W=30Y]4N
M(@H*(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES(&YO('1E>'0@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9"(*;7-G<W1R("*]T.'BT-W0(-_@WM';U=P@W^#8(-'@
MV.C5^M4@W=`@)7,N(+[2T"#3WB#2X-#BV"#AU>#2U>#>XB(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HV-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@
M<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(B(*(KW0X>+0W=`@W^#>T=O5W"#?
MX-@@T>#8Z-7ZU2#=T"#?WNCBU=WAVM[BWB#AT-W4T.?5+B"^TM`@T]X@TN#0
MXM@@X=7@TM7@WN(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C(Q"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B*]T.'BT-W0
M(-_@WM';U=P@W^#8(-'@V.C5^M4@W=`@W][HXM7=X=K>XMX@X=#=U-#GU2X@
MOM+0(-/>(-+@T.+8(.'5X-+5X-[B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.CDP
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@8V]P>6EN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N
M(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB
MO=#AXM#=T"#3X-7HVM`@W^#8(-K>W]C@T/K5(-W0(-_>X-#:V.+5(-+>(%PB
M)7-<(BX@OM+0(-/>(-+@T.+8(.'5X-+5X-[B(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C$Y."!L:6(O365S<V%G92YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F
M<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(B(*(KW0X>+0W=`@T^#5Z-K0(-_@V"#1X-CH
MU?K5(-W0(-_>X-#:V.+5(-[4(-_0W]K0XM`@7"(E<UPB+B"^TM`@T]X@TN#0
MXM@@(@HBX=7@TM7@WN(B"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN
M9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B*]T.'BT-W0(-/@U>C:
MT"#?X-@@T>#8Z-7ZU2#=T"#?WN#0VMCBU2#2WB#?T-_:T.+0(%PB)7-<(BX@
MOM+0(-/>(-+@T.+8("(*(N'5X-+5X-[B(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C(Q,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`E<R(*;7-G<W1R("*]T.'BT-W0(-/@U>C:T"#?X-@@T>#8
MZ-7ZU2#=T"#?WN#0VMCBU2X@OM+0(-/>(-+@T.+8(.'5X-+5X-[B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.CDY"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V
M96YT.B`E<RXB"FUS9W-T<B`BO=#AXM#=T"#3X-7HVM`@W^#8(-_@V-K0UR#=
MT"#1T.#0W=#BT"#?WN#0VM`N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN
M+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR:6-H960N<&AP.C,W"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R="(*;7-G<W1R("*]T.'BT-W0(-/@U>C:T"#?X-@@W^#0
M_-#ZU2#=T"#?WN#0VM#BT"(*"B,Z(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB
M+TUE<W-A9V4N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E
M<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS
M9W-T<B`B(@HBO=#AXM#=T"#3X-7HVM`@W^#8(-_>X>+0TN/2T/K5(-#BX-C1
MX^+8(-W0(-_>X-#:V.+5(-+>(-_0W]K0XM`@7"(E<UPB+B"^TM`@(@HBT]X@
MTN#0XM@@X=7@TM7@WN(B"@HC.B!F;VQD97)S+G!H<#HQ-C4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@)7,N(@IM<V=S='(@(KW0X>+0W=`@T^#5Z-K0(-_@V"#7T.?CTN/2T/K5
M(-W0(-W5U]#2X.C5W=`@W][@T-K0+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T
M<B`BO=#AXM#=T"#3X-7HVM`@W^#8(-_@V-K0UR#=T"#1T.#0W=#BT"#?WN#0
MVM`N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(KW0X>+0W=`@T^#5Z-K0(-_@
MV"#?X-C:T-<@W=`@T=#@T-W0XM`@W][@T-K0+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S
M>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(KW0X>+0W=`@T^#5Z-K0(-_@
MV"#?X-C:T-<@W=`@T=#@T-W0XM`@W][@T-K0+B(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<
M(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T
M<B`B(@HBO=#AXM#=T"#3X-7HVM`@W^#8(-_@U=S5X>+CTM#ZU2#=T"#?WN#0
MVMCBU2#2WB!<(B5S7"(N(+[2T"#3WB#2X-#BV"#AU>#2U>#>XB(*"B,Z(&-O
M;7!O<V4N<&AP.C$R-#0*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N(@IM<V=S='(@
M(KW0X>+0W=`@T^#5Z-K0(-_@V"#7T.?CTN/2T/K5(-W0(-W5U]#2X.C5W=`@
MW][@T-K0+B(*"B,Z(&-O;7!O<V4N<&AP.C$P,#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@
M;65S<V%G93H@)7,B"FUS9W-T<B`BO=#AXM#=T"#3X-7HVM`@W^#8(-_@T/S0
M^M4@W=`@W][@T-K0XM`B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`BO=#AXM#=
MT"#3X-7HVM`@W^#8(-_@V-K0UR#=T"#1T.#0W=#BT"#?WN#0VM`N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B
M5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T
M<B`BO=#AXM#=T"#3X-7HVM`@W^#8(-_@T/S0^M4@W=`@W][@T-K0XM`B"@HC
M.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3<*;7-G:60@(E1H:7,@2%1-
M3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY,`IM<V=I9"`B(@HB
M5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@
M0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@(@HB=&AI<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-@IM<V=I9"`B5&AI
M<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#0@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q.`HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,30S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3<*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,R!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,S$T"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3<Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3D*;7-G:60@(E1H
M:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,30*;7-G:60@
M(E1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@8V]N=&EN=64_(@IM<V=S='(@(K[2T"#<WM;5(-30(-_>XN#0U2X@
MM-#;V"#AXM4@X=C3X^#=V"#4U=K0(.'0VM#BU2#4T"#?X-[4WMO6V.+5/R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@
M(E1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q,`IM<V=I
M9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA
M="!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+R(*(DU)344N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$T"FUS
M9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T
M(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H
M:7,@;65S<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O
M<FUA=&EO;BP@8G5T('1H92!F;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES
M('5N:VYO=VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C,Q-0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR-#`@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S4P"FUS9VED("(B"B)4:&ES(&UE
M<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'
M4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4
M:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R
M96-T(%,O34E-12!F;W)M870N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*
M;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D
M('9I82!01U`N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,30S"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A
M;&QY('-I9VYE9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C(S.`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E
M9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HR,#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDQ"FUS9VED
M(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*
M;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S
M<V%G92!T;R(*;7-G<W1R("*^TM#0(-_>X-#:T"#4WB(*"B,Z(&%C;"YP:'`Z
M-#8*;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$P.0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!T
M:')E860N<&AP.C$U,@IM<V=I9"`B5&AR96%D($1I<W!L87DB"FUS9W-T<B`B
M(@H*(SH@=&AR96%D+G!H<#HW-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(R
M"B,L(&9U>GIY"FUS9VED(")4:')E860@5FEE=R(*;7-G<W1R("*^X=+5UM@@
MW^#8VM#7(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP.C8P-B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S92]R
M96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS9VED(")4;R(*
M;7-G<W1R("*TWB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3D*(RP@
M9G5Z>GD*;7-G:60@(E1O($%D9')E<W,B"FUS9W-T<B`BOM0@T-3@U>'0(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(V"FUS9VED
M("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE("(*(F-L:6-K
M:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C$S-`IM
M<V=I9"`B(@HB5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO=2!M=7-T(&)E
M(')U;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C`N-B!O<B`B"B)H:6=H97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4W-PHC+"!F=7IZ>0IM<V=I9"`B5&]T86P@071T86-H;65N=',@4VEZ93HB
M"FUS9W-T<B`BO^#8VM#GU=W8(.30^-O>TM@B"@HC.B!F;VQD97)S+G!H<#HS
M.#@*(RP@9G5Z>GD*;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G<W1R("*_T-_:
MT""^XM_0U-[:.B(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI
M;F,Z,C,*;7-G:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`BO]#?VM`@ON+?
MT-3>VCHB"@HC.B!L:6(O475O=&$O8WER=7,N<&AP.C8U(&QI8B]1=6]T82]M
M97)C=7)Y,S(N<&AP.C<Y(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC.B!L
M:6(O475O=&$O;&]G9FEL92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP
M.C4S(&QI8B]1=6]T82]M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O
M(')E=')I979E('%U;W1A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,V"FUS9VED(")5;F%N<W=E<F5D(@IM<V=S='(@(KW5WM33WM+>X-7=V"(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@(E5N86YS
M=V5R960@;65S<V%G97,B"FUS9W-T<B`BO=7>U-/>TM[@U=W8(-_>X-#:V"(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T
M92(*;7-G<W1R("*_WM+@T.+8(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y(&UA:6QB
M;W@N<&AP.C8P,B!L:6(O34E-12](96%D97)S+G!H<#HR,3(*;7-G:60@(E5N
M9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`BO=7?WM?=T.(@W^#8W-#B
MU=LB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#0W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B
M"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-38U"FUS9VED(")5;FMN;W=N
M($1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O;G-E(&9R
M;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8S-0IM<V=I9"`B56YK
M;F]W;B!-965T:6YG(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C8Q.`HC
M+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`BO=7?
MWM?=T.(@W^#8W-#BU=LB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A
M<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(KW5V-S5W>/2T-TB"@HC.B!M97-S
M86=E+G!H<#HT.3D@;6%I;&)O>"YP:'`Z-S`X('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S(*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHU"FUS9VED(")5;G-E
M96XB"FUS9W-T<B`BO=7?X-[GV.+0W=@B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O;2!&;VQD
M97(H<RDB"FUS9W-T<B`BP=[:X-CX(-_0W]K0*-@I(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@T"FUS9VED(")5<&1A=&4@071T86-H
M;65N="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C(P"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T
M=7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN
M:6YC.C4X('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-38*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA
M:6QS96QE8W0N:6YC.C0Q"FUS9VED(")5<V4@1&5F875L="!686QU92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"B,L(&9U>GIY
M"FUS9VED(")5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS9W-T
M<B`BNM[@V.'BU>+5(-_0W]K8(-_@U=+7U=S5W=@@WM0@24U!4"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW,S4*;7-G:60@(E5S92!6:7)T=6%L(%1R
M87-H($9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$T,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("*ZWN#8X=W8
MY]K>(-C<U2(*"B,Z(&%C;"YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB57-E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I
M960@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-S<*;7-G:60@(E5S97)N
M86UE(@IM<V=S='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C$W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M
M93HB"FUS9W-T<B`BNM[@V.'=V.?:WB#8W-4B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,C<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B5FEE=R(*;7-G
M<W1R("*_X-C:T-;8("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z
M.3(@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W("5S(@IM<V=S='(@(K_@V-K0UM@@)7,B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(%!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC
M+"!F=7IZ>0IM<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<B"FUS9W-T<B`BP=[AXM#2X]+0^M4@W=`@W][@T-K8(-+>(-W>
MTB`HW][AU='5W2D@W^#>U][@U>8N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,C@*(RP@9G5Z>GD*;7-G:60@(E9I97<@365S<V%G97,B
M"FUS9W-T<B`BO=[2V"#?WN#0VM@B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE
M=R!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM
M<V=I9"`B5FEE=R!4:')E860B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V-0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GD*;7-G:60@(E9I
M97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R("+!
MWN'BT-+CTM#ZU2#=T"#?WN#0VM@@TMX@W=[2("C?WN'5T=7=*2#?X-[7WN#5
MYBXB"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@9G5Z
M>GD*;7-G:60@(E9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*
M;7-G<W1R("+!WN'BT-+CTM#ZU2#=T"#?WN#0VM@@TMX@W=[2("C?WN'5T=7=
M*2#?X-[7WN#5YBXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30P
M"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP
M.C,X,"!M86EL8F]X+G!H<#HU,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E9I97<@;65S<V%G97,@:6X@)7,B"FUS9W-T<B`BO^#8VM#6V"#?WN#0
MVM@@TMX@(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T
M+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T
M97(@;&]G:6XZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-S`*(RP@9G5Z>GD*;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R("*_
MX-C:T-;8("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P,0HC
M+"!F=7IZ>0IM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM<V=S='(@(K_@V-K0
MUM@@W][@T-K8(-+>("(*"B,Z('-E87)C:"YP:'`Z,C8S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E
M9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`BO]#?VM#BT"!<(B5S7"(@U2#CX=_5
MZ-W>(-C7T>#8Z-#=T"XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C$Q,2!L:6(O24U!4"]4<F5E+G!H<#HQ,S@@;&EB+TE-05`O5')E92YP:'`Z
M,34Q"B,Z(&QI8B])34%0+U1R964N<&AP.C$U,R!L:6(O24U!4"]4<F5E+G!H
M<#HQ-3<@;&EB+TE-05`O5')E92YP:'`Z,34X"B,Z(&QI8B])34%0+U1R964N
M<&AP.C,V.2!L:6(O24U!4"]4<F5E+G!H<#HS.3,@;&EB+TE-05`O5')E92YP
M:'`Z-#,S"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L($9O;&1E<G,B"FUS9W-T
M<B`BNN#5V.#0^"#?T-_:T"(*"B,Z('-E87)C:"YP:'`Z,C0U"FUS9VED(")6
M:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA8F5L+B(*;7-G<W1R("(B"@HC
M.B!L:6(O5D9O;&1E<BYP:'`Z,3<U(&QI8B]61F]L9&5R+G!H<#HQ.#`*;7-G
M:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M-#$V"FUS9VED(")6:7)T=6%L($E.0D]8($9O;&1E<B(*;7-G<W1R("(B"@HC
M.B!M86EL8F]X+G!H<#HT-3(@;&EB+U9&;VQD97(N<&AP.C$Q-"!L:6(O5D9O
M;&1E<BYP:'`Z,3$Y"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(B(*
M"B,Z(&9O;&1E<G,N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B5FER='5A;"!4
M<F%S:"!&;VQD97(B"FUS9W-T<B`BO]#?VM`@ON+?T-3>VCHB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$S,PIM<V=I9"`B5FER='5A;"!F;VQD
M97(@;&%B96PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HS-S0*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BLMW8W-#=V-4B"@HC
M.B!L;V=I;BYP:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@
M=&\@)7,B"FUS9W-T<B`BM-[1X-74WOC4WM+BU2#2WB`E<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV,3D*;7-G:60@(B(*(E=H870@<VAO=6QD('=E
M(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R
M97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(W"B,L(&9U>GIY"FUS9VED("(B
M"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4
M<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H96T@87,@9&5L
M971E9#\B"FUS9W-T<B`B(@HBO^#8(-'@V.C5^M4@W=`@W][@T-K8+"#?X-7<
MU>'BV"#3V"#2WB#?T-_:T.+0(+[BW]#4WMH@W=#<U>'BWB#4T"#3V"`B"B+>
MU]W0Y^/2T.@@VM#:WB#8U]'@V.C0W=@N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDP-PIM<V=I9"`B5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L
M('=H:6-H('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C$*;7-G:60@(E=H96X@
M<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD('=E('-A=F4@871T86-H;65N="!D
M871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(V
M"FUS9VED("(B"B)7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D
M<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD('1O("(*(G5N
M<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@
M7")`7"(I/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,3D*;7-G:60@(E=H:71E;&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDW.`IM<V=I9"`B665S(@IM<V=S='(@(K30(@H*(SH@;&EB+TUA:6YT
M96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HU.`HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&%R92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F
M;VQL;W=I;F<@86-C;W5N="AS*3HB"FUS9W-T<B`BP=4@WM'8U./2T.+5(-30
M(-/8(-C7T>#8Z-7BU2#AV]74W=C2U2#?T-_:V#HB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G
M97,@8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*
M;7-G<W1R("+!U2#>T=C4X]+0XM4@U-`@T]@@V-?1X-CHU>+5(.';U=3=V-+5
M(-_0W]K8.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER
M;2YH=&UL.CD*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T
M;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(L'5
M(-[1V-3CTM#BU2#4T"#3V"#8U]'@V.C5XM4@X=O5U-W8TM4@W]#?VM@Z(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"B,L(&9U>GIY"FUS9VED
M(")9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS
M9W-T<B`BJ-`@X-78W-7=X]+0XM4@W]#?VM#BT#H@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#(*;7-G:60@(EEO=2!A<F4@8W)E
M871I;F<@82!S=6(M9F]L9&5R('1O("(*;7-G<W1R("*ZX-78X-#BU2#=WM+0
M(-_0W]K0(-+>("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3`T"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@=&]P
M+6QE=F5L(&9O;&1E<BXB"FUS9W-T<B`BNN#5V.#0XM4@W=[2T"#?T-_:T"#2
MWB`B"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L9&5R<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ,S4*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@(@IM
M<V=S='(@(JC0(.#5V-S5W>/2T.+5(-_0W]K0XM`Z("(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A
M;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(L/AW]7H
MW=X@^-`@X=[:X-C2XM4@W]#?VM#BT"!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C,U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S(&EN
M('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@(@HB8W5R<F5N="!M
M97-S86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T=7)E+B(*;7-G<W1R
M("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H
M<#HS-`IM<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS
M(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E
M9"`B"B)T;R!L;V=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$V.0IM<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@
M=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O36%I;&QO9RYP:'`Z,3(Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W
M:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A;&5R="YI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M:&%V92`E<R!N97<@;65S<V%G97,N(@IM<V=S='(@(KC<T.+5("5S(-W>TM@@
MW][@T-K8+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS
M9VED(")9;W4@:&%V92`Q(&YE=R!M97-S86=E+B(*;7-G<W1R("*XW-#BU2#5
MU-W0(-W>TM`@W][@T-K0+B(*"B,Z(&-O;7!O<V4N<&AP.C0Y-`HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E
M+B(*;7-G<W1R("*XW-#BU2#5U-W0(-W>TM`@W][@T-K0+B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U
M(&AA=F4@870@;&5A<W0@;VYE(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y
M;W4@9&ED;B=T('5P;&]A9"!Y970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!S96YD('1H:7,@;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE
M;G1S/R(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,#<T"B,L(&9U>GIY
M"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<CHB"FUS9W-T<B`BN-S0XM4@W=[2V"#?WN#0VM@@TMX@X=O5U-W8TM4@
MW]#?VM@Z7%QN(@H*(SH@;&EB+TE-4"YP:'`Z,3`W.0HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S
M.B(*;7-G<W1R("*XW-#BU2#=WM+8(-_>X-#:V"#2WB#AV]74W=C2U2#?T-_:
MV#I<7&XB"@HC.B!C;VUP;W-E+G!H<#HQ-3,*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N(@IM<V=S='(@
M(KS>X-`@U-`@TMW5X=7BU2#1T.#5W"#5U-7=(-_@V-S0YRXB"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HS,#(*;7-G:60@(B(*(EEO=2!M=7-T(&5N
M=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T
M;R!V:65W('1H:7,@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C(T.0IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@
M=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O
M('9I97<@=&AI<R`B"B)M97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C8T('1E;7!L871E<R]M86EL8F]X
M+VIA=F%S8W)I<'0N:6YC.C(P,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@
M=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM<V=S='(@(KS>X-`@W^#2WB#4T"#A
MU=O5VN+8X-#BU2#FU=O=WB#?WNCBU=WAVMX@X=#=U-#GU2XB"@HC.B!F971C
M:&UA:6QP<F5F<RYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S='(@(KS>X-`@
MU-`@V-?1U>#5XM4@VM[X(-C4U=WBV.+5XB#4T"#AU2#8U]'@V.C5+B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z.#$*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G
M<W1R("*\WN#0(-_@TMX@U-`@X=7;U=KBV.#0XM4@YM7;W=X@W][HXM7=X=K>
M(.'0W=30Y]4N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z
M('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*
M;7-G<W1R("*\WN#0(-_@TMX@U-`@V-?1U>#5XM4@T=#@U=P@U=3=T"#?WN#0
MVM`N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G<W1R("*\
MWN#0(-30(-+=U>'5XM4@W^#8W-#G+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V%T=&%C:&UE;G1S+FIS.C(Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y(&%T(&QE87-T(&]N92!F:6QE('1O(&%T=&%C:"XB"FUS9W-T<B`B
MN-?1U>#5XM4@W^#2WB#:WO@@Y-#XVR#4T"#AU2#?X-C:T.?8+B(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@;F5E9"!T;R!H879E(%PB)7-<(B!E;F%B;&5D(&EN('EO
M=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUA
M:6QL;V<N<&AP.C$S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(')E9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T
M<B`BO^#5W=#AWN?8(/C0(-_>X-#:T-+0.B(*"B,Z(&QI8B]-86EL;&]G+G!H
M<#HQ-#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!R97!L:65D
M('1O('1H:7,@;65S<V%G92!O;B`E<RXB"FUS9W-T<B`BO^#5W=#AWN?8(/C0
M(-_>X-#:T-+0.B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N
M($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BO=4@^-`@
MV-S0XM4@W^#5TM?5W-#=WB#?T-_:T.+0(%PB)7-<(BX@OM+0(-/>(-+@T.+8
M(.'5X-+5X-[B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34Y"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!<(B5S
M7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BO=4@
M^-`@V-S0XM4@X=K@V-7=WB#?T-_:T.+0(%PB)7-<(BX@OM+0(-/>(-+@T.+8
M(.'5X-+5X-[B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3$P"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O
M(%PB)7-<(B(*;7-G<W1R("+#X=_5Z-W>(/C0(-_@U=+7U=S0TN+5(-_0W]K0
MXM`@7"(E<UPB+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D
M(&9R;VT@7"(E<UPB(@IM<V=S='(@(L/AW]7HW=X@^-`@X=[:X-C2XM4@W]#?
MVM#BT"!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"B,L
M(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`BN-S5(-@@W^#5U]C<
MU3HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G:60@(EEO=7(@
M4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4'5B;&EC($ME>2(*;7-G<W1R
M("*XW-4@V"#?X-77V-S5.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C4*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE
M;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`BL-3@U>'0(-W0(-K>^-`@_-4@
MTM@@WM33WM+>X-#0XCH@/&D^*-W5U]#4WMO6V.+5V]W>*3PO:3XB"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-
M12!0=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S='(@(K+0Z-@@V-35
MW>+8XM7BV#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3<S"FUS9VED
M("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I;VYA;"P@96YT
M97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D
M:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B(@HBLM#HV-[B
M(-_@U>+@T-;CTM#G(-W5(-_>U.#6X]+0(-+0VM+>(-_5Y]#BU?K5+B"_X-CB
MV.'=U>+5($-O;G1R;VPOOM_FV/C0("L@4"`B"B+7T"#4T"#?U>?0XM7BU2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,Y"FUS9VED(")9;W5R(&1E
M9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC.C$*;7-G
M:60@(EEO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN
M9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;65S<V%G92!W87,@
M<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB"FUS9W-T<B`BO]#?VM#BT"!<(B5S
M7"(@U2#CX=_5Z-W>(-C7T>#8Z-#=T"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS9W-T<B`BO][B
MW]CA.B(*"B,Z(&UE<W-A9V4N<&AP.C(X."!C;VUP;W-E+G!H<#HQ,C@T(&UA
M:6QB;W@N<&AP.C4T.2!L:6(O0V]M<&]S92YP:'`Z.#$X"B,L(&9U>GIY"FUS
M9VED(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6['5UR#BU=S072(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(P-0HC+"!F=7IZ>0IM<V=I
M9"`B7T)C8R(*;7-G<W1R("*]U=+8U-O8TM`@VM[?V/C0(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")?0FQA8VML
M:7-T(@IM<V=S='(@(L;@W=`@V]CAXM`B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHQ-30*(RP@9G5Z>GD*;7-G:60@(E]#8R(*;7-G<W1R
M("*ZWM_8^-`B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED
M(")?1&5L971E(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!L:6(O24U0+G!H<#HY
M-SD*(RP@9G5Z>GD*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@(K_0W]K8(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.#$*(RP@9G5Z>GD*
M;7-G:60@(E])9&5N=&ET>2(*;7-G<W1R("*XU-7=XMCBU>+8XM4B"@HC.B!L
M:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G<W1R("(B"@HC.B!L
M:6(O24U0+G!H<#HQ,#(P"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U="(*;7-G
M<W1R("*^U/C0TM`B"@HC.B!M97-S86=E+G!H<#HS.#0*(RP@9G5Z>GD*;7-G
M:60@(E]-97-S86=E(%-O=7)C92(*;7-G<W1R("*XU]+>X"#=T"#?WN#0VM`B
M"@HC.B!L:6(O24U0+G!H<#HY-S8*(RP@9G5Z>GD*;7-G:60@(E].97<@365S
M<V%G92(*;7-G<W1R("*]WM+8(-_>X-#:V"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B7U!R
M:6YT(@IM<V=S='(@(K_5Y]#BV"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(W,B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M.#D*;7-G:60@(E]0<FEO<FET>2(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H
M<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E]2969R97-H("5S
M(@IM<V=S='(@(K[ATM76V"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED(")?4F5P;'DB"FUS9W-T
M<B`BOM33WM+>X-@B"@HC.B!L:6(O24U0+G!H<#HY.#$*(RP@9G5Z>GD*;7-G
M:60@(E]396%R8V@B"FUS9W-T<B`BO^#5T=#@X]+0^"(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0S,0HC+"!F=7IZ>0IM<V=I9"`B7U-E;F0@365S<V%G92(*
M;7-G<W1R("*XX=_@T.+8(-_>X-#:T"(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(E]4:')E
M860B"FUS9W-T<B`BO=7?X-[GV.+0W=`B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHQ,38*(RP@9G5Z>GD*;7-G:60@(E]4;R(*;7-G<W1R
M("*TWB(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"B,L
M(&9U>GIY"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`BO][2X-#BV"(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I
M9"`B7U9I97<@5&AR96%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3<V"FUS9VED(")A9&1R97-S964@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#0P"B,L(&9U>GIY
M"FUS9VED(")A='1A8VAM96YT(@IM<V=S='(@(K_@V-K0Y]7=(.30^-LB"@HC
M.B!V:65W+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B871T86-H;65N=',N>FEP
M(@IM<V=S='(@(K_@V-K0Y]7=V"#DT/C;WM+8(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B>71E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`P"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M-S(*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ-C0*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(P"FUS9VED
M(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ.38*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V.`IM<V=I9"`B
M9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(R-`IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"B,L(&9U>GIY
M"FUS9VED(")F<F]M(@IM<V=S='(@(K[4(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C$X,`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C(P-`IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#@*;7-G:60@(FEN
M=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H
M<#HR.2!P9W`N<&AP.C8Y"FUS9VED(")K97DB"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")M86EL8F]X(&9I;&4B"FUS
M9W-T<B`BO][HXM7=X=K>(.'0W=30Y]4B"@HC.B!C;VUP;W-E+G!H<#HQ,#8W
M(&QI8B]-97-S86=E+G!H<#HT-C8*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS
M9W-T<B`BO=78W-7=X]+0W2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*;7-G<W1R("+=V-74W=`B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*
M;7-G<W1R("+8V]@B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$V"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,C$R"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-`IM<V=I9"`B<V5R=FEC92!U
M;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R(@IM<V=S='(@
M(M_@T-+>W]CAW=`@T^#5Z-K0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B
MW^#0TM[?V.'=V"#3X-7HVM@B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DR"B,L
M(&9U>GIY"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`BW^#0TM[?V.'=
MT"#3X-7HVM`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`X"FUS9VED(")T96UP
M;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HU
M,0HC+"!F=7IZ>0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`BQN#=
MT"#;V.'BT"(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H
M:71E;&ES="(*;7-G<W1R("(B"@`````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]P;R]L=E],5BYP;P``````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S-3<Q,3``,3`T,3<S-C(W-C0`,#$W
M,C$W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",@3&%T=FEA;B!T<F%N<VQA=&EO;B!F;W(@24U0"B,@2V%S<&%R<R!+87!E
M;FEE:W,@/&MA<W!A<G-`<F-C+FQV/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U0(#,N,5QN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#(M,3$M,C@@,3@Z,3`K,#(P,%QN(@HB3&%S="U4
M<F%N<VQA=&]R.B!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^
M7&XB"B),86YG=6%G92U496%M.B!,871V:6%N(#QI,3AN0&QI<W1S+FAO<F1E
M+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]0U`Q,C4W7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q
M.`HC+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z("(*;7-G<W1R(")38?+G;>=J
M<SH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q-0IM<V=I9"`B("`@("`@5&\Z
M("(*;7-G<W1R(")38?+G;>=J<SH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P
M,PIM<V=I9"`B("`@($1A=&4Z("(*;7-G<W1R("(@($1A='5M<SH@(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0P-@IM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R
M(")3^W3N=.)J<SH@(@H*(SH@;6%I;&)O>"YP:'`Z-#(R('1E;7!L871E<R]F
M;VQD97)S+VAE860N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3(*
M;7-G:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B("!496UA=',Z("(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I9"`B(&EN("(*
M;7-G<W1R("(@+2`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE
M861E<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@(B,B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"
M("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP
M.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@365S<V%G97,B
M"FUS9W-T<B`B)60@;F\@)60@=N=S='5LYVTB"@HC.B!M86EL8F]X+G!H<#HQ
M-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA
M=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")087+B9.YT(';G<W1U;&DL(&MA
M9"!I<B!I>FUA;G1O=&D@9FEL=')I+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA
M=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("+0[B!VYW-T=6QE(&ER(&%T>NYMYW1A
M(&OB('-P86US+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E
M9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`BT.X@=N=S='5L92!I<B!A='KN;>=T
M82!KXB!S<&%M<RXB"@HC.B!L:6(O4W!A;2YP:'`Z,3<P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T
M960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("+0[B!VYW-T=6QE(&ER(&%T>NYMYW1A(&OB('-P86US+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D
M(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R
M("+0[B!VYW-T=6QE(&ER(&%T>NYMYW1A(&OB('-P86US+B(*"B,Z(&UA:6QB
M;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!T;R`E9"!O9B`E
M9"!-97-S86=E<R(*;7-G<W1R("(E9"!L[F1Z("5D(&YO("5D(';G<W1U;.=M
M(@H*(SH@;6%I;&)O>"YP:'`Z-C0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($M"(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M
M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R
M96YA;65D+B(*;7-G<W1R("(E<R!J874@96MS:7-TYRX@36%P:2`E<R!PXG)S
M875K="!N96EZ9&5VXG,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!M86EL8F]X+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@=&AE('-T
M87)T(&]F('1H92!M;VYT:"XB"FUS9W-T<B`B36%P92`E<R!T:65K('#B<G-A
M=6MT82!MYVYE\&$@<^)K=6WB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DS"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E
M<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE
M(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@=&5N=&%T:79E;'D@86-C97!T960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P
M<F5S96YC92!A="`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C0Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(DUA<&4@7"(E<UPB
M('9E:6MS;>YG:2!PXG)S875K=&$@<&%R(%PB)7-<(BXB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('=I<VAE<R!T;R!A;6UE;F0@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M
M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(X
M-2!M97-S86=E+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T;W`N
M:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO
M9B9N8G-P.R5D*2(*;7-G<W1R("(E<SH@)7,@*"5D)FYB<W`[;F\F;F)S<#LE
M9"DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S"FUS
M9VED("(H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C
M<F5E;BXI(@IM<V=S='(@(BA386=L86+B="#P[G,@:7IM86GR87,@=6X@<.)R
M=FEE=&]T:65S('5Z(&[B:V%M;R!E:W+B;G4N*2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`*;7-G:60@(BA$:7-C87)D(&%L;"!C
M:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BDB"FUS
M9W-T<B`B*$%T8V5L="!V:7-A<R!I>FUA:?)A<R!U;B!A=&=R:65Z=&EE<R!P
M:64@=N=S='5L97,@<F5D:>SG\&%N87,N*2(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*$A434PI(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B
M*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG+G!H<#HR.#`*
M;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R
M(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("`B"B)#:&%N
M9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D
M+BDB"FUS9W-T<B`B(@HB*$%T9W)I97IT:65S('!I92!VYW-T=6QE<R!R961I
M[.?P86YA<R!PYV,@:7IM86GR=2!S86=L86+B\&%N87,N("#086KB(&5K<N)N
MXB`B"B)V96EK=.)S(&EZ;6%I\F%S($Y%5$E+4R!S86=L86+B=&%S+BDB"@HC
M.B!S<&5L;&EN9RYP:'`Z,C<W"B,L(&9U>GIY"FUS9VED("(B"B(H4V5N9"!M
M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F
M87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT('-C<F5E;B!W:6QL($Y/
M5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*$%T9W)I97IT:65S('!I92!V
MYW-T=6QE<R!R961I[.?P86YA<R!PYV,@:7IM86GR=2!S86=L86+B\&%N87,N
M("#086KB(&5K<N)NXB`B"B)V96EK=.)S(&EZ;6%I\F%S($Y%5$E+4R!S86=L
M86+B=&%S+BDB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*B(*;7-G
M<W1R("(J(%!I979I96YO="#P;W,@;F]S<&EE_F]T($]+("HB"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A
M<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS9W-T<B`B*B!,^V1Z=2!I>G;G
M;&EE=&EE<R!A9')E<VDH+65S*2`J(@H*(SH@;6%I;&)O>"YP:'`Z,3<T"B,L
M(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B261E;G1I=.)T92!<(B5S7"(@=F5I:W-M[F=I(&EZ9'KG<W1A+B(*
M"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G
M92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+0[B!VYW-T=6QE(&ER(&%T>NYM
MYW1A(&OB('-P86US+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C`*(RP@9G5Z>GD*
M;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A
M;2XB"FUS9W-T<B`BT.X@=N=S='5L92!I<B!A='KN;>=T82!KXB!S<&%M<RXB
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<R"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A
M9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("+0[B!VYW-T=6QE(&ER(&%T>NYMYW1A
M(&OB('-P86US+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G
M:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G
M<W1R("+0[B!VYW-T=6QE(&ER(&%T>NYMYW1A(&OB('-P86US+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*(RP@9G5Z>GD*;7-G:60@(C$P,"!C
M:&%R86-T97)S(@IM<V=S='(@(LYP8?!I92!S:6UB;VQI(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@R,@HC+"!F=7IZ>0IM<V=I9"`B,3`P,"!C:&%R
M86-T97)S(@IM<V=S='(@(LYP8?!I92!S:6UB;VQI(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R,`HC+"!F=7IZ>0IM<V=I9"`B,C4P(&-H87)A8W1E
M<G,B"FUS9W-T<B`BSG!A\&EE('-I;6)O;&DB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#(Q"B,L(&9U>GIY"FUS9VED("(U,#`@8VAA<F%C=&5R<R(*
M;7-G<W1R("+.<&'P:64@<VEM8F]L:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM
M86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z
M-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U
M;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C
M:7!I96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD
M<RYI;F,Z-0IM<V=I9"`B04Y$(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.3`*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@
M(D%C8V5P="!R97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U,PIM<V=I
M9"`B06-C97!T960B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C(U-PIM<V=I9"`B06-C97!T960Z("(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-PHC+"!F=7IZ>0IM<V=I
M9"`B06-C;W5N="=S(&YA;64Z(@IM<V=S='(@(DED96YT:73B=&5S(&YO<V%U
M:W5M<SHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(P(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW,S`*(RP@9G5Z>GD*;7-G:60@(D%C=&EO
M;G,B"FUS9W-T<B`B1&%R8NYB82(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP
M.C(P,"!L:6(O34E-12](96%D97)S+G!H<#HR,#$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%D9"`E<R!T;R!M>2!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B4&EE=FEE;F]T(&MO;G1A:W1I96T@*"5S*2(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P,PHC+"!F=7IZ>0IM<V=I9"`B061D
M('-O=7)C92(*;7-G<W1R(")P:65V:65N;W0@879O='4B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#@*;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@
M(B(*"B,Z(&-O;7!O<V4N<&AP.C$R-38*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R
M(")0:65L:6MU;7,@<&EE=FEE;F]T<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DX"FUS9VED("(B"B)!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES
M<&QA>2!W:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@
M:&5A9&5R("(*(F]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B061D:71I;VYA;"!I;F9O
M<FUA=&EO;B!D971A:6QS(@IM<V=S='(@(E!E<G-O;NYGXB!I;F9O<FWB8VEJ
M82(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDS"FUS9VED(")!
M9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW
M.`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E
M=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N=&%C
M=',N<&AP.C@U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O
M:R(*;7-G<W1R(")+;VYT86MT:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S0*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B
M2V]N=&%K=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Y"FUS9VED
M("(B"B)!9&1R97-S97,@=&\@0D-#(&%L;"!M97-S86=E<SH@/&5M/BAO<'1I
M;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W("(*(FQI;F4I/"]E
M;3XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,0IM
M<V=I9"`B(@HB061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H:7,@
M:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D<F5S
M<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@R,PIM<V=I9"`B06QL(@IM<V=S='(@(E9I<VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$S"FUS9VED("(B"B)!;&P@;65S<V%G
M97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A
M9&5D(&EN=&\@;VYE($U"3U@@(@HB9FEL93HB"FUS9W-T<B`B5FES87,@=N=S
M='5L97,@;F\@<V5K;VIO\&%JXFT@;6%PYVT@=&EK<R!I96SB9.=T87,@=FEE
M;N(@34)/6"!F86ELXCHB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G
M95]T<F%S:"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE
M<W-A9V5S(&EN('EO=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A
M>7,@=VEL;"!B92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R("(B
M"B)6:7-A<R!VYW-T=6QE<R!J^W-U(%PB)7-<(B!M87#G+"!K87,@:7(@=F5C
MXFMA<R!P87(@)7,@9&EE;N)M('1I:W,@(@HB;F5A=&=R:65Z96YI<VMI(&EZ
M9'KG<W1A<RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?871T
M86-H;65N='-?;6]N=&AL>2YP:'`Z-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E
M<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B(@HB5FES
M87,@;F]S^W3N=&\@<&%S='4@;6%P97,L(&MA<R!I<B!V96/B:V%S('!A<B`E
M<R!MYVYE\&EE;2!T:6MS(&EZ9'KG<W1A<RXB"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@
M(B(*(E9I<V%S(&YO<_MT[G1O('!A<W1U(&UA<&5S+"!K87,@:7(@=F5CXFMA
M<R!P87(@)7,@;>=N9?!I96T@=&EK<R!I>F1ZYW-T87,N(@H*(SH@86-L+G!H
M<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(')I9VAT<R!O
M;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U<V5R
M(%PB)7-<(BXB"FUS9W-T<B`B36%P92!<(B5S7"(@=F5I:W-M[F=I('#B<G-A
M=6MT82!P87(@7"(E<UPB+B(*"B,Z(&QI8B]A<&DN<&AP.C<V"FUS9VED(")!
M;&QO=R!&;VQD97(@0W)E871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U
M;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$P"FUS9VED
M(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<R(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU.#0*;7-G:60@(D%L=V%Y<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34W"B,L(&9U>GIY"FUS9VED(")!;'=A
M>7,@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(")0:65L:6MU;7,@<&EE=FEE
M;F]T<RXB"@HC.B!L:6(O365S<V%G92YP:'`Z-3`U"FUS9VED("(B"B)!;B!E
M<G)O<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T
M=&%C:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B06X@
M=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@
M;F]T92XB"FUS9W-T<B`B2^_[9&$@<&EE=FEE;F]J;W0@:F%U;G4@:65R86MS
M='4N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X-PHC+"!F=7IZ>0IM<V=I9"`B
M06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N
M97<@=&%S:RXB"FUS9W-T<B`B2^_[9&$@<&EE=FEE;F]J;W0@:F%U;G4@:65R
M86MS='4N(@H*(SH@;65S<V%G92YP:'`Z-3`P(&UA:6QB;W@N<&AP.C<Q-"!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C,U"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI
M;F,Z-@IM<V=I9"`B06YS=V5R960B"FUS9W-T<B`B071B:6QDYW1S(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B06YS=V5R960@
M;65S<V%G97,B"FUS9W-T<B`B071B:6QDYW3B<R!VYW-T=6QE<R(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B
M07!P;'D@1FEL=&5R<R(*;7-G<W1R(")0:65L:65T;W0@9FEL=')U<R!U>B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B07!P;'D@1FEL=&5R<R!T;R`E<R(*;7-G<W1R
M(")0:65L:65T;W0@9FEL=')U<R!U>B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL=&5R(')U
M;&5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`B4&EE<VSG9'IO=&EE<R!P
M:65L:65T;W0@9FEL='+G\&%N87,@;&EK=6UU<RXB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(D%P<&QY(&9I
M;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_(@IM<V=S
M='(@(D%T:F%U;F]J;W0@<&%S=&MA<W1I('!I96QI971O="!F:6QT<N?P86YA
M<R!L:6MU;75S+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L(&9U>GIY"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\B
M"FUS9W-T<B`B5F%I(&K[<R!E<V%T('#B<FQI96-I;N)T<RP@:V$@=N=L871I
M97,@=&\@9&%R[G0_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW
M.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(B(*(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I
M<R!.3U0@<F5C;VUM96YD960A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FIS.C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T
M:&ES/R(*;7-G<W1R(")686D@:OMS(&5S870@<.)R;&EE8VENXG1S+"!K82!V
MYVQA=&EE<R!T;R!D87+N=#\B"@HC.B!M97-S86=E+G!H<#HT,#<@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S
M<V%G97,_(@IM<V=S='(@(B(*(E9A:2!J^W,@97-A="!PXG)L:65C:6[B=',L
M(&MA(';G;&%T:65S($Y%051'4DE%6D5.25-+22!I>F1ZYW-T(/#N<R!VYW-T
M=6QE<S\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U>GIY
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@
M9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B(@HB5F%I(&K[<R!E
M<V%T('#B<FQI96-I;N)T<RP@:V$@=N=L871I97,@3D5!5$=2245:14Y)4TM)
M(&EZ9'KG<W0@\.YS(';G<W1U;&5S/R(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@96UP='D@=&AI<R!F;VQD97(_(@IM<V=S='(@(E9A:2!J^W,@=&EE\.)M
M(';G;&%T:65S(&EZ='5K\&]T(/!O(&UA<&D_(@H*(SH@;&EB+TE-4"YP:'`Z
M.3<S"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`B5F%I(&K[<R!T:67P
MXFT@=N=L871I97,@:7IT=6OP;W0@871K<FET=6UU(&UA<&D_(@H*(SH@;&EB
M+TE-4"YP:'`Z.38V"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M96UP='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(E9A:2!J^W,@=&EE
M\.)M(';G;&%T:65S(&EZ='5K\&]T(&%T:W)I='5M=2!M87!I/R(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*(RP@9G5Z>GD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@
M=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(B(*(E9A:2!J^W,@97-A="!PXG)L
M:65C:6[B=',L(&MA(';G;&%T:65S($Y%051'4DE%6D5.25-+22!I>F1ZYW-T
M(/#N<R!VYW-T=6QE<S\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R
M:7!T+FEN8SHX,"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW
M.0HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E
M<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_(@IM<V=S='(@(E9A:2!J
M^W,@=&EE\.)M(';G;&%T:65S(&EZ='5K\&]T(/!O(&UA<&D_(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-S4@=&5M<&QA=&5S+VUA
M:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*(RP@9G5Z>GD*;7-G:60@(D%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S('-P
M86T_(@IM<V=S='(@(E9A:2!J^W,@=&EE\.)M(';G;&%T:65S(&EZ='5K\&]T
M(/!O(&UA<&D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I
M9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(E-A\F5M\&%N87,@;&%I:W,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E;F1I;F<B
M"FUS9W-T<B`B075G;_!I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$Y"FUS
M9VED(")!='1A8V@B"FUS9W-T<B`B4&EE=FEE;F]T(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<U"B,L(&9U>GIY"FUS9VED(")!='1A
M8V@@1FEL97,B"FUS9W-T<B`B4&EE;&EK=6UI(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-#4V"FUS9VED(")!='1A8V@@82!C;W!Y(&]F
M('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3`Y"B,L(&9U>GIY
M"FUS9VED(")!='1A8VAE9"!&:6QE.B(*;7-G<W1R(")0:65V:65N;W0B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z-#4Q(&QI8B]#;VUP;W-E+G!H<#HU,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB071T86-H960@9FEL92!<(B5S7"(@97AC
M965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T
M86-H960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HS-S8*;7-G:60@(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A
M<B!R97%U97-T('EO=2!S96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C$V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHQ-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU,#8@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3<*;7-G
M:60@(D%T=&%C:&UE;G0B"FUS9W-T<B`B4&EE;&EK=6US(@H*(SH@8V]M<&]S
M92YP:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")!='1A8VAM
M96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W,PHC.B!L:6(O0V]M<&]S
M92YP:'`Z,3`W,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`B4&EE;&EK
M=6UI(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,@HC+"!F=7IZ
M>0IM<V=I9"`B071T96YD965S(@IM<V=S='(@(E!I96QI:W5M:2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"B,L(&9U>GIY"FUS
M9VED(")!='1E;G1I;VXB"FUS9W-T<B`B1&%R8NYB82(*"B,Z(&QI8B]!=71H
M+VEM<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-#`*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I
M;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@
M;7D@(@HB861D<F5S<V)O;VL_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B079A
M:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(E!I965J86WB<R!A9')E
M<W4@9W+B;6%T87,Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q
M.0IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`B071P
M86MA[R!U>B`E<R(*"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0F%C:R!T;R`E<R(*;7-G<W1R(")!='!A:V'O('5Z("5S(@H*(SH@=&AR
M96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6
M:65W($EN9&5X(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,R"FUS9VED
M(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!O
M<B!M86QF;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M
M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G
M<W1R(")"8V,B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*
M;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN
M9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM<V=S='(@(DUE
M;&YA:7,@<V%R86MS=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C(Y
M"FUS9VED(")";&]C:R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@
M=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E<W1E9#\B"FUS9W-T<B`B(@H*
M(SH@;&EB+U-E87)C:"YP:'`Z-#(*;7-G:60@(D)O9'DB"FUS9W-T<B`BS65R
M;65N:7,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C(S('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z,SD*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHU-2!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C<Q"FUS9VED
M(")";W1H(@IM<V=S='(@(D%B:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.#<*;7-G:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@
M365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHR-S(*;7-G:60@(D-?:&%R<V5T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G
M:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Y.0IM
M<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V
M97(Z("(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&%R=&EA;"YP
M:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V%N(&YO="!D:7-P;&%Y
M("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@
M:6X@=&AE(&-U<G)E;G0@(@HB;6%I;&)O>"XB"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z,C@T('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,C4U"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C$@=&5M<&QA
M=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C$Y"B,Z('1E;7!L871E<R]S
M;6EM92]P87-S<&AR87-E+FEN8SHR,2!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z.#8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$R,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,R"B,Z('1E;7!L
M871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C8*;7-G:60@(D-A;F-E;"(*;7-G
M<W1R(")!=&-E;'0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHW,2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S4*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,0IM<V=I9"`B0V%N8V5L
M($UE<W-A9V4B"FUS9W-T<B`B071C96QT(';G<W1U;&DB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FIS.C8*;7-G:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I
M;&P@<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@
M(D%T8V7O;W0@=N=S='5L:2P@=&EK<R!N96%T9W)I97IE;FES:VD@:7ID>N=S
M=',@=.)S('-A='5R<RXB"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5C;VUP;W-E+FEN8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM<V=I9"`B
M0V,B"FUS9W-T<B`B0V,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V86EL
M86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R`B"B)S
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW,#$*(RP@9G5Z>GD*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R(")0
M97)S;V[N9V%I<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHX,`IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(DUA:6[N="(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L
M;"(*;7-G<W1R("))>FUA:6[N="!V:7-U<R(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E($9O;&1E<B(*;7-G
M<W1R("))>G9E:61O="!M87!I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S
M(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"`B
M"B)H;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`B(@HB27IM86EN
M[G0@96MRXFYA('!A<F%M971R=7,L('!I96WG<F%M+"!VYW-T=>]U('-K86ET
M=2!K871RXB!L87#B('5N(&OB("(*(G;G<W1U;&5S('1I:W,@:^)R=&]T87,N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY"FUS9VED
M(")#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS
M9W-T<B`B27IM86EN[G0@<&%S=&$@<V5R=F5R82!P87)A;65T<G5S+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB
M"FUS9W-T<B`B(@HB27IM86EN[G0@=N)R9'4L(&%D<F5S:2!U;B!P87)A:W-T
M=2P@:V%S(&+[<R!R961Z86UI(';G<W1U[W4@<V'RYVWG:FEE;2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(T"FUS9VED(")#:&%R86-T97)S('1O
M(&1I<W!L87DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C$U"FUS9VED(")#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-
M86EL(@IM<V=S='(@(E#B<F)A=63N="!M87#G*',I(&IA=6YO('!A<W1U(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C<U"FUS9VED(")#:&5C:R!?
M06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F
M971C:&UA:6PN:6YC.C$P('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL
M+FEN8SHR,0IM<V=I9"`B0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N
M="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-C,*(RP@9G5Z>GD*;7-G:60@(D-H96-K('-P96QL
M:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B4F%DXG,@
M:^_[9&$@<_MT;W0@=N=S='5L:3H@)7,B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHT"FUS9VED(")#:&]O<V4@06-T:6]N.B(*;7-G<W1R
M("))>G;G;&EE=&EE<R!D87)B[F)U.B(*"B,Z(&-O;F9I9R]S97)V97)S+G!H
M<"YD:7-T.C$X,@HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V
M97(Z(@IM<V=S='(@(DEZ;6%I;NYT('!A<W1A('-E<G9E<F$@<&%R86UE=')U
M<RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,C4@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,38V"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(Q-PIM<V=I9"`B0VAO;W-E(&$@;6%T8V@@
M;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C$@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<S,0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&%N(&%C
M=&EO;CHB"FUS9W-T<B`B27IVYVQI971I97,@9&%R8NYB=3HB"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*(RP@9G5Z>GD*;7-G
M:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN
M9R!A9&1R97-S97,N(@IM<V=S='(@(DEZ=N=L:65T:65S(&%D<F5S=2!G<N)M
M871U+"!K=7)A:2!P:65V:65N;W0@:F%U;N)S(&%D<F5S97,N(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"B,L(&9U>GIY"FUS
M9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A
M<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B27IVYVQA
M=&EE<R!KXG)T[F)U+"!KXF3B('#B<F)A=63N="!A9')E<W4@9W+B;6%T87,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I
M;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@
M<&%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@
M=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S
M='(@(E)A:W-T[G0@=N=S='5L97,@871S979I\.WB(&QO9^(N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT
M,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I
M97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S
M='(@(E)A:W-T[G0@=N=S='5L97,@871S979I\.WB(&QO9^(N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P
M87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@=&\@
M4TA/5R!T:&4@26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,R,0HC+"!F=7IZ>0IM<V=I9"`B(@HB0VQI
M8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@
M=&AE;B!S96QE8W0@86QL(&9I96QD<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@
M(B(*(DYO<W!I9?YA="!U>B!V:65N87,@;F\@:7IVYVSG=&%JXFT@861R97-U
M(&=RXFUA=.)M('5N('1A9"!I>G;G;&%T:65S('9I<W5S("(*(FQA=6MU<RP@
M:W5R;W,@;65K;.=T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W
M,0IM<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R
M($%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R!T;R!3
M879E(%,O34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E<W,@
M0F]O:R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34P
M"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@
M82!N97<@;65S<V%G92!T;R!T:&4@<V5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3$*;7-G:60@(D-L:6-K:6YG(&]N('1H
M92!A9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN
M8SHR.`HC+"!F=7IZ>0IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B4F%K<W3N="(*
M"B,Z(&-O;7!O<V4N<&AP.C@R."!C;VUP;W-E+G!H<#HQ,30X"FUS9VED(")#
M;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT
M,CD*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS9W-T<B`B36%P92!A:7IVYW)T
M82(*"B,Z(&9O;&1E<G,N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B0V]L;&%P
M<V4B"FUS9W-T<B`B06EZ=N=R="!V:7-U(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*;7-G<W1R
M(")!:7IVYW)T('9I<W4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T<B`B
M06EZ=N=R="!V:7-A<R!M87!E<R(*"B,Z(&9O;&1E<G,N<&AP.C0T.0IM<V=I
M9"`B0V]L;&%P<V4@1F]L9&5R(@IM<V=S='(@(D%I>G;G<G0@;6%P:2(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L
M;W(@26YD:6-A=&]R.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$P,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S8Y"B,L(&9U>GIY"FUS9VED(")#;VUP
M;&5T960B"FUS9W-T<B`B4F%K<W3N="(*"B,Z(&-O;7!O<V4N<&AP.C@R-R!C
M;VUP;W-E+G!H<#HQ,30W"B,L(&9U>GIY"FUS9VED(")#;VUP;W-E(&%N;W1H
M97(@;65S<V%G92(*;7-G<W1R(")286MS=.YT(';G<W1U;&DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#,T"B,L(&9U>GIY"FUS9VED(")#;VUP;W-E
M(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")286MS
M=.YT(';G<W1U;&5S(&%T<V5V:?#MXB!L;V?B+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET
M:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S
M('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8W"FUS9VED(")#;VYF:6=U<F4@:&]W(&UE<W-A9V5S(&%R
M92!D:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-PHC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE
M=R!O<'1I;VYS+B(*;7-G<W1R("))>FUA:6[N="!P87-T82!S97)V97)A('!A
M<F%M971R=7,N(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G:60@
M(D-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@(D-O;FYE
M8W1I;VX@=&\@<V5R=F5R(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R
M;VP@4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R
M;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P=&EO;G,@
M<F5L871I;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O;G1R;VP@
M=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE
M<B!O<B!N;W0@=&\@;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV97,N(@IM
M<V=S='(@(DEE<W3B9.YT+"!K860@<.)R8F%U9.YT('!A<W1U('5N(&)R[F1I
M;N)T('!A<B!J875N82!P87-T82!P:65NXFOP86YU+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.38*;7-G:60@(D-O;G9E<G0@=&5X='5A;"!E;6]T
M:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@
M(DMO<.=T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"B,L(&9U
M>GIY"FUS9VED(")#;W!Y('1O(&9O;&1E<B(*;7-G<W1R("))>G1U:_!O="!A
M=&MR:71U;74@;6%P:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G<W1R(")087)E:7II(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B0V]R
M<F5C=&5D(%1E>'0B"FUS9W-T<B`B27IL86)O=',@=&5K<W1S(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ
M("5S(@IM<V=S='(@(DYE:7ID97;B<R!I>F1ZYW-T(';G<W1U;&5S(&YO("5S
M.B`E<R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C0P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@
M)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B3F5I>F1E=N)S(&EZ
M9'KG<W0@=N=S='5L97,@;F\@)7,Z("5S(@H*(SH@;&EB+U-E<W-I;VXN<&AP
M.C,Q.`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`B57IT=7+G\&%N87,@;W!E<N)C
M:6IA<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HU-`IM<V=I9"`B
M0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE
M($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H
M92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@87)C:&EV92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(W,PIM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C,Q-"!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C,Y"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C`*;7-G:60@(D-R96%T
M92(*;7-G<W1R("))>G9E:61O="(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C8*;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T<B`B27IV
M96ED;W0@;6%P:2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*(RP@
M9G5Z>GD*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(DEZ=F5I9&]T(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$T"B,L(&9U>GIY"FUS
M9VED(")#<F5A=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B27IV96ED;W0@
M;6%P:2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N
M:6YC.C(V"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA
M=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")#
M<F5A=&4@82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B27IV96ED;W0@:F%U
M;G4@;6%P:2!A=&MR:71U;6EE;2(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD
M97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N
M:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<B(*;7-G
M<W1R("))>G9E:61O="!J875N=2!M87!I(&UE;&YR86MS=&EE;2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@
M;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B27IV96ED;W0@:F%U;G4@
M;6%P:2!N;W/[=.YT86KB;2!VYW-T=6SG;2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L
M96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(*
M;7-G<W1R("))>G9E:61O="!J875N=2!M87!I(&%T:W)I='5M:65M(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R.`IM<V=I9"`B(@HB0W)E871E(&9I
M;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL
M('-O<G0@:70@:6YT;R!F;VQD97)S+"`B"B)A;F0@9&5L971E('-P86TN(@IM
M<V=S='(@(B(*(DEZ=F5I9&]T(&9I;'1RY_!A;F%S(&QI:W5M=7,@:65NXFMO
M\.(@<&%S=&$@;W)G86YI>N?P86YA:2X@2^)R=&_P86YA('!A("(*(FUA<.=M
M('5N(&1ZY_!A;F$N(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB
M"FUS9W-T<B`B27IV96ED;W0@:F%U;G4@;6%P:2!N;W/[=.YT86KB;2!VYW-T
M=6SG;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*;7-G:60@(D-R
M96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4*;7-G:60@(D-U<W1O;6EZ92!A8V-O
M=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*(RP@9G5Z
M>GD*;7-G:60@(D-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"XB"FUS9W-T
M<B`B4&EE;.)G;W0@<&%S=&$@<_MT[O!A;G4@=6X@;65L;G)A:W-T=2!S86=L
M86+B\&%N=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+B(*;7-G<W1R(")0:65LXF=O="!U>F1E=G5M=7,L(&MA<R!T
M:65K('9E:6MT:2!P:65S;.=D>F]T:65S("5S+B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@
M(D1A=%]E(@IM<V=S='(@(D1A='5M<R(*"B,Z(&UE<W-A9V4N<&AP.C(V,B!T
M:')E860N<&AP.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R(")$871U;7,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4W"B,L(&9U>GIY"FUS9VED
M(")$96-L:6YE9"(*;7-G<W1R("))>F1ZYW-T<R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HR-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I
M9"`B1&5F875L="(*;7-G<W1R(")$>N=S="(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHQ.`IM<V=I9"`B1&5F875L="!3
M96%R8V@@1FEE;&0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDR,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G
M<W1R(").;VML=7/G=&EE(&OB<G1O\&%N87,@;F]S86/N:G5M:3HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,S"FUS9VED(")$969A=6QT('-O<G1I
M;F<@9&ER96-T:6]N.B(*;7-G<W1R(").;VML=7/G=&%I<R!KXG)T;_!A;F%S
M('9I<GII96YS.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C4*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R("))>F1ZYW-T<R(*
M"B,Z(&9O;&1E<G,N<&AP.C0Q.2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M-#0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z."!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ,`HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C(U('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR.`HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D1E;&5T92(*;7-G
M<W1R(")$>N=S="(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U
M"FUS9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G:60@(D1E;&5T92!&
M;VQD97(H<RDB"FUS9W-T<B`B1'KG<W0@;6%P:2@M97,I(@H*(SH@9F]L9&5R
M<RYP:'`Z,C@U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L
M9&5R<R(*;7-G<W1R(")$>N=S="!M87!I*"UE<RDB"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!3=&%T:6]N97)Y(@IM<V=S='(@(D1ZYW-T(&UA<&DH+65S*2(*"B,Z(&9O
M;&1E<G,N<&AP.C0Q.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%9I<G1U86P@
M1F]L9&5R(@IM<V=S='(@(D1ZYW-T(&UA<&DH+65S*2(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L971E(&9E=&-H
M960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(X"FUS9VED(")$96QE=&4@
M9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8X"B,L(&9U>GIY"FUS9VED(")$96QE=&4@;VQD(&QI;FME
M9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@
M(DWG;F7P82!SXFMU;>(@:7ID>N=S="!V96/B<R!N;W/[=.YTXB!P87-T82!M
M87!E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3`*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN
M:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")-YVYE\&$@<^)K=6WB(&EZ9'KG<W0@
M=F5CXG,@;F]S^W3N=.(@<&%S=&$@;6%P97,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C$W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<W!A;2!M97-S
M86=E<R(*;7-G<W1R(")$>N=S="!VYW-T=6QE<R(*"B,Z(&UE<W-A9V4N<&AP
M.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,X('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L971E9"(*
M;7-G<W1R("))>F1ZYW-T<R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B27ID>N=S
M=.)S(';G<W1U;&5S(@H*(SH@8V]M<&]S92YP:'`Z,S`W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB)7-<
M(BXB"FUS9W-T<B`B4&EE;&EK=6US(&EZ9'KG<W1S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@36]V:6YG($UE
M<W-A9V5S(@IM<V=S='(@(D1ZYW-T('5N('#B<G9I971O="!VYW-T=6QE<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3(*;7-G:60@(D1E;GD@
M<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-30P"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3,R"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(D1I;'-T;_!I(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(Q(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T
M:6]N(@IM<V=S='(@(DQI971O=.)J82!O<&-I:F%S(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")$
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-S<*;7-G:60@(D1I;2!S:6=N871U<F5S/R(*;7-G<W1R(")-873G="!P87)A
M:W-T=7,_(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M,S8*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B4&%RXF3N="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-SD*;7-G:60@(D1I<W!L87D@8V]N9FER;6%T
M:6]N(&%F=&5R('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED(")$:7-P;&%Y(&EN($)O
M9'D@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-SDR"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y('!O<"UU<"!N;W1I
M9FEC871I;VX@;V8@;F5W(&UA:6P_(@IM<V=S='(@(D)R[F1I;N)T('!A<B!J
M875N=2!VYW-T=>]U('!I96[B:_!A;G4N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<U.`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@
M;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!4
M<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B1&ES<&]S:71I;VXB"FUS9W-T<B`B16MRXFYA(&]P8VEJ87,B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/
M5"!M871C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHQ-@IM<V=I9"`B1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@
M3F5W($UA:6PB"FUS9W-T<B`B3F5PXG)B875D[G0@:F%U;F\@<&%S='4@;6%P
MYW,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34R"FUS9VED(")$;R!N
M;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`W-0IM<V=I9"`B1&\@>6]U('=A;G0@
M=&\@;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`B5F%I(&K[<R!VYVQA=&EE
M<R!A=';G<G0@\&\@;6%P:3\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(S,@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3(V"FUS9VED(")$;VYE(@IM<V=S='(@(DEZ<&EL9.YT<R(*"B,Z(&QI
M8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3(*;7-G:60@(D1O=VYL;V%D
M($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,`IM<V=I9"`B1&]W
M;FQO860@1F]L9&5R*',I(@IM<V=S='(@(DEE;.)DYW0@;6%P:2@M97,I(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*(RP@9G5Z>GD*
M;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=(@IM<V=S
M='(@(DEE;.)DYW0@;6%P:2@M97,I(@H*(SH@;&EB+TU)344O0V]N=&5N=',N
M<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M870B"FUS9W-T
M<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC
M.CD*;7-G:60@(D1R869T(@IM<V=S='(@(DUE;&YR86MS=',B"@HC.B!F;VQD
M97)S+G!H<#HS.3(*(RP@9G5Z>GD*;7-G:60@(D1R869T(&9O;&1E<B(*;7-G
M<W1R(")-96QN<F%K<W1U(&UA<&4Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O
M;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD97(Z(@IM<V=S
M='(@(DUE;&YR86MS='4@;6%P93HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3`X"B,L(&9U>GIY"FUS9VED(")%+6UA:6P@061D<F5S<R(*;7-G<W1R
M(")%+7!A<W1A(&%D<F5S92(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,#D*;7-G
M:60@(D5.1"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HW-`IM<V=I9"`B15)23U(Z(%EO=7(@;65S<V%G92!C;W5L9"!N;W0@
M8F4@9&5L:79E<F5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,C`@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$Y"FUS9VED(")%9&ET
M(@IM<V=S='(@(E)E9&GLYW0B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM<V=S
M='(@(DUE;&YA:7,@<V%R86MS=',B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G
M<W1R(")087-T82!F:6QT<FDB"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C$V"FUS9VED(")%9&ET(%9I<G1U86P@
M1F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L($9O
M;&1E<B!$969I;FET:6]N(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ
M.`HC+"!F=7IZ>0IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*;7-G<W1R
M(")2961I[.=T(&9I;'1RY_!A;F%S(&QI:W5M=7,B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@
M<G5L97,B"FUS9W-T<B`B4F5D:>SG="!F:6QT<N?P86YA<R!L:6MU;75S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V,0IM<V=I9"`B161I="!Y;W5R
M('!R969E<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C(S"B,L(&9U>GIY"FUS9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S
M='(@(E)E9&GLYW0@9FEL='+G\&%N87,@;&EK=6UU<R(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(D4M<&%S=&$@861R97-E(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C8U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B16UP=&EE9"!A
M;&P@;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T<B`B27IT[G+N=&%S('9I<V%S
M(';G<W1U;&5S(&YO("5S+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B27IT
M=6OP;W0@;6%P:2@M97,I(@H*(SH@9F]L9&5R<RYP:'`Z,C@V"B,L(&9U>GIY
M"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(DEZ='5K
M\&]T(&UA<&DH+65S*2(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C,Y"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`B27IT
M=6OP;W0@871K<FET=6UU(&UA<&DB"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@
M9G5Z>GD*;7-G:60@(D5M<'1Y(%]3<&%M(@IM<V=S='(@(DEZ='5K\&]T(&%T
M:W)I='5M=7,B"@HC.B!L:6(O24U0+G!H<#HY-C8*(RP@9G5Z>GD*;7-G:60@
M(D5M<'1Y(%]4<F%S:"(*;7-G<W1R("))>G1U:_!O="!A=&MR:71U;75S(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$@=&5M<&QA=&5S+W!G<"]N;W1A
M8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ('1E
M;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C8*;7-G:60@(D5N86)L92!3
M+TU)344@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@Q,0IM<V=I9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE
M=W,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0T,@IM<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$W(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-3<*;7-G:60@(D5N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S@T"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A
M9V4B"FUS9W-T<B`B4.)R<_MT[G3B<R!VYW-T=6QE<R!B96EG87,B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,S0Q"B,L(&9U>GIY"FUS9VED(")%;F0@;65S<V%G
M92(*;7-G<W1R(")696/B<R!VYW-T=6QE<R(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5N9"!M97-S86=E
M(&9R;VT@)7,B"FUS9W-T<B`B4.)R<_MT[G1A(';G<W1U;&4@;F\@)7,B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW-PIM<V=I9"`B16YT97(@4&%S<W!H<F%S92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z.0HC+"!F=7IZ
M>0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P86T@9F]L
M9&5R(@IM<V=S='(@(DEE=F%D:65T(&IA=6[B<R!A=&MR:71U;74@;6%P97,@
M;F]S875K=6UU(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T
M<R!F;VQD97(B"FUS9W-T<B`B265V861I970@:F%U;N)S(&UE;&YR86MS='4@
M;6%P97,@;F]S875K=6UU(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL
M<V5L96-T+FEN8SHR,PIM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@
M;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B265V861I970@:N)U;N)S
M(&YO<_MT[G1O('!A<W1U(&UA<&5S(&YO<V%U:W5M=2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA
M;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<B(*;7-G<W1R("))979A9&EE
M="!J875NXG,@871K<FET=6UU(&UA<&5S(&YO<V%U:W5M=2(*"B,Z(&QI8B]3
M96%R8V@N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")%;G1I<F4@365S<V%G92(*
M;7-G<W1R(")0XG)A9')E<^=T(';G<W1U;&DB"@HC.B!M97-S86=E+G!H<#HQ
M.30@8V]M<&]S92YP:'`Z,3$S-"!T:')E860N<&AP.C<Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")%;G1R>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(DEE<F%K<W1S
M(%PB)7-<(B!V96EK<VWN9VD@<&EE=FEE;F]T<R!A9')E<W4@9W+B;6%T86DB
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$X('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR,0HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W
M-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.#8*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z-S(@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M,38S"FUS9VED(")%<G)O<B(*;7-G<W1R(")+[_MD82(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z-#4T"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-O
M;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S(#H@)7,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,#D@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S
M96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B179E;G0@<W5C8V5S
M<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(DUA<&4@7"(E<UPB('9E:6MS;>YG
M:2!I>F1ZYW-T82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@R"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMA=')A<R`Q-2!M:6[[
M=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W.0IM<V=I9"`B179E
M<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")+871R87,@,S`@<V5K=6YD97,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q"FUS9VED(")%=F5R>2`U(&UI
M;G5T97,B"FUS9W-T<B`B2V%T<F%S(#4@;6EN^W1E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.#,*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G
M<W1R(")+871R=2!P=7-S='5N9'4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S@P"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2V%T<G4@;6EN
M^W1I(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B071VYW)T('9I<W5S(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`B
M071VYW)T('9I<W5S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R(")!=';G
M<G0@=FES87,@;6%P97,B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X
M<&%N9"!&;VQD97(B"FUS9W-T<B`B071VYW)T(&UA<&DB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C4S"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T<B`B
M4&%RXF3N="!VXG)D=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V
M,PIM<V=I9"`B17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A
M=71O;6%T:6-A;&QY(&EN('1H92!B86-K9W)O=6YD/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@P"B,L(&9U>GIY"FUS9VED(")%
M>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN('1H
M92!F;VQD97)S('9I97<_(@IM<V=S='(@(DYO:VQU<^=T:2!A=';G<G0@=FES
M=2!M87!J=2!K;VMU(&UA<&IU('-K873N:G5MXBXB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(T-2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3`Q"B,L(&9U
M>GIY"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T<B`B071VYW)T('9I<W5S(@H*
M(SH@;&EB+TE-4"YP:'`Z.3@T(&QI8B])35`N<&AP.CDX-@HC+"!F=7IZ>0IM
M<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T<B`B2F%U;F$@=N=S='5L92(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`T"B,L(&9U>GIY"FUS9VED(")&971C:"!-86EL
M(@IM<V=S='(@(DIA=6YA(';G<W1U;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#8Y"B,L(&9U>GIY"FUS9VED(")&971C:"!-86EL(&EN(&$@<V5P
M87)A=&4@=VEN9&]W/R(*;7-G<W1R(")286MS=.YT(';G<W1U;&5S(&%T<V5V
M:?#MXB!L;V?B+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHT-@HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G
M:6YG(&]N/R(*;7-G<W1R(")0:65S;.=D>F]T:65S('!I96QI971O="!F:6QT
M<N?P86YA<R!L:6MU;75S+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E
M<R!F<F]M("5S(@IM<V=S='(@(DEZ=.YR[G1A<R!V:7-A<R!VYW-T=6QE<R!N
M;R`E<RXB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS
M9W-T<B`B4.)R<_MT[G1A(';G<W1U;&4@;F\@)7,B"@HC.B!L:6(O1F5T8VAM
M86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C:&UA
M:6PN<&AP.C(X.0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")&971C:&UA
M:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B2G5M<R!I<B`E<R!J875N
M87,@=N=S='5L97,N(@H*(SH@;&EB+TE-4"YP:'`Z.3DP"B,L(&9U>GIY"FUS
M9VED(")&:5]L=&5R<R(*;7-G<W1R(")&:6QT<FDB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B
M1FEL=')I(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"B,L
M(&9U>GIY"FUS9VED(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R(")#:71A<R!O
M<&-I:F%S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.CD*(RP@
M9G5Z>GD*;7-G:60@(D9I;'1E<B!3971T:6YG<R(*;7-G<W1R(")&:6QT<N?P
M86YA<R!L:6MU;6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`P"B,L
M(&9U>GIY"FUS9VED(")&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F
M86YI='D_(@IM<V=S='(@(D9I;'1RYW0@=N=S='5L97,@<V%T=7)U('#G8R!P
M<F]F86[B8VEJ87,N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E
M+FEN8SHQ,0IM<V=I9"`B1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@
M=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C<*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')I(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHS"FUS9VED(")&:6QT
M97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z
M,3`U"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<G,Z("5S(&UA;F%G96UE
M;G0@<&%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN9"(*;7-G<W1R(")-96MLYW0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`U"B,L(&9U>GIY"FUS9VED(")&
M:7)S="!-86EL8F]X(%!A9V4B"FUS9W-T<B`B4&ER;>(@;&%P82(*"B,Z(&UA
M:6QB;W@N<&AP.C,T-0IM<V=I9"`B1FER<W0@4&%G92(*;7-G<W1R(")0:7)M
MXB!L87!A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"B,L(&9U
M>GIY"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R(")0XG)S^W3N="(*"B,Z(&9O
M;&1E<G,N<&AP.C(V-B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I
M<FTN:'1M;#HU"FUS9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O
M;&1E<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A
M9V5S96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E
M<V5L96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R
M(")-87!J=2!C9>]V961I<R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS
M"B,L(&9U>GIY"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R(")&96)R
M=>)R:7,B"@HC.B!A8VPN<&AP.C(T"FUS9VED(")&;VQD97(@<VAA<FEN9R!I
M<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-C(*
M;7-G:60@(D9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-CD*;7-G:60@(D9O<FUA="!O
M9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A
M9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C<X
M,"!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A
M<F0B"FUS9W-T<B`B4.)R<_MT[G0B"@HC.B!C;VUP;W-E+G!H<#HW-C4*;7-G
M:60@(D9O<G=A<F0Z(@IM<V=S='(@(E#B<G/[=.YT.B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HS-CD*(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E
M(@IM<V=S='(@(E#B<G/[=.YTXG,@=N=S='5L97,@8F5I9V%S(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;W)W87)D
M960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(E#B<G/[=.YT82!VYW-T=6QE
M(&YO("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,PHC+"!F
M=7IZ>0IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(E-E
M<G9E<F$@:6YF;W)MXF-I:F$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#DT"FUS9VED(")&<F5E+T)U<WD@4F5P;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`IM<V=I9"`B1G)E92]"=7-Y
M(%)E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0P,0IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B1G)O7VTB"FUS9W-T<B`B4_MT[G3B
M:G,B"@HC.B!M97-S86=E+G!H<#HR-C,@=&AR96%D+G!H<#HQ-#D@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.3D*(SH@;&EB+U-E87)C:"YP:'`Z
M,C(*;7-G:60@(D9R;VTB"FUS9W-T<B`B4_MT[G3B:G,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3$X"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T
M<B`B4_MT[G3B:F$@861R97-E(@H*(SH@8V]M<&]S92YP:'`Z-S<W(&-O;7!O
M<V4N<&AP.C<X,0IM<V=I9"`B1G=D.B(*;7-G<W1R(")&=SHB"@HC.B!C;VUP
M;W-E+G!H<#HQ,CDT"B,L(&9U>GIY"FUS9VED(")&=V0Z("(*;7-G<W1R(")&
M=SHB"@HC.B!C;VUP;W-E+G!H<#HQ,CDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E<R(*;7-G<W1R(")0
MXG)S^W3N=.)S(';G<W1U;&5S(&)E:6=A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`HC
M+"!F=7IZ>0IM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S='(@(DQI971O
M=.)J82!O<&-I:F%S(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N
M;'DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C,Q"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$S
M-@HC+"!F=7IZ>0IM<V=I9"`B1V\@=&\@365S<V%G92(*;7-G<W1R(").XFMA
M;>(@=N=S='5L92(*"B,Z(&QI8B])35`N<&AP.C0Y.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F(%PB
M)7-<(B(*;7-G<W1R(")0:65V:65N;W0@:V]N=&%K=&EE;2`H)7,I(@H*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@86-C97-S
M(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T-B!L:6(O1FEL=&5R+G!H
M<#HQ,#4@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.34*(SH@;&EB+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$P-`HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC.B!L:6(O34E-12]6:65W
M97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z
M-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(SH@;&EB+TU)344O
M5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(P(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM<V=I9"`B2$5212(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S$@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-PHC.B!L:6(O34E-12]6:65W
M97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@
M8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I;VX@;V8@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN
M8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@=&AE(&UE
M<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C8X"FUS9VED(")(:61D96XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PHC+"!F=7IZ>0IM<V=I
M9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(E!A=F5D:65N=2!S
M:V%T[FIU;7,B"@HC.B!M86EL8F]X+G!H<#HS-C<*;7-G:60@(DAI9&4@1&5L
M971E9"(*;7-G<W1R(")087-LYW!T(&EZ9'KG<W1O<R(*"B,Z(&9O;&1E<G,N
M<&AP.C(Y.`IM<V=I9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`B4&%S
M;.=P="!N97!A<F%K<W3N=&]S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z(&UE<W-A
M9V4N<&AP.C(Y-R!M86EL8F]X+G!H<#HW,C0@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ,@IM<V=I9"`B2&EG:"!0<FEO<FET>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@
M(DAI9VAE<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8X.`IM<V=I9"`B2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H
M;65N=',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,#0*(RP@9G5Z>GD*;7-G:60@(DAO=R!T;R!A='1R:6)U=&4@<75O=&5D(&QI
M;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`B2^(@<')E9FEK<^=T('/B:V]T;N=J
M;R!VYW-T=6QI+"!R86MS=&]T(&%T8FEL9&DZ(@H*(SH@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T
M96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HS.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!397)V97(@8VQO
M<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-33"(*
M;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$U,@IM<V=I
M9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38W"FUS
M9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-C@*;7-G:60@(DE-05`@<V5R=F5R
M(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C4@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C0Y"FUS9VED("))34%0+U!/4#,@36%I;"!3
M97)V97)S(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C@V-@IM<V=I9"`B
M24Y"3U@B"FUS9W-T<B`B24Y"3U@B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V
M92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ
M,3(*(RP@9G5Z>GD*;7-G:60@(DEF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A
M9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B92!L;W-T(2(*;7-G<W1R(")6
M:7-A<R!VYW-T=6QE<R!N;R#P[G,@;6%P97,@=&EK<R!I>F1ZYW-T87,A(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@R"FUS9VED("))
M9VYO<F4B"FUS9W-T<B`B26=N;W+G="(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G<W1R("))
M9VYO<N=T('9I<W5S(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA
M9V4N:6YC.C@*;7-G:60@(DEM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+VEM<&]R="YI;F,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEM<&]R
M="(*;7-G<W1R(")3=F%R[F=I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C4*
M(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!+97DB"FUS9W-T<B`B4W9A<NYG:2(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,SD*(RP@9G5Z>GD*;7-G:60@
M(DEM<&]R="!+97EP86ER(@IM<V=S='(@(E-V87+N9VDB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B26UP
M;W)T($UE<W-A9V5S(@IM<V=S='(@(E-V87+N9V%S(';G<W1U;&5S(@H*(SH@
M<&=P+G!H<#HT,@IM<V=I9"`B26UP;W)T(%!'4"!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B26UP;W)T
M(%!E<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O:6UP;W)T7VME>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA
M;"!0<FEV871E(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));7!O<G0@4&5R<V]N86P@4'5B
M;&EC(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM
M<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!097)S;VYA;"!3+TU)344@
M0V5R=&EF:6-A=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS9VED("))
M;7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P
M+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0($ME
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z.`IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@
M(B(*"B,Z('-M:6UE+G!H<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+97DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHY
M"FUS9VED("));7!O<G0@;6)O>"!&:6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T
M<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`R(&UA:6QB;W@N<&AP.C<S-"!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C,S"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M-PIM<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(E-V87+N9VDB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@;65S
M<V%G97,B"FUS9W-T<B`B4W9A<NYG87,@=N=S='5L97,B"@HC.B!F;VQD97)S
M+G!H<#HQ-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D
M("5D(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(DEZ=.YR[G1A<R!V:7-A
M<R!VYW-T=6QE<R!N;R`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S<S"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@(B(*"B,Z(&9O;&1E
M<G,N<&AP.C,X-"!L:6(O1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR
M,30@;&EB+TE-4"YP:'`Z,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L
M:6(O24U!4"]4<F5E+G!H<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3(*(RP@9G5Z>GD*;7-G:60@
M(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D97(@:6X@82!R
M97!L>3\B"FUS9W-T<B`B265K[V%U="!SXFMO=&[G:F\@=N=S='5L:2!A=&)I
M;&3G/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#<*;7-G:60@(DEN
M8VQU9&4@;W)I9VEN86P@;65S<V%G92!I;B!A(')E<&QY/R(*;7-G<W1R("))
M96OO875T('/B:V]T;N=J;R!VYW-T=6QI(&%T8FEL9.<_(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z,3,P"B,L(&9U>GIY"FUS9VED("));F9O(@IM<V=S='(@
M(DEG;F]RYW0B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@;VX@
M4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*
M;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC
M.C$U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY.`HC+"!F=7IZ>0IM<V=I
M9"`B26YL:6YE(@IM<V=S='(@(FYE=FEE;G,B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I9FEC871E
M($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME
M>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z,3`*;7-G:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME
M>2!(97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,@IM<V=I
M9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT
M+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O>"YP:'`Z
M-C(V"B,L(&9U>GIY"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS9W-T<B`B
M12UP87-T82!A9')E<V4B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C,P
M-PIM<V=I9"`B26YV86QI9"!296UO=&4@36%I;&)O>"(*;7-G<W1R("(B"@HC
M.B!C;VUP;W-E+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI
M9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R("(B
M"@HC.B!S;6EM92YP:'`Z.#(@<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K
M97DB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ.38*;7-G:60@(DEN=F%L:60@
M<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!P9W`N
M<&AP.C$W,0IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME
M>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHQ,@IM<V=I9"`B26YV97)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B2T(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T
M:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS
M9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T
M;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E;F5R871I;VX_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S4@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED(")+97D@:6UP;W)T(&ES
M(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N
M('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P+FEN8SHS.0IM<V=I9"`B
M(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A
M9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C;VYT86-T<RXB
M"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME>2!S=6-C97-S
M9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,38*;7-G:60@(DQA
M;F=U86=E(@IM<V=S='(@(E9A;&]D82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,#8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@36%I;&)O>"!086=E(@IM
M<V=S='(@(E#G9.=J82!L87!A(@H*(SH@;6%I;&)O>"YP:'`Z,S4X"FUS9VED
M("),87-T(%!A9V4B"FUS9W-T<B`B4.=DYVIA(&QA<&$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#D*(RP@9G5Z>GD*;7-G:60@(DQI
M7VYK($%T=&%C:&UE;G1S(@IM<V=S='(@(E!I96QI:W5M:2(*"B,Z(&%T=&%C
M:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED("),:6YK
M960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN
M:W,@=VEL;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S
M('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L
M960L('EO=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E
M87)C:"!F;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8X-0IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A9&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`B
M4&%S=&MA<W1E(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`HC
M+"!F=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B1&%R8NYB82(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(U"FUS9VED("),;V<@:6XB
M"FUS9W-T<B`B4&EE<VSG9W1I97,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G
M<W1R(")0:65S;.=G=&EE<R`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3,W"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R(")0:65S
M;.=G=&EE<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I9"`B
M3&]G:6X@5&%S:W,B"FUS9W-T<B`B4&EE<VSG9_!A;N)S('5Z9&5V=6UI(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDV"FUS9VED("),
M;W<B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,CDY(&UA:6QB;W@N<&AP
M.C<R-R!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$S"FUS9VED("),
M;W<@4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`HC+"!F=7IZ>0IM
M<V=I9"`B36%C:6YT;W-H($9I;&4B"FUS9W-T<B`B4&%S=&$@9FEL=')I(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L(&9U>GIY
M"FUS9VED(")-86EL(@IM<V=S='(@(E!A<W1K87-T92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-@HC+"!F=7IZ>0IM<V=I9"`B36%I;"!0<F5V:65W
M<R(*;7-G<W1R(")087-T82!F:6QT<FDB"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V1R:79E<E]S96QE8W0N:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T
M>7!E('1O(&-O;FYE8W0@=&\Z(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP
M.C0P,@IM<V=I9"`B36%I;&)O>"(*;7-G<W1R(")087-T:V%S=&4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L(&9U>GIY"FUS9VED(")-86EL
M8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D5K<N)N
M82!O<&-I:F%S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,3@*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C$Y"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS
M965N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P
M"FUS9VED(")-87)K(&%S.B(*;7-G<W1R(")!='KN;>=T(&OB.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT
M(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS
M9W-T<B`B071Z[FWG="!D8?[B9'5S(&-I=.?P86YA<R!L[FUE\G5S(&%T\.UI
M<NYGXG,@:W+B<^)S/R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHT,`IM<V=I9"`B36%R:R!M97-S86=E<R!A<R!S965N/R`H24U!4"!O
M;FQY*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4X
M"FUS9VED(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT-@IM<V=I9"`B36%T8V@@06QL
M(%%U97)I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D
M97(N:6YC.C0R"FUS9VED(")-871C:"!!;GD@475E<GDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"B,L(&9U>GIY
M"FUS9VED(")-87AI;75M($%T=&%C:&UE;G0@4VEZ92(*;7-G<W1R(")0:65L
M:6MU;7,B"@HC.B!L:6(O87!I+G!H<#HW.0IM<V=I9"`B36%X:6UU;2!.=6UB
M97(@;V8@1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT.30*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T
M=&%C:&UE;G1S(')E86-H960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0X.0IM<V=I9"`B36%X:6UU;2!T;W1A;"!A
M='1A8VAM96YT('-I>F4@<F5A8VAE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B365E=&EN9R!#86YC96QL
M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4W-0HC+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G
M<W1R(")397)V97)A(&EN9F]R;>)C:6IA(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4X-0IM<V=I9"`B365E=&EN9R!0<F]P;W-A;"(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W"FUS9VED(")-
M965T:6YG(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU.3@*;7-G:60@(DUE971I;F<@57!D871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#,*;7-G:60@(DUE971I
M;F<@57!D871E(%)E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R
M965?9F]L9&5R<RYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365N=2!&;VQD97(@
M3&ES="(*;7-G<W1R(")!=';G<G0@;6%P:2(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS,S$*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B5N=S='5L92(*"B,Z(&-O
M;7!O<V4N<&AP.C4V,"!C;VUP;W-E+G!H<#HU.#<@8V]M<&]S92YP:'`Z-C0Q
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP
M;W-I=&EO;B(*;7-G<W1R(")6YW-T=6QE<R!R86MS=.[P86YA(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E(@IM
M<V=S='(@(E;G<W1U;&5S(&1A='5M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M,PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(E;G
M<W1U;&5S('5Z(@H*(SH@<V5A<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@
M4V5A<F-H(@IM<V=S='(@(E;G<W1U[W4@;65K;.?P86YA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I9"`B365S<V%G92!3:7IE(@IM<V=S
M='(@(E;G<W1U;&5S(&EZ;>=R<R(*"B,Z(&UE<W-A9V4N<&AP.C,X-`IM<V=I
M9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`B5N=S='5L97,@<&ER;71E:W-T
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G
M92!6:65W:6YG(@IM<V=S='(@(E;G<W1U;&5S(&%P<VMA=&4B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B
M"FUS9W-T<B`B5N=S='5L97,@:V%R;V1Z:?)I(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM<V=S
M='(@(E;G<W1U[W4@;6%P97,B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS
M9W-T<B`B5N=S='7O=2!M87!E<R(*"B,Z(&UA:6QB;W@N<&AP.C8V-PHC+"!F
M=7IZ>0IM<V=I9"`B365S<V%G92!H87,@871T86-H;65N=',B"FUS9W-T<B`B
M4&EE;&EK=6US(&EZ9'KG<W1S(@H*(SH@;6%I;&)O>"YP:'`Z-C4X"B,L(&9U
M>GIY"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E9"(*;7-G<W1R(")6YW-T
M=6QE<R!L875K:2(*"B,Z(&UA:6QB;W@N<&AP.C8U,PHC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92!I<R!S:6=N960B"FUS9W-T<B`B5N=S='5L97,@;&%U:VDB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S,*(RP@9G5Z>GD*
M;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R(")6YW-T=6QE<R!D871U
M;7,B"@HC.B!C;VUP;W-E+G!H<#HX,C0@8V]M<&]S92YP:'`Z.#,X"B,L(&9U
M>GIY"FUS9VED(")-97-S86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R(")6YW-T=6QE(&YO<_MT[G1A('9E:6MS;>YG:2P@8F5T(&YA=B!S
M86=L86+B=&$B"@HC.B!C;VUP;W-E+G!H<#HQ,#@T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@
M;F]T('-A=F5D('1O("5S(@IM<V=S='(@(E;G<W1U;&4@;F]S^W3N=&$@=F5I
M:W-M[F=I+"!B970@;F%V('-A9VQA8N)T82(*"B,Z(&-O;7!O<V4N<&AP.C$Q
M-#,@8V]M<&]S92YP:'`Z,3$U.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!S
M96YT('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5N=S='5L92!N;W/[=.YT82!V
M96EK<VWN9VDL(&)E="!N878@<V%G;&%BXG1A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDT,0IM<V=I9"`B365S<V%G97,@<&5R('!A9V4@:6X@=&AE
M(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`B5N=S='7O=2!S:V%I=',@=FEE;N(@
M;&%PXB!P87-T:V%S=&5S('-K873N:G5MXBXB"@HC.B!M86EL8F]X+G!H<#HS
M,C(*;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S='(@(E;G<W1U;&5S('5Z(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB"FUS
M9W-T<B`B36%I;NYT(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN
M8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E('1H86X@;VYE(&%D9')E
M<W,@9F]U;F0@9F]R(&9I96QD(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E(@IM<V=S='(@
M(E#B<G9I971O="(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,Q-@HC+"!F=7IZ>0IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(G#B
M<G9I971O=&EE<R!L96IU<"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M,3@*;7-G:60@(DUO=F4@<W!A;2!M97-S86=E<R!T;R!S<&%M(&9O;&1E<B!A
M;F0@:6YN;V-E;G0@;65S<V%G97,@=&\@24Y"3U@B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"B,L(&9U>GIY"FUS9VED(")-
M;W9E('1O(&9O;&1E<B(*;7-G<W1R(")I>G;G;.=T:65S(&UA<&DB"@HC.B!T
M96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,30*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B<.)R=FEE=&]T:65S(&%U9_!U<"(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(W"FUS9VED
M(")-=6QT:7!A<G0O86QT97)N871I=F4B"FUS9W-T<B`B(@H*(SH@=&AR96%D
M+G!H<#HW-B!T:')E860N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B375L=&EP
M;&4@365S<V%G92!6:65W(@IM<V=S='(@(E;G<W1U;&5S(&%P<VMA=&4B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z-0IM
M<V=I9"`B3D].12(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED(").3U1%(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,X(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(DYA;64B"FUS9W-T
M<B`B5N)R9',B"@HC.B!P9W`N<&AP.C$Q,`IM<V=I9"`B3F%M92!A;F0O;W(@
M96UA:6P@8V%N(&YO="!B92!E;7!T>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S<X"B,L(&9U>GIY"FUS9VED(").965D<R!!
M8W1I;VXB"FUS9W-T<B`B1&%R8NYB82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-S`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S<X"FUS9VED(").979E<B(*;7-G<W1R(").96MA
M9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C`*(RP@9G5Z>GD*;7-G
M:60@(DYE=F5R('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B4&EE;&EK=6US
M(&EZ9'KG<W1S(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R-`IM<V=I
M9"`B3F5W(@IM<V=S='(@(DIA=6YS(@H*(SH@;&EB+TE-4"YP:'`Z-38S"B,L
M(&9U>GIY"FUS9VED(").97<@1F]L9&5R(@IM<V=S='(@(D%T=N=R="!M87!I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@36%I
M;"(*;7-G<W1R(")*875N82!VYW-T=6QE(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$Y(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,S"B,L(&9U
M>GIY"FUS9VED(").97<@365S<V%G92(*;7-G<W1R(").XFMA;>(@=N=S='5L
M92(*"B,Z(&UA:6QB;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ
M.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O
M("5S(@IM<V=S='(@(DIA=6YA<R!VYW-T=6QE<R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R
M(")*875N87,@=N=S='5L97,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3,S"FUS9VED(").97AT(@IM<V=S='(@(D[B:V%M86ES(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHS,PIM
M<V=I9"`B3F5X="!-97-S86=E(@IM<V=S='(@(D[B:V%MXB!VYW-T=6QE(@H*
M(SH@;6%I;&)O>"YP:'`Z,S4V"FUS9VED(").97AT(%!A9V4B"FUS9W-T<B`B
M3N)K86WB(&QA<&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW-PIM<V=I9"`B3F\B"FUS
M9W-T<B`B3N<B"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED(").;R!#97)T:69I
M8V%T92!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Y"FUS9VED(").;R!+
M97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S<U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*;7-G
M<W1R(")*875N87,@=N=S='5L97,B"@HC.B!P9W`N<&AP.C$S-PIM<V=I9"`B
M3F\@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L
M($-E<G1I9FEC871E(%!R97-E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QB
M;W@N<&AP.C,R.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT(@IM
M<V=S='(@(DEZ;&%B;W1S('1E:W-T<R(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,34*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S
M='(@(B(*"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L
M:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O=&YE9BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DYO(&%T=&%C:&UE;G1S
M(&9O=6YD+B(*;7-G<W1R(")0:65L:6MU;6DB"@HC.B!L:6(O0W)Y<'0O4TU)
M344N<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I;VX@;&]C871E
M9"!I;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HW
M,B!A8VPN<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97(@<V5L96-T
M960N(@IM<V=S='(@(FYA=B!I>G;G;.=T82!M87!E(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C$T,0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@
M8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C(Q."!L:6(O1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P
M"FUS9VED(").;R!F;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(DYA
M=B!N;W+B9.YT87,@;6%P97,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,30W"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@;F5W(&UE<W-A
M9V5S(@IM<V=S='(@(DYA=B!I>F1ZYW-T87,@=N=S='5L97,B"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,30T"B,L(&9U>GIY"FUS9VED(").;R!F;VQD
M97)S('=I=&@@=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(DYA=B!I>F1ZYW-T
M87,@=N=S='5L97,B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(U"B,L(&9U>GIY
M"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R(")PXG)V:65T
M;W0@=N=S='5L:2!U>B(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS-S$*(RP@9G5Z
M>GD*;7-G:60@(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N(@IM
M<V=S='(@(DYE=FEE;F$@=N=S='5L92!N96%T8FEL<W0@;65K;.?P86YA<R!N
M;W-A8^YJ=6UI96TB"@HC.B!P9W`N<&AP.C$X.0IM<V=I9"`B3F\@<&5R<V]N
M86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!P
M9W`N<&AP.C$V-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@
M:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR,#$*;7-G:60@
M(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP;W)T960N(@IM
M<V=S='(@(B(*"B,Z('-P96QL:6YG+G!H<#HR,C`*;7-G:60@(DYO('-P96QL
M8VAE8VMI;F<@<')O9W)A;2!C;VYF:6=U<F5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G:60@(DYO('-P
M96QL:6YG(&5R<F]R<R(*;7-G<W1R(")+[_MD=2!N878B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`P"FUS9VED(").;R!S=6=G97-T
M:6]N<R(*;7-G<W1R("))971E:6MU;74@;F%V(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HU-C0*;7-G:60@(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M86-L+G!H<#HV."!A8VPN<&AP.CDT"B,L(&9U>GIY"FUS9VED(").;R!U<V5R
M('-P96-I9FEE9"XB"FUS9W-T<B`B3F%V(&YO<N)D[G1A<R!M87!E<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#D*;7-G:60@(DYO;B!087)T
M:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$Q('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z
M-#`*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S4@=&5M
M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(DYO;F4B"FUS9W-T<B`B3F5V:65N
M<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-0IM<V=I
M9"`B3F]R;6%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS.0IM
M<V=I9"`B3F]T($1E;&5T960B"FUS9W-T<B`B3F%V(&EZ9'KG<W1S(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(S"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z-#(*;7-G:60@(DYO="!$<F%F="(*;7-G<W1R(").
M878@;65L;G)A:W-T<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$W
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@(DYO
M="!);7!O<G1A;G0B"FUS9W-T<B`B3F%V('-V87+N9W,B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS9VED(").;W0@4&5R<V]N86PB
M"FUS9W-T<B`B3F%V('!E<G-O;FES:W,B"@HC.B!L:6(O0W)Y<'0O4$=0+G!H
M<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@;&EB+T-R>7!T+U--24U%
M+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A;&ED('!U8FQI8R!K97DN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-C<*;7-G:60@
M(DYO="!D96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(DYA=B!I>F1ZYW-T87,@
M=N=S='5L97,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS
M9VED(").;W0@:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(DYA=B!S=F%R
M[F=A<R!VYW-T=6QE<R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H
M;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T
M86ME('-O;64@=&EM92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C$V"B,L(&9U>GIY"FUS9VED(").;W1H:6YG(@IM<V=S='(@(D-I
M=.=J=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*(RP@9G5Z>GD*
M;7-G:60@(DYU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T
M=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(E-A
M9VQA8N)J86UO(&YO<_MT[G1O(';G<W1U[W4@;6%P:G4@<VMA:71S+"!J82!T
MXG,@:6L@;>=N97-I('1I96L@9'KG<W1A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-3D*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!O;&0@<V5N
M="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+B(*
M;7-G<W1R("(B"B)386=L86+B:F%M;R!N;W/[=.YT;R!VYW-T=>]U(&UA<&IU
M('-K86ET<RP@:F$@=.)S(&EK(&WG;F5S:2!T:65K(&1ZYW-T87,B"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-"!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW,S,*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN
M:6YC.C0Y"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-#@*;7-G
M:60@(D]2(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,34*;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R(")696/B<R!VYW-T
M=6QE<R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I
M;%]M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S
M(&)E:6YG('!U<F=E9"XB"FUS9W-T<B`B5&EE:R!T[G+N=&%S('9E8^)S(&YO
M<_MT[G1O(';G<W1U[W4@;6%P97,N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C(U"FUS9VED(")/;FQY(&1I<W!L87D@9F]L9&5R<R!W:71H('5N<F5A
M9"!M97-S86=E<R!I;B!T:&5M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"B,L(&9U>GIY"FUS9VED(")/;FQY
M(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO
M;BXB"FUS9W-T<B`B3/MD>G4@:7IVYVQI971I97,@=&EK86D@=FEE;G4@;6%P
M:2#P86D@;W!E<N)C:6IA:2XB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,3`@
M=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")/<&5N($9O
M7VQD97(B"FUS9W-T<B`B071VYW)T(&UA<&DB"@HC.B!F;VQD97)S+G!H<#HT
M,C<*(RP@9G5Z>GD*;7-G:60@(D]P96YE9"!&;VQD97(B"FUS9W-T<B`B071V
MYW)T(&UA<&DB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`U"FUS
M9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!F971C
M:&UA:6PN<&AP.C,S('1E;7!L871E<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHV"B,L(&9U>GIY
M"FUS9VED(")/=&AE<B!-86EL($%C8V]U;G1S(@IM<V=S='(@(D-I=&%S(&]P
M8VEJ87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,`IM<V=I9"`B
M3W1H97(@3W!T:6]N<R(*;7-G<W1R(")#:71A<R!O<&-I:F%S(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#$*;7-G:60@(D]U=&)O=6YD(%-E
M<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N
M:6YC.C$V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,CDP"FUS9VED(")01U`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHW"B,L(&9U>GIY"FUS9VED(")01U`@16YC
M<GEP="!-97-S86=E(@IM<V=S='(@(D%T8V5L="!VYW-T=6QI(@H*(SH@8V]M
M<&]S92YP:'`Z,S4X"B,L(&9U>GIY"FUS9VED(")01U`@17)R;W(Z("(*;7-G
M<W1R(")+[_MD82(*"B,Z(&-O;7!O<V4N<&AP.C,S-PIM<V=I9"`B4$=0($5R
M<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"B,L
M(&9U>GIY"FUS9VED(")01U`@3W!T:6]N<R(*;7-G<W1R(")/<&-I:F%S(@H*
M(SH@<&=P+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A<V4@26YP=70B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4U"FUS9VED(")0
M1U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HQ-S,*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E>'0B"FUS
M9W-T<B`B(@H*(SH@<&=P+G!H<#HQ-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S("@E<RE<(B!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")-87!E(%PB)7-<(B!V96EK<VWN
M9VD@:7IV96ED;W1A+B(*"B,Z('!G<"YP:'`Z,C0U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S
M=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B36%P92!<(B5S7"(@=F5I
M:W-M[F=I(&EZ9'KG<W1A+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`HC+"!F=7IZ>0IM
M<V=I9"`B4$=0(%-I9VX@365S<V%G92(*;7-G<W1R(")3^W3N="!VYW-T=6QI
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"FUS
M9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M<&=P+G!H<#HR,#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!P<FEV871E(&ME>2!S
M=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E!A<F%K<W1S('9E:6MS;>YG
M:2!A:7IV:65T;W1S+B(*"B,Z('!G<"YP:'`Z,3<W"FUS9VED(")01U`@<'5B
M;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")01U`@<W5P<&]R
M="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`X"FUS9VED("(B"B)01U`@<W5P
M<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S
M:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.34*;7-G:60@(B(*
M(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!M
M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED("(B"B)01U`@<W5P
M<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y
M;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A8FQE('!O
M<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@
M96QS92!T:&4@4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C
M=&QY+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P
M-0IM<V=I9"`B4$]0,R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS
M*2(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q-PIM
M<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS
M:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF
M+7-I9VYE9"DB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`B3&%P82`E9"!N;R`E9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#,*;7-G:60@(E!A9V4@=VET:"!T
M:&4@1FER<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H('1H92!,87-T
M(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VAE861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S='(@(D1A
M[V$H<RDB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS9VED(")0
M87-S<&AR87-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R("(B"@HC
M.B!S;6EM92YP:'`Z,C,U('!G<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")0
M87-S<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`B5N=S
M='5L92!N;W/[=.YT82!V96EK<VWN9VDL(&)E="!N878@<V%G;&%BXG1A(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$X('1E;7!L871E
M<R]P9W`O<&%S<W!H<F%S92YI;F,Z,CD*;7-G:60@(E!A<W-P:')A<V4Z(@IM
M<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$R"FUS9VED(")087-S<&AR87-E<R!C
M86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$T"FUS
M9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$Y,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQE(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L(&9U>GIY
M"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_(@IM<V=S='(@(E!I97-LYV1Z;W1I97,@:7IP:6QD[G0@=7IT=7+G\&%N
M87,@;W!E<N)C:6IA<R(*"B,Z(&%C;"YP:'`Z-S8@86-L+G!H<#HQ,#(*;7-G
M:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N(&YO="!B92!C:&%N
M9V5D+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HT.3,@;6%I;&)O>"YP
M:'`Z-S`S('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,`IM<V=I9"`B4&5R<V]N86PB
M"FUS9W-T<B`B4&5R<V]N[F=A:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(E!E
M<G-O;NYGXB!I;F9O<FWB8VEJ82(*"B,Z('!G<"YP:'`Z,3(P"FUS9VED(")0
M97)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$R-PIM<V=I9"`B4&5R<V]N86P@4$=0
M(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z('-M
M:6UE+G!H<#HR,#<*;7-G:60@(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T
M97,@3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$S
M,@IM<V=I9"`B4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C(*;7-G:60@(E!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S
M(&%N9"!F;W)W87)D<S\B"FUS9W-T<B`B265V:65T;W0@<&%R86MS='4@<&ER
M;7,@871B:6QDYVT@=6X@<.)R<_MT[O!A;N)M/R(*"B,Z(&-O;7!O<V4N<&AP
M.C(U-`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDY"FUS9VED("(B
M"B)0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@5&AI<R!R97%U:7)E<R!Y;W5R
M(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E9"`B"B)S;W5N9"!F:6QE<RX@
M($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A;F0@36%C+"!B=70@;W1H97(@
M<&QA=&9O<FUS('=I;&P@(@HB<F5Q=6ER92!A('!L=6=I;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"B,L(&9U>GIY"FUS
M9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CHB
M"FUS9W-T<B`B3/MD>G4@:65V861I970@:F%U;N)S(&UA<&5S(&YO<V%U:W5M
M=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P,B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B4&QE
M87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.B(*;7-G<W1R
M("),^V1Z=2!I979A9&EE="!J875NXG,@;6%P97,@;F]S875K=6UU.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,W"FUS9VED(")0
M;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.B(*;7-G<W1R("),^V1Z=2!I979A
M9&EE="!J875N;R!N;W-A=6MU;74Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S
M<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@
M96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y
M+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB96YT97(@=&AI<R!P87-S<&AR
M87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@
M4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@(@HB=&\@
M96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G:60@(B(*(E!L96%S
M92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A
M9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI97,@04Y$('EO=2!A
M<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I;F1O=W,L('EO=2!W
M:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD
M;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C:V5R<R!F<F]M("(*
M(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@
M86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-S$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!P<F]V
M:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S='(@(DS[9'IU(&EE=F%D:65T(&QI
M971O=.)J82!VXG)D=2!U;B!P87)O;&DB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C8W"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE+B(*;7-G<W1R("),^V1Z=2!I979A9&EE="!L:65T;W3B
M:F$@=N)R9'4@=6X@<&%R;VQI(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])
M35`N<&AP.C0U.0IM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R
M(&EN=F%L:60@861D<F5S<V5S+B(*;7-G<W1R("),^V1Z=2!I>FQA8F]J:65T
M(&YE=FEE;FYO>NYM[F=A<R!V86D@;F5D97+N9V%S(&%D<F5S97,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8T,@IM<V=I9"`B(@HB4&QE87-E
M(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S
M96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C$*
M;7-G:60@(E!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F
M;W)M(&%N>2!A8W1I;VYS+B(*;7-G<W1R("),^V1Z=2!I>G;G;&EE=&EE<R!K
MXF1U(&UA<&D@<&ER;7,@=F5I:W0@9&%R8NYB87,@87(@=&\N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4P,@HC+"!F=7IZ>0IM<V=I9"`B4&QE
M87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS
M9W-T<B`B3/MD>G4@:7IVYVQI971I97,@;65K;.?P86YA:2!V:7-M87H@=FEE
M;G4@;6%P:2XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC
M.C0Q"FUS9VED(")0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@
M=&\@<V5A<F-H+B(*;7-G<W1R("),^V1Z=2!I>G;G;&EE=&EE<R!M96MLY_!A
M;F%I('9I<VUA>B!V:65N=2!M87!I+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O
M;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B3/MD>G4@
M:7IVYVQI971I97,@=&EK86D@=FEE;G4@;6%P:2#P86D@;W!E<N)C:6IA:2XB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-S,*(RP@9G5Z
M>GD*;7-G:60@(E!L96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O
M('1H92!R:6=H=#HB"FUS9W-T<B`B3/MD>G4@:65Z[FWG:FEE="!V86D@<F5D
M:>SG:FEE="!NXFMA;6\Z(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*
M;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q-`HC+"!F=7IZ>0IM<V=I9"`B4')E8V5D92!Y
M;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R(")3
MXFMT(&K[<W4@<&%R86MS='4@87(@*"<M+2`G*2(*"B,Z('-M:6UE+G!H<#HR
M-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"B,L(&9U>GIY"FUS
M9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T
M<B`B36%P92!<(B5S7"(@=F5I:W-M[F=I(&EZ=F5I9&]T82XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PHC+"!F=7IZ>0IM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R("))97!R:65K\.=JXB!L87!A(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR.`IM<V=I9"`B
M4')E=FEO=7,@365S<V%G92(*;7-G<W1R("))97!R:65K\.=JXB!VYW-T=6QE
M(@H*(SH@;6%I;&)O>"YP:'`Z,S0W"FUS9VED(")0<F5V:6]U<R!086=E(@IM
M<V=S='(@(DEE<')I96OPYVKB(&QA<&$B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@
M(D1R=6OB="(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X
M"B,L(&9U>GIY"FUS9VED(")0<FEO<FET>2(*;7-G<W1R(")$<G5KXG0B"@HC
M.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S8*;7-G:60@(E!R
M:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T
M=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X"FUS9VED(")0<F]M<'0@979E
M<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM<V=S='(@(B(*"B,Z(&QI8B]#<GEP
M="]01U`N<&AP.C0R.0IM<V=I9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P
M<&]R="!H87,@8F5E;B!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<U]D96QE=&5D+FEN8SHX"B,L(&9U>GIY"FUS9VED(")0=7)?9V4@
M1&5L971E9"(*;7-G<W1R("))>G3N<NYT(&EZ9'KG<W1O<R(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G-?9&5L971E9"YI;F,Z.`IM<V=I9"`B4'5R9V4@1&5L971E9"(*
M;7-G<W1R("))>G3N<NYT(&EZ9'KG<W1O<R(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")0=7)G92!&;VQD
M97(H<RDB"FUS9W-T<B`B1'KG<W0@;6%P:2@M97,I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N
M.B(*;7-G<W1R(")#:6L@8FEE_FD@=.YR[G0@871K<FET=6UU<SHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`U"B,L(&9U>GIY"FUS9VED(")0=7)G
M92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M
M;W5N="!O9B!D87ES+B(*;7-G<W1R(")4[G+N="!VYW-T=6QE<R!N;R!A=&MR
M:71U;74@;6%P97,L(&IA('3B<R!V96/B:V%S('!A<B#P;R!D:65N=2!S:V%I
M='4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"B,L(&9U>GIY"FUS
M9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B
M"FUS9W-T<B`B27IT[G+N="!V96/B<R!VYW-T=6QE<R!N;R!A=&MR:71U;74@
M;6%P97,B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!U<F=I;F<@)60@
M;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(E3N<F$@)60@
M=N=S='5L97,@;F\@871K<FET=6UU(&UA<&5S+B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B
M4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@
M(E3N<F$@)60@=N=S='5L97,@;F\@871K<FET=6UU(&UA<&5S+B(*"B,Z('1E
M;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,
M24U)5"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC
M.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@3D\@3$E-
M250B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T
M<B`B0VETYVIU(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,S@V"FUS9VED(")295]Q=65S="!$96QI=F5R>2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@
M(E)E8V5I=F5D($]N(@IM<V=S='(@(E-A\F5M=',B"@HC.B!L:6(O4V5A<F-H
M+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T
M<B`B4V'R96UT<R(*"B,Z(&QI8B]396%R8V@N<&AP.C4T"B,L(&9U>GIY"FUS
M9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R(")38?)E;71S(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"B,L(&9U>GIY
M"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B4.)R861R97/G="(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B
M4F5D:7)E8W0B"FUS9W-T<B`B4.)R861R97/G="(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E9&ER96-T($UE<W-A
M9V4B"FUS9W-T<B`B4.)R861R97/G="!VYW-T=6QI(@H*(SH@8V]M<&]S92YP
M:'`Z-S@W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B
M4.)R861R97/G="#P;R!VYW-T=6QI(@H*(SH@8V]M<&]S92YP:'`Z.#0W"FUS
M9VED(")2961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(E#B<F%D<F5SYW0@
M;F5I>F1E=N)S+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4X,PIM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")!=&IA=6YO="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E<V@@1F]L9&5R
M(%9I97=S.B(*;7-G<W1R(")!=&IA=6YO="!M87!J=2!S:V%T[FIU;75S.B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHT"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS
M9W-T<B`B4.)R;.)DYW0@<VMA=.YJ=6UU(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I97<B"FUS9W-T<B`B4.)R
M;.)DYW0@<VMA=.YJ=6UU(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4R-B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30U"FUS9VED(")296UE
M;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<Y"FUS9VED(")296UE;6)E<B!T
M:&4@;&%S="!V:65W(@IM<V=S='(@(D%T8V5RYW1I97,@<.=DYVIO('-K873N
M:G5M=2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PHC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(E!A<W1K
M87-T92(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I
M9"`B4F5M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R(")I>F1ZYW-T(&%V;W1U(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM
M<V=I9"`B4F5N86UE($9O;&1E<BAS*2(*;7-G<W1R(")0XG)S875K="!M87!I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I
M9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO
M;G1H/R(*;7-G<W1R(")0XG)S875K="!S96YT+6UA:6P@;6%P:2!MYVYE\&$@
M<^)K=6WB(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#4U"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E;F%M:6YG(%PB)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(DYE:7ID97;B<R!P
MXG)S875K="!N;R!<(B5S7"(@=7H@7"(E<UPB+B#0XF1A(&)I:F$@<V5R=F5R
M82!A=&)I;&1E+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS
M9W-T<B`B071B:6QDYW0@=FES:65M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G<W1R
M(")!:7IS=.)T(&%R.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHX"FUS9VED(")297!L>2(*;7-G<W1R(")!=&)I;&3G="(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0P.0HC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@4V5N="XB
M"FUS9W-T<B`B4F5P;'DM=&\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R
M(")!=&)I;&3G="!V:7-I96TB"@HC.B!C;VUP;W-E+G!H<#HW,S,*;7-G:60@
M(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B071B:6QDYW0@=FES:65M.B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F
M=7IZ>0IM<V=I9"`B4F5P;'D@=&\@3&ES="(*;7-G<W1R(")!=&)I;&3G="!V
M:7-I96TB"@HC.B!C;VUP;W-E+G!H<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E)E
M<&QY('1O($QI<W0Z(@IM<V=S='(@(D%T8FEL9.=T('9I<VEE;3HB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*(RP@9G5Z
M>GD*;7-G:60@(E)E<&QY('1O(%]!;&PB"FUS9W-T<B`B071B:6QDYW0@=FES
M:65M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3,W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU-#<*;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S
M86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,S4*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N
M=&AS+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3,T"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-PHC+"!F
M=7IZ>0IM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`B4F5P;'DM5&\Z("(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT,#D*;7-G:60@(E)E<&QY+51O.B`B"FUS9W-T
M<B`B4F5P;'DM5&\Z("(*"B,Z(&-O;7!O<V4N<&AP.C<S,0IM<V=I9"`B4F5P
M;'DZ(@IM<V=S='(@(D%T8FEL9.=T.B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT
M(@IM<V=S='(@(E!I971E:6MT(&OB('-P86UU(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,U('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C(S"FUS9VED(")297!O<G0@87,@4W!A;2(*;7-G<W1R
M(")0:65T96EK="!KXB!S<&%M=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,X,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!A(%]296%D
M(%)E8V5I<'0B"FUS9W-T<B`B4&EE<')A<^YT(&%T<VMA:71I('!A<B!S8?)E
M;?!A;G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@U"FUS9VED(")2
M97%U97-T(&1E;&EV97)Y(&-O;F9I<FUA=&EO;C\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q
M=65S="!R96%D(')E8V5I<'1S/R(*;7-G<W1R(")0:65P<F%S[G0@871S:V%I
M=&D@<&%R('-A\F5M\&%N=2(*"B,Z(&UA:6QB;W@N<&AP.C$X.0IM<V=I9"`B
M4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDW"FUS9VED(")297%U:7)E9"!0
M87)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$T,R!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,0IM<V=I9"`B4F5S970B"FUS9W-T
M<B`B1'KG<W0@=FES=7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3$U"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R(")4=7)P:6[B="(*"B,Z(')E8V]M
M<&]S92YP:'`Z.3@*;7-G:60@(E)E<W5M92!Y;W5R('-E<W-I;VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0T"B,L
M(&9U>GIY"FUS9VED(")2971U<FX@=&\@7")-97-S86=E($-O;7!O<VET:6]N
M7"(B"FUS9W-T<B`B5N=S='5L97,@<F%K<W3N\&%N82(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,S$@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C8Y"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M86-C;W5N=%]S96QE8W0N:6YC.C,R"FUS9VED(")2971U<FX@=&\@1F5T8V@@
M36%I;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHR,@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP;&%T97,O<VUI;64O
M;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30Y
M('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,38R('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S,*(RP@
M9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(DQI971O
M=.)J82!O<&-I:F%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q.`IM
M<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@
M9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S
M='(@(B(*(D%T9W)I97IT:65S('!I92!VYW-T=>]U('-A<F%K<W1A('#G8R!V
MYW-T=6QE<R!I>F1ZY_!A;F%S+"!PXG)V:65T;_!A;F%S('9A:2`B"B)N;VMO
M<.?P86YA<S\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS
M9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS9VED(")3+TU)344B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN
M8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HS.30*;7-G:60@(E,O34E-12!%<G)O<CH@(@IM
M<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C,W,PIM<V=I9"`B4R]-24U%($5R
M<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"B,L
M(&9U>GIY"FUS9VED(")3+TU)344@3W!T:6]N<R(*;7-G<W1R(")/<&-I:F%S
M(@H*(SH@<VUI;64N<&AP.C0Y"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!)
M;G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C4T"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E
M<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC
M.B!S;6EM92YP:'`Z,30P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M+TU)344@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@
M9&5L971E9"XB"FUS9W-T<B`B36%P92!<(B5S7"(@=F5I:W-M[F=I(&EZ9'KG
M<W1A+B(*"B,Z('-M:6UE+G!H<#HQ-C(*;7-G:60@(E,O34E-12!0=6)L:6,@
M2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+
M97ER:6YG(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR,3$*;7-G:60@(E,O
M34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L
M:7-T+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%(%-I9VX@365S<V%G
M92(*;7-G<W1R(")3^W3N="!VYW-T=6QI(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHQ-`IM<V=I9"`B4R]-24U%(%-I9VXO16YC
M<GEP="!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]N
M;W1A8W1I=F4N:6YC.C0*;7-G:60@(E,O34E-12!S=7!P;W)T(&ES(&1I<V%B
M;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@
M:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N
M86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<S"FUS9VED("(B"B)3+TU)344@<W5P
M<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S
M:6=N960@;65S<V%G92!C86X@;F]T("(*(F)E(&1I<W!L87EE9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*;7-G:60@
M(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I
M=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@IM<V=I
M9"`B(@HB4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T
M;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES("(*(F-U<G)E;G1L>2!S
M970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@
M=&AI<R!S971T:6YG(&]R(&5L<V4@(@HB=&AE(%,O34E-12!F96%T=7)E<R!W
M:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#4*;7-G:60@(E--5%`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4U"B,L(&9U
M>GIY"FUS9VED(")37W5B:F5C="(*;7-G<W1R(")496UA=',B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-C,*(RP@9G5Z>GD*;7-G:60@
M(E-A7W9E(&$@8V]P>2!I;B`B"FUS9W-T<B`B4V%G;&%BXG0@:V]P:6IU("(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@HC
M+"!F=7IZ>0IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B4V%G;&%BXG0@:^(B
M"@HC.B!S96%R8V@N<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`B4V%G;&%B
MXG0@:^(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S@*
M;7-G:60@(E-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M
M;6%I;"!F;VQD97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0S,PIM<V=I9"`B4V%V92!$<F%F="(*;7-G<W1R(")386=L86+B="!M96QN
M<F%K<W1U(@H*(SH@<V%V96EM86=E+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B
M4V%V92!);6%G92(*;7-G<W1R(")386=L86+B="!KXB(*"B,Z(&QI8B]-24U%
M+T-O;G1E;G1S+G!H<#HR,#0*;7-G:60@(E-A=F4@26UA9V4@:6X@1V%L;&5R
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M-3D@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#`*(SH@=&5M<&QA=&5S
M+W-M:6UE+VYO=&%C=&EV92YI;F,Z,3(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$T.`HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,3,*(RP@9G5Z
M>GD*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("),:65T;W3B:F$@;W!C
M:6IA<R(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,`IM
M<V=I9"`B4V%V92!3=&%T:6]N97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0S,PHC+"!F=7IZ>0IM<V=I9"`B4V%V92!?1')A9G0B"FUS
M9W-T<B`B4V%G;&%BXG0@;65L;G)A:W-T=2(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%V92!A<R(*;7-G
M<W1R(")386=L86+B="!KXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-S(*;7-G:60@(E-A=F4@<F5C
M:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@
M8F]O:S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHQ,C<*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*(RP@
M9G5Z>GD*;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R(")386=L86+B
M="!N;W/[=.YT;R!P87-T=2(*"B,Z(&-O;7!O<V4N<&AP.C$R,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DYE:7ID97;B
M<R!S86=L86+B="!M96QN<F%K<W1U+B#0XF1A(&)I:F$@<V5R=F5R82!A=&)I
M;&1E.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,3DY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L
M;V-K+W1R965?9F]L9&5R<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R
M(")-96MLY_!A;F$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z
M,3@@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S(@IM<V=S='(@(DUE:VSG\&%N
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C`*(RP@9G5Z>GD*;7-G
M:60@(E-E87)C:"!/<'1I;VYS(@IM<V=S='(@(DQI971O=.)J82!O<&-I:F%S
M(@H*(SH@<V5A<F-H+G!H<#HR-C4*;7-G:60@(E-E87)C:"!297-U;'1S(@IM
M<V=S='(@(DUE:VSG\&%N87,@<F5Z=6QTXG1I(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,Q"FUS9VED(")3965N(@IM<V=S='(@(E)E9'KG=',B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*;7-G:60@(E-E;&5C="(*;7-G
M<W1R("))>G;G;&EE<R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHW,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N
M="(*;7-G<W1R(").96EZ=N=LYW1I97,@;F5K;R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O9FEE;&1S+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@
M9&%T92(*;7-G<W1R("))>G;G;&EE<R!I9&5N=&ETXG1I(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]F:65L9',N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!F:65L9"(*;7-G<W1R("))97KN;>=T('9I<W5S(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$W"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@82!S=&%T:6]N97)Y.B(*;7-G<W1R(").96EZ=N=LYW1I97,@;F5K
M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N
M9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`B27IVYVQI97,@
M861R97-U(&=RXFUA='4@879O='5S(&%D<F5S=2!P:65V:65N;_!A;F%I('5N
M(&UE:VSG\&%N86DN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX
M.`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("))97KN;>=T('9I<W5S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(S"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@86QL(&9I96QD<R!T;R!S96%R8V@@=VAE;B!E
M>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("))>G;G;&%T:65S(&OB<G3N
M8G4L(&OB9.(@<.)R8F%U9.YT(&%D<F5S=2!G<N)M871A<RXB"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B3F5I>G;G;.=T
M:65S(&YE:V\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@Y"FUS
M9VED(")396QE8W0@;F]N92(*;7-G<W1R(").96EZ=N=LYW1I97,@;F5K;R(*
M"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS9VED
M(")396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C
M="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS,#D*(RP@9G5Z>GD*;7-G:60@(E-E;&5C=&5D($%D9')E<W,@8F]O:W,Z
M(@IM<V=S='(@(DEZ=N=LYW3B<R!A9')E<W4@9W+B;6%T87,Z(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")396YD($ME>2!T;R!0=6)L
M:6,@2V5Y<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,#0*(RP@9G5Z>GD*;7-G:60@(E-E;F0@3&%T97-T($EN9F]R
M;6%T:6]N(@IM<V=S='(@(E-E<G9E<F$@:6YF;W)MXF-I:F$B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,S$*;7-G:60@(E-E;F0@365S<V%G92(*;7-G<W1R
M(")3^W3N="!VYW-T=6QI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P
M,PIM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T960@8GD@
M=&AE('-E;F1E<C\B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,SDW"B,L
M(&9U>GIY"FUS9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(DYO<_MT
M[G1O(';G<W1U[W4@;6%P93HB"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA
M:6QS96QE8W0N:6YC.C,X"FUS9VED(")396YT(&UA:6P@9F]L9&5R.B(*;7-G
M<W1R(").;W/[=.YT;R!VYW-T=>]U(&UA<&4Z(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ,S(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M-#8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-3,*;7-G:60@(E-E
M<G9E<B(*;7-G<W1R(")397)V97)I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,PHC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF
M;W)M871I;VXB"FUS9W-T<B`B4V5R=F5R82!I;F9O<FWB8VEJ82(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5R=F5R.B(*;7-G<W1R(")397)V97)I<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,`IM<V=I9"`B4V5T('!R969E<F5N8V5S(&9O<B!W:&%T
M(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+B(*
M;7-G<W1R("))97-TXF3N="!K;R!D87+N="!K860@:7ID>N?P('9A:2!PXG)V
M:65T;R!VYW-T=6QI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,CD*
M;7-G:60@(E-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I
M;F<@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,0HC+"!F=7IZ>0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G<W1R
M(")-87!E<R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@HC+"!F=7IZ
M>0IM<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(DYO<_MT[G1O
M(';G<W1U[W4@;6%P93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*
M;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E
M<G,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*
M;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@
M8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T
M;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T
M:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R
M(%!'4"!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$S"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L
M;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`B5F%I(';G<W1U
M;&5S(')E9&GLY_!A;F%S(&QO9W,@:N)A:7IV97(@<.=C(&UE;&YR86MS=&$@
M<V%G;&%BXO!A;F%S/R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHT"FUS
M9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B92!A='1A8VAE
M9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`B06EZ=N=R="!V:7-A<R!M87!E
M<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8W"FUS9VED
M(")3:&]W($%L;"!(96%D97)S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP
M.C,V-0IM<V=I9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(E!A<N)D[G0@:7ID
M>N=S=&]S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*
M;7-G:60@(E-H;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P"B,L(&9U>GIY"FUS9VED
M(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R(")097)S
M;V[N9^(@:6YF;W)MXF-I:F$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.CDR"B,L(&9U>GIY"FUS9VED(")3:&]W($]N;'D@4W5B<V-R:6)E9"!&
M;VQD97)S(@IM<V=S='(@(E!A<F%K<W3N=&EE<R!U>B!M87!I*"WG;2DB"@HC
M.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D(@IM
M<V=S='(@(E!A<N)D[G0@;F5P87)A:W-T[G1O<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV,#@*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S
M=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,#(*(RP@9G5Z>GD*
M;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S
M='(@(E+B9.YT('!A<VMA:61R;VIU;75S('!A<W1K87-T97,@<VMA=.YJ=6WB
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#`*;7-G:60@(E-H;W<@
M<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('!R
M979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#<W"FUS9VED(")3:&]W('1H92!&971C:"!-86EL(&EC
M;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU-`IM<V=I
M9"`B4VAO=R!T:&4@9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR.`IM<V=I9"`B4VAO
M=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8V"FUS9VED(")3:&]W;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")3:5]Z92(*;7-G<W1R("))>FWG
M<G,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$W"B,L(&9U
M>GIY"FUS9VED(")3:6=N960B"FUS9W-T<B`B27IMYW)S(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS
M9W-T<B`B27IMYW)S(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHQ,0IM<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,38*;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(V"B,L(&9U>GIY"FUS
M9VED(")3;W)T(&)Y($9R;VT@061D<F5S<R(*;7-G<W1R(")3^W3N=.)J82!A
M9')E<V4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C0Q"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($UE<W-A9V4@4VEZ92(*
M;7-G<W1R(")6YW-T=6QE<R!I>FWG<G,B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C,V"B,L(&9U>GIY"FUS9VED(")3;W)T
M(&)Y(%-U8FIE8W0B"FUS9W-T<B`B0F5Z('9I<G-R86MS=&$B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"B,L(&9U>GIY
M"FUS9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R(")0879E9&EE;G,B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q"B,L
M(&9U>GIY"FUS9VED(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`B4_MT
M[G3B:F$@861R97-E(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N
M:6YC.C(S"B,L(&9U>GIY"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`B
M071K<FET=6UU(&UA<&4Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S0V"FUS9VED(")3<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T<B`B
MSG!A\&EE('-I;6)O;&DB"@HC.B!S96%R8V@N<&AP.C$S,PIM<V=I9"`B4W!E
M8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N(&YO="!B92!E9&ET960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T,PIM
M<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`B4&%R96EZ<F%K<W3N8F%S('#B
M<F)A=61E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V
M"FUS9VED(")3<&5L;"!#:&5C:V5R(@IM<V=S='(@(E!A<F5I>G)A:W-T[F)A
M<R!PXG)B875D[G3B:G,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-#@@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS
M9VED(")3<&5L;"!C:&5C:R!C;VUP;&5T92(*;7-G<W1R(")087)E:7IR86MS
M=.YB87,@<.)R8F%U9&4@<&%B96EG=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#<Q"FUS9VED(")3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W
M:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R("(B"B)087)E:7IR86MS=.YB
M87,@:^_[9'4@<VMA:71S('9I96[B(&5K<N)NXBP@=F5I8V]T('!A<F5I>G)A
M:W-T[F)A<R!PXG)B875D:2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3$R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3(*;7-G:60@(E-T
M87)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q,0IM<V=I
M9"`B4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@;F%M93HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(X
M"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R
M>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X
M.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+T-O;G1E
M;G1S+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B
M"FUS9W-T<B`B4&EE;&EK=6US(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@S,@IM<V=I9"`B4W1R:7`@;&EN96)R96%K<S\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-PHC+"!F
M=7IZ>0IM<V=I9"`B4W5B7VIE8W0B"FUS9W-T<B`B5&5M871S(@H*(SH@;65S
M<V%G92YP:'`Z,C8X('1H<F5A9"YP:'`Z,34P('1E;7!L871E<R]C;VUP;W-E
M+W)E8V]M<&]S92YI;F,Z,C4*(SH@;&EB+U-E87)C:"YP:'`Z,S@*;7-G:60@
M(E-U8FIE8W0B"FUS9W-T<B`B5&5M871S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDR,`IM<V=I9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R(")496UA
M=&$@;&%U:W,B"@HC.B!S96%R8V@N<&AP.C,Q."!T96UP;&%T97,O<V%V96EM
M86=E+W-A=F5I;6%G92YI;F,Z,3@*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P
M:')A<V4N:6YC.C(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S$*
M(RP@9G5Z>GD*;7-G:60@(E-U8FUI="(*;7-G<W1R(")496UA=',B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B4W5B<V-R
M:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R(")087)A:W-T[G1I97,@=7H@;6%P
M:2@MYVTI(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#`@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C@W"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E9E:6MS;64B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@
M(E-U9V=E<W1I;VYS(@IM<V=S='(@(DEE=&5I:W5M:2(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-C(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8V-`IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#`S"FUS9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0P-`IM<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I;VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS
M9VED(")3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,3D*(RP@
M9G5Z>GD*;7-G:60@(E1E7WAT(@IM<V=S='(@(E1E:W-T<R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HR-CD*;7-G:60@(E1E;G1A=&EV93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G
M:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV
M96QY($%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N
M<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R(")496MS=',B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN
M(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3,R"FUS9VED("(B"B)4:&4@24U!
M4"!S97)V97(@9&]E<R!N;W0@87!P96%R('1O('-U<'!O<G0@=&AE(&%U=&AE
M;G1I8V%T:6]N(&UE=&AO9"`B"B)S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@
M>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0IM<V=I9"`B5&AE($UA
M8VEN=&]S:"!R97-O=7)C92!F;W)K(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A
M9&5D("5S+B(*;7-G<W1R("(B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ETXG1E(%PB)7-<
M(B!V96EK<VWN9VD@:7ID>N=S=&$N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP
M.C<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<
M(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(DED96YT:73B=&4@7"(E
M<UPB('-A9VQA8N)T82XB"@HC.B!A='1A8VAM96YT+G!H<#HT,PIM<V=I9"`B
M5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y"FUS9VED(")4:&4@8V%L96YD
M87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V]M<&]S95]W:6XN:G,Z,S<*;7-G:60@(B(*(E1H
M92!C;VUP;W-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U
M(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD
M;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B
M;&4N<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S
M:"!F:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C@W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!C=7)R96YT(&9O;&1E<BAS*2!<(B5S7"(@
M=VEL;"!B92!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B5&5K;_#B(&UA
M<&4H<RD@7"(E<UPB('1I:W,@<.)R<V%U:W1A('!A<B!<(B5S7"(N(@H*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E
M;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C
M;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N
M<&AP.C$R,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B
M965N('-A=F5D('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3,Y"FUS9VED(")4:&4@979E
M;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I96QD(%PB)7-<(B!C86XG="!B92!E>'!A
M;F1E9"XB"FUS9W-T<B`B261E;G1I=.)T92!<(B5S7"(@=F5I:W-M[F=I(&EZ
M9'KG<W1A+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!A;')E861Y(&5X:7-T<R(*;7-G
M<W1R(")-87!E(%PB)7-<(B!J874@96MS:7-TYR(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@9F]L9&5R(%PB
M)7-<(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N
M($ET(&UA>2!C875S92`B"B)P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-87!E<R!<(B5S7"(@
M;F]S875K=6US('-A='5R(&YE873O875T=7,@<VEM8F]L=7,N($S[9'IU('-A
M>FEN:65T:65S(&%R("(*(F%D;6EN:7-T<F%T;W)U+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@
M=&\@:70N(@IM<V=S='(@(DUA<&4@7"(E<UPB('1I:V$@:7IV96ED;W1A(&)E
M="!J^W,@=7H@=&\@;F5E<V%T('!A<F%K<W3N:FEE<RXB"@HC.B!L:6(O1F]L
M9&5R+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<
M(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB
M960@9G)O;2!I="XB"FUS9W-T<B`B36%P92!<(B5S7"(@=&EK82!I>F1ZYW-T
M82P@8F5T(&K[<R!N965S870@;F\@=.)S(&%T<F%K<W3N:FEE<RXB"@HC.B!L
M:6(O1F]L9&5R+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O
M;&1E<B!<(B5S7"(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED(@IM<V=S='(@(DUA<&D@7"(E<UPB(&YE:7ID97;B<R!I
M>G9E:61O="X@4V5R=F5R82!A=&)I;&1E(&)I:F$@\.)D82XB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(DUA<&D@7"(E<UPB(&YE:7ID97;B<R!I>F1Z
MYW-T+B!397)V97)A(&%T8FEL9&4@8FEJXB#PXF1A(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z,S4Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E
M<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B36%P92!<
M(B5S7"(@=F5I:W-M[F=I(&EZ=F5I9&]T82XB"@HC.B!L:6(O1F]L9&5R+G!H
M<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@
M=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")-87!E(%PB)7-<
M(B!V96EK<VWN9VD@:7ID>N=S=&$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#4S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S
M=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(DUA<&4@
M7"(E<UPB('9E:6MS;>YG:2!PXG)S875K=&$@<&%R(%PB)7-<(BXB"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I
M;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?<V%V96EM86=E7W=I
M;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N
M;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S
M97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"FUS9VED("(B"B)4:&4@:6UA
M9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P
M<F5S96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I
M;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G
M93HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-3$*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDP"FUS9VED(")4:&4@
M;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93HB
M"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E
M;7!T>2XB"FUS9W-T<B`B36%P92!<(B5S7"(@:F%U(&5K<VES=.<B"@HC.B!L
M:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B>71E<RD@97AC965D
M<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PHC+"!F=7IZ>0IM<V=I9"`B5&AE
M(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET
M:6YG+B(*;7-G<W1R(")2961I[.=J86WB(';G<W1U;&4@=&EK82!A:7IVYW)T
M82X@0F5I9'IU+B(*"B,Z(&UE<W-A9V4N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E
M;G1I=.)T92!<(B5S7"(@=F5I:W-M[F=I(&EZ9'KG<W1A+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B5&AE(&UE
M<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(DED96YT:73B=&4@
M7"(E<UPB('-A9VQA8N)T82XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C,X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!H87,@
M8F5E;B!V97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+V]P96Y?<VUI;65?=VEN+FIS.C$P('1E;7!L871E<R]P
M9W`O;W!E;E]P9W!?=VEN+FIS.C$P"FUS9VED("(B"B)4:&4@<&%S<W!H<F%S
M92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E
M="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI
M8R!+97D@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W1N968N<&AP.C8P"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I
M;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE($U3+51.148@871T86-H;65N="XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G
M:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@
M6FEP(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@
M;65S<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H
M:7,@;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE("(*(FYO
M=&EF:6-A=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HV.0IM<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T
M(&%B;&4@=&\@8W)E871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`T
M"B,L(&9U>GIY"FUS9VED(")4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R
M97!L86-E9"XB"FUS9W-T<B`B4&%R86MS='4@;F5I>F1Z=N)S(&%I>G9I971O
M="XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P,@IM<V=I
M9"`B5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+B(*
M;7-G<W1R(")087)A:W-T<R!V96EK<VWN9VD@86EZ=FEE=&]T<RXB"@HC.B!A
M='1A8VAM96YT+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!S=&%T:6]N97)Y+G!H<#HX
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@
M7"(E<UPB(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R("))9&5N=&ETXG1E(%PB
M)7-<(B!S86=L86+B=&$N(@H*(SH@<W1A=&EO;F5R>2YP:'`Z-C,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ETXG1E(%PB)7-<(B!V
M96EK<VWN9VD@:7ID>N=S=&$N(@H*(SH@<W1A=&EO;F5R>2YP:'`Z.#<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<
M(B!H87,@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("))9&5N=&ETXG1E(%PB)7-<
M(B!V96EK<VWN9VD@:7ID>N=S=&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$V.0IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@
M>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(E1H92!T97AT(&]F('1H
M92!M97-S86=E(@IM<V=S='(@(FEZ9.=S="!VYW-T=6QI(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#`*;7-G
M:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E
M(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")4:&4@
M=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@(E#B<F%D<F5SYW0@
M\&\@=N=S='5L:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN
M<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S
M96YT(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B
M5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U
M;&QY('-T;W)E9"XB"FUS9W-T<B`B4&%R86MS=',@=F5I:W-M[F=I(&%I>G9I
M971O=',N(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX
M-@IM<V=I9"`B5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V5M<'1Y7VUA:6QB;W@N:6YC.C,*;7-G:60@(E1H97)E
M(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N(@IM<V=S='(@(M!A
M:N(@<&%S=&MA<W3G(&YA=B!VYW-T=>]U+B(*"B,Z('1H<F5A9"YP:'`Z,3`Y
M"FUS9VED(")4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U
M;F=I;F<@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B4F%DXG,@<')O8FSG;6$@9'KG\&]T("5S+B#0XF1A(&)I:F$@<V5R=F5R
M82!A=&)I;&1E(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I
M;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B
M4F%DXG,@<')O8FSG;6$@=.YR;W0@<&%S=&MA<W1I+B#0XF1A(&)I:F$@<V5R
M=F5R82!A=&)I;&1E.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,C$*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(E)A9.)S
M('!R;V)LYVUA('3N<F]T('!A<W1K87-T:2X@T.)D82!B:6IA('-E<G9E<F$@
M871B:6QD92(*"B,Z(&QI8B]-97-S86=E+G!H<#HY,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@
M;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@
M=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(E)A9.)S(&OO^V1A(&MO<.=J
M;W0@=N=S='5L97,@=7H@7"(E<UPB+B#0XF1A(&)I:F$@<V5R=F5R82!A=&)I
M;&1E(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Y."!L:6(O365S<V%G92YP:'`Z
M,C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4
M:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(E)A9.)S
M(&OO^V1A(&1ZY_!O="!VYW-T=6QE<R!N;R!M87!E<R!<(B5S7"(N(-#B9&$@
M8FEJ82!S97)V97)A(&%T8FEL9&4B"@HC.B!L:6(O365S<V%G92YP:'`Z,C<U
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R(")2863B<R!K[_MD
M82!D>N?P;W0@=N=S='5L97,@;6%PYR!<(B5S7"(N(-#B9&$@8FEJ82!S97)V
M97)A(&%T8FEL9&4B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I
M;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S
M(@IM<V=S='(@(E)A9.)S(&OO^V1A(&1ZY_!O="!VYW-T=6QE<RX@T.)D82!B
M:6IA('-E<G9E<F$@871B:6QD92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HY.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(E)A
M9.)S(&OO^V1A(&%P<VMA=&]T('!I97!R87/N=&\@=N=S='5L:2XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E<B]E
M;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E)A9.)S(&OO^V1A
M('!A<N)D;W0@\&\@=N=S='5L97,@9&'O=2(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HU-#4@;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@
M=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R
M('-A:60B"FUS9W-T<B`B4F%DXG,@:^_[9&$@:V%R;V=O:F]T(';G<W1U;&5S
M(&UA<.<@7"(E<UPB+B#0XF1A(&)I:F$@<V5R=F5R82!A=&)I;&1E+B(*"B,Z
M(&9O;&1E<G,N<&AP.C$V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RXB"FUS9W-T<B`B4F%D
MXG,@:^_[9&$@<V%G;&%BXFIO="!M96QN<F%K<W1U+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E
M<RXB"FUS9W-T<B`B4F%DXG,@:^_[9&$@87!S:V%T;W0@<&EE<')A<^YT;R!V
MYW-T=6QI+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-C8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R(")2863B<R!K[_MD82!A
M<'-K871O="!P:65P<F%S[G1O(';G<W1U;&DN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$U,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`B4F%DXG,@:^_[9&$@<_MT;W0@
M=N=S='5L:3H@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z.#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I
M;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(E)A9.)S(&OO^V1A('#B
M<G9I971O:F]T(';G<W1U;&5S('5Z(%PB)7-<(BX@T.)D82!B:6IA('-E<G9E
M<F$@871B:6QD92(*"B,Z(&-O;7!O<V4N<&AP.C$R-#0*(RP@9G5Z>GD*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S
M(&$@9')A9G0N(@IM<V=S='(@(E)A9.)S(&OO^V1A('!A<N)D;W0@\&\@=N=S
M='5L97,@9&'O=2(*"B,Z(&-O;7!O<V4N<&AP.C$P,#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@>6]U<B!M97-S
M86=E.B`E<R(*;7-G<W1R(")2863B<R!K[_MD82!S^W1O="!VYW-T=6QI.B`E
M<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")2863B<R!K[_MD82!S^W1O="!V
MYW-T=6QI.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*
M(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!N;R!T97AT(&EN('1H:7,@;65S
M<V%G92!P87)T(@IM<V=S='(@(E)A9.)S(&OO^V1A('!A<N)D;W0@\&\@=N=S
M='5L97,@9&'O=2(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM
M<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I
M;B!I="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.CDP"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M
M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T
M:&ES.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,38V"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T
M;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$P-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$X"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#,@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$U-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<S
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,30*;7-G:60@(E1H:7,@86-T
M:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B5&%S('9A
M<B!P<F%S[G0@9&%U9'H@;&%I:V$N(%9A:2!VYVQA=&EE<R!T=7)P:6[B=#\B
M"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED
M(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3`*;7-G
M:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H
M870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4R\B"B)-24U%+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q-`IM
M<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA
M="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B"B)4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF
M;W)M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G92!I
M<R!U;FMN;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HS,34*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R<F]R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C0P
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,U,`IM<V=I9"`B(@HB5&AI<R!M
M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!0
M1U`@9F]R;6%T("AA8V-O<F1I;F<@=&\@(@HB4D9#(#(P,34I+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B
M5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R
M<F5C="!3+TU)344@9F]R;6%T+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR,#4@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z-#$V
M"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE
M9"!V:6$@4$=0+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C$T,PIM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET
M86QL>2!S:6=N960@=FEA(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ,SD@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR,S@*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T
M960@=FEA(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,C`Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,0IM<V=I
M9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C$Q"FUS9VED(")4:&ES(&UE
M<W-A9V4@=&\B"FUS9W-T<B`BT&\@=N=S='5L:2!U>B(*"B,Z(&%C;"YP:'`Z
M-#8*;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R
M("+0:7,@;&]G<R!JXFEZ<V%U8R!N;R!VYW-T=6QE<R!R961I[.?P86YA<R!L
M;V=A(@H*(SH@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H<F5A
M9"!$:7-P;&%Y(@IM<V=S='(@(E!A<N)D[G0B"@HC.B!T:')E860N<&AP.C<V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C(*;7-G:60@(E1H<F5A9"!6:65W
M(@IM<V=S='(@(E!A=F5D:65N=2!S:V%T[FIU;7,B"@HC.B!M97-S86=E+G!H
M<#HR-C0@;6%I;&)O>"YP:'`Z-C`V('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C8Q
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,3`@;&EB+U-E
M87)C:"YP:'`Z,C8*;7-G:60@(E1O(@IM<V=S='(@(E-A\N=MYVIS(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ.0HC+"!F=7IZ>0IM<V=I9"`B5&\@
M061D<F5S<R(*;7-G<W1R(")3^W3N=.)J82!A9')E<V4B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O('-E
M;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4
M;R!U<V4@82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A
M('9E<G-I;VX@;V8@4$A0(#4N,"XV(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3<W"B,L(&9U
M>GIY"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*;7-G<W1R(")0
M:65L:6MU;6DB"@HC.B!F;VQD97)S+G!H<#HS.#@*(RP@9G5Z>GD*;7-G:60@
M(E1R87-H(&9O;&1E<B(*;7-G<W1R(")!=&MR:71U;74@;6%P93HB"@HC.B!T
M96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4<F%S
M:"!F;VQD97(Z(@IM<V=S='(@(D%T:W)I='5M=2!M87!E.B(*"B,Z(&QI8B]1
M=6]T82]C>7)U<RYP:'`Z-C4@;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z-SD@
M;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1=6]T82]L;V=F:6QE
M+G!H<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+VUD
M865M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS
M=V5R960B"FUS9W-T<B`B3F5A=&)I;&3G=',B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S(@IM
M<V=S='(@(DYE871B:6QDYW3B<R!VYW-T=6QE<R(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHT('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C$S"FUS9VED(")5;F1E;&5T92(*;7-G<W1R(")!=&IA
M=6YO="(*"B,Z(&UA:6QB;W@N<&AP.C4X.2!M86EL8F]X+G!H<#HV,#(@;&EB
M+TU)344O2&5A9&5R<RYP:'`Z,C$R"FUS9VED(")5;F1I<V-L;W-E9"!296-I
M<&EE;G1S(@IM<V=S='(@(DYE871K;.)T:64@<V'RYVWG:FDB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-#0W"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B(@H*
M(SH@;6%I;&)O>"YP:'`Z-38U"FUS9VED(")5;FMN;W=N($1A=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E
M<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8S-0IM<V=I9"`B56YK;F]W;B!-965T:6YG
M(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C8Q.`HC+"!F=7IZ>0IM<V=I
M9"`B56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`B3F5A=&MLXG1I92!S8?+G
M;>=J:2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*
M;7-G<W1R("(B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-C4*;7-G:60@(E5N
M;F%M960B"FUS9W-T<B`B3F5N;W-A=6MT<R(*"B,Z(&UE<W-A9V4N<&AP.C0Y
M.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*;7-G<W1R
M(").97)E9'KG=',B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RDB"FUS9W-T
M<B`B071R86MS=.YT[F5S(&YO(&UA<&5S*"WG;2DB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU.#0*;7-G:60@(E5P9&%T92!!='1A8VAM
M96YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,C`*;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I9"`B
M57!L;V%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I
M;'-E;&5C="YI;F,Z-#$*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S
M='(@(DQI971O="!N;VML=7/G=&\@=N=R=.YB=2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-38*(RP@9G5Z>GD*;7-G:60@(E5S92!)34%0(&9O;&1E
M<B!S=6)S8W)I<'1I;VYS/R(*;7-G<W1R("),:65T;W0@<&%R86MS=.[P86YO
M<R!U>B!)34%0(&UA<.=M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S
M-0HC+"!F=7IZ>0IM<V=I9"`B57-E(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*
M;7-G<W1R("))>G1U:_!O="!A=&MR:71U;74@;6%P:2(*"B,Z('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-#(*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T
M<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@86-L+G!H<#HX-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@
M=&AE('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-PIM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$W"B,L(&9U>GIY"FUS
M9VED(")5<V5R;F%M93HB"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*(RP@9G5Z>GD*;7-G
M:60@(E9I97<B"FUS9W-T<B`B4VMA=.YT("5S(@H*(SH@;&EB+TU)344O5FEE
M=V5R+WII<"YP:'`Z.3(@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E-K873N="`E
M<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,@
M4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3$V"B,L(&9U>GIY"FUS9VED(")6:65W($A434P@8V]N=&5N="!I
M;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")286MS=.YT(';G<W1U;&5S
M(&%T<V5V:?#MXB!L;V?B+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C(X"B,L(&9U>GIY"FUS9VED(")6:65W($UE<W-A9V5S(@IM<V=S
M='(@(DIA=6YA<R!VYW-T=6QE<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6:65W
M(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R
M"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"B,L
M(&9U>GIY"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R(")0879E9&EE;G,B
M"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z,38U"FUS9VED(")6:65W(%1H=6UB;F%I;"(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC
M+"!F=7IZ>0IM<V=I9"`B5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@
M=VEN9&]W(@IM<V=S='(@(E)A:W-T[G0@=N=S='5L97,@871S979I\.WB(&QO
M9^(N(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L(&9U
M>GIY"FUS9VED(")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B
M"FUS9W-T<B`B4F%K<W3N="!VYW-T=6QE<R!A='-E=FGP[>(@;&]GXBXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30P"FUS9VED(")6:65W(&5V
M96YT(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,X,"!M86EL8F]X+G!H
M<#HU,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@;65S<V%G
M97,@:6X@)7,B"FUS9W-T<B`B07!S:V%T[G0@=N=S='5L97,@(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM<V=I9"`B
M5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S
M='(@(E-K871S('9A:2!P87-T:V%S=&4@:V\@<&%RXF3N="!PYV,@<&EE<VSG
M9_!A;N)S.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S`*(RP@
M9G5Z>GD*;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R(")3:V%T[G0@)7,B"@HC
M.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED
M(")6:65W('1H92!);6%G97,B"FUS9W-T<B`B07!S:V%T[G0@=N=S='5L97,@
M(@H*(SH@<V5A<F-H+G!H<#HR-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<(B!C<F5A=&5D('-U8V-E<V9U;&QY
M+B(*;7-G<W1R(")-87!E(%PB)7-<(B!V96EK<VWN9VD@:7ID>N=S=&$N(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E
M92YP:'`Z,3,X(&QI8B])34%0+U1R964N<&AP.C$U,0HC.B!L:6(O24U!4"]4
M<F5E+G!H<#HQ-3,@;&EB+TE-05`O5')E92YP:'`Z,34W(&QI8B])34%0+U1R
M964N<&AP.C$U.`HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-CD@;&EB+TE-05`O
M5')E92YP:'`Z,SDS(&QI8B])34%0+U1R964N<&AP.C0S,PHC+"!F=7IZ>0IM
M<V=I9"`B5FER='5A;"!&;VQD97)S(@IM<V=S='(@(DEZ=F5I9&]T(&UA<&DB
M"@HC.B!S96%R8V@N<&AP.C(T-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E
M<75I<F4@82!L86)E;"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&;VQD97(N<&AP
M.C$W-2!L:6(O5D9O;&1E<BYP:'`Z,3@P"FUS9VED(")6:7)T=6%L($E.0D]8
M(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q-@IM<V=I9"`B5FER='5A
M;"!)3D)/6"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-#4R
M(&QI8B]61F]L9&5R+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0IM<V=I
M9"`B5FER='5A;"!4<F%S:"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT
M,3,*(RP@9G5Z>GD*;7-G:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S
M='(@(DEZ='5K\&]T(&%T:W)I='5M=2!M87!I(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U86P@9F]L9&5R(&QA8F5L
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<T
M"FUS9VED(")787)N:6YG(@IM<V=S='(@(D)R[F1I;N)J=6US(@H*(SH@;&]G
M:6XN<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S
M(@IM<V=S='(@(DQA:7!N:2!L^V1Z86T@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C$Y"FUS9VED("(B"B)7:&%T('-H;W5L9"!W92!D;R!W:71H
M('-P86T@;65S<V%G97,@869T97(@=&AE>2!H879E(&)E96X@<F5P;W)T960@
M87,@<W!A;2`B"B)O<B!I;FYO8V5N=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<R-PHC+"!F=7IZ>0IM<V=I9"`B(@HB5VAE;B!D
M96QE=&EN9R!M97-S86=E<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L
M9&5R(&EN<W1E860@;V8@;6%R:VEN9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM
M<V=S='(@(B(*(D1ZY_!O="!VYW-T=6QE<R!PXG)V:65T;W0@=.)S('5Z(&%T
M:W)I='5M=2!M87!I+"!N979I<R!A='KN;>=T(&OB(&EZ9'KG<W1A<RXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS9VED(")7:&5N(&]P96YI
M;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S
M=&%R="!O;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@
M<V%V92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN9R!M86EL
M(&]R(&5X<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W
M92!A<'!E;F0@=&\@(@HB=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A
M9&1R97-S97,@=VET:&]U="!<(D!<(BD_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B5VAI=&5L:7-T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<X"FUS9VED(")997,B"FUS9W-T<B`B
M2N(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN
M<&AP.C4X"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&%B;W5T('1O(&9E=&-H
M(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O=6YT*',I.B(*;7-G<W1R
M(")*^W,@;>?L:6YA="!I>F1ZYW-T('-E:V]J;_!A<R!M87!E<SHB"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F
M=7IZ>0IM<V=I9"`B(@HB66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A
M;&P@;65S<V%G97,@8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R
M(@HB*',I+B(*;7-G<W1R(")*^W,@;>?L:6YA="!I>F1ZYW-T('-E:V]J;_!A
M<R!M87!E<SHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I
M<FTN:'1M;#HY"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&%T=&5M<'1I;F<@
M=&\@9&5L971E('1H92!F;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G<W1R(")*
M^W,@;>?L:6YA="!I>F1ZYW-T('-E:V]J;_!A<R!M87!E<SHB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I
M;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(EEO=2!A
M<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+B(*;7-G<W1R(")*
M^W,@<.)R<V%U8V%T(&UA<&DZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3`R"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@<W5B
M+69O;&1E<B!T;R`B"FUS9W-T<B`B2OMS('9E:61O:F%T(&%P86OP;6%P:2`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I
M9"`B66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N(@IM<V=S
M='(@(DK[<R!V96ED;VIA="!A=6?PYVKB(&SN;67R82!M87!I+B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C,R,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@9F]L9&5R<RXB"FUS9W-T<B`B2OMS('9E:61O
M:F%T(&%U9_#G:N(@;.YM9?)A(&UA<&DN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,S(W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-0IM<V=I9"`B
M66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B`B"FUS9W-T<B`B2OMS('#B
M<G-A=6-A="!M87!I.B`B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EEO=2!C86X@;F]T('5N<W5B<V-R:6)E
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")*^W,@97-A="!V96EK<VWN9VD@871R
M86MS=.YJ:65S(&YO(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@8V%N
M('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO
M;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G92!C;VYT
M96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z,S0*;7-G:60@
M(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E
M(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@(@HB=&\@;&]G
M:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-CD*
M;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A
M8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QL
M;V<N<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9F]R=V%R9&5D
M('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE
M;G1S.B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE
M<G0N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&AA=F4@)7,@;F5W
M(&UE<W-A9V5S+B(*;7-G<W1R(")*=6US(&ER("5S(&IA=6YA<R!VYW-T=6QE
M<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PIM<V=I9"`B
M66]U(&AA=F4@,2!N97<@;65S<V%G92XB"FUS9W-T<B`B2G5M<R!I<B!V:65N
M82!J875N82!VYW-T=6QE+B(*"B,Z(&-O;7!O<V4N<&AP.C0Y-`HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E
M+B(*;7-G<W1R(")*=6US(&ER('9I96YA(&IA=6YA(';G<W1U;&4N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,3$U"FUS9VED("(B
M"B)9;W4@:&%V92!A="!L96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T
M:&%T('EO=2!D:61N)W0@=7!L;V%D('EE="X@07)E("(*(GEO=2!S=7)E('EO
M=2!W86YT('1O('-E;F0@=&AI<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T
M86-H;65N=',_(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-S0*;7-G
M:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R
M.B(*;7-G<W1R(")*=6US(&ER(&IA=6YS('!A<W1S('-E:V]J;_#B(&UA<.<Z
M(@H*(SH@;&EB+TE-4"YP:'`Z,3`W.0IM<V=I9"`B66]U(&AA=F4@;F5W(&UA
M:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.B(*;7-G<W1R(")*=6US(&ER
M(&IA=6YS('!A<W1S('-E:V]J;_#B<R!M87#G<SHB"@HC.B!C;VUP;W-E+G!H
M<#HQ-3,*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE87-T
M(&]N92!R96-I<&EE;G0N(@IM<V=S='(@(DKB;F]RXF1A('9I<VUA>B!V:65N
M<R!S8?+G;>=J<RXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,#(*
M;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y
M;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G92(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T.0IM<V=I
M9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@
M4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R`B"B)M97-S86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC
M.C8T('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(P,0IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER<W0N(@IM
M<V=S='(@(DIU;7,@=FES<&ER;7,@:N)N;W+B9&$@;>=R[6$@<&%S=&MA<W1E
M+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B2N)I>G;G;&%S(&ED96YT:73B=&4L(&MO(&EZ9'KG<W0N(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0IM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(E9I<W!I
M<FUS(&KB:7IVYVQA<R!A9')E<V4N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC
M.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S
M86=E(&9I<G-T+B(*;7-G<W1R(")6:7-P:7)M<R!JXFEZ=N=L87,@=FES;6%Z
M('9I96YA(';G<W1U;&4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E
M8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT
M+B(*;7-G<W1R(")*XFYO<N)D82!S8?+G;>=J<R(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C(Y"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!F:6QE('1O(&%T=&%C:"XB"FUS
M9W-T<B`B2G5M<R!V:7-P:7)M<R!JXFYO<N)D82!F86EL<R!K;R!P:65V:65N
M;W0N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N
M86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R("(B
M"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@
M)25S+B(*;7-G<W1R(")0XG)A9')E<^=T(/!O(';G<W1U;&DB"@HC.B!L:6(O
M36%I;&QO9RYP:'`Z,30Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM<V=S='(@(E#B
M<F%D<F5SYW0@\&\@=N=S='5L:2(*"B,Z(&QI8B]&;VQD97(N<&AP.C4P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T
M;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B3F5I>F1E=N)S('!A<F%K<W3N=&EE<R!U>B!M87!I(%PB)7-<(BX@T.)D
M82!B:6IA('-E<G9E<F$@871B:6QD92(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@=6YS=6)S8W)I
M8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED
M(@IM<V=S='(@(DYE:7ID97;B<R!A=')A:W-T[G1I97,@;F\@7"(E<UPB+B#0
MXF1A(&)I:F$@<V5R=F5R82!A=&)I;&1E(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M-3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL
M>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")*^W,@97-A="!V96EK
M<VWN9VD@<&%R86MS=.YJ:65S('5Z(%PB)7-<(B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C4V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S
M9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB(@IM<V=S='(@(DK[<R!E
M<V%T('9E:6MS;>YG:2!A=')A:W-T[FII97,@;F\@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"B,L(&9U>GIY"FUS9VED(")9;W5R($YA
M;64B"FUS9W-T<B`B2OMS=2!P:6QN86ES(';B<F1S.B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHU,`IM<V=I9"`B66]U<B!01U`@4'5B;&EC+U!R:79A
M=&4@2V5Y<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<Q('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-@IM<V=I9"`B66]U<B!0
M<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C8W('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,0HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!0=6)L:6,@2V5Y(@IM<V=S='(@(DK[<W4@<&EL;F%I<R!V
MXG)D<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"B,L(&9U>GIY
M"FUS9VED(")9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L
M*3PO96T^(@IM<V=S='(@(DK[<W4@4F5P;'DM=&\Z(&%D<F5S93H@/&D^*&YE
M;V)L:6?B=&$I/"]I/B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M-#D*;7-G:60@(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC
M871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U
M;G1?<V5L96-T+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!A8V-O=6YT
M<SHB"FUS9W-T<B`B2OMS=2!I9&5N=&ETXG1E<SHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E
M<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W
M(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP
M92XB"FUS9W-T<B`B(@HB2OMS=2!PXG)L^VMP<F]G<F%M;6$@;F5U>G1U<B#P
M;R!D<G5KXO!A;F%S(&EE<W#G:G4N($YO<W!I9?YI970@0W1R;"]/<'1I;VX@
M*R`B"B)0(&QA:2!I>F1R=6OB='4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN
M9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M8W)Y<'1S96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T
M:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB
M"FUS9W-T<B`B36%P92!<(B5S7"(@=F5I:W-M[F=I(&EZ9'KG<W1A+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@(EEO=7(@<VEG;F%T
M=7)E.B(*;7-G<W1R(")*^W-U('!A<F%K<W1S.B(*"B,Z(&UE<W-A9V4N<&AP
M.C(X."!C;VUP;W-E+G!H<#HQ,C@T(&UA:6QB;W@N<&AP.C4T.2!L:6(O0V]M
M<&]S92YP:'`Z.#$X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6T)E
M>B!V:7)S<F%K<W1A72(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(P-0HC+"!F=7IZ>0IM<V=I9"`B7T)C8R(*;7-G<W1R(")"8V,B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*(RP@9G5Z>GD*;7-G:60@
M(E]";&%C:VQI<W0B"FUS9W-T<B`B365L;F%I<R!S87)A:W-T<R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$U-`HC+"!F=7IZ>0IM<V=I
M9"`B7T-C(@IM<V=S='(@(D-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC+"!F
M=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")$>N=S="(*"B,Z(&QI8B])
M35`N<&AP.CDW.0HC+"!F=7IZ>0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`B
M36%P97,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,0HC
M+"!F=7IZ>0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@(DED96YT:73B=&4B
M"@HC.B!L:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G<W1R("(B
M"@HC.B!L:6(O24U0+G!H<#HQ,#(P"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U
M="(*;7-G<W1R("))>FEE="(*"B,Z(&UE<W-A9V4N<&AP.C,X-`HC+"!F=7IZ
M>0IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(E;G<W1U;&5S('!I
M<FUT96MS=',B"@HC.B!L:6(O24U0+G!H<#HY-S8*(RP@9G5Z>GD*;7-G:60@
M(E].97<@365S<V%G92(*;7-G<W1R(")*875N87,@=N=S='5L97,B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S,*(RP@9G5Z
M>GD*;7-G:60@(E]0<FEN="(*;7-G<W1R(")$<G5KXG0B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C@Y"FUS9VED(")?4')I;W)I='DB"FUS9W-T<B`B(@H*
M(SH@;6%I;&)O>"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")?4F5F<F5S:"`E<R(*;7-G<W1R(")!=&IA=6YO="(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED
M(")?4F5P;'DB"FUS9W-T<B`B071B:6QDYW0B"@HC.B!L:6(O24U0+G!H<#HY
M.#$*(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B365K;.?P86YA
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"B,L(&9U>GIY"FUS9VED(")?
M4V5N9"!-97-S86=E(@IM<V=S='(@(E/[=.YT(';G<W1U;&DB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,R"B,L(&9U>GIY
M"FUS9VED(")?5&AR96%D(@IM<V=S='(@(E!A=F5D:65N<R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B
M7U1O(@IM<V=S='(@(E-A\N=MYVIS(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E]5;F1E;&5T92(*;7-G
M<W1R(")!=&IA=6YO="(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B7U9I97<@5&AR96%D(@IM
M<V=S='(@(E!A=F5D:65N<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3<V"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#0P"B,L(&9U>GIY"FUS9VED(")A
M='1A8VAM96YT(@IM<V=S='(@(E!I96QI:W5M<R(*"B,Z('9I97<N<&AP.CDY
M"B,L(&9U>GIY"FUS9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B4&EE
M;&EK=6UI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S
M"FUS9VED(")B>71E<R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,C`P"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S(*;7-G:60@(F-A;FYO="!O<&5N
M(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C0*;7-G
M:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,C(P"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.38*;7-G:60@(F-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$V.`IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(R-`IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,3DP"FUS9VED(")F<F]M(@IM<V=S='(@(FYO(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$X,`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P-`IM<V=I9"`B:6YP
M=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ.#@*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8Y"FUS9VED(")K97DB"FUS
M9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")M
M86EL8F]X(&9I;&4B"FUS9W-T<B`B4&%S=&MA<W1E(@H*(SH@8V]M<&]S92YP
M:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z-#8V"B,L(&9U>GIY"FUS9VED(")N
M86UE(@IM<V=S='(@(E;B<F1S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C<V"FUS9VED(")N;VYE(@IM<V=S='(@(FYE=FEE;G,B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")O
M<B(*;7-G<W1R(")V86DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$V"FUS9VED
M(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,C$R"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X-`IM<V=I9"`B<V5R=FEC
M92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R(@IM<V=S
M='(@(G!A<F5I>G)A:W-T[F)A<R!K[_MD82(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W)S(@IM
M<V=S='(@(G!A<F5I>G)A:W-T[F)A<R!K[_MD87,B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,3DR"B,L(&9U>GIY"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T
M<B`B<&%R96EZ<F%K<W3N8F%S(&OO^V1A(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C(P.`IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T9I;'1E<BYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(GEO=7(@8FQA8VML
M:7-T(@IM<V=S='(@(DUE;&YA:7,@<V%R86MS=',B"@HC.B!L:6(O1FEL=&5R
M+G!H<#HV,0IM<V=I9"`B>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+W!O+VYN7TY/+G!O````````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,W,C0Q,@`Q,#0Q-S,V,C<V-``P
M,3<R,#8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R!)35`@3F]R=V5G:6%N($YY;F]R<VL@=')A;G-L871I;VX*(R!#;W!Y
M<FEG:'0@*$,I(#(P,#(@4&5R+5-T:6%N(%9A=&YE(#QN>6YO<G-K0&]R<W1A
M+F]R9SX*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A
M;64@;&EC96YS92!A<R!T:&4@24U0('!A8VMA9V4N"B,@4&5R+5-T:6%N(%9A
M=&YE(#QP<W9`;W)S=&$N;W)G/BP@,C`P,BX*(R`*;7-G:60@(B(*;7-G<W1R
M("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($E-4"`T+C`M8W9S7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P,BTP-BTP."`R,CHS-"LP,3`P7&XB"B),87-T
M+51R86YS;&%T;W(Z(%!E<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R9SY<
M;B(*(DQA;F=U86=E+51E86TZ($YO<G=E9VEA;B!.>6YO<G-K(#QN>6YO<G-K
M0&]R<W1A+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B("`@("`@0V,Z("(*;7-G<W1R
M("(@("`@(%1I;#H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q-0IM<V=I9"`B
M("`@("`@5&\Z("(*;7-G<W1R("(@("`@(%1I;#H@(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C0P,PIM<V=I9"`B("`@($1A=&4Z("(*;7-G<W1R("(@("`@1&%T
M;SH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P-@IM<V=I9"`B("`@($9R;VTZ
M("(*;7-G<W1R("(@("`@($9RY3H@(@H*(SH@;6%I;&)O>"YP:'`Z-#(R('1E
M;7!L871E<R]F;VQD97)S+VAE860N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HT,3(*;7-G:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B("`@($5M;F4Z
M("(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW,`IM<V=I
M9"`B(&EN("(*;7-G<W1R("(@:2`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@(B,B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T
M:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M365S<V%G97,B"FUS9W-T<B`B)60@878@)60@;65L9&EN9V%R(@H*(SH@;6%I
M;&)O>"YP:'`Z,3<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M
M97-S86=E<R!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B)7,@;65L9&EN
M9V%R('9A<G0@:&5N=&$N+BXB"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E9"!M97-S86=E<R!H879E(&)E
M96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@HB1&5N;F4@;65L9&EN9V$@97(@<F%P<&]R
M=&5R="!S;VT@<_AP<&5L<&]S="!T:6P@9&EN('-Y<W1E;6%D;6EN:7-T<F%T
M;W(N(@H*(SH@;&EB+U-P86TN<&AP.C$U.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO
M="!S<&%M+B(*;7-G<W1R(")$96YN92!M96QD:6YG82!E<B!R87!P;W)T97)T
M('-O;2!S^'!P96QP;W-T+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R
M97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(D1E;FYE(&UE;&1I;F=A(&5R(')A<'!O<G1E<G0@<V]M
M('/X<'!E;'!O<W0@=&EL(&1I;B!S>7-T96UA9&UI;FES=')A=&]R+B(*"B,Z
M(&QI8B]3<&%M+G!H<#HQ-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G
M<W1R(")$96YN92!M96QD:6YG82!E<B!R87!P;W)T97)T('-O;2!S^'!P96QP
M;W-T+B(*"B,Z(&UA:6QB;W@N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"!T:6P@)60@
M878@)60@;65L9&EN9V%R(@H*(SH@;6%I;&)O>"YP:'`Z-C0P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F
M;VQD97(@=V%S(&YO="!R96YA;65D+B(*;7-G<W1R("(E<R!E:W-I<W1E<F5R
M(&%L;&5R96EE+B!.86UN970@<.4@;6%P<&$@)7,@=F%R="!I:VMJ92!E;F1R
M82XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S
M96YT;6%I;%]M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO
M;G1H+B(*;7-G<W1R(")-87!P82`E<R!FY7(@96YD<F$@;F%M;F5T('9E9"!S
M=&%R=&5N(&%V(&WE;F%D96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C(U-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@86-C97!T960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@9&5C;&EN960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S
M="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@
M:6YV:71A=&EO;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0X,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@
M<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4X-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R
M97-E;F-E(&%T("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-#$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B36%P<&$@7"(E<UPB
M(&5N9')A(&YA;6X@=&EL(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T
M;R!A;6UE;F0@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O
M(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O
M=70@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(X-2!M97-S86=E
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC.C$S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D
M*2(*;7-G<W1R("(E<SH@)7,@*"5D)FYB<W`[878F;F)S<#LE9"DB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S"FUS9VED("(H07!P
M;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C<F5E;BXI(@IM
M<V=S='(@(BA"<G5K(&1E<W-E(&5N9')I;F=A;F4@;V<@9^4@=&EL(&YE<W1E
M('-K:F5R;6)I;&5T92XI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E
M='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("(B"B(H5&EL
M8F%K97-T:6QL(&%L;&4@96YD<FEN9V%R(&]G(&?E('1I;&)A:V4@=&EL('-K
M:F5R;6)I;&5T970@9F]R('-K<FEV("(*(FUE;&1I;F<N*2(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*$A434PI(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ
M-@IM<V=I9"`B*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG
M+G!H<#HR.#`*;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R
M965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N
M("`B"B)#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B
M92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*$?E('1I;&)A:V4@=&EL('-K:F5R
M;6)I;&5T970@9F]R('-K<FEV(&UE;&1I;F<@971T97(@Y2!H82!A:W1I=F5R
M="!A;&QE("(*(F5N9')I;F=A;F4@9'4@:&%R(&=J;W)T('/E(&QA;F=T+B!%
M;F1R:6YG87(@:2!D971T92!S:VIE<FUB:6QE=&5T('9I;"!)2TM*12`B"B)B
M;&D@8G)U:W0N*2(*"B,Z('-P96QL:6YG+G!H<#HR-S<*(RP@9G5Z>GD*;7-G
M:60@(B(*(BA396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG
M97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE("(*(F-U<G)E;G0@
M<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H1^4@
M=&EL8F%K92!T:6P@<VMJ97)M8FEL971E="!F;W(@<VMR:78@;65L9&EN9R!E
M='1E<B#E(&AA(&%K=&EV97)T(&%L;&4@(@HB96YD<FEN9V%N92!D=2!H87(@
M9VIO<G0@<^4@;&%N9W0N($5N9')I;F=A<B!I(&1E='1E('-K:F5R;6)I;&5T
M970@=FEL($E+2TI%("(*(F)L:2!B<G5K="XI(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@(BH@061D('1H97-E(&)Y
M(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B!,96=G('1I;"!D97-S92!V960@
MY2!K;&EK:V4@3TL@*B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C`V"FUS9VED("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@
M*B(*;7-G<W1R("(J(%9E;"!A9')E<W-E*'(I("HB"@HC.B!M86EL8F]X+G!H
M<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R(")$96YN92!M96QD:6YG82!E<B!R87!P;W)T97)T('-O
M;2!S^'!P96QP;W-T+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*(RP@9G5Z>GD*
M;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A
M;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)$
M96YN92!M96QD:6YG82!E<B!R87!P;W)T97)T('-O;2!S^'!P96QP;W-T('1I
M;"!D:6X@<WES=&5M861M:6YI<W1R871O<BXB"@HC.B!L:6(O4W!A;2YP:'`Z
M,38P"B,L(&9U>GIY"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86TN(@IM<V=S='(@(D1E;FYE(&UE;&1I;F=A(&5R(')A
M<'!O<G1E<G0@<V]M('/X<'!E;'!O<W0N(@H*(SH@;&EB+U-P86TN<&AP.C$W
M,@HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D
M(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B(@HB1&5N;F4@;65L9&EN9V$@97(@<F%P<&]R=&5R="!S;VT@<_AP<&5L
M<&]S="!T:6P@9&EN('-Y<W1E;6%D;6EN:7-T<F%T;W(N(@H*(SH@;&EB+U-P
M86TN<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N
M(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(D1E;FYE(&UE;&1I;F=A(&5R
M(')A<'!O<G1E<G0@<V]M('/X<'!E;'!O<W0N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@Q.0HC+"!F=7IZ>0IM<V=I9"`B,3`P(&-H87)A8W1E<G,B
M"FUS9W-T<B`B4W!E<VEA;'1E:6MN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@R,@HC+"!F=7IZ>0IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S
M='(@(E-P97-I86QT96EK;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,C`*(RP@9G5Z>GD*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(E-P
M97-I86QT96EK;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C$*(RP@
M9G5Z>GD*;7-G:60@(C4P,"!C:&%R86-T97)S(@IM<V=S='(@(E-P97-I86QT
M96EK;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B02!L87)G92!I;6%G92!N86UE9"`E
M<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N(@IM<V=S='(@(D1E;FYE
M(&]F9F5N=&QE9V4@4$=0+6[X:VME;&5N('9A<B!L86=T('9E9"!M96QD:6YG
M82XB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,`IM
M<V=I9"`B(@HB02!M97-S86=E('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D
M(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H92`B"B)R96-I<&EE
M;G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN
M8SHU"FUS9VED(")!3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Y,`IM<V=I9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-PIM<V=I9"`B06-C
M97!T(')E<75E<W0@86YD(&%D9"!I="!T;R!M>2!C86QE;F1A<B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4S"FUS9VED(")!
M8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,C4W"FUS9VED(")!8V-E<'1E9#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT)W,@
M;F%M93HB"FUS9W-T<B`B3F%M;B!PY2!K;VYT;SHB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3(P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M,S`*(RP@9G5Z>GD*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B2&%N9&QI;F<B
M"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)344O2&5A9&5R
M<RYP:'`Z,C`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,@
M=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@(DQE9V<@=&EL(&%D<F5S<V5B
M;VL@*"5S*2(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC
M.C,P,PHC+"!F=7IZ>0IM<V=I9"`B061D('-O=7)C92(*;7-G<W1R(")L96=G
M('1I;"!K:F5L9&4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<W
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D9"!T:&ES
M('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!A
M<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("),82!T:6P@96ET('9E9&QE9V<N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D
M:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\96T^
M*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE
M*3PO96T^(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@
M:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@9G5Z>GD*
M;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<R(*;7-G<W1R
M(")097)S;VYL96<@:6YF;W)M87-J;VXB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I
M;',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E
M=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S
M<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET
M:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(&-A;B!B92!V:65W960@)7,N
M(@IM<V=S='(@(B(*"B,Z(&-O;G1A8W1S+G!H<#HX-2!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$X,`HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS,SD@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C4R"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S96)O:R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*(RP@9G5Z>GD*;7-G:60@
M(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B061R97-S96)O:R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.#D*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!"
M0T,@86QL(&UE<W-A9V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D
M9')E<W,@;VX@82!N97<@(@HB;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S97,@
M=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I
M;VYA;"P@96YT97(@96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E
M;3XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHQ,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")!;&PB"FUS
M9W-T<B`B06QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3,*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG
M(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B
M"B)F:6QE.B(*;7-G<W1R(")!;&QE(&UE;&1I;F=A<B!I(&;X;&=J86YD92!M
M87!P92AR*2!V:6P@8FQI(&QA<W1A(&YE9"!T:6P@96D@34)/6"UF:6PZ(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R(%PB
M)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N
M96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB06QL92!M96QD:6YG87(@
M:2!M87!P82!<(B5S7"(@<V]M(&5R(&5L9')E(&5N;B`E<R!D86=A<BP@=FEL
M(&)L:2!S;&5T=&$@(@HB<&5R;6%N96YT+B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK960@871T86-H
M;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D
M+B(*;7-G<W1R("(B"B)!;&QE(&=A;6QE(&MA=&%L;V=A<B!M960@<V5N9'0@
M<&]S="!S;VT@97(@96QD<F4@96YN("5S(&WE;F%D97(L('9I;"!B;&D@(@HB
M<VQE='1A+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT
M;6%I;%]M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@
M;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD
M('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B(@HB06QL92!G86UL92!K871A
M;&]G87(@;65D('-E;F1T('!O<W0@<V]M(&5R(&5L9')E(&5N;B`E<R!MY6YA
M9&5R+"!V:6P@8FQI("(*(G-L971T82XB"@HC.B!A8VPN<&AP.C@U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@<FEG:'1S(&]N(&9O;&1E<B!<
M(B5S7"(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@7"(E<UPB+B(*
M;7-G<W1R(")-87!P82!<(B5S7"(@96YD<F$@;F%M;B!T:6P@7"(E<UPB+B(*
M"B,Z(&QI8B]A<&DN<&AP.C<V"FUS9VED(")!;&QO=R!&;VQD97(@0W)E871I
M;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@
M:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A;'1E<FYA=&EV92YP:'`Z,3$P"FUS9VED(")!;'1E<FYA=&EV92!P87)T
M<R!F;W(@=&AI<R!S96-T:6]N.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3<R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#0*;7-G
M:60@(D%L=V%Y<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-34W"B,L(&9U>GIY"FUS9VED(")!;'=A>7,@<V%V92!A='1A8VAM96YT
M<R(*;7-G<W1R("),82!T:6P@96ET('9E9&QE9V<N(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C4P-0IM<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E9"!W:&EL92!A
M='1E;7!T:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S
M97)V97(@(@HB<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HS.#@*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E
M9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W(&YO=&4N(@IM<V=S='(@(E5K:F5N
M="!F96EL(&[E<B!O<'!F^')I;F=A('-K=6QL92!L96=G:F%S="!T:6PN(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C,X-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@=&%S
M:RXB"FUS9W-T<B`B56MJ96YT(&9E:6P@;N5R(&]P<&;X<FEN9V$@<VMU;&QE
M(&QE9V=J87-T('1I;"XB"@HC.B!M97-S86=E+G!H<#HU,#`@;6%I;&)O>"YP
M:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R(")3=F%R="!P
MY2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@(D%N
M<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(DUE;&1I;F=A<B!D=2!H87(@<W9A
M<G0@<.4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@
M9G5Z>GD*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B0G)U:R!F:6QT
M97(@<.4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B
M"FUS9W-T<B`B0G)U:R!F:6QT97(@<.4B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(D%P<&QY(&9I;'1E<B!R
M=6QE<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(D)R=6L@9FEL=&5R<F5G
M;&%R('9E9"!PY6QO9V=I;F<N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@
M=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/R(*;7-G<W1R(")"<G5K(&9I
M;'1E<G)E9VQA<B!NY7(@<&]S=&)O:W-A(&)L:7(@9G)I<VMA(&]P<"XB"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR-PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E
M;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(D5R(&1U('-I:VME<B!P
MY2!A="!D=2!V:6P@<VQE='1E(&1E;FYE(&]F9F5N=&QE9V4@;OAK:V5L96X_
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z.#4*;7-G:60@(B(*(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM
M96YD960A*2(*;7-G<W1R("(B"B)%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL
M('-L971T92!N^&MK96QP87)E="!D:71T/R`H1&5T=&4@97(@24M+2D4@=&EL
M<N5D9"$I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\B"FUS9W-T<B`B17(@9'4@<VEK
M:V5R('#E(&%T(&1U('9I;"!G:F5R92!D971T93\B"@HC.B!M97-S86=E+G!H
M<#HT,#<@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C@*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE
M=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(D5R(&1U('-I:VME<B!PY2!A
M="!D=2!V:6P@<VQE='1E(&1E<W-E(&UE;&1I;F=A;F4@4$5234%.14Y4/R(*
M"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@
M=&AI<R!A='1A8VAM96YT/R(*;7-G<W1R(")%<B!D=2!S:6MK97(@<.4@870@
M9'4@=FEL('-L971T92!D97-S92!M96QD:6YG86YE(%!%4DU!3D5.5#\B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/R(*;7-G
M<W1R(")%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('3X;6UE(&1E;FYE(&UA
M<'!A/R(*"B,Z(&QI8B])35`N<&AP.CDW,PHC+"!F=7IZ>0IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@<W!A;2!F;VQD97(_
M(@IM<V=S='(@(D5R(&1U('-I:VME<B!PY2!A="!D=2!V:6P@=/AM;64@<_AP
M<&5L:V]R9V$@9&D_(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_
M(@IM<V=S='(@(D5R(&1U('-I:VME<B!PY2!A="!D=2!V:6P@=/AM;64@<_AP
M<&5L:V]R9V$@9&D_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`B
M17(@9'4@<VEK:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@9&5S<V4@;65L9&EN
M9V%N92!015)-04Y%3E0_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C
M<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M-SD*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R
M97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R(")%<B!D
M=2!S:6MK97(@<.4@870@9'4@=FEL('3X;6UE(&1E;FYE(&UA<'!A/R(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E
M<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"B,L(&9U>GIY"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A
M<R!S<&%M/R(*;7-G<W1R(")%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('3X
M;6UE(&1E;FYE(&UA<'!A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,38*;7-G:60@(D%R<FEV86P@5&EM92(*;7-G<W1R(")4:60@;6]T=&5K92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S$*;7-G:60@(D%S8V5N9&EN
M9R(*;7-G<W1R(")3=&EG86YD92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,PIM<V=I9"`B07-K(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q
M.0IM<V=I9"`B071T86-H(@IM<V=S='(@(DQE9V<@=F5D(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<U"B,L(&9U>GIY"FUS9VED(")!
M='1A8V@@1FEL97,B"FUS9W-T<B`B5F5D;&%G="!F:6PZ(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#4V"FUS9VED(")!='1A8V@@82!C
M;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/R(*
M;7-G<W1R("),96=G('9E9"!E:6X@:V]P:2!A=B!D:6X@;V9F96YT;&5G92!0
M1U`M;OAK:V5L(&D@;65L9&EN9V$_(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N
M968N<&AP.C$P.0IM<V=I9"`B071T86-H960@1FEL93HB"FUS9W-T<B`B5F5D
M;&%G="!F:6PZ(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0U,2!L:6(O0V]M<&]S
M92YP:'`Z-3,V"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%T=&%C:&5D(&9I
M;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N
M($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,S<V"FUS9VED(")!='1A8VAE9"!I<R!A(')E<&QY
M('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,30*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3`V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FIS.CDW"FUS9VED(")!='1A8VAM96YT(@IM<V=S='(@(E9E9&QE9V<B
M"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*;7-G
M:60@(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@
M='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHS-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<S"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ,#<S"FUS9VED(")!='1A8VAM96YT<R(*;7-G
M<W1R(")6961L96=G(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X
M,@HC+"!F=7IZ>0IM<V=I9"`B071T96YD965S(@IM<V=S='(@(E9E9&QE9V<B
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PHC+"!F
M=7IZ>0IM<V=I9"`B071T96YT:6]N(@IM<V=S='(@(DAA;F1L:6YG(@H*(SH@
M;&EB+T%U=&@O:6UP+G!H<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8T,`IM<V=I9"`B(@HB075T;VUA=&EC86QL
M>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E
M<B!I<R!I;B!M>2`B"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDX"B,L(&9U>GIY"FUS
M9VED(")!=F%I;&%B;&4@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`B5&EL9VIE
M;F=E;&5G92!A9')E<W-E8OAK97(Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<Q.0IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS
M9W-T<B`B5&EL8F%K92!T:6P@)7,B"@HC.B!T:')E860N<&AP.C$S-R!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B5&EL8F%K92!T:6P@
M)7,B"@HC.B!T:')E860N<&AP.C$S-`IM<V=I9"`B0F%C:R!T;R!-=6QT:7!L
M92!-97-S86=E(%9I97<@26YD97@B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H
M<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D($1I<W!L87DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N
M9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR-C8@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C(*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L:6(O4V5A<F-H+G!H<#HS-`IM<V=I
M9"`B0F-C(@IM<V=S='(@(D)L:6YD(&MO<&DB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X
M="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR
M,2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B0FQA
M8VML:7-T(@IM<V=S='(@(E-V87)T96QI<W0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C(Y"FUS9VED(")";&]C:R!I;6%G97,@:6X@2%1-3"!M97-S
M86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E<W1E9#\B
M"FUS9W-T<B`B(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(*;7-G:60@(D)O9'DB
M"FUS9W-T<B`B2W)O<'`B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C(S('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,SD*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHU-2!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C<Q"FUS9VED(")";W1H(@IM<V=S='(@(D)E9V=E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8X-PIM<V=I9"`B0F]T:"!(96%D97(@3&ES=&EN9R!A
M;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(D+E9&4@=FES:6YG(&%V(&UE
M;&1I;F=S:&]V=60@;V<@;65L9&EN9W-K<F]P<"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(W,@IM<V=I9"`B0U]H87)S970B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED
M(")#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C(P,0HC+"!F=7IZ>0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H
M92!R96UO=&4@;6%I;"!S97)V97(N(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L
M92!T:6P@92UP;W-T=&5N87)E;B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,3DY"B,L(&9U>GIY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE
M(')E;6]T92!M86EL('-E<G9E<CH@(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L
M92!T:6P@92UP;W-T=&5N87)E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P87)T
M:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T(&1I
M<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S
M<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R("(B"@HC
M.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T
M96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M<&QA
M=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM92]I
M;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(D%V8G)Y="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S-0HC
M.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#
M86YC96P@365S<V%G92(*;7-G<W1R(")!=F)R>70@;65L9&EN9R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A
M9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS
M9W-T<B`B5F5D(.4@879B<GET92!D96YN92!M96QD:6YG82!V:6P@9'4@;6ES
M=&4@:6YN:&%L9&5T(&9O<B!G;V1T+B(*"B,Z(&UE<W-A9V4N<&AP.C(V-2!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC.B!T96UP;&%T
M97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI8B]396%R8V@N<&AP.C,P
M"FUS9VED(")#8R(*;7-G<W1R(")+;W!I(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHY,PIM<V=I9"`B(@HB0V5R=&EF:6-A=&4@:6UP;W)T(&ES
M(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N
M('1H:7,@(@HB<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S`Q"B,L(&9U>GIY"FUS9VED(")#:&%I<B!097)S;VXB
M"FUS9W-T<B`B4&5R<V]N;&5G(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C@P"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B16YD<F4B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#$*;7-G:60@(D-H
M86YG92!!;&PB"FUS9W-T<B`B16YD<F4@86QL92(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E($9O;&1E<B(*
M;7-G<W1R(")/<'!R970@;6%P<&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I
M;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H
M('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R
M("(B"B)%;F1R92!V:7-I;F=S86QT97)N871I=BP@<VQI:R!S;VT@9F%R9V5S
M:VIE;6$L(&MR;R!M86YG92!M96QD:6YG87(@9'4@<V5R('#E("(*(FMV87(@
M<VED92P@;V<@:V]R;&5I<R!M96QD:6YG86YE(&)L:7(@<V]R=&5R=&4N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY"FUS9VED(")#
M:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS9W-T
M<B`B16YD<F4@:6YN<W1I;&QI;F=A<B!F;W(@<&]S='1E;F%R+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N
M86UE+"!A9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W
M:&5N('1H97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS
M9W-T<B`B(@HB16YD<F4@;F%M;BP@861R97-S92!O9R!S:6=N871U<F5N(&9O
M;&L@<V5R(&[E<B!D96D@;&5S(&]G('-V87)A<B!PY2!E+7!O<W0@(@HB9G+E
M(&1E9RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(T"FUS9VED(")#
M:&%R86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#:&5C:R!&;VQD97(H
M<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(E-J96MK(&UA<'!E*'(I(&9O<B!N
M>2!E+7!O<W0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-S4*;7-G
M:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]F971C:&UA:6PN:6YC.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V
M97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V,PHC+"!F=7IZ>0IM<V=I9"`B
M0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G
M<W1R(")6:7,@<W1A9&9E<W1I;F<@971T97(@Y2!H82!S96YD="!E:2!M96QD
M:6YG/R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G
M:60@(D-H;V]S92!!8W1I;VXZ(@IM<V=S='(@(E9E;"!H86YD;&EN9SHB"@HC
M.B!C;VYF:6<O<V5R=F5R<RYP:'`N9&ES=#HQ.#(*(RP@9G5Z>GD*;7-G:60@
M(D-H;V]S92!A(&UA:6P@<V5R=F5R.B(*;7-G<W1R(")%;F1R92!I;FYS=&EL
M;&EN9V%R(&9O<B!P;W-T=&5N87(N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,3<*;7-G
M:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE
M(')I9VAT.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*(RP@9G5Z>GD*
M;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(E9E;"!H86YD;&EN
M9SHB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*
M(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S
M92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(E9E;"!A9')E<W-E
M8F]K82!D=2!V:6P@8G)U:V4@9F]R(.4@;&5G9VIE('1I;"!N>64@861R97-S
M97(N(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS
M"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@
M8F]O:W,@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS
M9W-T<B`B5F5L(')E:VME9OAL9VIE('#E(&%D<F5S<V5B^&ME<B#E('/X:V4@
M:2!V960@:V]N=')O;&P@878@861R97-S97(N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K
M("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y
M;W5R(&)R;W=S97(@8V%N('9I97<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T9I;'1E<BYP:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K
M("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(E-K<FEV(&UE;&1I;F=A
M<B!I(&5I9V4@=FEN9&%U9V4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I
M97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(E-K<FEV(&UE;&1I;F=A
M<B!I(&5I9V4@=FEN9&%U9V4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T
M960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I
M97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@
M=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP
M:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC
M.C,R,0HC+"!F=7IZ>0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO=7(@
M<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I
M96QD<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(DML:6MK('#E(&5I(&%V
M(&1I;F4@=F%L9&4@861R97-S96+X:V5R(&]G('9E;"!A;&QE(&9E;'1A(&1E
M="!S:V%L('/X:V%S="!I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C$W,0HC+"!F=7IZ>0IM<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC
M($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R(")+;&EK:R!F;W(@
MY2!L86=R92!O9F9E;G1L96<@4$=0+6[X:VME;"!I(&%D<F5S<V5B;VMA(&1I
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,#(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-24U%(&-E<G1I
M9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K(@IM<V=S='(@(DML
M:6MK(&9O<B#E(&QA9W)E(&]F9F5N=&QE9R!01U`M;OAK:V5L(&D@861R97-S
M96)O:V$@9&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34P"FUS9VED
M(")#;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@
M;65S<V%G92!T;R!T:&4@<V5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-3$*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R
M97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR.`HC
M+"!F=7IZ>0IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B3GD@;65L9&EN9R(*"B,Z
M(&-O;7!O<V4N<&AP.C@R."!C;VUP;W-E+G!H<#HQ,30X"FUS9VED(")#;&]S
M92!T:&ES('=I;F1O=R(*;7-G<W1R("),=6MK(&1E='1E('9I;F1A=6=E="(*
M"B,Z(&9O;&1E<G,N<&AP.C0R.0IM<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G
M<W1R("),=6MK82!M87!P92(*"B,Z(&9O;&1E<G,N<&AP.C0T.0HC+"!F=7IZ
M>0IM<V=I9"`B0V]L;&%P<V4B"FUS9W-T<B`B1F]L9"!S86UA;B!A;&QE(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O
M;&QA<'-E($%L;"(*;7-G<W1R(")&;VQD('-A;6%N(&%L;&4B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@
M06QL($9O;&1E<G,B"FUS9W-T<B`B1F]L9"!S86UA;B!A;&QE(&UA<'!E<B(*
M"B,Z(&9O;&1E<G,N<&AP.C0T.0IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM
M<V=S='(@(D9O;&0@<V%M86X@;6%P<&4B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC871O<CH@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`B2V]M;65N=&%R(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<V.0HC+"!F=7IZ>0IM<V=I9"`B0V]M<&QE=&5D(@IM
M<V=S='(@(DMO;6UE;G1A<B(*"B,Z(&-O;7!O<V4N<&AP.C@R-R!C;VUP;W-E
M+G!H<#HQ,30W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S<V%G92(*;7-G
M<W1R(")3:W)I=B!E:2!M96QD:6YG('1I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,S0*(RP@9G5Z>GD*;7-G:60@(D-O;7!O<V4@;65S<V%G97,@
M:6X@82!S97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(E-K<FEV(&UE;&1I;F=A
M<B!I(&5I9V4@=FEN9&%U9V4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T,PIM<V=I9"`B(@HB0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@
M1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE("(*(F9E
M871U<F4I/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I<W!L87EE
M9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"B,L
M(&9U>GIY"FUS9VED(")#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N
M(@IM<V=S='(@(D5N9')E(&EN;G-T:6QL:6YG87(@9F]R('!O<W1T96YA<BXB
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM<V=I9"`B0V]N;F5C=&EO
M;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S
M97)V97(@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@
M4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R(")+;VYT<F]L;&5R97(@4$=0
M+7-T^'1T92!F;W(@24U0+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4R]-24U%
M('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R(")+;VYT<F]L;&5R97(@4$=0+7-T
M^'1T92!F;W(@24U0+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*
M;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M97-S86=E<R!S
M96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL('=I;&P@8F4@
M8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N;W1I9GD@>6]U
M("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB2V]N=')O;&QE<B!N
MY7(@9&5T('-K86P@<VIE:VMA<W0@9F]R(&YY('!O<W0L(&]G(&]M(&1U('-K
M86P@=F%R<VQA<W0@96QL97(@(@HB:6MK:F4@;N5R(&YY('!O<W0@:VIE;2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CDV"FUS9VED(")#;VYV97)T
M('1E>'1U86P@96UO=&EC;VYS(&EN=&\@9W)A<&AI8V%L(&]N97,_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM<V=I9"`B
M0V]P>2(*;7-G<W1R(")+;W!I97(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM<V=S
M='(@(E3X;2!S^'!P96QK;W)G(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S='(@(DMO<G)I9V5R
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I
M9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`B2V]R<FEG97)T('1E:W-T(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@
M1VEV96XZ("5S(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92!M96QD:6YG
M87(@9G+E("5S.B`E<R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD
M.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C0P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&UE<W-A
M9V5S(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@<VQE='1E(&UE;&1I;F=A<B!F<N4@)7,Z("5S(@H*(SH@;&EB
M+U-E<W-I;VXN<&AP.C,Q.`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&5X
M96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`B5F5D;&EK
M96AA;&1S;W!E<F%S:F]N87(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z-30*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@
M9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(DMU
M;FYE(&EK:VIE('1R96MK92!U="!D96X@9OAR97-P=7)D92!F:6QA(@H*(SH@
M;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!:
M:7`@87)C:&EV92XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@=')E:VME('5T(&1E
M;B!F^')E<W!U<F1E(&9I;&$B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<S"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N
M(&9R;VT@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z
M,S$T('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V
M,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(D]P<')E='0B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHV"FUS9VED(")#<F5A=&4@1F]L9&5R
M(@IM<V=S='(@(D]P<')E="!M87!P92(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,S<*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(D]P<')E='0@
M;OAK;&%R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$T"B,L
M(&9U>GIY"FUS9VED(")#<F5A=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B
M3W!P<F5T(&UA<'!E(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT
M7W-E;&5C="YI;F,Z,C8*;7-G:60@(D-R96%T92!A($YE=R!!8V-O=6YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHQ
M,B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*(RP@9G5Z>GD*
M;7-G:60@(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R(")/<'!R
M971T(&YY(&UA<'!E(&9O<B!S^'!P96QK;W)G(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L
M9&5R(@IM<V=S='(@(D]P<')E='0@;GD@;6%P<&4@9F]R(&ML861D(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR-B!T96UP;&%T
M97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0R"FUS9VED(")#<F5A=&4@
M82!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")/<'!R971T(&YY(&UA
M<'!E(&9O<B!S96YD="!P;W-T(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H
M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC
M.C(T"FUS9VED(")#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@
M(D]P<')E='0@;GD@;6%P<&4@9F]R('/X<'!E;&MO<F<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG
M(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I
M="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`B
M3W!P<F5T="!F:6QT97)R96=L87(@(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@;F5W('-T
M871I;VYE<GDB"FUS9W-T<B`B3W!P<F5T="!N>2!M87!P92!F;W(@<V5N9'0@
M<&]S="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*;7-G:60@(D-R
M96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4*(RP@9G5Z>GD*;7-G:60@(D-U<W1O
M;6EZ92!A8V-O=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C
M8V]U;G1S+B(*;7-G<W1R(")3:W)E9&1A<G-Y(&MO;G1O87(@9F]R(.4@:&5N
M=&4@;6%I;"!F<N4@86YD<F4@4$]0,RTO24U!4"UK;VYT;V%R+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B0W5S=&]M
M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R(")4:6QP87-S(&MO<FQE
M:7,@9'4@<V5N9&5R('!O<W0@;V<@:W9A<B!K;&%D9&5N(&)L:7(@;&%G<F$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B5&EL<&%S<R!O<'!GY79E<B!S;VT@<VMA;"!K^'ER87-T
M('9E9"!PY6QO9V=I;F<@=&EL("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3<*(RP@9G5Z>GD*;7-G:60@(D1A=%]E
M(@IM<V=S='(@(D1A=&\B"@HC.B!M97-S86=E+G!H<#HR-C(@=&AR96%D+G!H
M<#HQ-#@*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T;R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW-3<*(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D
M(@IM<V=S='(@(E-L971T82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HR-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*
M;7-G<W1R(")3;&5T="(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A
M<F-H<V5L96-T+FEN8SHQ.`IM<V=I9"`B1&5F875L="!396%R8V@@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,PIM<V=I
M9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")3=&%N9&%R
M9"!S;W)T97)I;F=S:W)I=&5R:75M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,S,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM
M<V=S='(@(E-T86YD87)D('-O<G1E<FEN9W-R96MK96;X;&=J93HB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U"B,L(&9U>GIY"FUS9VED(")$
M96QE9V%T960B"FUS9W-T<B`B4VQE='1A(@H*(SH@9F]L9&5R<RYP:'`Z-#$Y
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(T-"!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z-@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHX('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:6YC.C(X"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-PIM<V=I9"`B1&5L971E(@IM<V=S='(@(E-L971T(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+
M97DB"FUS9W-T<B`B4VQE='0@)7,@;V9F96YT;&5G(&[X:VME;"(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C@U"FUS9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(E-L
M971T(&YO=F5R86YD92!N^&ML87(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHY"FUS9VED(")$96QE=&4@1F]L9&5R*',I(@IM<V=S='(@
M(E-L971T92!M87!P92AR*2(*"B,Z(&9O;&1E<G,N<&AP.C(X-0HC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B4VQE
M='1E(&UA<'!E*'(I(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C0R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4W1A=&EO;F5R>2(*;7-G
M<W1R(")3;&5T=&4@;6%P<&4H<BDB"@HC.B!F;VQD97)S+G!H<#HT,3D*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")3
M;&5T=&4@;6%P<&4H<BDB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!F971C:&5D(&UE<W-A
M9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\B"FUS9W-T<B`B4VQE='0@;65L9&EN
M9V%R('-O;2!H96YT87-T(&9RY2!T96YA<F5N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8R.`IM<V=I9"`B1&5L971E(&9R;VT@;7D@8V%L96YD
M87(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.`HC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@
M870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")3;&5T="!G86UL92!M
M87!P97(@;65D('-E;F1T('!O<W0@=F5D('-T87)T96X@878@;>5N861E;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3`*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F
M(&UO;G1H/R(*;7-G<W1R(")3;&5T="!G86UL92!M87!P97(@;65D('-E;F1T
M('!O<W0@=F5D('-T87)T96X@878@;>5N861E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV,3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M(&UE
M<W-A9V5S(@IM<V=S='(@(E-L971T(&UE;&1I;F=A<B(*"B,Z(&UE<W-A9V4N
M<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,X
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L971E
M9"(*;7-G<W1R(")3;&5T=&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(E-L971T
M82!M96QD:6YG87(B"@HC.B!C;VUP;W-E+G!H<#HS,#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T960@=&AE(&%T=&%C:&UE;G0@7"(E<UPB
M+B(*;7-G<W1R(")3;&5T="!E:70@=F5D;&5G9RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG(&%N9"!-;W9I;F<@365S
M<V%G97,B"FUS9W-T<B`B4VQE='1I;F<@;V<@9FQY='1I;F<@878@;65L9&EN
M9V%R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,@IM<V=I9"`B
M1&5N>2!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU-#`*;7-G:60@(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,S(*;7-G:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`B4WEN:V%N9&4B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8V.0HC+"!F=7IZ>0IM<V=I9"`B1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B0G)U:V%R86QT97)N871I=B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I
M9"`B1&5T86EL<R(*;7-G<W1R(")$971A;&IA<B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-S<*;7-G:60@(D1I;2!S:6=N871U<F5S/R(*;7-G<W1R
M(")$:6T@<VEG;F%T=7)A<C\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R(")6:7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Y"FUS9VED(")$:7-P;&%Y(&-O
M;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B
M5FES('-T861F97-T:6YG(&5T=&5R(.4@:&$@<V5N9'0@96D@;65L9&EN9S\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED(")$:7-P;&%Y
M(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R(")6:7,@:2!M96QD:6YG<VMR
M;W!P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y,@HC+"!F=7IZ>0IM
M<V=I9"`B1&ES<&QA>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL
M/R(*;7-G<W1R(")6:7,@<W!R971T;W!P+79A<G-E;"!O;2!N>2!P;W-T+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-3@*(RP@9G5Z>GD*;7-G:60@
M(D1I<W!L87D@=&AE(%PB16UP='D@4W!A;5PB(&QI;FL@:6X@=&AE(&UE;G5B
M87(_(@IM<V=S='(@(E9I<R`G5/AM('/X<'!E;&MO<F<G+6MO<&QI;F<@:2!M
M96YY;&EN:F4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U,`HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@
M:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(E9I<R`G5/AM('/X<'!E;&MO<F<G
M+6MO<&QI;F<@:2!M96YY;&EN:F4_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")$:7-P;W-I=&EO
M;B(*;7-G<W1R(")6:7-I;F=S86QT97)N871I=B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA=&-H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$V"FUS
M9VED(")$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G
M<W1R(")):VMJ92!S:F5K:R!M87!P92AR*2!F;W(@;GD@92UP;W-T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E;F5R
M871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(B(*"B,Z
M(&QI8B])35`N<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@
M=&AA="!F;VQD97(_(@IM<V=S='(@(E9I;"!D=2!O<&YE(&1E;B!M87!P83\B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(S,@IM<V=I9"`B1&]N
M)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(V"FUS9VED(")$;VYE
M(@IM<V=S='(@(D9E<F1I9R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,@:6X@+GII<"!&
M;W)M870B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R
M<RYI;F,Z-3(*;7-G:60@(D1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@
M+GII<"!F:6QE*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR,`IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S
M='(@(DQA<W0@;F5D(&UA<'!E*'(I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D1O=VYL;V%D($9O;&1E
M<BAS*2!;+GII<"!F;W)M871=(@IM<V=S='(@(DQA<W0@;F5D(&UA<'!E*'(I
M(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO
M860@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z
M-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S
M='(@(DML861D(@H*(SH@9F]L9&5R<RYP:'`Z,SDR"B,L(&9U>GIY"FUS9VED
M(")$<F%F="!F;VQD97(B"FUS9W-T<B`B2VQA9&0M;6%P<&4Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T
M<R!F;VQD97(Z(@IM<V=S='(@(DML861D+6UA<'!E.B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,#@*;7-G:60@(D4M;6%I;"!!9&1R97-S(@IM<V=S
M='(@(D4M<&]S=&%D<F5S<V4B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S`Y"FUS
M9VED(")%3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z-S0*;7-G:60@(D524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T
M(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#(P
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ.0IM<V=I9"`B161I
M="(*;7-G<W1R(")%;F1R92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B161I="!";&%C:VQI<W0B"FUS9W-T
M<B`B4W9A<G1E;&ES="(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(D4M
M<&]S=&9I;'1E<B(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<V5A
M<F-H+VAE861E<BYI;F,Z,38*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E
M9FEN:71I;VX@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHR,PIM<V=I9"`B161I="!7:&ET96QI<W0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"B,L(&9U
M>GIY"FUS9VED(")%9&ET('EO=7(@8FQA8VML:7-T(@IM<V=S='(@(D5N9')E
M(&9I;'1E<G)E9VQA;F4@9&EN92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHQ,PIM<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(*;7-G
M<W1R(")%;F1R92!F:6QT97)R96=L86YE(&1I;F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#8Q"FUS9VED(")%9&ET('EO=7(@<')E9F5R96YC97,@
M9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C,*(RP@9G5Z>GD*
M;7-G:60@(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B16YD<F4@9FEL
M=&5R<F5G;&%N92!D:6YE(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR,SD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B12UP
M;W-T861R97-S92(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@
M)7,N(@IM<V=S='(@(D9J97)N82!A;&QE(&UE;&1I;F=A<B!F<N4@)7,N(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C(*;7-G:60@(D5M
M<'1Y($9O;&1E<BAS*2(*;7-G<W1R(")4^&T@;6%P<&4H<BDB"@HC.B!F;VQD
M97)S+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O
M;&1E<G,B"FUS9W-T<B`B5/AM(&UA<'!E*'(I(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y(%1R87-H(&9O;&1E
M<B(*;7-G<W1R(")4^&T@<_AP<&5L:V]R9R(*"B,Z(&QI8B])35`N<&AP.CDW
M,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@7U-P86TB"FUS9W-T<B`B5/AM('/X
M<'!E;&MO<F<B"@HC.B!L:6(O24U0+G!H<#HY-C8*(RP@9G5Z>GD*;7-G:60@
M(D5M<'1Y(%]4<F%S:"(*;7-G<W1R(")4^&T@<_AP<&5L:V]R9R(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ('1E;7!L871E<R]P9W`O;F]T86-T:79E
M+FEN8SHV"FUS9VED(")%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S
M='(@(E-LY2!PY2!01U`M9G5N:W-J;VYA;&ET970_(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHQ('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N
M:6YC.C8*(RP@9G5Z>GD*;7-G:60@(D5N86)L92!3+TU)344@9G5N8W1I;VYA
M;&ET>3\B"FUS9W-T<B`B4VSE('#E(%!'4"UF=6YK<VIO;F%L:71E=#\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS9VED(")%;F%B;&4@;65S
M<V%G92!P<F5V:65W<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#0R"FUS9VED(")%;F-R7WEP=&EO;B!/<'1I;VYS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3<@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U-PIM<V=I9"`B16YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#0*;7-G:60@(D5N9"!F;W)W
M87)D960@;65S<V%G92(*;7-G<W1R(")3;'5T="!V:61A<F5S96YD="!M96QD
M:6YG(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,T,0HC+"!F=7IZ>0IM<V=I9"`B
M16YD(&UE<W-A9V4B"FUS9W-T<B`B1V%M;&4@;65L9&EN9V%R(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C,S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M16YD(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")6:61A<F5S96YD92!M96QD
M:6YG87(@9G+E("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW
M,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P
M:')A<V4B"FUS9W-T<B`B4VMR:78@:6YN('!A<W-O<F1F<F%S92(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHY"B,L(&9U>GIY"FUS9VED
M(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(B"FUS
M9W-T<B`B4VMR:78@:6YN(&YA;6YE="!PY2!D:2!N>64@<_AP<&5L:V]R9R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@
M(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM
M<V=S='(@(E-K<FEV(&EN;B!N86UN970@<.4@9&D@;GEE(&ML861D+6UA<'!E
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR,PIM
M<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F
M;VQD97(B"FUS9W-T<B`B4VMR:78@:6YN(&YA;65T('#E(&1I(&YY92!M87!P
M92!F;W(@<V5N9'0@<&]S="(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E
M;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W
M('1R87-H(&9O;&1E<B(*;7-G<W1R(")3:W)I=B!I;FX@;F%M;F5T('#E(&1I
M(&YY92!S^'!P96QK;W)G(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*(RP@9G5Z
M>GD*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(DMR>7!T97(@;65L
M9&EN9R(*"B,Z(&UE<W-A9V4N<&AP.C$Y-"!C;VUP;W-E+G!H<#HQ,3,T('1H
M<F5A9"YP:'`Z-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5N=')Y
M(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B3W!P9OAR:6YG82!<(B5S7"(@=F%R="!L86=T('1I
M;"!A9')E<W-E8F]K82(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,S<V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X-@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@(D9E:6PB
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!C;VYN96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S`Y
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@
M(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("));FYS=&EL
M;&EN9V%R('9A<G0@;W!P9&%T97)T92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S@R"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMV
M87)T(#$U+B!M:6YU='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<Y
M"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DMV87)T(#,P+B!S
M96MU;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@Q"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B2W9A<G0@-2X@;6EN=71T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,PIM<V=I9"`B179E<GD@:&%L9B!H
M;W5R(@IM<V=S='(@(DMV87(@:&%L=F4@=&EM92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")+
M=F%R="!M:6YU='0B"@HC.B!F;VQD97)S+G!H<#HT-3<*(RP@9G5Z>GD*;7-G
M:60@(D5X<&%N9"(*;7-G<W1R(")6:7,@86QL92(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%>'!A;F0@06QL(@IM<V=S
M='(@(E9I<R!A;&QE(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R(")6:7,@
M86QL92!M87!P97(B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X<&%N
M9"!&;VQD97(B"FUS9W-T<B`B5FES(&UA<'!E(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHU,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(DMO;G1R
M;VQL97(@;F%M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8S"FUS
M9VED(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M
M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.#`*(RP@9G5Z>GD*;7-G:60@(D5X<&%N
M9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O
M;&1E<G,@=FEE=S\B"FUS9W-T<B`B571V:60@:&5I;&4@;6%P<&5S=')U:W1U
M<F5N(&D@;6%P<&5V:7-I;F<@<V]M('-T86YD87)D+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$T-"!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHQ.30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,C0U('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,#$*(RP@
M9G5Z>GD*;7-G:60@(D5X<&%N9&EN9R(*;7-G<W1R(")6:7,@86QL92(*"B,Z
M(&QI8B])35`N<&AP.CDX-"!L:6(O24U0+G!H<#HY.#8*(RP@9G5Z>GD*;7-G
M:60@(D9?971C:"!-86EL(@IM<V=S='(@(DAE;G0@92UP;W-T(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#0*;7-G:60@(D9E=&-H($UA:6PB"FUS9W-T<B`B2&5N
M="!E+7!O<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8Y"FUS9VED
M(")&971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")(
M96YT('!O<W0@:2!E:6=E('9I;F1A=6=E/R(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@;65S
M<V%G97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")"<G5K(&9I;'1E<G)E
M9VQA<B!V960@<.5L;V=G:6YG+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S
M86=E<R!F<F]M("5S(@IM<V=S='(@(D9J97)N82!A;&QE(&UE;&1I;F=A<B!F
M<N4@)7,N(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S(@IM
M<V=S='(@(E9I9&%R97-E;F1E(&UE;&1I;F=A<B!F<N4@)7,B"@HC.B!L:6(O
M1F5T8VAM86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&
M971C:&UA:6PN<&AP.C(X.0HC+"!F=7IZ>0IM<V=I9"`B1F5T8VAM86EL.B`B
M"FUS9W-T<B`B2&5N="!E+7!O<W0B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR
M.3$*(RP@9G5Z>GD*;7-G:60@(D9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S
M+B(*;7-G<W1R(")$=2!H87(@)7,@;GEE(&UE;&1I;F=A<BXB"@HC.B!L:6(O
M24U0+G!H<#HY.3`*(RP@9G5Z>GD*;7-G:60@(D9I7VQT97)S(@IM<V=S='(@
M(D9I;'1E<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P
M,B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHX,@HC+"!F=7IZ
M>0IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6QT97(B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D9I;'1E<B!/
M<'1I;VYS(@IM<V=S='(@(D%N9')E(&%L=&5R;F%T:78B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B1FEL=&5R
M(%-E='1I;F=S(@IM<V=S='(@(D9I;'1E<G)E9VQA<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,#`*(RP@9G5Z>GD*;7-G:60@(D9I;'1E<B!M97-S
M86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`B1FEL=')E<B!M
M96QD:6YG<VEN;FAA;&0@9F]R('5K=F5M<V]R9"XB"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")&:6QT
M97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T
M<B`B4$=0+7-T^'1T92!E<B!S;.5T="!A=B!PY2!D971T92!S>7-T96UE="XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S
M(@IM<V=S='(@(D9I;'1E<B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C
M=&EV92YI;F,Z,PHC+"!F=7IZ>0IM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E
M(@IM<V=S='(@(E!'4"!)2TM*12!A:W1I=B(*"B,Z(&QI8B]&:6QT97(N<&AP
M.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97)S.B`E<R!M86YA9V5M
M96YT('!A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ.#8*;7-G:60@(D9I;F0B"FUS9W-T<B`B1FEN;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*(RP@9G5Z>GD*;7-G:60@(D9I
M<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")&^')S=&4@<VED92(*"B,Z(&UA
M:6QB;W@N<&AP.C,T-0IM<V=I9"`B1FER<W0@4&%G92(*;7-G<W1R(")&^')S
M=&4@<VED92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0HC+"!F
M=7IZ>0IM<V=I9"`B1F]?<G=A<F0B"FUS9W-T<B`B5FED87)E<V5N9"(*"B,Z
M(&9O;&1E<G,N<&AP.C(V-B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O
M;F9I<FTN:'1M;#HU"FUS9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S
M+V9O;&1E<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA
M;'!A9V5S96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP
M86=E<V5L96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G
M<W1R(")-87!P96YA=FEG97)I;F<B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B1F]L9&5R(%-U;6UA<GDB"FUS9W-T<B`B
M1F5B<G5A<B(*"B,Z(&%C;"YP:'`Z,C0*;7-G:60@(D9O;&1E<B!S:&%R:6YG
M(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HV
M,@IM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B1F]R;6%T
M(&]F(&UE<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S
M<V%G97,@9&%T960@=&]D87DB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z
M-S@P('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R
M=V%R9"(*;7-G<W1R(")6:61A<F5S96YD(@H*(SH@8V]M<&]S92YP:'`Z-S8U
M"FUS9VED(")&;W)W87)D.B(*;7-G<W1R(")6:61A<F5S96YD.B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS-CD*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(@IM
M<V=S='(@(E9I9&%R97-E;F1T(&UE;&1I;F<B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E
M(&9R;VT@)7,B"FUS9W-T<B`B5FED87)E<V5N9&4@;65L9&EN9V%R(&9RY2`E
M<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*(RP@9G5Z>GD*
M;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R(")496YA<FEN
M9F]R;6%S:F]N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y-`IM
M<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT.#@*;7-G:60@(D9R964O0G5S>2!297%U97-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*
M;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*
M(RP@9G5Z>GD*;7-G:60@(D9R;U]M(@IM<V=S='(@(D9RY2(*"B,Z(&UE<W-A
M9V4N<&AP.C(V,R!T:')E860N<&AP.C$T.2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I9"`B1G)O
M;2(*;7-G<W1R(")&<N4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$X
M"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`B1G+E+6%D<F5S<V4B"@HC
M.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP:'`Z-S@Q"FUS9VED(")&=V0Z
M(@IM<V=S='(@(E93.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.30*(RP@9G5Z>GD*
M;7-G:60@(D9W9#H@(@IM<V=S='(@(E93.B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M.38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R=V%R
M9&5D($UE<W-A9V5S(@IM<V=S='(@(E9I9&%R97-E;F1T(&UE;&1I;F<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@*(RP@9G5Z>GD*;7-G:60@(D=E;F5R86P@3W!T:6]N
M<R(*;7-G<W1R(")"<G5K87)A;'1E<FYA=&EV(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C,W"B,L(&9U>GIY"FUS9VED(")'970@;VYL
M>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI(@IM<V=S='(@(DAE;G0@8F5R
M<F4@;GEE(&UE;&1I;F=A<B`H8F5R<F4@9F]R($E-05`I(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@
M(B(*"B,Z('1H<F5A9"YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")';R!T;R!-
M97-S86=E(@IM<V=S='(@(DYE<W1E(&UE;&1I;F<B"@HC.B!L:6(O24U0+G!H
M<#HT.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=O('1O(&%D9')E
M<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B3&5G9R!T:6P@861R
M97-S96)O:R`H)7,I(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM
M<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP
M.C4T-B!L:6(O1FEL=&5R+G!H<#HQ,#4@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z.34*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q
M-@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6
M:65W97(O<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,3@*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R
M-PIM<V=I9"`B2$5212(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q
M-PHC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA4
M34PB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,
M(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M(")-96QD:6YG<VAO=G5D(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP
M;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E
M(&-O;7!O<VEN9SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8V.`IM<V=I9"`B2&ED9&5N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-C<*(RP@9G5Z>GD*;7-G:60@(DAI9&1E;B!I;B!4
M:')E860@5FEE=R(*;7-G<W1R(")4<N5D=FES:6YG(@H*(SH@;6%I;&)O>"YP
M:'`Z,S8W"FUS9VED(")(:61E($1E;&5T960B"FUS9W-T<B`B4VMJ=6P@<VQE
M='1A(@H*(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")(:61E(%5N<W5B<V-R
M:6)E9"(*;7-G<W1R(")3:VIU;"!U+V%B;VYN96UE;G0B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B"FUS9W-T
M<B`B2/AG(@H*(SH@;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N<&AP.C<R-"!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H(%!R
M:6]R:71Y(@IM<V=S='(@(DCX9R!P<FEO<FET970B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T
M<B`B2/AG87-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X.`IM<V=I
M9"`B2&]W(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_(@IM
M<V=S='(@(DMO<FQE:7,@=FEL(&1U('9I<V4@=F5D;&5G9S\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")(;W<@=&\@
M871T<FEB=71E('%U;W1E9"!L:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(E!R
M969I:W,@<.4@<VET97)T92!L:6YJ97(@:2!E:70@<W9A<CHB"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$S-`IM<V=I9"`B24U!4"(*;7-G<W1R("))
M34%0(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-
M05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!397)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S<&]N
M9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$V-B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!
M4"!O=F5R(%-33"(*;7-G<W1R("))34%0(&]V97(@4U-,(@H*(SH@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(DE-05`@;W9E
M<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("))34%0
M(&]V97(@4U-,("AS:OAL=BUS:6=N97)T*2(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,38W"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I
M9VYE9"DB"FUS9W-T<B`B24U!4"!O=F5R(%-33"`H<VKX;'8M<VEG;F5R="DB
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!4"!S97)V
M97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(DE-05`L(&EK
M:VIE(%1,4R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z-#D*;7-G:60@
M(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+TE-
M4"YP:'`Z.#8V"FUS9VED("))3D)/6"(*;7-G<W1R("));FYB;VMS(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HT,3$*;7-G:60@(DEF('5S:6YG(%-33"!O
M<B!43%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L(&5X=&5N<VEO
M;B!L;V%D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O
M;&1E<G-?8V]N9FER;2YH=&UL.C$R"B,L(&9U>GIY"FUS9VED("))9B!Y;W4@
M8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@
M8F4@;&]S="$B"FUS9W-T<B`B06QL92!M96QD:6YG87(@:2!M87!P92AR*2!V
M:6P@8FQI('1A<'0A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T<B`B26=N;W)E<B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I9"`B26=N;W)E
M($%L;"(*;7-G<W1R("))9VYO<F5R(&%L;&4B"@HC.B!T96UP;&%T97,O<V%V
M96EM86=E+W-A=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,`HC+"!F=7IZ
M>0IM<V=I9"`B26UP;W)T(@IM<V=S='(@(E9I:W1I9R(*"B,Z('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C8U"FUS9VED("));7!O<G0@2V5Y(@IM<V=S='(@(DEM<&]R
M=&5R(&[X:VME;"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,SD*;7-G
M:60@(DEM<&]R="!+97EP86ER(@IM<V=S='(@(DEM<&]R=&5R(&[X:VME;'!A
M<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(W"B,L(&9U
M>GIY"FUS9VED("));7!O<G0@365S<V%G97,B"FUS9W-T<B`B5FEK=&EG92!M
M96QD:6YG87(B"@HC.B!P9W`N<&AP.C0R"FUS9VED("));7!O<G0@4$=0($ME
M>2(*;7-G<W1R("));7!O<G1E<B!01U`M;OAK:V5L(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHY,0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!E
M<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@(DEM<&]R=&5R('!E<G-O;FQE
M9R!P<FEV870@4$=0+6[X:VME;"(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T
M7VME>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'
M4"!+97DB"FUS9W-T<B`B26UP;W)T97(@<&5R<V]N;&5G('!R:79A="!01U`M
M;OAK:V5L(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHY"FUS
M9VED("));7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B
M26UP;W)T97(@<&5R<V]N;&5G(&]F9F5N=&QE9R!01U`M;OAK:V5L(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0*(RP@9G5Z>GD*;7-G
M:60@(DEM<&]R="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S(@IM<V=S
M='(@(DEM<&]R=&5R('!E<G-O;FQE9R!P<FEV870@4$=0+6[X:VME;"(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C0R"FUS9VED("));7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("))
M;7!O<G1E<B!O9F9E;G1L96<@;OAK:V5L(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC(%!'4"!+97DB
M"FUS9W-T<B`B26UP;W)T97(@;V9F96YT;&5G(%!'4"UN^&MK96PB"@HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`HC+"!F=7IZ>0IM<V=I
M9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(DEM<&]R=&5R
M(&]F9F5N=&QE9R!N^&MK96PB"@HC.B!S;6EM92YP:'`Z,38*(RP@9G5Z>GD*
M;7-G:60@(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@(DEM<&]R=&5R(&[X
M:VME;"(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z.0HC+"!F
M=7IZ>0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R("));7!O<G1E
M<B!N^&MK96PB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT
M;R!F;VQD97(@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,B!M
M86EL8F]X+G!H<#HW,S0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,38@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R
M(")6:6MT:6<B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS
M9VED("));7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B5FEK=&EG92!M96QD
M:6YG87(B"@HC.B!F;VQD97)S+G!H<#HQ-C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S
M='(@(D9J97)N82!A;&QE(&UE;&1I;F=A<B!F<N4@)7,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<W,PIM<V=I9"`B26X@4')O8V5S<R(*;7-G
M<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS.#0@;&EB+T9O;&1E<BYP:'`Z.#8@
M;&EB+T9O;&1E<BYP:'`Z,C$T(&QI8B])35`N<&AP.C,Q,PHC.B!L:6(O24U!
M4"]4<F5E+G!H<#HQ,30@;&EB+TE-05`O5')E92YP:'`Z,C$Y"FUS9VED("))
M;F)O>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR
M"B,L(&9U>GIY"FUS9VED("));F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T
M:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM<V=S='(@(DEN:VQU9&5R92!O<FEG
M:6YA;"!M96QD:6YG(&D@<W9A<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#@W"FUS9VED("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R
M97!L>3\B"FUS9W-T<B`B26YK;'5D97)E(&]R:6=I;F%L(&UE;&1I;F<@:2!S
M=F%R/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$S,`HC+"!F=7IZ>0IM<V=I
M9"`B26YF;R(*;7-G<W1R("))9VYO<F5R(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*
M;7-G<W1R("));F9O<FUA<VIO;B!O;2`E<R!O9F9E;G1L96<@;OAK:V5L(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED("));F9O<FUA=&EO
M;B!O;B!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("));F9O<FUA<VIO
M;B!O;2!P97)S;VYL96<@<')I=F%T(&[X:VME;"(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS
M9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(DEN9F]R;6%S:F]N(&]M('!E<G-O;FQE9R!O9F9E;G1L96<@;OAK:V5L
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY.`HC+"!F=7IZ>0IM<V=I9"`B26YL
M:6YE(@IM<V=S='(@(FEN9V5N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.CD*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!#97)T:69I8V%T
M92!(97)E(@IM<V=S='(@(E-E="!I;FX@;OAK:V5L(&AE<B(*"B,Z('1E;7!L
M871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R92(*;7-G<W1R("))
M;7!O<G1E<B!P97)S;VYL96<@<')I=F%T(%!'4"UN^&MK96PB"@HC.B!T96UP
M;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$P"B,L(&9U>GIY"FUS9VED("))
M;G-E<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("))
M;7!O<G1E<B!P97)S;VYL96<@;V9F96YT;&5G(%!'4"UN^&MK96PB"@HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4*(RP@9G5Z>GD*;7-G:60@
M(DEN<V5R="!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(DEM<&]R=&5R
M(&]F9F5N=&QE9R!01U`M;OAK:V5L(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C0Q,@IM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R
M('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU
M.#0@;6%I;&)O>"YP:'`Z-C(V"B,L(&9U>GIY"FUS9VED("));G9A;&ED($%D
M9')E<W,B"FUS9W-T<B`B12UP;W-T861R97-S92(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X
M(@IM<V=S='(@(E5G>6QD:6<@96MS=&5R;B!P;W-T:V%S<V4B"@HC.B!C;VUP
M;W-E+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!C:&%R
M86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R("(B"@HC.B!S
M;6EM92YP:'`Z.#(@<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K97DB"FUS
M9W-T<B`B56=Y;&1I9R!01U`M;OAK:V5L+B(*"B,Z('!G<"YP:'`Z,3DV"FUS
M9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS9W-T
M<B`B56=Y9&QI9R!P97)S;VYL96<@<')V870@4$=0+6[X:VME;"XB"@HC.B!P
M9W`N<&AP.C$W,0IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC
M(&ME>2XB"FUS9W-T<B`B56=Y;&1I9R!P97)S;VYL96<@;V9F96YT;&5G(%!'
M4"UN^&MK96PN(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M,@IM<V=I9"`B26YV97)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B2T(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T:"(*
M;7-G<W1R(").^&MK96QL96YG9&4B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO
M;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E
M;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED(")+97D@
M:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E
M;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P+FEN8SHS
M.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@
M:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C
M;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME
M>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,38*
M;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<N5K(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!-86EL8F]X
M(%!A9V4B"FUS9W-T<B`B4VES=&4@<VED92(*"B,Z(&UA:6QB;W@N<&AP.C,U
M.`IM<V=I9"`B3&%S="!086=E(@IM<V=S='(@(E-I<W1E('-I9&4B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#D*(RP@9G5Z>GD*;7-G
M:60@(DQI7VYK($%T=&%C:&UE;G1S(@IM<V=S='(@(E9E9&QE9V<B"@HC.B!A
M='1A8VAM96YT+G!H<#HS-"!L:6(O0V]M<&]S92YP:'`Z,3`V,PHC+"!F=7IZ
M>0IM<V=I9"`B3&EN:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B:61D96XN(@IM
M<V=S='(@(D9A;FX@:6YG96X@=F5D;&5G9R(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ,#@P"B,L('!H<"UF;W)M870*;7-G:60@(DQI;FMS('=I;&P@97AP:7)E
M(&]N("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#@R"FUS9VED("(B"B),:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@
M=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"`B
M"B)O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI
M8VET;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.#4*;7-G:60@(DQI<W1I;F<@:6X@=&AE($AE861E<B(*;7-G<W1R("),:7-T
M:6YG(&D@;65L9&EN9W-H;W9U9"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHS,`IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`B
M3&]K86P@<&]S=&MA<W-E.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-S0*(RP@9G5Z>GD*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DAA;F1L
M:6YG(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C4*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R("),;V=G(&EN;B(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O("5S
M(@IM<V=S='(@(DQO9V<@:6YN('1I;"`E<R(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,3,W"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R
M("),;V=G(&EN;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM<V=I
M9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B3W!P9^5V97(@=F5D(&EN;FQO9V=I
M;F<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.38*;7-G
M:60@(DQO=R(*;7-G<W1R("),878B"@HC.B!M97-S86=E+G!H<#HR.3D@;6%I
M;&)O>"YP:'`Z-S(W('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3,*
M;7-G:60@(DQO=R!0<FEO<FET>2(*;7-G<W1R("),878@<')I;W)I=&5T(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED("),
M;W=E<W0B"FUS9W-T<B`B3&%V87-T(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P
M<&QE9&]U8FQE+G!H<#HT-`HC+"!F=7IZ>0IM<V=I9"`B36%C:6YT;W-H($9I
M;&4B"FUS9W-T<B`B12UP;W-T9FEL=&5R(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W!A<W-P:')A<V4N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")-86EL(@IM<V=S
M='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R(")%+7!O<W1F:6QT
M97(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM
M<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I;&)O>"(*
M;7-G<W1R(")0;W-T:V%S<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$Q"B,L(&9U>GIY"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA
M>2!/<'1I;VYS(@IM<V=S='(@(E9I<VEN9W-A;'1E<FYA=&EV(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL
M($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")-87)K($%L
M;"!-97-S86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-2!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-87)K(&%S.B(*
M;7-G<W1R(")-87)K97(@<V]M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG
M('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`B365R:R!U;&EK92!N
M:7;E(&%V('-I=&5R:6YG(&UE9"!U;&EK92!F87)G87(_(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0P"B,L(&9U>GIY"FUS9VED(")-
M87)K(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI(@IM<V=S='(@(DAE
M;G0@8F5R<F4@;GEE(&UE;&1I;F=A<B`H8F5R<F4@9F]R($E-05`I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U.`IM<V=I9"`B36%R:R!S:6UP;&4@
M;6%R:W5P/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z-#8*;7-G:60@(DUA=&-H($%L;"!1=65R:65S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT,@IM<V=I9"`B36%T
M8V@@06YY(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4Q,PHC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!!='1A
M8VAM96YT(%-I>F4B"FUS9W-T<B`B5F5D;&5G9R(*"B,Z(&QI8B]A<&DN<&AP
M.C<Y"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!&;VQD97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-`IM<V=I
M9"`B36%X:6UU;2!N=6UB97(@;V8@871T86-H;65N=',@<F5A8VAE9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@Y
M"FUS9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(V
M"FUS9VED(")-965T:6YG($-A;F-E;&QA=&EO;B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<U"B,L(&9U>GIY"FUS9VED(")-
M965T:6YG($EN9F]R;6%T:6]N(@IM<V=S='(@(E1E;F%R:6YF;W)M87-J;VXB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@U"FUS9VED(")-965T
M:6YG(%!R;W!O<V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,3<*;7-G:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y.`IM<V=I9"`B365E=&EN
M9R!5<&1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8P,PIM<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS"B,L(&9U>GIY
M"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@(D]P;F4@;6%P<&4B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Q"B,L(&9U>GIY"FUS9VED(")-97-S
M86=E(@IM<V=S='(@(FUE;&1I;F=A<B!T:6PB"@HC.B!C;VUP;W-E+G!H<#HU
M-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O<V4N<&AP.C8T,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S:71I;VXB"FUS
M9W-T<B`B4VMR:78@;65L9&EN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,3<*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G<W1R(")-96QD:6YG<V1A
M=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#D@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#<@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@3W!T:6]N<R(*;7-G<W1R(")M96QD:6YG87(@=&EL(@H*(SH@<V5A
M<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@4V5A<F-H(@IM<V=S='(@(DUE
M;&1I;F=S<_AK(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I
M9"`B365S<V%G92!3:7IE(@IM<V=S='(@(DUE;&1I;F=S<W1O<FQE:6LB"@HC
M.B!M97-S86=E+G!H<#HS.#0*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM<V=S
M='(@(DUE;&1I;F=S:VIE;&1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8V"FUS9VED(")-97-S86=E(%9I97=I;F<B"FUS9W-T<B`B365L9&EN9W-V
M:7-I;F<B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8*;7-G:60@
M(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`B365L9&EN9W-F;&%G9R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#,*;7-G:60@(DUE<W-A9V4@9F]L
M9&5R<R(*;7-G<W1R(")-96QD:6YG<VUA<'!E<B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@
M9G)O;2`E<R(*;7-G<W1R(")-96QD:6YG<VUA<'!E<B(*"B,Z(&UA:6QB;W@N
M<&AP.C8V-PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!H87,@871T86-H;65N
M=',B"FUS9W-T<B`B4VQE='0@96ET('9E9&QE9V<N(@H*(SH@;6%I;&)O>"YP
M:'`Z-C4X"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E9"(*
M;7-G<W1R(")-96QD:6YG<V9E;'0B"@HC.B!M86EL8F]X+G!H<#HV-3,*(RP@
M9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(DUE;&1I
M;F=S9F5L="(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHS,PHC
M+"!F=7IZ>0IM<V=I9"`B365S<V%G92!M871C:&5S(@IM<V=S='(@(DUE;&1I
M;F=S9&%T;R(*"B,Z(&-O;7!O<V4N<&AP.C@R-"!C;VUP;W-E+G!H<#HX,S@*
M(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(DUE;&1I;F<@<V5N9'0N(@H*(SH@8V]M<&]S92YP:'`Z
M,3`X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365S<V%G92!S96YT
M('-U8V-E<W-F=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<R(*;7-G<W1R(")-
M96QD:6YG82!V87)T('-E;F1T+"!M96X@:6MK:F4@;&%G<F$@=&EL(@H*(SH@
M8V]M<&]S92YP:'`Z,3$T,R!C;VUP;W-E+G!H<#HQ,34X"FUS9VED(")-97-S
M86=E('-E;G0@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")-96QD:6YG('-E;F1T
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE<W-A
M9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@(DUE
M;&1I;F=A<B!P97(@<VED92!I('!O<W1B;VMS=FES:6YG+B(*"B,Z(&UA:6QB
M;W@N<&AP.C,R,@IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B;65L9&EN
M9V%R('1I;"(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I9"`B
M36]D:69Y(@IM<V=S='(@(DUO9&EF:7-E<F4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E>'!A;F0N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@
M=&AA;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@
M(DUO=F4B"FUS9W-T<B`B1FQY='0B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,38*(RP@9G5Z>GD*;7-G:60@(DUO=F4@9&]W;B(*
M;7-G<W1R(")F;'ET="!N960B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C$X"FUS9VED(")-;W9E('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD97(@
M86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`HC+"!F=7IZ>0IM<V=I9"`B
M36]V92!T;R!F;VQD97(B"FUS9W-T<B`B5F5L(&UA<'!E(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$T"B,L(&9U>GIY"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(F9L>71T(&]P<"(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(W"FUS9VED(")-=6QT:7!A<G0O86QT
M97)N871I=F4B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HW-B!T:')E860N
M<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@365S<V%G92!6:65W
M(@IM<V=S='(@(DUE;&1I;F=S=FES:6YG(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C4*;7-G:60@(DY/3D4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,@IM<V=I9"`B3D]412(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S."!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C@X"FUS9VED(").86UE(@IM<V=S='(@(DYA;6XB"@HC.B!P9W`N
M<&AP.C$Q,`IM<V=I9"`B3F%M92!A;F0O;W(@96UA:6P@8V%N(&YO="!B92!E
M;7!T>2(*;7-G<W1R(").86UN(&]G+V5L;&5R(&4M<&]S=&%D<F5S<V4@:V%N
M(&EK:VIE('9E<F4@=&]M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<W.`HC+"!F=7IZ>0IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(DAA
M;F1L:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-S@*;7-G:60@(DYE=F5R(@IM<V=S='(@(D%L9')I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4V,`HC+"!F=7IZ>0IM<V=I9"`B3F5V97(@<V%V92!A
M='1A8VAM96YT<R(*;7-G<W1R(")3;&5T="!E:70@=F5D;&5G9RXB"@HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`B
M3GDB"@HC.B!L:6(O24U0+G!H<#HU-C,*(RP@9G5Z>GD*;7-G:60@(DYE=R!&
M;VQD97(B"FUS9W-T<B`B3W!N92!M87!P92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX.`IM<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`B3GD@92UP;W-T
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$Y(&QI8B]";&]C:R]T<F5E
M7V9O;&1E<G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(").97<@365S<V%G92(*
M;7-G<W1R(").97-T92!M96QD:6YG(@H*(SH@;6%I;&)O>"YP:'`Z-S<V(&QI
M8B]-24U%+TAE861E<G,N<&AP.C$Y,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B3GEE(&UE;&1I;F=A
M<B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3D*;7-G:60@(DYE
M=R!M97-S86=E<R(*;7-G<W1R(").>64@;65L9&EN9V%R(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B3F5X="(*;7-G
M<W1R(").97-T92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G92(*;7-G<W1R(").97-T
M92!M96QD:6YG(@H*(SH@;6%I;&)O>"YP:'`Z,S4V"FUS9VED(").97AT(%!A
M9V4B"FUS9W-T<B`B3F5S=&4@<VED92(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS
M9VED(").;R(*;7-G<W1R(").96DB"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED
M(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y
M<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Y
M"FUS9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B26YG96X@;OAK
M;&%R(&D@;OAK:V5L:VYI<'!E(@H*(SH@;6%I;&)O>"YP:'`Z,S<U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*;7-G<W1R(").
M>64@;65L9&EN9V%R(@H*(SH@<&=P+G!H<#HQ,S<*;7-G:60@(DYO(%!'4"!P
M=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("));F=E;B!O9F9E;G1L96<@
M4$=0+6[X:VME;"!I;7!O<G1E<G0N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHX-`HC+"!F=7IZ>0IM<V=I9"`B3F\@4&5R<V]N86P@0V5R=&EF
M:6-A=&4@4')E<V5N="(*;7-G<W1R("));7!O<G1E<B!P97)S;VYL96<@<')I
M=F%T(%!'4"UN^&MK96PB"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S(Y"B,L(&9U
M>GIY"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`B2V]R<FEG97)T
M('1E:W-T(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ-0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS9W-T<B`B1&EN
M(&]F9F5N=&QE9V4@;OAK:V5L(@H*(SH@<VUI;64N<&AP.C$U,0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S
M='(@(DEN9V5N(&]F9F5N=&QE9R!01U`M;OAK:V5L(&EM<&]R=&5R="XB"@HC
M.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3`*;7-G:60@(DYO(&%T=&%C
M:&UE;G1S(&9O=6YD+B(*;7-G<W1R(")&86YN(&EN9V5N('9E9&QE9V<B"@HC
M.B!L:6(O0W)Y<'0O4TU)344N<&AP.C$T,`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M96UA:6P@:6YF;W)M871I;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2XB
M"FUS9W-T<B`B26YF;W)M87-J;VX@;VT@)7,@;V9F96YT;&5G(&[X:VME;"(*
M"B,Z(&%C;"YP:'`Z-S(@86-L+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M9F]L9&5R('-E;&5C=&5D+B(*;7-G<W1R(")I;F=A(&UA<'!E('9E;'0B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD97)S
M(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B(@H*
M(SH@9F]L9&5R<RYP:'`Z,C$X(&QI8B]&;VQD97(N<&AP.C4P,"!L:6(O1F]L
M9&5R+G!H<#HU-3`*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C:69I960B
M"FUS9W-T<B`B26YG96X@;6%P<&4H<BD@=F%R="!S<&5S:69I<V5R="(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#<*(RP@9G5Z>GD*;7-G:60@(DYO
M(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`B26MK:F4@<VQE
M='1A(&UE;&1I;F=A<B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#0*
M(RP@9G5Z>GD*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G
M97,B"FUS9W-T<B`B26MK:F4@<VQE='1A(&UE;&1I;F=A<B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HS,C4*;7-G:60@(DYO(&UE<W-A9V4@8F]D>2!T97AT(@IM
M<V=S='(@(DEN9V$@=&5K<W0@:2!M96QD:6YG<VMR;W!P(@H*(SH@;&EB+TUA
M:6QB;W@N<&AP.C,W,0HC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G97,@;6%T
M8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B26YG96X@;65L9&EN9V%R('-A
M;7-V87)A(&UE9"!S^&ME="!D:71T(@H*(SH@<&=P+G!H<#HQ.#D*;7-G:60@
M(DYO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T
M<B`B26YG96X@<&5R<V]N;&5G('!R:79A="!01U`M;OAK:V5L(&EM<&]R=&5R
M="XB"@HC.B!P9W`N<&AP.C$V-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U
M8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DEN9V5N('!E<G-O;FQE9R!O
M9F9E;G1L96<@4$=0+6[X:VME;"!I;7!O<G1E<G0N(@H*(SH@<VUI;64N<&AP
M.C(P,0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&5R<V]N86P@4R]-24U%(&-E<G1I
M9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B26YG96X@<&5R<V]N;&5G('!R
M:79A="!01U`M;OAK:V5L(&EM<&]R=&5R="XB"@HC.B!S<&5L;&EN9RYP:'`Z
M,C(P"FUS9VED(").;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C0X"FUS9VED(").;R!S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B26YG
M96X@<W1A=F5F96EL(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B26YG96X@
M9F]R<VQA9R(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-38T"FUS9VED(").
M;R!S=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@
M8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-C@@86-L+G!H<#HY
M-`HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<B!S<&5C:69I960N(@IM<V=S='(@
M(DEN9V5N(&UA<'!E*'(I('9A<G0@<W!E<VEF:7-E<G0B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S`Y"FUS9VED(").;VX@4&%R=&EC:7!A;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M,2!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,U('1E;7!L871E<R]P
M<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C8T"FUS9VED(").;VYE(@IM<V=S='(@(DEN9V5N(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDU"FUS9VED(").;W)M86PB
M"FUS9W-T<B`B3F]R;6%L(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Y"FUS9VED
M(").;W0@1&5L971E9"(*;7-G<W1R(")):VMJ92!S;&5T=&$B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$R('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM<V=S='(@(DEK:VIE
M(&ML861D(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHX('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3<*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-`IM<V=I9"`B3F]T($EM<&]R
M=&%N="(*;7-G<W1R(")):VMJ92!V:6MT:6<B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C(U"FUS9VED(").;W0@4&5R<V]N86PB"FUS9W-T
M<B`B26MK:F4@<&5R<V]N;&5G(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z,3,Y
M(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP="]334E-12YP:'`Z
M,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G<W1R("))
M:VMJ92!E:6X@9WEL9&EG(&]F9F5N=&QE9R!N^&MK96PN(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T960@;65S
M<V%G97,B"FUS9W-T<B`B26MK:F4@<VQE='1A(&UE;&1I;F=A<B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A
M;G0@;65S<V%G97,B"FUS9W-T<B`B26MK:F4@=FEK=&EG92!M96QD:6YG87(B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP
M.C<Q"FUS9VED(").;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I;64B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q-@HC+"!F
M=7IZ>0IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R(")3:71E<F5R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-PHC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R
M(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@
M9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB5&%L970@<.4@9V%M;&4@
M;6%P<&5R(&UE9"!S96YD="!P;W-T(.4@=&$@=F%R92!PY2!V960@;>5N861L
M96<@<VQE='1I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"B,L
M(&9U>GIY"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S
M('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB5&%L
M970@<.4@9V%M;&4@;6%P<&5R(&UE9"!S96YD="!P;W-T(.4@=&$@=F%R92!P
MY2!V960@;>5N861L96<@<VQE='1I;F<B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(U-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-34R"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S,*;7-G:60@(D]+
M(@IM<V=S='(@(D]+(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC
M.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0Y"B,Z('1E;7!L
M871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-#@*;7-G:60@(D]2(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,34*;7-G:60@(D]L
M9"!M97-S86=E<R(*;7-G<W1R(")'86UL92!M96QD:6YG87(B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z
M-3(*;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P=7)G960N
M(@IM<V=S='(@(D=A;6QE(&UA<'!E<B!M960@<V5N9'0@<&]S="!B;&ER('-L
M971T82XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D]N
M;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H
M96T_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U
M;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R(")696P@
M:W5N(&5I(&UA<'!E(&9O<B!D96YN92!O<&5R87-J;VYE;BXB"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U
M>GIY"FUS9VED(")/<&5N($9O7VQD97(B"FUS9W-T<B`B3W!N92!M87!P92(*
M"B,Z(&9O;&1E<G,N<&AP.C0R-PHC+"!F=7IZ>0IM<V=I9"`B3W!E;F5D($9O
M;&1E<B(*;7-G<W1R(")/<&YE(&UA<'!E(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<P-0IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS
M9W-T<B`B(@H*(SH@9F5T8VAM86EL+G!H<#HS,R!T96UP;&%T97,O9F5T8VAM
M86EL+W1O<"YI;F,Z,PHC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I
M;"YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B3W1H97(@36%I;"!!8V-O=6YT<R(*
M;7-G<W1R(")!;F1R92!K;VYT;V%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-3`*;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`B06YD<F4@
M86QT97)N871I=B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`Q
M"FUS9VED(")/=71B;W5N9"!397)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ-B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-C4*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`T(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(Y,`IM<V=I9"`B4$=0(@IM<V=S='(@(E!'
M4"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-PHC
M+"!F=7IZ>0IM<V=I9"`B4$=0($5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")0
M1U`M<VEG;F5R+RUK<GEP=&5R(&UE;&1I;F<B"@HC.B!C;VUP;W-E+G!H<#HS
M-3@*(RP@9G5Z>GD*;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S='(@(E!'4"UF
M96EL.B`E<R(*"B,Z(&-O;7!O<V4N<&AP.C,S-PIM<V=I9"`B4$=0($5R<F]R
M.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*
M;7-G<W1R(")01U`M9F5I;#H@5')E;F<@<&%S<V]R9&9R87-E(&9O<B!P97)S
M;VYL96<@<')I=F%T(&[X:VME;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30R"FUS9VED(")01U`@3W!T:6]N<R(*;7-G<W1R(")01U`@06QT97)N
M871I=B(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!087-S<&AR87-E($EN
M<'5T(@IM<V=S='(@(E!'4"!I;FYT87-T:6YG(&%V('!A<W-O<F1F<F%S92(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O
M;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B4W3X='1E(&9O<B!P97)S;VYL96<@4$=0+6[X
M:VME;'!A<B!K<F5V(&5I('-I:VME<B!W96(M:V]P;&EN9RXB"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(E!'4"!0
M=6)L:6,@2V5Y(%1E>'0B"FUS9W-T<B`B3V9F96YT;&5G(%!'4"UN^&MK96PB
M"@HC.B!P9W`N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B
M;&EC($ME>2!F;W(@7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"XB"FUS9W-T<B`B3V9F96YT;&5G(%!'4"UN^&MK96P@9F]R(%PB)7,@*"5S
M*5PB('9A<G0@;&%G="!T:6PN(@H*(SH@<&=P+G!H<#HR-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C
M8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(D]F9F5N=&QE9R!01U`M;OAK
M:V5L(&9O<B!<(B5S7"(@=F%R="!S;&5T=&$N(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T
M<B`B3V9F96YT;&5G(%!'4"UN^&MK96QR:6YG(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHX"FUS9VED(")01U`@4VEG;B!-97-S
M86=E(@IM<V=S='(@(E!'4"!3:6=N97(@;65L9&EN9R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.0IM<V=I9"`B4$=0(%-I9VXO
M16YC<GEP="!-97-S86=E(@IM<V=S='(@(E!'4"US:6=N97(O+6MR>7!T97(@
M;65L9&EN9R(*"B,Z('!G<"YP:'`Z,C`R"B,L(&9U>GIY"FUS9VED(")01U`@
M<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")/9F9E
M;G1L96<O<')I=F%T92!01U`M;OAK:V5L<&%R('9A<G0@;&%G="!T:6PN(@H*
M(SH@<&=P+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(E!'4"!P=6)L:6,@:V5Y
M('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B3V9F96YT;&5G+W!R:79A
M=&4@4$=0+6[X:VME;'!A<B!V87)T(&QA9W0@=&EL+B(*"B,Z('1E;7!L871E
M<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")01U`@<W5P<&]R="!I<R!D
M:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B4$=0+7-T^'1T92!E
M<B!S;.5T="!A=B!PY2!D971T92!S>7-T96UE="XB"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR,#@*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO
M="!C=7)R96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I
M<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E!'4"US
M=/AT=&4@97(@9F]R('1I9&$@:6MK:F4@86MT:78L('/E(&1E;B!D:6=I=&%L
M92!S:6=N871U<F5N(&MA;B!I:VMJ92`B"B)V97)I9FES97)A<W0N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDU"FUS9VED("(B"B)01U`@<W5P
M<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I
M<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B"B)01U`M<W3X
M='1E(&5R(&9O<B!T:61A(&EK:VIE(&%K=&EV+"!SY2!M96QD:6YG82!K86X@
M:6MK:F4@9&5K<GEP=&5R87-T+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR"FUS9VED("(B"B)01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD
M;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY
M("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H
M86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@4$=0("(*(F9E871U<F5S
M('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G<W1R(")0
M3U`S(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G:60@(E!/
M4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(E!/4#,@
M;W9E<B!34TPB"FUS9W-T<B`B24U!4"!O=F5R(%-33"(*"B,Z(&QI8B]&971C
M:&UA:6PO:6UA<"YP:'`Z,3(S"B,L(&9U>GIY"FUS9VED(")03U`S(&]V97(@
M4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B4$]0,R!O
M=F5R(%-33"`H<VKX;'8M<VEG;F5R="DB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$V.0IM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N
M960I(@IM<V=S='(@(E!/4#,@;W9E<B!34TP@*'-J^&QV+7-I9VYE<G0I(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L(&YO
M(%1,4R(*;7-G<W1R(")03U`S+"!I:VMJ92!43%,B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(E!A
M9V4@)60@;V8@)60B"FUS9W-T<B`B4VED92`E9"!A=B`E9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,#,*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER
M<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H('1H92!,87-T(%5N<V5E
M;B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S='(@(D1E;"AA<BDB
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS9VED(")087-S<&AR
M87-E(@IM<V=S='(@(E!A<W-O<F1F<F%S92(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R
M(")087-S;W)D9G)A<V4@*&EG:F5N*2(*"B,Z('-M:6UE+G!H<#HR,S4@<&=P
M+G!H<#HS,3`*;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A
M9&5D+B(*;7-G<W1R(")087-S;W)D9G)A<V4@=F%R="!L87-T82!U="XB"@HC
M.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA=&5S
M+W!G<"]P87-S<&AR87-E+FEN8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS
M9W-T<B`B4&%S<V]R9&9R87-E.B(*"B,Z('!G<"YP:'`Z,3$R"FUS9VED(")0
M87-S<&AR87-E<R!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(E!A<W-O<F1F
M<F%S87(@:V%N(&EK:VIE('9E<F4@=&]M;64B"@HC.B!P9W`N<&AP.C$Q-`IM
M<V=I9"`B4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(E!A<W-O
M<F1F<F%S87(@<V%M<W9A<F%R(&EK:VIE(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y
M+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y,@IM<V=I
M9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHT.`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")+^'ER('9E9&QI
M:V5H86QD<V]P97)A<VIO;F%R('9E9"!I;FYL;V=G:6YG/R(*"B,Z(&%C;"YP
M:'`Z-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES
M('5S97(@8V%N(&YO="!B92!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HT.3,@;6%I;&)O>"YP:'`Z-S`S('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHQ,`IM<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`B4&5R<V]N;&5G(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")097)S;VYA;"!);F9O
M<FUA=&EO;B(*;7-G<W1R(")097)S;VYL96<@:6YF;W)M87-J;VXB"@HC.B!P
M9W`N<&AP.C$R,`IM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&5R<V]N;&5G(%!'4"UN^&MK
M96QP87(@=F%R="!G96YE<F5R="XB"@HC.B!P9W`N<&AP.C$R-PIM<V=I9"`B
M4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(E!E<G-O;FQE9R!01U`M;OAK;&%R('9A<G0@<VQE='1A+B(*"B,Z('-M
M:6UE+G!H<#HR,#<*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L(%,O34E-12!C
M97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`B26YG96X@<&5R
M<V]N;&5G('!R:79A="!01U`M;OAK:V5L(&EM<&]R=&5R="XB"@HC.B!S;6EM
M92YP:'`Z,3,R"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!3+TU)344@:V5Y
M<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&5R<V]N;&5G(%!'
M4"UN^&ML87(@=F%R="!S;&5T=&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R,@IM<V=I9"`B4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E
M<&QI97,@86YD(&9O<G=A<F1S/R(*;7-G<W1R(")0;&%S<V5R('-I9VYA='5R
M(&;X<B!S=F%R(&]G('9I9&%R97-E;F1T/R(*"B,Z(&-O;7!O<V4N<&AP.C(U
M-`HC+"!F=7IZ>0IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G
M92(*;7-G<W1R(")6:7,@:2!M96QD:6YG<VMR;W!P(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Y.0IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O;B!N97<@
M;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O<G0@
M96UB961D960@(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I
M;F1O=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL("(*(G)E
M<75I<F4@82!P;'5G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(E-K<FEV(&EN;B!N
M86UN970@<.4@9&5N(&YY92!M87!P83HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C$P,B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$P-`IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H
M92!N97<@9F]L9&5R.B(*;7-G<W1R(")3:W)I=B!I;FX@;F%M;F5T('#E(&1E
M;B!N>64@;6%P<&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ,S<*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM
M<V=S='(@(E-K<FEV(&EN;B!D970@;GEE(&YA;6YE=#HB"@HC.B!T96UP;&%T
M97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO
M=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB
M96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM
M<V=S='(@(B(*(E-K<FEV(&EN;B!P87-S;W)D9G)A<V5N(&9O<B!D:6X@<')I
M=F%T92!01U`M;OAK:V5L+B!$=2!T<F5N9R!B97)R92#E('-K<FEV92`B"B)I
M;FX@9&5N;F4@<&%S<V]R9&9R87-E;B!E:6X@9V]N9R!P97(@24U0+?AK="XB
M"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL
M(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P
M97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HB4VMR:78@:6YN('!A<W-O<F1F
M<F%S96X@9F]R(&1I;B!P<FEV871E(%!'4"UN^&MK96PN($1U('1R96YG(&)E
M<G)E(.4@<VMR:79E("(*(FEN;B!D96YN92!P87-S;W)D9G)A<V5N(&5I;B!G
M;VYG('!E<B!)35`M^&MT+B(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G:60@
M(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN9R!Y
M;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI97,@
M04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I;F1O
M=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO=7(@
M;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C:V5R
M<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO
M9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S$*(RP@9G5Z>GD*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S='(@(E-K<FEV(&EN
M;B!D:71T(&)R=6MA<FYA;6X@;V<@<&%S<V]R9"(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(E-K<FEV(&EN;B!D:71T(&)R
M=6MA<FYA;6X@;V<@<&%S<V]R9"(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O
M24U0+G!H<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O
M<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B3W)D;F4@;W!P(&D@9FQE
M:7)T>61I9V4@96QL97(@=6=Y;&1I9V4@861R97-S97(N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8T,@IM<V=I9"`B(@HB4&QE87-E(')E=FEE
M=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@
M86X@86-T:6]N(&9R;VT@=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C$*;7-G:60@
M(E!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N
M>2!A8W1I;VYS+B(*;7-G<W1R(")696P@96D@;6%P<&4@9OAR(&1U(&OX>7)E
M<B!E:2!E;&QE<B!F;&5I<F4@:&%N9&QI;F=A<BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3`R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<V5L
M96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R(")6
M96P@;6EN<W0@96D@;6%P<&4@Y2!S^&ME(&DN(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]J879A<V-R:7!T+FEN8SHT,0IM<V=I9"`B4&QE87-E('-E;&5C="!A
M="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"XB"FUS9W-T<B`B5F5L(&UI
M;G-T(&5I(&UA<'!E(.4@<_AK92!I+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O
M;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B5F5L(&MU
M;B!E:2!M87!P92!F;W(@9&5N;F4@;W!E<F%S:F]N96XN(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"B,L(&9U>GIY"FUS9VED(")0
M;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z
M(@IM<V=S='(@(E9E;"!E;&QE<B!E;F1R92!R971T(&YE<W1E.B(*"B,Z(&-O
M;F9I9R]M;W1D+G!H<"YD:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,30*(RP@
M9G5Z>GD*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H
M97,@*"<M+2`G*3\B"FUS9W-T<B`B0G)U:R!S=')E:V%R("@G+2T@)RD@9OAR
M('-I9VYA='5R96X@9&EN+B(*"B,Z('-M:6UE+G!H<#HR-#$@<&=P+G!H<#HR
M-3<@9FEL=&5R<')E9G,N<&AP.C0P"FUS9VED(")0<F5F97)E;F-E<R!S=6-C
M97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B26YN<W1I;&QI;F=A<B!V87)T
M(&]P<&1A=&5R=&4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:6YC.C,*(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS9W-T<B`B1F]R
M<FEG92!S:61E(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@365S<V%G92(*;7-G<W1R(")&
M;W)R:6=E(&UE;&1I;F<B"@HC.B!M86EL8F]X+G!H<#HS-#<*;7-G:60@(E!R
M979I;W5S(%!A9V4B"FUS9W-T<B`B1F]R<FEG92!S:61E(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")0<FEN
M="(*;7-G<W1R(")3:W)I=B!U="(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C,X"FUS9VED(")0<FEO<FET>2(*;7-G<W1R(")0<FEO<FET
M970B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S8*(RP@
M9G5Z>GD*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@(E!R
M:79A="!N^&MK96PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34Y"FUS
M9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[
M(&1E9F%U;'0@=&\@3D\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4U.`IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H
M;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3`*;7-G:60@(E!R;W1O
M8V]L.B(*;7-G<W1R(")0<F]T;VMO;&PZ(@H*(SH@;&EB+T-R>7!T+U!'4"YP
M:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA
M<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R(")3=/AT=&4@9F]R(&]F9F5N=&QE
M9R!01U`M;OAK:V5L=&5N87(@97(@<VSE='0@878N(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<U]D96QE=&5D+FEN8SHX"B,L(&9U>GIY"FUS9VED(")0=7)?9V4@1&5L
M971E9"(*;7-G<W1R(")&:F5R;B!S;&5T=&$B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M7V1E;&5T960N:6YC.C@*;7-G:60@(E!U<F=E($1E;&5T960B"FUS9W-T<B`B
M1FIE<FX@<VQE='1A(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R
M(")3;&5T=&4@;6%P<&4H<BDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(E3X
M;2!S^'!P96QK;W)G82!K;W(@;V9T93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#`U"B,L(&9U>GIY"FUS9VED(")0=7)G92!M97-S86=E<R!I;B!4
M<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*
M;7-G<W1R(")&:F5R;B!M96QD:6YG87(@:2!S^'!P96QK;W)G82!S;VT@97(@
M96QD<F4@96YN(&1E='1E('1A;&5T('#E(&1A9V%R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X-@HC+"!F=7IZ>0IM<V=I9"`B4'5R9V4@;VQD(&UE
M<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(_(@IM<V=S='(@(D9J97)N(&=A
M;6QE(&UE;&1I;F=A<B!F<N4@<_AP<&5L:V]R9V$B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F
M;VQD97(N(@IM<V=S='(@(D9J97)N97(@)60@;65L9&EN9RAA<BD@9G+E('/X
M<'!E;&MO<F=A+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R
M87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@
M9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(D9J97)N97(@)60@;65L9&EN
M9RAA<BD@9G+E('/X<'!E;&MO<F=A+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q
M=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S
M.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M
M870*;7-G:60@(E%U;W1A('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T<B`B4VET97)E<B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B4F5?
M<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]396%R8V@N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!/;B(*
M;7-G<W1R(")-;W1T96ME('#E(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3@*(RP@
M9G5Z>GD*;7-G:60@(E)E8V5I=F5D(%-I;F-E(@IM<V=S='(@(DUO='1E:V4@
M<.4B"@HC.B!L:6(O4V5A<F-H+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4F5C
M96EV960@56YT:6PB"FUS9W-T<B`B36]T=&5K92!PY2(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B4F5D:7)E8U]T(@IM<V=S='(@(D]M9&ER:6=E<B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E
M8W0B"FUS9W-T<B`B3VUD:7)I9V5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C$Q,`IM<V=I9"`B4F5D:7)E8W0@365S<V%G92(*;7-G
M<W1R(")/;61I<FEG97(@;65L9&EN9R(*"B,Z(&-O;7!O<V4N<&AP.C<X-PIM
M<V=I9"`B4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S='(@(D]M9&ER:6=E
M<B!D96YN92!M96QD:6YG82(*"B,Z(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B
M4F5D:7)E8W1I;F<@9F%I;&5D+B(*;7-G<W1R(")+=6YN92!I:VMJ92!O;61I
M<FEG97)E+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X
M,PIM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")&<FES:R!O<'`B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S@T"FUS9VED(")2969R97-H($9O;&1E<B!6
M:65W<SHB"FUS9W-T<B`B1G)I<VL@;W!P(&UA<'!E=FES:6YG87(Z(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.2!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C0*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R
M(")/<'!D871E<B!V:7-I;F<B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D
M+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R(")/<'!D871E<B!V
M:7-I;F<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(V(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU-#4*;7-G:60@(E)E;65M8F5R('1H92!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-SD*;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I
M97<B"FUS9W-T<B`B2'5G<R!S:7-T92!V:7-I;F<B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T92!-86EL8F]X
M.B(*;7-G<W1R(")%:W-T97)N('!O<W1K87-S93HB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M
M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,#4*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!S;W5R8V4B
M"FUS9W-T<B`B9FIE<FX@:VIE;&1E(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B4F5N86UE($9O;&1E<BAS
M*2(*;7-G<W1R(")':2!N>71T(&YA;6X@=&EL(&UA<'!E(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5N86UE('-E
M;G0M;6%I;"!F;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R
M(")%;F1R92!N86UN('#E(&UA<'!E(&9O<B!S96YD="!P;W-T('9E9"!S=&%R
M=&5N(&%V(&WE;F%D96XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT-34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL
M960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@96YD<F4@;F%M;B!PY2!<(B5S7"(@=&EL(%PB)7-<(BX@1&5T
M=&4@97(@:W9A('1E;F%R96X@<V$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(E)E<&Q?>2!T
M;R!,:7-T(@IM<V=S='(@(E-V87(@=&EL(&QI<W1E(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H
M.B(*;7-G<W1R(")%<G-T871T(&UE9#HB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`B
M4W9A<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0P.0HC+"!F=7IZ>0IM<V=I9"`B4F5P;'D@
M4V5N="XB"FUS9W-T<B`B4W9A<BUT:6PB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*
M;7-G<W1R(")3=F%R('1I;"!A;&QE(@H*(SH@8V]M<&]S92YP:'`Z-S,S"FUS
M9VED(")297!L>2!T;R!!;&PZ(@IM<V=S='(@(E-V87(@=&EL(&%L;&4Z(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$P"FUS
M9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@(E-V87(@=&EL(&QI<W1E(@H*
M(SH@8V]M<&]S92YP:'`Z-S,U"FUS9VED(")297!L>2!T;R!,:7-T.B(*;7-G
M<W1R(")3=F%R('1I;"!L:7-T93HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O
M(%]!;&PB"FUS9W-T<B`B4W9A<B!T:6P@86QL92(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S
M-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED(")297!L
M>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,U"FUS9VED(")297!L>2!W:71H
M(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-`IM<V=I9"`B4F5P;'D@=VET
M:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!M97-S86=E+G!H<#HR-C<*(RP@9G5Z>GD*;7-G:60@(E)E<&QY+51O
M(@IM<V=S='(@(E-V87(@=&EL.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`Y
M"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(E-V87(@=&EL.B`B"@HC.B!C
M;VUP;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*;7-G<W1R(")3=F%R.B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS."!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR-@HC+"!F=7IZ>0IM<V=I
M9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S='(@(E)A<&]R=&5R('-O;2!S
M^'!P96QP;W-T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C,U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(S"FUS
M9VED(")297!O<G0@87,@4W!A;2(*;7-G<W1R(")287!O<G1E<B!S;VT@<_AP
M<&5L<&]S="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X
M,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS
M9W-T<B`B0F4@;VT@<F5T=7)K=FET=&5R:6YG(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4X-0IM<V=I9"`B4F5Q=65S="!D96QI=F5R>2!C;VYF:7)M
M871I;VX_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-S,*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS
M9W-T<B`B0F4@;VT@<F5T=7)K=FET=&5R:6YG(@H*(SH@;6%I;&)O>"YP:'`Z
M,3@Y"FUS9VED(")297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.3<*;7-G:60@
M(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z,30S('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHR-@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q"FUS9VED(")2
M97-E="(*;7-G<W1R(").=6QL<W1I;&PB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3$U"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R(")':F5N;W!P=&$B
M"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")297-U;64@>6]U<B!S97-S
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O(%PB365S<V%G92!#
M;VUP;W-I=&EO;EPB(@IM<V=S='(@(E-K<FEV(&UE;&1I;F<B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C,Q('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,@HC+"!F=7IZ>0IM<V=I9"`B4F5T
M=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`B2&5N="!E+7!O<W0B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E
M<G,O;F]T86-T:79E+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$P,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T
M:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ-S,*(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T
M;R!/<'1I;VYS(@IM<V=S='(@(D)R=6MA<F%L=&5R;F%T:78B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S$X"FUS9VED("(B"B)2971U<FX@=&\@=&AE
M(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C
M;W!Y:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B(@HB1^4@=&EL8F%K92!T:6P@
M<&]S=&)O:W-L:7-T82!E='1E<B#E(&AA('-L971T82P@9FQY='1A(&5L;&5R
M(&MO<&EE<G0@96D@(@HB;65L9&EN9S\B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C@X"FUS9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,C,W"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS
M9VED(")3+TU)344B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M96YC<GEP=%]L:7-T+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5N
M8W)Y<'0@365S<V%G92(*;7-G<W1R(")+<GEP=&5R(&UE;&1I;F<B"@HC.B!C
M;VUP;W-E+G!H<#HS.30*;7-G:60@(E,O34E-12!%<G)O<CH@(@IM<V=S='(@
M(B(*"B,Z(&-O;7!O<V4N<&AP.C,W,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%
M($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@
M:V5Y+B(*;7-G<W1R(")01U`M9F5I;#H@5')E;F<@<&%S<V]R9&9R87-E(&9O
M<B!P97)S;VYL96<@<')I=F%T(&[X:VME;"XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34Q"B,L(&9U>GIY"FUS9VED(")3+TU)344@3W!T:6]N<R(*
M;7-G<W1R("),86=R92!A;'1E<FYA=&EV(@H*(SH@<VUI;64N<&AP.C0Y"B,L
M(&9U>GIY"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R
M(")01U`@:6YN=&%S=&EN9R!A=B!P87-S;W)D9G)A<V4B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C4T"B,L(&9U>GIY"FUS9VED(")3+TU)344@
M4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R(")3=/AT=&4@9F]R('!E<G-O;FQE9R!0
M1U`M;OAK:V5L<&%R(&MR978@96D@<VEK:V5R('=E8BUK;W!L:6YG+B(*"B,Z
M('-M:6UE+G!H<#HQ-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E,O
M34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D
M96QE=&5D+B(*;7-G<W1R(")/9F9E;G1L96<@4$=0+6[X:VME;"!F;W(@7"(E
M<UPB('9A<G0@<VQE='1A+B(*"B,Z('-M:6UE+G!H<#HQ-C(*(RP@9G5Z>GD*
M;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB
M"FUS9W-T<B`B3V9F96YT;&5G+W!R:79A=&4@4$=0+6[X:VME;'!A<B!V87)T
M(&QA9W0@=&EL+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`*
M(RP@9G5Z>GD*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R
M(")/9F9E;G1L96<@4$=0+6[X:VME;')I;F<B"@HC.B!S;6EM92YP:'`Z,C$Q
M"B,L(&9U>GIY"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I
M<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(D]F9F5N=&QE9R]P<FEV
M871E(%!'4"UN^&MK96QP87(@=F%R="!L86=T('1I;"XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"B,L(&9U>GIY"FUS9VED
M(")3+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(E!'4"!3:6=N97(@;65L
M9&EN9R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z
M,30*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G
M92(*;7-G<W1R(")01U`M<VEG;F5R+RUK<GEP=&5R(&UE;&1I;F<B"@HC.B!T
M96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHT"B,L(&9U>GIY"FUS9VED
M(")3+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB
M"FUS9W-T<B`B4$=0+7-T^'1T92!E<B!S;.5T="!A=B!PY2!D971T92!S>7-T
M96UE="XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T,0HC+"!F
M=7IZ>0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L
M>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92`B"B)D
M96-R>7!T960N(@IM<V=S='(@(B(*(E!'4"US=/AT=&4@97(@9F]R('1I9&$@
M:6MK:F4@86MT:78L('/E(&UE;&1I;F=A(&MA;B!I:VMJ92!D96MR>7!T97)A
M<W0N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S,*;7-G:60@
M(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT
M96YT<R!O9B!T:&ES('-I9VYE9"!M97-S86=E(&-A;B!N;W0@(@HB8F4@9&ES
M<&QA>65D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C$T-@HC+"!F=7IZ>0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@
M;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L
M92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB4$=0+7-T^'1T92!E
M<B!F;W(@=&ED82!I:VMJ92!A:W1I=BP@<^4@9&5N(&1I9VET86QE('-I9VYA
M='5R96X@:V%N(&EK:VIE("(*(G9E<FEF:7-E<F%S="XB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T
M(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@
M8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@
M=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E
M("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C`U"FUS9VED(")33510(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C(U-0HC+"!F=7IZ>0IM<V=I9"`B4U]U8FIE8W0B
M"FUS9W-T<B`B16UN92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,V,PHC+"!F=7IZ>0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G
M<W1R("),86=R92!E:6X@:V]P:2!I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")385]V92!A
M<R(*;7-G<W1R("),86=R92!S;VTB"@HC.B!S96%R8V@N<&AP.C,Q-B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*(RP@9G5Z>GD*;7-G:60@
M(E-A=F4B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE;G1S('=I
M=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@(E-A=F4@1')A9G0B"FUS
M9W-T<B`B3&%G<F4@:VQA9&0B"@HC.B!S879E:6UA9V4N<&AP.C0R"B,L(&9U
M>GIY"FUS9VED(")3879E($EM86=E(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z
M(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,#0*;7-G:60@(E-A=F4@26UA9V4@
M:6X@1V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z-3D@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#`*(SH@
M=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,3(@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$T.`HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z
M,3,*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("),86=R92!A;'1E<FYA
M=&EV(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"B,L
M(&9U>GIY"FUS9VED(")3879E(%-T871I;VYE<GDB"FUS9W-T<B`B3&%G<F4@
M86QT97)N871I=B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PHC+"!F=7IZ
M>0IM<V=I9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B3&%G<F4@:VQA9&0B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G
M:60@(E-A=F4@87,B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W,@IM
M<V=I9"`B4V%V92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E
M9F%U;'0@861D<F5S<R!B;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@87,@82!V
M:7)T=6%L(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(S,`HC+"!F=7IZ>0IM<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM
M<V=S='(@(DQA9W)E('-E;F1T('!O<W0B"@HC.B!C;VUP;W-E+G!H<#HQ,C(W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I;&5D
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R(")+
M=6YN92!I:VMJ92!L86=R92!K;&%D9"X@1&5T=&4@97(@:W9A('1E;F%R96X@
M<V$Z("5S(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M.3D@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O0FQO
M8VLO=')E95]F;VQD97)S+G!H<#HT,0IM<V=I9"`B4V5A<F-H(@IM<V=S='(@
M(E/X:R(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ."!T96UP
M;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")396%R8V@@)7,B"FUS9W-T<B`B4_AK(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($]P
M=&EO;G,B"FUS9W-T<B`B3&%G<F4@86QT97)N871I=B(*"B,Z('-E87)C:"YP
M:'`Z,C8U"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R(")3^&ME<F5S
M=6QT870B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$T('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E96XB"FUS
M9W-T<B`B3&5S="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M.0IM<V=I9"`B4V5L96-T(@IM<V=S='(@(E9E;"(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHW,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M($%N;W1H97(@06-C;W5N="(*;7-G<W1R(")696P@96EN(&MO;G1O(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(E9E;"!E:6X@:V]N=&\B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(E9E;"!A;&QE(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$W"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@82!S=&%T:6]N97)Y.B(*;7-G<W1R(")696P@96EN(&MO;G1O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E
M87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R(")696P@:VIE;&1E<B!F
M;W(@861R97-S96)O:R!T:6P@Y2!L96=G92!T:6P@;V<@<_AK92!E='1E<B!A
M9')E<W-E<B!I+B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#@*
M;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5F5L(&%L;&4B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N(@IM<V=S='(@(E9E;"!R96MK96;X;&=J92!PY2!A9')E
M<W-E8OAK97(@Y2!S^&ME(&D@=F5D(&MO;G1R;VQL(&%V(&%D<F5S<V5R+B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(Q
M"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R(")696P@96EN(&MO
M;G1O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I9"`B
M4V5L96-T(&YO;F4B"FUS9W-T<B`B5F5L(&EN9V5N(@H*(SH@=&5M<&QA=&5S
M+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.CD*;7-G:60@(E-E;&5C="!T:&4@
M9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHR,0IM<V=I
M9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P.0HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T960@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`B5F%L
M9&4@861R97-S96+X:V5R.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`T"B,L(&9U>GIY
M"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R(")496YA
M<FEN9F]R;6%S:F]N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"FUS9VED
M(")396YD($UE<W-A9V4B"FUS9W-T<B`B4V5N9"!M96QD:6YG(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<P,PIM<V=I9"`B4V5N9"!R96%D(')E8V5I
M<'0@=VAE;B!R97%U97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B(@H*
M(SH@9F]L9&5R<RYP:'`Z,SDW"B,L(&9U>GIY"FUS9VED(")396YT(&UA:6P@
M9F]L9&5R(@IM<V=S='(@(DUA<'!E(&9O<B!S96YD="!P;W-T.B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,S@*;7-G:60@(E-E
M;G0@;6%I;"!F;VQD97(Z(@IM<V=S='(@(DUA<'!E(&9O<B!S96YD="!P;W-T
M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS9W-T<B`B5&5N87(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E
M<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E1E;F%R:6YF;W)M
M87-J;VXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C,*
M;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B5&5N87(Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@<')E9F5R96YC97,@9F]R('=H
M870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N
M(@IM<V=S='(@(B(*(E-E="!I;FYS=&EL;&EN9V%R(&9O<B!K=F$@<V]M('-K
M:F5R(&[E<B!D=2!F;'ET=&%R(&]G('-L971T87(@;65L9&EN9V%R+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@6"U0
M<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S
M='(@(E-E="!8+5!R:6]R:71Y+6UE;&1I;F=S:&]V=60@;N5R(&5I;B!S:W)I
M=B!M96QD:6YG87(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q"B,L
M(&9U>GIY"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(DUA<'!E<B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B
M4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(DUA<'!E(&9O<B!S96YD="!P
M;W-T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4VAA
M<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V.0IM<V=I9"`B(@HB
M4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X="!B92!S:&]W;B!O
M<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E("(*(G1O9V=L960@96%S
M:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B4VAO=6QD('1H
M92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@
M4$=0(&1A=&$_(@IM<V=S='(@(E9I;"!D=2!S^&ME(&=J96YN;VT@;65L9&EN
M9W-K<F]P<&5N(&9O<B!01U`M9&%T83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$S"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E
M(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`B(@HB4VMA
M;"!V:6YD875G970@9F]R('-K<FEV(&UE;&1I;F<@;'5K:V%S="!E='1E<B!A
M="!D=2!H87(@;&%G<F$@96EN(&ML861D/R(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHT"B,L(&9U>GIY"FUS9VED(")3:&]U;&0@>6]U<B!01U`@<'5B
M;&EC(&ME>2!T;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E
M9F%U;'0_(@IM<V=S='(@(B(*(E9I;"!D=2!L96=G92!V960@9&EN(&]F9F5N
M=&QE9V4@4$=0+6[X:VME;"!I(&UE;&1I;F=A;F4@9&EN92!S;VT@<W1A;F1A
M<F0_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@HC+"!F=7IZ
M>0IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")6:7,@86QL92!M
M96QD:6YG<VAO=G5D(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI
M;F,Z-C<*;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B5FES(&%L
M;&4@;65L9&EN9W-H;W9U9"(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM<V=I9"`B
M4VAO=R!$96QE=&5D(@IM<V=S='(@(E9I<R!S;&5T=&$B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D
M($AE861E<G,B"FUS9W-T<B`B5FES(&%V9W)E;G-A(&UE;&1I;F=S:&]V=60B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW,`IM<V=I9"`B
M4VAO=R!-86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T<B`B5FES(&EN
M9F]R;6%S:F]N(&]M(&4M<&]S=&QI<W1E(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!/;FQY(%-U8G-C
M<FEB960@1F]L9&5R<R(*;7-G<W1R(")!8F]N;F5R92!PY2!M87!P92AR*2(*
M"B,Z(&9O;&1E<G,N<&AP.C(Y.`IM<V=I9"`B4VAO=R!5;G-U8G-C<FEB960B
M"FUS9W-T<B`B5FES('4O86)O;FYE;65N="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV,#@*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I
M<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,#(*(RP@9G5Z>GD*;7-G
M:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S='(@
M(E9I<R!T96EK;F9O<FML87)I;F<@:2!P;W-T:V%S<V5V:7-I;F<N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T,`IM<V=I9"`B4VAO=R!P<F5V:65W
M<R!F;W(@=6YR96%D(&UE<W-A9V5S(&]N;'D_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#@*;7-G:60@(E-H;W<@<')E=FEE=W,@
M:6X@=&]O;'1I<',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-S<*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T
M:&4@;65N=6)A<C\B"FUS9W-T<B`B5FES($AE;G0@<&]S="UI:V]N970@:2!M
M96YY;&EN:F4_(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDU"B,L
M(&9U>GIY"FUS9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B5FES(&%V
M9W)E;G-A(&UE;&1I;F=S:&]V=60B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z-30*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(&9I;'1E<B!I
M8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R(")6:7,@2&5N="!P;W-T+6EK
M;VYE="!I(&UE;GEL:6YJ93\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,C@*;7-G:60@(E-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O;&1E
M<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-@HC
M+"!F=7IZ>0IM<V=I9"`B4VAO=VXB"FUS9W-T<B`B0G)U;B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#(*(RP@9G5Z>GD*
M;7-G:60@(E-I7WIE(@IM<V=S='(@(E-T;W)L96EK(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;&5G96YD+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B4VEG;F5D
M(@IM<V=S='(@(E-T;W)L96EK(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B4W1O<FQE:6LB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q
M"FUS9VED(")3;W)T(&)Y($%R<FEV86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R
M="!B>2!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@
M1G)O;2!!9&1R97-S(@IM<V=S='(@(D9RY2UA9')E<W-E(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT,0HC+"!F=7IZ>0IM
M<V=I9"`B4V]R="!B>2!-97-S86=E(%-I>F4B"FUS9W-T<B`B365L9&EN9W-S
M=&]R;&5I:R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G
M<W1R(")4;VUT(&5M;F4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y(%1H<F5A
M9"(*;7-G<W1R(")4<N5D(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!4;R!!
M9&1R97-S(@IM<V=S='(@(D9RY2UA9')E<W-E(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-P86US96QE8W0N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")3<&%M(&9O
M;&1E<CHB"FUS9W-T<B`B4_AP<&5L:V]R9SHB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M<R(*;7-G<W1R(")3<&5S:6%L=&5I:VXB"@HC.B!S96%R8V@N<&AP.C$S,PIM
M<V=I9"`B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N(&YO="!B92!E9&ET
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,T,PIM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`B4W1A=F5K;VYT
M<F]L;"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM
M<V=I9"`B4W!E;&P@0VAE8VME<B(*;7-G<W1R(")3=&%V96MO;G1R;VQL(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU-@IM<V=I9"`B4W!E;&P@8VAE8VL@
M8V]M<&QE=&4B"FUS9W-T<B`B4W1A=F5K;VYT<F]L;"!F97)D:6<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Q"FUS9VED(")3<&5L;&EN9R!E<G)O
M<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R(")3
M=&%V969E:6P@<&5R('-K:F5R;6)I;&5T92!V960@<W1A=F5K;VYT<F]L;"XB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$R(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-3(*(RP@9G5Z>GD*;7-G:60@(E-T87)T(@IM<V=S
M='(@(E-T871U<R(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q,0IM<V=I9"`B
M4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@;F%M93HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS
M9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U<R(*"B,Z(&QI8B]-24U%+T-O
M;G1E;G1S+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(E-T<FEP($%T=&%C:&UE
M;G0B"FUS9W-T<B`B5F5D;&5G9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*(RP@
M9G5Z>GD*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(D5M;F4B"@HC.B!M97-S
M86=E+G!H<#HR-C@@=&AR96%D+G!H<#HQ-3`@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM<V=I9"`B
M4W5B:F5C="(*;7-G<W1R(")%;6YE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDR,`IM<V=I9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R(")%;6YE9F5L
M="(*"B,Z('-E87)C:"YP:'`Z,S$X('1E;7!L871E<R]S879E:6UA9V4O<V%V
M96EM86=E+FEN8SHQ.`HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI
M;F,Z,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,0IM<V=I9"`B
M4W5B;6ET(@IM<V=S='(@(E-E;F0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E<BAS*2(*
M;7-G<W1R(")!8F]N;F5R92!PY2!M87!P92AR*2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,S@P(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X
M.0HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX-PIM<V=I9"`B4W5C
M8V5S<R(*;7-G<W1R(")3=6MS97-S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G<W1R(")&
M;W)S;&%G(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V,B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(")3=6UM87)Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,"!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#,*;7-G:60@(E-W:71C
M:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@=&\@2%1-
M3"!C;VUP;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!P;&%I;B!T97AT
M(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0Q.0HC+"!F=7IZ>0IM<V=I9"`B5&5?>'0B"FUS9W-T
M<B`B5&5K<W0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8Y"FUS
M9VED(")496YT871I=F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3DQ"FUS9VED(")496YT871I=F5L>2!!8V-E<'0@<F5Q
M=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S8Q"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R("(B"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O9B!397)V:6-E(&9I;&4@;F]T
M('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G<W1R(")6:6QKY7(@9F]R('1E
M;F5S=&$M9FEL82!I:VMJ92!S<&5S:69I<V5R="!I(&-O;F8N<&AP(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,P"FUS9VED(")497AT
M(@IM<V=S='(@(E1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU
M-`IM<V=I9"`B5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U
M;&0@8F4@;&EN:V5D.B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C4S,@IM<V=I9"`B(@HB5&AE($E-05`@<V5R=F5R(&1O97,@;F]T(&%P
M<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A=&EO;B!M971H;V0@(@HB
M<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O
M=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R
M:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N
M<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S
M;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RXB"FUS9W-T<B`B(@H*
M(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(")+;VYT;V5N(%PB)7-<(B!V87)T('-L971T82XB"@HC.B!F971C:&UA:6QP
M<F5F<RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@
M7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")+;VYT;V5N(%PB)7-<
M(B!V87)T(&QA9W)A+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C0S"B,L(&9U>GIY
M"FUS9VED(")4:&4@871T86-H;65N="!W87,@;F]T(&9O=6YD+B(*;7-G<W1R
M(")&86YN(&EN9V5N('9E9&QE9V<B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-CD*;7-G:60@(E1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C;VUP
M;W-E7W=I;BYJ<SHS-PIM<V=I9"`B(@HB5&AE(&-O;7!O<V4@=VEN9&]W(&-A
M;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W
M<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#(*;7-G:60@(E1H
M92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+B(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N
M=&UA:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&-U<G)E;G0@9F]L9&5R*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M960@=&\@
M7"(E<UPB+B(*;7-G<W1R(").86UN970@<.4@9VIE;&1A;F1E(&UA<'!E*'(I
M(%PB)7-<(B!V:6P@8FQI(&5N9')A('1I;"!<(B5S7"(N(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES
M="!O9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N
M;W0@8F4@<F5T<FEE=F5D(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B965N('-A
M=F5D('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,3,Y"FUS9VED(")4:&4@979E;G0@=V%S
M(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I96QD(%PB)7-<(B!C86XG="!B92!E>'!A;F1E9"XB
M"FUS9W-T<B`B261E;G1I=&5T96X@7"(E<UPB('9A<G0@<VQE='1A+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9F]L9&5R(%PB)7-<(B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(")-87!P82!<
M(B5S7"(@96MS:7-T97)E<B!A;&QE<F5I92(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C$V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@9F]L9&5R(%PB)7-<
M(B!C;VYT86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET
M(&UA>2!C875S92`B"B)P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).86UN970@<.4@;6%P<&$@
M7"(E<UPB(&EN;F5H96QD('5L;W9L96=E('1E:6MN+B!$971T92!K86X@<VMA
M<&4@<')O8FQE;2X@(@HB2V]N=&%K="!D:6X@<WES=&5M861M:6YI<W1R871O
M<BXB"@HC.B!L:6(O1F]L9&5R+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&-R96%T960@8G5T('EO=2!W97)E
M(&YO="!S=6)S8W)I8F5D('1O(&ET+B(*;7-G<W1R(")-87!P82!<(B5S7"(@
M=F%R="!O<'!R971T82P@;65N(&1U(&%B;VYN97)E<B!I:VMJ92!PY2!D96XN
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N
M;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N(@IM<V=S='(@(DUA<'!A(%PB)7-<
M(B!V87)T('-L971T82P@;65N(&1U(&%B;VYN97)E<B!F<F%M;&5I<R!PY2!D
M96XN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@8W)E871E9"X@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")-87!P82!<(B5S7"(@
M=F%R="!I:VMJ92!O<'!R971T82X@1&5T=&4@97(@:W9A('1E;F%R96X@<V$B
M"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@9&5L971E9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")-87!P82`G)7,G
M('9A<G0@:6MK:F4@<VQE='1A+B!$971T92!E<B!K=F$@=&5N87)E;B!S82(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N(@IM
M<V=S='(@(DUA<'!A(%PB)7-<(B!V87)T(&]P<')E='1A+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R
M(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(DUA
M<'!A(%PB)7-<(B!V87)T('-L971T82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B36%P
M<&$@7"(E<UPB(&5N9')A(&YA;6X@=&EL(%PB)7-<(BXB"@HC.B!L:6(O34E-
M12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I;F<@9FEL
M97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?<V%V96EM86=E7W=I;BYJ<SHQ
M,@IM<V=I9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@
M;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@(@HB
M=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.CDW"FUS9VED("(B"B)4:&4@:6UA9V5S('=I
M;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT
M(&EN('EO=7(@(@HB861D<F5S<V)O;VLN(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I;"!S97)V
M97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93HB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z
M-3$*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO
M=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDP"FUS9VED(")4:&4@;6%I;"!S
M97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93HB"FUS9W-T
M<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB
M"FUS9W-T<B`B36%P<&$@7"(E<UPB(&5K<VES=&5R97(@86QL97)E:64B"@HC
M.B!L:6(O1F5T8VAM86EL+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B>71E<RD@97AC
M965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%
M>&ET:6YG+B(*;7-G<W1R(")-96QD:6YG82!S;VT@8FQI<B!S:W)I=F5N('9A
M<G0@;'5K:V$N($%V<VQU='1A<BXB"@HC.B!M97-S86=E+G!H<#HQ-#@*(RP@
M9G5Z>GD*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(DED96YT:71E=&5N(%PB)7-<(B!V87)T('-L971T82XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3,*(RP@9G5Z>GD*;7-G:60@(E1H
M92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G<W1R(")$96YN92!M
M96QD:6YG82!E<B!R87!P;W)T97)T('-O;2!S^'!P96QP;W-T+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"X@4V5N
M9&5R.B`E<RXB"FUS9W-T<B`B1&5N;F4@;65L9&EN9V$@97(@<F%P<&]R=&5R
M="!S;VT@<_AP<&5L<&]S="XB"@HC.B!T96UP;&%T97,O<VUI;64O;W!E;E]S
M;6EM95]W:6XN:G,Z,3`@=&5M<&QA=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z
M,3`*;7-G:60@(B(*(E1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O
M<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B
M"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(')A=R!T97AT(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D
M("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z
M-C`*;7-G:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I
M;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R(")$96X@9OAR97-P
M=7)D92!F:6QA(&5K<VES=&5R97(@:6MK:F4@:2!-4RU43D5&+79E9&QE9V=E
M="XB"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H
M92!::7`@871T86-H;65N="XB"FUS9W-T<B`B1&5N(&;X<F5S<'5R9&4@9FEL
M82!E:W-I<W1E<F5R(&EK:VIE(&D@35,M5$Y%1BUV961L96=G970N(@H*(SH@
M;65S<V%G92YP:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S
M96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E
M($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO
M=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@
M<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4:&4@
M<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@
M=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@
M8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R(")3:6=N871U<F5N(&MU
M;FYE(&EK:VIE(&)L:2!E<G-T871T82XB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FIS.C$P,@IM<V=I9"`B5&AE('-I9VYA='5R92!W87,@<W5C
M8V5S<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R(")3:6=N871U<F5N('9A<G0@
M97)S=&%T=&$N(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S
M<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@
M<W1A=&EO;F5R>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T
M<B`B2V]N=&]E;B!<(B5S7"(@=F%R="!L86=R82XB"@HC.B!S=&%T:6]N97)Y
M+G!H<#HV,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I
M;VYE<GD@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DMO;G1O
M96X@7"(E<UPB('9A<G0@<VQE='1A+B(*"B,Z('-T871I;VYE<GDN<&AP.C@W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<
M(B5S7"(@:&%S(&)E96X@=7!D871E9"XB"FUS9W-T<B`B2V]N=&]E;B!<(B5S
M7"(@=F%R="!S;&5T=&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$V.0IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T
M87-K;&ES="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S
M86=E(@IM<V=S='(@(G-L971T(&UE;&1I;F<B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX,`IM<V=I9"`B5&AE
M('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E1H92!T97AT(&]F
M('1H92!S96YT(&UE<W-A9V4B"FUS9W-T<B`B3VUD:7)I9V5R(&1E;FYE(&UE
M;&1I;F=A(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@
M;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")4:&4@
M=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@
M<W1O<F5D+B(*;7-G<W1R(")3:6=N871U<F5N('9A<G0@97)S=&%T=&$N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@HC+"!F=7IZ
M>0IM<V=I9"`B5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D1E="!V87(@:6YG
M96X@86QT97)N871I=F4@9&5L87(@<V]M(&MU;FYE('9I<V%S="!I;FYE8GEG
M9"XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS
M"FUS9VED(")4:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X
M+B(*;7-G<W1R(")$970@97(@:6YG96X@;65L9&EN9V%R(&D@9&5N;F4@<&]S
M=&MA<W-A+B(*"B,Z('1H<F5A9"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M(@IM<V=S='(@(D1E="!V87(@:6YG96X@86QT97)N871I=F4@9&5L87(@<V]M
M(&MU;FYE('9I<V%S="!I;FYE8GEG9"XB"@HC.B!L:6(O365S<V%G92YP:'`Z
M-C$R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(E!R;V)L96T@=F5D('3X;6UI;F<@878@)7,N($1E='1E(&5R(&MV
M82!T96YA<F5N('-A(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U
M;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T
M<B`B4')O8FQE;2!V960@=/AM;6EN9R!A=B!P;W-T:V%S<V4N($1E='1E(&5R
M(&MV82!T96YA<F5N('-A.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,C$*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL
M8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(E!R
M;V)L96T@=F5D('3X;6UI;F<@878@<&]S=&MA<W-E+B!$971T92!E<B!K=F$@
M=&5N87)E;B!S82(*"B,Z(&QI8B]-97-S86=E+G!H<#HY,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI
M;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(E!R;V)L96T@=F5D(&MO
M<&EE<FEN9R!A=B!M96QD:6YG('1I;"!<(B5S7"(N($1E='1E(&5R(&MV82!T
M96YA<F5N('-A(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Y."!L:6(O365S<V%G
M92YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@7"(E
M<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(B(*(E!R;V)L96T@=F5D('-L971T:6YG(&%V(&UE;&1I;F=A<B!F<N4@;6%P
M<&$@7"(E<UPB+B!$971T92!E<B!K=F$@=&5N87)E;B!S82(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@
M7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S
M='(@(B(*(E!R;V)L96T@=F5D('-L971T:6YG(&%V(&UE;&1I;F=A<B!I(&UA
M<'!A(%PB)7-<(BX@1&5T=&4@97(@:W9A('1E;F%R96X@<V$B"@HC.B!L:6(O
M365S<V%G92YP:'`Z,C$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B4')O8FQE;2!V960@<VQE='1I
M;F<@878@;65L9&EN9V%R+B!$971T92!E<B!K=F$@=&5N87)E;B!S83H@)7,B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z.3D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T
M:&4@979E;G0Z("5S+B(*;7-G<W1R(")0<F]B;&5M(&UE9"#E('9I<V4@9&5N
M(&;X<F5S<'5R=&4@;65L9&EN9V$N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L
M86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR:6-H960N<&AP.C,W"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R(")0<F]B;&5M('9E9"!V:7-I;F<@878@9&5N;F4@
M;65L9&EN9W-D96QE;B(*"B,Z(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE
M<W-A9V4N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<
M(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T
M<B`B(@HB4')O8FQE;2!V960@9FQA9V=I;F<@878@;65L9&EN9V%R(&D@;6%P
M<&$@7"(E<UPB+B!$971T92!E<B!K=F$@=&5N87)E;B!S82(*"B,Z(&9O;&1E
M<G,N<&AP.C$V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RXB"FUS9W-T<B`B4')O8FQE;2!V
M960@;&%G<FEN9R!A=B!K;&%D9"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,3,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@
M(E!R;V)L96T@;65D(.4@=FES92!D96X@9OAR97-P=7)T92!M96QD:6YG82XB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!T87-K.B`E<RXB"FUS9W-T<B`B4')O8FQE;2!M960@Y2!V:7-E(&1E
M;B!F^')E<W!U<G1E(&UE;&1I;F=A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O
M<FUA=&EO;CH@)7,N(@IM<V=S='(@(E!R;V)L96T@=F5D('-E;F1I;F<@878@
M;65L9&EN9V$@9&DZ("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M;6]V:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R(")0<F]B;&5M('9E
M9"!F;'ET=&EN9R!A=B!M96QD:6YG87(@=&EL(%PB)7-<(BX@1&5T=&4@97(@
M:W9A('1E;F%R96X@<V$B"@HC.B!C;VUP;W-E+G!H<#HQ,C0T"B,L(&9U>GIY
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@;65S<V%G
M92!A<R!A(&1R869T+B(*;7-G<W1R(")0<F]B;&5M('9E9"!V:7-I;F<@878@
M9&5N;F4@;65L9&EN9W-D96QE;B(*"B,Z(&-O;7!O<V4N<&AP.C$P,#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I;F<@
M>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R(")0<F]B;&5M('9E9"!S96YD:6YG
M(&%V(&UE;&1I;F=A(&1I.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")0
M<F]B;&5M('9E9"!S96YD:6YG(&%V(&UE;&1I;F=A(&1I.B`E<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!N;R!T97AT(&EN('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@
M(E!R;V)L96T@=F5D('9I<VEN9R!A=B!D96YN92!M96QD:6YG<V1E;&5N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"B,L(&9U>GIY"FUS9VED
M(")4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET
M+B(*;7-G<W1R(")$96YN92!M96QD:6YG82!E<B!K<GEP=&5R="!M960@4$=0
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY,`IM<V=I9"`B(@HB
M5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="X@
M0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@(@HB=&AI<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-@IM<V=I9"`B5&AI
M<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N
M(@IM<V=S='(@(D1E;FYE(&]F9F5N=&QE9V4@4$=0+6[X:VME;&5N('9A<B!L
M86=T('9E9"!M96QD:6YG82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3`T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3@*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$T,R!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,34W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S,@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C,Q-`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$W.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$Y"FUS
M9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$T
M"FUS9VED(")4:&ES(&UA>2!T86ME('-O;64@=&EM92X@07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&-O;G1I;G5E/R(*;7-G<W1R(")$971T92!K86X@=&$@
M96EN(&1E;"!T:60N($5R(&1U('-I:VME<B!PY2!A="!D=2!V:6P@:&%L9&4@
M9G)A;3\B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P
M"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT
M,3`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!A
M;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V
M:6$@4R\B"B)-24U%+B(*;7-G<W1R(")$96YN92!M96QD:6YG82!E<B!D:6=I
M=&%L="!S:6=N97)T('9I82!01U`N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HT,30*(RP@9G5Z>GD*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT
M86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I
M82!3+TU)344N(@IM<V=S='(@(D1E;FYE(&UE;&1I;F=A(&5R(&MR>7!T97)T
M(&UE9"!01U`N(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P
M"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R
M>2!S=&%T=7,@:6YF;W)M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H
M:7,@;65S<V%G92!I<R!U;FMN;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HS,34*(RP@9G5Z>GD*;7-G:60@(B(*(E1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC
M<GEP=&5D(&UE<W-A9V4N($5R<F]R.B`B"FUS9W-T<B`B(@HB1&5N;F4@;65L
M9&EN9V$@<V5R(&EK:VIE('5T('1I;"#E('9E<F4@:2!K;W)R96MT(%!'4"UF
M;W)M870@*&D@9OAL9VIE(%)&0R`B"B(R,#$U*2XB"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S4P
M"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B"B)2
M1D,@,C`Q-2DN(@IM<V=S='(@(B(*(D1E;FYE(&UE;&1I;F=A('-E<B!I:VMJ
M92!U="!T:6P@Y2!V97)E(&D@:V]R<F5K="!01U`M9F]R;6%T("AI(&;X;&=J
M92!21D,@(@HB,C`Q-2DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HQ-S`*(RP@9G5Z>GD*;7-G:60@(E1H:7,@;65S<V%G92!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="XB"FUS
M9W-T<B`B(@HB1&5N;F4@;65L9&EN9V$@<V5R(&EK:VIE('5T('1I;"#E('9E
M<F4@:2!K;W)R96MT(%!'4"UF;W)M870@*&D@9OAL9VIE(%)&0R`B"B(R,#$U
M*2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#4@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z-#$V"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E
M96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G<W1R(")$96YN92!M
M96QD:6YG82!E<B!D:6=I=&%L="!S:6=N97)T('9I82!01U`N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(E1H
M:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)
M344N(@IM<V=S='(@(D1E;FYE(&UE;&1I;F=A(&5R(&1I9VET86QT('-I9VYE
M<G0@=FEA(%!'4"XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$S
M.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S.`HC+"!F=7IZ>0IM<V=I
M9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%
M+B(*;7-G<W1R(")$96YN92!M96QD:6YG82!E<B!K<GEP=&5R="!M960@4$=0
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P,2!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR.3$*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E
M;B!E;F-R>7!T960@=VET:"!01U`N(@IM<V=S='(@(D1E;FYE(&UE;&1I;F=A
M(&5R(&MR>7!T97)T(&UE9"!01U`N(@H*(SH@;65S<V%G92YP:'`Z,C$Q"FUS
M9VED(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T<B`B1&5N;F4@;65L9&EN9V$@
M=&EL(@H*(SH@86-L+G!H<#HT-@IM<V=I9"`B5&AI<R!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y"B,L(&9U>GIY"FUS
M9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S
M92!W:6YD;W<N(@IM<V=S='(@(D1E='1E('9I;F1A=6=E="!MY2!K86QL87-T
M(&9RY2!V:6YD875G970@9F]R('-K<FEV(&UE;&1I;F<B"@HC.B!T:')E860N
M<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B5&AR96%D($1I<W!L87DB"FUS9W-T
M<B`B5FES(@H*(SH@=&AR96%D+G!H<#HW-B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3(R"FUS9VED(")4:')E860@5FEE=R(*;7-G<W1R(")4<N5D=FES:6YG
M(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP.C8P-B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E<R]C;VUP;W-E
M+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O
M<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS9VED(")4;R(*;7-G<W1R
M(")4:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$Y"B,L(&9U>GIY
M"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(D9RY2UA9')E<W-E(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(V"FUS9VED("(B
M"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE("(*(F-L:6-K:6YG
M+B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C$S-`IM<V=I
M9"`B(@HB5&\@=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO=2!M=7-T(&)E(')U
M;FYI;F<@82!V97)S:6]N(&]F(%!(4"`U+C`N-B!O<B`B"B)H:6=H97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W
M-PHC+"!F=7IZ>0IM<V=I9"`B5&]T86P@071T86-H;65N=',@4VEZ93HB"FUS
M9W-T<B`B5F5D;&5G9R(*"B,Z(&9O;&1E<G,N<&AP.C,X.`HC+"!F=7IZ>0IM
M<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(E/X<'!E;&MO<F<Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A
M<V@@9F]L9&5R.B(*;7-G<W1R(")3^'!P96QK;W)G.B(*"B,Z(&QI8B]1=6]T
M82]C>7)U<RYP:'`Z-C4@;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z-SD@;&EB
M+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1=6]T82]L;V=F:6QE+G!H
M<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+VUD865M
M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS=V5R
M960B"FUS9W-T<B`B56)E<W9A<G0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C,U"FUS9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@
M(E5B97-V87)T92!M96QD:6YG87(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHQ,PIM<V=I9"`B56YD96QE=&4B"FUS9W-T<B`B06YG<F4@<VQE='0B
M"@HC.B!M86EL8F]X+G!H<#HU.#D@;6%I;&)O>"YP:'`Z-C`R(&QI8B]-24U%
M+TAE861E<G,N<&AP.C(Q,@IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I96YT
M<R(*;7-G<W1R(")3:VIU;'0@;6]T=&%K87(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-#0W"B,L('!H<"UF;W)M870*;7-G:60@(E5N:&%N9&QE
M9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B(@H*(SH@;6%I;&)O
M>"YP:'`Z-38U"FUS9VED(")5;FMN;W=N($1A=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YK;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R
M(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8S-0IM<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@
M(B(*"B,Z(&UA:6QB;W@N<&AP.C8Q.`HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W
M;B!296-I<&EE;G0B"FUS9W-T<B`B4VMJ=6QT(&UO='1A:V%R(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S<*;7-G:60@(E5N;&]A9"!087-S<&AR87-E(@IM<V=S='(@(DQA<W0@
M=70@<&%S<V]R9&9R87-E(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(E5T86X@;F%M;B(*"B,Z(&UE<W-A9V4N
M<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*
M;7-G<W1R(")5;&5S="(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N
M:6YC.C$R"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS*2(*;7-G
M<W1R(")396D@;W!P(&%B;VYN96UE;G0@<.4@;6%P<&4H<BDB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU.#0*;7-G:60@(E5P9&%T92!!
M='1A8VAM96YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,C`*;7-G:60@(E5P9&%T92!R97-P;VYD96YT
M('-T871U<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM
M<V=I9"`B57!L;V%D(@IM<V=S='(@(DQA<W0@;W!P(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U
M;'0@5F%L=64B"FUS9W-T<B`B0G)U:R!S=&%N9&%R9'9E<F1I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(U-@HC+"!F=7IZ>0IM<V=I9"`B57-E($E-
M05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(D)R=6L@86)O;FYE
M;65N="!PY2!)34%0+6UA<'!E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW,S4*(RP@9G5Z>GD*;7-G:60@(E5S92!6:7)T=6%L(%1R87-H($9O;&1E
M<C\B"FUS9W-T<B`B5/AM('/X<'!E;&MO<F<B"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,30R"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(D)R
M=6MA<FYA;6XB"@HC.B!A8VPN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E8VEF
M:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<W"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R(")"<G5K87)N86UN(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B
M0G)U:V%R;F%M;CHB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW-PIM<V=I9"`B5FEE=R(*;7-G<W1R(")6:7,B"@HC.B!L:6(O34E-12]6
M:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3`X
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5FES("5S
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R!0
M=6)L:6,@2V5Y(@IM<V=S='(@(E9I<R`E<R!O9F9E;G1L96<@;OAK:V5L(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I
M9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS
M9W-T<B`B2&5N="!P;W-T(&D@96EG92!V:6YD875G93\B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR.`HC+"!F=7IZ>0IM<V=I9"`B5FEE
M=R!-97-S86=E<R(*;7-G<W1R(").>64@;65L9&EN9V%R(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T<B`B
M5FES('!E<G-O;FQE9R!P<FEV870@;OAK:V5L(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G
M:60@(E9I97<@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R(")6:7,@<&5R
M<V]N;&5G(&]F9F5N=&QE9R!N^&MK96PB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,3@*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M5&AR96%D(@IM<V=S='(@(E1RY60B"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38U"FUS
M9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C0Q.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!A='1A
M8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(DAE;G0@<&]S
M="!I(&5I9V4@=FEN9&%U9V4_(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T
M960N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")6:65W(&-O;G1E;G0@:6X@82!S
M97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B2&5N="!P;W-T(&D@96EG92!V:6YD
M875G93\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30P"FUS9VED
M(")6:65W(&5V96YT(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,X,"!M
M86EL8F]X+G!H<#HU,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I
M97<@;65S<V%G97,@:6X@)7,B"FUS9W-T<B`B5FES(&UE;&1I;F=A<B!I(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM
M<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ
M(@IM<V=S='(@(E9I<VEN9R!E;&QE<B!P;W-T8F]K<R!S;VT@<VMA;"!V:7-A
M<W0@971T97(@:6YN;&]G9VEN9SHB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,3<P"B,L(&9U>GIY"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B
M5FES("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P,0HC+"!F
M=7IZ>0IM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM<V=S='(@(E9I<R!M96QD
M:6YG87(@:2(*"B,Z('-E87)C:"YP:'`Z,C8S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C
M97-F=6QL>2XB"FUS9W-T<B`B36%P<&$@7"(E<UPB('9A<G0@<VQE='1A+B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])34%0+U1R
M964N<&AP.C$S."!L:6(O24U!4"]4<F5E+G!H<#HQ-3$*(SH@;&EB+TE-05`O
M5')E92YP:'`Z,34S(&QI8B])34%0+U1R964N<&AP.C$U-R!L:6(O24U!4"]4
M<F5E+G!H<#HQ-3@*(SH@;&EB+TE-05`O5')E92YP:'`Z,S8Y(&QI8B])34%0
M+U1R964N<&AP.C,Y,R!L:6(O24U!4"]4<F5E+G!H<#HT,S,*(RP@9G5Z>GD*
M;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*;7-G<W1R(")/<'!R970@;6%P<&4B
M"@HC.B!S96%R8V@N<&AP.C(T-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E
M<75I<F4@82!L86)E;"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&;VQD97(N<&AP
M.C$W-2!L:6(O5D9O;&1E<BYP:'`Z,3@P"FUS9VED(")6:7)T=6%L($E.0D]8
M(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q-@IM<V=I9"`B5FER='5A
M;"!)3D)/6"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-#4R
M(&QI8B]61F]L9&5R+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0IM<V=I
M9"`B5FER='5A;"!4<F%S:"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT
M,3,*(RP@9G5Z>GD*;7-G:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S
M='(@(E3X;2!S^'!P96QK;W)G(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHQ,S,*;7-G:60@(E9I<G1U86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S<T"FUS9VED(")7
M87)N:6YG(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")696QK;VUE;B!T
M:6P@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$Y"FUS9VED("(B
M"B)7:&%T('-H;W5L9"!W92!D;R!W:71H('-P86T@;65S<V%G97,@869T97(@
M=&AE>2!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2`B"B)O<B!I;FYO8V5N
M=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<R-PHC
M+"!F=7IZ>0IM<V=I9"`B(@HB5VAE;B!D96QE=&EN9R!M97-S86=E<RP@;6]V
M92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E860@;V8@;6%R:VEN
M9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM<V=S='(@(B(*(E9E9"!S;&5T=&EN
M9R!A=B!M96QD:6YG87(L(&9L>71T(&1E:2!T:6P@<_AP<&5L:V]R9V$@:2!S
M=&%D96X@9F]R(.4@;6%R:V5R92`B"B)D96D@<V]M('-L971T82XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS9VED(")7:&5N(&]P96YI;F<@
M82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R
M="!O;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V
M,0IM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V
M92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN9R!M86EL(&]R
M(&5X<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A
M<'!E;F0@=&\@(@HB=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R
M97-S97,@=VET:&]U="!<(D!<(BD_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<X"FUS9VED(")997,B"FUS9W-T<B`B2F$B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP
M.C4X"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M
M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O=6YT*',I.B(*;7-G<W1R(")$
M=2!P<OAV97(@Y2!S;&5T=&4@9OAL9VIA;F1E(&UA<'!E<CHB"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ
M>0IM<V=I9"`B(@HB66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@
M;65S<V%G97,@8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB
M*',I+B(*;7-G<W1R(")$=2!P<OAV97(@Y2!S;&5T=&4@9OAL9VIA;F1E(&UA
M<'!E<CHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN
M:'1M;#HY"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&%T=&5M<'1I;F<@=&\@
M9&5L971E('1H92!F;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G<W1R(")$=2!P
M<OAV97(@Y2!S;&5T=&4@9OAL9VIA;F1E(&UA<'!E<CHB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O
M>"]J879A<V-R:7!T+FEN8SHQ.3(*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@
M8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+B(*;7-G<W1R(")$=2!E
M;F1R87(@;F%M;B!PY2!M87!P83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$P,@IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U
M8BUF;VQD97(@=&\@(@IM<V=S='(@(D1U(&]P<')E='1A<B!E:2!U;F1E<FUA
M<'!E('1I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,3`T"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E
M<BXB"FUS9W-T<B`B1'4@;W!P<F5T=&%R(&5I('1O<'!N:7;E+6UA<'!E+B(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C,R,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@9F]L9&5R<RXB"FUS9W-T<B`B1'4@
M;W!P<F5T=&%R(&5I('1O<'!N:7;E+6UA<'!E+B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L9&5R<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S4*;7-G
M:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@(@IM<V=S='(@(D1U
M(&5N9')A<B!N86UN('#E(&UA<'!A.B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS
M=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D1I='0@86)O;FYE;65N
M="!PY2!<(B5S7"(@97(@<V%G="!O<'`B"@HC.B!T96UP;&%T97,O<W1A=&EO
M;F5R>2]P<F5F<RYI;F,Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M(&-A;B!U<V4@=&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T
M871I;VYE<GD@=&5X=#H@)6,@9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@
M8V]N=&5N=#L@)7,@9F]R('1H92!S:6=N871U<F4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C,T"FUS
M9VED("(B"B)9;W4@9&ED(&YO="!A9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R
M=FEC92!A9W)E96UE;G0L('-O('EO=2!W97)E(&YO="!A;&QO=V5D("(*(G1O
M(&QO9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M,38Y"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N
M9V4@86-C97-S('1O('1H:7,@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M86EL;&]G+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O<G=A
M<F1E9"!T:&ES(&UE<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C
M:7!I96YT<SH@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%L97)T+FEN8SHS"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!H879E("5S
M(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B1'4@:&%R("5S(&YY92!M96QD:6YG
M87(N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@
M(EEO=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(D1U(&AA<B`Q(&YY
M(&UE;&1I;F<N(@H*(SH@8V]M<&]S92YP:'`Z-#DT"B,L(&9U>GIY"FUS9VED
M(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N(@IM<V=S
M='(@(D1U(&AA<B`Q(&YY(&UE;&1I;F<N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O871T86-H;65N=',N:G,Z,3$U"FUS9VED("(B"B)9;W4@:&%V92!A="!L
M96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@
M=7!L;V%D('EE="X@07)E("(*(GEO=2!S=7)E('EO=2!W86YT('1O('-E;F0@
M=&AI<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N=',_(@IM<V=S
M='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-S0*;7-G:60@(EEO=2!H879E(&YE
M=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R(")$=2!H
M87(@;GD@<&]S="!I(&;X;&=J86YD92!M87!P93HB"@HC.B!L:6(O24U0+G!H
M<#HQ,#<Y"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W
M:6YG(&9O;&1E<G,Z(@IM<V=S='(@(D1U(&AA<B!N>2!P;W-T(&D@9OAL9VIA
M;F1E(&UA<'!E<CHB"@HC.B!C;VUP;W-E+G!H<#HQ-3,*(RP@9G5Z>GD*;7-G
M:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N(@IM
M<V=S='(@(D1U(&WE(&AA(&UI;G-T(&5I;B!M;W1T86MA<BXB"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HS,#(*;7-G:60@(B(*(EEO=2!M=7-T(&5N
M=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T
M;R!V:65W('1H:7,@;65S<V%G92(*;7-G<W1R("(B"B)$=2!MY2!S:W)I=F4@
M:6YN('!A<W-O<F1F<F%S82!F;W(@9&EN('!R:79A=&4@4$=0+6[X:VME;"!F
M;W(@Y2!V:7-E(&1E;FYE("(*(FUE;&1I;F=A(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=2!M=7-T
M(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E
M(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*;7-G<W1R("(B"B)$=2!M
MY2!S:W)I=F4@:6YN('!A<W-O<F1F<F%S82!F;W(@9&EN('!R:79A=&4@4$=0
M+6[X:VME;"!F;W(@Y2!V:7-E(&1E;FYE("(*(FUE;&1I;F=A(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-C0@=&5M<&QA=&5S+VUA
M:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS9VED(")9;W4@;75S="!S96QE
M8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB"FUS9W-T<B`B1'4@;>4@9OAR
M<W0@=F5L:F4@96D@;>5L;6%P<&4N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP
M.C@U"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D
M96QE=&5D+B(*;7-G<W1R(")$=2!MY2!V96QJ92!E:6X@:V]N=&\@<V]M('-K
M86P@<VQE='1A<W0N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHX,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N(&%D9')E<W,@9FER
M<W0N(@IM<V=S='(@(D1U(&WE(&;X<G-T('9E;&IE(&5I(&%D<F5S<V4N(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R(")$=2!M
MY2!F^')S="!V96QJ92!M:6YS="!E:2!M96QD:6YG+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,PIM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!A(')E8VEP:65N="XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF:7-E<F4@
M96EN(&UO='1A:V%R+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FIS.C(Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&%T
M(&QE87-T(&]N92!F:6QE('1O(&%T=&%C:"XB"FUS9W-T<B`B1'4@;>4@9OAR
M<W0@<W!E<VEF:7-E<F4@9FEL82!S;VT@<VMA;"!V961L96=G87-T+B(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@;F5E9"!T;R!H879E(%PB)7-<(B!E;F%B;&5D(&EN
M('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TUA:6QL;V<N<&AP.C$S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(')E9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS
M9W-T<B`B3VUD:7)I9V5R(&1E;FYE(&UE;&1I;F=A(@H*(SH@;&EB+TUA:6QL
M;V<N<&AP.C$T,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E
M<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S+B(*;7-G<W1R(")/;61I<FEG
M97(@9&5N;F4@;65L9&EN9V$B"@HC.B!L:6(O1F]L9&5R+G!H<#HU,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@
M7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(DMU;FYE(&EK:VIE(&%B;VYN97)E('#E(%PB)7-<(BX@1&5T=&4@97(@:W9A
M('1E;F%R96X@<V$B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB
M)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")$
M:71T(&%B;VYN96UE;G0@<.4@7"(E<UPB('9A<G0@:6MK:F4@<V%G="!O<'`N
M($1E='1E(&5R(&MV82!T96YA<F5N('-A(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M-3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL
M>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")$=2!A8F]N;F5R97(@
M;F\@<.4@7"(E<UPB(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-38R"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB
M960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B1&ET="!A8F]N;F5M96YT('#E(%PB
M)7-<(B!E<B!S86=T(&]P<"(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHY
M.`IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(D1I='0@;F%M;B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHU,`IM<V=I9"`B66]U<B!01U`@4'5B;&EC
M+U!R:79A=&4@2V5Y<R(*;7-G<W1R(")$:6YE(&]F9F5N=&QE9V4O<')I=F%T
M92!01U`M;OAK;&%R(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW
M,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T
M92!+97DB"FUS9W-T<B`B1&EN('!R:79A=&4@;OAK:V5L(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S$*;7-G:60@(EEO=7(@4'5B;&EC($ME>2(*;7-G<W1R(")$:6X@;V9F96YT
M;&5G92!N^&MK96PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"B,L
M(&9U>GIY"FUS9VED(")9;W5R(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P
M=&EO;F%L*3PO96T^(@IM<V=S='(@(D1I(%-V87(M=&EL.B!A9')E<W-E.B`\
M:3XH=F%L9G)I='0I/"]I/B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-#D*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV
M871E($-E<G1I9FEC871E<R(*;7-G<W1R(")$:6YE(&]F9F5N=&QE9V4O<')I
M=F%T92!01U`M;OAK;&%R(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O
M=6YT7W-E;&5C="YI;F,Z,38*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S
M='(@(D1I;F4@:V]N=&]A<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I
M;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B
M3F5T=&QE<V%R96X@9&EN('-T^'1T87(@:6MK:F4@=FES:6YG(&%V(&)I;&5T
M92!A=B!D96YN92!T>7!E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,SD*;7-G:60@(EEO=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE
M<W-A9V5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O96YC<GEP
M='-E;&5C="YI;F,Z,0IM<V=I9"`B66]U<B!D969A=6QT(&5N8W)Y<'1I;VX@
M;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!M97-S86=E('=A<R!S=6-C97-S9G5L;'D@9&5L:79E<F5D+B(*;7-G
M<W1R(")-87!P82!<(B5S7"(@=F%R="!S;&5T=&$N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(P-@IM<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM<V=S
M='(@(D1I;B!S:6=N871U<CHB"@HC.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S
M92YP:'`Z,3(X-"!M86EL8F]X+G!H<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q
M.`IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM4;VUT(&5M;F5=(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,L(&9U>GIY
M"FUS9VED(")?0F-C(@IM<V=S='(@(D)L:6YD(&MO<&DB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E]";&%C:VQI
M<W0B"FUS9W-T<B`B4W9A<G1E;&ES="(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C$U-`HC+"!F=7IZ>0IM<V=I9"`B7T-C(@IM<V=S='(@
M(DMO<&DB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")?
M1&5L971E(@IM<V=S='(@(E-L971T(@H*(SH@;&EB+TE-4"YP:'`Z.3<Y"B,L
M(&9U>GIY"FUS9VED(")?1F]L9&5R<R(*;7-G<W1R(")-87!P97(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHX,0HC+"!F=7IZ>0IM<V=I
M9"`B7TED96YT:71Y(@IM<V=S='(@(DED96YT:71E="(*"B,Z(&QI8B])35`N
M<&AP.CDV,0IM<V=I9"`B7TEN8F]X(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N
M<&AP.C$P,C`*(RP@9G5Z>GD*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(DQO
M9V<@=70B"@HC.B!M97-S86=E+G!H<#HS.#0*(RP@9G5Z>GD*;7-G:60@(E]-
M97-S86=E(%-O=7)C92(*;7-G<W1R(")-96QD:6YG<VMJ96QD92(*"B,Z(&QI
M8B])35`N<&AP.CDW-@HC+"!F=7IZ>0IM<V=I9"`B7TYE=R!-97-S86=E(@IM
M<V=S='(@(DYY92!M96QD:6YG87(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(E]0<FEN="(*
M;7-G<W1R(")3:W)I=B!U="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(W,B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.#D*
M(RP@9G5Z>GD*;7-G:60@(E]0<FEO<FET>2(*;7-G<W1R(")0<FEO<FET970B
M"@HC.B!M86EL8F]X+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E]2969R97-H("5S(@IM<V=S='(@(D9R:7-K(&]P<"(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS
M9VED(")?4F5P;'DB"FUS9W-T<B`B4W9A<B(*"B,Z(&QI8B])35`N<&AP.CDX
M,0HC+"!F=7IZ>0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")3^&LB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,S$*(RP@9G5Z>GD*;7-G:60@(E]396YD($UE
M<W-A9V4B"FUS9W-T<B`B4V5N9"!M96QD:6YG(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,@HC+"!F=7IZ>0IM<V=I9"`B
M7U1H<F5A9"(*;7-G<W1R(")4<N5D(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,3$V"B,L(&9U>GIY"FUS9VED(")?5&\B"FUS9W-T<B`B
M5&EL(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*(RP@
M9G5Z>GD*;7-G:60@(E]5;F1E;&5T92(*;7-G<W1R(")!;F=R92!S;&5T="(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`HC
M+"!F=7IZ>0IM<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S='(@(E1RY60B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W-@IM<V=I9"`B
M861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C0T,`HC+"!F=7IZ>0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R(")6
M961L96=G(@H*(SH@=FEE=RYP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(F%T=&%C
M:&UE;G1S+GII<"(*;7-G<W1R(")6961L96=G(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B>71E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`P"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M-S(*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ-C0*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(P"FUS9VED
M(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ.38*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V.`IM<V=I9"`B
M9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(R-`IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")F
M<F]M(@IM<V=S='(@(F9RY2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#`*;7-G
M:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR,#0*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@X"FUS9VED(")I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,CD@<&=P
M+G!H<#HV.0IM<V=I9"`B:V5Y(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP
M.C$V,0HC+"!F=7IZ>0IM<V=I9"`B;6%I;&)O>"!F:6QE(@IM<V=S='(@(E!O
M<W1K87-S92(*"B,Z(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP
M.C0V-@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R(").86UN(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<V"FUS9VED(")N;VYE
M(@IM<V=S='(@(FEN9V5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$P-0IM<V=I9"`B;W(B"FUS9W-T<B`B96QL97(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,C$V"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$R"FUS9VED(")R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$X-`IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@
M(G-P96QL:6YG(&5R<F]R(@IM<V=S='(@(G-T879E9F5I;"(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@
M97)R;W)S(@IM<V=S='(@(G-T879E9F5I;"(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")S
M=&%V969E:6PB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`X"FUS9VED(")T96UP
M;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HU
M,0HC+"!F=7IZ>0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B4W9A
M<G1E;&ES="(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H
M:71E;&ES="(*;7-G<W1R("(B"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+W!L7U!,+G!O````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0P,#<P,P`Q,#0Q
M-S,V,C<V-``P,3<R,#``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!0;VQI<V@@=')A;G-L871I;VYS(&9O<B!)35`@<&%C
M:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC(%1H
M:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E
M(&%S('1H92!)35`@<&%C:V%G92X*(R!-871E=7-Z($MA;6EN<VMI(#QM871I
M<&Q`<&QD+6QI;G5X+F]R9SXL(#(P,#4N"B,@2W)Z>7-Z=&]F($MO>FQO=W-K
M:2`\:V]Z:6LQ0&\R+G!L/BP@,C`P-2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*
M(E!R;VIE8W0M260M5F5R<VEO;CH@26UP(&@S+30N,"XS7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3$M,C0@,C`Z,S4K,#$P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-2TQ,2TR-"`R,#HT-2LP,3`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($MR>GES>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#Y<
M;B(*(DQA;F=U86=E+51E86TZ(%!O;&ES:"`\:3$X;D!L:7-T<RYH;W)D92YO
M<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3)<;B(*(D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR
M-C4@;&EB+T-O;7!O<V4N<&AP.C,Q-PIM<V=I9"`B("`@("`@5&\Z("(*;7-G
M<W1R("(@("`@("!$;SH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(U,R!L:6(O
M0V]M<&]S92YP:'`Z,S`U"FUS9VED("(@("`@1&%T93H@(@IM<V=S='(@(B`@
M("!$871A.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C4V(&QI8B]#;VUP;W-E
M+G!H<#HS,#@*;7-G:60@(B`@("!&<F]M.B`B"FUS9W-T<B`B("`@($]D.B`B
M"@HC.B!M86EL8F]X+G!H<#HT,#8@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS
M9W-T<B`B*&ML=6-Z(&1O<W3J<'4@)7,I(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C(V,B!L:6(O0V]M<&]S92YP:'`Z,S$T"FUS9VED("(@4W5B:F5C=#H@(@IM
M<V=S='(@(B!496UA=#H@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C<T"FUS9VED("(@:6X@(@IM<V=S='(@(B!W("(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B
M"FUS9W-T<B`B(R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HW,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM
M<V=S='(@(B4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"@HC.B!M86EL8F]X
M+G!H<#HQ.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V
M92!B965N(&1E;&5T960N(@IM<V=S='(@(B5D('=I861O;6^V8VD@>F]S=&&S
M;R!U<W5N:>IT92XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"B(E9"!W:6%D;VUOMF-I('IO<W1ALV\@>F>S;W-Z;VYY8V@@:F%K
M;R!N:64M<W!A;2!D;R!4=V]J96=O(&%D;6EN:7-T<F%T;W)A+B(*"B,Z(&QI
M8B]3<&%M+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G
M97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(E
M9"!W:6%D;VUOMF-I('IO<W1ALV\@>F>S;W-O>FYY8V@@:F%K;R!N:64M<W!A
M;2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO
M=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B5D('=I861O;6^V
M8VD@>F]S=&&S;R!Z9[-O<WIO;GEC:"!J86MO('-P86T@9&\@5'=O:F5G;R!A
M9&UI;FES=')A=&]R82XB"@HC.B!L:6(O4W!A;2YP:'`Z,34P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M+B(*;7-G<W1R("(E9"!W:6%D;VUOMF-I('IO<W1ALV\@>F>S;W-Z
M;VYY8V@@:F%K;R!S<&%M(@H*(SH@;6%I;&)O>"YP:'`Z,S8Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D($UE<W-A9V5S(@IM<V=S='(@
M(B5D(&1O("5D('H@)60@=VEA9&]M;[9C:2(*"B,Z(&UA:6QB;W@N<&AP.C8Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*
M"B,Z('!G<"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%!'4"!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!!9&UI;FES=')A8VIA(%!'4"(*
M"B,Z('-M:6UE+G!H<#HR-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4R]-
M24U%($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S($%D;6EN:7-T<F%C:F$@
M4R]-24U%(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L
M<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N
M(@IM<V=S='(@(B5S(&IUOR!I<W1N:65N:64N($YA>G=A(&9O;&1E<G4@)7,@
M;FEE('IO<W1ALV$@>FUI96YI;VYA+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV
M,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B9F]L9&5R("5S(&YI92!J
M97-T('!R87=I9+-O=WDN(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N
M86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T
M:&4@;6]N=&@N(@IM<V=S='(@(F9O;&1E<B`E<R!Z;6EE;FD@;F%Z=^H@;F$@
M<&]C>K%T:W4@<')Z>7-ZLV5G;R!M:65S:;%C82XB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@>F%A:V-E<'1O=V%N92XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(B5S('-K87-O=V&S
M("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R
M("(E<R!Z86%K8V5P=&]W86YE+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@
M=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B)7,@;V1P;W=I961Z
M:6&S(&YA('IA<'ET86YI92!W;VQN>2]Z86KJ='DB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C$V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E
M<R!O9'!O=VEE9'II8;,@;F$@>F%P<F]S>F5N:64@9&\@)7,B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-#@R"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B5S('=Y<[-ALR!#:2!I;F9O<FUA8VIE+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HR-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M('1E;G1A=&EV96QY(&%C8V5P=&5D+B(*;7-G<W1R("(E<R`@<'+S8FYI92!Z
M86%K8V5P=&]W8;,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R964O
M8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@=WESLV&S('IA<'ET86YI
M92!D;R!#:65B:64@;R!I;F9O<FUA8VKJ('=O;&YY+WIA:NIT>2XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N(@IM<V=S='(@
M(B5S('!Y=&$@;R!4=V]JL2!O8F5C;F^VYB!N82`E<RXB"@HC.B!L:6(O365S
M<V%G92YP:'`Z,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@)7,N(@IM<V=S='(@(B5S('IO<W1ALR!P;W!R
M87=N:64@9&]D86YY(&1O("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M
M;65N9"`E<RXB"FUS9W-T<B`B)7,@OWEC>GD@<V]B:64@)7,N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@
M(B5S(&-H8V4@0VGJ('!O:6YF;W)M;W=AYB!O("5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U
M="`E<RXB"FUS9W-T<B`B)7,@<')O<VD@;R!N86IN;W=S>F4@:6YF;W)M86-J
M92!O("5S+B(*"B,Z(&UE<W-A9V4N<&AP.C(V.2!M97-S86=E+G!H<#HR-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC.C$S"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*2(*
M;7-G<W1R("(E<SH@)7,@*"5D)FYB<W`[>B9N8G-P.R5D*2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#`*;7-G:60@(BA!<'!L>2!T
M:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@<V-R965N+BDB"FUS9W-T
M<B`B*$%K8V5P='5J('1E('IM:6%N>2!I(&EDO"!D;R!N87-TZG!N96=O(&5K
M<F%N=2XI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R
M-PIM<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E='5R;B!T;R!T
M:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("(H06YU;'5J('=S>GES=&MI
M92!Z;6EA;GD@:2!W<O-C(&1O(&]K;F$@961Y8VII+BDB"@HC.B!S<&5L;&EN
M9RYP:'`Z,C@P"FUS9VED("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C
M<F5E;B!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R
M+B`@(@HB0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@
M8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BA0;W=R\^8@9&\@;VMN82!E9'EC
M:FD@<&\@>F%S=&]S;W=A;FEU(&1O='EC:&-Z87-O=WEC:"!Z;6EA;BX@(%IM
M:6%N>2!W("(*(F)I97)ZL6-Y;2!O:VYI92!N:64@8NIDL2!Z87-T;W-O=V%N
M92XI(@H*(SH@<W!E;&QI;F<N<&AP.C(W-PIM<V=I9"`B(@HB*%-E;F0@;65S
M<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R
M+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@
M8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BA7>;9L:6H@=VEA9&]M;[;F('!O
M('IA<W1O<V]W86YI=2!W<WIY<W1K:6-H('IM:6%N+B`@6FUI86YY('<@8FEE
MO[%C>6T@;VMN:64@(@HB;FEE(&+J9+$@>F%S=&]S;W=A;F4N*2(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D
M9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@1&]D86H@<&]P
M<GIE>B!K;&EK;FGJ8VEE($]+("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E
M<W,H97,I("HB"FUS9W-T<B`B*B!7>6)I97)Z(&%D<F5S*'DI("HB"@HC.B!M
M86EL8F]X+G!H<#HQ.30*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("(Q('=I861O;6^VYB!Z;W-T8;-A('5S=6YIZG1A+B(*
M"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E
M;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(Q('=I861O;6^VYB!Z;W-T8;-A('IGLV]S>F]N
M82!J86MO(&YI92US<&%M(&1O(%1W;VIE9V\@861M:6YI<W1R871O<F$N(@H*
M(SH@;&EB+U-P86TN<&AP.C$V,`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N
M(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(Q('=I861O;6^VYB!Z
M;W-T8;-A('IGLV]S>F]N82!J86MO(&YI92US<&%M+B(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ-S(*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(C$@=VEA9&]M;[;F('IO<W1ALV$@>F>S;W-Z;VYA(&IA:V\@<W!A;2!D;R!4
M=V]J96=O(&%D;6EN:7-T<F%T;W)A+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*
M;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*
M;7-G<W1R("(Q('=I861O;6^VYB!Z;W-T8;-A('IGLV]S>F]N82!J86MO('-P
M86TN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X.`IM<V=I9"`B,3`P
M(&-H87)A8W1E<G,B"FUS9W-T<B`B,3`P('IN86OS=R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.3$*;7-G:60@(C$P,#`@8VAA<F%C=&5R<R(*;7-G
M<W1R("(Q,#`P('IN86OS=R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.#D*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(C(U,"!Z;F%K\W<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDP"FUS9VED("(U,#`@8VAA
M<F%C=&5R<R(*;7-G<W1R("(U,#`@>FYA:_-W(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,38R"B,L('!H<"UF;W)M870*;7-G:60@(D$@;&%R
M9V4@:6UA9V4@;F%M960@)7,@:7,@871T86-H960@=&\@=&AI<R!M97-S86=E
M+B(*;7-G<W1R(")$=;]Y(&]B<F%Z96L@)7,@:F5S="!D;[.Q8WIO;GD@9&\@
M=&5J('=I861O;6^V8VDB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T
M:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M97-S86=E('EO=2!H879E('-E;G0@
M:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H
M92`B"B)R96-I<&EE;G0N(@IM<V=S='(@(EIW<O-C;VYO(&YO=.H@;V0@;V1B
M:6]R8WD@=VEA9&]M;[9C:2!W>7.S86YE:B!P<GIE>B!#:65B:64N(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4*;7-G:60@(D%.1"(*;7-G
M<W1R("))(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,`IM<V=I
M9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B06MC971P=6H@O[%D86YI92(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*(RP@9G5Z>GD*;7-G
M:60@(D%C8V5P="!R97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B
M"FUS9W-T<B`B5WED87)Z96YI92!Z;W-T8;-O(&1O9&%N92!D;R!T=V]J96=O
M(&MA;&5N9&%R>F$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U
M,PIM<V=I9"`B06-C97!T960B"FUS9W-T<B`B06MC97!T=6HB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,C4W"FUS9VED(")!8V-E<'1E9#H@(@IM
M<V=S='(@(EIA86MC97!T;W=A;F4Z("(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT)W,@;F%M93HB"FUS9W-T
M<B`B3F%Z=V$@:V]N=&$Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4R,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,P"FUS9VED(")!8W1I
M;VYS(@IM<V=S='(@(D%K8VIE(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C
M97-E;&5C="YI;F,Z,S`S"FUS9VED(")!9&0@<V]U<F-E(@IM<V=S='(@(D1O
M9&%J(+QR\V2S;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S<@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X.`IM<V=I9"`B061D('1H:7,@
M=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B1&]D86H@9&\@;6]J96=O(&MA;&5N
M9&%R>F$B"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)344O
M2&5A9&5R<RYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T;R!!
M9&1R97-S(&)O;VL@*"5S*2(*;7-G<W1R(")$;V1A:B!D;R!M;VIE:B!K<VFQ
MOVMI(&%D<F5S;W=E:B`H)7,I(@H*(SH@8V]M<&]S92YP:'`Z,3$Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T86-H;65N
M="XB"FUS9W-T<B`B4&QI:R!<(B5S7"(@9&]D86YY(&IA:V\@>F&SL6-Z;FEK
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(B(*(D%D
M9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&D^
M*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE
M*3PO:3XB"FUS9W-T<B`B(@HB1&]D871K;W=E(&YA9[/S=VMI('=YMG=I971L
M86YE('!O9&-Z87,@<&]D9VRQ9&%N:6$Z(#QI/BAO<&-J;VYA;&YI92P@(@HB
M=W!R;W=A9+P@:V&_9'D@;F%GL_-W96L@=R!N;W=E:B!L:6YI:2D\+VD^(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO;B!C86X@8F4@
M=FEE=V5D("5S+B(*;7-G<W1R(")$;V1A=&MO=V4@:6YF;W)M86-J92!M;V>Q
M(&)YYB!Z87=A<G1E('<@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C(*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@
M9&5T86EL<R(*;7-G<W1R(")3>F-Z96?SLWD@9&]T>6-ZL6-E(&1O9&%T:V]W
M>6-H(&EN9F]R;6%C:FDB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HY,PIM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T
M<B`B4WIC>F5G\[-Y(&1O='EC>K%C92!D;V1A=&MO=V5J('=I861O;6^V8VDB
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@
M=FEE=V5D("5S+B(*;7-G<W1R(")3>F-Z96?SLWD@9&]T>6-ZL6-E(&1O9&%T
M:V]W96H@=VEA9&]M;[9C:2!M;V>Q(&)YYB!Z87=A<G1E('<@)7,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N
M86P@;65S<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@(E-Z8WIE9_.S;W=E
M(&EN9F]R;6%C:F4@;R!BL^ID>FEE(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M
M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T
M<B`B4WIC>F5G\[-O=V4@:6YF;W)M86-J92!O(&*SZF1Z:64@;6^_;F$@<')Z
M96=LL61NL>8@=R`E<RXB"@HC.B!C;VYT86-T<RYP:'`Z.3`@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S,P('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T
M+FEN8SHU-0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DMS:;&_:V$@
M861R97-O=V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED
M(")!9&1R97-S($)O;VMS(@IM<V=S='(@(DMS:;&_:VD@861R97-O=V4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"FUS9VED("(B"B)!9&1R97-S
M97,@=&\@0D-#(&%L;"!M97-S86=E<SH@/&D^*&]P=&EO;F%L+"!E;G1E<B!E
M86-H(&%D9')E<W,@;VX@82!N97<@(@HB;&EN92D\+VD^(@IM<V=S='(@(B(*
M(D%D<F5S($)#0R!D;&$@=W-Z>7-T:VEC:"!W:6%D;VUOMF-I.B`\:3XH;W!C
M:F]N86QN:64L('=P<F]W862\(&MAOV1Y(&%D<F5S('<@(@HB;F]W96H@;&EN
M:6DI/"]I/B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S,*;7-G:60@
M(B(*(D%D9')E<W-E<R!T;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES(&ED96YT
M:71Y.B`\:3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D<F5S<R!O;B!A
M(&YE=R!L:6YE*3PO:3XB"FUS9W-T<B`B(@HB061R97-Y(+9C:;9L92!P<GIY
M=VFQ>F%N92!D;R!T96H@=&^_<V%M;[9C:3H@/&D^*&]P8VIO;F%L;FEE+"!W
M<')O=V%DO"!K8;]D>2`B"B)A9')E<R!W(&YO=V5J(&QI;FEI*3PO:3XB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$P(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.3(*;7-G:60@(D%L;"(*;7-G<W1R(")7<WIY<W1K;R(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C4*;7-G:60@
M(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W
M:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G
M<W1R("(B"B)7<WIY<W1K:64@=VEA9&]M;[9C:2!W(&9O;&1E<GIE*&%C:"D@
M8NIDL2"V8VFQ9V%N92!D;R!J961N96=O('!L:6MU($U"3U@Z(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R(%PB)7-<(B!F
M;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@
M(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB5W-Z>7-T:VEE('=I861O;6^V8VD@
M=R!F;VQD97)Z92!<(B5S7"(L('-T87)S>F4@;FF_("5S(&1N:2P@>F]S=&%N
ML2`B"B)B97IP;W=R;W1N:64@<VMA<V]W86YE+B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM
M<V=S='(@(B(*(E=S>GES=&MI92!S=&%R92!L:6YK:2!Z8;.Q8WIN:6OS=R!S
M=&%R<WIE(&YIOR`E<R!M:65S:>IC>2!Z;W-T86ZQ('-K87-O=V%N92XB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL
M>2YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S96YT+6UA
M:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E
M;&5T960N(@IM<V=S='(@(B(*(E=S>GES=&MI92!S=&%R92!F;VQD97)Y('-E
M;G0M;6%I;"P@>F$@=WEJL71K:65M("5S(&YA:FYO=W-Z>6-H+"!Z;W-T86ZQ
M("(*(G-K87-O=V%N92XB"@HC.B!A8VPN<&AP.C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S9G5L
M;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(B(*(E=S>GES
M=&EE('5P<F%W;FEE;FEA(&9O;&1E<G4@7"(E<UPB(&1L82!UOWET:V]W;FEK
M82!<(B5S7"(@>F]S=&&S>2!U<W5N:>IT92(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHU-0IM<V=I9"`B06QL;W<@9FEL=&5R(')U;&5S('1O
M(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(E!O>G=O;&GF
M(&YA('IA<W1O<V]W86YI92!F:6QT<O-W(&1L82!W<WIY<W1K:6-H('-K<GIY
M;F5K/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$P
M"FUS9VED(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*
M;7-G<W1R(")!;'1E<FYA='EW;F4@8WKJMF-I(&1L82!T96H@<V5K8VII.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C4@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4W-PIM<V=I9"`B06QW87ES(@IM<V=S='(@(EIA=W-Z92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3`*;7-G:60@(D%L=V%Y<R!S879E
M(&%T=&%C:&UE;G1S(@IM<V=S='(@(EIA=W-Z92!Z87!I<W5J('IAL[%C>FYI
M:VDB"@HC.B!L:6(O365S<V%G92YP:'`Z-#8X"FUS9VED("(B"B)!;B!E<G)O
M<B!O8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C
M:&UE;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B(@HB
M5WES=+%P:;,@8K.Q9"!P;V1C>F%S('!R\V)Y('5S=6YIZF-I82!Z8;.Q8WIN
M:6MA+B!397)W97(@24U!4"!Z=W+S8VFS("(*(F]D<&]W:65DO#HB"@HC.B!L
M:6(O365S<V%G92YP:'`Z,S8T"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C
M8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+B(*;7-G<W1R(")7
M>7-TL7!ILR!N:65Z;F%N>2!BL[%D('!O9&-Z87,@='=O<GIE;FEA(&YO=V5G
M;R!Z861A;FEA+B(*"B,Z(&UA:6QB;W@N<&AP.C8Y,R!M97-S86=E+G!H<#HT
M.#0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHY"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3@@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E
M;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D(@IM<V=S='(@(D]D<&]W:65D>FEA
M;F4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS9VED(")!
M;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")7:6%D;VUOMF-I('H@;V1P;W=I
M961Z:;$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*;7-G
M:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B6F%S=&]S=6H@9FEL=')Y(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`B6F%S=&]S
M=6H@9FEL=')Y(&1O("5S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C0S"FUS9VED(")!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG
M(&]N/R(*;7-G<W1R("):87-T;W-O=V'F(&9I;'1R>2!P;V1C>F%S(&QO9V]W
M86YI83\B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#D*;7-G
M:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P
M;&%Y960_(@IM<V=S='(@(EIA<W1O<V]W8>8@9FEL=')Y('!O9&-Z87,@=WFV
M=VEE=&QA;FEE($]D96)R86YE/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDS"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\B
M"FUS9W-T<B`B0WIY(&-H8V5S>B!U<W5NL>8@=&5N(&ML=6-Z('!U8FQI8WIN
M>3\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$R."!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,38Y"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E
M8V]M;65N9&5D(2DB"FUS9W-T<B`B0WIY(&-H8V5S>B!U<W5NL>8@5'=O:K$@
M<&%R82!K;'5C>GD_("AN:65Z86QE8V%N92$I(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YJ<SHV"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI
M<S\B"FUS9W-T<B`B0WIY(&-H8V5S>B!N82!P97=N;R!T;R!Z<F]B:>8_(@H*
M(SH@;65S<V%G92YP:'`Z,SDQ('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I
M<'0N:6YC.C8X"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$52
M34%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R(")#>GD@
M8VAC97-Z('5S=6ZQYB!C8;-K;W=I8VEE('1E('=I861O;6^V8VD_(@H*(SH@
M;&EB+TU)344O0V]N=&5N=',N<&AP.C(P,@IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE
M;G0_(@IM<V=S='(@(D-Z>2!C:&-E<WH@=7-U;K'F(&-ALVMO=VEC:64@=&4@
M>F&SL6-Z;FEK:3\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H
M:7,@9F]L9&5R/R(*;7-G<W1R(")#>GD@8VAC97-Z(&]P<O._;FGF('1E;B!F
M;VQD97(_(@H*(SH@;&EB+TE-4"YP:'`Z.3,Q"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S
M='(@(D-Z>2!C:&-E<WH@;W!R\[]N:>8@:V]S>C\B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHX"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*
M;7-G<W1R(")#>GD@8VAC97-Z('5S=6ZQYB!C8;-K;W=I8VEE('1E('=I861O
M;6^V8VD_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z
M.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E
M(&%S(&EN;F]C96YT/R(*;7-G<W1R(")#>GD@8VAC97-Z('IGLV]S:>8@=.H@
M=VEA9&]M;[;F(&IA:V\@;FEE<WIK;V1L:7>Q/R(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E<R]M86EL8F]X+VIA
M=F%S8W)I<'0N:6YC.C<T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*;7-G<W1R(")#>GD@
M8VAC97-Z('IGLV]S:>8@=.H@=VEA9&]M;[;F(&IA:V\@<W!A;3\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#@W"FUS9VED(")!<G)I=F%L(%1I;64B
M"FUS9W-T<B`B0WIA<R!P<GIY8GEC:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3`R"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B5WIR87-T86JQ
M8V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-S8*;7-G:60@(D%S:R(*;7-G<W1R("):87!Y=&%J(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`Y"FUS9VED(")!
M='1A8V@B"FUS9W-T<B`B6F&SL6-Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#8V"FUS9VED(")!='1A8V@@1FEL97,B"FUS9W-T<B`B
M6F&SL6-Z('!L:6MI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#0W"FUS9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI
M8R!K97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R("):8;.Q8WIYYB!K;W!I
MZB!4=V]J82!K;'5C>F$@<'5B;&EC>FYE9V\@4$=0(&1O('=I861O;6^V8VD_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.0IM<V=I9"`B071T
M86-H960@1FEL93HB"FUS9W-T<B`B6F&SL6-Z;VYE('!L:6MI.B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS-C(@;&EB+T-O;7!O<V4N<&AP.C0T-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S
M('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE
M9"XB"FUS9W-T<B`B(@HB6F&SL6-Z;VYY('!L:6L@7"(E<UPB('!R>F5K<F%C
M>F$@;&EM:70@<F]Z;6EA<G4@>F&SL6-Z;FEK82X@4&QI:R`B"B)N:65Z8;.Q
M8WIO;GDN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,W-@IM<V=I
M9"`B071T86-H960@:7,@82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@
M>6]U('-E;G0N(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C<R.2!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$V"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-"!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT.38*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N
M:G,Z.3@*;7-G:60@(D%T=&%C:&UE;G0B"FUS9W-T<B`B6F&SL6-Z;FEK(@H*
M(SH@8V]M<&]S92YP:'`Z,3`P,2!L:6(O365S<V%G92YP:'`Z-#(Y"FUS9VED
M(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y
M<&4B"FUS9W-T<B`B6F&SL6-Z;FEK('=Y;6%Z86YY.B!/<GEG:6YA;&YY('1Y
M<"!Z8;.Q8WIN:6MA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0V-`HC.B!L
M:6(O0V]M<&]S92YP:'`Z.3@T"FUS9VED(")!='1A8VAM96YT<R(*;7-G<W1R
M("):8;.Q8WIN:6MI(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X
M,@IM<V=I9"`B071T96YD965S(@IM<V=S='(@(E5C>F5S=&YI8W1W82(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"FUS9VED(")!
M='1E;G1I;VXB"FUS9W-T<B`B57=A9V$B"@HC.B!L:6(O075T:"]I;7`N<&AP
M.C0T"FUS9VED(")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM<#H@5WEM86=A;F4@<F]Z<WIE
M<GIE;FEE($E-05`@;FEE('IN86QE>FEO;F4N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8S-`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W(&EM
M86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M
M>2`B"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@HB075T;VUA='EC>FYI92!P
M;VMA>GEW8>8@>F1JZF-I82!W('=I86UO;6^V8VEA8V@@2%1-3"!O9"!A=71O
M<F$L(&MT\W)Y("(*(GIN86ID=6IE('-IZB!W(&UO:F5J(&MS:;&_8V4@861R
M97-O=V5J/R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC
M.C(Y.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@
M(D1O<W3J<&YE(&MS:;&_:VD@861R97-O=V4Z(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<Q.0IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS
M9W-T<B`B3V-Z96MU:K%C92!N82!O9'!O=VEE9+PB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*
M;7-G:60@(D)A8U]K('1O("5S(@IM<V=S='(@(E!O=W+S="!D;R`E<R`H7VLI
M(@H*(SH@=&AR96%D+G!H<#HX-B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8VL@=&\@
M)7,B"FUS9W-T<B`B4&]W<O-T(&1O("5S(@H*(SH@;65S<V%G92YP:'`Z,C4P
M('-E87)C:"YP:'`Z,30W('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`*
M;7-G:60@(D)C8R(*;7-G<W1R(")"8V,B"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W(&ES('1H92!R87<@=&5X="!O
M9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(E!O
M;FF_96H@:F5S="!Z=WEKLWD@=&5K<W0@>B!W:6%D;VUOMF-I(&EN9F]R;6%C
M>6IN96HN(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED
M(")";&%C:VQI<W0B"FUS9W-T<B`B0WIA<FYA(&QI<W1A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8R,@IM<V=I9"`B0FQO8VL@:6UA9V5S(&EN($A4
M34P@;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I9FEC86QL>2!R97%U
M97-T960_(@IM<V=S='(@(D)L;VMU:B!O8G)A>FMI('<@=VEA9&]M;[9C:6%C
M:"!(5$U,+"!C:'EB82"_92!J97-T('-P96-J86QN82!P<F^V8F$_(@H*(SH@
M<V5A<F-H+G!H<#HQ-34*;7-G:60@(D)O9'DB"FUS9W-T<B`B5')EMN8B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C(S('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z,SD*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU
M-2!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C<Q"FUS9VED(")";W1H(@IM
M<V=S='(@(D]B82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#$*;7-G
M:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*
M;7-G<W1R(").86>S\W=E:R!I('1R9;;F(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,C@S"FUS9VED(")#7VAA<G-E="(*;7-G<W1R(")5
M:[-A9"!Z;F%K\W<@*%]H*2(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YD87)Z(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N;W0@
M8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R(")"
ML[%D('!OL[%C>F5N:6$@>F4@>F1A;&YY;2!S97)W97)E;2!P;V-Z='DN(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ.3D*;7-G:60@(D-A;B!N;W0@
M8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B`B"FUS9W-T<B`B
M0K.Q9"!P;[.Q8WIE;FEA('IE('ID86QN>6T@<V5R=V5R96T@<&]C>G1Y.B`B
M"@HC.B!L:6(O34E-12]6:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E
M<R!O9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@
M(@HB;6%I;&)O>"XB"FUS9W-T<B`B(@HB3FEE(&UO9^H@=WFV=VEE=&QIYB`M
M('IN86QA>K-E;2!T>6QK;R`E<R!Z("5S(&-ZZK9C:2!T96H@=VEA9&]M;[9C
M:2!W("(*(G-K<GIY;F-E('!O8WIT;W=E:BXB"@HC.B!F;VQD97)S+G!H<#HR
M-S,@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,C(*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K
M97DN:6YC.C@U('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C<*
M(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,B!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C8V"FUS9VED(")#86YC96PB"FUS9W-T<B`B
M06YU;'5J(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S`@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(V"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,38*;7-G:60@(D-A;F-E;"!-97-S
M86=E(@IM<V=S='(@(D%N=6QU:B!W:6%D;VUOMN8B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FIS.C8*;7-G:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@
M<&5R;6%N96YT;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(D%N
M=6QO=V%N:64@=&5J('=I861O;6^V8VD@=7-U;FEE(&IE:B!Z87=A<G1OMN8@
M8F5Z<&]W<F]T;FEE+B(*"B,Z(&UE<W-A9V4N<&AP.C(T.2!S96%R8V@N<&AP
M.C$T,R!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC.B!T
M96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U"FUS9VED(")#8R(*
M;7-G<W1R(")#8R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#$*
M;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R(").86-Z96QN>2(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX-@IM<V=I9"`B0VAA;F=E
M(@IM<V=S='(@(EIM;FEE\2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHX-PIM<V=I9"`B0VAA;F=E($%L;"(*;7-G<W1R("):;6EE\2!7
M<WIY<W1K;R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-R!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z.3@*;7-G:60@(D-H86YG92!&;VQD97(B"FUS9W-T
M<B`B6FUI9?$@9F]L9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,0IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO
M=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E(&%N9"`B"B)H
M;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`B(@HB6FUI86YY(&]P
M8VII('=YMG=I971L86YI82!T86MI8V@@:F%K.B!I;&^VYB!W:6%D;VUOMF-I
M('=I9&]C>FYY8V@@;F$@(@HB<&]S>F-Z96?S;&YY8V@@<W1R;VYA8V@L('-O
M<G1O=V%N:64@=VEA9&UOMF-I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-`IM<V=I9"`B0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T
M=&EN9W,N(@IM<V=S='(@(EIM:67Q('-E<G=E<B!P;V-Z='D@:2!U<W1A=VEE
M;FEA(&9O;&1E<G4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U"FUS
M9VED("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U
M<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"`B"B)R97!L
M>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B):;6EE\2!N87IWZBP@861R
M97,@:2!P;V1P:7,L(&MT\W)Y(&QU9'II92!W:61ZL2!P;V1C>F%S(&-Z>71A
M;FEA(&D@(@HB;V1P;W=I861A;FEA(&YA(%1W\VH@96UA:6PN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y,PIM<V=I9"`B0VAA<F%C=&5R<R!T;R!D
M:7-P;&%Y.B(*;7-G<W1R("):;F%K:2!D;R!W>;9W:65T;&5N:6$Z(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3,*;7-G:60@(D-H96-K
M($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B4W!R87=D>F%J(&9O
M;&1E<BAY*2!C>GD@:F5S="!N;W=A('!O8WIT82(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHW,0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S
M='(@(EI?87IN86-Z(%=S>GES=&MO+TYI8R(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO9F5T8VAM86EL+FEN8SHQ-`IM<V=I9"`B0VAE8VL@86QL(&UA:6P@
M<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S='(@
M(E-P<F%W9'IA:B!W<WIY<W1K:64@<V5R=V5R>2!P;V-Z='DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4T"FUS9VED(")#:&5C:R!S<&5L;&EN9R!B
M969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(E-P<F%W9'IAYB!P
M:7-O=VYIZB!P<GIE9"!W>7.S86YI96T@=VEA9&]M;[9C:3\B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT"FUS9VED(")#:&]O<V4@06-T
M:6]N.B(*;7-G<W1R(")7>6)I97)Z(&%K8VKJ.B(*"B,Z(&-O;F9I9R]S97)V
M97)S+G!H<"YD:7-T.C$Y-0IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z
M(@IM<V=S='(@(E=Y8FEE<GH@<V5R=V5R('!O8WIT;W=Y.B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-R!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHQ-S<*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C(X"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E
M9&ET('1H92!A9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`B5WEB:65R
M>B!L=6(@961Y='5J('<@;VMN:64Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4R,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,Q"FUS9VED
M(")#:&]O<V4@86X@86-T:6]N.B(*;7-G<W1R(")7>6)I97)Z(&]P97)A8VKJ
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,T.0IM
M<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D
M:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B5WEB:65R>B!K<VFQOVOJ(&%D<F5S
M;W>Q+"!D;R!K=/-R96H@8NIDL2!D;V1A=V%N92!A9')E<WDN(@H*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"FUS9VED(")#:&]O
M<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H96X@
M97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB5WEB:65R>B!K;VQE
M:FYOMN8@<')Z97-Z=6MI=V%N:6$@:W-IL;]E:R!A9')E<V]W>6-H('!O9&-Z
M87,@<F]Z<WIE<GIA;FEA("(*(F%D<F5S\W<N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K
M("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y
M;W5R(&)R;W=S97(@8V%N('9I97<N(@IM<V=S='(@(B(*(DML:6MN:6H@)7,L
M(&%B>2!Z;6EE;FGF(&9O<FUA="!O8G)A>FMA(&YA(&]B<[-U9VEW86YY('!R
M>F5Z('1W;VJQ("(*(G!R>F5G;+%D87)KZBXB"@HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E
M<R!T;R!D;W=N;&]A9"!T:&4@:6UA9V4N(@IM<V=S='(@(DML:6MN:6H@='5T
M86HL(&%B>2!Z87!I<V%C(&]B<F%Z96L@)7,N(@H*(SH@;&EB+T9I;'1E<BYP
M:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O
M("5S(&UA;F%G96UE;G0@<&%G92XB"FUS9W-T<B`B2VQI:VYI:B`E<RP@86)Y
M('#S:K;F(&1O('-T<F]N>2!Z87)ZL61Z86YI82`E<RXB"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3(X"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN
M9&]W+B(*;7-G<W1R(")+;&EK;FEJ("5S(&%B>2!Z;V)A8WIYYB!Z87=A<G1O
MMN8@2%1-3"!W(&]S;V)N>6T@;VMN:64N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S
M('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B
M2VQI:VYI:B`E<R!A8GD@>F]B86-Z>>8@;6EN:6%T=7)KZB!T96=O(&]B<F%Z
M:V$N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N
M="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B2VQI:VYI:B`E<R!A
M8GD@>F]B86-Z>>8@>F&SL6-Z;FEK('<@;W-O8FYY;2!O:VYI92XB"@HC.B!L
M:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D
M('!A<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(DML:6MN:6H@
M)7,L(&%B>2!Z;V)A8WIYYB!Z8;.Q8WIN:6L@=R!O<V]B;GEM(&]K;FEE+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#0*;7-G:60@(D-L:6-K
M(&AE<F4@=&\@2$E$12!T:&4@26UA9V5S(@IM<V=S='(@(DML:6MN:6H@='5T
M86H@86)Y('5K<GGF(&]B<F%Z:VDB"@HC.B!L:6(O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3`X"FUS9VED(")#;&EC:R!H97)E('1O(%-(3U<@=&AE($EM86=E
M<R(*;7-G<W1R(")+;&EK;FEJ('1U=&%J(&%B>2!P;VMA>F'F(&]B<F%Z:VDB
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*;7-G
M:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@
M8F]O:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H
M+B(*;7-G<W1R("(B"B)+;&EK;FEJ(&YA(&IE9&YY;2!Z('=Y8G)A;GEC:"!K
M<VFQOV5K(&%D<F5S;W=Y8V@@:2!O:W)EMFP@<&]L82!W962S=6<@(@HB:W3S
M<GEC:"!R;WIP;V-ZL>8@<WIU:V%N:64N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,3<Q"FUS9VED(")#;&EC:R!T;R!3879E(%!'4"!0=6)L:6,@
M2V5Y(&EN('EO=7(@061D<F5S<R!B;V]K(@IM<V=S='(@(B(*(DML:6MN:6H@
M='5T86HL(&%B>2!Z86-H;W=AYB!K;'5C>B!P=6)L:6-Z;GD@4$=0('<@5'=O
M:F5J(&MS:;&_8V4@861R97-O=V5J(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HQ.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@=&\@4V%V
M92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B(@HB2VQI:VYI:B!T=71A:BP@86)Y('IA8VAO=V'F(&-E
M<G1Y9FEK870@4R]-24U%("5S('<@5'=O:F5J(&MS:;&_8V4@861R97-O=V5J
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I9"`B0VQI8VMI
M;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@
M=&\@=&AE('-E;F1E<B(*;7-G<W1R(")+;&EK;FGJ8VEE(&YA(&%D<F5S('-P
M;V1O=W5J92!S='=O<GIE;FEE(&YO=V5J('=I861O;6^V8VD@9&\@875T;W)A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,@IM<V=I9"`B0VQI8VMI
M;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E
M(')E860B"FUS9W-T<B`B2VQI:VYIZF-I92!N82!A9')E<R!S<&]W;V1U:F4@
M;W1W87)C:64@=VEA9&]M;[9C:2!D;R!C>GET86YI82(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHS,`IM<V=I9"`B0VQO<V4B"FUS
M9W-T<B`B6F%M:VYI:B(*"B,Z(&-O;7!O<V4N<&AP.C<W-2!C;VUP;W-E+G!H
M<#HQ,#@R"FUS9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R("):86UK
M;FEJ('1O(&]K;F\B"@HC.B!F;VQD97)S+G!H<#HT,38*;7-G:60@(D-L;W-E
M9"!&;VQD97(B"FUS9W-T<B`B1F]L9&5R('IA;6MN:>IT>2(*"B,Z(&9O;&1E
M<G,N<&AP.C0S-@IM<V=I9"`B0V]L;&%P<V4B"FUS9W-T<B`B6G=I\2(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,T"FUS9VED(")#;VQL
M87!S92!!;&PB"FUS9W-T<B`B6G=I\2!W<WIY<W1K;R(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,T"FUS9VED(")#;VQL87!S92!!;&P@
M1F]L9&5R<R(*;7-G<W1R("):=VGQ('=S>GES=&MI92!F;VQD97)Y(@H*(SH@
M9F]L9&5R<RYP:'`Z-#,V"FUS9VED(")#;VQL87!S92!&;VQD97(B"FUS9W-T
M<B`B6G=I\2!F;VQD97(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC871O<CH@(@IM<V=S='(@(DMO
M;&]R('=S:V%Z=6JQ8WDZ("(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M.3$*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M96YT87)Z(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<V.0IM<V=I9"`B0V]M<&QE=&5D(@IM
M<V=S='(@(E5K;_%C>F]N92(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M.2!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HT,@IM<V=I9"`B0V]M<&]S
M92(*;7-G<W1R(")4=_-R>B(*"B,Z(&UA:6QB;W@N<&AP.C<U-B!L:6(O34E-
M12](96%D97)S+G!H<#HQ.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]M<&]S
M92!-97-S86=E("@E<RDB"FUS9W-T<B`B5'?S<GH@=VEA9&]M;[;F("@E<RDB
M"@HC.B!C;VUP;W-E+G!H<#HW-S0@8V]M<&]S92YP:'`Z,3`X,0IM<V=I9"`B
M0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B"FUS9W-T<B`B5'?S<GH@:6YNL2!W
M:6%D;VUOMN8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED
M(")#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G
M<W1R(")4=V]R>GGF('=I861O;6^VYB!W(&]S;V)N>6T@;VMI;FEE/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(B(*(D-O;7!O<V4@
M;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W
M<V5R('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@HB5'?S
M<GH@9&]M>;9L;FEE('=I861O;6^V8VD@>B!'54D@2%1-3"`H:F6V;&D@5'=O
M:F$@<')Z96=LL61A<FMA(&]B<[-U9W5J92DB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E
M(&1I<W!L87EE9"XB"FUS9W-T<B`B2V]N9FEG=7)U:F4@<W!O<_-B('=YMG=I
M971L86YI82!W:6%D;VUOMF-I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-@IM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+B(*
M;7-G<W1R(")+;VYF:6=U<G5J92!O<&-J92!P;V1G;+%D=2!L:7-T=2XB"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO
M;B!T;R!S97)V97(@9F%I;&5D(@IM<V=S='(@(DYI92!N87=IL7IA;F\@<&^S
ML6-Z96YI82!Z('-E<G=E<F5M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%!'4"!S=7!P;W)T
M(&9O<B`E<RXB"FUS9W-T<B`B6F%R>K%D>F%N:64@;W!C:F%M:2!01U`@+2`E
M<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G
M<W1R("):87)ZL61Z86YI92!O<&-J86UI(%,O34E-12`M("5S+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B(@HB0V]N=')O;"!W:&5N
M(&YE=R!M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R
M(&YO="!T;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T
M<B`B(@HB6F%R>K%D>F%N:64@<W!R87=D>F%N:65M(&YO=WEC:"!W:6%D;VUO
MMF-I(&]R87H@:6YF;W)M;W=A;FEE;2!O(&EC:"`B"B)N861E:K9C:74N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y,0IM<V=I9"`B0V]N=F5R="!T
M97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R
M("):86UI96YI8>8@=&5K<W1O=V4@96UO=&EK;VYY(&YA(&=R869I8WIN93\B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'DB
M"FUS9W-T<B`B2V]P:6$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M-3$*;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@(DMO<&EU:B!D;R!F
M;VQD97)U(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8V
M"FUS9VED(")#;W)R96-T(@IM<V=S='(@(DMO<F5K=&$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,30U"FUS9VED(")#;W)R96-T960@
M5&5X="(*;7-G<W1R(")3:V]R>6=O=V%N>2!T96MS="(*"B,Z(&%T=&%C:&UE
M;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A
M=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G<W1R(").:64@;6^_;&EW92!U
M='=O<GIE;FEE('=S<&%R8VEA(%9&4SH@)7,B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C`S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R
M(").:64@;6^_;&EW92!U<W5N:>IC:64@=VEA9&]M;[9C:2!Z("5S+E-E<G=E
M<B!Z=W+S8VFS(&]D<&]W:65DO#H@)7,B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z
M,CDS"FUS9VED(")#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R
M871I;VYS+B(*;7-G<W1R(").:64@;6^_;&EW92!U<G5C:&]M:65N:64@;W!C
M:FD@:V]N<V5R=V%C:FDN(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I
M;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R(").:64@
M;6^_;&EW92!R;WIP86MO=V%N:64@<&QI:W4@>B!Z8;.Q8WIN:6MA($U3+51.
M148N(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O
M=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!:
M:7`@87)C:&EV92XB"FUS9W-T<B`B3FEE(&UOOVQI=V4@<F]Z<&%K;W=AYB!P
M;&EK\W<@>B!A<F-H:7=U;2!::7`N(@H*(SH@<V5A<F-H+G!H<#HS-C$@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C,Y('1E;7!L871E<R]A8VPO86-L+FEN8SHQ
M-3<*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W"FUS9VED
M(")#<F5A=&4B"FUS9W-T<B`B5'?S<GHB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHU"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@
M(E1W\W)Z(&9O;&1E<B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-3(*
M;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(E1W\W)Z(&ML=6-Z92(*"B,Z
M('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-`IM<V=I9"`B0W)E871E
M(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(E1W\W)Z('=I<G1U86QN>2!F;VQD
M97(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN
M8SHR-@IM<V=I9"`B0W)E871E(&$@3F5W($%C8V]U;G0B"FUS9W-T<B`B4W1W
M\W)Z(&YO=V4@:V]N=&\B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"FUS
M9VED(")#<F5A=&4@82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B4W1W\W)Z
M(&YO=WD@9F]L9&5R(&YA('-P86TB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L
M9&5R<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T
M+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W(&1R869T<R!F;VQD97(B"FUS
M9W-T<B`B5'=O<GIE;FEE(&YO=V5G;R!F;VQD97)U(')O8F]C>F5G;R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C<@=&5M<&QA
M=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,PIM<V=I9"`B0W)E871E
M(&$@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B5'=O<GIE;FEE(&YO
M=V5G;R!F;VQD97)U('!O8WIT>2!W>7.S86YE:B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H
M<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E
M<B(*;7-G<W1R(")4=V]R>F5N:64@;F]W96=O(&9O;&1E<G4@:V]S>F$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(P"FUS9VED("(B"B)#<F5A=&4@
M9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I
M;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE=&4@<W!A;2XB
M"FUS9W-T<B`B(@HB5'=O<GIE;FEE(')E9W6S(&9I;'1R;W=A;FEA(&D@;W)G
M86YI>F]W86YI82!N861C:&]D>K%C96H@<&]C>G1Y+"!S;W)T;W=A;FEE("(*
M(F1O(&9O;&1E<O-W+"!U<W5W86YI92!S<&%M=2XB"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A
M8V-E<W,@=&\@)7,B"FUS9W-T<B`B3V)E8VYY(&1O<W3J<"!D;R`E<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@(D-U<W1O;6EZ92!A
M8V-O=6YT<R!F;W(@9F5T8VAI;F<@;6%I;"!F<F]M(&]T:&5R(&%C8V]U;G1S
M+B(*;7-G<W1R(")$969I;FEO=V%N:64@:V]N="!O9&)I97)A:K%C>6-H('!O
M8WITZB!Z(&EN;GEC:"!K;VYT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4Q"FUS9VED(")#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN(@IM<V=S
M='(@(D1O<W1O<W5J('-P;W/S8B!W>7-YLV%N:6$@<&]C>G1Y(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T
M<B`B5WEB:65R>B!Z861A;FEA+"!K=/-R92!M86JQ(&)YYB!W>6MO;F%N92!P
M;V1C>F%S(&QO9V]W86YI82!D;R`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C$W"FUS9VED(")$871?92(*;7-G<W1R
M(")$871A("A?92DB"@HC.B!M97-S86=E+G!H<#HR-#8@=&AR96%D+G!H<#HY
M,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$871A(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<U-PIM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B3V1R
M>G5C;VYE(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,PIM<V=I
M9"`B1&5C;&EN960Z("(*;7-G<W1R(")/9')Z=6-O;F4Z("(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B
M1&]M>;9L;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DT"FUS9VED
M(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(D1O;7FV;&YE
M(&MR>71E<FEA('-O<G1O=V%N:6$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDP-`IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS
M9W-T<B`B1&]M>;9L;GD@<W!O<_-B('-O<G1O=V%N:6$Z(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<V-0IM<V=I9"`B1&5L96=A=&5D(@IM<V=S
M='(@(D]D9&5L96=O=V%N92(*"B,Z(&9O;&1E<G,N<&AP.C0P-R!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(T-`HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z-B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHX"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C$P('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C4*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(X('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.3,*
M;7-G:60@(D1E;&5T92(*;7-G<W1R(")5<W7Q(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHV-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS9W-T
M<B`B2VQU8WH@<'5B;&EC>FYY("5S('5S=6YIZG1Y(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHQ,C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$V
M.0IM<V=I9"`B1&5L971E($-U<G)E;G0@2V5Y<R(*;7-G<W1R(")5<W7Q(&]B
M96-N92!K;'5C>F4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHW"FUS9VED(")$96QE=&4@1F]L9&5R*',I(@IM<V=S='(@(E5S=?$@9F]L
M9&5R*'DI(@H*(SH@9F]L9&5R<RYP:'`Z,C<T"FUS9VED(")$96QE=&4@4V5L
M96-T960@1F]L9&5R<R(*;7-G<W1R(")5<W7Q('=Y8G)A;F4@9F]L9&5R>2(*
M"B,Z(&9O;&1E<G,N<&AP.C0P-PIM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L
M9&5R(@IM<V=S='(@(E5S=?$@=VER='5A;&YY(&9O;&1E<B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L971E(&9E
M=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G<W1R(")5
M<W5NL>8@=VEA9&]M;[9C:2!P;V)R86YE('IE('ID86QN96=O('-E<G=E<F$_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R.`IM<V=I9"`B1&5L
M971E(&9R;VT@;7D@8V%L96YD87(B"FUS9W-T<B`B57-U\2!Z(&UO:F5G;R!K
M86QE;F1A<GIA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,@IM<V=I
M9"`B1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG
M(&]F(&UO;G1H/R(*;7-G<W1R(")#>GD@=7-U=V'F('-T87)E('IAL[%C>FYI
M:VD@;F$@<&]C>K%T:W4@:V&_9&5G;R!M:65S:;%C83\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I
M;"!F;VQD97)S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B0WIY
M('5S=7=AYB!S=&%R>2!F;VQD97(@<&]C>G1Y('=Y<[-A;F5J(&YA('!O8WJQ
M=&MU(&MAOV1E9V\@;6EE<VFQ8V$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8Q,@IM<V=I9"`B1&5L971E('-P86T@;65S<V%G97,@869T97(@=&AE
M>2!H879E(&)E96X@<F5P;W)T960@87,@<W!A;3\B"FUS9W-T<B`B0WIY('5S
M=7=AYB!W:6%D;VUOMF-I('-P86T@<&\@>F>S;W-Z96YI=2!J86MO('-P86T_
M(@H*(SH@;6%I;&)O>"YP:'`Z-S$Y(&UE<W-A9V4N<&AP.C0X-R!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C(P"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHX
M"FUS9VED(")$96QE=&5D(@IM<V=S='(@(E5S=6YIZG1E(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B1&5L971E9"!M97-S86=E
M<R(*;7-G<W1R(")5<W5N:>IT92!W:6%D;VUOMF-I(@H*(SH@8V]M<&]S92YP
M:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@=&AE(&%T=&%C
M:&UE;G0@7"(E<UPB+B(*;7-G<W1R(")5<W5N:>IT;R!Z8;.Q8WIN:6L@7"(E
M<UPB+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B1&5L
M971I;F<@86YD($UO=FEN9R!-97-S86=E<R(*;7-G<W1R(")5<W5W86YI92!I
M('!R>F5N;W-Z96YI92!W:6%D;VUOMF-I(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(D]D
M<GIUYB!Z87!Y=&%N:64B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-30P"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;B(*;7-G<W1R(")/9')Z=>8@>F%P>71A;FEE(&\@:6YF;W)M86-JZB!W
M;VQN>2]Z86KJ='DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS
M9VED(")$97-C96YD:6YG(@IM<V=S='(@(DUA;&5JL6-O(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C(Q(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-CD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D]P
M:7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8U('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,3$S"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHY,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30W"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ-3$*;7-G:60@(D1E=&%I;',B"FUS9W-T<B`B4WIC>F5G
M\[-Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W,0IM<V=I9"`B1&EM
M('-I9VYA='5R97,_(@IM<V=S='(@(EIA<[-O;FGF('!O9'!I<WD_(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S8*;7-G:60@(D1I
M<W!L87DB"FUS9W-T<B`B5WFV=VEE=&QA;FEE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0W,`IM<V=I9"`B1&ES<&QA>2!C;VYF:7)M871I;VX@869T
M97(@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(E=YMG=I971L8>8@<&]T
M=VEE<F1Z96YI92!W>7.S86YE:B!W:6%D;VUOMF-I/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.#`*;7-G:60@(D1I<W!L87D@:6X@0F]D>2!O9B!-
M97-S86=E(@IM<V=S='(@(E=YMG=I971L86H@=R!T<F6V8VD@=VEA9&]M;[9C
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-C@*;7-G:60@(D1I<W!L
M87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\B"FUS9W-T<B`B
M3W1W:65R8>8@;F]W92!O:VYO('H@:6YF;W)M86-JL2!O(&YO=V5J('!O8WIC
M:64_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S,PIM<V=I9"`B1&ES
M<&QA>2!T:&4@)T5M<'1Y(%1R87-H)R!L:6YK(&EN('1H92!M96YU8F%R/R(*
M;7-G<W1R(")0;VMA>GEW8>8@<')Z>6-I<VL@)T]P<O._;FEJ(&MO<WHG(&YA
M('!A<VMU(&UE;G4_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:6YC.C$Q"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R(")2;WIM:65S
M>F-Z96YI92(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM
M<V=I9"`B1&\@3D]4(&UA=&-H(@IM<V=S='(@(DYI92!Z9V%D>F$@<VGJ(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,30*;7-G:60@(D1O
M($YO="!#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(DYI
M92!S<')A=V1Z86H@9F]L9&5R\W<@8WIY(&IE<W0@;F]W82!P;V-Z=&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(S"FUS9VED(")$;R!N;W0@9V5N
M97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS9W-T<B`B3FEE
M(&=E;F5R=6H@;&EN:V$@=R!P;VQU($]D.B!K;VQU;6YA(@H*(SH@;&EB+TE-
M4"YP:'`Z,3`S,0IM<V=I9"`B1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O
M;&1E<C\B"FUS9W-T<B`B0WIY(&-H8V5S>B!O='=O<GIYYB!T96X@9F]L9&5R
M/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G
M:60@(D1O;F4B"FUS9W-T<B`B6G)O8FEO;F\B"@HC.B!L:6(O34E-12]#;VYT
M96YT<RYP:'`Z,3DQ"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S
M(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(E!O8FEE<GH@)7,@=R!F;W)M86-I
M92`N>FEP(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3(*
M;7-G:60@(D1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE
M*2(*;7-G<W1R(")0;V)I97)Z('=S>GES=&MI92!Z8;.Q8WIN:6MI("AW('!L
M:6MU("YZ:7`I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,3@*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R(")0;V)I97)Z
M(&9O;&1E<BAY*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C$Y"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(*
M;7-G<W1R(")0;V)I97)Z(&9O;&1E<BAY*2!;9F]R;6%T("YZ:7!=(@H*(SH@
M;&EB+TU)344O0V]N=&5N=',N<&AP.C$Y,0IM<V=I9"`B1&]W;FQO860@:6X@
M+GII<"!&;W)M870B"FUS9W-T<B`B4&]B:65R>B!W(&9O<FUA8VEE("YZ:7`B
M"@HC.B!M86EL8F]X+G!H<#HV.3@@;65S<V%G92YP:'`Z-#@U('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3$*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHR,B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C0Q"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.0IM
M<V=I9"`B1')A9G0B"FUS9W-T<B`B4F]B;V-Z>2(*"B,Z(&9O;&1E<G,N<&AP
M.C,X-PIM<V=I9"`B1')A9G0@9F]L9&5R(@IM<V=S='(@(D9O;&1E<B!R;V)O
M8WIY(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*
M;7-G:60@(D1R869T<R!F;VQD97(Z(@IM<V=S='(@(D9O;&1E<B!R;V)O8WIY
M.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ.38*;7-G:60@(D4M;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D%D<F5S(&4M;6%I;"(*"B,Z(&QI8B]-86EL
M8F]X+G!H<#HS,#,*;7-G:60@(D5.1"(*;7-G<W1R(")+3TY)14,B"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-`IM<V=I9"`B15)23U(Z(%EO
M=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D+B(*;7-G<W1R(")"
ML[%D.B!4=V]J82!W:6%D;VUOMN8@;FEE(&UOOV4@8GGF(&1O<W1A<F-Z;VYA
M+B(*"B,Z(&9O;&1E<G,N<&AP.C0P.`IM<V=I9"`B161I="(*;7-G<W1R(")%
M9'ET=6HB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C$*;7-G
M:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(D5D>71U:B!C>F%R;K$@;&ES
M=.HB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,38*;7-G:60@
M(D5D:70@1FEL=&5R<R(*;7-G<W1R(")%9'ET=6H@9FEL=')Y(@H*(SH@9F]L
M9&5R<RYP:'`Z-#`X('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"FUS9VED(")%9&ET
M(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(D5D>71U:B!F;VQD97(@=FER='5A
M;&YY(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I
M;VX@9F]R("5S(@IM<V=S='(@(D5D>71U:B!D969I;FEC:F4@9F]L9&5R=2!W
M:7)T=6%L;F5G;R!D;&$@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,C8*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(D5D>71U
M:B!B:6&SL2!L:7-TZB(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHR,0IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*;7-G<W1R(")%9'ET
M=6H@=[-A<VZQ(&-Z87)NL2!L:7-TZB(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHQ-@IM<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(*
M;7-G<W1R(")%9'ET=6H@=[-A<VYE(&9I;'1R>2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,S`*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F
M;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(D5D
M>6-J82!P<F5F97)E;F-J:2!D;W-TZG!U(&1O(&EN;GEC:"!K;VYT('!O8WIT
M;W=Y8V@N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(V"FUS
M9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(D5D>6-J82!WLV%S
M;F5J(&)I8;-E:B!L:7-T>2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%D
M<F5S(&5M86EL(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8R,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G
M<W1R(")/<'+SO&YI;VYO('=S>GES=&MI92!W:6%D;VUOMF-I('H@)7,N(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C`*;7-G:60@(D5M
M<'1Y($9O;&1E<BAS*2(*;7-G<W1R(")/<'+SOVYI:B!F;VQD97(H>2DB"@HC
M.B!F;VQD97)S+G!H<#HR-S4*;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O;&1E
M<G,B"FUS9W-T<B`B3W!R\[]N:6H@=WEB<F%N92!F;VQD97)Y(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y(%1R
M87-H(&9O;&1E<B(*;7-G<W1R(")/<'+SOVYI:B!F;VQD97(@:V]S>F$B"@HC
M.B!L:6(O24U0+G!H<#HY,S$*;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R
M(")/<'+SOVYI:B!K;W-Z("A?="DB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C`@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$V"FUS9VED(")%
M;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(E>SL6-Z>>8@9G5N
M:V-J92!01U`_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR,"!T
M96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-@IM<V=I9"`B16YA8FQE
M(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")7L[%C>GGF(&9U;FMC
M:F4@4R]-24U%/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G
M:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G<W1R(")7L[%C>GGF
M('!O9&=LL60@=VEA9&]M;[9C:3\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,S,*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS
M9W-T<B`B3W!C:F4@:V]D;W=A;FEA("A?>2DB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3$W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3<*
M;7-G:60@(D5N9"(*;7-G<W1R(")+;VYI96,B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S,P"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B
M2V]N:65C('!R>F5K87IA;F5J('=I861O;6^V8VDB"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,C<Q"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R(")+;VYI96,@
M=VEA9&]M;[9C:2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR-CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B16YD(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")+;VYI
M96,@=VEA9&]M;[9C:2!O9"`E<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,3$W('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-3$*;7-G:60@(D5N
M=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B5W!R;W=A9+P@:&%SLV\B"@HC.B!T
M96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@
M=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(E=P
M<F]W862\(&YA>G?J(&1L82!T=V]J96=O(&YO=V5G;R!F;VQD97)U(&YA('-P
M86TB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHY"FUS
M9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E
M<B(*;7-G<W1R(")7<')O=V%DO"!N87IWZB!D;&$@='=O:F5G;R!N;W=E9V\@
M9F]L9&5R=2!R;V)O8WIE9V\B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA
M:6QS96QE8W0N:6YC.C(T"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")7<')O=V%DO"!N87IW
MZB!D;&$@='=O:F5G;R!N;W=E9V\@:V%T86QO9W4@<&]C>G1Y('=Y<[-A;F5J
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHY"FUS9VED
M(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R(@IM
M<V=S='(@(E=P<F]W862\(&YA>G?J(&1L82!T=V]J96=O(&YO=V5G;R!F;VQD
M97)U(&MO<WIA(@H*(SH@<V5A<F-H+G!H<#HQ-3D*;7-G:60@(D5N=&ER92!-
M97-S86=E(@IM<V=S='(@(D-ALV$@=VEA9&]M;[;F(@H*(SH@8V]M<&]S92YP
M:'`Z,3`V."!M97-S86=E+G!H<#HQ-S@@=&AR96%D+G!H<#HS.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%;G1R>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K(@IM<V=S='(@(E=P:7,@7"(E<UPB
M('IO<W1ALR!P;W!R87=N:64@9&]D86YY(&1O(%1W;VIE:B!K<VFQOVMI(&%D
M<F5S;W=E:B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-3@@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C@T"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,S8U(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X-@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@(D*SL60B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN
M9R!R97!L>3H@)7,N(@IM<V=S='(@(D*SL60@=WESLV%N:6$@;V1P;W=I961Z
M:3H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,0IM<V=I
M9"`B179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(E=Y9&%R
M>F5N:64@>F]S=&&S;R!U<W5N:>IT92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S4X"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-O
M(#$U(&UI;G5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U-0IM<V=I
M9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")#;R`S,"!S96MU;F0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4W"FUS9VED(")%=F5R>2`U(&UI
M;G5T97,B"FUS9W-T<B`B0V\@-2!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-3D*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#
M;R!P\[,@9V]D>FEN>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-38*
M;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")#;R!M:6YU=.HB"@HC.B!F
M;VQD97)S+G!H<#HT-#4*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")2;WIW:?$B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B
M17AP86YD($%L;"(*;7-G<W1R(")2;WIW:?$@=W-Z>7-T:V\B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B17AP86YD($%L
M;"!&;VQD97)S(@IM<V=S='(@(E)O>G=I\2!W<WIY<W1K:64@9F]L9&5R>2(*
M"B,Z(&9O;&1E<G,N<&AP.C0T-0IM<V=I9"`B17AP86YD($9O;&1E<B(*;7-G
M<W1R(")2;WIW:?$@9F]L9&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S,Q('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU
M-@IM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(E)O>G=I\2!N87IW>2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#(Q"FUS9VED(")%>'!A;F0@
M;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@
M=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(D%U=&]M871Y8WIN:64@<F]Z=VEJ
M8>8@;F%Z=WD@=R!O:VYI92!T=V]R>F5N:6$@=VEA9&]M;[9C:3\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")%>'!A;F0@=&AE(&5N
M=&ER92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I
M97<_(@IM<V=S='(@(E)O>G=I:F'F(&1O;7FV;&YI92!D<GIE=V\@=R!W:61O
M:W4@9F]L9&5R\W<_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,34U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(P-0HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-38@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$P-`IM<V=I9"`B17AP86YD:6YG(@IM<V=S
M='(@(E)O>G=I:F%N:64B"@HC.B!L:6(O24U0+G!H<#HY-#`@;&EB+TE-4"YP
M:'`Z.30R"FUS9VED(")&7V5T8V@@36%I;"(*;7-G<W1R(")0;V)I97)Z('!O
M8WITZB`H7V8I(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN
M:6YC.C(Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#,*;7-G:60@(D9E=&-H
M($UA:6PB"FUS9W-T<B`B4&]B:65R>B!P;V-Z=.HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#,Y"FUS9VED(")&971C:"!-86EL(&EN(&$@<V5P87)A
M=&4@=VEN9&]W/R(*;7-G<W1R(")0;V)R8>8@<&]C>G3J('<@;W-O8FYY;2!O
M:VYI93\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#8*
M;7-G:60@(D9E=&-H(&UE<W-A9V5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T
M<B`B4&]B:65R8>8@<&]C>G3J('!O9&-Z87,@;&]G;W=A;FEA/R(*"B,Z(&QI
M8B]&971C:&UA:6PN<&AP.C(X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&971C
M:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,B"FUS9W-T<B`B4&]B<F%N;R`E9"!W
M:6%D;VUOMF-I('H@)7,B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*
M;7-G<W1R(")0;V)R86YO(#$@=VEA9&]M;[;F('H@)7,B"@HC.B!L:6(O1F5T
M8VAM86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C
M:&UA:6PN<&AP.C(X.0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B4&]B
M<F%N;SH@(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"FUS9VED(")&971C
M:&UA:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B4&]B<F%N;SH@8G)A
M:R!N;W=Y8V@@=VEA9&]M;[9C:2XB"@HC.B!L:6(O24U0+G!H<#HY-#8*;7-G
M:60@(D9I7VQT97)S(@IM<V=S='(@(D9I7VQT<GDB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT.3(@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:G,Z.#,*;7-G:60@(D9I;&4B"FUS9W-T<B`B4&QI:R(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS-0IM<V=I9"`B1FEL=&5R
M($]P=&EO;G,B"FUS9W-T<B`B3W!C:F4@9FEL=')O=V%N:6$B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.`IM<V=I9"`B1FEL=&5R(%-E='1I
M;F=S(@IM<V=S='(@(E5S=&%W:65N:6$@9FEL=')U(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4Y-`IM<V=I9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N
M="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R(")&:6QT<G5J('IA=V%R=&^VYB!W
M:6%D;VUOMF-I('IE('=Z9VSJ9'4@;F$@=W5L9V%R;F^VYC\B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C@*;7-G:60@(D9I;'1E<B!S
M=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")/
M8G.S=6=A(&9I;'1R\W<@:F5S="!W>;.Q8WIO;F$@;F$@='EM('-Y<W1E;6EE
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3D*;7-G:60@(D9I;'1E
M<G,B"FUS9W-T<B`B1FEL=')Y(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T
M86-T:79E+FEN8SHR"FUS9VED(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T
M<B`B1FEL=')Y($Y)12!A:W1Y=VYE(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`V
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<G,Z("5S(&UA;F%G96UE;G0@
M<&%G92(*;7-G<W1R(")&:6QT<GDZ('-T<F]N82!Z87)ZL61Z86YI82`E<R(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS9VED
M(")&:6YD(@IM<V=S='(@(EIN86IDO"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-S8*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")0
M:65R=W-Z82!S=')O;F$@<VMR>GEN:VD@<&]C>G1O=V5J(@H*(SH@;6%I;&)O
M>"YP:'`Z,S0Q"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(E!I97)W<WIA
M('-T<F]N82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I
M9"`B1F]?<G=A<F0B"FUS9W-T<B`B4')Z96MAOR`H7W(I(@H*(SH@9F]L9&5R
M<RYP:'`Z,C4U('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH
M=&UL.C4*;7-G:60@(D9O;&1E<B!!8W1I;VYS("T@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(D-Z>6YN;[9C:2!N82!K871A;&]G86-H("T@<&]T=VEE<F1Z96YI
M92(*"B,Z(&9O;&1E<G,N<&AP.C(Y,B!T96UP;&%T97,O9F]L9&5R<R]H96%D
M+FEN8SHY"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI
M;F,Z-@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC
M.C$P"FUS9VED(")&;VQD97(@3F%V:6=A=&]R(@IM<V=S='(@(DYA=VEG871O
M<B!F;VQD97+S=R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<U
M"FUS9VED(")&;VQD97(@4')E9FEX(@IM<V=S='(@(E!R969I>"!F;VQD97)U
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D9O;&1E<B!3
M=6UM87)Y(@IM<V=S='(@(E!O9'-U;6]W86YI92!F;VQD97)U(@H*(SH@86-L
M+G!H<#HR-`IM<V=I9"`B1F]L9&5R('-H87)I;F<@:7,@;F]T(&5N86)L960N
M(@IM<V=S='(@(E5D;W-TZG!N:6%N:64@9F]L9&5R=2!N:64@:F5S="!A:W1Y
M=VYE+B(*"B,Z(&9O;&1E<G,N<&AP.C4R"FUS9VED(")&;VQD97(@=7-E(&ES
M(&YO="!E;F%B;&5D+B(*;7-G<W1R(")5OWEC:64@9F]L9&5R=2!N:64@:F5S
M="!A:W1Y;G=E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#`*;7-G
M:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL8F]X('9I
M97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@(B(*"B,Z(&-O
M;7!O<V4N<&AP.C<R-R!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,34*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*
M;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B4')Z96MAOR(*"B,Z(&-O;7!O<V4N
M<&AP.C<Q,@IM<V=I9"`B1F]R=V%R9#HB"FUS9W-T<B`B4')Z96MAOSHB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,CDY"FUS9VED(")&;W)W87)D960@;65S<V%G
M92(*;7-G<W1R(")0<GIE:V%Z86YA('=I861O;6^VYB(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]R=V%R9&5D(&UE
M<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")0<GIE:V%Z86YA('=I861O;6^VYB!O
M9"`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*;7-G:60@
M(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VIA('=O
M;&YY+WIA:NIT>2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.30*
M;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R(")/9'!O=VEE9+P@=V]L
M;GDO>F%JZG1Y(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`IM
M<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B6F%P>71A;FEE('=O
M;&YY+WIA:NIT>2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*
M;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(D]D
M<&]W:65DO"!N82!Z87!Y=&%N:64@=V]L;GDO>F%JZG1Y(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR-PIM<V=I9"`B1G)O
M7VTB"FUS9W-T<B`B3V0@*%]M*2(*"B,Z(&UE<W-A9V4N<&AP.C(T-R!S96%R
M8V@N<&AP.C$S-2!T:')E860N<&AP.CDS"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.CDX"FUS9VED(")&<F]M(@IM<V=S='(@(D]D(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X.0IM<V=I9"`B1G)O;2!!9&1R97-S
M(@IM<V=S='(@(D%D<F5S(&]D(@H*(SH@8V]M<&]S92YP:'`Z-S(T(&-O;7!O
M<V4N<&AP.C<R.`IM<V=I9"`B1G=D.B(*;7-G<W1R(")&=V0Z(@H*(SH@8V]M
M<&]S92YP:'`Z,3(R.0IM<V=I9"`B1G=D.B`B"FUS9W-T<B`B1G=D.B`B"@HC
M.B!C;VUP;W-E+G!H<#HQ,C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D9W9#H@
M)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(D9W9#H@)74@<')Z96MA
M>F%N92!W:6%D;VUOMF-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")'96YE
M<F%L($]P=&EO;G,B"FUS9W-T<B`B3W!C:F4@9[/S=VYE(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,W"FUS9VED(")'970@;VYL>2!N
M97<@;65S<V%G97,_("A)34%0(&]N;'DI(@IM<V=S='(@(E!O8FEE<F%J('1Y
M;&MO(&YO=V4@=VEA9&]M;[9C:2`H='EL:V\@24U!4"DB"@HC.B!T:')E860N
M<&AP.C@U"FUS9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@(DEDO"!D;R!W
M:6%D;VUOMF-I(@H*(SH@;&EB+TE-4"YP:'`Z-34S"B,L('!H<"UF;W)M870*
M;7-G:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS
M9W-T<B`B262\(&1O('=P:7-U(%PB)7-<(B!W(&MS:;&_8V4@861R97-O=V5J
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@
M86-C97-S(@IM<V=S='(@(E!R>GEZ;F%J(&1O<W3J<"(*"B,Z(&UE<W-A9V4N
M<&AP.C4S,"!L:6(O1FEL=&5R+G!H<#HQ,#8@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.34*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$R.`HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-
M12]6:65W97(O<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HT,#<*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT
M,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$R-PIM<V=I9"`B2$5212(*;7-G<W1R(")4551!2B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,CD@;&EB+TU)344O5FEE=V5R+W)E;&%T960N
M<&AP.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!C;VUP;W-E
M+G!H<#HR,CD*;7-G:60@(DA434P@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S
M='(@(E=I861O;6^VYB!W('=E<G-J:2!(5$U,(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M3F%GL_-W:VDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC
M.C4*;7-G:60@(DAE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S
M:6YG.B(*;7-G<W1R(")4=71A:B!Z;F%J9'5J92!S:>H@=VEA9&]M;[;F+"!K
M=/-RL2!T=V]R>GFS9;8Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V
M,@IM<V=I9"`B2&ED9&5N(@IM<V=S='(@(E5K<GET92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-C$*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE
M=R(*;7-G<W1R(")5:W)Y=&4@=R!P;V1G;+%D>FEE('>Q=&MU(@H*(SH@;6%I
M;&)O>"YP:'`Z,S8S"FUS9VED(")(:61E($1E;&5T960B"FUS9W-T<B`B56MR
M>6H@=7-U;FGJ=&4B"@HC.B!F;VQD97)S+G!H<#HR.#<*;7-G:60@(DAI9&4@
M56YS=6)S8W)I8F5D(@IM<V=S='(@(E5K<GEJ(&YI97-U8G-K<GEB;W=A;F4B
M"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`T"FUS9VED(")(:61E
M('1H92!);6%G97,B"FUS9W-T<B`B56MR>6H@;V)R87IK:2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P-0IM<V=I9"`B2&EG:"(*;7-G
M<W1R(")7>7-O:VDB"@HC.B!M86EL8F]X+G!H<#HW,#,@;65S<V%G92YP:'`Z
M,C@Q('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI
M9V@@4')I;W)I='DB"FUS9W-T<B`B5WES;VMI('!R:6]R>71E="(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P-`IM<V=I9"`B2&EG:&5S
M="(*;7-G<W1R(").86IW>;]S>GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C@R"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A
M8VAM96YT<S\B"FUS9W-T<B`B2F%K('=YMG=I971L8>8@>F&SL6-Z;FEK:3\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DV"FUS9VED(")(;W<@=&\@
M871T<FEB=71E('%U;W1E9"!L:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(DIA
M:R!P<GIY<&ES>7=AYB!C>71O=V%N92!L:6YI92!W(&]D<&]W:65D>FDB"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$S-`IM<V=I9"`B24U!4"(*;7-G
M<W1R("))34%0(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G
M:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B24U!
M4"`H875T;VUA='EC>FYA(&1E=&5K8VIA('!R;W1O:V^S=2DB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V,R!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-33"(*;7-G<W1R(")0;[.Q8WIE
M;FEE(%-33"!D;&$@24U!4"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,34R"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I
M8V%T92DB"FUS9W-T<B`B4&^SL6-Z96YI92!34TP@9&QA($E-05`@*'>S87-N
M>2!C97)T>69I:V%T*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,38T"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T
M<B`B4&^SL6-Z96YI92!34TP@9&QA($E-05`@*'>S87-N>2!P;V1P:7,I(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C(@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R("))
M34%0+"!B97H@5$Q3(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HT.0IM
M<V=I9"`B24U!4"]03U`S($UA:6P@4V5R=F5R<R(*;7-G<W1R(")397)W97)Y
M('!O8WIT;W=E($E-05`O4$]0,R(*"B,Z(&QI8B])35`N<&AP.C@X-@IM<V=I
M9"`B24Y"3U@B"FUS9W-T<B`B3V1E8G)A;F4B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,@IM<V=I9"`B268@>6]U(&-O
M;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@=&AE(&9O;&1E<BAS*2!W:6QL(&)E
M(&QO<W0A(@IM<V=S='(@(B(*(DIEMFQI(&+J9'II97-Z(&MO;G1Y;G5O=V&S
M+"!T;R!W<WIY<W1K:64@=VEA9&]M;[9C:2!W(&9O;&1E<GIE*&%C:"D@>F]S
M=&%NL2`B"B)U=')A8V]N92$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z.#@*;7-G:60@(DEG;F]R92(*;7-G<W1R("))9VYO<G5J(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@Y"FUS9VED("))
M9VYO<F4@06QL(@IM<V=S='(@(DEG;F]R=6H@=W-Z>7-T:V\B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P"FUS9VED("));7!O<G0B"FUS
M9W-T<B`B26UP;W)T(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN
M:6YC.C@T('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C4*;7-G:60@
M(DEM<&]R="!+97DB"FUS9W-T<B`B26UP;W)T;W=A;FEE(&ML=6-Z82(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-30*;7-G:60@(DEM<&]R="!+97EP
M86ER(@IM<V=S='(@(DEM<&]R=&]W86YI92!P87)Y(&ML=6-Z82(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(U"FUS9VED("));7!O<G0@
M365S<V%G97,B"FUS9W-T<B`B26UP;W)T=6H@=VEA9&]M;[9C:2(*"B,Z('!G
M<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@(DEM<&]R
M=&]W86YI92!K;'5C>F$@<'5B;&EC>FYE9V\@4$=0(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHQ-#@*;7-G:60@(DEM<&]R="!097)S;VYA;"!#
M97)T:69I8V%T97,B"FUS9W-T<B`B26UP;W)T;W=A;FEE(&]S;V)I<W1E9V\@
M8V5R='EF:6MA='4B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC
M.C$T"FUS9VED("));7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y(@IM
M<V=S='(@(DEM<&]R=&]W86YI92!P<GEW871N96=O(&ML=6-Z82!01U`B"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.CD*;7-G:60@(DEM<&]R
M="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("));7!O<G1O=V%N
M:64@<'5B;&EC>FYE9V\@<&5R<V]N86QN96=O(&ML=6-Z82!01U`B"@HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T
M(%!E<G-O;F%L(%,O34E-12!#97)T:69I8V%T97,B"FUS9W-T<B`B26UP;W)T
M;W=A;FEE(&-E<G1Y9FEK871U('!E<W)O;F%L;F5G;R!3+TU)344B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,#<*;7-G:60@(DEM<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(DEM
M<&]R=&]W86YI92!K;'5C>F$@<'5B;&EC>FYE9V\B"@HC.B!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0
M($ME>2(*;7-G<W1R("));7!O<G1O=V%N:64@:VQU8WIA('!U8FQI8WIN96=O
M(%!'4"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX"FUS
M9VED("));7!O<G0@4'5B;&EC(%,O34E-12!+97DB"FUS9W-T<B`B26UP;W)T
M;W=A;FEE(&ML=6-Z82!P=6)L:6-Z;F5G;R!3+TU)344B"@HC.B!S;6EM92YP
M:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@(DEM<&]R
M=&]W86YI92!K;'5C>F$@4R]-24U%(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@;6)O>"!&:6QE(@IM<V=S='(@
M(DEM<&]R=&]W86YI92!P;&EK=2!M8F]X(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O:6UP;W)T+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@
M;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G<W1R("));7!O<G1O
M=V%N:64@<&QI:W4@;6)O>"`E<R!D;R!F;VQD97)U("5S+B(*"B,Z(&UA:6QB
M;W@N<&AP.C<Q,R!M97-S86=E+G!H<#HT.#8@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R
M=&%N="(*;7-G<W1R(")78;]N92(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-#<*;7-G:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(")7
M8;]N92!W:6%D;VUOMF-I(@H*(SH@9F]L9&5R<RYP:'`Z,34W"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@)7,N(@IM
M<V=S='(@(DEM<&]R=&]W86YO("5D('=I861O;6^V8VD@>B`E<RXB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS9VED("));B!0<F]C97-S
M(@IM<V=S='(@(D%K='EW;F4B"@HC.B!F;VQD97)S+G!H<#HS-SD@;&EB+TE-
M4"YP:'`Z,S4X(&QI8B]&;VQD97(N<&AP.C(R-R!L:6(O24U!4"]4<F5E+G!H
M<#HQ,#4*(SH@;&EB+TE-05`O5')E92YP:'`Z,C`T"FUS9VED("));F)O>"(*
M;7-G<W1R(")/9&5B<F%N92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.#0*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H96%D
M97(@:6X@82!R97!L>3\B"FUS9W-T<B`B6F&SL6-Z8>8@<&]D<W5M;W=A;FEE
M('<@;F%GL_-W:W4@;V1P;W=I961Z:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#<X"FUS9VED("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@
M82!R97!L>3\B"FUS9W-T<B`B6F&SL6-Z8>8@;W)Y9VEN86QNL2!W:6%D;VUO
MMN8@=R!O9'!O=VEE9'II/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$S,`IM
M<V=I9"`B26YF;R(*;7-G<W1R("));F9O(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHV-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*
M;7-G<W1R("));F9O<FUA8VIE(&\@:VQU8WIU('!U8FQI8WIN>6T@)7,B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,34Q"FUS9VED("));F9O<FUA=&EO
M;B!O;B!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("));F9O<FUA8VIE
M(&\@;W-O8FES='EM(&ML=6-Z=2!P<GEW871N>6TB"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C$Q,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30W
M"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(DEN9F]R;6%C:F4@;R!O<V]B:7-T>6T@:VQU8WIU('!U8FQI8WIN
M>6TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,34@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DW"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDY"FUS9VED("));FQI;F4B"FUS
M9W-T<B`B3&EN:6$B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI
M;F,Z.0IM<V=I9"`B26YS97)T($-E<G1I9FEC871E($AE<F4B"FUS9W-T<B`B
M5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y($AE<F4B"FUS9W-T<B`B5W!R;W=A9+P@;W-O8FES='D@:VQU8WH@
M<')Y=V%T;GD@4$=0('1U=&%J(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?
M:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@
M2V5Y($AE<F4B"FUS9W-T<B`B5W!R;W=A9+P@;W-O8FES='D@:VQU8WH@<'5B
M;&EC>FYY(%!'4"!T=71A:B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS
M9W-T<B`B5W!R;W=A9+P@:VQU8WH@<'5B;&EC>FYY(%!'4"!T=71A:B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3(*;7-G:60@(DEN=F%L:60@
M06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`B
M5WEB<F%N;R!ZL[$@;W!C:NH@9&QA('1E9V\@:V]M<&]N96YT=2XB"@HC.B!M
M86EL8F]X+G!H<#HU-C,@;6%I;&)O>"YP:'`Z-C`U"FUS9VED("));G9A;&ED
M($%D9')E<W,B"FUS9W-T<B`B3FEE<&]P<F%W;GD@861R97,B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!296UO=&4@
M36%I;&)O>"(*;7-G<W1R(").:65P;W!R87=N82!Z9&%L;F$@<VMR>GEN:V$@
M<&]C>G1O=V$B"@HC.B!C;VUP;W-E+G!H<#HQ,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S
M+B(*;7-G<W1R(").:65P;W!R87=N>2!Z;F%K('<@861R97-I92!E+6UA:6PZ
M("5S+B(*"B,Z('-M:6UE+G!H<#HX,B!P9W`N<&AP.C$V"FUS9VED("));G9A
M;&ED(&ME>2(*;7-G<W1R(").:65P;W!R87=N>2!K;'5C>B(*"B,Z('!G<"YP
M:'`Z,3DV"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME
M>2XB"FUS9W-T<B`B3FEE<&]P<F%W;GD@;W-O8FES='D@:VQU8WH@<')Y=V%T
M;GD@4$=0+B(*"B,Z('!G<"YP:'`Z,3<Q"FUS9VED("));G9A;&ED('!E<G-O
M;F%L(%!'4"!P=6)L:6,@:V5Y+B(*;7-G<W1R(").:65P;W!R87=N>2!O<V]B
M:7-T>2!K;'5C>B!P=6)L:6-Z;GD@4$=0+B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,3(*;7-G:60@(DEN=F5R="(*;7-G<W1R(")/9'=R
M\^8B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-C<*;7-G
M:60@(DM"(@IM<V=S='(@(DM"(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C(P,0IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")$LW5G;[;F(&ML=6-Z
M82(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-3(*;7-G:60@(B(*(DME
M>2!G96YE<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE('1O(&-O;7!L971E
M+B`@0V]N=&EN=64@=VET:"!K97D@(@HB9V5N97)A=&EO;C\B"FUS9W-T<B`B
M1V5N97)O=V%N:64@:VQU8WIA(&UOOV4@>F%JL>8@9'6_;R!C>F%S=2X@2V]N
M='5N=6]W8>8_(@H*(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME>2!S=6-C97-S
M9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M2VQU8WH@=WESLV%N>2!P;VUYMFQN:64@;F$@<'5B;&EC>FYY('-E<G=E<B!K
M;'5C>GDN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3D*;7-G
M:60@(DQA;F=U86=E(@IM<V=S='(@(DKJ>GEK(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@W-PIM<V=I9"`B3&%S="!-86EL8F]X(%!A9V4B"FUS9W-T
M<B`B3W-T871N:6$@<W1R;VYA('-K<GIY;FMI(@H*(SH@;6%I;&)O>"YP:'`Z
M,S4T"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`B3W-T871N:6$@<W1R;VYA
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@P"FUS9VED
M("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R("),:5]N:W5J('IAL[%C>FYI
M:VDB"@HC.B!A='1A8VAM96YT+G!H<#HS-"!L:6(O0V]M<&]S92YP:'`Z.3<T
M"FUS9VED("),:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS
M9W-T<B`B3&EN:V]W86YI92!Z8;.Q8WIN:6OS=R!J97-T('IA8G)O;FEO;F4N
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.CDY,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R(")/9&YOMFYI:VD@
M<W1A;K$@<VGJ(&YI96%K='5A;&YE("5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-#`*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@
M;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO
M=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F
M;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@HB4&]K87IY=V'F('=S>GES=&MI
M92!K;VYT86MT>2!P;V1C>F%S(+-A9&]W86YI82!O:VYA(&MO;G1A:W3S=S\H
M:F6V;&D@(@HB=WFSL6-Z;VYE+"!W:61O8WIN92!BZF2Q(&IE9'EN:64@<&]C
M>G5K:7=A;F4@:V]N86MT>2DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C<Y"FUS9VED("),:7-T:6YG(&EN('1H92!(96%D97(B"FUS9W-T<B`B5WFV
M=VEE=&QA;FEE('<@;F%GL_-W:W4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,S`*;7-G:60@(DQO8V%L($UA:6QB;W@Z(@IM<V=S='(@
M(DQO:V%L;F$@<VMR>GEN:V$Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8W-`IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3&]K86QI>F%C:F$B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P-PIM<V=I9"`B3&]G
M(&EN(@IM<V=S='(@(EIA;&]G=6H@<VGJ(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),;V<@:6X@=&\@)7,B
M"FUS9W-T<B`B6F%L;V=U:B!S:>H@9&\@)7,B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$S-@IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B3F%Z=V$@
M=;]Y=&MO=VYI:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(EIA9&%N:6$@<')Z>2!L;V=O=V%N
M:74B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,#<*;7-G
M:60@(DQO=R(*;7-G<W1R(").:7-K:2(*"B,Z(&UA:6QB;W@N<&AP.C<P-B!M
M97-S86=E+G!H<#HR.#,@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ
M,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(DYI<VMI('!R:6]R>71E
M="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P.`IM<V=I
M9"`B3&]W97-T(@IM<V=S='(@(DYA:FYIOW-Z>2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]A<'!L961O=6)L92YP:'`Z-#0*;7-G:60@(DUA8VEN=&]S:"!&:6QE
M(@IM<V=S='(@(E!L:6L@36%C:6YT;W-C:"(*"B,Z('-M:6UE+G!H<#HR-30@
M<&=P+G!H<#HS,S(@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S
M"FUS9VED(")-86EL(@IM<V=S='(@(E!O8WIT82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-0IM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R(")0
M;V1G;+%D('!O8WIT>2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R
M7W-E;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N
M;F5C="!T;SHB"FUS9W-T<B`B5'EP('!OL[%C>F5N:6$@>B!S97)W97)E;2!P
M;V-Z='DZ(@H*(SH@9F]L9&5R<RYP:'`Z,SDW"FUS9VED(")-86EL8F]X(@IM
M<V=S='(@(E-K<GIY;FMA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,`IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T:6]N<R(*
M;7-G<W1R(")/<&-J92!W>;9W:65T;&%N:6$@<VMR>GEN:VD@:2!F;VQD97)U
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@
M(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@
M(D]Z;F%C>B!W<WIY<W1K:64@=VEA9&]M;[9C:2!W(&9O;&1E<GIE(&IA:V\@
M=VED>FEA;F4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ
M-PIM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%5N<V5E
M;B(*;7-G<W1R(")/>FYA8WH@=W-Z>7-T:VEE('=I861O;6^V8VD@=R!F;VQD
M97)Z92!J86MI(&YI97=I9'II86YE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM<V=S='(@(EIA>FYA8WH@:F%K
M;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0T"FUS9VED(")-87)K
M(&1I9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C
M;VQO<G,_(@IM<V=S='(@(D]Z;F%C>F'F('+SOVYY;6D@:V]L;W)A;6D@<&]Z
M:6]M>2!P<FEO<GET973S=S\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-
M05`@;VYL>2DB"FUS9W-T<B`B3WIN86-Z>>8@=VEA9&]M;[9C:2!J86MO('=I
M9'II86YE/R`H='EL:V\@24U!4"DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C4R"FUS9VED(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT-@IM<V=I9"`B36%T
M8V@@06QL(%%U97)I97,B"FUS9W-T<B`B5W-Z>7-T:VEE('IA<'ET86YI82!M
M=7-ZL2!P87-O=V'F(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC
M.C0R"FUS9VED(")-871C:"!!;GD@475E<GDB"FUS9W-T<B`B2F%K:65K;VQW
M:65K('!A<W5JL6-E('IA<'ET86YI92(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4P,PIM<V=I9"`B36%X:6UU;2!!='1A8VAM96YT(%-I
M>F4B"FUS9W-T<B`B36%K<WEM86QN>2!R;WIM:6%R('IAL[%C>FYI:V$B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.#0*;7-G:60@(DUA
M>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N(@IM<V=S='(@
M(DUA:W-Y;6%L;F$@;&EC>F)A('IAL[%C>FYI:_-W(&]S:;%G;FGJ=&$N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#<Y"FUS9VED(")-
M87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*;7-G<W1R
M(")#8;-K;W=I='D@;6%K<WEM86QN>2!R;WIM:6%R('IAL[%C>FYI:V$@;W-I
ML6=N:>IT>2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(V"FUS
M9VED(")-965T:6YG($-A;F-E;&QA=&EO;B(*;7-G<W1R(")!;G5L;W=A;FEE
M('-P;W1K86YI82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S4*
M;7-G:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-J
M92!O('-P;W1K86YI=2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M.#4*;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B4')O<&]Z>6-J
M82!S<&]T:V%N:6$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W
M"FUS9VED(")-965T:6YG(%)E<&QY(@IM<V=S='(@(D]D<&]W:65DO"!O9&YO
MMFYI92!S<&]T:V%N:6$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3DX"FUS9VED(")-965T:6YG(%5P9&%T92(*;7-G<W1R("):;6EA;F$@<W!O
M=&MA;FEA(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,PIM<V=I
M9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R("):87!Y=&%N:64@
M;R!Z;6EA;NH@<W!O=&MA;FEA(@H*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R
M<RYP:'`Z,PIM<V=I9"`B365N=2!&;VQD97(@3&ES="(*;7-G<W1R("),:7-T
M82!M96YU(&9O;&1E<G4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C0V"FUS9VED
M(")-97-S86=E(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&-O;7!O<V4N<&AP
M.C4P-R!C;VUP;W-E+G!H<#HU,S0@8V]M<&]S92YP:'`Z-3@X(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO;B(*
M;7-G<W1R(")4=V]R>F5N:64@=VEA9&]M;[9C:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.#@*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G<W1R(")$
M871A('=I861O;6^V8VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#D@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDT(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#(*;7-G:60@
M(DUE<W-A9V4@3W!T:6]N<R(*;7-G<W1R(")/<&-J92!W:6%D;VUOMF-I(@H*
M(SH@<V5A<F-H+G!H<#HS-3D*;7-G:60@(DUE<W-A9V4@4V5A<F-H(@IM<V=S
M='(@(E-Z=6MA;FEE('=I861O;6^V8VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#DR"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`B4F]Z;6EA
M<B!W:6%D;VUOMF-I(@H*(SH@;65S<V%G92YP:'`Z,S8X"FUS9VED(")-97-S
M86=E(%-O=7)C92(*;7-G<W1R("*L<O-DLV\@=VEA9&]M;[9C:2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G92!6:65W:6YG
M(@IM<V=S='(@(E=YMG=I971L86YI92!W:6%D;VUOMF-I(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C4U"FUS9VED(")-97-S86=E(&9I96QD
M<R(*;7-G<W1R(")0;VQE('=I861O;6^V8VDB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`B
M3WIN86-Z96YI82!W:6%D;VUOMF-I(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM<V=S='(@(D9O
M;&1E<B!W:6%D;VUOMF-I(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B5VEA
M9&]M;[;F(&]D("5S(@H*(SH@;6%I;&)O>"YP:'`Z-C0V"FUS9VED(")-97-S
M86=E(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R(")7:6%D;VUOMN8@;6$@>F&S
ML6-Z;FEK:2(*"B,Z(&UA:6QB;W@N<&AP.C8S-PIM<V=I9"`B365S<V%G92!I
M<R!E;F-R>7!T960B"FUS9W-T<B`B5VEA9&]M;[;F(&IE<W0@>F%S>GEF<F]W
M86YA(@H*(SH@;6%I;&)O>"YP:'`Z-C,R"FUS9VED(")-97-S86=E(&ES('-I
M9VYE9"(*;7-G<W1R(")7:6%D;VUOMN8@:F5S="!P;V1P:7-A;F$B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S,*;7-G:60@(DUE<W-A9V4@
M;6%T8VAE<R(*;7-G<W1R(")7:6%D;VUOMN8@<&%S=6IE(@H*(SH@8V]M<&]S
M92YP:'`Z-S<Q(&-O;7!O<V4N<&AP.C<X-0IM<V=I9"`B365S<V%G92!R961I
M<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5VEA9&]M;[;F('!R>F5K
M:65R;W=A;F$@<')A=VEDLV]W;RXB"@HC.B!C;VUP;W-E+G!H<#HQ,#$X"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL
M(&)U="!N;W0@<V%V960@=&\@)7,B"FUS9W-T<B`B5VEA9&]M;[;F('=Y<[-A
M;F$L(&%L92!N:64@>F%P:7-A;F$@=R`E<R(*"B,Z(&-O;7!O<V4N<&AP.C$P
M-S<@8V]M<&]S92YP:'`Z,3`Y,@IM<V=I9"`B365S<V%G92!S96YT('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B5VEA9&]M;[;F('=Y<[-A;F$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDQ,@IM<V=I9"`B365S<V%G97,@<&5R('!A
M9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB"FUS9W-T<B`B26QOMN8@=VEA9&]M
M;[9C:2!W>;9W:65T;&%N>6-H(&YA(&IE9&YE:B!S=')O;FEE+B(*"B,Z(&UA
M:6QB;W@N<&AP.C,Q.`IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B5VEA
M9&]M;[9C:2!D;R(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I
M9"`B36]D:69Y(@IM<V=S='(@(EIM:6%N82(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!T
M:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N(@IM<V=S
M='(@(E=IZF-E:B!N:;\@:F5D96X@861R97,@>FYA;&5Z:6]N>2!D;&$@<&]L
M82!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS
M9VED(")-;W9E(@IM<V=S='(@(E!R>F5N:66V(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S$V"FUS9VED(")-;W9E(&1O=VXB"FUS
M9W-T<B`B4')Z96YI9;8@=R!D\[,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z-3`*;7-G:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@(E!R>F5N
M:66V(&1O(&9O;&1E<G4B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHS,30*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B4')Z96YI9;8@
M=R!G\W+J(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ
M,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E<FYA=&EV92(*;7-G<W1R(")-=6QT
M:7!A<G0O86QT97)N871I=F4B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C(T('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C0*;7-G:60@(DY/5$4B"FUS9W-T<B`B
M3D]402(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,X
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(DYA;64B"FUS
M9W-T<B`B3F%Z=V$B"@HC.B!P9W`N<&AP.C$Q,`IM<V=I9"`B3F%M92!A;F0O
M;W(@96UA:6P@8V%N(&YO="!B92!E;7!T>2(*;7-G<W1R(").87IW82!I+VQU
M8B!A9')E<R!N:64@;6]GL2!B>>8@<'5S=&4B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S<X"FUS9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`B
M5WEM86=A('=Y:V]N86YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-C,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W-0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S4T"FUS9VED(").979E<B(*;7-G<W1R(").:6=D>2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3,*;7-G:60@(DYE=F5R('-A=F4@
M871T86-H;65N=',B"FUS9W-T<B`B3FEG9'D@;FEE('IA<&ES=6H@>F&SL6-Z
M;FEK\W<B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3(V"FUS9VED(").
M97<B"FUS9W-T<B`B3F]W>2(*"B,Z(&QI8B])35`N<&AP.C8Q-0IM<V=I9"`B
M3F5W($9O;&1E<B(*;7-G<W1R(").;W=Y(&9O;&1E<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`B3F]W
M82!P;V-Z=&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Y"FUS
M9VED(").97<@;65S<V%G97,B"FUS9W-T<B`B3F]W92!W:6%D;VUOMF-I(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B
M3F5X="(*;7-G<W1R(").87-TZG!N92(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G92(*
M;7-G<W1R(").87-TZG!N82!W:6%D;VUOMN8B"@HC.B!M86EL8F]X+G!H<#HS
M-3(*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(").87-TZG!N82!S=')O;F$B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S(@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDT.`IM<V=I9"`B3F\B"FUS9W-T<B`B3FEE(@H*
M(SH@<VUI;64N<&AP.C(R-@IM<V=I9"`B3F\@0V5R=&EF:6-A=&4@9F]U;F0B
M"FUS9W-T<B`B3FEE('IN86QE>FEO;F\@8V5R='EF:6MA='4B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N
M8W)Y<'1I;VXB"FUS9W-T<B`B0G)A:R!K;V1O=V%N:6$B"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z.#`*;7-G:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*
M;7-G<W1R(")"<F%K(&ML=6-Z>2!W('IB:6]R>F4B"@HC.B!M86EL8F]X+G!H
M<#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B"FUS9W-T
M<B`B0G)A:R!W:6%D;VUOMF-I(@H*(SH@<&=P+G!H<#HQ,S<*;7-G:60@(DYO
M(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(").:64@>F%I;7!O
M<G1O=V%N;R!P=6)L:6-Z;F5G;R!K;'5C>F$@4$=0+B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,30P"FUS9VED(").;R!097)S;VYA;"!#97)T
M:69I8V%T92!0<F5S96YT(@IM<V=S='(@(D)R86L@;W-O8FES=&5G;R!C97)T
M>69I:V%T=2(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,C,*;7-G:60@(DYO(%!R
M979I97<@5&5X="(*;7-G<W1R(")"<F%K('!O9&=LL61U(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B3F\@4'5B;&EC($ME>7,@
M1F]U;F0B"FUS9W-T<B`B3FEE('IN86QE>FEO;F\@<'5B;&EC>FYE9V\@:VQU
M8WIA(@H*(SH@<VUI;64N<&AP.C$U,0IM<V=I9"`B3F\@4R]-24U%('!U8FQI
M8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DYI92!Z86EM<&]R=&]W86YO('!U
M8FQI8WIN96=O(&ML=6-Z82!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W1N968N<&AP.CDP"FUS9VED(").;R!A='1A8VAM96YT<R!F;W5N9"XB"FUS
M9W-T<B`B3FEE('IN86QE>FEO;F\@>F&SL6-Z;FEK\W<N(@H*(SH@;&EB+T-R
M>7!T+U--24U%+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(DYO(&5M86EL(&EN
M9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K97DN(@IM<V=S='(@
M(DEN9F]R;6%C:F4@;R!K;'5C>G4@<'5B;&EC>FYY;2`E<R(*"B,Z(&%C;"YP
M:'`Z-S(@86-L+G!H<#HY.`IM<V=I9"`B3F\@9F]L9&5R('-E;&5C=&5D+B(*
M;7-G<W1R(").:64@=WEB<F%N;R!F;VQD97)A+B(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HQ,S`*;7-G:60@(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H
M96-K960@9F]R(&YE=R!M86EL+B(*;7-G<W1R("*O861E;B!F;VQD97(@;FEE
M('IO<W1ALR!W>6)R86YY(&1O('-P<F%W9'IA;FEA(&YO=V5J('!O8WIT>2XB
M"@HC.B!F;VQD97)S+G!H<#HR,#<@;&EB+T9O;&1E<BYP:'`Z-#@P(&QI8B]&
M;VQD97(N<&AP.C4S,`IM<V=I9"`B3F\@9F]L9&5R<R!W97)E('-P96-I9FEE
M9"(*;7-G<W1R(").:64@>F1E9FEN:6]W86YO(+]A9&YY8V@@9F]L9&5R\W<B
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3,V"FUS9VED(").;R!F;VQD
M97)S('=I=&@@;F5W(&UE<W-A9V5S(@IM<V=S='(@(D)R86L@9F]L9&5R=2!Z
M(&YO=WEM:2!W:6%D;VUOMF-I86UI(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$S,PIM<V=I9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E
M<R(*;7-G<W1R(")"<F%K(&9O;&1E<G4@>B!N:65W:61Z:6%N>6UI('=I861O
M;6^V8VEA;6DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C0P"FUS9VED(").;R!M
M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R(")"<F%K('1E:W-T=2!W('1R9;9C
M:2!W:6%D;VUOMF-I(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,V-0IM<V=I9"`B
M3F\@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B3FEE
M('IN86QE>FEO;F\@=VEA9&]M;[9C:2!S<&6S;FEA:K%C>6-H(&MR>71E<FEA
M('=Y<WIU:VEW86YI82XB"@HC.B!P9W`N<&AP.C$X.0IM<V=I9"`B3F\@<&5R
M<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(")/<V]B
M:7-T>2!K;'5C>B!P<GEW871N>2!01U`@;FEE>F%I;7!O<G1O=V%N>2XB"@HC
M.B!P9W`N<&AP.C$V-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K
M97D@:6UP;W)T960N(@IM<V=S='(@(D]S;V)I<W1Y(&ML=6-Z('!U8FQI8WIN
M>2!01U`@;FEE>F%I;7!O<G1O=V%N>2XB"@HC.B!S;6EM92YP:'`Z,C`Q"FUS
M9VED(").;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D
M+B(*;7-G<W1R(")/<V]B:7-T>2!C97)T>69I:V%T(%,O34E-12!N:65Z86EM
M<&]R=&]W86YY+B(*"B,Z('-P96QL:6YG+G!H<#HR,C`*;7-G:60@(DYO('-P
M96QL8VAE8VMI;F<@<')O9W)A;2!C;VYF:6=U<F5D+B(*;7-G<W1R(").:64@
M<VMO;F9I9W5R;W=A;F\@<')O9W)A;74@<W!R87=D>F%JL6-E9V\@<&ES;W=N
M:>HN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4P"FUS
M9VED(").;R!S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B0G)A:R!BL^ID\W<@
M=R!P:7-O=VYI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$P-@IM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B0G)A:R!S=6=E
M<W1I:2(*"B,Z(&%C;"YP:'`Z-C@@86-L+G!H<#HY-`IM<V=I9"`B3F\@=7-E
M<B!S<&5C:69I960N(@IM<V=S='(@(DYI92!W>6)R86YO('6_>71K;W=N:6MA
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#D*;7-G:60@(DYO
M;B!087)T:6-I<&%N="(*;7-G<W1R(")"<F%K('5C>F5S=&YI8W1W82(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@=&5M<&QA=&5S+W!R
M969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS-2!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I
M9"`B3F]N92(*;7-G<W1R("*O861E;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,P-@IM<V=I9"`B3F]R;6%L(@IM<V=S='(@(DYO<FUA
M;&YY(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,2!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Y"FUS9VED(").;W0@1&5L971E
M9"(*;7-G<W1R(").:65U<W5N:>IT>2(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHR,PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0R
M"FUS9VED(").;W0@1')A9G0B"FUS9W-T<B`B3FEE('-Z:VEC(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHS-`IM<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R(").
M:65W8;]N92(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*
M;7-G:60@(DYO="!097)S;VYA;"(*;7-G<W1R(").:65O<V]B:7-T92(*"B,Z
M(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S
M-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@
M<'5B;&EC(&ME>2XB"FUS9W-T<B`B6K-Y(&ML=6-Z('!U8FQI8WIN>2XB"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED(").;W0@9&5L
M971E9"!M97-S86=E<R(*;7-G<W1R(").:65U<W5N:>IT92!W:6%D;VUOMF-I
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B3F]T
M(&EM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R(").:65W8;]N92!W:6%D;VUO
MMF-I(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN
M+G!H<#HW,0IM<V=I9"`B3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T
M:6UE(@IM<V=S='(@(E1A(&]P97)A8VIA(&UOOV4@=')W8>8@9+-UOW-ZL2!C
M:'=I;.HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"FUS9VED(").
M=6UB97(@;V8@;6]N=&AS('1O(&ME97`@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!I9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R("(B"B));&^VYB!M:65S
M:>IC>2!P<GIE>B!K=/-R92!M86JQ(&)YYB!Z86-H;W=A;F4@<W1A<F4@;&EN
M:VD@>F&SL6-Z;FEK\W<@(@HB<&]D8WIA<R!C;VUI97-IZF-Z;F5G;R!U<W5W
M86YI82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"FUS9VED(").
M=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L
M971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB26QOMN8@<W1A<GEC:"!F;VQD
M97+S=R!P;V-Z='D@=WESLV%N96HL(&MT\W)A(&UA(&)YYB!Z86-H;W=A;F$@
M<&]D8WIA<R`B"B)C;VUI97-IZF-Z;F5G;R!U<W5W86YI82XB"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-"!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M,S,*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC
M.C0W"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-#@*;7-G:60@
M(D]2(@IM<V=S='(@(DQ50B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,34*;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R(")3=&%R92!W:6%D
M;VUOMF-I(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C4R"FUS9VED(")/;&0@<V5N="UM86EL(&9O;&1E
M<G,@8F5I;F<@<'5R9V5D+B(*;7-G<W1R(")3=&%R92!F;VQD97)Y('-E;G0M
M;6%I;"!Z;W-T86ZQ('-K87-O=V%N92XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,C<*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR
M96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(E=YMG=I971L:>8@='EL
M:V\@9F]L9&5R>2!Z(&YI96-Z>71A;GEM:2!W:6%D;VUOMF-I86UI/R(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C<Q"FUS9VED(")/
M;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C
M=&EO;BXB"FUS9W-T<B`B36^_92!B>>8@=WEB<F%N>2!T>6QK;R!J961E;B!F
M;VQD97(@9&QA('1E:B!A:V-J:2XB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z
M-R!T96UP;&%T97,O;65N=2YI;F,Z,C<*;7-G:60@(D]P95]N($9O;&1E<B(*
M;7-G<W1R(")/='?S<GH@1F]L9&5R("A?;BDB"@HC.B!T96UP;&%T97,O;65N
M=2YI;F,Z,C,*;7-G:60@(D]P96X@1F]L9&5R(@IM<V=S='(@(D]T=_-R>B!&
M;VQD97(B"@HC.B!F;VQD97)S+G!H<#HT,30*;7-G:60@(D]P96YE9"!&;VQD
M97(B"FUS9W-T<B`B1F]L9&5R(&]T=V%R='DB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S`U"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*
M;7-G<W1R(")/<&-J;VYA;&YE('!R>GEN86QEOVYOMF-I(@H*(SH@9F5T8VAM
M86EL+G!H<#HS,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H
M97(@36%I;"!!8V-O=6YT<R(*;7-G<W1R("));FYE(&MO;G1A('!O8WIT;W=E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30R"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(DEN;F4@;W!C
M:F4B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP"FUS9VED(")0
M1U`B"FUS9W-T<B`B4$=0(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP
M=%]L:7-T+FEN8SHW"FUS9VED(")01U`@16YC<GEP="!-97-S86=E(@IM<V=S
M='(@(E=I861O;6^VYB!K;V1O=V%N82!01U`B"@HC.B!C;VUP;W-E+G!H<#HS
M,S$*;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S='(@(D*SL60@4$=0.B`B"@HC
M.B!C;VUP;W-E+G!H<#HS,3`*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S
M<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B0K.Q
M9"!01U`Z(%=Y;6%G86YE(&AA<[-O(&1L82!O<V]B:7-T96=O(&ML=6-Z82!P
M<GEW871N96=O+B(*"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHV
M"FUS9VED(")01U`@3D]4($%C=&EV92(*;7-G<W1R(")01U`@3FEE86MT>7=N
M92(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHV(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S0*;7-G:60@(E!'4"!/<'1I;VYS(@IM<V=S='(@(D]P8VIE
M(%!'4"(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!087-S<&AR87-E($EN
M<'5T(@IM<V=S='(@(E=P<F]W861Z96YI92!H87.S82!01U`B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")01U`@4&5R<V]N86P@2V5Y
M<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R(")/8G.S=6=A(&]S;V)I<W1E9V\@:VQU8WIA(%!'4"!W>6UA
M9V$@8F5Z<&EE8WIN96=O('!OL[%C>F5N:6$@=W=W+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C$W,PIM<V=I9"`B4$=0(%!U8FQI8R!+97D@5&5X
M="(*;7-G<W1R(")496MS=&]W>2!K;'5C>B!P=6)L:6-Z;GD@4$=0(@H*(SH@
M<&=P+G!H<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+
M97D@9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM
M<V=S='(@(E!U8FQI8WIN>2!K;'5C>B!01U`@9&QA(%PB)7,@*"5S*5PB('IO
M<W1ALR!D;V1A;GDN(@H*(SH@<&=P+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U
M;&QY(&1E;&5T960N(@IM<V=S='(@(E!U8FQI8WIN>2!K;'5C>B!01U`@9&QA
M(%PB)7-<(B!Z;W-T8;,@=7-U;FGJ='DN(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<R"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B
M6F)I\W(@<'5B;&EC>FYY8V@@:VQU8WIY(%!'4"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`IM<V=I9"`B4$=0(%-I9VX@365S
M<V%G92(*;7-G<W1R(")7:6%D;VUOMN8@;WIN86-Z;VYA(&ML=6-Z96T@4$=0
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"FUS
M9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B5VEA9&]M
M;[;F(&MO9&]W86YA+W!O9'!I<V%N82!K;'5C>F5M(%!'4"(*"B,Z('!G<"YP
M:'`Z,C`R"FUS9VED(")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D
M9&5D+B(*;7-G<W1R(")0<GEW871N>2!K;'5C>B!01U`@9&]D86YY+B(*"B,Z
M('!G<"YP:'`Z,3<W"FUS9VED(")01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L
M;'D@861D960N(@IM<V=S='(@(E!U8FQI8WIN>2!K;'5C>B!01U`@9&]D86YY
M+B(*"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B
M4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S
M='(@(D]B<[-U9V$@4$=0(&IE<W0@=WFSL6-Z;VYA(&YA('1Y;2!S>7-T96UI
M92XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#@*;7-G:60@(B(*
M(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!D
M:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(B(*(D]B<[-U9V$@4$=0(&YI92!Z;W-T8;-A(&%K='EW;W=A
M;F$@9&QA=&5G;R!C>69R;W=Y('!O9'!I<R!N:64@;6^_92!B>>8@(@HB>G=E
M<GEF:6MO=V%N>2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.34*
M;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E
M('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N(@IM
M<V=S='(@(B(*(D]B<[-U9V$@4$=0(&YI92!Z;W-T8;-A(&%K='EW;W=A;F$@
M9&QA=&5G;R!W:6%D;VUOMN8@;FEE(&UOOV4@>F]S=&'F("(*(F]D:V]D;W=A
M;F$N(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(T"FUS9VED("(B"B)0
M1U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N
M("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A
M8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I
M;F<@;W(@96QS92!T:&4@4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O<FL@
M8V]R<F5C=&QY(@IM<V=S='(@(B(*(D]B<[-U9V$@4$=0('=Y;6%G82!WL[%C
M>F5N:6$@;W!C:FD@;F]W>6-H(&]K:65N('<@5'=O:F5J('!R>F5G;+%D87)C
M92X@2F6V;&D@(@HB;6%S>B!W>;.Q8WIO;K$@=+$@;W!C:NH@<&]W:6YI96YE
MMB!T;R!Z;6EE;FGF+B!7('!R>F5C:7=N>6T@=WEP861K=2!P97=N92`B"B)F
M=6MN8VIE(%!'4"!M;V>Q(&YI92!F=6YK8VIO;F]W8>8@<')A=VEDLV]W;R(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM
M<V=S='(@(E!/4#,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM
M<V=I9"`B4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R(")0
M3U`S("A!=71O;6%T>6-Z;F4@=WEK<GEW86YI92!P<F]T;VMOLW4I(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3<*;7-G:60@(E!/4#,@;W9E<B!3
M4TPB"FUS9W-T<B`B4$]0,R!P<GIE>B!34TPB"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N
M960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(E!/4#,@<')Z97H@4U-,("AWLV%S
M;GD@<&]D<&ES(&-E<G1Y9FEK871E;2DB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$V-@IM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N
M960I(@IM<V=S='(@(E!/4#,@<')Z97H@4U-,("AWLV%S;GD@<&]D<&ES*2(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$Q"FUS9VED(")03U`S+"!N
M;R!43%,B"FUS9W-T<B`B4$]0,RP@8F5Z(%1,4R(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&%G
M92`E9"!O9B`E9"(*;7-G<W1R(")3=')O;F$@)60@>B`E9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-S0*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER
M<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`B4W1R;VYA('H@<&EE<G=S>K$@
M;FEE=VED>FEA;K$@=VEA9&]M;[9C:;$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#<U"FUS9VED(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE
M<W-A9V4B"FUS9W-T<B`B4W1R;VYA('H@;W-T871N:;$@;FEE=VED>FEA;K$@
M=VEA9&]M;[;F:;$B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN
M8SHT,PIM<V=I9"`B4&%R="AS*2(*;7-G<W1R(")#>NJV8VDB"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,C$Q"FUS9VED(")087-S<&AR87-E(@IM<V=S
M='(@(DAA<[-O(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q-@IM<V=I
M9"`B4&%S<W!H<F%S92`H06=A:6XI(@IM<V=S='(@(DAA<[-O("AP;VYO=VYI
M92DB"@HC.B!S;6EM92YP:'`Z,C,U('!G<"YP:'`Z,S$P"FUS9VED(")087-S
M<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`B2&%SLV\@
M<')A=VEDLV]W;R!U<W5N:>IT92XB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S
M<W!H<F%S92YI;F,Z,3D@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHR
M.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`B2&%SLV\Z(@H*(SH@<&=P
M+G!H<#HQ,3(*;7-G:60@(E!A<W-P:')A<V5S(&-A;B!N;W0@8F4@96UP='DB
M"FUS9W-T<B`B2&%SLV$@;FEE(&UO9[$@8GGF('!U<W1E(@H*(SH@<&=P+G!H
M<#HQ,30*;7-G:60@(E!A<W-P:')A<V5S(&1O(&YO="!M871C:"(*;7-G<W1R
M(")(87.S82!N:64@>F=A9'IA:K$@<VGJ(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+VEM<&]R=%]K97DN:6YC.C8Y('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3DS"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,`IM<V=I
M9"`B4&%S<W=O<F0B"FUS9W-T<B`B2&%SLV\B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B5WEK;VYY=V'F(&]P
M97)A8VIE(&-Y:VQI8WIN92!P;R!Z86QO9V]W86YI=3\B"@HC.B!A8VPN<&AP
M.C<V(&%C;"YP:'`Z,3`R"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U
M<V5R(&-A;B!N;W0@8F4@8VAA;F=E9"XB"FUS9W-T<B`B57!R87=N:65N:6$@
M9&QA('1E9V\@=;]Y=&MO=VYI:V$@;FEE(&UO9[$@8GGF('IM:65N:6]N92XB
M"@HC.B!M86EL8F]X+G!H<#HV.#(@;65S<V%G92YP:'`Z-#<W('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ,`IM<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`B3W-O8FES
M=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:F4@;W-O8FES=&4B
M"@HC.B!P9W`N<&AP.C$R,`IM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7!A:7(@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&%R82!K;'5C>GD@
M;W-O8FES='EC:"!01U`@=WEG96YE<F]W86YA('!O;7FV;&YI92XB"@HC.B!P
M9W`N<&AP.C$R-PIM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(DML=6-Z92!O<V]B:7-T92!01U`@=7-U
M;FGJ=&4@<&]M>;9L;FEE+B(*"B,Z('-M:6UE+G!H<#HR,#<*;7-G:60@(E!E
M<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B"FUS
M9W-T<B`B3W-O8FES=&4@8V5R='EF:6MA='D@4R]-24U%(&YI97IA:6UP;W)T
M;W=A;F4Z("(*"B,Z('-M:6UE+G!H<#HQ,S(*;7-G:60@(E!E<G-O;F%L(%,O
M34E-12!K97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")/<V]B
M:7-T92!K;'5C>F4@4R]-24U%('5S=6YIZG1E('!O;7FV;&YI92XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$T"FUS9VED(")0;&%C92!Y;W5R('-I
M9VYA='5R92!B969O<F4@<F5P;&EE<R!A;F0@9F]R=V%R9',_(@IM<V=S='(@
M(D-Z>2!Z86UI97-Z8WIAYB!4=_-J('!O9'!I<R!P<GIE9"!O9'!O=VEE9'II
M86UI(&D@<')Z96MA>F%N:6%M:3\B"@HC.B!C;VUP;W-E+G!H<#HR,C<*;7-G
M:60@(E!L86EN=&5X="!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B5V5R
M<VIA(&-Z>71E9V\@=&5K<W1U('=I861O;6^V8VDB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@9F]L9&5R.B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@;F%Z
M=^H@9&QA(&YO=V5G;R!F;VQD97)U.B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VIA=F%S8W)I<'0N:6YC.CDT('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I
M<'0N:6YC.CDV"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE
M(&YE=R!F;VQD97(Z(@IM<V=S='(@(E!R;W-ZZB!P;V1AYB!N87IWZB!N;W=E
M9V\@9F]L9&5R=3HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R:7!T
M+FEN8SHQ,CD*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM
M<V=S='(@(E!R;W-ZZB!P;V1AYB!N;W>Q(&YA>G?J.B(*"B,Z('1E;7!L871E
M<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P
M<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O("(*(F5N=&5R('1H
M:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B
M"B)7<')O=V%DO"!H87.S;R!D;&$@<W=O:F5G;R!P<GEW86YT96=O(&ML=6-Z
M82!01U`N(%=P<F]W861Z96YI92!H87.S82`B"B)W>6UA9V%N92!J97-T('1Y
M;&MO(')A>B!D;&$@)7,@<V5S:FDN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A
M<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S
M92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T
M92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES('!A
M<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HB5W!R
M;W=A9+P@:&%SLV\@9&QA('-W;VIE9V\@<')Y=V%T;F5G;R!K;'5C>F$@4R]-
M24U%+B!7<')O=V%D>F5N:64@:&%SLV$@(@HB=WEM86=A;F4@:F5S="!T>6QK
M;R!R87H@9&QA("5S('-E<VII+B(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*;7-G
M:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN
M9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI
M97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I
M;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO
M=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C
M:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P
M;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@(B(*(EIA
M;&]G=6H@<VGJ('!O;F]W;FEE(&)Y('=Z;F]W:>8@='=O<GIE;FEE('-W;VIE
M:B!W:6%D;VUOMF-I+B!*9;9L:2!4=V]J82`B"B)P<GIE9VRQ9&%R:V$@;FEE
M('6_>7=A('!L:6OS=R!T>7!U("=C;V]K:65S)RP@82!T=V]R>F]N82!P<GIE
M>B!#:65B:64@(@HB=VEA9&]M;[;F('IN86ID=6IE('-IZB!W(&YO=WEM(&]K
M;FEE+"!W>6UA9V%N92!J97-T('!O;F]W;F4@;&]G;W=A;FEE+B`B"B)/<&5R
M86-J82!T82!W>6UA9V%N82!J97-T('IE('=Z9VSJ9'4@;F$@8F5Z<&EE8WIE
M\7-T=V\@5'=O:F5J('-E<VII+B`B"B)0<GIE<')A<WIA;7D@>F$@=W-Z96QK
M:64@;FEE9&]G;V1N;[9C:2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C<R"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D+B(*
M;7-G<W1R(")0<F]S>NH@=W!R;W=A9'IIYB!H87.S;RXB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C8X"FUS9VED(")0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE+B(*;7-G<W1R(")0<F]S>NH@=W!R;W=A9'IIYB!N87IW
MZB!UOWET:V]W;FEK82XB"@HC.B!C;VUP;W-E+G!H<#HW.2!L:6(O24U0+G!H
M<#HU,#D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A
M;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B4&]P<F%W(&YI96IE9&YO>FYA8WIN
M>2!L=6(@;FEE<')A=VEDLV]W>2!A9')E<RXB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C0R"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H92!F
M;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I
M;VX@9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@HB4')Z96=L
ML61N:6H@<&]N:;]S>K$@:6YF;W)M86-JZBP@82!P;W1E;2!W>6)I97)Z(&IE
M9&ZQ('H@;W!C:FD@9&]S=.IP;GEC:"!W("(*(FUE;G4N(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O:F%V87-C<FEP="YI;F,Z-3,*;7-G:60@(E!L96%S92!S
M96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I;VYS
M+B(*;7-G<W1R(")7>6)I97)Z(&9O;&1E<B!P<GIE9"!W>6MO;F%N:65M(&IA
M:VEE:FMO;'=I96L@86MC:FDN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4P,@IM<V=I9"`B4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T
M:&4@;65N=2!B96QO=RXB"FUS9W-T<B`B5WEB:65R>B!O<&-JZB!Z('!O;FF_
M<WIE9V\@;65N=2XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N
M:6YC.C0Q"FUS9VED(")0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD
M97(@=&\@<V5A<F-H+B(*;7-G<W1R(")7>6)I97)Z(&-H;V-I8;\@:F5D96X@
M9F]L9&5R(&1O('!R>F5S>G5K86YI82XB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]J879A<V-R:7!T+FEN8SHT"FUS9VED(")0;&5A<V4@<V5L96-T(&]N;'D@
M;VYE(&9O;&1E<B!F;W(@=&AI<R!O<&5R871I;VXN(@IM<V=S='(@(E=Y8FEE
M<GH@='EL:V\@:F5D96X@9F]L9&5R(&1L82!T96H@;W!E<F%C:FDN(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<V"FUS9VED(")0;&5A
M<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM
M<V=S='(@(E=Y8FEE<GH@;'5B(&5D>71U:B!W(&]K;FEE.B(*"B,Z(&-O;F9I
M9R]M;W1D+G!H<"YD:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM
M<V=S='(@(DYA<.ID>F%N92!P<GIE>B!(;W)D92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#8*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U<F4@
M=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B4&]P<GIE9'IIYB!4=_-J
M('!O9'!I<R!M>;9L;FEK86UI("@G+2T@)RD_(@H*(SH@<VUI;64N<&AP.C(T
M,2!P9W`N<&AP.C(U-R!F:6QT97)P<F5F<RYP:'`Z-#`*;7-G:60@(E!R969E
M<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")5<W1A=VEE
M;FEA('IO<W1ALWD@>FUI96YI;VYE+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E!O
M9&=LL60B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C(X"FUS9VED(")0<F5V:6]U<R!-97-S86=E(@IM<V=S='(@(E!O<')Z
M961N:6$@=VEA9&]M;[;F(@H*(SH@;6%I;&)O>"YP:'`Z,S0S"FUS9VED(")0
M<F5V:6]U<R!086=E(@IM<V=S='(@(E!O<')Z961N:6$@<W1R;VYA(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,Q"FUS9VED
M(")0<FEN="(*;7-G<W1R(")$<G5K=6HB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]H96%D97)S+FEN8SHS.`IM<V=I9"`B4')I;W)I='DB"FUS9W-T<B`B4')I
M;W)Y=&5T(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<T
M"FUS9VED(")0<FEV871E($ME>2!087-S=V]R9"(*;7-G<W1R(")(87.S;R!P
M<GEW871N96=O(&ML=6-Z82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-3(*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@
M<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R(")0>71A:B!Z82!K8;]D>6T@
M<F%Z96T@9V1Y('IAL[%C>FYI:R!J97-T('=Y<[-A;GD[(&1O;7FV;&YI92!.
M244B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34Q"FUS9VED(")0<F]M
M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@
M=&\@6453(@IM<V=S='(@(E!Y=&%J('IA(&MAOV1Y;2!R87IE;2!G9'D@>F&S
ML6-Z;FEK(&IE<W0@=WESLV%N>3L@9&]M>;9L;FEE(%1!2R(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ
M(@IM<V=S='(@(E!R;W1O:_.S.B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0R
M.0IM<V=I9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E
M;B!D:7-A8FQE9"XB"FUS9W-T<B`B3V)SLW5G82!S97)W97)A('!U8FQI8WIN
M>6-H(&ML=6-Z>2!01U`@>F]S=&&S82!W>;.Q8WIO;F$N(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)?9V4@1&5L971E9"(*
M;7-G<W1R(")7>6-Z>;;F('5S=6YIZG1E("A?9RDB"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS7V1E;&5T960N:6YC.C@*;7-G:60@(E!U<F=E($1E;&5T960B"FUS9W-T
M<B`B5WEC>GFVYB!U<W5N:>IT92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C(R"FUS9VED(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B
M5WEC>GFVYB!F;VQD97)Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,`IM<V=I9"`B4'5R9V4@5')A<V@@:&]W(&]F=&5N.B(*;7-G<W1R(")*86L@
M8WKJ<W1O(&]P<O._;FEAYB!+;W-Z.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.3D*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E
M<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@(E5S
M=7=A:B!W:6%D;VUOMF-I('H@2V]S>F$@<W1A<G-Z92!N:;\@=&$@;&EC>F)A
M(&1N:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED(")0
M=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS9W-T
M<B`B57-U;K'F('-T87*Q('=I861O;6^VYB!Z($MO<WIA/R(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L
M9&5R+B(*;7-G<W1R(")5<W5W86YI92`E9"!W:6%D;VUOMF-I('H@2V]S>F$N
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8T
M"FUS9VED(")0=7)G:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB
M"FUS9W-T<B`B57-U=V%N:64@,2!W:6%D;VUOMF-I('H@2V]S>F$N(@H*(SH@
M=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHQ-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB
M"FUS9W-T<B`B5WEK;W)Z>7-T86YI92!P;VIE;6YOMF-I(&MO;G1A.B`E+C)F
M34(@+R`E+C)F34(@("@E+C)F)24I(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U
M;W1A+FEN8SHR,0HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z
M("4N,F9-0B`O($Y/($Q)34E4(@IM<V=S='(@(E=Y:V]R>GES=&%N:64@<&]J
M96UN;[9C:2!K;VYT83H@)2XR9DU"("\@0E)!2R!,24U)5%4B"@HC.B!T96UP
M;&%T97,O<75O=&$O<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E%U;W1A('-T871U<SH@3D\@3$E-250B"FUS9W-T<B`B5WEK;W)Z>7-T86YI
M92!P;VIE;6YOMF-I(&MO;G1A.B!"4D%+($Q)34E452(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN
M9R`E9CHB"FUS9W-T<B`B0WET;W=A;FEE("5F.B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,W-PIM<V=I9"`B4F5?<75E<W0@1&5L:79E
M<GD@0V]N9FER;6%T:6]N(@IM<V=S='(@(E=Y;6%G86H@<&]T=VEE<F1Z96YI
M82!O9&5B<F%N:6$@*%]Q*2(*"B,Z('-E87)C:"YP:'`Z,38S"FUS9VED(")2
M96-E:79E9"!/;B(*;7-G<W1R(")/=')Z>6UA;F4B"@HC.B!S96%R8V@N<&AP
M.C$W,0IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`B3W1R>GEM86YE
M('!Z960B"@HC.B!S96%R8V@N<&AP.C$V-PIM<V=I9"`B4F5C96EV960@56YT
M:6PB"FUS9W-T<B`B3W1R>GEM86YE(&1O(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C7W0B"FUS
M9W-T<B`B4')Z96MI97)U:B`H7W0I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C="(*;7-G<W1R
M(")0<GIE:VEE<G5J(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C$Q-0IM<V=I9"`B4F5D:7)E8W0@365S<V%G92(*;7-G<W1R(")0<GIE
M:VEE<G5J('=I861O;6^VYB(*"B,Z(&-O;7!O<V4N<&AP.C<S-`IM<V=I9"`B
M4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S='(@(E!R>F5K:65R=6H@=+$@
M=VEA9&]M;[;F(@H*(SH@8V]M<&]S92YP:'`Z-SDT"FUS9VED(")2961I<F5C
M=&EN9R!F86EL960N(@IM<V=S='(@(E!R>F5K:65R;W=A;FEE(&YI975D86YE
M+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W,PIM<V=I
M9"`B4F5F<F5S:"(*;7-G<W1R(")/9+9W:66_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<V,`IM<V=I9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM
M<V=S='(@(D]DMG=I9;\@=VED;VL@9F]L9&5R83HB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]H96%D+FEN8SHY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI
M;F,Z-`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E!R>F6S861U:B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+VAE860N:6YC.C,*;7-G:60@(E)E;&]A9"!6:65W
M(@IM<V=S='(@(E!R>F6S861U:B!W:61O:R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,C8@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM
M<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B4&%M:>IT86H@;R!I;F9O<FUA8VII('=O;&YY+WIA:NIT>2XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34P"FUS9VED(")296UE;6)E<B!T
M:&4@;&%S="!V:65W(@IM<V=S='(@(EIA<&%M:>IT86H@;W-T871N:2!W:61O
M:R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PIM<V=I
M9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(EID86QN82!S:W)Z>6YK82(*
M"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M
M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(E5S=?$@<&]L92!Z('-Z
M=6MA;FEA(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S`U"FUS9VED(")296UO=F4@<V]U<F-E(@IM<V=S='(@(E5S=?$@O'+S9+-O
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B
M4F5N86UE($9O;&1E<BAS*2(*;7-G<W1R("):;6EE\2!N87IWZB!F;VQD97)U
M(&QU8B!F;VQD97+S=R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*
M;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O
M9B!M;VYT:#\B"FUS9W-T<B`B(@HB6FUI96YI8>8@;F%Z=^H@9F]L9&5R82!W
M:6%D;VUOMF-I('=Y<[-A;GEC:"!N82!P;V-ZL71K=2!K8;]D96=O(&UI97-I
ML6-A/R(*"B,Z(&QI8B]&;VQD97(N<&AP.C0T,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296YA;6EN9R!<(B5S7"(@=&\@7"(E<UPB(&9A:6QE9"X@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("):;6EA;F$@;F%Z=WD@
M>B!<(B5S7"(@;F$@7"(E<UPB(&YI92!U9&%N82X@4V5R=V5R('IW<O-C:;,@
M;V1P;W=I962\(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C$P"FUS9VED(")297!L7WD@=&\@3&ES="(*;7-G<W1R(")/9'!O
M=VEE9'H@9W)U<&EE("A?>2DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3$Q"FUS9VED(")297!L86-E('=I=&@Z(@IM<V=S='(@(EIA
M;6EE\2!Z.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHX"FUS9VED(")297!L>2(*;7-G<W1R(")/9'!O=VEE9'HB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$Q(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT,#D*;7-G:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@(D]D<&]W
M:65DO"!W>7.S86YA+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL(@IM<V=S='(@(D]D
M<&]W:65D>B!W<WIY<W1K:6TB"@HC.B!C;VUP;W-E+G!H<#HV.#`*;7-G:60@
M(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B3V1P;W=I962\(&1O('=S>GES=&MI
M8V@Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$P"FUS9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@(D]D<&]W:65D>B!G
M<G5P:64B"@HC.B!C;VUP;W-E+G!H<#HV.#(*;7-G:60@(E)E<&QY('1O($QI
M<W0Z(@IM<V=S='(@(D]D<&]W:65DO"!D;R!G<G5P>3HB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY
M('1O(%]!;&PB"FUS9W-T<B`B3V1P;W=I961Z('=S>GES=&MI;2`H7V$I(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3,W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M-#<*;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM
M<V=S='(@(D]D<&]W:65DO"!Z87=I97)A(&YI92!O8G.S=6=I=V%N>2!F;W)M
M870@=VEA9&]M;[9C:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,S4*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N
M=&AS+B(*;7-G<W1R(")/9'!O=VEA9&%J('!R>F5Z(&MO;&5J;F4@9'=A(&UI
M97-IL6-E("AW;VQN>2]Z86KJ='DI(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4S-`IM<V=I9"`B4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R(")/9'!O=VEA9&%J(+^Q9&%NL2!I
M;F9O<FUA8VJQ('=O;&YY+WIA:NIT>2XB"@HC.B!M97-S86=E+G!H<#HR-3$*
M;7-G:60@(E)E<&QY+51O(@IM<V=S='(@(D]D<&]W:65D>BU$;R(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HR-3D@;&EB+T-O;7!O<V4N<&AP.C,Q,0IM<V=I9"`B
M4F5P;'DM5&\Z("(*;7-G<W1R(")/9'!O=VEE9'HM1&\Z(@H*(SH@8V]M<&]S
M92YP:'`Z-C<X"FUS9VED(")297!L>3HB"FUS9W-T<B`B3V1P;W=I961Z.B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS-B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR-@IM<V=I9"`B4F5P;W)T
M(&%S($EN;F]C96YT(@IM<V=S='(@(E)A<&]R='5J(&IA:V\@;FEE<WIK;V1L
M:7=Y(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C,S('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(T"FUS9VED(")2
M97!O<G0@87,@4W!A;2(*;7-G<W1R(")287!O<G1U:B!J86MO('-P86TB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-S0*;7-G:60@(E)E
M<75E<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(J^Q9&%J('!O='=I95]R
M9'IE;FEA('H@>F%P;WIN86YI96T@<VGJ('H@=')EMF-IL2!W:6%D;VUOMF-I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W.`IM<V=I9"`B4F5Q=65S
M="!D96QI=F5R>2!C;VYF:7)M871I;VX_(@IM<V=S='(@(J]A9&'F('!O='=I
M97)D>F5N:6$@9&]S=&%R8WIE;FEA/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-C8*;7-G:60@(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T
M<B`BK[%D8>8@<&]T=VEE<F1Z96YI82!Z87!O>FYA;FEA('-IZB!Z('1R9;9C
M:;$_(@H*(SH@;6%I;&)O>"YP:'`Z,C`T"FUS9VED(")297%U97-T960@;65S
M<V%G92!N;W0@9F]U;F0N(@IM<V=S='(@(E=Y;6%G86YA('=I861O;6^VYB!N
M:65Z;F%L97II;VYA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M.3<*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(E=Y;6%G
M86YY('5C>F5S=&YI:R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M,30S('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHR-@HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,34X"FUS9VED(")297-E="(*;7-G<W1R(")297-E
M="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,34*;7-G:60@(E)E
M<W!O;F1E;G0@4W1A='5S(%5P9&%T960N(@IM<V=S='(@(E-T871U<R!O9'!O
M=VEA9&%JL6-E9V\@=6%K='5A;&YI;VYY(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(X"FUS9VED(")297-U;64B"FUS9W-T
M<B`B5WIN\W<B"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")297-U;64@
M>6]U<B!S97-S:6]N(@IM<V=S='(@(E=Z;O-W('-W;VJQ('-E<VKJ(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHS,2!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,S(*;7-G:60@(E)E='5R;B!T
M;R!&971C:"!-86EL(@IM<V=S='(@(E!O=W+S="!D;R!O<&-J:2!P;V)I97)A
M;FEA('!O8WIT>2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHW
M,"!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$S"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,34X('1E;7!L871E<R]S;6EM92]N;W1A
M8W1I=F4N:6YC.C,S"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-3D@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C$V.0HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C8X('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHS,PIM<V=I9"`B
M4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B4&]W<O-T(&1O(&]P8VII(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q-`IM<V=I9"`B(@HB4F5T=7)N
M('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN
M9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*(E!O=W+S="!D
M;R!W:61O:W4@<VMR>GEN:VD@<&\@<VMA<V]W86YI=2P@<')Z96YI97-I96YI
M=2!L=6(@<VMO<&EO=V%N:74@(@HB=VEA9&]M;[9C:3\B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")2;VQE(@IM<V=S='(@(E)O
M;&$B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$S,2!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(R-@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C0P.`IM<V=I9"`B4R]-24U%(@IM<V=S='(@(E,O34E-12(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3(*;7-G:60@
M(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B5VEA9&]M;[;F(&MO
M9&]W86YA(&ML=6-Z96T@4R]-24U%(@H*(SH@8V]M<&]S92YP:'`Z,S8W"FUS
M9VED(")3+TU)344@17)R;W(Z("(*;7-G<W1R(")"L[%D(%,O34E-13H@(@H*
M(SH@8V]M<&]S92YP:'`Z,S0V"FUS9VED(")3+TU)344@17)R;W(Z($YE960@
M<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@
M(D*S860@4R]-24U%.B!7>6UA9V%N92!H87.S;R!D;&$@;W-O8FES=&5G;R!K
M;'5C>F$@<')Y=V%T;F5G;RXB"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T
M:79E+FEN8SHV"FUS9VED(")3+TU)344@3D]4($%C=&EV92(*;7-G<W1R(")3
M+TU)344@;FEE86MT>7=N92(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")3+TU)344@
M3W!T:6]N<R(*;7-G<W1R(")/<&-J92!3+TU)344B"@HC.B!S;6EM92YP:'`Z
M-#D*;7-G:60@(E,O34E-12!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(E=P
M<F]W861Z96YI92!H87.S82!D;&$@4R]-24U%(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHQ,#`*;7-G:60@(E,O34E-12!097)S;VYA;"!+97EP
M86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M(@IM<V=S='(@(D]B<[-U9V$@4R]-24U%('=Y;6%G82!B97IP:65C>FYE9V\@
M<&^SL6-Z96YI82!34TPN(@H*(SH@<VUI;64N<&AP.C$T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S
M=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B2VQU8WH@<'5B;&EC>FYY
M(%,O34E-12!D;&$@7"(E<UPB('!O;7FV;&YI92!U<W5N:>IT>2XB"@HC.B!S
M;6EM92YP:'`Z,38R"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S
M9G5L;'D@861D960N(@IM<V=S='(@(DML=6-Z('!U8FQI8WIN>2!3+TU)344@
M9&]D86YY('!O;7FV;&YI92XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C0U"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B
M6F)I\W(@<'5B;&EC>FYY8V@@:VQU8WIY(%,O34E-12(*"B,Z('-M:6UE+G!H
M<#HR,3$*;7-G:60@(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U
M8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B4'5B;&EC>FYA+U!R>7=A=&YA
M('!A<F$@:VQU8WIY(%,O34E-12!D;V1A;F$@<')A=VEDLV]W;RXB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"FUS9VED(")3
M+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(E!O9'!I<R!K;'5C>F$@4R]-
M24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ
M-`IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@
M(E=I861O;6^VYB!P;V1P:7-A;F$O:V]D;W=A;F$@:VQU8WIE;2!3+TU)344B
M"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B
M4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM
M<V=S='(@(D]B<[-U9V$@4R]-24U%(&IE<W0@=WFSL6-Z;VYA(&YA('1Y;2!S
M>7-T96UI92XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S,`IM
M<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B
M;&5D('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92`B"B)D96-R>7!T
M960N(@IM<V=S='(@(B(*(D]B<[-U9V$@4R]-24U%(&YI92!Z;W-T8;-A(&%K
M='EW;W=A;F$@9&QA=&5G;R!W:6%D;VUOMN8@;FEE(&UOOV4@>F]S=&'F("(*
M(GID96MO9&]W86YA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,38R"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S
M;R!T:&4@8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S<V%G92!C86X@;F]T
M("(*(F)E(&1I<W!L87EE9"XB"FUS9W-T<B`B(@HB3V)SLW5G82!3+TU)344@
M;FEE('IO<W1ALV$@86MT>7=O=V%N82!D;&%T96=O>F%W87)T;[;F('1E:B!P
M;V1P:7-A;F5J("(*(G=I861O;6^V8VD@;FEE(&UOOV4@>F]S=&'F('=YMG=I
M971L;VYA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3,U"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@
M9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D
M+B(*;7-G<W1R("(B"B)/8G.S=6=A(%,O34E-12!N:64@>F]S=&&S82!A:W1Y
M=V]W86YA(&1L871E9V\@<&]D<&ES(&-Y9G)O=WD@;FEE(&UOOV4@8GGF("(*
M(GIW97)Y9FEK;W=A;GDN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-`IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@
M=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES("(*(F-U
M<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S
M="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@(@HB=&AE(%,O34E-12!F
M96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2(*;7-G<W1R("(B"B)/
M8G.S=6=A(%,O34E-12!W>6UA9V$@;V)SLW5G:7=A;FEA('=Y<VMA:W5JL6-Y
M8V@@;VMI96YE:RX@2F6V;&D@='=O:F$@(@HB<')Z96=LL61A<FMA(&]B96-N
M:64@;6$@=WFSL6-Z;VYE('=Y:W-K86MU:K%C92!O:VEE;FMA+"!M=7-I<WH@
M>FUI96YIYB!T;R`B"B)U<W1A=VEE;FEE(&%L8F\@4R]-24U%(&YI92!BZF1Z
M:64@9'II8;-AYB!P;W!R87=N:64B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHR-C8*;7-G:60@(E-?=6)J96-T(@IM<V=S='(@(E1E;6%T
M("A?=2DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-30*
M;7-G:60@(E-A7W9E(&$@8V]P>2!I;B`B"FUS9W-T<B`B6F%P:7-Z(&MO<&EE
M('<@*%]V*2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHS,`IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B6F%P:7-Z(&IA:V\@
M*%]V*2(*"B,Z('-E87)C:"YP:'`Z,S8S('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHV-PIM<V=I9"`B4V%V92(*;7-G<W1R("):87!I<WHB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,C@*;7-G:60@(E-A
M=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD
M97(_(@IM<V=S='(@(EIA<&ES>7=AYB!Z8;.Q8WIN:6MI('H@=VEA9&]M;[9C
M:;$@=R!F;VQD97)Z92!W>7.S86YE+7=I861O;6^V8VD_(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C@@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#(T"FUS9VED(")3879E($1R869T(@IM<V=S='(@(EIA
M<&ES>B!S>FMI8R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHV
M.2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W"B,Z('1E;7!L871E<R]S
M;6EM92]N;W1A8W1I=F4N:6YC.C(S('1E;7!L871E<R]P9W`O<&=P+FEN8SHV
M-`HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,C,*;7-G:60@(E-A
M=F4@3W!T:6]N<R(*;7-G<W1R("):87!I<WH@;W!C:F4B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV."!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,C0*;7-G:60@(E-A=F4@7T1R869T(@IM<V=S='(@(EIA
M<&ES>B!S>FMI8R`H7V0I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C,P"FUS9VED(")3879E(&%S(@IM<V=S='(@(EIA<&ES
M>B!J86MO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B
M4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R("):87!I<WEW8>8@<WIK
M:6-E(&IA:V\@;FEE=VED>FEA;F4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P,S`*;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY
M('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\B"FUS9W-T<B`B6F%P:7-Y
M=V'F(&%U=&]M871Y8WIN:64@861R97-A=/-W('<@9&]M>;9L;F5J(&MS:;&_
M8V4@861R97-O=V5J/R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M,3(W"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U86P@9F]L9&5R/R(*
M;7-G<W1R("):87!I<WH@<WIU:V%N:64@:F%K;R!W:7)T=6%L;GD@9F]L9&5R
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C,*;7-G:60@(E-A=F4@
M<V5N="!M86EL/R(*;7-G<W1R("):87!I<WEW8>8@=WESLV%NL2!W:6%D;VUO
MMF,_(@H*(SH@8V]M<&]S92YP:'`Z,3$V,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B6F%P:7-Z86YI92!S>FMI8W4@;FEE
M=61A;F4N(%-E<G=E<B!Z=W+S8VFS(&]D<&]W:65DO#H@)7,B"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y.2!T96UP;&%T97,O;6%I
M;&)O>"]H96%D97(N:6YC.C$Q"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N
M<&AP.C4P"FUS9VED(")396%R8V@B"FUS9W-T<B`B4WIU:V%J(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X
M+VAE861E<BYI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S
M(@IM<V=S='(@(E-Z=6MA:B`E<R(*"B,Z('-E87)C:"YP:'`Z,S$V"FUS9VED
M(")396%R8V@@4F5S=6QT<R(*;7-G<W1R(")7>6YI:VD@=WES>G5K:7=A;FEA
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM<V=S='(@
M(E=I9'II86YE(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHY
M"FUS9VED(")396QE8W0B"FUS9W-T<B`B5WEB:65R>B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H
M97(@06-C;W5N="(*;7-G<W1R(")7>6)I97)Z(&EN;F4@:V]N=&\B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(E-E;&5C="!A
M(&1A=&4B"FUS9W-T<B`B5WEB:65R>B!D873J(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]F:65L9',N:6YC.C$P"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G
M<W1R(")7>6)I97)Z('!O;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(W"FUS9VED(")396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D
M9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S='(@(E=Y
M8FEE<GH@:W-IL;]KZB!A9')E<V]WL2!D;R!P<GIE<WIU:VEW86YI82!I(&1O
M9&%W86YI82!A9')E<_-W+B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z.#@*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5WEB:65R>B!W<WIY
M<W1K;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R
M,PIM<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H96X@97AP
M86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B5WEB:65R>B!W<WIY<W1K:64@
M<&]L82!D;R!P<GIE<WIU:VEW86YI82!P;V1C>F%S(')O>G-Z97)Z86YI82!A
M9')E<_-W+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE
M8W0N:6YC.C(Q"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G<W1R(")7
M>6)I97)Z(&MO;G1O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX
M.0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B3FEE('=Y8FEE<F%J(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHR,0IM
M<V=I9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S='(@(E=Y
M8FEE<GH@='EP('-E<G=E<F$@<&]C>G1O=V5G;R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P.0IM<V=I9"`B4V5L96-T960@061D
M<F5S<R!B;V]K<SHB"FUS9W-T<B`B5WEB<F%N92!K<VFQOVMI(&%D<F5S;W=E
M.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-#<*;7-G:60@(E-E;F0@
M2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`B5WFV;&EJ(&ML=6-Z
M(&1O('!U8FQI8WIN96=O('-E<G=E<F$@:VQU8WIY(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8P-`IM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M
M871I;VXB"FUS9W-T<B`B5WFV;&EJ(&YA:K9W:66_<WJQ(&EN9F]R;6%C:NHB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,C(*;7-G:60@(E-E;F0@365S<V%G
M92(*;7-G<W1R(")7>;9L:6H@=VEA9&]M;[;F(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8Y.`IM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R
M97%U97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B5WES>;-AYB!P;W1W
M:65R9'IE;FEE('!R>F5C>GET86YI82!K:65D>2!Z8;]Y8WIO;F4@<')Z97H@
M;F%D87=CZC\B"@HC.B!F;VQD97)S+G!H<#HS.3(*;7-G:60@(E-E;G0@;6%I
M;"!F;VQD97(B"FUS9W-T<B`B1F]L9&5R('!O8WIT>2!W>7.S86YE:B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,SD*;7-G:60@
M(E-E;G0@;6%I;"!F;VQD97(Z(@IM<V=S='(@(D9O;&1E<B!P;V-Z='D@=WES
MLV%N96HZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-#4*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ-3(*;7-G:60@(E-E<G9E<B(*;7-G<W1R(")397)W97(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*;7-G:60@(E-E<G9E<B!A
M;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:F4@;R!S
M97)W97)Z92!I(&9O;&1E<GIE(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C(S"FUS9VED(")397)V97(Z(@IM<V=S='(@(E-E<G=E<CHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F
M97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E
M;&5T92!M97-S86=E<RXB"FUS9W-T<B`B57-T87<@<')E9F5R96YC:F4@<')Z
M96YO<WIE;FEA(&D@=7-U=V%N:6$@=VEA9&]M;[9C:2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")3970@=&AE(%@M4')I;W)I='D@
M:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R("(B"B):
M8;.Q8WIAYB!W(&YA9[/S=VMU(&EN9F]R;6%C:NH@;R!P<FEO<GET96-I92!P
M;V1C>F%S('1W;W)Z96YI82!W:6%D;VUOMF-I/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G<W1R(")5
M9&]S=.IP;FEA:B!F;VQD97)Y(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C@V"FUS9VED(")3:&%R92!M86EL(&9O;&1E<G,B"FUS9W-T<B`B561O<W3J
M<&YI86H@9F]L9&5R>2!P;V-Z=&]W92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O
M=&AE<B!U<V5R<RXB"FUS9W-T<B`B561O<W3J<&YI86H@9F]L9&5R>2!P;V-Z
M=&]W92!D;&$@:6YN>6-H('6_>71K;W=N:6OS=RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C8S"FUS9VED("(B"B)3:&]U;&0@;&%R9V4@8FQO8VMS
M(&]F('%U;W1E9"!T97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT
M/R!)="!C86X@8F4@(@HB=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C
M:&]O<V4N(@IM<V=S='(@(B(*(D-Z>2!P;VMA>GEW8>8@;'5B('5K<GEW8>8@
M9&]M>;9L;FEE(&1UOV4@8FQO:VD@=&5K<W1U(&-Y=&]W86YE9V\_(%1E;B!W
M>6+S<B`B"B)M;[]E(&)YYB!P<GIY9&%T;GDN(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C4R"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P
M;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\B"FUS9W-T
M<B`B0WIY('-P<F%W9'IAYB!O8F5C;F^VYB!D86YY8V@@4$=0('<@=VEA9&]M
M;[9C:6%C:#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`U"FUS9VED
M(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S
M879I;F<@82!D<F%F=#\B"FUS9W-T<B`B0WIY('IA;6MNL>8@;VMN;R!T=V]R
M>F5N:6$@=VEA9&]M;[9C:2P@9V1Y('-Z:VEC('IO<W1A;FEE('IA8VAO=V%N
M>3\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#`*;7-G:60@(E-H;W5L
M9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@
M;65S<V%G97,@8GD@9&5F875L=#\B"FUS9W-T<B`B0WIY(&1O;7FV;&YI92!Z
M8;.Q8WIAYB!D;R!W:6%D;VUOMF-I(%1W\VH@:VQU8WH@<'5B;&EC>FYY(%!'
M4#\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"FUS9VED(")3
M:&]W($%L;"!&;VQD97)S(@IM<V=S='(@(E!O:V&_('=S>GES=&MI92!F;VQD
M97)Y(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C<*;7-G
M:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B4&]K8;\@=W-Z>7-T:VEE
M(&YA9[/S=VMI(@H*(SH@;6%I;&)O>"YP:'`Z,S8Q"FUS9VED(")3:&]W($1E
M;&5T960B"FUS9W-T<B`B4&]K8;\@=7-U;FGJ=&4B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D($AE
M861E<G,B"FUS9W-T<B`B4&]K8;\@;V=R86YI8WIO;F4@;F%GL_-W:VDB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW,`IM<V=I9"`B4VAO
M=R!-86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T<B`B4&]K8;\@:6YF
M;W)M86-J92!L:7-T>2!M86EL;W=E:B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E
M<G,B"FUS9W-T<B`B4&]K8;\@='EL:V\@<W5B<VMR>6)O=V%N92!F;VQD97)Y
M(@H*(SH@9F]L9&5R<RYP:'`Z,C@W"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E
M9"(*;7-G<W1R(")0;VMAOR!N:65S=6)S:W)Y8F]W86YE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8P,PIM<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L
M;&]W('-T<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*
M;7-G<W1R(")0;VMA>GEW8>8@:6MO;NH@<&]Z=V%L86JQ8[$@;F$@<&]B:65R
M86YI92!Z8;.Q8WIN:6OS=R!Z('=I861O;6^V8VD_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDW-`IM<V=I9"`B4VAO=R!L96=E;F0@:6X@=&AE(&UA
M:6QB;W@@=FEE=S\B"FUS9W-T<B`B5WFV=VEE=&QAYB!L96=E;F3J('<@=VED
M;VMU('-K<GIY;FMI/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#D*
M;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY
M/R(*;7-G<W1R(")7>;9W:65T;&'F('!O9&=LL60@='EL:V\@9&QA(&YI97!R
M>F5C>GET86YY8V@@=VEA9&]M;[9C:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#$W"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*
M;7-G<W1R(")7>;9W:65T;&'F('!O9&=LL60@=R!P;W)A9&%C:#\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('1H92!&971C
M:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(E=YMG=I971L
M8>8@:6YF;W)M86-JZB!O(&YO=V5J('!O8WIC:64@;F$@<&%S:W4@>F%D8?$_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P.`IM<V=I9"`B4VAO
M=R!T:&4@26UA9V5S(@IM<V=S='(@(E!O:V&_(&]B<F%Z>2(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHV,0IM<V=I9"`B4VAO=R!T:&4@9FEL
M=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(E=YMG=I971L8>8@
M:6MO;NH@9FEL=&5R\W<@;F$@<&%S:W4@>F%D8?$_(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C,P"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M
M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(E=YMG=I971L8>8@8V&S:V]W:72Q
M(&QI8WIBZB!W:6%D;VUOMF-I('<@9F]L9&5R>F4_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8V,`IM<V=I9"`B4VAO=VXB"FUS9W-T<B`B4&]K87IA
M;F4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C0R"FUS9VED(")3:5]Z92(*;7-G<W1R(")2;U]Z;6EA<B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$S"FUS9VED(")3:6=N('5P(&EF(&YO
M="!R96=I<W1E<F5D(@IM<V=S='(@(EIA<F5J97-T<G5J('-IZBP@:F6V;&D@
M:F5S>F-Z92!T96=O(&YI92!Z<F]B:;-EMB(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z,3<*;7-G:60@(E-I9VYE9"(*;7-G<W1R(")0;V1P
M:7-A;F4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z
M,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")2;WIM:6%R(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHX,0IM<V=I9"`B4V]R="!$
M:7)E8W1I;VXB"FUS9W-T<B`B4W!O<_-B('-O<G1O=V%N:6$B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3
M;W)T(&)Y($%R<FEV86PB"FUS9W-T<B`B4V]R='5J('=G(&-Z87-U('!R>GEB
M>6-I82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,38*;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R(")3;W)T=6H@=V<@
M9&%T>2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,C8*;7-G:60@(E-O<G0@8GD@1G)O;2!!9&1R97-S(@IM<V=S='(@(E-O
M<G1U:B!W9R!P;VQA(&YA9&%W8WDB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C0Q"FUS9VED(")3;W)T(&)Y($UE<W-A9V4@
M4VEZ92(*;7-G<W1R(")3;W)T=6H@=V<@<F]Z;6EA<G4@=VEA9&]M;[9C:2(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S8*
M;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R(")3;W)T=6H@=V<@=&5M
M871U(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHS,0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B4V]R='5J('=G
M('>Q=&MU(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHR,0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R97-S(@IM<V=S='(@(E-O
M<G1U:B!W9R!P;VQA(&%D<F5S871A(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P
M86US96QE8W0N:6YC.C(S"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`B
M1F]L9&5R('-P86UU.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,S-PIM<V=I9"`B4W!E8VEA;"!#:&%R86-T97)S(@IM<V=S='(@(EIN
M86MI('-P96-J86QN92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,S-`IM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`B4W!R87=D>F%N
M:64@<&ES;W=N:2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHT.`IM<V=I9"`B4W!E;&P@0VAE8VME<B(*;7-G<W1R(")3<')A=V1Z86YI
M92!P:7-O=VYI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C4P('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU.`IM<V=I9"`B
M4W!E;&P@8VAE8VL@8V]M<&QE=&4B"FUS9W-T<B`B4W!R87=D>F%N:64@<&ES
M;W=N:2!Z86MO\6-Z;VYE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V
M,@IM<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L
M;"!C:&5C:VEN9RXB"FUS9W-T<B`B0K/J9/-W('!I<V]W;FD@;F$@96MR86X@
M<&]D8WIA<R!S<')A=V1Z86YI82!P:7-O=VYI+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU,3(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U
M,@IM<V=I9"`B4W1A<G0B"FUS9W-T<B`B4W1A<G0B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A
M='5S(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(P,@IM<V=I9"`B4W1R
M:7`@071T86-H;65N="(*;7-G<W1R(")0;V)I97)Z('IAL[%C>FYI:R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#$*;7-G:60@(E-T<FEP(&QI;F5B
M<F5A:W,_(@IM<V=S='(@(E5S=6ZQYB!P<GIE<G=Y/R(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*;7-G:60@(E-U8E]J
M96-T(@IM<V=S='(@(E1E;6%T("A?:BDB"@HC.B!M97-S86=E+G!H<#HR-3(@
M<V5A<F-H+G!H<#HQ-3$@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN
M8SHR-0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")496UA="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX.3$*;7-G:60@(E-U8FIE8W0@1FEE;&0B"FUS
M9W-T<B`B4&]L92!T96UA='4B"@HC.B!S96%R8V@N<&AP.C,V-2!T96UP;&%T
M97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C$*(SH@=&5M<&QA=&5S+W!G<"]P
M87-S<&AR87-E+FEN8SHS,0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E=YMFQI
M:B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G:60@
M(E-U8G-C<FEB92!T;R!&;VQD97(H<RDB"FUS9W-T<B`B4')Z96YOMB!S=6)S
M:W)Y<&-JZB!D;R!F;VQD97)U*/-W*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,S8Y(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X.0HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R(")0;VUYMFQN:64B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z.3(*;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S='(@(E-U9V5S
M=&EE(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V,B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C8T"FUS9VED(")3=6UM87)Y(@IM<V=S='(@
M(E!O9'-U;6]W86YI92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,Y,2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.30*;7-G
M:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B4')Z9;.Q
M8WH@;65T;V3J('1W;W)Z96YI82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,Y-0IM<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S:71I
M;VXB"FUS9W-T<B`B4')Z9;.Q8WH@;F$@9F]R;6%T($A434PB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.34*;7-G:60@(E-W:71C:"!T
M;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@(E!R>F6SL6-Z(&YA
M('IW>6NS>2!T96MS="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0Q,`IM<V=I9"`B5&5?>'0B"FUS9W-T<B`B5&5K<W0@*%]X*2(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@
M(E1E;G1A=&EV93H@(@IM<V=S='(@(E!R\V)N:64@>F%A:V-E<'1O=V%N92(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A
M=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(E!R\V)N82!A:V-E<'1A
M8VIA(+^Q9&%N:6$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8Q
M"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R(")0<O-B;FEE
M('IA86MC97!T;W=A;F4B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O
M9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G
M<W1R(")0;&EK(%1O4R`H5V%R=6YK:2!K;W)Z>7-T86YI82D@;FEE('ID969I
M;FEO=V%N>2!W(&-O;F8N<&AP(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDR-0IM<V=I9"`B5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S
M:&]U;&0@8F4@;&EN:V5D.B(*;7-G<W1R(")0;VQE($]D.B!K;VQU;6YA('=I
M861O;6^V8VD@<&]W:6YN82!B>>8@<&^SL6-Z;VYA.B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O
M<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R(")+;VYT;R!<(B5S7"(@>F]S=&&S;R!U<W5N:>IT
M92XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R(")+;VYT;R!<(B5S7"(@>F]S=&&S;R!Z87!I<V%N92XB"@HC.B!L:6(O
M1FEL=&5R+G!H<#HY-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S
M<R!<(B5S7"(@:&%S(&)E96X@861D960@=&\@)7,N(@IM<V=S='(@(D%D<F5S
M(%PB)7-<(B!Z;W-T8;,@9&]D86YY(&1O("5S+B(*"B,Z(&%T=&%C:&UE;G0N
M<&AP.C0S"FUS9VED(")4:&4@871T86-H;65N="!W87,@;F]T(&9O=6YD+B(*
M;7-G<W1R("):8;.Q8WIN:6L@;FEE('IO<W1ALR!Z;F%L97II;VYY+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.0IM<V=I9"`B5&AE(&-A;&5N
M9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R(")$871A('<@:V%L96YD87)Z
M=2!J97-T(&YI97!R87=I9+-O=V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S
M92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E
M="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS
M9W-T<B`B(@HB3VMI96YK;R!T=V]R>F5N:6$@=VEA9&]M;[9C:2!N:64@;6^_
M92!Z;W-T8>8@;W1W87)T92X@0WIYOV)Y('1W;VIA("(*(G!R>F5G;+%D87)K
M82!B;&]K;W=ALV$@=WES:V%K=6JQ8V4@;VMI96YK83\B"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N
M=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B
M6F%W87)T;[;F('!L:6MU($UA8VEN=&]S:"!J97-T('!O;FF_96HN(@H*(SH@
M;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN
M<&AP.CDQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C=7)R96YT(&9O;&1E
M<BAS*2!<(B5S7"(@=VEL;"!B92!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T
M<B`B3F%Z=V$@;V)E8VYE9V\@9F]L9&5R82CS=RD@7"(E<UPB('IO<W1A;FEE
M('IM:65N:6]N82!N82!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$Q,@IM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W
M:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE
M=F5D(@IM<V=S='(@(B(*(D]B96-N82!L:7-T82!UOWET:V]W;FEK\W<@>B!D
M;W-TZG!E;2!D;R!T96=O(&9O;&1E<F$@;FEE(&UOOV4@8GGF(&]D='=O<GIO
M;F$B"@HC.B!C;VUP;W-E+G!H<#HQ,3<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T;R!T:&4@7"(E<UPB(&9O;&1E
M<BXB"FUS9W-T<B`B4WIK:6,@>F]S=&&S('IA<&ES86YY(&1O(&9O;&1E<F$@
M7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,SD*;7-G
M:60@(E1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS
M9W-T<B`B5WED87)Z96YI92!Z;W-T8;-O(&1O9&%N92!D;R!T=V]J96=O(&MA
M;&5N9&%R>F$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@
M8F4@97AP86YD960N(@IM<V=S='(@(E!O;&4@7"(E<UPB(&YI92!M;[]E('IO
M<W1AYB!R;WIW:6YIZG1E+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!A;')E861Y(&5X
M:7-T<R(*;7-G<W1R("))<W1N:65J92!J=;\@9F]L9&5R(&\@;F%Z=VEE(%PB
M)7-<(BXB"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A;"!C
M:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O8FQE
M;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HB3F%Z=V$@9F]L9&5R82!<(B5S7"(@>F%W:65R82!N:64@<')A
M=VEDLV]W92!Z;F%K:2X@36^_92!B>>8@=&\@O'+S9+-E;2`B"B)P\[QN:65J
M<WIY8V@@<')O8FQE;?-W+B!:;V)A8WH@<W?S:B!P86YE;"!A9&UI;FES=')A
M8WEJ;GDN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S0W"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@
M=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B(@HB1F]L9&5R
M(%PB)7-<(B!Z;W-T8;,@=71W;W)Z;VYY+"!A;&4@;FEE('IO<W1ALV6V(&1O
M(&YI96=O('-U8G-K<GEB;W=A;GDN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!D
M96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@:70N
M(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@>F]S=&&S('-K87-O=V%N>2P@86QE
M(&YI92!U<W5N:>IT;R!4=V]J96H@<W5B<VMR>7!C:FDN(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9"(*;7-G<W1R(")&;VQD97(@7"(E<UPB(&YI92!Z;W-T8;,@=71W
M;W)Z;VYY+B!397)W97(@>G=R\V-ILR!O9'!O=VEE9+PB"@HC.B!L:6(O1F]L
M9&5R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<
M(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@;FEE('IO<W1ALR!U<W5N
M:65T>2X@3W1O(&-O(&]D<&]W:65D>FEALR!S97)W97(B"@HC.B!L:6(O1F]L
M9&5R+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<
M(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+B(*;7-G<W1R(")&;VQD
M97(@7"(E<UPB('IO<W1ALR!U='=O<GIO;GDN(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z,C@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B1F]L9&5R(%PB
M)7-<(B!Z;W-T8;,@=7-U;FGJ='DN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#,X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S
M=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(EIM:65N
M:6]N;R!N87IWZB!F;VQD97)A(%PB)7-<(B!N82!<(B5S7"(@<&]M>;9L;FEE
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY,@IM<V=I9"`B5&AE
M(&9O;&QO=VEN9R!F:6QE<R!W97)E(&%T=&%C:&5D('1O('1H:7,@<&%R=#HB
M"FUS9W-T<B`B3F%S=.IP=6JQ8V4@<&QI:VD@>F]S=&&S>2!D;[.Q8WIO;F4@
M9&\@=&5J(&-ZZK9C:3HB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M.38*;7-G:60@(B(*(E1H92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C
M875S92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U<B`B"B)A9&1R97-S
M8F]O:RXB"FUS9W-T<B`B(@HB3V)R87IK:2!BZF2Q('=YMG=I971L86YE('!O
M;FEE=V&_(&YA9&%W8V$@>FYA:F1U:F4@<VGJ('<@='=O:F5J(&MS:;&_8V4@
M(@HB861R97-O=V5J+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<U"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL
M;W=I;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B4V5R=V5R('!O8WIT;W=Y
M('=Y9V5N97)O=V&S(&YA<W3J<'5JL6.Q('=I861O;6^VYB!Z(&*SZF1E;3HB
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0IM<V=I
M9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN
M9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`B4V5R=V5R('!O8WIT;W=Y
M('=Y9V5N97)O=V&S(&YA<W3J<'5JL6.Q('=I861O;6^VYB!I;F9O<FUA8WEJ
M;K$Z(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@
M(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S
M86=E.B(*;7-G<W1R(")397)W97(@<&]C>G1O=WD@=WEG96YE<F]W8;,@;F%S
M=.IP=6JQ8[$@=VEA9&]M;[;F.B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D
M>2!E;7!T>2XB"FUS9W-T<B`B4VMR>GEN:V$@)7,@:F5S="!J=;\@<'5S=&$N
M(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B`H)60@8GET97,I
M(&5X8V5E9',@9F5T8V@@<VEZ92!L:6UI="XB"FUS9W-T<B`B5VEA9&]M;[;F
M(%PB)7-<(B!O9"!<(B5S7"(@*"5D(&)A:G3S=RD@<')Z96MR86-Z82!L:6UI
M="!R;WIM:6%R=2XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$P,PIM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S
M(&)E96X@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")4=V]R>F]N82!W:6%D
M;VUOMN8@>F]S=&&S82!Z86UK;FGJ=&$N(%=Y8VAO9'IE;FEE+B(*"B,Z(&UE
M<W-A9V4N<&AP.C$T,@IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B5VEA9&]M;[;F('IO<W1ALV$@=7-U;FGJ=&$N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDS"FUS9VED(")4:&4@;65S
M<V%G92!H87,@8F5E;B!V97)I9FEE9"XB"FUS9W-T<B`B5VEA9&]M;[;F('IO
M<W1ALV$@>G=E<GEF:6MO=V%N82XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!H
M87,@8F5E;B!V97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T<B`B5VEA9&]M
M;[;F('IO<W1ALV$@>G=E<GEF:6MO=V%N82X@3F%D87=C83H@)7,N(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+V]P96Y?<VUI;65?=VEN+FIS.C$P('1E;7!L871E
M<R]P9W`O;W!E;E]P9W!?=VEN+FIS.C$P"FUS9VED("(B"B)4:&4@<&%S<W!H
M<F%S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E
M('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B
M"FUS9W-T<B`B(@HB3VMN;R!Z(&AA<[-E;2!N:64@;6^_92!Z;W-T8>8@;W1W
M87)T92X@0WIYOV)Y('1W;VIA('!R>F5G;+%D87)K82!B;&]K;W=ALV$@(@HB
M=WES:V%K=6JQ8V4@;VMI96YK83\B"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F
M('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M("*L<O-DLV]W>2!T96MS="!K;'5C>F$@<'5B;&EC>FYE9V\@4$=0(&UOOV4@
M8GGF('=I9'II86YY("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H
M<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T
M(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(J^Q9&%N>2!P
M;&EK(&YI92!W>7-TZG!U:F4@=R!Z8;.Q8WIN:6MU($U3+51.148N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G:60@(E1H92!R97%U97-T
M960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C:&UE;G0N
M(@IM<V=S='(@(J^Q9&%N>2!P;&EK(&YI92!W>7-TZG!U:F4@=R!Z8;.Q8WIN
M:6MU(%II<"XB"@HC.B!M97-S86=E+G!H<#HU,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S
M=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("(*(F9R
M;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S
M92!C;&EC:R`E<R!T;R!S96YD('1H92`B"B)N;W1I9FEC871I;VX@;65S<V%G
M92XB"FUS9W-T<B`B(@HB3F%D87=C82!T96H@=VEA9&]MMF-I('=Y;6%G82!P
M;W1W:65R9'IE;FEA('!Z96-Z>71A;FEA('1E:B!W:6%D;6^V8VDN("(*(DML
M:6MN:6H@)7,@86)Y('=Y<[-AYB!W:6%D;VUOMN8@>B!Z87=I861O;6EE;FEE
M;2XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HV.0IM<V=I9"`B
M5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E871E(&$@=&AU;6)N86EL
M(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(E-E<G=E<B!N:64@<&]T<F%F:;,@
M<W1W;W)Z>>8@;6EN:6%T=7)K:2!T96=O(&]B<F%Z:V$N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#0*;7-G:60@(E1H92!S:6=N871U
M<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R(")0;V1P:7,@;FEE
M(&UOOV4@8GGF('IA<W2Q<&EO;F$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YJ<SHQ,#(*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E
M<W-F=6QL>2!R97!L86-E9"XB"FUS9W-T<B`B4&]D<&ES('IA<W2Q<&EO;F$@
M<&]M>;9L;FEE+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4Y"FUS9VED(")4:&4@
M<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D]K<F6V
M;&]N>2!P;&EK(&YI92!I<W1N:65J92XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,38Y"FUS9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T
M;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R("):861A;FEE('IO<W1ALV\@9&]D
M86YE(&1O('1W;VIE:B!L:7-T>2!Z861A\2XB"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HY-0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A
M9V4B"FUS9W-T<B`B5&5K<W0@=VEA9&]M;[9C:2(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M97AT(&]F('1H92!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@
M(E1E:W-T('=I861O;6^V8VD@;6^_92!B>>8@=WFV=VEE=&QO;GD@)7,N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#`*;7-G:60@(E1H92!T
M97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(@IM<V=S='(@(EIW<O-C;VYO
M(&]D<&]W:65DO"(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE
M9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(EIW<O-C;VYA
M(&]D<&]W:65DO"!M;[]E(&)YYB!W>;9W:65T;&]N82`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`IM<V=I9"`B5&AE('1E
M>'0@;V8@=&AE('-E;G0@;65S<V%G92(*;7-G<W1R(")7:6%D;VUOMN8@=WES
MLV%N82(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE
M<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B5VEA9&]M;[;F('=Y
M<[-A;F$@;6^_92!B>>8@=WFV=VEE=&QO;F$@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$U-`IM<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T
M<B`B26YF;W)M86-J82!O('6_>71K;W=N:6MU("AW;VQN>2]Z86KJ='DI('IO
M<W1ALV$@>F%C:&]W86YA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA
M=&EV92YP:'`Z.#8*;7-G:60@(E1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(").
M:64@;6$@OV%D;GEC:"!A;'1E<FYA='EW;GEC:"!C>NJV8VDL(&MT\W)E(&UO
M9[-Y8GD@>F]S=&'F('!O:V%Z86YE+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V5M<'1Y7VUA:6QB;W@N:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!M97-S
M86=E<R!I;B!T:&ES(&UA:6QB;W@N(@IM<V=S='(@(DYI92!M82!N;W=Y8V@@
M=VEA9&]M;[9C:2XB"@HC.B!T:')E860N<&AP.C8Y"B,L(&9U>GIY"FUS9VED
M(")4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(DYI92!M82"_861N>6-H(&%L=&5R;F%T>7=N>6-H(&-Z
MZK9C:2P@:W3S<F4@;6]GLWEB>2!Z;W-T8>8@<&]K87IA;F4N(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C4W-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R(")7>7-TL7!ILR!P<F]B;&5M('!O9&-Z87,@
M=WEM87IY=V%N:6$@)7,N($]T;R!C;R!O9'!O=VEE9'II8;,@<V5R=V5R(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C8Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE
M('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("(B"B)7>7-TL7!ILR!P<F]B;&5M
M('!O9&-Z87,@=WEM87IY=V%N:6$@<VMR>GEN:VDN(%-E<G=E<B!Z=W+S8VFS
M(&]D<&]W:65DO#H@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z-3@T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)7>7-T
ML7!ILR!P<F]B;&5M('!O9&-Z87,@=WEM87IY=V%N:6$@<VMR>GEN:VD@<&]C
M>G1O=V5J+B!/=&\@8V\@<&]W:65D>FEALR`B"B)S97)W97(B"@HC.B!L:6(O
M365S<V%G92YP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@
M7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S
M='(@(B(*(E=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!K;W!I;W=A;FEA('=I861O
M;6^V8VD@>B!<(B5S7"(@9&\@7"(E<UPB+B!397)W97(@(@HB>G=R\V-ILR!O
M9'!O=VEE9+PB"@HC.B!L:6(O365S<V%G92YP:'`Z,C`P(&QI8B]-97-S86=E
M+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B!<(B5S
M7"(N(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B
M(@HB5WES=+%P:;,@8K.Q9"!P;V1C>F%S('5S=7=A;FEA('=I861O;6^V8VD@
M>B!F;VQD97)A(%PB)7-<(BX@4V5R=V5R('IW<O-C:;,@(@HB;V1P;W=I962\
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@
M=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R
M('-A:60B"FUS9W-T<B`B(@HB5WES=+%P:;,@8K.Q9"!P;V1C>F%S('5S=7=A
M;FEA('=I861O;6^V8VD@=R!F;VQD97)Z92!<(B5S7"(N(%-E<G=E<B!Z=W+S
M8VFS("(*(F]D<&]W:65DO"(*"B,Z(&QI8B]-97-S86=E+G!H<#HR,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG
M(&UE<W-A9V5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*
M;7-G<W1R("(B"B)7>7-TL7!ILR!BL[%D('!O9&-Z87,@=7-U=V%N:6$@=VEA
M9&]M;[9C:2X@4V5R=V5R('IW<O-C:;,@;V1P;W=I962\.B`E<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB
M"FUS9W-T<B`B(@HB5WES=+%P:;,@8K.Q9"!P;V1C>F%S('5S=7=A;FEA('=I
M861O;6^V8VDN(%-E<G=E<B!Z=W+S8VFS(&]D<&]W:65DO#H@)7,B"@HC.B!L
M:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E<B]E
M;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E=Y<W2Q<&FS(&*S
ML60@<&]D8WIA<R!W>;9W:65T;&%N:6$@=&5J(&-ZZK9C:2!W:6%D;VUOMF-I
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4P."!L:6(O365S<V%G92YP:'`Z-30X
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!F
M;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)7>7-TL7!I
MLR!BL[%D('!O9&-Z87,@;WIN86-Z86YI82!W:6%D;VUOMF-I('<@9F]L9&5R
M>F4@7"(E<UPB+B!397)W97(@(@HB>G=R\V-ILR!O9'!O=VEE9+PB"@HC.B!F
M;VQD97)S+G!H<#HQ-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RXB"FUS9W-T<B`B5WES=+%P:;,@8K.Q
M9"!P;V1C>F%S(&EM<&]R=&]W86YI82`E<RXB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,3,V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B
M5WES=+%P:;,@8K.Q9"!P;V1C>F%S(&EM<&]R=&]W86YI82!Z9&%R>F5N:6$@
M)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!T87-K.B`E<RXB"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S(&EM
M<&]R=&]W86YI82!Z861A;FEA("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M.B`E<RXB"FUS9W-T<B`B(@HB5WES=+%P:;,@8K.Q9"!P;V1C>F%S(&EM<&]R
M=&]W86YI82!I;F9O<FUA8VII("AW;VQN>2]Z86KJ='DI(&\@=;]Y=&MO=VYI
M:W4Z("4B"B)S+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HX-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A
M9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B
M"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)7>7-TL7!ILR!BL[%D('!O9&-Z
M87,@<')Z96YO<WIE;FEA('=I861O;6^V8VD@>B!F;VQD97)U(%PB)7-<(B!D
M;R!<(B5S7"(N("(*(E-E<G=E<B!Z=W+S8VFS(&]D<&]W:65DO"(*"B,Z(&-O
M;7!O<V4N<&AP.C$Q-SD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I
M;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N(@IM<V=S='(@(E=Y<W2Q<&FS
M(&*SL60@<&]D8WIA<R!Z87!I<WEW86YI82!S>FMI8W4N(@H*(SH@8V]M<&]S
M92YP:'`Z.30P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS9W-T<B`B5WES=+%P
M:;,@8K.Q9"!P;V1C>F%S('=Y<WFS86YI82!W:6%D;VUOMF-I(#HE<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@
M)7,N(@IM<V=S='(@(E=Y<W2Q<&FS(&*S860@<&]D8WIA<R!A:W1U86QI>F%C
M:FD@>F1A<GIE;FEA.B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN
M<&AP.C4Y"FUS9VED(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R(")"<F%K('1E:W-T=2!W('!O;'4@=VEA9&]M;[9C
M:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-`IM<V=I9"`B5&AI
M<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS
M9W-T<B`B5VEA9&]M;[;F('<@9F]R;6%C:64@2%1-3"!Z87=I97)A('!L:6MI
M(&=R869I8WIN92XB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3`*
M;7-G:60@(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D
M960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L:6ME("(*(G1H:7,Z
M("(*;7-G<W1R("(B"B)7:6%D;VUOMN8@=R!F;W)M86-I92!(5$U,('IA=VEE
M<F$@<&QI:VD@9W)A9FEC>FYE+B!";&]K;W=A;F4@;V)R87IK:2!P;V1O8FYO
M("(*(F1O.B`B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C8*;7-G
M:60@(E1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O('1H92!M
M97-S86=E+B(*;7-G<W1R(")4=_-J('!U8FQI8WIN>2!K;'5C>B!01U`@>F]S
M=&&S('IAL[%C>F]N>2!D;R!W:6%D;VUOMF-I+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ,#0@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q
M.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30S(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ-3<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$W,R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$T"FUS9VED(")4:&ES
M(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")482!O<&5R86-J
M82!N:64@:F5S="!O8G.S=6=I=V%N82XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3<Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3D*;7-G
M:60@(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S
M='(@(E1A(&]P8VIA(&YI92!J97-T(&IE<WIC>F4@>F&SL6-Z;VYA+B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C8*;7-G:60@(E1H
M:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@8V]N=&EN=64_(@IM<V=S='(@(E1O(&UOOV4@>F%JL>8@=')O8VCJ(&-Z
M87-U+B!#:&-E<WH@:V]N='EN=6]W8>8_(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%P<&QE9&]U8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A
M:6YS(&$@36%C:6YT;W-H(&9I;&4N(@IM<V=S='(@(E1O(&IE<W0@=VEA9&]M
M;[;F('IA=VEE<F%JL6-A('!L:6L@36%C:6YT;W-H+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,SDY"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@
M8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL
M>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS9W-T<B`B5&$@=VEA9&]M;[;F
M('IA=VEE<F$@>F&SL6-Z;FEK+"!K=/-R>2!J97-T('!O9'!I<V%N>2!P<GIE
M>B!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,#,*
M;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H
M870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(E1A
M('=I861O;6^VYB!Z87=I97)A('IAL[%C>FYI:RP@:W3S<GD@:F5S="!Z86MO
M9&]W86YY('!R>F5Z(%,O34E-12XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!M
M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M
M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@(B(*
M(E1A('=I861M;[;F('IA=VEE<F$@=VEA9&]M;[;F(&EN9F]R;6%C>6INL2!O
M('-T871U<VEE(&1O<W1A<F-Z96YI82`H9&5L:79E<GD@(@HB<W1A='5S(&EN
M9F]R;6%T:6]N*2P@86QE(&9O<FUA="!W:6%D;VUOMF-I(&IE<W0@;FEE>FYA
M;GDN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S$U"FUS9VED("(B
M"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@(@IM<V=S='(@(B(*(E1A
M('=I861O;6^V8R!N:64@=WEG;+%D82!N82!P;W!R87=NL2!W:6%D;VUOMN8@
M:V]D;W=A;K$@<')Z97H@4$=0+B!"L[%D.B`B"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HR-#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S4P"FUS
M9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN
M('1H92!C;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@
M,C`Q-2DN(@IM<V=S='(@(E1A('=I861M;[;F(&YI92!W>6=LL61A(&YA('!O
M<')A=VYY(&9O<FUA="!01U`@*'IG;V1N:64@>B!21D,@,C`Q-2DN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-3D*;7-G:60@(E1H:7,@;65S
M<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4R]-
M24U%(&9O<FUA="XB"FUS9W-T<B`B5&$@=VEA9&]M;[;F(&YI92!W>6=LL61A
M(&YA('!O<')A=VYY(&9O<FUA="!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,C`U(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C0Q-@IM
M<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@
M=FEA(%!'4"XB"FUS9W-T<B`B5&$@=VEA9&]M;[;F('IO<W1ALV$@<&]D<&ES
M86YA(&-Y9G)O=V\@>F$@<&]M;V.Q(%!'4"XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C$S,@IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N
M(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12XB"FUS9W-T<B`B5&$@=VEA
M9&]M;[;F('IO<W1ALV$@<&]D<&ES86YA(&-Y9G)O=V\@>F$@<&]M;V.Q(%,O
M34E-12XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$R."!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C(R-PIM<V=I9"`B5&AI<R!M97-S86=E
M(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R(")482!W
M:6%D;VUOMN8@>F]S=&&S82!Z86MO9&]W86YA('IA('!O;6]CL2!3+TU)344N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`Q(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C(Y,0IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N
M(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`B5&$@=VEA9&]M;[9C('IO
M<W1ALV$@>F%K;V1O=V%N82!Z82!P;VUO8[$@4$=0+B(*"B,Z(&UE<W-A9V4N
M<&AP.C$Y-0IM<V=I9"`B5&AI<R!M97-S86=E('1O(@IM<V=S='(@(E=I861O
M;6^VYB!D;R(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H:7,@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")496X@
M<V5R=V5R(&YI92!O8G.S=6=U:F4@=61O<W3J<&YI86YI82!F;VQD97+S=RXB
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P.0IM<V=I
M9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A(&-O;7!O<V4@
M=VEN9&]W+B(*;7-G<W1R(")4;R!O:VYO(&UU<VD@>F]S=&'F('=Y=V^S86YE
M('!R>F5Z(&]K;F\@:V]M<&]Z>71O<F$@=VEA9&]M;[9C:2XB"@HC.B!T:')E
M860N<&AP.C0T('1E;7!L871E<R]T:')E860O=&]P+FEN8SHS(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.3,*;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@
M(E!O9&=LL60@=[%T:W4B"@HC.B!M86EL8F]X+G!H<#HU.#4@;65S<V%G92YP
M:'`Z,C0X('-E87)C:"YP:'`Z,3,Y"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C8T"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,3`*;7-G
M:60@(E1O(@IM<V=S='(@(D1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@Y,`IM<V=I9"`B5&\@061D<F5S<R(*;7-G<W1R(").82!A9')E<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM<V=I9"`B
M(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H92!#
M;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C;&EC:VEN
M9RXB"FUS9W-T<B`B(@HB06)Y('=Y8G)AYB!W:65L;VMR;W1N92!P;VQA('!R
M>GET<GIY;6%J($-O;G1R;VP@*%!#*2!L=6(@0V]M;6%N9"`H36%C("(*(G!O
M9&-Z87,@:VQI:V%N:6$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-38W"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*;7-G
M<W1R(")2;WIM:6%R('=S>GES=&MI8V@@>F&SL6-Z;FEK\W<Z(@H*(SH@9F]L
M9&5R<RYP:'`Z,S@S"FUS9VED(")4<F%S:"!F;VQD97(B"FUS9W-T<B`B1F]L
M9&5R(&MO<WIA(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN
M8SHR,PIM<V=I9"`B5')A<V@@9F]L9&5R.B(*;7-G<W1R(")&;VQD97(@:V]S
M>F$Z(@H*(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV-2!L:6(O475O=&$O;65R
M8W5R>3,R+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N9"YP:'`Z-S(*(SH@;&EB
M+U%U;W1A+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T82]C;W5R:65R+G!H<#HU
M,R!L:6(O475O=&$O;61A96UO;BYP:'`Z-#@*;7-G:60@(E5N86)L92!T;R!R
M971R:65V92!Q=6]T82(*;7-G<W1R(").:64@;6^_;&EW92!S<')A=V1Z96YI
M92!P;VIE;6YOMF-I(&MO;G1A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHQ,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S8*;7-G
M:60@(E5N86YS=V5R960B"FUS9W-T<B`B0F5Z(&]D<&]W:65D>FDB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5;F%N<W=E<F5D
M(&UE<W-A9V5S(@IM<V=S='(@(E=I861O;6^V8VD@8F5Z(&]D<&]W:65D>FDB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-"!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B56YD96QE
M=&4B"FUS9W-T<B`B3V1T=_-R>B(*"B,Z(&UA:6QB;W@N<&AP.C4V."!M86EL
M8F]X+G!H<#HU.#$@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$R"FUS9VED(")5
M;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(DYI975J87=N:65N:2!A
M9')E<V%C:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E
M.B`E<R(*;7-G<W1R(").:64@;V)SLW5G:7=A;GD@:V]M<&]N96YT('1Y<'4Z
M("5S(@H*(SH@;6%I;&)O>"YP:'`Z-30T"FUS9VED(")5;FMN;W=N($1A=&4B
M"FUS9W-T<B`B3FEE>FYA;F$@9&%T82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,S4*;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R(").
M:65Z;F%N92!S<&]T:V%N:64B"@HC.B!M86EL8F]X+G!H<#HU.3<*;7-G:60@
M(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@(DYI97IN86YY(&%D<F5S870B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$Q-R!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,34Q"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*;7-G
M<W1R(")5<W7Q(&AA<[-O(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(D)E>B!N87IW>2(*"B,Z(&UA:6QB;W@N
M<&AP.C8X-R!M97-S86=E+G!H<#HT.#,@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*
M;7-G<W1R(").:65W:61Z:6%N92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C$P"FUS9VED(")5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS
M*2(*;7-G<W1R(")5<W7Q('-U8G-K<GEP8VKJ('H@9F]L9&5R82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W-`IM<V=I9"`B57!D871E
M($%T=&%C:&UE;G0@26YF;W)M871I;VXB"FUS9W-T<B`B56%K='5A;&YI:B!I
M;F9O<FUA8VIE(&\@>F&SL6-Z;FEK=2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,C`*;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*
M;7-G<W1R(")586MT=6%L;FEJ('-T871U<R!O9'!O=VEA9&%JL6-E9V\B"@HC
M.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-38@=&5M<&QA=&5S
M+W!G<"]I;7!O<G1?:V5Y+FEN8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@
M(EIALV%D=6HB"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N
M:6YC.C0R"FUS9VED(")5<V4@1&5F875L="!686QU92(*;7-G<W1R(")5OWEJ
M(&1O;7FV;&YE:B!W87)T;[9C:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-3`*;7-G:60@(E5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/R(*
M;7-G<W1R(")5OWGF('-U8G-K<GEP8VII(&9O;&1E<G4@24U!4#\B"@HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,30P"FUS9VED(")5<V5R(@IM<V=S='(@
M(E6_>71K;W=N:6LB"@HC.B!A8VPN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E
M8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(B(*(E6_>71K;W=N:6L@7"(E<UPB('!R87=I9+-O=V\@>F1E9FEN:6]W8;,@
M<')A=V$@9&]S=.IP=2!D;R!F;VQD97)A(%PB)7-<(BXB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$X,0IM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,3<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(").87IW
M82!UOWET:V]W;FEK83HB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C8U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3$S"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,3$W('1E;7!L871E<R]P9W`O<&=P+FEN8SHY
M,PHC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30W('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-3$*;7-G:60@(E9I97<B"FUS9W-T<B`B5VED;VLB"@HC.B!L
M:6(O34E-12]6:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE
M9BYP:'`Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`B5VED;VL@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8U
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHY,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B5WFV=VEE=&P@)7,@:VQU
M8WH@<'5B;&EC>FYY(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R
M.`IM<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD
M;W<B"FUS9W-T<B`B5WFV=VEE=&P@>F%W87)T;[;F($A434P@=R!O<V]B;GEM
M(&]K;FEE(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,3<@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C$U,0IM<V=I9"`B5FEE=R!097)S;VYA;"!0
M<FEV871E($ME>2(*;7-G<W1R(")7>;9W:65T;"!O<V]B:7-T>2!K;'5C>B!P
M<GEW871N>2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3$S('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ-#<*;7-G:60@(E9I97<@4&5R<V]N86P@
M4'5B;&EC($ME>2(*;7-G<W1R(")7>;9W:65T;"!O<V]B:7-T>2!K;'5C>B!P
M=6)L:6-Z;GDB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,3<*;7-G:60@(E9I97<@5&AR96%D(@IM<V=S='(@(E=YMG=I971L
M('>Q=&5K(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V-0IM<V=I9"`B5FEE=R!4:'5M
M8FYA:6PB"FUS9W-T<B`B5WFV=VEE=&P@;6EN:6%T=7)KZB(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#`W"FUS9VED(")6:65W(&%T=&%C:&UE
M;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B5WFV=VEE=&P@>F&S
ML6-Z;FEK('<@;W-O8FYY;2!O:VYI92(*"B,Z(&QI8B]-24U%+U9I97=E<B]R
M96QA=&5D+G!H<#HW.0IM<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W(@IM<V=S='(@(E=YMG=I971L('IA=V%R=&^VYB!W(&]S;V)N
M>6T@;VMN:64B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30P"FUS
M9VED(")6:65W(&5V96YT(@IM<V=S='(@(E=YMG=I971L('ID87)Z96YI92(*
M"B,Z(&9O;&1E<G,N<&AP.C,W-2!M86EL8F]X+G!H<#HU,3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G<W1R(")7>;9W
M:65T;&5N:64@=VEA9&]M;[9C:2!W("5S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VEN:71I86QP86=E<V5L96-T+FEN8SHR-@IM<V=I9"`B5FEE=R!O<B!M86EL
M8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S='(@(E=I9&]K(&QU
M8B!S:W)Z>6YK82!D;R!P;VMA>F%N:6$@<&\@;&]G;W=A;FEU.B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S`*;7-G:60@(E9I97<@=&%S:R(*
M;7-G<W1R(")7>;9W:65T;"!Z861A;FEE(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$Q,PIM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM<V=S='(@
M(E!O:V%Z=6H@<&QI:VD@9W)A9FEC>FYE(@H*(SH@<V5A<F-H+G!H<#HS,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FER='5A;"!&;VQD97(@7"(E<UPB(&-R
M96%T960@<W5C8V5S9G5L;'DN(@IM<V=S='(@(E=I<G1U86QN>2!F;VQD97(@
M7"(E<UPB('IO<W1ALR!U='=O<GIO;GDN(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E92YP:'`Z,3(Y(&QI8B])34%0
M+U1R964N<&AP.C$T,@HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ-#0@;&EB+TE-
M05`O5')E92YP:'`Z,30X(&QI8B])34%0+U1R964N<&AP.C$T.0HC.B!L:6(O
M24U!4"]4<F5E+G!H<#HS-30@;&EB+TE-05`O5')E92YP:'`Z,S<X(&QI8B])
M34%0+U1R964N<&AP.C0Q.`IM<V=I9"`B5FER='5A;"!&;VQD97)S(@IM<V=S
M='(@(E=I<G1U86QN92!F;VQD97)Y(@H*(SH@<V5A<F-H+G!H<#HR.38*;7-G
M:60@(E9I<G1U86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN(@IM<V=S='(@
M(E=I<G1U86QN92!F;VQD97)Y('=Y;6%G86JQ(&5T>6MI971Y+B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3,S"FUS9VED(")6:7)T=6%L(&9O
M;&1E<B!L86)E;"(*;7-G<W1R(")%='EK:65T82!W:7)T=6%L;F5G;R!F;VQD
M97)U(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-C,*;7-G:60@
M(E=A<FYI;F<B"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L;V=I;BYP:'`Z
M,3,P"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T
M<B`B5VET86UY('<@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(T
M"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@
M=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H
M96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HB2VEE9'D@=7-U=V%S>B!W:6%D
M;VUOMF-I+"!P<GIE;FEEMB!J92!D;R!K;W-Z82!Z86UI87-T('IA>FYA8WIA
M;FEA(&EC:"!J86MO("(*(G5S=6YIZG1E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-S@*;7-G:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X
M+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N/R(*;7-G<W1R
M(")+:65D>2!O='=O<GIY<WH@;F]WL2!S:W)Z>6YKZBP@:W3S<K$@<W1R;V[J
M(&-H8V5S>B!U<G5C:&]M:>8_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4U-`IM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@
M<V%V92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(B(*(DMI961Y('IA<&ES
M=6IE<WH@=R!W:6%D;VUOMF-I+7=Y<[-A;F4L('!O=VEN:65N96T@>F%P:7-Y
M=V'F('IAL[%C>FYI:VD_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M,0IM<V=I9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D
M9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U
M;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T
M(%PB0%PB*3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C(R('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$Y"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B0FEALV$@;&ES=&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"FUS9VED(")7<F%P('1E
M>'0@870@=&AI<R!M86YY(&-H87)A8W1E<G,N(@IM<V=S='(@(EIA=VGQ('1E
M:W-T('!O('1E:B!L:6-Z8FEE('IN86OS=RXB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT
M.0IM<V=I9"`B665S(@IM<V=S='(@(E1A:R(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-3@*;7-G:60@(EEO=2!A<F4@
M86)O=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U
M;G0H<RDZ(@IM<V=S='(@(E!O8FEE<F%S>B!W:6%D;VUOMF-I('H@;F%S=.IP
M=6JQ8WEC:"!K;VYT.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?
M8V]N9FER;2YH=&UL.C$P"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@
M=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO
M=VEN9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@(E!R\V)U:F5S>B!U<W5NL>8@
M=W-Z>7-T:VEE('=I861O;6^V8VD@=R!N87-TZG!U:K%C>6-H(&9O;&1E<F%C
M:"XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M
M;#HY"FUS9VED(")9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F
M;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G<W1R(")0<O-B=6IE<WH@=7-U;K'F
M(&YA<W3J<'5JL6-E(&9O;&1E<GDN(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@
M;F5W(&9O;&1E<BXB"FUS9W-T<B`B2V]P:75J97-Z+W!R>F5N;W-I<WH@9&\@
M;F]W96=O(&9O;&1E<G4N(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:F%V87-C
M<FEP="YI;F,Z.30*;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L
M9&5R('1O("(*;7-G<W1R(")4=V]R>GES>B!N;W=Y('!O9&9O;&1E<B!W("(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.CDV"FUS9VED
M(")9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BXB"FUS9W-T
M<B`B5'=O<GIY<WH@9F]L9&5R('=YOW-Z>2XB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]J879A<V-R:7!T+FEN8SHQ,C<*;7-G:60@(EEO=2!A<F4@<F5N86UI
M;F<@=&AE(&9O;&1E<CH@(@IM<V=S='(@(EIM:65N:6%S>B!N87IWZB!F;VQD
M97)O=VDZ("(*"B,Z(&QI8B]&;VQD97(N<&AP.C4S-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(E1W;VIA('-U8G-K<GEP8VIA('IO<W1ALV$@=7-U
M;FGJ=&$@>B!<(B5S7"(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R964@
M=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@=V5R
M92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB"FUS9W-T<B`B3FEE('IG;V1Z
M:;-EMB!S:>H@>B!W87)U;FMA;6D@5&]3+"!W:>IC(&YI92!M;[]E<WH@<VGJ
M('IA;&]G;W=AYBXB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38U"FUS
M9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C
M97-S('1O('1H:7,@9F]L9&5R(@IM<V=S='(@(DYI92!M87-Z('!R87<@86)Y
M('IM:65N:>8@=7!R87=N:65N:6$@9&QA('1E9V\@9F]L9&5R82(*"B,Z(&QI
M8B]-86EL;&]G+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O
M<G=A<F1E9"!T:&ES(&UE<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@
M<F5C:7!I96YT<SH@)7,N(@IM<V=S='(@(E!R>F5K87IU:F5S>B!TL2!W:6%D
M;VUOMN8@)25S(&1O(&YA<W3J<'5JL6-Y8V@@861R97-A=/-W.B`E<RXB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@:&%V92`E<R!N97<@;65S<V%G97,N(@IM<V=S='(@(DUA
M<WH@)7,@;F]W>6-H('=I861O;6^V8VDN(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H879E(#$@;F5W(&UE<W-A9V4N
M(@IM<V=S='(@(DUA<WH@,2!N;W>Q('=I861O;6^VYBXB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHQ,38*;7-G:60@(B(*(EEO=2!H
M879E(&%T(&QE87-T(&]N92!A='1A8VAM96YT('-E;&5C=&5D('1H870@>6]U
M(&1I9&XG="!U<&QO860@>65T+B!!<F4@(@HB>6]U('-U<F4@>6]U('=A;G0@
M=&\@<V5N9"!T:&ES(&UE<W-A9V4@=VET:&]U="!T:&5S92!A='1A8VAM96YT
M<S\B"FUS9W-T<B`B(@HB36%S>B!W>6)R86YY('!R>GEN86IM;FEE:B!J961E
M;B!Z8;.Q8WIN:6LL(&%L92!J97-Z8WIE(+]A9&YE9V\@;FEE("(*(F1OL[%C
M>GFS9;8N(%=Y<[-AYB!TZB!W:6%D;VUOMN8@8F5Z('IAL[%C>FYI:_-W/R(*
M"B,Z(&QI8B])35`N<&AP.C$P,S`*;7-G:60@(EEO=2!H879E(&YE=R!M86EL
M(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R(")-87-Z(&YO=[$@
M<&]C>G3J('<@;F%S=.IP=6JQ8WEM(&9O;&1E<GIE.B(*"B,Z(&QI8B])35`N
M<&AP.C$P,S4*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL
M;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`B36%S>B!N;W>Q('!O8WITZB!W(&YA
M<W3J<'5JL6-Y8V@@9F]L9&5R86-H.B(*"B,Z(&-O;7!O<V4N<&AP.C$R-@IM
M<V=I9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB
M"FUS9W-T<B`B375S:7-Z('=P<F]W861Z:>8@<')Z>6YA:FUN:65J(&IE9&YE
M9V\@861R97-A=&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S`R
M"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@
M>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4B"FUS
M9W-T<B`B(@HB375S:7-Z('=P<F]W861Z:>8@:&%SLV\@9&QA('-W;VIE9V\@
M<')Y871N96=O(&ML=6-Z82!01U`@86)Y('=YMG=I971L:>8@=+$@(@HB=VEA
M9&]M;[;F(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G
M:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*
M;7-G<W1R("(B"B)-=7-I<WH@=W!R;W=A9'IIYB!H87.S;R!D;&$@<W=O:F5G
M;R!P<GEA=&YE9V\@:VQU8WIA(%,O34E-12!A8GD@=WFV=VEE=&QIYB`B"B)T
ML2!W:6%D;VUOMN8B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T
M+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T
M+B(*;7-G<W1R(")-=7-I<WH@;F%J<&EE<G<@=WEB<F'F(&1O8V5L;W>Q('-K
M<GIY;FOJ+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX-0IM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"XB"FUS9W-T
M<B`B375S:7-Z('=Y8G)AYB!K;VYT;R!D;R!U<W5N:>IC:6$N(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHX,0IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N(&%D9')E<W,@9FER<W0N(@IM<V=S='(@(DUU<VES>B!N
M86IP:65R=R!W>6)R8>8@861R97,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC
M.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S
M86=E(&9I<G-T+B(*;7-G<W1R(")-=7-I<WH@;F%J<&EE<G<@=WEB<F'F('!R
M>GEN86IM;FEE:B!J961NL2!W:6%D;VUOMN8N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@<F5C:7!I96YT+B(*;7-G<W1R(")-=7-I<WH@>F1E9FEN:6]W8>8@861R
M97-A=&$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z
M,CD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I;&4@
M=&\@871T86-H+B(*;7-G<W1R(")-=7-I<WH@>F1E9FEN:6]W8>8@<')Z>6YA
M:FUN:65J(&IE9&5N('!L:6L@9&\@9&^SL6-Z96YI82XB"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N86)L960@:6X@
M>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R(")-=7-I<WH@=[.Q
M8WIYYB`G)7,G('<@=R!O<&-J86-H(&MO;G-E<G=A8VII+B(*"B,Z(&QI8B]-
M86EL;&]G+G!H<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E9&ER
M96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T<B`B4')Z
M96MI97)O=V&S9;8@=VEA9&]M;[;F(&1O("5S(&YA("4E<RXB"@HC.B!L:6(O
M36%I;&QO9RYP:'`Z,30Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R97!L
M:65D('1O('1H:7,@;65S<V%G92!O;B`E<RXB"FUS9W-T<B`B3V1P;W=I961Z
M:6&S9;8@;F$@=.H@=VEA9&]M;[;F(&1N:6$@)7,N(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-#@W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E(&YO="!S
M=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@
M<V%I9"(*;7-G<W1R("(B"B)4=V]J82!S=6)S:W)Y<&-J82!W(%PB)7-<(B!N
M:64@>F]S=&&S82!A:W1Y=V]W86YA+B!397)W97(@>G=R\V-ILR!O9'!O=VEE
M9+PB"@HC.B!L:6(O1F]L9&5R+G!H<#HU,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(BX@2&5R
M92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(B"B)4=V]J82!S
M=6)S:W)Y<&-J82!W(%PB)7-<(B!N:64@>F]S=&&S82!A;G5L;W=A;F$N(%-E
M<G=E<B!Z=W+S8VFS(&]D<&]W:65DO"(*"B,Z(&QI8B]&;VQD97(N<&AP.C0Y
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L;'D@
M<W5B<V-R:6)E9"!T;R!<(B5S7"(B"FUS9W-T<B`B6F]S=&&S9;8@<W5B<VMR
M>6)O=V%N>2!D;R!<(B5S7"(B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('5N<W5B
M<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R(")4=V]J82!S=6)S:W)Y<&-J
M82!Z;W-T8;-A('5S=6YIZG1A('H@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$X-@IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E1W;VIA
M(&YA>G=A(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q.0IM<V=I9"`B
M66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*;7-G<W1R(")4=V]J92!P
M=6)L:6-Z;F4O<')Y=V%T;F4@:VQU8WIE(%!'4"(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,3$V('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-3`*
M;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B5'?S:B!K;'5C>B!P
M<GEW871N>2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3$R('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ-#8*;7-G:60@(EEO=7(@4'5B;&EC($ME
M>2(*;7-G<W1R(")4=_-J(&ML=6-Z('!U8FQI8WIN>2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-3<*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E
M<W,Z(#QI/BAO<'1I;VYA;"D\+VD^(@IM<V=S='(@(E1W;VIA($]D<&]W:65D
MO"UD;SH@861R97,Z(#QI/BAO<&-J;VYA;&YI92D\+VD^(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B66]U<B!3+TU)344@4'5B
M;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@(E1W;VIE('!U8FQI
M8WIN92]P<GEW871N92!K;'5C>F4@4R]-24U%(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*;7-G:60@(EEO=7(@86-C
M;W5N=',Z(@IM<V=S='(@(E1W;VIE(&MO;G1A.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-C4*;7-G:60@(B(*(EEO=7(@86QI87,@861D<F5S<V5S
M.B`\:3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L
M:6YE*3PO:3XB"FUS9W-T<B`B(@HB5'=O:F4@86QI87-Y(&%D<F5S=3H@/&D^
M*&]P8VIO;F%L;FEE+"!W<')O=V%DO"!K8;]D>2!A9')E<R!W(&YO=V5J(&QI
M;FDI/"]I/B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDR"FUS
M9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES
M<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(B(*(E1W;VIA('!R
M>F5G;+%D87)K82!N:64@;V)SLW5G=6IE('=YMG=I971L86YI82!P;&EK\W<@
M9W)A9FEC>FYY8V@@=&5G;R!T>7!U+B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+W!R:6YT+FEN8SHR-PIM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T
M:6]N("L@4"!T;R`B"B)P<FEN="XB"FUS9W-T<B`B(@HB5'=O:F$@<')Z96=L
ML61A<FMA(&YI92!O8G.S=6=U:F4@=&5J(&]P8VII(&1R=6MO=V%N:6$N($YA
M:F-IMFYI:B!#=')L+T]P8VIA("(*(BL@4"!A8GD@=WED<G5K;W=AYBXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,R"FUS9VED(")9;W5R(&1E9F%U
M;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B1&]M
M>;9L;GD@=6NS860@>FYA:_-W(&1L82!W>7-YLV%N>6-H('=I861O;6^V8VDZ
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC.C$*;7-G
M:60@(EEO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN
M9R!M97-S86=E<SHB"FUS9W-T<B`B1&]M>;9L;F$@;65T;V1A(&MO9&]W86YI
M82!W>7-YLV%N>6-H('=I861O;6^V8VDZ(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.#D*;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S
M<V9U;&QY(&1E;&EV97)E9"XB"FUS9W-T<B`B5'=O:F$@=VEA9&]M;[;F('IO
M<W1ALV$@9&]S=&%R8WIO;F$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y.`IM<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM<V=S='(@(E1W\VH@<&]D
M<&ES.B(*"B,Z(&UA:6QB;W@N<&AP.C4R."!C;VUP;W-E+G!H<#HQ,C$Y(&UE
M<W-A9V4N<&AP.C(W,B!L:6(O0V]M<&]S92YP:'`Z-S(Y"FUS9VED(");3F\@
M4W5B:F5C=%TB"FUS9W-T<B`B6V)R86L@=&5M871U72(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Q-@IM<V=I9"`B7T)C8R(*;7-G<W1R
M(")?0F-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED
M(")?0FQA8VML:7-T(@IM<V=S='(@(D-Z87)N82!L:7-T82`H7V(I(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,38U"FUS9VED(")?0V,B
M"FUS9W-T<B`B7T-C(@H*(SH@;&EB+TE-4"YP:'`Z.3,S"FUS9VED(")?0V]M
M<&]S92(*;7-G<W1R(")4=_-R>B`H7V,I(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ
M,`IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")5<W7Q("A?9"DB"@HC.B!L:6(O
M24U0+G!H<#HY,S4*;7-G:60@(E]&;VQD97)S(@IM<V=S='(@(E]&;VQD97)Y
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.#`*;7-G:60@
M(E])9&5N=&ET>2(*;7-G<W1R(")4;[]S86UOMN8@*%]I*2(*"B,Z(&QI8B])
M35`N<&AP.CDR-@IM<V=I9"`B7TEN8F]X(@IM<V=S='(@(D]D96)R86YE("A?
M:2DB"@HC.B!L:6(O24U0+G!H<#HY-S8*;7-G:60@(E],;V<@;W5T(@IM<V=S
M='(@(E=Y7VQO9W5J(@H*(SH@;65S<V%G92YP:'`Z,S8X"FUS9VED(")?365S
M<V%G92!3;W5R8V4B"FUS9W-T<B`BK'+S9+-O('=I861O7VUOMF-I(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,Q"FUS9VED
M(")?4')I;G0B"FUS9W-T<B`B1')U:W5J("A?<"DB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.#,@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S`P"FUS9VED(")?4')I;W)I='DB"FUS9W-T<B`B7U!R:6]R
M>71E="(*"B,Z(&UA:6QB;W@N<&AP.C0P,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")?4F5F<F5S:"`E<R(*;7-G<W1R(")/9+9W:66_("5S("A?<BDB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B
M7U)E<&QY(@IM<V=S='(@(D]D<&]W:65D>B`H7W(I(@H*(SH@;&EB+TE-4"YP
M:'`Z.3,W"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E]3>G5K86HB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHT,C(*;7-G:60@(E]396YD($UE<W-A9V4B"FUS
M9W-T<B`B5WFV;&EJ('=I861O;6^VYB(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S(*;7-G:60@(E]4:')E860B"FUS9W-T
M<B`B5[%?=&5K(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,3$U"FUS9VED(")?5&\B"FUS9W-T<B`B1&\@*%]T*2(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")?56YD96QE=&4B"FUS
M9W-T<B`B3V1T=_-R>B`H7W4I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$W"FUS9VED(")?5FEE=R!4:')E860B"FUS9W-T
M<B`B5WFV=VEE=&P@=[%T96L@*%]V*2(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHR,B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R(")":6&S82!L
M:7-T82`H7W<I(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,U,0IM<V=I9"`B871T
M86-H;65N="(*;7-G<W1R(")Z8;.Q8WIN:6LB"@HC.B!V:65W+G!H<#HY.0IM
M<V=I9"`B871T86-H;65N=',N>FEP(@IM<V=S='(@(GIAL[%C>FYI:VDN>FEP
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`S"FUS9VED
M(")B>71E<R(*;7-G<W1R(")B86IT\W<B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B9G)O;2(*;7-G<W1R(")O9"(*
M"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8Y"FUS9VED(")K97DB"FUS9W-T
M<B`B:VQU8WHB"@HC.B!F;VQD97)S+G!H<#HQ-3$*;7-G:60@(FUA:6QB;W@@
M9FEL92(*;7-G<W1R(")P;&EK('-K<GIY;FMI(@H*(SH@8V]M<&]S92YP:'`Z
M,3`P,2!L:6(O365S<V%G92YP:'`Z-#(Y"FUS9VED(")N86UE(@IM<V=S='(@
M(FYA>G=A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P
M"FUS9VED(")N;VYE(@IM<V=S='(@(K]A9&5N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$Q,0IM<V=I9"`B;W(B"FUS9W-T<B`B;'5B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED
M(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R(")BL[%D('!I<V]W;FDB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G:60@(G-P96QL
M:6YG(&5R<F]R<R(*;7-G<W1R(")BL^ID>2!P:7-O=VYI(@H*(SH@;&EB+T9I
M;'1E<BYP:'`Z-3$*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM<V=S='(@(G1W
M;VIA(&-Z87)N82!L:7-T82(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED
M(")Y;W5R('=H:71E;&ES="(*;7-G<W1R(")T=V]J82!B:6&S82!L:7-T82(*
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+W!O+VMM7TM(+G!O````````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#8T-3,S-P`Q,#0Q-S,V,C<V-``P,3<R,#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!33TU%($1%4T-2
M25!4259%(%1)5$Q%+@HC($-O<'ER:6=H="`H0RD@645!4B!(;W)D92!0<F]J
M96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M(&QI8V5N<V4@87,@=&AE(%!!0TM!1T4@<&%C:V%G92X*(R!+96\@4V]P:&]N
M(#QK96]S;W!H;VY`:VAM97)O<RYI;F9O/BP@,C`P-2X*(R!,96%N9R!#:'5M
M<V]B96X@/'-O8F5N0&MH;65R;W,N:6YF;SXL(#(P,#8N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($E-4%QN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#0M,3(M,#@@,3`Z,C@K,#$P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-2TP-BTQ-2`Q,3HU,RLP-S`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($QE86YG($-H=6US;V)E;B`\<V]B96Y`:VAM97)O<RYI;F9O
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@2VAM97(@/'-U<'!O<G1`:VAM97)O<RYI
M;F9O/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#UU=&8M.%QN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$U-3@*
M;7-G:60@(B`@("`@($-C.B`B"FUS9W-T<B`B("`@("`@X9Z%X9Z8X9^2X9Z;
MX9Z$PJ#AGY8@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$U-34*;7-G:60@(B`@
M("`@(%1O.B`B"FUS9W-T<B`B("`@("`@X9Z1X9^%PJ#AGY8@(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$U-#,*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B
M("`@(.&>@.&>MN&>F^&>E.&>FN&>M^&>A>&?DN&>AN&?@>&>D<*@X9^6("(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-30V"FUS9VED("(@("`@1G)O;3H@(@IM
M<V=S='(@(B`@("#AGI;AGKC"H.&?EB`B"@HC.B!F;VQD97)S+G!H<#HR-S0@
M;6%I;&)O>"YP:'`Z,S,Q"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S
M:V5Y("5S*2(*;7-G<W1R("(HX9Z"X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z%X9Z[
MX9Z%XH"+X9Z5X9^2X9Z;X9Z\X9Z<XH"+X9Z`X9ZVX9Z/X9^+("5S*2(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ-34R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S
M='(@(B#AGI3AGY+AGIKAGI+AGK;AGI/AGI3AGI'"H.&?EB`B"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HQ-CD*;7-G:60@(B!;(%-A=F4@=&AE(&ME
M>2!T;R!Y;W5R($%D9')E<W,@8F]O:R!=("(*;7-G<W1R("(@6R#AGIKAGH#A
MGY+AGI_AGK;AGI'AGKOAGH#B@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI'AGX7B
M@(OAGI_AGX#AGISAGI?AGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;A
MGI/B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`@72`B"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HQ-S$*;7-G:60@(B!;(%9I97<@=&AE(')A
M=R!K97D@72`B"FUS9W-T<B`B(%L@X9Z8X9Z^X9Z;XH"+X9Z"X9^2X9Z:X9ZV
MX9Z4X9^+X9Z%X9Z[X9Z%XH"+X9Z*X9Z^X9Z8X9^%(%T@(@H*(SH@;6%I;&)O
M>"YP:'`Z-38P"FUS9VED("(C(@IM<V=S='(@(B,B"@HC.B!T:')E860N<&AP
M.C$U,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!-97-S86=E<R(*;7-G<W1R
M("+AGI_AGK;AGIKB@(OAGH7AGX;AGI/AGKWAGI,@)60B"@HC.B!L:6(O4W!A
M;2YP:'`Z,C$X"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA
M=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGH7AGX;A
MGI/AGKWAGI,@)60@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;
MX9Z[X9Z4PJ#AGY0B"@HC.B!L:6(O4W!A;2YP:'`Z,C`P"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("+AGI_AGK;AGIH@)60@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3
MXH"+X9Z:X9ZVX9Z9XH"+X9Z`X9ZVX9Z:X9Z.X9^-XH"+X9Z1X9^%XH"+X9Z`
MX9ZVX9Z3X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z"X9^2X9Z:X9Z4X9^+XH"+
MX9Z"X9^2X9Z:X9Z$XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z:
MX9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z0X9ZVXH"+X9Z8X9ZWX9Z3
MXH"+X9Z8X9^"X9Z3XH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3
MXH"+X9Z`X9ZVX9Z:PJ#AGY0B"@HC.B!L:6(O4W!A;2YP:'`Z,3@P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E
M9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`BX9Z?X9ZVX9Z:("5D(.&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>FN&>MN&>F>*`B^&>@.&>MN&>FN&>
MCN&?C>*`B^&>D.&>MN*`B^&>F.&>M^&>D^*`B^&>F.&?@N&>D^*`B^&>G^&>
MMN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FL*@X9^4(@H*
M(SH@;&EB+U-P86TN<&AP.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M
M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+AGI_AGK;AGIH@)60@X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z:X9ZVX9Z9XH"+X9Z`X9ZV
MX9Z:X9Z.X9^-XH"+X9Z1X9^%XH"+X9Z`X9ZVX9Z3X9^+XH"+X9ZBX9^2X9Z3
MX9Z`XH"+X9Z"X9^2X9Z:X9Z4X9^+XH"+X9Z"X9^2X9Z:X9Z$XH"+X9Z4X9^2
MX9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3
MX9Z`XH"+X9Z0X9ZVXH"+XH"+X9Z'X9ZVXH"+XH"+X9Z?X9ZVX9Z:XH"+X9ZE
MX9Z/XH"+X9Z4X9ZVX9Z3X9Z`X9ZVX9Z:(@H*(SH@;&EB+U-P86TN<&AP.C$W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@
M<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`BX9Z?X9ZVX9Z:("5D(.&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>FN&>MN&>F>*`B^&>@.&>MN&>
MFN&>CN&?C>*`B^&>D.&>MN*`B^&>A^&>MN*`B^&>G^&>MN&>FN*`B^&>I>&>
MC^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FL*@X9^4(@H*(SH@;6%I;&)O>"YP
M:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D($UE
M<W-A9V5S(@IM<V=S='(@(B5D(.&>BN&>F^&?BR`E9"#AGI/AGX/B@(OAGI_A
MGK;AGIH@)60B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z-38W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($%T=&%C:&UE;G1S+"`E<R(*;7-G<W1R("+A
MGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGH7AGX;A
MGI/AGKWAGI,@)7,L("5S(@H*(SH@;6%I;&)O>"YP:'`Z-S@T(&QI8B]-24U%
M+T-O;G1E;G1S+G!H<#HU-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B
M"FUS9W-T<B`B)7,@2T(B"@HC.B!M86EL8F]X+G!H<#HW.#(@;&EB+TU)344O
M0V]N=&5N=',N<&AP.C4U-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-0B(*
M;7-G<W1R("(E<R#AGICAGX'AGH#AGK;AGI3AGX,B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@
M9F]L9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@X9Z8X9ZVX9Z3
MXH"+X9Z:X9Z]X9Z%XH"+X9Z@X9Z^X9Z9PJ#AGY0@X9Z0X9Z/("5S(.&>FN&>
ME.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>B.&?
MDN&>F.&?A.&?A^*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C4V,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!B>71E<R(*
M;7-G<W1R("(E<R#AGI3AGX,B"@HC.B!L:6(O365S<V%G92YP:'`Z-S(S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B5S(.&>D>&?AN&>D^&>A.*`B^&>
MA^&>MN*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?
MDN&>FN*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>
MO.&>G,*@X9^4(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E
M;G1M86EL7VUO;G1H;'DN<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N
M=&@N(@IM<V=S='(@(N&>D.&>CR`E<R#AGI/AGKGAGH3B@(OB@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGY+AGH_AGKSAGIKB@(OAGHCA
MGY+AGICAGX3AGX?B@(L@X9Z3X9^%XH"+X9Z6X9^!X9Z;XH"+X9Z%X9ZVX9Z4
MX9^+XH"+X9Z5X9^2X9Z/X9Z^X9Z8XH"+X9Z3X9^#XH"+X9Z!X9^"PJ#AGY0B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4W"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&AA<R!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@X9Z4X9ZV
MX9Z3XH"+X9Z1X9Z1X9Z]X9Z;PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C$W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC
M96QL960@7"(E<UPB+B(*;7-G<W1R("(E<R#AGI3AGK;AGI/B@(OAGI3AGX3A
MGX?AGI3AGH3AGXL@7"(E<UPBPJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!D96-L
M:6YE9"XB"FUS9W-T<B`B)7,@X9Z4X9ZVX9Z3XH"+X9Z4X9Z*X9ZWX9Z?X9^!
MX9Z2PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DR"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B
M=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S(.&>E.&>MN&>D^*`B^&>AN&?DN&>
MF^&>ON&>F>*`B^&>C^&>E.*`B^&>D>&?A>*`B^&>D^&>N>&>A.*`B^&>G^&?
MAN&>CN&>OB#AGI'AGX;AGI/AGX'AGIHOX9Z:X9Z<X9Z;X9^+(.&>F.&>O>&>
MF<*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A
M=&EO;B!T;R!<(B5S7"(N(@IM<V=S='(@(B5S(.&>E.&>MN&>D^*`B^&>AN&?
MDN&>F^&>ON&>F>&>C^&>E.*`B^&>D>&?A>*`B^&>G^&?@>&>A>&>@.&?DN&>
MBN&>N.*`B^&>HN&>B>&?DN&>A^&>ON&>B>*`B^&>D>&?A>*`B^&>@.&>MN&>
MD^&?BR!<(B5S7"+"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@X9Z4X9ZVX9Z3XH"+
MX9Z5X9^2X9Z)X9Z^XH"+X9ZRX9^2X9Z9XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z3
MX9Z\X9Z<XH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3(.&>D>&?AN&>D^&?@>&>
MFB_AGIKAGISAGIOAGXO"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('1E;G1A=&EV
M96QY(&%C8V5P=&5D+B(*;7-G<W1R("(E<R#AGI3AGK;AGI/B@(OAGI'AGI'A
MGKWAGIOB@(OAGH?AGK;B@(OAGI3AGH[AGY+AGH_AGX3AGX?B@(OAGJ+AGK;A
MGI_AGI/AGY+AGI/"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(.&>G^&?DN&>D^&>
MON*`B^&>G^&>N^&?AN*`B^&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`BR#AGI'A
MGX;AGI/AGX'AGIHOX9Z:X9Z<X9Z;X9^+XH"+(.&>FN&>E.&>G^&?B^*`B^&>
MHN&?DN&>D^&>@,*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4X,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R
M97-E;F-E(&%T(%PB)7-<(BXB"FUS9W-T<B`B)7,@X9Z?X9Z[X9^&XH"+X9ZR
MX9^2X9Z9XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZVX9Z3XH"+X9Z<X9Z/X9^2
MX9Z/X9Z8X9ZVX9Z3XH"+X9Z3X9^%(%PB)7-<(L*@X9^4(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B)7,@X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8XH"+
MX9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"X9Z'X9^0X9Z9XH"+X9Z1X9^%XH"+X9Z`
MX9ZVX9Z3X9^+(%PB)7-<(L*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@
M86UM96YD(%PB)7-<(BXB"FUS9W-T<B`B)7,@X9Z%X9Z$X9^+XH"+X9ZRX9^2
MX9Z9(&%M;65N9"!<(B5S7"+"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O
M(&UA:V4@>6]U(&%W87)E(&]F(%PB)7-<(BXB"FUS9W-T<B`B)7,@X9Z%X9Z$
MX9^+XH"+X9ZRX9^2X9Z9XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z*X9ZYX9Z$XH"+
MX9ZBX9^&X9Z6X9ZX(%PB)7-<(L*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@
M=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T(%PB)7-<
M(BXB"FUS9W-T<B`B)7,@X9Z%X9Z$X9^+XH"+X9Z1X9Z1X9Z]X9Z;XH"+X9Z6
MX9^0X9Z/X9^,X9Z8X9ZVX9Z3XH"+X9Z%X9Z[X9Z$X9Z`X9^2X9Z:X9^$X9Z9
MXH"+X9Z4X9^&X9Z5X9Z[X9Z/XH"+X9ZBX9^&X9Z6X9ZX(%PB)7-<(L*@X9^4
M(@H*(SH@;65S<V%G92YP:'`Z,C4T(&UE<W-A9V4N<&AP.C(U.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7/"H.&?EB`E<R(*"B,Z
M(&UE<W-A9V4N<&AP.C0Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@
M*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7/"H.&?EB`E<R`H)60F
M;F)S<#MO9B9N8G-P.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FAT;6PZ-S,*;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M
M;W9E('1O(&YE>'0@<V-R965N+BDB"FUS9W-T<B`B*.&>HN&>D^&>N^&>G.&>
MC^&?DN&>C^*`B^&>@.&>MN&>FN*`B^&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>
ME.&?DN&>C^&>O.&>FN*`B^&>D>&>MN&?AN&>A.*`B^&>D^&?@>&?AR#AGI/A
MGK?AGH0@X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9Z1X9^%XH"+
MX9Z`X9ZVX9Z3X9^+XH"+X9ZBX9^!X9Z`X9^2X9Z:X9Z$X9^+XH"+X9Z4X9Z3
MX9^2X9Z1X9ZVX9Z4X9^+PJ#AGY0I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:'1M;#HV,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@
M86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("(H
MX9Z4X9^$X9^'X9Z%X9^$X9Z;XH"+X9Z`X9ZVX9Z:XH"+X9Z5X9^2X9Z;X9ZV
MX9Z?X9^+XH"+X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?
MX9^+(.&>D^&>M^&>A"#AGH_AGY+AGIKAGJ'AGI3AGXOB@(OAGI'AGX7B@(OA
MGH#AGK;AGI/AGXOB@(OAGJ+AGX'AGH#AGY+AGIKAGH3AGXOB@(OB@(OAGH_A
MGX+AGH3"H.&?E"DB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G<W1R("(H2%1-3"DB"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!4
M97AT*2(*;7-G<W1R("(HX9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z2X9Z8X9^2
MX9Z8X9Z/X9ZV*2(*"B,Z('-P96QL:6YG+G!H<#HR-#D*;7-G:60@(B(*(BA2
M971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L
M;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("`B"B)#:&%N9V5S(&]N('1H92!C
M=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B
M(@HBX9Z/X9^2X9Z:X9ZAX9Z4X9^+XH"+X9Z1X9^%XH"+X9ZBX9^!X9Z`X9^2
MX9Z:X9Z$X9^+XH"+X9Z/X9^"X9Z$(.&>E.&>D^&?DN&>D>&>MN&>E.&?B^*`
MB^&>EN&>N.*`B^&>HN&>D^&>N^&>G.&>C^&?DN&>C^*`B^&>@.&>MN&>FN*`
MB^&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>D>&>
MMN&?AN&>A.*`B^&>HN&>G^&?B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>
MDN&?DN&>G.&>ON*`B^*`B^*`B^&>FN&>H.&>O.&>C^*`B^&>BN&>F^&?B^*`
MB^&>EN&?@>&>F^*`B^&>D^&?@>&?A\*@X9^4(.&>@.&>MN&>FN*`B^&>E>&?
MDN&>F^&>MN&>G^&?B^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>F^&>ON*`BR(*
M(N&>HN&?@>&>@.&?DN&>FN&>A.&?B^*`B^&>E.&>A>&?DN&>A>&>N^&>E.&?
MDN&>E.&>D^&?DN&>DR#AGI/AGKGAGH3B@(OAGICAGK?AGI/B@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGJ+AGI/AGKOAGISAGH_AGY+AGH_B
M@(OAGJ'AGK[AGIG"H.&?E"(*"B,Z('-P96QL:6YG+G!H<#HR-#8*;7-G:60@
M(B(*(BA396YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@
M;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE("(*(F-U<G)E;G0@<V-R
M965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B+AGI7AGY+A
MGHGAGK[B@(OAGI_AGK;AGIH@X9Z4X9Z3X9^2X9Z1X9ZVX9Z4X9^+XH"+X9Z6
MX9ZXX9ZBX9Z3X9Z[X9Z<X9Z/X9^2X9Z/XH"+X9Z`X9ZVX9Z:XH"+X9Z5X9^2
MX9Z;X9ZVX9Z?X9^+XH"+X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1X9ZVX9^&X9Z$
MX9ZBX9Z?X9^+XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z2X9^2X9Z<
MX9Z^XH"+X9Z:X9Z@X9Z\X9Z/XH"+X9Z*X9Z;X9^+XH"+X9Z6X9^!X9Z;XH"+
MX9Z3X9^!X9^'PJ#AGY0@X9Z`X9ZVX9Z:XH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+
MX9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z;X9Z^XH"+X9ZBX9^!X9Z`X9^2X9Z:X9Z$
MX9^+XH"+(@HBX9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2X9Z4X9Z3X9^2X9Z3(.&>
MD^&>N>&>A.*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>HN&>D^&>N^&>G.&>C^&?DN&>C^*`B^&>H>&>ON&>F<*@X9^4
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FAT;6PZ-#<*;7-G
M:60@(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B#A
MGI3AGI/AGY+AGI#AGX+AGICB@(OAGI'AGK;AGX;AGH3B@(OAGI/AGX'AGX<@
MX9Z*X9^$X9Z9XH"+X9Z%X9Z[X9Z%XH"+X9Z9X9Z;X9^+X9Z6X9^2X9Z:X9Z8
M("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:'1M;#HS,@IM
M<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E<W,H97,I("HB"FUS9W-T<B`B
M*B#AGI_AGKSAGICB@(OAGH?AGY+AGIKAGK[AGI_B@(OAGJ+AGK;AGI_AGIGA
MGHKAGY+AGHOAGK;AGI,@*B(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HU
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B,2!!='1A8VAM96YT+"`E<R(*;7-G
M<W1R("+AGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OA
MGH7AGX;AGI/AGKWAGI,@X9^A+"`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,S$*;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(N&?H>&?
MH.&?H"#AGH_AGKWB@(OAGJ+AGH#AGY+AGI_AGIHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#,T"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T
M<B`BX9^AX9^@X9^@X9^@(.&>C^&>O>*`B^&>HN&>@.&?DN&>G^&>FB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G:60@(C(U,"!C:&%R86-T
M97)S(@IM<V=S='(@(N&?HN&?I>&?H"#AGH_AGKWB@(OAGJ+AGH#AGY+AGI_A
MGIHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,S"FUS9VED("(U,#`@
M8VAA<F%C=&5R<R(*;7-G<W1R("+AGZ7AGZ#AGZ`@X9Z/X9Z]XH"+X9ZBX9Z`
MX9^2X9Z?X9Z:(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S
M"B,L('!H<"UF;W)M870*;7-G:60@(D$@;&%R9V4@:6UA9V4@;F%M960@)7,@
M:7,@871T86-H960@=&\@=&AI<R!M97-S86=E+B(*;7-G<W1R("+AGIKAGKSA
MGI3AGI?AGK;AGI;B@(OAGI+AGX;B@(OAGICAGKWAGIGB@(OAGHKAGX+AGIOB
M@(OAGICAGK;AGI/B@(OAGHCAGY+AGICAGX3AGX<@)7,@X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+XH"+X9Z'X9ZV
MX9Z8X9Z]X9Z9XH"+XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'PJ#AGY0B"@HC
M.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,`IM<V=I9"`B
M(@HB02!M97-S86=E('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@
M<F5T=7)N(&YO=&EF:6-A=&EO;B!F<F]M('1H92`B"B)R96-I<&EE;G0N(@IM
M<V=S='(@(N&>G^&>MN&>FN*`B^&>F.&>O>&>F>*`B^&>BN&?@N&>F^*`B^&>
MHN&?DN&>D^&>@.*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>OB#AGI3AGK;A
MGI/B@(OAGI7AGY+AGH_AGIOAGXOB@(OAGIOAGI'AGY+AGI+AGI7AGIOB@(OA
MGH?AGK;B@(OAGH#AGK;AGIKB@(OAGH?AGKSAGI/AGHKAGX;AGH[AGKGAGH3B
M@(OAGH_AGY+AGIKAGJ'AGI3AGXOB@(OAGICAGKWAGID@XH"+X9Z6X9ZXXH"+
MX9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;PJ#AGY0B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YH=&UL.C0Y"FUS9VED(")!3D0B"FUS9W-T<B`B
MX9Z3X9ZWX9Z$(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P-0IM<V=I
M9"`B06)O=F4@=&AE(&UE<W-A9V4@=&5X="(*;7-G<W1R("+AGH'AGK;AGH3B
M@(OAGIOAGK[B@(OAGJ+AGH_AGY+AGI#AGI3AGI'B@(OAGI_AGK;AGIHB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@R"FUS9VED(")!8V-E<'0@
M86YD(&%D9"!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("+AGI;AGY+AGIKAGICB
M@(OAGI'AGI'AGKWAGIL@X9Z@X9Z^X9Z9XH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8
MXH"+X9Z1X9^%XH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z1X9ZWX9Z3XH"+X9Z:X9Z4
MX9Z?X9^+XH"+X9Z!X9^2X9Z)X9Z[X9^&(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4X-0IM<V=I9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B
MX9Z6X9^2X9Z:X9Z8XH"+XH"+X9Z1X9Z1X9Z]X9Z;XH"+XH"+X9Z?X9^&X9Z.
MX9Z^(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<T-@IM<V=I9"`B
M06-C97!T960B"FUS9W-T<B`BX9Z4X9ZVX9Z3XH"+X9Z1X9Z1X9Z]X9Z;(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U.`IM<V=I9"`B06-C97!T
M960Z("(*;7-G<W1R("+AGI3AGK;AGI/B@(OAGI'AGI'AGKWAGIO"H.&?EB`B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-PIM<V=I9"`B
M06-C;W5N="=S(&YA;64Z(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?A^*`B^&>
M@N&>CN&>D^&>N,*@X9^6(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4R,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S(U"FUS9VED(")!8W1I
M;VYS(@IM<V=S='(@(N&>HN&?AN&>EN&>OB(*"B,Z(&QI8B]-24U%+TAE861E
M<G,N<&AP.C(P,2!L:6(O34E-12](96%D97)S+G!H<#HR,#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D("5S('1O(&UY($%D9')E<W,@0F]O:R(*;7-G<W1R
M("+AGI3AGI/AGY+AGI#AGX+AGI@@)7,@X9Z1X9^%XH"+X9Z?X9^`X9Z<X9Z7
MX9^%XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z:X9Z4X9Z?
MX9^+XH"+X9Z!X9^2X9Z)X9Z[X9^&(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,S`S"FUS9VED(")!9&0@<V]U<F-E(@IM<V=S='(@
M(N&>E.&>D^&?DN&>D.&?@N&>F.*`B^&>E.&?DN&>FN&>E^&>EB(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S,*;7-G:60@(D%D9"!T:&ES('1O
M(&UY(&-A;&5N9&%R(@IM<V=S='(@(N&>E.&>D^&?DN&>D.&?@N&>F.*`B^&>
MD^&?@>&?A^*`B^&>D>&?A>*`B^&>E.&?DN&>FN&>C^&>M^&>D>&>M^&>D^*`
MB^&>FN&>E.&>G^&?B^*`B^&>@>&?DN&>B>&>N^&?AB(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.#,*;7-G:60@(D%D9"!T;R!M>2!C86QE;F1A
M<B(*;7-G<W1R("+AGI3AGI/AGY+AGI#AGX+AGICB@(OAGI'AGX7B@(OAGI3A
MGY+AGIKAGH_AGK?AGI'AGK?AGI/B@(OAGIKAGI3AGI_AGXOB@(OAGH'AGY+A
MGHGAGKOAGX8B"@HC.B!C;VUP;W-E+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D960@7"(E<UPB(&%S(&%N(&%T=&%C:&UE;G0N(@IM<V=S='(@
M(N&>E.&>MN&>D^*`B^&>E.&>D^&?DN&>D.&?@N&>F"!<(B5S7"(@X9Z'X9ZV
MXH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z8
MX9Z]X9Z9PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DY"FUS
M9VED("(B"B)!9&1I=&EO;F%L(&AE861E<G,@=&\@9&ES<&QA>2!W:&5N('9I
M97=I;F<Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@:&5A9&5R("(*(F]N
M(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HBX9Z`X9^2X9Z4X9ZVX9Z;
MXH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8XH"+X9Z1X9^`X9Z/(.&>BN&?@N&>F^*`
MB^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>D^&?
MA>*`B^&>EN&?@>&>F^*`B^&>F.&>ON&>F\*@X9^6(#QE;3XHX9Z?X9^2X9Z:
MX9^!X9Z%XH"+X9Z%X9ZWX9Z/X9^2X9Z/(.&>E.&>B>&?DN&>A>&>O.&>F^*`
MB^&>@.&?DN&>E.&>MN&>F^*`B^&>D^&>N.&>F.&>O>&>F>&?E^*`B^&>F^&>
MON*`B^&>A^&>O>&>FN*`B^&>D.&?DN&>F.&>N"D\+V5M/B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`BX9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3XH"+X9Z4X9Z3X9^2
MX9Z0X9^"X9Z8XH"+X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z8X9Z^X9Z;XH"+("5SPJ#AGY0B"@HC.B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@IM<V=I9"`B061D:71I;VYA;"!I
M;F9O<FUA=&EO;B!D971A:6QS(@IM<V=S='(@(N&>G^&?@>&>A>&>@.&?DN&>
MC^&>N.*`B^&>F^&>F.&?DN&>HN&>M^&>C^&>FN&>E.&>G^&?B^*`B^*`B^&>
MEN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>E.&>D^&?DN&>D.&?@N&>F"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDS"FUS9VED(")!9&1I=&EO
M;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G<W1R("+AGI_AGX'AGH7AGH#AGY+A
MGH_AGKCB@(OAGIOAGICAGY+AGJ+AGK?AGH_B@(OAGIKAGI3AGI_AGXOB@(OA
MGI_AGK;AGIKB@(OAGI3AGI/AGY+AGI#AGX+AGI@B"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I
M=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G
M<W1R("+AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGIOAGICAGY+AGJ+AGK?A
MGH_B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OAGI3AGI/AGY+AGI#A
MGX+AGICB@(L@X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZV
MX9Z3XH"+X9Z8X9Z^X9Z;XH"+("5SPJ#AGY0B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R
M<F]R(&1E=&%I;',B"FUS9W-T<B`BX9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZXXH"+
MX9Z;X9Z8X9^2X9ZBX9ZWX9Z/XH"+X9ZBX9^&X9Z6X9ZXXH"+X9Z`X9^&X9Z@
MX9Z[X9Z?XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z4X9Z3X9^2
MX9Z0X9^"X9Z8(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R
M(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`BX9Z?X9^!X9Z%
MX9Z`X9^2X9Z/X9ZXXH"+X9Z;X9Z8X9^2X9ZBX9ZWX9Z/XH"+X9ZBX9^&X9Z6
MX9ZXXH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZV
MX9Z:XH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8(.&>HN&>MN&>A>*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>F.&>ON&>F^*`B^*`BR`E<R#B@(OA
MGY0B"@HC.B!C;VUP;W-E+G!H<#HX-C<@8V]M<&]S92YP:'`Z,3(S,"!C;VYT
M86-T<RYP:'`Z-S<*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FAT
M;6PZ.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(N&>G^&?@.&>G.&>
ME^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS
M9W-T<B`BX9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+
MX9ZVX9Z3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N
M86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^
M(@IM<V=S='(@(N&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>BN&?
M@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>F^&>MN&>@.&?B^*`B^&>G^&>
MMN&>FN*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?B\*@X9^6(#QE;3XHX9Z?X9^2
MX9Z:X9^!X9Z%XH"+X9Z%X9ZWX9Z/X9^2X9Z/+"#AGI3AGHGAGY+AGH7AGKSA
MGIOB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGI/AGKCAGICA
MGKWAGIGAGY?B@(OAGIOAGK[B@(OAGH?AGKWAGIKB@(OAGI#AGY+AGICAGK@I
M/"]E;3XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@R"FUS9VED("(B
M"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET
M>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"`B"B)A9&1R97-S(&]N(&$@
M;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HBX9ZBX9ZVX9Z?X9Z9X9Z*X9^2
MX9Z+X9ZVX9Z3XH"+X9Z*X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z%
MX9Z$XH"+X9Z'X9ZVX9Z`X9^+X9Z;X9ZVX9Z`X9^+XH"+X9Z3X9ZYX9Z$XH"+
MX9ZBX9Z/X9^2X9Z/X9Z?X9Z)X9^2X9Z)X9ZVX9Z.XH"+X9Z3X9^!X9^'PJ#A
MGY8@/&5M/BCAGI_AGY+AGIKAGX'AGH7B@(OAGH7AGK?AGH_AGY+AGH\L(.&>
ME.&>B>&?DN&>A>&>O.&>F^*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>
MD^*`B^&>D^&>N.&>F.&>O>&>F>&?E^*`B^&>F^&>ON*`B^&>A^&>O>&>FN*`
MB^&>D.&?DN&>F.&>N"D\+R(*(F5M/B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYH=&UL.C<*;7-G:60@(D%L;"(*;7-G<W1R("+AGI'AGK;AGX;A
MGH3AGJ+AGI_AGXLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C$S"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN
M9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@
M(@HB9FEL93HB"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z1X9ZVX9^&X9Z$XH"+
MX9ZBX9Z?X9^+XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z0X9Z/XH"+X9Z!X9ZV
MX9Z$X9Z`X9^2X9Z:X9^$X9Z8(.&>D^&>N>&>A.*`B^&>C^&?DN&>FN&>O.&>
MG.*`B^&>E.&>MN&>D^*`B^&>D>&>MN&>B>*`B^&>F>&>@.&>BN&?A.&>F>*`
MB^&>BN&>MN&>@.&?B^*`B^&>D>&?A>&>@.&?DN&>D^&>N^&>A.*`B^&>K^&>
M@.&>G^&>MN&>FB!-0D]8(.&>F.&>O>&>F<*@X9^4(@H*(SH@;&EB+TUA:6YT
M96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!Y;W5R(%PB)7-<(B!F;VQD97(@
M;VQD97(@=&AA;B`E<R!D87ES('=I;&P@8F4@<&5R;6%N96YT;'D@(@HB9&5L
M971E9"XB"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?
MX9^+XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z0X9Z/(%PB)7-<(B#AGIKAGI3A
MGI_AGXOB@(OAGJ+AGY+AGI/AGH`@X9Z*X9^"X9Z;XH"+X9Z%X9ZVX9Z?X9^+
MXH"+X9Z'X9ZVX9Z$("5S(.&>D.&?DN&>A.&?@R#AGI/AGKGAGH3B@(OAGH_A
MGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI3B@(OAGH7AGX3A
MGIOB@(OAGH?AGK;B@(OAGJ+AGH7AGK?AGI/AGY+AGH_AGY+AGIKAGX/AGIGA
MGXW"H.&?E"(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]A='1A
M8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E('1H86X@)7,@;6]N=&AS
M(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@(N&>K^&>@.&>G^&>MN&>
MFN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>A>&>MN&>G^&?B^*`B^&>D>&>
MMN&?AN&>A.*`B^&>HN&>G^&?B^*`B^&>BN&?@N&>F^*`B^&>A>&>MN&>G^&?
MB^*`B^&>A^&>MN&>A"`E<R#AGH'AGX(@X9Z3X9ZYX9Z$XH"+X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4XH"+PJ#AGY0B"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T
M960N(@IM<V=S='(@(N&>D.&>C^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`
MB^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>ON&>D>&>MN&?
MAN&>A.*`B^&>HN&>G^&?BR#AGHKAGX+AGIOB@(OAGH7AGK;AGI_AGXOB@(OA
MGH?AGK;AGH0@)7,@X9Z!X9^"(.&>D^&>N>&>A.*`B^&>C^&?DN&>FN&>O.&>
MG.*`B^&>E.&>MN&>D^*`B^&>F^&>N^&>E,*@X9^4(@H*(SH@86-L+G!H<#HX
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@<FEG:'1S(&]N(&9O;&1E<B!<
M(B5S7"(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@7"(E<UPB+B(*
M;7-G<W1R("+AGI_AGK?AGI'AGY+AGI+AGK?B@(OAGI'AGK;AGX;AGH3AGJ+A
MGI_AGXOB@(OAGI/AGX7B@(OAGIOAGK[B@(OAGI#AGH\@7"(E<UPB(.&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>F>&>@.*`B^&>A>&?@>&>B>*`
MB^&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F>*`B^&>G^&>F.&?DN&>
MFN&>MN&>E.&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OB!<(B5S
M7"+"H.&?E"(*"B,Z(&QI8B]A<&DN<&AP.C@Q"FUS9VED(")!;&QO=R!&;VQD
M97(@0W)E871I;VX_(@IM<V=S='(@(N&>HN&>D^&>N^&>B>&?DN&>B>&>MN&>
MC^*`B^&>LN&?DN&>F>*`B^&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>D.&>C\*@
M/R(*"B,Z(&9I;'1E<G!R969S+G!H<#HY.`IM<V=I9"`B06QL;W<@9FEL=&5R
M(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@
M(N&>HN&>D^&>N^&>B>&?DN&>B>&>MN&>C^*`B^&>LN&?DN&>F>*`B^&>HN&>
MD^&>N^&>G.&>C^&?DN&>C^*`B^&>@.&?DN&>E.&>O>&>D^*`B^&>C^&>F.&?
MDN&>FN&>A.*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>E.&?DN&>FN&>HN&>E.&?
MB^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>CN&>MN&>F.&>O>&>F>*`
MB^&>K.*`B^&>D>&?@<*@/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA
M=&EV92YP:'`Z,3$Q"FUS9VED(")!;'1E<FYA=&EV92!P87)T<R!F;W(@=&AI
M<R!S96-T:6]N.B(*;7-G<W1R("+AGI7AGY+AGI/AGX+AGH#B@(OAGI/AGX/B
M@(OAGH?AGICAGY+AGIKAGK[AGI\@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+
MX9Z7X9ZVX9Z"XH"+X9Z3X9^!X9^'PJ#AGY8B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3@T"FUS9VED(")!;'=A>7,B"FUS9W-T<B`BX9Z'X9ZVX9Z3
MX9ZWX9Z%X9^2X9Z%(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V.0IM
M<V=I9"`B06QW87ES('-A=F4@871T86-H;65N=',B"FUS9W-T<B`BX9Z:X9Z`
MX9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7
MX9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z'X9ZVX9Z3X9ZWX9Z%X9^2X9Z%(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C4V,PIM<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E
M9"!W:&EL92!A='1E;7!T:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4
M:&4@24U!4"!S97)V97(@(@HB<V%I9#H@(@IM<V=S='(@(N&>@.&?AN&>H.&>
MN^&>G^*`B^&>F.&>O>&>F>*`B^&>E.&>MN&>D^*`B^&>@.&>ON&>C^*`B^&>
MH>&>ON&>A"#AGH'AGH[AGXCAGI;AGX'AGIOB@(OAGI3AGXGAGKOAGI/AGI3A
MGXGAGH3B@(OAGH7AGY+AGI3AGKWAGH_B@(OAGJ_AGH#AGI_AGK;AGIKB@(OA
MGI?AGY+AGH?AGK;AGI3AGXOB@(OAGH7AGX'AGHG"H.&?E"#AGICAGXGAGK;A
MGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGKX@24U!4"#AGI3AGK;AGI/B
M@(OAGI/AGK?AGIGAGK;AGIG"H.&?EB(*"B,Z(&QI8B]-97-S86=E+G!H<#HT
M-#8*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A
M=&EN9R!T:&4@;F5W(&YO=&4N(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`
MB^&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?B^*`B^&>F.&>O>&>F>*`
MB^&>E.&>MN&>D^*`B^&>@.&>ON&>C^&>H>&>ON&>A"#AGH'AGH[AGXCB@(OA
MGI;AGX'AGIOB@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGH7AGX;AGH[AGK;A
MGX;B@(OAGI#AGY+AGICAGKC"H.&?E"(*"B,Z(&QI8B]-97-S86=E+G!H<#HT
M-#4*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A
M=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`
MB^&>BN&?@N&>F^*`B^&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?B^*`
MB^&>F.&>O>&>F>*`B^&>E.&>MN&>D^*`B^&>@.&>ON&>C^*`B^&>H>&>ON&>
MA"#AGH'AGH[AGXCB@(OAGI;AGX'AGIOB@(OAGI3AGH3AGY+AGH#AGK[AGH_B
M@(OAGI?AGK;AGIKAGH#AGK?AGH7AGY+AGH7B@(OAGI#AGY+AGICAGKC"H.&?
ME"(*"B,Z(&UE<W-A9V4N<&AP.C0W,B!M86EL8F]X+G!H<#HX,3@@;6%I;&)O
M>"YP:'`Z.3<Q"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YH=&UL.CD@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,34*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,S`@=&5M<&QA=&5S+VUA
M:6QB;W@O;&5G96YD+FAT;6PZ-`IM<V=I9"`B06YS=V5R960B"FUS9W-T<B`B
MX9Z4X9ZVX9Z3XH"+X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4(@H*(SH@<V5A
M<F-H+G!H<#HS,CD*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@
M(N&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>AN&?DN&>
MF^&>ON&>F>*`B^&>C^&>E"(*"B,Z(&UA:6QB;W@N<&AP.C,U,0IM<V=I9"`B
M07!P;'D@1FEL=&5R<R(*;7-G<W1R("+AGJ+AGI/AGKOAGISAGH_AGY+AGH_B
M@(OAGH_AGICAGY+AGIKAGH0B"@HC.B!M86EL8F]X+G!H<#HS-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B07!P;'D@1FEL=&5R<R!T;R`E<R(*;7-G<W1R("+A
MGJ+AGI/AGKOAGISAGH_AGY+AGH_B@(OAGH_AGICAGY+AGIKAGH3B@(OAGI'A
MGX4@)7,B"@HC.B!F:6QT97)P<F5F<RYP:'`Z.38*;7-G:60@(D%P<&QY(&9I
M;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(N&>HN&>D^&>
MN^&>G.&>C^&?DN&>C^*`B^&>@.&?DN&>E.&>O>&>D^*`B^&>C^&>F.&?DN&>
MFN&>A.*`BR#AGJ+AGK;AGI_AGY+AGIKAGY#AGIGB@(OAGIOAGK[B@(OAGH#A
MGK;AGIKB@(OAGH7AGKSAGIO"H#\B"@HC.B!F:6QT97)P<F5F<RYP:'`Z.3<*
M;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!);F)O>"!I<R!D
M:7-P;&%Y960_(@IM<V=S='(@(N&>HN&>D^&>N^&>G.&>C^&?DN&>C^*`B^&>
M@.&?DN&>E.&>O>&>D^*`B^&>C^&>F.&?DN&>FN&>A"#AGI;AGX'AGIOB@(OA
MGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI3AGY+AGIKAGJ+AGI3AGXOB@(OAGI'A
MGI'AGKWAGIO"H#\B"@HC.B!M86EL8F]X+G!H<#HS-C$*;7-G:60@(D%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!6:7)T=6%L($9O;&1E
M<B!$969I;FET:6]N/R(*;7-G<W1R("+AGH_AGK[B@(OAGJ+AGY+AGI/AGH#B
M@(OAGI;AGK?AGH_B@(OAGH?AGK;B@(OAGH7AGH3AGXOB@(OAGIOAGKOAGI3B
M@(OAGI/AGK?AGIGAGICAGI/AGY#AGIGB@(OAGI#AGH_B@(OAGI/AGK?AGICA
MGY+AGICAGK?AGH_B@(OAGI/AGX'AGX?B@(OAGJS"H#\B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!T:&ES
M('!U8FQI8R!K97D_(@IM<V=S='(@(N&>C^&>ON*`B^&>HN&?DN&>D^&>@.*`
MB^&>EN&>M^&>C^*`B^&>A^&>MN*`B^&>A>&>A.&?B^*`B^&>F^&>N^&>E.*`
MB^&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B.*`B^&>
MD^&?@>&?A^*`B^&>K,*@/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@*%1H
M:7,@:7,@3D]4(')E8V]M;65N9&5D(2DB"FUS9W-T<B`BX9Z/X9Z^XH"+X9ZB
MX9^2X9Z3X9Z`XH"+X9Z6X9ZWX9Z/XH"+X9Z'X9ZVXH"+X9Z%X9Z$X9^+XH"+
MX9Z;X9Z[X9Z4XH"+X9Z"X9Z\XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z:X9Z4
MX9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9ZLPJ`_("CAGICAGK?AGI/B@(OA
MGICAGX+AGI/B@(OAGH?AGK;B@(OAGJ+AGI/AGKOAGI_AGK;AGI_AGI/AGXTA
M*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+VIA=F%S8W)I<'0N:6YC.C8*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(*;7-G<W1R
M("+AGH_AGK[B@(OAGJ+AGY+AGI/AGH#B@(OAGI;AGK?AGH_B@(OAGH?AGK;B
M@(OAGH7AGH3AGXOB@(OAGI+AGY+AGISAGK[B@(OAGHKAGKSAGH7B@(OAGI/A
MGX'AGX?B@(OAGJS"H#\B"@HC.B!M97-S86=E+G!H<#HU,S<@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z.#`*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G
M97,_(@IM<V=S='(@(N&>C^&>ON*`B^&>HN&?DN&>D^&>@.*`B^&>EN&>M^&>
MC^*`B^&>A^&>MN*`B^&>A>&>A.&?B^*`B^&>F^&>N^&>E.*`B^&>G^&>MN&>
MFN*`B^&>D>&>MN&?AN&>A.*`B^&>D^&?@>&?A^*`B^&>A^&>MN*`B^&>HN&>
MA>&>M^&>D^&?DN&>C^&?DN&>FN&?@^&>F>&?C>*`B^&>K.*`B\*@/^*`BR(*
M"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR-#(*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A
M8VAM96YT/R(*;7-G<W1R("+AGH_AGK[B@(OAGJ+AGY+AGI/AGH#B@(OAGI;A
MGK?AGH_B@(OAGH?AGK;B@(OAGH7AGH3AGXOB@(OAGIOAGKOAGI3B@(OAGJ_A
MGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGI/AGX'AGX?B
M@(OAGH?AGK;B@(OAGJ+AGH7AGK?AGI/AGY+AGH_AGY+AGIKAGX/AGIGAGXWB
M@(OAGJS"H#\B"@HC.B!M86EL8F]X+G!H<#HT-C0*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`B
MX9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z6X9ZWX9Z/XH"+X9Z'X9ZVXH"+
MX9Z%X9Z$X9^+XH"+X9Z?X9Z8X9^2X9ZBX9ZVX9Z/XH"+X9Z0X9Z/XH"+X9Z3
MX9^!X9^'XH"+X9ZLPJ`_(@H*(SH@;&EB+TE-4"YP:'`Z-S@W"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E
M<C\B"FUS9W-T<B`BX9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z6X9ZWX9Z/
MXH"+X9Z'X9ZVXH"+X9Z%X9Z$X9^+XH"+X9Z?X9Z8X9^2X9ZBX9ZVX9Z/XH"+
MX9Z0X9Z/XH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`
MX9ZVX9Z:XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9ZLPJ`_
M(@H*(SH@;&EB+TE-4"YP:'`Z-S<W"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(N&>
MC^&>ON*`B^&>HN&?DN&>D^&>@.*`B^&>EN&>M^&>C^*`B^&>A^&>MN*`B^&>
MA>&>A.&?B^*`B^&>G^&>F.&?DN&>HN&>MN&>C^*`B^&>D.&>C^*`B^&>G^&?
MAN&>FN&>MN&>F.*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>
MK,*@/R(*"B,Z(&UA:6QB;W@N<&AP.C0V,PIM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E
M<S\B"FUS9W-T<B`BX9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z6X9ZWX9Z/
MXH"+X9Z'X9ZVXH"+X9Z%X9Z$X9^+XH"+X9Z;X9Z[X9Z4XH"+X9Z?X9ZVX9Z:
MXH"+X9Z1X9ZVX9^&X9Z$XH"+X9Z3X9^!X9^'XH"+X9Z'X9ZVXH"+X9ZBX9Z%
MX9ZWX9Z3X9^2X9Z/X9^2X9Z:X9^#X9Z9X9^-XH"+X9ZLPJ`_(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z,S8@=&5M<&QA=&5S+VUA
M:6QB;W@O:F%V87-C<FEP="YI;F,Z.3$*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/R(*
M;7-G<W1R("+AGH_AGK[B@(OAGJ+AGY+AGI/AGH#B@(OAGI;AGK?AGH_B@(OA
MGH?AGK;B@(OAGH7AGH3AGXOB@(OAGIKAGK;AGIGB@(OAGH#AGK;AGIKAGH[A
MGXWB@(OAGJ+AGX;AGI;AGKCB@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OA
MGI#AGK;B@(OAGH?AGK;B@(OAGI_AGK;AGIKB@(OAGIOAGY+AGJ+B@(OAGJS"
MH#\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHS,2!T
M96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHX-@IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@
M<W!A;3\B"FUS9W-T<B`BX9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z6X9ZW
MX9Z/XH"+X9Z'X9ZVXH"+X9Z%X9Z$X9^+XH"+X9Z:X9ZVX9Z9XH"+X9Z`X9ZV
MX9Z:X9Z.X9^-XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+X9Z0X9ZV(.&>
MA^&>MN*`B^&>G^&>MN&>FN&>I>&>C^*`B^&>E.&>MN&>D^&>@.&>MN&>FN*`
MB^&>K,*@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C<*;7-G:60@
M(D%R<FEV86P@5&EM92(*;7-G<W1R("+AGI;AGX'AGIOB@(OAGISAGX'AGIOA
MGK;B@(OAGICAGH#B@(OAGHKAGIOAGXLB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.30R"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`BX9ZAX9Z^X9Z$
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,PIM<V=I9"`B07-K(@IM
M<V=S='(@(N&>G^&>O>&>FB(*"B,Z(&-O;7!O<V4N<&AP.C$S,#`*;7-G:60@
M(D%T=&%C:"!&:6QE<R(*;7-G<W1R("+AGI?AGY+AGH?AGK;AGI3AGXOB@(OB
M@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGH?AGK;AGICAGKWAGIDB"@HC.B!C;VUP
M;W-E+G!H<#HQ,CDR"FUS9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0
M('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R("+AGI?AGY+A
MGH?AGK;AGI3AGXOB@(OAGH?AGK;AGICAGKWAGIGB@(OAGI/AGKSAGISB@(OA
MGH7AGY+AGI3AGK;AGI3AGXOB@(OAGH7AGICAGY+AGIOAGH3B@(OAGICAGKWA
MGIGB@(OAGI/AGX/B@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;A
MGIKAGH[AGX@@4$=0(.&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`BR#A
MGI'AGX7B@(OAGI_AGK;AGIKB@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/A
MGH#"H#\B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3$Q"FUS9VED
M(")!='1A8VAE9"!&:6QE.B(*;7-G<W1R("+AGJ_AGH#AGI_AGK;AGIKB@(OA
MGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OA
MGH?AGK;AGICAGKWAGIG"H.&?EB(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-3DQ
M(&QI8B]#;VUP;W-E+G!H<#HQ-C@W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@
M<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("+AGJ_A
MGH#AGI_AGK;AGIKB@(L@7"(E<UPB(.&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`
MB^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>A^&>MN&>F.&>O>&>F2#AGIOAGK[A
MGI_B@(OAGH#AGICAGY+AGIKAGK?AGH_B@(OAGI'AGX;AGJ#AGX;B@(OAGJ_A
MGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXO"H.&?E"#AGJ_AGH#A
MGI_AGK;AGIKB@(OAGICAGK?AGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGI?AGY+AGH?AGK;AGI3AGXO"H.&?E"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HS-S<*;7-G:60@(D%T=&%C:&5D(&ES(&$@<F5P
M;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+B(*;7-G<W1R("+A
MGJ_AGH#AGI_AGK;AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI?A
MGY+AGH?AGK;AGI3AGXL@X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9Z`X9ZVX9Z:XH"+
MX9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4XH"+X9Z8X9Z]X9Z9XH"+X9Z1X9^%
MXH"+X9Z?X9^&X9Z.X9Z^XH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z1X9ZWX9Z3XH"+
MX9Z*X9^"X9Z;X9ZBX9^2X9Z3X9Z`X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z)X9Z^
MPJ#AGY0B"@HC.B!M86EL8F]X+G!H<#HY.#,@=&5M<&QA=&5S+V-O;7!O<V4O
M:F%V87-C<FEP="YI;F,Z,C0R"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N
M9"YH=&UL.C$T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HR-CD*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C,R-0IM<V=I9"`B
M071T86-H;65N="(*;7-G<W1R("+AGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+A
MGH?AGK;AGI3AGXLB"@HC.B!A='1A8VAM96YT+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!='1A8VAM96YT("5S(&1E;&5T960N(@IM<V=S='(@(N&>
MK^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BR`E<R#AGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI3"H.&?E"(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HR,C4V"FUS9VED(")!='1A8VAM96YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>K^&>@.&>
MG^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BR(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HU,C0@;&EB+T-O;7!O<V4N<&AP.C8T,`IM<V=I9"`B071T86-H;65N
M="!S=')I<'!E9#H@3W)I9VEN86P@871T86-H;65N="!T>7!E(@IM<V=S='(@
M(N&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>BN&?
M@N&>F^*`B^&>E.&>MN&>D^*`B^&>A>&?DN&>E.&>O.&>C^*`B^&>F>&>@.*`
MB^&>A>&?@>&>B<*@X9^6(.&>E.&?DN&>FN&>E^&?@>&>D>*`B^&>K^&>@.&>
MG^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>BN&>ON&>F"(*"B,Z
M(&-O;7!O<V4N<&AP.C$R-#$@;&EB+T-O;7!O<V4N<&AP.C(R,C0@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C(T,@IM<V=I9"`B071T86-H;65N
M=',B"FUS9W-T<B`BX9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4
MX9^+(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W.`IM<V=I9"`B
M071T96YD965S(@IM<V=S='(@(N&>HN&?DN&>D^&>@.&>A>&>O.&>F^&>FN&>
MO>&>F"(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S
M"FUS9VED(")!='1E;G1I;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z4X9^2
MX9Z:X9Z[X9Z$XH"+X9Z4X9^2X9Z:X9Z9X9^0X9Z/X9^2X9Z3(@H*(SH@;&EB
M+T%U=&@O:6UP+G!H<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z(.&>
MFN&>@.*`B^&>F.&>M^&>D^*`B^&>@^&>ON&>B>*`B^&>E>&?DN&>D^&?@N&>
M@.*`B^&>E.&>D^&?DN&>D.&?@N&>F"!)34%0(.&>BN&?@N&>F^*`B^&>C^&?
MDN&>FN&>O.&>G.&>@.&>MN&>FN*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8T,`IM<V=I9"`B(@HB075T;VUA=&EC86QL
M>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E
M<B!I<R!I;B!M>2`B"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@HBX9Z4X9Z$
MX9^2X9Z@X9ZVX9Z)XH"+X9Z:X9Z\X9Z4X9Z7X9ZVX9Z6XH"+X9Z`X9^2X9Z3
MX9Z[X9Z$XH"+X9Z?X9ZVX9Z:($A434P@X9Z*X9^$X9Z9XH"+X9Z?X9^2X9Z<
MX9^0X9Z9XH"+X9Z4X9^2X9Z:X9Z<X9Z/X9^2X9Z/X9ZW(.&>EN&?@>&>F^*`
MB^&>HN&?DN&>D^&>@.*`B^&>E>&?DN&>B>&>ON*`B^&>G^&?DN&>D.&>M^&>
MC^*`B^&>D^&?A>*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>G^&?@.&>G.&>E^&?
MA>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>FN&>E.&>G^&?
MB^*`B^&>@>&?DN&>B>&>N^&?AL*@/R(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M;W5R8V5S96QE8W0N:6YC.C(Y.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@
M8F]O:W,Z(@IM<V=S='(@(N&>G^&?@.&>G.&>E^&?A>*`B^&>HN&>MN&>G^&>
MF>&>BN&?DN&>B^&>MN&>D^*`B^&>BN&?@N&>F^*`B^&>F.&>MN&>DR(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,30*;7-G:60@(D%W86ET:6YG
M(%)E<W!O;G-E(@IM<V=S='(@(N&>@.&?AN&>EN&>N^&>A.*`B^&>FN&>A.&>
MA>&>MN&?AN*`B^&>@.&>MN&>FN*`B^&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>
ME"(*"B,Z(&UE<W-A9V4N<&AP.C4Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M86-?:R!T;R`E<R(*;7-G<W1R(")?2^&>C^&?DN&>FN&>H>&>E.&?B^*`B^&>
MD>&?A2`E<R`B"@HC.B!M97-S86=E+G!H<#HU,3`@=&AR96%D+G!H<#HQ,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R("+AGH_A
MGY+AGIKAGJ'AGI3AGXOB@(OAGI'AGX4@)7,B"@HC.B!T:')E860N<&AP.C$S
M,@IM<V=I9"`B0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD97@B
M"FUS9W-T<B`BX9Z/X9^2X9Z:X9ZAX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z;X9ZW
MX9Z4X9ZWX9Z`X9^2X9Z:X9Z8XH"+X9Z1X9ZWX9Z*X9^2X9Z+X9Z7X9ZVX9Z6
MXH"+X9Z?X9ZVX9Z:XH"+X9Z%X9^2X9Z:X9Z^X9Z3(@H*(SH@=&AR96%D+G!H
M<#HQ,S`*;7-G:60@(D)A8VL@=&\@5&AR96%D($1I<W!L87DB"FUS9W-T<B`B
MX9Z/X9^2X9Z:X9ZAX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z`X9ZVX9Z:XH"+X9Z4
MX9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z'X9ZVXH"+X9Z!X9^2X9Z?X9^"XH"+X9Z?
MX9^2X9Z:X9ZAX9ZVX9Z9(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&QO9VEN(&YA;64@;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?A^*`B^&>A>&>O.&>FR#AGJP@
MX9Z6X9ZVX9Z`X9^2X9Z9X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z8X9ZW
MX9Z3XH"+X9Z;X9^2X9ZBPJ#AGY0B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")"860@;W(@;6%L9F]R;65D(')E
M<75E<W0N(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(N&>G^&?AN&>
MCN&>ON*`B^&>F.&>M^&>D^*`B^&>F^&?DN&>HB#AGJP@X9Z8X9ZWX9Z3XH"+
MX9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<PJ#AGY0@X9Z8X9^)X9ZV
MX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+
MX9Z&X9^2X9Z;X9Z^X9Z9X9Z/X9Z4XH"+X9Z0X9ZVPJ#AGY8@)7,B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C4W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")"
M860@<F5Q=65S=#H@)7,N(@IM<V=S='(@(N&>G^&?AN&>CN&>ON*`B^&>F.&>
MM^&>D^*`B^&>F^&?DN&>HL*@X9^6("5SPJ#AGY0B"@HC.B!M97-S86=E+G!H
M<#HR,S4@;&EB+U-E87)C:"YP:'`Z-C$U('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYH=&UL.C0R"B,Z('1E;7!L871E<R]L;V=I;B]R96-O;7!O<V4N
M:'1M;#HS,@IM<V=I9"`B0F-C(@IM<V=S='(@(N&>F^&>MN&>@.&?BR(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I9"`B0F5L;W<@
M:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S
M<V%G92XB"FUS9W-T<B`BX9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8XH"+
MX9Z"X9ZZXH"+X9Z'X9ZVXH"+X9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z&X9^%
MX9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^#XH"+X9Z6X9^0X9Z/
MX9^,X9Z8X9ZVX9Z3XH"+X9Z?X9^2X9Z0X9ZVX9Z3X9Z7X9ZVX9Z6PJ#AGY0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S`V"FUS9VED(")"96QO=R!T
M:&4@;65S<V%G92!T97AT(@IM<V=S='(@(N&>@>&>MN&>A.*`B^&>@.&?DN&>
MFN&?A.&>F.*`B^&>HN&>C^&?DN&>D.&>E.&>D>*`B^&>G^&>MN&>FB(*"B,Z
M(&UE<W-A9V4N<&AP.C4V-2!M86EL8F]X+G!H<#HT.3`*;7-G:60@(D)L86-K
M;&ES="(*;7-G<W1R("+AGI3AGHGAGY+AGH?AGKCB@(OAGH'AGY+AGICAGX4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C(Y"FUS9VED(")";&]C:R!I
M;6%G97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF
M:6-A;&QY(')E<75E<W1E9#\B"FUS9W-T<B`BX9Z1X9Z4X9^+X9Z?X9^2X9Z`
MX9ZVX9Z/X9^+XH"+X9Z:X9Z\X9Z4X9Z7X9ZVX9Z6XH"+X9Z`X9^2X9Z3X9Z[
MX9Z$XH"+X9Z?X9ZVX9Z:($A434P@X9Z4X9^2X9Z:X9Z?X9ZWX9Z3XH"+X9Z4
MX9Z^XH"+X9Z6X9Z]X9Z`XH"+X9Z<X9ZVXH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z?X9^2X9Z3X9Z^XH"+X9Z?X9Z[
MX9^&XH"+X9Z'X9ZVXH"+X9Z6X9ZWX9Z?X9^!X9Z?PJ`_(@H*(SH@;&EB+U-E
M87)C:"YP:'`Z-C(S"FUS9VED(")";V1Y(@IM<V=S='(@(N&>C^&>O2(*"B,Z
M('-E87)C:"YP:'`Z,S(V('-E87)C:"YP:'`Z,S,Q('-E87)C:"YP:'`Z,S,V
M('-E87)C:"YP:'`Z,S0Q"FUS9VED(")";W1H(@IM<V=S='(@(N&>D>&>MN&?
MAN&>A.&>EN&>N.&>FB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.38*
M;7-G:60@(D)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G
M92(*;7-G<W1R("+AGI'AGK;AGX;AGH3B@(OAGH#AGK;AGIKB@(OAGIKAGK;A
MGIGB@(OAGI3AGHOAGICAGH#AGI#AGK8@X9Z3X9ZWX9Z$(.&>C^&>O>*`B^&>
MFN&>E.&>G^&?B^*`B^&>G^&>MN&>FB(*"B,Z(&-O;7!O<V4N<&AP.C$Q.#@*
M;7-G:60@(D-?:&%R<V5T(@IM<V=S='(@(E](X9Z?X9^&X9Z.X9Z[X9^&XH"+
MX9Z/X9Z]XH"+X9ZBX9Z`X9^2X9Z?X9Z:("(*"B,Z('-E87)C:"YP:'`Z,S$R
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+AGI3AGY+AGIKAGH_AGK?AGI'A
MGK?AGI,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$U-0IM<V=I9"`B
M0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N(@IM
M<V=S='(@(N&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>C^*`B^&>E^&?DN&>
MA^&>MN&>E.&?B^*`B^&>D>&?A>*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`
MB^&>E.&>F.&?DN&>FN&>ON*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>
MAN&?DN&>A.&>MN&>F<*@X9^4(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H
M<#HQ-3,*;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA
M:6P@<V5R=F5R.B`B"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+
MX9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z8X9^)X9ZVX9Z?
MX9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z?X9^&X9Z4X9Z[X9Z/
MX9^2X9Z:XH"+X9Z&X9^2X9Z$X9ZVX9Z9PJ#AGY8B"@HC.B!L:6(O34E-12]6
M:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O
M9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@(@HB;6%I;&)O>"XB"FUS
M9W-T<B`BX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z$X9^2X9Z@X9ZV
MX9Z)("T@X9Z:X9Z`XH"+X9Z#X9Z^X9Z)XH"+X9Z/X9^"("5S(.&>D^&?@^*`
MB^&>E>&?DN&>D^&?@N&>@"`E<R#AGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB
M@(OAGI/AGX'AGX<@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z4X9^2X9Z:X9ZBX9Z4
MX9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z4X9Z%X9^2X9Z%X9Z[
MX9Z4X9^2X9Z4X9Z3X9^2X9Z3PJ#AGY0B"@HC.B!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,C$@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN
M:6YC.C@V"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FAT;6PZ-S0*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,C,@=&5M<&QA=&5S+V9O
M;&1E<G,O:6UP;W)T+FAT;6PZ,3<*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S
M879E:6UA9V4N:'1M;#HQ.2!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH
M=&UL.C8P"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YH=&UL.C0Y"FUS
M9VED(")#86YC96PB"FUS9W-T<B`BX9Z4X9^$X9^'X9Z4X9Z$X9^+(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:'1M;#HW."!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FAT;6PZ,C4*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YH=&UL.C(P.`IM<V=I9"`B0V%N8V5L($UE<W-A9V4B"FUS9W-T
M<B`BX9Z4X9^$X9^'X9Z4X9Z$X9^+XH"+X9Z?X9ZVX9Z:(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O:F%V87-C<FEP="YI;F,Z-@IM<V=I9"`B0V%N8V5L;&EN
M9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C
M;VYT96YT<RXB"FUS9W-T<B`BX9Z4X9^$X9^'X9Z4X9Z$X9^+XH"+X9Z?X9ZV
MX9Z:XH"+X9Z3X9^!X9^'(.&>D^&>N>&>A.*`B^&>E.&?A.&?A^&>A>&?A.&>
MF^*`B^&>F.&>MN&>C^&>M^&>@.&>MN*`B^&>FN&>E.&>G^&?B^*`B^&>G.&>
MMN*`B^&>A^&>MN*`B^&>HN&>A>&>M^&>D^&?DN&>C^&?DN&>FN&?@^&>F>&?
MC<*@X9^4(@H*(SH@;65S<V%G92YP:'`Z,C,T(&QI8B]396%R8V@N<&AP.C8Q
M,2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:'1M;#HT,0HC.B!T96UP
M;&%T97,O;&]G:6XO<F5C;VUP;W-E+FAT;6PZ,C,*;7-G:60@(D-C(@IM<V=S
M='(@(N&>A>&>F.&?DN&>F^&>A"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z.3,*;7-G:60@(B(*(D-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@
M879A:6QA8FQE+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES
M("(*(G-E<G9E<BXB"FUS9W-T<B`B(@HBX9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3
MXH"+X9Z`X9ZVX9Z:XH"+X9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z<X9ZWX9Z)
MX9^2X9Z)X9ZVX9Z4X9Z3X9Z4X9Z/X9^2X9Z:XH"+X9ZAX9Z^X9Z9PJ#AGY0@
MX9Z`X9ZVX9Z:XH"+X9Z5X9^2X9Z1X9Z[X9Z`XH"+X9ZOX9Z`X9Z?X9ZVX9Z:
MXH"+X9ZAX9Z^X9Z$(.&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>
ME.&>MN&>D^*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>E.&?DN&>
MFN&>ON*`B^&>E.&>MN&>D^*`B^&>H>&>ON&>F>*`B^&>F^&>ON*`B^&>F.&?
MB>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`BR(*(N&>D^&?
M@>&?A\*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-@IM
M<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(N&>E.&?DN&>FN&>DN&>MN&>
MDR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FAT;6PZ,S0*;7-G
M:60@(D-H86YG92(*;7-G<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI3A
MGY+AGH_AGKSAGIHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH
M=&UL.C,U"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(N&>E>&?DN&>F^&>
MMN&>G^&?B^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>D>&>MN&?AN&>A.*`B^&>
MHN&>G^&?BR(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B
M0VAA;F=E($9O;&1E<B(*;7-G<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OA
MGI3AGY+AGH_AGKSAGIKB@(OAGI#AGH\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$S"FUS9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U
M8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@
M86YD("(*(FAO=R!M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R("(B"B+A
MGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI3AGY+AGH_AGKSAGIKB@(OAGH?AGICA
MGY+AGIKAGK[AGI_B@(OAGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGHKAGKSAGH7A
MGH?AGK8@X9Z?X9ZVX9Z:XH"+X9Z%X9^&X9Z3X9Z]X9Z3XH"+X9Z4X9^)X9Z[
MX9Z3X9^2X9Z8X9ZVX9Z3XH"+X9Z*X9^"X9Z;XH"+X9ZBX9^2X9Z3X9Z`XH"+
MX9Z#X9Z^X9Z)XH"+X9Z;X9Z^XH"+X9Z1X9^&X9Z6X9^0X9Z:XH"+X9Z3X9ZW
MX9Z8X9Z]X9Z9X9^7(.&>D^&>M^&>A"#AGI_AGK;AGIKB@(OAGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGH_AGICAGY+AGIKAGX#AGI3B@(OAGIGA
MGXGAGK;AGH3B@(LB"B+AGHKAGKSAGH7AGICAGY+AGH_AGX'AGH7"H.&?E"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B0VAA;F=E(&UA
M:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@(N&>E>&?
MDN&>F^&>MN&>G^&?B^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>@.&>MN&>FN*`
MB^&>@.&?AN&>CN&>C^&?B^*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>
ME.&>F.&?DN&>FN&>ON*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FB#AGI/AGK?A
MGH0@X9Z0X9Z/PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*
M;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA
M='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD("(*(G)E
M<&QY('1O('EO=7(@96UA:6PN(@IM<V=S='(@(B(*(N&>E>&?DN&>F^&>MN&>
MG^&?B^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>B.&?DN&>F.&?A.&?AR#AGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,@X9Z3X9ZWX9Z$(.&>H.&>C^&?DN&>
MD.&>F^&?@>&>@>&>MN*`B^&>BN&?@N&>F^*`B^&>F.&>D^&>N^&>G^&?DN&>
MG^*`B^&>@^&>ON&>B>*`BR#AGI;AGX'AGIOB@(OAGI;AGKWAGH#B@(OAGH+A
MGX'B@(OAGJ+AGK;AGI,@X9Z3X9ZWX9Z$(.&>AN&?DN&>F^&>ON&>F>*`B^&>
MC^&>E.*`B^&>D>&?A>*`B^&>HN&?BN&>N.&>F.&?@N&>F^*`B^&>FN&>E.&>
MG^&?B^&>HN&?DN&>D^&>@,*@X9^4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@S-0IM<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R
M("+AGH_AGKWB@(OAGJ+AGH#AGY+AGI_AGIKB@(OAGHKAGX+AGIOB@(OAGH_A
MGY+AGIKAGKSAGISB@(OAGI3AGH3AGY+AGJ#AGK;AGHG"H.&?EB(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:'1M;#HQ-PIM<V=I9"`B0VAE8VL@
M1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G<W1R("+AGI;AGK?AGI/AGK?A
MGH_AGY+AGIGB@(OAGICAGK[AGIOB@(OAGI#AGH_B@(L@X9Z?X9Z8X9^2X9Z:
MX9ZVX9Z4X9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9^2X9Z8
MX9ZX(@H*(SH@9F]L9&5R<RYP:'`Z,C@V(&UA:6QB;W@N<&AP.C8T,`IM<V=I
M9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(E]!X9Z2X9ZXX9Z`XH"+X9Z1
MX9ZVX9^&X9Z$X9ZBX9Z?X9^++^&>F.&>M^&>D^*`B^&>DN&>N.&>@.*`B^&>
MD>&>MN&?AN&>A.&>HN&>G^&?BR`B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA
M:6PN:6YC.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W
M86YT('1O(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`BX9Z6X9ZWX9Z3X9ZW
MX9Z/X9^2X9Z9XH"+X9Z8X9Z^X9Z;XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3
MXH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+(.&>
MBN&?@N&>F^*`B^&>HN&?DN&>D^&>@.*`B^&>A>&>A.&?B^*`B^*`B^&>D>&?
MA>*`B^&>E.&?DN&>FN&>F.&>O.&>F^*`B^&>F>&>@.*`B^&>G^&?AN&>E.&>
MN^&>C^&?DN&>FN*`B^&>EN&>N,*@X9^6(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0V-`IM<V=I9"`B0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I
M;F<@82!M97-S86=E/R(*;7-G<W1R("+AGI;AGK?AGI/AGK?AGH_AGY+AGIGB
M@(OAGJ+AGH#AGY+AGH'AGIKAGK;AGISAGK?AGIKAGKOAGI'AGY+AGI(@X9Z8
MX9Z[X9Z3XH"+X9Z6X9^!X9Z;XH"+X9Z5X9^2X9Z)X9Z^XH"+X9Z?X9ZVX9Z:
MX9Z8X9Z]X9Z9PJ`_(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH
M=&UL.C8*;7-G:60@(D-H;V]S92!!8W1I;VXB"FUS9W-T<B`BX9Z'X9^2X9Z:
MX9Z^X9Z?XH"+X9ZBX9^&X9Z6X9Z^(@H*(SH@8V]N9FEG+W-E<G9E<G,N<&AP
M+F1I<W0Z,3<Y"FUS9VED(")#:&]O<V4@82!M86EL('-E<G9E<CHB"FUS9W-T
M<B`BX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+
MX9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:PJ#AGY8B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ-C0*;7-G:60@
M(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I
M9VAT.B(*;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_B@(OAGHKAGX;AGH[AGKSA
MGH7B@(OAGICAGKWAGID@X9ZL(.&>@.&?@N&>G^&>F.&?DN&>FN&>O>&>F^*`
MB^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>D^&?A>*`B^&>@>&>
MMN&>A.*`B^&>G^&?DN&>BN&>MN&?AL*@X9^6(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"FUS9VED(")#:&]O<V4@=&AE(&%D
M9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+B(*;7-G
M<W1R("+AGH?AGY+AGIKAGK[AGI_B@(OAGI_AGX#AGISAGI?AGX7B@(OAGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGHKAGX+AGIOB@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGY+AGIKAGKX@X9Z6X9^!X9Z;XH"+X9Z4X9Z3X9^2
MX9Z0X9^"X9Z8XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3PJ#AGY0B
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3,*;7-G
M:60@(D-H;V]S92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R
M8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("+AGH?AGY+A
MGIKAGK[AGI_B@(OAGIOAGX;AGHKAGK;AGI3AGXOB@(OAGI_AGX#AGISAGI?A
MGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/AGHKAGX+AGIOB@(OA
MGH_AGY+AGIKAGKSAGISB@(OAGI_AGY+AGISAGX+AGH3B@(OAGIKAGH`@X9Z6
MX9^!X9Z;XH"+X9Z6X9Z$X9^2X9Z:X9ZXX9Z`XH"+X9ZBX9ZVX9Z?X9Z9X9Z*
MX9^2X9Z+X9ZVX9Z3PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N
M=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E
M<B!C86X@=FEE=RXB"FUS9W-T<B`BX9Z%X9Z[X9Z%("5S(.&>BN&>ON&>F.&?
MDN&>E.&>N.*`B^&>E.&>F.&?DN&>F^&?@N&>A.*`B^&>K^&>@.&>G^&>MN&>
MFN*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>D>&?A>*`B^&>A^&>MN*`B^&>
MD>&?DN&>FN&>A.&?B^*`B^&>D>&?DN&>FN&>MN&>F>*`B^&>BN&?@N&>F^*`
MB^&>@.&>F.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>FN&>N^&>@.&>FN&>@.*`
MB^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>HN&>MN&>A>&>E.&>
MA.&?DN&>H.&>MN&>B<*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,3`T"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O
M=VYL;V%D('1H92!I;6%G92XB"FUS9W-T<B`BX9Z%X9Z[X9Z%("5S(.&>BN&>
MON&>F.&?DN&>E.&>N.*`B^&>D>&>MN&>B>&>F>&>@.&>FN&>O.&>E.&>E^&>
MMN&>EL*@X9^4(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G
M92XB"FUS9W-T<B`BX9Z%X9Z[X9Z%("5S(.&>BN&>ON&>F.&?DN&>E.&>N.*`
MB^&>D>&?A>*`B^&>@.&>MN&>D^&?B^&>D>&?AN&>EN&?D.&>FN*`B^&>@N&?
MDN&>FN&>E.&?B^*`B^&>@N&?DN&>FN&>A"`E<\*@X9^4XH"+(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G
M92XB"FUS9W-T<B`BX9Z%X9Z[X9Z%("5S(.&>BN&>ON&>F.&?DN&>E.&>N.*`
MB^&>F.&>ON&>F^*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>C^&>O.&>A>*`
MB^&>FN&>E.&>G^&?B^*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>D^&?@>&?
MA\*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H
M;65N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`BX9Z%X9Z[X9Z%
M("5S(.&>BN&>ON&>F.&?DN&>E.&>N.*`B^&>F.&>ON&>F^*`B^&>K^&>@.&>
MG^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>@.&?DN&>D^&>N^&>
MA.*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`B^&>E>&?DN&>G^&?@>&>A,*@X9^4
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AI<R!M=6QT:7!A<G0O
M<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R("+A
MGH7AGKOAGH4@)7,@X9Z*X9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z8X9Z^X9Z;XH"+
MX9Z5X9^2X9Z3X9^"X9Z`XH"+X9Z%X9^2X9Z:X9Z^X9Z3XH"+X9Z5X9^2X9Z3
MX9^"X9Z`(.&>K"#AGI7AGY+AGI/AGX+AGH#B@(OAGI'AGK;AGH#AGXOAGI'A
MGH3B@(OAGH+AGY+AGI/AGK;B@(OAGI/AGX'AGX?B@(OAGI/AGX7B@(OAGH#A
MGY+AGI/AGKOAGH3B@(OAGI3AGH3AGY+AGJ+AGKWAGH7B@(OAGI7AGY+AGI_A
MGX'AGH3"H.&?E"(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,R,0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T
M960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T
M;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(N&>A>&>N^&>A>*`B^&>F^&>ON*`
MB^&>G^&?@.&>G.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>
MD^*`B^&>F.&>O>&>F2#AGH#AGY+AGI/AGKOAGH3B@(OAGH7AGX;AGH[AGX3A
MGICB@(OAGI_AGX#AGISAGI?AGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI/B@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGH?AGY+AGIKAGK[A
MGI_B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`@X9Z3X9ZWX9Z$(.&>
ME.&>D^&?DN&>D>&>MN&>E.&?B^*`B^&>F.&>@.*`B^&>A^&?DN&>FN&>ON&>
MG^*`B^&>@.&?DN&>FN&>H>&>MN*`BR(*(N&>D>&>D>&>N>&>A.*`B^&>D>&>
MMN&?AN&>A.&>HN&>G^&?B^*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>
MG.*`B^&>G^&?DN&>G.&?@N&>A.*`B^&>FN&>@,*@X9^4(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U
M<B!!9&1R97-S($)O;VLB"FUS9W-T<B`BX9Z%X9Z[X9Z%(.&>BN&>ON&>F.&?
MDN&>E.&>N.*`B^&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>G.&>
MM^&>B>&?DN&>B>&>MN&>E.&>D^&>E.&>C^&?DN&>FN*`B^&>FN&>E.&>G^&?
MBR!3+TU)344@X9Z3X9^#("5S(.&>@.&?DN&>D^&>N^&>A.*`B^&>G^&?@.&>
MG.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>FN&>
ME.&>G^&?B^*`B^&>HN&?DN&>D^&>@"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-C$*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@
M8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B"FUS9W-T<B`B
MX9Z%X9Z[X9Z%XH"+X9Z;X9Z^XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZV
MX9Z3XH"+(.&>D^&>N>&>A.*`B^&>C^&?@N&>A.*`B^&>G^&>MN&>FN*`B^&>
MD.&?DN&>F.&>N.*`B^&>F.&>O>&>F>*`B^&>D>&?A>*`B^&>HN&?DN&>D^&>
M@.*`B^&>E>&?DN&>B>&>OB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-C(*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E;B!T
M:&4@;65S<V%G92!T;R!B92!R96%D(@IM<V=S='(@(N&>A>&>N^&>A>*`B^&>
MF^&>ON*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DR#AGI/AGKGAGH3B
M@(OAGI3AGK[AGH#B@(OAGI_AGK;AGIKB@(OAGHKAGX+AGIOB@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGJ+AGK;AGI,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S='(@(N&>E.&>
MM^&>D2(*"B,Z(&-O;7!O<V4N<&AP.C$U,`IM<V=I9"`B0VQO<V4@=&AI<R!W
M:6YD;W<B"FUS9W-T<B`BX9Z4X9ZWX9Z1XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%
MXH"+X9Z3X9^!X9^'(@H*(SH@;&EB+TE-05`O5')E92YP:'`Z-#(U"FUS9VED
M(")#;&]S960@1F]L9&5R(@IM<V=S='(@(N&>D.&>C^*`B^&>BN&?@N&>F^*`
MB^&>E.&>MN&>D^*`B^&>E.&>M^&>D2(*"B,Z(&QI8B])34%0+U1R964N<&AP
M.C0T.`IM<V=I9"`B0V]L;&%P<V4B"FUS9W-T<B`BX9Z<X9^!X9Z)(@H*(SH@
M9F]L9&5R<RYP:'`Z,S`T"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T<B`B
MX9Z<X9^!X9Z)XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+(@H*(SH@9F]L9&5R
M<RYP:'`Z,S`T"FUS9VED(")#;VQL87!S92!!;&P@1F]L9&5R<R(*;7-G<W1R
M("+AGISAGX'AGHGB@(OAGI#AGH_B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXLB
M"@HC.B!L:6(O24U!4"]4<F5E+G!H<#HT-#@*;7-G:60@(D-O;&QA<'-E($9O
M;&1E<B(*;7-G<W1R("+AGISAGX'AGHGB@(OAGI#AGH\B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R($EN9&EC
M871O<CH@(@IM<V=S='(@(N&>D>&?DN&>FN&>D^&>M^&>A>&>E.&>A.&?DN&>
MH.&>MN&>B>*`B^*`B^&>EN&>CN&?C,*@X9^6(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$P,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("+AGI_AGX'A
MGH7AGH#AGY+AGH_AGKCB@(OAGJ+AGI+AGK?AGI3AGY+AGI3AGK;AGIDB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8R"FUS9VED(")#;VUP;&5T
M960B"FUS9W-T<B`BX9Z1X9ZVX9^&X9Z$X9Z?X9^2X9Z:X9Z[X9Z$(@H*(SH@
M8V]M<&]S92YP:'`Z,30Y"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S<V%G
M92(*;7-G<W1R("+AGH_AGX+AGH3B@(OAGI_AGK;AGIKB@(OAGICAGKWAGIGB
M@(OAGI7AGY+AGI_AGX'AGH0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#,U"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN
M9&]W/R(*;7-G<W1R("+AGH_AGX+AGH3B@(OAGI_AGK;AGIKB@(OAGH#AGY+A
MGI/AGKOAGH3B@(OAGI3AGH3AGY+AGJ+AGKWAGH7B@(OAGI7AGY+AGI_AGX'A
MGH3B@(OAGJS"H#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0T"FUS
M9VED("(B"B)#;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@8GD@
M9&5F875L="`H:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R92D_
M(@IM<V=S='(@(N&>C^&?@N&>A.*`B^&>G^&>MN&>FN*`B^&>A^&>MN&>F.&>
MO>&>F2!(5$U,($=522#AGHKAGX3AGIGB@(OAGIOAGX;AGI/AGK;AGX;AGHKA
MGK[AGI@@*.&>E.&?DN&>FN&>G^&>M^&>D^*`B^&>E.&>ON*`B^&>@.&>F.&?
MDN&>F.&>G.&>M^&>DN&>N.*`B^&>FN&>N^&>@.&>FN&>@.*`B^&>@N&>MN&?
MAN&>D>&?DN&>FN*`B^&>F^&>@.&?DN&>@>&>CN&?B.*`B^&>EN&>M^&>G^&?
M@>&>G^*`B^&>D^&?@>&?ARG"H#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I<W!L
M87EE9"XB"FUS9W-T<B`BX9Z`X9^&X9Z.X9Z/X9^+XH"+X9Z:X9Z%X9Z3X9ZV
MXH"+X9Z?X9Z8X9^2X9Z6X9^0X9Z3X9^2X9Z2X9Z0X9ZV(.*`B^&>C^&>ON*`
MB^&>G^&>MN&>FN*`B^&>E.&?B>&>N^&>D^&?DN&>F.&>MN&>D^*`B^&>BN&?
M@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>A.&?DN&>H.&>MN&>B<*@
MX9^4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED(")#;VYF
M:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N(@IM<V=S='(@(N&>@.&?AN&>
MCN&>C^&?B^*`B^&>FN&>A>&>D^&>MN*`B^&>G^&>F.&?DN&>EN&?D.&>D^&?
MDN&>DN*`B^&>A^&>F.&?DN&>FN&>ON&>G^*`B^&>F.&>ON&>F^*`B^&>G^&?
MAN&>E.&>N^&>C^&?DN&>FN*`B^&>A^&>MN*`B^&>F.&>N^&>D\*@X9^4(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G:60@(D-O;FYE8W1I;VX@
M9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+
MX9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z1X9Z8X9^2X9Z;X9ZVX9Z`X9^+XH"+X9Z%X9^$X9Z;XH"+
MX9Z*X9^$X9Z9XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2
MX9Z:X9Z^($E-05#"H.&?E"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,3@X"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F86EL960B"FUS9W-T
M<B`BX9Z`X9ZVX9Z:XH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z1X9^%
MXH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+
MX9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L
M(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`BX9Z/X9^2X9Z:X9Z]X9Z/
MXH"+X9Z6X9ZWX9Z3X9ZWX9Z/X9^2X9Z9XH"+X9Z`X9ZVX9Z:X9Z"X9ZVX9^&
MX9Z1X9^2X9Z:(%!'4"#AGI_AGICAGY+AGIKAGK;AGI3AGXL@)7/"H.&?E"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@
M(N&>C^&?DN&>FN&>O>&>C^*`B^&>EN&>M^&>D^&>M^&>C^&?DN&>F>&>@.&>
MMN&>FN*`B^&>@N&>MN&?AN&>D>&?DN&>FB!3+TU)344@X9Z?X9Z8X9^2X9Z:
MX9ZVX9Z4X9^+("5SPJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(R"FUS9VED(")#;VYT<F]L(&]P=&EO;G,@<F5L871I;F<@=&\@;65S<V%G
M97,@<V5A<F-H:6YG+B(*;7-G<W1R("+AGI3AGHGAGY+AGH?AGK;B@(OAGH?A
MGICAGY+AGIKAGK[AGI_B@(OAGHKAGX+AGIOB@(OAGI'AGK;AGH#AGXOAGI'A
MGH3B@(OAGI'AGX7B@(OAGI/AGKGAGH3B@(OAGH#AGK;AGIKB@(OAGI_AGY+A
MGISAGX+AGH3AGIKAGH#B@(OAGI_AGK;AGIK"H.&?E"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M
M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T
M;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`BX9Z/
MX9^2X9Z:X9Z]X9Z/XH"+X9Z6X9ZWX9Z3X9ZWX9Z/X9^2X9Z9(.&>EN&?@>&>
MF^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>D.&?DN&>F.&>N.*`B^&>
MD^&>N>&>A.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>EN&>
MM^&>D^&>M^&>C^&?DN&>F>*`B^&>F.&>ON&>FR#AGI/AGK?AGH0@X9Z0X9ZV
MXH"+X9Z/X9Z^XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z'X9Z\X9Z3XH"+X9Z*
MX9^&X9Z.X9ZYX9Z$XH"+X9Z*X9Z;X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9ZL
MXH"+X9ZBX9Z/X9^+(.&>EN&?@>&>F^*`B^&>G.&>MN*`B^&>F.&>@.*`B^&>
MBN&>F^&?B\*@X9^4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-@IM
M<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A
M;"!O;F5S/R(*;7-G<W1R("+AGI3AGICAGY+AGIOAGX+AGH3B@(OAGI_AGHGA
MGY+AGHGAGK;B@(OAGJ+AGK;AGIKAGICAGY+AGICAGH[AGXWB@(OAGHKAGX+A
MGIOB@(OAGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSAGISB@(OB@(OAGH_A
MGK;AGICB@(OAGJ+AGH_AGY+AGI#AGI3AGI$@X9Z1X9^%XH"+X9Z'X9ZVXH"+
MX9Z?X9Z)X9^2X9Z)X9ZVXH"+X9ZBX9ZVX9Z:X9Z8X9^2X9Z8X9Z.X9^-XH"+
MX9Z`X9^2X9Z:X9ZVX9Z@X9^2X9Z<X9ZWX9Z`PJ`_(@H*(SH@;65S<V%G92YP
M:'`Z-3`T(&UE<W-A9V4N<&AP.C8Y-B!M86EL8F]X+G!H<#HT,C`@;6%I;&)O
M>"YP:'`Z.3DX"FUS9VED(")#;W!Y(@IM<V=S='(@(N&>A>&>F.&?DN&>F^&>
MA"(*"B,Z(&UE<W-A9V4N<&AP.C4P-"!M97-S86=E+G!H<#HV.38@;6%I;&)O
M>"YP:'`Z-#(P(&UA:6QB;W@N<&AP.CDY.`IM<V=I9"`B0V]P>2!T;R!F;VQD
M97(B"FUS9W-T<B`BX9Z%X9Z8X9^2X9Z;X9Z$XH"+X9Z1X9^%XH"+X9Z0X9Z/
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:'1M;#HR.`IM<V=I
M9"`B0V]R<F5C="(*;7-G<W1R("+AGH#AGX(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYH=&UL.C@R"FUS9VED(")#;W)R96-T960@5&5X="(*
M;7-G<W1R("+AGJ+AGH_AGY+AGI#AGI3AGI'B@(OAGHKAGX+AGIOB@(OAGI3A
MGK;AGI/B@(OAGH#AGX(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,X,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]M<&QE=&4@<F5Q=65S
M="X@4F5A<V]N($=I=F5N.B`E<R(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+A
MGK;AGH7B@(OAGI3AGHGAGY+AGH7AGI3AGXOB@(OAGI_AGX;AGH[AGK["H.&?
ME"#AGICAGKSAGIOAGJ#AGX'AGH_AGKOB@(OAGH+AGKK"H.&?EB`E<R(*"B,Z
M(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G<W1R("+AGICA
MGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGH7A
MGKOAGH3B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGID@5D93PJ#AGY8@
M)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z-S$U"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E
M<G9E<B!S86ED.B`E<R(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+AGK;AGH7B
M@(OAGIOAGKOAGI3B@(OAGI_AGK;AGIKB@(OAGI;AGK@@)7/"H.&?E"#AGICA
MGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI3AGK;A
MGI/B@(OAGI/AGK?AGIGAGK;AGIGB@(OAGI#AGK;"H.&?EB`E<R(*"B,Z(&QI
M8B]397-S:6]N+G!H<#HS,C(*;7-G:60@(D-O=6QD(&YO="!E>&5C=71E(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>
MHN&>MN&>A>*`B^&>HN&>D^&>N^&>G.&>C^&?DN&>C^*`B^&>E.&?DN&>FN&>
MC^&>M^&>E.&>C^&?DN&>C^&>M^&>@.&>MN&>FN*`B^&>C^&?AN&>H.&?@N&>
MD>&>MN&?AL*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C4T
M"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@
M9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("+AGICAGK?A
MGI/B@(OAGJ+AGK;AGH7B@(OAGI_AGY+AGIKAGH3AGXOB@(OAGH7AGX'AGHGB
M@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OA
MGI_AGY+AGI/AGK[AGI_AGKOAGX8@X9Z6X9ZXXH"+X9ZOX9Z`X9Z?X9ZVX9Z:
MXH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+($U3+51.14;"H.&?E"(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C
M="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM
M<V=S='(@(N&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>G^&?DN&>FN&>A.&?
MB^*`B^&>A>&?@>&>B>*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`
MB^&>E.&>MN&>D^*`B^&>G^&?DN&>D^&>ON*`B^&>G^&>N^&?AN&>EN&>N.&>
ME.&?D.&>CN&?DN&>CN&>G^&>MN&>FB!::7#"H.&?E"(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N('-E8W5R92!C;VYN96-T:6]N('1O('1H92!)34%0('-E<G9E<BX@
M)7,@.B`E<RXB"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4
MX9Z^X9Z`XH"+X9Z`X9ZVX9Z:XH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+
MX9Z?X9Z[X9Z<X9Z/X9^2X9Z0X9ZWX9Z7X9ZVX9Z6XH"+X9Z1X9^%XH"+X9Z`
MX9ZVX9Z3X9^+XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2
MX9Z:X9Z^($E-05`@X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0@)7/"H.&?
MEB`E<\*@X9^4(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(W,`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-
M05`@<V5R=F5R+B(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OA
MGI'AGX7B@(OAGIGAGH#B@(OAGI;AGY#AGH_AGXSAGICAGK;AGI,@;F%M97-P
M86-E(.&>EN&>N.*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?
MDN&>FN&>OB!)34%0PJ#AGY0B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C,Y"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ-C$*;7-G:60@(D-R96%T92(*;7-G<W1R("+A
MGI3AGH3AGY+AGH#AGK[AGH\B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FAT;6PZ.`IM<V=I9"`B0W)E871E($9O;&1E<B(*;7-G<W1R("+AGI3A
MGH3AGY+AGH#AGK[AGH_B@(OAGI#AGH\B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,3,W"FUS9VED(")#<F5A=&4@2V5Y<R(*;7-G<W1R("+AGI3AGH3A
MGY+AGH#AGK[AGH_B@(OAGH#AGKSAGI/AGI_AGX0B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR-@IM<V=I9"`B0W)E871E
M(&$@3F5W($%C8V]U;G0B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+
MX9Z"X9Z.X9Z3X9ZXXH"+X9Z0X9^2X9Z8X9ZXXH"+X9Z8X9Z]X9Z9(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C$R('1E;7!L871E<R]P
M<F5F<R]S<&%M<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W(%-P
M86T@9F]L9&5R(@IM<V=S='(@(N&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>D.&>
MC^*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>
MFN*`B^&>D.&?DN&>F.&>N.*`B^&>F.&>O>&>F2(*"B,Z('1E;7!L871E<R]P
M<F5F<R]F;VQD97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F;VQD
M97)S96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S(&9O
M;&1E<B(*;7-G<W1R("+AGI3AGH3AGY+AGH#AGK[AGH_B@(OAGI#AGH_B@(OA
MGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI;AGY+AGIKAGK;AGH3B@(OAGI#A
MGY+AGICAGKCB@(OAGICAGKWAGIDB"@HC.B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C(V('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E
M;&5C="YI;F,Z-#(*;7-G:60@(D-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L
M9&5R(@IM<V=S='(@(N&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>D.&>C^*`B^&>
MG^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`
MB^&>E>&?DN&>B>&>ON*`B^&>D.&?DN&>F.&>N.*`B^&>F.&>O>&>F2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S
M+W!R969S+W1R87-H<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W
M('1R87-H(&9O;&1E<B(*;7-G<W1R("+AGI3AGH3AGY+AGH#AGK[AGH_B@(OA
MGI#AGH_B@(OAGI_AGX;AGIKAGK;AGICB@(OAGI#AGY+AGICAGKCB@(OAGICA
MGKWAGIDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Y"FUS9VED("(B
M"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC
M;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE
M=&4@<W!A;2XB"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z`X9^2
MX9Z4X9Z]X9Z3XH"+X9Z/X9Z8X9^2X9Z:X9Z$(.&>BN&>ON&>F.&?DN&>E.&>
MN.*`B^&>FN&?@.&>E.*`B^&>A>&?AN*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>
MFN*`B^&>A>&>O.&>F^*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@"#A
MGH_AGICAGY+AGIKAGX#AGI3B@(OAGISAGK;B@(OAGH7AGKSAGIOB@(OAGH#A
MGY+AGI/AGKOAGH3B@(OAGI#AGH\@X9Z3X9ZWX9Z$(.&>F^&>N^&>E.*`B^&>
MG^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FL*@X9^4
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"FUS9VED
M(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z`
MX9Z^X9Z/XH"+X9Z5X9^2X9Z1X9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:
MX9^$X9Z9XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9^2X9Z8X9ZX
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B0W)E871E
M('-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+B(*;7-G<W1R("+AGI3A
MGH3AGY+AGH#AGK[AGH_B@(OAGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OA
MGH#AGY+AGIKAGX3AGIGB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH@X9Z@X9Z^
MX9Z9XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z`X9ZVX9Z:XH"+X9Z&X9^2
MX9Z;X9Z^X9Z9X9Z/X9Z4PJ#AGY0B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A8V-E<W,@=&\@
M)7,B"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z%X9Z\X9Z;XH"+X9Z*X9^&X9Z.
MX9Z^X9Z:X9Z`X9ZVX9Z:XH"+X9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2X9Z4X9Z3
MX9^2X9Z3XH"+X9Z1X9^%("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P-@IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M
M86EL(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(N&>E.&?DN&>C^&>
MO.&>FN*`B^&>@N&>CN&>D^&>N.*`B^&>C^&>MN&>F.*`B^&>E.&?AN&>CN&>
MA"#AGHKAGK[AGICAGY+AGI3AGKCB@(OAGI'AGX7B@(OAGI3AGY+AGIKAGICA
MGKSAGIOB@(OAGIGAGH#B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI;A
MGKCAGH+AGH[AGI/AGKCB@(OAGI7AGY+AGI_AGX'AGH3"H.&?E"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0IM<V=I9"`B0W5S=&]M:7IE(&AO=R!Y
M;W4@<V5N9"!M86EL+B(*;7-G<W1R("+AGI3AGY+AGH_AGKSAGIKB@(OB@(OB
M@(OAGIKAGI3AGX#AGI3B@(OAGHKAGX+AGIOB@(OAGJ+AGY+AGI/AGH#B@(OA
MGI7AGY+AGHGAGK[B@(OAGI_AGK;AGIKB@(OAGH_AGK;AGICB@(OAGI3AGX;A
MGH[AGH3"H.&?E"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N(@IM<V=S='(@(N&>E.&?DN&>C^&>O.&>FN*`B^&>E^&>
MMN&>FN&>@.&>M^&>A>&?DN&>A>*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>FN&>C^&?B^*`B^&>C^&>MN&>F.*`B^&>E.&?AN&>CN&>A"#A
MGJ+AGK;AGI_AGY+AGIKAGY#AGIGB@(OAGIOAGK[B@(OAGH#AGK;AGIKB@(OA
MGH7AGKSAGIOB@(OAGI'AGX7B@(L@)7/"H.&?E"(*"B,Z(&UA:6QB;W@N<&AP
M.C4V-0IM<V=I9"`B1&%T7V4B"FUS9W-T<B`B7T7AGH#AGK;AGIOAGI3AGIKA
MGK?AGH7AGY+AGH;AGX'AGI$@(@H*(SH@;65S<V%G92YP:'`Z,C,Q('1H<F5A
M9"YP:'`Z,34P"FUS9VED(")$871E(@IM<V=S='(@(N&>@.&>MN&>F^&>E.&>
MFN&>M^&>A>&?DN&>AN&?@>&>D2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-3`*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(N&>E.&>MN&>D^*`
MB^&>E.&>BN&>M^&>G^&?@>&>DB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-C0*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`BX9Z4X9ZVX9Z3
MXH"+X9Z4X9Z*X9ZWX9Z?X9^!X9Z2PJ#AGY8@(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4T.0IM<V=I9"`B1&5F875L="(*;7-G<W1R("+AGIOAGX;A
MGI/AGK;AGX;AGHKAGK[AGI@B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L
M='-E87)C:'-E;&5C="YI;F,Z,C$*;7-G:60@(D1E9F%U;'0@4V5A<F-H($9I
M96QD(@IM<V=S='(@(N&>G.&>MN&>F^*`B^&>G^&?DN&>G.&?@N&>A.&>FN&>
M@.*`B^&>F^&?AN&>D^&>MN&?AN&>BN&>ON&>F"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,S0*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I
M83HB"FUS9W-T<B`BX9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z<X9ZWX9Z3X9ZW
MX9Z%X9^2X9Z&X9^0X9Z9XH"+X9Z/X9Z8X9^2X9Z:X9^`X9Z4XH"+X9Z;X9^&
MX9Z3X9ZVX9^&XH"+X9Z*X9Z^X9Z8PJ#AGY8B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.30T"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N
M.B(*;7-G<W1R("+AGI'AGK?AGI_B@(OAGH_AGICAGY+AGIKAGX#AGI3B@(OA
MGIOAGX;AGI/AGK;AGX;B@(OAGHKAGK[AGIC"H.&?EB(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW-3@*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R
M("+AGI3AGK;AGI/B@(OAGI7AGY+AGH_AGIOAGXOB@(OAGI_AGK?AGI'AGK?A
MGY+AGI(B"@HC.B!M97-S86=E+G!H<#HU,S<@;6%I;&)O>"YP:'`Z-#8S(&UA
M:6QB;W@N<&AP.C0V-@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-C@@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-0HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<@;&EB+TE-05`O5')E92YP:'`Z-#$R"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYH=&UL.C8T"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`BX9Z;X9Z[X9Z4(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E("5S(%!U8FQI8R!+97DB"FUS9W-T<B`BX9Z;
MX9Z[X9Z4XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.
MX9^(("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T92!#=7)R96YT($ME
M>7,B"FUS9W-T<B`BX9Z;X9Z[X9Z4XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z4
MX9Z%X9^2X9Z%X9Z[X9Z4X9^2X9Z4X9Z3X9^2X9Z3(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYH=&UL.C$Q"FUS9VED(")$96QE=&4@1F]L9&5R
M*',I(@IM<V=S='(@(N&>F^&>N^&>E.*`B^&>D.&>C^*`BR(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C(R"FUS9VED(")$
M96QE=&4@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R("+AGIOAGKOAGI3B@(OA
MGI#AGH_B@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGH?AGY+AGIKAGK[A
MGI\B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#(*;7-G
M:60@(D1E;&5T92!3=&%T:6]N97)Y(@IM<V=S='(@(N&>F^&>N^&>E.*`B^&>
ME>&?DN&>D>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F>*`B^&>
MG^&?AN&>E.&>N^&>C^&?DN&>FB(*"B,Z(&QI8B])34%0+U1R964N<&AP.C0Q
M,@IM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(N&>F^&>
MN^&>E.*`B^&>D.&>C^*`B^&>D^&>M^&>F.&>M^&?DN&>F.&>CR(*"B,Z(&UA
M:6QB;W@N<&AP.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@5FER
M='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`BX9Z;X9Z[
MX9Z4XH"+X9Z3X9ZWX9Z9X9Z8X9Z3X9^0X9Z9XH"+X9Z0X9Z/XH"+X9Z3X9ZW
MX9Z8X9^2X9Z8X9ZWX9Z/XH"+X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+("5S(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$
M96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM
M<V=S='(@(N&>F^&>N^&>E.*`B^&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>
ME.&>MN&>D^*`B^&>D>&?A>*`B^&>E.&?DN&>FN&>F.&>O.&>F^*`B^&>F>&>
M@.*`BR#AGI;AGKCB@(OAGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICA
MGY+AGIKAGK[B@(OAGH;AGY+AGH3AGK;AGIG"H#\B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C$Y"FUS9VED(")$96QE=&4@9G)O;2!M>2!C86QE
M;F1A<B(*;7-G<W1R("+AGIOAGKOAGI3B@(OAGI;AGKCB@(OAGI3AGY+AGIKA
MGH_AGK?AGI'AGK?AGI/B@(OAGIKAGI3AGI_AGXOB@(OAGH'AGY+AGHGAGKOA
MGX8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Y"FUS9VED(")$96QE
M=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N
M=&@_(@IM<V=S='(@(N&>F^&>N^&>E.*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>
ME^&?DN&>A^&>MN&>E.&?B^*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>
MC^*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>A>&>MN&>G^&?BR#AGI/AGX7B
M@(OAGI;AGX'AGIOB@(OAGH7AGK;AGI3AGXOB@(OAGI7AGY+AGH_AGK[AGICB
M@(OAGI/AGX/B@(OAGH'AGX+AGJS"H#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4Q"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S
M(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BX9Z;X9Z[X9Z4XH"+
MX9Z0X9Z/XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z*X9^"X9Z;XH"+
MX9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z)X9Z^XH"+X9Z%X9ZVX9Z?X9^+(.&>D^&?
MA>*`B^&>EN&?@>&>F^*`B^&>A>&>MN&>E.&?B^*`B^&>E>&?DN&>C^&>ON&>
MF.*`B^&>D^&?@^*`B^&>@>&?@N*`B^&>K,*@/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV,3<*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM
M<V=S='(@(N&>F^&>N^&>E.*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>
MMN&>D^*`B^&>@.&>MN&>FB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:'1M;#HS,S<*;7-G:60@(D1E;&5T93\B"FUS9W-T<B`BX9Z;X9Z[X9Z4
MPJ`_(@H*(SH@;65S<V%G92YP:'`Z-#<U(&UA:6QB;W@N<&AP.C@T,2!M86EL
M8F]X+G!H<#HY-S,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ
M,3<@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,S,*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;&5G96YD+FAT;6PZ-@IM<V=I9"`B1&5L971E9"(*;7-G
M<W1R("+AGI3AGK;AGI/B@(OAGIOAGKOAGI0B"@HC.B!S96%R8V@N<&AP.C,S
M.0IM<V=I9"`B1&5L971E9"!M97-S86=E<R(*;7-G<W1R("+AGI_AGK;AGIKB
M@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI0B"@HC.B!C;VUP
M;W-E+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@
M871T86-H;65N="!<(B5S7"(N(@IM<V=S='(@(N&>E.&>MN&>D^*`B^&>F^&>
MN^&>E.*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BR!<
M(B5S7"+"H.&?E"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,`IM<V=I
M9"`B1&5L971I;F<@86YD($UO=FEN9R!-97-S86=E<R(*;7-G<W1R("+AGH#A
MGX;AGI;AGKOAGH3B@(OAGIOAGKOAGI0@X9Z3X9ZWX9Z$(.&>E>&?DN&>F^&>
MMN&>G^&?B^*`B^&>D>&>N.*`B^&>G^&>MN&>FB(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R
M("+AGI3AGHKAGK?AGI_AGX'AGI+B@(OAGI_AGX;AGH[AGKXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-30R"FUS9VED(")$96YY(')E<75E<W0@
M9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("+AGI3AGHKAGK?A
MGI_AGX'AGI+B@(OAGI_AGX;AGH[AGK[B@(OAGI_AGICAGY+AGIKAGK;AGI3A
MGXOB@(OAGI;AGY#AGH_AGXSAGICAGK;AGI,@X9Z1X9^&X9Z3X9^!X9Z:+^&>
MFN&>G.&>F^&?BR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#,*;7-G
M:60@(D1E<V-E;F1I;F<B"FUS9W-T<B`BX9Z%X9Z[X9^'(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8V-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`BX9Z6X9ZWX9Z6X9Z.X9^,X9Z3X9ZV(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YH=&UL.C,S,0IM<V=I9"`B1&5S8W)I<'1I;VXZ(@IM
M<V=S='(@(N&>EN&>M^&>EN&>CN&?C.&>D^&>ML*@X9^6(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C8X"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-R!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED
M(")$971A:6QS(@IM<V=S='(@(N&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^&>
MF^&>F.&?DN&>HN&>M^&>CR(*"B,Z(&-O;7!O<V4N<&AP.C,Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$:60@;F]T(&%T=&%C:"!<(B5S7"(@87,@=&AE(&9I
M;&4@=V%S(&5M<'1Y+B(*;7-G<W1R("+AGICAGK?AGI/B@(OAGI3AGK;AGI/B
M@(OAGI?AGY+AGH?AGK;AGI3AGXL@7"(E<UPB(.&>H>&>ON&>F2#AGHKAGX3A
MGIGB@(OAGI_AGK;AGIKB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI'AGI'AGX'"
MH.&?E"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-S<*;7-G:60@(D1I
M;2!S:6=N871U<F5S/R(*;7-G<W1R("+AGI+AGY+AGISAGK[B@(OAGK+AGY+A
MGIGB@(OAGJ#AGH_AGY+AGI#AGIOAGX'AGH'AGK;B@(OAGI;AGK?AGI3AGK;A
MGH#B@(OAGICAGK[AGIOB@(OAGJS"H#\B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:'1M;#HU-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R("+A
MGI3AGH3AGY+AGJ#AGK;AGHDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#@P"FUS9VED(")$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG
M(&$@;65S<V%G93\B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z`
MX9ZVX9Z:XH"+X9ZBX9^'X9ZBX9ZVX9Z$(.&>E.&>D^&?DN&>D>&>MN&>E.&?
MB^*`B^&>EN&>N.&>E>&?DN&>B>&>ON*`B^&>G^&>MN&>FN&>F.&>O>&>F<*@
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.34*;7-G:60@(D1I<W!L
M87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(N&>E.&>A.&?DN&>H.&>
MMN&>B>*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>C^&>O>*`B^&>FN&>E.&>G^&?
MB^*`B^&>G^&>MN&>FB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#0*
M;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I
M;#\B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z`X9ZVX9Z:XH"+
MXH"+X9Z'X9Z\X9Z3X9Z*X9^&X9Z.X9ZYX9Z$XH"+X9Z*X9^"X9Z;XH"+X9Z;
MX9^!X9Z%X9ZAX9Z^X9Z$XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9^&X9Z4X9Z[
MX9Z/X9^2X9Z:XH"+X9Z0X9^2X9Z8X9ZXPJ`_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<W,`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3<&%M
M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z@
MX9ZVX9Z)XH"+X9Z/X9^&X9Z.(%PBX9Z?X9Z8X9^2X9ZBX9ZVX9Z/XH"+X9Z?
MX9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9ZVX9Z:7"(@X9Z`
MX9^2X9Z3X9Z[X9Z$XH"+X9Z:X9Z4X9ZVX9Z:XH"+X9Z8X9^)X9ZZX9Z3X9Z[
MX9Z9PJ`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V,@IM<V=I9"`B
M1&ES<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B
M87(_(@IM<V=S='(@(N&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>C^&?AN&>CB!<
M(N&>G^&>F.&?DN&>HN&>MN&>C^*`B^&>G^&?AN&>FN&>MN&>F%PB(.&>@.&?
MDN&>D^&>N^&>A.*`B^&>FN&>E.&>MN&>FN*`B^&>F.&?B>&>NN&>D^&>N^&>
MF<*@/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HS,C(*
M;7-G:60@(D1I<W!O<VET:6]N.B(*;7-G<W1R("+AGH7AGIKAGK?AGH_"H.&?
MEB(*"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FAT;6PZ-C@*;7-G:60@
M(D1O($Y/5"!M871C:"(*;7-G<W1R("+AGICAGK?AGI/B@(OAGI7AGY+AGH+A
MGKSAGI7AGY+AGH+AGH0B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FAT;6PZ,3@*;7-G:60@(D1O($YO="!#:&5C:R!&;VQD97(H<RD@9F]R($YE
M=R!-86EL(@IM<V=S='(@(N&>@.&>N^&?AN*`B^&>EN&>M^&>D^&>M^&>C^&?
MDN&>F>*`B^&>F.&>ON&>F^*`B^&>D.&>CR#AGI_AGICAGY+AGIKAGK;AGI3A
MGXOB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI#AGY+AGICAGK@B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38S"FUS9VED(")$;R!N;W0@9V5N
M97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS9W-T<B`BX9Z`
MX9Z[X9^&XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z/X9^&X9Z.XH"+X9Z8
MX9Z]X9Z9XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z'X9Z]X9Z:XH"+X9Z(X9Z:
MXH"+(%PBX9Z6X9ZXPJ#AGY9<(B(*"B,Z(&QI8B])35`N<&AP.CDU.`IM<V=I
M9"`B1&\@>6]U('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`B
MX9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z%X9Z$X9^+XH"+X9Z4X9Z^X9Z`
MXH"+X9Z0X9Z/XH"+X9Z3X9^$X9^'XH"+X9ZLPJ`_(@H*(SH@;&]G:6XN<&AP
M.C,U-0IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*
M;7-G<W1R("+AGICAGK?AGI/B@(OAGICAGK;AGI/B@(OAGH+AGH[AGI/AGKC"
MH#\@X9Z?X9Z\X9Z8XH"+X9Z%X9Z[X9^'X9Z(X9^2X9Z8X9^$X9^'PJ#AGY0B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C8V"FUS9VED
M(")$;VYE(@IM<V=S='(@(N&>DN&?DN&>G.&>ON*`B^&>FN&>O>&>A2(*"B,Z
M(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`BX9Z1X9ZV
MX9Z)X9Z9X9Z`("5S(.&>A^&>MN*`B^&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>
MFN&>MN&>F2`N>FEP(@H*(SH@;65S<V%G92YP:'`Z-C8T"FUS9VED(")$;W=N
M;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB"FUS9W-T<B`B
MX9Z1X9ZVX9Z)X9Z9X9Z`XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'
MX9ZVX9Z4X9^+XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+("CAGH?AGK;B@(OA
MGJ_AGH#AGI_AGK;AGIH@+GII<"DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FAT;6PZ,C(*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G
M<W1R("+AGI'AGK;AGHGAGIGAGH`@XH"+X9Z0X9Z/(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYH=&UL.C(S"FUS9VED(")$;W=N;&]A9"!&;VQD
M97(H<RD@6RYZ:7`@9F]R;6%T72(*;7-G<W1R("+AGI'AGK;AGHGAGIGAGH#B
M@(L@X9Z0X9Z/XH"+X9Z5X9^2X9Z?X9^!X9Z$X9^7(%OAGI'AGY+AGIKAGH3A
MGXOB@(OAGI'AGY+AGIKAGK;AGID@+GII<%TB"@HC.B!L:6(O34E-12]#;VYT
M96YT<RYP:'`Z,C$Y"FUS9VED(")$;W=N;&]A9"!I;B`N>FEP($9O<FUA="(*
M;7-G<W1R("+AGI'AGK;AGHGAGIGAGH#B@(OAGH?AGK;B@(OAGI'AGY+AGIKA
MGH3AGXOB@(OAGI'AGY+AGIKAGK;AGID@+GII<"(*"B,Z(&UE<W-A9V4N<&AP
M.C0W,R!M86EL8F]X+G!H<#HX,C,@;6%I;&)O>"YP:'`Z.3<T"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YH=&UL.C$Q('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYH=&UL.C$Y"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYH=&UL.C,V('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YH=&UL
M.C<*;7-G:60@(D1R869T(@IM<V=S='(@(N&>G^&?@>&>A>&>@.&?DN&>C^&>
MN.*`B^&>EN&?DN&>FN&>MN&>A"(*"B,Z(&QI8B])34%0+U1R964N<&AP.C,W
M-`IM<V=I9"`B1')A9G0@9F]L9&5R(@IM<V=S='(@(N&>D.&>C^*`B^&>G^&?
M@>&>A>&>@.&?DN&>C^&>N.*`B^&>EN&?DN&>FN&>MN&>A"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS9VED(")$<F%F=',@
M9F]L9&5R.B(*;7-G<W1R("+AGI#AGH_B@(OAGI_AGX'AGH7AGH#AGY+AGH_A
MGKCB@(OAGI;AGY+AGIKAGK;AGH3"H.&?EB(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ,#@*;7-G:60@(D4M;6%I;"!!9&1R97-S(@IM<V=S='(@(N&>
MHN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>
MFR(*"B,Z(&UA:6QB;W@N<&AP.C@Y-0IM<V=I9"`B14Y$(@IM<V=S='(@(N&>
MA>&>N^&>A.&>E.&>B>&?DN&>A>&>E.&?BR(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C<T"FUS9VED(")%4E)/4CH@66]U<B!M97-S86=E(&-O
M=6QD(&YO="!B92!D96QI=F5R960N(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>
MG\*@X9^6(.&>G^&>MN&>FN*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>
M@.*`B^&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`
MB^&>E.&>MN&>D^*`B^&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>D>&?A>&>BN&>
MF^&?B\*@X9^4(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C$Y(&QI8B])34%0+U1R964N<&AP.C0Q,PIM<V=I9"`B161I="(*;7-G<W1R
M("+AGH#AGX+B@(OAGI_AGICAGY+AGIKAGKWAGILB"@HC.B!M86EL8F]X+G!H
M<#HS-C0@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:'1M;#HQ.0IM<V=I9"`B
M161I="!396%R8V@@475E<GDB"FUS9W-T<B`BX9Z`X9^"X9Z?X9Z8X9^2X9Z:
MX9Z]X9Z;XH"+X9Z?X9^&X9Z.X9Z]X9Z:XH"+X9Z?X9^2X9Z<X9^"X9Z$X9Z:
MX9Z`(@H*(SH@;&EB+TE-05`O5')E92YP:'`Z-#$S('1E;7!L871E<R]S96%R
M8V@O<V5A<F-H+FAT;6PZ,3<*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B
M"FUS9W-T<B`BX9Z`X9^"XH"+X9Z?X9Z8X9^2X9Z:X9Z]X9Z;XH"+X9Z0X9Z/
MXH"+X9Z3X9ZWX9Z8X9ZWX9^2X9Z8X9Z/(@H*(SH@;6%I;&)O>"YP:'`Z,S8P
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F
M:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`BX9Z`X9^"XH"+X9Z?X9Z8X9^2X9Z:
MX9Z]X9Z;XH"+X9Z3X9ZWX9Z9X9Z8X9Z3X9^0X9Z9XH"+X9Z0X9Z/XH"+X9Z3
MX9ZWX9Z8X9^2X9Z8X9ZWX9Z/XH"+X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+("5S
M(@H*(SH@9FEL=&5R<')E9G,N<&AP.C<Y"FUS9VED(")%9&ET('EO=7(@0FQA
M8VML:7-T(@IM<V=S='(@(N&>@.&?@N&>G^&>F.&?DN&>FN&>O>&>F^*`B^&>
ME.&>B>&?DN&>A^&>N.*`B^&>@>&?DN&>F.&?A>*`B^&>FN&>E.&>G^&?B^*`
MB^&>HN&?DN&>D^&>@"(*"B,Z(&9I;'1E<G!R969S+G!H<#HW.`IM<V=I9"`B
M161I="!Y;W5R($9I;'1E<B!2=6QE<R(*;7-G<W1R("+AGH#AGX+AGI_AGICA
MGY+AGIKAGKWAGIOB@(OAGH#AGY+AGI3AGKWAGI/B@(OAGH_AGICAGY+AGIKA
MGH3B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`B"@HC.B!F:6QT97)P
M<F5F<RYP:'`Z.#`*;7-G:60@(D5D:70@>6]U<B!7:&ET96QI<W0B"FUS9W-T
M<B`BX9Z`X9^"X9Z?X9Z8X9^2X9Z:X9Z]X9Z;XH"+X9Z4X9Z)X9^2X9Z'X9ZX
MXH"+X9Z?XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@W,@IM<V=I9"`B161I="!Y;W5R('!R969E
M<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS
M9W-T<B`BX9Z`X9^"XH"+X9Z?X9Z8X9^2X9Z:X9Z]X9Z;XH"+X9Z%X9^&X9Z.
MX9Z$X9^+XH"+X9Z%X9^&X9Z.X9Z\X9Z;XH"+X9Z%X9ZWX9Z/X9^2X9Z/XH"+
MX9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(.&>G^&>F.&?DN&>FN&>MN&>
ME.&?B^*`B^&>A>&>O.&>F^*`B^&>BN&?AN&>CN&>ON&>FN&>@.&>MN&>FN*`
MB^&>@N&>CN&>D^&>N.*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>E>&?
MDN&>G^&?@>&>A.&?E\*@X9^4(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FAT;6PZ-3D*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B
MX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"
MX9Z;(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("+A
MGI3AGK;AGI/B@(OB@(OAGIOAGKOAGI3B@(OAGI3AGX;AGI3AGK;AGH_AGXOA
MGI_AGK;AGIKB@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXOB@(OAGI;AGK@@)7/"
MH.&?E"(*"B,Z(&QI8B]-97-S86=E+G!H<#HW,#@*;7-G:60@(D5M<'1I960@
M86QL(&UE<W-A9V5S(&9R;VT@5FER='5A;"!4<F%S:"!&;VQD97(N(@IM<V=S
M='(@(N&>E.&>MN&>D^*`B^&>G^&>F.&?DN&>HN&>MN&>C^*`B^&>G^&>MN&>
MFN*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?B^*`B^&>EN&>N.*`B^&>D.&>C^*`
MB^&>G^&?AN&>FN&>MN&>F.*`B^&>D^&>M^&>F.&?DN&>F.&>M^&>C\*@X9^4
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH=&UL.C(T"FUS9VED
M(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`BX9Z?X9Z8X9^2X9ZBX9ZVX9Z/
MXH"+X9Z0X9Z/(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF
M:7)M+FAT;6PZ,C(*;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS
M9W-T<B`BX9Z?X9Z8X9^2X9ZBX9ZVX9Z/XH"+X9Z0X9Z/XH"+X9Z*X9^"X9Z;
MXH"+X9Z4X9ZVX9Z3XH"+X9Z'X9^2X9Z:X9Z^X9Z?(@H*(SH@;6%I;&)O>"YP
M:'`Z-#8T"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`BX9Z?
MX9Z8X9^2X9ZBX9ZVX9Z/XH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8(@H*
M(SH@;&EB+TE-4"YP:'`Z-S@W"FUS9VED(")%;7!T>2!?4W!A;2(*;7-G<W1R
M(")?4^&>G^&>F.&?DN&>HN&>MN&>C^*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`
MB^&>E.&>MN&>D^*`B^&>@.&>MN&>FB`B"@HC.B!L:6(O24U0+G!H<#HW-S<*
M;7-G:60@(D5M<'1Y(%]4<F%S:"(*;7-G<W1R(")?5.&>G^&>F.&?DN&>HN&>
MMN&>C^*`B^*`B^&>G^&?AN&>FN&>MN&>F"`B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I
M9"`B16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("+AGI+AGY+A
MGISAGK[B@(OAGK+AGY+AGIGB@(OAGICAGKOAGH'B@(OAGH3AGK;AGIH@4$=0
M(.&>E.&?DN&>FN&>ON*`B^&>E.&>MN&>D\*@/R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN
M8SHV"FUS9VED(")%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_(@IM<V=S
M='(@(N&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>F.&>N^&>@>&>A.&>
MMN&>FB!3+TU)344@X9Z4X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3PJ`_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,PIM<V=I9"`B16YA8FQE(&UE<W-A
M9V4@<')E=FEE=W,_(@IM<V=S='(@(N&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>
MF>*`B^&>@.&>MN&>FN*`B^&>F.&>ON&>F^*`B^&>G^&>MN&>FN*`B^&>A^&>
MMN*`B^&>F.&>N^&>D^*`B^&>E.&?DN&>FN&>ON*`B^&>E.&>MN&>D\*@/R(*
M"B,Z(&-O;7!O<V4N<&AP.C$R.#8*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO
M;G,B"FUS9W-T<B`B7UGAGH?AGICAGY+AGIKAGK[AGI_B@(OAGI3AGICAGY+A
MGIOAGX+AGH3B@(OAGH?AGK;B@(OAGH#AGKSAGHH@(@H*(SH@;6%I;&)O>"YP
M:'`Z.3@U('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YH=&UL.C$V"FUS9VED
M(")%;F-R>7!T960B"FUS9W-T<B`BX9Z4X9ZVX9Z3XH"+X9Z4X9Z8X9^2X9Z;
MX9^"X9Z$XH"+X9Z'X9ZVXH"+X9Z`X9Z\X9Z*(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4Q-B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$X
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3$@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8U,PIM<V=I9"`B16YD(@IM<V=S='(@(N&>E.&>B>&?
MDN&>A>&>E.&?BR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-#@T"FUS9VED(")%
M;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z%X9Z4
MX9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z4
MX9Z)X9^2X9Z'X9Z\X9Z3XH"+X9Z4X9Z3X9^2X9Z/(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C$T,#,*;7-G:60@(D5N9"!M97-S86=E(@IM<V=S='(@(N&>E.&>
MB>&?DN&>A>&>E.&?B^*`B^&>G^&>MN&>FB(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(D5N9"!M97-S86=E(&9R;VT@
M)7,B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z%X9Z4X9^+XH"+X9Z?X9ZVX9Z:XH"+
MX9Z6X9ZX("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A
M<V4B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z#X9^2X9Z;X9ZV
MXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-P86US96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y
M;W5R(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R("+AGI3AGHGAGY+AGH7AGKSA
MGIOB@(OAGHCAGY+AGICAGX3AGX?B@(OAGI#AGY+AGICAGK@@X9Z?X9Z8X9^2
MX9Z:X9ZVX9Z4X9^+XH"+X9Z0X9Z/XH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+
MX9Z4X9ZVX9Z3XH"+X9Z`X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZXXH"+X9Z:X9Z4
MX9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O
M;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO
M=7(@;F5W(&1R869T<R!F;VQD97(B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z%X9Z\
MX9Z;XH"+X9Z(X9^2X9Z8X9^$X9^'(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`
MB^&>D.&>C^*`B^&>G^&?@>&>A>&>@.&?DN&>C^&>N.&>EN&?DN&>FN&>MN&>
MA.*`B^&>D.&?DN&>F.&>N.*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>
M@"(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*
M;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@
M9F]L9&5R(@IM<V=S='(@(N&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>B.&?DN&>
MF.&?A.&?AR#AGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OAGI#AGH_B@(OAGI_A
MGX;AGI3AGKOAGH_AGY+AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OA
MGI7AGY+AGHGAGK[B@(OAGI#AGY+AGICAGKCB@(OAGIKAGI3AGI_AGXOB@(OA
MGJ+AGY+AGI/AGH`B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N
M:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S
M:"!F;VQD97(B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z(X9^2
MX9Z8X9^$X9^'(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>D.&>C^*`B^&>
MG^&?AN&>FN&>MN&>F.*`B^&>D.&?DN&>F.&>N.*`B^&>FN&>E.&>G^&?B^*`
MB^&>HN&?DN&>D^&>@"(*"B,Z(&QI8B]396%R8V@N<&AP.C8R-PIM<V=I9"`B
M16YT:7)E($UE<W-A9V4B"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z1X9ZVX9^&
MX9Z$X9Z8X9Z\X9Z;(@H*(SH@;65S<V%G92YP:'`Z,34W('1H<F5A9"YP:'`Z
M-S`@;&EB+T-O;7!O<V4N<&AP.C<Q,R!L:6(O0V]M<&]S92YP:'`Z.3<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D5N=')Y(%PB)7-<(B!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`BX9Z2X9ZV
MX9Z/X9Z[(%PB)7-<(B#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OA
MGI3AGI/AGY+AGI#AGX+AGICB@(OAGHKAGX3AGIGB@(OAGH?AGX3AGH+AGH?A
MGY#AGID@X9Z1X9^%XH"+X9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9
MX9Z*X9^2X9Z+X9ZVX9Z3(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HS.#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDT
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C$V-0IM<V=I9"`B17)R;W(B"FUS9W-T<B`BX9Z`
MX9^&X9Z@X9Z[X9Z?(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT,S$@;&EB
M+TE-05`O0VQI96YT+G!H<#HT-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E<G9E<BX@)7,@.B`E<RXB"FUS9W-T
M<B`BX9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZV
MX9Z:XH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z`X9ZV
MX9Z3X9^+XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:
MX9Z^($E-05#"H.&?E"`E<\*@X9^6("5SPJ#AGY0B"@HC.B!L:6(O34E-12]#
M;VYT96YT<RYP:'`Z,3(T"FUS9VED(")%<G)O<B!D:7-P;&%Y:6YG(&UE<W-A
M9V4N(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`B^&>@.&?DN&>D^&>N^&>
MA.*`B^&>@.&>MN&>FN*`B^&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>G^&>MN&>
MFL*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q,"!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-#`X"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R("+AGH#AGX;AGJ#A
MGKOAGI_B@(OAGI3AGHGAGY+AGH?AGKSAGI/B@(OAGH#AGK;AGIKB@(OAGH;A
MGY+AGIOAGK[AGIGB@(OAGH_AGI3B@(OAGI'AGX7"H.&?EB`E<\*@X9^4(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,@IM<V=I9"`B179E;G0@
M<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(N&>E.&>MN&>D^*`B^&>
MF^&>N^&>E.*`B^&>EN&?DN&>FN&>N>&>C^&?DN&>C^&>M^&>@.&>MN&>FN&>
MCN&?C>*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>@N*`B^&>A^&?D.&>F<*@X9^4
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y-`IM<V=I9"`B179E<GD@
M,34@;6EN=71E<R(*;7-G<W1R("+AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXOB
M@(L@X9^AX9^E(.&>D^&>MN&>D>&>N"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BX9Z:
MX9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+(.&?H^&?H"#AGISAGK?AGI/AGK;A
MGI'AGK@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,Q(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.3,*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G
M<W1R("+AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXL@X9^E(.&>D^&>MN&>D>&>
MN"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.34*;7-G:60@(D5V97)Y
M(&AA;&8@:&]U<B(*;7-G<W1R("+AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXOB
M@(OAGH#AGI/AGY+AGIOAGX?B@(OAGICAGXGAGX3AGH0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T
M<B`BX9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+X9Z3X9ZVX9Z1X9ZX(@H*(SH@
M;&EB+TE-05`O5')E92YP:'`Z-#4V"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B
MX9Z4X9Z3X9^2X9Z;X9ZVX9Z9(@H*(SH@9F]L9&5R<RYP:'`Z,S`S"FUS9VED
M(")%>'!A;F0@06QL(@IM<V=S='(@(N&>E.&>D^&?DN&>F^&>MN&>F>*`B^&>
MD>&>MN&?AN&>A.&>HN&>G^&?BR(*"B,Z(&9O;&1E<G,N<&AP.C,P,PIM<V=I
M9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(N&>E.&>D^&?DN&>F^&>
MMN&>F>*`B^&>D.&>C^*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?BR(*"B,Z(&QI
M8B])34%0+U1R964N<&AP.C0U-@IM<V=I9"`B17AP86YD($9O;&1E<B(*;7-G
M<W1R("+AGI3AGI/AGY+AGIOAGK;AGIGB@(OAGI#AGH\B"@HC.B!C;VUP;W-E
M+G!H<#HX-C@@8V]M<&]S92YP:'`Z,3(S,0IM<V=I9"`B17AP86YD($YA;65S
M(@IM<V=S='(@(N&>E.&>D^&?DN&>F^&>MN&>F>*`B^&>B.&?DN&>F.&?A.&?
MAR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<T"FUS9VED(")%>'!A
M;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@
M:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(N&>E.&>D^&?DN&>F^&>MN&>
MF>*`B^&>B.&?DN&>F.&?A.&?A^*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>E.&>
MA.&?DN&>HN&>O>&>A>*`B^&>C^&?@N&>A.&>BN&?A.&>F>*`B^&>G^&?DN&>
MG.&?D.&>F>*`B^&>E.&?DN&>FN&>G.&>C^&?DN&>C^&>MR#AGH#AGY+AGI/A
MGKOAGH3B@(OAGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKA
MGX3AGIG"H#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3DQ"FUS9VED
M(")%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN
M('1H92!F;VQD97)S('9I97<_(@IM<V=S='(@(N&>E.&>D^&?DN&>F^&>MN&>
MF>*`B^&>F.&?@N&>@.*`B^&>DN&>MN&>A.*`B^&>D.&>C^*`B^&>D>&>MN&?
MAN&>A.*`B^&>F.&>O.&>F^*`B^&>A^&>MN*`B^&>F^&?AN&>D^&>MN&?AN&>
MBN&>ON&>F"#AGH#AGY+AGI/AGKOAGH3B@(OAGI'AGK?AGHKAGY+AGHOAGI?A
MGK;AGI;B@(OAGI#AGH_"H#\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YH=&UL.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HX
M,@IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>E.&>
MD^&?DN&>F^&>MN&>F2(*"B,Z(&QI8B])35`N<&AP.C<Y."!L:6(O24U0+G!H
M<#HX,#`*;7-G:60@(D9?971C:"!-86EL(@IM<V=S='(@(E]%X9Z1X9^%XH"+
MX9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`XH"+X9Z?X9^&X9Z4X9Z[X9Z/
MX9^2X9Z:("(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN
M8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")&971C:"!-
M86EL(@IM<V=S='(@(EPBX9Z1X9^%XH"+XH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;
MXH"+X9Z9X9Z`XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:7"(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#@P"FUS9VED(")&971C:"!-86EL(&EN(&$@
M<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")<(N&>D>&?A>*`B^&>E.&?DN&>
MFN&>F.&>O.&>F^*`B^&>F>&>@.*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FEPB
M(.*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`B^&>
ME>&?DN&>G^&?@>&>A.&>K,*@/R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G
M:6YG(&]N/R(*;7-G<W1R("+AGI'AGX7B@(OAGI3AGY+AGIKAGICAGKSAGIOB
M@(OAGIGAGH#B@(OAGI_AGK;AGIH@X9ZBX9ZVX9Z?X9^2X9Z:X9^0X9Z9XH"+
MX9Z;X9Z^XH"+X9Z`X9ZVX9Z:XH"+X9Z%X9Z\X9Z;X9ZLPJ`_(@H*(SH@;&EB
M+T9E=&-H;6%I;"YP:'`Z,CDQ"B,L('!H<"UF;W)M870*;7-G:60@(D9E=&-H
M960@)60@;65S<V%G97,@9G)O;2`E<R(*;7-G<W1R("+AGI3AGK;AGI/B@(OA
MGI'AGX7B@(OAGI3AGY+AGIKAGICAGKSAGIOB@(OAGIGAGH#B@(OAGI_AGK;A
MGIKB@(OAGH7AGX;AGI/AGKWAGI,@)60@X9Z6X9ZX("5S(@H*(SH@;&EB+T9E
M=&-H;6%I;"YP:'`Z,C@Y"B,L('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@
M,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`BX9Z4X9ZVX9Z3XH"+X9Z1X9^%
MXH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`XH"+X9Z?X9ZVX9Z:XH"+
MX9Z%X9^&X9Z3X9Z]X9Z3(.&?H2#AGI;AGK@@)7,B"@HC.B!L:6(O1F5T8VAM
M86EL+G!H<#HR.#<@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y(&QI8B]&971C:&UA
M:6PN<&AP.C(Y,0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`BX9Z1X9^%
MXH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`XH"+X9Z?X9^&X9Z4X9Z[
MX9Z/X9^2X9Z:PJ#AGY8B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3,*;7-G
M:60@(D9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R("+AGI'A
MGX7B@(OB@(OAGI3AGY+AGIKAGICAGKSAGIOB@(OAGIGAGH#B@(OAGI_AGX;A
MGI3AGKOAGH_AGY+AGIK"H.&?EB#AGH+AGY+AGICAGK;AGI/B@(OAGI_AGK;A
MGIKB@(OAGI#AGY+AGICAGKC"H.&?E"(*"B,Z(&QI8B])35`N<&AP.C@P-`IM
M<V=I9"`B1FE?;'1E<G,B"FUS9W-T<B`B7TSAGH_AGICAGY+AGIKAGH0@(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O:F%V87-C<FEP="YI;F,Z,C(W('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HR-C4*;7-G:60@(D9I;&4B"FUS
M9W-T<B`BX9ZOX9Z`X9Z?X9ZVX9Z:(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:'1M;#HT.`IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B
MX9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z/X9Z8X9^2
MX9Z:X9Z$(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:'1M;#HS-@IM
M<V=I9"`B1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>
M@.&?AN&>CN&>C^&?B^*`B^&>C^&>F.&?DN&>FN&>A"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,#`*;7-G:60@(D9I;'1E<B!M97-S86=E(&-O;G1E
M;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`BX9Z/X9^2X9Z:X9Z$XH"+X9Z8
MX9ZVX9Z/X9ZWX9Z`X9ZVXH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:(.&>
MG^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>E^&>MN&>EN*`B^&>HN&>MN&>G^&>
M@N&?DN&>FN&>MN&>F,*@/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FAT;6PZ,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N
M('1H:7,@<WES=&5M+B(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGH+AGK;AGX;A
MGI'AGY+AGIKB@(OAGH_AGICAGY+AGIKAGH3B@(OAGH_AGY+AGIKAGKSAGISB
M@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI3A
MGY+AGIKAGK[B@(OAGIOAGX+AGH3B@(OAGI3AGK;AGI,@XH"+X9Z;X9Z^XH"+
MX9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z3X9^!X9^'PJ#AGY0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED(")&:6QT97)S(@IM
M<V=S='(@(N&>C^&>F.&?DN&>FN&>A"(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FAT;6PZ,PIM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM<V=S
M='(@(N&>C^&>F.&?DN&>FN&>A.*`B^&>F.&>M^&>D^*`B^&>G^&>@.&>F.&?
MDN&>F"(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4B"FUS9W-T<B`BX9Z/
MX9Z8X9^2X9Z:X9Z$PJ#AGY8@X9Z1X9^&X9Z6X9^0X9Z:XH"+X9Z"X9^2X9Z:
MX9Z4X9^+XH"+X9Z"X9^2X9Z:X9Z$("5S(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FAT;6PZ,3,*;7-G:60@(D9I;F0Z(@IM<V=S='(@(N&>
MFN&>@,*@X9^6(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I
M9"`B1FER<W0@36%I;&)O>"!086=E(@IM<V=S='(@(N&>D>&?AN&>EN&?D.&>
MFN*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>
MFN*`B^&>BN&?AN&>E.&>O.&>A"(*"B,Z(&UA:6QB;W@N<&AP.C0S,@IM<V=I
M9"`B1FER<W0@4&%G92(*;7-G<W1R("+AGI'AGX;AGI;AGY#AGIKB@(OAGHKA
MGX;AGI3AGKSAGH0B"@HC.B!M97-S86=E+G!H<#HU-30@;6%I;&)O>"YP:'`Z
M-3`Q"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R(")?4N&>E.&>B>&?DN&>A^&>
MO.&>D^*`B^&>E.&>D^&?DN&>CR`B"@HC.B!F;VQD97)S+G!H<#HR,38@=&5M
M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ-0IM<V=I9"`B
M1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`BX9ZBX9^&
MX9Z6X9Z^XH"+X9Z0X9Z/("T@X9ZBX9^'X9ZBX9ZVX9Z$(@H*(SH@9F]L9&5R
M<RYP:'`Z,C0Y('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI
M;F,Z-@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC
M.C$P('1E;7!L871E<R]F;VQD97)S+VAE860N:'1M;#HR"FUS9VED(")&;VQD
M97(@3F%V:6=A=&]R(@IM<V=S='(@(N&>@.&>F.&?DN&>F.&>G.&>M^&>DN&>
MN.*`B^&>FN&>N^&>@.*`B^&>FN&>@.*`B^&>D.&>CR(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HS"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R
M("+AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI_AGH3AGY+AGH'AGX'AGI3B
M@(OAGIKAGI3AGI_AGXOB@(OAGI#AGH\B"@HC.B!A8VPN<&AP.C(S"FUS9VED
M(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`BX9Z`
MX9ZVX9Z:XH"+X9Z%X9^"X9Z`XH"+X9Z:X9^&X9Z;X9^"X9Z`XH"+X9Z0X9Z/
MXH"+X9Z"X9ZZXH"+X9ZBX9Z?X9Z`X9Z8X9^2X9Z8PJ#AGY0B"@HC.B!F;VQD
M97)S+G!H<#HR-`IM<V=I9"`B1F]L9&5R('5S92!I<R!N;W0@96YA8FQE9"XB
M"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z0X9Z/XH"+
MX9Z"X9ZZXH"+X9ZBX9Z?X9Z`X9Z8X9^2X9Z8PJ#AGY0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3@P"FUS9VED(")&;W)M870@;V8@;65S<V%G92!D
M871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T
M;V1A>2(*;7-G<W1R("(B"B+AGI'AGY+AGIKAGH3AGXOB@(OAGI'AGY+AGIKA
MGK;AGIGB@(OB@(OAGI/AGX/B@(OAGH#AGK;AGIOB@(OAGI3AGIKAGK?AGH7A
MGY+AGH;AGX'AGI'B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIH@X9Z`X9^2
MX9Z3X9Z[X9Z$XH"+X9Z1X9ZWX9Z*X9^2X9Z+X9Z7X9ZVX9Z6XH"+X9Z4X9^2
MX9Z:X9ZBX9Z4X9^+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:(.&>G^&>F.&?DN&>
MFN&>MN&>E.&?B^&>G^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`
MB^&>A>&>N^&?A^*`B^&>@.&>MN&>F^*`B^&>E.&>FN&>M^&>A>&?DN&>AN&?
M@>&>D>*`B^&>D.&?DN&>A.&?@^*`B^&>D^&?@>&?AR(*"B,Z(&UE<W-A9V4N
M<&AP.C4U-"!M86EL8F]X+G!H<#HU,#$@;&EB+T-O;7!O<V4N<&AP.C$T-34*
M;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z'X9Z\X9Z3XH"+
MX9Z4X9Z3X9^2X9Z/(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$T-#$*;7-G:60@
M(D9O<G=A<F0Z(@IM<V=S='(@(N&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>E.&>
MD^&?DN&>C\*@X9^6(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$T-CD*;7-G:60@
M(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>BN&?
M@N&>F^*`B^&>E.&>MN&>D^*`B^&>E.&>B>&?DN&>A^&>O.&>D^*`B^&>E.&>
MD^&?DN&>CR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-#8W"B,L('!H<"UF;W)M
M870*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B
MX9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z)X9^2
MX9Z'X9Z\X9Z3XH"+X9Z4X9Z3X9^2X9Z/XH"+X9Z6X9ZX("5S(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0P,@IM<V=I9"`B1G)E92]"=7-Y(%)E
M<75E<W0@4F5S<&]N<V4B"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z&X9^2X9Z;
MX9Z^X9Z9XH"+X9Z/X9Z4XH"+X9Z?X9^&X9Z.X9Z^(.&>D>&?AN&>D^&?@>&>
MFB_AGIKAGISAGIOAGXLB"@HC.B!M86EL8F]X+G!H<#HU-S4*;7-G:60@(D9R
M;U]M(@IM<V=S='(@(E]-X9Z6X9ZX("(*"B,Z(&UE<W-A9V4N<&AP.C(S,B!T
M:')E860N<&AP.C$U,2!L:6(O4V5A<F-H+G!H<#HV,#,*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YH=&UL.C,Q"FUS9VED(")&<F]M(@IM<V=S='(@
M(N&>EN&>N"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,CD*;7-G:60@
M(D9R;VT@061D<F5S<R(*;7-G<W1R("+AGI;AGKCB@(OAGJ+AGK;AGI_AGIGA
MGHKAGY+AGHOAGK;AGI,B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,30U,B!L:6(O
M0V]M<&]S92YP:'`Z,30U-@IM<V=I9"`B1G=D.B(*;7-G<W1R("+AGI3AGHGA
MGY+AGH?AGKSAGI/B@(OAGI3AGI/AGY+AGH_"H.&?EB(*"B,Z(&-O;7!O<V4N
M<&AP.C8Q.0IM<V=I9"`B1G=D.B`B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z'X9Z\
MX9Z3XH"+X9Z4X9Z3X9^2X9Z/PJ#AGY8B"@HC.B!C;VUP;W-E+G!H<#HV,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1G=D.B`E=2!&;W)W87)D960@365S<V%G
M97,B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z'X9Z\X9Z3XH"+X9Z4X9Z3X9^2X9Z/
MPJ#AGY8@X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z4
MX9Z)X9^2X9Z'X9Z\X9Z3XH"+X9Z4X9Z3X9^2X9Z/("5U(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS9W-T<B`BX9Z'X9Z8
MX9^2X9Z:X9Z^X9Z?XH"+X9Z1X9Z\X9Z1X9^%(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@;65S
M<V%G97,_("A)34%0(&]N;'DI(@IM<V=S='(@(N&>F>&>@.*`B^&>C^&?@N*`
MB^&>G^&>MN&>FN*`B^&>D.&?DN&>F.&>N,*@/R`HX9Z/X9^"($E-05`I(@H*
M(SH@9F]L9&5R<RYP:'`Z,C@X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M-30@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<R.`IM<V=I9"`B1V\B"FUS
M9W-T<B`BX9Z1X9^%(@H*(SH@=&AR96%D+G!H<#HQ,S0*;7-G:60@(D=O('1O
M($UE<W-A9V4B"FUS9W-T<B`BX9Z1X9^%XH"+X9Z`X9ZVX9Z3X9^+XH"+X9Z?
MX9ZVX9Z:(@H*(SH@;&EB+TE-4"YP:'`Z,S8S"B,L('!H<"UF;W)M870*;7-G
M:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T
M<B`BX9Z1X9^%XH"+X9Z`X9ZVX9Z3X9^+XH"+X9Z2X9ZVX9Z/X9Z[XH"+X9Z?
MX9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+
MX9Z3X9^#(%PB)7-<(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,S8*
M;7-G:60@(D=R86YT(&%C8V5S<R(*;7-G<W1R("+AGJ+AGI/AGKOAGHGAGY+A
MGHGAGK;AGH_B@(OAGK+AGY+AGIGB@(OAGH7AGKSAGIOB@(OAGHKAGX;AGH[A
MGK[AGIKAGH#AGK;AGIHB"@HC.B!M97-S86=E+G!H<#HT,C@@;&EB+T9I;'1E
M<BYP:'`Z,3`Q(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC.B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,3$@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,3$S"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V-"!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@HC.B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV."!L:6(O34E-12]6
M:65W97(O<F5L871E9"YP:'`Z-SD*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HT,C,@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C`@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,3(Y"FUS9VED(")(15)%(@IM<V=S='(@(N&>D>&>
MN.&>D^&?@>&?AR(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS,2!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$Y"B,Z(&QI8B]-24U%
M+U9I97=E<B]R96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(
M5$U,(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,V,`IM<V=I9"`B2%1-3"!697)S
M:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`BX9Z`X9^&X9Z.X9^"($A434P@X9Z:
MX9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:(@H*(SH@;65S<V%G92YP:'`Z-C@S"FUS
M9VED(")(96%D97)S(@IM<V=S='(@(N&>E.&>B^&>F.&>@.&>D.&>MB(*"B,Z
M('1E;7!L871E<R]L;V=I;B]R96-O;7!O<V4N:'1M;#HW"FUS9VED(")(97)E
M(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B
MX9Z3X9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9Z?X9ZVX9Z:XH"+X9Z*
MX9^"X9Z;XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9^&X9Z6
MX9Z[X9Z$XH"+X9Z/X9^"X9Z$PJ#AGY8B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C8X"FUS9VED(")(:61D96XB"FUS9W-T<B`BX9Z;X9ZVX9Z`X9^+
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PIM<V=I9"`B2&ED9&5N
M(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(N&>F^&>MN&>@.&?B^*`B^&>@.&?
MDN&>D^&>N^&>A.*`B^&>D>&>M^&>BN&?DN&>B^&>E^&>MN&>EN*`B^*`B^&>
M@>&?DN&>G^&?@N*`B^&>HN&?AN&>E.&?A.&?AR(*"B,Z(&UA:6QB;W@N<&AP
M.C(W,@IM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@(N&>F^&>MN&>@.&?
MBR!<(N&>E.&>MN&>D^*`B^&>F^&>N^&>E%PB(@H*(SH@9F]L9&5R<RYP:'`Z
M,CDT"FUS9VED(")(:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R("+AGIOAGK;A
MGH#AGXL@7"+AGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGH?AGK;AGIQ<(B(*
M"B,Z(&-O;7!O<V4N<&AP.C$R,#0*;7-G:60@(DAI9V@B"FUS9W-T<B`BX9Z!
MX9^2X9Z6X9Z?X9^+(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP
M.C@R."!M86EL8F]X+G!H<#HY-S<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FAT;6PZ,3`*;7-G:60@(DAI9V@@4')I;W)I='DB"FUS9W-T<B`BX9ZB
MX9ZVX9Z1X9ZWX9Z7X9ZVX9Z6XH"+X9Z!X9^2X9Z6X9Z?X9^+(@H*(SH@8V]M
M<&]S92YP:'`Z,3(P,PIM<V=I9"`B2&EG:&5S="(*;7-G<W1R("+AGH'AGY+A
MGI;AGI_AGXOB@(OAGI3AGX;AGI7AGKOAGH\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-CDW"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA
M>2!A='1A8VAM96YT<S\B"FUS9W-T<B`BX9Z/X9Z^XH"+X9ZBX9^2X9Z3X9Z`
MXH"+X9Z%X9Z$X9^+XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9ZOX9Z`X9Z?
MX9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z9X9^)X9ZVX9Z$XH"+
MX9Z*X9Z\X9Z%X9Z8X9^2X9Z/X9^!X9Z%PJ`_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P-0IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q=6]T960@
M;&EN97,@:6X@82!R97!L>2(*;7-G<W1R("+AGIKAGI3AGX#AGI3B@(OAGH#A
MGX;AGH[AGH_AGXOB@(OAGI3AGI/AGY+AGI'AGK;AGH_AGXOB@(OAGHKAGX+A
MGIOB@(OAGI3AGK;AGI/B@(OAGHKAGH#B@(OAGI_AGY+AGIKAGH3AGXL@X9Z`
MX9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z&X9^2X9Z;X9Z^X9Z9XH"+
MX9Z/X9Z4(@H*(SH@;&EB+TE-05`N<&AP.C$Y.0IM<V=I9"`B24U!4"(*;7-G
M<W1R("))34%0(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#<*;7-G
M:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B24U!
M4"`H075T;R!$971E8W0@4')O=&]C;VQS*2(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,SDQ"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@4V5R=F5R(&-L
M;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS
M9W-T<B`BX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^
M($E-05`@X9Z4X9ZVX9Z3XH"+X9Z4X9ZWX9Z1XH"+X9Z`X9ZVX9Z:XH"+X9Z/
MX9Z7X9^2X9Z'X9ZVX9Z4X9^+PJ#AGY0@X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3
MXH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+X9Z&X9^2X9Z;X9Z^
MX9Z9X9Z/X9Z4XH"+X9Z0X9ZVPJ#AGY8@)7,B"@HC.B!L:6(O24U!4"YP:'`Z
M,C$Q"FUS9VED("))34%0(&]V97(@4U-,(@IM<V=S='(@(DE-05`@X9Z;X9Z^
M(%-33"(*"B,Z(&QI8B])34%0+G!H<#HR,3<*;7-G:60@(DE-05`@;W9E<B!3
M4TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("))34%0(.&>
MF^&>OB!34TP@*.&>G.&>M^&>B>&?DN&>B>&>MN&>E.&>D^&>E.&>C^&?DN&>
MFN*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>A>&>N^&?A^*`B^&>H.&>
MC^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>BN&?A.&>F>*`B^&>@>&?DN&>F^&>
MO>&>D^*`B^&>K^&>A"DB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM
M<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(*;7-G
M<W1R("+AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGKX@
M24U!4"#AGI3AGK;AGI/B@(OAGI3AGK?AGI'B@(OAGH#AGK;AGIKB@(OAGH_A
MGI?AGY+AGH?AGK;AGI3AGXO"H.&?E"(*"B,Z(&QI8B])34%0+G!H<#HR,#4*
M;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R("))34%0(.&>@N&?DN&>F.&>
MMN&>DR!43%,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C0Y"FUS9VED
M("))34%0+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@(N&>F.&?B>&>MN&>
MG^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>G^&?AN&>E.&>N^&>
MC^&?DN&>FB!)34%0+U!/4#,B"@HC.B!L:6(O24U0+G!H<#HV-3<*;7-G:60@
M(DE.0D]8(@IM<V=S='(@(N&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>D>&>D>&>
MO>&>FR(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#$Q"FUS9VED("))9B!U
M<VEN9R!34TP@;W(@5$Q3+"!Y;W4@;75S="!H879E('1H92!02%`@;W!E;G-S
M;"!E>'1E;G-I;VX@;&]A9&5D+B(*;7-G<W1R("+AGI3AGK[B@(OAGI3AGY+A
MGIKAGKX@4U-,(.&>K"!43%,L(.&>HN&?DN&>D^&>@.*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>C^&?@N*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>D>&>N^&>@.*`
MB^&>E>&?DN&>D^&?@N&>@.*`B^&>E.&>D^&?DN&>D.&?@N&>F"!O<&5N<W-L
M(.&>FN&>E.&>G^&?BR!02%#"H.&?E"(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"FUS9VED("))9B!Y;W4@8V]N=&EN
M=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S
M="$B"FUS9W-T<B`BX9Z4X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9Z3X9^2
MX9Z/(.&>G^&>MN&>FN*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?B^*`B^&>D^&?
MA>*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>D.&>C^*`B^&>D^&>N>&>A.*`B^&>
MC^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>MN&>C^&?B^&>E.&>
MA.&?B\*@(2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FAT;6PZ
M,S8*;7-G:60@(DEG;F]R92(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+AGK[A
MGI;AGKXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C,W
M"FUS9VED("))9VYO<F4@06QL(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>HN&>
MON&>EN&>ON*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?BR(*"B,Z('-A=F5I;6%G
M92YP:'`Z-#8*;7-G:60@(DEM86=E(@IM<V=S='(@(N&>FN&>O.&>E.&>E^&>
MMN&>EB(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("));6%G97,@87)E(&)L;V-K960Z("5S('1O('!R;W1E
M8W0@>6]U<B!P<FEV86-Y+B`E<R(*;7-G<W1R("+AGIKAGKSAGI3AGI?AGK;A
MGI;B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI'AGI3AGXOA
MGI_AGY+AGH#AGK;AGH_AGXO"H.&?EB`E<R#AGHKAGK[AGICAGY+AGI3AGKCB
M@(OAGH#AGK;AGIKAGI;AGK;AGIKB@(OAGI?AGK;AGI;B@(OAGJ_AGH#AGH?A
MGI/B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"H.&?E"`E<R(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YH=&UL.C$V"FUS9VED("));7!O
M<G0B"FUS9W-T<B`BX9Z3X9ZVX9^&X9Z%X9Z\X9Z;(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O:6UP;W)T
M7VME>2YH=&UL.C0X"FUS9VED("));7!O<G0@2V5Y(@IM<V=S='(@(N&>D^&>
MMN&?AN&>A>&>O.&>F^*`B^&>@.&>O.&>D^&>G^&?A"(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,SD*;7-G:60@(DEM<&]R="!+97EP86ER(@IM<V=S
M='(@(N&>D^&>MN&?AN&>A>&>O.&>F^*`B^&>@N&>O.*`B^&>@.&>O.&>D^&>
MG^&?A"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:'1M;#HR.0IM
M<V=I9"`B26UP;W)T($UE<W-A9V5S(@IM<V=S='(@(N&>D^&>MN&?AN&>A>&>
MO.&>F^*`B^&>G^&>MN&>FB(*"B,Z('!G<"YP:'`Z,SD*;7-G:60@(DEM<&]R
M="!01U`@2V5Y(@IM<V=S='(@(N&>D^&>MN&?AN&>A>&>O.&>F^*`B^&>@.&>
MO.&>D^&>G^&?A.*`B^&>FN&>E.&>G^&?BR!01U`B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.CDQ"FUS9VED("));7!O<G0@4&5R<V]N86P@0V5R
M=&EF:6-A=&4B"FUS9W-T<B`BX9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z<X9ZW
MX9Z)X9^2X9Z)X9ZVX9Z4X9Z3X9Z4X9Z/X9^2X9Z:XH"+X9Z5X9^2X9Z1X9ZV
MX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FAT;6PZ,3$*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV
M871E(%!'4"!+97DB"FUS9W-T<B`BX9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z`
MX9Z\X9Z3X9Z?X9^$(%!'4"#AGJ_AGH#AGH?AGI/B@(OAGI7AGY+AGI'AGK;A
MGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI,B"@HC.B!T96UP;&%T97,O<&=P+VEM
M<&]R=%]K97DN:'1M;#HQ.`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>2!(97)E.B(*;7-G<W1R("+AGI/AGK;AGX;AGH7AGKSAGIOB
M@(OAGH#AGKSAGI/AGI_AGX0@4$=0(.&>K^&>@.&>A^&>D^*`B^&>E>&?DN&>
MD>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DR#AGI/AGX7B@(OAGI'AGKCA
MGI/AGX'AGX?"H.&?EB(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y
M+FEN8SHT"FUS9VED("));7!O<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC
M871E<R(*;7-G<W1R("+AGI/AGK;AGX;AGH7AGKSAGIOB@(OAGISAGK?AGHGA
MGY+AGHGAGK;AGI3AGI/AGI3AGH_AGY+AGIH@4R]-24U%(.&>E>&?DN&>D>&>
MMN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DR(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS9VED
M("));7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("+AGI/AGK;AGX;AGH7AGKSA
MGIOB@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGX@B
M"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:'1M;#HQ,0IM<V=I9"`B
M26UP;W)T(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(N&>D^&>MN&?AN&>A>&>
MO.&>F^*`B^&>@.&>O.&>D^&>G^&?A"!01U`@X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.
MX9^((@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FAT;6PZ,3@*;7-G
M:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2!(97)E.B(*;7-G<W1R("+AGI/A
MGK;AGX;AGH7AGKSAGIOB@(OAGH#AGKSAGI/AGI_AGX0@4$=0(.&>G^&>MN&>
MDN&>MN&>FN&>CN&?B"#AGI/AGX7B@(OAGI'AGKCAGI/AGX'AGX?"H.&?EB(*
M"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX"FUS9VED("))
M;7!O<G0@4'5B;&EC(%,O34E-12!+97DB"FUS9W-T<B`BX9Z3X9ZVX9^&X9Z%
MX9Z\X9Z;XH"+X9Z`X9Z\X9Z3X9Z?X9^$(%,O34E-12#AGI_AGK;AGI+AGK;A
MGIKAGH[AGX@B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)
M344@2V5Y(@IM<V=S='(@(N&>D^&>MN&?AN&>A>&>O.&>F^*`B^&>@.&>O.&>
MD^&>G^&?A"!3+TU)344B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N
M:'1M;#HV"FUS9VED("));7!O<G0@;6)O>"!&:6QE(@IM<V=S='(@(N&>D^&>
MMN&?AN&>A>&>O.&>F^*`B^&>K^&>@.&>G^&>MN&>FB!M8F]X(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FAT;6PZ,3$*;7-G:60@(DEM<&]R="!M
M8F]X(&9I;&4B"FUS9W-T<B`BX9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9ZOX9Z`
MX9Z?X9ZVX9Z:(&UB;W@B"@HC.B!M97-S86=E+G!H<#HT-S0@;6%I;&)O>"YP
M:'`Z.#,V(&UA:6QB;W@N<&AP.CDW,@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:'1M;#HW('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYH=&UL.C$S"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.C(X
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YH=&UL.C4*;7-G:60@(DEM<&]R
M=&%N="(*;7-G<W1R("+AGI_AGX;AGH'AGK;AGI/AGXLB"@HC.B!S96%R8V@N
M<&AP.C,S-`IM<V=I9"`B26UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(N&>
MG^&>MN&>FN*`B^&>G^&?AN&>@>&>MN&>D^&?BR(*"B,Z(&9O;&1E<G,N<&AP
M.C$Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"`E9"!M97-S86=E
M<R!F<F]M("5S+B(*;7-G<W1R("+AGI3AGK;AGI/B@(OAGI/AGK;AGX;AGH7A
MGKSAGIOB@(OAGI_AGK;AGIH@)60@X9Z6X9ZX("5SPJ#AGY0B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S8V"FUS9VED("));B!0<F]C97-S(@IM
M<V=S='(@(N&>G^&?DN&>D.&>M^&>C^*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>
MBN&?AN&>CN&>ON&>FN&>@.&>MN&>FB(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M;FET:6%L<&%G97-E;&5C="YI;F,Z,30@;&EB+T9O;&1E<BYP:'`Z.#8*(SH@
M;&EB+T9O;&1E<BYP:'`Z,C$Q(&QI8B])35`N<&AP.C,P."!L:6(O24U!4"]4
M<F5E+G!H<#HQ,3`*(SH@;&EB+TE-05`O5')E92YP:'`Z,C$S(&QI8B])34%0
M+U1R964N<&AP.C,U.0IM<V=I9"`B26YB;W@B"FUS9W-T<B`BX9Z4X9^2X9Z:
MX9ZBX9Z4X9^+XH"+X9Z1X9Z1X9Z]X9Z;(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y,PIM<V=I9"`B26YC;'5D92!A(&)R:65F('-U;6UA<GD@;V8@
M=&AE(&AE861E<B!I;B!A(')E<&QY/R(*;7-G<W1R("+AGIKAGKWAGICB@(OA
MGI3AGHGAGY+AGH7AGKSAGIOB@(OAGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OA
MGI_AGH3AGY+AGH'AGX'AGI3B@(OAGH'AGY+AGIOAGKCB@(OAGIKAGI3AGI_A
MGXOB@(OAGI3AGHOAGICAGH#AGI#AGK;B@(OAGH#AGY+AGI/AGKOAGH3B@(OA
MGH#AGK;AGIKB@(OAGH;AGY+AGIOAGK[AGIGB@(OAGH_AGI3"H#\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@X"FUS9VED("));F-L=61E(&]R:6=I
M;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B"FUS9W-T<B`BX9Z:X9Z]X9Z8XH"+
MX9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z?X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z7
MX9Z6XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z&X9^2X9Z;
MX9Z^X9Z9XH"+X9Z/X9Z4PJ`_(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3,R
M"FUS9VED("));F9O(@IM<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>DR(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(DEN9F]R;6%T:6]N
M(&]N("5S(%!U8FQI8R!+97DB"FUS9W-T<B`BX9Z6X9^0X9Z/X9^,X9Z8X9ZV
MX9Z3XH"+X9ZBX9^&X9Z6X9ZXXH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZV
MX9Z2X9ZVX9Z:X9Z.X9^(XH"+("5S(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C<W"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0<FEV871E
M($ME>2(*;7-G<W1R("+AGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGJ+AGX;A
MGI;AGKCB@(OAGH#AGKSAGI/AGI_AGX3B@(OAGJ_AGH#AGH?AGI/B@(OAGI7A
MGY+AGI'AGK;AGIOAGXOAGH'AGY+AGIOAGKWAGI,B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM
M<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G
M<W1R("+AGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGJ+AGX;AGI;AGKCB@(OA
MGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGXCB@(OAGI7A
MGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI,B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]J879A<V-R:7!T+FEN8SHR-#,@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YH=&UL.C(W,`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FAT;6PZ,S(V"FUS9VED("));FQI;F4B"FUS9W-T<B`BX9Z`X9^2X9Z3
MX9Z[X9Z$XH"+X9Z/X9Z](@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K
M97DN:6YC.CD*;7-G:60@(DEN<V5R="!#97)T:69I8V%T92!(97)E(@IM<V=S
M='(@(N&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>G.&>M^&>B>&?DN&>B>&>MN&>
ME.&>D^&>E.&>C^&?DN&>FN*`B^&>D>&>N.&>D^&?@>&?AR(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT,3,*;7-G:60@(DEN=F%L:60@06-T:6]N
M('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`BX9ZBX9^&
MX9Z6X9Z^XH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z'X9^2X9Z:X9Z^
MX9Z?XH"+(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>G^&>F.&>MN&>G^&>
ME^&>MN&>@N*`B^&>D^&?@>&?A\*@X9^4(@H*(SH@;6%I;&)O>"YP:'`Z-S(T
M(&UA:6QB;W@N<&AP.C<V-@IM<V=I9"`B26YV86QI9"!!9&1R97-S(@IM<V=S
M='(@(N&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>F.&>M^&>D^*`
MB^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G"(*"B,Z(&QI8B]&971C
M:&UA:6PO:6UA<"YP:'`Z,C8Q"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL
M8F]X(@IM<V=S='(@(N&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>
MN^&>C^&?DN&>FN*`B^&>AN&?DN&>A.&>MN&>F>*`B^&>F.&>M^&>D^*`B^&>
MC^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G"(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ,#,V"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@8VAA<F%C
M=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`BX9Z/X9Z]XH"+
MX9ZBX9Z`X9^2X9Z?X9Z:XH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9ZYX9Z8
MX9Z/X9^2X9Z:X9Z\X9Z<(.*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>HN&>MN&>
MG^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>F\*@X9^6
M("5SPJ#AGY0B"@HC.B!S;6EM92YP:'`Z-S@@<&=P+G!H<#HQ-@IM<V=I9"`B
M26YV86QI9"!K97DB"FUS9W-T<B`BX9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z8X9ZW
MX9Z3XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$Y-PIM<V=I9"`B26YV86QI9"!M97-S86=E+"!C86X@
M;F]T(')E<W5M92!D<F%F="XB"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z8X9ZW
MX9Z3XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<+"#AGICAGK?A
MGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGI/AGY+AGH_B@(OAGI_AGX'AGH7AGH#A
MGY+AGHKAGKCB@(OAGI;AGY+AGIKAGK;AGH0B"@HC.B!P9W`N<&AP.C(P,@IM
M<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN(@IM<V=S
M='(@(N&>@.&>O.&>D^&>G^&?A.*`B^&>K^&>@.&>A^&>DR!01U`@X9Z5X9^2
MX9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3XH"+X9Z8X9ZWX9Z3X9Z/
MX9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<PJ#AGY0B"@HC.B!P9W`N<&AP
M.C$W-PIM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB
M"FUS9W-T<B`BX9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.
MX9^(XH"+(%!'4"#AGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWA
MGI/B@(OAGICAGK?AGI/AGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSAGIS"
MH.&?E"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.CD*;7-G
M:60@(DEN=F5R="(*;7-G<W1R("+AGHKAGK;AGH#AGXOAGI3AGHGAGY+AGH7A
MGY+AGIKAGK;AGI\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT
M;6PZ,S$T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HS-#D*;7-G
M:60@(DM"(@IM<V=S='(@(DM"(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$Q,PIM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("+AGI3AGY+AGIKAGISA
MGX+AGH3B@(OAGH#AGKSAGI/AGI_AGX0B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K92!A
M(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y("(*
M(F=E;F5R871I;VX_(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>E.&>A.&?DN&>
M@.&>ON&>C^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>HN&>MN&>A>*`B^&>D^&>
MN>&>A.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>@.&>MN&>FN*`B^&>FN&>F>&?
MB.&>EN&?@>&>F^*`B^&>F>&>O.&>FL*@X9^4("#AGI3AGI/AGY+AGH_B@(OA
MGI3AGH3AGY+AGH#AGK[AGH_B@(OAGH#AGKSAGI/AGI_AGX3"H#\B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&
M:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BXB"FUS
M9W-T<B`B(@HBX9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z`X9ZVX9Z:XH"+
MX9Z3X9ZVX9^&X9Z%X9Z\X9Z;XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZAX9Z^
MX9Z9PJ#AGY0@X9Z`X9ZVX9Z:XH"+X9Z1X9ZVX9Z)X9Z9X9Z`XH"+X9ZOX9Z`
MX9Z?X9ZVX9Z:(.&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>E.&?DN&>FN&>
MON*`B^&>E.&>MN&>D^*`B^&>H>&>ON&>F>*`B^&>F^&>ON*`B^&>F.&?B>&>
MMN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>D^&?@>&?A\*@
MX9^4(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS-R!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,SD*;7-G:60@(B(*(DME>2!I;7!O<G0@:7,@;F]T
M(&%V86EL86)L92X@66]U(&AA=F4@;F\@861D<F5S<R!B;V]K(&1E9FEN960@
M=&\@861D('EO=7(@(@HB8V]N=&%C=',N(@IM<V=S='(@(B(*(N&>F.&>M^&>
MD^*`B^&>F.&>MN&>D^*`B^&>@.&>MN&>FN*`B^&>D^&>MN&?AN&>A>&>O.&>
MF^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>H>&>ON&>F<*@X9^4(.&>HN&?DN&>
MD^&>@.*`B^&>F.&>M^&>D^*`B^&>E.&>MN&>D^*`B^&>@.&?AN&>CN&>C^&?
MB^*`B^&>G^&?@.&>G.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>
MMN&>DR#AGHKAGK[AGICAGY+AGI3AGKCB@(OAGI3AGI/AGY+AGI#AGX+AGICB
M@(OAGI'AGX;AGI/AGK;AGH#AGXOB@(OAGI'AGX;AGI/AGH3B@(OAGIKAGI3A
MGI_AGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGJ'AGK[AGIG"H.&?E"(*"B,Z('!G
M<"YP:'`Z,S(T"FUS9VED(")+97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(N&>@.&>O.&>D^&>G^&?A.*`
MB^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E>&?DN&>B>&>ON*`
MB^&>BN&?A.&>F>*`B^&>A^&?A.&>@N*`B^&>A^&?D.&>F2#B@(OAGI'AGX7B
M@(OAGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OA
MGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGXC"H.&?E"(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYH=&UL.C$Q,PIM<V=I9"`B3&%N
M9W5A9V4B"FUS9W-T<B`BX9Z7X9ZVX9Z?X9ZV(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ-PIM<V=I9"`B3&%S="!-86EL8F]X(%!A9V4B"FUS9W-T
M<B`BX9Z1X9^&X9Z6X9^0X9Z:XH"+X9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?
MX9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z%X9Z[X9Z$XH"+X9Z`X9^2X9Z:X9^$
MX9Z9(@H*(SH@;6%I;&)O>"YP:'`Z-#0T"FUS9VED("),87-T(%!A9V4B"FUS
M9W-T<B`BX9Z1X9^&X9Z6X9^0X9Z:XH"+X9Z%X9Z[X9Z$XH"+X9Z`X9^2X9Z:
MX9^$X9Z9(@H*(SH@8V]M<&]S92YP:'`Z,3,R-PIM<V=I9"`B3&EN:R!!='1A
M8VAM96YT<S\B"FUS9W-T<B`BX9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9ZO
MX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+PJ`_(@H*(SH@871T
M86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C(R,34*;7-G:60@(DQI
M;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R("+AGJ_A
MGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGJ#AGK;AGICAGH/AGK;AGH_AGXO"H.&?
ME"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C,Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DQI;FMS('=I;&P@97AP:7)E(&]N("5S(@IM<V=S='(@(N&>C^&?AN&>
MCN*`B^&>D^&>N>&>A.*`B^&>E>&>N^&>C^&>@.&?AN&>CN&>C^&?B^*`B^&>
MD^&?A2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#DS"FUS9VED
M("(B"B),:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I;F<@=&AE(&-O;G1A
M8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL;"`B"B)O;FQY('-E
M92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X<&QI8VET;'DI(@IM
M<V=S='(@(B(*(N&>FN&>MN&>F>*`B^&>@.&>MN&>FN*`B^&>D>&>MN&>@.&?
MB^*`B^&>D>&>A.*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?BR#AGI;AGX'AGIOB
M@(OAGI7AGY+AGI'AGKOAGH#B@(OAGJ+AGX'AGH#AGY+AGIKAGH3AGXOB@(OA
MGH#AGK;AGIKB@(OAGI'AGK;AGH#AGXOAGI'AGH3"H#\@*.&>E.&?DN&>FN&>
MG^&>M^&>D^*`B^&>E.&>ON*`B^&>HN&>G^&>@.&>F.&?DN&>F"#AGJ+AGY+A
MGI/AGH#B@(OAGI/AGKGAGH3B@(OAGH/AGK[AGHGB@(OAGH_AGX+B@(OAGH#A
MGK;AGIKB@(OAGI'AGK;AGH#AGXOB@(OAGI'AGH3B@(OAGHKAGX+AGIOB@(LB
M"B+AGJ+AGY+AGI/AGH#AGI_AGY+AGISAGX+AGH3AGIKAGH#B@(OAGIGAGXGA
MGK;AGH3B@(OAGH?AGK;AGH#AGXOB@(OAGIOAGK;AGH#AGXLI(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8Y-`IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@
M2&5A9&5R(@IM<V=S='(@(N&>FN&>MN&>F>*`B^&>@.&?DN&>D^&>N^&>A.*`
MB^&>E.&>B^&>F.&>@.&>D.&>MB(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHS,`IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`B
MX9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+
MX9Z8X9Z\X9Z;X9Z*X9^2X9Z+X9ZVX9Z3PJ#AGY8B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C<Q"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("+A
MGI'AGKCAGH_AGK;AGX;AGH0B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,3`T"B,L('!H<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G<W1R
M("+AGH7AGKSAGIOB@(OAGI'AGX4@)7,B"@HC.B!L;V=I;BYP:'`Z,S4R"FUS
M9VED("),;V=I;B(*;7-G<W1R("+AGH7AGKSAGILB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(N&>
ME^&>MN&>FN&>@.&>M^&>A>&?DN&>A>*`B^&>A>&>O.&>FR(*"B,Z(&-O;7!O
M<V4N<&AP.C$R,#8*;7-G:60@(DQO=R(*;7-G<W1R("+AGI'AGK;AGI0B"@HC
M.B!M97-S86=E+G!H<#HR-C8@;6%I;&)O>"YP:'`Z.#,Q(&UA:6QB;W@N<&AP
M.CDW.`HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:'1M;#HQ,0IM<V=I
M9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(N&>HN&>MN&>D>&>M^&>E^&>MN&>
MEN*`B^&>D>&>MN&>E"(*"B,Z(&-O;7!O<V4N<&AP.C$R,#<*;7-G:60@(DQO
M=V5S="(*;7-G<W1R("+AGI'AGK;AGI3B@(OAGI3AGX;AGI7AGKOAGH\B"@HC
M.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0T"FUS9VED(")-
M86-I;G1O<V@@1FEL92(*;7-G<W1R("+AGJ_AGH#AGI_AGK;AGIH@36%C:6YT
M;W-H(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"FUS
M9VED(")-86EL(@IM<V=S='(@(N&>G^&?AN&>E.&>N^&>C^&?DN&>FB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B36%I;"!0<F5V:65W
M<R(*;7-G<W1R("+AGICAGK[AGIOB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB
M@(OAGH?AGK;B@(OAGICAGKOAGI,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V1R:79E<E]S96QE8W0N:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E
M('1O(&-O;FYE8W0@=&\Z(@IM<V=S='(@(N&>E.&?DN&>FN&>E^&?@>&>D>*`
MB^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>
MG^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>D>&?A>*`B^&>@.&>MN&>
MD^&?B\*@X9^6(@H*(SH@;&EB+TE-05`O5')E92YP:'`Z,S8U(&QI8B])34%0
M+U1R964N<&AP.C,Y,PIM<V=I9"`B36%I;&)O>"(*;7-G<W1R("+AGI3AGY+A
MGIKAGJ+AGI3AGXOB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS9VED(")-86EL8F]X(&%N9"!&;VQD
M97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(N&>A^&>F.&?DN&>FN&>ON&>
MG^*`B^&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`
MB^&>G^&?AN&>E.&>N^&>C^&?DN&>FB#AGI/AGK?AGH0@X9Z0X9Z/(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH=&UL.C(P"FUS9VED(")-87)K
M($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G<W1R("+AGI_A
MGICAGY+AGH+AGK;AGIOAGXOB@(OAGI_AGK;AGIKB@(OAGI'AGK;AGX;AGH3A
MGJ+AGI_AGXOB@(L@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z0X9Z/XH"+X9Z0X9ZV
MXH"+X9Z4X9ZVX9Z3XH"+X9Z8X9Z^X9Z;(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYH=&UL.C(Q"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I
M;B!&;VQD97(@87,@56YS965N(@IM<V=S='(@(N&>G^&>F.&?DN&>@N&>MN&>
MF^&?B^*`B^&>G^&>MN&>FN*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?B^*`B^&>
M@.&?DN&>D^&>N^&>A.*`B^&>D.&>C^&>D.&>MB!<(N&>F.&>M^&>D^*`B^&>
ME.&>MN&>D^*`B^&>F.&>ON&>FUPB(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FAT;6PZ-2!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:'1M;#HR-0IM<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`BX9Z?X9Z8X9^2
MX9Z"X9ZVX9Z;X9^+XH"+X9Z'X9ZVPJ#AGY8B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C4P"FUS9VED(")-87)K(&1I9F9E<F5N="!L979E;',@;V8@
M<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_(@IM<V=S='(@(N&>G^&>
MF.&?DN&>@N&>MN&>F^&?B^*`B^&>@.&>F.&?DN&>FN&>M^&>C^*`B^&>@>&>
MN^&>G^&?E^*`B^&>@N&?DN&>D^&>MN*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>
MF.&?DN&>FN&>A.&?BR#AGHKAGX3AGIGB@(OAGI;AGH[AGXSB@(OAGH'AGKOA
MGI_B@(OAGH+AGY+AGI/AGK;"H#\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@
M*$E-05`@;VYL>2DB"FUS9W-T<B`BX9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+XH"+
MX9Z?X9ZVX9Z:XH"+X9Z'X9ZV(%PBX9Z4X9ZVX9Z3XH"+X9Z8X9Z^X9Z;7"(@
MX9ZLPJ`_("CAGH_AGX(@24U!4"DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C4X"FUS9VED(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(N&>
MG^&>F.&?DN&>@N&>MN&>F^&?B^*`B^&>@.&>MN&>FN*`B^&>C^&>F.&?DN&>
MF^&>ON&>A.*`B^&>C^&>F.&?DN&>F^&?@^*`B^&>G^&>MN&>F.&>B>&?DN&>
MB<*@/R(*"B,Z('-E87)C:"YP:'`Z,C(V"FUS9VED(")-871C:"!!;&P@475E
M<FEE<R(*;7-G<W1R("+AGHKAGKSAGH7B@(OAGI_AGX;AGH[AGKWAGIKB@(OA
MGI'AGK;AGX;AGH3AGJ+AGI_AGXLB"@HC.B!S96%R8V@N<&AP.C(R-`IM<V=I
M9"`B36%T8V@@06YY(%%U97)Y(@IM<V=S='(@(N&>BN&>O.&>A>*`B^&>G^&?
MAN&>CN&>O>&>FN*`B^&>CN&>MN&>F.&>O>&>F2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:'1M;#HR-S8*;7-G:60@(DUA>&EM=6T@071T86-H
M;65N="!3:7IE(@IM<V=S='(@(N&>D>&?AN&>H.&?AN*`B^&>K^&>@.&>G^&>
MMN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>HN&>C^&>M^&>E.&>FN&>
MF.&>MB(*"B,Z(&QI8B]A<&DN<&AP.C@T"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!&;VQD97)S(@IM<V=S='(@(N&>A>&?AN&>D^&>O>&>D^*`B^&>D.&>
MC^*`B^&>HN&>C^&>M^&>E.&>FN&>F.&>MB(*"B,Z(&QI8B]A<&DN<&AP.C@W
M"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!296-I<&EE;G1S('!E<B!-97-S
M86=E(@IM<V=S='(@(N&>A>&?AN&>D^&>O>&>D^*`B^&>HN&?DN&>D^&>@.*`
MB^&>D>&>D>&>O>&>F^*`B^&>HN&>C^&>M^&>E.&>FN&>F.&>MN*`B^&>@.&?
MDN&>D^&>N^&>A.*`B^&>G^&>MN&>FN*`B^&>F.&>O>&>F2(*"B,Z(&QI8B]A
M<&DN<&AP.CDP"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!296-I<&EE;G1S
M('!E<B!4:6UE(%!E<FEO9"(*;7-G<W1R("+AGH7AGX;AGI/AGKWAGI/B@(OA
MGJ+AGY+AGI/AGH#B@(OAGI'AGI'AGKWAGIOB@(OAGH7AGY+AGIKAGK[AGI/B
M@(OAGI3AGX;AGI7AGKOAGH_B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGICAGKWA
MGIGB@(OAGIKAGIGAGXCAGI;AGX'AGILB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FAT;6PZ,C4X"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A
M='1A8VAM96YT<R!R96%C:&5D+B(*;7-G<W1R("+AGI3AGK;AGI/B@(OAGICA
MGH#B@(OAGHKAGIOAGXOB@(OAGH#AGICAGY+AGIKAGK?AGH_B@(OAGI/AGX/B
M@(OAGH7AGX;AGI/AGKWAGI/B@(OAGJ+AGH_AGK?AGI3AGIKAGICAGK;B@(OA
MGIKAGI3AGI_AGXOAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3A
MGXO"H.&?E"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HR
M-3,*;7-G:60@(DUA>&EM=6T@=&]T86P@871T86-H;65N="!S:7IE(')E86-H
M960N(@IM<V=S='(@(N&>E.&>MN&>D^*`B^&>F.&>@.*`B^&>BN&>F^&?B^*`
MB^&>@.&>F.&?DN&>FN&>M^&>C^*`B^&>D^&?@^*`B^&>D>&?AN&>H.&?AN*`
MB^&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>G^&>
MFN&>N^&>E.&>HN&>C^&>M^&>E.&>FN&>F.&>MB(*"B,Z(&QI8B]";&]C:R]T
M<F5E7V9O;&1E<G,N<&AP.C,*;7-G:60@(DUE;G4@1F]L9&5R($QI<W0B"FUS
M9W-T<B`BX9Z4X9Z)X9^2X9Z'X9ZXXH"+X9Z0X9Z/XH"+X9Z8X9^)X9ZZX9Z3
MX9Z[X9Z9(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$S.3,*;7-G:60@(DUE<W-A
M9V4B"FUS9W-T<B`BX9Z?X9ZVX9Z:(@H*(SH@8V]M<&]S92YP:'`Z,S,Q(&-O
M;7!O<V4N<&AP.C,U."!C;VUP;W-E+G!H<#HS-C<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P"FUS9VED(")-97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@
M(N&>@.&>MN&>FN*`B^&>C^&?@N&>A.*`B^&>G^&>MN&>FB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,C@*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G
M<W1R("+AGH#AGK;AGIOB@(OAGI3AGIKAGK?AGH7AGY+AGH;AGX'AGI'B@(OA
MGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIHB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YH=&UL.C$Q,@IM<V=I9"`B365S<V%G92!&;&%G<R(*;7-G<W1R
M("+AGI'AGH3AGXOB@(OAGI_AGK;AGIHB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YH=&UL.C$S-PIM<V=I9"`B365S<V%G92!&;VQD97)S(@IM<V=S
M='(@(N&>D.&>C^*`B^&>G^&>MN&>FB(*"B,Z('1E;7!L871E<R]S96%R8V@O
M<V5A<F-H+FAT;6PZ,S,*;7-G:60@(DUE<W-A9V4@36%T8VAE<R(*;7-G<W1R
M("+AGHKAGX;AGH[AGKSAGH7B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#D@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#@@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#0*;7-G:60@(DUE<W-A9V4@3W!T:6]N
M<R(*;7-G<W1R("+AGH?AGICAGY+AGIKAGK[AGI_B@(OAGIKAGI3AGI_AGXOB
M@(OAGI_AGK;AGIHB"@HC.B!S96%R8V@N<&AP.C0P-@IM<V=I9"`B365S<V%G
M92!396%R8V@B"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z?X9^2X9Z<X9^"X9Z$
MXH"+X9Z:X9Z`X9Z?X9ZVX9Z:(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDS,@IM<V=I9"`B365S<V%G92!3:7IE(@IM<V=S='(@(N&>D>&?AN&>H.&?
MAN*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>FB(*"B,Z(&UE<W-A9V4N<&AP
M.C4W.`IM<V=I9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`BX9Z4X9^2X9Z:
MX9Z7X9Z6XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8V"FUS9VED(")-97-S86=E(%9I97=I;F<B"FUS
M9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z8X9Z^X9Z;XH"+X9Z?X9ZVX9Z:(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$S.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B365S
M<V%G92!F<F]M("5S(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>EN&>N"`E<R(*
M"B,Z(&UA:6QB;W@N<&AP.C@V-@IM<V=I9"`B365S<V%G92!H87,@871T86-H
M;65N=',B"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z8X9ZVX9Z3XH"+X9ZOX9Z`
MX9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+(@H*(SH@;6%I;&)O>"YP
M:'`Z.#4X"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E9"(*;7-G<W1R("+A
MGI_AGK;AGIKB@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3A
MGICAGY+AGIOAGX+AGH3B@(OAGH?AGK;B@(OAGH#AGKSAGHHB"@HC.B!M86EL
M8F]X+G!H<#HX-30*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@
M(N&>G^&>MN&>FN*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
MA>&>N^&?A^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MB(*"B,Z(&-O;7!O<V4N
M<&AP.C0W-"!C;VUP;W-E+G!H<#HT.#$*;7-G:60@(DUE<W-A9V4@<F5D:7)E
M8W1E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>
MD>&>M^&>G^*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F<*@X9^4
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C8V,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O
M("5S(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>
ME.&>MN&>D^*`B^&>E>&?DN&>B>&>ON*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>
M@N*`B^&>A^&?D.&>F2#AGI3AGXGAGKOAGI/AGY+AGH_AGX+B@(OAGICAGK?A
MGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIKAGH#AGY+A
MGI_AGK;B@(OAGI'AGKOAGH#B@(OAGI'AGX4@)7,B"@HC.B!C;VUP;W-E+G!H
M<#HU-#(@8V]M<&]S92YP:'`Z-34P"FUS9VED(")-97-S86=E('-E;G0@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGI7AGY+AGHGAGK[B@(OAGHKAGX3AGIGB@(OA
MGH?AGX3AGH+B@(OAGH?AGY#AGIG"H.&?E"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-3(*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H92!M
M86EL8F]X('9I97<N(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>@.&?DN&>D^&>
MN^&>A.*`B^&>F.&>O>&>F>*`B^&>D>&?AN&>EN&?D.&>FB#AGH#AGY+AGI/A
MGKOAGH3B@(OAGI'AGK?AGHKAGY+AGHOAGI?AGK;AGI;B@(OAGI3AGY+AGIKA
MGJ+AGI3AGXOB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(O"H.&?E"(*"B,Z
M(&UA:6QB;W@N<&AP.C(T-0IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B
MX9Z?X9ZVX9Z:XH"+X9Z1X9^%XH"+X9Z`X9ZVX9Z3X9^+(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB"FUS9W-T<B`BX9Z`
MX9^"X9Z4X9^2X9Z:X9^"(@H*(SH@97AP86YD+G!H<#HT,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-;W)E('1H86X@;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I
M96QD(%PB)7-<(BXB"FUS9W-T<B`BX9Z4X9ZVX9Z3XH"+X9Z:X9Z`X9Z#X9Z^
MX9Z)XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z%X9^2X9Z:
MX9Z^X9Z3XH"+X9Z'X9ZVX9Z$XH"+X9Z8X9Z]X9Z9(.&>G^&>F.&?DN&>FN&>
MMN&>E.&?B^*`B^&>G.&>MN&>FR!<(B5S7"+"H.&?E"(*"B,Z(&UE<W-A9V4N
M<&AP.C4P,R!M97-S86=E+G!H<#HV.34@;6%I;&)O>"YP:'`Z-#$Y(&UA:6QB
M;W@N<&AP.CDY-PIM<V=I9"`B36]V92(*;7-G<W1R("+AGI7AGY+AGIOAGK;A
MGI_AGXOB@(OAGI'AGK@B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHS,38*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("+AGH7AGKOA
MGX?B@(OAGH#AGY+AGIKAGX3AGI@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C$X"FUS9VED(")-;W9E('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD
M97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(N&>
ME>&?DN&>F^&>MN&>G^&?B^&>D>&>N.*`B^&>G^&>MN&>FN*`B^&>I>&>C^*`
MB^&>E.&>MN&>D^*`B^&>@.&>MN&>FN*`B^&>D>&?A>*`B^&>D.&>C^*`B^&>
MG^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FB#AGJ#A
MGK[AGIGB@(OAGI7AGY+AGIOAGK;AGI_AGXOAGI'AGKCB@(OAGI_AGK;AGIKB
M@(OAGIOAGY+AGJ+B@(OAGI'AGX7B@(OAGI3AGY+AGIKAGJ+AGI3AGXOB@(OA
MGI'AGI'AGKWAGILB"@HC.B!M97-S86=E+G!H<#HU,#,@;65S<V%G92YP:'`Z
M-CDU(&UA:6QB;W@N<&AP.C0Q.2!M86EL8F]X+G!H<#HY.3<*;7-G:60@(DUO
M=F4@=&\@9F]L9&5R(@IM<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>
MD>&>N.*`B^&>D.&>CR(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,Q-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("+AGJ'AGK[AGH3B
M@(OAGIOAGKXB"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP
M.C$R.`IM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@(N&>
MA>&?DN&>FN&>ON&>D^*`B^&>E>&?DN&>D^&?@N&>@"_AGH;AGY+AGIOAGK;A
MGI_AGXLB"@HC.B!T:')E860N<&AP.C<U('1H<F5A9"YP:'`Z,34T"FUS9VED
M(")-=6QT:7!L92!-97-S86=E(%9I97<B"FUS9W-T<B`BX9Z1X9ZWX9Z*X9^2
MX9Z+X9Z7X9ZVX9Z6XH"+X9Z?X9ZVX9Z:XH"+X9Z%X9^2X9Z:X9Z^X9Z3(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C@*
M;7-G:60@(DY/3D4B"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I
M9"`B3D]412(*;7-G<W1R("+AGH7AGX;AGH[AGK;AGX8B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C@S('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYH=&UL.C4X"FUS9VED(").86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?
MA.&?AR(*"B,Z('!G<"YP:'`Z,3$V"FUS9VED(").86UE(&%N9"]O<B!E;6%I
M;"!C86YN;W0@8F4@96UP='DB"FUS9W-T<B`BX9Z(X9^2X9Z8X9^$X9^'(.&>
MD^&>M^&>A"_AGJP@X9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z8X9ZWX9Z3XH"+
MX9ZBX9ZVX9Z%XH"+X9Z1X9Z1X9^!XH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,0IM<V=I9"`B3F5E
M9',@06-T:6]N(@IM<V=S='(@(N&>C^&?DN&>FN&>O.&>G.*`B^&>@.&>MN&>
MFN*`B^&>HN&?AN&>EN&>OB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y,`IM<V=I9"`B3F5V97(B"FUS
M9W-T<B`BX9Z`X9Z[X9^&(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W
M,@IM<V=I9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R("+AGH#A
MGKOAGX;B@(OAGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGJ_AGH#A
MGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXLB"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`BX9Z0X9^2X9Z8
MX9ZX(@H*(SH@;&EB+TE-4"YP:'`Z-#(X"FUS9VED(").97<@1F]L9&5R(@IM
M<V=S='(@(N&>D.&>C^*`B^&>D.&?DN&>F.&>N"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.0IM<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`BX9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9^2X9Z8X9ZX(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(V(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-PHC.B!L
M:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS,0IM<V=I9"`B3F5W($UE<W-A
M9V4B"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZX(@H*(SH@;6%I
M;&)O>"YP:'`Z.3$Y(&QI8B]-24U%+TAE861E<G,N<&AP.C$Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("+AGI_A
MGK;AGIKB@(OAGI#AGY+AGICAGKCB@(OAGI'AGX4@)7,B"@HC.B!S96%R8V@N
M<&AP.C,R-0IM<V=I9"`B3F5W(&UE<W-A9V5S(@IM<V=S='(@(N&>G^&>MN&>
MFN*`B^&>D.&?DN&>F.&>N"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FAT;6PZ-S,*;7-G:60@(DYE>'0B"FUS9W-T<B`BX9Z4X9Z3X9^2X9Z1
MX9ZVX9Z4X9^+(@H*(SH@;65S<V%G92YP:'`Z-3(Q(&UE<W-A9V4N<&AP.C<P
M,@IM<V=I9"`B3F5X="!-97-S86=E(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>
ME.&>D^&?DN&>D>&>MN&>E.&?BR(*"B,Z(&UA:6QB;W@N<&AP.C0T,@IM<V=I
M9"`B3F5X="!086=E(@IM<V=S='(@(N&>D>&?AN&>EN&?D.&>FN*`B^&>E.&>
MD^&?DN&>D>&>MN&>E.&?BR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,S`@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX.`HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FAT;6PZ,CDV"FUS9VED(").;R(*;7-G<W1R("+AGH+A
MGY+AGICAGK;AGI,B"@HC.B!S;6EM92YP:'`Z,C(R"FUS9VED(").;R!#97)T
M:69I8V%T92!F;W5N9"(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI/B@(OAGISA
MGK?AGHGAGY+AGHGAGK;AGI3AGI/AGI3AGH_AGY+AGIKB@(OAGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGIKAGH#AGH/AGK[AGHDB"@HC.B!L:6(O
M24U0+G!H<#HQ,S$S"FUS9VED(").;R!%;F-R>7!T:6]N(@IM<V=S='(@(N&>
M@N&?DN&>F.&>MN&>D^*`B^&>@.&>MN&>FN*`B^&>E.&>F.&?DN&>F^&?@N&>
MA.*`B^&>A^&>MN*`B^&>@.&>O.&>BB(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I;B!+97ER:6YG(@IM<V=S='(@(N&>
M@N&?DN&>F.&>MN&>D^*`B^&>@.&>O.&>D^*`B^&>G^&?A.*`B^&>@.&?DN&>
MD^&>N^&>A"!+97ER:6YG(@H*(SH@;6%I;&)O>"YP:'`Z,C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO($UE<W-A9V5S(@IM<V=S='(@(N&>@N&?DN&>F.&>
MMN&>D^*`B^&>G^&>MN&>FB(*"B,Z('!G<"YP:'`Z,30S"FUS9VED(").;R!0
M1U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZV
MX9Z3XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(
M(%!'4"#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI/AGK;AGX;A
MGH7AGKSAGIO"H.&?E"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC871E(%!R97-E;G0B"FUS
M9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z<X9Z/X9^2X9Z/X9Z8X9ZVX9Z3
MXH"+X9Z<X9ZWX9Z)X9^2X9Z)X9ZVX9Z4X9Z3X9Z4X9Z/X9^2X9Z:XH"+X9Z5
MX9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3(@H*(SH@;6%I;&)O
M>"YP:'`Z.#<V"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`BX9Z"
MX9^2X9Z8X9ZVX9Z3XH"+X9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z8X9Z^X9Z;
MXH"+X9Z'X9ZVXH"+X9Z8X9Z[X9Z3(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHQ-0IM<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B"FUS9W-T
M<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZV
MX9Z2X9ZVX9Z:X9Z.X9^((.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>FN&>@.&>@^&>ON&>B2(*"B,Z('-M:6UE+G!H<#HQ-#<*;7-G:60@(DYO
M(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("+AGH+AGY+A
MGICAGK;AGI/B@(OAGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKA
MGH[AGX@@4R]-24U%(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
MD^&>MN&?AN&>A>&>O.&>F\*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N
M968N<&AP.CDR"FUS9VED(").;R!A='1A8VAM96YT<R!F;W5N9"XB"FUS9W-T
M<B`BX9Z:X9Z`XH"+X9Z8X9ZWX9Z3XH"+X9Z#X9Z^X9Z)XH"+X9ZOX9Z`X9Z?
MX9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+PJ#AGY0B"@HC.B!L:6(O0W)Y
M<'0O4TU)344N<&AP.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I;VX@
M;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`BX9Z8X9ZWX9Z3
MXH"+X9Z8X9ZVX9Z3XH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3XH"+X9ZBX9^*
MX9ZXX9Z8X9^"X9Z;XH"+X9Z3X9^%XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`
MX9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(XH"+X9ZAX9Z^
MX9Z9PJ#AGY0B"@HC.B!A8VPN<&AP.C<Q(&%C;"YP:'`Z.3<*;7-G:60@(DYO
M(&9O;&1E<B!S96QE8W1E9"XB"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+
MX9Z0X9Z/(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>A^&?DN&>
MFN&>ON&>G\*@X9^4(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$S,@IM
M<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA
M:6PN(@IM<V=S='(@(N&>@N&?DN&>F.&>MN&>D^*`B^&>D.&>C^*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>EN&>M^&>D^&>M^&>C^&?DN&>
MF>*`B^&>F.&>ON&>FR#AGI_AGICAGY+AGIKAGK;AGI3AGXOAGI_AGX;AGI3A
MGKOAGH_AGY+AGIKB@(OAGI#AGY+AGICAGKC"H.&?E"(*"B,Z(&9O;&1E<G,N
M<&AP.C$V-2!L:6(O1F]L9&5R+G!H<#HU,3$@;&EB+T9O;&1E<BYP:'`Z-38Q
M"FUS9VED(").;R!F;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(N&>
M@N&?DN&>F.&>MN&>D^*`B^&>D.&>CR#AGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGI3AGHGAGY+AGH?AGK;AGH#AGXLB"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,3,X"FUS9VED(").;R!F;VQD97)S('=I=&@@;F5W(&UE
M<W-A9V5S(@IM<V=S='(@(N&>@N&?DN&>F.&>MN&>D^*`B^&>D.&>C^*`B^&>
MBN&?@N&>F^*`B^&>F.&>MN&>D^*`B^&>G^&>MN&>FN*`B^&>D.&?DN&>F.&>
MN"(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,S4*;7-G:60@(DYO(&9O
M;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`BX9Z"X9^2X9Z8
MX9ZVX9Z3XH"+X9Z0X9Z/XH"+X9Z*X9^"X9Z;XH"+X9Z8X9ZVX9Z3XH"+X9Z?
MX9ZVX9Z:XH"+X9Z8X9ZWX9Z3XH"+X9Z1X9ZVX9Z3X9^+XH"+X9Z8X9Z^X9Z;
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$S.#<*;7-G:60@(DYO(&UE<W-A9V4@
M8F]D>2!T97AT(@IM<V=S='(@(N&>@N&?DN&>F.&>MN&>D^*`B^&>HN&>C^&?
MDN&>D.&>E.&>D>*`B^&>D^&?@^*`B^&>C^&>O>*`B^&>FN&>E.&>G^&?B^*`
MB^&>G^&>MN&>FB(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-38Y"FUS9VED
M(").;R!M97-S86=E(')E='5R;F5D+B(*;7-G<W1R("+AGICAGK?AGI/B@(OA
MGICAGK;AGI/B@(OAGI_AGK;AGIKB@(OAGH_AGY+AGIKAGJ'AGI3AGXOB@(OA
MGICAGH#B@(OAGISAGK?AGHGB@(OAGJ'AGK[AGIG"H.&?E"(*"B,Z(&UA:6QB
M;W@N<&AP.C(U.`IM<V=I9"`B3F\@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E
M87)C:"XB"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z?X9ZVX9Z:X9Z*
MX9^"X9Z;XH"+XH"+X9Z5X9^2X9Z"X9Z\X9Z5X9^2X9Z"X9Z$XH"+X9Z1X9^%
MXH"+X9Z3X9ZYX9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z?X9^2X9Z<X9^"X9Z$XH"+
MX9Z:X9Z`XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY0B"@HC
M.B!P9W`N<&AP.C$Y-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!R:79A=&4@
M:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI/B@(OAGH#A
MGKSAGI/AGI_AGX3B@(OAGJ_AGH#AGH?AGI,@4$=0(.&>E>&?DN&>D>&>MN&>
MF^&?B^*`B^&>@>&?DN&>F^&>O>&>DR#B@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGI3AGK;AGI/B@(OAGI/AGK;AGX;AGH7AGKSAGIO"H.&?E"(*"B,Z('!G<"YP
M:'`Z,3<Q"FUS9VED(").;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O
M<G1E9"XB"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z`X9Z\X9Z3X9Z?
MX9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^((%!'4"#AGI7AGY+AGI'AGK;A
MGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI/B@(L@X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9Z4X9ZVX9Z3XH"+X9Z3X9ZVX9^&X9Z%X9Z\X9Z;PJ#AGY0B"@HC.B!S;6EM
M92YP:'`Z,3DW"FUS9VED(").;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A
M=&5S(&EM<&]R=&5D+B(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI/B@(OAGISA
MGK?AGHGAGY+AGHGAGK;AGI3AGI/AGI3AGH_AGY+AGIH@4R]-24U%(.&>E>&?
MDN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DR#AGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGI/AGK;AGX;AGH7AGKSAGIO"H.&?E"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0V"FUS9VED("(B"B).;R!P
M97)S;VYA;"!P<FEV871E(&ME>2!E>&ES=',@<V\@=&AE(&UE<W-A9V4@:7,@
M=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+
MX9Z8X9ZVX9Z3XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZOX9Z`X9Z'X9Z3XH"+
MX9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3XH"+X9ZAX9Z^
MX9Z9(.&>BN&>O.&>A>&?DN&>D^&?@>&?A^*`B^&>G^&>MN&>FN*`B^&>D^&>
MN>&>A.*`B^&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>
MG.*`B^&>E.&>MN&>D^*`B^&>E.&>F.&?DN&>F^&?@N&>A.*`B^&>F.&>@.*`
MB^&>A^&>MN*`B^&>E^&>MN&>EN*`B^&>DN&>F.&?DN&>F.&>C^&>MN*`B^&>
MG.&>M^&>B>*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@<W!E;&QI;F<N<&AP.C$Y
M,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N
M(@IM<V=S='(@(N&>@N&?DN&>F.&>MN&>D^*`B^&>@.&>F.&?DN&>F.&>G.&>
MM^&>DN&>N.*`B^&>EN&>M^&>D^&>M^&>C^&?DN&>F>*`B^&>HN&>@.&?DN&>
M@>&>FN&>MN&>G.&>M^&>FN&>N^&>D>&?DN&>DB#AGH_AGY+AGIKAGKSAGISB
M@(OAGI3AGK;AGI/B@(OAGH#AGX;AGH[AGH_AGXOB@(OAGIKAGH7AGI/AGK;B
M@(OAGI_AGICAGY+AGI;AGY#AGI/AGY+AGI+"H.&?E"(*"B,Z(&-O;7!O<V4N
M<&AP.CDY,PIM<V=I9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`BX9Z"X9^2
MX9Z8X9ZVX9Z3XH"+X9Z9X9^$X9Z4X9Z;X9^+(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HU-C$*;7-G:60@(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS9W-T<B`BX9Z8X9ZW
MX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z:X9Z`X9Z#X9Z^X9Z)XH"+X9Z<X9ZWX9Z2
MX9ZXX9Z?X9ZVX9Z?X9^2X9Z/X9^2X9Z:XH"+X9Z5X9^2X9Z1X9^`X9Z$X9Z5
MX9^2X9Z1X9ZVX9Z/X9^+($E-05`@X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+
MX9Z"X9ZVX9^&X9Z1X9^2X9Z:PJ#AGY0B"@HC.B!A8VPN<&AP.C8W(&%C;"YP
M:'`Z.3,*;7-G:60@(DYO('5S97(@<W!E8VEF:65D+B(*;7-G<W1R("+AGH+A
MGY+AGICAGK;AGI/B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKX@X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z'X9ZVX9Z`
MX9^+PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`T"FUS
M9VED(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3
MXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z%X9Z\X9Z;X9Z:X9Z]X9Z8(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0@=&5M<&QA=&5S+W!R
M969S+W-E;G1M86EL<V5L96-T+FEN8SHT,`HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS-2!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z,C0*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR
M-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Q"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYH=&UL.C@*;7-G:60@(DYO;F4B"FUS9W-T<B`BX9Z"
MX9^2X9Z8X9ZVX9Z3(@H*(SH@8V]M<&]S92YP:'`Z,3(P-0IM<V=I9"`B3F]R
M;6%L(@IM<V=S='(@(N&>DN&>F.&?DN&>F.&>C^&>MB(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYH=&UL.C$X('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYH=&UL.C,T"FUS9VED(").;W0@1&5L971E9"(*;7-G<W1R("+AGICA
MGK?AGI/B@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI0B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:'1M;#HQ,B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:'1M;#HR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:'1M;#HS-PIM<V=I9"`B3F]T($1R869T(@IM<V=S='(@(N&>F.&>M^&>
MD^*`B^&>F.&?@N&>D^*`B^&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^&>EN&?
MDN&>FN&>MN&>A"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YH=&UL.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,30*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,CD*;7-G:60@(DYO
M="!);7!O<G1A;G0B"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9Z?X9^&X9Z!X9ZV
MX9Z3X9^+(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,C(*
M;7-G:60@(DYO="!097)S;VYA;"(*;7-G<W1R("+AGICAGK?AGI/B@(OAGICA
MGX+AGI/B@(OAGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI,B
M"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H
M<#HQ,S0@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A
M;&ED('!U8FQI8R!K97DN(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>F.&?@N&>
MD^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B.&>
MC^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>F.&>O>&>F<*@X9^4
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P-PIM<V=I9"`B3F]T(&%T
M(&%L;"(*;7-G<W1R("+AGJ+AGH_AGXOB@(OAGI_AGX3AGX<B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C<Q"FUS9VED
M(").;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I;64B"FUS9W-T<B`B
MX9Z%X9^&X9Z.X9ZVX9^&XH"+X9Z0X9ZVXH"+(.&>G.&>MN*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>@.&>MN&>FN*`B^&>EN&?@>&>F^*`B^&>G.&?@>&>F^&>
MMN*`B^&>E.&>D^&?DN&>C^&>M^&>A>*`B^&>E.&>D^&?DN&>C^&>O>&>A2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,38*;7-G:60@(DYO=&AI;F<B
M"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+X9ZBX9^2X9Z<X9ZXXH"+X9Z?
MX9^$X9^'(@H*(SH@871T86-H;65N="YP:'`Z.#D*;7-G:60@(DYO=&EF:6-A
M=&EO;CH@3&EN:V5D(&%T=&%C:&UE;G0@9&]W;FQO861E9"(*;7-G<W1R("+A
MGI_AGX'AGH7AGH#AGY+AGHKAGKCB@(OAGH?AGKSAGI/B@(OAGHKAGX;AGH[A
MGKGAGH3"H.&?EB#AGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3A
MGXOB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGH_AGI?AGY+AGH?AGK;A
MGI3AGXL@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z1X9ZVX9Z)
MX9Z9X9Z`XH"+X9Z@X9Z^X9Z9PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<X"FUS9VED(").=6UB97(@;V8@;6]N=&AS('1O(&ME97`@;VQD
M(&QI;FME9"!A='1A8VAM96YT<R!I9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G
M<W1R("+AGH7AGX;AGI/AGKWAGI/B@(OAGH'AGX+B@(OAGHKAGX+AGIOB@(OA
MGH_AGY+AGIKAGKSAGISB@(OAGIKAGH#AGY+AGI_AGK;AGJ_AGH#AGI_AGK;A
MGIKAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B
M@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGH7AGK;AGI_AGXL@X9Z4X9^2X9Z:
MX9Z?X9ZWX9Z3XH"+X9Z4X9Z^XH"+X9Z;X9Z[X9Z4XH"+X9Z:X9ZVX9Z;X9^+
MXH"+X9Z!X9^"PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8P
M"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O(&ME
M97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`BX9Z%X9^&X9Z3X9Z]
MX9Z3X9Z3X9^#XH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+
MX9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z)X9Z^XH"+X9Z*X9^"X9Z;XH"+X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9Z:X9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`(.&>E.&?
MDN&>FN&>G^&>M^&>D^*`B^&>E.&>ON&>F^&>N^&>E.*`B^&>FN&>MN&>F^&?
MB^*`B^&>@>&?@L*@X9^4(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FAT;6PZ-S,*;7-G:60@(D]+(@IM<V=S='(@(N&>F>&>F^&?B^*`B^&>
MEN&?DN&>FN&>F"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHT.2!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YH=&UL.C0Y"B,Z('1E;7!L
M871E<R]P9W`O:6UP;W)T7VME>2YH=&UL.C,P"FUS9VED(")/4B(*;7-G<W1R
M("+AGJPB"@HC.B!S96%R8V@N<&AP.C,R-`IM<V=I9"`B3VQD(&UE<W-A9V5S
M(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>A>&>MN&>G^&?BR(*"B,Z(&QI8B]-
M86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HU
M,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"XB
M"FUS9W-T<B`BX9Z0X9Z/(%PBX9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z4
MX9ZVX9Z3XH"+X9Z5X9^2X9Z)X9Z^7"(@X9Z%X9ZVX9Z?X9^+XH"+X9Z`X9^&
MX9Z6X9Z[X9Z$XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;
MX9Z[X9Z4XH"+X9Z4X9^&X9Z4X9ZVX9Z/X9^+PJ#AGY0B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,S,*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S
M('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(N&>E.&>
MA.&?DN&>H.&>MN&>B>*`B^&>C^&?@N*`B^&>D.&>C^*`B^&>BN&?@N&>F^*`
MB^&>F.&>MN&>D^*`B^&>G^&>MN&>FN*`B^&>F.&>M^&>D^*`B^&>D>&>MN&>
MD^&?B^*`B^&>HN&>MN&>D\*@/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z.#$*;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@
M8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R("+AGH_AGX+B
M@(OAGI#AGH_B@(OAGICAGKWAGIGB@(OAGI3AGXGAGKOAGH[AGY+AGH[AGX3A
MGX<@X9Z"X9Z]X9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+X9ZB
MX9^&X9Z6X9Z^XH"+X9Z3X9^!X9^'PJ#AGY0B"@HC.B!L:6(O24U0+G!H<#HX
M-3@@;&EB+TE-4"YP:'`Z.#8S"FUS9VED(")/<&5N($9O7VQD97(B"FUS9W-T
M<B`B7TSAGI3AGK[AGH#B@(OAGI#AGH\@(@H*(SH@;&EB+TE-05`O5')E92YP
M:'`Z-#(R"FUS9VED(")/<&5N960@1F]L9&5R(@IM<V=S='(@(N&>D.&>C^*`
MB^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>E.&>ON&>@"(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW,#`*;7-G:60@(D]P=&EO;F%L(%!A<G1I
M8VEP86YT(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>A>&>O.&>F^*`B^&>
MFN&>O>&>F.*`B^&>G^&?DN&>FN&?@>&>A>*`B^&>F^&>ON*`B^&>A>&>M^&>
MC^&?DN&>CR(*"B,Z(&9E=&-H;6%I;"YP:'`Z-#,@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]T;W`N:6YC.C,*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA
M:6PN:6YC.C8*;7-G:60@(D]T:&5R($UA:6P@06-C;W5N=',B"FUS9W-T<B`B
MX9Z"X9Z.X9Z3X9ZXXH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z5X9^2
MX9Z?X9^!X9Z$X9^7(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3$*
M;7-G:60@(D]T:&5R($]P=&EO;G,B"FUS9W-T<B`BX9Z'X9Z8X9^2X9Z:X9Z^
MX9Z?XH"+X9Z5X9^2X9Z?X9^!X9Z$X9^7(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FAT;6PZ,3`Q"FUS9VED(")/=71B;W5N9"!397)V97(B"FUS9W-T
M<B`BX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+
MX9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^%(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M87-S<&AR87-E+FEN8SHQ-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C0*
M(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C$R(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C(Y,PIM<V=I9"`B4$=0(@IM<V=S='(@(E!'4"(*"B,Z(&QI
M8B])35`N<&AP.C$S,38*;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS
M9W-T<B`B4$=0($5N8W)Y<'0@365S<V%G92(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ,30T"FUS9VED(")01U`@17)R;W(Z("(*;7-G<W1R("+AGH#AGX;AGJ#A
MGKOAGI\@4$=0PJ#AGY8@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Q,C,*;7-G
M:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P
M<FEV871E(&ME>2XB"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?(%!'4,*@X9^6
M(.&>C^&?DN&>FN&>O.&>G.&>@.&>MN&>FN*`B^&>@^&?DN&>F^&>MN*`B^&>
MG^&>F.&?DN&>A.&>MN&>C^&?BR#AGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OA
MGH#AGKSAGI/AGI_AGX3B@(OAGJ_AGH#AGH?AGI/B@(OAGI7AGY+AGI'AGK;A
MGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI/"H.&?E"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#,*;7-G:60@(E!'4"!/<'1I;VYS(@IM<V=S='(@(N&>
MA^&>F.&?DN&>FN&>ON&>GR!01U`B"@HC.B!P9W`N<&AP.C,P"FUS9VED(")0
M1U`@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGI3A
MGHGAGY+AGH7AGKSAGIOB@(OAGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3A
MGK;AGH_AGXOB@(OAGIKAGI3AGI_AGXL@4$=0(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C4U"FUS9VED(")01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P
M;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R
M("+AGH#AGK;AGIKB@(OAGH+AGK;AGX;AGI'AGY+AGIKAGH+AGKSB@(OAGH#A
MGKSAGI/AGI_AGX3B@(OAGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOA
MGKWAGI,@4$=0(.&>D>&>MN&>F.&>D>&>MN&>FN*`B^&>@.&>MN&>FN*`B^&>
MC^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>E.&>CN&?DN&>C^&>MN&>B>*`B^&>
MG^&>N^&>G.&>C^&?DN&>D.&>M^&>E^&>MN&>EL*@X9^4(@H*(SH@<&=P+G!H
M<#HQ-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R
M(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(N&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B"!01U`@
MX9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+(%PB)7,@*"5S*5PB("#AGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGI/AGY+AGI#AGX+AGICB@(OAGHKA
MGX3AGIGB@(OAGH?AGX3AGH+B@(OAGH?AGY#AGIG"H.&?E"(*"B,Z('!G<"YP
M:'`Z,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O
M<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("+A
MGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGX@@4$=0(.&>
MG^&>F.&?DN&>FN&>MN&>E.&?BR!<(B5S7"(@X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"
MX9Z'X9^0X9Z9PJ#AGY0B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")01U`@4'5B;&EC
M($ME>7)I;F<B"@HC.B!L:6(O24U0+G!H<#HQ,S$W"FUS9VED(")01U`@4VEG
M;B!-97-S86=E(@IM<V=S='(@(E!'4"!3:6=N($UE<W-A9V4B"@HC.B!L:6(O
M24U0+G!H<#HQ,S$X"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B
M"FUS9W-T<B`B4$=0(%-I9VXO16YC<GEP="!-97-S86=E(@H*(SH@<&=P+G!H
M<#HR,#@*;7-G:60@(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D
M960N(@IM<V=S='(@(N&>@.&>O.&>D^&>G^&?A.*`B^&>K^&>@.&>A^&>DR!0
M1U`@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z3X9^2X9Z0
MX9^"X9Z8XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"X9Z'X9^0X9Z9PJ#AGY0B
M"@HC.B!P9W`N<&AP.C$X,PIM<V=I9"`B4$=0('!U8FQI8R!K97D@<W5C8V5S
M<V9U;&QY(&%D9&5D+B(*;7-G<W1R("+AGH#AGKSAGI/AGI_AGX3B@(OAGI_A
MGK;AGI+AGK;AGIKAGH[AGX@@4$=0(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>E.&>D^&?DN&>D.&?@N&>F.*`B^&>BN&?A.&>F>*`B^&>A^&?
MA.&>@N&>A^&?D.&>F<*@X9^4(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I
M=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H
M:7,@<WES=&5M+B(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGH+AGK;AGX;AGI'A
MGY+AGIH@4$=0(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>DN&?
MDN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>E.&?DN&>FN&>ON*`B^&>F^&?@N&>
MA.*`B^&>E.&>MN&>D^*`BR#AGIOAGK[B@(OAGI3AGY+AGIKAGI;AGY#AGI/A
MGY+AGI+B@(OAGI/AGX'AGX?"H.&?E"(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR"FUS9VED("(B"B)01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W
M:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N
M=&QY("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T
M(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@4$=0("(*(F9E871U
M<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B+AGH#A
MGK;AGIKB@(OAGH+AGK;AGX;AGI'AGY+AGIH@4$=0(.&>D>&>MN&>F.&>D>&>
MMN&>FN*`B^&>LN&?DN&>F>*`B^&>E.&?DN&>FN&>ON*`B^&>E.&>A.&?DN&>
MHN&>O>&>A>*`B^&>F^&?@>&>A>&>H>&>ON&>A,*@X9^4(.&>E.&>ON*`B^&>
M@.&>F.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>FN&>N^&>@.&>FN&>@.*`B^&>
MFN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>@.&?AN&>EN&>N^&>A.*`
MB^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>E.&>A.&?DN&>HN&>O>&>
MA>*`B^&>F^&?@>&>A>&>H>&>ON&>A.*`B^&>E.&?DN&>FN&>ON*`B^&>F^&?
M@N&>A.*`BR(*(N&>E.&>MN&>DR#AGJ+AGY+AGI/AGH#B@(OAGH_AGY+AGIKA
MGKSAGISB@(OAGH_AGX+B@(OAGI7AGY+AGIOAGK;AGI_AGXOAGI3AGY+AGHKA
MGKSAGIKB@(OAGH#AGK;AGIKB@(OAGH#AGX;AGH[AGH_AGXOB@(OAGI/AGX'A
MGX<@X9Z4X9Z^XH"+X9Z6X9Z[X9^&XH"+X9Z3X9^$X9^'XH"+X9Z1X9^!XH"+
MX9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z6X9ZWX9Z?X9^!X9Z?(%!'4"#AGI/A
MGKGAGH3B@(OAGICAGK?AGI/B@(OAGHKAGX;AGH[AGK[AGIKAGH#AGK;AGIKB
M@(OAGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSAGISB@(OAGJ'AGK[AGIG"
MH.&?E"(*"B,Z(&QI8B])34%0+G!H<#HQ-S4*;7-G:60@(E!/4#,B"FUS9W-T
M<B`B4$]0,R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`R"FUS9VED
M(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(E!/4#,@
M*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"@HC.B!L:6(O24U!4"YP:'`Z,3@W
M"FUS9VED(")03U`S(&]V97(@4U-,(@IM<V=S='(@(E!/4#,@X9Z;X9Z^(%-3
M3"(*"B,Z(&QI8B])34%0+G!H<#HQ.3,*;7-G:60@(E!/4#,@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R(")03U`S(.&>F^&>
MOB!34TP@*.&>G.&>M^&>B>&?DN&>B>&>MN&>E.&>D^&>E.&>C^&?DN&>FN*`
MB^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>A>&>N^&?A^*`B^&>H.&>C^&?
MDN&>D.&>F^&?@>&>@>&>MN*`B^&>BN&?A.&>F>*`B^&>@>&?DN&>F^&>O>&>
MD^*`B^&>K^&>A"DB"@HC.B!L:6(O24U!4"YP:'`Z,3@Q"FUS9VED(")03U`S
M+"!N;R!43%,B"FUS9W-T<B`B4$]0,R#AGH+AGY+AGICAGK;AGI,@5$Q3(@H*
M(SH@;6%I;&)O>"YP:'`Z,S<T"B,L('!H<"UF;W)M870*;7-G:60@(E!A9V4@
M)60@;V8@)60B"FUS9W-T<B`BX9Z1X9^&X9Z6X9^0X9Z:("5D(.&>D^&?@R`E
M9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,30*;7-G:60@(E!A9V4@
M=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4B"FUS9W-T<B`BX9Z1X9^&
MX9Z6X9^0X9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z8X9ZVX9Z3XH"+X9Z?X9ZVX9Z:
MXH"+X9Z8X9ZWX9Z3XH"+X9Z4X9ZVX9Z3XH"+X9Z8X9Z^X9Z;XH"+X9Z*X9^&
MX9Z4X9Z\X9Z$(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-0IM<V=I
M9"`B4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@
M(N&>D>&?AN&>EN&?D.&>FN*`B^&>BN&?@N&>F^*`B^&>F.&>MN&>D^*`B^&>
MG^&>MN&>FN*`B^&>F.&>M^&>D^*`B^&>E.&>MN&>D^&>F.&>ON&>F^*`B^*`
MB^&>A>&>N^&>A.*`B^&>@.&?DN&>FN&?A.&>F2(*"B,Z(&UE<W-A9V4N<&AP
M.C8V-@IM<V=I9"`B4&%R="AS*2(*;7-G<W1R("+AGI7AGY+AGI/AGX+AGH`B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS9VED(")087-S<&AR
M87-E(@IM<V=S='(@(N&>@^&?DN&>F^&>MN*`B^&>G^&>F.&?DN&>A.&>MN&>
MC^&?BR(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!A
M<W-P:')A<V4@*$%G86EN*2(*;7-G<W1R("+AGH/AGY+AGIOAGK;B@(OAGI_A
MGICAGY+AGH3AGK;AGH_AGXL@*.&>F.&?DN&>C^&>A.*`B^&>D>&?@.&>CRDB
M"@HC.B!S;6EM92YP:'`Z,C,Q('!G<"YP:'`Z,S$V"FUS9VED(")087-S<&AR
M87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`BX9Z#X9^2X9Z;
MX9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z:X9Z^XH"+X9Z%X9^!X9Z)XH"+X9Z*X9^$X9Z9
MXH"+X9Z'X9^$X9Z"XH"+X9Z'X9^0X9Z9PJ#AGY0B"@HC.B!T96UP;&%T97,O
M<VUI;64O<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S<&AR
M87-E+FEN8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`BX9Z#X9^2
MX9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+PJ#AGY8B"@HC.B!P9W`N
M<&AP.C$Q.`IM<V=I9"`B4&%S<W!H<F%S97,@8V%N;F]T(&)E(&5M<'1Y(@IM
M<V=S='(@(N&>@^&?DN&>F^&>MN*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B^*`
MB^&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>D>&>D>&?@>*`B^&>E.&>MN&>
MD^*`B^&>H>&>ON&>F2(*"B,Z('!G<"YP:'`Z,3(P"FUS9VED(")087-S<&AR
M87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`BX9Z#X9^2X9Z;X9ZVXH"+X9Z?
MX9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z8X9ZWX9Z3XH"+X9Z5X9^2X9Z"X9Z\
MX9Z5X9^2X9Z"X9Z$(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C(P('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:'1M;#HY,`IM<V=I9"`B4&%S<W=O<F0B
M"FUS9W-T<B`BX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/
MX9^+(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"FUS
M9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M(@IM<V=S='(@(N&>DN&?DN&>G.&>ON*`B^&>E.&?DN&>FN&>C^&>M^&>E.&>
MC^&?DN&>C^&>M^&>@.&>MN&>FN*`B^&>C^&?AN&>H.&?@N&>D>&>MN&?AB#A
MGI;AGX'AGIOB@(OAGH7AGKSAGIO"H#\B"@HC.B!A8VPN<&AP.C<U(&%C;"YP
M:'`Z,3`Q"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R(&-A;FYO
M="!B92!C:&%N9V5D+B(*;7-G<W1R("+AGI_AGK?AGI'AGY+AGI+AGK?B@(OA
MGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+A
MGIKAGK[B@(OAGI/AGX'AGX<@X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+
MX9Z4X9^2X9Z*X9Z\X9Z:XH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0B
M"@HC.B!M97-S86=E+G!H<#HT-C`@;6%I;&)O>"YP:'`Z.#`V(&UA:6QB;W@N
M<&AP.CDW-0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:'1M;#HR,2!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:'1M;#HX"FUS9VED(")097)S;VYA
M;"(*;7-G<W1R("+AGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWA
MGI,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>
MD^*`B^&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DR(*"B,Z
M('!G<"YP:'`Z,3(V"FUS9VED(")097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+AGH+AGKSB@(OAGH#AGKSA
MGI/AGI_AGX0@4$=0(.&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>
MO>&>DR#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGH3AGY+A
MGH#AGK[AGH_B@(OAGHKAGX3AGIGB@(OAGH?AGX3AGH+AGH?AGY#AGIG"H.&?
ME"(*"B,Z('!G<"YP:'`Z,3,S"FUS9VED(")097)S;VYA;"!01U`@:V5Y<R!D
M96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BX9Z`X9Z\X9Z3X9Z?X9^$
M(%!'4"#AGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI,@X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4XH"+X9Z*X9^$
MX9Z9XH"+X9Z'X9^$X9Z"X9Z'X9^0X9Z9PJ#AGY0B"@HC.B!S;6EM92YP:'`Z
M,C`S"FUS9VED(")097)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I
M;7!O<G1E9#H@(@IM<V=S='(@(N&>G.&>M^&>B>&?DN&>B>&>MN&>E.&>D^&>
ME.&>C^&?DN&>FB!3+TU)344@X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2
MX9Z;X9Z]X9Z3(.&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>D^&>MN&?AN*`B^&>A>&>O.&>F^*`B^&>H>&>ON&>F<*@X9^6
M(@H*(SH@<VUI;64N<&AP.C$R.`IM<V=I9"`B4&5R<V]N86P@4R]-24U%(&ME
M>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(N&>@.&>O.&>D^&>
MG^&?A"!3+TU)344@X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]
MX9Z3XH"+(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>F^&>N^&>
ME.*`B^&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F<*@X9^4(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,PIM<V=I9"`B4&QA8V4@>6]U<B!S
M:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/R(*;7-G<W1R
M("+AGHKAGK;AGH#AGXOB@(OAGJ#AGH_AGY+AGI#AGIOAGX'AGH'AGK;B@(OA
MGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`@X9Z8X9Z[X9Z3XH"+X9Z`X9ZV
MX9Z:XH"+X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4(.&>D^&>M^&>A"#AGI3A
MGHGAGY+AGH?AGKSAGI/AGI3AGI/AGY+AGH_"H#\B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,S4X"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E
M(@IM<V=S='(@(N&>@.&?AN&>CN&?@N*`B^&>HN&>C^&?DN&>D.&>E.&>D>*`
MB^&>DN&>F.&?DN&>F.&>C^&>MN*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>
MFB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3$*;7-G:60@(B(*(E!L
M87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@8G)O
M=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D("(*(G-O=6YD(&9I;&5S+B`@06QM
M;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P;&%T
M9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@<&QU9VEN+B(*;7-G<W1R("(B"B+A
MGH7AGK;AGH#AGXOB@(OAGI_AGICAGY+AGIOAGX'AGH3B@(OAGI;AGX'AGIOB
M@(OAGICAGK;AGI/B@(OAGI_AGK;AGIKB@(OAGI#AGY+AGICAGKC"H#\@(.&>
MG.&>MN*`B^&>D>&>MN&>F.&>D>&>MN&>FN*`B^&>LN&?DN&>F>*`B^&>@.&>
MF.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>FN&>N^&>@.&>FN&>@.*`B^&>FN&>
ME.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>@N&>MN&?AN&>D>&?DN&>FN*`
MB^&>K^&>@.&>G^&>MN&>FN*`B^&>G^&>F.&?DN&>F^&?@>&>A.*`B^&>E.&>
MA.&?DN&>@.&>E.&?B\*@X9^4("#AGH#AGICAGY+AGICAGISAGK?AGI+AGKCB
M@(LB"B+AGIKAGKOAGH#AGIKAGH#B@(OAGI_AGY+AGI'AGK[AGIKB@(OAGH_A
MGX+B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXOB@(OAGI/AGX7B@(OAGIOAGKX@
M5VEN9&]W<R#AGI/AGK?AGH0@36%C(.&>E.&>MN&>D^*`B^&>@N&>MN&?AN&>
MD>&?DN&>FB#AGI3AGXGAGKOAGI/AGY+AGH_AGX+B@(OAGISAGX'AGI'AGK?A
MGH#AGK;B@(OAGI7AGY+AGI_AGX'AGH3B@(OAGI'AGX#AGH_B@(OAGI/AGKGA
MGH3B@(OAGI'AGK;AGICAGI'AGK;AGIKB@(OAGH#AGICAGY+AGICAGISAGK?A
MGI+AGKCB@(OAGH?AGX;AGI/AGKWAGIGB@(LB"B+AGH'AGK;AGH3B@(OAGH#A
MGY+AGI/AGKOAGH3B@(OAGICAGKWAGIG"H.&?E"(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<P('1E;7!L871E<R]M86EL8F]X+VIA
M=F%S8W)I<'0N:6YC.C$Y-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F
M;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(N&>G^&>O.&>F.*`B^&>E.&>
MB>&?DN&>A>&>O.&>F^*`B^&>B.&?DN&>F.&?A.&?A^*`B^&>F.&>O>&>F2#A
MGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OAGI#AGH_B@(OAGI#AGY+AGICAGKC"
MH.&?EB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`V"FUS9VED(")0
M;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S
M='(@(N&>G^&>O.&>F.*`B^&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>B.&?DN&>
MF.&?A.&?A^*`B^&>FN&>E.&>G^&?B^*`B^&>D.&>C^*`B^&>D.&?DN&>F.&>
MN,*@X9^6(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ
M,SD*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@
M(N&>G^&>O.&>F.*`B^&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>B.&?DN&>F.&?
MA.&?A^*`B^&>D.&?DN&>F.&>N,*@X9^6(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M87-S<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A
M<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@
M:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB96YT97(@=&AI<R!P87-S
M<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*(N&>G^&>
MO.&>F.*`B^&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>@^&?DN&>F^&>MN*`B^&>
MG^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`
MB^&>@.&>O.&>D^&>G^&?A.*`B^&>K^&>@.&>A^&>DR!01U`@X9Z:X9Z4X9Z?
MX9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY0@X9ZBX9^2X9Z3X9Z`XH"+X9Z%X9ZV
MX9^&X9Z4X9ZVX9Z%X9^+XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z#X9^2
MX9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z3X9^!X9^'XH"+
MX9Z/X9^"XH"+X9Z8X9Z]X9Z9XH"+X9Z*X9Z$(.&>@.&?DN&>D^&>N^&>A.*`
MB^&>F.&>O>&>F>*`BR(*(N&>G^&>F.&?D.&>F2`E<\*@X9^4(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U
M<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T
M;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB
M"FUS9W-T<B`B(@HBX9Z?X9Z\X9Z8XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+
MX9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z?X9Z8
MX9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZOX9Z`X9Z'
MX9Z3(%,O34E-12#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"H.&?E"#A
MGJ+AGY+AGI/AGH#B@(OAGH7AGK;AGX;AGI3AGK;AGH7AGXOB@(OAGI3AGHGA
MGY+AGH7AGKSAGIOB@(OAGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;A
MGH_AGXOB@(OAGI/AGX'AGX?B@(OAGH_AGX+B@(OAGICAGKWAGIGB@(OAGHKA
MGH0@X9Z`X9^2X9Z3X9Z[X9Z$XH"+(@HBX9Z8X9Z]X9Z9XH"+X9Z?X9Z8X9^0
MX9Z9("5SPJ#AGY0B"@HC.B!L;V=I;BYP:'`Z,3@P"FUS9VED("(B"B)0;&5A
M<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S
M86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R`B"B)C;V]K:65S($%.1"!Y;W4@
M87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@
M=VEL;"!H879E('1O("(*(FQO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN
M9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2`B
M"B)H:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R
M(&%N>2!I;F-O;G9E;FEE;F-E+B(*;7-G<W1R("(B"B+AGI_AGKSAGICB@(OA
MGH7AGKSAGIOB@(OAGICAGY+AGH_AGH3B@(OAGI'AGX#AGH\@X9Z*X9Z^X9Z8
MX9^2X9Z4X9ZXXH"+X9Z4X9Z3X9^2X9Z/XH"+X9Z/X9^"X9Z$XH"+X9Z?X9ZV
MX9Z:XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY0@X9Z4X9^2
MX9Z:X9Z?X9ZWX9Z3XH"+X9Z4X9Z^XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZW
MX9Z3XH"+X9Z`X9^&X9Z6X9Z[X9Z$XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z!X9Z\
MX9Z"X9ZX(.&>D^&>M^&>A"#AGJ+AGY+AGI/AGH#B@(OAGH#AGX;AGI;AGKOA
MGH3B@(OAGH_AGX+AGH3B@(OAGI_AGK;AGIKB@(OAGH#AGY+AGI/AGKOAGH3B
M@(OAGI3AGH3AGY+AGJ+AGKWAGH7B@(LB"B+AGIOAGX'AGH7AGJ'AGK[AGH0@
MX9ZBX9^2X9Z3X9Z`X9Z%X9ZVX9^&X9Z4X9ZVX9Z%X9^+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z%X9Z\X9Z;XH"+X9Z8X9^2X9Z/X9Z$XH"+X9Z1X9^`X9Z/(.&>
M@.&?DN&>D^&>N^&>A.*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`B^&>F.&?@>*`
MB^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>E>&>A.*`B^&>BN&?
M@N&>FL*@X9^4(.&>D^&?@>&?A^*`B^&>@N&>NN*`B^&>BN&>ON&>F.&?DN&>
ME.&>N.*`B^&>FN&>MN&>FN&>MN&?AN&>A.*`B^&>HN&?DN&>D^&>@.*`B^&>
MG.&>MN&>F>*`B^&>E.&?DN&>FN&>H.&>MN&>FN*`B^&>EN&>N.*`BR(*(N&>
M@.&>MN&>FN*`B^&>E.&?DN&>F^&>D^&?B^*`B^&>HN&>C^&?DN&>C^&>G^&>
MB>&?DN&>B>&>MN&>CN*`B^&>G^&>F.&?D.&>F>*`B^&>FN&>E.&>G^&?B^*`
MB^&>HN&?DN&>D^&>@,*@X9^4(.&>F>&>ON*`B^&>A.*`B^&>G^&>O.&>F.*`
MB^&>D>&?A.&>G^*`B^&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>E^&>MN&>
MEN*`B^&>F.&>M^&>D^*`B^&>A.&>MN&>F>&>G^&?DN&>FN&>O>&>F^*`B^&>
MCN&>MN&>F.&>O>&>F<*@X9^4(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VIA=F%S
M8W)I<'0N:6YC.C,V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W
M;W)D+B(*;7-G<W1R("+AGI_AGKSAGICB@(OAGI7AGY+AGH_AGIOAGXOB@(OA
MGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;AGH_AGXOB@(OAGIKA
MGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"H.&?E"(*"B,Z('1E;7!L871E<R]L
M;V=I;B]J879A<V-R:7!T+FEN8SHS,@IM<V=I9"`B4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`BX9Z?X9Z\X9Z8XH"+X9Z5X9^2X9Z/
MX9Z;X9^+XH"+X9Z(X9^2X9Z8X9^$X9^'XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4
MX9^2X9Z:X9Z^XH"+X9Z:X9Z4X9Z?X9^+X9ZBX9^2X9Z3X9Z`PJ#AGY0B"@HC
M.B!C;VUP;W-E+G!H<#HQ,#8@;&EB+T-O;7!O<V4N<&AP.C(S.3@*;7-G:60@
M(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E
M<RXB"FUS9W-T<B`BX9Z?X9Z\X9Z8XH"+X9Z*X9^$X9^'XH"+X9Z?X9^2X9Z:
MX9ZVX9Z9XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z*X9^"
MX9Z;XH"+X9Z8X9ZWX9Z3XH"+X9Z%X9^2X9Z4X9ZVX9Z?X9^+(.&>K"#AGICA
MGK?AGI/B@(OAGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSAGIS"H.&?E"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C,*;7-G:60@
M(E!L96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M('1H
M:7,@86-T:6]N+B(*;7-G<W1R("+AGI_AGKSAGICB@(OAGH?AGY+AGIKAGK[A
MGI_B@(OAGI#AGH_B@(OAGICAGKWAGID@X9Z8X9Z[X9Z3XH"+X9Z3X9ZYX9Z$
MXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z4X9Z/X9^2X9Z/
MX9ZWXH"+X9ZBX9^&X9Z6X9Z^XH"+X9Z3X9^!X9^'PJ#AGY0B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC.C0Q"FUS9VED(")0;&5A<V4@
M<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H+B(*;7-G<W1R
M("+AGI_AGKSAGICB@(OAGH?AGY+AGIKAGK[AGI_B@(OAGIGAGXGAGK;AGH3B
M@(OAGJ#AGX3AGH7B@(OAGH[AGK;AGI_AGXOB@(OAGI#AGH_B@(OAGICAGKWA
MGID@X9Z*X9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z?X9^2X9Z<X9^"X9Z$XH"+X9Z:
MX9Z`PJ#AGY0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$R"FUS9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@
M=&AI<R!O<&5R871I;VXN(@IM<V=S='(@(N&>G^&>O.&>F.*`B^&>A^&?DN&>
MFN&>ON&>G^*`B^&>D.&>C^*`B^&>C^&?@N*`B^&>F.&>O>&>F>*`B^&>@N&>
MC^&?BR#AGI_AGICAGY+AGIKAGK;AGI3AGXOB@(OAGI3AGY+AGIKAGH_AGK?A
MGI3AGH_AGY+AGH_AGK?AGH#AGK;AGIKB@(OAGI/AGX'AGX?"H.&?E"(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FAT;6PZ,SD*;7-G:60@(E!L
M96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB
M"FUS9W-T<B`BX9Z?X9Z\X9Z8XH"+X9Z'X9^2X9Z:X9Z^X9Z?(.&>K"#AGH#A
MGX+AGI_AGICAGY+AGIKAGKWAGIOB@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI3A
MGY+AGIKAGJ+AGI3AGXOB@(OAGI'AGX7B@(OAGH'AGK;AGH3B@(OAGI_AGY+A
MGH_AGK;AGX;"H.&?EB(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD:7-T.C0Q"FUS
M9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S='(@(N&>DN&?DN&>G.&>ON*`
MB^&>LN&?DN&>F>*`B^&>BN&>ON&>FN*`B^&>BN&?A.&>F2!(;W)D92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@(E!R96-E9&4@>6]U
M<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`BX9Z3
MX9ZVX9^&XH"+X9Z8X9Z[X9Z!XH"+X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZV
MXH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z*X9^$X9Z9XH"+
MX9Z?X9Z)X9^2X9Z)X9ZVXH"+X9Z*X9ZVX9Z%X9^+X9^7("@G+2T@)RG"H#\B
M"@HC.B!S;6EM92YP:'`Z,C,W('!G<"YP:'`Z,C8S(&9I;'1E<G!R969S+G!H
M<#HT,0IM<V=I9"`B4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P9&%T960N
M(@IM<V=S='(@(N&>A>&?AN&>CN&>A.&?B^*`B^&>A>&?AN&>CN&>O.&>F^&>
MA>&>M^&>C^&?DN&>CR#B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI'AGK;AGI/AGXOB@(OA
MGI_AGICAGY#AGIGB@(OAGHKAGX3AGIGB@(OAGI_AGY+AGISAGY#AGIGB@(OA
MGI3AGY+AGIKAGISAGH_AGY+AGH_AGK?"H.&?E"(*"B,Z(&-O;7!O<V4N<&AP
M.C$S-#<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C,Q-`IM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R("+AGICAGK[AGIOB@(OAGH?AGK;B@(OAGICA
MGKOAGI,B"@HC.B!M97-S86=E+G!H<#HU,3,@;65S<V%G92YP:'`Z-CDY"FUS
M9VED(")0<F5V:6]U<R!-97-S86=E(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>
MF.&>N^&>DR(*"B,Z(&UA:6QB;W@N<&AP.C0S-`IM<V=I9"`B4')E=FEO=7,@
M4&%G92(*;7-G<W1R("+AGI'AGX;AGI;AGY#AGIKB@(OAGICAGKOAGI,B"@HC
M.B!M97-S86=E+G!H<#HU.30*;7-G:60@(E!R:6YT(@IM<V=S='(@(N&>E.&?
MA.&?A^&>EN&>N^&>F.&?DN&>EB(*"B,Z(&UE<W-A9V4N<&AP.C8U-0IM<V=I
M9"`B4')I;W)I='DB"FUS9W-T<B`BX9ZBX9ZVX9Z1X9ZWX9Z7X9ZVX9Z6(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<V"FUS9VED(")0
M<FEV871E($ME>2!087-S=V]R9"(*;7-G<W1R("+AGI;AGK;AGH#AGY+AGIGB
M@(OAGI_AGICAGY+AGH3AGK;AGH_AGXOB@(OAGIKAGI3AGI_AGXOAGH#AGKSA
MGI/AGI_AGX3B@(OAGJ_AGH#AGH?AGI,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3<Q"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM
M96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B"FUS9W-T<B`BX9Z:X9^&X9Z;
MX9ZYX9Z`XH"+X9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+X9Z6X9^!X9Z;
MXH"+X9Z*X9^"X9Z;XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZV
MX9Z4X9^+XH"+X9Z8X9Z]X9Z9XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZV
MX9Z3XH"+X9Z5X9^2X9Z)X9Z^PJ#AGY0@X9Z;X9^&X9Z3X9ZVX9^&X9Z*X9Z^
MX9Z8X9Z"X9ZZXH"+X9Z1X9^!PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3<P"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM
M96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453(@IM<V=S='(@(N&>FN&?AN&>
MF^&>N>&>@.*`B^&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`B^&>EN&?@>&>
MF^*`B^&>BN&?@N&>F^*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>
MMN&>E.&?B^*`B^&>F.&>O>&>F>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>E>&?DN&>B>&>OL*@X9^4(.&>F^&?AN&>D^&>MN&?AN&>BN&>
MON&>F.&>@N&>NN*`B^&>E.&>MN&>D<*@X9^4(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0<F]T;V-O;#HB"FUS9W-T
M<B`BX9Z6X9ZWX9Z2X9ZXX9Z`X9ZVX9Z:PJ#AGY8B"@HC.B!L:6(O0W)Y<'0O
M4$=0+G!H<#HT,S`*;7-G:60@(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O
M<G0@:&%S(&)E96X@9&ES86)L960N(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>
M@N&>MN&?AN&>D>&?DN&>FN*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>
ME.&>F.&?DN&>FN&>ON*`B^&>@.&>O.&>D^&>G^&?A"!01U`@X9Z?X9ZVX9Z2
MX9ZVX9Z:X9Z.X9^((.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
MDN&?DN&>G.&>ON&>LN&?DN&>F>*`B^&>E.&?DN&>FN&>ON*`B^&>F^&?@N&>
MA.*`B^&>E.&>MN&>D\*@X9^4(@H*(SH@;6%I;&)O>"YP:'`Z,S@X(&UA:6QB
M;W@N<&AP.C0X,PIM<V=I9"`B4'5R7V=E($1E;&5T960B"FUS9W-T<B`B7T?A
MGIOAGKOAGI3B@(OAGI3AGX;AGI3AGK;AGH_AGXL@7"+AGI3AGK;AGI/B@(OA
MGIOAGKOAGI1<(B`B"@HC.B!M86EL8F]X+G!H<#HS.#@@;6%I;&)O>"YP:'`Z
M-#@S"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(N&>F^&>N^&>E.*`
MB^&>E.&?AN&>E.&>MN&>C^&?BR!<(N&>E.&>MN&>D^*`B^&>F^&>N^&>E%PB
M("(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:'1M;#HR-@IM<V=I
M9"`B4'5R9V4@1F]L9&5R*',I(@IM<V=S='(@(N&>F^&>N^&>E.*`B^&>E.&?
MAN&>E.&>MN&>C^&?B^*`B^&>D.&>CR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.3<*;7-G:60@(E!U<F=E(%1R87-H(&AO=R!O9G1E;CHB"FUS9W-T
M<B`BX9Z%X9^&X9Z3X9Z]X9Z3XH"+X9Z*X9Z$XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z;X9Z[X9Z4XH"+X9Z4X9^&X9Z4X9ZVX9Z/X9^+XH"+X9Z?X9^&X9Z:
MX9ZVX9Z8PJ#AGY8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS
M9VED(")0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA
M;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*;7-G<W1R("+AGIOAGKOAGI3B@(OA
MGI3AGX;AGI3AGK;AGH_AGXOB@(OAGI_AGK;AGIKB@(OAGH#AGY+AGI/AGKOA
MGH3B@(OAGI#AGH_B@(OAGI_AGX;AGIKAGK;AGI@@X9Z*X9^"X9Z;XH"+X9Z%
MX9ZVX9Z?X9^+XH"+X9Z'X9ZVX9Z$XH"+X9Z%X9^&X9Z3X9Z]X9Z3XH"+X9Z0
MX9^2X9Z$X9^#XH"+X9Z3X9^!X9^'PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@W"FUS9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE
M(%1R87-H(&9O;&1E<C\B"FUS9W-T<B`BX9Z;X9Z[X9Z4XH"+X9Z4X9^&X9Z4
MX9ZVX9Z/X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z%X9ZVX9Z?X9^+XH"+X9Z`X9^2
MX9Z3X9Z[X9Z$XH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8PJ`_(@H*(SH@
M;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8U"B,L('!H
M<"UF;W)M870*;7-G:60@(E!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S
M:"!F;VQD97(N(@IM<V=S='(@(N&>@.&?AN&>EN&>N^&>A.*`B^&>F^&>N^&>
ME.*`B^&>E.&?AN&>E.&>MN&>C^&?B^*`B^&>G^&>MN&>FN*`B^&>A>&?AN&>
MD^&>O>&>DR`E9"#AGI;AGKCB@(OAGI#AGH_B@(OAGI_AGX;AGIKAGK;AGIC"
MH.&?E"(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H
M<#HV,PIM<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD
M97(N(@IM<V=S='(@(N&>@.&?AN&>EN&>N^&>A.*`B^&>F^&>N^&>E.*`B^&>
ME.&?AN&>E.&>MN&>C^&?B^*`B^&>G^&>MN&>FN*`B^&>A>&?AN&>D^&>O>&>
MDR#AGZ$@X9Z6X9ZXXH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8PJ#AGY0B
M"@HC.B!L:6(O24U0+G!H<#HY,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O
M=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@
M(N&>G^&?DN&>D.&>MN&>D^&>E^&>MN&>EN*`B^&>@.&>O.&>C^&>ML*@X9^6
M("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"@HC.B!L:6(O24U0+G!H<#HY
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@
M+R!.3R!,24U)5"(*;7-G<W1R("+AGI_AGY+AGI#AGK;AGI/AGI?AGK;AGI;B
M@(OAGH#AGKSAGH_AGK;"H.&?EB`E+C)F34(@+R#AGH+AGY+AGICAGK;AGI/B
M@(OAGH#AGX;AGH[AGH_AGXLB"@HC.B!L:6(O24U0+G!H<#HY,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B!.3R!,24U)5"(*;7-G<W1R
M("+AGI_AGY+AGI#AGK;AGI/AGI?AGK;AGI;B@(OAGH#AGKSAGH_AGK;"H.&?
MEB#AGH+AGY+AGICAGK;AGI/B@(OAGH#AGX;AGH[AGH_AGXLB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3`Q"B,L('!H<"UF;W)M870*;7-G:60@(E%U
M;W1I;F<@)68Z(@IM<V=S='(@(N&>G^&>F.&?DN&>FN&>A.&?BR`E9L*@X9^6
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH=&UL.C,Q"FUS9VED
M(")296)U:6QD($9O;&1E<B!4<F5E(@IM<V=S='(@(N&>G^&?DN&>D.&>MN&>
ME.&>D^&>MN*`B^&>F.&?@N&>@.&>DN&>MN&>A.*`B^&>D.&>C^*`B^&>H>&>
MON&>A.*`B^&>G.&>M^&>B2(*"B,Z(&QI8B]396%R8V@N<&AP.C8S,0IM<V=I
M9"`B4F5C96EV960@3VXB"FUS9W-T<B`BX9Z4X9ZVX9Z3XH"+X9Z1X9Z1X9Z]
MX9Z;(.*`B^&>D^&?A>*`B^&>D.&?DN&>A.&?@R(*"B,Z(&QI8B]396%R8V@N
M<&AP.C8S.0IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`BX9Z4X9ZV
MX9Z3XH"+X9Z1X9Z1X9Z]X9Z;XH"+(.&>A>&>MN&>E.&?B^*`B^&>C^&>MN&?
MAN&>A.*`B^&>EN&>N"(*"B,Z(&QI8B]396%R8V@N<&AP.C8S-0IM<V=I9"`B
M4F5C96EV960@56YT:6PB"FUS9W-T<B`BX9Z4X9ZVX9Z3XH"+X9Z1X9Z1X9Z]
MX9Z;(.&>FN&>H.&>O.&>C^&>BN&>F^&?BR(*"B,Z(&UE<W-A9V4N<&AP.C4U
M-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(E]4X9Z4X9^2X9Z/X9Z\X9Z:
MXH"+X9Z1X9ZWX9Z?("(*"B,Z(&UE<W-A9V4N<&AP.C4U-@IM<V=I9"`B4F5D
M:7)E8W0B"FUS9W-T<B`BX9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1X9ZWX9Z?(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:'1M;#HW-PIM<V=I9"`B
M4F5D:7)E8W0@365S<V%G92(*;7-G<W1R("+AGI3AGY+AGH_AGKSAGIKB@(OA
MGI'AGK?AGI_B@(OAGI_AGK;AGIHB"@HC.B!C;VUP;W-E+G!H<#HT,S,*;7-G
M:60@(E)E9&ER96-T('1H:7,@;65S<V%G92(*;7-G<W1R("+AGI3AGY+AGH_A
MGKSAGIKB@(OAGI'AGK?AGI_B@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX<B"@HC
M.B!C;VUP;W-E+G!H<#HT.38*;7-G:60@(E)E9&ER96-T:6YG(&9A:6QE9"XB
M"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z1X9ZW
MX9Z?XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9PJ#AGY0B"@HC
M.B!F;VQD97)S+G!H<#HR-S8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`BX9Z2
MX9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z?X9^2X9Z:X9Z?X9^+(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y-@IM<V=I9"`B4F5F<F5S:"!&;VQD
M97(@5FEE=W,Z(@IM<V=S='(@(N&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`
MB^&>D>&>M^&>BN&?DN&>B^&>E^&>MN&>EN*`B^&>FN&>E.&>G^&?B^*`B^&>
MD.&>C^*`B^&>G^&?DN&>FN&>G^&?B\*@X9^6(@H*(SH@;6%I;&)O>"YP:'`Z
M,S0Y"FUS9VED(")296QO860B"FUS9W-T<B`BX9Z5X9^2X9Z1X9Z[X9Z`XH"+
MX9ZAX9Z^X9Z$XH"+X9Z<X9ZWX9Z)(@H*(SH@9F]L9&5R<RYP:'`Z,C8V"FUS
M9VED(")296QO860@5FEE=R(*;7-G<W1R("+AGI7AGY+AGI'AGKOAGH#B@(OA
MGI'AGK?AGHKAGY+AGHOAGI?AGK;AGI;B@(OAGJ'AGK[AGH3B@(OAGISAGK?A
MGHDB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(X(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E;65M8F5R('1H92!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(N&>A>&>A.&>A>&>MN&?AN*`
MB^&>EN&?D.&>C^&?C.&>F.&>MN&>DR#AGI'AGX;AGI/AGX'AGIHOX9Z:X9Z<
MX9Z;X9^+PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3DP"FUS
M9VED(")296UE;6)E<B!T:&4@;&%S="!V:65W(@IM<V=S='(@(N&>A>&>A.&>
MA>&>MN&?AN*`B^&>D>&>M^&>BN&?DN&>B^&>E^&>MN&>EN*`B^&>A>&>N^&>
MA.*`B^&>@.&?DN&>FN&?A.&>F2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHR-PIM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@
M(N&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`
MB^&>AN&?DN&>A.&>MN&>F<*@X9^6(@H*(SH@<V5A<F-H+G!H<#HS,C`*;7-G
M:60@(E)E;6]V92!&:65L9"!&<F]M(%-E87)C:"(*;7-G<W1R("+AGIGAGH#B
M@(OAGISAGK;AGIOB@(OAGH7AGX'AGHGB@(OAGI;AGKCB@(OAGH#AGK;AGIKB
M@(OAGI_AGY+AGISAGX+AGH3B@(OAGIKAGH`B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*;7-G:60@(E)E;6]V92!S;W5R8V4B
M"FUS9W-T<B`BX9Z9X9Z`XH"+X9Z4X9^2X9Z:X9Z7X9Z6XH"+X9Z%X9^!X9Z)
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH=&UL.C$P"FUS9VED
M(")296YA;64@1F]L9&5R*',I(@IM<V=S='(@(N&>E.&?DN&>C^&>O.&>FN*`
MB^&>B.&?DN&>F.&?A.&?A^*`B^&>D.&>CR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#(*;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T
M(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`BX9Z4X9^2X9Z/X9Z\X9Z:
MXH"+X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z4X9Z[X9Z/
MX9^2X9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z)X9Z^
M(.&>D^&?A>*`B^&>EN&?@>&>F^*`B^&>A>&>MN&>E.&?B^*`B^&>E>&?DN&>
MC^&>ON&>F.*`B^&>D^&?@^*`B^&>@>&?@L*@/R(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")296YA;6EN9R!<(B5S7"(@
M=&\@7"(E<UPB(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9"(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGI3AGY+AGH_AGKSAGIKB@(OAGHCA
MGY+AGICAGX3AGX<@7"(E<UPB(.&>D>&?A2!<(B5S7"(@X9Z4X9ZVX9Z3XH"+
MX9Z4X9Z:X9ZVX9Z'X9^0X9Z9PJ#AGY0@X9Z3X9^!X9^'XH"+X9Z"X9ZZXH"+
MX9Z'X9ZVXH"+X9ZBX9^2X9Z<X9ZXXH"+X9Z*X9^"X9Z;XH"+X9Z8X9^)X9ZV
MX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+
MX9Z3X9ZWX9Z9X9ZVX9Z9(@H*(SH@;65S<V%G92YP:'`Z-30S"FUS9VED(")2
M97!L7WD@=&\@3&ES="(*;7-G<W1R(")?6>&>AN&?DN&>F^&>ON&>F>*`B^&>
MC^&>E.*`B^&>D>&?A>*`B^&>E.&>B>&?DN&>A^&>N"`B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C4P"FUS9VED(")297!L86-E('=I
M=&@Z(@IM<V=S='(@(N&>A^&?AN&>D^&>O>&>G^*`B^&>BN&?A.&>F<*@X9^6
M(@H*(SH@;65S<V%G92YP:'`Z-30P"FUS9VED(")297!L>2(*;7-G<W1R("+A
MGH;AGY+AGIOAGK[AGIGB@(OAGH_AGI0B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,S$R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3`*;7-G
M:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>AN&?DN&>
MF^&>ON&>F>*`B^&>C^&>E.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>E>&?DN&>B>&>OB(*"B,Z(&UE<W-A9V4N<&AP.C4T.0IM<V=I9"`B
M4F5P;'D@=&\@06QL(@IM<V=S='(@(N&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>
ME.*`B^&>D>&?A>*`B^&>D>&>MN&?AN&>A.*`B^&>HN&>G^&?BR(*"B,Z(&-O
M;7!O<V4N<&AP.C0P-@IM<V=I9"`B4F5P;'D@=&\@06QL.B(*;7-G<W1R("+A
MGH;AGY+AGIOAGK[AGIGB@(OAGH_AGI3B@(OAGI'AGX7B@(OAGI'AGK;AGX;A
MGH3B@(OAGJ+AGI_AGXO"H.&?EB(*"B,Z(&UE<W-A9V4N<&AP.C4T,PIM<V=I
M9"`B4F5P;'D@=&\@3&ES="(*;7-G<W1R("+AGH;AGY+AGIOAGK[AGIGB@(OA
MGH_AGI3B@(OAGI'AGX7B@(OAGI3AGHGAGY+AGH?AGK@B"@HC.B!C;VUP;W-E
M+G!H<#HT,#@*;7-G:60@(E)E<&QY('1O($QI<W0Z(@IM<V=S='(@(N&>AN&?
MDN&>F^&>ON&>F>*`B^&>C^&>E.*`B^&>D>&?A>*`B^&>E.&>B>&?DN&>A^&>
MN,*@X9^6(@H*(SH@;65S<V%G92YP:'`Z-30Y"FUS9VED(")297!L>2!T;R!?
M06QL(@IM<V=S='(@(E]!X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4XH"+X9Z1
MX9^%X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+("(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,S`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S.0HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30Y"FUS9VED(")297!L>2!W
M:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R("+AGH;AGY+AGIOA
MGK[AGIGB@(OAGH_AGI3B@(OAGHKAGX3AGIGB@(OB@(OAGI_AGK;AGIKB@(OA
MGHKAGX+AGIOB@(OAGICAGK?AGI/B@(OAGH+AGK;AGX;AGI'AGY+AGIHB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,W"FUS9VED(")297!L>2!W
M:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`BX9Z&
MX9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4X9Z*X9^$X9Z9(.&>D>&?AN&>D^&?@>&>
MFB_AGIKAGISAGIOAGXL@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+(.&?HB#A
MGH'AGX+B@(OAGI3AGI/AGY+AGI'AGK;AGI3AGXO"H.&?E"(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU,S8*;7-G:60@(E)E<&QY('=I=&@@<F5Q
M=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`BX9Z&X9^2
MX9Z;X9Z^X9Z9XH"+X9Z/X9Z4XH"+X9Z*X9^$X9Z9XH"+XH"+X9Z6X9^0X9Z/
MX9^,X9Z8X9ZVX9Z3XH"+(.&>D>&?AN&>D^&?@>&>FB_AGIKAGISAGIOAGXL@
MX9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z?X9^2X9Z3X9Z^XH"+X9Z?X9Z[
MX9^&PJ#AGY0B"@HC.B!M97-S86=E+G!H<#HR,S8*;7-G:60@(E)E<&QY+51O
M(@IM<V=S='(@(N&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E.*`BRWAGI'AGX4B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,34T.0IM<V=I9"`B4F5P;'DM5&\Z("(*
M;7-G<W1R("+AGH;AGY+AGIOAGK[AGIGB@(OAGH_AGI3B@(LMX9Z1X9^%PJ#A
MGY8@(@H*(SH@8V]M<&]S92YP:'`Z-#`T"FUS9VED(")297!L>3HB"FUS9W-T
M<B`BX9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4PJ#AGY8B"@HC.B!M97-S86=E
M+G!H<#HV,#<@;6%I;&)O>"YP:'`Z-3$T"FUS9VED(")297!O<G0@87,@26YN
M;V-E;G0B"FUS9W-T<B`BX9Z:X9ZVX9Z9X9Z`X9ZVX9Z:X9Z.X9^-XH"+X9Z0
MX9ZVXH"+X9Z;X9^2X9ZB(@H*(SH@;65S<V%G92YP:'`Z-3DY(&UA:6QB;W@N
M<&AP.C4P-@IM<V=I9"`B4F5P;W)T(&%S(%-P86TB"FUS9W-T<B`BX9Z:X9ZV
MX9Z9X9Z`X9ZVX9Z:X9Z.X9^-XH"+X9Z'X9ZVXH"+X9Z?X9ZVX9Z:XH"+X9ZE
MX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9ZVX9Z:(@H*(SH@8V]M<&]S92YP:'`Z
M,3(W,`IM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`B
M7U+AGI_AGY+AGI/AGK[B@(OAGI_AGKOAGX;B@(OAGI3AGH3AGY+AGH#AGK;A
MGI/AGXOB@(OAGHKAGX/B@(OAGJ+AGK;AGI/B@(OAGICAGKWAGID@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X-0IM<V=I9"`B4F5Q=65S="!R96%D
M(')E8V5I<'1S/R(*;7-G<W1R("+AGI_AGY+AGI/AGK[B@(OAGI_AGKOAGX;B
M@(OAGI3AGH3AGY+AGH#AGK;AGI/AGXOB@(OAGHKAGX/B@(OAGJ+AGK;AGI/"
MH#\B"@HC.B!M86EL8F]X+G!H<#HQ,S$*;7-G:60@(E)E<75E<W1E9"!M97-S
M86=E(&YO="!F;W5N9"XB"FUS9W-T<B`BX9Z:X9Z`XH"+X9Z8X9ZWX9Z3XH"+
MX9Z#X9Z^X9Z)XH"+X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3
MXH"+X9Z?X9^2X9Z3X9Z^XH"+X9Z?X9Z[X9^&PJ#AGY0B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-CDR"FUS9VED(")297%U:7)E9"!087)T:6-I
M<&%N="(*;7-G<W1R("+AGJ+AGY+AGI/AGH#B@(OAGH7AGKSAGIOB@(OAGIKA
MGKWAGICB@(OAGHKAGX+AGIOB@(OAGI'AGK;AGICAGI'AGK;AGIHB"@HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L871E<R]S96%R8V@O<V5A
M<F-H+FAT;6PZ,CD*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:'1M;#HQ
M.#$*;7-G:60@(E)E<V5T(@IM<V=S='(@(N&>@.&?AN&>CN&>C^&?B^*`B^&>
MH>&>ON&>A.*`B^&>G.&>M^&>B2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,38*;7-G:60@(E)E<W!O;F1E;G0@4W1A='5S(%5P9&%T960N(@IM
M<V=S='(@(N&>G^&?DN&>D.&>MN&>D^&>E^&>MN&>EN*`B^&>AN&?DN&>F^&>
MON&>F>*`B^&>C^&>E.*`BR#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI'AGK;AGI/AGXOB@(OA
MGI_AGICAGY#AGIG"H.&?E"(*"B,Z(&UE<W-A9V4N<&AP.C4X-PIM<V=I9"`B
M4F5S=6UE(@IM<V=S='(@(N&>DN&?DN&>G.&>ON*`B^&>E.&>D^&?DN&>CR(*
M"B,Z(&QO9VEN+G!H<#HQ.#$*;7-G:60@(E)E<W5M92!Y;W5R('-E<W-I;VXB
M"FUS9W-T<B`BX9Z2X9^2X9Z<X9Z^XH"+X9Z4X9Z3X9^2X9Z/XH"+X9Z?X9Z8
MX9^0X9Z9XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0T"FUS9VED(")2971U<FX@
M=&\@7")-97-S86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`BX9Z/X9^2X9Z:
MX9ZAX9Z4X9^+XH"+X9Z1X9^%(%PBX9Z`X9ZVX9Z:XH"+X9Z/X9^"X9Z$XH"+
MX9Z?X9ZVX9Z:7"(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S
M96QE8W0N:6YC.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV
M.0HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS
M,@IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`BX9Z/X9^2
MX9Z:X9ZAX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z`X9ZVX9Z3X9^+(%PBX9Z1X9^%
MXH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`XH"+X9Z?X9^&X9Z4X9Z[
MX9Z/X9^2X9Z:7"(B"@HC.B!F:6QT97)P<F5F<RYP:'`Z-3,@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHQ,#$*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C
M=&EV92YI;F,Z,34@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T.0HC.B!T96UP
M;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,34@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$V,PHC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3<U"FUS9VED(")2
M971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("+AGH_AGY+AGIKAGJ'AGI3AGXOB
M@(OAGI'AGX7B@(OAGH?AGICAGY+AGIKAGK[AGI\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S,P"FUS9VED("(B"B)2971U<FX@=&\@=&AE(&UA:6QB
M;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG
M(&$@;65S<V%G93\B"FUS9W-T<B`BX9Z/X9^2X9Z:X9ZAX9Z4X9^+XH"+X9Z1
MX9^%XH"+X9Z`X9ZVX9Z:XH"+X9Z:X9ZVX9Z9XH"+X9Z:X9Z4X9Z?X9^+XH"+
MX9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:(.&>
ME.&>D^&?DN&>D>&>MN&>E.&?B^&>EN&>N.*`B^&>F^&>N^&>E"#AGI7AGY+A
MGIOAGK;AGI_AGXOB@(OAGI'AGK@@X9ZL(.&>A>&>F.&?DN&>F^&>A.*`B^&>
MG^&>MN&>FN*`B^&>F.&>O>&>F<*@/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV.#,*;7-G:60@(E)O;&4B"FUS9W-T<B`BX9Z/X9Z]X9Z3X9ZV
MX9Z1X9ZX(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HT,C0*;7-G:60@(E,O34E-12(*;7-G<W1R(")3+TU)344B
M"@HC.B!L:6(O24U0+G!H<#HQ,S(Q"FUS9VED(")3+TU)344@16YC<GEP="!-
M97-S86=E(@IM<V=S='(@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,3$W-@IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS
M9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?(%,O34E-1<*@X9^6("(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ,34U"FUS9VED(")3+TU)344@17)R;W(Z($YE960@<&%S
M<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(N&>
M@.&?AN&>H.&>N^&>GR!3+TU)347"H.&?EB#AGH_AGY+AGIKAGKSAGISB@(OA
MGH#AGK;AGIKB@(OAGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;AGH_A
MGXL@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+
MX9ZOX9Z`X9Z'X9Z3XH"+X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;
MX9Z]X9Z3PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34R"FUS
M9VED(")3+TU)344@3W!T:6]N<R(*;7-G<W1R("+AGH?AGICAGY+AGIKAGK[A
MGI\@4R]-24U%(@H*(SH@<VUI;64N<&AP.C0V"FUS9VED(")3+TU)344@4&%S
M<W!H<F%S92!);G!U="(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGI3AGHGAGY+A
MGH7AGKSAGIOB@(OAGH/AGY+AGIOAGK;B@(OAGI_AGICAGY+AGH3AGK;AGH_A
MGXL@4R]-24U%(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM
M<V=I9"`B4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E
M<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BX9Z`X9ZVX9Z:
MXH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:XH"+X9Z"X9Z\XH"+X9Z`X9Z\X9Z3X9Z?
MX9^$XH"+X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]X9Z3(%,O
M34E-12#AGI'AGK;AGICB@(OAGI'AGK;AGIKB@(OAGH#AGK;AGIKB@(OAGH_A
MGI?AGY+AGH?AGK;AGI3AGXOB@(OAGH_AGK;AGICB@(OAGI3AGH[AGY+AGH_A
MGK;AGHGB@(OAGI_AGKOAGISAGH_AGY+AGI#AGK?AGI?AGK;AGI;"H.&?E"(*
M"B,Z('-M:6UE+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%
M(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T
M960N(@IM<V=S='(@(N&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>
MFN&>CN&?B"!3+TU)344@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+(%PB)7-<(B#A
MGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI3B@(OAGHKA
MGX3AGIGB@(OAGH?AGX3AGH+AGH?AGY#AGIG"H.&?E"(*"B,Z('-M:6UE+G!H
M<#HQ-3@*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A
M9&1E9"XB"FUS9W-T<B`BX9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZV
MX9Z:X9Z.X9^((%,O34E-12#AGH_AGY+AGIKAGKSB@(OAGISAGI3AGK;AGI/B
M@(OAGI3AGI/AGY+AGI#AGX+AGICB@(OAGHKAGX3AGIGB@(OAGH?AGX3AGH+A
MGH?AGY#AGIG"H.&?E"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,3`*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")3+TU)
M344@4'5B;&EC($ME>7)I;F<B"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")3
M+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C97-S9G5L;'D@861D
M960N(@IM<V=S='(@(N&>@N&>O.*`B^&>@.&>O.&>D^&>G^&?A"#AGI_AGK;A
MGI+AGK;AGIKAGH[AGX@OX9ZOX9Z`X9Z'X9Z3(%,O34E-12#AGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGI/AGY+AGI#AGX+AGICB@(OAGHKA
MGX3AGIGB@(OAGH?AGX3AGH+AGH?AGY#AGIG"H.&?E"(*"B,Z(&QI8B])35`N
M<&AP.C$S,C(*;7-G:60@(E,O34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B
M4R]-24U%(%-I9VX@365S<V%G92(*"B,Z(&QI8B])35`N<&AP.C$S,C,*;7-G
M:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")3+TU)
M344@4VEG;B]%;F-R>7!T($UE<W-A9V4B"@HC.B!T96UP;&%T97,O<VUI;64O
M;F]T86-T:79E+FEN8SHT"FUS9VED(")3+TU)344@<W5P<&]R="!I<R!D:7-A
M8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z"
MX9ZVX9^&X9Z1X9^2X9Z:(%,O34E-1>*`BR#AGH+AGKKB@(OAGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB
M@(OAGI3AGY+AGIKAGK[B@(OAGIOAGX+AGH3B@(OAGI3AGK;AGI/B@(OAGIOA
MGK[B@(OAGI3AGY+AGIKAGI;AGY#AGI/AGY+AGI+B@(OAGI/AGX'AGX?"H.&?
ME"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"FUS9VED("(B
M"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L960@<V\@
M=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E9"XB"FUS
M9W-T<B`B(@HBX9Z`X9ZVX9Z:XH"+X9Z"X9ZVX9^&X9Z1X9^2X9Z:(%,O34E-
M12#AGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+AGI/B@(OAGICAGK?A
MGI/B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISA
MGK[B@(OAGK+AGY+AGIGAGI3AGY+AGIKAGK[B@(OAGI3AGK;AGI,@X9Z*X9Z\
MX9Z%X9^2X9Z3X9^!X9^'XH"+X9Z?X9ZVX9Z:XH"+X9Z8X9ZWX9Z3XH"+X9ZB
MX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9Z8X9^2X9Z;X9^"X9Z$
MXH"+X9Z8X9Z`XH"+X9Z'X9ZVXH"+X9Z7X9ZVX9Z6XH"+X9Z2X9Z8X9^2X9Z8
MX9Z/X9ZVPJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W
M,PIM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@
M=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N;F]T("(*
M(F)E(&1I<W!L87EE9"XB"FUS9W-T<B`B(@HBX9Z`X9ZVX9Z:XH"+X9Z"X9ZV
MX9^&X9Z1X9^2X9Z:(%,O34E-12#AGICAGK?AGI/B@(OAGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OA
MGI3AGY+AGIKAGK[B@(OAGI3AGK;AGI/B@(OAGJ'AGK[AGID@X9Z*X9Z\X9Z%
MX9^2X9Z3X9^!X9^'XH"+X9Z8X9ZVX9Z/X9ZWX9Z`X9ZVXH"+X9Z:X9Z4X9Z?
MX9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z%
MX9Z[X9^'XH"+X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZVXH"+X9Z3X9^!X9^'
M(.&>D^&>N>&>A.*`B^&>F.&>M^&>D^*`BR(*(N&>HN&>MN&>A>*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>A.&?DN&>H.&>MN&>B>*`
MB^&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES
M(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B
M;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(N&>@.&>MN&>FN*`
MB^&>@N&>MN&?AN&>D>&?DN&>FB!3+TU)344@X9Z8X9ZWX9Z3XH"+X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2
MX9Z9XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9(.&>
MBN&>O.&>A>&?DN&>D^&?@>&?A^*`B^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>
MMN*`B^&>C.&>N.&>A^&>N.&>D.&>F^*`B^&>D^&>N>&>A.*`B^&>F.&>M^&>
MD^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>E>&?DN&>D>&?@.&>A.&>E>&?DN&>D>&>MN&>C^&?B^*`BR(*(N&>E.&>
MMN&>D^*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P
M;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@
M(@HB8W5R<F5N=&QY('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO
M=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-
M24U%(&9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"B+AGH#AGK;AGIKB@(OAGH+AGK;AGX;AGI'AGY+AGIH@4R]-24U%(.&>
MD>&>MN&>F.&>D>&>MN&>FN*`B^&>LN&?DN&>F>*`B^&>E.&?DN&>FN&>ON*`
MB^&>E.&>A.&?DN&>HN&>O>&>A>*`B^&>F^&?@>&>A>&>H>&>ON&>A,*@X9^4
M(.&>E.&>ON*`B^&>@.&>F.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>FN&>N^&>
M@.&>FN&>@.*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>@.&?
MAN&>EN&>N^&>A.*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>E.&>
MA.&?DN&>HN&>O>&>A>*`B^&>F^&?@>&>A>&>H>&>ON&>A.*`B^&>E.&?DN&>
MFN&>ON*`BR(*(N&>F^&?@N&>A.*`B^&>E.&>MN&>DR#AGJ+AGY+AGI/AGH#B
M@(OAGH_AGY+AGIKAGKSAGISB@(OAGH_AGX+B@(OAGI7AGY+AGIOAGK;AGI_A
MGXOAGI3AGY+AGHKAGKSAGIKB@(OAGH#AGK;AGIKB@(OAGH#AGX;AGH[AGH_A
MGXOB@(OAGI/AGX'AGX<@X9Z4X9Z^XH"+X9Z6X9Z[X9^&XH"+X9Z3X9^$X9^'
MXH"+X9Z1X9^!XH"+X9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z6X9ZWX9Z?X9^!
MX9Z?(%,O34E-12#AGI/AGKGAGH3B@(OAGICAGK?AGI/B@(OAGHKAGX;AGH[A
MGK[AGIKAGH#AGK;AGIKB@(OAGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSA
MGISB@(LB"B+AGJ'AGK[AGIG"H.&?E"(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYH=&UL.C$P-0IM<V=I9"`B4TU44"(*;7-G<W1R(")33510(@H*(SH@
M8V]M<&]S92YP:'`Z,3$W.0IM<V=I9"`B4U]U8FIE8W0B"FUS9W-T<B`B7U7A
MGI3AGY+AGIKAGI+AGK;AGI/B@(OAGI3AGI$@(@H*(SH@8V]M<&]S92YP:'`Z
M,3(T.0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R(")?5N&>FN&>
M@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>A>&?DN&>E.&>MN&>E.&?B^*`
MB^&>A>&>F.&?DN&>F^&>A.*`B^&>@.&?DN&>D^&>N^&>A"`B"@HC.B!M97-S
M86=E+G!H<#HU.3(*;7-G:60@(E-A7W9E(&%S(@IM<V=S='(@(E]6X9Z:X9Z`
MX9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+X9Z'X9ZV("(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T97,O<V5A<F-H+W-E
M87)C:"YH=&UL.C(X"B,Z('1E;7!L871E<R]S96%R8V@O<V5A<F-H+FAT;6PZ
M,3@P"FUS9VED(")3879E(@IM<V=S='(@(N&>FN&>@.&?DN&>G^&>MN*`B^&>
MD>&>N^&>@"(*"B,Z(&-O;7!O<V4N<&AP.C$S,C,*;7-G:60@(E-A=F4@071T
M86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_(@IM
M<V=S='(@(N&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>K^&>@.&>
MG^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>A^&>MN&>F.&>O>&>
MF>*`B^&>G^&>MN&>FN*`BR#AGH#AGY+AGI/AGKOAGH3B@(OAGI#AGH_B@(OA
MGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B
M@(OAGI7AGY+AGHGAGK["H#\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FAT;6PZ,C,@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C(P
M-@IM<V=I9"`B4V%V92!$<F%F="(*;7-G<W1R("+AGIKAGH#AGY+AGI_AGK;B
M@(OAGI'AGKOAGH`@XH"+X9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZXXH"+X9Z6X9^2
MX9Z:X9ZVX9Z$(@H*(SH@<V%V96EM86=E+G!H<#HU,0IM<V=I9"`B4V%V92!)
M;6%G92(*;7-G<W1R("+AGIKAGH#AGY+AGI_AGK;AGI'AGKOAGH#B@(OAGIKA
MGKSAGI3AGI?AGK;AGI8B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C,Q
M"FUS9VED(")3879E($EM86=E(&EN($=A;&QE<GDB"FUS9W-T<B`BX9Z:X9Z`
MX9^2X9Z?X9ZVX9Z1X9Z[X9Z`XH"+X9Z:X9Z\X9Z4X9Z7X9ZVX9Z6XH"+X9Z`
MX9^2X9Z3X9Z[X9Z$XH"+X9Z<X9ZWX9Z%X9ZWX9Z/X9^2X9Z:X9Z?X9ZVX9Z;
M(@H*(SH@9FEL=&5R<')E9G,N<&AP.C$Q-"!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ
M,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O
M;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@
M(N&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`BR#AGH?AGICAGY+AGIKA
MGK[AGI\B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#`*
M;7-G:60@(E-A=F4@4W1A=&EO;F5R>2(*;7-G<W1R("+AGIKAGH#AGY+AGI_A
MGK;AGI'AGKOAGH#B@(OAGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#A
MGY+AGIKAGX3AGIGB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIHB"@HC.B!C;VUP
M;W-E+G!H<#HQ,#DT"FUS9VED(")3879E(%]$<F%F="(*;7-G<W1R(")?1.&>
MFN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>G^&?@>&>A>&>@.&?DN&>
MC^&>N.&>EN&?DN&>FN&>MN&>A"`B"@HC.B!M97-S86=E+G!H<#HU.3(*;7-G
M:60@(E-A=F4@87,B"FUS9W-T<B`BX9Z:X9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[
MX9Z`XH"+X9Z'X9ZV(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM
M<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R("+AGIKAGH#A
MGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGI_AGX'AGH7AGH#AGY+AGH_AGKCB
M@(OAGI;AGY+AGIKAGK;AGH3B@(OAGH?AGK;B@(OAGICAGK?AGI/B@(OAGI3A
MGK;AGI/B@(OAGICAGK[AGIOB@(OAGJS"H#\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3,R"FUS9VED(")3879E(&1R869T<R!A=71O;6%T:6-A;&QY
M('=H:6QE(&-O;7!O<VEN9S\B"FUS9W-T<B`BX9Z:X9Z`X9^2X9Z?X9ZVX9Z1
MX9Z[X9Z`XH"+X9Z?X9^!X9Z%X9Z`X9^2X9Z*X9ZXX9Z6X9^2X9Z:X9ZVX9Z$
MXH"+X9Z*X9^$X9Z9XH"+X9Z?X9^2X9Z<X9^0X9Z9X9Z4X9^2X9Z:X9Z<X9Z/
MX9^2X9Z/X9ZW(.&>@>&>CN&?B.*`B^&>EN&?@>&>F^*`B^&>C^&?@N&>A,*@
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@S"FUS9VED(")3879E
M(')E8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R
M97-S(&)O;VL_(@IM<V=S='(@(N&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>
M@.*`B^&>HN&?DN&>D^&>@.&>D>&>D>&>O>&>F^*`B^&>D>&>MN&?AN&>A.&>
MH>&>MN&>F2#AGI'AGX7B@(OAGH#AGK;AGI/AGXOB@(OAGI_AGX#AGISAGI?A
MGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGIOAGX;AGI/A
MGK;AGX;B@(OAGHKAGK[AGICB@(OB@(OAGHKAGX3AGIGB@(OAGI_AGY+AGISA
MGY#AGIGB@(OAGI3AGY+AGIKAGISAGH_AGY+AGH_AGK?"H#\B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YH=&UL.C$W,@IM<V=I9"`B4V%V92!S96%R
M8V@@87,@82!V:7)T=6%L(&9O;&1E<C\B"FUS9W-T<B`BX9Z:X9Z`X9^2X9Z?
MX9ZVXH"+X9Z1X9Z[X9Z`XH"+X9Z`X9ZVX9Z:XH"+X9Z?X9^2X9Z<X9^"X9Z$
MXH"+X9Z:X9Z`(.&>A^&>MN*`B^&>D.&>C^*`B^&>D^&>M^&>F.&?DN&>F.&>
MM^&>C^&>F.&>O>&>F>&>K,*@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,S$*;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R("+AGIKAGH#A
MGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB
M@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/AGI7AGY+AGHGAGK[B@(OAGJSB@(OA
MGI'AGX'"H#\B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,34P"FUS9VED(")3879I
M;F<@=&AE(&1R869T(&9A:6QE9"X@0V]U;&0@;F]T(&-R96%T92!A(&1R869T
M<R!F;VQD97(N(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>FN&>@.&?DN&>G^&>
MMN&>D>&>N^&>@.*`B^&>G^&?@>&>A>&>@.&?DN&>BN&>N.&>EN&?DN&>FN&>
MMN&>A.*`B^&>E.&>MN&>D^*`B^&>E.&>FN&>MN&>A^&?D.&>F<*@X9^4(.&>
MF.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>
MD.&>C^*`B^&>G^&?@>&>A>&>@.&?DN&>BN&>N.&>EN&?DN&>FN&>MN&>A.*`
MB^&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C@Y"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@3F\@9')A
M9G0@9F]L9&5R('-P96-I9FEE9"XB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z:
MX9Z`X9^2X9Z?X9ZVX9Z1X9Z[X9Z`XH"+X9Z?X9^!X9Z%X9Z`X9^2X9Z*X9ZX
MX9Z6X9^2X9Z:X9ZVX9Z$XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0
MX9Z9PJ#AGY0@X9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z0X9Z/XH"+X9Z?
MX9^!X9Z%X9Z`X9^2X9Z*X9ZXX9Z6X9^2X9Z:X9ZVX9Z$XH"+X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z'X9ZVX9Z`X9^+XH"+
MX9Z;X9Z8X9^2X9ZBX9ZWX9Z/PJ#AGY0B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,38U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I
M;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R
M("+AGH#AGK;AGIKB@(OAGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OA
MGI_AGX'AGH7AGH#AGY+AGH_AGKCAGI;AGY+AGIKAGK;AGH3B@(OAGI3AGK;A
MGI/B@(OAGI3AGIKAGK;AGH?AGY#AGIG"H.&?E"#AGI/AGX'AGX?B@(OAGH+A
MGKKB@(OAGH?AGK;B@(OAGJ+AGY+AGISAGKCB@(OAGHKAGX+AGIOB@(OAGICA
MGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI3AGK;A
MGI/AGI/AGK?AGIGAGK;AGIG"H.&?EB`E<R(*"B,Z(&UA:6QB;W@N<&AP.C,U
M-B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS.0HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:'1M;#HR-0IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(N&>G^&?DN&>G.&?@N&>A.*`B^&>FN&>@"(*"B,Z(&UA:6QB;W@N<&AP
M.C,U-B!S96%R8V@N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R
M8V@@)7,B"FUS9W-T<B`BX9Z?X9^2X9Z<X9^"X9Z$XH"+X9Z:X9Z`("5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM<V=I9"`B4V5A<F-H($]P
M=&EO;G,B"FUS9W-T<B`BX9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z?X9^2X9Z<
MX9^"X9Z$X9Z:X9Z`(@H*(SH@<V5A<F-H+G!H<#HQ-C4*;7-G:60@(E-E87)C
M:"!297-U;'1S(@IM<V=S='(@(N&>F^&>D>&?DN&>DN&>E>&>F^*`B^&>G^&?
MDN&>G.&?@N&>A.*`B^&>FN&>@"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYH=&UL.C$Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.C(V
M"FUS9VED(")3965N(@IM<V=S='(@(N&>E.&>MN&>D^*`B^&>F.&>ON&>FR(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW,`IM<V=I9"`B
M4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G<W1R("+AGH?AGY+AGIKAGK[A
MGI_B@(OAGH+AGH[AGI/AGKCB@(OAGICAGKWAGIGB@(OAGI7AGY+AGI_AGX'A
MGH0B"@HC.B!S96%R8V@N<&AP.C,Q,0IM<V=I9"`B4V5L96-T(&$@9&%T92(*
M;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_B@(OAGH#AGK;AGIOAGI3AGIKAGK?A
MGH7AGY+AGH;AGX'AGI$B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YH
M=&UL.C4U"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R("+AGH?AGY+A
MGIKAGK[AGI_B@(OAGISAGK;AGILB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,V"FUS9VED(")396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R
M(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S='(@
M(N&>A^&?DN&>FN&>ON&>G^*`B^&>E.&?DN&>FN&>E^&>EN*`B^&>G^&?@.&>
MG.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DR#AGI_AGICA
MGY+AGIKAGK;AGI3AGXOB@(OAGI3AGI/AGY+AGI#AGX+AGI@@X9Z3X9ZWX9Z$
M(.&>G^&?DN&>G.&?@N&>A.*`B^&>FN&>@.*`B^&>HN&>MN&>G^&>F>&>BN&?
MDN&>B^&>MN&>D\*@X9^4XH"+(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:'1M;#HQ-#$*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`BX9Z'X9^2
MX9Z:X9Z^X9Z?XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(S"FUS9VED(")396QE8W0@
M86QL(&9I96QD<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S
M+B(*;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_B@(OAGISAGK;AGIOB@(OAGHKA
MGX+AGIOB@(OAGH_AGY+AGIKAGKSAGISB@(OAGI_AGY+AGISAGX+AGH3B@(OA
MGIKAGH#B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXL@X9Z6X9^!X9Z;XH"+X9Z6
MX9Z$X9^2X9Z:X9ZXX9Z`XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3
MPJ#AGY0B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T
M+FEN8SHR,0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`BX9Z'
MX9^2X9Z:X9Z^X9Z?XH"+X9Z"X9Z.X9Z3X9ZX(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:'1M;#HQ-#(*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S
M='(@(N&>A^&?DN&>FN&>ON&>G^*`B^&>@N&?DN&>F.&>MN&>DR(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HQ,S,*;7-G:60@(E-E;&5C
M="!S=&%T:6]N97)Y.B(*;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_B@(OAGI7A
MGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGIGB@(OAGI_A
MGX;AGI3AGKOAGH_AGY+AGIK"H.&?EB(*"B,Z('1E;7!L871E<R]S879E:6UA
M9V4O<V%V96EM86=E+FAT;6PZ.`IM<V=I9"`B4V5L96-T('1H92!G86QL97)Y
M('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R("+AGH?AGY+AGIKAGK[A
MGI_B@(OAGISAGK?AGH7AGK?AGH_AGY+AGIKAGI_AGK;AGIL@X9Z*X9Z^X9Z8
MX9^2X9Z4X9ZXXH"+X9Z:X9Z`X9^2X9Z?X9ZVX9Z1X9Z[X9Z`XH"+X9Z:X9Z\
MX9Z4X9Z7X9ZVX9Z6XH"+X9Z3X9^%XH"+X9Z`X9^2X9Z3X9Z[X9Z$PJ#AGY0B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C(Q
M"FUS9VED(")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T<B`B
MX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z4X9^2X9Z:X9Z7X9^!X9Z1XH"+X9Z8X9^)
MX9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z?X9^&X9Z4
MX9Z[X9Z/X9^2X9Z:(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT
M;6PZ-@IM<V=I9"`B4V5L96-T.B(*;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_"
MH.&?EB(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P
M.0IM<V=I9"`B4V5L96-T960@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`BX9Z?
MX9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+
MX9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z'X9^2X9Z:X9Z^X9Z?PJ#AGY8B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(E-E;F0@2V5Y
M('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`BX9Z4X9Z)X9^2X9Z'X9Z\
MX9Z3XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z1X9^%XH"+X9Z8X9^)X9ZVX9Z?
MX9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z`X9Z\X9Z3X9Z?X9^$
MXH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^((@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4Y-PIM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I;VXB
M"FUS9W-T<B`BX9Z5X9^2X9Z)X9Z^XH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3
MXH"+X9Z0X9^2X9Z8X9ZXXH"+X9Z4X9^&X9Z5X9Z[X9Z/(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C(Q('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:'1M;#HR,#0*;7-G:60@(E-E;F0@365S<V%G92(*;7-G<W1R
M("+AGI7AGY+AGHGAGK[B@(OAGI_AGK;AGIHB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]J879A<V-R:7!T+FEN8SHQ,3D*;7-G:60@(E-E;F0@;65S<V%G92!W
M:71H;W5T(&$@4W5B:F5C=#\B"FUS9W-T<B`BX9Z5X9^2X9Z)X9Z^XH"+X9Z?
MX9ZVX9Z:XH"+X9Z*X9^$X9Z9XH"+X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z4X9^2
MX9Z:X9Z2X9ZVX9Z3X9Z4X9Z1PJ`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<Q-0IM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T
M960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`BX9Z5X9^2X9Z)X9Z^XH"+X9Z4
MX9Z$X9^2X9Z`X9ZVX9Z3X9^+X9Z*X9^#XH"+X9Z4X9ZVX9Z3XH"+X9ZBX9ZV
MX9Z3(.&>D^&?A>*`B^&>EN&?@>&>F^*`B^&>E.&>MN&>D^*`B^&>G^&?DN&>
MD^&>ON*`B^&>BN&?A.&>F>*`B^&>HN&?DN&>D^&>@.*`B^&>E>&?DN&>B>&>
MOL*@/R(*"B,Z(&QI8B])34%0+U1R964N<&AP.C,X-0IM<V=I9"`B4V5N="!M
M86EL(&9O;&1E<B(*;7-G<W1R("+AGI#AGH_B@(OAGI_AGX;AGI3AGKOAGH_A
MGY+AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI7AGY+AGHGAGKXB
M"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,X"FUS
M9VED(")396YT(&UA:6P@9F]L9&5R.B(*;7-G<W1R("+AGI#AGH_B@(OAGI_A
MGX;AGI3AGKOAGH_AGY+AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OA
MGI7AGY+AGHGAGK["H.&?EB(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYH
M=&UL.C,V('1E;7!L871E<R]L;V=I;B]L;V=I;BYH=&UL.C4P"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYH=&UL.C8R"FUS9VED(")397)V97(B"FUS9W-T
M<B`BX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S"FUS9VED(")397)V97(@86YD
M($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G<W1R("+AGI;AGY#AGH_AGXSAGICA
MGK;AGI/B@(OAGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKA
MGKX@X9Z3X9ZWX9Z$(.&>D.&>CR(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHR,PIM<V=I9"`B4V5R=F5R.B(*;7-G<W1R("+AGICAGXGA
MGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK["H.&?EB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,0IM<V=I9"`B4V5T('!R969E<F5N8V5S
M(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE
M<W-A9V5S+B(*;7-G<W1R("+AGH#AGX;AGH[AGH_AGXOB@(OAGH7AGX;AGH[A
MGH3AGXOB@(OAGH7AGX;AGH[AGKSAGIOAGH7AGK?AGH_AGY+AGH_AGI#AGK;B
M@(OAGJ+AGY+AGISAGKCB@(OAGI/AGKGAGH3B@(OAGH_AGY+AGIKAGKSAGISB
M@(OAGH#AGK[AGH_AGJ'AGK[AGH0@X9Z6X9^!X9Z;XH"+X9ZBX9^2X9Z3X9Z`
MXH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+X9Z1X9ZX(.&>D^&>M^&>A"#AGIOAGKOA
MGI3B@(OAGI_AGK;AGIK"H.&?E"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-#$*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C
M;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(N&>@.&?AN&>CN&>C^&?B^*`
MB^&>E.&>B^&>F.&>@.&>D.&>MN*`B^&>HN&>MN&>D>&>M^&>E^&>MN&>EB!8
M(.&>EN&?@>&>F^*`B^&>C^&?@N&>A.*`B^&>G^&>MN&>FL*@/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*
M;7-G<W1R("+AGH7AGX+AGH#B@(OAGIKAGX;AGIOAGX+AGH#B@(OAGI#AGH\B
M"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.#8*;7-G:60@(E-H87)E(&UA
M:6P@9F]L9&5R<R(*;7-G<W1R("+AGH7AGX+AGH#B@(OAGIKAGX;AGIOAGX+A
MGH#B@(OAGI#AGH_B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F
M;VQD97)S('=I=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@(N&>A>&?@N&>@.*`
MB^&>FN&?AN&>F^&?@N&>@.*`B^&>D.&>C^*`B^&>G^&?AN&>E.&>N^&>C^&?
MDN&>FN*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@"#AGH?AGK;AGICA
MGKWAGIGB@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGK[B@(OAGI7AGY+A
MGI_AGX'AGH3"H.&?E"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*
M;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@
M8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T
M;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B
M(@HBX9Z'X9ZVXH"+X9Z;X9^&X9Z3X9ZVX9^&XH"+X9Z*X9Z^X9Z8XH"+(.&>
MC^&>ON*`B^&>E.&>CN&?DN&>C^&>N^&?AN*`B^&>DN&?AN&>D^&?@^*`B^&>
MHN&>C^&?DN&>D.&>E.&>D>*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>
MG^&?DN&>FN&>A.&?BR#AGH+AGKWAGIKB@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGI3AGK;AGI/B@(OAGI3AGH3AGY+AGJ#AGK;AGHD@X9ZL(.&>F^&>MN&>@.&?
MB^*`B^&>K.*`B^&>D>&?@<*@/R#AGICAGKWAGIGB@(OAGH[AGK;B@(OAGH#A
MGX_B@(OAGHKAGX3AGIGB@(OAGHKAGX+AGIOB@(OAGJ+AGY+AGI/AGH#B@(OA
MGH?AGY+AGIKAGK[AGI\@(@HBX9Z<X9ZVXH"+X9ZBX9ZVX9Z%XH"+X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9ZWX9Z1XH"+X9Z4X9Z^X9Z`
MXH"+X9Z*X9^$X9Z9XH"+X9Z$X9ZVX9Z9X9Z?X9^2X9Z:X9Z]X9Z;PJ#AGY0B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM<V=I9"`B4VAO=6QD('1H
M92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE9"!F;W(@
M4$=0(&1A=&$_(@IM<V=S='(@(N&>C^&>ON*`B^&>C^&>O>*`B^&>D^&?@^*`
MB^&>G^&>MN&>FN*`B^&>HN&>C^&?DN&>D.&>E.&>D2_AGI+AGICAGY+AGICA
MGH_AGK8@X9Z"X9Z]X9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3
MXH"+X9Z<X9ZWX9Z7X9ZVX9Z"(.&>G^&>F.&?DN&>FN&>MN&>E.&?B^*`B^&>
MD>&>M^&>D^&?DN&>D^&>D^&?D.&>F2!01U`@X9ZLXH"+X9Z1X9^!PJ`_XH"+
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q-`IM<V=I9"`B4VAO=6QD
M('1H92!C;VUP;W-E('=I;F1O=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@
M9')A9G0_(@IM<V=S='(@(N&>C^&>ON*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`
MB^&>C^&?@N&>A.*`B^&>@N&>O>&>FN*`B^&>C^&?@N*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>M^&>D2#AGI3AGI/AGY+AGI'AGK;A
MGI3AGXOB@(OAGI;AGKCB@(OAGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B
M@(OAGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI;AGY+AGIKAGK;AGH3B@(OA
MGJSAGI'AGX'"H#\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I
M9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@
M=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*;7-G<W1R("+AGH_AGK[B
M@(OAGH#AGKSAGI/B@(OAGI_AGX3B@(OAGI_AGK;AGI+AGK;AGIKAGH[AGX@@
M4$=0(.&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@.*`BR#AGH+AGKWAGIKB
M@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI?AGY+AGH?AGK;A
MGI3AGXOB@(OAGI'AGX7B@(OAGI_AGK;AGIKB@(OAGIKAGI3AGI_AGXOB@(OA
MGJ+AGY+AGI/AGH#B@(OB@(OAGH?AGK;B@(OAGIOAGX;AGI/AGK;AGX;B@(OA
MGHKAGK[AGICB@(OAGJSB@(OAGI'AGX'"H#\B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+W-E87)C:"YH=&UL.C$T-`IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*
M;7-G<W1R("+AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI#AGH_B@(OAGI'AGK;A
MGX;AGH3B@(OAGJ+AGI_AGXLB"@HC.B!M97-S86=E+G!H<#HV-S@*;7-G:60@
M(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)
MXH"+X9Z4X9Z+X9Z8X9Z`X9Z0X9ZVXH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+
M(@H*(SH@;6%I;&)O>"YP:'`Z,C<P"FUS9VED(")3:&]W($1E;&5T960B"FUS
M9W-T<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)(%PBX9Z4X9ZVX9Z3XH"+X9Z;X9Z[
MX9Z47"(B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3@*;7-G:60@
M(E-H;W<@26UA9V5S/R(*;7-G<W1R("+AGI3AGH3AGY+AGJ#AGK;AGHGB@(OA
MGIKAGKSAGI3AGI?AGK;AGI;"H#\B"@HC.B!M97-S86=E+G!H<#HV-S(*;7-G
M:60@(E-H;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(N&>E.&>A.&?DN&>
MH.&>MN&>B2!<(N&>E.&>B^&>F.&>@.&>D.&>MN*`B^&>BN&?@N&>F^*`B^&>
ME.&>MN&>D^*`B^&>@.&>F.&?DN&>FN&>M^&>CUPB(@H*(SH@;65S<V%G92YP
M:'`Z-C@Q"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*
M;7-G<W1R("+AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI;AGY#AGH_AGXSAGICA
MGK;AGI/B@(OAGIKAGI3AGI_AGXOB@(OAGI3AGHGAGY+AGH?AGKCB@(OAGI_A
MGX;AGI3AGKOAGH_AGY+AGIKB@(OAGIKAGKWAGI@B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+W-E87)C:"YH=&UL.C$T-`IM<V=I9"`B4VAO=R!/;FQY(%-U8G-C
M<FEB960@1F]L9&5R<R(*;7-G<W1R("+AGI3AGH3AGY+AGJ#AGK;AGHGB@(OA
MGH_AGX+B@(OAGI#AGH_B@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGH?A
MGK;AGIPB"@HC.B!F;VQD97)S+G!H<#HR.30*;7-G:60@(E-H;W<@56YS=6)S
M8W)I8F5D(@IM<V=S='(@(N&>E.&>A.&?DN&>H.&>MN&>B2!<(N&>E.&>MN&>
MD^*`B^&>B.&>E.&?B^*`B^&>A^&>MN&>G%PB(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8P.`IM<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T
M<FEP<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*;7-G<W1R
M("+AGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGIKAGKSAGI3B@(OAGH_AGX;AGH[A
MGK;AGH3B@(OAGHKAGX+AGIOB@(OAGJ+AGI/AGKOAGHGAGY+AGHGAGK;AGH_B
M@(OAGK+AGY+AGIGB@(OAGH7AGY+AGI3AGKSAGH_B@(OAGJ_AGH#AGI_AGK;A
MGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGH7AGX'AGHGB@(OAGI;AGKCB
M@(OAGI_AGK;AGIKB@(OAGJS"H#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`Q,PIM<V=I9"`B4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE
M=S\B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z/X9ZVX9Z$(.&>
M@.&?DN&>D^&>N^&>A.*`B^&>D>&>M^&>BN&?DN&>B^&>E^&>MN&>EN*`B^&>
ME.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FL*@/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-3$*;7-G:60@(E-H;W<@<')E
M=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R("+AGI3A
MGH3AGY+AGJ#AGK;AGHGB@(OAGICAGK[AGIOB@(OAGH?AGK;B@(OAGICAGKOA
MGI,@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z/X9^"XH"+X9Z?X9ZVX9Z:
MXH"+X9Z8X9ZWX9Z3XH"+X9Z1X9ZVX9Z3X9^+XH"+X9ZBX9ZVX9Z3PJ`_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U.0IM<V=I9"`B4VAO=R!P<F5V
M:65W<R!I;B!T;V]L=&EP<S\B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)
MXH"+X9Z8X9Z^X9Z;XH"+X9Z'X9ZVXH"+X9Z8X9Z[X9Z3(.&>A^&>MN*`B^&>
MEN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>A^&?AN&>D^&>O>&>F<*@/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.#@*;7-G:60@(E-H;W<@=&AE($9E
M=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`BX9Z4X9Z$
MX9^2X9Z@X9ZVX9Z)XH"+X9Z:X9Z\X9Z4XH"+X9Z/X9^&X9Z.X9ZVX9Z$(%PB
MX9Z1X9^%XH"+X9Z4X9^2X9Z:X9Z8X9Z\X9Z;XH"+X9Z9X9Z`XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:7"(@X9Z;X9Z^XH"+X9Z:X9Z4X9ZVX9Z:XH"+X9Z8
MX9^)X9ZZX9Z3X9Z[X9Z9PJ`_(@H*(SH@9FEL=&5R<')E9G,N<&AP.CDY"FUS
M9VED(")3:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS
M9W-T<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z:X9Z\X9Z4X9Z/X9^&X9Z.
MX9ZVX9Z$XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z/X9Z8X9^2X9Z:X9Z$XH"+X9Z;
MX9Z^XH"+X9Z:X9Z4X9ZVX9Z:XH"+X9Z8X9^)X9ZZX9Z3X9Z[X9Z9PJ`_(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,V"FUS9VED(")3:&]W('1O=&%L
M(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(N&>E.&>A.&?
MDN&>H.&>MN&>B>*`B^&>A>&?AN&>D^&>O>&>D^*`B^&>G^&?AN&>E.&>N^&>
MC^&?DN&>FN*`B^&>G^&>FN&>N^&>E.*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>
MD.&>C\*@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C8*;7-G:60@
M(E-H;W=N(@IM<V=S='(@(N&>E.&>MN&>D^*`B^&>E.&>A.&?DN&>H.&>MN&>
MB2(*"B,Z(&UA:6QB;W@N<&AP.C4Y,`IM<V=I9"`B4VE?>F4B"FUS9W-T<B`B
M7UKAGI'AGX;AGJ#AGX8@(@H*(SH@;6%I;&)O>"YP:'`Z.3@T('1E;7!L871E
M<R]M86EL8F]X+VQE9V5N9"YH=&UL.C$U"FUS9VED(")3:6=N960B"FUS9W-T
M<B`BX9Z4X9ZVX9Z3XH"+X9Z%X9Z[X9^'XH"+X9Z@X9Z/X9^2X9Z0X9Z;X9^!
MX9Z!X9ZV(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C,Q
M-`IM<V=I9"`B4VEZ93HB"FUS9W-T<B`BX9Z1X9^&X9Z@X9^&PJ#AGY8B"@HC
M.B!M86EL8F]X+G!H<#HU-3D*;7-G:60@(E-O<G0@8GD@07)R:79A;"(*;7-G
M<W1R("+AGH_AGICAGY+AGIKAGX#AGI3B@(OAGH_AGK;AGICB@(OAGH#AGK;A
MGIKB@(OAGICAGH#B@(OAGHKAGIOAGXLB"@HC.B!M86EL8F]X+G!H<#HU-C0*
M;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R("+AGH_AGICAGY+AGIKAGX#A
MGI3B@(OAGH_AGK;AGICB@(OAGH#AGK;AGIOB@(OAGI3AGIKAGK?AGH7AGY+A
MGH;AGX'AGI$B"@HC.B!M86EL8F]X+G!H<#HU-S0*;7-G:60@(E-O<G0@8GD@
M1G)O;2!!9&1R97-S(@IM<V=S='(@(N&>C^&>F.&?DN&>FN&?@.&>E.*`B^&>
MC^&>MN&>F.*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DR!<(N&>EN&>
MN%PB(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y"FUS9VED(")3;W)T(&)Y($UE<W-A
M9V4@4VEZ92(*;7-G<W1R("+AGH_AGICAGY+AGIKAGX#AGI3B@(OAGH_AGK;A
MGICB@(OAGI'AGX;AGJ#AGX;B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIHB
M"@HC.B!M86EL8F]X+G!H<#HU.#0*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*
M;7-G<W1R("+AGH_AGICAGY+AGIKAGX#AGI3B@(OAGH_AGK;AGICB@(OAGI3A
MGY+AGIKAGI+AGK;AGI/B@(OAGI3AGI$B"@HC.B!M86EL8F]X+G!H<#HU-SD*
M;7-G:60@(E-O<G0@8GD@5&AR96%D(@IM<V=S='(@(N&>C^&>F.&?DN&>FN&?
M@.&>E.*`B^&>C^&>MN&>F.*`B^&>@>&?DN&>G^&?@N*`B^&>HN&?AN&>E.&?
MA.&?AR(*"B,Z(&UA:6QB;W@N<&AP.C4V.0IM<V=I9"`B4V]R="!B>2!4;R!!
M9&1R97-S(@IM<V=S='(@(N&>C^&>F.&?DN&>FN&?@.&>E.*`B^&>C^&>MN&>
MF.*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`BR!<(N&>D>&?A5PB
M(@H*(SH@;&EB+TE-05`O5')E92YP:'`Z,S<Y"FUS9VED(")3<&%M(&9O;&1E
M<B(*;7-G<W1R("+AGI#AGH_B@(OAGI_AGK;AGIKB@(OAGJ7AGH_B@(OAGI3A
MGK;AGI/B@(OAGH#AGK;AGIKB@(LB"@HC.B!T96UP;&%T97,O<')E9G,O<W!A
M;7-E;&5C="YI;F,Z,C,*;7-G:60@(E-P86T@9F]L9&5R.B(*;7-G<W1R("+A
MGI#AGH_B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OAGJ7AGH_B@(OA
MGI3AGK;AGI/AGH#AGK;AGIK"H.&?EB(*"B,Z(&-O;7!O<V4N<&AP.C$R,S@*
M;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G<W1R("+AGH_AGKWAGJ+A
MGH#AGY+AGI_AGIKB@(OAGI;AGK?AGI_AGX'AGI\B"@HC.B!S96%R8V@N<&AP
M.C4S"FUS9VED(")3<&5C:6%L(%9I<G1U86P@1F]L9&5R<R!C86YN;W0@8F4@
M961I=&5D+B(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGH#A
MGX+AGI_AGICAGY+AGIKAGKWAGIOB@(OAGI#AGH_B@(OAGI/AGK?AGICAGY+A
MGICAGK?AGH_B@(OAGI;AGK?AGI_AGX'AGI_B@(OAGI3AGK;AGI/B@(OAGJ'A
MGK[AGIG"H.&?E"(*"B,Z(&-O;7!O<V4N<&AP.C$R,S0*;7-G:60@(E-P96QL
M($-H96-K(@IM<V=S='(@(N&>EN&>M^&>D^&>M^&>C^&?DN&>F>*`B^*`B^&>
MHN&>@.&?DN&>@>&>FN&>MN&>G.&>M^&>FN&>N^&>D>&?DN&>DB(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FAT;6PZ,3D*;7-G:60@(E-P96QL
M($-H96-K97(B"FUS9W-T<B`BX9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZXXH"+
MX9Z6X9ZWX9Z3X9ZWX9Z/X9^2X9Z9XH"+XH"+X9ZBX9Z`X9^2X9Z!X9Z:X9ZV
MX9Z<X9ZWX9Z:X9Z[X9Z1X9^2X9Z2(@H*(SH@8V]M<&]S92YP:'`Z.3<S"FUS
M9VED(")3<&5L;"!C:&5C:R!C;VUP;&5T92(*;7-G<W1R("+AGH#AGK;AGIKB
M@(OAGI;AGK?AGI/AGK?AGH_AGY+AGIGB@(OAGJ+AGH#AGY+AGH'AGIKAGK;A
MGISAGK?AGIKAGKOAGI'AGY+AGI+B@(OAGI3AGK;AGI/B@(OAGI3AGHGAGY+A
MGH7AGI3AGXOB@(OAGI'AGK;AGX;AGH3B@(OAGI_AGY+AGIKAGKOAGH0B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C(Q"FUS9VED(")3
M<&5L;"!C:&5C:R!C;VUP;&5T92`M($YO('-P96QL:6YG(&5R<F]R<R(*;7-G
M<W1R("+AGH#AGK;AGIKB@(OAGI;AGK?AGI/AGK?AGH_AGY+AGIGAGJ+AGH#A
MGY+AGH'AGIKAGK;AGISAGK?AGIKAGKOAGI'AGY+AGI+B@(OAGI3AGK;AGI/B
M@(OAGI3AGHGAGY+AGH7AGI3AGXOB@(OAGJ#AGK[AGID@+2#AGICAGK?AGI/B
M@(OAGICAGK;AGI/B@(OAGH#AGX;AGJ#AGKOAGI_B@(OAGJ+AGH#AGY+AGH'A
MGIKAGK;AGISAGK?AGIKAGKOAGI'AGY+AGI+B@(OAGJ'AGK[AGIDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<R"FUS9VED(")3<&5L;&EN9R!E<G)O
M<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R("+A
MGH#AGX;AGJ#AGKOAGI_B@(OAGJ+AGH#AGY+AGH'AGIKAGK;AGISAGK?AGIKA
MGKOAGI'AGY+AGI+B@(OAGH#AGY+AGI/AGKOAGH3B@(OAGICAGKWAGIGB@(OA
MGJ+AGX'AGH#AGY+AGIKAGH3AGXL@X9Z6X9^!X9Z;XH"+X9Z6X9ZWX9Z3X9ZW
MX9Z/X9^2X9Z9X9ZBX9Z`X9^2X9Z!X9Z:X9ZVX9Z<X9ZWX9Z:X9Z[X9Z1X9^2
MX9Z2PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`W(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#D*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8T,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C0T"FUS
M9VED(")3=&%R="(*;7-G<W1R("+AGH7AGK;AGI3AGXOAGI7AGY+AGH_AGK[A
MGI@B"@HC.B!C;VUP;W-E+G!H<#HQ,C$Y('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHY"FUS9VED(")3=&%T:6]N97)Y(@IM<V=S='(@(N&>E>&?
MDN&>D>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F>*`B^&>G^&?
MAN&>E.&>N^&>C^&?DN&>FB(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHR-@IM<V=I9"`B4W1A=&EO;F5R>2!N86UE.B(*;7-G<W1R("+A
MGHCAGY+AGICAGX3AGX?B@(OAGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OA
MGH#AGY+AGIKAGX3AGIGB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIK"H.&?EB(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR.`IM<V=I9"`B
M4W1A=&EO;F5R>2!T>7!E.B(*;7-G<W1R("+AGI3AGY+AGIKAGI?AGX'AGI'B
M@(OAGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGIGB
M@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIK"H.&?EB(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB"FUS
M9W-T<B`BX9Z5X9^2X9Z1X9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$
MX9Z9XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:PJ#AGY8B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C@S"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B
MX9Z?X9^2X9Z0X9ZVX9Z3X9Z7X9ZVX9Z6(@H*(SH@;&EB+TU)344O0V]N=&5N
M=',N<&AP.C(T,@IM<V=I9"`B4W1R:7`@071T86-H;65N="(*;7-G<W1R("+A
MGH7AGY+AGI3AGKSAGH_B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?A
MGK;AGI3AGXOB@(OAGH7AGX'AGHDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#0S"FUS9VED(")3=')I<"!L:6YE8G)E86MS/R(*;7-G<W1R("+AGH7A
MGY+AGI3AGKSAGH_B@(OAGH#AGK;AGIKB@(OAGH7AGKOAGX?B@(OAGI3AGI/A
MGY+AGI'AGK;AGH_AGXOB@(OAGH7AGX'AGHG"H#\B"@HC.B!M86EL8F]X+G!H
M<#HU.#4*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(E]*X9Z4X9^2X9Z:X9Z2
MX9ZVX9Z3X9Z4X9Z1("(*"B,Z(&UE<W-A9V4N<&AP.C(S-R!T:')E860N<&AP
M.C$U,B!L:6(O4V5A<F-H+G!H<#HV,3D*(SH@=&5M<&QA=&5S+VQO9VEN+W)E
M8V]M<&]S92YH=&UL.C0Q"FUS9VED(")3=6)J96-T(@IM<V=S='(@(N&>E.&?
MDN&>FN&>DN&>MN&>D^&>E.&>D2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,S$*;7-G:60@(E-U8FIE8W0@1FEE;&0B"FUS9W-T<B`BX9Z<X9ZVX9Z;
MXH"+XH"+X9Z4X9^2X9Z:X9Z2X9ZVX9Z3X9Z4X9Z1(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E;7!L871E<R]P9W`O<&%S<W!H
M<F%S92YI;F,Z,S$*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:'1M;#HR
M."!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YH=&UL.C$X,`HC.B!T96UP;&%T
M97,O<V%V96EM86=E+W-A=F5I;6%G92YH=&UL.C$X"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`BX9Z*X9ZVX9Z`X9^+XH"+X9Z?X9^2X9Z3X9Z^(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH=&UL.C$S"FUS9VED(")3=6)S8W)I
M8F4@=&\@1F]L9&5R*',I(@IM<V=S='(@(N&>A^&>MN&>G.*`B^&>E.&?DN&>
MFN&>A>&>MN&?AN*`B^&>D>&?A>*`B^&>D.&>CR(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,S@U(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y
M-PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX-PIM<V=I9"`B4W5C
M8V5S<R(*;7-G<W1R("+AGH?AGX3AGH+AGH?AGY#AGIDB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C0P"FUS9VED(")3=6=G97-T:6]N
M<R(*;7-G<W1R("+AGIGAGX3AGI3AGIOAGXLB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C4Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C$*
M;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BX9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZX
MXH"+X9Z?X9Z$X9^2X9Z!X9^!X9Z4(@H*(SH@8V]M<&]S92YP:'`Z,3(W-2!C
M;VUP;W-E+G!H<#HQ,C<V"FUS9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T
M:&]D(@IM<V=S='(@(N&>E.&?DN&>C^&>O.&>FN*`B^&>G.&>M^&>DN&>N.*`
MB^&>G^&>MN&>G^&?DN&>C^&?DN&>FN*`B^&>C^&?@N&>A"(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HQ.#D*;7-G:60@(E-W:71C:"!T
M;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(N&>E.&?DN&>C^&>O.&>FN*`
MB^&>D>&?A>*`B^*`B^&>@.&>MN&>FN&>C^&?@N&>A.*`BR!(5$U,(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C$X.0IM<V=I9"`B4W=I
M=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`BX9Z4X9^2
MX9Z/X9Z\X9Z:XH"+X9Z1X9^%XH"+X9Z`X9ZVX9Z:XH"+X9Z/X9^"X9Z$XH"+
MX9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z2X9Z8X9^2X9Z8X9Z/X9ZV(@H*(SH@
M8V]M<&]S92YP:'`Z,3(X,`IM<V=I9"`B5&5?>'0B"FUS9W-T<B`B7UCAGJ+A
MGH_AGY+AGI#AGI3AGI$@(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C(W,`IM<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`BX9Z4X9Z.X9^2X9Z*
MX9^$X9^'X9ZBX9ZVX9Z?X9Z3X9^2X9Z3PJ#AGY8@(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4X-@IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T
M(')E<75E<W0B"FUS9W-T<B`BX9Z6X9^2X9Z:X9Z8XH"+X9Z1X9Z1X9Z]X9Z;
MXH"+X9Z?X9^&X9Z.X9Z^XH"+X9Z'X9ZVXH"+X9Z4X9Z.X9^2X9Z*X9^$X9^'
MXH"+X9ZBX9ZVX9Z?X9Z3X9^2X9Z3(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<U-`IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T
M<B`BX9Z4X9ZVX9Z3XH"+X9Z1X9Z1X9Z]X9Z;XH"+X9Z'X9ZVXH"+X9Z4X9Z.
MX9^2X9Z/X9^$X9^'XH"+X9ZBX9ZVX9Z?X9Z3X9^2X9Z3(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&5R;7,@;V8@4V5R=FEC92!F:6QE(&YO="!S<&5C:69I
M960@:6X@8V]N9BYP:'`B"FUS9W-T<B`BX9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z;
MX9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,XH"+X9Z3X9^#XH"+X9Z?X9^!X9Z<X9ZV
M(.&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>
ME.&>B>&?DN&>A^&>MN&>@.&?B^*`B^&>@.&?DN&>D^&>N^&>A"!C;VYF+G!H
M<"(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I
M9"`B5&5X="(*;7-G<W1R("+AGJ+AGH_AGY+AGI#AGI3AGI$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.38U"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN
M(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@(N&>
MEN&>N,*@X9^6(.&>A^&>O>&>FN&>B.&>FN*`B^&>FN&>E.&>G^&?B^*`B^&>
MG^&>MN&>FN*`B^&>@N&>O>&>FN*`B^&>C^&?@N*`B^&>C^&?DN&>FN&>O.&>
MG.*`B^&>E.&>MN&>D^*`B^&>C^&>E^&?DN&>A^&>MN&>E.&?B\*@X9^6(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,S`*;7-G:60@(B(*(E1H92!)34%0
M('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@875T:&5N
M=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+AGICAGXGA
MGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGKX@24U!4"#AGI'AGX;A
MGI/AGH3B@(OAGH?AGK;B@(OAGICAGK?AGI/B@(OAGH+AGK;AGX;AGI'AGY+A
MGIKB@(OAGISAGK?AGI+AGKCAGI_AGK;AGI_AGY+AGH_AGY+AGIKB@(OAGI7A
MGY+AGI'AGX#AGH3AGI7AGY+AGI'AGK;AGH_AGXOB@(OAGHKAGX+AGIOB@(OA
MGI3AGK;AGI/B@(OAGH?AGY+AGIKAGK[AGI_B@(OAGJ'AGK[AGIG"H.&?E"#A
MGI_AGKSAGICB@(OAGI'AGK;AGH#AGXOAGI'AGH3B@(OAGJ+AGY+AGI/AGH#B
M@(OAGH+AGY+AGIKAGI3AGXOAGH+AGY+AGIKAGH3B@(OAGI3AGY+AGIKAGI;A
MGY#AGI/AGY+AGI+B@(LB"B+AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#"
MH.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*
M;7-G:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R("+A
MGI7AGY+AGI/AGX+AGH#B@(OAGI+AGI/AGI+AGK;AGI/B@(OAGIKAGI3AGI_A
MGXL@36%C:6YT;W-H(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE
M+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E
M<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(N&>
ME>&?DN&>D^&?@N&>@.*`B^&>DN&>D^&>DN&>MN&>D^*`B^&>FN&>E.&>G^&?
MBR!-86-I;G1O<V@@X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z1X9ZVX9Z)X9Z9X9Z`XH"+("5SPJ#AGY0B"@HC.B!F971C
M:&UA:6QP<F5F<RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C
M8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(N&>@N&>
MCN&>D^&>N"!<(B5S7"(@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9Z;X9Z[X9Z4PJ#AGY0B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R("+AGH+AGH[AGI/AGK@@7"(E<UPB(.&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>
MN^&>@,*@X9^4(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A
M='1A8VAM96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(N&>K^&>@.&>G^&>
MMN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>F.&>M^&>D^*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>FN&>@.&>@^&>ON&>B<*@X9^4
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q"FUS9VED(")4:&4@
M8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(N&>D>&>M^&>D^&?
MDN&>D^&>D^&?D.&>F>*`B^&>E.&?DN&>FN&>C^&>M^&>D>&>M^&>D^*`B^&>
MF.&>M^&>D^*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>
MH>&>ON&>F2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V]M<&]S
M95]W:6XN:G,Z,S<*;7-G:60@(B(*(E1H92!C;VUP;W-E('=I;F1O=R!C86XG
M="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E
M<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"B+AGICA
MGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGK[AGH#B@(OAGI3AGH3AGY+AGJ+A
MGKWAGH7B@(OAGH_AGX+AGH3B@(OAGI3AGK;AGI/B@(OAGI'AGX'"H.&?E"#A
MGI3AGY+AGIKAGJ#AGX+AGIOB@(OAGH?AGK;B@(OAGJ+AGY+AGI/AGH#B@(OA
MGI3AGK;AGI/B@(OAGH#AGX;AGH[AGH_AGXOB@(OAGH#AGICAGY+AGICAGISA
MGK?AGI+AGKCB@(OAGIKAGKOAGH#AGIKAGH#B@(OAGIKAGI3AGI_AGXOB@(OA
MGJ+AGY+AGI/AGH#B@(L@X9ZRX9^2X9Z9XH"+X9Z1X9Z4X9^+XH"+X9Z?X9^2
MX9Z`X9ZVX9Z/X9^+XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%XH"+X9Z;X9^!X9Z%
MXH"+X9ZAX9Z^X9Z$PJ`_(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U
M8FQE+G!H<#HT,@IM<V=I9"`B5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O
M<V@@9FEL92!A<F4@8F5L;W<N(@IM<V=S='(@(N&>F.&>MN&>C^&>M^&>@.&>
MMN*`B^&>FN&>E.&>G^&?B^*`B^&>K^&>@.&>G^&>MN&>FB!-86-I;G1O<V@@
MX9Z"X9ZZXH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8PJ#AGY0B"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL
M>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L
M9&5R*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G
M<W1R("+AGI#AGH_B@(OAGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+A
MGI,@7"(E<UPB(.&>D^&>N>&>A.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>B.&?DN&>F.&?A.&?A^*`B^&>
MD>&?A>*`B^&>A^&>MB!<(B5S7"+"H.&?E"(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHQ,#<*;7-G:60@(B(*(E1H92!C=7)R96YT(&QI<W0@;V8@=7-E
M<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E
M=')I979E9"(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI'A
MGX7B@(OAGIGAGH#B@(OAGI3AGHGAGY+AGH?AGKCB@(OAGI3AGH7AGY+AGH7A
MGKOAGI3AGY+AGI3AGI/AGY+AGI/B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+A
MGI/AGH#AGI3AGY+AGIKAGKX@XH"+X9Z*X9^"X9Z;XH"+X9Z%X9Z\X9Z;XH"+
MX9Z*X9^&X9Z.X9Z^X9Z:X9Z`X9ZVX9Z:XH"+X9Z1X9^%XH"+X9Z0X9Z/XH"+
MX9Z3X9^!X9^'(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE(%PB
M)7-<(B!F;VQD97(N(@IM<V=S='(@(N&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`
MB^&>EN&?DN&>FN&>MN&>A.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>D>&?A>*`B^&>
MD.&>CR!<(B5S7"+"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ-#`*;7-G:60@(E1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE
M;F1A<BXB"FUS9W-T<B`BX9Z6X9^2X9Z:X9ZYX9Z/X9^2X9Z/X9ZWX9Z`X9ZV
MX9Z:X9Z.X9^-XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4
MX9Z3X9^2X9Z0X9^"X9Z8XH"+X9Z1X9^%XH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z1
MX9ZWX9Z3XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY0B"@HC
M.B!E>'!A;F0N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:65L
M9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@(N&>F.&>M^&>
MD^*`B^&>HN&>MN&>A>*`B^&>E.&>D^&?DN&>F^&>MN&>F>*`B^&>G.&>MN&>
MFR!<(B5S7"(@X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`BX9Z0X9Z/(%PB)7-<
M(B#AGICAGK;AGI/B@(OAGIKAGKWAGH7B@(OAGJ#AGK[AGIDB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HQ-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&9O
M;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET
M<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O8FQE;7,N(%!L96%S92!S964@
M>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBX9Z0X9Z/
M(%PB)7-<(B#AGICAGK;AGI/B@(OAGH_AGKWB@(OAGJ+AGH#AGY+AGI_AGIKB
M@(OAGH'AGKOAGI_B@(OAGH7AGY+AGI3AGK;AGI3AGXOAGH#AGY+AGI/AGKOA
MGH3B@(OAGHCAGY+AGICAGX3AGX?B@(OAGIKAGI3AGI_AGXOB@(OAGISAGK;"
MH.&?E"#AGISAGK;B@(OAGJ+AGK;AGH7B@(OAGI3AGH3AGY+AGH#B@(OAGI3A
MGHGAGY+AGJ#AGK;"H.&?E"#AGI_AGKSAGICB@(OAGH?AGKWAGI3B@(OAGH?A
MGK;AGICAGKWAGIGB@(OAGJ+AGY+AGI/AGH#B@(OAGH+AGY+AGIKAGI3AGXOB
M@(OAGH+AGY+AGIKAGH3B@(OAGI3AGY+AGIKAGI;AGY#AGI/AGY+AGI+B@(LB
M"B+AGIKAGI3AGI_AGXOAGJ+AGY+AGI/AGH#"H.&?E"(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@
M=&\@:70N(@IM<V=S='(@(N&>D.&>CR!<(B5S7"(@X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/(.&>E.&?B>&>N^&>
MD^&?DN&>C^&?@N*`B^&>HN&?DN&>D^&>@.*`B^&>F.&>M^&>D^*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>A^&>MN&>G.*`B^&>E.&?DN&>
MFN&>A>&>MN&?AN*`B^&>D>&?A>&>G.&>ML*@X9^4(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E
M<UPB('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D
M(&9R;VT@:70N(@IM<V=S='(@(N&>D.&>CR!<(B5S7"(@X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4(.&>E.&?B>&>N^&>D^&?DN&>
MC^&?@N*`B^&>HN&?DN&>D^&>@.*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>B.&>E.&?B^*`B^&>A^&>MN&>G.*`B^&>
MEN&>N.&>G.&>ML*@X9^4(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S0S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@8W)E
M871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R("+A
MGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OA
MGI#AGH\@7"(E<UPB(.&>H>&>ON&>F>*`B\*@X9^4(.&>D^&?@>&?A^*`B^&>
M@N&>NN*`B^&>A^&>MN*`B^&>HN&?DN&>G.&>N.*`B^&>BN&?@N&>F^*`B^&>
MF.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>E.&>
MMN&>D^&>D^&>M^&>F>&>MN&>F2(*"B,Z(&QI8B]&;VQD97(N<&AP.C(V,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T
M(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`BX9Z0X9Z/(%PB)7-<(B#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGH_A
MGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIOAGKOAGI3B@(OAGI3AGK;A
MGI/B@(OAGJ'AGK[AGIG"H.&?E"#AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OA
MGI3AGICAGY+AGIKAGK[B@(OAGI3AGK;AGI/B@(OAGI#AGK;B@(OAGJ+AGHGA
MGY+AGH7AGKGAGH0B"@HC.B!L:6(O1F]L9&5R+G!H<#HS-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!C<F5A=&5D+B(*;7-G<W1R("+AGI#AGH\@7"(E<UPB(.&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>BN&?
MA.&>F>*`B^&>A^&?A.&>@N*`B^&>A^&?D.&>F<*@X9^4(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`BX9Z0
MX9Z/(%PB)7-<(B#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIOA
MGKOAGI3B@(OAGHKAGX3AGIGB@(OAGH?AGX3AGH+AGH?AGY#AGIG"H.&?E"(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C0V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@
M7"(E<UPB+B(*;7-G<W1R("+AGI#AGH\@7"(E<UPB(.&>C^&?DN&>FN&>O.&>
MG.*`B^&>E.&>MN&>D^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>B.&?DN&>F.&?
MA.&?A^*`B^&>D>&?A>*`B^&>A^&>MB!<(B5S7"(@X9Z*X9^$X9Z9XH"+X9Z'
MX9^$X9Z"XH"+X9Z'X9^0X9Z9PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z.30*;7-G:60@(E1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A
M='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@(N&>K^&>@.&>G^&>MN&>
MFN*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F.*`BR#AGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGI?AGY+AGH?AGK;AGI3AGXOB@(OAGI'A
MGX7B@(OAGH?AGK;AGICAGKWAGIGB@(OAGI7AGY+AGI/AGX+AGH#B@(OAGI/A
MGX'AGX?"H.&?EB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?<V%V
M96EM86=E7W=I;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN
M9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y
M;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T
M<B`B(@HBX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z^X9Z`XH"+X9Z4
MX9Z$X9^2X9ZBX9Z]X9Z%XH"+X9Z:X9Z`X9^2X9Z?X9ZVX9Z1X9Z[X9Z`XH"+
MX9Z:X9Z\X9Z4X9Z7X9ZVX9Z6XH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#A
MGY0@X9Z4X9^2X9Z:X9Z@X9^"X9Z;XH"+X9Z'X9ZVXH"+X9ZBX9^2X9Z3X9Z`
MXH"+X9Z4X9ZVX9Z3XH"+X9Z`X9^&X9Z.X9Z/X9^+XH"+X9ZRX9^2X9Z9XH"+
MX9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZXXH"+X9Z:X9Z[X9Z`X9Z:X9Z`XH"+
MX9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(.&>D>&>E.&?B^&>G^&?DN&>
M@.&>MN&>C^&?B^*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`BR(*(N&>F^&?@>&>
MA>&>H>&>ON&>A.*`B^&>H.&>ON&>F>*`B^&>F.&>ON&>F^*`B^&>D>&?A<*@
M/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4
M:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@97)R;W(@
M;65S<V%G93HB"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4
MX9Z8X9^2X9Z:X9Z^XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z4X9ZV
MX9Z3XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z?X9ZVX9Z:XH"+X9Z`X9^&
MX9Z@X9Z[X9Z?XH"+X9Z*X9Z\X9Z%XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:
MX9^$X9Z8PJ#AGY8B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HU,0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`BX9Z8
MX9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z$X9^2X9Z`X9Z^
MX9Z/XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^#X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3
MXH"+X9Z*X9Z\X9Z%X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8PJ#AGY8B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B5&AE
M(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z
M(@IM<V=S='(@(N&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>
MFN&>ON*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>E.&>MN&>D^*`B^&>
ME.&>A.&?DN&>@.&>ON&>C^*`B^&>G^&>MN&>FN*`B^&>BN&>O.&>A>*`B^&>
M@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F,*@X9^6(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C<R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;6%I;&)O>"`E
M<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R("+AGI3AGY+AGIKAGJ+AGI3A
MGXOB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH@)7,@X9Z"X9ZZXH"+X9Z1X9Z1
MX9^!XH"+X9Z:X9Z]X9Z%X9Z@X9Z^X9Z9PJ#AGY0B"@HC.B!L:6(O1F5T8VAM
M86EL+G!H<#HR-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A9V4@
M7"(E<UPB(&9R;VT@7"(E<UPB("@E9"!B>71E<RD@97AC965D<R!F971C:"!S
M:7IE(&QI;6ET+B(*;7-G<W1R("+AGI_AGK;AGIH@7"(E<UPB(.&>EN&>N"!<
M(B5S7"(@X9Z;X9Z^X9Z?("@E9"#AGI3AGX,I(.&>@.&>F.&?DN&>FN&>M^&>
MC^*`B^&>D>&?AN&>H.&?AN*`B^&>D>&>MN&>B>*`B^&>F>&>@.*`B\*@X9^4
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+VIA=F%S8W)I<'0N:6YC.C$P,PIM
M<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO
M<V5D+B!%>&ET:6YG+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGHKAGX+AGIOB
M@(OAGH#AGX;AGI;AGKOAGH3B@(OAGH_AGX+AGH3B@(L@X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9ZWX9Z1PJ#AGY0@X9Z%X9^!X9Z)PJ#A
MGY0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]J879A<V-R:7!T+FEN8SHQ,3D*
M;7-G:60@(E1H92!M97-S86=E(&1O97,@;F]T(&AA=F4@82!3=6)J96-T(&5N
M=&5R960N(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>F.&>M^&>D^*`B^&>F.&>
MMN&>D^*`B^&>E.&?DN&>FN&>DN&>MN&>D^&>E.&>D>*`B^&>H>&>ON&>F<*@
MX9^4(@H*(SH@;&EB+U-P86TN<&AP.C(Q-@IM<V=I9"`B5&AE(&UE<W-A9V4@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z;X9Z[X9Z4PJ#AGY0B"@HC.B!L
M:6(O4W!A;2YP:'`Z,C`R"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGI3AGK;AGI/B@(OAGIKAGK;AGIGAGH#AGK;AGIKAGH[AGXWB@(OAGI'AGX7B
M@(OAGJ+AGY+AGI/AGH#B@(OAGH+AGY+AGIKAGI3AGXOAGH+AGY+AGIKAGH3B
M@(OAGI3AGY+AGIKAGI;AGY#AGI/AGY+AGI+B@(OAGIKAGI3AGI_AGXOB@(OA
MGJ+AGY+AGI/AGH#B@(OAGI#AGK8@X9Z8X9ZWX9Z3XH"+X9Z8X9^"X9Z3XH"+
MX9Z'X9ZVXH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`
MX9ZVX9Z:XH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!L:6(O4W!A;2YP:'`Z,3@R
M"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@
M<W!A;2XB"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9Z4X9ZVX9Z3XH"+X9Z:X9ZVX9Z9X9Z`X9ZVX9Z:X9Z.X9^-XH"+X9Z0X9ZV
M(.&>F.&>M^&>D^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>G^&>MN&>FN*`
MB^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FN*`B^&>H>&>ON&>F<*@
MX9^4(@H*(SH@;&EB+U-P86TN<&AP.C$Y-`IM<V=I9"`B5&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGIKAGK;AGIGAGH#AGK;AGIKAGH[AGXWB@(OA
MGI'AGX7B@(OAGJ+AGY+AGI/AGH#B@(OAGH+AGY+AGIKAGI3AGXOAGH+AGY+A
MGIKAGH3B@(OAGI3AGY+AGIKAGI;AGY#AGI/AGY+AGI+B@(OAGIKAGI3AGI_A
MGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGI#AGK8@X9Z'X9ZVXH"+X9Z?X9ZVX9Z:
MXH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9ZVX9Z:PJ#AGY0B"@HC.B!L
M:6(O4W!A;2YP:'`Z,3<T"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIKAGK;AGIGAGH#AGK;AGIKAGH[A
MGXWB@(OAGI#AGK8@X9Z'X9ZVXH"+X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4
MX9ZVX9Z3XH"+X9Z`X9ZVX9Z:PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HT,#$*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF
M:65D+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGI3AGK;AGI/B@(OAGI7AGY+AGI'AGX#AGH3B@(OAGI7AGY+AGI'AGK;AGH_A
MGXO"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF
M:65D+B!396YD97(Z("5S+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI7AGY+AGI'AGX#AGH3B@(OAGI7A
MGY+AGI'AGK;AGH_AGXO"H.&?E"#AGJ+AGY+AGI/AGH#B@(OAGI7AGY+AGHGA
MGK["H.&?EB`E<\*@X9^4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]P9W!?=VEN+FIS.C@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]S
M;6EM95]W:6XN:G,Z.`IM<V=I9"`B(@HB5&AE('!A<W-P:')A<V4@=VEN9&]W
M(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B
M<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*
M(N&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>E.&>ON&>@.*`B^&>E.&>A.&?
MDN&>HN&>O>&>A>*`B^&>@^&?DN&>F^&>MN*`B^&>G^&>F.&?DN&>A.&>MN&>
MC^&?B\*@X9^4(.&>E.&?DN&>FN&>H.&?@N&>F^*`B^&>A^&>MN*`B^&>HN&?
MDN&>D^&>@.*`B^&>E.&>MN&>D^*`B^&>@.&?AN&>CN&>C^&?B^*`B^&>@.&>
MF.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>FN&>N^&>@.*`B^&>FN&>@.*`B^&>
MFN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@"#AGK+AGY+AGIGB@(OAGI'AGI3A
MGXOAGI_AGY+AGH#AGK;AGH_AGXOB@(OAGI3AGH3AGY+AGJ+AGKWAGH7B@(OA
MGIOAGX'AGH7AGJ'AGK[AGH3"H#\B"@HC.B!L:6(O34E-12]6:65W97(O=&YE
M9BYP:'`Z-C`*;7-G:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E
M>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("+AGJ_A
MGH#AGI_AGK;AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI_AGY+A
MGI/AGK[B@(OAGI_AGKOAGX8@X9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z`
MX9^2X9Z3X9Z[X9Z$XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZV
MX9Z4X9^+($U3+51.14;"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8T"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI
M<W0@:6X@=&AE(%II<"!A='1A8VAM96YT+B(*;7-G<W1R("+AGJ_AGH#AGI_A
MGK;AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B@(OAGI_AGY+AGI/AGK[B
M@(OAGI_AGKOAGX;B@(L@X9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z`X9^2
MX9Z3X9Z[X9Z$XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4
MX9^+(%II<,*@X9^4(@H*(SH@;65S<V%G92YP:'`Z-#(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E
M<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`B
M"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E+B!0
M;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(N&>HN&?DN&>D^&>@.*`B^&>E>&?DN&>B>&>
MON*`B^&>G^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>@.&?AN&>EN&>N^&>A.*`
MB^&>G^&?DN&>D^&>ON*`B^&>G^&>N^&?AN*`BR!<(N&>@.&>MN&>FN*`B^&>
MA^&>O.&>D^*`B^&>BN&?AN&>CN&>N>&>A.*`B^&>A>&>FN&>M^&>C^*`B^&>
MFN&>E.&>G^&?B^*`B^&>G^&>MN&>FEPB(.&>EN&>N.*`B^&>HN&?DN&>D^&>
M@"#AGI;AGX'AGIOAGJ+AGY+AGI/AGH#B@(OAGI3AGK;AGI/B@(OAGJ+AGK;A
MGI/B@(OAGI_AGK;AGIKAGI/AGX'AGX?"H.&?E"#AGI_AGKSAGICB@(OAGH7A
MGKOAGH4@)7,@(@HBX9Z*X9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z5X9^2X9Z)X9Z^
MXH"+X9Z?X9ZVX9Z:XH"+X9Z'X9Z\X9Z3XH"+X9Z*X9^&X9Z.X9ZYX9Z$PJ#A
MGY0B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HV-PIM<V=I9"`B
M5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E871E(&$@=&AU;6)N86EL
M(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(N&>F.&?B>&>MN&>G^&?BN&>N.&>
MD^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`
MB^&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>
MC^&>O.&>A>&?E^*`B^&>D^&?@^*`B^&>FN&>O.&>E.&>E^&>MN&>EN*`B^&>
MD^&?@>&?A^*`B^&>E.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O:F%V87-C<FEP="YI;F,Z.#,*;7-G:60@(E1H92!S
M:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R("+AGJ#A
MGH_AGY+AGI#AGIOAGX'AGH'AGK;B@(OAGICAGK?AGI/B@(OAGJ+AGK;AGH7B
M@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGH?AGX;AGI/AGKWA
MGI_"H.&?E"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+VIA=F%S8W)I<'0N:6YC
M.C@Q"FUS9VED(")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P
M;&%C960N(@IM<V=S='(@(N&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>
MC^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>A^&?AN&>D^&>O>&>G^*`
MB^&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F<*@X9^4(@H*(SH@871T
M86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@9FEL92!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`BX9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z*X9^"
MX9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z'X9ZVX9Z`X9^+XH"+X9Z8
MX9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!S=&%T
M:6]N97)Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO
M;F5R>2!<(B5S7"(@:&%S(&)E96X@861D960N(@IM<V=S='(@(N&>E>&?DN&>
MD>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F>*`B^&>G^&?AN&>
ME.&>N^&>C^&?DN&>FB!<(B5S7"(@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZV
MX9Z3XH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8PJ#AGY0B"@HC.B!S=&%T:6]N97)Y
M+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BX9Z5X9^2X9Z1X9^#
MXH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9XH"+X9Z?X9^&X9Z4X9Z[
MX9Z/X9^2X9Z:(%PB)7-<(B#AGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGIOAGKOAGI3"H.&?E"(*"B,Z('-T871I;VYE<GDN<&AP.C@W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E
M;B!U<&1A=&5D+B(*;7-G<W1R("+AGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B
M@(OAGH#AGY+AGIKAGX3AGIGB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH@7"(E
M<UPB(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>DN&?DN&>G.&>
MON*`B^&>LN&?DN&>F>*`B^&>D>&>MN&>D^&?B^&>G^&>F.&?D.&>F<*@X9^4
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,`IM<V=I9"`B5&AE
M('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T
M<B`BX9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z3X9^2X9Z0X9^"X9Z8XH"+X9Z1X9^%XH"+
MX9Z4X9Z)X9^2X9Z'X9ZXXH"+X9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%XH"+
MX9Z:X9Z4X9Z?X9^+X9ZBX9^2X9Z3X9Z`PJ#AGY0B"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY-0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE
M<W-A9V4B"FUS9W-T<B`BX9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z:X9Z4X9Z?
MX9^+XH"+X9Z?X9ZVX9Z:(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP
M:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE
M<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`BX9ZBX9Z/X9^2X9Z0
MX9Z4X9Z1XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+X9ZBX9ZVX9Z%
MXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z8X9Z^X9Z;("5S
MPJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX,`IM<V=I
M9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`B
MX9ZBX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:
MXH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z/X9^2X9Z:X9ZAX9Z4X9^+
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@
M8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`BX9ZBX9Z/X9^2X9Z0X9Z4X9Z1
MXH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z*X9^"X9Z;XH"+X9Z4
MX9ZVX9Z3XH"+X9Z/X9^2X9Z:X9ZAX9Z4X9^+(.&>HN&>MN&>A>*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>F.&>ON&>F^*`BR`E<\*@X9^4
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*;7-G
M:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4B"FUS9W-T<B`BX9ZB
MX9Z/X9^2X9Z0X9Z4X9Z1XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+
MX9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z)X9Z^(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92!C86X@8F4@
M=FEE=V5D("5S+B(*;7-G<W1R("+AGJ+AGH_AGY+AGI#AGI3AGI'B@(OAGIKA
MGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OAGHKAGX+AGIOB@(OAGI3AGK;AGI/B
M@(OAGI7AGY+AGHGAGKX@X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9Z4X9ZVX9Z3XH"+X9Z8X9Z^X9Z;XH"+("5SPJ#AGY0B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,34U"FUS9VED(")4:&4@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G
M<W1R("+AGI;AGY#AGH_AGXSAGICAGK;AGI/B@(L@X9Z1X9^&X9Z3X9^!X9Z:
M+^&>FN&>G.&>F^&?B^*`BR#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#B
M@(OAGI3AGY+AGIKAGKX@X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9Z:X9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+X9Z*X9^$X9Z9XH"+X9Z'
MX9^$X9Z"X9Z'X9^0X9Z9PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O86QT
M97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I
M=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z5X9^2X9Z3X9^"X9Z`XH"+X9Z5X9^2
MX9Z?X9^!X9Z$XH"+X9Z*X9^"X9Z;XH"+X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z`
MX9^2X9Z3X9Z[X9Z$XH"+X9Z/X9Z]PJ#AGY0B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]E;7!T>5]M86EL8F]X+FAT;6PZ,@IM<V=I9"`B5&AE<F4@87)E(&YO
M(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O>"XB"FUS9W-T<B`BX9Z"X9^2X9Z8
MX9ZVX9Z3XH"+X9Z?X9ZVX9Z:XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z4X9^2
MX9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z3X9^!
MX9^'PJ#AGY0B"@HC.B!T:')E860N<&AP.C$P.0IM<V=I9"`B5&AE<F4@:7,@
M;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M("+AGICAGK?AGI/B@(OAGICAGK;AGI/B@(OAGJ+AGH_AGY+AGI#AGI3AGI$@
MX9Z*X9^"X9Z;XH"+X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z`X9^2X9Z3X9Z[X9Z$
MXH"+X9Z/X9Z]XH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!L
M:6(O365S<V%G92YP:'`Z-S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@<V5R
M=F5R('-A:60Z("5S(@IM<V=S='(@(N&>F.&>MN&>D^*`B^&>E.&>B>&?DN&>
MH.&>MN*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>E.&?AN&>
ME.&>MN&>C^&?B^*`B^&>A>&?A.&>F^*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`
MB^&>G^&?AN&>E.&>N^&>C^&?DN&>FL*@X9^4(.&>F.&?B>&>MN&>G^&?BN&>
MN.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>E.&>MN&>D^*`B^&>D^&>M^&>
MF>&>MN&>F>&>D.&>ML*@X9^6("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Q
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M8V]P>6EN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@
M:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`BX9Z8X9ZVX9Z3
MXH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z8X9Z]X9Z9(.&>@.&?DN&>D^&>N^&>
MA.*`B^&>@.&>MN&>FN*`B^&>A>&>F.&?DN&>F^&>A.*`B^&>G^&>MN&>FN*`
MB^&>EN&>N"!<(B5S7"(@X9Z1X9^%(%PB)7-<(L*@X9^4(.&>D^&?@>&?A^*`
MB^&>@N&>NN*`B^&>A^&>MN*`B^&>HN&?DN&>G.&>N.*`B^&>BN&?@N&>F^*`
MB^&>F.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>
ME.&>MN&>D^*`B^&>D^&>M^&>F>&>MN&>F2(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BX9Z8
MX9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z8X9Z]X9Z9(.&>@.&?DN&>
MD^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>F^&>N^&>E.*`B^&>G^&>MN&>FN*`
MB^&>EN&>N.&>D.&>CR!<(B5S7"+"H.&?E"#AGI/AGX'AGX?B@(OAGH+AGKKB
M@(OAGH?AGK;B@(OAGJ+AGY+AGISAGKCB@(OAGHKAGX+AGIOB@(OAGICAGXGA
MGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI3AGK;AGI/B
M@(OAGI/AGK?AGIGAGK;AGIDB"@HC.B!L:6(O365S<V%G92YP:'`Z,S(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE
M=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+AGICAGK;AGI/B@(OA
MGH#AGX;AGJ#AGKOAGI_B@(OAGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+
MX9Z`X9ZVX9Z:XH"+X9Z;X9Z[X9Z4XH"+X9Z?X9ZVX9Z:XH"+X9Z`X9^2X9Z3
MX9Z[X9Z$XH"+X9Z0X9Z/(%PB)7-<(L*@X9^4(.&>D^&?@>&?A^*`B^&>@N&>
MNN*`B^&>A^&>MN*`B^&>HN&?DN&>G.&>N.*`B^&>BN&?@N&>F^*`B^&>F.&?
MB>&>MN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>E.&>MN&>
MD^*`B^&>D^&>M^&>F>&>MN&>F2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(N&>F.&>MN&>
MD^*`B^&>@.&?AN&>H.&>N^&>G^*`B^&>F.&>O>&>F2#AGH#AGY+AGI/AGKOA
MGH3B@(OAGH#AGK;AGIKB@(OAGIOAGKOAGI3B@(OAGI;AGY+AGIKAGKGAGH_A
MGY+AGH_AGK?AGH#AGK;AGIKAGH[AGXW"H.&?EB`E<\*@X9^4(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR
M:6-H960N<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("+AGICAGK;AGI/B@(OA
MGH#AGX;AGJ#AGKOAGI_B@(OAGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+
MX9Z`X9ZVX9Z:XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z5X9^2X9Z3X9^"
MX9Z`XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C8P-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE
M(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A
M:60B"FUS9W-T<B`BX9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z8
MX9Z]X9Z9(.&>@.&?DN&>D^&>N^&>A.&>@.&>MN&>FN*`B^&>BN&>MN&>@.&?
MB^&>D>&>A.&?B^*`B^&>LN&?DN&>F>*`B^&>G^&>MN&>FN*`B^&>@.&?DN&>
MD^&>N^&>A.*`B^&>D.&>CR!<(B5S7"+"H.&?E"#AGI/AGX'AGX?B@(OAGH+A
MGKKB@(OAGH?AGK;B@(OAGJ+AGY+AGISAGKCB@(OAGHKAGX+AGIOB@(OAGICA
MGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI3AGK;A
MGI/B@(OAGI/AGK?AGIGAGK;AGIDB"@HC.B!F;VQD97)S+G!H<#HQ,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R`E<RXB"FUS9W-T<B`BX9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+
MX9Z8X9Z]X9Z9(.&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>D^&>
MMN&?AN&>A>&>O.&>FR`E<\*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(N&>F.&>
MMN&>D^*`B^&>@.&?AN&>H.&>N^&>G^&>F.&>O>&>F2#AGH#AGY+AGI/AGKOA
MGH3B@(OAGH#AGK;AGIKB@(OAGI/AGK;AGX;AGH7AGKSAGIOB@(OAGI;AGY+A
MGIKAGKGAGH_AGY+AGH_AGK?AGH#AGK;AGIKAGH[AGXW"H.&?EB`E<\*@X9^4
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T
M87-K.B`E<RXB"FUS9W-T<B`BX9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?
MXH"+X9Z8X9Z]X9Z9(.&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^*`
MB^*`B^&>D^&>MN&?AN&>A>&>O.&>F^*`B^&>E^&>MN&>FN&>@.&>M^&>A>&?
MDN&>A<*@X9^6("5SPJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,34S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N
M(@IM<V=S='(@(N&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>N^&>G^*`B^&>F.&>
MO>&>F2#AGH#AGY+AGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OAGI/AGK;AGX;A
MGH7AGKSAGIOB@(OAGI;AGY#AGH_AGXSAGICAGK;AGI,@X9Z1X9^&X9Z3X9^!
MX9Z:+^&>FN&>G.&>F^&?BR#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH#B
M@(OAGI3AGY+AGIKAGK["H.&?EB`E<\*@X9^4(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@
M5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("+AGICA
MGK;AGI/B@(OAGH#AGX;AGJ#AGKOAGI_B@(OAGICAGKWAGID@X9Z`X9^2X9Z3
MX9Z[X9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1
MX9ZXXH"+X9Z?X9ZVX9Z:XH"+X9Z6X9ZX(%PB)7-<(B#AGI'AGX4@7"(E<UPB
MPJ#AGY0@X9Z3X9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9ZBX9^2X9Z<
MX9ZXXH"+X9Z*X9^"X9Z;XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z4
MX9Z8X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+X9Z3X9ZWX9Z9X9ZVX9Z9(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C4V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM
M<V=S='(@(N&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>N^&>G^*`B^&>F.&>O>&>
MF2#AGH#AGY+AGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OAGI7AGY+AGHGAGK[B
M@(OAGI_AGK;AGIKAGIKAGI3AGI_AGXOAGJ+AGY+AGI/AGH#"H.&?EB`E<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N
M=#H@)7,N(@IM<V=S='(@(N&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>N^&>G^*`
MB^&>F.&>O>&>F2#AGH#AGY+AGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OAGI+A
MGY+AGISAGK[B@(OB@(OAGK+AGY+AGIGB@(OB@(OAGI;AGY+AGIKAGKGAGH_A
MGY+AGH_AGK?AGH#AGK;AGIKAGH[AGXWB@(OAGI'AGK;AGI/AGXOB@(OAGI_A
MGICAGY#AGIG"H.&?EB`E<\*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L
M86EN+G!H<#HU.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M
M97-S86=E('!A<G0B"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+
MX9ZBX9Z/X9^2X9Z0X9Z4X9Z1(.&>@.&?DN&>D^&>N^&>A.*`B^&>E>&?DN&>
MD^&?@N&>@.*`B^&>D^&?@^*`B^*`B^&>G^&>MN&>FN*`B^&>D^&?@>&?AR(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-0IM<V=I9"`B5&AI<R!0
M1U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N(@IM
M<V=S='(@(N&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?
MB"!01U`@X9Z3X9^!X9^'XH"+(.&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>D>&?A>*`B^&>G^&>MN&>FN*`
MB^&>D^&?@>&?A\*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$P-2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$Y"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ-#0@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$U.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<T(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HS,34*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>@N&>MN&?AN&>
MD>&?DN&>FN*`B^&>HN&?AN&>EN&>ON*`B^&>D^&?@>&?A\*@X9^4(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$X,"!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#(P"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM
M<&QE;65N=&5D+B(*;7-G<W1R("+AGJ+AGX;AGI;AGK[B@(OAGI/AGX'AGX?B
M@(OAGICAGK?AGI/B@(OAGI'AGK;AGI/AGXOB@(OAGH_AGY+AGIKAGKSAGISB
M@(OAGI3AGK;AGI/B@(OAGJ+AGI/AGKOAGISAGH_AGY+AGH_B@(OAGJ'AGK[A
MGIG"H.&?E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,30*;7-G:60@(E1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_(@IM<V=S='(@(N&>D^&?@>&?A^*`
MB^&>E.&?DN&>FN&>H.&?@N&>F^*`B^&>A^&>MN*`B^&>C^&?DN&>FN&>O.&>
MG.*`B^&>@.&>MN&>FN*`B^&>EN&?@>&>F^*`B^&>E.&>D^&?DN&>C^&>M^&>
MA>*`B^&>E.&>D^&?DN&>C^&>O>&>A<*@X9^4(.&>C^&>ON*`B^&>HN&?DN&>
MD^&>@.*`B^&>EN&>M^&>C^*`B^&>A^&>MN*`B^&>A>&>A.&?B^*`B^&>E.&>
MD^&?DN&>C^*`B^&>K,*@/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O
M=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A($UA
M8VEN=&]S:"!F:6QE+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGI/AGX'AGX?B
M@(OAGICAGK;AGI/B@(OAGI7AGY+AGI'AGKOAGH#B@(OAGJ_AGH#AGI_AGK;A
MGIH@36%C:6YT;W-H(.&>F.&>O>&>F<*@X9^4(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HT,34*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT
M86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I
M9VYE9"!V:6$@4R\B"B)-24U%+B(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGI/A
MGX'AGX?B@(OAGICAGK;AGI/B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+A
MGH?AGK;AGI3AGXL@X9Z*X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z%X9Z[X9^'XH"+X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZV
MXH"+X9Z,X9ZXX9Z'X9ZXX9Z0X9Z;XH"+X9Z/X9ZVX9Z8XH"+X9Z:X9Z9X9^(
M(%,O34E-1<*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT
M,3D*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT
M('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@
M(N&>G^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>F.&>MN&>D^*`B^&>K^&>@.&>
MG^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BR#AGHKAGX+AGIOB@(OAGH_A
MGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGICAGY+AGIOAGX+AGH3B
M@(OAGH?AGK;B@(OAGH#AGKSAGHKB@(OAGH_AGK;AGICB@(OAGIKAGIGAGX@@
M4R]-24U%PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ
M-C(*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!M86EL(&1E;&EV
M97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M870@;V8@(@HB
M=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@(N&>G^&>MN&>FN*`
MB^&>D^&?@>&?A^*`B^&>F.&>MN&>D^*`B^&>EN&?D.&>C^&?C.&>F.&>MN&>
MD^*`B^&>G^&?DN&>D.&>MN&>D^&>E^&>MN&>EN*`B^&>E.&>B>&?DN&>A^&>
MO.&>D^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FB#AGI3AGXGAGKOAGI/AGY+A
MGH_AGX+B@(OAGI'AGY+AGIKAGH3AGXOB@(OAGI'AGY+AGIKAGK;AGIGB@(OA
MGIKAGI3AGI_AGXOB@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX<@X9Z8X9ZWX9Z3
MXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z?X9^2X9Z"X9ZV
MX9Z;X9^+XH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HS,C,*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R
M<F]R.B`B"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+X9Z8X9ZW
MX9Z3XH"+X9Z1X9^&X9Z3X9Z$XH"+X9Z'X9ZVXH"+X9Z?X9ZVX9Z:XH"+X9Z*
MX9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z'
MX9ZVXH"+X9Z`X9Z\X9Z*(%!'4"#AGH_AGY+AGIKAGKGAGICB@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGICAGKWAGIGB@(OAGJ'AGK[AGIG"H.&?E"#AGH#AGX;A
MGJ#AGKOAGI_"H.&?EB(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(T
M,R!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS-3@*;7-G:60@(B(*(E1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@
M4$=0(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T
M<B`BX9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+X9Z8X9ZWX9Z3XH"+X9Z1X9^&
MX9Z3X9Z$XH"+X9Z'X9ZVXH"+X9Z8X9ZVX9Z3XH"+X9Z1X9^2X9Z:X9Z$X9^+
MXH"+X9Z1X9^2X9Z:X9ZVX9Z9(%!'4"#AGH_AGY+AGIKAGKGAGICAGH_AGY+A
MGIKAGKSAGIP@*.&>F>&?A.&>A.*`B^&>C^&>MN&>F"!21D,@,C`Q-2G"H.&?
ME"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4
M:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R
M96-T(%,O34E-12!F;W)M870N(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>D^&?
M@>&?A^*`B^&>F.&>M^&>D^*`B^&>D>&?AN&>D^&>A.*`B^&>A^&>MN*`B^&>
MF.&>MN&>D^*`B^&>D>&?DN&>FN&>A.&?B^*`B^&>D>&?DN&>FN&>MN&>F2!3
M+TU)344@X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<PJ#AGY0B"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#`*;7-G:60@(B(*(E1H:7,@
M;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D(&%N9"!E;F-R>7!T
M960@=VET:"!01U`L(&)U="!T:&4@(@HB<VEG;F%T=7)E(&-A;FYO="!B92!V
M97)I9FEE9"XB"FUS9W-T<B`B(@HBX9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+
MX9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z%X9Z[X9^'XH"+X9Z@
MX9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZVXH"+X9Z,X9ZXX9Z'X9ZXX9Z0X9Z;(.&>
MD^&>M^&>A"#AGI3AGICAGY+AGIOAGX+AGH3B@(OAGH?AGK;B@(OAGH#AGKSA
MGHKB@(OAGHKAGX3AGIGB@(OAGI3AGY+AGIKAGKX@4$=0(.&>E.&?B>&>N^&>
MD^&?DN&>C^&?@N*`B^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>F.&>
MM^&>D^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`BR(*(N&>E>&?DN&>D>&?@.&>A.&>E>&?DN&>D>&>MN&>C^&?B^*`B^&>
ME.&>MN&>D^*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,C`V"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG
M:71A;&QY('-I9VYE9"!A;F0@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R
M("+AGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGI3AGK;AGI/B@(OAGH7AGKOAGX?B@(OAGJ#AGH_AGY+AGI#AGIOAGX'AGH'A
MGK;B@(OAGHSAGKCAGH?AGKCAGI#AGIL@X9Z3X9ZWX9Z$(.&>E.&>F.&?DN&>
MF^&?@N&>A.*`B^&>A^&>MN*`B^&>@.&>O.&>BN*`B^&>BN&?A.&>F>*`B^&>
ME.&?DN&>FN&>OB!01U#"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(P,@IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET
M86QL>2!S:6=N960@=FEA(%!'4"P@8G5T('1H92!S:6=N871U<F4@8V%N;F]T
M(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B+AGI_AGK;AGIKB@(OAGI/A
MGX'AGX?B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGH7AGKOA
MGX?AGJ#AGH_AGY+AGI#AGIOAGX'AGH'AGK;B@(OAGHSAGKCAGH?AGKCAGI#A
MGIOB@(OAGH_AGK;AGICB@(OAGIKAGIGAGX@@4$=0(.&>E.&?B>&>N^&>D^&?
MDN&>C^&?@N*`B^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>F.&>M^&>
MD^*`B^&>HN&>MN&>A>*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>E>&?DN&>D>&?@.&>A.&>E>&?DN&>D>&>MN&>C^&?B^*`B^&>E.&>MN&>
MD^*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,C`X(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C0R-`IM<V=I9"`B5&AI
M<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"XB
M"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z%X9Z[X9^'XH"+X9Z@X9Z/X9^2X9Z0X9Z;
MX9^!X9Z!X9ZVXH"+X9Z'X9ZVXH"+X9Z;X9^!X9Z!XH"+X9Z/X9ZVX9Z8X9Z:
MX9Z9X9^((%!'4,*@X9^4(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HQ-#,*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@
M<VEG;F5D('9I82!3+TU)344N(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>D^&?
M@>&?A^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>A>&>N^&?
MA^*`B^&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MN*`B^&>C.&>N.&>A^&>N.&>
MD.&>F^*`B^&>C^&>MN&>F.&>FN&>F>&?B"!3+TU)347"H.&?E"(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3,Y(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,C,X"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC
M<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>D^&?
M@>&?A^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>F.&?
MDN&>F^&?@N&>A.*`B^&>A^&>MN*`B^&>@.&>O.&>BN*`B^&>C^&>MN&>F.&>
MFN&>F>&?B"!3+TU)347"H.&?E"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(Y.`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y
M<'1E9"!W:71H(%!'4"P@:&]W979E<BP@4$=0('-U<'!O<G0@:7,@9&ES86)L
M960@(@HB<V\@=&AE(&UE<W-A9V4@8V%N;F]T(&)E(&1E8W)Y<'1E9"XB"FUS
M9W-T<B`B(@HBX9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z'X9ZV
MXH"+X9Z`X9Z\X9Z*XH"+X9Z*X9^$X9Z9XH"+X9Z4X9^2X9Z:X9Z^(%!'4"#A
MGI'AGX3AGX?B@(OAGIGAGXGAGK;AGH3B@(OAGH[AGK8@X9Z`X9ZVX9Z:XH"+
MX9Z"X9ZVX9^&X9Z1X9^2X9Z:(%!'4"#AGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI3AGY+AGIKA
MGK[B@(OAGIOAGX+AGH3B@(OAGI3AGK;AGI,@(@HBX9Z*X9Z\X9Z%X9^2X9Z3
MX9^!X9^'XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9ZYX9Z$XH"+X9Z8X9ZWX9Z3XH"+
MX9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4
MX9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z8X9Z`XH"+X9Z'X9ZVXH"+X9Z7X9ZVX9Z6
MXH"+X9Z2X9Z8X9^2X9Z8X9Z/X9ZVXH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^X9Z9
MPJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,#,*;7-G:60@
M(B(*(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`L
M(&AO=V5V97(L(&YO('!E<G-O;F%L('!R:79A=&4@:V5Y("(*(F5X:7-T<R!S
M;R!T:&4@;65S<V%G92!C86YN;W0@8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B
M"B+AGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGI3AGK;AGI/B@(OAGI3AGICAGY+AGIOAGX+AGH3B@(OAGH?AGK;B@(OAGH#A
MGKSAGHKB@(OAGHKAGX3AGIGB@(OAGI3AGY+AGIKAGKX@4$=0(.&>D>&?A.&?
MA^*`B^&>F>&?B>&>MN&>A.*`B^&>CN&>MB#AGICAGK?AGI/B@(OAGI'AGK;A
MGI/AGXOB@(OAGICAGK;AGI/B@(OAGH#AGKSAGI/AGI_AGX3B@(OAGJ_AGH#A
MGH?AGI/B@(OAGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI/B
M@(OAGI/AGX7B@(OAGJ'AGK[AGIGB@(OAGI'AGX$@X9Z*X9Z\X9Z%X9^2X9Z3
MX9^!X9^'XH"+(@HBX9Z?X9ZVX9Z:XH"+X9Z3X9ZYX9Z$XH"+X9Z8X9ZWX9Z3
MXH"+X9ZBX9ZVX9Z%XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9Z4X9Z8X9^2X9Z;X9^"X9Z$XH"+X9Z8X9Z`XH"+X9Z'X9ZVXH"+X9Z7X9ZV
MX9Z6XH"+X9Z2X9Z8X9^2X9Z8X9Z/X9ZVXH"+X9Z4X9ZVX9Z3XH"+X9ZAX9Z^
MX9Z9PJ#AGY0B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.30*;7-G
M:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N
M(@IM<V=S='(@(N&>G^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>F.&?DN&>F^&?@N&>A.*`B^&>A^&>
MMN*`B^&>@.&>O.&>BN*`B^&>BN&?A.&>F2!01U#"H.&?E"(*"B,Z(&UE<W-A
M9V4N<&AP.C4P-0IM<V=I9"`B5&AI<R!M97-S86=E('1O(@IM<V=S='(@(N&>
MG^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>D>&?A2(*"B,Z(&%C;"YP:'`Z-#4*
M;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F
M;VQD97)S+B(*;7-G<W1R("+AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI3A
MGICAGY+AGIKAGK[B@(OAGI/AGX'AGX?B@(OAGICAGK?AGI/B@(OAGH+AGK;A
MGX;AGI'AGY+AGIKB@(OAGI#AGH_B@(OAGHKAGX+AGIOB@(OAGH7AGX+AGH#B
M@(OAGIKAGX;AGIOAGX+AGH#"H.&?E"(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]J879A<V-R:7!T+FEN8SHQ,#D*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`BX9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+X9Z@X9^%XH"+X9Z4X9Z$X9^2X9ZB
MX9Z]X9Z%XH"+X9Z3X9^!X9^'(.&>EN&>N.*`B^&>E.&>A.&?DN&>HN&>O>&>
MA>*`B^&>C^&?@N&>A.*`B^&>F.&>O>&>F<*@X9^4(@H*(SH@=&AR96%D+G!H
M<#HQ-30*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(N&>E.&>A.&?
MDN&>H.&>MN&>B>*`B^&>A^&>MN*`B^&>@>&?DN&>G^&?@N*`B^&>G^&?DN&>
MFN&>H>&>MN&>F2(*"B,Z('1H<F5A9"YP:'`Z-S4@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDS,PIM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`BX9Z1X9ZW
MX9Z*X9^2X9Z+X9Z7X9ZVX9Z6XH"+X9Z!X9^2X9Z?X9^"X9ZBX9^&X9Z4X9^$
MX9^'(@H*(SH@;65S<V%G92YP:'`Z,C,S(&-O;7!O<V4N<&AP.C@W.2!M86EL
M8F]X+G!H<#HU-S`@;6%I;&)O>"YP:'`Z-S0V"B,Z(&QI8B]396%R8V@N<&AP
M.C8P-R!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:'1M;#HS.0HC.B!T
M96UP;&%T97,O;&]G:6XO<F5C;VUP;W-E+FAT;6PZ,30*;7-G:60@(E1O(@IM
M<V=S='(@(N&>D>&?A2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S`*
M;7-G:60@(E1O($%D9')E<W,B"FUS9W-T<B`BX9Z1X9^%XH"+X9ZBX9ZVX9Z?
MX9Z9X9Z*X9^2X9Z+X9ZVX9Z3(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C
M97-E;&5C="YI;F,Z,S(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@
M9FEE;&1S+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I('=H:6QE("(*(F-L:6-K:6YG+B(*;7-G<W1R("+AGH?AGY+AGIKA
MGK[AGI_B@(OAGH#AGY+AGIKAGJ'AGK;B@(OAGI'AGI'AGKGAGH3B@(OAGH7A
MGY+AGIKAGK[AGI,@X9Z?X9Z$X9^2X9Z`X9Z/X9^+XH"+X9Z4X9Z)X9^2X9Z'
MX9ZV("A00RD@X9ZL(.&>E.&>B>&?DN&>A^&>MB`H36%C*2#AGH'AGH[AGXCA
MGI;AGX'AGIOB@(OAGH#AGX;AGI;AGKOAGH3B@(OAGH7AGKOAGH7"H.&?E"(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@
M82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I
M;VX@;V8@4$A0(#4N,"XV(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`BX9Z*X9Z^
MX9Z8X9^2X9Z4X9ZXXH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z`X9ZVX9Z:XH"+X9Z/
MX9Z7X9^2X9Z'X9ZVX9Z4X9^+(%1,4R#AGJ+AGY+AGI/AGH#B@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGH_AGX+B@(OAGH#AGX;AGI;AGKOAGH3B@(OAGIKAGH_A
MGXL@4$A0(.&>@.&?AN&>CN&?@B`U+C`N-B#AGJP@X9Z!X9^2X9Z6X9Z?X9^+
MXH"+X9Z'X9ZVX9Z$PJ#AGY0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FAT;6PZ,S0Y"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*
M;7-G<W1R("+AGI'AGX;AGJ#AGX;B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?A
MGY+AGH?AGK;AGI3AGXOB@(OAGI_AGIKAGKOAGI3"H.&?EB(*"B,Z(&QI8B])
M34%0+U1R964N<&AP.C,V.`IM<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@
M(N&>D.&>C^*`B^&>G^&?AN&>FN&>MN&>F"(*"B,Z('1E;7!L871E<R]P<F5F
M<R]T<F%S:'-E;&5C="YI;F,Z,C,*;7-G:60@(E1R87-H(&9O;&1E<CHB"FUS
M9W-T<B`BX9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8PJ#AGY8B"@HC.B!L:6(O
M475O=&$O8WER=7,N<&AP.C8T(&QI8B]1=6]T82]M97)C=7)Y,S(N<&AP.C<Y
M(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC.B!L:6(O475O=&$O;&]G9FEL
M92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP.C4S(&QI8B]1=6]T82]M
M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O(')E=')I979E('%U;W1A
M(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>D>&?A>*`B^&>
MF>&>@.*`B^&>@.&>O.&>C^&>MB(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YH=&UL.C$P('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYH=&UL.C$V"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.C,Q
M"FUS9VED(")5;F%N<W=E<F5D(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>E.&>
MMN&>D^*`B^&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E"(*"B,Z('-E87)C:"YP
M:'`Z,S,P"FUS9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(N&>
MG^&>MN&>FN*`B^&>BN&?@N&>F^*`B^&>F.&>M^&>D^*`B^&>E.&>MN&>D^*`
MB^&>AN&?DN&>F^&>ON&>F>*`B^&>C^&>E"(*"B,Z(&UE<W-A9V4N<&AP.C4S
M-2!M86EL8F]X+G!H<#HT-S$*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(N&>
MF.&>M^&>D^*`B^&>F^&>N^&>E"(*"B,Z('-E87)C:"YP:'`Z,S0P"FUS9VED
M(")5;F1E;&5T960@;65S<V%G97,B"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z8
MX9ZWX9Z3XH"+X9Z1X9ZVX9Z3X9^+XH"+X9Z;X9Z[X9Z4(@H*(SH@;6%I;&)O
M>"YP:'`Z-S(Y(&UA:6QB;W@N<&AP.C<T,B!L:6(O34E-12](96%D97)S+G!H
M<#HR,3,*;7-G:60@(E5N9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`B
MX9Z8X9ZWX9Z3XH"+X9Z4X9ZVX9Z3X9Z4X9^2X9Z:X9Z`X9ZVX9Z?XH"+XH"+
MX9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L
M960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(N&>G^&>F.&>MN&>
MG^&>E^&>MN&>@N*`B^&>BN&?@N&>F^*`B^&>F.&>M^&>D^*`B^&>E.&>MN&>
MD^*`B^&>BN&?A.&?A^*`B^&>G^&?DN&>FN&>MN&>F>*`B^&>D^&?@^*`B^&>
ME.&?DN&>FN&>E^&?@>&>D<*@X9^6("5S(@H*(SH@<V5A<F-H+G!H<#HS,S4*
M;7-G:60@(E5N:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(N&>G^&>MN&>
MFN*`B^&>F.&>M^&>D^*`B^&>G^&?AN&>@>&>MN&>D^&?BR(*"B,Z(&UA:6QB
M;W@N<&AP.C<P.0IM<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@(N&>@.&>
MMN&>F^*`B^&>E.&>FN&>M^&>A>&?DN&>AN&?@>&>D>*`B^&>BN&?@N&>F^*`
MB^&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?BR(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@
M24U!4"!R97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD
M960Z("5S(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?
MB^*`B^&>A>&>F.&?DN&>F^&>ON&>F2!)34%0(.&>EN&>N.*`B^&>F.&?B>&>
MMN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>OL*@X9^4(.&>F.&?B>&>
MMN&>G^&?BN&>N.&>D^*`B^&>E.&>F.&?DN&>FN&>ON*`B^&>E.&>MN&>D^*`
MB^&>AN&?DN&>F^&>ON&>F>&>C^&>E.*`B^&>D.&>ML*@X9^6("5S(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B56YK;F]W;B!-
M965T:6YG(@IM<V=S='(@(N&>@.&>M^&>A>&?DN&>A>*`B^&>E.&?DN&>FN&>
MA^&>N^&?AN*`B^&>BN&?@N&>F^*`B^&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>
MMN&>F^&?BR(*"B,Z(&UA:6QB;W@N<&AP.C<U.`IM<V=I9"`B56YK;F]W;B!2
M96-I<&EE;G0B"FUS9W-T<B`BX9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;
MXH"+X9Z*X9^"X9Z;XH"+X9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E5N;&]A9"!087-S<&AR87-E(@IM<V=S
M='(@(N&>FN&>ON*`B^&>@^&?DN&>F^&>MN*`B^&>G^&>F.&?DN&>A.&>MN&>
MC^&?B^*`B^&>A>&?@>&>B2(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HV-0IM
M<V=I9"`B56YN86UE9"(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI/B@(OAGHCA
MGY+AGICAGX3AGX<B"@HC.B!M97-S86=E+G!H<#HT-CD@;6%I;&)O>"YP:'`Z
M.#$Q(&UA:6QB;W@N<&AP.CDW,`HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:'1M;#HV('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH
M=&UL.C$R"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.C(W('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YH=&UL.C,*;7-G:60@(E5N<V5E;B(*
M;7-G<W1R("+AGICAGK?AGI/B@(OB@(OAGI3AGK;AGI/B@(OAGICAGK[AGILB
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FAT;6PZ,30*;7-G:60@
M(E5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I(@IM<V=S='(@(N&>B.&>E.&?
MB^*`B^&>A^&>MN&>G.*`B^&>EN&>N.*`B^&>D.&>CR(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HR.#0*;7-G:60@(E5P9&%T92(*;7-G
M<W1R("+AGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI'AGK;AGI/AGXOA
MGI_AGICAGY#AGIDB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$R
M"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`BX9Z2
MX9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z?X9^2X9Z0X9ZVX9Z3X9Z7X9ZV
MX9Z6XH"+X9Z&X9^2X9Z;X9Z^X9Z9XH"+X9Z/X9Z4XH"+X9Z1X9ZVX9Z3X9^+
MX9Z?X9Z8X9^0X9Z9(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN
M:6YC.C4X"FUS9VED(")5<&QO860B"FUS9W-T<B`BX9Z5X9^2X9Z1X9Z[X9Z`
MXH"+X9ZAX9Z^X9Z$(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FAT
M;6PZ,S@*;7-G:60@(E5P;&]A9#HB"FUS9W-T<B`BX9Z5X9^2X9Z1X9Z[X9Z`
MXH"+X9ZAX9Z^X9Z$PJ#AGY8B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA
M:6QS96QE8W0N:6YC.C0Q"FUS9VED(")5<V4@1&5F875L="!686QU92(*;7-G
M<W1R("+AGI3AGY+AGIKAGK[B@(OAGH_AGICAGY+AGIOAGX/B@(OAGIOAGX;A
MGI/AGK;AGX;AGHKAGK[AGI@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C4W"FUS9VED(")5<V4@24U!4"!F;VQD97(@<W5B<V-R:7!T:6]N<S\B"FUS
M9W-T<B`BX9Z4X9^2X9Z:X9Z^XH"+X9Z`X9ZVX9Z:XH"+X9Z'X9ZVX9Z<XH"+
MX9Z0X9Z/($E-05`@X9ZLPJ`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<T-PIM<V=I9"`B57-E(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*;7-G<W1R
M("+AGI3AGY+AGIKAGKX@X9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZVX9Z8XH"+X9Z3
MX9ZWX9Z8X9^2X9Z8X9ZWX9Z/PJ`_(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$T,PIM<V=I9"`B57-E<B(*;7-G<W1R("+AGJ+AGY+AGI/AGH#B@(OA
MGI3AGY+AGIKAGKXB"@HC.B!A8VPN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E
M8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(N&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OB!<(B5S7"(@X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z5X9^2X9Z*X9Z;X9^+XH"+X9Z?X9ZW
MX9Z1X9^2X9Z2X9ZWXH"+X9Z*X9^"X9Z;XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z)
MX9^2X9Z'X9ZVX9Z`X9^+XH"+X9Z;X9Z8X9^2X9ZBX9ZWX9Z/XH"+X9Z*X9^$
MX9Z9XH"+X9Z'X9^$X9Z"X9Z'X9^0X9Z9XH"+X9Z@X9Z^X9Z9(.&>G^&>F.&?
MDN&>FN&>MN&>E.&?B^*`B^&>D.&>CR!<(B5S7"+"H.&?E"(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYH=&UL.C@S"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R("+AGHCAGY+AGICAGX3AGX?B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+A
MGIKAGKXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,3<*
M;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+AGHCAGY+AGICAGX3AGX?B@(OA
MGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGK["H.&?EB(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHV.`HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHR-PHC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6:65W(@IM<V=S='(@
M(N&>F.&>ON&>FR(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.CDR(&QI
M8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R("+AGICAGK[AGIL@)7,B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(%!U8FQI8R!+97DB"FUS
M9W-T<B`BX9Z8X9Z^X9Z;XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2
MX9ZVX9Z:X9Z.X9^(("5S(@H*(SH@;6%I;&)O>"YP:'`Z-3$Y"FUS9VED(")6
M:65W($UE<W-A9V5S(@IM<V=S='(@(N&>F.&>ON&>F^*`B^&>G^&>MN&>FB(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<W"FUS9VED(")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y
M(@IM<V=S='(@(N&>F.&>ON&>F^*`B^*`B^&>@.&>O.&>D^&>G^&?A.*`B^&>
MK^&>@.&>A^&>D^*`B^&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>
MO>&>DR(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI
M8R!+97DB"FUS9W-T<B`BX9Z8X9Z^X9Z;XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+
MX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(XH"+X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+
MX9Z!X9^2X9Z;X9Z]X9Z3(@H*(SH@;65S<V%G92YP:'`Z-34Y"FUS9VED(")6
M:65W(%1H<F5A9"(*;7-G<W1R("+AGICAGK[AGIOB@(OAGH'AGY+AGI_AGX+B
M@(OAGJ+AGX;AGI3AGX3AGX<B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38V"FUS9VED
M(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R("+AGICAGK[AGIOB@(OAGIKAGKSA
MGI3AGI?AGK;AGI;B@(OAGH_AGKSAGH4B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C0R,PIM<V=I9"`B5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W(@IM<V=S='(@(N&>F.&>ON&>F^*`B^&>K^&>@.&>G^&>
MMN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?BR#B@(OB@(OAGH#AGY+AGI/AGKOA
MGH3B@(OAGI3AGH3AGY+AGJ+AGKWAGH7B@(OAGHKAGK;AGH7AGXOB@(OAGHKA
MGX3AGIGB@(OAGJ'AGX+AGH`B"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E
M9"YP:'`Z-SD*;7-G:60@(E9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I
M;F1O=R(*;7-G<W1R("+AGICAGK[AGIOB@(OAGICAGK;AGH_AGK?AGH#AGK;B
M@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI3AGH3AGY+AGJ+AGKWAGH7B@(OAGI7A
MGY+AGI_AGX'AGH0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30Q
M"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(N&>F.&>ON&>F^*`B^&>EN&?
MDN&>FN&>N>&>C^&?DN&>C^&>M^&>@.&>MN&>FN&>CN&?C2(*"B,Z(&UA:6QB
M;W@N<&AP.C8V.2!L:6(O24U!4"]4<F5E+G!H<#HS-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G<W1R("+AGICAGK[A
MGIOB@(OAGI_AGK;AGIKB@(OAGH#AGY+AGI/AGKOAGH0@)7,B"@HC.B!T96UP
M;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C(S"FUS9VED(")6
M:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CHB"FUS9W-T
M<B`BX9Z1X9ZWX9Z*X9^2X9Z+X9Z7X9ZVX9Z6(.&>K"#AGI3AGY+AGIKAGJ+A
MGI3AGXOB@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGHKAGX+AGIOB@(OA
MGH_AGY+AGIKAGKSAGISB@(OAGI3AGH3AGY+AGJ#AGK;AGHGB@(L@X9Z4X9Z3
MX9^2X9Z1X9ZVX9Z4X9^+XH"+X9Z6X9ZXXH"+X9Z%X9Z\X9Z;PJ#AGY8B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<Q"FUS9VED(")6:65W('1A
M<VLB"FUS9W-T<B`BX9Z8X9Z^X9Z;XH"+X9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2
MX9Z%(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.`IM<V=I9"`B
M5FEE=R!T:&ES($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB
M"FUS9W-T<B`BX9Z8X9Z^X9Z;XH"+X9Z8X9ZVX9Z/X9ZWX9Z`X9ZV($A434P@
MX9Z3X9^!X9^'XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z4X9Z$X9^2X9ZBX9Z]
MX9Z%XH"+X9Z5X9^2X9Z?X9^!X9Z$PJ#AGY0B"@HC.B!S96%R8V@N<&AP.C$V
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@
M8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`BX9Z0X9Z/XH"+X9Z3X9ZW
MX9Z8X9ZWX9^2X9Z8X9Z/(%PB)7-<(B#AGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGHKAGX3AGIGB@(OAGH?A
MGX3AGH+B@(OAGH?AGY#AGIG"H.&?E"(*"B,Z(&QI8B])34%0+U1R964N<&AP
M.C$S,B!L:6(O24U!4"]4<F5E+G!H<#HQ-#4@;&EB+TE-05`O5')E92YP:'`Z
M,30W"B,Z(&QI8B])34%0+U1R964N<&AP.C$U,2!L:6(O24U!4"]4<F5E+G!H
M<#HQ-3(@;&EB+TE-05`O5')E92YP:'`Z-C$S"B,Z(&QI8B])34%0+U1R964N
M<&AP.C8S-R!L:6(O24U!4"]4<F5E+G!H<#HV-S4*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:'1M;#HQ-C4*;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*
M;7-G<W1R("+AGI#AGH_B@(OAGI/AGK?AGICAGK?AGY+AGICAGH\B"@HC.B!S
M96%R8V@N<&AP.C$U-`IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@
M82!L86)E;"XB"FUS9W-T<B`BX9Z0X9Z/XH"+X9Z3X9ZWX9Z8X9^2X9Z8X9ZW
MX9Z/XH"+X9Z1X9ZVX9Z8X9Z1X9ZVX9Z:XH"+X9Z?X9^2X9Z;X9ZVX9Z`XH"+
MX9Z8X9Z]X9Z9PJ#AGY0B"@HC.B!L:6(O4V5A<F-H+G!H<#HT,S0*;7-G:60@
M(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`BX9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+
MX9Z1X9Z1X9Z]X9Z;XH"+X9Z3X9ZWX9Z8X9^2X9Z8X9ZWX9Z/(@H*(SH@;&EB
M+TE-05`O5')E92YP:'`Z-#`Y"FUS9VED(")6:7)T=6%L($E.0D]8($9O;&1E
M<B(*;7-G<W1R("+AGI#AGH_B@(OAGI3AGY+AGIKAGJ+AGI3AGXOB@(OAGI'A
MGI'AGKWAGIOB@(OAGI/AGK?AGICAGY+AGICAGK?AGH\B"@HC.B!L:6(O4V5A
M<F-H+G!H<#HS.#`*;7-G:60@(E9I<G1U86P@5')A<V@B"FUS9W-T<B`BX9Z?
MX9^&X9Z:X9ZVX9Z8XH"+X9Z3X9ZWX9Z8X9^2X9Z8X9ZW(@H*(SH@;&EB+TE-
M05`O5')E92YP:'`Z-#`U"FUS9VED(")6:7)T=6%L(%1R87-H($9O;&1E<B(*
M;7-G<W1R("+AGI#AGH_B@(OAGI_AGX;AGIKAGK;AGICB@(OAGI/AGK?AGICA
MGY+AGICAGK?AGH\B"@HC.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YH=&UL
M.C$W-@IM<V=I9"`B5FER='5A;"!F;VQD97(@;&%B96PZ(@IM<V=S='(@(N&>
MG^&?DN&>F^&>MN&>@.*`B^&>D.&>C^*`B^&>D^&>M^&>F.&?DN&>F.&>M^&>
MC\*@X9^6(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-SD*;7-G
M:60@(E=A<FYI;F<B"FUS9W-T<B`BX9Z6X9^2X9Z:X9Z8X9ZVX9Z3(@H*(SH@
M;&]G:6XN<&AP.C$X-"!L;V=I;BYP:'`Z,C8V"B,L('!H<"UF;W)M870*;7-G
M:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`BX9Z?X9Z\X9Z8XH"+X9Z?X9^2
MX9Z<X9ZVX9Z"X9Z8X9Z3X9^-XH"+X9Z8X9Z`XH"+X9Z`X9ZVX9Z3X9^+("5S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.0IM<V=I9"`B(@HB5VAA
M="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F=&5R('1H97D@
M:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@(@HB;W(@:6YN;V-E;G0_(@IM
M<V=S='(@(B(*(N&>C^&>ON*`B^&>F>&>ON&>A.*`B^&>C^&?DN&>FN&>O.&>
MG.*`B^&>DN&?DN&>G.&>ON*`B^&>F>&?B>&>MN&>A.*`B^&>BN&>O.&>A>&>
MF.&?DN&>BN&?@>&>A>*`B^&>A^&>MN&>F.&>O>&>F>*`B^&>G^&>MN&>FN*`
MB^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FB#AGI3AGI/AGY+AGI'A
MGK;AGI3AGXOB@(OAGI;AGKCB@(OAGI;AGKWAGH#B@(OAGISAGK;B@(OAGH_A
MGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B@(OAGIKAGK;AGIGAGH#AGK;AGIKA
MGH[AGXWB@(OAGI#AGK;B@(OAGH?AGK;B@(OAGI_AGK;AGIKB@(OAGJ7AGH_B
M@(OAGI3AGK;AGI/B@(OAGH#AGK;AGIH@X9ZL("(*(N&>G^&>MN&>FN*`B^&>
MF^&?DN&>HL*@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,SD*;7-G
M:60@(B(*(E=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y
M;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A
M<R!D96QE=&5D/R(*;7-G<W1R("+AGI;AGX'AGIOB@(OAGIOAGKOAGI3B@(OA
MGI_AGK;AGIH@X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9Z6X9Z]
MX9Z`XH"+X9Z<X9ZVXH"+X9Z1X9^%XH"+X9Z0X9Z/XH"+X9Z?X9^&X9Z:X9ZV
MX9Z8XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`(.&>A^&?AN&>D^&>
MO>&>G^*`B^&>LN&?DN&>F>*`B^&>@.&>MN&>FN*`B^&>G^&>F.&?DN&>@N&>
MMN&>F^&?B^*`B^&>EN&>O>&>@.*`B^&>G.&>MN*`B^&>D.&>MN*`B^&>E.&>
MMN&>D^*`B^&>F^&>N^&>E,*@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,3@*;7-G:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC
M:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N/R(*;7-G<W1R("+AGI;A
MGX'AGIOB@(OAGI3AGK[AGH#B@(OAGI3AGY+AGIKAGJ+AGI3AGXOB@(OAGI_A
MGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI#AGY+AGICAGKCB@(OAGICAGKWAGID@
MX9Z1X9^&X9Z6X9^0X9Z:XH"+X9Z.X9ZVX9Z8X9Z]X9Z9XH"+X9Z*X9^"X9Z;
MXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z%X9Z$X9^+XH"+X9Z%X9ZVX9Z4X9^+X9Z5
MX9^2X9Z/X9Z^X9Z8XH"+X9Z6X9ZXPJ`_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4W,PIM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U
M;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(N&>EN&?@>&>
MF^*`B^&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`B^&>G^&?AN&>E.&>
MN^&>C^&?DN&>FN*`B^*`B^*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`B^&>
ME>&?DN&>B>&>ON*`BR#AGH_AGK[B@(OAGIGAGK[AGH3B@(OAGH+AGKWAGIKB
M@(OAGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(OAGI'AGK?AGI/AGY+A
MGI/AGI/AGY#AGIGB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;A
MGI3AGXOB@(OAGJSB@(OAGI'AGX'"H#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#(W"FUS9VED("(B"B)7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A
M;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD
M('1O("(*(G5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S
M('=I=&AO=70@7")`7"(I/R(*;7-G<W1R("(B"B+AGI/AGX7B@(OAGI;AGX'A
MGIOB@(OAGI7AGY+AGHGAGK[B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIH@X9ZL
M(.&>E.&>D^&?DN&>F^&>MN&>F>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>
MMN&>DR#AGH_AGK[B@(OAGHKAGX+AGI/B@(OAGJ+AGY+AGISAGKCB@(OAGHKA
MGX+AGIOB@(OAGIGAGK[AGH3B@(OAGH+AGKWAGIKB@(OAGI3AGI/AGY+AGI#A
MGX+AGICB@(OAGI'AGX7B@(OAGH'AGK;AGH3B@(OAGH7AGKOAGH3B@(OAGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGHKAGX+AGIOB@(OAGICAGK?A
MGI/B@(OAGICAGK;AGI/B@(OAGIOAGH#AGY+AGH'AGH[AGXCB@(LB"B+AGH+A
MGY+AGIKAGI3AGXOAGH+AGY+AGIKAGK;AGI/AGXL@*.&>HN&>MN&>G^&>F>&>
MBN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>F^*`B^&>BN&?@N&>
MF^*`B^&>@N&?DN&>F.&>MN&>DR!<(D!<(BG"H#\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S`X"FUS9VED(")7:&5R92!D;R!Y;W4@=V%N="!T;R!D
M:7-P;&%Y(&QI;FMS('1O(&%L=&5R;F%T:79E(&9O<FUA=',@;V8@82!M97-S
M86=E/R(*;7-G<W1R("+AGH_AGK[B@(OAGJ+AGY+AGI/AGH#B@(OAGH7AGH3A
MGXOB@(OAGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGH_AGX;AGH[B@(OAGI'AGX7B
M@(OAGH#AGK;AGI/AGXOB@(OAGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;A
MGIGB@(OAGH?AGX;AGI/AGKWAGI_B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGK;A
MGIKB@(OAGICAGKWAGID@X9Z3X9^%XH"+X9Z`X9Z3X9^2X9Z;X9^"X9Z$XH"+
MX9Z.X9ZVPJ`_(@H*(SH@;65S<V%G92YP:'`Z-3<Q(&UA:6QB;W@N<&AP.C0Y
M-@IM<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@(N&>E.&>B>&?DN&>A^&>N.*`
MB^&>GR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.#D@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YH=&UL.C(Y-0IM<V=I9"`B665S(@IM<V=S='(@
M(N&>E.&>MN&>D2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I
M;%]L;V=I;BYP:'`Z-3@*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@
M96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@
M(N&>HN&?DN&>D^&>@.*`B^&>D>&?AN&>D^&>A.*`B^&>A^&>MN&>D>&?A>*`
MB^&>E.&?DN&>FN&>F.&>O.&>F^*`B^&>F>&>@.*`B^*`B^&>HN&?BN&>N.&>
MF.&?@N&>FR#AGI;AGKCB@(OAGH+AGH[AGI/AGKCB@(OAGH'AGK;AGH3B@(OA
MGH#AGY+AGIKAGX3AGICB@(O"H.&?EB(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P"FUS9VED("(B"B)9;W4@87)E(&%T
M=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@
M=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@(N&>HN&?DN&>
MD^&>@.*`B^&>@.&?AN&>EN&>N^&>A.*`B^&>E.&?B>&>N^&>D^&>E.&?B>&>
MA.*`B^&>F^&>N^&>E.*`B^&>G^&>MN&>FN*`B^&>D>&>MN&?AN&>A.&>HN&>
MG^&?BR#AGHKAGX+AGIOB@(OAGICAGK;AGI/B@(OAGH#AGY+AGI/AGKOAGH3B
M@(OAGI#AGH_B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGIC"H.&?E"(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.CD*
M;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@=&AE(&9O;&QO
M=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>@.&?
MAN&>EN&>N^&>A.*`B^&>E.&?B>&>N^&>D^&>E.&?B>&>A.*`B^&>F^&>N^&>
ME.*`B^&>D.&>C^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F,*@X9^4
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-S`@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DU"FUS9VED(")9;W4@
M87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B
MX9ZBX9^2X9Z3X9Z`XH"+X9Z`X9^&X9Z6X9Z[X9Z$XH"+X9Z%X9Z8X9^2X9Z;
MX9Z$+^&>E>&?DN&>F^&>MN&>G^&?B^&>D>&>N.*`BR#AGI'AGX7B@(OAGI#A
MGH_AGI#AGY+AGICAGKCB@(OAGICAGKWAGIG"H.&?E.*`BR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")9;W4@87)E
M(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`BX9ZBX9^2X9Z3
MX9Z`XH"+X9Z`X9^&X9Z6X9Z[X9Z$XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+
MX9Z0X9Z/XH"+X9Z:X9Z$XH"+X9Z8X9Z]X9Z9XH"+X9Z3X9^#(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#8*;7-G:60@(EEO=2!A
M<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R("+AGJ+A
MGY+AGI/AGH#B@(OAGH#AGX;AGI;AGKOAGH3B@(OAGI3AGH3AGY+AGH#AGK[A
MGH_B@(OAGI#AGH_B@(OAGH#AGICAGY+AGIKAGK?AGH_B@(OAGH#AGX;AGI;A
MGKSAGIOB@(OAGICAGKWAGIG"H.&?E"(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R
M,`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@9F]L9&5R
M<RXB"FUS9W-T<B`BX9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9ZBX9Z3X9Z[X9Z)X9^2X9Z)X9ZV
MX9Z/XH"+X9ZRX9^2X9Z9XH"+X9Z4X9Z$X9^2X9Z`X9Z^X9Z/XH"+X9Z0X9Z/
MXH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&9O;&1E<G,N(@IM<V=S='(@(N&>HN&?DN&>D^&>
M@.*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`
MB^&>HN&>D^&>N^&>B>&?DN&>B>&>MN&>C^*`B^&>LN&?DN&>F>*`B^&>E.&>
MA.&?DN&>@.&>ON&>C^*`B^&>D.&>C^*`B^&>A>&?DN&>FN&>ON&>D^*`B^&>
MA^&>MN&>A"`E9"#AGJ'AGK[AGIG"H.&?E"(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HX,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!S96YD(&UE<W-A9V5S('1O(&UO<F4@=&AA;B`E9"!R96-I<&EE
M;G1S('=I=&AI;B`E9"`B"B)H;W5R<RXB"FUS9W-T<B`BX9ZBX9^2X9Z3X9Z`
MXH"+X9Z8X9ZWX9Z3XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+
MX9ZBX9Z3X9Z[X9Z)X9^2X9Z)X9ZVX9Z/XH"+X9ZRX9^2X9Z9XH"+X9Z5X9^2
MX9Z)X9Z^XH"+X9Z?X9ZVX9Z:XH"+X9Z1X9^%XH"+X9ZBX9^2X9Z3X9Z`XH"+
MX9Z1X9Z1X9Z]X9Z;XH"+X9Z%X9^2X9Z:X9Z^X9Z3XH"+X9Z'X9ZVX9Z$("5D
M(.&>D^&>MN&>@.&?B^*`B^&>H>&>ON&>F2#AGH#AGY+AGI/AGKOAGH3B@(OA
MGIKAGIGAGXCAGI;AGX'AGIL@)60@X9Z8X9^)X9^$X9Z$PJ#AGY0B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,3`T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M87)E(&YO="!A;&QO=V5D('1O('-E;F0@;65S<V%G97,@=&\@;6]R92!T:&%N
M("5D(')E8VEP:65N=',N(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>F.&>
MM^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>HN&>D^&>
MN^&>B>&?DN&>B>&>MN&>C^*`B^&>LN&?DN&>F>*`B^&>E>&?DN&>B>&>ON*`
MB^&>G^&>MN&>FN*`B^&>D>&?A>*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>
MO>&>F^*`B^&>A>&?DN&>FN&>ON&>D^*`B^&>A^&>MN&>A"`E9"#AGI/AGK;A
MGH#AGXOB@(OAGJ'AGK[AGIG"H.&?E"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3,W"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H
M92!F;VQD97(Z("(*;7-G<W1R("+AGJ+AGY+AGI/AGH#B@(OAGH#AGX;AGI;A
MGKOAGH3B@(OAGI3AGY+AGH_AGKSAGIKB@(OAGHCAGY+AGICAGX3AGX?B@(OA
MGI#AGH_"H.&?EB(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@8V%N('5S92!T:&4@
M9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT
M.B`E8R!F;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F
M;W(@=&AE('-I9VYA='5R92XB"FUS9W-T<B`B(@HBX9ZBX9^2X9Z3X9Z`XH"+
MX9ZBX9ZVX9Z%XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z`X9Z3X9^2X9Z;X9^"X9Z$
MXH"+X9Z*X9ZVX9Z`X9^+XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8
M(.&>D^&?A>*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>HN&>C^&?DN&>D.&>E.&>
MD>*`B^&>E>&?DN&>D>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>
MF>*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FL*@X9^6("5C(.&>G^&>F.&?DN&>
MFN&>MN&>E.&?B^*`B^&>F.&>MN&>C^&>M^&>@.&>MN*`B^&>G^&>MN&>FN*`
MB^&>E.&>A>&?DN&>A>&>N^&>E.&?DN&>E.&>D^&?DN&>DSL@(@HB)7,@X9Z?
MX9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZV
MPJ#AGY0B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&-A;FYO="!U;G-U8G-C<FEB92!F<F]M(%PB)7-<(BXB"FUS
M9W-T<B`BX9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+
MX9Z(X9Z4X9^+X9Z'X9ZVX9Z<XH"+X9Z6X9ZX(%PB)7-<(B#AGI3AGK;AGI/B
M@(OAGJ'AGK[AGIG"H.&?E"(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O
M<U]A9W)E96UE;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED(&YO="!A9W)E
M92!T;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O('EO=2!W
M97)E(&YO="!A;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R("+AGJ+AGY+A
MGI/AGH#B@(OAGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGIGAGIOAGXOB@(OA
MGI;AGY+AGIKAGICB@(OAGI'AGX7B@(OAGIOAGH#AGY+AGH'AGH'AGH[AGY+A
MGHSB@(OAGH#AGK?AGH7AGY+AGH7B@(OAGI/AGX/B@(OAGI;AGY+AGIKAGICB
M@(OAGI;AGY+AGIKAGX#AGH3B@(OB@(OAGI_AGX'AGISAGK8@X9Z*X9Z\X9Z%
MX9^2X9Z3X9^!X9^'XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z8X9ZWX9Z3XH"+X9Z/
MX9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9ZBX9Z3X9Z[X9Z)X9^2X9Z)
MX9ZVX9Z/XH"+X9ZRX9^2X9Z9XH"+X9Z%X9Z\X9Z;PJ#AGY0B"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,3<P"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@
M<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R(@IM
M<V=S='(@(N&>HN&?DN&>D^&>@.*`B^*`B^&>F.&>M^&>D^*`B^&>F.&>MN&>
MD^*`B^&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^&>HN&>D^&>N^&>B>&?DN&>
MB>&>MN&>C^*`BR#AGHKAGK[AGICAGY+AGI3AGKCB@(OAGI7AGY+AGIOAGK;A
MGI_AGXOB@(OAGI3AGY+AGH_AGKSAGIKB@(OAGH#AGK;AGIKB@(OAGH7AGKSA
MGIOB@(OAGHKAGX;AGH[AGK[AGIKAGH#AGK;AGIKB@(OAGI'AGX7B@(OAGI#A
MGH_B@(OAGI/AGX'AGX<B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,P"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N
M("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R
M("+AGJ+AGY+AGI/AGH#B@(OAGI3AGK;AGI/B@(OAGI3AGHGAGY+AGH?AGKSA
MGI/B@(OAGI3AGI/AGY+AGH_B@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX?B@(OA
MGIOAGKX@)25S(.&>D>&?A>*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>
MF^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F,*@X9^6("5SPJ#AGY0B
M"@HC.B!M86EL8F]X+G!H<#HQ,#`Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!H879E("5S(&YE=R!M97-S86=E<RXB"FUS9W-T<B`BX9ZBX9^2X9Z3X9Z`
MXH"+X9Z8X9ZVX9Z3XH"+X9Z?X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZX("5SPJ#A
MGY0B"@HC.B!M86EL8F]X+G!H<#HQ,#`Y"FUS9VED(")9;W4@:&%V92`Q(&YE
M=R!M97-S86=E+B(*;7-G<W1R("+AGJ+AGY+AGI/AGH#B@(OAGICAGK;AGI/B
M@(OAGI_AGK;AGIKB@(OAGI#AGY+AGICAGK@@X9^APJ#AGY0B"@HC.B!C;VUP
M;W-E+G!H<#HR,38*;7-G:60@(EEO=2!H879E(&%L<F5A9'D@<W5B;6ET=&5D
M('1H:7,@<&%G92XB"FUS9W-T<B`BX9ZBX9^2X9Z3X9Z`XH"+X9Z4X9ZVX9Z3
MXH"+X9Z*X9ZVX9Z`X9^+X9Z?X9^2X9Z3X9Z^XH"+X9Z1X9^&X9Z6X9^0X9Z:
MXH"+X9Z3X9^!X9^'XH"+X9Z:X9Z]X9Z%XH"+X9Z@X9Z^X9Z9PJ#AGY0B"@HC
M.B!L:6(O24U0+G!H<#HY-3<*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN
M('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R("+AGJ+AGY+AGI/AGH#B
M@(OAGICAGK;AGI/B@(OAGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI#AGY+A
MGICAGK@@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z0X9Z/XH"+X9Z*X9Z\X9Z%XH"+
MXH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z8PJ#AGY8B"@HC.B!L:6(O
M24U0+G!H<#HY-C(*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R<SHB"FUS9W-T<B`BX9ZBX9^2X9Z3X9Z`XH"+X9Z8
MX9ZVX9Z3XH"+X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9^2X9Z8X9ZX
M(.&>@.&?DN&>D^&>N^&>A.*`B^&>D.&>C^*`B^*`B^*`B^&>BN&>O.&>A>*`
MB^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F,*@X9^6(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$P,S$*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE87-T
M(&]N92!R96-I<&EE;G0N(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>C^&?@N*`B^&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>
MF>&?B>&>MN&>A.*`B^&>H.&?A.&>A>*`B^&>CN&>MN&>G^&?B^*`B^&>HN&?
MDN&>D^&>@.*`B^&>D>&>D>&>O>&>F^*`B^&>F.&>O>&>F<*@X9^4(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S$P"FUS9VED("(B"B)9;W4@;75S
M="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K
M97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4B"FUS9W-T<B`BX9ZBX9^2X9Z3X9Z`
MXH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+X9Z4X9Z)X9^2X9Z%X9Z\
MX9Z;XH"+X9Z#X9^2X9Z;X9ZVXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+
MX9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9ZO
MX9Z`X9Z'X9Z3(%!'4"#AGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`@X9Z*
MX9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z8X9Z^X9Z;XH"+X9Z?X9ZVX9Z:XH"+X9Z3
MX9^!X9^'(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-30*;7-G
M:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*
M;7-G<W1R("+AGJ+AGY+AGI/AGH#B@(OB@(OAGH_AGY+AGIKAGKSAGISB@(OA
MGH_AGX+B@(OAGI3AGHGAGY+AGH7AGKSAGIOB@(OAGH/AGY+AGIOAGK;B@(OA
MGI_AGICAGY+AGH3AGK;AGH_AGXOB@(OAGI_AGICAGY+AGIKAGK;AGI3AGXOB
M@(OAGH#AGKSAGI/AGI_AGX3B@(OAGJ_AGH#AGH?AGI,@4R]-24U%(.&>FN&>
ME.&>G^&?B^*`B^&>HN&?DN&>D^&>@"#AGHKAGK[AGICAGY+AGI3AGKCB@(OA
MGICAGK[AGIOB@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX<B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHW.2!T96UP;&%T97,O;6%I;&)O
M>"]J879A<V-R:7!T+FEN8SHR,#0*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M('1A<F=E="!M86EL8F]X(&9I<G-T+B(*;7-G<W1R("+AGHKAGX;AGI3AGKSA
MGH0@X9ZBX9^2X9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+
MX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z4X9^2X9Z:X9ZBX9Z4X9^+XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z"X9^$X9Z;XH"+X9Z*X9^%XH"+X9Z8X9Z]
MX9Z9PJ#AGY0B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#4*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S
M='(@(N&>HN&?DN&>D^&>@.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>C^&?@N*`
MB^&>A^&?DN&>FN&>ON&>G^*`B^&>@N&>CN&>D^&>N.*`B^&>BN&?@N&>F^*`
MB^&>C^&?DN&>FN&>O.&>G.*`B^&>F^&>N^&>E.*`B^&>F.&>O>&>F<*@X9^4
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+VIA=F%S8W)I<'0N:6YC.C@Q"FUS
M9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T
M<B`BX9Z*X9^&X9Z4X9Z\X9Z$(.&>HN&?DN&>D^&>@.*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>C^&?@N*`B^&>A^&?DN&>FN&>ON&>G^*`B^&>HN&>MN&>G^&>
MF>&>BN&?DN&>B^&>MN&>D^*`B^&>F.&>O>&>F<*@X9^4(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0@=&5M<&QA=&5S+VUA:6QB
M;W@O:F%V87-C<FEP="YI;F,Z,C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VIA
M=F%S8W)I<'0N:6YC.C(V.`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE
M87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R("+AGHKAGX;AGI3AGKSA
MGH0@X9ZBX9^2X9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+
MX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z9X9^)X9ZVX9Z$XH"+X9Z@X9^$X9Z%XH"+
MX9Z.X9ZVX9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z8X9Z]X9Z9PJ#AGY0B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]J879A<V-R:7!T+FEN8SHQ.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="XB"FUS9W-T<B`BX9ZBX9^2
MX9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+X9Z4X9Z)X9^2
MX9Z'X9ZVX9Z`X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;XH"+
MX9Z8X9Z]X9Z9PJ#AGY0B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@=&\@:&%V
M92!<(B5S7"(@96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N
M(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>C^&?DN&>FN&>O.&>G.&>C^&?
M@N*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F2!<(B5S7"(@X9Z4X9^2X9Z:
MX9Z^XH"+X9Z4X9ZVX9Z3XH"+X9Z3X9^%XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+
MX9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z0X9^"X9Z1X9ZVX9^&XH"+X9Z:X9Z4
MX9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY0B"@HC.B!L:6(O36%I;&QO9RYP
M:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R961I<F5C=&5D('1H
M:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N(@IM<V=S='(@(N&>HN&?DN&>D^&>
M@.&>E.&>MN&>D^*`B^&>E.&?DN&>C^&>O.&>FN*`B^&>D>&>M^&>G^*`B^&>
MG^&>MN&>FN*`B^&>D^&?@>&?A^*`B^&>D>&?A2`E<R#AGIOAGKX@)25SPJ#A
MGY0B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RXB"FUS9W-T
M<B`BX9ZBX9^2X9Z3X9Z`XH"+X9Z4X9ZVX9Z3XH"+X9Z&X9^2X9Z;X9Z^X9Z9
MXH"+X9Z/X9Z4XH"+X9Z1X9^%XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'XH"+
MX9Z;X9Z^("5SPJ#AGY0B"@HC.B!L:6(O1F]L9&5R+G!H<#HU,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@7"(E
M<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(N&>
MHN&?DN&>D^&>@.*`B^*`B^&>F.&>M^&>D^*`B^&>C^&?DN&>FN&>O.&>G.*`
MB^*`B^&>E.&>MN&>D^*`B^&>A^&>MN&>G.*`B^&>E.&?DN&>FN&>A>&>MN&?
MAN*`B^&>D>&?A2!<(B5S7"+"H.&?E"#AGI/AGX'AGX?B@(OAGH+AGKKB@(OA
MGH?AGK;B@(OAGJ+AGY+AGISAGKCB@(OAGHKAGX+AGIOB@(OAGICAGXGAGK;A
MGI_AGXKAGKCAGI/B@(OAGI3AGICAGY+AGIKAGK[B@(OAGI3AGK;AGI/B@(OA
MGI/AGK?AGIGAGK;AGIDB"@HC.B!L:6(O1F]L9&5R+G!H<#HU-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M
M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R
M("+AGJ+AGY+AGI/AGH#B@(OAGICAGK?AGI/AGH_AGY+AGIKAGKSAGISB@(OB
M@(OAGI3AGK;AGI/B@(OAGHCAGI3AGXOB@(OAGH?AGK;AGISB@(OAGI;AGK@@
M7"(E<UPBPJ#AGY0@X9Z3X9^!X9^'XH"+X9Z"X9ZZXH"+X9Z'X9ZVXH"+X9ZB
MX9^2X9Z<X9ZXXH"+X9Z*X9^"X9Z;XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3
MXH"+X9Z4X9Z8X9^2X9Z:X9Z^XH"+X9Z4X9ZVX9Z3XH"+X9Z3X9ZWX9Z9X9ZV
MX9Z9(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<
M(B(*;7-G<W1R("+AGJ+AGY+AGI/AGH#AGH_AGY+AGIKAGKSAGISB@(OB@(OA
MGI3AGK;AGI/B@(OAGH?AGK;AGISB@(OAGI3AGY+AGIKAGH7AGK;AGX;B@(OA
MGI'AGX4@7"(E<UPB(.&>BN&?A.&>F>*`B^&>A^&?A.&>@N&>A^&?D.&>F2(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C4W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB
M(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>C^&?DN&>FN&>O.&>G.*`B^*`
MB^&>E.&>MN&>D^*`B^&>B.&>E.&?B^*`B^&>A^&>MN&>G.*`B^&>EN&>N"!<
M(B5S7"(@X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"XH"+X9Z'X9^0X9Z9(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`BX9Z(X9^2X9Z8X9^$X9^'XH"+X9Z:X9Z4X9Z?X9^+X9ZBX9^2X9Z3
MX9Z`(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4P"FUS9VED(")9;W5R
M(%!'4"!0=6)L:6,O4')I=F%T92!+97ES(@IM<V=S='(@(N&>@.&>O.&>D^&>
MG^&?A"#AGI_AGK;AGI+AGK;AGIKAGH[AGX@OX9ZOX9Z`X9Z'X9Z3(%!'4"#A
MGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C<Q('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-@IM<V=I
M9"`B66]U<B!0<FEV871E($ME>2(*;7-G<W1R("+AGH#AGKSAGI/AGI_AGX3B
M@(OAGJ_AGH#AGH?AGI/B@(OAGIKAGI3AGI_AGXOB@(OAGJ+AGY+AGI/AGH`B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW,0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y(@IM<V=S='(@
M(N&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B.*`B^&>
MFN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-C8*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE
M;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`BX9ZBX9ZVX9Z?X9Z9X9Z*X9^2
MX9Z+X9ZVX9Z3XH"+X9Z&X9^2X9Z;X9Z^X9Z9X9Z/X9Z4+>&>D>&?A>*`B^&>
MFN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@,*@X9^6(#QE;3XHX9Z?X9^2X9Z:
MX9^!X9Z%XH"+X9Z%X9ZWX9Z/X9^2X9Z/*3PO96T^(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHT.0IM<V=I9"`B66]U<B!3+TU)344@4'5B;&EC
M+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@(N&>G.&>M^&>B>&?DN&>
MB>&>MN&>E.&>D^&>E.&>C^&?DN&>FN*`BR#AGI_AGK;AGI+AGK;AGIKAGH[A
MGX@OX9ZOX9Z`X9Z'X9Z3XH"+(.&>D^&?@R!3+TU)344@X9Z:X9Z4X9Z?X9^+
MXH"+X9ZBX9^2X9Z3X9Z`(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O
M=6YT7W-E;&5C="YI;F,Z,38*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S
M='(@(N&>@N&>CN&>D^&>N.*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>
M@,*@X9^6(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-`IM<V=I9"`B
M(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R
M(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(N&>
MHN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>@.&?DN&>F^&?@N&>A.&>
M@.&?DN&>F^&>MN&>F>*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@,*@
MX9^6(#QE;3XHX9Z?X9^2X9Z:X9^!X9Z%XH"+X9Z%X9ZWX9Z/X9^2X9Z/+"#A
MGI3AGHGAGY+AGH7AGKSAGIOB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;A
MGI/B@(OAGI/AGKCAGICAGKWAGIGAGY?B@(OAGIOAGK[B@(OAGH?AGKWAGIKB
M@(OAGI#AGY+AGICAGK@I/"]E;3XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ,#$*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T
M<B`BX9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZXXH"+X9Z:X9Z[X9Z`X9Z:X9Z`
MXH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+(.&>F.&>M^&>D^&>
M@N&>MN&?AN&>D>&?DN&>FN*`B^&>@.&>MN&>FN*`B^&>E.&>A.&?DN&>H.&>
MMN&>B>*`B^&>@.&?DN&>D^&>N^&>A.&>C^&>O2#AGI/AGX/B@(OAGI3AGY+A
MGIKAGI?AGX'AGI'B@(OAGIKAGKSAGI3AGI?AGK;AGI;B@(OAGI/AGX'AGX?"
MH.&?E"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3$*;7-G:60@(EEO
M=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G
M<W1R("+AGI_AGX;AGH[AGKOAGX;B@(OAGH_AGKWB@(OAGJ+AGH#AGY+AGI_A
MGIKB@(OAGIOAGX;AGI/AGK;AGX;B@(OAGHKAGK[AGICB@(OAGIKAGI3AGI_A
MGXOAGJ+AGY+AGI/AGH`@X9Z?X9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+XH"+X9Z5
MX9^2X9Z)X9Z^XH"+X9Z?X9ZVX9Z:PJ#AGY8B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YC<GEP='-E;&5C="YI;F,Z,0IM<V=I9"`B66]U<B!D969A=6QT(&5N
M8W)Y<'1I;VX@;65T:&]D(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G<W1R
M("+AGISAGK?AGI+AGKCAGI_AGK;AGI_AGY+AGH_AGY+AGIKB@(OAGI3AGICA
MGY+AGIOAGX+AGH3B@(OAGH?AGK;B@(OAGH#AGKSAGHKB@(OAGIOAGX;AGI/A
MGK;AGX;AGHKAGK[AGICB@(OAGIKAGI3AGI_AGXOAGJ+AGY+AGI/AGH`@X9Z?
MX9Z8X9^2X9Z:X9ZVX9Z4X9^+XH"+XH"+X9Z5X9^2X9Z)X9Z^XH"+X9Z?X9ZV
MX9Z:PJ#AGY8B"@HC.B!A='1A8VAM96YT+G!H<#HY-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R(&QI;FME9"!A='1A8VAM96YT(&AA<R!B965N(&1O
M=VYL;V%D960@8GD@870@;&5A<W0@;VYE('5S97(N7&XB"B)<;B(*(D%T=&%C
M:&UE;G0@;F%M93H@)7-<;B(*(D%T=&%C:&UE;G0@9&%T93H@)7-<;B(*(EQN
M(@HB0VQI8VL@;VX@=&AE(&9O;&QO=VEN9R!L:6YK('1O('!E<FUA;F5N=&QY
M(&1E;&5T92!T:&4@871T86-H;65N=#I<;B(*(B5S(@IM<V=S='(@(B(*(N&>
MK^&>@.&>G^&>MN&>FN*`B^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>FN&>E.&>
MG^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>BN&?@N&>F^*`B^&>E.&>MN&>D^*`
MB^&>C^&>E^&?DN&>A^&>MN&>E.&?BR#AGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGI'AGK;AGHGAGIGAGH#B@(OAGHKAGX3AGIGB@(OAGJ+AGY+A
MGI/AGH#B@(OAGI3AGY+AGIKAGK[B@(OAGIGAGXGAGK;AGH3B@(OAGH_AGK?A
MGH7B@(OAGICAGY+AGI/AGK;AGH#"H.&?E%QN(@HB7&XB"B+AGHCAGY+AGICA
MGX3AGX?B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI?AGY+AGH?AGK;AGI3AGXO"
MH.&?EB`E<UQN(@HBX9Z`X9ZVX9Z;X9Z4X9Z:X9ZWX9Z%X9^2X9Z&X9^!X9Z1
MXH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+PJ#AGY8@
M)7-<;B(*(EQN(@HBX9Z%X9Z[X9Z%XH"+X9Z/X9^&X9Z.XH"+X9Z!X9ZVX9Z$
MXH"+X9Z`X9^2X9Z:X9^$X9Z8XH"+X9Z*X9Z^X9Z8X9^2X9Z4X9ZXXH"+X9Z;
MX9Z[X9Z4XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+
MXH"+X9Z'X9ZVXH"+X9ZBX9Z%X9ZWX9Z3X9^2X9Z/X9^2X9Z:X9^#X9Z9X9^-
MPJ#AGY9<;B(*(B5S(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M.#D*;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV
M97)E9"XB"FUS9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZB
MX9^2X9Z3X9Z`XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4
MX9Z)X9^2X9Z'X9Z\X9Z3XH"+X9Z*X9^$X9Z9XH"+X9Z'X9^$X9Z"XH"+X9Z'
MX9^0X9Z9PJ#AGY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`W"FUS
M9VED(")9;W5R('-I9VYA='5R93HB"FUS9W-T<B`BX9Z@X9Z/X9^2X9Z0X9Z;
MX9^!X9Z!X9ZVXH"+X9Z:X9Z4X9Z?X9^+XH"+X9ZBX9^2X9Z3X9Z`PJ#AGY8B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z
M-PIM<V=I9"`B6TAI9&4@061D<F5S<V5S72(*;7-G<W1R(");X9Z;X9ZVX9Z`
MX9^+XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z372(*"B,Z(&UE<W-A
M9V4N<&AP.C(U-R!C;VUP;W-E+G!H<#HV,#D@;6%I;&)O>"YP:'`Z-CDQ(&QI
M8B]#;VUP;W-E+G!H<#HQ.38X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T
M<B`B6^&>@N&?DN&>F.&>MN&>D^*`B^&>E.&?DN&>FN&>DN&>MN&>D^&>E.&>
MD5TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N
M:G,Z.`IM<V=I9"`B6U-H;W<@061D<F5S<V5S("TB"FUS9W-T<B`B6^&>E.&>
MA.&?DN&>H.&>MN&>B>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DR`M
M(@H*(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C(R"B,L('!H<"UF;W)M870*
M;7-G:60@(EM3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP:65N='-=(@IM<V=S
M='(@(EOAGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGJ+AGK;AGI_AGIGAGHKAGY+A
MGHOAGK;AGI,@+2#AGJ+AGY+AGI/AGH#B@(OAGI'AGI'AGKWAGIOB@(OAGH7A
MGX;AGI/AGKWAGI,@)7-=(@H*(SH@8V]M<&]S92YP:'`Z,3$S,`IM<V=I9"`B
M7T)C8R(*;7-G<W1R(")?0N&>F^&>MN&>@.&?BR`B"@HC.B!M97-S86=E+G!H
M<#HU-C4@;6%I;&)O>"YP:'`Z-#DP"FUS9VED(")?0FQA8VML:7-T(@IM<V=S
M='(@(E]"X9Z4X9Z)X9^2X9Z'X9ZXXH"+X9Z!X9^2X9Z8X9^%("(*"B,Z(&-O
M;7!O<V4N<&AP.C$Q,C<*;7-G:60@(E]#8R(*;7-G<W1R(")?0^&>A>&>F.&?
MDN&>F^&>A"`B"@HC.B!M97-S86=E+G!H<#HU,S<@;6%I;&)O>"YP:'`Z-#8S
M(&UA:6QB;W@N<&AP.C0V-@IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")?1.&>
MF^&>N^&>E"`B"@HC.B!L:6(O24U0+G!H<#HW.3,*;7-G:60@(E]&;VQD97)S
M(@IM<V=S='(@(E]&X9Z0X9Z/("(*"B,Z(&-O;7!O<V4N<&AP.C$Q,#<*;7-G
M:60@(E])9&5N=&ET>2(*;7-G<W1R(")?2>&>HN&>C^&?DN&>C^&>G^&>B>&?
MDN&>B>&>MN&>CB`B"@HC.B!L:6(O24U0+G!H<#HW-3@*;7-G:60@(E]);F)O
M>"(*;7-G<W1R(")?2>&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>D>&>D>&>O>&>
MFR`B"@HC.B!L:6(O24U0+G!H<#HX,S0*;7-G:60@(E],;V<@;W5T(@IM<V=S
M='(@(E],X9Z%X9^!X9Z)("(*"B,Z(&UE<W-A9V4N<&AP.C4W.`IM<V=I9"`B
M7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(E]-X9Z`X9Z\X9Z*XH"+X9Z:X9Z4
MX9Z?X9^+XH"+X9Z?X9ZVX9Z:("(*"B,Z(&QI8B])35`N<&AP.C<Y,`IM<V=I
M9"`B7TYE=R!-97-S86=E(@IM<V=S='(@(E].X9Z?X9ZVX9Z:XH"+X9Z0X9^2
MX9Z8X9ZX("(*"B,Z(&UE<W-A9V4N<&AP.C4Y-`IM<V=I9"`B7U!R:6YT(@IM
M<V=S='(@(E]0X9Z4X9^$X9^'X9Z6X9Z[X9Z8X9^2X9Z6("(*"B,Z(&-O;7!O
M<V4N<&AP.C$Q.3@*;7-G:60@(E]0<FEO<FET>2(*;7-G<W1R(")?4.&>HN&>
MMN&>D>&>M^&>E^&>MN&>EB`B"@HC.B!M86EL8F]X+G!H<#HS,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7U)E9G)E<V@@)7,B"FUS9W-T<B`B7U+AGI+AGY+A
MGISAGK[B@(OAGK+AGY+AGID@)7,@X9Z?X9^2X9Z:X9Z?X9^+("(*"B,Z(&UE
M<W-A9V4N<&AP.C4T,`IM<V=I9"`B7U)E<&QY(@IM<V=S='(@(E]2X9Z&X9^2
MX9Z;X9Z^X9Z9XH"+X9Z/X9Z4("(*"B,Z(&QI8B])35`N<&AP.C<Y-0IM<V=I
M9"`B7U-E87)C:"(*;7-G<W1R(")?4^&>G^&?DN&>G.&?@N&>A.*`B^&>FN&>
M@"`B"@HC.B!C;VUP;W-E+G!H<#HQ,#DR(&-O;7!O<V4N<&AP.C$P.38*;7-G
M:60@(E]396YD($UE<W-A9V4B"FUS9W-T<B`B7U/AGI7AGY+AGHGAGK[B@(OA
MGI_AGK;AGIH@(@H*(SH@;6%I;&)O>"YP:'`Z-3@P"FUS9VED(")?5&AR96%D
M(@IM<V=S='(@(E]4X9Z!X9^2X9Z?X9^#XH"+X9Z?X9^2X9Z:X9ZAX9ZVX9Z9
M("(*"B,Z(&-O;7!O<V4N<&AP.C$Q,C,@8V]M<&]S92YP:'`Z,3$R-0IM<V=I
M9"`B7U1O(@IM<V=S='(@(E]4X9Z1X9^%("(*"B,Z(&UA:6QB;W@N<&AP.C0W
M,0IM<V=I9"`B7U5N9&5L971E(@IM<V=S='(@(E]5X9Z8X9ZWX9Z3XH"+X9Z;
MX9Z[X9Z4("(*"B,Z(&UE<W-A9V4N<&AP.C4U.0IM<V=I9"`B7U9I97<@5&AR
M96%D(@IM<V=S='(@(E]6X9Z8X9Z^X9Z;XH"+X9Z!X9^2X9Z?X9^"XH"+X9Z?
MX9^2X9Z:X9ZAX9ZVX9Z9("(*"B,Z(&UE<W-A9V4N<&AP.C4W,2!M86EL8F]X
M+G!H<#HT.38*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B7U?AGI3AGHGA
MGY+AGH?AGKCAGI\@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C@U,PIM<V=I9"`B
M861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9Z?X9^2
MX9Z"X9ZVX9Z;X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;XH"+
MX9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$U
M.#`*;7-G:60@(F%T=&%C:&UE;G0B"FUS9W-T<B`BX9ZOX9Z`X9Z?X9ZVX9Z:
MXH"+X9Z7X9^2X9Z'X9ZVX9Z4X9^+(@H*(SH@=FEE=RYP:'`Z,3$T"FUS9VED
M(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B871T86-H;65N=',N>FEP(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C(W-@IM<V=I9"`B
M8GET97,B"FUS9W-T<B`BX9Z4X9^#(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C@W
M-PIM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("+A
MGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OA
MGJ_AGH#AGI_AGK;AGIKB@(OAGIOAGI'AGY+AGI+AGI7AGILB"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z.#0Y"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G
M<W1R("+AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGK[AGH#B@(OAGI;A
MGY#AGH_AGXSAGICAGK;AGI/B@(OAGI3AGHGAGY+AGH7AGKSAGILB"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z.#0Q"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9ZVX9Z:XH"+
MX9Z4X9^2X9Z:X9Z^XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z6X9ZV
MX9Z`X9^2X9Z9X9Z4X9Z)X9^2X9Z'X9ZV(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C@Y-PIM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("+AGH#A
MGX;AGJ#AGKOAGI_B@(OAGH#AGK;AGIKB@(OAGH#AGX;AGH[AGH_AGXOB@(OA
MGIKAGH7AGI/AGK;AGI_AGICAGY+AGI;AGY#AGI/AGY+AGI(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z.#<S"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M
M:7-S:6YG(@IM<V=S='(@(N&>E.&>MN&>C^&?B^*`B^&>K^&>@.&>G^&>MN&>
MFN*`B^&>E.&?DN&>FN&>EN&?D.&>D^&?DN&>DN*`B^&>G^&?AN&>@>&>MN&>
MD^&?B^*`B^&>E.&?AN&>E>&>N^&>CR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HX
M-#4*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(N&>@.&?AN&>
MH.&>N^&>G^*`B^&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F>*`B^&>
MD>&>M^&>D^&?DN&>D^&>D^&?D.&>F2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HY
M,#$*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("+AGIKAGH#B@(OA
MGICAGK?AGI/B@(OAGH/AGK[AGHGB@(OAGI+AGK;AGH_AGKOB@(OAGI3AGHGA
MGY+AGH7AGKSAGILB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:'1M;#HQ-@IM<V=I9"`B9G)O;2(*;7-G<W1R("+AGI;AGK@B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z.#4W"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G
M<W1R("+AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOAGXOB@(OAGHCAGY+A
MGICAGX3AGX?B@(OAGICAGXGAGK;AGI_AGXKAGKCAGI,B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C,Q"FUS9VED(")I;B(*;7-G<W1R
M("+AGH#AGY+AGI/AGKOAGH0B"@HC.B!L:6(O0V]M<&]S92YP:'`Z.#@Q"FUS
M9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[
MX9Z?XH"+X9Z4X9Z)X9^2X9Z%X9^!X9Z)+^&>E.&>B>&?DN&>A>&>O.&>FR(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HX-C4*;7-G:60@(FEN=&5R;F%L('-O9G1W
M87)E(&5R<F]R(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`B^&>@.&>F.&?
MDN&>F.&>G.&>M^&>DN&>N.*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A2(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YH=&UL.C$S"FUS9VED(")I
M;G1O(&9O;&1E<B(*;7-G<W1R("+AGI'AGX7B@(OAGH#AGY+AGI/AGKOAGH3B
M@(OAGI#AGH\B"@HC.B!S;6EM92YP:'`Z,CD@<&=P+G!H<#HW-PIM<V=I9"`B
M:V5Y(@IM<V=S='(@(N&>@.&>O.&>D^&>G^&?A"(*"B,Z(&9O;&1E<G,N<&AP
M.C$P.0IM<V=I9"`B;6%I;&)O>"!F:6QE(@IM<V=S='(@(N&>K^&>@.&>G^&>
MMN&>FN*`B^&>E.&?DN&>FN&>HN&>E.&?B^*`B^&>G^&?AN&>E.&>N^&>C^&?
MDN&>FB(*"B,Z(&QI8B]-97-S86=E+G!H<#HU,C0@;&EB+T-O;7!O<V4N<&AP
M.C8T,`IM<V=I9"`B;F%M92(*;7-G<W1R("+AGHCAGY+AGICAGX3AGX<B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C,R"FUS9VED(")N
M;VYE(@IM<V=S='(@(N&>@N&?DN&>F.&>MN&>DR(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FAT;6PZ-3`*;7-G:60@(F]R(@IM<V=S='(@(N&>
MK"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HX.3,*;7-G:60@(G!E<FUI<W-I;VX@
M9&5N:65D(@IM<V=S='(@(N&>G^&>M^&>D>&?DN&>DN&>M^*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>BN&>M^&>G^&?@>&>DB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V%D9')E<W-E<T)L;V-K<RYJ<SHX"FUS
M9VED(")R96-I<&EE;G1S72(*;7-G<W1R("+AGJ+AGY+AGI/AGH#B@(OAGI'A
MGI'AGKWAGIM=(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C@X.0IM<V=I9"`B<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>
MG^*`B^&>EN&>N.*`B^&>A>&>F.&?DN&>A.&>MN&>F>*`B^&>@.&?DN&>D^&>
MN^&>A.*`B^&>EN&>M^&>DN&>N.&>@.&>MN&>FB(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HX-C$*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B
MX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z:X9Z`XH"+X9Z?X9^!X9Z<X9ZV
MXH"+X9Z4X9ZVX9Z3(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:'1M;#HQ.0IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS9W-T<B`BX9Z`X9^&
MX9Z@X9Z[X9Z?XH"+X9ZBX9Z`X9^2X9Z!X9Z:X9ZVX9Z<X9ZWX9Z:X9Z[X9Z1
MX9^2X9Z2(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:'1M;#HQ
M.0IM<V=I9"`B<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@(N&>@.&?AN&>H.&>
MN^&>G^*`B^&>HN&>@.&?DN&>@>&>FN&>MN&>G.&>M^&>FN&>N^&>D>&?DN&>
MDB(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HX-CD*;7-G:60@(G-Y<W1E;2!E<G)O
M<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OAGI3AGY+AGIKAGI;AGY#A
MGI/AGY+AGI(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z.#@U"FUS9VED(")T96UP
M;W)A<GD@9F%I;'5R92(*;7-G<W1R("+AGI3AGIKAGK;AGH?AGY#AGIGB@(OA
MGI3AGH[AGY+AGHKAGX3AGX?AGJ+AGK;AGI_AGI/AGY+AGI,B"@HC.B!L:6(O
M1FEL=&5R+G!H<#HU,0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B
MX9Z4X9Z)X9^2X9Z'X9ZXXH"+X9Z!X9^2X9Z8X9^%XH"+X9Z:X9Z4X9Z?X9^+
MXH"+X9ZBX9^2X9Z3X9Z`(@H*(SH@;&EB+T9I;'1E<BYP:'`Z-C$*;7-G:60@
M(GEO=7(@=VAI=&5L:7-T(@IM<V=S='(@(N&>E.&>B>&?DN&>A^&>N.*`B^&>
MG^*`B^&>FN&>E.&>G^&?B^*`B^&>HN&?DN&>D^&>@"(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+VAE7TE,
M+G!O````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#,Q,#8T,@`Q,#0Q-S,V,C<V-``P,3<Q-30`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!(96)R97<@=')A;G-L871I;VYS
M(&9O<B!);7`@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#8@36%T="!3
M96QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^"B,@5&AI<R!F:6QE(&ES(&1I
M<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($EM<"!P
M86-K86=E+@HC($%U=&]M871I8V%L;'D@9V5N97)A=&5D+"`R,#`V+@HC"FUS
M9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!);7`@2#,@
M*#0N,BUC=G,I7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#$M,C0@
M,38Z-3<K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,2TR-"`Q
M-CHU-RLP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($UA='0@4V5L<VMY(#QS
M96QS:WE`8V]L=6UB:6$N961U/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L
M:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]551&+3A<;B(*(D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ-34X"FUS9VED("(@("`@("!#8SH@(@IM<V=S='(@(B`@("`@(->4
MUZ+7JM>GUYG7G3H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$U-34*;7-G:60@
M(B`@("`@(%1O.B`B"FUS9W-T<B`B("`@("`@UY#7G#H@(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$U-#,*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@
M(->JUY#7J->9UYHZ("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-30V"FUS9VED
M("(@("`@1G)O;3H@(@IM<V=S='(@(B`@("#7GM>0UZHZ("(*"B,Z(&9O;&1E
M<G,N<&AP.C(W-"!M86EL8F]X+G!H<#HS,S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ-34R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(B#7H->5UZG7
MD#H@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38Y"FUS9VED("(@
M6R!3879E('1H92!K97D@=&\@>6]U<B!!9&1R97-S(&)O;VL@72`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<Q"FUS9VED("(@
M6R!6:65W('1H92!R87<@:V5Y(%T@(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N
M<&AP.C4V,`IM<V=I9"`B(R(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$U
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!-97-S86=E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O4W!A;2YP:'`Z,C$X"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O4W!A;2YP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE
M<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O4W!A
M;2YP:'`Z,3@P"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA
M=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B(@H*(SH@
M;&EB+U-P86TN<&AP.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S
M86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O4W!A;2YP:'`Z
M,3<R"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E
M;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H
M<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@=&\@)60@;V8@)60@365S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C4V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!!='1A8VAM96YT<RP@)7,B"FUS
M9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-S@T(&QI8B]-24U%+T-O;G1E;G1S
M+G!H<#HU-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B
M(@H*(SH@;6%I;&)O>"YP:'`Z-S@R(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HU
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@34(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN
M<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S
M+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HU-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@8GET97,B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!M86EL8F]X+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E:6YG(')E;F%M960@
M870@=&AE('-T87)T(&]F('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M(&-A;F-E;&QE9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M(&1E8VQI;F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-#DR"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D
M('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('1E;G1A
M=&EV96QY(&%C8V5P=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-#@X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E
M<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-#<R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DR
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!A;6UE;F0@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3<Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO
M=2!A=V%R92!O9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES
M:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(U-"!M97-S86=E
M+G!H<#HR-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B(*"B,Z(&UE<W-A9V4N<&AP.C0Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:'1M;#HW,PIM<V=I9"`B*$%P<&QY
M('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C8P
M"FUS9VED("(H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H
M92!C;VUP;W-E('-C<F5E;BXI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*$A434PI(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I
M9"`B*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG+G!H<#HR
M-#D*;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F
M=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("`B"B)#
M:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L
M:65D+BDB"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(T-@IM<V=I9"`B
M(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M
M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E
M96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYH=&UL.C0W"FUS9VED("(J($%D9"!T
M:&5S92!B>2!C;&EC:VEN9R!/2R`J(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYH=&UL.C,R"FUS9VED("(J(%!L96%S92!S
M96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]#
M;VYT96YT<RYP:'`Z-38U"B,L('!H<"UF;W)M870*;7-G:60@(C$@071T86-H
M;65N="P@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@S,0IM<V=I9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@S-`IM<V=I9"`B,3`P,"!C:&%R86-T97)S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,S(*;7-G
M:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,S,*;7-G:60@(C4P,"!C:&%R86-T97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C
M:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G
M92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I
M9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+W-E87)C:"YH=&UL.C0Y"FUS9VED(")!3D0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P-0IM<V=I
M9"`B06)O=F4@=&AE(&UE<W-A9V4@=&5X="(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3@R"FUS9VED(")!8V-E<'0@86YD(&%D
M9"!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3@U"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S0V"FUS9VED(")!
M8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,C4X"FUS9VED(")!8V-E<'1E9#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT)W,@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4R,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S(U"FUS9VED(")!8W1I
M;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(P,2!L
M:6(O34E-12](96%D97)S+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D("5S('1O(&UY($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*;7-G:60@(D%D9"!S
M;W5R8V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4W,PIM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X,PIM<V=I9"`B061D
M('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C,R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@87,@86X@871T
M86-H;65N="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y.0IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@
M=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E
M<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C(*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL
M<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY
M,PIM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G
M92!E<G)O<B!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*
M"B,Z(&-O;7!O<V4N<&AP.C@V-R!C;VUP;W-E+G!H<#HQ,C,P(&-O;G1A8W1S
M+G!H<#HW-PHC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:'1M;#HX
M"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B061D<F5S<R!";V]K<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("(B"B)!
M9&1R97-S97,@=&\@0D-#(&%L;"!M97-S86=E<SH@/&5M/BAO<'1I;VYA;"P@
M96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W("(*(FQI;F4I/"]E;3XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,@IM<V=I9"`B
M(@HB061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H:7,@:61E;G1I
M='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D<F5S<R!O;B!A
M(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYH=&UL.C<*;7-G:60@(D%L;"(*;7-G<W1R("+7E->;UYPB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S"FUS9VED
M("(B"B)!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RD@
M=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@(@HB9FEL93HB"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I
M;B!Y;W5R(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@
M8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN
M<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T
M=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L
M971E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L
M971E7W-E;G1M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO
M;G1H<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A8VPN
M<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L
M9&5R(%PB)7-<(B!S=6-C97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@Q"FUS9VED(")!;&QO
M=R!&;VQD97(@0W)E871I;VX_(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G!R969S
M+G!H<#HY.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI
M960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$Q"FUS9VED(")!;'1E<FYA=&EV92!P
M87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3@T"FUS9VED(")!;'=A>7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V.0IM<V=I9"`B06QW87ES('-A
M=F4@871T86-H;65N=',B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C4V,PIM<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T
M:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@
M(@HB<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HT-#8*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN
M9R!T:&4@;F5W(&YO=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HT-#4*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C
M<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N
M<&AP.C0W,B!M86EL8F]X+G!H<#HX,3@@;6%I;&)O>"YP:'`Z.3<Q"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YH=&UL.CD@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,34*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FAT;6PZ,S`@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FAT
M;6PZ-`IM<V=I9"`B06YS=V5R960B"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H
M<#HS,CD*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z
M(&UA:6QB;W@N<&AP.C,U,0IM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R
M("(B"@HC.B!M86EL8F]X+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M07!P;'D@1FEL=&5R<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F:6QT97)P<F5F
M<RYP:'`Z.38*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I
M;F<@;VX_(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G!R969S+G!H<#HY-PIM<V=I
M9"`B07!P;'D@9FEL=&5R(')U;&5S('=H96YE=F5R($EN8F]X(&ES(&1I<W!L
M87EE9#\B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S8Q"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@5FER='5A;"!&
M;VQD97(@1&5F:6YI=&EO;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L
M:6,@:V5Y/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4
M:&ES(&ES($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+VIA=F%S8W)I<'0N:6YC.C8*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HU,S<@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M.#`*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,
M62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+T-O;G1E;G1S+G!H<#HR-#(*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT/R(*
M;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HT-C0*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-4"YP:'`Z-S@W"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TE-4"YP:'`Z-S<W"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(B(*"B,Z
M(&UA:6QB;W@N<&AP.C0V,PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z,S8@
M=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z.3$*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S
M(&EN;F]C96YT/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHS,2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHX-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R
M="!T:&ES(&UE<W-A9V4@87,@<W!A;3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDR-PIM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#(*;7-G:60@(D%S
M8V5N9&EN9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3,P
M,`IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N
M<&AP.C$R.3(*;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B
M;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]T;F5F+G!H<#HQ,3$*;7-G:60@(D%T=&%C:&5D($9I;&4Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-3DQ(&QI8B]#;VUP
M;W-E+G!H<#HQ-C@W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%T=&%C:&5D
M(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE;G0@<VEZ92!L:6UI
M=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,S<W"FUS9VED(")!='1A8VAE9"!I<R!A(')E
M<&QY('1O(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N="XB"FUS9W-T<B`B
M(@H*(SH@;6%I;&)O>"YP:'`Z.3@S('1E;7!L871E<R]C;VUP;W-E+VIA=F%S
M8W)I<'0N:6YC.C(T,@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:'1M
M;#HQ-"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,C8Y"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HS,C4*;7-G:60@(D%T=&%C
M:&UE;G0B"FUS9W-T<B`B(@H*(SH@871T86-H;65N="YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B071T86-H;65N="`E<R!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(U-@IM<V=I9"`B071T86-H;65N
M="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-3(T(&QI8B]#;VUP;W-E+G!H<#HV-#`*;7-G:60@(D%T=&%C:&UE;G0@<W1R
M:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP92(*;7-G<W1R("(B"@HC
M.B!C;VUP;W-E+G!H<#HQ,C0Q(&QI8B]#;VUP;W-E+G!H<#HR,C(T('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HR-#(*;7-G:60@(D%T=&%C:&UE
M;G1S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-S@*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,PIM<V=I9"`B071T96YT:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*;7-G:60@(D%U=&A?
M:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-#`*;7-G:60@(B(*
M(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W
M:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y
M.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,30*;7-G:60@(D%W86ET
M:6YG(%)E<W!O;G-E(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4Q,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")"86-?:R!T;R`E<R(*;7-G<W1R("(B"@HC
M.B!M97-S86=E+G!H<#HU,3`@=&AR96%D+G!H<#HQ,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP
M.C$S,@IM<V=I9"`B0F%C:R!T;R!-=6QT:7!L92!-97-S86=E(%9I97<@26YD
M97@B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S`*;7-G:60@(D)A8VL@
M=&\@5&AR96%D($1I<W!L87DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HU-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&QO9VEN(&YA
M;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M
M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0F%D(')E<75E<W0Z("5S+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H
M<#HR,S4@;&EB+U-E87)C:"YP:'`Z-C$U('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYH=&UL.C0R"B,Z('1E;7!L871E<R]L;V=I;B]R96-O;7!O<V4N
M:'1M;#HS,@IM<V=I9"`B0F-C(@IM<V=S='(@(M>4UZ+7JM>GUYG7G2#7HM>9
MUY77E=>HUYG7G2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V
M,PIM<V=I9"`B0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@
M:6YF;W)M871I;VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<P-@IM<V=I9"`B0F5L;W<@=&AE(&UE<W-A9V4@=&5X
M="(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-C4@;6%I;&)O>"YP:'`Z
M-#DP"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`BUZC7J=>9UY[7E"#7J=>7
MUY77J->4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8R.0IM<V=I9"`B
M0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@87)E
M('-P96-I9FEC86QL>2!R97%U97-T960_(@IM<V=S='(@(B(*"B,Z(&QI8B]3
M96%R8V@N<&AP.C8R,PIM<V=I9"`B0F]D>2(*;7-G<W1R("(B"@HC.B!S96%R
M8V@N<&AP.C,R-B!S96%R8V@N<&AP.C,S,2!S96%R8V@N<&AP.C,S-B!S96%R
M8V@N<&AP.C,T,0IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-CDV"FUS9VED(")";W1H($AE861E<B!,:7-T:6YG
M(&%N9"!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP
M:'`Z,3$X.`IM<V=I9"`B0U]H87)S970B"FUS9W-T<B`B(@H*(SH@<V5A<F-H
M+G!H<#HS,3(*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,34U"FUS9VED(")#86X@;F]T(&-O;FYE8W0@
M=&\@=&AE(')E;6]T92!M86EL('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-3,*;7-G:60@(D-A;B!N;W0@8V]N;F5C
M="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@
M)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT("(*(FUA
M:6QB;W@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR
M87-E+FEN8SHR,2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#8*
M(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:'1M;#HW-`HC.B!T96UP;&%T97,O9F]L9&5R
M<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HR,R!T96UP;&%T97,O9F]L9&5R<R]I
M;7!O<G0N:'1M;#HQ-PHC.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G
M92YH=&UL.C$Y('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FAT;6PZ-C`*
M(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FAT;6PZ-#D*;7-G:60@(D-A
M;F-E;"(*;7-G<W1R("+7J=>@UY0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R
M961I<F5C="YH=&UL.C<X('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M
M;#HR-0HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,C`X"FUS
M9VED(")#86YC96P@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]J879A<V-R:7!T+FEN8SHV"FUS9VED(")#86YC96QL:6YG('1H
M:7,@;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E
M;G1S+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR,S0@;&EB+U-E87)C
M:"YP:'`Z-C$Q('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYH=&UL.C0Q
M"B,Z('1E;7!L871E<R]L;V=I;B]R96-O;7!O<V4N:'1M;#HR,PIM<V=I9"`B
M0V,B"FUS9W-T<B`BUY37HM>JUZ?7F=>=(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHY,PIM<V=I9"`B(@HB0V5R=&EF:6-A=&4@:6UP;W)T(&ES
M(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N
M('1H:7,@(@HB<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-CDV"FUS9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:'1M;#HS-`IM<V=I
M9"`B0VAA;F=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FAT;6PZ,S4*;7-G:60@(D-H86YG92!!;&PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDR"FUS9VED(")#:&%N9V4@1F]L
M9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,*
M;7-G:60@(B(*(D-H86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@
M;6%N>2!M97-S86=E<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@(@HB:&]W
M(&UE<W-A9V5S(&%R92!S;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B0VAA;F=E(&UA:6P@<V5R=F5R(&%N
M9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A9&1R
M97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S-0IM<V=I9"`B0VAA<F%C=&5R
M<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FAT;6PZ,3<*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@
M3F5W($UA:6PB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C@V(&UA:6QB
M;W@N<&AP.C8T,`IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHQ,"!T96UP
M;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C$*;7-G:60@(D-H96-K
M(&%L;"!M86EL('-E<G9E<G,@>6]U('=A;G0@=&\@9F5T8V@@;6%I;"!F<F]M
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#8T"FUS
M9VED(")#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN9R!A(&UE<W-A9V4_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:'1M
M;#HV"FUS9VED(")#:&]O<V4@06-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]S97)V97)S+G!H<"YD:7-T.C$W.0IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S
M97)V97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:'1M;#HV-`IM<V=I9"`B0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@
M861D<F5S<R!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,T.0IM<V=I9"`B0VAO;W-E('1H
M92!A9&1R97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E<W-E<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,CDS"FUS9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O
M:W,@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3$U"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E
M(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I97<N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@
M:6UA9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M
M96YT('!A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V
M:65W(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S
M97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]R96QA=&5D+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E
M<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I;B!A('-E
M<&%R871E('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-O=7)C97-E;&5C="YI;F,Z,S(Q"FUS9VED("(B"B)#;&EC:R!O;B!O;F4@
M;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C
M="!A;&P@9FEE;&1S('1O("(*(G-E87)C:"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@
M>6]U<B!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDV,0IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@
M=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38R"FUS9VED(")#
M;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@
M=&\@8F4@<F5A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S='(@(M>AUY+7
ME=>H(@H*(SH@8V]M<&]S92YP:'`Z,34P"FUS9VED(")#;&]S92!T:&ES('=I
M;F1O=R(*;7-G<W1R("+7H=>2UYG7J->J(->7UYS7E=>?(->6UY0B"@HC.B!L
M:6(O24U!4"]4<F5E+G!H<#HT,C4*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-05`O5')E92YP:'`Z-#0X"FUS9VED(")#;VQL
M87!S92(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS,#0*;7-G:60@(D-O
M;&QA<'-E($%L;"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS,#0*;7-G
M:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S='(@(B(*"B,Z(&QI8B])
M34%0+U1R964N<&AP.C0T.`IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHU,0IM
M<V=I9"`B0V]L;W(@26YD:6-A=&]R.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$P,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("+7
MJM>2UY77D=>4(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V,@IM
M<V=I9"`B0V]M<&QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$T
M.0IM<V=I9"`B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-0IM<V=I9"`B0V]M<&]S92!M
M97-S86=E<R!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-`IM<V=I9"`B(@HB0V]M<&]S92!M
M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S
M97(@<W5P<&]R=',@=&AE("(*(F9E871U<F4I/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@
M;65S<V%G97,@87)E(&1I<W!L87EE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDX"FUS9VED(")#;VYF:6=U<F4@;6%I;"!P<F5V
M:65W(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP
M:'`Z,S<P"FUS9VED(")#;VYN96-T:6]N(&1R;W!P960@8GD@24U!4"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3@X
M"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F86EL960B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYT<F]L(%,O34E-12!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@IM<V=I9"`B0V]N
M=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED
M("(B"B)#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C:&5C:V5D(&9O
M<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@(@HB=VAE;B!I
M="!A<G)I=F5S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C@V"FUS9VED(")#;VYV97)T('1E>'1U86P@96UO=&EC;VYS(&EN=&\@
M9W)A<&AI8V%L(&]N97,_(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P
M-"!M97-S86=E+G!H<#HV.38@;6%I;&)O>"YP:'`Z-#(P(&UA:6QB;W@N<&AP
M.CDY.`IM<V=I9"`B0V]P>2(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU
M,#0@;65S<V%G92YP:'`Z-CDV(&UA:6QB;W@N<&AP.C0R,"!M86EL8F]X+G!H
M<#HY.3@*;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FAT;6PZ,C@*;7-G:60@(D-O<G)E
M8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:'1M;#HX,@IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E87-O;B!':79E;CH@)7,B
M"FUS9W-T<B`B(@H*(SH@871T86-H;65N="YP:'`Z-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HW,34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S86=E<R!F<F]M("5S
M+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]397-S
M:6]N+G!H<#HS,C(*;7-G:60@(D-O=6QD(&YO="!E>&5C=71E(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]T;F5F+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E
M<75E<W1E9"!F:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@
M(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H
M92!::7`@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT
M+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M<V5C=7)E(&-O;FYE8W1I;VX@=&\@=&AE($E-05`@<V5R=F5R+B`E<R`Z("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<P"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R;VT@
M24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T97,O86-L+V%C;"YI;F,Z,SD*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,0IM<V=I9"`B0W)E871E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:'1M;#HX"FUS
M9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,S<*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V
M"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R
M969S+W-P86US96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@4W!A
M;2!F;VQD97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z
M,C8@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I
M9"`B0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHQ,B!T96UP;&%T
M97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N
M97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,CD*;7-G:60@(B(*(D-R96%T92!F:6QT97)I;F<@<G5L97,@
M=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@
M9F]L9&5R<RP@(@HB86YD(&1E;&5T92!S<&%M+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*;7-G:60@(D-R96%T
M92!N97<@<W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#4P"FUS9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R
M;2!R97-P;VYS97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L
M+FEN8SHY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C8V5S<R!T
M;R`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V
M"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@
M9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4Q"FUS9VED(")#=7-T;VUI>F4@:&]W('EO=2!S96YD
M(&UA:6PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP
M.C4V-0IM<V=I9"`B1&%T7V4B"FUS9W-T<B`BUZK7D->HUYG7FB(*"B,Z(&UE
M<W-A9V4N<&AP.C(S,2!T:')E860N<&AP.C$U,`IM<V=I9"`B1&%T92(*;7-G
M<W1R("+7JM>0UZC7F=>:(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<U,`IM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(V-`IM<V=I9"`B1&5C;&EN960Z("(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30Y"FUS9VED(")$969A
M=6QT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A
M<F-H<V5L96-T+FEN8SHR,0IM<V=I9"`B1&5F875L="!396%R8V@@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS-`IM<V=I
M9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30T"FUS9VED(")$969A=6QT('-O<G1I
M;F<@9&ER96-T:6]N.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S4X"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z-3,W(&UA:6QB;W@N<&AP.C0V,R!M86EL8F]X+G!H<#HT
M-C8*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C4*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W(&QI8B])34%0+U1R964N<&AP.C0Q,@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:'1M;#HV-`IM<V=I9"`B1&5L971E(@IM<V=S='(@
M(M>>UY?7IR(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS
M9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:'1M;#HQ,0IM<V=I9"`B1&5L971E($9O
M;&1E<BAS*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD
M97)S7V-O;F9I<FTN:'1M;#HR,@IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O
M;&1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C0R"FUS9VED(")$96QE=&4@4W1A=&EO;F5R>2(*;7-G<W1R("(B
M"@HC.B!L:6(O24U!4"]4<F5E+G!H<#HT,3(*;7-G:60@(D1E;&5T92!6:7)T
M=6%L($9O;&1E<B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HS-C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L9&5R($1E9FEN
M:71I;VX@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L971E(&9E=&-H960@;65S<V%G
M97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C$Y"FUS9VED(")$96QE=&4@9G)O;2!M>2!C
M86QE;F1A<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S8Y"FUS9VED(")$96QE=&4@;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B
M96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-3$*;7-G:60@(D1E;&5T92!O;&0@<V5N="UM86EL(&9O
M;&1E<G,@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")$96QE=&4@<W!A;2!M
M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FAT;6PZ,S,W"FUS9VED(")$96QE=&4_(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C0W-2!M86EL8F]X+G!H<#HX-#$@;6%I;&)O>"YP:'`Z.3<S
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.C$W('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYH=&UL.C,S"B,Z('1E;7!L871E<R]M86EL8F]X
M+VQE9V5N9"YH=&UL.C8*;7-G:60@(D1E;&5T960B"FUS9W-T<B`B(@H*(SH@
M<V5A<F-H+G!H<#HS,SD*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS9W-T
M<B`B(@H*(SH@8V]M<&]S92YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T960@=&AE(&%T=&%C:&UE;G0@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(D1E;&5T:6YG(&%N
M9"!-;W9I;F<@365S<V%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4X-PIM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#(*;7-G:60@(D1E
M;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#,*;7-G:60@(D1E<V-E
M;F1I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8V-@IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C,S,0IM<V=I9"`B1&5S8W)I<'1I
M;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B1&5T86EL<R(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HS,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&ED
M(&YO="!A='1A8V@@7"(E<UPB(&%S('1H92!F:6QE('=A<R!E;7!T>2XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W-PIM<V=I9"`B
M1&EM('-I9VYA='5R97,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYH=&UL.C4V"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#`*;7-G:60@(D1I<W!L
M87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S86=E/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CDU"FUS9VED(")$
M:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#`T"FUS9VED(")$:7-P;&%Y('!O<"UU<"!N
M;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-S`*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP
M='D@4W!A;5PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-C(*;7-G:60@(D1I<W!L87D@=&AE
M(%PB16UP='D@5')A<VA<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,S(R"FUS
M9VED(")$:7-P;W-I=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:'1M;#HV.`IM<V=I9"`B1&\@3D]4(&UA=&-H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:'1M;#HQ.`IM
M<V=I9"`B1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV,PIM<V=I9"`B
M1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.CDU.`IM<V=I9"`B1&\@>6]U('=A
M;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@;&]G:6XN
M<&AP.C,U-0IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH
M=&UL.C8V"FUS9VED(")$;VYE(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+T-O
M;G1E;G1S+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@
M)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z
M-C8T"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@
M9FEL92DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYH=&UL.C(R"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH=&UL.C(S"FUS9VED
M(")$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$Y"FUS9VED(")$;W=N;&]A
M9"!I;B`N>FEP($9O<FUA="(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HT
M-S,@;6%I;&)O>"YP:'`Z.#(S(&UA:6QB;W@N<&AP.CDW-`HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:'1M;#HQ,2!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:'1M;#HQ.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:'1M;#HS-B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:'1M;#HW
M"FUS9VED(")$<F%F="(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]4<F5E+G!H
M<#HS-S0*;7-G:60@(D1R869T(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I9"`B1')A9G1S
M(&9O;&1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$P.`IM<V=I9"`B12UM86EL($%D9')E<W,B"FUS9W-T<B`BUY/7E=>0UZ@M
MUY#7G->GUYC7J->5UZ#7F2(*"B,Z(&UA:6QB;W@N<&AP.C@Y-0IM<V=I9"`B
M14Y$(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<T"FUS9VED(")%4E)/4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B92!D
M96QI=F5R960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHQ.2!L:6(O24U!4"]4<F5E+G!H<#HT,3,*;7-G:60@(D5D
M:70B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S8T('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FAT;6PZ,3D*;7-G:60@(D5D:70@4V5A<F-H(%%U97)Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+U1R964N<&AP.C0Q,R!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YH=&UL.C$W"FUS9VED(")%9&ET(%9I<G1U86P@
M1F]L9&5R(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C,V,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@
M9F]R("5S(@IM<V=S='(@(B(*"B,Z(&9I;'1E<G!R969S+G!H<#HW.0IM<V=I
M9"`B161I="!Y;W5R($)L86-K;&ES="(*;7-G<W1R("(B"@HC.B!F:6QT97)P
M<F5F<RYP:'`Z-S@*;7-G:60@(D5D:70@>6]U<B!&:6QT97(@4G5L97,B"FUS
M9W-T<B`B(@H*(SH@9FEL=&5R<')E9G,N<&AP.C@P"FUS9VED(")%9&ET('EO
M=7(@5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-S(*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C
M97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYH=&UL.C4Y"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HW,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B16UP=&EE9"!A;&P@;65S<V%G97,@9G)O
M;2`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C<P.`IM<V=I
M9"`B16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2!6:7)T=6%L(%1R87-H($9O
M;&1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYH=&UL.C(T"FUS9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,C(*
M;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@
M;6%I;&)O>"YP:'`Z-#8T"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z-S@W"FUS9VED(")%;7!T>2!?4W!A
M;2(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HW-S<*;7-G:60@(D5M<'1Y
M(%]4<F%S:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE
M(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI
M;F,Z-@IM<V=I9"`B16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(S"FUS9VED(")%
M;F%B;&4@;65S<V%G92!P<F5V:65W<S\B"FUS9W-T<B`B(@H*(SH@8V]M<&]S
M92YP:'`Z,3(X-@IM<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*;7-G<W1R
M("(B"@HC.B!M86EL8F]X+G!H<#HY.#4@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FAT;6PZ,38*;7-G:60@(D5N8W)Y<'1E9"(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$V(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU,3@*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U,2!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4S"FUS9VED(")%;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$T.#0*;7-G:60@(D5N9"!F;W)W
M87)D960@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,30P,PIM<V=I9"`B16YD(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YD(&UE<W-A
M9V4@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B16YT
M97(@4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M<W!A;7-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO
M=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@(D5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z
M.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O
M;&1E<B(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HV,C<*;7-G:60@
M(D5N=&ER92!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C$U
M-R!T:')E860N<&AP.C<P(&QI8B]#;VUP;W-E+G!H<#HW,3,@;&EB+T-O;7!O
M<V4N<&AP.CDW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!<(B5S7"(@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,S@Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y-`HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HQ-C4*;7-G:60@(D5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z-#,Q(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S
M97)V97(N("5S(#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+T-O;G1E
M;G1S+G!H<#HQ,C0*;7-G:60@(D5R<F]R(&1I<W!L87EI;F<@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q,"!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`X"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3`R"FUS9VED(")%=F5N="!S=6-C
M97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<Y-`IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDQ"FUS9VED(")%=F5R
M>2`S,"!S96-O;F1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y,PIM<V=I9"`B179E
M<GD@-2!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.34*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDR"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O5')E92YP:'`Z-#4V"FUS9VED
M(")%>'!A;F0B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S`S"FUS9VED
M(")%>'!A;F0@06QL(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,P,PIM
M<V=I9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(B(*"B,Z(&QI8B])
M34%0+U1R964N<&AP.C0U-@IM<V=I9"`B17AP86YD($9O;&1E<B(*;7-G<W1R
M("(B"@HC.B!C;VUP;W-E+G!H<#HX-C@@8V]M<&]S92YP:'`Z,3(S,0IM<V=I
M9"`B17AP86YD($YA;65S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#<T"FUS9VED(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O
M<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.3$*;7-G:60@
M(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@
M=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:'1M;#HV-R!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FAT;6PZ.#(*;7-G:60@(D5X<&%N9&EN9R(*;7-G<W1R("(B"@HC.B!L
M:6(O24U0+G!H<#HW.3@@;&EB+TE-4"YP:'`Z.#`P"FUS9VED(")&7V5T8V@@
M36%I;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I9"`B
M1F5T8V@@36%I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#@P"FUS9VED(")&971C:"!-86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-#8*;7-G:60@(D9E=&-H(&UE<W-A9V5S('5P;VX@;&]G9VEN9R!O;C\B
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"B,L('!H<"UF
M;W)M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@9G)O;2`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#<@;&EB+T9E=&-H;6%I;"YP:'`Z
M,C@Y(&QI8B]&971C:&UA:6PN<&AP.C(Y,0IM<V=I9"`B1F5T8VAM86EL.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDS"FUS9VED(")&
M971C:&UA:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TE-4"YP:'`Z.#`T"FUS9VED(")&:5]L=&5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]J879A<V-R:7!T+FEN8SHR,C<@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YH=&UL.C(V-0IM<V=I9"`B1FEL92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYH=&UL.C0X"FUS9VED
M(")&:6QT97(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYH=&UL.C,V"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P,`IM<V=I9"`B
M1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYH=&UL.C$Q"FUS9VED
M(")&:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R.`IM<V=I
M9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYH=&UL.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C=&EV92(*;7-G<W1R
M("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYH=&UL.C$S"FUS9VED(")&
M:6YD.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$V
M"FUS9VED(")&:7)S="!-86EL8F]X(%!A9V4B"FUS9W-T<B`B(@H*(SH@;6%I
M;&)O>"YP:'`Z-#,R"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@(B(*"B,Z
M(&UE<W-A9V4N<&AP.C4U-"!M86EL8F]X+G!H<#HU,#$*;7-G:60@(D9O7W)W
M87)D(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C(Q-B!T96UP;&%T97,O
M9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HU"FUS9VED(")&;VQD97(@
M06-T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F;VQD97)S
M+G!H<#HR-#D@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN
M8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z
M,3`@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YH=&UL.C(*;7-G:60@(D9O;&1E
M<B!.879I9V%T;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C,*;7-G:60@(D9O;&1E<B!3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&%C
M;"YP:'`Z,C,*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B;&5D
M+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR-`IM<V=I9"`B1F]L9&5R
M('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDX,`IM<V=I9"`B1F]R;6%T(&]F(&UE<W-A9V4@9&%T
M97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T960@=&]D
M87DB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-34T(&UA:6QB;W@N<&AP
M.C4P,2!L:6(O0V]M<&]S92YP:'`Z,30U-0IM<V=I9"`B1F]R=V%R9"(*;7-G
M<W1R("+7E->DUZ4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,30T,0IM<V=I9"`B
M1F]R=V%R9#HB"FUS9W-T<B`BUY37I->E.B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ-#8Y"FUS9VED(")&;W)W87)D960@;65S<V%G92(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,30V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT,#(*;7-G:60@(D9R964O0G5S>2!297%U
M97-T(%)E<W!O;G-E(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4W-0IM
M<V=I9"`B1G)O7VTB"FUS9W-T<B`BUY[7D->J(@H*(SH@;65S<V%G92YP:'`Z
M,C,R('1H<F5A9"YP:'`Z,34Q(&QI8B]396%R8V@N<&AP.C8P,PHC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,S$*;7-G:60@(D9R;VTB"FUS
M9W-T<B`BUY[7D->J(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR.0IM
M<V=I9"`B1G)O;2!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ-#4R(&QI8B]#;VUP;W-E+G!H<#HQ-#4V"FUS9VED(")&=V0Z(@IM
M<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C8Q.0IM<V=I9"`B1G=D.B`B"FUS
M9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z-C(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.`IM<V=I9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S='(@
M(M>0UZ37J=>HUY77F=>5UZH@UYO7G-><UYG7E=>J(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@
M;65S<V%G97,_("A)34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C(X."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-34T(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,C@*;7-G:60@(D=O(@IM<V=S='(@(M><UYHB
M"@HC.B!T:')E860N<&AP.C$S-`IM<V=I9"`B1V\@=&\@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!L:6(O24U0+G!H<#HS-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3,V"FUS9VED(")'<F%N
M="!A8V-E<W,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-#(X(&QI8B]&
M:6QT97(N<&AP.C$P,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*
M(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3$Q(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C$Q,PHC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*
M(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@@;&EB+TU)
M344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z-#(S(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z
M-#$*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$R.0IM<V=I9"`B2$5212(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S$@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$Q.0HC.B!L:6(O34E-12]6:65W97(O<F5L
M871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C,V,`IM<V=I9"`B2%1-3"!697)S:6]N(&]F($UE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-C@S"FUS9VED(")(96%D97)S
M(@IM<V=S='(@(M>;UY77JM>HUY77JB(*"B,Z('1E;7!L871E<R]L;V=I;B]R
M96-O;7!O<V4N:'1M;#HW"FUS9VED(")(97)E(&ES('1H92!M97-S86=E('EO
M=2!W97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8V.`IM<V=I9"`B2&ED9&5N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C<*;7-G:60@(DAI9&1E;B!I;B!4:')E
M860@5FEE=R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HR-S(*;7-G:60@
M(DAI9&4@1&5L971E9"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR.30*
M;7-G:60@(DAI9&4@56YS=6)S8W)I8F5D(@IM<V=S='(@(B(*"B,Z(&-O;7!O
M<V4N<&AP.C$R,#0*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@;65S<V%G
M92YP:'`Z,C8T(&UA:6QB;W@N<&AP.C@R."!M86EL8F]X+G!H<#HY-S<*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FAT;6PZ,3`*;7-G:60@(DAI9V@@
M4')I;W)I='DB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3(P,PIM<V=I
M9"`B2&EG:&5S="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-CDW"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A
M8VAM96YT<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P-0IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@
M82!R97!L>2(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"YP:'`Z,3DY"FUS9VED
M("))34%0(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,3`W"FUS9VED("))34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S
M='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,SDQ"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX@
M4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`N
M<&AP.C(Q,0IM<V=I9"`B24U!4"!O=F5R(%-33"(*;7-G<W1R("(B"@HC.B!L
M:6(O24U!4"YP:'`Z,C$W"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I
M9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HS-C@*;7-G:60@(DE-05`@<V5R=F5R(&-L;W-E9"!T:&4@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`N<&AP.C(P-0IM<V=I
M9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z-C4W"FUS9VED("))3D)/6"(*;7-G
M<W1R("+7D]>5UY#7J"#7H->;UZ#7H2(*"B,Z(&QI8B])34%0+T-L:65N="YP
M:'`Z-#$Q"FUS9VED("))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@;75S="!H
M879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M
M;#HQ,@IM<V=I9"`B268@>6]U(&-O;G1I;G5E+"!A;&P@;65S<V%G97,@:6X@
M=&AE(&9O;&1E<BAS*2!W:6QL(&)E(&QO<W0A(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FAT;6PZ,S8*;7-G:60@(DEG;F]R
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH
M=&UL.C,W"FUS9VED("))9VYO<F4@06QL(@IM<V=S='(@(B(*"B,Z('-A=F5I
M;6%G92YP:'`Z-#8*;7-G:60@(DEM86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;6%G97,@87)E(&)L;V-K960Z("5S('1O('!R;W1E8W0@>6]U<B!P<FEV86-Y
M+B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N
M:'1M;#HQ-@IM<V=I9"`B26UP;W)T(@IM<V=S='(@(M>9UY'7D"(*"B,Z('1E
M;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T97,O<&=P
M+VEM<&]R=%]K97DN:'1M;#HT.`IM<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y"FUS9VED("));7!O
M<G0@2V5Y<&%I<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FAT;6PZ,CD*;7-G:60@(DEM<&]R="!-97-S86=E<R(*;7-G<W1R
M("(B"@HC.B!P9W`N<&AP.C,Y"FUS9VED("));7!O<G0@4$=0($ME>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDQ"FUS9VED
M("));7!O<G0@4&5R<V]N86P@0V5R=&EF:6-A=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FAT;6PZ,3$*;7-G:60@(DEM<&]R
M="!097)S;VYA;"!0<FEV871E(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FAT;6PZ,3@*;7-G:60@(DEM<&]R="!0
M97)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R93HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R
M="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C0R"FUS9VED("));7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:'1M;#HQ,0IM<V=I9"`B
M26UP;W)T(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O:6UP;W)T7VME>2YH=&UL.C$X"FUS9VED("));7!O<G0@4'5B;&EC
M(%!'4"!+97D@2&5R93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+VEM<&]R=%]K97DN:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@4R]-24U%
M($ME>2(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R
M="!3+TU)344@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VEM<&]R="YH=&UL.C8*;7-G:60@(DEM<&]R="!M8F]X($9I;&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FAT;6PZ,3$*;7-G
M:60@(DEM<&]R="!M8F]X(&9I;&4B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP
M:'`Z-#<T(&UA:6QB;W@N<&AP.C@S-B!M86EL8F]X+G!H<#HY-S(*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FAT;6PZ-R!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:'1M;#HQ,PHC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:'1M;#HR."!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:'1M
M;#HU"FUS9VED("));7!O<G1A;G0B"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H
M<#HS,S0*;7-G:60@(DEM<&]R=&%N="!M97-S86=E<R(*;7-G<W1R("(B"@HC
M.B!F;VQD97)S+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M960@)60@;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C<V-@IM<V=I9"`B26X@4')O8V5S<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N
M:6YC.C$T(&QI8B]&;VQD97(N<&AP.C@V"B,Z(&QI8B]&;VQD97(N<&AP.C(Q
M,2!L:6(O24U0+G!H<#HS,#@@;&EB+TE-05`O5')E92YP:'`Z,3$P"B,Z(&QI
M8B])34%0+U1R964N<&AP.C(Q,R!L:6(O24U!4"]4<F5E+G!H<#HS-3D*;7-G
M:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.3,*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H92!H
M96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0X.`IM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S86=E
M(&EN(&$@<F5P;'D_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$S,@IM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I
M9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O
M;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O:F%V87-C<FEP="YI;F,Z,C0S('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:'1M;#HR-S`*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL
M.C,R-@IM<V=I9"`B26YL:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A
M=&4@2&5R92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#$S"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI
M<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C<R-"!M
M86EL8F]X+G!H<#HW-C8*;7-G:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R
M("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(V,0IM<V=I9"`B26YV
M86QI9"!296UO=&4@36%I;&)O>"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,3`S-@HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A
M8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N(@IM<V=S='(@(B(*"B,Z('-M
M:6UE+G!H<#HW."!P9W`N<&AP.C$V"FUS9VED("));G9A;&ED(&ME>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DW"FUS9VED("));G9A;&ED
M(&UE<W-A9V4L(&-A;B!N;W0@<F5S=6UE(&1R869T+B(*;7-G<W1R("(B"@HC
M.B!P9W`N<&AP.C(P,@IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<')I
M=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3<W"FUS9VED("))
M;G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:'1M;#HY"FUS9VED("));G9E
M<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH
M=&UL.C,Q-"!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,S0Y"FUS
M9VED(")+0B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,3$S"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,S<*;7-G:60@(B(*(DME>2!G96YE<F%T:6]N(&UA
M>2!T86ME(&$@;&]N9R!T:6UE('1O(&-O;7!L971E+B`@0V]N=&EN=64@=VET
M:"!K97D@(@HB9V5N97)A=&EO;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHS-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,S<*
M;7-G:60@(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO
M860@:7,@;F]T(&5N86)L960@;VX@=&AI<R!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S<@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C,Y"FUS9VED("(B"B)+97D@:6UP;W)T(&ES(&YO="!A=F%I
M;&%B;&4N(%EO=2!H879E(&YO(&%D9')E<W,@8F]O:R!D969I;F5D('1O(&%D
M9"!Y;W5R("(*(F-O;G1A8W1S+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C,R
M-`IM<V=I9"`B2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:'1M;#HQ,3,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3<*;7-G:60@(DQA<W0@36%I;&)O>"!0
M86=E(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C0T-`IM<V=I9"`B3&%S
M="!086=E(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$S,C<*;7-G:60@
M(DQI;FL@071T86-H;65N=',_(@IM<V=S='(@(B(*"B,Z(&%T=&%C:&UE;G0N
M<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HR,C$U"FUS9VED("),:6YK960@871T
M86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C(R,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL
M;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P.3,*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@
M;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO
M=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F
M;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Y-`IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A9&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`IM
M<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8W,0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$P-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("),;V<@:6X@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP
M.C,U,@IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("(B"@HC
M.B!C;VUP;W-E+G!H<#HQ,C`V"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,C8V(&UA:6QB;W@N<&AP.C@S,2!M86EL8F]X+G!H<#HY
M-S@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FAT;6PZ,3$*;7-G:60@
M(DQO=R!0<FEO<FET>2(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C`W
M"FUS9VED("),;W=E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%P<&QE9&]U8FQE+G!H<#HT-`IM<V=I9"`B36%C:6YT;W-H($9I;&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S
M"FUS9VED(")-86EL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-PIM<V=I9"`B36%I;"!0<F5V:65W<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C$V"FUS9VED
M(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE8W0@=&\Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B])34%0+U1R964N<&AP.C,V-2!L:6(O24U!4"]4<F5E+G!H<#HS
M.3,*;7-G:60@(DUA:6QB;W@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q,@IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FAT;6PZ,C`*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O
M;&1E<B!A<R!3965N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:'1M;#HR,0IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@
M1F]L9&5R(&%S(%5N<V5E;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:'1M;#HU('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYH=&UL.C(U"FUS9VED(")-87)K(&%S.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4P"FUS9VED(")-87)K(&1I9F9E
M<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHT,`IM<V=I9"`B36%R:R!M97-S86=E<R!A<R!S965N/R`H24U!4"!O;FQY
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4X"FUS
M9VED(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(B(*"B,Z('-E87)C
M:"YP:'`Z,C(V"FUS9VED(")-871C:"!!;&P@475E<FEE<R(*;7-G<W1R("(B
M"@HC.B!S96%R8V@N<&AP.C(R-`IM<V=I9"`B36%T8V@@06YY(%%U97)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HR
M-S8*;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C@T"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!&
M;VQD97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@W"FUS9VED(")-
M87AI;75M($YU;6)E<B!O9B!296-I<&EE;G1S('!E<B!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.CDP"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!296-I<&EE;G1S('!E<B!4:6UE(%!E<FEO9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,C4X"FUS9VED(")-
M87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,C4S"FUS
M9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS"FUS
M9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ,SDS"FUS9VED(")-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O
M;7!O<V4N<&AP.C,S,2!C;VUP;W-E+G!H<#HS-3@@8V]M<&]S92YP:'`Z,S8W
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP
M;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3(X"FUS9VED(")-97-S86=E($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:'1M;#HQ,3(*;7-G:60@(DUE<W-A9V4@1FQA
M9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:'1M
M;#HQ,S<*;7-G:60@(DUE<W-A9V4@1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+W-E87)C:"YH=&UL.C,S"FUS9VED(")-97-S86=E
M($UA=&-H97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-SD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS
M9VED(")-97-S86=E($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H
M<#HT,#8*;7-G:60@(DUE<W-A9V4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S(*;7-G:60@(DUE<W-A9V4@4VEZ92(*
M;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-S@*;7-G:60@(DUE<W-A9V4@
M4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-@IM<V=I9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ,SDQ"B,L('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@
M9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HX-C8*;7-G:60@
M(DUE<W-A9V4@:&%S(&%T=&%C:&UE;G1S(@IM<V=S='(@(B(*"B,Z(&UA:6QB
M;W@N<&AP.C@U.`IM<V=I9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T
M<B`B(@H*(SH@;6%I;&)O>"YP:'`Z.#4T"FUS9VED(")-97-S86=E(&ES('-I
M9VYE9"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HT-S0@8V]M<&]S92YP
M:'`Z-#@Q"FUS9VED(")-97-S86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-C8P"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N
M;W0@<V%V960@=&\@)7,B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z-30R
M(&-O;7!O<V4N<&AP.C4U,`IM<V=I9"`B365S<V%G92!S96YT('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU
M,@IM<V=I9"`B365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE
M=RXB"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,C0U"FUS9VED(")-97-S
M86=E<R!T;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M,CD*;7-G:60@(DUO9&EF>2(*;7-G<W1R("(B"@HC.B!E>'!A;F0N<&AP.C0P
M"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@861D<F5S<R!F
M;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!M97-S86=E
M+G!H<#HU,#,@;65S<V%G92YP:'`Z-CDU(&UA:6QB;W@N<&AP.C0Q.2!M86EL
M8F]X+G!H<#HY.3<*;7-G:60@(DUO=F4B"FUS9W-T<B`BUY37HM>1UZ@B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,38*;7-G:60@
M(DUO=F4@9&]W;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C$X"FUS9VED(")-;W9E('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD
M97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(B(*
M"B,Z(&UE<W-A9V4N<&AP.C4P,R!M97-S86=E+G!H<#HV.34@;6%I;&)O>"YP
M:'`Z-#$Y(&UA:6QB;W@N<&AP.CDY-PIM<V=I9"`B36]V92!T;R!F;VQD97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,S$T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(X"FUS9VED(")-=6QT:7!A<G0O
M86QT97)N871I=F4B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HW-2!T:')E
M860N<&AP.C$U-`IM<V=I9"`B375L=&EP;&4@365S<V%G92!6:65W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T
M+FEN8SHX"FUS9VED(").3TY%(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHT."!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C(*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,R!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:'1M;#HU.`IM<V=I9"`B3F%M
M92(*;7-G<W1R("+7J=>=(@H*(SH@<&=P+G!H<#HQ,38*;7-G:60@(DYA;64@
M86YD+V]R(&5M86EL(&-A;FYO="!B92!E;7!T>2(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<Q"FUS9VED(").965D<R!!8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SDP"FUS9VED(").979E<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<R"FUS9VED(").979E
M<B!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ,C0*;7-G:60@(DYE=R(*;7-G<W1R("(B"@HC.B!L:6(O
M24U0+G!H<#HT,C@*;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(").97<@36%I;"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C8@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C(W"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP
M.C,Q"FUS9VED(").97<@365S<V%G92(*;7-G<W1R("+7E->5UY/7HM>4(->7
MUY/7J=>4(@H*(SH@;6%I;&)O>"YP:'`Z.3$Y(&QI8B]-24U%+TAE861E<G,N
M<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C,R-0IM<V=I9"`B3F5W(&UE
M<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FAT;6PZ-S,*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;65S<V%G
M92YP:'`Z-3(Q(&UE<W-A9V4N<&AP.C<P,@IM<V=I9"`B3F5X="!-97-S86=E
M(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C0T,@IM<V=I9"`B3F5X="!0
M86=E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX.`HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FAT;6PZ,CDV"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!S
M;6EM92YP:'`Z,C(R"FUS9VED(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ,S$S"FUS9VED(").;R!%;F-R>7!T
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ.0IM
M<V=I9"`B3F\@2V5Y<R!I;B!+97ER:6YG(@IM<V=S='(@(B(*"B,Z(&UA:6QB
M;W@N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*
M;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$T,PIM<V=I9"`B3F\@4$=0('!U8FQI
M8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC871E
M(%!R97-E;G0B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z.#<V"FUS9VED
M(").;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHQ-0IM<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C$T-PIM<V=I9"`B3F\@4R]-24U%
M('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]T;F5F+G!H<#HY,@IM<V=I9"`B3F\@871T86-H;65N=',@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"FUS
M9VED(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L
M:6,@:V5Y+B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C<Q(&%C;"YP:'`Z.3<*
M;7-G:60@(DYO(&9O;&1E<B!S96QE8W1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C$S,@IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@
M8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(B(*"B,Z(&9O
M;&1E<G,N<&AP.C$V-2!L:6(O1F]L9&5R+G!H<#HU,3$@;&EB+T9O;&1E<BYP
M:'`Z-38Q"FUS9VED(").;R!F;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,S@*;7-G:60@(DYO
M(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C$S-0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H
M('5N<V5E;B!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3,X-PIM<V=I9"`B3F\@;65S<V%G92!B;V1Y('1E>'0B"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-CD*;7-G:60@(DYO(&UE<W-A
M9V4@<F5T=7)N960N(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C(U.`IM
M<V=I9"`B3F\@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T
M<B`B(@H*(SH@<&=P+G!H<#HQ.34*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P
M<FEV871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ
M-S$*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D
M+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,3DW"FUS9VED(").;R!P97)S
M;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T-@IM<V=I9"`B(@HB
M3F\@<&5R<V]N86P@<')I=F%T92!K97D@97AI<W1S('-O('1H92!M97-S86=E
M(&ES('5N86)L92!T;R!B92!D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z('-P
M96QL:6YG+G!H<#HQ.3`*;7-G:60@(DYO('-P96QL8VAE8VMI;F<@<')O9W)A
M;2!C;VYF:6=U<F5D+B(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HY.3,*
M;7-G:60@(DYO('-U9V=E<W1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z-38Q"FUS9VED(").;R!S=7!P;W)T960@24U!4"!A=71H
M96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&%C;"YP:'`Z-C<@86-L+G!H<#HY,PIM<V=I9"`B3F\@=7-E<B!S<&5C
M:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW,#0*;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR-"!T96UP;&%T97,O
M<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,U('1E;7!L871E<R]P<F5F<R]S<&%M<V5L
M96-T+FEN8SHR-`HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC
M.C(T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C$*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FAT;6PZ.`IM<V=I9"`B3F]N92(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HQ,C`U"FUS9VED(").;W)M86PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,3@@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,S0*;7-G:60@(DYO="!$96QE=&5D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YH=&UL.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.C(P
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.C,W"FUS9VED(").
M;W0@1')A9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FAT;6PZ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:'1M;#HQ-`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:'1M;#HR.0IM
M<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:'1M;#HR,@IM<V=I9"`B3F]T(%!E<G-O;F%L(@IM
M<V=S='(@(B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O
M4TU)344N<&AP.C$S-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B
M3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<P-PIM<V=I9"`B3F]T(&%T(&%L;"(*;7-G<W1R
M("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN
M<&AP.C<Q"FUS9VED(").;W1E('1H870@=&AI<R!C86X@=&%K92!S;VUE('1I
M;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q-@IM
M<V=I9"`B3F]T:&EN9R(*;7-G<W1R("(B"@HC.B!A='1A8VAM96YT+G!H<#HX
M.0IM<V=I9"`B3F]T:69I8V%T:6]N.B!,:6YK960@871T86-H;65N="!D;W=N
M;&]A9&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S@*;7-G:60@(DYU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D
M(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C`*;7-G:60@(DYU;6)E<B!O
M9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M
M;VYT:&QY+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:'1M;#HW,PIM<V=I9"`B3TLB"FUS9W-T<B`BUY#7F=>IUY77J"(*
M"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.2!T96UP;&%T
M97,O<V5A<F-H+W-E87)C:"YH=&UL.C0Y"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YH=&UL.C,P"FUS9VED(")/4B(*;7-G<W1R("+7D->5(@H*(SH@
M<V5A<F-H+G!H<#HS,C0*;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN
M9R!P=7)G960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HS,PIM<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E860@
M;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHX,0IM<V=I9"`B3VYL>2!O;F4@9F]L9&5R
M('-H;W5L9"!B92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B])35`N<&AP.C@U."!L:6(O24U0+G!H<#HX-C,*;7-G:60@
M(D]P96X@1F]?;&1E<B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]4<F5E+G!H
M<#HT,C(*;7-G:60@(D]P96YE9"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<P,`IM<V=I9"`B3W!T:6]N86P@4&%R
M=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL+G!H<#HT,R!T96UP
M;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H97(@36%I;"!!8V-O=6YT
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C`*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,0IM
M<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:'1M;#HQ,#$*;7-G:60@(D]U=&)O=6YD(%-E<G9E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$V
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-`HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HR,3(@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDS"FUS
M9VED(")01U`B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3,Q-@IM<V=I
M9"`B4$=0($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3$T-`IM<V=I9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C$Q,C,*;7-G:60@(E!'4"!%<G)O<CH@3F5E
M9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B4$=0
M($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,`IM<V=I9"`B4$=0
M(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C4U"FUS9VED(")01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P
M;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R
M("(B"@HC.B!P9W`N<&AP.C$U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")01U`@
M4'5B;&EC($ME>2!F;W(@7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"XB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HR-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S
M<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-`IM<V=I9"`B4$=0(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@
M(B(*"B,Z(&QI8B])35`N<&AP.C$S,3<*;7-G:60@(E!'4"!3:6=N($UE<W-A
M9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3,Q.`IM<V=I9"`B4$=0
M(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z
M,C`X"FUS9VED(")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D
M+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$X,PIM<V=I9"`B4$=0('!U8FQI
M8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4$=0('-U<'!O<G0@
M:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED("(B"B)01U`@<W5P<&]R="!R
M97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R
M;W=S97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I
M;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T
M:&4@4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*
M;7-G<W1R("(B"@HC.B!L:6(O24U!4"YP:'`Z,3<U"FUS9VED(")03U`S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`R"FUS9VED
M(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(B(*"B,Z
M(&QI8B])34%0+G!H<#HQ.#<*;7-G:60@(E!/4#,@;W9E<B!34TPB"FUS9W-T
M<B`B(@H*(SH@;&EB+TE-05`N<&AP.C$Y,PIM<V=I9"`B4$]0,R!O=F5R(%-3
M3"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z(&QI
M8B])34%0+G!H<#HQ.#$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R("(B
M"@HC.B!M86EL8F]X+G!H<#HS-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&%G
M92`E9"!O9B`E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$T"FUS9VED(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S
M86=E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,34*
M;7-G:60@(E!A9V4@=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!M97-S86=E+G!H<#HV-C8*;7-G:60@(E!A<G0H<RDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R,PIM<V=I9"`B
M4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!9V%I;BDB"FUS9W-T<B`B(@H*
M(SH@<VUI;64N<&AP.C(S,2!P9W`N<&AP.C,Q-@IM<V=I9"`B4&%S<W!H<F%S
M92!S=6-C97-S9G5L;'D@=6YL;V%D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A
M<W-P:')A<V4N:6YC.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R("(B
M"@HC.B!P9W`N<&AP.C$Q.`IM<V=I9"`B4&%S<W!H<F%S97,@8V%N;F]T(&)E
M(&5M<'1Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3(P"FUS9VED(")087-S
M<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:'1M;#HY
M,`IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`BUZ'7F=>AUY[7D"(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`IM<V=I9"`B4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("(B
M"@HC.B!A8VPN<&AP.C<U(&%C;"YP:'`Z,3`Q"FUS9VED(")097)M:7-S:6]N
M<R!F;W(@=&AI<R!U<V5R(&-A;FYO="!B92!C:&%N9V5D+B(*;7-G<W1R("(B
M"@HC.B!M97-S86=E+G!H<#HT-C`@;6%I;&)O>"YP:'`Z.#`V(&UA:6QB;W@N
M<&AP.CDW-0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:'1M;#HR,2!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:'1M;#HX"FUS9VED(")097)S;VYA
M;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z('!G<"YP
M:'`Z,3(V"FUS9VED(")097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$S,PIM<V=I
M9"`B4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM
M<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR,#,*;7-G:60@(E!E<G-O;F%L(%,O
M34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`B(@H*
M(SH@<VUI;64N<&AP.C$R.`IM<V=I9"`B4&5R<V]N86P@4R]-24U%(&ME>7,@
M9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,C,*;7-G:60@(E!L86-E('EO=7(@<VEG;F%T=7)E
M(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C,U.`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@
M;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#$Q"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@5&AI
M<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E9"`B
M"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A;F0@
M36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q=6ER92!A('!L
M=6=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C
M<FEP="YI;F,Z-S`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M,3DU"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O
M;&1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ,#0@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ
M,#8*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O
M;&1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ,SD*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@
M;VYL>2!N965D('1O("(*(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E
M<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE
M87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV
M871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D("(*(G1O(&5N=&5R('1H:7,@
M<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!L;V=I;BYP:'`Z,3@P"FUS9VED("(B"B)0;&5A<V4@;&]G(&EN(&%G86EN
M('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E
M($Y/5"!U<VEN9R`B"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M
M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O("(*
M(FQO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H
M:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA8VMI;F<@>6]U
M<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE
M;F-E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO:F%V87-C<FEP
M="YI;F,Z,S8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]J879A<V-R:7!T+FEN
M8SHS,@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS
M9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B]#;VUP;W-E+G!H<#HR
M,SDX"FUS9VED(")0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI
M9"!A9&1R97-S97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z-C,*;7-G:60@(E!L96%S92!S96QE8W0@82!F;VQD
M97(@8F5F;W)E('EO=2!P97)F;W)M('1H:7,@86-T:6]N+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC.C0Q"FUS9VED
M(")0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@=&\@<V5A<F-H
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C$R"FUS9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F
M;W(@=&AI<R!O<&5R871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FAT;6PZ,SD*;7-G:60@(E!L96%S92!S96QE8W0@
M;W(@961I="!I;B!T:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*;7-G:60@(E!O=V5R960@8GD@
M2&]R9&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q
M-0IM<V=I9"`B4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H
M)RTM("<I/R(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,C,W('!G<"YP:'`Z
M,C8S(&9I;'1E<G!R969S+G!H<#HT,0IM<V=I9"`B4')E9F5R96YC97,@<W5C
M8V5S<V9U;&QY('5P9&%T960N(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP
M.C$S-#<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C,Q-`IM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU,3,@;65S
M<V%G92YP:'`Z-CDY"FUS9VED(")0<F5V:6]U<R!-97-S86=E(@IM<V=S='(@
M(B(*"B,Z(&UA:6QB;W@N<&AP.C0S-`IM<V=I9"`B4')E=FEO=7,@4&%G92(*
M;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU.30*;7-G:60@(E!R:6YT(@IM
M<V=S='(@(M>4UY/7I->A(@H*(SH@;65S<V%G92YP:'`Z-C4U"FUS9VED(")0
M<FEO<FET>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z-S8*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S$*;7-G:60@(E!R
M;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L
M="!T;R!.3R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3<P"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES
M('-E;G0[(&1E9F%U;'0@=&\@6453(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM
M<V=S='(@(B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0S,`IM<V=I9"`B4'5B
M;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"XB
M"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S@X(&UA:6QB;W@N<&AP.C0X
M,PIM<V=I9"`B4'5R7V=E($1E;&5T960B"FUS9W-T<B`B(@H*(SH@;6%I;&)O
M>"YP:'`Z,S@X(&UA:6QB;W@N<&AP.C0X,PIM<V=I9"`B4'5R9V4@1&5L971E
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FAT
M;6PZ,C8*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDW"FUS9VED(")0=7)G92!4<F%S:"!H
M;W<@;V9T96XZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,#8*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O
M;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(E!U<F=E(&]L9"!M
M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R("(B"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S86=E<R!F<F]M(%1R87-H
M(&9O;&1E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M<'5R9V5?=')A<V@N<&AP.C8S"FUS9VED(")0=7)G:6YG(#$@;65S<V%G92!F
M<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z
M.3$W"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"
M("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H
M<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F
M34(@+R!.3R!,24U)5"(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HY,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S.B!.3R!,24U)5"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:'1M;#HS,0IM<V=I9"`B4F5B=6EL
M9"!&;VQD97(@5')E92(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HV
M,S$*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R
M8V@N<&AP.C8S.0IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+U-E87)C:"YP:'`Z-C,U"FUS9VED(")296-E:79E9"!5;G1I;"(*
M;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-38*;7-G:60@(E)E9&ER96-?
M="(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-38*;7-G:60@(E)E9&ER
M96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T
M+FAT;6PZ-S<*;7-G:60@(E)E9&ER96-T($UE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@8V]M<&]S92YP:'`Z-#,S"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A
M9V4B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z-#DV"FUS9VED(")2961I
M<F5C=&EN9R!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C(W
M-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-SDV"FUS9VED(")2969R97-H($9O;&1E<B!6:65W<SHB"FUS
M9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S0Y"FUS9VED(")296QO860B"FUS
M9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C8V"FUS9VED(")296QO860@5FEE
M=R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(X
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E;65M8F5R
M('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.3`*;7-G:60@(E)E;65M8F5R('1H92!L
M87-T('9I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C(W"FUS9VED(")296UO=&4@36%I;&)O>#HB"FUS9W-T<B`B
M(@H*(SH@<V5A<F-H+G!H<#HS,C`*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M
M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,#4*;7-G:60@(E)E;6]V92!S;W5R8V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH=&UL.C$P"FUS9VED
M(")296YA;64@1F]L9&5R*',I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#(*;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R
M(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG(%PB
M)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4T,PIM<V=I9"`B
M4F5P;%]Y('1O($QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:'1M;#HU,`IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G
M<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-#`*;7-G:60@(E)E<&QY(@IM<V=S
M='(@(M>4UZG7D2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3(@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,`IM<V=I9"`B4F5P;'D@4V5N
M="XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-30Y"FUS9VED(")297!L
M>2!T;R!!;&PB"FUS9W-T<B`BUY37J=>1(-><UYO7G"(*"B,Z(&-O;7!O<V4N
M<&AP.C0P-@IM<V=I9"`B4F5P;'D@=&\@06QL.B(*;7-G<W1R("(B"@HC.B!M
M97-S86=E+G!H<#HU-#,*;7-G:60@(E)E<&QY('1O($QI<W0B"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z-#`X"FUS9VED(")297!L>2!T;R!,:7-T.B(*
M;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-#D*;7-G:60@(E)E<&QY('1O
M(%]!;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4S,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,Y"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU-#D*;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U
M<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,S<*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O
M<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3,V"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N
M<&AP.C(S-@IM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$U-#D*;7-G:60@(E)E<&QY+51O.B`B"FUS9W-T<B`B(@H*
M(SH@8V]M<&]S92YP:'`Z-#`T"FUS9VED(")297!L>3HB"FUS9W-T<B`B(@H*
M(SH@;65S<V%G92YP:'`Z-C`W(&UA:6QB;W@N<&AP.C4Q-`IM<V=I9"`B4F5P
M;W)T(&%S($EN;F]C96YT(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4Y
M.2!M86EL8F]X+G!H<#HU,#8*;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S
M='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R-S`*;7-G:60@(E)E<75E<W0@82!?
M4F5A9"!296-E:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU.#4*;7-G:60@(E)E<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T
M<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,3,Q"FUS9VED(")297%U97-T960@;65S
M<V%G92!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV.3(*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-C(@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:'1M;#HR.0HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YH=&UL.C$X,0IM<V=I9"`B4F5S970B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-@IM<V=I9"`B4F5S<&]N9&5N
M="!3=&%T=7,@57!D871E9"XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z
M-3@W"FUS9VED(")297-U;64B"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$X
M,0IM<V=I9"`B4F5S=6UE('EO=7(@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#0*;7-G:60@(E)E='5R
M;B!T;R!<(DUE<W-A9V4@0V]M<&]S:71I;VY<(B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C,Q('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,@IM<V=I9"`B4F5T=7)N('1O
M($9E=&-H($UA:6PB"FUS9W-T<B`B(@H*(SH@9FEL=&5R<')E9G,N<&AP.C4S
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`Q"B,Z('1E;7!L871E<R]S
M;6EM92]N;W1A8W1I=F4N:6YC.C$U('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M-#D*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-C,*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$W
M-0IM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<S,`IM<V=I9"`B(@HB4F5T=7)N('1O('1H
M92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@;W(@
M8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV.#,*;7-G:60@(E)O;&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT
M,C0*;7-G:60@(E,O34E-12(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ
M,S(Q"FUS9VED(")3+TU)344@16YC<GEP="!-97-S86=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,3<V"FUS9VED(")3+TU)344@17)R;W(Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3$U-0IM<V=I9"`B
M4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R
M:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34R"FUS9VED(")3+TU)344@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S
M;6EM92YP:'`Z-#8*;7-G:60@(E,O34E-12!087-S<&AR87-E($EN<'5T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-30*;7-G
M:60@(E,O34E-12!097)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@
M82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z('-M:6UE
M+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+
M97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(B(*"B,Z('-M:6UE+G!H<#HQ-3@*;7-G:60@(E,O34E-12!0=6)L:6,@
M2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+
M97ER:6YG(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR,#<*;7-G:60@(E,O
M34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3,R,@IM<V=I9"`B4R]-
M24U%(%-I9VX@365S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HQ
M,S(S"FUS9VED(")3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-`IM<V=I
M9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Q
M"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N
M86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y
M<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HQ-S,*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D
M('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I9VYE9"!M97-S86=E(&-A;FYO
M="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I
M<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA
M8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T
M(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@
M8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@
M=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E
M("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYH=&UL
M.C$P-0IM<V=I9"`B4TU44"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ
M,3<Y"FUS9VED(")37W5B:F5C="(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H
M<#HQ,C0Y"FUS9VED(")385]V92!A(&-O<'D@:6X@(@IM<V=S='(@(B(*"B,Z
M(&UE<W-A9V4N<&AP.C4Y,@IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E
M<R]S96%R8V@O<V5A<F-H+FAT;6PZ,C@*(SH@=&5M<&QA=&5S+W-E87)C:"]S
M96%R8V@N:'1M;#HQ.#`*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@8V]M
M<&]S92YP:'`Z,3,R,PIM<V=I9"`B4V%V92!!='1A8VAM96YT<R!W:71H(&UE
M<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C(S('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:'1M;#HR,#8*;7-G:60@(E-A=F4@1')A9G0B"FUS9W-T
M<B`B(@H*(SH@<V%V96EM86=E+G!H<#HU,0IM<V=I9"`B4V%V92!);6%G92(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C,Q"FUS9VED
M(")3879E($EM86=E(&EN($=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@9FEL=&5R
M<')E9G,N<&AP.C$Q-"!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC
M.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,R!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN
M8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,`IM<V=I9"`B4V%V92!3=&%T
M:6]N97)Y(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$P.30*;7-G:60@
M(E-A=F4@7T1R869T(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4Y,@IM
M<V=I9"`B4V%V92!A<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3(R"FUS9VED(")3879E(&1R869T<R!A<R!U;G-E96X_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S(*;7-G:60@(E-A
M=F4@9')A9G1S(&%U=&]M871I8V%L;'D@=VAI;&4@8V]M<&]S:6YG/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X,PIM<V=I9"`B
M4V%V92!R96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@
M861D<F5S<R!B;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+W-E87)C:"YH=&UL.C$W,@IM<V=I9"`B4V%V92!S96%R8V@@87,@82!V:7)T
M=6%L(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S,0IM<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ-3`*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@
M9F%I;&5D+B!#;W5L9"!N;W0@8W)E871E(&$@9')A9G1S(&9O;&1E<BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C@Y"FUS9VED(")3879I;F<@
M=&AE(&1R869T(&9A:6QE9"X@3F\@9')A9G0@9F]L9&5R('-P96-I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B(@H*(SH@;6%I;&)O
M>"YP:'`Z,S4V(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,Y"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYH=&UL.C(U"FUS9VED(")396%R
M8V@B"FUS9W-T<B`BUY?7I->I(@H*(SH@;6%I;&)O>"YP:'`Z,S4V('-E87)C
M:"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:"`E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"FUS9VED(")3
M96%R8V@@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C$V-0IM
M<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,3$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FAT;6PZ,C8*;7-G:60@(E-E96XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<P"FUS9VED(")396QE8W0@06YO
M=&AE<B!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z,S$Q"FUS
M9VED(")396QE8W0@82!D871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FAT;6PZ-34*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@
M(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S
M96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]S96%R8V@N:'1M;#HQ-#$*;7-G:60@(E-E;&5C="!A;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,S(S"FUS9VED(")396QE8W0@86QL(&9I96QD<R!T;R!S96%R8V@@=VAE
M;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L
M96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]S96%R8V@N:'1M;#HQ-#(*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:'1M;#HQ,S,*;7-G
M:60@(E-E;&5C="!S=&%T:6]N97)Y.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V%V96EM86=E+W-A=F5I;6%G92YH=&UL.C@*;7-G:60@(E-E;&5C="!T
M:&4@9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHR,0IM
M<V=I9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYH=&UL.C8*;7-G:60@(E-E
M;&5C=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S`Y"FUS9VED(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@
M(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PIM<V=I9"`B4V5N9"!,871E
M<W0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YH=&UL.C(Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:'1M;#HR,#0*;7-G:60@(E-E;F0@365S<V%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]J879A<V-R:7!T+FEN8SHQ,3D*;7-G:60@(E-E
M;F0@;65S<V%G92!W:71H;W5T(&$@4W5B:F5C=#\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q-0IM<V=I9"`B4V5N9"!R96%D(')E
M8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-05`O5')E92YP:'`Z,S@U"FUS9VED(")396YT(&UA:6P@
M9F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I
M;'-E;&5C="YI;F,Z,S@*;7-G:60@(E-E;G0@;6%I;"!F;VQD97(Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYH=&UL.C,V('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYH=&UL.C4P"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYH=&UL.C8R"FUS9VED(")397)V97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(S"FUS9VED(")397)V97(@86YD($9O;&1E
M<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q"FUS9VED(")3970@<')E9F5R
M96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE
M=&4@;65S<V%G97,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-#$*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE
M;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@1F]L9&5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z.#8*;7-G:60@(E-H87)E
M(&UA:6P@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@
M;W1H97(@=7-E<G,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-CD*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O
M=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A
M;B!B92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@
M(E-H;W5L9"!T:&4@8F]D>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C
M86YN960@9F]R(%!'4"!D871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3$T"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN
M9&]W(&)E(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0*;7-G:60@(E-H;W5L9"!Y
M;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S
M<V%G97,@8GD@9&5F875L=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]S96%R8V@N:'1M;#HQ-#0*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-C<X"FUS9VED(")3:&]W($%L
M;"!(96%D97)S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C(W,`IM<V=I
M9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HY.`IM<V=I9"`B4VAO=R!);6%G97,_(@IM<V=S='(@(B(*
M"B,Z(&UE<W-A9V4N<&AP.C8W,@IM<V=I9"`B4VAO=R!,:6UI=&5D($AE861E
M<G,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-C@Q"FUS9VED(")3:&]W
M($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+W-E87)C:"YH=&UL.C$T-`IM<V=I9"`B4VAO=R!/;FQY
M(%-U8G-C<FEB960@1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HR.30*;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#@*;7-G:60@(E-H;W<@86X@:6-O
M;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S
M86=E<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M,3,*;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-3$*;7-G:60@
M(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4Y"FUS9VED(")3
M:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#@X"FUS9VED(")3:&]W('1H92!&971C:"!-
M86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&9I;'1E
M<G!R969S+G!H<#HY.0IM<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC;VX@;VX@
M=&AE(&UE;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HS-@IM<V=I9"`B4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@
M9F]L9&5R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C8V"FUS9VED(")3:&]W;B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HU
M.3`*;7-G:60@(E-I7WIE(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.CDX
M-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:'1M;#HQ-0IM<V=I9"`B4VEG
M;F5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:'1M;#HS,30*;7-G:60@(E-I>F4Z(@IM<V=S='(@(M>2UY77D]><.B(*"B,Z
M(&UA:6QB;W@N<&AP.C4U.0IM<V=I9"`B4V]R="!B>2!!<G)I=F%L(@IM<V=S
M='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V-`IM<V=I9"`B4V]R="!B>2!$871E
M(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4W-`IM<V=I9"`B4V]R="!B
M>2!&<F]M($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y
M"FUS9VED(")3;W)T(&)Y($UE<W-A9V4@4VEZ92(*;7-G<W1R("(B"@HC.B!M
M86EL8F]X+G!H<#HU.#0*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R
M("(B"@HC.B!M86EL8F]X+G!H<#HU-SD*;7-G:60@(E-O<G0@8GD@5&AR96%D
M(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V.0IM<V=I9"`B4V]R="!B
M>2!4;R!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+U1R964N<&AP
M.C,W.0IM<V=I9"`B4W!A;2!F;VQD97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S"FUS9VED(")3<&%M(&9O;&1E
M<CHB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3(S.`IM<V=I9"`B4W!E
M8VEA;"!#:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z-3,*
M;7-G:60@(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;FYO="!B92!E9&ET
M960N(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R,S0*;7-G:60@(E-P
M96QL($-H96-K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FAT;6PZ,3D*;7-G:60@(E-P96QL($-H96-K97(B"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z.3<S"FUS9VED(")3<&5L;"!C:&5C:R!C;VUP
M;&5T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYH=&UL.C(Q"FUS9VED(")3<&5L;"!C:&5C:R!C;VUP;&5T92`M($YO('-P
M96QL:6YG(&5R<F]R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#<R"FUS9VED(")3<&5L;&EN9R!E<G)O<G,@<&5R('-C<F5E;B!W
M:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3`W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,#D*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8T,B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C0T"FUS9VED(")3=&%R="(*;7-G<W1R("(B"@HC
M.B!C;VUP;W-E+G!H<#HQ,C$Y('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHY"FUS9VED(")3=&%T:6]N97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR-@IM<V=I9"`B4W1A=&EO;F5R
M>2!N86UE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,C@*;7-G:60@(E-T871I;VYE<GD@='EP93HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,S"FUS9VED
M(")3=&%T:6]N97)Y.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C@S"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O0V]N=&5N=',N<&AP.C(T,@IM<V=I9"`B4W1R:7`@071T86-H;65N
M="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0S"FUS
M9VED(")3=')I<"!L:6YE8G)E86MS/R(*;7-G<W1R("(B"@HC.B!M86EL8F]X
M+G!H<#HU.#4*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(M>@UY77J=>0(@H*
M(SH@;65S<V%G92YP:'`Z,C,W('1H<F5A9"YP:'`Z,34R(&QI8B]396%R8V@N
M<&AP.C8Q.0HC.B!T96UP;&%T97,O;&]G:6XO<F5C;VUP;W-E+FAT;6PZ-#$*
M;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BUZ#7E=>IUY`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")3=6)J96-T($9I96QD(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,"!T
M96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"B,Z('1E;7!L871E<R]S
M96%R8V@O<V5A<F-H+FAT;6PZ,C@@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N
M:'1M;#HQ.#`*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:'1M
M;#HQ.`IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:'1M;#HQ,PIM<V=I9"`B4W5B<V-R:6)E('1O($9O
M;&1E<BAS*2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C,X-2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3<*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@(E-U8V-E<W,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:'1M;#HT,`IM
M<V=I9"`B4W5G9V5S=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8U.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Q
M"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M-S4@8V]M<&]S92YP:'`Z,3(W-@IM<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N
M($UE=&AO9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FAT;6PZ,3@Y"FUS9VED(")3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT
M;6PZ,3@Y"FUS9VED(")3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C@P"FUS9VED(")495]X
M="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C<P
M"FUS9VED(")496YT871I=F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3@V"FUS9VED(")496YT871I=F5L>2!!8V-E<'0@
M<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S4T"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R("(B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O9B!397)V:6-E(&9I;&4@
M;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S`*;7-G:60@(E1E>'0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV-0IM<V=I9"`B
M5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN
M:V5D.B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4S,`IM
M<V=I9"`B(@HB5&AE($E-05`@<V5R=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S
M=7!P;W)T('1H92!A=71H96YT:6-A=&EO;B!M971H;V0@(@HB<V5L96-T960N
M(%!L96%S92!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z
M-#$*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R
M:R!C86X@8F4@9&]W;FQO861E9"`E<RXB"FUS9W-T<B`B(@H*(SH@9F5T8VAM
M86EL<')E9G,N<&AP.C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O
M=6YT(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F
M971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC
M.B!A='1A8VAM96YT+G!H<#HT,PIM<V=I9"`B5&AE(&%T=&%C:&UE;G0@=V%S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C<Q"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V]M
M<&]S95]W:6XN:G,Z,S<*;7-G:60@(B(*(E1H92!C;VUP;W-E('=I;F1O=R!C
M86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O
M=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4
M:&4@8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E
M;G1M86EL7VUO;G1H;'DN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!C=7)R96YT(&9O;&1E<BAS*2!<(B5S7"(@=VEL;"!B92!R96YA;65D('1O
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H
M(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92!<
M(B5S7"(@9F]L9&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,30P"FUS9VED(")4:&4@979E;G0@=V%S(&%D9&5D('1O('EO
M=7(@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z(&5X<&%N9"YP:'`Z,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I96QD(%PB)7-<(B!C86XG="!B92!E
M>'!A;F1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S,W"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C$V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@9F]L9&5R(%PB)7-<(B!C;VYT86EN
M<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S
M92`B"B)P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HS-38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&-R96%T
M960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+B(*;7-G<W1R
M("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E
M(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO
M="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U
M;&QY(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0V
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@
M<W5C8V5S<V9U;&QY(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.30*;7-G:60@(E1H92!F;VQL
M;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?<V%V96EM86=E
M7W=I;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A
M;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R
M;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S4*;7-G:60@(E1H92!M
M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S
M86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T
M:6]N+G!H<#HU,0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T
M:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H
M92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E
M.B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-S(U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(T-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@
M*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@;&EM:70N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]J879A<V-R:7!T+FEN8SHQ,#,*
M;7-G:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L
M;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O:F%V87-C<FEP="YI;F,Z,3$Y"FUS9VED(")4:&4@;65S<V%G92!D;V5S
M(&YO="!H879E(&$@4W5B:F5C="!E;G1E<F5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O4W!A;2YP:'`Z,C$V"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O4W!A;2YP:'`Z,C`R"FUS9VED
M(")4:&4@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T
M;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O4W!A;2YP:'`Z,3@R"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B(@H*(SH@;&EB+U-P86TN
M<&AP.C$Y-`IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@
M87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!L:6(O4W!A;2YP:'`Z,3<T"FUS9VED(")4:&4@;65S<V%G92!H
M87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HT,#$*;7-G:60@(E1H92!M97-S86=E(&AA
M<R!B965N('9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C,X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S
M<V%G92!H87,@8F5E;B!V97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]P9W!?=VEN+FIS.C@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]S;6EM95]W:6XN:G,Z.`IM
M<V=I9"`B(@HB5&AE('!A<W-P:')A<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE
M9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L
M;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O
M97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"FUS9VED(")4
M:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A
M='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HT,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A
M9V4@:7,@<F5Q=65S=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N("(*(F9R;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE
M<W-A9V4N(%!L96%S92!C;&EC:R`E<R!T;R!S96YD('1H92`B"B)N;W1I9FEC
M871I;VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z-C<*;7-G:60@(E1H92!S97)V97(@=V%S(&YO="!A8FQE
M('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]J879A<V-R:7!T+FEN8SHX,PIM
M<V=I9"`B5&AE('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+VIA=F%S8W)I<'0N:6YC
M.C@Q"FUS9VED(")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P
M;&%C960N(@IM<V=S='(@(B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4Y"FUS9VED
M(")4:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z('-T871I;VYE<GDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E9"XB"FUS9W-T
M<B`B(@H*(SH@<W1A=&EO;F5R>2YP:'`Z-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z('-T871I;VYE<GDN<&AP.C@W"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A=&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<P
M"FUS9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML
M:7-T+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HY-0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z.#`*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S
M86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U
M<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"FUS9VED(")4
M:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$U-0IM<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM<V=I9"`B5&AE
M<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V5M<'1Y7VUA:6QB;W@N:'1M;#HR"FUS9VED(")4:&5R92!A<F4@;F\@;65S
M<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*;7-G<W1R("(B"@HC.B!T:')E860N
M<&AP.C$P.0IM<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@<V5R=F5R('-A:60Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S
M<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE
M("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE
M(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A
M:60B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L
M971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!L86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR:6-H960N
M<&AP.C,W"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C`W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@
M5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"@HC
M.B!F;VQD97)S+G!H<#HQ,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M;6]V:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I
M<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-38W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V
M96YT.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN
M+G!H<#HU.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,38U"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE
M9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$Y
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#0@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$U.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3<T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,34*;7-G:60@(E1H:7,@
M86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ.#`@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0R,`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE
M;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,`IM<V=I9"`B
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$U"FUS9VED
M("(B"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T
M(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3D*;7-G
M:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@
M:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,@IM<V=I9"`B(@HB5&AI
M<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R
M;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@
M=6YK;F]W;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,S(S"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(T,R!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HS-3@*;7-G:60@(B(*(E1H:7,@;65S
M<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0
M(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S`*;7-G:60@(E1H
M:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E
M8W0@4R]-24U%(&9O<FUA="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,C`P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@:&%S(&)E
M96X@9&EG:71A;&QY('-I9VYE9"!A;F0@96YC<GEP=&5D('=I=&@@4$=0+"!B
M=70@=&AE("(*(G-I9VYA='5R92!C86YN;W0@8F4@=F5R:69I960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-@IM<V=I9"`B
M5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@86YD(&5N
M8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,C`R"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@:&%S(&)E
M96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+"!B=70@=&AE('-I9VYA='5R
M92!C86YN;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(P."!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HT,C0*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@
M<VEG;F5D('9I82!01U`N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,30S"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@
M9&EG:71A;&QY('-I9VYE9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C(S.`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N
M8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR.3@*;7-G:60@(B(*(E1H:7,@;65S<V%G92!H87,@
M8F5E;B!E;F-R>7!T960@=VET:"!01U`L(&AO=V5V97(L(%!'4"!S=7!P;W)T
M(&ES(&1I<V%B;&5D("(*(G-O('1H92!M97-S86=E(&-A;FYO="!B92!D96-R
M>7!T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C,P,PIM<V=I9"`B(@HB5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E
M9"!W:71H(%!'4"P@:&]W979E<BP@;F\@<&5R<V]N86P@<')I=F%T92!K97D@
M(@HB97AI<W1S('-O('1H92!M97-S86=E(&-A;FYO="!B92!D96-R>7!T960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-`IM
M<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'
M4"XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`U"FUS9VED(")4:&ES
M(&UE<W-A9V4@=&\B"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HT-0IM<V=I9"`B
M5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]J879A<V-R:7!T
M+FEN8SHQ,#D*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R
M;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H
M<#HQ-30*;7-G:60@(E1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z('1H
M<F5A9"YP:'`Z-S4@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,PIM<V=I9"`B
M5&AR96%D(%9I97<B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C,S(&-O
M;7!O<V4N<&AP.C@W.2!M86EL8F]X+G!H<#HU-S`@;6%I;&)O>"YP:'`Z-S0V
M"B,Z(&QI8B]396%R8V@N<&AP.C8P-R!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:'1M;#HS.0HC.B!T96UP;&%T97,O;&]G:6XO<F5C;VUP;W-E+FAT
M;6PZ,30*;7-G:60@(E1O(@IM<V=S='(@(M>0UYPB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3,P"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM<V=I
M9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C;&EC
M:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HQ,S0*
M;7-G:60@(B(*(E1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B
M92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@-2XP+C8@;W(@(@HB:&EG:&5R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT
M;6PZ,S0Y"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*;7-G<W1R
M("(B"@HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-C@*;7-G:60@(E1R87-H(&9O
M;&1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE
M8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM<V=S='(@(B(*"B,Z
M(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C0@;&EB+U%U;W1A+VUE<F-U<GDS,BYP
M:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<R"B,Z(&QI8B]1=6]T82]L
M;V=F:6QE+G!H<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@;&EB+U%U
M;W1A+VUD865M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T<FEE=F4@
M<75O=&$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FAT;6PZ,3`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT
M;6PZ,38*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FAT;6PZ,S$*;7-G
M:60@(E5N86YS=V5R960B"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS,S`*
M;7-G:60@(E5N86YS=V5R960@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@;65S
M<V%G92YP:'`Z-3,U(&UA:6QB;W@N<&AP.C0W,0IM<V=I9"`B56YD96QE=&4B
M"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS-#`*;7-G:60@(E5N9&5L971E
M9"!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HW,CD@;6%I
M;&)O>"YP:'`Z-S0R(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q,PIM<V=I9"`B
M56YD:7-C;&]S960@4F5C:7!I96YT<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B(@H*(SH@
M<V5A<F-H+G!H<#HS,S4*;7-G:60@(E5N:6UP;W)T86YT(&UE<W-A9V5S(@IM
M<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C<P.0IM<V=I9"`B56YK;F]W;B!$
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,SDU"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!4"!R97-P;VYS92!F<F]M
M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C8*;7-G:60@(E5N:VYO
M=VX@365E=&EN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HW-3@*;7-G
M:60@(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W
M"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!F971C
M:&UA:6QP<F5F<RYP:'`Z-C4*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B(@H*
M(SH@;65S<V%G92YP:'`Z-#8Y(&UA:6QB;W@N<&AP.C@Q,2!M86EL8F]X+G!H
M<#HY-S`*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FAT
M;6PZ-B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:'1M;#HQ,@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:'1M;#HR-R!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:'1M;#HS"FUS9VED(")5;G-E96XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYH=&UL.C$T"FUS9VED(")5;G-U
M8G-C<FEB92!F<F]M($9O;&1E<BAS*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,C@T"FUS9VED(")5<&1A=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q,@IM<V=I
M9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU.`IM<V=I9"`B57!L;V%D
M(@IM<V=S='(@(M>4UZ+7G->0UY0B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:'1M;#HS.`IM<V=I9"`B57!L;V%D.B(*;7-G<W1R("+7E->BUYS7
MD->4.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z
M-#$*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(E5S92!)34%0(&9O;&1E
M<B!S=6)S8W)I<'1I;VYS/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S0W"FUS9VED(")5<V4@5FER='5A;"!4<F%S:"!&;VQD97(_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-#,*;7-G
M:60@(E5S97(B"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HX-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@
M=&AE('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:'1M;#HX,PIM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`BUZ?7E=>3(->6UYG7E->5UYD@UY[7
MJ=>JUY[7J2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ
M-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV
M.`HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR-PHC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6:65W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.CDR(&QI8B]-24U%+U9I97=E
M<B]T;F5F+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z
M-3$Y"FUS9VED(")6:65W($UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<W"FUS9VED(")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<R"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI8R!+
M97DB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-34Y"FUS9VED(")6:65W
M(%1H<F5A9"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38V"FUS9VED
M(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C0R,PIM<V=I9"`B5FEE=R!A='1A8VAM96YT(&EN(&$@
M<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]R96QA=&5D+G!H<#HW.0IM<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P
M87)A=&4@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-#$*;7-G:60@(E9I97<@979E;G0B"FUS9W-T<B`B(@H*(SH@
M;6%I;&)O>"YP:'`Z-C8Y(&QI8B])34%0+U1R964N<&AP.C,U,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,C,*
M;7-G:60@(E9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<Q
M"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C$Q.`IM<V=I9"`B5FEE=R!T:&ES($A434P@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@<V5A<F-H
M+G!H<#HQ-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FER='5A;"!&;VQD97(@
M7"(E<UPB(&-R96%T960@<W5C8V5S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&QI
M8B])34%0+U1R964N<&AP.C$S,B!L:6(O24U!4"]4<F5E+G!H<#HQ-#4@;&EB
M+TE-05`O5')E92YP:'`Z,30W"B,Z(&QI8B])34%0+U1R964N<&AP.C$U,2!L
M:6(O24U!4"]4<F5E+G!H<#HQ-3(@;&EB+TE-05`O5')E92YP:'`Z-C$S"B,Z
M(&QI8B])34%0+U1R964N<&AP.C8S-R!L:6(O24U!4"]4<F5E+G!H<#HV-S4*
M(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R8V@N:'1M;#HQ-C4*;7-G:60@(E9I
M<G1U86P@1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP.C$U-`IM
M<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#,T"FUS9VED(")6:7)T=6%L($E.
M0D]8(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+U1R964N<&AP.C0P.0IM<V=I
M9"`B5FER='5A;"!)3D)/6"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@;&EB+U-E
M87)C:"YP:'`Z,S@P"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(B(*
M"B,Z(&QI8B])34%0+U1R964N<&AP.C0P-0IM<V=I9"`B5FER='5A;"!4<F%S
M:"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]S96%R
M8V@N:'1M;#HQ-S8*;7-G:60@(E9I<G1U86P@9F]L9&5R(&QA8F5L.B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W.0IM<V=I
M9"`B5V%R;FEN9R(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3@T(&QO9VEN
M+G!H<#HR-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$Y"FUS9VED
M("(B"B)7:&%T('-H;W5L9"!W92!D;R!W:71H('-P86T@;65S<V%G97,@869T
M97(@=&AE>2!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2`B"B)O<B!I;FYO
M8V5N=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S
M.0IM<V=I9"`B(@HB5VAE;B!D96QE=&EN9R!M97-S86=E<RP@;6]V92!T:&5M
M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E860@;V8@;6%R:VEN9R`B"B)T
M:&5M(&%S(&1E;&5T960_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,3@*;7-G:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X
M+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T(&]N/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S"FUS9VED(")7:&5N
M('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@
M9&%T83\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M-PIM<V=I9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D
M9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U
M;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T
M(%PB0%PB*3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<P.`IM<V=I9"`B5VAE<F4@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!L:6YK
M<R!T;R!A;'1E<FYA=&EV92!F;W)M871S(&]F(&$@;65S<V%G93\B"FUS9W-T
M<B`B(@H*(SH@;65S<V%G92YP:'`Z-3<Q(&UA:6QB;W@N<&AP.C0Y-@IM<V=I
M9"`B5VAI=&5L:7-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YH=&UL.C(Y-0IM
M<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K
M+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-3@*;7-G:60@(EEO=2!A<F4@86)O=70@
M=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N
M9FER;2YH=&UL.C$P"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@
M9&5L971E(&%L;"!M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN
M9R!F;VQD97(B"B(H<RDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T
M96UP=&EN9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC
M.C<P('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y-0IM<V=I
M9"`B66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,3`T"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ,#8*;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L
M9&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C@R
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@87)E(&YO="!A;&QO=V5D
M('1O('-E;F0@;65S<V%G97,@=&\@;6]R92!T:&%N("5D(')E8VEP:65N=',@
M=VET:&EN("5D("(*(FAO=7)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,3`T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O('-E;F0@;65S<V%G97,@=&\@;6]R92!T:&%N("5D(')E8VEP
M:65N=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,3,W"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD
M97(Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@
M=&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@
M=&5X=#H@)6,@9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@
M)7,@9F]R('1H92!S:6=N871U<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N;F]T('5N
M<W5B<V-R:6)E(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB
M66]U(&1I9"!N;W0@86=R964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R
M965M96YT+"!S;R!Y;W4@=V5R92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$W,`IM<V=I
M9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S
M<R!T;R!T:&ES(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP
M:'`Z,3,P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI
M<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z
M("5S+B(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HQ,#`Y"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!H879E("5S(&YE=R!M97-S86=E<RXB"FUS9W-T
M<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,3`P.0IM<V=I9"`B66]U(&AA=F4@,2!N
M97<@;65S<V%G92XB"FUS9W-T<B`BUYG7J=>!(-><UYH@UY/7E=>0UZ@@UY?7
MD]>I+B(*"B,Z(&-O;7!O<V4N<&AP.C(Q-@IM<V=I9"`B66]U(&AA=F4@86QR
M96%D>2!S=6)M:71T960@=&AI<R!P86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M24U0+G!H<#HY-3<*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F
M;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HY
M-C(*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@
M9F]L9&5R<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$P,S$*
M;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q,`IM
M<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO
M=7(@4$=0('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R!M97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C4T"FUS9VED
M("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3
M+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z
M-SD@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`T"FUS9VED
M(")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB"FUS
M9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O:F%V87-C<FEP="YI;F,Z.#$*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW
M-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,3$*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8X"FUS9VED(")9;W4@
M;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+VIA=F%S8W)I<'0N:6YC.C$X
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@96YA
M8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(')E9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$T,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE
M<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-3<P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E
M(&YO="!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(N($AE<F4@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M-3(Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL
M>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!L:6(O1F]L
M9&5R+G!H<#HU-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C
M8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.3@*;7-G:60@(EEO=7(@3F%M
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*;7-G
M:60@(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S$*;7-G:60@(EEO=7(@4'5B;&EC($ME>2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38V"FUS9VED(")9;W5R
M(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#D*;7-G:60@
M(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T
M+FEN8SHQ-@IM<V=I9"`B66]U<B!A8V-O=6YT<SHB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W-`IM<V=I9"`B(@HB66]U<B!A;&EA
M<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S
M<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.C$P,0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G92!T
M>7!E+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34Q
M"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S
M86=E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N8W)Y<'1S
M96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE
M=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*(SH@871T
M86-H;65N="YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!L
M:6YK960@871T86-H;65N="!H87,@8F5E;B!D;W=N;&]A9&5D(&)Y(&%T(&QE
M87-T(&]N92!U<V5R+EQN(@HB7&XB"B)!='1A8VAM96YT(&YA;64Z("5S7&XB
M"B)!='1A8VAM96YT(&1A=&4Z("5S7&XB"B)<;B(*(D-L:6-K(&]N('1H92!F
M;VQL;W=I;F<@;&EN:R!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE(&%T=&%C
M:&UE;G0Z7&XB"B(E<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HX.0IM<V=I9"`B66]U<B!M97-S86=E('=A<R!S=6-C97-S
M9G5L;'D@9&5L:79E<F5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C`W"FUS9VED(")9;W5R('-I9VYA='5R93HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O861D<F5S<V5S0FQO8VMS+FIS
M.C<*;7-G:60@(EM(:61E($%D9')E<W-E<UTB"FUS9W-T<B`B(@H*(SH@;65S
M<V%G92YP:'`Z,C4W(&-O;7!O<V4N<&AP.C8P.2!M86EL8F]X+G!H<#HV.3$@
M;&EB+T-O;7!O<V4N<&AP.C$Y-C@*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C
M:W,N:G,Z.`IM<V=I9"`B6U-H;W<@061D<F5S<V5S("TB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G
M:60@(EM3:&]W(&%D9')E<W-E<R`M("5S(')E8VEP:65N='-=(@IM<V=S='(@
M(B(*"B,Z(&-O;7!O<V4N<&AP.C$Q,S`*;7-G:60@(E]"8V,B"FUS9W-T<B`B
MUY37HM>JUZ?7F=>=(->BUYG7E=>5UZC7F=>=(@H*(SH@;65S<V%G92YP:'`Z
M-38U(&UA:6QB;W@N<&AP.C0Y,`IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R
M("+7J->IUYG7GM>4(->IUY?7E=>HUY0B"@HC.B!C;VUP;W-E+G!H<#HQ,3(W
M"FUS9VED(")?0V,B"FUS9W-T<B`BUY37HM>JUZ?7F=>=(@H*(SH@;65S<V%G
M92YP:'`Z-3,W(&UA:6QB;W@N<&AP.C0V,R!M86EL8F]X+G!H<#HT-C8*;7-G
M:60@(E]$96QE=&4B"FUS9W-T<B`BUY[7E]>G(@H*(SH@;&EB+TE-4"YP:'`Z
M-SDS"FUS9VED(")?1F]L9&5R<R(*;7-G<W1R("+7JM>9UZ?7F=>5UZHB"@HC
M.B!C;VUP;W-E+G!H<#HQ,3`W"FUS9VED(")?261E;G1I='DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-4"YP:'`Z-S4X"FUS9VED(")?26YB;W@B"FUS9W-T<B`B
MUY/7E=>0UZ@@UZ#7F]>@UZ$B"@HC.B!L:6(O24U0+G!H<#HX,S0*;7-G:60@
M(E],;V<@;W5T(@IM<V=S='(@(M>4UZK7H->JUZ?7E=>J(@H*(SH@;65S<V%G
M92YP:'`Z-3<X"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TE-4"YP:'`Z-SDP"FUS9VED(")?3F5W($UE<W-A9V4B"FUS9W-T
M<B`BUY37E=>3UZ+7E"#7E]>3UZG7E"(*"B,Z(&UE<W-A9V4N<&AP.C4Y-`IM
M<V=I9"`B7U!R:6YT(@IM<V=S='(@(M>4UY/7I->A(@H*(SH@8V]M<&]S92YP
M:'`Z,3$Y.`IM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z(&UA:6QB
M;W@N<&AP.C,R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")?4F5F<F5S:"`E<R(*
M;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HU-#`*;7-G:60@(E]297!L>2(*
M;7-G<W1R("+7E->IUY$B"@HC.B!L:6(O24U0+G!H<#HW.34*;7-G:60@(E]3
M96%R8V@B"FUS9W-T<B`BUY?7I->I(@H*(SH@8V]M<&]S92YP:'`Z,3`Y,B!C
M;VUP;W-E+G!H<#HQ,#DV"FUS9VED(")?4V5N9"!-97-S86=E(@IM<V=S='(@
M(B(*"B,Z(&UA:6QB;W@N<&AP.C4X,`IM<V=I9"`B7U1H<F5A9"(*;7-G<W1R
M("(B"@HC.B!C;VUP;W-E+G!H<#HQ,3(S(&-O;7!O<V4N<&AP.C$Q,C4*;7-G
M:60@(E]4;R(*;7-G<W1R("+7D-><(@H*(SH@;6%I;&)O>"YP:'`Z-#<Q"FUS
M9VED(")?56YD96QE=&4B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-34Y
M"FUS9VED(")?5FEE=R!4:')E860B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP
M:'`Z-3<Q(&UA:6QB;W@N<&AP.C0Y-@IM<V=I9"`B7U=H:71E;&ES="(*;7-G
M<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z.#4S"FUS9VED(")A9&1R97-S
M964@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,34X
M,`IM<V=I9"`B871T86-H;65N="(*;7-G<W1R("(B"@HC.B!V:65W+G!H<#HQ
M,30*;7-G:60@(F%T=&%C:&UE;G1S+GII<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FAT;6PZ,C<V"FUS9VED(")B>71E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z.#<W"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HX-#D*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HX-#$*;7-G:60@(F-O;6UA;F0@;&EN
M92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M.#DW"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HX-S,*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F
M:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C@T
M-0IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.CDP,0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYH=&UL.C$V
M"FUS9VED(")F<F]M(@IM<V=S='(@(M>>UY#7JB(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HX-3<*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FAT;6PZ,S$*;7-G:60@
M(FEN(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HX.#$*;7-G:60@
M(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z.#8U"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:'1M;#HQ,PIM
M<V=I9"`B:6YT;R!F;VQD97(B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(Y
M('!G<"YP:'`Z-S<*;7-G:60@(FME>2(*;7-G<W1R("(B"@HC.B!F;VQD97)S
M+G!H<#HQ,#D*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R("(B"@HC.B!L
M:6(O365S<V%G92YP:'`Z-3(T(&QI8B]#;VUP;W-E+G!H<#HV-#`*;7-G:60@
M(FYA;64B"FUS9W-T<B`BUZG7G2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FAT;6PZ,S(*;7-G:60@(FYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:'1M;#HU,`IM<V=I9"`B;W(B"FUS
M9W-T<B`BUY#7E2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HX.3,*;7-G:60@(G!E
M<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V%D9')E<W-E<T)L;V-K<RYJ<SHX"FUS9VED(")R96-I<&EE;G1S
M72(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z.#@Y"FUS9VED(")R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C@V,0IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C$Y
M"FUS9VED(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYH=&UL.C$Y"FUS9VED(")S<&5L;&EN9R!E
M<G)O<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C@V.0IM<V=I
M9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HX.#4*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&:6QT97(N<&AP.C4Q"FUS9VED(")Y;W5R(&)L86-K;&ES="(*;7-G
M<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HV,0IM<V=I9"`B>6]U<B!W:&ET
M96QI<W0B"FUS9W-T<B`B(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O<&\O9&%?1$LN<&\`````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P-#$V-#<V`#$P-#$W,S8R-S8T`#`Q-S$U,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````C($E-4"!$
M86YI<V@@=')A;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@
M4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($UA<G1I;B!,
M:7-T+5!E=&5R<V5N(#QM87)T:6Y`;&ES="UP971E<G-E;BYD:SXL(#(P,#$N
M"B,@0G)I86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`8G)I86YT<G5E;'-E;BYD
M:SXL(#(P,#4N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($E-4"`T+C$M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-2TQ,"TP.2`Q,SHR-BLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($)R:6%N
M(%1R=65L<V5N(#QH;W)D92MI,3AN0&)R:6%N=')U96QS96XN9&L^7&XB"B),
M86YG=6%G92U496%M.B!$86YI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN
M(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$X"FUS
M9VED("(@("`@("!#8SH@(@IM<V=S='(@(B`@("`@($-C.B`B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#$U"FUS9VED("(@("`@("!4;SH@(@IM<V=S='(@(B`@
M("`@(%1I;#H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P,PIM<V=I9"`B("`@
M($1A=&4Z("(*;7-G<W1R("(@("`@1&%T;SH@(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C0P-@IM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R("(@("`@1G)A.B`B
M"@HC.B!M86EL8F]X+G!H<#HT,C(@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS
M9W-T<B`B("A!8V-E<W-K97D@)7,I(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q
M,@IM<V=I9"`B(%-U8FIE8W0Z("(*;7-G<W1R("(@16UN93H@(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<P"FUS9VED("(@:6X@(@IM
M<V=S='(@(B!I("(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T<B`B(R(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@
M+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B`O("4N,F9-0B`@
M*"4N,F8E)2DB"@HC.B!T:')E860N<&AP.C$U,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!-97-S86=E<R(*;7-G<W1R("(E9"!B97-K961E<B(*"B,Z(&UA
M:6QB;W@N<&AP.C$W-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E
M<R!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B)60@8F5S:V5D97(@97(@
M8FQE=F5T('-L971T970N(@H*(SH@;&EB+U-P86TN<&AP.C$W.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@HB)60@8F5S:V5D97(@97(@8FQE=F5T('-E;F1T(&EN9"!S
M;VT@96HM<W!A;2!T:6P@9&EN('-Y<W1E;6%D;6EN:7-T<F%T;W(N(@H*(SH@
M;&EB+U-P86TN<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S
M86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@
M(B5D(&)E<VME9&5R(&5R(&)L979E="!I;F1B97)E='1E="!S;VT@<W!A;2XB
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(B5D(&)E<VME9&5R
M(&5R(&)L979E="!I;F1B97)E='1E="!S;VT@<W!A;2!T:6P@9&EN('-Y<W1E
M;6%D;6EN:7-T<F%T;W(N(@H*(SH@;&EB+U-P86TN<&AP.C$U,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@<W!A;2XB"FUS9W-T<B`B)60@8F5S:V5D97(@97(@8FQE=F5T(&EN9&)E
M<F5T=&5T('-O;2!S<&%M+B(*"B,Z(&UA:6QB;W@N<&AP.C,W,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R
M("(E9"!T:6P@)60@868@)60@8F5S:V5D97(B"@HC.B!M86EL8F]X+G!H<#HV
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T
M<B`B)7,@9FEN9&5S(&%L;&5R961E+B!-87!P96X@)7,@8FQE=B!I:VME(&]M
M9/AB="XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB
M;W@N(@IM<V=S='(@(B5S('-Y;F5S(&EK:V4@870@=N9R92!E;B!G>6QD:6<@
M8G)E=F)A:VME+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S
M96YT;6%I;%]M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO
M;G1H+B(*;7-G<W1R(")-87!P96X@)7,@=FEL(&)L:79E(&]M9/AB="!I('-T
M87)T96X@868@:'9E<B!MY6YE9"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!A8V-E<'1E
M9"XB"FUS9W-T<B`B)7,@:&%R(&%C8V5P=&5R970N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8R-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H
M87,@8V%N8V5L;&5D("5S+B(*;7-G<W1R("(E<R!H87(@869L>7-T("5S+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(E<R!H87(@;N9G
M=&5T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@
M<F5Q=65S="XB"FUS9W-T<B`B)7,@:&%R('-V87)E="!PY2!E;B!L961I9R]O
M<'1A9V5T+6%N;6]D;FEN9RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C$V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O
M('1H92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E<R!H87(@<W9A<F5T
M('#E(&EN=FET871I;VX@=&EL("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HT.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@
M>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@:&%R('-E
M;F1T(&QE9&EG+V]P=&%G970M:6YF;W)M871I;VX@=&EL(&1I9RXB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@
M:&%R(&%C8V5P=&5R970@=&5N=&%T:79T+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S
M=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(&%N
M;6]D97(@;VT@9&EN92!L961I9R]O<'1A9V5T+6EN9F]R;6%T:6]N97(N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G
M<W1R("(E<R!A;FUO9&5R(&]M(&1I;B!T:6QS=&5D97;F<F5L<V4@9&5N("5S
M+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HT,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N(@IM<V=S
M='(@(B5S(&5R('-U8V-E<V9U;&1T(&)L979E="!T:6QF^&IE="!T:6P@7"(E
M<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N9"`E<RXB"FUS9W-T
M<B`B)7,@^&YS:V5R(&%T(&IU<W1E<F4@)7,N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H
M97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B5S(/AN<VME
M<B!A="!G^')E(&1I9R!O<&WF<FMS;VT@<.4@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W
M:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T
M("5S+B(*;7-G<W1R("(E<R#X;G-K97(@870@;6]D=&%G92!S96YE<W1E(&EN
M9F]R;6%T:6]N(&]M("5S+B(*"B,Z(&UE<W-A9V4N<&AP.C(X-2!M97-S86=E
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B5S.B`E<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC
M.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N
M8G-P.R5D*2(*;7-G<W1R("(E<SH@)7,@*"5D)FYB<W`[868F;F)S<#LE9"DB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S"FUS9VED
M("(H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@;6]V92!T;R!N97AT('-C<F5E
M;BXI(@IM<V=S='(@(BA';V1K96YD(.9N9')I;F=E<FYE(&]G(&?E('1I;"!N
MYG-T92!S:^9R;2XI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E='5R
M;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("(H06YN=6QL97(@
M86QL92#F;F1R:6YG97(@;V<@9^4@=&EL8F%G92!T:6P@<VMR:79N:6YG(&%F
M(&)E<VME9&5R+BDB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G<W1R("(H2%1-3"DB"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I;B!4
M97AT*2(*;7-G<W1R("(H4F5N('1E:W-T*2(*"B,Z('-P96QL:6YG+G!H<#HR
M.#`*;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N(&%F
M=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("`B"B)#
M:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L
M:65D+BDB"FUS9W-T<B`B(@HB*$?E('1I;&)A9V4@=&EL('-K<FEV;FEN9R!A
M9B!B97-K960@969T97(@870@:&%V92!G96UT(.9N9')I;F=E<B!L879E="`B
M"B)I;F1T:6P@;G4N(,9N9')I;F=E<B!PY2!D96X@86MT=65L;&4@<VED92!V
M:6P@:6MK92!B;&EV92!G96UT+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"FUS
M9VED("(B"B(H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N
M9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92`B"B)C=7)R96YT
M('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*%-E
M;F0@8F5S:V5D(&5F=&5R(&%T(&AA=F4@9V5M="#F;F1R:6YG97(@;&%V970@
M:6YD=&EL(&YU+B#&;F1R:6YG97(@<.4@9&5N("(*(F%K='5E;&QE('-I9&4@
M=FEL(&EK:V4@8FQI=F4@9V5M="XI(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S
M+V-O;G1A8W1S+FEN8SHR,C<*;7-G:60@(BH@061D('1H97-E(&)Y(&-L:6-K
M:6YG($]+("HB"FUS9W-T<B`B*B!4:6QF^&H@9&ES<V4@=F5D(&%T(&-L:6-K
M92!/2R`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S
M='(@(BH@5N9L9R!V96YL:6=S="!A9')E<W-E*'(I("HB"@HC.B!M86EL8F]X
M+G!H<#HQ-S0*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("(Q(&)E<VME9"!E<B!B;&5V970@<VQE='1E="XB"@HC.B!L:6(O
M4W!A;2YP:'`Z,3@P"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@HB,2!B97-K960@97(@8FQE=F5T(&EN9&)E<F5T=&5T('-O
M;2!E:BUS<&%M('1I;"!D:6X@<WES=&5M861M:6YI<W1R871O<BXB"@HC.B!L
M:6(O4W!A;2YP:'`Z,38P"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P
M;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(C$@8F5S:V5D(&5R(&)L979E
M="!I;F1B97)E='1E="!S;VT@96HM<W!A;2XB"@HC.B!L:6(O4W!A;2YP:'`Z
M,3<R"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A
M;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(Q(&)E
M<VME9"!E<B!B;&5V970@:6YD8F5R971T970@<V]M('-P86T@=&EL(&1I;B!S
M>7-T96UA9&UI;FES=')A=&]R+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*;7-G
M:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G
M<W1R("(Q(&)E<VME9"!E<B!B;&5V970@:6YD8F5R971T970@<V]M('-P86TN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q.0IM<V=I9"`B,3`P(&-H
M87)A8W1E<G,B"FUS9W-T<B`B,3`P('1E9VXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#(R"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B"FUS9W-T<B`B
M,3`P,"!T96=N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,`IM<V=I
M9"`B,C4P(&-H87)A8W1E<G,B"FUS9W-T<B`B,C4P('1E9VXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#(Q"FUS9VED("(U,#`@8VAA<F%C=&5R<R(*
M;7-G<W1R("(U,#`@=&5G;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA
M;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B
M170@<W1O<B!B:6QL961E(&)E;N9V;G0@)7,@97(@:.9F=&5T('9E9"!D96YN
M92!B97-K960N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R
M97-U;'1E9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB
M<F5C:7!I96YT+B(*;7-G<W1R("(B"B)%;B!B97-K960L('-O;2!D=2!H87(@
M<V5N9'0L(&AA<B!R97-U;'1E<F5T(&D@7")R971U<FX@;F]T:69I8V%T:6]N
M7"(@9G)A("(*(FUO9'1A9V5R96XN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F
M:65L9',N:6YC.C4*;7-G:60@(D%.1"(*;7-G<W1R(")/1R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU.3`*;7-G:60@(D%C8V5P="!R97%U97-T
M(@IM<V=S='(@(D%C8V5P=.ER(&%N;6]D;FEN9R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@(D%C8V5P="!R97%U97-T(&%N9"!A
M9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B06-C97!TZ7(@86YM;V1N
M:6YG(&]G('1I;&;X:B!T:6P@:V%L96YD97(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S4S"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R(")!8V-E
M<'1E<F5T(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-PIM<V=I
M9"`B06-C97!T960Z("(*;7-G<W1R(")!8V-E<'1E<F5T.B`B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-PIM<V=I9"`B06-C;W5N="=S
M(&YA;64Z(@IM<V=S='(@(DYA=FX@<.4@:V]N=&\Z(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4R,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S,P"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(DAA;F1L:6YG97(B"@HC.B!L
M:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)344O2&5A9&5R<RYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"`E<R!T;R!M>2!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B5&EL9OAJ("5S('1I;"!M:70@861R97-S96MA<G1O
M=&5K(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`S
M"FUS9VED(")!9&0@<V]U<F-E(@IM<V=S='(@(E1I;&;X:B!K:6QD92(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S<@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4X.`IM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L96YD87(B
M"FUS9W-T<B`B1OAJ('1I;"!K86QE;F1E<B(*"B,Z(&-O;7!O<V4N<&AP.C$R
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB(&%S(&%N(&%T
M=&%C:&UE;G0N(@IM<V=S='(@(E1I;&;X:F5T(%PB)7-<(B!S;VT@=F5D:.9F
M=&5L<V4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`IM<V=I9"`B
M(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I<W!L87D@=VAE;B!V:65W:6YG
M.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&AE861E<B`B"B)O;B!A(&YE
M=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(EED97)L:6=E<F4@9F5L=&5R(&1E
M<B!V:7-E<R!U;F1E<B!LYG-N:6YG.B`\96T^*'9A;&=F<FDL(&5T(&9E;'0@
M<'(N(&QI;FEE*3PO(@HB96T^(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA
M;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")99&5R
M;&EG97)E(&EN9F]R;6%T:6]N(&MA;B!S97,@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*;7-G:60@(D%D9&ET:6]N86P@
M:6YF;W)M871I;VX@9&5T86EL<R(*;7-G<W1R(")99&5R;&EG97)E(&)E<VME
M9"UD971A:6QE<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDS
M"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G<W1R(")9
M9&5R;&EG97)E(&)E<VME9"UD971A;&IE<B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N
M86P@;65S<V%G92!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@
M(EED97)L:6=E<F4@8F5S:V5D+61E=&%L:F5R(&MA;B!S97,@)7,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N
M86P@;65S<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@(EED97)L:6=E<F4@
M9&5T86QJ97(@;VT@8F5S:V5D+69E:FPB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L
M(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G
M<W1R(")99&5R;&EG97)E(&1E=&%L:F5R(&]M(&)E<VME9"UF96IL(&-A;B!S
M97,@)7,N(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3(*
M;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E:V%R=&]T96LB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"FUS9VED(")!9&1R97-S
M($)O;VMS(@IM<V=S='(@(D%D<F5S<V5K87)T;W1E:V5R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I9"`B(@HB061D<F5S<V5S('1O($)#
M0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D
M<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM<V=S='(@(B(*(D)#0R!A
M;&QE(&)E<VME9&5R('1I;"!D:7-S92!A9')E<W-E<CH@/&5M/BAV86QG9G)I
M+"#I;B!A9')E<W-E('!R+B!L:6YI92D\+R(*(F5M/B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.#$*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!E>'!L
M:6-I=&QY('1I92!T;R!T:&ES(&ED96YT:71Y.B`\96T^*&]P=&EO;F%L+"!E
M;G1E<B!E86-H("(*(F%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/B(*;7-G
M<W1R("(B"B)!9')E<W-E<BP@<V]M(&5K<W!L:6-I="!K;GET=&5S('1I;"!D
M96YN92!I9&5N=&ET970Z(#QE;3XH=F%L9V9R:2P@Z6X@(@HB861R97-S92!P
M<BX@;&EN:64I/"]E;3XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C,*;7-G:60@(D%L;"(*
M;7-G<W1R(")!;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ,PIM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('1H92!F;VQL;W=I
M;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I;G1O(&]N92!-0D]8
M("(*(F9I;&4Z(@IM<V=S='(@(B(*(D%L;&4@8F5S:V5D97(@:2!D92!F^&QG
M96YD92!M87!P92AR*2!V:6P@8FQI=F4@9V5M="!I(&5N(&5N:V5L="!-0D]8
M(&9I;#HB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN
M('EO=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B
M92!P97)M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R("(B"B)!;&QE(&)E
M<VME9&5R(&D@9&EN(%PB)7-<(B!M87!P92P@<V]M(&5R(.9L9')E(&5N9"`E
M<R!D86=E('9I;"!B;&EV92!S;&5T=&5T+B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M
M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S
M='(@(B(*(D%L;&4@9V%M;&4@<F5F97)E<F5D92!V961HYF9T96QS97(L(&1E
M<B!E<B#F;&1R92!E;F0@)7,@;>5N961E<B!V:6P@8FQI=F4@(@HB<VQE='1E
M="XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?
M;6]N=&AL>2YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!S
M96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL
M(&)E(&1E;&5T960N(@IM<V=S='(@(B(*(D%L;&4@9V%M;&4@<V5N9'1E(&)E
M<VME9&5R+"!D97(@97(@YFQD<F4@96YD("5S(&WE;F5D97(@=FEL(&)L:79E
M('-L971T970N(@H*(SH@86-L+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!;&P@<FEG:'1S(&]N(&9O;&1E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(')E
M;6]V960@9F]R('5S97(@7"(E<UPB+B(*;7-G<W1R(")!;&QE(')E='1I9VAE
M9&5R('1I;"!M87!P96X@7"(E<UPB(&5R(&)L978@9FIE<FYE="!F;W(@8G)U
M9V5R(%PB)7-<(BXB"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@
M1F]L9&5R($-R96%T:6]N/R(*;7-G<W1R(")4:6QL860@;W!R971T96QS92!A
M9B!M87!P97(_(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0X
M"FUS9VED(")!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A
M;GD@;6%I;&)O>#\B"FUS9W-T<B`B5&EL;&%D(&%T(&9I;'1E<BUR96=L97(@
M<.5F^')E<R!V:6QKY7)L:6=E(&)R979B86MK97(_(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E
M('!A<G1S(&9O<B!T:&ES('-E8W1I;VXZ(@IM<V=S='(@(D%L=&5R;F%T:79E
M(&1E;&4@=&EL(&1E='1E(&%F<VYI=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3<R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#0*;7-G:60@(D%L
M=V%Y<R(*;7-G<W1R(")!;'1I9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-3<*;7-G:60@(D%L=V%Y<R!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@
M(D=E;2!A;'1I9"!V961HYF9T96QS97(N(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C4P-0IM<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T
M:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@
M(@HB<V%I9#H@(@IM<V=S='(@(B(*(D5N(&9E:FP@;W!S=&]D('5N9&5R(&9O
M<G/X9V5T('#E(&%T('-K<N9L;&4@=F5D:.9F=&5L<V5N(&%F+B!)34%0+7-E
M<G9E<F5N("(*(FUE;&1T93H@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X.`IM
M<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG
M('1H92!N97<@;F]T92XB"FUS9W-T<B`B1&5R('-K971E(&5N('5K96YD="!F
M96IL('5N9&5R('1I;&;X:F5L<V5N(&%F(&1E="!N>64@;F]T:71S+B(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HS.#<*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@
M;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@
M(D1E<B!S:V5T92!E;B!U:V5N9'0@9F5J;"!U;F1E<B!T:6QF^&IE;'-E;B!A
M9B!D970@;GEE(&]P9V%V92XB"@HC.B!M97-S86=E+G!H<#HU,#`@;6%I;&)O
M>"YP:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R(")"97-V
M87)E="(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@
M(D%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(D)E<W9A<F5D92!B97-K961E
M<B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PIM<V=I9"`B
M07!P;'D@1FEL=&5R<R(*;7-G<W1R(")0Y6;X<B!F:6QT<F4B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07!P;'D@1FEL=&5R<R!T;R`E<R(*;7-G<W1R(")0Y6;X<B!<(B5S7"(@
M9FEL=')E(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS
M9VED(")!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G
M<W1R(")0Y6;X<B!F:6QT<F4L(&[E<B!D=2!L;V=G97(@:6YD+B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT,@IM<V=I9"`B07!P;'D@9FEL
M=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS9W-T
M<B`B4.5F^'(@9FEL=&5R<F5G;&5R+"!NY7(@9&EN(&EN9&)A:VME(&)L:79E
M<B!V:7-T+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\B"FUS9W-T<B`B17(@
M9'4@<VEK:V5R('#E+"!A="!D=2!V:6P@<VQE='1E(&1E;FYE(&]F9F5N=&QI
M9V4@;OAG;&4_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(B(*(D%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.
M3U0@<F5C;VUM96YD960A*2(*;7-G<W1R("(B"B)%<B!D=2!S:6MK97(@<.4L
M(&%T(&1U('9I;"!S;&5T=&4@9&ET(&[X9VQE<&%R/R`H1&5T=&4@:V%N($E+
M2T4@86YB969A;&5S(2DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(*;7-G<W1R(")%
M<B!D=2!324M+15(L(&%T(&1U('9I;"!F;W)T<^9T=&4_(@H*(SH@;65S<V%G
M92YP:'`Z-#`W('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C8X
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@
M9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R(")%<B!D=2!S:6MK97(L
M(&%T(&1U('9I;"!S;&5T=&4@9&ES<V4@8F5S:V5D97(_(@H*(SH@;&EB+TU)
M344O0V]N=&5N=',N<&AP.C(Q-0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_(@IM
M<V=S='(@(D5R(&1U('-I:VME<BP@870@9'4@=FEL(%!%4DU!3D5.5"!S;&5T
M=&4@9&5N;F4@=F5D:.9F=&5L<V5R/R(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@96UP='D@=&AI<R!F;VQD97(_(@IM<V=S='(@(D5R(&1U('-I:VME<BP@
M870@9'4@=FEL('3X;6UE(&1E;FYE(&UA<'!E/R(*"B,Z(&QI8B])35`N<&AP
M.CDW,PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO
M=7(@<W!A;2!F;VQD97(_(@IM<V=S='(@(D5R(&1U('-I:VME<BP@870@9'4@
M=FEL('3X;6UE(&1I;B!S<&%M+6UA<'!E/R(*"B,Z(&QI8B])35`N<&AP.CDV
M-@IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('EO=7(@
M=')A<V@@9F]L9&5R/R(*;7-G<W1R(")%<B!D=2!S:6MK97(L(&%T(&1U('9I
M;"!T^&UM92!D:6X@<VMR86QD97-P86YD/R(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S
M='(@(D5R(&1U('-I:VME<B!PY2P@870@9'4@=FEL('-L971T92!D:7-S92!B
M97-K961E<B!P97)M86YE;G0_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V
M87-C<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z-SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@
M=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R(")%<B!D=2!S:6MK
M97(L(&%T(&1U('9I;"!I;F1R87!P;W)T97)E(&1E;FYE(&)E<VME9"!S;VT@
M:&%R;6SX<S\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN
M8SHW-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW-`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A
M9V4@87,@<W!A;3\B"FUS9W-T<B`B17(@9'4@<VEK:V5R+"!A="!D=2!V:6P@
M:6YD8F5R971T970@9&5N;F4@8F5S:V5D('-O;2!S<&%M/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,38*;7-G:60@(D%R<FEV86P@5&EM92(*;7-G
M<W1R(")-;V1T86=E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S$*
M;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")3=&EG96YD92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X
M,PIM<V=I9"`B07-K(@IM<V=S='(@(E-P^')G(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3$Y"FUS9VED(")!='1A8V@B"FUS9W-T<B`B
M5F5D:.9F="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W
M-0IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S='(@(E9E9&CF9G0@9FEL97(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-38*;7-G:60@
M(D%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!Y;W5R
M(&UE<W-A9V4_(@IM<V=S='(@(DCF9G0@96X@:V]P:2!A9B!D:6X@;V9F96YT
M;&EG92!01U`M;OAG;&4@=F5D(&1I;B!B97-K960_(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W1N968N<&AP.C$P.0IM<V=I9"`B071T86-H960@1FEL93HB"FUS
M9W-T<B`B5F5D:.9F=&5T(&9I;#HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#4Q
M(&QI8B]#;VUP;W-E+G!H<#HU,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M071T86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T86-H;65N="!S
M:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(@IM<V=S='(@(B(*(E-T
M^')R96QS92!A9B!F:6QE;B!<(B5S7"(@;W9E<G-T:6=E<B!B96=RYFYS;FEN
M9V5N+B!&:6QE;B!)2TM%('9E9&CF9G1E="XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,S<V"FUS9VED(")!='1A8VAE9"!I<R!A(')E<&QY('1O
M(&$@8V%L96YD87(@<F5Q=65S="!Y;W4@<V5N="XB"FUS9W-T<B`B1&5R(&5R
M('9E9&CF9G1E="!E="!S=F%R('1I;"!E;B!K86QE;F1E<BUA;FUO9&YI;F<L
M('-O;2!D=2!H87(@<V5N9'0N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHQ-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z
M,30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`V('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.CDW"FUS9VED(")!='1A8VAM
M96YT(@IM<V=S='(@(E9E9&CF9G1E;'-E(@H*(SH@8V]M<&]S92YP:'`Z,3`V
M-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")!='1A8VAM96YT('-T<FEP
M<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T<B`B5F5D:.9F
M=&5L<V5N('1A9V5T(&%F.B!/<')I;F1E;&EG('1Y<&4@868@=F5D:.9N9R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T.2!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S,*(SH@;&EB+T-O;7!O<V4N<&AP
M.C$P-S,*;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S='(@(E9E9&CF9G1E;'-E
M<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#(*;7-G:60@(D%T
M=&5N9&5E<R(*;7-G<W1R(")$96QT86=E<F4B"@HC.B!L:6(O34E-12]6:65W
M97(O;F]T:69I8V%T:6]N+G!H<#HU,PIM<V=I9"`B071T96YT:6]N(@IM<V=S
M='(@(D)E;>9R:R(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*;7-G:60@(D%U
M=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?:6UP.B!+<N9V970@24U!4"!U9'9I9&1E;'-E(&EK:V4@
M9G5N9&5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-#`*;7-G:60@
M(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E
M<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM
M<V=S='(@(B(*(E-K86P@8FEL;&5D97(@:2!(5$U,+6)E<VME9&5R('9I<V5S
M(&%U=&]M871I<VLL(&AV:7,@869S96YD97)E;B!S=.5R(&D@;6ET("(*(F%D
M<F5S<V5K87)T;W1E:S\B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHR.3@*;7-G:60@(D%V86EL86)L92!!9&1R97-S(&)O;VMS.B(*
M;7-G<W1R(")!9')E<W-E:V%R=&]T96ME<BP@9&5R('-TY7(@=&EL('+E9&EG
M:&5D.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@
M(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@(D%F=F5N=&5R(')E86MT:6]N
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"86-?:R!T;R`E<R(*;7-G<W1R(")4
M:6QB86=E('1I;"`E<R(*"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R(")4:6QB86=E('1I;"`E<R(*"B,Z
M('1H<F5A9"YP:'`Z,3,T"FUS9VED(")"86-K('1O($UU;'1I<&QE($UE<W-A
M9V4@5FEE=R!);F1E>"(*;7-G<W1R(")4:6QB86=E('1I;"!O=F5R<VEG='-V
M:7-N:6YG(@H*(SH@=&AR96%D+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR
M96%D($1I<W!L87DB"FUS9W-T<B`B5&EL8F%G92!T:6P@='+E9"UV:7-N:6YG
M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N
M9&5D.B`E<R(*;7-G<W1R(")$Y7)L:6<@96QL97(@<FEN9V4@9F]R;75L97)E
M="!A;FUO9&YI;F<N(%-E<G9E<F5N(')E86=E<F5D92!M960Z("5S(@H*(SH@
M;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C`@
M;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G<W1R(")"8V,B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C$*;7-G:60@(D)E;&]W
M(&ES('1H92!R87<@=&5X="!O9B!T:&4@<W1A='5S(&EN9F]R;6%T:6]N(&UE
M<W-A9V4N(@IM<V=S='(@(DYE9&5N9F]R(&9O<F5F:6YD97,@<N5T96MS=&5N
M(&%F('-T871U<R!B97-K961E;BXB"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,38*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R(")";&%C:VQI<W1E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8R.0IM<V=I9"`B0FQO8VL@
M:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I
M9FEC86QL>2!R97%U97-T960_(@IM<V=S='(@(D)L;VOI<B!B:6QL961E<B!I
M($A434PM8F5S:V5D97(@;65D(&UI;F1R92!D92!A;FUO9&5S('-P96-I9FEK
M=#\B"@HC.B!L:6(O4V5A<F-H+G!H<#HT,@IM<V=I9"`B0F]D>2(*;7-G<W1R
M(")"97-K960B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C(S('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,SD*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHU-2!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C<Q"FUS
M9VED(")";W1H(@IM<V=S='(@(D)E9V=E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8X-PIM<V=I9"`B0F]T:"!(96%D97(@3&ES=&EN9R!A;F0@0F]D
M>2!O9B!-97-S86=E(@IM<V=S='(@(D+E9&4@8F5S:V5D96YS(&9E;'0M;&ES
M=&4@;V<@8G+X9'1E:W-T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C<R"FUS9VED(")#7VAA<G-E="(*;7-G<W1R(")496=N<^9T(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED(")#86QE
M;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,C`Q"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T
M92!M86EL('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!FY2!F;W)B:6YD
M96QS92!T:6P@;6%I;"US97)V97)E;BXB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO
M=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R(")+86X@:6MK92!F;W)B:6YD92!T
M:6P@9FIE<FX@;6%I;"US97)V97(Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M87)T:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T
M(&1I<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@
M;65S<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R("(B
M"B)+86X@:6MK92!V:7-E<R`M(&AA<B!K=6X@9G5N9&5R("5S(&%F("5S(&1E
M;&4@868@9&5N;F4@8F5S:V5D(&D@9&5N(&%K='5E;&QE("(*(F)R979B86MK
M92XB"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN
M8SHR,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@
M=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z
M,S(*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B
M0V%N8V5L(@IM<V=S='(@(D%N;G5L;&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#,U"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3$*
M;7-G:60@(D-A;F-E;"!-97-S86=E(@IM<V=S='(@(D%N;G5L;&5R(&)E<VME
M9"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN9R!T
M:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT
M96YT<RXB"FUS9W-T<B`B2'9I<R!D=2!A;FYU;&QE<F5R(&1E;FYE(&)E<VME
M9"P@;6ES=&5R(&1U(&EN9&AO;&1E="!P97)M86YE;G0N(@H*(SH@;65S<V%G
M92YP:'`Z,C8U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(Q
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,34@;&EB+U-E
M87)C:"YP:'`Z,S`*;7-G:60@(D-C(@IM<V=S='(@(D-C(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHY,PIM<V=I9"`B(@HB0V5R=&EF:6-A=&4@
M:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E
M;F%B;&5D(&]N('1H:7,@(@HB<V5R=F5R+B(*;7-G<W1R("(B"B));7!O<G0@
M868@8V5R=&EF:6MA="!I:VME(&UU;&EG+B!(96YT;FEN9R!A9B!F:6QE<B!E
M<B!I:VME('-LY65T('1I;"!PY2`B"B)D96YN92!S97)V97(N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<P,0IM<V=I9"`B0VAA:7(@4&5R<V]N
M(@IM<V=S='(@(DWX9&5L961E<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHX,`IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(L9N9')E(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#
M:&%N9V4@06QL(@IM<V=S='(@(L9N9')E(&%L;&4B"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z.3(*;7-G:60@(D-H86YG92!&;VQD97(B"FUS9W-T<B`B
M4VMI9G0@;6%P<&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS
M9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA
M;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M
M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R("(B"B)(97(@:V%N(&1U(.9N
M9')E(&WE9&5N(&1I;F4@8F5S:V5D97(@8FQI=F5R('9I<W0@<.4L('-O;2!F
M+F5K<RX@:'9O<B!M86YG92`B"B)B97-K961E<B!D97(@=FES97,@<.4@:'9E
M<B!S:61E+"!S86UT(&AV;W)D86X@9&4@<V]R=&5R97,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T"FUS9VED(")#:&%N9V4@;6%I;"!S97)V97(@
M86YD(&9O;&1E<B!S971T:6YG<RXB"FUS9W-T<B`B2&5R(&MA;B!D=2#F;F1R
M92!O<'/F=&YI;F=E;B!T:6P@;6%I;'-E<G9E<B!O9R!M87!P97(N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@=&AA="!P96]P;&4@<V5E
M('=H96X@=&AE>2!R96%D(&%N9"`B"B)R97!L>2!T;R!Y;W5R(&5M86EL+B(*
M;7-G<W1R("(B"B)(97(@:V%N(&1U(.9N9')E(&YA=FXL(&%D<F5S<V4@;V<@
M9&5N('-I9VYA='5R+"!S;VT@86YD<F4@<V5R+"!NY7(@9&4@;.9S97(@(@HB
M;V<@<W9A<F5R('#E(&1I;F4@92UM86EL+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,C0*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB"FUS
M9W-T<B`B5&5G;B!T:6P@=FES;FEN9SHB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ-0IM<V=I9"`B0VAE8VL@1F]L9&5R*',I(&9O<B!.
M97<@36%I;"(*;7-G<W1R(")+;VYT<F]L;&5R(&UA<'!E*'(I(&9O<B!N>64@
M92UM86EL(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C<U"FUS9VED
M(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B2&%K(&%L;&4O:6YG96X@868B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,3`@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(Q"FUS9VED(")#:&5C
M:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O
M;3HB"FUS9W-T<B`B2&%R(&%L;&4@;6%I;"US97)V97)E;BP@<V]M(&1U('9I
M;"!H96YT92!E+6UA:6P@9G)A+"!A9CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#8S"FUS9VED(")#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN
M9R!A(&UE<W-A9V4_(@IM<V=S='(@(DMO;G1R;VQLZ7(@<W1A=FYI;F<@9OAR
M(&%F<V5N9&5L<V4@868@8F5S:V5D/R(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C0*;7-G:60@(D-H;V]S92!!8W1I;VXZ(@IM<V=S='(@
M(E;F;&<@:&%N9&QI;F<Z(@H*(SH@8V]N9FEG+W-E<G9E<G,N<&AP+F1I<W0Z
M,3@R"FUS9VED(")#:&]O<V4@82!M86EL('-E<G9E<CHB"FUS9W-T<B`B5N9L
M9R!M86EL+7-E<G9E<CHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHQ,C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,38V"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Q-PIM<V=I9"`B0VAO
M;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z
M(@IM<V=S='(@(E;F;&<@96X@<&%S;FEN9R!E;&QE<B!R970@861R97-S96X@
M=&EL(&CX:G)E.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C$@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,0IM<V=I9"`B0VAO;W-E(&%N
M(&%C=&EO;CHB"FUS9W-T<B`B5N9L9R!H86YD;&EN9SHB"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*;7-G:60@(D-H;V]S92!T
M:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N
M(@IM<V=S='(@(E;F;&<@9&5N(&%D<F5S<V5K87)T;W1E:RP@<V]M(&1E<B!S
M:V%L(&MU;FYE('1I;&;X:F5S(&%D<F5S<V5R('1I;"XB"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3,*;7-G:60@(D-H;V]S92!T
M:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A
M;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("(B"B)6YFQG(&1E;B!RYFMK96;X
M;&=E('-O;2!A9')E<W-E:V%R=&]T96ME<B!B;&EV97(@9V5N;F5M<_AG="!I
M+"!NY7(@9'4@<VSE<B`B"B)A9')E<W-E<B!O<"XB"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T
M('EO=7(@8G)O=W-E<B!C86X@=FEE=RXB"FUS9W-T<B`B(@HB0VQI8VL@)7,@
M9F]R(&%T(&]M<^9T=&4@8FEL;&5D9FEL96X@=&EL(&5T(&9O<FUA="P@<V]M
M(&1I;B!B<F]W<V5R(&MA;B!V:7-E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M(&1O=VYL;V%D('1H92!I;6%G92XB"FUS9W-T<B`B0VQI8VL@)7,@9F]R(&%T
M(&AE;G1E(&)I;&QE9&5T+B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M
M96YT('!A9V4N(@IM<V=S='(@(D-L:6-K("5S(&9O<B!A="!K;VUM92!T:6P@
M)7,@=F5D;&EG96AO;&1E;'-E<W-I9&5N+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@
M=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM
M<V=S='(@(D-L:6-K("5S(&9O<B!A="!S92!(5$U,(&EN9&AO;&0@:2!E="!S
M97!A<F%T('9I;F1U92XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A
M('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R(")#;&EC:R`E<R!F
M;W(@870@<V4@96X@9G)I;>9R:V5U9&=A=F4@868@8FEL;&5D970N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E
M<&%R871E('=I;F1O=RXB"FUS9W-T<B`B0VQI8VL@)7,@9F]R(&%T('-E('9E
M9&CF9G1E;'-E;B!I(&5T('-E<&%R870@=FEN9'5E+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]R96QA=&5D+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&EC:R`E<R!T;R!V:65W('1H:7,@;75L=&EP87)T+W)E;&%T960@<&%R="!I
M;B!A('-E<&%R871E('=I;F1O=RXB"FUS9W-T<B`B(@HB0VQI8VL@)7,@9F]R
M(&%T('-E(&1E;FYE(#QE;3YM=6QT:7!A<G0O<F5L871E9#PO96T^(&1E;"!I
M(&5T('-E<&%R870@=FEN9'5E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL
M+G!H<#HY-0IM<V=I9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!);6%G97,B
M"FUS9W-T<B`B0VQI8VL@:&5R(&9O<B!A="!625-%(&)I;&QE9&5R;F4B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*;7-G:60@
M(B(*(D-L:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O
M:W,@86YD('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*
M;7-G<W1R("(B"B)+;&EK('#E(&5N(&%F(&1E('9A;&=T92!A9')E<W-E:V%R
M=&]T96ME<B!O9R!VYFQG(&1E(&9E;'1E<BP@9&5R('-K86P@<_AG97,@(@HB
M:2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S$*;7-G:60@(D-L
M:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O
M;VLB"FUS9W-T<B`B0VQI8VL@9F]R(&%T(&=E;6UE(&]F9F5N=&QI9R!01U`M
M;OAG;&4@:2!D:70@861R97-S96MA<G1O=&5K(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B0VQI8VL@9F]R(&%T(&=E;6UE(%,O34E-12UC
M97)T:69I:V%T(&9O<B`E<R!I(&1I="!A9')E<W-E:V%R=&]T96LB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34P"FUS9VED(")#;&EC:VEN9R!O;B!T
M:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@
M<V5N9&5R(@IM<V=S='(@(E-K<FEV(&5T(&YY="!B<F5V('1I;"!A9G-E;F1E
M<F5N('9E9"!A="!C;&EC:V4@<.4@861R97-S96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#;&EC:VEN9R!O;B!T:&4@861D<F5S
M<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9"(*;7-G<W1R(")"
M97-K961E;B!V:6P@8FQI=F5R(.5B;F5T('1I;"!LYG-N:6YG('9E9"!A="!C
M;&EC:V4@<.4@861R97-S96XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E
M=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S='(@(DQU:R(*"B,Z
M(&-O;7!O<V4N<&AP.C@R."!C;VUP;W-E+G!H<#HQ,30X"FUS9VED(")#;&]S
M92!T:&ES('=I;F1O=R(*;7-G<W1R("),=6L@=FEN9'5E(@H*(SH@9F]L9&5R
M<RYP:'`Z-#(Y"FUS9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(DQU:VME
M="!M87!P92(*"B,Z(&9O;&1E<G,N<&AP.C0T.0IM<V=I9"`B0V]L;&%P<V4B
M"FUS9W-T<B`B3'5K(&%L;&4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL(@IM<V=S='(@(DQU:R!A
M;&QE(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G
M:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S='(@(DQU:R!A;&QE(&UA
M<'!E<B(*"B,Z(&9O;&1E<G,N<&AP.C0T.0IM<V=I9"`B0V]L;&%P<V4@1F]L
M9&5R(@IM<V=S='(@(DQU:R!M87!P92(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@26YD:6-A=&]R.B`B"FUS
M9W-T<B`B1F%R=F5I;F1I:V%T;W(Z("(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ,#,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M;65N=&%R(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V.0IM<V=I9"`B0V]M<&QE
M=&5D(@IM<V=S='(@(D%F<VQU='1E="(*"B,Z(&-O;7!O<V4N<&AP.C@R-R!C
M;VUP;W-E+G!H<#HQ,30W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S<V%G
M92(*;7-G<W1R(")3:W)I=B!E;B!A;F1E;B!B97-K960B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN
M(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")3:W)I=B!B97-K961E<B!I
M(&5T('-E<&5R870@=FEN9'5E/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET:"!A;B!(5$U,
M($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H92`B"B)F
M96%T=7)E*3\B"FUS9W-T<B`B(@HB4VMR:79E(&)E<VME9&5R(&UE9"!E;B!(
M5$U,+7-N:71F;&%D92!S;VT@<W1A;F1A<F0@*&)R;W=S97(@<VMA;"!U;F1E
M<G-T^'1T92`B"B)M=6QI9VAE9&5N*3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I
M<W!L87EE9"XB"FUS9W-T<B`B26YD<W1I;"!H=F]R9&%N(&)E<VME9&5R('-K
M86P@=FES97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED
M(")#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N(@IM<V=S='(@(DMO
M;F9I9W5RZ7(@92UM86EL+6=L:6UT(&EN9'-T:6QL:6YG97(N(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G:60@(D-O;FYE8W1I;VX@9')O<'!E
M9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T<B`B1F]R8FEN9&5L<V5N(&)L978@
M869B<G5D="!A9B!)34%0+7-E<G9E<BXB"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V97(@9F%I;&5D
M(@IM<V=S='(@(D9O<F)I;F1E;'-E('1I;"!S97)V97(@9F5J;&5D92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(DMO;G1R
M;VQLZ7(@4$=0+75N9&5R<W3X='1E;'-E(&9O<B`E<RXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R
M;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R(")+;VYT<F]L;.ER
M(%,O34E-12!U;F1E<G-T^'1T96QS92!F;W(@)7,N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R,0IM<V=I9"`B0V]N=')O;"!O<'1I;VYS(')E;&%T
M:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RXB"FUS9W-T<B`B2V]N=')O;&SI
M<B!I;F1S=&EL;&EN9V5R('9E9'+X<F5N9&4@<_AG;FEN9R!A9B!B97-K961E
M<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O
M;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@
M=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV
M97,N(@IM<V=S='(@(B(*(DEN9'-T:6P@:'9O<F[E<B!D97(@8VAE8VME<R!F
M;W(@;GEE(&UA:6PL('-A;70@;VT@;V<@:'9O<F1A;B!D=2!S:V%L("(*(F]P
M;>9R:W-O;2!PY2!N>64@8F5S:V5D97(N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Y-@IM<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I
M;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R(")/;7/F="!T96MS="T\96T^
M<VUI;&5Y<SPO96T^('1I;"!G<F%F:7-K93\B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:65R(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y('1O
M(&9O;&1E<B(*;7-G<W1R(")+;W!IZ7(@=&EL(&UA<'!E(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM
M<V=S='(@(DMO<G)I9V5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`B2V]R
M<FEG97)E="!T96MS="(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T
M+B!296%S;VX@1VEV96XZ("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@9G5L9&;X
M<F4@86YM;V1N:6YG+B#%<G-A9SH@)7,B"@HC.B!A='1A8VAM96YT+G!H<#HU
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E('1H92!6
M1E,@8F%C:V5N9#H@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!O<')E='1E(#QE
M;3Y61E,@8F%C:V5N9#H\+V5M/B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S
M86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DMU
M;FYE(&EK:V4@<VQE='1E(&)E<VME9&5R(&9R82!<(B5S7"(N(%-E<G9E<F5N
M(&UE;&1T93H@)7,B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,S$X"FUS9VED(")#
M;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G
M<W1R(")+=6YN92!I:VME('5D9OAR92!V961L:6=E:&]L9&5L<V5S;W!G879E
M<BXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-30*;7-G:60@(D-O
M=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!-
M4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(DMU;FYE(&EK:V4@=61D<F%G
M92!D96X@86YM;V1E9&4@9FEL(&9R82!-4RU43D5&+79E9&CF9G1E;'-E;BXB
M"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HU.`IM<V=I9"`B0V]U;&0@
M;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A
M<F-H:79E+B(*;7-G<W1R(")+=6YN92!I:VME('5D9')A9V4@9&5N(&%N;6]D
M961E(&9I;&4@9G)A(%II<"UA<FMI=F5T+B(*"B,Z(&QI8B]397-S:6]N+G!H
M<#HR-S,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!N86UE<W!A8V4@:6YF
M;W)M871I;VX@9G)O;2!)34%0('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK
M92!I;F1H96YT92`\96T^;F%M97-P86-E/"]E;3XM:6YF;W)M871I;VX@9G)A
M($E-05`M<V5R=F5R96XN(@H*(SH@<V5A<F-H+G!H<#HS,30@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L+FEN
M8SHS.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38P"FUS9VED(")#<F5A
M=&4B"FUS9W-T<B`B3W!R970B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHV"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@(D]P<F5T
M(&UA<'!E(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I9"`B
M0W)E871E($ME>7,B"FUS9W-T<B`B3W!R970@;OAG;&5R(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C$T"FUS9VED(")#<F5A=&4@5FER='5A
M;"!&;VQD97(B"FUS9W-T<B`B3W!R970@=FER='5E;"!M87!P92(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"FUS9VED
M(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R(")/<')E="!E;B!N>2!K
M;VYT;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHQ,B!T
M96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T
M92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R(")/<')E="!E;B!N>2!S<&%M
M+6UA<'!E(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z
M,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@
M(D-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(D]P<F5T(&5N
M(&YY(&UA<'!E('1I;"!K;&%D9&5R(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E
M;G1M86EL<V5L96-T+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS
M96QE8W0N:6YC.C0R"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M86EL(&9O
M;&1E<B(*;7-G<W1R(")/<')E="!E;B!N>2!M87!P92!T:6P@869S96YD=&4@
M8F5S:V5D97(B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC
M.C$R('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*;7-G:60@
M(D-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B3W!R970@96X@
M;GD@<VMR86QD97-P86YD('1I;"!S;&5T=&5D92!B97-K961E<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C@*;7-G:60@(B(*(D-R96%T92!F:6QT
M97)I;F<@<G5L97,@=&\@;W)G86YI>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S
M;W)T(&ET(&EN=&\@9F]L9&5R<RP@(@HB86YD(&1E;&5T92!S<&%M+B(*;7-G
M<W1R("(B"B)/<')E="!F:6QT97)R96=L97(@9&5R('-O<G1E<F5R(&YY92!E
M+6UA:6QS+"!F;'ET=&5R(&1E;2!I(&UA<'!E<B!O9R!S;&5T=&5R("(*(E-0
M04TN(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"FUS
M9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`B3W!R970@96X@
M;GET(&)R979P87!I<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*
M;7-G:60@(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB
M"FUS9W-T<B`B3W!R970@8G)E=G!A<&ER(&]G(&9O<FUU;&%R+7-V87(N(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(D%K='5E;"!A9&=A
M;F<@=&EL("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM<V=I
M9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@
M;W1H97(@86-C;W5N=',N(@IM<V=S='(@(E1I;')E="!K;VYT:2!T:6P@:&5N
M=&YI;F<@868@92UM86EL(&9R82!A;F1R92!K;VYT:2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D-U<W1O;6EZ92!H;W<@>6]U('-E
M;F0@;6%I;"XB"FUS9W-T<B`B5&EL<&%S(&AV;W)D86X@9'4@<V5N9&5R(&4M
M;6%I;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+B(*;7-G<W1R(")4:6QP87,@;W!G879E<BP@9&5R(&)L:79E<B!U
M9&;X<G0L(&[E<B!D=2!L;V=G97(@:6YD(&D@)7,N(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-PIM<V=I9"`B1&%T7V4B
M"FUS9W-T<B`B1&%T;R(*"B,Z(&UE<W-A9V4N<&AP.C(V,B!T:')E860N<&AP
M.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R(")$871O(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C<U-PIM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B
M069V:7-T(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,PIM<V=I
M9"`B1&5C;&EN960Z("(*;7-G<W1R(")!9G9I<W0Z("(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,S<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4W1A
M;F1A<F0B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C
M="YI;F,Z,3@*;7-G:60@(D1E9F%U;'0@4V5A<F-H($9I96QD(@IM<V=S='(@
M(E-T86YD87)D('/X9V5F96QT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDR,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R
M(")3=&%N9&%R9&MR:71E<FEE(&9O<B!S;W)T97)I;F<Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDS,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I
M<F5C=&EO;CHB"FUS9W-T<B`B3>5D96XL(&1E<B!S:V%L('-O<G1E<F5S('#E
M.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C4*;7-G:60@(D1E
M;&5G871E9"(*;7-G<W1R(")$96QE9V5R970B"@HC.B!F;VQD97)S+G!H<#HT
M,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4VQE="(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0=6)L:6,@
M2V5Y(@IM<V=S='(@(E-L970@)7,@;V9F96YT;&EG92!N^&=L92(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C@U"FUS9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(E-L
M970@86MT=65L(&[X9VQE(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G<W1R(")3;&5T
M(&UA<'!E*'(I(@H*(SH@9F]L9&5R<RYP:'`Z,C@U"FUS9VED(")$96QE=&4@
M4V5L96-T960@1F]L9&5R<R(*;7-G<W1R(")3;&5T('9A;&=T92!M87!P97(B
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#(*;7-G:60@
M(D1E;&5T92!3=&%T:6]N97)Y(@IM<V=S='(@(E-L970@8G)E=G!A<&ER(@H*
M(SH@9F]L9&5R<RYP:'`Z-#$Y"FUS9VED(")$96QE=&4@5FER='5A;"!&;VQD
M97(B"FUS9W-T<B`B4VQE="!V:7)T=65L(&UA<'!E(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE
M9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@(E-L970@
M:&5N=&5D92!B97-K961E<B!F<F$@9FIE<FX@<V5R=F5R/R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY
M(&-A;&5N9&%R(@IM<V=S='(@(E-L970@9G)A(&UI;B!K86QE;F1E<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(D1E;&5T92!O;&0@
M;&EN:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS
M9W-T<B`B4VQE="!G86UL92!R969E<F5R961E('9E9&CF9G1E;'-E<B!I('-T
M87)T96X@868@;>5N961E;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S4P"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S(&%T(&)E
M9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B4VQE="!G86UL92!M87!P97(@
M9F]R(&%F<V5N9'1E(&)E<VME9&5R(&D@<W1A<G1E;B!A9B!MY6YE9&5N/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3<*;7-G:60@(D1E;&5T92!S
M<&%M(&UE<W-A9V5S(@IM<V=S='(@(E-L970@<W!A;2UB97-K961E<B(*"B,Z
M(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I
M9"`B1&5L971E9"(*;7-G<W1R(")3;&5T=&5T(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B1&5L971E9"!M97-S86=E<R(*;7-G
M<W1R(")3;&5T=&5D92!B97-K961E<B(*"B,Z(&-O;7!O<V4N<&AP.C,P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB
M)7-<(BXB"FUS9W-T<B`B5F5D:.9F=&5L<V5N(%PB)7-<(B!S;&5T=&5T+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B1&5L971I;F<@
M86YD($UO=FEN9R!-97-S86=E<R(*;7-G<W1R(")3;&5T;FEN9R!O9R!F;'ET
M;FEN9R!A9B!B97-K961E<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.3(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R(")!9G9I<R!A;FUO
M9&YI;F<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30P"FUS9VED
M(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G
M<W1R(")!9G9I<R!A;FUO9&YI;F<@;VT@;&5D:6<O;W!T86=E="UI;F9O<FUA
M=&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S(*;7-G:60@(D1E
M<V-E;F1I;F<B"FUS9W-T<B`B1F%L9&5N9&4B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8V.0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B0F5S:W)I=F5L
M<V4B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C(W('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S<*;7-G:60@(D1E=&%I;',B"FUS9W-T<B`B1&5T86QJ97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<W"FUS9VED(")$:6T@<VEG;F%T
M=7)E<S\B"FUS9W-T<B`B4VSX<B!S:6=N871U<F5R/R(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$:7-P;&%Y(@IM
M<V=S='(@(E9I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-SD*;7-G
M:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S
M86=E/R(*;7-G<W1R(")6:7,@8F5K<N9F=&5L<V4@969T97(@869S96YD96QS
M92!A9B!E;B!B97-K960_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X
M-@IM<V=I9"`B1&ES<&QA>2!I;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B
M5FES(&D@8G+X9'1E:W-T(&%F(&)E<VME9"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.3(*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO
M;B!O9B!N97<@;6%I;#\B"FUS9W-T<B`B5FES(&5T('!O<'5P('9I;F1U92!V
M960@;GEE(&4M;6%I;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4X
M"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%-P86U<(B!L:6YK(&EN('1H
M92!M96YU8F%R/R(*;7-G<W1R(")6:7,@7")4^&T@<W!A;5PB(&AE;G9I<VYI
M;F=E;B!I(&UE;G5L:6YI96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<U,`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@
M:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(E9I<R!<(E3X;2!S:W)A;&1E<W!A
M;F1<(B!H96YV:7-N:6YG96X@:2!M96YU;&EN:65N/R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0IM<V=I9"`B1&ES<&]S:71I
M;VXB"FUS9W-T<B`B1F]R;2(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA=&-H(@IM<V=S='(@(E!A<R!)2TM%
M('1I;"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$V"FUS
M9VED(")$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G
M<W1R(")#:&5C:R!I:VME(&UA<'!E*'(I(&9O<B!N>64@92UM86EL(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E;F5R
M871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM<V=S='(@(D=E;F5R
MZ7(@:6MK92!H96YV:7-N:6YG(&D@1G)A.B!K;VQO;FYE;B(*"B,Z(&QI8B])
M35`N<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F
M;VQD97(_(@IM<V=S='(@(E9I;"!D=2#E8FYE(&1E;FYE(&UA<'!E/R(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,R"FUS9VED(")$;VXG="!H
M879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(DAA<B!D=2!I:VME
M(&YO9V5N(&MO;G1O/R!-96QD(&1I9R!T:6PN(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B1&]N92(*;7-G<W1R(")&
MYG)D:6<B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"B,L('!H<"UF
M;W)M870*;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S
M='(@(DAE;G0@)7,@:2`N>FEP+69O<FUA="(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VAE861E<G,N:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H
M;65N=',@*&EN("YZ:7`@9FEL92DB"FUS9W-T<B`B2&5N="!A;&QE('9E9&CF
M9G1E;'-E<B`H:2`N>FEP+69I;"DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR,`IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S
M='(@(DAE;G0@;6%P<&4H<BDB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHR,0IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O
M<FUA=%TB"FUS9W-T<B`B2&5N="!M87!P92AR*2!;+GII<"!U9&=A=F5=(@H*
M(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@
M:6X@+GII<"!&;W)M870B"FUS9W-T<B`B2&5N="!I("YZ:7`M9F]R;6%T(@H*
M(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G
M:60@(D1R869T(@IM<V=S='(@(DML861D92(*"B,Z(&9O;&1E<G,N<&AP.C,Y
M,@IM<V=I9"`B1')A9G0@9F]L9&5R(@IM<V=S='(@(DML861D97(B"@HC.B!T
M96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I9"`B1')A
M9G1S(&9O;&1E<CHB"FUS9W-T<B`B36%P<&4@=&EL(&ML861D97(Z(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I9"`B12UM86EL($%D9')E
M<W,B"FUS9W-T<B`B92UM86EL+6%D<F5S<V4B"@HC.B!L:6(O36%I;&)O>"YP
M:'`Z,S`Y"FUS9VED(")%3D0B"FUS9W-T<B`B4TQ55"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED(")%4E)/4CH@66]U<B!M97-S
M86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N(@IM<V=S='(@(D9%2DPZ($1I
M;B!B97-K960@:W5N;F4@:6MK92!A9FQE=F5R97,N(@H*(SH@9F]L9&5R<RYP
M:'`Z-#(P('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ.0IM<V=I
M9"`B161I="(*;7-G<W1R("+&;F1R92(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!";&%C:VQI<W0B"FUS9W-T<B`B
MQFYD<F4@8FQA8VML:7-T92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHQ,PIM<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(L9N9')E(&9I
M;'1R92(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z,38*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T
M<B`B4F5T('9I<G1U96P@;6%P<&4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A
M;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`BQFYD<F4@=FER
M='5E;"!M87!P92!D969I;FET:6]N96X@9F]R("5S(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*
M;7-G<W1R(")2970@<&]S:71I=FQI<W1E(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET('EO=7(@8FQA8VML:7-T(@IM
M<V=S='(@(L9N9')E(&1I;B!B;&%C:VQI<W1E(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<')E9G,N:6YC.C$S"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U
M;&5S(@IM<V=S='(@(L9N9')E(&1I;F4@9FEL=&5R<F5G;&5R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V,0IM<V=I9"`B161I="!Y;W5R('!R969E
M<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS
M9W-T<B`B4F5T(&1I;F4@<'+F9F5R96YC97(@=F5D<OAR96YD92!T:6QG86YG
M('1I;"!A;F1R92!E+6UA:6PM:V]N=&DN(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C(S"FUS9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM
M<V=S='(@(L9N9')E(&1I;B!P;W-I=&EV;&ES=&4B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S.0IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R(")E+6UA:6PM861R97-S92(*"B,Z(&QI8B]-97-S86=E+G!H
M<#HV-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B16UP=&EE9"!A;&P@;65S<V%G
M97,@9G)O;2`E<RXB"FUS9W-T<B`B06QL92!B97-K961E<B!F:F5R;F5T(&9R
M82`E<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS
M9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B5/AM(&UA<'!E*'(I(@H*
M(SH@9F]L9&5R<RYP:'`Z,C@V"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD
M97)S(@IM<V=S='(@(E3X;2!V86QG=&4@;6%P<&5R(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y(%1R87-H(&9O
M;&1E<B(*;7-G<W1R(")4^&T@<VMR86QD97-P86YD(@H*(SH@;&EB+TE-4"YP
M:'`Z.3<S"FUS9VED(")%;7!T>2!?4W!A;2(*;7-G<W1R(")4^&T@<W!A;2(*
M"B,Z(&QI8B])35`N<&AP.CDV-@IM<V=I9"`B16UP='D@7U1R87-H(@IM<V=S
M='(@(E3X;2!S:W)A;&1E<W!A;F0B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA
M8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")!:W1I=NER(%!'4"UF
M=6YK=&EO;F%L:71E=#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA
M8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")!:W1I=NER(%,O
M34E-12UF=6YK=&EO;F%L:71E=#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#$Q"FUS9VED(")%;F%B;&4@;65S<V%G92!P<F5V:65W<S\B"FUS9W-T
M<B`B06MT:7;I<B!B97-K960M9VQI;70_(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#0R"FUS9VED(")%;F-R7WEP=&EO;B!/<'1I;VYS
M(@IM<V=S='(@(DMR>7!T97)I;F=S:6YD<W1I;&QI;F=E<B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU,3<@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8U-PIM<V=I9"`B16YD(@IM<V=S='(@(E-L=70B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S@T"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS
M9W-T<B`B4VQU="!A9B!V:61E<F5S96YD="!B97-K960B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S0Q"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R(")!9G-L
M=70@8F5S:V5D(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(D%F<VQU
M="!B97-K960@9G)A("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A
M<W-P:')A<V4B"FUS9W-T<B`B26YD=&%S="!L^'-E;B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M
M92!F;W(@>6]U<B!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B26YD=&%S="!N
M879N970@=&EL(&1E;B!N>64@;6%P<&4L(&1U('9I;"!B<G5G92!S;VT@<W!A
M;2UM87!P92(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC
M.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@
M9F]L9&5R(@IM<V=S='(@(DEN9'1A<W0@;F%V;F5T('1I;"!D96X@;GEE(&UA
M<'!E+"!D=2!V:6P@9V5M;64@:VQA9&1E<B!I(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-E;G1M86EL<V5L96-T+FEN8SHR,PIM<V=I9"`B16YT97(@=&AE(&YA
M;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B26YD
M=&%S="!N879N970@=&EL(&1E;B!N>64@;6%P<&4L(&1U('9I;"!G96UM92!S
M96YD=&4@92UM86EL(&DB"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE
M8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T
M<F%S:"!F;VQD97(B"FUS9W-T<B`B26YD=&%S="!N879N970@=&EL(&1E;B!N
M>64@;6%P<&4L(&1U('9I;"!B<G5G92!S;VT@<VMR86QD97-P86YD(@H*(SH@
M;&EB+U-E87)C:"YP:'`Z-#8*;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S
M='(@(DAE;&4@8F5S:V5D96XB"@HC.B!M97-S86=E+G!H<#HQ.30@8V]M<&]S
M92YP:'`Z,3$S-"!T:')E860N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D5N=')Y(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B7"(E<UPB(&)L978@=&EL9OAJ970@=&EL
M(&%D<F5S<V5K87)T;W1E:V5T(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HS-S8@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,S@V"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T<B`B
M1F5J;"(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S
M(#H@)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@9F]R8FEN9&4@=&EL($E-05`@
M<V5R=F5R+B`E<R`Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C,P.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`W"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R(")&
M96IL('9E9"!S=F%R9F]R<V5N9&5L<V4Z("5S+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ,#$*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D
M96QE=&5D+B(*;7-G<W1R(")(YFYD96QS96X@<VQE='1E="XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S@R"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S
M(@IM<V=S='(@(DAV97(@:W9A<G1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B2'9E
M<B!H86QV92!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#$*
M;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")(=F5R(#4N(&UI;G5T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,PIM<V=I9"`B179E<GD@
M:&%L9B!H;W5R(@IM<V=S='(@(DAV97(@:&%L=F4@=&EM92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R(")(=F5R(&UI;G5T(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED(")%
M>'!A;F0B"FUS9W-T<B`B561V:60B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R("+%8F5N
M(&%L;&4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.`IM
M<V=I9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S='(@(L5B96X@86QL92!M
M87!P97(B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X<&%N9"!&;VQD
M97(B"FUS9W-T<B`BQ6)E;B!M87!P92(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,T,"!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI
M;F,Z-3,*;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R("),878@970@;W!S
M;&%G('#E(&YA=FYE;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V
M,PIM<V=I9"`B17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A
M=71O;6%T:6-A;&QY(&EN('1H92!B86-K9W)O=6YD/R(*;7-G<W1R(")%:W-P
M86YDZ7(@875T;VUA=&ES:R!N879N92!I('-K<FEV;FEN9W-V:6YD=65T(&)A
M9R!TYG!P970_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX,`IM<V=I
M9"`B17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I
M;B!T:&4@9F]L9&5R<R!V:65W/R(*;7-G<W1R("+%8F5N(&%L;&4@;6%P<&5R
M(&D@;W9E<G-I9W1E;B!S;VT@<W1A;F1A<F0N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,30T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C$Y-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M-#4@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0IM<V=I9"`B
M17AP86YD:6YG(@IM<V=S='(@(E5D=FED9&5R(@H*(SH@;&EB+TE-4"YP:'`Z
M.3@T(&QI8B])35`N<&AP.CDX-@IM<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T
M<B`B2&5N="!E+6UA:6PB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B
M1F5T8V@@36%I;"(*;7-G<W1R(")(96YT(&4M;6%I;"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-CD*;7-G:60@(D9E=&-H($UA:6P@:6X@82!S97!A
M<F%T92!W:6YD;W<_(@IM<V=S='(@(DAE;G0@8F5S:V5D(&D@970@<V5P97)A
M="!V:6YD=64_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C0V"FUS9VED(")&971C:"!M97-S86=E<R!U<&]N(&QO9V=I;F<@;VX_(@IM
M<V=S='(@(DAE;G0@8F5S:V5D97(L(&[E<B!D=2!L;V=G97(@:6YD/R(*"B,Z
M(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M971C:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,B"FUS9W-T<B`B)60@8F5S:V5D
M97(@:&5N=&5T(&9R82`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S
M(@IM<V=S='(@(C$@8F5S:V5D(&AE;G1E="!F<F$@)7,B"@HC.B!L:6(O1F5T
M8VAM86EL+G!H<#HR.#4@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C
M:&UA:6PN<&AP.C(X.0IM<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`B1F5T
M8VAM86EL.B`B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*;7-G:60@(D9E
M=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")&971C:&UA:6PZ
M(&EN9V5N(&YY92!B97-K961E<BXB"@HC.B!L:6(O24U0+G!H<#HY.3`*;7-G
M:60@(D9I7VQT97)S(@IM<V=S='(@(D9I;'1R92(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4P,B!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYJ<SHX,@IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6PB"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S$*;7-G:60@(D9I;'1E<B!/
M<'1I;VYS(@IM<V=S='(@(D9I;'1E<BUI;F1S=&EL;&EN9V5R(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.CD*;7-G:60@(D9I;'1E<B!3971T
M:6YG<R(*;7-G<W1R(")&:6QT97(M;W!SYG1N:6YG(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8P,`IM<V=I9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N
M="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R(")&:6QT<F5R(&)E<VME9&5N<R!I
M;F1H;VQD(&9O<B!S=.9R:V4@;W)D+B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+VYO=&%C=&EV92YI;F,Z,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I
M<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")&:6QT97(M=6YD97)S
M=/AT=&5L<V4@97(@<VSE970@9G)A('#E(&1E='1E('-Y<W1E;2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S
M='(@(D9I;'1R92(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI
M;F,Z,PIM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM<V=S='(@(D9I;'1R
M92!)2TM%(&%K=&EV97)E9&4B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E
M(@IM<V=S='(@(D9I;'1R93H@)7,@:.5N9'1E<FEN9W-S:61E(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*;7-G:60@(D9I;F0B
M"FUS9W-T<B`B1FEN9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*
M;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R(")&^')S=&4@<VED
M92(*"B,Z(&UA:6QB;W@N<&AP.C,T-0IM<V=I9"`B1FER<W0@4&%G92(*;7-G
M<W1R(")&^')S=&4@<VED92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHR,0IM<V=I9"`B1F]?<G=A<F0B"FUS9W-T<B`B5FED97)E<V5N9"(*"B,Z
M(&9O;&1E<G,N<&AP.C(V-B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O
M;F9I<FTN:'1M;#HU"FUS9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")-87!P92UH86YD;&EN9V5R("T@0F5K<N9F=&5L<V4B
M"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI
M;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC
M.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHQ
M,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R(")-87!P96YA=FEG
M871O<B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(")&;VQD
M97(@4W5M;6%R>2(*;7-G<W1R(")/<'-U;6UE<FEN9R!A9B!M87!P92(*"B,Z
M(&%C;"YP:'`Z,C0*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B
M;&5D+B(*;7-G<W1R(")$96QI;F<@868@;6%P<&5R(&EK:V4@86MT:79E<F5T
M+B(*"B,Z(&9O;&1E<G,N<&AP.C8R"FUS9VED(")&;VQD97(@=7-E(&ES(&YO
M="!E;F%B;&5D+B(*;7-G<W1R(")!;G9E;F1E;'-E(&%F(&UA<'!E<B!E<B!I
M:VME(&%K=&EV97)E="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38Y
M"FUS9VED(")&;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I;&)O
M>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A>2(*;7-G<W1R(")&;W)M
M871E="!A9B!D871O97(@:2!B<F5V8F%K:V4M=FES;FEN9R!F;W(@8F5S:V5D
M97(@9&%T97)E="!I(&1A9R(*"B,Z(&-O;7!O<V4N<&AP.C<X,"!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A<F0B"FUS9W-T
M<B`B5FED97)E<V5N9"(*"B,Z(&-O;7!O<V4N<&AP.C<V-0IM<V=I9"`B1F]R
M=V%R9#HB"FUS9W-T<B`B5FED97)E<V5N9#HB"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S8Y"FUS9VED(")&;W)W87)D960@;65S<V%G92(*;7-G<W1R(")6:61E
M<F5S96YD="!B97-K960B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS
M9W-T<B`B5FED97)E<V5N9'0@8F5S:V5D(&9R82`E<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT.#,*;7-G:60@(D9R964O0G5S>2!);F9O<FUA
M=&EO;B(*;7-G<W1R(")&<FDO;W!T86=E="UI;F9O<FUA=&EO;B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.30*;7-G:60@(D9R964O0G5S>2!2
M97!L>2(*;7-G<W1R("),961I9R]O<'1A9V5T+7-V87(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S
M="(*;7-G<W1R("),961I9R]O<'1A9V5T+6%N;6]D;FEN9R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*;7-G:60@(D9R964O0G5S>2!297%U
M97-T(%)E<W!O;G-E(@IM<V=S='(@(DQE9&EG+V]P=&%G970M86YM;V1N:6YG
M<RUS=F%R(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHR-PIM<V=I9"`B1G)O7VTB"FUS9W-T<B`B1G)A(@H*(SH@;65S<V%G
M92YP:'`Z,C8S('1H<F5A9"YP:'`Z,30Y('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.CDY"B,Z(&QI8B]396%R8V@N<&AP.C(R"FUS9VED(")&<F]M
M(@IM<V=S='(@(D9R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3@*
M;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R(")&<F$@861R97-S92(*"B,Z
M(&-O;7!O<V4N<&AP.C<W-R!C;VUP;W-E+G!H<#HW.#$*;7-G:60@(D9W9#HB
M"FUS9W-T<B`B1G=D.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.30*;7-G:60@(D9W
M9#H@(@IM<V=S='(@(E93.B`B"@HC.B!C;VUP;W-E+G!H<#HQ,CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(D9W9#H@)74@1F]R=V%R9&5D($UE<W-A9V5S(@IM
M<V=S='(@(E93.B`E=2!V:61E<F5S96YD=&4@8F5S:V5D97(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@*;7-G:60@(D=E;F5R86P@3W!T:6]N<R(*;7-G<W1R(")'<G5N
M9&SF9V=E;F1E(&EN9'-T:6QL:6YG97(B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M97-S86=E
M<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B2&5N="!K=6X@;GEE(&)E<VME9&5R
M/R`H2W5N($E-05`I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@(E5D9OAR(@H*(SH@=&AR96%D+G!H
M<#HQ,S8*;7-G:60@(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B3N9S=&4@8F5S
M:V5D(@H*(SH@;&EB+TE-4"YP:'`Z-#DX"B,L('!H<"UF;W)M870*;7-G:60@
M(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B
M5FES(%PB)7-<(B!I(&%D<F5S<V5K87)T;W1E:R(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ,S4*;7-G:60@(D=R86YT(&%C8V5S<R(*;7-G<W1R(")4
M:6QD96P@861G86YG(@H*(SH@;65S<V%G92YP:'`Z-30V(&QI8B]&:6QT97(N
M<&AP.C$P-2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#(@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M,R!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8R(&QI8B]-24U%+U9I97=E<B]N;W1I
M9FEC871I;VXN<&AP.C8X"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H
M<#HW.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C$W,PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C`@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(W"FUS9VED(")(15)%(@IM
M<V=S='(@(DA%4B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS,2!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$W"B,Z(&QI8B]-24U%
M+U9I97=E<B]R96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(
M5$U,(@H*(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I;VX@
M;V8@365S<V%G92(*;7-G<W1R(")(5$U,+75D9V%V92!A9B!B97-K960B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU.`IM<V=I9"`B2&5A
M9&5R<R(*;7-G<W1R(")/=F5R<VMR:69T97(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@=&AE(&UE<W-A
M9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R(")(97(@97(@8F5S:V5D
M96XL('-O;2!D=2!S:W)E=CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C8X"FUS9VED(")(:61D96XB"FUS9W-T<B`B4VMJ=6QT(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8V-PIM<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6
M:65W(@IM<V=S='(@(E-K:G5L="!I('1RY60M=FES;FEN9R(*"B,Z(&UA:6QB
M;W@N<&AP.C,V-PIM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@(E-K:G5L
M('-L971T961E(@H*(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")(:61E(%5N
M<W5B<V-R:6)E9"(*;7-G<W1R(")3:VIU;"!D96%K=&EV97)E9&4B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B2/AJ(@H*(SH@;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N<&AP
M.C<R-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(
M:6=H(%!R:6]R:71Y(@IM<V=S='(@(DCX:B!P<FEO<FET970B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B
M"FUS9W-T<B`B2/AJ<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X
M"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT
M<S\B"FUS9W-T<B`B2'9O<F1A;B!V:6P@9'4@=FES92!V961HYF9T96QS97(_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-`IM<V=I9"`B2&]W('1O
M(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R97!L>2(*;7-G<W1R(")(
M=FEL:V5T('!RYF9I:W,@<^9T=&5S(&9O<F%N(&1E;B!C:71E<F5D92!T96MS
M="!I(&5T('-V87(Z(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*
M;7-G:60@(DE-05`B"FUS9W-T<B`B24U!4"(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3(Y"FUS9VED("))34%0("A!=71O($1E=&5C="!0<F]T;V-O
M;',I(@IM<V=S='(@(DE-05`@*&]P9&%G('!R;W1O:V]L;&5R(&%U=&]M871I
M<VLI(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!397)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B!3
M97)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("))34%0+7-E<G9E<B!L=6MK
M961E(&9O<F)I;F1E;'-E;BX@4V5R=F5R('-V87)E9&4Z("5S(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C8@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB"FUS9W-T<B`B24U!4"!O
M=F5R(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,34R"FUS9VED
M("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS
M9W-T<B`B24U!4"!O=F5R(%-33"`H<V5L=BUS:6=N97)E="!C97)T:69I:V%T
M*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38W"FUS9VED("))
M34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B24U!4"!O=F5R
M(%-33"`H<V5L=BUS:6=N97)E="DB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,V.`IM<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N
M+B(*;7-G<W1R("))34%0+7-E<G9E<B!L=6MK961E(&9O<F)I;F1E;'-E;BXB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!4"P@;F\@5$Q3(@IM<V=S='(@
M(DE-05`L(&EN9V5N(%1,4R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B24U!
M4"]03U`S(&UA:6PM<V5R=F5R92(*"B,Z(&QI8B])35`N<&AP.C@V-@IM<V=I
M9"`B24Y"3U@B"FUS9W-T<B`B26YD8F%K:V4B"@HC.B!L:6(O24U!4"]#;&EE
M;G0N<&AP.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU
M<W0@:&%V92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB"FUS
M9W-T<B`B(@HB2'9I<R!34TP@96QL97(@5$Q3(&)E;GET=&5S+"!S:V%L(&1U
M(&AA=F4@4$A0(&]P96YS<VP@=61V:61D96QS96X@;.9S<V5T+B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"FUS9VED
M("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R
M*',I('=I;&P@8F4@;&]S="$B"FUS9W-T<B`B2'9I<R!D=2!F;W)T<^9T=&5R
M+"!V:6P@9'4@;6ES=&4@86QL92!B97-K961E<B!I(&UA<'!E;B]M87!P97)N
M92$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#(*;7-G
M:60@(DEG;F]R92(*;7-G<W1R("))9VYO<F5R(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C@S"FUS9VED("))9VYO<F4@06QL(@IM<V=S
M='(@(DEG;F]R97(@86QT(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E
M:6UA9V4N:6YC.C@*;7-G:60@(DEM86=E(@IM<V=S='(@(D)I;&QE9&4B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P"FUS9VED("));7!O
M<G0B"FUS9W-T<B`B26UP;W)TZ7(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP
M;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV
M-0IM<V=I9"`B26UP;W)T($ME>2(*;7-G<W1R("));7!O<G3I<B!N^&=L92(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,SD*;7-G:60@(DEM<&]R="!+
M97EP86ER(@IM<V=S='(@(DEM<&]R=.ER(&[X9VQE<&%R(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C<*;7-G:60@(DEM<&]R="!-97-S
M86=E<R(*;7-G<W1R("));7!O<G3I<B!B97-K961E<B(*"B,Z('!G<"YP:'`Z
M-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@(DEM<&]R=.ER(%!'
M4"UN^&=L92(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3$*;7-G
M:60@(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G<W1R("));7!O
M<G3I<B!E9V5T(&-E<G1I9FEK870B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y(@IM<V=S='(@(DEM<&]R=.ER(&5G96XL('!R:79A=&4@4$=0+6[X
M9VQE(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED
M("));7!O<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B26UP
M;W)TZ7(@96=E;BP@;V9F96YT;&EG92!01U`M;OAG;&4B"@HC.B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!E<G-O
M;F%L(%,O34E-12!#97)T:69I8V%T97,B"FUS9W-T<B`B26UP;W)TZ7(@96=N
M92!3+TU)344@8V5R=&EF:6MA=&5R(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHT,"!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#(*;7-G:60@(DEM
M<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(DEM<&]R=.ER(&]F9F5N=&QI9R!N
M^&=L92(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-`IM<V=I
M9"`B26UP;W)T(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(DEM<&]R=.ER(&]F
M9F5N=&QI9R!01U`M;OAG;&4B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z.`IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM
M<V=S='(@(DEM<&]R=.ER(&]F9F5N=&QI9R!3+TU)344M;OAG;&4B"@HC.B!S
M;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@
M(DEM<&]R=.ER(%,O34E-12UN^&=L92(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R
M("));7!O<G3I<B!M8F]X+69I;"(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM
M<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T(&UB;W@@
M9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`B26UP;W)TZ7(@;6)O
M>"UF:6P@)7,@:6YD(&D@;6%P<&4@)7,N(@H*(SH@;65S<V%G92YP:'`Z-3`R
M(&UA:6QB;W@N<&AP.C<S-"!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M-B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,S"B,Z('1E;7!L871E
M<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM<V=I9"`B26UP;W)T86YT(@IM<V=S
M='(@(E9I9W1I9W0B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W
M"FUS9VED("));7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B5FEG=&EG92!B
M97-K961E<B(*"B,Z(&9O;&1E<G,N<&AP.C$V-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("(E
M9"!B97-K961E<B!I;7!O<G1E<F5T(&9R82`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S<S"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@
M(E!R;V-E<W-E;B!K^')E<B(*"B,Z(&9O;&1E<G,N<&AP.C,X-"!L:6(O1F]L
M9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-4"YP:'`Z,S$S
M"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4<F5E+G!H<#HR
M,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(DEN9&)A:VME(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Y,@IM<V=I9"`B26YC;'5D92!A(&)R:65F('-U
M;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A(')E<&QY/R(*;7-G<W1R(")-961T
M86<@96X@:V]R="!S86UM96YD<F%G(&%F(&)R979H;W9E9&5R(&D@96X@8F5S
M=F%R96QS93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W"FUS9VED
M("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B"FUS9W-T
M<B`B365D=&%G(&]P<FEN9&5L:6<@8F5S:V5D(&D@96X@8F5S=F%R96QS93\B
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,2!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HQ,S`*;7-G:60@(DEN9F\B"FUS9W-T
M<B`B26YF;R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(DEN
M9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B26YF;W)M871I
M;VX@;VT@)7,@;V9F96YT;&EG(&[X9VQE(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<W"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S;VYA;"!0<FEV
M871E($ME>2(*;7-G<W1R("));F9O<FUA=&EO;B!O;2!E9V5N+"!P<FEV871E
M(&[X9VQE(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E
M<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B26YF;W)M871I;VX@;VT@96=E
M;BP@;V9F96YT;&EG(&[X9VQE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T
M86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4P-PHC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY.`IM
M<V=I9"`B26YL:6YE(@IM<V=S='(@(DEN9&QE:G)E="(*"B,Z('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF
M:6-A=&4@2&5R92(*;7-G<W1R("));F1SYG0@8V5R=&EF:6MA="!H97(B"@HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED("));G-E
M<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T<B`B26YD
M<^9T(&5G96XL('!R:79A="!01U`M;OAG;&4@:&5R(@H*(SH@=&5M<&QA=&5S
M+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T(%!E<G-O;F%L
M(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B26YD<^9T(&5G96XL(&]F
M9F5N=&QI9R!01U`M;OAG;&4@:&5R(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHU"FUS9VED("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R
M92(*;7-G<W1R("));F1SYG0@;V9F96YT;&EG(%!'4"UN^&=L92!H97(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED
M($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@
M(E5G>6QD:6<@:&%N9&QI;F<@=F%L9W0@9F]R(&1E;FYE(&MO;7!O;F5N="XB
M"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O>"YP:'`Z-C(V"FUS9VED("))
M;G9A;&ED($%D9')E<W,B"FUS9W-T<B`B56=Y;&1I9R!A9')E<W-E(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M
M;W1E($UA:6QB;W@B"FUS9W-T<B`B56=Y;&1I9R!F:F5R;B!B<F5V8F%K:V4B
M"@HC.B!C;VUP;W-E+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV
M86QI9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R
M(")59WEL9&EG="!T96=N(&D@92UM86EL+6%D<F5S<V4Z("5S+B(*"B,Z('-M
M:6UE+G!H<#HX,B!P9W`N<&AP.C$V"FUS9VED("));G9A;&ED(&ME>2(*;7-G
M<W1R(")59WEL9&EG(&[X9VQE(@H*(SH@<&=P+G!H<#HQ.38*;7-G:60@(DEN
M=F%L:60@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R(")59WEL
M9&EG(&5G96XL('!R:79A="!01U`M;OAG;&4N(@H*(SH@<&=P+G!H<#HQ-S$*
M;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN(@IM<V=S
M='(@(E5G>6QD:6<@96=E;BP@;V9F96YT;&EG(%!'4"UN^&=L92XB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R"FUS9VED("));G9E<G0B
M"FUS9W-T<B`B26YV97)TZ7(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S='(@(DM"(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R
M(").^&=L96SF;F=D92(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*
M;7-G:60@(B(*(DME>2!G96YE<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE
M('1O(&-O;7!L971E+B`@0V]N=&EN=64@=VET:"!K97D@(@HB9V5N97)A=&EO
M;C\B"FUS9W-T<B`B(@HB3OAG;&4M9V5N97)E<FEN9R!K86X@=&%G92!M96=E
M="!L86YG('1I9"X@($9O<G1SYG0@;65D(&[X9VQE+6=E;F5R97)I;F<_(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS-2!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,S<*;7-G:60@(DME>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L
M92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R!S97)V97(N
M(@IM<V=S='(@(B(*(D[X9VQE+6EM<&]R=&5R:6YG(&EK:V4@=&EL9^9N9V5L
M:6<N("!(96YT;FEN9R!A9B!F:6QE<B!E<B!I:VME(&%K=&EV97)E="!PY2`B
M"B)D96YN92!S97)V97(N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHS-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,SD*;7-G:60@(B(*(DME>2!I
M;7!O<G0@:7,@;F]T(&%V86EL86)L92X@66]U(&AA=F4@;F\@861D<F5S<R!B
M;V]K(&1E9FEN960@=&\@861D('EO=7(@(@HB8V]N=&%C=',N(@IM<V=S='(@
M(B(*(D[X9VQE+6EM<&]R=&5R:6YG(&EK:V4@=&EL9^9N9V5L:6<N($1U(&AA
M<B!I:VME(&1E9FEN97)E="!N;V=E="`B"B)A9')E<W-E:V%R=&]T96LL(&AV
M;W(@9&EN92!K;VYT86MT97(@=&EL('1I;&;X:F5S+B(*"B,Z('!G<"YP:'`Z
M,S$X"FUS9VED(")+97D@<W5C8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(D[X9VQE(&5R('-E;F1T('1I;"!O9F9E
M;G1L:6<@;OAG;&4M<V5R=F5R+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C$V"FUS9VED("),86YG=6%G92(*;7-G<W1R(")3<')O9R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#8*;7-G:60@(DQA<W0@36%I;&)O
M>"!086=E(@IM<V=S='(@(E-I9'-T92!E+6UA:6P@<VED92(*"B,Z(&UA:6QB
M;W@N<&AP.C,U.`IM<V=I9"`B3&%S="!086=E(@IM<V=S='(@(E-I9'-T92!S
M:61E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@Y"FUS
M9VED("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R(")2969E<NER('9E9&CF
M9G1E;'-E<B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H
M<#HQ,#8S"FUS9VED("),:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E
M;BXB"FUS9W-T<B`B4F5F97)E<F5D92!V961HYF9T96QS97(@97(@9F]R8G5D
M="XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3`X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("),:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R(")(96YV:7-N
M:6YG97(@=61L^&)E<B!D96X@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`X,@IM<V=I9"`B(@HB3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D
M:6YG('1H92!C;VYT86-T<R!S8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I
M;&P@(@HB;VYL>2!S964@8V]N=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E
M>'!L:6-I=&QY*2(*;7-G<W1R("(B"B),:7-T(&%L;&4@:V]N=&%K=&5R+"!N
MY7(@:V]N=&%K="US:61E;B!H96YT97,_("AH=FES('-LY65T(&9R82!V:6P@
M9'4@:W5N('-E("(*(F1E(&MO;G1A:W1E<BP@<V]M(&1U('/X9V5R(&5F=&5R
M*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#4*;7-G:60@(DQI<W1I
M;F<@:6X@=&AE($AE861E<B(*;7-G<W1R(")&;W)T96=N96QS92!I8FQA;F1T
M(&)R979H;W9E9&5R;F4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,S`*;7-G:60@(DQO8V%L($UA:6QB;W@Z(@IM<V=S='(@(DQO:V%L
M('!O<W1K87-S92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-S0*
M;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E-T960B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(DQO
M9R!I;F0B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3$U"B,L('!H<"UF
M;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*;7-G<W1R("),;V<@:6YD('#E
M("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S<*;7-G:60@
M(DQO9VEN(@IM<V=S='(@(DQO9R!I;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(DQO9VEN+6]P
M9V%V97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.38*
M;7-G:60@(DQO=R(*;7-G<W1R("),878B"@HC.B!M97-S86=E+G!H<#HR.3D@
M;6%I;&)O>"YP:'`Z-S(W('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M,3,*;7-G:60@(DQO=R!0<FEO<FET>2(*;7-G<W1R("),878@<')I;W)I=&5T
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED
M("),;W=E<W0B"FUS9W-T<B`B3&%V97-T92(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#0*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM
M<V=S='(@(DUA8VEN=&]S:"UF:6PB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S
M<W!H<F%S92YI;F,Z,3,*;7-G:60@(DUA:6PB"FUS9W-T<B`B36%I;"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B36%I;"!0<F5V:65W
M<R(*;7-G<W1R(")%+6UA:6P@9VQI;70B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V1R:79E<E]S96QE8W0N:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T
M>7!E('1O(&-O;FYE8W0@=&\Z(@IM<V=S='(@(E1Y<&4@868@;6%I;"US97)V
M97(@870@9F]R8FEN9&4@=&EL.B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I
M9"`B36%I;&)O>"(*;7-G<W1R(")-86EL8F]X(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q,0IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R("));F1S=&EL;&EN9V5R;F4@9F]R(&4M;6%I
M;"T@;V<@;6%P<&4M=FES;FEN9R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C$X"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD
M97(@87,@4V5E;B(*;7-G<W1R(")-87)KZ7(@86QL92!B97-K961E<B!I(&UA
M<'!E('-O;2!S970B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHQ.0IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%5N
M<V5E;B(*;7-G<W1R(")-87)KZ7(@86QL92!B97-K961E<B!I(&UA<'!E('-O
M;2!U<V5T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E
M+FEN8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S`*;7-G:60@
M(DUA<FL@87,Z(@IM<V=S='(@(DUA<FME<B!S;VTZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8U,`IM<V=I9"`B36%R:R!D:69F97)E;G0@;&5V96QS
M(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S/R(*;7-G<W1R(")-
M87)KZ7(@9F]R<VME;&QI9V4@8VET870M;FEV96%U97(@;65D(&9O<G-K96QL
M:6=E(&9A<G9E<C\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@*$E-05`@;VYL
M>2DB"FUS9W-T<B`B36%R:^ER(&)E<VME9"!S;VT@<V5T/R`H2W5N($E-05`I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U.`IM<V=I9"`B36%R:R!S
M:6UP;&4@;6%R:W5P/R(*;7-G<W1R(")-87)KZ7(@<VEM<&QI9FEC97)E="!O
M<&WF<FMN:6YG/R(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT
M-@IM<V=I9"`B36%T8V@@06QL(%%U97)I97,B"FUS9W-T<B`B4&%S<V5R('1I
M;"!A;&QE(&9O<F5S</AR9W-L97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R(")0
M87-S97(@=&EL(&YO9V5N(&%F(&9O<F5S</AR9W-L97)N92(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PIM<V=I9"`B36%X:6UU;2!!
M='1A8VAM96YT(%-I>F4B"FUS9W-T<B`B4W3X<G)E;'-E('#E('-T^')S=&4@
M=F5D:.9F=&5L<V4B"@HC.B!L:6(O87!I+G!H<#HW.0IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@1F]L9&5R<R(*;7-G<W1R(")-86MS:6UA;'0@86YT86P@
M;6%P<&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DT
M"FUS9VED(")-87AI;75M(&YU;6)E<B!O9B!A='1A8VAM96YT<R!R96%C:&5D
M+B(*;7-G<W1R(")-86MS:6UA;'0@86YT86P@=F5D:.9F=&5L<V5R(&[E970N
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@Y"FUS9VED
M(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*;7-G
M<W1R(")-86MS:6UA;'0@=&]T86P@<W3X<G)E;'-E(&%F('9E9&CF9G1E;'-E
M(&[E970N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-@IM<V=I
M9"`B365E=&EN9R!#86YC96QL871I;VXB"FUS9W-T<B`B069L>7-N:6YG(&%F
M(&WX9&4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<U"FUS9VED
M(")-965T:6YG($EN9F]R;6%T:6]N(@IM<V=S='(@(DWX9&4M:6YF;W)M871I
M;VXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@U"FUS9VED(")-
M965T:6YG(%!R;W!O<V%L(@IM<V=S='(@(DWX9&4M9F]R<VQA9R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3<*;7-G:60@(DUE971I;F<@4F5P
M;'DB"FUS9W-T<B`B3?AD92US=F%R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Y.`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T<B`B3?AD
M92UO<&1A=&5R:6YG(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P
M,PIM<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R(")!;FUO
M9&YI;F<@;VT@;W!D871E<FEN9R!A9B!M^&1E(@H*(SH@;&EB+T)L;V-K+W1R
M965?9F]L9&5R<RYP:'`Z,PIM<V=I9"`B365N=2!&;VQD97(@3&ES="(*;7-G
M<W1R(")-96YU+6UA<'!E+6QI<W1E(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S
M,0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")"97-K960B"@HC.B!C;VUP;W-E
M+G!H<#HU-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O<V4N<&AP.C8T,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S:71I
M;VXB"FUS9W-T<B`B4VMR:79N:6YG(&%F(&YY(&)E<VME9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,3<*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G
M<W1R(")$871O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`S"FUS9VED(")-97-S
M86=E($]P=&EO;G,B"FUS9W-T<B`B0F5S:V5D+6EN9'-T:6QL:6YG97(B"@HC
M.B!S96%R8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T
M<B`B4_AG;FEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C$*;7-G
M:60@(DUE<W-A9V4@4VEZ92(*;7-G<W1R(")3=/AR<F5L<V4B"@HC.B!M97-S
M86=E+G!H<#HS.#0*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(D]P
M<FEN9&5L<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@
M(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R(")6:7-N:6YG(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-97-S86=E(&9L86=S(@IM
M<V=S='(@(DUA<FME<FEN9V5R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM<V=S='(@(DUA<'!E
M<B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365S<V%G92!F<F]M("5S(@IM<V=S='(@(D)E<VME9"!F<F$@)7,B"@HC
M.B!M86EL8F]X+G!H<#HV-C<*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C:&UE
M;G1S(@IM<V=S='(@(D)E<VME9"!H87(@=F5D:.9F=&5L<V5R(@H*(SH@;6%I
M;&)O>"YP:'`Z-C4X"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E9"(*;7-G
M<W1R(")"97-K960@97(@:W)Y<'1E<F5T(@H*(SH@;6%I;&)O>"YP:'`Z-C4S
M"FUS9VED(")-97-S86=E(&ES('-I9VYE9"(*;7-G<W1R(")"97-K960@97(@
M<VEG;F5R970B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S,*
M;7-G:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R(")"97-K960@<&%S<V5R
M(@H*(SH@8V]M<&]S92YP:'`Z.#(T(&-O;7!O<V4N<&AP.C@S.`IM<V=I9"`B
M365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B0F5S
M:V5D(&]M861R97-S97)E="XB"@HC.B!C;VUP;W-E+G!H<#HQ,#@T"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U
M="!N;W0@<V%V960@=&\@)7,B"FUS9W-T<B`B0F5S:V5D96X@8FQE=B!S96YD
M="P@;65N(&MU;FYE(&EK:V4@9V5M;65S(&D@)7,B"@HC.B!C;VUP;W-E+G!H
M<#HQ,30S(&-O;7!O<V4N<&AP.C$Q-3@*;7-G:60@(DUE<W-A9V4@<V5N="!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(D)E<VME9&5N(&5R('-E;F1T+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE<W-A9V5S('!E
M<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@(D)E<VME9&5R
M('!E<B!S:61E(&D@;6%I;&)O>'9I<VYI;F=E;BXB"@HC.B!M86EL8F]X+G!H
M<#HS,C(*;7-G:60@(DUE<W-A9V5S('1O(@IM<V=S='(@(D)E<VME9&5R('1I
M;"(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I9"`B36]D:69Y
M(@IM<V=S='(@(L9N9')E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD
M+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E('1H86X@;VYE(&%D
M9')E<W,@9F]U;F0@9F]R(&9I96QD(%PB)7-<(BXB"FUS9W-T<B`B1&5R(&)L
M978@9G5N9&5T(&9L97)E(&5N9"#I;B!A9')E<W-E(&9O<B!F96QT970@7"(E
M<UPB+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM<V=I9"`B
M36]V92(*;7-G<W1R(")&;'ET(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C
M97-E;&5C="YI;F,Z,S$V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1FQY
M="!N960B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$X"FUS9VED(")-
M;W9E('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT
M(&UE<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(D9L>70@<W!A;2UB97-K961E
M<B!T:6P@<W!A;2UM87!P92!O9R!O<F1E;G1L:6=E(&)E<VME9&5R('1I;"!)
M;F1B86MK92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM<V=I
M9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B5N9L9R!M87!P92(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-`IM<V=I9"`B36]V
M92!U<"(*;7-G<W1R(")&;'ET(&]P(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L
M=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E<FYA=&EV
M92(*;7-G<W1R(")-=6QT:7!A<G0O86QT97)N871I=F4B"@HC.B!T:')E860N
M<&AP.C<V('1H<F5A9"YP:'`Z,34R"FUS9VED(")-=6QT:7!L92!-97-S86=E
M(%9I97<B"FUS9W-T<B`B5FES;FEN9VD@;65D(&UU;'1I<&QE(&)E<VME9&5R
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC
M.C4*;7-G:60@(DY/3D4B"FUS9W-T<B`B24Y'14XB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED(").3U1%
M(@IM<V=S='(@(D)%3<922R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G
M:60@(DYA;64B"FUS9W-T<B`B3F%V;B(*"B,Z('!G<"YP:'`Z,3$P"FUS9VED
M(").86UE(&%N9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@
M(DYA=FX@;V<O96QL97(@92UM86EL(&MA;B!I:VME(';F<F4@=&]M;64B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<X"FUS9VED(").965D<R!!
M8W1I;VXB"FUS9W-T<B`B2&%N9&QI;F<@;OAD=F5N9&EG(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@R
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S@*;7-G:60@(DYE=F5R(@IM
M<V=S='(@(D%L9')I9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C`*
M;7-G:60@(DYE=F5R('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B1V5M(&%L
M9')I9R!V961HYF9T96QS97(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M,3(T"FUS9VED(").97<B"FUS9W-T<B`B3GDB"@HC.B!L:6(O24U0+G!H<#HU
M-C,*;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T<B`B3GD@;6%P<&4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#@*;7-G:60@(DYE=R!-86EL(@IM<V=S
M='(@(DYY92!B97-K961E<B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ
M.2!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS,PHC+"!F=7IZ>0IM<V=I
M9"`B3F5W($UE<W-A9V4B"FUS9W-T<B`B3GEE(&)E<VME9"(*"B,Z(&UA:6QB
M;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B3GEE(&)E
M<VME9&5R('1I;"`E<R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R(").>64@8F5S:V5D97(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S"FUS9VED
M(").97AT(@IM<V=S='(@(D[F<W1E(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHS,PIM<V=I9"`B3F5X="!-97-S86=E(@IM
M<V=S='(@(D[F<W1E(&)E<VME9"(*"B,Z(&UA:6QB;W@N<&AP.C,U-@IM<V=I
M9"`B3F5X="!086=E(@IM<V=S='(@(D[F<W1E('-I9&4B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#(@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDW-PIM<V=I9"`B3F\B"FUS9W-T<B`B3F5J(@H*(SH@<VUI;64N<&AP
M.C(R-@IM<V=I9"`B3F\@0V5R=&EF:6-A=&4@9F]U;F0B"FUS9W-T<B`B26YT
M970@8V5R=&EF:6MA="!F=6YD970B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T
M<B`B26YG96X@:W)Y<'1E<FEN9R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I;B!+97ER:6YG(@IM<V=S='(@(DEN9V5N
M(&[X9VQE<B!I(&[X9VQE<FEN9R(*"B,Z(&UA:6QB;W@N<&AP.C,W-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*;7-G<W1R("));F=E;B!B
M97-K961E<B(*"B,Z('!G<"YP:'`Z,3,W"FUS9VED(").;R!01U`@<'5B;&EC
M(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B26YG96X@;V9F96YT;&EG(%!'4"UN
M^&=L92!I;7!O<G1E<F5T+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC871E(%!R97-E;G0B
M"FUS9W-T<B`B16=E="!C97)T:69I:V%T(&9O<F5F:6YD97,@:6MK92(*"B,Z
M(&QI8B]-86EL8F]X+G!H<#HS,CD*;7-G:60@(DYO(%!R979I97<@5&5X="(*
M;7-G<W1R("));G1E="!T96MS="UG;&EM="(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,34*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM
M<V=S='(@(DEN9V5N(&]F9F5N=&QI9V4@;OAG;&5R(&9U;F1E="(*"B,Z('-M
M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L:6,@:V5Y(&EM<&]R
M=&5D+B(*;7-G<W1R("));F=E;B!O9F9E;G1L:6=E(%,O34E-12UN^&=L97(@
M:6UP;W)T97)E="XB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3`*
M;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R("));F=E;B!V
M961HYF9T96QS97(@9G5N9&5T+B(*"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z
M,30P"FUS9VED(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H
M92!P=6)L:6,@:V5Y+B(*;7-G<W1R("));F=E;B!E+6UA:6PM:6YF;W)M871I
M;VX@;&]K86QI<V5R970@:2!O9F9E;G1L:6<@;OAG;&4N(@H*(SH@86-L+G!H
M<#HW,B!A8VPN<&AP.CDX"FUS9VED(").;R!F;VQD97(@<V5L96-T960N(@IM
M<V=S='(@(DEN9V5N(&UA<'!E('9A;&=T+B(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ-#$*;7-G:60@(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K
M960@9F]R(&YE=R!M86EL+B(*;7-G<W1R("));F=E;B!M87!P97(@8FQI=F5R
M(&-H96-K970@9F]R(&YY('!O<W0N(@H*(SH@9F]L9&5R<RYP:'`Z,C$X(&QI
M8B]&;VQD97(N<&AP.C4P,"!L:6(O1F]L9&5R+G!H<#HU-3`*;7-G:60@(DYO
M(&9O;&1E<G,@=V5R92!S<&5C:69I960B"FUS9W-T<B`B26YG96X@;6%P<&5R
M(&%N9VEV970B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30W"FUS9VED
M(").;R!F;VQD97)S('=I=&@@;F5W(&UE<W-A9V5S(@IM<V=S='(@(DEN9V5N
M(&UA<'!E<B!M960@;GEE(&)E<VME9&5R(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$T-`IM<V=I9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S
M86=E<R(*;7-G<W1R("));F=E;B!M87!P97(@;65D('5LYG-T92!B97-K961E
M<B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,C4*;7-G:60@(DYO(&UE<W-A9V4@
M8F]D>2!T97AT(@IM<V=S='(@(DEN9V5N(&)R^&1T96MS="(*"B,Z(&QI8B]-
M86EL8F]X+G!H<#HS-S$*;7-G:60@(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U
M<B!S96%R8V@N(@IM<V=S='(@(D1I;B!S^&=N:6YG(&=A=B!I;F=E;B!B97-K
M961E<B(*"B,Z('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P97)S;VYA;"!01U`@
M<')I=F%T92!K97D@:6UP;W)T960N(@IM<V=S='(@(DEN9V5N(&5G96XL('!R
M:79A="!01U`M;OAG;&4@:6UP;W)T97)E="XB"@HC.B!P9W`N<&AP.C$V-0IM
M<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM
M<V=S='(@(DEN9V5N(&5G96XL(&]F9F5N=&QI9R!01U`M;OAG;&4@:6UP;W)T
M97)E="XB"@HC.B!S;6EM92YP:'`Z,C`Q"FUS9VED(").;R!P97)S;VYA;"!3
M+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G<W1R("));G1E="!E
M9V5T(%,O34E-12UC97)T:69I8V%T(&EM<&]R=&5R970N(@H*(SH@<W!E;&QI
M;F<N<&AP.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O
M;F9I9W5R960N(@IM<V=S='(@(D1E<B!E<B!I:VME(&MO;F9I9W5R97)E="!N
M;V=E="!P<F]G<F%M('1I;"!S=&%V96MO;G1R;VPN(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(").;R!S<&5L;&EN9R!E
M<G)O<G,B"FUS9W-T<B`B26YG96X@<W1A=F5F96IL(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P,`IM<V=I9"`B3F\@<W5G9V5S=&EO
M;G,B"FUS9W-T<B`B26YG96X@9F]R<VQA9R(*"B,Z(&QI8B])34%0+T-L:65N
M="YP:'`Z-38T"FUS9VED(").;R!S=7!P;W)T960@24U!4"!A=71H96YT:6-A
M=&EO;B!M971H;V0@8V]U;&0@8F4@9F]U;F0N(@IM<V=S='(@(DEN9V5N('5N
M9&5R<W3X='1E="!)34%0(.9G=&YI;F=S;65T;V1E(&9U;F1E="XB"@HC.B!A
M8VPN<&AP.C8X(&%C;"YP:'`Z.30*;7-G:60@(DYO('5S97(@<W!E8VEF:65D
M+B(*;7-G<W1R("));F=E;B!B<G5G97(@86YG:79E="XB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S`Y"FUS9VED(").;VX@4&%R=&EC:7!A;G0B
M"FUS9W-T<B`B16H@9&5L=&%G97(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C$Q('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI
M;F,Z-#`*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S4@
M=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@(DYO;F4B"FUS9W-T<B`B26YG
M96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.34*;7-G
M:60@(DYO<FUA;"(*;7-G<W1R(").;W)M86PB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S='(@(DEK:V4@<VQE='1E
M="(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@1')A9G0B"FUS
M9W-T<B`B26MK92!K;&%D9&4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHQ-PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,T"FUS9VED
M(").;W0@26UP;W)T86YT(@IM<V=S='(@(DEK:V4@=FEG=&EG="(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*;7-G:60@(DYO="!097)S
M;VYA;"(*;7-G<W1R(")):VME('!E<G-O;FQI9W0B"@HC.B!L:6(O0W)Y<'0O
M4$=0+G!H<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@;&EB+T-R>7!T
M+U--24U%+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A;&ED('!U8FQI8R!K97DN
M(@IM<V=S='(@(DEK:V4@96X@9WEL9&EG(&]F9F5N=&QI9R!N^&=L92(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-C<*;7-G:60@(DYO="!D96QE
M=&5D(&UE<W-A9V5S(@IM<V=S='(@(DEK:V4@<VQE='1E9&4@8F5S:V5D97(B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED(").;W0@
M:6UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(DEK:V4@=FEG=&EG92!B97-K
M961E<B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I
M;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@
M=&EM92(*;7-G<W1R(")"96WF<FL@870@9&5T=&4@:V%N('1A9V4@<VEN('1I
M9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,38*;7-G:60@(DYO=&AI
M;F<B"FUS9W-T<B`B26YG96YT:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-PIM<V=I9"`B3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L
M:6YK960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T
M<B`B(@HB06YT86P@;>5N961E<B!R969E<F5R961E('9E9&CF9G1E;'-E<B!S
M:V%L(&=E;6UE<RP@;N5R(&1E<B!S;&5T=&5S(&WE;F5D;&EG="XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"FUS9VED(").=6UB97(@;V8@;VQD
M('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL
M>2XB"FUS9W-T<B`B(@HB06YT86P@868@9V%M;&4@;6%P<&5R(&9O<B!S96YD
M="!E+6UA:6PL(&1E<B!S:V%L(&)E:&]L9&5S+"!NY7(@9&5R('-L971T97,@
M(@HB;>5N961L:6<N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR-30@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4U,@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S,S"FUS9VED(")/2R(*;7-G<W1R(")/
M2R(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.0HC.B!T96UP;&%T97,O<&=P+VEM
M<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*;7-G<W1R(")%3$Q%4B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,34*;7-G:60@(D]L9"!M97-S
M86=E<R(*;7-G<W1R(")'86UL92!B97-K961E<B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HU,@IM<V=I
M9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"XB"FUS9W-T
M<B`B1V%M;&4@;6%P<&5R(&UE9"!S96YD="!E+6UA:6P@8FQI=F5R(&9J97)N
M970N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(U"FUS9VED(")/;FQY
M(&1I<W!L87D@9F]L9&5R<R!W:71H('5N<F5A9"!M97-S86=E<R!I;B!T:&5M
M/R(*;7-G<W1R(")6:7,@:W5N(&UA<'!E<B!M960@=6SF<W1E(&)E<VME9#\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"FUS9VED
M(")/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES
M(&%C=&EO;BXB"FUS9W-T<B`B5N9L9R!V96YL:6=S="!K=6X@96X@;6%P<&4@
M9F]R(&1E;FYE(&AA;F1L:6YG+B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ
M,"!T96UP;&%T97,O;65N=2YI;F,Z,S`*;7-G:60@(D]P96X@1F]?;&1E<B(*
M;7-G<W1R("+%8F5N(&UA<'!E(@H*(SH@9F]L9&5R<RYP:'`Z-#(W"FUS9VED
M(")/<&5N960@1F]L9&5R(@IM<V=S='(@(L5B;F5T(&UA<'!E(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<P-0IM<V=I9"`B3W!T:6]N86P@4&%R
M=&EC:7!A;G0B"FUS9W-T<B`B5F%L9V9R:2!D96QT86=E<B(*"B,Z(&9E=&-H
M;6%I;"YP:'`Z,S,@=&5M<&QA=&5S+V9E=&-H;6%I;"]T;W`N:6YC.C,*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C8*;7-G:60@(D]T
M:&5R($UA:6P@06-C;W5N=',B"FUS9W-T<B`B06YD<F4@;6%I;"UK;VYT:2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/
M<'1I;VYS(@IM<V=S='(@(D%N9')E(&EN9'-T:6QL:6YG97(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,0IM<V=I9"`B3W5T8F]U;F0@4V5R
M=F5R(@IM<V=S='(@(E5D9^5E;F1E('-E<G9E<B(*"B,Z('1E;7!L871E<R]P
M9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,38U"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-"!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR.3`*;7-G:60@(E!'4"(*;7-G<W1R(")01U`B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*;7-G:60@
M(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B4$=0+6MR>7!TZ7(@8F5S
M:V5D(@H*(SH@8V]M<&]S92YP:'`Z,S4X"FUS9VED(")01U`@17)R;W(Z("(*
M;7-G<W1R(")01U`M9F5J;#H@(@H*(SH@8V]M<&]S92YP:'`Z,S,W"FUS9VED
M(")01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I
M=F%T92!K97DN(@IM<V=S='(@(E!'4"UF96IL.B!"96CX=F5R(&SX<V5N(&9O
M<B!E9V5N+"!P<FEV870@;OAG;&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B4$=0+6EN9'-T
M:6QL:6YG97(B"@HC.B!P9W`N<&AP.C,P"FUS9VED(")01U`@4&%S<W!H<F%S
M92!);G!U="(*;7-G<W1R("));F1T87-T;FEN9R!A9B!01U`M;/AS96XB"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA
M;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN(@IM<V=S='(@(E5N9&5R<W3X='1E;'-E(&%F(&5G;F4@4$=0+6[X
M9VQE<^9T(&MRYG9E<B!S:6MK97(@=V5B+69O<F)I;F1E;'-E+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PIM<V=I9"`B4$=0(%!U8FQI8R!+
M97D@5&5X="(*;7-G<W1R(")/9F9E;G1L:6<@4$=0+6[X9VQE=&5K<W0B"@HC
M.B!P9W`N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC
M($ME>2!F;W(@7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB
M"FUS9W-T<B`B3V9F96YT;&EG(%!'4"UN^&=L92!F;W(@7"(E<R`H)7,I7"(@
M=&EL9OAJ970N(@H*(SH@<&=P+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY
M(&1E;&5T960N(@IM<V=S='(@(D]F9F5N=&QI9R!01U`M;OAG;&4@9F]R(%PB
M)7-<(B!T:6QF^&IE="XB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")/9F9E;G1L:6<@
M4$=0+6[X9VQE<FEN9R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?
M;&ES="YI;F,Z.`IM<V=I9"`B4$=0(%-I9VX@365S<V%G92(*;7-G<W1R(")0
M1U`M<VEG;NER(&)E<VME9"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y
M<'1?;&ES="YI;F,Z.0IM<V=I9"`B4$=0(%-I9VXO16YC<GEP="!-97-S86=E
M(@IM<V=S='(@(E!'4"US:6=NZ7(O:W)Y<'3I<B!B97-K960B"@HC.B!P9W`N
M<&AP.C(P,@IM<V=I9"`B4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A
M9&1E9"XB"FUS9W-T<B`B4')I=F%T92!01U`M;OAG;&4@=&EL9OAJ970N(@H*
M(SH@<&=P+G!H<#HQ-S<*;7-G:60@(E!'4"!P=6)L:6,@:V5Y('-U8V-E<W-F
M=6QL>2!A9&1E9"XB"FUS9W-T<B`B3V9F96YT;&EG(%!'4"UN^&=L92!T:6QF
M^&IE="XB"@HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I
M9"`B4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM
M<V=S='(@(E5N9&5R<W3X='1E;'-E(&%F(%!'4"!E<B!S;.5E="!F<F$@<.4@
M9&5T=&4@<WES=&5M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P
M.`IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I
M=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B
M"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB56YD97)S=/AT=&5L<V4@868@4$=0
M(&5R(&D@^&IE8FQI:VME="!S;.5E="!F<F$@<^4@9&5N(&1I9VET86QE('-I
M9VYA='5R(&MA;B`B"B)I:VME('9E<FEF:6-E<F5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I9"`B(@HB4$=0('-U<'!O<G0@:7,@
M;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE
M('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB4$=0+75N9&5R<W3X='1E
M;'-E(&5R(&EK:V4@86MT:79E<F5T+"!SY2!B97-K961E;B!K86X@:6MK92!D
M96MR>7!T97)E<RXB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I
M9"`B(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B
M92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2`B"B)S970@
M=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI
M<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F96%T=7)E<R!W:6QL(&YO
M="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB56YD97)S=/AT=&5L<V4@
M868@4$=0(&MRYG9E<B!A;G9E;F1E;'-E(&%F('!O<'5P+79I;F1U97(N("!(
M=FES(&1I;B!B<F]W<V5R("(*(F5R('-A="!T:6P@870@9F]R:&EN9')E('!O
M<'5P+79I;F1U97(@8FQI=F5R(&1U(&[X9'0@=&EL(&%T(.9N9')E(&]P<^9T
M;FEN9R`B"B)F;W(@870@4$=0+69A8VEL:71E=&5R;F4@:V%N('9I<FME<B!K
M;W)R96MT+B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS9VED
M(")03U`S(@IM<V=S='(@(E!/4#,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*
M;7-G<W1R(")03U`S("AB97-T96UT('!R;W1O:V]L;&5R(&%U=&]M871I<VLI
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3<*;7-G:60@(E!/4#,@
M;W9E<B!34TPB"FUS9W-T<B`B4$]0,R!O=F5R(%-33"(*"B,Z(&QI8B]&971C
M:&UA:6PO:6UA<"YP:'`Z,3(S"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF
M+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B4$]0,R!O=F5R(%-33"`H
M<V5L=BUS:6=N97)E="!C97)T:69I:V%T*2(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I
M9VYE9"DB"FUS9W-T<B`B4$]0,R!O=F5R(%-33"`H<V5L=BUS:6=N97)E="DB
M"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q,0IM<V=I9"`B4$]0,RP@
M;F\@5$Q3(@IM<V=S='(@(E!/4#,L(&EN9V5N(%1,4R(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VAE861E<BYI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4&%G92`E9"!O9B`E9"(*;7-G<W1R(")3:61E("5D(&%F("5D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP,PIM<V=I9"`B4&%G92!W:71H('1H92!&
M:7)S="!5;G-E96X@365S<V%G92(*;7-G<W1R(")3:61E(&UE9"!F^')S=&4@
M=7-E=&4@8F5S:V5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-`IM
M<V=I9"`B4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S
M='(@(E-I9&4@;65D('-I9'-T92!U<V5T92!B97-K960B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R="AS*2(*;7-G
M<W1R(")$96PH92DB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS
M9VED(")087-S<&AR87-E(@IM<V=S='(@(DSX<V5N(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$R.`IM<V=I9"`B4&%S<W!H<F%S92`H06=A:6XI(@IM
M<V=S='(@(DSX<V5N("AI9V5N*2(*"B,Z('-M:6UE+G!H<#HR,S4@<&=P+G!H
M<#HS,3`*;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D
M+B(*;7-G<W1R("),^'-E;B!F:F5R;F5T+B(*"B,Z('1E;7!L871E<R]S;6EM
M92]P87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N
M:6YC.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R("),^'-E;CHB"@HC
M.B!P9W`N<&AP.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B92!E
M;7!T>2(*;7-G<W1R("),^'-E;B!K86X@:6MK92!VYG)E('1O;70B"@HC.B!P
M9W`N<&AP.C$Q-`IM<V=I9"`B4&%S<W!H<F%S97,@9&\@;F]T(&UA=&-H(@IM
M<V=S='(@(DSX<V5N97)N92!S:V%L(';F<F4@96YS(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y
M,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B2V]D96]R9"(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`IM<V=I9"`B4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")59&;X
M<B!V961L:6=E:&]L9&5L<V4@=F5D(&QO9R!I;F0_(@H*(SH@86-L+G!H<#HW
M-B!A8VPN<&AP.C$P,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E
M<B!C86X@;F]T(&)E(&-H86YG960N(@IM<V=S='(@(E1I;&QA9&5L<V5R;F4@
M9F]R(&1E;FYE(&)R=6=E<B!K86X@:6MK92#F;F1R97,N(@H*(SH@;65S<V%G
M92YP:'`Z-#DS(&UA:6QB;W@N<&AP.C<P,R!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(T"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M,3`*;7-G:60@(E!E<G-O;F%L(@IM<V=S='(@(E!E<G-O;FQI9R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-`IM<V=I9"`B4&5R<V]N86P@26YF;W)M
M871I;VXB"FUS9W-T<B`B4')O9FEL97(B"@HC.B!P9W`N<&AP.C$R,`IM<V=I
M9"`B4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`B16=E;B!01U`M;OAG;&5P87(@9V5N97)E<F5T(&UE9"!S
M=6-C97,N(@H*(SH@<&=P+G!H<#HQ,C<*;7-G:60@(E!E<G-O;F%L(%!'4"!K
M97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")%9VYE(%!'4"UN
M^&=L97(@<VQE='1E="XB"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")097)S
M;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM<V=S
M='(@(D5G;F4@4R]-24U%+6-E<G1I9FEK871E<B!)2TM%(&EM<&]R=&5R970Z
M("(*"B,Z('-M:6UE+G!H<#HQ,S(*;7-G:60@(E!E<G-O;F%L(%,O34E-12!K
M97ES(&1E;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")%9VYE(%,O34E-
M12UN^&=L97(@<VQE='1E="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C(R"FUS9VED(")0;&%C92!Y;W5R('-I9VYA='5R92!B969O<F4@<F5P;&EE
M<R!A;F0@9F]R=V%R9',_(@IM<V=S='(@(E/F="!D:6X@<VEG;F%T=7(@9F]R
M86X@<W9A<B!O9R!V:61E<F5S96YD96QS97(_(@H*(SH@8V]M<&]S92YP:'`Z
M,C4T"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S
M='(@(E)E;G1E:W-T+75D9V%V92!A9B!B97-K960B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SDY"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M
M86EL/R`@5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E
M;6)E9&1E9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN
M9&]W<R!A;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q
M=6ER92!A('!L=6=I;BXB"FUS9W-T<B`B(@HB069S<&EL(&QY9"!V960@;GD@
M8F5S:V5D/R!$971T92!K<N9V97(L(&%T(&1I;B!B<F]W<V5R('5N9&5R<W3X
M='1E<B`B"B)I;F1L96IR961E(&QY9"UF:6QE<BX@($]M=')E;G0@86QL92!G
M^'(@=6YD97(@5VEN9&]W<R!O9R!-86,L(&UE;B!A;F1R92`B"B)P;&%T9F]R
M;64@:W+F=F5R(&5T('!L=6=I;BXB"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHQ.3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@9F]L9&5R.B(*;7-G<W1R("));F1T87-T('9E;FQI9W-T(&5T(&YA=FX@
M=&EL(&1E;B!N>64@;6%P<&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ,#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ,#0*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W
M(&9O;&1E<CHB"FUS9W-T<B`B26YD=&%S="!V96YL:6=S="!N879N970@=&EL
M(&1E;B!N>64@;6%P<&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L
M9&5R<RYJ<SHQ,S<*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z
M(@IM<V=S='(@(D%N9VEV('9E;FQI9W-T(&1E="!N>64@;F%V;CHB"@HC.B!T
M96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U
M<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"!T;R`B"B)E
M;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS
M9W-T<B`B(@HB26YD=&%S="!V96YL:6=S="!E="!L^'-E;B!T:6P@9&EN('!R
M:79A=&4@4$=0+6[X9VQE+B`@1'4@=FEL(&MU;B!S:W5L;&4@(@HB:6YD=&%S
M=&4@9&5T=&4@;/AS96X@Z6X@9V%N9R`E<R!S97-S:6]N+B(*"B,Z('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@
M4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@(@HB=&\@
M96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM
M<V=S='(@(B(*(DEN9'1A<W0@970@;/AS96X@=&EL(&1I;B!P<FEV871E(%,O
M34E-12UN^&=L92X@($1U('9I;"!K=6X@<VMU;&QE(&EN9'1A<W1E("(*(F1E
M='1E(&SX<V5N(.EN(&=A;F<@<'(@)7,@<V5S<VEO;BXB"@HC.B!R96-O;7!O
M<V4N<&AP.CDW"FUS9VED("(B"B)0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E
M<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U
M<VEN9R`B"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E
M<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O("(*(FQO9R!I
M;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@
M=&\@:V5E<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA8VMI;F<@>6]U<B!S97-S
M:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E+B(*
M;7-G<W1R("(B"B),;V<@:6YD(&EG96X@9F]R(&%T(&9O<G1SYG1T92!S:W)I
M=FYI;F<N("!(=FES(&1U($E+2T4@8F5N>71T97(@8V]O:VEE<R!/1R`B"B)D
M=2!S:W)I=F5R(&D@970@<&]P=7`M=FEN9'5E+"!S:V%L(&1U(&]G<^4@;&]G
M9V4@:6YD(&D@9&ET(&AO=F5D+79I;F1U92X@(@HB1&5T=&4@97(@;OAD=F5N
M9&EG="!F;W(@870@9F]R:&EN9')E(&%N9W)I8F5R92!I(&%T(&MA8G)E(&1I
M="!S97-S:6]N+4E$+B!6:2`B"B)B96ML86=E<B!PY6;X<G1E('5L96UP97(N
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,0IM<V=I9"`B4&QE
M87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"XB"FUS9W-T<B`B26YD=&%S="!V
M96YL:6=S="!D:70@:V]D96]R9"XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C8W"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M+B(*;7-G<W1R("));F1T87-T('9E;FQI9W-T(&1I="!B<G5G97)N879N+B(*
M"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O24U0+G!H<#HT-3D*;7-G:60@(E!L
M96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB
M"FUS9W-T<B`B4F5T('9E;FQI9W-T(&1E;B!U='ED:6=E(&5L;&5R('5G>6QD
M:6=E(&%D<F5S<V4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8T
M,@IM<V=I9"`B(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R
M;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*
M(FUE;G4@8F5L;W<N(@IM<V=S='(@(D=E;FYE;6?E(&;X;&=E;F1E(&EN9F]R
M;6%T:6]N(&]G(';F;&<@96X@:&%N9&QI;F<@9G)A(&UE;G5E;B!N961E;F9O
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C8Q"FUS
M9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R
M;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B1'4@<VMA;"!VYFQG92!E;B!M87!P
M92P@9OAR(&1U(&MA;B!U9&;X<F4@96X@:&%N9&QI;F<N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4P,@IM<V=I9"`B4&QE87-E('-E;&5C="!A
M;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T<B`B5N9L9R!V
M96YL:6=S="!E;B!H86YD;&EN9R!F<F$@;65N=65N(&YE9&5N9F]R+B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L
M96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM
M<V=S='(@(E;F;&<@;6EN9'-T(&5N(&UA<'!E+"!S;VT@9'4@=FEL('/X9V4@
M:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS
M9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O
M<&5R871I;VXN(@IM<V=S='(@(E;F;&<@=F5N;&EG<W0@:W5N(&5N(&UA<'!E
M(&9O<B!D96YN92!O<&=A=F4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C<S"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@
M=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E;F;&<@=F5N;&EG<W0@
M96QL97(@<F5D:6=E<B!I(&)O:W-E;B!T:6P@:/AJ<F4Z(@H*(SH@8V]N9FEG
M+VUO=&0N<&AP+F1I<W0Z-#$*;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS
M9W-T<B`B4&]W97)E9"!B>2!(;W)D92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,30*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D
M87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B4^9T(&)I;F1E<W1R96=E<B`H)RTM
M("<I(&9O<F%N(&1I;B!S:6=N871U<C\B"@HC.B!S;6EM92YP:'`Z,C0Q('!G
M<"YP:'`Z,C4W(&9I;'1E<G!R969S+G!H<#HT,`IM<V=I9"`B4')E9F5R96YC
M97,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S='(@(E!RYF9E<F5N8V5R
M;F4@;W!D871E<F5T+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FEN8SHS"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D=L:6UT(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR.`IM<V=I
M9"`B4')E=FEO=7,@365S<V%G92(*;7-G<W1R(")&;W)R:6=E(&)E<VME9"(*
M"B,Z(&UA:6QB;W@N<&AP.C,T-PIM<V=I9"`B4')E=FEO=7,@4&%G92(*;7-G
M<W1R(")&;W)R:6=E('-I9&4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@(E5D<VMR
M:78B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHS.`IM<V=I
M9"`B4')I;W)I='DB"FUS9W-T<B`B4')I;W)I=&5T(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<V"FUS9VED(")0<FEV871E($ME>2!0
M87-S=V]R9"(*;7-G<W1R(")+;V1E;W)D('1I;"!P<FEV870@;OAG;&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34Y"FUS9VED(")0<F]M<'0@979E
M<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B
M"FUS9W-T<B`B4W#X<F<@:'9E<B!G86YG(&5N('9E9&CF9G1E;'-E('-E;F1E
M<SL@;F]R;6%L96X@97(@3D5*(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4U.`IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I
M<R!S96YT.R!D969A=6QT('1O(%E%4R(*;7-G<W1R(")3</AR9R!H=F5R(&=A
M;F<@96X@=F5D:.9F=&5L<V4@<V5N9&5S.R!N;W)M86QE;B!E<B!*02(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O
M=&]C;VPZ(@IM<V=S='(@(E!R;W1O:V]L.B(*"B,Z(&QI8B]#<GEP="]01U`N
M<&AP.C0R.0IM<V=I9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H
M87,@8F5E;B!D:7-A8FQE9"XB"FUS9W-T<B`B56YD97)S=/AT=&5L<V4@868@
M;V9F96YT;&EG(%!'4"UN^&=L97-E<G9E<B!E<B!S;.5E="!F<F$N(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)?9V4@1&5L
M971E9"(*;7-G<W1R(")&:F5R;B!S;&5T=&5D92(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G-?9&5L971E9"YI;F,Z.`IM<V=I9"`B4'5R9V4@1&5L971E9"(*;7-G<W1R
M(")&:F5R;B!S;&5T=&5D92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C(T"FUS9VED(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B4VQE
M="!M87!P92AR*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.38*;7-G
M:60@(E!U<F=E(%1R87-H(&AO=R!O9G1E;CHB"FUS9W-T<B`B5/AM('-K<F%L
M9&5S<&%N9&5N(&AV;W(@=&ET.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,#4*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O
M;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@(D9J97)N
M(&)E<VME9&5R(&D@<VMR86QD97-P86YD96XL(&1E<B!E<B#F;&1R92!E;F0@
M9&5T=&4@86YT86P@9&%G92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@V"FUS9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O
M;&1E<C\B"FUS9W-T<B`B1FIE<FX@9V%M;&4@8F5S:V5D97(@:2!S:W)A;&1E
M<W!A;F1E;C\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S
M:"YP:'`Z-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S
M86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B1FIE<FYE<B`E9"!B
M97-K961R(&9R82!S:W)A;&1E<W!A;F0N(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8S"FUS9VED(")0=7)G:6YG(#$@;65S
M<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B1FIE<FYE<B`Q(&)E
M<VME9"!F<F$@<VMR86QD97-P86YD+B(*"B,Z('1E;7!L871E<R]Q=6]T82]Q
M=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@<W1A='5S
M.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(DMV;W1E<W1A
M='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@H*(SH@=&5M<&QA=&5S
M+W%U;W1A+W%U;W1A+FEN8SHR,0HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T
M82!S=&%T=7,Z("4N,F9-0B`O($Y/($Q)34E4(@IM<V=S='(@(DMV;W1E<W1A
M='5S.B`E+C)F34(@+R!)3E1%5"!,3T94(@H*(SH@=&5M<&QA=&5S+W%U;W1A
M+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T
M=7,Z($Y/($Q)34E4(@IM<V=S='(@(DMV;W1E<W1A='5S.B!)3E1%5"!,3T94
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")1=6]T:6YG("5F.B(*;7-G<W1R(")#:71A="!A9B`E9CHB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#8*;7-G:60@(E)E
M7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(*;7-G<W1R(")!;FUO9"!O
M;2!B96MRYF9T96QS92!V960@869L979E<FEN9RXB"@HC.B!L:6(O4V5A<F-H
M+G!H<#HU,`IM<V=I9"`B4F5C96EV960@3VXB"FUS9W-T<B`B36]D=&%G970@
M9&5N(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3@*;7-G:60@(E)E8V5I=F5D(%-I
M;F-E(@IM<V=S='(@(DUO9'1A9V5T('-I9&5N(@H*(SH@;&EB+U-E87)C:"YP
M:'`Z-30*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM<V=S='(@(DUO9'1A9V5T
M(&;X<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(D]M861R97-S97(B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,38*;7-G
M:60@(E)E9&ER96-T(@IM<V=S='(@(D]M861R97-S97(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I<F5C="!-
M97-S86=E(@IM<V=S='(@(D]M861R97-S97(@8F5S:V5D(@H*(SH@8V]M<&]S
M92YP:'`Z-S@W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T
M<B`B3VUA9')E<W-E<B!D96YN92!B97-K960B"@HC.B!C;VUP;W-E+G!H<#HX
M-#<*;7-G:60@(E)E9&ER96-T:6YG(&9A:6QE9"XB"FUS9W-T<B`B3VUA9')E
M<W-E<FEN9R!M:7-L>6MK961E<RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU.#,*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B3W!D871E
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E
M<V@@1F]L9&5R(%9I97=S.B(*;7-G<W1R(")/<&1A=&5R('9I<VYI;F=E<FYE
M(&%F(&UA<'!E<CHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY
M('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-`IM<V=I9"`B4F5L;V%D
M(@IM<V=S='(@(D=E;F]P9G)I<VLB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H
M96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R(")/<&1A=&5R
M('9I<VYI;F<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(V(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#4*;7-G:60@(E)E;65M8F5R('1H
M92!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(DAU<VL@;&5D:6<O
M;W!T86=E="UI;F9O<FUA=&EO;F5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-SD*;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS9W-T
M<B`B2'5S:R!D96X@<VED<W1E('9I<VYI;F<B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*
M;7-G<W1R(")!9G-I9&5S(&)R979B86MK92(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I96QD($9R;VT@4V5A
M<F-H(@IM<V=S='(@(D9J97)N(&9E;'0@9G)A('/X9VYI;F<B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*;7-G:60@(E)E;6]V
M92!S;W5R8V4B"FUS9W-T<B`B1FIE<FX@:VEL9&4B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHX"FUS9VED(")296YA;64@1F]L9&5R*',I
M(@IM<V=S='(@(D]M9/AB(&UA<'!E*'(I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@
M8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")/;63X8B!M87!P92!F;W(@
M<V5N9'1E(&)E<VME9&5R(&D@<W1A<G1E;B!A9B!MY6YE9&5N/R(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C0U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296YA;6EN
M9R!<(B5S7"(@=&\@7"(E<UPB(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R("(B"B)/;63X8FYI;F<@868@7"(E<UPB('1I
M;"!<(B5S7"(@;6ES;'EK:V5D97,N($;X;&=E;F1E(&)E<VME9"!K;VT@9G)A
M('-E<G9E<F5N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C$P"FUS9VED(")297!L7WD@=&\@3&ES="(*;7-G<W1R(")3=F%R
M('1I;"!L:7-T92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T<B`B17)S=&%T(&UE
M9#HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M.`IM<V=I9"`B4F5P;'DB"FUS9W-T<B`B4W9A<B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P
M.0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B4W9A<B!S96YD="XB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G
M:60@(E)E<&QY('1O($%L;"(*;7-G<W1R(")3=F%R('1I;"!A;&QE(@H*(SH@
M8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L>2!T;R!!;&PZ(@IM<V=S='(@
M(E-V87(@=&EL(&%L;&4Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C$P"FUS9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@
M(E-V87(@=&EL(&QI<W1E(@H*(SH@8V]M<&]S92YP:'`Z-S,U"FUS9VED(")2
M97!L>2!T;R!,:7-T.B(*;7-G<W1R(")3=F%R('1I;"!L:7-T93HB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@
M(E)E<&QY('1O(%]!;&PB"FUS9W-T<B`B4W9A<B!T:6P@86QL92(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4S-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30W"FUS
M9VED(")297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R
M(")3=F%R(&UE9"!I:VME+75N9&5R<W3X='1E="UB97-K960B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3,U"FUS9VED(")297!L>2!W:71H(&9R
M964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B4W9A<B!M960@
M;&5D:6<O;W!T86=E="!F;W(@;N9S=&4@,B!MY6YE9&5R+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E<&QY('=I=&@@<F5Q
M=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B4W9A<B!M
M960@86YM;V1E="!L961I9R]O<'1A9V5T+6EN9F]R;6%T:6]N+B(*"B,Z(&UE
M<W-A9V4N<&AP.C(V-PIM<V=I9"`B4F5P;'DM5&\B"FUS9W-T<B`B4F5P;'DM
M5&\B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`Y"FUS9VED(")297!L>2U4;SH@
M(@IM<V=S='(@(E)E<&QY+51O.B`B"@HC.B!C;VUP;W-E+G!H<#HW,S$*;7-G
M:60@(E)E<&QY.B(*;7-G<W1R(")297!L>3HB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,C8*;7-G:60@(E)E<&]R="!A<R!);FYO8V5N="(*;7-G
M<W1R(")!;FUE;&0@<V]M(&5J+7-P86TB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(D%N
M;65L9"!S;VT@4U!!32(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,X,PIM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T
M<B`B06YM;V0@;VT@:W9I='1E<FEN9R!F;W(@;.9S;FEN9R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU.#4*;7-G:60@(E)E<75E<W0@9&5L:79E<GD@
M8V]N9FER;6%T:6]N/R(*;7-G<W1R(")!;FUO9"!O;2!B96MRYF9T96QS92!V
M960@869L979E<FEN9S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S
M"FUS9VED(")297%U97-T(')E860@<F5C96EP=',_(@IM<V=S='(@(D%N;6]D
M(&]M(&MV:71T97)I;F<@9F]R(&SF<VYI;F<B"@HC.B!M86EL8F]X+G!H<#HQ
M.#D*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"XB"FUS9W-T
M<B`B1F]R97-P=7)G=&4@8F5S:V5D(&EK:V4@9G5N9&5T+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV.3<*;7-G:60@(E)E<75I<F5D(%!A<G1I
M8VEP86YT(@IM<V=S='(@(DMRYG9E="!D96QT86=E<B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z,30S('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHR-@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q"FUS9VED(")2
M97-E="(*;7-G<W1R(").=6QS=&EL(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$Q-0IM<V=I9"`B4F5S<&]N9&5N="!3=&%T=7,@57!D871E9"XB
M"FUS9W-T<B`B4F5S<&]N9&5N="US=&%T=7,@;W!D871E<F5T+B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,`IM<V=I9"`B
M4F5S=6UE(@IM<V=S='(@(D9O<G1SYG0B"@HC.B!R96-O;7!O<V4N<&AP.CDX
M"FUS9VED(")297-U;64@>6]U<B!S97-S:6]N(@IM<V=S='(@(D9O<G1SYG0@
M9&EN('-E<W-I;VXB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z-#0*;7-G:60@(E)E='5R;B!T;R!<(DUE<W-A9V4@0V]M<&]S:71I;VY<
M(B(*;7-G<W1R(")696YD('1I;&)A9V4@=&EL(%PB4VMR:79N:6YG(&%F(&YY
M(&)E<VME9%PB(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L
M96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-CD*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,S(*
M;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@(E1I;&)A9V4@
M=&EL(&EN9'-T:6QL:6YG97)N92!F;W(@7")&971C:"!-86EL7"(B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E
M<G,O;F]T86-T:79E+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$P,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T
M:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L
M871E<R]A8VPO86-L+FEN8SHQ-S,*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS
M(@IM<V=S='(@(E1I;&)A9V4@=&EL(&EN9'-T:6QL:6YG97)N92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW,3@*;7-G:60@(B(*(E)E='5R;B!T;R!T
M:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R
M(&-O<'EI;F<@82!M97-S86=E/R(*;7-G<W1R("(B"B)'Y2!T:6QB86=E('1I
M;"!M86EL8F]X96X@969T97(@<VQE=&YI;F<L(&9L>71N:6YG(&5L;&5R(&MO
M<&EE<FEN9R!A9B!B97-K960_(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8X.`IM<V=I9"`B4F]L92(*;7-G<W1R(")296=E;"(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,C,W"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS
M9VED(")3+TU)344B"FUS9W-T<B`B4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y
M<'0@365S<V%G92(*;7-G<W1R(")3+TU)344M:W)Y<'1E<F5T(&)E<VME9"(*
M"B,Z(&-O;7!O<V4N<&AP.C,Y-`IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS
M9W-T<B`B4R]-24U%+69E:FPZ("(*"B,Z(&-O;7!O<V4N<&AP.C,W,PIM<V=I
M9"`B4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L
M('!R:79A=&4@:V5Y+B(*;7-G<W1R(")3+TU)344M9F5J;#H@3/AS96X@=&EL
M(&5G96XL('!R:79A="!N^&=L92!N^&1V96YD:6<N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U,0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS9W-T
M<B`B4R]-24U%+6EN9'-T:6QL:6YG97(B"@HC.B!S;6EM92YP:'`Z-#D*;7-G
M:60@(E,O34E-12!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(DEN9'1A<W0@
M4R]-24U%+6SX<V5N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHU
M-`IM<V=I9"`B4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U
M:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B56YD97)S
M=/AT=&5L<V4@868@96=E;B!3+TU)344@;OAG;&5P87(@:W+F=F5R('-I:VME
M<B!W96(M9F]R8FEN9&5L<V4N(@H*(SH@<VUI;64N<&AP.C$T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A
M<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B3V9F96YT;&EG(%,O
M34E-12UN^&=L92!F;W(@7"(E<UPB('-L971T970N(@H*(SH@<VUI;64N<&AP
M.C$V,@IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D
M9&5D+B(*;7-G<W1R(")/9F9E;G1L:6<@4R]-24U%(&[X9VQE('1I;&;X:F5T
M+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`*;7-G:60@(E,O
M34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")/9F9E;G1L:6<@4R]-24U%
M(&[X9VQE<FEN9R(*"B,Z('-M:6UE+G!H<#HR,3$*;7-G:60@(E,O34E-12!0
M=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS
M9W-T<B`B3V9F96YT;&EG+W!R:79A="!3+TU)344@;OAG;&5P87(@=&EL9OAJ
M970N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ
M,PIM<V=I9"`B4R]-24U%(%-I9VX@365S<V%G92(*;7-G<W1R(")3+TU)344M
M<VEG;NER(&)E<VME9"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?
M;&ES="YI;F,Z,30*;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G
M92(*;7-G<W1R(")3+TU)344@<VEG;NER+VMR>7!TZ7(@8F5S:V5D(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4R]-24U%
M('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@
M(E5N9&5R<W3X='1E;'-E(&%F(%,O34E-12!S;.5E="!F<F$@<.4@9&5T=&4@
M<WES=&5M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Q"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&5N86)L
M960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E8W)Y<'1E
M9"XB"FUS9W-T<B`B(@HB56YD97)S=/AT=&5L<V4@868@4R]-24U%(&5R(&EK
M:V4@86MT:79E<F5T+"!SY2!B97-K961E;B!K86X@:6MK92!D96MR>7!T97)E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PIM<V=I9"`B
M(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O;G1E
M;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO="`B"B)B92!D:7-P
M;&%Y960N(@IM<V=S='(@(B(*(E5N9&5R<W3X='1E;'-E(&%F(%,O34E-12!E
M<B!I:VME(&%K=&EV97)E="P@<^4@:6YD:&]L9&5T(&%F(&1E;FYE('-I9VYE
M<F5D92`B"B)B97-K960@:V%N(&EK:V4@=FES97,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T
M(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U
M;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E5N9&5R<W3X
M='1E;'-E(&%F(%,O34E-12!E<B!I:VME(&%K=&EV97)E="P@<^4@9&5N(&1I
M9VET86QE('-I9VYA='5R(&MA;B`B"B)I:VME('9E<FEF:6-E<F5S+B(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,@IM<V=I9"`B(@HB4R]-24U%
M('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@
M268@>6]U<B!B<F]W<V5R(&ES("(*(F-U<G)E;G1L>2!S970@=&\@9&ES86)L
M92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG
M(&]R(&5L<V4@(@HB=&AE(%,O34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K
M(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB56YD97)S=/AT=&5L<V4@868@4R]-
M24U%(&MRYG9E<B!A;G9E;F1E;'-E(&%F('!O<'5P+79I;F1U97(N("!(=FES
M(&1I;B`B"B)B<F]W<V5R(&5R('-A="!T:6P@870@8FQO:VME<F4@<&]P=7`M
M=FEN9'5E<BP@8FQI=F5R(&1U(&[X9'0@=&EL(&%T(.9N9')E("(*(F1E;FYE
M(&EN9'-T:6QL:6YG.R!E;&QE<G,@=FEL(%,O34E-12UF=6YK=&EO;F5R(&EK
M:V4@=FER:V4@:V]R<F5K="XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(P-0IM<V=I9"`B4TU44"(*;7-G<W1R(")33510(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4U"FUS9VED(")37W5B:F5C="(*
M;7-G<W1R(")%;6YE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,S8S"FUS9VED(")385]V92!A(&-O<'D@:6X@(@IM<V=S='(@(D=E;2!E
M;B!K;W!I(&D@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C,R"FUS9VED(")385]V92!A<R(*;7-G<W1R(")'96T@<V]M(@H*
M(SH@<V5A<F-H+G!H<#HS,38@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C8W"FUS9VED(")3879E(@IM<V=S='(@(D=E;2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4S.`IM<V=I9"`B4V%V92!!='1A8VAM
M96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T
M<B`B1V5M('9E9&CF9G1E;'-E<B!M960@8F5S:V5D97(@:2!<(E-E;F1T('!O
M<W1<(BUM87!P96X_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,S"FUS9VED
M(")3879E($1R869T(@IM<V=S='(@(D=E;2!K;&%D9&4B"@HC.B!S879E:6UA
M9V4N<&AP.C0R"FUS9VED(")3879E($EM86=E(@IM<V=S='(@(D=E;2!B:6QL
M961E(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(P-`IM<V=I9"`B4V%V
M92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@(D=E;2!B:6QL961E(&D@9V%L
M;&5R:2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O
M;F]T86-T:79E+FEN8SHQ,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z
M('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V92!/
M<'1I;VYS(@IM<V=S='(@(D=E;6UE($EN9'-T:6QL:6YG97(B"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#`*;7-G:60@(E-A=F4@4W1A
M=&EO;F5R>2(*;7-G<W1R(")'96UM92!B<F5V<&%P:7(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,S,*;7-G:60@(E-A=F4@7T1R869T(@IM<V=S='(@(D=E
M;2!K;&%D9&4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T<B`B1V5M('-O;2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G:60@(E-A=F4@9')A9G1S
M(&%S('5N<V5E;C\B"FUS9W-T<B`B1V5M(&ML861D97(@<V]M('5LYG-T/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<R"FUS9VED(")3879E(')E
M8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S
M(&)O;VL_(@IM<V=S='(@(D=E;2!M;V1T86=E<F4@875T;VUA=&ES:R!I(&1E
M="!N;W)M86QE(&%D<F5S<V5K87)T;W1E:S\B"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@87,@82!V:7)T
M=6%L(&9O;&1E<C\B"FUS9W-T<B`B1V5M('/X9VYI;F<@<V]M(&5N('9I<G1U
M96P@;6%P<&4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I
M9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(D=E;2!S96YD="!B97-K960_
M(@H*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@)7,B"FUS9W-T<B`B1V5M;FEN9R!A9B!K;&%D9&4@;6ES;'EK
M:V5D97,N($;X;&=E;F1E(&)E<VME9"!K;VT@9G)A('-E<G9E<F5N.B`E<R(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L
M871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?
M9F]L9&5R<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R(")3^&<B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R
M8V@@)7,B"FUS9W-T<B`B4_AG(&5F=&5R("5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R,`IM<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`B
M4_AG92UI;F1S=&EL;&EN9V5R(@H*(SH@<V5A<F-H+G!H<#HR-C4*;7-G:60@
M(E-E87)C:"!297-U;'1S(@IM<V=S='(@(E/X9V5R97-U;'1A=&5R(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM<V=S='(@(E-E="(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z.0IM<V=I9"`B4V5L
M96-T(@IM<V=S='(@(E;F;&<B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-S`*;7-G:60@(E-E;&5C="!!;F]T:&5R($%C8V]U;G0B"FUS
M9W-T<B`B5N9L9R!E;B!A;F1E;B!K;VYT;R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R
M(")6YFQG(&5N(&1A=&\B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z,3`*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(E;F;&<@970@
M9F5L="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PIM
M<V=I9"`B4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B5N9L9R!B<F5V
M<&%P:7(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B
M4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E
M87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R(")6YFQG(&%D<F5S<V5K
M87)T;W1E:V5R(&9O<B!O<')E='1E;'-E(&]G('/X9VYI;F<@868@861R97-S
M97(N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I9"`B
M4V5L96-T(&%L;"(*;7-G<W1R(")6YFQG(&%L;&4B"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*;7-G:60@(E-E;&5C="!A;&P@
M9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM
M<V=S='(@(E;F;&<@86QL92!F96QT97(@<V]M('-K86P@9V5N;F5M<_AG97,L
M(&[E<B!A9')E<W-E<B!E:W-P86YD97)E<RXB"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T(&%N
M(&%C8V]U;G0B"FUS9W-T<B`B5N9L9R!E;B!K;VYT;R(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S
M='(@(E;F;&<@:6YG96XB"@HC.B!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I
M;6%G92YI;F,Z.0IM<V=I9"`B4V5L96-T('1H92!G86QL97)Y('1O('-A=F4@
M=&AE(&EM86=E(&EN+B(*;7-G<W1R(")6YFQG(&=A;&QE<FDL(&AV;W)I(&)I
M;&QE9&5T('-K86P@9V5M;65S+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S
M97)V97(@='EP92(*;7-G<W1R(")6YFQG(&UA:6PM<V5R=F5R+71Y<&5N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"FUS9VED
M(")396QE8W1E9"!!9&1R97-S(&)O;VMS.B(*;7-G<W1R(")686QG=&4@861R
M97-S96MA<G1O=&5K97(Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R
M"FUS9VED(")396YD($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R(@IM<V=S='(@
M(E-E;F0@;OAG;&4@=&EL(&]F9F5N=&QI9R!N^&=L97-E<G9E<B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#0*;7-G:60@(E-E;F0@3&%T97-T
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E-E;F1T('-E;F5S=&4@:6YF;W)M871I
M;VXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S$*;7-G:60@(E-E;F0@365S
M<V%G92(*;7-G<W1R(")396YD(&)E<VME9"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW,#,*;7-G:60@(E-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q
M=65S=&5D(&)Y('1H92!S96YD97(_(@IM<V=S='(@(E-E;F0@;.9S="UK=FET
M=&5R:6YG(&[E<B!A;FUO9&5T(&%F(&%F<V5N9&5R/R(*"B,Z(&9O;&1E<G,N
M<&AP.C,Y-PIM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")-87!P
M92!F;W(@<V5N9'1E(&)E<VME9&5R(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E
M;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB
M"FUS9W-T<B`B36%P<&4@9F]R('-E;F1T92!E+6UA:6QS.B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,30V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,34S"FUS
M9VED(")397)V97(B"FUS9W-T<B`B4V5R=F5R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(S"FUS9VED(")397)V97(@86YD($9O;&1E<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")397)V97(M(&]G(&UA<'!E+6EN9F]R;6%T:6]N(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(S"FUS9VED(")3
M97)V97(Z(@IM<V=S='(@(E-E<G9E<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P
M96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S86=E<RXB"FUS9W-T
M<B`B(@HB26YD<W1I;&QI;F=E<B!F;W(@:'9A9"!D97(@<VME<BP@;N5R(&1U
M(&9L>71T97(@96QL97(@<VQE='1E<B!B97-K961E<BXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3970@=&AE(%@M4')I;W)I='D@
M:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/R(*;7-G<W1R(")3YG0@
M8G)E=FAO=F5D970@6"U0<FEO<FET>2!V960@<VMR:79N:6YG(&%F(&)E<VME
M9&5R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA
M<F4@1F]L9&5R<R(*;7-G<W1R(")$96P@;6%P<&5R(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C@V"FUS9VED(")3:&%R92!M86EL(&9O;&1E<G,B"FUS
M9W-T<B`B1&5L(&)E<VME9"UM87!P97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@
M;W1H97(@=7-E<G,N(@IM<V=S='(@(D1E;"!D:6YE('!O<W1M87!P97(@;65D
M(&%N9')E(&)R=6=E<F4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V
M.0IM<V=I9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@=&5X
M="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E("(*
M(G1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+B(*;7-G<W1R
M("(B"B)3:V%L('-T;W)E(&ML=6UP97(@868@8VET97)E="!T96MS="!VYG)E
M('-Y;FQI9R!E;&QE<B!S:VIU;'0@<V]M('-T86YD87)D/R`@(@HB2'9A9"!E
M;G1E;B!D=2!VYFQG97(@97(@9&5T(&YE;70@870@<VMI9G1E+B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@
M;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T
M83\B"FUS9W-T<B`B4VMA;"!B<OAD=&5K<W1E;B!A9B!T97AT+W!L86EN(&)E
M<VME9&5R(&=E;FYE;7/X9V5S(&9O<B!01U`M9&%T83\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$S"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@
M=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T
M<B`B4VMA;"!V:6YD=65T(&UE9"!D96X@;GEE(&)E<VME9"!L=6MK97,@969T
M97(@9V5M;FEN9R!A9B!K;&%D9&4_(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C0*;7-G:60@(E-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E
M(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\B"FUS9W-T
M<B`B4VMA;"!D970@=N9R92!N;W)M86QE;BP@870@9&EN(%!'4"UN^&=L92!V
M961HYF9T97,@8F5S:V5D97(_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHY,@IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")6:6P@
M86QL92!M87!P97(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN
M8SHV-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R(")6:7,@86QL
M92!B<F5V:&]V961E<B(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM<V=I9"`B4VAO
M=R!$96QE=&5D(@IM<V=S='(@(E9I<R!S;&5T=&5D92(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET960@
M2&5A9&5R<R(*;7-G<W1R(")6:7,@;F]R;6%L92!B<F5V:&]V961E<B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P"FUS9VED(")3:&]W
M($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R(")6:7,@;6%I;&QI
M<W1E+6EN9F]R;6%T:6]N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHY,@IM<V=I9"`B4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<R(*;7-G
M<W1R(")6:7,@:W5N(&%K=&EV97)E9&4@;6%P<&5R(@H*(SH@9F]L9&5R<RYP
M:'`Z,CDX"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")6:7,@
M9&5A:W1I=F5R961E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P.`IM
M<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP<&EN9R!O9B!A='1A
M8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*;7-G<W1R("(B"B)6:7,@970@<&EC
M=&]G<F%M('-O;2!G:79E<B!A9&=A;F<@=&EL(&%T(&9J97)N92!V961HYF9T
M96QS92!F<F$@8F5S:V5D97(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P,#(*;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_
M(@IM<V=S='(@(E9I<R!S>6UB;VQF;W)K;&%R:6YG(&D@;6%I;&)O>'9I<VYI
M;F=E;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0P"FUS9VED(")3
M:&]W('!R979I97=S(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\B"FUS9W-T
M<B`B5FD@:W5N(&=L:6UT(&%F('5LYG-T92!B97-K961E<C\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('!R979I97=S(&EN
M('1O;VQT:7!S/R(*;7-G<W1R(")6:7,@9VQI;70@:2`\96T^=&]O;'1I<',\
M+V5M/C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<W"FUS9VED(")3
M:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S
M='(@(E9I<R!<(D9E=&-H($UA:6Q<(B!K;F%P<&5N(&D@;65N=65N/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B4VAO=R!T:&4@
M26UA9V5S(@IM<V=S='(@(E9I<R!B:6QL961E<FYE(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F:6QT97(@
M:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B5FES(%PB1FEL=&5R7"(@
M:VYA<'!E;B!I(&UE;G5E;C\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z
M,C@*;7-G:60@(E-H;W<@=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O;&1E
M<C\B"FUS9W-T<B`B5FD@=&]T86QT(&%N=&%L(&)E<VME9&5R(&D@;6%P<&4_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-@IM<V=I9"`B4VAO=VXB
M"FUS9W-T<B`B5FES="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z-#(*;7-G:60@(E-I7WIE(@IM<V=S='(@(E-T<BXB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$W"FUS9VED(")3:6=N
M960B"FUS9W-T<B`B4VEG;F5R970B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")3=/AR<F5L
M<V4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C$Q"FUS9VED(")3;W)T(&)Y($%R<FEV86PB"FUS9W-T<B`B4V]R=.ER(&5F
M=&5R(&UO9'1A9V5L<V5S=&ED<W!U;FMT(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E
M(@IM<V=S='(@(E-O<G3I<B!E9G1E<B!D871O(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR-@IM<V=I9"`B4V]R="!B>2!&
M<F]M($%D9')E<W,B"FUS9W-T<B`B4V]R=.ER(&5F=&5R(&%F<V5N9&5R+6%D
M<F5S<V4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N
M:6YC.C0Q"FUS9VED(")3;W)T(&)Y($UE<W-A9V4@4VEZ92(*;7-G<W1R(")3
M;W)TZ7(@969T97(@<W3X<G)E;'-E(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHS-@IM<V=I9"`B4V]R="!B>2!3=6)J96-T
M(@IM<V=S='(@(E-O<G1E<B!E9G1E<B!E;6YE(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,0IM<V=I9"`B4V]R="!B>2!4
M:')E860B"FUS9W-T<B`B4V]R=&5R(&5F=&5R('1RY60B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q"FUS9VED(")3;W)T
M(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`B4V]R=.ER(&5F=&5R(&UO9'1A9V5R
M861R97-S92(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M,PIM<V=I9"`B4W!A;2!F;VQD97(Z(@IM<V=S='(@(DUA<'!E('1I;"!S<&%M
M+6)E<VME9&5R.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C,T-@IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97)S(@IM<V=S='(@(E-P96-I
M96QL92!T96=N(@H*(SH@<V5A<F-H+G!H<#HQ,S,*;7-G:60@(E-P96-I86P@
M5FER='5A;"!&;VQD97)S(&-A;B!N;W0@8F4@961I=&5D+B(*;7-G<W1R(")3
M<&5C:65L;&4@=FER='5E;&QE(&UA<'!E<B!M86X@:6MK92#F;F1R97,N(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0S"FUS9VED(")3
M<&5L;"!#:&5C:R(*;7-G<W1R(")3=&%V96MO;G1R;VPB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(E-P96QL($-H96-K
M97(B"FUS9W-T<B`B4W1A=F5K;VYT<F]L(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C0X('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHU-@IM<V=I9"`B4W!E;&P@8VAE8VL@8V]M<&QE=&4B"FUS9W-T<B`B
M4W1A=F5K;VYT<F]L(&%F<VQU='1E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-S$*;7-G:60@(E-P96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H
M96X@<W!E;&P@8VAE8VMI;F<N(@IM<V=S='(@(E-T879E9F5J;"!P<BX@<VOF
M<FTL(&[E<B!D97(@:_AR97,@<W1A=F5K;VYT<F]L+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,3(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8U,@IM<V=I9"`B4W1A<G0B"FUS9W-T<B`B4W1A<G0B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS,3$*;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`B0G)E
M=G!A<&ER(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V
M"FUS9VED(")3=&%T:6]N97)Y(&YA;64Z(@IM<V=S='(@(D)R979P87!I<FYA
M=FXZ(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS
M9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(D)R979P87!I<G1Y<&4Z
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,S"FUS9VED
M(")3=&%T:6]N97)Y.B(*;7-G<W1R(")"<F5V<&%P:7(Z(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(E-T871U<R(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*;7-G:60@
M(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T<B`B1FIE<FX@=F5D:.9F=&5L<V4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,R"FUS9VED(")3=')I<"!L
M:6YE8G)E86MS/R(*;7-G<W1R(")&:F5R;B!O;6)R>61N:6YG/R(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*;7-G:60@
M(E-U8E]J96-T(@IM<V=S='(@(D5M;F4B"@HC.B!M97-S86=E+G!H<#HR-C@@
M=&AR96%D+G!H<#HQ-3`@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN
M8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM<V=I9"`B4W5B:F5C="(*;7-G
M<W1R(")%;6YE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I
M9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R(")&96QT(&9O<B!%;6YE(@H*(SH@
M<V5A<F-H+G!H<#HS,3@@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N
M:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,"!T
M96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B069L97;I<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R*',I(@IM<V=S
M='(@(D%K=&EV97(@;6%P<&4H<BDB"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C,X,"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.#D*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`B561F^')T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G<W1R(")&;W)S;&%G(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V,B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C8T"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(DEN9&AO
M;&0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#`@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`S"FUS9VED(")3=VET8V@@
M0V]M<&]S:71I;VX@365T:&]D(@IM<V=S='(@(E-K:69T('-K<FEV;FEN9W-M
M971O9&4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*
M;7-G:60@(E-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(E-K
M:69T('1I;"!(5$U,+7-K<FEV;FEN9R(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O('!L86EN('1E>'0@
M8V]M<&]S:71I;VXB"FUS9W-T<B`B4VMI9G0@=&EL(')E;B!T96MS='-K<FEV
M;FEN9R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Q.0IM
M<V=I9"`B5&5?>'0B"FUS9W-T<B`B5&5K<W0B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,C8Y"FUS9VED(")496YT871I=F4Z("(*;7-G<W1R(")&
M;W)E;/AB:6<Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*
M;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(D%C
M8V5P=.ER(&%N;6]D;FEN9R!F;W)E;/AB:6=T(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<V,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B
M"FUS9W-T<B`B1F]R96SX8FEG="!A8V-E<'1E<F5T(@H*(SH@;&EB+TUA:6YT
M96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&5R;7,@;V8@4V5R=FEC92!F:6QE(&YO="!S<&5C:69I960@
M:6X@8V]N9BYP:'`B"FUS9W-T<B`B0F5T:6YG96QS97-F:6P@:6MK92!A;F=I
M=F5S(&D@8V]N9BYP:'`B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z,S`*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5K<W0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN
M(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@(D)E
M<VME9&5N<R!&<F$M:V]L;VYN92!S:V%L(')E9F5R97)E<SHB"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C4S,@IM<V=I9"`B(@HB5&AE($E-05`@<V5R=F5R
M(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H96YT:6-A=&EO
M;B!M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT86-T('EO=7(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DE-05`M<V5R=F5R96X@
M<WEN97,@:6MK92!A="!U;F1E<G-T^'1T92!D96X@=F%L9W1E(.9G=&YI;F=S
M;65T;V1E+B!+;VYT86MT("(*(F1I;B!S>7-T96UA9&UI;FES=')A=&]R+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@
M(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R("(\96T^36%C
M:6YT;W-H(')E<V]U<F-E(&9O<FL\+V5M/B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M($UA8VEN=&]S:"!R97-O=7)C92!F;W)K(&-A;B!B92!D;W=N;&]A9&5D("5S
M+B(*;7-G<W1R("(\/&5M/DUA8VEN=&]S:"!R97-O=7)C92!F;W)K/"]E;3X@
M:V%N(&AE;G1E<R`E<RXB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(DMO;G1O96X@7"(E<UPB(&5R('-L971T970N
M(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`B2V]N=&]E;B!<(B5S7"(@97(@9V5M="XB"@HC.B!A='1A8VAM96YT+G!H
M<#HT,PIM<V=I9"`B5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N9"XB"FUS
M9W-T<B`B5F5D:.9F=&5L<V5N(&EK:V4@9G5N9&5T+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV.0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@
M:7,@:6YV86QI9"(*;7-G<W1R(")+86QE;F1E<BUD871A(&5R('5G>6QD:6<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-O;7!O<V5?=VEN+FIS
M.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@;W!E
M;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB
M8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B4VMR:79N:6YG<W9I;F1U
M970@:V%N(&EK:V4@Y6)N97,N("!%<B!D:6X@<&]P+75P+6)L;VMK97(@86MT
M:79E<F5T/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z
M-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T:&4@36%C:6YT;W-H(&9I;&4@
M87)E(&)E;&]W+B(*;7-G<W1R("));F1H;VQD970@868@36%C:6YT;W-H+69I
M;&5N(&9O<F5F:6YD97,@;F5D96YF;W(N(@H*(SH@;&EB+TUA:6YT96YA;F-E
M+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C@W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!C=7)R96YT(&9O;&1E<BAS*2!<(B5S7"(@=VEL
M;"!B92!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B1&4H;BD@86MT=65L
M;&4@;6%P<&4H<BD@7"(E<UPB('9I;"!B;&EV92!O;63X8G0@=&EL(%PB)7-<
M(BXB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3`W"FUS9VED("(B"B)4
M:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@
M9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960B"FUS9W-T<B`B(@HB1&5N
M(&%K='5E;&QE(&QI<W1E(&]V97(@8G)U9V5R92P@<V]M(&AA<B!A9&=A;F<@
M=&EL(&1E;FYE(&UA<'!E+"!K=6YN92!I:VME("(*(FAE;G1E<R(*"B,Z(&-O
M;7!O<V4N<&AP.C$R,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T
M(&AA<R!B965N('-A=F5D('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R
M(")+;&%D9&5N(&5R(&=E;70@:2!<(B5S7"(@;6%P<&5N+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,SD*;7-G:60@(E1H92!E=F5N="!W87,@
M861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS9W-T<B`B2.9N9&5L<V5N(&5R
M(&EN9'-A="!I(&1I;B!K86QE;F1E<BXB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E>'!A;F0N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I96QD
M(%PB)7-<(B!C86XG="!B92!E>'!A;F1E9"XB"FUS9W-T<B`B1F5L=&5T(%PB
M)7-<(B!K86X@:6MK92!E:W-P86YD97)E<RXB"@HC.B!L:6(O1F]L9&5R+G!H
M<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@
M86QR96%D>2!E>&ES=',B"FUS9W-T<B`B36%P<&5N(%PB)7-<(B!F:6YD97,@
M86QL97)E9&4B"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A
M;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O
M8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@HB36%P<&5N(%PB)7-<(B!I;F1H;VQD97(@=6QO=FQI9V4@
M=&5G;B!I(&YA=FYE="X@1&5T=&4@:V%N(&;X<F4@=&EL("(*(G!R;V)L96UE
M<BX@2V]N=&%K="!V96YL:6=S="!D:6X@<WES=&5M861M:6YI<W1R871O<BXB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&-R96%T960@8G5T('EO=2!W97)E(&YO
M="!S=6)S8W)I8F5D('1O(&ET+B(*;7-G<W1R(")-87!P96X@7"(E<UPB(&)L
M978@;W!R971T970L(&UE;B!D96X@8FQE=B!I:VME(&%K=&EV97)E="XB"@HC
M.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U
M;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B36%P<&5N(%PB)7-<(B!B
M;&5V('-L971T970L(&UE;B!D96X@:W5N;F4@:6MK92!D96%K=&EV97)E<RXB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(DUA<'!E;B!<(B5S7"(@8FQE
M=B!I:VME(&]P<F5T=&5T+B!397)V97)E;G,@8F5S:V5D(&MO;6UE<B!H97(B
M"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(DUA<'!E;B!<(B5S7"(@8FQE
M=B!I:VME('-L971T970N(%-E<G9E<F5N<R!B97-K960@:V]M;65R(&AE<B(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N(@IM
M<V=S='(@(DUA<'!E;B!<(B5S7"(@97(@8FQE=F5T(&]P<F5T=&5T+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S
M='(@(DUA<'!E;B!<(B5S7"(@97(@8FQE=F5T('-L971T970N(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N
M(@IM<V=S='(@(DUA<'!E;B!<(B5S7"(@8FQE=B!O;63X8G0@=&EL(%PB)7-<
M(BXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H
M92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z
M(@IM<V=S='(@(D;X;&=E;F1E(&9I;&5R(&5R(&CF9G1E="!T:6P@9&5N;F4@
M9&5L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?<V%V96EM86=E
M7W=I;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A
M;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R
M;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB
M5FEN9'5E="!T:6P@;&%G<FEN9R!A9B!B:6QL961E<B!K=6YN92!I:VME(.5B
M;F5S+B`@17(@9&EN('!O<'5P+6)L;VMK97(@(@HB86MT:79E<F5T/R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B(@HB5&AE(&EM
M86=E<R!W:6QL(&)E(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@:7,@
M<')E<V5N="!I;B!Y;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R("(B"B)"
M:6QL961E<FYE('9I;"!B;&EV92!V:7,@9F]R9&D@869S96YD97)E;B!F:6YD
M97,@:2!D:70@861R97-S96MA<G1O=&5K+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A
M=&5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B36%I
M;"US97)V97)E;B!G96YE<F5R961E(&;X;&=E;F1E(&9E:FPM8F5S:V5D.B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"FUS9VED
M(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF
M;W)M871I;VYA;"!M97-S86=E.B(*;7-G<W1R(")-86EL+7-E<G9E<F5N(&1A
M;FYE9&4@9&5N;F4@:6YF;W)M871I=F4@;65D9&5L96QS93HB"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R
M=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@
M(DUA:6PM<V5R=F5R96X@9V5N97)E<F5D92!F^&QG96YD92!B97-K960Z(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C8U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R(")-87!P
M96X@)7,@86QL97)E9&4@=&]M+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(T
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!<(B5S7"(@9G)O
M;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@;&EM:70N
M(@IM<V=S='(@(B(*(D)E<VME9&5N(%PB)7-<(B!F<F$@7"(E<UPB("@E9"!B
M>71E*2!O=F5R<VMR:61E<B!S=/AR<F5L<V5S9W+F;G-E;B!V960@(@HB:&5N
M=&YI;F<N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M,#,*;7-G:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O<V5D(&AA<R!B965N
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B0F5S:V5D96XL(&1E<B!S:W)I
M=F5S('#E+"!E<B!L=6MK970N($%F<VQU='1E<BXB"@HC.B!M97-S86=E+G!H
M<#HQ-#@*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(D)E<VME9&5N(&5R('-L971T970N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,SDS"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V
M97)I9FEE9"XB"FUS9W-T<B`B0F5S:V5D96X@97(@=F5R:69I8V5R970N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E
M<CH@)7,N(@IM<V=S='(@(D)E<VME9&5N(&5R('9E<FEF:6-E<F5T+B!!9G-E
M;F1E<CH@)7,N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+V]P96Y?<VUI;65?=VEN
M+FIS.C$P('1E;7!L871E<R]P9W`O;W!E;E]P9W!?=VEN+FIS.C$P"FUS9VED
M("(B"B)4:&4@<&%S<W!H<F%S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!0
M97)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@
M<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B3/AS96XM=FEN9'5E="!K=6YN92!I
M:VME(.5B;F5S+B`@17(@9&EN('!O<'5P+6)L;VMK97(@<VSE970@=&EL/R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(E+E=&5K<W1E;B!A9B!D96X@;V9F
M96YT;&EG92!01U`M;OAG;&4@8V%N('9I<V5S("5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE
M(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM
M<V=S='(@(D1E;B!F;W)E<W!U<F=T92!F:6P@9FEN9&5S(&EK:V4@:2!-4RU4
M3D5&+79E9&CF;F=E="XB"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV
M-`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!::7`@871T86-H;65N="XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R9W1E
M(&9I;"!F:6YD97,@:6MK92!I(%II<"UV961HYFYG970N(@H*(SH@;65S<V%G
M92YP:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@
M;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E
M(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T
M:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*(D%F<V5N
M9&5R96X@868@9&5N;F4@8F5S:V5D(&%N;6]D97(@;VT@96X@/&5M/DUE<W-A
M9V4@1&ES<&]S:71I;VX@(@HB3F]T:69I8V%T:6]N("A-1$XI/"]E;3X@9G)A
M(&1I9RP@;N5R(&1U(&AA<B!LYG-T(&)E<VME9&5N+B`@0VQI8VL@)7,@9F]R
M(&%T("(*(F%F<V5N9&4@;F]T:71S96XN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z-CD*;7-G:60@(E1H92!S97)V97(@=V%S(&YO="!A8FQE
M('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R
M(")397)V97)E;B!K=6YN92!I:VME(&1A;FYE(&5T(&9R:6WF<FME(&%F(&)I
M;&QE9&5T+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`T
M"FUS9VED(")4:&4@<VEG;F%T=7)E(&-O=6QD(&YO="!B92!R97!L86-E9"XB
M"FUS9W-T<B`B1&EN('-I9VYA='5R(&MU;FYE(&EK:V4@97)S=&%T=&5S+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`R"FUS9VED(")4
M:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N(@IM<V=S
M='(@(D1I;B!S:6=N871U<B!E<B!B;&5V970@<F5T=&5T+B(*"B,Z(&%T=&%C
M:&UE;G0N<&AP.C4Y"FUS9VED(")4:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(D1E;B!F;W)E<W!U<F=T92!F:6QE(&9I;F1E
M<R!I:VME+B(*"B,Z('-T871I;VYE<GDN<&AP.C@T"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!A9&1E9"XB
M"FUS9W-T<B`B0G)E=G!A<&ER970@7"(E<UPB(&5R('1I;&;X:F5T+B(*"B,Z
M('-T871I;VYE<GDN<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")"
M<F5V<&%P:7)E="!<(B5S7"(@97(@<VQE='1E="XB"@HC.B!S=&%T:6]N97)Y
M+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<
M(B5S7"(@:&%S(&)E96X@=7!D871E9"XB"FUS9W-T<B`B0G)E=G!A<&ER970@
M7"(E<UPB(&5R(.9N9')E="XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,38Y"FUS9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R
M('1A<VML:7-T+B(*;7-G<W1R(")/<&=A=F5N('1I;"!S870@<.4@9&EN(&]P
M9V%V96QI<W1E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDU
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92(*;7-G<W1R(")"<OAD
M=&5K<W1E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(D)E<VME9&5N<R!B<OAD=&5K<W0@
M:V%N('-E<R`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX
M,`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS
M9W-T<B`B1&5N(')E='5R;F5R961E(&)E<VME9',@8G+X9'1E:W-T(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B1&5N(')E='5R;F5R961E(&)E<VME9',@
M8G+X9'1E:W-T(&MA;B!S97,@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-C@*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT
M(&UE<W-A9V4B"FUS9W-T<B`B0G+X9'1E:W-T96X@868@9&5N('-E;F1T92!B
M97-K960B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M
M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(D1E;B!A9G-E;F1T
M92!B97-K961S(&)R^&1T96MS="!K86X@<V5S("5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HQ-30*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S
M='(@(D)R=6=E<F5N<R!L961I9R]O<'1A9V5T+6EN9F]R;6%T:6]N(&5R(&=E
M;70N(@H*(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HX-@IM
M<V=I9"`B5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S('1H870@8V%N
M(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D1E<B!F:6YD97,@:6MK
M92!N;V=E;B!A;'1E<FYA=&EV(&1E;"P@<V]M(&MA;B!V:7-E<R!I;F1L96IR
M970N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z
M,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O
M>"XB"FUS9W-T<B`B1&5R(&5R(&EN9V5N(&)E<VME9&5R(&EN(&1E;FYE(&UA
M:6QB;W@N(@H*(SH@=&AR96%D+G!H<#HQ,#D*;7-G:60@(E1H97)E(&ES(&YO
M('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B
M1&5R(&9I;F1E<R!I;F=E;B!B<OAD=&5K<W0L('-O;2!K86X@=FES97,@:6YD
M;&5J<F5T+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB1&5R(&]P
M<W1O9"!E="!P<F]B;&5M('5N9&5R('3X;6YI;F<@868@)7,N($1E='1E(&5R
M+"!H=F%D('-E<G9E<F5N('-V87)E9&4B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-C4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM
M<V=S='(@(D1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!T^&UN:6YG(&%F
M(&UA:6QB;WAE;BX@4V5R=F5R96X@<W9A<F5D93H@)7,B"@HC.B!L:6(O365S
M<V%G92YP:'`Z-C(Q"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N
M9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9"(*;7-G<W1R("(B"B)$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@=/AM
M;FEN9R!A9B!M86EL8F]X96XN($1E='1E(&5R+"!H=F%D('-E<G9E<F5N("(*
M(G-V87)E9&4B"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G
M97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*
M(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(D1E<B!O<'-T;V0@96X@9F5J;"!U
M;F1E<B!K;W!I97)I;F<@868@8F5S:V5D97(@9G)A(%PB)7-<(B!T:6P@7"(E
M<UPB+B`B"B)397)V97)E;B!S:W)I=F5R(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C$Y."!L:6(O365S<V%G92YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M
M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E<G9E
M<B!S86ED(@IM<V=S='(@(B(*(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!S
M;&5T;FEN9V5N(&%F(&)E<VME9&5N(&9R82!M87!P96X@7"(E<UPB+B!(97(@
M97(@(@HB8F5S:V5D96X@9G)A('-E<G9E<F5N(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB
M1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R('-L971N:6YG96X@868@8F5S:V5D
M97(@:2!M87!P96X@7"(E<UPB+B!(97(@97(@(@HB8F5S:V5D96X@9G)A('-E
M<G9E<F5N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(Q,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(D1E
M<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!S;&5T;FEN9R!A9B!B97-K961E<BX@
M4V5R=F5R96X@<VMR978Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")$97(@;W!S=&]D
M(&5N(&9E:FP@=6YD97(@<VQE=&YI;F<@868@:.9N9&5L<V5N.B`E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E
M<B]E;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D1E<B!O<'-T
M;V0@96X@9F5J;"!U;F1E<B!V:7-N:6YG(&%F(&1E;FYE(&)E<VME9&1E;"(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A9V4N<&AP.C4X-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9FQA
M9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@
M=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB1&5R(&]P<W1O
M9"!E;B!F96IL('5N9&5R(&UA<FME<FEN9R!A9B!B97-K961E<B!I(&UA<'!E
M;B!<(B5S7"(N($1E='1E(&5R("(*(F)E<VME9&5N9G)A('-E<G9E<F5N(@H*
M(SH@9F]L9&5R<RYP:'`Z,38U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@)7,N(@IM<V=S='(@(D1E<B!O<'-T
M;V0@96X@9F5J;"!U;F1E<B!I;7!O<G1E<FEN9V5N(&%F("5S+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S
M+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T97)I
M;F=E;B!A9B!HYFYD96QS93H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS9W-T<B`B1&5R(&]P
M<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG96X@868@;W!G879E;CH@
M)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S
M97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R("(B"B)$
M97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T97)I;F=E;B!A9B!B<G5G
M97)S7&XB"B)L961I9R]O<'1A9V5T(&EN9F]R;6%T:6]N.B`E<R(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O
M(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G
M<W1R("(B"B)$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@9FQY=&YI;F=E;B!A
M9B!B97-K961E<B!F<F$@7"(E<UPB('1I;"!<(B5S7"(N7&XB"B)397)V97)E
M;B!S:W)E=B(*"B,Z(&-O;7!O<V4N<&AP.C$R-#0*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S(&$@9')A9G0N(@IM
M<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!L86=R:6YG(&%F(&1E
M;FYE(&)E<VME9"!S;VT@:VQA9&1E+B(*"B,Z(&-O;7!O<V4N<&AP.C$P,#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E;F1I
M;F<@>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E
M:FP@=6YD97(@869S96YD96QS96X@868@9&EN(&)E<VME9#H@)7,B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E;G0Z("5S
M+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@YFYD<FEN9V5N
M(&%F(&CF;F1E;'-E;CH@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN
M+G!H<#HU.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B1&5R('9A<B!I;F=E;B!T96MS="!I(&1E;FYE
M(&1E;"!A9B!B97-K961E;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY-PIM<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E
M9&1E9"!I;B!I="XB"FUS9W-T<B`B2%1-3"UB97-K961E;B!H87(@:6YD;&5J
M<F5D92!B:6QL961E<BXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M.3`*;7-G:60@(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB
M961D960@:6X@:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L:6ME("(*(G1H
M:7,Z("(*;7-G<W1R("(B"B)$96YN92!(5$U,+6)E<VME9"!H87(@:6YD;&5J
M<F5D92!B:6QL961E<BX@($)L;VMK97)E9&4@8FEL;&5D97(@=FES97,@(@HB
M<^5L961E<SH@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V"FUS
M9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@
M;65S<V%G92XB"FUS9W-T<B`B1&5N;F4@;V9F96YT;&EG92!01U`M;OAG;&4@
M97(@:.9F=&5T('9E9"!B97-K961E;BXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3`T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3@*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,R!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,34W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S,@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q-`IM<V=I9"`B5&AI<R!A8W1I
M;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1&5N;F4@:&%N9&QI;F<@
M97(@:6MK92!U;F1E<G-T^'1T970N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$W.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$Y"FUS9VED
M(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+B(*;7-G<W1R
M(")$96YN92!H86YD;&EN9R!E<B!E;F1N=2!I:VME(&EM<&QE;65N=&5R970N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I
M9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B1&5T=&4@=&%G97(@;F]K(&YO
M9V5T('1I9"X@17(@9'4@<VEK:V5R('#E+"!A="!D=2!V:6P@9F]R='/F='1E
M(#\B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS
M9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB
M"FUS9W-T<B`B0F5S:V5D96X@:6YD96AO;&1E<B!E;B!-86-I;G1O<V@M9FEL
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$P"FUS9VED("(B
M"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA
M<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS9W-T
M<B`B(@HB0F5S:V5D96X@;65D8G)I;F=E<B!E;B!V961HYF9T96QS92P@<V]M
M(&5R(&1I9VET86QT('-I9VYE<F5T('9I82!3+TU)344N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HT,30*;7-G:60@(E1H:7,@;65S<V%G92!C
M;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC<GEP=&5D
M('9I82!3+TU)344N(@IM<V=S='(@(D)E<VME9&5N(&UE9&)R:6YG97(@96X@
M=F5D:.9F=&5L<V4L('-O;2!E<B!K<GEP=&5R970@=FEA(%,O34E-12XB"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H
M:7,@;65S<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O
M<FUA=&EO;BP@8G5T('1H92!F;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES
M('5N:VYO=VXN(@IM<V=S='(@(B(*(D)E<VME9&5N(&EN9&5H;VQD97(@/&5M
M/FUA:6P@9&5L:79E<GD@<W1A='5S/"]E;3X@:6YF;W)M871I;VXL(&UE;B!F
M;W)M871E="`B"B)A9B!B97-K961E;B!E<B!U:V5N9'0N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,S$U"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M
M97-S86=E+B!%<G)O<CH@(@IM<V=S='(@(D)E<VME9&5N('-Y;F5S(&EK:V4@
M870@=N9R92!E;B!G>6QD:6<@4$=0+6MR>7!T97)E="!B97-K960N("!&96IL
M.B`B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,S4P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@
M*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(D)E<VME9&5N
M('-Y;F5S(&EK:V4@870@=N9R92!I(&MO<G)E:W0@4$=0+69O<FUA="`H:N9V
M;F;X<B!21D,@,C`Q-2DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HQ-S`*;7-G:60@(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@:6X@=&AE(&-O<G)E8W0@4R]-24U%(&9O<FUA="XB"FUS9W-T<B`B0F5S
M:V5D96X@<WEN97,@:6MK92!A="!VYG)E(&D@:V]R<F5K="!3+TU)344M9F]R
M;6%T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HT,38*;7-G:60@(E1H:7,@;65S<V%G92!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N(@IM<V=S='(@(D)E<VME
M9&5N(&5R(&1I9VET86QT('-I9VYE<F5T('9I82!01U`N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S<V%G92!H
M87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM<V=S='(@
M(D)E<VME9&5N(&5R(&1I9VET86QT('-I9VYE<F5T('9I82!3+TU)344N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ,SD@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E
M;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B0F5S:V5D96X@97(@
M:W)Y<'1E<F5T('9I82!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,C`Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,0IM<V=I9"`B
M5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS
M9W-T<B`B0F5S:V5D96X@97(@:W)Y<'1E<F5T(&UE9"!01U`N(@H*(SH@;65S
M<V%G92YP:'`Z,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T<B`B
M1&5N;F4@8F5S:V5D('1I;"(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H:7,@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G
M<W1R(")$96YN92!S97)V97(@=6YD97)S=/AT=&5R(&EK:V4@9&5L:6YG(&%F
M(&UA<'!E<BXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$P.0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A
M(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R(")$971T92!V:6YD=64@<VMA;"!A
M;G+E8F5S(&9R82!E;B!S:W)I=FYI;F=S=FEN9'5E+B(*"B,Z('1H<F5A9"YP
M:'`Z,34R"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G<W1R(")4<N5D970@
M=FES;FEN9R(*"B,Z('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDR,@IM<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B5'+E9&5T('9I
M<VYI;F<B"@HC.B!M97-S86=E+G!H<#HR-C0@;6%I;&)O>"YP:'`Z-C`V('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C8Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M8V]M<&]S92YI;F,Z,3`@;&EB+U-E87)C:"YP:'`Z,C8*;7-G:60@(E1O(@IM
M<V=S='(@(E1I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3D*;7-G
M:60@(E1O($%D9')E<W,B"FUS9W-T<B`B5&\Z($%D<F5S<V4B"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O
M('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM
M<V=S='(@(B(*(D9O<B!A="!M87)K97)E(&9L97)E(&9E;'1E<B!S:V%L(&1U
M(&AO;&1E($-T<FP@*%!#*2!E;&QE<B!#;VUM86YD("A-86,I("(*(FYE9&4L
M(&UE9&5N<R!D=2!K;&EK:V5R+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M,3,T"FUS9VED("(B"B)4;R!U<V4@82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU
M<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@;V8@4$A0(#4N,"XV(&]R("(*(FAI
M9VAE<BXB"FUS9W-T<B`B(@HB1F]R(&%T(&)R=6=E(&5N(%1,4RUF;W)B:6YD
M96QS92!S:V%L(&1U(&%N=F5N9&4@4$A0(#4N,"XV(&5L;&5R(&CX:F5R92XB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@
M(E1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z(@IM<V=S='(@(E9E9&CF9G1E;'-E
M<G,@=&]T86QE('-T^')R96QS93HB"@HC.B!F;VQD97)S+G!H<#HS.#@*;7-G
M:60@(E1R87-H(&9O;&1E<B(*;7-G<W1R(")3:W)A;&1E<W!A;F0B"@HC.B!T
M96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4<F%S
M:"!F;VQD97(Z(@IM<V=S='(@(E-K<F%L9&5S<&%N9#HB"@HC.B!L:6(O475O
M=&$O8WER=7,N<&AP.C8U(&QI8B]1=6]T82]M97)C=7)Y,S(N<&AP.C<Y(&QI
M8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC.B!L:6(O475O=&$O;&]G9FEL92YP
M:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP.C4S(&QI8B]1=6]T82]M9&%E
M;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O(')E=')I979E('%U;W1A(@IM
M<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@:W9O=&4B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R(")58F5S=F%R970B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5;F%N
M<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(E5B97-V87)E9&4@8F5S:V5D97(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-"!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B56YD96QE
M=&4B"FUS9W-T<B`B1F]R=')Y9"!S;&5T;FEN9R(*"B,Z(&UA:6QB;W@N<&AP
M.C4X.2!M86EL8F]X+G!H<#HV,#(@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$R
M"FUS9VED(")5;F1I<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(DEK:V4@
M=FES=&4@;6]D=&%G97)E(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT
M(&]F('1Y<&4Z("5S(@IM<V=S='(@(E5HY6YD=&5R970@:V]M<&]N96YT(&%F
M('1Y<&4Z("5S(@H*(SH@;6%I;&)O>"YP:'`Z-38U"FUS9VED(")5;FMN;W=N
M($1A=&4B"FUS9W-T<B`B56ME;F1T(&1A=&\B"@HC.B!L:6(O24U!4"]#;&EE
M;G0N<&AP.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N($E-05`@
M<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B!397)V97(@4F5S<&]N9&5D.B`E
M<R(*;7-G<W1R(")5:V5N9'0@24U!4"!R97-P;VYS(&9R82!S97)V97)E;BX@
M4V5R=F5R(&UE;&1T93H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C,U"FUS9VED(")5;FMN;W=N($UE971I;F<B"FUS9W-T<B`B56ME;F1T
M(&WX9&4B"@HC.B!M86EL8F]X+G!H<#HV,3@*;7-G:60@(E5N:VYO=VX@4F5C
M:7!I96YT(@IM<V=S='(@(E5K96YD="!M;V1T86=E<B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W
M"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*;7-G<W1R(")/<&CF=B!L^'-E
M;B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HV-0IM<V=I9"`B56YN86UE9"(*
M;7-G<W1R(")):VME(&YA=FYG:79E="(*"B,Z(&UE<W-A9V4N<&AP.C0Y.2!M
M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,34@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*;7-G<W1R(")5
M;.9S="(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$R"FUS
M9VED(")5;G-U8G-C<FEB92!F<F]M($9O;&1E<BAS*2(*;7-G<W1R(")$96%K
M=&EV97(@;6%P<&4H<BDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU.#0*;7-G:60@(E5P9&%T92!!='1A8VAM96YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D]P9&%TZ7(@:6YF;W)M871I;VX@;VT@=F5D:.9F=&5L<V4B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(P"FUS9VED(")5<&1A
M=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B3W!D873I<B!S=&%T=7,@
M;VX@<F5S<&]N9&5N="(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y
M+FEN8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED
M(")5<&QO860B"FUS9W-T<B`B57!L;V%D(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U;'0@5F%L
M=64B"FUS9W-T<B`B0G)U9R!S=&%N9&%R9';F<F1I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B57-E($E-05`@9F]L9&5R('-U8G-C
M<FEP=&EO;G,_(@IM<V=S='(@(D)R=6<@24U!4"!M87!P92!A:W1I=F5R:6YG
M97(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S-0IM<V=I9"`B57-E
M(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*;7-G<W1R(")!;G9E;F0@=FER='5E
M;"!S:W)A;&1E<W!A;F0_(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$T
M,@IM<V=I9"`B57-E<B(*;7-G<W1R(")"<G5G97(B"@HC.B!A8VPN<&AP.C@W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F
M=6QL>2!G:79E;B!T:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(D)R=6=E<B!<(B5S7"(@=&EL9&5L="!D92!G
M:79N92!R971T:6=H961E<B!T:6P@;6%P<&4@7"(E<UPB+B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<W"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R(")"<G5G97)N879N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B0G)U9V5R;F%V
M;CHB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I
M9"`B5FEE=R(*;7-G<W1R(")392(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N
M<&AP.CDR(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")6:7,@)7,B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(%!U8FQI8R!+97DB
M"FUS9W-T<B`B4V4@)7,@;V9F96YT;&EG(&[X9VQE(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C$Q-@IM<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B4V4@2%1-3"UI;F1H;VQD
M(&D@970@<V5P97)A="!V:6YD=64B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHR.`IM<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R(")3
M92!B97-K961E<B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6:65W(%!E<G-O;F%L
M(%!R:79A=&4@2V5Y(@IM<V=S='(@(E-E(&5G96X@<')I=F%T(&[X9VQE(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S(*;7-G:60@(E9I97<@4&5R<V]N86P@4'5B;&EC($ME>2(*
M;7-G<W1R(")392!E9V5N(&]F9F5N=&QI9R!N^&=L92(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B5FEE=R!4
M:')E860B"FUS9W-T<B`B4V4@='+E9"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$V,R!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C4*
M;7-G:60@(E9I97<@5&AU;6)N86EL(@IM<V=S='(@(E-E(&9R:6WF<FME(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*;7-G:60@(E9I97<@
M871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")392!V
M961HYF9T96QS97(@:2!E="!S97!E<F%T('9I;F1U92(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]R96QA=&5D+G!H<#HW.0IM<V=I9"`B5FEE=R!C;VYT96YT(&EN
M(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(E-E(&EN9&AO;&0@:2!E="!S
M97!E<F%T('9I;F1U92XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,30P"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(E-E(&CF;F1E;'-E(@H*
M(SH@9F]L9&5R<RYP:'`Z,S@P(&UA:6QB;W@N<&AP.C4S-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(E-E(&)E
M<VME9"!I("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L
M96-T+FEN8SHR,PIM<V=I9"`B5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@
M869T97(@;&]G:6XZ(@IM<V=S='(@(E9I<VYI;F<@96QL97(@8G)E=F)A:VME
M+"!S;VT@=FES92!E9G1E<B!L;V=I;CHB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3<P"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B4V4@;W!G
M879E(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P,0IM<V=I9"`B
M5FEE=R!T:&4@26UA9V5S(@IM<V=S='(@(E-E(&)I;&QE9&5R;F4B"@HC.B!S
M96%R8V@N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L($9O
M;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`B5FER
M='5E;"!M87!P92!<(B5S7"(@97(@9&%N;F5T+B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])34%0+U1R964N<&AP.C$S."!L:6(O
M24U!4"]4<F5E+G!H<#HQ-3$*(SH@;&EB+TE-05`O5')E92YP:'`Z,34S(&QI
M8B])34%0+U1R964N<&AP.C$U-R!L:6(O24U!4"]4<F5E+G!H<#HQ-3@*(SH@
M;&EB+TE-05`O5')E92YP:'`Z,S8Y(&QI8B])34%0+U1R964N<&AP.C,Y,R!L
M:6(O24U!4"]4<F5E+G!H<#HT,S,*;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*
M;7-G<W1R(")6:7)T=65L;&4@;6%P<&5R(@H*(SH@<V5A<F-H+G!H<#HR-#4*
M;7-G:60@(E9I<G1U86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN(@IM<V=S
M='(@(E9I<G1U96QL92!M87!P97(@:W+F=F5R(&5N('9I9VYE="XB"@HC.B!L
M:6(O5D9O;&1E<BYP:'`Z,3<U(&QI8B]61F]L9&5R+G!H<#HQ.#`*;7-G:60@
M(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`B5FER='5E;"!I;F1B86MK92(*"B,Z
M(&9O;&1E<G,N<&AP.C0Q-@IM<V=I9"`B5FER='5A;"!)3D)/6"!&;VQD97(B
M"FUS9W-T<B`B5FER='5E;"!I;F1B86MK92!M87!P92(*"B,Z(&UA:6QB;W@N
M<&AP.C0U,B!L:6(O5D9O;&1E<BYP:'`Z,3$T(&QI8B]61F]L9&5R+G!H<#HQ
M,3D*;7-G:60@(E9I<G1U86P@5')A<V@B"FUS9W-T<B`B5FER='5E;"!S:W)A
M;&1E<W!A;F0B"@HC.B!F;VQD97)S+G!H<#HT,3,*;7-G:60@(E9I<G1U86P@
M5')A<V@@1F]L9&5R(@IM<V=S='(@(E9I<G1U96P@<VMR86QD97-P86YD(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U
M86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@(E9I<G1U96P@;6%P<&4@=FEG;F5T
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S0*;7-G:60@(E=A
M<FYI;F<B"FUS9W-T<B`B061V87)S96PB"@HC.B!L;V=I;BYP:'`Z,3,X"B,L
M('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5F5L
M:V]M;65N('1I;"`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3D*
M;7-G:60@(B(*(E=H870@<VAO=6QD('=E(&1O('=I=&@@<W!A;2!M97-S86=E
M<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R
M(&EN;F]C96YT/R(*;7-G<W1R("(B"B)(=F%D('-K86P@9&5R('-K92!M960@
M<W!A;2UB97-K961E<B!E9G1E<B!A="!D92!E<B!I;F1B97)E='1E="!S;VT@
M<W!A;2`B"B)E;&QE<B!U<VMY;&1I9S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S(W"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M
M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K
M:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HB3N5R(&1U('-L
M971T97(@8F5S:V5D97(L('-K86P@9&4@9FQY='1E<R!T:6P@<VMR86QD97-P
M86YD96X@:2!S=&5D970@9F]R(&%T("(*(FUA<FME<F4@9&5M('-O;2!S;&5T
M=&5T/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(E=H
M96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W
M86YT('1O('-T87)T(&]N/R(*;7-G<W1R(")(=FEL:V5N('-I9&4@^&YS:V5R
M(&1U('/E(&%T('-T87)T92!PY2!V960@Y6)N:6YG(&%F(&5N(&YY(&)R979B
M86MK93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7
M:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE
M;G0@9&%T83\B"FUS9W-T<B`B4VMA;"!V961HYF9T96QS97(@9V5M;65S('9E
M9"!L86=R:6YG(&%F(&%F<V5N9'0@92UM86EL/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,C8*;7-G:60@(B(*(E=H96X@<V5N9&EN9R!M86EL(&]R
M(&5X<&%N9&EN9R!A9&1R97-S97,L('=H870@9&]M86EN('-H;W5L9"!W92!A
M<'!E;F0@=&\@(@HB=6YQ=6%L:69I960@861D<F5S<V5S("AE;6%I;"!A9&1R
M97-S97,@=VET:&]U="!<(D!<(BD_(@IM<V=S='(@(B(*(DAV:6QK970@9&]M
MYFYE('-K86P@969T97)S:W)I=F5S('5F=6QD<W3F;F1I9V4@861R97-S97(@
M*&4M;6%I;"UA9')E<W-E<B`B"B)U9&5N(%PB0%PB*2!V960@869S96YD96QS
M92!A9B!E+6UA:6P@96QL97(@=61V:61D96QS92!A9B!A9')E<W-E<C\B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E=H:71E;&ES
M="(*;7-G<W1R(")0;W-I=&EV;&ES=&4B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW.`IM
M<V=I9"`B665S(@IM<V=S='(@(DIA(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HU.`IM<V=I9"`B66]U(&%R92!A8F]U
M="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I;F<@86-C;W5N="AS
M*3HB"FUS9W-T<B`B1'4@97(@=F5D(&%T(&AE;G1E(&4M;6%I;"!F<F$@9OAL
M9V5N9&4@:V]N=&\O:V]N=&DZ(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L
M9&5R<U]C;VYF:7)M+FAT;6PZ,3`*;7-G:60@(B(*(EEO=2!A<F4@871T96UP
M=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@
M9F]L;&]W:6YG(&9O;&1E<B(*(BAS*2XB"FUS9W-T<B`B1'4@97(@=F5D(&%T
M('-L971T92!A;&QE(&)E<VME9&5R(&EN9&5H;VQD="!I(&;X;&=E;F1E(&UA
M<'!E+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH
M=&UL.CD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@=&AE
M(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(D1U(&5R('9E9"!A="!S
M;&5T=&4@9&4H;BD@9OAL9V5N9&4@;6%P<&4H<BDN(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O<'EI;F<O;6]V
M:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B1'4@97(@=F5D(&%T(&MO
M<&EE<F4O9FQY='1E('1I;"!E;B!N>2!M87!P92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$P,@IM<V=I9"`B66]U(&%R92!C<F5A
M=&EN9R!A('-U8BUF;VQD97(@=&\@(@IM<V=S='(@(D1U(&5R('9E9"!A="!O
M<')E='1E(&5N('5N9&5R;6%P<&4@=&EL("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")9;W4@87)E(&-R96%T:6YG
M(&$@=&]P+6QE=F5L(&9O;&1E<BXB"FUS9W-T<B`B1'4@97(@=F5D(&%T(&]P
M<F5T=&4@96X@;6%P<&4@<.4@:/AJ97-T92!N:79E874N(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,S(P"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!F;VQD97)S+B(*;7-G<W1R(")$=2!H87(@:6MK92!T:6QL861E;'-E
M('1I;"!A="!D86YN92!M87!P97(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(W
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R(")$=2!H87(@
M:6MK92!T:6QL861E;'-E('1I;"!A="!D86YN92!F;&5R92!E;F0@)60@;6%P
M<&5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,U
M"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z("(*;7-G<W1R
M(")$=2!E<B!V960@870@;VUD^&)E(&UA<'!E;CH@(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!C86X@;F]T('5N
M<W5B<V-R:6)E(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")$=2!K86X@:6MK92!D
M96%K=&EV97)E(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U
M<V4@=&AE(&9O;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE
M<GD@=&5X=#H@)6,@9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N
M=#L@)7,@9F]R('1H92!S:6=N871U<F4N(@IM<V=S='(@(B(*(D1U(&MA;B!B
M96YY='1E(&1I<W-E(&5R<W1A=&YI;F=E<B!I(&)R979P87!I<BUT96MS=&5N
M.B`E8R!F;W(@9&5N(&%K='5E;&QE("(*(F)R^&1T96MS=#L@)7,@9F]R('-I
M9VYA='5R96XN(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E
M;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O('1H
M92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T
M(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*(D1U(&%C8V5P=&5R
M961E(&EK:V4@8G)U9W-B971I;F=E;'-E<FYE+"!H=F]R=F5D(&1U(&5R(&)L
M979E="!NYF=T970@861G86YG+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHQ-CD*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H
M86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS9W-T<B`B1'4@:&%R(&EK
M:V4@=&EL;&%D96QS92!T:6P@870@YFYD<F4@861G86YG('1I;"!D96YN92!M
M87!P92(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&9O<G=A<F1E9"!T:&ES(&UE<W-A9V4@;VX@)25S('1O('1H
M92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N(@IM<V=S='(@(D1U('9I9&5R
M97-E;F1T92!D96YN92!B97-K960@9&5N("4E<R!T:6P@9OAL9V5N9&4@;6]D
M=&%G97)E.B`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@;65S<V%G
M97,N(@IM<V=S='(@(D1U(&AA<B`E<R!N>64@8F5S:V5D97(N(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H879E(#$@
M;F5W(&UE<W-A9V4N(@IM<V=S='(@(D1U(&AA<B`Q(&YY(&)E<VME9"XB"@HC
M.B!C;VUP;W-E+G!H<#HT.30*;7-G:60@(EEO=2!H879E(&%L<F5A9'D@<W5B
M;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T<B`B1&5N;F4@<VED92!E<B!A;&QE
M<F5D92!A9G-E;F1T+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA=F4@870@;&5A<W0@;VYE(&%T
M=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T('5P;&]A9"!Y970N
M($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD('1H:7,@;65S<V%G
M92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S/R(*;7-G<W1R("(B"B)$=2!H
M87(@;6EN9'-T(.EN('9E9&CF9G1E;'-E(&UA<FME<F5T+"!S;VT@9'4@96YD
M;G4@:6MK92!H87(@:&5N=&5T+B`@17(@9'4@(@HB<VEK:V5R('#E+"!A="!V
M:6P@<V5N9&4@8F5S:V5D('5D96X@9&ES<V4@=F5D:.9F=&5L<V5R/R(*"B,Z
M(&QI8B])35`N<&AP.C$P-S0*;7-G:60@(EEO=2!H879E(&YE=R!M86EL(&EN
M('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R(")$=2!H87(@;GEE(&)E
M<VME9&5R(&D@9OAL9V5N9&4@;6%P<&4Z(@H*(SH@;&EB+TE-4"YP:'`Z,3`W
M.0IM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F
M;VQD97)S.B(*;7-G<W1R(")$=2!H87(@;GEE(&)E<VME9&5R(&D@9OAL9V5N
M9&4@;6%P<&5R.B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PIM<V=I9"`B66]U(&UU
M<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS9W-T<B`B1&5R
M('-K86P@86YG:79E<R!M:6YD<W0@96X@;6]D=&%G97(N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,S`R"FUS9VED("(B"B)9;W4@;75S="!E;G1E
M<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@
M=FEE=R!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B(@HB1'4@<VMA;"!A;F=I=F4@
M;/AS96YE="!T:6P@9&EN('!R:79A=&4@4$=0+6[X9VQE(&9O<B!A="!S92!D
M96YN92!B97-K960B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T
M.0IM<V=I9"`B(@HB66]U(&UU<W0@96YT97(@=&AE('!A<W-P:')A<V4@9F]R
M('EO=7(@4R]-24U%('!R:79A=&4@:V5Y('1O('9I97<@=&AI<R`B"B)M97-S
M86=E(@IM<V=S='(@(B(*(D1U('-K86P@86YG:79E(&SX<V5N970@=&EL(&1I
M;B!P<FEV871E(%,O34E-12UN^&=L92!F;W(@870@<V4@9&5N;F4@8F5S:V5D
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-C0@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS9VED(")9;W4@
M;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB"FUS9W-T<B`B
M5N9L9R!M86EL8F]X(&;X<G-T+"!S;VT@<VMA;"!A;G9E;F1E<RXB"@HC.B!F
M971C:&UA:6QP<F5F<RYP:'`Z.#4*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S='(@(D1U('-K86P@=N9L
M9V4@96X@:V]N=&\L('-O;2!D=2!V:6P@<VQE='1E+B(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z.#$*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R(")$=2!S:V%L(&;X<G-T
M(';F;&=E(&5N(&%D<F5S<V4N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V
M87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V
M,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E
M(&9I<G-T+B(*;7-G<W1R(")$=2!S:V%L(';F;&=E(&UI;F1S="!E;B!B97-K
M960@9OAR<W0N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G
M<W1R(")$=2!S:V%L(&%N9VEV92!E;B!M;V1T86=E<BXB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHR.0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A="!L96%S="!O;F4@9FEL92!T;R!A='1A8V@N(@IM<V=S='(@
M(D1U('-K86P@86YG:79E(&UI;F1S="#I;B!F:6PL(&1E<B!S:V%L('9E9&CF
M9G1E<RXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@
M96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@
M(B(*(D1U(&)L:79E<B!N^&1T('1I;"!A="!H879E(%PB)7-<(B!S;.5E="!T
M:6P@:2!D:6YE("(*(G9E9&QI9V5H;VQD96QS97-I;F1S=&EL;&EN9V5R+B(*
M"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(')E9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS
M9W-T<B`B1'4@;VUA9')E<W-E<F5D92!D96YN92!B97-K960@=&EL("5S(&1E
M;B`E)7,N(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$T,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM
M<V=S='(@(D1U(&)E<W9A<F5D92!D96YN92!B97-K960@9&5N("5S+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B7"(E<UPB(&)L978@:6MK92!A:W1I
M=F5R970N($AE<B!E<B!B97-K961E;B!F<F$@<V5R=F5R96XB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HU-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@
M;F]T('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H
M92!S97)V97(@<V%I9"(*;7-G<W1R(")<(B5S7"(@8FQE=B!I:VME(&1E86MT
M:79E<F5T+B!(97(@97(@8F5S:V5D96X@9G)A('-E<G9E<F5N(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E
M('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")<
M(B5S7"(@8FQE=B!A:W1I=F5R970B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('5N
M<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@8FQE=B!D
M96%K=&EV97)E="(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHY.`IM<V=I
M9"`B66]U<B!.86UE(@IM<V=S='(@(D1I="!N879N(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C4P"FUS9VED(")9;W5R(%!'4"!0=6)L:6,O4')I=F%T
M92!+97ES(@IM<V=S='(@(D1I;F4@;V9F96YT;&EG92]P<FEV871E(%!'4"UN
M^&=L97(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Q('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-@IM<V=I9"`B66]U<B!0<FEV871E($ME>2(*
M;7-G<W1R(")$:6X@<')I=F%T92!N^&=L92(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<Q"FUS9VED
M(")9;W5R(%!U8FQI8R!+97DB"FUS9W-T<B`B1&EN(&]F9F5N=&QI9V4@;OAG
M;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38U"FUS9VED(")9;W5R
M(%)E<&QY+71O.B!A9&1R97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S
M='(@(B(*(F4M;6%I;"UA9')E<W-E;BP@<V]M(&%N9')E('-E;F1E<B!S=F%R
M('1I;"`H4F5P;'DM=&\Z*2`\96T^*'9A;&=F<FDI/"]E;3XB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-12!0
M=6)L:6,O4')I=F%T92!#97)T:69I8V%T97,B"FUS9W-T<B`B1&EN92!O9F9E
M;G1L:6=E+W!R:79A=&4@4R]-24U%+6-E<G1I9FEK871E<B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C$V"FUS9VED(")9
M;W5R(&%C8V]U;G1S.B(*;7-G<W1R(")$:6YE(&MO;G1I.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-S,*;7-G:60@(B(*(EEO=7(@86QI87,@861D
M<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@
M82!N97<@;&EN92D\+V5M/B(*;7-G<W1R(")$:6YE(&%L:6%S+6%D<F5S<V5R
M.B`\96T^*'9A;&=F<FDL(.EN(&%D<F5S<V4@<'(N(&QI;FEE*3PO96T^(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H
M:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B1&EN(&)R;W=S97(@=6YD97)S=/AT
M=&5R(&EK:V4@:6YD;&5J<F5T('9I<VYI;F<@868@9&5T=&4@8FEL;&5D9F]R
M;6%T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,SD*;7-G:60@(EEO
M=7(@9&5F875L="!C:&%R<V5T(&9O<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G
M<W1R(")$:70@;F]R;6%L92!T96=N<^9T('1I;"!A9G-E;F1E;'-E(&%F(&)E
M<VME9&5R.B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN
M8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M971H;V0@9F]R
M('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(D1I;B!N;W)M86QE(&MR>7!T
M97)I;F=S;65T;V1E('1I;"!A9G-E;F1E;'-E(&%F(&)E<VME9&5R.B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@Y"FUS9VED(")9;W5R(&UE
M<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(D1I
M;B!B97-K960@97(@869L979E<F5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,#8*;7-G:60@(EEO=7(@<VEG;F%T=7)E.B(*;7-G<W1R(")$:6X@
M<VEG;F%T=7(Z(@H*(SH@;65S<V%G92YP:'`Z,C@X(&-O;7!O<V4N<&AP.C$R
M.#0@;6%I;&)O>"YP:'`Z-30Y(&QI8B]#;VUP;W-E+G!H<#HX,3@*;7-G:60@
M(EM.;R!3=6)J96-T72(*;7-G<W1R(");26YT970@96UN95TB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*;7-G:60@(E]"8V,B"FUS
M9W-T<B`B0F-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS
M9VED(")?0FQA8VML:7-T(@IM<V=S='(@(D)L86-K;&ES=&4B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-30*;7-G:60@(E]#8R(*;7-G
M<W1R(")#8R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHV('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*;7-G:60@(E]$96QE=&4B
M"FUS9W-T<B`B4VQE="(*"B,Z(&QI8B])35`N<&AP.CDW.0IM<V=I9"`B7T9O
M;&1E<G,B"FUS9W-T<B`B36%P<&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z.#$*;7-G:60@(E])9&5N=&ET>2(*;7-G<W1R(")0<F]F
M:6PB"@HC.B!L:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G<W1R
M("));F1B86MK92(*"B,Z(&QI8B])35`N<&AP.C$P,C`*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(DQO9R!U9"(*"B,Z(&UE<W-A9V4N<&AP.C,X-`IM<V=I
M9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(DMI;&1E=&5K<W0B"@HC.B!L
M:6(O24U0+G!H<#HY-S8*;7-G:60@(E].97<@365S<V%G92(*;7-G<W1R(").
M>64@8F5S:V5D(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C,S"FUS9VED(")?4')I;G0B"FUS9W-T<B`B561S:W)I=B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.#D*;7-G:60@(E]0<FEO<FET>2(*;7-G
M<W1R(")0<FEO<FET970B"@HC.B!M86EL8F]X+G!H<#HT,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7U)E9G)E<V@@)7,B"FUS9W-T<B`B1V5N;W!F<FES:R`E
M<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX
M"FUS9VED(")?4F5P;'DB"FUS9W-T<B`B4W9A<B(*"B,Z(&QI8B])35`N<&AP
M.CDX,0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")3^&<B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,S$*;7-G:60@(E]396YD($UE<W-A9V4B"FUS9W-T<B`B
M069S96YD(&)E<VME9"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,S(*;7-G:60@(E]4:')E860B"FUS9W-T<B`B5'+E9"(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Q-@IM<V=I9"`B
M7U1O(@IM<V=S='(@(E1I;"(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C$S"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`B1F]R=')Y9"!S
M;&5T;FEN9R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ.`IM<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S='(@(E-E('1RY60B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET
M96QI<W0B"FUS9W-T<B`B4&]S:71I=FQI<W1E(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$W-@IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B861R
M97-S96YT('5K96YD="(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-#`*;7-G:60@
M(F%T=&%C:&UE;G0B"FUS9W-T<B`B=F5D:.9F=&5L<V4B"@HC.B!V:65W+G!H
M<#HY.0IM<V=I9"`B871T86-H;65N=',N>FEP(@IM<V=S='(@(G9E9&CF9G1E
M;'-E<BYZ:7`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,3,*;7-G:60@(F)Y=&5S(@IM<V=S='(@(F]K=&5T97(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,C`P"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE
M(@IM<V=S='(@(FMA;B!I:VME(&1A;FYE('5D9&%T82UF:6PB"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,3<R"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G
M<W1R(")K86X@:6MK92#E8FYE(&EN9&1A=&$B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,38T"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T
M<B`B9F5J;"!V960@86YV96YD96QS92!A9B!K;VUM86YD;RUL:6YI92(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR,C`*;7-G:60@(F-O;F9I9W5R871I;VX@97)R
M;W(B"FUS9W-T<B`B:V]N9FEG=7)A=&EO;G-F96IL(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C$Y-@IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9R(*;7-G<W1R(")M86YG;&5R(&MR:71I<VL@<WES=&5M9FEL(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$V.`IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS
M9W-T<B`B9F5J;"!I(&1A=&%F;W)M870B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,C(T"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B:6YD9V%N9R!I
M:VME(&9U;F1E="(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3DP"FUS9VED(")F<F]M(@IM<V=S='(@(F9R82(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HQ.#`*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@
M(G5K96YD="!M87-K:6YN879N(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P-`IM
M<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(FEN9&1A=&$O=61D
M871A+69E:FPB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@X"FUS9VED(")I;G1E
M<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R(")I;G1E<FX@<V]F='=A<F4M
M9F5J;"(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8Y"FUS9VED(")K97DB
M"FUS9W-T<B`B;OAG;&4B"@HC.B!F;VQD97)S+G!H<#HQ-C$*;7-G:60@(FUA
M:6QB;W@@9FEL92(*;7-G<W1R(")B<F5V8F%K:V4M9FEL(@H*(SH@8V]M<&]S
M92YP:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")N86UE(@IM
M<V=S='(@(FYA=FXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`B:6YG96XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*;7-G<W1R
M(")E;&QE<B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,38*;7-G:60@(G!E<FUI
M<W-I;VX@9&5N:65D(@IM<V=S='(@(G1I;&QA9&5L<V4@;N9G=&5T(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C(Q,@IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R
M;W1O8V]L(@IM<V=S='(@(F9E:FP@:2!P<F]T;VMO;"!F<F$@9FIE<FX@<VED
M92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#0*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B=&IE;F5S=&4@=71I;&?F;F=E;&EG(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L
M;&EN9R!E<G)O<B(*;7-G<W1R(")S=&%V969E:FPB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R
M<R(*;7-G<W1R(")S=&%V969E:FPB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DR
M"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B<WES=&5M9F5J;"(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR,#@*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E
M(@IM<V=S='(@(FUI9&QE<G1I9&EG(&9E:FQT:6QS=&%N9"(*"B,Z(&QI8B]&
M:6QT97(N<&AP.C4Q"FUS9VED(")Y;W5R(&)L86-K;&ES="(*;7-G<W1R(")D
M:6X@8FQA8VML:7-T92(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED(")Y
M;W5R('=H:71E;&ES="(*;7-G<W1R(")D:6X@<&]S:71I=FQI<W1E(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+V-S
M7T-:+G!O````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#0Q-#`T-0`Q,#0Q-S,V,C<V-``P,3<Q-S<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!)35`@0WIE8V@@5')A;G-L
M871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*(R!4
M:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS
M92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!0879E;"!#:'ET:6P@/'!A=F5L
M0&-H>71I;"YT:SXL(#(P,#$M,C`P-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*
M(E!R;VIE8W0M260M5F5R<VEO;CH@24U0(#0N,"XS7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@(#(P,#$M,#<M,C8@,30Z-38M,#DP,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!-:6QO<R!7:6UM97(@/'=I;6UE<D!Z8W4N8WH^7&XB"B),86YG
M=6%G92U496%M.B!#>F5C:"`\9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@."UB:71<;B(*(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU
M<F%L/2AN)3$P/3TQ("8F(&XE,3`P(3TQ,2`_(#`@.B!N)3$P/CTR("8F(&XE
M(@HB,3`\/30@)B8@*&XE,3`P/#$P('Q\(&XE,3`P/CTR,"D@/R`Q(#H@,BD[
M7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@
M("`@("!#8SH@(@IM<V=S='(@(B`@("`@($MO;74Z("(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HT,34*;7-G:60@(B`@("`@(%1O.B`B"FUS9W-T<B`B("`@("`@
M2V]M=3H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0P,PIM<V=I9"`B("`@($1A
M=&4Z("(*;7-G<W1R("(@("`@1&%T=6TZ("(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HT,#8*;7-G:60@(B`@("!&<F]M.B`B"FUS9W-T<B`B("`@($]D.B`B"@HC
M.B!M86EL8F]X+G!H<#HT,C(@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B("A0^.US='5P;W;](&ML[>@@)7,I(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0Q,@IM<V=I9"`B(%-U8FIE8W0Z("(*;7-G<W1R("(@4/AE9&WL=#H@(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<P"FUS9VED("(@
M:6X@(@IM<V=S='(@(B!V("(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T<B`B(R(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B`O("4N
M,F9-0B`@*"4N,F8E)2DB"@HC.B!T:')E860N<&AP.C$U,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T<B`BKN%D;ND@
M>G!RX79Y(@H*(SH@;6%I;&)O>"YP:'`Z,3<V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B)60@>G!RX78H82D@8GEL;RAA*2!V>6UA>N%N;RAA*2XB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3<X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE
M<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R
M('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B(E9"!Z<'+A=B!B
M>6QO(&YA:&SAN65N;R!68;EE;74@<WES=.EM;W;I;74@861M:6YI<W1RX71O
M<F]V:2!J86MO(&-H=.QNZ2`B"B)Z<'+A=GD@*&AA;2DN(@H*(SH@;&EB+U-P
M86TN<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H
M879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(B5D('IP
M<N%V(&)Y;&\@;F%H;.&Y96YO(&IA:V\@8VAT[&[I('IP<N%V>2`H:&%M*2XB
M"@HC.B!L:6(O4W!A;2YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(B5D('IP<N%V(&)Y
M;&\@;F%H;.&Y96YO(%9AN65M=2!S>7-TZ6UO=NEM=2!A9&UI;FES='+A=&]R
M;W9I(&IA:V\@;F5C:'3L;ND@(@HB>G!RX79Y("AS<&%M*2XB"@HC.B!L:6(O
M4W!A;2YP:'`Z,34P"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R("(E9"!Z<'+A
M=B!B>6QO(&YA:&SAN65N;R!J86MO(&YE8VAT[&[I('IP<N%V>2`H<W!A;2DN
M(@H*(SH@;6%I;&)O>"YP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M('1O("5D(&]F("5D($UE<W-A9V5S(@IM<V=S='(@(B5D(&&^("5D('H@)60@
M>G!RX78B"@HC.B!M86EL8F]X+G!H<#HV-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!L:6(O36%I;G1E;F%N8V4O
M5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R
M('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@=;X@97AI<W1U:F4N(%-L
M;[YK82`E<R!N96)Y;&$@</AE:FUE;F]VX6YA+B(*"B,Z(&QI8B]-97-S86=E
M+G!H<#HV-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B)7,@;F5N[2!P
M;&%T;N$@<V-H<N%N:V$N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N
M86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0R"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O9B!T
M:&4@;6]N=&@N(@IM<V=S='(@(DYA('IAZ.%T:W4@;>QS[6-E(&)U9&4@<VQO
MOFMA("5S('#X96IM96YO=N%N82XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!A8V-E<'1E
M9"XB"FUS9W-T<B`B)7,@</AI:F%L*&$I+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&-A
M;F-E;&QE9"`E<RXB"FUS9W-T<B`B)7,@>G)UN6EL*&$I("5S+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R("(E<R!O9&WM=&YU;"AA*2XB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#DS"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E
M<W0N(@IM<V=S='(@(B5S(&]D<&]V[&3L;"AA*2!N82"^X61O<W0@9G)E92]B
M=7-Y+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I
M;VX@=&\@)7,N(@IM<V=S='(@(B5S(&]D<&]V[&3L;"AA*2!N82!P;WIVX6YK
M=2!K("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I
M;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@>F%S;&%L*&$I(&EN9F]R;6%C:2!O
M(&9R964O8G5S>2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A8V-E
M<'1E9"XB"FUS9W-T<B`B)7,@</AE9&+LOF[L('#X:6IA;"AA*2XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@W"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(E<R"^X63A(&\@:6YF;W)M86-I(&\@9G)E92]B=7-Y+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T
M<B`B)7,@ON%DX2!O(%9AN6D@^NAA<W0@;F$@)7,N(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C0Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(B5S(&)Y
M;"AA*2#Z<W#LN6[L('#X:63A;BAA*2!D;R`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I
M<VAE<R!T;R!A;6UE;F0@)7,N(@IM<V=S='(@(B5S('-I('#X96IE(/IP<F%V
M=2`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O
M9B`E<RXB"FUS9W-T<B`B)7,@<VD@</AE:F4@5N%S('5P;WIO<FYI="!N82`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@
M:6YF;W)M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B5S('-I('#X96IE(&]B
M9'*^970@86MT=>%L;NT@:6YF;W)M86-E(&\@)7,N(@H*(SH@;65S<V%G92YP
M:'`Z,C@U(&UE<W-A9V4N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7W1O<"YI;F,Z,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S
M("@E9"9N8G-P.V]F)FYB<W`[)60I(@IM<V=S='(@(B5S.B`E<R`H)60F;F)S
M<#MZ)FYB<W`[)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$S,PIM<V=I9"`B*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@
M=&\@;F5X="!S8W)E96XN*2(*;7-G<W1R("(H06MT:79O=F%T('IM[&YY(&$@
M</AE<W5N;W5T('-E(&YA(&1A;+GM('-T<N%N:W4N*2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`*;7-G:60@(BA$:7-C87)D(&%L
M;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BDB
M"FUS9W-T<B`B(@HB*%IR=;EI="!VN65C:&YY('IM[&YY(&$@</AE<W5N;W5T
M('-E(&YA('-T<N%N:W4L(&MD92!S92!V>71VX?CM(&YO=N$@>G!RX79A+BDB
M"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*(RP@9G5Z
M>GD*;7-G:60@(BA(5$U,*2(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB
M"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E
M='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL
M(&-H86YG97,@;6%D92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U
M<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B
M"B(H4/AE<W7R('-E(&YA('-T<N%N:W4L(&MD92!S92!V>71VX?CM(&YO=N$@
M>G!RX79A('!O=.D@8V\@<V4@86MT=6%L:7IU:NT@(@HB=KEE8VAN>2!D;W-A
M=F%D;NT@>FWL;GDN("!:;>QN>2!N82!S;W7H87-NZ2!S='+A;F-E($Y%0E5$
M3U4@<&]UOFET>2XI(@H*(SH@<W!E;&QI;F<N<&AP.C(W-PIM<V=I9"`B(@HB
M*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E
M('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E96X@
M=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BA0;W-L870@>G!R
MX79U('!O(&%K=&EV;W;A;NT@=KEE8VAN>2!D;W-A=F%D;NUC:"!Z;>QN+B!:
M;>QN>2!N82!S;W7H87-NZ2`B"B)S='+A;F-E($Y%0E5$3U4@<&]UOFET>2XI
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C<*;7-G
M:60@(BH@061D('1H97-E(&)Y(&-L:6-K:6YG($]+("HB"FUS9W-T<B`B*B!0
M^&ED870@='ET;R!K;&EK;G5T[6T@;F$@3TL@*B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS9VED("(J(%!L96%S92!S96QE
M8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(%!R;W/M;2!V>6)E<G1E(&5M
M86EL;W9O=2CI*2!A9')E<W4H>2D@*B(*"B,Z(&UA:6QB;W@N<&AP.C$W-`HC
M+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(EIP<N%V82!B>6QA('9Y;6%ZX6YA+B(*"B,Z(&QI8B]3<&%M+G!H
M<#HQ.#`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B(Q('IP<N%V82!B>6QA(&YA:&SAN65N82!68;EE;74@<WES=.EM;W;I
M;74@861M:6YI<W1RX71O<F]V:2!J86MO(&-H=.QNX2`B"B)Z<'+A=F$@*&AA
M;2DN(@H*(SH@;&EB+U-P86TN<&AP.C$V,`IM<V=I9"`B,2!M97-S86=E(&AA
M<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(Q('IP<N%V
M82!B>6QA(&YA:&SAN65N82!J86MO(&-H=.QNX2!Z<'+A=F$@*&AA;2DN(@H*
M(SH@;&EB+U-P86TN<&AP.C$W,@IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N
M(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB,2!Z<'+A=F$@8GEL82!N86ALX;EE;F$@5F&Y96UU
M('-Y<W3I;6]VZ6UU(&%D;6EN:7-T<N%T;W)O=FD@:F%K;R!N96-H=.QNX2`B
M"B)Z<'+A=F$@*'-P86TI+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*;7-G:60@
M(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M+B(*;7-G<W1R
M("(Q('IP<N%V82!B>6QA(&YA:&SAN65N82!J86MO(&YE8VAT[&[A('IP<N%V
M82`H<W!A;2DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q.0IM<V=I
M9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B,3`P('IN86OY(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R,@IM<V=I9"`B,3`P,"!C:&%R86-T97)S
M(@IM<V=S='(@(C$P,#`@>FYA:_DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#(P"FUS9VED("(R-3`@8VAA<F%C=&5R<R(*;7-G<W1R("(R-3`@>FYA
M:_DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(Q"FUS9VED("(U,#`@
M8VAA<F%C=&5R<R(*;7-G<W1R("(U,#`@>FYA:_DB"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B02!L
M87)G92!I;6%G92!N86UE9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A
M9V4N(@IM<V=S='(@(EIP<N%V82!O8G-A:'5J92!P^.UL;VAU('9E(&9O<FWL
M('9E;&OI:&\@;V)RX7IK=2!S(&[A>G9E;2`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,`IM<V=I9"`B(@HB02!M97-S86=E
M('EO=2!H879E('-E;G0@:&%S(')E<W5L=&5D(&EN(&$@<F5T=7)N(&YO=&EF
M:6-A=&EO;B!F<F]M('1H92`B"B)R96-I<&EE;G0N(@IM<V=S='(@(E;A;6D@
M>F%S;&%NX2!Z<'+A=F$@8GEL82!P;W1V<GIE;F$@</CM:F5M8V5M+B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU"FUS9VED(")!3D0B"FUS
M9W-T<B`B02(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3`*;7-G
M:60@(D%C8V5P="!R97%U97-T(@IM<V=S='(@(E#X:6IM;W5T('!OOF%D879E
M:R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*(RP@9G5Z>GD*
M;7-G:60@(D%C8V5P="!R97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD
M87(B"FUS9W-T<B`B563A;&]S="!B>6QA('#X:63A;F$@9&\@5F&Y96AO(&MA
M;&5N9.'X92XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4S"FUS
M9VED(")!8V-E<'1E9"(*;7-G<W1R(")0^&EJ871O(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(U-PIM<V=I9"`B06-C97!T960Z("(*;7-G<W1R
M(")0^&EJ871O.B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHW"FUS9VED(")!8V-O=6YT)W,@;F%M93HB"FUS9W-T<B`B3N%Z978@^NAT
M=3HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(P(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,S`*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B
M06MC92(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(P,"!L:6(O34E-12](
M96%D97)S+G!H<#HR,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D
M9"`E<R!T;R!M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B5FQOOFET(&1O(&%D
M<F5SX?AE("@E<RDB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHS,#,*;7-G:60@(D%D9"!S;W5R8V4B"FUS9W-T<B`B4/AI9&%T('ID
M<F]J(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-R!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3@X"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C
M86QE;F1A<B(*;7-G<W1R(")0^&ED870@='5T;R!P;VQOOFMU(&1O(&MA;&5N
M9.'X92(*"B,Z(&-O;7!O<V4N<&AP.C$R-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D960@7"(E<UPB(&%S(&%N(&%T=&%C:&UE;G0N(@IM<V=S='(@(E#X
M:61A="!<(B5S7"(@:F%K;R!P^.UL;VAU+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.3@*(RP@9G5Z>GD*;7-G:60@(B(*(D%D9&ET:6]N86P@:&5A
M9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO<'1I;VYA;"P@
M96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@;&EN92D\+V5M/B(*;7-G
M<W1R("(B"B):;V)R87II="!D86RY[2!H;&%V:>AK>2!P^&D@<')O:&SMOF5N
M[3H@/&D^*&YE<&]V:6YNZ2P@=FQOOFET(&MAOF1O=2`B"B)H;&%V:>AK=2!N
M82!N;W;](/CA9&5K*3PO:3XB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L
M(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(D1A;+GM
M(&EN9F]R;6%C92!M;VAO=2!B_70@>F]B<F%Z96YY("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"FUS9VED(")!9&1I=&EO
M;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS9W-T<B`B1&%LN>T@:6YF;W)M
M8>AN[2!D971A:6QY(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M.3,*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(@IM<V=S='(@
M(D1A;+GM(&1E=&%I;'D@;R!Z<'+A=NPB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L
M(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")$
M86RY[2!D971A:6QY(&\@>G!RX7;L(&UO:&]U(&+]="!Z;V)R87IE;GD@)7,N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D
M9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@(D1A;+GM
M(&1E=&%I;'D@;R!C:'EB;W;I;2!H;.&Y96[M(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I97=E9"`E<RXB
M"FUS9W-T<B`B1&%LN>T@9&5T86EL>2!O(&-H>6)O=NEM(&ALX;EE;NT@;6]H
M;W4@8OUT('IO8G)A>F5N>2`E<RXB"@HC.B!C;VYT86-T<RYP:'`Z.#4@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHU,@IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D
M<F5SX?@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"FUS9VED(")!
M9&1R97-S($)O;VMS(@IM<V=S='(@(D%D<F5SX?AE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$X.0HC+"!F=7IZ>0IM<V=I9"`B(@HB061D<F5S<V5S
M('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A
M8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM<V=S='(@(B(*
M(D5M86EL;W;I(&%D<F5S>2!P<F\@0F-C('!R;R!VN65C:&YY('IP<N%V>3H@
M/&D^*&YE<&]V:6YNZ2P@=FQOOFET(&MAOF1O=2`B"B)H;&%V:>AK=2!N82!N
M;W;](/CA9&5K*3PO:3XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q
M"B,L(&9U>GIY"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T
M:64@=&\@=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C
M:"`B"B)A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB
M16UA:6QO=ND@861R97-Y('!A=/CM8^T@=.ET;R!I9&5N=&ET[#H@/&D^*&YE
M<&]V:6YNZ2P@=FQOOFET(&MAOF1O=2!H;&%V:>AK=2`B"B)N82!N;W;](/CA
M9&5K*3PO:3XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$P
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C,*;7-G:60@(D%L;"(*;7-G<W1R
M(")6N64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S
M"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD
M97(H<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@(@HB9FEL
M93HB"FUS9W-T<B`B(@HB5KEE8VAN>2!Z<'+A=GD@=B!NX7-L961U:NUC[2!S
M;&^^8V4@8G5D;W4@</AE;>US=.QN>2!D;R!J961N;VAO($U"3U@@<V]U8F]R
M=3HB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('EO
M=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P
M97)M86YE;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R("(B"B)6N65C:&YY('IP
M<N%V>2!V92!68;GM(%PB)7-<(B!S;&^^8V4@<W1A<KGM(&YEOB`E<R!D;NT@
M8G5D;W4@=')V86QE('9Y;6%ZX6YY+B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@
M(B(*(E:Y96-H;GD@</CM;&]H>2!U;&^^96[I(&IA:V\@;V1K87HL(&MT97+I
M(&IS;W4@<W1A<KGM(&[LOB`E<R!M['/M8_DL(&)U9&]U("(*(G9Y;6%ZX6YY
M+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E
M;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@
M8F4@9&5L971E9"XB"FUS9W-T<B`B(@HB5KEE8VAN>2!S=&%RZ2!S;&^^:WD@
M<R!O9&5S;&%N;W4@<&^Y=&]U('-T87*Y[2!N[+X@)7,@;>QS[6/Y(&)U9&]U
M('9Y;6%ZX6YY+B(*"B,Z(&%C;"YP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C97-S
M9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(B(*(E:Y
M96-H;F$@<'+A=F$@<')O('-L;[YK=2`G)7,G(&)Y;&$@^G-P[+EN["!O9'-T
M<F%N[&YA('!R;R!UOFEV871E;&4@)R5S)RXB"@HC.B!L:6(O87!I+G!H<#HW
M-@IM<V=I9"`B06QL;W<@1F]L9&5R($-R96%T:6]N/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#@*;7-G:60@(D%L;&]W
M(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/R(*
M;7-G<W1R(")$;W9O;&ET('!O=;YI=.T@9FEL=')O=F%C[6-H('!R879I9&5L
M(&YA(&IA:V]U:V]L:78@<V-H<N%N:W4_(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%L=&5R;F%T:79E+G!H<#HQ,3`*;7-G:60@(D%L=&5R;F%T:79E('!A<G1S
M(&9O<B!T:&ES('-E8W1I;VXZ(@IM<V=S='(@(D%L=&5R;F%T:79N[2#HX7-T
M:2!TZ71O('-E:V-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S(@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X-`IM<V=I9"`B06QW87ES(@IM<V=S
M='(@(E:^9'DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34W"FUS9VED
M(")!;'=A>7,@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(")6OF1Y('5L;[YI
M="!P^.UL;VAU+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HU,#4*;7-G:60@(B(*
M(D%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T
M:&4@871T86-H;65N="X@5&AE($E-05`@<V5R=F5R("(*(G-A:60Z("(*;7-G
M<W1R("(B"B).87-T86QA(&-H>6)A('#X:2!P;VMU<W4@;R!O9'-T<F%N[&[M
M('#X[6QO:'D@>F4@>G!RX79Y+B!(;.&Y96[M('H@24U!4"`B"B)S97)V97)U
M.B`B"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE
M=R!N;W1E+B(*;7-G<W1R(")0^&D@>F%K;.%DX6[M(&YO=NEH;R#Z:V]L=2!D
M;[EL;R!K(&YE>F[A;>D@8VAY8NPN(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X
M-PIM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T
M:6YG('1H92!N97<@=&%S:RXB"FUS9W-T<B`B4/AI('IA:VSA9.%N[2!N;W;I
M:&\@^FMO;'4@9&^Y;&\@:R!N97INX6WI(&-H>6+L+B(*"B,Z(&UE<W-A9V4N
M<&AP.C4P,"!M86EL8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHY"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D
M(@IM<V=S='(@(D]D<&]V['IE;NDB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C,Q"FUS9VED(")!;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")/
M9'!O=NQZ96[I('IP<N%V>2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z-PIM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R(")0;W6^[70@
M9FEL=')Y(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS9W-T
M<B`B4&]UONUT(&9I;'1R>2!N82`E<R(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHS-@IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('5P;VX@
M;&]G9VEN9R!O;C\B"FUS9W-T<B`B4&]UONUT(&9I;'1R;W9A8^T@<')A=FED
M;&$@</AI('#X:6ALX;EE;NT@9&\@<WES=.EM=3\B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z-#(*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE
M<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_(@IM<V=S='(@(E!O=;[M
M="!F:6QT<F]V86/M('!R879I9&QA(':^9'D@</AI('IO8G)A>F5N[2!)3D)/
M6'4_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(*;7-G<W1R(")*<W1E('-I
M(&II<W3M+""^92!C:&-E=&4@=GEM87IA="!T96YT;R!V9?AE:F[](&ML[>@_
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z.#4*;7-G:60@(B(*(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!D96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM
M96YD960A*2(*;7-G<W1R("(B"B)*<W1E('-I(&II<W3M+""^92!C:&-E=&4@
M=GEM87IA="!T96YT;R!K;.WH;W;]('#A<C\@*%1O=&\@;F5N[2!D;W!O<G7H
M96YO("(*(G!R;W;A9.QT(2DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(*;7-G<W1R
M(")*<W1E('-I(&II<W3M+""^92!T;R!C:&-E=&4@=63L;&%T/R(*"B,Z(&UE
M<W-A9V4N<&AP.C0P-R!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHV.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.
M5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`B2G-T92!S:2!J
M:7-T[2P@OF4@8VAC971E(%!%4DU!3D5.5$[,('-M87IA="!T>71O('IP<N%V
M>3\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@
M871T86-H;65N=#\B"FUS9W-T<B`B2G-T92!S:2!J:7-T[2P@OF4@<VD@8VAC
M971E(%!%4DU!3D5.5$[,('-M87IA="!T=71O('#X[6QO:'4_(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`B
M2G-T92!S:2!J:7-T[2P@OF4@8VAC971E('9Y<'+A>F1N:70@='5T;R!S;&^^
M:W4_(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U>GIY"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B
M"FUS9W-T<B`B2G-T92!S:2!J:7-T[2P@OF4@8VAC971E('9Y<'+A>F1N:70@
M<VQOOFMU(&MON64_(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_
M(@IM<V=S='(@(DIS=&4@<VD@:FES=.TL(+YE(&-H8V5T92!V>7!RX7ID;FET
M('-L;[YK=2!K;[EE/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE
M;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(DIS=&4@<VD@
M:FES=.TL(+YE(&-H8V5T92!015)-04Y!3E1.S"!S;6%Z870@='ET;R!Z<'+A
M=GD_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@
M=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S
M(&EN;F]C96YT/R(*;7-G<W1R(")*<W1E('-I(&II<W3M+""^92!C:&-E=&4@
M;F%H;.%S:70@='5T;R!Z<'+A=G4@:F%K;R!C:'3L;F]U("AH86TI/R(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E
M<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*
M;7-G<W1R(")*<W1E('-I(&II<W3M+""^92!C:&-E=&4@;F%H;.%S:70@='5T
M;R!Z<'+A=G4@:F%K;R!N96-H=.QN;W4@*'-P86TI/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,38*;7-G:60@(D%R<FEV86P@5&EM92(*;7-G<W1R
M("+(87,@9&]R=>AE;NTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Q
M"FUS9VED(")!<V-E;F1I;F<B"FUS9W-T<B`B5GIE<W1U<&[L(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B6F5P=&%T('-E(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$Y"FUS9VED(")!='1A8V@B"FUS
M9W-T<B`B4/AI;&^^:70B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT-S4*;7-G:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R(")0^&EL;[YI
M="!S;W5B;W)Y(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#4V"FUS9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K
M97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R(")0^&EL;[YI="!K;W!I:2!6
M8;EE:&\@4$=0(&ML[>AE(&L@>F%S;&%NZ2!Z<'+A=NP_(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W1N968N<&AP.C$P.0IM<V=I9"`B071T86-H960@1FEL93HB
M"FUS9W-T<B`B4/AI;&^^:70@<V]U8F]R(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0U,2!L:6(O0V]M<&]S92YP:'`Z-3,V"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE(&%T=&%C:&UE
M;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*;7-G<W1R("(B
M"B)0^&EL;[YE;ND@<V]U8F]R>2!<(B5S7"(@</AE<V%H=6KM('!O=F]L96[]
M(&QI;6ET('!R;R!V96QI:V]S="!P^.UL;V@N("(*(E-O=6)O<B!.14)93"!P
M^&EL;[YE;BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S<V"FUS
M9VED(")!='1A8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q=65S
M="!Y;W4@<V5N="XB"FUS9W-T<B`B4/AI;&^^96YA(&IE(&]D<&]V[.\@5F&Y
M[2"^X61O<W1I('H@:V%L96YDX?AE+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VQE9V5N9"YI;F,Z,38@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N
M:6YC.C$T"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-B!T
M96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHY-PIM<V=I9"`B071T
M86-H;65N="(*;7-G<W1R(")0^.UL;VAA(@H*(SH@8V]M<&]S92YP:'`Z,3`V
M-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")!='1A8VAM96YT('-T<FEP
M<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T<B`B4/CM;&]H
M82!O9'-T<F%N[&YA.B!/<FEG;N%L;NT@='EP('#X[6QO:'DB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#D@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#<S"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#<S"FUS
M9VED(")!='1A8VAM96YT<R(*;7-G<W1R(")0^.UL;VAY(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8X,@IM<V=I9"`B071T96YD965S(@IM<V=S
M='(@(MKH87-T;NUC:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I
M;VXN<&AP.C4S"FUS9VED(")!='1E;G1I;VXB"FUS9W-T<B`B4&]Z;W(B"@HC
M.B!L:6(O075T:"]I;7`N<&AP.C0T"FUS9VED(")!=71H7VEM<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM
M<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@24U!
M4"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0P"FUS9VED("(B"B)!
M=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A434P@;65S<V%G97,@=VAE
M;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*(F%D9')E<W-B;V]K/R(*;7-G<W1R
M("(B"B)!=71O;6%T:6-K>2!Z;V)R87II="!O8G+A>FMY('8@2%1-3"!Z<'+A
M=N%C:"P@<&]K=60@:F4@;V1E<^UL871E;"!V(&WI;2`B"B)A9')E<^'X:3\B
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3@*;7-G
M:60@(D%V86EL86)L92!!9&1R97-S(&)O;VMS.B(*;7-G<W1R(")$;W-T=7!N
MZ2!A9')E<^'X93HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S$Y
M"FUS9VED(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R(")/Z&5KX79A;N$@
M;V1P;W;L[R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS
M9W-T<B`B6G#L7W0@9&\@)7,B"@HC.B!T:')E860N<&AP.C$S-R!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M
M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B6G#L="!D;R`E<R(*"B,Z
M('1H<F5A9"YP:'`Z,3,T"FUS9VED(")"86-K('1O($UU;'1I<&QE($UE<W-A
M9V4@5FEE=R!);F1E>"(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C$S,@IM
M<V=I9"`B0F%C:R!T;R!4:')E860@1&ES<&QA>2(*;7-G<W1R("(B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C,X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")"
M860@;W(@;6%L9F]R;65D(')E<75E<W0N(%-E<G9E<B!297-P;VYD960Z("5S
M(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(R,@HC.B!T96UP;&%T97,O8V]M<&]S92]R
M96-O;7!O<V4N:6YC.C(P(&QI8B]396%R8V@N<&AP.C,T"FUS9VED(")"8V,B
M"FUS9W-T<B`B4VMR>73A($MO<&EE(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z,38Q"FUS9VED(")"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@
M=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+B(*;7-G<W1R(").[;YE
M(&IE('5V961E;F$@9&]S;&]V;N$@:6YF;W)M8>AN[2!Z<'+A=F$@;R!S=&%V
M=2XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(D)L
M86-K;&ES="(*;7-G<W1R("+(97)NX2!L:7-T:6YA(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8R.0IM<V=I9"`B0FQO8VL@:6UA9V5S(&EN($A434P@
M;65S<V%G97,@=6YL97-S('1H97D@87)E('-P96-I9FEC86QL>2!R97%U97-T
M960_(@IM<V=S='(@(D)L;VMO=F%T(&]B<N%Z:WD@=B!(5$U,('IP<N%VX6-H
M+"!P;VMU9"!N96IS;W4@:FEN86L@ON%DX6YY/R(*"B,Z(&QI8B]396%R8V@N
M<&AP.C0R"FUS9VED(")";V1Y(@IM<V=S='(@(E3L;&\B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C(S('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,SD*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU-2!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C<Q"FUS9VED(")";W1H(@IM<V=S='(@(D]B
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#<*;7-G:60@(D)O=&@@
M2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R(")/
M8F]J[2`M('-E>FYA;2!H;&%V:>AE:R!A('3L;"!Z<'+A=B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(W,@IM<V=I9"`B0U]H87)S970B
M"FUS9W-T<B`B6E]N86MO=N$@4V%D82(*"B,Z('1E;7!L871E<R]S96%R8V@O
M9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YD
MX?@B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(P,0IM<V=I9"`B0V%N
M(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N(@IM<V=S
M='(@(DYE;'IE('-E('#X:7!O:FET(&ME('9Z9.%L96[I;74@<&^Y=&]V;NUM
M=2!S97)V97)U(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ.3D*;7-G
M:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R
M.B`B"FUS9W-T<B`B3F5L>F4@<V4@</AI<&]J:70@:V4@=GIDX6QE;NEM=2!P
M;[ET;W9N[6UU('-E<G9E<G4Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P87)T
M:6%L+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T(&1I
M<W!L87D@+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S
M<V%G92!I;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R("(B"B).
M96QZ92!Z;V)R87II="`M(&)Y;&\@;F%L97IE;F\@<&]U>F4@)7,@Z.%S=.T@
M>B`E<R!P<F\@='5T;R!Z<'+A=G4@=B`B"B)S;W7H87-NZ2!S8VARX6YC92XB
M"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR
M,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M
M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*
M(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(EIR=;EI="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C<Q('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S
M-0HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED
M(")#86YC96P@365S<V%G92(*;7-G<W1R("):<G6Y:70@>G!RX79U(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")#86YC96QL:6YG('1H:7,@;65S
M<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+B(*
M;7-G<W1R("(B"B):<G6Y96[M('3I=&\@>G!RX79Y(&)U9&4@;>UT('IA(&[A
M<VQE9&5K(&MO;7!L971N[2!Z='+A='4@:F5J[6AO(&]B<V%H=2XB"@HC.B!M
M97-S86=E+G!H<#HR-C4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN
M8SHR,C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ-2!L
M:6(O4V5A<F-H+G!H<#HS,`IM<V=I9"`B0V,B"FUS9W-T<B`B2V]P:64B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDS"FUS9VED("(B"B)#97)T
M:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@
M:7,@;F]T(&5N86)L960@;VX@=&AI<R`B"B)S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#$*;7-G:60@(D-H86ER
M(%!E<G-O;B(*;7-G<W1R(")0^&5D<V5D86KM8^TB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R
M("):;>QN:70B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M.#$*;7-G:60@(D-H86YG92!!;&PB"FUS9W-T<B`B6FWL;FET(':Y92(*"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B0VAA;F=E($9O;&1E
M<B(*;7-G<W1R("):;>QN:70@<VQOOFMU(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,@IM<V=I9"`B(@HB0VAA;F=E(&1I<W!L87D@;W!T:6]N<R!S
M=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S('EO=2!S964@;VX@96%C:"!P86=E
M(&%N9"`B"B)H;W<@;65S<V%G97,@87)E('-O<G1E9"XB"FUS9W-T<B`B(@HB
M3F%S=&%V96[M('9L87-T;F]S=.T@>F]B<F%Z96[M(&IA:V\@;F%P^"X@:V]L
M:6L@>G!RX78@8G5D92!N82!J961NZ2!S='+A;F-E("(*(F$@:F%K(&)U9&]U
M('5S<&_XX63A;GDN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS
M9VED(")#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB
M"FUS9W-T<B`B3F%S=&%V96[M(%9AN65H;R!P;[ET;W9N[6AO('-E<G9E<G4@
M82!S;&^^96LN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U"FUS9VED
M("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"`B"B)R97!L>2!T
M;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B).87-T879E;NT@:FWI;F$L(&5M
M86EL;W;I(&%D<F5S>2!A('-I9VYA='5R>2P@:W1E<ND@=FED[2!P^.UJ96UC
M:2!68;EI8V@@(@HB>G!RX78N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@R-`IM<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P;&%Y.B(*;7-G<W1R("):
M;F%K>2!P<F\@>F]B<F%Z96[M.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C$U"FUS9VED(")#:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-
M86EL(@IM<V=S='(@(EIK;VYT<F]L;W9A="!N;W9O=2!P;[ET=2!V92!S;&^^
M8V4H<VQOOFOA8V@I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C<U
M"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B6FMO;G1R;VQO=F%T
M(%]VN64OON%D;NDB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I
M;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(Q
M"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W86YT('1O(&9E
M=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B6FMO;G1R;VQO=F%T(':Y96-H;GD@
M<&^Y=&]V;NT@<V5R=F5R>2!K92!S=&&^96[M(&YO=ND@<&^Y='DZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V,PIM<V=I9"`B0VAE8VL@<W!E;&QI
M;F<@8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R(")::V]N=')O
M;&]V870@<')A=F]P:7,@</AE9"!O9&5S;.%N[6T@>G!RX79Y/R(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G:60@(D-H;V]S92!!
M8W1I;VXZ(@IM<V=S='(@(E9Y8G)A="!A:V-I.B(*"B,Z(&-O;F9I9R]S97)V
M97)S+G!H<"YD:7-T.C$X,@IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z
M(@IM<V=S='(@(E9Y8G)A="!P;[ET;W9N[2!S97)V97(Z(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR,3<*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D
M:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R(")0<F]S[6T@
M=GEB97)T92!N96)O('5P<F%V=&4@=B!B;WAU('9P<F%V;SHB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW,S$*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(E9Y
M8G)A="!A:V-I.B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,T.0IM<V=I9"`B0VAO;W-E('1H92!A9&1R97-S(&)O;VL@=&\@=7-E
M('=H96X@861D:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B5GEB<F%T(&%D<F5S
MX?@L(&MT97+](&)U9&4@<&]UOFET('#X:2!Z863A=N%N[2!A9')E<RXB"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3,*;7-G:60@
M(D-H;V]S92!T:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@
M=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("(B"B)6>6)R870@
M<&_X863M(&%D<F5SX?CY+"!V(&IA:^EM(&)U9&]U('!R;VAL963A=N%N>2!P
M^&D@97AP86YD;W;A;NT@861R97,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R
M;W=S97(@8V%N('9I97<N(@IM<V=S='(@(B(*(DML:6MN['1E(&YA("5S('!R
M;R!K;VYV97)Z:2!O8G+A>FMO=NEH;R!S;W5B;W)U(&YA('1Y<"P@:W1E<OT@
M;'IE('IO8G)A>FET+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D
M('1H92!I;6%G92XB"FUS9W-T<B`B2VQI:V[L=&4@;F$@)7,@:R!S=&&^96[M
M(&]B<N%Z:W4N(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@<&%G
M92XB"FUS9W-T<B`B2VQI:V[L=&4@;F$@)7,@<')O('#X96-H;V0@;F$@)7,@
M<W1RX6YK=2!S(&UA;F%G96UE;G1E;2XB"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3$V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G
M<W1R(")+;&EK;NQT92!N82`E<R!P<F\@>F]B<F%Z96[M($A434P@;V)S86AU
M('8@;F]VZ6T@;VMN["XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A
M('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R(")+;&EK;NQT92!N
M82`E<R!P<F\@>F]B<F%Z96[M(&UI;FEA='5R>2!T;VAO=&\@;V)RX7IK=2(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@
M82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(DML:6MN['1E(&YA("5S('!R
M;R!Z;V)R87IE;NT@</CM;&]H>2!V(&YO=NEM(&]K;NPN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L:6-K("5S('1O('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T
M(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")+;&EK;NQT92!N82`E
M<R!P<F\@>F]B<F%Z96[M('-O=79I<V5J[6/M(.CA<W1I('8@;F]VZ6T@;VMN
M["XB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@(D-L
M:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S(@IM<V=S='(@(DML:6MN['1E
M('ID92!P<F\@6D]"4D%:14[-(&]B<N%Z:_DB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*;7-G:60@(B(*(D-L:6-K(&]N(&]N
M92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L
M96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*;7-G<W1R("(B"B)+;&EK
M;NQT92!N82!J961E;B!Z(%9AN6EC:"!A9')E<^'X^2!A('9Y8F5R=&4@=KEE
M8VAN82!P;VQE+"!K=&5RX2!S92!B=61O=2`B"B)P<F]H;&5DX79A="XB"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S$*;7-G:60@(D-L:6-K('1O
M(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VLB"FUS
M9W-T<B`B2VQI:VYU=.UM('5L;[[M=&4@4$=0('9E^&5J;OT@:VSMZ"!D;R!S
M=NEH;R!A9')E<^'X92(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,C`R"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-24U%
M(&-E<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K(@IM<V=S
M='(@(DML:6MN=73M;2!U;&^^[71E(%,O34E-12!C97)T:69I:^%T("5S(&1O
M('-VZ6AO(&%D<F5SX?AE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU
M,`IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E
M(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G<W1R(")+;&EK;G5T
M[6T@;F$@861R97-U(&QZ92!V>71V;_AI="!N;W9O=2!Z<'+A=G4@<')O(&]D
M97/M;&%T96QE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,0IM<V=I
M9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S
M86=E('1O(&)E(')E860B"FUS9W-T<B`B2VQI:VYU=.UM(&YA(&%D<F5S=2!L
M>F4@>F]B<F%Z:70@>G!RX79U(&L@</AEZ'1E;NTB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S
M='(@(E5Z87;X[70B"@HC.B!C;VUP;W-E+G!H<#HX,C@@8V]M<&]S92YP:'`Z
M,3$T.`IM<V=I9"`B0VQO<V4@=&AI<R!W:6YD;W<B"FUS9W-T<B`B57IA=OCM
M="!T;W1O(&]K;F\B"@HC.B!F;VQD97)S+G!H<#HT,CD*;7-G:60@(D-L;W-E
M9"!&;VQD97(B"FUS9W-T<B`B57IA=OCM="!S;&^^:W4B"@HC.B!F;VQD97)S
M+G!H<#HT-#D*;7-G:60@(D-O;&QA<'-E(@IM<V=S='(@(E-K;&%P;F]U="(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")#
M;VQL87!S92!!;&PB"FUS9W-T<B`B4VML87!N;W5T(':Y92(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")#;VQL87!S92!!
M;&P@1F]L9&5R<R(*;7-G<W1R(")3:VQA<&YO=70@=KEE8VAN>2!S;&^^:WDB
M"@HC.B!F;VQD97)S+G!H<#HT-#D*;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*
M;7-G<W1R(")3:VQA<&YO=70@<VQOOFMU(@H*(SH@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]M86YA9V4N:6YC.C4Q"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*
M;7-G<W1R("));F1I:^%T;W(@8F%R978Z("(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ,#,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B4&]Z;N%M:V$B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8Y"FUS9VED(")#;VUP
M;&5T960B"FUS9W-T<B`B1&]K;V[H96YO(@H*(SH@8V]M<&]S92YP:'`Z.#(W
M(&-O;7!O<V4N<&AP.C$Q-#<*;7-G:60@(D-O;7!O<V4@86YO=&AE<B!M97-S
M86=E(@IM<V=S='(@(E9Y='9O^&ET(&1A;+GM('IP<N%V=2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,S0*;7-G:60@(D-O;7!O<V4@;65S<V%G97,@
M:6X@82!S97!A<F%T92!W:6YD;W<_(@IM<V=S='(@(E9Y='9O^&ET('IP<N%V
M>2!V(&YO=NEM(&]K;NP_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M,PIM<V=I9"`B(@HB0V]M<&]S92!M97-S86=E<R!W:71H(&%N($A434P@1U5)
M(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE("(*(F9E871U
M<F4I/R(*;7-G<W1R("(B"B));7!L:6-I=&[L('9Y=';A^&5T('IP<N%V>2!V
M($A434P@1U5)("AP;V1P;W)U:F4M;&D@<')O:&SMOF7H('1U=&\@=F]L8G4I
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-PIM<V=I9"`B0V]N9FEG
M=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+B(*;7-G<W1R(").87-T
M879E;NT@>F]B<F%Z96[M('IP<N%V+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-PIM<V=I9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS
M+B(*;7-G<W1R(").87-T879I="!M;[YN;W-T:2!P<F\@;N%H;&5D('IP<N%V
M+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S<P"B,L(&9U>GIY"FUS9VED
M(")#;VYN96-T:6]N(&1R;W!P960@8GD@24U!4"!S97)V97(N(@IM<V=S='(@
M(E-P;VIE;NT@<V4@<V5R=F5R96T@<V5L:&%L;R(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,C,T"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F
M86EL960B"FUS9W-T<B`B4W!O:F5N[2!S92!S97)V97)E;2!S96QH86QO(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYT<F]L(%!'4"!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B3F%S
M=&%V96[M('!O9'!O<GD@4$=0('8@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT<F]L(%,O34E-
M12!S=7!P;W)T(&9O<B`E<RXB"FUS9W-T<B`B3F%S=&%V96[M('!O9'!O<GD@
M4R]-24U%('8@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM
M<V=I9"`B0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E
M87)C:&EN9RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@Y"FUS9VED("(B"B)#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C
M:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@
M(@HB=VAE;B!I="!A<G)I=F5S+B(*;7-G<W1R("(B"B).87-T879E;NT@:V]N
M=')O;'D@;F]V["!P^.UC:&]Z[6-H('IP<N%V(&$@>G#Y<V]B=2!I;F9O<FUO
M=N%N[2!O(&IE:FEC:"`B"B)P^.UC:&]D=2XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-CDV"FUS9VED(")#;VYV97)T('1E>'1U86P@96UO=&EC;VYS
M(&EN=&\@9W)A<&AI8V%L(&]N97,_(@IM<V=S='(@(DMO;G9E<G1O=F%T(&EK
M;VYK>2!S(&5M;V-E;6D@>B!T97AT=2!D;R!G<F%F:6MY/R(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")+
M;W#M<F]V870B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G
M:60@(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@(DMO<.UR;W9A="!D;R!S;&^^
M:WDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-C,*;7-G
M:60@(D-O<G)E8W0B"FUS9W-T<B`B57!R879I="(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#`*;7-G:60@(D-O<G)E8W1E9"!497AT
M(@IM<V=S='(@(E5P<F%V96[]('1E>'0B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C,X,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-O;7!L971E(')E<75E<W0N(%)E87-O;B!':79E;CH@)7,B"FUS9W-T<B`B
M3F5L>F4@=GET=F_X:70@5D93(&)A8VME;F0Z("5S(@H*(SH@871T86-H;65N
M="YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T
M92!T:&4@5D93(&)A8VME;F0Z("5S(@IM<V=S='(@(DYE;'IE('9Y='9O^&ET
M(%9&4R!B86-K96YD.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M97-S86=E<R!F
M<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DYE;'IE('9Y
M;6%Z870@>G!RX79Y('H@)7,N(%1O=&\@:F4@:&SAN65N[2!Z92!S97)V97)U
M.B`E<R(*"B,Z(&QI8B]397-S:6]N+G!H<#HS,3@*;7-G:60@(D-O=6QD(&YO
M="!E>&5C=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@(DYE
M;'IE('!R;W;I<W0@;W!E<F%C92#Z9'*^8GDN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@
M<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*
M;7-G<W1R(").96QZ92!Z[7-K870@<&^^861O=F%N_2!S;W5B;W(@>B!P^.UL
M;VAY('1Y<'4@35,M5$Y%1BXB"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H
M<#HU.`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E9"!F
M:6QE(&9R;VT@=&AE(%II<"!A<F-H:79E+B(*;7-G<W1R(").96QZ92!Z[7-K
M870@<&^^861O=F%N_2!S;W5B;W(@>B!P^.UL;VAY('1Y<'4@6FEP+B(*"B,Z
M(&QI8B]397-S:6]N+G!H<#HR-S,*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!N86UE<W!A8V4@:6YF;W)M871I;VX@9G)O;2!)34%0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS,30@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L+FEN8SHS.0HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,38P"FUS9VED(")#<F5A=&4B"FUS9W-T
M<B`B5GET=F_X:70B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHV"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@(E9Y='9O^&ET('-L
M;[YK=2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*;7-G:60@(D-R
M96%T92!+97ES(@IM<V=S='(@(E9Y='9O^&ET(&ML[>AE(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C$T"FUS9VED(")#<F5A=&4@5FER='5A
M;"!&;VQD97(B"FUS9W-T<B`B5GET=F_X:70@=FER='7A;&[M('-L;[YK=2(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V
M"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R
M(")$86RY[2!P;[ET;W9N[2#ZZ'1Y(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P
M86US96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN
M8SHR-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R
M(@IM<V=S='(@(E9Y='9O^&ET(&YO=F]U('-L;[YK=2!P<F\@:V^Y(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S
M+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE
M=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(E9Y='9O^&ET(&YO=F]U('-L;[YK
M=2!P<F\@<F]Z97!S86[I('IP<N%V>2(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL
M<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@;F5W('-E;G0@;6%I;"!F
M;VQD97(B"FUS9W-T<B`B5GET=F_X:70@;F]V;W4@<VQOOFMU('!R;R!O9&5S
M;&%NZ2!Z<'+A=GDB"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N
M:6YC.C$R('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*;7-G
M:60@(D-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B5GET=F_X
M:70@;F]V;W4@<VQOOFMU('!R;R!K;[DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(X"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG(')U;&5S('1O
M(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I;G1O(&9O
M;&1E<G,L("(*(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`B(@HB1FEL=')O
M=F%C[2!P<F%V:61L82!P<F\@;W)G86YI>F]VX6[M('#X[6-H;WKM8V@@>G!R
MX78L(&IE:FEC:"!T^.UD[&[M(&1O("(*(G-L;[YE:R!A(&UA>N%N[2!N96-H
M=.QN_6-H('IP<N%V("AS<&%M*2XB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!N97<@<W1A
M=&EO;F5R>2(*;7-G<W1R(")6>71V;_AI="!N;W9O=2!S;&^^:W4@<')O(&]D
M97-L86[I('IP<N%V>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#D*
M;7-G:60@(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E<W!O;G-E<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@
M(E-O=>AA<V[]('#X[7-T=7`@9&\@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H
M:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`B3F%S=&%V
M:70@^NAT>2!P<F\@<W1A:&]VX6[M('IP<N%V('H@9&%LN>UC:"!P;[ET;W9N
M[6-H(/KH=/DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED
M(")#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN(@IM<V=S='(@(DYA<W1A
M=F5N[2!Z</ES;V)U(&]D97/M;.%N[2!Z<'+A=BXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(").87-T
M879E;NT@^FMO;/D@<')O=N%D[&[]8V@@</AI('#X:6ALX;EE;NT@9&\@;6]D
M=6QU("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,3<*;7-G:60@(D1A=%]E(@IM<V=S='(@(D1A='5?;2(*"B,Z(&UE
M<W-A9V4N<&AP.C(V,B!T:')E860N<&AP.C$T.`IM<V=I9"`B1&%T92(*;7-G
M<W1R(")$871U;2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3<*
M;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(EIA;>UT;G5T(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C(V,PIM<V=I9"`B1&5C;&EN960Z("(*;7-G
M<W1R("):86WM=&YU=#H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S
M-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")3;6%Z870B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z,3@*
M;7-G:60@(D1E9F%U;'0@4V5A<F-H($9I96QD(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C,*;7-G:60@(D1E9F%U;'0@<V]R=&EN
M9R!C<FET97)I83HB"FUS9W-T<B`B5OUC:&]Z[2!T^.UD[6/M(&MR:73I<FEA
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S,*;7-G:60@(D1E9F%U
M;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@(E;]8VAO>NT@<VWL<B!T
M^.UD[&[M.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C4*;7-G
M:60@(D1E;&5G871E9"(*;7-G<W1R(")0^&ED[&QE;F\B"@HC.B!F;VQD97)S
M+G!H<#HT,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4VUA>F%T
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S
M(%!U8FQI8R!+97DB"FUS9W-T<B`B4VUA>F%T("5S('9E^&5J;OT@:VSMZ"(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C@U"FUS9VED(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S
M='(@(E-M87IA="!S;W7H87-N_2!K;.WH(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G
M<W1R(")3;6%Z870@<VQOOFMU*'DI(@H*(SH@9F]L9&5R<RYP:'`Z,C@U"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R
M(")3;6%Z870@<VQOOFMU*'DI(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4W1A=&EO;F5R
M>2(*;7-G<W1R(")3;6%Z870@=FER='7A;&[M('-L;[YK=2(*"B,Z(&9O;&1E
M<G,N<&AP.C0Q.0IM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L9&5R(@IM<V=S
M='(@(E-M87IA="!V:7)T=>%L;NT@<VQOOFMU(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE9"!M
M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@(E-M87IA="!S
M=&&^96[I('IP<N%V>2!Z92!V>F3A;&5NZ6AO('-E<G9E<G4_(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8R.`IM<V=I9"`B1&5L971E(&9R;VT@
M;7D@8V%L96YD87(B"FUS9W-T<B`B4VUA>F%T('H@;>EH;R!K86QE;F3A^&4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"FUS9VED(")$96QE=&4@
M;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M(@IM<V=S='(@(E-M87IA="!S=&%RZ2!P^.UL;VAY('5L;[YE;ND@:F%K;R!O
M9&MA>B!N82!Z8>CA=&MU(&WL<^UC93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4P"FUS9VED(")$96QE=&4@;VQD('-E;G0M;6%I;"!F;VQD97)S
M(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B4VUA>F%T('-T87+I
M('-C:'+A;FMY(',@;V1E<VQA;F]U('!ON71O=2!N82!Z8>CA=&MU(&WL<^UC
M93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@<W!A;2!M97-S86=E<R(*;7-G<W1R(")3;6%Z86[I('IP
M<N%V>2(*"B,Z(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H<#HW-#`@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI
M;F,Z.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R(")3;6%ZX6YO(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B1&5L971E9"!M97-S
M86=E<R(*;7-G<W1R(")3;6%Z86[I('IP<N%V>2(*"B,Z(&-O;7!O<V4N<&AP
M.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM
M96YT(%PB)7-<(BXB"FUS9W-T<B`B4VUA>F%NX2!P^.UL;VAA(%PB)7-<(BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG
M(&%N9"!-;W9I;F<@365S<V%G97,B"FUS9W-T<B`B4VUA>N%N[2!A('#X97-O
M=7;A;NT@>G!RX78B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DR
M"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B6F%M[71N;W5T('!OOF%D
M879E:R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#`*;7-G:60@
M(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S
M='(@(EIA;>UT;F]U="!P;[YA9&%V96L@;F$@:6YF;W)M86-I(&\@9G)E92]B
M=7-Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,@IM<V=I9"`B1&5S
M8V5N9&EN9R(*;7-G<W1R(")397-T=7!N["(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C8Y"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")0;W!I<R(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M-PIM<V=I9"`B1&5T86EL<R(*;7-G<W1R(")$971A:6QY(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8W-PIM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM
M<V=S='(@(EIA<W3M;FET('-I9VYA='5R>3\B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R
M("):;V)R87II="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-SD*;7-G
M:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S
M86=E/R(*;7-G<W1R("):;V)R87II="!P;W1V<GIE;NT@;R!O9&5S;.%N[2!Z
M<'+A=GD_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-@IM<V=I9"`B
M1&ES<&QA>2!I;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B6F]B<F%Z:70@
M=B!T[&QE('IP<N%V>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3(*
M;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I
M;#\B"FUS9W-T<B`B6F]B<F%Z:70@=7!O>F]R;NQN[2!O(&YO=ND@>G!RX7;L
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-3@*(RP@9G5Z>GD*;7-G
M:60@(D1I<W!L87D@=&AE(%PB16UP='D@4W!A;5PB(&QI;FL@:6X@=&AE(&UE
M;G5B87(_(@IM<V=S='(@(EIO8G)A>FET(&EK;VYU("=6>7!RX7ID;FET(&MO
MN2<@=B!L:;ET["!M96YU/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-3`*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP='D@5')A<VA<
M(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R("):;V)R87II="!I:V]N
M=2`G5GEP<N%Z9&YI="!K;[DG('8@;&FY=.P@;65N=3\B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,3$*;7-G:60@(D1I<W!O<VET
M:6]N(@IM<V=S='(@(D1I<W!O>FEC92(*"B,Z('1E;7!L871E<R]S96%R8V@O
M9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA=&-H(@IM<V=S='(@(DY%
M4TA/1%5*S2!S92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C$V"FUS9VED(")$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I
M;"(*;7-G<W1R(").96MO;G1R;VQO=F%T('-L;[YK=2AY*2!N82!N;W;I('IP
M<N%V>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-3(*;7-G:60@(D1O
M(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;B(*;7-G
M<W1R(").979Y=';A^&5T(&]D:V%Z>2!V92!S;&]U<&-I($]D.B(*"B,Z(&QI
M8B])35`N<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA
M="!F;VQD97(_(@IM<V=S='(@(D-H8V5T92!O=&5V^.UT('1U=&\@<VQOOFMU
M/R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,R"FUS9VED(")$
M;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C8*;7-G:60@(D1O
M;F4B"FUS9W-T<B`B1&]K;V[H96YO(@H*(SH@;&EB+TU)344O0V]N=&5N=',N
M<&AP.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R!I;B`N
M>FEP($9O<FUA="(*;7-G<W1R(")3=&%H;F]U="`E<R!V("YZ:7`@9F]R;>%T
M=2(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R"FUS9VED
M(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB"FUS
M9W-T<B`B4W1A:&]V870@=KEE8VAN>2!P^.UL;VAY("AV("YZ:7`@<V]U8F]R
M=2DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,`IM<V=I
M9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S='(@(E-T86AN;W5T('-L;[YK
M=2AY*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(Q"FUS
M9VED(")$;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(*;7-G<W1R
M(")3=&%H;W9A="!S;&^^:W4H>2D@6W8@+GII<"!F;W)MX71U72(*"B,Z(&QI
M8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*;7-G:60@(D1O=VYL;V%D(&EN("YZ
M:7`@1F]R;6%T(@IM<V=S='(@(E-T86AO=F%T('8@+GII<"!F;W)MX71U(@H*
M(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N<&AP.C<Q.2!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G
M:60@(D1R869T(@IM<V=S='(@(E)O>F5P<V%NX2!Z<'+A=F$B"@HC.B!F;VQD
M97)S+G!H<#HS.3(*;7-G:60@(D1R869T(&9O;&1E<B(*;7-G<W1R(")3;&^^
M:V$@<')O(')O>F5P<V%NZ2!Z<'+A=GDB"@HC.B!T96UP;&%T97,O<')E9G,O
M9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I9"`B1')A9G1S(&9O;&1E<CHB"FUS
M9W-T<B`B4VQOOFMA('!R;R!R;WIE<'-A;ND@>G!RX79Y.B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHQ,#@*;7-G:60@(D4M;6%I;"!!9&1R97-S(@IM
M<V=S='(@(D4M;6%I;&]VX2!A9')E<V$B"@HC.B!L:6(O36%I;&)O>"YP:'`Z
M,S`Y"B,L(&9U>GIY"FUS9VED(")%3D0B"FUS9W-T<B`B02(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED(")%4E)/4CH@66]U<B!M
M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N(@IM<V=S='(@(D-(64)!
M.B!68;GM('IP<N%V=2!N96QZ92!D;W)UZ&ET+B(*"B,Z(&9O;&1E<G,N<&AP
M.C0R,"!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,3D*;7-G:60@
M(D5D:70B"FUS9W-T<B`B57!R879I="(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!";&%C:VQI<W0B"FUS9W-T<B`B
M57!R879I="#H97)N;W4@;&ES=&EN=2(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHQ,PIM<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(E5P
M<F%V:70@9FEL=')O=F%C[2!P<F%V:61L82(*"B,Z(&9O;&1E<G,N<&AP.C0R
M,"!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,38*;7-G:60@(D5D:70@
M5FER='5A;"!&;VQD97(B"FUS9W-T<B`B57!R879I="!V:7)T=>%L;NT@<VQO
MOFMU(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I
M;VX@9F]R("5S(@IM<V=S='(@(E5P<F%V:70@9&5F:6YI8VD@=FER='7A;&[M
M('-L;[YK>2!P<F\@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(E5P<F%V:70@
M8NUL;W4@;&ES=&EN=2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHQ.`IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*;7-G<W1R(")5<')A
M=FET(.AE<FYO=2!L:7-T:6YU(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C$S"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(@IM<V=S
M='(@(E5P<F%V:70@<')A=FED;&$@9FEL=')O=N%N[2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-C$*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E
M<R!F;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@
M(E5P<F%V:70@;F%S=&%V96[M('!R;R!P^.US='5P(&L@:FEN_6T@<&^Y=&]V
M;NUM(/KH=/EM+B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHR
M,PIM<V=I9"`B161I="!Y;W5R('=H:71E;&ES="(*;7-G<W1R(")5<')A=FET
M(&+M;&]U(&QI<W1I;G4B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C(S.0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%;6%I
M;&]VX2!A9')E<V$B"@HC.B!L:6(O365S<V%G92YP:'`Z-C4W"B,L('!H<"UF
M;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM
M<V=S='(@(E9Y<'+A>F1N:70@=KEE8VAN>2!Z<'+A=GD@;V0@)7,B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,@IM<V=I9"`B16UP='D@
M1F]L9&5R*',I(@IM<V=S='(@(E9Y<'+A>F1N:70@<VQOOFMU*'DI(@H*(SH@
M9F]L9&5R<RYP:'`Z,C@V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!396QE8W1E
M9"!&;VQD97)S(@IM<V=S='(@(E9Y<'+A>F1N:70@<VQOOFMU*'DI(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y
M(%1R87-H(&9O;&1E<B(*;7-G<W1R(")6>7!RX7ID:70@<VQOOFMU(&MON64B
M"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%]3
M<&%M(@IM<V=S='(@(E9Y<'+A>F1I="!?:V^Y(@H*(SH@;&EB+TE-4"YP:'`Z
M.38V"FUS9VED(")%;7!T>2!?5')A<V@B"FUS9W-T<B`B5GEP<N%Z9&ET(%]K
M;[DB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,2!T96UP;&%T97,O<&=P
M+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%!'4"!F=6YC=&EO;F%L
M:71Y/R(*;7-G<W1R("):87!N;W5T(%!'4#\B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z
M-@IM<V=I9"`B16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R
M("):87!N;W5T(%,O34E-13\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#$Q"FUS9VED(")%;F%B;&4@;65S<V%G92!P<F5V:65W<S\B"FUS9W-T<B`B
M56UOOFYI="!NX6AL961Y('IP<N%V/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0T,@IM<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*
M;7-G<W1R(")-;[YN;W-T:2"Y:69R;U]VX6[M(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4Q-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4W
M"FUS9VED(")%;F0B"FUS9W-T<B`B2V]N96,B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,S@T"FUS9VED(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B
M2V]N96,@</AE<&]S;&%NZ2!Z<'+A=GDB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,S0Q"FUS9VED(")%;F0@;65S<V%G92(*;7-G<W1R(")+;VYE8R!Z<'+A=GDB
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D5N9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B2V]N96,@>G!RX79Y(&]D
M("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS
M9W-T<B`B6F%D96IT92!H97-L;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M
M<V5L96-T+FEN8SHY"B,L(&9U>GIY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F
M;W(@>6]U<B!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B5FQOOG1E(&IMZ6YO
M(&YO=ND@<VQOOFMY('!R;R!K;[DB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L
M9&5R<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R(")6;&^^=&4@:FWI;F\@;F]V
MZ2!S;&^^:WD@<')O(')O>F5P<V%NZ2!Z<'+A=GDB"@HC.B!T96UP;&%T97,O
M<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(S"FUS9VED(")%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")6
M;&^^=&4@:FWI;F\@;F]VZ2!S;&^^:WD@<')O(&]D97-L86[I('IP<N%V>2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z.0IM<V=I9"`B
M16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H(&9O;&1E<B(*;7-G
M<W1R(")6;&^^=&4@:FWI;F\@;F]VZ2!S;&^^:WD@<')O(&MON2(*"B,Z(&QI
M8B]396%R8V@N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")%;G1I<F4@365S<V%G
M92(*;7-G<W1R(")0^&5S;>QR;W9A="!Z<'+A=G4B"@HC.B!M97-S86=E+G!H
M<#HQ.30@8V]M<&]S92YP:'`Z,3$S-"!T:')E860N<&AP.C<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D5N=')Y(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('1H92!A9&1R97-S(&)O;VLB"FUS9W-T<B`B4&]L;[YK82!<(B5S
M7"(@8GEL82#Z<W#LN6[L('#X:63A;F$@9&\@861R97/A^&4B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C$X('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHR,0HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W-B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HS.#8*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z-S(@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38S"FUS9VED
M(")%<G)O<B(*;7-G<W1R(")#:'EB82(*"B,Z(&QI8B])34%0+T-L:65N="YP
M:'`Z-#4T"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@
M=&\@24U!4"!S97)V97(N("5S(#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HS,#D@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E
M<&QY.B`E<RXB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P^&D@;V1E<^ULX6[M
M(&]D<&]V[&1I.B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3`Q"FUS9VED(")%=F5N="!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T
M<B`B563A;&]S="!B>6QA(/IS<.RY;NP@<VUA>N%N82XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S@R"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM
M<V=S='(@(DMAOF3]8V@@,34@;6EN=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S<Y"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DMA
MOF3]8V@@,S`@<V5K=6YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X
M,0IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DMAOF3]8V@@-2!M
M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#,*;7-G:60@(D5V
M97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")+8;YD;W4@</EL(&AO9&EN=2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R(")+8;YD;W4@;6EN=71U(@H*(SH@9F]L9&5R<RYP:'`Z-#4W
M"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B4F]Z8F%L:70B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"(*
M;7-G<W1R(")2;WIB86QI="!VN64B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"!&;VQD97)S(@IM<V=S
M='(@(E)O>F)A;&ET(':Y96-H;GD@<VQOOFMY(@H*(SH@9F]L9&5R<RYP:'`Z
M-#4W"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(E)O>F)A;&ET('-L
M;[YK=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T,"!T
M96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3,*;7-G:60@(D5X<&%N
M9"!.86UE<R(*;7-G<W1R(")$;W!L\B!J;>EN82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#8S"FUS9VED(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O
M;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_
M(@IM<V=S='(@(D%U=&]M871I8VMY(&1O<&QN:70@:FWI;F$@</AI('9Y=';A
M^&5N[2!Z<'+A=GD_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX,`IM
M<V=I9"`B17AP86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L
M="!I;B!T:&4@9F]L9&5R<R!V:65W/R(*;7-G<W1R("));7!L:6-I=&[L(')O
M>F)A;&]V870@8V5L;W4@<W1R=6MT=7)U('-L;[YE:R!P^&D@:F5J:6-H('IO
M8G)A>F5N[3\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ
M-#0@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3DT"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(T-2!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z,3`Q"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T<B`B
M4F]Z8F%L=6II(@H*(SH@;&EB+TE-4"YP:'`Z.3@T(&QI8B])35`N<&AP.CDX
M-@HC+"!F=7IZ>0IM<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T<B`B4W3A:&YO
M=70@<&^Y='4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI
M;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B1F5T8V@@
M36%I;"(*;7-G<W1R(")3=.%H;F]U="!P;[ET=2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-CD*;7-G:60@(D9E=&-H($UA:6P@:6X@82!S97!A<F%T
M92!W:6YD;W<_(@IM<V=S='(@(E-T86AO=F%T('!ON71U('8@;F]VZ6T@;VMN
M[#\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#8*;7-G
M:60@(D9E=&-H(&UE<W-A9V5S('5P;VX@;&]G9VEN9R!O;C\B"FUS9W-T<B`B
M4W1A:&]V870@<&^Y='4@</AI('#X:6ALX;EE;NT@9&\@<WES=.EM=3\B"@HC
M.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@9G)O;2`E<R(*;7-G<W1R(")3
M=&&^96YO("5D('IP<N%V*&$I(&]D("5S+B(*"B,Z(&QI8B]&971C:&UA:6PN
M<&AP.C(X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q
M(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")3=&&^96YO("5D('IP<N%V*&$I
M(&]D("5S+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-2!L:6(O1F5T8VAM
M86EL+G!H<#HR.#<@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y"FUS9VED(")&971C
M:&UA:6PZ("(*;7-G<W1R(")3=&&^96[A('!ON71A.B(*"B,Z(&QI8B]&971C
M:&UA:6PN<&AP.C(Y,0IM<V=I9"`B1F5T8VAM86EL.B!N;R!N97<@;65S<V%G
M97,N(@IM<V=S='(@(E-T8;YE;N$@<&^Y=&$Z(+[A9&[I(&YO=ND@>G!RX79Y
M+B(*"B,Z(&QI8B])35`N<&AP.CDY,`IM<V=I9"`B1FE?;'1E<G,B"FUS9W-T
M<B`B1FE?;'1R>2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4P,B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHX,@IM<V=I
M9"`B1FEL92(*;7-G<W1R(")3;W5B;W(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,S$*;7-G:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S='(@
M(DUOOFYO<W1I(&9I;'1R^2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHY"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`B3F%S=&%V
M96[M(&9I;'1R^2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#`*;7-G
M:60@(D9I;'1E<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS
M9W-T<B`B3V1F:6QT<F]V870@;F5V:&]D;N$@<VQO=F$@>F4@>G!RX78_(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B
M1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM
M<V=S='(@(E1E;G1O('-Y<W3I;2!N975M;[[R=6IE(&9I;'1R;W;A;NTN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B1FEL=&5R<R(*
M;7-G<W1R(")&:6QT<GDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I
M=F4N:6YC.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C=&EV92(*;7-G<W1R(")&
M:6QT<GD@3D5*4T]5(&%K=&EV;W;A;GDB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N
M="!P86=E(@IM<V=S='(@(D9I;'1R>3H@)7,@<W1RX6YK82!M86YA9V5M96YT
M=2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS
M9VED(")&:6YD(@IM<V=S='(@(E9Y:&QE9&%T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP-0IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E(@IM<V=S
M='(@(E!R=F[M('-T<N%N:V$@<V-H<N%N:WDB"@HC.B!M86EL8F]X+G!H<#HS
M-#4*;7-G:60@(D9I<G-T(%!A9V4B"FUS9W-T<B`B4')V;NT@<W1RX6YK82(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-2!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]?<G=A
M<F0B"FUS9W-T<B`B4/A?97!O<VQA="(*"B,Z(&9O;&1E<G,N<&AP.C(V-B!T
M96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HU"FUS9VED
M(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC
M.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z
M.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C8*
M(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHQ,`IM
M<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R(").879I9^%T;W(@<VQO
MOF5K(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D9O;&1E
M<B!3=6UM87)Y(@IM<V=S='(@(E-H<FYU=.T@<VQOOF5K(@H*(SH@86-L+G!H
M<#HR-`IM<V=I9"`B1F]L9&5R('-H87)I;F<@:7,@;F]T(&5N86)L960N(@IM
M<V=S='(@(E-D[6QE;NT@<VQOOF5K(&YE;NT@<&]V;VQE;F\N(@H*(SH@9F]L
M9&5R<RYP:'`Z-C(*;7-G:60@(D9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N
M(@IM<V=S='(@(E!O=;YI=.T@<VQOOF5K(&YE;NT@<&]V;VQE;F\N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV.0IM<V=I9"`B1F]R;6%T(&]F(&UE
M<W-A9V4@9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S<V%G97,@
M9&%T960@=&]D87DB"FUS9W-T<B`B1F]R;>%T(&1A='5M=2!V('IO8G)A>F5N
M[2!S8VARX6YK>2!P<F\@9&YEN6[M('#X[6-H;WKM('IP<N%V>2(*"B,Z(&-O
M;7!O<V4N<&AP.C<X,"!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,34*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*
M;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B4/AE<&]S;&%T(@H*(SH@8V]M<&]S
M92YP:'`Z-S8U"FUS9VED(")&;W)W87)D.B(*;7-G<W1R(")0^&5P;W-L870Z
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,V.0IM<V=I9"`B1F]R=V%R9&5D(&UE
M<W-A9V4B"FUS9W-T<B`B4/AE<&]S;&%NX2!Z<'+A=F$B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D9O<G=A<F1E9"!M
M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B4/AE<&]S;&%NX2!Z<'+A=F$@;V0@
M)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@S"FUS9VED(")&
M<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-E(&\@1G)E
M92]"=7-Y(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y-`IM<V=I
M9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(D9R964O0G5S>2!O9'!O=NSO
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`IM<V=I9"`B1G)E
M92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B1G)E92]"=7-Y(+[A9&]S="(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*;7-G:60@(D9R964O0G5S
M>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(D9R964O0G5S>2!O9'!O=NSO
M(&YA(+[A9&]S="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,C<*;7-G:60@(D9R;U]M(@IM<V=S='(@(D]?9"(*"B,Z(&UE
M<W-A9V4N<&AP.C(V,R!T:')E860N<&AP.C$T.2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHY.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I9"`B
M1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,3@*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R(")!9')E<V$@3V0B"@HC
M.B!C;VUP;W-E+G!H<#HW-S<@8V]M<&]S92YP:'`Z-S@Q"FUS9VED(")&=V0Z
M(@IM<V=S='(@(E#X97`Z(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-`IM<V=I9"`B
M1G=D.B`B"FUS9W-T<B`B4/AE<#H@(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E
M<R(*;7-G<W1R(")0^&5P.B`E=2!P^&5P;W-L86[]8V@@>G!RX78B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@*;7-G:60@(D=E;F5R86P@3W!T:6]N<R(*;7-G<W1R(")6
MN65O8F5C;ND@;6^^;F]S=&DB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O;FQY(&YE=R!M97-S86=E<S\@*$E-
M05`@;VYL>2DB"FUS9W-T<B`B6NUS:V%T(&IE;B!N;W;I('IP<N%V>3\@*'!O
M=7IE('4@24U!4'4I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,S$*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,V
M"FUS9VED(")';R!T;R!-97-S86=E(@IM<V=S='(@(DKM="!N82!Z<'+A=G4B
M"@HC.B!L:6(O24U0+G!H<#HT.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T
M<B`B5FQOOFET(&1O(&%D<F5SX?AE("@E<RDB"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z,3,U"FUS9VED(")'<F%N="!A8V-E<W,B"FUS9W-T<B`B4&]V
M;VQI="!P^.US='5P(@H*(SH@;65S<V%G92YP:'`Z-30V(&QI8B]&:6QT97(N
M<&AP.C$P-2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#(@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M,R!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8R(&QI8B]-24U%+U9I97=E<B]N;W1I
M9FEC871I;VXN<&AP.C8X"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H
M<#HW.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C$W,PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,C`@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(W"FUS9VED(")(15)%(@IM
M<V=S='(@(EI$12(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHS,2!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$W"B,Z(&QI8B]-24U%
M+U9I97=E<B]R96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(
M5$U,(@H*(SH@8V]M<&]S92YP:'`Z,C4V"FUS9VED(")(5$U,(%9E<G-I;VX@
M;V8@365S<V%G92(*;7-G<W1R(")(5$U,('9E<GIE('IP<N%V>2(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4X"FUS9VED(")(96%D97)S
M(@IM<V=S='(@(DAL879IZ&MY(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C
M;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M97-S86=E('EO=2!W
M97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B5&]T;R!J92!Z<'+A=F$L(&MT97)O
M=2!J<W1E(&YA<'-A;&DZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V
M.`IM<V=I9"`B2&ED9&5N(@IM<V=S='(@(E5K<GET_2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-C<*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE
M=R(*;7-G<W1R(")5:W)Y=/T@=B!Z;V)R87IE;NT@<&]D;&4@<V]U=FES;&]S
M=&DB"@HC.B!M86EL8F]X+G!H<#HS-C<*;7-G:60@(DAI9&4@1&5L971E9"(*
M;7-G<W1R(")5:W+]="!S;6%Z86[I(@H*(SH@9F]L9&5R<RYP:'`Z,CDX"FUS
M9VED(")(:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")5:W+]="!N96%K=&EV
M;NTB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G
M:60@(DAI9V@B"FUS9W-T<B`B5GES;VOA(@H*(SH@;65S<V%G92YP:'`Z,CDW
M(&UA:6QB;W@N<&AP.C<R-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC
M.C$R"FUS9VED(")(:6=H(%!R:6]R:71Y(@IM<V=S='(@(E9Y<V]KX2!D^6QE
MOFET;W-T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDS
M"FUS9VED(")(:6=H97-T(@IM<V=S='(@(DYE:G9YN>TB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C@X"FUS9VED(")(;W<@9&\@>6]U('=A;G0@=&\@
M9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS9W-T<B`B2F%K('-I('#X96IE=&4@
M>F]B<F%Z:70@</CM;&]H>3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3`T"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E9"!L:6YE<R!I;B!A
M(')E<&QY(@IM<V=S='(@(DIA:R!O>FYAZ&ET(&-I=&%C92!V(&]D<&]V[&3M
M8V@B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$S-`IM<V=I9"`B24U!
M4"(*;7-G<W1R("))34%0(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M,CD*;7-G:60@(DE-05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T
M<B`B24U!4"`H075T;VUA=&EC:^$@9&5T96MC92!P<F]T;VMO;'4I(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HS.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!397)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S
M<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$V-B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B
M24U!4"!O=F5R(%-33"(*;7-G<W1R("))34%0('#X97,@4U-,(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-3(*;7-G:60@(DE-05`@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("))34%0('#X97,@
M4U-,("AS(&YE;V9I8VGA;&[M;2!C97)T:69I:^%T96TI(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C<*;7-G:60@(DE-05`@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D*2(*;7-G<W1R("))34%0('#X97,@4U-,("AS(&YE;V9I
M8VGA;&[M;2!C97)T:69I:^%T96TI(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HS-C@*(RP@9G5Z>GD*;7-G:60@(DE-05`@<V5R=F5R(&-L;W-E9"!T:&4@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`B5'EP('!ON71O=F[M:&\@<V5R=F5R=2!P
M<F\@</AI<&]J96[M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,38U(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS9VED("))34%0+"!N
M;R!43%,B"FUS9W-T<B`B24U!4"P@8F5Z(%1,4R(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B
M"FUS9W-T<B`B24U!4"]03U`S('!ON71O=F[M('-E<G9E<GDB"@HC.B!L:6(O
M24U0+G!H<#HX-C8*;7-G:60@(DE.0D]8(@IM<V=S='(@(DE.0D]8(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HT,3$*;7-G:60@(DEF('5S:6YG(%-33"!O
M<B!43%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L(&5X=&5N<VEO
M;B!L;V%D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O
M;&1E<G-?8V]N9FER;2YH=&UL.C$R"B,L(&9U>GIY"FUS9VED("))9B!Y;W4@
M8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@
M8F4@;&]S="$B"FUS9W-T<B`B5KEE8VAN>2!Z<'+A=GD@=F4@<VQOOF-E*&OA
M8V@I(&)U9&]U('IT<F%C96YY(2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHX,@IM<V=I9"`B26=N;W)E(@IM<V=S='(@(DEG;F]R;W9A
M="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I
M9"`B26=N;W)E($%L;"(*;7-G<W1R("))9VYO<F]V870@=KEE(@H*(SH@=&5M
M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C@*;7-G:60@(DEM86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z
M,C`*;7-G:60@(DEM<&]R="(*;7-G<W1R("));7!O<G1O=F%T(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@U('1E;7!L871E<R]P9W`O
M:6UP;W)T7VME>2YI;F,Z-C4*;7-G:60@(DEM<&]R="!+97DB"FUS9W-T<B`B
M26UP;W)T;W9A="!K;.WH(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S
M.0IM<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`B26UP;W)T;W9A="!K
M;.WH;W;]('#A<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C(W"FUS9VED("));7!O<G0@365S<V%G97,B"FUS9W-T<B`B26UP;W)T;W9A
M="!Z<'+A=GDB"@HC.B!P9W`N<&AP.C0R"FUS9VED("));7!O<G0@4$=0($ME
M>2(*;7-G<W1R("));7!O<G1O=F%T(%!'4"!K;.WH(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHY,0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T(%!E
M<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@(DEM<&]R=&]V870@5N&Y(&]S
M;V)N[2!C97)T:69I:^%T(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHQ-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!R:79A=&4@4$=0($ME
M>2(*;7-G<W1R("));7!O<G1O=F%T(%;AN2!O<V]B;NT@<')I=N%T;NT@4$=0
M(&ML[>@B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.CD*;7-G
M:60@(DEM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("))
M;7!O<G1O=F%T(%;AN2!O<V]B;NT@=F7X96IN_2!01U`@:VSMZ"(*"B,Z('1E
M;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@
M4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<R(*;7-G<W1R("));7!O<G1O
M=F%T(%;AN2!O<V]B;NT@4R]-24U%(&-E<G1I9FEKX70B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O<&=P+FEN8SHT
M,@IM<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B26UP;W)T;W9A
M="!V9?AE:F[](&ML[>@B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN
M:6YC.C0*;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("))
M;7!O<G1O=F%T('9E^&5J;OT@4$=0(&ML[>@B"@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.`IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)
M344@2V5Y(@IM<V=S='(@(DEM<&]R=&]V870@5N&Y('9E^&5J;OT@4R]-24U%
M(&ML[>@B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@
M2V5Y(@IM<V=S='(@(DEM<&]R=&]V870@4R]-24U%(&ML[>@B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.CD*;7-G:60@(DEM<&]R="!M8F]X
M($9I;&4B"FUS9W-T<B`B26UP;W)T;W9A="!M8F]X('-O=6)O<B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS
M9W-T<B`B26UP;W)T;W9A="!M8F]X('-O=6)O<B`E<R!D;R!S;&^^:WD@)7,N
M(@H*(SH@;65S<V%G92YP:'`Z-3`R(&UA:6QB;W@N<&AP.C<S-"!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,S"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM
M<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(D3Y;&6^:73I(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT(&UE<W-A
M9V5S(@IM<V=S='(@(D3Y;&6^:73I('IP<N%V>2(*"B,Z(&9O;&1E<G,N<&AP
M.C$V-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"`E9"!M97-S86=E
M<R!F<F]M("5S+B(*;7-G<W1R("));7!O<G1O=N%N;R`E9"!Z<'+A=BAA*2!O
M9"`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<S"FUS9VED
M("));B!0<F]C97-S(@IM<V=S='(@(E8@<')O8V5S=2(*"B,Z(&9O;&1E<G,N
M<&AP.C,X-"!L:6(O1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@
M;&EB+TE-4"YP:'`Z,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O
M24U!4"]4<F5E+G!H<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(DE.0D]8
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,@IM<V=I9"`B26YC;'5D
M92!A(&)R:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A(')E<&QY/R(*
M;7-G<W1R("):86AR;F]U="!S=')UZ&[I('-H<FYU=.T@:&QA=FGH96L@9&\@
M5F&Y[2!O9'!O=NQD:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W
M"FUS9VED("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B
M"FUS9W-T<B`B6F%H<FYO=70@</EV;V1N[2!Z<'+A=G4@9&\@5F&Y[2!O9'!O
M=NQD:3\B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV
M,2!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ,S`*;7-G:60@(DEN9F\B
M"FUS9W-T<B`B26YF;W)M86-E(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*;7-G<W1R
M("));F9O<FUA8V4@;R`E<R!V9?AE:F[I;2!K;.WH:2(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N
M86P@4')I=F%T92!+97DB"FUS9W-T<B`B26YF;W)M86-E(&\@5F&Y96T@;W-O
M8F[M;2!P<FEVX71N[6T@:VSMZ&DB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B26YF
M;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R("));F9O
M<FUA8V4@;R!68;EE;2!O<V]B;NUM('9E^&5J;NEM(&ML[>AI(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHY.`IM<V=I9"`B26YL:6YE(@IM<V=S='(@(E5V;FET
M^"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED
M("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("):9&4@=FQOOFET
M(&-E<G1I9FEKX70B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC
M.C$U"FUS9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE
M<F4B"FUS9W-T<B`B6F1E('9L;[YI="!6X;D@;W-O8F[M('!R:7;A=&[M(%!'
M4"!K;.WH(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM
M<V=I9"`B26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS
M9W-T<B`B6F1E('9L;[YI="!6X;D@;W-O8F[M('9E^&5J;OT@4$=0(&ML[>@B
M"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4*;7-G:60@(DEN
M<V5R="!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(EID92!V;&^^:70@
M=F7X96IN_2!01U`@:VSMZ"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT,3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES
M(&-O;7!O;F5N="XB"FUS9W-T<B`B0GEL82!V>6)RX6YA(&YE<W!RX79NX2!A
M:V-E('!R;R!T=71O(&MO;7!O;F5N='4N(@H*(SH@;6%I;&)O>"YP:'`Z-3@T
M(&UA:6QB;W@N<&AP.C8R-@IM<V=I9"`B26YV86QI9"!!9&1R97-S(@IM<V=S
M='(@(DYE<&QA=&[A(&%D<F5S82(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,S`W"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM<V=S='(@
M(DYE<&QA=&[A('9Z9.%L96[A('-C:'+A;FMA(@H*(SH@8V]M<&]S92YP:'`Z
M,34X"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@8VAA<F%C=&5R(&EN
M(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B3F5P;&%T;OT@>FYA:R!V
M(&4M;6%I;&]VZ2!A9')E<V4Z("5S+B(*"B,Z('-M:6UE+G!H<#HX,B!P9W`N
M<&AP.C$V"FUS9VED("));G9A;&ED(&ME>2(*;7-G<W1R(").97!L871N_2!K
M;.WH(@H*(SH@<&=P+G!H<#HQ.38*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@
M4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R(")6X;D@;W-O8F[M('!R:7;A=&[M
M(%!'4"!K;.WH(&IE(&YE<&QA=&[]+B(*"B,Z('!G<"YP:'`Z,3<Q"FUS9VED
M("));G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y+B(*;7-G<W1R(")6
MX;D@;W-O8F[M('9E^&5J;OT@4$=0(&ML[>@@:F4@;F5P;&%T;OTN(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B26YV97)T
M(@IM<V=S='(@(D]B<N%T:70B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHU-S<*;7-G:60@(DM"(@IM<V=S='(@(DM"(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R
M(")$Z6QK82!K;.WH92(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*
M;7-G:60@(B(*(DME>2!G96YE<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE
M('1O(&-O;7!L971E+B`@0V]N=&EN=64@=VET:"!K97D@(@HB9V5N97)A=&EO
M;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS
M-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,S<*;7-G:60@(DME>2!I;7!O<G0@
M:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@
M;VX@=&AI<R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,S<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,Y"FUS9VED
M("(B"B)+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H879E(&YO
M(&%D9')E<W,@8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R("(*(F-O;G1A8W1S
M+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C,Q.`IM<V=I9"`B2V5Y('-U8V-E
M<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M(")+;.WH(&)Y;"#Z<W#LN6[L(&]D97-LX6X@;F$@=F7X96IN_2!K;.WH;W;]
M('-E<G9E<BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(Q-@IM
M<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B2F%Z>6LB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3`V"FUS9VED("),87-T($UA:6QB;W@@4&%G92(*;7-G
M<W1R(")0;W-L961N[2!S='+A;FMA('-C:'+A;FMY(@H*(SH@;6%I;&)O>"YP
M:'`Z,S4X"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`B4&]S;&5D;NT@<W1R
MX6YK82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X.0IM
M<V=I9"`B3&E?;FL@071T86-H;65N=',B"FUS9W-T<B`B3&E?;FMO=F%NZ2!P
M^.UL;VAY(@H*(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP
M.C$P-C,*;7-G:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N
M+B(*;7-G<W1R(")0^.UL;VAY('5L;[YE;ND@:F%K;R!O9&MA>GD@;F5J<V]U
M('!O=F]L96YY+B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#@P"B,L('!H<"UF
M;W)M870*;7-G:60@(DQI;FMS('=I;&P@97AP:7)E(&]N("5S(@IM<V=S='(@
M(D]D:V%Z>2!B=61O=2!E>'!I<F]V870@=B`E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#@R"FUS9VED("(B"B),:7-T(&%L;"!C;VYT86-T<R!W
M:&5N(&QO861I;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D
M+"!Y;W4@=VEL;"`B"B)O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R
M8V@@9F]R(&5X<&QI8VET;'DI(@IM<V=S='(@(B(*(EIO8G)A>FET('-E>FYA
M;2!VN65C:"!K;VYT86MT^2!P^&D@<')O:&SMOF5N[2!K;VYT86MT^3\@*'!O
M:W5D(&YE;FD@(@HB86MT:79O=N%N;RP@=79I9.UT92!P;W5Z92!K;VYT86MT
M>2P@:W1E<ND@:G-T92!Z861A;&D@<')O('9Y:&QE9.%VX6[M*2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#4*;7-G:60@(DQI<W1I;F<@:6X@=&AE
M($AE861E<B(*;7-G<W1R(")6_7!I<R!V(&AL879IZ&-E(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P"FUS9VED("),;V-A;"!-86EL
M8F]X.B(*;7-G<W1R("),;VOA;&[M('-C:'+A;FMA('!ON71Y(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B3>US=&\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R
M-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(E#X:6ALX7-I="!S92(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&]G(&EN('1O("5S(@IM<V=S='(@(E#X:6ALX7-I="!S92!D;R`E<R(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,W"FUS9VED("),;V=I;B(*
M;7-G<W1R(")0^&EH;.%S:70@<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(MIK;VQY('!R;W;A
M9.QNZ2!P^&D@</AI:&SAN65N[2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@(D[M>FOA(@H*(SH@
M;65S<V%G92YP:'`Z,CDY(&UA:6QB;W@N<&AP.C<R-R!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C$S"FUS9VED("),;W<@4')I;W)I='DB"FUS9W-T
M<B`B3NUZ:^$@9/EL9;YI=&]S="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(Y-PIM<V=I9"`B3&]W97-T(@IM<V=S='(@(DYE:FYIOKGM
M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`IM<V=I
M9"`B36%C:6YT;W-H($9I;&4B"FUS9W-T<B`B4V]U8F]R('!O8VCA>NT@>B!-
M86-I;G1O<VAE(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC
M.C$S"FUS9VED(")-86EL(@IM<V=S='(@(E!ON71A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDV"FUS9VED(")-86EL(%!R979I97=S(@IM<V=S='(@
M(D[A:&QE9'D@<&^Y='DB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E
M<E]S96QE8W0N:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O
M;FYE8W0@=&\Z(@IM<V=S='(@(E1Y<"!P;[ET;W9N[6AO('-E<G9E<G4@<')O
M('#X:7!O:F5N[3HB"@HC.B!F;VQD97)S+G!H<#HT,#(*;7-G:60@(DUA:6QB
M;W@B"FUS9W-T<B`B4V-H<N%N:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$Q"FUS9VED(")-86EL8F]X(&%N9"!&;VQD97(@1&ES<&QA>2!/<'1I
M;VYS(@IM<V=S='(@(DUOOFYO<W1I('IO8G)A>F5N[2!S8VARX6YE:R!A('-L
M;[YE:R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X"FUS
M9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*;7-G
M<W1R(")/>FYAZ&ET(':Y96-H;GD@>G!RX79Y('9E('-L;[YC92!J86MO('!R
M;VALZ61N=73I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,3D*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E
M96XB"FUS9W-T<B`B3WIN8>AI="!VN65C:&YY('IP<N%V>2!V92!S;&^^8V4@
M:F%K;R!N97!R;VALZ61N=73I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM<V=S='(@(D]Z;F'H:70@:F%K;SHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4P"FUS9VED(")-87)K(&1I
M9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO
M<G,_(@IM<V=S='(@(D]Z;F'H:70@<OEZ;ND@^G)O=F[L(&-I=.%T^2!R^7IN
M_6UI(&)A<G9A;6D_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N
M;'DI(@IM<V=S='(@(D]Z;F'H:70@>G!RX79Y(&IA:V\@<')O:&SI9&YU=.D_
M("AP;W5Z92!)34%0*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3@*
M;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T<B`B3WIN8>AI="!J
M961N;V1U8VAO=2!Z;F'H:V]U/R(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A
M9&5R+FEN8SHT-@IM<V=I9"`B36%T8V@@06QL(%%U97)I97,B"FUS9W-T<B`B
M6F%C:'ET:70@=KEE8VAN>2!D;W1A>GDB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R
M("):86-H>71I="!J86O]:V]L:78@9&]T87HB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU,3,*;7-G:60@(DUA>&EM=6T@071T86-H;65N
M="!3:7IE(@IM<V=S='(@(DUA>&EMX6QN[2!V96QI:V]S="!P^.UL;VAY(@H*
M(SH@;&EB+V%P:2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F($9O;&1E<G,B"FUS9W-T<B`B0GEL(&1O<V&^96X@;6%X:6WA;&[M
M('!OZ&5T('#X[6QO:"XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT.30*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S
M(')E86-H960N(@IM<V=S='(@(D)Y;"!D;W-AOF5N(&UA>&EMX6QN[2!P;^AE
M="!P^.UL;V@N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#@Y"FUS9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C
M:&5D+B(*;7-G<W1R(")">6QA(&1O<V&^96YA(&UA>&EMX6QN[2!V96QI:V]S
M="!P^.UL;V@N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-@IM
M<V=I9"`B365E=&EN9R!#86YC96QL871I;VXB"FUS9W-T<B`B6G)UN65N[2!S
M8VCY>F4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<U"FUS9VED
M(")-965T:6YG($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C92!O('-C
M:/EZ:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@
M(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B3N%V<F@@;F$@<V-H^7II(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I9"`B365E=&EN
M9R!297!L>2(*;7-G<W1R(")/9'!O=NSO(&YA('-C:/EZ:2(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU.3@*;7-G:60@(DUE971I;F<@57!D871E
M(@IM<V=S='(@(D%K='5A;&EZ86-E('-C:/EZ92(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV,#,*;7-G:60@(DUE971I;F<@57!D871E(%)E<75E
M<W0B"FUS9W-T<B`B4&^^861A=F5K(&YA(&%K='5A;&EZ86-I('-C:/EZ92(*
M"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,*;7-G:60@(DUE;G4@
M1F]L9&5R($QI<W0B"FUS9W-T<B`B365N=2!P<F\@<V5Z;F%M('-L;[YE:R(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,S$*;7-G:60@(DUE<W-A9V4B"FUS9W-T
M<B`B6G!RX79A(@H*(SH@8V]M<&]S92YP:'`Z-38P(&-O;7!O<V4N<&AP.C4X
M-R!C;VUP;W-E+G!H<#HV-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P"FUS
M9VED(")-97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@(E9Y='9O^&ET('IP
M<N%V=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3<*;7-G:60@(DUE
M<W-A9V4@1&%T92(*;7-G<W1R(")$871U;2!Z<'+A=GDB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#<@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#,*;7-G:60@(DUE<W-A9V4@3W!T:6]N<R(*;7-G<W1R(")-
M;[YN;W-T:2!Z<'+A=B(*"B,Z('-E87)C:"YP:'`Z,S$R"FUS9VED(")-97-S
M86=E(%-E87)C:"(*;7-G<W1R(")6>6AL961A="!Z<'+A=G4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS
M9W-T<B`B5F5L:6MO<W0@>G!RX79Y(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS
M9VED(")-97-S86=E(%-O=7)C92(*;7-G<W1R("):9')O:F]V_2!K\V0@>G!R
MX79Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED(")-97-S
M86=E(%9I97=I;F<B"FUS9W-T<B`B6F]B<F%Z96[M('IP<N%V>2(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-@IM<V=I9"`B365S<V%G92!F;&%G
M<R(*;7-G<W1R(")4>7`@>G!RX79Y(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM<V=S='(@(E-L
M;[YK>2!P<F\@>G!RX79U(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B6G!R
MX79A(&]D("5S(@H*(SH@;6%I;&)O>"YP:'`Z-C8W"B,L(&9U>GIY"FUS9VED
M(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R("):<'+A=F$@<V4@
M<VAO9'5J92(*"B,Z(&UA:6QB;W@N<&AP.C8U.`HC+"!F=7IZ>0IM<V=I9"`B
M365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T<B`B4&]L92!Z<'+A=GDB"@HC
M.B!M86EL8F]X+G!H<#HV-3,*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@:7,@
M<VEG;F5D(@IM<V=S='(@(E!O;&4@>G!RX79Y(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]H96%D97(N:6YC.C,S"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS
M9W-T<B`B6G!RX79A('-E('-H;V1U:F4B"@HC.B!C;VUP;W-E+G!H<#HX,C0@
M8V]M<&]S92YP:'`Z.#,X"FUS9VED(")-97-S86=E(')E9&ER96-T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("):<'+A=F$@8GEL82#Z<W#LN6[L('#X97-M
M[')O=N%N82XB"@HC.B!C;VUP;W-E+G!H<#HQ,#@T"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V
M960@=&\@)7,B"FUS9W-T<B`B6G!RX79A(&)Y;&$@^G-P[+EN["!O9&5S;.%N
M82P@86QE(&YE8GEL82!U;&^^96YA(&1O("5S(@H*(SH@8V]M<&]S92YP:'`Z
M,3$T,R!C;VUP;W-E+G!H<#HQ,34X"FUS9VED(")-97-S86=E('-E;G0@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("):<'+A=F$@8GEL82#Z<W#LN6[L(&]D97-L
MX6YA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(DUE
M<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@
M(EIP<N%V(&YA('-T<N%N:W4@=B!Z;V)R87IE;NT@<V-H<N%N:WDN(@H*(SH@
M;6%I;&)O>"YP:'`Z,S(R"FUS9VED(")-97-S86=E<R!T;R(*;7-G<W1R("):
M<'+A=GD@9&\B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,CD*;7-G:60@
M(DUO9&EF>2(*;7-G<W1R("):;>QN:70B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E>'!A;F0N:6YC.C$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-
M;W)E('1H86X@;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I96QD(%PB)7-<(BXB
M"FUS9W-T<B`B0GEL;R!N86QE>F5N;R!V[6-E(&%D<F5S<R!P<F\@<&]L92`G
M)7,G+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM<V=I9"`B
M36]V92(*;7-G<W1R(")0^&5S=6YO=70B"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS,38*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R
M(")0;W-U;F]U="!D;VSY(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q
M.`IM<V=I9"`B36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N
M9"!I;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4@=&\@9F]L
M9&5R(@IM<V=S='(@(E#X97-U;F]U="!D;R!S;&^^:WDB"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,30*;7-G:60@(DUO=F4@=7`B
M"FUS9W-T<B`B4&]S=6YO=70@;F%H;W)U(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E<FYA
M=&EV92(*;7-G<W1R(")6[6-E(.CA<W3M("\@86QT97)N871I=F[M(@H*(SH@
M=&AR96%D+G!H<#HW-B!T:')E860N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B
M375L=&EP;&4@365S<V%G92!6:65W(@IM<V=S='(@(EIO8G)A>F5N[2!Z<'+A
M=GDB"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B3D].12(*;7-G<W1R(")03UI.P4U+02(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT."!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`B4$]:3L%-2T$B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S."!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C@X"FUS9VED(").86UE(@IM<V=S='(@(DIMZ6YO(@H*(SH@
M<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;B!N;W0@
M8F4@96UP='DB"FUS9W-T<B`B3F5L>F4@;F5C:&%T(&IMZ6YO(&$O;F5B;R!E
M;6%I;"!P<N%Z9&[I(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W
M.`IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(E!O=/AE8G5J92!A:V-I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S@*;7-G
M:60@(DYE=F5R(@IM<V=S='(@(DYI:V1Y(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4V,`IM<V=I9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G
M<W1R(").975K;.%D870@</CM;&]H>2(*"B,Z('1E;7!L871E<R]A8VPO86-L
M+FEN8SHQ,C0*;7-G:60@(DYE=R(*;7-G<W1R(").;W;A(@H*(SH@;&EB+TE-
M4"YP:'`Z-38S"FUS9VED(").97<@1F]L9&5R(@IM<V=S='(@(DYO=N$@<VQO
MOFMA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@
M36%I;"(*;7-G<W1R(").;W;A('!ON71A(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C$Y(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,S"B,L(&9U
M>GIY"FUS9VED(").97<@365S<V%G92(*;7-G<W1R(")$86RY[2!Z<'+A=F$B
M"@HC.B!M86EL8F]X+G!H<#HW-S8@;&EB+TU)344O2&5A9&5R<RYP:'`Z,3DR
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E
M<R(*;7-G<W1R(").;W;I('IP<N%V>2(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R(").;W;I
M('IP<N%V>2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ
M,S,*;7-G:60@(DYE>'0B"FUS9W-T<B`B1&%LN>TB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S"FUS9VED(").97AT($UE
M<W-A9V4B"FUS9W-T<B`B1&%LN>T@>G!RX79A(@H*(SH@;6%I;&)O>"YP:'`Z
M,S4V"FUS9VED(").97AT(%!A9V4B"FUS9W-T<B`B1&%LN>T@<W1RX6YK82(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3<W"FUS9VED(").;R(*;7-G<W1R(").92(*"B,Z
M('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO($-E<G1I9FEC871E(&9O=6YD(@IM
M<V=S='(@(DYE8GEL(&YA;&5Z96X@8V5R=&EF:6OA="(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP
M=&EO;B(*;7-G<W1R(")"97H@N6EF<F]VX6[M(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$Y"FUS9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T
M<B`BKN%D;ND@:VSMZ&4@;F5J<V]U(&1O<W1U<&[I(@H*(SH@;6%I;&)O>"YP
M:'`Z,S<U"B,L('!H<"UF;W)M870*;7-G:60@(DYO($UE<W-A9V5S(@IM<V=S
M='(@(J[A9&[I('IP<N%V>2(*"B,Z('!G<"YP:'`Z,3,W"FUS9VED(").;R!0
M1U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`BKN%D;OT@=F7X96IN
M_2!01U`@:VSMZ"!N96)Y;"!I;7!O<G1O=N%N+B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC
M871E(%!R97-E;G0B"FUS9W-T<B`BKN%D;OT@;W-O8F[M(&-E<G1I9FEKX70@
M;F5B>6P@;F%L97IE;B(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,CD*(RP@9G5Z
M>GD*;7-G:60@(DYO(%!R979I97<@5&5X="(*;7-G<W1R(").X6AL960B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$U"FUS9VED(").;R!0=6)L
M:6,@2V5Y<R!&;W5N9"(*;7-G<W1R("*NX61N_2!V9?AE:F[](&ML[>@@;F5B
M>6P@;F%L97IE;B(*"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-
M12!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("*NX61N_2!V9?AE:F[]
M(%,O34E-12!K;.WH(&YE8GEL(&EM<&]R=&]VX6XN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W1N968N<&AP.CDP"FUS9VED(").;R!A='1A8VAM96YT<R!F;W5N
M9"XB"FUS9W-T<B`B4/CM;&]H82!N96)Y;&$@;F%L97IE;F$N(@H*(SH@;&EB
M+T-R>7!T+U--24U%+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(DYO(&5M86EL
M(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U8FQI8R!K97DN(@IM<V=S
M='(@(DEN9F]R;6%C92!O("5S('9E^&5J;NEM(&ML[>AI(@H*(SH@86-L+G!H
M<#HW,B!A8VPN<&AP.CDX"FUS9VED(").;R!F;VQD97(@<V5L96-T960N(@IM
M<V=S='(@(DYE8GEL82!V>6)RX6YA(+[A9&[A('-L;[YK82XB"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,30Q"FUS9VED(").;R!F;VQD97)S(&%R92!B
M96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`BKN%D;N$@<VQO
MOFMA(&YE;NT@:V]N=')O;&]VX6YA(&YA('#X[71O;6YO<W0@;F]V_6-H('IP
M<N%V+B(*"B,Z(&9O;&1E<G,N<&AP.C(Q."!L:6(O1F]L9&5R+G!H<#HU,#`@
M;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED(").;R!F;VQD97)S('=E<F4@<W!E
M8VEF:65D(@IM<V=S='(@(J[A9&[A('-L;[YK82!N96)Y;&$@=7+H96YA(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T-PIM<V=I9"`B3F\@9F]L9&5R
M<R!W:71H(&YE=R!M97-S86=E<R(*;7-G<W1R("*NX61NX2!S;&^^:V$@;F5O
M8G-A:'5J92!N;W;I('IP<N%V>2(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ-#0*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S<V%G97,B
M"FUS9W-T<B`BKN%D;N$@<VQOOFMA(&YE;V)S86AU:F4@;F5P<F]H;.ED;G5T
MZ2!Z<'+A=GDB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S(U"FUS9VED(").;R!M
M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R("*NX61N_2!T97AT('9E('IP<N%V
M["(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS-S$*;7-G:60@(DYO(&UE<W-A9V5S
M(&UA=&-H960@>6]U<B!S96%R8V@N(@IM<V=S='(@(E9AN6EM('9Y:&QE9.%V
M86/M;2!K<FETZ7)I[6T@;F5O9'!O=NUDX2"^X61NX2!Z<'+A=F$N(@H*(SH@
M<&=P+G!H<#HQ.#D*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P<FEV871E(&ME
M>2!I;7!O<G1E9"XB"FUS9W-T<B`BKN%D;OT@>B!68;EI8V@@;W-O8F[M8V@@
M<')I=N%T;NUC:"!01U`@:VSMZ/D@;F5B>6P@:6UP;W)T;W;A;BXB"@HC.B!P
M9W`N<&AP.C$V-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@
M:6UP;W)T960N(@IM<V=S='(@(J[A9&[]('H@5F&Y:6-H(&]S;V)N[6-H('9E
M^&5J;OUC:"!01U`@:VSMZ/D@;F5B>6P@:6UP;W)T;W;A;BXB"@HC.B!S;6EM
M92YP:'`Z,C`Q"FUS9VED(").;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A
M=&5S(&EM<&]R=&5D+B(*;7-G<W1R("*NX61N_2!O<V]B;NT@4R]-24U%(&ML
M[>@@;F5B>6P@:6UP;W)T;W;A;BXB"@HC.B!S<&5L;&EN9RYP:'`Z,C(P"FUS
M9VED(").;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"XB"FUS
M9W-T<B`BKN%D;N$@:V]N=')O;&$@<')A=F]P:7-U(&YE;NT@:R!D:7-P;WII
M8VDN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS
M9VED(").;R!S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`BKN%D;ND@<')A=F]P
M:7-NZ2!C:'EB>2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHQ,#`*;7-G:60@(DYO('-U9V=E<W1I;VYS(@IM<V=S='(@(J[A9&[I(&[A
M=G)H>2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-38T"FUS9VED(").;R!S
M=7!P;W)T960@24U!4"!A=71H96YT:6-A=&EO;B!M971H;V0@8V]U;&0@8F4@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-C@@86-L+G!H<#HY-`IM
M<V=I9"`B3F\@=7-E<B!S<&5C:69I960N(@IM<V=S='(@(DYE8GEL('5V961E
M;B"^X61N_2!UOFEV871E;"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S`Y"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`B3F5N[2#Z
MZ&%S=&[M:V5M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M,2!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,U('1E;7!L871E<R]P
M<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C8T"FUS9VED(").;VYE(@IM<V=S='(@(J[A9&[](@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDU"FUS9VED(").;W)M86PB
M"FUS9W-T<B`B3F]R;>%L;NTB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G
M:60@(DYO="!$96QE=&5D(@IM<V=S='(@(DYE8GEL;R!S;6%ZX6YO(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(S"B,Z('1E;7!L871E<R]M86EL
M8F]X+VYA=F)A<BYI;F,Z-#(*;7-G:60@(DYO="!$<F%F="(*;7-G<W1R("*N
MX61NX2!R;WIE<'-A;N$@>G!RX79A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHX('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-`IM
M<V=I9"`B3F]T($EM<&]R=&%N="(*;7-G<W1R(").96[M(&3Y;&6^:73I(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T
M(%!E<G-O;F%L(@IM<V=S='(@(DYE;NT@;W-O8F[M(@H*(SH@;&EB+T-R>7!T
M+U!'4"YP:'`Z,3,Y(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP
M="]334E-12YP:'`Z,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y
M+B(*;7-G<W1R(").97!L871N_2!V9?AE:F[](&ML[>@N(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T960@;65S
M<V%G97,B"FUS9W-T<B`B3F5V>6UA>F%NZ2!Z<'+A=GDB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED(").;W0@:6UP;W)T86YT(&UE
M<W-A9V5S(@IM<V=S='(@(DYE9/EL9;YI=.D@>G!RX79Y(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HW,0IM<V=I9"`B
M3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE(@IM<V=S='(@(E5P
M;WIO<F[L;NTZ(%1A=&\@;W!E<F%C92!M^;YE('1R=F%T(&1L;W5H;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,38*;7-G:60@(DYO=&AI;F<B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B
M3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N
M=',@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB4&_H970@;>QS
M[6/Y+"!P;R!K=&5RZ2!B=61E;64@=6-H;W;A=F%T('#X[6QO:'D@=6QOOF5N
MZ2!J86MO(&]D:V%Z>2!P^&D@(@HB;>QS[>AN[6-H(.AIN73L;NTN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U.0IM<V=I9"`B3G5M8F5R(&]F(&]L
M9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H
M;'DN(@IM<V=S='(@(B(*(E!OZ&5T('-T87+]8V@@<VQOOF5K(',@;V1E<VQA
M;OUM:2!Z<'+A=F%M:2P@:W1E<ND@8GD@;F5M[&QY(&+]="!V>6UA>N%N>2`B
M"B(H=GEM87KA=N%N[2!M['/MZ&[L*2XB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(U-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-34R"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S,*;7-G:60@(D]+
M(@IM<V=S='(@(D]+(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC
M.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0Y"B,Z('1E;7!L
M871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-#@*;7-G:60@(D]2(@IM<V=S='(@
M(DY%0D\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$U"FUS9VED
M(")/;&0@;65S<V%G97,B"FUS9W-T<B`B4W1A<ND@>G!RX79Y(@H*(SH@;&EB
M+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO;G1H;'DN<&AP
M.C4R"FUS9VED(")/;&0@<V5N="UM86EL(&9O;&1E<G,@8F5I;F<@<'5R9V5D
M+B(*;7-G<W1R(")3=&%RZ2!S;&^^:WD@<R!O9&5S;&%N;W4@<&^Y=&]U+"!K
M=&5RZ2!S92!V>7!R87ID\G5J[2XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP
M:'`Z,C4*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D
M(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(EIO8G)A>FET('!O=7IE('-L
M;[YK>2!S(&YE</AEZ'1E;OUM:2!Z<'+A=F%M:3\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"FUS9VED(")/;FQY(&]N92!F;VQD
M97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO;BXB"FUS9W-T
M<B`B5'5T;R!A:V-I(&QZ92!P<F]VZ7-T('!O=7IE(',@:F5D;F]U('-L;[YK
M;W4N(@H*(SH@=&5M<&QA=&5S+VUE;G4N:6YC.C$P('1E;7!L871E<R]M96YU
M+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3W!E;B!&;U]L9&5R(@IM<V=S='(@
M(D]T97;X[70@<VQOOFMU(@H*(SH@9F]L9&5R<RYP:'`Z-#(W"FUS9VED(")/
M<&5N960@1F]L9&5R(@IM<V=S='(@(E-L;[YK82!O=&5V^&5N82(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#4*;7-G:60@(D]P=&EO;F%L(%!A
M<G1I8VEP86YT(@IM<V=S='(@(DUOOF[M(/KH87-T;NUC:2(*"B,Z(&9E=&-H
M;6%I;"YP:'`Z,S,@=&5M<&QA=&5S+V9E=&-H;6%I;"]T;W`N:6YC.C,*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C8*;7-G:60@(D]T
M:&5R($UA:6P@06-C;W5N=',B"FUS9W-T<B`B1&%LN>T@<&^Y=&]V;NT@^NAT
M>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE
M<B!/<'1I;VYS(@IM<V=S='(@(D1A;+GM(&UOOFYO<W1I(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#$*;7-G:60@(D]U=&)O=6YD(%-E<G9E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC
M.C$V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP
M"FUS9VED(")01U`B"FUS9W-T<B`B4$=0(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHW"FUS9VED(")01U`@16YC<GEP="!-97-S
M86=E(@IM<V=S='(@(E!'4""Y:69R;W;A;NT@>G!RX79Y(@H*(SH@8V]M<&]S
M92YP:'`Z,S4X"FUS9VED(")01U`@17)R;W(Z("(*;7-G<W1R(")01U`@8VAY
M8F$Z("(*"B,Z(&-O;7!O<V4N<&AP.C,S-PIM<V=I9"`B4$=0($5R<F]R.B!.
M965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G
M<W1R(")01U`@8VAY8F$Z($IE('!O=/AE8F$@:&5S;&\@<')O(%;AN2!O<V]B
M;NT@<')I=N%T;NT@:VSMZ"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"FUS9VED(")01U`@3W!T:6]N<R(*;7-G<W1R(")-;[YN;W-T:2!01U`B
M"@HC.B!P9W`N<&AP.C,P"FUS9VED(")01U`@4&%S<W!H<F%S92!);G!U="(*
M;7-G<W1R(")6;&^^:70@4$=0(&AE<VQO(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C4U"FUS9VED(")01U`@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T
M(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B
M"B)0;W6^:73M(%!'4"!O<V]B;NUH;R!K;.WH;W;I:&\@<.%R=2!V>;YA9'5J
M92!B97IP9>ANZ2!P^&EP;VIE;NT@*$A45%!3*2XB"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HQ-S,*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E>'0B
M"FUS9W-T<B`B5&5X="!V9?AE:F[I:&\@4$=0(&ML[>AE(@H*(SH@<&=P+G!H
M<#HQ-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R
M(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@
M(E9E^&5J;OT@4$=0(&ML[>@@<')O(%PB)7,@*"5S*5PB(&)Y;"#Z<W#LN6[L
M('#X:63A;BXB"@HC.B!P9W`N<&AP.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@
M9&5L971E9"XB"FUS9W-T<B`B5F7X96IN_2!01U`@:VSMZ"!P<F\@7"(E<UPB
M(&)Y;"#Z<W#LN6[L('9Y;6%ZX6XN(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B5F7X
M96IN_2!S=F%Z96L@4$=0(&ML[>CY(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M96YC<GEP=%]L:7-T+FEN8SHX"FUS9VED(")01U`@4VEG;B!-97-S86=E(@IM
M<V=S='(@(E!O9&5P<V%T('IP<N%V=2!P;VUO8^T@4$=0(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"FUS9VED(")01U`@4VEG
M;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B4&]D97!S870ON6EF<F]V870@
M>G!RX79U('!O;6]C[2!01U`B"@HC.B!P9W`N<&AP.C(P,@IM<V=I9"`B4$=0
M('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B4$=0
M('!R:7;A=&[M(&ML[>@@8GEL(/IS<.RY;NP@</AI9.%N+B(*"B,Z('!G<"YP
M:'`Z,3<W"FUS9VED(")01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D
M960N(@IM<V=S='(@(E!'4"!V9?AE:F[](&ML[>@@8GEL(/IS<.RY;NP@</AI
M9.%N+B(*"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED
M(")01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS
M9W-T<B`B5&5N=&\@<WES=.EM(&YE<&]D<&]R=6IE(%!'4"XB"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HR,#@*;7-G:60@(B(*(E!'4"!S=7!P;W)T
M(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!D:6=I=&%L('-I9VYA
M='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(E!'
M4"!N96[M(&%K=&EV;W;A;F\L(&1I9VETX6QN[2!P;V1P:7,@;F5L>F4@;W;L
M^&ET+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-0IM<V=I9"`B
M(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE
M(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B
M4$=0(&YE;NT@86MT:79O=N%N;RP@>G!RX79U(&YE;'IE(&1EN6EF<F]V870N
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*(RP@9G5Z>GD*;7-G:60@
M(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@
M=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@(@HB<V5T('1O
M(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@
M<V5T=&EN9R!O<B!E;'-E('1H92!01U`@(@HB9F5A='5R97,@=VEL;"!N;W0@
M=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(E!O9'!O<F$@4$=0('!O=/AE
M8G5J92!P;W!U<"!O:VYA+B!0;VMU9"!6X;D@<')O:&SMOF7H('IA;65Z=6IE
M('!O=;YI=.T@(@HB=.QC:'1O(&]K96XL(&IE('IA<&]T^&5B[2!U;6^^;FET
M(&IE:FEC:"!P;W6^:73M+"!J:6YA:R!01U`@;F5B=61E('-P<N%V;NP@(@HB
M<')A8V]V870N(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#4*;7-G
M:60@(E!/4#,B"FUS9W-T<B`B4$]0,R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,3`P"FUS9VED(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I
M(@IM<V=S='(@(E!/4#,@*$%U=&]M871I8VOA(&1E=&5K8V4@<')O=&]K;VSY
M*2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$W"FUS9VED(")03U`S
M(&]V97(@4U-,(@IM<V=S='(@(E!/4#,@</AE<R!34TPB"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L
M9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(E!/4#,@</AE<R!34TP@
M*',@;F5O9FEC:>%L;NUM(&-E<G1I9FEKX71E;2DB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$V.0IM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L
M9BUS:6=N960I(@IM<V=S='(@(E!/4#,@</AE<R!34TP@*',@;F5O9FEC:>%L
M;NUM(&-E<G1I9FEKX71E;2DB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP
M.C$Q,0IM<V=I9"`B4$]0,RP@;F\@5$Q3(@IM<V=S='(@(E!/4#,L(&)E>B!4
M3%,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`B4W1RX6YK
M82`E9"!Z("5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP,PIM<V=I
M9"`B4&%G92!W:71H('1H92!&:7)S="!5;G-E96X@365S<V%G92(*;7-G<W1R
M(")3='+A;FMA(',@<')V;NT@;F5P<F]H;.ED;G5T;W4@>G!RX79O=2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#0*;7-G:60@(E!A9V4@=VET:"!T
M:&4@3&%S="!5;G-E96X@365S<V%G92(*;7-G<W1R(")3='+A;FMA(',@<&]S
M;&5D;NT@;F5P<F]H;.ED;G5T;W4@>G!RX79O=2(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VAE861E<G,N:6YC.C0S"FUS9VED(")087)T*',I(@IM<V=S='(@
M(LCA<W0H:2DB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3(S"FUS9VED
M(")087-S<&AR87-E(@IM<V=S='(@(DAE<VQO(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$R.`IM<V=I9"`B4&%S<W!H<F%S92`H06=A:6XI(@IM<V=S
M='(@(DAE<VQO("AO<.QT*2(*"B,Z('-M:6UE+G!H<#HR,S4@<&=P+G!H<#HS
M,3`*;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+B(*
M;7-G<W1R(")(97-L;R!B>6QO(/IS<.RY;NP@<&]S:WET;G5T;RXB"@HC.B!T
M96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3@@=&5M<&QA=&5S+W!G
M<"]P87-S<&AR87-E+FEN8SHR.0IM<V=I9"`B4&%S<W!H<F%S93HB"FUS9W-T
M<B`B2&5S;&\Z(@H*(SH@<&=P+G!H<#HQ,3(*;7-G:60@(E!A<W-P:')A<V5S
M(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B3F5L>F4@>F%D870@<'+A>F1N
MZ2!H97-L;R(*"B,Z('!G<"YP:'`Z,3$T"FUS9VED(")087-S<&AR87-E<R!D
M;R!N;W0@;6%T8V@B"FUS9W-T<B`B2&5S;&$@<V4@;F5S:&]D=6KM(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E<R]S
M;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$Y,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B2&5S;&\B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T
M<B`B4')O=NES="!O<&5R86-E(/ID<KYB>2!P^&D@</AI:&SAN65N[2!D;R!S
M>7-TZ6UU/R(*"B,Z(&%C;"YP:'`Z-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E
M<FUI<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N(&YO="!B92!C:&%N9V5D+B(*
M;7-G<W1R(").96QZ92!Z;>QN:70@<'+A=F$@<')O('1O:&\@=;YI=F%T96QE
M+B(*"B,Z(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HW,#,@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R(")/<V]B
M;NTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D]S;V)N[2!I;F9O<FUA8V4B"@HC
M.B!P9W`N<&AP.C$R,`IM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5N&Y(&]S;V)N[2!01U`@
M:VSMZ&]V_2!PX7(@8GEL(/IS<.RY;NP@=GET=F_X96XN(@H*(SH@<&=P+G!H
M<#HQ,C<*;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R(")68;EE(&]S;V)N[2!01U`@:VSMZ&4@8GEL>2#Z
M<W#LN6[L('-M87KA;GDN(@H*(SH@<VUI;64N<&AP.C(P-PIM<V=I9"`B4&5R
M<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z("(*;7-G
M<W1R(")/<V]B;NT@4R]-24U%(&-E<G1I9FEKX71Y($Y%0EE,62!I;7!O<G1O
M=N%N>3HB"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S;VYA;"!3+TU)
M344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5F&Y92!O
M<V]B;NT@4R]-24U%(&ML[>AE(&)Y;'D@^G-P[+EN["!S;6%ZX6YY+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L86-E('EO=7(@
M<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\B"FUS9W-T
M<B`B56WM<W3M="!68;EI('-I9VYA='5R=2!P^&5D(&]D<&]V[.\@82!T86OI
M('#X960@</AE<&]S;&%N;W4@>G!RX79U/R(*"B,Z(&-O;7!O<V4N<&AP.C(U
M-`IM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G92(*;7-G<W1R
M(")497AT;W;A('9E<GIE('IP<N%V>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.3D*;7-G:60@(B(*(E!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4
M:&ES(')E<75I<F5S('EO=7(@8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D
M("(*(G-O=6YD(&9I;&5S+B`@06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N
M9"!-86,L(&)U="!O=&AE<B!P;&%T9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@
M<&QU9VEN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A
M<V-R:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHQ.3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M9F]L9&5R.B(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!NX7IE=B!N;W;I('-L
M;[YK>3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P
M,B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B
M4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.B(*;7-G
M<W1R(")0<F]S[6T@>F%D96IT92!NX7IE=B!N;W;I('-L;[YK>3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-PIM<V=I9"`B4&QE
M87-E(&5N=&5R('1H92!N97<@;F%M93HB"FUS9W-T<B`B4')O<^UM('IA9&5J
M=&4@;F]VZ2!J;>EN;SHB"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N
M:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T
M:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W
M:6QL(&]N;'D@;F5E9"!T;R`B"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC
M92!P97(@)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HB4')O<^UM('IA9&5J=&4@
M:&5S;&\@:R!68;EE;74@<')I=N%T;NUM=2!01U`@:VSMZ&DN($AE<VQO(&IE
M(&YU=&[I('IA9&%T("(*(G!O=7IE(&IE9&YO=2!Z82`E<R!R96QA8VDN(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F
M;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E
M9"`B"B)T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S
M<VEO;BXB"FUS9W-T<B`B(@HB4')O<^UM('IA9&5J=&4@:&5S;&\@:R!68;EE
M;74@<')I=N%T;NUM=2!3+TU)344@:VSMZ&DN($AE<VQO(&IE(&YU=&[I('IA
M9&%T("(*(G!O=7IE(&IE9&YO=2!Z82`E<R!R96QA8VDN(@H*(SH@<F5C;VUP
M;W-E+G!H<#HY-PIM<V=I9"`B(@HB4&QE87-E(&QO9R!I;B!A9V%I;B!T;R!R
M97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G92X@268@>6]U(&%R92!.3U0@
M=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U(&%R92!C;VUP;W-I;F<@;65S<V%G
M97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I;&P@:&%V92!T;R`B"B)L;V<@
M:6X@86=A:6X@:6X@>6]U<B!M86EN('=I;F1O=R!A<R!W96QL+B!4:&ES(&ES
M('1O(&ME97`@871T86-K97)S(&9R;VT@(@HB:&EJ86-K:6YG('EO=7(@<V5S
M<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A;GD@:6YC;VYV96YI96YC92XB
M"FUS9W-T<B`B(@HB4')O<^UM(&]P['0@<V4@</AI:&QAN71E+"!P;VMU9"!C
M:&-E=&4@<&]K<F'H;W9A="!V92!V>71VX?AE;NT@>G!RX79Y+B!0;VMU9"`B
M"B)N97!O=;[M=N%T92!C;V]K:65S(&$@=GET=N'X[71E('IP<N%V=2!V('!O
M<'5P(&]K;NPL(&)U9&5T92!S92!M=7-E="`B"B)P^&EH;.%S:70@=&%KZ2!V
M92!68;EE;2!H;&%V;NUM(&]K;NPN(%1A:V]VZ71O(&YA<W1A=F5N[2!Z86)R
M8?)U:F4@^G1OZ&[M:_EM("(*(GIM;V-N:70@<V4@5F&Y[2!R96QAZ&[M($E$
M+B!$[&MU:F5M92!Z82!P;V-H;W!E;NTN(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW,0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P87-S
M=V]R9"XB"FUS9W-T<B`B4')O<^UM('IA9&5J=&4@5F&Y92!H97-L;RXB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8W"FUS9VED(")0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE+B(*;7-G<W1R(")0<F]S[6T@>F%D96IT
M92!68;EE('6^:79A=&5L<VOI(&IMZ6YO+B(*"B,Z(&-O;7!O<V4N<&AP.C$P
M-B!L:6(O24U0+G!H<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG
M=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B4')O<^UM(&]P
M<F%V=&4@;F5J961N;WIN8>ANZ2!N96)O(&YE<&QA=&[I(&%D<F5S>2XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C0R"FUS9VED("(B"B)0;&5A
M<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N
M('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS
M9W-T<B`B(@HB4')O<^UM('IK;VYT<F]L=6IT92!NX7-L961U:NUC[2!I;F9O
M<FUA8V4@82!P86L@=GEB97)T92!A:V-I('H@;NV^92`B"B)U=F5D96[I:&\@
M;65N=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C8Q
M"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R
M9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B4')O<^UM('9Y8F5R=&4@;F5J
M9/CM=F4@<VQOOFMU(&$@<&%K('!R;W9E[W1E(&%K8VDN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4P,@IM<V=I9"`B4&QE87-E('-E;&5C="!A
M;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T<B`B4')O<^UM
M('9Y8F5R=&4@86MC:2!Z(&[MOF4@=79E9&5NZ6AO(&UE;G4N(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]J879A<V-R:7!T+FEN8SHT,0IM<V=I9"`B4&QE87-E
M('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"XB"FUS9W-T
M<B`B4')O<^UM('9Y8F5R=&4@;F5J;>EN["!J961N=2!S;&^^:W4@:R!P<F]H
M;&5DX6[M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z
M,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T
M:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B4')O<^UM('9Y8F5R=&4@<&]U>F4@
M:F5D;G4@<VQOOFMU('!R;R!T=71O(&]P97)A8VDN(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"FUS9VED(")0;&5A<V4@<V5L96-T
M(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E!R
M;W/M;2!V>6)E<G1E(&YE8F\@=7!R879T92!V(&)O>'4@=G!R879O.B(*"B,Z
M(&-O;F9I9R]M;W1D+G!H<"YD:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO
M<F1E(@IM<V=S='(@(EIA;&^^96YO(&YA($AO<F1E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Q-`IM<V=I9"`B4')E8V5D92!Y;W5R('-I9VYA='5R
M92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R(")0^&5D8VCA>F5T('-I
M9VYA='5R=2!P;VULZ&MA;6D@*"<M+2`G*3\B"@HC.B!S;6EM92YP:'`Z,C0Q
M('!G<"YP:'`Z,C4W(&9I;'1E<G!R969S+G!H<#HT,`IM<V=I9"`B4')E9F5R
M96YC97,@<W5C8V5S<V9U;&QY('5P9&%T960N(@IM<V=S='(@(E9AN64@;F%S
M=&%V96[M(&)Y;&$@^G-P[+EN["!U;&^^96YA+B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")0<F5V:65W(@IM<V=S
M='(@(D[A:&QE9"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,C@*;7-G:60@(E!R979I;W5S($UE<W-A9V4B"FUS9W-T<B`B
M4/AE9&-H;WKM('IP<N%V82(*"B,Z(&UA:6QB;W@N<&AP.C,T-PIM<V=I9"`B
M4')E=FEO=7,@4&%G92(*;7-G<W1R(")0^&5D8VAO>NT@<W1RX6YK82(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I
M9"`B4')I;G0B"FUS9W-T<B`B5&ES:R(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VAE861E<G,N:6YC.C,X"FUS9VED(")0<FEO<FET>2(*;7-G<W1R(")$^6QE
MOFET;W-T(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C<V
M"FUS9VED(")0<FEV871E($ME>2!087-S=V]R9"(*;7-G<W1R(")(97-L;R!P
M<F\@<')I=N%T;NT@:VSMZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-3D*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@
M<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R("):97!T870@<V4@<&]K8;YD
MZ2!P^&D@<&]S[6SA;NT@</CM;&]H>2P@:6UP;&EC:71N["!.12(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E=F5R>2!T
M:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS
M9W-T<B`B6F5P=&%T('-E('!O:V&^9.D@</AI('!O<^ULX6[M('#X[6QO:'DL
M(&EM<&QI8VET;NP@04Y/(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C$P"FUS9VED(")0<F]T;V-O;#HB"FUS9W-T<B`B4')O=&]K;VPZ
M(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0
M(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R
M(")0;V1P;W)A('9E^&5J;OUC:"!01U`@:VSMZ&]V_6-H('-E<G9E<OD@8GEL
M82!V>7!N=71A+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z.`IM
M<V=I9"`B4'5R7V=E($1E;&5T960B"FUS9W-T<B`B5GGH7VES=&ET('-M87IA
M;NDB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC.C@*;7-G:60@(E!U
M<F=E($1E;&5T960B"FUS9W-T<B`B5GGH:7-T:70@<VUA>F%NZ2(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(T"FUS9VED(")0=7)G92!&
M;VQD97(H<RDB"FUS9W-T<B`B5GGH:7-T:70@<VQOOFMU*'DI(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y-@IM<V=I9"`B4'5R9V4@5')A<V@@:&]W
M(&]F=&5N.B(*;7-G<W1R(")*86L@Z&%S=&\@=GEP<F%Z9/)O=F%T('-L;[YK
M=2!K;[DZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-0IM<V=I9"`B
M4'5R9V4@;65S<V%G97,@:6X@5')A<V@@9F]L9&5R(&]L9&5R('1H86X@=&AI
M<R!A;6]U;G0@;V8@9&%Y<RXB"FUS9W-T<B`B4VUA>F%T('IE('-L;[YK>2!K
M;[EE('IP<N%V>2P@:W1E<ND@:G-O=2!S=&%RN>T@;F6^('5V961E;OT@<&_H
M970@9&[M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@
M(E!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G
M<W1R(")3;6%Z870@<W1A<ND@>G!RX79Y('IE('-L;[YK>2!K;[EE/R(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M97-S86=E<R!F
M<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`BR&ES=.UM("5D('IP<N%V*'DI
M('IE('-L;[YK>2!K;[EE+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U
M<F=E7W1R87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4'5R9VEN9R`Q(&UE
M<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(LAI<W3M;2`E9"!Z
M<'+A=BAY*2!Z92!S;&^^:WD@:V^Y92XB"@HC.B!T96UP;&%T97,O<75O=&$O
M<75O=&$N:6YC.C$W"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U
M<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R(")3=&%V(&MV
M\W1Y.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@H*(SH@=&5M<&QA=&5S
M+W%U;W1A+W%U;W1A+FEN8SHR,0HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T
M82!S=&%T=7,Z("4N,F9-0B`O($Y/($Q)34E4(@IM<V=S='(@(E-T878@:W;S
M='DZ("4N,F9-0B`O($)%6B!,24U)5%4B"@HC.B!T96UP;&%T97,O<75O=&$O
M<75O=&$N:6YC.C(T"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U
M<SH@3D\@3$E-250B"FUS9W-T<B`B4W1A=B!K=O-T>3H@0D5:($Q)34E452(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T<B`B0VET=6II("5F.B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B4F5?<75E
M<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N(@IM<V=S='(@(J[A7V1O<W0@;R!P
M;W1V<GIE;NT@9&]R=>AE;NTB"@HC.B!L:6(O4V5A<F-H+G!H<#HU,`IM<V=I
M9"`B4F5C96EV960@3VXB"FUS9W-T<B`B4/AI:F%T;R!V(@H*(SH@;&EB+U-E
M87)C:"YP:'`Z-3@*;7-G:60@(E)E8V5I=F5D(%-I;F-E(@IM<V=S='(@(E#X
M:6IA=&\@;V0B"@HC.B!L:6(O4V5A<F-H+G!H<#HU-`IM<V=I9"`B4F5C96EV
M960@56YT:6PB"FUS9W-T<B`B4/AI:F%T;R!D;R(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8U]T
M(@IM<V=S='(@(E#X97-M[')O=F%?="(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8W0B"FUS9W-T
M<B`B4/AE<VWL<F]V870B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C
M="YI;F,Z,3$P"FUS9VED(")2961I<F5C="!-97-S86=E(@IM<V=S='(@(E#X
M97-M[')O=F%T('IP<N%V=2(*"B,Z(&-O;7!O<V4N<&AP.C<X-PIM<V=I9"`B
M4F5D:7)E8W0@=&AI<R!M97-S86=E(@IM<V=S='(@(E#X97-M[')O=F%T('1U
M=&\@>G!RX79U(@H*(SH@8V]M<&]S92YP:'`Z.#0W"FUS9VED(")2961I<F5C
M=&EN9R!F86EL960N(@IM<V=S='(@(E#X97-M[')O=N%N[2!S96QH86QO+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X,PIM<V=I9"`B
M4F5F<F5S:"(*;7-G<W1R(")/8FYO=FET(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<X-`IM<V=I9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S
M='(@(D]B;F]V:70@>F]B<F%Z96[M('-L;[YE:SHB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]H96%D+FEN8SHY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI
M;F,Z-`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(D]B;F]V:70B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]H96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*
M;7-G<W1R(")/8FYO=FET('IO8G)A>F5N[2(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU,C8@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM
M<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B6F%P;VUA=&]V870@<VD@:6YF;W)M86-I(&\@9G)E92]B=7-Y+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-SD*;7-G:60@(E)E;65M8F5R
M('1H92!L87-T('9I97<B"FUS9W-T<B`B6F%P;VUA=&]V870@<VD@<&]S;&5D
M;NT@>F]B<F%Z96[M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C(W"FUS9VED(")296UO=&4@36%I;&)O>#HB"FUS9W-T<B`B5GIDX6QE
M;N$@<V-H<N%N:V$Z(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC
M.C0Q"FUS9VED(")296UO=F4@1FEE;&0@1G)O;2!396%R8V@B"FUS9W-T<B`B
M3V1S=')A;FET('!O;&4@>B!V>6AL963A=N%N[2(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0IM<V=I9"`B4F5M;W9E('-O=7)C
M92(*;7-G<W1R(")/9'-T<F%N:70@>F1R;VHB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHX"FUS9VED(")296YA;64@1F]L9&5R*',I(@IM
M<V=S='(@(E#X96IM96YO=F%T('-L;[YK=2AY*2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R
M(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B4/AE:FUE;F]V870@
M<VQOOFMU(',@;V1E<VQA;OUM:2!Z<'+A=F%M:2!N82!Z8>CA=&MU(&WL<^UC
M93\B"@HC.B!L:6(O1F]L9&5R+G!H<#HT-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5N86UI;F<@7"(E<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B4/AE:FUE;F]VX6[M(%PB
M)7-<(B!N82!<(B5S7"(@<V5L:&%L;RX@5&]T;R!J92!H;.&Y96[M(&]D('-E
M<G9E<G4B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,3`*;7-G:60@(E)E<&Q?>2!T;R!,:7-T(@IM<V=S='(@(D]D<&]?=NQD
M['0@<V5Z;F%M=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T<B`B3F%H<F%D:70Z
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*
M;7-G:60@(E)E<&QY(@IM<V=S='(@(D]D<&]V[&3L="(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0P.0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B3V1P;W;L[R!B>6QA
M(&]D97-LX6YA+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL(@IM<V=S='(@(D]D<&]V
M[&3L="!VN65M(@H*(SH@8V]M<&]S92YP:'`Z-S,S"FUS9VED(")297!L>2!T
M;R!!;&PZ(@IM<V=S='(@(D]D<&]V[&3L="!VN65M.B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;'D@
M=&\@3&ES="(*;7-G<W1R(")/9'!O=NQD['0@<V5Z;F%M=2(*"B,Z(&-O;7!O
M<V4N<&AP.C<S-0IM<V=I9"`B4F5P;'D@=&\@3&ES=#HB"FUS9W-T<B`B3V1P
M;W;L9.QT('-E>FYA;74Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!?06QL(@IM<V=S='(@
M(D]D<&]V[&3L="!?=KEE;2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU,C@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-PHC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED(")297!L>2!W:71H($YO="!3
M=7!P;W)T960@365S<V%G92(*;7-G<W1R(")/9'!O=NSO(',@;F5S=&%N9&%R
M9&[M('IP<N%V;W4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,U
M"FUS9VED(")297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H
M<RXB"FUS9W-T<B`B3V1P;W;L9.QT(&YA(&9R964O8G5S>2!N82!P^.VY=.T@
M,B!M['/M8V4N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-`IM
M<V=I9"`B4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+B(*;7-G<W1R(")/9'!O=NQD['0@<R!P;[YA9&]V86YO=2!I;F9O<FUA
M8^T@9G)E92]B=7-Y+B(*"B,Z(&UE<W-A9V4N<&AP.C(V-PIM<V=I9"`B4F5P
M;'DM5&\B"FUS9W-T<B`B3V1P;W;L9.QT+6MO;74B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z-#`Y"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(D]D<&]V[&3L
M="UK;VUU.B`B"@HC.B!C;VUP;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*
M;7-G<W1R(")/9'!O=NSO.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHR-@IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S='(@(DYA:&SA
M<VET(&IA:V\@8VAT[&[I("AH86TI(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C,U('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C(S"FUS9VED(")297!O<G0@87,@4W!A;2(*;7-G<W1R(").86AL
MX7-I="!J86MO(&YE8VAT[&[I("AS<&%M*2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,X,PIM<V=I9"`B4F5Q=65S="!A(%]296%D(%)E
M8V5I<'0B"FUS9W-T<B`BKN%D;W-T(&\@7W!O='9R>F5N[2!P^&7H=&5N[2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#4*;7-G:60@(E)E<75E<W0@
M9&5L:79E<GD@8V]N9FER;6%T:6]N/R(*;7-G<W1R("*NX61O<W0@;R!P;W1V
M<GIE;NT@9&]R=>AE;NT_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W
M,PIM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G<W1R("*NX61O
M<W0@;R!P;W1V<GIE;NT@</AEZ'1E;NT_(@H*(SH@;6%I;&)O>"YP:'`Z,3@Y
M"FUS9VED(")297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N(@IM<V=S='(@
M(E!OOF%D;W9A;N$@>G!RX79A(&YE8GEL82!N86QE>F5N82XB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-CDW"FUS9VED(")297%U:7)E9"!087)T
M:6-I<&%N="(*;7-G<W1R(")0;[YA9&]V86[M(/KH87-T;NUC:2(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,30S('1E;7!L871E<R]S96%R8V@O
M:&5A9&5R+FEN8SHR-@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q"FUS
M9VED(")297-E="(*;7-G<W1R(")6_6-H;WKM(&YA<W1A=F5N[2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,34*;7-G:60@(E)E<W!O;F1E;G0@
M4W1A='5S(%5P9&%T960N(@IM<V=S='(@(E-T878@;V1P;W;M9&%J[6/M8V@@
M8GEL(&%K='5A;&EZ;W;A;BXB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R(")0;VMR
M8>AO=F%T(@H*(SH@<F5C;VUP;W-E+G!H<#HY.`IM<V=I9"`B4F5S=6UE('EO
M=7(@<V5S<VEO;B(*;7-G<W1R(")0;VMR8>AO=F%T('8@<F5L86-I(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0T"B,L(&9U>GIY"FUS
M9VED(")2971U<FX@=&\@7")-97-S86=E($-O;7!O<VET:6]N7"(B"FUS9W-T
M<B`B5GET=F_X:70@>G!RX79U(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D
M<FEV97)?<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C
M="YI;F,Z,S(*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@
M(D[A=G)A="!K92!S=&%H;W;A;NT@<&^Y='DB"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E
M+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP
M;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L871E<R]A8VPO86-L
M+FEN8SHQ-S,*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(D[A
M=G)A="!D;R!M;[YN;W-T[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M,3@*;7-G:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F
M=&5R(&1E;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/R(*
M;7-G<W1R(")6<N%T:70@<V4@9&\@<V-H<N%N:WD@<&\@<VUA>N%N[2P@</AE
M<W5N=73M+"!N96)O('IK;W#M<F]VX6[M('IP<N%V>3\B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")2;VQE(@IM<V=S='(@(MIL
M;VAA(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#(@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HR,S<*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HT,3D*;7-G:60@(E,O34E-12(*;7-G<W1R(")3+TU)344B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$R"FUS9VED
M(")3+TU)344@16YC<GEP="!-97-S86=E(@IM<V=S='(@(E,O34E-12"Y:69R
M;W9A;N$@>G!RX79A(@H*(SH@8V]M<&]S92YP:'`Z,SDT"FUS9VED(")3+TU)
M344@17)R;W(Z("(*;7-G<W1R(")3+TU)344@8VAY8F$Z("(*"B,Z(&-O;7!O
M<V4N<&AP.C,W,PIM<V=I9"`B4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A
M<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R(")3+TU)344@
M8VAY8F$Z($IE('!O=/AE8F$@:&5S;&\@<')O(%;AN2!O<V]B;NT@<')I=N%T
M;NT@:VSMZ"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"FUS9VED
M(")3+TU)344@3W!T:6]N<R(*;7-G<W1R(")-;[YN;W-T:2!3+TU)344B"@HC
M.B!S;6EM92YP:'`Z-#D*;7-G:60@(E,O34E-12!087-S<&AR87-E($EN<'5T
M(@IM<V=S='(@(E9L;[YI="!3+TU)344@:&5S;&\B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y
M<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R("(B"B)*92!P;W3X96)A(&)E>G!EZ&[I:&\@</AI<&]J96[M
M(&L@<^UT:2`H2%144%,I+"!A8GES=&4@;6]H;&D@<&]UONUT(%;AN2`B"B)O
M<V]B;NT@4R]-24U%(&ML[>AO=OT@<.%R+B(*"B,Z('-M:6UE+G!H<#HQ-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@9F]R(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(E,O34E-
M12!V9?AE:F[](&ML[>@@<')O(%PB)7-<(B!B>6P@^G-P[+EN["!S;6%ZX6XN
M(@H*(SH@<VUI;64N<&AP.C$V,@IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@
M<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")3+TU)344@=F7X96IN_2!K
M;.WH(&)Y;"#Z<W#LN6[L('#X:63A;BXB"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C$P"FUS9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS
M9W-T<B`B4R]-24U%('9E^&5J;OT@<W9A>F5K(&ML[>CY(@H*(SH@<VUI;64N
M<&AP.C(Q,0IM<V=I9"`B4R]-24U%(%!U8FQI8R]0<FEV871E($ME>7!A:7(@
M<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")3+TU)344@=F7X96IN_2]P
M<FEVX71N[2!K;.WH;W;]('#A<B!B>6P@^G-P[+EN["!P^&EDX6XN(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,PIM<V=I9"`B
M4R]-24U%(%-I9VX@365S<V%G92(*;7-G<W1R(")3+TU)344@<&]D97!S86[A
M('IP<N%V82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI
M;F,Z,30*;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G
M<W1R(")3+TU)344@<&]D97!S86[A+[EI9G)O=F%NX2!Z<'+A=F$B"@HC.B!T
M96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHT"FUS9VED(")3+TU)344@
M<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B
M5&5N=&\@<WES=.EM(&YE<&]D<&]R=6IE(%,O34E-12XB"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U<'!O
M<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES
M('5N86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(E!O9'!O<F$@
M4R]-24U%(&YE;NT@86MT:79O=N%N82P@>G!RX79U(&YE;'IE(&1EN6EF<F]V
M870N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S,*(RP@9G5Z
M>GD*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O
M('1H92!C;VYT96YT<R!O9B!T:&ES('-I9VYE9"!M97-S86=E(&-A;B!N;W0@
M(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R(")0;V1P;W)A(%,O34E-12!N96[M
M(&%K=&EV;W;A;F$L(&1I9VETX6QN[2!P;V1P:7,@;F5L>F4@;W;L^&ET+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3
M+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S
M:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M(")0;V1P;W)A(%,O34E-12!N96[M(&%K=&EV;W;A;F$L(&1I9VETX6QN[2!P
M;V1P:7,@;F5L>F4@;W;L^&ET+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,@HC+"!F=7IZ>0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@<F5Q
M=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W
M<V5R(&ES("(*(F-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD
M;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@(@HB
M=&AE(%,O34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB
M"FUS9W-T<B`B(@HB4&]D<&]R82!3+TU)344@<&]T^&5B=6IE('!O<'5P(&]K
M;F$N(%!O:W5D(%;AN2!P<F]H;.V^9>@@>F%M97IU:F4@<&]UOFET[2`B"B)T
M[&-H=&\@;VME;BP@:F4@>F%P;W3X96+M('5M;[YN:70@:F5J:6-H('!O=;YI
M=.TL(&II;F%K(%,O34E-12!N96)U9&4@(@HB<W!RX79N["!P<F%C;W9A="XB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P-0IM<V=I9"`B4TU4
M4"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHR-34*;7-G:60@(E-?=6)J96-T(@IM<V=S='(@(E]0^&5D;>QT(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S8S"FUS9VED(")385]V
M92!A(&-O<'D@:6X@(@IM<V=S='(@(E5L7V^^:70@:V]P:6D@9&\@(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED
M(")385]V92!A<R(*;7-G<W1R(")5;%]OOFET(&IA:V\B"@HC.B!S96%R8V@N
M<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*;7-G
M:60@(E-A=F4B"FUS9W-T<B`B56QOOFET(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE;G1S('=I
M=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R(")5;&^^
M:70@</CM;&]H>2!S92!Z<'+A=F]U('9E('-L;[YC92!P<F\@;V1E<VQA;F]U
M('!ON71U/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PIM<V=I9"`B4V%V
M92!$<F%F="(*;7-G<W1R(")5;&^^:70@<F]Z97!S86YO=2!Z<'+A=G4B"@HC
M.B!S879E:6UA9V4N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")3879E($EM86=E
M(@IM<V=S='(@(E5L;[YI="!J86MO(@H*(SH@;&EB+TU)344O0V]N=&5N=',N
M<&AP.C(P-`IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T
M86-T:79E+FEN8SHQ,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E
M;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V92!/<'1I
M;VYS(@IM<V=S='(@(E5L;[YI="!M;[YN;W-T:2(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHT,`HC+"!F=7IZ>0IM<V=I9"`B4V%V92!3
M=&%T:6]N97)Y(@IM<V=S='(@(E5L;[YI="!M;[YN;W-T:2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0S,PIM<V=I9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B
M56QOOFET(%]R;WIE<'-A;F]U('IP<N%V=2(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%V92!A<R(*;7-G
M<W1R(")5;&^^:70@:F%K;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B56QO
MOFET(')O>F5P<V%N;W4@>G!RX79U(&IA:V\@;F5P<F]H;.ED;G5T;W4_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-S(*;7-G:60@(E-A=F4@<F5C
M:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@
M8F]O:S\B"FUS9W-T<B`B56QOOFET(&%U=&]M871I8VMY('#X[6IE;6-E(&1O
M(&EM<&QI8VET;NUH;R!A9')E<^'X93\B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@87,@82!V:7)T=6%L
M(&9O;&1E<C\B"FUS9W-T<B`B56QOOFET('9Y:&QE9.%VX6[M(&1O('9I<G1U
MX6QN[2!S;&^^:WD_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM
M<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(E5L;[YI="!O9&5S;&%N
M;W4@<&^Y='4_(@H*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B3F5P;V1A^&EL;R!S92!U
M;&^^:70@<F]Z97!S86YO=2!Z<'+A=G4N(%1O=&\@:F4@:&SAN65N[2!Z92!S
M97)V97)U.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3DY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB
M+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G
M<W1R(")6>6AL963A=N%N[2(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R
M+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E-E87)C:"`E<R(*;7-G<W1R(")6>6AL963A=N%N
M[2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C`*(RP@9G5Z>GD*
M;7-G:60@(E-E87)C:"!/<'1I;VYS(@IM<V=S='(@(E5L;[YI="!M;[YN;W-T
M:2(*"B,Z('-E87)C:"YP:'`Z,C8U"FUS9VED(")396%R8V@@4F5S=6QT<R(*
M;7-G<W1R(")6_7-L961K>2!V>6AL963A=N%N[2(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,30@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS,0IM<V=I9"`B4V5E;B(*;7-G<W1R(")0<F]H;.ED;G5TZ2(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z.0IM<V=I9"`B4V5L96-T
M(@IM<V=S='(@(E9Y8G)A="(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHW,`IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G
M<W1R(")6>6)R870@:FEN_2#ZZ&5T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F
M:65L9',N:6YC.C,V"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E9Y
M8G)A="!D871U;2(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHQ
M,`IM<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`B5GEB<F%T('!O;&4B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@(E9Y8G)A
M="!D871U;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@
M(E-E;&5C="!A9&1R97-S(&)O;VL@<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S
M96%R8VAI;F<@9F]R(&%D9')E<W-E<RXB"FUS9W-T<B`B5F]L8F$@>F1R;VKY
M(&%D<F5SX?AE('!R;R!P^&EDX79A;NT@82!V>6AL963A=N%N[2!A9')E<RXB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE
M8W0@86QL(@IM<V=S='(@(E9Y8G)A="!6N64B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*;7-G:60@(E-E;&5C="!A;&P@9FEE
M;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S
M='(@(E9Y8G)A="!VN65C:&YA('!O;&4@<')O('9Y:&QE9.%VX6[M('#X:2!E
M>'!A;GII(&%D<F5S+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N
M=%]S96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@86X@86-C;W5N="(*;7-G
M<W1R(")6>6)R870@^NAE="(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z.#D*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(DYE=GEB<N%N;R(*
M"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS9VED
M(")396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C
M="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP92(*
M;7-G<W1R(")6>6)R870@='EP('!ON71O=F[M:&\@<V5R=F5R=2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P.0IM<V=I9"`B4V5L
M96-T960@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`B5GEB<F%N_2!Z9')O:B!A
M9')E<^'X^3HB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@
M(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`B4&]S;&%T
M(&ML[>@@=F7X96INZ6UU(&ML[>AO=NEM=2!S97)V97)U(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8P-`IM<V=I9"`B4V5N9"!,871E<W0@26YF
M;W)M871I;VXB"FUS9W-T<B`B4&]S;&%T(&YE:F%K='7A;&[L:KGM(&EN9F]R
M;6%C92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0IM<V=I9"`B4V5N9"!-
M97-S86=E(@IM<V=S='(@(D]D97-L870@>G!RX79U(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<P,PHC+"!F=7IZ>0IM<V=I9"`B4V5N9"!R96%D(')E
M8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B
M4&]S;&%T($U$3B!P;VMU9"!J92"^X63A;F\@;V1E<^UL871E;&5M/R(*"B,Z
M(&9O;&1E<G,N<&AP.C,Y-PIM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G
M<W1R(")3;&^^:V$@<R!O9&5S;&%N;W4@<&^Y=&]U(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I9"`B4V5N="!M86EL
M(&9O;&1E<CHB"FUS9W-T<B`B4VQOOFMA(',@;V1E<VQA;F]U('!ON71O=3HB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$T-@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$U,PIM<V=I9"`B4V5R=F5R(@IM<V=S='(@(E-E<G9E<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PIM<V=I9"`B4V5R=F5R(&%N9"!&;VQD
M97(@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-E(&\@<V5R=F5R=2!A
M('-L;[YKX6-H(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C(S"FUS9VED(")397)V97(Z(@IM<V=S='(@(E-E<G9E<CHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F97)E;F-E<R!F
M;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M97-S
M86=E<RXB"FUS9W-T<B`B3F%S=&%V96[M(&%K8^T@<')O=N%D[&[]8V@@</AI
M('#X97-O=7;A;NT@82!M87KA;NT@>G!RX78N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4R.0IM<V=I9"`B4V5T('1H92!8+5!R:6]R:71Y(&AE861E
M<B!W:&5N(&-O;7!O<VEN9R!M97-S86=E<S\B"FUS9W-T<B`B3F%S=&%V:70@
M</AI('9Y=';A^&5N[2!Z<'+A=B!H;&%V:>AK=2!8+5!R:6]R:71Y/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@1F]L9&5R
M<R(*;7-G<W1R(")39.UL96[I('-L;[YK>2(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHX-@IM<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@
M(E-D[6QE="!P;[ET;W9N[2!S;&^^:WDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@
M;W1H97(@=7-E<G,N(@IM<V=S='(@(E-D[6QE="!P;[ET;W9N[2!S;&^^:WD@
M<R!J:6[];6D@=;YI=F%T96QI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-CD*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D
M('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B
M92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS
M9W-T<B`B(@HB3>$@8OUT(&EM<&QI8VET;NT@;F%S=&%V96[M('!R;R!V96QK
MZ2!B;&]K>2!C:71O=F%NZ6AO('1E>'1U('IO8G)A>F5NZ2!N96)O("(*(G5K
M<GETZ3\@3'IE(&IE9&YO9'6Y92!P^&5P;F]U="!B97H@;VAL961U(&YA(';]
M8NQR+B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW"FUS9VED(")3:&]U
M;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D
M(&9O<B!01U`@9&%T83\B"FUS9W-T<B`B36%J[2!S92!H;&5D870@4$=0(&1A
M=&$@=B!T[&QE('1E>'0O<&QA:6X@>G!RX78_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4Q,PIM<V=I9"`B4VAO=6QD('1H92!C;VUP;W-E('=I;F1O
M=R!B92!C;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_(@IM<V=S='(@(DWA
M('-E(&]K;F\@<')O('9Y='9O^&5N[2!Z<'+A=GD@=7IA=OCM="!P;R!U;&^^
M96[M(')O>F5P<V%NZ2!Z<'+A=GD_(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C0*;7-G:60@(E-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E
M(&%T=&%C:&5D('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\B"FUS9W-T
M<B`B3>$@8OUT(%;AN2!V9?AE:F[](%!'4"!K;.WH(&EM<&QI8VET;NP@</AI
M<&]J;W;A;B!K(%9AN6EM('IP<N%VX6T_(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHY,@IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R
M("):;V)R87II="!VN65C:&YY('-L;[YK>2(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VAE861E<G,N:6YC.C8W"FUS9VED(")3:&]W($%L;"!(96%D97)S(@IM
M<V=S='(@(EIO8G)A>FET(':Y96-H;GD@:&QA=FGH:WDB"@HC.B!M86EL8F]X
M+G!H<#HS-C4*;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R("):;V)R87II
M="!S;6%Z86[I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z
M-C$*;7-G:60@(E-H;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(EIO8G)A
M>FET(')E9'5K;W9A;ND@:&QA=FGH:WDB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]H96%D97)S+FEN8SHW,`IM<V=I9"`B4VAO=R!-86EL:6YG($QI<W0@26YF
M;W)M871I;VXB"FUS9W-T<B`B6F]B<F%Z:70@:6YF;W)M86-E(&\@96QE:W1R
M;VYI8VOI(&MO;F9E<F5N8VDB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.CDR"FUS9VED(")3:&]W($]N;'D@4W5B<V-R:6)E9"!&;VQD97)S(@IM
M<V=S='(@(EIO8G)A>FET('!O=7IE(&%K=&EV;W9A;ND@<VQOOFMY(@H*(SH@
M9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G
M<W1R("):;V)R87II="!N96%K=&EV;NTB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C`X"FUS9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P
M:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(EIO
M8G)A>FET(&EK;VYU('!R;R!O9'-T<F%N[&[M('#X[6QO:"!Z92!Z<'+A=C\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P,@IM<V=I9"`B4VAO=R!L
M96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\B"FUS9W-T<B`B6F]B<F%Z:70@
M;&5G96YD=2!V('IO8G)A>F5N[2!S8VARX6YK>3\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#0P"FUS9VED(")3:&]W('!R979I97=S(&9O<B!U;G)E
M860@;65S<V%G97,@;VYL>3\B"FUS9W-T<B`B6F]B<F%Z:70@;N%H;&5D>2!P
M;W5Z92!P<F\@;F5P^&7H=&5NZ2!Z<'+A=GD_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@T.`IM<V=I9"`B4VAO=R!P<F5V:65W<R!I;B!T;V]L=&EP
M<S\B"FUS9W-T<B`B6F]B<F%Z:70@;N%H;&5D>2!V('1I<&5C:#\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<W"FUS9VED(")3:&]W('1H92!&971C
M:"!-86EL(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(EIO8G)A>FET
M(&EK;VYU('-T86AO=N%N[2!P;[ET>2!V(&QIN73L(&UE;G4_(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VAT;6PN<&AP.CDU"FUS9VED(")3:&]W('1H92!);6%G
M97,B"FUS9W-T<B`B6F]B<F%Z:70@;V)RX7IK>2(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHU-`IM<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC
M;VX@;VX@=&AE(&UE;G5B87(_(@IM<V=S='(@(EIO8G)A>FET(&EK;VYU(&9I
M;'1R;W;A;NT@=B!L:;ET["!M96YU/R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HR.`IM<V=I9"`B4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@
M9F]L9&5R/R(*;7-G<W1R("):;V)R87II="!C96QK;W;]('!OZ&5T('IP<N%V
M('9E('-L;[YC93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8V"FUS
M9VED(")3:&]W;B(*;7-G<W1R(")5:^%ZX6YO(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT,@IM<V=I9"`B4VE?>F4B"FUS
M9W-T<B`B5F5?;&EK;W-T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHQ-PIM<V=I9"`B4VEG;F5D(@IM<V=S='(@(E!O9&5P<V%NX2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")3
M:7IE(@IM<V=S='(@(E9E;&EK;W-T(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHQ,0IM<V=I9"`B4V]R="!B>2!!<G)I=F%L
M(@IM<V=S='(@(E-E=/CM9&ET('!O9&QE('!O^&%D[2!D;W)UZ&5N[2(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,38*;7-G
M:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R(")3973X[61I="!P;V1L92!D871A
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR
M-@IM<V=I9"`B4V]R="!B>2!&<F]M($%D9')E<W,B"FUS9W-T<B`B4V5T^.UD
M:70@<&]D;&4@861R97-Y(&]D97/M;&%T96QE(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT,0IM<V=I9"`B4V]R="!B>2!-
M97-S86=E(%-I>F4B"FUS9W-T<B`B4V5T^.UD:70@<&]D;&4@=F5L:6MO<W1I
M('IP<N%V>2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,S8*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R(")3973X
M[61I="!P;V1L92!P^&5D;>QT=2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z,S$*;7-G:60@(E-O<G0@8GD@5&AR96%D(@IM
M<V=S='(@(E-E=/CM9&ET('!O9&QE('-O=79I<VQO<W1I(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B4V]R
M="!B>2!4;R!!9&1R97-S(@IM<V=S='(@(E-E=/CM9&ET('!O9&QE(&%D<F5S
M>2!P^.UJ96UC92(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN
M8SHR,PIM<V=I9"`B4W!A;2!F;VQD97(Z(@IM<V=S='(@(E-L;[YK82!P<F\@
M<W!A;3HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#8*
M;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G<W1R("):=FSAN71N[2!Z
M;F%K>2(*"B,Z('-E87)C:"YP:'`Z,3,S"FUS9VED(")3<&5C:6%L(%9I<G1U
M86P@1F]L9&5R<R!C86X@;F]T(&)E(&5D:71E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0S"FUS9VED(")3<&5L
M;"!#:&5C:R(*;7-G<W1R(")+;VYT<F]L82!P<F%V;W!I<W4B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(E-P96QL($-H
M96-K97(B"FUS9W-T<B`B2V]N=')O;&]R('!R879O<&ES=2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E
M(@IM<V=S='(@(DMO;G1R;VQA('!R879O<&ES=2!D;VMO;NAE;F$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Q"FUS9VED(")3<&5L;&EN9R!E<G)O
M<G,@<&5R('-C<F5E;B!W:&5N('-P96QL(&-H96-K:6YG+B(*;7-G<W1R(").
M86QE>F5NZ2!P<F%V;W!I<V[I(&-H>6)Y(&YA('-T<N%N8V4N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q,B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C4R"FUS9VED(")3=&%R="(*;7-G<W1R("):8>CA=&5K(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.CD@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,S$Q"FUS9VED(")3=&%T:6]N97)Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR-@IM
M<V=I9"`B4W1A=&EO;F5R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C@*;7-G:60@(E-T871I;VYE<GD@
M='EP93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C,S"FUS9VED(")3=&%T:6]N97)Y.B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`B4W1A=B(*"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HR,34*;7-G
M:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T<B`B3V1S=')A;FET('#X[6QO
M:'4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,R"FUS9VED(")3=')I
M<"!L:6YE8G)E86MS/R(*;7-G<W1R(")/9'-T<F%N:70@^.%D:V]VX6[M/R(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*
M;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(E#X95]D;>QT(@H*(SH@;65S<V%G
M92YP:'`Z,C8X('1H<F5A9"YP:'`Z,34P('1E;7!L871E<R]C;VUP;W-E+W)E
M8V]M<&]S92YI;F,Z,C4*(SH@;&EB+U-E87)C:"YP:'`Z,S@*;7-G:60@(E-U
M8FIE8W0B"FUS9W-T<B`B4/AE9&WL="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,C`*;7-G:60@(E-U8FIE8W0@1FEE;&0B"FUS9W-T<B`B4&]L92!P
M^&5D;>QT(@H*(SH@<V5A<F-H+G!H<#HS,3@@=&5M<&QA=&5S+W-A=F5I;6%G
M92]S879E:6UA9V4N:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR
M87-E+FEN8SHR,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q"FUS
M9VED(")3=6)M:70B"FUS9W-T<B`B4&]D870B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B4W5B<V-R:6)E('1O($9O;&1E
M<BAS*2(*;7-G<W1R(")!:W1I=F]V870@<VQOOFMU*'DI(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HS.#`@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@W"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(MIS<.RY;NPB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E<W1I;VYS(@IM<V=S
M='(@(D[A=G)H>2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C(@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B4W5M;6%R>2(*
M;7-G<W1R(")3:')N=73M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#`P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,PIM
M<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G<W1R(")0^&5P
M;F]U="!K;VUP;WIIZ&[M(&UE=&]D=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H('1O($A434P@8V]M<&]S
M:71I;VXB"FUS9W-T<B`B4/AE<&YO=70@;F$@2%1-3"!K;VUP;WII8VDB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W
M:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@(E#X97!N
M;W5T(&YA('1E>'1O=F]U(&MO;7!O>FEC:2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0Q.0IM<V=I9"`B5&5?>'0B"FUS9W-T<B`B5&5?
M>'0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8Y"FUS9VED(")4
M96YT871I=F4Z("(*;7-G<W1R(")0<F]Z873M;6[M.B`B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3DQ"FUS9VED(")496YT871I=F5L>2!!8V-E
M<'0@<F5Q=65S="(*;7-G<W1R(")0<F]Z873M;6[L('!O='9R>F5NX2"^X61O
M<W0B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8Q"FUS9VED(")4
M96YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R(")0<F]Z873M;6[L('!O='9R
M>F5N;R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@
M9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP(@IM<V=S='(@(E-O=6)O
M<B!D969I;G5J[6/M('!O9&WM;FMY('!O=;YI=.T@;F5N[2!O8G-AOF5N('8@
M8V]N9BYP:'`B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,S`*(RP@9G5Z>GD*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5?>'0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED(")4:&4@1G)O;3H@8V]L
M=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@
M(E-L;W5P96,@3V0Z(&)Y(&WL;"!B_70@;V1K87IO=N%N.B(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z-3,R"FUS9VED("(B"B)4:&4@24U!4"!S97)V97(@
M9&]E<R!N;W0@87!P96%R('1O('-U<'!O<G0@=&AE(&%U=&AE;G1I8V%T:6]N
M(&UE=&AO9"`B"B)S96QE8W1E9"X@4&QE87-E(&-O;G1A8W0@>6]U<B!S>7-T
M96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0IM<V=I9"`B5&AE($UA8VEN=&]S:"!R
M97-O=7)C92!F;W)K(@IM<V=S='(@(DUA8VEN=&]S:"!Z9')O:F]VZ2!R;WID
M=F]J96[M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E
M(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(DUA8VEN=&]S
M:"!Z9')O:F]VZ2!R;WID=F]J96[M(&WYOF4@8OUT('-T8;YE;F\@>B`E<RXB
M"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(MKH970@7"(E<UPB(&)Y;"!S;6%ZX6XN(@H*(SH@9F5T8VAM86EL<')E
M9G,N<&AP.C<T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB
M)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`BVNAE="!<(B5S7"(@8GEL
M('5L;[YE;BXB"@HC.B!A='1A8VAM96YT+G!H<#HT,PIM<V=I9"`B5&AE(&%T
M=&%C:&UE;G0@=V%S(&YO="!F;W5N9"XB"FUS9W-T<B`B4/CM;&]H82!N96)Y
M;&$@;F%L97IE;F$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y
M"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@
M(D1A=&$@=B!K86QE;F3A^&D@:G-O=2!N97!L871NX2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V]M<&]S95]W:6XN:G,Z,S<*;7-G:60@(B(*
M(E1H92!C;VUP;W-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@
M>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W
M:6YD;W=S/R(*;7-G<W1R("(B"B)/:VYO('!R;R!V>71VX?AE;NT@>G!RX78@
M;F5L>F4@;W1E=OCM="X@6OAE:FWL(&IS=&4@;F%S=&%V:6QI(%;AN2!P<F]H
M;.V^9>@@(@HB=&%K+"!A8GD@8FQO:V]V86P@<&]P=7`@;VMN83\B"@HC.B!L
M:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4:&4@
M8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB"FUS
M9W-T<B`B3V)S86@@<V]U8F]R=2!Z($UA8VEN=&]S:&4@:F4@>F]B<F%Z96X@
M;NV^92XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA
M:6Q?;6]N=&AL>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-U
M<G)E;G0@9F]L9&5R*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M960@=&\@7"(E
M<UPB+B(*;7-G<W1R(")3;W7H87-NX2!S;&^^:V$H>2D@7"(E<UPB(&)U9&4@
M</AE:FUE;F]VX6YA(&YA(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,3`W"FUS9VED("(B"B)4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S
M('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R
M:65V960B"FUS9W-T<B`B3F5L>F4@>NUS:V%T('-E>FYA;2!UOFEV871E;/D@
M<R!P^.US='5P96T@:R!TZ71O('-L;[YC92(*"B,Z(&-O;7!O<V4N<&AP.C$R
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B965N('-A
M=F5D('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R(")2;WIE<'-A;N$@
M>G!RX79A(&)Y;&$@=6QOOF5N82!V(%PB)7-<(B!S;&^^8V4N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$S.0IM<V=I9"`B5&AE(&5V96YT('=A
M<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G<W1R(")59.%L;W-T(&)Y
M;&$@</AI9.%N82!D;R!68;EE:&\@:V%L96YDX?AE+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5X<&%N9"YI;F,Z.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I96QD(%PB)7-<(B!C86XG="!B92!E>'!A;F1E9"XB"FUS
M9W-T<B`B4&]L92`G)7,G(&YE;'IE(&1O<&QN:70N(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z,S,W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(E-L;[YK82!<(B5S7"(@=;X@
M97AI<W1U:F4B"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A
M;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O
M8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@HB3N%Z978@<VQOOFMY(%PB)7-<(B!O8G-A:'5J92!N97!O
M=F]L96[I('IN86MY+B!4;R!M^;YE('IP^7-O8FET('!R;V)LZ6UY+B`B"B)0
M<F]S[6T@:V]N=&%K='5J=&4@<W;I:&\@<WES=.EM;W;I:&\@861M:6YI<W1R
MX71O<F$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4V"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@
M=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B4VQOOFMA(%PB
M)7-<(B!B>6QA('9Y='9O^&5N82P@86QE(&YE;NT@86MT:79O=N%N82XB"@HC
M.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U
M;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B4VQOOFMA(%PB)7-<(B!B
M>6QA('-M87KA;F$L(&%L92!N96)Y;&$@9&5A:W1I=F]VX6YA+B(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L
M9&5R(%PB)7-<(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B4VQOOFMA(%PB)7-<(B!N96)Y;&$@=GET
M=F_X96YA+B!4;W1O(&IE(&ALX;EE;NT@<V5R=F5R=2(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`B4VQOOFMA(%PB)7-<(B!N96)Y;&$@<VUA>N%N82X@
M5&]T;R!J92!H;.&Y96[M('-E<G9E<G4B"@HC.B!L:6(O1F]L9&5R+G!H<#HS
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!C<F5A=&5D+B(*;7-G<W1R(")3;&^^:V$@7"(E<UPB
M(&)Y;&$@^G-P[+EN["!V>71V;_AE;F$N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,C<U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A
M<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B4VQOOFMA(%PB)7-<
M(B!B>6QA(/IS<.RY;NP@<VUA>N%N82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B4VQO
MOFMA(%PB)7-<(B!B>6QA(/IS<.RY;NP@</AE:FUE;F]VX6YA(&YA(%PB)7-<
M(BXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H
M92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z
M(@IM<V=S='(@(D[A<VQE9'5J[6/M('-O=6)O<GD@8GEL>2!P^&EL;[YE;GD@
M:R!TZ71O(.CA<W1I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M<V%V96EM86=E7W=I;BYJ<SHQ,@HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE(&EM
M86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H87!S('EO
M=2!H879E('-E="!Y;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN
M9&]W<S\B"FUS9W-T<B`B(@HB3VMN;R!P<F\@=GET=N'X96[M('IP<N%V(&YE
M;'IE(&]T97;X[70N(%KX96IM["!J<W1E(&YA<W1A=FEL:2!6X;D@<')O:&SM
MOF7H("(*(G1A:RP@86)Y(&)L;VMO=F%L('!O<'5P(&]K;F$_(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"FUS9VED("(B"B)4:&4@:6UA9V5S
M('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S
M96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN(@IM<V=S='(@(D]B<N%Z96L@
M8G5D92!Z;V)R87IE;BP@<')O=&^^92!O9&5S[6QA=&5L(&IE('9E(%9AN65M
M(&%D<F5SX?AI+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U
M"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I
M;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B4&^Y=&]V;NT@<V5R=F5R(&=E
M;F5R;W9A;"!NX7-L961U:NUC[2!C:'EB;W;I(&ALX;EE;NTZ(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3$*;7-G:60@(E1H92!M
M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO
M;F%L(&UE<W-A9V4Z(@IM<V=S='(@(E!ON71O=F[M('-E<G9E<B!G96YE<F]V
M86P@;N%S;&5D=6KM8^T@:6YF;W)M8>AN[2!H;.&Y96[M.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.CDP"FUS9VED(")4:&4@;6%I;"!S97)V
M97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93HB"FUS9W-T<B`B
M4&^Y=&]V;NT@<V5R=F5R(&=E;F5R;W9A;"!NX7-L961U:NUC[2!H;.&Y96[M
M.B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B
M4V-H<N%N:V$@)7,@:F4@:FF^('!RX7ID;N$N(@H*(SH@;&EB+T9E=&-H;6%I
M;"YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(%PB
M)7-<(B!F<F]M(%PB)7-<(B`H)60@8GET97,I(&5X8V5E9',@9F5T8V@@<VEZ
M92!L:6UI="XB"FUS9W-T<B`B(@HB6G!RX79A(%PB)7-<(B!O9"!<(B5S7"(@
M*"5D(&)Y=/DI('#X96MR;^AI;&$@;&EM:70@<')O('-T86AO=N%N[2!P;[ET
M>2XB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P,PIM
M<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@8V]M<&]S960@:&%S(&)E96X@8VQO
M<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")6>71VX?AE;N$@>G!RX79A(&)Y;&$@
M=7IA=OAE;F$N($MO;NCM;2XB"@HC.B!M97-S86=E+G!H<#HQ-#@*;7-G:60@
M(E1H92!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(EIP<N%V
M82!B>6QA('9Y;6%ZX6YA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C,Y,PIM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(@IM
M<V=S='(@(EIP<N%V82!B>6QA(&]V[/AE;F$N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE
M<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@)7,N(@IM<V=S='(@
M(EIP<N%V82!B>6QA(&]V[/AE;F$N($]D97/M;&%T96PZ("5S+B(*"B,Z('1E
M;7!L871E<R]S;6EM92]O<&5N7W-M:6UE7W=I;BYJ<SHQ,"!T96UP;&%T97,O
M<&=P+V]P96Y?<&=P7W=I;BYJ<SHQ,`IM<V=I9"`B(@HB5&AE('!A<W-P:')A
M<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S
M970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM
M<V=S='(@(B(*(DYE;'IE(&]T97;X[70@;VMN;R!S(&AE<VQE;2X@6OAE:FWL
M(&IS=&4@;F%S=&%V:6QI(%;AN2!P<F]H;.V^9>@@=&%K+"!A8GD@(@HB8FQO
M:V]V86P@<&]P=7`@;VMN83\B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F('1H
M92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")4
M97AT(%!'4"!V9?AE:F[I:&\@:VSMZ&4@;?F^92!B_70@<')O:&SI9&YU="`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@(E1H
M92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%
M1B!A='1A8VAM96YT+B(*;7-G<W1R(")0;[YA9&]V86[]('-O=6)O<B!V($U3
M+51.148@</CM;&]Z92!N965X:7-T=6IE+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8T"FUS9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N
M;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM96YT+B(*;7-G<W1R(")0;[YA
M9&]V86[]('-O=6)O<B!V('II<"!P^.UL;WIE(&YE97AI<W1U:F4N(@H*(SH@
M;65S<V%G92YP:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S
M96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E
M($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO
M=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@
M<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(D]D97/M;&%T96P@=.ET;R!Z<'+A=GD@;V0@5N%S('!OOF%D=6IE('!O='9R
M>F5N[2`H365S<V%G92!$:7-P;W-I=&EO;B`B"B).;W1I9FEC871I;VXI('!O
M('#X9>AT96[M('IP<N%V>2X@4')O<^UM(&ML:6MN['1E("5S('!R;R!O9&5S
M;.%N[2!TZ71O("(*(GIP<N%V>2XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HV.0IM<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@
M8W)E871E(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(E-E
M<G9E<B!N96)Y;"!S8VAO<&5N('9Y='9O^&ET(&UI;FEA='5R=2!T;VAO=&\@
M;V)RX7IK=2XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P
M-`IM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N
M(@IM<V=S='(@(DYE;'IE(&YA:')A9&ET('-I9VYA='5R=2XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P,@IM<V=I9"`B5&AE('-I9VYA
M='5R92!W87,@<W5C8V5S<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R(")3:6=N
M871U<F$@8GEL82#Z<W#LN6[L(&YA:')A>F5N82XB"@HC.B!A='1A8VAM96YT
M+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")0;[YA9&]V86[]('-O=6)O<B!N965X:7-T=6IE+B(*
M"B,Z('-T871I;VYE<GDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@861D960N(@IM
M<V=S='(@(MKH970@7"(E<UPB(&)Y;"!U;&^^96XN(@H*(SH@<W1A=&EO;F5R
M>2YP:'`Z-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T
M:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+:Z&5T
M(%PB)7-<(B!B>6P@<VUA>N%N+B(*"B,Z('-T871I;VYE<GDN<&AP.C@W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S
M7"(@:&%S(&)E96X@=7!D871E9"XB"FUS9W-T<B`BVNAE="!<(B5S7"(@8GEL
M('-M87KA;BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38Y"FUS
M9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T
M+B(*;7-G<W1R("+::V]L(&)Y;"!P^&EDX6X@9&\@5F&Y96AO('-E>FYA;74@
M^FMO;/DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G
M:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S='(@(E1E>'0@>G!R
MX79Y(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B5&5X="!Z<'+A=GD@;'IE('!R;VALZ61N
M;W5T("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R
M(")497AT(&YA=G+A8V5NZ2!Z<'+A=GDB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O
M9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G
M<W1R(")497AT(&YA=G+A8V5NZ2!Z<'+A=GD@;'IE('!R;VALZ61N;W5T("5S
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@(E1E
M>'0@>F%S;&%NZ2!Z<'+A=GDB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I
M8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O
M9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@
M(E1E>'0@>F%S;&%NZ2!Z<'+A=GD@;'IE('!R;VALZ61N;W5T("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-30*;7-G:60@(E1H92!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R
M960N(@IM<V=S='(@(E6^:79A=&5L;W9A(&EN9F]R;6%C92!O(&9R964O8G5S
M>2!B>6QA(/IS<.RY;NP@=6QOOF5N82XB"@HC.B!L:6(O34E-12]6:65W97(O
M86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N
M871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS
M9W-T<B`BKN%D;ND@:FENZ2#HX7-T:2!N96QZ92!U=FYI=/@@>G!RX79Y('IO
M8G)A>FET+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V5M<'1Y7VUA:6QB;W@N
M:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA
M:6QB;W@N(@IM<V=S='(@(E1A=&\@<V-H<N%N:V$@;F5O8G-A:'5J92"^861N
MZ2!Z<'+A=GDN(@H*(SH@=&AR96%D+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@
M(E1H97)E(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92XB"FUS9W-T<B`BKN%D;ND@:FENZ2#HX7-T:2!N96QZ92!U=FYI=/@@>G!R
MX79Y('IO8G)A>FET+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B4/AI
M('9Y<')A>F3R;W;A;NT@)7,@9&^Y;&\@:R!C:'EB["X@5&]T;R!J92!H;.&Y
M96[M('-E<G9E<G4B"@HC.B!L:6(O365S<V%G92YP:'`Z-C4S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H
M92!M86EL8F]X+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(E#X:2!V
M>7!R87ID\F]VX6[M('-C:'+A;FMY(&1ON6QO(&L@8VAY8NPN(%1O=&\@:F4@
M:&SAN65N[2!S97)V97)U.B`E<R(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,C$*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL
M8F]X+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(E#X
M:2!V>7!R87ID\F]VX6[M('-C:'+A;FMY(&1ON6QO(&L@8VAY8NPN(%1O=&\@
M:F4@:&SAN65N[2!S97)V97)U(@H*(SH@;&EB+TUE<W-A9V4N<&AP.CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y
M:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)0^&D@:V]P[7)O
M=N%N[2!Z<'+A=GD@>B!<(B5S7"(@9&\@7"(E<UPB(&1ON6QO(&L@8VAY8NPN
M(%1O=&\@:F4@:&SAN65N[2`B"B)S97)V97)U(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C$Y."!L:6(O365S<V%G92YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F
M<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(B(*(E#X:2!M87KA;NT@>G!RX78H>2D@>F4@
M<VQOOFMY(%PB)7-<(B!D;[EL;R!K(&-H>6+L+B!4;W1O(&IE(&ALX;EE;NT@
M<V5R=F5R=2(*"B,Z(&QI8B]-97-S86=E+G!H<#HR-S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A
M9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*
M(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(E#X:2!M87KA;NT@>G!RX79Y('IE
M('-L;[YK>2!<(B5S7"(@9&^Y;&\@:R!C:'EB["X@5&]T;R!J92!H;.&Y96[M
M('-E<G9E<G4B"@HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B
M4/AI(&UA>N%N[2!Z<'+A=B!D;[EL;R!K(&-H>6+L+B!4;W1O(&IE(&ALX;EE
M;NT@<V5R=F5R=3H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@
M</AI(&UA>N%N[2!U9.%L;W-T:3H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!L86EN+G!H<#HU,B!L:6(O34E-12]6:65W97(O96YR:6-H960N<&AP.C,W
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R(")$;[EL;R!K(&-H>6+L('#X:2!Z;V)R87IO
M=N%N[2!TZ71O(.CA<W1I('IP<N%V>2(*"B,Z(&QI8B]-97-S86=E+G!H<#HU
M-#4@;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE
M(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A
M:60B"FUS9W-T<B`B(@HB4/AI(&]Z;F'H;W;A;NT@>G!RX78@=F4@<VQOOF-E
M(%PB)7-<(B!D;[EL;R!K(&-H>6+L+B!4;W1O(&IE(&ALX;EE;NT@<V5R=F5R
M=2(*"B,Z(&9O;&1E<G,N<&AP.C$V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R(")0^&D@
M:6UP;W)T=2`E<R!D;[EL;R!K(&-H>6+L+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(").
M87-T86QA(&-H>6)A('#X:2!I;7!O<G1O=N%N[2!U9.%L;W-T:3H@)7,N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K
M.B`E<RXB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P^&D@:6UP;W)T;W;A;NT@
M^FMO;'4Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T
M<B`B3F%S=&%L82!C:'EB82!P^&D@:6UP;W)T;W;A;NT@=;YI=F%T96QO=GD@
M:6YF;W)M86-E(&\@9G)E92]B=7-Y.B`E<RXB"@HC.B!L:6(O365S<V%G92YP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H
M:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB4/AI
M('#X97-U;G4@>G!RX78@>B!<(B5S7"(@9&\@7"(E<UPB(&1ON6QO(&L@8VAY
M8NPN(%1O=&\@:F4@:&SAN65N[2!S97)V97)U(@H*(SH@8V]M<&]S92YP:'`Z
M,3(T-`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE
M<W-A9V4@87,@82!D<F%F="XB"FUS9W-T<B`B4/AI('5K;.%DX6[M('3I=&\@
M<F]Z97!S86[I('IP<N%V>2!D;[EL;R!K(&-H>6+L+B(*"B,Z(&-O;7!O<V4N
M<&AP.C$P,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R(")0^&D@;V1E
M<^ULX6[M(%9AN>T@>G!RX79Y.B`E<R!D;[EL;R!K(&-H>6+L(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RXB
M"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P^&D@86MT=6%L:7IA8VD@=63A;&]S
M=&DZ("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*;7-G
M:60@(E1H97)E('=A<R!N;R!T97AT(&EN('1H:7,@;65S<V%G92!P87)T(@IM
M<V=S='(@(EIP<N%V82!N96]B<V%H;W9A;&$@=B!TZ71O(.CA<W1I(+[A9&[]
M('1E>'0B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3<*;7-G:60@
M(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N
M(@IM<V=S='(@(E1A=&\@2%1-3"!Z<'+A=F$@;V)S86AU:F4@;V)RX7IK>2XB
M"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3`*;7-G:60@(B(*(E1H
M:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N($)L
M;V-K960@:6UA9V5S(&%P<&5A<B!L:6ME("(*(G1H:7,Z("(*;7-G<W1R("(B
M"B)4871O($A434P@>G!RX79A(&]B<V%H=6IE(&]B<N%Z:WDN($)L;VMO=F%N
MZ2!O8G+A>FMY('9Y<&%D86KM(&[A<VQE9&]V;NPZ(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y
M('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B5&5N=&\@
M=F7X96IN_2!01U`@:VSMZ"!B>6P@</AI;&^^96X@:V4@>G!RX7;L+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#0@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$Q.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30S
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3<*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$W,R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$T
M"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M(")4871O(&%K8V4@;F5N[2!M;[YNX2XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3<Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3D*;7-G
M:60@(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S
M='(@(E1A=&\@86MC92!N96[M(&1O<W5D(&EM<&QE;65N=&]VX6YA+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,30*;7-G:60@(E1H
M:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@8V]N=&EN=64_(@IM<V=S='(@(E1O=&\@;?F^92!C:';M;&D@=')V870N
M($IS=&4@<VD@:FES=.TL(+YE(&-H8V5T92!P;VMR8>AO=F%T/R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@
M;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R(")4
M871O('IP<N%V82!O8G-A:'5J92!S;W5B;W(@>B!-86-I;G1O<VAE+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$P"FUS9VED("(B"B)4:&ES
M(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N
M(&1I9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS9W-T<B`B5&%T
M;R!Z<'+A=F$@;V)S86AU:F4@</CM;&]H=2!D:6=I=.%L;NP@<&]D97!S86YO
M=2!P;VUO8^T@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#$T"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H
M;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G
M<W1R(")4871O('IP<N%V82!O8G-A:'5J92!P^.UL;VAU(+EI9G)O=F%N;W4@
M<&]M;V/M(%,O34E-12XB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN<R!M86EL(&1E
M;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F;W)M870@;V8@
M(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@(B(*(E1A=&\@
M>G!RX79A(&]B<V%H=6IE(&EN9F]R;6%C:2!O('-T879U(&1O<G7H96[M+"!A
M;&4@;>$@;F5Z;N%M_2!F;W)MX70N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G
M<"YP:'`Z,S$U"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O
M<CH@(@IM<V=S='(@(E1A=&\@>G!RX79A(&YE=GEP863A(&IA:V\@<W!RX79N
M["!01U`@N6EF<F]V86[A('IP<N%V82X@0VAY8F$Z("(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(T,"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS
M-3`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D:6YG('1O("(*
M(E)&0R`R,#$U*2XB"FUS9W-T<B`B5&%T;R!Z<'+A=F$@;F5N[2!V92!S<'+A
M=F[I;2!01U`@9F]R;>%T=2`H<&]D;&4@4D9#(#(P,34I+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4:&ES(&UE<W-A9V4@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-12!F
M;W)M870N(@IM<V=S='(@(E1A=&\@>G!RX79A(&YE;NT@=F4@<W!RX79NZ6T@
M4R]-24U%(&9O<FWA='4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,C`U(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C0Q-@IM<V=I9"`B5&AI<R!M
M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"XB"FUS
M9W-T<B`B5&%T;R!Z<'+A=F$@:F4@9&EG:73A;&[L('!O9&5P<V%NX2!P;VUO
M8^T@4$=0+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30S"FUS
M9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V
M:6$@4R]-24U%+B(*;7-G<W1R(")4871O('IP<N%V82!J92!D:6=I=.%L;NP@
M<&]D97!S86[A('!O;6]C[2!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HQ,SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*
M;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O
M34E-12XB"FUS9W-T<B`B5&%T;R!Z<'+A=F$@:F4@N6EF<F]V86[A('!O;6]C
M[2!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`Q(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,0IM<V=I9"`B5&AI<R!M97-S86=E
M(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`B5&%T;R!Z
M<'+A=F$@:F4@N6EF<F]V86[A('!O;6]C[2!01U`B"@HC.B!M97-S86=E+G!H
M<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G92!T;R(*;7-G<W1R(")4871O('IP
M<N%V82!D;R(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@(E1H:7,@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")496YT
M;R!S97)V97(@;F5P;V1P;W)U:F4@<V3M;&5N[2!S;&^^96LN(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,#D*;7-G:60@(E1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB
M"FUS9W-T<B`B5&]T;R!O:VYO(&UU<^T@8OUT('9O;.%N;R!P;W5Z92!Z(&]K
M;F$@=GET=N'X96[M('IP<N%V+B(*"B,Z('1H<F5A9"YP:'`Z,34R"B,L(&9U
M>GIY"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G<W1R("):;V)R87II="(*
M"B,Z('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,@IM
M<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B6F]B<F%Z96[M('!O9&QE('-O
M=79I<VQO<W1I(@H*(SH@;65S<V%G92YP:'`Z,C8T(&UA:6QB;W@N<&AP.C8P
M-B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S
M92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C(V"FUS9VED(")4
M;R(*;7-G<W1R(")+;VUU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ
M.0IM<V=I9"`B5&\@061D<F5S<R(*;7-G<W1R(").82!A9')E<W4B"@HC.B!T
M96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*
M(E1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N
M=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N
M(@IM<V=S='(@(B(*(E!O:W5D('-I('#X96IE=&4@=GEB<F%T(';M8V4@<&]L
M[2P@>FWAZ&MN['1E(&$@9'*^=&4@:VSA=F5S=2!#;VYT<F]L("A00RD@(@HB
M;F5B;R!#;VUM86YD("A-86,I(&$@:VQI:V[L=&4@;F$@<&]L;[YK=2XB"@HC
M.B!L:6(O24U!4"]#;&EE;G0N<&AP.C$S-`IM<V=I9"`B(@HB5&\@=7-E(&$@
M5$Q3(&-O;FYE8W1I;VXL('EO=2!M=7-T(&)E(')U;FYI;F<@82!V97)S:6]N
M(&]F(%!(4"`U+C`N-B!O<B`B"B)H:6=H97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B5&]T86P@
M071T86-H;65N=',@4VEZ93HB"FUS9W-T<B`B0V5L:V]VX2!V96QI:V]S="!P
M^.UL;V@Z(@H*(SH@9F]L9&5R<RYP:'`Z,S@X"FUS9VED(")4<F%S:"!F;VQD
M97(B"FUS9W-T<B`B4VQOOFMA(&MON64B"@HC.B!T96UP;&%T97,O<')E9G,O
M=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM<V=S
M='(@(E-L;[YK82!K;[EE.B(*"B,Z(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C4@
M;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N
M<&AP.C<R"B,Z(&QI8B]1=6]T82]L;V=F:6QE+G!H<#HX."!L:6(O475O=&$O
M8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+VUD865M;VXN<&AP.C0X"FUS9VED
M(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B"FUS9W-T<B`B3F5L>F4@>FII
M<W1I="!K=O-T=2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ.0HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,V"FUS9VED(")5;F%N
M<W=E<F5D(@IM<V=S='(@(DYE>F]D<&]V['IE;NDB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C,U"FUS9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S
M(@IM<V=S='(@(DYE>F]D<&]V['IE;ND@>G!RX79Y(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(D]B
M;F]V:70@<VUA>F%NZ2(*"B,Z(&UA:6QB;W@N<&AP.C4X.2!M86EL8F]X+G!H
M<#HV,#(@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$R"FUS9VED(")5;F1I<V-L
M;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(E5T86IE;NT@</CM:F5M8VDB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#0W"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T
M<B`B3F5O=FSA9.%N_2!K;VUP;VYE;G0@='EP=3H@)7,B"@HC.B!M86EL8F]X
M+G!H<#HU-C4*;7-G:60@(E5N:VYO=VX@1&%T92(*;7-G<W1R(").97INX6WI
M(&1A='5M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YK;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E
M<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8S-0IM<V=I9"`B56YK;F]W;B!-965T
M:6YG(@IM<V=S='(@(DYE>F[A;>$@<V-H^7IE(@H*(SH@;6%I;&)O>"YP:'`Z
M-C$X"FUS9VED(")5;FMN;W=N(%)E8VEP:65N="(*;7-G<W1R(").97INX6W]
M('#X[6IE;6-E(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E5N;&]A9"!087-S<&AR
M87-E(@IM<V=S='(@(E5N;&]A9"!H97-L;R(*"B,Z(&9E=&-H;6%I;'!R969S
M+G!H<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")"97IE:FUE;F[I(@H*
M(SH@;65S<V%G92YP:'`Z-#DY(&UA:6QB;W@N<&AP.C<P."!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C8*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C,R"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-0IM<V=I
M9"`B56YS965N(@IM<V=S='(@(DYE</AEZ'1E;NDB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O
M;2!&;VQD97(H<RDB"FUS9W-T<B`B1&5A:W1I=F]V870@<VQOOFMU*'DI(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@T"FUS9VED(")5
M<&1A=&4@071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R(")!:W1U86QI
M>F]V870@:6YF;W)M86-E(&\@</CM;&]Z92(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,C`*;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U
M<R(*;7-G<W1R(")!:W1U86QI>F]V870@<W1A=B!O9'!O=NUD86KM8^UH;R(*
M"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU."!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED(")5<&QO860B"FUS9W-T
M<B`B4/AE;F]S(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T
M+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U;'0@5F%L=64B"FUS9W-T<B`B4&]U
MONUT(&EM<&QI8VET;NT@:&]D;F]T=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-38*;7-G:60@(E5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS
M/R(*;7-G<W1R(")0;W6^[70@24U!4"!A:W1I=F%C:2!S;&^^96L_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S-0HC+"!F=7IZ>0IM<V=I9"`B57-E
M(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*;7-G<W1R(")6:7)T=>%L;NT@<VQO
MOFMY(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$T,@IM<V=I9"`B57-E
M<B(*;7-G<W1R(")5OFEV871E;"(*"B,Z(&%C;"YP:'`Z.#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL
M>2!G:79E;B!T:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(E6^:79A=&5L("<E<R<@^G-P[+EN["!P;W-K>71N
M=6P@>FWM;NQNX2!P<N%V82!P<F\@<VQOOFMU("<E<R<N(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-S<*;7-G:60@(E5S97)N86UE(@IM<V=S
M='(@(E6^:79A=&5L<VOI(&IMZ6YO(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B5;YI
M=F%T96QS:^D@:FWI;F\Z(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S<*;7-G:60@(E9I97<B"FUS9W-T<B`B6F]B<F%Z:70B"@HC.B!L
M:6(O34E-12]6:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE
M9BYP:'`Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`B>F]B<F%Z:70@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B6F]B<F%Z:70@)7,@
M=F7X96IN_2!K;.WH(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q
M-@IM<V=I9"`B5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD
M;W<B"FUS9W-T<B`B6F]B<F%Z96[M($A434P@;V)S86AU('8@;F]VZ6T@;VMN
M["(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X"B,L(&9U
M>GIY"FUS9VED(")6:65W($UE<W-A9V5S(@IM<V=S='(@(DYO=ND@>G!RX79Y
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N86P@4')I=F%T92!+
M97DB"FUS9W-T<B`B6F]B<F%Z:70@;W-O8F[M('!R:7;A=&[M(&ML[>@B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW,@IM<V=I9"`B5FEE=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(EIO8G)A>FET(&]S;V)N[2!V9?AE:F[](&ML[>@B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3@*;7-G:60@(E9I
M97<@5&AR96%D(@IM<V=S='(@(EIO8G)A>FET('-O=79I<VQO<W0B"@HC.B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,38U"FUS9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R
M("):;V)R87II="!M:6YI871U<GDB"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C0Q.`IM<V=I9"`B5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W(@IM<V=S='(@(EIO8G)A>F5N[2!P^.UL;VAY('8@;F]VZ6T@
M;VMN["(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0IM<V=I
M9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@
M(EIO8G)A>F5N[2!O8G-A:'4@=B!N;W;I;2!O:V[L(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R
M("):;V)R87II="!U9.%L;W-T(@H*(SH@9F]L9&5R<RYP:'`Z,S@P(&UA:6QB
M;W@N<&AP.C4S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE<W-A9V5S
M(&EN("5S(@IM<V=S='(@(EIO8G)A>FET('IP<N%V>2!V("5S(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHR,PIM<V=I9"`B
M5FEE=R!O<B!M86EL8F]X('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S
M='(@(EIO8G)A>F5N[2!S8VARX6YE:R!P;R!P^&EH;.&Y96[M(&1O('-Y<W3I
M;74Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,`IM<V=I9"`B
M5FEE=R!T87-K(@IM<V=S='(@(EIO8G)A>FET(/IK;VPB"@HC.B!L:6(O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3`Q"FUS9VED(")6:65W('1H92!);6%G97,B
M"FUS9W-T<B`B6F]B<F%Z:70@;V)RX7IK>2(*"B,Z('-E87)C:"YP:'`Z,C8S
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<(B!C
M<F5A=&5D('-U8V-E<V9U;&QY+B(*;7-G<W1R(")6:7)T=>%L;NT@<VQOOFMA
M(%PB)7-<(B!B>6QA(/IS<.RY;NP@>F%L;[YE;F$N(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E92YP:'`Z,3,X(&QI
M8B])34%0+U1R964N<&AP.C$U,0HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ-3,@
M;&EB+TE-05`O5')E92YP:'`Z,34W(&QI8B])34%0+U1R964N<&AP.C$U.`HC
M.B!L:6(O24U!4"]4<F5E+G!H<#HS-CD@;&EB+TE-05`O5')E92YP:'`Z,SDS
M(&QI8B])34%0+U1R964N<&AP.C0S,PIM<V=I9"`B5FER='5A;"!&;VQD97)S
M(@IM<V=S='(@(E9I<G1UX6QN[2!S;&^^:WDB"@HC.B!S96%R8V@N<&AP.C(T
M-0IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB"FUS
M9W-T<B`B5FER='7A;&[M('-L;[YK>2!V>;YA9'5J[2!O>FYAZ&5N[2XB"@HC
M.B!L:6(O5D9O;&1E<BYP:'`Z,3<U(&QI8B]61F]L9&5R+G!H<#HQ.#`*;7-G
M:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M-#$V"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L($E.0D]8($9O;&1E<B(*;7-G
M<W1R(")6:7)T=>%L;NT@<VQOOFMY(@H*(SH@;6%I;&)O>"YP:'`Z-#4R(&QI
M8B]61F]L9&5R+G!H<#HQ,30@;&EB+U9&;VQD97(N<&AP.C$Q.0HC+"!F=7IZ
M>0IM<V=I9"`B5FER='5A;"!4<F%S:"(*;7-G<W1R(")6:7)T=>%L;NT@<VQO
MOFMY(@H*(SH@9F]L9&5R<RYP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")6:7)T
M=6%L(%1R87-H($9O;&1E<B(*;7-G<W1R(")6:7)T=>%L;NT@<VQOOFMY(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,S,*;7-G:60@(E9I<G1U
M86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@(D]Z;F'H96[M('9I<G1UX6QN[2!S
M;&^^:WDB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W-`IM<V=I
M9"`B5V%R;FEN9R(*;7-G<W1R(")5<&]Z;W)N[&[M(@H*(SH@;&]G:6XN<&AP
M.C$S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(E;M=&5J=&4@=B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M,3D*(RP@9G5Z>GD*;7-G:60@(B(*(E=H870@<VAO=6QD('=E(&1O('=I=&@@
M<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G<W1R(")3;6%Z870@>G!RX79Y
M('!O=.D@8V\@8GEL>2!N86ALX;EE;GD@:F%K;R!N96-H=.QNZ2!Z<'+A=GD@
M*'-P86TI/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,C<*;7-G:60@
M(B(*(E=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R
M(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D
M96QE=&5D/R(*;7-G<W1R("(B"B)0^&D@;6%ZX6[M('IP<N%V('#X97-U;F]U
M="!Z<'+A=GD@9&\@<VQOOFMY(&MON64@;>US=&\@;WIN8>AE;NT@:F%K;R`B
M"B)V>6UA>F%NZ3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS
M9VED(")7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@<&%G92!D
M;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\B"FUS9W-T<B`B3F$@:W1E<ND@<W1R
MX6YC92!Z8>CM="!P^&D@>F]B<F%Z96[M(&YO=ND@<V-H<N%N:WD_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@
M<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_(@IM
M<V=S='(@(E5K;.%D870@=&%KZ2!P^.UL;VAY('#X:2!U:VSA9.%N[2!O9&5S
M;&%NZ2!P;[ET>3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(V"FUS
M9VED("(B"B)7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S
M<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD('1O("(*(G5N<75A
M;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@7")`
M7"(I/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3D*;7-G:60@(E=H:71E;&ES="(*;7-G<W1R(")"[6SA(&QI<W1I;F$B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#$@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDW.`IM<V=I9"`B665S(@IM<V=S='(@(D%N;R(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-3@*
M;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T:&4@
M9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(E-N8;[M=&4@<V4@<W3A
M:&YO=70@>G!RX79Y('H@;N%S;&5D=6KM8^UC:"#ZZ'3Y.B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P"B,L(&9U>GIY
M"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M
M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H
M<RDN(@IM<V=S='(@(E!O:V]UN>UT92!S92!S;6%Z870@;N%S;&5D=6KM8^T@
M<VQOOFMY.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER
M;2YH=&UL.CD*(RP@9G5Z>GD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T
M;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(E!O
M:V]UN>UT92!S92!S;6%Z870@;N%S;&5D=6KM8^T@<VQOOFMY.B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B66]U(&%R92!C;W!Y
M:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(@IM<V=S='(@(DMO<.UR;W;A
M;NTO</AE<V]U=N%N[2!D;R!N;W;I('-L;[YK>2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$P,@IM<V=I9"`B66]U(&%R92!C<F5A
M=&EN9R!A('-U8BUF;VQD97(@=&\@(@IM<V=S='(@(E9Y=';A^.UT92!P;V1S
M;&^^:W4@=79N:73X("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3`T"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L
M(&9O;&1E<BXB"FUS9W-T<B`B5GET=N'X[71E('-L;[YK=2!N82!N96IV>;FY
M[2#Z<F]V;FDN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(P"B,L(&9U>GIY"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!F;VQD97)S+B(*
M;7-G<W1R(")6>71VX?CM=&4@<VQOOFMU(&YA(&YE:G9YN;GM(/IR;W9N:2XB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&9O
M;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD
M97(Z("(*;7-G<W1R(")0^&5J;65N;W;A=N%T92!S;&^^:W4Z("(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(MIS<.RY;NP@:G-T92!D96%K=&EV;W9A;&D@<VQOOFMU(%PB)7-<(B(*"B,Z
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E
M:&]L9&5R<R!I;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*
M(F-U<G)E;G0@;65S<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G
M<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O
M('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@
M;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*(DYE<V]U:&QA
M<VEL:2!J<W1E('H@=&5R;>UN>2!P;W6^:73M('1O:&\@=&\@<WES=.EM=2P@
M<')O=&\@<V4@;F5M^;YE=&4@(@HB</AI:&SA<VET+B(*"B,Z('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-CD*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M
M:7-S:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS9W-T
M<B`B3F5MX71E(&]P<N%V;NQN[2!P<F\@>FWL;G4@</CM<W1U<&]V_6-H('!R
MX78@<')O('1U=&\@<VQOOFMU(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G
M92!O;B`E)7,@=&\@=&AE(&9O;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS
M9W-T<B`B5&%T;R!Z<'+A=F$@8GEL82!P^&5P;W-LX6YA('8@)25S(&[A<VQE
M9'5J[6/M;2!P^.UJ96UC^6TZ("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%L97)T+FEN8SHS"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!H879E("5S
M(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B3>%T92`E<R!N;W;]8V@@>G!RX78N
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO
M=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(DWA=&4@,2!N;W9O=2!Z
M<'+A=G4N(@H*(SH@8V]M<&]S92YP:'`Z-#DT"B,L(&9U>GIY"FUS9VED(")9
M;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N(@IM<V=S='(@
M(DWA=&4@,2!N;W9O=2!Z<'+A=G4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M871T86-H;65N=',N:G,Z,3$U"FUS9VED("(B"B)9;W4@:&%V92!A="!L96%S
M="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO=2!D:61N)W0@=7!L
M;V%D('EE="X@07)E("(*(GEO=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI
M<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N=',_(@IM<V=S='(@
M(B(*(DWA=&4@86QE<W!O\B!J961N=2!P^.UL;VAU+"!K=&5R;W4@:G-T92!D
M;W-U9"!N97#X96YE<VQI+B!*<W1E('-I(&II<W3M+""^92`B"B)C:&-E=&4@
M<&]S;&%T('1U=&\@>G!RX79U(&)E>B!P^.UL;V@_(@H*(SH@;&EB+TE-4"YP
M:'`Z,3`W-`IM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO
M=VEN9R!F;VQD97(Z(@IM<V=S='(@(DYO=N$@<&^Y=&$@=B!NX7-L961U:NUC
M[2!S;&^^8V4Z(@H*(SH@;&EB+TE-4"YP:'`Z,3`W.0IM<V=I9"`B66]U(&AA
M=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.B(*;7-G<W1R
M(").;W;A('!ON71A('8@;N%S;&5D=6KM8^UC:"!S;&^^:^%C:#HB"@HC.B!C
M;VUP;W-E+G!H<#HQ-3,*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE87-T
M(&]N92!R96-I<&EE;G0N(@IM<V=S='(@(DUU<^UT92!Z861A="!A;&5S<&_R
M(&IE9&YO:&\@</CM:F5M8V4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,S`R"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S
M92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A
M9V4B"FUS9W-T<B`B(@HB0VAC971E+6QI('#X9>CM<W0@='5T;R!Z<'+A=G4L
M(&UU<^UT92!Z861A="!H97-L;R!68;EE:&\@<')I=N%T;NUH;R!01U`@(@HB
M:VSMZ&4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#D*;7-G
M:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*
M;7-G<W1R("(B"B)#:&-E=&4M;&D@</AEZ.US="!T=71O('IP<N%V=2P@;75S
M[71E('IA9&%T(&AE<VQO(%9AN65H;R!P<FEVX71N[6AO(%,O34E-12`B"B)K
M;.WH92XB"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHV
M-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+B(*;7-G
M<W1R(")-=7/M=&4@;F5J<')V92!V>6)R870@8^UL;W9O=2!S8VARX6YK=2XB
M"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#4*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E;&5T960N(@IM<V=S='(@(DUU<^UT
M92!V>6)R870@^NAE="P@:W1E<OT@8VAC971E('-M87IA="XB"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C@Q"FUS9VED(")9;W4@;75S
M="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`B375S[71E(&YE
M:G!R=F4@=GEB<F%T(&5M86EL;W9O=2!A9')E<W4N(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T
M(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R(")-=7/M=&4@;F5J9/CM=F4@
M=GEB<F%T(&%L97-P;_(@:F5D;G4@>G!RX79U+B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHQ,PIM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A(')E8VEP:65N="XB"FUS9W-T<B`B375S[71E('IA9&%T('#X[6IE;6-E
M+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C(Y"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&%T(&QE87-T(&]N92!F:6QE('1O(&%T
M=&%C:"XB"FUS9W-T<B`B375S[71E('IA9&%T(&%L97-P;_(@:F5D96X@<V]U
M8F]R('#X[6QO:'DN(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@;F5E9"!T
M;R!H879E(%PB)7-<(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T
M:6]N<RXB"FUS9W-T<B`B4&]T^&5B=6IE=&4@86MT:79O=F%T("<E<R<@=F4@
M5F&Y:6-H(&UOOFYO<W1E8V@@<')O(&]P97)A8V4@^F1ROF)Y+B(*"B,Z(&QI
M8B]-86EL;&]G+G!H<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E
M9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T<B`B
M5&%T;R!Z<'+A=F$@8GEL82!P^&5S;>QR;W;A;F$@;F$@)7,@=B`E)7,N(@H*
M(SH@;&EB+TUA:6QL;V<N<&AP.C$T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A9V4@;VX@)7,N(@IM<V=S='(@(DYA
M('1U=&\@>G!RX79U(&)Y;&\@;V1P;W;L>F5N;R!V("5S+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N
M;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60B"FUS9W-T<B`B4VQOOFMA(%PB)7-<(B!N96)Y;&$@86MT:79O
M=N%N82X@5&]T;R!J92!H;.&Y96[M('-E<G9E<G4B"@HC.B!L:6(O1F]L9&5R
M+G!H<#HU-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N
M<W5B<V-R:6)E9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V
M97(@<V%I9"(*;7-G<W1R(")3;&^^:V$@7"(E<UPB(&YE8GEL82!D96%K=&EV
M;W;A;F$N(%1O=&\@:F4@:&SAN65N[2!S97)V97)U(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E
M<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R("+:<W#LN6[L
M(&IS=&4@86MT:79O=F%L:2!S;&^^:W4@7"(E<UPB(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-38R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E
M<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`BVG-P
M[+EN["!J<W1E(&1E86MT:79O=F%L:2!S;&^^:W4@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B5F&Y92!J;>EN;R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU,`IM
M<V=I9"`B66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*;7-G<W1R(")6
M8;EE(%!'4"!V9?AE:F[I+W!R:7;A=&[M(&ML[>AE(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*
M;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`B5N&Y('!R:7;A=&[M
M(&ML[>@B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW,0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y(@IM
M<V=S='(@(E;AN2!V9?AE:F[](&ML[>@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,38U"B,L(&9U>GIY"FUS9VED(")9;W5R(%)E<&QY+71O.B!A9&1R
M97-S.B`\96T^*&]P=&EO;F%L*3PO96T^(@IM<V=S='(@(E9AN64@861R97-A
M('!R;R!/9'!O=NSO+6MO;74Z(#QI/BAN97!O=FEN;NDI/"]I/B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-#D*;7-G:60@(EEO=7(@4R]-24U%
M(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<R(*;7-G<W1R(")68;EE(%,O
M34E-12!V9?AE:F[I+W!R:7;A=&[M(&-E<G1I9FEKX71Y(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,38*;7-G:60@(EEO
M=7(@86-C;W5N=',Z(@IM<V=S='(@(E9AN64@^NAT>3HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3<S"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%L
M:6%S(&%D9')E<W-E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R
M97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B5F&Y92!A;&EA<V]V
MZ2!A9')E<WDZ(#QI/BAN97!O=FEN;NDL('9L;[YI="!J961N=2!A9')E<W4@
M;F$@^.%D96LI/"]I/B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.CDR"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI
M;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(E;AN2!P
M<F]H;.V^9>@@;F5P;V1P;W)U:F4@>F]B<F%Z96[M('1O:&]T;R!T>7!U(&]B
M<N%Z:W4@=B!T[&QE('IP<N%V>2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN
M9R!M97-S86=E<SHB"FUS9W-T<B`B5F&Y92!I;7!L:6-I=&[M('IN86MO=N$@
M<V%D82!P<F\@;V1E<^ULX6[M('IP<N%V.B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC
M<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@
M(E9AN64@:6UP;&EC:71N[2!M971O9&$@N6EF<F]VX6[M('!R;R!O9&5S[6SA
M;NT@>G!RX78Z(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*
M;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E
M9"XB"FUS9W-T<B`B5F&Y92!Z<'+A=F$@8GEL82#Z<W#LN6[L(&1O<G7H96YA
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@(EEO=7(@
M<VEG;F%T=7)E.B(*;7-G<W1R(")68;EE('-I9VYA='5R83HB"@HC.B!M97-S
M86=E+G!H<#HR.#@@8V]M<&]S92YP:'`Z,3(X-"!M86EL8F]X+G!H<#HU-#D@
M;&EB+T-O;7!O<V4N<&AP.C@Q.`IM<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S
M='(@(ENNX61N_2!P^&5D;>QT72(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(P-0IM<V=I9"`B7T)C8R(*;7-G<W1R(")?4VMR>73A(&MO
M<&EE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED(")?
M0FQA8VML:7-T(@IM<V=S='(@(LAE7W)NX2!L:7-T:6YA(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,34T"FUS9VED(")?0V,B"FUS9W-T
M<B`B7TMO<&EE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B7T1E;&5T
M92(*;7-G<W1R(")3;6%Z85]T(@H*(SH@;&EB+TE-4"YP:'`Z.3<Y"FUS9VED
M(")?1F]L9&5R<R(*;7-G<W1R(")?4VQOOFMY(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z.#$*;7-G:60@(E])9&5N=&ET>2(*;7-G<W1R
M(")?261E;G1I=&$B"@HC.B!L:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O
M>"(*;7-G<W1R(")?4&^Y=&$B"@HC.B!L:6(O24U0+G!H<#HQ,#(P"FUS9VED
M(")?3&]G(&]U="(*;7-G<W1R(")?3V1H;.&Y96[M(@H*(SH@;65S<V%G92YP
M:'`Z,S@T"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T<B`B7UID<F]J
M;W;](&OS9"!Z<'+A=GDB"@HC.B!L:6(O24U0+G!H<#HY-S8*(RP@9G5Z>GD*
M;7-G:60@(E].97<@365S<V%G92(*;7-G<W1R(").;W;I('IP<N%V>2(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I
M9"`B7U!R:6YT(@IM<V=S='(@(E]4:7-K(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,C<R('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C(X.0IM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(E]$^6QEOFET;W-T
M(@H*(SH@;6%I;&)O>"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(E]2
M969R97-H("5S(@IM<V=S='(@(D]?8FYO=FET("5S(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@(E]297!L>2(*
M;7-G<W1R(")?3V1P;W;L9.QT(@H*(SH@;&EB+TE-4"YP:'`Z.3@Q"FUS9VED
M(")?4V5A<F-H(@IM<V=S='(@(E9Y7VAL961A="(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C0S,0IM<V=I9"`B7U-E;F0@365S<V%G92(*;7-G<W1R(")?6F%S
M;&%T('IP<N%V=2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,S(*;7-G:60@(E]4:')E860B"FUS9W-T<B`B7U-O=79I<VQO
M<W0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*;7-G
M:60@(E]4;R(*;7-G<W1R(")?2V]M=2(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C$S"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`B7T]B
M;F]V:70@<VUA>F%NZ2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ.`IM<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S='(@(E]:
M;V)R87II="!S;W5V:7-L;W-T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$Y"FUS9VED(")?5VAI=&5L:7-T(@IM<V=S='(@(D+M;.$@7VQI<W1I
M;F$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<V"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#0P"FUS
M9VED(")A='1A8VAM96YT(@IM<V=S='(@(G#X[6QO:&$B"@HC.B!V:65W+G!H
M<#HY.0IM<V=I9"`B871T86-H;65N=',N>FEP(@IM<V=S='(@(G!R:6QO:'DN
M>FEP(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS
M9VED(")B>71E<R(*;7-G<W1R(")B>73Y(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C(P,`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<R"FUS9VED(")C86YN;W0@;W!E
M;B!I;G!U="(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38T"FUS
M9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C(R,`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DV"FUS9VED(")C
M<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HQ-C@*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C0*;7-G:60@(F5N=')Y
M(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B9G)O;2(*;7-G<W1R(")O9"(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ.#`*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#0*;7-G:60@(FEN
M<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3@X"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!S;6EM92YP:'`Z,CD@<&=P+G!H<#HV.0IM<V=I9"`B:V5Y(@IM
M<V=S='(@(FML[>@B"@HC.B!F;VQD97)S+G!H<#HQ-C$*;7-G:60@(FUA:6QB
M;W@@9FEL92(*;7-G<W1R(")S;W5B;W(@<V-H<N%N:WDB"@HC.B!C;VUP;W-E
M+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*;7-G:60@(FYA;64B"FUS
M9W-T<B`B:FWI;F\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`BON%D;OTB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*;7-G<W1R
M(")N96)O(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q-@IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q
M,@IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#0*;7-G:60@(G-E<G9I8V4@=6YA=F%I
M;&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R(")C:'EB
M82!V('!R879O<&ES=2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@(F-H>6)Y
M('8@<')A=F]P:7-U(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y,@HC+"!F=7IZ
M>0IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(F-H>6)A('8@<')A=F]P
M:7-U(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P.`IM<V=I9"`B=&5M<&]R87)Y
M(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z-3$*;7-G
M:60@(GEO=7(@8FQA8VML:7-T(@IM<V=S='(@(E9AN64@Z&5R;N$@;&ES=&EN
M82(*"B,Z(&QI8B]&:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H:71E;&ES
M="(*;7-G<W1R(")68;EE(&+M;.$@;&ES=&EN82(*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+W!T
M7T)2+G!O````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#0R-S<Q-@`Q,#0Q-S,V,C<V-@`P,3<R,3<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!T<F%N<VQA=&EO;B!O9B!I
M;7`N<&]T('1O($)R87II;&EA;B!0;W)T=6=U97-E"B,@0V]P>7)I9VAT("A#
M*2!914%2($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T
M960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@26UP('!A8VMA9V4N
M"B,*(R!&86)I;R!';VUE<R`\9FQG;VUS0'5O;"YC;VTN8G(^+"`R,#`V+@IM
M<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@26UP7&XB
M"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN
M(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN
M(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-2`Q,SHP,2TP,C`P7&XB
M"B),87-T+51R86YS;&%T;W(Z($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O
M;2YB<CY<;B(*(DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T=6=U97-E
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB
M6"U'96YE<F%T;W(Z($M"86)E;"`Q+C,N,5QN(@HB4&QU<F%L+49O<FUS.B`@
M;G!L=7)A;',],CL@<&QU<F%L/2AN(#X@,2D[7&XB"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z-#(Y"FUS9VED("(@("`@("!#8SH@(@IM<V=S='(@(B`@("`@($-C
M.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#(V"FUS9VED("(@("`@("!4;SH@
M(@IM<V=S='(@(B`@("`@(%!A<F$Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT
M,30*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B("`@($1A=&$Z("(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HT,3<*;7-G:60@(B`@("!&<F]M.B`B"FUS9W-T
M<B`B("`@($1E.B`B"@HC.B!M86EL8F]X+G!H<#HT,#8@=&5M<&QA=&5S+V9O
M;&1E<G,O:&5A9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S
M<VME>2`E<RDB"FUS9W-T<B`B("A496-L82!D92!!=&%L:&\@)7,I(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0R,PIM<V=I9"`B(%-U8FIE8W0Z("(*;7-G<W1R
M("(@07-S=6YT;SH@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C<P"FUS9VED("(@:6X@(@IM<V=S='(@(B!E;2`B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM
M<V=S='(@(B,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G
M<W1R("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@H*(SH@=&AR96%D+G!H
M<#HQ-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@365S<V%G97,B"FUS9W-T
M<B`B)60@365N<V%G96YS(@H*(SH@;6%I;&)O>"YP:'`Z,3<T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("(E9"!M96YS86=E;2AN<RD@9F]I*')A;2D@97AC;'7M9&$H<RDN
M(@H*(SH@;&EB+U-P86TN<&AP.C$Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@
M=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB)60@
M;65N<V%G96YS(&9O<F%M(')E<&]R=&%D87,@8V]M;R!NXV\@<W!A;2!A;R!S
M974@861M:6YI<W1R861O<B!D92!S:7-T96UA+B(*"B,Z(&QI8B]3<&%M+G!H
M<#HQ-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(E9"!M96YS86=E
M;G,@9F]R86T@<F5P;W)T861A<R!C;VUO(&[C;R!S<&%M+B(*"B,Z(&QI8B]3
M<&%M+G!H<#HQ.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@
M:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB)60@;65N<V%G96YS(&9O<F%M(')E
M<&]R=&%D87,@8V]M;R!S<&%M(&%O('-E=2!A9&UI;FES=')A9&]R(&1E('-I
M<W1E;6$N(@H*(SH@;&EB+U-P86TN<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2XB
M"FUS9W-T<B`B)60@;65N<V%G96YS(&9O<F%M(')E<&]R=&%D87,@8V]M;R!S
M<&%M+B(*"B,Z(&UA:6QB;W@N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("(E9"#@("5D(&1E
M("5D($UE;G-A9V5N<R(*"B,Z(&UA:6QB;W@N<&AP.C8R-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E
M<R!F;VQD97(@=V%S(&YO="!R96YA;65D+B(*;7-G<W1R("(E<R!JX2!E>&ES
M=&4N(%-U82!P87-T82`E<R!NXV\@9F]I(')E;F]M96%D82XB"@HC.B!L:6(O
M365S<V%G92YP:'`Z-C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B5S
M(&[C;R!P87)E8V4@<V5R('5M82!P87-T82!VX6QI9&$N(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0R
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9O;&1E<B!B96EN9R!R96YA;65D
M(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N(@IM<V=S='(@(D$@<&%S=&$@
M)7,@97-TX2!S96YD;R!R96YO;65A9&$@;F\@:6[M8VEO(&1O(&WJ<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&AA<R!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@9F]I(&%C96ET
M;RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@7"(E<UPB+B(*;7-G<W1R
M("(E<R!C86YC96QO=2!<(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@9&5C;&EN
M960N(@IM<V=S='(@(B5S(')E8W5S;W4N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P
M;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R("(E<R!R97-P
M;VYD974@82!U;6$@<F5Q=6ES:>?C;R!D92!I;F9O<FUAY^-O(&QI=G)E+V]C
M=7!A9&\N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A
M=&EO;B!T;R!<(B5S7"(N(@IM<V=S='(@(B5S(')E<W!O;F1E=2!A;R!C;VYV
M:71E('!A<F$@7"(E<UPB+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@96YV:6]U(&$@=F]C
MZB!U;6$@:6YF;W)M8>?C;R!L:79R92]O8W5P861O+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S('1E;G1A=&EV96QY(&%C8V5P=&5D+B(*;7-G<W1R("(E<R!A8V5I=&]U
M('!R;W9I<V]R:6%M96YT92XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#@X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(E<R!R97%U:7-I=&]U
M('-U82!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4X,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R
M97%U97-T<R!Y;W5R('!R97-E;F-E(&%T(%PB)7-<(BXB"FUS9W-T<B`B)7,@
M<V]L:6-I=&]U('-U82!P<F5S96[G82!E;2!<(B5S7"(N(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C0T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B)7,@9F]I(&%D
M:6-I;VYA9&\@8V]M('-U8V5S<V\@96T@)7,N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H
M97,@=&\@86UM96YD(%PB)7-<(BXB"FUS9W-T<B`B)7,@9&5S96IA(&-O<G)I
M9VER(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO=2!A
M=V%R92!O9B!<(B5S7"(N(@IM<V=S='(@(B5S(&1E<V5J82!I;F9O<FUA<B!V
M;V/J('-O8G)E(%PB)7-<(BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3DV"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E
M:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@7"(E<UPB+B(*;7-G
M<W1R("(E<R!D97-E:F$@<F5C96)E<B!A(/IL=&EM82!I;F9O<FUAY^-O('-O
M8G)E(%PB)7-<(BXB"@HC.B!M97-S86=E+G!H<#HR.34@;65S<V%G92YP:'`Z
M,S`P"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@
M)7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?=&]P+FEN8SHQ,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE
M9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P.V1E)FYB<W`[)60I(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B*$%P
M<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*
M;7-G<W1R("(H07!L:6-A<B!E<W1A<R!A;'1E<F'G]65S(&4@:7(@<&%R82!A
M('!R\WAI;6$@=&5L82XI(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H86YG97,@86YD(')E
M='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G<W1R("(H1&5S8V%R
M=&%R('1O9&%S(&%L=&5R8>?U97,@92!R971O<FYA<B#@('1E;&$@9&4@8V]M
M<&]S:>?C;RXI(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C$V"FUS9VED("(H2%1-3"DB"FUS9W-T<B`B*$A434PI(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X
M="DB"FUS9W-T<B`B*%1E>'1O(%!U<F\I(@H*(SH@<W!E;&QI;F<N<&AP.C(W
M.0IM<V=I9"`B(@HB*%)E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T
M97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@("(*(D-H
M86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI
M960N*2(*;7-G<W1R("(B"B(H4F5T;W)N87(@X"!T96QA(&1E(&-O;7!O<VGG
MXV\@87#S<R!A<&QI8V%R('1O9&%S(&%L=&5R8>?U97,@<F5A;&EZ861A<R!A
M=.D@(@HB86=O<F$N("!!;'1E<F'G]65S(&YA('1E;&$@871U86P@3L-/('-E
M<N-O(&%P;&EC861A<RXI(@H*(SH@<W!E;&QI;F<N<&AP.C(W-@IM<V=I9"`B
M(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M
M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E
M96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BA%;G9I92!A
M(&UE;G-A9V5M(&%P\W,@87!L:6-A<B!T;V1A<R!A<R!A;'1E<F'G]65S(')E
M86QI>F%D87,@873I(&%G;W)A+B`@(@HB06QT97)AY_5E<R!N82!T96QA(&%T
M=6%L($[#3R!S97+C;R!A<&QI8V%D87,N*2(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D9"!T:&5S92!B>2!C
M;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@061I8VEO;F4@97-T97,@8VQI8V%N
M9&\@96T@3TL@*B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C`V"FUS9VED("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*
M;7-G<W1R("(J(%!O<B!F879O<B!S96QE8VEO;F4@;RAS*2!E;F1E<F7G;RAS
M*2`J(@H*(SH@;6%I;&)O>"YP:'`Z,3<R"FUS9VED("(Q(&UE<W-A9V4@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B,2!M96YS86=E;2!F;VD@97AC;'7M
M9&$N(@H*(SH@;&EB+U-P86TN<&AP.C$Y.`IM<V=I9"`B,2!M97-S86=E(&AA
M<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(C$@;65N<V%G96T@9F]I(')E<&]R
M=&%D82!C;VUO(&[C;R!S<&%M(&%O('-E=2!A9&UI;FES=')A9&]R(&1E('-I
M<W1E;6$N(@H*(SH@;&EB+U-P86TN<&AP.C$W.`IM<V=I9"`B,2!M97-S86=E
M(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(Q(&UE
M;G-A9V5M(&9O:2!R97!O<G1A9&$@8V]M;R!NXV\@<W!A;2XB"@HC.B!L:6(O
M4W!A;2YP:'`Z,3DP"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(Q(&UE;G-A9V5M(&9O:2!R97!O<G1A9&$@8V]M;R!S<&%M(&%O('-E
M=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6$N(@H*(SH@;&EB+U-P86TN<&AP
M.C$W,`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P
M86TN(@IM<V=S='(@(C$@;65N<V%G96T@9F]I(')E<&]R=&%D82!C;VUO('-P
M86TN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P.`IM<V=I9"`B,3`P
M(&-H87)A8W1E<G,B"FUS9W-T<B`B,3`P(&-A<F%C=&5R97,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS9VED("(Q,#`P(&-H87)A8W1E<G,B
M"FUS9W-T<B`B,3`P,"!C87)A8W1E<F5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@P.0IM<V=I9"`B,C4P(&-H87)A8W1E<G,B"FUS9W-T<B`B,C4P
M(&-A<F%C=&5R97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$P"FUS
M9VED("(U,#`@8VAA<F%C=&5R<R(*;7-G<W1R("(U,#`@8V%R86-T97)E<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D
M('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B56T@:6UA9V5M(&=R86YD92!D
M92!N;VUE("5S(&5S=.$@86YE>&%D82!A(&5S=&$@;65N<V%G96TN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*
M(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E
M='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G
M<W1R("(B"B)5;6$@;65N<V%G96T@<75E('9O8^H@96YV:6]U(')E<W5L=&]U
M(&5M('5M82!N;W1I9FEC8>?C;R!D92!R971O<FYO(&1O("(*(F1E<W1I;F%T
MX7)I;RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0IM<V=I
M9"`B04Y$(@IM<V=S='(@(D4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3@R"FUS9VED(")!8V-E<'0@86YD(&%D9"!T;R!M>2!C86QE;F1A<B(*
M;7-G<W1R(")!8V5I=&%R(&4@861I8VEO;F%R(&$@;6EN:&$@86=E;F1A(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-0IM<V=I9"`B06-C97!T
M(')E<75E<W0B"FUS9W-T<B`B06-E:71A<B!S;VQI8VET8>?C;R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-#8*;7-G:60@(D%C8V5P=&5D(@IM
M<V=S='(@(D%C96ET82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-3@*;7-G:60@(D%C8V5P=&5D.B`B"FUS9W-T<B`B06-E:71A.B`B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-PIM<V=I9"`B06-C;W5N
M="=S(&YA;64Z(@IM<V=S='(@(DYO;64@9&$@8V]N=&$Z(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4R,B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S(U"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(D'G]65S(@H*(SH@;&EB
M+TU)344O2&5A9&5R<RYP:'`Z,3DR(&QI8B]-24U%+TAE861E<G,N<&AP.C$Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,@=&\@;7D@061D<F5S<R!"
M;V]K(@IM<V=S='(@(D%D:6-I;VYA<B`E<R!A;R!#873A;&]G;R!D92!%;F1E
M<F7G;W,B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M,#,*;7-G:60@(D%D9"!S;W5R8V4B"FUS9W-T<B`B061I8VEO;F%R(&9O;G1E
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W,PIM<V=I9"`B061D
M('1H:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B061I8VEO;F%R(&ES=&\@
M82!M:6YH82!A9V5N9&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3@S"FUS9VED(")!9&0@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B061I8VEO
M;F%R(&$@;6EN:&$@86=E;F1A(@H*(SH@8V]M<&]S92YP:'`Z-3DP"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT
M+B(*;7-G<W1R(")<(B5S7"(@861I8VEO;F%D;R!C;VUO('5M(&%N97AO+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3@*;7-G:60@(B(*(D%D9&ET
M:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@/&5M/BAO
M<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@;&EN92D\
M+V5M/B(*;7-G<W1R("(B"B)#86)EYV%L:&]S(&%D:6-I;VYA:7,@<&%R82!M
M;W-T<F%R(&%O('9I<W5A;&EZ87(Z(#QE;3XH;W!C:6]N86PL(&1I9VET92!C
M861A("(*(F-A8F7G86QH;R!E;2!U;6$@;F]V82!L:6YH82D\+V5M/B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B26YF;W)M8>?U97,@861I8VEO;F%I<R!P;V1E
M;2!S97(@=FES=6%L:7IA9&%S("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C8R"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T
M:6]N(&1E=&%I;',B"FUS9W-T<B`B1&5T86QH97,@861I8VEO;F%I<R!D82!I
M;F9O<FUAY^-O(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3,*
M;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(@IM<V=S='(@(D1E
M=&%L:&5S(&%D:6-I;VYA:7,@9&$@;65N<V%G96TB"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I
M=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G
M<W1R(")$971A;&AE<R!A9&EC:6]N86ES(&1A(&UE;G-A9V5M('!O9&5M('-E
M<B!V:7-U86QI>F%D;W,@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A
M:6QS(@IM<V=S='(@(D1E=&%L:&5S(&%D:6-I;VYA:7,@9&4@97)R;R!D82!M
M96YS86=E;2(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<W"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D
M971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(D1E=&%L:&5S(&%D
M:6-I;VYA:7,@9&4@97)R;R!D82!M96YS86=E;2!P;V1E;2!S97(@=FES=6%L
M:7IA9&]S("5S+B(*"B,Z(&-O;G1A8W1S+G!H<#HX-2!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$X,`HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS,SD@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C4R"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B0V%TX6QO9V\@9&4@
M16YD97)EYV]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`IM<V=I
M9"`B061D<F5S<R!";V]K<R(*;7-G<W1R(")#873A;&]G;W,@9&4@16YD97)E
MYV]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I9"`B(@HB
M061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL
M(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM
M<V=S='(@(B(*(D5N9&5R9>=O<R!E;2!#8V\@96T@=&]D87,@87,@;65N<V%G
M96YS.B`\:3XH;W!C:6]N86PL('!R965N8VAA(&-A9&$@96YD97)EYV\@(@HB
M96T@=6UA(&YO=F$@;&EN:&$I/"]I/B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.#$*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!E>'!L:6-I=&QY('1I
M92!T;R!T:&ES(&ED96YT:71Y.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H
M("(*(F%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"B)%
M;F1E<F7G;W,@97AP;&EC:71A;65N=&4@;&EG861O<R!A(&5S=&$@:61E;G1I
M9&%D93H@/&D^*&]P8VEO;F%L+"!P<F5E;F-H82`B"B)C861A(&5N9&5R9>=O
M(&5M('5M82!N;W9A(&QI;FAA*3PO:3XB"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3(*;7-G
M:60@(D%L;"(*;7-G<W1R(")4;V1O<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3,*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T
M:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT
M;R!O;F4@34)/6"`B"B)F:6QE.B(*;7-G<W1R("(B"B)4;V1A<R!A<R!M96YS
M86=E;G,@;F$H<RD@<V5G=6EN=&4H<RD@<&%S=&$H<RD@<V5RXV\@8F%I>&%D
M87,@96T@=6T@87)Q=6EV;R`B"B)-0D]8.B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+W!U<F=E7W1R87-H+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!;&P@;65S<V%G97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R
M('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N
M(@IM<V=S='(@(B(*(E1O9&%S(&%S(&UE;G-A9V5N<R!E;2!S=6$@<&%S=&$@
M7"(E<UPB(&UA:7,@86YT:6=A<R!Q=64@)7,@9&EA<R!S97+C;R`B"B)E>&-L
M=>UD87,@<&5R;6%N96YT96UE;G1E+B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@
M(E1O9&]S(&]S(&%N97AO<R!L:6=A9&]S(&UA:7,@86YT:6=O<R!Q=64@)7,@
M;65S97,@<V5RXV\@97AC;'7M9&]S+B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA
M;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B(@HB
M5&]D87,@87,@<&%S=&%S(%PB16YV:6%D;W-<(B!M86ES(&%N=&EG87,@<75E
M("5S(&UE<V5S('-E<N-O(&5X8VQU[61A<RXB"@HC.B!A8VPN<&AP.C@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<
M(B!S=6-C97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S
M='(@(B(*(E1O9&]S(&]S(&1I<F5I=&]S(&YA('!A<W1A(%PB)7-<(B!F;W)A
M;2!R96UO=FED87,@9&\@=7-UX7)I;R!<(B5S7"(@8V]M("(*(G-U8V5S<V\N
M(@H*(SH@;&EB+V%P:2YP:'`Z-S8*;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A
M=&EO;C\B"FUS9W-T<B`B4&5R;6ET:7(@0W)I8>?C;R!D92!087-T87,_(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0X"FUS9VED(")!;&QO
M=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@;6%I;&)O>#\B
M"FUS9W-T<B`B4&5R;6ET:7(@<75E(&%S(')E9W)A<R!D92!F:6QT<F\@<V5J
M86T@87!L:6-A9&%S(&5M('%U86QQ=65R('!A<W1A/R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3$P"FUS9VED(")!;'1E<FYA=&EV
M92!P87)T<R!F;W(@=&AI<R!S96-T:6]N.B(*;7-G<W1R(")087)T97,@86QT
M97)N871I=F%S('!A<F$@97-T82!S9>?C;SHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3<R"FUS9VED(")!;'=A>7,B"FUS9W-T<B`B4V5M<')E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U-PIM<V=I9"`B06QW87ES('-A
M=F4@871T86-H;65N=',B"FUS9W-T<B`B4V5M<')E('-A;'9A<B!A;F5X;W,B
M"@HC.B!L:6(O365S<V%G92YP:'`Z-3,T"FUS9VED("(B"B)!;B!E<G)O<B!O
M8V-U<F5D('=H:6QE(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE
M;G0N(%1H92!)34%0('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B3V-O<G)E
M=2!U;2!E<G)O(&%O('1E;G1A<B!R96UO=F5R(&\@86YE>&\N($\@<V5R=FED
M;W(@24U!4"!D:7-S93H@(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-PIM<V=I
M9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H
M92!N97<@;F]T92XB"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&1E<V-O;FAE
M8VED;R!A;R!C<FEA<B!A(&YO=F$@;F]T82XB"@HC.B!L:6(O365S<V%G92YP
M:'`Z-#$V"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@
M8W)E871I;F<@=&AE(&YE=R!T87-K+B(*;7-G<W1R(")/8V]R<F5U('5M(&5R
M<F\@9&5S8V]N:&5C:61O(&%O(&-R:6%R(&$@;F]V82!T87)E9F$N(@H*(SH@
M;65S<V%G92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C8Y.2!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,U"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-@IM<V=I9"`B
M06YS=V5R960B"FUS9W-T<B`B4F5S<&]N9&ED82(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,S$*;7-G:60@(D%N<W=E<F5D(&UE<W-A9V5S(@IM
M<V=S='(@(DUE;G-A9V5N<R!R97-P;VYD:61A<R(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,Z-PIM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G
M<W1R(")!<&QI8V%R($9I;'1R;W,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07!P;'D@1FEL=&5R
M<R!T;R`E<R(*;7-G<W1R(")!<&QI8V%R($9I;'1R;W,@96T@)7,B"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S8*;7-G:60@(D%P<&QY(&9I
M;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(D%P;&EC87(@
M<F5G<F%S(&1E(&9I;'1R;R!A;R!C;VYE8W1A<C\B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z-#(*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE
M<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P;&%Y960_(@IM<V=S='(@(D%P;&EC
M87(@<F5G<F%S(&1E(&9I;'1R;R!S96UP<F4@<75E(&$@0V%I>&$@9&4@16YT
M<F%D82!F;W(@97AI8FED83\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C$T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L
M971E('1H:7,@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;C\B"FUS9W-T<B`B
M5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!E>&-L=6ER(&5S=&$@1&5F:6YI
MY^-O(&1E(%!A<W1A(%9I<G1U86P_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y
M/R(*;7-G<W1R(")6;V/J('1E;2!C97)T97IA('%U92!Q=65R(&5X8VQU:7(@
M97-T82!C:&%V92!P^F)L:6-A/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS9VED("(B"B)!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('EO=7(@:V5Y<&%I<C\@
M*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D(2DB"FUS9W-T<B`B(@HB5F]CZB!T
M96T@8V5R=&5Z82!Q=64@<75E<B!E>&-L=6ER('-E=2!P87(@9&4@8VAA=F5S
M/R`H27-T;R!NXV\@Z2`B"B)R96-O;65N9&%D;R$I(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YJ<SHV"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@
M=&AI<S\B"FUS9W-T<B`B5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!F87IE
M<B!I<W1O/R(*"B,Z(&UE<W-A9V4N<&AP.C0P."!T96UP;&%T97,O;6%I;&)O
M>"]J879A<V-R:7!T+FEN8SHV.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS
M9W-T<B`B5F]CZB!T96T@8V5R=&5Z82!Q=64@9&5S96IA(&5X8VQU:7(@4$52
M34%.14Y414U%3E1%(&5S=&%S(&UE;G-A9V5N<S\B"@HC.B!L:6(O34E-12]#
M;VYT96YT<RYP:'`Z,C,Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T
M<B`B5F]CZB!T96T@8V5R=&5Z82!Q=64@9&5S96IA(&5X8VQU:7(@4$5234%.
M14Y414U%3E1%(&5S=&4@86YE>&\_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!E;7!T>2!T:&ES(&9O;&1E<C\B"FUS9W-T<B`B5F]CZB!T96T@8V5R=&5Z
M82!Q=64@9&5S96IA(&5S=F%Z:6%R(&5S=&$@<&%S=&$_(@H*(SH@;&EB+TE-
M4"YP:'`Z.3(S"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP
M='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`B5F]CZB!T96T@8V5R=&5Z
M82!Q=64@9&5S96IA(&5S=F%Z:6%R('-U82!P87-T82!D92!S<&%M<S\B"@HC
M.B!L:6(O24U0+G!H<#HY,38*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`B5F]CZB!T
M96T@8V5R=&5Z82!Q=64@9&5S96IA(&5S=F%Z:6%R('-U82!,:7AE:7)A/R(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE
M<V4@;65S<V%G97,_(@IM<V=S='(@(E9O8^H@=&5M(&-E<G1E>F$@<75E(&1E
M<V5J82!E>&-L=6ER('!E<FUA;F5N=&5M96YT92!E<W1A<R!M96YS86=E;G,_
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z.#`@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-SD*;7-G:60@(D%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN
M;F]C96YT/R(*;7-G<W1R(")6;V/J('1E;2!C97)T97IA('%U92!D97-E:F$@
M<F5P;W)T87(@97-T82!M96YS86=E;2!C;VUO(&EN;V-E;G1E/R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C<U('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*;7-G
M<W1R(")6;V/J('1E;2!C97)T97IA('%U92!D97-E:F$@<F5P;W)T87(@97-T
M82!M96YS86=E;2!C;VUO('-P86T_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDP-0IM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(DAO<F$@9&$@
M0VAE9V%D82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C`*;7-G:60@
M(D%S8V5N9&EN9R(*;7-G<W1R(")!<V-E;F1E;G1E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4W,0IM<V=I9"`B07-K(@IM<V=S='(@(E!E<F=U;G1A
M<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W,@IM<V=I
M9"`B071T86-H($9I;&5S(@IM<V=S='(@(D%R<75I=F]S($%N97AA9&]S(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#4S"FUS9VED(")!
M='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M
M97-S86=E/R(*;7-G<W1R(")!;F5X87(@=6UA(&/S<&EA(&1E('-U82!C:&%V
M92!P^F)L:6-A(%!'4"!A(&5S=&$@;65N<V%G96T_(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W1N968N<&AP.C$Q,0IM<V=I9"`B071T86-H960@1FEL93HB"FUS
M9W-T<B`B07)Q=6EV;R!!;F5X861O.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT
M-C(@;&EB+T-O;7!O<V4N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A8VAM96YT
M('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T<B`B(@HB
M3R!A<G%U:79O(&%N97AA9&\@7"(E<UPB(&5X8V5D92!O(&QI;6ET92!D92!T
M86UA;FAO(&1E(&%N97AO+B!!<G%U:79O($[#3R`B"B)A;F5X861O+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S<*;7-G:60@(D%T=&%C:&5D
M(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+B(*
M;7-G<W1R("(B"B)392!E;F-O;G1R82!A;F5X861A(&$@<F5S<&]S=&$@X"!R
M97%U:7-IY^-O(&1E(&%G96YD86UE;G1O('%U92!V;V/J(&5N=FEO=2XB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$V('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-`HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU,#`@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:G,Z-34*;7-G:60@(D%T=&%C:&UE;G0B"FUS9W-T<B`B06YE>&\B"@HC
M.B!A='1A8VAM96YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!='1A
M8VAM96YT("5S(&1E;&5T960N(@IM<V=S='(@(D%N97AO("5S(&5X8VQU[61O
M+B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,3(U"FUS9VED(")!='1A8VAM96YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6'GXV\@9&\@06YE>&\B"@HC
M.B!C;VUP;W-E+G!H<#HQ,3`U(&QI8B]-97-S86=E+G!H<#HT.34*;7-G:60@
M(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP
M92(*;7-G<W1R(")!;F5X;R!R96UO=FED;SH@5&EP;R!O<FEG:6YA;"!D;R!A
M;F5X;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T.2!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S`*(SH@;&EB+T-O;7!O
M<V4N<&AP.C$P.3,*;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S='(@(D%N97AO
M<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-S@*;7-G:60@(D%T
M=&5N9&5E<R(*;7-G<W1R(")087)T:6-I<&%N=&5S(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*;7-G:60@(D%T=&5N=&EO;B(*
M;7-G<W1R(")!=&5NY^-O(@H*(SH@;&EB+T%U=&@O:6UP+G!H<#HT-`IM<V=I
M9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]I;7`Z17AT96YSXV\@24U!4"!O8G)I9V%T\W)I
M82!NXV\@96YC;VYT<F%D82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C(X"FUS9VED("(B"B)!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A4
M34P@;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*(F%D9')E
M<W-B;V]K/R(*;7-G<W1R("(B"B)%>&EB:7(@:6UA9V5N<R!A=71O;6%T:6-A
M;65N=&4@96T@;65N<V%G96YS(&9O<FUA=&\@2%1-3"!Q=6%N9&\@;R`B"B)D
M97-T:6YA=.%R:6\@97-T:79E<B!E;2!M974@8V%TX6QO9V\@9&4@96YD97)E
MYV]S/R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y
M.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(D-A
M=.%L;V=O<R!D92!%;F1E<F7G;R!D:7-P;V[M=F5I<SHB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S$T"FUS9VED(")!=V%I=&EN9R!297-P;VYS
M92(*;7-G<W1R(")!9W5A<F1A;F1O(')E<W!O<W1A(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")"86-?:R!T;R`E<R(*;7-G<W1R(")2971O<FYA7W(@<&%R82`E
M<R(*"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T
M;R`E<R(*;7-G<W1R(")2971O<FYA<B!P87)A("5S(@H*(SH@=&AR96%D+G!H
M<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN
M9&5X(@IM<V=S='(@(E9O;'1A<B!P87)A(&\@S6YD:6-E(&1E(%9I<W5A;&EZ
M8>?C;R!D92!-^FQT:7!L87,@365N<V%G96YS(@H*(SH@=&AR96%D+G!H<#HQ
M,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D($1I<W!L87DB"FUS9W-T<B`B5F]L
M=&%R(.`@5FES=6%L:7IAY^-O('!O<B!$:7-C=7-SXV\B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")"860@;&]G
M:6X@;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B3&]G:6X@;W4@<V5N:&$@
M:6YVX6QI9&]S+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S@W"B,L('!H
M<"UF;W)M870*;7-G:60@(D)A9"!O<B!M86QF;W)M960@<F5Q=65S="X@4V5R
M=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B4V]L:6-I=&'GXV\@:6YVX6QI
M9&$@;W4@9&5F96ET=6]S83H@;R!397)V:61O<B!297-P;VYD974Z("5S(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0F%D(')E<75E<W0Z("5S+B(*;7-G<W1R(")3;VQI8VET8>?C;R!I;G;A
M;&ED83H@)7,N(@H*(SH@;65S<V%G92YP:'`Z,C<V('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M8V]M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z-C`Q"FUS9VED(")"8V,B
M"FUS9W-T<B`B0V-O(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M,38Q"FUS9VED(")"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE('-T871U
M<R!I;F9O<FUA=&EO;B!M97-S86=E+B(*;7-G<W1R(")!8F%I>&\@97-TX2!O
M('1E>'1O(&)R=71O(&1A(&UE;G-A9V5M(&1E(&EN9F]R;6'GXV\@9&4@<VET
M=6'GXV\N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED
M(")";&%C:VQI<W0B"FUS9W-T<B`B3&ES=&$@3F5G<F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")";&]C:R!I;6%G97,@:6X@2%1-
M3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E
M<W1E9#\B"FUS9W-T<B`B(@HB0FQO<75E87(@;65N<V%G96YS(&5M($A434P@
M82!M96YO<R!Q=64@96QA<R!T96YH86T@<VED;R!E>'!L:6-I=&%M96YT92`B
M"B)S;VQI8VET861A<S\B"@HC.B!L:6(O4V5A<F-H+G!H<#HV,#D*;7-G:60@
M(D)O9'DB"FUS9W-T<B`B0V]R<&\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C(S('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,SD*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU-2!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C<Q"FUS9VED(")";W1H(@IM<V=S='(@(D%M8F]S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8X-`IM<V=I9"`B0F]T:"!(96%D97(@3&ES
M=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(D%M8F%S($QI<W1A
M9V5M(&1O($-A8F7G86QH;R!E($-O<G!O(&1A($UE;G-A9V5M(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R"FUS9VED(")#7VAA<G-E
M="(*;7-G<W1R(")#;VY?:G5N=&\@9&4@8V%R86-T97)E<R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS
M9W-T<B`B06=E;F1A(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*
M;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R
M=F5R+B(*;7-G<W1R(").XV\@8V]N<VEG;R!C;VYE8W1A<B!A;R!S97)V:61O
M<B!D92!C;W)R96EO(')E;6]T;RXB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@
M;6%I;"!S97)V97(Z("(*;7-G<W1R(").XV\@8V]N<VEG;R!C;VYE8W1A<B!A
M;R!S97)V:61O<B!D92!C;W)R96EO(')E;6]T;SH@(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@;V8@)7,@<&%R=',@
M;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT("(*(FUA:6QB;W@N(@IM
M<V=S='(@(B(*(D[C;R!C;VYS:6=O(&5X:6)I<B`M(&5N8V]N=')A9&%S('-O
M;65N=&4@)7,@9&4@)7,@<&%R=&5S(&1E<W1A(&UE;G-A9V5M(&YA("(*(G!A
M<W1A(&%T=6%L+B(*"B,Z(&9O;&1E<G,N<&AP.C(W,"!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(U-0HC.B!T96UP;&%T97,O9F]L9&5R<R]I
M;7!O<G0N:6YC.C(Q('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN
M8SHQ.0HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C$@=&5M
M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@V"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR
M87-E+FEN8SHS,@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8V
M"FUS9VED(")#86YC96PB"FUS9W-T<B`B0V%N8V5L87(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHW,2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,S(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C$Q,0IM<V=I9"`B0V%N8V5L($UE<W-A9V4B"FUS9W-T<B`B0V%N8V5L
M87(@365N<V%G96TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI
M;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G:60@(D-A
M;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R
M9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(D-A;F-E;&%R(&5S=&$@;65N<V%G
M96T@9&5S8V%R=&%RX2!P97)M86YE;G1E;65N=&4@<V5U(&-O;G1E^F1O+B(*
M"B,Z(&UE<W-A9V4N<&AP.C(W-2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C(R,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC
M.C$U(&QI8B]396%R8V@N<&AP.C4Y-PIM<V=I9"`B0V,B"FUS9W-T<B`B0V,B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.CDS"FUS9VED("(B"B)#
M97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO
M860@:7,@;F]T(&5N86)L960@;VX@=&AI<R`B"B)S97)V97(N(@IM<V=S='(@
M(B(*(DEM<&]R=&'GXV\@9&4@8V5R=&EF:6-A9&]S(&[C;R!E<W3A(&1I<W!O
M;NUV96PN($\@96YV:6\@9&4@87)Q=6EV;W,@;N-O(&5S=.$@(@HB:&%B:6QI
M=&%D;R!N97-T92!S97)V:61O<BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-CDV"FUS9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`B36]D97)A
M9&]R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS
M9VED(")#:&%N9V4B"FUS9W-T<B`B06QT97)A<B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I9"`B0VAA;F=E($%L;"(*;7-G
M<W1R(")!;'1E<F%R(%1O9&%S(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.CDR"FUS9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S='(@(D%L=&5R87(@4&%S
M=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS9VED("(B"B)#
M:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G
M97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A
M<F4@<V]R=&5D+B(*;7-G<W1R("(B"B)!;'1E<F$@;W#G]65S(&1E(&5X:6)I
MY^-O('1A:7,@8V]M;R!Q=6%N=&%S(&UE;G-A9V5N<R!V;V/J('!O9&4@=F5R
M(&5M(&-A9&$@(@HB<.%G:6YA(&4@<75A;G1A<R!M96YS86=E;G,@<^-O(&%R
M;6%Z96YA9&%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-`IM<V=I
M9"`B0VAA;F=E(&UA:6P@<V5R=F5R(&%N9"!F;VQD97(@<V5T=&EN9W,N(@IM
M<V=S='(@(D%L=&5R82!S97)V:61O<B!D92!C;W)R96EO(&4@8V]N9FEG=7)A
MY_5E<R!D92!P87-T87,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U
M"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N
M871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"`B"B)R
M97!L>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B)!;'1E<F$@;R!N;VUE
M+"!E;F1E<F7G;R!E(&%S<VEN871U<F$@<75E(&%S('!E<W-O87,@=NIE;2!Q
M=6%N9&\@96QA<R!LZF5M(&4@(@HB<F5S<&]N9&5M('-U87,@;65N<V%G96YS
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3,*;7-G:60@(D-H87)A
M8W1E<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B0V%R86-T97)E<R!A(&5X:6)I
M<CHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-0IM<V=I
M9"`B0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G<W1R(")697)I
M9FEC87(@3F]V87,@365N<V%G96YS(&YA*',I(%!A<W1A*',I(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,B!T96UP;&%T97,O;6%I;&)O
M>"]M97-S86=E7VAE861E<G,N:6YC.C<U"FUS9VED(")#:&5C:R!?06QL+TYO
M;F4B"FUS9W-T<B`B36%R8V%R(%1O9&%S+TYE;FAU;6$B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]F971C:&UA:6PN:6YC.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S
M97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B
M(@HB5F5R:69I8V%R('1O9&]S(&]S('-E<G9I9&]R97,@9&4@8V]R<F5I;R!D
M92!O;F1E('9O8^H@<75E<B!T<F%Z97(@;65N<V%G96YS.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-C,*;7-G:60@(D-H96-K('-P96QL:6YG(&)E
M9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B5F5R:69I8V%R(&]R
M=&]G<F%F:6$@86YT97,@9&4@96YV:6%R('5M82!M96YS86=E;3\B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT"FUS9VED(")#:&]O<V4@
M06-T:6]N.B(*;7-G<W1R(")%<V-O;&AA(&$@0>?C;SHB"@HC.B!C;VYF:6<O
M<V5R=F5R<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-H;V]S92!A(&UA:6P@<V5R
M=F5R.B(*;7-G<W1R(")%<V-O;&AA('5M('-E<G9I9&]R(&1E(&-O<G)E:6\Z
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHR,3<*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R
M(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R(")0;W(@
M9F%V;W(@<V5L96-I;VYE(&]U(&5D:71E(&YA(&-A:7AA(.`@9&ER96ET83HB
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*;7-G
M:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN
M9R!A9&1R97-S97,N(@IM<V=S='(@(D5S8V]L:&$@;R!C873A;&]G;R!D92!E
M;F1E<F7G;W,@<&%R82!U=&EL:7IA<B!A;R!A9&EC:6]N87(@96YD97)EYV]S
M+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PIM
M<V=I9"`B0VAO;W-E('1H92!O<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E
M87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(B(*(D5S
M8V]L:&$@82!O<F1E;2!D92!P97-Q=6ES82!D;W,@8V%TX6QO9V]S(&1E(&5N
M9&5R9>=O<R!A;R!E>'!A;F1I<B!E;F1E<F7G;W,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M:6-K("5S('1O(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA
M="!Y;W5R(&)R;W=S97(@8V%N('9I97<N(@IM<V=S='(@(B(*(D-L:7%U92!E
M;2`E<R!P87)A(&-O;G9E<G1E<B!O(&%R<75I=F\@9&4@:6UA9V5M(&5M('5M
M(&9O<FUA=&\@<75E('-E=2`B"B)N879E9V%D;W(@<&]D92!E>&EB:7(N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92XB"FUS
M9W-T<B`B0VQI<75E(&5M("5S('!A<F$@8F%I>&%R(&$@:6UA9V5M+B(*"B,Z
M(&QI8B]&:6QT97(N<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC
M:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M96YT('!A9V4N(@IM<V=S='(@(D-L
M:7%U92!E;2`E<R!P87)A(&ER('!A<F$@82!PX6=I;F$@9&4@9V5R96YC:6%M
M96YT;R!D92`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@2%1-3"!C
M;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")#;&EQ=64@
M96T@)7,@<&%R82!V97(@;R!C;VYT9?ID;R!(5$U,(&5M('5M82!J86YE;&$@
M<V5P87)A9&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M
M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B0VQI<75E(&5M("5S('!A
M<F$@=F5R('5M82!M:6YI871U<F$@9&5S=&$@:6UA9V5M+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L:6-K("5S('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T
M92!W:6YD;W<N(@IM<V=S='(@(D-L:7%U92!E;2`E<R!P87)A('9E<B!O(&%N
M97AO(&5M('5M82!J86YE;&$@82!P87)T92XB"@HC.B!L:6(O34E-12]6:65W
M97(O<F5L871E9"YP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S
M97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(B(*(D-L:7%U92!E;2`E<R!P87)A
M('9I<W5A;&EZ87(@97-T82!P87)T92!D;R!T:7!O(&UU;'1I<&%R="]R96QA
M=&5D(&5M('5M82`B"B)J86YE;&$@<V5P87)A9&$N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.CDX"FUS9VED(")#;&EC:R!H97)E('1O(%-(3U<@
M=&AE($EM86=E<R(*;7-G<W1R(")#;&EQ=64@87%U:2!P87)A($5824))4B!A
M<R!I;6%G96YS(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,S(Q"FUS9VED("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E
M9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S('1O
M("(*(G-E87)C:"XB"FUS9W-T<B`B(@HB0VQI<75E(&5M('5M(&1E('-E=7,@
M0V%TX6QO9V]S(&1E($5N9&5R9>=O<R!S96QE8VEO;F%D;W,@92!E;G3C;R!S
M96QE8VEO;F4@(@HB=&]D;W,@;W,@8V%M<&]S(&$@<&5S<75I<V%R+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,`IM<V=I9"`B0VQI8VL@=&\@
M4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G
M<W1R(")#;&EQ=64@<&%R82!386QV87(@82!#:&%V92!0^F)L:6-A(%!'4"!E
M;2!S974@0V%TX6QO9V\@9&4@16YD97)EYV]S(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B(@HB0VQI<75E('!A<F$@4V%L=F%R(&\@8V5R
M=&EF:6-A9&\@4R]-24U%(&1E("5S(&5M('-E=2!#873A;&]G;R!D92!%;F1E
M<F7G;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Y"FUS9VED(")#
M;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S
M<V%G92!T;R!T:&4@<V5N9&5R(@IM<V=S='(@(D-L:6-A<B!N;R!E;F1E<F7G
M;R!I<N$@8V]M<&]R('5M82!N;W9A(&UE;G-A9V5M('!A<F$@;R!R96UE=&5N
M=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30P"FUS9VED(")#;&EC
M:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@
M8F4@<F5A9"(*;7-G<W1R(")#;&EC87(@;F\@96YD97)EYV\@86)R:7+A(&$@
M;65N<V%G96T@<&%R82!S97(@;&ED82(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9F5T8VAM86EL+FEN8SHR.`IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B1F5C
M:&%R(@H*(SH@8V]M<&]S92YP:'`Z-#$X"FUS9VED(")#;&]S92!T:&ES('=I
M;F1O=R(*;7-G<W1R(")&96-H87(@97-T82!J86YE;&$B"@HC.B!F;VQD97)S
M+G!H<#HT,3`*;7-G:60@(D-L;W-E9"!&;VQD97(B"FUS9W-T<B`B1F5C:&%R
M(%!A<W1A(@H*(SH@9F]L9&5R<RYP:'`Z-#,P"FUS9VED(")#;VQL87!S92(*
M;7-G<W1R(")#;VYT<F%I<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C0P"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T<B`B0V]N=')A
M:7(@5&]D87,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT
M,`IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS9W-T<B`B0V]N=')A
M:7(@5&]D87,@4&%S=&%S(@H*(SH@9F]L9&5R<RYP:'`Z-#,P"FUS9VED(")#
M;VQL87!S92!&;VQD97(B"FUS9W-T<B`B0V]N=')A:7(@4&%S=&$B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R
M($EN9&EC871O<CH@(@IM<V=S='(@(DEN9&EC861O<B!D92!#;W(Z("(*"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*;7-G:60@(D-O;6UE;G0B"FUS
M9W-T<B`B0V]M96YT87(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S8R"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B16YC97)R861A(@H*(SH@
M8V]M<&]S92YP:'`Z-#$W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S<V%G
M92(*;7-G<W1R(")#;VUP;W(@;W5T<F$@;65N<V%G96TB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN
M(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")#;VUP;W(@;65N<V%G96YS
M(&5M('5M82!J86YE;&$@<V5P87)A9&$_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T,PIM<V=I9"`B(@HB0V]M<&]S92!M97-S86=E<R!W:71H(&%N
M($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@<W5P<&]R=',@=&AE
M("(*(F9E871U<F4I/R(*;7-G<W1R("(B"B)#;VUP;W(@;65N<V%G96YS(&5M
M('5M(&5D:71O<B!(5$U,('!O<B!P861RXV\@*'-E(&\@;F%V96=A9&]R('-U
M<&]R=&%R(&5S=&$@(@HB8V%R86-T97+M<W1I8V$I/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-PIM<V=I9"`B0V]N9FEG=7)E(&AO=R!M97-S86=E
M<R!A<F4@9&ES<&QA>65D+B(*;7-G<W1R(")#;VYF:6=U<F$@8V]M(&%S(&UE
M;G-A9V5N<R!SXV\@97AI8FED87,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDW"FUS9VED(")#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N
M(@IM<V=S='(@(D-O;F9I9W5R82!O<.?U97,@9&4@<'+I+79I<W5A;&EZ8>?C
M;R!D92!M96YS86=E;2XB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM
M<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G
M<W1R(")#;VYE>.-O(&1E<V-A<G1A9&$@<&5L;R!S97)V:61O<B!)34%0+B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C,T"FUS9VED(")#;VYN96-T
M:6]N('1O('-E<G9E<B!F86EL960B"FUS9W-T<B`B02!C;VYE>.-O(&-O;2!O
M('-E<G9I9&]R(&9A;&AO=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R="!F
M;W(@)7,N(@IM<V=S='(@(D-O;G1R;VQA(&\@<W5P;W)T92!01U`@<&%R82`E
M<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G
M<W1R(")#;VYT<F]L82!O('-U<&]R=&4@4R]-24U%('!A<F$@)7,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM<V=I9"`B0V]N=')O;"!O<'1I
M;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E87)C:&EN9RXB"FUS9W-T<B`B
M3W#G]65S(&1E(&-O;G1R;VQE(')E;&%C:6]N861A<R!A('!E<W%U:7-A(&1E
M(&UE;G-A9V5N<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G
M:60@(B(*(D-O;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@
M9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2`B"B)W:&5N
M(&ET(&%R<FEV97,N(@IM<V=S='(@(B(*(D-O;G1R;VQA('%U86YD;R!F87IE
M<B!A('9E<FEF:6-AY^-O('!O<B!N;W9A<R!M96YS86=E;G,@92!S92!D979E
M(&YO=&EF:6-A<B`B"B)O=2!NXV\@<75A;F1O(&5L87,@8VAE9V%R96TN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W-`IM<V=I9"`B0V]N=F5R="!T
M97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R
M(")#;VYV97)T97(@)V5M;W1I8V]N<R<@=&5X='5A:7,@96T@9W+A9FEC;W,_
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y
M(@IM<V=S='(@(D-O<&EA<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHU,0IM<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T<B`B0V]P:6%R('!A
M<F$@82!P87-T82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHV,PIM<V=I9"`B0V]R<F5C="(*;7-G<W1R(")#;W)R:6=I<B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#`*;7-G:60@(D-O<G)E
M8W1E9"!497AT(@IM<V=S='(@(E1E>'1O($-O<G)I9VED;R(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z,S@R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S(@IM<V=S
M='(@(DEM<&]S<^UV96P@8V]M<&QE=&%R(&$@<V]L:6-I=&'GXV\Z(%)A>N-O
M.B`E<R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G
M<W1R(").XV\@8V]N<V5G=6D@8W)I87(@=6T@8V]N96-T;W(@5E-&.B`E<R(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!M97-S86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R
M('-A:60Z("5S(@IM<V=S='(@(D[C;R!C;VYS96=U:2!E>&-L=6ER(&%S(&UE
M;G-A9V5N<R!D92`E<RX@3R!S97)V:61O<B!D:7-S93H@)7,B"@HC.B!L:6(O
M4V5S<VEO;BYP:'`Z,S(Q"FUS9VED(")#;W5L9"!N;W0@97AE8W5T92!M86EN
M=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R(").XV\@8V]N<V5G=6D@97AE
M8W5T87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W1N968N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C
M="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM
M96YT+B(*;7-G<W1R(").XV\@8V]N<V5G=6D@97AT<F%I<B!O(&%R<75I=F\@
M<V]L:6-I=&%D;R!D;R!A;F5X;R!-4RU43D5&+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@
M<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@
M(D[C;R!C;VYS96=U:2!E>'1R86ER(&\@87)Q=6EV;R!S;VQI8VET861O(&1O
M(&%R<75I=F\@6FEP+B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N('-E8W5R92!C;VYN
M96-T:6]N('1O('1H92!)34%0('-E<G9E<BX@)7,@.B`E<RXB"FUS9W-T<B`B
M26UP;W-S[79E;"!A8G)I<B!C;VYE>.-O('-E9W5R82!N;R!S97)V:61O<B!)
M34%0.B`E<SH@)7,N(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(V.0IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M
M($E-05`@<V5R=F5R+B(*;7-G<W1R("));7!O<W/M=F5L(&]B=&5R(&EN9F]R
M;6'G]65S(&1E(&YO;65S(&1O('-E<G9I9&]R($E-05`N(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E<R]A8VPO86-L
M+FEN8SHS.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Q"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B0W)I87(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHV"FUS9VED(")#<F5A=&4@1F]L9&5R(@IM<V=S='(@(D-R
M:6%R(%!A<W1A(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I
M9"`B0W)E871E($ME>7,B"FUS9W-T<B`B0W)I87(@0VAA=F5S(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C8*;7-G:60@
M(D-R96%T92!A($YE=R!!8V-O=6YT(@IM<V=S='(@(D]U=')A<R!#;VYT87,@
M9&4@0V]R<F5I;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN
M8SHQ,B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,C0*;7-G:60@
M(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R(")#<FEA<B!U;6$@
M;F]V82!P87-T82!D92!S<&%M(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S
M='(@(D-R:6%R('5M82!N;W9A('!A<W1A(&1E(')A<V-U;FAO<R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@
M;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B0W)I87(@=6UA(&YO=F$@
M<&%S=&$@;65N<V%G96YS(&5N=FEA9&%S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W1R87-H<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE
M8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R(@IM
M<V=S='(@(D-R:6%R('5M82!N;W9A(&QI>&5I<F$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG(')U
M;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I="!I
M;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`B(@HB
M0W)I82!R96=R87,@9&4@9FEL=')O('!A<F$@;W)G86YI>F%R(&%S(&YO=F%S
M(&UE;G-A9V5N<RP@;W)D96[A+6QA<R!E;2`B"B)P87-T87,@92!E>&-L=6ER
M('-P86TN(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T
M"FUS9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`B0W)I87(@
M=6T@;F]V;R!P87!E;"!D92!C87)T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-#D*;7-G:60@(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M(')E
M<W!O;G-E<RXB"FUS9W-T<B`B0W)I87(@<&%P96P@9&4@8V%R=&$@92!F;W)M
M=6SA<FEO(&1E(')E<W!O<W1A<RXB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R<F5N="!A8V-E<W,@=&\@
M)7,B"FUS9W-T<B`B06-E<W-O(&%T=6%L(&$@)7,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R
M(&9E=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`B
M0W5S=&]M:7IA(&-O;G1A<R!P87)A('1R87IE<B!M96YS86=E;G,@9&4@;W5T
M<F%S(&-O;G1A<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G
M:60@(D-U<W1O;6EZ92!H;W<@>6]U('-E;F0@;6%I;"XB"FUS9W-T<B`B0W5S
M=&]M:7IA(&-O;6\@=F]CZB!E;G9I82!M96YS86=E;G,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B
M0W5S=&]M:7IA('1A<F5F87,@82!S97)E;2!E>&5C=71A9&%S(&%O(&-O;F5C
M=&%R(&$@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHQ-PIM<V=I9"`B1&%T7V4B"FUS9W-T<B`B1&%T7V$B"@HC.B!M
M97-S86=E+G!H<#HR-S(@=&AR96%D+G!H<#HQ-3,*;7-G:60@(D1A=&4B"FUS
M9W-T<B`B1&%T82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3`*
M;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(E)E8W5S861O(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C(V-`IM<V=I9"`B1&5C;&EN960Z("(*;7-G
M<W1R(")296-U<V%D;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*
M;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B17AC;'5I<B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHR,0IM<V=I9"`B1&5F
M875L="!396%R8V@@1FEE;&0B"FUS9W-T<B`B0V%M<&\@9&4@4&5S<75I<V$@
M4&%D<N-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ,@IM<V=I9"`B
M1&5F875L="!S;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R(")#<FETZ7)I;R!P
M861RXV\@9&4@;W)D96YAY^-O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,C(*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S
M='(@(D1I<F7GXV\@9&4@;W)D96YAY^-O('!A9'+C;SHB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S4X"FUS9VED(")$96QE9V%T960B"FUS9W-T
M<B`B1&5L96=A9&\B"@HC.B!F;VQD97)S+G!H<#HT,#`@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS9VED
M(")$96QE=&4B"FUS9W-T<B`B17AC;'5I<B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@
M(D5X8VQU:7(@0VAA=F4@4/IB;&EC82`E<R(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@U"FUS9VED
M(")$96QE=&4@0W5R<F5N="!+97ES(@IM<V=S='(@(D5X8VQU:7(@0VAA=F5S
M($%T=6%I<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*
M;7-G:60@(D1E;&5T92!&;VQD97(H<RDB"FUS9W-T<B`B17AC;'5I<B!087-T
M82AS*2(*"B,Z(&9O;&1E<G,N<&AP.C(W,0IM<V=I9"`B1&5L971E(%-E;&5C
M=&5D($9O;&1E<G,B"FUS9W-T<B`B17AC;'5I<B!087-T87,@4V5L96-I;VYA
M9&%S(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0R"FUS
M9VED(")$96QE=&4@4W1A=&EO;F5R>2(*;7-G<W1R(")%>&-L=6ER(%!A<&5L
M(&1E($-A<G1A(@H*(SH@9F]L9&5R<RYP:'`Z-#`P"FUS9VED(")$96QE=&4@
M5FER='5A;"!&;VQD97(B"FUS9W-T<B`B17AC;'5I<B!087-T87,@5FER='5A
M:7,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$T"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92!6:7)T=6%L($9O;&1E<B!$969I;FET
M:6]N(&9O<B`E<R(*;7-G<W1R(")%>&-L=6ER($1E9FEN:>?U97,@9&4@4&%S
M=&%S(%9I<G1U86ES(&1E("5S(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F
M<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@(D5X8VQU:7(@;65N<V%G96YS
M('1R87II9&%S(&1O('-E<G9I9&]R(')E;6]T;S\B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C$Y"FUS9VED(")$96QE=&4@9G)O;2!M>2!C86QE
M;F1A<B(*;7-G<W1R(")%>&-L=6ER(&1A(&UI;FAA(&%G96YD82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(D1E;&5T92!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T
M<B`B17AC;'5I<B!L:6YK<R!D92!A;F5X;W,@86YT:6=O<R!N;R!I;NUC:6\@
M9&\@;>IS/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3`*;7-G:60@
M(D1E;&5T92!O;&0@<V5N="UM86EL(&9O;&1E<G,@870@8F5G:6YN:6YG(&]F
M(&UO;G1H/R(*;7-G<W1R(")%>&-L=6ER('!A<W1A<R!A;G1I9V%S(&1E(&UE
M;G-A9V5N<R!E;G9I861A<R!N;R!I;NUC:6\@9&\@;>IS/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV,#4*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A
M9V5S(@IM<V=S='(@(D5X8VQU:7(@<W!A;7,B"@HC.B!M97-S86=E+G!H<#HU
M,#8@;6%I;&)O>"YP:'`Z-S(U('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,C`*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS."!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C@*;7-G:60@(D1E;&5T960B"FUS
M9W-T<B`B17AC;'7M9&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(DUE;G-A9V5N
M<R!%>&-L=>UD87,B"@HC.B!C;VUP;W-E+G!H<#HU-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!T:&4@871T86-H;65N="!<(B5S7"(N(@IM<V=S
M='(@(D%N97AO(%PB)7-<(B!E>&-L=>UD;RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG(&%N9"!-;W9I;F<@365S<V%G
M97,B"FUS9W-T<B`B17AC;'5I;F1O(&4@36]V96YD;R!-96YS86=E;G,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@W"FUS9VED(")$96YY(')E
M<75E<W0B"FUS9W-T<B`B3F5G87(@<V]L:6-I=&'GXV\B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-30R"FUS9VED(")$96YY(')E<75E<W0@9F]R
M(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R(").96=A<B!S;VQI8VET
M8>?C;R!D92!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@
M(D1E<V-E;F1E;G1E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:6YC.C(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C8*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:>?C;R(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B
M1&5T86EL<R(*;7-G<W1R(")$971A;&AE<R(*"B,Z(&-O;7!O<V4N<&AP.C4X
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$:60@;F]T(&%T=&%C:"!<(B5S7"(@
M87,@=&AE(&9I;&4@=V%S(&5M<'1Y+B(*;7-G<W1R(").XV\@86YE>&]U(%PB
M)7-<(B!P;VES(&\@87)Q=6EV;R!E<W1A=F$@=F%Z:6\N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8V-0IM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM
M<V=S='(@(D5S;6%E8V5R(&%S<VEN871U<F%S/R(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V"FUS9VED(")$:7-P;&%Y(@IM<V=S
M='(@(D5X:6)I<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-SD*;7-G
M:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S
M86=E/R(*;7-G<W1R(")%>&EB:7(@8V]N9FER;6'GXV\@87#S<R!E;G9I87(@
M=6UA(&UE;G-A9V5M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#,*
M;7-G:60@(D1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(D5X
M:6)I<B!N;R!#;W)P;R!D82!-96YS86=E;2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.#$*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO
M;B!O9B!N97<@;6%I;#\B"FUS9W-T<B`B17AI8FER('!O<"UU<"!D92!N;W1I
M9FEC8>?C;R!D92!N;W9A(&UE;G-A9V5M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-#<*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP='D@4W!A;5PB
M(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(D5X:6)I<B!O(.UC;VYE
M("=!<&%G87(@4W!A;7,G(&YA(&)A<G)A(&1E(&UE;G5S/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW,SD*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP
M='D@5')A<VA<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R(")%>&EB
M:7(@;R#M8V]N92`G17-V87II87(@3&EX96ER82<@;F$@8F%R<F$@9&4@;65N
M=7,_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$Q
M"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R(")$:7-P;W-IY^-O(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C(V"FUS9VED(")$;R!.3U0@
M;6%T8V@B"FUS9W-T<B`B3L-/(&-O<G)E<W!O;F1E(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#:&5C:R!&
M;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(D[C;R!697)I9FEC82!.
M;W9A<R!-96YS86=E;G,@;F$H<RD@4&%S=&$H<RDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.30Q"FUS9VED(")$;R!N;W0@9V5N97)A=&4@82!L:6YK
M(&EN('1H92!&<F]M.B!C;VQU;6XB"FUS9W-T<B`B3N-O(&=E<F%R('5M(&QI
M;FL@;F$@8V]L=6YA(%PB1&4Z7"(B"@HC.B!L:6(O24U0+G!H<#HQ,#(T"FUS
M9VED(")$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/R(*;7-G<W1R
M(")6;V/J('%U97(@86)R:7(@97-T82!P87-T83\B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(S,0IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O
M=6YT/R!3:6=N('5P+B(*;7-G<W1R(").XV\@<&]S<W5I('5M82!C;VYT83\@
M0V%D87-T<F4M<V4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$R-@IM<V=I9"`B1&]N92(*;7-G<W1R(")&96ET;R(*"B,Z(&QI8B]-
M24U%+T-O;G1E;G1S+G!H<#HR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W
M;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B0F%I>&%R("5S(&YO
M(&9O<FUA=&\@+GII<"(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ
M:7`@9FEL92DB"FUS9W-T<B`B0F%I>&%R('1O9&]S(&%N97AO<R`H96T@87)Q
M=6EV;R`N>FEP*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C(P"FUS9VED(")$;W=N;&]A9"!&;VQD97(H<RDB"FUS9W-T<B`B0F%I>&%R
M(%!A<W1A*',I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,C$*;7-G:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=(@IM
M<V=S='(@(D)A:7AA<B!087-T82AS*2!;9F]R;6%T;R`N>FEP72(*"B,Z(&QI
M8B]-24U%+T-O;G1E;G1S+G!H<#HR,38*;7-G:60@(D1O=VYL;V%D(&EN("YZ
M:7`@1F]R;6%T(@IM<V=S='(@(D)A:7AA<B!E;2!F;W)M871O("YZ:7`B"@HC
M.B!M97-S86=E+G!H<#HU,#0@;6%I;&)O>"YP:'`Z-S`T('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3$*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHR,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C0Q"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.0IM<V=I
M9"`B1')A9G0B"FUS9W-T<B`B4F%S8W5N:&\B"@HC.B!F;VQD97)S+G!H<#HS
M-S,*;7-G:60@(D1R869T(&9O;&1E<B(*;7-G<W1R(")087-T82!<(E)A<V-U
M;FAO<UPB(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z
M,C,*;7-G:60@(D1R869T<R!F;VQD97(Z(@IM<V=S='(@(E!A<W1A(%PB4F%S
M8W5N:&]S7"(Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$P.`IM<V=I
M9"`B12UM86EL($%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@9&4@92UM86EL
M(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,P,@IM<V=I9"`B14Y$(@IM<V=S='(@
M(D9)32(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED
M(")%4E)/4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N
M(@IM<V=S='(@(D524D\Z(%-U82!M96YS86=E;2!NXV\@</1D92!S97(@96YT
M<F5G=64N(@H*(SH@9F]L9&5R<RYP:'`Z-#`Q('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHQ.0IM<V=I9"`B161I="(*;7-G<W1R(")%9&ET87(B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D
M:70@0FQA8VML:7-T(@IM<V=S='(@(D5D:71A<B!,:7-T82!.96=R82(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM<V=I9"`B161I="!&
M:6QT97)S(@IM<V=S='(@(D5D:71A<B!&:6QT<F]S(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]H96%D97(N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,38*;7-G:60@(D5D:70@4V5A<F-H(%%U97)Y(@IM<V=S='(@(D5D
M:71A<B!396YT96[G82!D92!097-Q=6ES82(*"B,Z(&9O;&1E<G,N<&AP.C0P
M,2!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3<*;7-G:60@(D5D:70@
M5FER='5A;"!&;VQD97(B"FUS9W-T<B`B161I=&%R(%!A<W1A(%9I<G1U86PB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F
M;W(@)7,B"FUS9W-T<B`B161I=&%R($1E9FEN:>?C;R!D82!087-T82!6:7)T
M=6%L('!A<F$@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(D5D:71A<B!,:7-T
M82!"<F%N8V$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*
M;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B161I=&%R('-U
M82!L:7-T82!N96=R82(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHQ,PIM<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(*;7-G<W1R(")%
M9&ET87(@<W5A<R!R96=R87,@9&4@9FEL=')O(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@U,`IM<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O
M<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B161I
M=&$@<W5A<R!P<F5F97+J;F-I87,@86\@86-E<W-A<B!O=71R87,@8V]N=&%S
M(&1E(&4M;6%I;"XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,C,*;7-G:60@(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B161I=&%R
M('-U82!L:7-T82!B<F%N8V$B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(S.0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%
M;F1E<F7G;R!D92!%+4UA:6PB"@HC.B!L:6(O365S<V%G92YP:'`Z-C<W"B,L
M('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@
M)7,N(@IM<V=S='(@(E1O9&%S(&UE;G-A9V5N<R!D92`E<R!F;W)A;2!E>&-L
M=>UD87,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,PIM<V=I9"`B16UP=&EE
M9"!A;&P@;65S<V%G97,@9G)O;2!6:7)T=6%L(%1R87-H($9O;&1E<BXB"FUS
M9W-T<B`B5&]D87,@87,@;65N<V%G96YS(&1A($QI>&5I<F$@5FER='5A;"!F
M;W)A;2!E>&-L=>UD87,N(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,C(*;7-G:60@(D5M<'1Y($9O;&1E<BAS*2(*;7-G<W1R(")%<W9A
M>FEA<B!087-T82AS*2(*"B,Z(&9O;&1E<G,N<&AP.C(W,@IM<V=I9"`B16UP
M='D@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R(")%<W9A>FEA<B!087-T82AS
M*2!396QE8VEO;F%D82AS*2(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C,Y"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS9W-T<B`B
M17-V87II87(@3&EX96ER82(*"B,Z(&QI8B])35`N<&AP.CDR,PIM<V=I9"`B
M16UP='D@7U-P86TB"FUS9W-T<B`B07!A9V%R(%-?<&%M(@H*(SH@;&EB+TE-
M4"YP:'`Z.3$V"FUS9VED(")%;7!T>2!?5')A<V@B"FUS9W-T<B`B17-V87II
M87(@7TQI>&5I<F$B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,2!T96UP
M;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%!'4"!F
M=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")(86)I;&ET87(@9G5N8VEO;F%L:61A
M9&4@4$=0/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,2!T96UP
M;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4R]-
M24U%(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(DAA8FEL:71A<B!F=6YC:6]N
M86QI9&%D92!3+TU)344_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P
M,`IM<V=I9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_(@IM<V=S='(@(DAA
M8FEL:71A<B!P<NDM=FES=6%L:7IAY^-O(&1E(&UE;G-A9V5M/R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S.0IM<V=I9"`B16YC<E]Y
M<'1I;VX@3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&4@7T-R:7!T;V=R869I
M82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3@*;7-G:60@
M(D5N8W)Y<'1E9"(*;7-G<W1R(")#<FEP=&]G<F%F861O(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4Q-B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3$X"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3$@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8U,PIM<V=I9"`B16YD(@IM<V=S='(@(D9I
M;F%L(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,Y-0IM<V=I9"`B16YD(&9O<G=A
M<F1E9"!M97-S86=E(@IM<V=S='(@(D9I;F%L(&1A(&UE;G-A9V5M(&5N8V%M
M:6YH861A(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,U,@IM<V=I9"`B16YD(&UE
M<W-A9V4B"FUS9W-T<B`B1FEN86P@9&$@;65N<V%G96TB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D5N9"!M97-S86=E
M(&9R;VT@)7,B"FUS9W-T<B`B1FEN86P@9&$@;65N<V%G96T@9&4@)7,B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW-PIM<V=I9"`B16YT97(@4&%S<W!H<F%S92(*;7-G<W1R(")&
M;W)N9>=A(&$@<V5N:&$B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C
M="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(%-P
M86T@9F]L9&5R(@IM<V=S='(@(D9O<FYEYV$@;R!N;VUE(&1E('-U82!N;W9A
M('!A<W1A(&1E('-P86US(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E
M;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W
M(&1R869T<R!F;VQD97(B"FUS9W-T<B`B1F]R;F7G82!O(&YO;64@9&4@<W5A
M(&YO=F$@<&%S=&$@9&4@<F%S8W5N:&]S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-E;G1M86EL<V5L96-T+FEN8SHR,PIM<V=I9"`B16YT97(@=&AE(&YA;64@
M9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B1F]R;F7G
M82!O(&YO;64@9&4@<W5A(&YO=F$@<&%S=&$@9&4@;65N<V%G96YS(&5N=FEA
M9&%S(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHY"FUS
M9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L9&5R
M(@IM<V=S='(@(D9O<FYEYV$@;R!N;VUE(&1E('-U82!N;W9A(&QI>&5I<F$B
M"@HC.B!L:6(O4V5A<F-H+G!H<#HV,3,*;7-G:60@(D5N=&ER92!-97-S86=E
M(@IM<V=S='(@(E1O9&$@82!-96YS86=E;2(*"B,Z(&UE<W-A9V4N<&AP.C$Y
M-"!C;VUP;W-E+G!H<#HQ,3<R('1H<F5A9"YP:'`Z-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R(")296=I<W1R;R!<(B5S7"(@
M9F]I(&%D:6-I;VYA9&\@86\@8V%TX6QO9V\@9&4@96YD97)EYV]S(&-O;2!S
M=6-E<W-O(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ."!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HS.#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDP"B,Z(&QI8B]-
M24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T<B`B17)R;R(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z-#,Q(&QI8B])34%0+T-L:65N="YP:'`Z-#4T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!
M4"!S97)V97(N("5S(#H@)7,N(@IM<V=S='(@(D5R<F\@8V]N96-T86YD;R!A
M;R!S97)V:61O<B!)34%0.B`E<SH@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C,Q,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`X"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*
M;7-G<W1R(")%<G)O(&%O(&5N=FEA<B!R97-P;W-T83H@)7,N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,@IM<V=I9"`B179E;G0@<W5C8V5S
M<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(D5V96YT;R!E>&-L=>UD;R!C;VT@
M<W5C97-S;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<Q"FUS9VED
M(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,34@;6EN=71O<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-C@*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=U;F1O<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-S`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R(")#861A(#4@;6EN=71O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-S(*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#861A
M(&UE:6$@:&]R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-CD*;7-G
M:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")#861A(&UI;G5T;R(*"B,Z(&9O
M;&1E<G,N<&AP.C0S.`IM<V=I9"`B17AP86YD(@IM<V=S='(@(D5X<&%N9&ER
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@
M(D5X<&%N9"!!;&PB"FUS9W-T<B`B17AP86YD:7(@5&]D87,B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B17AP86YD($%L
M;"!&;VQD97)S(@IM<V=S='(@(D5X<&%N9&ER(%1O9&%S(%!A<W1A<R(*"B,Z
M(&9O;&1E<G,N<&AP.C0S.`IM<V=I9"`B17AP86YD($9O;&1E<B(*;7-G<W1R
M(")%>'!A;F1I<B!087-T82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C,T,"!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-3,*
M;7-G:60@(D5X<&%N9"!.86UE<R(*;7-G<W1R(")%>'!A;F1I<B!.;VUE<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4R"FUS9VED(")%>'!A;F0@
M;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I8V%L;'D@:6X@
M=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(B(*(D5X<&%N9&ER(&YO;65S(&YA
M(&IA;F5L82!D92!C;VUP;W-IY^-O(&%U=&]M871I8V%M96YT92!E;2!S96=U
M;F1O('!L86YO/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-CD*;7-G
M:60@(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@
M:6X@=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T<B`B(@HB17AP86YD:7(L('!O
M<B!P861RXV\L(&EN=&5I<F%M96YT92!A(.%R=F]R92!D92!P87-T87,@;F$@
M=FES=6%L:7IAY^-O(&1E("(*(G!A<W1A<S\B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(T
M-2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3`Q"FUS9VED(")%
M>'!A;F1I;F<B"FUS9W-T<B`B17AP86YD:6YD;R(*"B,Z(&QI8B])35`N<&AP
M.CDS-"!L:6(O24U0+G!H<#HY,S8*;7-G:60@(D9?971C:"!-86EL(@IM<V=S
M='(@(E1R87IE<B!-96YS86=E;G,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM
M<V=I9"`B1F5T8V@@36%I;"(*;7-G<W1R(")4<F%Z97(@365N<V%G96YS(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U.`IM<V=I9"`B1F5T8V@@36%I
M;"!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B5')A>F5R(&UE;G-A
M9V5N<R!E;2!U;6$@:F%N96QA('-E<&%R861A/R(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@
M=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")4<F%Z97(@;65N<V%G96YS(&%O
M(&-O;F5C=&%R/R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(Y,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&971C:&5D("5D(&UE<W-A9V5S(&9R;VT@)7,B"FUS
M9W-T<B`B)60@;65N<V%G96YS('1R87II9&%S(&1E("5S(@H*(SH@;&EB+T9E
M=&-H;6%I;"YP:'`Z,C@Y"B,L('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@
M,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B,2!M96YS86=E;2!T<F%Z:61A
M(&1E("5S(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C:&UA
M:6PN<&AP.C(X.2!L:6(O1F5T8VAM86EL+G!H<#HR.3$*;7-G:60@(D9E=&-H
M;6%I;#H@(@IM<V=S='(@(E1R87IE<B!-96YS86=E;G,Z("(*"B,Z(&QI8B]&
M971C:&UA:6PN<&AP.C(Y,PIM<V=I9"`B1F5T8VAM86EL.B!N;R!N97<@;65S
M<V%G97,N(@IM<V=S='(@(E1R87IE<B!-96YS86=E;G,Z('-E;2!M96YS86=E
M;G,@;F]V87,N(@H*(SH@;&EB+TE-4"YP:'`Z.30P"FUS9VED(")&:5]L=&5R
M<R(*;7-G<W1R(")?1FEL=')O<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0Y-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ
M<SHT,`IM<V=I9"`B1FEL92(*;7-G<W1R(")!<G%U:79O(@H*(SH@=&5M<&QA
M=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"FUS9VED(")&:6QT97(@3W!T:6]N
M<R(*;7-G<W1R(")/<.?U97,@9&4@1FEL=')O(@H*(SH@=&5M<&QA=&5S+V9I
M;'1E<G,O<')E9G,N:6YC.CD*;7-G:60@(D9I;'1E<B!3971T:6YG<R(*;7-G
M<W1R(")#;VYF:6=U<F'G]65S(&1E($9I;'1R;R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU.#@*;7-G:60@(D9I;'1E<B!M97-S86=E(&-O;G1E;G0@
M9F]R('!R;V9A;FET>3\B"FUS9W-T<B`B1FEL=')A<B!M96YS86=E;2!C;VT@
M8V]N=&7Z9&\@;V9E;G-I=F\_(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T
M86-T:79E+FEN8SHQ,0IM<V=I9"`B1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L
M960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(D\@<W5P;W)T92!A(&9I;'1R
M;W,@97-TX2!D97-A8FEL:71A9&\@;F5S=&4@<VES=&5M82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S='(@
M(D9I;'1R;W,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC
M.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C=&EV92(*;7-G<W1R(")&:6QT<F]S
M($[#3R!!=&EV;W,B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E(@IM<V=S
M='(@(D9I;'1R;W,Z('#A9VEN82!D92!G97)E;F-I86UE;G1O(&1E("5S(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*;7-G:60@
M(D9I;F0B"FUS9W-T<B`B16YC;VYT<F%R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Y-`IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E(@IM<V=S='(@
M(E!R:6UE:7)A(%#A9VEN82!D82!087-T82(*"B,Z(&UA:6QB;W@N<&AP.C,R
M.`IM<V=I9"`B1FER<W0@4&%G92(*;7-G<W1R(")0<FEM96ER82!0X6=I;F$B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,34@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O7W)W
M87)D(@IM<V=S='(@(D5N8V%M:6Y?:&%R(@H*(SH@9F]L9&5R<RYP:'`Z,C4R
M('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G
M:60@(D9O;&1E<B!!8W1I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(D'G
M]65S(&1E(%!A<W1A<R`M($-O;F9I<FUAY^-O(@H*(SH@9F]L9&5R<RYP:'`Z
M,C@Y('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S
M+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L871E<R]P
M<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.
M879I9V%T;W(B"FUS9W-T<B`B3F%V96=A9&]R(&1E(%!A<W1A<R(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED(")&;VQD97(@4W5M;6%R>2(*
M;7-G<W1R(")297-U;6\@9&4@4&%S=&%S(@H*(SH@86-L+G!H<#HR,PIM<V=I
M9"`B1F]L9&5R('-H87)I;F<@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(D\@
M8V]M<&%R=&EL:&%M96YT;R!D92!P87-T87,@;N-O(&5S=.$@:&%B:6QI=&%D
M;RXB"@HC.B!F;VQD97)S+G!H<#HT-PIM<V=I9"`B1F]L9&5R('5S92!I<R!N
M;W0@96YA8FQE9"XB"FUS9W-T<B`B02!U=&EL:7IAY^-O(&1E('!A<W1A<R!N
MXV\@97-TX2!H86)I;&ET861A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-3@*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M
M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@
M(B(*(D9O<FUA=&\@9&$@9&%T82!D87,@;65N<V%G96YS(&YA('9I<W5A;&EZ
M8>?C;R!D82!C86EX82!P;W-T86P@<&%R82!M96YS86=E;G,@(@HB9&%T861A
M<R!D92!H;VIE(@H*(SH@8V]M<&]S92YP:'`Z.#(P('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")%;F-A
M;6EN:&%R(@H*(SH@8V]M<&]S92YP:'`Z.#`U"FUS9VED(")&;W)W87)D.B(*
M;7-G<W1R(")%;F-A;6EN:&%R.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#`*
M;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(DUE;G-A9V5M(&5N
M8V%M:6YH861A(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,W.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@
M(DUE;G-A9V5M(&5N8V%M:6YH861A(&1E("5S(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0P,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0@4F5S
M<&]N<V4B"FUS9W-T<B`B4F5S<&]S=&$@9&$@4V]L:6-I=&'GXV\@9&4@26YF
M;W)M8>?C;R!,:79R92]/8W5P861O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHR-PIM<V=I9"`B1G)O7VTB"FUS9W-T<B`B
M7T1E(@H*(SH@;65S<V%G92YP:'`Z,C<S('1H<F5A9"YP:'`Z,34T('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.CDY"B,Z(&QI8B]396%R8V@N<&AP
M.C4X.0IM<V=I9"`B1G)O;2(*;7-G<W1R(")$92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,#<*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R(")%
M;F1E<F7G;R!D;R!296UE=&5N=&4B"@HC.B!C;VUP;W-E+G!H<#HX,3<@8V]M
M<&]S92YP:'`Z.#(Q"FUS9VED(")&=V0Z(@IM<V=S='(@(D5N8SHB"@HC.B!C
M;VUP;W-E+G!H<#HQ,S$Q"FUS9VED(")&=V0Z("(*;7-G<W1R(")%;F,Z("(*
M"B,Z(&-O;7!O<V4N<&AP.C$S,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1G=D
M.B`E=2!&;W)W87)D960@365S<V%G97,B"FUS9W-T<B`B16YC.B`E=2!-96YS
M86=E;G,@16YC86UI;FAA9&%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")'
M96YE<F%L($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S($=E<F%I<R(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS-PIM<V=I9"`B1V5T(&]N
M;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*2(*;7-G<W1R(")/8G1E<B!S
M;VUE;G1E(&YO=F%S(&UE;G-A9V5N<S\@*'-O;65N=&4@24U!4"DB"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-34T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M,C@*;7-G:60@(D=O(@IM<V=S='(@(DER(@H*(SH@=&AR96%D+G!H<#HQ,S8*
M;7-G:60@(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B27(@<&%R82!A($UE;G-A
M9V5M(@H*(SH@;&EB+TE-4"YP:'`Z-3`T"B,L('!H<"UF;W)M870*;7-G:60@
M(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B
M27(@<&%R82!O(')E9VES=')O(&1O(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!D
M92!<(B5S7"(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3,V"FUS9VED
M(")'<F%N="!A8V-E<W,B"FUS9W-T<B`B0V]N8V5D97(@86-E<W-O(@H*(SH@
M;65S<V%G92YP:'`Z-30Y(&QI8B]&:6QT97(N<&AP.C$P-2!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ,#0*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,3$Q(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$Q,PHC.B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$Q.0HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HV,B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC
M.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HT,C,*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U
M8FQE+G!H<#HT,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S(*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C$R-PIM<V=I9"`B2$5212(*;7-G<W1R(")!455)(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,Q(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HQ,C`*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N
M<&AP.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!C;VUP;W-E
M+G!H<#HR-C`*;7-G:60@(DA434P@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S
M='(@(E9E<G/C;R!(5$U,(&1A($UE;G-A9V5M(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M0V%B9>=A;&AO<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI
M;F,Z-0IM<V=I9"`B2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@=V5R92!C;VUP
M;W-I;F<Z(@IM<V=S='(@(D%Q=6D@97-TX2!A(&UE;G-A9V5M('%U92!V;V/J
M(&5S=&%V82!C;VUP;VYD;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C4V"FUS9VED(")(:61D96XB"FUS9W-T<B`B3V-U;'1O(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8U-0IM<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6
M:65W(@IM<V=S='(@(D]C=6QT;R!N82!6:7-U86QI>F'GXV\@<&]R($1I<V-U
M<W/C;R(*"B,Z(&UA:6QB;W@N<&AP.C,U,`IM<V=I9"`B2&ED92!$96QE=&5D
M(@IM<V=S='(@(D]C=6QT87(@17AC;'7M9&%S(@H*(SH@9F]L9&5R<RYP:'`Z
M,C@T"FUS9VED(")(:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")/8W5L=&%R
M($[C;R!);G-C<FET87,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR.30*;7-G:60@(DAI9V@B"FUS9W-T<B`B06QT82(*"B,Z(&UE<W-A
M9V4N<&AP.C,P-R!M86EL8F]X+G!H<#HW,#D@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ,@IM<V=I9"`B2&EG:"!0<FEO<FET>2(*;7-G<W1R(")0
M<FEO<FED861E($%L=&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T<B`B06QT[7-S:6UA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-0IM<V=I9"`B2&]W(&1O('EO
M=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_(@IM<V=S='(@(D-O;6\@
M=F]CZB!D97-E:F$@97AI8FER(&%N97AO<S\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`T"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E9"!L
M:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(D-O;6\@871R:6)U:7(@;&EN:&%S
M(&-I=&%D87,@96T@=6UA(')E<W!O<W1A(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T<B`B24U!4"(*"B,Z(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(Y"FUS9VED("))34%0("A!=71O($1E
M=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(DE-05`@*$%U=&\@1&5T96-T87(@
M4')O=&]C;VQO<RDB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE
M8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@(D\@4V5R=FED
M;W(@24U!4"!F96-H;W4@82!C;VYE>.-O.B!O(%-E<G9I9&]R(%)E<W!O;F1E
M=3H@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-2!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!4"!O=F5R(%-33"(*
M;7-G<W1R("))34%0('-O8G)E(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,34R"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C
M97)T:69I8V%T92DB"FUS9W-T<B`B24U!4"!S;V)R92!34TP@*&-E<G1I9FEC
M861O(&%U=&\M87-S:6YA9&\I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHQ-C8*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*
M;7-G<W1R("))34%0('-O8G)E(%-33"`H875T;RUA<W-I;F%D;RDB"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C,V.`IM<V=I9"`B24U!4"!S97)V97(@8VQO
M<V5D('1H92!C;VYN96-T:6]N+B(*;7-G<W1R(")/('-E<G9I9&]R($E-05`@
M9F5C:&]U(&$@8V]N97CC;RXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$V-"!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T,`IM<V=I9"`B24U!
M4"P@;F\@5$Q3(@IM<V=S='(@(DE-05`L('-E;2!43%,B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C0Y"FUS9VED("))34%0+U!/4#,@36%I;"!397)V
M97)S(@IM<V=S='(@(E-E<G9I9&]R97,@9&4@0V]R<F5I;R!)34%0+U!/4#,B
M"@HC.B!L:6(O24U0+G!H<#HX,#0*;7-G:60@(DE.0D]8(@IM<V=S='(@(D-A
M:7AA(&1E($5N=')A9&$B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0Q,0IM
M<V=I9"`B268@=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@
M4$A0(&]P96YS<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B(@HB4V4@
M97-T:79E<B!U=&EL:7IA;F1O(%-33"!O=2!43%,L(&$@97AT96YSXV\@;W!E
M;G-S;"!D;R!02%`@9&5V92!E<W1A<B`B"B)C87)R96=A9&$N(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3(*;7-G:60@
M(DEF('EO=2!C;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H
M<RD@=VEL;"!B92!L;W-T(2(*;7-G<W1R(")4;V1A<R!A<R!M96YS86=E;G,@
M;F$H<RD@<&%S=&$H<RD@<V5RXV\@<&5R9&ED87,A(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T
M<B`B26=N;W)A<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G<W1R("))9VYO<F%R(%1O9&%S
M(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C@*;7-G
M:60@(DEM86=E(@IM<V=S='(@(DEM86=E;2(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+VEM<&]R="YI;F,Z,C`*;7-G:60@(DEM<&]R="(*;7-G<W1R("));7!O
M<G1A<B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C8U"FUS9VED("));7!O<G0@
M2V5Y(@IM<V=S='(@(DEM<&]R=&%R($-H879E(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$S.0IM<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`B
M26UP;W)T87(@4&%R(&1E($-H879E<R(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C(W"FUS9VED("));7!O<G0@365S<V%G97,B"FUS9W-T
M<B`B26UP;W)T87(@365N<V%G96YS(@H*(SH@<&=P+G!H<#HT,0IM<V=I9"`B
M26UP;W)T(%!'4"!+97DB"FUS9W-T<B`B26UP;W)T87(@0VAA=F4@4$=0(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B26UP;W)T
M(%!E<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@(DEM<&]R=&%R($-E<G1I
M9FEC861O<R!097-S;V%I<R(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+
M97DB"FUS9W-T<B`B26UP;W)T87(@0VAA=F4@4')I=F%D82!01U`@4&5S<V]A
M;"(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B
M26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(DEM<&]R
M=&%R($-H879E(%#Z8FQI8V$@4$=0(%!E<W-O86PB"@HC.B!T96UP;&%T97,O
M<VUI;64O:6UP;W)T7VME>2YI;F,Z-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L
M(%,O34E-12!#97)T:69I8V%T97,B"FUS9W-T<B`B26UP;W)T87(@0V5R=&EF
M:6-A9&]S(%,O34E-12!097-S;V%I<R(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS9VED("))
M;7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("));7!O<G1A<B!#:&%V92!0^F)L
M:6-A(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED
M("));7!O<G0@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B26UP;W)T87(@0VAA
M=F4@4/IB;&EC82!01U`B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z.`IM<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S
M='(@(DEM<&]R=&%R($-H879E(%#Z8FQI8V$@4R]-24U%(@H*(SH@<VUI;64N
M<&AP.C$V"FUS9VED("));7!O<G0@4R]-24U%($ME>2(*;7-G<W1R("));7!O
M<G1A<B!#:&%V92!3+TU)344B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O
M<G0N:6YC.CD*;7-G:60@(DEM<&]R="!M8F]X($9I;&4B"FUS9W-T<B`B26UP
M;W)T87(@07)Q=6EV;R!M8F]X(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP
M;W)T+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0@;6)O>"!F
M:6QE("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G<W1R("));7!O<G1A<B!A<G%U
M:79O(&UB;W@@)7,@<&%R82!A('!A<W1A("5S+B(*"B,Z(&UE<W-A9V4N<&AP
M.C4P-2!M86EL8F]X+G!H<#HW,3D@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,38@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*
M;7-G<W1R("));7!O<G1A;G1E(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@(DUE
M;G-A9V5N<R!I;7!O<G1A;G1E<R(*"B,Z(&9O;&1E<G,N<&AP.C$U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"`E9"!M97-S86=E<R!F<F]M("5S
M+B(*;7-G<W1R("(E9"!M96YS86=E;G,@:6UP;W)T861A<R!D92`E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8V"FUS9VED("));B!0<F]C
M97-S(@IM<V=S='(@(E!R;V-E<W-A;F1O(@H*(SH@9F]L9&5R<RYP:'`Z,S8U
M('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,30@;&EB
M+T9O;&1E<BYP:'`Z.#8*(SH@;&EB+T9O;&1E<BYP:'`Z,C$Q(&QI8B])35`N
M<&AP.C,P."!L:6(O24U!4"]4<F5E+G!H<#HQ,3D*(SH@;&EB+TE-05`O5')E
M92YP:'`Z,C(R"FUS9VED("));F)O>"(*;7-G<W1R(")#86EX82!D92!%;G1R
M861A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,@IM<V=I9"`B26YC
M;'5D92!A(&)R:65F('-U;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A(')E<&QY
M/R(*;7-G<W1R("));F-L=6ER('5M(&)R979E(')E<W5M;R!D;R!C86)EYV%L
M:&\@;F$@<F5S<&]S=&$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X
M-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@<F5P;'D_
M(@IM<V=S='(@(DEN8VQU:7(@;65N<V%G96T@;W)I9VEN86P@;F$@<F5S<&]S
M=&$_(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C$@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3,P"FUS9VED("));F9O(@IM
M<V=S='(@(DEN9F]R;6'GXV\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@
M(DEN9F]R;6'GXV\@<V]B<F4@82!#:&%V92!0^F)L:6-A("5S(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED("));F9O<FUA=&EO;B!O;B!0
M97)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("));F9O<FUAY^-O('-O8G)E
M($-H879E(%!R:79A9&$@4&5S<V]A;"(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED("))
M;F9O<FUA=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(DEN
M9F]R;6'GXV\@<V]B<F4@0VAA=F4@4/IB;&EC82!097-S;V%L(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4P,0HC.B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHU-@IM<V=I9"`B26YL:6YE(@IM<V=S='(@(DEN8V]R
M<&]R861O(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.CD*
M;7-G:60@(DEN<V5R="!#97)T:69I8V%T92!(97)E(@IM<V=S='(@(DEN<VER
M82!O($-E<G1I9FEC861O($%Q=6DB"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y($AE<F4B"FUS9W-T<B`B26YS:7)A(&$@0VAA=F4@4')I=F%D82!0
M1U`@4&5S<V]A;"!!<75I(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHQ,`IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y
M($AE<F4B"FUS9W-T<B`B26YS:7)A(&$@0VAA=F4@4/IB;&EC82!01U`@4&5S
M<V]A;"!!<75I(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU
M"FUS9VED("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("))
M;G-I<F$@82!#:&%V92!0^F)L:6-A(%!'4"!!<75I(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0Q,PIM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L
M96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R(")!Y^-O(&EN=N%L
M:61A('-E;&5C:6]N861A('!A<F$@97-T92!C;VUP;VYE;G1E+B(*"B,Z(&UA
M:6QB;W@N<&AP.C4W,"!M86EL8F]X+G!H<#HV,3(*;7-G:60@(DEN=F%L:60@
M061D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!);G;A;&ED;R(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(%)E;6]T92!-
M86EL8F]X(@IM<V=S='(@(D-A:7AA(%!O<W1A;"!296UO=&$@:6YVX6QI9&$B
M"@HC.B!C;VUP;W-E+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV
M86QI9"!C:&%R86-T97(@:6X@92UM86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R
M(")#87)A8W1E<B!I;G;A;&ED;R!N;R!E;F1E<F7G;R!D92!E+6UA:6PZ("5S
M+B(*"B,Z('-M:6UE+G!H<#HW."!P9W`N<&AP.C$V"FUS9VED("));G9A;&ED
M(&ME>2(*;7-G<W1R(")#:&%V92!I;G;A;&ED82(*"B,Z('!G<"YP:'`Z,3DR
M"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS
M9W-T<B`B0VAA=F4@4')I=F%D82!01U`@4&5S<V]A;"!I;G;A;&ED82XB"@HC
M.B!P9W`N<&AP.C$V-PIM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B
M;&EC(&ME>2XB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82!01U`@4&5S<V]A;"!I
M;G;A;&ED82XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R
M"FUS9VED("));G9E<G0B"FUS9W-T<B`B26YV97)T97(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU.3$*;7-G:60@(DM"(@IM<V=S='(@
M(DM"(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y
M($QE;F=T:"(*;7-G<W1R(")486UA;FAO(&1A($-H879E(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I9"`B(@HB2V5Y(&=E;F5R871I;VX@
M;6%Y('1A:V4@82!L;VYG('1I;64@=&\@8V]M<&QE=&4N("!#;VYT:6YU92!W
M:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*;7-G<W1R("(B"B)!(&=E<F'GXV\@
M9&4@8VAA=F4@9&5V92!L979A<B!M=6ET;R!T96UP;R!P87)A('1E<FUI;F%R
M+B!#;VYT:6YU87(@8V]M(&$@(@HB9V5R8>?C;R!D92!C:&%V93\B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&
M:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BXB"FUS
M9W-T<B`B(@HB02!I;7!O<G1AY^-O(&[C;R!E<W3A(&1I<W!O;NUV96PN($\@
M96YV:6\@9&4@87)Q=6EV;W,@;N-O(&5S=.$@:&%B:6QI=&%D;R`B"B)N97-T
M92!S97)V:61O<BXB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R
M="!I<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@
M9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@HB
M02!I;7!O<G1AY^-O(&[C;R!E<W3A(&1I<W!O;NUV96PN(%9O8^H@;N-O('1E
M;2!U;2!C873A;&]G;R!D92!E;F1E<F7G;W,@(@HB9&5F:6YI9&\@<&%R82!A
M9&EC:6]N87(@<V5U<R!C;VYT871O<RXB"@HC.B!P9W`N<&AP.C,Q-`IM<V=I
M9"`B2V5Y('-U8V-E<W-F=6QL>2!S96YT('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R(")#:&%V92!E;G9I861A(&-O;2!S=6-E<W-O('!A<F$@
M;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,34*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(DED:6]M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.34*;7-G:60@
M(DQA<W0@36%I;&)O>"!086=E(@IM<V=S='(@(MIL=&EM82!0X6=I;F$@9&$@
M4&%S=&$B"@HC.B!M86EL8F]X+G!H<#HS-#$*;7-G:60@(DQA<W0@4&%G92(*
M;7-G<W1R("+:;'1I;6$@4.%G:6YA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-30Y"FUS9VED("),:6YK($%T=&%C:&UE;G1S/R(*;7-G
M<W1R(")#<FEA<B!L:6YK<R!P87)A($%N97AO<S\B"@HC.B!A='1A8VAM96YT
M+G!H<#HS-"!L:6(O0V]M<&]S92YP:'`Z,3`X-`IM<V=I9"`B3&EN:V5D(&%T
M=&%C:&UE;G1S(&%R92!F;W)B:61D96XN(@IM<V=S='(@(DQI;FMS(&1E(&%N
M97AO<R!NXV\@<^-O('!E<FUI=&ED;W,N(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C$Q,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL;"!E>'!I<F4@
M;VX@)7,B"FUS9W-T<B`B3W,@;&EN:W,@97AP:7)A<N-O(&5M("5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-S$*;7-G:60@(B(*(DQI<W0@86QL
M(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H
M:68@9&ES86)L960L('EO=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H
M870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@HB3&ES
M=&%R('1O9&]S(&-O;G1A=&]S('%U86YD;R!C87)R96=A<B!A('1E;&$@9&4@
M8V]N=&%T;W,_("AS92!D97-A8FEL:71A9&\L("(*(G9O8^H@=F5RX2!S;VUE
M;G1E(&-O;G1A=&]S('%U92!V;V/J(&5X<&QI8VET86UE;G1E('!E<W%U:7-A
M<BDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@R"FUS9VED("),:7-T
M:6YG(&EN('1H92!(96%D97(B"FUS9W-T<B`B3&ES=&%N9&\@;F\@0V%B9>=A
M;&AO(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P"FUS
M9VED("),;V-A;"!-86EL8F]X.B(*;7-G<W1R(")#86EX82!0;W-T86P@3&]C
M86PZ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W,0IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`B4F5G:>-O(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,C0*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")#;VYE8W1A
M<B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&]G(&EN('1O("5S(@IM<V=S='(@(D-O;F5C=&%R(&$@)7,B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S.`IM<V=I9"`B3&]G
M:6XB"FUS9W-T<B`B0V]N96-T87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(E1A<F5F87,@9&4@
M0V]N97CC;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y
M-@IM<V=I9"`B3&]W(@IM<V=S='(@(D)A:7AA(@H*(SH@;65S<V%G92YP:'`Z
M,S`Y(&UA:6QB;W@N<&AP.C<Q,B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N
M:6YC.C$S"FUS9VED("),;W<@4')I;W)I='DB"FUS9W-T<B`B4')I;W)I9&%D
M92!"86EX82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y
M-PIM<V=I9"`B3&]W97-T(@IM<V=S='(@(D)A:7CM<W-I;6$B"@HC.B!L:6(O
M34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0T"FUS9VED(")-86-I;G1O
M<V@@1FEL92(*;7-G<W1R(")!<G%U:79O($UA8VEN=&]S:"(*"B,Z('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PIM<V=I9"`B36%I;"(*;7-G
M<W1R(")#;W)R96EO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS
M9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(E!RZ2UV:7-U86QI>F'GXV\@
M9&4@365N<V%G96YS(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?
M<V5L96-T+FEN8SHQ-@IM<V=I9"`B36%I;"!S97)V97(@='EP92!T;R!C;VYN
M96-T('1O.B(*;7-G<W1R(")4:7!O(&1E('-E<G9I9&]R(&1E(&-O<G)E:6\@
M82!C;VYE8W1A<CHB"@HC.B!F;VQD97)S+G!H<#HS-CD@9F]L9&5R<RYP:'`Z
M,S@S"FUS9VED(")-86EL8F]X(@IM<V=S='(@(D-A:7AA(%!O<W1A;"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*;7-G:60@(DUA:6QB;W@@86YD
M($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1E(%9I
M<W5A;&EZ8>?C;R!D92!#86EX82!0;W-T86P@92!087-T87,B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@
M365S<V%G97,@:6X@1F]L9&5R(&%S(%-E96XB"FUS9W-T<B`B36%R8V%R(&-O
M;6\@3&ED87,@5&]D87,@87,@365N<V%G96YS(&YA(%!A<W1A(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL
M($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T<B`B36%R8V%R
M(&-O;6\@3N-O($QI9&%S(%1O9&%S(&%S($UE;G-A9V5N<R!N82!087-T82(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-2!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-87)K(&%S
M.B(*;7-G<W1R(")-87)C87(@8V]M;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C,X"FUS9VED(")-87)K(&1I9F9E<F5N="!L979E;',@;V8@<75O
M=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_(@IM<V=S='(@(DUA<F-A<B!D
M:69E<F5N=&5S(&[M=F5I<R!D92!C:71AY^-O(&-O;2!D:69E<F5N=&5S(&-O
M<F5S/R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,`IM
M<V=I9"`B36%R:R!M97-S86=E<R!A<R!S965N/R`H24U!4"!O;FQY*2(*;7-G
M<W1R(")-87)C87(@;65N<V%G96YS(&-O;6\@;&ED87,_("AS;VUE;G1E($E-
M05`I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T-@IM<V=I9"`B36%R
M:R!S:6UP;&4@;6%R:W5P/R(*;7-G<W1R(")297-S86QT87(@;6%R8V%D;W(@
M<VEM<&QE<S\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#D*
M;7-G:60@(DUA=&-H($%L;"!1=65R:65S(@IM<V=S='(@(D-O:6YC:61I<B!T
M;V1A<R(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT-0IM<V=I
M9"`B36%T8V@@06YY(%%U97)Y(@IM<V=S='(@(D-O:6YC:61I<B!Q=6%L<75E
M<B!U;6$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#<*
M;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM<V=S='(@(E1A;6%N
M:&\@3>%X:6UO(&1E($%N97AO(@H*(SH@;&EB+V%P:2YP:'`Z-SD*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B"FUS9W-T<B`B3OIM97)O($WA
M>&EM;R!D92!087-T87,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT.#D*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S
M(')E86-H960N(@IM<V=S='(@(D[Z;65R;R!MX7AI;6\@9&4@86YE>&]S(&%T
M:6YG:61O+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X
M-0IM<V=I9"`B36%X:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE
M9"XB"FUS9W-T<B`B5&%M86YH;R!MX7AI;6\@9&4@86YE>&]S(&%T:6YG:61O
M+B(*"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,*;7-G:60@(DUE
M;G4@1F]L9&5R($QI<W0B"FUS9W-T<B`B365N=2!D92!,:7-T82!D92!087-T
M87,B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0R"FUS9VED(")-97-S86=E(@IM
M<V=S='(@(DUE;G-A9V5M(@H*(SH@8V]M<&]S92YP:'`Z-3DX(&-O;7!O<V4N
M<&AP.C8R-2!C;VUP;W-E+G!H<#HV-SD@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P"FUS9VED(")-97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@(D-O;7!O
M<VGGXV\@9&4@365N<V%G96TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`V"FUS9VED(")-97-S86=E($1A=&4B"FUS9W-T<B`B1&%T82!D82!-96YS
M86=E;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PIM<V=I9"`B365S<V%G92!/
M<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!-96YS86=E;2(*"B,Z('-E87)C
M:"YP:'`Z,S`V"FUS9VED(")-97-S86=E(%-E87)C:"(*;7-G<W1R(")097-Q
M=6ES87(@365N<V%G96YS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ
M,`IM<V=I9"`B365S<V%G92!3:7IE(@IM<V=S='(@(E1A;6%N:&\@9&$@365N
M<V%G96TB"@HC.B!M97-S86=E+G!H<#HS.3$*;7-G:60@(DUE<W-A9V4@4V]U
M<F-E(@IM<V=S='(@(D/S9&EG;R!&;VYT92!D82!-96YS86=E;2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G92!6:65W:6YG
M(@IM<V=S='(@(E9I<W5A;&EZ8>?C;R!D82!-96YS86=E;2(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z-@IM<V=I9"`B365S<V%G92!F;&%G<R(*
M;7-G<W1R(")-87)C861O<F5S(&1A(&UE;G-A9V5M(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM
M<V=S='(@(E!A<W1A<R!D92!M96YS86=E;2(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B365S<V%G92!F<F]M("5S(@IM
M<V=S='(@(DUE;G-A9V5M(&1E("5S(@H*(SH@;6%I;&)O>"YP:'`Z-C4S"FUS
M9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R(")!(&UE;G-A
M9V5M('1E;2!A;F5X;W,B"@HC.B!M86EL8F]X+G!H<#HV-#0*;7-G:60@(DUE
M<W-A9V4@:7,@96YC<GEP=&5D(@IM<V=S='(@(D$@;65N<V%G96T@97-TX2!C
M<FEP=&]G<F%F861A(@H*(SH@;6%I;&)O>"YP:'`Z-C,Y"FUS9VED(")-97-S
M86=E(&ES('-I9VYE9"(*;7-G<W1R(")!(&UE;G-A9V5M(&5S=.$@87-S:6YA
M9&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S8*;7-G:60@
M(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R(")-96YS86=E;2!C;W)R97-P;VYD
M92(*"B,Z(&-O;7!O<V4N<&AP.C@V-"!C;VUP;W-E+G!H<#HX-S$*;7-G:60@
M(DUE<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DUE
M;G-A9V5M(')E9&ER96-I;VYA9&$@8V]M('-U8V5S<V\N(@H*(SH@8V]M<&]S
M92YP:'`Z,3$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@
M<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@(DUE
M;G-A9V5M(&5N=FEA9&$@8V]M('-U8V5S<V\L(&UA<R!NXV\@9F]I('-A;'9A
M(&5M("5S(@H*(SH@8V]M<&]S92YP:'`Z,3$X,2!C;VUP;W-E+G!H<#HQ,3@Y
M"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")-
M96YS86=E;2!E;G9I861A(&-O;2!S=6-E<W-O+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,S`*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H
M92!M86EL8F]X('9I97<N(@IM<V=S='(@(DUE;G-A9V5N<R!P;W(@<.%G:6YA
M(&YA('9I<W5A;&EZ8>?C;R!D82!C86EX82!P;W-T86PN(@H*(SH@;6%I;&)O
M>"YP:'`Z,S`X"FUS9VED(")-97-S86=E<R!T;R(*;7-G<W1R(")-96YS86=E
M;G,@<&%R82(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I9"`B
M36]D:69Y(@IM<V=S='(@(D%L=&5R87(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E>'!A;F0N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA
M;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R
M(")-86ES(&1E('5M(&5N9&5R9>=O(&5N8V]N=')A9&\@;F\@8V%M<&\@)R5S
M)RXB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO
M=F4B"FUS9W-T<B`B36]V97(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,38*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")!8F%I
M>&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`V"FUS9VED(")-;W9E
M('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE
M<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(B(*(DUO=F5R('-P86US('!A<F$@
M82!P87-T82!S<&%M(&4@;65N<V%G96YS(&EN;V-E;G1E<R!P87)A(&$@0V%I
M>&$@9&4@16YT<F%D82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU
M,`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B36]V97(@<&%R82!A
M('!A<W1A(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S$T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(D%C:6UA(@H*(SH@;&EB+TU)
M344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R
M="]A;'1E<FYA=&EV92(*;7-G<W1R(")-=6QT:7!A<G0O86QT97)N871I=F4B
M"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z,34W"FUS9VED(")-=6QT
M:7!L92!-97-S86=E(%9I97<B"FUS9W-T<B`B5FES=6%L:7IAY^-O(&1E($WZ
M;'1I<&QA<R!-96YS86=E;G,B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L
M='-E87)C:'-E;&5C="YI;F,Z.`IM<V=I9"`B3D].12(*;7-G<W1R(").14Y(
M54TB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR"FUS9VED(").3U1%(@IM<V=S='(@(DY/5$$B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S."!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C@S"FUS9VED(").86UE(@IM<V=S='(@(DYO;64B"@HC.B!P
M9W`N<&AP.C$P-@IM<V=I9"`B3F%M92!A;F0O;W(@96UA:6P@8V%N;F]T(&)E
M(&5M<'1Y(@IM<V=S='(@(DYO;64@92]O=2!E+6UA:6P@;N-O('!O9&4@<V5R
M('9A>FEO(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W,0IM<V=I
M9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(DYE8V5S<VET82!D92!!Y^-O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S8W"FUS9VED(").979E<B(*;7-G<W1R(").=6YC82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C`*;7-G:60@(DYE=F5R('-A=F4@871T
M86-H;65N=',B"FUS9W-T<B`B3G5N8V$@<V%L=F%R(&%N97AO<R(*"B,Z('1E
M;7!L871E<R]A8VPO86-L+FEN8SHQ,C0*;7-G:60@(DYE=R(*;7-G<W1R(").
M;W9A(@H*(SH@;&EB+TE-4"YP:'`Z-38Y"FUS9VED(").97<@1F]L9&5R(@IM
M<V=S='(@(DYO=F$@4&%S=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#@*;7-G:60@(DYE=R!-86EL(@IM<V=S='(@(DYO=F$@365N<V%G96TB"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C(R"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C0V"FUS9VED
M(").97<@365S<V%G92(*;7-G<W1R(").;W9A($UE;G-A9V5M(@H*(SH@;6%I
M;&)O>"YP:'`Z-S8Q(&QI8B]-24U%+TAE861E<G,N<&AP.C$X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R(").;W9A
M($UE;G-A9V5M('!A<F$@)7,B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C$Y"FUS9VED(").97<@;65S<V%G97,B"FUS9W-T<B`B3F]V87,@;65N
M<V%G96YS(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S
M,PIM<V=I9"`B3F5X="(*;7-G<W1R(")0<O-X:6UA(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHS,PIM<V=I9"`B3F5X="!-
M97-S86=E(@IM<V=S='(@(E!R\WAI;6$@365N<V%G96TB"@HC.B!M86EL8F]X
M+G!H<#HS,SD*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(")0<O-X:6UA(%#A
M9VEN82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,"!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-3,*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B3N-O(@H*(SH@
M<VUI;64N<&AP.C(R,@IM<V=I9"`B3F\@0V5R=&EF:6-A=&4@9F]U;F0B"FUS
M9W-T<B`B3F5N:'5M($-E<G1I9FEC861O(&5N8V]N=')A9&\B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N
M8W)Y<'1I;VXB"FUS9W-T<B`B4V5M($-R:7!T;V=R869I82(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHQ.0IM<V=I9"`B3F\@2V5Y<R!I;B!+97ER:6YG
M(@IM<V=S='(@(E-E;2!#:&%V97,@;F\@0VAA=F5I<F\B"@HC.B!M86EL8F]X
M+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B"FUS
M9W-T<B`B4V5M($UE;G-A9V5N<R(*"B,Z('!G<"YP:'`Z,3,S"FUS9VED(").
M;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B3F5N:'5M82!C
M:&%V92!P^F)L:6-A(%!'4"!I;7!O<G1A9&$N(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHX-`IM<V=I9"`B3F\@4&5R<V]N86P@0V5R=&EF:6-A
M=&4@4')E<V5N="(*;7-G<W1R(").96YH=6T@0V5R=&EF:6-A9&\@4&5S<V]A
M;"!0<F5S96YT92(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,3D*;7-G:60@(DYO
M(%!R979I97<@5&5X="(*;7-G<W1R(")396T@4'+I+79I<W5A;&EZ8>?C;R!D
M92!497AT;R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G
M:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(DYE;FAU;6$@0VAA
M=F4@4/IB;&EC82!%;F-O;G1R861A(@H*(SH@<VUI;64N<&AP.C$T-PIM<V=I
M9"`B3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DYE
M;FAU;6$@8VAA=F4@</IB;&EC82!3+TU)344@:6UP;W)T861A+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]T;F5F+G!H<#HY,@IM<V=I9"`B3F\@871T86-H;65N
M=',@9F]U;F0N(@IM<V=S='(@(DYE;FAU;2!A;F5X;R!E;F-O;G1R861O+B(*
M"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"FUS9VED(").;R!E;6%I;"!I
M;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+B(*;7-G<W1R
M(").96YH=6T@92UM86EL(&5N8V]N=')A9&\@;F$@8VAA=F4@</IB;&EC82XB
M"@HC.B!A8VPN<&AP.C<Q(&%C;"YP:'`Z.3<*;7-G:60@(DYO(&9O;&1E<B!S
M96QE8W1E9"XB"FUS9W-T<B`B3F5N:'5M82!P87-T82!S96QE8VEO;F%D82XB
M"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30V"FUS9VED(").;R!F;VQD
M97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T<B`B
M3F]V87,@;65N<V%G96YS(&[C;R!E<W3C;R!S96YD;R!V97)I9FEC861A<R!E
M;2!N96YH=6UA('!A<W1A+B(*"B,Z(&9O;&1E<G,N<&AP.C(P,2!L:6(O1F]L
M9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED(").;R!F;VQD
M97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(DYE;FAU;6$@<&%S=&$@9F]I
M(&5S<&5C:69I8V%D82(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-3(*
M;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T<B`B
M3F5N:'5M82!P87-T82!C;VT@;F]V87,@;65N<V%G96YS(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C$T.0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H('5N
M<V5E;B!M97-S86=E<R(*;7-G<W1R(").96YH=6UA('!A<W1A(&-O;2!M96YS
M86=E;G,@;N-O(&QI9&%S(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S-@IM<V=I
M9"`B3F\@;65S<V%G92!B;V1Y('1E>'0B"FUS9W-T<B`B3F5N:'5M('1E>'1O
M(&YO(&-O<G!O(&1A(&UE;G-A9V5M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H
M<#HU-CD*;7-G:60@(DYO(&UE<W-A9V4@<F5T=7)N960N(@IM<V=S='(@(DYE
M;FAU;6$@;65N<V%G96T@<F5T;W)N861A+B(*"B,Z(&QI8B]-86EL8F]X+G!H
M<#HS-C(*;7-G:60@(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N
M(@IM<V=S='(@(DYE;FAU;6$@;65N<V%G96T@8V]R<F5S<&]N9&5U(&$@<W5A
M('!E<W%U:7-A+B(*"B,Z('!G<"YP:'`Z,3@U"FUS9VED(").;R!P97)S;VYA
M;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N(@IM<V=S='(@(DYE;FAU;6$@
M8VAA=F4@<')I=F%D82!01U`@<&5S<V]A;"!F;VD@:6UP;W)T861A+B(*"B,Z
M('!G<"YP:'`Z,38Q"FUS9VED(").;R!P97)S;VYA;"!01U`@<'5B;&EC(&ME
M>2!I;7!O<G1E9"XB"FUS9W-T<B`B3F5N:'5M82!C:&%V92!P^F)L:6-A(%!'
M4"!P97-S;V$@9F]I(&EM<&]R=&%D82XB"@HC.B!S;6EM92YP:'`Z,3DW"FUS
M9VED(").;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D
M+B(*;7-G<W1R(").96YH=6T@8V5R=&EF:6-A9&\@4R]-24U%('!E<W-O86P@
M9F]I(&EM<&]R=&%D;RXB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C(T-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3D*;7-G:60@(B(*(DYO
M('!E<G-O;F%L('!R:79A=&4@:V5Y(&5X:7-T<R!S;R!T:&4@;65S<V%G92!I
M<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B"B).XV\@97AI
M<W1E('5M82!C:&%V92!P97-S;V%L('!R:79A9&$L(&1E=FED;R!A(&ES<V\@
M82!M96YS86=E;2!NXV\@<&]D92!S97(@(@HB9&5S8W)I<'1O9W)A9F%D82XB
M"@HC.B!S<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").;R!S<&5L;&-H96-K:6YG
M('!R;V=R86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`B3F5N:'5M('!R;V=R86UA
M(&1E('9E<FEF:6-AY^-O(&1E(&]R=&]G<F%F:6$@9F]I(&-O;F9I9W5R861O
M+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT.`IM<V=I
M9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@(DYE;FAU;2!E<G)O(&1E
M(&]R=&]G<F%F:6$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G<W1R(")396T@<W5G
M97-T]65S(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-C$*;7-G:60@(DYO
M('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!C;W5L9"!B
M92!F;W5N9"XB"FUS9W-T<B`B3F5N:'5M('-U<&]R=&4@82!MZ71O9&]S(&1E
M(&%U=&5N=&EC8>?C;R!)34%0(&9O:2!E;F-O;G1R861O+B(*"B,Z(&%C;"YP
M:'`Z-C<@86-L+G!H<#HY,PIM<V=I9"`B3F\@=7-E<B!S<&5C:69I960N(@IM
M<V=S='(@(DYE;FAU;2!U<W7A<FEO(&5S<&5C:69I8V%D;RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S`T"FUS9VED(").;VX@4&%R=&EC:7!A
M;G0B"FUS9W-T<B`B4V5M(%!A<G1I8VEP86YT97,B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C$Q('1E;7!L871E<R]P<F5F<R]F;VQD97)S
M96QE8W0N:6YC.C(T"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C
M="YI;F,Z-#`@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T('1E;7!L871E
M<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,C0*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8V,0IM<V=I9"`B3F]N92(*;7-G<W1R(").96YH=6UA(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDU"FUS9VED(").
M;W)M86PB"FUS9W-T<B`B3F]R;6%L(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Y
M"FUS9VED(").;W0@1&5L971E9"(*;7-G<W1R(").XV\@17AC;'7M9&$B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$R('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM<V=S='(@
M(D[C;R!287-C=6YH;R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$W
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@(DYO
M="!);7!O<G1A;G0B"FUS9W-T<B`B3N-O($EM<&]R=&%N=&4B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(U"FUS9VED(").;W0@4&5R<V]N
M86PB"FUS9W-T<B`B3N-O(%!E<W-O86PB"@HC.B!L:6(O0W)Y<'0O4$=0+G!H
M<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H<#HQ,S0@;&EB+T-R>7!T+U--24U%
M+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A;&ED('!U8FQI8R!K97DN(@IM<V=S
M='(@(D[C;R#I('5M82!C:&%V92!P^F)L:6-A(';A;&ED82XB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED(").;W0@9&5L971E9"!M
M97-S86=E<R(*;7-G<W1R(")-96YS86=E;G,@;N-O(&5X8VQU[61A<R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-3$*;7-G:60@(DYO="!I;7!O
M<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B365N<V%G96YS(&[C;R!I;7!O<G1A
M;G1E<R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I
M;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@
M=&EM92(*;7-G<W1R(").;W1E('%U92!I<W1O('!O9&4@;&5V87(@86QG=6T@
M=&5M<&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`T"FUS9VED(").
M;W1H:6YG(@IM<V=S='(@(DYA9&$B"@HC.B!A='1A8VAM96YT+G!H<#HX.0IM
M<V=I9"`B3F]T:69I8V%T:6]N.B!,:6YK960@871T86-H;65N="!D;W=N;&]A
M9&5D(@IM<V=S='(@(DYO=&EF:6-AY^-O.B!!;F5X;R!B86EX861O(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B3G5M8F5R(&]F(&UO
M;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L971I
M;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HB3OIM97)O(&1E(&UE<V5S('!A<F$@
M;6%N=&5R(&QI;FMS(&1E(&%N97AO<R!A;G1I9V]S('-E(&5S=&EV97(@97AC
M;'5I;F1O("(*(FUE;G-A;&UE;G1E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-3D*;7-G:60@(DYU;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E
M<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+B(*;7-G<W1R("(B"B).
M^FUE<F\@9&4@<&%S=&%S(&%N=&EG87,@9&4@;65N<V%G96YS(&5N=FEA9&%S
M(&$@;6%N=&5R('-E(&5S=&EV97(@97AC;'5I;F1O("(*(FUE;G-A;&UE;G1E
M+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T"FUS
M9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE
M;&1S+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.0HC
M.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*
M;7-G<W1R(")/52(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,34*
M;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R(")-96YS86=E;G,@86YT:6=A
M<R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E
M:6YG('!U<F=E9"XB"FUS9W-T<B`B07,@<&%S=&%S(&%N=&EG87,@9&4@;65N
M<V%G96YS(&5N=FEA9&%S(&5S=.-O('-E;F1O(&5X8VQU[61A<RXB"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C@*;7-G:60@(D]N;'D@9&ES<&QA>2!F
M;VQD97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@
M(D5X:6)I<B!S;VUE;G1E('!A<W1A<R!C;VT@;65N<V%G96YS(&[C;R!L:61A
M<S\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C@Q"FUS
M9VED(")/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T
M:&ES(&%C=&EO;BXB"FUS9W-T<B`B4V]M96YT92!U;6$@<&%S=&$@9&5V92!S
M97(@<V5L96-I;VYA9&$@<&%R82!E<W1A(&'GXV\N(@H*(SH@=&5M<&QA=&5S
M+VUE;G4N:6YC.C$P('1E;7!L871E<R]M96YU+FEN8SHS,`IM<V=I9"`B3W!E
M;B!&;U]L9&5R(@IM<V=S='(@(D%B<FER(%]087-T82(*"B,Z(&9O;&1E<G,N
M<&AP.C0P.`IM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G<W1R(")087-T82!!
M8F5R=&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`P"FUS9VED
M(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G<W1R(")087)T:6-I<&'GXV\@
M3W!C:6]N86PB"@HC.B!F971C:&UA:6PN<&AP.C0S('1E;7!L871E<R]F971C
M:&UA:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM
M86EL+FEN8SHV"FUS9VED(")/=&AE<B!-86EL($%C8V]U;G1S(@IM<V=S='(@
M(D]U=')A<R!#;VYT87,@9&4@0V]R<F5I;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D]U
M=')A<R!/<.?U97,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P
M,`IM<V=I9"`B3W5T8F]U;F0@4V5R=F5R(@IM<V=S='(@(E-E<G9I9&]R(&1E
M($5N=FEO(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ-B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C0*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,C`S(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(X.0IM<V=I
M9"`B4$=0(@IM<V=S='(@(E!'4"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N
M8W)Y<'1?;&ES="YI;F,Z-PIM<V=I9"`B4$=0($5N8W)Y<'0@365S<V%G92(*
M;7-G<W1R(")-96YS86=E;2!#<FEP=&]G<F%F861A(&-O;2!01U`B"@HC.B!C
M;VUP;W-E+G!H<#HS,S4*;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S='(@(D5R
M<F\@9&\@4$=0.B`B"@HC.B!C;VUP;W-E+G!H<#HS,30*;7-G:60@(E!'4"!%
M<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME
M>2XB"FUS9W-T<B`B17)R;R!D;R!01U`Z(%-E;FAA(&YE8V5S<^%R:6$@<&%R
M82!A(&-H879E('!R:79A9&$@<&5S<V]A;"XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30R"FUS9VED(")01U`@3W!T:6]N<R(*;7-G<W1R(")/<.?U
M97,@9&4@4$=0(@H*(SH@<&=P+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A
M<V4@26YP=70B"FUS9W-T<B`B16YT<F%D82!D82!396YH82!D;R!01U`B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA
M;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN(@IM<V=S='(@(E-U<&]R=&4@82!087(@9&4@0VAA=F5S(%!'4"!0
M97-S;V%I<R!R97%U97(@=6UA(&-O;F5XXV\@=V5B('-E9W5R82XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S(*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(%1E>'0B"FUS9W-T<B`B5&5X=&\@9&$@0VAA=F4@4/IB;&EC82!01U`B
M"@HC.B!P9W`N<&AP.C$T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B
M;&EC($ME>2!F;W(@7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"XB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82!01U`@9&4@7"(E<R`H)7,I7"(@
M9F]I(&%D:6-I;VYA9&$@8V]M('-U8V5S<V\N(@H*(SH@<&=P+G!H<#HR-#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<
M(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(D-H879E(%#Z
M8FQI8V$@4$=0(&1E(%PB)7-<(B!F;VD@97AC;'7M9&$@8V]M('-U8V5S<V\N
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B
M;&EC($ME>7)I;F<B"FUS9W-T<B`B0VAA=F5I<F\@4/IB;&EC;R!01U`B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*;7-G:60@
M(E!'4"!3:6=N($UE<W-A9V4B"FUS9W-T<B`B365N<V%G96T@07-S:6YA9&$@
M8V]M(%!'4"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI
M;F,Z.0IM<V=I9"`B4$=0(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@
M(DUE;G-A9V5M($%S<VEN861A+T-R:7!T;V=R869A9&$@8V]M(%!'4"(*"B,Z
M('!G<"YP:'`Z,3DX"FUS9VED(")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U
M;&QY(&%D9&5D+B(*;7-G<W1R(")#:&%V92!P<FEV861A(%!'4"!A9&EC:6]N
M861A(&-O;2!S=6-E<W-O+B(*"B,Z('!G<"YP:'`Z,3<S"FUS9VED(")01U`@
M<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(D-H879E
M('#Z8FQI8V$@4$=0(&%D:6-I;VYA9&$@8V]M('-U8V5S<V\N(@H*(SH@=&5M
M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E!'4"!S=7!P;W)T
M(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R(")3=7!O<G1E
M(&$@4$=0(&5S=.$@9&5S86)I;&ET861O(&YE<W1E('-I<W1E;6$N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`W"FUS9VED("(B"B)01U`@<W5P
M<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S
M:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M("(B"B)3=7!O<G1E(&$@4$=0(&[C;R!E<W3A(&%T=6%L;65N=&4@871I=F\L
M('-E;F1O(&%S<VEM(&[C;R#I('!O<W/M=F5L("(*(G9E<FEF:6-A<B!A(&%S
M<VEN871U<F$@9&EG:71A;"XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HR.30*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@
M86-T:79E('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T
M960N(@IM<V=S='(@(B(*(E-U<&]R=&4@82!01U`@;N-O(&5S=.$@871U86QM
M96YT92!A=&EV;RP@<V5N9&\@87-S:6T@;N-O(.D@<&]S<^UV96P@(@HB9&5S
M8W)I<'1O9W)A9F%R(&$@;65N<V%G96TN(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C(*;7-G:60@(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S('!O<'5P
M('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R!C=7)R
M96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU
M<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H92!01U`@(@HB9F5A
M='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(E-U
M<&]R=&4@82!01U`@<F5Q=65R('%U92!J86YE;&%S('!O<"UU<"!S96IA;2!U
M=&EL:7IA9&%S+B`@4V4@<V5U(&YA=F5G861O<B`B"B)E<W3A(&%T=6%L;65N
M=&4@8V]N9FEG=7)A9&\@<&%R82!B;&]Q=65A<B!P;W`M=7!S+"!V;V/J(&1E
M=F4@86QT97)A<B!E<W1A("(*(F-O;F9I9W5R8>?C;R!O=2!A<R!F=6[G]65S
M(%!'4"!NXV\@9G5N8VEO;F%RXV\@8V]R<F5T86UE;G1E+B(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM<V=S='(@(E!/
M4#,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B4$]0
M,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R(")03U`S("A!=71O
M($1E=&5C=&%R(%!R;W1O8V]L;W,I(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ,3<*;7-G:60@(E!/4#,@;W9E<B!34TPB"FUS9W-T<B`B4$]0,R!S
M;V)R92!34TPB"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM<V=I
M9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM
M<V=S='(@(E!/4#,@<V]B<F4@4U-,("AC97)T:69I8V%D;R!A=71O+6%S<VEN
M861O*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38X"FUS9VED
M(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B4$]0,R!S
M;V)R92!34TP@*&%U=&\M87-S:6YA9&\I(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R(")03U`S
M+"!S96T@5$Q3(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHR
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")086=E("5D(&]F("5D(@IM<V=S='(@
M(E#A9VEN82`E9"!D92`E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M.3(*;7-G:60@(E!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4B
M"FUS9W-T<B`B4.%G:6YA(&-O;2!A<R!-96YS86=E;G,@3N-O($QI9&%S(%!R
M:6UE:7)O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y,PIM<V=I9"`B
M4&%G92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(E#A
M9VEN82!C;VT@87,@365N<V%G96YS($[C;R!,:61A<R!P;W(@VFQT:6UO(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A
M<G0H<RDB"FUS9W-T<B`B4&%R=&4H<RDB"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,3(S"FUS9VED(")087-S<&AR87-E(@IM<V=S='(@(E-E;FAA(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R.`IM<V=I9"`B4&%S<W!H<F%S
M92`H06=A:6XI(@IM<V=S='(@(E-E;FAA("A.;W9A;65N=&4I(@H*(SH@<VUI
M;64N<&AP.C(S,2!P9W`N<&AP.C,P-@IM<V=I9"`B4&%S<W!H<F%S92!S=6-C
M97-S9G5L;'D@=6YL;V%D960N(@IM<V=S='(@(E-E;FAA(&1E<V-A<G)E9V%D
M82!C;VT@<W5C97-S;RXB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S
M92YI;F,Z,3@@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHR.0IM<V=I
M9"`B4&%S<W!H<F%S93HB"FUS9W-T<B`B4V5N:&$Z(@H*(SH@<&=P+G!H<#HQ
M,#@*;7-G:60@(E!A<W-P:')A<V5S(&-A;FYO="!B92!E;7!T>2(*;7-G<W1R
M(")!<R!S96YH87,@;N-O('!O9&5M(&5S=&%R(&5M(&)R86YC;R(*"B,Z('!G
M<"YP:'`Z,3$P"FUS9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS
M9W-T<B`B07,@<V5N:&%S(&[C;R!C;VEN8VED96TB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z,C`@=&5M<&QA=&5S+W-M:6UE+VEM<&]R
M=%]K97DN:6YC.C<Q"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3DQ
M"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")396YH82(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`IM<V=I9"`B4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")%>&5C=71A
M<B!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!A;R!C;VYE8W1A<C\B"@HC.B!A
M8VPN<&AP.C<U(&%C;"YP:'`Z,3`Q"FUS9VED(")097)M:7-S:6]N<R!F;W(@
M=&AI<R!U<V5R(&-A;FYO="!B92!C:&%N9V5D+B(*;7-G<W1R(")!<R!P97)M
M:7-S]65S('!A<F$@97-T92!U<W7A<FEO(&[C;R!P;V1E;2!S97(@86QT97)A
M9&%S+B(*"B,Z(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HV.#@@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R(")0
M97-S;V%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")0
M97)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUAY_5E<R!097-S
M;V%I<R(*"B,Z('!G<"YP:'`Z,3$V"FUS9VED(")097)S;VYA;"!01U`@:V5Y
M<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")087(@9&4@
M0VAA=F5S(%!'4"!097-S;V%L(&=E<F%D82!C;VT@<W5C97-S;RXB"@HC.B!P
M9W`N<&AP.C$R,PIM<V=I9"`B4&5R<V]N86P@4$=0(&ME>7,@9&5L971E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(D-H879E<R!01U`@4&5S<V]A:7,@97AC
M;'7M9&%S(&-O;2!S=6-E<W-O+B(*"B,Z('-M:6UE+G!H<#HR,#,*;7-G:60@
M(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@3D]4(&EM<&]R=&5D.B`B
M"FUS9W-T<B`B0V5R=&EF:6-A9&]S(%,O34E-12!097-S;V%I<R!.PT\@9F]R
M86T@:6UP;W)T861O<SH@(@H*(SH@<VUI;64N<&AP.C$R.`IM<V=I9"`B4&5R
M<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(D-H879E<R!3+TU)344@4&5S<V]A:7,@97AC;'7M9&%S(&-O;2!S=6-E
M<W-O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L
M86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D
M<S\B"FUS9W-T<B`B26YS97)I<B!S=6$@87-S:6YA='5R82!A;G1E<R!D92!R
M97-P;W-T87,@92!E;F-A;6EN:&%M96YT;W,_(@H*(SH@8V]M<&]S92YP:'`Z
M,C4X"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S
M='(@(E9E<G/C;R!D82!-96YS86=E;2!E;2!497AT;R!0=7)O(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<X.`IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O
M;B!N97<@;6%I;#\@(%1H:7,@<F5Q=6ER97,@>6]U<B!B<F]W<V5R('1O('-U
M<'!O<G0@96UB961D960@(@HB<V]U;F0@9FEL97,N("!!;&UO<W0@86QL(&1O
M(&]N(%=I;F1O=W,@86YD($UA8RP@8G5T(&]T:&5R('!L871F;W)M<R!W:6QL
M("(*(G)E<75I<F4@82!P;'5G:6XN(@IM<V=S='(@(B(*(D5M:71I<B!A=FES
M;R!S;VYO<F\@86\@<F5C96)E<B!N;W9A(&UE;G-A9V5M/R!)<W1O(')E<75E
M<B!Q=64@<V5U(&YA=F5G861O<B`B"B)S=7!O<G1E(&%R<75I=F]S(&1E('-O
M;G,@96UB=71I9&]S+B!1=6%S92!T;V1O<R!S=7!O<G1A;2!E;2!7:6YD;W=S
M(&4@36%C+"`B"B)M87,@;W5T<F%S('!L871A9F]R;6%S(&YE8V5S<VET87)A
M;2!D92!U;2!P;'5G:6XN(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C
M<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M,3DR"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O
M;&1E<CHB"FUS9W-T<B`B4&]R(&9A=F]R(&9O<FYEYV$@=6T@;F]M92!P87)A
M(&$@;F]V82!P87-T83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$P-"!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P
M-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L
M9&5R.B(*;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G82!O(&YO;64@<&%R82!A
M(&YO=F$@<&%S=&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ,SD*;7-G:60@(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM
M<V=S='(@(E!O<B!F879O<B!F;W)N9>=A(&\@;F]V;R!N;VUE.B(*"B,Z('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O("(*(F5N
M=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G
M<W1R("(B"B)0;W(@9F%V;W(@9F]R;F7G82!A('-E;FAA('!A<F$@<W5A(&-H
M879E('!R:79A9&$@4$=0+B!6;V/J('-O;65N=&4@<')E8VES87+A("(*(F9O
M<FYE8V5R(&5S=&$@<V5N:&$@=6UA('9E>B!P;W(@<V5S<^-O("5S+B(*"B,Z
M('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R
M('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@
M(@HB=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I
M;VXN(@IM<V=S='(@(B(*(E!O<B!F879O<B!F;W)N9>=A(&$@<V5N:&$@<&%R
M82!S=6$@8VAA=F4@<')I=F%D82!3+TU)344N(%9O8^H@<V]M96YT92`B"B)P
M<F5C:7-A<N$@9F]R;F5C97(@97-T82!S96YH82!U;6$@=F5Z('!O<B!S97-S
MXV\@)7,N(@H*(SH@<F5C;VUP;W-E+G!H<#HY-@IM<V=I9"`B(@HB4&QE87-E
M(&QO9R!I;B!A9V%I;B!T;R!R97-U;64@8V]M<&]S:6YG('EO=7(@;65S<V%G
M92X@268@>6]U(&%R92!.3U0@=7-I;F<@(@HB8V]O:VEE<R!!3D0@>6]U(&%R
M92!C;VUP;W-I;F<@;65S<V%G97,@:6X@<&]P=7`@=VEN9&]W<RP@>6]U('=I
M;&P@:&%V92!T;R`B"B)L;V<@:6X@86=A:6X@:6X@>6]U<B!M86EN('=I;F1O
M=R!A<R!W96QL+B!4:&ES(&ES('1O(&ME97`@871T86-K97)S(&9R;VT@(@HB
M:&EJ86-K:6YG('EO=7(@<V5S<VEO;B!)1"X@5V4@87!O;&]G:7IE(&9O<B!A
M;GD@:6YC;VYV96YI96YC92XB"FUS9W-T<B`B(@HB4&]R(&9A=F]R(&-O;F5C
M=&4M<V4@;F]V86UE;G1E('!A<F$@8V]N=&EN=6%R(&-O;7!O;F1O('-U82!M
M96YS86=E;2X@4V4@=F]CZB`B"B).PT\@97-TX2!U=&EL:7IA;F1O(&-O;VMI
M97,@12!V;V/J(&5S=.$@8V]M<&]N9&\@;65N<V%G96YS(&5M('5M82!J86YE
M;&$@<&]P+2(*(G5P+"!V;V/J('1E<N$@<75E(&-O;F5C=&%R(&YO=F%M96YT
M92!N82!J86YE;&$@<')I;F-I<&%L('1A;6+I;2X@27-T;R#I('!A<F$@(@HB
M<')E=F5N:7(@<75E(&AA8VME<G,@9&5T96YH86T@;R!)1"!D92!S=6$@<V5S
M<^-O+B!.;W,@9&5S8W5L<&%M;W,@<&]R("(*(G%U86QQ=65R(&EN8V]N=F5N
M:>IN8VEA+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S$*;7-G
M:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S='(@(E!O
M<B!F879O<B!F;W)N9>=A('-U82!S96YH82XB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C8W"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S
M97)N86UE+B(*;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G82!S974@=7-UX7)I
M;RXB"@HC.B!C;VUP;W-E+G!H<#HQ,#8@;&EB+TE-4"YP:'`Z-#8U"FUS9VED
M(")0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S
M97,N(@IM<V=S='(@(E!O<B!F879O<B!C;W)R:6IA(&5N9&5R9>=O<R!I;G;A
M;&ED;W,@;W4@86UB[6=U;W,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHV,PIM<V=I9"`B4&QE87-E('-E;&5C="!A(&9O;&1E<B!B
M969O<F4@>6]U('!E<F9O<FT@=&AI<R!A8W1I;VXN(@IM<V=S='(@(E!O<B!F
M879O<B!S96QE8VEO;F4@=6UA('!A<W1A(&%N=&5S(&1E(')E86QI>F%R(&5S
M=&$@8>?C;RXB"@HC.B!T96UP;&%T97,O<V5A<F-H+VIA=F%S8W)I<'0N:6YC
M.C0Q"FUS9VED(")0;&5A<V4@<V5L96-T(&%T(&QE87-T(&]N92!F;VQD97(@
M=&\@<V5A<F-H+B(*;7-G<W1R(")0;W(@9F%V;W(@<V5L96-I;VYE('!E;&\@
M;65N;W,@=6UA('!A<W1A('!A<F$@<&5S<75I<V%R+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE
M8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T
M<B`B4&]R(&9A=F]R('-E;&5C:6]N92!S;VUE;G1E('5M82!P87-T82!P87)A
M(&5S=&$@;W!E<F'GXV\N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E
M8W0N:6YC.C<S"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE
M(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E!O<B!F879O<B!S96QE8VEO
M;F4@;W4@961I=&4@;F$@8V%I>&$@X"!D:7)E:71A.B(*"B,Z(&-O;F9I9R]M
M;W1D+G!H<"YD:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S
M='(@(E!O=V5R960@8GD@2&]R9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C$T"FUS9VED(")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S
M:&5S("@G+2T@)RD_(@IM<V=S='(@(E!R96-E9&5R('-U82!A<W-I;F%T=7)A
M(&-O;2!T<F'G;W,@*"<M+2<I/R(*"B,Z('-M:6UE+G!H<#HR,S<@<&=P+G!H
M<#HR-3,@9FEL=&5R<')E9G,N<&AP.C0P"FUS9VED(")0<F5F97)E;F-E<R!S
M=6-C97-S9G5L;'D@=7!D871E9"XB"FUS9W-T<B`B4')E9F5RZFYC:6%S(&%T
M=6%L:7IA9&%S(&-O;2!S=6-E<W-O+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E!R
MZ2UV:7-U86QI>F'GXV\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U<R!-97-S86=E(@IM<V=S
M='(@(DUE;G-A9V5M($%N=&5R:6]R(@H*(SH@;6%I;&)O>"YP:'`Z,S,P"FUS
M9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(E#A9VEN82!!;G1E<FEO<B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM
M<V=I9"`B4')I;G0B"FUS9W-T<B`B26UP<FEM:7(B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]H96%D97)S+FEN8SHS.`IM<V=I9"`B4')I;W)I='DB"FUS9W-T
M<B`B4')I;W)I9&%D92(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y
M+FEN8SHW-@IM<V=I9"`B4')I=F%T92!+97D@4&%S<W=O<F0B"FUS9W-T<B`B
M4V5N:&$@9&$@0VAA=F4@4')I=F%D82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-3D*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE
M;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R(")097)G=6YT87(@
M<V5M<')E('%U92!U;2!A;F5X;R#I(&5N=FEA9&\[('!A9'+C;R#I($[#3R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP="!E
M=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!9
M15,B"FUS9W-T<B`B4&5R9W5N=&%R('-E;7!R92!Q=64@=6T@86YE>&\@Z2!E
M;G9I861O.R!P861RXV\@Z2!324TB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,3`*;7-G:60@(E!R;W1O8V]L.B(*;7-G<W1R(")0<F]T
M;V-O;&\Z(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#,P"FUS9VED(")0=6)L
M:6,@4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*
M;7-G<W1R(")3=7!O<G1E(&$@<V5R=FED;W)E<R!D92!C:&%V92!P^F)L:6-A
M(&5S=.$@9&5S86)I;&ET861O+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E
M9"YI;F,Z-PIM<V=I9"`B4'5R7V=E($1E;&5T960B"FUS9W-T<B`B17-V85]Z
M:6%R($QI>&5I<F$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC.C<*
M;7-G:60@(E!U<F=E($1E;&5T960B"FUS9W-T<B`B17-V87II87(@3&EX96ER
M82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(T"FUS9VED
M(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B17-V87II87(@4&%S=&$H<RDB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"FUS9VED(")0=7)G92!4
M<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(D9R97'\ZFYC:6$@<&%R82!E<W9A
M>FEA<B!,:7AE:7)A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*
M;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T
M:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@(D5X8VQU:7(@;65N
M<V%G96YS(&1A($QI>&5I<F$@;6%I<R!A;G1I9V%S('%U92!E<W1A('%U86YT
M:61A9&4@9&4@9&EA<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V
M"FUS9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E
M<C\B"FUS9W-T<B`B17AC;'5I<B!M96YS86=E;G,@86YT:6=A<R!N82!,:7AE
M:7)A/R(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H
M<#HV-0HC+"!P:'`M9F]R;6%T"FUS9VED(")0=7)G:6YG("5D(&UE<W-A9V5S
M(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R(")%>&-L=6EN9&\@)60@;65N
M<V%G96TH;G,I(&1A($QI>&5I<F$N(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<'5R9V5?=')A<V@N<&AP.C8S"FUS9VED(")0=7)G:6YG(#$@;65S<V%G
M92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B17AC;'5I;F1O(#$@;65N
M<V%G96T@9&$@3&EX96ER82XB"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N
M:6YC.C$W"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR
M9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R(")3:71U8>?C;R!D82!1
M=6]T83H@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*"B,Z('1E;7!L871E
M<R]Q=6]T82]Q=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O
M=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G<W1R(")3:71U8>?C
M;R!D82!1=6]T83H@)2XR9DU"("\@4T5-($Q)34E412(*"B,Z('1E;7!L871E
M<R]Q=6]T82]Q=6]T82YI;F,Z,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O
M=&$@<W1A='5S.B!.3R!,24U)5"(*;7-G<W1R(")3:71U8>?C;R!D82!1=6]T
M83H@4T5-($Q)34E412(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T<B`B0VET
M86YD;R`E9CHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR
M.0IM<V=I9"`B4F5B=6EL9"!&;VQD97(@5')E92(*;7-G<W1R(")296-O;G-T
M<G5I<B!A(,%R=F]R92!D92!087-T87,B"@HC.B!L:6(O4V5A<F-H+G!H<#HV
M,3<*;7-G:60@(E)E8V5I=F5D($]N(@IM<V=S='(@(E)E8V5B:61O($5M(@H*
M(SH@;&EB+U-E87)C:"YP:'`Z-C(U"FUS9VED(")296-E:79E9"!3:6YC92(*
M;7-G<W1R(")296-E8FED;R!$97-D92(*"B,Z(&QI8B]396%R8V@N<&AP.C8R
M,0IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`B4F5C96)I9&\@073I
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B4F5D:7)E8U]I;VYA<B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I
M9"`B4F5D:7)E8W0B"FUS9W-T<B`B4F5D:7)E8VEO;F%R(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,`IM<V=I9"`B4F5D:7)E8W0@
M365S<V%G92(*;7-G<W1R(")2961I<F5C:6]N87(@365N<V%G96TB"@HC.B!C
M;VUP;W-E+G!H<#HX,C<*;7-G:60@(E)E9&ER96-T('1H:7,@;65S<V%G92(*
M;7-G<W1R(")2961I<F5C:6]N87(@97-T82!M96YS86=E;2(*"B,Z(&-O;7!O
M<V4N<&AP.C@X,`IM<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*;7-G<W1R
M(")2961I<F5C:6]N86UE;G1O(&9A;&AO=2XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S<S"FUS9VED(")2969R97-H($9O;&1E<B!6:65W<SHB"FUS
M9W-T<B`B071U86QI>F%R(%9I<W5A;&EZ8>?C;R!D92!087-T87,Z(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.2!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C0*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")!='5A;&EZ
M87(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHS"FUS9VED(")2
M96QO860@5FEE=R(*;7-G<W1R(")!='5A;&EZ87(@5FES=6%L:7IAY^-O(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-30W"FUS9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("),96UB<F%R(&$@:6YF;W)M8>?C;R!L
M:79R92]O8W5P861O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-C@*
M;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS9W-T<B`B3&5M8G)A
M<B!A(/IL=&EM82!V:7-U86QI>F'GXV\B"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*;7-G
M<W1R(")#86EX82!0;W-T86P@4F5M;W1A.B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I96QD($9R;VT@4V5A
M<F-H(@IM<V=S='(@(E)E;6]V97(@0V%M<&\@9&$@4&5S<75I<V$B"@HC.B!T
M96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#4*;7-G:60@(E)E
M;6]V92!S;W5R8V4B"FUS9W-T<B`B4F5M;W9E<B!O<FEG96TB"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHX"FUS9VED(")296YA;64@1F]L
M9&5R*',I(@IM<V=S='(@(E)E;F]M96%R(%!A<W1A*',I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F
M;VQD97(@870@8F5G:6YN:6YG(&]F(&UO;G1H/R(*;7-G<W1R(")296YO;65A
M<B!<(D5N=FEA9&]S7"(@;F\@:6[M8VEO(&1O(&WJ<S\B"@HC.B!L:6(O1F]L
M9&5R+G!H<#HT-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E
M<UPB('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`B1F%L:&$@86\@<F5N;VUE87(@7"(E<UPB('!A<F$@
M7"(E<UPB+B!)<W1O(.D@;R!Q=64@;R!S97)V:61O<B!D:7-S92(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B
M4F5P;%]Y('1O($QI<W0B"FUS9W-T<B`B4F5S<&]N9&5R('!A<F$@3&ES=&$@
M9&4@1&ES8U]U<W/C;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T<B`B4W5B<W1I
M='5I<B!P;W(Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S='(@(E)E<W!O;F1E<B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3(@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0Q,`IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B4F5S
M<&]S=&$@16YV:6%D82XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R(")2
M97-P;VYD97(@82!4;V1O<R(*"B,Z(&-O;7!O<V4N<&AP.C<W,0IM<V=I9"`B
M4F5P;'D@=&\@06QL.B(*;7-G<W1R(")297-P;VYD97(@82!4;V1O<SHB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G
M:60@(E)E<&QY('1O($QI<W0B"FUS9W-T<B`B4F5S<&]N9&5R('!A<F$@82!,
M:7-T82!D92!$:7-C=7-SXV\B"@HC.B!C;VUP;W-E+G!H<#HW-S,*;7-G:60@
M(E)E<&QY('1O($QI<W0Z(@IM<V=S='(@(E)E<W!O;F1E<B!P87)A(&$@3&ES
M=&$@9&4@1&ES8W5S<^-O.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@7T%L;"(*;7-G<W1R
M(")297-P;VYD97(@82!4;V1O<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,S`@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S.0HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-30Y"FUS9VED(")297!L>2!W:71H($YO
M="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R(")297-P;VYD97(@8V]M($UE
M;G-A9V5M($[C;R!3=7!O<G1A9&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3,W"FUS9VED(")297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X
M="`R(&UO;G1H<RXB"FUS9W-T<B`B4F5S<&]N9&5R(&-O;2!I;F9O<FUAY^-O
M(&QI=G)E+V]C=7!A9&\@9'5R86YT92`R(&UE<V5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,S8*;7-G:60@(E)E<&QY('=I=&@@<F5Q=65S
M=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B4F5S<&]N9&5R
M(&-O;2!S;VQI8VET8>?C;R!D92!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\N
M(@H*(SH@;65S<V%G92YP:'`Z,C<W"FUS9VED(")297!L>2U4;R(*;7-G<W1R
M(")297!L>2U4;R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,C`*;7-G:60@(E)E
M<&QY+51O.B`B"FUS9W-T<B`B16YD97)EYV\@<&%R82!297-P;W-T82`H4F5P
M;'DM5&\I.B`B"@HC.B!C;VUP;W-E+G!H<#HW-CD*;7-G:60@(E)E<&QY.B(*
M;7-G<W1R(")297-P;VYD97(Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E;G0B"FUS9W-T<B`B4F5P
M;W)T87(@8V]M;R!);F]C96YT92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHS-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHR,PIM<V=I9"`B4F5P;W)T(&%S(%-P86TB"FUS9W-T<B`B4F5P;W)T
M87(@8V]M;R!3<&%M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,S@V"FUS9VED(")297%U97-T(&$@7U)E860@4F5C96EP="(*;7-G<W1R
M(")3;VQI8VET87(@0V]N9FER;6'GXV\@9&4@7TQE:71U<F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3<S"FUS9VED(")297%U97-T(')E860@<F5C
M96EP=',_(@IM<V=S='(@(E-O;&EC:71A<B!C;VYF:7)M8>?C;R!D92!L96ET
M=7)A/R(*"B,Z(&UA:6QB;W@N<&AP.C$X-PIM<V=I9"`B4F5Q=65S=&5D(&UE
M<W-A9V4@;F]T(&9O=6YD+B(*;7-G<W1R(")!(&UE;G-A9V5M('-O;&EC:71A
M9&$@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV.3(*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S
M='(@(E!A<G1I8VEP86YT92!/8G)I9V%T\W)I;R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,3,X('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN
M8SHR.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R"FUS9VED(")297-E
M="(*;7-G<W1R("),:6UP87(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3$V"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D+B(*;7-G
M<W1R(")3:71U8>?C;R!D92!297-P;W-T82!!='5A;&EZ861A+B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,`IM<V=I9"`B
M4F5S=6UE(@IM<V=S='(@(D-O;G1I;G5A<B(*"B,Z(')E8V]M<&]S92YP:'`Z
M.3<*;7-G:60@(E)E<W5M92!Y;W5R('-E<W-I;VXB"FUS9W-T<B`B0V]N=&EN
M=6%R('-U82!S97-SXV\B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z-#0*;7-G:60@(E)E='5R;B!T;R!<(DUE<W-A9V4@0V]M<&]S:71I
M;VY<(B(*;7-G<W1R(")2971O<FYA<B!P87)A(%PB0V]M<&]S:>?C;R!D92!-
M96YS86=E;5PB(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L
M96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-CD*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,S$*
M;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@(E)E=&]R;F%R
M('!A<F$@5')A>F5R($UE;G-A9V5M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z
M,C(*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#$@=&5M<&QA=&5S
M+W-M:6UE+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,R!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M,3<U"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")2971O<FYA
M<B#@($]PY_5E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,#<*;7-G
M:60@(B(*(E)E='5R;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E
M;&5T:6YG+"!M;W9I;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/R(*;7-G<W1R
M("(B"B)2971O<FYA<B#@(&QI<W1A9V5M(&1A(&-A:7AA('!O<W1A;"!A</-S
M(&5X8VQU:7(L(&UO=F5R(&]U(&-O<&EA<B!U;6$@(@HB;65N<V%G96T_(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,PIM<V=I9"`B4F]L92(*
M;7-G<W1R(")&=6[GXV\B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C$T,B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S-PHC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C0R-`IM<V=I9"`B4R]-24U%(@IM<V=S='(@
M(E,O34E-12(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI
M;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B
M365N<V%G96T@0W)I<'1O9W)A9F%D82!C;VT@4R]-24U%(@H*(SH@8V]M<&]S
M92YP:'`Z,S<Q"FUS9VED(")3+TU)344@17)R;W(Z("(*;7-G<W1R(")%<G)O
M(&1O(%,O34E-13H@(@H*(SH@8V]M<&]S92YP:'`Z,S4P"FUS9VED(")3+TU)
M344@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T
M92!K97DN(@IM<V=S='(@(D5R<F\@9&\@4R]-24U%.B!396YH82!N96-E<W/A
M<FEA('!A<F$@82!C:&%V92!P<FEV861A('!E<W-O86PN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$U,0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS
M9W-T<B`B3W#G]65S(&1O(%,O34E-12(*"B,Z('-M:6UE+G!H<#HT-@IM<V=I
M9"`B4R]-24U%(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`B16YT<F%D82!D
M82!396YH82!3+TU)344B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C4T"FUS9VED(")3+TU)344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E
M<75I<F5S(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")3=7!O
M<G1E(&$@4&%R(&1E($-H879E<R!3+TU)344@4&5S<V]A:7,@<F5Q=65R('5M
M82!C;VYE>.-O('=E8B!S96=U<F$N(@H*(SH@<VUI;64N<&AP.C$S-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@7"(E<UPB
M('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B0VAA=F4@4/IB
M;&EC82!3+TU)344@9&4@7"(E<UPB(&9O:2!E>&-L=>UD82!C;VT@<W5C97-S
M;RXB"@HC.B!S;6EM92YP:'`Z,34X"FUS9VED(")3+TU)344@4'5B;&EC($ME
M>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(D-H879E(%#Z8FQI8V$@
M4R]-24U%(&%D:6-I;VYA9&$@8V]M('-U8V5S<V\N(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97ER
M:6YG(@IM<V=S='(@(D-H879E:7)O(%#Z8FQI8V\@4R]-24U%(@H*(SH@<VUI
M;64N<&AP.C(P-PIM<V=I9"`B4R]-24U%(%!U8FQI8R]0<FEV871E($ME>7!A
M:7(@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R(")087(@9&4@0VAA=F5S
M(%#Z8FQI8V$O4')I=F%D82!3+TU)344@861I8VEO;F%D;R!C;VT@<W5C97-S
M;RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S
M"FUS9VED(")3+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(DUE;G-A9V5M
M($%S<VEN861A(&-O;2!3+TU)344B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M;F-R>7!T7VQI<W0N:6YC.C$T"FUS9VED(")3+TU)344@4VEG;B]%;F-R>7!T
M($UE<W-A9V4B"FUS9W-T<B`B365N<V%G96T@07-S:6YA9&$O0W)I<'1O9W)A
M9F%D82!C;VT@4R]-24U%(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV
M92YI;F,Z-`IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@
M=&AI<R!S>7-T96TN(@IM<V=S='(@(E-U<&]R=&4@82!3+TU)344@97-TX2!D
M97-A8FEL:71A9&\@;F5S=&4@<VES=&5M82XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@
M;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L
M92!T;R!B92`B"B)D96-R>7!T960N(@IM<V=S='(@(B(*(E-U<&]R=&4@82!3
M+TU)344@;N-O(&5S=.$@871U86QM96YT92!H86)I;&ET861O+"!S96YD;R!A
M<W-I;2!NXV\@Z2!P;W-S[79E;"`B"B)D97-C<FEP=&]G<F%F87(@82!M96YS
M86=E;2XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,PIM<V=I
M9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@=&AE(&-O
M;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N;F]T("(*(F)E(&1I
M<W!L87EE9"XB"FUS9W-T<B`B(@HB3R!S=7!O<G1E(%,O34E-12!NXV\@97-T
MX2!H86)I;&ET861O('!O<B!I<W-O(&\@8V]N=&7Z9&\@9&5S=&$@;65N<V%G
M96T@;N-O("(*(G!O9&4@<V5R(&5X:6)I9&$N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES
M(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B
M;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E-U<&]R=&4@82!3
M+TU)344@;N-O(&5S=.$@871U86QM96YT92!H86)I;&ET861O+"!S96YD;R!A
M<W-I;2!NXV\@Z2!P;W-S[79E;"`B"B)V97)I9FEC87(@82!A<W-I;F%T=7)A
M(&1I9VET86PN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S
M('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY
M('-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG
M92!T:&ES('-E='1I;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S
M('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)/('-U<&]R
M=&4@4R]-24U%(')E<75E<B!Q=64@:F%N96QA<R!P;W`M=7`@<V5J82!U=&EL
M:7IA9&%S+B`@4V4@<V5U("(*(FYA=F5G861O<B!E<W3A(&%T=6%L;65N=&4@
M8V]N9FEG=7)A9&\@<&%R82!D97-A8FEL:71A<B!J86YE;&%S('!O<"UU<"P@
M=F]CZB`B"B)D979E(&%L=&5R87(@97-T82!C;VYF:6=U<F'GXV\@;W4@87,@
M9G5NY_5E<R!3+TU)344@;N-O(&9U;F-I;VYA<N-O("(*(F-O<G)E=&%M96YT
M92XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P-`IM<V=I9"`B
M4TU44"(*;7-G<W1R(")33510(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,C4U"FUS9VED(")37W5B:F5C="(*;7-G<W1R(")!7W-S=6YT
M;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,V,PIM<V=I
M9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R(")386Q?=F%R('5M82!C\W!I
M82!E;2`B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,S(*;7-G:60@(E-A7W9E(&%S(@IM<V=S='(@(E-A;'9A<B!C;VUO(@H*
M(SH@<V5A<F-H+G!H<#HS,#@@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C8W"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9A<B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4S-@IM<V=I9"`B4V%V92!!='1A
M8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS
M9W-T<B`B4V%L=F%R(&%N97AO<R!C;VT@82!M96YS86=E;2!N82!P87-T82!D
M92!M96YS86=E;G,@96YV:6%D87,_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#,P"FUS9VED(")3879E($1R869T(@IM<V=S='(@(E-A;'9A<B!287-C=6YH
M;R(*"B,Z('-A=F5I;6%G92YP:'`Z-#(*;7-G:60@(E-A=F4@26UA9V4B"FUS
M9W-T<B`B4V%L=F%R(&-O;6\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z
M,C(X"FUS9VED(")3879E($EM86=E(&EN($=A;&QE<GDB"FUS9W-T<B`B4V%L
M=F%R($EM86=E;2!N82!'86QE<FEA(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C4Y('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`P"B,Z
M('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C$S('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ-#@*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC
M.C$S"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B4V%L=F%R($]PY_5E
M<R(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,`IM<V=I
M9"`B4V%V92!3=&%T:6]N97)Y(@IM<V=S='(@(E-A;'9A<B!087!E;"!D92!#
M87)T82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,`IM<V=I9"`B4V%V92!?
M1')A9G0B"FUS9W-T<B`B4V%L=F%R(%)A<V-U;E]H;R(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I9"`B4V%V92!A
M<R(*;7-G<W1R(")386QV87(@8V]M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T
M<B`B4V%L=F%R(')A<V-U;FAO<R!C;VUO(&[C;R!L:61O<S\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`V,0IM<V=I9"`B4V%V92!R96-I<&EE;G1S
M(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S<R!B;V]K/R(*
M;7-G<W1R("(B"B)386QV87(@875T;VUA=&EC86UE;G1E(&1E<W1I;F%TX7)I
M;W,@;F\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!P861RXV\_(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,C(*;7-G:60@(E-A=F4@<V5A
M<F-H(&%S(&$@=FER='5A;"!F;VQD97(_(@IM<V=S='(@(E-A;'9A<B!P97-Q
M=6ES82!C;VUO('5M82!P87-T82!V:7)T=6%L/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,S`*;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R
M(")386QV87(@96YV:6%D;W,_(@H*(SH@8V]M<&]S92YP:'`Z,3(V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B1F%L:&$@
M86\@<V%L=F%R(')A<V-U;FAO+B!)<W1O(.D@;R!Q=64@;R!S97)V:61O<B!D
M:7-S93H@)7,B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$Y.2!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,Z(&QI8B]"
M;&]C:R]T<F5E7V9O;&1E<G,N<&AP.C4T"FUS9VED(")396%R8V@B"FUS9W-T
M<B`B4&5S<75I<V%R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC
M.C(Q('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V5A<F-H("5S(@IM<V=S='(@(E!E<W%U:7-A<B`E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C`*;7-G:60@(E-E87)C:"!/
M<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!097-Q=6ES82(*"B,Z('-E87)C
M:"YP:'`Z,C8S"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R(")297-U
M;'1A9&]S(&1A(%!E<W%U:7-A(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ-"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Q"FUS
M9VED(")3965N(@IM<V=S='(@(DQI9&$B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.CD*;7-G:60@(E-E;&5C="(*;7-G<W1R(")396QE8VEO
M;F%R(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<P"FUS
M9VED(")396QE8W0@06YO=&AE<B!!8V-O=6YT(@IM<V=S='(@(E-E;&5C:6]N
M87(@3W5T<F$@0V]N=&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z,S8*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L96-I;VYE
M('5M82!D871A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P
M"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R(")396QE8VEO;F4@=6T@
M8V%M<&\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3<*
M;7-G:60@(E-E;&5C="!A('-T871I;VYE<GDZ(@IM<V=S='(@(E-E;&5C:6]N
M92!U;2!P87!E;"!D92!C87)T83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,U"FUS9VED(")396QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R
M(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S='(@
M(B(*(E-E;&5C:6]N92!U;2!C873A;&]G;R!D92!E;F1E<F7G;W,@<&%R82!A
M9&EC:6]N87(@92!P97-Q=6ES87(@96YD97)EYV]S+B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z.#@*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T
M<B`B4V5L96-I;VYA<B!T;V1A<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R
M8V5S96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@
M<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B4V5L
M96-I;VYA<B!T;V1O<R!O<R!C86UP;W,@82!P97-Q=6ES87(@<75A;F1O(&5X
M<&%N9&ER(&5N9&5R9>=O<RXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C
M8V]U;G1?<V5L96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B
M"FUS9W-T<B`B4V5L96-I;VYA<B!U;6$@8V]N=&$B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C@Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R
M(").XV\@<V5L96-I;VYA<B!N96YH=6TB"@HC.B!T96UP;&%T97,O<V%V96EM
M86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B4V5L96-T('1H92!G86QL97)Y
M('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R(")396QE8VEO;F%R(&$@
M9V%L97)I82!O;F1E('-A;'9A<B!A(&EM86=E;2XB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@
M=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T<B`B4V5L96-I;VYE(&\@=&EP
M;R!D92!S97)V:61O<B!D92!C;W)R96EO(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-O=7)C97-E;&5C="YI;F,Z,S`Y"FUS9VED(")396QE8W1E9"!!9&1R97-S
M(&)O;VMS.B(*;7-G<W1R(")#873A;&]G;W,@9&4@16YD97)EYV]S(%-E;&5C
M:6]N861O<SHB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@
M(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T<B`B16YV:6%R
M(&-H879E('!A<F$@;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DW"FUS9VED(")396YD($QA
M=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R(")%;G9I87(@VFQT:6UA<R!);F9O
M<FUAY_5E<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R.`IM<V=I9"`B4V5N
M9"!-97-S86=E(@IM<V=S='(@(D5N=FEA<B!-96YS86=E;2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3(V"FUS9VED(")396YD(&UE<W-A
M9V4@=VET:&]U="!A(%-U8FIE8W0_(@IM<V=S='(@(D5N=FEA<B!A(&UE;G-A
M9V5M('-E;2!U;2!!<W-U;G1O/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.3(*;7-G:60@(E-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D
M(&)Y('1H92!S96YD97(_(@IM<V=S='(@(D5N=FEA<B!.1$T@<75A;F1O('-O
M;&EC:71A9&\@<&5L;R!R96UE=&5N=&4_(@H*(SH@9F]L9&5R<RYP:'`Z,S<X
M"FUS9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(E!A<W1A($5N=FEA
M9&]S(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS
M.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`B4&%S=&$@16YV
M:6%D;W,Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S,@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-#4*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ-3(*;7-G:60@(E-E<G9E<B(*;7-G<W1R(")397)V:61O
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PIM<V=I9"`B4V5R=F5R
M(&%N9"!&;VQD97(@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M8>?U97,@
M9&4@4V5R=FED;W(@92!087-T87,B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B4V5R=FED
M;W(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@
M<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N
M9"!D96QE=&4@;65S<V%G97,N(@IM<V=S='(@(B(*(D1E9FEN92!P<F5F97+J
M;F-I87,@<V]B<F4@;R!Q=64@86-O;G1E8V4@<75A;F1O('9O8^H@;6]V92!E
M(&5X8VQU:2!M96YS86=E;G,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4R.0IM<V=I9"`B4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O
M;7!O<VEN9R!M97-S86=E<S\B"FUS9W-T<B`B26YS97)I<B!O(&-A8F7G86QH
M;R!8+5!R:6]R:71Y(&%O(&-O;7!O<B!M96YS86=E;G,_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Q"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S
M='(@(E!A<W1A<R!#;VUP87)T:6QH861A<R(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHX-@IM<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@
M(D-O;7!A<G1I;&AA<B!P87-T87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H
M97(@=7-E<G,N(@IM<V=S='(@(D-O;7!A<G1I;&AA('-U87,@<&%S=&%S(&1E
M(&-O<G)E:6\@8V]M(&]U=')O<R!U<W7A<FEO<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C4W"FUS9VED("(B"B)3:&]U;&0@;&%R9V4@8FQO8VMS
M(&]F('%U;W1E9"!T97AT(&)E('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT
M/R!)="!C86X@8F4@(@HB=&]G9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C
M:&]O<V4N(@IM<V=S='(@(B(*(D)L;V-O<R!G<F%N9&5S(&1E('1E>'1O(&-I
M=&%D;R!D979E;2!S97(@97AI8FED;W,@;W4@;V-U;'1A9&]S('!O<B!P861R
MXV\_("(*(DES=&\@<&]D92!S97(@86QT97)A9&\@9F%C:6QM96YT92!S96UP
M<F4@<75E('%U:7-E<BXB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM
M<V=I9"`B4VAO=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@
M8F4@<V-A;FYE9"!F;W(@4$=0(&1A=&$_(@IM<V=S='(@(B(*(D\@8V]R<&\@
M9&%S(&UE;G-A9V5N<R!T97AT;R!P=7)O(&1E=F4@<V5R(&5X86UI;F%D;R!A
M('!R;V-U<F$@9&4@9&%D;W,@4$=0/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@
M8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R(")!(&IA;F5L
M82!D92!C;VUP;W-IY^-O(&1E=F4@<V5R(&9E8VAA9&$@87#S<R!S86QV87(@
M=6T@<F%S8W5N:&\_(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0*;7-G
M:60@(E-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D
M('1O('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\B"FUS9W-T<B`B4&]R('!A
M9'+C;R!D979E+7-E(&%N97AA<B!S=6$@8VAA=F4@</IB;&EC82!01U`@96T@
M<W5A<R!M96YS86=E;G,_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHY,@IM<V=I9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")%>&EB:7(@
M5&]D87,@87,@4&%S=&%S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R
M<RYI;F,Z-C<*;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B17AI
M8FER(%1O9&]S(&]S($-A8F7G86QH;W,B"@HC.B!M86EL8F]X+G!H<#HS-#@*
M;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R(")%>&EB:7(@17AC;'7M9&%S
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*;7-G:60@
M(E-H;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(D5X:6)I<B!#86)EYV%L
M:&]S($QI;6ET861O<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C<P"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*
M;7-G<W1R(")%>&EB:7(@26YF;W)M8>?U97,@9&$@3&ES=&$@9&4@1&ES8W5S
M<^-O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@IM<V=I9"`B
M4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<R(*;7-G<W1R(")%>&EB:7(@
M4V]M96YT92!087-T87,@26YS8W)I=&%S(@H*(SH@9F]L9&5R<RYP:'`Z,C@T
M"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")%>&EB:7(@3N-O
M($EN<V-R:71A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.38*;7-G
M:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@871T86-H
M;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`B17AI8FER('5M(.UC;VYE
M('!A<F$@<&5R;6ET:7(@<F5M;W9E<B!A;F5X;W,@9&4@;65N<V%G96YS/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.3$*;7-G:60@(E-H;W<@;&5G
M96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S='(@(D5X:6)I<B!L96=E
M;F1A(&YA('9I<W5A;&EZ8>?C;R!D82!C86EX82!P;W-T86P_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R.0IM<V=I9"`B4VAO=R!P<F5V:65W<R!F
M;W(@=6YR96%D(&UE<W-A9V5S(&]N;'D_(@IM<V=S='(@(D5X:6)I<B!P<NDM
M=FES=6%L:7IAY^-O('-O;65N=&4@9&4@;65N<V%G96YS(&[C;R!L:61A<S\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,W"FUS9VED(")3:&]W('!R
M979I97=S(&EN('1O;VQT:7!S/R(*;7-G<W1R(")%>&EB:7(@<'+I+79I<W5A
M;&EZ8>?C;R!N;W,@8F%L]65S(&1E(&1I8V%S/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-C8*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O
M;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B17AI8FER(&\@[6-O;F4@5')A
M>F5R($UE;G-A9V5N<R!N82!B87)R82!D92!M96YU/R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HY.`IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM
M<V=S='(@(D5X:6)I<B!A<R!);6%G96YS(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F:6QT97(@:6-O;B!O
M;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B17AI8FER(&\@[6-O;F4@9&4@9FEL
M=')O<R!N82!B87)R82!D92!M96YU/R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HS,0IM<V=I9"`B4VAO=R!T;W1A;"!N=6UB97(@;V8@;6%I;',@:6X@
M9F]L9&5R/R(*;7-G<W1R(")%>&EB:7(@;R!N^FUE<F\@=&]T86P@9&4@;65N
M<V%G96YS(&YA('!A<W1A/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-30*;7-G:60@(E-H;W=N(@IM<V=S='(@(D5X:6)I9&%S(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT,@IM<V=I9"`B4VE?
M>F4B"FUS9W-T<B`B5&%?;6%N:&\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L
M96=E;F0N:6YC.C$W"FUS9VED(")3:6=N960B"FUS9W-T<B`B07-S:6YA9&$B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I
M9"`B4VEZ92(*;7-G<W1R(")486UA;FAO(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM<V=I9"`B4V]R="!B>2!!<G)I
M=F%L(@IM<V=S='(@(D]R9&5N87(@96T@3W)D96T@9&4@0VAE9V%D82(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,38*;7-G
M:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R(")/<F1E;F%R('!O<B!$871A(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR-@IM
M<V=I9"`B4V]R="!B>2!&<F]M($%D9')E<W,B"FUS9W-T<B`B3W)D96YA<B!P
M;W(@16YD97)EYV\@9&4@4F5M971E;G1E(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHT,0IM<V=I9"`B4V]R="!B>2!-97-S
M86=E(%-I>F4B"FUS9W-T<B`B3W)D96YA<B!P;W(@5&%M86YH;R!D82!-96YS
M86=E;2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,S8*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R(")/<F1E;F%R
M('!O<B!!<W-U;G1O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHS,0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS9W-T<B`B
M3W)D96YA<B!P;W(@1&ES8W5S<^-O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHR,0IM<V=I9"`B4V]R="!B>2!4;R!!9&1R
M97-S(@IM<V=S='(@(D]R9&5N87(@<&]R($5N9&5R9>=O(&1E($1E<W1I;F%T
MX7)I;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR,PIM
M<V=I9"`B4W!A;2!F;VQD97(Z(@IM<V=S='(@(E!A<W1A(&1E(%-P86TZ(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0V"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T<B`B0V%R86-T97)E<R!%<W!E8VEA
M:7,B"@HC.B!S96%R8V@N<&AP.C$T,@IM<V=I9"`B4W!E8VEA;"!6:7)T=6%L
M($9O;&1E<G,@8V%N;F]T(&)E(&5D:71E9"XB"FUS9W-T<B`B4&%S=&%S($5S
M<&5C:6%I<R!6:7)T=6%I<R!NXV\@<&]D96T@<V5R(&5D:71A9&%S+B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T,PIM<V=I9"`B4W!E
M;&P@0VAE8VLB"FUS9W-T<B`B5F5R:69I8V%R($]R=&]G<F%F:6$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(E-P96QL
M($-H96-K97(B"FUS9W-T<B`B5F5R:69I8V'GXV\@3W)T;V=RX69I8V$B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS9VED(")3<&5L;"!C:&5C:R!C
M;VUP;&5T92(*;7-G<W1R(")697)I9FEC8>?C;R!O<G1O9W+A9FEC82!C;VUP
M;&5T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@(E-P
M96QL:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N
M(@IM<V=S='(@(D[Z;65R;R!D92!E<G)O<R!D92!O<G1O9W)A9FEA('!O<B!T
M96QA(&1U<F%N=&4@82!V97)I9FEC8>?C;RXB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3`W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#D*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8T,B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C0T"FUS9VED(")3=&%R="(*;7-G<W1R("));FEC:6%R
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.CD@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$Q"FUS9VED(")3=&%T:6]N97)Y
M(@IM<V=S='(@(E!A<&5L(&1E($-A<G1A(@H*(SH@=&5M<&QA=&5S+W-T871I
M;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T:6]N97)Y(&YA;64Z(@IM
M<V=S='(@(DYO;64@9&\@<&%P96P@9&4@8V%R=&$Z(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y
M<&4Z(@IM<V=S='(@(E1I<&\@9&4@<&%P96P@9&4@8V%R=&$Z(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,S"FUS9VED(")3=&%T:6]N
M97)Y.B(*;7-G<W1R(")087!E;"!D92!#87)T83HB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C@S"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4VET
M=6'GXV\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C,Y"FUS9VED(")3
M=')I<"!!='1A8VAM96YT(@IM<V=S='(@(E)E;6]V97(@06YE>&\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(Q"FUS9VED(")3=')I<"!L:6YE8G)E
M86MS/R(*;7-G<W1R(")296UO=F5R('%U96)R87,@9&4@;&EN:&$_(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-PIM<V=I
M9"`B4W5B7VIE8W0B"FUS9W-T<B`B7T%S<W5N=&\B"@HC.B!M97-S86=E+G!H
M<#HR-S@@=&AR96%D+G!H<#HQ-34@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP
M;W-E+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HV,#4*;7-G:60@(E-U8FIE
M8W0B"FUS9W-T<B`B07-S=6YT;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,#D*;7-G:60@(E-U8FIE8W0@1FEE;&0B"FUS9W-T<B`B0V%M<&\@07-S
M=6YT;R(*"B,Z('-E87)C:"YP:'`Z,S$P('1E;7!L871E<R]S879E:6UA9V4O
M<V%V96EM86=E+FEN8SHQ.`HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S
M92YI;F,Z,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS,0IM<V=I
M9"`B4W5B;6ET(@IM<V=S='(@(D5N=FEA<B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R
M*',I(@IM<V=S='(@(DEN<V-R979E<BUS92#@*',I(%!A<W1A*',I(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#4@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,SDS"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@W
M"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U8V5S<V\B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(E-U9V=E<W1I;VYS
M(@IM<V=S='(@(E-U9V5S=/5E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV-3D@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V,0IM<V=I9"`B
M4W5M;6%R>2(*;7-G<W1R(")297-U;6\B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS.3<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-#`P"FUS9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D(@IM<V=S
M='(@(E1R;V-A<B!O($WI=&]D;R!D92!#;VUP;W-IY^-O(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`Q"FUS9VED(")3=VET8V@@=&\@
M2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R(")4<F]C87(@<&%R82!O(&5D:71O
M<B!(5$U,(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`Q
M"FUS9VED(")3=VET8V@@=&\@<&QA:6X@=&5X="!C;VUP;W-I=&EO;B(*;7-G
M<W1R(")4<F]C87(@<&%R82!O(&5D:71O<B!D92!T97AT;R!P=7)O(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#$V"FUS9VED(")495]X
M="(*;7-G<W1R(")495]X=&\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,C<P"FUS9VED(")496YT871I=F4Z("(*;7-G<W1R(")0<F]V:7/S<FEO
M.B`B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@V"FUS9VED(")4
M96YT871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")!8V5I=&%R('-O
M;&EC:71AY^-O('!R;W9I<V]R:6%M96YT92(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW-30*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM
M<V=S='(@(D%C96ET;R!0<F]V:7-O<FEA;65N=&4B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]T;W-?86=R965M96YT+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")497)M<R!O9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I
M;B!C;VYF+G!H<"(*;7-G<W1R(")!<G%U:79O(&1E(%1E<FUO<R!D;R!397)V
M:>=O(&[C;R!E<W!E8VEF:6-A9&\@96T@8V]N9BYP:'`B"@HC.B!T96UP;&%T
M97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S`*;7-G:60@(E1E>'0B"FUS9W-T
M<B`B5&5?>'1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,PIM<V=I
M9"`B5&AE($9R;VTZ(&-O;'5M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@
M;&EN:V5D.B(*;7-G<W1R(")!(&-O;'5N82!$93H@;F$@;65N<V%G96T@9&5V
M92!S97(@;&EG861A(&$Z(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,S`*
M;7-G:60@(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@
M<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D
M+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"B)/('-E<G9I9&]R($E-05`@<&%R96-E(&[C;R!S=7!O<G1A
M<B!O(&WI=&]D;R!D92!A=71E;G1I8V'GXV\@<V5L96-I;VYA9&\N("(*(E!O
M<B!F879O<B!E;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(@
M9&\@<VES=&5M82XB"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N
M<&AP.C0Q"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"FUS
M9W-T<B`B1F]R:R!D92!R96-U<G-O<R!-86-I;G1O<V@B"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO
M861E9"`E<RXB"FUS9W-T<B`B1F]R:R!D92!R96-U<G-O<R!-86-I;G1O<V@@
M<&]D92!S97(@8F%I>&%D;R`E<RXB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z
M.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(D$@8V]N=&$@7"(E<UPB(&9O:2!E
M>&-L=>UD82XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R(")!(&-O;G1A(%PB)7-<(B!F;VD@<V%L=F$N(@H*(SH@871T
M86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT('=A<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(D\@86YE>&\@;N-O(&9O:2!E;F-O;G1R861O+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,0IM<V=I9"`B5&AE(&-A
M;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R(")/(&1A9&\@9&$@86=E
M;F1A(.D@:6YVX6QI9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W:6YD
M;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R
M(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B
M(@HB02!J86YE;&$@9&4@8V]M<&]S:>?C;R!NXV\@<&]D92!S97(@86)E<G1A
M+B!486QV97H@=F]CZB!T96YH82!C;VYF:6=U<F%D;R`B"B)S974@;F%V96=A
M9&]R('!A<F$@8FQO<75E87(@<&]P+75P<S\B"@HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N=',@;V8@
M=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B3R!C;VYT
M9?ID;R!D;R!A<G%U:79O($UA8VEN=&]S:"!E<W3A(&%B86EX;RXB"@HC.B!L
M:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP
M:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&-U<G)E;G0@9F]L9&5R
M*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M960@=&\@7"(E<UPB+B(*;7-G<W1R
M(")!*',I('!A<W1A*',I(%PB)7-<(B!A='5A;"AI87,I('-E<N$HXV\I(')E
M;F]M96%D82AS*2!P87)A(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,3`W"FUS9VED("(B"B)4:&4@8W5R<F5N="!L:7-T(&]F('5S97)S
M('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD(&YO="!B92!R971R
M:65V960B"FUS9W-T<B`B02!L:7-T82!A='5A;"!D92!U<W7A<FEO<R!C;VT@
M86-E<W-O(&$@97-T82!P87-T82!NXV\@</1D92!S97(@;V)T:61A(@H*(SH@
M8V]M<&]S92YP:'`Z,3(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9')A
M9G0@:&%S(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F;VQD97(N(@IM<V=S
M='(@(D\@<F%S8W5N:&\@9F]I('-A;'9O(&YA('!A<W1A(%PB)7-<(BXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30P"FUS9VED(")4:&4@979E
M;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(D\@979E
M;G1O(&9O:2!A9&EC:6]N861O(&5M('-U82!A9V5N9&$N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@
M(D\@8V%M<&\@7"(E<UPB(&[C;R!P;V1E('-E<B!E>'!A;F1I9&\N(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M;VQD97(@7"(E<UPB(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D$@<&%S=&$@
M7"(E<UPB(&KA(&5X:7-T92(*"B,Z(&QI8B]&;VQD97(N<&AP.C$V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@9F]L9&5R(%PB)7-<(B!C;VYT86EN
M<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C875S
M92`B"B)P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B)!('!A<W1A(%PB)7-<(B!C;VYT96T@8V%R
M86-T97)E<R!I;&5G86ES(&5M('-E=2!N;VUE+B!)<W1O('!O9&4@8V%U<V%R
M("(*(G!R;V)L96UA<RX@4&]R(&9A=F]R(&5N=')E(&5M(&-O;G1A=&\@8V]M
M(&\@861M:6YI<W1R861O<B!D;R!S:7-T96UA+B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<
M(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@
M:70N(@IM<V=S='(@(D$@<&%S=&$@7"(E<UPB(&9O:2!C<FEA9&$@;6%S('9O
M8^H@;N-O(&9O:2!I;G-C<FET;R!N96QA+B(*"B,Z(&QI8B]&;VQD97(N<&AP
M.C(V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W
M87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M
M(&ET+B(*;7-G<W1R(")!('!A<W1A(%PB)7-<(B!F;VD@97AC;'7M9&$@;6%S
M('9O8^H@;N-O('-E(&1E<VEN<V-R979E=2!D96QA+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C,S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B"FUS9W-T<B`B02!P87-T82!<(B5S7"(@9F]I(&-R:6%D82X@27-T
M;R#I(&\@<75E(&\@<V5R=FED;W(@9&ES<V4B"@HC.B!L:6(O1F]L9&5R+G!H
M<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@
M=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M(@IM<V=S='(@(D$@<&%S=&$@7"(E<UPB(&[C;R!F;VD@97AC;'7M9&$N($ES
M=&\@Z2!O('%U92!O('-E<G9I9&]R(&1I<W-E(@H*(SH@;&EB+T9O;&1E<BYP
M:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB
M('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B02!P87-T82!<
M(B5S7"(@9F]I(&-R:6%D82!C;VT@<W5C97-S;RXB"@HC.B!L:6(O1F]L9&5R
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")!('!A<W1A
M(%PB)7-<(B!F;VD@97AC;'7M9&$@8V]M('-U8V5S<V\N(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-#4V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE9"!T;R!<(B5S7"(N(@IM
M<V=S='(@(D$@<&%S=&$@7"(E<UPB(&9O:2!R96YO;65A9&$@<&%R82!<(B5S
M7"(@8V]M('-U8V5S<V\N(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP
M.CDT"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@
M=&\@=&AI<R!P87)T.B(*;7-G<W1R(")/<R!S96=U:6YT97,@87)Q=6EV;W,@
M9F]R86T@86YE>&%D;W,@82!E<W1A('!A<G1E.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?<V%V96EM86=E7W=I;BYJ<SHQ,@IM<V=I9"`B(@HB
M5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N;W0@8F4@;W!E;F5D+B!097)H
M87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S97(@(@HB=&\@8FQO8VL@<&]P
M=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@HB02!J86YE;&$@9&4@8V]M<&]S:>?C
M;R!NXV\@<&]D92!S97(@86)E<G1A+B!486QV97H@=F]CZB!T96YH82!C;VYF
M:6=U<F%D;R`B"B)S974@;F%V96=A9&]R('!A<F$@8FQO<75E87(@<&]P+75P
M<S\B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`P"FUS9VED("(B
M"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E
M;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN(@IM<V=S
M='(@(B(*(D%S(&EM86=E;G,@<V5RXV\@97AI8FED87,@<&]R<75E(&\@<F5M
M971E;G1E(&5S=.$@<')E<V5N=&4@96T@<V5U(&-A=.%L;V=O("(*(F1E(&5N
M9&5R9>=O<RXB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-0IM
M<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG
M(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(D\@<V5R=FED;W(@9&4@8V]R<F5I
M;R!G97)O=2!A('-E9W5I;G1E(&UE;G-A9V5M(&1E(&5R<F\Z(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3$*;7-G:60@(E1H92!M
M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO
M;F%L(&UE<W-A9V4Z(@IM<V=S='(@(D\@<V5R=FED;W(@9&4@8V]R<F5I;R!G
M97)O=2!A('-E9W5I;G1E(&UE;G-A9V5M(&EN9F]R;6%T:79A.B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDP"FUS9VED(")4:&4@;6%I;"!S
M97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93HB"FUS9W-T
M<B`B3R!S97)V:61O<B!D92!C;W)R96EO(&=E<F]U(&$@<V5G=6EN=&4@;65N
M<V%G96TZ(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G
M<W1R(")!(&-A:7AA('!O<W1A;"`E<R!JX2!E<W3A('9A>FEA+B(*"B,Z(&QI
M8B]&971C:&UA:6PN<&AP.C(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S
M(&9E=&-H('-I>F4@;&EM:70N(@IM<V=S='(@(B(*(D$@;65N<V%G96T@7"(E
M<UPB(&1E(%PB)7-<(B`H)60@8GET97,I(&5X8V5D974@;R!L:6UI=&4@9&4@
M=&%M86YH;R!P87)A("(*(G1R87IE<BXB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C$P,PIM<V=I9"`B5&AE(&UE<W-A9V4@8F5I;F<@
M8V]M<&]S960@:&%S(&)E96X@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")!
M(&UE;G-A9V5M('-E;F1O(&-O;7!O<W1A(&9O:2!F96-H861A+B!386EN9&\N
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,C8*;7-G:60@
M(E1H92!M97-S86=E(&1O97,@;F]T(&AA=F4@82!3=6)J96-T(&5N=&5R960N
M(@IM<V=S='(@(D$@;65N<V%G96T@;N-O('!O<W-U:2!U;2!!<W-U;G1O+B(*
M"B,Z(&UE<W-A9V4N<&AP.C$T.`IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B02!M96YS86=E;2!F;VD@97AC;'7M9&$N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDW"FUS9VED(")4:&4@
M;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"XB"FUS9W-T<B`B02!M96YS86=E
M;2!F;VD@=F5R:69I8V%D82XB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C,X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!H87,@
M8F5E;B!V97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T<B`B02!M96YS86=E
M;2!F;VD@=F5R:69I8V%D82X@4F5M971E;G1E.B`E<RXB"@HC.B!T96UP;&%T
M97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA=&5S+W!G<"]O
M<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S<&AR87-E('=I
M;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO
M=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R
M("(B"B)!(&IA;F5L82!D92!S96YH82!NXV\@9F]I(&%B97)T82X@5&%L=F5Z
M('9O8^H@=&5N:&$@8V]N9FEG=7)A9&\@<V5U("(*(FYA=F5G861O<B!P87)A
M(&)L;W%U96%R('!O<"UU<',_(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!R87<@=&5X="!O9B!T
M:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B
M3R!T97AT;R!P=7)O(&1A($-H879E(%#Z8FQI8V$@4$=0('!O9&4@<V5R('9I
M<W5A;&EZ861A("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HV
M,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(D\@87)Q=6EV;R!S
M;VQI8VET861O(&[C;R!E>&ES=&4@;F\@86YE>&\@35,M5$Y%1BXB"@HC.B!L
M:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`IM<V=I9"`B5&AE(')E<75E<W1E
M9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H;65N="XB
M"FUS9W-T<B`B3R!A<G%U:79O('-O;&EC:71A9&\@;N-O(&5X:7-T92!N;R!A
M;F5X;R!::7`N(@H*(SH@;65S<V%G92YP:'`Z-34P"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E
M<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F
M<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A
M<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A
M9V4N(@IM<V=S='(@(B(*(D\@<F5M971E;G1E(&1E<W1A(&UE;G-A9V5M(&5S
M=.$@<V]L:6-I=&%N9&\@=6UA($YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\@
M9&4@(@HB365N<V%G96T@9&4@=F]CZB!Q=6%N9&\@=&EV97(@;&ED;R!E<W1A
M(&UE;G-A9V5M+B!0;W(@9F%V;W(@8VQI<75E(&5M("5S("(*(G!A<F$@96YV
M:6%R(&$@;65N<V%G96T@9&4@;F]T:69I8V'GXV\N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z-C<*;7-G:60@(E1H92!S97)V97(@=V%S(&YO
M="!A8FQE('1O(&-R96%T92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*
M;7-G<W1R(")/('-E<G9I9&]R(&[C;R!C;VYS96=U:74@8W)I87(@=6UA(&UI
M;FEA='5R82!D97-T82!I;6%G96TN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YJ<SHY,`IM<V=I9"`B5&AE('-I9VYA='5R92!C;W5L9"!N;W0@
M8F4@<F5P;&%C960N(@IM<V=S='(@(D$@87-S:6YA='5R82!NXV\@</1D92!S
M97(@<W5B<W1I='7M9&$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YJ<SHX.`IM<V=I9"`B5&AE('-I9VYA='5R92!W87,@<W5C8V5S<V9U;&QY
M(')E<&QA8V5D+B(*;7-G<W1R(")!(&%S<VEN871U<F$@9F]I('-U8G-T:71U
M[61A(&-O;2!S=6-E<W-O+B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4Y"FUS9VED
M(")4:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(D\@87)Q=6EV;R!E<W!E8VEF:6-A9&\@;N-O(&5X:7-T92XB"@HC.B!S=&%T
M:6]N97)Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO
M;F5R>2!<(B5S7"(@:&%S(&)E96X@861D960N(@IM<V=S='(@(D\@<&%P96P@
M9&4@8V%R=&$@7"(E<UPB(&9O:2!A9&EC:6]N861O+B(*"B,Z('-T871I;VYE
M<GDN<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")/('!A<&5L(&1E
M(&-A<G1A(%PB)7-<(B!F;VD@97AC;'7M9&\N(@H*(SH@<W1A=&EO;F5R>2YP
M:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E
M<UPB(&AA<R!B965N('5P9&%T960N(@IM<V=S='(@(D\@<&%P96P@9&4@8V%R
M=&$@7"(E<UPB(&9O:2!A='5A;&EZ861O+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ-S`*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D
M('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(D$@=&%R969A(&9O:2!A9&EC
M:6]N861A(&$@<W5A(&QI<W1A(&1E('1A<F5F87,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z.34*;7-G:60@(E1H92!T97AT(&]F('1H92!M
M97-S86=E(@IM<V=S='(@(D\@=&5X=&\@9&$@;65N<V%G96TB"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*
M;7-G<W1R(")/('1E>'1O(&1A(&UE;G-A9V5M('!O9&4@<V5R('9I<W5A;&EZ
M861O("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS
M9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R
M(")/('1E>'1O(&1A(&UE;G-A9V5M(&1E(')E=&]R;F\B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D
M("5S+B(*;7-G<W1R(")/('1E>'1O(&1A(&UE;G-A9V5M(&1E(')E=&]R;F\@
M<&]D92!S97(@=FES=6%L:7IA9&\@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C@*;7-G:60@(E1H92!T97AT(&]F('1H92!S
M96YT(&UE<W-A9V4B"FUS9W-T<B`B3R!T97AT;R!D82!M96YS86=E;2!E;G9I
M861A(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S
M<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")/('1E>'1O(&1A(&UE
M;G-A9V5M(&5N=FEA9&$@<&]D92!S97(@=FES=6%L:7IA9&\@)7,N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U-0IM<V=I9"`B5&AE('5S97(G
M<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E
M9"XB"FUS9W-T<B`B02!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\@9&\@=7-U
MX7)I;R!F;VD@87)M87IE;F%D82!C;VT@<W5C97-S;RXB"@HC.B!L:6(O34E-
M12]6:65W97(O86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@
M;F\@86QT97)N871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92XB"FUS9W-T<B`B3N-O(&5X:7-T96T@<&%R=&5S(&%L=&5R;F%T:79A
M<R!Q=64@<&]D96T@<V5R(&5X:6)I9&%S(&EN8V]R<&]R861A<RXB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]E;7!T>5]M86EL8F]X+FEN8SHS"FUS9VED(")4
M:&5R92!A<F4@;F\@;65S<V%G97,@:6X@=&AI<R!M86EL8F]X+B(*;7-G<W1R
M(").XV\@97AI<W1E;2!M96YS86=E;G,@;F5S=&$@8V%I>&$@<&]S=&%L+B(*
M"B,Z('1H<F5A9"YP:'`Z,3$P"FUS9VED(")4:&5R92!I<R!N;R!T97AT('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D[C;R!E>&ES
M=&5M('!A<G1E<R!A;'1E<FYA=&EV87,@<75E('!O9&5M('-E<B!E>&EB:61A
M<R!I;F-O<G!O<F%D87,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN
M9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R(")(
M;W5V92!U;2!P<F]B;&5M82!A;R!E<W9A>FEA<B!A(&-A:7AA('!O<W1A;"X@
M3R!S97)V:61O<B!D:7-S93H@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O
M<'EI;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES
M('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(DAO=79E('5M
M(&5R<F\@86\@8V]P:6%R(&UE;G-A9V5N<R!D92!<(B5S7"(@<&%R82!<(B5S
M7"(N($ES=&\@Z2!O('%U92!O("(*(G-E<G9I9&]R(&1I<W-E(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C(P-B!L:6(O365S<V%G92YP:'`Z,C(T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@
M(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(B(*(DAO=79E('5M(&5R<F\@
M86\@97AC;'5I<B!M96YS86=E;G,@9&$@<&%S=&$@7"(E<UPB+B!)<W1O(&9O
M:2!O('%U92!O("(*(G-E<G9I9&]R(&1I<W-E(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB
M2&]U=F4@=6T@97)R;R!A;R!E>&-L=6ER(&UE;G-A9V5N<R!N82!P87-T82!<
M(B5S7"(N($ES=&\@Z2!O('%U92!O('-E<G9I9&]R("(*(F1I<W-E(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(B(*(DAO=79E('5M(&5R
M<F\@86\@97AC;'5I<B!A<R!M96YS86=E;G,N($ES=&\@9F]I(&\@<75E(&\@
M<V5R=FED;W(@9&ES<V4Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B2&]U=F4@=6T@
M97)R;R!A;R!E>&-L=6ER(&\@979E;G1O.B`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E<B]E;G)I8VAE9"YP
M:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T(@IM<V=S='(@(DAO=79E('5M(&5R<F\@86\@97AI
M8FER(&5S=&$@<&%R=&4@9&$@;65N<V%G96TB"@HC.B!L:6(O365S<V%G92YP
M:'`Z-3<T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!F;&%G9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@
M5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)(
M;W5V92!U;2!E<G)O(&%O(&UA<F-A<B!A<R!M96YS86=E;G,@;F5S=&$@<&%S
M=&$@7"(E<UPB+B!)<W1O(.D@;R!Q=64@;R`B"B)S97)V:61O<B!D:7-S92(*
M"B,Z(&9O;&1E<G,N<&AP.C$T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G<W1R(")(;W5V92!U
M;2!E<G)O(&%O(&EM<&]R=&%R("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")(;W5V
M92!U;2!E<G)O(&%O(&EM<&]R=&%R(&\@979E;G1O.B`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,38W"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*
M;7-G<W1R(")(;W5V92!U;2!E<G)O(&%O(&EM<&]R=&%R(&$@=&%R969A.B`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E
M<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(DAO=79E
M('5M(&5R<F\@86\@:6UP;W)T87(@82!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A
M9&\@9&\@=7-UX7)I;SH@)7,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I
M;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(DAO=79E('5M(&5R
M<F\@86\@;6]V97(@;65N<V%G96YS(&1E(%PB)7-<(B!P87)A(%PB)7-<(BX@
M27-T;R#I(&\@<75E(&\@(@HB<V5R=FED;W(@9&ES<V4B"@HC.B!C;VUP;W-E
M+G!H<#HQ,C@P"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H
M:7,@;65S<V%G92!A<R!A(&1R869T+B(*;7-G<W1R(")(;W5V92!U;2!E<G)O
M(&%O('-A;'9A<B!E<W1A(&UE;G-A9V5M(&-O;6\@<F%S8W5N:&\N(@H*(SH@
M8V]M<&]S92YP:'`Z,3`S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM<V=S='(@
M(DAO=79E('5M(&5R<F\@86\@96YV:6%R(&5S=&$@;65N<V%G96TZ("5S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT
M.B`E<RXB"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!A='5A;&EZ87(@;R!E
M=F5N=&\Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*
M;7-G:60@(E1H97)E('=A<R!N;R!T97AT(&EN('1H:7,@;65S<V%G92!P87)T
M(@IM<V=S='(@(D[C;R!H879I82!T97AT;R!N97-T82!P87)T92!D82!M96YS
M86=E;2(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G:60@
M(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N
M(@IM<V=S='(@(D5S=&$@;65N<V%G96T@2%1-3"!T96T@:6UA9V5N<R!I;F-O
M<G!O<F%D87,@82!E;&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.CDS"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M
M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T
M:&ES.B`B"FUS9W-T<B`B(@HB17-T82!M96YS86=E;2!(5$U,('1E;2!I;6%G
M96YS(&EN8V]R<&]R861A<R!A(&5L82X@26UA9V5N<R!B;&]Q=65A9&%S("(*
M(F%P87)E8V5M(&1E<W1A(&9O<FUA.B`B"@HC.B!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HQ-C4*;7-G:60@(E1H:7,@4$=0(%!U8FQI8R!+97D@=V%S(&%T
M=&%C:&5D('1O('1H92!M97-S86=E+B(*;7-G<W1R(")!($-H879E(%#Z8FQI
M8V$@4$=0(&9O:2!A;F5X861A(&$@97-T82!M96YS86=E;2XB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,3`U(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,3D*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T-"!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,34X"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-S0@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q-0IM<V=I
M9"`B5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B17-T
M82!AY^-O(&[C;R#I('-U<&]R=&%D82XB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3@P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,C`*;7-G
M:60@(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S
M='(@(D5S=&$@8>?C;R!A:6YD82!NXV\@97-TX2!I;7!L96UE;G1A9&$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B
M5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B27-T;R!P;V1E(&QE=F%R(&%L9W5M
M('1E;7!O+B!6;V/J('1E;2!C97)T97IA('%U92!Q=65R('!R;W-S96=U:7(_
M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,`IM<V=I
M9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N(@IM
M<V=S='(@(D5S=&$@;65N<V%G96T@8V]N=.EM('5M(&%R<75I=F\@36%C:6YT
M;W-H+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$U"FUS9VED
M("(B"B)4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T
M(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS
M9W-T<B`B(@HB17-T82!M96YS86=E;2!C;VYTZ6T@=6T@86YE>&\@<75E(&9O
M:2!A<W-I;F%D;R!D:6=I=&%L;65N=&4@8V]M(%,O34E-12XB"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.0IM<V=I9"`B5&AI<R!M97-S86=E
M(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R>7!T
M960@=FEA(%,O34E-12XB"FUS9W-T<B`B17-T82!M96YS86=E;2!C;VYTZ6T@
M=6T@86YE>&\@<75E(&9O:2!C<FEP=&]G<F%F861O(&-O;2!3+TU)344N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B"B)4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF
M;W)M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G92!I
M<R!U;FMN;W=N+B(*;7-G<W1R("(B"B)%<W1A(&UE;G-A9V5M(&-O;G3I;2!I
M;F9O<FUAY^-O(&1E('-I='5AY^-O(&1E(&5N=')E9V$L(&UA<R!O(&9O<FUA
M=&\@9&$@(@HB;65N<V%G96T@Z2!D97-C;VYH96-I9&\N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,S$Y"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M
M97-S86=E+B!%<G)O<CH@(@IM<V=S='(@(B(*(D5S=&$@;65N<V%G96T@;N-O
M('!A<F5C92!S97(@=6UA(&UE;G-A9V5M(';A;&ED82!C<FEP=&]G<F%F861A
M(&-O;2!01U`N("(*(D5R<F\Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(S.2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS-30*;7-G:60@(B(*
M(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O
M<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB
M"FUS9W-T<B`B(@HB17-T82!M96YS86=E;2!NXV\@<&%R96-E(&5S=&%R(&YO
M(&9O<FUA=&\@8V]R<F5T;R!01U`@*&1E(&%C;W)D;R!C;VT@82!21D,@(@HB
M,C`Q-2DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S`*;7-G
M:60@(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE
M(&-O<G)E8W0@4R]-24U%(&9O<FUA="XB"FUS9W-T<B`B17-T82!M96YS86=E
M;2!NXV\@<&%R96-E(&5S=&%R(&YO(&9O<FUA=&\@8V]R<F5T;R!3+TU)344N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`T(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C0R,`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N
M(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"XB"FUS9W-T<B`B17-T82!M96YS
M86=E;2!F;VD@87-S:6YA9&$@9&EG:71A;&UE;G1E(&-O;2!01U`N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S
M<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM
M<V=S='(@(D5S=&$@;65N<V%G96T@9F]I(&%S<VEN861A(&1I9VET86QM96YT
M92!C;VT@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,3,Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,X"FUS9VED(")4:&ES
M(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S
M='(@(D5S=&$@;65N<V%G96T@9F]I(&-R:7!T;V=R869A9&$@8V]M(%,O34E-
M12XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#`@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,CDP"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E
M96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R(")%<W1A(&UE;G-A9V5M
M(&9O:2!C<FEP=&]G<F%F861A(&-O;2!01U`N(@H*(SH@;65S<V%G92YP:'`Z
M,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T<B`B17-T82!M96YS
M86=E;2!P87)A(@H*(SH@86-L+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D\@
M<V5R=FED;W(@;N-O('-U<&]R=&$@<&%S=&%S(&-O;7!A<G1I;&AA9&%S+B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`Y"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&$@8V]M<&]S92!W
M:6YD;W<N(@IM<V=S='(@(D5S=&$@:F%N96QA(&1E=F4@<V5R(&%B97)T82!A
M('!A<G1I<B!D82!J86YE;&$@9&4@8V]M<&]S:>?C;RXB"@HC.B!T:')E860N
M<&AP.C$U-PIM<V=I9"`B5&AR96%D($1I<W!L87DB"FUS9W-T<B`B17AI8FGG
MXV\@9&$@1&ES8W5S<^-O(@H*(SH@=&AR96%D+G!H<#HW-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3$Q"FUS9VED(")4:')E860@5FEE=R(*;7-G<W1R(")6
M:7-U86QI>F'GXV\@9&4@1&ES8W5S<_5E<R(*"B,Z(&UE<W-A9V4N<&AP.C(W
M-"!M86EL8F]X+G!H<#HU.3(@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHR,B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H
M+G!H<#HU.3,*;7-G:60@(E1O(@IM<V=S='(@(E!A<F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3`X"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@
M(D5N9&5R9>=O(&1O(&1E<W1I;F%TX7)I;R`B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM<V=S='(@(B(*
M(E!A<F$@<V5L96-I;VYA<B!VX7)I;W,@8V%M<&]S+"!S96=U<F4@0V]N=')O
M;"`H4$,I(&]U($-O;6UA;F0@*$UA8RD@86\@(@HB8VQI8V%R+B(*"B,Z(&QI
M8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@82!43%,@
M8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@;V8@
M4$A0(#4N,"XV(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B(@HB4&%R82!U=&EL
M:7IA<B!U;6$@8V]N97CC;R!43%,L('9O8^H@9&5V92!E<W1A<B!U=&EL:7IA
M;F1O(%!(4"`U+C`N-B!O=2`B"B)S=7!E<FEO<BXB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHU.3$*;7-G:60@(E1O=&%L($%T=&%C:&UE
M;G1S(%-I>F4Z(@IM<V=S='(@(E1A;6%N:&\@5&]T86P@9&]S($%N97AO<SHB
M"@HC.B!F;VQD97)S+G!H<#HS-CD*;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G
M<W1R("),:7AE:7)A(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T
M+FEN8SHR,PIM<V=I9"`B5')A<V@@9F]L9&5R.B(*;7-G<W1R("),:7AE:7)A
M.B(*"B,Z(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C0@;&EB+U%U;W1A+VUE<F-U
M<GDS,BYP:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<Q"B,Z(&QI8B]1
M=6]T82]L;V=F:6QE+G!H<#HX."!L:6(O475O=&$O8V]U<FEE<BYP:'`Z-3,@
M;&EB+U%U;W1A+VUD865M;VXN<&AP.C0X"FUS9VED(")5;F%B;&4@=&\@<F5T
M<FEE=F4@<75O=&$B"FUS9W-T<B`B26UP;W-S[79E;"!O8G1E<B!Q=6]T82(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3`@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ.0HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,V"FUS9VED(")5;F%N<W=E<F5D(@IM<V=S
M='(@(D[C;R!297-P;VYD:61A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")-
M96YS86=E;G,@;N-O(')E<W!O;F1I9&%S(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,3,*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(E)E<W1A=7)A
M<B(*"B,Z(&UA:6QB;W@N<&AP.C4W-2!M86EL8F]X+G!H<#HU.#@@;&EB+TU)
M344O2&5A9&5R<RYP:'`Z,C`T"FUS9VED(")5;F1I<V-L;W-E9"!296-I<&EE
M;G1S(@IM<V=S='(@(D1E<W1I;F%TX7)I;W,@3N-O(%)E=F5L861O<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R
M(")#;VUP;VYE;G1E(&[C;R!S=7!O<G1A9&\@9&\@=&EP;SH@)7,B"@HC.B!M
M86EL8F]X+G!H<#HU-34*;7-G:60@(E5N:VYO=VX@1&%T92(*;7-G<W1R(")$
M871A($1E<V-O;FAE8VED82(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,SDU
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@24U!4"!R97-P;VYS92!F
M<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD960Z("5S(@IM<V=S='(@
M(E)E<W!O<W1A(&1E<V-O;FAE8VED82!D;R!S97)V:61O<B!)34%0.B!O(%-E
M<G9I9&]R(%)E<W!O;F1E=3H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C(V"FUS9VED(")5;FMN;W=N($UE971I;F<B"FUS9W-T<B`B4F5U
M;FGC;R!$97-C;VYH96-I9&$B"@HC.B!M86EL8F]X+G!H<#HV,#0*;7-G:60@
M(E5N:VYO=VX@4F5C:7!I96YT(@IM<V=S='(@(D1E<W1I;F%TX7)I;R!$97-C
M;VYH96-I9&\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P:')A
M<V4B"FUS9W-T<B`B1&5S8V%R<F5G87(@4V5N:&$B"@HC.B!F971C:&UA:6QP
M<F5F<RYP:'`Z-C4*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B4V5M($YO;64B
M"@HC.B!M97-S86=E+G!H<#HU,#(@;6%I;&)O>"YP:'`Z-CDS('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S(*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHU"FUS
M9VED(")5;G-E96XB"FUS9W-T<B`B3N-O($QI9&$B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O
M;2!&;VQD97(H<RDB"FUS9W-T<B`B1&5S:6YS8W)E=F5R+7-E(&1A*',I(%!A
M<W1A*',I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$U
M"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B071U86QI>F%R(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C8Q,@IM<V=I9"`B57!D871E(')E<W!O;F1E
M;G0@<W1A='5S(@IM<V=S='(@(D%T=6%L:7IA<B!S:71U8>?C;R!D82!R97-P
M;W-T82(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU."!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B16YV:6%R(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL
M<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U;'0@5F%L=64B"FUS9W-T
M<B`B571I;&EZ87(@5F%L;W(@4&%D<N-O(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(U-@IM<V=I9"`B57-E($E-05`@9F]L9&5R('-U8G-C<FEP=&EO
M;G,_(@IM<V=S='(@(E5T:6QI>F%R(&EN<V-R:>?U97,@9&4@<&%S=&%S($E-
M05`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<R-`IM<V=I9"`B57-E
M(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*;7-G<W1R(")5=&EL:7IA<B!,:7AE
M:7)A(%9I<G1U86P_(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$T,PIM
M<V=I9"`B57-E<B(*;7-G<W1R(")5<W7A<FEO(@H*(SH@86-L+G!H<#HX-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C97-S9G5L
M;'D@9VEV96X@=&AE('-P96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R("(B"B)&;W)A;2!C;VYC961I9&%S(&-O;2!S=6-E
M<W-O(&%S('!E<FUI<W/U97,@<&%R82!O('5S=>%R:6\@)R5S)R!N82!P87-T
M82`G)7,G+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<V"FUS
M9VED(")5<V5R;F%M92(*;7-G<W1R(")5<W7A<FEO(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS
M9W-T<B`B57-UX7)I;SHB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW-PIM<V=I9"`B5FEE=R(*;7-G<W1R(")697(B"@HC.B!L:6(O34E-
M12]6:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z
M,3$P"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5F5R
M("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(E9E<B!#:&%V92!0^F)L:6-A("5S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0IM<V=I9"`B5FEE=R!(
M5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B5F5R
M(&-O;G1E^F1O($A434P@96T@=6UA(&IA;F5L82!S97!A<F%D82(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X"FUS9VED(")6:65W($UE
M<W-A9V5S(@IM<V=S='(@(E9E<B!-96YS86=E;G,B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM
M<V=I9"`B5FEE=R!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R(")697(@
M0VAA=F4@4')I=F%D82!097-S;V%L(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(E9I
M97<@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R(")697(@0VAA=F4@4/IB
M;&EC82!097-S;V%L(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C$X"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R(")697(@
M1&ES8W5S<^-O(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38T
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V-@IM<V=I9"`B5FEE=R!4
M:'5M8FYA:6PB"FUS9W-T<B`B5F5R($UI;FEA='5R82(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z-#(S"FUS9VED(")6:65W(&%T=&%C:&UE;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B5F5R(&%N97AO(&5M('5M
M82!J86YE;&$@82!P87)T92(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D
M+G!H<#HW.0IM<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN
M9&]W(@IM<V=S='(@(E9I<W5A;&EZ87(@;R!C;VYT9?ID;R!E;2!U;6$@:F%N
M96QA('-E<&%R861A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T
M,0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R(")697(@979E;G1O(@H*(SH@
M9F]L9&5R<RYP:'`Z,S8Q(&UA:6QB;W@N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S(@IM<V=S='(@(E9E<B!M96YS
M86=E;G,@96T@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S
M96QE8W0N:6YC.C(S"FUS9VED(")6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA
M>2!A9G1E<B!L;V=I;CHB"FUS9W-T<B`B5FESXV\@;W4@8V%I>&$@<&]S=&%L
M(&$@97AI8FER(&%P\W,@8V]N96-T87(Z(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$W,0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(E9E<B!T
M87)E9F$B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`T"FUS9VED
M(")6:65W('1H92!);6%G97,B"FUS9W-T<B`B5F5R(&%S($EM86=E;G,B"@HC
M.B!S96%R8V@N<&AP.C(V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L
M($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`B
M4&%S=&$@5FER='5A;"!<(B5S7"(@8W)I861A(&-O;2!S=6-E<W-O+B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3$Q(&QI8B])34%0+U1R964N
M<&AP.C$T,2!L:6(O24U!4"]4<F5E+G!H<#HQ-30*(SH@;&EB+TE-05`O5')E
M92YP:'`Z,34V(&QI8B])34%0+U1R964N<&AP.C$V,"!L:6(O24U!4"]4<F5E
M+G!H<#HQ-C$*(SH@;&EB+TE-05`O5')E92YP:'`Z,S<Q(&QI8B])34%0+U1R
M964N<&AP.C,Y-2!L:6(O24U!4"]4<F5E+G!H<#HT,S,*;7-G:60@(E9I<G1U
M86P@1F]L9&5R<R(*;7-G<W1R(")087-T87,@5FER='5A:7,B"@HC.B!S96%R
M8V@N<&AP.C(U,@IM<V=I9"`B5FER='5A;"!&;VQD97)S(')E<75I<F4@82!L
M86)E;"XB"FUS9W-T<B`B4&%S=&%S(%9I<G1U86ES(&YE8V5S<VET86T@9&4@
M=6T@;F]M92XB"@HC.B!L:6(O4V5A<F-H+G!H<#HT,C`*;7-G:60@(E9I<G1U
M86P@24Y"3U@B"FUS9W-T<B`B3&EX96ER82!6:7)T=6%L(@H*(SH@9F]L9&5R
M<RYP:'`Z,SDW"FUS9VED(")6:7)T=6%L($E.0D]8($9O;&1E<B(*;7-G<W1R
M(")#86EX82!D92!%;G1R861A(%9I<G1U86PB"@HC.B!L:6(O36%I;&)O>"YP
M:'`Z,34V(&QI8B]396%R8V@N<&AP.C,V-@IM<V=I9"`B5FER='5A;"!4<F%S
M:"(*;7-G<W1R("),:7AE:7)A(%9I<G1U86PB"@HC.B!F;VQD97)S+G!H<#HS
M.30*;7-G:60@(E9I<G1U86P@5')A<V@@1F]L9&5R(@IM<V=S='(@(DQI>&5I
M<F$@5FER='5A;"(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(X
M"FUS9VED(")6:7)T=6%L(&9O;&1E<B!L86)E;"(*;7-G<W1R(").;VUE(&1A
M('!A<W1A('9I<G1U86PB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C,W.0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!=FES;R(*"B,Z(&QO9VEN
M+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R(")"96TM=FEN9&\@86\@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C`W"FUS9VED("(B"B)7:&%T('-H;W5L9"!W92!D;R!W:71H('-P
M86T@;65S<V%G97,@869T97(@=&AE>2!H879E(&)E96X@<F5P;W)T960@87,@
M<W!A;2`B"B)O<B!I;FYO8V5N=#\B"FUS9W-T<B`B(@HB3R!Q=64@9F%Z97(@
M8V]M('-P86US(&%P\W,@96QE<R!T97)E;2!S:61O(')E<&]R=&%D;W,@8V]M
M;R!S<&%M(&]U(&EN;V-E;G1E<S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S$V"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E
M('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG
M("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HB06\@97AC;'5I<B!M
M96YS86=E;G,L(&UO=NHM;&%S('!A<F$@82!,:7AE:7)A(&%O(&EN=NES(&1E
M(&UA<F/A+6QA<R!C;VUO("(*(F5X8VQU[61A<S\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#DV"FUS9VED(")7:&5N(&]P96YI;F<@82!N97<@;6%I
M;&)O>"P@=VAI8V@@<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\B"FUS
M9W-T<B`B475A;F1O(&%B<FER('5M82!N;W9A(&-A:7AA('!O<W1A;"P@96T@
M<75E('#A9VEN82!V;V/J('%U97(@:6YI8VEA<C\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL
M('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B06\@
M<V%L=F%R(&5N=FEA9&]S+"!D979E<F5M;W,@<V%L=F%R(&]S(&%N97AO<S\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(V"FUS9VED("(B"B)7:&5N
M('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O
M;6%I;B!S:&]U;&0@=V4@87!P96YD('1O("(*(G5N<75A;&EF:65D(&%D9')E
M<W-E<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@7")`7"(I/R(*;7-G<W1R
M("(B"B)!;R!E;G9I87(@;65N<V%G96YS(&]U(&5X<&%N9&ER(&5N9&5R9>=O
M<RP@<75A;"!D;VWM;FEO(&1E=F5RX2!S97(@:6YC;'7M9&\@(@HB96T@=6T@
M96YD97)EYV\@;N-O('%U86QI9FEC861O("AE;F1E<F7G;R!D92!E+6UA:6P@
M<V5M(%PB0%PB*3\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*
M;7-G:60@(E=H:71E;&ES="(*;7-G<W1R("),:7-T82!"<F%N8V$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,SD@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-34R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-C<*;7-G:60@(EEE<R(*;7-G<W1R(")3:6TB"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C4X"FUS9VED(")9;W4@
M87)E(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A
M8V-O=6YT*',I.B(*;7-G<W1R(")6;V/J(&5S=&$@<')E<W1E<R!A('1R87IE
M<B!M96YS86=E;G,@9&$H<RD@<V5G=6EN=&4H<RD@8V]N=&$H<RDZ(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3`*;7-G
M:60@(B(*(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A
M9V5S(&-O;G1A:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<B(*(BAS*2XB
M"FUS9W-T<B`B(@HB5F]CZB!E<W3A('1E;G1A;F1O(&5X8VQU:7(@=&]D87,@
M87,@;65N<V%G96YS(&-O;G1I9&%S(&YA*',I('-E9W5I;G1E*',I("(*(G!A
M<W1A*',I+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER
M;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@
M=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(E9O8^H@97-TX2!T
M96YT86YD;R!E>&-L=6ER(&$H<RD@<V5G=6EN=&4H<RD@<&%S=&$H<RDN(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA
M=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@87)E
M(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B5F]C
MZB!E<W3A(&-O<&EA;F1O+VUO=F5N9&\@<&%R82!U;6$@;F]V82!P87-T82XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM<V=I
M9"`B66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@(@IM<V=S='(@
M(E9O8^H@97-TX2!C<FEA;F1O('5M82!S=6)P87-T82!E;2`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-@IM<V=I9"`B66]U(&%R
M92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N(@IM<V=S='(@(E9O8^H@
M97-TX2!C<FEA;F1O('5M82!P87-T82!P<FEN8VEP86PN(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,S$U"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!F;VQD97)S+B(*;7-G<W1R(")6;V/J(&5S=.$@8W)I86YD;R!U;6$@
M<&%S=&$@<')I;F-I<&%L+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T
M92!M;W)E('1H86X@)60@9F]L9&5R<RXB"FUS9W-T<B`B5F]CZB!NXV\@97-T
MX2!A=71O<FEZ861O(&$@8W)I87(@;6%I<R!D92`E9"!P87-T87,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,S<*;7-G:60@(EEO
M=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E<CH@(@IM<V=S='(@(E9O8^H@97-T
MX2!R96YO;65A;F1O(&$@<&%S=&$Z("(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@
M8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A
M=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G92!C
M;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB"FUS9W-T<B`B(@HB5F]C
MZB!P;V1E('5T:6QI>F%R(&]S('-E9W5I;G1E<R!D96QI;6ET861O<F5S(&YO
M('1E>'1O(&1O('!A<&5L(&1E(&-A<G1A.B`E8R`B"B)P87)A(&$@;65N<V%G
M96T@871U86P[("5S('!A<F$@82!A<W-I;F%T=7)A+B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N;F]T('5N
M<W5B<V-R:6)E(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")6;V/J(&[C;R!P;V1E
M('-E(&1E<VEN<V-R979E<B!D92!<(B5S7"(N(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D
M:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N
M="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S
M='(@(B(*(E9O8^H@;N-O(&-O;F-O<F1O=2!C;VT@;W,@5&5R;6]S(&1E(%-E
M<G9IYV\L('-E;F1O(&%S<VEM('9O8^H@;N-O(&9O:2`B"B)A=71O<FEZ861O
M(&$@8V]N96-T87(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$W,`IM
M<V=I9"`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C
M8V5S<R!T;R!T:&ES(&9O;&1E<B(*;7-G<W1R(")6;V/J(&[C;R!T96T@<&5R
M;6ES<^-O('!A<F$@86QT97)A<B!O(&%C97-S;R!A(&5S=&$@<&%S=&$B"@HC
M.B!L:6(O36%I;&QO9RYP:'`Z,3,P"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W
M:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R("(B"B)6;V/J(&5N8V%M:6YH
M;W4@97-T82!M96YS86=E;2!E;2`E)7,@<&%R82!O<R!S96=U:6YT97,@9&5S
M=&EN873A<FEO<SH@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N
M:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE
M<W-A9V5S+B(*;7-G<W1R(")6;V/J('1E;2`E<R!N;W9A<R!M96YS86=E;G,N
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO
M=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(E9O8^H@=&5M(#$@;F]V
M82!M96YS86=E;2XB"@HC.B!C;VUP;W-E+G!H<#HT.#(*;7-G:60@(EEO=2!H
M879E(&%L<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T<B`B5F]C
MZB!JX2!E;G9I;W4@97-T82!PX6=I;F$N(@H*(SH@;&EB+TE-4"YP:'`Z,3`R
M,PIM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO=VEN9R!F
M;VQD97(Z(@IM<V=S='(@(E9O8^H@=&5M(&YO=F%S(&UE;G-A9V5N<R!N82!S
M96=U:6YT92!P87-T83HB"@HC.B!L:6(O24U0+G!H<#HQ,#(X"FUS9VED(")9
M;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM
M<V=S='(@(E9O8^H@=&5M(&YO=F%S(&UE;G-A9V5N<R!N87,@<V5G=6EN=&5S
M('!A<W1A<SHB"@HC.B!C;VUP;W-E+G!H<#HQ-3,*;7-G:60@(EEO=2!M=7-T
M(&5N=&5R(&%T(&QE87-T(&]N92!R96-I<&EE;G0N(@IM<V=S='(@(E9O8^H@
M9&5V92!F;W)N96-E<B!P96QO(&UE;F]S('5M(&1E<W1I;F%TX7)I;RXB"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,#8*;7-G:60@(B(*(EEO=2!M
M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E
M(&ME>2!T;R!V:65W('1H:7,@;65S<V%G92(*;7-G<W1R("(B"B)6;V/J(&1E
M=F4@9F]R;F5C97(@82!S96YH82!P87)A('-U82!C:&%V92!P<FEV861A(%!'
M4"!P87)A('9I<W5A;&EZ87(@97-T82`B"B)M96YS86=E;2(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P:V-S-RYP:'`Z,C4T"FUS9VED("(B"B)9;W4@;75S="!E
M;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K
M97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS9W-T<B`B(@HB5F]CZB!D
M979E(&9O<FYE8V5R(&$@<V5N:&$@<&%R82!S=6$@8VAA=F4@<')I=F%D82!3
M+TU)344@<&%R82!V:7-U86QI>F%R("(*(F5S=&$@;65N<V%G96TB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHV-"!T96UP;&%T97,O
M;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+B(*;7-G<W1R(")6;V/J(&1E
M=F4@<V5L96-I;VYA<B!U;6$@8V%I>&$@<&]S=&%L(&1E(&1E<W1I;F\@<')I
M;65I<F\N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R
M(")6;V/J(&1E=F4@<V5L96-I;VYA<B!U;6$@8V]N=&$@<&%R82!E>&-L=6ER
M+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z.#$*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R
M(")6;V/J(&1E=F4@<V5L96-I;VYA<B!U;2!E;F1E<F7G;R!P<FEM96ER;RXB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8S"FUS9VED(")9;W4@;75S="!S
M96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@(E9O
M8^H@9&5V92!S96QE8VEO;F%R('!E;&\@;65N;W,@=6UA(&UE;G-A9V5M('!R
M:6UE:7)O+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ
M,PIM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="XB"FUS9W-T
M<B`B5F]CZB!D979E(&5S<&5C:69I8V%R('5M(&1E<W1I;F%TX7)I;RXB"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@96YA8FQE9"!I
M;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@(E9O8^H@<')E
M8VES82!E<W1A<B!C;VT@7"(E<UPB(&AA8FEL:71A9&\@;F%S(&]PY_5E<R!D
M92!M86YU=&5NY^-O+B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(')E9&ER96-T960@=&AI<R!M97-S86=E('1O
M("5S(&]N("4E<RXB"FUS9W-T<B`B5F]CZB!R961I<F5C:6]N;W4@97-T82!M
M96YS86=E;2!P87)A("5S(&5M("4E<RXB"@HC.B!L:6(O36%I;&QO9RYP:'`Z
M,30R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!R97!L:65D('1O('1H:7,@
M;65S<V%G92!O;B`E<RXB"FUS9W-T<B`B5F]CZB!R97!L:6-O=2!E<W1A(&UE
M;G-A9V5M(&5M("5S+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4P-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S
M7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B5F]C
MZB!NXV\@9F]I(&EN<V-R:71O(&5M(%PB)7-<(BX@07%U:2!E<W3A(&\@<75E
M(&\@<V5R=FED;W(@9&ES<V4B"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F
M<F]M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G
M<W1R(")6;V/J(&[C;R!F;VD@9&5S:6YS8W)I=&\@9&4@7"(E<UPB+B!!<75I
M(&5S=.$@;R!Q=64@;R!S97)V:61O<B!D:7-S92(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C4Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S
M9G5L;'D@<W5B<V-R:6)E9"!T;R!<(B5S7"(B"FUS9W-T<B`B5F]CZB!F;VD@
M:6YS8W)I=&\@96T@7"(E<UPB(&-O;2!S=6-E<W-O(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-38R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E
M<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B5F]C
MZB!F;VD@9&5S:6YS8W)I=&\@9&4@7"(E<UPB(&-O;2!S=6-E<W-O(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`B4V5U($YO;64B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-3`*
M;7-G:60@(EEO=7(@4$=0(%!U8FQI8R]0<FEV871E($ME>7,B"FUS9W-T<B`B
M4W5A<R!#:&%V97,@4/IB;&EC82]0<FEV861A(%!'4"(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-S$@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<V
M"FUS9VED(")9;W5R(%!R:79A=&4@2V5Y(@IM<V=S='(@(E-U82!#:&%V92!0
M<FEV861A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-R!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S$*;7-G:60@(EEO=7(@4'5B;&EC($ME>2(*
M;7-G<W1R(")3=6$@0VAA=F4@4/IB;&EC82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-C4*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE
M;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`B4V5U(&5N9&5R9>=O(%)E<W!O
M;F1E<BU087)A.B`\96T^*&]P8VEO;F%L*3PO96T^(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHT.0IM<V=I9"`B66]U<B!3+TU)344@4'5B;&EC
M+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@(E-E=7,@0V5R=&EF:6-A
M9&]S(%#Z8FQI8V\O4')I=F%D;R!3+TU)344B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHQ-@IM<V=I9"`B66]U<B!A8V-O
M=6YT<SHB"FUS9W-T<B`B4W5A<R!C;VYT87,Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$W,PIM<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z
M(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L
M:6YE*3PO96T^(@IM<V=S='(@(B(*(E-E=7,@96YD97)EYV]S('-E8W5N9.%R
M:6]S("AA;&EA<RDZ(#QI/BAO<&-I;VYA;"P@<')E96YC:&$@8V%D82!E;F1E
M<F7G;R!E;2`B"B)U;6$@;F]V82!L:6YH82D\+VD^(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z,3`Q"FUS9VED(")9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!I;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y
M<&4N(@IM<V=S='(@(E-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@97AI8FGG
MXV\@:6YC;W)P;W)A9&$@9&5S=&4@=&EP;R!D92!I;6%G96TN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D969A=6QT(&-H
M87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(E-E=2!C;VYJ
M=6YT;R!D92!C87)A8W1E<F5S('!A9'+C;R!P87)A(&5N=FEA<B!M96YS86=E
M;G,Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC.C$*
M;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N
M9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B4V5U(&WI=&]D;R!D92!C<FEP=&]G
M<F%F:6$@<&%D<N-O('!A<F$@96YV:6%R(&UE;G-A9V5N<SHB"@HC.B!A='1A
M8VAM96YT+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&QI
M;FME9"!A='1A8VAM96YT(&AA<R!B965N(&1O=VYL;V%D960@8GD@870@;&5A
M<W0@;VYE('5S97(N7&XB"B)<;B(*(D%T=&%C:&UE;G0@;F%M93H@)7-<;B(*
M(D%T=&%C:&UE;G0@9&%T93H@)7-<;B(*(EQN(@HB0VQI8VL@;VX@=&AE(&9O
M;&QO=VEN9R!L:6YK('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&4@871T86-H
M;65N=#I<;B(*(B5S(@IM<V=S='(@(B(*(E-E=2!A;F5X;R!F;VD@8F%I>&%D
M;R!P;W(@<&5L;R!M96YO<R!U;2!U<W7A<FEO+EQN(@HB7&XB"B).;VUE(&1O
M(&%N97AO.B`E<UQN(@HB1&%T82!D;R!A;F5X;SH@)7-<;B(*(EQN(@HB0VQI
M<75E(&YO(&QI;FL@82!S96=U:7(@<&%R82!E>&-L=6ER('!E<FUA;F5N=&5M
M96YT92!O(&%N97AO.EQN(@HB)7,B"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HX.0IM<V=I9"`B66]U<B!M97-S86=E('=A<R!S=6-C97-S9G5L
M;'D@9&5L:79E<F5D+B(*;7-G<W1R(")3=6$@;65N<V%G96T@9F]I(&5N=FEA
M9&$@8V]M('-U8V5S<V\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P
M-@IM<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM<V=S='(@(E-U82!A<W-I;F%T
M=7)A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V%D9')E<W-E<T)L;V-K
M<RYJ<SHW"FUS9VED(");2&ED92!!9&1R97-S97-=(@IM<V=S='(@(EM/8W5L
M=&%R($5N9&5R9>=O<UTB"@HC.B!M97-S86=E+G!H<#HR.3@@8V]M<&]S92YP
M:'`Z,3,P,2!M86EL8F]X+G!H<#HU,S,@;&EB+T-O;7!O<V4N<&AP.C@S.`IM
M<V=I9"`B6TYO(%-U8FIE8W1=(@IM<V=S='(@(EM396T@07-S=6YT;UTB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N:G,Z.`IM
M<V=I9"`B6U-H;W<@061D<F5S<V5S("TB"FUS9W-T<B`B6T5X:6)I<B!%;F1E
M<F7G;W,@+2(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(");4VAO=R!A9&1R97-S97,@+2`E<R!R96-I<&EE;G1S
M72(*;7-G<W1R(");17AI8FER(&5N9&5R9>=O<R`M("5S(&1E<W1I;F%TX7)I
M;W-=(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"FUS
M9VED(")?0F-C(@IM<V=S='(@(D-C7V\B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,38*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B3&ES=&$@
M7TYE9W)A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,34T
M"FUS9VED(")?0V,B"FUS9W-T<B`B7T-C(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ
M,`IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")%7WAC;'5I<B(*"B,Z(&QI8B])
M35`N<&AP.CDR.0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`B7U!A<W1A<R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C@Q"FUS9VED(")?
M261E;G1I='DB"FUS9W-T<B`B7TED96YT:61A9&4B"@HC.B!L:6(O24U0+G!H
M<#HX.3@*;7-G:60@(E]);F)O>"(*;7-G<W1R(")#86EX82!D92!?16YT<F%D
M82(*"B,Z(&QI8B])35`N<&AP.CDW,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T
M<B`B7T1E<V-O;F5C=&%R(@H*(SH@;65S<V%G92YP:'`Z,SDQ"FUS9VED(")?
M365S<V%G92!3;W5R8V4B"FUS9W-T<B`B0_-D:5]G;R!&;VYT92!D82!-96YS
M86=E;2(*"B,Z(&QI8B])35`N<&AP.CDR-@IM<V=I9"`B7TYE=R!-97-S86=E
M(@IM<V=S='(@(DYO=F$@;65N<V%G96TB"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E]0<FEN="(*;7-G<W1R
M("))7VUP<FEM:7(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHR-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@Y"FUS9VED
M(")?4')I;W)I='DB"FUS9W-T<B`B4')?:6]R:61A9&4B"@HC.B!M86EL8F]X
M+G!H<#HT,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7U)E9G)E<V@@)7,B"FUS
M9W-T<B`B071U86QI7WIA<B`E<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")?4F5P;'DB"FUS9W-T<B`B4F5?
M<W!O;F1E<B(*"B,Z(&QI8B])35`N<&AP.CDS,0IM<V=I9"`B7U-E87)C:"(*
M;7-G<W1R(")097-?<75I<V%R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(X
M"FUS9VED(")?4V5N9"!-97-S86=E(@IM<V=S='(@(D5N=FEA<B!?365N<V%G
M96TB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C,R"FUS9VED(")?5&AR96%D(@IM<V=S='(@(D1I<V-?=7-SXV\B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*;7-G:60@(E]4;R(*
M;7-G<W1R(")087)?82(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$S"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`B7U)E<W1A=7)A<B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM
M<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S='(@(E]697(@1&ES8W5S<^-O(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")?5VAI=&5L
M:7-T(@IM<V=S='(@(DQI<W1A(%]"<F%N8V$B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3<U"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")D97-T
M:6YA=.%R:6\@9&5S8V]N:&5C:61O(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0U
M,0IM<V=I9"`B871T86-H;65N="(*;7-G<W1R(")A;F5X;R(*"B,Z('9I97<N
M<&AP.CDW"FUS9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B86YE>&]S
M+GII<"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PIM
M<V=I9"`B8GET97,B"FUS9W-T<B`B8GET97,B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3DY"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S
M='(@(FEM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!D92!D97-T:6YO(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$W,0IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B
M"FUS9W-T<B`B:6UP;W-S[79E;"!A8G)I<B!O<FEG96TB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,38S"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B
M"FUS9W-T<B`B97)R;R!D92!S:6YT87AE(&YA(&QI;FAA(&1E(&-O;6%N9&\B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$Y"FUS9VED(")C;VYF:6=U<F%T:6]N
M(&5R<F]R(@IM<V=S='(@(F5R<F\@9&4@8V]N9FEG=7)AY^-O(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$Y-0IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9R(*;7-G<W1R(")E<W3A(&9A;'1A;F1O('5M(&%R<75I=F\@8W+M
M=&EC;R!D;R!S:7-T96UA(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V-PIM<V=I
M9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B97)R;R!N;R!F;W)M871O
M(&1O<R!D861O<R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C,*;7-G:60@(F5N
M=')Y(&YO="!F;W5N9"(*;7-G<W1R(")R96=I<W1R;R!NXV\@96YC;VYT<F%D
M;R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS
M9VED(")F<F]M(@IM<V=S='(@(F1E(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$W
M.0IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B;F]M92!D;R!H
M;W-T(.D@9&5S8V]N:&5C:61O(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P,PIM
M<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(F5R<F\@9&4@96YT
M<F%D82]S8>UD82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#<*;7-G:60@(FEN
M=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(F5R<F\@:6YT97)N;R!D
M;R!P<F]G<F%M82(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8X"FUS9VED
M(")K97DB"FUS9W-T<B`B8VAA=F4B"@HC.B!F;VQD97)S+G!H<#HQ-#4*;7-G
M:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R(")A<G%U:79O(&UA:6QB;W@B"@HC
M.B!C;VUP;W-E+G!H<#HQ,3`U(&QI8B]-97-S86=E+G!H<#HT.34*;7-G:60@
M(FYA;64B"FUS9W-T<B`B;F]M92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*;7-G<W1R(")N96YH=6UA(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C4*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B
M;W(B"FUS9W-T<B`B;W4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$U"FUS9VED
M(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")P97)M:7-SXV\@;F5G861A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O861D<F5S<V5S0FQO8VMS+FIS
M.C@*;7-G:60@(G)E8VEP:65N='-=(@IM<V=S='(@(F1E<W1I;F%TX7)I;W-=
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q,0IM<V=I9"`B<F5M;W1E(&5R<F]R
M(&EN('!R;W1O8V]L(@IM<V=S='(@(F5R<F\@<F5M;W1O(&YO('!R;W1O8V]L
M;R(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#,*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B<V5R=FGG;R!I;F1I<W!O;NUV96PB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL
M:6YG(&5R<F]R(@IM<V=S='(@(F5R<F\@9&4@;W)T;V=R869I82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI
M;F<@97)R;W)S(@IM<V=S='(@(F5R<F]S(&1E(&]R=&]G<F%F:6$B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,3DQ"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T
M<B`B97)R;R!D;R!S:7-T96UA(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P-PIM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B9F%L:&$@=&5M<&]R
MX7)I82(*"B,Z(&QI8B]&:6QT97(N<&AP.C4Q"FUS9VED(")Y;W5R(&)L86-K
M;&ES="(*;7-G<W1R(")S=6$@;&ES=&$@;F5G<F$B"@HC.B!L:6(O1FEL=&5R
M+G!H<#HV,0IM<V=I9"`B>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B<W5A(&QI
M<W1A(&)R86YC82(*````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM
M<"]P;R]P=%]05"YP;P``````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`T,#0U,#8`,3`T,3<S-C(W-C8`,#$W,C(W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@24U0(%!O<G1U
M9V%L(%!O<G1U9W5E<V4@=')A;G-L871I;VXN"B,@36%N=65L($UE;F5Z97,@
M9&4@4V5Q=65I<F$@/$UA;G5E;"Y397%U96ER83XL(#(P,#4N"B,@0F%S960@
M;VX@82!P<F5V:6]U<R!T<F%N<VQA=&EO;B!B>2!.=6YO($QO=7)E:7)O(#QN
M=6YO0&5T:"YP=#XL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($E-4"`T+C`M8W9S7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3,@,3<Z,3,K,#(P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P,BTP,2TP-R`Q.#HR-2`K,#(P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!.=6YO($QO=7)E:7)O(#QN=6YO0&5T:"YP=#Y<;B(*(DQA;F=U86=E
M+51E86TZ($)R87II;&EA;B!0;W)T=6=U97-E(#QD979`;&ES=',N:&]R9&4N
M;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C(V-2!L:6(O0V]M<&]S92YP:'`Z,S$W"FUS9VED("(@("`@("!4;SH@(@IM
M<V=S='(@(B`@("!087)A.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C4S(&QI
M8B]#;VUP;W-E+G!H<#HS,#4*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B
M("`@($1A=&$Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR-38@;&EB+T-O;7!O
M<V4N<&AP.C,P.`IM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R("(@("`@("!$
M93H@(@H*(SH@;6%I;&)O>"YP:'`Z-#`V('1E;7!L871E<R]F;VQD97)S+VAE
M860N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I
M(@IM<V=S='(@(B`H0VAA=F4@9&4@86-E<W-O("5S*2(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR-C(@;&EB+T-O;7!O<V4N<&AP.C,Q-`IM<V=I9"`B(%-U8FIE
M8W0Z("(*;7-G<W1R("(@07-S=6YT;SH@(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C<T"FUS9VED("(@:6X@(@IM<V=S='(@(B!E;2`@
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ
M,@IM<V=I9"`B(R(*;7-G<W1R("(C(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B`O("4N,F9-0B`@
M*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*
M"B,Z(&UA:6QB;W@N<&AP.C$Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M
M97-S86=E<R!H879E(&)E96X@9&5L971E9"XB"FUS9W-T<B`B)60@;65N<V%G
M96YS(&9O<F%M(')E;6]V:61A<RXB"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"B(E9"!M96YS86=E;G,@9F]R86T@<F5P;W)T861A
M<R!C;VUO(&[C;R!S<&%M(&%O('-E=2!A9&UI;FES=')A9&]R(&1E('-I<W1E
M;6%S+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M
M+B(*;7-G<W1R("(E9"!M96YS86=E;G,@9F]R86T@<F5P;W)T861A<R!C;VUO
M(&[C;R!S<&%M+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P
M86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB
M)60@;65N<V%G96YS(&9O<F%M(')E<&]R=&%D87,@8V]M;R!S<&%M(&%O('-E
M=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S+B(*"B,Z(&QI8B]3<&%M+G!H
M<#HQ-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(B5D(&UE;G-A9V5N<R!F
M;W)A;2!R97!O<G1A9&%S(&-O;6\@<W!A;2XB"@HC.B!M86EL8F]X+G!H<#HS
M-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@=&\@)60@;V8@)60@365S<V%G
M97,B"FUS9W-T<B`B)60@82`E9"!D92`E9"!-96YS86=E;G,B"@HC.B!M86EL
M8F]X+G!H<#HV,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T
M<B`B)7,@2T(B"@HC.B!P9W`N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!01U`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C
M;R!D;R!01U`@<&%R82`E<R(*"B,Z('-M:6UE+G!H<#HR-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@4R]-24U%($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F'GXV\@9&\@4R]-24U%('!A<F$@)7,B"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(%EO=7(@
M)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T<B`B)7,@:N$@97AI
M<W1E+B!!('!A<W1A("5S(&[C;R!F;VD@<F5N;VUE861A+B(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HV,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O>"XB"FUS9W-T<B`B)7,@
M;N-O('!A<F5C92!S97(@=6UA(&-A:7AA('!O<W1A;"!VX6QI9&$N(@H*(SH@
M;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN
M<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&9O;&1E<B!B96EN9R!R
M96YA;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N(@IM<V=S='(@(D$@
M<&%S=&$@)7,@<V5RX2!R96YO;65A9&$@;F\@:6[M8VEO(&1O(&WJ<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&AA<R!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@86-E:71O=2XB
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(B5S(&-A
M;F-E;&]U("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&1E8VQI;F5D+B(*;7-G<W1R
M("(E<R!D96-L:6YO=2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#DS"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O(&$@
M9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S(')E<W!O;F1E=2!A('5M
M('!E9&ED;R!L:79R92]O8W5P861O+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI
M960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@(B5S(')E<W!O
M;F1E=2!A;R!C;VYV:71E('!A<F$@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0X,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N
M="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(E<R!E;G9I
M;W4M;&AE(&EN9F]R;6'GXV\@;&EV<F4O;V-U<&%D;RXB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@86-E:71O
M=2!T96YT871I=F%M96YT92XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-#@W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(E<R!S;VQI8VET82UL
M:&4@82!S=6$@:6YF;W)M8>?C;R!L:79R92]O8W5P861O+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T<B`B)7,@
M<&5D92!A('-U82!P<F5S96[G82!E;2`E<RXB"@HC.B!L:6(O365S<V%G92YP
M:'`Z,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@)7,N(@IM<V=S='(@(B5S(&9O:2!A9&EC:6]N861A(&-O
M;2!S=6-E<W-O(&$@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C4Y-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@86UM96YD
M("5S+B(*;7-G<W1R("(E<R!D97-E:F$@8V]R<FEG:7(@)7,N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@
M(B5S(&1E<V5J82!A=FESX2UL;R!D92!Q=64@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W
M:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T
M("5S+B(*;7-G<W1R("(E<R!D97-E:F$@<F5C96)E<B!A(&EN9F]R;6'GXV\@
M;6%I<R!A8W1U86QI>F%D82!S;V)R92`E<RXB"@HC.B!M97-S86=E+G!H<#HR
M-CD@;65S<V%G92YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E
M<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?=&]P+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@*"5D
M)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P.V1E
M)FYB<W`[)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$T,`IM<V=I9"`B*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@
M;F5X="!S8W)E96XN*2(*;7-G<W1R("(H169E8W1U87(@86QT97)AY_5E<R!E
M(&%V86[G87(@<&%R82!A('!R\WAI;6$@<.%G:6YA+BDB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(W"FUS9VED("(H1&ES8V%R9"!A
M;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;BXI
M(@IM<V=S='(@(B(*(BA#86YC96QA<B!T;V1A<R!A<R!A;'1E<F'G]65S(&4@
M<F5T;W)N87(@X"!J86YE;&$@9&4@97-C<FET82!D92!M96YS86=E;2XI(@H*
M(SH@<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E='5R;B!T;R!T:&4@
M8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D
M92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N
M('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H5F]L=&%R(.`@
M:F%N96QA(&1E(&-O;7!O<VGGXV\@9&5P;VES(&1E(&5F96-T=6%R(&%S(&%L
M=&5R8>?U97,@9F5I=&%S(&%TZ2`B"B)A;R!M;VUE;G1O+B!!<R!A;'1E<F'G
M]65S(&YA(&IA;F5L82!A8W1U86P@3L-/('-E<N-O(&5F96-T=6%D87,N*2(*
M"B,Z('-P96QL:6YG+G!H<#HR-S<*;7-G:60@(B(*(BA396YD(&UE<W-A9V4@
M869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H
M86YG97,@;VX@=&AE("(*(F-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P
M<&QI960N*2(*;7-G<W1R("(B"B(H16YV:6%R(&UE;G-A9V5M(&1E<&]I<R!D
M92!A<&QI8V%R('1O9&%S(&%S(&%L=&5R8>?U97,@9F5I=&%S(&%TZ2!A;R`B
M"B)M;VUE;G1O+B!!<R!A;'1E<F'G]65S(&YA(&IA;F5L82!A8W1U86P@3L-/
M('-E<N-O(&5F96-T=6%D87,N*2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D9"!T:&5S92!B>2!C;&EC:VEN
M9R!/2R`J(@IM<V=S='(@(BH@061I8VEO;F4@8VQI8V%N9&\@96T@3TL@*B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS9VED
M("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(J(%!O
M<B!F879O<B!S96QE8V-I;VYE(&5N9&5R9>=O*',I("HB"@HC.B!M86EL8F]X
M+G!H<#HQ.30*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("(Q(&UE;G-A9V5M(&9O:2!R96UO=FED82XB"@HC.B!L:6(O4W!A
M;2YP:'`Z,3@P"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HB,2!M96YS86=E;2!F;VD@<F5P;W)T861A(&-O;6\@;N-O('-E
M;F1O('-P86T@86\@<V5U(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M82XB"@HC
M.B!L:6(O4W!A;2YP:'`Z,38P"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@
M<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(C$@;65N<V%G96T@9F]I
M(')E<&]R=&%D82!C;VUO(&[C;R!S96YD;R!S<&%M+B(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ-S(*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(C$@;65N<V%G96T@9F]I(')E<&]R=&%D82!C;VUO('-P86T@86\@<V5U(&%D
M;6EN:7-T<F%D;W(@9&4@<VES=&5M82XB"@HC.B!L:6(O4W!A;2YP:'`Z,34R
M"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2XB
M"FUS9W-T<B`B,2!M96YS86=E;2!F;VD@<F5P;W)T861A(&-O;6\@<W!A;2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@X"FUS9VED("(Q,#`@8VAA
M<F%C=&5R<R(*;7-G<W1R("(Q,#`@8V%R86-T97)E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.3$*;7-G:60@(C$P,#`@8VAA<F%C=&5R<R(*;7-G
M<W1R("(Q,#`P(&-A<F%C=&5R97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S@Y"FUS9VED("(R-3`@8VAA<F%C=&5R<R(*;7-G<W1R("(R-3`@8V%R
M86-T97)E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3`*;7-G:60@
M(C4P,"!C:&%R86-T97)S(@IM<V=S='(@(C4P,"!C87)A8W1E<F5S(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38R"B,L('!H<"UF;W)M870*
M;7-G:60@(D$@;&%R9V4@:6UA9V4@;F%M960@)7,@:7,@871T86-H960@=&\@
M=&AI<R!M97-S86=E+B(*;7-G<W1R(")5;6$@9W)A;F1E(&EM86=E;2!C:&%M
M861A("5S(.D@86YE>&\@9&5S=&$@;65N<V%G96TN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G
M92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I
M9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G<W1R("(B"B)5
M;6$@;65N<V%G96T@<&]R('-I(&5N=FEA9&$@<F5S=6QT;W4@;G5M82!N;W1I
M9FEC8>?C;R!D92!R971O<FYO(&1O("(*(F1E<W1I;F%TX7)I;RXB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0IM<V=I9"`B04Y$(@IM<V=S
M='(@(D4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DP"FUS9VED
M(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")!8V5I=&%R('!E9&ED;R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@(D%C8V5P="!R
M97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B06-E
M:71A<B!P961I9&\@92!A9&EC:6]NX2UL;R!A;R!M974@8V%L96YDX7)I;R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-3,*;7-G:60@(D%C8V5P
M=&5D(@IM<V=S='(@(D%C96ET92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-3<*;7-G:60@(D%C8V5P=&5D.B`B"FUS9W-T<B`B06-E:71E.B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW"FUS9VED(")!
M8V-O=6YT)W,@;F%M93HB"FUS9W-T<B`B3F]M92!D82!C;VYT83HB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(P(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW,S`*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B06/G]65S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`S"FUS9VED
M(")!9&0@<V]U<F-E(@IM<V=S='(@(D%D:6-I;VYA<B!F;VYT92(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S<@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4X.`IM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L96YD87(B"FUS
M9W-T<B`B061I8VEO;F%R(&ES=&\@86\@;65U(&-A;&5N9.%R:6\B"@HC.B!L
M:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)344O2&5A9&5R<RYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T;R!!9&1R97-S(&)O;VL@
M*"5S*2(*;7-G<W1R(")!9&EC:6]N87(@86\@3&EV<F\@9&4@16YD97)EYV]S
M("@E<RDB"@HC.B!C;VUP;W-E+G!H<#HQ,3DQ"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R(")<
M(B5S7"(@:6YC;'7M9&\@8V]M;R!A;F5X;RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DP"FUS9VED("(B"B)!9&1I=&EO;F%L(&AE861E<G,@=&\@
M9&ES<&QA>2!W:&5N('9I97=I;F<Z(#QI/BAO<'1I;VYA;"P@96YT97(@96%C
M:"!H96%D97(@(@HB;VX@82!N97<@;&EN92D\+VD^(@IM<V=S='(@(B(*(D-A
M8F7G86QH;W,@861I8VEO;F%I<R!A(&UO<W1R87(@<75A;F1O('9I<W5A;&EZ
M86YD;SH@/&D^*&]P8VEO;F%L+"!C861A("(*(F-A8F7G86QH;R!E;2!S=6$@
M;&EN:&$I/"]I/B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN
M<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M
M871I;VX@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B26YF;W)M8>?C;R!A
M9&EC:6]N86P@<&]D92!S97(@=FES=&$@)7,N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*;7-G:60@(D%D9&ET:6]N86P@:6YF
M;W)M871I;VX@9&5T86EL<R(*;7-G<W1R(")0;W)M96YO<F5S(&%D:6-I;VYA
M:7,@9&$@:6YF;W)M8>?C;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.CDS"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R(*;7-G
M<W1R(")0;W)M96YO<F5S(&%D:6-I;VYA:7,@9&$@;65N<V%G96TB"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D
M("5S+B(*;7-G<W1R(")0;W)M96YO<F5S(&%D:6-I;VYA:7,@9&$@;65N<V%G
M96T@<&]D96T@<V5R('9I<W1O<R`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R
M(&1E=&%I;',B"FUS9W-T<B`B4&]R;65N;W)E<R!A9&EC:6]N86ES(&1A(&UE
M;G-A9V5M(&1E(&5R<F\B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@
M97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R(")0;W)M
M96YO<F5S(&1E(&5R<F\@861I8VEO;F%I<R!D82!M96YS86=E;2!P;V1E;2!S
M97(@=FES=&]S("5S+B(*"B,Z(&-O;G1A8W1S+G!H<#HY,"!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C$X,`HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS,S`@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C4U"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B3&EV<F\@9&4@
M16YD97)EYV]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I
M9"`B061D<F5S<R!";V]K<R(*;7-G<W1R("),:7-T87,@9&4@0V]N=&%C=&]S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,0IM<V=I9"`B(@HB061D
M<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QI/BAO<'1I;VYA;"P@96YT
M97(@96%C:"!A9&1R97-S(&]N(&$@;F5W("(*(FQI;F4I/"]I/B(*;7-G<W1R
M("(B"B)%;F1E<F7G;W,@86]S('%U86ES(&5N=FEA<B!C;VUO($-C;R!T;V1A
M<R!A<R!M96YS86=E;G,Z(#QI/BAO<&-I;VYA;"P@8V%D82`B"B)E;F1E<F7G
M;R!E;2!S=6$@;&EN:&$I/"]I/B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-S,*;7-G:60@(B(*(D%D9')E<W-E<R!T;R!E>'!L:6-I=&QY('1I92!T
M;R!T:&ES(&ED96YT:71Y.B`\:3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB
M861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO:3XB"FUS9W-T<B`B(@HB16YD97)E
MYV]S(&$@;&EG87(@97AP;&EC:71A;65N=&4@82!E<W1A(&ED96YT:61A9&4Z
M(#QI/BAO<&-I;VYA;"P@8V%D82`B"B)E;F1E<F7G;R!E;2!S=6$@;&EN:&$I
M/"]I/B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3`@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y,@IM<V=I9"`B06QL(@IM<V=S='(@(E1U
M9&\B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R:7!T+FEN8SHU"FUS
M9VED("(B"B)!;&P@;65S<V%G97,@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(H
M<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@;VYE($U"3U@@(@HB9FEL93HB
M"FUS9W-T<B`B(@HB5&]D87,@87,@;65N<V%G96YS(&1A*',I('-E9W5I;G1E
M*',I('!A<W1A<RAS*2!S97+C;R!P=7AA9&%S('!A<F$@=6T@^FYI8V\@(@HB
M87)Q=6EV;R!-0D]8("(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E
M7W1R87-H+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S
M<V%G97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y
M<R!W:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N(@IM<V=S='(@(B(*
M(E1O9&%S(&%S(&UE;G-A9V5N<R!D82!P87-T82!<(B5S7"(@8V]M(&UA:7,@
M9&\@<75E("5S(&1I87,@<V5RXV\@(@HB<&5R;6%N96YT96UE;G1E(')E;6]V
M:61A<RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?871T86-H
M;65N='-?;6]N=&AL>2YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL
M(&]L9"!L:6YK960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O
M;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R(")4;V1O<R!O<R!A;F5X;W,@
M8V]M(&QI9V'G]65S(&-O;2!M86ES(&1E("5S(&UE<V5S('-E<N-O(')E;6]V
M:61O<RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA
M:6Q?;6]N=&AL>2YP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L
M9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W
M:6QL(&)E(&1E;&5T960N(@IM<V=S='(@(B(*(E1O9&%S(&%S('!A<W1A<R!D
M92!M96YS86=E;G,@96YV:6%D87,@8V]M(&UA:7,@9&\@<75E("5S(&UE<V5S
M('-E<N-O("(*(G)E;6]V:61A<RXB"@HC.B!A8VPN<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R(%PB)7-<(B!S=6-C
M97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N(@IM<V=S='(@(B(*
M(E1O9&]S(&]S(&1I<F5I=&]S('-O8G)E(&$@<&%S=&$@7"(E<UPB(&9O<F%M
M(')E;6]V:61O<R!C;VT@<W5C97-S;R!P87)A(&\@(@HB=71I;&EZ861O<B!<
M(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4U"FUS
M9VED(")!;&QO=R!F:6QT97(@<G5L97,@=&\@8F4@87!P;&EE9"!I;B!A;GD@
M;6%I;&)O>#\B"FUS9W-T<B`B4&5R;6ET:7(@82!A<&QI8V'GXV\@9&4@<F5G
M<F%S(&1E(&9I;'1R86=E;2!A('%U86QQ=65R(&-A:7AA('!O<W1A;#\B"@HC
M.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B
M06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B
M4&%R=&5S(&%L=&5R;F%T:79A<R!P87)A(&5S=&$@<V5CY^-O.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4W-PIM<V=I9"`B06QW87ES(@IM<V=S='(@(E-E;7!R92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-3`*;7-G:60@(D%L=V%Y<R!S879E(&%T=&%C
M:&UE;G1S(@IM<V=S='(@(D=U87)D87(@<V5M<')E(&]S(&%N97AO<R(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HT-C@*;7-G:60@(B(*(D%N(&5R<F]R(&]C8W5R
M960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@
M5&AE($E-05`@<V5R=F5R("(*(G-A:60Z("(*;7-G<W1R(")/8V]R<F5U('5M
M(&5R<F\@86\@=&5N=&%R(&1E<V-A<G1A<B!O(&%N97AO+B!/('-E<G9I9&]R
M($E-05`@9&ES<V4Z("(*"B,Z(&QI8B]-97-S86=E+G!H<#HS-C0*;7-G:60@
M(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@
M;F5W('1A<VLN(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!D97-C;VYH96-I
M9&\@86\@8W)I87(@=6UA(&YO=F$@=&%R969A+B(*"B,Z(&UE<W-A9V4N<&AP
M.C0X-"!M86EL8F]X+G!H<#HV.3,@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHY"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS-0HC.B!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C8*;7-G:60@(D%N<W=E<F5D(@IM
M<V=S='(@(E)E<W!O;F1I9&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C,Q"FUS9VED(")!;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")-96YS
M86=E;G,@<F5S<&]N9&ED87,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D
M97(N:6YC.C<*;7-G:60@(D%P<&QY($9I;'1E<G,B"FUS9W-T<B`B07!L:6-A
M<B!&:6QT<F]S(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS
M9W-T<B`B07!L:6-A<B!&:6QT<F]S(&$@)7,B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z-#,*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U
M<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(D%P;&EC87(@87,@<F5G<F%S(&1E
M(&9I;'1R86=E;2!A<75A;F1O(&1A(&5N=')A9&$_(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C0Y"FUS9VED(")!<'!L>2!F:6QT97(@<G5L
M97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/R(*;7-G<W1R(")!<&QI
M8V%R(&%S(')E9W)A<R!D92!F:6QT<F%G96T@<75A;F1O(&$@16YT<F%D82!F
M;W(@;6]S=')A9&$_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV
M-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.3,*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(*;7-G<W1R
M(")496T@82!C97)T97IA('%U92!D97-E:F$@<F5M;W9E<B!E<W1A(&-H879E
M('#Z8FQI8V$_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,C@@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$V.0IM<V=I9"`B(@HB07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES
M($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(B(*(E1E;2!A(&-E<G1E>F$@
M9&4@<75E('%U97(@<F5M;W9E<B!O('-E=2!P87(@9&4@8VAA=F5S/R`H3L-/
M(.D@<F5C;VUE;F1A9&\A*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_(@IM<V=S='(@
M(E1E;2!A(&-E<G1E>F$@<75E(&1E<V5J82!F87IE<B!I<W1O/R(*"B,Z(&UE
M<W-A9V4N<&AP.C,Y,2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHV.`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.
M5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS9W-T<B`B5&5M(&$@8V5R
M=&5Z82!Q=64@9&5S96IA(')E;6]V97(@4$5234%.14Y414U%3E1%(&5S=&%S
M(&UE;G-A9V5N<S\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C`R"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L
M971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B5&5M(&$@8V5R=&5Z82!Q
M=64@9&5S96IA(')E;6]V97(@4$5234%.14Y414U%3E1%(&5S=&4@86YE>&\_
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O;&1E<C\B
M"FUS9W-T<B`B5&5M(&$@8V5R=&5Z82!Q=64@9&5S96IA(')E;6]V97(@97-T
M82!P87-T83\B"@HC.B!L:6(O24U0+G!H<#HY,S$*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS
M9W-T<B`B5&5M(&$@8V5R=&5Z82!Q=64@9&5S96IA(&5S=F%Z:6%R(&$@<&%S
M=&$@9&4@;&EX;S\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHX"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT
M;'D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R(")496T@82!C97)T
M97IA('%U92!D97-E:F$@<F5M;W9E<B!P97)M86YE;G1E;65N=&4@97-T87,@
M;65N<V%G96YS/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N
M:6YC.C@P('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S
M<V%G92!A<R!I;FYO8V5N=#\B"FUS9W-T<B`B5&5M(&$@8V5R=&5Z82!D92!Q
M=64@<75E<B!R97!O<G1A<B!E<W1A(&UE;G-A9V5M(&-O;6\@<V5N9&\@:6YO
M8V5N=&4_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z
M-S4@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E
M(&%S('-P86T_(@IM<V=S='(@(E1E;2!A(&-E<G1E>F$@9&4@<75E('%U97(@
M<F5P;W)T87(@97-T82!M96YS86=E;2!C;VUO('-E;F1O('-P86T_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X-PIM<V=I9"`B07)R:79A;"!4:6UE
M(@IM<V=S='(@(D1A=&$@9&4@0VAE9V%D82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,#(*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")#<F5S8V5N
M=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-S8*;7-G:60@(D%S:R(*;7-G<W1R(")097)G=6YT87(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#D*;7-G:60@
M(D%T=&%C:"(*;7-G<W1R(")!;F5X87(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT-C8*;7-G:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R
M(")!;F5X87(@07)Q=6EV;W,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT-#<*;7-G:60@(D%T=&%C:"!A(&-O<'D@;V8@>6]U<B!01U`@
M<'5B;&EC(&ME>2!T;R!Y;W5R(&UE<W-A9V4_(@IM<V=S='(@(D%N97AA<B!U
M;6$@8_-P:6$@9&$@<W5A(&-H879E('#Z8FQI8V$@9&4@4$=0(.`@<W5A(&UE
M;G-A9V5M/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ,#D*;7-G
M:60@(D%T=&%C:&5D($9I;&4Z(@IM<V=S='(@(D%R<75I=F\@06YE>&%D;SHB
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8R(&QI8B]#;VUP;W-E+G!H<#HT-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB071T86-H960@9FEL92!<(B5S7"(@
M97AC965D<R!T:&4@871T86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@
M871T86-H960N(@IM<V=S='(@(D\@87)Q=6EV;R!<(B5S7"(@97AC961E(&$@
M9&EM96YSXV\@;&EM:71E+B!/(&%R<75I=F\@3L-/(&9O:2!A;F5X861O+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S8*;7-G:60@(D%T=&%C
M:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT
M+B(*;7-G<W1R(")%;2!A;F5X;R!E<W3A(&$@<F5S<&]S=&$@82!U;2!P961I
M9&\@9&4@8V%L96YDX7)I;R!Q=64@=F]CZB!E;G9I;W4N(@H*(SH@;6%I;&)O
M>"YP:'`Z-S(Y('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-@HC.B!T96UP;&%T97,O8V]M<&]S
M92]A='1A8VAM96YT<RYJ<SHY.`IM<V=I9"`B071T86-H;65N="(*;7-G<W1R
M(")!;F5X;R(*"B,Z(&-O;7!O<V4N<&AP.C$P,#$@;&EB+TUE<W-A9V4N<&AP
M.C0R.0IM<V=I9"`B071T86-H;65N="!S=')I<'!E9#H@3W)I9VEN86P@871T
M86-H;65N="!T>7!E(@IM<V=S='(@(D%N97AO(&1E<V-A<G1A9&\Z(%1I<&\@
M9&4@86YE>&\@;W)I9VEN86PB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#8T
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HY.#0*;7-G:60@(D%T=&%C:&UE;G1S(@IM
M<V=S='(@(D%N97AO<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M.#(*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")087)T:6-I<&%N=&5S(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*;7-G:60@
M(D%T=&5N=&EO;B(*;7-G<W1R(")!=&5NY^-O(@H*(SH@;&EB+T%U=&@O:6UP
M+G!H<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z($5X=&5N<^-O($E-
M05`@;F5C97-SX7)I82!M87,@;N-O(&5N8V]N=')A9&$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8S-`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S
M:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I
M<R!I;B!M>2`B"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@HB36]S=')A<B!A
M=71O;6%T:6-A;65N=&4@:6UA9V5N<R!E;2!M96YS86=E;G,@2%1-3"!Q=6%N
M9&\@96YV:6%D87,@<&]R("(*(F-O<G)E<W!O;F1E;G1E(&QI<W1A9&\@;F\@
M;65U(&QI=G)O(&1E(&5N9&5R9>=O<S\B"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHR.3@*;7-G:60@(D%V86EL86)L92!!9&1R97-S
M(&)O;VMS.B(*;7-G<W1R("),:79R;W,@9&4@16YD97)EYV]S(&1I<W!O;NUV
M96ES.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@
M(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@(D5S<&5R86YD;R!297-P;W-T
M82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`B
M5F]L7W1A<B!P87)A("5S(@H*(SH@=&AR96%D+G!H<#HX-B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M870*
M;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B5F]L=&%R('!A<F$@)7,B"@HC
M.B!M97-S86=E+G!H<#HR-3`@<V5A<F-H+G!H<#HQ-#<@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C(*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5C;VUP;W-E+FEN8SHR,`IM<V=I9"`B0F-C(@IM<V=S='(@(D)C8R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM<V=I9"`B0F5L;W<@
M:7,@=&AE(')A=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S
M<V%G92XB"FUS9W-T<B`B06)A:7AO(&5N8V]N=')A+7-E(&\@=&5X=&\@8W)U
M(&1A(&UE;G-A9V5M(&1E(&EN9F]R;6'GXV\@9&4@97-T861O+B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.2!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM
M<V=S='(@(DQI<W1A($YE9W)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8R,@IM<V=I9"`B0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL
M97-S('1H97D@87)E('-P96-I9FEC86QL>2!R97%U97-T960_(@IM<V=S='(@
M(B(*(D)L;W%U97(@:6UA9V5N<R!E;2!M96YS86=E;G,@2%1-3"!E>&-E<'1O
M('%U86YD;R!E>'!L:6-I=&%M96YT92!P961I9&%S/R(*"B,Z('-E87)C:"YP
M:'`Z,34U"FUS9VED(")";V1Y(@IM<V=S='(@(D-O<G!O(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C,Y"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")!
M;6)A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#$*;7-G:60@(D)O
M=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*;7-G<W1R
M("),:7-T86=E;2!N;R!#86)EYV%L:&\@92!#;W)P;R!D82!-96YS86=E;2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(X,PIM<V=I9"`B
M0U]H87)S970B"FUS9W-T<B`B0_-?9&EG;R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B0V%L
M96YDX7)I;R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C`Q"FUS9VED
M(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<BXB
M"FUS9W-T<B`B26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!D92!C
M;W)R96EO(&5L96-T<O-N:6-O(')E;6]T;RXB"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R
M96UO=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R("));7!O<W/M=F5L(&-O;F5C
M=&%R(&%O('-E<G9I9&]R(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@<F5M;W1O
M.B`B"@HC.B!L:6(O34E-12]6:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL
M>2`E<R!O9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E
M;G0@(@HB;6%I;&)O>"XB"FUS9W-T<B`B(@HB3N-O('-E('!O9&4@;6]S=')A
M<B`M(&5N8V]N=')A9&%S(&%P96YA<R`E<R!D92`E<R!P87)T97,@9&5S=&$@
M;65N<V%G96T@;F$@(@HB8V%I>&$@<&]S=&%L(&-O<G)E;G1E+B(*"B,Z(&9O
M;&1E<G,N<&AP.C(W,R!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(U-0HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(Q('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI
M;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$R-PHC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,R
M('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C8*;7-G:60@(D-A;F-E
M;"(*;7-G<W1R(")#86YC96QA<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C<P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R
M-@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$V"FUS9VED
M(")#86YC96P@365S<V%G92(*;7-G<W1R(")#86YC96QA<B!-96YS86=E;2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES
M(&UE<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT
M<RXB"FUS9W-T<B`B(@HB06\@8V%N8V5L87(@97-T82!M96YS86=E;2!I<N$@
M<&5R9&5R('1O9&\@;R!S974@8V]N=&7Z9&\@<&5R;6%N96YT96UE;G1E+B(*
M"B,Z(&UE<W-A9V4N<&AP.C(T.2!S96%R8V@N<&AP.C$T,R!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC.B!T96UP;&%T97,O8V]M<&]S
M92]R96-O;7!O<V4N:6YC.C$U"FUS9VED(")#8R(*;7-G<W1R(")#8R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#$*;7-G:60@(D-H86ER(%!E
M<G-O;B(*;7-G<W1R(")-;V1E<F%D;W(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@(D-H86YG92(*;7-G<W1R(")!;'1E
M<F%R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@W"FUS
M9VED(")#:&%N9V4@06QL(@IM<V=S='(@(D%L=&5R87(@5'5D;R(*"B,Z('1E
M;7!L871E<R]A8VPO86-L+FEN8SHY-R!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M.3@*;7-G:60@(D-H86YG92!&;VQD97(B"FUS9W-T<B`B06QT97)A<B!087-T
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*;7-G:60@(B(*(D-H
M86YG92!D:7-P;&%Y(&]P=&EO;G,@<W5C:"!A<R!H;W<@;6%N>2!M97-S86=E
M<R!Y;W4@<V5E(&]N(&5A8V@@<&%G92!A;F0@(@HB:&]W(&UE<W-A9V5S(&%R
M92!S;W)T960N(@IM<V=S='(@(B(*(D%L=&5R87(@;W#G]65S(&1E('9I<W5A
M;&EZ8>?C;R!T86ES(&-O;6\@<75A;G1A<R!M96YS86=E;G,@<75E<B!V97(@
M<&]R("(*(G#A9VEN82!E(&$@<F5S<&5C=&EV82!O<F1E;F'GXV\N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS9VED(")#:&%N9V4@;6%I;"!S
M97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS9W-T<B`B06QT97)A<B!D
M861O<R!D;R!S97)V:61O<B!D92!C;W)R96EO(&5L96-T<O-N:6-O(&4@9&%S
M('!A<W1A<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD("(*(G)E<&QY('1O
M('EO=7(@96UA:6PN(@IM<V=S='(@(B(*(D%L=&5R87(@;R!N;VUE+"!E;6%I
M;"!E(&%S<VEN871U<F$@<75E(&%S('!E<W-O87,@=F5RXV\@<75A;F1O(&QE
M<F5M(&4@(@HB<F5S<&]N9&5R96T@X"!S=6$@;65N<V%G96TN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y,PIM<V=I9"`B0VAA<F%C=&5R<R!T;R!D
M:7-P;&%Y.B(*;7-G<W1R(")#87)A8W1E<F5S(&$@;6]S=')A<CHB"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B0VAE8VL@
M1F]L9&5R*',I(&9O<B!.97<@36%I;"(*;7-G<W1R(")697)I9FEC82!S92!H
MX2!-96YS86=E;G,@3F]V87,@;F$H<RD@4&%S=&$H<RDB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z-S$*;7-G:60@(D-H96-K(%]!;&PO3F]N92(*
M;7-G<W1R(")-87)C87(@7U1U9&\O3F%D82(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO9F5T8VAM86EL+FEN8SHQ-`IM<V=I9"`B0VAE8VL@86QL(&UA:6P@
M<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S='(@
M(E9E<FEF:6-A<B!T;V1O<R!O<R!S97)V:61O<F5S(&1E(&]N9&4@<')E=&5N
M9&4@9&5S8V%R<F5G87(@8V]R<F5I;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#4T"FUS9VED(")#:&5C:R!S<&5L;&EN9R!B969O<F4@<V5N9&EN
M9R!A(&UE<W-A9V4_(@IM<V=S='(@(E9E<FEF:6-A<B!A(&]R=&]G<F%F:6$@
M86YT97,@9&4@96YV:6%R(&$@;65N<V%G96T_(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I9"`B0VAO;W-E($%C=&EO;CHB"FUS
M9W-T<B`B06/GXV\Z(@H*(SH@8V]N9FEG+W-E<G9E<G,N<&AP+F1I<W0Z,3DU
M"FUS9VED(")#:&]O<V4@82!M86EL('-E<G9E<CHB"FUS9W-T<B`B17-C;VQH
M97(@=6T@<V5R=FED;W(@9&4@8V]R<F5I;R!E;&5C='+S;FEC;SHB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,C<@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,3<W"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(R.`IM<V=I9"`B0VAO;W-E(&$@;6%T8V@@;W(@961I="!T
M:&4@861D<F5S<R!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(D5S8V]L:&$@=6UA
M(&1A<R!C;W)R97-P;VYDZFYC:6%S(&]U(&5D:71E(&\@96YD97)EYV\@X"!D
M:7)E:71A.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C$@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,0IM<V=I9"`B0VAO;W-E(&%N(&%C
M=&EO;CHB"FUS9W-T<B`B17-C;VQH82!U;6$@86/GXV\Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"FUS9VED(")#:&]O<V4@
M=&AE(&%D9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S
M+B(*;7-G<W1R(")%<V-O;&AA(&\@;&EV<F\@9&4@96YD97)EYV]S(&$@=7-A
M<B!Q=6%N9&\@<V4@861I8VEO;F%R(&5N9&5R9>=O<RXB"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHR.3,*;7-G:60@(D-H;V]S92!T
M:&4@;W)D97(@;V8@861D<F5S<R!B;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A
M;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("(B"B)%<V-O;&AA(&$@;W)D96T@
M9&]S(&QI=G)O<R!D92!E;F1E<F7G;W,@82!P<F]C=7)A<B!Q=6%N9&\@97AP
M86YD:6YD;R`B"B)E;F1E<F7G;W,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M(&-O;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R
M;W=S97(@8V%N('9I97<N(@IM<V=S='(@(B(*(D-A<G)E9W5E(&5M("5S('!A
M<F$@8V]N=F5R=&5R(&\@87)Q=6EV;R!D92!I;6%G96T@<&%R82!U;2!F;W)M
M871O('%U92!O("(*(FYA=F5G861O<B!P;W-S82!M;W-T<F%R+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92XB"FUS9W-T<B`B
M0V%R<F5G=64@96T@)7,@<&%R82!D97-C87)R96=A<B!A(&EM86=E;2XB"@HC
M.B!L:6(O1FEL=&5R+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R(")#
M87)R96=U92!E;2`E<R!P87)A(&ER('!A<F$@<.%G:6YA(&1E(&=E<W3C;R!D
M;R`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3(X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT
M(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")#87)R96=U92!E;2`E
M<R!P87)A('9E<B!O(&-O;G1E^F1O($A434P@;G5M82!J86YE;&$@X"!P87)T
M92XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I;"!O
M9B!T:&ES(&EM86=E+B(*;7-G<W1R(")#87)R96=U92!E;2`E<R!P87)A('9E
M<B!M:6YI871U<F$@9&5S=&$@:6UA9V5M+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z-#`W"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S
M('1O('9I97<@=&AE(&%T=&%C:&UE;G0@:6X@82!S97!A<F%T92!W:6YD;W<N
M(@IM<V=S='(@(D-A<G)E9W5E(&5M("5S('!A<F$@=F5R(&\@86YE>&\@;G5M
M82!J86YE;&$@X"!P87)T92XB"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E
M9"YP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE
M=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S97!A<F%T92!W
M:6YD;W<N(@IM<V=S='(@(B(*(D-A<G)E9W5E(&5M("5S('!A<F$@=F5R(&UU
M;'1I<&%R=&4O<&%R=&4@<F5L86-I;VYA9&$@;G5M82!J86YE;&$@X"!P87)T
M92XB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`T"FUS9VED(")#
M;&EC:R!H97)E('1O($A)1$4@=&AE($EM86=E<R(*;7-G<W1R(")#87)R96=U
M92!A<75I('!A<F$@15-#3TY$15(@87,@26UA9V5N<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,#@*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/
M5R!T:&4@26UA9V5S(@IM<V=S='(@(D-A<G)E9W5E(&%Q=6D@<&%R82!615(@
M87,@26UA9V5N<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,R,0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F('EO=7(@<V5L96-T
M960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@86QL(&9I96QD<R!T
M;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(D-A<G)E9W5E(&YU;2!D;W,@<V5U
M<R!L:79R;W,@9&4@96YD97)EYV]S('-E;&5C8VEO;F%D;W,@92!D97!O:7,@
M97-C;VQH82!O<R`B"B)C86UP;W,@82!P<F]C=7)A<BXB"@HC.B!L:6(O34E-
M12]6:65W97(O<&=P+G!H<#HQ-S$*;7-G:60@(D-L:6-K('1O(%-A=F4@4$=0
M(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VLB"FUS9W-T<B`B0VQI
M<75E('!A<F$@1W5A<F1A<B!A($-H879E(%#Z8FQI8V$@4$=0(&YO('-E=2!,
M:79R;R!D92!%;F1E<F7G;W,B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C$Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R!T;R!3879E(%,O
M34E-12!C97)T:69I8V%T92!O9B`E<R!I;B!Y;W5R($%D9')E<W,@0F]O:R(*
M;7-G<W1R("(B"B)#;&EQ=64@<&%R82!'=6%R9&%R(&\@0V5R=&EF:6-A9&\@
M4R]-24U%(&1E("5S(&YO('-E=2!,:79R;R!D92!%;F1E<F7G;W,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")#;&EC:VEN9R!O;B!T
M:&4@861D<F5S<R!W:6QL(&-O;7!O<V4@82!N97<@;65S<V%G92!T;R!T:&4@
M<V5N9&5R(@IM<V=S='(@(D-A<G)E9V%R(&YO(&5N9&5R9>=O(&-O;7!O<N$@
M=6UA(&YO=F$@;65N<V%G96T@<&%R82!O(')E;65T96YT92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,C(*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A
M9&1R97-S('=I;&P@;W!E;B!T:&4@;65S<V%G92!T;R!B92!R96%D(@IM<V=S
M='(@(D-A<G)E9V%R(&YO(&5N9&5R9>=O(&%B<FERX2!A(&UE;G-A9V5M('!A
M<F$@;&5I='5R82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL
M+FEN8SHS,`IM<V=I9"`B0VQO<V4B"FUS9W-T<B`B1F5C:&%R(@H*(SH@8V]M
M<&]S92YP:'`Z-S<U(&-O;7!O<V4N<&AP.C$P.#(*;7-G:60@(D-L;W-E('1H
M:7,@=VEN9&]W(@IM<V=S='(@(D9E8VAA<B!E<W1A($IA;F5L82(*"B,Z(&9O
M;&1E<G,N<&AP.C0Q-@IM<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G<W1R(")0
M87-T82!&96-H861A(@H*(SH@9F]L9&5R<RYP:'`Z-#,V"FUS9VED(")#;VQL
M87!S92(*;7-G<W1R(")#;VQA<'-A<B(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C,T"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T<B`B
M1F5C:&%R(%1O9&%S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,S0*;7-G:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM<V=S='(@(D9E
M8VAA<B!4;V1A<R!087-T87,B"@HC.B!F;VQD97)S+G!H<#HT,S8*;7-G:60@
M(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R(")&96-H87(@4&%S=&$B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-3$*;7-G:60@(D-O;&]R
M($EN9&EC871O<CH@(@IM<V=S='(@(DEN9&EC861O<B!#;VQO<FED;SHB"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3DQ"FUS9VED(")#;VUM96YT(@IM
M<V=S='(@(D-O;65N=.%R:6\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S8Y"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B0V]M<&QE=&\B"@HC
M.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K+W1R965?9F]L
M9&5R<RYP:'`Z-#(*;7-G:60@(D-O;7!O<V4B"FUS9W-T<B`B17-C<F5V97(B
M"@HC.B!M86EL8F]X+G!H<#HW-38@;&EB+TU)344O2&5A9&5R<RYP:'`Z,3DR
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;7!O<V4@365S<V%G92`H)7,I(@IM
M<V=S='(@(D5S8W)E=F5R("@E<RDB"@HC.B!C;VUP;W-E+G!H<#HW-S0@8V]M
M<&]S92YP:'`Z,3`X,0IM<V=I9"`B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B
M"FUS9W-T<B`B17-C<F5V97(@=6UA(&]U=')A(&UE;G-A9V5M(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B0V]M<&]S92!M97-S86=E
M<R!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B17-C<F5V97(@;65N
M<V%G96YS(&YU;6$@:F%N96QA('-E<&%R861A/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-#8*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET
M:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S
M('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@HB0V]M<&]R(&UE;G-A9V5N
M<R!C;VT@;R!A;6)I96YT92!(5$U,('!O<B!O;6ES<^-O("AS92!O(&YA=F5G
M861O<B!O('-U<&]R=&%R*3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I<W!L87EE
M9"XB"FUS9W-T<B`B0V]N9FEG=7)A<B!M;V1O(&1E('9I<W5A;&EZ8>?C;R!D
M92!M96YS86=E;G,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV"FUS
M9VED(")#;VYF:6=U<F4@;6%I;"!P<F5V:65W(&]P=&EO;G,N(@IM<V=S='(@
M(D-O;F9I9W5R92!A<R!O<.?U97,@9&4@<')E=FESXV\@9&4@;65N<V%G96YS
M(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\N(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HR,S0*;7-G:60@(D-O;FYE8W1I;VX@=&\@<V5R=F5R(&9A:6QE
M9"(*;7-G<W1R(")!(&-O;FYE8^?C;R!A;R!S97)V:61O<B!F86QH;W4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R(")#;VYT
M<F]L87(@<W5P;W)T92!D92!01U`@<&%R82!O("5S+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O
M;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(D-O;G1R;VQA<B!S
M=7!O<G1E(&1E(%,O34E-12!P87)A(&\@)7,N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@X"FUS9VED("(B"B)#;VYT<F]L('=H96X@;F5W(&UA:6P@
M=VEL;"!B92!C:&5C:V5D(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO
M=&EF>2!Y;W4@(@HB=VAE;B!I="!A<G)I=F5S+B(*;7-G<W1R(")#;VYT<F]L
M87(@82!V97)I9FEC8>?C;R!D92!N;W9A<R!M96YS86=E;G,@92!R97-P96-T
M:79A(&YO=&EF:6-AY^-O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.3$*;7-G:60@(D-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P
M:&EC86P@;VYE<S\B"FUS9W-T<B`B0V]N=F5R=&5R(.UC;VYE<R!D92!E;6_G
MXV\@9&4@=&5X=&\@<&%R82!G<N%F:6-O<S\B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:6%R(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y('1O
M(&9O;&1E<B(*;7-G<W1R(")#;W!I87(@<&%R82!P87-T82(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHV-@IM<V=I9"`B0V]R<F5C="(*
M;7-G<W1R(")#;W)R:6=I<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHQ-#4*;7-G:60@(D-O<G)E8W1E9"!497AT(@IM<V=S='(@(E1E
M>'1O($-O<G)I9VED;R(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD
M.B`E<R(*;7-G<W1R("));7!O<W/M=F5L(&-R:6%R(&\@;65C86YI<VUO(%9&
M4SH@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z-C`S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE
M('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@;65N<V%G96YS(&1E("5S+B!/('-E<G9I9&]R(&1I<W-E.B`E<R(*
M"B,Z(&QI8B]397-S:6]N+G!H<#HR.3,*;7-G:60@(D-O=6QD(&YO="!E>&5C
M=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@97AE8W5T87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C4T"FUS9VED(")#;W5L
M9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M
M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5X
M=')A:7(@;R!A<G%U:79O(&1E<V5J861O(&1O(&%N97AO($U3+51.148N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD(&YO
M="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@87)C
M:&EV92XB"FUS9W-T<B`B26UP;W-S[79E;"!E>'1R86ER(&\@87)Q=6EV;R!D
M97-E:F%D;R!D;R!A<G%U:79O(%II<"XB"@HC.B!S96%R8V@N<&AP.C,V,2!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA=&5S+V%C
M;"]A8VPN:6YC.C,Y"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-3<*;7-G
M:60@(D-R96%T92(*;7-G<W1R(")#<FEA<B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C4*;7-G:60@(D-R96%T92!&;VQD97(B"FUS9W-T
M<B`B0W)I87(@4&%S=&$B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C4R
M"FUS9VED(")#<F5A=&4@2V5Y<R(*;7-G<W1R(")#<FEA<B!C:&%V97,B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,30*;7-G:60@(D-R96%T
M92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")#<FEA<B!087-T82!6:7)T=6%L
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z
M,C8*;7-G:60@(D-R96%T92!A($YE=R!!8V-O=6YT(@IM<V=S='(@(D-R:6%R
M($YO=F$@0V]N=&$B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI
M;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T"FUS9VED
M(")#<F5A=&4@82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B0W)I87(@=6UA
M(&YO=F$@<&%S=&$@9&4@4W!A;2(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD
M97)S96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N
M:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<B(*;7-G
M<W1R(")#<FEA<B!U;6$@<&%S=&$@9&4@<F%S8W5N:&]S(&YO=F$B"@HC.B!T
M96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C(W('1E;7!L871E
M<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#,*;7-G:60@(D-R96%T92!A
M(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(D-R:6%R('5M82!P87-T
M82!D92!M96YS86=E;G,@96YV:6%D87,@;F]V82(*"B,Z('1E;7!L871E<R]P
M<F5F<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W1R87-H
M<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H(&9O;&1E
M<B(*;7-G<W1R(")#<FEA<B!U;6$@;F]V82!P87-T82!D92!L:7AO(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,`IM<V=I9"`B(@HB0W)E871E(&9I
M;'1E<FEN9R!R=6QE<R!T;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL
M('-O<G0@:70@:6YT;R!F;VQD97)S+"`B"B)A;F0@9&5L971E('-P86TN(@IM
M<V=S='(@(B(*(D-R:6%R(')E9W)A<R!D92!F:6QT<F%G96T@<&%R82!O<F=A
M;FEZ87(@87,@;65N<V%G96YS(')E8V5B:61A<RP@9&ES=')I8G7M+2(*(FQA
M<R!P96QA<R!R97-P96-T:79A<R!P87-T87,@92!R96UO=F5R('-P86TN(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(D%C97-S;R!C;W)R
M96YT92!A("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I
M9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R;VT@
M;W1H97(@86-C;W5N=',N(@IM<V=S='(@(E!E<G-O;F%L:7IA<B!C;VYT87,@
M<&%R82!D97-C87)R96=A<B!C;W)R96EO(&1E(&]U=')A<R!C;VYT87,N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q"FUS9VED(")#=7-T;VUI>F4@
M:&]W('EO=2!S96YD(&UA:6PN(@IM<V=S='(@(E!E<G-O;F%L:7IA<B!F;W)M
M82!D92!E;G9I;R!D92!C;W)R96EO+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!E<G-O;F%L:7IA
M<B!T87)E9F%S(&5X96-U=&%D87,@86\@86-E9&5R(&$@)7,N(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-PIM<V=I9"`B
M1&%T7V4B"FUS9W-T<B`B7T1A=&$B"@HC.B!M97-S86=E+G!H<#HR-#8@=&AR
M96%D+G!H<#HY,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$871A(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C<U-PIM<V=I9"`B1&5C;&EN960B"FUS
M9W-T<B`B1&5C;&EN861A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C(V,PIM<V=I9"`B1&5C;&EN960Z("(*;7-G<W1R(")$96-L:6YA9&$Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B1&5F875L="(*
M;7-G<W1R(")0;W(@3VUI<W/C;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.30*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!C<FET97)I83HB"FUS9W-T
M<B`B0W)I=.ER:6\@9&4@;W)D96YAY^-O('!A9'+C;SHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3`T"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER
M96-T:6]N.B(*;7-G<W1R(")/<F1E;F'GXV\@<&%D<N-O.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-C4*;7-G:60@(D1E;&5G871E9"(*;7-G
M<W1R(")$96QE9V%D83HB"@HC.B!F;VQD97)S+G!H<#HT,#<@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHV-2!T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDS"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B4F5M;W9E<B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92`E<R!0=6)L:6,@2V5Y(@IM<V=S
M='(@(E)E;6]V97(@0VAA=F4@4/IB;&EC82`E<R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,3(X('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-CD*
M;7-G:60@(D1E;&5T92!#=7)R96YT($ME>7,B"FUS9W-T<B`B4F5M;W9E<B!#
M:&%V97,@0V]R<F5N=&5S(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z-PIM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G<W1R(")296UO
M=F5R(%!A<W1A*',I(@H*(SH@9F]L9&5R<RYP:'`Z,C<T"FUS9VED(")$96QE
M=&4@4V5L96-T960@1F]L9&5R<R(*;7-G<W1R(")296UO=F5R(%!A<W1A<R!3
M96QE8V-I;VYA9&%S(@H*(SH@9F]L9&5R<RYP:'`Z-#`W"FUS9VED(")$96QE
M=&4@5FER='5A;"!&;VQD97(B"FUS9W-T<B`B4F5M;W9E<B!087-T82!6:7)T
M=6%L(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS
M9VED(")$96QE=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V
M97(_(@IM<V=S='(@(E)E;6]V97(@9&\@<V5R=FED;W(@<F5M;W1O(&%S(&UE
M;G-A9V5N<R!D97-C87)R96=A9&%S/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM
M<V=S='(@(E)E;6]V97(@9&\@;65U(&-A;&5N9.%R:6\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S8R"FUS9VED(")$96QE=&4@;VQD(&QI;FME9"!A
M='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(E)E
M;6]V97(@86YE>&]S(&QI9V%D;W,@86YT:6=O<R!N;R!I;NUC:6\@9&4@8V%D
M82!MZG,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B
M1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@
M;6]N=&@_(@IM<V=S='(@(E)E;6]V97(@<&%S=&%S(&%N=&EG87,@9&4@96YV
M:6%D;W,@;F\@:6[M8VEO(&1E(&-A9&$@;>IS/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV,3(*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(&%F
M=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T_(@IM<V=S='(@
M(E)E;6]V97(@;65N<V%G96YS(&1E('-P86T@<75A;F1O(&-O;6\@=&%L(&9O
M<F5M(')E<&]R=&%D87,_(@H*(SH@;65S<V%G92YP:'`Z-#@W(&UA:6QB;W@N
M<&AP.C<Q.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(P"B,Z('1E
M;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB
M;W@O;&5G96YD+FEN8SHX"FUS9VED(")$96QE=&5D(@IM<V=S='(@(E)E;6]V
M:61A(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B
M1&5L971E9"!M97-S86=E<R(*;7-G<W1R(")-96YS86=E;G,@<F5M;W9I9&%S
M(@H*(SH@8V]M<&]S92YP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T960@=&AE(&%T=&%C:&UE;G0@7"(E<UPB+B(*;7-G<W1R(")!;F5X;R!<
M(B5S7"(@<F5M;W9I9&\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y
M"FUS9VED(")$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S(@IM<V=S='(@
M(E)E;6]V96YD;R!E($UO=F5N9&\@365N<V%G96YS(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S
M='(@(E)E8W5S87(@<&5D:61O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4T,`IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF
M;W)M871I;VXB"FUS9W-T<B`B4F5C=7-A<B!P961I9&\@9&4@:6YF;W)M8>?C
M;R!L:79R92]O8W5P861O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP
M,PIM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R(")$96-R97-C96YT92(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR,2!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C8Y"FUS9VED(")$97-C<FEP=&EO;B(*;7-G
M<W1R(")$97-C<FGGXV\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C8U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3$S"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHY,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30W"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-3$*;7-G:60@(D1E=&%I;',B"FUS
M9W-T<B`B1&5T86QH97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<Q
M"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B"FUS9W-T<B`B07-S:6YA='5R87,@
M1$E-/R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,V
M"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(E9I<W5A;&EZ8>?C;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S`*;7-G:60@(D1I<W!L87D@8V]N9FER
M;6%T:6]N(&%F=&5R('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R(")-;W-T
M<F%R(&-O;F9I<FUAY^-O(&%P\W,@96YV:6%R('5M82!M96YS86=E;3\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@P"FUS9VED(")$:7-P;&%Y(&EN
M($)O9'D@;V8@365S<V%G92(*;7-G<W1R(")-;W-T<F%R(&YO($-O<G!O(&1A
M($UE;G-A9V5M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V.`IM<V=I
M9"`B1&ES<&QA>2!P;W`M=7`@;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL/R(*
M;7-G<W1R(")-;W-T<F%R('5M82!N;W1I9FEC8>?C;R!<(G!O<'5P7"(@<75A
M;F1O(&-H96=A<F5M(&YO=F%S(&UE;G-A9V5N<S\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S,S"FUS9VED(")$:7-P;&%Y('1H92`G16UP='D@5')A
M<V@G(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(DUO<W1R87(@;R!L
M:6YK("=%<W9A>FEA<B!L:7AO)R!N82!B87)R82!D;R!M96YU/R(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ,0IM<V=I9"`B1&ES
M<&]S:71I;VXB"FUS9W-T<B`B1&ES<&]S:>?C;R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA=&-H(@IM<V=S
M='(@(D[#3R!C;W)R97-P;VYD92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C$T"FUS9VED(")$;R!.;W0@0VAE8VL@1F]L9&5R*',I(&9O
M<B!.97<@36%I;"(*;7-G<W1R(").XV\@5F5R:69I8V%R('-E($CA($UE;G-A
M9V5N<R!.;W9A<R!N82AS*2!087-T82AS*2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,C,*;7-G:60@(D1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@
M=&AE($9R;VTZ(&-O;'5M;B(*;7-G<W1R(").XV\@9V5R87(@=6UA(&QI9V'G
MXV\@;F$@8V]L=6YA($1E.B(*"B,Z(&QI8B])35`N<&AP.C$P,S$*;7-G:60@
M(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD97(_(@IM<V=S='(@(D1E
M<V5J82!A8G)I<B!E<W-A('!A<W1A/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(D1O;F4B"FUS9W-T<B`B1F5I=&\B
M"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DQ"B,L('!H<"UF;W)M870*
M;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(D1E
M<V-A<G)E9V%R("5S(&5M(&9O<FUA=&\@+GII<"(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VAE861E<G,N:6YC.C4R"FUS9VED(")$;W=N;&]A9"!!;&P@071T
M86-H;65N=',@*&EN("YZ:7`@9FEL92DB"FUS9W-T<B`B1&5S8V%R<F5G87(@
M5&]D;W,@;W,@06YE>&]S("AN=6T@9FEC:&5I<F\@+GII<"DB"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B1&]W;FQO860@
M1F]L9&5R*',I(@IM<V=S='(@(E)E8V5B97(@4&%S=&$H<RDB"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B1&]W;FQO860@
M1F]L9&5R*',I(%LN>FEP(&9O<FUA=%TB"FUS9W-T<B`B4F5C96)E<B!087-T
M82AS*2!;+GII<"!F;W)M871=(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP
M.C$Y,0IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B
M1&5S8V%R<F5G87(@;F\@1F]R;6%T;R`N>FEP(@H*(SH@;65S<V%G92YP:'`Z
M-#@U(&UA:6QB;W@N<&AP.C8Y."!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,C(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP
M;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S
M='(@(E)A<V-U;FAO(@H*(SH@9F]L9&5R<RYP:'`Z,S@W"FUS9VED(")$<F%F
M="!F;VQD97(B"FUS9W-T<B`B4&%S=&$@9&4@<F%S8W5N:&]S(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T
M<R!F;VQD97(Z(@IM<V=S='(@(E!A<W1A(&1E(')A<V-U;FAO<SHB"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3DV"FUS9VED(")%+6UA:6P@061D<F5S
M<R(*;7-G<W1R(")%;F1E<F7G;R!D92!#;W)R96EO($5L96-T<O-N:6-O(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,P,PIM<V=I9"`B14Y$(@IM<V=S='(@(D9)
M32(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED(")%
M4E)/4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N(@IM
M<V=S='(@(D524D\Z($$@<W5A(&UE;G-A9V5M(&[C;R!P]&1E('-E<B!E;G1R
M96=U92XB"@HC.B!F;VQD97)S+G!H<#HT,#@*;7-G:60@(D5D:70B"FUS9W-T
M<B`B161I=&%R(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(Q
M"FUS9VED(")%9&ET($)L86-K;&ES="(*;7-G<W1R(")%9&ET87(@3&ES=&$@
M3F5G<F$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,38*;7-G
M:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R(")%9&ET87(@1FEL=')O<R(*"B,Z
M(&9O;&1E<G,N<&AP.C0P."!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z
M,38*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,PIM<V=I9"`B
M161I="!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")%9&ET87(@4&%S=&$@5FER
M='5A;"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B!$969I;FET
M:6]N(&9O<B`E<R(*;7-G<W1R(")%9&ET87(@1&5F:6YIY^-O(&1E(%!A<W1A
M(%9I<G1U86P@9&4@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z,C8*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(D5D:71A<B!,
M:7-T82!"<F%N8V$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,C$*;7-G:60@(D5D:70@>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B161I=&%R
M(&$@<W5A(&QI<W1A(&YE9W)A(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C$V"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(@IM<V=S
M='(@(D5D:71A<B!A<R!S=6%S(')E9W)A<R!D92!F:6QT<F%G96TB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,P"FUS9VED(")%9&ET('EO=7(@<')E
M9F5R96YC97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+B(*
M;7-G<W1R("(B"B)%9&ET87(@87,@<W5A('!R969E<NIN8VEA<R!P87)A(&%C
M961E<B!A(&]U=')A<R!C;VYT87,@9&4@8V]R<F5I;R`B"B)E;&5C='+S;FEC
M;RXB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,C8*;7-G:60@
M(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B161I=&%R(&$@<W5A(&QI
M<W1A(&)R86YC82(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C,Y"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O
M(&1E($5M86EL(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8R,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F<F]M("5S+B(*;7-G
M<W1R(")4;V1A<R!A<R!M96YS86=E;2!D92`E<R!F;W)A;2!E<W9A>FEA9&%S
M+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS9VED
M(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B17-V87II87(@('!A<W1A*',I
M(@H*(SH@9F]L9&5R<RYP:'`Z,C<U"FUS9VED(")%;7!T>2!396QE8W1E9"!&
M;VQD97)S(@IM<V=S='(@(D5S=F%Z:6%R(%!A<W1A<R!396QE8V-I;VYA9&%S
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@
M(D5M<'1Y(%1R87-H(&9O;&1E<B(*;7-G<W1R(")%<W9A>FEA<B!A(%!A<W1A
M(&1E($QI>&\B"@HC.B!L:6(O24U0+G!H<#HY,S$*;7-G:60@(D5M<'1Y(%]4
M<F%S:"(*;7-G<W1R(")%<W9A>FEA<B!,:5]X;R(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR,"!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,38*
M;7-G:60@(D5N86)L92!01U`@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B06-T
M:79A<B!F=6YC:6]N86QI9&%D97,@9&\@4$=0/R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,C`@=&5M<&QA=&5S+W-M:6UE+VYO=&%C=&EV92YI
M;F,Z,38*;7-G:60@(D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\B"FUS
M9W-T<B`B06-T:79A<B!F=6YC:6]N86QI9&%D97,@9&\@4R]-24U%/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G:60@(D5N86)L92!M97-S
M86=E('!R979I97=S/R(*;7-G<W1R(")!8W1I=F%R('!R979I<_5E<R!D92!M
M96YS86=E;G,_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#,S"FUS9VED(")%;F-R7WEP=&EO;B!/<'1I;VYS(@IM<V=S='(@(D]PY_5E
M<R!D92!%;F-R:7!?=&'GXV\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3$W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3<*;7-G:60@(D5N
M9"(*;7-G<W1R(")&:6TB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,P"FUS9VED
M(")%;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B1FEN86QI>F%R(&UE
M;G-A9V5M(')E96YV:6%D82(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR-S$*;7-G
M:60@(D5N9"!M97-S86=E(@IM<V=S='(@(D9I;2!D82!M96YS86=E;2(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YD
M(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")&:6T@9&$@;65N<V%G96T@9&4@
M)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$Q-R!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,34Q"FUS9VED(")%;G1E<B!087-S<&AR87-E(@IM
M<V=S='(@(DEN=')O9'5Z82!A($9R87-E+4-H879E(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-P86US96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE
M(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R("));G1R;V1U>F$@
M;R!N;VUE(&1A('-U82!N;W9A('!A<W1A(%-P86TB"@HC.B!T96UP;&%T97,O
M<')E9G,O9F]L9&5R<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M
M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R("));G1R;V1U
M>F$@;R!N;VUE(&1A('-U82!N;W9A('!A<W1A(&1E(')A<V-U;FAO<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C0*;7-G:60@
M(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R
M(@IM<V=S='(@(DEN=')O9'5Z82!O(&YO;64@9&$@<W5A(&YO=F$@<&%S=&$@
M9&4@;65N<V%G96YS(&5N=FEA9&%S(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R
M87-H<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U
M<B!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(DEN=')O9'5Z82!O(&YO;64@
M9&$@<W5A(&YO=F$@<&%S=&$@9&4@;&EX;R(*"B,Z('-E87)C:"YP:'`Z,34Y
M"FUS9VED(")%;G1I<F4@365S<V%G92(*;7-G<W1R(")-96YS86=E;2!#;VUP
M;&5T82(*"B,Z(&UE<W-A9V4N<&AP.C$W."!C;VUP;W-E+G!H<#HQ,#8X('1H
M<F5A9"YP:'`Z,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB
M('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*
M;7-G<W1R(")!(&5N=')A9&$@7"(E<UPB(&9O:2!A9&EC:6]N861A(&%O(&QI
M=G)O(&1E(&5N9&5R9>=O<R!C;VT@<W5C97-S;R(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-3@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@T"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S8U(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C,X-@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW
M,B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C,*;7-G:60@(D5R<F]R
M(@IM<V=S='(@(D5R<F\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,S`Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(D5R
M<F\@86\@96YV:6%R(')E<W!O<W1A.B`E<RXB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,3`Q"FUS9VED(")%=F5N="!S=6-C97-S9G5L;'D@9&5L
M971E9"XB"FUS9W-T<B`B179E;G1O(')E;6]V:61O(&-O;2!S=6-E<W-O+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-3@*;7-G:60@(D5V97)Y(#$U
M(&UI;G5T97,B"FUS9W-T<B`B0V%D82`Q-2!M:6YU=&]S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<U-0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*
M;7-G<W1R(")#861A(#,P('-E9W5N9&]S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<U-PIM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D-A
M9&$@-2!M:6YU=&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.0IM
M<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D-A9&$@;65I82UH;W)A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U-@IM<V=I9"`B179E<GD@
M;6EN=71E(@IM<V=S='(@(D-A9&$@;6EN=71O(@H*(SH@9F]L9&5R<RYP:'`Z
M-#0U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B17AP86YD:7(B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B17AP86YD($%L
M;"(*;7-G<W1R(")%>'!A;F1I<B!4=61O(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,S,*;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*
M;7-G<W1R(")%>'!A;F1I<B!4;V1A<R!A<R!087-T87,B"@HC.B!F;VQD97)S
M+G!H<#HT-#4*;7-G:60@(D5X<&%N9"!&;VQD97(B"FUS9W-T<B`B17AP86YD
M:7(@4&%S=&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M,S$@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4V"FUS9VED(")%
M>'!A;F0@3F%M97,B"FUS9W-T<B`B17AP86YD:7(@3F]M97,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`R,0IM<V=I9"`B17AP86YD(&YA;65S(&EN
M('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H92!B86-K
M9W)O=6YD/R(*;7-G<W1R("(B"B)%>'!A;F1I<B!N;VUE<R!N82!J86YE;&$@
M9&4@8V]M<&]S:>?C;R!A=71O;6%T:6-A;65N=&4@92!N;W,@8F%S=&ED;W)E
M<S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")%>'!A
M;F0@=&AE(&5N=&ER92!F;VQD97(@=')E92!B>2!D969A=6QT(&EN('1H92!F
M;VQD97)S('9I97<_(@IM<V=S='(@(DUO<W1R87(@<&]R(&]M:7-SXV\@=&]D
M82!A(.%R=F]R92!D92!P87-T87,@;F$@=FES=6%L:7IAY^-O(&1E('!A<W1A
M<S\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-34@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(U-B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z,3`T"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T<B`B17AP86YD
M:6YD;R(*"B,Z(&QI8B])35`N<&AP.CDT,"!L:6(O24U0+G!H<#HY-#(*;7-G
M:60@(D9?971C:"!-86EL(@IM<V=S='(@(E]$97-C87)R96=A<B(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`S"FUS9VED(")&971C:"!-86EL(@IM<V=S='(@(D1E
M<V-A<G)E9V%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S.0IM<V=I
M9"`B1F5T8V@@36%I;"!I;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B
M1&5S8V%R<F5G87(@;G5M82!J86YE;&$@<V5P87)A9&$_(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0V"FUS9VED(")&971C:"!M97-S
M86=E<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S='(@(D1E<V-A<G)E9V%R(&UE
M;G-A9V5N<R!A;R!E;G1R87(_(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@9G)O
M;2`E<R(*;7-G<W1R("(E9"!M96YS86=E;G,@9&5S8V%R<F5G861A<R!D92`E
M<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(C$@;65N
M<V%G96T@9&5S8V%R<F5G861A(&1E("5S(@H*(SH@;&EB+T9E=&-H;6%I;"YP
M:'`Z,C@U(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL+G!H
M<#HR.#D*;7-G:60@(D9E=&-H;6%I;#H@(@IM<V=S='(@(D1E<V-A<G)E9V%M
M96YT;W,Z(@H*(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"FUS9VED(")&971C
M:&UA:6PZ(&YO(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B1&5S8V%R<F5G86UE
M;G1O<SH@<V5M(&UE;G-A9V5N<R!N;W9A<RXB"@HC.B!L:6(O24U0+G!H<#HY
M-#8*;7-G:60@(D9I7VQT97)S(@IM<V=S='(@(D9I7VQT<F]S(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DR('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FIS.C@S"FUS9VED(")&:6QE(@IM<V=S='(@(D%R
M<75I=F\B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S4*;7-G
M:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!&:6QT<F%G
M96TB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.`IM<V=I9"`B
M1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(D-O;F9I9W5R8>?U97,@9&$@1FEL
M=')A9V5M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Y-`IM<V=I9"`B
M1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R
M(")&:6QT<F%R(&-O;G1E^F1O('!R;V9A;F\@9&4@;65N<V%G96YS/R(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z.`IM<V=I9"`B1FEL
M=&5R('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S
M='(@(D\@<W5P;W)T92!D92!F:6QT<F]S(&5S=.$@9&5S86-T:79A9&\@;F5S
M=&4@<VES=&5M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Y"FUS
M9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R;W,B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C(*;7-G:60@(D9I;'1E<G,@3D]4($%C
M=&EV92(*;7-G<W1R(")&:6QT<F]S($EN86-T:79O<R(*"B,Z(&QI8B]&:6QT
M97(N<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QT97)S.B`E<R!M
M86YA9V5M96YT('!A9V4B"FUS9W-T<B`B1FEL=')O<SH@)7,@<.%G:6YA<R!D
M92!G97-TXV\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C$X-@IM<V=I9"`B1FEN9"(*;7-G<W1R(")0<F]C=7)A<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-S8*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G
M92(*;7-G<W1R(")0<FEM96ER82!0X6=I;F$@9&$@0V%I>&$@4&]S=&%L(@H*
M(SH@;6%I;&)O>"YP:'`Z,S0Q"FUS9VED(")&:7)S="!086=E(@IM<V=S='(@
M(E!R:6UE:7)A(%#A9VEN82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHR,0IM<V=I9"`B1F]?<G=A<F0B"FUS9W-T<B`B7T5N8V%M:6YH87(B"@HC
M.B!F;VQD97)S+G!H<#HR-34@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C
M;VYF:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF:7)M
M871I;VXB"FUS9W-T<B`B06/G]65S(&1E(%!A<W1A("T@0V]N9FER;6'GXV\B
M"@HC.B!F;VQD97)S+G!H<#HR.3(@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI
M;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC
M.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHQ
M,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R("),:7-T82!D92!0
M87-T87,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-0IM<V=I
M9"`B1F]L9&5R(%!R969I>"(*;7-G<W1R(")0<F5F:7AO(&1E(%!A<W1A(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C,*;7-G:60@(D9O;&1E<B!3=6UM
M87)Y(@IM<V=S='(@(E-U;>%R:6\@9&$@4&%S=&$B"@HC.B!A8VPN<&AP.C(T
M"FUS9VED(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS9W-T
M<B`B4&%R=&EL:&$@9&4@<&%S=&%S(&EN86-T:79A+B(*"B,Z(&9O;&1E<G,N
M<&AP.C4R"FUS9VED(")&;VQD97(@=7-E(&ES(&YO="!E;F%B;&5D+B(*;7-G
M<W1R(")5=&EL:7IAY^-O(&1E('!A<W1A<R!I;F%C=&EV82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.30P"FUS9VED(")&;W)M870@;V8@;65S<V%G
M92!D871E<R!I;B!T:&4@;6%I;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E
M9"!T;V1A>2(*;7-G<W1R(")&;W)M871O(&1A<R!D871A<R!D87,@;65N<V%G
M96YS(&1E(&AO:F4B"@HC.B!C;VUP;W-E+G!H<#HW,C<@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")&;W)W87)D(@IM<V=S='(@(D5N
M8V%M:6YH87(B"@HC.B!C;VUP;W-E+G!H<#HW,3(*;7-G:60@(D9O<G=A<F0Z
M(@IM<V=S='(@(D5N8V%M:6YH861A.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR
M.3D*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(DUE;G-A9V5M
M(&5N8V%M:6YH861A(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Y-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")&;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S
M='(@(DUE;G-A9V5M(&5N8V%M:6YH861A(&1E("5S(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C0X,PIM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DEN9F]R;6'GXV\@9&4@1&ES<&]N:6)I;&ED861E<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.30*;7-G:60@(D9R964O
M0G5S>2!297!L>2(*;7-G<W1R(")297-P;W-T82!,:79R92]/8W5P861O(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X.`IM<V=I9"`B1G)E92]"
M=7-Y(%)E<75E<W0B"FUS9W-T<B`B4&5D:61O($QI=G)E+T]C=7!A9&\B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Q"FUS9VED(")&<F5E+T)U
M<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R(")297-P;W-T82!A(%!E9&ED
M;R!,:79R92]/8W5P861O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHR-PIM<V=I9"`B1G)O7VTB"FUS9W-T<B`B7T1E(@H*
M(SH@;65S<V%G92YP:'`Z,C0W('-E87)C:"YP:'`Z,3,U('1H<F5A9"YP:'`Z
M.3,*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.3@*;7-G:60@
M(D9R;VTB"FUS9W-T<B`B1&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#@Y"FUS9VED(")&<F]M($%D9')E<W,B"FUS9W-T<B`B1&\@16YD97)EYV\B
M"@HC.B!C;VUP;W-E+G!H<#HW,C0@8V]M<&]S92YP:'`Z-S(X"FUS9VED(")&
M=V0Z(@IM<V=S='(@(D5N8SHB"@HC.B!C;VUP;W-E+G!H<#HQ,C(Y"FUS9VED
M(")&=V0Z("(*;7-G<W1R(")%;F,Z("(*"B,Z(&-O;7!O<V4N<&AP.C$R,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1G=D.B`E=2!&;W)W87)D960@365S<V%G
M97,B"FUS9W-T<B`B16YC.B`E=2!-96YS86=E;G,@16YC86UI;FAA9&%S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS9W-T
M<B`B3W#G]65S($=E<F%I<R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHS-PIM<V=I9"`B1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!
M4"!O;FQY*2(*;7-G<W1R(")$97-C87)R96=A<B!A<&5N87,@;65N<V%G96YS
M(&YO=F%S/R`H87!E;F%S($E-05`I(@H*(SH@=&AR96%D+G!H<#HX-0IM<V=I
M9"`B1V\@=&\@365S<V%G92(*;7-G<W1R("))<B!P87)A($UE;G-A9V5M(@H*
M(SH@;&EB+TE-4"YP:'`Z-34S"B,L('!H<"UF;W)M870*;7-G:60@(D=O('1O
M(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B27(@<&%R
M82!A(&5N=')A9&$@9&\@;&EV<F\@9&4@96YD97)EYV]S(&-O<G)E<W!O;F1E
M;G1E(&$@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM
M<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(D%U=&]R:7IA<B!A8V5S<V\B
M"@HC.B!M97-S86=E+G!H<#HU,S`@;&EB+T9I;'1E<BYP:'`Z,3`V(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$P,B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*
M(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HQ,C@*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A
M=&EO;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z
M-C@*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z-#`W"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L
M961O=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%4D4B"FUS9W-T<B`B05%522(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,CD@;&EB+TU)344O5FEE
M=V5R+W)E;&%T960N<&AP.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB
M"@HC.B!C;VUP;W-E+G!H<#HR,CD*;7-G:60@(DA434P@5F5R<VEO;B!O9B!-
M97-S86=E(@IM<V=S='(@(E9E<G/C;R!(5$U,(&1A($UE;G-A9V5M(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@(DAE861E
M<G,B"FUS9W-T<B`B0V%B9>=A;&AO<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W)E8V]M<&]S92YI;F,Z-0IM<V=I9"`B2&5R92!I<R!T:&4@;65S<V%G92!Y
M;W4@=V5R92!C;VUP;W-I;F<Z(@IM<V=S='(@(D%Q=6D@97-TX2!A(&UE;G-A
M9V5M(&5M(&-O;7!O<VGGXV\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8V,@IM<V=I9"`B2&ED9&5N(@IM<V=S='(@(D5S8V]N9&ED;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C$*;7-G:60@(DAI9&1E;B!I;B!4:')E
M860@5FEE=R(*;7-G<W1R(")%<V-O;F1I9&\@96T@5FES=6%L:7IAY^-O(&1E
M($-O;G9E<G-A(@H*(SH@;6%I;&)O>"YP:'`Z,S8S"FUS9VED(")(:61E($1E
M;&5T960B"FUS9W-T<B`B17-C;VYD97(@4F5M;W9I9&%S(@H*(SH@9F]L9&5R
M<RYP:'`Z,C@W"FUS9VED(")(:61E(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")%
M<V-O;F1E<B!.XV\M4W5B<V-R:71A<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,#0*;7-G:60@(DAI9&4@=&AE($EM86=E<R(*;7-G<W1R(")%
M<V-O;F1E<B!A<R!);6%G96YS(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S`U"FUS9VED(")(:6=H(@IM<V=S='(@(D%L=&$B"@HC.B!M
M97-S86=E+G!H<#HR.#$@;6%I;&)O>"YP:'`Z-S`S('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI9V@@4')I;W)I='DB"FUS9W-T
M<B`B06QT82!0<FEO<FED861E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S`T"FUS9VED(")(:6=H97-T(@IM<V=S='(@(D$@36%I<R!!
M;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X,@IM<V=I9"`B2&]W
M(&1O('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_(@IM<V=S='(@
M(D-O;6\@<75E<B!M;W-T<F%R(&]S(&%N97AO<S\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#DV"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E
M9"!L:6YE<R!I;B!A(')E<&QY(@IM<V=S='(@(D-O;6\@871R:6)U:7(@87,@
M;&EN:&%S(&-I=&%D87,@;G5M82!R97-P;W-T82(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3,T"FUS9VED("))34%0(@IM<V=S='(@(DE-05`B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H075T
M;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R("))34%0("A0<F]T;V-O;&]S
M(&-O;2!!=71O+61E=&5CY^-O*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,38S(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))
M34%0(&]V97(@4U-,(@IM<V=S='(@(DE-05`@<V]B<F4@4U-,(@H*(SH@;&EB
M+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-3(*;7-G:60@(DE-05`@;W9E<B!34TP@
M*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("))34%0('-O8G)E
M(%-33"`H8V5R=&EF:6-A9&\@875T;RUA<W-I;F%D;RDB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$V-`IM<V=I9"`B24U!4"!O=F5R(%-33"`H
M<V5L9BUS:6=N960I(@IM<V=S='(@(DE-05`@<V]B<F4@4U-,("AA=71O+6%S
M<VEN861O*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38R(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS9VED("))34%0+"!N;R!43%,B
M"FUS9W-T<B`B24U!4"P@<V5M(%1,4R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T
M<B`B4V5R=FED;W)E<R!D92!#;W)R96EO($5L96-T<O-N:6-O($E-05`O4$]0
M,R(*"B,Z(&QI8B])35`N<&AP.C@X-@IM<V=I9"`B24Y"3U@B"FUS9W-T<B`B
M16YT<F%D82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER
M;2YH=&UL.C$R"FUS9VED("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E
M<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S="$B"FUS9W-T<B`B4V4@
M8V]N=&EN=6%R+"!T;V1A<R!A<R!M96YS86=E;G,@9&$H<RD@<&%S=&%S*',I
M('-E('!E<F1E<N-O(2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHX.`IM<V=I9"`B26=N;W)E(@IM<V=S='(@(DEG;F]R87(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#D*;7-G:60@(DEG;F]R
M92!!;&PB"FUS9W-T<B`B26=N;W)A<B!4=61O(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O:6UP;W)T+FEN8SHR,`IM<V=I9"`B26UP;W)T(@IM<V=S='(@(DEM
M<&]R=&%R(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@T
M('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C4*;7-G:60@(DEM<&]R
M="!+97DB"FUS9W-T<B`B26UP;W)T87(@0VAA=F4B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,C4T"FUS9VED("));7!O<G0@2V5Y<&%I<B(*;7-G<W1R
M("));7!O<G1A<B!087(@9&4@0VAA=F5S(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,C4*;7-G:60@(DEM<&]R="!-97-S86=E<R(*;7-G
M<W1R("));7!O<G1A<B!-96YS86=E;G,B"@HC.B!P9W`N<&AP.C0R"FUS9VED
M("));7!O<G0@4$=0($ME>2(*;7-G<W1R("));7!O<G1A<B!#:&%V92!01U`B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$T.`IM<V=I9"`B26UP
M;W)T(%!E<G-O;F%L($-E<G1I9FEC871E<R(*;7-G<W1R("));7!O<G1A<B!#
M97)T:69I8V%D;W,@4&5S<V]A:7,B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y(@IM<V=S='(@(DEM<&]R=&%R(&-H879E('!E<W-O86P@<')I=F%D
M82!01U`B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.CD*;7-G
M:60@(DEM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("))
M;7!O<G1A<B!C:&%V92!P97-S;V%L('#Z8FQI8V$@4$=0(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R="!097)S
M;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S(@IM<V=S='(@(DEM<&]R=&%R($-E
M<G1I9FEC861O<R!097-S;V%I<R!3+TU)344B"@HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#<*;7-G
M:60@(DEM<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(DEM<&]R=&%R(&-H879E
M('#Z8FQI8V$B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0*
M;7-G:60@(DEM<&]R="!0=6)L:6,@4$=0($ME>2(*;7-G<W1R("));7!O<G1A
M<B!C:&%V92!P^F)L:6-A(%!'4"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O
M<G1?:V5Y+FEN8SHX"FUS9VED("));7!O<G0@4'5B;&EC(%,O34E-12!+97DB
M"FUS9W-T<B`B26UP;W)T87(@0VAA=F4@4/IB;&EC82!3+TU)344B"@HC.B!S
M;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@
M(DEM<&]R=&%R($-H879E(%,O34E-12(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G<W1R
M("));7!O<G1A<B!!<G%U:79O($U"3U@B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]I;7!O<G0N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!M
M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N(@IM<V=S='(@(DEM<&]R=&%R
M(&%R<75I=F\@34)/6"`E<R!P87)A(&$@<&%S=&$@)7,N(@H*(SH@;65S<V%G
M92YP:'`Z-#@V(&UA:6QB;W@N<&AP.C<Q,R!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,S"B,Z
M('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM<V=I9"`B26UP;W)T
M86YT(@IM<V=S='(@(DEM<&]R=&%N=&4B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@;65S<V%G97,B"FUS9W-T
M<B`B365N<V%G96YS(&EM<&]R=&%N=&5S(@H*(SH@9F]L9&5R<RYP:'`Z,34W
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S(&9R
M;VT@)7,N(@IM<V=S='(@(B5D(&UE;G-A9V5N<R!I;7!O<G1A9&%S(&1E("5S
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-S,*;7-G:60@(DEN
M(%!R;V-E<W,B"FUS9W-T<B`B16T@4')O8V5S<V%M96YT;R(*"B,Z(&9O;&1E
M<G,N<&AP.C,W.2!L:6(O1F]L9&5R+G!H<#HR,C<@;&EB+TE-4"YP:'`Z,S4X
M(&QI8B])34%0+U1R964N<&AP.C$P-0HC.B!L:6(O24U!4"]4<F5E+G!H<#HR
M,#0*;7-G:60@(DEN8F]X(@IM<V=S='(@(D5N=')A9&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#@T"FUS9VED("));F-L=61E(&$@8G)I968@<W5M
M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM<V=S='(@(DEN8VQU
M:7(@=6T@8G)E=F4@<W5MX7)I;R!D;R!C86)EYV%L:&\@;G5M82!R97-P;W-T
M83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<X"FUS9VED("));F-L
M=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B"FUS9W-T<B`B26YC
M;'5I<B!A(&UE;G-A9V5M(&]R:6=I;F%L(&YA(')E<W!O<W1A/R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C$S,`IM<V=I9"`B26YF;R(*;7-G<W1R("));F9O
M<FUAY^-O(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-2!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YF
M;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*;7-G<W1R("));F9O<FUAY^-O
M('-O8G)E(&$@8VAA=F4@</IB;&EC82`E<R(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHQ-3$*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R
M:79A=&4@2V5Y(@IM<V=S='(@(DEN9F]R;6'GXV\@<V]B<F4@82!C:&%V92!P
M97-S;V%L('!R:79A9&$B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C$Q,R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30W"FUS9VED("));F9O<FUA
M=&EO;B!O;B!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(DEN9F]R;6'G
MXV\@<V]B<F4@82!C:&%V92!P97-S;V%L('#Z8FQI8V$B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,34@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#DW"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FIS.CDY"FUS9VED("));FQI;F4B"FUS9W-T<B`B16TM;&EN:&$B
M"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B
M26YS97)T($-E<G1I9FEC871E($AE<F4B"FUS9W-T<B`B26YS:7)A(&\@0V5R
M=&EF:6-A9&\@07%U:2(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI
M;F,Z,34*;7-G:60@(DEN<V5R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@
M2&5R92(*;7-G<W1R("));G-I<F$@82!#:&%V92!097-S;V%L(%!R:79A9&$@
M4$=0($%Q=6DB"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$P
M"FUS9VED("));G-E<G0@4&5R<V]N86P@4'5B;&EC(%!'4"!+97D@2&5R92(*
M;7-G<W1R("));G-I<F$@82!#:&%V92!097-S;V%L(%#Z8FQI8V$@4$=0($%Q
M=6DB"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4*;7-G:60@
M(DEN<V5R="!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(DEN<VER82!A
M($-H879E(%#Z8FQI8V$@4$=0($%Q=6DB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E9"!F
M;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(D%CY^-O('-E;&5C8VEO;F%D
M82!I;G;A;&ED82!P87)A(&5S=&4@8V]M<&]N96YT92XB"@HC.B!M86EL8F]X
M+G!H<#HU-C,@;6%I;&)O>"YP:'`Z-C`U"FUS9VED("));G9A;&ED($%D9')E
M<W,B"FUS9W-T<B`B16YD97)EYV\@26YVX6QI9&\B"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!296UO=&4@36%I;&)O
M>"(*;7-G<W1R(")#86EX82!0;W-T86P@4F5M;W1A($EN=N%L:61A(@H*(SH@
M8V]M<&]S92YP:'`Z,3,Q"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@
M8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B0V%R
M86-T97)E(&EN=N%L:61O(&YO(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R
M\VYI8V\Z("5S+B(*"B,Z('-M:6UE+G!H<#HX,B!P9W`N<&AP.C$V"FUS9VED
M("));G9A;&ED(&ME>2(*;7-G<W1R(")#:&%V92!I;G;A;&ED82(*"B,Z('!G
M<"YP:'`Z,3DV"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E
M(&ME>2XB"FUS9W-T<B`B0VAA=F4@<&5S<V]A;"!P<FEV861A(%!'4"!I;G;A
M;&ED82XB"@HC.B!P9W`N<&AP.C$W,0IM<V=I9"`B26YV86QI9"!P97)S;VYA
M;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T<B`B0VAA=F4@</IB;&EC82!P97-S
M;V%L(%!'4"!I;G;A;&ED82XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C$R"FUS9VED("));G9E<G0B"FUS9W-T<B`B26YV97)T97(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-C<*;7-G:60@(DM"
M(@IM<V=S='(@(DM"(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(P,0IM
M<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")#;VUP<FEM96YT;R!D82!C:&%V
M92(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-3(*;7-G:60@(B(*(DME
M>2!G96YE<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE('1O(&-O;7!L971E
M+B`@0V]N=&EN=64@=VET:"!K97D@(@HB9V5N97)A=&EO;C\B"FUS9W-T<B`B
M02!G97)AY^-O(&1A<R!C:&%V97,@<&]D92!D96UO<F%R(&UU:71O('1E;7!O
M+B`@0V]N=&EN=6%R/R(*"B,Z('!G<"YP:'`Z,S$X"FUS9VED(")+97D@<W5C
M8V5S<V9U;&QY('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D-H879E(&5N=FEA9&$@8V]M('-U8V5S<V\@<&%R82!O('-E<G9I9&]R
M(&1E(&-H879E<RXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$Y
M.0IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B261I;VUA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@W-PIM<V=I9"`B3&%S="!-86EL8F]X(%!A9V4B
M"FUS9W-T<B`BVFQT:6UA(%#A9VEN82!D82!#86EX82!0;W-T86PB"@HC.B!M
M86EL8F]X+G!H<#HS-30*;7-G:60@(DQA<W0@4&%G92(*;7-G<W1R("+:;'1I
M;6$@4.%G:6YA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,S@P"FUS9VED("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R(")!;F5X;W,@
M8V]M($QI9V'G]65S(@H*(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O
M<V4N<&AP.CDW-`IM<V=I9"`B3&EN:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B
M:61D96XN(@IM<V=S='(@(D%N97AO<R!C;VT@;&EG8>?U97,@<^-O('!R;VEB
M:61O<RXB"@HC.B!L:6(O0V]M<&]S92YP:'`Z.3DQ"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI;FMS('=I;&P@97AP:7)E(&]N("5S(@IM<V=S='(@(DQI9V'G
M]65S(&5X<&ER87+C;R!E;2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#0P"FUS9VED("(B"B),:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I
M;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL
M;"`B"B)O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X
M<&QI8VET;'DI(@IM<V=S='(@(B(*(DQI<W1A<R!T;V1O<R!O<R!C;VYT86-T
M;W,@<75A;F1O(&-A<G)E9V%N9&\@82!J86YE;&$@9&4@8V]N=&%C=&]S/R`H
M<V4@(@HB9&5S86-T:79A9&\L('9E<N$@87!E;F%S(&]S(&-O;G1A8W1O<R!P
M96QO<R!Q=6%I<R!P<F]C=7)A<B!E>'!L:6-I=&%M96YT92DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C<Y"FUS9VED("),:7-T:6YG(&EN('1H92!(
M96%D97(B"FUS9W-T<B`B3&ES=&%G96T@;F\@0V%B9>=A;&AO(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P"FUS9VED("),;V-A;"!-
M86EL8F]X.B(*;7-G<W1R(")#86EX82!0;W-T86P@3&]C86PZ(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B3&]C86PB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P
M-PIM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D5N=')A<B(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN
M('1O("5S(@IM<V=S='(@(D5N=')A<B!E;2`E<R(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3,V"FUS9VED("),;V=I;B(*;7-G<W1R(")%;G1R
M87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(DQO9VEN
M(%1A<VMS(@IM<V=S='(@(E1A<F5F87,@9&4@16YT<F%D82(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P-PIM<V=I9"`B3&]W(@IM<V=S
M='(@(D)A:7AO(@H*(SH@;65S<V%G92YP:'`Z,C@S(&UA:6QB;W@N<&AP.C<P
M-B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$S"FUS9VED("),;W<@
M4')I;W)I='DB"FUS9W-T<B`B0F%I>&$@4')I;W)I9&%D92(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P.`IM<V=I9"`B3&]W97-T(@IM
M<V=S='(@(DUA:7,@0F%I>&\B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D
M;W5B;&4N<&AP.C0T"FUS9VED(")-86-I;G1O<V@@1FEL92(*;7-G<W1R(")!
M<G%U:79O($UA8VEN=&]S:"(*"B,Z('-M:6UE+G!H<#HR-30@<&=P+G!H<#HS
M,S(@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"FUS9VED(")-
M86EL(@IM<V=S='(@(D-O<G)E:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.34*;7-G:60@(DUA:6P@4')E=FEE=W,B"FUS9W-T<B`B4')E=FESXV\@
M9&\@0V]R<F5I;R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E
M;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C
M="!T;SHB"FUS9W-T<B`B5&EP;R!D;R!S97)V:61O<B!D92!C;W)R96EO(&5L
M96-T<O-N:6-O(&%O('%U86P@8V]N96-T87(Z(@H*(SH@9F]L9&5R<RYP:'`Z
M,SDW"FUS9VED(")-86EL8F]X(@IM<V=S='(@(D-A:7AA(%!O<W1A;"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DUA:6QB;W@@86YD
M($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1E(%!A
M<W1A<R!E(%9I<W5A;&EZ8>?C;R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C$V"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD
M97(@87,@4V5E;B(*;7-G<W1R(")-87)C87(@5&]D87,@87,@365N<V%G96YS
M(&YA(%!A<W1A($-O;6\@3&ED87,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHQ-PIM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L
M9&5R(&%S(%5N<V5E;B(*;7-G<W1R(")-87)C87(@5&]D87,@87,@365N<V%G
M96YS(&YA(%!A<W1A($-O;6\@4&]R($QE<B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-2!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C,P"FUS9VED(")-87)K(&%S.B(*;7-G<W1R(")-87)C87(@
M8V]M;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0T"FUS9VED(")-
M87)K(&1I9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N
M="!C;VQO<G,_(@IM<V=S='(@(DUA<F-A<B!O<R!D:69E<F5N=&5S(&[M=F5I
M<R!D92!C:71AY^-O(&-O;2!C;W)E<R!D:69E<F5N=&5S/R(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,`IM<V=I9"`B36%R:R!M97-S
M86=E<R!A<R!S965N/R`H24U!4"!O;FQY*2(*;7-G<W1R(")-87)C87(@:6UA
M9V5N<R!C;VUO(&QI9&%S/R`H87!E;F%S($E-05`I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8U,@IM<V=I9"`B36%R:R!S:6UP;&4@;6%R:W5P/R(*
M;7-G<W1R(")-;W-T<F%R(&UA<F-AY_5E<R!S:6UP;&5S/R(*"B,Z('1E;7!L
M871E<R]S96%R8V@O:&5A9&5R+FEN8SHT-@IM<V=I9"`B36%T8V@@06QL(%%U
M97)I97,B"FUS9W-T<B`B4')O8W5R82!4;V1O<R!O<R!#87-O<R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT,@IM<V=I9"`B36%T8V@@06YY
M(%%U97)Y(@IM<V=S='(@(E!R;V-U<F$@475A;'%U97(@0V%S;W,B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#,*;7-G:60@(DUA>&EM
M=6T@071T86-H;65N="!3:7IE(@IM<V=S='(@(E1A;6%N:&\@3>%X:6UO(&1O
M<R!!;F5X;W,B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M.#0*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H
M960N(@IM<V=S='(@(D[Z;65R;R!MX7AI;6\@9&4@86YE>&]S(&%T:6YG:61O
M+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W.0IM<V=I
M9"`B36%X:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@<F5A8VAE9"XB"FUS
M9W-T<B`B5&%M86YH;R!T;W1A;"!MX7AI;6\@9&4@86YE>&]S(&%T:6YG:61O
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C8*;7-G:60@(DUE
M971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@(D-A;F-E;&%M96YT;R!D92!2
M975N:>-O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-0IM<V=I
M9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUAY^-O('-O
M8G)E(%)E=6YIXV\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3@U
M"FUS9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S='(@(E!R;W!O<W1A(&1E
M(%)E=6YIXV\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$W"FUS
M9VED(")-965T:6YG(%)E<&QY(@IM<V=S='(@(E)E<W!O<W1A(&$@4F5U;FGC
M;R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3@*;7-G:60@(DUE
M971I;F<@57!D871E(@IM<V=S='(@(D%C='5A;&EZ8>?C;R!D92!2975N:>-O
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,PIM<V=I9"`B365E
M=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R(")0961I9&\@9&4@06-T=6%L
M:7IAY^-O(&1E(%)E=6YIXV\B"@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S
M+G!H<#HS"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@(DQI<W1A
M(&1E($UE;G5S(&1E(%!A<W1A(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(T-@IM
M<V=I9"`B365S<V%G92(*;7-G<W1R(")-96YS86=E;2(*"B,Z(&-O;7!O<V4N
M<&AP.C4P-R!C;VUP;W-E+G!H<#HU,S0@8V]M<&]S92YP:'`Z-3@X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO
M;B(*;7-G<W1R(")%<V-R:71A(&1E($UE;G-A9V5M(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@X.`IM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@
M(D1A=&$@9&$@365N<V%G96TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDT(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#(*;7-G
M:60@(DUE<W-A9V4@3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&4@365N<V%G
M96YS(@H*(SH@<V5A<F-H+G!H<#HS-3D*;7-G:60@(DUE<W-A9V4@4V5A<F-H
M(@IM<V=S='(@(E!R;V-U<F%R($UE;G-A9V5M(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@Y,@IM<V=I9"`B365S<V%G92!3:7IE(@IM<V=S='(@(E1A
M;6%N:&\@9&$@365N<V%G96TB"@HC.B!M97-S86=E+G!H<#HS-C@*;7-G:60@
M(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(D/S9&EG;RUF;VYT92!D82!-96YS
M86=E;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S
M<V%G92!6:65W:6YG(@IM<V=S='(@(E9I<W5A;&EZ8>?C;R!D82!-96YS86=E
M;2(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHU-0IM<V=I9"`B
M365S<V%G92!F:65L9',B"FUS9W-T<B`B0V%M<&]S(&1A(&UE;G-A9V5M(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-97-S86=E
M(&9L86=S(@IM<V=S='(@(D%T<FEB=71O<R!D82!M96YS86=E;2(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#,*;7-G:60@(DUE<W-A9V4@9F]L
M9&5R<R(*;7-G<W1R(")087-T87,@9&4@;65N<V%G96YS(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R
M;VT@)7,B"FUS9W-T<B`B365N<V%G96T@9&4@)7,B"@HC.B!M86EL8F]X+G!H
M<#HV-#8*;7-G:60@(DUE<W-A9V4@:&%S(&%T=&%C:&UE;G1S(@IM<V=S='(@
M(DUE;G-A9V5M(&-O;2!A;F5X;W,B"@HC.B!M86EL8F]X+G!H<#HV,S<*;7-G
M:60@(DUE<W-A9V4@:7,@96YC<GEP=&5D(@IM<V=S='(@(D$@;65N<V%G96T@
M97-TX2!E;F-R:7!T861A(@H*(SH@;6%I;&)O>"YP:'`Z-C,R"FUS9VED(")-
M97-S86=E(&ES('-I9VYE9"(*;7-G<W1R(")!(&UE;G-A9V5M(&5S=.$@87-S
M:6YA9&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S,*;7-G
M:60@(DUE<W-A9V4@;6%T8VAE<R(*;7-G<W1R(")4:7!O(&1E('!R;V-U<F$B
M"@HC.B!C;VUP;W-E+G!H<#HW-S$@8V]M<&]S92YP:'`Z-S@U"FUS9VED(")-
M97-S86=E(')E9&ER96-T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!(&UE
M;G-A9V5M(&9O:2!R961I<F5C8VEO;F%D82!C;VT@<W5C97-S;RXB"@HC.B!C
M;VUP;W-E+G!H<#HQ,#$X"B,L('!H<"UF;W)M870*;7-G:60@(DUE<W-A9V4@
M<V5N="!S=6-C97-S9G5L;'DL(&)U="!N;W0@<V%V960@=&\@)7,B"FUS9W-T
M<B`B365N<V%G96T@96YV:6%D82!C;VT@<W5C97-S;R!M87,@;N-O(&=U87)D
M861A(&5M("5S(@H*(SH@8V]M<&]S92YP:'`Z,3`W-R!C;VUP;W-E+G!H<#HQ
M,#DR"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M(")-96YS86=E;2!E;G9I861A(&-O;2!S=6-E<W-O+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,3(*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN
M('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@(DUE;G-A9V5N<R!P;W(@<.%G
M:6YA(&YA('9I<W5A;&EZ8>?C;R!D82!C86EX82!P;W-T86PN(@H*(SH@;6%I
M;&)O>"YP:'`Z,S$X"FUS9VED(")-97-S86=E<R!T;R(*;7-G<W1R(")-96YS
M86=E;G,@<&%R82(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I
M9"`B36]D:69Y(@IM<V=S='(@(DUO9&EF:6-A<B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R
M92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S7"(N(@IM
M<V=S='(@(DUA:7,@9&\@<75E('5M(&5N9&5R9>=O(&5N8V]N=')A9&\@8V]M
M(&\@8V%M<&\@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHU,`IM<V=I9"`B36]V92(*;7-G<W1R(")-;W9E<B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-@IM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(D1E<V-E<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHU,`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B36]V97(@<&%R
M82!P87-T82(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC
M.C,Q-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")3=6)I<B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(W"FUS9VED(")-=6QT:7!A
M<G0O86QT97)N871I=F4B"FUS9W-T<B`B375L=&EP87)T92]A;'1E<FYA=&EV
M82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT."!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(T"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-`IM<V=I9"`B3D]412(*;7-G<W1R(").3U1!(@H*(SH@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S@@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8X.`IM<V=I9"`B3F%M92(*;7-G<W1R(").;VUE(@H*(SH@
M<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;B!N;W0@
M8F4@96UP='DB"FUS9W-T<B`B3R!.;VUE(&4O;W4@;R!E;6%I;"!NXV\@<&]D
M96T@<V5R('9A>FEO<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M-S@*;7-G:60@(DYE961S($%C=&EO;B(*;7-G<W1R(")!8^?C;R!.96-E<W/A
M<FEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3<U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-30*
M;7-G:60@(DYE=F5R(@IM<V=S='(@(DYU;F-A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4U,PIM<V=I9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*
M;7-G<W1R(").=6YC82!G=6%R9&%R(&%N97AO<R(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ,C8*;7-G:60@(DYE=R(*;7-G<W1R(").;W9A(@H*(SH@
M;&EB+TE-4"YP:'`Z-C$U"FUS9VED(").97<@1F]L9&5R(@IM<V=S='(@(DYO
M=F$@4&%S=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@
M(DYE=R!-86EL(@IM<V=S='(@(DYO=F$@365N<V%G96TB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$Y"FUS9VED(").97<@;65S<V%G97,B"FUS
M9W-T<B`B365N<V%G96YS(&YO=F%S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B3F5X="(*;7-G<W1R(")0<O-X:6UA
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHS
M,PIM<V=I9"`B3F5X="!-97-S86=E(@IM<V=S='(@(E!R\WAI;6$@365N<V%G
M96TB"@HC.B!M86EL8F]X+G!H<#HS-3(*;7-G:60@(DYE>'0@4&%G92(*;7-G
M<W1R(")0<O-X:6UA(%#A9VEN82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C4S,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30X"FUS9VED
M(").;R(*;7-G<W1R(").XV\B"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED(").
M;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R(")#97)T:69I8V%D;R!NXV\@
M9F]I(&5N8V]N=')A9&\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T
M7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T<B`B4V5M
M($5N8W)I<'1AY^-O(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C@P"FUS
M9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B3N-O(&5X:7-T92!N
M96YH=6UA(&-H879E(@H*(SH@;6%I;&)O>"YP:'`Z,S<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(DYO($UE<W-A9V5S(@IM<V=S='(@(D[C;R!(X2!-96YS86=E
M;G,B"@HC.B!P9W`N<&AP.C$S-PIM<V=I9"`B3F\@4$=0('!U8FQI8R!K97D@
M:6UP;W)T960N(@IM<V=S='(@(D[C;R!F;VD@:6UP;W)T861A(&$@8VAA=F4@
M</IB;&EC82!01U`N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ
M-#`*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC871E(%!R97-E;G0B"FUS
M9W-T<B`B4V5M($-E<G1I9FEC861O(%!E<W-O86P@4')E<V5N=&4B"@HC.B!L
M:6(O36%I;&)O>"YP:'`Z,S(S"FUS9VED(").;R!0<F5V:65W(%1E>'0B"FUS
M9W-T<B`B4V5M(%1E>'1O(&1E(%!R979I<^-O(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B3F\@4'5B;&EC($ME>7,@1F]U;F0B
M"FUS9W-T<B`B3N-O($9O<F%M($5N8V]N=')A9&%S($-H879E<R!0^F)L:6-A
M<R(*"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L:6,@
M:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(").XV\@9F]I(&EM<&]R=&%D82!N96YH
M=6UA(&-H879E('#Z8FQI8V$@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]T;F5F+G!H<#HY,`IM<V=I9"`B3F\@871T86-H;65N=',@9F]U;F0N(@IM
M<V=S='(@(D[C;R!S92!E;F-O;G1R;W4@86YE>&]S+B(*"B,Z(&QI8B]#<GEP
M="]334E-12YP:'`Z,30P"FUS9VED(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L
M;V-A=&5D(&EN('1H92!P=6)L:6,@:V5Y+B(*;7-G<W1R(").XV\@:.$@:6YF
M;W)M8>?C;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(&YA(&-H879E('#Z8FQI
M8V$N(@H*(SH@86-L+G!H<#HW,B!A8VPN<&AP.CDX"FUS9VED(").;R!F;VQD
M97(@<V5L96-T960N(@IM<V=S='(@(D[C;R!F;VD@<V5L96-C:6]N861A(&YE
M;FAU;6$@<&%S=&$N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$S,`IM
M<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA
M:6PN(@IM<V=S='(@(DYE;FAU;6$@<&%S=&$@97-TX2!A('9E<FEF:6-A<B!N
M;W9A<R!M96YS86=E;G,N(@H*(SH@9F]L9&5R<RYP:'`Z,C`W(&QI8B]&;VQD
M97(N<&AP.C0X,"!L:6(O1F]L9&5R+G!H<#HU,S`*;7-G:60@(DYO(&9O;&1E
M<G,@=V5R92!S<&5C:69I960B"FUS9W-T<B`B3F5N:'5M82!P87-T82!F;VD@
M97-P96-I9FEC861A(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$S-@IM
M<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<R(*;7-G<W1R(").
MXV\@:.$@<&%S=&%S(&-O;2!N;W9A<R!M96YS86=E;G,B"@HC.B!L:6(O0FQO
M8VLO<W5M;6%R>2YP:'`Z,3,S"FUS9VED(").;R!F;VQD97)S('=I=&@@=6YS
M965N(&UE<W-A9V5S(@IM<V=S='(@(D[C;R!HX2!P87-T87,@8V]M(&UE;G-A
M9V5N<R!P;W(@;&5R(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(T,`IM<V=I9"`B
M3F\@;65S<V%G92!B;V1Y('1E>'0B"FUS9W-T<B`B365N<V%G96T@<V5M('1E
M>'1O(&YO(&-O<G!O(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,V-0IM<V=I9"`B
M3F\@;65S<V%G97,@;6%T8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`B3F5N
M:'5M82!M96YS86=E;2!C;W)R97-P;VYD92#@('-U82!P<F]C=7)A+B(*"B,Z
M('!G<"YP:'`Z,3@Y"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K
M97D@:6UP;W)T960N(@IM<V=S='(@(D[C;R!F;VD@:6UP;W)T861A(&YE;FAU
M;6$@8VAA=F4@<&5S<V]A;"!P<FEV861A(%!'4"XB"@HC.B!P9W`N<&AP.C$V
M-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N
M(@IM<V=S='(@(D[C;R!F;VD@:6UP;W)T861A(&YE;FAU;6$@8VAA=F4@<&5S
M<V]A;"!P^F)L:6-A(%!'4"XB"@HC.B!S;6EM92YP:'`Z,C`Q"FUS9VED(").
M;R!P97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(*;7-G
M<W1R(").XV\@9F]I(&EM<&]R=&%D;R!N96YH=6T@8V5R=&EF:6-A9&\@<&5S
M<V]A;"!3+TU)344N(@H*(SH@<W!E;&QI;F<N<&AP.C(R,`IM<V=I9"`B3F\@
M<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N(@IM<V=S='(@(E!R
M;V=R86UA(&1E(&-O<G)E8^?C;R!O<G1O9W+A9FEC82!NXV\@9F]I(&-O;F9I
M9W5R861O+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU
M,`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@(DYE;FAU;2!E
M<G)O(&1E(&]R=&]G<F%F:6$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3`V"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G<W1R(")3
M96T@<W5G97-T]65S(@H*(SH@86-L+G!H<#HV."!A8VPN<&AP.CDT"FUS9VED
M(").;R!U<V5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F5N:'5M('5T:6QI>F%D
M;W(@97-P96-I9FEC861O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<P.0IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(D[C;RU087)T
M:6-I<&%N=&4B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Q
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#$*(SH@=&5M
M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S4@=&5M<&QA=&5S+W!R
M969S+W-P86US96QE8W0N:6YC.C(T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV-C0*;7-G:60@(DYO;F4B"FUS9W-T<B`B3F5N:'5M82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P-@IM<V=I9"`B3F]R;6%L
M(@IM<V=S='(@(DYO<FUA;"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS.0IM<V=I
M9"`B3F]T($1E;&5T960B"FUS9W-T<B`B3N-O(%)E;6]V:61A(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C(S"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z-#(*;7-G:60@(DYO="!$<F%F="(*;7-G<W1R(").XV\@
M4F%S8W5N:&\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-PHC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,T"FUS9VED(").;W0@26UP
M;W)T86YT(@IM<V=S='(@(D[C;R!);7!O<G1A;G1E(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T(%!E<G-O;F%L(@IM
M<V=S='(@(D[C;R!097-S;V%L(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z,3,Y
M(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP="]334E-12YP:'`Z
M,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G<W1R(")#
M:&%V92!P^F)L:6-A($EN=N%L:61A+B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-C<*;7-G:60@(DYO="!D96QE=&5D(&UE<W-A9V5S(@IM<V=S
M='(@(DUE;G-A9V5N<R!NXV\@<F5M;W9I9&%S(@H*(SH@=&5M<&QA=&5S+W-E
M87)C:"]M86EN+FEN8SHU,0IM<V=I9"`B3F]T(&EM<&]R=&%N="!M97-S86=E
M<R(*;7-G<W1R(").XV\@<^-O(&UE;G-A9V5N<R!I;7!O<G1A;G1E<R(*"B,Z
M(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-S$*
M;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM92(*;7-G
M<W1R(").;W1E('%U92!I<W1O('!O9&4@9&5M;W)A<B!A;&=U;2!T96UP;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*;7-G:60@(DYU;6)E<B!O
M9B!M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E
M;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(D[Z;65R;R!D92!M97-E<R!D
M=7)A;G1E(&]S('%U86ES(&%N97AO<R!L:6=A9&]S('9E;&AO<R!SXV\@;6%N
M=&ED;W,L('-E('-E("(*(F5S=&EV97(@82!R96UO=NHM;&]S(&UE;G-A;&UE
M;G1E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*;7-G:60@(DYU
M;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE
M=&EN9R!M;VYT:&QY+B(*;7-G<W1R("(B"B).^FUE<F\@9&4@<&%S=&%S(&%N
M=&EG87,@9&4@;65N<V%G96YS(&5N=FEA9&%S(&$@;6%N=&5R+"!S92!S92!E
M<W1I=F5R(&$@(@HB<F5M;W;J+6QA<R!M96YS86QM96YT92XB"@HC.B!T96UP
M;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-"!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-34R"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M,S,*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC
M.C0W"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-#@*;7-G:60@
M(D]2(@IM<V=S='(@(D]5(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHQ-0IM<V=I9"`B3VQD(&UE<W-A9V5S(@IM<V=S='(@(DUE;G-A9V5N<R!A
M;G1I9V%S(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C4R"FUS9VED(")/;&0@<V5N="UM86EL(&9O;&1E
M<G,@8F5I;F<@<'5R9V5D+B(*;7-G<W1R(")!<R!P87-T87,@86YT:6=A<R!D
M92!M96YS86=E;G,@96YV:6%D87,@97-TXV\@82!S97(@<'5R9V%D87,N(@H*
M(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(W"FUS9VED(")/;FQY(&1I<W!L
M87D@9F]L9&5R<R!W:71H('5N<F5A9"!M97-S86=E<R!I;B!T:&5M/R(*;7-G
M<W1R(")-;W-T<F%R(&%P96YA<R!P87-T87,@8V]M(&UE;G-A9V5N<R!P;W(@
M;&5R/R(*"B,Z('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C<Q
M"FUS9VED(")/;FQY(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O
M<B!T:&ES(&%C=&EO;BXB"FUS9W-T<B`B07!E;F%S('-E(&1E=F4@<V5L96-C
M:6]N87(@=6UA('!A<W1A('!A<F$@97-T82!O<&5R8>?C;RXB"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z-R!T96UP;&%T97,O;65N=2YI;F,Z,C<*;7-G:60@
M(D]P95]N($9O;&1E<B(*;7-G<W1R(")!8G)I7W(@4&%S=&$B"@HC.B!T96UP
M;&%T97,O;65N=2YI;F,Z,C,*;7-G:60@(D]P96X@1F]L9&5R(@IM<V=S='(@
M(D%B<FER(%!A<W1A(@H*(SH@9F]L9&5R<RYP:'`Z-#$T"FUS9VED(")/<&5N
M960@1F]L9&5R(@IM<V=S='(@(E!A<W1A($%B97)T82(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,#4*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP
M86YT(@IM<V=S='(@(E!A<G1I8VEP86YT92!/<&-I;VYA;"(*"B,Z(&9E=&-H
M;6%I;"YP:'`Z,S,@=&5M<&QA=&5S+V9E=&-H;6%I;"]T;W`N:6YC.C(*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C8*;7-G:60@(D]T
M:&5R($UA:6P@06-C;W5N=',B"FUS9W-T<B`B3W5T<F%S($-O;G1A<R!D92!#
M;W)R96EO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$X"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30R"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(D]U
M=')A<R!/<.?U97,B"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC
M.C$V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-0HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP
M"FUS9VED(")01U`B"FUS9W-T<B`B4$=0(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8SHW"FUS9VED(")01U`@16YC<GEP="!-97-S
M86=E(@IM<V=S='(@(D5N8W)I<'1A<B!-96YS86=E;2!C;VT@4$=0(@H*(SH@
M8V]M<&]S92YP:'`Z,S,Q"FUS9VED(")01U`@17)R;W(Z("(*;7-G<W1R(")%
M<G)O(&1O(%!'4#H@(@H*(SH@8V]M<&]S92YP:'`Z,S$P"FUS9VED(")01U`@
M17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K
M97DN(@IM<V=S='(@(D5R<F\@9&\@4$=0.B#)(&YE8V5S<^%R:6\@82!F<F%S
M92!C:&%V92!P87)A(&$@8VAA=F4@<&5S<V]A;"!P<FEV861A+B(*"B,Z('1E
M;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED(")01U`@3D]4($%C
M=&EV92(*;7-G<W1R(")01U`@;N-O(&%C=&EV;R(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*;7-G:60@
M(E!'4"!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!01U`B"@HC.B!P9W`N
M<&AP.C,P"FUS9VED(")01U`@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("))
M;G1R;V1UY^-O(&1A(&9R87-E(&-H879E(%!'4"(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!'4"!097)S;VYA;"!+97EP86ER('-U
M<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(D\@<&%R(&1E(&-H879E<R!P97-S;V%I<R!01U`@;F5C97-S:71A(&1E
M('5M82!L:6=AY^-O('=E8B!S96=U<F$N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,3<S"FUS9VED(")01U`@4'5B;&EC($ME>2!497AT(@IM<V=S
M='(@(E1E>'1O(&1A($-H879E(%#Z8FQI8V$@4$=0(@H*(SH@<&=P+G!H<#HQ
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB
M)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(D$@
M0VAA=F4@4/IB;&EC82!01U`@<&%R82!<(B5S7"(@*"5S*2!F;VD@861I8VEO
M;F%D82!C;VT@<W5C97-S;RXB"@HC.B!P9W`N<&AP.C(T-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C
M97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B02!C:&%V92!P^F)L:6-A(%!'
M4"!P87)A(%PB)7-<(B!F;VD@<F5M;W9I9&$@8V]M('-U8V5S<V\N(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")01U`@4'5B;&EC($ME
M>7)I;F<B"FUS9W-T<B`B06YE;"!D92!#:&%V97,@4/IB;&EC87,@4$=0(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHX"FUS9VED
M(")01U`@4VEG;B!-97-S86=E(@IM<V=S='(@(D%S<VEN87(@365N<V%G96T@
M8V]M(%!'4"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI
M;F,Z.0IM<V=I9"`B4$=0(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@
M(D%S<VEN87(O16YC<FEP=&%R($UE;G-A9V5M(&-O;2!01U`B"@HC.B!P9W`N
M<&AP.C(P,@IM<V=I9"`B4$=0('!R:79A=&4@:V5Y('-U8V-E<W-F=6QL>2!A
M9&1E9"XB"FUS9W-T<B`B0VAA=F5S('!R:79A9&$@4$=0(&%D:6-I;VYA9&$@
M8V]M('-U8V5S<V\N(@H*(SH@<&=P+G!H<#HQ-S<*;7-G:60@(E!'4"!P=6)L
M:6,@:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B02!C:&%V97,@
M</IB;&EC82!01U`@9F]I(&%D:6-I;VYA9&$@8V]M('-U8V5S<V\N(@H*(SH@
M=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$Q"FUS9VED(")01U`@<W5P
M<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B3R!S
M=7!O<G1E(&1E(%!'4"!E<W3A(&1E<V%C=&EV861O(&YE<W1E('-I<W1E;6$N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`X"FUS9VED("(B"B)0
M1U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG
M:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*
M;7-G<W1R("(B"B)/('-U<&]R=&4@9&4@4$=0(&[C;R!E<W3A(&%C=&EV;R!D
M92!M;VUE;G1O+"!P;W(@:7-S;R!NXV\@Z2!P;W-S[79E;"`B"B)V97)I9FEC
M87(@82!A<W-I;F%T=7)A(&1I9VET86PN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,CDU"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R
M<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@
M9&5C<GEP=&5D+B(*;7-G<W1R("(B"B)/('-U<&]R=&4@9&4@4$=0(&[C;R!E
M<W3A(&%C=&EV;R!D92!M;VUE;G1O+"!P;W(@:7-S;R!NXV\@Z2!P;W-S[79E
M;"`B"B)D97-E;F-R:7!T87(@82!M96YS86=E;2XB"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,C0*;7-G:60@(B(*(E!'4"!S=7!P;W)T(')E<75I<F5S
M('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I
M<R!C=7)R96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@
M>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E('1H92!01U`@
M(@HB9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DB"FUS9W-T<B`B
M(@HB3R!S=7!O<G1E(&1E(%!'4"!E>&EG92!A('5T:6QI>F'GXV\@9&4@:F%N
M96QA<R!<(G!O<'5P7"(N("!392!O('-E=2`B"B)N879E9V%D;W(@87,@97-T
M:79E<B!A(&)L;W%U96%R+"!D979E<N$@86QT97)A<B!E<W-A(&-O;F9I9W5R
M8>?C;RP@<&]I<R!D92`B"B)O=71R;R!M;V1O(&%S(&9U;F-I;VYA;&ED861E
M<R!D;R!01U`@;N-O('-E(&-O;7!O<G1A<N-O(&-O;6\@9&5S96IA9&\B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G
M<W1R(")03U`S(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G
M:60@(E!/4#,@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B4$]0
M,R`H4')O=&]C;VQO<R!C;VT@075T;RUD971E8^?C;RDB"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G
M<W1R(")03U`S('-O8G)E(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z,3(S"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T
M:69I8V%T92DB"FUS9W-T<B`B4$]0,R!S;V)R92!34TP@*&-E<G1I9FEC861O
M(&%U=&\M87-S:6YA9&\I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ-C8*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G
M<W1R(")03U`S('-O8G)E(%-33"`H875T;RUA<W-I;F%D;RDB"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$Q,0IM<V=I9"`B4$]0,RP@;F\@5$Q3(@IM
M<V=S='(@(E!/4#,L('-E;2!43%,B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@
M)60B"FUS9W-T<B`B4.%G:6YA("5D(&1E("5D(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@W-`IM<V=I9"`B4&%G92!W:71H('1H92!&:7)S="!5;G-E
M96X@365S<V%G92(*;7-G<W1R(")0X6=I;F$@8V]M(&$@4')I;65I<F$@365N
M<V%G96T@4&]R(&QE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-S4*
M;7-G:60@(E!A9V4@=VET:"!T:&4@3&%S="!5;G-E96X@365S<V%G92(*;7-G
M<W1R(")0X6=I;F$@8V]M(&$@VFQT:6UA($UE;G-A9V5M('!O<B!,97(B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R
M="AS*2(*;7-G<W1R(")087)T92AS*2(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR,3$*;7-G:60@(E!A<W-P:')A<V4B"FUS9W-T<B`B1G)A<V4@8VAA
M=F4B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$V"FUS9VED(")087-S
M<&AR87-E("A!9V%I;BDB"FUS9W-T<B`B1G)A<V4@8VAA=F4@*&YO=F%M96YT
M92DB"@HC.B!S;6EM92YP:'`Z,C,U('!G<"YP:'`Z,S$P"FUS9VED(")087-S
M<&AR87-E('-U8V-E<W-F=6QL>2!U;FQO861E9"XB"FUS9W-T<B`B02!F<F%S
M92!C:&%V92!F;VD@9&5S8V%R<F5G861A(&-O;2!S=6-E<W-O+B(*"B,Z('1E
M;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ.2!T96UP;&%T97,O<&=P
M+W!A<W-P:')A<V4N:6YC.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R
M(")&<F%S92!C:&%V93HB"@HC.B!P9W`N<&AP.C$Q,@IM<V=I9"`B4&%S<W!H
M<F%S97,@8V%N(&YO="!B92!E;7!T>2(*;7-G<W1R(")!(&9R87-E(&-H879E
M(&[C;R!P;V1E('-E<B!V87II82(*"B,Z('!G<"YP:'`Z,3$T"FUS9VED(")0
M87-S<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B07,@9G)A<V5S(&-H
M879E(&[C;R!C;VEN8VED96TB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z,C`@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C8Y
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3DS"FUS9VED(")087-S
M=V]R9"(*;7-G<W1R(")086QA=G)A+7!A<W-E(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C0X"FUS9VED(")097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D5X96-U=&%R(&%S
M(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%Q=6%N9&\@9&$@96YT<F%D83\B
M"@HC.B!A8VPN<&AP.C<V(&%C;"YP:'`Z,3`R"FUS9VED(")097)M:7-S:6]N
M<R!F;W(@=&AI<R!U<V5R(&-A;B!N;W0@8F4@8VAA;F=E9"XB"FUS9W-T<B`B
M07,@<&5R;6ES<_5E<R!D97-T92!U=&EL:7IA9&]R(&[C;R!P;V1E;2!S97(@
M86QT97)A9&%S+B(*"B,Z(&UE<W-A9V4N<&AP.C0W-R!M86EL8F]X+G!H<#HV
M.#(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T
M97,O;6%I;&)O>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G
M<W1R(")097-S;V%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS
M9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUAY_5E
M<R!097-S;V%I<R(*"B,Z('!G<"YP:'`Z,3(P"FUS9VED(")097)S;VYA;"!0
M1U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")0
M87(@9&4@8VAA=F5S('!E<W-O86ES(%!'4"!G97)A9&%S(&-O;2!S=6-E<W-O
M(@H*(SH@<&=P+G!H<#HQ,C<*;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES(&1E
M;&5T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")#:&%V97,@<&5S<V]A:7,@
M4$=0(')E;6]V:61A<R!C;VT@<W5C97-S;RXB"@HC.B!S;6EM92YP:'`Z,C`W
M"FUS9VED(")097)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O
M<G1E9#H@(@IM<V=S='(@(D-E<G1I9FEC861O<R!3+TU)344@<&5S<V]A:7,@
M3L-/(&EM<&]R=&%D;W,B"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S
M;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B0VAA=F5S('!E<W-O86ES(%,O34E-12!R96UO=FED87,@8V]M('-U8V5S
M<V\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-`IM<V=I9"`B4&QA
M8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S
M/R(*;7-G<W1R(")#;VQO8V%R(&$@<W5A(&%S<VEN871U<F$@86YT97,@9&4@
M<F5S<&]S=&%S(&]U(')E96YC86UI;FAA;65N=&]S/R(*"B,Z(&-O;7!O<V4N
M<&AP.C(R-PIM<V=I9"`B4&QA:6YT97AT(%9E<G-I;VX@;V8@365S<V%G92(*
M;7-G<W1R(")697)SXV\@9&$@365N<V%G96T@96T@5&5X=&\@4VEM<&QE<R(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L
M871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(E!O
M<B!F879O<BP@:6YT<F]D=7IA(&\@;F]M92!D82!N;W9A('!A<W1A.B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.CDT('1E;7!L871E
M<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.CDV"FUS9VED(")0;&5A<V4@96YT
M97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(E!O<B!F
M879O<BP@:6YT<F]D=7IA(&\@;F]M92!D82!N;W9A('!A<W1A.B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C$R.0IM<V=I9"`B4&QE
M87-E(&5N=&5R('1H92!N97<@;F%M93HB"FUS9W-T<B`B4&]R(&9A=F]R+"!I
M;G1R;V1U>F$@;R!N;W9O(&YO;64Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S
M<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@
M96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R:79A=&4@:V5Y
M+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB96YT97(@=&AI<R!P87-S<&AR
M87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*(E!O<B!F879O
M<B!I;G1R;V1U>F$@82!F<F%S92UC:&%V92!D82!S=6$@8VAA=F4@<')I=F%D
M82!01U`N($%P96YA<R!P<F5C:7-A("(*(F1E(&EN=')O9'5Z:7(@97-T82!F
M<F%S92!C:&%V92!U;6$@=F5Z('!O<B!S97-SXV\@)7,@;F\@24U0+B(*"B,Z
M('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R
M('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@
M(@HB=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I
M;VXN(@IM<V=S='(@(B(*(E!O<B!F879O<B!I;G1R;V1U>F$@82!F<F%S92UC
M:&%V92!D82!S=6$@8VAA=F4@<')I=F%D82!3+TU)344N($%P96YA<R`B"B)P
M<F5C:7-A(&1E(&EN=')O9'5Z:7(@97-T82!F<F%S92!C:&%V92!U;6$@=F5Z
M('!O<B!S97-SXV\@)7,@;F\@24U0+B(*"B,Z(')E8V]M<&]S92YP:'`Z.3<*
M;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O;7!O
M<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*(F-O
M;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O<'5P
M('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN(&EN
M('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P(&%T
M=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N(%=E
M(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@(B(*
M(E!O<B!F879O<B!E;G1R92!D92!N;W9O('!A<F$@<F5C;VUEYV%R(&$@8V]M
M<&]S:>?C;R!D82!S=6$@;65N<V%G96TN(%-E($[#3R`B"B)E<W1I=F5R(&$@
M=7-A<B!<(F-O;VMI97-<(B!E(&5S=&EV97(@82!C;VUP;W(@96T@:F%N96QA
M<R!D92!<(G!O<'5P7"(L('1E<N$@(@HB=&%M8NEM(&1E(&5N=')A<B!D92!N
M;W9O(&YA(&IA;F5L82!P<FEN8VEP86PN($ES=&\@<V5R=F4@<&%R82!I;7!E
M9&ER("(*(F%T86-A;G1E<R!D92!S97%U97-T<F%R(&\@240@9&$@<W5A('-E
M<W/C;RX@4&5D:6UO<R!D97-C=6QP82!P;W(@<75A;'%U97(@(@HB:6YC;VYV
M96YI96YT92XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R"FUS
M9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D+B(*;7-G<W1R(")0
M;W(@9F%V;W(@:6YT<F]D=7IA(&$@<W5A('!A;&%V<F$M<&%S<V4N(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV.`IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B4&]R(&9A=F]R(&EN=')O
M9'5Z82!O('-E=2!N;VUE(&1E('5T:6QI>F%D;W(N(@H*(SH@8V]M<&]S92YP
M:'`Z-SD@;&EB+TE-4"YP:'`Z-3`Y"FUS9VED(")0;&5A<V4@<F5S;VQV92!A
M;6)I9W5O=7,@;W(@:6YV86QI9"!A9&1R97-S97,N(@IM<V=S='(@(E!O<B!F
M879O<B!R97-O;'9A(&]S(&5N9&5R9>=O<R!A;6+M9W5O<R!O=2!I;G;A;&ED
M;W,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8T,@IM<V=I9"`B
M(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A
M;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*(FUE;G4@8F5L
M;W<N(@IM<V=S='(@(B(*(E!O<B!F879O<B!R979E:F$@82!I;F9O<FUAY^-O
M('%U92!S92!S96=U92!E(&1E<&]I<R!D96QE8V-I;VYE('5M82!A8^?C;R!D
M;R`B"B)M96YU(&%B86EX;RXB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]J879A
M<V-R:7!T+FEN8SHU,PIM<V=I9"`B4&QE87-E('-E;&5C="!A(&9O;&1E<B!B
M969O<F4@>6]U('!E<F9O<FT@86YY(&%C=&EO;G,N(@IM<V=S='(@(E!O<B!F
M879O<BP@<V5L96-C:6]N92!U;6$@<&%S=&$@86YT97,@9&4@969E8W1U87(@
M<75A;'%U97(@;W!E<F'GXV\N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4P,@IM<V=I9"`B4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T
M:&4@;65N=2!B96QO=RXB"FUS9W-T<B`B4&]R(&9A=F]R('-E;&5C8VEO;F4@
M=6UA(&%CY^-O(&1O(&UE;G4@86)A:7AO+B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@870@
M;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(E!O<B!F879O
M<BP@<V5L96-C:6]N92!P96QO(&UE;F]S('5M82!P87-T82!P87)A(&5F96-T
M=6%R(&$@<&5S<75I<V$N(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:F%V87-C
M<FEP="YI;F,Z-`IM<V=I9"`B4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD
M97(@9F]R('1H:7,@;W!E<F%T:6]N+B(*;7-G<W1R(")0;W(@9F%V;W(L('-E
M;&5C8VEO;F4@87!E;F%S('5M82!P87-T82!P87)A(&5F96-T=6%R(&5S=&$@
M;W!E<F'GXV\N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C<V"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T
M;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E!O<B!F879O<B!S96QE8V-I;VYE(&]U
M(&5D:71E(&$@8V%I>&$@X"!P<O-X:6UA.B(*"B,Z(&-O;F9I9R]M;W1D+G!H
M<"YD:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S='(@(D)A
M<V5A9&\@96T@2&]R9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`V
M"FUS9VED(")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G
M+2T@)RD_(@IM<V=S='(@(E!R96-E9&5R(&$@<W5A(&%S<VEN871U<F$@8V]M
M(&1O:7,@:.UF96YS("@G+2T@)RD_(@H*(SH@<VUI;64N<&AP.C(T,2!P9W`N
M<&AP.C(U-R!F:6QT97)P<F5F<RYP:'`Z-#`*;7-G:60@(E!R969E<F5N8V5S
M('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R(")!<R!P<F5F97+J;F-I
M87,@9F]R86T@86QT97)A9&%S(&-O;2!S=6-E<W-O+B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")0<F5V:65W(@IM
M<V=S='(@(E!R979I<^-O(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7VYA=FEG871E+FEN8SHR.`IM<V=I9"`B4')E=FEO=7,@365S<V%G92(*;7-G
M<W1R(")-96YS86=E;2!!;G1E<FEO<B(*"B,Z(&UA:6QB;W@N<&AP.C,T,PIM
M<V=I9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R(")0X6=I;F$@06YT97)I;W(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S$*
M;7-G:60@(E!R:6YT(@IM<V=S='(@(DEM<')I;6ER(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*;7-G:60@(E!R:6]R:71Y(@IM<V=S
M='(@(E!R:6]R:61A9&4B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z-S0*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@
M(E!A;&%V<F$M<&%S<V4@9&$@0VAA=F4@4')I=F%D82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-3(*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N
M(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R(")0
M97)G=6YT87(@<V5M<')E('%U92!U;2!A;F5X;R!F;W(@96YV:6%D;SL@;R!V
M86QO<B!P;W(@;VUI<W/C;R#I($[#3R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-3$*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE
M;G0@:7,@<V5N=#L@9&5F875L="!T;R!915,B"FUS9W-T<B`B4&5R9W5N=&%R
M('-E;7!R92!Q=64@=6T@86YE>&\@9F]R(&5N=FEA9&\[(&\@=F%L;W(@<&]R
M(&]M:7-SXV\@Z2!324TB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,3`*;7-G:60@(E!R;W1O8V]L.B(*;7-G<W1R(")0<F]T;V-O;&\Z
M(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0
M(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R
M(")/('-U<&]R=&4@<&%R82!S97)V:61O<F5S(&1E(&-H879E<R!01U`@</IB
M;&EC87,@9F]I(&1E<V%C=&EV861O+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L
M971E9"YI;F,Z.`IM<V=I9"`B4'5R7V=E($1E;&5T960B"FUS9W-T<B`B16QI
M;6EN87(@4F5M;U]V:61A<R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C,V('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI
M;F,Z.`IM<V=I9"`B4'5R9V4@1&5L971E9"(*;7-G<W1R(")%;&EM:6YA<B!2
M96UO=FED87,B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR
M,@IM<V=I9"`B4'5R9V4@1F]L9&5R*',I(@IM<V=S='(@(E)E;6]V97(@4&%S
M=&$H<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")0
M=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(D9R97%UZFYC:6$@9&%S
M('!U<F=A<R!D82!P87-T82!D92!,:7AO.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3D*;7-G:60@(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O
M;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@
M(E!U<F=A<B!M96YS86=E;G,@9&$@<&%S=&$@9&4@3&EX;R!C;VT@;6%I<R!D
M;R!Q=64@97-T92!N^FUE<F\@9&4@9&EA<RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@P"FUS9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE
M(%1R87-H(&9O;&1E<C\B"FUS9W-T<B`B4'5R9V%R(&UE;G-A9V5N<R!A;G1I
M9V%S(&1A('!A<W1A(&1E($QI>&\_(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<'5R9V5?=')A<V@N<&AP.C8V"B,L('!H<"UF;W)M870*;7-G:60@(E!U
M<F=I;F<@)60@;65S<V%G97,@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@
M(E!U<F=A;F1O("5D(&UE;G-A9V5M*&YS*2!D82!P87-T82!D92!,:7AO+B(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HV-`IM
M<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N(@IM
M<V=S='(@(E!U<F=A;F1O(#$@;65N<V%G96T@9&$@<&%S=&$@9&4@3&EX;RXB
M"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C$W"B,L('!H<"UF;W)M
M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR
M9B4E*2(*;7-G<W1R(")%<W1A9&\@9&$@<75O=&$Z("4N,F9-0B`O("4N,F9-
M0B`@*"4N,F8E)2DB"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@
M3D\@3$E-250B"FUS9W-T<B`B17-T861O(&1A('%U;W1A.B`E+C)F34(@+R!3
M14T@3$E-251%(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM
M<V=S='(@(D5S=&%D;R!D82!Q=6]T83H@4T5-($Q)34E412(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O
M=&EN9R`E9CHB"FUS9W-T<B`B0VET86YD;R`E9CHB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS-S<*;7-G:60@(E)E7W%U97-T($1E;&EV
M97)Y($-O;F9I<FUA=&EO;B(*;7-G<W1R(")095]D:7(@079I<V\@9&4@4F5C
M97#GXV\B"@HC.B!S96%R8V@N<&AP.C$V,PIM<V=I9"`B4F5C96EV960@3VXB
M"FUS9W-T<B`B4F5C96)I9&$@16TB"@HC.B!S96%R8V@N<&AP.C$W,0IM<V=I
M9"`B4F5C96EV960@4VEN8V4B"FUS9W-T<B`B4F5C96)I9&$@1&5S9&4B"@HC
M.B!S96%R8V@N<&AP.C$V-PIM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T
M<B`B4F5C96)I9&$@073I(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B4F5D
M:7)E7V-C:6]N87(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(E)E9&ER96-C
M:6]N87(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$U
M"FUS9VED(")2961I<F5C="!-97-S86=E(@IM<V=S='(@(E)E9&ER96-C:6]N
M87(@365N<V%G96TB"@HC.B!C;VUP;W-E+G!H<#HW,S0*;7-G:60@(E)E9&ER
M96-T('1H:7,@;65S<V%G92(*;7-G<W1R(")2961I<F5C8VEO;F%R(&5S=&$@
M;65N<V%G96TB"@HC.B!C;VUP;W-E+G!H<#HW.30*;7-G:60@(E)E9&ER96-T
M:6YG(&9A:6QE9"XB"FUS9W-T<B`B4F5D:7)E8V-I;VYA;65N=&\@9F%L:&]U
M+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W,PIM<V=I
M9"`B4F5F<F5S:"(*;7-G<W1R(")2969R97-C87(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S8P"FUS9VED(")2969R97-H($9O;&1E<B!6:65W<SHB
M"FUS9W-T<B`B06-T=6%L:7IA<B!6:7-U86QI>F'GXV\@9&4@4&%S=&%S.B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHT"FUS9VED(")296QO860B"FUS9W-T<B`B4F5C
M87)R96=A<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.C,*;7-G
M:60@(E)E;&]A9"!6:65W(@IM<V=S='(@(E)E8V%R<F5G87(@5FES=6%L:7IA
MY^-O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R-B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-30U"FUS9VED(")296UE;6)E<B!T:&4@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("),96UB<F%R(&$@:6YF;W)M
M8>?C;R!L:79R92]O8W5P861O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-3`*;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I97<B"FUS9W-T<B`B
M3&5M8G)A<B!A(/IL=&EM82!V:7-U86QI>F'GXV\B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T92!-86EL8F]X
M.B(*;7-G<W1R(")#86EX82!0;W-T86P@4F5M;W1A.B(*"B,Z('1E;7!L871E
M<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I96QD($9R
M;VT@4V5A<F-H(@IM<V=S='(@(E)E;6]V97(@0V%M<&\@9&$@4')O8W5R82(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0IM<V=I
M9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R(")296UO=F5R(&9O;G1E(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B4F5N86UE
M($9O;&1E<BAS*2(*;7-G<W1R(")296YO;65A<B!087-T82AS*2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*;7-G:60@(E)E;F%M92!S96YT+6UA
M:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B4F5N
M;VUE87(@82!P87-T82!D92!M96YS86=E;G,@96YV:6%D87,@;F\@:6[M8VEO
M(&1E(&-A9&$@;>IS/R(*"B,Z(&QI8B]&;VQD97(N<&AP.C0T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296YA;6EN9R!<(B5S7"(@=&\@7"(E<UPB(&9A:6QE
M9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")!(')E
M;F]M96'GXV\@9&4@7"(E<UPB('!A<F$@7"(E<UPB(&9A;&AO=2X@3R!S97)V
M:61O<B!D:7-S92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI<W0B"FUS9W-T<B`B4F5S
M7W!O;F1E<B!P87)A(&$@3&ES=&$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z,3$Q"FUS9VED(")297!L86-E('=I=&@Z(@IM<V=S='(@
M(E-U8G-T:71U:7(@<&]R.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L>2(*;7-G<W1R(")297-P;VYD
M97(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$Q(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HT,#D*;7-G:60@(E)E<&QY(%-E;G0N(@IM<V=S
M='(@(E)E<W!O<W1A($5N=FEA9&$N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!!;&PB"FUS
M9W-T<B`B4F5S<&]N9&5R(%]A(%1O9&]S(@H*(SH@8V]M<&]S92YP:'`Z-C@P
M"FUS9VED(")297!L>2!T;R!!;&PZ(@IM<V=S='(@(E)E<W!O;F1E<B!A(%1O
M9&]S.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHQ,`IM<V=I9"`B4F5P;'D@=&\@3&ES="(*;7-G<W1R(")297-P;VYD97(@
M<&%R82!A($QI<W1A(@H*(SH@8V]M<&]S92YP:'`Z-C@R"FUS9VED(")297!L
M>2!T;R!,:7-T.B(*;7-G<W1R(")297-P;VYD97(@<&%R82!A($QI<W1A.B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM
M<V=I9"`B4F5P;'D@=&\@7T%L;"(*;7-G<W1R(")297-P;VYD97(@82!?5&]D
M;W,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(X(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,S<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4T-PIM<V=I9"`B4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A
M9V4B"FUS9W-T<B`B4F5S<&]N9&5R(&-O;2!-96YS86=E;2!.XV\@4W5P;W)T
M861A(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-0IM<V=I9"`B
M4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S
M='(@(E)E<W!O;F1E<B!C;VT@;&EV<F4O;V-U<&%D;R!P87)A(&]S('!R\WAI
M;6]S(#(@;65S97,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S
M-`IM<V=I9"`B4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R(")297-P;VYD97(@8V]M(&$@:6YF;W)M8>?C;R!L
M:79R92]O8W5P861O(&QI=G)E+B(*"B,Z(&UE<W-A9V4N<&AP.C(U,0IM<V=I
M9"`B4F5P;'DM5&\B"FUS9W-T<B`B4F5S<&]N9&5R(%!A<F$B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,C4Y(&QI8B]#;VUP;W-E+G!H<#HS,3$*;7-G:60@(E)E
M<&QY+51O.B`B"FUS9W-T<B`B4F5S<&]N9&5R(%!A<F$Z("(*"B,Z(&-O;7!O
M<V4N<&AP.C8W.`IM<V=I9"`B4F5P;'DZ(@IM<V=S='(@(E)E<W!O;F1E<CHB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S8@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C8*;7-G:60@(E)E<&]R
M="!A<R!);FYO8V5N="(*;7-G<W1R(")297!O<G1A<B!C;VUO($[C;R!3<&%M
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(T"FUS9VED(")297!O
M<G0@87,@4W!A;2(*;7-G<W1R(")297!O<G1A<B!C;VUO(%-P86TB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-S0*;7-G:60@(E)E<75E
M<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(E!E9&ER($%V:7-O(&1E(%],
M96ET=7)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W.`IM<V=I9"`B
M4F5Q=65S="!D96QI=F5R>2!C;VYF:7)M871I;VX_(@IM<V=S='(@(E!E9&ER
M(&-O;F9I<FUAY^-O(&1E(&5N=')E9V$_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4V-@IM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G
M<W1R(")3;VQI8VET87(@<F5C:6)O<R!D92!L96ET=7)A/R(*"B,Z(&UA:6QB
M;W@N<&AP.C(P-`IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD
M+B(*;7-G<W1R(")-96YS86=E;2!P961I9&$@;N-O(&5N8V]N=')A9&$N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-PIM<V=I9"`B4F5Q=6ER
M960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B4&%R=&EC:7!A;G1E($EN9&ES<&5N
M<^%V96PB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$U.`IM<V=I9"`B4F5S970B"FUS9W-T<B`B3&EM<&%R(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-0IM<V=I9"`B4F5S<&]N9&5N
M="!3=&%T=7,@57!D871E9"XB"FUS9W-T<B`B17-T861O(&1O(%)E<W!O;F1E
M;G1E($%C='5A;&EZ861O(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C(X"FUS9VED(")297-U;64B"FUS9W-T<B`B0V]N=&EN
M=6%R(@H*(SH@<F5C;VUP;W-E+G!H<#HY.`IM<V=I9"`B4F5S=6UE('EO=7(@
M<V5S<VEO;B(*;7-G<W1R(")296-O;67G87(@82!S97-SXV\B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C,Q('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,@IM<V=I9"`B4F5T=7)N('1O($9E
M=&-H($UA:6PB"FUS9W-T<B`B5F]L=&%R(&%O($1E<V-A<G)E9V%M96YT;R!D
M92!#;W)R96EO(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C<P
M('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,3,*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHQ-3@@=&5M<&QA=&5S+W-M:6UE+VYO=&%C
M=&EV92YI;F,Z,S,*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(V."!T96UP
M;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,S,*(SH@=&5M<&QA=&5S+V%C;"]A
M8VPN:6YC.C$U.2!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Y"FUS9VED(")2
M971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")6;VQT87(@X',@3W#G]65S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q-`IM<V=I9"`B(@HB4F5T=7)N
M('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN
M9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*(E9O;'1A<B#@
M(&QI<W1A9V5M(&1E(&-A:7AA<R!P;W-T86ES(&1E<&]I<R!D92!R96UO=F5R
M+"!M;W9E<B!O=2!C;W!I87(@=6UA("(*(FUE;G-A9V5M/R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@(E)O;&4B"FUS9W-T<B`B
M4F5G<F$B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$S,2!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C(R-@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C0P.`IM<V=I9"`B4R]-24U%(@IM<V=S='(@(E,O34E-12(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3(*;7-G
M:60@(E,O34E-12!%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B16YC<FEP=&%R
M($UE;G-A9V5M(&-O;2!3+TU)344B"@HC.B!C;VUP;W-E+G!H<#HS-C<*;7-G
M:60@(E,O34E-12!%<G)O<CH@(@IM<V=S='(@(D5R<F\@9&\@4R]-24U%.B`B
M"@HC.B!C;VUP;W-E+G!H<#HS-#8*;7-G:60@(E,O34E-12!%<G)O<CH@3F5E
M9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T
M<B`B17)R;R!D;R!3+TU)344Z($YE8V5S<^%R:6$@9G)A<V4M8VAA=F4@<&%R
M82!A(&-H879E('!E<W-O86P@<')I=F%D82XB"@HC.B!T96UP;&%T97,O<VUI
M;64O;F]T86-T:79E+FEN8SHV"FUS9VED(")3+TU)344@3D]4($%C=&EV92(*
M;7-G<W1R(")3+TU)344@3L-/($%C=&EV;R(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED
M(")3+TU)344@3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&4@4R]-24U%(@H*
M(SH@<VUI;64N<&AP.C0Y"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U
M="(*;7-G<W1R("));G1R;V1UY^-O(&1A(&9R87-E+6-H879E(%,O34E-12(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`P"FUS9VED(")3+TU)
M344@4&5R<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")/('-U<&]R=&4@82!087)E<R!D
M92!#:&%V97,@4&5S<V]A:7,@4R]-24U%(&5X:6IE('5M82!L:6=AY^-O('-E
M9W5R82XB"@HC.B!S;6EM92YP:'`Z,30P"B,L('!H<"UF;W)M870*;7-G:60@
M(E,O34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!D96QE=&5D+B(*;7-G<W1R(")!($-H879E(%#Z8FQI8V$@4R]-24U%(&1E
M(%PB)7-<(B!F;VD@<F5M;W9I9&$@8V]M('-U8V5S<V\N(@H*(SH@<VUI;64N
M<&AP.C$V,@IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY
M(&%D9&5D+B(*;7-G<W1R(")#:&%V92!0^F)L:6-A(%,O34E-12!A9&EC:6]N
M861A(&-O;2!S=6-E<W-O+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-#4*;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")!
M;F5L(&1E($-H879E<R!0^F)L:6-A<R!3+TU)344B"@HC.B!S;6EM92YP:'`Z
M,C$Q"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I<B!S=6-C
M97-S9G5L;'D@861D960N(@IM<V=S='(@(E!A<B!D92!#:&%V97,@4/IB;&EC
M82]0<FEV861A(%,O34E-12!A9&EC:6]N861O(&-O;2!S=6-E<W-O+B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*;7-G:60@
M(E,O34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B07-S:6YA<B!-96YS86=E
M;2!C;VT@4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L
M:7-T+FEN8SHQ-`IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E
M(@IM<V=S='(@(D%S<VEN87(O16YC<FEP=&%R($UE;G-A9V5M(&-O;2!3+TU)
M344B"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,0IM<V=I
M9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN
M(@IM<V=S='(@(D\@<W5P;W)T92!D92!3+TU)344@97-TX2!D97-A8W1I=F%D
M;R!N97-T92!S:7-T96UA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,C,P"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*
M(F1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB3R!S=7!O<G1E(&1E(%,O34E-12!N
MXV\@97-TX2!A8W1I=F\@9&4@;6]M96YT;RP@<&]R(&ES<V\@;N-O(.D@<&]S
M<^UV96P@(@HB9&5S96YC<FEP=&%R(&$@;65N<V%G96TN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HQ-C(*;7-G:60@(B(*(E,O34E-12!S=7!P
M;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I
M9VYE9"!M97-S86=E(&-A;B!N;W0@(@HB8F4@9&ES<&QA>65D+B(*;7-G<W1R
M("(B"B)/('-U<&]R=&4@9&4@4R]-24U%(&[C;R!E<W3A(&%C=&EV;RP@<&]R
M(&ES<V\@;N-O(.D@<&]S<^UV96P@;6]S=')A<B!O("(*(F-O;G1E^F1O(&1E
M<W1A(&UE;G-A9V5M(&%S<VEN861A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,3,U"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@
M96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O
M(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)/('-U<&]R=&4@9&4@4R]-
M24U%(&[C;R!E<W3A(&%C=&EV;RP@<&]R(&ES<V\@;N-O(.D@<&]S<^UV96P@
M=F5R:69I8V%R(&$@(@HB87-S:6YA='5R82!D:6=I=&%L+B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,C0*;7-G:60@(B(*(E,O34E-12!S=7!P
M;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO
M=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P
M=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E
M;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R
M96-T;'DB"FUS9W-T<B`B(@HB3R!S=7!O<G1E(&1E(%,O34E-12!E>&EG92!A
M('5T:6QI>F'GXV\@9&4@:F%N96QA<R!<(G!O<'5P7"(N("!392!O('-E=2`B
M"B)N879E9V%D;W(@87,@97-T:79E<B!A(&)L;W%U96%R+"!D979E<N$@86QT
M97)A<B!E<W-A(&-O;F9I9W5R8>?C;RP@<&]I<R!D92`B"B)O=71R;R!M;V1O
M(&%S(&9U;F-I;VYA;&ED861E<R!D;R!01U`@;N-O('-E(&-O;7!O<G1A<N-O
M(&-O;6\@9&5S96IA9&\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR-C8*;7-G:60@(E-?=6)J96-T(@IM<V=S='(@(D%?<W-U;G1O(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S4T"FUS9VED(")3
M85]V92!A(&-O<'D@:6X@(@IM<V=S='(@(D=U87)D87(@=6UA($/S<&EA(&5M
M("(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS
M,`IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B1W5A<E]D87(@8V]M;R(*"B,Z
M('-E87)C:"YP:'`Z,S8S('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHV-PIM<V=I9"`B4V%V92(*;7-G<W1R(")'<F%V87(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,C@*;7-G:60@(E-A=F4@071T86-H
M;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_(@IM<V=S
M='(@(D=U87)D87(@06YE>&]S(&-O;2!A(&UE;G-A9V5M(&YA('!A<W1A(&1E
M(&UE;G-A9V5N<R!E;G9I861A<S\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHV."!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M,C0*;7-G:60@(E-A=F4@1')A9G0B"FUS9W-T<B`B1W5A<F1A<B!287-C=6YH
M;R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHV.2!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C,W"B,Z('1E;7!L871E<R]S;6EM92]N;W1A
M8W1I=F4N:6YC.C(S('1E;7!L871E<R]P9W`O<&=P+FEN8SHV-`HC.B!T96UP
M;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,C,*;7-G:60@(E-A=F4@3W!T:6]N
M<R(*;7-G<W1R(")'=6%R9&%R($]PY_5E<R(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C8X('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0R-`IM<V=I9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B1W5A<F1A<B!?
M4F%S8W5N:&\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S`*;7-G:60@(E-A=F4@87,B"FUS9W-T<B`B1W5A<F1A<B!C;VUO
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,PIM<V=I9"`B4V%V92!D
M<F%F=',@87,@=6YS965N/R(*;7-G<W1R(")'=6%R9&%R(')A<V-U;FAO<R!C
M;VUO('!O<B!L97(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,S`*
M;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D
M969A=6QT(&%D9')E<W,@8F]O:S\B"FUS9W-T<B`B(@HB1W5A<F1A<B!D97-T
M:6YA=.%R:6]S(&%U=&]M871I8V%M96YT92!N;R!L:79R;R!D92!E;F1E<F7G
M;W,@<&]R(&]M:7-SXV\_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHQ,C<*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_
M(@IM<V=S='(@(D=U87)D87(@<')O8W5R82!C;VUO('!A<W1A('9I<G1U86P_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,PIM<V=I9"`B4V%V92!S
M96YT(&UA:6P_(@IM<V=S='(@(D=U87)D87(@;65N<V%G96YS(&5N=FEA9&%S
M/R(*"B,Z(&-O;7!O<V4N<&AP.C$Q-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("5S(@IM<V=S='(@(D\@<F%S8W5N:&\@;N-O(&9O:2!G<F%V
M861O+B!/('-E<G9I9&]R(&1I<W-E.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z-3`*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")0<F]C=7)A<B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:&5A9&5R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N
M:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:"`E<R(*;7-G<W1R
M(")0<F]C=7)A<B`E<R(*"B,Z('-E87)C:"YP:'`Z,S$V"FUS9VED(")396%R
M8V@@4F5S=6QT<R(*;7-G<W1R(")297-U;'1A9&]S(&1A(%!R;V-U<F$B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$T('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E96XB"FUS9W-T<B`B3&ED
M82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z.0IM<V=I9"`B
M4V5L96-T(@IM<V=S='(@(E-E;&5C8VEO;F%R(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C<P"FUS9VED(")396QE8W0@06YO=&AE<B!!
M8V-O=6YT(@IM<V=S='(@(E-E;&5C8VEO;F4@3W5T<F$@0V]N=&$B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@(E-E;&5C="!A
M(&1A=&4B"FUS9W-T<B`B4V5L96-C:6]N92!U;6$@9&%T82(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHQ,`IM<V=I9"`B4V5L96-T(&$@9FEE
M;&0B"FUS9W-T<B`B4V5L96-C:6]N92!U;2!C86UP;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E-E;&5C="!A9&1R97-S(&)O;VL@
M<V]U<F-E<R!F;W(@861D:6YG(&%N9"!S96%R8VAI;F<@9F]R(&%D9')E<W-E
M<RXB"FUS9W-T<B`B(@HB4V5L96-C:6]N87(@;W,@;&EV<F]S(&1E(&5N9&5R
M9>=O<R!O;F1E('-E(&%D:6-I;VYA<N-O(&4@<')O8W5R87+C;R`B"B)E;F1E
M<F7G;W,N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R(")396QE8V-I;VYA<B!T=61O(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(S"FUS9VED(")3
M96QE8W0@86QL(&9I96QD<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D
M<F5S<V5S+B(*;7-G<W1R(")396QE8V-I;VYE('1O9&]S(&]S(&-A;7!O<R!A
M('!R;V-U<F%R('%U86YD;R!E>'!A;F1I;F1O(&5N9&5R9>=O<RXB"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR,0IM<V=I
M9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B4V5L96-C:6]N92!U;6$@
M8V]N=&$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@Y"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R(")396QE8V-I;VYA<B!N96YH=6UA(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8SHR,0IM
M<V=I9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E(@IM<V=S='(@(E-E
M;&5C8VEO;F4@;R!T:7!O(&1O('-E<G9I9&]R(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S`Y"FUS9VED(")396QE8W1E9"!!9&1R
M97-S(&)O;VMS.B(*;7-G<W1R("),:79R;W,@9&4@16YD97)EYV]S('-E;&5C
M8VEO;F%D;W,Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T-PIM<V=I
M9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R(")%;G9I
M87(@0VAA=F4@<&%R82!O(%-E<G9I9&]R(&1E($-H879E<R!0^F)L:6-A<R(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,#0*;7-G:60@(E-E;F0@
M3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(D5N=FEA<B#:;'1I;6$@26YF
M;W)M8>?C;R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8V
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R,@IM<V=I9"`B4V5N
M9"!-97-S86=E(@IM<V=S='(@(D5N=FEA<B!-96YS86=E;2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV.3@*;7-G:60@(E-E;F0@<F5A9"!R96-E:7!T
M('=H96X@<F5Q=65S=&5D(&)Y('1H92!S96YD97(_(@IM<V=S='(@(D5N=FEA
M<B!A=FES;R!D92!L96ET=7)A('%U86YD;R!F;W(@<F5Q=65R:61O/R(*"B,Z
M(&9O;&1E<G,N<&AP.C,Y,@IM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G
M<W1R(")087-T82!D92!M96YS86=E;G,@96YV:6%D87,B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C,Y"FUS9VED(")396YT(&UA
M:6P@9F]L9&5R.B(*;7-G<W1R(")087-T82!D92!M96YS86=E;G,@96YV:6%D
M87,Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S(@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-#4*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ-3(*;7-G:60@(E-E<G9E<B(*;7-G<W1R(")397)V:61O<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PIM<V=I9"`B4V5R=F5R(&%N
M9"!&;VQD97(@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M8>?C;R!S;V)R
M92!397)V:61O<F5S(&4@4&%S=&%S(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C(S"FUS9VED(")397)V97(Z(@IM<V=S='(@(E-E<G9I
M9&]R.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,`IM<V=I9"`B4V5T
M('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A
M;F0@9&5L971E(&UE<W-A9V5S+B(*;7-G<W1R("(B"B)!:G5S=&%R('!R969E
M<NIN8VEA<R!A8V5R8V$@9&\@<75E(&%C;VYT96-E('%U86YD;R!M;W9E(&]U
M(')E;6]V92!M96YS86=E;G,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4R,@IM<V=I9"`B4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O
M;7!O<VEN9R!M97-S86=E<S\B"FUS9W-T<B`B0V]L;V-A<B!O(&-A8F7G86QH
M;R!8+5!R:6]R:61A9&4@86\@8V]M<&]R(&%S(&UE;G-A9V5N<S\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*;7-G:60@(E-H87)E($9O;&1E<G,B
M"FUS9W-T<B`B4&%R=&EL:&%R(%!A<W1A<R(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHX-@IM<V=I9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@
M(E!A<G1I;&AA<B!P87-T87,@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M
M86EL(&9O;&1E<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`B4&%R=&EL
M:&%R('!A<W1A<R!D92!C;W)R96EO(&5L96-T<O-N:6-O(&-O;2!O=71R;W,@
M=71I;&EZ861O<F5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C,*
M;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@
M8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T
M;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B
M(@HB1W)E;F1E<R!B;&]C;W,@9&4@=&5X=&\@8VET861O(&1E=F5M('-E<B!M
M;W-T<F%D;W,@;W4@;V-U;'1A9&]S('!O<B!O;6ES<^-O/R`B"B)!('-U82!E
M<V-O;&AA('!O9&4@<V5R(&%L=&5R861A(&9A8VEL;65N=&4N(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C4R"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@
M;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T
M83\B"FUS9W-T<B`B(@HB3R!C;W)P;R!D92!M96YS86=E;G,@9&4@7")T97AT
M+W!L86EN7"(@9&5V92!S97(@<&5R8V]R<FED;R!P<F]C=7)A;F1O(&1A9&]S
M("(*(E!'4#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`U"FUS9VED
M(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S
M879I;F<@82!D<F%F=#\B"FUS9W-T<B`B(@HB02!J86YE;&$@9&4@8V]M<&]S
M:>?C;R!D979E('-E<B!F96-H861A(&1E<&]I<R!D92!G=6%R9&%R('5M(')A
M<V-U;FAO/T$@(@HB:F%N96QA(&1E(&5S8W)I=&$@9&4@;65N<V%G96T@9&5V
M97+A('-E<B!F96-H861A(&%P\W,@82!G<F%V8>?C;R!D;R!R87-C=6YH;S\B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-#`*;7-G:60@(E-H;W5L9"!Y
M;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O('EO=7(@;65S
M<V%G97,@8GD@9&5F875L=#\B"FUS9W-T<B`B(@HB475E<B!Q=64@82!S=6$@
M8VAA=F4@</IB;&EC82!01U`@<V5J82!A;F5X861A(.%S('-U87,@;65N<V%G
M96YS('!O<B!O;6ES<^-O/R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z.3(*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`B36]S=')A
M<B!4;V1A<R!A<R!087-T87,B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D
M97)S+FEN8SHV-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R(")-
M;W-T<F%R(%1O9&]S(&]S($-A8F7G86QH;W,B"@HC.B!M86EL8F]X+G!H<#HS
M-C$*;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R(")-;W-T<F%R(%)E;6]V
M:61A<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS
M9VED(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R(")-;W-T<F%R($-A
M8F7G86QH;W,@3&EM:71A9&]S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A
M9&5R<RYI;F,Z-S`*;7-G:60@(E-H;W<@36%I;&EN9R!,:7-T($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DUO<W1R87(@26YF;W)M8>?U97,@9&4@3&ES=&$@9&4@
M0V]R<F5I;R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G
M:60@(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`B36]S
M=')A<B!!<&5N87,@4&%S=&%S(%-U8G-C<FET87,B"@HC.B!F;VQD97)S+G!H
M<#HR.#<*;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D(@IM<V=S='(@(DUO<W1R
M87(@3N-O(%-U8G-C<FET87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C`S"FUS9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P:6YG(&]F
M(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(DUO<W1R87(@
M=6T@[6-O;F4@<&%R82!P97)M:71I<B!L:6)E<G1A<B!M96YS86=E;G,@9&]S
M('-E=7,@86YE>&]S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S0*
M;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I97<_(@IM<V=S
M='(@(DUO<W1R87(@;&5G96YD82!N82!V:7-U86QI>F'GXV\@9&$@8V%I>&$@
M<&]S=&%L/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#D*;7-G:60@
M(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G
M<W1R(")-;W-T<F%R('!R979I<_5E<R!A<&5N87,@9&%S(&UE;G-A9V5N<R!P
M;W(@;&5R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3<*;7-G:60@
M(E-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_(@IM<V=S='(@(DUO<W1R87(@
M<')E=FES]65S(&-O;6\@86YO=&'G]65S("A<(G1O;VQT:7!S7"(I/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#@*;7-G:60@(E-H;W<@=&AE($9E
M=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B36]S=')A
M<B!O(.UC;VYE("=$97-C87)R96=A<B<@;F$@8F%R<F$@9&\@;65N=3\B"@HC
M.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`X"FUS9VED(")3:&]W('1H
M92!);6%G97,B"FUS9W-T<B`B36]S=')A<B!A<R!);6%G96YS(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C8Q"FUS9VED(")3:&]W('1H92!F
M:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B36]S=')A<B!O
M(.UC;VYE(&1E(&9I;'1R86=E;2!N82!B87)R82!D;R!M96YU/R(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HS,`IM<V=I9"`B4VAO=R!T;W1A;"!N=6UB
M97(@;V8@;6%I;',@:6X@9F]L9&5R/R(*;7-G<W1R(")-;W-T<F%R(&[Z;65R
M;R!T;W1A;"!D92!M96YS86=E;G,@;F$@<&%S=&$_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8V,`IM<V=I9"`B4VAO=VXB"FUS9W-T<B`B36]S=')A
M9&$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C0R"FUS9VED(")3:5]Z92(*;7-G<W1R(")?5&%M86YH;R(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C$S"FUS9VED(")3:6=N('5P(&EF(&YO
M="!R96=I<W1E<F5D(@IM<V=S='(@(E-U8G-C<F5V82P@<V4@86EN9&$@;N-O
M(&5S=.$@<F5G:7-T861O(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHQ-PIM<V=I9"`B4VEG;F5D(@IM<V=S='(@(D%S<VEN861A(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*;7-G:60@(E-I
M>F4B"FUS9W-T<B`B5&%M86YH;R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z.#$*;7-G:60@(E-O<G0@1&ER96-T:6]N(@IM
M<V=S='(@(D1I<F5CY^-O(&1E($]R9&5N8>?C;R(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3$*;7-G:60@(E-O<G0@8GD@
M07)R:79A;"(*;7-G<W1R(")/<F1E;F%R('!O<B!#:&5G861A(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B
M4V]R="!B>2!$871E(@IM<V=S='(@(D]R9&5N8>?C;R!P;W(@1&%T82(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C8*;7-G
M:60@(E-O<G0@8GD@1G)O;2!!9&1R97-S(@IM<V=S='(@(D]R9&5N87(@<&]R
M($5N9&5R9>=O(&1E($]R:6=E;2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z-#$*;7-G:60@(E-O<G0@8GD@365S<V%G92!3
M:7IE(@IM<V=S='(@(D]R9&5N87(@<&5L;R!486UA;FAO(&1A($UE;G-A9V5M
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS
M-@IM<V=I9"`B4V]R="!B>2!3=6)J96-T(@IM<V=S='(@(D]R9&5N87(@<&]R
M($%S<W5N=&\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C,Q"FUS9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R(")/<F1E
M;F%R('!O<B!#;VYV97)S82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,C$*;7-G:60@(E-O<G0@8GD@5&\@061D<F5S<R(*
M;7-G<W1R(")/<F1E;F%R('!E;&\@1&5S=&EN873A<FEO(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S"FUS9VED(")3<&%M(&9O;&1E
M<CHB"FUS9W-T<B`B4&%S=&$@9&4@7")3<&%M7"(Z(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,W"FUS9VED(")3<&5C:6%L($-H87)A
M8W1E<G,B"FUS9W-T<B`B0V%R86-T97)E<R!%<W!E8VEA:7,B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,S0*;7-G:60@(E-P96QL($-H
M96-K(@IM<V=S='(@(E9E<FEF:6-A<B!/<G1O9W)A9FEA(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(")3<&5L;"!#:&5C
M:V5R(@IM<V=S='(@(D-O<G)E8W1O<B!/<G1O9W+A9FEC;R(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU,"!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z-3@*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E
M(@IM<V=S='(@(E9E<FEF:6-AY^-O(&]R=&]G<N%F:6-A(&-O;7!L971A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V,@IM<V=I9"`B4W!E;&QI;F<@
M97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T
M<B`B17)R;W,@9&4@;W)T;V=R869I82!P;W(@96-RXR!Q=6%N=&\@=F5R:69I
M8V%N9&\N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q,B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C4R"FUS9VED(")3=&%R="(*;7-G<W1R
M(")#;VUEYV%R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(D5S=&%D;R(*"B,Z(&QI8B]-24U%+T-O
M;G1E;G1S+G!H<#HR,#(*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T
M<B`B1&5S8V%R=&%R($%N97AO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@P,0IM<V=I9"`B4W1R:7`@;&EN96)R96%K<S\B"FUS9W-T<B`B16QI;6EN
M87(@9FEN<RUD92UL:6YH83\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C,W"FUS9VED(")3=6)?:F5C="(*;7-G<W1R(")!
M7W-S=6YT;R(*"B,Z(&UE<W-A9V4N<&AP.C(U,B!S96%R8V@N<&AP.C$U,2!T
M96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(U"FUS9VED(")3=6)J
M96-T(@IM<V=S='(@(D%S<W5N=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#DQ"FUS9VED(")3=6)J96-T($9I96QD(@IM<V=S='(@(D-A;7!O(&1E
M($%S<W5N=&\B"@HC.B!S96%R8V@N<&AP.C,V-2!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,C$*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E
M+FEN8SHS,0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E-U8FUE=&5R(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B4W5B<V-R
M:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R(")3=6)S8W)E=F5R(%!A<W1A*',I
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-CD@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,S@Y"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C@W"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U8V5S<V\B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.3(*;7-G:60@(E-U9V=E
M<W1I;VYS(@IM<V=S='(@(E-U9V5S=/5E<R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-C(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM
M<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")3=6WA<FEO(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,SDQ('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,Y-`IM<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N($UE=&AO
M9"(*;7-G<W1R(")4<F]C87(@3>ET;V1O(&1E($-O;7!O<VGGXV\B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.34*;7-G:60@(E-W:71C
M:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(E1R;V-A<B!P87)A($-O
M;7!O<VGGXV\@2%1-3"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,Y-0IM<V=I9"`B4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I
M;VXB"FUS9W-T<B`B5')O8V%R('!A<F$@0V]M<&]S:>?C;R!E;2!497AT;R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Q,`IM<V=I9"`B
M5&5?>'0B"FUS9W-T<B`B5&5?>'1O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C(V.0IM<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B5&5N=&%T
M:79A.B`B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DQ"FUS9VED
M(")496YT871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")!8V5I=&%R
M('!E9&ED;R!T96YT871I=F%M96YT92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S
M='(@(D%C96ET92!496YT871I=F%M96YT92(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O
M;F8N<&AP(@IM<V=S='(@(D\@9FEC:&5I<F\@9&4@5&5R;6]S(&1O(%-E<G9I
MYV\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@96T@8V]N9BYP:'`B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(U"FUS9VED(")4:&4@1G)O;3H@8V]L=6UN
M(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK960Z(@IM<V=S='(@(D$@
M8V]L=6YA($1E.B!D979E<FEA('-E<B!L:6=A9&$Z(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0IM<V=I9"`B5&AE($UA8VEN=&]S
M:"!R97-O=7)C92!F;W)K(@IM<V=S='(@(D\@7")-86-I;G1O<V@@<F5S;W5R
M8V4@9F]R:UPB(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H
M<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U
M<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(D\@7")-
M86-I;G1O<V@@<F5S;W5R8V4@9F]R:UPB('!O9&4@<V5R(&1E<V-A<G)E9V%D
M;R`E<RXB"@HC(&,M9F]R;6%T"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B02!C;VYT82!<(B5S7"(@9F]I(')E;6]V
M:61A+B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HW-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(D$@8V]N=&$@7"(E<UPB(&9O:2!G=6%R9&%D82XB"@HC.B!L:6(O
M1FEL=&5R+G!H<#HY-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@861D<F5S
M<R!<(B5S7"(@:&%S(&)E96X@861D960@=&\@)7,N(@IM<V=S='(@(D\@96YD
M97)EYV\@7"(E<UPB(&9O:2!A9&EC:6]N861O(&$@)7,N(@H*(SH@871T86-H
M;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT('=A<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(D\@86YE>&\@;N-O(&9O:2!E;F-O;G1R861O+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.0IM<V=I9"`B5&AE(&-A;&5N
M9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R(")/<R!D861O<R!D92!C86QE
M;F3A<FEO('/C;R!I;G;A;&ED;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S
M92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E
M="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS
M9W-T<B`B(@HB02!J86YE;&$@9&4@8V]M<&]S:>?C;R!NXV\@</1D92!S97(@
M86)E<G1A+B!486QV97H@=&5N:&$@8V]N9FEG=7)A9&\@;R!S974@(@HB;F%V
M96=A9&]R('!A<F$@8FQO<75E87(@:F%N96QA<R!D92!<(G!O<'5P7"(_(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,@IM<V=I9"`B
M5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A<F4@8F5L;W<N
M(@IM<V=S='(@(D\@8V]N=&7Z9&\@9&\@87)Q=6EV;R!-86-I;G1O<V@@96YC
M;VYT<F$M<V4@86)A:7AO+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E
M;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HY,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB('=I;&P@8F4@<F5N
M86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(D$H<RD@<&%S=&$H<RD@8V]R<F5N
M=&4H<RD@7"(E<UPB('-E<N$HXV\I(')E;F]M96%D82AS*2!P87)A(%PB)7-<
M(BXB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3$R"FUS9VED("(B"B)4
M:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@
M9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960B"FUS9W-T<B`B(@HB02!L
M:7-T82!C;W)R96YT92!D92!U=&EL:7IA9&]R97,@8V]M(&%C97-S;R!A(&5S
M=&$@<&%S=&$@;N-O('#T9&4@<V5R("(*(F5N8V]N=')A9&$N(@H*(SH@8V]M
M<&]S92YP:'`Z,3$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9')A9G0@
M:&%S(&)E96X@<V%V960@=&\@=&AE(%PB)7-<(B!F;VQD97(N(@IM<V=S='(@
M(D\@<F%S8W5N:&\@9F]I(&=U87)D861O(&YA('!A<W1A(%PB)7-<(BXB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3,Y"FUS9VED(")4:&4@979E
M;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(D\@979E
M;G1O(&9O:2!A9&EC:6]N861O(&%O('-E=2!C86QE;F3A<FEO+B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*;7-G
M<W1R(")/(&-A;7!O(%PB)7-<(B!NXV\@<&]D92!S97(@97AP86YD:61O+B(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C,R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9F]L9&5R(%PB)7-<(B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(")!('!A
M<W1A(%PB)7-<(B!JX2!E>&ES=&4B"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N
M=&%I;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@
M8V%U<V4@(@HB<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3R!N;VUE(&1A('!A<W1A(%PB)7-<
M(B!C;VYTZ6T@8V%R86-T97)E<R!I;G;A;&ED;W,@92!P;V1E(&-A=7-A<B!P
M<F]B;&5M87,N("(*(D5N=')E(&5M(&-O;G1A8W1O(&-O;2!O(&%D;6EN:7-T
M<F%D;W(@9&\@<VES=&5M82XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS-#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&-R96%T
M960@8G5T('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+B(*;7-G<W1R
M(")!('!A<W1A(%PB)7-<(B!F;VD@8W)I861A(&UA<R!NXV\@97-TX2!N82!S
M=6$@;&ES=&$@9&4@<W5B<V-R:71A<RXB"@HC.B!L:6(O1F]L9&5R+G!H<#HR
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I
M="XB"FUS9W-T<B`B02!P87-T82!<(B5S7"(@9F]I(')E;6]V:61A(&UA<R!C
M;VYT:6YU82!N82!S=6$@;&ES=&$@9&4@<W5B<V-R:71A<RXB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(D$@<&%S=&$@7"(E<UPB(&[C;R!F;VD@8W)I
M861A+B!/('-E<G9I9&]R(&1I<W-E(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N
M;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G
M<W1R(")!('!A<W1A(%PB)7-<(B!NXV\@9F]I(')E;6]V:61A+B!%:7,@;R!Q
M=64@;R!S97)V:61O<B!D:7-S92(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C
M8V5S<V9U;&QY(&-R96%T960N(@IM<V=S='(@(D$@<&%S=&$@(%PB)7-<(B!F
M;VD@8W)I861A(&-O;2!S=6-E<W-O+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(X
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@
M<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@(D$@<&%S=&$@7"(E<UPB
M(&9O:2!R96UO=FED82!C;VT@<W5C97-S;RXB"@HC.B!L:6(O1F]L9&5R+G!H
M<#HT,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@
M=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B
M02!P87-T82!<(B5S7"(@9F]I(')E;F]M96%D82!P87)A(%PB)7-<(B!C;VT@
M<W5C97-S;RXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G
M:60@(E1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES
M('!A<G0Z(@IM<V=S='(@(D]S('-E9W5I;G1E<R!A<G%U:79O<R!F;W)A;2!A
M;F5X861O<R!A(&5S=&$@<&%R=&4Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT
M;6PN<&AP.CDV"FUS9VED("(B"B)4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA
M>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@(@HB
M861D<F5S<V)O;VLN(@IM<V=S='(@(B(*(D%S(&EM86=E;G,@<V5RXV\@;6]S
M=')A9&%S+"!P;VES(&\@<F5M971E;G1E(&-O;G-T82!N;R!S974@;&EV<F\@
M9&4@(@HB96YD97)EYV]S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C<U"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F
M;VQL;W=I;F<@97)R;W(@;65S<V%G93HB"FUS9W-T<B`B3R!S97)V:61O<B!D
M92!C;W)R96EO(&5L96-T<O-N:6-O(&=E<F]U(&$@<V5G=6EN=&4@;65N<V%G
M96T@9&4@97)R;SHB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N
M+G!H<#HU,0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`B(@HB
M3R!S97)V:61O<B!D92!C;W)R96EO(&5L96-T<O-N:6-O(&=E<F]U(&$@<V5G
M=6EN=&4@;65N<V%G96T@:6YF;W)M871I=F$Z(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE
M<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E.B(*;7-G<W1R(")/('-E<G9I
M9&]R(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@9V5R;W4@82!S96=U:6YT92!M
M96YS86=E;3HB"@HC.B!L:6(O365S<V%G92YP:'`Z-C$T"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM
M<V=S='(@(D$@8V%I>&$@<&]S=&%L("5S(&5S=.$@:N$@=F%Z:6$N(@H*(SH@
M;&EB+T9E=&-H;6%I;"YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B`H)60@8GET97,I(&5X8V5E
M9',@9F5T8V@@<VEZ92!L:6UI="XB"FUS9W-T<B`B(@HB02!M96YS86=E;2!<
M(B5S7"(@9&4@7"(E<UPB("@E9"!B>71E*2!E>&-E9&4@;R!T86UA;FAO(&WA
M>&EM;R!D92`B"B)D97-C87)R96=A;65N=&\N(@H*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,#,*;7-G:60@(E1H92!M97-S86=E(&)E
M:6YG(&-O;7!O<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T
M<B`B02!M96YS86=E;2!E;2!C;VUP;W-IY^-O(&9O:2!F96-H861A+B!38>UN
M9&\N(@H*(SH@;65S<V%G92YP:'`Z,30R"FUS9VED(")4:&4@;65S<V%G92!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!(&UE;G-A9V5M(&9O:2!R96UO
M=FED82XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3,*;7-G:60@
M(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G<W1R(")!(&UE
M;G-A9V5M(&9O:2!V97)I9FEC861A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E
M(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R(")!(&UE
M;G-A9V5M(&9O:2!V97)I9FEC861A+B!296UE=&5N=&4Z("5S+B(*"B,Z('1E
M;7!L871E<R]S;6EM92]O<&5N7W-M:6UE7W=I;BYJ<SHQ,"!T96UP;&%T97,O
M<&=P+V]P96Y?<&=P7W=I;BYJ<SHQ,`IM<V=I9"`B(@HB5&AE('!A<W-P:')A
M<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S
M970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O=W,_(@IM
M<V=S='(@(B(*(D$@:F%N96QA(&1A('!A;&%V<F$M<&%S<V4@;N-O('#T9&4@
M<V5R(&%B97)T82X@5&%L=F5Z('1E;FAA(&-O;F9I9W5R861O(&\@(@HB<V5U
M(&YA=F5G861O<B!P87)A(&)L;W%U96%R(&IA;F5L87,@9&4@7")P;W!U<%PB
M/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0=6)L:6,@2V5Y
M(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(D\@=&5X=&\@8W)U(&1A($-H
M879E(%#Z8FQI8V$@4$=0('!O9&4@<V5R('9I<W1O("5S+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F
M:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N
M(@IM<V=S='(@(D\@87)Q=6EV;R!P961I9&\@;N-O(&5X:7-T92!N;R!A;F5X
M;R!-4RU43D5&+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"FUS
M9VED(")4:&4@<F5Q=65S=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE
M(%II<"!A='1A8VAM96YT+B(*;7-G<W1R(")/(&%R<75I=F\@<&5D:61O(&[C
M;R!E>&ES=&4@;F\@86YE>&\@6FEP+B(*"B,Z(&UE<W-A9V4N<&AP.C4S,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<V5N9&5R(&]F('1H:7,@;65S
M<V%G92!I<R!R97%U97-T:6YG(&$@365S<V%G92!$:7-P;W-I=&EO;B!.;W1I
M9FEC871I;VX@(@HB9G)O;2!Y;W4@=VAE;B!Y;W4@:&%V92!R96%D('1H:7,@
M;65S<V%G92X@4&QE87-E(&-L:6-K("5S('1O('-E;F0@=&AE("(*(FYO=&EF
M:6-A=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"B)/(')E;65N=&5N=&4@9&5S
M=&$@;65N<V%G96T@<&5D92!U;6$@3F]T:69I8V'GXV\@9&4@1&ES<&]S:>?C
M;R!D92!-96YS86=E;2`B"B)Q=6%N9&\@;&5R(&5S=&$@;65N<V%G96TN(%!O
M<B!F879O<B!C87)R96=U92!E;2`E<R!P87)A(&5N=FEA<B!A(&UE;G-A9V5M
M(&1E("(*(FYO=&EF:6-AY^-O+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C8Y"FUS9VED(")4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C
M<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B3R!S
M97)V:61O<B!NXV\@</1D92!C<FEA<B!A(&UI;FEA='5R82!D97-T82!I;6%G
M96TN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#0*;7-G
M:60@(E1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G
M<W1R(")!(&%S<VEN871U<F$@;N-O('#T9&4@<V5R('-U8G-T:71U[61A+B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`R"FUS9VED(")4
M:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N(@IM<V=S
M='(@(D$@87-S:6YA='5R82!F;VD@<W5B<W1I='7M9&$@8V]M('-U8V5S<V\N
M(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@
M9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3R!A<G%U:79O(&5S<&5C
M:69I8V%D;R!NXV\@97AI<W1E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-CD*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO
M=7(@=&%S:VQI<W0N(@IM<V=S='(@(D$@=&%R969A(&9O:2!A9&EC:6]N861A
M(.`@<W5A(&QI<W1A(&1E('1A<F5F87,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z.34*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E
M(@IM<V=S='(@(D\@=&5X=&\@9&$@;65N<V%G96TB"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M(")/('1E>'1O(&1A(&UE;G-A9V5M('!O9&4@<V5R('9I<W1O("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R(")/('1E>'1O(&1A
M(&UE;G-A9V5M(&1E=F]L=FED82(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H
M92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@
M(D\@=&5X=&\@9&$@;65N<V%G96T@9&5V;VQV:61A('!O9&4@<V5R('9I<W1O
M("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@
M(D\@=&5X=&\@9&$@;65N<V%G96T@96YV:6%D82(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E
M<RXB"FUS9W-T<B`B3R!T97AT;R!D82!M96YS86=E;2!E;G9I861A('!O9&4@
M<V5R('9I<W1O("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M-30*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A
M<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(D$@:6YF;W)M8>?C;R!L
M:79R92]O8W5P861O(&1O('5T:6QI>F%D;W(@9F]I(&%R<75I=F%D82!C;VT@
M<W5C97-S;RXB"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP
M.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3N-O(&CA('!A
M<G1E<R!A;'1E<FYA=&EV87,@<75E('!O<W-A;2!S97(@;6]S=')A9&%S(&5M
M+6QI;FAA+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V5M<'1Y7VUA:6QB;W@N
M:6YC.C,*;7-G:60@(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA
M:6QB;W@N(@IM<V=S='(@(D[C;R!HX2!M96YS86=E;G,@;F5S=&$@8V%I>&$@
M<&]S=&%L+B(*"B,Z('1H<F5A9"YP:'`Z-CD*;7-G:60@(E1H97)E(&ES(&YO
M('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B
M3N-O(&CA('%U86QQ=65R('1E>'1O('%U92!P;W-S82!S97(@;6]S=')A9&\@
M96TM;&EN:&$N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4W-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")/8V]R<F5U
M('5M('!R;V)L96UA(')E;6]V96YD;R`E<RX@3R!S97)V:61O<B!D:7-S92(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H
M92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B3V-O<G)E=2!U;2!P<F]B;&5M
M82!R96UO=F5N9&\@82!C86EX82!P;W-T86PN($\@<V5R=FED;W(@9&ES<V4Z
M("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4X-`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B3V-O<G)E=2!U;2!P<F]B;&5M
M82!R96UO=F5N9&\@82!C86EX82!P;W-T86PN($\@<V5R=FED;W(@9&ES<V4B
M"@HC.B!L:6(O365S<V%G92YP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&-O<'EI;F<@;65S<V%G97,@9G)O;2!<
M(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S
M86ED(@IM<V=S='(@(B(*(D]C;W)R974@=6T@97)R;R!C;W!I86YD;R!M96YS
M86=E;G,@9&4@7"(E<UPB('!A<F$@7"(E<UPB+B!/('-E<G9I9&]R(&1I<W-E
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(P,"!L:6(O365S<V%G92YP:'`Z,C$U
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!D
M96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES
M(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(B(*(D]C;W)R
M974@=6T@97)R;R!A;R!R96UO=F5R(&UE;G-A9V5N<R!D82!P87-T82!<(B5S
M7"(N($5I<R!O('%U92!O('-E<G9I9&]R("(*(F1I<W-E(@H*(SH@;&EB+TUE
M<W-A9V4N<&AP.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<
M(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T
M<B`B(@HB3V-O<G)E=2!U;2!E<G)O(&%O(')E;6]V97(@;65N<V%G96YS(&1A
M('!A<W1A(%PB)7-<(BX@16ES(&\@<75E(&\@<V5R=FED;W(@(@HB9&ES<V4B
M"@HC.B!L:6(O365S<V%G92YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B3V-O<G)E=2!U
M;2!E<G)O(&%O(')E;6]V97(@;65N<V%G96YS+B!%:7,@;R!Q=64@;R!S97)V
M:61O<B!D:7-S93H@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(D]C;W)R974@=6T@97)R
M;R!A;R!R96UO=F5R(&\@979E;G1O.B`E<RXB"@HC.B!L:6(O34E-12]6:65W
M97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E<B]E;G)I8VAE9"YP:'`Z
M,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!A;R!M;W-T
M<F%R(&5S=&$@<&%R=&4@9&$@;65N<V%G96TB"@HC.B!L:6(O365S<V%G92YP
M:'`Z-3`X(&QI8B]-97-S86=E+G!H<#HU-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN
M('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E
M<B!S86ED(@IM<V=S='(@(B(*(D]C;W)R974@=6T@97)R;R!A;R!M87)C87(@
M87,@;65N<V%G96YS(&1A('!A<W1A(%PB)7-<(BX@16ES(&\@<75E(&\@<V5R
M=FED;W(@(@HB9&ES<V4B"@HC.B!F;VQD97)S+G!H<#HQ-34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RXB
M"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O(&EM<&]R=&%R("5S+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z
M("5S+B(*;7-G<W1R(")/8V]R<F5U('5M(&5R<F\@86\@:6UP;W)T87(@;R!E
M=F5N=&\Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-C8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!A
M;R!I;7!O<G1A<B!A('1A<F5F83H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I
M;VXZ("5S+B(*;7-G<W1R("(B"B)/8V]R<F5U('5M(&5R<F\@86\@:6UP;W)T
M87(@82!I;F9O<FUAY^-O(&QI=G)E+V]C=7!A9&\@9&\@=71I;&EZ861O<CH@
M)7,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@9G)O
M;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E
M<B!S86ED(@IM<V=S='(@(B(*(D]C;W)R974@=6T@97)R;R!A;R!M;W9E<B!A
M<R!M96YS86=E;G,@9&4@7"(E<UPB('!A<F$@7"(E<UPB+B!%:7,@;R!Q=64@
M;R`B"B)S97)V:61O<B!D:7-S92(*"B,Z(&-O;7!O<V4N<&AP.C$Q-SD*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E(&%S
M(&$@9')A9G0N(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!A;R!G=6%R9&%R
M(&5S=&$@;65N<V%G96T@8V]M;R!U;2!R87-C=6YH;RXB"@HC.B!C;VUP;W-E
M+G!H<#HY-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R(")/8V]R<F5U
M('5M(&5R<F\@86\@96YV:6%R(&$@<W5A(&UE;G-A9V5M.B`E<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N
M(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!A;R!A8W1U86QI>F%R(&\@979E
M;G1O.B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4Y"FUS
M9VED(")4:&5R92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R="(*
M;7-G<W1R(").XV\@:&%V:6$@=&5X=&\@;F5S=&$@<&%R=&4@9&$@;65N<V%G
M96TB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.30*;7-G:60@(E1H
M:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM
M<V=S='(@(D5S=&$@;65N<V%G96T@2%1-3"!T96T@:6UA9V5N<R!E;6)E8FED
M87,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP"FUS9VED("(B
M"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET
M+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T
M<B`B(@HB17-T82!M96YS86=E;2!(5$U,('1E;2!I;6%G96YS(&5M8F5B:61A
M<RX@26UA9V5N<R!B;&]Q=65A9&%S(&%P87)E8V5M(&-O;2`B"B)E<W1E(&%S
M<&5C=&\Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-@IM<V=I
M9"`B5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE
M<W-A9V4N(@IM<V=S='(@(D5S=&$@8VAA=F4@</IB;&EC82!01U`@9F]I(&%N
M97AA9&$@X"!M96YS86=E;2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3`T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3@*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$T,R!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,34W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S,@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C,Q-`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B17-T82!A8^?C;R!NXV\@Z2!S=7!O
M<G1A9&$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W.2!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-#$Y"FUS9VED(")4:&ES(&%C=&EO;B!I
M<R!N;W0@>65T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")%<W1A(&%CY^-O(&%I
M;F1A(&[C;R!E<W3A(&EM<&QE;65N=&%D82XB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]J879A<V-R:7!T+FEN8SHV"FUS9VED(")4:&ES(&UA>2!T86ME('-O
M;64@=&EM92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O;G1I;G5E/R(*
M;7-G<W1R("))<W1O('!O9&4@;&5V87(@86QG=6T@=&5M<&\N(%1E;2!C97)T
M97IA('%U92!D97-E:F$@8V]N=&EN=6%R/R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT
M86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R(")%<W1A(&UE;G-A9V5M
M(&-O;G3I;2!U;2!F:6-H96ER;R!-86-I;G1O<V@N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HS.3D*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C
M;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY
M('-I9VYE9"!V:6$@4R\B"B)-24U%+B(*;7-G<W1R("(B"B)%<W1A(&UE;G-A
M9V5M(&-O;G3I;2!U;2!A;F5X;R!Q=64@9F]I(&%S<VEN861O(&1I9VET86QM
M96YT92!V:6$@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#`S"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H
M;65N="!T:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G
M<W1R("(B"B)%<W1A(&UE;G-A9V5M(&-O;G3I;2!U;2!A;F5X;R!Q=64@9F]I
M(&5N8W)I<'1A9&\@9&EG:71A;&UE;G1E('9I82!3+TU)344N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B"B)4:&ES(&UE
M<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M871I
M;VXL(&)U="!T:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G92!I<R!U;FMN
M;W=N+B(*;7-G<W1R("(B"B)%<W1A(&UE;G-A9V5M(&-O;G3I;2!I;F9O<FUA
MY^-O(&1E(&5S=&%D;R!D92!E;G1R96=A(&1O(&-O<G)E:6\L(&UA<R!O('-E
M=2`B"B)F;W)M871O(.D@9&5S8V]N:&5C:61O+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C,Q-0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G
M92X@17)R;W(Z("(*;7-G<W1R(")%<W1A(&UE;G-A9V5M(&[C;R!P87)E8V4@
M<V5R('5M82!M96YS86=E;2!E;F-R:7!T861A(&-O;2!01U`N($5R<F\Z("(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(T,"!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HS-3`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O<G)E8W0@4$=0(&9O<FUA="`H86-C
M;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB"FUS9W-T<B`B(@HB17-T82!M96YS
M86=E;2!NXV\@<&%R96-E(&5S=&%R(&1E(&%C;W)D;R!C;VT@;R!F;W)M871O
M(%!'4"`H<V5G=6YD;R!O(%)&0R`B"B(R,#$U*2XB"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C$U.0IM<V=I9"`B5&AI<R!M97-S86=E(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R;6%T
M+B(*;7-G<W1R(")%<W1A(&UE;G-A9V5M(&[C;R!P87)E8V4@97-T87(@9&4@
M86-O<F1O(&-O;2!O(&9O<FUA=&\@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*
M;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D
M('9I82!01U`N(@IM<V=S='(@(D5S=&$@;65N<V%G96T@9F]I(&%S<VEN861A
M(&1I9VET86QM96YT92!V:6$@4$=0+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,3,R"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG
M:71A;&QY('-I9VYE9"!V:6$@4R]-24U%+B(*;7-G<W1R(")%<W1A(&UE;G-A
M9V5M(&9O:2!A<W-I;F%D82!D:6=I=&%L;65N=&4@=FEA(%,O34E-12XB"@HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$R."!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C(R-PIM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N
M(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R(")%<W1A(&UE;G-A9V5M
M(&9O:2!E;F-R:7!T861A('9I82!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,C`Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,0IM
M<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'
M4"XB"FUS9W-T<B`B17-T82!M96YS86=E;2!F;VD@96YC<FEP=&%D82!C;VT@
M4$=0+B(*"B,Z(&UE<W-A9V4N<&AP.C$Y-0IM<V=I9"`B5&AI<R!M97-S86=E
M('1O(@IM<V=S='(@(D5S=&$@;65N<V%G96T@<&%R82(*"B,Z(&%C;"YP:'`Z
M-#8*;7-G:60@(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R(")%<W1E('-E<G9I9&]R(&[C;R!S=7!O<G1A
M('!A<G1I;&AA(&1E('!A<W1A<RXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$P.0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R("(B"B)%<W1A
M(&IA;F5L82!T96T@9&4@<V5R(&-H86UA9&$@82!P87)T:7(@9&$@:F%N96QA
M(&1E(&5S8W)I=&$@9&4@;65N<V%G96TB"@HC.B!T:')E860N<&AP.C0T('1E
M;7!L871E<R]T:')E860O=&]P+FEN8SHS(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.3,*;7-G:60@(E1H<F5A9"!6:65W(@IM<V=S='(@(E9I<W5A;&EZ8>?C
M;R!D;R!4:')E860B"@HC.B!M97-S86=E+G!H<#HR-#@@;6%I;&)O>"YP:'`Z
M-3@U('-E87)C:"YP:'`Z,3,Y"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,C(@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C8T
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,3`*;7-G:60@
M(E1O(@IM<V=S='(@(E!A<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#DP"FUS9VED(")4;R!!9&1R97-S(@IM<V=S='(@(E!A<F$@;R!%;F1E<F7G
M;R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C
M;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&%R82!S96QE8V-I;VYA<B!M^FQT:7!L
M;W,@8V%M<&]S+"!P<F5S<VEO;F4@0V]N=')O;&\@*%!#*2!O=2!#;VUA;F1O
M("A-86,I("(*(G%U86YD;R!C;&EC87(N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-38W"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3
M:7IE.B(*;7-G<W1R(")486UA;FAO(%1O=&%L(&1O<R!!;F5X;W,Z(@H*(SH@
M9F]L9&5R<RYP:'`Z,S@S"FUS9VED(")4<F%S:"!F;VQD97(B"FUS9W-T<B`B
M4&%S=&$@9&4@;&EX;R(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C
M="YI;F,Z,C,*;7-G:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`B4&%S=&$@
M9&4@;&EX;SHB"@HC.B!L:6(O475O=&$O8WER=7,N<&AP.C8U(&QI8B]1=6]T
M82]M97)C=7)Y,S(N<&AP.C<Y(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC
M.B!L:6(O475O=&$O;&]G9FEL92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N
M<&AP.C4S(&QI8B]1=6]T82]M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE
M('1O(')E=')I979E('%U;W1A(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@82!Q=6]T82(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,V"FUS9VED(")5
M;F%N<W=E<F5D(@IM<V=S='(@(D[C;R!R97-P;VYD:61A(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M97-S
M86=E<R(*;7-G<W1R(")-96YS86=E;G,@;N-O(')E<W!O;F1I9&%S(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C0@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@(E5N9&5L971E(@IM
M<V=S='(@(E)E8W5P97)A<B(*"B,Z(&UA:6QB;W@N<&AP.C4V."!M86EL8F]X
M+G!H<#HU.#$@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C$R"FUS9VED(")5;F1I
M<V-L;W-E9"!296-I<&EE;G1S(@IM<V=S='(@(D1E<W1I;F%TX7)I;W,@;N-O
M(')E=F5L861O<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T
M>7!E.B`E<R(*;7-G<W1R(")#;VUP;VYE;G1E(&1E('1I<&\@;N-O('-U<&]R
M=&%D;SH@)7,B"@HC.B!M86EL8F]X+G!H<#HU-#0*;7-G:60@(E5N:VYO=VX@
M1&%T92(*;7-G<W1R(")$871A($1E<V-O;FAE8VED82(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,S4*;7-G:60@(E5N:VYO=VX@365E=&EN9R(*
M;7-G<W1R(")2975N:>-O($1E<V-O;FAE8VED82(*"B,Z(&UA:6QB;W@N<&AP
M.C4Y-PIM<V=I9"`B56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`B1&5S=&EN
M873A<FEO($1E<V-O;FAE8VED;R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,3$W('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ-3$*;7-G:60@(E5N
M;&]A9"!087-S<&AR87-E(@IM<V=S='(@(D1E<V-A<G)E9V%R(&9R87-E+6-H
M879E(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D
M(@IM<V=S='(@(E-E;2!N;VUE(@H*(SH@;65S<V%G92YP:'`Z-#@S(&UA:6QB
M;W@N<&AP.C8X-R!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-2!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,R"B,Z('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z-0IM<V=I9"`B56YS965N(@IM<V=S='(@(E!O<B!L
M97(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,`IM<V=I
M9"`B56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RDB"FUS9W-T<B`B0V%N8V5L
M87(@4W5B<V-R:>?C;R!D92!087-T82AS*2(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C4W-`IM<V=I9"`B57!D871E($%T=&%C:&UE;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B06-T=6%L:7IA<B!);F9O<FUAY^-O('-O
M8G)E($%N97AO<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C`*
M;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R(")!8W1U
M86QI>F%R(&\@97-T861O(&1O(')E<W!O;F1E;G1E(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+VEM<&]R=%]K97DN:6YC.C4V('1E;7!L871E<R]P9W`O:6UP;W)T
M7VME>2YI;F,Z-38*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")5<&QO860B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0R"FUS9VED
M(")5<V4@1&5F875L="!686QU92(*;7-G<W1R(")5<V%R(&\@=F%L;W(@<&%D
M<N-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,`IM<V=I9"`B57-E
M($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(E5S87(@<W5B
M<V-R:>?C;R!D92!P87-T87,@24U!4#\B"@HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,30P"FUS9VED(")5<V5R(@IM<V=S='(@(E5T:6QI>F%D;W(B"@HC
M.B!A8VPN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E5S97(@7"(E
M<UPB('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E8VEF:65D(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*(D\@=71I;&EZ861O
M<B!<(B5S7"(@871R:6)U:74@8V]M('-U8V5S<V\@;W,@9&ER96ET;W,@97-P
M96-I9FEC861O<R!P87)A(&$@(@HB<&%S=&$@7"(E<UPB+B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3@Q"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R(")5=&EL:7IA9&]R(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B57-E<FYA;64Z
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV-2!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C$Q,PHC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C$Q-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.3,*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$T-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,34Q"FUS
M9VED(")6:65W(@IM<V=S='(@(E9I<W5A;&EZ87(B"@HC.B!L:6(O34E-12]6
M:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3`X
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5FES=6%L
M:7IA<B`E<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C4@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,@4'5B;&EC($ME>2(*;7-G<W1R(")697(@82!C:&%V92!P^F)L:6-A
M("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R.`IM<V=I9"`B
M5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T
M<B`B5F5R(&-O;G1E^F1O($A434P@;G5M82!J86YE;&$@<V5P87)A9&$N(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,3<@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$U,0IM<V=I9"`B5FEE=R!097)S;VYA;"!0<FEV871E($ME
M>2(*;7-G<W1R(")697(@82!C:&%V92!P97-S;V%L('!R:79A9&$B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$Q,R!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,30W"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS
M9W-T<B`B5F5R(&$@8VAA=F4@<&5S<V]A;"!P^F)L:6-A(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$W"FUS9VED(")6:65W
M(%1H<F5A9"(*;7-G<W1R(")697(@0V]N=F5R<V$B"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,38U"FUS9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R(")697(@36EN
M:6%T=7)A(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,#<*;7-G
M:60@(E9I97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G
M<W1R(")697(@86YE>&\@;G5M82!J86YE;&$@<V5P87)A9&$N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y"FUS9VED(")6:65W(&-O;G1E
M;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`B5F5R(&-O;G1E^F1O
M(&YU;6$@:F%N96QA('-E<&%R861A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-#`*;7-G:60@(E9I97<@979E;G0B"FUS9W-T<B`B5F5R(&5V
M96YT;R(*"B,Z(&9O;&1E<G,N<&AP.C,W-2!M86EL8F]X+G!H<#HU,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G<W1R
M(")697(@;65N<V%G96YS(&5M("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+VEN
M:71I86QP86=E<V5L96-T+FEN8SHR-@IM<V=I9"`B5FEE=R!O<B!M86EL8F]X
M('1O(&1I<W!L87D@869T97(@;&]G:6XZ(@IM<V=S='(@(D-A:7AA('!O<W1A
M;"!O=2!V:7-T82!A(&UO<W1R87(@9&5P;VES(&1A(&5N=')A9&$Z(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W,`IM<V=I9"`B5FEE=R!T87-K
M(@IM<V=S='(@(E9E<B!T87)E9F$B"@HC.B!L:6(O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3$S"FUS9VED(")6:65W('1H92!);6%G97,B"FUS9W-T<B`B5F5R
M(&%S($EM86=E;G,B"@HC.B!S96%R8V@N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F
M=6QL>2XB"FUS9W-T<B`B02!087-T82!6:7)T=6%L(%PB)7-<(B!F;VD@8W)I
M861A(&-O;2!S=6-E<W-O+B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,3$Q(&QI8B])34%0+U1R964N<&AP.C$R.2!L:6(O24U!4"]4<F5E+G!H
M<#HQ-#(*(SH@;&EB+TE-05`O5')E92YP:'`Z,30T(&QI8B])34%0+U1R964N
M<&AP.C$T."!L:6(O24U!4"]4<F5E+G!H<#HQ-#D*(SH@;&EB+TE-05`O5')E
M92YP:'`Z,S4T(&QI8B])34%0+U1R964N<&AP.C,W."!L:6(O24U!4"]4<F5E
M+G!H<#HT,3@*;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*;7-G<W1R(")087-T
M87,@5FER='5A:7,B"@HC.B!S96%R8V@N<&AP.C(Y-@IM<V=I9"`B5FER='5A
M;"!&;VQD97)S(')E<75I<F4@82!L86)E;"XB"FUS9W-T<B`B4&%S=&%S(%9I
M<G1U86ES('!R96-I<V%M(&1E('5M82!E=&EQ=65T82XB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$S,PIM<V=I9"`B5FER='5A;"!F;VQD97(@
M;&%B96PB"FUS9W-T<B`B171I<75E=&$@9&$@<&%S=&$@=FER='5A;"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S8S"FUS9VED(")787)N:6YG
M(@IM<V=S='(@(D%V:7-O(@H*(SH@;&]G:6XN<&AP.C$S,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D)E;2UV:6YD;R!A
M;R`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,C0*;7-G:60@(B(*
M(E=H96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R
M87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE
M=&5D/R(*;7-G<W1R("(B"B)1=6%N9&\@<F5M;W9E<B!M96YS86=E;G,L(&UO
M=NHM;&%S('!A<F$@82!P87-T82!D92!,:7AO(&5M('9E>B!D92!M87)CX2UL
M87,@(@HB8V]M;R!R96UO=FED87,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@W.`IM<V=I9"`B5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H
M:6-H('!A9V4@9&\@>6]U('=A;G0@=&\@<W1A<G0@;VX_(@IM<V=S='(@(E%U
M86YD;R!A8G)I;F1O('5M82!N;W9A(&-A:7AA('!O<W1A;"P@96T@<75E('#A
M9VEN82!Q=65R(&-O;67G87(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4U-`IM<V=I9"`B5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@
M<V%V92!A='1A8VAM96YT(&1A=&$_(@IM<V=S='(@(E%U86YD;R!G=6%R9&%N
M9&\@;65N<V%G96YS(&5N=FEA9&%S+"!G=6%R9&%R('1A;6+I;2!O<R!D861O
M<R!A;F5X;W,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R,0IM<V=I
M9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E
M<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI
M9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB
M*3\B"FUS9W-T<B`B(@HB06\@96YV:6%R(&UE;G-A9V5N<R!O=2!A;R!E>'!A
M;F1I<B!E;F1E<F7G;W,L('%U92!D;VWM;FEO(&1E=F4@<V5R("(*(F%D:6-I
M;VYA9&\@86]S(&5N9&5R9>=O<R!NXV\@<75A;&EF:6-A9&]S("AI+F4N+"!E
M;F1E<F7G;W,@9&4@8V]R<F5I;R`B"B)E;&5C='+S;FEC;R!S96T@7")`7"(I
M/R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR
M,B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B5VAI
M=&5L:7-T(@IM<V=S='(@(DQI<W1A($)R86YC82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,S<*;7-G:60@(E=R87`@=&5X="!A="!T:&ES(&UA;GD@
M8VAA<F%C=&5R<RXB"FUS9W-T<B`B475E8G)A<B!A(&QI;FAA(&1E<&]I<R!D
M97-T82!Q=6%N=&ED861E(&1E(&-A<F%C=&5R97,N(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-#D*;7-G:60@(EEE<R(*;7-G<W1R(")3:6TB"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C4X"FUS9VED(")9;W4@
M87)E(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A
M8V-O=6YT*',I.B(*;7-G<W1R(")%<W3A(&$@=&5N=&%R(&1E<V-A<G)E9V%R
M(&-O<G)E:6\@9&$H<RD@<V5G=6EN=&4H<RD@8V]N<W0H<RDZ(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3`*;7-G:60@
M(B(*(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S
M(&-O;G1A:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<B(*(BAS*2XB"FUS
M9W-T<B`B(@HB17-TX2!A('1E;G1A<B!R96UO=F5R('1O9&%S(&%S(&UE;G-A
M9V5N<R!C;VYT:61A<R!N82AS*2!S96=U:6YT92AS*2!P87-T82AS*2(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.CD*;7-G
M:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN
M9R!F;VQD97(H<RDN(@IM<V=S='(@(D5S=.$@82!T96YT87(@<F5M;W9E<B!A
M*',I('-E9W5I;G1E*',I('!A<W1A*',I+B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VIA=F%S8W)I<'0N:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C$Y,@IM<V=I9"`B66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T
M;R!A(&YE=R!F;VQD97(N(@IM<V=S='(@(D5S=.$@82!C;W!I87(O;6]V97(@
M<&%R82!U;6$@;F]V82!P87-T82XB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]J
M879A<V-R:7!T+FEN8SHY-`IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U
M8BUF;VQD97(@=&\@(@IM<V=S='(@(D5S=.$@82!C<FEA<B!U;6$@<W5B+7!A
M<W1A(&5M("(*"B,Z('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC
M.CDV"FUS9VED(")9;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E
M<BXB"FUS9W-T<B`B17-TX2!A(&-R:6%R('5M82!P87-T82!N;R!N[79E;"!D
M92!T;W!O+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC
M.C$R-PIM<V=I9"`B66]U(&%R92!R96YA;6EN9R!T:&4@9F]L9&5R.B`B"FUS
M9W-T<B`B17-TX2!A(')E;F]M96%R(&$@<&%S=&$Z("(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@8V%N(&YO="!U
M;G-U8G-C<FEB92!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B3N-O('!O9&4@8V5S
M<V%R(&$@<W5B<V-R:>?C;R!D92!<(B5S7"(N(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D
M:60@;F]T(&%G<F5E('1O('1H92!497)M<R!O9B!397)V:6-E(&%G<F5E;65N
M="P@<V\@>6]U('=E<F4@;F]T(&%L;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S
M='(@(D[C;R!D974@;R!S974@86-O<F1O(&%O<R!497)M;W,@9&4@4V5R=FGG
M;W,L('!O<B!I<W-O(&[C;R!P;V1E(&5N=')A<BXB"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z,38U"FUS9VED(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES
M<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H:7,@9F]L9&5R(@IM<V=S='(@
M(D[C;R!T96T@<&5R;6ES<^-O('!A<F$@86QT97)A<B!O(&%C97-S;R!A(&5S
M=&$@<&%S=&$B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T
M;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R(")2965N
M=FEO=2!E<W1A(&UE;G-A9V5M(&5M("4E<R!P87)A(&]S('-E9W5I;G1E<R!D
M97-T:6YA=.%R:6]S.B`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R
M="YI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@
M;65S<V%G97,N(@IM<V=S='(@(E1E;2`E<R!M96YS86=E;G,@;F]V87,N(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H
M879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(E1E;2`Q(&UE;G-A9V5M(&YO
M=F$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,3$V
M"FUS9VED("(B"B)9;W4@:&%V92!A="!L96%S="!O;F4@871T86-H;65N="!S
M96QE8W1E9"!T:&%T('EO=2!D:61N)W0@=7!L;V%D('EE="X@07)E("(*(GEO
M=2!S=7)E('EO=2!W86YT('1O('-E;F0@=&AI<R!M97-S86=E('=I=&AO=70@
M=&AE<V4@871T86-H;65N=',_(@IM<V=S='(@(B(*(E1E;2!P96QO(&UE;F]S
M('5M(&%N97AO('-E;&5C8VEO;F%D;R!Q=64@86EN9&$@;N-O(&-A<G)E9V]U
M+B!1=65R(&UE<VUO('%U92`B"B)E;G9I96UO<R!E<W1A(&UE;G-A9V5M('-E
M(&5S<V5S(&%N97AO<S\B"@HC.B!L:6(O24U0+G!H<#HQ,#,P"FUS9VED(")9
M;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS
M9W-T<B`B5&5M(&YO=F%S(&UE;G-A9V5N<R!N82!S96=U:6YT92!P87-T83HB
M"@HC.B!L:6(O24U0+G!H<#HQ,#,U"FUS9VED(")9;W4@:&%V92!N97<@;6%I
M;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(E1E;2!N;W9A
M<R!M96YS86=E;G,@;F%S('-E9W5I;G1E<R!P87-T87,Z(@H*(SH@8V]M<&]S
M92YP:'`Z,3(V"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@
M<F5C:7!I96YT+B(*;7-G<W1R(")496T@9&4@:6YT<F]D=7II<B!P96QO(&UE
M;F]S('5M(&1E<W1I;F%TX7)I;RXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HS,#(*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S
M<V%G92(*;7-G<W1R("(B"B)496T@9&4@:6YT<F]D=7II<B!A(&9R87-E+6-H
M879E(&1A('-U82!C:&%V92!P<FEV861A(%!'4"!P87)A('9E<B!E<W1A("(*
M(FUE;G-A9V5M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*
M;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y
M;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G
M92(*;7-G<W1R("(B"B)496T@9&4@:6YT<F]D=7II<B!A(&9R87-E+6-H879E
M(&1A('-U82!C:&%V92!P<FEV861A(%,O34E-12!P87)A('9E<B!E<W1A("(*
M(FUE;G-A9V5M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI
M;F,Z-C0@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS
M9VED(")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB
M"FUS9W-T<B`B5&5M(&1E('-E;&5C8VEO;F%R('!R:6UE:7)O('5M82!C86EX
M82!P;W-T86PN(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9
M;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R(")496T@9&4@<V5L96-C:6]N87(@=6UA(&-O;G1A('!A<F$@<V5R(')E
M;6]V:61A+B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M.#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S(&9I<G-T+B(*
M;7-G<W1R(")496T@9&4@<V5L96-C:6]N87(@<')I;65I<F\@=6T@96YD97)E
MYV\N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@
M=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L
M871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R
M(")496T@9&4@<V5L96-C:6]N87(@<')I;65I<F\@<&5L;R!M96YO<R!U;6$@
M;65N<V%G96TN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G
M<W1R(")496T@9&4@:6YT<F]D=7II<B!U;2!D97-T:6YA=.%R:6\N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,CD*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@870@;&5A<W0@;VYE(&9I;&4@=&\@871T86-H+B(*
M;7-G<W1R(")496T@9&4@97-P96-I9FEC87(@<&5L;R!M96YO<R!U;2!A<G%U
M:79O(&$@86YE>&%R+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@;F5E9"!T;R!H879E
M(%PB)7-<(B!E;F%B;&5D(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RXB
M"FUS9W-T<B`B4')E8VES82!D92!T97(@7"(E<UPB(&%C=&EV861O(&YA<R!S
M=6%S(&]PY_5E<R!D92!M86YU=&5NY^-O+B(*"B,Z(&QI8B]-86EL;&]G+G!H
M<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E9&ER96-T960@=&AI
M<R!M97-S86=E('1O("5S(&]N("4E<RXB"FUS9W-T<B`B4F5D:7)E8V-I;VYO
M=2!E<W1A(&UE;G-A9V5M('!A<F$@)7,@96T@)25S+B(*"B,Z(&QI8B]-86EL
M;&]G+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@
M=&\@=&AI<R!M97-S86=E(&]N("5S+B(*;7-G<W1R(")297-P;VYD974@82!E
M<W1A(&UE;G-A9V5M(&5M("5S+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0X-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T
M;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B(@HB02!P87-T82!<(B5S7"(@;N-O(&5S=&%V82!N82!S=6$@;&ES=&$@
M9&4@<W5B<V-R:>?U97,N($%Q=6D@97-TX2!O('%U92!O("(*(G-E<G9I9&]R
M(&1I<W-E(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-3,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(N
M($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB02!P
M87-T82!<(B5S7"(@;N-O(&9O:2!R971I<F%D82!D82!S=6$@;&ES=&$@9&4@
M<W5B<V-R:>?U97,N($%Q=6D@97-TX2!O('%U92`B"B)O('-E<G9I9&]R(&1I
M<W-E(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#DP"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<
M(B(*;7-G<W1R(")!('!A<W1A(%PB)7-<(B!F;VD@:6YC;'7M9&$@8V]M('-U
M8V5S<V\@;F$@<W5A(&QI<W1A(&1E('-U8G-C<FGG]65S(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-30R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U
M8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B
M02!P87-T82!<(B5S7"(@9F]I(&5X8VQU[61A(&-O;2!S=6-E<W-O(&1A('-U
M82!L:7-T82!D92!S=6)S8W)IY_5E<R(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHQ.#8*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")/(%-E=2!.;VUE
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q.0IM<V=I9"`B66]U<B!0
M1U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*;7-G<W1R(")!<R!3=6%S($-H879E
M<R!0=6)L:6-A<R]0<FEV861A<R!01U`B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C$Q-B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,34P"FUS9VED
M(")9;W5R(%!R:79A=&4@2V5Y(@IM<V=S='(@(D$@4W5A($-H879E(%!R:79A
M9&$B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$Q,B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,30V"FUS9VED(")9;W5R(%!U8FQI8R!+97DB"FUS
M9W-T<B`B02!3=6$@0VAA=F4@4/IB;&EC82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-3<*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QI
M/BAO<'1I;VYA;"D\+VD^(@IM<V=S='(@(D\@4V5U($5N9&5R9>=O(&1E(%)E
M<W!O<W1A(#QI/BAO<&-I;VYA;"D\+VD^.B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z.3$*;7-G:60@(EEO=7(@4R]-24U%(%!U8FQI8R]0<FEV
M871E($-E<G1I9FEC871E<R(*;7-G<W1R(")/<R!3975S($-E<G1I9FEC861O
M<R!0=6)L:6-O<R]0<FEV861O<R!3+TU)344B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHQ-@IM<V=I9"`B66]U<B!A8V-O
M=6YT<SHB"FUS9W-T<B`B07,@<W5A<R!C;VYT87,Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$V-0IM<V=I9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S
M97,Z(#QI/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W
M(&QI;F4I/"]I/B(*;7-G<W1R("(B"B)/<R!S975S(&5N9&5R9>=O<R!E<75I
M=F%L96YT97,Z(#QI/BAO<&-I;VYA;"P@:6YT<F]D=7IA(&-A9&$@96YD97)E
MYV\@96T@<W5A("(*(FQI;FAA*3PO:3XB"@HC.B!L:6(O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HY,@IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G92!T>7!E+B(*;7-G
M<W1R("(B"B)/('-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@82!V:7-U86QI
M>F'GXV\@96TM;&EN:&$@9&5S=&4@=&EP;R!D92!I;6%G96TN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S,@IM<V=I9"`B66]U<B!D969A=6QT(&-H
M87)S970@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(D\@<V5U(&/S
M9&EG;R!D92!C87)A8W1E<F5S('!O<B!E;6ES<^-O(&%O(&5N=FEA<B!M96YS
M86=E;G,Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N8W)Y<'1S96QE8W0N:6YC
M.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T:6]N(&UE=&AO9"!F;W(@
M<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B3R!S974@;>ET;V1O(&1E(&5N
M8W)I<'1AY^-O('!O<B!O;6ES<^-O(&%O(&5N=FEA<B!M96YS86=E;G,Z(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*;7-G:60@(EEO=7(@
M;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB"FUS9W-T<B`B
M02!S=6$@;65N<V%G96T@9F]I(&5N=FEA9&$@8V]M('-U8V5S<V\N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y.`IM<V=I9"`B66]U<B!S:6=N871U
M<F4Z(@IM<V=S='(@(D$@4W5A($%S<VEN871U<F$Z(@H*(SH@;65S<V%G92YP
M:'`Z,C<R(&-O;7!O<V4N<&AP.C$R,3D@;6%I;&)O>"YP:'`Z-3(X(&QI8B]#
M;VUP;W-E+G!H<#HW,CD*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");
M4V5M($%S<W5N=&]=(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,C$V"FUS9VED(")?0F-C(@IM<V=S='(@(E]"8V,B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3D@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T
M<B`B3&ES=&$@3E]E9W)A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,38U"FUS9VED(")?0V,B"FUS9W-T<B`B7T-C(@H*(SH@;&EB+TE-
M4"YP:'`Z.3,S"FUS9VED(")?0V]M<&]S92(*;7-G<W1R(")%<V-R979E7W(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"B,Z('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C$P"FUS9VED(")?1&5L971E(@IM<V=S='(@
M(E)E;6]?=F5R(@H*(SH@;&EB+TE-4"YP:'`Z.3,U"FUS9VED(")?1F]L9&5R
M<R(*;7-G<W1R(")?4&%S=&%S(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z.#`*;7-G:60@(E])9&5N=&ET>2(*;7-G<W1R(")?261E;G1I
M9&%D92(*"B,Z(&QI8B])35`N<&AP.CDR-@IM<V=I9"`B7TEN8F]X(@IM<V=S
M='(@(E]%;G1R861A(@H*(SH@;&EB+TE-4"YP:'`Z.3<V"FUS9VED(")?3&]G
M(&]U="(*;7-G<W1R(")?4V%I<B(*"B,Z(&UE<W-A9V4N<&AP.C,V.`IM<V=I
M9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(D/S9&EG;RUF;VYT92!D82!-
M96YS86=E;2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHS,0IM<V=I9"`B7U!R:6YT(@IM<V=S='(@(E]);7!R:6UI<B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(X,R!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHS,#`*;7-G:60@(E]0<FEO<FET>2(*;7-G
M<W1R(")0<FEO<FED861E(@H*(SH@;6%I;&)O>"YP:'`Z-#`R"B,L('!H<"UF
M;W)M870*;7-G:60@(E]2969R97-H("5S(@IM<V=S='(@(E]2969R97-C87(@
M)7,B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M.`IM<V=I9"`B7U)E<&QY(@IM<V=S='(@(E)E<W!?;VYD97(B"@HC.B!L:6(O
M24U0+G!H<#HY,S<*;7-G:60@(E]396%R8V@B"FUS9W-T<B`B4')O8U]U<F%R
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C8@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(R"FUS9VED(")?4V5N9"!-97-S
M86=E(@IM<V=S='(@(E]%;G9I87(@365N<V%G96TB"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,R"FUS9VED(")?5&AR96%D
M(@IM<V=S='(@(E]#;VYV97)S82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C$Q-0IM<V=I9"`B7U1O(@IM<V=S='(@(E]087)A(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3,*;7-G:60@(E]5;F1E
M;&5T92(*;7-G<W1R(")?4F5C=7!E<F%R(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$W"FUS9VED(")?5FEE=R!4:')E860B
M"FUS9W-T<B`B7U9E<B!#;VYV97)S82(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHR,B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R("),:7-T82!"
M7W)A;F-A(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,U,0IM<V=I9"`B871T86-H
M;65N="(*;7-G<W1R(")A;F5X;R(*"B,Z('9I97<N<&AP.CDY"FUS9VED(")A
M='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B86YE>&]S+GII<"(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P,PIM<V=I9"`B8GET97,B"FUS
M9W-T<B`B8GET97,B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$Y,`IM<V=I9"`B9G)O;2(*;7-G<W1R(")D92(*"B,Z('-M:6UE+G!H
M<#HR.2!P9W`N<&AP.C8Y"FUS9VED(")K97DB"FUS9W-T<B`B8VAA=F4B"@HC
M.B!F;VQD97)S+G!H<#HQ-3$*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R
M(")F:6-H96ER;R!D92!C86EX82!P;W-T86PB"@HC.B!C;VUP;W-E+G!H<#HQ
M,#`Q(&QI8B]-97-S86=E+G!H<#HT,CD*;7-G:60@(FYA;64B"FUS9W-T<B`B
M3F]M92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM
M<V=I9"`B;F]N92(*;7-G<W1R(")N96YH=6TB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z,3$Q"FUS9VED(")O<B(*;7-G<W1R(")O=2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT.`IM<V=I9"`B
M<W!E;&QI;F<@97)R;W(B"FUS9W-T<B`B97)R;R!D92!O<G1O9W)A9FEA(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS9VED(")S
M<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B97)R;W,@9&4@;W)T;V=R869I82(*
M"B,Z(&QI8B]&:6QT97(N<&AP.C4Q"FUS9VED(")Y;W5R(&)L86-K;&ES="(*
M;7-G<W1R(")A('-U82!L:7-T82!N96=R82(*"B,Z(&QI8B]&:6QT97(N<&AP
M.C8Q"FUS9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R(")A('-U82!L:7-T
M82!B<F%N8V$B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+W!O+VEM<"YP;W0`````````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#,Q-#`T,``Q,#0Q-S,V,C<V-@`P,3<Q-#,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!33TU%($1%4T-2
M25!4259%(%1)5$Q%+@HC($-O<'ER:6=H="`H0RD@645!4B!(;W)D92!0<F]J
M96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M(&QI8V5N<V4@87,@=&AE(%!!0TM!1T4@<&%C:V%G92X*(R!&25)35"!!551(
M3U(@/$5-04E,0$%$1%)%4U,^+"!914%2+@HC"B,L(&9U>GIY"FUS9VED("(B
M"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!004-+04=%(%9%4E-)
M3TY<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT-RLP
M,3`P7&XB"B)03RU2979I<VEO;BU$871E.B!914%2+4U/+41!($A/.DU)*UI/
M3D5<;B(*(DQA<W0M5')A;G-L871O<CH@1E5,3"!.04U%(#Q%34%)3$!!1$12
M15-3/EQN(@HB3&%N9W5A9V4M5&5A;3H@3$%.1U5!1T4@/$Q,0&QI+F]R9SY<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]0TA!4E-%5%QN(@HB0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0R.0IM<V=I
M9"`B("`@("`@0V,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M-#(V"FUS9VED("(@("`@("!4;SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HT,30*;7-G:60@(B`@("!$871E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0Q-PIM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R
M("(B"@HC.B!M86EL8F]X+G!H<#HT,#@@=&5M<&QA=&5S+V9O;&1E<G,O:&5A
M9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0R,PIM<V=I9"`B(%-U
M8FIE8W0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z-S`*;7-G:60@(B!I;B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G
M<W1R("(B"@HC.B!T:')E860N<&AP.C$U-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!-97-S86=E<R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HQ-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)60@;65S<V%G97,@:&%V92!B965N(')E<&]R
M=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO
M="!S<&%M+B(*;7-G<W1R("(B"@HC.B!L:6(O4W!A;2YP:'`Z,3@X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM
M<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!T;R`E9"!O9B`E9"!-97-S86=E<R(*;7-G<W1R("(B"@HC.B!M
M86EL8F]X+G!H<#HV,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L
M<F5A9'D@97AI<W1S+B!9;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M;6%I;&)O>"XB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO
M<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C0R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&9O;&1E<B!B96EN9R!R96YA;65D(&%T('1H92!S=&%R="!O
M9B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HR-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P
M=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C$W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!D96-L:6YE9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S
M>2!R97%U97-T+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D
M('1O('1H92!I;G9I=&%T:6]N('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I=F5L>2!A8V-E<'1E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R964O
M8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4X,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U
M97-T<R!Y;W5R('!R97-E;F-E(&%T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C0V,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!W:7-H97,@=&\@86UM96YD(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3DV"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E
M('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!M97-S86=E+G!H<#HR.3(@;65S<V%G92YP:'`Z,CDW"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?=&]P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B
M*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3(P"FUS9VED("(H1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N
M('1O('1H92!C;VUP;W-E('-C<F5E;BXI(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B*$A434PI(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ
M-@IM<V=I9"`B*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z('-P96QL:6YG
M+G!H<#HR-SD*;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R
M965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N
M("`B"B)#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B
M92!A<'!L:65D+BDB"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(W-@IM
M<V=I9"`B(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA
M;F=E<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N
M="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J
M($%D9"!T:&5S92!B>2!C;&EC:VEN9R!/2R`J(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C`V"FUS9VED("(J(%!L
M96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*;7-G<W1R("(B"@HC.B!M86EL
M8F]X+G!H<#HQ-S,*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O4W!A;2YP:'`Z,3DX"FUS9VED("(Q(&UE
M<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+U-P86TN
M<&AP.C$W.`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M+B(*;7-G<W1R("(B"@HC.B!L:6(O4W!A;2YP:'`Z,3DP"FUS
M9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O
M4W!A;2YP:'`Z,3<P"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T
M960@87,@<W!A;2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@P.`IM<V=I9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q,0IM<V=I9"`B,3`P,"!C:&%R86-T
M97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,#D*
M;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,3`*;7-G:60@(C4P,"!C:&%R86-T97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T
M=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S
M<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N
M;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0IM<V=I9"`B04Y$
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#(*
M;7-G:60@(D%C8V5P="!A;F0@861D('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(D%C
M8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW-#8*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3@*;7-G:60@(D%C8V5P=&5D.B`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C<*;7-G:60@(D%C8V]U;G0G<R!N86UE.B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3(R(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW,C4*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O2&5A9&5R<RYP:'`Z,3DR(&QI8B]-24U%+TAE861E<G,N<&AP.C$Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,@=&\@;7D@061D<F5S<R!";V]K
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,P,PIM<V=I9"`B061D('-O=7)C92(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3<S"FUS9VED(")!9&0@=&AI<R!T;R!M
M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3@S"FUS9VED(")!9&0@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z-3DP"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DX"FUS9VED("(B"B)!9&1I=&EO;F%L
M(&AE861E<G,@=&\@9&ES<&QA>2!W:&5N('9I97=I;F<Z(#QE;3XH;W!T:6]N
M86PL(&5N=&5R(&5A8V@@:&5A9&5R("(*(F]N(&$@;F5W(&QI;F4I/"]E;3XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA
M=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@IM<V=I9"`B061D:71I;VYA
M;"!I;F9O<FUA=&EO;B!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.CDS"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A
M9V4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE
M<W-A9V4@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW.`IM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D:71I;VYA;"!M97-S86=E(&5R<F]R(&1E=&%I;',@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N=&%C=',N<&AP.C@U('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C,S-R!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"FUS9VED(")!9&1R97-S($)O
M;VMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#D*
M;7-G:60@(B(*(D%D9')E<W-E<R!T;R!"0T,@86QL(&UE<W-A9V5S.B`\96T^
M*&]P=&EO;F%L+"!E;G1E<B!E86-H(&%D9')E<W,@;VX@82!N97<@(@HB;&EN
M92D\+V5M/B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3@Q"FUS9VED("(B"B)!9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@
M=&AI<R!I9&5N=&ET>3H@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"`B"B)A
M9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#$R"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,PIM<V=I9"`B(@HB06QL(&UE<W-A
M9V5S(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO
M861E9"!I;G1O(&]N92!-0D]8("(*(F9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@>6]U<B!<(B5S7"(@
M9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E<FUA;F5N=&QY
M("(*(F1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT<R!M;W)E
M('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E
M;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@
M8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HX-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!;&P@<FEG:'1S(&]N(&9O;&1E<B!<(B5S7"(@<W5C
M8V5S<V9U;&QY(')E;6]V960@9F]R('5S97(@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L9&5R($-R96%T
M:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z-#@*;7-G:60@(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B92!A<'!L:65D
M(&EN(&%N>2!M86EL8F]X/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O86QT97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B06QT97)N871I=F4@<&%R
M=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4W,@IM<V=I9"`B06QW87ES(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3<*;7-G:60@(D%L=V%Y<R!S879E
M(&%T=&%C:&UE;G1S(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HU
M-3$*;7-G:60@(B(*(D%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN
M9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE($E-05`@<V5R=F5R("(*
M(G-A:60Z("(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-#,U"FUS
M9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@
M=&AE(&YE=R!N;W1E+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-#,T"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E
M871I;F<@=&AE(&YE=R!T87-K+B(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H
M<#HU,#,@;6%I;&)O>"YP:'`Z-S`X('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS
M9VED(")!;G-W97)E9"!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]H96%D97(N:6YC.C<*;7-G:60@(D%P<&QY($9I;'1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS
M9VED(")!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#(*;7-G
M:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!W:&5N979E<B!)3D)/6"!I<R!D:7-P
M;&%Y960_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,30*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE
M=&4@=&AI<R!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR-PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(&1E;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C@U"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E
M('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D(2DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C4@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\B"FUS9W-T<B`B(@H*(SH@;65S
M<V%G92YP:'`Z-#`X('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC
M.C8X"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y4
M3%D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]#;VYT96YT<RYP:'`Z,C,Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES
M(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.34Q"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O
M;&1E<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.30T"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD
M97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P97)M86YE
M;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E;7!L871E<R]M
M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI
M;F,Z-S4@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S
M86=E(&%S('-P86T_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,#4*;7-G:60@(D%R<FEV86P@5&EM92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(P"FUS9VED(")!<V-E;F1I;F<B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,0IM<V=I9"`B
M07-K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0W,`IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U,0IM<V=I9"`B071T86-H
M(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G
M93\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$Q
M,0IM<V=I9"`B071T86-H960@1FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0V,B!L:6(O0V]M<&]S92YP:'`Z-34W"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D%T=&%C:&5D(&9I;&4@7"(E<UPB(&5X8V5E9',@=&AE
M(&%T=&%C:&UE;G0@<VEZ92!L:6UI=',N($9I;&4@3D]4(&%T=&%C:&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S<W"FUS
M9VED(")!='1A8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q=65S
M="!Y;W4@<V5N="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ-B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI
M;F,Z,30*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DX('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C4U"FUS9VED(")!='1A
M8VAM96YT(@IM<V=S='(@(B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C<P"B,L('!H
M<"UF;W)M870*;7-G:60@(D%T=&%C:&UE;G0@)7,@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Q,C4*;7-G:60@(D%T=&%C:&UE
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3$P
M-2!L:6(O365S<V%G92YP:'`Z-3$S"FUS9VED(")!='1A8VAM96YT('-T<FEP
M<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0W('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0V.`HC.B!L:6(O0V]M<&]S92YP:'`Z,3`Y
M,PIM<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8W.`IM<V=I9"`B071T96YD965S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"FUS
M9VED(")!='1E;G1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T%U=&@O:6UP+G!H
M<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8R.`IM<V=I9"`B(@HB075T;VUA=&EC86QL>2!S:&]W(&EM86=E<R!I
M;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE('-E;F1E<B!I<R!I;B!M>2`B"B)A
M9&1R97-S8F]O:S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O
M=7)C97-E;&5C="YI;F,Z,CDX"FUS9VED(")!=F%I;&%B;&4@061D<F5S<R!B
M;V]K<SHB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<Q-`IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")"86-?:R!T;R`E<R(*;7-G<W1R("(B"@HC.B!T
M:')E860N<&AP.C$S-R!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A
M=&4N:6YC.C(V"B,L('!H<"UF;W)M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS
M9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L
M=&EP;&4@365S<V%G92!6:65W($EN9&5X(@IM<V=S='(@(B(*"B,Z('1H<F5A
M9"YP:'`Z,3,R"FUS9VED(")"86-K('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D)A9"!L;V=I;B!N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,X-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")"860@;W(@;6%L9F]R;65D(')E<75E<W0N(%-E<G9E<B!297-P
M;VYD960Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M-3<V"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!R97%U97-T.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C<S('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M
M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z-C`Q"FUS9VED(")"8V,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38Q"FUS
M9VED(")"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE('-T871U<R!I;F9O
M<FUA=&EO;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,38*;7-G:60@(D)L86-K;&ES="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")";&]C:R!I;6%G
M97,@:6X@2%1-3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A
M;&QY(')E<75E<W1E9#\B"FUS9W-T<B`B(@H*(SH@;&EB+U-E87)C:"YP:'`Z
M-C`Y"FUS9VED(")";V1Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z,C,@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS.0HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4U('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z-S$*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8X-`IM<V=I9"`B0F]T:"!(96%D97(@3&ES
M=&EN9R!A;F0@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B])
M34%0+T-L:65N="YP:'`Z-3`Q"FUS9VED(")#4D%-+4U$-2!O<B!$24=%4U0M
M340U(')E<75I<F5S('1H92!!=71H7U-!4TP@<&%C:V%G92!T;R!B92!I;G-T
M86QL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(W,`IM<V=I9"`B0U]H87)S970B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V"FUS9VED(")#86QE;F1A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C(P,0IM<V=I
M9"`B0V%N(&YO="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3DY"FUS
M9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P87)T:6%L+G!H
M<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T(&1I<W!L87D@
M+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S<V%G92!I
M;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HR-S`@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T
M97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M
M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N8V5L(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,`HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI
M;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G:60@(D-A
M;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@9&ES8V%R
M9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(W
M,B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC.B!T96UP
M;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI8B]396%R8V@N<&AP
M.C4Y-PIM<V=I9"`B0V,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHY,PIM<V=I9"`B(@HB0V5R=&EF:6-A=&4@:6UP;W)T(&ES
M(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N
M('1H:7,@(@HB<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-CDV"FUS9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C@P"FUS9VED
M(")#:&%N9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B0VAA;F=E($9O;&1E
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS
M9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA
M;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M
M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C0*;7-G:60@(D-H86YG92!M86EL('-E<G9E<B!A;F0@
M9F]L9&5R('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92P@861D<F5S
M<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD("(*(G)E<&QY('1O('EO=7(@96UA:6PN(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3,*;7-G:60@(D-H87)A8W1E<G,@
M=&\@9&ES<&QA>3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,34*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W
M($UA:6PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C<U"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C$P('1E;7!L871E<R]F
M971C:&UA:6PO9F5T8VAM86EL+FEN8SHR,0IM<V=I9"`B0VAE8VL@86QL(&UA
M:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-C,*;7-G:60@(D-H
M96-K('-P96QL:6YG(&)E9F]R92!S96YD:6YG(&$@;65S<V%G93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I
M9"`B0VAO;W-E($%C=&EO;CHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W-E<G9E
M<G,N<&AP+F1I<W0Z,C`R"FUS9VED(")#:&]O<V4@82!M86EL('-E<G9E<CHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,3(S('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$V-`HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,34*;7-G:60@(D-H;V]S92!A
M(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M-#D*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N
M(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y,PIM<V=I9"`B0VAO;W-E('1H92!O
M<F1E<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN
M9R!A9&1R97-S97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!C;VYV97)T('1H92!I;6%G92!F:6QE(&EN=&\@82!F;W)M870@>6]U<B!B
M<F]W<V5R(&-A;B!V:65W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HQ,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M)7,@=&\@9&]W;FQO860@=&AE(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M1FEL=&5R+G!H<#HQ,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@
M=&\@9V\@=&\@)7,@;6%N86=E;65N="!P86=E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K("5S('1O('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A
M=&4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@
M=FEE=R!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@
M<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<F5L871E9"YP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A<G0@:6X@82!S
M97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HY.`IM<V=I9"`B0VQI8VL@:&5R92!T;R!32$]7('1H92!)
M;6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S(Q"FUS9VED("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S
M96QE8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE
M;&1S('1O("(*(G-E87)C:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,3<P"FUS9VED(")#;&EC:R!T;R!3879E(%!'4"!0=6)L
M:6,@2V5Y(&EN('EO=7(@061D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L:6-K('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC871E(&]F("5S(&EN
M('EO=7(@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,SD*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S
M('=I;&P@8V]M<&]S92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,`IM<V=I9"`B
M0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E
M('1O(&)E(')E860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]F971C:&UA:6PN:6YC.C(X"FUS9VED(")#;&]S92(*;7-G<W1R("(B"@HC
M.B!C;VUP;W-E+G!H<#HT,3@*;7-G:60@(D-L;W-E('1H:7,@=VEN9&]W(@IM
M<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q,`IM<V=I9"`B0VQO<V5D($9O
M;&1E<B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT,S`*;7-G:60@(D-O
M;&QA<'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C0P"FUS9VED(")#;VQL87!S92!!;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-#`*;7-G:60@(D-O;&QA
M<'-E($%L;"!&;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0S
M,`IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHU,0IM<V=I9"`B0V]L;W(@26YD
M:6-A=&]R.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$P,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-S8R"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z-#$W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@
M;65S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#,T"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN
M9&]W/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0S
M"FUS9VED("(B"B)#;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'54D@
M8GD@9&5F875L="`H:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@(@HB9F5A='5R
M92D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-PIM
M<V=I9"`B0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@
M(D-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G:60@(D-O;FYE8W1I;VX@
M9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@(D-O;FYE8W1I;VX@=&\@<V5R
M=F5R(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4$=0('-U<'!O
M<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4R]-24U%('-U
M<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P=&EO;G,@<F5L871I;F<@=&\@
M;65S<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O;G1R;VP@=VAE;B!N97<@;6%I
M;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N;W0@=&\@
M;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV97,N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-S0*;7-G:60@(D-O;G9E<G0@=&5X
M='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,0IM
M<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#`*
M;7-G:60@(D-O<G)E8W1E9"!497AT(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z,S@R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C;VUP;&5T92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S(@IM<V=S='(@
M(B(*"B,Z(&%T=&%C:&UE;G0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E
M<G9E<B!S86ED.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z
M,S,S"FUS9VED(")#;W5L9"!N;W0@97AE8W5T92!M86EN=&5N86YC92!O<&5R
M871I;VYS+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z-30*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@
M9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N
M;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R
M8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-#0V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N('-E8W5R92!C
M;VYN96-T:6]N('1O('1H92!)34%0('-E<G9E<BX@)7,@.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(X,`IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z-C<@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C,Y"B,Z('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-C$*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHV"FUS9VED(")#<F5A
M=&4@1F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHQ,S<*;7-G:60@(D-R96%T92!+97ES(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"FUS9VED(")#
M<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US
M96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@4W!A;2!F;VQD97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI
M;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G
M:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA
M=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E
M(&$@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O
M=')A<VAS96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N97<@=')A<V@@
M9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C@*;7-G:60@(B(*(D-R96%T92!F:6QT97)I;F<@<G5L97,@=&\@;W)G86YI
M>F4@>6]U<B!I;F-O;6EN9R!M86EL+"!S;W)T(&ET(&EN=&\@9F]L9&5R<RP@
M(@HB86YD(&1E;&5T92!S<&%M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,30*;7-G:60@(D-R96%T92!N97<@<W1A
M=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#0Y"FUS9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS
M97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U"FUS9VED(")#
M=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O;2!O=&AE
M<B!A8V-O=6YT<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Q"FUS9VED(")#=7-T;VUI>F4@:&]W('EO=2!S96YD(&UA:6PN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z,3<*;7-G:60@(D1A=%]E(@IM<V=S='(@(B(*
M"B,Z(&UE<W-A9V4N<&AP.C(V.2!T:')E860N<&AP.C$U,PIM<V=I9"`B1&%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4P
M"FUS9VED(")$96-L:6YE9"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,C8T"FUS9VED(")$96-L:6YE9#H@(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*;7-G:60@(D1E9F%U;'0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS
M96QE8W0N:6YC.C(Q"FUS9VED(")$969A=6QT(%-E87)C:"!&:65L9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$R"FUS9VED(")$
M969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,C(*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D
M:7)E8W1I;VXZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-3@*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HT,#`@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T
M96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E("5S(%!U
M8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G:60@(D1E;&5T
M92!#=7)R96YT($ME>7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z.0IM<V=I9"`B1&5L971E($9O;&1E<BAS*2(*;7-G
M<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR-S$*;7-G:60@(D1E;&5T92!396QE
M8W1E9"!&;VQD97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHT,@IM<V=I9"`B1&5L971E(%-T871I;VYE<GDB"FUS
M9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#`P"FUS9VED(")$96QE=&4@5FER
M='5A;"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@5FER
M='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE
M=&4@9F5T8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3D*;7-G:60@
M(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(D1E;&5T92!O;&0@;&EN:V5D
M(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B1&5L971E
M(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#4*;7-G
M:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&UE<W-A
M9V4N<&AP.C4P-B!M86EL8F]X+G!H<#HW,S0@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHR,`HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C,X('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L
M971E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C8S"FUS9VED(")$96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;7!O<V4N<&AP.C4W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('1H
M92!A='1A8VAM96YT(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@36]V:6YG($UE
M<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#<*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-30R"FUS9VED(")$96YY(')E<75E<W0@
M9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")$97-C96YD:6YG(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR
M,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8V"FUS9VED(")$97-C<FEP
M=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(D1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@8V]M<&]S92YP:'`Z-3@R"B,L('!H<"UF;W)M870*;7-G:60@(D1I
M9"!N;W0@871T86-H(%PB)7-<(B!A<R!T:&4@9FEL92!W87,@96UP='DN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C4*;7-G:60@
M(D1I;2!S:6=N871U<F5S/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Y"FUS9VED(")$:7-P
M;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD:6YG(&$@;65S<V%G93\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X,PIM<V=I9"`B
M1&ES<&QA>2!I;B!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I9"`B1&ES<&QA>2!P;W`M=7`@
M;F]T:69I8V%T:6]N(&]F(&YE=R!M86EL/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S0W"FUS9VED(")$:7-P;&%Y('1H92!<(D5M
M<'1Y(%-P86U<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,Y"FUS9VED(")$:7-P;&%Y('1H
M92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$Q
M"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M871C:"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM
M<V=I9"`B1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT,0IM<V=I9"`B
M1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T:&4@1G)O;3H@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-34*;7-G:60@(D1O('EO=2!W
M86YT('1O(&]P96X@=&AA="!F;VQD97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C,Q"FUS9VED(")$;VXG="!H879E(&%N
M(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C8*;7-G:60@(D1O;F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(Q-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU,@IM<V=I9"`B
M1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I;&4I(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS
M9VED(")$;W=N;&]A9"!&;VQD97(H<RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*;7-G:60@(D1O=VYL;V%D($9O
M;&1E<BAS*2!;+GII<"!F;W)M871=(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+T-O;G1E;G1S+G!H<#HR,38*;7-G:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R
M;6%T(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P-"!M86EL8F]X+G!H
M<#HW,3,@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(R('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHY"FUS9VED(")$<F%F="(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HS-S,*;7-G:60@(D1R869T(&9O;&1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHR,PIM<V=I9"`B
M1')A9G1S(&9O;&1E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$P.`IM<V=I9"`B12UM86EL($%D9')E<W,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,Q-@IM<V=I9"`B14Y$(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<T"FUS9VED(")%4E)/
M4CH@66]U<B!M97-S86=E(&-O=6QD(&YO="!B92!D96QI=F5R960N(@IM<V=S
M='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,2!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,3D*;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET($)L86-K
M;&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z,3,*;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHQ-@IM<V=I9"`B161I="!396%R8V@@475E<GDB"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#`Q('1E;7!L871E<R]S96%R8V@O:&5A
M9&5R+FEN8SHQ-PIM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO
M;B!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D:70@
M>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C$S"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-3`*;7-G
M:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F;W(@86-C97-S:6YG(&]T:&5R
M(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT
M97)S+W!R969S+FEN8SHR,PIM<V=I9"`B161I="!Y;W5R('=H:71E;&ES="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(S.0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("(B"@HC.B!L:6(O
M365S<V%G92YP:'`Z-CDS"B,L('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@
M86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S
M86=E+G!H<#HV-CD*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@
M5FER='5A;"!4<F%S:"!&;VQD97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H
M<RDB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C<R"FUS9VED(")%;7!T
M>2!396QE8W1E9"!&;VQD97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.34Q"FUS9VED(")%;7!T
M>2!?4W!A;2(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HY-#0*;7-G:60@
M(D5M<'1Y(%]4<F%S:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B
M16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C$@=&5M<&QA=&5S+W-M:6UE+VYO=&%C
M=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y
M/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`P"FUS
M9VED(")%;F%B;&4@;65S<V%G92!P<F5V:65W<S\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,W"FUS9VED(")%;F-R
M7WEP=&EO;B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL
M8F]X+VQE9V5N9"YI;F,Z,3@*;7-G:60@(D5N8W)Y<'1E9"(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$V(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HU,3@*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8U,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4S"FUS9VED(")%;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,Y-0IM<V=I9"`B16YD
M(&9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HS-3(*;7-G:60@(D5N9"!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YD(&UE
M<W-A9V4@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B
M16YT97(@4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O<W!A;7-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R
M('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N
M86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@
M(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI
M;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('1R87-H
M(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HV,3,*;7-G
M:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP
M.C$Y-"!C;VUP;W-E+G!H<#HQ,3<R('1H<F5A9"YP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@861D
M960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C$X('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M,0HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X,2!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HS.3`*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP
M:'`Z-S(@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38S"FUS9VED(")%
M<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0S,2!L
M:6(O24U!4"]#;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!C;VYN96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$P(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,#(*;7-G:60@(D5V96YT('-U8V-E<W-F
M=6QL>2!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S<Q"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-C@*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<W,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S(*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8Y"FUS
M9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M-#,X"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G
M:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F;VQD97)S
M+G!H<#HT,S@*;7-G:60@(D5X<&%N9"!&;VQD97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,X('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD($YA;65S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#4R"FUS9VED
M(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN9&]W(&%U=&]M871I
M8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-CD*;7-G:60@(D5X<&%N9"!T:&4@96YT:7)E
M(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@=&AE(&9O;&1E<G,@=FEE=S\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,30R('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y,@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#,@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5D:7)E8W0N:6YC.C$P,0HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E7V5X<&%N9"YJ<SHT.0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(B(*
M"B,Z(&QI8B])35`N<&AP.CDV,B!L:6(O24U0+G!H<#HY-C0*;7-G:60@(D9?
M971C:"!-86EL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M9F5T8VAM86EL+FEN8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS
M9VED(")&971C:"!-86EL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-3@*;7-G:60@(D9E=&-H($UA:6P@:6X@82!S97!A<F%T92!W
M:6YD;W<_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG
M(&]N/R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&971C:&5D(#$@;65S<V%G92!F<F]M("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L:6(O1F5T8VAM86EL
M+G!H<#HR.#D@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"FUS9VED(")&971C:&UA
M:6PZ("(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3,*;7-G
M:60@(D9E=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O24U0+G!H<#HY-C@*;7-G:60@(D9I7VQT97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-"!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHT,`IM<V=I9"`B1FEL92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S$*;7-G
M:60@(D9I;'1E<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHY"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X.`IM<V=I9"`B
M1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C$Q"FUS
M9VED(")&:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM
M<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]N;W1A8W1I=F4N:6YC.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C=&EV92(*
M;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS
M9VED(")&:6YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.30*;7-G:60@(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R("(B"@HC
M.B!M86EL8F]X+G!H<#HS,S`*;7-G:60@(D9I<G-T(%!A9V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")&;U]R
M=V%R9"(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR-3(@=&5M<&QA=&5S
M+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R
M($%C=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9F]L9&5R
M<RYP:'`Z,C@Y('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD*(SH@=&5M
M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L96-T+FEN8SHV"B,Z('1E;7!L
M871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,3`*;7-G:60@(D9O
M;&1E<B!.879I9V%T;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA
M<GDN<&AP.C,*;7-G:60@(D9O;&1E<B!3=6UM87)Y(@IM<V=S='(@(B(*"B,Z
M(&%C;"YP:'`Z,C,*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO="!E;F%B
M;&5D+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HT-PIM<V=I9"`B1F]L
M9&5R('5S92!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDU.`IM<V=I9"`B1F]R;6%T(&]F(&UE<W-A9V4@
M9&%T97,@:6X@=&AE(&UA:6QB;W@@=FEE=R!F;W(@;65S<V%G97,@9&%T960@
M=&]D87DB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z.#(P('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R
M("(B"@HC.B!C;VUP;W-E+G!H<#HX,#4*;7-G:60@(D9O<G=A<F0Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.#`*;7-G:60@(D9O<G=A<F1E
M9"!M97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4@9G)O;2`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`R
M"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(W
M"FUS9VED(")&<F]?;2(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR-S`@
M=&AR96%D+G!H<#HQ-30@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M.3<*(SH@;&EB+U-E87)C:"YP:'`Z-3@Y"FUS9VED(")&<F]M(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G:60@(D9R;VT@
M061D<F5S<R(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HX,3<@8V]M<&]S
M92YP:'`Z.#(Q"FUS9VED(")&=V0Z(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N
M<&AP.C$S,3$*;7-G:60@(D9W9#H@(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N
M<&AP.C$S,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1G=D.B`E=2!&;W)W87)D
M960@365S<V%G97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED
M(")'96YE<F%L($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C,W"FUS9VED(")'970@;VYL>2!N97<@;65S
M<V%G97,_("A)34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C,R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU-30*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<R.`IM<V=I9"`B
M1V\B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,S8*;7-G:60@(D=O('1O
M($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z-3`R"B,L('!H
M<"UF;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S
M-@IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N
M<&AP.C4T.2!L:6(O1FEL=&5R+G!H<#HQ,S$@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$Q
M,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,3,*(SH@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z,38T(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HQ,3D*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(SH@;&EB+TU)
M344O5FEE=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z-#(T"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z
M-#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<R"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HQ,C<*;7-G:60@(DA%4D4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C,Q(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HQ,C`*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C@P"FUS9VED
M(")(5$U,(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C(V,`IM<V=I9"`B
M2%1-3"!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHU
M"FUS9VED(")(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O<VEN
M9SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U-@IM
M<V=I9"`B2&ED9&5N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-34*;7-G:60@(DAI9&1E;B!I;B!4:')E860@5FEE=R(*;7-G<W1R
M("(B"@HC.B!M86EL8F]X+G!H<#HS-3(*;7-G:60@(DAI9&4@1&5L971E9"(*
M;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR.#0*;7-G:60@(DAI9&4@56YS
M=6)S8W)I8F5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(Y,@IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HS,#0@;6%I;&)O>"YP:'`Z-S$X('1E;7!L871E<R]M86EL8F]X
M+VQE9V5N9"YI;F,Z,3(*;7-G:60@(DAI9V@@4')I;W)I='DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDQ"FUS9VED
M(")(:6=H97-T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.#4*;7-G:60@(DAO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T=&%C
M:&UE;G1S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3`T"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E9"!L:6YE<R!I;B!A
M(')E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z
M,3,T"FUS9VED("))34%0(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3(Y"FUS9VED("))34%0("A!=71O($1E=&5C="!0<F]T;V-O
M;',I(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,SDQ"B,L
M('!H<"UF;W)M870*;7-G:60@(DE-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N
M;F5C=&EO;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C4@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB"FUS9W-T<B`B(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-3(*;7-G:60@(DE-05`@;W9E
M<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V-@IM<V=I9"`B24U!4"!O
M=F5R(%-33"`H<V5L9BUS:6=N960I(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z,S8X"FUS9VED("))34%0('-E<G9E<B!C;&]S960@=&AE
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,38T(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS9VED
M("))34%0+"!N;R!43%,B"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HT.0IM<V=I9"`B24U!4"]03U`S($UA:6P@4V5R=F5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I9"`B268@
M=7-I;F<@4U-,(&]R(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS
M<VP@97AT96YS:6]N(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3(*;7-G:60@(DEF('EO
M=2!C;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL
M;"!B92!L;W-T(2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#,*;7-G:60@(DEG;F]R
M92!!;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E
M:6UA9V4N:6YC.C@*;7-G:60@(DEM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C`*;7-G:60@(DEM<&]R="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#4@
M=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-0IM<V=I9"`B26UP;W)T
M($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,Y
M"FUS9VED("));7!O<G0@2V5Y<&%I<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PIM<V=I9"`B26UP;W)T($UE<W-A
M9V5S(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z-#$*;7-G:60@(DEM<&]R="!0
M1U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z.3$*;7-G:60@(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS
M9VED("));7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B
M26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O
M<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHT,@IM<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("))
M;7!O<G0@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@
M4R]-24U%($ME>2(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@
M(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT
M;R!F;VQD97(@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P-2!M
M86EL8F]X+G!H<#HW,C@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,38@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS9VED("))
M;7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M,34Q"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S
M(&9R;VT@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-C8*;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z,S8U('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C
M="YI;F,Z,30@;&EB+T9O;&1E<BYP:'`Z.#4*(SH@;&EB+TE-4"YP:'`Z.#,R
M(&QI8B])34%0+U1R964N<&AP.C$Q.2!L:6(O24U!4"]4<F5E+G!H<#HR,C(*
M;7-G:60@(DEN8F]X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3(*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y(&]F('1H
M92!H96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S
M86=E(&EN(&$@<F5P;'D_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]N;W1I9FEC871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C$S,`IM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E<R!0=6)L:6,@
M2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM
M<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T92!+97DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E
M<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0Y.0HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT
M<RYJ<SHU-@IM<V=I9"`B26YL:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));G-E<G0@0V5R=&EF
M:6-A=&4@2&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!U8FQI8R!0
M1U`@2V5Y($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHU"FUS9VED("));G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$S
M"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP
M;VYE;G0N(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4W-"!M86EL8F]X
M+G!H<#HV,C$*;7-G:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!2
M96UO=&4@36%I;&)O>"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ-3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!C:&%R86-T97(@:6X@92UM
M86EL(&%D9')E<W,Z("5S+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z-S@@
M<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K97DB"FUS9W-T<B`B(@H*(SH@
M<&=P+G!H<#HQ.3(*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!R:79A
M=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$V-PIM<V=I9"`B26YV
M86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,@IM<V=I9"`B26YV97)T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4Y,0IM<V=I9"`B2T(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$Q,PIM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A
M=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I
M;G5E('=I=&@@:V5Y("(*(F=E;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C,W"FUS9VED(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I
M;&4@=7!L;V%D(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N
M;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE
M9"!T;R!A9&0@>6]U<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P
M+G!H<#HS,30*;7-G:60@(DME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,34*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.34*;7-G:60@(DQA<W0@36%I
M;&)O>"!086=E(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C,T,PIM<V=I
M9"`B3&%S="!086=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C4T-PIM<V=I9"`B3&EN:R!!='1A8VAM96YT<S\B"FUS
M9W-T<B`B(@H*(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP
M.C$P.#0*;7-G:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3$P,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("),:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W,0IM<V=I9"`B(@HB
M3&ES="!A;&P@8V]N=&%C=',@=VAE;B!L;V%D:6YG('1H92!C;VYT86-T<R!S
M8W)E96X_("AI9B!D:7-A8FQE9"P@>6]U('=I;&P@(@HB;VYL>2!S964@8V]N
M=&%C=',@=&AA="!Y;W4@<V5A<F-H(&9O<B!E>'!L:6-I=&QY*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@R"FUS9VED("),:7-T
M:6YG(&EN('1H92!(96%D97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C,P"FUS9VED("),;V-A;"!-86EL8F]X.B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C<Q"FUS
M9VED("),;V-A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(R-`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6UM87)Y+G!H<#HQ,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&]G(&EN('1O("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3,X"FUS9VED("),;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-`IM
M<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C,P-B!M86EL
M8F]X+G!H<#HW,C$@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM
M<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-0IM<V=I9"`B3&]W97-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#0*;7-G
M:60@(DUA8VEN=&]S:"!&:6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]P87-S<&AR87-E+FEN8SHQ,PIM<V=I9"`B36%I;"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*;7-G:60@(DUA:6P@4')E
M=FEE=W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV
M97)?<V5L96-T+FEN8SHQ-@IM<V=I9"`B36%I;"!S97)V97(@='EP92!T;R!C
M;VYN96-T('1O.B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS-CD@9F]L
M9&5R<RYP:'`Z,S@S"FUS9VED(")-86EL8F]X(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*;7-G:60@(DUA:6QB;W@@86YD($9O
M;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL($UE<W-A
M9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")-87)K($%L;"!-97-S
M86=E<R!I;B!&;VQD97(@87,@56YS965N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-2!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-87)K(&%S.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C,X"FUS9VED(")-87)K
M(&1I9F9E<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C
M;VQO<G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT,`IM<V=I9"`B36%R:R!M97-S86=E<R!A<R!S965N/R`H24U!
M4"!O;FQY*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C0V"FUS9VED(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHT.0IM<V=I9"`B36%T8V@@
M06QL(%%U97)I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C0U"FUS9VED(")-871C:"!!;GD@475E<GDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`U"FUS9VED
M(")-87AI;75M($%T=&%C:&UE;G0@4VEZ92(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HW.0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@1F]L9&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M.#<*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0X,PIM<V=I9"`B36%X:6UU;2!T;W1A;"!A='1A8VAM96YT('-I>F4@
M<F5A8VAE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R
M<RYP:'`Z,PIM<V=I9"`B365N=2!&;VQD97(@3&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,S0R"FUS9VED(")-97-S86=E(@IM<V=S='(@
M(B(*"B,Z(&-O;7!O<V4N<&AP.C4Y."!C;VUP;W-E+G!H<#HV,C4@8V]M<&]S
M92YP:'`Z-C<Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B365S
M<V%G92!#;VUP;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3`V"FUS9VED(")-97-S86=E($1A=&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`S"FUS9VED(")-97-S86=E($]P=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS,#(*;7-G:60@(DUE<W-A9V4@
M4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,3`*;7-G:60@(DUE<W-A9V4@4VEZ92(*;7-G<W1R("(B"@HC.B!M97-S86=E
M+G!H<#HS.3$*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S<V%G92!6:65W
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M-@IM<V=I9"`B365S<V%G92!F;&%G<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E(&9O;&1E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T<B`B(@H*(SH@;6%I
M;&)O>"YP:'`Z-C8R"FUS9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*
M;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HV-3,*;7-G:60@(DUE<W-A9V4@
M:7,@96YC<GEP=&5D(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C8T.`IM
M<V=I9"`B365S<V%G92!I<R!S:6=N960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-E87)C:"]H96%D97(N:6YC.C,V"FUS9VED(")-97-S86=E(&UA=&-H
M97,B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z.#8T(&-O;7!O<V4N<&AP
M.C@W,0IM<V=I9"`B365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,3$R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A
M=F5D('1O("5S(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$Q.#$@8V]M
M<&]S92YP:'`Z,3$X.0IM<V=I9"`B365S<V%G92!S96YT('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,`IM
M<V=I9"`B365S<V%G97,@<&5R('!A9V4@:6X@=&AE(&UA:6QB;W@@=FEE=RXB
M"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S$P"FUS9VED(")-97-S86=E
M<R!T;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,CD*
M;7-G:60@(DUO9&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]E>'!A;F0N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA
M;B!O;F4@861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO
M=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C
M="YI;F,Z,S$V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8P-@IM<V=I9"`B36]V92!S<&%M(&UE<W-A
M9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T;R!)
M3D)/6"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M-3`*;7-G:60@(DUO=F4@=&\@9F]L9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-`IM<V=I9"`B36]V92!U
M<"(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N
M<&AP.C$R-PIM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E(@IM<V=S='(@
M(B(*"B,Z('1H<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3<*;7-G:60@(DUU
M;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O9&5F875L='-E87)C:'-E;&5C="YI;F,Z.`IM<V=I9"`B3D].12(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M-#@@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR"FUS9VED(").3U1%(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,X(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV.#,*;7-G:60@(DYA;64B"FUS9W-T<B`B(@H*(SH@<&=P
M+G!H<#HQ,#8*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;FYO="!B92!E
M;7!T>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S<Q"FUS9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8W
M"FUS9VED(").979E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-38P"FUS9VED(").979E<B!S879E(&%T=&%C:&UE;G1S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ,C0*;7-G:60@(DYE
M=R(*;7-G<W1R("(B"@HC.B!L:6(O24U0+G!H<#HU.34*;7-G:60@(DYE=R!&
M;VQD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X
M"FUS9VED(").97<@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,C$@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(R"B,Z(&QI8B]"
M;&]C:R]T<F5E7V9O;&1E<G,N<&AP.C0V"FUS9VED(").97<@365S<V%G92(*
M;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HW-S`@;&EB+TU)344O2&5A9&5R
M<RYP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3,S"FUS9VED(").97AT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!M86EL
M8F]X+G!H<#HS-#$*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S@@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-34Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HR,C(*
M;7-G:60@(DYO($-E<G1I9FEC871E(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@
M16YC<GEP=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3D*;7-G:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R("(B"@HC
M.B!M86EL8F]X+G!H<#HS-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ,S,*;7-G:60@(DYO(%!'
M4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S;VYA;"!#97)T
M:69I8V%T92!0<F5S96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EL8F]X+G!H
M<#HS,S,*;7-G:60@(DYO(%!R979I97<@5&5X="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$U"FUS9VED(").;R!0=6)L:6,@
M2V5Y<R!&;W5N9"(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,30W"FUS9VED
M(").;R!3+TU)344@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDR"FUS9VED(").;R!A='1A
M8VAM96YT<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T-R>7!T+U--24U%
M+G!H<#HQ-#`*;7-G:60@(DYO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@
M:6X@=&AE('!U8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-S$@
M86-L+G!H<#HY-PIM<V=I9"`B3F\@9F]L9&5R('-E;&5C=&5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,30Y"FUS9VED(").;R!F
M;VQD97)S(&%R92!B96EN9R!C:&5C:V5D(&9O<B!N97<@;6%I;"XB"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C`Q(&QI8B]&;VQD97(N<&AP.C0V-R!L
M:6(O1F]L9&5R+G!H<#HU,3<*;7-G:60@(DYO(&9O;&1E<G,@=V5R92!S<&5C
M:69I960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$U
M-0IM<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S86=E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,34R"FUS9VED(").;R!F
M;VQD97)S('=I=&@@=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS,S8*;7-G:60@(DYO(&UE<W-A9V4@8F]D>2!T97AT
M(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-38X"FUS9VED
M(").;R!M97-S86=E(')E='5R;F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I
M;&)O>"YP:'`Z,S<U"FUS9VED(").;R!M97-S86=E<R!M871C:&5D('EO=7(@
M<V5A<F-H+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$X-0IM<V=I9"`B3F\@
M<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("(B
M"@HC.B!P9W`N<&AP.C$V,0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI
M8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ.3<*
M;7-G:60@(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP;W)T
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,C0V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y.0IM<V=I9"`B(@HB3F\@
M<&5R<V]N86P@<')I=F%T92!K97D@97AI<W1S('-O('1H92!M97-S86=E(&ES
M('5N86)L92!T;R!B92!D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z('-P96QL
M:6YG+G!H<#HR,C`*;7-G:60@(DYO('-P96QL8VAE8VMI;F<@<')O9W)A;2!C
M;VYF:6=U<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z-#@*;7-G:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`P
M"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4V,`IM<V=I9"`B3F\@<W5P<&]R=&5D($E-05`@875T
M:&5N=&EC871I;VX@;65T:&]D(&-O=6QD(&)E(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!A8VPN<&AP.C8W(&%C;"YP:'`Z.3,*;7-G:60@(DYO('5S97(@<W!E
M8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S`T"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,2!T96UP;&%T97,O<')E
M9G,O9F]L9&5R<V5L96-T+FEN8SHR-`HC.B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C0P('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,U"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M-"!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV-C$*;7-G:60@(DYO;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDS"FUS9VED
M(").;W)M86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Y"FUS
M9VED(").;W0@1&5L971E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$R('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHT,@IM<V=I9"`B3F]T($1R869T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S0*;7-G:60@(DYO="!);7!O<G1A;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I9"`B3F]T(%!E
M<G-O;F%L(@IM<V=S='(@(B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L
M:6(O0W)Y<'0O4TU)344N<&AP.C$S-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T
M.0IM<V=I9"`B3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV-PIM<V=I9"`B3F]T(&1E
M;&5T960@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHU,0IM<V=I9"`B3F]T(&EM<&]R=&%N="!M97-S86=E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?
M;&]G:6XN<&AP.C<Q"FUS9VED(").;W1E('1H870@=&AI<R!C86X@=&%K92!S
M;VUE('1I;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8P-`IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R("(B"@HC.B!A='1A8VAM96YT
M+G!H<#HX.0IM<V=I9"`B3F]T:69I8V%T:6]N.B!,:6YK960@871T86-H;65N
M="!D;W=N;&]A9&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S<*;7-G:60@(DYU;6)E<B!O9B!M;VYT:',@=&\@:V5E<"!O;&0@
M;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*;7-G:60@(DYU
M;6)E<B!O9B!O;&0@<V5N="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE
M=&EN9R!M;VYT:&QY+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(U-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4@=&5M<&QA=&5S+W-M:6UE
M+VEM<&]R=%]K97DN:6YC.C0Y"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z-#@*;7-G:60@(D]2(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,34*;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?
M;6]N=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B
M96EN9R!P=7)G960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y
M+G!H<#HR.`IM<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E
M860@;65S<V%G97,@:6X@=&AE;3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHX,0IM<V=I9"`B3VYL>2!O;F4@9F]L
M9&5R('-H;W5L9"!B92!S96QE8W1E9"!F;W(@=&AI<R!A8W1I;VXN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ,"!T96UP;&%T97,O;65N
M=2YI;F,Z,S`*;7-G:60@(D]P96X@1F]?;&1E<B(*;7-G<W1R("(B"@HC.B!F
M;VQD97)S+G!H<#HT,#@*;7-G:60@(D]P96YE9"!&;VQD97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P,`IM<V=I9"`B3W!T
M:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL+G!H
M<#HT,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H97(@36%I
M;"!!8V-O=6YT<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3D*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$U,`IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(P,`IM<V=I9"`B3W5T8F]U;F0@
M4V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S
M92YI;F,Z,38@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38T"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(P,R!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HR.#D*;7-G:60@(E!'4"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C<*;7-G:60@(E!'4"!%;F-R>7!T($UE
M<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,S,U"FUS9VED(")0
M1U`@17)R;W(Z("(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS,30*;7-G
M:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P
M<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<&=P
M+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4U"FUS9VED(")01U`@4&5R
M<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-S(*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E>'0B"FUS9W-T<B`B
M(@H*(SH@<&=P+G!H<#HQ-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U
M8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D
M960N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,C0Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,30*;7-G:60@(E!'4"!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*;7-G
M:60@(E!'4"!3:6=N($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY"FUS9VED(")01U`@4VEG;B]%
M;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ.3@*;7-G
M:60@(E!'4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S
M='(@(B(*"B,Z('!G<"YP:'`Z,3<S"FUS9VED(")01U`@<'5B;&EC(&ME>2!S
M=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M9W`O;F]T86-T:79E+FEN8SHT"FUS9VED(")01U`@<W5P<&]R="!I<R!D:7-A
M8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,C`W"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N
M;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@
M:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HR.30*;7-G:60@(B(*(E!'4"!S=7!P
M;W)T(&ES(&YO="!C=7)R96YT;'D@86-T:79E('-O('1H92!M97-S86=E(&ES
M('5N86)L92!T;R!B92!D96-R>7!T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHR"FUS9VED("(B"B)01U`@<W5P<&]R="!R97%U
M:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S
M97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O
M=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@
M4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G
M<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B
M4$]0,R(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P
M,`IM<V=I9"`B4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R
M("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Q-PIM<V=I9"`B4$]0
M,R!O=F5R(%-33"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R
M=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,38X"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3$*;7-G
M:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]H96%D97(N:6YC.C(R"B,L('!H<"UF;W)M870*;7-G:60@(E!A9V4@
M)60@;V8@)60B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@Y,@IM<V=I9"`B4&%G92!W:71H('1H92!&:7)S="!5;G-E96X@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DS"FUS
M9VED(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-#,*;7-G
M:60@(E!A<G0H<RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$R,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!9V%I
M;BDB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(S,2!P9W`N<&AP.C,P-@IM
M<V=I9"`B4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@=6YL;V%D960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ."!T
M96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C(Y"FUS9VED(")087-S<&AR
M87-E.B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$P.`IM<V=I9"`B4&%S<W!H
M<F%S97,@8V%N;F]T(&)E(&5M<'1Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z
M,3$P"FUS9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L
M871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$Y,0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"FUS9VED(")0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S
M='(@(B(*"B,Z(&%C;"YP:'`Z-S4@86-L+G!H<#HQ,#$*;7-G:60@(E!E<FUI
M<W-I;VYS(&9O<B!T:&ES('5S97(@8V%N;F]T(&)E(&-H86YG960N(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HV.3<@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O;F%L
M($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$V"FUS9VED
M(")097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$R,PIM<V=I9"`B4&5R<V]N86P@
M4$=0(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z
M('-M:6UE+G!H<#HR,#,*;7-G:60@(E!E<G-O;F%L(%,O34E-12!C97)T:69I
M8V%T97,@3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP
M.C$R.`IM<V=I9"`B4&5R<V]N86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C(*;7-G:60@(E!L86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L
M:65S(&%N9"!F;W)W87)D<S\B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z
M,C4X"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#@*;7-G:60@(B(*
M(E!L87D@<V]U;F0@;VX@;F5W(&UA:6P_("!4:&ES(')E<75I<F5S('EO=7(@
M8G)O=W-E<B!T;R!S=7!P;W)T(&5M8F5D9&5D("(*(G-O=6YD(&9I;&5S+B`@
M06QM;W-T(&%L;"!D;R!O;B!7:6YD;W=S(&%N9"!-86,L(&)U="!O=&AE<B!P
M;&%T9F]R;7,@=VEL;"`B"B)R97%U:7)E(&$@<&QU9VEN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@9F]L9&5R.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-"!T96UP
M;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-@IM<V=I9"`B4&QE87-E
M(&5N=&5R('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S.0IM<V=I
M9"`B4&QE87-E(&5N=&5R('1H92!N97<@;F%M93HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO
M=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB
M96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A
M<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@=VEL
M;"!O;FQY(&YE960@(@HB=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@
M<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z(')E8V]M<&]S92YP:'`Z
M.38*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE(&-O
M;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG("(*
M(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN('!O
M<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G86EN
M(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K965P
M(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@240N
M(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S$*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C<*;7-G:60@(E!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP
M.C$P-B!L:6(O24U0+G!H<#HT-C,*;7-G:60@(E!L96%S92!R97-O;'9E(&%M
M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHV,PIM<V=I9"`B4&QE
M87-E('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@=&AI<R!A
M8W1I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O:F%V87-C
M<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@870@;&5A<W0@;VYE
M(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V9O;&1E<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@
M;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"FUS9VED
M(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@<FEG
M:'0Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD:7-T.C0Q"FUS
M9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,30*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U
M<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B(@H*(SH@<VUI;64N
M<&AP.C(S-R!P9W`N<&AP.C(U,R!F:6QT97)P<F5F<RYP:'`Z,SD*;7-G:60@
M(E!R969E<F5N8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U<R!-97-S86=E
M(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C,S,@IM<V=I9"`B4')E=FEO
M=7,@4&%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X"FUS9VED(")0<FEO
M<FET>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME
M>2YI;F,Z-S8*;7-G:60@(E!R:79A=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP
M="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T
M;R!.3R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X
M"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E
M;G0[(&1E9F%U;'0@=&\@6453(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHQ,`IM<V=I9"`B4')O=&]C;VPZ(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0S,`IM<V=I9"`B4'5B;&EC
M(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D:7-A8FQE9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHW"FUS9VED
M(")0=7)?9V4@1&5L971E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M7V1E;&5T960N:6YC.C<*;7-G:60@(E!U<F=E($1E;&5T960B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C0*;7-G:60@
M(E!U<F=E($9O;&1E<BAS*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@
M(E!U<F=E(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H
M:7,@86UO=6YT(&]F(&1A>7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#8*;7-G:60@(E!U<F=E(&]L9"!M97-S86=E<R!I;B!T
M:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N
M8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4'5R9VEN9R`E9"!M97-S86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N
M<&AP.C8S"FUS9VED(")0=7)G:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O
M;&1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN
M8SHQ-PHC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z("4N,F9-
M0B`O("4N,F9-0B`@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W%U;W1A+W%U;W1A+FEN8SHR,0HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T
M82!S=&%T=7,Z("4N,F9-0B`O($Y/($Q)34E4(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B475O=&$@<W1A='5S.B!.3R!,24U)5"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3`P"B,L('!H<"UF;W)M870*;7-G:60@(E%U
M;W1I;F<@)68Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C
M=&EO;G,N:6YC.C(Y"FUS9VED(")296)U:6QD($9O;&1E<B!4<F5E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP.C8Q-PIM<V=I9"`B4F5C96EV960@
M3VXB"FUS9W-T<B`B(@H*(SH@;&EB+U-E87)C:"YP:'`Z-C(U"FUS9VED(")2
M96-E:79E9"!3:6YC92(*;7-G<W1R("(B"@HC.B!L:6(O4V5A<F-H+G!H<#HV
M,C$*;7-G:60@(E)E8V5I=F5D(%5N=&EL(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D
M:7)E8U]T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8W0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,`IM<V=I9"`B
M4F5D:7)E8W0@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HX
M,C<*;7-G:60@(E)E9&ER96-T('1H:7,@;65S<V%G92(*;7-G<W1R("(B"@HC
M.B!C;VUP;W-E+G!H<#HX.#`*;7-G:60@(E)E9&ER96-T:6YG(&9A:6QE9"XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W,PIM<V=I
M9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA:6QB;W@O:&5A
M9&5R+FEN8SHT"FUS9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I97<B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R."!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-30W"FUS9VED(")296UE;6)E<B!T:&4@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.38X"FUS9VED(")296UE;6)E<B!T:&4@;&%S="!V
M:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHR-PIM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E
M($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0IM<V=I9"`B4F5M;W9E('-O=7)C
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHX"FUS9VED(")296YA;64@1F]L9&5R*',I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E;F%M92!S96YT+6UA
M:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z-#(U"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M;F%M:6YG(%PB)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B4F5P;%]Y('1O($QI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B
M4F5P;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C,Q,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#$P"FUS9VED(")297!L
M>2!396YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O($%L;"(*;7-G<W1R
M("(B"@HC.B!C;VUP;W-E+G!H<#HW-S$*;7-G:60@(E)E<&QY('1O($%L;#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C$P"FUS9VED(")297!L>2!T;R!,:7-T(@IM<V=S='(@(B(*"B,Z
M(&-O;7!O<V4N<&AP.C<W,PIM<V=I9"`B4F5P;'D@=&\@3&ES=#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C$S"FUS9VED(")297!L>2!T;R!?06QL(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU,S`@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4S.0HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30Y"FUS9VED
M(")297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,W"FUS9VED(")297!L
M>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-@IM<V=I9"`B4F5P
M;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!M97-S86=E+G!H<#HR-S0*;7-G:60@(E)E<&QY+51O(@IM
M<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,C`*;7-G:60@(E)E<&QY
M+51O.B`B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z-S8Y"FUS9VED(")2
M97!L>3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,U('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(S"FUS9VED(")297!O<G0@87,@
M4W!A;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHS.#0*;7-G:60@(E)E<75E<W0@82!?4F5A9"!296-E:7!T(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S,*;7-G:60@(E)E
M<75E<W0@<F5A9"!R96-E:7!T<S\B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP
M:'`Z,3@X"FUS9VED(")297%U97-T960@;65S<V%G92!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.3(*;7-G
M:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O;6%I;BYI;F,Z,30P('1E;7!L871E<R]S96%R8V@O:&5A
M9&5R+FEN8SHR.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R"FUS9VED
M(")297-E="(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3$V"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R("(B"@HC.B!R96-O;7!O<V4N
M<&AP.CDW"FUS9VED(")297-U;64@>6]U<B!S97-S:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT-`IM<V=I9"`B
M4F5T=7)N('1O(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,S$@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8Y"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C,Q"FUS9VED(")2971U
M<FX@=&\@1F5T8V@@36%I;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E
M+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP
M;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38S('1E;7!L871E<R]A8VPO86-L
M+FEN8SHQ-S4*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,#<*;7-G:60@(B(*(E)E='5R
M;B!T;R!T:&4@;6%I;&)O>"!L:7-T:6YG(&%F=&5R(&1E;&5T:6YG+"!M;W9I
M;F<L(&]R(&-O<'EI;F<@82!M97-S86=E/R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C@S"FUS9VED(")2;VQE(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30R(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z-#(U"FUS9VED(")3+TU)344B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,@IM<V=I9"`B4R]-24U%
M($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS
M-S$*;7-G:60@(E,O34E-12!%<G)O<CH@(@IM<V=S='(@(B(*"B,Z(&-O;7!O
M<V4N<&AP.C,U,`IM<V=I9"`B4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A
M<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"FUS9VED(")3+TU)344@3W!T:6]N
M<R(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z-#8*;7-G:60@(E,O34E-12!0
M87-S<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z-30*;7-G:60@(E,O34E-12!097)S;VYA;"!+97EP86ER
M('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4R]-24U%(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U
M;&QY(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('-M:6UE+G!H<#HQ-3@*;7-G
M:60@(E,O34E-12!0=6)L:6,@2V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,`IM<V=I
M9"`B4R]-24U%(%!U8FQI8R!+97ER:6YG(@IM<V=S='(@(B(*"B,Z('-M:6UE
M+G!H<#HR,#<*;7-G:60@(E,O34E-12!0=6)L:6,O4')I=F%T92!+97EP86ER
M('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,PIM<V=I9"`B4R]-24U%(%-I
M9VX@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M;F-R>7!T7VQI<W0N:6YC.C$T"FUS9VED(")3+TU)344@4VEG;B]%;F-R>7!T
M($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VYO=&%C
M=&EV92YI;F,Z-`IM<V=I9"`B4R]-24U%('-U<'!O<G0@:7,@9&ES86)L960@
M;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,C0Q"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N
M;W0@8W5R<F5N=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE
M('1O(&)E("(*(F1E8W)Y<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HQ-S,*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T
M(&ES(&YO="!E;F%B;&5D('-O('1H92!C;VYT96YT<R!O9B!T:&ES('-I9VYE
M9"!M97-S86=E(&-A;FYO="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3
M+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S
M:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*
M(E,O34E-12!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@
M=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O
M(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@
M<V5T=&EN9R!O<B!E;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N
M;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C`T"FUS9VED(")33510(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(U,PIM<V=I9"`B4U]U
M8FIE8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S8Q"FUS9VED(")385]V92!A(&-O<'D@:6X@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM
M<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS,#0@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W"FUS9VED(")3879E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4S-`IM<V=I9"`B4V%V92!!='1A8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@
M<V5N="UM86EL(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#(X"FUS9VED(")3879E($1R869T(@IM<V=S='(@(B(*"B,Z('-A
M=F5I;6%G92YP:'`Z-#(*;7-G:60@(E-A=F4@26UA9V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(R.`IM<V=I9"`B4V%V92!);6%G
M92!I;B!'86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC
M.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,R!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN
M8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,`IM<V=I9"`B4V%V92!3=&%T
M:6]N97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0R.`IM
M<V=I9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")3879E(&%S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G:60@
M(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-C$*;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A
M=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,C,*;7-G
M:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(E-A=F4@
M<V5N="!M86EL/R(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C8S"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I;&5D+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y.2!T96UP;&%T
M97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,Z(&QI8B]";&]C:R]T<F5E7V9O
M;&1E<G,N<&AP.C4T"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X
M+VAE861E<BYI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H("5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C`*;7-G
M:60@(E-E87)C:"!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z
M,C4X"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$T('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,S$*;7-G:60@(E-E96XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHY"FUS9VED(")396QE8W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<P
M"FUS9VED(")396QE8W0@06YO=&AE<B!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B4V5L96-T
M(&$@9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD
M<RYI;F,Z,3`*;7-G:60@(E-E;&5C="!A(&9I96QD(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-0IM<V=I9"`B4V5L
M96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R
M8V5S(&9O<B!A9&1I;F<@86YD('-E87)C:&EN9R!F;W(@861D<F5S<V5S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS
M9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S;W5R8V5S96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L96-T(&%L;"!F:65L
M9',@=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI
M;F,Z,C$*;7-G:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C="!N
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM
M86=E+FEN8SHY"FUS9VED(")396QE8W0@=&AE(&=A;&QE<GD@=&\@<V%V92!T
M:&4@:6UA9V4@:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I
M;"!S97)V97(@='EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M<V]U<F-E<V5L96-T+FEN8SHS,#D*;7-G:60@(E-E;&5C=&5D($%D9')E<W,@
M8F]O:W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DW"FUS9VED(")3
M96YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHT,C8*;7-G:60@(E-E;F0@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C$R-@IM<V=I9"`B
M4V5N9"!M97-S86=E('=I=&AO=70@82!3=6)J96-T/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CDR"FUS9VED(")396YD(')E860@
M<F5C96EP="!W:&5N(')E<75E<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R
M("(B"@HC.B!F;VQD97)S+G!H<#HS-S@*;7-G:60@(E-E;G0@;6%I;"!F;VQD
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L
M96-T+FEN8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S,@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHQ-#4*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHQ-3(*;7-G:60@(E-E<G9E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C,*;7-G:60@(E-E<G9E<B!A;F0@1F]L9&5R($EN
M9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHR,PIM<V=I9"`B4V5R=F5R.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E="!P<F5F97)E;F-E
M<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@86YD(&1E;&5T92!M
M97-S86=E<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4R.0IM<V=I9"`B4V5T('1H92!8+5!R:6]R:71Y(&AE861E<B!W:&5N(&-O
M;7!O<VEN9R!M97-S86=E<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Q"FUS9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@IM<V=I9"`B4VAA<F4@;6%I
M;"!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET:"!O=&AE
M<B!U<V5R<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8U-PIM<V=I9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q=6]T960@
M=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@8V%N(&)E
M("(*(G1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-PIM<V=I9"`B4VAO
M=6QD('1H92!B;V1Y(&]F('1E>'0O<&QA:6X@;65S<V%G97,@8F4@<V-A;FYE
M9"!F;W(@4$=0(&1A=&$_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@
M8F4@8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I9"`B4VAO=6QD('EO=7(@
M4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E
M<R!B>2!D969A=6QT/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.CDR"FUS9VED(")3:&]W($%L;"!&;VQD97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8W"FUS9VED
M(")3:&]W($%L;"!(96%D97)S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP
M.C,U,`IM<V=I9"`B4VAO=R!$96QE=&5D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET
M960@2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H
M96%D97)S+FEN8SHW,`IM<V=I9"`B4VAO=R!-86EL:6YG($QI<W0@26YF;W)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHY,@IM<V=I9"`B4VAO=R!/;FQY(%-U8G-C<FEB960@1F]L9&5R<R(*;7-G
M<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR.#0*;7-G:60@(E-H;W<@56YS=6)S
M8W)I8F5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.38*;7-G:60@(E-H;W<@86X@:6-O;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@
M871T86-H;65N=',@9G)O;2!M97-S86=E<S\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDY,0IM<V=I9"`B4VAO=R!L96=E;F0@:6X@
M=&AE(&UA:6QB;W@@=FEE=S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@R.0IM<V=I9"`B4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D
M(&UE<W-A9V5S(&]N;'D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,S<*;7-G:60@(E-H;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-C8*;7-G
M:60@(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDX"FUS
M9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C4T"FUS9VED(")3:&]W('1H92!F:6QT97(@
M:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W-U;6UA<GDN<&AP.C,Q"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M
M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-30*;7-G:60@(E-H;W=N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#(*;7-G:60@(E-I
M7WIE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI
M;F,Z,3<*;7-G:60@(E-I9VYE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C$Q"FUS9VED(")3;W)T(&)Y($%R<FEV86PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B
M4V]R="!B>2!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C8*;7-G:60@(E-O<G0@8GD@1G)O;2!!
M9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z-#$*;7-G:60@(E-O<G0@8GD@365S<V%G92!3:7IE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,S8*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q
M"FUS9VED(")3;W)T(&)Y(%1H<F5A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q"FUS9VED(")3;W)T
M(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-P86US96QE8W0N:6YC.C(S"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0T"FUS
M9VED(")3<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@<V5A<F-H
M+G!H<#HQ,S<*;7-G:60@(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;FYO
M="!B92!E9&ET960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,T,0IM<V=I9"`B4W!E;&P@0VAE8VLB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED
M(")3<&5L;"!#:&5C:V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+W-P96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@(E-P96QL
M:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#<@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4P.0HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C0R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#0*;7-G
M:60@(E-T87)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,P
M.0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@;F%M
M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A
M=&EO;F5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8X,PIM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+T-O;G1E;G1S+G!H<#HR,SD*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,0IM<V=I9"`B
M4W1R:7`@;&EN96)R96%K<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS-PIM<V=I9"`B4W5B7VIE8W0B
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C<U('1H<F5A9"YP:'`Z,34U
M('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C4*(SH@;&EB+U-E
M87)C:"YP:'`Z-C`U"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#D*;7-G:60@(E-U8FIE8W0@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS,#8@=&5M<&QA=&5S+W-A=F5I
M;6%G92]S879E:6UA9V4N:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P87-S
M<&AR87-E+FEN8SHR,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C,Q
M"FUS9VED(")3=6)M:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,3$*;7-G:60@(E-U8G-C<FEB92!T;R!&;VQD97(H
M<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS
M.#4@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,SDS"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C@W"FUS9VED(")3=6-C97-S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX-@IM<V=I9"`B
M4W5G9V5S=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8U.2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Q"FUS9VED
M(")3=6UM87)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C,Y-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M.3@*;7-G:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,SDY"FUS9VED
M(")3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.3D*;7-G:60@(E-W:71C
M:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Q-`IM<V=I9"`B5&5?>'0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(W,`IM
M<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4X-@IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T(')E
M<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<U-`IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5R;7,@;V8@4V5R=FEC92!F:6QE(&YO
M="!S<&5C:69I960@:6X@8V]N9BYP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,P"FUS9VED(")497AT(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#,*;7-G:60@(E1H
M92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME
M9#HB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,C4*;7-G
M:60@(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P
M<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0
M;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q
M"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@
M8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I
M;'!R969S+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N
M="!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9F5T
M8VAM86EL<')E9G,N<&AP.C<T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A
M8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@
M871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT('=A<R!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW,0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP
M.C0R"FUS9VED(")4:&4@8V]N=&5N=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE
M(&%R92!B96QO=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!C=7)R96YT(&9O;&1E<BAS*2!<(B5S7"(@=VEL;"!B
M92!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O
M9B!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@
M8F4@<F5T<FEE=F5D(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B965N('-A=F5D
M('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,30P"FUS9VED(")4:&4@979E;G0@=V%S(&%D
M9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5X<&%N9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O1F]L9&5R+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z,34P"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS(&EL;&5G86P@8VAA<F%C=&5R
M<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E("(*(G!R;V)L96US+B!0;&5A
M<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]&;VQD97(N<&AP.C,Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9F]L9&5R(%PB)7-<(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T
M('-U8G-C<FEB960@=&\@:70N(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<
M(B!W87,@9&5L971E9"!B=70@>6]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F
M<F]M(&ET+B(*;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HR.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!C
M<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z,S$U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E
M<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@<F5N86UE
M9"!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T
M;F5F+G!H<#HY-`IM<V=I9"`B5&AE(&9O;&QO=VEN9R!F:6QE<R!W97)E(&%T
M=&%C:&5D('1O('1H:7,@<&%R=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<&]P=7`N:G,Z-3D*;7-G:60@(B(*(E1H92!I;6%G92!S
M879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V
M92!S970@>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P('=I;F1O=W,_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#`*
M;7-G:60@(B(*(E1H92!I;6%G97,@=VEL;"!B92!D:7-P;&%Y960@8F5C875S
M92!T:&4@<V5N9&5R(&ES('!R97-E;G0@:6X@>6]U<B`B"B)A9&1R97-S8F]O
M:RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-S4*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO
M=VEN9R!E<G)O<B!M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0IM<V=I9"`B5&AE(&UA:6P@<V5R
M=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S
M<V%G93HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP
M:'`Z.3`*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O
M;&QO=VEN9R!M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M86EL8F]X("5S(&ES
M(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PN
M<&AP.C(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!<(B5S
M7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@
M;&EM:70N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,3`S"FUS9VED(")4:&4@;65S<V%G92!B96EN9R!C;VUP;W-E
M9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3(V"FUS9VED(")4:&4@;65S
M<V%G92!D;V5S(&YO="!H879E(&$@4W5B:F5C="!E;G1E<F5D+B(*;7-G<W1R
M("(B"@HC.B!M97-S86=E+G!H<#HQ-#@*;7-G:60@(E1H92!M97-S86=E(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C,Y-PIM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R
M:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,SDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA<R!B
M965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<&=P+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(')A=R!T97AT(&]F('1H92!01U`@4'5B;&EC($ME>2!C86X@8F4@=FEE
M=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z-C`*;7-G:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES
M="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`IM<V=I9"`B5&AE(')E<75E<W1E
M9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H;65N="XB
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-34P"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E<75E
M<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B`B"B)F
M<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A
M<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C8W"FUS9VED(")4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@
M82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHY,`IM<V=I9"`B5&AE('-I9VYA
M='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z.#@*;7-G:60@(E1H92!S:6=N
M871U<F4@=V%S('-U8V-E<W-F=6QL>2!R97!L86-E9"XB"FUS9W-T<B`B(@H*
M(SH@871T86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S<&5C:69I960@9FEL
M92!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@<W1A=&EO;F5R>2YP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E
M<UPB(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!S=&%T:6]N97)Y
M+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<W1A=&EO
M;F5R>2YP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE
M<GD@7"(E<UPB(&AA<R!B965N('5P9&%T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S`*;7-G:60@(E1H92!T87-K(&AA
M<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDU"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5X
M="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX,`IM<V=I9"`B5&AE
M('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@8V%N(&)E
M('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO
M=&EF:6-A=&EO;BYP:'`Z-C@*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT
M(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@
M;V8@=&AE('-E;G0@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34U"FUS9VED(")4
M:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L
M;'D@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O86QT
M97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I
M=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z
M,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O
M>"XB"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ,3`*;7-G:60@(E1H97)E
M(&ES(&YO('1E>'0@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8X.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I
M;&)O>"X@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M365S<V%G92YP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O
M(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G
M<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z,C(V(&QI8B]-97-S86=E+G!H
M<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE
M(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A
M:60B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S
M<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H
M92!E=F5N=#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M;&%I;BYP:'`Z-3(@;&EB+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS-PIM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4Y,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9FQA
M9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@
M=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@H*(SH@9F]L9&5R
M<RYP:'`Z,30Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M('1A<VLZ("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,34S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M
M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T
M:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z
M,3(X,`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE
M<W-A9V4@87,@82!D<F%F="XB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z
M,3`S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G
M:60@(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@
M:70N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY
M,PIM<V=I9"`B(@HB5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E
M9&1E9"!I;B!I="X@0FQO8VME9"!I;6%G97,@87!P96%R(&QI:V4@(@HB=&AI
M<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V
M-0IM<V=I9"`B5&AI<R!01U`@4'5B;&EC($ME>2!W87,@871T86-H960@=&\@
M=&AE(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ,#4@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q.0HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,30T(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-3@*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$W-"!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$U"FUS9VED(")4:&ES(&%C=&EO
M;B!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,3@P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT
M,C`*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,30*;7-G:60@(E1H:7,@;6%Y('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@
M;65S<V%G92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q-@IM<V=I9"`B(@HB
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@
M8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(P"FUS9VED(")4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B
M965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S
M<V%G92!C;VYT86EN<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO
M;BP@8G5T('1H92!F;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO
M=VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q
M.0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,SD@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,S4T"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M
M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4:&ES(&UE
M<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O
M34E-12!F;W)M870N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT,C`*;7-G:60@
M(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!0
M1U`N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,30S"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I
M9VYE9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S
M.`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@
M4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HR,#`@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDP"FUS9VED(")4:&ES
M(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*;7-G<W1R
M("(B"@HC.B!M97-S86=E+G!H<#HR,3`*;7-G:60@(E1H:7,@;65S<V%G92!T
M;R(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ,#D*;7-G
M:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E
M('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H<#HQ-3<*;7-G:60@
M(E1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z-S8@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ,0IM<V=I9"`B5&AR96%D(%9I97<B
M"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,C<Q(&UA:6QB;W@N<&AP.C8P
M,2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(R('1E;7!L871E
M<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S
M92]R96-O;7!O<V4N:6YC.C$P(&QI8B]396%R8V@N<&AP.C4Y,PIM<V=I9"`B
M5&\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP.`IM
M<V=I9"`B5&\@061D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM<V=S='(@(B(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@
M82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I
M;VX@;V8@4$A0(#4N,2XP(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3DQ"FUS9VED(")4;W1A
M;"!!='1A8VAM96YT<R!3:7IE.B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HS-CD*;7-G:60@(E1R87-H(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(S"FUS9VED(")4<F%S:"!F
M;VQD97(Z(@IM<V=S='(@(B(*"B,Z(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C0@
M;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N
M<&AP.C<Q"B,Z(&QI8B]1=6]T82]L;V=F:6QE+G!H<#HX."!L:6(O475O=&$O
M8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+VUD865M;VXN<&AP.C0X"FUS9VED
M(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,"!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C$Y"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,S8*;7-G:60@(E5N86YS=V5R960B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA;G-W
M97)E9"!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ,PIM<V=I9"`B56YD96QE=&4B"FUS9W-T<B`B(@H*(SH@;6%I
M;&)O>"YP:'`Z-3<Y(&UA:6QB;W@N<&AP.C4Y-R!L:6(O34E-12](96%D97)S
M+G!H<#HR,#0*;7-G:60@(E5N9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T
M<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-38*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\@05542$5.5$E#051%(&-O
M;6UA;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3(P
M"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($1I
M9V5S="U-1#4@<F5S<&]N<V4N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z-3,V"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O($Q/1TE.(&-O;6UA;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R("(B"@HC
M.B!M86EL8F]X+G!H<#HU-3<*;7-G:60@(E5N:VYO=VX@1&%T92(*;7-G<W1R
M("(B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;FMN;W=N($E-05`@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R
M+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C(V"FUS9VED(")5;FMN;W=N($UE971I;F<B
M"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z-C$S"FUS9VED(")5;FMN;W=N
M(%)E8VEP:65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL
M;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N
M<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N
M<&AP.C4P,B!M86EL8F]X+G!H<#HW,#(@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ
M,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O;2!&;VQD97(H<RDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED
M(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8Q,@IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU."!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T
M+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U;'0@5F%L=64B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B57-E($E-05`@
M9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW,C0*;7-G:60@(E5S92!6:7)T=6%L(%1R87-H($9O
M;&1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$T
M,PIM<V=I9"`B57-E<B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C@V"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E5S97(@7"(E<UPB('-U8V-E<W-F=6QL>2!G
M:79E;B!T:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3<V"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z,3<*;7-G:60@(E5S97)N86UE.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM
M<V=I9"`B5FEE=R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O>FEP
M+G!H<#HY,B!L:6(O34E-12]6:65W97(O=&YE9BYP:'`Z,3$P"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R!0=6)L:6,@2V5Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,3D*;7-G:60@
M(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X"FUS
M9VED(")6:65W($UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"FUS
M9VED(")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C<R"FUS9VED(")6:65W(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$X"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C0@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,38V"FUS9VED(")6:65W(%1H=6UB;F%I;"(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0R-`IM<V=I9"`B5FEE
M=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0IM<V=I9"`B5FEE
M=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#$*;7-G:60@(E9I97<@979E
M;G0B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S8Q(&UA:6QB;W@N<&AP
M.C4R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E
M;&5C="YI;F,Z,C,*;7-G:60@(E9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3<Q"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P-`IM<V=I9"`B5FEE=R!T:&4@
M26UA9V5S(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z,C4U"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<(B!C<F5A=&5D('-U
M8V-E<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA
M:6XN:6YC.C$Q,B!L:6(O24U!4"]4<F5E+G!H<#HQ-#$@;&EB+TE-05`O5')E
M92YP:'`Z,34T"B,Z(&QI8B])34%0+U1R964N<&AP.C$U-B!L:6(O24U!4"]4
M<F5E+G!H<#HQ-C`@;&EB+TE-05`O5')E92YP:'`Z,38Q"B,Z(&QI8B])34%0
M+U1R964N<&AP.C,W,2!L:6(O24U!4"]4<F5E+G!H<#HS.34@;&EB+TE-05`O
M5')E92YP:'`Z-#,S"FUS9VED(")6:7)T=6%L($9O;&1E<G,B"FUS9W-T<B`B
M(@H*(SH@<V5A<F-H+G!H<#HR-#<*;7-G:60@(E9I<G1U86P@1F]L9&5R<R!R
M97%U:7)E(&$@;&%B96PN(@IM<V=S='(@(B(*"B,Z(&QI8B]396%R8V@N<&AP
M.C0R,`IM<V=I9"`B5FER='5A;"!)3D)/6"(*;7-G<W1R("(B"@HC.B!F;VQD
M97)S+G!H<#HS.3<*;7-G:60@(E9I<G1U86P@24Y"3U@@1F]L9&5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-86EL8F]X+G!H<#HQ-S$@;&EB+U-E87)C:"YP:'`Z
M,S8V"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(B(*"B,Z(&9O;&1E
M<G,N<&AP.C,Y-`IM<V=I9"`B5FER='5A;"!4<F%S:"!&;VQD97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,CD*;7-G:60@
M(E9I<G1U86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,S<Y"FUS9VED(")787)N:6YG(@IM<V=S='(@
M(B(*"B,Z(&QO9VEN+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92!T;R`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C`W"FUS9VED("(B"B)7:&%T('-H;W5L9"!W92!D;R!W:71H('-P86T@
M;65S<V%G97,@869T97(@=&AE>2!H879E(&)E96X@<F5P;W)T960@87,@<W!A
M;2`B"B)O<B!I;FYO8V5N=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<Q-@IM<V=I9"`B(@HB5VAE;B!D96QE=&EN9R!M97-S86=E
M<RP@;6]V92!T:&5M('1O('EO=7(@5')A<V@@9F]L9&5R(&EN<W1E860@;V8@
M;6%R:VEN9R`B"B)T:&5M(&%S(&1E;&5T960_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.38*;7-G:60@(E=H96X@;W!E;FEN9R!A
M(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO=2!W86YT('1O('-T87)T
M(&]N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38Q
M"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA:6PL('-H;W5L9"!W92!S879E
M(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@;W(@
M97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P
M<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E
M<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3,W('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4U,`HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.38W"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HU.`IM<V=I9"`B
M66]U(&%R92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H92!F;VQL;W=I
M;F<@86-C;W5N="AS*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ,3`*;7-G:60@(B(*(EEO=2!A<F4@
M871T96UP=&EN9R!T;R!D96QE=&4@86QL(&UE<W-A9V5S(&-O;G1A:6YE9"!I
M;B!T:&4@9F]L;&]W:6YG(&9O;&1E<B(*(BAS*2XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ.0IM<V=I
M9"`B66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG
M(&9O;&1E<BAS*2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@
M;F5W(&9O;&1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!S
M=6(M9F]L9&5R('1O("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C$P-@IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A
M('1O<"UL979E;"!F;VQD97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&;VQD97(N
M<&AP.C(W-@IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S-PIM<V=I9"`B66]U(&%R
M92!R96YA;6EN9R!T:&4@9F]L9&5R.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,U"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S
M(&EN('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@(@HB8W5R<F5N
M="!M97-S86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T=7)E+B(*;7-G
M<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HU,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&-A;FYO="!U;G-U8G-C<FEB92!F<F]M(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N
M="YP:'`Z,S0*;7-G:60@(B(*(EEO=2!D:60@;F]T(&%G<F5E('1O('1H92!4
M97)M<R!O9B!397)V:6-E(&%G<F5E;65N="P@<V\@>6]U('=E<F4@;F]T(&%L
M;&]W960@(@HB=&\@;&]G:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ-S`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S
M:6]N('1O(&-H86YG92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TUA:6QL;V<N<&AP.C$S,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O
M;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PIM<V=I9"`B66]U(&AA=F4@,2!N
M97<@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z-#@R"FUS
M9VED(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A9V4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-30*;7-G:60@(EEO=2!H879E
M(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(*;7-G<W1R("(B
M"@HC.B!L:6(O24U0+G!H<#HQ,#4Y"FUS9VED(")9;W4@:&%V92!N97<@;6%I
M;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM<V=S='(@(B(*"B,Z(&-O
M;7!O<V4N<&AP.C$U,PIM<V=I9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@
M;VYE(')E8VEP:65N="XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z,S`V"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES
M(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HR-30*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR
M87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@
M(@HB;65S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J
M879A<V-R:7!T+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T
M+FEN8SHR,#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL
M8F]X(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z
M.#4*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z.#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A9&1R97-S
M(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A
M<V-R:7!T+FEN8SHV,B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHR,#@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8S
M"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@
M9FER<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHQ,PIM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C0X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@
M7"(E<UPB(&5N86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,X"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O
M;B`E)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E
M(&]N("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O1F]L9&5R+G!H<#HT-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@
M7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4R-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E
M(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C0W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S
M=6-C97-S9G5L;'D@<W5B<V-R:6)E9"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z-3(Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"FUS9VED
M(")9;W5R($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C4P"FUS9VED(")9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S$@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C<V"FUS9VED(")9;W5R(%!R:79A=&4@2V5Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C<@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<Q"FUS9VED(")9;W5R(%!U8FQI8R!+
M97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V-0IM
M<V=I9"`B66]U<B!297!L>2UT;SH@861D<F5S<SH@/&5M/BAO<'1I;VYA;"D\
M+V5M/B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C0Y"FUS9VED(")9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I
M8V%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O
M=6YT7W-E;&5C="YI;F,Z,38*;7-G:60@(EEO=7(@86-C;W5N=',Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-S,*;7-G:60@(B(*
M(EEO=7(@86QI87,@861D<F5S<V5S.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E
M86-H(&%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#$*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H
M:7,@:6UA9V4@='EP92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4S.0IM<V=I9"`B66]U<B!D969A=6QT(&-H87)S970@9F]R('-E
M;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC
M<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@
M(B(*"B,Z(&%T=&%C:&UE;G0N<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@;&EN:V5D(&%T=&%C:&UE;G0@:&%S(&)E96X@9&]W;FQO861E
M9"!B>2!A="!L96%S="!O;F4@=7-E<BY<;B(*(EQN(@HB071T86-H;65N="!N
M86UE.B`E<UQN(@HB071T86-H;65N="!D871E.B`E<UQN(@HB7&XB"B)#;&EC
M:R!O;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@<&5R;6%N96YT;'D@9&5L971E
M('1H92!A='1A8VAM96YT.EQN(@HB)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z.#D*;7-G:60@(EEO=7(@;65S<V%G92!W
M87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P-@IM<V=I9"`B66]U<B!S:6=N871U<F4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V%D9')E<W-E
M<T)L;V-K<RYJ<SHW"FUS9VED(");2&ED92!!9&1R97-S97-=(@IM<V=S='(@
M(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y-2!C;VUP;W-E+G!H<#HQ,S`Q(&UA:6QB
M;W@N<&AP.C4S-2!L:6(O0V]M<&]S92YP:'`Z.#,X"FUS9VED(");3F\@4W5B
M:F5C=%TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O861D
M<F5S<V5S0FQO8VMS+FIS.C@*;7-G:60@(EM3:&]W($%D9')E<W-E<R`M(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(");4VAO=R!A9&1R97-S97,@+2`E<R!R96-I<&EE;G1S
M72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHR,#,*;7-G:60@(E]"8V,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C$V"FUS9VED(")?0FQA8VML:7-T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$U,@IM<V=I9"`B
M7T-C(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHV('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*;7-G:60@(E]$
M96QE=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.34W"FUS9VED(")?
M1F]L9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHW.0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B])35`N<&AP.CDR-@IM<V=I9"`B7TEN8F]X(@IM<V=S='(@(B(*"B,Z(&QI
M8B])35`N<&AP.CDY.`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,SDQ"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TE-4"YP:'`Z.34T"FUS9VED(")?3F5W($UE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO
M;G,N:6YC.C,S"FUS9VED(")?4')I;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<P('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(X-PIM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(B(*
M"B,Z(&UA:6QB;W@N<&AP.C0P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")?4F5F
M<F5S:"`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B7U)E<&QY(@IM<V=S='(@(B(*"B,Z
M(&QI8B])35`N<&AP.CDU.0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,C8*;7-G:60@(E]396YD($UE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHS,@IM<V=I9"`B7U1H<F5A9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,30*;7-G:60@(E]4;R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM
M<V=I9"`B7U5N9&5L971E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B7U9I97<@5&AR96%D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM
M<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3<U"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z-#4Q"FUS9VED(")A='1A8VAM96YT(@IM<V=S
M='(@(B(*"B,Z('9I97<N<&AP.CDW"FUS9VED(")A='1A8VAM96YT<RYZ:7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-3`U"FUS9VED(")B>71E<R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3DY"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S$*;7-G:60@(F-A;FYO="!O
M<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C,*
M;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,C$Y"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.34*;7-G:60@
M(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$V-PIM<V=I9"`B9&%T82!F;W)M870@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(R,PIM<V=I9"`B96YT
M<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED(")F<F]M(@IM<V=S='(@(B(*"B,Z
M(&QI8B]#;VUP;W-E+G!H<#HQ-SD*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#,*;7-G:60@(FEN
M<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3@W"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!S;6EM92YP:'`Z,CD@<&=P+G!H<#HV.`IM<V=I9"`B:V5Y(@IM
M<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C$T-0IM<V=I9"`B;6%I;&)O>"!F
M:6QE(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$Q,#4@;&EB+TUE<W-A
M9V4N<&AP.C4Q,PIM<V=I9"`B;F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI
M;F,Z,C4*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM
M<V=I9"`B;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q-0IM
M<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O861D<F5S<V5S0FQO8VMS+FIS.C@*;7-G:60@(G)E
M8VEP:65N='-=(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,3$*
M;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3@S"FUS9VED(")S97)V:6-E('5N879A:6QA
M8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L
M;&EN9R!E<G)O<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y
M,0IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR,#<*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C<Y"FUS9VED(")Y;W5R(&)L86-K;&ES
M="(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HX.0IM<V=I9"`B>6]U
M<B!W:&ET96QI<W0B"FUS9W-T<B`B(@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R]N8E].
M3RYP;P``````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`S-C$S-34`,3`T,3<S-C(W-C8`,#$W,C`P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@24U0($YO<G=E9VEA;B!B;VMM
M86%L('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`Q+3(P,#(@2&]R
M9&4@4')O:F5C="X*(R!/>79I;F0@36]N<VQO<"`\;6]N<T!R97AT82YN970^
M+"`R,#`Q+@HC($]Y<W1E:6X@4W1E:6UL97(@/&]Y<W1E:6Y`<F5X=&$N;F5T
M/BP@,C`P,2X*(R!4;W)S=&5I;B!3+B!(86YS96X@/&AU;&5B;V5R0'1E8VAB
M964N;F\^+"`R,#`R+@HC($%N9')E87,@1W5N;&5I:W-K86%S(#QA;F1R96%S
M0&=U;FQE:6MS:V%A<RYN;SXL(#(P,#,N"B,*;7-G:60@(B(*;7-G<W1R("(B
M"B)0<F]J96-T+4ED+59E<G-I;VXZ($E-4"`S+C(N,5QN(@HB4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#0M,#4M,3@@,C,Z,S<K,#(P,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!!;F1R96%S($=U;FQE:6MS:V%A<R`\86YD<F5A<T!G=6YL96EK
M<VMA87,N;F\^7&XB"B),86YG=6%G92U496%M.B!.;W)W96=I86X@*$)O:VUA
M;"D@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q
M+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M
M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@("`@
M("!#8SH@(@IM<V=S='(@(B`@("`@5&EL.B`B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z-#$U"FUS9VED("(@("`@("!4;SH@(@IM<V=S='(@(B`@("`@5&EL.B`B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@1&%T93H@(@IM
M<V=S='(@(B`@("!$871O.B`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`V"FUS
M9VED("(@("`@1G)O;3H@(@IM<V=S='(@(B`@("`@1G)A.B`B"@HC.B!M86EL
M8F]X+G!H<#HT,C(@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C0Q,@IM<V=I9"`B(%-U8FIE8W0Z("(*;7-G
M<W1R("(@("`@16UN93H@(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C<P"FUS9VED("(@:6X@(@IM<V=S='(@(B!I("(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B
M"FUS9W-T<B`B(R(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HV.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM
M<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,34Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!-97-S86=E<R(*;7-G<W1R("(E9"!A=B`E9"!M96QD
M:6YG97(B"@HC.B!M86EL8F]X+G!H<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("))9&5N=&ET971E;B!<(B5S7"(@8FQE('-L971T970N(@H*(SH@;&EB
M+U-P86TN<&AP.C$W.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M('1O
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D1E;FYE
M(&UE;&1I;F=E;B!E<B!B;&ET="!R87!P;W)T97)T('-O;2!S<&%M('1I;"!S
M>7-T96UA9&UI;FES=')A=&]R96XN(@H*(SH@;&EB+U-P86TN<&AP.C$U.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B
M965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(B"B)$96YN92!M
M96QD:6YG96X@97(@8FQI='0@<F%P<&]R=&5R="!S;VT@<W!A;2!T:6P@<WES
M=&5M861M:6YI<W1R871O<F5N+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E
M;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*(D1E;FYE(&UE;&1I;F=E;B!E<B!B;&ET="!R87!P
M;W)T97)T('-O;2!S<&%M('1I;"!S>7-T96UA9&UI;FES=')A=&]R96XN(@H*
M(SH@;&EB+U-P86TN<&AP.C$U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P86TN(@IM
M<V=S='(@(B(*(D1E;FYE(&UE;&1I;F=E;B!E<B!B;&ET="!R87!P;W)T97)T
M('-O;2!S<&%M('1I;"!S>7-T96UA9&UI;FES=')A=&]R96XN(@H*(SH@;6%I
M;&)O>"YP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F
M("5D($UE<W-A9V5S(@IM<V=S='(@(B5D("T@)60@878@)60@;65L9&EN9V5R
M(@H*(SH@;6%I;&)O>"YP:'`Z-C0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($M"(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M
M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A;')E861Y(&5X:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R
M96YA;65D+B(*;7-G<W1R("(E<R!F:6YN97,@86QL97)E9&4N($UA<'!E;B`E
M<R!B;&4@:6MK92!G:71T(&YY='0@;F%V;BXB"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B5S('-E<B!I:VME
M('5T('-O;2!E<B!E;B!G>6QD:6<@<&]S=&)O:W,B"@HC.B!L:6(O36%I;G1E
M;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N=&AL>2YP:'`Z-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L9&5R(&)E:6YG(')E;F%M960@870@
M=&AE('-T87)T(&]F('1H92!M;VYT:"XB"FUS9W-T<B`B36%P<&5N("<E<R<@
M8FQI<B!G:71T(&YY='0@;F%V;B!I(&)E9WEN;F5L<V5N(&%V(&WE;F5D96XN
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!H87,@9&5C;&EN960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E
M<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@
M=&\@)7,N(@IM<V=S='(@(D1U('-V87)T92!PY2!D96YN92!M96QD:6YG96X@
M<.4@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT871I
M=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T
M<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<
M(BXB"FUS9W-T<B`B36%P<&5N(%PB)7-<(B!H971E<B!NY2!<(B5S7"(N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!W:7-H97,@=&\@86UM96YD("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T
M97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+B(*;7-G<W1R("(B"@HC.B!M97-S
M86=E+G!H<#HR.#4@;65S<V%G92YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?=&]P+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,@
M*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7,Z("5S("@E9"9N8G-P
M.V]F)FYB<W`[)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N
M:6YC.C$S,PIM<V=I9"`B*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@
M=&\@;F5X="!S8W)E96XN*2(*;7-G<W1R("(H0G)U:R!D:7-S92!R971T:6YG
M96YE+"!O9R!GY2!T:6P@;F5S=&4@<VED92XI(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H
M86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G
M<W1R("(H1F]R:V%S="!A;&QE(&5N9')I;F=E<BP@;V<@<F5T=7)N97(@=&EL
M(&UE;&1I;F=E;BXI(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C$V"FUS9VED("(H2%1-3"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB
M"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E
M='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL
M(&-H86YG97,@;6%D92!T:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U
M<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B
M"B(H4F5T=7)N97)E('1I;"!M96QD:6YG96X@971T97(@870@96YD<FEN9V5N
M92!SY2!L86YG="!E<B!G:F]R="X@16YD<FEN9V5N92!I("(*(F1E='1E(&)I
M;&1E="!V:6P@24M+12!B;&D@9VIO<G0N*2(*"B,Z('-P96QL:6YG+G!H<#HR
M-S<*(RP@9G5Z>GD*;7-G:60@(B(*(BA396YD(&UE<W-A9V4@869T97(@87!P
M;'EI;F<@86QL(&-H86YG97,@;6%D92!T:'5S(&9A<BX@($-H86YG97,@;VX@
M=&AE("(*(F-U<G)E;G0@<V-R965N('=I;&P@3D]4(&)E(&%P<&QI960N*2(*
M;7-G<W1R("(B"B(H4F5T=7)N97)E('1I;"!M96QD:6YG96X@971T97(@870@
M96YD<FEN9V5N92!SY2!L86YG="!E<B!G:F]R="X@16YD<FEN9V5N92!I("(*
M(F1E='1E(&)I;&1E="!V:6P@24M+12!B;&D@9VIO<G0N*2(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D9"!T
M:&5S92!B>2!C;&EC:VEN9R!/2R`J(@IM<V=S='(@(BH@3&5G9R!T:6P@9&ES
M<V4@=F5D(.4@:VQI:VME($]+("HB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D9')E
M<W,H97,I("HB"FUS9W-T<B`B*B!696YN;&EG<W0@=F5L9R!A9')E<W-E*&YE
M*2`J(@H*(SH@;6%I;&)O>"YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("(Q(&UE
M<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@
M7"(E<UPB(&)L92!S;&5T=&5T+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*(RP@
M9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N
M;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B)$96YN92!M96QD:6YG96X@97(@8FQI='0@<F%P<&]R=&5R="!S;VT@
M<W!A;2!T:6P@<WES=&5M861M:6YI<W1R871O<F5N+B(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R
M97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B(@HB1&5N;F4@;65L9&EN
M9V5N(&5R(&)L:71T(')A<'!O<G1E<G0@<V]M('-P86T@=&EL('-Y<W1E;6%D
M;6EN:7-T<F%T;W)E;BXB"@HC.B!L:6(O4W!A;2YP:'`Z,3<R"B,L(&9U>GIY
M"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T
M;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)$96YN
M92!M96QD:6YG96X@97(@8FQI='0@<F%P<&]R=&5R="!S;VT@<W!A;2!T:6P@
M<WES=&5M861M:6YI<W1R871O<F5N+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-3(*
M(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M+B(*;7-G<W1R("(B"B)$96YN92!M96QD:6YG96X@97(@8FQI='0@
M<F%P<&]R=&5R="!S;VT@<W!A;2!T:6P@<WES=&5M861M:6YI<W1R871O<F5N
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,3D*(RP@9G5Z>GD*;7-G
M:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(E-P97-I86QT96=N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,@HC+"!F=7IZ>0IM<V=I9"`B,3`P
M,"!C:&%R86-T97)S(@IM<V=S='(@(E-P97-I86QT96=N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@R,`HC+"!F=7IZ>0IM<V=I9"`B,C4P(&-H87)A
M8W1E<G,B"FUS9W-T<B`B4W!E<VEA;'1E9VXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#(Q"B,L(&9U>GIY"FUS9VED("(U,#`@8VAA<F%C=&5R<R(*
M;7-G<W1R(")3<&5S:6%L=&5G;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E
M(&YA;65D("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*
M;7-G:60@(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E
M9"!I;B!A(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I
M96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z-0IM<V=I9"`B04Y$(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.3`*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@(D%C
M8V5P="!R97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U,PIM<V=I9"`B
M06-C97!T960B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C(U-PIM<V=I9"`B06-C97!T960Z("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B
M06-C;W5N="=S(&YA;64Z(@IM<V=S='(@(DMO;G1O97(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3(P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HW,S`*(RP@9G5Z>GD*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B2&%N9&QI
M;F<B"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB+TU)344O2&5A
M9&5R<RYP:'`Z,C`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M)7,@=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@(DQE9V<@=&EL(&D@861D
M<F5S<V5B;VL@*"5S*2(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,P,PHC+"!F=7IZ>0IM<V=I9"`B061D('-O=7)C92(*;7-G<W1R
M(")L96=G('1I;"!K:6QD92(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU-S<@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X.`IM<V=I9"`B061D
M('1H:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP
M:'`Z,3(U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB(&%S(&%N(&%T=&%C:&UE;G0N(@IM<V=S='(@(DQA('1I;"!E="!V961L
M96=G+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3@*;7-G:60@(B(*
M(D%D9&ET:6]N86P@:&5A9&5R<R!T;R!D:7-P;&%Y('=H96X@=FEE=VEN9SH@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!H96%D97(@(@HB;VX@82!N97<@
M;&EN92D\+V5M/B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T
M:69I8V%T:6]N+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO
M;F%L(&EN9F]R;6%T:6]N(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L(&9U
M>GIY"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS
M9W-T<B`B4&5R<V]N;&EG(&EN9F]R;6%S:F]N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z.3,*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!D
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G
M92!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<X"FUS9VED(")!9&1I=&EO;F%L
M(&UE<W-A9V4@97)R;W(@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D
M("5S+B(*;7-G<W1R("(B"@HC.B!C;VYT86-T<RYP:'`Z.#4@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T
M+FEN8SHU,@IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D9')E<W-E
M8OAK97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S($)O;VMS(@IM<V=S='(@(D%D9')E<W-E8OAK97(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Y"FUS9VED("(B"B)!9&1R
M97-S97,@=&\@0D-#(&%L;"!M97-S86=E<SH@/&5M/BAO<'1I;VYA;"P@96YT
M97(@96%C:"!A9&1R97-S(&]N(&$@;F5W("(*(FQI;F4I/"]E;3XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,0IM<V=I9"`B(@HB
M061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H:7,@:61E;G1I='DZ
M(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D<F5S<R!O;B!A(&YE
M=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,PIM<V=I
M9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$S"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@=&AE
M(&9O;&QO=VEN9R!F;VQD97(H<RD@=VEL;"!B92!D;W=N;&]A9&5D(&EN=&\@
M;VYE($U"3U@@(@HB9FEL93HB"FUS9W-T<B`B06QL92!M96QD:6YG96YE(&D@
M9OAL9V5N9&4@;6%P<&4H<BD@=FEL(&)L:2!L87-T970@;F5D(&D@Z6X@34)/
M6"UF:6PZ(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I
M;B!Y;W5R(%PB)7-<(B!F;VQD97(@;VQD97(@=&AA;B`E<R!D87ES('=I;&P@
M8F4@<&5R;6%N96YT;'D@(@HB9&5L971E9"XB"FUS9W-T<B`B(@HB06QL92!M
M96QD:6YG96YE(&D@7"(E<UPB+6UA<'!E;B!S;VT@97(@96QD<F4@96YN("5S
M(&1A9V5R+"!V:6P@8FQI('-L971T970@(@HB<&5R;6%N96YT+B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY
M+G!H<#HU.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L
M:6YK960@871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL
M;"!B92!D96QE=&5D+B(*;7-G<W1R(")-87!P97(@;65D('-E;G1E(&UE;&1I
M;F=E<B!E;&1R92!E;FX@)7,@;>5N961E<BP@=FEL(&)L:2!S;&5T=&5T+B(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT
M:&QY+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E;G0M
M;6%I;"!F;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@
M9&5L971E9"XB"FUS9W-T<B`B36%P<&5R(&UE9"!S96YT92!M96QD:6YG97(@
M96QD<F4@96YN("5S(&WE;F5D97(L('9I;"!B;&D@<VQE='1E="XB"@HC.B!A
M8VPN<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@<FEG
M:'1S(&]N(&9O;&1E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R
M('5S97(@7"(E<UPB+B(*;7-G<W1R(")-87!P96X@7"(E<UPB(&AE=&5R(&[E
M(%PB)7-<(BXB"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L
M9&5R($-R96%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z-#@*;7-G:60@(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B
M92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B06QT97)N
M871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B06QT97)N
M871I=F4@9&5L97(@9F]R(&1E;FYE('-E:W-J;VYE;CHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3<R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#0*
M;7-G:60@(D%L=V%Y<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-34W"B,L(&9U>GIY"FUS9VED(")!;'=A>7,@<V%V92!A='1A8VAM
M96YT<R(*;7-G<W1R("),82!T:6P@970@=F5D;&5G9RXB"@HC.B!L:6(O365S
M<V%G92YP:'`Z-3`U"FUS9VED("(B"B)!;B!E<G)O<B!O8V-U<F5D('=H:6QE
M(&%T=&5M<'1I;F<@=&\@<W1R:7`@=&AE(&%T=&%C:&UE;G0N(%1H92!)34%0
M('-E<G9E<B`B"B)S86ED.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!O8V-U
M<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T92XB"FUS9W-T<B`B16X@
M=6MJ96YT(&9E:6P@;W!P<W1O9"!V960@:6YN;&5G9VEN9R!A=B!D96X@;GEE
M(&]P<&;X<FEN9V5N+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#<*(RP@9G5Z
M>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A
M=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(D5N('5K:F5N="!F96EL(&]P
M<'-T;V0@=F5D(&EN;FQE9V=I;F<@878@9&5N(&YY92!O<'!F^')I;F=E;BXB
M"@HC.B!M97-S86=E+G!H<#HU,#`@;6%I;&)O>"YP:'`Z-S$T('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z.0HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S4*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHV"FUS
M9VED(")!;G-W97)E9"(*;7-G<W1R(")"97-V87)T(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHS,0IM<V=I9"`B06YS=V5R960@;65S<V%G97,B
M"FUS9W-T<B`B0F5S=F%R=&4@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY"FUS9VED(")!<'!L>2!&:6QT
M97)S(@IM<V=S='(@(D)R=6L@9FEL=')E('#E(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!<'!L>2!&:6QT97)S('1O("5S(@IM<V=S='(@(D)R=6L@9FEL=')E('#E
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS9VED(")!
M<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")"
M<G5K(&9I;'1E<G)E9VQE<B!V960@<.5L;V=G:6YG+B(*"B,Z('1E;7!L871E
M<R]F:6QT97)S+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@
M9FEL=&5R(')U;&5S('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS
M9W-T<B`B0G)U:R!F:6QT97)R96=L97(@=F5D(&]P<&1A=&5R:6YG(&%V('!O
M<W1B;VMS+B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\B"FUS
M9W-T<B`B17(@9'4@4TE+2T52('#E(&%T(&1U(/AN<VME<B#E(&9O<G1S971T
M93\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O
M;6UE;F1E9"$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_(@IM<V=S
M='(@(D5R(&1U(%-)2TM%4B!PY2!A="!D=2#X;G-K97(@Y2!F;W)T<V5T=&4_
M(@H*(SH@;65S<V%G92YP:'`Z-#`W('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C8X"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M4$5234%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R(")%
M<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('-L971T92!D96YN92!M96QD:6YG
M96X@1D]2($=/1%0B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"B,L
M(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.
M14Y43%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B17(@9'4@
M<VEK:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@9&5N;F4@;65L9&EN9V5N($9/
M4B!'3T14(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!T:&ES(&9O
M;&1E<C\B"FUS9W-T<B`B17(@9'4@<VEK:V5R('#E(&%T(&1U('9I;"!S;&5T
M=&4@9&5N;F4@;65L9&EN9V5N($9/4B!'3T14(@H*(SH@;&EB+TE-4"YP:'`Z
M.3<S"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`B17(@9'4@<VEK:V5R
M('#E(&%T(&1U('9I;"!S;&5T=&4@9&5N;F4@;65L9&EN9V5N($9/4B!'3T14
M(@H*(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD97(_(@IM<V=S='(@(D5R
M(&1U('-I:VME<B!PY2!A="!D=2!V:6P@<VQE='1E(&1E;FYE(&UE;&1I;F=E
M;B!&3U(@1T]$5"(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C@*(RP@9G5Z>GD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P
M97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(D5R
M(&1U('-I:VME<B!PY2!A="!D=2!V:6P@<VQE='1E(&1E;FYE(&UE;&1I;F=E
M;B!&3U(@1T]$5"(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N
M:6YC.C@P('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"B,L
M(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T
M('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\B"FUS9W-T<B`B17(@9'4@<VEK
M:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@9&5N;F4@;65L9&EN9V5N($9/4B!'
M3T14(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-S4@
M=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*(RP@9G5Z>GD*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M
M97-S86=E(&%S('-P86T_(@IM<V=S='(@(D5R(&1U('-I:VME<B!PY2!A="!D
M=2!V:6P@<VQE='1E(&1E;FYE(&UE;&1I;F=E;B!&3U(@1T]$5"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,38*;7-G:60@(D%R<FEV86P@5&EM92(*
M;7-G<W1R(")!;FMO;7-T=&ED(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDS,0IM<V=I9"`B07-C96YD:6YG(@IM<V=S='(@(E-T:6=E;F1E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3$Y"FUS9VED(")!='1A8V@B"FUS9W-T<B`B
M3&5G9R!V960B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT
M-S4*(RP@9G5Z>GD*;7-G:60@(D%T=&%C:"!&:6QE<R(*;7-G<W1R(")6961L
M96=G(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#4V"FUS
M9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U8FQI8R!K97D@=&\@
M>6]U<B!M97-S86=E/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M=&YE9BYP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")!='1A8VAE9"!&:6QE.B(*
M;7-G<W1R("),96=G('9E9"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT-3$@;&EB
M+T-O;7!O<V4N<&AP.C4S-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!='1A
M8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A8VAM96YT('-I>F4@
M;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C,W-@IM<V=I9"`B071T86-H960@:7,@
M82!R97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,38@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$T"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHY-PIM<V=I9"`B071T86-H;65N="(*;7-G<W1R(")6
M961L96=G(@H*(SH@8V]M<&]S92YP:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z
M-#8V"FUS9VED(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A
M8VAM96YT('1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,S0Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0W,PHC.B!L:6(O0V]M<&]S92YP:'`Z,3`W,PIM<V=I9"`B071T86-H;65N
M=',B"FUS9W-T<B`B5F5D;&5G9R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV.#(*(RP@9G5Z>GD*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")6
M961L96=G(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z
M-3,*(RP@9G5Z>GD*;7-G:60@(D%T=&5N=&EO;B(*;7-G<W1R(")(86YD;&EN
M9R(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*;7-G:60@(D%U=&A?:6UP.B!2
M97%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-#`*;7-G:60@(B(*(D%U=&]M
M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@2%1-3"!M97-S86=E<R!W:&5N('1H
M92!S96YD97(@:7,@:6X@;7D@(@HB861D<F5S<V)O;VL_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C(Y.`HC+"!F
M=7IZ>0IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@
M(E1I;&=J96YG96QI9V4@861R97-S96+X:V5R.B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T
M92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS
M9W-T<B`B5&EL8F%K92!T:6P@)7,B"@HC.B!T:')E860N<&AP.C$S-R!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B5&EL8F%K92!T:6P@
M)7,B"@HC.B!T:')E860N<&AP.C$S-`IM<V=I9"`B0F%C:R!T;R!-=6QT:7!L
M92!-97-S86=E(%9I97<@26YD97@B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H
M<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D($1I<W!L87DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N
M9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR-C8@=&5M<&QA
M=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C(*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L:6(O4V5A<F-H+G!H<#HS-`IM<V=I
M9"`B0F-C(@IM<V=S='(@(E-K:G5L="!K;W!I('1I;"(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]S=&%T=7,N<&AP.C$V,0IM<V=I9"`B0F5L;W<@:7,@=&AE(')A
M=R!T97AT(&]F('1H92!S=&%T=7,@:6YF;W)M871I;VX@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED
M(")";&%C:VQI<W0B"FUS9W-T<B`B4W9A<G1E;&ES=&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C(Y"FUS9VED(")";&]C:R!I;6%G97,@:6X@2%1-
M3"!M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E
M<W1E9#\B"FUS9W-T<B`B(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(*;7-G:60@
M(D)O9'DB"FUS9W-T<B`B365L9&EN9W-T96MS="(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z,C,@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS
M.0HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C4U('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z-S$*;7-G:60@(D)O=&@B"FUS9W-T<B`B0F5G9V4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@W"FUS9VED(")";W1H($AE
M861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R"FUS9VED(")#
M7VAA<G-E="(*;7-G<W1R(")496=N<V5T="(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N;W0@
M8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO
M="!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<&%R=&EA;"YP:'`Z-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V%N(&YO="!D:7-P;&%Y("T@9F]U;F0@;VYL
M>2`E<R!O9B`E<R!P87)T<R!O9B!T:&ES(&UE<W-A9V4@:6X@=&AE(&-U<G)E
M;G0@(@HB;6%I;&)O>"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,C@T
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4U"B,Z('1E;7!L
M871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C$@=&5M<&QA=&5S+W-A=F5I;6%G
M92]S879E:6UA9V4N:6YC.C$Y"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR
M87-E+FEN8SHR,2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#8*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$R,"!T96UP;&%T
M97,O<&=P+W!A<W-P:')A<V4N:6YC.C,R"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z-C8*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")!=F)R>70B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHW,2!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,S4*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5D:7)E8W0N:6YC.C$Q,0IM<V=I9"`B0V%N8V5L($UE<W-A9V4B"FUS
M9W-T<B`B079B<GET(&UE;&1I;F<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R
M961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*
M;7-G:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT
M;'D@9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(DAV:7,@9'4@879B
M<GET97(@9&5N;F4@;65L9&EN9V5N+"!M:7-T97(@9'4@:6YN:&]L9&5T+B(*
M"B,Z(&UE<W-A9V4N<&AP.C(V-2!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C(R,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC
M.C$U(&QI8B]396%R8V@N<&AP.C,P"FUS9VED(")#8R(*;7-G<W1R(")+;W!I
M('1I;"(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G:60@
M(B(*(D-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&:6QE
M('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P,0HC+"!F
M=7IZ>0IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(E!E<G-O;FQI9R(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(D5N9')E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(D5N
M9')E(&%L="(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@HC+"!F=7IZ
M>0IM<V=I9"`B0VAA;F=E($9O;&1E<B(*;7-G<W1R(")/<'!R971T(&UA<'!E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,@IM<V=I9"`B(@HB0VAA
M;F=E(&1I<W!L87D@;W!T:6]N<R!S=6-H(&%S(&AO=R!M86YY(&UE<W-A9V5S
M('EO=2!S964@;VX@96%C:"!P86=E(&%N9"`B"B)H;W<@;65S<V%G97,@87)E
M('-O<G1E9"XB"FUS9W-T<B`B(@HB16YD<F4@=FES;FEN9W-V86QG('-O;2!A
M;G1A;&QE="!M96QD:6YG97(@<&5R('-I9&4@;V<@;65L9&EN9W-S;W)T97)I
M;F<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"B,L(&9U>GIY"FUS
M9VED(")#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB
M"FUS9W-T<B`B16YD<F4@92UP;W-T<V5R=F5R(&EN<W1I;&QI;F=E<BXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@(B(*(D-H86YG92!T
M:&4@;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD("(*(G)E<&QY('1O('EO=7(@96UA:6PN
M(@IM<V=S='(@(B(*(D5N9')E(&YA=FXL(&%D<F5S<V4@;V<@<VEG;F%T=7(@
M<V]M(&9O;&L@<V5R(&[E<B!D92!L97-E<B!O9R!S=F%R97(@<.4@(@HB<&]S
M=&5N(&1I;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(T"FUS9VED
M(")#:&%R86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#:&5C:R!&;VQD
M97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(E-E(&5T=&5R(&YY('!O<W0@
M:2!M87!P96XH92DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN
M8SHR('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-S4*
M;7-G:60@(D-H96-K(%]!;&PO3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]F971C:&UA:6PN:6YC.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S
M97)V97)S('EO=2!W86YT('1O(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B
M5F5L9R!A;&QE('-E<G9E<F4@9'4@=FEL(&AE;G1E(&4M<&]S="!F<F$Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V,PHC+"!F=7IZ>0IM<V=I9"`B
M0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G
M<W1R(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R('-E;F1I;F<@878@;65L
M9&EN9V5N.B`E<R(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C0*;7-G:60@(D-H;V]S92!!8W1I;VXZ(@IM<V=S='(@(E9E;&<@:&%N9&QI
M;F<Z(@H*(SH@8V]N9FEG+W-E<G9E<G,N<&AP+F1I<W0Z,3@R"FUS9VED(")#
M:&]O<V4@82!M86EL('-E<G9E<CHB"FUS9W-T<B`B5F5L9R!E;B!E+7!O<W1S
M97)V97(Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,3<*;7-G:60@(D-H;V]S92!A(&UA
M=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(Q(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,S$*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A
M;B!A8W1I;VXZ(@IM<V=S='(@(E9E;&<@:&%N9&QI;F<Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"B,L(&9U>GIY"FUS9VED
M(")#:&]O<V4@=&AE(&%D9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@
M861D<F5S<V5S+B(*;7-G<W1R(")696QG(&%D<F5S<V5B;VME;B!S;VT@<VMA
M;"!B<G5K97,@=F5D('9A;&<@878@861R97-S97(N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS"B,L(&9U>GIY"FUS9VED(")#
M:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@<V5A<F-H('=H
M96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B(@HB5F5L9R!R96MK
M96;X;&=E;B!B;&%N="!A9')E<W-E8OAK96YE('-O;2!B<G5K97,@=&EL('5T
M=FED96QS92!A=B!A9')E<W-E<BXB"@HC.B!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@
M8V]N=F5R="!T:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O
M=W-E<B!C86X@=FEE=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z.34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L
M:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92XB"FUS9W-T<B`B5')Y:VL@
M:&5R(&9O<B#E(%9)4T4@8FEL9&5N92(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M
M86YA9V5M96YT('!A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@
M=&\@=FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM
M<V=S='(@(E1R>6MK("5S(&9O<B#E('9I<V4@2%1-3"UI;FYH;VQD(&D@970@
M96=E="!V:6YD=2XB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H
M=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E
M<&%R871E('=I;F1O=RXB"FUS9W-T<B`B5')Y:VL@)7,@9F]R(.4@=FES92!(
M5$U,+6EN;FAO;&0@:2!E="!E9V5T('9I;F1U+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]R96QA=&5D+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A
M<G0@:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(E1R>6MK("5S(&9O
M<B#E('9I<V4@2%1-3"UI;FYH;VQD(&D@970@96=E="!V:6YD=2XB"@HC.B!L
M:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@
M=&\@4TA/5R!T:&4@26UA9V5S(@IM<V=S='(@(E1R>6MK(&AE<B!F;W(@Y2!6
M25-%(&)I;&1E;F4B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHS,C$*(RP@9G5Z>GD*;7-G:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y
M;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L
M;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*;7-G<W1R("(B"B)+;&EK:R!PY2!E
M;B!A=B!D:6YE('9A;&=T92!A9')E<W-E8OAK97(L(&]G('9E;&<@9F5L=&5N
M92!S;VT@9&5T('-K86P@<_AK97,@(@HB:2XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HQ-S$*;7-G:60@(D-L:6-K('1O(%-A=F4@4$=0(%!U8FQI
M8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VLB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQI8VL@=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@
M>6]U<B!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDU,`IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@
M=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#
M;&EC:VEN9R!O;B!T:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@
M=&\@8F4@<F5A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S='(@(DQU:VLB
M"@HC.B!C;VUP;W-E+G!H<#HX,C@@8V]M<&]S92YP:'`Z,3$T.`IM<V=I9"`B
M0VQO<V4@=&AI<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z
M-#(Y"FUS9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(DQU:VME="!M87!P
M92(*"B,Z(&9O;&1E<G,N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B0V]L;&%P
M<V4B"FUS9W-T<B`B4VSE('-A;6UE;B!A;&QE(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*;7-G
M<W1R(")3;.4@<V%M;65N(&%L;&4B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@06QL($9O;&1E<G,B"FUS
M9W-T<B`B4VSE('-A;6UE;B!A;&QE(&UA<'!E;F4B"@HC.B!F;VQD97)S+G!H
M<#HT-#D*;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R(")3;.4@<V%M
M;65N(&UA<'!E(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C4Q"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-CD*(RP@9G5Z
M>GD*;7-G:60@(D-O;7!L971E9"(*;7-G<W1R(").>2!M96QD:6YG(@H*(SH@
M8V]M<&]S92YP:'`Z.#(W(&-O;7!O<V4N<&AP.C$Q-#<*(RP@9G5Z>GD*;7-G
M:60@(D-O;7!O<V4@86YO=&AE<B!M97-S86=E(@IM<V=S='(@(E-K<FEV(&5N
M(&UE;&1I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED
M(")#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G
M<W1R("),86<@;GD@;65L9&EN9R!I(&5T(&5G970@=FEN9'4N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0T,PIM<V=I9"`B(@HB0V]M<&]S92!M97-S
M86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S97(@
M<W5P<&]R=',@=&AE("(*(F9E871U<F4I/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@;65S
M<V%G97,@87)E(&1I<W!L87EE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDW"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U<F4@;6%I
M;"!P<F5V:65W(&]P=&EO;G,N(@IM<V=S='(@(D5N9')E(&4M<&]S='-E<G9E
M<B!I;G-T:6QL:6YG97(N(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*
M;7-G:60@(D-O;FYE8W1I;VX@9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,S0*;7-G:60@
M(D-O;FYE8W1I;VX@=&\@<V5R=F5R(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1R;VP@4$=0('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1R;VP@4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P
M=&EO;G,@<F5L871I;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O
M;G1R;VP@=VAE;B!N97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@
M=VAE=&AE<B!O<B!N;W0@=&\@;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV
M97,N(@IM<V=S='(@(B(*(E-E='0@:'9O<B!O9G1E(&1E="!S:V%L('-J96MK
M97,@971T97(@;GD@<&]S="P@;V<@;VT@9'4@^&YS:V5R('9A<G-L:6YG+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.38*;7-G:60@(D-O;G9E<G0@
M=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#
M;W!Y(@IM<V=S='(@(DMO<&EE<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2!T;R!F;VQD97(B"FUS9W-T
M<B`B4_AP<&5L;6%P<&4Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S='(@(DMO<G)E:W0B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,30P"FUS9VED(")#
M;W)R96-T960@5&5X="(*;7-G<W1R(")2971T970@=&5K<W0B"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C,X,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-O;7!L971E(')E<75E<W0N(%)E87-O;B!':79E;CH@
M)7,B"FUS9W-T<B`B26MK92!S;&5T=&5D92!M96QD:6YG(@H*(SH@871T86-H
M;65N="YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R
M96%T92!T:&4@5D93(&)A8VME;F0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HV-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S
M86ED.B`E<R(*;7-G<W1R(")):VME('-L971T961E(&UE;&1I;F<B"@HC.B!L
M:6(O4V5S<VEO;BYP:'`Z,S$X"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M97AE8W5T92!M86EN=&5N86YC92!O<&5R871I;VYS+B(*;7-G<W1R(")6961L
M:6ME:&]L9'-O<&5R87-J;VYE<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T;F5F
M+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(&5X=')A8W0@=&AE(')E<75E<W1E
M9"!F:6QE(&9R;VT@=&AE($U3+51.148@871T86-H;65N="XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-3@*;7-G:60@(D-O=6QD
M(&YO="!E>'1R86-T('1H92!R97%U97-T960@9FEL92!F<F]M('1H92!::7`@
M87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(W,PIM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA=&EO
M;B!F<F]M($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!S96%R8V@N<&AP
M.C,Q-"!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C,Y"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ
M-C`*;7-G:60@(D-R96%T92(*;7-G<W1R(")/<'!R971T(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E
M<B(*;7-G<W1R(")/<'!R971T(&UA<'!E(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$S-PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E($ME>7,B"FUS9W-T
M<B`B3W!P<F5T="(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ
M-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(%9I<G1U86P@1F]L9&5R(@IM<V=S
M='(@(E9I<G1U96QL92!M87!P97(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V%C8V]U;G1?<V5L96-T+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E
M(&$@3F5W($%C8V]U;G0B"FUS9W-T<B`B06YD<F4@;6%I;&MO;G1O97(B"@HC
M.B!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S
M+W!R969S+W-P86US96QE8W0N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")#<F5A
M=&4@82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B3&%G(&YY('/X<'!E;&UA
M<'!E(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R
M96%T92!A(&YE=R!D<F%F=',@9F]L9&5R(@IM<V=S='(@(DQA9R!N>2!K;&%D
M9&5M87!P92(*"B,Z('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI
M;F,Z,C8@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM
M<V=I9"`B0W)E871E(&$@;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B
M3&%G(&5N(&YY("=396YD=&4@96QE;65N=&5R)RUM87!P92(*"B,Z('1E;7!L
M871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S
M+W1R87-H<V5L96-T+FEN8SHR-`IM<V=I9"`B0W)E871E(&$@;F5W('1R87-H
M(&9O;&1E<B(*;7-G<W1R("),86<@;GD@<_AP<&5L;6%P<&4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R
M:6YG(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R
M="!I="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T
M<B`B(@HB3&%G(&9I;'1R92!F;W(@Y2!O<F=A;FES97)E(&EN;FMO;6UE;F1E
M('!O<W0L(&9O<F1E;&4@9&5N(&D@;6%P<&5R+"!O9R!F;W(@Y2`B"B)S;&5T
M=&4@<W!A;2XB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!N97<@<W1A=&EO;F5R>2(*;7-G
M<W1R("),86<@96X@;GD@)U-E;F1T92!E;&5M96YT97(G+6UA<'!E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T.0IM<V=I9"`B0W)E871E('-T871I
M;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5R
M<F5N="!A8V-E<W,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-0IM<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F
M971C:&EN9R!M86EL(&9R;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,0HC+"!F=7IZ>0IM<V=I9"`B
M0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R("(B"B)4:6QP
M87-S(&AV;W)D86X@9'4@<V5N9&5R('!O<W0L(&]G(&AV;W(@:VQA9&1E<B!O
M9R!S96YD=&4@;65L9&EN9V5R(&)L:7(@(@HB;&%G<F5T+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(E1I;'!A<W,@;W!P9V%V97(@<V]M(&MJ^')E<R!V960@:6YN;&]G9VEN9R!T
M:6P@)7,N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S
M+FEN8SHQ-PIM<V=I9"`B1&%T7V4B"FUS9W-T<B`B1&%T;R(*"B,Z(&UE<W-A
M9V4N<&AP.C(V,B!T:')E860N<&AP.C$T.`IM<V=I9"`B1&%T92(*;7-G<W1R
M(")$871O(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B4VQE='1E="(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C,*;7-G:60@(D1E8VQI;F5D.B`B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")3;&5T="(*"B,Z('1E;7!L
M871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN8SHQ.`IM<V=I9"`B
M1&5F875L="!396%R8V@@1FEE;&0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR,PIM<V=I9"`B1&5F875L="!S;W)T:6YG(&-R:71E
M<FEA.B(*;7-G<W1R(")3=&%N9&%R9"!S;W)T97)I;F=S:W)I=&5I97(Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS,PIM<V=I9"`B1&5F875L="!S
M;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B4W1A;F1A<F0@<V]R=&5R:6YG
M<W)E:VME9OAL9V4Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V
M-0HC+"!F=7IZ>0IM<V=I9"`B1&5L96=A=&5D(@IM<V=S='(@(E-L971T970B
M"@HC.B!F;VQD97)S+G!H<#HT,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C8X"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,C0T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHR-2!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS
M9W-T<B`B4VQE='0B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@)7,@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX
M-0IM<V=I9"`B1&5L971E($-U<G)E;G0@2V5Y<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHY"FUS9VED(")$96QE=&4@
M1F]L9&5R*',I(@IM<V=S='(@(E-L971T(&UA<'!E;BAE*2(*"B,Z(&9O;&1E
M<G,N<&AP.C(X-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%-E;&5C=&5D($9O
M;&1E<G,B"FUS9W-T<B`B4VQE='0@;6%P<&5N*&4I(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@4W1A=&EO;F5R>2(*;7-G<W1R(")3;&5T="!M87!P96XH92DB"@HC.B!F
M;VQD97)S+G!H<#HT,3D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!6:7)T=6%L
M($9O;&1E<B(*;7-G<W1R(")6:7)T=65L;&4@;6%P<&5R(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T
M8VAE9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T
M92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T
M<B`B4VQE='0@9V%M;&4@;6%P<&5R(&UE9"!S96YD=&4@;65L9&EN9V5R('#E
M(&)E9WEN;F5L<V5N(&%V(&WE;F5D96X_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,U,`IM<V=I9"`B1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R
M<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(E-L971T(&=A;6QE
M(&UA<'!E<B!M960@<V5N9'1E(&UE;&1I;F=E<B!PY2!B96=Y;FYE;'-E;B!A
M=B!MY6YE9&5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3<*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!S<&%M(&UE<W-A9V5S(@IM<V=S='(@(E-L
M971T(&UE;&1I;F=E<B(*"B,Z(&UE<W-A9V4N<&AP.C4P,R!M86EL8F]X+G!H
M<#HW-#`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,`HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,X('1E;7!L871E<R]M86EL8F]X
M+VQE9V5N9"YI;F,Z.`IM<V=I9"`B1&5L971E9"(*;7-G<W1R(")3;&5T=&5T
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV,PIM<V=I9"`B1&5L
M971E9"!M97-S86=E<R(*;7-G<W1R(")3;&5T=&5D92!M96QD:6YG97(B"@HC
M.B!C;VUP;W-E+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T960@=&AE(&%T=&%C:&UE;G0@7"(E<UPB+B(*;7-G<W1R(")3;&5T
M=&5T(&5T('9E9&QE9V<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y
M"FUS9VED(")$96QE=&EN9R!A;F0@36]V:6YG($UE<W-A9V5S(@IM<V=S='(@
M(E-L971T92!O9R!F;'ET=&4@;65L9&EN9V5R(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4Y,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#`*;7-G:60@(D1E
M;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S(*;7-G:60@(D1E<V-E
M;F1I;F<B"FUS9W-T<B`B4WEN:V5N9&4B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]A='1A8VAM96YT<RYI;F,Z,C$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8V.0HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B06YD
M<F4@=F%L9R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW-PIM<V=I9"`B1&5T86EL<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<W"FUS9VED(")$:6T@<VEG;F%T=7)E
M<S\B"FUS9W-T<B`B4VMY9V=E;&5G9R!S:6=N871U<C\B"@HC.B!T96UP;&%T
M97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*
M;7-G<W1R(")6:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<Y"B,L
M(&9U>GIY"FUS9VED(")$:7-P;&%Y(&-O;F9I<FUA=&EO;B!A9G1E<B!S96YD
M:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B(@HB5FES(&)E:W)E9G1E;'-E(&5T
M=&5R(.4@:&$@<V5N9'0@96X@;65L9&EN9S\@*&=J96QD97(@:W5N(&]M(&YY
M92!M96QD:6YG97(@(@HB:6MK92!B;&ER('-K<F5V970@:2!E;B!P;W`M=7`@
M8F]K<RDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED(")$
M:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-SDR"FUS9VED(")$:7-P;&%Y('!O<"UU<"!N
M;W1I9FEC871I;VX@;V8@;F5W(&UA:6P_(@IM<V=S='(@(E9A<G-L92!N>2!P
M;W-T(&UE9"!P;W`M=7`@;65L9&EN9S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S4X"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%-P86U<(B!L
M:6YK(&EN('1H92!M96YU8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S4P"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%1R
M87-H7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R(")6:7-N:6YG<W9A;&<B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,C8*;7-G:60@(D1O($Y/5"!M
M871C:"(*;7-G<W1R("))2TM%('1I;&9R961S<W1I;&PB"@HC.B!T96UP;&%T
M97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B1&\@3F]T($-H96-K
M($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B26MK92!S92!E='1E
M<B!N>2!P;W-T(&D@;6%P<&5N*&4I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDU,@IM<V=I9"`B1&\@;F]T(&=E;F5R871E(&$@;&EN:R!I;B!T:&4@
M1G)O;3H@8V]L=6UN(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP.C$P-S4*
M;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD97(_(@IM<V=S
M='(@(E9I;"!D=2#E<&YE(&1E;B!M87!P96X_(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,S(*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B1&]N92(*;7-G<W1R(")&97)D:6<B
M"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,3DR"B,L('!H<"UF;W)M870*
M;7-G:60@(D1O=VYL;V%D("5S(&EN("YZ:7`@1F]R;6%T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R"FUS9VED(")$
M;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C`*;7-G
M:60@(D1O=VYL;V%D($9O;&1E<BAS*2(*;7-G<W1R("),87-T(&YE9"!M87!P
M96XH92DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,0HC
M+"!F=7IZ>0IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA
M=%TB"FUS9W-T<B`B3&%S="!N960@;6%P<&5N*&4I(@H*(SH@;&EB+TU)344O
M0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M
M870B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N<&AP
M.C<Q.2!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Q
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O>"]L
M96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S='(@(DML861D(@H*(SH@
M9F]L9&5R<RYP:'`Z,SDR"B,L(&9U>GIY"FUS9VED(")$<F%F="!F;VQD97(B
M"FUS9W-T<B`B2VQA9&1E;6%P<&4Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V9O
M;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R869T<R!F;VQD97(Z(@IM<V=S
M='(@(DML861D96UA<'!E.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M,#@*(RP@9G5Z>GD*;7-G:60@(D4M;6%I;"!!9&1R97-S(@IM<V=S='(@(D4M
M<&]S=&%D<F5S<V4B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S`Y"FUS9VED(")%
M3D0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-S0*;7-G:60@(D524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E
M;&EV97)E9"XB"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ.0IM<V=I9"`B161I="(*;7-G
M<W1R(")2961I9V5R(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C$X"B,L(&9U>GIY"FUS9VED(")%9&ET($)L86-K;&ES="(*;7-G<W1R(")3
M=F%R=&5L:7-T92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ
M,PHC+"!F=7IZ>0IM<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(E!O<W1F
M:6QT<F4B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")%9&ET(%9I<G1U86P@1F]L
M9&5R(@IM<V=S='(@(E9I<G1U96QL92!M87!P97(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]H96%D97(N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"B,L(&9U>GIY
M"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R(")(=FET;&ES=&5T(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"B,L(&9U>GIY"FUS
M9VED(")%9&ET('EO=7(@8FQA8VML:7-T(@IM<V=S='(@(D5N9')E(&UI;F4@
M9FEL=&5R<F5G;&5R(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC
M.C$S"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S(@IM<V=S='(@(D5N
M9')E(&UI;F4@9FEL=&5R<F5G;&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@V,0IM<V=I9"`B161I="!Y;W5R('!R969E<F5N8V5S(&9O<B!A8V-E
M<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")%
M9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(D5N9')E(&UI;F4@9FEL=&5R
M<F5G;&5R(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR
M,SD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B12UP;W-T861R97-S
M92(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-3<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S
M='(@(E9I9&5R97-E;F1T(&UE;&1I;F<@9G)A("5S+B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H
M<RDB"FUS9W-T<B`B4VQE='0@;6%P<&5N*&4I(@H*(SH@9F]L9&5R<RYP:'`Z
M,C@V"B,L(&9U>GIY"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD97)S(@IM
M<V=S='(@(E-L971T(&UA<'!E;BAE*2(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")%;7!T>2!4<F%S:"!F;VQD97(B"FUS
M9W-T<B`B4_AP<&5L;6%P<&4Z(@H*(SH@;&EB+TE-4"YP:'`Z.3<S"B,L(&9U
M>GIY"FUS9VED(")%;7!T>2!?4W!A;2(*;7-G<W1R(")4^&T@<_AP<&5L:W5R
M=F5N(@H*(SH@;&EB+TE-4"YP:'`Z.38V"B,L(&9U>GIY"FUS9VED(")%;7!T
M>2!?5')A<V@B"FUS9W-T<B`B5/AM('/X<'!E;&MU<G9E;B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHQ('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN
M8SHV"FUS9VED(")%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,2!T96UP;&%T97,O
M<VUI;64O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4R]-24U%(&9U
M;F-T:6]N86QI='D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,3$*;7-G:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-#(*
M;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q-R!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C4W"FUS9VED(")%;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C,X-`IM<V=I9"`B16YD(&9O<G=A<F1E9"!M97-S86=E(@IM<V=S
M='(@(E-L=71T('#E('9I9&5R97-E;F1T(&UE;&1I;F<B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S0Q"B,L(&9U>GIY"FUS9VED(")%;F0@;65S<V%G92(*;7-G
M<W1R(")'86UL92!M96QD:6YG97(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G92!F<F]M
M("5S(@IM<V=S='(@(E9I9&5R97-E;F1T(&UE;&1I;F<@9G)A("5S(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.CD*(RP@9G5Z>GD*
M;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!3<&%M(&9O;&1E
M<B(*;7-G<W1R(").879N9VD@9&5N(&YY92!S^'!P96QM87!P96X@9&EN(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z.0IM<V=I9"`B
M16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W(&1R869T<R!F;VQD97(B"FUS
M9W-T<B`B3F%V;F=I(&1E;B!N>64@:VQA9&1E;6%P<&5N(&1I;B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@(D5N
M=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R(@IM
M<V=S='(@(DYA=FYG:2!D96X@;GEE("=396YD=&4@96QE;65N=&5R)RUM87!P
M96X@9&EN(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHY
M"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A<V@@9F]L
M9&5R(@IM<V=S='(@(DYA=FYG:2!D96X@;GEE('/X<'!E;&UA<'!E;B!D:6XB
M"@HC.B!L:6(O4V5A<F-H+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B16YT:7)E
M($UE<W-A9V4B"FUS9W-T<B`B3VUA9')E<W/I<B!M96QD:6YG(@H*(SH@;65S
M<V%G92YP:'`Z,3DT(&-O;7!O<V4N<&AP.C$Q,S0@=&AR96%D+G!H<#HW,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R
M(")/<'!F^')I;F=E;B!<(B5S7"(@8FQE(&QA9W0@=&EL(&%D<F5S<V5B;VME
M;B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3@@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(Q"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,S<V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X-@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HW,B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H
M<#HQ-C,*;7-G:60@(D5R<F]R(@IM<V=S='(@(D9E:6PB"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C
M;VYN96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D5V96YT('-U8V-E
M<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")-87!P96X@7"(E<UPB(&)L92!S
M;&5T=&5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#(*;7-G:60@
M(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B2'9E<G0@,34N(&UI;G5T="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-SD*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`B2'9E<G0@,S`N('-E:W5N9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#$*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R(")(=F5R="`U+B!M:6YU='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S@S"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B2'9E
M<B!H86QV=&EM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#`*;7-G
M:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")(=F5R="!M:6YU='0B"@HC.B!F
M;VQD97)S+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"(*;7-G<W1R
M(")5='9I9"!A;&QE(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`B571V:60@86QL92(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%
M>'!A;F0@06QL($9O;&1E<G,B"FUS9W-T<B`B571V:60@86QL92!M87!P96YE
M(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED(")%>'!A;F0@1F]L9&5R(@IM
M<V=S='(@(E5T=FED(&UA<'!E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU
M,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(E5T=FED(&YA=FXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V,PIM<V=I9"`B17AP86YD(&YA
M;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H
M92!B86-K9W)O=6YD/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3@P"FUS9VED(")%>'!A;F0@=&AE(&5N=&ER92!F;VQD97(@=')E
M92!B>2!D969A=6QT(&EN('1H92!F;VQD97)S('9I97<_(@IM<V=S='(@(E5T
M=FED(&AE;&4@;6%P<&5T<F5E="!S;VT@<W1A;F1D87)D(&D@;6%P<&5V:7-N
M:6YG96X_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5D:7)E8W0N:6YC.C$P,0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD:6YG(@IM
M<V=S='(@(E5T=FED(&%L;&4B"@HC.B!L:6(O24U0+G!H<#HY.#0@;&EB+TE-
M4"YP:'`Z.3@V"B,L(&9U>GIY"FUS9VED(")&7V5T8V@@36%I;"(*;7-G<W1R
M(")(96YT(&4M<&]S="(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM
M86EL+FEN8SHR-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`T"FUS9VED(")&
M971C:"!-86EL(@IM<V=S='(@(DAE;G0@92UP;W-T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@V.0HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@36%I;"!I
M;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`B3&%G(&YY(&UE;&1I;F<@
M:2!E="!E9V5T('9I;F1U+B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O
M;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")"<G5K(&9I;'1E<G)E9VQE<B!V960@
M<.5L;V=G:6YG+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M
M("5S(@IM<V=S='(@(E9I9&5R97-E;F1T(&UE;&1I;F<@9G)A("5S+B(*"B,Z
M(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")6:61E
M<F5S96YD="!M96QD:6YG(&9R82`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP
M.C(X-2!L:6(O1F5T8VAM86EL+G!H<#HR.#<@;&EB+T9E=&-H;6%I;"YP:'`Z
M,C@Y"B,L(&9U>GIY"FUS9VED(")&971C:&UA:6PZ("(*;7-G<W1R(")(96YT
M(&4M<&]S="(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(Y,0HC+"!F=7IZ>0IM
M<V=I9"`B1F5T8VAM86EL.B!N;R!N97<@;65S<V%G97,N(@IM<V=S='(@(D1U
M(&AA<B`E<R!N>64@;65L9&EN9V5R(2(*"B,Z(&QI8B])35`N<&AP.CDY,`HC
M+"!F=7IZ>0IM<V=I9"`B1FE?;'1E<G,B"FUS9W-T<B`B1FEL=')E(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`R('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C@R"B,L(&9U>GIY"FUS9VED(")&:6QE
M(@IM<V=S='(@(D9I;'1R92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T
M<B`B06YD<F4@=F%L9R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHY"B,L(&9U>GIY"FUS9VED(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`B
M1FEL=&5R<F5G;&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P,`IM
M<V=I9"`B1FEL=&5R(&UE<W-A9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*
M;7-G<W1R(")&:6QT<F5R('9U;&?F<G0@;65L9&EN9W-I;FYH;VQD+B(*"B,Z
M('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,3$*;7-G:60@(D9I
M;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&
M:6QT97)S(@IM<V=S='(@(D9I;'1R92(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+VYO=&%C=&EV92YI;F,Z,PIM<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#8*;7-G
M:60@(D9I;F0B"FUS9W-T<B`B4_AK(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDP-0HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@36%I;&)O>"!086=E(@IM
M<V=S='(@(D;X<G-T92!S:61E(@H*(SH@;6%I;&)O>"YP:'`Z,S0U"FUS9VED
M(")&:7)S="!086=E(@IM<V=S='(@(D;X<G-T92!S:61E(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C(Q"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R
M(")6:61E<F5S96YD(@H*(SH@9F]L9&5R<RYP:'`Z,C8V('1E;7!L871E<R]F
M;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G:60@(D9O;&1E<B!!
M8W1I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C,P,R!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY"B,Z('1E;7!L
M871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z-@HC.B!T96UP;&%T
M97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C$P"FUS9VED(")&;VQD
M97(@3F%V:6=A=&]R(@IM<V=S='(@(DUA<'!E;F%V:6=A=/AR(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D9O;&1E<B!3
M=6UM87)Y(@IM<V=S='(@(F9E8G)U87(B"@HC.B!A8VPN<&AP.C(T"FUS9VED
M(")&;VQD97(@<VAA<FEN9R!I<R!N;W0@96YA8FQE9"XB"FUS9W-T<B`B(@H*
M(SH@9F]L9&5R<RYP:'`Z-C(*;7-G:60@(D9O;&1E<B!U<V4@:7,@;F]T(&5N
M86)L960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-CD*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M86EL
M8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@(B(*
M"B,Z(&-O;7!O<V4N<&AP.C<X,"!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,34*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,C$*;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`B5FED97)E<V5N9"(*"B,Z
M(&-O;7!O<V4N<&AP.C<V-0IM<V=I9"`B1F]R=V%R9#HB"FUS9W-T<B`B5FED
M97)E<V5N9#HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8Y"B,L(&9U>GIY"FUS
M9VED(")&;W)W87)D960@;65S<V%G92(*;7-G<W1R(")3;'5T="!PY2!V:61E
M<F5S96YD="!M96QD:6YG(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,V-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")&;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM
M<V=S='(@(E9I9&5R97-E;F1T(&UE;&1I;F<@9G)A("5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0X,PHC+"!F=7IZ>0IM<V=I9"`B1G)E92]"
M=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(E-E<G9E<FEN9F]R;6%S:F]N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y-`IM<V=I9"`B1G)E92]"
M=7-Y(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.#@*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*;7-G:60@(D9R964O
M0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R;U]M
M(@IM<V=S='(@(D%V<V5N9&5R(@H*(SH@;65S<V%G92YP:'`Z,C8S('1H<F5A
M9"YP:'`Z,30Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.CDY"B,Z
M(&QI8B]396%R8V@N<&AP.C(R"FUS9VED(")&<F]M(@IM<V=S='(@(D9R82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D
M<F5S<R(*;7-G<W1R(")&<F$M861R97-S92(*"B,Z(&-O;7!O<V4N<&AP.C<W
M-R!C;VUP;W-E+G!H<#HW.#$*;7-G:60@(D9W9#HB"FUS9W-T<B`B1G=D.B(*
M"B,Z(&-O;7!O<V4N<&AP.C$R.30*(RP@9G5Z>GD*;7-G:60@(D9W9#H@(@IM
M<V=S='(@(D9W9#HB"@HC.B!C;VUP;W-E+G!H<#HQ,CDV"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E<R(*
M;7-G<W1R(")3;'5T="!PY2!V:61E<F5S96YD="!M96QD:6YG(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X"B,L(&9U>GIY"FUS9VED(")'96YE<F%L($]P=&EO;G,B"FUS
M9W-T<B`B06YD<F4@=F%L9R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHS-PIM<V=I9"`B1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!
M4"!O;FQY*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I
M;VYS+FEN8SHS,0IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@=&AR96%D+G!H
M<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B
M3F5S=&4@;65L9&EN9R(*"B,Z(&QI8B])35`N<&AP.C0Y.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y(&]F
M(%PB)7-<(B(*;7-G<W1R("),96=G('1I;"!I(&%D9')E<W-E8F]K("@E<RDB
M"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3,U"FUS9VED(")'<F%N="!A
M8V-E<W,B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-30V(&QI8B]&:6QT
M97(N<&AP.C$P-2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HY-0HC.B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#(@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,3`T"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V,R!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$V"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C8X"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D
M+G!H<#HW.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`HC.B!L:6(O
M34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C$W,PHC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ
M,C`@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3(W"FUS9VED(")(15)%
M(@IM<V=S='(@(DA%4B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,2!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$W"B,Z(&QI8B]-
M24U%+U9I97=E<B]R96QA=&5D+G!H<#HX,`IM<V=I9"`B2%1-3"(*;7-G<W1R
M("(B"@HC.B!C;VUP;W-E+G!H<#HR-38*;7-G:60@(DA434P@5F5R<VEO;B!O
M9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C4X"FUS9VED(")(96%D97)S(@IM<V=S='(@(DUE;&1I;F=S
M:&]D97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*
M;7-G:60@(DAE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8X"FUS
M9VED(")(:61D96XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8V-PHC+"!F=7IZ>0IM<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W
M(@IM<V=S='(@(E1RY61V:7-N:6YG(@H*(SH@;6%I;&)O>"YP:'`Z,S8W"FUS
M9VED(")(:61E($1E;&5T960B"FUS9W-T<B`B4VMJ=6P@<VQE='1E9&4@96QE
M;65N=&5R(@H*(SH@9F]L9&5R<RYP:'`Z,CDX"FUS9VED(")(:61E(%5N<W5B
M<V-R:6)E9"(*;7-G<W1R(")3:VIU;"!U86)O;FYE<G1E(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S
M='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y-R!M86EL8F]X+G!H<#HW,C0@=&5M
M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,@IM<V=I9"`B2&EG:"!0<FEO
M<FET>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8X.`IM<V=I9"`B2&]W(&1O('EO=2!W86YT('1O
M(&1I<W!L87D@871T86-H;65N=',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(DAO=R!T;R!A='1R
M:6)U=&4@<75O=&5D(&QI;F5S(&EN(&$@<F5P;'DB"FUS9W-T<B`B2'9O<F1A
M;B!S:V%L('-I=&5R=&4@;&EN:F5R(&D@970@<W9A<B!R>6MK97,@:6YN.B(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3,T"FUS9VED("))34%0(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3(Y"FUS9VED
M("))34%0("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,SDQ"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E
M<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ-C8@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ-#8*;7-G:60@
M(DE-05`@;W9E<B!34TPB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HQ-3(*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D
M(&-E<G1I9FEC871E*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$V-PIM<V=I9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N
M960I(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S8X"FUS
M9VED("))34%0('-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38U(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS9VED("))34%0+"!N;R!43%,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HT.0IM<V=I9"`B
M24U!4"]03U`S($UA:6P@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!L:6(O24U0
M+G!H<#HX-C8*;7-G:60@(DE.0D]8(@IM<V=S='(@(DE.3D)/2U,B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R
M(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N
M(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L
M9&5R<U]C;VYF:7)M+FAT;6PZ,3(*(RP@9G5Z>GD*;7-G:60@(DEF('EO=2!C
M;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B
M92!L;W-T(2(*;7-G<W1R(")!;&QE(&UE;&1I;F=E<B!I(&1E;FYE(&UA<'!E
M;BAE*2!V:6P@8FQI('-L971T970A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C@R"FUS9VED("))9VYO<F4B"FUS9W-T<B`B26=N;W+I
M<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,PIM<V=I
M9"`B26=N;W)E($%L;"(*;7-G<W1R("))9VYO<NER(&%L="(*"B,Z('1E;7!L
M871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHX"FUS9VED("));6%G92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(P
M"B,L(&9U>GIY"FUS9VED("));7!O<G0B"FUS9W-T<B`B5FEK=&EG(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@U('1E;7!L871E<R]P
M9W`O:6UP;W)T7VME>2YI;F,Z-C4*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!+
M97DB"FUS9W-T<B`B5FEK=&EG(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$S.0HC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`B
M5FEK=&EG(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C<*
M(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!-97-S86=E<R(*;7-G<W1R(")6:6MT
M:6=E(&UE;&1I;F=E<B(*"B,Z('!G<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!0
M1U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z.3$*;7-G:60@(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$T"FUS
M9VED("));7!O<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM<V=I9"`B
M26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O
M<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHT,@IM<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("))
M;7!O<G0@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@
M4R]-24U%($ME>2(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@
M(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N:6YC.C$V
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@)7,@:6YT
M;R!F;VQD97(@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,B!M
M86EL8F]X+G!H<#HW,S0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,38@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R=&%N="(*;7-G<W1R
M(")6:6MT:6<B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C0W"FUS
M9VED("));7!O<G1A;G0@;65S<V%G97,B"FUS9W-T<B`B5FEK=&EG92!M96QD
M:6YG97(B"@HC.B!F;VQD97)S+G!H<#HQ-C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R=&5D("5D(&UE<W-A9V5S(&9R;VT@)7,N(@IM<V=S
M='(@(E9I9&5R97-E;F1T(&UE;&1I;F<@9G)A("5S+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW-S,*;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T
M<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,S@T(&QI8B]&;VQD97(N<&AP.C@V(&QI
M8B]&;VQD97(N<&AP.C(Q-"!L:6(O24U0+G!H<#HS,3,*(SH@;&EB+TE-05`O
M5')E92YP:'`Z,3$T(&QI8B])34%0+U1R964N<&AP.C(Q.0IM<V=I9"`B26YB
M;W@B"FUS9W-T<B`B26YN8F]K<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.3(*(RP@9G5Z>GD*;7-G:60@(DEN8VQU9&4@82!B<FEE9B!S=6UM87)Y
M(&]F('1H92!H96%D97(@:6X@82!R97!L>3\B"FUS9W-T<B`B26YN:VQU9&5R
M(&]R9VEN86P@;65L9&EN9R!I('-V87(_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN
M(&$@<F5P;'D_(@IM<V=S='(@(DEN;FML=61E<B!O<F=I;F%L(&UE;&1I;F<@
M:2!S=F%R/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP
M.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$S,`HC+"!F=7IZ>0IM
M<V=I9"`B26YF;R(*;7-G<W1R("));FYB;VMS(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G
M:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED("));F9O<FUA=&EO;B!O;B!097)S
M;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHU,#<*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N
M:G,Z.3@*(RP@9G5Z>GD*;7-G:60@(DEN;&EN92(*;7-G<W1R(")I;F=E;B(*
M"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("))
M;G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R<V]N
M86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T(%!E<G-O
M;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED("));G-E<G0@4'5B;&EC
M(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E9"!F
M;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP
M.C4X-"!M86EL8F]X+G!H<#HV,C8*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M061D<F5S<R(*;7-G<W1R(")%+7!O<W1A9')E<W-E(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@4F5M;W1E($UA:6QB
M;W@B"FUS9W-T<B`B(@H*(SH@8V]M<&]S92YP:'`Z,34X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@
M861D<F5S<SH@)7,N(@IM<V=S='(@(E5L;W9L:6<@=&5G;B!I(&4M<&]S="!A
M9')E<W-E;BXB"@HC.B!S;6EM92YP:'`Z.#(@<&=P+G!H<#HQ-@IM<V=I9"`B
M26YV86QI9"!K97DB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HQ.38*;7-G:60@
M(DEN=F%L:60@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B
M"@HC.B!P9W`N<&AP.C$W,0IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@
M<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHQ,@IM<V=I9"`B26YV97)T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B2T(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Q,PIM<V=I9"`B
M2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO
M;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E
M;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED(")+97D@
M:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E
M;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P+FEN8SHS
M.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@
M:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C
M;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME
M>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,38*
M;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<N5K(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!-86EL8F]X
M(%!A9V4B"FUS9W-T<B`B4VES=&4@<VED92(*"B,Z(&UA:6QB;W@N<&AP.C,U
M.`IM<V=I9"`B3&%S="!086=E(@IM<V=S='(@(E-I<W1E('-I9&4B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#D*;7-G:60@(DQI7VYK
M($%T=&%C:&UE;G1S(@IM<V=S='(@(DQI;FL@=F5D;&5G9R(*"B,Z(&%T=&%C
M:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#8S"B,L(&9U>GIY"FUS
M9VED("),:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T
M<B`B3&EN:R!V961L96=G(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$P.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.#(*;7-G:60@
M(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C
M=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL("(*(F]N;'D@<V5E
M(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC:71L>2DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-0IM<V=I9"`B
M3&ES=&EN9R!I;B!T:&4@2&5A9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3&]C
M86P@36%I;&)O>#HB"FUS9W-T<B`B4&]S=&)O:W,B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C<T"B,L(&9U>GIY"FUS9VED("),;V-A=&EO;B(*
M;7-G<W1R(")(86YD;&EN9R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C(U"FUS9VED("),;V<@:6XB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!L
M:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@
M(DQO9R!I;B!T;R`E<R(*;7-G<W1R("),;V=G(&EN;B!PY2`E<R(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,W"B,L(&9U>GIY"FUS9VED("),
M;V=I;B(*;7-G<W1R("),;V=G(&EN;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B26YN;&]G9VEN
M9W-O<'!G879E<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(Y
M.2!M86EL8F]X+G!H<#HW,C<@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN
M8SHQ,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-PIM<V=I9"`B3&]W97-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z
M-#0*(RP@9G5Z>GD*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM<V=S='(@(E!O
M<W1F:6QT<F4B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z
M,3,*(RP@9G5Z>GD*;7-G:60@(DUA:6PB"FUS9W-T<B`B4&]S=&)O:W,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*(RP@9G5Z>GD*;7-G:60@(DUA
M:6P@4')E=FEE=W,B"FUS9W-T<B`B4&]S=&9I;'1R92(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@
M<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T;SHB"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z-#`R"FUS9VED(")-86EL8F]X(@IM<V=S='(@(E!O<W1B;VMS
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!F=7IZ>0IM<V=I
M9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M(")6:7-N:6YG<W9A;&<B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S
M(%-E96XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N
M<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL($UE<W-A9V5S(&EN($9O;&1E<B!A
M<R!5;G-E96XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM<V=S='(@(DUA<FME<B!S;VTZ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U,`IM<V=I9"`B36%R:R!D:69F
M97)E;G0@;&5V96QS(&]F('%U;W1I;F<@=VET:"!D:69F97)E;G0@8V]L;W)S
M/R(*;7-G<W1R(")-97)K(&9O<G-K:F5L;&EG92!N:7;E97(@878@<W9A<FUE
M;&1I;F=E<B!M960@9F]R<VMJ96QL:6=E(&9A<F=E<C\B"@HC.B!T96UP;&%T
M97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G
M97,@87,@<V5E;C\@*$E-05`@;VYL>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8U.`IM<V=I9"`B36%R:R!S:6UP;&4@;6%R:W5P
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z
M-#8*;7-G:60@(DUA=&-H($%L;"!1=65R:65S(@IM<V=S='(@(E1I;&9R961S
M<W1I;&P@86QL92!K<FET97)I97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE
M861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R(")4
M:6QF<F5D<W-T:6QL(&5T="!K<FET97)I=6TB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FEN8SHU,3,*;7-G:60@(DUA>&EM=6T@071T86-H;65N
M="!3:7IE(@IM<V=S='(@(DUA:W,@<W3X<G)E;'-E('#E('9E9&QE9V<B"@HC
M.B!L:6(O87!I+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!.=6UB
M97(@;V8@1F]L9&5R<R(*;7-G<W1R(")-86MS(&%N=&%L;"!V961L96=G(&[E
M9&0B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.30*;7-G
M:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N(@IM
M<V=S='(@(DUA:W,@86YT86QL('9E9&QE9V<@;N5D9"(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X.0IM<V=I9"`B36%X:6UU;2!T;W1A
M;"!A='1A8VAM96YT('-I>F4@<F5A8VAE9"XB"FUS9W-T<B`B36%K<R!T;W1A
M;"!S=/AR<F5L<V4@<.4@=F5D;&5G9R!NY61D(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C8R-@IM<V=I9"`B365E=&EN9R!#86YC96QL871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4W-0HC
M+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R(")3
M97)V97)I;F9O<FUA<VIO;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.#4*;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I9"`B365E=&EN9R!2
M97!L>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-3DX"FUS9VED(")-965T:6YG(%5P9&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C`S"FUS9VED(")-965T:6YG(%5P9&%T
M92!297%U97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T<F5E7V9O;&1E
M<G,N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE;G4@1F]L9&5R($QI<W0B"FUS
M9W-T<B`BQ7!N92!M87!P92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,S$*;7-G
M:60@(DUE<W-A9V4B"FUS9W-T<B`B365L9&EN9R(*"B,Z(&-O;7!O<V4N<&AP
M.C4V,"!C;VUP;W-E+G!H<#HU.#<@8V]M<&]S92YP:'`Z-C0Q(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO;B(*
M;7-G<W1R(")3:W)I=B!M96QD:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(DUE;&1I;F=S
M9&%T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M365S<V%G92!/<'1I;VYS(@IM<V=S='(@(DUE;&1I;F=E<B!T:6PB"@HC.B!S
M96%R8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T<B`B
M4_AK(&5T=&5R(&UE;&1I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS9W-T<B`B365L9&EN9W-S=/AR
M<F5L<V4B"@HC.B!M97-S86=E+G!H<#HS.#0*;7-G:60@(DUE<W-A9V4@4V]U
M<F-E(@IM<V=S='(@(DUE;&1I;F=S:VEL9&4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C8*;7-G:60@(DUE<W-A9V4@5FEE=VEN9R(*;7-G<W1R(")-
M96QD:6YG<W9I<VYI;F<B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`B365L9&EN9W-F;&%G
M9R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#,*;7-G:60@(DUE
M<W-A9V4@9F]L9&5R<R(*;7-G<W1R(")-96QD:6YG<VUA<'!E<B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DUE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")-96QD:6YG<VUA<'!E<B(*"B,Z
M(&UA:6QB;W@N<&AP.C8V-PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!H87,@
M871T86-H;65N=',B"FUS9W-T<B`B365L9&EN9R!T:6QF<F5D<W-T:6QL97(B
M"@HC.B!M86EL8F]X+G!H<#HV-3@*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@
M:7,@96YC<GEP=&5D(@IM<V=S='(@(DUE;&1I;F=S9F5L="(*"B,Z(&UA:6QB
M;W@N<&AP.C8U,PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!I<R!S:6=N960B
M"FUS9W-T<B`B365L9&EN9W-F96QT(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H
M96%D97(N:6YC.C,S"FUS9VED(")-97-S86=E(&UA=&-H97,B"FUS9W-T<B`B
M365L9&EN9R!T:6QF<F5D<W-T:6QL97(B"@HC.B!C;VUP;W-E+G!H<#HX,C0@
M8V]M<&]S92YP:'`Z.#,X"B,L(&9U>GIY"FUS9VED(")-97-S86=E(')E9&ER
M96-T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")-96QD:6YG96X@97(@<V5N
M9'0B"@HC.B!C;VUP;W-E+G!H<#HQ,#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A
M=F5D('1O("5S(@IM<V=S='(@(DUE;&1I;F=E;B!E<B!S96YD="P@;65N(&)L
M92!I:VME(&QA9W)E="!I(@H*(SH@8V]M<&]S92YP:'`Z,3$T,R!C;VUP;W-E
M+G!H<#HQ,34X"B,L(&9U>GIY"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R(")-96QD:6YG96X@97(@<V5N9'0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.30Q"FUS9VED(")-97-S86=E<R!P97(@<&%G
M92!I;B!T:&4@;6%I;&)O>"!V:65W+B(*;7-G<W1R(")!;G1A;&P@;65L9&EN
M9V5R('!R+B!S:61E(&[E<B!P;W-T8F]K<V5N('9I<V5S+B(*"B,Z(&UA:6QB
M;W@N<&AP.C,R,@IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B365L9&EN
M9V5R('1I;"(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHR.0IM<V=I9"`B
M36]D:69Y(@IM<V=S='(@(D5N9')E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M97AP86YD+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E('1H86X@
M;VYE(&%D9')E<W,@9F]U;F0@9F]R(&9I96QD(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E
M(@IM<V=S='(@(D9L>71T(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S$V"B,L(&9U>GIY"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T
M<B`B9FQY='0@;F5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.`IM
M<V=I9"`B36]V92!S<&%M(&UE<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I
M;FYO8V5N="!M97-S86=E<R!T;R!)3D)/6"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3`*(RP@9G5Z>GD*;7-G:60@(DUO=F4@
M=&\@9F]L9&5R(@IM<V=S='(@(G9E;&<@;6%P<&4B"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,30*(RP@9G5Z>GD*;7-G:60@(DUO
M=F4@=7`B"FUS9W-T<B`B9FQY='0@;W!P(@H*(SH@;&EB+TU)344O5FEE=V5R
M+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@(DUU;'1I<&%R="]A;'1E<FYA
M=&EV92(*;7-G<W1R("(B"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z
M,34R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!-97-S86=E(%9I97<B"FUS
M9W-T<B`B365L9&EN9W-V:7-N:6YG(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E
M9F%U;'1S96%R8VAS96QE8W0N:6YC.C4*;7-G:60@(DY/3D4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,@IM<V=I9"`B3D]412(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(S."!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C@X"FUS9VED(").86UE(@IM<V=S='(@(DYA=FXB"@HC.B!P9W`N<&AP
M.C$Q,`IM<V=I9"`B3F%M92!A;F0O;W(@96UA:6P@8V%N(&YO="!B92!E;7!T
M>2(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<X
M"B,L(&9U>GIY"FUS9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`B2&%N9&QI
M;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W.`IM
M<V=I9"`B3F5V97(B"FUS9W-T<B`B06QD<FDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-38P"B,L(&9U>GIY"FUS9VED(").979E<B!S879E(&%T=&%C
M:&UE;G1S(@IM<V=S='(@(E-L971T970@970@=F5D;&5G9RXB"@HC.B!T96UP
M;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`B3GDB
M"@HC.B!L:6(O24U0+G!H<#HU-C,*;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T
M<B`B3GD@;6%P<&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#@*;7-G
M:60@(DYE=R!-86EL(@IM<V=S='(@(DYY('!O<W0B"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,3D@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,S,*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!-97-S86=E(@IM<V=S='(@(DYE<W1E(&UE
M;&1I;F<B"@HC.B!M86EL8F]X+G!H<#HW-S8@;&EB+TU)344O2&5A9&5R<RYP
M:'`Z,3DR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G
M92!T;R`E<R(*;7-G<W1R(").>64@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHQ.0IM<V=I9"`B3F5W(&UE<W-A9V5S(@IM<V=S
M='(@(DYY92!M96QD:6YG97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3,S"FUS9VED(").97AT(@IM<V=S='(@(DYE<W1E(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHS,PIM<V=I
M9"`B3F5X="!-97-S86=E(@IM<V=S='(@(DYE<W1E(&UE;&1I;F<B"@HC.B!M
M86EL8F]X+G!H<#HS-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(").97-T
M92!S:61E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30R
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S<*;7-G:60@(DYO(@IM<V=S='(@
M(DYE:2(*"B,Z('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO($-E<G1I9FEC871E
M(&9O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y
M<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3D*;7-G:60@(DYO($ME>7,@
M:6X@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HS-S4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO($UE<W-A9V5S(@IM<V=S='(@
M(DYY92!M96QD:6YG97(B"@HC.B!P9W`N<&AP.C$S-PIM<V=I9"`B3F\@4$=0
M('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I
M9FEC871E(%!R97-E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QB;W@N<&AP
M.C,R.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT(@IM<V=S='(@
M(E)E='1E="!T96MS="(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z
M,34*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(B(*"B,Z
M('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L:6,@:V5Y(&EM
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD+B(*
M;7-G<W1R(")6961L96=G(@H*(SH@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#`*
M;7-G:60@(DYO(&5M86EL(&EN9F]R;6%T:6]N(&QO8V%T960@:6X@=&AE('!U
M8FQI8R!K97DN(@IM<V=S='(@(B(*"B,Z(&%C;"YP:'`Z-S(@86-L+G!H<#HY
M.`HC+"!F=7IZ>0IM<V=I9"`B3F\@9F]L9&5R('-E;&5C=&5D+B(*;7-G<W1R
M(")I;F=E;B!M87!P92!V86QG="(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ-#$*;7-G:60@(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R
M(&YE=R!M86EL+B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HR,3@@;&EB
M+T9O;&1E<BYP:'`Z-3`P(&QI8B]&;VQD97(N<&AP.C4U,`IM<V=I9"`B3F\@
M9F]L9&5R<R!W97)E('-P96-I9FEE9"(*;7-G<W1R("));F=E;B!M87!P92!E
M<B!V86QG="(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#<*(RP@9G5Z
M>GD*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B"FUS9W-T
M<B`B26MK92!S;&5T=&5D92!M96QD:6YG97(B"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,30T"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@
M=6YS965N(&UE<W-A9V5S(@IM<V=S='(@(DEK:V4@<VQE='1E9&4@;65L9&EN
M9V5R(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R-0HC+"!F=7IZ>0IM<V=I9"`B
M3F\@;65S<V%G92!B;V1Y('1E>'0B"FUS9W-T<B`B9FQY='0@;65L9&EN9V5N
M('1I;"(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS-S$*(RP@9G5Z>GD*;7-G:60@
M(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N(@IM<V=S='(@(E/X
M:V5T('!A<W-E="!I:VME(&UE9"!N;V5N(&UE;&1I;F=E<B(*"B,Z('!G<"YP
M:'`Z,3@Y"FUS9VED(").;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP
M;W)T960N(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,38U"FUS9VED(").;R!P
M97)S;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@<VUI;64N<&AP.C(P,0IM<V=I9"`B3F\@<&5R<V]N86P@4R]-24U%(&-E
M<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@<W!E;&QI;F<N
M<&AP.C(R,`IM<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I
M9W5R960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@
M(DEN9V5N('-T879E9F5I;"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL
M:6YG+FEN8SHQ,#`*;7-G:60@(DYO('-U9V=E<W1I;VYS(@IM<V=S='(@(DEN
M9V5N(&9O<G-L86<B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4V-`IM<V=I
M9"`B3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T:&]D(&-O
M=6QD(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C8X(&%C;"YP
M:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO('5S97(@<W!E8VEF:65D+B(*;7-G
M<W1R("));F=E;B!M87!P92!E<B!V86QG="(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW,#D*;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Q('1E;7!L
M871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#`*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S4@=&5M<&QA=&5S+W!R969S+W-P
M86US96QE8W0N:6YC.C(T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-C0*;7-G:60@(DYO;F4B"FUS9W-T<B`B26YG96XB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.34*;7-G:60@(DYO<FUA;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(Q('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D
M(@IM<V=S='(@(DEK:V4@<VQE='1E="(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]N879I9V%T92YI;F,Z,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHR,PHC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0R
M"FUS9VED(").;W0@1')A9G0B"FUS9W-T<B`B26MK92!K;&%D9"(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z."!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C$W"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,S0*;7-G:60@(DYO="!);7!O<G1A;G0B"FUS9W-T<B`B
M579I:W1I9R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*
M;7-G:60@(DYO="!097)S;VYA;"(*;7-G<W1R(")):VME('!E<G-O;FQI9R(*
M"B,Z(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP
M.C$S-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L
M:60@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T960@;65S<V%G97,B"FUS
M9W-T<B`B26MK92!S;&5T=&5D92!M96QD:6YG97(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C4Q"FUS9VED(").;W0@:6UP;W)T86YT(&UE<W-A
M9V5S(@IM<V=S='(@(E5V:6MT:6=E(&UE;&1I;F=E<B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO
M=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$V"B,L(&9U>GIY"FUS9VED(").
M;W1H:6YG(@IM<V=S='(@(E-I=&%T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-PHC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&UO;G1H<R!T;R!K
M965P(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL
M>2XB"FUS9W-T<B`B(@HB06YT86QL(&=A;6QE(&UA<'!E<B!M960@<V5N9'1E
M(&5L96UE;G1E<B!S;VT@<VMA;"!B96AO;&1E<R!V960@;>5N961T;&EG("(*
M(G-L971T:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U.0IM<V=I
M9"`B3G5M8F5R(&]F(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF
M(&1E;&5T:6YG(&UO;G1H;'DN(@IM<V=S='(@(B(*(D%N=&%L;"!G86UL92!M
M87!P97(@;65D('-E;F1T92!E;&5M96YT97(@<V]M('-K86P@8F5H;VQD97,@
M=F5D(&WE;F5D=&QI9R`B"B)S;&5T=&EN9R(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,C4T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU-3(*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,PIM<V=I9"`B
M3TLB"FUS9W-T<B`B3TLB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z-2!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHT.`IM<V=I9"`B3U(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ-0IM<V=I9"`B
M3VQD(&UE<W-A9V5S(@IM<V=S='(@(D=A;6QE(&UE;&1I;F=E<B(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H
M<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E
M9"XB"FUS9W-T<B`B1V%M;&4@;6%P<&5R(&UE9"!S96YD=&4@96QE;65N=&5R
M(&)L:7(@9FIE<FYE="XB"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C4*
M;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD97)S('=I=&@@=6YR96%D(&UE<W-A
M9V5S(&EN('1H96T_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&9O
M;&1E<B!S:&]U;&0@8F4@<V5L96-T960@9F]R('1H:7,@86-T:6]N+B(*;7-G
M<W1R(")696YN;&EG<W0@=F5L9R!B87)E(.EN(&UA<'!E(&9O<B!D96YN92!O
M<&5R87-J;VYE;BXB"@HC.B!T96UP;&%T97,O;65N=2YI;F,Z,3`@=&5M<&QA
M=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")/<&5N($9O7VQD97(B
M"FUS9W-T<B`BQ7!N92!M87!P92(*"B,Z(&9O;&1E<G,N<&AP.C0R-PHC+"!F
M=7IZ>0IM<V=I9"`B3W!E;F5D($9O;&1E<B(*;7-G<W1R("+%<&YE(&UA<'!E
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P-0IM<V=I9"`B3W!T
M:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL+G!H
M<#HS,R!T96UP;&%T97,O9F5T8VAM86EL+W1O<"YI;F,Z,PHC.B!T96UP;&%T
M97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z-@IM<V=I9"`B3W1H97(@36%I
M;"!!8V-O=6YT<R(*;7-G<W1R(")!;F1R92!M86EL:V]N=&]E<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I;VYS
M(@IM<V=S='(@(D%N9')E('9A;&<B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(P,0IM<V=I9"`B3W5T8F]U;F0@4V5R=F5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,38U"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3`*;7-G:60@(E!'4"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N
M:6YC.C<*(RP@9G5Z>GD*;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS
M9W-T<B`B079B<GET(&UE;&1I;F<B"@HC.B!C;VUP;W-E+G!H<#HS-3@*(RP@
M9G5Z>GD*;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S='(@(D9E:6PB"@HC.B!C
M;VUP;W-E+G!H<#HS,S<*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR
M87-E(&9O<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@HC+"!F=7IZ>0IM<V=I9"`B4$=0
M($]P=&EO;G,B"FUS9W-T<B`B5F%L9R(*"B,Z('!G<"YP:'`Z,S`*;7-G:60@
M(E!'4"!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHU-0IM<V=I9"`B4$=0(%!E<G-O;F%L($ME>7!A:7(@
M<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"FUS9VED
M(")01U`@4'5B;&EC($ME>2!497AT(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z
M,30Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC($ME
M>2!F;W(@7"(E<R`H)7,I7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS
M9W-T<B`B36%P<&5N(%PB)7-<(B!B;&4@;W!P<F5T=&5T+B(*"B,Z('!G<"YP
M:'`Z,C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")01U`@4'5B;&EC
M($ME>2!F;W(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS
M9W-T<B`B36%P<&5N(%PB)7-<(B!B;&4@<VQE='1E="XB"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,30*;7-G:60@(E!'4"!0=6)L:6,@2V5Y<FEN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N
M:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!'4"!3:6=N($UE<W-A9V4B"FUS9W-T
M<B`B4V5N9"!M96QD:6YG(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP
M=%]L:7-T+FEN8SHY"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HR,#(*(RP@9G5Z>GD*;7-G:60@(E!'
M4"!P<FEV871E(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E-I
M9VYA='5R96X@8FQE(&5R<W1A='1E="XB"@HC.B!P9W`N<&AP.C$W-PIM<V=I
M9"`B4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B
M4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P.`IM<V=I9"`B
M(@HB4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE
M(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDU
M"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV
M92!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I9"`B
M(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U
M<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2`B"B)S970@=&\@
M9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S
M971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F96%T=7)E<R!W:6QL(&YO="!W
M;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I
M;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B"FUS9W-T<B`B(@H*(SH@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G:60@(E!/4#,@*$%U=&\@1&5T96-T
M(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ,3<*;7-G:60@(E!/4#,@;W9E<B!34TPB"FUS9W-T<B`B(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,C,*;7-G:60@(E!/4#,@;W9E<B!3
M4TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$V.0IM<V=I9"`B4$]0,R!O=F5R
M(%-33"`H<V5L9BUS:6=N960I(@IM<V=S='(@(B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3$Q"FUS9VED(")03U`S+"!N;R!43%,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")086=E("5D(&]F("5D(@IM<V=S='(@(E-I9&4@)60@
M878@)60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS9VED(")0
M86=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#0*;7-G:60@(E!A9V4@=VET
M:"!T:&4@3&%S="!5;G-E96X@365S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHT,PIM<V=I9"`B4&%R="AS*2(*
M;7-G<W1R(")$96PH97(I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R
M,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!9V%I;BDB"FUS
M9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(S-2!P9W`N<&AP.C,Q,`HC+"!F=7IZ
M>0IM<V=I9"`B4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@=6YL;V%D960N(@IM
M<V=S='(@(DUE;&1I;F=E;B!E<B!S96YD="P@;65N(&)L92!I:VME(&QA9W)E
M="!I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$X('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,CD*;7-G:60@(E!A<W-P:')A
M<V4Z(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$R"FUS9VED(")087-S<&AR
M87-E<R!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z
M,3$T"FUS9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L
M871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$Y,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%S
M<V]R9"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`IM
M<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/R(*;7-G<W1R(")5=&;X<B!V961L:6ME:&]L9'-O<&5R87-J;VYE<B!V960@
M:6YN;&]G9VEN9S\B"@HC.B!A8VPN<&AP.C<V(&%C;"YP:'`Z,3`R"FUS9VED
M(")097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R(&-A;B!N;W0@8F4@8VAA;F=E
M9"XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-#DS(&UA:6QB;W@N<&AP
M.C<P,R!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(T"B,Z('1E;7!L
M871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3`*;7-G:60@(E!E<G-O;F%L(@IM
M<V=S='(@(E!E<G-O;FQI9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B4&5R<V]N
M;&EG(&EN9F]R;6%S:F]N(@H*(SH@<&=P+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G
M:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(DUE;&1I;F=E;B!E<B!S96YD="(*"B,Z('!G<"YP:'`Z
M,3(W"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B365L9&EN9V5N(&5R('-E;F1T(@H*
M(SH@<VUI;64N<&AP.C(P-PIM<V=I9"`B4&5R<V]N86P@4R]-24U%(&-E<G1I
M9FEC871E<R!.3U0@:6UP;W)T960Z("(*;7-G<W1R("(B"@HC.B!S;6EM92YP
M:'`Z,3,R"FUS9VED(")097)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R,@IM<V=I9"`B4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E
M<&QI97,@86YD(&9O<G=A<F1S/R(*;7-G<W1R("),96=G92!T:6P@<VEG;F%T
M=7)E;B!D:6X@9F]R<F%N('-V87(@;V<@=FED97)E<V5N9&EN9S\B"@HC.B!C
M;VUP;W-E+G!H<#HR-30*;7-G:60@(E!L86EN=&5X="!697)S:6]N(&]F($UE
M<W-A9V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y
M.0IM<V=I9"`B(@HB4&QA>2!S;W5N9"!O;B!N97<@;6%I;#\@(%1H:7,@<F5Q
M=6ER97,@>6]U<B!B<F]W<V5R('1O('-U<'!O<G0@96UB961D960@(@HB<V]U
M;F0@9FEL97,N("!!;&UO<W0@86QL(&1O(&]N(%=I;F1O=W,@86YD($UA8RP@
M8G5T(&]T:&5R('!L871F;W)M<R!W:6QL("(*(G)E<75I<F4@82!P;'5G:6XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N
M:6YC.C4U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z
M(@IM<V=S='(@(E9E;FYL:6=S="!S:W)I=B!I;FX@;F%V;F5T('#E(&1E;B!N
M>64@;6%P<&5N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3`R('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`T"FUS
M9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(Z
M(@IM<V=S='(@(E9E;FYL:6=S="!S:W)I=B!I;FX@;F%V;F5T('#E(&1E;B!N
M>64@;6%P<&5N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3,W"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.B(*;7-G
M<W1R(")696YN;&EG<W0@<VMR:78@:6YN(&1E="!N>64@;F%V;F5T.B(*"B,Z
M('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y
M;W5R(%!'4"!P<FEV871E(&ME>2X@66]U('=I;&P@;VYL>2!N965D('1O("(*
M(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E('!E<B`E<R!S97-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2X@66]U('=I
M;&P@;VYL>2!N965D("(*(G1O(&5N=&5R('1H:7,@<&%S<W!H<F%S92!O;F-E
M('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!R96-O;7!O<V4N<&AP
M.CDW"FUS9VED("(B"B)0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C
M;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R`B
M"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P
M;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O("(*(FQO9R!I;B!A9V%I
M;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E
M<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$
M+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<Q"B,L(&9U>GIY
M"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D+B(*;7-G<W1R
M(")696YN;&EG<W0@;W!P9VD@8G)U:V5R;F%V;B!O9R!P87-S;W)D(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-PHC+"!F=7IZ>0IM<V=I9"`B
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB"FUS9W-T<B`B5F5N;FQI
M9W-T(&]P<&=I(&)R=6ME<FYA=FX@;V<@<&%S<V]R9"(*"B,Z(&-O;7!O<V4N
M<&AP.C$P-B!L:6(O24U0+G!H<#HT-3D*;7-G:60@(E!L96%S92!R97-O;'9E
M(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB"FUS9W-T<B`B5F5N
M;FQI9W-T(')E='0@='9E='ED:6=E(&5L;&5R('5G>6QD:6=E(&%D<F5S<V5R
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*
M(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD
M('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C8Q"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y
M;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B5F5N;FQI9W-T('9E
M;&<@96X@;6%P<&4@9OAR(&1U('5T9OAR97(@;F]E;B!H86YD;&EN9V5R+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#(*(RP@9G5Z>GD*;7-G
M:60@(E!L96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L
M;W<N(@IM<V=S='(@(E9E;FYL:6=S="!V96QG(&UI;G-T(.EN(&UA<'!E(.4@
M<_AK92!I+B(*"B,Z('1E;7!L871E<R]S96%R8V@O:F%V87-C<FEP="YI;F,Z
M-#$*;7-G:60@(E!L96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T
M;R!S96%R8V@N(@IM<V=S='(@(E9E;FYL:6=S="!V96QG(&UI;G-T(.EN(&UA
M<'!E(.4@<_AK92!I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3(*;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R
M(&9O<B!T:&ES(&]P97)A=&EO;BXB"FUS9W-T<B`B5F5N;FQI9W-T('9E;&<@
M8F%R92#I;B!M87!P92!F;W(@9&5N;F4@;W!E<F%S:F]N96XN(@H*(R!(54@_
M(0HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-S,*(RP@9G5Z
M>GD*;7-G:60@(E!L96%S92!S96QE8W0@;W(@961I="!I;B!T:&4@8F]X('1O
M('1H92!R:6=H=#HB"FUS9W-T<B`B5F5N;FQI9W-T('9E;&<@96QL97(@96YD
M<F4@:/AY<F4Z(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*;7-G:60@
M(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Q-`HC+"!F=7IZ>0IM<V=I9"`B4')E8V5D92!Y;W5R('-I
M9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R("),96=G('1I
M;"!S=')E:V5R(&]V97(@<VEG;F%T=7)E;B!D:6X@*"<M+2`G*2(*"B,Z('-M
M:6UE+G!H<#HR-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP.C0P"B,L
M(&9U>GIY"FUS9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E
M9"XB"FUS9W-T<B`B36%P<&5N(%PB)7-<(B!B;&4@;W!P<F5T=&5T+B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"B,L(&9U>GIY
M"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D9O<G)I9V4@<VED92(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C@*;7-G:60@
M(E!R979I;W5S($UE<W-A9V4B"FUS9W-T<B`B1F]R<FEG92!M96QD:6YG(@H*
M(SH@;6%I;&)O>"YP:'`Z,S0W"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S
M='(@(D9O<G)I9V4@<VED92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B4')I;G0B"FUS9W-T<B`B4VMR:78@
M=70B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHS.`HC+"!F
M=7IZ>0IM<V=I9"`B4')I;W)I='DB"FUS9W-T<B`B4VMR:78@=70B"@HC.B!T
M96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S8*;7-G:60@(E!R:79A
M=&4@2V5Y(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-3D*;7-G:60@(E!R;VUP="!E=F5R>2!T:6UE(&%N(&%T=&%C
M:&UE;G0@:7,@<V5N=#L@9&5F875L="!T;R!.3R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X"FUS9VED(")0<F]M<'0@979E<GD@
M=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ
M,`IM<V=I9"`B4')O=&]C;VPZ(@IM<V=S='(@(B(*"B,Z(&QI8B]#<GEP="]0
M1U`N<&AP.C0R.0IM<V=I9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R
M="!H87,@8F5E;B!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)?9V4@1&5L971E9"(*;7-G
M<W1R(")&:F5R;B!S;&5T=&5D92!E;&5M96YT97(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS7V1E;&5T960N:6YC.C@*;7-G:60@(E!U<F=E($1E;&5T960B"FUS9W-T
M<B`B1FIE<FX@<VQE='1E9&4@96QE;65N=&5R(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!U<F=E($9O
M;&1E<BAS*2(*;7-G<W1R(")3;&5T="!M87!P96XH92DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T
M96XZ(@IM<V=S='(@(DAV;W(@;V9T92!S:V%L(%/X<'!E;&5T(&9J97)N97,Z
M("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E
M(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO
M=6YT(&]F(&1A>7,N(@IM<V=S='(@(D9J97)N(&UE;&1I;F=E<B!I(%/X<'!E
M;&5T('-O;2!E<B!E;&1R92!E;FX@9&5T=&4@86YT86QL(&1A9V5R+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*(RP@9G5Z>GD*;7-G:60@(E!U
M<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@9F]L9&5R/R(*;7-G<W1R
M(")&:F5R;B!G86UL92!M96QD:6YG97(@:2!3^'!P96QE=#\B"@HC.B!L:6(O
M36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z-C4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E!U<F=I;F<@)60@;65S<V%G97,@9G)O;2!4
M<F%S:"!F;VQD97(N(@IM<V=S='(@(D9J97)N97(@)60@9V%M;&4@;65L9&EN
M9V5R(&9R82!3^'!P96QE="(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U
M<F=E7W1R87-H+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4'5R9VEN9R`Q(&UE
M<W-A9V4@9G)O;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(D9J97)N97(@)60@
M9V%M;&4@;65L9&EN9V5R(&9R82!3^'!P96QE="(*"B,Z('1E;7!L871E<R]Q
M=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B475O=&$@
M<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(T"B,L('!H
M<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@3D\@3$E-250B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T<B`B4VET870B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#8*;7-G:60@
M(E)E7W%U97-T($1E;&EV97)Y($-O;F9I<FUA=&EO;B(*;7-G<W1R(")"92!O
M;2!L979E<FEN9W-B96MR969T96QS92(*"B,Z(&QI8B]396%R8V@N<&AP.C4P
M"FUS9VED(")296-E:79E9"!/;B(*;7-G<W1R(")-;W1T871T(&1A=&\B"@HC
M.B!L:6(O4V5A<F-H+G!H<#HU.`IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS
M9W-T<B`B36]T=&%T="!S:61E;B(*"B,Z(&QI8B]396%R8V@N<&AP.C4T"FUS
M9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R(")-;W1T871T(&9R96T@=&EL
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B4F5D:7)I9V5R(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2
M961I<F5C="(*;7-G<W1R(")/;6%D<F5S<^ER(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$Q,`IM<V=I9"`B4F5D:7)E8W0@365S<V%G
M92(*;7-G<W1R(")/;6%D<F5S<^ER(&UE;&1I;F<B"@HC.B!C;VUP;W-E+G!H
M<#HW.#<*;7-G:60@(E)E9&ER96-T('1H:7,@;65S<V%G92(*;7-G<W1R(")/
M;6%D<F5S<^ER(&1E;FYE(&UE;&1I;F=E;B(*"B,Z(&-O;7!O<V4N<&AP.C@T
M-PIM<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*;7-G<W1R(")/;6%D<F5S
M<V5R:6YG(&9E:6QE="XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU.#,*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B3W!P9&%T97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@T"FUS9VED(")2969R97-H($9O
M;&1E<B!6:65W<SHB"FUS9W-T<B`B3W!P9&%T97(@;6%P<&5V:7-N:6YG.B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA
M:6QB;W@O:&5A9&5R+FEN8SHT"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS
M9W-T<B`B3&%S="!V:7-N:6YG('#E(&YY='0B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]H96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R("),
M87-T('9I<VYI;F<@<.4@;GET="(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU,C8@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM<V=I9"`B
M4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW.0IM<V=I9"`B4F5M96UB
M97(@=&AE(&QA<W0@=FEE=R(*;7-G<W1R(")(=7-K('-I<W1E('9I<VYI;F<B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]T92!-86EL8F]X.B(*;7-G<W1R(")0;W-T8F]K<R(*
M"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M
M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E('-O=7)C92(*;7-G<W1R(")F:F5R;B!K:6QD92(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E)E
M;F%M92!&;VQD97(H<RDB"FUS9W-T<B`B1VD@;GET="!N879N('1I;"!M87!P
M96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")296YA
M;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM
M<V=S='(@(D=I("=396YD=&4@96QE;65N=&5R)R!N>71T(&YA=FX@<.4@8F5G
M>6YN96QS96X@878@;>5N961E;B(*"B,Z(&QI8B]&;VQD97(N<&AP.C0U-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296YA;6EN9R!<(B5S7"(@=&\@7"(E<UPB
M(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R
M(")+=6YN92!I:VME(&=I(%PB)7-<(B!N879N970@7"(E<UPB+B!-96QD:6YG
M(&9R82!S97)V97)E;B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;%]Y('1O($QI<W0B
M"FUS9W-T<B`B4W9A<B!T:6P@86QL92(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W-P96QL:6YG+FEN8SHQ,#4*;7-G:60@(E)E<&QA8V4@=VET:#HB"FUS9W-T
M<B`B17)S=&%T="!M960Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S='(@(E-V87(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S$Q(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HT,#D*(RP@9G5Z>GD*;7-G:60@(E)E<&QY(%-E;G0N(@IM
M<V=S='(@(E-V87(M=&EL(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C$S"FUS9VED(")297!L>2!T;R!!;&PB"FUS9W-T<B`B
M4W9A<B!T:6P@86QL92(*"B,Z(&-O;7!O<V4N<&AP.C<S,PIM<V=I9"`B4F5P
M;'D@=&\@06QL.B(*;7-G<W1R(")3=F%R('1I;"!A;&QE.B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM
M<V=I9"`B4F5P;'D@=&\@3&ES="(*;7-G<W1R(")3=F%R('1I;"!A;&QE(@H*
M(SH@8V]M<&]S92YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!,
M:7-T.B(*;7-G<W1R(")3=F%R('1I;"!A;&QE.B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@
M7T%L;"(*;7-G<W1R(")3=F%R('1I;"!A;&QE(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4R."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,W
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E<&QY
M('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S4*;7-G:60@(E)E<&QY('=I=&@@
M9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,T"FUS9VED(")297!L>2!W:71H
M(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&UE<W-A9V4N<&AP.C(V-PHC+"!F=7IZ>0IM<V=I9"`B4F5P;'DM5&\B
M"FUS9W-T<B`B4W9A<BUT:6PZ("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#D*
M;7-G:60@(E)E<&QY+51O.B`B"FUS9W-T<B`B4W9A<BUT:6PZ("(*"B,Z(&-O
M;7!O<V4N<&AP.C<S,0IM<V=I9"`B4F5P;'DZ(@IM<V=S='(@(E-V87(Z(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,X('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(V"B,L(&9U>GIY"FUS9VED
M(")297!O<G0@87,@26YN;V-E;G0B"FUS9W-T<B`B4F%P<&]R=&5R('-O;2!S
M<&%M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C,U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(S"FUS9VED(")2
M97!O<G0@87,@4W!A;2(*;7-G<W1R(")287!P;W)T97(@<V]M('-P86TB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#,*;7-G:60@(E)E
M<75E<W0@82!?4F5A9"!296-E:7!T(@IM<V=S='(@(D)E(&]M(&QE<V5B96MR
M969T96QS92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#4*(RP@9G5Z
M>GD*;7-G:60@(E)E<75E<W0@9&5L:79E<GD@8V]N9FER;6%T:6]N/R(*;7-G
M<W1R(")"92!O;2!L979E<FEN9W-B96MR969T96QS92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-S,*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W0@<F5A
M9"!R96-E:7!T<S\B"FUS9W-T<B`B0F4@;VT@;&5S96)E:W)E9G1E;'-E(@H*
M(SH@;6%I;&)O>"YP:'`Z,3@Y"FUS9VED(")297%U97-T960@;65S<V%G92!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV.3<*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,30S('1E;7!L871E
M<R]S96%R8V@O:&5A9&5R+FEN8SHR-@HC.B!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z,38Q"FUS9VED(")297-E="(*;7-G<W1R(").=6QL<W1I;&PB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$U"FUS9VED(")297-P;VYD96YT
M(%-T871U<R!5<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G
M<W1R(")':F5N;W!P=&$B"@HC.B!R96-O;7!O<V4N<&AP.CDX"FUS9VED(")2
M97-U;64@>6]U<B!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N
M('1O(%PB365S<V%G92!#;VUP;W-I=&EO;EPB(@IM<V=S='(@(E-K<FEV(&UE
M;&1I;F<B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N
M:6YC.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,@HC+"!F
M=7IZ>0IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`B2&5N
M="!E+7!O<W0B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@
M=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHR,@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP;&%T97,O<VUI;64O;F]T86-T
M:79E+FEN8SHQ-`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L
M871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,38R('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S,*(RP@9G5Z>GD*
M;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(D%N9')E('9A;&<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S$X"FUS9VED("(B"B)2971U
M<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN9RP@;6]V
M:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B(@HB1^4@=&EL
M8F%K92!T:6P@<&]S=&)O:W-L:7-T96X@971T97(@Y2!H82!S;&5T=&5T+"!F
M;'ET=&5T(&5L;&5R(&MO<&EE<G0@96X@(@HB;65L9&EN9S\B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")2;VQE(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30R(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z-#$Y"FUS9VED(")3+TU)344B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,@IM<V=I9"`B4R]-24U%
M($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HS
M.30*;7-G:60@(E,O34E-12!%<G)O<CH@(@IM<V=S='(@(B(*"B,Z(&-O;7!O
M<V4N<&AP.C,W,PIM<V=I9"`B4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A
M<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34Q"B,L(&9U>GIY"FUS9VED(")3+TU)
M344@3W!T:6]N<R(*;7-G<W1R(")686QG(@H*(SH@<VUI;64N<&AP.C0Y"FUS
M9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C4T"FUS9VED(")3+TU)344@4&5R
M<V]N86P@2V5Y<&%I<B!S=7!P;W)T(')E<75I<F5S(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!S;6EM92YP:'`Z,30P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!F;W(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B36%P
M<&5N(%PB)7-<(B!B;&4@<VQE='1E="XB"@HC.B!S;6EM92YP:'`Z,38R"FUS
M9VED(")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`*;7-G
M:60@(E,O34E-12!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!S;6EM
M92YP:'`Z,C$Q"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I
M<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@
M(E,O34E-12!3:6=N($UE<W-A9V4B"FUS9W-T<B`B4V5N9"!M96QD:6YG(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ-`IM<V=I
M9"`B4R]-24U%(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C0*;7-G:60@(E,O34E-
M12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(T,0IM<V=I9"`B
M(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!E;F%B;&5D('-O
M('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92`B"B)D96-R>7!T960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<S"FUS
M9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@
M8V]N=&5N=',@;V8@=&AI<R!S:6=N960@;65S<V%G92!C86X@;F]T("(*(F)E
M(&1I<W!L87EE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E
M;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@
M8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z,@IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@<F5Q=6ER
M97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R
M(&ES("(*(F-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S
M+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@(@HB=&AE
M(%,O34E-12!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#4*;7-G
M:60@(E--5%`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,C4U"FUS9VED(")37W5B:F5C="(*;7-G<W1R(")%;6YE(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S8S"FUS9VED(")3
M85]V92!A(&-O<'D@:6X@(@IM<V=S='(@(DQA9W)E(&MO<&D@:2`B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@
M(E-A7W9E(&%S(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z('-E87)C:"YP:'`Z
M,S$V('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-PHC+"!F=7IZ
M>0IM<V=I9"`B4V%V92(*;7-G<W1R("),86=R92!S;VTB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S@*;7-G:60@(E-A=F4@071T86-H
M;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PIM<V=I9"`B4V%V92!$
M<F%F="(*;7-G<W1R("),86=R92!K;&%D9"(*"B,Z('-A=F5I;6%G92YP:'`Z
M-#(*(RP@9G5Z>GD*;7-G:60@(E-A=F4@26UA9V4B"FUS9W-T<B`B3&%G<F4@
M<V]M(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(P-`IM<V=I9"`B4V%V
M92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ,B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O;F]T86-T
M:79E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(D%N9')E('9A;&<B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z-#`*;7-G:60@(E-A=F4@4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT,S,*(RP@9G5Z>GD*;7-G:60@(E-A=F4@
M7T1R869T(@IM<V=S='(@(DQA9W)E(&ML861D(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")3
M879E(&%S(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-S(*;7-G:60@
M(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT
M(&%D9')E<W,@8F]O:S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C
M:"]M86EN+FEN8SHQ,C<*;7-G:60@(E-A=F4@<V5A<F-H(&%S(&$@=FER='5A
M;"!F;VQD97(_(@IM<V=S='(@(DQA9W)E('/X:R!S;VT@96X@=FER='5E;&P@
M;6%P<&4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`HC+"!F=7IZ
M>0IM<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(DQA9W)E('-E;F1T
M('!O<W0B"@HC.B!C;VUP;W-E+G!H<#HQ,C(W"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("),86=R92!K;&%D9"!F96EL970N
M($UE;&1I;F<@9G)A('-E<G9E<F5N.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M86EL8F]X+VAE861E
M<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z-#$*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")3^&LB"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8V@@)7,B"FUS9W-T<B`B4_AK
M("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,`HC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H($]P=&EO;G,B"FUS9W-T<B`B06YD<F4@=F%L9R(*"B,Z
M('-E87)C:"YP:'`Z,C8U"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R
M(")3^&ME<F5S=6QT870B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$T('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S$*;7-G:60@
M(E-E96XB"FUS9W-T<B`B3&5S="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z.0IM<V=I9"`B4V5L96-T(@IM<V=S='(@(E9E;&<B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-S`*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!!;F]T:&5R($%C8V]U;G0B"FUS9W-T<B`B5F5L9R!I;F=E
M;B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHS-@HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")696QG(&5T(&9E;'0B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,3`*;7-G:60@(E-E
M;&5C="!A(&9I96QD(@IM<V=S='(@(E9E;&<@970@9F5L="(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PHC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B5F5L9R!E="!F96QT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E
M87)C:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R(")696QG(&%D<F5S<V5B
M;VLM:VEL9&5R(&9O<B#E(&QE9V=E('1I;"!O9R#E('/X:V4@971T97(@861R
M97-S97(N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.`IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R(")696QG(&%L;&4B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C,*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A
M9&1R97-S97,N(@IM<V=S='(@(B(*(E9E;&<@<F5K:V5F^&QG96X@8FQA;G0@
M861R97-S96+X:V5N92!S;VT@8G)U:V5S('1I;"!U='9I9&5L<V4@878@861R
M97-S97(N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C
M="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM
M<V=S='(@(E9E;&<@:6YG96XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C@Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")696QG(&EN9V5N
M(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.CD*;7-G
M:60@(E-E;&5C="!T:&4@9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?<V5L
M96-T+FEN8SHR,0IM<V=I9"`B4V5L96-T('1H92!M86EL('-E<G9E<B!T>7!E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,P.0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T960@061D<F5S<R!B;V]K
M<SHB"FUS9W-T<B`B5F5L9R!A9')E<W-E8OAK97(Z(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<R"FUS9VED(")396YD($ME>2!T;R!0=6)L:6,@2V5Y
M<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV,#0*(RP@9G5Z>GD*;7-G:60@(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N
M(@IM<V=S='(@(E-E<G9E<FEN9F]R;6%S:F]N(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#,Q"FUS9VED(")396YD($UE<W-A9V4B"FUS9W-T<B`B4V5N9"!M
M96QD:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P,PIM<V=I9"`B
M4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T960@8GD@=&AE('-E;F1E
M<C\B"FUS9W-T<B`B(@H*(SH@9F]L9&5R<RYP:'`Z,SDW"B,L(&9U>GIY"FUS
M9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(E-E;F1T92!E;&5M96YT
M97(Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHS
M.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB"FUS9W-T<B`B4V5N9'1E(&5L
M96UE;G1E<CHB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$S,B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$T-@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$U,PIM<V=I9"`B4V5R=F5R(@IM<V=S='(@(E-E<G9E
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5R=F5R(&%N9"!&;VQD97(@26YF;W)M871I;VXB"FUS9W-T<B`B4V5R
M=F5R:6YF;W)M87-J;VXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`B4V5R
M=F5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@
M<')E9F5R96YC97,@9F]R('=H870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N
M9"!D96QE=&4@;65S<V%G97,N(@IM<V=S='(@(DEN;G-T:6QL;F=E<B!F;W(@
M:'9A('-O;2!S:VIE<B!NY7(@9'4@9FQY='1E<B!O9R!S;&5T=&5R(&UE;&1I
M;F=E<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3
M970@=&AE(%@M4')I;W)I='D@:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A
M9V5S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*
M(RP@9G5Z>GD*;7-G:60@(E-H87)E($9O;&1E<G,B"FUS9W-T<B`B36%P<&5R
M(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C@V"B,L(&9U>GIY"FUS9VED
M(")3:&%R92!M86EL(&9O;&1E<G,B"FUS9W-T<B`B4V5N9'1E(&5L96UE;G1E
M<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E
M('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*;7-G:60@(B(*(E-H
M;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@
M:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL
M>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D>2!O9B!T
M97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D871A/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$S"FUS9VED
M(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E<B!S
M879I;F<@82!D<F%F=#\B"FUS9W-T<B`B(@HB4VMA;"!V:6YD=65T("=.>2!M
M96QD:6YG)R!L=6MK97,@971T97(@870@;65L9&EN9V5N(&5R(&QA9W)E="!S
M;VT@:VQA9&0_(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0*;7-G:60@
M(E-H;W5L9"!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O(&)E(&%T=&%C:&5D('1O
M('EO=7(@;65S<V%G97,@8GD@9&5F875L=#\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@HC+"!F=7IZ>0IM<V=I9"`B4VAO
M=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")6:7,@86QL92!M96QD:6YG<VAO9&5R
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C<*;7-G:60@
M(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B5FES(&%L;&4@;65L9&EN9W-H
M;V1E<B(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM<V=I9"`B4VAO=R!$96QE=&5D
M(@IM<V=S='(@(E9I<R!S;&5T=&5D92!E;&5M96YT97(B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHV,0IM<V=I9"`B4VAO=R!,:6UI=&5D
M($AE861E<G,B"FUS9W-T<B`B5FES(&)E9W)E;G-E=&4@;65L9&EN9W-H;V1E
M<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P"B,L(&9U
M>GIY"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G
M<W1R(")097)S;VYL:6<@:6YF;W)M87-J;VXB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.CDR"B,L(&9U>GIY"FUS9VED(")3:&]W($]N;'D@4W5B
M<V-R:6)E9"!&;VQD97)S(@IM<V=S='(@(D%B;VYNZ7(@<.4@;6%P<&4H<BDB
M"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@(E-H;W<@56YS=6)S8W)I8F5D
M(@IM<V=S='(@(E9I<R!U86)O;FYE<G1E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8P.`IM<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP
M<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P,@IM<V=I9"`B4VAO=R!L
M96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\B"FUS9W-T<B`B5FES(&9A<F=E
M9F]R:VQA<FEN9V5R(&[E<B!P;W-T;&ES=&5N('9I<V5S/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-#`*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R
M('5N<F5A9"!M97-S86=E<R!O;FQY/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('!R979I97=S(&EN('1O
M;VQT:7!S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#<W"FUS9VED(")3:&]W('1H92!&971C:"!-86EL(&EC;VX@;VX@=&AE(&UE
M;G5B87(_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<#HY-0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@26UA9V5S(@IM<V=S='(@
M(E9I<R!B96=R96YS971E(&UE;&1I;F=S:&]D97(B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]P<F5F<RYI;F,Z-30*;7-G:60@(E-H;W<@=&AE(&9I;'1E<B!I
M8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z,C@*;7-G:60@(E-H;W<@=&]T86P@;G5M8F5R(&]F(&UA
M:6QS(&EN(&9O;&1E<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V-@IM<V=I9"`B4VAO=VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHT,@IM<V=I9"`B4VE?
M>F4B"FUS9W-T<B`B4W3X<G)E;'-E(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B4VEG;F5D(@IM<V=S='(@
M(E-T^')R96QS92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FEN8SHS"FUS9VED(")3:7IE(@IM<V=S='(@(E-T^')R96QS92(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,3$*;7-G:60@
M(E-O<G0@8GD@07)R:79A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$V"FUS9VED(")3;W)T(&)Y($1A
M=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!&<F]M($%D
M9')E<W,B"FUS9W-T<B`B1G)A+6%D<F5S<V4B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0Q"B,L(&9U>GIY"FUS9VED(")3
M;W)T(&)Y($UE<W-A9V4@4VEZ92(*;7-G<W1R(")-96QD:6YG<W-T^')R96QS
M92(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,S8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R("))
M;G1E="!E;6YE(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!B>2!4:')E860B"FUS
M9W-T<B`B5'+E9"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@5&\@061D<F5S
M<R(*;7-G<W1R(")&<F$M861R97-S92(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M<&%M<V5L96-T+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B4W!A;2!F;VQD97(Z
M(@IM<V=S='(@(E/X<'!L96UA<'!E.B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C,T-@IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97)S(@IM
M<V=S='(@(E-P97-I86QT96=N(@H*(SH@<V5A<F-H+G!H<#HQ,S,*;7-G:60@
M(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;B!N;W0@8F4@961I=&5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS
M-#,*;7-G:60@(E-P96QL($-H96-K(@IM<V=S='(@(E-T879E:V]N=')O;&PB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@
M(E-P96QL($-H96-K97(B"FUS9W-T<B`B4W1A=F5K;VYT<F]L;"(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L
M971E(@IM<V=S='(@(E-T879E:V]N=')O;&QE;B!E<B!F=6QL9OAR="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@(E-P96QL:6YG(&5R
M<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N(@IM<V=S='(@
M(E-T879E9F5I;"!P<BX@<VED92!U;F1E<B!S=&%V96MO;G1R;VQL+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3(@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8U,@IM<V=I9"`B4W1A<G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.CD@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,S$Q"FUS9VED(")3=&%T:6]N97)Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHR-@IM<V=I
M9"`B4W1A=&EO;F5R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C@*;7-G:60@(E-T871I;VYE<GD@='EP
M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N
M:6YC.C,S"FUS9VED(")3=&%T:6]N97)Y.B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(")3=&%T=7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(Q-0HC+"!F=7IZ>0IM
M<V=I9"`B4W1R:7`@071T86-H;65N="(*;7-G<W1R(")6961L96=G(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S,@IM<V=I9"`B4W1R:7`@;&EN96)R
M96%K<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHS-PIM<V=I9"`B4W5B7VIE8W0B"FUS9W-T<B`B16UN
M92(*"B,Z(&UE<W-A9V4N<&AP.C(V."!T:')E860N<&AP.C$U,"!T96UP;&%T
M97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(U"B,Z(&QI8B]396%R8V@N<&AP
M.C,X"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D5M;F4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3(P"FUS9VED(")3=6)J96-T($9I96QD(@IM<V=S
M='(@(D5M;F5F96QT(@H*(SH@<V5A<F-H+G!H<#HS,3@@=&5M<&QA=&5S+W-A
M=F5I;6%G92]S879E:6UA9V4N:6YC.C$X"B,Z('1E;7!L871E<R]S;6EM92]P
M87-S<&AR87-E+FEN8SHR,"!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC
M.C,Q"FUS9VED(")3=6)M:70B"FUS9W-T<B`B4V5N9"(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@=&\@
M1F]L9&5R*',I(@IM<V=S='(@(D%B;VYNZ7(@<.4@;6%P<&4H<BDB"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X,"!L:6(O34E-12]6:65W97(O
M<&=P+G!H<#HS.#D*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*
M;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5K<V5S<R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX-@IM<V=I9"`B4W5G9V5S=&EO;G,B
M"FUS9W-T<B`B1F]R<VQA9R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV-C(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B4W5M
M;6%R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT,#`@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`S"B,L
M(&9U>GIY"FUS9VED(")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D(@IM<V=S
M='(@(D)Y='0@=&EL($A434P@961I=&]R(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@=&\@2%1-3"!C;VUP
M;W-I=&EO;B(*;7-G<W1R(")">71T('1I;"!(5$U,(&5D:71O<B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P-`IM<V=I9"`B4W=I=&-H
M('1O('!L86EN('1E>'0@8V]M<&]S:71I;VXB"FUS9W-T<B`B0GET="!T:6P@
M=F%N;&EG('1E:W-T961I=&]R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#$Y"FUS9VED(")495]X="(*;7-G<W1R(")496MS="(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-CD*;7-G:60@(E1E;G1A=&EV
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M.3$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*;7-G:60@(E1E
M;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN
M(&-O;F8N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R(")496MS="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-30*;7-G:60@(E1H92!&<F]M.B!C
M;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#HB"FUS9W-T
M<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU,S(*;7-G:60@(B(*(E1H
M92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@
M875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A<V4@8V]N
M=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"FUS9VED(")4
M:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O
M=VYL;V%D960@)7,N(@IM<V=S='(@(B(*"B,Z(&9E=&-H;6%I;'!R969S+G!H
M<#HX,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED96YT:71E=&5N
M(%PB)7-<(B!B;&4@<VQE='1E="XB"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z
M-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB
M)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@7"(E
M<UPB(&)L92!L86=R970N(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@
M(E1H92!A='1A8VAM96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.0IM<V=I9"`B5&AE(&-A;&5N
M9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4
M:&4@8V]M<&]S92!W:6YD;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO
M=2!H879E('-E="!Y;W5R(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN
M9&]W<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U
M8FQE+G!H<#HT,@IM<V=I9"`B5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O
M<V@@9FEL92!A<F4@8F5L;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HX-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@8W5R<F5N="!F;VQD97(H<RD@7"(E<UPB
M('=I;&P@8F4@<F5N86UE9"!T;R!<(B5S7"(N(@IM<V=S='(@(DUA<'!E;BAE
M*2!<(B5S7"(@=FEL(&[E(&AE=&4@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ,#<*;7-G:60@(B(*(E1H92!C=7)R96YT(&QI<W0@;V8@
M=7-E<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E
M(')E=')I979E9"(*;7-G<W1R("(B"@HC.B!C;VUP;W-E+G!H<#HQ,C,V"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!D<F%F="!H87,@8F5E;B!S879E9"!T
M;R!T:&4@7"(E<UPB(&9O;&1E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$S.0IM<V=I9"`B5&AE(&5V96YT('=A<R!A9&1E
M9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]E>'!A;F0N:6YC.CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S
M='(@(DED96YT:71E=&5N(%PB)7-<(B!B;&4@<VQE='1E="XB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B36%P<&5N(%PB)7-<
M(B!F:6YN97,@86QL97)E9&4B"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I
M;G,@:6QL96=A;"!C:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U
M<V4@(@HB<')O8FQE;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@HB36%P<&5N(%PB)7-<(B!I;FYE:&]L9&5R
M('5G>6QD:6=E('1E9VX@:2!N879N970N($1E='1E(&MA;B!S:V%P92!P<F]B
M;&5M97(N("(*(E9E;FYL:6=S="!S;F%K:R!M960@<WES=&5M861M:6YI<W1R
M871O<F5N(&1I;BXB"@HC.B!L:6(O1F]L9&5R+G!H<#HS-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&-R96%T960@8G5T
M('EO=2!W97)E(&YO="!S=6)S8W)I8F5D('1O(&ET+B(*;7-G<W1R(")-87!P
M96X@7"(E<UPB(&)L92!L86=E="P@;65N(&1U(&%B;VYN97)E<B!I:VME('#E
M(&1E;BXB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W
M97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B36%P<&5N
M(%PB)7-<(B!B;&4@<VQE='1E="P@;65N(&1U(&AA9&1E(&EK:V4@<V%G="!O
M<'`@86)O;FYE;65N=&5T+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,T,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T(&-R
M96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B
M36%P<&5N(%PB)7-<(B!B;&4@:6MK92!L86=E="X@365L9&EN9R!F<F$@<V5R
M=F5R96XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(DUA<'!E;B!<(B5S
M7"(@8FQE(&EK:V4@<VQE='1E="X@365L9&EN9R!F<F$@<V5R=F5R96XB"@HC
M.B!L:6(O1F]L9&5R+G!H<#HS-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+B(*;7-G
M<W1R(")-87!P96X@7"(E<UPB(&)L92!O<'!R971T970N(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B36%P
M<&5N(%PB)7-<(B!B;&4@<VQE='1E="XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M('-U8V-E<W-F=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B36%P
M<&5N(%PB)7-<(B!H971E<B!NY2!<(B5S7"(N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.CDR"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I;&5S('=E
M<F4@871T86-H960@=&\@=&AI<R!P87)T.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7W-A=F5I;6%G95]W:6XN:G,Z,3(*;7-G
M:60@(B(*(E1H92!I;6%G92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE
M9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R("(*(G1O(&)L
M;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E
M(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y
M;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E
M;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"FUS
M9VED(")4:&4@;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@
M:6YF;W)M871I;VYA;"!M97-S86=E.B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R
M(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-97-S86=E+G!H<#HV-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!M86EL8F]X("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S
M='(@(B5S(&5R(&%L;&5R961E('1O;2(*"B,Z(&QI8B]&971C:&UA:6PN<&AP
M.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S<V%G92!<(B5S7"(@
M9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E=&-H('-I>F4@;&EM
M:70N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,3`S"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!B96EN9R!C
M;VUP;W-E9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(DUE
M;&1I;F=E;B!S;VT@:&%R(&)L:71T('-K<F5V970@:&%R(&)L:71T('-T96YG
M="X@079S;'5T=&5R+B(*"B,Z(&UE<W-A9V4N<&AP.C$T.`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M261E;G1I=&5T96X@7"(E<UPB(&)L92!S;&5T=&5T+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B5&AE(&UE<W-A
M9V4@:&%S(&)E96X@=F5R:69I960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB
M)7-<(B!B;&4@;&%G<F5T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E(&AA<R!B
M965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA=&5S+W!G
M<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S<&AR87-E
M('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T
M('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F('1H92!01U`@4'5B;&EC
M($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@(E1H92!R97%U97-T960@9FEL
M92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`IM<V=I
M9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!:
M:7`@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z-30W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI<R!M
M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI
M<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB;F]T
M:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4:&4@<V5R=F5R('=A<R!N;W0@
M86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#0*
M(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E
M<&QA8V5D+B(*;7-G<W1R(")3:6=N871U<F5N(&MU;FYE(&EK:V4@97)S=&%T
M=&5S+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z,3`R"FUS
M9VED(")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P;&%C960N
M(@IM<V=S='(@(E-I9VYA='5R96X@8FQE(&5R<W1A='1E="XB"@HC.B!A='1A
M8VAM96YT+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E
M<UPB(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R("))9&5N=&ET971E;B!<(B5S
M7"(@8FQE(&QA9W)E="XB"@HC.B!S=&%T:6]N97)Y+G!H<#HV,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB)7-<(B!B
M;&4@<VQE='1E="XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B
M965N('5P9&%T960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB)7-<(B!B;&4@
M<VQE='1E="XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38Y"FUS
M9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY
M-0HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4B"FUS
M9W-T<B`B<VQE='0@;65L9&EN9R(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H
M92!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X="!O
M9B!T:&4@<F5T=7)N960@;65S<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92!C86X@8F4@=FEE=V5D
M("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T
M:6]N+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E
M;G0@;65S<V%G92(*;7-G<W1R(")/;6%D<F5S<^ER(&1E;FYE(&UE;&1I;F=E
M;B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A
M9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B5&AE('5S97(G
M<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E
M9"XB"FUS9W-T<B`B4VEG;F%T=7)E;B!B;&4@97)S=&%T=&5T+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z.#8*;7-G:60@(E1H97)E
M(&%R92!N;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]E
M;7!T>5]M86EL8F]X+FEN8SHS"FUS9VED(")4:&5R92!A<F4@;F\@;65S<V%G
M97,@:6X@=&AI<R!M86EL8F]X+B(*;7-G<W1R(")$970@97(@:6YG96X@;65L
M9&EN9V5R(&D@9&5N;F4@<&]S=&)O:W-E;BXB"@HC.B!T:')E860N<&AP.C$P
M.0IM<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-C$R
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP
M=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(D1E="!O<'!S=&]D(&5T('!R;V)L96T@=6YD97(@<VQE='1I;F=E;B!A
M=B`E<RX@365L9&EN9R!F<F$@<V5R=F5R96XB"@HC.B!L:6(O365S<V%G92YP
M:'`Z-C4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E<B!S
M86ED.B`E<R(*;7-G<W1R("(B"B)$970@;W!P<W1O9"!E="!P<F]B;&5M('9E
M9"!F:F5R;FEN9R!A=B!P;W-T8F]K<V5N+B!-96QD:6YG(&9R82!S97)V97)E
M;B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,C$*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(B(*(D1E="!O<'!S=&]D(&5T('!R
M;V)L96T@=F5D(&9J97)N:6YG(&%V('!O<W1B;VMS96XN($UE;&1I;F<@9G)A
M('-E<G9E<F5N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.CDP"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@8V]P>6EN
M9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA
M="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB1&5T(&]P<'-T;V0@
M96X@9F5I;"!U;F1E<B!K;W!I97)I;F=E;B!A=B!M96QD:6YG96X@=&EL(%PB
M)7-<(BX@365L9&EN9R!F<F$@(@HB<V5R=F5R96XB"@HC.B!L:6(O365S<V%G
M92YP:'`Z,3DX(&QI8B]-97-S86=E+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S
M(&9R;VT@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="`B"B)T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB1&5T(&]P<'-T;V0@96X@9F5I;"!U
M;F1E<B!S;&5T=&EN9R!A=B!M96QD:6YG97(@9G)A(&UA<'!E;B!<(B5S7"(N
M($UE;&1I;F<@(@HB9G)A('-E<G9E<F5N(@H*(SH@;&EB+TUE<W-A9V4N<&AP
M.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H
M:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB1&5T
M(&]P<'-T;V0@96X@9F5I;"!V960@<VQE='1I;F<@878@8F5S:VIE9&5R(&9R
M82!M87!P96X@7"(E<UPB+B!-96QD:6YG(&9R82`B"B)S97)V97)E;B(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HR,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`B1&5T(&]P
M<'-T;V0@96X@9F5I;"!U;F1E<B!S;&5T=&EN9R!A=B!M96QD:6YG97(N($UE
M;&1I;F<@9G)A('-E<G9E<F5N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.CDY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B1&5T
M(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!V:7-N:6YG(&%V(&9O<F5S<'5R="!M
M96QD:6YG+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3(@;&EB
M+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS-PIM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T
M<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!F;W)S^&L@<.4@Y2!V:7-E
M(&1E;FYE(&UE;&1I;F=S9&5L96XB"@HC.B!L:6(O365S<V%G92YP:'`Z-30U
M(&QI8B]-97-S86=E+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F
M;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED
M(@IM<V=S='(@(B(*(D1E="!O<'!S=&]D(&5N(&9E:6P@=F5D(&9L86=G:6YG
M(&%V(&UE;&1I;F=E<B!I(&UA<'!E;B!<(B5S7"(N($UE;&1I;F<@9G)A("(*
M(G-E<G9E<F5N(@H*(SH@9F]L9&5R<RYP:'`Z,38U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S
M+B(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R(&QA9W)I;F<@
M878@:VQA9&0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$S-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")$970@;W!P<W1O
M9"!E;B!F96EL('5N9&5R('9I<VYI;F<@878@9F]R97-P=7)T(&UE;&1I;F<N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$V-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@
M=6YD97(@=FES;FEN9R!A=B!F;W)E<W!U<G0@;65L9&EN9RXB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F
M<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R(")$970@;W!P<W1O
M9"!E;B!F96EL('5N9&5R('-E;F1I;F<@878@;65L9&EN9V5N.B`E<R(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&UO=FEN9R!M97-S86=E<R!F<F]M
M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R
M('-A:60B"FUS9W-T<B`B(@HB1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!F
M;'ET=&EN9V5N(&%V(&UE;&1I;F=E;B!T:6P@7"(E<UPB+B!-96QD:6YG(&9R
M82`B"B)S97)V97)E;B(*"B,Z(&-O;7!O<V4N<&AP.C$R-#0*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AI<R!M97-S86=E
M(&%S(&$@9')A9G0N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD
M97(@9F]R<_AK('#E(.4@=FES92!D96YN92!M96QD:6YG<V1E;&5N(@H*(SH@
M8V]M<&]S92YP:'`Z,3`P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z("5S(@IM<V=S='(@
M(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@<V5N9&EN9R!A=B!M96QD:6YG
M96XZ("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N
M(&9E:6P@=6YD97(@<V5N9&EN9R!A=B!M96QD:6YG96XZ("5S(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!L86EN+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@=V%S(&YO('1E>'0@:6X@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B
M1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!F;W)S^&L@<.4@Y2!V:7-E(&1E
M;FYE(&UE;&1I;F=S9&5L96XB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP
M:'`Z.3<*;7-G:60@(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB
M961D960@:6X@:70N(@IM<V=S='(@(D1E;FYE($A434PM;65L9&EN9V5N(&AA
M<B!B:6QD97(@:2!S96<N(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.CDP"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M
M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T
M:&ES.B`B"FUS9W-T<B`B1&5N;F4@2%1-3"!M96QD:6YG96X@:&%R(&)I;&1E
M<B!I('-E9RX@0FQO:VME<G1E(&)I;&1E<B!V:7-E<R!S;&EK.B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C$V-@IM<V=I9"`B5&AI<R!01U`@4'5B
M;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#0@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C$Q.`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,30S(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3<*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$W,R!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,S$T"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<Y(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3D*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,30*;7-G:60@(E1H:7,@;6%Y
M('1A:V4@<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N
M=&EN=64_(@IM<V=S='(@(D1E='1E(&MA;B!T82!L:71T('1I9"X@17(@9'4@
M<VEK:V5R('#E(&%T(&1U('9I;"!F;W)T<V5T=&4_(@H*(SH@;&EB+TU)344O
M5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,`IM<V=I9"`B5&AI<R!M97-S86=E
M(&-O;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$P"FUS9VED("(B"B)4:&ES(&UE
M<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&1I
M9VET86QL>2!S:6=N960@=FEA(%,O(@HB34E-12XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,30*;7-G:60@(E1H:7,@;65S
M<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@96YC
M<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.C$V,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O
M;G1A:6YS(&UA:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@
M=&AE(&9O<FUA="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S$U"B,L(&9U
M>GIY"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@4$=0(&5N8W)Y<'1E9"!M97-S86=E+B!%<G)O<CH@(@IM
M<V=S='(@(B5S('-E<B!I:VME('5T('-O;2!E<B!E;B!G>6QD:6<@<&]S=&)O
M:W,B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR-#`@;&EB+TU)344O
M5FEE=V5R+W!G<"YP:'`Z,S4P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%!'4"!F;W)M870@
M*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P"FUS9VED(")4:&ES(&UE<W-A
M9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R96-T(%,O34E-
M12!F;W)M870N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(P-2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*;7-G:60@(E1H
M:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,30S
M"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE
M9"!V:6$@4R]-24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S.`IM
M<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-
M24U%+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M,#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED
M(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@96YC<GEP=&5D('=I=&@@4$=0+B(*
M;7-G<W1R(")$96YN92!(5$U,+6UE;&1I;F=E;B!H87(@8FEL9&5R(&D@<V5G
M+B(*"B,Z(&UE<W-A9V4N<&AP.C(Q,0IM<V=I9"`B5&AI<R!M97-S86=E('1O
M(@IM<V=S='(@(D1E;FYE(&UE;&1I;F=E;B!T:6PB"@HC.B!A8VPN<&AP.C0V
M"FUS9VED(")4:&ES('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ,#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`B
M1&5T=&4@=FEN9'5E="!MY2!B;&D@Y7!N970@9G)A("=.>2!M96QD:6YG)R!V
M:6YD=65T(@H*(SH@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H
M<F5A9"!$:7-P;&%Y(@IM<V=S='(@(E9I<R(*"B,Z('1H<F5A9"YP:'`Z-S8@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,@IM<V=I9"`B5&AR96%D(%9I97<B
M"FUS9W-T<B`B5'+E9'9I<VYI;F<B"@HC.B!M97-S86=E+G!H<#HR-C0@;6%I
M;&)O>"YP:'`Z-C`V('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z
M,C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z
M,C(@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C8Q"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,3`@;&EB+U-E87)C:"YP:'`Z
M,C8*;7-G:60@(E1O(@IM<V=S='(@(E1I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,3D*(RP@9G5Z>GD*;7-G:60@(E1O($%D9')E<W,B"FUS9W-T
M<B`B1G)A+6%D<F5S<V4B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!F:65L
M9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA
M8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@82!43%,@8V]N;F5C
M=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@;V8@4$A0(#4N
M,"XV(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3<W"B,L(&9U>GIY"FUS9VED(")4;W1A;"!!
M='1A8VAM96YT<R!3:7IE.B(*;7-G<W1R(")-86MS('-T^')R96QS92!PY2!V
M961L96=G(@H*(SH@9F]L9&5R<RYP:'`Z,S@X"B,L(&9U>GIY"FUS9VED(")4
M<F%S:"!F;VQD97(B"FUS9W-T<B`B4_AP<&QE;6%P<&4Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHR,PIM<V=I9"`B5')A<V@@9F]L
M9&5R.B(*;7-G<W1R(")3^'!P;&5M87!P93HB"@HC.B!L:6(O475O=&$O8WER
M=7,N<&AP.C8U(&QI8B]1=6]T82]M97)C=7)Y,S(N<&AP.C<Y(&QI8B]1=6]T
M82]C;VUM86YD+G!H<#HW,@HC.B!L:6(O475O=&$O;&]G9FEL92YP:'`Z.#@@
M;&EB+U%U;W1A+V-O=7)I97(N<&AP.C4S(&QI8B]1=6]T82]M9&%E;6]N+G!H
M<#HT.`IM<V=I9"`B56YA8FQE('1O(')E=')I979E('%U;W1A(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,3`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ.0HC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C,V"FUS9VED(")5;F%N<W=E<F5D(@IM
M<V=S='(@(E5B97-V87)T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHS-0IM<V=I9"`B56YA;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")58F5S
M=F%R=&4@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,3,*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(D=J96YO<'!R971T(@H*(SH@
M;6%I;&)O>"YP:'`Z-3@Y(&UA:6QB;W@N<&AP.C8P,B!L:6(O34E-12](96%D
M97)S+G!H<#HR,3(*;7-G:60@(E5N9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS
M9W-T<B`B4VMJ=6QT92!M;W1T86ME<F4B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#0W"B,L('!H<"UF;W)M870*;7-G:60@(E5N:&%N9&QE9"!C
M;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP
M:'`Z-38U"FUS9VED(")5;FMN;W=N($1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK
M;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E
M<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8S-0IM<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@(B(*
M"B,Z(&UA:6QB;W@N<&AP.C8Q.`HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!2
M96-I<&EE;G0B"FUS9W-T<B`B4VMJ=6QT92!M;W1T86ME<F4B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@
M9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@
M(E5T96X@;F%V;B(*"B,Z(&UE<W-A9V4N<&AP.C0Y.2!M86EL8F]X+G!H<#HW
M,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHV"B,Z
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,34@=&5M<&QA=&5S+VUA
M:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E
M;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*;7-G<W1R(")5;&5S="(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$R"FUS9VED(")5;G-U8G-C
M<FEB92!F<F]M($9O;&1E<BAS*2(*;7-G<W1R(")3:2!O<'`@86)O;FYE;65N
M="!PY2!M87!P92AR*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C4X-`IM<V=I9"`B57!D871E($%T=&%C:&UE;G0@26YF;W)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R,`IM
M<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHU."!T96UP;&%T97,O
M<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS9VED(")5<&QO860B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM
M<V=I9"`B57-E($1E9F%U;'0@5F%L=64B"FUS9W-T<B`B0G)U:R!S=&%N9&%R
M9"!V97)D:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-38*;7-G:60@
M(E5S92!)34%0(&9O;&1E<B!S=6)S8W)I<'1I;VYS/R(*;7-G<W1R(")"<G5K
M($E-05`@;6%P<&5A8F]N;F5M96YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<S-0HC+"!F=7IZ>0IM<V=I9"`B57-E(%9I<G1U86P@5')A<V@@1F]L
M9&5R/R(*;7-G<W1R(")6:7)T=65L;&4@;6%P<&5R(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C$T,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R
M(")"<G5K97)N879N(@H*(SH@86-L+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)5<V5R(%PB)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE('-P
M96-I9FEE9"!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$W-PIM<V=I9"`B
M57-E<FYA;64B"FUS9W-T<B`B0G)U:V5R;F%V;B(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA
M;64Z(@IM<V=S='(@(D)R=6ME<FYA=FXB"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,C<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B5FEE=R(*;7-G<W1R
M(")6:7,@)7,B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HY,B!L:6(O
M34E-12]6:65W97(O=&YE9BYP:'`Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@)7,B"FUS9W-T<B`B5FES("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(RP@9G5Z>GD*;7-G
M:60@(E9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM
M<V=S='(@(E1R>6MK("5S(&9O<B#E('9I<V4@2%1-3"UI;FYH;VQD(&D@970@
M96=E="!V:6YD=2XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN
M8SHR.`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!-97-S86=E<R(*;7-G<W1R(").
M>64@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW
M,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<@4&5R<V]N
M86P@4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@
M(E9I97<@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3@*(RP@9G5Z>GD*
M;7-G:60@(E9I97<@5&AR96%D(@IM<V=S='(@(E-E('1RY60B"@HC.B!L:6(O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,38U"B,L(&9U>GIY"FUS9VED(")6:65W(%1H=6UB;F%I;"(*
M;7-G<W1R(")392!T<N5D(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,3@*(RP@9G5Z>GD*;7-G:60@(E9I97<@871T86-H;65N="!I;B!A('-E
M<&%R871E('=I;F1O=R(*;7-G<W1R("),86<@;GD@;65L9&EN9R!I(&5T(&5G
M970@=FEN9'4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y
M"B,L(&9U>GIY"FUS9VED(")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W
M:6YD;W<B"FUS9W-T<B`B5')Y:VL@)7,@9F]R(.4@=FES92!(5$U,+6EN;FAO
M;&0@:2!E="!E9V5T('9I;F1U+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-#`*;7-G:60@(E9I97<@979E;G0B"FUS9W-T<B`B(@H*(SH@9F]L
M9&5R<RYP:'`Z,S@P(&UA:6QB;W@N<&AP.C4S-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G<W1R(")6:7,@
M;65L9&EN9R!I("(*"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E
M;&5C="YI;F,Z,C,*;7-G:60@(E9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN.B(*;7-G<W1R(")6:7-N:6YG(&5L;&5R('!O<W1B;VMS
M('-O;2!S:V%L('9I<V5S(&5T=&5R(&EN;FQO9V=I;F<Z(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$W,`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!T
M87-K(@IM<V=S='(@(E9I<R`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL
M+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(E9I97<@=&AE($EM86=E<R(*;7-G
M<W1R(")6:7,@;65L9&EN9R!I("(*"B,Z('-E87)C:"YP:'`Z,C8S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@
M8W)E871E9"!S=6-C97-F=6QL>2XB"FUS9W-T<B`B36%P<&5N(%PB)7-<(B!B
M;&4@<VQE='1E="XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Q
M,2!L:6(O24U!4"]4<F5E+G!H<#HQ,S@@;&EB+TE-05`O5')E92YP:'`Z,34Q
M"B,Z(&QI8B])34%0+U1R964N<&AP.C$U,R!L:6(O24U!4"]4<F5E+G!H<#HQ
M-3<@;&EB+TE-05`O5')E92YP:'`Z,34X"B,Z(&QI8B])34%0+U1R964N<&AP
M.C,V.2!L:6(O24U!4"]4<F5E+G!H<#HS.3,@;&EB+TE-05`O5')E92YP:'`Z
M-#,S"FUS9VED(")6:7)T=6%L($9O;&1E<G,B"FUS9W-T<B`B5FER='5E;&QE
M(&UA<'!E<B(*"B,Z('-E87)C:"YP:'`Z,C0U"B,L(&9U>GIY"FUS9VED(")6
M:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA8F5L+B(*;7-G<W1R(").879N
M('#E('9I<G1U96QL(&UA<'!E(@H*(SH@;&EB+U9&;VQD97(N<&AP.C$W-2!L
M:6(O5D9O;&1E<BYP:'`Z,3@P"FUS9VED(")6:7)T=6%L($E.0D]8(@IM<V=S
M='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q-@HC+"!F=7IZ>0IM<V=I9"`B5FER
M='5A;"!)3D)/6"!&;VQD97(B"FUS9W-T<B`B5FER='5E;&QE(&UA<'!E<B(*
M"B,Z(&UA:6QB;W@N<&AP.C0U,B!L:6(O5D9O;&1E<BYP:'`Z,3$T(&QI8B]6
M1F]L9&5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(E9I<G1U86P@5')A<V@B
M"FUS9W-T<B`B5FER='5E;&QE(&UA<'!E<B(*"B,Z(&9O;&1E<G,N<&AP.C0Q
M,PHC+"!F=7IZ>0IM<V=I9"`B5FER='5A;"!4<F%S:"!&;VQD97(B"FUS9W-T
M<B`B5FER='5E;&QE(&UA<'!E<B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z,3,S"FUS9VED(")6:7)T=6%L(&9O;&1E<B!L86)E;"(*;7-G<W1R
M(").879N('#E('9I<G1U96QL(&UA<'!E(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HS-S0*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B061V87)S
M96PB"@HC.B!L;V=I;BYP:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64@=&\@)7,B"FUS9W-T<B`B5F5L:V]M;65N('1I;"`E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV,3D*;7-G:60@(B(*(E=H870@<VAO=6QD
M('=E(&1O('=I=&@@<W!A;2!M97-S86=E<R!A9G1E<B!T:&5Y(&AA=F4@8F5E
M;B!R97!O<G1E9"!A<R!S<&%M("(*(F]R(&EN;F]C96YT/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(W"FUS9VED("(B"B)7:&5N
M(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F
M;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B
M"FUS9W-T<B`B(@HB5F5D('-L971T:6YG(&%V(&UE;&1I;F=E<BP@9FQY='0@
M9&5M('1I;"!3^'!P96QM87!P96X@:7-T961E="!F;W(@Y2!M87)K97)E("(*
M(F1E;2!S;VT@<VQE='1E=#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`W"FUS9VED(")7:&5N(&]P96YI;F<@82!N97<@;6%I;&)O>"P@=VAI8V@@
M<&%G92!D;R!Y;W4@=V%N="!T;R!S=&%R="!O;C\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@
M<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C8*;7-G:60@
M(B(*(E=H96X@<V5N9&EN9R!M86EL(&]R(&5X<&%N9&EN9R!A9&1R97-S97,L
M('=H870@9&]M86EN('-H;W5L9"!W92!A<'!E;F0@=&\@(@HB=6YQ=6%L:69I
M960@861D<F5S<V5S("AE;6%I;"!A9&1R97-S97,@=VET:&]U="!<(D!<(BD_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM
M<V=I9"`B5VAI=&5L:7-T(@IM<V=S='(@(DAV:71L:7-T970B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#$@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDW.`IM<V=I9"`B665S(@IM<V=S='(@(DIA(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HU.`HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&%R92!A8F]U="!T;R!F971C:"!E;6%I;"!F<F]M('1H
M92!F;VQL;W=I;F<@86-C;W5N="AS*3HB"FUS9W-T<B`B1'4@<'+X=F5R(.4@
M<VQE='1E(&;X;&=E;F1E(&UA<'!E<CHB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM<V=I9"`B(@HB
M66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N
M=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R
M(")$=2!P<OAV97(@Y2!S;&5T=&4@9OAL9V5N9&4@;6%P<&5R.B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.CD*(RP@9G5Z
M>GD*;7-G:60@(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@=&AE(&9O
M;&QO=VEN9R!F;VQD97(H<RDN(@IM<V=S='(@(D1U('!R^'9E<B#E('-L971T
M92!F^&QG96YD92!M87!P97(Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V
M87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z,3DR"FUS9VED(")9;W4@87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W
M(&9O;&1E<BXB"FUS9W-T<B`B1'4@:V]P:65R97(O9FQY='1E<B!T:6P@96X@
M;GD@;6%P<&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ
M<SHQ,#(*;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O
M("(*;7-G<W1R(")$=2!L86=E<B!E;B!U;F1E<FUA<'!E(&D@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(EEO=2!A
M<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R(")$=2!L
M86=E<B!E;B!T;W!P;FEVY6UA<'!E+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,R
M,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@9F]L9&5R<RXB"FUS9W-T<B`B1'4@;&%G97(@96X@=&]P<&YI=N5M87!P
M92XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V9O;&1E<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F
M;VQD97(Z("(*;7-G<W1R(")$=2!G:7(@;GET="!N879N('1I;"!M87!P96XZ
M("(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N
M(@IM<V=S='(@(D1U('-A(&]P<"!A8F]N;F5M96YT970@<.4@7"(E<UPB(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,U"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@<&QA
M8V5H;VQD97)S(&EN('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@
M(@HB8W5R<F5N="!M97-S86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T
M=7)E+B(*;7-G<W1R("(B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R964@
M=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@=V5R
M92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%C;"]A8VPN:6YC.C$V.0IM<V=I9"`B66]U(&1O(&YO="!H879E
M('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T
M;R!T:&4@9F]L;&]W:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R(")$=2!V
M:61E<F5S96YD=&4@9&5N;F4@;65L9&EN9V5N('#E("4E<R!T:6P@9OAL9V5N
M9&4@;6]T=&%K97)E.B`E<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R
M="YI;F,Z,PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@
M;65S<V%G97,N(@IM<V=S='(@(D1U(&AA<B`E<R!N>64@;65L9&EN9V5R(2(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED(")9;W4@
M:&%V92`Q(&YE=R!M97-S86=E+B(*;7-G<W1R(")$=2!H87(@,2!N>2!M96QD
M:6YG(2(*"B,Z(&-O;7!O<V4N<&AP.C0Y-`HC+"!F=7IZ>0IM<V=I9"`B66]U
M(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P86=E+B(*;7-G<W1R(")$
M=2!H87(@,2!N>2!M96QD:6YG(2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T
M=&%C:&UE;G1S+FIS.C$Q-0IM<V=I9"`B(@HB66]U(&AA=F4@870@;&5A<W0@
M;VYE(&%T=&%C:&UE;G0@<V5L96-T960@=&AA="!Y;W4@9&ED;B=T('5P;&]A
M9"!Y970N($%R92`B"B)Y;W4@<W5R92!Y;W4@=V%N="!T;R!S96YD('1H:7,@
M;65S<V%G92!W:71H;W5T('1H97-E(&%T=&%C:&UE;G1S/R(*;7-G<W1R("(B
M"@HC.B!L:6(O24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@:&%V92!N97<@;6%I
M;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`B1'4@:&%R(&YY
M('!O<W0@:2!F^&QG96YD92!M87!P93HB"@HC.B!L:6(O24U0+G!H<#HQ,#<Y
M"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O
M;&1E<G,Z(@IM<V=S='(@(D1U(&AA<B!N>2!P;W-T(&D@9OAL9V5N9&4@;6%P
M<&5R.B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PHC+"!F=7IZ>0IM<V=I9"`B66]U
M(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS9W-T<B`B
M1'4@;>4@:&$@;6EN<W0@Z6X@;6]T=&%K97(N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!G<"YP:'`Z,S`R"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@
M<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T
M:&ES(&UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HR-#D*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S
M<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H
M:7,@(@HB;65S<V%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]J879A<V-R:7!T+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R
M:7!T+FEN8SHR,#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M
M86EL8F]X(&9I<G-T+B(*;7-G<W1R(")$=2!MY2!V96QG92!E;B!MY6PM<&]S
M=&)O:W,@9OAR<W0N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D
M96QE=&5D+B(*;7-G<W1R(")$=2!MY2!V96QG92!E;B!I9&5N=&ET970@<V]M
M('-K86P@<VQE='1E<RXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C@Q"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F
M:7)S="XB"FUS9W-T<B`B1'4@;>4@=F5L9V4@96X@861R97-S92!F^')S="XB
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C8S"FUS9VED(")9;W4@;75S="!S
M96QE8W0@870@;&5A<W0@;VYE(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@(D1U
M(&WE('9E;&=E(&UI;G-T(.EN(&UE;&1I;F<@9OAR<W0N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y(&$@<F5C:7!I96YT+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R
M92!E;B!M;W1T86ME<BXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM
M96YT<RYJ<SHR.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M="!L96%S="!O;F4@9FEL92!T;R!A='1A8V@N(@IM<V=S='(@(D1U(&WE(&;X
M<G-T('-P97-I9FES97)E(&9I;&5N('-O;2!S:V%L(&QE9V=E<R!V960N(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N86)L960@
M:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!L
M:6(O36%I;&QO9RYP:'`Z,3,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@=&\@)7,@;VX@)25S+B(*
M;7-G<W1R(")$=2!S=F%R=&4@<.4@9&5N;F4@;65L9&EN9V5N('#E("5S+B(*
M"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S+B(*;7-G<W1R(")$
M=2!S=F%R=&4@<.4@9&5N;F4@;65L9&EN9V5N('#E("5S+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N
M;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60B"FUS9W-T<B`B1'4@9FEK:R!I:VME(&%B;VYN97)E('#E(%PB
M)7-<(BX@365L9&EN9R!F<F$@<V5R=F5R96XB"@HC.B!L:6(O1F]L9&5R+G!H
M<#HU-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@;F]T('5N<W5B
M<V-R:6)E9"!F<F]M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@
M<V%I9"(*;7-G<W1R(")$=2!F:6MK(&EK:V4@<VD@;W!P(&%B;VYN96UE;G1E
M="!PY2!<(B5S7"(N($UE;&1I;F<@9G)A('-E<G9E<F5N(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U
M8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")$=2!A
M8F]N;F5R97(@;N4@<.4@7"(E<UPB(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-38R
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U
M;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B1'4@<V$@;W!P(&%B
M;VYN96UE;G1E="!PY2!<(B5S7"(B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z.3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")&=6QL
M="!N879N.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU,`IM<V=I9"`B
M66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Q('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW-@IM<V=I9"`B66]U<B!0<FEV871E($ME>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHW,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y(@IM
M<V=S='(@(D9U;&QT(&YA=FXZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$V-0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!297!L>2UT;SH@861D<F5S<SH@
M/&5M/BAO<'1I;VYA;"D\+V5M/B(*;7-G<W1R(")$:6X@<W9A<F%D<F5S<V4Z
M(#QI/BAV86QG9G)I*3PO:3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C0Y"FUS9VED(")9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T
M:69I8V%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A
M8V-O=6YT7W-E;&5C="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@86-C
M;W5N=',Z(@IM<V=S='(@(DMO;G1O97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M
M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I
M/"]E;3XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS
M9W-T<B`B(@HB3F5T=&QE<V5R96X@9&EN('-T^'1T97(@:6MK92!D96YN92!U
M='-K:69T<V]P97)A<VIO;F5N+B!4<GEK:R!+;VYT<F]L;"\B"B)/<'-J;VX@
M*R!0(&9O<B#E('-K<FEV92!U="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N9&EN
M9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M8W)Y<'1S96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R>7!T
M:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB
M"FUS9W-T<B`B36%P<&5N(%PB)7-<(B!B;&4@<VQE='1E="XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R93HB
M"FUS9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z(&UE<W-A9V4N<&AP.C(X."!C
M;VUP;W-E+G!H<#HQ,C@T(&UA:6QB;W@N<&AP.C4T.2!L:6(O0V]M<&]S92YP
M:'`Z.#$X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6TEN=&5T(&5M
M;F5=(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C`U"FUS
M9VED(")?0F-C(@IM<V=S='(@(D)L:6YD(&MO<&DB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(E]";&%C:VQI<W0B"FUS9W-T<B`B
M4W9A<G1E;&ES="!A=G-E;F1E<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C$U-`IM<V=I9"`B7T-C(@IM<V=S='(@(DMO<&D@=&EL(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C8@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`HC.B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS+FEN8SHQ,`IM<V=I9"`B7T1E;&5T92(*;7-G<W1R(")3
M;&5T="(*"B,Z(&QI8B])35`N<&AP.CDW.0IM<V=I9"`B7T9O;&1E<G,B"FUS
M9W-T<B`B36%P<&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z.#$*;7-G:60@(E])9&5N=&ET>2(*;7-G<W1R("))9&5N=&ET970B"@HC
M.B!L:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G<W1R("));FYB
M;VMS(@H*(SH@;&EB+TE-4"YP:'`Z,3`R,`IM<V=I9"`B7TQO9R!O=70B"FUS
M9W-T<B`B3&]G9R!U="(*"B,Z(&UE<W-A9V4N<&AP.C,X-`IM<V=I9"`B7TUE
M<W-A9V4@4V]U<F-E(@IM<V=S='(@(DUE;&1I;F=S:VEL9&4B"@HC.B!L:6(O
M24U0+G!H<#HY-S8*(RP@9G5Z>GD*;7-G:60@(E].97<@365S<V%G92(*;7-G
M<W1R(").>64@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")?4')I;G0B"FUS9W-T<B`B7U-K
M<FEV('5T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(X.0HC+"!F=7IZ>0IM
M<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(E]3:W)I=B!U="(*"B,Z(&UA:6QB
M;W@N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7U)E9G)E
M<V@@)7,B"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z.`IM<V=I9"`B7U)E<&QY(@IM<V=S='(@
M(E]3=F%R(@H*(SH@;&EB+TE-4"YP:'`Z.3@Q"FUS9VED(")?4V5A<F-H(@IM
M<V=S='(@(E/X:R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,0HC+"!F=7IZ
M>0IM<V=I9"`B7U-E;F0@365S<V%G92(*;7-G<W1R(")396YD(&UE;&1I;F<B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,R
M"FUS9VED(")?5&AR96%D(@IM<V=S='(@(E1RY60B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*;7-G:60@(E]4;R(*;7-G<W1R(")4
M:6PB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM<V=I
M9"`B7U5N9&5L971E(@IM<V=S='(@(D=J96YO<'!R971T(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")?5FEE
M=R!4:')E860B"FUS9W-T<B`B4V4@='+E9"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*;7-G<W1R(")(=FET
M;&ES="!A=G-E;F1E<B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S8*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HT-#`*(RP@9G5Z>GD*;7-G:60@(F%T=&%C:&UE;G0B"FUS9W-T<B`B
M5F5D;&5G9R(*"B,Z('9I97<N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")A='1A
M8VAM96YT<RYZ:7`B"FUS9W-T<B`B5F5D;&5G9R(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PIM<V=I9"`B8GET97,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P,`IM<V=I9"`B8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,3<R"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,38T"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(R,`IM<V=I
M9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3DV"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S
M:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-C@*;7-G:60@
M(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HR,C0*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$Y,`IM<V=I9"`B
M9G)O;2(*;7-G<W1R(")F<F$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@P"FUS
M9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,C`T"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X.`IM<V=I9"`B:6YT97)N86P@
M<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(Y('!G
M<"YP:'`Z-CD*;7-G:60@(FME>2(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H
M<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(FUA:6QB;W@@9FEL92(*;7-G<W1R(")0
M;W-T8F]K<R(*"B,Z(&-O;7!O<V4N<&AP.C$P-C<@;&EB+TUE<W-A9V4N<&AP
M.C0V-@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R(").879N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<V"FUS9VED(")N;VYE
M(@IM<V=S='(@(FEN9V5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$P-0IM<V=I9"`B;W(B"FUS9W-T<B`B96QL97(B"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z,C$V"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C$R"FUS9VED(")R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C$X-`IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@
M(G-P96QL:6YG(&5R<F]R(@IM<V=S='(@(G-T879E9F5I;"(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@
M97)R;W)S(@IM<V=S='(@(G-T879E9F5I;"(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")S
M=&%V969E:6PB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`X"FUS9VED(")T96UP
M;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HU
M,0HC+"!F=7IZ>0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`B4W9A
M<G1E;&ES=&4B"@HC.B!L:6(O1FEL=&5R+G!H<#HV,0HC+"!F=7IZ>0IM<V=I
M9"`B>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`B2'9I=&QI<W1E="(*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]P;R]S=E]312YP;P``````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,C4P-3(`
M,3`T,3<S-C(W-C8`,#$W,C$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@24U0(%-W961I<V@@=')A;G-L871I;VX*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#(M,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE($EM<"!P86-K86=E+@HC($IO87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO
M0'=E8F)P;&%T<V5N+G-E/BP@,C`P-2P@,C`P-BX*(R!!;F1R96%S($1A:&SI
M;B`\86YD<F5A<T!D86AL96XN=W,^+"`R,#`U+@HC(%5P9&%T97,@9G)O;2!0
M;VYT=7,@1G)E>6AU;'0@/'!O;G1?:&]R9&5`<V]U82YN970^(#(P,#4M,#(M
M,#0@"B,@57!D871E<R!F<F]M($%N9')E87,@4.5H;'-S;VX@/&%N9')E87-`
M<&%H;'-S;VXN:6YF;SX@,C`P,BTP,2TQ-PHC"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!);7`@-"XQ7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#8M,#(M,30@,34Z,S`K,#$P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-BTP,BTQ-"`Q-CHP,"LP,3`P7&XB"B),87-T+51R86YS
M;&%T;W(Z($IO87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N
M+G-E/EQN(@HB3&%N9W5A9V4M5&5A;3H@4W=E9&ES:"`\:3$X;D!L:7-T<RYH
M;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A;"U&;W)M<SH@
M;G!L=7)A;',],CL@<&QU<F%L/2AN("$](#$I.UQN(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C0R.0IM<V=I9"`B("`@("`@0V,Z("(*;7-G<W1R("(@("`@("!#
M8SH@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0R-@IM<V=I9"`B("`@("`@5&\Z
M("(*;7-G<W1R("(@("`@5&EL;#H@(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C0Q
M-`IM<V=I9"`B("`@($1A=&4Z("(*;7-G<W1R("(@("!$871U;3H@(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0Q-PIM<V=I9"`B("`@($9R;VTZ("(*;7-G<W1R
M("(@("`@1G+E;CH@(@H*(SH@;6%I;&)O>"YP:'`Z-#`Y('1E;7!L871E<R]F
M;VQD97)S+VAE860N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B`H<VYA8F)T86YG96YT("5S*2(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HT,C,*;7-G:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B
M("#$<F5N9&4Z("(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHW,`IM<V=I9"`B(&EN("(*;7-G<W1R("(@:2`B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S
M='(@(B,B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R
M("(E+C)F34(@+R`E+C)F34(@("@E,F8E)2DB"@HC.B!T:')E860N<&AP.C$U
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!-97-S86=E<R(*;7-G<W1R("(E
M9"!M961D96QA;F1E;B(*"B,Z(&UA:6QB;W@N<&AP.C$W-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B)60@;65D9&5L86YD92AN*2!H87(@<F%D97)A=',N(@H*(SH@;&EB
M+U-P86TN<&AP.C$Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E9"!M97-S
M86=E<R!H879E(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB)60@;65D9&5L86YD
M96X@:&%R(')A<'!O<G1E<F%T<R!S;VT@14HM<VMRY'!P;W-T('1I;&P@9&EN
M("(*(G-Y<W1E;6%D;6EN:7-T<F%T]G(N(@H*(SH@;&EB+U-P86TN<&AP.C$W
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@
M<F5P;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(B5D(&UE9&1E;&%N9&5N
M(&AA<B!R87!P;W)T97)A=',@<V]M($5*+7-K<N1P<&]S="XB"@HC.B!L:6(O
M4W!A;2YP:'`Z,3@X"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(B5D(&UE9&1E;&%N9&5N(&AA<B!R
M87!P;W)T97)A=',@<V]M('-K<N1P<&]S="!T:6QL('-Y<W1E;6%D;6EN:7-T
M<F%T]G)E;BXB"@HC.B!L:6(O4W!A;2YP:'`Z,38X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M+B(*;7-G<W1R("(E9"!M961D96QA;F1E;B!H87(@<F%P<&]R=&5R871S('-O
M;2!S:W+D<'!O<W0N(@H*(SH@;6%I;&)O>"YP:'`Z,S4Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D('1O("5D(&]F("5D($UE<W-A9V5S(@IM<V=S='(@(B5D
M('1I;&P@)60@878@)60@;65D9&5L86YD96XB"@HC.B!M86EL8F]X+G!H<#HV
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2V(B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T
M<B`B)7,@9FEN;G,@<F5D86XN($YA;6YE="!PY2!M87!P96X@)7,@Y&YD<F%D
M97,@:6YT92XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA
M:6QB;W@N(@IM<V=S='(@(B5S('9E<FMA<B!I;G1E('9A<F$@96X@:V]R<F5K
M="!M87!P+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT
M;6%I;%]M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F
M;VQD97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H
M+B(*;7-G<W1R(")-87!P96X@)7,@9N5R(&YY='0@;F%M;B!I(&+V<FIA;B!A
M=B!MY6YA9&5N+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G<W1R
M("(E<R!H87(@86-C97!T97)A="XB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C$W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL
M960@7"(E<UPB+B(*;7-G<W1R("(E<R!H87(@86YN=6QL97)A="!<(B5S7"(N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!H87,@9&5C;&EN960N(@IM<V=S='(@(B5S(&AA<B!A
M=F+V:G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S
M>2!R97%U97-T+B(*;7-G<W1R("(E<R!H87(@<W9A<F%T('#E(&5N(&)E9^1R
M86X@;VT@:6YF;W)M871I;VX@86YGY65N9&4@;&5D:6<O=7!P=&%G96XN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R!<
M(B5S7"(N(@IM<V=S='(@(B5S(&AA<B!S=F%R870@<.4@:6YB:G5D86X@=&EL
M;"`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#@S"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN(@IM<V=S='(@(B5S(&AA<B!S:VEC:V%T(&1I9R!I;F9O<FUA
M=&EO;B!O;2!L961I9R]U<'!T86=E;BXB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!T96YT
M871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@:&%R(&%C8V5P=&5R870@
M<')E;&EM:6[D<G0N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0X
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R964O
M8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@969T97)F<N5G87(@:6YF
M;W)M871I;VX@;VT@;N1R(&1U(.1R(&QE9&EG+W5P<'1A9V5N+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="!<(B5S7"(N(@IM<V=S
M='(@(B5S(&5F=&5R9G+E9V%R(&1I;B!NY')V87)O("5S+B(*"B,Z(&QI8B]-
M97-S86=E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(B5S(&QA9&5S
M('1I;&P@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@86UM96YD(%PB)7-<
M(BXB"FUS9W-T<B`B)7,@=FEL;"#D;F1R82`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3<Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I
M<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B!<(B5S7"(N(@IM<V=S='(@(B5S
M('9I;&P@9_9R82!D:6<@;65D=F5T96X@;VT@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W
M:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T
M(%PB)7-<(BXB"FUS9W-T<B`B)7,@=FEL;"!E<FCE;&QA(&1E;B!S96YA<W1E
M(&EN9F]R;6%T:6]N96X@;VT@)7,N(@H*(SH@;65S<V%G92YP:'`Z,CDS(&UE
M<W-A9V4N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS
M9W-T<B`B)7,Z("5S(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7W1O
M<"YI;F,Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S("@E9"9N8G-P
M.V]F)FYB<W`[)60I(@IM<V=S='(@(B5S.B`E<R`H)60F;F)S<#MA=B9N8G-P
M.R5D*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*
M;7-G:60@(BA!<'!L>2!T:&5S92!C:&%N9V5S(&%N9"!M;W9E('1O(&YE>'0@
M<V-R965N+BDB"FUS9W-T<B`B*%9E<FMS=.1L;"#D;F1R:6YG87)N82!O8V@@
M9F]R='/D='0@=&EL;"!NY'-T82!S:^1R;2XI(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C$R,`IM<V=I9"`B*$1I<V-A<F0@86QL(&-H
M86YG97,@86YD(')E='5R;B!T;R!T:&4@8V]M<&]S92!S8W)E96XN*2(*;7-G
M<W1R("(H5&$@8F]R="!A;&QA(.1N9')I;F=A<B!O8V@@Y71E<G;D;F0@=&EL
M;"!M961D96QA;F1E+BDB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z,38*;7-G:60@(BA(5$U,*2(*;7-G<W1R("(H2%1-3"DB"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*;7-G:60@(BA0;&%I
M;B!497AT*2(*;7-G<W1R("(H5&5X="DB"@HC.B!S<&5L;&EN9RYP:'`Z,C<Y
M"FUS9VED("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A9G1E
M<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@(@HB0VAA
M;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE
M9"XI(@IM<V=S='(@(B(*(BC%=&5R=N1N9"!T:6QL(&UE9&1E;&%N9&4@969T
M97(@=F5R:W-TY&QL86YD92!A=B!H:71T:6QL<R!G:F]R9&$@Y&YD<FEN9V%R
M+B`B"B+$;F1R:6YG87(@<.4@86MT:78@<VOD<FT@:V]M;65R($E.5$4@=F5R
M:W-TY&QL87,N*2(*"B,Z('-P96QL:6YG+G!H<#HR-S8*;7-G:60@(B(*(BA3
M96YD(&UE<W-A9V4@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T
M:'5S(&9A<BX@($-H86YG97,@;VX@=&AE("(*(F-U<G)E;G0@<V-R965N('=I
M;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(H4VMI8VMA(&UE9&1E
M;&%N9&4@969T97(@=F5R:W-TY&QL86YD92!A=B!H:71T:6QL<R!G:F]R9&$@
MY&YD<FEN9V%R+B`B"B+$;F1R:6YG87(@<.4@86MT:78@<VOD<FT@:V]M;65R
M($E.5$4@=F5R:W-TY&QL87,N*2(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C
M;VYT86-T<RYI;F,Z,C(W"FUS9VED("(J($%D9"!T:&5S92!B>2!C;&EC:VEN
M9R!/2R`J(@IM<V=S='(@(BH@3.1G9R!T:6QL(&1E;2!HY'(@9V5N;VT@871T
M(&ML:6-K82!/2R`J(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,#8*;7-G:60@(BH@4&QE87-E('-E;&5C="!A9&1R97-S*&5S*2`J
M(@IM<V=S='(@(BH@5N1L:B!A9')E<W,H97(I("HB"@HC.B!M86EL8F]X+G!H
M<#HQ-S0*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R(")-961D96QA;F1E="!H87(@<F%D97)A=',N(@H*(SH@;&EB+U-P86TN
M<&AP.C$Y.`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(C$@;65D9&5L86YD92!H87(@<F%P<&]R=&5R871S('-O;2!%2BUS
M:W+D<'!O<W0@=&EL;"!D:6X@<WES=&5M861M:6YI<W1R873V<BXB"@HC.B!L
M:6(O4W!A;2YP:'`Z,3<X"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P
M;W)T960@87,@;F]T('-P86TN(@IM<V=S='(@(C$@;65D9&5L86YD92!H87(@
M<F%P<&]R=&5R871S('-O;2!%2BUS:W+D<'!O<W0N(@H*(SH@;&EB+U-P86TN
M<&AP.C$Y,`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@HB,2!M961D96QA;F1E(&AA<B!R87!P;W)T97)A=',@<V]M('-K<N1P<&]S
M="!T:6QL(&1I;B!S>7-T96UA9&UI;FES=')A=/9R+B(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ-S`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M+B(*;7-G<W1R("(Q(&UE9&1E;&%N9&4@:&%R(')A<'!O<G1E<F%T
M<R!S;VT@<VMRY'!P;W-T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,#@*;7-G:60@(C$P,"!C:&%R86-T97)S(@IM<V=S='(@(C$P,"!T96-K96XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Q"FUS9VED("(Q,#`P(&-H
M87)A8W1E<G,B"FUS9W-T<B`B,3`P,"!T96-K96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#`Y"FUS9VED("(R-3`@8VAA<F%C=&5R<R(*;7-G<W1R
M("(R-3`@=&5C:V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q,`IM
M<V=I9"`B-3`P(&-H87)A8W1E<G,B"FUS9W-T<B`B-3`P('1E8VME;B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O
M('1H:7,@;65S<V%G92XB"FUS9W-T<B`B16X@<W1O<B!B:6QD("@E<RD@Y'(@
M8FEF;V=A9"!T:6QL(&UE9&1E;&%N9&5T+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]N;W1I9FEC871I;VXN<&AP.C4P"FUS9VED("(B"B)!(&UE<W-A9V4@>6]U
M(&AA=F4@<V5N="!H87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T
M:6]N(&9R;VT@=&AE("(*(G)E8VEP:65N="XB"FUS9W-T<B`B1'4@:&%R(&;E
M='0@;&5V97)A;G-B96MRY&9T96QS92!PY2!E='0@;65D9&5L86YD92!D=2!S
M:VEC:V%T+B(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHU"FUS
M9VED(")!3D0B"FUS9W-T<B`B3T-((@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4X,@IM<V=I9"`B06-C97!T(&%N9"!A9&0@=&\@;7D@8V%L96YD
M87(B"FUS9W-T<B`B06-C97!T97)A(&]C:"!LY&=G('1I;&P@;6EN(&MA;&5N
M9&5R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-0IM<V=I9"`B
M06-C97!T(')E<75E<W0B"FUS9W-T<B`B06-C97!T97)A(&)E9^1R86XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S0V"FUS9VED(")!8V-E<'1E
M9"(*;7-G<W1R(")!8V-E<'1E<F%D(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C(U.`IM<V=I9"`B06-C97!T960Z("(*;7-G<W1R(")!8V-E<'1E
M<F%D.B`B"@HC.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHS."!T96UP;&%T
M97,O;65N=2]M96YU+FEN8SHT,`IM<V=I9"`B06-C;U]U;G1S(@IM<V=S='(@
M(DMO;E]T;VXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M-PIM<V=I9"`B06-C;W5N="=S(&YA;64Z(@IM<V=S='(@(DMO;G1O=',@;F%M
M;CHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(R(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HW,C4*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B
MQ71GY')D97(B"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(@;&EB+TU)
M344O2&5A9&5R<RYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"`E
M<R!T;R!M>2!!9&1R97-S($)O;VLB"FUS9W-T<B`B3.1G9R!T:6QL("5S(&D@
M;6EN(&%D<F5S<V)O:R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,P,PIM<V=I9"`B061D('-O=7)C92(*;7-G<W1R("),Y&=G('1I
M;&P@:^1L;&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3<S"FUS
M9VED(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("),Y&=G('1I
M;&P@:2!M:6X@:V%L96YD97(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3@S"FUS9VED(")!9&0@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B3.1G
M9R!T:6QL(&D@;6EN(&MA;&5N9&5R(@H*(SH@8V]M<&]S92YP:'`Z-3DP"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM
M96YT+B(*;7-G<W1R("),861E('1I;&P@)7,@<V]M(&5N(&)I;&%G82XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DX"FUS9VED("(B"B)!9&1I=&EO
M;F%L(&AE861E<G,@=&\@9&ES<&QA>2!W:&5N('9I97=I;F<Z(#QE;3XH;W!T
M:6]N86PL(&5N=&5R(&5A8V@@:&5A9&5R("(*(F]N(&$@;F5W(&QI;F4I/"]E
M;3XB"FUS9W-T<B`B(@HB671T97)L:6=A<F4@:'5V=61R861E<B!A='0@=FES
M83H@/&5M/BAE:B!O8FQI9V%T;W)I<VMT+"!A;F=E('9A<FIE(&AU=G5D<F%D
M("(*(G#E(&5N(&5G96X@<F%D*3PO96T^(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M:71I;VYA;"!I;F9O<FUA=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M(")9='1E<FQI9V%R92!I;F9O<FUA=&EO;B!V:7-A<R`E<RXB"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,@IM<V=I9"`B061D:71I
M;VYA;"!I;F9O<FUA=&EO;B!D971A:6QS(@IM<V=S='(@(D9L97(@9&5T86QJ
M97(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B
M061D:71I;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`B1FQE<B!D971A
M;&IE<B!O;2!M961D96QA;F1E="(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S
M<V%G92!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(D9L97(@
M9&5T86QJ97(@;VT@;65D9&5L86YD970@=FES87,@)7,N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S
M<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@(D9L97(@9F5L;65D9&5L86YD
M92UD971A;&IE<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O
M<B!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(D9L97(@9F5L
M;65D9&5L86YD92UD971A;&IE<B!V:7-A<R`E<RXB"@HC.B!C;VYT86-T<RYP
M:'`Z.#4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.#`*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L871E<R]C
M;VUP;W-E+W)E9&ER96-T+FEN8SHU,@IM<V=I9"`B061D<F5S<R!";V]K(@IM
M<V=S='(@(D%D<F5S<V)O:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S0*;7-G:60@(D%D9')E<W,@0F]O:W,B"FUS9W-T<B`B061R97-S8O9C:V5R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0IM<V=I9"`B(@HB061D
M<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE;3XH;W!T:6]N86PL(&5N
M=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L:6YE*3PO96T^(@IM<V=S
M='(@(B(*(D%D<F5S<V5R(&%T="!LY&=G82!T:6QL('-O;2!"0T,@=&EL;"!A
M;&QA(&UE9&1E;&%N9&5N.B`\96T^*&5J("(*(F]B;&EG871O<FES:W0L('-K
M<FEV('9A<FIE(&%D<F5S<R!PY2!E;B!E9V5N(')A9"D\+V5M/B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#$*;7-G:60@(B(*(D%D9')E<W-E<R!T
M;R!E>'!L:6-I=&QY('1I92!T;R!T:&ES(&ED96YT:71Y.B`\96T^*&]P=&EO
M;F%L+"!E;G1E<B!E86-H("(*(F%D9')E<W,@;VX@82!N97<@;&EN92D\+V5M
M/B(*;7-G<W1R("(B"B)!9')E<W-E<B!K;W!P;&%D92!T:6QL(&1E;B!HY'(@
M:61E;G1I=&5N.B`\96T^*&5J(&]B;&EG871O<FES:W0L('-K<FEV('9A<FIE
M("(*(F%D<F5S<R!PY2!E;B!E9V5N(')A9"D\+V5M/B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@Q,@IM<V=I9"`B06QL(@IM<V=S='(@(D%L;&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$S('1E;7!L871E<R]F;VQD97)S+VIA
M=F%S8W)I<'0N:6YC.C4*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@
M9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O
M;F4@34)/6"`B"B)F:6QE.B(*;7-G<W1R(")!;&QA(&UE9&1E;&%N9&5N(&D@
M9O9L:F%N9&4@;6%P<"AA<BD@;&%D9&%S(&YE<B!T:6QL(&5N($U"3U@M9FEL
M.B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@>6]U
M<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E
M<FUA;F5N=&QY("(*(F1E;&5T960N(@IM<V=S='(@(B(*(D%L;&$@;65D9&5L
M86YD96X@:2!D:6X@)R5S)RUM87!P+"#D;&1R92#D;B`E<R!D86=A<B!K;VUM
M97(@871T(')A9&5R87,@(@HB<&5R;6%N96YT+B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD(&QI;FME9"!A='1A8VAM96YT
M<R!M;W)E('1H86X@)7,@;6]N=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(@IM
M<V=S='(@(D%L;&$@;.1N:V%D92!B:6QA9V]R(.1L9')E(.1N("5S(&WE;F%D
M97(@:V]M;65R(&%T="!R861E<F%S+B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!;&P@;VQD('-E;G0M;6%I;"!F;VQD97)S(&UO<F4@=&AA
M;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B(@HB
M06QL82!M87!P87(@9O9R('-K:6-K861E(&UE9&1E;&%N9&5N+"#D;&1R92#D
M;B`E<R!MY6YA9&5R(&MO;6UE<B!A='0@<F%D97)A<RXB"@HC.B!A8VPN<&AP
M.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!R:6=H=',@;VX@9F]L9&5R
M(%PB)7-<(B!S=6-C97-S9G5L;'D@<F5M;W9E9"!F;W(@=7-E<B!<(B5S7"(N
M(@IM<V=S='(@(D)E:/9R:6=H971E<B!T:6QL(&UA<'!E;B`G)7,G(')A9&5R
M861E<R!F]G(@86YVY&YD87)E("<E<R<N(@H*(SH@;&EB+V%P:2YP:'`Z-S8*
M;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A=&EO;C\B"FUS9W-T<B`B5&EL;.5T
M(&%T="!M87!P87(@<VMA<&%S/R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHT.`IM<V=I9"`B06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P
M<&QI960@:6X@86YY(&UA:6QB;W@_(@IM<V=S='(@(E1I;&SE="!A='0@9FEL
M=&5R+7)E9VQE<B!T:6QLY&UP87,@:2!A;&QA(&)R979LY61O<C\B"@HC.B!L
M:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM<V=I9"`B06QT
M97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS9W-T<B`B06QT
M97)N871I=F$@9&5L87(@9O9R(&1E;B!HY'(@9&5L96XZ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4W,@IM<V=I9"`B06QW87ES(@IM<V=S='(@(D%L
M;'1I9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3<*;7-G:60@(D%L
M=V%Y<R!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(E-P87)A(&%L;'1I9"!B
M:6QA9V]R(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C4U-`IM<V=I9"`B(@HB06X@
M97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-T<FEP('1H92!A
M='1A8VAM96YT+B!4:&4@24U!4"!S97)V97(@(@HB<V%I9#H@(@IM<V=S='(@
M(D5T="!F96P@=7!P<W1O9"!NY'(@8FEL86=A;B!S:W5L;&4@=&%S(&)O<G0Z
M($E-05`M<V5R=F5R;B!S=F%R861E.B`B"@HC.B!L:6(O365S<V%G92YP:'`Z
M-#,W"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E
M871I;F<@=&AE(&YE=R!N;W1E+B(*;7-G<W1R(")%='0@;VOD;G0@9F5L('5P
M<'-T;V0@=FED('5P<&SD9V=N:6YG96X@878@=7!P9VEF=&5N+B(*"B,Z(&QI
M8B]-97-S86=E+G!H<#HT,S8*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C
M=7)E9"!W:&EL92!C<F5A=&EN9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(D5T
M="!O:^1N="!F96P@=7!P<W1O9"!V:60@=7!P;.1G9VYI;F=E;B!A=B!U<'!G
M:69T96XN(@H*(SH@;65S<V%G92YP:'`Z-3`T(&UA:6QB;W@N<&AP.C<P.2!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.CD*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C,U"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI
M;F,Z-@IM<V=I9"`B06YS=V5R960B"FUS9W-T<B`B0F5S=F%R870B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS9VED(")!;G-W97)E9"!M
M97-S86=E<R(*;7-G<W1R(")"97-V87)A9&4@;65D9&5L86YD96XB"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C<*;7-G:60@(D%P<&QY($9I
M;'1E<G,B"FUS9W-T<B`B5F5R:W-TY&QL(&9I;'1E<B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VAE861E<BYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M<'!L>2!&:6QT97)S('1O("5S(@IM<V=S='(@(E9E<FMS=.1L;"!F:6QT97(@
M<.4@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,S8*;7-G
M:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I;F<@;VX_(@IM<V=S
M='(@(E9E<FMS=.1L;"!F:6QT97)R96=L97(@=FED(&EN;&]G9VYI;F<_(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C0R"FUS9VED(")!<'!L
M>2!F:6QT97(@<G5L97,@=VAE;F5V97(@24Y"3U@@:7,@9&ES<&QA>65D/R(*
M;7-G<W1R(")697)K<W3D;&P@9FEL=&5R<F5G;&5R(&[D<B!I;FMO<F=E;B!V
M:7-A<S\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@5FER
M='5A;"!&;VQD97(@1&5F:6YI=&EO;C\B"FUS9W-T<B`BQ'(@9'4@<^1K97(@
M871T(&1U('9I;&P@<F%D97)A(&%K='5E;&P@=FER='5E;&P@;6%P<#\B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR-PIM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E
M;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(L1R(&1U('/D:V5R(&%T
M="!D=2!V:6QL(')A9&5R82!D96X@<'5B;&EK82!N>6-K96QN/R(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-SD@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C@U"FUS9VED("(B"B)!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&5L
M971E('EO=7(@:V5Y<&%I<C\@*%1H:7,@:7,@3D]4(')E8V]M;65N9&5D(2DB
M"FUS9W-T<B`BQ'(@9'4@<^1K97(@871T(&1U('9I;&P@<F%D97)A(&YY8VME
M;'!A<F5T/R`H4F5K;VUM96YD97)A<R!)3E1%(2DB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FIS.C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T
M:&ES/R(*;7-G<W1R("+$<B!D=2!SY&ME<C\B"@HC.B!M97-S86=E+G!H<#HT
M,#D@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@
M=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(L1R(&1U('/D:V5R('#E(&%T="!D
M=2!V:6QL(')A9&5R82!D97-S82!M961D96QA;F1E;B!015)-04Y%3E0_(@H*
M(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C(S.0IM<V=I9"`B07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&ES(&%T=&%C
M:&UE;G0_(@IM<V=S='(@(L1R(&1U('/D:V5R('#E(&%T="!D=2!V:6QL(')A
M9&5R82!B:6QA9V%N(%!%4DU!3D5.5#\B"@HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&5M<'1Y('1H:7,@9F]L9&5R/R(*;7-G<W1R("+$<B!D=2!SY&ME<B!P
MY2!A='0@9'4@=FEL;"!T]FUM82!M87!P96X_(@H*(SH@;&EB+TE-4"YP:'`Z
M.30Y"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U
M<B!S<&%M(&9O;&1E<C\B"FUS9W-T<B`BQ'(@9'4@<^1K97(@<.4@871T(&1U
M('9I;&P@=/9M;6$@9&EN(&UA<'`@9O9R('-K<N1P<&]S=#\B"@HC.B!T96UP
M;&%T97,O;65N=2]M96YU+FEN8SHR.2!L:6(O24U0+G!H<#HY-#(*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O
M;&1E<C\B"FUS9W-T<B`BQ'(@9'4@<^1K97(@<.4@871T(&1U('9I;&P@=/9M
M;6$@9&EN('!A<'!E<G-K;W)G/R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!P
M97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(L1R
M(&1U('/D:V5R('#E(&%T="!D=2!V:6QL(')A9&5R82!D97-S82!M961D96QA
M;F1E;B!015)-04Y%3E0_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C
M<FEP="YI;F,Z.#`@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z
M-SD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI
M<R!M97-S86=E(&%S(&EN;F]C96YT/R(*;7-G<W1R("+$<B!D=2!SY&ME<B!P
MY2!A='0@9'4@=FEL;"!R87!P;W)T97)A(&UE9&1E;&%N9&5T('-O;2!O<VMY
M;&1I9W0_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z
M-S4@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-S0*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E
M(&%S('-P86T_(@IM<V=S='(@(L1R(&1U('/D:V5R('#E(&%T="!D=2!V:6QL
M(')A<'!O<G1E<F$@;65D9&5L86YD970@<V]M('-K<N1P<&]S=#\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`U"FUS9VED(")!<G)I=F%L(%1I;64B
M"FUS9W-T<B`B06YK;VUS='1I9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,C`*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R(")3=&EG86YD92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-S$*;7-G:60@(D%S:R(*;7-G<W1R
M(")&<N5G82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W
M,@IM<V=I9"`B071T86-H($9I;&5S(@IM<V=S='(@(D)I9F]G82!F:6QE<B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0U,PIM<V=I9"`B
M071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@
M;65S<V%G93\B"FUS9W-T<B`B0FEF;V=A(&5N(&MO<&EA(&%V(&1I;B!P=6)L
M:6MA(%!'4"UN>6-K96P@=&EL;"!M961D96QA;F1E=#\B"@HC.B!L:6(O34E-
M12]6:65W97(O=&YE9BYP:'`Z,3$Q"FUS9VED(")!='1A8VAE9"!&:6QE.B(*
M;7-G<W1R(")":69O9V%D(&9I;#HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#8R
M(&QI8B]#;VUP;W-E+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M071T86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T86-H;65N="!S
M:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(@IM<V=S='(@(B(*(D)I
M9F]G860@9FEL(%PB)7-<(B#V=F5R<VMR:61E<B!M87AS=&]R;&5K(&;V<B!B
M:6QA9V]R+B!&:6QE;B!H87(@96H@8FEF;V=A=',N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C,W-PIM<V=I9"`B071T86-H960@:7,@82!R97!L
M>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N(@IM<V=S='(@(D)I
M9F]G87(@<W9A<B!PY2!K86QE;F1E<BUF]G)F<N5G86X@9'4@<VMI8VMA9&4N
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,30*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3`P('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FIS.C4U"FUS9VED(")!='1A8VAM96YT(@IM<V=S='(@(D)I;&%G
M82(*"B,Z(&%T=&%C:&UE;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D%T=&%C:&UE;G0@)7,@9&5L971E9"XB"FUS9W-T<B`B0FEF;V=A9&4@9FEL
M96X@)7,@<F%D97)A9&5S+B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,3(U"FUS
M9VED(")!='1A8VAM96YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D)I;&%G96EN
M9F]R;6%T:6]N(@H*(SH@8V]M<&]S92YP:'`Z,3$P-2!L:6(O365S<V%G92YP
M:'`Z-3$U"FUS9VED(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A
M='1A8VAM96YT('1Y<&4B"FUS9W-T<B`B0FEL86=A(&)O<G1T86=E;CH@5'EP
M('#E('5R<W!R=6YG<V)I;&%G86XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#<P"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ,#DS"FUS9VED(")!='1A8VAM96YT
M<R(*;7-G<W1R(")":6QA9V]R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8W.`IM<V=I9"`B071T96YD965S(@IM<V=S='(@(D1E;'1A9V%R92(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4S"FUS9VED
M(")!='1E;G1I;VXB"FUS9W-T<B`B3V)S97)V97)A(@H*(SH@;&EB+T%U=&@O
M:6UP+G!H<#HT-`IM<V=I9"`B075T:%]I;7`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z($MA;B!I;G1E
M(&AI='1A(&1E;B!N]F1VY&YD:6=A($E-05`M=73V:VYI;F=E;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C(X"FUS9VED("(B"B)!=71O;6%T:6-A
M;&QY('-H;W<@:6UA9V5S(&EN($A434P@;65S<V%G97,@=VAE;B!T:&4@<V5N
M9&5R(&ES(&EN(&UY("(*(F%D9')E<W-B;V]K/R(*;7-G<W1R("(B"B)6:7-A
M(&)I;&1E<B!I($A434PM;65D9&5L86YD96X@875T;VUA=&ES:W0@;N1R(&%V
M<^1N9&%R96X@9FEN;G,@:5QN(@HB861R97-S8F]K96X_(@H*(SH@=&5M<&QA
M=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDX"FUS9VED(")!=F%I;&%B
M;&4@061D<F5S<R!B;V]K<SHB"FUS9W-T<B`B5&EL;&?D;F=L:6=A(&%D<F5S
M<V+V8VME<CHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S$T"FUS
M9VED(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R(")6Y&YT87(@<.4@<W9A
M<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`B
M5&EL;&)A7VMA('1I;&P@)7,B"@HC.B!T:')E860N<&AP.C$S-R!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V"B,L('!H<"UF;W)M
M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B5&EL;&)A:V$@=&EL;"`E
M<R(*"B,Z('1H<F5A9"YP:'`Z,3,T"FUS9VED(")"86-K('1O($UU;'1I<&QE
M($UE<W-A9V4@5FEE=R!);F1E>"(*;7-G<W1R("+%=&5R=N1N9"!T:6QL(&UE
M9&1E;&%N9&5V:7-N:6YG96XB"@HC.B!T:')E860N<&AP.C$S,@IM<V=I9"`B
M0F%C:R!T;R!4:')E860@1&ES<&QA>2(*;7-G<W1R(")4:6QL8F%K82!T:6QL
M('1RY61V:7-N:6YG(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-S(*;7-G
M:60@(D)A9"!L;V=I;B!N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")/9VEL
M=&EG="!A;G;D;F1A<FYA;6X@96QL97(@;/9S96YO<F0N(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%D(&]R
M(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G
M<W1R(")/9VEL=&EG(&;V<F9RY6=A;BX@4V5R=F5R;B!S=F%R861E.B`E<R(*
M"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z-3<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D)A9"!R97%U97-T.B`E<RXB"FUS9W-T<B`B1F5L86MT:6<@8F5GY')A
M;CH@)7,N(@H*(SH@;65S<V%G92YP:'`Z,C<T('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M
M<&]S92YI;F,Z,C`@;&EB+U-E87)C:"YP:'`Z-C`Q"FUS9VED(")"8V,B"FUS
M9W-T<B`B0F-C(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38Q
M"FUS9VED(")"96QO=R!I<R!T:&4@<F%W('1E>'0@;V8@=&AE('-T871U<R!I
M;F9O<FUA=&EO;B!M97-S86=E+B(*;7-G<W1R(").961A;B!F:6YN<R!U<G-P
M<G5N9W-T97AT96X@9G+E;B!S=&%T=7-M961D96QA;F1E="XB"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C$@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,38*;7-G:60@(D)L86-K;&ES="(*;7-G
M<W1R(")3<.1R<F$@861R97-S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8Q-PIM<V=I9"`B0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G97,@=6YL
M97-S('1H97D@87)E('-P96-I9FEC86QL>2!R97%U97-T960_(@IM<V=S='(@
M(D)L;V-K97)A(&)I;&1E<B!I($A434PM;65D9&5L86YD96X@;VT@9&4@:6YT
M92!SY')S:VEL="!E9G1E<F9RY6=A<S\B"@HC.B!L:6(O4V5A<F-H+G!H<#HV
M,#D*;7-G:60@(D)O9'DB"FUS9W-T<B`B365D9&5L86YD971E>'0B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C(S('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,SD*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU-2!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C<Q"FUS9VED(")";W1H(@IM<V=S
M='(@(D+E9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@T"FUS9VED
M(")";W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4B"FUS
M9W-T<B`B0N5D92!I(&AU=G5D970@;V-H(&D@;65D9&5L86YD970B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C4P,0IM<V=I9"`B0U)!32U-1#4@;W(@1$E'
M15-4+4U$-2!R97%U:7)E<R!T:&4@075T:%]305-,('!A8VMA9V4@=&\@8F4@
M:6YS=&%L;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHR-S(*;7-G:60@(D-?:&%R<V5T(@IM<V=S='(@(E1?96-K
M96YK;V1N:6YG(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C,V
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,C`Q"FUS9VED(")#86X@;F]T(&-O;FYE8W0@
M=&\@=&AE(')E;6]T92!M86EL('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EN=&4@
M:V]N=&%K=&$@92UP;W-T<V5R=F5R;B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,3DY"FUS9VED(")#86X@;F]T(&-O;FYE8W0@=&\@=&AE(')E;6]T
M92!M86EL('-E<G9E<CH@(@IM<V=S='(@(DMA;B!I;G1E(&MO;G1A:W1A(&4M
M<&]S='-E<G9E<FXZ("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P87)T:6%L+G!H
M<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#86X@;F]T(&1I<W!L87D@
M+2!F;W5N9"!O;FQY("5S(&]F("5S('!A<G1S(&]F('1H:7,@;65S<V%G92!I
M;B!T:&4@8W5R<F5N="`B"B)M86EL8F]X+B(*;7-G<W1R("(B"B)+86X@:6YT
M92!V:7-A("T@:&ET=&%D92!B87)A("5S(&%V("5S(&1E;&%R(&%V(&UE9&1E
M;&%N9&5T(&D@86MT=65L;"`B"B)B<F5V;.5D82XB"@HC.B!F;VQD97)S+G!H
M<#HR-S`@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-34*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR,2!T96UP;&%T97,O<V%V
M96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M<&QA=&5S+W-M:6UE+W!A
M<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P('1E
M;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%V
M8G)Y="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<Q('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@365S<V%G
M92(*;7-G<W1R(")!=F)R>70B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS.C8*;7-G
M:60@(D-A;F-E;&QI;F<@=&AI<R!M97-S86=E('=I;&P@<&5R;6%N96YT;'D@
M9&ES8V%R9"!I=',@8V]N=&5N=',N(@IM<V=S='(@(D]M(&1U(&%V8G)Y=&5R
M(&;V<G-V:6YN97(@86QL="!I(&UE9&1E;&%N9&5T+B(*"B,Z(&UE<W-A9V4N
M<&AP.C(W,R!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R,0HC
M.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$U(&QI8B]396%R
M8V@N<&AP.C4Y-PIM<V=I9"`B0V,B"FUS9W-T<B`B0V,B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I
M;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N
M86)L960@;VX@=&AI<R`B"B)S97)V97(N(@IM<V=S='(@(B(*(D-E<G1I9FEK
M871I;7!O<G0@Y'(@:6YT92!T:6QL9^1N9VQI9W0N(%5P<&QA9&1N:6YG(&%V
M(&9I;&5R(.1R(&EN=&4@(@HB86MT:79E<F%T('#E('-E<G9E<FXN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-@IM<V=I9"`B0VAA:7(@4&5R
M<V]N(@IM<V=S='(@(D]R9&;V<F%N9&4B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R("+$;F1R
M82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,0IM<V=I
M9"`B0VAA;F=E($%L;"(*;7-G<W1R("+$;F1R82!A;&QA(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.CDR"FUS9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S
M='(@(L1N9')A(&UA<'`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R
M"FUS9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W
M(&UA;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO
M=R!M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R("+$;F1R82!I;G-TY&QL
M;FEN9V%R(&;V<B!V:7-N:6YG(&%V(&%N=&%L(&UE9&1E;&%N9&5N(&]C:"!S
M;W)T97)I;F<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T"FUS9VED
M(")#:&%N9V4@;6%I;"!S97)V97(@86YD(&9O;&1E<B!S971T:6YG<RXB"FUS
M9W-T<B`BQ&YD<F$@:6YS=.1L;&YI;F=A<B!F]G(@92UP;W-T<V5R=F5R(&]C
M:"!M87!P87(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U"FUS9VED
M("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S:6=N871U<F4@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"`B"B)R97!L>2!T
M;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B+$;F1R82!N86UN+"!A9')E<W,@
M;V-H('-I9VYA='5R('-O;2!M;W1T86=A<FYA('-E<B!NY'(@9&4@;.1S97(@
M;V-H('-V87)A<B`B"B)PY2!D:6X@;65D9&5L86YD96XN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@Q,PIM<V=I9"`B0VAA<F%C=&5R<R!T;R!D:7-P
M;&%Y.B(*;7-G<W1R(")!;G1A;"!T96-K96X@871T('9I<V$Z(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,34*;7-G:60@(D-H96-K($9O
M;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B2V]N=')O;&QE<F$@;6%P
M<"AA<BD@9O9R(&YY82!M961D96QA;F1E;B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@
M(DUA<FME<F$@7T%L;&$O26YG96XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+V9E=&-H;6%I;"YI;F,Z,3`@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA
M:6PN:6YC.C(Q"FUS9VED(")#:&5C:R!A;&P@;6%I;"!S97)V97)S('EO=2!W
M86YT('1O(&9E=&-H(&UA:6P@9G)O;3HB"FUS9W-T<B`B2W)Y<W-A(&;V<B!A
M;&QA(&4M<&]S='-E<G9R87(@9'4@=FEL;"!HY&UT82!P;W-T(&9RY6XZ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0V,PIM<V=I9"`B0VAE8VL@<W!E
M;&QI;F<@8F5F;W)E('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R(")+;VYT
M<F]L;&5R82!S=&%V;FEN9R!I;FYA;B!M961D96QA;F1E('-K:6-K87,_(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O=F9O;&1E<E]A8W1I;VYS+FEN8SHS('1E
M;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C0*;7-G:60@(D-H;V]S92!!
M8W1I;VXZ(@IM<V=S='(@(E;D;&H@Y71GY')D.B(*"B,Z(&-O;F9I9R]S97)V
M97)S+G!H<"YD:7-T.C(P,@IM<V=I9"`B0VAO;W-E(&$@;6%I;"!S97)V97(Z
M(@IM<V=S='(@(E;D;&H@96X@92UP;W-T<V5R=F5R.B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,C$W"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E9&ET('1H92!A9&1R
M97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`B5N1L:B!E;&QE<B#D;F1R82!A
M9')E<W-E;B!I(')U=&%N('1I;&P@:/9G97(Z(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-O=7)C97-E;&5C="YI;F,Z,S0Y"FUS9VED(")#:&]O<V4@=&AE(&%D
M9')E<W,@8F]O:R!T;R!U<V4@=VAE;B!A9&1I;F<@861D<F5S<V5S+B(*;7-G
M<W1R(")6Y&QJ(&%D<F5S<V)O:R!DY'(@;GEA(&%D<F5S<V5R(&SD9V=S('1I
M;&PN(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,CDS
M"FUS9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@=&\@
M<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B5N1L
M:B!O<F1N:6YG('-O;2!A9')E<W-B]F-K97(@9V5N;VUS]FMS('9I9"!E>'!A
M;G-I;VX@878@861R97-S97(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O
M;G9E<G0@=&AE(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S
M97(@8V%N('9I97<N(@IM<V=S='(@(B(*(DML:6-K82`E<R!F]G(@871T(&MO
M;G9E<G1E<F$@8FEL9&5N('1I;&P@971T(&9O<FUA="!D:6X@=V5B8FSD<V%R
M92!K86Y<;B(*(G9I<V$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z,3`T"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL
M;V%D('1H92!I;6%G92XB"FUS9W-T<B`B2VQI8VMA("5S(&;V<B!A='0@;&%D
M9&$@;F5R(&)I;&1E;BXB"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N86=E;65N
M="!P86=E+B(*;7-G<W1R(")+;&EC:V$@)7,@9O9R(&%T="!GY2!T:6QL("5S
M+6AA;G1E<FEN9W-S:61A;BXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP
M:'`Z,3$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@
M2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G<W1R(")+
M;&EC:V$@)7,@9O9R(&%T="!V:7-A($A434PM:6YN96CE;&P@:2!E='0@96=E
M="!F]FYS=&5R+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!V:65W(&$@=&AU
M;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(DML:6-K82`E<R!F]G(@
M871T('9I<V$@96X@;6EN:6%T>7(@878@9&5N(&CD<B!B:6QD96XN(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E
M<&%R871E('=I;F1O=RXB"FUS9W-T<B`B2VQI8VMA("5S(&;V<B!A='0@=FES
M82!B:6QA9V%N(&D@971T(&5G970@9O9N<W1E<BXB"@HC.B!L:6(O34E-12]6
M:65W97(O<F5L871E9"YP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI
M8VL@)7,@=&\@=FEE=R!T:&ES(&UU;'1I<&%R="]R96QA=&5D('!A<G0@:6X@
M82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(DML:6-K82`E<R!F]G(@871T
M('9I<V$@;75L=&EP87)T+W)E;&%T960@:2!E='0@96=E="!F]FYS=&5R+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY.`IM<V=I9"`B0VQI8VL@
M:&5R92!T;R!32$]7('1H92!);6%G97,B"FUS9W-T<B`B2VQI8VMA(&CD<B!F
M]G(@871T(%9)4T$@8FEL9&5R;F$B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,C$*;7-G:60@(B(*(D-L:6-K(&]N(&]N92!O9B!Y
M;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O:W,@86YD('1H96X@<V5L96-T(&%L
M;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*;7-G<W1R("(B"B)+;&EC:V$@<.4@
M96X@878@9&EN82!A9')E<W-B]F-K97(@;V-H(&%N9V4@<V5D86X@=FEL:V$@
M9N1L="!S;VT@<VMA;&P@(@HB9V5N;VUS]FMA<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O<&=P+G!H<#HQ-S`*;7-G:60@(D-L:6-K('1O(%-A=F4@4$=0(%!U
M8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VLB"FUS9W-T<B`B2VQI8VMA
M(&;V<F$@871T('-P87)A('!U8FQI:R!01U`M;GEC:V5L(&D@9&EN(&%D<F5S
M<V)O:R(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C`R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC
M871E(&]F("5S(&EN('EO=7(@061D<F5S<R!";V]K(@IM<V=S='(@(DML:6-K
M82!F]G)A(&%T="!S<&%R82!3+TU)344@8V5R=&EF:6MA="!F]G(@)7,@:2!D
M:6X@861R97-S8F]K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS.0IM
M<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@
M;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E<B(*;7-G<W1R("(B"B)/;2!D=2!K
M;&EC:V%R('#E(&%D<F5S<V5N(&;E<B!D=2!S:W)I=F$@971T(&YY='0@;65D
M9&5L86YD92!T:6QL7&XB"B)A=G/D;F1A<F5N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDT,`IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D9')E<W,@
M=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860B"FUS9W-T<B`B3VT@
M9'4@:VQI8VMA<B!PY2!A9')E<W-E;B#V<'!N87,@;65D9&5L86YD970@9O9R
M('9I<VYI;F<B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI
M;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S='(@(E-TY&YG(@H*(SH@8V]M<&]S
M92YP:'`Z-#$X"FUS9VED(")#;&]S92!T:&ES('=I;F1O=R(*;7-G<W1R(")3
M=.1N9R!F]FYS=')E="(*"B,Z(&9O;&1E<G,N<&AP.C0Q,`IM<V=I9"`B0VQO
M<V5D($9O;&1E<B(*;7-G<W1R(")3=.1N9V1A(&UA<'!A<B(*"B,Z(&9O;&1E
M<G,N<&AP.C0S,`IM<V=I9"`B0V]L;&%P<V4B"FUS9W-T<B`B4W3D;F<B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B0V]L
M;&%P<V4@06QL(@IM<V=S='(@(E-TY&YG(&%L;&$B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHT,`IM<V=I9"`B0V]L;&%P<V4@06QL($9O
M;&1E<G,B"FUS9W-T<B`B4W3D;F<@86QL82!M87!P87(B"@HC.B!F;VQD97)S
M+G!H<#HT,S`*;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R(")3=.1N
M9R!M87!P(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C4Q
M"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R(")&Y')G:6YD:6MA
M=&]R.B`B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`S"FUS9VED(")#
M;VUM96YT(@IM<V=S='(@(DMO;6UE;G1A<B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW-C(*;7-G:60@(D-O;7!L971E9"(*;7-G<W1R(")3;'5T
M9O9R9"(*"B,Z(&-O;7!O<V4N<&AP.C0Q-PIM<V=I9"`B0V]M<&]S92!A;F]T
M:&5R(&UE<W-A9V4B"FUS9W-T<B`B4VMR:78@971T(&%N;F%T(&UE9&1E;&%N
M9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,T"FUS9VED(")#;VUP
M;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")3
M:W)I=B!M961D96QA;F1E;B!I(&5T="!S97!A<F%T(&;V;G-T97(_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,PIM<V=I9"`B(@HB0V]M<&]S92!M
M97-S86=E<R!W:71H(&%N($A434P@1U5)(&)Y(&1E9F%U;'0@*&EF(&)R;W=S
M97(@<W5P<&]R=',@=&AE("(*(F9E871U<F4I/R(*;7-G<W1R("(B"B)3:W)I
M=B!M961D96QA;F1E;B!M960@971T($A434PM9W+D;G-S;FET="`H;VT@=V5B
M;.1S87)E;B!S=/9D:F5R(&9U;FMT:6]N96XI/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-PIM<V=I9"`B0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A
M<F4@9&ES<&QA>65D+B(*;7-G<W1R("));G-TY&QL;FEN9V%R(&;V<B!M961D
M96QA;F1E=FES;FEN9RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*
M;7-G:60@(D-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB"FUS9W-T
M<B`BQ&YD<F$@:6YS=.1L;&YI;F=A<B!F]G)H86YD<V=R86YS:VYI;F<N(@H*
M(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-S`*;7-G:60@(D-O;FYE8W1I;VX@
M9')O<'!E9"!B>2!)34%0('-E<G9E<BXB"FUS9W-T<B`B1O9R8FEN9&5L<V5N
M(&YE9&MO<'!L860@878@24U!4"US97)V97)N+B(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,C,T"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F
M86EL960B"FUS9W-T<B`B06YS;'5T;FEN9R!T:6QL('-E<G9E<FX@;6ES<VQY
M8VMA9&5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM
M<V=S='(@(DAA;G1E<FEN9R!A=B!01U`@:2`E<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@
M4R]-24U%('-U<'!O<G0@9F]R("5S+B(*;7-G<W1R(")(86YT97)I;F<@878@
M4R]-24U%(&D@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0IM
M<V=I9"`B0V]N=')O;"!O<'1I;VYS(')E;&%T:6YG('1O(&UE<W-A9V5S('-E
M87)C:&EN9RXB"FUS9W-T<B`B26YS=.1L;&YI;F=A<B!F]G(@<_9K;FEN9R!I
M(&UE9&1E;&%N9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS
M9VED("(B"B)#;VYT<F]L('=H96X@;F5W(&UA:6P@=VEL;"!B92!C:&5C:V5D
M(&9O<BP@86YD('=H971H97(@;W(@;F]T('1O(&YO=&EF>2!Y;W4@(@HB=VAE
M;B!I="!A<G)I=F5S+B(*;7-G<W1R("(B"B)+;VYT<F]L;&5R82!NY'(@;GEA
M(&UE9&1E;&%N9&5N(&%N;.1N9&5R(&]C:"!A;F=E(&]M(&YO=&EF:65R:6YG
M('-K86QL('-K92`B"B)NY'(@9&4@86YLY&YD97(N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8W-`IM<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M;W1I
M8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G<W1R(")+;VYV97)T97)A
M(&OD;G-L;VEK;VYE<B!I('1E>'1F;W)M('1I;&P@9W)A9FES:V$_(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S
M='(@(DMO<&EE<F$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*
M;7-G:60@(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@(DMO<&EE<F$@=&EL;"!M
M87!P(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS
M9VED(")#;W)R96-T(@IM<V=S='(@(DMO<G)E:W0B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z,30P"FUS9VED(")#;W)R96-T960@5&5X
M="(*;7-G<W1R(")+;W)R:6=E<F%D('1E>'0B"@HC.B!L:6(O24U!4"]#;&EE
M;G0N<&AP.C,X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]M
M<&QE=&4@<F5Q=65S="X@4F5A<V]N($=I=F5N.B`E<R(*;7-G<W1R(")+=6YD
M92!I;G1E('-L=71F]G)A(&)E9^1R86XN($%N;&5D;FEN9SH@)7,B"@HC.B!A
M='1A8VAM96YT+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8W)E871E('1H92!61E,@8F%C:V5N9#H@)7,B"FUS9W-T<B`B2W5N9&4@
M:6YT92!S:V%P82!61E,M:V]P<&QI;F=E;CH@)7,B"@HC.B!L:6(O365S<V%G
M92YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@;65S<V%G97,@9G)O;2`E<RX@5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G
M<W1R(")+=6YD92!I;G1E(')A9&5R82!M961D96QA;F1E;B!F<N5N("5S+B!3
M97)V97)N('-V87)A9&4Z("5S(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C,S,PIM
M<V=I9"`B0V]U;&0@;F]T(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<RXB"FUS9W-T<B`B2W5N9&4@:6YT92!U=&;V<F$@=6YD97)HY6QL<V%K=&EV
M:71E=&5R(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C4T"FUS9VED
M(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T
M:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R(")+=6YD92!I;G1E(&5X
M=')A:&5R82!B96?D<F0@9FEL(&9RY6X@35,M5$Y%1B!B:6QA9V%N+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@
M97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI
M=F4N(@IM<V=S='(@(DMU;F1E(&EN=&4@97AT<F%H97)A(&)E9^1R9"!F:6P@
M9G+E;B!:25`M87)K:79E="XB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C0T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!S96-U<F4@
M8V]N;F5C=&EO;B!T;R!T:&4@24U!4"!S97)V97(N("5S(#H@)7,N(@IM<V=S
M='(@(DMA;B!I;G1E('-K87!A(&5N('/D:V5R(&%N<VQU=&YI;F<@=&EL;"!)
M34%0+7-E<G9E<FXN("5S(#H@)7,N(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C(X
M,`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&YA;65S<&%C92!I;F9O<FUA
M=&EO;B!F<F]M($E-05`@<V5R=F5R+B(*;7-G<W1R(")+86X@:6YT92!HY&UT
M82!N86UN9&5F:6YI=&EO;B!F<N5N($E-05`M<V5R=F5R+B(*"B,Z('1E;7!L
M871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T97,O86-L+V%C
M;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,0IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(E-K87!A(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E<B(*;7-G<W1R(")3
M:V%P82!M87!P(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I
M9"`B0W)E871E($ME>7,B"FUS9W-T<B`B4VMA<&$@;GEC:VQA<B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+W9F;VQD97)?86-T:6]N<RYI;F,Z,3$*;7-G:60@
M(D-R96%T92!6:7)T=6%L($9O;&1E<B(*;7-G<W1R(")3:V%P82!V:7)T=65L
M;"!M87!P(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C
M="YI;F,Z,C8*;7-G:60@(D-R96%T92!A($YE=R!!8V-O=6YT(@IM<V=S='(@
M(E-K87!A(&YY='0@:V]N=&\B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E
M;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T
M"FUS9VED(")#<F5A=&4@82!N97<@4W!A;2!F;VQD97(B"FUS9W-T<B`B4VMA
M<&$@;GD@;6%P<"!F]G(@<VMRY'!P;W-T(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E
M;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L9&5R
M(@IM<V=S='(@(E-K87!A(&YY(&UA<'`@9O9R('5T:V%S="(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S+W!R
M969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@;F5W
M('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B4VMA<&$@;GD@;6%P<"!F]G(@
M<VMI8VMA9&4@;65D9&5L86YD96XB"@HC.B!T96UP;&%T97,O<')E9G,O=')A
M<VAS96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T
M<B`B4VMA<&$@;GD@;6%P<"!F]G(@<&%P<&5R<VMO<F<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG
M(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I
M="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`B
M(@HB4VMA<&$@9FEL=')E<FEN9W-R96=L97(@9O9R(&%T="!O<F=A;FES97)A
M(&EN:V]M;6%N9&4@;65D9&5L86YD96XL('-O<G1E<F$@(@HB:6X@:2!M87!P
M87(@;V-H(')A9&5R82!S:W+D<'!O<W0N(@H*(SH@=&5M<&QA=&5S+W-T871I
M;VYE<GDO<')E9G,N:6YC.C$T"FUS9VED(")#<F5A=&4@;F5W('-T871I;VYE
M<GDB"FUS9W-T<B`B4VMA<&$@;GD@;6%L;"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-#D*;7-G:60@(D-R96%T92!S=&%T:6]N97)Y(&%N9"!F;W)M
M(')E<W!O;G-E<RXB"FUS9W-T<B`B4VMA<&$@;6%L;&%R(&]C:"!F;W)M=6SD
M<G-V87(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-U<G)E;G0@86-C97-S('1O("5S(@IM<V=S='(@(DYU
M=F%R86YD92!RY'1T:6=H971E<B!F]G(@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E
M=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`B4VMR
MY&1D87)S>2!K;VYT;VX@9O9R(&CD;71N:6YG(&%V(&UE9&1E;&%N9&5N(&9R
MY6X@86YD<F$@:V]N=&]N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,0IM<V=I9"`B0W5S=&]M:7IE(&AO=R!Y;W4@<V5N9"!M86EL+B(*;7-G<W1R
M(")3:W+D9&1A<G-Y(&AU<B!D=2!S:VEC:V%R(&UE9&1E;&%N9&5N+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM
M<V=S='(@(E-K<N1D9&%R<WD@86MT:79I=&5T97(@<V]M(&OV<G,@=FED(&EN
M;&]G;FEN9R!T:6QL("5S+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,3<*;7-G:60@(D1A=%]E(@IM<V=S='(@(D1A=%]U
M;2(*"B,Z(&UE<W-A9V4N<&AP.C(W,"!T:')E860N<&AP.C$U,PIM<V=I9"`B
M1&%T92(*;7-G<W1R(")$871U;2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HW-3`*;7-G:60@(D1E8VQI;F5D(@IM<V=S='(@(D%V8O9J="(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C0*;7-G:60@(D1E8VQI;F5D
M.B`B"FUS9W-T<B`B079B]FIT.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,W"FUS9VED(")$969A=6QT(@IM<V=S='(@(E-T86YD87)D(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C(Q"FUS
M9VED(")$969A=6QT(%-E87)C:"!&:65L9"(*;7-G<W1R(")&]G)V86QT('/V
M:V;D;'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$R"FUS9VED(")$
M969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S='(@(D;V<G9A;&0@<V]R
M=&5R:6YG<V]R9&YI;F<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR
M,@IM<V=I9"`B1&5F875L="!S;W)T:6YG(&1I<F5C=&EO;CHB"FUS9W-T<B`B
M1O9R=F%L9"!S;W)T97)I;F=S<FEK=&YI;F<Z(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C<U.`IM<V=I9"`B1&5L96=A=&5D(@IM<V=S='(@(D1E
M;&5G97)A9"(*"B,Z(&9O;&1E<G,N<&AP.C0P,"!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR-#0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z."!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC.B!T96UP;&%T97,O<VUI
M;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FEN8SHR.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*;7-G:60@(D1E
M;&5T92(*;7-G<W1R(")2861E<F$B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@)7,@4'5B;&EC($ME>2(*;7-G<W1R(")2861E
M<F$@<'5B;&EK(&YY8VME;"!F]G(@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B
M1&5L971E($-U<G)E;G0@2V5Y<R(*;7-G<W1R(")2861E<F$@86MT=65L;&$@
M;GEC:VQA<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*
M;7-G:60@(D1E;&5T92!&;VQD97(H<RDB"FUS9W-T<B`B4F%D97)A(&UA<'`H
M87(I(@H*(SH@9F]L9&5R<RYP:'`Z,C<Q"FUS9VED(")$96QE=&4@4V5L96-T
M960@1F]L9&5R<R(*;7-G<W1R(")2861E<F$@=F%L9&$@;6%P<"AA<BDB"@HC
M.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z-#(*;7-G:60@(D1E
M;&5T92!3=&%T:6]N97)Y(@IM<V=S='(@(E)A9&5R82!M86QL(@H*(SH@9F]L
M9&5R<RYP:'`Z-#`P('1E;7!L871E<R]F;VQD97)S+W9F;VQD97)?86-T:6]N
M<RYI;F,Z-@IM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@
M(E)A9&5R82!V:7)T=65L;"!M87!P(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:&5A9&5R+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@5FER
M='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B"FUS9W-T<B`BQ&YD<F$@
M9&5F:6YI=&EO;F5N(&;V<B!D96X@=FER='5E;&QA(&UA<'!E;B`E<R(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L
M971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G
M<W1R(")2861E<F$@:.1M=&%D92!M961D96QA;F1E;B!F<N5N('-E<G9E<C\B
M"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C$Y"FUS9VED(")$96QE
M=&4@9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R(")482!B;W)T(&9RY6X@;6EN
M(&MA;&5N9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I
M9"`B1&5L971E(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG
M(&]F(&UO;G1H/R(*;7-G<W1R(")2861E<F$@;.1N:V%D92!B:6QA9V]R(&D@
M8O9R:F%N(&%V(&WE;F%D96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,U,`IM<V=I9"`B1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B
M96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(E)A9&5R82!M87!P*&%R*2!F
M]G(@<VMI8VMA9&4@;65D9&5L86YD96X@=FED(&+V<FIA;B!A=B!MY6YA9&5N
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,#4*;7-G:60@(D1E;&5T
M92!S<&%M(&UE<W-A9V5S(@IM<V=S='(@(E)A9&5R82!S:W+D<'!O<W0B"@HC
M.B!M97-S86=E+G!H<#HU,#<@;6%I;&)O>"YP:'`Z-S,U('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,C`*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C@*;7-G
M:60@(D1E;&5T960B"FUS9W-T<B`B4F%D97)A9"(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS
M9W-T<B`B4F%D97)A9&4@;65D9&5L86YD96XB"@HC.B!C;VUP;W-E+G!H<#HU
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@871T86-H;65N
M="!<(B5S7"(N(@IM<V=S='(@(E)A9&5R861E(&)I;&%G86X@)7,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@
M36]V:6YG($UE<W-A9V5S(@IM<V=S='(@(E)A9&5R82!O8V@@9FQY='1A(&UE
M9&1E;&%N9&5N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-PIM
M<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(D%V<VSE(&)E9^1R86XB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30R"FUS9VED(")$96YY(')E
M<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R(")!=G-L
MY2!B96?D<F%N(&]M(&QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I9"`B1&5S8V5N9&EN9R(*
M;7-G<W1R(")&86QL86YD92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FEN8SHR,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8V"FUS
M9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")"97-K<FEV;FEN9R(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM
M<V=I9"`B1&5T86EL<R(*;7-G<W1R(")$971A;&IE<B(*"B,Z(&-O;7!O<V4N
M<&AP.C4X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$:60@;F]T(&%T=&%C:"!<
M(B5S7"(@87,@=&AE(&9I;&4@=V%S(&5M<'1Y+B(*;7-G<W1R(")<(B5S7"(@
M8FEF;V=A9&5S(&EN=&4@969T97)S;VT@9&5N(.1R('1O;2XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C8U"FUS9VED(")$:6T@<VEG;F%T=7)E<S\B
M"FUS9W-T<B`B1W+E;6%R:V5R82!S:6=N871U<C\B"@HC.B!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S-@IM<V=I9"`B1&ES<&QA>2(*;7-G
M<W1R(")6:7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W.0IM<V=I
M9"`B1&ES<&QA>2!C;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A
M9V4_(@IM<V=S='(@(E9I<V$@8F5K<N1F=&5L<V4@969T97(@871T(&UE9&1E
M;&%N9&4@:&%R('-K:6-K871S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.#,*;7-G:60@(D1I<W!L87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S
M='(@(E9I<V$@:2!M961D96QA;F1E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.#$*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O
M9B!N97<@;6%I;#\B"FUS9W-T<B`B5FES82!P;W!U<"!N;W1I9FEE<FEN9R!V
M:60@;GEA(&UE9&1E;&%N9&5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-#<*;7-G:60@(D1I<W!L87D@=&AE(%PB16UP='D@4W!A;5PB(&QI;FL@
M:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@(E9I<V$@7")4]FT@<VMRY'!P;W-T
M7"(@:2!M96YY;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S,Y"FUS
M9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%1R87-H7"(@;&EN:R!I;B!T:&4@
M;65N=6)A<C\B"FUS9W-T<B`B5FES82!<(E3V;2!P87!P97)K;W)G7"(@:2!M
M96YY;C\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z
M,3$*;7-G:60@(D1I<W!O<VET:6]N(@IM<V=S='(@(E!L86-E<FEN9R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4
M(&UA=&-H(@IM<V=S='(@(E-K86QL($E.5$4@;6%T8VAA(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#:&5C
M:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(DMO;G1R;VQL97)A
M(&EN=&4@;6%P<"AA<BD@9O9R(&YY82!M961D96QA;F1E;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-#$*;7-G:60@(D1O(&YO="!G96YE<F%T92!A
M(&QI;FL@:6X@=&AE($9R;VTZ(&-O;'5M;B(*;7-G<W1R(")3:V%P82!I;F=E
M;B!LY&YK(&%V($9RY6XM:V]L=6UN96XB"@HC.B!L:6(O24U0+G!H<#HQ,#4S
M"FUS9VED(")$;R!Y;W4@=V%N="!T;R!O<&5N('1H870@9F]L9&5R/R(*;7-G
M<W1R(")6:6QL(&1U(/9P<&YA(&UA<'!E;C\B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C(S,0IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT
M/R!3:6=N('5P+B(*;7-G<W1R(")(87(@9'4@:6YG970@:V]N=&\_(%)E9VES
M=')E<F$@9&EG+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHQ,C8*;7-G:60@(D1O;F4B"FUS9W-T<B`B2VQA<B(*"B,Z(&QI8B]-24U%
M+T-O;G1E;G1S+G!H<#HR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO
M860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B2.1M=&$@)7,@<V]M(&5N
M("YZ:7`M9FEL(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z
M-3(*;7-G:60@(D1O=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F
M:6QE*2(*;7-G<W1R(")(Y&UT82!A;&QA(&)I;&%G;W(@*'-O;2!E;B`N>FEP
M+69I;"DB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,`IM
M<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S='(@(DCD;71A(&UA<'`H
M87(I(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*;7-G
M:60@(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=(@IM<V=S='(@
M(DCD;71A(&UA<'`H87(I("AS;VT@96X@+GII<"UF:6PI(@H*(SH@;&EB+TU)
M344O0V]N=&5N=',N<&AP.C(Q-@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&
M;W)M870B"FUS9W-T<B`B2.1M=&$@:2`N>FEP+69O<FUA="(*"B,Z(&UE<W-A
M9V4N<&AP.C4P-2!M86EL8F]X+G!H<#HW,30@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHQ,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHY"FUS9VED(")$<F%F
M="(*;7-G<W1R(")5=&MA<W0B"@HC.B!F;VQD97)S+G!H<#HS-S,*;7-G:60@
M(D1R869T(&9O;&1E<B(*;7-G<W1R(")5=&MA<W0M;6%P<"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS9VED(")$<F%F=',@
M9F]L9&5R.B(*;7-G<W1R(")5=&MA<W0M;6%P<#HB"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3`X"FUS9VED(")%+6UA:6P@061D<F5S<R(*;7-G<W1R
M(")%+7!O<W1A9')E<W,B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S`R"FUS9VED
M(")%3D0B"FUS9W-T<B`B4TQ55"(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C<T"FUS9VED(")%4E)/4CH@66]U<B!M97-S86=E(&-O=6QD(&YO
M="!B92!D96QI=F5R960N(@IM<V=S='(@(D9%3#H@1&ET="!M961D96QA;F1E
M(&MU;F1E(&EN=&4@;&5V97)E<F%S+B(*"B,Z(&9O;&1E<G,N<&AP.C0P,2!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,3D*;7-G:60@(D5D:70B
M"FUS9W-T<B`BQ&YD<F$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z,3@*;7-G:60@(D5D:70@0FQA8VML:7-T(@IM<V=S='(@(L1N9')A('-P
MY')R861E(&%D<F5S<V5R(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C$S"FUS9VED(")%9&ET($9I;'1E<G,B"FUS9W-T<B`BQ&YD<F$@9FEL
M=&5R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$Y('1E;7!L
M871E<R]M86EL8F]X+VAE861E<BYI;F,Z,38*;7-G:60@(D5D:70@4V5A<F-H
M(%%U97)Y(@IM<V=S='(@(E)E9&EG97)A('/V:V9RY6=A(@H*(SH@9F]L9&5R
M<RYP:'`Z-#`Q('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ-PHC.B!T
M96UP;&%T97,O9F]L9&5R<R]V9F]L9&5R7V%C=&EO;G,N:6YC.C0*;7-G:60@
M(D5D:70@5FER='5A;"!&;VQD97(B"FUS9W-T<B`BQ&YD<F$@=FER='5E;&P@
M;6%P<"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B!$969I;FET
M:6]N(&9O<B`E<R(*;7-G<W1R("+$;F1R82!D969I;FET:6]N96X@9O9R(&1E
M;B!V:7)T=65L;&$@;6%P<&5N("5S(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O
M<')E9G,N:6YC.C(S"FUS9VED(")%9&ET(%=H:71E;&ES="(*;7-G<W1R("+$
M;F1R82!B971R;V1D82!A9')E<W-E<B(*"B,Z('1E;7!L871E<R]F:6QT97)S
M+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*;7-G
M<W1R("+$;F1R82!S<.1R<F%D92!A9')E<W-E<B(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHQ,PIM<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R
M=6QE<R(*;7-G<W1R("+$;F1R82!F:6QT97)R96=L97(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#4P"FUS9VED(")%9&ET('EO=7(@<')E9F5R96YC
M97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S+B(*;7-G<W1R
M("+$;F1R82!I;G-TY&QL;FEN9V%R(&;V<B#E=&MO;7-T(&%V(&%N9')A(&4M
M<&]S=&MO;G1O;BXB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,C,*;7-G:60@(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`BQ&YD<F$@
M8F5T<F]D9&$@861R97-S97(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C(S.0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%
M+7!O<W1A9')E<W,B"@HC.B!L:6(O365S<V%G92YP:'`Z-CDW"B,L('!H<"UF
M;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE<W-A9V5S(&9R;VT@)7,N(@IM
M<V=S='(@(E)E;G-A9&4@86QL82!M961D96QA;F1E;B!F<N5N("5S+B(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HV-S,*;7-G:60@(D5M<'1I960@86QL(&UE<W-A
M9V5S(&9R;VT@5FER='5A;"!4<F%S:"!&;VQD97(N(@IM<V=S='(@(E)E;G-A
M9&4@86QL82!M961D96QA;F1E;B!F<N5N('9I<G1U96QL82!P87!P97)S:V]R
M9V5N+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS
M9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B5/9M(&UA<'`H87(I(@H*
M(SH@9F]L9&5R<RYP:'`Z,C<R"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD
M97)S(@IM<V=S='(@(E3V;2!M87)K97)A9&4@;6%P<&%R(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5M<'1Y(%1R87-H
M(&9O;&1E<B(*;7-G<W1R(")4]FT@4&%P<&5R<VMO<F<B"@HC.B!L:6(O24U0
M+G!H<#HY-#D*;7-G:60@(D5M<'1Y(%]3<&%M(@IM<V=S='(@(E3V;2!?<VMR
MY'!P;W-T(@H*(SH@=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z,CD@;&EB+TE-
M4"YP:'`Z.30R"FUS9VED(")%;7!T>2!?5')A<V@B"FUS9W-T<B`B5/9M(%]P
M87!P97)S:V]R9R(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ('1E;7!L
M871E<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4$=0(&9U
M;F-T:6]N86QI='D_(@IM<V=S='(@(D%K=&EV97)A(%!'4"UF=6YK=&EO;F%L
M:71E=#\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$@=&5M<&QA
M=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B16YA8FQE(%,O34E-
M12!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")!:W1I=F5R82!3+TU)344M9G5N
M:W1I;VYA;&ET970_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@P,`IM
M<V=I9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_(@IM<V=S='(@(D%K=&EV
M97)A(&;V<FAA;F1S9W)A;G-K;FEN9R!A=B!M961D96QA;F1E;C\B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,SD*;7-G:60@(D5N8W)?
M>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`B2W)?>7!T97)I;F=S:6YS=.1L;&YI
M;F=A<B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3@*;7-G
M:60@(D5N8W)Y<'1E9"(*;7-G<W1R(")+<GEP=&5R870B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3$V(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU,3@*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8U,2!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-C4S"FUS9VED(")%;F0B"FUS9W-T<B`B4VQU
M="(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS.34*;7-G:60@(D5N9"!F;W)W87)D
M960@;65S<V%G92(*;7-G<W1R(")3;'5T('#E('9I9&%R96)E9F]R9')A="!M
M961D96QA;F1E(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,U,@IM<V=I9"`B16YD
M(&UE<W-A9V4B"FUS9W-T<B`B4VQU="!PY2!M961D96QA;F1E;B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YD(&UE
M<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")3;'5T('#E(&UE9&1E;&%N9&4@9G+E
M;B`E<R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")%;G1E<B!087-S<&AR87-E(@IM
M<V=S='(@(D%N9V4@;/9S96YO<F0B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A
M;7-E;&5C="YI;F,Z.0IM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@
M;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(D%N9V4@;F%M;B!PY2!N>2!M87!P
M(&;V<B!S:W+D<'!O<W0B"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L
M96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M9')A9G1S(&9O;&1E<B(*;7-G<W1R(")!;F=E(&YA;6X@<.4@;GD@;6%P<"!F
M]G(@=71K87-T(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T
M+FEN8SHR,PIM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E
M;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B06YG92!N86UN('#E(&YY(&UA<'`@
M9O9R('-K:6-K861E(&UE9&1E;&%N9&5N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W1R87-H<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@
M>6]U<B!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(D%N9V4@;F%M;B!PY2!N
M>2!P87!P97)S:V]R9R(*"B,Z(&QI8B]396%R8V@N<&AP.C8Q,PIM<V=I9"`B
M16YT:7)E($UE<W-A9V4B"FUS9W-T<B`B2&5L82!M961D96QA;F1E="(*"B,Z
M(&UE<W-A9V4N<&AP.C$Y-2!C;VUP;W-E+G!H<#HQ,3<R('1H<F5A9"YP:'`Z
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<GD@7"(E<UPB('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(*;7-G<W1R("(G
M)7,G(&QA9&5S('1I;&P@:2!A9')E<W-B;VME;BXB"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C$X('1E;7!L871E<R]P9W`O<&=P+FEN8SHR,0HC
M.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,X,2!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HS.3`*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M-S(@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38S"FUS9VED(")%<G)O
M<B(*;7-G<W1R(")&96PB"@HC.B!L:6(O1F5T8VAM86EL+VAO=&UA:6PN<&AP
M.C(R.`IM<V=I9"`B17)R;W(@-#`S.B!297%U97-T('=A<R!F;W)B:61D96XN
M(@IM<V=S='(@(D9E;"`T,#,Z($)E9^1R86X@=&EL;.5T<R!I;G1E+B(*"B,Z
M(&QI8B]&971C:&UA:6PO:&]T;6%I;"YP:'`Z,C,R"FUS9VED(")%<G)O<B`U
M,#,Z(%-E<G9I8V4@:7,@=6YA=F%I;&%B;&4N(@IM<V=S='(@(D9E;"`U,#,Z
M(%-E<G9I8V4@96H@=&EL;&?D;F=L:6<B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C0S,2!L:6(O24U!4"]#;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!C;VYN96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z
M("5S+B(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT82!M86EL<V5R=F5R;BX@
M)7,@.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3`@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`B1F5L('5N9&5R
M('/D;F1N:6YG(&%V('-V87)S;65D9&5L86YD93H@)7,B"@HC.B!L:6(O1F5T
M8VAM86EL+VAO=&UA:6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)%<G)O<CH@2&%D('1O(&UA:V4@)60@<F5Q=65S=',L(&-H96-K('5S97)N
M86UE(&%N9"!P87-S=V]R9"!O<B!I;F-R96%S92`B"B)R97%U97-T(&-O=6YT
M(&QI;6ET+B(*;7-G<W1R("(B"B)&96PZ($=J;W)D92`E9"!F]G)S]FLL('9A
M<B!G;V0@:V]N=')O;&QE<B!A;G;D;F1A<FYA;6X@;V-H(&SV<V5N;W)D+"!E
M;&QE<B`B"B+V:V$@;6%X(&%N=&%L(&;V<G/V:RXB"@HC.B!L:6(O1F5T8VAM
M86EL+VAO=&UA:6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<CH@56YR96-O9VYI>F5D($A45%`@<W1A='5S('=A<R!R96-I979E9#H@)7,N
M(@IM<V=S='(@(D9E;#H@3VOD;F0@2%144"US=&%T=7,Z("5S+B(*"B,Z(&QI
M8B]&971C:&UA:6PO:&]T;6%I;"YP:'`Z,C8S"FUS9VED(")%<G)O<CH@9G-O
M8VMO<&5N*"D@9F%I;&5D+B(*;7-G<W1R(")&96PZ(&9S;V-K;W!E;B@I(&UI
M<W-L>6-K861E<RXB"@HC.B!L:6(O1F5T8VAM86EL+VAO=&UA:6PN<&AP.C(V
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<CH@9G-O8VMO<&5N*"D@9F%I
M;&5D+B!%<G)O<B!N;SH@)7,N($5R<F]R('-T<FEN9R`E<RXB"FUS9W-T<B`B
M1F5L.B!F<V]C:V]P96XH*2!M:7-S;'EC:V%D97,N($9E;"!N<CH@)7,N($9E
M;'1E>'0Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,#(*
M;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")(
MY&YD96QS92!R861E<F%D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-S$*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B5F%R(#$U.F4@
M;6EN=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8X"FUS9VED(")%
M=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(E9A<B`S,#IE('-E:W5N9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S`*;7-G:60@(D5V97)Y(#4@;6EN
M=71E<R(*;7-G<W1R(")687(@-3IE(&UI;G5T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<W,@IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@
M(E9A<FIE(&AA;'9T:6UM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-CD*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")687)J92!M:6YU="(*
M"B,Z(&9O;&1E<G,N<&AP.C0S.`IM<V=I9"`B17AP86YD(@IM<V=S='(@(D5X
M<&%N9&5R82(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Y
M"FUS9VED(")%>'!A;F0@06QL(@IM<V=S='(@(D5X<&%N9&5R82!A;&QA(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D5X
M<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R(")%>'!A;F1E<F$@86QL82!M87!P
M87(B"@HC.B!F;VQD97)S+G!H<#HT,S@*;7-G:60@(D5X<&%N9"!&;VQD97(B
M"FUS9W-T<B`B17AP86YD97)A(&UA<'`B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS-#`@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C4S"FUS9VED(")%>'!A;F0@3F%M97,B"FUS9W-T<B`B17AP86YD97)A
M(&YA;6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U,@IM<V=I9"`B
M17AP86YD(&YA;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A
M;&QY(&EN('1H92!B86-K9W)O=6YD/R(*;7-G<W1R(")!=71O;6%T:7-K(&)A
M:V=R=6YD<V5X<&%N<VEO;B!A=B!A9')E<W-E<B!NY'(@9'4@86YG97(@;6]T
M=&%G87)E/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-CD*;7-G:60@
M(D5X<&%N9"!T:&4@96YT:7)E(&9O;&1E<B!T<F5E(&)Y(&1E9F%U;'0@:6X@
M=&AE(&9O;&1E<G,@=FEE=S\B"FUS9W-T<B`B17AP86YD97)A(&%L;&$@;6%P
M<&%R('-O;2!F]G)V86QD(&EN<W3D;&QN:6YG(&D@;6%P<'9Y;C\B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-#0@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,3DT"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C(T-2!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z
M,3`Q"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V5?97AP86YD+FIS.C0Y
M"FUS9VED(")%>'!A;F1I;F<B"FUS9W-T<B`B17AP86YD97)A<B(*"B,Z(&QI
M8B])35`N<&AP.CDV,"!L:6(O24U0+G!H<#HY-C(*;7-G:60@(D9?971C:"!-
M86EL(@IM<V=S='(@(DCD;5]T82!E+7!O<W0B"@HC.B!T96UP;&%T97,O9F5T
M8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P-`IM<V=I9"`B1F5T8V@@36%I;"(*;7-G<W1R(")(Y&UT82!E+7!O<W0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4X"FUS9VED(")&971C:"!-
M86EL(&EN(&$@<V5P87)A=&4@=VEN9&]W/R(*;7-G<W1R(")(Y&UT82!E+7!O
M<W0@:2!E='0@<V5P87)A="!F]FYS=&5R+B(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO;6%N86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O
M;B!L;V=G:6YG(&]N/R(*;7-G<W1R(")(Y&UT82!M961D96QA;F1E;B!V:60@
M:6YL;V=G;FEN9S\B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S(@IM
M<V=S='(@(DCD;71A9&4@)60@;65D9&5L86YD96X@9G+E;B`E<RXB"@HC.B!L
M:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F5T
M8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R(")(Y&UT861E(#$@;65D
M9&5L86YD92!F<N5N("5S+B(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-R!L
M:6(O1F5T8VAM86EL+G!H<#HR.#D@;&EB+T9E=&-H;6%I;"YP:'`Z,CDQ"FUS
M9VED(")&971C:&UA:6PZ("(*;7-G<W1R(")&971C:&UA:6PZ("(*"B,Z(&QI
M8B]&971C:&UA:6PN<&AP.C(Y,PIM<V=I9"`B1F5T8VAM86EL.B!N;R!N97<@
M;65S<V%G97,N(@IM<V=S='(@(D9E=&-H;6%I;#H@:6YG82!N>6$@;65D9&5L
M86YD96XN(@H*(SH@=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z-#0@;&EB+TE-
M4"YP:'`Z.38V"FUS9VED(")&:5]L=&5R<R(*;7-G<W1R(")&:5]L=&5R(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#DV('1E;7!L871E
M<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FIS.C0P"FUS9VED(")&:6QE(@IM<V=S
M='(@(D9I;"(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHS,0IM
M<V=I9"`B1FEL=&5R($]P=&EO;G,B"FUS9W-T<B`B1FEL=&5R:6YS=.1L;&YI
M;F=A<B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHY"FUS9VED
M(")&:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`B1FEL=&5R:6YS=.1L;&YI;F=A
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#@*;7-G:60@(D9I;'1E
M<B!M97-S86=E(&-O;G1E;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`B1FEL
M=')E<F$@;65D9&5L86YD92!PY2!S=F]R9&]M87(_(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O;F]T86-T:79E+FEN8SHQ,0IM<V=I9"`B1FEL=&5R('-U<'!O
M<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(D9I;'1E
M<G-U<'!O<G0@Y'(@879S=.1N9W0@:2!S>7-T96UE="XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I
M;'1E<B(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,PIM
M<V=I9"`B1FEL=&5R<R!.3U0@06-T:79E(@IM<V=S='(@(D9I;'1E<B#D<B!)
M3E1%(&%K=&EV="(*"B,Z(&QI8B]&:6QT97(N<&AP.C$S,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QT97)S.B`E<R!M86YA9V5M96YT('!A9V4B"FUS9W-T
M<B`B)7,M9FEL=&5R:&%N=&5R:6YG<W-I9&$B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN9"(*;7-G<W1R(")3
M]FLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#DT"FUS9VED(")&:7)S
M="!-86EL8F]X(%!A9V4B"FUS9W-T<B`B1O9R<W1A(&)R979LY61E<VED86XB
M"@HC.B!M86EL8F]X+G!H<#HS,S$*;7-G:60@(D9I<G-T(%!A9V4B"FUS9W-T
M<B`B1O9R<W1A('-I9&%N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC
M.C(Q"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R(")6:61A7W)E8F5F;W)D<F$B
M"@HC.B!F;VQD97)S+G!H<#HR-3(@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R
M<U]C;VYF:7)M+FAT;6PZ-0IM<V=I9"`B1F]L9&5R($%C=&EO;G,@+2!#;VYF
M:7)M871I;VXB"FUS9W-T<B`B0F5K<N1F=&5L<V4@9O9R(.5T9^1R9&5R(&D@
M;6%P<&%R(@H*(SH@9F]L9&5R<RYP:'`Z,C@Y('1E;7!L871E<R]F;VQD97)S
M+VAE860N:6YC.CD*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E<V5L
M96-T+FEN8SHV"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C
M="YI;F,Z,3`*;7-G:60@(D9O;&1E<B!.879I9V%T;W(B"FUS9W-T<B`B36%P
M<&YA=FEG871O<B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HS"FUS9VED
M(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R(")-87!P<V%M;6%N<W3D;&QN:6YG
M(@H*(SH@86-L+G!H<#HR,PIM<V=I9"`B1F]L9&5R('-H87)I;F<@:7,@;F]T
M(&5N86)L960N(@IM<V=S='(@(DUA<'!D96QN:6YG(.1R(&EN=&4@=&EL;&?D
M;F=L:6=T+B(*"B,Z(&9O;&1E<G,N<&AP.C0W"FUS9VED(")&;VQD97(@=7-E
M(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R(")-87!P86YVY&YD;FEN9R#D<B!I
M;G1E('1I;&QGY6YG;&EG="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.34X"FUS9VED(")&;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I
M;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A>2(*;7-G<W1R(")$
M871U;69O<FUA="!I(&)R979LY61E=GEN(&;V<B!M961D96QA;F1E;B!D871E
M<F%D92!I9&%G(@H*(SH@8V]M<&]S92YP:'`Z.#(P('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G<W1R(")6:61A
M<F5B969O<F1R82(*"B,Z(&-O;7!O<V4N<&AP.C@P-0IM<V=I9"`B1F]R=V%R
M9#HB"FUS9W-T<B`B5FED87)E8F5F;W)D<F$Z(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C,X,`IM<V=I9"`B1F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`B5FED
M87)E8F5F;W)D<F%T(&UE9&1E;&%N9&4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,S<X"B,L('!H<"UF;W)M870*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(&9R
M;VT@)7,B"FUS9W-T<B`B5FED87)E8F5F;W)D<F%T(&UE9&1E;&%N9&4@9G+E
M;B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#(*;7-G:60@
M(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(E-V87(@<.4@
M;&5D:6<O=7!P=&%G96XM9O9R9G+E9V%N(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHR-PIM<V=I9"`B1G)O7VTB"FUS9W-T
M<B`B1G+E7VXB"@HC.B!M97-S86=E+G!H<#HR-S$@=&AR96%D+G!H<#HQ-30@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.3D*(SH@;&EB+U-E87)C
M:"YP:'`Z-3@Y"FUS9VED(")&<F]M(@IM<V=S='(@(D9RY6XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3`W"FUS9VED(")&<F]M($%D9')E<W,B"FUS
M9W-T<B`B1G+E;BUA9')E<W,B"@HC.B!C;VUP;W-E+G!H<#HX,3<@8V]M<&]S
M92YP:'`Z.#(Q"FUS9VED(")&=V0Z(@IM<V=S='(@(E9".B(*"B,Z(&-O;7!O
M<V4N<&AP.C$S,3$*;7-G:60@(D9W9#H@(@IM<V=S='(@(E9".B`B"@HC.B!C
M;VUP;W-E+G!H<#HQ,S$S"B,L('!H<"UF;W)M870*;7-G:60@(D9W9#H@)74@
M1F]R=V%R9&5D($UE<W-A9V5S(@IM<V=S='(@(E9".B`E=2!V:61A<F)E9F]R
M9')A="!M961D96QA;F1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")'96YE
M<F%L($]P=&EO;G,B"FUS9W-T<B`B06QL;>1N;F$@:6YS=.1L;&YI;F=A<B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHS-PIM<V=I9"`B
M1V5T(&]N;'D@;F5W(&UE<W-A9V5S/R`H24U!4"!O;FQY*2(*;7-G<W1R(")(
MY&UT82!E;F)A<G0@;GEA(&UE9&1E;&%N9&5N/R`H24U!4"DB"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS,B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-34T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,C@*
M;7-G:60@(D=O(@IM<V=S='(@(D]+(@H*(SH@=&AR96%D+G!H<#HQ,S8*;7-G
M:60@(D=O('1O($UE<W-A9V4B"FUS9W-T<B`B1^4@=&EL;"!M961D96QA;F1E
M(@H*(SH@;&EB+TE-4"YP:'`Z-3`R"B,L('!H<"UF;W)M870*;7-G:60@(D=O
M('1O(&%D9')E<W,@8F]O:R!E;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`B1^4@
M=&EL;"!A9')E<W-B;VMS<&]S="!F]G(@7"(E<UPB(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C$S-@IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S='(@
M(E1I;&SE="#E=&MO;7-T(@H*(SH@;65S<V%G92YP:'`Z-34P(&QI8B]&:6QT
M97(N<&AP.C$S,2!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*(SH@
M;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3$Q(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$Q,PHC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HQ-C0@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q.0HC.B!L:6(O34E-
M12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L:6(O34E-12]6:65W97(O
M;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-12]6:65W97(O<F5L871E
M9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,C,*(SH@;&EB
M+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT,2!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HQ-S(*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R-PIM<V=I9"`B2$52
M12(*;7-G<W1R(")(Q%(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F
M<RYI;F,Z,S$@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R,`HC.B!L:6(O
M34E-12]6:65W97(O<F5L871E9"YP:'`Z.#`*;7-G:60@(DA434PB"FUS9W-T
M<B`B2%1-3"(*"B,Z(&-O;7!O<V4N<&AP.C(V,`IM<V=I9"`B2%1-3"!697)S
M:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B2%1-3"UV97)S:6]N(&%V(&UE9&1E
M;&%N9&5T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`B4G5B<FEK97(B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G:60@(DAE<F4@:7,@=&AE
M(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*;7-G<W1R(")(Y'(@Y'(@
M;65D9&5L86YD970@9'4@<VMR978@<.4Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U-@IM<V=I9"`B2&ED9&5N(@IM<V=S='(@(D?V;60B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4U"FUS9VED(")(:61D96X@:6X@5&AR
M96%D(%9I97<B"FUS9W-T<B`B1_9M9"!I('1RY61V>2(*"B,Z(&UA:6QB;W@N
M<&AP.C,U,PIM<V=I9"`B2&ED92!$96QE=&5D(@IM<V=S='(@(D3V;&H@<F%D
M97)A9&4B"@HC.B!F;VQD97)S+G!H<#HR.#0*;7-G:60@(DAI9&4@56YS=6)S
M8W)I8F5D(@IM<V=S='(@(D?V;2!U;G-U8G-C<FEB960B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B"FUS9W-T
M<B`B2/9G(@H*(SH@;65S<V%G92YP:'`Z,S`U(&UA:6QB;W@N<&AP.C<Q.2!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H(%!R
M:6]R:71Y(@IM<V=S='(@(DCV9R!P<FEO<FET970B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.3,*;7-G:60@(DAI9VAE<W0B"FUS9W-T
M<B`B2/9G<W0B"@HC.B!L:6(O1F5T8VAM86EL+VAO=&UA:6PN<&AP.C4P"FUS
M9VED(")(;W1M86EL($%C8V]U;G1S(@IM<V=S='(@(DAO=&UA:6PM:V]N=&]N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X-0IM<V=I9"`B2&]W(&1O
M('EO=2!W86YT('1O(&1I<W!L87D@871T86-H;65N=',_(@IM<V=S='(@(DAU
M<B!V:6QL(&1U('9I<V$@8FEL86=O<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3`T"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E9"!L:6YE
M<R!I;B!A(')E<&QY(@IM<V=S='(@(DAU<B!C:71E<F%D92!R861E<B!V:7-A
M<R!I(&5T="!S=F%R(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*
M;7-G:60@(DE-05`B"FUS9W-T<B`B24U!4"(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3(Y"FUS9VED("))34%0("A!=71O($1E=&5C="!0<F]T;V-O
M;',I(@IM<V=S='(@(DE-05`@*'5P<'3D8VL@<')O=&]K;VQL(&%U=&]M871I
M<VMT*2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,SDQ"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@4V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BX@
M4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B24U!4"US97)V97)N(&)R
M]G0@9O9R8FEN9&5L<V5N+B!397)V97)N('-V87)A9&4Z("5S(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C4@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB"FUS9W-T<B`B24U!4"#V
M=F5R(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,34R"FUS9VED
M("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"!C97)T:69I8V%T92DB"FUS
M9W-T<B`B24U!4"#V=F5R(%-33"`H<VKD;'9S:6=N97)A="!C97)T:69I:V%T
M*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38V"FUS9VED("))
M34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B24U!4"#V=F5R
M(%-33"`H<VKD;'9S:6=N97)A9"DB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP
M.C,V.`IM<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N
M+B(*;7-G<W1R("))34%0+7-E<G9E<FX@8G+V="!F]G)B:6YD96QS96XN(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C0@;&EB+T9E=&-H;6%I
M;"]I;6%P+G!H<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R("))
M34%0+"!I;F=E;B!43%,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C0Y
M"FUS9VED("))34%0+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@(DE-05`O
M4$]0,R!E+7!O<W1S97)V<F%R(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT
M,3$*;7-G:60@(DEF('5S:6YG(%-33"!O<B!43%,L('EO=2!M=7-T(&AA=F4@
M=&AE(%!(4"!O<&5N<W-L(&5X=&5N<VEO;B!L;V%D960N(@IM<V=S='(@(B(*
M(D]M(&1U(&%N=N1N9&5R(%-33"!E;&QE<B!43%,@<^4@;>5S=&4@9'4@:&$@
M3U!%3E-33"UT:6QLY&=G970@=&EL;"!02%`@(@HB;&%D9&%T+B(*"B,Z('1E
M;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"FUS9VED
M("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R
M*',I('=I;&P@8F4@;&]S="$B"FUS9W-T<B`B(@HB3VT@9'4@=N1L:F5R(&%T
M="!F;W)T<^1T=&$@<^4@:V]M;65R(&%L;&$@;65D9&5L86YD96X@:2!M87!P
M96XO;6%P<&%R;F$@871T("(*(F;V<G-V:6YN82$B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G<W1R
M("))9VYO<F5R82(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G<W1R("))9VYO<F5R82!A;&QA
M(@H*(SH@=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C@*;7-G
M:60@(DEM86=E(@IM<V=S='(@(D)I;&0B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]I;7!O<G0N:6YC.C(P"FUS9VED("));7!O<G0B"FUS9W-T<B`B26UP;W)T
M97)A(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@U('1E
M;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-C4*;7-G:60@(DEM<&]R="!+
M97DB"FUS9W-T<B`B26UP;W)T97)A(&YY8VME;"(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ,SD*;7-G:60@(DEM<&]R="!+97EP86ER(@IM<V=S='(@
M(DEM<&]R=&5R82!N>6-K96QP87(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR-PIM<V=I9"`B26UP;W)T($UE<W-A9V5S(@IM<V=S='(@
M(DEM<&]R=&5R82!M961D96QA;F1E;B(*"B,Z('!G<"YP:'`Z-#$*;7-G:60@
M(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@(DEM<&]R=&5R82!01U`M;GEC:V5L
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHY,0IM<V=I9"`B26UP
M;W)T(%!E<G-O;F%L($-E<G1I9FEC871E(@IM<V=S='(@(DEM<&]R=&5R82!P
M97)S;VYL:6=T(&-E<G1I9FEK870B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y(@IM<V=S='(@(DEM<&]R=&5R82!P97)S;VYL:6<@<')I=F%T(%!'
M4"UN>6-K96PB"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.CD*
M;7-G:60@(DEM<&]R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2(*;7-G<W1R
M("));7!O<G1E<F$@<&5R<V]N;&EG('!U8FQI:R!01U`M;GEC:V5L(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0*;7-G:60@(DEM<&]R
M="!097)S;VYA;"!3+TU)344@0V5R=&EF:6-A=&5S(@IM<V=S='(@(DEM<&]R
M=&5R82!P97)S;VYL:6=T(%,O34E-12UC97)T:69I:V%T(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHT,"!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-#(*;7-G:60@(DEM<&]R="!0=6)L:6,@2V5Y(@IM<V=S='(@(DEM<&]R=&5R
M82!P=6)L:6L@;GEC:V5L(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B
M26UP;W)T('!U8FQI:R!01U`M;GEC:V5L(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+VEM<&]R=%]K97DN:6YC.C@*;7-G:60@(DEM<&]R="!0=6)L:6,@4R]-24U%
M($ME>2(*;7-G<W1R("));7!O<G1E<F$@<'5B;&EK(%,O34E-12UN>6-K96PB
M"@HC.B!S;6EM92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@2V5Y(@IM
M<V=S='(@(DEM<&]R=&5R82!3+TU)344M;GEC:V5L(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@;6)O>"!&:6QE
M(@IM<V=S='(@(DEM<&]R=&5R82!M8F]X+69I;"(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+VEM<&]R="YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T(&UB;W@@9FEL92`E<R!I;G1O(&9O;&1E<B`E<RXB"FUS9W-T<B`B26UP
M;W)T97)A(&UB;W@M9FEL("5S('1I;&P@;6%P<&5N("5S+B(*"B,Z(&UE<W-A
M9V4N<&AP.C4P-B!M86EL8F]X+G!H<#HW,CD@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,PHC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM<&]R
M=&%N="(*;7-G<W1R(")6:6MT:6=T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHT-PIM<V=I9"`B26UP;W)T86YT(&UE<W-A9V5S(@IM<V=S='(@
M(E9I:W1I9V$@;65D9&5L86YD96XB"@HC.B!F;VQD97)S+G!H<#HQ-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E
M<RXB"FUS9W-T<B`B26UP;W)T97)A9&4@)60@;65D9&5L86YD96X@9G+E;B`E
M<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8V"FUS9VED("))
M;B!0<F]C97-S(@IM<V=S='(@(E#E9^5E;F1E(@H*(SH@9F]L9&5R<RYP:'`Z
M,S8U('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z,30@
M;&EB+T9O;&1E<BYP:'`Z.#8*(SH@;&EB+T9O;&1E<BYP:'`Z,C$Q(&QI8B])
M35`N<&AP.C@S,"!L:6(O24U!4"]4<F5E+G!H<#HQ,3D*(SH@;&EB+TE-05`O
M5')E92YP:'`Z,C(R"FUS9VED("));F)O>"(*;7-G<W1R("));FMO<F<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR"FUS9VED("));F-L=61E(&$@
M8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P;'D_(@IM<V=S
M='(@(DEN:VQU9&5R82!E;B!K;W)T('-A;6UA;G-TY&QL;FEN9R!A=B!R=6)R
M:6ME<FYA(&D@<W9A<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W
M"FUS9VED("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L>3\B
M"FUS9W-T<B`B26YK;'5D97)A(&]R9VEN86QM961D96QA;F1E(&D@<W9A<C\B
M"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,2!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HQ,S`*;7-G:60@(DEN9F\B"FUS9W-T
M<B`B26YF;R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,L('!H<"UF;W)M870*;7-G:60@(DEN
M9F]R;6%T:6]N(&]N("5S(%!U8FQI8R!+97DB"FUS9W-T<B`B26YF;W)M871I
M;VX@;VT@<'5B;&EK(&YY8VME;"!F]G(@)7,B"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z-S<*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!R
M:79A=&4@2V5Y(@IM<V=S='(@(DEN9F]R;6%T:6]N(&]M('!E<G-O;FQI9R!P
M<FEV870@;GEC:V5L(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV
M."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN9F]R;6%T:6]N
M(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B26YF;W)M871I;VX@
M;VT@<&5R<V]N;&EG('!U8FQI:R!N>6-K96PB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]A='1A8VAM96YT<RYI;F,Z,34@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-3`Q"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S
M+FIS.C4V"FUS9VED("));FQI;F4B"FUS9W-T<B`B26YL:6YE(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.CD*;7-G:60@(DEN<V5R="!#
M97)T:69I8V%T92!(97)E(@IM<V=S='(@(DEN9F]G82!C97)T:69I:V%T(&CD
M<B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,34*;7-G:60@
M(DEN<V5R="!097)S;VYA;"!0<FEV871E(%!'4"!+97D@2&5R92(*;7-G<W1R
M("));F9O9V$@<&5R<V]N;&EG('!R:79A="!01U`M;GEC:V5L(&CD<B(*"B,Z
M('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,3`*;7-G:60@(DEN<V5R
M="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S='(@(DEN9F]G
M82!P97)S;VYL:6<@<'5B;&EK(%!'4"UN>6-K96P@;GEC:V5L(@H*(SH@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED("));G-E<G0@4'5B
M;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("));F9O9V$@<'5B;&EK(%!'4"UN
M>6-K96P@:.1R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,PIM
M<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N
M96YT+B(*;7-G<W1R(")(86YD;&EN9R#D<B!O9VEL=&EG(&;V<B!D96X@:.1R
M(&MO;7!O;F5N=&5N+B(*"B,Z(&UA:6QB;W@N<&AP.C4W-2!M86EL8F]X+G!H
M<#HV,C(*;7-G:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R(")&96QA:W1I
M9R!A9')E<W,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C,P-R!L:6(O
M1F5T8VAM86EL+VAO=&UA:6PN<&AP.C$P,@IM<V=I9"`B26YV86QI9"!296UO
M=&4@36%I;&)O>"(*;7-G<W1R(")&96QA:W1I9R!F:N1R<F)R979LY61A(@H*
M(SH@8V]M<&]S92YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L
M:60@8VAA<F%C=&5R(&EN(&4M;6%I;"!A9&1R97-S.B`E<RXB"FUS9W-T<B`B
M3V=I;'1I9W0@=&5C:V5N(&D@92UP;W-T861R97-S.B`E<RXB"@HC.B!S;6EM
M92YP:'`Z-S@@<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K97DB"FUS9W-T
M<B`B1F5L86MT:6<@;GEC:V5L(@H*(SH@<&=P+G!H<#HQ.3(*;7-G:60@(DEN
M=F%L:60@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y+B(*;7-G<W1R(")&96QA
M:W1I9R!P97)S;VYL:6<@<')I=F%T(%!'4"UN>6-K96PN(@H*(SH@<&=P+G!H
M<#HQ-C<*;7-G:60@(DEN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN
M(@IM<V=S='(@(D9E;&%K=&EG('!E<G-O;FQI9R!P=6)L:6L@4$=0+6YY8VME
M;"XB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R"FUS9VED
M("));G9E<G0B"FUS9W-T<B`B26YV97)T97)A('5R=F%L(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3DQ"FUS9VED(")+0B(*;7-G<W1R
M(")+0B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*;7-G:60@(DME
M>2!,96YG=&@B"FUS9W-T<B`B3GEC:V5L;.1N9V0B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@
M=&%K92!A(&QO;F<@=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@
M:V5Y("(*(F=E;F5R871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS
M9VED(")+97D@:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D
M(&ES(&YO="!E;F%B;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHS.0IM<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA
M8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@
M>6]U<B`B"B)C;VYT86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,30*
M;7-G:60@(DME>2!S=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B3GEC:V5L('-K:6-K861E<R!T:6QL(&1E;B!P
M=6)L:6MA(&YY8VME;'-E<G9E<FXN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,34*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<N5K(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y-0IM<V=I9"`B3&%S="!-86EL
M8F]X(%!A9V4B"FUS9W-T<B`B4VES=&$@8G)E=FSE9&5S:61A;B(*"B,Z(&UA
M:6QB;W@N<&AP.C,T-`IM<V=I9"`B3&%S="!086=E(@IM<V=S='(@(E-I<W1A
M('-I9&%N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30Y
M"FUS9VED("),:6YK($%T=&%C:&UE;G1S/R(*;7-G<W1R("),Y%]N:V$@8FEL
M86=O<C\B"@HC.B!A='1A8VAM96YT+G!H<#HS-"!L:6(O0V]M<&]S92YP:'`Z
M,3`X-`IM<V=I9"`B3&EN:V5D(&%T=&%C:&UE;G1S(&%R92!F;W)B:61D96XN
M(@IM<V=S='(@(DSD;FMA(&)I;&%G;W(@Y'(@:6YT92!T:6QLY71E="XB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,3$P,`HC+"!P:'`M9F]R;6%T"FUS9VED("),
M:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G<W1R("),Y&YK87(@:V]M;65R
M(&%T="!L]G!A('5T("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-S$*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T
M:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL("(*
M(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC
M:71L>2DB"FUS9W-T<B`B(@HB5FES82!A;&QA(&MO;G1A:W1E<B!NY'(@9'4@
M=&%R(&9R86T@:V]N=&%K='9Y;C\@*$%N;F%R<R!S97(@9'4@8F%R85QN(@HB
M:V]N=&%K=&5R(&[D<B!D=2!E>'!L:6-I="!S]FME<B!E9G1E<B!D96TI(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X,@IM<V=I9"`B3&ES=&EN9R!I
M;B!T:&4@2&5A9&5R(@IM<V=S='(@(E9I<V$@:2!H=79U9&5T(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,P"FUS9VED("),;V-A;"!-
M86EL8F]X.B(*;7-G<W1R("),;VMA;"!M87!P.B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HV-S$*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E!L
M871S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,C0*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R("),;V=G82!I;B(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&]G(&EN('1O("5S
M(@IM<V=S='(@(DQO9V=A(&EN('1I;&P@)7,B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$S.`IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B3&]G:6XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SD*;7-G:60@(DQO9VEN(%1A
M<VMS(@IM<V=S='(@(DQO9VEN86MT:79I=&5T97(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR.38*;7-G:60@(DQO=R(*;7-G<W1R("),
MY6<B"@HC.B!M97-S86=E+G!H<#HS,#<@;6%I;&)O>"YP:'`Z-S(R('1E;7!L
M871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3,*;7-G:60@(DQO=R!0<FEO<FET
M>2(*;7-G<W1R("),Y6<@<')I;W)I=&5T(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E<W0B"FUS9W-T<B`B3.1G
M<W0B"@HC.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0T"FUS
M9VED(")-86-I;G1O<V@@1FEL92(*;7-G<W1R(")-86-I;G1O8VAF:6PB"@HC
M.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*;7-G:60@(DUA
M:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDV"FUS9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(D;V<FAA;F1S9W)A
M;G-K;FEN9R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C
M="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C="!T
M;SHB"FUS9W-T<B`B5'EP(&%V(&4M<&]S="!S97)V97(@871T(&%N<VQU=&$@
M=&EL;#HB"@HC.B!F;VQD97)S+G!H<#HS-CD@9F]L9&5R<RYP:'`Z,S@S"FUS
M9VED(")-86EL8F]X(@IM<V=S='(@(D)R979LY61A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,0IM<V=I9"`B36%I;&)O>"!A;F0@1F]L9&5R($1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R(")6:7-N:6YG<VEN<W3D;&QN:6YG87(@
M9O9R(&)R979LY61A(&]C:"!M87!P87(B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@
M1F]L9&5R(&%S(%-E96XB"FUS9W-T<B`B36%R:V5R82!A;&QA(&UE9&1E;&%N
M9&5N(&D@;6%P<&5N('-O;2!LY'-T82(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&
M;VQD97(@87,@56YS965N(@IM<V=S='(@(DUA<FME<F$@86QL82!M961D96QA
M;F1E;B!I(&UA<'!E;B!S;VT@;VSD<W1A(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHU('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,S`*;7-G:60@(DUA<FL@87,Z(@IM<V=S='(@(DUA<FME<F$@
M<V]M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,S@*;7-G:60@(DUA
M<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT
M(&-O;&]R<S\B"FUS9W-T<B`B36%R:V5R82!O;&EK82!N:7;E97(@878@8VET
M870@;65D(&]L:6MA(&;D<F=E<C\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL
M+VUA;F%G92YI;F,Z-#`*;7-G:60@(DUA<FL@;65S<V%G97,@87,@<V5E;C\@
M*$E-05`@;VYL>2DB"FUS9W-T<B`B36%R:V5R82!M961D96QA;F1E;B!S;VT@
M;.1S=&$_("AE;F1A<W0@24U!4"DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0V"FUS9VED(")-87)K('-I;7!L92!M87)K=7`_(@IM<V=S='(@(DAA
M;G1E<F$@96YK96P@=&5X='5P<&WD<FMN:6YG/R(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:&5A9&5R+FEN8SHT.0IM<V=I9"`B36%T8V@@06QL(%%U97)I97,B
M"FUS9W-T<B`B4V%M=&QI9V$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z-#4*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R(")-:6YS
M="!E;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PIM
M<V=I9"`B36%X:6UU;2!!='1A8VAM96YT(%-I>F4B"FUS9W-T<B`B36%X:6UA
M;"!B:6QA9V5S=&]R;&5K(@H*(SH@;&EB+V%P:2YP:'`Z-SD*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F($9O;&1E<G,B"FUS9W-T<B`B36%X(&%N=&%L(&UA
M<'!A<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0X.0IM
M<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@871T86-H;65N=',@<F5A8VAE9"XB
M"FUS9W-T<B`B36%X(&%N=&%L(&)I;&%G;W(@=7!P;N5T="XB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT.#4*;7-G:60@(DUA>&EM=6T@
M=&]T86P@871T86-H;65N="!S:7IE(')E86-H960N(@IM<V=S='(@(DUA>'-T
M;W)L96L@9O9R('-A;71L:6=A(&)I;&%G;W(@=7!P;N5D9"XB"@HC.B!L:6(O
M0FQO8VLO=')E95]F;VQD97)S+G!H<#HS"FUS9VED(")-96YU($9O;&1E<B!,
M:7-T(@IM<V=S='(@(DUE;GD@;6%P<&QI<W1A(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C,T,@IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-961D96QA;F1E(@H*
M(SH@8V]M<&]S92YP:'`Z-3DX(&-O;7!O<V4N<&AP.C8R-2!C;VUP;W-E+G!H
M<#HV-SD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P"FUS9VED(")-97-S86=E
M($-O;7!O<VET:6]N(@IM<V=S='(@(E-K<FEV(&UE9&1E;&%N9&4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`V"FUS9VED(")-97-S86=E($1A=&4B
M"FUS9W-T<B`B365D9&5L86YD961A='5M(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`S"FUS9VED(")-97-S86=E($]P=&EO;G,B"FUS9W-T<B`B365D9&5L86YD
M96EN<W3D;&QN:6YG87(B"@HC.B!S96%R8V@N<&AP.C,P-@IM<V=I9"`B365S
M<V%G92!396%R8V@B"FUS9W-T<B`B365D9&5L86YD97/V:VYI;F<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$P"FUS9VED(")-97-S86=E(%-I>F4B
M"FUS9W-T<B`B365D9&5L86YD97-T;W)L96LB"@HC.B!M97-S86=E+G!H<#HS
M.3(*;7-G:60@(DUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(DUE9&1E;&%N9&5K
MY&QL82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B365S
M<V%G92!6:65W:6YG(@IM<V=S='(@(DUE9&1E;&%N9&5V:7-N:6YG(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-97-S86=E(&9L
M86=S(@IM<V=S='(@(DUE9&1E;&%N9&5F;&%G9V]R(@H*(SH@=&5M<&QA=&5S
M+W-E87)C:"]M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD97)S(@IM
M<V=S='(@(DUE9&1E;&%N9&4@;6%P<&%R(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS
M9W-T<B`B365D9&5L86YD92!F<N5N("5S(@H*(SH@;6%I;&)O>"YP:'`Z-C8S
M"FUS9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R(")-961D
M96QA;F1E="!H87(@8FEL86=O<B(*"B,Z(&UA:6QB;W@N<&AP.C8U-`IM<V=I
M9"`B365S<V%G92!I<R!E;F-R>7!T960B"FUS9W-T<B`B365D9&5L86YD970@
MY'(@:W)Y<'1E<F%T(@H*(SH@;6%I;&)O>"YP:'`Z-C0Y"FUS9VED(")-97-S
M86=E(&ES('-I9VYE9"(*;7-G<W1R(")-961D96QA;F1E="#D<B!S:6=N97)A
M="(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHS-@IM<V=I9"`B
M365S<V%G92!M871C:&5S(@IM<V=S='(@(DUE9&1E;&%N9&4@;6%T8VAA<B(*
M"B,Z(&-O;7!O<V4N<&AP.C@V-"!C;VUP;W-E+G!H<#HX-S$*;7-G:60@(DUE
M<W-A9V4@<F5D:7)E8W1E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DUE9&1E
M;&%N9&4@969T97)SY&YT+B(*"B,Z(&-O;7!O<V4N<&AP.C$Q,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365S<V%G92!S96YT('-U8V-E<W-F=6QL>2P@8G5T
M(&YO="!S879E9"!T;R`E<R(*;7-G<W1R(")-961D96QA;F1E('-K:6-K861E
M<RP@;65N(&MU;F1E(&EN=&4@<W!A<F%S('1I;&P@)7,B"@HC.B!C;VUP;W-E
M+G!H<#HQ,3@Q(&-O;7!O<V4N<&AP.C$Q.#D*;7-G:60@(DUE<W-A9V4@<V5N
M="!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DUE9&1E;&%N9&4@<VMI8VMA9&5S
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S`*;7-G:60@(DUE<W-A
M9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X('9I97<N(@IM<V=S='(@(DUE
M9&1E;&%N9&4@<&5R('-I9&$@:2!M87!P=GEN+B(*"B,Z(&UA:6QB;W@N<&AP
M.C,Q,0IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B365D9&5L86YD92!T
M:6QL(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C(Y"FUS9VED(")-;V1I
M9GDB"FUS9W-T<B`BQ&YD<F$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E>'!A
M;F0N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@
M861D<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R(")-97(@
MY&X@96X@861R97-S(&AI='1A="!F]G(@9N1L=&5T("<E<R<N(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E(@IM<V=S='(@
M(D9L>71T82(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC
M.C,Q-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(D9L>71T82!N97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`V"FUS9VED(")-;W9E('-P86T@
M;65S<V%G97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S
M('1O($E.0D]8(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHU,`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B1FQY='1A
M('1I;&P@;6%P<"(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,Q-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")&;'ET=&$@=7!P(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%L=&5R;F%T:79E+G!H<#HQ,C<*;7-G:60@
M(DUU;'1I<&%R="]A;'1E<FYA=&EV92(*;7-G<W1R(")-=6QT:7!A<G0O86QT
M97)N871I=F4B"@HC.B!T:')E860N<&AP.C<V('1H<F5A9"YP:'`Z,34W"FUS
M9VED(")-=6QT:7!L92!-97-S86=E(%9I97<B"FUS9W-T<B`B1FQE<FUE9&1E
M;&%N9&5V:7-N:6YG(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R
M8VAS96QE8W0N:6YC.C@*;7-G:60@(DY/3D4B"FUS9W-T<B`B24Y'150B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@@=&5M<&QA=&5S
M+W-M:6UE+W-M:6UE+FEN8SHR"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M"FUS9VED(").3U1%(@IM<V=S='(@(DYO=&5R:6YG(@H*(SH@=&5M<&QA=&5S
M+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S@@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8X,PIM<V=I9"`B3F%M92(*;7-G<W1R(").86UN(@H*(SH@<&=P
M+G!H<#HQ,#8*;7-G:60@(DYA;64@86YD+V]R(&5M86EL(&-A;FYO="!B92!E
M;7!T>2(*;7-G<W1R(").86UN(&]C:"]E;&QE<B!E+7!O<W0@9N5R(&EN=&4@
M=F%R82!T;VTB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S<Q"FUS
M9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`B0F5H]G9E<B#E=&?D<F0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<P(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-C<*;7-G:60@(DYE=F5R(@IM<V=S='(@(D%L9')I9R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-C`*;7-G:60@(DYE=F5R('-A=F4@871T
M86-H;65N=',B"FUS9W-T<B`B4W!A<F$@86QD<FEG(&)I;&%G;W(B"@HC.B!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T<B`B
M3GDB"@HC.B!L:6(O24U0+G!H<#HU.34*;7-G:60@(DYE=R!&;VQD97(B"FUS
M9W-T<B`B3GD@;6%P<"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.`IM
M<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`B3GEA(&UE9&1E;&%N9&5N(@H*(SH@
M;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(Q(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HR,@HC.B!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HT-@IM<V=I9"`B
M3F5W($UE<W-A9V4B"FUS9W-T<B`B3GET="!M961D96QA;F1E(@H*(SH@;6%I
M;&)O>"YP:'`Z-S<Q(&QI8B]-24U%+TAE861E<G,N<&AP.C$X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R(").>71T
M(&UE9&1E;&%N9&4@=&EL;"`E<R(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R(").>6$@;65D
M9&5L86YD96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,3,S"FUS9VED(").97AT(@IM<V=S='(@(D[D<W1A(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHS,PIM<V=I9"`B3F5X="!-
M97-S86=E(@IM<V=S='(@(D[D<W1A(&UE9&1E;&%N9&4B"@HC.B!M86EL8F]X
M+G!H<#HS-#(*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(").Y'-T82!S:61A
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30P('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4U,PHC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.38V"FUS9VED(").;R(*;7-G<W1R(").96HB"@HC.B!S;6EM
M92YP:'`Z,C(R"FUS9VED(").;R!#97)T:69I8V%T92!F;W5N9"(*;7-G<W1R
M("));F=E="!C97)T:69I:V%T(&AI='1A="(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-0IM<V=I9"`B3F\@16YC<GEP=&EO;B(*
M;7-G<W1R("));F=E;B!K<GEP=&5R:6YG(@H*(SH@=&5M<&QA=&5S+W!G<"]P
M9W`N:6YC.C$Y"FUS9VED(").;R!+97ES(&EN($ME>7)I;F<B"FUS9W-T<B`B
M26YG82!N>6-K;&%R(&D@;GEC:V5L<FEN9V5N(@H*(SH@;6%I;&)O>"YP:'`Z
M,S8Q"FUS9VED(").;R!-97-S86=E<R(*;7-G<W1R("));F=A(&UE9&1E;&%N
M9&5N(@H*(SH@<&=P+G!H<#HQ,S,*;7-G:60@(DYO(%!'4"!P=6)L:6,@:V5Y
M(&EM<&]R=&5D+B(*;7-G<W1R("));F=E;B!P=6)L:6L@4$=0+6YY8VME;"!I
M;7!O<G1E<F%D97,N(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHX
M-`IM<V=I9"`B3F\@4&5R<V]N86P@0V5R=&EF:6-A=&4@4')E<V5N="(*;7-G
M<W1R("));F=E="!P97)S;VYL:6=T(&-E<G1I9FEK870@=&EL;&?D;F=L:6=T
M(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,Q.0IM<V=I9"`B3F\@4')E=FEE=R!4
M97AT(@IM<V=S='(@(DEN9V5N(&;V<FAA;F1S=FES;FEN9R(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G:60@(DYO(%!U8FQI8R!+97ES
M($9O=6YD(@IM<V=S='(@(DEN9V$@<'5B;&EK82!N>6-K;&%R(&AI='1A9&5S
M(@H*(SH@<VUI;64N<&AP.C$T-PIM<V=I9"`B3F\@4R]-24U%('!U8FQI8R!K
M97D@:6UP;W)T960N(@IM<V=S='(@(DEN9V5N('!U8FQI:R!3+TU)344M;GEC
M:V5L(&EM<&]R=&5R861E<RXB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z.3(*;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD+B(*;7-G<W1R(")"
M:6QA9V]R('-A:VYA<RXB"@HC.B!L:6(O0W)Y<'0O4TU)344N<&AP.C$T,`IM
M<V=I9"`B3F\@96UA:6P@:6YF;W)M871I;VX@;&]C871E9"!I;B!T:&4@<'5B
M;&EC(&ME>2XB"FUS9W-T<B`B26YG96X@92UP;W-T:6YF;W)M871I;VX@Y71E
M<F9A;FYS(&D@9&5N('!U;&EK82!N>6-K96QN+B(*"B,Z(&%C;"YP:'`Z-S$@
M86-L+G!H<#HY-PIM<V=I9"`B3F\@9F]L9&5R('-E;&5C=&5D+B(*;7-G<W1R
M("));F=E;B!M87!P('9A;&0N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$T.0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I;F<@8VAE8VME9"!F;W(@
M;F5W(&UA:6PN(@IM<V=S='(@(DEN9V$@;6%P<&%R(&MO;G1R;VQL97)A<R!F
M]G(@;GD@92UP;W-T+B(*"B,Z(&9O;&1E<G,N<&AP.C(P,2!L:6(O1F]L9&5R
M+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z-34P"FUS9VED(").;R!F;VQD97)S
M('=E<F4@<W!E8VEF:65D(@IM<V=S='(@(DEN9V$@;6%P<&%R(.1R('9A;&1A
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$U-0IM<V=I9"`B3F\@9F]L
M9&5R<R!W:71H(&YE=R!M97-S86=E<R(*;7-G<W1R("));F=A(&UA<'!A<B!M
M960@;GEA(&UE9&1E;&%N9&5N(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP
M.C$U,@IM<V=I9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<R(*
M;7-G<W1R("));F=A(&UA<'!A<B!M960@;VSD<W1A(&UE9&1E;&%N9&5N(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C,S-@IM<V=I9"`B3F\@;65S<V%G92!B;V1Y
M('1E>'0B"FUS9W-T<B`B26YG96X@;65D9&5L86YD971E>'0B"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C4V.`IM<V=I9"`B3F\@;65S<V%G92!R971U<FYE
M9"XB"FUS9W-T<B`B26YG970@;65D9&5L86YD92!HY&UT870N(@H*(SH@;&EB
M+TUA:6QB;W@N<&AP.C,V,@IM<V=I9"`B3F\@;65S<V%G97,@;6%T8VAE9"!Y
M;W5R('-E87)C:"XB"FUS9W-T<B`B26YG82!M961D96QA;F1E;B!M;W1S=F%R
M861E(&1I;B!S]FMN:6YG+B(*"B,Z('!G<"YP:'`Z,3@U"FUS9VED(").;R!P
M97)S;VYA;"!01U`@<')I=F%T92!K97D@:6UP;W)T960N(@IM<V=S='(@(DEN
M9V5N('!E<G-O;FQI9R!P<FEV870@4$=0+6YY8VME;"!I;7!O<G1E<F%D97,N
M(@H*(SH@<&=P+G!H<#HQ-C$*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P=6)L
M:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R("));F=E;B!P97)S;VYL:6<@<'5B
M;&EK(%!'4"UN>6-K96P@:6UP;W)T97)A9&5S+B(*"B,Z('-M:6UE+G!H<#HQ
M.3<*;7-G:60@(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP
M;W)T960N(@IM<V=S='(@(DEN9V5N="!P97)S;VYL:6<@4R]-24U%+6-E<G1I
M9FEK870@:6UP;W)T97)A9&5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,C0V(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y.0IM<V=I9"`B
M(@HB3F\@<&5R<V]N86P@<')I=F%T92!K97D@97AI<W1S('-O('1H92!M97-S
M86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N(@IM<V=S='(@(DUE9&1E
M;&%N9&5T(&MA;B!I;G1E(&1E:W)Y<'1E<F%S+"!D970@9FEN;G,@:6YG96X@
M<')I=F%T(&YY8VME;"XB"@HC.B!S<&5L;&EN9RYP:'`Z,C(P"FUS9VED(").
M;R!S<&5L;&-H96-K:6YG('!R;V=R86T@8V]N9FEG=7)E9"XB"FUS9W-T<B`B
M2&ET=&%D92!I;F=E="!P<F]G<F%M(&;V<B!RY'1T<W1A=FYI;F=S:V]N=')O
M;&PN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X"FUS
M9VED(").;R!S<&5L;&EN9R!E<G)O<G,B"FUS9W-T<B`B26YG82!S=&%V9F5L
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P,`IM<V=I
M9"`B3F\@<W5G9V5S=&EO;G,B"FUS9W-T<B`B26YG82!F]G)S;&%G(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HU-C`*;7-G:60@(DYO('-U<'!O<G1E9"!)
M34%0(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@86-L+G!H<#HV-R!A8VPN<&AP.CDS"FUS9VED(").;R!U
M<V5R('-P96-I9FEE9"XB"FUS9W-T<B`B26YG96X@86YVY&YD87)E(&%N9VEV
M96XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P-`IM<V=I9"`B
M3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(DEC:V4M9&5L=&%G87)E(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ,2!T96UP;&%T97,O<')E
M9G,O9F]L9&5R<V5L96-T+FEN8SHR-`HC.B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C0P('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,U"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR
M-"!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HV-C$*;7-G:60@(DYO;F4B"FUS9W-T<B`B
M26YG96XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.34*
M;7-G:60@(DYO<FUA;"(*;7-G<W1R(").;W)M86PB"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S='(@(D5J(')A9&5R
M860B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$R('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C,*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,@IM<V=I9"`B3F]T($1R869T(@IM
M<V=S='(@(D5J('5T:V%S="(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC
M.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S0*;7-G:60@
M(DYO="!);7!O<G1A;G0B"FUS9W-T<B`B16H@=FEK=&EG="(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*;7-G:60@(DYO="!097)S;VYA
M;"(*;7-G<W1R(")%:B!P97)S;VYL:6=T(@H*(SH@;&EB+T-R>7!T+U!'4"YP
M:'`Z,3,Y(&QI8B]#<GEP="]334E-12YP:'`Z,3,T(&QI8B]#<GEP="]334E-
M12YP:'`Z,30Y"FUS9VED(").;W0@82!V86QI9"!P=6)L:6,@:V5Y+B(*;7-G
M<W1R(")&96QA:W1I9R!P=6)L:6L@4$=0+6YY8VME;"XB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C8W"FUS9VED(").;W0@9&5L971E9"!M97-S
M86=E<R(*;7-G<W1R(")%:B!R861E<F%D92!M961D96QA;F1E;B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A
M;G0@;65S<V%G97,B"FUS9W-T<B`B16H@=FEK=&EG82!M961D96QA;F1E;B(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z
M-S$*;7-G:60@(DYO=&4@=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM92(*
M;7-G<W1R(")$970@:V%N('1A(&5N('-T=6YD+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV,#0*;7-G:60@(DYO=&AI;F<B"FUS9W-T<B`B26YG96YT
M:6YG(@H*(SH@871T86-H;65N="YP:'`Z.#D*;7-G:60@(DYO=&EF:6-A=&EO
M;CH@3&EN:V5D(&%T=&%C:&UE;G0@9&]W;FQO861E9"(*;7-G<W1R(")/8G,Z
M($SD;FMA9&4@8FEL86=O<B!N961L861D861E(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W-PIM<V=I9"`B3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P
M(&]L9"!L:6YK960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2XB
M"FUS9W-T<B`B06YT86P@;>5N861E<B!S;VT@;.1N:V%D92!B:6QA9V]R('-K
M86QL('-P87)A<RP@;VT@;>5N861S=FES(')A9&5R:6YG+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-3D*;7-G:60@(DYU;6)E<B!O9B!O;&0@<V5N
M="UM86EL(&9O;&1E<G,@=&\@:V5E<"!I9B!D96QE=&EN9R!M;VYT:&QY+B(*
M;7-G<W1R("(B"B)!;G1A;"!M87!P87(@9O9R('-K:6-K861E(&UE9&1E;&%N
M9&5N('-O;2!S:V%L;"!S<&%R87,@=FED(&WE;F%T;&EG(')A9&5R:6YG+B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T"FUS9VED
M(")/2R(*;7-G<W1R(")/2R(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S
M+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT.0HC.B!T
M96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/4B(*;7-G
M<W1R(")E;&QE<B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,34*
M;7-G:60@(D]L9"!M97-S86=E<R(*;7-G<W1R(")'86UL82!M961D96QA;F1E
M;B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M
M;VYT:&QY+G!H<#HU,@IM<V=I9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E
M:6YG('!U<F=E9"XB"FUS9W-T<B`B36%P<"!F]G(@<VMI8VMA9&4@;65D9&5L
M86YD96X@<F5N<V%S+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR.`IM
M<V=I9"`B3VYL>2!D:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E860@;65S<V%G
M97,@:6X@=&AE;3\B"FUS9W-T<B`B5FES82!B87)A(&UA<'!A<B!M960@;VSD
M<W1A(&UE9&1E;&%N9&5N/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z.#$@=&5M<&QA=&5S+V9O;&1E<G,O:F%V87-C<FEP="YI;F,Z
M-S$*;7-G:60@(D]N;'D@;VYE(&9O;&1E<B!S:&]U;&0@8F4@<V5L96-T960@
M9F]R('1H:7,@86-T:6]N+B(*;7-G<W1R(")"87)A(&5N(&UA<'`@:V%N('9A
M<F$@=F%L9"!F]G(@9&5N(&CD<B!H86YD;&EN9V5N+B(*"B,Z('1E;7!L871E
M<R]M96YU+VUE;G4N:6YC.C$P,"!T96UP;&%T97,O;65N=2]M96YU+FEN8SHQ
M,#$*;7-G:60@(D]P95]N($9O;&1E<B(*;7-G<W1R("+6<'!?;F$@;6%P<"(*
M"B,Z('1E;7!L871E<R]M96YU+FEN8SHQ,"!T96UP;&%T97,O;65N=2YI;F,Z
M,S`*;7-G:60@(D]P96X@1F]?;&1E<B(*;7-G<W1R("+6<'!N82!M87!P(@H*
M(SH@=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z.3$@=&5M<&QA=&5S+VUE;G4O
M;65N=2YI;F,Z.30*;7-G:60@(D]P96X@1F]L9&5R(@IM<V=S='(@(M9P<&YA
M(&UA<'`B"@HC.B!F;VQD97)S+G!H<#HT,#@*;7-G:60@(D]P96YE9"!&;VQD
M97(B"FUS9W-T<B`BUG!P;F%D92!M87!P(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<P,`IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS
M9W-T<B`B26-K92!O8FQI9V%T;W)I<VMA(&1E;'1A9V%R92(*"B,Z(&9E=&-H
M;6%I;"YP:'`Z-#,@=&5M<&QA=&5S+V9E=&-H;6%I;"]T;W`N:6YC.C,*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C8*;7-G:60@(D]T
M:&5R($UA:6P@06-C;W5N=',B"FUS9W-T<B`B06YD<F$@92UP;W-T:V]N=&]N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,"!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@(D]T:&5R
M($]P=&EO;G,B"FUS9W-T<B`B06YD<F$@:6YS=.1L;&YI;F=A<B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`P"FUS9VED(")/=71B;W5N9"!3
M97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E
M+FEN8SHQ-B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C0*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,C`S(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(X.0IM<V=I9"`B4$=0(@IM<V=S='(@(E!'4"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-PIM<V=I9"`B4$=0($5N8W)Y<'0@
M365S<V%G92(*;7-G<W1R(")01U`M:W)Y<'1E<F$B"@HC.B!C;VUP;W-E+G!H
M<#HS,S4*;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S='(@(E!'4"UF96PZ("(*
M"B,Z(&-O;7!O<V4N<&AP.C,Q-`IM<V=I9"`B4$=0($5R<F]R.B!.965D('!A
M<W-P:')A<V4@9F]R('!E<G-O;F%L('!R:79A=&4@:V5Y+B(*;7-G<W1R(")0
M1U`M9F5L.B!"96CV=F5R(&SV<V5N;W)D(&;V<B!P97)S;VYL:6<@<')I=F%T
M(&YY8VME;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED
M(")01U`@3W!T:6]N<R(*;7-G<W1R(")01U`M:6YS=.1L;&YI;F=A<B(*"B,Z
M('!G<"YP:'`Z,S`*;7-G:60@(E!'4"!087-S<&AR87-E($EN<'5T(@IM<V=S
M='(@(DEN;6%T;FEN9R!A=B!01U`M;/9S96YO<F0B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA;"!+97EP86ER('-U
M<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(E!'4"!P97)S;VYL:6=T(&YY8VME;'!A<B!K<N1V97(@<^1K97(@9O9R
M8FEN9&5L<V4@*$A45%!3*2XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H
M<#HQ-S(*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(%1E>'0B"FUS9W-T<B`B4'5B
M;&EK(%!'4"UN>6-K96PB"@HC.B!P9W`N<&AP.C$T-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<R`H)7,I7"(@=V%S('-U
M8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`B4'5B;&EK(%!'4"UN>6-K96P@
M9O9R("<E<R`H)7,I)R!L861E<R!T:6QL+B(*"B,Z('!G<"YP:'`Z,C0Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@
M=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R(")0=6)L:6L@4$=0
M+6YY8VME;"!F]G(@)R5S)R!R861E<F%D97,N(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T
M<B`B4'5B;&EK(&YY8VME;')I;F<@9O9R(%!'4"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.`IM<V=I9"`B4$=0(%-I9VX@365S
M<V%G92(*;7-G<W1R(")3:6=N97)A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M96YC<GEP=%]L:7-T+FEN8SHY"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE
M<W-A9V4B"FUS9W-T<B`B4VEG;F5R82]+<GEP=&5R82(*"B,Z('!G<"YP:'`Z
M,3DX"FUS9VED(")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D
M+B(*;7-G<W1R(")0<FEV870@4$=0+6YY8VME;"!L861E<R!T:6QL+B(*"B,Z
M('!G<"YP:'`Z,3<S"FUS9VED(")01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L
M;'D@861D960N(@IM<V=S='(@(E!U8FQI:R!01U`M;GEC:V5L(&QA9&5S('1I
M;&PN(@H*(SH@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C0*;7-G:60@
M(E!'4"!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@<WES=&5M+B(*;7-G
M<W1R(")01U`M<W5P<&]R="#D<B!A=G-TY&YG="!I('-Y<W1E;65T+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-PIM<V=I9"`B(@HB4$=0('-U
M<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@
M<VEG;F%T=7)E(&ES('5N86)L92!T;R!B92`B"B)V97)I9FEE9"XB"FUS9W-T
M<B`B(@HB1&5N(&1I9VET86QA('-I9VYA='5R96X@:V%N(&EN=&4@=F5R:69I
M97)A<R!P9V$@871T(%!'4"US=7!P;W)T(&EN=&4@Y'(@(@HB86MT:79E<F%T
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y-`IM<V=I9"`B(@HB
M4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E;G1L>2!A8W1I=F4@<V\@=&AE(&UE
M<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB
M365D9&5L86YD970@:V%N(&EN=&4@9&5K<GEP=&5R87,@<&=A(&%T="!01U`M
M<W5P<&]R="!I;G1E(.1R(&%K=&EV97)A="XB"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,@IM<V=I9"`B(@HB4$=0('-U<'!O<G0@<F5Q=6ER97,@<&]P
M=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@>6]U<B!B<F]W<V5R(&ES(&-U
M<G)E;G1L>2`B"B)S970@=&\@9&ES86)L92!P;W!U<"!W:6YD;W=S+"!Y;W4@
M;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L<V4@=&AE(%!'4"`B"B)F
M96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB
M4$=0+7-T]F1E="!K<N1V97(@871T('!O<'5P+6;V;G-T97(@9G5N9V5R87(N
M($]M(&1I;B!W96)B;.1S87)E(.1R(&EN<W3D;&QD("(*(F%T="!B;&]C:V5R
M82!P;W!U<"UF]FYS=&5R(&WE<W1E(&1U(.1N9')A(&1E;B!I;G-TY&QL;FEN
M9V5N(&;V<B!A='0@4$=0+2(*(G-T]F1E="!S:V$@9G5N9V5R82(*"B,Z(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`U"FUS9VED(")03U`S(@IM<V=S='(@
M(E!/4#,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B
M4$]0,R`H075T;R!$971E8W0@4')O=&]C;VQS*2(*;7-G<W1R(")03U`S("AU
M<'!TY&-K('!R;W1O:V]L;"!A=71O;6%T:7-K="DB"@HC.B!L:6(O1F5T8VAM
M86EL+VEM87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R
M(")03U`S(/9V97(@4U-,(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ
M,C,*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC
M871E*2(*;7-G<W1R(")03U`S(/9V97(@4U-,("AS:N1L=G-I9VYE<F%T(&-E
M<G1I9FEK870I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C@*
M;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E;&8M<VEG;F5D*2(*;7-G<W1R(")0
M3U`S(/9V97(@4U-,("AS:N1L=G-I9VYE<F%D*2(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,3$Q"FUS9VED(")03U`S+"!N;R!43%,B"FUS9W-T<B`B
M4$]0,RP@:6YG96X@5$Q3(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R
M+FEN8SHR,@HC+"!P:'`M9F]R;6%T"FUS9VED(")086=E("5D(&]F("5D(@IM
M<V=S='(@(E-I9&$@)60@878@)60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#DR"FUS9VED(")086=E('=I=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S
M86=E(@IM<V=S='(@(E-I9&%N(&UE9"!F]G)S=&$@;VSD<W1A(&UE9&1E;&%N
M9&5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y,PIM<V=I9"`B4&%G
M92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(E-I9&%N
M(&UE9"!D970@<VES=&$@;VSD<W1A(&UE9&1E;&%N9&5T(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS
M9W-T<B`B1&5L*&%R*2(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C,*
M;7-G:60@(E!A<W-P:')A<V4B"FUS9W-T<B`B3/9S96YO<F0B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!9V%I
M;BDB"FUS9W-T<B`B3/9S96YO<F0@*&EG96XI(@H*(SH@<VUI;64N<&AP.C(S
M,2!P9W`N<&AP.C,P-@IM<V=I9"`B4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@
M=6YL;V%D960N(@IM<V=S='(@(DSV<V5N;W)D(&9R:6=J;W)T+B(*"B,Z('1E
M;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ."!T96UP;&%T97,O<&=P
M+W!A<W-P:')A<V4N:6YC.C(Y"FUS9VED(")087-S<&AR87-E.B(*;7-G<W1R
M("),]G-E;F]R9#HB"@HC.B!P9W`N<&AP.C$P.`IM<V=I9"`B4&%S<W!H<F%S
M97,@8V%N;F]T(&)E(&5M<'1Y(@IM<V=S='(@(DSV<V5N;W)D(&MA;B!I;G1E
M('9A<F$@=&]M;6$B"@HC.B!P9W`N<&AP.C$Q,`IM<V=I9"`B4&%S<W!H<F%S
M97,@9&\@;F]T(&UA=&-H(@IM<V=S='(@(DSV<V5N;W)D('-TY&UM97(@:6YT
M92#V=F5R<F5N<R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S$*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3$*;7-G:60@(E!A<W-W;W)D(@IM
M<V=S='(@(DSV<V5N;W)D(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C0X"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_(@IM<V=S='(@(E5T9O9R('5N9&5R:.5L;'-A:W1I=FET
M971E<B!V:60@:6YL;V=G;FEN9S\B"@HC.B!A8VPN<&AP.C<U(&%C;"YP:'`Z
M,3`Q"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R(&-A;FYO="!B
M92!C:&%N9V5D+B(*;7-G<W1R(")+86X@:6YT92#D;F1R82!RY'1T:6=H971E
M<B!F]G(@9&5N;F$@86YVY&YD87)E+B(*"B,Z(&UE<W-A9V4N<&AP.C0Y-"!M
M86EL8F]X+G!H<#HV.3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR
M-`HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$P"FUS9VED(")0
M97)S;VYA;"(*;7-G<W1R(")097)S;VYL:6<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S
M='(@(E!E<G-O;FQI9R!I;F9O<FUA=&EO;B(*"B,Z('!G<"YP:'`Z,3$V"FUS
M9VED(")097)S;VYA;"!01U`@:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R(")097)S;VYL:6=T(&YY8VME;'!A<B!F]G(@4$=0('-K
M87!A9&5S+B(*"B,Z('!G<"YP:'`Z,3(S"FUS9VED(")097)S;VYA;"!01U`@
M:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&5R<V]N;&EG
M="!N>6-K96QP87(@9O9R(%!'4"!R861E<F%D97,N(@H*(SH@<VUI;64N<&AP
M.C(P,PIM<V=I9"`B4&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!.3U0@
M:6UP;W)T960Z("(*;7-G<W1R("));F=E="!P97)S;VYL:6=T(%,O34E-12UC
M97)T:69I:V%T(&EM<&]R=&5R861E<RXB"@HC.B!S;6EM92YP:'`Z,3(X"FUS
M9VED(")097)S;VYA;"!3+TU)344@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`B4&5R<V]N;&EG="!N>6-K96QP87(@9O9R(%,O34E-12!R
M861E<F%D97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I
M9"`B4&QA8V4@>6]U<B!S:6=N871U<F4@8F5F;W)E(')E<&QI97,@86YD(&9O
M<G=A<F1S/R(*;7-G<W1R("));F9O9V$@<VEG;F%T=7(@9O9R92!S=F%R(&]C
M:"!V:61A<F)E9F]R9')I;F<_(@H*(SH@8V]M<&]S92YP:'`Z,C4X"FUS9VED
M(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S='(@(DUE9&1E
M;&%N9&4@:2!P;&%I;G1E>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S@X"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@5&AI<R!R
M97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E9"`B"B)S
M;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A;F0@36%C
M+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q=6ER92!A('!L=6=I
M;BXB"FUS9W-T<B`B(@HB4W!E;&$@;&IU9"!NY'(@;GD@92UP;W-T('1A<R!E
M;6]T/R!$971T82!K<N1V97(@871T(&1I;B!W96)B;.1S87)E(&AA<B!S=/9D
M("(*(F;V<B!I;G!A8VMA9&4@;&IU9&9I;&5R+B!.Y'-T86X@86QL82!W96)B
M;.1S87)E(&;V<B!-86,@;V-H(%=I;F1O=W,@:&%R('-T]F0@(@HB9O9R(&1E
M='1A+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N:6YC.C4U
M('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C$Y,@IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z(@IM<V=S
M='(@(E-K<FEV(&5T="!N86UN(&;V<B!D96X@;GEA(&UA<'!E;CHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-"!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]J879A<V-R:7!T+FEN8SHY-"!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R
M:7!T+FEN8SHY-@IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H
M92!N97<@9F]L9&5R.B(*;7-G<W1R(")!;F=E(&YA;6X@<.4@;GD@;6%P<#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$S.0HC.B!T
M96UP;&%T97,O9F]L9&5R<R]V9F]L9&5R7VIA=F%S8W)I<'0N:6YC.C$P,0HC
M.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R:7!T+FEN8SHQ,CD*;7-G:60@
M(E!L96%S92!E;G1E<B!T:&4@;F5W(&YA;64Z(@IM<V=S='(@(E-K<FEV(&EN
M(&1E="!N>6$@;F%M;F5T.B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S
M92YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(&5N=&5R
M('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2X@66]U
M('=I;&P@;VYL>2!N965D('1O("(*(F5N=&5R('1H:7,@<&%S<W!H<F%S92!O
M;F-E('!E<B`E<R!S97-S:6]N+B(*;7-G<W1R("(B"B)687(@9V]D(&%N9V4@
M;/9S96YO<F0@9O9R(&1I;B!P<FEV871A(%!'4"UN>6-K96PN($SV<V5N;W)D
M970@8F5H]G9E<B!B87)A("(*(F%N9V5S(&5N(&?E;F<@<&5R("5S+7-E<W-I
M;VXN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H
M<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N
M;'D@;F5E9"`B"B)T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@
M)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HB5F%R(&=O9"!A;F=E(&SV<V5N;W)D
M(&;V<B!D:6X@<')I=F%T82!3+TU)344M;GEC:V5L+B!,]G-E;F]R9&5T(&)E
M:/9V97(@8F%R82`B"B)A;F=E<R!E;B!GY6YG('!E<B`E<RUS97-S:6]N+B(*
M"B,Z(')E8V]M<&]S92YP:'`Z.38*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@
M86=A:6X@=&\@<F5S=6UE(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO
M=2!A<F4@3D]4('5S:6YG("(*(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S
M:6YG(&UE<W-A9V5S(&EN('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@
M=&\@(@HB;&]G(&EN(&%G86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L
M;"X@5&AI<R!I<R!T;R!K965P(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN
M9R!Y;W5R('-E<W-I;VX@240N(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N
M=F5N:65N8V4N(@IM<V=S='(@(B(*(DQO9V=A(&EN(&EG96X@9O9R(&%T="#E
M=&5R=7!P=&$@87)B971E="!M960@871T('-K<FEV82!PY2!D:71T7&XB"B)M
M961D96QA;F1E+B!/;2!D=2!)3E1%(&%C8V5P=&5R87(@:V%K;W(@3T-(('-K
M<FEV97(@8G)E=B!I7&XB"B)P;W!U<"UF]FYS=&5R(&WE<W1E(&1U(&]C:W/E
M(&QO9V=A(&EN(&D@:'5V=61F]FYS=')E="!I9V5N+B!$971T82#D<EQN(@HB
M96X@<^1K97)H971SY71GY')D(&;V<B!A='0@:&EN9')A(&%T="!D:6X@<V5S
M<VEO;B#V=F5R=&%S+B!6:2!B97(@;VU<;B(*(G5R<^1K="!F]G(@979E;G1U
M96QL82!O;.1G96YH971E<B!D971T82!O<G-A:V%R+B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S$*;7-G:60@(E!L96%S92!P<F]V:61E('EO
M=7(@<&%S<W=O<F0N(@IM<V=S='(@(D%N9V4@9&ET="!L]G-E;F]R9"XB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8W"FUS9VED(")0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE+B(*;7-G<W1R(")!;F=E(&1I='0@86YV
MY&YD87)N86UN+B(*"B,Z(&-O;7!O<V4N<&AP.C$P-B!L:6(O24U0+G!H<#HT
M-C,*;7-G:60@(E!L96%S92!R97-O;'9E(&%M8FEG=6]U<R!O<B!I;G9A;&ED
M(&%D9')E<W-E<RXB"FUS9W-T<B`B4N1T=&$@9F5L86MT:6=A(&5L;&5R('1V
M971Y9&EG82!A9')E<W-E<BXB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]V9F]L
M9&5R7VIA=F%S8W)I<'0N:6YC.C0Y"B,Z('1E;7!L871E<R]F;VQD97)S+VIA
M=F%S8W)I<'0N:6YC.C4S"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R
M(&)E9F]R92!Y;W4@<&5R9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`B5N1L
M:B!E;B!M87!P(&EN;F%N(&1U('5T9O9R(&AA;F1L:6YG87(N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHV,PIM<V=I9"`B4&QE87-E
M('-E;&5C="!A(&9O;&1E<B!B969O<F4@>6]U('!E<F9O<FT@=&AI<R!A8W1I
M;VXN(@IM<V=S='(@(E;D;&H@96X@;6%P<"!I;FYA;B!D=2!U=&;V<B!D96YN
M82!A:W1I=FET970N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]J879A<V-R:7!T
M+FEN8SHT,0IM<V=I9"`B4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L
M9&5R('1O('-E87)C:"XB"FUS9W-T<B`B5N1L:B#E=&UI;G-T;VYE(&5N(&UA
M<'`@871T('/V:V$@:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$R('1E;7!L871E<R]F;VQD97)S+VIA=F%S8W)I<'0N:6YC.C0*
M;7-G:60@(E!L96%S92!S96QE8W0@;VYL>2!O;F4@9F]L9&5R(&9O<B!T:&ES
M(&]P97)A=&EO;BXB"FUS9W-T<B`B5N1L:B!B87)A(&5N(&UA<'`@9O9R(&1E
M;B!HY'(@;W!E<F%T:6]N96XN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C<S"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@
M=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(E;D;&H@96QL97(@Y&YD
M<F$@:2!R=71A;B!T:6QL(&CV9V5R.B(*"B,Z(&-O;F9I9R]M;W1D+G!H<"YD
M:7-T.C0Q"FUS9VED(")0;W=E<F5D(&)Y($AO<F1E(@IM<V=S='(@(D1R:79S
M(&UE9"!(;W)D92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,30*;7-G
M:60@(E!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G
M*3\B"FUS9W-T<B`B1O9R96?E('-I9VYA='5R(&UE9"!S=')E8VL@*"<M+2<I
M/R(*"B,Z('-M:6UE+G!H<#HR,S<@<&=P+G!H<#HR-3,@9FEL=&5R<')E9G,N
M<&AP.C,Y"FUS9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E
M9"XB"FUS9W-T<B`B26YS=.1L;&YI;F=A<B!U<'!D871E<F%D92XB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4')E
M=FEE=R(*;7-G<W1R(")&]G)H86YD<W9I<VYI;F<B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U
M<R!-97-S86=E(@IM<V=S='(@(D;V<F5GY65N9&4@;65D9&5L86YD92(*"B,Z
M(&UA:6QB;W@N<&AP.C,S,PIM<V=I9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R
M(")&]G)E9^5E;F1E('-I9&$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?86-T:6]N<RYI;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@(E-K<FEV
M('5T(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*;7-G
M:60@(E!R:6]R:71Y(@IM<V=S='(@(E!R:6]R:71E="(*"B,Z('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I9"`B4')I=F%T92!+97D@
M4&%S<W=O<F0B"FUS9W-T<B`B3/9S96YO<F0@9O9R('!R:79A="!N>6-K96PB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34Y"FUS9VED(")0<F]M<'0@
M979E<GD@=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@
M3D\B"FUS9W-T<B`B0F5K<N1F=&$@=F%R:F4@9^5N9R!E;B!B:6QA9V$@<VMI
M8VMA<RP@:&$@3D5*('-O;2!S=&%N9&%R9'-V87(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-34X"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A
M='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453(@IM<V=S='(@(D)E
M:W+D9G1A('9A<FIE(&?E;F<@96X@8FEL86=A('-K:6-K87,L(&AA($I!('-O
M;2!S=&%N9&%R9'-V87(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G
M92YI;F,Z,3`*;7-G:60@(E!R;W1O8V]L.B(*;7-G<W1R(")0<F]T;VMO;&PZ
M(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#,P"FUS9VED(")0=6)L:6,@4$=0
M(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R
M(")3=7!P;W)T(&;V<B!01U`M;GEC:V5L<V5R=F5R(.1R(&EN=&4@86MT:79T
M+B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,V('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,Z-PIM<V=I9"`B4'5R
M7V=E($1E;&5T960B"FUS9W-T<B`B4F5N7W-A(')A9&5R861E(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<U]D96QE=&5D+FEN8SHW"FUS9VED(")0=7)G92!$96QE=&5D
M(@IM<V=S='(@(E)E;G-A(')A9&5R861E(@H*(SH@=&5M<&QA=&5S+V9O;&1E
M<G,O86-T:6]N<RYI;F,Z,C0*;7-G:60@(E!U<F=E($9O;&1E<BAS*2(*;7-G
M<W1R(")4]FT@;6%P<"AA<BDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDV"FUS9VED(")0=7)G92!4<F%S:"!H;W<@;V9T96XZ(@IM<V=S='(@(DAU
M<B!O9G1A(')E;G-A<R!P87!P97)K;W)G96XZ(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0P-0IM<V=I9"`B4'5R9V4@;65S<V%G97,@:6X@5')A<V@@
M9F]L9&5R(&]L9&5R('1H86X@=&AI<R!A;6]U;G0@;V8@9&%Y<RXB"FUS9W-T
M<B`B4F5N<V$@;65D9&5L86YD96X@:2!P87!P97)K;W)G96X@Y&QD<F4@Y&X@
M<^4@:.1R(&WE;F=A(&1A9V%R+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#8*;7-G:60@(E!U<F=E(&]L9"!M97-S86=E<R!I;B!T:&4@5')A<V@@
M9F]L9&5R/R(*;7-G<W1R(")296YS82!G86UL82!M961D96QA;F1E;B!I('!A
M<'!E<FMO<F=E;C\B"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T
M<F%S:"YP:'`Z-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4'5R9VEN9R`E9"!M
M97-S86=E<R!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B4F5N<V%R("5D
M(&UE9&1E;&%N9&4H;BD@9G+E;B!P87!P97)K;W)G96XN(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8S"FUS9VED(")0=7)G
M:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B4F5N
M<V%R(#$@;65D9&5L86YD92!F<N5N('!A<'!E<FMO<F=E;BXB"@HC.B!T96UP
M;&%T97,O<75O=&$O<75O=&$N:6YC.C$W"B,L('!H<"UF;W)M870*;7-G:60@
M(E%U;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G
M<W1R(")1=6]T82!S=&%T=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4R9B4E*2(*
M"B,Z('1E;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R!.3R!,24U)5"(*;7-G
M<W1R(")1=6]T82!S=&%T=7,Z("4N,F9-0B`O($E.1T5.($)%1U+$3E-.24Y'
M(@H*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`IM<V=I9"`B475O
M=&$@<W1A='5S.B!.3R!,24U)5"(*;7-G<W1R(")1=6]T82!S=&%T=7,Z($E.
M1T5.($)%1U+$3E-.24Y'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T:6YG("5F.B(*;7-G<W1R(")#
M:71E<F%R("5F.B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC
M.C(Y"FUS9VED(")296)U:6QD($9O;&1E<B!4<F5E(@IM<V=S='(@(L5T97)S
M:V%P82!I;F9O<FUA=&EO;B!F]G(@;6%P<'9Y(@H*(SH@;&EB+U-E87)C:"YP
M:'`Z-C$W"FUS9VED(")296-E:79E9"!/;B(*;7-G<W1R(")!;FMO;2!D96XB
M"@HC.B!L:6(O4V5A<F-H+G!H<#HV,C4*;7-G:60@(E)E8V5I=F5D(%-I;F-E
M(@IM<V=S='(@(D%N:V]M(&5F=&5R(@H*(SH@;&EB+U-E87)C:"YP:'`Z-C(Q
M"FUS9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R(")!;FMO;2!F<F%M('1I
M;&PB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,38*;7-G:60@(E)E9&ER96-?="(*;7-G<W1R(")%9G1E<G/D;E]D(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED
M(")2961I<F5C="(*;7-G<W1R(")%9G1E<G/D;F0B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]R961I<F5C="YI;F,Z,3$P"FUS9VED(")2961I<F5C="!-97-S
M86=E(@IM<V=S='(@(D5F=&5R<^1N9"!M961D96QA;F1E(@H*(SH@8V]M<&]S
M92YP:'`Z.#(W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T
M<B`B169T97)SY&YD(&1E="!HY'(@;65D9&5L86YD970B"@HC.B!C;VUP;W-E
M+G!H<#HX.#`*;7-G:60@(E)E9&ER96-T:6YG(&9A:6QE9"XB"FUS9W-T<B`B
M169T97)SY&YD;FEN9R!M:7-S;'EC:V%D97,N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<W,PIM<V=I9"`B4F5F<F5S:"!&;VQD97(@5FEE=W,Z(@IM
M<V=S='(@(E5P<&1A=&5R82!M87!P=GEE<CHB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]H96%D+FEN8SHY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z
M-`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(DQA9&1A(&]M(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I97<B"FUS
M9W-T<B`B3&%D9&$@;VT@=GDB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3(X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E
M;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(DMO
M;2!I:.5G(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-C@*;7-G:60@(E)E;65M8F5R('1H92!L
M87-T('9I97<B"FUS9W-T<B`B2V]M(&EHY6<@<V5N87-T92!V>6XB"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C<*;7-G:60@(E)E;6]T
M92!-86EL8F]X.B(*;7-G<W1R(")&:N1R<F)R979LY61A.B(*"B,Z('1E;7!L
M871E<R]S96%R8V@O9FEE;&1S+FEN8SHT,0IM<V=I9"`B4F5M;W9E($9I96QD
M($9R;VT@4V5A<F-H(@IM<V=S='(@(E1A(&)O<G0@9N1L="!F<N5N('/V:VYI
M;F=E;B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P
M-0IM<V=I9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R(")482!B;W)T(&OD;&QA
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.`IM<V=I9"`B
M4F5N86UE($9O;&1E<BAS*2(*;7-G<W1R(")">70@;F%M;B!PY2!M87!P*&%R
M*2(*"B,Z('1E;7!L871E<R]F;VQD97)S+W9F;VQD97)?86-T:6]N<RYI;F,Z
M-0IM<V=I9"`B4F5N86UE(%9I<G1U86P@1F]L9&5R(@IM<V=S='(@(E-K87!A
M('9I<G1U96QL(&UA<'`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q
M"FUS9VED(")296YA;64@<V5N="UM86EL(&9O;&1E<B!A="!B96=I;FYI;F<@
M;V8@;6]N=&@_(@IM<V=S='(@(D)Y="!N86UN('#E(&UA<'`@9O9R('-K:6-K
M861E(&UE9&1E;&%N9&5N(&D@8O9R:F%N(&%V(&WE;F%D96X_(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z-#4X"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG
M(%PB)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(DYA;6YB>71E(&9RY6X@)R5S)R!T:6QL("<E
M<R<@;6ES<VQY8VMA9&5S+B!397)V97)N('-V87)A9&4B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G:60@(E)E<&Q?
M>2!T;R!,:7-T(@IM<V=S='(@(E-V85]R82!T:6QL(&QI<W1A(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B4F5P;&%C
M92!W:71H.B(*;7-G<W1R(")%<G/D='0@;65D.B(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")297!L>2(*;7-G
M<W1R(")3=F%R82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,3(@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,`IM<V=I9"`B4F5P;'D@4V5N
M="XB"FUS9W-T<B`B4W9A<B!S:VEC:V%T+B(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL
M(@IM<V=S='(@(E-V87)A(&%L;&$B"@HC.B!C;VUP;W-E+G!H<#HW-S$*;7-G
M:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B4W9A<F$@86QL83HB"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3`*;7-G:60@
M(E)E<&QY('1O($QI<W0B"FUS9W-T<B`B4W9A<F$@=&EL;"!L:7-T82(*"B,Z
M(&-O;7!O<V4N<&AP.C<W,PIM<V=I9"`B4F5P;'D@=&\@3&ES=#HB"FUS9W-T
M<B`B4W9A<F$@=&EL;"!L:7-T83HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,3,*;7-G:60@(E)E<&QY('1O(%]!;&PB"FUS
M9W-T<B`B4W9A<F$@7V%L;&$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3,P(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,SD*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4T.0IM<V=I9"`B4F5P;'D@=VET:"!.;W0@
M4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B4W9A<F$@871T(&)E9^1R86X@
M:6YT92!S=/9D<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S<*
M;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS
M+B(*;7-G<W1R(")3=F%R82!M960@:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P
M=&%G96X@9O9R(&MO;6UA;F1E('1VY2!MY6YA9&5R+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU,S8*;7-G:60@(E)E<&QY('=I=&@@<F5Q=65S
M=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B4W9A<F$@;65D
M(&1E;B!B96?D<F1A(&QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N96XN(@H*
M(SH@;65S<V%G92YP:'`Z,C<U"FUS9VED(")297!L>2U4;R(*;7-G<W1R(")3
M=F%R('1I;&PB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#(P"FUS9VED(")297!L
M>2U4;SH@(@IM<V=S='(@(E-V87(@=&EL;#H@(@H*(SH@8V]M<&]S92YP:'`Z
M-S8Y"FUS9VED(")297!L>3HB"FUS9W-T<B`B4W9A<F$Z(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,X('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C(V"FUS9VED(")297!O<G0@87,@26YN;V-E
M;G0B"FUS9W-T<B`B4F%P<&]R=&5R82!S;VT@;W-K>6QD:6=T(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,U('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(S"FUS9VED(")297!O<G0@87,@4W!A
M;2(*;7-G<W1R(")287!P;W)T97)A('-O;2!S:W+D<'!O<W0B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#8*;7-G:60@(E)E<75E<W0@
M82!?4F5A9"!296-E:7!T(@IM<V=S='(@(D)E9^1R(%]LY'-K=FET=&\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S"FUS9VED(")297%U97-T(')E
M860@<F5C96EP=',_(@IM<V=S='(@(D)E9^1R(&SD<VMV:71T;S\B"@HC.B!M
M86EL8F]X+G!H<#HQ.#D*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F
M;W5N9"XB"FUS9W-T<B`B0F5GY')T(&UE9&1E;&%N9&4@96H@9G5N;F5T+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.3(*;7-G:60@(E)E<75I
M<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(D]B;&EG871O<FES:R!D96QT86=A
M<F4B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$S."!T96UP;&%T
M97,O<V5A<F-H+VAE861E<BYI;F,Z,CD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$V,@IM<V=I9"`B4F5S970B"FUS9W-T<B`BQ71E<G-TY&QL(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$Q-@IM<V=I9"`B4F5S<&]N9&5N
M="!3=&%T=7,@57!D871E9"XB"FUS9W-T<B`B4W9A<G-S=&%T=7,@=7!P9&%T
M97)A9"XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R("+%=&5R=&$B"@HC.B!R96-O
M;7!O<V4N<&AP.CDW"FUS9VED(")297-U;64@>6]U<B!S97-S:6]N(@IM<V=S
M='(@(L5T97)U<'!T82!S97-S:6]N(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C0T"FUS9VED(")2971U<FX@=&\@7")-97-S86=E($-O
M;7!O<VET:6]N7"(B"FUS9W-T<B`BQ71E<G;D;F0@=&EL;"!A='0@<VMR:79A
M(&UE9&1E;&%N9&4B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S
M96QE8W0N:6YC.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV
M.0HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS
M,0IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`BQ71E<G;D
M;G0@=&EL;"!&971C:"!-86EL(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E
M9G,N:6YC.C8P('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z,C(*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#$@=&5M<&QA=&5S+W-M
M:6UE+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$T.2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,34*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$V,R!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3<U
M"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("+%=&5R=N1N9"!T
M:6QL(&EN<W3D;&QN:6YG87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S`W"FUS9VED("(B"B)2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A
M9G1E<B!D96QE=&EN9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\B
M"FUS9W-T<B`B(@HBQ71E<G;D;F1A('1I;&P@;6%P<'9Y;B!E9G1E<B!R861E
M<FEN9RP@9FQY='1N:6YG(&5L;&5R(&MO<&EE<FEN9R!A=B`B"B)M961D96QA
M;F1E/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#,*;7-G:60@
M(E)O;&4B"FUS9W-T<B`B4F]L;"(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S
M-RYP:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W"B,Z(&QI
M8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#(T"FUS9VED(")3+TU)344B"FUS
M9W-T<B`B4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L
M:7-T+FEN8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G92(*;7-G
M<W1R(")3+TU)344@:W)Y<'1E<F$B"@HC.B!C;VUP;W-E+G!H<#HS-S$*;7-G
M:60@(E,O34E-12!%<G)O<CH@(@IM<V=S='(@(E,O34E-12UF96PZ(@H*(SH@
M8V]M<&]S92YP:'`Z,S4P"FUS9VED(")3+TU)344@17)R;W(Z($YE960@<&%S
M<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(E,O
M34E-12UF96PZ($)E:/9V97(@;/9S96YO<F0@9O9R('!E<G-O;FQI9R!P<FEV
M870@;GEC:V5L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3$*;7-G
M:60@(E,O34E-12!/<'1I;VYS(@IM<V=S='(@(E,O34E-12!I;G-TY&QL;FEN
M9V%R(@H*(SH@<VUI;64N<&AP.C0V"FUS9VED(")3+TU)344@4&%S<W!H<F%S
M92!);G!U="(*;7-G<W1R("));FUA=&YI;F<@878@4R]-24U%+6SV<V5N;W)D
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B4R]-
M24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B4R]-24U%('!E<G-O;FQI9W0@
M;GEC:V5L<&%R(&MRY'9E<B!SY&ME<B!F]G)B:6YD96QS92`H2%144%,I+B(*
M"B,Z('-M:6UE+G!H<#HQ,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%
M(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T
M960N(@IM<V=S='(@(E!U8FQI:R!3+TU)344M;GEC:V5L(&;V<B`G)7,G(')A
M9&5R861E<RXB"@HC.B!S;6EM92YP:'`Z,34X"FUS9VED(")3+TU)344@4'5B
M;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E!U8FQI:R!3
M+TU)344M;GEC:V5L(&QA9&5S('1I;&PN(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHQ,`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97ER:6YG(@IM
M<V=S='(@(E!U8FQI:R!N>6-K96QR:6YG(&;V<B!3+TU)344B"@HC.B!S;6EM
M92YP:'`Z,C`W"FUS9VED(")3+TU)344@4'5B;&EC+U!R:79A=&4@2V5Y<&%I
M<B!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(E!U8FQI:W0O<')I=F%T
M(&YY8VME;'!A<B!F]G(@4R]-24U%(&QA9&5S('1I;&PN(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHQ,PIM<V=I9"`B4R]-24U%
M(%-I9VX@365S<V%G92(*;7-G<W1R(")3+TU)344@<VEG;F5R82(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*;7-G:60@(E,O
M34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")3+TU)344@4VEG
M;F5R82]+<GEP=&5R82(*"B,Z('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N
M:6YC.C0*;7-G:60@(E,O34E-12!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H
M:7,@<WES=&5M+B(*;7-G<W1R(")3+TU)344M<W5P<&]R="#D<B!A=G-TY&YG
M="!I('-Y<W1E;65T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z
M,C0Q"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY
M(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*(F1E
M8W)Y<'1E9"XB"FUS9W-T<B`B(@HB365D9&5L86YD970@:V%N(&EN=&4@9&5K
M<GEP=&5R87,@<&=A(&%T="!S=/9D(&;V<B!3+TU)344@:6YT92#D<B!A:W1I
M=F5R870N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-S,*;7-G
M:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!C
M;VYT96YT<R!O9B!T:&ES('-I9VYE9"!M97-S86=E(&-A;FYO="`B"B)B92!D
M:7-P;&%Y960N(@IM<V=S='(@(B(*(DEN;F5HY6QL970@:2!D970@<VEG;F5R
M861E(&UE9&1E;&%N9&5T(&MA;B!I;G1E('9E<FEF:65R87,@<&=A(&%T="!S
M=/9D(&;V<B`B"B)3+TU)344@:6YT92#D<B!A:W1I=F5R870N(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S
M=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H92!D:6=I=&%L('-I9VYA='5R
M92!I<R!U;F%B;&4@=&\@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(D1E
M;B!D:6=I=&%L82!S:6=N871U<F5N(&MA;B!I;G1E('9E<FEF:65R87,@<&=A
M(&%T="!S=/9D(&;V<B!3+TU)344@:6YT92#D<B`B"B)A:W1I=F5R870N(@H*
M(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR"FUS9VED("(B"B)3+TU)
M344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N
M("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY('-E="!T;R!D:7-A
M8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I
M;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O
M<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)3+TU)344M<W3V9&5T(&%N=N1N
M9&5R('!O<'5P+6;V;G-T97(N($]M(&1I;B!W96)B;.1S87)E(.1R(&EN<W3D
M;&QD7&XB"B)A='0@8FQO8VME<F$@<&]P=7`M9O9N<W1E<B!MY7-T92!D=2#D
M;F1R82!D96X@:6YS=.1L;&YI;F=E;B!F]G(@871T7&XB"B)3+TU)344M<W3V
M9&5T('-K82!F=6YG97)A(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR,#0*;7-G:60@(E--5%`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,C4U"FUS9VED(")37W5B:F5C="(*;7-G<W1R
M("+$7W)E;F1E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M,S8S"FUS9VED(")385]V92!A(&-O<'D@:6X@(@IM<V=S='(@(E-P85]R82!K
M;W!I82!I("(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHS,@IM<V=I9"`B4V%?=F4@87,B"FUS9W-T<B`B4W!A7W)A('-O;2(*
M"B,Z('-E87)C:"YP:'`Z,S`X('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHV-PIM<V=I9"`B4V%V92(*;7-G<W1R(")3<&%R82(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4S-@IM<V=I9"`B4V%V92!!='1A
M8VAM96YT<R!W:71H(&UE<W-A9V4@:6X@<V5N="UM86EL(&9O;&1E<C\B"FUS
M9W-T<B`B4W!A<F$@8FEL86=O<B!M960@;65D9&5L86YD970@:2!S96YT+6UA
M:6P@;6%P<&5N/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,`IM<V=I9"`B
M4V%V92!$<F%F="(*;7-G<W1R(")3<&%R82!U=&MA<W0B"@HC.B!S879E:6UA
M9V4N<&AP.C0R"FUS9VED(")3879E($EM86=E(@IM<V=S='(@(E-P87)A(&)I
M;&0B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C(X"FUS9VED(")3879E
M($EM86=E(&EN($=A;&QE<GDB"FUS9W-T<B`B4W!A<F$@8FEL9"!I(&=A;&QE
M<FDB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-3D@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+W-M:6UE+VYO
M=&%C=&EV92YI;F,Z,3,@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$T.`HC.B!T
M96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,3,*;7-G:60@(E-A=F4@3W!T
M:6]N<R(*;7-G<W1R(")3<&%R82!I;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"FUS9VED(")3879E(%-T871I
M;VYE<GDB"FUS9W-T<B`B4W!A<F$@;6%L;"(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0S,`IM<V=I9"`B4V%V92!?1')A9G0B"FUS9W-T<B`B4W!A<F$@7W5T
M:V%S="(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHS,@IM<V=I9"`B4V%V92!A<R(*;7-G<W1R(")3<&%R82!S;VTB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Q"FUS9VED(")3879E(&1R869T<R!A
M<R!U;G-E96X_(@IM<V=S='(@(E-P87)A('5T:V%S="!S;VT@;VSD<W1A/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8Q"FUS9VED(")3879E(')E
M8VEP:65N=',@875T;VUA=&EC86QL>2!T;R!T:&4@9&5F875L="!A9&1R97-S
M(&)O;VL_(@IM<V=S='(@(DSD9V<@=&EL;"!M;W1T86=A<F4@=&EL;"!H=79U
M9&%D<F5S<V)O:V5N(&%U=&]M871I<VMT/R(*"B,Z('1E;7!L871E<R]S96%R
M8V@O;6%I;BYI;F,Z,3(R"FUS9VED(")3879E('-E87)C:"!A<R!A('9I<G1U
M86P@9F]L9&5R/R(*;7-G<W1R(")3<&%R82!S]FMN:6YG('-O;2!E;B!V:7)T
M=65L;"!F;VQD97(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM
M<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(E-P87)A('-K:6-K861E
M(&UE9&1E;&%N9&5N/R(*"B,Z(&-O;7!O<V4N<&AP.C$R-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V:6YG('1H92!D<F%F="!F86EL960N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(DUI<W-L>6-K861E
M<R!A='0@<W!A<F$@=71K87-T+B!397)V97)N('-V87)A9&4Z("5S(@H*(SH@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ.3D@=&5M<&QA=&5S
M+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,0HC.B!L:6(O0FQO8VLO=')E95]F;VQD
M97)S+G!H<#HU-`IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E/V:R(*"B,Z('1E
M;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O
M>"]H96%D97(N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:"`E
M<R(*;7-G<W1R(")3]FL@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(P"FUS9VED(")396%R8V@@3W!T:6]N<R(*;7-G<W1R("));G-TY&QL;FEN
M9V%R(&;V<B!S]FMN:6YG(@H*(SH@<V5A<F-H+G!H<#HR-C,*;7-G:60@(E-E
M87)C:"!297-U;'1S(@IM<V=S='(@(E/V:W)E<W5L=&%T(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-"!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C,Q"FUS9VED(")3965N(@IM<V=S='(@(E-E9&0B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*;7-G:60@(E-E;&5C="(*
M;7-G<W1R(")6Y&QJ(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C<P"FUS9VED(")396QE8W0@06YO=&AE<B!!8V-O=6YT(@IM<V=S='(@
M(E;D;&H@971T(&%N;F%T(&MO;G1O(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F
M:65L9',N:6YC.C,V"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E;D
M;&H@971T(&1A='5M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC
M.C$P"FUS9VED(")396QE8W0@82!F:65L9"(*;7-G<W1R(")6Y&QJ(&5T="!F
MY&QT(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S$W"FUS
M9VED(")396QE8W0@82!S=&%T:6]N97)Y.B(*;7-G<W1R(")6Y&QJ(&5N(&UA
M;&PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L
M96-T(&%D9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E87)C
M:&EN9R!F;W(@861D<F5S<V5S+B(*;7-G<W1R(")6Y&QJ(&%D<F5S<V)O:R!F
M]G(@=&EL;.1G9R!O8V@@<_9K;FEN9R!A=B!A9')E<W-E<BXB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL(@IM
M<V=S='(@(E;D;&H@86QL82(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C,R,PIM<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@<V5A
M<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B5N1L:B!F
MY&QT('-O;2!G96YO;7/V:W,@=FED(&5X<&%N<VEO;B!A=B!A9')E<W-E<BXB
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHR
M,0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B5N1L:B!E='0@
M:V]N=&\B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@Y"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R(")6Y&QJ(&EN9V5N(@H*(SH@=&5M<&QA
M=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.CD*;7-G:60@(E-E;&5C="!T
M:&4@9V%L;&5R>2!T;R!S879E('1H92!I;6%G92!I;BXB"FUS9W-T<B`B5N1L
M:B!G86QL97)I(&%T="!S<&%R82!B:6QD96X@:2XB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC.C(Q"FUS9VED(")396QE8W0@
M=&AE(&UA:6P@<V5R=F5R('1Y<&4B"FUS9W-T<B`B5N1L:B!E+7!O<W1S97)V
M97)T>7`B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M,#D*;7-G:60@(E-E;&5C=&5D($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(E9A
M;&1A(&%D<F5S<V+V8VME<CHB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S(*;7-G:60@(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B"FUS9W-T
M<B`B4VMI8VMA(&YY8VME;"!T:6QL('!U8FQI:R!N>6-K96QS97)V97(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DW"FUS9VED(")396YD($QA
M=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R(")3:VEC:V$@<V5N87-T92!I;F9O
M<FUA=&EO;F5N(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#(X"FUS9VED(")3
M96YD($UE<W-A9V4B"FUS9W-T<B`B4VMI8VMA(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YJ<SHQ,C8*;7-G:60@(E-E;F0@;65S<V%G92!W:71H
M;W5T(&$@4W5B:F5C=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Y,@IM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U
M97-T960@8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B4VMI8VMA(&SD<V)E:W+D
M9G1E;'-E(&[D<B!SY&YD87)E;B!B96?D<B!D970_(@H*(SH@9F]L9&5R<RYP
M:'`Z,S<X"FUS9VED(")396YT(&UA:6P@9F]L9&5R(@IM<V=S='(@(DUA<'`@
M9O9R('-K:6-K861E(&UE9&1E;&%N9&5N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-E;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E
M<CHB"FUS9W-T<B`B36%P<"!F]G(@<VMI8VMA9&4@;65D9&5L86YD96XZ(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S,@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ-#4*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ-3(*;7-G:60@(E-E<G9E<B(*;7-G<W1R(")397)V97(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,*;7-G:60@(E-E<G9E<B!A;F0@1F]L9&5R
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E-E<G9E<BT@;V-H(&UA<'!I;F9O<FUA
M=&EO;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,PIM
M<V=I9"`B4V5R=F5R.B(*;7-G<W1R(")397)V97(Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@P"FUS9VED(")3970@<')E9F5R96YC97,@9F]R('=H
M870@:&%P<&5N<R!W:&5N('EO=2!M;W9E(&%N9"!D96QE=&4@;65S<V%G97,N
M(@IM<V=S='(@(B(*(D%N9V4@:6YS=.1L;&YI;F=A<B!F]G(@=F%D('-O;2!H
MY&YD97(@=FED(&9L>71T(&]C:"!R861E<FEN9R!A=B!M961D96QA;F1E;BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3970@=&AE
M(%@M4')I;W)I='D@:&5A9&5R('=H96X@8V]M<&]S:6YG(&UE<W-A9V5S/R(*
M;7-G<W1R(")!;F=E("=8+5!R:6]R:71Y)R!R=6)R:6L@;N1R(&UE9&1E;&%N
M9&5N('-K:6-K87,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q"FUS
M9VED(")3:&%R92!&;VQD97)S(@IM<V=S='(@(D1E;&$@;6%P<&%R(@H*(SH@
M=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C@V"FUS9VED(")3:&%R92!M86EL(&9O
M;&1E<G,B"FUS9W-T<B`B1&5L82!E+7!O<W1M87!P87(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S(*;7-G:60@(E-H87)E('EO=7(@;6%I;"!F;VQD
M97)S('=I=&@@;W1H97(@=7-E<G,N(@IM<V=S='(@(D1E;&$@92UP;W-T;6%P
M<&%R(&UE9"!A;F1R82!A;G;D;F1A<F4N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U-PIM<V=I9"`B(@HB4VAO=6QD(&QA<F=E(&)L;V-K<R!O9B!Q
M=6]T960@=&5X="!B92!S:&]W;B!O<B!H:61D96X@8GD@9&5F875L=#\@270@
M8V%N(&)E("(*(G1O9V=L960@96%S:6QY('=H:6-H979E<B!Y;W4@8VAO;W-E
M+B(*;7-G<W1R("(B"B)3:V$@<W1O<F$@<VIO:R!A=B!C:71E<F%D('1E>'0@
M=FES87,@96QL97(@9_9M;6%S('-O;2!S=&%N9&%R9#]<;B(*(D]A=G-E='0@
M=FEL:V5T(&1U(';D;&IE<B#D<B!D970@;.1T="!A='0@Y&YD<F$N(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D
M>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D
M871A/R(*;7-G<W1R(")6:6QL(&1U('/V:V$@969T97(@4$=0(&1A=&$@:2!T
M97AT+W!L86EN+6UE9&1E;&%N9&5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,3,*;7-G:60@(E-H;W5L9"!T:&4@8V]M<&]S92!W:6YD;W<@8F4@
M8VQO<V5D(&%F=&5R('-A=FEN9R!A(&1R869T/R(*;7-G<W1R("(B"B)3:V%L
M;"!F]FYS=')E="`G<VMR:78@;65D9&5L86YD92<@<W3D;F=A<R!E9G1E<B!A
M='0@=71K87-T(&AA<B!S<&%R871S/R(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T;R!B
M92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM<V=S
M='(@(E9I;&P@9'4L('-O;2!S=&%N9&%R9"P@8FEF;V=A(&1I;B!P=6)L:6MA
M(%!'4"UN>6-K96P@=&EL;"!M961D96QA;F1E;C\B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.CDR"FUS9VED(")3:&]W($%L;"!&;VQD97)S(@IM
M<V=S='(@(E9I<V$@86QL82!M87!P87(B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]H96%D97)S+FEN8SHV-PIM<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G
M<W1R(")6:7-A(&%L;&$@<G5B<FEK97(B"@HC.B!M86EL8F]X+G!H<#HS-3$*
M;7-G:60@(E-H;W<@1&5L971E9"(*;7-G<W1R(")6:7-A(')A9&5R861E(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C$*;7-G:60@(E-H
M;W<@3&EM:71E9"!(96%D97)S(@IM<V=S='(@(E9I<V$@8F5G<N1N<V%D92!R
M=6)R:6ME<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C<P
M"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(*;7-G<W1R
M(")6:7-A(&EN9F]R;6%T:6]N(&]M(&UA:6QL:7-T82(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@3VYL>2!3=6)S8W)I
M8F5D($9O;&1E<G,B"FUS9W-T<B`B5FES82!B87)A(&UA<'!A<B!M960@<')E
M;G5M97)A=&EO;F5R(@H*(SH@9F]L9&5R<RYP:'`Z,C@T"FUS9VED(")3:&]W
M(%5N<W5B<V-R:6)E9"(*;7-G<W1R(")6:7-A('5N<W5B<V-R:6)E9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.38*;7-G:60@(E-H;W<@86X@:6-O
M;B!T;R!A;&QO=R!S=')I<'!I;F<@;V8@871T86-H;65N=',@9G)O;2!M97-S
M86=E<S\B"FUS9W-T<B`B5FES82!E;B!I:V]N(&;V<B!A='0@=&$@8F]R="!B
M:6QA9V]R(&9RY6X@;65D9&5L86YD96X_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDY,0IM<V=I9"`B4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@
M=FEE=S\B"FUS9W-T<B`B5FES82!F]G)K;&%R:6YG(&D@;6%P<'9Y;C\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(Y"FUS9VED(")3:&]W('!R979I
M97=S(&9O<B!U;G)E860@;65S<V%G97,@;VYL>3\B"FUS9W-T<B`B5FES82!F
M]G)H86YD<V=R86YS:VYI;F=A<B!B87)A(&;V<B!O;.1S=&$@;65D9&5L86YD
M96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S-PIM<V=I9"`B4VAO
M=R!P<F5V:65W<R!I;B!T;V]L=&EP<S\B"FUS9W-T<B`B5FES82!F]G)H86YD
M<V=R86YS:VYI;F=A<B!I('9E<FMT>6=T:7!S/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-C8*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O
M;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B5FES82`G:.1M=&$@;65D9&5L
M86YD96XG(&D@;65N>6X_(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.CDX"FUS9VED(")3:&]W('1H92!);6%G97,B"FUS9W-T<B`B5FES82!A;&QA
M(&)I;&1E<B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU-`IM
M<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B87(_(@IM
M<V=S='(@(E9I<V$@9FEL=&5R:6MO;B!I(&UE;GEN/R(*"B,Z(&QI8B]";&]C
M:R]S=6UM87)Y+G!H<#HS,0IM<V=I9"`B4VAO=R!T;W1A;"!N=6UB97(@;V8@
M;6%I;',@:6X@9F]L9&5R/R(*;7-G<W1R(")6:7-A(&%N=&%L(&UE9&1E;&%N
M9&5N(&D@;6%P<#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4T"FUS
M9VED(")3:&]W;B(*;7-G<W1R(")6:7-A9&4B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0R"FUS9VED(")3:5]Z92(*;7-G
M<W1R(")3=&]?<FQE:R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI
M;F,Z,3<*;7-G:60@(E-I9VYE9"(*;7-G<W1R(")3:6=N97)A="(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")3:7IE
M(@IM<V=S='(@(E-T;W)L96LB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C$Q"FUS9VED(")3;W)T(&)Y($%R<FEV86PB"FUS
M9W-T<B`B4V]R=&5R82!PY2!A;FMO;7-T(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E
M(@IM<V=S='(@(E-O<G1E<F$@<.4@9&%T=6TB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(V"FUS9VED(")3;W)T(&)Y($9R
M;VT@061D<F5S<R(*;7-G<W1R(")3;W)T97)A('#E(&%D<F5S<R(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z-#$*;7-G:60@
M(E-O<G0@8GD@365S<V%G92!3:7IE(@IM<V=S='(@(E-O<G1E<F$@<.4@<W1O
M<FQE:R(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,S8*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*;7-G<W1R(")3;W)T97)A
M('#E(.1R96YD92(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,S$*;7-G:60@(E-O<G0@8GD@5&AR96%D(@IM<V=S='(@(E-O
M<G1E<F$@<.4@='+E9"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,C$*;7-G:60@(E-O<G0@8GD@5&\@061D<F5S<R(*;7-G
M<W1R(")3;W)T97)A('#E(&%D<F5S<R(*"B,Z('1E;7!L871E<R]P<F5F<R]S
M<&%M<V5L96-T+FEN8SHR,PIM<V=I9"`B4W!A;2!F;VQD97(Z(@IM<V=S='(@
M(DUA<'`@9O9R('-K<N1P<&]S=#HB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G
M<W1R(")3<&5C:6%L=&5C:V5N(@H*(SH@<V5A<F-H+G!H<#HQ-#(*;7-G:60@
M(E-P96-I86P@5FER='5A;"!&;VQD97)S(&-A;FYO="!B92!E9&ET960N(@IM
M<V=S='(@(E9I<G1U96QL82!M87!P87(@<V]M(.1R('-P8VEE;&QA(&MA;B!I
M;G1E(.1N9')A<RXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS-#,*;7-G:60@(E-P96QL($-H96-K(@IM<V=S='(@(E-T879N:6YG<VMO
M;G1R;VQL(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V
M"FUS9VED(")3<&5L;"!#:&5C:V5R(@IM<V=S='(@(E-T879N:6YG<VMO;G1R
M;VQL(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0X('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHU-@IM<V=I9"`B4W!E;&P@
M8VAE8VL@8V]M<&QE=&4B"FUS9W-T<B`B4W1A=FYI;F=S:V]N=')O;&P@:VQA
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@(E-P96QL
M:6YG(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N(@IM
M<V=S='(@(D%N=&%L('-T879F96P@<&5R('-KY')M('9I9"!S=&%V;FEN9W-K
M;VYT<F]L;"XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`W(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,#D*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8T,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C0T"FUS
M9VED(")3=&%R="(*;7-G<W1R(")3=&%R="(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C,Q,0IM<V=I9"`B4W1A=&EO;F5R>2(*;7-G<W1R(")-86QL(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T
M:6]N97)Y(&YA;64Z(@IM<V=S='(@(DUA;&QE;G,@;F%M;CHB"@HC.B!T96UP
M;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,C@*;7-G:60@(E-T871I;VYE
M<GD@='EP93HB"FUS9W-T<B`B36%L;'1Y<#HB"@HC.B!T96UP;&%T97,O<W1A
M=&EO;F5R>2]P<F5F<RYI;F,Z,S,*;7-G:60@(E-T871I;VYE<GDZ(@IM<V=S
M='(@(DUA;&PZ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,PIM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U<R(*"B,Z(&QI8B]-24U%+T-O
M;G1E;G1S+G!H<#HR,SD*;7-G:60@(E-T<FEP($%T=&%C:&UE;G0B"FUS9W-T
M<B`B5&$@8F]R="!B:6QA9V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#(Q"FUS9VED(")3=')I<"!L:6YE8G)E86MS/R(*;7-G<W1R(")482!B;W)T
M(')A9&)R>71N:6YG87(_(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G
M95]H96%D97)S+FEN8SHS-PIM<V=I9"`B4W5B7VIE8W0B"FUS9W-T<B`BQ%]R
M96YD92(*"B,Z(&UE<W-A9V4N<&AP.C(W-B!T:')E860N<&AP.C$U-2!T96UP
M;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C(U"B,Z(&QI8B]396%R8V@N
M<&AP.C8P-0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+$<F5N9&4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`Y"FUS9VED(")3=6)J96-T($9I96QD
M(@IM<V=S='(@(L1R96YD96;D;'0B"@HC.B!S96%R8V@N<&AP.C,Q,"!T96UP
M;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3@*(SH@=&5M<&QA=&5S
M+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(P('1E;7!L871E<R]P9W`O<&%S<W!H
M<F%S92YI;F,Z,S$*;7-G:60@(E-U8FUI="(*;7-G<W1R(")3:VEC:V$B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B4W5B
M<V-R:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R(")0<F5N=6UE<F5R82!PY2!M
M87!P*&%R*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@U(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Y,PHC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("),>6-K870B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#8*;7-G:60@
M(E-U9V=E<W1I;VYS(@IM<V=S='(@(D;V<G-L86<B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C4Y(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-C$*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4V%M;6%N<W3D;&QN:6YG(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,SDW('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,`IM<V=I9"`B4W=I=&-H($-O;7!O
M<VET:6]N($UE=&AO9"(*;7-G<W1R(")">70@<VMR:79LY&=E(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#`Q"FUS9VED(")3=VET8V@@
M=&\@2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R(")">70@=&EL;"!(5$U,+6SD
M9V4B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#$*;7-G
M:60@(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@
M(D)Y="!T:6QL('1E>'1LY&=E(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#$V"FUS9VED(")495]X="(*;7-G<W1R(")495]X="(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-S`*;7-G:60@(E1E;G1A=&EV
M93H@(@IM<V=S='(@(E!R96QI;6ENY')T.B`B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3@V"FUS9VED(")496YT871I=F5L>2!!8V-E<'0@<F5Q
M=65S="(*;7-G<W1R(")';V1KY&YN(&)E9^1R86X@<')E;&EM:6[D<G0B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4T"FUS9VED(")496YT871I
M=F5L>2!!8V-E<'1E9"(*;7-G<W1R(")0<F5L:6UI;N1R="!A8V-E<'1E<F%T
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO=&]S7V%G<F5E;65N="YP:'`Z
M-#D*;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D
M(&EN(&-O;F8N<&AP(@IM<V=S='(@(D9I;"!M960@879T86QS=FEL;&MO<B#D
M<B!I;G1E(&%N9VEV96X@:2!C;VYF+G!H<"(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R(")495]X
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-#,*;7-G:60@(E1H92!&
M<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME9#HB
M"FUS9W-T<B`B5F%D('-K86QL(%PB1G+E;EPB+6MO;'5M;F5N(&%V(&UE9&1E
M;&%N9&5T(&SD;FMA('1I;&PZ(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU
M,C4*;7-G:60@(B(*(E1H92!)34%0('-E<G9E<B!D;V5S(&YO="!A<'!E87(@
M=&\@<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D("(*(G-E;&5C
M=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"B))34%0+7-E<G9E<FX@=F5R:V%R(&EN=&4@<W3V:F1A
M(&1E;B!V86QD82!A=71E;G1I<V5R:6YG<VUE=&]D96XN(%9A<B!G;V0@(@HB
M:V]N=&%K=&$@<WES=&5M861M:6YI<W1R873V<F5N+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-86-I;G1O
M<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R(")-86-I;G1O<V@@<F5S=7)S+7-T
M<O9M;65N(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C:6YT;W-H(')E<V]U<F-E
M(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM<V=S='(@(DUA8VEN=&]S
M:"!R97-U<G,M<W1R]FUM96X@:V%N(&QA9&1A<R!N97(@)7,N(@H*(SH@9F5T
M8VAM86EL<')E9G,N<&AP.C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A
M8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")+;VYT
M;W0@)R5S)R!R861E<F%D97,N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B2V]N=&]T("<E<R<@<W!A<F%D97,N(@H*
M(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM96YT('=A
M<R!N;W0@9F]U;F0N(@IM<V=S='(@(D)I;&%G;W(@<V%K;F%S+B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,0IM<V=I9"`B5&AE(&-A;&5N9&%R
M(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R(")+86QE;F1E<FEN9F]R;6%T:6]N
M96X@Y'(@9F5L86MT:6<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-O;7!O<V5?=VEN+FIS.C,W"FUS9VED("(B"B)4:&4@8V]M<&]S92!W:6YD
M;W<@8V%N)W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R
M(&)R;W=S97(@=&\@(@HB8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B
M(@HB2V%N(&EN=&4@]G!P;F$@9O9N<W1R970@871T('-K<FEV82!M961D96QA
M;F1E;B!I+"!K86YS:V4@:&%R(&1U('-TY&QL="!I;B`B"B)D:6X@=V5B8FSD
M<V%R92!A='0@8FQO8VME<F$@<&]P=7`M9O9N<W1E<C\B"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N
M=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B
M26YN96CE;&QE="!I($UA8VEN=&]S:"UF:6QE;B#E=&5R9FEN;G,@;F5D86XN
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO
M;G1H;'DN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C=7)R96YT
M(&9O;&1E<BAS*2!<(B5S7"(@=VEL;"!B92!R96YA;65D('1O(%PB)7-<(BXB
M"FUS9W-T<B`B3F%M;F5T('#E(&YU=F%R86YD92!M87!P*&%R*2`G)7,G(&MO
M;6UE<B!A='0@8GET87,@=&EL;"`G)7,G+B(*"B,Z('1E;7!L871E<R]A8VPO
M86-L+FEN8SHQ,#<*;7-G:60@(B(*(E1H92!C=7)R96YT(&QI<W0@;V8@=7-E
M<G,@=VET:"!A8V-E<W,@=&\@=&AI<R!F;VQD97(@8V]U;&0@;F]T(&)E(')E
M=')I979E9"(*;7-G<W1R(")+=6YD92!I;G1E(&CD;71A(&QI<W1A;B!PY2!A
M;G;D;F1A<F4@;65D('1I;&QGY6YG('1I;&P@9&5N;F$@;6%P<"(*"B,Z(&-O
M;7!O<V4N<&AP.C$R-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T
M(&AA<R!B965N('-A=F5D('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R
M(")5=&MA<W1E="!H87(@<W!A<F%T<R!I(&UA<'!E;B!<(B5S7"(N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,`IM<V=I9"`B5&AE(&5V96YT
M('=A<R!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G<W1R(")(Y&YD96QS
M96X@:&%R(&QA9W1S('1I;&P@:2!D:6X@:V%L96YD97(N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O97AP86YD+FEN8SHY"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD960N(@IM<V=S='(@
M(D;D;'1E="`G)7,G(&MA;B!I;G1E(&5X<&%N9&5R87,N(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DUA<'!E;B`G)7,G(&9I
M;FYS(')E9&%N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A:6YS(&EL;&5G
M86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A=7-E("(*(G!R
M;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(DYA;6YE="!PY2!M87!P96X@)R5S)R!I;FYE:.5L;&5R
M(&9E;&%K=&EG82!T96-K96X@<V]M(&MA;B!M961F]G)A('!R;V)L96TN("(*
M(E9A<B!G;V0@:V]N=&%K=&$@9&EN('-Y<W1E;6%D;6EN:7-T<F%T]G(N(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@
M<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B36%P<&5N("<E<R<@<VMA<&%D
M97,@;65N(&1U(&+V<FIA9&4@:6YT92!P<F5N=6UE<F5R82!PY2!D96XN(@H*
M(SH@;&EB+T9O;&1E<BYP:'`Z,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F;VQD97(@7"(E<UPB('=A<R!D96QE=&5D(&)U="!Y;W4@=V5R92!N;W0@
M=6YS=6)S8W)I8F5D(&9R;VT@:70N(@IM<V=S='(@(DUA<'!E;B`G)7,G(')A
M9&5R861E<R!M96X@9&EN('!R96YU;65R871I;VX@<.4@;6%P<&5N('1O9W,@
M:6YT92!B;W)T+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,S.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@;F]T(&-R96%T960N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B36%P<&5N
M("<E<R<@<VMA<&%D97,@:6YT92X@4V5R=F5R;B!S=F%R861E(@H*(SH@;&EB
M+T9O;&1E<BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD
M97(@7"(E<UPB('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R(")-87!P96X@)R5S)R!R861E<F%D97,@:6YT
M92X@4V5R=F5R;B!S=F%R861E(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C
M97-S9G5L;'D@8W)E871E9"XB"FUS9W-T<B`B36%P<&5N("<E<R<@<VMA<&%D
M97,N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E
M9"XB"FUS9W-T<B`B36%P<&5N("<E<R<@<F%D97)A9&5S+B(*"B,Z(&QI8B]&
M;VQD97(N<&AP.C0U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R
M(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@7"(E<UPB+B(*
M;7-G<W1R(").86UN970@<.4@;6%P<&5N("<E<R<@Y&YD<F%D97,@=&EL;"`G
M)7,G(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.CDT"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@871T86-H960@=&\@=&AI<R!P87)T
M.B(*;7-G<W1R(")&]FQJ86YD92!F:6QE<B!V87(@8FEF;V=A9&4@9&5N(&CD
M<B!D96QE;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7W-A=F5I
M;6%G95]W:6XN:G,Z,3(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<&]P=7`N
M:G,Z-3D*;7-G:60@(B(*(E1H92!I;6%G92!S879E('=I;F1O=R!C86X@;F]T
M(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R
M("(*(G1O(&)L;V-K('!O<'5P('=I;F1O=W,_(@IM<V=S='(@(B(*(DMA;B!I
M;G1E(/9P<&YA(&;V;G-T<F5T(&%T="!S<&%R82!B:6QD97(@:2P@:V%N<VME
M(&AA<B!D=2!S=.1L;'0@:6X@9&EN("(*(G=E8F)LY'-A<F4@871T(&)L;V-K
M97)A('!O<'5P+6;V;G-T97(_(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$P,`IM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E(&1I<W!L87EE
M9"!B96-A=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y;W5R("(*(F%D
M9')E<W-B;V]K+B(*;7-G<W1R(")6:7-A<B!B:6QD97(@9.4@879SY&YD87)E
M;B!F:6YN<R!I(&1I;B!A9')E<W-B;VLN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z-S4*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T
M960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.B(*;7-G<W1R(")%+7!O
M<W1S97)V97)N(&=A=B!F]FQJ86YD92!F96QM961D96QA;F1E.B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C4Q"FUS9VED(")4:&4@
M;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@:6YF;W)M871I
M;VYA;"!M97-S86=E.B(*;7-G<W1R(")%+7!O<W1S97)V97)N(&=A=B!F]FQJ
M86YD92!I;F9O<FUA=&EO;G-M961D96QA;F1E.B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]S=&%T=7,N<&AP.CDP"FUS9VED(")4:&4@;6%I;"!S97)V97(@9V5N
M97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93HB"FUS9W-T<B`B12UP;W-T
M<V5R=F5R;B!G878@9O9L:F%N9&4@;65D9&5L86YD93HB"@HC.B!L:6(O365S
M<V%G92YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M86EL8F]X
M("5S(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(DUA<'!E;B`G)7,G(.1R
M(')E9&%N('1O;2XB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR-#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&UE<W-A9V4@7"(E<UPB(&9R;VT@7"(E<UPB
M("@E9"!B>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI;6ET+B(*;7-G<W1R
M("(B"B)-961D96QA;F1E="!F<N5N(%PB)7-<(B!T:6QL(%PB)7-<(B`H)60@
M8GET97,I(/9V97)S:W)I9&5R(&UA>'-T;W)L96ME;EQN(@HB9O9R(&UE9&1E
M;&%N9&5N('-O;2!HY&UT87,N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O
M;G1A8W1S+FEN8SHQ,#,*;7-G:60@(E1H92!M97-S86=E(&)E:6YG(&-O;7!O
M<V5D(&AA<R!B965N(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B365D9&5L
M86YD970@<V]M('-K<FEV<R!H87(@<W3D;F=T<RX@079S;'5T87(N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,C8*;7-G:60@(E1H92!M
M97-S86=E(&1O97,@;F]T(&AA=F4@82!3=6)J96-T(&5N=&5R960N(@IM<V=S
M='(@(DUE9&1E;&%N9&5T(&AA<B!S86MN87(@:6YN96CE;&P@:2#D<F5N9&5R
M861E;BXB"@HC.B!M97-S86=E+G!H<#HQ-#D*;7-G:60@(E1H92!M97-S86=E
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DUE9&1E;&%N9&5T(&AA<B!R
M861E<F%T<RXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3<*;7-G
M:60@(E1H92!M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G<W1R(")-
M961D96QA;F1E="!H87(@=F5R:69I97)A=',N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HS.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UE
M<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E<CH@)7,N(@IM<V=S='(@
M(DUE9&1E;&%N9&5T(&AA<B!V97)I9FEE<F%T<RX@079SY&YD87)E.B`E<R(*
M"B,Z('1E;7!L871E<R]S;6EM92]O<&5N7W-M:6UE7W=I;BYJ<SHQ,"!T96UP
M;&%T97,O<&=P+V]P96Y?<&=P7W=I;BYJ<SHQ,`IM<V=I9"`B(@HB5&AE('!A
M<W-P:')A<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y;W4@
M:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I;F1O
M=W,_(@IM<V=S='(@(B(*(DMA;B!I;G1E(/9P<&YA(&;V;G-T<F5T(&;V<B!A
M='0@9G+E9V$@969T97(@;/9S96YF<F%S+B!+86YS:V4@:&%R(&1U('-TY&QL
M=%QN(@HB:6X@9&EN('=E8F)LY'-A<F4@871T(&)L;V-K97)A('!O<'5P+6;V
M;G-T97(_(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI
M8R!+97D@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B4N5T97AT96X@9O9R
M(%!'4"UN>6-K96QN('9I<V%S("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]T
M;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T
M(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(D1E
M;B!B96?D<F1A(&9I;&5N(&9I;FYS(&EN=&4@:2!-4RU43D5&+6)I;&%G86XN
M(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*;7-G:60@(E1H92!R
M97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T=&%C
M:&UE;G0N(@IM<V=S='(@(D1E;B!B96?D<F1A(&9I;&5N(&9I;FYS(&EN=&4@
M:2`N>FEP+6)I;&%G86XN(@H*(SH@;65S<V%G92YP:'`Z-34Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES
M(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E
M+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@(@HB;F]T:69I8V%T:6]N
M(&UE<W-A9V4N(@IM<V=S='(@(B(*(D%V<^1N9&%R96X@8F5GY'(@;&5V97)A
M;G-B96MRY&9T96QS92!A=B!D:6<@;N1R(&1U(&SD<W0@9&5T=&%<;B(*(FUE
M9&1E;&%N9&4N($ML:6-K82`E<R!F]G(@871T('-K:6-K82!L979E<F%N<V)E
M:W+D9G1E;'-E+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8W
M"FUS9VED(")4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T
M:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B4V5R=F5R;B!K=6YD
M92!I;G1A('-K87!A(&5N(&UI;FEA='ER8FEL9"!F]G(@8FEL9&5N+B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z.3`*;7-G:60@(E1H92!S
M:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G<W1R(")+=6YD
M92!I;G1E(&)Y=&$@=70@<VEG;F%T=7)E;BXB"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]C;VUP;W-E+FIS.C@X"FUS9VED(")4:&4@<VEG;F%T=7)E('=A<R!S
M=6-C97-S9G5L;'D@<F5P;&%C960N(@IM<V=S='(@(E-I9VYA='5R96X@:&%R
M(&5R<V%T=',N(@H*(SH@871T86-H;65N="YP:'`Z-3D*;7-G:60@(E1H92!S
M<&5C:69I960@9FEL92!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B06YG:79E
M;B!F:6P@9FEN;G,@:6YT92XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E
M96X@861D960N(@IM<V=S='(@(DUA;&QE;B`G)7,G(&QA9&5S('1I;&PN(@H*
M(SH@<W1A=&EO;F5R>2YP:'`Z-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(DUA;&QE;B`G)7,G(')A9&5R861E<RXB"@HC.B!S=&%T:6]N97)Y+G!H<#HX
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W1A=&EO;F5R>2!<(B5S7"(@
M:&%S(&)E96X@=7!D871E9"XB"FUS9W-T<B`B36%L;&5N("<E<R<@:&%R('5P
M<&1A=&5R871S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S`*
M;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI
M<W0N(@IM<V=S='(@(E5P<&=I9G1E;B!H87(@;&%G=',@=&EL;"!I(&1I;B!U
M<'!G:69T<VQI<W1A+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.CDU"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92(*;7-G<W1R(")4
M97AT96X@9O9R(&UE9&1E;&%N9&5T(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T
M871U<RYP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@
M=&AE(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B5&5X=&5N
M(&;V<B!M961D96QA;F1E="!K86X@=FES87,@)7,N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W-T871U<RYP:'`Z.#`*;7-G:60@(E1H92!T97AT(&]F('1H92!R
M971U<FYE9"!M97-S86=E(@IM<V=S='(@(E1E>'1E;B!F]G(@9&5T(')E='5R
M;F5R861E(&UE9&1E;&%N9&5T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H
M92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@
M(E1E>'1E;B!F]G(@9&5T(')E='5R;F5R861E(&UE9&1E;&%N9&5T(&MA;B!V
M:7-A<R`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H
M<#HV.`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE('-E;G0@;65S<V%G92(*;7-G
M<W1R(")497AT96X@9O9R(&1E="!S:VEC:V%D92!M961D96QA;F1E="XB"@HC
M.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A
M;B!B92!V:65W960@)7,N(@IM<V=S='(@(E1E>'1E;B!F]G(@9&5T('-K:6-K
M861E(&UE9&1E;&%N9&5T(&MA;B!V:7-A<R`E<RXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,34U"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R
M("),961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;B!F]G(@86YVY&YD87)E;B!H
M87(@<W!A<F%T<RXB"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N
M<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B1&5T(&9I
M;FYS(&EN9V$@86QT97)N871I=F$@9&5L87,@<V]M(&MA;B!V:7-A<R!I;FQI
M;F4N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,Z
M,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I;&)O
M>"XB"FUS9W-T<B`B1&5T(&9I;FYS(&EN9V$@;65D9&5L86YD96X@:2!D96X@
M:.1R(&UA<'!E;BXB"@HC.B!T:')E860N<&AP.C$Q,`IM<V=I9"`B5&AE<F4@
M:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G
M<W1R(")$970@9FEN;G,@:6YG96X@=&5X="!S;VT@:V%N('9I<V%S(&EN;&EN
M92XB"@HC.B!L:6(O365S<V%G92YP:'`Z-CDS"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X
M+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(E!R;V)L96T@=FED(')A
M9&5R:6YG(&%V(&EN;F5HY6QL970@:2!M87!P96XN(%-E<G9E<FX@<W9A<F%D
M93H@)7,B"@HC.B!L:6(O365S<V%G92YP:'`Z,3$P"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S
M(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S
M97)V97(@<V%I9"(*;7-G<W1R("(B"B)$970@=7!P<W1O9"!P<F]B;&5M('9I
M9"!K;W!I97)I;F<@878@;65D9&5L86YD96X@=&EL;"`G)7,G('1I;&P@)R5S
M)RX@(@HB4V5R=F5R;B!S=F%R861E(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C(R
M-B!L:6(O365S<V%G92YP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H
M92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(B(*(D1E="!U<'!S=&]D('!R;V)L96T@=FED(')A9&5R
M:6YG(&%V(&UE9&1E;&%N9&5N(&9RY6X@;6%P<&5N("<E<R<N(%-E<G9E<FX@
M(@HB<W9A<F%D92(*"B,Z(&QI8B]-97-S86=E+G!H<#HS,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE
M<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE
M("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(D1E="!U<'!S=&]D('!R;V)L
M96T@=FED(')A9&5R:6YG(&%V(&UE9&1E;&%N9&5N(&9RY6X@;6%P<&5N("<E
M<R<N(%-E<G9E<FX@(@HB<W9A<F%D92(*"B,Z(&QI8B]-97-S86=E+G!H<#HR
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1E
M;&5T:6YG(&UE<W-A9V5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`E<R(*;7-G<W1R(")$970@=7!P<W1O9"!P<F]B;&5M('9I9"!R861E<FEN
M9R!A=B!M961D96QA;F1E;BX@4V5R=F5R;B!S=F%R861E("5S(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB
M"FUS9W-T<B`B1&5T('5P<'-T;V0@971T(&9E;"!V:60@<F%D97)I;F<@878@
M:.1N9&5L<V4Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN+G!H<#HU
M,B!L:6(O34E-12]6:65W97(O96YR:6-H960N<&AP.C,W"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*
M;7-G<W1R(")$970@=7!P<W1O9"!E='0@9F5L('9I9"!V:7-N:6YG(&%V(&UE
M9&1E;&%N9&5D96QE;BXB"@HC.B!L:6(O365S<V%G92YP:'`Z-3DT"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!F;&%G9VEN
M9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)$970@=7!P<W1O9"!P
M<F]B;&5M('9I9"!MY')K;FEN9R!A=B!M961D96QA;F1E;B!I(&UA<'!E;B`G
M)7,G+B!397)V97)N("(*(G-V87)A9&4B"@HC.B!F;VQD97)S+G!H<#HQ-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R`E<RXB"FUS9W-T<B`B1&5T('5P<'-T;V0@971T(&9E;"!V:60@:6UP
M;W)T.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")&96P@=FED(&EM<&]R="!A=B!H
MY&YD96QS96XZ("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(D9E;"!V:60@:6UP;W)T
M(&%V('5P<&=I9G1E;CH@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C$U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S
M+B(*;7-G<W1R(")&96P@=FED(&EM<&]R="!A=B!I;F9O<FUA=&EO;B!O;2!L
M961I9R]U<'!T86=E;CH@)7,N(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;6]V
M:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)$970@=7!P<W1O
M9"!P<F]B;&5M('9I9"!F;'ET="!A=B!M961D96QA;F1E;B!T:6QL("<E<R<@
M=&EL;"`G)7,G+B!397)V97)N("(*(G-V87)A9&4B"@HC.B!C;VUP;W-E+G!H
M<#HQ,C@P"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@<V%V:6YG('1H:7,@
M;65S<V%G92!A<R!A(&1R869T+B(*;7-G<W1R(")$970@=7!P<W1O9"!E='0@
M9F5L(&[D<B!M961D96QA9&5T('-K=6QL92!S<&%R87,@<V]M('5T:V%S="XB
M"@HC.B!C;VUP;W-E+G!H<#HQ,#,Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!S96YD:6YG('EO=7(@;65S<V%G93H@)7,B"FUS
M9W-T<B`B1&5T('5P<'-T;V0@971T(&9E;"!NY'(@9&ET="!M961D96QA;F1E
M('-K:6-K861E<SH@)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")$970@=7!P<W1O9"!E
M='0@9F5L('9I9"`S=7!P9&%T97)I;F<@878@:.1N9&5L<V5N.B`E<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3D*;7-G:60@(E1H97)E('=A
M<R!N;R!T97AT(&EN('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(DEN9V5N
M('1E>'0@:2!D96X@:.1R(&UE9&1E;&%N9&5D96QE;B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,#`*;7-G:60@(E1H:7,@2%1-3"!M97-S86=E
M(&AA<R!I;6%G97,@96UB961D960@:6X@:70N(@IM<V=S='(@(DA434PM;65D
M9&5L86YD970@:&%R(&EN8N1D9&%D92!B:6QD97(N(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VAT;6PN<&AP.CDS"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G
M92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A
M<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T<B`B(@HB1&5T=&$@2%1-3"UM
M961D96QA;F1E(&AA<B!I;F+D9&1A9&4@8FEL9&5R+B!";&]C:V5R861E(&)I
M;&1E<B!V:7-A<R!SY2!HY'(Z(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP
M:'`Z,38U"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE
M9"!T;R!T:&4@;65S<V%G92XB"FUS9W-T<B`B1&5N(&CD<B!P=6)L:6MA(%!'
M4"UN>6-K96QN('9A<B!B:69O9V%T('1I;&P@;65D9&5L86YD970N(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P-2!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z,3$Y"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-#0@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U.`HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z,3<T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,34*
M;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(D1E;FYA(&AA;F1L:6YG('-T]F1S(&EN=&4N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$X,"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#(P
M"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R(")(86YD;&EN9V5N(.1R(&EN=&4@:6UP;&5M96YT97)A9"#D;FYU
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,30@=&5M
M<&QA=&5S+V9O;&1E<G,O:F%V87-C<FEP="YI;F,Z-@IM<V=I9"`B5&AI<R!M
M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C
M;VYT:6YU93\B"FUS9W-T<B`B1&5T(&MA;B!T82!L:71E('1I9"P@Y'(@9'4@
M<^1K97(@<.4@871T(&1U('9I;&P@9F]R='/D='1A/R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#`*;7-G:60@(E1H:7,@;65S<V%G
M92!C;VYT86EN<R!A($UA8VEN=&]S:"!F:6QE+B(*;7-G<W1R(")$971T82!M
M961D96QA;F1E(&EN;F5HY6QL97(@96X@36%C:6YT;W-H+69I;"XB"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q-0IM<V=I9"`B(@HB5&AI<R!M
M97-S86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!D
M:6=I=&%L;'D@<VEG;F5D('9I82!3+R(*(DU)344N(@IM<V=S='(@(DUE9&1E
M;&%N9&5T(&EN;F5HY6QL97(@96X@8FEL86=A('-O;2!H87(@<VEG;F5R871S
M('9I82!3+TU)344N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT
M,3D*;7-G:60@(E1H:7,@;65S<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT
M('1H870@:&%S(&)E96X@96YC<GEP=&5D('9I82!3+TU)344N(@IM<V=S='(@
M(DUE9&1E;&%N9&5T(&EN;F5HY6QL97(@96X@8FEL86=A('-O;2!H87(@:W)Y
M<'1E<F%T<R!V:6$@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C$V,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA
M:6P@9&5L:79E<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA
M="!O9B`B"B)T:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T<B`B(@HB
M1&5T=&$@;65D9&5L86YD92!I;FYE:.5L;&5R(&QE=F5R86YS:6YF;W)M871I
M;VX@;VT@92UP;W-T+"!M96Y<;B(*(F9O<FUA=&5T('#E(&UE9&1E;&%N9&5T
M(.1R(&]KY&YT+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,Q.0IM
M<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G92X@17)R;W(Z("(*;7-G<W1R
M(")$970@:.1R(&UE9&1E;&%N9&5T('9E<FMA<B!I;G1E(&AA(&5T="!R:6MT
M:6=T(%!'4"UF;VUA="X@1F5L.B`B"@HC.B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HR,SD@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S4T"FUS9VED("(B
M"B)4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C
M;W)R96-T(%!'4"!F;W)M870@*&%C8V]R9&EN9R!T;R`B"B)21D,@,C`Q-2DN
M(@IM<V=S='(@(B(*(D1E="!HY'(@;65D9&5L86YD970@=F5R:V%R(&EN=&4@
M:&$@971T(')I:W1I9W0@4$=0+69O<FUA="`H96YL:6=T(%)&0R`R,#$U*2XB
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI
M<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C
M="!3+TU)344@9F]R;6%T+B(*;7-G<W1R(")$970@:.1R(&UE9&1E;&%N9&5T
M('9E<FMA<B!I;G1E(&AA(&5T="!R:6MT:6=T(%,O34E-12UF;VUA="XB"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR,#0@;&EB+TU)344O5FEE=V5R
M+W!G<"YP:'`Z-#(P"FUS9VED(")4:&ES(&UE<W-A9V4@:&%S(&)E96X@9&EG
M:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G<W1R(")-961D96QA;F1E="!H
M87(@<VEG;F5R871S('9I82!01U`N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I
M=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM<V=S='(@(DUE9&1E;&%N9&5T
M(&AA<B!S:6=N97)A=',@=FEA(%,O34E-12XB"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C$S.2!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C(S
M.`IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@
M4R]-24U%+B(*;7-G<W1R(")-961D96QA;F1E="!H87(@:W)Y<'1E<F%T<R!V
M:6$@4R]-24U%+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P,"!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3`*;7-G:60@(E1H:7,@;65S<V%G
M92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N(@IM<V=S='(@(DUE9&1E
M;&%N9&5T(&AA<B!K<GEP=&5R871S('9I82!01U`N(@H*(SH@;65S<V%G92YP
M:'`Z,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T<B`B365D9&5L
M86YD970@=&EL;"(*"B,Z(&%C;"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$
M96YN82!S97)V97(@<W3V9&5R(&EN=&4@9&5L861E(&UA<'!A<BXB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C$P.0IM<V=I9"`B5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A(&-O;7!O<V4@=VEN9&]W
M+B(*;7-G<W1R("(B"B)$971T82!F]FYS=&5R(&MA;B!B87)A(/9P<&YA<R!F
M<N5N(&5T="!F]FYS=&5R(&;V<B!A='0@<VMR:79A(&UE9&1E;&%N9&5N+B(*
M"B,Z('1H<F5A9"YP:'`Z,34W"FUS9VED(")4:')E860@1&ES<&QA>2(*;7-G
M<W1R(")4<N5D=FES;FEN9R(*"B,Z('1H<F5A9"YP:'`Z-S8@=&5M<&QA=&5S
M+W1H<F5A9"]T;W`N:6YC.C,@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ,0IM
M<V=I9"`B5&AR96%D(%9I97<B"FUS9W-T<B`B5'+E9'9Y(@H*(SH@;65S<V%G
M92YP:'`Z,C<R(&UA:6QB;W@N<&AP.C8P,B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C(Q.0HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C(R('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN
M8SHV,0HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C$P(&QI
M8B]396%R8V@N<&AP.C4Y,PIM<V=I9"`B5&\B"FUS9W-T<B`B5&EL;"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#@*;7-G:60@(E1O($%D9')E<W,B
M"FUS9W-T<B`B5&EL;"!A9')E<W,B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U
M<F-E<V5L96-T+FEN8SHS,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L
M92!F:65L9',L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA
M;F0@*$UA8RD@=VAI;&4@(@HB8VQI8VMI;F<N(@IM<V=S='(@(B(*(D;V<B!A
M='0@=N1L:F$@9FQE<F$@9N1L="P@:.5L;"!N97)E($-O;G1R;VP@*'#E(%!#
M*2!E;&QE<B!#;VUM86YD("APY5QN(@HB36%C*2!O8V@@:VQI8VMA+B(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4;R!U<V4@82!4
M3%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A('9E<G-I;VX@
M;V8@4$A0(#4N,2XP(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B(@HB1O9R(&%T
M="!A;G;D;F1A(%1,4RUA;G-L=71N:6YG+"!SY2!MY7-T92!D=2!A;G;D;F1A
M(%!(4"`U+C$N,"!E;&QE<B!S96YA<F4N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3DQ"FUS9VED(")4;W1A;"!!='1A8VAM96YT<R!3
M:7IE.B(*;7-G<W1R(")3=&]R;&5K('#E(&)I;&%G;W(Z(@H*(SH@9F]L9&5R
M<RYP:'`Z,S8Y"FUS9VED(")4<F%S:"!F;VQD97(B"FUS9W-T<B`B4&%P<&5R
M<VMO<F<B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(S
M"FUS9VED(")4<F%S:"!F;VQD97(Z(@IM<V=S='(@(E!A<'!E<G-K;W)G(@H*
M(SH@;&EB+U%U;W1A+V-Y<G5S+G!H<#HV-"!L:6(O475O=&$O;65R8W5R>3,R
M+G!H<#HW.2!L:6(O475O=&$O8V]M;6%N9"YP:'`Z-S$*(SH@;&EB+U%U;W1A
M+VQO9V9I;&4N<&AP.C@X(&QI8B]1=6]T82]C;W5R:65R+G!H<#HU,R!L:6(O
M475O=&$O;61A96UO;BYP:'`Z-#@*;7-G:60@(E5N86)L92!T;R!R971R:65V
M92!Q=6]T82(*;7-G<W1R(")+=6YD92!I;G1E(&SD<V$@:W9O=&$B"@HC.B!T
M96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$P('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3D*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHS-@IM<V=I9"`B56YA;G-W97)E9"(*;7-G<W1R(")/
M8F5S=F%R870B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,U"FUS
M9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(D]B97-V87)A9&4@
M;65D9&5L86YD96XB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,PIM
M<V=I9"`B56YD96QE=&4B"FUS9W-T<B`BQ71E<G1A(@H*(SH@;6%I;&)O>"YP
M:'`Z-3@P(&UA:6QB;W@N<&AP.C4Y."!L:6(O34E-12](96%D97)S+G!H<#HR
M,#0*;7-G:60@(E5N9&ES8VQO<V5D(%)E8VEP:65N=',B"FUS9W-T<B`B1&]L
M9&$@;6]T=&%G87)E(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HU-38*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\@05542$5.
M5$E#051%(&-O;6UA;F0N(@IM<V=S='(@(D]VY&YT870@<W9A<B!F<N5N('-E
M<G9E<B!F]G(@05542$5.5$E#051%+6MO;6UA;F1O.B`B"@HC.B!L:6(O24U!
M4"]#;&EE;G0N<&AP.C4R,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;R!$:6=E<W0M340U(')E<W!O;G-E+B(*;7-G<W1R(")/
M=N1N=&%T('-V87(@9G+E;B!S97)V97(@9O9R($1I9V5S="U-1#4Z("(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-3,V"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O($Q/1TE.(&-O;6UA;F0N(@IM<V=S='(@
M(D]VY&YT870@<W9A<B!F<N5N('-E<G9E<B!F]G(@3$]'24XM:V]M;6%N9&\Z
M("(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*
M;7-G<W1R("))8VME(&AA;G1E<F%D(&MO;7!O;F5N="!A=B!T>7`Z("5S(@H*
M(SH@;6%I;&)O>"YP:'`Z-34X"FUS9VED(")5;FMN;W=N($1A=&4B"FUS9W-T
M<B`B3VOD;G0@9&%T=6TB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N($E-05`@<F5S<&]N<V4@9G)O
M;2!T:&4@<V5R=F5R+B!397)V97(@4F5S<&]N9&5D.B`E<R(*;7-G<W1R(")/
M:^1N="!S=F%R(&9RY6X@24U!4"US97)V97(N(%-E<G9E<FX@<W9A<F%D93H@
M)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(V"FUS9VED(")5
M;FMN;W=N($UE971I;F<B"FUS9W-T<B`B3VOD;G0@;?9T92(*"B,Z(&UA:6QB
M;W@N<&AP.C8Q-`IM<V=I9"`B56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`B
M3VOD;F0@;6]T=&%G87)E(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E5N;&]A9"!0
M87-S<&AR87-E(@IM<V=S='(@(D9R:6?V<B!L]G-E;F]R9"(*"B,Z(&9E=&-H
M;6%I;'!R969S+G!H<#HV-0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").86UN
M;/9S(@H*(SH@;65S<V%G92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<P,R!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C8*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-2!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C,R"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z
M-0IM<V=I9"`B56YS965N(@IM<V=S='(@(D]LY'-T(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3(*;7-G:60@(E5N<W5B<V-R:6)E(&9R
M;VT@1F]L9&5R*',I(@IM<V=S='(@(D%V<VQU=&$@<')E;G5M97)A=&EO;B!P
MY2!M87!P*&%R*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4Q-0IM<V=I9"`B57!D871E(@IM<V=S='(@(E5P<&1A=&5R82(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3(*;7-G:60@(E5P9&%T92!R97-P
M;VYD96YT('-T871U<R(*;7-G<W1R(")5<'!D871E<F$@<W1A='5S('#E('-V
M87)A;F1E(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C4X
M('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z-38*;7-G:60@(E5P;&]A
M9"(*;7-G<W1R("),861D82!U<'`B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C0Q"FUS9VED(")5<V4@1&5F875L="!686QU92(*
M;7-G<W1R(")!;G;D;F0@9O9R=F%L="!VY')D92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-38*;7-G:60@(E5S92!)34%0(&9O;&1E<B!S=6)S8W)I
M<'1I;VYS/R(*;7-G<W1R(")!;G;D;F0@24U!4',@;6%P<'!R96YU;65R871I
M;VYE<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(T"FUS9VED(")5
M<V4@5FER='5A;"!4<F%S:"!&;VQD97(_(@IM<V=S='(@(D%N=N1N9"!V:7)T
M=65L;"!P87!P97)S:V]R9S\B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z
M,30S"FUS9VED(")5<V5R(@IM<V=S='(@(D%N=N1N9&%R92(*"B,Z(&%C;"YP
M:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB57-E<B!<(B5S7"(@<W5C
M8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B1V%V(&%N=N1N9&%R96X@7"(E<UPB
M(&%N9VEV;F$@<N1T=&EG:&5T97(@=&EL;"!M87!P96X@7"(E<UPB+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<V"FUS9VED(")5<V5R;F%M
M92(*;7-G<W1R(")!;G;D;F1A<FYA;6XB"@HC.B!T96UP;&%T97,O9F5T8VAM
M86EL+VUA;F%G92YI;F,Z,3<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")!
M;G;D;F1A<FYA;6XZ(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR
M-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"B,Z
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S<*;7-G:60@(E9I97<B"FUS9W-T<B`B5FES82(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]Z:7`N<&AP.CDR(&QI8B]-24U%+U9I97=E<B]T;F5F+G!H<#HQ
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")6:7-A
M("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(E9I<V$@<'5B;&EK(&YY8VME;"!F]G(@
M)7,B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3$Y"FUS9VED(")6
M:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R
M(")6:7-A($A434PM:6YN96CE;&P@:2!E='0@<V5P87)A="!F]FYS=&5R(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C@*;7-G:60@(E9I
M97<@365S<V%G97,B"FUS9W-T<B`B5FES82!M961D96QA;F1E;B(*"B,Z('1E
M;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C<W"FUS9VED(")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S
M='(@(E9I<V$@<&5R<V]N;&EG+"!P<FEV870@;GEC:V5L(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S(*;7-G:60@(E9I97<@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R(")6
M:7-A('!E<G-O;FQI9RP@<'5B;&EK(&YY8VME;"(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B5FEE=R!4:')E
M860B"FUS9W-T<B`B5FES82!T<N5D(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z,38T(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V-@IM
M<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B5FES82!M:6YI871Y<F)I
M;&0B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0R,PIM<V=I9"`B
M5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@
M(E9I<V$@8FEL86=O<B!I(&5T="!S97!A<F%T(&;V;G-T97(B"@HC.B!L:6(O
M34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*;7-G:60@(E9I97<@8V]N=&5N
M="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R(")6:7-A(&EN;F5HY6QL
M(&D@971T('-E<&%R870@9O9N<W1E<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HQ-#$*;7-G:60@(E9I97<@979E;G0B"FUS9W-T<B`B5FES82!H
MY&YD96QS92(*"B,Z(&9O;&1E<G,N<&AP.C,V,2!M86EL8F]X+G!H<#HU,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!M97-S86=E<R!I;B`E<R(*;7-G
M<W1R(")6:7-A(&UE9&1E;&%N9&5N(&D@)7,B"@HC.B!T96UP;&%T97,O<')E
M9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C(S"FUS9VED(")6:65W(&]R(&UA
M:6QB;W@@=&\@9&ES<&QA>2!A9G1E<B!L;V=I;CHB"FUS9W-T<B`B5GD@96QL
M97(@;6%P<"!A='0@=FES82!E9G1E<B!I;FQO9V=N:6YG.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ-S$*;7-G:60@(E9I97<@=&%S:R(*;7-G
M<W1R(")6:7-A('5P<&=I9G0B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP
M:'`Z,3`T"FUS9VED(")6:65W('1H92!);6%G97,B"FUS9W-T<B`B5FES82!B
M:6QD97(B"@HC.B!S96%R8V@N<&AP.C(V,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F=6QL>2XB
M"FUS9W-T<B`B5FER='5E;&P@;6%P<"!<(B5S7"(@<VMA<&%D97,N(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@=&5M<&QA=&5S+V9O;&1E
M<G,O=F9O;&1E<E]H96%D+FEN8SHR"B,Z(&QI8B])34%0+U1R964N<&AP.C$T
M,2!L:6(O24U!4"]4<F5E+G!H<#HQ-30@;&EB+TE-05`O5')E92YP:'`Z,34V
M"B,Z(&QI8B])34%0+U1R964N<&AP.C$V,"!L:6(O24U!4"]4<F5E+G!H<#HQ
M-C$@;&EB+TE-05`O5')E92YP:'`Z,S<Q"B,Z(&QI8B])34%0+U1R964N<&AP
M.C,Y-2!L:6(O24U!4"]4<F5E+G!H<#HT,S,*;7-G:60@(E9I<G1U86P@1F]L
M9&5R<R(*;7-G<W1R(")6:7)T=65L;&$@;6%P<&%R(@H*(SH@<V5A<F-H+G!H
M<#HR-3(*;7-G:60@(E9I<G1U86P@1F]L9&5R<R!R97%U:7)E(&$@;&%B96PN
M(@IM<V=S='(@(E9I<G1U96QL82!M87!P87(@;>5S=&4@:&$@971T(&YA;6XB
M"@HC.B!L:6(O5D9O;&1E<BYP:'`Z,3<V(&QI8B]61F]L9&5R+G!H<#HQ.#8@
M;&EB+U-E87)C:"YP:'`Z-#(P"FUS9VED(")6:7)T=6%L($E.0D]8(@IM<V=S
M='(@(E9I<G1U96QL(&EN:V]R9R(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PIM<V=I
M9"`B5FER='5A;"!)3D)/6"!&;VQD97(B"FUS9W-T<B`B5FER='5E;&P@:6YK
M;W)G(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C$U-B!L:6(O5D9O;&1E<BYP:'`Z
M,3$Q(&QI8B]61F]L9&5R+G!H<#HQ,C,*(SH@;&EB+U-E87)C:"YP:'`Z,S8V
M"FUS9VED(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(E9I<G1U96QL('!A<'!E
M<G-K;W)G(@H*(SH@9F]L9&5R<RYP:'`Z,SDT"FUS9VED(")6:7)T=6%L(%1R
M87-H($9O;&1E<B(*;7-G<W1R(")6:7)T=65L;"!P87!P97)S:V]R9R(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3(X"FUS9VED(")6:7)T=6%L
M(&9O;&1E<B!L86)E;"(*;7-G<W1R(").86UN('#E('9I<G1U96QL(&UA<'`B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W.0IM<V=I9"`B5V%R
M;FEN9R(*;7-G<W1R(")687)N:6YG(@H*(SH@;&]G:6XN<&AP.C$U,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E;D;&MO
M;6UE;B!T:6QL("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P-PIM
M<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A9V5S
M(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@(@HB;W(@
M:6YN;V-E;G0_(@IM<V=S='(@(B(*(DAU<B!S:V%L;"!M961D96QA;F1E;B!H
M86YT97)A<R!E9G1E<B!D92!H87(@<F%P<&]R=&5R871S('-O;2!S:W+D<'!O
M<W0@96QL97(@(@HB<V]M($5*+7-K<N1P<&]S=#\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S$V"FUS9VED("(B"B)7:&5N(&1E;&5T:6YG(&UE<W-A
M9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F;VQD97(@:6YS=&5A9"!O
M9B!M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B"FUS9W-T<B`B(@HB3N1R
M(&UE9&1E;&%N9&5N(')A9&5R87,L(&9L>71T82!D96T@=&EL;"!P87!P97)S
M:V]R9V5N(&ES=.1L;&5T(&;V<B!A='0@(@HB;6%R:V5R82!D96T@<V]M(')A
M9&5R861E/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.38*;7-G:60@
M(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O('EO
M=2!W86YT('1O('-T87)T(&]N/R(*;7-G<W1R(").Y'(@9'4@]G!P;F%R(&5N
M(&YY(&UA<'`L('9I;&ME;B!S:61A('9I;&P@9'4@8O9R:F$@<.4_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,0IM<V=I9"`B5VAE;B!S879I;F<@
M<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM96YT(&1A=&$_(@IM
M<V=S='(@(D[D<B!S:VEC:V%D('!O<W0@<W!A<F%S+"!S:V%L;"!B:6QA9V]R
M(&]C:W/E('-P87)A<S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(V
M"FUS9VED("(B"B)7:&5N('-E;F1I;F<@;6%I;"!O<B!E>'!A;F1I;F<@861D
M<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@=V4@87!P96YD('1O("(*(G5N
M<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@861D<F5S<V5S('=I=&AO=70@
M7")`7"(I/R(*;7-G<W1R("(B"B).Y'(@=FD@<VMI8VMA<B!E+7!O<W0@96QL
M97(@97AP86YD97)A<B!A9')E<W-E<BP@=FEL:V5N(&1O;>1N('-K86QL('9I
M(&SD9V=A("(*(G1I;&P@;V9U;&QS=.1N9&EG82!E+7!O<W1A9')E<W-E<B`H
M861R97-S97(@=71A;B!<(D!<(BD_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C$Y"FUS9VED(")7:&ET96QI<W0B"FUS9W-T<B`B0F5T<F]D9&$@
M861R97-S97(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU
M,SD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-34R"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-C<*;7-G:60@(EEE<R(*;7-G<W1R(")*82(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z
M-3@*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O;2!T
M:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM<V=S='(@(D1U(&MO;6UE<B!A
M='0@:.1M92!M961D96QA;F1E;B!F<N5N(&;V;&IA;F1E(&MO;G1O*&XI.B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$P
M"FUS9VED("(B"B)9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E(&%L;"!M
M97-S86=E<R!C;VYT86EN960@:6X@=&AE(&9O;&QO=VEN9R!F;VQD97(B"B(H
M<RDN(@IM<V=S='(@(D1U(&;V<G/V:V5R('1A(&)O<G0@86QL82!M961D96QA
M;F1E;B!I(&;V;&IA;F1E(&UA<'`H87(I.B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.CD*;7-G:60@(EEO=2!A<F4@871T
M96UP=&EN9R!T;R!D96QE=&4@=&AE(&9O;&QO=VEN9R!F;VQD97(H<RDN(@IM
M<V=S='(@(D1U(&;V<G/V:V5R('1A(&)O<G0@9O9L:F%N9&4@;6%P<"AA<BDZ
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS9VED(")9;W4@
M87)E(&-O<'EI;F<O;6]V:6YG('1O(&$@;F5W(&9O;&1E<BXB"FUS9W-T<B`B
M1'4@9FQY='1A<B]K;W!I97)A<B!T:6QL(&5N(&YY(&UA<'`N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#0@=&5M<&QA=&5S+V9O
M;&1E<G,O:F%V87-C<FEP="YI;F,Z.30*;7-G:60@(EEO=2!A<F4@8W)E871I
M;F<@82!S=6(M9F]L9&5R('1O("(*;7-G<W1R(")$=2!S:V%P87(@96X@=6YD
M97)M87!P('1I;&P@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R
M<RYJ<SHQ,#8@=&5M<&QA=&5S+V9O;&1E<G,O:F%V87-C<FEP="YI;F,Z.38*
M;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!T;W`M;&5V96P@9F]L9&5R+B(*
M;7-G<W1R(")$=2!S:V%P87(@96X@;6%P<"!PY2!T;W!P;FEVY6XN(@H*(SH@
M;&EB+T9O;&1E<BYP:'`Z,S$U"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!F;VQD97)S+B(*;7-G<W1R(")$=2!FY7(@:6YT92!S:V%P
M82!M87!P87(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(R"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!F;VQD97)S+B(*;7-G<W1R(")$=2!FY7(@:6YT92!S:V%P82!M
M97(@Y&X@)60@;6%P<"AA<BDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M9F]L9&5R<RYJ<SHQ,S<*(SH@=&5M<&QA=&5S+V9O;&1E<G,O=F9O;&1E<E]J
M879A<V-R:7!T+FEN8SHY.0HC.B!T96UP;&%T97,O9F]L9&5R<R]J879A<V-R
M:7!T+FEN8SHQ,C<*;7-G:60@(EEO=2!A<F4@<F5N86UI;F<@=&AE(&9O;&1E
M<CH@(@IM<V=S='(@(D1U(&3V<&5R(&]M(&UA<'!E;CH@(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,U"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=2!C86X@=7-E('1H92!F;VQL;W=I;F<@<&QA8V5H;VQD97)S
M(&EN('1H92!S=&%T:6]N97)Y('1E>'0Z("5C(&9O<B!T:&4@(@HB8W5R<F5N
M="!M97-S86=E(&-O;G1E;G0[("5S(&9O<B!T:&4@<VEG;F%T=7)E+B(*;7-G
M<W1R("(B"B)$=2!K86X@86YVY&YD82!F]FQJ86YD92!M86MR;VX@:2!M86QL
M=&5X=&5N.B`E8R!F]G(@;65D9&5L86YD96EN;F5HY6QL970[("5S("(*(F;V
M<B!S:6=N871U<F5N+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@8V%N;F]T('5N<W5B<V-R:6)E(&9R;VT@7"(E
M<UPB+B(*;7-G<W1R(")$=2!K86X@:6YT92!A=G-L=71A(&1I;B!P<F5N=6UE
M<F%T:6]N('#E(%PB)7-<(BXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T
M;W-?86=R965M96YT+G!H<#HS-`IM<V=I9"`B(@HB66]U(&1I9"!N;W0@86=R
M964@=&\@=&AE(%1E<FUS(&]F(%-E<G9I8V4@86=R965M96YT+"!S;R!Y;W4@
M=V5R92!N;W0@86QL;W=E9"`B"B)T;R!L;V=I;BXB"FUS9W-T<B`B169T97)S
M;VT@9'4@:6YT92!G;V1KY&YT(&%N=N1N9&YI;F=S=FEL;&MO<F5N(&;E<B!D
M=2!I;G1E(&QO9V=A(&EN+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ
M-S`*;7-G:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG
M92!A8V-E<W,@=&\@=&AI<R!F;VQD97(B"FUS9W-T<B`B1'4@:&%R(&EN=&4@
M<N1T="!A='0@Y&YD<F$@<N1T=&EG:&5T97(@9O9R(&1E;FYA(&UA<'`B"@HC
M.B!L:6(O36%I;&QO9RYP:'`Z,3,P"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!F;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W
M:6YG(')E8VEP:65N=',Z("5S+B(*;7-G<W1R(")$=2!V:61A<F)E9F]R9')A
M9&4@;65D9&5L86YD970@)25S('1I;&P@9O9L:F%N9&4@;6]T=&%G87)E.B`E
M<RXB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A;&5R="YI;F,Z,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@:&%V92`E<R!N97<@;65S<V%G97,N(@IM<V=S
M='(@(D1U(&AA<B`E<R!N>6$@;65D9&5L86YD96XN(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H879E(#$@;F5W(&UE
M<W-A9V4N(@IM<V=S='(@(D1U(&AA<B`Q(&YY='0@;65D9&5L86YD92XB"@HC
M.B!C;VUP;W-E+G!H<#HT.#(*;7-G:60@(EEO=2!H879E(&%L<F5A9'D@<W5B
M;6ET=&5D('1H:7,@<&%G92XB"FUS9W-T<B`B1'4@:&%R('-E9&%N('-K:6-K
M870@<VED86XO9F]R;75LY')E="XB"@HC.B!L:6(O24U0+G!H<#HQ,#4R"FUS
M9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E
M<CHB"FUS9W-T<B`B1'4@:&%R(&YY82!M961D96QA;F1E;B!M87!P96XZ(@H*
M(SH@;&EB+TE-4"YP:'`Z,3`U-PIM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@
M:6X@=&AE(&9O;&QO=VEN9R!F;VQD97)S.B(*;7-G<W1R(")$=2!H87(@;GEA
M(&UE9&1E;&%N9&5N(&D@9O9L:F%N9&4@;6%P<&%R.B(*"B,Z('1E;7!L871E
M<R]F;VQD97)S+W9F;VQD97)?:F%V87-C<FEP="YI;F,Z-3(*;7-G:60@(EEO
M=2!M87D@;VYL>2!E9&ET(#$@9F]L9&5R(&%T(&$@=&EM92XB"FUS9W-T<B`B
M1'4@:V%N(&)A<F$@<F5D:6=E<F$@96X@;6%P<"#E="!GY6YG96XN(@H*(SH@
M8V]M<&]S92YP:'`Z,34S"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S
M="!O;F4@<F5C:7!I96YT+B(*;7-G<W1R(")6Y&QJ(&UI;G-T(&5N(&UO='1A
M9V%R92XB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,#8*;7-G:60@
M(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%!'
M4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G92(*;7-G<W1R("(B
M"B)$=2!MY7-T92!A;F=E(&SV<V5N;W)D(&;V<B!D:6X@<')I=F%T82!01U`M
M;GEC:V5L(&;V<B!A='0@:W5N;F$@=FES82!D970@:.1R("(*(FUE9&1E;&%N
M9&5T+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C4T"FUS9VED
M("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3
M+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS
M9W-T<B`B(@HB1'4@;>5S=&4@86YG92!L]G-E;F]R9"!F]G(@9&EN('!R:79A
M=&$@4R]-24U%+6YY8VME;"!F]G(@871T(&MU;FYA('9I<V$@9&5T("(*(FCD
M<B!M961D96QA;F1E="XB"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R
M:7!T+FEN8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR
M,#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I
M<G-T+B(*;7-G<W1R(")6Y&QJ(&5N(&WE;&UA<'`@9O9R<W0N(@H*(SH@9F5T
M8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")!;F=E(&MO;G1O="!S
M;VT@<VMA;&P@<F%D97)A<RXB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N
M=&%C=',N:6YC.C@Q"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S
M<R!F:7)S="XB"FUS9W-T<B`B1'4@;>5S=&4@86YG92!E;B!A9')E<W,@9O9R
M<W0N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C(@
M=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`X"B,Z('1E;7!L
M871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(V,PIM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(*;7-G<W1R
M(")6Y&QJ(&UI;G-T(&5T="!M961D96QA;F1E(&;V<G-T+B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,PIM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A(')E8VEP:65N="XB"FUS9W-T<B`B5N1L:B!E;B!M;W1T86=A
M<F4N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N
M86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*;7-G<W1R(")$
M=2!MY7-T92!A:W1I=F5R82!<(B5S7"(@:2!U;F1E<FCE;&QS:6YS=.1L;&YI
M;F=A<BXB"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,X"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E
M)7,N(@IM<V=S='(@(D1U(&5F=&5R<^1N9&4@;65D9&5L86YD970@=&EL;"`E
M<R!D96X@)25S+B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N("5S
M+B(*;7-G<W1R(")$=2!S=F%R861E('#E(&UE9&1E;&%N9&5T("5S+B(*"B,Z
M(&QI8B]&;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B1'4@8FQE=B!I;G1E('!R96YU;65R
M86YT('#E(%PB)7-<(BX@4V5R=F5R;B!S=F%R861E(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-34Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E(&YO="!U
M;G-U8G-C<FEB960@9G)O;2!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60B"FUS9W-T<B`B1&EN('!R96YU;65R871I;VX@<.4@7"(E<UPB
M(&%V<VQU=&%D97,@:6YT92X@4V5R=F5R;B!S=F%R861E(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z-3$P"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U
M8V-E<W-F=6QL>2!S=6)S8W)I8F5D('1O(%PB)7-<(B(*;7-G<W1R(")0<F5N
M=6UE<F%T:6]N('#E(%PB)7-<(B!S=&%R=&%D97,N(@H*(SH@;&EB+T9O;&1E
M<BYP:'`Z-38R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E
M<W-F=6QL>2!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`B1&EN
M('!R96YU;65R871I;VX@<.4@7"(E<UPB(&%V<VQU=&%D97,N(@H*(SH@=&5M
M<&QA=&5S+W!G<"]P9W`N:6YC.CDX"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B1&ET="!N86UN(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4P"FUS
M9VED(")9;W5R(%!'4"!0=6)L:6,O4')I=F%T92!+97ES(@IM<V=S='(@(D1I
M;B!P=6)L:6MA+W!R:79A=&$@;GEC:V5L(&;V<B!01U`B"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C<Q('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M-@IM<V=I9"`B66]U<B!0<FEV871E($ME>2(*;7-G<W1R(")$:6X@<')I=F%T
M82!N>6-K96PB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW,0IM<V=I9"`B66]U<B!0=6)L:6,@2V5Y
M(@IM<V=S='(@(D1I;B!P=6)L:6MA(&YY8VME;"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-C4*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z
M(#QE;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`B1&EN(%)E<&QY+71O.B!A
M9')E<W,Z(#QE;3XH=F%L9G)I*3PO96T^(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHT.0IM<V=I9"`B66]U<B!3+TU)344@4'5B;&EC+U!R:79A
M=&4@0V5R=&EF:6-A=&5S(@IM<V=S='(@(D1I='0@<'5B;&EK82]P<FEV871A
M(&-E<G1I9FEK870@9O9R(%,O34E-12(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO86-C;W5N=%]S96QE8W0N:6YC.C$V"FUS9VED(")9;W5R(&%C8V]U;G1S
M.B(*;7-G<W1R(")$:6YA(&MO;G1O;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M
M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I
M/"]E;3XB"FUS9W-T<B`B(@HB1&EN82!A;&EA<V%D<F5S<V5R.B`\96T^*&5J
M(&]B;&EG871O<FES:W0L('-K<FEV('9A<FIE(&%D<F5S<R!PY2!E;B!N>5QN
M(@HB<F%D*3PO96T^(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M,3`Q"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;FQI
M;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(@IM<V=S='(@(D1I;B!W
M96)LY'-A<F4@<W3V9&IE<B!I;G1E(&EN;&EN92UV:7-N:6YG(&%V(&1E;B!H
MY'(@8FEL9'1Y<&5N+B(*"B,Z('1E;7!L871E<R]M97-S86=E+W!R:6YT+FEN
M8SHR-PIM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T
M;R`B"B)P<FEN="XB"FUS9W-T<B`B(@HB1&EN('=E8FSD<V%R92!S=/9D:F5R
M(&EN=&4@=71S:W)I9G1S9G5N:W1I;VYE;BX@5')Y8VL@8V]N=')O;"]O<'1I
M;VX@*R!0(&;V<B`B"B)A='0@<VMR:79A('5T+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,SD*;7-G:60@(EEO=7(@9&5F875L="!C:&%R<V5T(&9O
M<B!S96YD:6YG(&UE<W-A9V5S.B(*;7-G<W1R(")3=&%N9&%R9'1E>'1K;V1N
M:6YG(&[D<B!D=2!S:VEC:V%R(&UE9&1E;&%N9&5N.B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U
M;'0@96YC<GEP=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM
M<V=S='(@(E-T86YD87)D;65T;V0@9O9R(&MR>7!T97)I;F<@;N1R(&1U('-K
M:6-K87(@;65D9&5L86YD96XZ(@H*(SH@871T86-H;65N="YP:'`Z.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!L:6YK960@871T86-H;65N="!H
M87,@8F5E;B!D;W=N;&]A9&5D(&)Y(&%T(&QE87-T(&]N92!U<V5R+EQN(@HB
M7&XB"B)!='1A8VAM96YT(&YA;64Z("5S7&XB"B)!='1A8VAM96YT(&1A=&4Z
M("5S7&XB"B)<;B(*(D-L:6-K(&]N('1H92!F;VQL;W=I;F<@;&EN:R!T;R!P
M97)M86YE;G1L>2!D96QE=&4@=&AE(&%T=&%C:&UE;G0Z7&XB"B(E<R(*;7-G
M<W1R("(B"B)$92!LY&YK861E(&)I9F]G861E(&1O:W5M96YT96X@:&%R(&QA
M9&1A=',@;F5D(&%V(.5T;6EN<W1O;F4@96X@86YVY&YD87)E+EQN(@HB7&XB
M"B).86UN.B`E<UQN(@HB1&%T=6TZ("5S7&XB"B)<;B(*(DML:6-K82!PY2!L
MY&YK96X@9O9R(&%T="!R861E<F$@9&4@8FEF;V=A9&4@9&]K=6UE;G1E;CI<
M;B(*(B5S(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*;7-G
M:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB
M"FUS9W-T<B`B365D9&5L86YD970@;&5V97)E<F%D97,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P-@IM<V=I9"`B66]U<B!S:6=N871U<F4Z(@IM
M<V=S='(@(D1I;B!S:6=N871U<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]A9&1R97-S97-";&]C:W,N:G,Z-PIM<V=I9"`B6TAI9&4@061D<F5S<V5S
M72(*;7-G<W1R(");1_9M(&%D<F5S<V5R72(*"B,Z(&UE<W-A9V4N<&AP.C(Y
M-B!C;VUP;W-E+G!H<#HQ,S`Q(&UA:6QB;W@N<&AP.C4S-B!L:6(O0V]M<&]S
M92YP:'`Z.#,X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6TEN9V5T
M(.1R96YD95TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-"
M;&]C:W,N:G,Z.`IM<V=I9"`B6U-H;W<@061D<F5S<V5S("TB"FUS9W-T<B`B
M6U9I<V$@861R97-S97(@+2(*"B,Z(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!A9&1R97-S97,@+2`E<R!R
M96-I<&EE;G1S72(*;7-G<W1R(");5FES82!A9')E<W-E<B`M("5S(&UO='1A
M9V%R95TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR,#4*
M;7-G:60@(E]"8V,B"FUS9W-T<B`B7T)C8R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHQ-@IM<V=I9"`B7T)L86-K;&ES="(*;7-G<W1R(")?4W#D
M<G)A(&%D<F5S<R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C$U-`IM<V=I9"`B7T-C(@IM<V=S='(@(E]#8R(*"B,Z('1E;7!L871E<R]M
M96YU+VUE;G4N:6YC.C,Q"FUS9VED(")?0V]M<&]S92(*;7-G<W1R(")?4VMR
M:78@;65D9&5L86YD92(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8SHV('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3`*;7-G:60@(E]$
M96QE=&4B"FUS9W-T<B`B7U)A9&5R82(*"B,Z('1E;7!L871E<R]M96YU+VUE
M;G4N:6YC.C,S(&QI8B])35`N<&AP.CDU-0IM<V=I9"`B7T9O;&1E<G,B"FUS
M9W-T<B`B7TUA<'!A<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C@Q"FUS9VED(")?261E;G1I='DB"FUS9W-T<B`B7TED96YT:71E="(*
M"B,Z('1E;7!L871E<R]M96YU+VUE;G4N:6YC.C(T(&QI8B])35`N<&AP.CDR
M-`IM<V=I9"`B7TEN8F]X(@IM<V=S='(@(E]);FMO<F<B"@HC.B!T96UP;&%T
M97,O;65N=2]M96YU+FEN8SHX,R!L:6(O24U0+G!H<#HY.38*;7-G:60@(E],
M;V<@;W5T(@IM<V=S='(@(E],;V=G82!U="(*"B,Z(&UE<W-A9V4N<&AP.C,Y
M,@IM<V=I9"`B7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(E]-961D96QA;F1E
M:^1L;&$B"@HC.B!L:6(O24U0+G!H<#HY-3(*;7-G:60@(E].97<@365S<V%G
M92(*;7-G<W1R(")?3GET="!M961D96QA;F1E(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")?4')I;G0B"FUS
M9W-T<B`B7U5T<VMR:69T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C<R('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(X.0IM
M<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(E]0<FEO<FET970B"@HC.B!M86EL
M8F]X+G!H<#HT,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B7U)E9G)E<V@@)7,B
M"FUS9W-T<B`B7T;V<FYY82`E<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")?4F5P;'DB"FUS9W-T<B`B7U-V
M87)A(@H*(SH@=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z,S4@;&EB+TE-4"YP
M:'`Z.34W"FUS9VED(")?4V5A<F-H(@IM<V=S='(@(E]3]FLB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,C@*;7-G:60@(E]396YD($UE<W-A9V4B"FUS9W-T
M<B`B7U-K:6-K82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A
M9&5R<RYI;F,Z,S(*;7-G:60@(E]4:')E860B"FUS9W-T<B`B7U1RY60B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ,38*;7-G:60@(E]4
M;R(*;7-G<W1R(")?5&EL;"(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C$S"FUS9VED(")?56YD96QE=&4B"FUS9W-T<B`BQ71E<G1A(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS
M9VED(")?5FEE=R!4:')E860B"FUS9W-T<B`B7U9I<V$@='+E9"(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR-"!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ.0IM<V=I9"`B7U=H:71E;&ES="(*
M;7-G<W1R(")?0F5T<F]D9&$@861R97-S97(B"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z,3<U"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")O:^1N
M9"!M;W1T86=A<F4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#4Q"FUS9VED(")A
M='1A8VAM96YT(@IM<V=S='(@(F)I;&%G82(*"B,Z('9I97<N<&AP.CDW"FUS
M9VED(")A='1A8VAM96YT<RYZ:7`B"FUS9W-T<B`B8FEL86=O<BYZ:7`B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#<*;7-G:60@(F)Y
M=&5S(@IM<V=S='(@(G1E8VME;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3D*
M;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B2V%N
M(&EN=&4@<VMA<&$@=71F:6PB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<Q"FUS
M9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")K86X@:6YT92#V<'!N
M82!I;F1A=&$B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38S"FUS9VED(")C;VUM
M86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B:V]M;6%N9&]R861S9F5L
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q.0IM<V=I9"`B8V]N9FEG=7)A=&EO
M;B!E<G)O<B(*;7-G<W1R(")K;VYF:6=U<F%T:6]N<V9E;"(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.34*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI
M<W-I;F<B"FUS9W-T<B`B:W)I=&ES:R!S>7-T96UF:6P@<V%K;F%S(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$V-PIM<V=I9"`B9&%T82!F;W)M870@97)R;W(B
M"FUS9W-T<B`B9F]R;6%T9F5L(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(R,PIM
M<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(G!O<W0@<V%K;F%S+B(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DP"FUS9VED
M(")F<F]M(@IM<V=S='(@(F9RY6XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3<Y
M"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R(")O:^1N9"!VY')D
M9&%T;W(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`S"FUS9VED(")I;G!U="]O
M=71P=70@97)R;W(B"FUS9W-T<B`B8F5A<F)E=&YI;F=S9F5L(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C$X-PIM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R
M;W(B"FUS9W-T<B`B26YT97)N="!M:G5K=F%R=69E;"(*"B,Z('-M:6UE+G!H
M<#HR.2!P9W`N<&AP.C8X"FUS9VED(")K97DB"FUS9W-T<B`B;GEC:V5L(@H*
M(SH@9F]L9&5R<RYP:'`Z,30U"FUS9VED(")M86EL8F]X(&9I;&4B"FUS9W-T
M<B`B8G)E=FSE9&5F:6PB"@HC.B!C;VUP;W-E+G!H<#HQ,3`U(&QI8B]-97-S
M86=E+G!H<#HU,34*;7-G:60@(FYA;64B"FUS9W-T<B`B;F%M;B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHW-@IM<V=I9"`B;F]N92(*
M;7-G<W1R(")I;F=E;B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N
M=%]S96QE8W0N:6YC.C(U"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHQ,#4*;7-G:60@(F]R(@IM<V=S='(@(F5L;&5R(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C(Q-0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T
M<B`BY71K;VUS="!N96MA9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V%D
M9')E<W-E<T)L;V-K<RYJ<SHX"FUS9VED(")R96-I<&EE;G1S72(*;7-G<W1R
M(")M;W1T86=A<F5=(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q,0IM<V=I9"`B
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(G!R;W1O:V]L;&9E
M;"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#,*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B<V5R=FEC92!E:B!T:6QL9^1N9VQI9R(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E
M;&QI;F<@97)R;W(B"FUS9W-T<B`B<W1A=F9E;"(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W)S
M(@IM<V=S='(@(G-T879F96PB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DQ"FUS
M9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B<WES=&5M9F5L(@H*(SH@;&EB
M+T-O;7!O<V4N<&AP.C(P-PIM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS
M9W-T<B`B=&EL;&;D;&QI9W0@9F5L(@H*(SH@;&EB+T9I;'1E<BYP:'`Z-SD*
M;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM<V=S='(@(F1I;F$@<W#D<G)A9&4@
M861R97-S97(B"@HC.B!L:6(O1FEL=&5R+G!H<#HX.0IM<V=I9"`B>6]U<B!W
M:&ET96QI<W0B"FUS9W-T<B`B9&EN82!B971R;V1D82!A9')E<W-E<B(*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM
M<"]P;R]T<E]44BYP;P``````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`T,34T-S$`,3`T,3<S-C(W-C8`,#$W,C,V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@5'5R:VES:"!T
M<F%N<VQA=&EO;G,@9F]R($E-4"!P86-K86=E"B,@24U0('!A:V5T:2!IYVEN
M(%3\<FOG92#'979I<FEL97(N"B,@0V]P>7)I9VAT("A#*2`R,#`U($AO<F1E
M(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@24U0('!A8VMA9V4N"B,@1V5N97)A=&5D
M(&)Y"B,@4V5R=F5T($?\;F5Y(#QS9W5N97E`;65T=2YE9'4N='(^"B,@06AM
M970@UGIT_')K(#QO86AM971`;65T=2YE9'4N='(^"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($EM<"TT+C`N,UQN(@HB4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#4M,#8M,C@@,30Z-#@K,#,P,%QN(@HB3&%S
M="U4<F%N<VQA=&]R.B!!=71O;6%T:6-A;&QY(&=E;F5R871E9%QN(@HB3&%N
M9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R
M<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]25-/+3@X-3DM.5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STQ.R!P;'5R86P],#M<
M;B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3@*(RP@9G5Z>GD*;7-G:60@(B`@
M("`@($-C.B`B"FUS9W-T<B`B("`@2VEM93H@(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C0Q-0IM<V=I9"`B("`@("`@5&\Z("(*;7-G<W1R("(@("!+:6UE.B`B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@1&%T93H@(@IM
M<V=S='(@(B`@5&%R:6@Z("(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#8*;7-G
M:60@(B`@("!&<F]M.B`B"FUS9W-T<B`B($MI;61E;CH@("(*"B,Z(&UA:6QB
M;W@N<&AP.C0R,B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(H17)I
M_FEM($%N86AT87+]("5S*2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,3(*;7-G
M:60@(B!3=6)J96-T.B`B"FUS9W-T<B`B("`@2V]N=3H@(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<P"FUS9VED("(@:6X@(@IM<V=S
M='(@(B`M/B`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E
M<G,N:6YC.C$R"FUS9VED("(C(@IM<V=S='(@(B,B"@HC.B!L:6(O0FQO8VLO
M<W5M;6%R>2YP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"("\@
M)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@+R`E+C)F34(@("@E
M+C)F)24I(@H*(SH@=&AR96%D+G!H<#HQ-3$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5D($UE<W-A9V5S(@IM<V=S='(@(MUL971I(%EO:R(*"B,Z
M(&UA:6QB;W@N<&AP.C$W-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M)60@;65S<V%G97,@:&%V92!B965N(&1E;&5T960N(@IM<V=S='(@(B5D(&EL
M971I('-I;&EN9&DN(@H*(SH@;&EB+U-P86TN<&AP.C$W.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HB)60@:6QE=&EN:6X@:7-T96YM97EE;B!I;&5T:2!O;&UA9/WP
M_2!S:7-T96T@>?9N971I8VES:6YE(')A<&]R(&5D:6QD:2XB"@HC.B!L:6(O
M4W!A;2YP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S
M(&AA=F4@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS9W-T<B`B)60@
M:6QE=&EN:6X@:7-T96YM97EE;B!I;&5T:2!O;&UA9/WP_2!R87!O<B!E9&EL
M9&DN(@H*(SH@;&EB+U-P86TN<&AP.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y
M;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(E9"!I;&5T:6YI
M;B!I<W1E;FUE>65N(&EL971I(&]L9'7P=2!S:7-T96T@>?9N971I8VES:6YE
M(')A<&]R(&5D:6QD:2XB"@HC.B!L:6(O4W!A;2YP:'`Z,34P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@8F5E;B!R97!O<G1E9"!A
M<R!S<&%M+B(*;7-G<W1R("(E9"!I;&5T:6YI;B!I<W1E;FUE>65N(&EL971I
M(&]L9'7P=2!R87!O<B!E9&EL9&DN(@H*(SH@;6%I;&)O>"YP:'`Z,S<S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D('1O("5D(&]F("5D($UE<W-A9V5S(@IM
M<V=S='(@(B5D("T@)60@+R`E9"!I;&5T:2(*"B,Z(&UA:6QB;W@N<&AP.C8T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*
M"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT
M:&QY+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X
M:7-T<RX@66]U<B`E<R!F;VQD97(@=V%S(&YO="!R96YA;65D+B(*;7-G<W1R
M("(E<R!Z871E;B!V87(N($1I>FEN:6YI>B`E<R!Y96YI9&5N(&%D;&%N9/UR
M_6QA;6%D_2XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA
M:6QB;W@N(@IM<V=S='(@(B5S(&=EYV5R;&D@8FER('!O<W1A(&MU='5S=2!D
M9?!I;"XB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA
M:6Q?;6]N=&AL>2YP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@9F]L
M9&5R(&)E:6YG(')E;F%M960@870@=&AE('-T87)T(&]F('1H92!M;VYT:"XB
M"FUS9W-T<B`B)7,@9&EZ:6X@87D@8F'^_6YD82!Y96YI9&5N(&%D;&%N9/UR
M_6QD_2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C4V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&AA<R!A8V-E<'1E9"XB"FUS9W-T<B`B)7,@
M;VYA>6QA;F3](@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@8V%N8V5L;&5D("5S+B(*;7-G
M<W1R("(E<R!V87IG9>=T:3H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@9&5C;&EN
M960N(@IM<V=S='(@(B5S(')E9&1E9&EL9&DN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@
M<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R("(E<R!S
M97)B97-T+VUE_F=U;"!I<W1E\&D@>6%N_71L863]+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HV,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@
M(B5S("5S(&1A=F5T:6YI('EA;OUT;&%D_2XB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-#@R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!S
M96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S('-I
M>F4@<V5R8F5S="]M9?YG=6P@8FEL9VD@9_9N9&5R9&DN("(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HR-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S('1E;G1A=&EV96QY(&%C8V5P=&5D+B(*;7-G<W1R("(E<R!G9>=I
M8VD@;VQA<F%K(&]N87EL86YD:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U
M<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S('-E<F)E<W0O
M;67^9W5L(&)I;&=I;FEZ:2!I<W1E9&DN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T
M<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(E<R`E<R!D92!B=6QU
M;FUA;OUZ_2!I<W1E9&DN(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C0Q-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!<(B5S7"(N(@IM<V=S='(@(B5S(&)A_F%R_7EL82!E:VQE;F1I
M.B5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%M;65N9"`E<RXB"FUS9W-T
M<B`B)7,@)7,@9&7P:?YI;6EN:2!I<W1E;65K=&5D:7(N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B5S
M("5S(&MO;G5S=6YD82!H86)E<F1A<B!O;&UA;OUZ_2!I<W1E;65K=&5D:7(N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN
M9F]R;6%T:6]N(&%B;W5T("5S+B(*;7-G<W1R("(E<R`E<R!H86MK_6YD82!S
M;VX@:&%B97)L97)I(&%L;6%N_7K](&ES=&5M96MT961I<BXB"@HC.B!M97-S
M86=E+G!H<#HR.#4@;65S<V%G92YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?=&]P+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,@*"5D)FYB<W`[;V8F;F)S<#LE9"DB"FUS9W-T<B`B)7,Z("5S("@E
M9"9N8G-P.R\F;F)S<#LE9"DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3,S"FUS9VED("(H07!P;'D@=&AE<V4@8VAA;F=E<R!A;F0@
M;6]V92!T;R!N97AT('-C<F5E;BXI(@IM<V=S='(@(BA$9?!I_FEK;&EK;&5R
M:2!U>6=U;&%Y_6X@=F4@8FER('-O;G)A:VD@96MR86YA(&=EYVEN+BDB"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED("(H
M1&ES8V%R9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E
M('-C<F5E;BXI(@IM<V=S='(@(BA$9?!I_FEK;&EK;&5R:2!Y;VMS87D@=F4@
M3VQU_G1U<FUA(&5K<F%N_6YA(&=E<FD@9/9N+BDB"@HC.B!T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(BA(5$U,
M*2(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB"FUS9W-T<B`B(@H*(SH@
M<W!E;&QI;F<N<&AP.C(X,`IM<V=I9"`B(@HB*%)E='5R;B!T;R!T:&4@8V]M
M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D92!T
M:'5S(&9A<BX@("(*(D-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I
M;&P@3D]4(&)E(&%P<&QI960N*2(*;7-G<W1R("(B"B(HWG4@86YA(&MA9&%R
M('EA</UL86X@9&7P:?YI:VQI:VQE<FD@=7EG=6QA('9E($]L=?YT=7)M82!E
M:W)A;OUN82!G97)I(&3V;BX@(@HB0G4@96MR86YD86MI(&1E\&G^:6ML:6QE
M<B!564=53$%.34%904-!2RXI(@H*(SH@<W!E;&QI;F<N<&AP.C(W-PIM<V=I
M9"`B(@HB*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E
M<R!M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N="!S
M8W)E96X@=VEL;"!.3U0@8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(BC>=2!A
M;F$@:V%D87(@>6%P_6QA;B!D9?!I_FEK;&5R:2!U>6=U;&$@=F4@:6QE=&EY
M:2!G]FYD97(N($)U(&5K<F%N9&$@;VQA;B`B"B)D9?!I_FEK;&EK;&5R(%59
M1U5,04Y-05E!0T%++BDB"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C
M=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@
M*B(*;7-G<W1R("(J($5V971E(&)A<V%R86L@96ML97EI;B`J(@H*(SH@=&5M
M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,#8*;7-G:60@(BH@4&QE
M87-E('-E;&5C="!A9&1R97-S*&5S*2`J(@IM<V=S='(@(BH@3/QT9F5N(&%D
M<F5S('-EYVEN("HB"@HC.B!M86EL8F]X+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G
M:60@(C$@;65S<V%G92!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+=;&5T
M:2!S:6QI;F1I+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ.#`*;7-G:60@(C$@;65S
M<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2!T;R!Y;W5R('-Y
M<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B(Q(&EL971I;FEN(&ES
M=&5N;65Y96X@:6QE=&D@;VQM863]\/T@<VES=&5M('GV;F5T:6-I;FEZ92!R
M87!O<B!E9&EL;6G^=&ER+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ-C`*;7-G:60@
M(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB"FUS
M9W-T<B`B,2!I;&5T:6YI;B!I<W1E;FUE>65N(&EL971I(&]L;6%D_?#](')A
M<&]R(&5D:6QM:?YT:7(N(@H*(SH@;&EB+U-P86TN<&AP.C$W,@IM<V=I9"`B
M,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86T@=&\@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB,2!I;&5T:6YI;B!I
M<W1E;FUE>65N(&EL971I(&]L9'7P=2!S:7-T96T@>?9N971I8VEN:7IE(')A
M<&]R(&5D:6QM:?YT:7(N(@H*(SH@;&EB+U-P86TN<&AP.C$U,@IM<V=I9"`B
M,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@
M(C$@:6QE=&EN:6X@:7-T96YM97EE;B!I;&5T:2!O;&1U\'4@<F%P;W(@961I
M;&UI_G1I<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Y"FUS9VED
M("(Q,#`@8VAA<F%C=&5R<R(*;7-G<W1R("(Q,#`@:V%R86MT97(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(R"FUS9VED("(Q,#`P(&-H87)A8W1E
M<G,B"FUS9W-T<B`B,3`P,"!K87)A:W1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,C`*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(C(U
M,"!K87)A:W1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C$*;7-G
M:60@(C4P,"!C:&%R86-T97)S(@IM<V=S='(@(C4P,"!K87)A:W1E<B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D("5S(&ES(&%T=&%C:&5D('1O
M('1H:7,@;65S<V%G92XB"FUS9W-T<B`B)7,@863];F1A(&+\>?QK(&?V<OQN
M=/P@9&]S>6%S_2!B=2!I;&5T:7EE(&5K;&5N9&DN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*(D$@;65S<V%G
M92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E='5R;B!N;W1I
M9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G<W1R(")']FYD
M97)D:?!I;FEZ(&EL971I(&%L_6/]9&%N(&)I<B!D;_!R=6QA;6%N_6X@9V5L
M;65S:2!I;&4@<V]N=>=L86YD_2XB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I
M96QD<RYI;F,Z-0IM<V=I9"`B04Y$(@IM<V=S='(@(E9%(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4Y,`IM<V=I9"`B06-C97!T(')E<75E<W0B
M"FUS9W-T<B`BW7-T9?!I(&]N87EL82(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU.#<*(RP@9G5Z>GD*;7-G:60@(D%C8V5P="!R97%U97-T(&%N
M9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B3VQA>2!T86MV:6UI
M;FEZ92!E:VQE;F1I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW
M-3,*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(D]N87EL86YD_2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-3<*;7-G:60@(D%C8V5P=&5D.B`B
M"FUS9W-T<B`B3VYA>6QA;F3].B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO
M;6%N86=E+FEN8SHW"FUS9VED(")!8V-O=6YT)W,@;F%M93HB"FUS9W-T<B`B
M2&5S87`@W7-M:3HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(P
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S`*;7-G:60@(D%C=&EO;G,B
M"FUS9W-T<B`B17EL96UL97(B"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR
M,#`@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C`Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@)7,@=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@
M(D%D<F5S(&1E9G1E<FEN92`H)7,I(&5K;&4B"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,#,*;7-G:60@(D%D9"!S;W5R8V4B"FUS
M9W-T<B`B2V%Y;F%K($5K;&4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#@*;7-G:60@(D%D
M9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(D)U;G4@=&%K=FEM:6UE
M($5K;&4B"@HC.B!C;VUP;W-E+G!H<#HQ,C4V"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R(")<
M(B5S7"(@96L@;VQA<F%K(&5K;&5N9&DN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D
M97)S('1O(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E
M;G1E<B!E86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S
M='(@(B(*(D?V<OQN=/QL96YE8V5K(&EL879E(&)A_FS]:VQA<CH@/&D^("AS
M9>=I;6QI+"!H97)B:7(@8F'^;/WP_2!Y96YI(&)I<B`B"B)S873]<F1A(&=I
M<FEN+BD\+VD^(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP
M:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA
M=&EO;B!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("+=;&%V92!B:6QG:2`E
M<R!G]G+\;&5B:6QI<BXB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T
M:6]N+G!H<#HV,@IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO;B!D971A
M:6QS(@IM<V=S='(@(MUL879E(&)I;&=I(&%Y<OUN=/UL87+](@H*(SH@;&EB
M+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3,*;7-G:60@(D%D9&ET:6]N86P@
M;65S<V%G92!D971A:6QS(@IM<V=S='(@(MUL879E(&EL971I(&%Y<OUN=/UL
M87+](@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!M97-S86=E(&1E=&%I;',@8V%N
M(&)E('9I97=E9"`E<RXB"FUS9W-T<B`BW6QA=F4@:6QE=&D@87ER_6YT_6QA
M<OT@)7,@9_9R_&QE8FEL:7(N(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S<V%G92!E<G)O<B!D971A
M:6QS(@IM<V=S='(@(MUL879E(&EL971I(&AA=&$@87ER_6YT_6QA<OTB"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@
M8F4@=FEE=V5D("5S+B(*;7-G<W1R("+=;&%V92!I;&5T:2!H871A(&%Y<OUN
M=/UL87+]("5S(&?V<OQN=/QL96YE8FEL:7(N(@H*(SH@8V]N=&%C=',N<&AP
M.C@U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@P"B,Z('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,S.2!T96UP;&%T97,O8V]M
M<&]S92]R961I<F5C="YI;F,Z-3(*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R(")!9')E<R!$969T97)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-`IM<V=I9"`B061D<F5S<R!";V]K<R(*;7-G<W1R(")!9')E<R!$969T
M97)L97)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X.0HC+"!F=7IZ
M>0IM<V=I9"`B(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE
M;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L
M:6YE*3PO96T^(@IM<V=S='(@(B(*(D+\=/QN(&EL971I;&5R:6X@1VEZ;&D@
M2RY++B!G]FYD97)I;&5C9?!I(&%D<F5S;&5R.B`\:3XH<V7G:6UL:2P@:&5R
M8FER("(*(F%D<F5S:2!Y96YI('-A=/UR9&$@9VER:6XN*3PO:3XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@Q"B,L(&9U>GIY"FUS9VED("(B"B)!
M9&1R97-S97,@=&\@97AP;&EC:71L>2!T:64@=&\@=&AI<R!I9&5N=&ET>3H@
M/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"`B"B)A9&1R97-S(&]N(&$@;F5W
M(&QI;F4I/"]E;3XB"FUS9W-T<B`B(@HB061R97-L97(@8>?]:V-A(&)U(&MI
M;6QI\&4@8F'P;&%N86-A:SH@/&D^*'-EYVEM;&DL:&5R8FER(&%D<F5S:2!Y
M96YI("(*(G-A=/UR9&$@9VER:6XN*3PO:3XB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C,*
M;7-G:60@(D%L;"(*;7-G<W1R(")4_&W\(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9F]L9&5R<RYJ<SHQ,PIM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN
M('1H92!F;VQL;W=I;F<@9F]L9&5R*',I('=I;&P@8F4@9&]W;FQO861E9"!I
M;G1O(&]N92!-0D]8("(*(F9I;&4Z(@IM<V=S='(@(D1I>FEN*&QE<BED96MI
M(&+\=/QN(&EL971I;&5R(&)I<B!T86YE($U"3U@@9&]S>6%S:6YA(&EN9&ER
M:6QE8V5K=&ER.B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R
M87-H+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S<V%G
M97,@:6X@>6]U<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W
M:6QL(&)E('!E<FUA;F5N=&QY("(*(F1E;&5T960N(@IM<V=S='(@(B(*(EPB
M)7-<(B!D:7II;FEN9&5K:2`E<R!G_&YD96X@9&%H82!E<VMI(&]L86X@8OQT
M_&X@:6QE=&EL97(@:V%L_6/](&]L87)A:R`B"B)S:6QI;F5C96MT:7(N(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO
M;G1H;'DN<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O;&0@;&EN
M:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@
M8F4@9&5L971E9"XB"FUS9W-T<B`B)7,@87ED86X@9&%H82!E<VMI(&]L86X@
M8OQT_&X@97-K:2!B8?!L_2!E:VQE<B!S:6QI;F5C96MT:7(N("(*"B,Z(&QI
M8B]-86EN=&5N86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H
M<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@;VQD('-E;G0M;6%I;"!F
M;VQD97)S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E
M9"XB"FUS9W-T<B`B)7,@87ED86X@9&%H82!E<VMI(&]L86X@8OQT_&X@9_9N
M9&5R:6QM:?X@<&]S=&$@9&EZ:6YL97)I('-I;&EN96-E:RXB"@HC.B!A8VPN
M<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!;&P@<FEG:'1S
M(&]N(&9O;&1E<B!<(B5S7"(@<W5C8V5S<V9U;&QY(')E;6]V960@9F]R('5S
M97(@7"(E<UPB+B(*;7-G<W1R("(B"B(G)7,G(&1I>FEN:6YD96MI(&+\=/QN
M(&AA:VQA<B`E<R!K=6QL86[]8_US_2!IYVEN(&)A_F%R_7EL82!K86QD_7+]
M;&W]_G3]<BXB"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I9"`B06QL;W<@1F]L
M9&5R($-R96%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z-#@*;7-G:60@(D%L;&]W(&9I;'1E<B!R=6QE<R!T;R!B
M92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/R(*;7-G<W1R(")3_'IG9><@:W5R
M86QL87+](&AE<FAA;F=I(&)I<B!P;W-T82!K=71U<W5N82!U>6=U;&%N<_UN
M(&W]/R`B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q
M,`IM<V=I9"`B06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB
M"FUS9W-T<B`B0G4@8O9L_&T@:>=I;B#V=&5K:2!E:VQE<CHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3<R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M.#0*;7-G:60@(D%L=V%Y<R(*;7-G<W1R(")(97(@>F%M86XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-34W"FUS9VED(")!;'=A>7,@<V%V92!A='1A
M8VAM96YT<R(*;7-G<W1R(")(97(@>F%M86X@96ML97)I('-A:VQA(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C4P-0IM<V=I9"`B(@HB06X@97)R;W(@;V-C=7)E
M9"!W:&EL92!A='1E;7!T:6YG('1O('-T<FEP('1H92!A='1A8VAM96YT+B!4
M:&4@24U!4"!S97)V97(@(@HB<V%I9#H@(@IM<V=S='(@(D5K(.?]:V%R=/UL
M;6%Y82#G86S]_OUL_7)K96X@8FER(&AA=&$@;65Y9&%N82!G96QD:2X@24U!
M4"!S=6YU8W4Z("(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#@*(RP@9G5Z>GD*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN
M9R!T:&4@;F5W(&YO=&4N(@IM<V=S='(@(EEE;FD@9_9R978@>6%R873];/UR
M:V5N(&)I;&EN;65Y96X@8FER(&AA=&$@;65Y9&%N82!G96QD:2XB"@HC.B!L
M:6(O365S<V%G92YP:'`Z,S@W"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C
M8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+B(*;7-G<W1R(")9
M96YI(&?V<F5V('EA<F%T_6S]<FME;B!B:6QI;FUE>65N(&)I<B!H871A(&UE
M>61A;F$@9V5L9&DN(@H*(SH@;65S<V%G92YP:'`Z-3`P(&UA:6QB;W@N<&AP
M.C<Q-"!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.CD*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ."!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,U"B,Z('1E;7!L871E<R]M86EL8F]X+VQE
M9V5N9"YI;F,Z-@IM<V=I9"`B06YS=V5R960B"FUS9W-T<B`B0V5V87!L86YM
M_?XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS9VED(")!
M;G-W97)E9"!M97-S86=E<R(*;7-G<W1R(")#979A<&QA;FW]_B#=;&5T:6QE
M<B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PIM<V=I9"`B
M07!P;'D@1FEL=&5R<R(*;7-G<W1R(")3_'IG9>=L97)I(%5Y9W5L82(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!<'!L>2!&:6QT97)S('1O("5S(@IM<V=S='(@(B5S(&GG:6X@
M4_QZ9V7G;&5R:2!5>6=U;&$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z,S8*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!U<&]N(&QO9V=I
M;F<@;VX_(@IM<V=S='(@(D?\;FS\:R!K87G]=&QA<B!S_7)A<_UN9&$@<_QZ
M9V7G(&MU<F%L;&%R_2!U>6=U;&%N<_UN(&W]/R(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHT,@IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S
M('=H96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS9W-T<B`B4_QZ9V7G
M(&MU<F%L;&%R_2!'14Q%3B!+55154U4@:&5R(&?V<OQN=/QL96YD:?!I;F1E
M('5Y9W5N;&%N<_UN(&W]/R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,C4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@9&5L971E('1H:7,@<'5B;&EC(&ME>3\B"FUS
M9W-T<B`B0G4@8>?]:R!A;F%H=&%R_2!S:6QM96L@:7-T961I\&EN:7IE(&5M
M:6X@;6ES:6YI>C\B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES
M($Y/5"!R96-O;6UE;F1E9"$I(@IM<V=S='(@(B(*(D%N86AT87(@:6MI;&EN
M:7II('-I;&UE:R!I<W1E9&GP:6YI>F1E;B!E;6EN(&UI<VEN:7H_("A4879S
M:7EE("(*(D5$W4Q-14U%2U1%1-U2(2DB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z-2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FIS
M.C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(*
M;7-G<W1R(")"=6YU('EA<&UA:R!I<W1E9&GP:6YI>F1E;B!E;6EN(&UI<VEN
M:7H_(@H*(SH@;65S<V%G92YP:'`Z-#`W('1E;7!L871E<R]M86EL8F]X+VIA
M=F%S8W)I<'0N:6YC.C8X"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@4$5234%.14Y43%D@9&5L971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R
M(")"=2!I;&5T:6QE<FD@2T%,24-)(&]L87)A:R!S:6QM96L@:7-T961I\&EZ
M9&5N(&5M:6X@;6ES:6YI>C\B"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z
M,C$U"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@4$5234%.14Y4
M3%D@9&5L971E('1H:7,@871T86-H;65N=#\B"FUS9W-T<B`B0G4@96MI($M!
M3$E#22!O;&%R86L@<VEL;65K(&ES=&5D:?!I;FEZ9&5N(&5M:6X@;6ES:6YI
M>C\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R
M/R(*;7-G<W1R(")"=2!D:7II;FD@8F_^86QT;6%K(&ES=&5D:?!I;FEZ9&5N
M(&5M:6X@;6ES:6YI>C\B"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P
M86T@9F]L9&5R/R(*;7-G<W1R("+']G`@:W5T=6YU>G4@8F_^86QT;6%K(&ES
M=&5D:?!I;FEZ9&5N(&5M:6X@;6ES:6YI>C\B"@HC.B!L:6(O24U0+G!H<#HY
M-C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R
M('1R87-H(&9O;&1E<C\B"FUS9W-T<B`BQ_9P(&MU='5N=7IU(&)O_F%L=&UA
M:R!I<W1E9&GP:6YI>F1E;B!E;6EN(&UI<VEN:7H_(@H*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z.`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B
M"FUS9W-T<B`B0G4@:6QE=&EL97)I(&MA;/UC_2!O;&%R86L@<VEL;65K(&ES
M=&5D:?!I;FEZ9&5N(&5M:6X@;6ES:6YI>C\B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]J879A<V-R:7!T+FEN8SHX,"!T96UP;&%T97,O;6%I;&)O>"]J879A
M<V-R:7!T+FEN8SHW.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(')E<&]R="!T:&ES(&UE<W-A9V4@87,@:6YN;V-E;G0_(@IM<V=S='(@(D)U
M(&EL971I>6D@=&5M:7H@;VQA<F%K(')A<&]R(&5T;65K(&ES=&5D:?!I;FEZ
M9&5N(&5M:6X@;6ES:6YI>C\B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A
M<V-R:7!T+FEN8SHW-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHW-`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T
M:&ES(&UE<W-A9V4@87,@<W!A;3\B"FUS9W-T<B`B(@HB0G4@:6QE=&EY:2!I
M<W1E;FUE>65N(&EL971I(&]L87)A:R!R87!O<B!E=&UE:R!I<W1E9&GP:6YI
M>F1E;B!E;6EN(&UI<VEN:7H_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDQ-@IM<V=I9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(D=E;&G^(%IA;6%N
M_2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,S$*;7-G:60@(D%S8V5N
M9&EN9R(*;7-G<W1R(")!<G1A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,PIM<V=I9"`B07-K(@IM
M<V=S='(@(E-O<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C4Q.0IM<V=I9"`B071T86-H(@IM<V=S='(@(D5K;&4B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-S4*;7-G:60@(D%T=&%C:"!&:6QE
M<R(*;7-G<W1R(")$;W-Y82!%:VQE(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#4V"FUS9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@
M4$=0('!U8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R(")01U`@
M8>?]:R!A;F%H=&%R_6[]>B!I;&5T:6YI>F4@96ML96YS:6X@;6D_(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.0IM<V=I9"`B071T86-H960@
M1FEL93HB"FUS9W-T<B`B1&]S>6$@16ML93HB"@HC.B!L:6(O0V]M<&]S92YP
M:'`Z-#4Q(&QI8B]#;VUP;W-E+G!H<#HU,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB071T86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T86-H
M;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(@IM<V=S='(@
M(B(*(D5K;&5N;65K(&ES=&5N96X@9&]S>6$@7"(E<UPB(&5K(&)O>75T(&QI
M;6ET:6YI(&'^_7EO<BY$;W-Y82!%2TQ%3DU%645#14L@(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C,W-@IM<V=I9"`B071T86-H960@:7,@82!R
M97!L>2!T;R!A(&-A;&5N9&%R(')E<75E<W0@>6]U('-E;G0N(@IM<V=S='(@
M(D5K=&5K:2!S:7II;B!T86MV:6T@:7-T9?!I;FEZ92!Y86[]='3]<BXB"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$V('1E;7!L871E<R]C
M;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ-`HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU,#8@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N
M=',N:G,Z.3<*;7-G:60@(D%T=&%C:&UE;G0B"FUS9W-T<B`B16L@3VQA<F%K
M(@H*(SH@8V]M<&]S92YP:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS
M9VED(")!='1A8VAM96YT('-T<FEP<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT
M('1Y<&4B"FUS9W-T<B`B16L@8O9L_&YD_#H@UGIG_&X@96L@=/QR_"(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,T.2!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHT-S,*(SH@;&EB+T-O;7!O<V4N<&AP.C$P
M-S,*;7-G:60@(D%T=&%C:&UE;G1S(@IM<V=S='(@(D5K;&5R(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,@IM<V=I9"`B071T96YD965S(@IM
M<V=S='(@(DMA=/UL_6UC_6QA<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I
M9FEC871I;VXN<&AP.C4S"FUS9VED(")!='1E;G1I;VXB"FUS9W-T<B`B57EA
M<OTB"@HC.B!L:6(O075T:"]I;7`N<&AP.C0T"FUS9VED(")!=71H7VEM<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VEM<#H@1V5R96ML:2!)34%0('5Z86YT_7/](&)U;'5N86UA9/TN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T,`IM<V=I9"`B(@HB075T;VUA
M=&EC86QL>2!S:&]W(&EM86=E<R!I;B!(5$U,(&UE<W-A9V5S('=H96X@=&AE
M('-E;F1E<B!I<R!I;B!M>2`B"B)A9&1R97-S8F]O:S\B"FUS9W-T<B`B(@HB
M1_9N9&5R96X@861R97,@9&5F=&5R:6UD92!I<V4@9_9R_&YT_&QE<B!O=&]M
M871I:R!O;&%R86L@2%1-3"!I;&5T:6QE<FEN:6X@(@HB:>=I;F1E(&?V<W1E
M<FEL<VEN(&UI/R(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C(Y.`IM<V=I9"`B079A:6QA8FQE($%D9')E<W,@8F]O:W,Z(@IM<V=S
M='(@(DUE=F-U="!!9')E<R!$969T97)I.B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW,3D*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S
M='(@(EEA;OUT($)E:VQI>6]R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"86-?
M:R!T;R`E<R(*;7-G<W1R(")?1V5R:2!D]FX@)7,B"@HC.B!T:')E860N<&AP
M.C$S-R!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(V
M"B,L('!H<"UF;W)M870*;7-G:60@(D)A8VL@=&\@)7,B"FUS9W-T<B`B1V5R
M:2!D]FX@)7,B"@HC.B!T:')E860N<&AP.C$S-`IM<V=I9"`B0F%C:R!T;R!-
M=6QT:7!L92!-97-S86=E(%9I97<@26YD97@B"FUS9W-T<B`B(@H*(SH@=&AR
M96%D+G!H<#HQ,S(*;7-G:60@(D)A8VL@=&\@5&AR96%D($1I<W!L87DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0F%D(&]R(&UA;&9O<FUE9"!R97%U97-T+B!397)V97(@
M4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!M97-S86=E+G!H<#HR-C8@
M=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C(*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHR,"!L:6(O4V5A<F-H+G!H<#HS
M-`IM<V=I9"`B0F-C(@IM<V=S='(@(D=I>FQI($LN($LN(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z,38Q"FUS9VED(")"96QO=R!I<R!T:&4@
M<F%W('1E>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+B(*
M;7-G<W1R(")$=7)U;2!B:6QG:2!I;&5T:7-I;FEN(&AA;2!M971I;B!H86QI
M(&'^8?#]9&%D_7(N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")";&%C:VQI<W0B"FUS9W-T<B`B2V%R82!,:7-T92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV,CD*;7-G:60@(D)L;V-K(&EM86=E<R!I
M;B!(5$U,(&UE<W-A9V5S('5N;&5S<R!T:&5Y(&%R92!S<&5C:69I8V%L;'D@
M<F5Q=65S=&5D/R(*;7-G<W1R("(B"B+6>F5L;&EK;&4@:7-T96YM96UI_G-E
M($A434P@:6QE=&EL97)I;FEN(&GG:6YD96MI(&?V<OQN=/QL97(@96YG96QL
M96YS:6X@;6D_(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(*;7-G:60@(D)O9'DB
M"FUS9W-T<B`BW>=E<FEK(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHR,R!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C,Y"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z-34@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN
M8SHW,0IM<V=I9"`B0F]T:"(*;7-G<W1R(")(97(@W6MI<VDB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C@W"FUS9VED(")";W1H($AE861E<B!,:7-T
M:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4B"FUS9W-T<B`B0F'^;/UK($)I;&=I
M;&5R:2!V92#=;&5T:2#=YV5R:?!I;FEN(&AE<B!I:VES:61E(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R"FUS9VED(")#7VAA<G-E
M="(*;7-G<W1R(")+87)A:W1E<B!?4V5T:2(*"B,Z('1E;7!L871E<R]S96%R
M8V@O9FEE;&1S+FEN8SHS-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B5&%K
M=FEM(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A
M;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G
M<W1R(")5>F%K=&%K:2!E;&5K=')O;FEK('!O<W1A('-U;G5C=7-U;F$@8F'P
M;&%N_6QA;?UY;W(N(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ.3D*
M;7-G:60@(D-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R
M=F5R.B`B"FUS9W-T<B`B57IA:W1A:VD@96QE:W1R;VYI:R!P;W-T82!S=6YU
M8W5S=6YA(&)A\&QA;OUL86W]>6]R.B`B"@HC.B!L:6(O34E-12]6:65W97(O
M<&%R=&EA;"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V%N(&YO
M="!D:7-P;&%Y("T@9F]U;F0@;VYL>2`E<R!O9B`E<R!P87)T<R!O9B!T:&ES
M(&UE<W-A9V4@:6X@=&AE(&-U<G)E;G0@(@HB;6%I;&)O>"XB"FUS9W-T<B`B
M(@HB1_9R_&YT_&QE;F5M:7EO<B`M(-YU(&%N9&%K:2!P;W-T82!K=71U<W5N
M9&$@:6QE=&EN:6X@<V%D96-E("5S+R5S('!A<N=A<_T@(@HB8G5L=6YD=2XB
M"@HC.B!F;VQD97)S+G!H<#HR.#0@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR-34*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHR
M,2!T96UP;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z,3D*(SH@=&5M
M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C(Q('1E;7!L871E<R]S;6EM
M92]I;7!O<G1?:V5Y+FEN8SHX-@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z,3(P('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,S(*
M(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-@IM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(MUP=&%L(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-S$@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,U
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3$*;7-G:60@
M(D-A;F-E;"!-97-S86=E(@IM<V=S='(@(MUL971I9&5N(%9A>F=EYR(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES(&UE
M<W-A9V4@=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB
M"FUS9W-T<B`B(@HB0G4@:6QE=&EY:2!I<'1A;"!E=&UE:RQIYV5R:?!I;FEN
M(&MA;/UC_2!O;&%R86L@>6]K(&]L;6%S:6YA('EO;"!AYV%C86MT_7(N(@H*
M(SH@;65S<V%G92YP:'`Z,C8U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z
M,34@;&EB+U-E87)C:"YP:'`Z,S`*;7-G:60@(D-C(@IM<V=S='(@(DMA<F)O
M;B!+;W!Y82(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G
M:60@(B(*(D-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&
M:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P,0IM
M<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(D)A_FMA;B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX,`IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(D1E\&G^=&ER(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(E3\;?QN_"!$
M9?!I_G1I<B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY,@IM<V=I9"`B
M0VAA;F=E($9O;&1E<B(*;7-G<W1R(")$:7II;FD@1&7P:?YT:7(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS9VED("(B"B)#:&%N9V4@9&ES
M<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S<V%G97,@>6]U('-E
M92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M97-S86=E<R!A<F4@<V]R=&5D
M+B(*;7-G<W1R("(B"B)(97(@<V%Y9F%D82!K8><@:6QE=&D@9_9R_&YE8V7P
M:2QI;&5T:6QE<FEN(&YA<_UL('/]<F%L86YA8V'P_2!G:6)I("(*(F?V<OQN
M=/QL96UE('-EYV5N96ML97)I;FD@9&7P:?YT:7)I;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-`IM<V=I9"`B0VAA;F=E(&UA:6P@<V5R=F5R(&%N
M9"!F;VQD97(@<V5T=&EN9W,N(@IM<V=S='(@(D5L96MT<F]N:6L@<&]S=&$@
M<W5N=6-U('9E(&1I>FEN(&%Y87)L87+];OT@9&7P:?YT:7)I;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34*;7-G:60@(B(*(D-H86YG92!T:&4@
M;F%M92P@861D<F5S<RP@86YD('-I9VYA='5R92!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD("(*(G)E<&QY('1O('EO=7(@96UA:6PN(@IM
M<V=S='(@(B(*(MUN<V%N;&%R_6X@9_9N9&5R9&GP:6YI>B!E;&5K=')O;FEK
M('!O<W1A;&%R_2!O:W5R:V5N('9E(&-E=F%P;&%R:V5N("(*(F?V<F5C96ML
M97)I(&%D_6[]>OTL861R97-I;FEZ:2!V92!I;7IA;OUZ_2!D9?!I_G1I<FEN
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C0*;7-G:60@(D-H87)A
M8W1E<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B1_9R_&YT_&QE;F5C96L@2V%R
M86MT97)L97(Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,34*;7-G:60@(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T
M<B`B1&EZ:6YI(%EE;FD@4&]S=&$@:>=I;B!$96YE=&QE(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C<U"FUS9VED(")#:&5C:R!?06QL+TYO;F4B
M"FUS9W-T<B`B2&5P<VEN:2!?1&5N971L92](:>=B:7)I;FD@1&5N971L96UE
M(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C$P('1E
M;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR,0IM<V=I9"`B0VAE
M8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R
M;VTZ(@IM<V=S='(@(E!O<W1A(&%L;6%K(&ES=&5D:?!I;FEZ(&5L96MT<F]N
M:6L@<&]S=&$@<W5N=6-U;&%R_6[]('-EYVEN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0V,PIM<V=I9"`B0VAE8VL@<W!E;&QI;F<@8F5F;W)E('-E
M;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("+=;&5T:2!G]FYD97)M961E;B#V
M;F-E('EA>OUM(&1E;F5T:6UI('5Y9W5L86YS_6X@;?T_(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I9"`B0VAO;W-E($%C=&EO
M;CHB"FUS9W-T<B`BW?YL96T@4V7G(@H*(SH@8V]N9FEG+W-E<G9E<G,N<&AP
M+F1I<W0Z,3@R"FUS9VED(")#:&]O<V4@82!M86EL('-E<G9E<CHB"FUS9W-T
M<B`B16QE:W1R;VYI:R!P;W-T82!S=6YU8W4@<V7G:6XZ(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,3(U('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C$V-@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHR,3<*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A(&UA=&-H(&]R(&5D
M:70@=&AE(&%D9')E<W,@=&\@=&AE(')I9VAT.B(*;7-G<W1R("),_'1F96X@
M:W5T=6YU;B!IYVEN9&5N('-A\&$@9&_P<G4@<V7G:6T@>6%D82!D_'IE;FQE
M;64@>6%P_6XZ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,2!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S,Q"FUS9VED(")#:&]O<V4@86X@
M86-T:6]N.B(*;7-G<W1R(")%>6QE;2!S9>=I;CHB"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*;7-G:60@(D-H;V]S92!T:&4@
M861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R97-S97,N(@IM
M<V=S='(@(D%D<F5S(&5K;&5R:V5N(&MU;&QA;OUL8V%K(&%D<F5S(&1E9G1E
M<FEN:2!S9>=I;BXB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T
M+FEN8SHR.3,*;7-G:60@(D-H;V]S92!T:&4@;W)D97(@;V8@861D<F5S<R!B
M;V]K<R!T;R!S96%R8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G
M<W1R(")!9')E<VQE<FD@8>=A<FME;B!A<F%N86-A:R!A9')E<R!D969T97)I
M;FD@<V7G:6XN(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O(&-O;G9E<G0@=&AE
M(&EM86=E(&9I;&4@:6YT;R!A(&9O<FUA="!Y;W5R(&)R;W=S97(@8V%N('9I
M97<N(@IM<V=S='(@(B(*(E1A<F%Y_6/];OUZ_6X@9_9S=&5R96)I;&5C9?!I
M(&)I<B!B:>=I;64@YV5V:7)M96L@:>=I;B`E<R#\>F5R:6YE('3]:VQA>?UN
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92XB
M"FUS9W-T<B`B1_9R_&YT_"!D;W-Y87/];OT@:6YD:7)M96L@:>=I;B`E<R#\
M>F5R:6YE('3]:VQA>?UN+B(*"B,Z(&QI8B]&:6QT97(N<&AP.C$P-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M
M96YT('!A9V4N(@IM<V=S='(@(B5S('GV;F5T:6T@<V%Y9F%S_6YA(&=I=&UE
M:R!IYVEN("5S(/QZ97)I;F4@=/UK;&%Y_6XN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E
M<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=RXB
M"FUS9W-T<B`B2%1-3"!IYV5R:?!I;FD@87ER_2!B:7(@<&5N8V5R961E(&?V
M<FUE:R!IYVEN("5S(/QZ97)I;F4@=/UK;&%Y_6XN(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z,38S"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G92XB"FUS
M9W-T<B`B0G4@9_9R_&YT_&[\;B!M:6YY873\<B!H86QI;FD@9_9R;65K(&GG
M:6X@)7,@_'IE<FEN92!T_6ML87G];BXB"@HC.B!L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&EC:R`E<R!T
M;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*
M;7-G<W1R(")%:VD@87ER_2!B:7(@<&5N8V5R961E(&?V<FUE:R!IYVEN("5S
M(/QZ97)I;F4@=/UK;&%Y_6XN(@H*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T
M960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I
M97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@
M=VEN9&]W+B(*;7-G<W1R("(B"B)"=2#G;VML=2]I;&=I;&D@<&%RYV%Y_2!A
M>7+](&)I<B!P96YC97)E9&4@9_9R;65K(&GG:6X@)7,@_'IE<FEN92!T_6ML
M87G];BXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G:60@
M(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S(@IM<V=S='(@(E)E<VEM
M;&5R:2!'UE-415)-14L@:>=I;B!B=7)A>6$@=/UK;&%Y_6XB"@HC.B!T96UP
M;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,C$*;7-G:60@(B(*(D-L
M:6-K(&]N(&]N92!O9B!Y;W5R('-E;&5C=&5D(&%D9')E<W,@8F]O:W,@86YD
M('1H96X@<V5L96-T(&%L;"!F:65L9',@=&\@(@HB<V5A<F-H+B(*;7-G<W1R
M("(B"B)39>=I;&UI_B!A9')E<R!D969T97)L97)I;FEZ9&5N(&)I<FEN92!T
M_6ML87G];B!V92!B_'3\;B!A;&%N;&%R_2!A<F%M86L@(@HB:>=I;B!S9>=I
M;BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S$*;7-G:60@(D-L
M:6-K('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O
M;VLB"FUS9W-T<B`B4$=0($'G_6L@06YA:'1A<OUN_7K](&%D<F5S(&1E9G1E
M<FEN92!S86ML86UA:R!IYVEN('3]:VQA>?UN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@
M=&\@4V%V92!3+TU)344@8V5R=&EF:6-A=&4@;V8@)7,@:6X@>6]U<B!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B)7,@4R]-24U%(&]N87D@8F5L9V5S:6YI(&%D
M<F5S(&1E9G1E<FEN:7IE('-A:VQA;6%K(&GG:6X@=/UK;&%Y_6XN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,`IM<V=I9"`B0VQI8VMI;F<@;VX@
M=&AE(&%D9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE
M('-E;F1E<B(*;7-G<W1R(")!9')E<VQE<F4@=/UK;&%M86LL(&?V;F1E<F5N
M92!K:?YI>64@>65N:2!B:7(@:6QE=&D@;VQU_G1U<F%C86MT_7(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34Q"FUS9VED(")#;&EC:VEN9R!O;B!T
M:&4@861D<F5S<R!W:6QL(&]P96X@=&AE(&UE<W-A9V4@=&\@8F4@<F5A9"(*
M;7-G<W1R(")!9')E<VQE<F4@=/UK;&%M86LL:6QE=&EN:6X@;VMU;FUA:R!I
MYVEN(&'G_6QM87/];OT@<V'P;&%Y86-A:W3]<BXB"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L;W-E(@IM<V=S
M='(@(DMA<&%T(@H*(SH@8V]M<&]S92YP:'`Z.#(X(&-O;7!O<V4N<&AP.C$Q
M-#@*;7-G:60@(D-L;W-E('1H:7,@=VEN9&]W(@IM<V=S='(@(E!E;F-E<F5Y
M:2!K87!A="(*"B,Z(&9O;&1E<G,N<&AP.C0R.0IM<V=I9"`B0VQO<V5D($9O
M;&1E<B(*;7-G<W1R(")$:7II;FD@2V%P870N(@H*(SH@9F]L9&5R<RYP:'`Z
M-#0Y"FUS9VED(")#;VQL87!S92(*;7-G<W1R(")$87)A;'0B"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B0V]L;&%P<V4@
M06QL(@IM<V=S='(@(DAE<'-I;FD@1&%R86QT(@H*(SH@=&5M<&QA=&5S+V9O
M;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"!&;VQD
M97)S(@IM<V=S='(@(D+\=/QN($1I>FEN;&5R:2!$87)A;'0B"@HC.B!F;VQD
M97)S+G!H<#HT-#D*;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R(")$
M:7II;FD@1&%R86QT(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C4Q"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R(")296YK
M($?V<W1E<F=E<VDZ("(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,#,*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B0>?]:VQA;6$B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-S8Y"FUS9VED(")#;VUP;&5T960B"FUS9W-T
M<B`B5&%M86UL86YD_2(*"B,Z(&-O;7!O<V4N<&AP.C@R-R!C;VUP;W-E+G!H
M<#HQ,30W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@;65S<V%G92(*;7-G<W1R
M(")"8?YK82!B:7(@:6QE=&D@;VQU_G1U<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,S0*;7-G:60@(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A
M<F%T92!W:6YD;W<_(@IM<V=S='(@(MUL971I>6D@>65N:2!P96YC97)E9&4@
M;VQU_G1U<FUA:R!I<W1E<B!M:7-I;FEZ/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@;65S<V%G97,@=VET:"!A
M;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W<V5R('-U<'!O<G1S('1H
M92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@HB5F%R<V%Y_6QA;B!O;&%R86L@
M:6QE=&EL97)I($A434P@:W5L;&%N_6/](&%R86)I<FEM:7EL92!O;'7^='5R
M;6%K(&ES=&5R("(*(FUI<VEN:7H_*$7P97(@=&%R87G]8_UN_7H@8G4@]GIE
M;&QI\&D@9&5S=&5K;&EY;W)S82DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C<*;7-G:60@(D-O;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I<W!L
M87EE9"XB"FUS9W-T<B`BW6QE=&EL97)I;B!N87/];"!G]G+\;G3\;&5N96-E
M\&EN:2!Y87#];&%N9/UR_6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3<*;7-G:60@(D-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB"FUS
M9W-T<B`B4&]S=&%L87+];B#V;FEZ;&5M92!S9>=E;F5K;&5R:6YI('EA</UL
M86YD_7+];BXB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`HC+"!F=7IZ
M>0IM<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*
M;7-G<W1R(")3=6YU8W5Y82!B8?!L86YT_2!B8?YA<OUS_7HB"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S
M97)V97(@9F%I;&5D(@IM<V=S='(@(E-U;G5C=7EA(&)A\&QA;G3](&)A_F%R
M_7/]>B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R="!F;W(@)7,N(@IM<V=S
M='(@(B5S(&GG:6X@4$=0(&1E<W1E\&EN:2!D96YE=&QE+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M=')O;"!3+TU)344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(B5S(&GG:6X@
M4R]-24U%(&1E<W1E\&EN:2!D96YE=&QE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T
M;R!M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M
M86EL('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T
M;R!N;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HB
M665N:2!P;W-T86[];B`L;F4@>F%M86X@9&5N971L96YE8V7P:6YI('9E('EE
M;FD@<&]S=&QA;&%R_6X@<VEZ92!B:6QD:7)I;&EP("(*(F)I;&1I<FEL;65Y
M96-E\&EN:6MO;G1O;"!E9&EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8Y-@IM<V=I9"`B0V]N=F5R="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R
M87!H:6-A;"!O;F5S/R(*;7-G<W1R("(B"B)-971I;B!D=7EG=2!S:6UG96QE
M<FEN:2!G]G+\;G3\<V5L(&1U>6=U('-I;6=E;&5R:6YE(&3V;OS^=/QR;65K
M(&ES=&5R("(*(FUI<VEN:7H_(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C4Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<'EA;&$B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$Y('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@(D-O<'D@=&\@9F]L9&5R
M(@IM<V=S='(@(D1I>FEN:2!+;W!Y86QA(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T(@IM<V=S='(@(D3\
M>F5L="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ-#`*
M;7-G:60@(D-O<G)E8W1E9"!497AT(@IM<V=S='(@(D3\>F5L=&EL;6G^(&UE
M=&EN(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T+B!2
M96%S;VX@1VEV96XZ("5S(@IM<V=S='(@(E9&4R!S;VX@8?YA;6%S_2!Y87)A
M=/UL86UA9/TZ("5S(@H*(SH@871T86-H;65N="YP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z
M("5S(@IM<V=S='(@(E9&4R!S;VX@8?YA;6%S_2!Y87)A=/UL86UA9/TZ("5S
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S(&9R;VT@)7,N(%1H92!S97)V
M97(@<V%I9#H@)7,B"FUS9W-T<B`B)7,@:>=I;F1E:VD@:6QE=&EL97(@<VEL
M:6YE;65D:2X@4W5N=6-U.B`E<R(*"B,Z(&QI8B]397-S:6]N+G!H<#HS,3@*
M;7-G:60@(D-O=6QD(&YO="!E>&5C=71E(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,N(@IM<V=S='(@(D)A:_UM(&G^;&5M;&5R:2!Y_'+\=/QL96UE9&DN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C4T"FUS9VED(")#;W5L9"!N
M;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@35,M5$Y%
M1B!A='1A8VAM96YT+B(*;7-G<W1R("+=<W1E;F5N(&1O<WEA($U3+51.148@
M96MI;F1E;B!S9>=I<"#G_6MA<G3];&%M863]+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@
M<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R8VAI=F4N(@IM<V=S='(@
M(DES=&5N96X@9&]S>6$@6FEP(&%R_FEV:6YD96X@<V7G:7`@Y_UK87)T_6QA
M;6%D_2XB"@HC.B!L:6(O4V5S<VEO;BYP:'`Z,C<S"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R;VT@24U!4"!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C:"YP:'`Z,S$T('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T96UP;&%T97,O86-L+V%C;"YI
M;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,`IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(EEA<F%T(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T
M:6]N<RYI;F,Z-@IM<V=I9"`B0W)E871E($9O;&1E<B(*;7-G<W1R(")$:7II
M;B!987)A="(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*;7-G:60@
M(D-R96%T92!+97ES(@IM<V=S='(@(D%N86AT87(@66%R870B"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,30*;7-G:60@(D-R96%T92!6:7)T
M=6%L($9O;&1E<B(*;7-G<W1R(")386YA;"!$:7II;B!987)A="(*"B,Z('1E
M;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"B,L(&9U
M>GIY"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G<W1R(")$:?!E
M<B!0;W-T82!(97-A<&QA<OTB"@HC.B!T96UP;&%T97,O<')E9G,O<W!A;7-E
M;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(T
M"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!N97<@4W!A;2!F;VQD97(B"FUS
M9W-T<B`B665N:2#G]G`@:W5T=7-U('EA<F%T(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L
M9&5R(@IM<V=S='(@(EEE;FD@=&%S;&%K(&1I>FEN:2!Y87)A="(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C8@=&5M<&QA=&5S
M+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,@IM<V=I9"`B0W)E871E(&$@
M;F5W('-E;G0@;6%I;"!F;VQD97(B"FUS9W-T<B`B665N:2!G]FYD97)I;&UI
M_B!P;W-T82!D:7II;FD@>6%R870B"@HC.B!T96UP;&%T97,O<')E9G,O=')A
M<VAS96QE8W0N:6YC.C$R('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI
M;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T
M<B`B665N:2#G]G`@:W5T=7-U('EA<F%T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R.`IM<V=I9"`B(@HB0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T
M;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F
M;VQD97)S+"`B"B)A;F0@9&5L971E('-P86TN(@IM<V=S='(@(B(*(D=E;&5N
M('!O<W1A;&%R_6[]>OT@9/QZ96YL96UE:RP@9&EZ:6YL97)I;B!IYVEN92!A
M=&UA:R!V92!I<W1E;FUE>65N("(*(FEL971I;&5R:2!S:6QM96L@:>=I;B!S
M_'IG9><@:W5R86QL87)I('EA<F%T_6XN(@H*(SH@=&5M<&QA=&5S+W-T871I
M;VYE<GDO<')E9G,N:6YC.C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@;F5W
M('-T871I;VYE<GDB"FUS9W-T<B`B665N:2!G]FYD97)I;&UI_B!P;W-T82!D
M:7II;FD@>6%R870B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Y"FUS
M9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHY-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C8V5S<R!T;R`E<R(*;7-G<W1R("(E
M<R!IYVEN('G\<OQR;/QK=&5K:2!E<FG^:6TB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`U"FUS9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E
M=&-H:6YG(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`B(@HB
M1&GP97(@96QE:W1R;VYI:R!P;W-T82!H97-A<&QA<OUN_7ID86X@<&]S=&%L
M87+];B!G971I<FEL;65S:6YI("(*(FMI_FES96QL9?YT:7)I;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D-U<W1O;6EZ92!H;W<@
M>6]U('-E;F0@;6%I;"XB"FUS9W-T<B`B3F%S_6P@<&]S=&$@9_9N9&5R9&GP
M:6YI>FD@:VG^:7-E;&QE_G1I<FEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B)7,@9VER:?YI;F1E
M(.=A;/W^86-A:R!G]G)E=FQE<FD@:VG^:7-E;&QE_G1I<FEN(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ-PIM<V=I9"`B
M1&%T7V4B"FUS9W-T<B`B5&%R:5]H(@H*(SH@;65S<V%G92YP:'`Z,C8R('1H
M<F5A9"YP:'`Z,30X"FUS9VED(")$871E(@IM<V=S='(@(E1A<FEH(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U-PIM<V=I9"`B1&5C;&EN960B
M"FUS9W-T<B`B4F5D9&5D:6QD:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HR-C,*;7-G:60@(D1E8VQI;F5D.B`B"FUS9W-T<B`B4F5D9&5D:6QD
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0B"FUS9W-T<B`B4VEL(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C$X"FUS9VED(")$969A=6QT(%-E
M87)C:"!&:65L9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3(S"FUS9VED(")$969A=6QT('-O<G1I;F<@8W)I=&5R:6$Z(@IM<V=S
M='(@(E9A<G-A>6EL86X@<_UR86QA;6$@]FSG_'3\.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,S,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E
M8W1I;VXZ(@IM<V=S='(@(E9A<G-A>?UL86X@<_UR86QA;6$@>?9N_#HB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U"FUS9VED(")$96QE9V%T
M960B"FUS9W-T<B`B665T:VEL:2(*"B,Z(&9O;&1E<G,N<&AP.C0Q.2!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHR-#0@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]C;VUP;W-E
M+V%T=&%C:&UE;G1S+FEN8SHR.`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,C<*;7-G:60@(D1E;&5T92(*;7-G<W1R(")3:6PB"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,@4'5B;&EC($ME>2(*;7-G
M<W1R("(E<R!!Y_UK($%N86AT87+];OT@4VEL(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z.#4*;7-G
M:60@(D1E;&5T92!#=7)R96YT($ME>7,B"FUS9W-T<B`B6?QR_')L_&MT96MI
M($%N86AT87)L87+](%-I;"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.CD*;7-G:60@(D1E;&5T92!&;VQD97(H<RDB"FUS9W-T<B`B1&EZ
M:6YI(%-I;"(*"B,Z(&9O;&1E<G,N<&AP.C(X-0HC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B1&EZ:6YI(%-I;"(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,@HC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E(%-T871I;VYE<GDB"FUS9W-T<B`B4V%N86P@1&EZ
M:6YI(%-I;"(*"B,Z(&9O;&1E<G,N<&AP.C0Q.0IM<V=I9"`B1&5L971E(%9I
M<G1U86P@1F]L9&5R(@IM<V=S='(@(E-A;F%L($1I>FEN:2!3:6PB"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#,*;7-G:60@(D1E;&5T
M92!F971C:&5D(&UE<W-A9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\B"FUS9W-T
M<B`B57IA:W1A:VD@<W5N=6-U9&%N(&=E=&ER:6QE;B!I;&5T:6QE<FD@<VEL
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8R.`IM<V=I9"`B1&5L
M971E(&9R;VT@;7D@8V%L96YD87(B"FUS9W-T<B`B5&%K=FEM:6UD96X@<VEL
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B1&5L971E
M(&]L9"!L:6YK960@871T86-H;65N=',@870@8F5G:6YN:6YG(&]F(&UO;G1H
M/R(*;7-G<W1R(")%<VMI(&)A\&S](&5K;&5R(&%Y(&)A_OUN9&$@<VEL:6YS
M:6X@;6D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B
M1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@
M;6]N=&@_(@IM<V=S='(@(D5S:VD@9_9N9&5R:6QM:?X@<&]S=&$@9&EZ:6YL
M97)I(&%Y(&)A_OUN9&$@<VEL:6YS:6X@;6D_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-P86T@;65S
M<V%G97,B"FUS9W-T<B`B4VEL:6YE8V5K(-UL971I;&5R(@H*(SH@;65S<V%G
M92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<T,"!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C(P"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHX"FUS9VED(")$96QE
M=&5D(@IM<V=S='(@(E-I;&EN96-E:R(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-C,*;7-G:60@(D1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B
M4VEL:6YE8V5K(-UL971I;&5R(@H*(SH@8V]M<&]S92YP:'`Z,S`W"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T960@=&AE(&%T=&%C:&UE;G0@7"(E<UPB
M+B(*;7-G<W1R(")%:R!<(B5S7"(@<VEL:6YD:2XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SD*;7-G:60@(D1E;&5T:6YG(&%N9"!-;W9I;F<@365S
M<V%G97,B"FUS9W-T<B`BW6QE=&EL97)I;B!3:6QI;FUE<VD@=F4@5&'^_6YM
M87/](@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y,@IM<V=I9"`B
M1&5N>2!R97%U97-T(@IM<V=S='(@(MUS=&7P:2!R961D970B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-30P"FUS9VED(")$96YY(')E<75E<W0@
M9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R(")397)B97-T+VUE
M_F=U;"!B:6QG:2!I<W1E:VQE<FEN:2!R961D970B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3,R"FUS9VED(")$97-C96YD:6YG(@IM<V=S='(@(D%Z
M86QA;B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR
M,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Y"FUS9VED(")$97-C<FEP
M=&EO;B(*;7-G<W1R(")!Y_UK;&%M82(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B1&5T86EL<R(*
M;7-G<W1R(")!>7+];G3];&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8W-PIM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM<V=S='(@(MUM>F%L87(@
M9VEZ;&5S:6X@;6D_(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR,S8*;7-G:60@(D1I<W!L87DB"FUS9W-T<B`B1_9S=&5R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W.0IM<V=I9"`B1&ES<&QA>2!C;VYF
M:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(MUL
M971I(&?V;F1E<F1I:W1E;B!S;VYR82!D;_!R=6QA;6$@9_9R_&YT_&QE;G-I
M;B!M:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@V"FUS9VED(")$
M:7-P;&%Y(&EN($)O9'D@;V8@365S<V%G92(*;7-G<W1R("+=;&5T:6YI;B!I
MYVEN9&4@9_9R_&YT_&QE;G-I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.3(*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N
M97<@;6%I;#\B"FUS9W-T<B`B665N:2!I;&5T:2!B:6QG:7-I(&)E;&ER96X@
M:&%T_7)L871M82!O;&%R86L@9_9R_&YT_&QE;G-I;B!M:3\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S4X"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y
M('1H92!<(D5M<'1Y(%-P86U<(B!L:6YK(&EN('1H92!M96YU8F%R/R(*;7-G
M<W1R("(G0F_^(,?V<"!+=71U<W4G(&)A\&QA;G3]<_T@;65N_"#G=6)U\'5N
M9&$@9_9R_&YT_&QE;G-I;B!M:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S4P"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y('1H92!<(D5M<'1Y(%1R
M87-H7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B)T)O_B#']G`@
M2W5T=7-U)R!B8?!L86YT_7/](&UE;OP@YW5B=?!U;F1A(&?V<OQN=/QL96YS
M:6X@;6D_(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC
M.C$Q"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R(")$_'IE;B(*"B,Z('1E
M;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHR-@IM<V=I9"`B1&\@3D]4(&UA
M=&-H(@IM<V=S='(@(D7^;&7^;65Y96XB"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B1&\@3F]T($-H96-K($9O;&1E<BAS
M*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B1&EZ:6YI(%EE;FD@4&]S=&$@:>=I
M;B!$96YE=&QE;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34R"FUS
M9VED(")$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU
M;6XB"FUS9W-T<B`B1V5L96XZ(&MO;&]N=6YD82!B8?!L86YT_2!Y87)A=&UA
M(@H*(SH@;&EB+TE-4"YP:'`Z,3`W-0IM<V=I9"`B1&\@>6]U('=A;G0@=&\@
M;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`B1&EZ:6YI(&'G;6%K(&ES=&EY
M;W(@;75S=6YU>C\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(S
M,@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(V
M"FUS9VED(")$;VYE(@IM<V=S='(@(D)I='1I(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E
M<R!I;B`N>FEP($9O<FUA="(*;7-G<W1R("(N6FEP($)IYVEM:6YD92!I;F1I
M<CHE<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C4R"FUS
M9VED(")$;W=N;&]A9"!!;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB
M"FUS9W-T<B`B0OQT_&X@16ML97)I("@N>FEP(&1O<WEA<_T@;VQA<F%K*2!I
M;F1I<B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS
M9VED(")$;W=N;&]A9"!&;VQD97(H<RDB"FUS9W-T<B`B1&EZ:6YI(-UN9&ER
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C$*;7-G:60@
M(D1O=VYL;V%D($9O;&1E<BAS*2!;+GII<"!F;W)M871=(@IM<V=S='(@(D1I
M>FEN:2#=;F1I<B!;+GII<"!":>=I;6EN9&5=(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO860@:6X@+GII<"!&;W)M870B
M"FUS9W-T<B`B+EII<"!B:>=I;6EN9&4@:6YD:7(B"@HC.B!M97-S86=E+G!H
M<#HU,#$@;6%I;&)O>"YP:'`Z-S$Y('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHR,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0Q"B,Z('1E
M;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z.0IM<V=I9"`B1')A9G0B"FUS
M9W-T<B`B5&%S;&%K(@H*(SH@9F]L9&5R<RYP:'`Z,SDR"FUS9VED(")$<F%F
M="!F;VQD97(B"FUS9W-T<B`B5&%S;&%K($1I>FEN:2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS9VED(")$<F%F=',@9F]L
M9&5R.B(*;7-G<W1R(")487-L86ML87(@1&EZ:6YI.B(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,#@*;7-G:60@(D4M;6%I;"!!9&1R97-S(@IM<V=S
M='(@(D5L96MT<F]N:6L@4&]S=&$@061R97-I(@H*(SH@;&EB+TUA:6QB;W@N
M<&AP.C,P.0HC+"!F=7IZ>0IM<V=I9"`B14Y$(@IM<V=S='(@(E9%(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-S0*;7-G:60@(D524D]2.B!9
M;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV97)E9"XB"FUS9W-T<B`B
M2$%403H@W6QE=&EN:6YI>B!T97-L:6T@961I;&5M961I+B(*"B,Z(&9O;&1E
M<G,N<&AP.C0R,"!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,3D*
M;7-G:60@(D5D:70B"FUS9W-T<B`B1/QZ96YL92(*"B,Z('1E;7!L871E<R]F
M:6QT97)S+W!R969S+FEN8SHQ.`IM<V=I9"`B161I="!";&%C:VQI<W0B"FUS
M9W-T<B`B2V%R82!,:7-T97EI($3\>F5N;&4B"@HC.B!T96UP;&%T97,O9FEL
M=&5R<R]P<F5F<RYI;F,Z,3,*;7-G:60@(D5D:70@1FEL=&5R<R(*;7-G<W1R
M(")3_'IG9>=L97)I($3\>F5N;&4B"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M
M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$V"FUS9VED(")%9&ET(%9I<G1U
M86P@1F]L9&5R(@IM<V=S='(@(E-A;F%L($1I>FEN;&5R:2!$_'IE;FQE(@H*
M(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R($1E9FEN:71I;VX@9F]R
M("5S(@IM<V=S='(@(B5S(&GG:6X@4V%N86P@1&EZ:6X@5&%N_6W];OT@1/QZ
M96YL92(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHR,PIM<V=I
M9"`B161I="!7:&ET96QI<W0B"FUS9W-T<B`B0F5Y87H@3&ES=&5Y:2!$_'IE
M;FQE(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS9VED
M(")%9&ET('EO=7(@8FQA8VML:7-T(@IM<V=S='(@(DMA<F$@3&ES=&5N:7II
M($3\>F5N;&5Y:6XB"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,3,*;7-G:60@(D5D:70@>6]U<B!F:6QT97(@<G5L97,B"FUS9W-T<B`B4_QZ
M9V7G($MU<F%L;&%R_6[]>OT@1/QZ96YL97EI;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-C$*;7-G:60@(D5D:70@>6]U<B!P<F5F97)E;F-E<R!F
M;W(@86-C97-S:6YG(&]T:&5R(&UA:6P@86-C;W5N=',N(@IM<V=S='(@(D1I
M\&5R('!O<W1A(&AE<V%P;&%R_6YA(&5R:?YI;2!IYVEN('1E<F-I:&QE<FEN
M:7II(&3\>F5N;&5Y:6XN(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N
M:6YC.C(S"FUS9VED(")%9&ET('EO=7(@=VAI=&5L:7-T(@IM<V=S='(@(D)E
M>6%Z($QI<W1E;FEZ:2!$_'IE;FQE>6EN(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR,SD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS
M9W-T<B`B16QE:W1R;VYI:R!0;W-T82!!9')E<VDB"@HC.B!L:6(O365S<V%G
M92YP:'`Z-C4W"B,L('!H<"UF;W)M870*;7-G:60@(D5M<'1I960@86QL(&UE
M<W-A9V5S(&9R;VT@)7,N(@IM<V=S='(@(B5S(&GG:6YD96MI('3\;2!I;&5T
M:6QE<B!B;_YA;'3];&3]+B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO
M;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD97(H<RDB"FUS9W-T<B`B0F_^
M($1I>FEN*&QE<BDB"@HC.B!F;VQD97)S+G!H<#HR.#8*(RP@9G5Z>GD*;7-G
M:60@(D5M<'1Y(%-E;&5C=&5D($9O;&1E<G,B"FUS9W-T<B`B0F_^($1I>FEN
M*&QE<BDB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM
M<V=I9"`B16UP='D@5')A<V@@9F]L9&5R(@IM<V=S='(@(L?V<"!+=71U<W5N
M=2!";_YA;'0B"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@
M(D5M<'1Y(%]3<&%M(@IM<V=S='(@(L?V<"!+=71U<W5N=2!?0F_^86QT(@H*
M(SH@;&EB+TE-4"YP:'`Z.38V"FUS9VED(")%;7!T>2!?5')A<V@B"FUS9W-T
M<B`BQ_9P($MU='5S=6YU(%]";_YA;'0B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z,2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-@IM<V=I9"`B
M16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R(")01U`@:?YL979I
M(&5T:VEN;&7^=&ER:6QS:6X@;6D_(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHQ('1E;7!L871E<R]S;6EM92]N;W1A8W1I=F4N:6YC.C8*;7-G
M:60@(D5N86)L92!3+TU)344@9G5N8W1I;VYA;&ET>3\B"FUS9W-T<B`B4R]-
M24U%(&G^;&5V:2!E=&MI;FQE_G1I<FEL<VEN(&UI/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,3$*;7-G:60@(D5N86)L92!M97-S86=E('!R979I
M97=S/R(*;7-G<W1R("+=;&5T:2#V;FEZ;&5M92!E=&MI;FQE_G1I<FEL<VEN
M(&UI/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0T,@IM
M<V=I9"`B16YC<E]Y<'1I;VX@3W!T:6]N<R(*;7-G<W1R("+>:5]F<F5L96UE
M(%-EYV5N96ML97)I(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Q
M-R!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4W"FUS9VED(")%;F0B"FUS
M9W-T<B`B4V]N(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,X-`IM<V=I9"`B16YD
M(&9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(MUL971I;&5N(&EL971I;FEN
M('-O;G4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0Q"FUS9VED(")%;F0@;65S
M<V%G92(*;7-G<W1R("+=;&5T:7EI(&)I=&ER(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;F0@;65S<V%G92!F<F]M
M("5S(@IM<V=S='(@(B5S(&1E;B!I;&5T:7EI(&)I=&ER(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M-S<*;7-G:60@(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`B1V7G:?X@5/QM
M8V5S:6YI($=I<FEN(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N
M:6YC.CD*(RP@9G5Z>GD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!3<&%M(&9O;&1E<B(*;7-G<W1R(")996YI(.?V<"!K=71U<W5N=6X@
M863];OT@9VER:6XB"@HC.B!T96UP;&%T97,O<')E9G,O9F]L9&5R<V5L96-T
M+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A
M9G1S(&9O;&1E<B(*;7-G<W1R(")996YI('1A<VQA:R!D:7II;FEN(&%D_6[]
M(&=I<FEN(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN
M8SHR,PIM<V=I9"`B16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@
M;6%I;"!F;VQD97(B"FUS9W-T<B`B665N:2!G]FYD97)I;&UI_B!P;W-T82!D
M:7II;FEN:6X@863];OT@9VER:6XB"@HC.B!T96UP;&%T97,O<')E9G,O=')A
M<VAS96QE8W0N:6YC.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R
M(&YE=R!T<F%S:"!F;VQD97(B"FUS9W-T<B`B665N:2#G]G`@:W5T=7-U;G5N
M(&%D_6[](&=I<FEN(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#8*(RP@9G5Z>GD*
M;7-G:60@(D5N=&ER92!-97-S86=E(@IM<V=S='(@(DEL971I>6D@6?9N;&5R
M9&ER(@H*(SH@;65S<V%G92YP:'`Z,3DT(&-O;7!O<V4N<&AP.C$Q,S0@=&AR
M96%D+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R>2!<(B5S7"(@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T:&4@861D<F5S<R!B;V]K(@IM
M<V=S='(@(EPB)7-<(B!K87G]=/T@8F'^87+]>6QA(&%D<F5S(&1E9G1E<FEN
M92!E:VQE;F1I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ."!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,C$*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HS-S8@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S@V"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<R(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C$V,PIM<V=I9"`B17)R;W(B"FUS9W-T<B`B2&%T82(*"B,Z
M(&QI8B])34%0+T-L:65N="YP:'`Z-#4T"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V97(N("5S(#H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS,#D@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0P-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`B66%N_73](&?V
M;F1E<FUE9&4@:&%T83H@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C$P,0IM<V=I9"`B179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM
M<V=S='(@(D]L87D@8F'^87+]>6QA('-I;&EN9&DN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<X,@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G
M<W1R(")(97(@,34@9&%K:6MA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<W.0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")(97(@,S`@
M<V%N:7EE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I9"`B
M179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DAE<B`U(&1A:VEK82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#,*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R(")(97(@>6%R_6T@<V%A="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")(97(@
M9&%K:6MA(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED(")%>'!A;F0B"FUS
M9W-T<B`B1V5N:?YL970B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS
M+FEN8SHS.`IM<V=I9"`B17AP86YD($%L;"(*;7-G<W1R(")(97!S:6YI($=E
M;FG^;&5T(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*
M;7-G:60@(D5X<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R(")"_'3\;B!$:7II
M;FQE<FD@1V5N:?YL970B"@HC.B!F;VQD97)S+G!H<#HT-3<*;7-G:60@(D5X
M<&%N9"!&;VQD97(B"FUS9W-T<B`B1&EZ:6YI($=E;FG^;&5T(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP
M;W-E+W)E9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S
M='(@(MUS:6UL97)I($?V<W1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#8S"FUS9VED(")%>'!A;F0@;F%M97,@:6X@=&AE(&-O;7!O<V4@=VEN
M9&]W(&%U=&]M871I8V%L;'D@:6X@=&AE(&)A8VMG<F]U;F0_(@IM<V=S='(@
M(B(*(MUL971I(&]L=?YT=7)M82!P96YC97)E<VEN9&4@:7-I;6QE<B#V>F1E
M=FEN:6UL:2!O;&%R86L@87)T86QA;F1A(&'G_6QS_6X@;?T_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDX,`IM<V=I9"`B17AP86YD('1H92!E;G1I
M<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R<R!V:65W
M/R(*;7-G<W1R(")"_'3\;B!D:7II;B!A\&%C_6[]('9A<G-A>?UL86X@;VQA
M<F%K(&=E;FG^;&5T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z,30T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0IM<V=I9"`B17AP86YD:6YG(@IM<V=S
M='(@(D=E;FG^;&5T:6QI>6]R(@H*(SH@;&EB+TE-4"YP:'`Z.3@T(&QI8B])
M35`N<&AP.CDX-@HC+"!F=7IZ>0IM<V=I9"`B1E]E=&-H($UA:6PB"FUS9W-T
M<B`B4&]S=&$@1V5T:7(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B
M1F5T8V@@36%I;"(*;7-G<W1R(")0;W-T82!'971I<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-CD*;7-G:60@(D9E=&-H($UA:6P@:6X@82!S97!A
M<F%T92!W:6YD;W<_(@IM<V=S='(@(E!O<W1A($%Y<OT@0FER(%!E;F-E<F5D
M92!'971I<FEL<VEN(&UI/R(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N
M86=E+FEN8SHT-@IM<V=I9"`B1F5T8V@@;65S<V%G97,@=7!O;B!L;V=G:6YG
M(&]N/R(*;7-G<W1R(")':7)I_B!S_7)A<_UN9&$@:6QE=&EL97(@9V5T:7)I
M;'-I;B!M:3\B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9E=&-H960@)60@;65S<V%G97,@9G)O;2`E
M<R(*;7-G<W1R("(E<R!K;VYU;75N9&%N("5D(&EL971I(&=E=&ER:6QD:2(*
M"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1F5T8VAE9"`Q(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("(E
M<R!K;VYU;75N9&%N("5D(&EL971I(&=E=&ER:6QD:2(*"B,Z(&QI8B]&971C
M:&UA:6PN<&AP.C(X-2!L:6(O1F5T8VAM86EL+G!H<#HR.#<@;&EB+T9E=&-H
M;6%I;"YP:'`Z,C@Y"FUS9VED(")&971C:&UA:6PZ("(*;7-G<W1R(")0;W-T
M82!'971I<CHB"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*;7-G:60@(D9E
M=&-H;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R(")0;W-T82!'971I
M<CH@665N:2!I;&5T:2!Y;VLN(@H*(SH@;&EB+TE-4"YP:'`Z.3DP"FUS9VED
M(")&:5]L=&5R<R(*;7-G<W1R(")3_%]Z9V7G;&5R(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3`R('1E;7!L871E<R]C;VUP;W-E+V%T
M=&%C:&UE;G1S+FIS.C@R"FUS9VED(")&:6QE(@IM<V=S='(@(D1O<WEA(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"FUS9VED(")&:6QT
M97(@3W!T:6]N<R(*;7-G<W1R(")3_'IG9><@4V7G96YE:VQE<FDB"@HC.B!T
M96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0IM<V=I9"`B1FEL=&5R(%-E
M='1I;F=S(@IM<V=S='(@(E/\>F=EYR!!>6%R;&%R_2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV,#`*;7-G:60@(D9I;'1E<B!M97-S86=E(&-O;G1E
M;G0@9F]R('!R;V9A;FET>3\B"FUS9W-T<B`BW6QE=&EL97(@:_QF_'(@:>=I
M;B!S_'K\;'/\;B!M_#\B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I
M=F4N:6YC.C$Q"FUS9VED(")&:6QT97(@<W5P<&]R="!I<R!D:7-A8FQE9"!O
M;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`B4_QZ9V7G(&1E<W1E9VD@8G4@<VES
M=&5M9&4@<V7G:6QI<B!K_6S];FUA;?W^=/UR+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C<*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B4_QZ9V7G
M;&5R(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHS"FUS
M9VED(")&:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B4_QZ9V7G;&5R(&5T
M:VEN($1%T-U,(@H*(SH@;&EB+T9I;'1E<BYP:'`Z,3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;'1E<G,Z("5S(&UA;F%G96UE;G0@<&%G92(*;7-G<W1R
M(")3_'IG9>=L97(Z("5S('GV;F5T:6T@<V%Y9F%S_2(*"B,Z('1E;7!L871E
M<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS9VED(")&:6YD(@IM<V=S
M='(@(D)U;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#4*;7-G:60@
M(D9I<G-T($UA:6QB;W@@4&%G92(*;7-G<W1R("+=;&L@4&]S=&$@2W5T=7-U
M(%-A>69A<_TB"@HC.B!M86EL8F]X+G!H<#HS-#4*;7-G:60@(D9I<G-T(%!A
M9V4B"FUS9W-T<B`BW6QK(%-A>69A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C=&EO
M;G,N:6YC.C(Q"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R("+=;&5?="(*"B,Z
M(&9O;&1E<G,N<&AP.C(V-B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O
M;F9I<FTN:'1M;#HU"FUS9VED(")&;VQD97(@06-T:6]N<R`M($-O;F9I<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S
M+V9O;&1E<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA
M;'!A9V5S96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP
M86=E<V5L96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G
M<W1R(")$:7II;B!$;VQA_OUM_2(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HS"FUS9VED(")&;VQD97(@4W5M;6%R>2(*;7-G<W1R(")$:7II;B#6>F5T
M:2(*"B,Z(&%C;"YP:'`Z,C0*;7-G:60@(D9O;&1E<B!S:&%R:6YG(&ES(&YO
M="!E;F%B;&5D+B(*;7-G<W1R(")$:7II;B!P87EL8?[];?T@<V7G:6QI<B!K
M_6S];FUA;?W^+B(*"B,Z(&9O;&1E<G,N<&AP.C8R"FUS9VED(")&;VQD97(@
M=7-E(&ES(&YO="!E;F%B;&5D+B(*;7-G<W1R(")$:7II;B!K=6QL86[];?T@
M<V7G:6QI<B!K_6S];FUA;?W^+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-CD*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN('1H92!M
M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM<V=S='(@
M(E!O<W1A(&MU='5S=6YD86MI(&EL971I('1A<FEH;&5R:6YI;B!B:>=I;6D@
M8G5G_&YE('1A<FEH;&5N;6G^(@H*(SH@8V]M<&]S92YP:'`Z-S@P('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ-0HC.B!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHR,0IM<V=I9"`B1F]R=V%R9"(*;7-G
M<W1R("+=;&5T(@H*(SH@8V]M<&]S92YP:'`Z-S8U"FUS9VED(")&;W)W87)D
M.B(*;7-G<W1R("+=;&5T.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS-CD*;7-G
M:60@(D9O<G=A<F1E9"!M97-S86=E(@IM<V=S='(@(MUL971I;&5N(-UL971I
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&;W)W87)D960@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(B5S('1A<F%F
M_6YD86X@:6QE=&EL96X@:6QE=&DB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-#@S"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T
M<B`B4V5R8F5S="]-9?YG=6P@0FEL9VDB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#DT"FUS9VED(")&<F5E+T)U<WD@4F5P;'DB"FUS9W-T<B`B
M4V5R8F5S="]-9?YG=6P@66%N_70B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R(")3
M97)B97-T+TUE_F=U;"#=<W1E:R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT,#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM
M<V=S='(@(E-E<F)E<W0O367^9W5L(-US=&5K(%EA;OUT_2(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R
M;U]M(@IM<V=S='(@(DMI;5]D96XB"@HC.B!M97-S86=E+G!H<#HR-C,@=&AR
M96%D+G!H<#HQ-#D@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.3D*
M(SH@;&EB+U-E87)C:"YP:'`Z,C(*;7-G:60@(D9R;VTB"FUS9W-T<B`B2VEM
M9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ.`IM<V=I9"`B1G)O
M;2!!9&1R97-S(@IM<V=S='(@(D=E;&5N($%D<F5S(@H*(SH@8V]M<&]S92YP
M:'`Z-S<W(&-O;7!O<V4N<&AP.C<X,0IM<V=I9"`B1G=D.B(*;7-G<W1R("+=
M;&5T.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.30*;7-G:60@(D9W9#H@(@IM<V=S
M='(@(MUL970Z(@H*(SH@8V]M<&]S92YP:'`Z,3(Y-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E<R(*;7-G<W1R("+=
M;&5T.B`E=2#=;&5T:6QE;B#=;&5T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.`IM<V=I
M9"`B1V5N97)A;"!/<'1I;VYS(@IM<V=S='(@(D=E;F5L(%-EYV5N96ML97(B
M"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@
M(D=E="!O;FQY(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B
M4V%D96-E('EE;FD@:6QE=&D@86P@*%-A9&5C92!)34%0*2(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,Q"FUS9VED(")';R(*;7-G<W1R
M("(B"@HC.B!T:')E860N<&AP.C$S-@IM<V=I9"`B1V\@=&\@365S<V%G92(*
M;7-G<W1R("+=;&5T:7EE(&=I="(*"B,Z(&QI8B])35`N<&AP.C0Y.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1V\@=&\@861D<F5S<R!B;V]K(&5N
M=')Y(&]F(%PB)7-<(B(*;7-G<W1R(")!9')E<R!D969T97)I;F4@*"5S*2!E
M:VQE(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A
M;G0@86-C97-S(@IM<V=S='(@(D5R:?YI;2!V97(B"@HC.B!M97-S86=E+G!H
M<#HU-#8@;&EB+T9I;'1E<BYP:'`Z,3`U(&QI8B]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.CDU"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P,B!L
M:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*(SH@;&EB+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ
M,38*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(@;&EB
M+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(SH@;&EB+TU)344O
M5FEE=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z-#$X"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HQ
M,C<*;7-G:60@(DA%4D4B"FUS9W-T<B`B0E5205E!(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C,Q(&QI8B]-24U%+U9I97=E<B]H=&UL
M+G!H<#HQ,3<*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C@P"FUS
M9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!C;VUP;W-E+G!H<#HR-38*
M;7-G:60@(DA434P@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S='(@(MUL971I
M;FEN($A434P@4_QR_&W\(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R
M<RYI;F,Z-3@*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B0F'^;/UK($)I;&=I
M<VDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O;7!O<V4N:6YC.C4*;7-G
M:60@(DAE<F4@:7,@=&AE(&UE<W-A9V4@>6]U('=E<F4@8V]M<&]S:6YG.B(*
M;7-G<W1R(")/;'7^='5R=7EO<B!O;&1U\'5N=7H@:6QE=&DZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V.`IM<V=I9"`B2&ED9&5N(@IM<V=S='(@
M(D=I>FQI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-PIM<V=I9"`B
M2&ED9&5N(&EN(%1H<F5A9"!6:65W(@IM<V=S='(@(DAA8F5R(-9B9?!I($?V
M<OQN=/QS_&[\;B!IYVEN9&4@1VEZ;&4B"@HC.B!M86EL8F]X+G!H<#HS-C<*
M;7-G:60@(DAI9&4@1&5L971E9"(*;7-G<W1R(")3:6QI;F5C96ML97)I($=I
M7WIL92(*"B,Z(&9O;&1E<G,N<&AP.C(Y.`IM<V=I9"`B2&ED92!5;G-U8G-C
M<FEB960B"FUS9W-T<B`BW'EE($]L=6YM87EA;FQA<OT@1VEZ;&4B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR.30*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B6?QK<V5K(@H*(SH@;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N
M<&AP.C<R-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED
M(")(:6=H(%!R:6]R:71Y(@IM<V=S='(@(EG\:W-E:R#6;F-E;&EK(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDS"FUS9VED(")(:6=H
M97-T(@IM<V=S='(@(D5N('G\:W-E:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.#@*;7-G:60@(DAO=R!D;R!Y;W4@=V%N="!T;R!D:7-P;&%Y(&%T
M=&%C:&UE;G1S/R(*;7-G<W1R(")%:VQE<FD@;F%S_6P@9_9R_&YT_&QE;65K
M(&ES=&EY;W)S=6YU>C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`T
M"FUS9VED(")(;W<@=&\@871T<FEB=71E('%U;W1E9"!L:6YE<R!I;B!A(')E
M<&QY(@IM<V=S='(@(EEA;OUT;&%R9&$@86S];G3]('EA</UL86X@<V%T_7)L
M87+];B!N:71E;&GP:2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3,T
M"FUS9VED("))34%0(@IM<V=S='(@(DE-05`B"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$R.0IM<V=I9"`B24U!4"`H075T;R!$971E8W0@4')O=&]C
M;VQS*2(*;7-G<W1R("))34%0("C=;&5T:?YI;2!+=7)A;&QA<OUN_2#6>F1E
M=FEN:6UL:2!O;&%R86L@0G5L*2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z
M,SDQ"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@4V5R=F5R(&-L;W-E9"!T
M:&4@8V]N;F5C=&EO;BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C8@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ-#8*;7-G:60@(DE-05`@;W9E<B!34TPB"FUS9W-T
M<B`B4U-,(/QZ97)I;F1E;B!)34%0(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P
M+G!H<#HQ-3(*;7-G:60@(DE-05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E
M<G1I9FEC871E*2(*;7-G<W1R(")34TP@_'IE<FEN9&5N($E-05`@*&ME;F1I
M;F1E;B!I;7IA;/T@;VYA>2!B96QG97-I*2(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,38W"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I
M9VYE9"DB"FUS9W-T<B`B4U-,(/QZ97)I;F1E;B!)34%0("AK96YD:6YD96X@
M:6UZ86S]*2(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,S8X"B,L(&9U>GIY
M"FUS9VED("))34%0('-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(D)A\&QA;OUL86-A:R!E;&5K=')O;FEK('!O<W1A('-U;G5C=2!T
M_'+\.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38U(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,30P"FUS9VED("))34%0+"!N;R!43%,B"FUS
M9W-T<B`B24U!4"P@5$Q3('EO:R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP
M:'`Z-#D*;7-G:60@(DE-05`O4$]0,R!-86EL(%-E<G9E<G,B"FUS9W-T<B`B
M24U!4"]03U`S($5L96MT<F]N:6L@4&]S=&$@4W5N=6-U;&%R_2(*"B,Z(&QI
M8B])35`N<&AP.C@V-@IM<V=I9"`B24Y"3U@B"FUS9W-T<B`B1T5,14X@2U54
M55-5(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HT,3$*;7-G:60@(DEF('5S
M:6YG(%-33"!O<B!43%,L('EO=2!M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L
M(&5X=&5N<VEO;B!L;V%D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V9O;&1E<G-?8V]N9FER;2YH=&UL.C$R"B,L(&9U>GIY"FUS9VED
M("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E<R!I;B!T:&4@9F]L9&5R
M*',I('=I;&P@8F4@;&]S="$B"FUS9W-T<B`B1&EZ:6XH;&5R*61E:VD@8OQT
M_&X@:6QE=&EL97(@:V%Y8F]L86-A:W3]<B$B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G<W1R(")9
M;VMS87DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#,*
M;7-G:60@(DEG;F]R92!!;&PB"FUS9W-T<B`B5/QM_&[\('EO:W-A>2(*"B,Z
M('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHX"FUS9VED("))
M;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N
M:6YC.C(P"FUS9VED("));7!O<G0B"FUS9W-T<B`B*-WG97)I*2!!:W1A<B(*
M"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T
M97,O<&=P+VEM<&]R=%]K97DN:6YC.C8U"FUS9VED("));7!O<G0@2V5Y(@IM
M<V=S='(@(BC=YV5R:2D@06MT87)M82!!;F%H=&%R_2(*"B,Z('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHQ,SD*;7-G:60@(DEM<&]R="!+97EP86ER(@IM<V=S
M='(@(BC=YV5R:2D@06MT87)M82!!;F%H=&%R(-UK:6QI<VDB"@HC.B!T96UP
M;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR-PIM<V=I9"`B26UP;W)T($UE
M<W-A9V5S(@IM<V=S='(@(MUL971I;&5R:2`HW>=E<FDI($%K=&%R(@H*(SH@
M<&=P+G!H<#HT,@IM<V=I9"`B26UP;W)T(%!'4"!+97DB"FUS9W-T<B`B4$=0
M($%N86AT87+];OT@*-WG97)I*2!!:W1A<B(*"B,Z('1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,Z.3$*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="!097)S;VYA
M;"!#97)T:69I8V%T92(*;7-G<W1R(")+:?YI<V5L($]N87D@8F5L9V5L97)I
M;FD@*-WG97)I*2!!:W1A<B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z,30*;7-G:60@(DEM<&]R="!097)S;VYA;"!0<FEV871E(%!'4"!+
M97DB"FUS9W-T<B`B2VG^:7-E;"#6>F5L(%!'4"!!;F%H871A<OT@*-WG97)I
M*2!!:W1A<B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z.0IM
M<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(@IM<V=S='(@
M(DMI_FES96P@0>?]:R!01U`@06YA:'1A<OT@*-WG97)I*2!!:W1A<B(*"B,Z
M('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O
M<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E<R(*;7-G<W1R(")+:?YI
M<V5L(%,O34E-12!/;F%Y($)E;&=E;&5R:6YI("C=YV5R:2D@06MT87(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0P('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHT,@IM<V=I9"`B26UP;W)T(%!U8FQI8R!+97DB"FUS9W-T<B`B
M0>?]:R!!;F%H=&%R_2`HW>=E<FDI($%K=&%R(@H*(SH@=&5M<&QA=&5S+W!G
M<"]I;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC(%!'4"!+
M97DB"FUS9W-T<B`B0>?]:R!01U`@0>?]:R!!;F%H=&%R_6[]("C=YV5R:2D@
M06MT87(B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`IM
M<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(D'G_6L@
M4R]-24U%($%N86AT87+];OT@*-WG97)I*2!!:W1A<B(*"B,Z('-M:6UE+G!H
M<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+97DB"FUS9W-T<B`B4R]-24U%
M($%N86AT87+];OT@*-WG97)I*2!!:W1A<B(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP;W)T(&UB;W@@1FEL92(*;7-G
M<W1R(")M8F]X(&1O<WEA<_UN_2`HW>=E<FDI($%K=&%R(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+B(*;7-G<W1R
M("(E<R!M8F]X(&1O<WEA<_UN_2`E<R!D:7II;FEN92`H:>=E<FDI(&%K=&%R
M(@H*(SH@;65S<V%G92YP:'`Z-3`R(&UA:6QB;W@N<&AP.C<S-"!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,S"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM
M<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(M9N96UL:2(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z-#<*;7-G:60@(DEM<&]R=&%N="!M97-S86=E
M<R(*;7-G<W1R("+6;F5M;&D@W6QE=&EL97(B"@HC.B!F;VQD97)S+G!H<#HQ
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@)60@;65S<V%G97,@
M9G)O;2`E<RXB"FUS9W-T<B`B)60@:6QE=&D@)7,@:V]N=6UU;F1A;B`H:>=E
M<FDI(&%K=&%R_6QD_2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-S<S"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@(E/\<OQY;W(B"@HC.B!F
M;VQD97)S+G!H<#HS.#0@;&EB+T9O;&1E<BYP:'`Z.#8@;&EB+T9O;&1E<BYP
M:'`Z,C$T(&QI8B])35`N<&AP.C,Q,PHC.B!L:6(O24U!4"]4<F5E+G!H<#HQ
M,30@;&EB+TE-05`O5')E92YP:'`Z,C$Y"FUS9VED("));F)O>"(*;7-G<W1R
M(")'96QE;B!+=71U<W4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR
M"FUS9VED("));F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R
M(&EN(&$@<F5P;'D_(@IM<V=S='(@(D)A_FS]:R!B:6QG:6QE<FEN:6X@:_US
M82!B:7(@]GIE=&D@>6%N_71A(&5K;&5N<VEN(&UI/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.#<*;7-G:60@(DEN8VQU9&4@;W)I9VEN86P@;65S
M<V%G92!I;B!A(')E<&QY/R(*;7-G<W1R("+6>F?\;B!I;&5T:2!Y86[]=&$@
M96ML96YS:6X@;6D_(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C$@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,3,P"FUS9VED
M("));F9O(@IM<V=S='(@(D)I;&=I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(*;7-G
M<W1R("(E<R!!Y_UK($%N86AT87+]($AA:VO];F1A($)I;&=I<VDB"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(DEN9F]R;6%T:6]N(&]N
M(%!E<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(DMI_FES96P@UGIE;"!!
M;F%H=&%R($AA:VO];F1A($)I;&=I(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN
M9F]R;6%T:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B2VG^
M:7-E;"!!Y_UK($%N86AT87(@2&%K:_UN9&$@0FEL9VDB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,34@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3`W"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FIS.CDX"FUS9VED("));FQI;F4B"FUS9W-T<B`B365T:6YE($?V
M;?QL_"(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS
M9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R(")/;F%Y($)E
M;&=E<VEN:2!"=7)A>6$@665R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHQ-0IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!R:79A
M=&4@4$=0($ME>2!(97)E(@IM<V=S='(@(DMI_FES96P@UGIE;"!01U`@06YA
M:'1A<OUN_2!"=7)A>6$@665R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B26YS97)T(%!E<G-O;F%L(%!U8FQI
M8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B2VG^:7-E;"#6>F5L($'G_6L@06YA
M:'1A<OT@0G5R87EA(%EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z-0IM<V=I9"`B26YS97)T(%!U8FQI8R!01U`@2V5Y($AE
M<F4B"FUS9W-T<B`B0>?]:R!01U`@06YA:'1A<OUN_2!"=7)A>6$@665R;&7^
M=&ER(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q,@IM<V=I9"`B
M26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*
M;7-G<W1R(")"=2!B:6QE_F5N(&GG:6X@9V7G97)S:7H@8FER(&5Y;&5M('-E
MYVEL9&DN(@H*(SH@;6%I;&)O>"YP:'`Z-3@T(&UA:6QB;W@N<&AP.C8R-@IM
M<V=I9"`B26YV86QI9"!!9&1R97-S(@IM<V=S='(@(D=EYV5R<VEZ($%D<F5S
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HS,#<*;7-G:60@(DEN=F%L
M:60@4F5M;W1E($UA:6QB;W@B"FUS9W-T<B`B1V7G97)S:7H@57IA:R!%;&5K
M=')O;FEK(%!O<W1A($MU='5S=2(*"B,Z(&-O;7!O<V4N<&AP.C$U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@
M861D<F5S<SH@)7,N(@IM<V=S='(@(D5L96MT<F]N:6L@4&]S=&$@861R97-I
M;F1E(&=EYV5R<VEZ(&MA<F%K=&5R.B`E<RXB"@HC.B!S;6EM92YP:'`Z.#(@
M<&=P+G!H<#HQ-@IM<V=I9"`B26YV86QI9"!K97DB"FUS9W-T<B`B1V7G97)S
M:7H@06YA:'1A<B(*"B,Z('!G<"YP:'`Z,3DV"FUS9VED("));G9A;&ED('!E
M<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB"FUS9W-T<B`B1V7G97)S:7H@:VG^
M:7-E;"#V>F5L(%!'4"!A;F%H=&%R_2XB"@HC.B!P9W`N<&AP.C$W,0IM<V=I
M9"`B26YV86QI9"!P97)S;VYA;"!01U`@<'5B;&EC(&ME>2XB"FUS9W-T<B`B
M1V7G97)S:7H@:VG^:7-E;"!AY_UK(%!'4"!A;F%H=&%R_2XB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R"FUS9VED("));G9E<G0B"FUS
M9W-T<B`B5&5R<R#'979I<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4W-PIM<V=I9"`B2T(B"FUS9W-T<B`B2T(B"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3$S"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@
M(D%N86AT87(@57IU;FQU\'4B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,3,W"FUS9VED("(B"B)+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@
M=&EM92!T;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y("(*(F=E;F5R
M871I;VX_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,S4@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,W"FUS9VED(")+97D@:6UP
M;W)T(&ES(&YO="!A=F%I;&%B;&4N($9I;&4@=7!L;V%D(&ES(&YO="!E;F%B
M;&5D(&]N('1H:7,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C,W('1E;7!L871E<R]P9W`O<&=P+FEN8SHS.0IM
M<V=I9"`B(@HB2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V
M92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U<B`B"B)C;VYT
M86-T<RXB"FUS9W-T<B`B(@H*(SH@<&=P+G!H<#HS,3@*;7-G:60@(DME>2!S
M=6-C97-S9G5L;'D@<V5N="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B06YA:'1A<B!B8?YA<OUY;&$@8>?]:R!A;F%H=&%R('-U;G5C=7-U
M;F$@9_9N9&5R:6QD:2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(Q-@IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B1&EL(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP-@IM<V=I9"`B3&%S="!-86EL8F]X(%!A9V4B
M"FUS9W-T<B`B4V]N(%!O<W1A($MU='5S=2!387EF87/](@H*(SH@;6%I;&)O
M>"YP:'`Z,S4X"FUS9VED("),87-T(%!A9V4B"FUS9W-T<B`B4V]N(%-A>69A
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@Y"FUS9VED
M("),:5]N:R!!='1A8VAM96YT<R(*;7-G<W1R(")%:VQE<FD@7T)A\&QA(@H*
M(SH@871T86-H;65N="YP:'`Z,S0@;&EB+T-O;7!O<V4N<&AP.C$P-C,*;7-G
M:60@(DQI;FME9"!A='1A8VAM96YT<R!A<F4@9F]R8FED9&5N+B(*;7-G<W1R
M(")"8?!L86YM_?X@96ML97(@>6%S86ML86YM_?YT_7(N(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&EN:W,@=VEL
M;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B)7,@=&%R:6AI;F1E(&)A\&QA<OUN
M('/\<F5S:2!D;VQA8V%K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A8W1S('=H96X@;&]A9&EN9R!T
M:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES86)L960L('EO=2!W:6QL("(*
M(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U('-E87)C:"!F;W(@97AP;&EC
M:71L>2DB"FUS9W-T<B`B(@HB26QE=&G^:6T@;F]K=&%L87+](&5K<F%N_6[]
M('G\:VQE<FME;B!T_&T@:6QE=&G^:6T@;F]K=&%L87+]9&$@;&ES=&5L96YS
M:6X@(@HB;6D_("A%\&5R("!S9>=I;&UE>B!K_6S];FW]_G-A+"!S861E8V4@
M8>?]:^=A(&%R863]\/UN_7H@:6QE=&G^:6T@(@HB;F]K=&%L87+];OT@9_9R
M96-E:W-I;FEZ+B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@U"FUS
M9VED("),:7-T:6YG(&EN('1H92!(96%D97(B"FUS9W-T<B`B0F'^;/UK=&$@
M3&ES=&5L96UE(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C,P"FUS9VED("),;V-A;"!-86EL8F]X.B(*;7-G<W1R(")997)E;"!0;W-T
M82!+=71U<W4Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8W-`IM
M<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B665R(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,C4*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")':7)I
M_B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&]G(&EN('1O("5S(@IM<V=S='(@(B5S($=I<FG^:2(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,W"FUS9VED("),;V=I;B(*
M;7-G<W1R(")':7)I_B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.0IM
M<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B1VER:?X@1_9R979L97)I(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDV"FUS9VED("),
M;W<B"FUS9W-T<B`B1/S^_&LB"@HC.B!M97-S86=E+G!H<#HR.3D@;6%I;&)O
M>"YP:'`Z-S(W('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3,*;7-G
M:60@(DQO=R!0<FEO<FET>2(*;7-G<W1R(")$_/[\:R#6;F-E;&EK(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED("),;W=E
M<W0B"FUS9W-T<B`B16X@9/S^_&LB"@HC.B!L:6(O34E-12]6:65W97(O87!P
M;&5D;W5B;&4N<&AP.C0T"FUS9VED(")-86-I;G1O<V@@1FEL92(*;7-G<W1R
M(")-86-I;G1O<V@@1&]S>6%S_2(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S
M<&AR87-E+FEN8SHQ,PIM<V=I9"`B36%I;"(*;7-G<W1R(")0;W-T82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-@IM<V=I9"`B36%I;"!0<F5V:65W
M<R(*;7-G<W1R(")0;W-T82#6;FEZ;&5M92(*"B,Z('1E;7!L871E<R]F971C
M:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R
M('1Y<&4@=&\@8V]N;F5C="!T;SHB"FUS9W-T<B`B0F'P;&%N_6QA8V%K(&5L
M96MT<F]N:6L@<&]S=&$@<W5N=6-U('3\<OPZ(@H*(SH@9F]L9&5R<RYP:'`Z
M-#`R"FUS9VED(")-86EL8F]X(@IM<V=S='(@(E!O<W1A($MU='5S=2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*;7-G:60@(DUA:6QB;W@@86YD
M($9O;&1E<B!$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B4&]S=&$@2W5T=7-U
M('9E($1I>FEN($?V<OQN=/QL96UE(%-EYV5N96ML97)I(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL($UE
M<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@(D1I>FEN9&5K:2!"
M_'3\;B#=;&5T:6QE<FD@3VMU;FUU_B!/;&%R86L@W?YA<F5T;&4@(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@
M06QL($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T<B`B1&EZ
M:6YD96MI($+\=/QN(-UL971I;&5R:2!/:W5N;6%M_?X@3VQA<F%K(-W^87)E
M=&QE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHU('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S`*;7-G:60@(DUA
M<FL@87,Z(@IM<V=S='(@(MW^87)E=&QE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-3`*;7-G:60@(DUA<FL@9&EF9F5R96YT(&QE=F5L<R!O9B!Q
M=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O;&]R<S\B"FUS9W-T<B`B1F%R:VS]
M(&3\>F5Y9&5K:2!A;/UN=/UL87(@9F%R:VS](')E;FML97)L92!I_F%R971L
M96YS:6X@;6D_(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E96X_("A)34%0(&]N;'DI
M(@IM<V=S='(@(MUL971I;&5R(&?V<OQL;?S^(&]L87)A:R!I_F%R971L96YS
M:6X@;6D_*%-A9&5C92!)34%0*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T<B`B0F%S
M:70@8FGG:6UL96UE(&G^87)E=&QE;G-I;B!M:3\B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z-#8*;7-G:60@(DUA=&-H($%L;"!1=65R:65S
M(@IM<V=S='(@(D+\=/QN(%-O<F=U;&%R;&$@1?YL9?XB"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R
M>2(*;7-G<W1R(")(97)H86YG:2!":7(@4V]R9W5Y;&$@1?YL9?XB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3,*;7-G:60@(DUA>&EM
M=6T@071T86-H;65N="!3:7IE(@IM<V=S='(@(D5N($+\>?QK($5K($)O>75T
M=2(*"B,Z(&QI8B]A<&DN<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!&;VQD97)S(@IM<V=S='(@(D5N(&9A>FQA(&5K('-A>?US
M_6YA('5L8?[];&3]+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0Y-`IM<V=I9"`B36%X:6UU;2!N=6UB97(@;V8@871T86-H;65N=',@
M<F5A8VAE9"XB"FUS9W-T<B`B16X@9F%Z;&$@96L@<V%Y_7/];F$@=6QA_OUL
M9/TN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@Y"FUS
M9VED(")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*
M;7-G<W1R(")%;B!B_'G\:R!E:R!B;WEU='5N82!U;&'^_6QD_2XB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(V"FUS9VED(")-965T:6YG($-A
M;F-E;&QA=&EO;B(*;7-G<W1R(")4;W!L86YT_2#=<'1A;&DB"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-3<U"FUS9VED(")-965T:6YG($EN9F]R
M;6%T:6]N(@IM<V=S='(@(E1O<&QA;G3]($)I;&=I<VDB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3@U"FUS9VED(")-965T:6YG(%!R;W!O<V%L
M(@IM<V=S='(@(E1O<&QA;G3](-9N97)I<VDB"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-C$W"FUS9VED(")-965T:6YG(%)E<&QY(@IM<V=S='(@
M(E1O<&QA;G3](%EA;OUT_2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU.3@*;7-G:60@(DUE971I;F<@57!D871E(@IM<V=S='(@(E1O<&QA;G3]
M($?\;F-E;&QE;65S:2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M,#,*;7-G:60@(DUE971I;F<@57!D871E(%)E<75E<W0B"FUS9W-T<B`B5&]P
M;&%N=/T@1_QN8V5L;&5M92#=<W1E\&DB"@HC.B!L:6(O0FQO8VLO=')E95]F
M;VQD97)S+G!H<#HS"FUS9VED(")-96YU($9O;&1E<B!,:7-T(@IM<V=S='(@
M(D1I>FEN($QI<W1E($UE;OQS_"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,S$*
M;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BW6QE=&DB"@HC.B!C;VUP;W-E+G!H
M<#HU-C`@8V]M<&]S92YP:'`Z-3@W(&-O;7!O<V4N<&AP.C8T,2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3`*;7-G:60@(DUE<W-A9V4@0V]M<&]S:71I;VXB
M"FUS9W-T<B`BW6QE=&D@3VQU_G1U<FUA(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDQ-PIM<V=I9"`B365S<V%G92!$871E(@IM<V=S='(@(MUL971I
M(%1A<FEH:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PIM<V=I9"`B365S<V%G
M92!/<'1I;VYS(@IM<V=S='(@(MUL971I(%-EYV5N96ML97)I(@H*(SH@<V5A
M<F-H+G!H<#HS,3(*;7-G:60@(DUE<W-A9V4@4V5A<F-H(@IM<V=S='(@(MUL
M971I($%R86UA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,0IM<V=I
M9"`B365S<V%G92!3:7IE(@IM<V=S='(@(MUL971I($)O>75T=2(*"B,Z(&UE
M<W-A9V4N<&AP.C,X-`IM<V=I9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`B
MW6QE=&D@2V%Y;F'P_2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM
M<V=I9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@(MUL971I($?V<OQN_&W\
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHV"FUS9VED(")-97-S
M86=E(&9L86=S(@IM<V=S='(@(MUL971I(&G^87)E=&QE<FDB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@S"FUS9VED(")-97-S86=E(&9O;&1E
M<G,B"FUS9W-T<B`BW6QE=&D@9&EZ:6YL97)I(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B
M"FUS9W-T<B`B)7,@9&5N(&EL971I(@H*(SH@;6%I;&)O>"YP:'`Z-C8W"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R
M(")%_FQE_F5N(&EL971I;&5R(@H*(SH@;6%I;&)O>"YP:'`Z-C4X"B,L(&9U
M>GIY"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E9"(*;7-G<W1R("+=;&5T
M:2!A;&%N;&%R_2(*"B,Z(&UA:6QB;W@N<&AP.C8U,PHC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92!I<R!S:6=N960B"FUS9W-T<B`BW6QE=&D@86QA;FQA<OTB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,S,*;7-G:60@(DUE
M<W-A9V4@;6%T8VAE<R(*;7-G<W1R(")%_FQE_F5N(&EL971I;&5R(@H*(SH@
M8V]M<&]S92YP:'`Z.#(T(&-O;7!O<V4N<&AP.C@S.`IM<V=I9"`B365S<V%G
M92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BW6QE=&D@8F'^
M87+]>6QA('GV;FQE;F1I<FEL;6G^=&ER+B(*"B,Z(&-O;7!O<V4N<&AP.C$P
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B365S<V%G92!S96YT('-U8V-E<W-F
M=6QL>2P@8G5T(&YO="!S879E9"!T;R`E<R(*;7-G<W1R("+=;&5T:2!B8?YA
M<OUY;&$@9_9N9&5R:6QD:2P@9F%K870@)7,@:>=I;F4@:V%Y9&5D:6QE;65D
M:2XB"@HC.B!C;VUP;W-E+G!H<#HQ,30S(&-O;7!O<V4N<&AP.C$Q-3@*;7-G
M:60@(DUE<W-A9V4@<V5N="!S=6-C97-S9G5L;'DN(@IM<V=S='(@(MUL971I
M(&)A_F%R_7EL82!G]FYD97)I;&1I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-#$*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL
M8F]X('9I97<N(@IM<V=S='(@(E!O<W1A(&MU='5S=2!G]G+\;G3\<_QN9&4@
M<V%Y9F$@8F'^_6YA(&EL971I(@H*(SH@;6%I;&)O>"YP:'`Z,S(R"FUS9VED
M(")-97-S86=E<R!T;R(*;7-G<W1R("+=;&5T:6QE<FDB"@HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,CD*;7-G:60@(DUO9&EF>2(*;7-G<W1R(")$9?!I
M_G1I<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@861D<F5S
M<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R(")!;&%N("<E<R<@
M:>=I;B!B:7)D96X@9F%Z;&$@861R97,@8G5L=6YD=2XB"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C$X('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z-3`*;7-G:60@(DUO=F4B"FUS9W-T<B`B5&'^
M_2(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,Q-@IM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(D'^86?](%1A_OTB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C$X"FUS9VED(")-;W9E('-P86T@;65S<V%G
M97,@=&\@<W!A;2!F;VQD97(@86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.
M0D]8(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU
M,`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`B1&EZ:6YE('1A_OTB
M"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,30*;7-G
M:60@(DUO=F4@=7`B"FUS9W-T<B`B675K87+]('1A_OTB"@HC.B!L:6(O34E-
M12]6:65W97(O86QT97)N871I=F4N<&AP.C$R-PIM<V=I9"`B375L=&EP87)T
M+V%L=&5R;F%T:79E(@IM<V=S='(@(L=O:R!087+G86S]+U-EYV5N96ML:2(*
M"B,Z('1H<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G
M:60@(DUU;'1I<&QE($UE<W-A9V4@5FEE=R(*;7-G<W1R("+=;&5T:2!']G+\
M;OQM_"(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T
M+FEN8SHU"B,L(&9U>GIY"FUS9VED(").3TY%(@IM<V=S='(@(DY/5"(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT."!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(*
M;7-G:60@(DY/5$4B"FUS9W-T<B`B3D]4(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHR,S@@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8X.`IM<V=I9"`B3F%M92(*;7-G<W1R(")!9"(*"B,Z('!G<"YP:'`Z,3$P
M"FUS9VED(").86UE(&%N9"]O<B!E;6%I;"!C86X@;F]T(&)E(&5M<'1Y(@IM
M<V=S='(@(D%D('9E+W9E>6$@96QE:W1R;VYI:R!P;W-T82!B;_X@;VQA;6%Z
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W.`IM<V=I9"`B3F5E
M9',@06-T:6]N(@IM<V=S='(@(D5Y;&5M($=E<F5K:7EO<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-S`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X
M,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<X"FUS9VED(").979E<B(*
M;7-G<W1R(")!<VQA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,`IM
M<V=I9"`B3F5V97(@<V%V92!A='1A8VAM96YT<R(*;7-G<W1R(")%:VQE<FD@
M87-L82!S86ML86UA(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R-`IM
M<V=I9"`B3F5W(@IM<V=S='(@(EEE;FDB"@HC.B!L:6(O24U0+G!H<#HU-C,*
M;7-G:60@(DYE=R!&;VQD97(B"FUS9W-T<B`B665N:2!$:7II;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B3F5W($UA:6PB"FUS9W-T
M<B`B665N:2!0;W-T82(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ.2!L
M:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B
M3F5W($UE<W-A9V4B"FUS9W-T<B`B4V]N<F%K:2#=;&5T:2(*"B,Z(&UA:6QB
M;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@
M(EEE;FD@:6QE=&EL97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C$Y"FUS9VED(").97<@;65S<V%G97,B"FUS9W-T<B`B665N:2!I;&5T:6QE
M<B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B4V]N<F%K:2(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,S,*;7-G:60@(DYE>'0@365S<V%G
M92(*;7-G<W1R(")3;VYR86MI(-UL971I(@H*(SH@;6%I;&)O>"YP:'`Z,S4V
M"FUS9VED(").97AT(%!A9V4B"FUS9W-T<B`B4V]N<F%K:2!387EF82(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3<W"FUS9VED(").;R(*;7-G<W1R(")(87G]<B(*"B,Z
M('-M:6UE+G!H<#HR,C8*;7-G:60@(DYO($-E<G1I9FEC871E(&9O=6YD(@IM
M<V=S='(@(D]N87D@0F5L9V5S:2!"=6QU;F%M863](@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHU"FUS9VED(").;R!%;F-R>7!T
M:6]N(@IM<V=S='(@(MYI9G)E;&5M92!9;VLB"@HC.B!T96UP;&%T97,O<&=P
M+W!G<"YI;F,Z,3D*;7-G:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R
M(")!;F%H=&%R('II;F-I<FEN9&4@86YA:'1A<B!Y;VLB"@HC.B!M86EL8F]X
M+G!H<#HS-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G97,B"FUS
M9W-T<B`BW6QE=&D@66]K(@H*(SH@<&=P+G!H<#HQ,S<*;7-G:60@(DYO(%!'
M4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(")(:>=B:7(@4$=0($'G
M_6L@06YA:'1A<OT@*&GG97)I*2!A:W1A<OUL86UA9/TB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C@T"FUS9VED(").;R!097)S;VYA;"!#97)T
M:69I8V%T92!0<F5S96YT(@IM<V=S='(@(DMI_FES96P@3VYA>2!"96QG97-I
M($)U;'5N;6%M86MT863]<B(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS,CD*(RP@
M9G5Z>GD*;7-G:60@(DYO(%!R979I97<@5&5X="(*;7-G<W1R("+6;FEZ;&5M
M92(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,34*;7-G:60@(DYO
M(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(D'G_6L@06YA:'1A<B!"=6QU
M;F%M863](@H*(SH@<VUI;64N<&AP.C$U,0IM<V=I9"`B3F\@4R]-24U%('!U
M8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(DAIYV)I<B!3+TU)344@8>?]
M:R!A;F%H=&%R_2`H:>=E<FDI(&%K=&%R_6QA;6%D_2XB"@HC.B!L:6(O34E-
M12]6:65W97(O=&YE9BYP:'`Z.3`*;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O
M=6YD+B(*;7-G<W1R(")(:>=B:7(@96L@8G5L=6YA;6%D_2XB"@HC.B!L:6(O
M0W)Y<'0O4TU)344N<&AP.C$T,`HC+"!F=7IZ>0IM<V=I9"`B3F\@96UA:6P@
M:6YF;W)M871I;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME>2XB"FUS9W-T
M<B`B)7,@0>?]:R!!;F%H=&%R_2!(86MK_6YD82!":6QG:7-I(@H*(SH@86-L
M+G!H<#HW,B!A8VPN<&AP.CDX"FUS9VED(").;R!F;VQD97(@<V5L96-T960N
M(@IM<V=S='(@(DAIYV)I<B!D:7II;B!S9>=I;&D@9&7P:6PN(@H*(SH@;&EB
M+T)L;V-K+W-U;6UA<GDN<&AP.C$T,0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@
M8F5I;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(DAIYV)I<B!D
M:7II;B!Y96YI('!O<W1A(&GG:6X@9&5N971L96YE;65D:2XB"@HC.B!F;VQD
M97)S+G!H<#HR,3@@;&EB+T9O;&1E<BYP:'`Z-3`P(&QI8B]&;VQD97(N<&AP
M.C4U,`IM<V=I9"`B3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9"(*;7-G<W1R
M(")(:>=B:7(@9&EZ:6X@8F5L:7)T:6QM961I(@H*(SH@;&EB+T)L;V-K+W-U
M;6UA<GDN<&AP.C$T-PIM<V=I9"`B3F\@9F]L9&5R<R!W:71H(&YE=R!M97-S
M86=E<R(*;7-G<W1R(")(:>=B:7(@9&EZ:6YD92!Y96YI(&EL971I('EO:R(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#0*;7-G:60@(DYO(&9O;&1E
M<G,@=VET:"!U;G-E96X@;65S<V%G97,B"FUS9W-T<B`B2&GG8FER(&1I>FEN
M9&4@9_9R_&QM96UI_B!I;&5T:2!Y;VLB"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M,S(U"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G<W1R("+=;&5T
M:2!G]G9D97-I;F1E(&UE=&EN('EO:R(*"B,Z(&QI8B]-86EL8F]X+G!H<#HS
M-S$*;7-G:60@(DYO(&UE<W-A9V5S(&UA=&-H960@>6]U<B!S96%R8V@N(@IM
M<V=S='(@(DAIYV)I<B!I;&5T:2!A<F%M86[]>FQA(&7^;&7^;65D:2XB"@HC
M.B!P9W`N<&AP.C$X.0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!R:79A=&4@
M:V5Y(&EM<&]R=&5D+B(*;7-G<W1R(")(:>=B:7(@:VG^:7-E;"#V>F5L(%!'
M4"!A;F%H=&%R_2`H:>=E<FDI(&%K=&%R_6QA;6%D_2XB"@HC.B!P9W`N<&AP
M.C$V-0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T
M960N(@IM<V=S='(@(DAIYV)I<B!K:?YI<V5L(&'G_6L@4$=0(&%N86AT87+]
M("AIYV5R:2D@86MT87+];&%M863]+B(*"B,Z('-M:6UE+G!H<#HR,#$*;7-G
M:60@(DYO('!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@:6UP;W)T960N
M(@IM<V=S='(@(DAIYV)I<B!K:?YI<V5L(%,O34E-12!O;F%Y(&)E;&=E<VD@
M*&GG97)I*2!A:W1A<OUL86UA9/TN(@H*(SH@<W!E;&QI;F<N<&AP.C(R,`IM
M<V=I9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N(@IM
M<V=S='(@(DAIYV)I<B!Y87K];2!D96YE=&EM('!R;V=R86W]('EA</UL86YD
M_7+];&UA;?W^+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN
M8SHT.`IM<V=I9"`B3F\@<W!E;&QI;F<@97)R;W)S(@IM<V=S='(@(EEA>OUM
M(&AA=&%S_2!Y;VLB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G<W1R("+6;F5R:2!Y
M;VLB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4V-`IM<V=I9"`B3F\@<W5P
M<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T:&]D(&-O=6QD(&)E(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!A8VPN<&AP.C8X(&%C;"YP:'`Z.30*;7-G
M:60@(DYO('5S97(@<W!E8VEF:65D+B(*;7-G<W1R(")+=6QL86[]8_T@8F5L
M:7)T:6QM961I+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#D*
M;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R(")+873];/UM8_T@1&7P
M:6PB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$Q('1E;7!L
M871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z-#`*(SH@=&5M<&QA=&5S
M+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S4@=&5M<&QA=&5S+W!R969S+W-P
M86US96QE8W0N:6YC.C(T"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-C0*;7-G:60@(DYO;F4B"FUS9W-T<B`B2&GG8FER:2(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-0IM<V=I9"`B3F]R;6%L(@IM<V=S
M='(@(D]L8?!A;B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,C$@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS.0IM<V=I9"`B3F]T
M($1E;&5T960B"FUS9W-T<B`B4VEL:6YM97EE8V5K(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C(S"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z-#(*;7-G:60@(DYO="!$<F%F="(*;7-G<W1R(")487-L86L@1&7P
M:6PB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-PHC.B!T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC.C,T"FUS9VED(").;W0@26UP;W)T86YT
M(@IM<V=S='(@(M9N96US:7HB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C(U"FUS9VED(").;W0@4&5R<V]N86PB"FUS9W-T<B`B2VG^:7-E
M;"!$9?!I;"(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O
M4TU)344N<&AP.C$S-"!L:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B
M3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB"FUS9W-T<B`B1V7G97)L:2!B:7(@
M8>?]:R!A;F%H=&%R(&1E\&EL+B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z-C<*;7-G:60@(DYO="!D96QE=&5D(&UE<W-A9V5S(@IM<V=S='(@
M(E-I;&EN;65Y96-E:R!I;&5T:6QE<B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A;G0@;65S<V%G97,B"FUS
M9W-T<B`BUFYE;7-I>B!I;&5T:6QE<B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@=&AA="!T
M:&ES(&-A;B!T86ME('-O;64@=&EM92(*;7-G<W1R(")"=2!B:7)A>B!Z86UA
M;B!A;&%B:6QI<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV,38*;7-G
M:60@(DYO=&AI;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-PIM<V=I9"`B3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L
M:6YK960@871T86-H;65N=',@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T
M<B`B(@HB1?!E<B!A>6S]:R!O;&%R86L@<VEL:6YI>6]R<V$L(&5S:VD@8F'P
M;/T@96ML97)I;B!S86ML86YA8V'P_2!A>2!S87G]<_TN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,U.0IM<V=I9"`B3G5M8F5R(&]F(&]L9"!S96YT
M+6UA:6P@9F]L9&5R<R!T;R!K965P(&EF(&1E;&5T:6YG(&UO;G1H;'DN(@IM
M<V=S='(@(B(*(D7P97(@87EL_6L@;VQA<F%K('-I;&EN:7EO<G-A+"!E<VMI
M(&?V;F1E<FEL;6G^('!O<W1A(&1I>FEN;&5R:6YI;B`B"B)S86ML86YA8V'P
M_2!A>2!S87G]<_TN(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHR-30@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4U,@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-S,S"FUS9VED(")/2R(*;7-G<W1R(")%
M=F5T(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C4@=&5M<&QA
M=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C0Y"B,Z('1E;7!L871E<R]P9W`O
M:6UP;W)T7VME>2YI;F,Z-#@*;7-G:60@(D]2(@IM<V=S='(@(E9%64$B"@HC
M.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$U"FUS9VED(")/;&0@;65S
M<V%G97,B"FUS9W-T<B`B17-K:2#=;&5T:6QE<B(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+V1E;&5T95]S96YT;6%I;%]M;VYT:&QY+G!H<#HU,@IM<V=I
M9"`B3VQD('-E;G0M;6%I;"!F;VQD97)S(&)E:6YG('!U<F=E9"XB"FUS9W-T
M<B`B16MS:2!G]FYD97)I;&UI_B!P;W-T82!D:7II;FQE<FD@<VEL:6YE8V5K
M+B(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HR-0IM<V=I9"`B3VYL>2!D
M:7-P;&%Y(&9O;&1E<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\B
M"FUS9W-T<B`B4V%D96-E(&]K=6YM86W]_B!I;&5T:2!IYV5R96X@9&EZ:6YL
M97(@9_9R_&YT_&QE;G-I;B!M:3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C<Y"FUS9VED(")/;FQY(&]N92!F;VQD97(@<VAO=6QD
M(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO;BXB"FUS9W-T<B`B0G4@97EL
M96T@:>=I;B!S861E8V4@8FER(&1I>FEN('-EYVEL;65L:61I<BXB"@HC.B!T
M96UP;&%T97,O;65N=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L
M(&9U>GIY"FUS9VED(")/<&5N($9O7VQD97(B"FUS9W-T<B`B1&EZ:6X@0><B
M"@HC.B!F;VQD97)S+G!H<#HT,C<*;7-G:60@(D]P96YE9"!&;VQD97(B"FUS
M9W-T<B`B1_9R_&YT_&QE;F5N($1I>FEN(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C<P-0IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS
M9W-T<B`B4V7G:6UL:2!+873];/UM8_TB"@HC.B!F971C:&UA:6PN<&AP.C,S
M('1E;7!L871E<R]F971C:&UA:6PO=&]P+FEN8SHS"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO9F5T8VAM86EL+FEN8SHV"FUS9VED(")/=&AE<B!-86EL($%C
M8V]U;G1S(@IM<V=S='(@(D1I\&5R(%!O<W1A($AE<V%P;&%R_2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I;VYS
M(@IM<V=S='(@(D1I\&5R(%-EYV5N96ML97(B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C(P,0IM<V=I9"`B3W5T8F]U;F0@4V5R=F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3`*;7-G:60@
M(E!'4"(*;7-G<W1R(")01U`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R
M>7!T7VQI<W0N:6YC.C<*;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS
M9W-T<B`B4$=0(&EL92#>:69R96QE;FUI_B#=;&5T:2(*"B,Z(&-O;7!O<V4N
M<&AP.C,U.`IM<V=I9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`B4$=0($AA=&%S
M_3H@(@H*(SH@8V]M<&]S92YP:'`Z,S,W"FUS9VED(")01U`@17)R;W(Z($YE
M960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM<V=S
M='(@(E!'4"!(871A<_TZ($MI_FES96P@]GIE;"!A;F%H=&%R(&GG:6X@9V7G
M:?X@=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T,@IM<V=I9"`B4$=0($]P=&EO;G,B"FUS9W-T<B`B4$=0
M(%-EYV5N96ML97)I(@H*(SH@<&=P+G!H<#HS,`IM<V=I9"`B4$=0(%!A<W-P
M:')A<V4@26YP=70B"FUS9W-T<B`B4$=0($=EYVG^(%3\;6-E8VGP:2!':7)I
M_FDB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!0
M97)S;VYA;"!+97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*(E!'4"!+:?YI<V5L($%N86AT87(@
MW6MI;&ES:2!D97-T9?!I(&?\=F5N;&D@8FER('=E8B!B8?!L86YT_7/]("(*
M(F=E<F5K=&ER;65K=&5D:7(N("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C$W,PIM<V=I9"`B4$=0(%!U8FQI8R!+97D@5&5X="(*;7-G<W1R(")0
M1U`@0>?]:R!!;F%H=&%R($UE=&YI(@H*(SH@<&=P+G!H<#HQ-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB
M('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(EPB)7,@*"5S*5PB
M(&GG:6X@4$=0($'G_6L@06YA:'1A<OT@8F'^87+]>6QA(&5K;&5N9&DN(@H*
M(SH@<&=P+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI
M8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM
M<V=S='(@(EPB)7-<(B!01U`@0>?]:R!!;F%H=&%R_2!B8?YA<OUY;&$@<VEL
M:6YD:2XB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R(")01U`@0>?]:R!!;F%H=&%R(%II
M;F-I<FDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC
M.C@*;7-G:60@(E!'4"!3:6=N($UE<W-A9V4B"FUS9W-T<B`B4$=0(-UM>F$@
M365S86K](@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN
M8SHY"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B
M4$=0(-UM>F$OWFEF<F5L96UE($UE<V%J_2(*"B,Z('!G<"YP:'`Z,C`R"FUS
M9VED(")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G
M<W1R(")01U`@]GIE;"!A;F%H=&%R_2!B8?YA<OUY;&$@96ML96YD:2XB"@HC
M.B!P9W`N<&AP.C$W-PIM<V=I9"`B4$=0('!U8FQI8R!K97D@<W5C8V5S<V9U
M;&QY(&%D9&5D+B(*;7-G<W1R(")01U`@8>?]:R!A;F%H=&%R_2!B8?YA<OUY
M;&$@96ML96YD:2XB"@HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z
M-`IM<V=I9"`B4$=0('-U<'!O<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T
M96TN(@IM<V=S='(@(E!'4"!D97-T9?!I(&)U('-I<W1E;61E('-EYVEL96UE
M>B!K_6S];FW]_G3]<BXB"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M,#@*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T
M:79E('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@
M(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E!'4"!D97-T9?!I('G\<OQR;/QK
M=&4@9&7P:6P@8G4@;F5D96YL92!S87G]<V%L(&EM>F$@9&_P<G5L86YA;6%K
M=&%D_7(N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDU"FUS9VED
M("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T
M:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R
M("(B"B)01U`@9&5S=&7P:2!Y_'+\<FS\:W1E(&1E\&EL(&)U(&YE9&5N;&4@
M:6QE=&EN:6X@_FEF<F5S:2#G]GK\;&5M96UE:W1E9&ER(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C(*(RP@9G5Z>GD*;7-G:60@(B(*(E!'4"!S=7!P
M;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO
M=7(@8G)O=W-E<B!I<R!C=7)R96YT;'D@(@HB<V5T('1O(&1I<V%B;&4@<&]P
M=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E
M;'-E('1H92!01U`@(@HB9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*(E!'4"!D97-T9?!I(&)E;&ER96X@<&5N8V5R96QE
M<FD@:W5L;&%N;6%K(&ES=&5M96MT961I<BX@1?!E<B!T87)A>?UC_6[]>B`B
M"B)B96QI<F5N('!E;F-E<F5L97)I('-EYVEM<VEZ(&O];&3]>7-A+"!B=2!A
M>6%R_2!D9?!I_G1I<FUE;&ES:6YI>BP@86MS:2`B"B)T86MT:7)D92!01U`@
M]GIE;&QI:VQE<FED;_!R=2#G86S]_FUA>6%C86MT_7(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G<W1R(")03U`S
M(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#`*;7-G:60@(E!/4#,@
M*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B4$]0,R`HW6QE=&G^
M:6T@2W5R86QL87+];OT@UGID979I;FEM;&D@06QG_6QA*2(*"B,Z(&QI8B]&
M971C:&UA:6PO:6UA<"YP:'`Z,3$W"FUS9VED(")03U`S(&]V97(@4U-,(@IM
M<V=S='(@(E-33"#\>F5R:6YD96X@4$]0,R(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,3(S"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE
M9"!C97)T:69I8V%T92DB"FUS9W-T<B`B4U-,(/QZ97)I;F1E;B!34TP@*&ME
M;F1I;F1E;B!I;7IA;/T@;VYA>2!B96QG97-I*2(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF
M+7-I9VYE9"DB"FUS9W-T<B`B4U-,(/QZ97)I;F1E;B!03U`S("AK96YD:6YD
M96X@:6UZ86S]*2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$Q"FUS
M9VED(")03U`S+"!N;R!43%,B"FUS9W-T<B`B4$]0,RQ43%,@>6]K(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHQ.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")086=E("5D(&]F("5D(@IM<V=S='(@(E-A>69A("5D("T@)60B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`S"FUS9VED(")086=E('=I
M=&@@=&AE($9I<G-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(MUL:R!/:W5N
M;6%M_?X@W6QE=&EN:6X@0G5L=6YD=?!U(%-A>69A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G92!W:71H('1H92!,87-T(%5N
M<V5E;B!-97-S86=E(@IM<V=S='(@(E-O;B!/:W5N;6%M_?X@W6QE=&EN:6X@
M0G5L=6YD=?!U(%-A>69A(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R
M<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`B0O9L_&TH;&5R*2(*
M"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,C,*;7-G:60@(E!A<W-P:')A
M<V4B"FUS9W-T<B`B1V7G:?X@5/QM8V5C:?!I(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$R.`IM<V=I9"`B4&%S<W!H<F%S92`H06=A:6XI(@IM<V=S
M='(@(D=EYVG^(%3\;6-E8VGP:2`H5&5K<F%R*2(*"B,Z('-M:6UE+G!H<#HR
M,S4@<&=P+G!H<#HS,3`*;7-G:60@(E!A<W-P:')A<V4@<W5C8V5S<V9U;&QY
M('5N;&]A9&5D+B(*;7-G<W1R(")'9>=I_B!4_&UC96-I\&D@8F'^87+]>6QA
M(.?]:V%R=/UL9/TN(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N
M:6YC.C$X('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,CD*;7-G:60@
M(E!A<W-P:')A<V4Z(@IM<V=S='(@(D=EYVG^(%3\;6-E8VGP:3HB"@HC.B!P
M9W`N<&AP.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B92!E;7!T
M>2(*;7-G<W1R(")'9>=I_B!4_&UC96-I:VQE<FD@8F_^(&]L86UA>B(*"B,Z
M('!G<"YP:'`Z,3$T"FUS9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T8V@B
M"FUS9W-T<B`B1V7G:?X@5/QM8V5C:6ML97)I(&7^;&7^;65M96MT961I<B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR,"!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-S$*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ.3(*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E!A<F]L
M82(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`IM<V=I
M9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*
M;7-G<W1R(")"86O];2!I_FQE;6QE<FD@9VER:?YT92!G97+G96ML9?YT:7)I
M;'-I;B!M:3\B"@HC.B!A8VPN<&AP.C<V(&%C;"YP:'`Z,3`R"FUS9VED(")0
M97)M:7-S:6]N<R!F;W(@=&AI<R!U<V5R(&-A;B!N;W0@8F4@8VAA;F=E9"XB
M"FUS9W-T<B`B0G4@:W5L;&%N_6/];OUN(&EZ:6YL97)I(&1E\&G^=&ER:6QE
M;65Z+B(*"B,Z(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X+G!H<#HW,#,@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T96UP;&%T97,O;6%I
M;&)O>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA;"(*;7-G<W1R(")+
M:?YI<V5L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")0
M97)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")+:?YI<V5L($)I;&=I;&5R
M(@H*(SH@<&=P+G!H<#HQ,C`*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DMI_FES96P@4$=0
M(&%N86AT87(@:6MI;&ES:2!B8?YA<OUY;&$@_')E=&EL9&DN(@H*(SH@<&=P
M+G!H<#HQ,C<*;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R(")+:?YI<V5L(%!'4"!A;F%H=&%R;&%R_2!B
M8?YA<OUY;&$@<VEL:6YD:2XB"@HC.B!S;6EM92YP:'`Z,C`W"FUS9VED(")0
M97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S($Y/5"!I;7!O<G1E9#H@(@IM
M<V=S='(@(DMI_FES96P@4R]-24U%(&]N87D@8F5L9V5S:2`H:>=E<FDI($%+
M5$%224Q!34%$23H@(@H*(SH@<VUI;64N<&AP.C$S,@IM<V=I9"`B4&5R<V]N
M86P@4R]-24U%(&ME>7,@9&5L971E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(DMI_FES96P@4R]-24U%(&%N86AT87)L87+](&)A_F%R_7EL82!S:6QI;F1I
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L86-E
M('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D<S\B
M"FUS9W-T<B`BW6UZ86[]>B!Y86[]=&QA<F1A;B!V92!I;&5T:6QE8V5K;&5R
M9&5N(/9N8V4@>65R;&7^=&ER:6QS:6X@;6D_(@H*(SH@8V]M<&]S92YP:'`Z
M,C4T"FUS9VED(")0;&%I;G1E>'0@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S
M='(@(MUL971I;FEN($3\>B!-971I;B!3_'+\;?PB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SDY"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M
M86EL/R`@5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E
M;6)E9&1E9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN
M9&]W<R!A;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q
M=6ER92!A('!L=6=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,3DR"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&9O;&1E<CHB"FUS9W-T<B`B3/QT9F5N('EE;FD@<&]S=&$@:W5T
M=7-U(&GG:6X@8FER(&%D(&=I<FEN.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3`R('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3`T"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE
M(&YE=R!F;VQD97(Z(@IM<V=S='(@(DS\=&9E;B!Y96YI(&1I>FEN(&GG:6X@
M8FER(&%D(&=I<FEN.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3,W"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE.B(*
M;7-G<W1R("),_'1F96X@>65N:2!A9/T@9VER:6XZ(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P87-S<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R
M:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@(@HB96YT97(@=&AI
M<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*
M(DS\=&9E;B!01U`@]GIE;"!A;F%H=&%R_6[]>B!IYVEN(&=EYVG^('3\;6-E
M8VGP:6YI(&=I<FEN+D)U(&=EYVG^("(*(G3\;6-E8VGP:6YI(&AE<B`E<R!O
M='5R=6T@:>=I;B!G:7)M96YI>B!G97)E:V5C96MT:7(N(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3
M+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N;'D@;F5E9"`B"B)T;R!E
M;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@)7,@<V5S<VEO;BXB"FUS
M9W-T<B`B(@HB3/QT9F5N(%,O34E-12#V>F5L(&%N86AT87+];OUZ(&GG:6X@
M9V7G:?X@=/QM8V5C:?!I;FD@9VER:6XN0G4@9V7G:?X@(@HB=/QM8V5C:?!I
M;FD@:&5R("5S(&]T=7)U;2!IYVEN(&=I<FUE;FEZ(&=E<F5K96-E:W1I<BXB
M"@HC.B!R96-O;7!O<V4N<&AP.CDW"FUS9VED("(B"B)0;&5A<V4@;&]G(&EN
M(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y
M;W4@87)E($Y/5"!U<VEN9R`B"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O
M<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E
M('1O("(*(FQO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E
M;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA8VMI
M;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O
M;G9E;FEE;F-E+B(*;7-G<W1R("(B"B),_'1F96X@>65N:61E;B!G:7)I_B!Y
M87#];B!V92!Y96YI(&EL971I(&]L=?YT=7)M87EA(&1E=F%M(&5D:6XN1?!E
M<B#G97)E>B`B"B)+54Q,04Y-25E/4E-!3DE:('9E('EE;FD@:6QE=&EN:7II
M(&)E;&ER96X@<&5N8V5R961E(&]L=?YT=7)U>6]R<V%N_7HL("(*(GEE;FED
M96X@86YA('!E;F-E<F5Y92!D92!G:7)I_B!Y87!M86[]>B!G97)E:V5C96MT
M:7(N0G4L('-A;&3]<F=A;FQA<OUN("(*(F]T=7)U;2!K:6UL:6L@;G5M87)A
M;OUZ_2!E;&4@9V7G:7)M97-I;FD@]FYL96UE:R!IYVEN9&ER+E)A:&%T<_UZ
M;/UK(&GG:6X@(@HB]GK\<B!D:6QE<FEZ+B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-S$*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S
M<W=O<F0N(@IM<V=S='(@(DS\=&9E;B!P87)O;&%N_7K](&=I<FEN+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C<*;7-G:60@(E!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64N(@IM<V=S='(@(DS\=&9E;B!K=6QL86[]
M8_T@863];OUZ_2!G:7)I;BXB"@HC.B!C;VUP;W-E+G!H<#HQ,#8@;&EB+TE-
M4"YP:'`Z-#4Y"FUS9VED(")0;&5A<V4@<F5S;VQV92!A;6)I9W5O=7,@;W(@
M:6YV86QI9"!A9&1R97-S97,N(@IM<V=S='(@(DS\=&9E;B!G9>=E<G-I>B!Y
M861A(&)E;&ER<VEZ(&%D<F5S;&5R:2#G]GK\;BXB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C0R"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H
M92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A
M8W1I;VX@9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@HB3/QT
M9F5N('1A:VEP(&5D96X@8FEL9VEY:2!G]GID96X@9V7G:7)I;BP@87)D_6YD
M86X@8?YA\/UD86MI(&UE;OQD96X@8FER("(*(F5Y;&5M('-EYVEN+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C$*;7-G:60@(E!L
M96%S92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A
M8W1I;VYS+B(*;7-G<W1R("),_'1F96X@:&5R:&%N9VD@8FER(&5Y;&5M(&=E
M<N=E:VQE_G1I<FUE9&5N(/9N8V4@8FER(&1I>FEN('-EYVEN+B`B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3`R"FUS9VED(")0;&5A<V4@<V5L
M96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R("),
M_'1F96X@8?YA\/UD86MI(&UE;OQD96X@8FER(&5Y;&5M('-EYVEN+B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L
M96%S92!S96QE8W0@870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM
M<V=S='(@(DS\=&9E;B!A<F%M82!IYVEN(&5N(&%Z(&)I<B!D:7II;B!S9>=I
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$R"FUS
M9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@=&AI<R!O
M<&5R871I;VXN(@IM<V=S='(@(DS\=&9E;B!B=2!I_FQE;2!IYVEN('-A9&5C
M92!B:7(@9&EZ:6X@<V7G:6XN(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C<S"FUS9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@
M=&AE(&)O>"!T;R!T:&4@<FEG:'0Z(@IM<V=S='(@(DS\=&9E;B!K=71U;G5N
M(&GG:6YD96X@<V'P82!D;_!R=2!S9>=I;2!Y861A(&3\>F5N;&5M92!Y87#]
M;CHB"@HC.B!C;VYF:6<O;6]T9"YP:'`N9&ES=#HT,0IM<V=I9"`B4&]W97)E
M9"!B>2!(;W)D92(*;7-G<W1R(")(;W)D92!$97-K=&5K;&DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C$T"FUS9VED(")0<F5C961E('EO=7(@<VEG
M;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_(@IM<V=S='(@(MUM>F%N_7H@
M]FYC97-I;F1E(&ME<VEK;&D@YVEZ9VD@*"<M+2<I(&)U;'5N<W5N(&UU/R(*
M"B,Z('-M:6UE+G!H<#HR-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N<&AP
M.C0P"FUS9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E9"XB
M"FUS9W-T<B`B5&5R8VEH;&5R:6YI>B!B8?YA<OUY;&$@9_QN8V5L;&5N9&DN
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*;7-G
M:60@(E!R979I97<B"FUS9W-T<B`BUFYI>FQE;64B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U
M<R!-97-S86=E(@IM<V=S='(@(M9N8V5K:2#=;&5T:2(*"B,Z(&UA:6QB;W@N
M<&AP.C,T-PIM<V=I9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R("+6;F-E:VD@
M4V%Y9F$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI
M;F,Z,S,*;7-G:60@(E!R:6YT(@IM<V=S='(@(EEA>F3]<B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VAE861E<G,N:6YC.C,X"FUS9VED(")0<FEO<FET>2(*
M;7-G<W1R("+6;F-E;&EK(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K
M97DN:6YC.C<V"FUS9VED(")0<FEV871E($ME>2!087-S=V]R9"(*;7-G<W1R
M("+6>F5L($%N86AT87(@4&%R;VQA<_TB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-34Y"FUS9VED(")0<F]M<'0@979E<GD@=&EM92!A;B!A='1A8VAM
M96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@3D\B"FUS9W-T<B`B2&5R(&5K(&?V
M;F1E<FEL:7)K96X@<V]R.R#V;G1A;OUM;/T@9&7P97(@2$%925(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34X"FUS9VED(")0<F]M<'0@979E<GD@
M=&EM92!A;B!A='1A8VAM96YT(&ES('-E;G0[(&1E9F%U;'0@=&\@6453(@IM
M<V=S='(@(DAE<B!E:R!G]FYD97)I;&ER:V5N('-O<CL@]FYT86[];6S](&1E
M\&5R($56150B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M,3`*;7-G:60@(E!R;W1O8V]L.B(*;7-G<W1R("+=;&5T:?YI;2!+=7)A;&QA
M<OTZ(@H*(SH@;&EB+T-R>7!T+U!'4"YP:'`Z-#(Y"FUS9VED(")0=6)L:6,@
M4$=0(&ME>7-E<G9E<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G
M<W1R(")!Y_UK(%!'4"!A;F%H=&%R('-U;G5C=7-U(&1E<W1E\&D@<V7G:6QE
M;65Z(&O];/UN9/TN(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX
M"FUS9VED(")0=7)?9V4@1&5L971E9"(*;7-G<W1R(")3:6QI;F5C96ML97)I
M(%]496UI>FQE(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS
M9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(E-I;&EN96-E:VQE<FD@5&5M
M:7IL92(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(T"FUS
M9VED(")0=7)G92!&;VQD97(H<RDB"FUS9W-T<B`B1&EZ:6XH;&5R*6D@5&5M
M:7IL92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.38*;7-G:60@(E!U
M<F=E(%1R87-H(&AO=R!O9G1E;CHB"FUS9W-T<B`BQ_9P($MU='5S=2!T96UI
M>FQE;64@<_UK;/WP_3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`U
M"FUS9VED(")0=7)G92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@
M=&AA;B!T:&ES(&%M;W5N="!O9B!D87ES+B(*;7-G<W1R(")"=2!K861A<B!G
M_&YD96X@9&%H82!E<VMI(.?V<"!K=71U<W5N9&%K:2!I;&5T:6QE<FD@=&5M
M:7IL92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(")0
M=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS9W-T
M<B`BQ_9P(&MU='5S=6YD86MI(&5S:VD@:6QE=&EL97(@=&5M:7IL96YS:6X@
M;6D_(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP
M.C8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")0=7)G:6YG("5D(&UE
M<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R("(E9"!I;&5T:2#'
M]G`@2W5T=7-U;F1A;B!T96UI>FQE;FEY;W(N(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")0
M=7)G:6YG(#$@;65S<V%G92!F<F]M(%1R87-H(&9O;&1E<BXB"FUS9W-T<B`B
M)60@:6QE=&D@Q_9P($MU='5S=6YD86X@=&5M:7IL96YI>6]R+B(*"B,Z('1E
M;7!L871E<R]Q=6]T82]Q=6]T82YI;F,Z,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B475O=&$@<W1A='5S.B`E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM
M<V=S='(@(DMO=&$@1'5R=6UU.B`E+C)F34(@+R`E+C)F34(@*"4N,F8E)2DB
M"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250B"FUS
M9W-T<B`B2V]T82!$=7)U;74Z("4N,F9-0B`O(%-)3DE24TE:(@H*(SH@=&5M
M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")1=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM<V=S='(@(DMO=&$@1'5R=6UU
M.B!324Y)4E-)6B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B475O=&EN9R`E9CHB"FUS9W-T<B`B2V]T82`E
M9B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I
M9"`B4F5?<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N(@IM<V=S='(@(E1E
M7W-L:6T@3VYA>6D@W7-T92(*"B,Z(&QI8B]396%R8V@N<&AP.C4P"FUS9VED
M(")296-E:79E9"!/;B(*;7-G<W1R(")487)I:&EN9&4@1V5L96XB"@HC.B!L
M:6(O4V5A<F-H+G!H<#HU.`IM<V=I9"`B4F5C96EV960@4VEN8V4B"FUS9W-T
M<B`B5&%R:6AI;F1E;B!3;VYR82!'96QE;B(*"B,Z(&QI8B]396%R8V@N<&AP
M.C4T"FUS9VED(")296-E:79E9"!5;G1I;"(*;7-G<W1R(")487)I:&EN92!+
M861A<B!'96QE;B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(EGV;FQE;E]D
M:7(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z
M,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(EGV;FQE;F1I<B(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E9&ER
M96-T($UE<W-A9V4B"FUS9W-T<B`B26QE=&EY:2!9]FYL97)D:7(B"@HC.B!C
M;VUP;W-E+G!H<#HW.#<*;7-G:60@(E)E9&ER96-T('1H:7,@;65S<V%G92(*
M;7-G<W1R(")"=2!I;&5T:7EI('GV;FQE;F1I<B(*"B,Z(&-O;7!O<V4N<&AP
M.C@T-PIM<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*;7-G<W1R(")9]FYL
M96YD:7)M92!B8?YA<OUS_7H@;VQD=2XB"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHU.#,*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B665N
M:6QE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X-`IM<V=I9"`B4F5F
M<F5S:"!&;VQD97(@5FEE=W,Z(@IM<V=S='(@(D1I>FEN:2!']G+\;OQM;&5R
M:6YI(%EE;FEL93HB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY
M('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-`IM<V=I9"`B4F5L;V%D
M(@IM<V=S='(@(EEE;FED96X@6?QK;&4B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]H96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R(")']G+\
M;OQM_"!996YI9&5N(%G\:VQE(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C4R-B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-30U"FUS9VED(")2
M96UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R(")3
M97)B97-T+TUE_F=U;"!B:6QG:7EI(&AA=/UR;&$N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDW.0IM<V=I9"`B4F5M96UB97(@=&AE(&QA<W0@=FEE
M=R(*;7-G<W1R(")3;VX@9_9R_&[\;?P@:&%T_7)L82(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PIM<V=I9"`B4F5M;W1E($UA:6QB
M;W@Z(@IM<V=S='(@(E5Z86MT86MI(%!O<W1A($MU='5S=3HB"@HC.B!T96UP
M;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L
M9"!&<F]M(%-E87)C:"(*;7-G<W1R(")!;&%N_2!!<F%M861A;B#'_6MA<B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0IM<V=I
M9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R(")+87EN8?#](.?]:V%R(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z.`IM<V=I9"`B4F5N86UE
M($9O;&1E<BAS*2(*;7-G<W1R(")$:7II;FD@665N:61E;B!!9&QA;F3]<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E;F%M92!S
M96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O9B!M;VYT:#\B"FUS9W-T
M<B`B1_9N9&5R:6QM:?XM<&]S=&$@9&EZ:6YI(&%Y_6X@8F'^_6YD82!Y96YI
M9&5N(&%D;&%N9/UR_6QS_6X@;?T_(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-#4U
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E;F%M:6YG(%PB)7-<(B!T;R!<(B5S
M7"(@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(B(*(EPB)7-<(B!<(B5S7"(@;VQA<F%K('EE;FED96X@861L86YD_7+]
M;&UA<_T@8F'^87+]<_UZ(&]L9'4N4W5N=6-U;G5N("(*(F)E;&ER='1I\&D@
M8G5D=7(@(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$P"FUS9VED(")297!L7WD@=&\@3&ES="(*;7-G<W1R(")?3&ES=&5Y
M:2!986[]=&QA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC
M.C$P-0IM<V=I9"`B4F5P;&%C92!W:71H.B(*;7-G<W1R(")997)I;F4@2V]Y
M.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX
M"FUS9VED(")297!L>2(*;7-G<W1R(")986[]=&QA(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C,Q,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-#`Y"FUS9VED(")297!L>2!396YT+B(*;7-G<W1R(")986[]="!']FYD97)I
M;&1I+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN
M8SHQ,PIM<V=I9"`B4F5P;'D@=&\@06QL(@IM<V=S='(@(DAE<FME<V4@66%N
M_71L82(*"B,Z(&-O;7!O<V4N<&AP.C<S,PIM<V=I9"`B4F5P;'D@=&\@06QL
M.B(*;7-G<W1R(")(97)K97-E(%EA;OUT;&$Z(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$P"FUS9VED(")297!L>2!T;R!,
M:7-T(@IM<V=S='(@(DQI<W1E>64@66%N_71L82(*"B,Z(&-O;7!O<V4N<&AP
M.C<S-0IM<V=I9"`B4F5P;'D@=&\@3&ES=#HB"FUS9W-T<B`B3&ES=&5Y92!9
M86[]=&QA.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ,PIM<V=I9"`B4F5P;'D@=&\@7T%L;"(*;7-G<W1R(")(95]R:V5S
M92!986[]=&QA(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R."!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3,W"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU-#<*;7-G:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E
M9"!-97-S86=E(@IM<V=S='(@(D1E<W1E:VQE;FUE>65N(-UL971I(&EL92!9
M86[]=&QA(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-0IM<V=I
M9"`B4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM
M<V=S='(@(D=E;&5C96L@,B!A>2!IYVEN('-E<F)E<W0O;67^9W5L(&EL92!Y
M86[]=&QA+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G
M:60@(E)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`BW7-T96YE;B!S97)B97-T+VUE_F=U;"!B:6QG:7-I(&EL
M92!Y86[]=&QA+B(*"B,Z(&UE<W-A9V4N<&AP.C(V-PIM<V=I9"`B4F5P;'DM
M5&\B"FUS9W-T<B`B66%N_70M061R97-I(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C0P.0IM<V=I9"`B4F5P;'DM5&\Z("(*;7-G<W1R(")986[]="!!9')E<VDZ
M(@H*(SH@8V]M<&]S92YP:'`Z-S,Q"FUS9VED(")297!L>3HB"FUS9W-T<B`B
M66%N_71L83HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C8*;7-G
M:60@(E)E<&]R="!A<R!);FYO8V5N="(*;7-G<W1R(")496UI>B!/;&%R86L@
M4F%P;W(@170B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*;7-G
M:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S='(@(MUS=&5N;65Y96X@W6QE=&D@
M3VQA<F%K(%)A<&]R($5T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S@S"FUS9VED(")297%U97-T(&$@7U)E860@4F5C96EP="(*;7-G
M<W1R(")/:W5N;6$@7T)I;&=I<VD@W7-T92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU.#4*;7-G:60@(E)E<75E<W0@9&5L:79E<GD@8V]N9FER;6%T
M:6]N/R(*;7-G<W1R(")497-L:6T@0FE?;&=I<VD@W7-T92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-S,*;7-G:60@(E)E<75E<W0@<F5A9"!R96-E
M:7!T<S\B"FUS9W-T<B`B3VMU;F1U(&%L_6YD_7/](&ES=&5N<VEN(&UI/R(*
M"B,Z(&UA:6QB;W@N<&AP.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@
M;F]T(&9O=6YD+B(*;7-G<W1R("+=<W1E;F5N(&EL971I(&)U;'5N86UA9/TN
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y-PIM<V=I9"`B4F5Q
M=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B1V5R96ME;B!+873];/UM8_TB
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP;&%T97,O
M<V5A<F-H+VAE861E<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C$V,0IM<V=I9"`B4F5S970B"FUS9W-T<B`B5&5M:7IL92(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ,34*;7-G:60@(E)E<W!O;F1E;G0@4W1A
M='5S(%5P9&%T960N(@IM<V=S='(@(DMA<O[];/UK($=E;&5N($1U<G5M($?\
M;F-E;&QE;F1I+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHS,`IM<V=I9"`B4F5S=6UE(@IM<V=S='(@(D1E=F%M($5T(@H*
M(SH@<F5C;VUP;W-E+G!H<#HY.`IM<V=I9"`B4F5S=6UE('EO=7(@<V5S<VEO
M;B(*;7-G<W1R(")/='5R=6UU;G5Z82!D979A;2!E9&EN(@H*(SH@=&5M<&QA
M=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")2
M971U<FX@=&\@7")-97-S86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`BW6QE
M=&D@3VQU_G1U<FUA(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?
M<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z
M,S(*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@(E!O<W1A
M($=E=&ER;65Y92!$]F[\;B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHV,"!T96UP;&%T97,O9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C(R"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,3`Q('1E;7!L871E<R]S;6EM
M92]N;W1A8W1I=F4N:6YC.C$T"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ
M-#D@=&5M<&QA=&5S+W!G<"]N;W1A8W1I=F4N:6YC.C$U"B,Z('1E;7!L871E
M<R]A8VPO86-L+FEN8SHQ-C(@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$W,PIM
M<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B4V7G96YE:VQE<F4@
M1/9N_&XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S$X"FUS9VED("(B
M"B)2971U<FX@=&\@=&AE(&UA:6QB;W@@;&ES=&EN9R!A9G1E<B!D96QE=&EN
M9RP@;6]V:6YG+"!O<B!C;W!Y:6YG(&$@;65S<V%G93\B"FUS9W-T<B`B(@HB
MW6QE=&EN:6X@<VEL:6YM97-I;F1E;BQT8?[];FUA<_UN9&%N('9E>6$@:V]P
M>6%L86YM87/];F1A;B!S;VYR82!P;W-T82`B"B)K=71U<W4@;&ES=&5S:6YE
M(&3V;OQL<_QN(&W\/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M.#@*;7-G:60@(E)O;&4B"FUS9W-T<B`B1_9R978B"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C$T,B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C(S-PHC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.0IM<V=I9"`B
M4R]-24U%(@IM<V=S='(@(E,O34E-12(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V5N8W)Y<'1?;&ES="YI;F,Z,3(*;7-G:60@(E,O34E-12!%;F-R>7!T($UE
M<W-A9V4B"FUS9W-T<B`B4R]-24U%(-YI9G)E;&5N;6G^(-UL971I(@H*(SH@
M8V]M<&]S92YP:'`Z,SDT"FUS9VED(")3+TU)344@17)R;W(Z("(*;7-G<W1R
M(")3+TU)344@2&%T87/].B(*"B,Z(&-O;7!O<V4N<&AP.C,W,PIM<V=I9"`B
M4R]-24U%($5R<F]R.B!.965D('!A<W-P:')A<V4@9F]R('!E<G-O;F%L('!R
M:79A=&4@:V5Y+B(*;7-G<W1R(")3+TU)344@2&%T87/].B!+:?YI<V5L(/9Z
M96P@86YA:'1A<B!IYVEN(&=EYVG^('3\;6-E8VGP:2!G97)E:VEY;W(N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,0IM<V=I9"`B4R]-24U%($]P
M=&EO;G,B"FUS9W-T<B`B4R]-24U%(%-EYV5N96ML97)I(@H*(SH@<VUI;64N
M<&AP.C0Y"FUS9VED(")3+TU)344@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R
M(")3+TU)344@1V7G:?X@5/QM8V5C:?!I($=I<FG^:2(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z-30*;7-G:60@(E,O34E-12!097)S;VYA;"!+
M97EP86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I
M;VXN(@IM<V=S='(@(B(*(E,O34E-12!+:?YI<V5L($%N86AT87(@W6MI;&ES
M:2!D97-T9?!I(&?\=F5N;&D@8FER('=E8B!B8?!L86YT_7/]("(*(FES=&5M
M96MT961I<BXB"@HC.B!S;6EM92YP:'`Z,30P"B,L('!H<"UF;W)M870*;7-G
M:60@(E,O34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E<W-F
M=6QL>2!D96QE=&5D+B(*;7-G<W1R(")<(B5S7"(@:>=I;B!3+TU)344@0>?]
M:R!!;F%H=&%R_2!B8?YA<OUY;&$@<VEL:6YD:2X@(@H*(SH@<VUI;64N<&AP
M.C$V,@IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D
M9&5D+B(*;7-G<W1R(")3+TU)344@0>?]:R!!;F%H=&%R_2!B8?YA<OUY;&$@
M96ML96YD:2XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P"FUS
M9VED(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B4R]-24U%($'G
M_6L@06YA:'1A<B!::6YC:7)I(@H*(SH@<VUI;64N<&AP.C(Q,0IM<V=I9"`B
M4R]-24U%(%!U8FQI8R]0<FEV871E($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D
M9&5D+B(*;7-G<W1R(")3+TU)344@0>?]:R_6>F5L($%N86AT87(@W6MI;&ES
M:2!B8?YA<OUY;&$@96ML96YD:2XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]E
M;F-R>7!T7VQI<W0N:6YC.C$S"FUS9VED(")3+TU)344@4VEG;B!-97-S86=E
M(@IM<V=S='(@(E,O34E-12#=;7IA($UE<V%J_2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*;7-G:60@(E,O34E-12!3:6=N
M+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R(")3+TU)344@26UZ82_>:69R92!-
M97-A:OTB"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHT"FUS
M9VED(")3+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E
M;2XB"FUS9W-T<B`B4R]-24U%(&1E<W1E\&D@8G4@<VES=&5M9&4@<V7G:6QE
M;65Z(&O];/UN;?W^=/UR+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP
M:'`Z,C0Q"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N;W0@8W5R<F5N
M=&QY(&5N86)L960@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E("(*
M(F1E8W)Y<'1E9"XB"FUS9W-T<B`B(@HB4R]-24U%(&1E<W1E\&D@>?QR_')L
M_&MT92!D9?!I;"!B=2!N961E;FQE(&EL971I;FEN(/YI9G)E<VEN:6X@Y_9Z
M_&QM97-I("(*(F]L86YA:W/]>BXB"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C$W,PIM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N
M86)L960@<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@
M8V%N(&YO="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(B(*(E,O34E-12!D
M97-T9?!I('G\<OQR;/QK=&4@9&7P:6P@8G4@;F5D96YL92!I;7IA;&%N;?W^
M(&EL971I("(*(F?V<OQN=/QL96YE;65Y8V5K=&ER+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R
M="!I<R!N;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@
M=6YA8FQE('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)3+TU)344@
M9&5S=&7P:2!Y_'+\<FS\:W1E(&1E\&EL(&)U(&YE9&5N;&4@<V%Y_7-A;"!I
M;7IA;OUN(&1O\')U;&%N;6%S_2`B"B)O;&%N86MS_7HN(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHR"B,L(&9U>GIY"FUS9VED("(B"B)3+TU)
M344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N
M("!)9B!Y;W5R(&)R;W=S97(@:7,@(@HB8W5R<F5N=&QY('-E="!T;R!D:7-A
M8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I
M;F<@;W(@96QS92`B"B)T:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O
M<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)3+TU)344@9&5S=&7P:2!B96QI
M<F5N('!E;F-E<F5L97)I(&MU;&QA;FUA:R!I<W1E;65K=&5D:7(N($7P97(@
M=&%R87G]8_UN_7H@(@HB8F5L:7)E;B!P96YC97)E;&5R:2!S9>=I;7-I>B!K
M_6QD_7ES82P@8G4@87EA<OT@9&7P:?YT:7)M96QI<VEN:7HL(&%K<VD@(@HB
M=&%K9&ER9&4@4R]-24U%(/9Z96QL:6ML97)I9&_P<G4@YV%L_?YM87EA8V%K
M=/UR(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,#4*;7-G:60@
M(E--5%`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C4U"FUS9VED(")37W5B:F5C="(*;7-G<W1R(")+;U]N=2(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,V,PIM<V=I9"`B4V%?
M=F4@82!C;W!Y(&EN("(*;7-G<W1R(")+;W!Y87-I;FD@:V%?>61E="(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHS,@IM<V=I
M9"`B4V%?=F4@87,B"FUS9W-T<B`B7T9A<FML_2!+87ED970B"@HC.B!S96%R
M8V@N<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*
M;7-G:60@(E-A=F4B"FUS9W-T<B`B2V%Y9&5T(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE;G1S
M('=I=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R(")%
M:VQE<BP@:6QE=&D@:6QE(&)I<FQI:W1E(&?V;F1E<FEL;6G^('!O<W1A(&1I
M>FEN:6YE(&MA>61E9&EL<VEN(&UI/R(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C0S,PIM<V=I9"`B4V%V92!$<F%F="(*;7-G<W1R(")487-L86L@2V%Y9&5T
M(@H*(SH@<V%V96EM86=E+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B4V%V92!)
M;6%G92(*;7-G<W1R(")&87)K;/T@2V%Y9&5T(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C(P-`IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL97)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI
M;64O;F]T86-T:79E+FEN8SHQ,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X
M"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V
M92!/<'1I;VYS(@IM<V=S='(@(E-EYV5N96ML97)I($MA>61E="(*"B,Z('1E
M;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHT,`HC+"!F=7IZ>0IM<V=I
M9"`B4V%V92!3=&%T:6]N97)Y(@IM<V=S='(@(E-EYV5N96ML97)I($MA>61E
M="(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8Y('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PIM<V=I9"`B4V%V92!?1')A
M9G0B"FUS9W-T<B`B7U1A<VQA:R!+87ED970B"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS
M9W-T<B`B1F%R:VS]($MA>61E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,C$*;7-G:60@(E-A=F4@9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B
M5&%S;&%K;&%R(&?V<OQL;65M:?X@;VQA<F%K(&MA>61E9&EL<VEN(&UI/R`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W,@IM<V=I9"`B4V%V92!R
M96-I<&EE;G1S(&%U=&]M871I8V%L;'D@=&\@=&AE(&1E9F%U;'0@861D<F5S
M<R!B;V]K/R(*;7-G<W1R(")!;/UC_6QA<B#V>F1E=FEN:6UL:2!O;&%R86L@
M=F%R<V%Y_6QA;B!A9')E<R!D969T97)I;F4@:V%Y9&5D:6QS:6X@;6D_(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,C<*;7-G:60@(E-A=F4@
M<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_(@IM<V=S='(@(D%R86UA>?T@
M<V%N86P@9&EZ:6X@;VQA<F%K('-A:VQA(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(S,`IM<V=I9"`B4V%V92!S96YT(&UA:6P_(@IM<V=S='(@(D?V
M;F1E<FEL;6G^('!O<W1A(&MA>61E9&EL<VEN(&UI/R(*"B,Z(&-O;7!O<V4N
M<&AP.C$R,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V:6YG('1H92!D<F%F
M="!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("5S(@IM
M<V=S='(@(E1A<VQA\/UN(&MA>61E9&EL;65S:2!B8?YA<OUS_7H@;VQD=2X@
M4W5N=6-U.B`E<R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,3DY('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB
M+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G
M<W1R(")!<F%M82(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A9&5R+FEN8SHQ
M."!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E-E87)C:"`E<R(*;7-G<W1R(")!<F$Z("5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H
M($]P=&EO;G,B"FUS9W-T<B`B4V7G96YE:VQE<FD@2V%Y9&5T(@H*(SH@<V5A
M<F-H+G!H<#HR-C4*;7-G:60@(E-E87)C:"!297-U;'1S(@IM<V=S='(@(D%R
M86UA(%-O;G7G;&%R_2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,30@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,0IM<V=I9"`B
M4V5E;B(*;7-G<W1R(")/:W5N;77^(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHY"FUS9VED(")396QE8W0B"FUS9W-T<B`B4V7G(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<P"FUS9VED(")396QE
M8W0@06YO=&AE<B!!8V-O=6YT(@IM<V=S='(@(D)A_FMA($)I<B!(97-A<"!3
M9><B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z,S8*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B0FER(%1A<FEH(%-EYVEN(@H*(SH@
M=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C$P"FUS9VED(")396QE8W0@
M82!F:65L9"(*;7-G<W1R(")":7(@06QA;B!39>=I;B(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q-PHC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&$@<W1A=&EO;F5R>3HB"FUS9W-T<B`B0FER(%1A<FEH(%-EYVEN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4V5L96-T(&%D
M9')E<W,@8F]O:R!S;W5R8V5S(&9O<B!A9&1I;F<@86YD('-E87)C:&EN9R!F
M;W(@861D<F5S<V5S+B(*;7-G<W1R(")!9')E<R!E:VQE;64@=F4@87)A;6$@
M:>=I;B!A9')E<R!D969T97)I(&MA>6YA:VQA<OUN_2!S9>=I;BXB"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C@X"FUS9VED(")396QE8W0@86QL
M(@IM<V=S='(@(DAE<'-I(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E
M;&5C="YI;F,Z,S(S"FUS9VED(")396QE8W0@86QL(&9I96QD<R!T;R!S96%R
M8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R(")!9')E<VQE
M<FD@9V5N:?YL971I<FME;B!A<F%M82!IYVEN(&+\=/QN(&%L86YL87+]('-E
MYRXB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN
M8SHR,0IM<V=I9"`B4V5L96-T(&%N(&%C8V]U;G0B"FUS9W-T<B`B0FER(&AE
M<V%P('-EYVEN(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B2&GG8FER:2(*"B,Z('1E;7!L
M871E<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS9VED(")396QE8W0@
M=&AE(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*
M;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP92(*;7-G<W1R(")0
M;W-T82!S=6YU8W5S=2!T_'+\;OP@<V7G:6XB"@HC.B!T96UP;&%T97,O<')E
M9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*;7-G:60@(E-E;&5C=&5D($%D9')E
M<W,@8F]O:W,Z(@IM<V=S='(@(E-EYVEL;6G^($%D<F5S($1E9G1E<FQE<FDZ
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")396YD($ME
M>2!T;R!0=6)L:6,@2V5Y<V5R=F5R(@IM<V=S='(@(D%N86AT87+]($'G_6L@
M06YA:'1A<B!3=6YU8W5S=6YA($?V;F1E<B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,#0*;7-G:60@(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N
M(@IM<V=S='(@(E-O;B!":6QG:6QE<FD@1_9N9&5R(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#,Q"FUS9VED(")396YD($UE<W-A9V4B"FUS9W-T<B`BW6QE
M=&D@1_9N9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<P,PHC+"!F
M=7IZ>0IM<V=I9"`B4V5N9"!R96%D(')E8V5I<'0@=VAE;B!R97%U97-T960@
M8GD@=&AE('-E;F1E<C\B"FUS9W-T<B`B1_9N9&5R96X@=&%R86;];F1A;B!I
M<W1E;F1I\&EN9&4@341.(&?V;F1E<FEL<VEN(&UI/R(*"B,Z(&9O;&1E<G,N
M<&AP.C,Y-PIM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G<W1R(")']FYD
M97)I;&UI_B!P;W-T82!D:7II;FDB"@HC.B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C,X"FUS9VED(")396YT(&UA:6P@9F]L9&5R.B(*
M;7-G<W1R(")']FYD97)I;&UI_B!P;W-T82!D:7II;FDZ(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,S(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHQ-#8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-3,*;7-G
M:60@(E-E<G9E<B(*;7-G<W1R(")3=6YU8W4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,*;7-G:60@(E-E<G9E<B!A;F0@1F]L9&5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(E-U;G5C=2!V92!$:7II;B!":6QG:6QE<FDB"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E<G9E
M<CHB"FUS9W-T<B`B4W5N=6-U.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,`IM<V=I9"`B4V5T('!R969E<F5N8V5S(&9O<B!W:&%T(&AA<'!E;G,@
M=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+B(*;7-G<W1R("(B
M"B+=;&5T:6QE<FD@=&'^_6UA;OUZ('EA9&$@<VEL;65N:7H@9'5R=6UU;F1A
M:VD@=&5R8VEH;&5R:6YI>FD@8F5L:7)L97EI;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET>2!H96%D
M97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(MUL971I(&]L
M=?YT=7)U<FME;B!8+5!R:6]R:71Y(&)A_FS]\/T@:V]N<W5N(&UU/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0IM<V=I9"`B4VAA<F4@1F]L9&5R
M<R(*;7-G<W1R(")087EL8?[];2!$:7II;FQE<FDB"@HC.B!T96UP;&%T97,O
M86-L+V%C;"YI;F,Z.#8*;7-G:60@(E-H87)E(&UA:6P@9F]L9&5R<R(*;7-G
M<W1R(")087EL8?[];&%N('!O<W1A(&1I>FEN;&5R:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E
M<G,@=VET:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`B1&GP97(@:W5L;&%N_6/]
M;&%R;&$@<&]S=&$@9&EZ:6YL97)I;FD@<&%Y;&'^+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-CD*;7-G:60@(B(*(E-H;W5L9"!L87)G92!B;&]C
M:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO=VX@;W(@:&ED9&5N(&)Y(&1E9F%U
M;'0_($ET(&-A;B!B92`B"B)T;V=G;&5D(&5A<VEL>2!W:&EC:&5V97(@>6]U
M(&-H;V]S92XB"FUS9W-T<B`B(@HB0OQY_&L@]F)E:VQI(&%L_6YT_2!Y87#]
M;&W]_B!S873]<FQA<B#V;G1A;OUM;/T@;VQA<F%K(&?V<W1E<FEL<VEN('EA
M9&$@(@HB9VEZ;&5N<VEN(&UI/RY(86YG:7-I('-EYVEL:7)S92!S9>=I;'-I
M;B!D:?!E<FEN92!K;VQA>6S]:VQA(&=EYVEL96)I;&ER+B(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW"FUS9VED(")3:&]U;&0@=&AE(&)O9'D@;V8@
M=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N;F5D(&9O<B!01U`@9&%T83\B
M"FUS9W-T<B`B1/QZ(&UE=&EN(&EL971I;&5R:6X@:>=E<FGP:2!01U`@=F5R
M:7-I(&GG:6X@=&%R86YS_6X@;?T_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Q,PIM<V=I9"`B4VAO=6QD('1H92!C;VUP;W-E('=I;F1O=R!B92!C
M;&]S960@869T97(@<V%V:6YG(&$@9')A9G0_(@IM<V=S='(@(D)I<B!T87-L
M86L@:V%Y9&5D:6QD:6MT96X@<V]N<F$@;VQU_G1U<FUA('!E;F-E<F5S:2!K
M87!A;G/];B!M_3\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I
M9"`B4VAO=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@
M=&\@>6]U<B!M97-S86=E<R!B>2!D969A=6QT/R(*;7-G<W1R(")687)S87G]
M;&%N(&]L87)A:R!01U`@8>?]:R!A;F%H=&%R_2!I;&5T:6YI>F4@96ML96YS
M:6X@;6D_(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHY,@IM<V=I
M9"`B4VAO=R!!;&P@1F]L9&5R<R(*;7-G<W1R(")"_'3\;B!$:7II;FQE<FD@
M1_9S=&5R(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-C<*
M;7-G:60@(E-H;W<@06QL($AE861E<G,B"FUS9W-T<B`B0OQT_&X@0F'^;/UK
M($)I;&=I<VEN:2!']G-T97(B"@HC.B!M86EL8F]X+G!H<#HS-C4*;7-G:60@
M(E-H;W<@1&5L971E9"(*;7-G<W1R(")3:6QI;F5C96ML97)I($?V<W1E<B(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED(")3
M:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R(")3_6[]<FQA;FW]_B!"8?YL
M_6L@0FEL9VES:6YI($?V<W1E<B(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C<P"FUS9VED(")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA
M=&EO;B(*;7-G<W1R(")%;&5K=')O;FEK(%!O<W1A($QI<W1E($)I;&=I<VEN
M:2!']G-T97(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.CDR"FUS
M9VED(")3:&]W($]N;'D@4W5B<V-R:6)E9"!&;VQD97)S(@IM<V=S='(@(E-A
M9&5C92#<>64@3VQU;FUU_B!$:7II;FQE<FD@1_9S=&5R(@H*(SH@9F]L9&5R
M<RYP:'`Z,CDX"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R("+<
M>64@3VQU;FUA;?W^;&%R_2!']G-T97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C`X"FUS9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@<W1R:7!P
M:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S='(@(MUL
M971I;&5R9&5N(&5K;&5R:2!A;&UA>6$@:7II;B!V97)M96L@:>=I;B!B:7(@
M<VEM9V4@9_9S=&5R:6QS:6X@;6D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P,#(*;7-G:60@(E-H;W<@;&5G96YD(&EN('1H92!M86EL8F]X('9I
M97<_(@IM<V=S='(@(E!O<W1A(&MU='5S=2!G]G+\;G3\<_QN9&4@9_9S=&5R
M9V4@8G5L=6YS=6X@;74_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T
M,`IM<V=I9"`B4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE<W-A9V5S(&]N
M;'D_(@IM<V=S='(@(E-A9&5C92!O:W5N;6%M_?X@:6QE=&EL97(@:>=I;B!M
M:2#V;FEZ;&5M92!G]G-T97)I;'-I;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#0X"FUS9VED(")3:&]W('!R979I97=S(&EN('1O;VQT:7!S/R(*
M;7-G<W1R(")!<F'G(&EP=>=L87+];F1A(/9N:7IL96UE(&?V<W1E<FEL<VEN
M(&UI/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-S<*;7-G:60@(E-H
M;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T
M<B`B365N_"#G=6)U\'5N9&$@4&]S=&$@1V5T:7(@<VEM9V5S:2!G]G-T97)I
M;'-I;B!M:3\B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.34*;7-G
M:60@(E-H;W<@=&AE($EM86=E<R(*;7-G<W1R(")']G+\;G3\;&5R:2!']G-T
M97(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-30*;7-G:60@
M(E-H;W<@=&AE(&9I;'1E<B!I8V]N(&]N('1H92!M96YU8F%R/R(*;7-G<W1R
M(")-96[\(.=U8G7P=6YD82!S_'IG9><@<VEM9V5S:2!G]G-T97)I;'-I;B!M
M:3\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R>2YP:'`Z,C@*;7-G:60@(E-H;W<@
M=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O;&1E<C\B"FUS9W-T<B`B1&EZ
M:6YD96MI('1O<&QA;2!P;W-T82!S87G]<_T@9_9S=&5R:6QS:6X@;6D_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V-@IM<V=I9"`B4VAO=VXB"FUS
M9W-T<B`B1_9S=&5R:6QE;B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z-#(*;7-G:60@(E-I7WIE(@IM<V=S='(@(D)O7WEU
M="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z,3<*;7-G:60@
M(E-I9VYE9"(*;7-G<W1R("+<>64@;VQD=6YU>BXB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM<V=I9"`B4VEZ92(*;7-G<W1R
M(")";WEU="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,3$*;7-G:60@(E-O<G0@8GD@07)R:79A;"(*;7-G<W1R(")'96QI
M_B!:86UA;OUN82!']G)E(%/]<F%L82(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,38*;7-G:60@(E-O<G0@8GD@1&%T92(*
M;7-G<W1R(")487)I:&4@1_9R92!3_7)A;&$B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(V"FUS9VED(")3;W)T(&)Y($9R
M;VT@061D<F5S<R(*;7-G<W1R(")'96QE;B!!9')E<V4@1_9R92!3_7)A;&$B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0Q
M"FUS9VED(")3;W)T(&)Y($UE<W-A9V4@4VEZ92(*;7-G<W1R("));&5T:2!"
M;WEU='5N82!']G)E(%/]<F%L82(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z,S8*;7-G:60@(E-O<G0@8GD@4W5B:F5C="(*
M;7-G<W1R(")+;VYU>6$@1_9R92!3_7)A;&$B"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,Q"FUS9VED(")3;W)T(&)Y(%1H
M<F5A9"(*;7-G<W1R(")+;VYU(-9B9?!I;F4@1_9R92!3_7)A;&$B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C(Q"FUS9VED
M(")3;W)T(&)Y(%1O($%D9')E<W,B"FUS9W-T<B`B061R97-E($?V<F4@4_UR
M86QA(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S"FUS
M9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`BW7-T96YM97EE;B!I;&5T:2!D
M:7II;FDZ(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0V
M"FUS9VED(")3<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T<B`BUGIE;"!+87)A
M:W1E<FQE<B(*"B,Z('-E87)C:"YP:'`Z,3,S"FUS9VED(")3<&5C:6%L(%9I
M<G1U86P@1F]L9&5R<R!C86X@;F]T(&)E(&5D:71E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0S"FUS9VED(")3
M<&5L;"!#:&5C:R(*;7-G<W1R(")987K];2!$96YE=&EM:2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT-@IM<V=I9"`B4W!E;&P@0VAE
M8VME<B(*;7-G<W1R(")987K];2!$96YE=.=I<VDB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@@=&5M<&QA=&5S+V-O;7!O<V4O<W!E
M;&QI;F<N:6YC.C4V"FUS9VED(")3<&5L;"!C:&5C:R!C;VUP;&5T92(*;7-G
M<W1R(")987K];2!D96YE=&EM:2!T86UA;6QA;F3](@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0W,0IM<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S
M8W)E96X@=VAE;B!S<&5L;"!C:&5C:VEN9RXB"FUS9W-T<B`B66%Z_6T@9&5N
M971I;6ES:2!S_7)A<_UN9&%K:2!E:W)A;B!B8?[];F$@9/S^96X@>6%Z_6T@
M:&%T86QA<OTB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3$R(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3(*;7-G:60@(E-T87)T(@IM<V=S
M='(@(D)A_FQA="(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHY('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,Q,0IM<V=I9"`B
M4W1A=&EO;F5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R
M>2]P<F5F<RYI;F,Z,C8*;7-G:60@(E-T871I;VYE<GD@;F%M93HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(X"FUS
M9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S=&%T:6]N97)Y+W!R969S+FEN8SHS,PIM<V=I9"`B4W1A=&EO;F5R>3HB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8X.`IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(D1U<G5M(@H*(SH@;&EB+TU)344O0V]N
M=&5N=',N<&AP.C(Q-0IM<V=I9"`B4W1R:7`@071T86-H;65N="(*;7-G<W1R
M(")%:VQE<FD@Q_UK87)T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S
M,@IM<V=I9"`B4W1R:7`@;&EN96)R96%K<S\B"FUS9W-T<B`B4V%T_7(@4V]N
M;&%R_6[](,?]:V%R="(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,S<*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(DMO;E]U
M(@H*(SH@;65S<V%G92YP:'`Z,C8X('1H<F5A9"YP:'`Z,34P('1E;7!L871E
M<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z,C4*(SH@;&EB+U-E87)C:"YP:'`Z
M,S@*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B2V]N=2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,C`*;7-G:60@(E-U8FIE8W0@1FEE;&0B"FUS9W-T
M<B`B2V]N=2!!;&%N_2(*"B,Z('-E87)C:"YP:'`Z,S$X('1E;7!L871E<R]S
M879E:6UA9V4O<V%V96EM86=E+FEN8SHQ.`HC.B!T96UP;&%T97,O<VUI;64O
M<&%S<W!H<F%S92YI;F,Z,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN
M8SHS,0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(D?V;F1E<B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Q"FUS9VED(")3=6)S8W)I8F4@
M=&\@1F]L9&5R*',I(@IM<V=S='(@(D1I>FEN92#\>64@;VPB"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C,X,"!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HS.#D*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#<*;7-G
M:60@(E-U8V-E<W,B"FUS9W-T<B`B0F'^87+](@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G
M<W1R("+6;F5R:6QE<B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV
M-C(@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B4W5M;6%R
M>2(*;7-G<W1R("+6>F5T(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#`P('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0P,PIM
M<V=I9"`B4W=I=&-H($-O;7!O<VET:6]N($UE=&AO9"(*;7-G<W1R(")/;'7^
M='5R;6$@6?9N=&5M:6YI($1E\&G^=&ER(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-#`T"FUS9VED(")3=VET8V@@=&\@2%1-3"!C;VUP
M;W-I=&EO;B(*;7-G<W1R(")(5$U,($]L87)A:R!/;'7^='5R;6%Y82!'9><B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@
M(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@(E-A
M9&4@365T:6X@3VQA<F%K($]L=?YT=7)M87EA($=EYR(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Q.0IM<V=I9"`B5&5?>'0B"FUS9W-T
M<B`B35]E=&EN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V.0IM
M<V=I9"`B5&5N=&%T:79E.B`B"FUS9W-T<B`B1V7G:6-I.B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A=&EV96QY($%C
M8V5P="!R97%U97-T(@IM<V=S='(@(MUS=&7P:2!G9>=I8VD@;VQA<F%K(&MA
M8G5L(&5T(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V,0IM<V=I
M9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B1V7G:6-I(&]L87)A
M:R!K86)U;"!E9&EL9&DB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")497)M<R!O
M9B!397)V:6-E(&9I;&4@;F]T('-P96-I9FEE9"!I;B!C;VYF+G!H<"(*;7-G
M<W1R(")(:7IM970@2V_^=6QL87+](&1O<WEA<_T@8V]N9BYP:'`@9&]S>6%S
M_6YD82!B96QI<G1I;&UE;6G^(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C,P"B,L(&9U>GIY"FUS9VED(")497AT(@IM<V=S='(@(DU?
M971I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-30*;7-G:60@(E1H
M92!&<F]M.B!C;VQU;6X@;V8@=&AE(&UE<W-A9V4@<VAO=6QD(&)E(&QI;FME
M9#HB"FUS9W-T<B`BW6QE=&EN:6X@2VEM9&5N.B!K;VQO;G4@8F'P;&%N;6%L
M_3HB"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4S,@IM<V=I9"`B(@HB5&AE
M($E-05`@<V5R=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A
M=71H96YT:6-A=&EO;B!M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT
M86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H
M92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R(")-86-I;G1O<V@@
M9&]S>6%S_6[];B!K87EN86L@:_US;?TB"@HC.B!L:6(O34E-12]6:65W97(O
M87!P;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!-
M86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RXB
M"FUS9W-T<B`B36%C:6YT;W-H(&1O<WEA<_UN_6X@:V%Y;F%K(&O]<VW]('G\
M:VQE;F5B:6QI<CH@)7,B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(EPB)7-<(B!H97-A8OT@<VEL:6YD:2XB"@HC
M.B!F971C:&UA:6QP<F5F<RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")<
M(B5S7"(@:&5S86+](&MA>61E9&EL9&DN(@H*(SH@871T86-H;65N="YP:'`Z
M-#,*;7-G:60@(E1H92!A='1A8VAM96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(D5K(&)U;'5N86UA9/TN(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8Y"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM
M<V=S='(@(E1A:W9I;2!V97)I<VD@9V7G97)S:7HN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C;VUP;W-E7W=I;BYJ<SHS-PIM<V=I9"`B(@HB
M5&AE(&-O;7!O<V4@=VEN9&]W(&-A;B=T(&)E(&]P96YE9"X@4&5R:&%P<R!Y
M;W4@:&%V92!S970@>6]U<B!B<F]W<V5R('1O("(*(F)L;V-K('!O<'5P('=I
M;F1O=W,_(@IM<V=S='(@(B(*(D]L=?YT=7)M82!P96YC97)E<VD@8>?];&%M
M863]+E1A<F%Y_6/];OUZ(&)E;&ER96X@<&5N8V5R96QE<FEE;F=E;&QE;65Y
M92`B"B)A>6%R;&%N;?W^(&]L86)I;&ER+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]A<'!L961O=6)L92YP:'`Z-#(*;7-G:60@(E1H92!C;VYT96YT<R!O9B!T
M:&4@36%C:6YT;W-H(&9I;&4@87)E(&)E;&]W+B(*;7-G<W1R(")-86-I;G1O
M<V@@9&]S>6%S_6[];B!IYV5R:?!I(&'^8?#]9&%D_7(N(@H*(SH@;&EB+TUA
M:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO;G1H;'DN<&AP.C@W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C=7)R96YT(&9O;&1E<BAS*2!<
M(B5S7"(@=VEL;"!B92!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`B6?QR
M_&S\:W1E:VD@7"(E<UPB(&1I>FEN:2!<(B5S7"(@;VQA<F%K('EE;FED96X@
M861L86YD_7+];&%C86LN(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$P
M-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H(&%C
M8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D(@IM
M<V=S='(@(D)U(&1I>FEN92!E<FG^:6UI(&]L86X@:W5L;&%N_6/](&QI<W1E
M<VD@9V5T:7)I;&5M961I(@H*(SH@8V]M<&]S92YP:'`Z,3(S-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9')A9G0@:&%S(&)E96X@<V%V960@=&\@=&AE
M(%PB)7-<(B!F;VQD97(N(@IM<V=S='(@(E1A<VQA:R!<(B5S7"(@9&EZ:6YI
M;F4@:V%Y9&5D:6QD:2XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3,Y"FUS9VED(")4:&4@979E;G0@=V%S(&%D9&5D('1O('EO=7(@8V%L96YD
M87(N(@IM<V=S='(@(D]L87D@=&%K=FEM:6YI>F4@96ML96YD:2XB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]E>'!A;F0N:6YC.CD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!F:65L9"!<(B5S7"(@8V%N)W0@8F4@97AP86YD
M960N(@IM<V=S='(@(B<E<R<@86QA;OT@9V5N:?YL971I;&5M:7EO<BXB"@HC
M.B!L:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B7"(E<UPB
M(&1I>FEN:2!Z871E;B!V87(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,38S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!F;VQD97(@7"(E<UPB(&-O;G1A
M:6YS(&EL;&5G86P@8VAA<F%C=&5R<R!I;B!I=',@;F%M92X@270@;6%Y(&-A
M=7-E("(*(G!R;V)L96US+B!0;&5A<V4@<V5E('EO=7(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*(EPB)7-<(B!D:7II;FD@863];F1A(&=E
MYV5R<VEZ(&MA<F%K=&5R;&5R(&GG97)M96MT961I<BY"=2!P<F]B;&5M;&5R
M92!Y;VP@(@HB8>=A8FEL:7(N3/QT9F5N('-I<W1E;2!Y]FYE=&EC:6YI>FQE
M(&?V<OS^_&XN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4V"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!C<F5A=&5D(&)U="!Y
M;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!I="XB"FUS9W-T<B`B7"(E<UPB
M(&1I>FEN:2!Y87)A=/UL9/T@86UA(&1I>FEN92#\>64@9&7P:6QS:6YI>BXB
M"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO
M="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS9W-T<B`B7"(E<UPB(&1I>FEN
M:2!S:6QI;F1I(&%M82!D:7II;B!IYVEN(/QY96QI\&4@9&5V86T@961I>6]R
M<W5N=7HN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S0S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@8W)E871E9"X@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")<(B5S7"(@9&EZ
M:6YI('EA<F%T_6QA;6%D_2X@4W5N=6-U(&)U;G4@8F5L:7)T;65K=&5D:7(N
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,C8U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!N;W0@9&5L971E9"X@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9"(*;7-G<W1R(")<(B5S7"(@9&EZ:6YI('-I
M;&EN96UE9&DN4W5N=6-U(&)U;G4@8F5L:7)T;65K=&5D:7(B"@HC.B!L:6(O
M1F]L9&5R+G!H<#HS-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E
M<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D+B(*;7-G<W1R(")<
M(B5S7"(@9&EZ:6YI(&)A_F%R_7EL82!Y87)A=/UL9/TN(@H*(SH@;&EB+T9O
M;&1E<BYP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@
M7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@9&5L971E9"XB"FUS9W-T<B`B7"(E
M<UPB(&1I>FEN:2!B8?YA<OUY;&$@<VEL:6YD:2XB"@HC.B!L:6(O1F]L9&5R
M+G!H<#HT-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@=V%S('-U8V-E<W-F=6QL>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T
M<B`B7"(E<UPB(&1I>FEN:2!<(B5S7"(@;VQA<F%K(&)A_F%R_7EL82!Y96YI
M9&5N(&%D;&%N9/UR_6QD_2XB"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I;F<@9FEL97,@=V5R92!A='1A8VAE
M9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@(E1A:VEP(&5D96X@9&]S>6%L87(@
M8G4@:_US;6$@96ML96YD:3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7W-A=F5I;6%G95]W:6XN:G,Z,3(*(RP@9G5Z>GD*;7-G:60@(B(*(E1H
M92!I;6%G92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P
M<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P
M('=I;F1O=W,_(@IM<V=S='(@(B(*(D]L=?YT=7)M82!P96YC97)E<VD@8>?]
M;&%M863]+E1A<F%Y_6/];OUZ(&)E;&ER96X@<&5N8V5R96QE<FEE;F=E;&QE
M;65Y92`B"B)A>6%R;&%N;?W^(&]L86)I;&ER+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B(@HB5&AE(&EM86=E<R!W:6QL(&)E
M(&1I<W!L87EE9"!B96-A=7-E('1H92!S96YD97(@:7,@<')E<V5N="!I;B!Y
M;W5R("(*(F%D9')E<W-B;V]K+B(*;7-G<W1R("(B"B)']FYD97)E;B!A9')E
M<R!D969T97)I;FEZ9&4@:V%Y_71L_2!O;&1U\'4@:>=I;B!G]G+\;G3\;&5R
M(&?V<W1E<FEL96-E:W1I<BXB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@(D5L96MT<F]N:6L@
M<&]S=&$@<W5N=6-U<W4@=&%K:7`@961E;B!H871A(&UE<V%J_6[](/QR971T
M:3HB"@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HU,0IM
M<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG
M(&EN9F]R;6%T:6]N86P@;65S<V%G93HB"FUS9W-T<B`B16QE:W1R;VYI:R!P
M;W-T82!S=6YU8W4@=&%K:7`@961E;B!B:6QG:2!M97-A:OUN_2#\<F5T=&DZ
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3`*;7-G:60@(E1H
M92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O;&QO=VEN9R!M97-S86=E
M.B(*;7-G<W1R(")%;&5K=')O;FEK('!O<W1A('-U;G5C=7-U('1A:VEP(&5D
M96X@;65S86K](/QR971T:3HB"@HC.B!L:6(O365S<V%G92YP:'`Z-C4Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!M86EL8F]X("5S(&ES(&%L<F5A9'D@
M96UP='DN(@IM<V=S='(@(B5S('!O<W1A(&MU='5S=2!Z871E;B!B;_XN(@H*
M(SH@;&EB+T9E=&-H;6%I;"YP:'`Z,C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!M97-S86=E(%PB)7-<(B!F<F]M(%PB)7-<(B`H)60@8GET97,I(&5X
M8V5E9',@9F5T8V@@<VEZ92!L:6UI="XB"FUS9W-T<B`B(@HBW6QE=&D@7"(E
M<UPB("A<(B5S7"(@9&5N(&=E;&5N*2`H)60@8GET92D@9V5T:7)M92!B;WEU
M="!L:6UI=&EN:2!A_FUA:W1A9/UR+B(*"B,Z('1E;7!L871E<R]C;VYT86-T
M<R]C;VYT86-T<RYI;F,Z,3`S"FUS9VED(")4:&4@;65S<V%G92!B96EN9R!C
M;VUP;W-E9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(D]L
M=?YT=7)U;&%N(&EL971I(&MA<&%T_6QD_2['_6O]_B!Y87#];/UY;W(N(@H*
M(SH@;65S<V%G92YP:'`Z,30X"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R("+=;&5T:2!S:6QI;F1I+B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,Y,PIM<V=I9"`B5&AE(&UE<W-A9V4@:&%S
M(&)E96X@=F5R:69I960N(@IM<V=S='(@(MUL971I(&1O\')U;&%N9/TN(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&UE<W-A9V4@:&%S(&)E96X@=F5R:69I960N(%-E;F1E
M<CH@)7,N(@IM<V=S='(@(MUL971I(&1O\')U;&%N9/TN($?V;F1E<F5N.B`E
M<RXB"@HC.B!T96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@
M=&5M<&QA=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H
M92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@
M>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W
M:6YD;W=S/R(*;7-G<W1R("(B"B)'9>=I_B!T_&UC96-I\&D@<&5N8V5R97-I
M(&'G_6QA;6%D_2Y487)A>?UC_6[]>B!B96QI<F5N('!E;F-E<F5L97)I("(*
M(F5N9V5L;&5M97EE(&%Y87)L86YM_?X@;VQA8FEL:7(N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!R87<@=&5X="!O9B!T:&4@4$=0(%!U8FQI8R!+97D@8V%N(&)E('9I97=E
M9"`E<RXB"FUS9W-T<B`B4$=0($'G_6L@06YA:'1A<OUN_6X@:&%M(&UE=&EN
M(&AA;&D@9_9R_&QE8FEL:7(Z)7,B"@HC.B!L:6(O34E-12]6:65W97(O=&YE
M9BYP:'`Z-C`*;7-G:60@(E1H92!R97%U97-T960@9FEL92!D;V5S(&YO="!E
M>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("+=<W1E
M;F5N(&1O<WEA($U3+51.148@96MI;F1E(&)U;'5N;6%M86MT863]<BXB"@HC
M.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV-`IM<V=I9"`B5&AE(')E<75E
M<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN('1H92!::7`@871T86-H;65N
M="XB"FUS9W-T<B`BW7-T96YE;B!D;W-Y82!::7`@96MI;F1E(&)U;'5N;6%M
M86MT863]<BXB"@HC.B!M97-S86=E+G!H<#HU-#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S
M=&EN9R!A($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("(*(F9R
M;VT@>6]U('=H96X@>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S
M92!C;&EC:R`E<R!T;R!S96YD('1H92`B"B)N;W1I9FEC871I;VX@;65S<V%G
M92XB"FUS9W-T<B`B(@HB0G4@:6QE=&EY:2!G]FYD97)E;B!S:7ID96X@:6QE
M=&EN:6X@8F'^87+]>6QA('5L8?YT_?#];OT@=F4@<VEZ:6X@;VMU\'5N=7IU
M("(*(F)I;&1I<F5N(&)I<B!U>6%R_2!G]FYD97)M96YI>FD@:7-T96UE:W1E
M9&ER+DS\=&9E;B!G]FYD97)M96L@:>=I;B`E<R`B"B+\>F5R:6YE('3]:VQA
M>?UN+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED
M(")4:&4@<V5R=F5R('=A<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA
M:6P@;V8@=&AI<R!I;6%G92XB"FUS9W-T<B`B4W5N=6-U(&)U(&?V<OQN=/QN
M_&X@;6EN>6%T_'(@8F]Y=71U;G4@>6%R871A;6%D_2XB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FIS.C$P-`IM<V=I9"`B5&AE('-I9VYA='5R
M92!C;W5L9"!N;W0@8F4@<F5P;&%C960N(@IM<V=S='(@(MUM>F$@>65R:6YE
M(&MO;F%M863]+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z
M,3`R"FUS9VED(")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S9G5L;'D@<F5P
M;&%C960N(@IM<V=S='(@(MUM>F$@8F'^87+]>6QA('EE<FEN92!K;VYD=2XB
M"@HC.B!A='1A8VAM96YT+G!H<#HU.0IM<V=I9"`B5&AE('-P96-I9FEE9"!F
M:6QE(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")"96QI<G1I;&5N(&1O<WEA
M(&)U;'5N;6%M86MT863]<BXB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB
M(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R(")<(B5S7"(@:&5S86+](&MA>61E
M9&EL9&DN(@H*(SH@<W1A=&EO;F5R>2YP:'`Z-C,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R(")<(B5S7"(@:&5S86+]('-I;&EN9&DN(@H*(SH@
M<W1A=&EO;F5R>2YP:'`Z.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!U<&1A=&5D+B(*;7-G
M<W1R(")<(B5S7"(@:&5S86+]('-I;&EN9&DN(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$V.0IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@861D
M960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B0G4@9_9R978@9_9R978@
M;&ES=&5N:7IE(&5K;&5N9&DN(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z.34*;7-G:60@(E1H92!T97AT(&]F('1H92!M97-S86=E(@IM<V=S
M='(@(MUL971I;FEN(&UE=&YI(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U
M<RYP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS9W-T<B`BW6QE=&EN:6X@
M;65T;FD@9_9R_&QE8FEL:7(Z("5S+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.C@P"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@
M;65S<V%G92(*;7-G<W1R(")$]FYE;B!I;&5T:6YI;B!M971N:2(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(D3V;F5N(&EL971I;FEN(&UE=&YI("!G]G+\
M;&5B:6QI<CH@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-C@*;7-G:60@(E1H92!T97AT(&]F('1H92!S96YT(&UE<W-A9V4B
M"FUS9W-T<B`B1_9N9&5R:6QM:?X@:6QE=&EN:6X@;65T;FDB"@HC.B!L:6(O
M34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V
M:65W960@)7,N(@IM<V=S='(@(D?V;F1E<FEL;6G^(&EL971I;FEN(&UE=&YI
M(&?V<OQL96)I;&ER.B`E<RXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,34T"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R(")+=6QL86[]8_UN
M_6X@<V5R8F5S="]M9?YG=6P@8FEL9VES:2!B8?YA<OUY;&$@9&5P;VQA;F3]
M+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z.#8*;7-G
M:60@(E1H97)E(&%R92!N;R!A;'1E<FYA=&EV92!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")-971N92!G]FW\;/P@;VQA
M<F%K(&?V<W1E<FEL96)I;&5C96L@;VQA<_T@:_US_6TH;&%R*2!B=6QU;FUA
M;6%K=&%D_7(N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O
M>"YI;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@
M;6%I;&)O>"XB"FUS9W-T<B`B0G4@<&]S=&$@:W5T=7-U;F1A(&EL971I(&)U
M;'5N;6%M86MT863]<BXB"@HC.B!T:')E860N<&AP.C$P.0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+B(*;7-G<W1R(")-971N92!G]FW\;/P@;VQA<F%K(&?V<W1E<FEL
M96)I;&5C96L@;VQA<_T@:_US_6TH;&%R*2!B=6QU;FUA;6%K=&%D_7(N(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C8Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(&5X<'5N9VEN9R`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9"(*;7-G<W1R("(E<R`@<VEL:6YI<FME;B!S;W)U
M;B!O;'7^='4N4W5N=6-U(&)U;G4@8FEL9&ER;65K=&5D:7(N(@H*(SH@;&EB
M+TUE<W-A9V4N<&AP.C8U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E
M<B!S86ED.B`E<R(*;7-G<W1R(")0;W-T82!K=71U<W5N=6X@<VEL:6YM97-I
M;F1E('-O<G5N(&]L=?YT=2Y3=6YU8W4Z("5S(@H*(SH@;&EB+TUE<W-A9V4N
M<&AP.C8R,0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@
M=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS
M9W-T<B`B4&]S=&$@:W5T=7-U;G5N('-I;&EN;65S:6YD92!S;W)U;B!O;'7^
M='4N4W5N=6-U(&)U;G4@8FEL9&ER;65K=&5D:7(N(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!C;W!Y:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<
M(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B
M"B+=;&5T:6QE<FD@7"(E<UPB(&MO;G5M=6YD86X@7"(E<UPB(&MO;G5M=6YA
M(&MO<'EA;&%R:V5N(&AA=&$@;VQU_G1U+E-U;G5C=2`B"B)B=6YU(&)I;&1I
M<FUE:W1E9&ER+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HQ.3@@;&EB+TUE<W-A
M9V4N<&AP.C(Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@9G)O;2!T:&4@9F]L9&5R(%PB
M)7-<(BX@5&AI<R!I<R!W:&%T("(*(G1H92!S97)V97(@<V%I9"(*;7-G<W1R
M("(B"B+=;&5T:6QE<B!<(B5S7"(@9&EZ:6YD96X@<VEL:6YI<FME;B!H871A
M(&]L=?YT=2Y3=6YU8W4@8G5N=2!B:6QD:7)M96MT961I<BXB"@HC.B!L:6(O
M365S<V%G92YP:'`Z,C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R
M(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G
M<W1R("(B"B+=;&5T:6QE<B!<(B5S7"(@9&EZ:6YI;F1E;B!S:6QI;FER:V5N
M(&AA=&$@;VQU_G1U+E-U;G5C=2!B=6YU(&)I;&1I<FUE:W1E9&ER+B(*"B,Z
M(&QI8B]-97-S86=E+G!H<#HR,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("+=;&5T:6QE<FEN('-I
M;&EN;65S:6YD92!H871A(&]L=?YT=2Y3=6YU8W4Z("5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G
M<W1R(")/;&%Y_6X@<VEL:6YM97-I;F1E(&AA=&$@;VQU_G1U.B`E<RXB"@HC
M.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R(&QI8B]-24U%+U9I97=E
M<B]E;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(MUL971I;FEN
M(&)U(&O]<VW];OT@9_9R_&YT_&QE;FUE<VEN9&4@:&%T82!O;'7^='4N(@H*
M(SH@;&EB+TUE<W-A9V4N<&AP.C4T-2!L:6(O365S<V%G92YP:'`Z-3@U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!F;&%G
M9VEN9R!M97-S86=E<R!I;B!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W
M:&%T('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B)<(B5S7"(@9&EZ
M:6YI;F1E:VD@:6QE=&EL97)I(&G^87)E=&QE<FME;B!H871A(&]L=?YT=2Y3
M=6YU8W4@8G5N=2`B"B)B:6QD:7)M96MT961I<BXB"@HC.B!F;VQD97)S+G!H
M<#HQ-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R`E<RXB"FUS9W-T<B`B)7,@*&GG97)I*2!A:W1A<OUL_7)K
M96X@:&%T82!O;'7^='4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,3,V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B3VQA>?UN("AIYV5R
M:2D@86MT87+];?T@<_UR87/];F1A(&AA=&$@;VQU_G1U.B`E<R(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N
M(@IM<V=S='(@(D?V<F5V:6X@*&GG97)I*2!A:W1A<OUM_2!S_7)A<_UN9&$@
M:&%T82!O;'7^='4Z)7,B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,34R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM
M<V=S='(@(B(*(DMU;&QA;OUC_6[];B!S97)B97-T+VUE_F=U;"!B:6QG:6QE
M<FEN:6X@*&GG97)I*2!A:W1A<OUM_2!S_7)A<_UN9&$@:&%T82`B"B)O;'7^
M='4Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I;F<@;65S<V%G97,@
M9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H870@=&AE("(*(G-E
M<G9E<B!S86ED(@IM<V=S='(@(B(*(MUL971I;&5R:2!<(B5S7"(@:V]N=6UU
M;F1A;B!<(B5S7"(@:V]N=6UU;F$@=&'^_7)K96X@:&%T82!O;'7^='4N4W5N
M=6-U(&)U;G4@(@HB8FEL9&ER;65K=&5D:7(N(@H*(SH@8V]M<&]S92YP:'`Z
M,3(T-`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE
M<W-A9V4@87,@82!D<F%F="XB"FUS9W-T<B`BW6QE=&D@=&%S;&%K(&]L87)A
M:R!K87ED961I;&ER:V5N(&AA=&$@;VQU_G1U+B(*"B,Z(&-O;7!O<V4N<&AP
M.C$P,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M('-E;F1I;F<@>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R("+=;&5T:2!G]FYD
M97)I;&5R:V5N(&AA=&$@;VQU_G1U.B`E<R(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(D]L
M87D@9_QN8V5L;&5N:7)K96X@:&%T82!O;'7^='4Z("5S(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!L86EN+G!H<#HU.0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E
M>'0@:6X@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`BW6QE=&EN:6X@8G4@
M:_US;?UN9&$@;65T:6X@8G5L=6YM86UA:W1A9/UR+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B5&AI<R!(5$U,(&UE<W-A9V4@
M:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS9W-T<B`B0G4@2%1-3"!I
M;&5T:7-I;FEN(&GG:6YE(&?V;?QL;?S^(&?V<OQN=/QL97(@8G5L=6YM86MT
M863]<BXB"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z.3`*;7-G:60@
M(B(*(E1H:7,@2%1-3"!M97-S86=E(&AA<R!I;6%G97,@96UB961D960@:6X@
M:70N($)L;V-K960@:6UA9V5S(&%P<&5A<B!L:6ME("(*(G1H:7,Z("(*;7-G
M<W1R("(B"B)"=2!(5$U,(&EL971I<VEN:6X@:>=I;F4@9_9M_&QM_/X@9_9R
M_&YT_&QE<B!B=6QU;FUA:W1A9/UR+B!']G+\;G3\;&5R(/[V>6QE("(*(F?V
M<OQN96-E:W1I<CH@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V
M"FUS9VED(")4:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T
M:&4@;65S<V%G92XB"FUS9W-T<B`B0G4@4$=0($'G_6L@06YA:'1A<OT@:6QE
M=&EY92!E:VQE;FUI_G1I<BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3`T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,3@*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C$T,R!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,34W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-S,@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C,Q-`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B0G4@97EL96T@9&5S=&5K;&5N;65M
M96MT961I<BXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<Y(&QI
M8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,3D*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(D)U(&5Y;&5M(&AE
M;OQZ(&=E<N=E:VQE_G1I<FEL;65M:?YT:7(N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M87D@=&%K92!S
M;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C;VYT:6YU93\B
M"FUS9W-T<B`B0G4@:?YL96T@>F%M86X@86QA8FEL:7(N1&5V86T@971M96L@
M:7-T961I\&EN:7IE(&5M:6X@;6ES:6YI>C\B"@HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N
M=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS9W-T<B`B0G4@:6QE=&D@36%C
M:6YT;W-H(&1O<WEA<_T@:>=E<FUE:W1E9&ER+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P:V-S-RYP:'`Z-#$P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@8V]N
M=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N(&1I9VET86QL>2!S
M:6=N960@=FEA(%,O(@HB34E-12XB"FUS9W-T<B`B0G4@:6QE=&D@<V%Y_7-A
M;"!O;&%R86L@4R]-24U%('EO;'5Y;&$@:6UZ86QA;FW]_B!B:7(@96L@:>=E
M<FUE:W1E9&ER+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$T
M"FUS9VED(")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T
M:&%T(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(*;7-G<W1R(")"
M=2!I;&5T:2!3+TU)344@>6]L=7EL82#^:69R96QE;FUI_B!B:7(@96L@:>=E
M<FUE:W1E9&ER+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V
M,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&-O;G1A:6YS(&UA:6P@9&5L:79E
M<GD@<W1A='5S(&EN9F]R;6%T:6]N+"!B=70@=&AE(&9O<FUA="!O9B`B"B)T
M:&ES(&UE<W-A9V4@:7,@=6YK;F]W;BXB"FUS9W-T<B`B(@HB0G4@:6QE=&D@
M=&5S;&EM(&1U<G5M(&)I;&=I<VD@:>=E<FUE:W1E9&ER(&%M82!I;&5T:6YI
M;B!B:>=I;6D@(@HB8FEL:6YM96UE:W1E9&ER+B(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]P9W`N<&AP.C,Q-0IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G
M92X@17)R;W(Z("(*;7-G<W1R("(B"B)"=2!I;&5T:2!G9>=E<FQI(&)I<B!0
M1U`@_FEF<F5L96YM:?X@:6QE=&D@;VQA<F%K(&?V<OQN;65M96MT961I<BX@
M2&%T83H@(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C0P(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,U,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R
M;6%T("AA8V-O<F1I;F<@=&\@(@HB4D9#(#(P,34I+B(*;7-G<W1R(")"=2!I
M;&5T:2!D;_!R=2!01U`@8FGG:6UI;F1E(&1E\&EL9&ER+B`H4D9#(#(P,34@
M92!G]G)E*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,3<P"FUS
M9VED(")4:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H
M92!C;W)R96-T(%,O34E-12!F;W)M870N(@IM<V=S='(@(D)U(&EL971I(&1O
M\')U("!3+TU)344@8FGG:6UI;F1E(&1E\&EL9&ER+B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]P9W`N<&AP.C(P-2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HT
M,38*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG
M;F5D('9I82!01U`N(@IM<V=S='(@(D)U(&EL971I('-A>?US86P@;VQA<F%K
M(%!'4"!Y;VQU>6QA(&EM>F%L86YM_?YT_7(N(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@;65S<V%G92!H87,@8F5E
M;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N(@IM<V=S='(@(D)U(&EL
M971I('-A>?US86P@;VQA<F%K(%,O34E-12!Y;VQU>6QA(&EM>F%L86YM_?YT
M_7(N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ,SD@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@(E1H:7,@;65S<V%G92!H
M87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B0G4@:6QE
M=&D@4R]-24U%('EO;'5Y;&$@_FEF<F5L96YM:?YT:7(N(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,C`Q(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C(Y,0IM<V=I9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!W
M:71H(%!'4"XB"FUS9W-T<B`B0G4@:6QE=&D@4$=0(&EL92#^:69R96QE;FUI
M_G1I<BXB"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S<V%G
M92!T;R(*;7-G<W1R(")"=2!I;&5T:7EI(@H*(SH@86-L+G!H<#HT-@IM<V=I
M9"`B5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N(@IM<V=S='(@(D)U('-U;G5C=2!D:7II;B!P87EL8?[];?UN_2!D97-T
M96ML96UE;65K=&5D:7(N(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ,#D*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`B0G4@<&5N8V5R92!B
M:7(@;VQU_G1U<FUA('!E;F-E<F5S:2!T87)A9OUN9&%N(&'G_6QM86S]9/UR
M+B(*"B,Z('1H<F5A9"YP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")4:')E860@
M1&ES<&QA>2(*;7-G<W1R(")']G-T97(B"@HC.B!T:')E860N<&AP.C<V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C(*;7-G:60@(E1H<F5A9"!6:65W(@IM
M<V=S='(@(DAA8F5R(-9B9?!I($?V<OQN=/QS_"(*"B,Z(&UE<W-A9V4N<&AP
M.C(V-"!M86EL8F]X+G!H<#HV,#8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHR,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D
M97)S+FEN8SHR,B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z-C$*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A
M<F-H+G!H<#HR-@IM<V=I9"`B5&\B"FUS9W-T<B`B2VEM92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,3D*;7-G:60@(E1O($%D9')E<W,B"FUS9W-T
M<B`B061R97,B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8SHS,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI
M;&4@(@HB8VQI8VMI;F<N(@IM<V=S='(@(B(*(D)I<F1E;B!F87IL82!A;&%N
M('-EYV5B:6QM96L@:>=I;BP@=/UK;&%R:V5N($-O;G1R;VPH4$,I('EA9&$@
M0V]M;6%N9"A-86,I("(*(G1U_FQA<OUN_2!B87/];/T@='5T=6XN(@H*(SH@
M;&EB+TE-05`O0VQI96YT+G!H<#HQ,S0*;7-G:60@(B(*(E1O('5S92!A(%1,
M4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B92!R=6YN:6YG(&$@=F5R<VEO;B!O
M9B!02%`@-2XP+C8@;W(@(@HB:&EG:&5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-S<*;7-G:60@(E1O=&%L($%T
M=&%C:&UE;G1S(%-I>F4Z(@IM<V=S='(@(E1O<&QA;2!%:R!";WEU='4Z(@H*
M(SH@9F]L9&5R<RYP:'`Z,S@X"FUS9VED(")4<F%S:"!F;VQD97(B"FUS9W-T
M<B`BQ_9P($MU='5S=2(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C
M="YI;F,Z,C,*;7-G:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`BQ_9P($MU
M='5S=3HB"@HC.B!L:6(O475O=&$O8WER=7,N<&AP.C8U(&QI8B]1=6]T82]M
M97)C=7)Y,S(N<&AP.C<Y(&QI8B]1=6]T82]C;VUM86YD+G!H<#HW,@HC.B!L
M:6(O475O=&$O;&]G9FEL92YP:'`Z.#@@;&EB+U%U;W1A+V-O=7)I97(N<&AP
M.C4S(&QI8B]1=6]T82]M9&%E;6]N+G!H<#HT.`IM<V=I9"`B56YA8FQE('1O
M(')E=')I979E('%U;W1A(@IM<V=S='(@(DMO=&$@8F5L:7)L96YE;65D:2(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3`@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ.0HC.B!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C,V"FUS9VED(")5;F%N<W=E<F5D(@IM<V=S
M='(@(D-E=F%P;&%N;6%M_?XB"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C,U"FUS9VED(")5;F%N<W=E<F5D(&UE<W-A9V5S(@IM<V=S='(@(D-E
M=F%P;&%N;6%M_?X@W6QE=&EL97(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z-"!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHQ,PIM<V=I9"`B56YD96QE=&4B"FUS9W-T<B`B4VEL;64B"@HC.B!M
M86EL8F]X+G!H<#HU.#D@;6%I;&)O>"YP:'`Z-C`R(&QI8B]-24U%+TAE861E
M<G,N<&AP.C(Q,@IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I96YT<R(*;7-G
M<W1R(")']G-T97)I;&UE>65N($%L_6/];&%R(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C0T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L
M960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(D)I;&EN;65Y96X@
M8FEL9?YE;B!T:7!I.B`E<R(*"B,Z(&UA:6QB;W@N<&AP.C4V-0IM<V=I9"`B
M56YK;F]W;B!$871E(@IM<V=S='(@(D)I;&EN;65Y96X@5&%R:6@B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;FMN;W=N($E-05`@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B!397)V97(@
M4F5S<&]N9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-C,U"FUS9VED(")5;FMN;W=N($UE971I;F<B"FUS9W-T<B`B
M0FEL:6YM97EE;B!4;W!L86YT_2(*"B,Z(&UA:6QB;W@N<&AP.C8Q.`IM<V=I
M9"`B56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`B0FEL:6YM97EE;B!!;/UC
M_2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C<W"FUS9VED(")5;FQO860@4&%S<W!H<F%S92(*;7-G
M<W1R(")'9>=I_B!4_&UC96-I\&EN:2!+86QD_7(B"@HC.B!F971C:&UA:6QP
M<F5F<RYP:'`Z-C4*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BW7-I;7-I>B(*
M"B,Z(&UE<W-A9V4N<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R
M+FEN8SHS,@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G
M:60@(E5N<V5E;B(*;7-G<W1R(")/:W5N;6%M_?XB"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O
M;2!&;VQD97(H<RDB"FUS9W-T<B`B1&EZ:6YI;B#\>65L:?!I;F1E;B#G_6LN
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3@T"FUS9VED
M(")5<&1A=&4@071T86-H;65N="!);F9O<FUA=&EO;B(*;7-G<W1R(")%:R!"
M:6QG:7-I;FD@1_QN8V5L;&4B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-C(P"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T
M<B`B0V5V87!L87G]8_T@9'5R=6UU;G4@9_QN8V5L;&4B"@HC.B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(EG\:VQE(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I
M9"`B57-E($1E9F%U;'0@5F%L=64B"FUS9W-T<B`BUFX@=&%N_6UL_2!$9?!E
M<FD@2W5L;&%N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I
M9"`B57-E($E-05`@9F]L9&5R('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(DE-
M05`@9&EZ:6YI;FEN(/QY96QI:VQE<FD@:W5L;&%N_6QS_6X@;?T_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S-0HC+"!F=7IZ>0IM<V=I9"`B57-E
M(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*;7-G<W1R(")386YA;"!$:7II;FQE
M<B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-#(*;7-G:60@(E5S97(B
M"FUS9W-T<B`B2W5L;&%N_6/](@H*(SH@86-L+G!H<#HX-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB57-E<B!<(B5S7"(@<W5C8V5S<V9U;&QY
M(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`B(@HB)R5S)R!K=6QL86[]8_US_6YA("<E<R<@9&EZ
M:6YI(&GG:6X@8F5L:7)T:6QM:?X@:&%K;&%R(&)A_F%R_7EL82!V97)I;&1I
M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3<W"FUS9VED(")5
M<V5R;F%M92(*;7-G<W1R(")+=6QL86[]8_T@063](@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB"FUS
M9W-T<B`B2W5L;&%N_6/]($%D_3HB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C@*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C<*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R(*;7-G<W1R(")']G+\;G3\;&4B
M"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HY,B!L:6(O34E-12]6:65W
M97(O=&YE9BYP:'`Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B
M"FUS9W-T<B`B1_9R_&YT_&QE("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B5S($'G
M_6L@06YA:'1A<OUN_2!']G+\;G3\;&4B"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3$V"FUS9VED(")6:65W($A434P@8V]N=&5N="!I;B!A('-E
M<&%R871E('=I;F1O=R(*;7-G<W1R(")(5$U,(&GG97)I\&EN:2!A>7+](&)I
M<B!P96YC97)E9&4@9_9R_&YT_&QE+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+V%C=&EO;G,N:6YC.C(X"B,L(&9U>GIY"FUS9VED(")6:65W($UE<W-A9V5S
M(@IM<V=S='(@(EEE;FD@:6QE=&EL97(B"@HC.B!T96UP;&%T97,O<VUI;64O
M<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B
M5FEE=R!097)S;VYA;"!0<FEV871E($ME>2(*;7-G<W1R(")+:?YI<V5L(-9Z
M96P@06YA:'1A<OT@1_9R_&YT_&QE(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M
M:6UE+FEN8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(E9I
M97<@4&5R<V]N86P@4'5B;&EC($ME>2(*;7-G<W1R(")+:?YI<V5L($'G_6L@
M06YA:'1A<OT@1_9R_&YT_&QE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")6:65W(%1H<F5A9"(*;7-G<W1R
M(")(86)E<B#68F7P:6YI($?V<OQN=/QL92(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C$V,R!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ
M-C4*;7-G:60@(E9I97<@5&AU;6)N86EL(@IM<V=S='(@(DUI;GEA=/QR($)O
M>75T=&$@1_9R_&YT_&QE(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HT,3@*;7-G:60@(E9I97<@871T86-H;65N="!I;B!A('-E<&%R871E('=I
M;F1O=R(*;7-G<W1R(")%:VD@87ER_2!B:7(@<&5N8V5R961E(&?V<OQN=/QL
M92(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0IM<V=I9"`B
M5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(MWG
M97)I\&D@87ER_2!B:7(@<&5N8V5R961E(&?V<OQN=/QL92(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HQ-#`*;7-G:60@(E9I97<@979E;G0B"FUS
M9W-T<B`B3VQA>?T@1_9R_&YT_&QE(@H*(SH@9F]L9&5R<RYP:'`Z,S@P(&UA
M:6QB;W@N<&AP.C4S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE<W-A
M9V5S(&EN("5S(@IM<V=S='(@(B5S(&GG:6YD96MI(&EL971I;&5R:2!G]G+\
M;G3\;&4B"@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A9V5S96QE8W0N
M:6YC.C(S"FUS9VED(")6:65W(&]R(&UA:6QB;W@@=&\@9&ES<&QA>2!A9G1E
M<B!L;V=I;CHB"FUS9W-T<B`B1VER:?YT96X@<V]N<F$@9_9S=&5R:6QE8V5K
M(&?V<OQN_&T@>6%D82!P;W-T82!K=71U<W4Z(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C$W,`IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(D?V
M<F5V:2!']G+\;G3\;&4B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M,3`Q"FUS9VED(")6:65W('1H92!);6%G97,B"FUS9W-T<B`B1_9R_&YT_&QE
M<FD@1_9R_&YT_&QE(@H*(SH@<V5A<F-H+G!H<#HR-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5FER='5A;"!&;VQD97(@7"(E<UPB(&-R96%T960@<W5C8V5S
M9G5L;'DN(@IM<V=S='(@(E-A;F%L($1I>FEN(%PB)7-<(B!B8?YA<OUY;&$@
M>6%R873];&3]+B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,3$Q
M(&QI8B])34%0+U1R964N<&AP.C$S."!L:6(O24U!4"]4<F5E+G!H<#HQ-3$*
M(SH@;&EB+TE-05`O5')E92YP:'`Z,34S(&QI8B])34%0+U1R964N<&AP.C$U
M-R!L:6(O24U!4"]4<F5E+G!H<#HQ-3@*(SH@;&EB+TE-05`O5')E92YP:'`Z
M,S8Y(&QI8B])34%0+U1R964N<&AP.C,Y,R!L:6(O24U!4"]4<F5E+G!H<#HT
M,S,*;7-G:60@(E9I<G1U86P@1F]L9&5R<R(*;7-G<W1R(")386YA;"!$:7II
M;FQE<B(*"B,Z('-E87)C:"YP:'`Z,C0U"FUS9VED(")6:7)T=6%L($9O;&1E
M<G,@<F5Q=6ER92!A(&QA8F5L+B(*;7-G<W1R(")386YA;"!$:7II;FQE<B!B
M:7(@971I:V5T(&=E<F5K=&ER;65K=&5D:7(N(@H*(SH@;&EB+U9&;VQD97(N
M<&AP.C$W-2!L:6(O5D9O;&1E<BYP:'`Z,3@P"FUS9VED(")6:7)T=6%L($E.
M0D]8(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q-@HC+"!F=7IZ>0IM
M<V=I9"`B5FER='5A;"!)3D)/6"!&;VQD97(B"FUS9W-T<B`B4V%N86P@1&EZ
M:6YL97(B"@HC.B!M86EL8F]X+G!H<#HT-3(@;&EB+U9&;VQD97(N<&AP.C$Q
M-"!L:6(O5D9O;&1E<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L
M(%1R87-H(@IM<V=S='(@(E-A;F%L($1I>FEN;&5R(@H*(SH@9F]L9&5R<RYP
M:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")6:7)T=6%L(%1R87-H($9O;&1E<B(*
M;7-G<W1R(")386YA;"!$:7II;FQE<B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,3,S"FUS9VED(")6:7)T=6%L(&9O;&1E<B!L86)E;"(*;7-G
M<W1R(")386YA;"!D:7II;B!E=&EK971I(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HS-S0*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B57EA<OTB
M"@HC.B!L;V=I;BYP:'`Z,3,X"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O
M;64@=&\@)7,B"FUS9W-T<B`B)7,@2&_^9V5L9&EN:7HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C$Y"B,L(&9U>GIY"FUS9VED("(B"B)7:&%T('-H
M;W5L9"!W92!D;R!W:71H('-P86T@;65S<V%G97,@869T97(@=&AE>2!H879E
M(&)E96X@<F5P;W)T960@87,@<W!A;2`B"B)O<B!I;FYO8V5N=#\B"FUS9W-T
M<B`B(@HBW7-T96YM97EE;B!I;&5T:6QE<BP@:7-T96YM97EE;B!I;&5T:2!O
M;&%R86L@<F%P;W(@961I;&1I:W1E;B!S;VYR82!S:6QI;G-I;B`B"B)M:3\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S(W"FUS9VED("(B"B)7:&5N
M(&1E;&5T:6YG(&UE<W-A9V5S+"!M;W9E('1H96T@=&\@>6]U<B!4<F%S:"!F
M;VQD97(@:6YS=&5A9"!O9B!M87)K:6YG("(*(G1H96T@87,@9&5L971E9#\B
M"FUS9W-T<B`B(@HBW6QE=&EL97)I('-I;&5R:V5N+"!S:6QI;F5C96L@;VQA
M<F%K(&G^87)E=&QE;65K('EE<FEN92#']G`@2W5T=7-U;F$@(@HB=&'^_6YS
M_6X@;?T_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-PIM<V=I9"`B
M5VAE;B!O<&5N:6YG(&$@;F5W(&UA:6QB;W@L('=H:6-H('!A9V4@9&\@>6]U
M('=A;G0@=&\@<W1A<G0@;VX_(@IM<V=S='(@(EEE;FD@8FER('!O<W1A(&MU
M='5S=2!AY_UL_7)K96XL(&AA;F=I('-A>69A9&%N(&)A_FQA;6%K(&ES=&5R
M<VEN:7H_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4V,0IM<V=I9"`B
M5VAE;B!S879I;F<@<V5N="UM86EL+"!S:&]U;&0@=V4@<V%V92!A='1A8VAM
M96YT(&1A=&$_(@IM<V=S='(@(D?V;F1E<FEL;6G^('!O<W1A;&%R_2!K87ED
M961E<FME;BP@96ML97)D92!K87ED961I;'-I;B!M:3\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#(V"FUS9VED("(B"B)7:&5N('-E;F1I;F<@;6%I
M;"!O<B!E>'!A;F1I;F<@861D<F5S<V5S+"!W:&%T(&1O;6%I;B!S:&]U;&0@
M=V4@87!P96YD('1O("(*(G5N<75A;&EF:65D(&%D9')E<W-E<R`H96UA:6P@
M861D<F5S<V5S('=I=&AO=70@7")`7"(I/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E=H:71E;&ES="(*;7-G
M<W1R(")"97EA>B!,:7-T92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<X"FUS9VED(")9
M97,B"FUS9W-T<B`B179E="(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+V9E
M=&-H;6%I;%]L;V=I;BYP:'`Z-3@*;7-G:60@(EEO=2!A<F4@86)O=70@=&\@
M9F5T8V@@96UA:6P@9G)O;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(@IM
M<V=S='(@(E1A:VEP(&5D96X@:&5S87!L87)D86X@<&]S=&$@9V5T:7)M96L@
M_'IE<F5S:6YI>BXB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O
M;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U(&%R92!A='1E
M;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D(&EN('1H
M92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G<W1R(")486MI<"!E9&5N
M(&1I>FEN;&5R('-I;&EN96-E:SHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F
M;VQD97)S7V-O;F9I<FTN:'1M;#HY"B,L(&9U>GIY"FUS9VED(")9;W4@87)E
M(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F;VQL;W=I;F<@9F]L9&5R*',I
M+B(*;7-G<W1R(")486MI<"!E9&5N(&1I>FEN;&5R('-I;&EN96-E:SHB"@HC
M.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP;&%T
M97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@(EEO=2!A<F4@
M8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+B(*;7-G<W1R(")996YI
M(&)I<B!D:7II;F4@:V]P>6%L_7EO<G-U;G5Z+W1A_OUY;W-U;G5Z+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R"FUS9VED(")9
M;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B"FUS9W-T<B`B06QT
M9&EZ:6X@>6%R873];&%C86L@9&EZ:6X@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O9F]L9&5R<RYJ<SHQ,#0*;7-G:60@(EEO=2!A<F4@8W)E871I;F<@
M82!T;W`M;&5V96P@9F]L9&5R+B(*;7-G<W1R("+<<W1D_'IE>2!B:7(@9&EZ
M:6X@>6%R873]>6]R<W5N=7HN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(P"B,L
M(&9U>GIY"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!F
M;VQD97)S+B(*;7-G<W1R("+<<W1D_'IE>2!B:7(@9&EZ:6X@>6%R873]>6]R
M<W5N=7HN(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(W"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]F;VQD97)S+FIS.C$S-0IM<V=I9"`B66]U(&%R92!R96YA;6EN9R!T
M:&4@9F]L9&5R.B`B"FUS9W-T<B`B1&EZ:6X@>65N:61E;B!A9&QA;F3]<OUL
M_6-A:SH@(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-34W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@8V%N(&YO="!U;G-U8G-C<FEB92!F<F]M(%PB
M)7-<(BXB"FUS9W-T<B`B7"(E<UPB(/QY96QI\&EN9&5N(&)A_F%R_7EL82#G
M_6MT_6[]>BXB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@=&AE(&9O
M;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X=#H@
M)6,@9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R
M('1H92!S:6=N871U<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED
M(&YO="!A9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L
M('-O('EO=2!W97)E(&YO="!A;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R
M("(B"B)(:7IM970@2V_^=6QL87+](&%N;&'^;6%S_6[](&]N87EL86UA9/UN
M_7HL(&)U('-E8F5B;&4@9VER:?X@>6%P;6%N_7IA(&EZ:6X@(@HB=F5R:6QM
M96UE:W1E9&ER+B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-CD*;7-G
M:60@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N('1O(&-H86YG92!A8V-E
M<W,@=&\@=&AI<R!F;VQD97(B"FUS9W-T<B`B0G4@9&EZ:6YI;B!E<FG^:6T@
M:&%K;&%R_6[](&1E\&G^=&ER;65K(&GG:6X@:7IN:6YI>B!Y;VLB"@HC.B!L
M:6(O36%I;&QO9RYP:'`Z,3(Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!F
M;W)W87)D960@=&AI<R!M97-S86=E(&]N("4E<R!T;R!T:&4@9F]L;&]W:6YG
M(')E8VEP:65N=',Z("5S+B(*;7-G<W1R(")"=2!I;&5T:7EI('1A:VEP(&5D
M96X@86S]8_UL87)A("4E<R!D92!I;&5T=&EN:7HZ("5S+B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%L97)T+FEN8SHS"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!H879E("5S(&YE=R!M97-S86=E<RXB"FUS9W-T<B`B)7,@>65N:2!I
M;&5T:6YI>B!V87(N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC
M.C,*;7-G:60@(EEO=2!H879E(#$@;F5W(&UE<W-A9V4N(@IM<V=S='(@(C$@
M>65N:2!I;&5T:6YI>B!V87(N(@H*(SH@8V]M<&]S92YP:'`Z-#DT"B,L(&9U
M>GIY"FUS9VED(")9;W4@:&%V92!A;')E861Y('-U8FUI='1E9"!T:&ES('!A
M9V4N(@IM<V=S='(@(C$@>65N:2!I;&5T:6YI>B!V87(N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z,3$U"FUS9VED("(B"B)9;W4@
M:&%V92!A="!L96%S="!O;F4@871T86-H;65N="!S96QE8W1E9"!T:&%T('EO
M=2!D:61N)W0@=7!L;V%D('EE="X@07)E("(*(GEO=2!S=7)E('EO=2!W86YT
M('1O('-E;F0@=&AI<R!M97-S86=E('=I=&AO=70@=&AE<V4@871T86-H;65N
M=',_(@IM<V=S='(@(B(*(DAE;OQZ('G\:VQE;65D:?!I;FEZ(&5N(&%Z_6YD
M86X@8FER('1A;F4@96L@<V7G=&EN:7HN($)U(&EL971I>6D@96MS:7H@(@HB
M9_9N9&5R;65K(&ES=&5D:?!I;FEZ9&5N(&5M:6X@;6ES:6YI>C\B"@HC.B!L
M:6(O24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@:&%V92!N97<@;6%I;"!I;B!T
M:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`B1&EZ:6YL97)D92!Y96YI
M('!O<W1A('9A<CHB"@HC.B!L:6(O24U0+G!H<#HQ,#<Y"FUS9VED(")9;W4@
M:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z(@IM<V=S
M='(@(D1I>FEN;&5R9&4@>65N:2!P;W-T82!V87(Z(@H*(SH@8V]M<&]S92YP
M:'`Z,34S"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@<F5C
M:7!I96YT+B(*;7-G<W1R(")%;B!A>B!B:7(@=&%N92!A;/UC_2!G:7)M96QI
M<VEN:7HN(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S`R"FUS9VED
M("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!0
M1U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4B"FUS9W-T<B`B
M(@HB0G4@:6QE=&EY:2!G]G+\;G3\;&5Y96)I;&UE:R!IYVEN(%!'4"#V>F5L
M(&%N86AT87+];OUZ_6X@9V7G:?X@=/QM8V5C:?!I;FD@(@HB9VER;65L:7-I
M;FEZ+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C0Y"FUS9VED
M("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!3
M+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES("(*(FUE<W-A9V4B"FUS
M9W-T<B`B(@HB0G4@:6QE=&EY:2!G]G+\;G3\;&5Y96)I;&UE:R!IYVEN(%,O
M34E-12#V>F5L(&%N86AT87+];OUZ_6X@9V7G:?X@(@HB=/QM8V5C:?!I;FD@
M9VER;65L:7-I;FEZ+B(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I
M<'0N:6YC.C8T('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C(P
M,0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&$@=&%R9V5T(&UA:6QB;W@@9FER
M<W0N(@IM<V=S='(@(M9N8V4@8FER(&AE9&5F('!O<W1A(&MU='5S=2!S9>=M
M96QI<VEN:7HN(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"FUS9VED(")9
M;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R(")3:6QI;F5C96L@8FER(&AE<V%P('-EYVUE;&ES:6YI>BXB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C@Q"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB"FUS9W-T<B`BUFYC92!B
M:7(@861R97,@<V7G;65L:7-I;FEZ+B(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VIA=F%S8W)I<'0N:6YC.C8R('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I
M<'0N:6YC.C(P.`HC.B!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN
M8SHR-C,*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@;65S
M<V%G92!F:7)S="XB"FUS9W-T<B`BUFYC92!E;B!A>B!B:7(@:6QE=&D@<V7G
M;65L:7-I;FEZ+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN
M8SHQ,PIM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="XB"FUS
M9W-T<B`B0FER(&%L_6/](&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHR.0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A="!L96%S="!O;F4@9FEL92!T;R!A='1A8V@N(@IM<V=S='(@
M(D5K;&5N96-E:R!E;B!A>B!B:7(@9&]S>6$@8F5L:7)T;65L:7-I;FEZ+B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B66]U(&YE960@=&\@:&%V92!<(B5S7"(@
M96YA8FQE9"!I;B!Y;W5R(&UA:6YT96YA;F-E(&]P=&EO;G,N(@IM<V=S='(@
M(B5S(&)A:_UM('-EYV5N96ML97)I;F1E('-EYVEL:7(@:_UL_6YM86S]9/UR
M+B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(')E9&ER96-T960@=&AI<R!M97-S86=E('1O("5S(&]N("4E<RXB
M"FUS9W-T<B`B0G4@:6QE=&EY:2`E<R!E("4E<R!D92!Y]FYL96YD:7)D:6YI
M>BXB"@HC.B!L:6(O36%I;&QO9RYP:'`Z,30Q"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!R97!L:65D('1O('1H:7,@;65S<V%G92!O;B`E<RXB"FUS9W-T
M<B`B0G4@:6QE=&EY92`E<R!D92!C979A<"!V97)D:6YI>BXB"@HC.B!L:6(O
M1F]L9&5R+G!H<#HU,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@
M;F]T('-U8G-C<FEB960@=&\@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(EPB)7-<(B!D:7II;FEN92#\>64@9&7P:6QS
M:6YI>BY3=6YU8W4@8G5N=2!B96QI<G1M96MT961I<B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!N;W0@
M=6YS=6)S8W)I8F5D(&9R;VT@7"(E<UPB+B!(97)E(&ES('=H870@=&AE('-E
M<G9E<B!S86ED(@IM<V=S='(@(EPB)7-<(B#\>65L:?!I;FEZ(&1E=F%M(&5D
M:7EO<BY3=6YU8W4@8G5N=2!B96QI<G1M96MT961I<B(*"B,Z(&QI8B]&;VQD
M97(N<&AP.C4Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C
M97-S9G5L;'D@<W5B<V-R:6)E9"!T;R!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB
M(&1I>FEN:6YE(&)A_F%R_7EL82#\>64@;VQD=6YU>BXB"@HC.B!L:6(O1F]L
M9&5R+G!H<#HU-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C
M8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R(")<
M(B5S7"(@_'EE;&GP:6YD96X@8F'^87+]>6QA(.?]:W3];OUZ+B(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHY.`IM<V=I9"`B66]U<B!.86UE(@IM<V=S
M='(@(D%D_6[]>B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHU,`IM<V=I
M9"`B66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*;7-G<W1R(")01U`@
M0>?]:R_6>F5L($%N86AT87)L87+];OUZ(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S8*;7-G:60@
M(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`BUGIE;"!!;F%H=&%R_6[]>B(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-C<@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<Q"FUS9VED(")9;W5R(%!U8FQI8R!+97DB"FUS9W-T<B`B
M0>?]:R!!;F%H=&%R_6[]>B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C4*(RP@9G5Z>GD*;7-G:60@(EEO=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE
M;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T<B`B66%N_70Z(&%D<F5S.B`\:3XH
M<V7G:6UL:2D\+VD^(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHT
M.0IM<V=I9"`B66]U<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A
M=&5S(@IM<V=S='(@(E,O34E-12!!Y_UK+]9Z96P@3VYA>2!"96QG96YI>B(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C$V
M"FUS9VED(")9;W5R(&%C8V]U;G1S.B(*;7-G<W1R(")(97-A<&QA<OUN_7HZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PHC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N
M=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@
M(M9T96MI(&%D(&%D<F5S;&5R:3H@/&D^*'-EYVEM;&DL(&AE<B!A9')E<R!I
MYVEN(&)I<B!S873]<B!G:7)I;BD\+VD^(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z.3(*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS
M9W-T<B`B(@HB5&%R87G]8_UN_7H@8G4@9_9R_&YT_"!T_'+\;OP@;65T;F4@
M9_9M_&S\(&?V<W1E<FEM:6YI(&1E<W1E:VQE;65M96MT961I<BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@
M8VAA<G-E="!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`BUFX@=&%N
M_6UL_2!K87)A:W1E<B!K_&UE;FEZ.B(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F-R>7!T<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP
M=&EO;B!M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(MUL
M971I(&?V;F1E<FUE:R!IYVEN(/9N('1A;OUM;/T@_FEF<F5L96UE('GV;G1E
M;6EN:7HZ(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*;7-G
M:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB
M"FUS9W-T<B`BW6QE=&EN:7H@8F'^87+]>6QA('1E<VQI;2!E9&EL;6G^=&ER
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@(EEO=7(@
M<VEG;F%T=7)E.B(*;7-G<W1R("+=;7IA;OUZ.B(*"B,Z(&UE<W-A9V4N<&AP
M.C(X."!C;VUP;W-E+G!H<#HQ,C@T(&UA:6QB;W@N<&AP.C4T.2!L:6(O0V]M
M<&]S92YP:'`Z.#$X"FUS9VED(");3F\@4W5B:F5C=%TB"FUS9W-T<B`B6TMO
M;G4@66]K72(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(P
M-0IM<V=I9"`B7T)C8R(*;7-G<W1R(")':7I?;&D@2RY++B(*"B,Z('1E;7!L
M871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O
M;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B7T)L86-K;&ES="(*;7-G
M<W1R(")?2V%R82!,:7-T92(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C$U-`IM<V=I9"`B7T-C(@IM<V=S='(@(DLN($MO7W!Y82(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C@*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,3`*;7-G:60@(E]$96QE=&4B"FUS9W-T<B`B7U-I
M;"(*"B,Z(&QI8B])35`N<&AP.CDW.0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T
M<B`B7T1I>FEN;&5R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z.#$*;7-G:60@(E])9&5N=&ET>2(*;7-G<W1R(")+:5]M;&EK(@H*(SH@
M;&EB+TE-4"YP:'`Z.38Q"FUS9VED(")?26YB;W@B"FUS9W-T<B`B7T=E;&5N
M($MU='5S=2(*"B,Z(&QI8B])35`N<&AP.C$P,C`*;7-G:60@(E],;V<@;W5T
M(@IM<V=S='(@(L?]7VO]_B(*"B,Z(&UE<W-A9V4N<&AP.C,X-`IM<V=I9"`B
M7TUE<W-A9V4@4V]U<F-E(@IM<V=S='(@(MU?;&5T:2!+87EN8?#](@H*(SH@
M;&EB+TE-4"YP:'`Z.3<V"B,L(&9U>GIY"FUS9VED(")?3F5W($UE<W-A9V4B
M"FUS9W-T<B`B665N:2!I;&5T:6QE<B(*"B,Z('1E;7!L871E<R]M97-S86=E
M+VYA=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B7U!R:6YT(@IM<V=S='(@
M(E]987ID_7(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M-S(@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C@Y"FUS9VED(")?
M4')I;W)I='DB"FUS9W-T<B`BUFY?8V5L:6LB"@HC.B!M86EL8F]X+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B7U)E9G)E<V@@)7,B"FUS9W-T<B`B
M7UEE;FEL92`E<R(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHX"FUS9VED(")?4F5P;'DB"FUS9W-T<B`B7T-E=F%P(%EA>B(*
M"B,Z(&QI8B])35`N<&AP.CDX,0IM<V=I9"`B7U-E87)C:"(*;7-G<W1R(")?
M07)A(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"FUS9VED(")?4V5N9"!-
M97-S86=E(@IM<V=S='(@(MUL971I(%]']FYD97(B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,R"FUS9VED(")?5&AR96%D
M(@IM<V=S='(@(DMO;G4@UF)E\&DB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHQ,38*;7-G:60@(E]4;R(*;7-G<W1R(")?2VEM92(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")?56YD
M96QE=&4B"FUS9W-T<B`B4VEL7VUE(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M;F%V8F%R7V%C=&EO;G,N:6YC.C$X"FUS9VED(")?5FEE=R!4:')E860B"FUS
M9W-T<B`B7TAA8F5R(-9B9?!I;FD@1_9R(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(T('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C$Y"FUS9VED(")?5VAI=&5L:7-T(@IM<V=S='(@(E]"97EA
M>B!,:7-T92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ-S8*;7-G:60@(F%D9')E
M<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT
M-#`*;7-G:60@(F%T=&%C:&UE;G0B"FUS9W-T<B`B16LB"@HC.B!V:65W+G!H
M<#HY.0IM<V=I9"`B871T86-H;65N=',N>FEP(@IM<V=S='(@(D5K+GII<"(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PIM<V=I9"`B
M8GET97,B"FUS9W-T<B`B8GET92(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#`*
M;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C$W,@IM<V=I9"`B8V%N;F]T(&]P96X@:6YP
M=70B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V-`IM<V=I9"`B
M8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HR,C`*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y-@IM<V=I9"`B8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,38X"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(T"FUS9VED(")E;G1R>2!N;W0@
M9F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A
M8W1S+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS9W-T<B`B:VEM9&5N(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$X,`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P-`IM<V=I9"`B:6YP
M=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ.#@*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z('-M:6UE+G!H<#HR.2!P9W`N<&AP.C8Y"FUS9VED(")K97DB"FUS
M9W-T<B`B86YA:'1A<B(*"B,Z(&9O;&1E<G,N<&AP.C$V,0IM<V=I9"`B;6%I
M;&)O>"!F:6QE(@IM<V=S='(@(G!O<W1A(&MU='5S=2!D;W-Y87/](@H*(SH@
M8V]M<&]S92YP:'`Z,3`V-R!L:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")N
M86UE(@IM<V=S='(@(F%D(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C<V"FUS9VED(")N;VYE(@IM<V=S='(@(FAIYV)I<FDB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")O<B(*
M;7-G<W1R(")V97EA(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q-@IM<V=I9"`B
M<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N
M<&AP.C(Q,@IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.#0*;7-G:60@(G-E<G9I8V4@
M=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S<&5L;&EN9R!E<G)O<B(*;7-G<W1R
M(")Y87K];2!H871A<_TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R<R(*;7-G<W1R(")Y87K]
M;2!H871A;&%R_2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ.3(*(RP@9G5Z>GD*
M;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")Y87K];2!H871A<_TB"@HC
M.B!L:6(O0V]M<&]S92YP:'`Z,C`X"FUS9VED(")T96UP;W)A<GD@9F%I;'5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HU,0IM<V=I9"`B>6]U
M<B!B;&%C:VQI<W0B"FUS9W-T<B`B:V%R82!L:7-T96YI>B(*"B,Z(&QI8B]&
M:6QT97(N<&AP.C8Q"FUS9VED(")Y;W5R('=H:71E;&ES="(*;7-G<W1R(")B
M97EA>B!L:7-T96YI>B(*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W!O+V5L7T=2+G!O````````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,V-S$T-``Q,#0Q-S,V,C<V
M-@`P,3<Q-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(R!)35`@1W)E96L@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#
M*2`R,#`R(%-T969A;F]S($DN($1I;6ET<FEO=2X*(R!3=&5F86YO<R!)+B!$
M:6UI=')I;W4@/'-D:6UI=')I7W=E8FUA:6Q`=&5I871H+F=R/BP@,C`P,BX*
M(R!3:6QL:6=A<F1O<R!8<FES=&]F;W)O<RP@,C`P,BX*(R!!;F%G;F]S=&]P
M;W5L;W,@07!O<W1O;&ES+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!)35`Z(#,N,BUC=G-<;B(*(E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E
M871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I
M<VEO;BU$871E.B`R,#`Q+3`U+3`U(#$U.C`P*S`R,#!<;B(*(DQA<W0M5')A
M;G-L871O<CH@4W1E9F%N;W,@22X@1&EM:71R:6]U(#QS=7!P;W)T7W=E8FUA
M:6Q`=&5I871H+F=R/EQN(@HB3&%N9W5A9V4M5&5A;3H@1W)E96L@/&1E=D!L
M:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3=<;B(*
M(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#$X"B,L(&9U>GIY"FUS9VED("(@("`@("!#8SH@(@IM
M<V=S='(@(B`@("#0\>_R.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,34*;7-G
M:60@(B`@("`@(%1O.B`B"FUS9W-T<B`B("`@(-#Q[_(Z(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C0P,PIM<V=I9"`B("`@($1A=&4Z("(*;7-G<W1R("+'[.7Q
M[^SG[=_A.B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HT,#8*;7-G:60@(B`@("!&
M<F]M.B`B"FUS9W-T<B`B("`@(,'P_#HB"@HC.B!M86EL8F]X+G!H<#HT,C(@
M=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C0Q,@IM<V=I9"`B(%-U8FIE8W0Z("(*;7-G<W1R("(@R-WLX3HB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-S`*;7-G:60@
M(B!I;B`B"FUS9W-T<B`B(//E("(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z,3(*;7-G:60@(B,B"FUS9W-T<B`B(R(*"B,Z
M(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E+C)F34(@+R`E+C)F34(@("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z('1H
M<F5A9"YP:'`Z,34Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!-
M97-S86=E<R(*;7-G<W1R("(E9"#A\/P@)60@S.?M_>SA].$B"@HC.B!M86EL
M8F]X+G!H<#HQ-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D(&UE
M<W-A9V5S(&AA=F4@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+'(/3A]?3\].?T
MX2!<(B5S7"(@Y.GAX_'<]N?JY2XB"@HC.B!L:6(O4W!A;2YP:'`Z,3<X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E9"!M97-S86=E<R!H879E
M(&)E96X@<F5P;W)T960@87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBU.\@[-[M]>SA(.'U]/P@X>WA]MWQ
MZ.?JY2#Y\B`G4W!A;2<@\_3O(.3IX??EZ?'I\_3>(/3O]2#S]?/TWNSA]._R
M(//A\BXB"@HC.B!L:6(O4W!A;2YP:'`Z,34X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@
M;F]T('-P86TN(@IM<V=S='(@(B(*(M3O(.S>[?7LX2#A]?3\(.'MX?;=\>CG
MZN4@^?(@)U-P86TG(//T[R#DZ>'WY>GQZ?/TWB#T[_4@\_7S]-[LX?3O\B#S
MX?(N(@H*(SH@;&EB+U-P86TN<&AP.C$W,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S('-P
M86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB
MU.\@[-[M]>SA(.'U]/P@X>WA]MWQZ.?JY2#Y\B`G4W!A;2<@\_3O(.3IX??E
MZ?'I\_3>(/3O]2#S]?/TWNSA]._R(//A\BXB"@HC.B!L:6(O4W!A;2YP:'`Z
M,34P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H
M879E(&)E96X@<F5P;W)T960@87,@<W!A;2XB"FUS9W-T<B`B(@HBU.\@[-[M
M]>SA(.'U]/P@X>WA]MWQZ.?JY2#Y\B`G4W!A;2<@\_3O(.3IX??EZ?'I\_3>
M(/3O]2#S]?/TWNSA]._R(//A\BXB"@HC.B!M86EL8F]X+G!H<#HS-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@=&\@)60@;V8@)60@365S<V%G97,B"FUS
M9W-T<B`B)60@W?GR("5D(.'P_"`E9"#,Y^W][.'TX2(*"B,Z(&UA:6QB;W@N
M<&AP.C8T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE9"XB"FUS9W-T
M<B`B)7,@]?#<\??EZ2#>Y.<N(,\@)7,@]MSJY>OO\B#DY>T@[.7T[^WO[-SS
M].?JY2XB"@HC.B!L:6(O365S<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB
M;W@N(@IM<V=S='(@(B5S(.3E[2#EW^WAZ2#=X^KU\>\@X_'A[.SA]._JZ>+^
M].GO+B(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I
M;%]M;VYT:&QY+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD
M97(@8F5I;F<@<F5N86UE9"!A="!T:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*
M;7-G<W1R("(E<R#VW.KEZ^_R(.CA(.SE]._M[^SA\_3EWR#S].?M(.'Q]]X@
M]._U(.S>[>$N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@86-C97!T960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@9&5C;&EN960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO
M;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0X,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!T96YT871I=F5L>2!A8V-E<'1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T
M("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z-#$T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`BSR#VW.KEZ^_R(%PB)7-<(B#LY?3O
M[>_LW//TY^KE(.SE(.7PZ?3U]]_A(//E(%PB)7-<(BXB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('=I<VAE<R!T;R!A;6UE;F0@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C`R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M
M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(X
M-2!M97-S86=E+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T;W`N
M:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO
M9B9N8G-P.R5D*2(*;7-G<W1R("(E<SH@)7,@*"5D)FYB<W`[X?#\)FYB<W`[
M)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$S,PIM
M<V=I9"`B*$%P<&QY('1H97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S
M8W)E96XN*2(*;7-G<W1R("(HQ?;A\>SOX]X@X?7T_NT@]/GM(.'KZ^'C_NT@
MZN'I(.SE].'JW^WG\^<@\_3G[2#E\/SLY>WG(._H_.WG+BDB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3(P"FUS9VED("(H1&ES8V%R
M9"!A;&P@8VAA;F=E<R!A;F0@<F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E
M;BXI(@IM<V=S='(@(B(*(BC!\/SQ\>GXYR#\Z_GM(/3Y[2#AZ^OAX_[M(.KA
MZ2#E\.GS]/'O]MX@\_3G[2#OZ/SMYR#S_>WHY?/G\B#LY^W][.'T[_(N*2(*
M"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-@IM<V=I9"`B
M*$A434PI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHQ-@IM<V=I9"`B*%!L86EN(%1E>'0I(@IM<V=S='(@(B(*"B,Z
M('-P96QL:6YG+G!H<#HR.#`*;7-G:60@(B(*(BA2971U<FX@=&\@=&AE(&-O
M;7!O<V4@<V-R965N(&%F=&5R(&%P<&QY:6YG(&%L;"!C:&%N9V5S(&UA9&4@
M=&AU<R!F87(N("`B"B)#:&%N9V5S(&]N('1H92!C=7)R96YT('-C<F5E;B!W
M:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T<B`B(@HB*,7PZ?/T\>_VWB#S
M].?M(._H_.WG(//][>CE\^?R(.'V[_T@W??O]>T@Y?;A\>SO\_3EWR#\Z^7R
M(._I(.'KZ^'CW?(N(,_I("(*(N'KZ^'CW?(@\^4@X?7TWB#TY^T@[^C\[><@
MQ,7-(.CA(.7VX?'L[_/T[_WM+BDB"@HC.B!S<&5L;&EN9RYP:'`Z,C<W"B,L
M(&9U>GIY"FUS9VED("(B"B(H4V5N9"!M97-S86=E(&%F=&5R(&%P<&QY:6YG
M(&%L;"!C:&%N9V5S(&UA9&4@=&AU<R!F87(N("!#:&%N9V5S(&]N('1H92`B
M"B)C=7)R96YT('-C<F5E;B!W:6QL($Y/5"!B92!A<'!L:65D+BDB"FUS9W-T
M<B`B(@HB*,7PZ?/T\>_VWB#S].?M(._H_.WG(//][>CE\^?R(.'V[_T@W??O
M]>T@Y?;A\>SO\_3EWR#\Z^7R(._I(.'KZ^'CW?(N(,_I("(*(N'KZ^'CW?(@
M\^4@X?7TWB#TY^T@[^C\[><@Q,7-(.CA(.7VX?'L[_/T[_WM+BDB"@HC.B!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!
M9&0@=&AE<V4@8GD@8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J(-#Q[_/HWNKG
M(.'U]/[M(.7PZ>O=X^_M].'R(,_*("HB"@HC.B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(P-@IM<V=I9"`B*B!0;&5A<V4@<V5L96-T(&%D
M9')E<W,H97,I("HB"FUS9W-T<B`B*B#0X?'AZN'K_B#E\.GKW>[TY2#TYR#D
MZ>7]Z/7M\^<HY>GR*2`J(@H*(SH@;6%I;&)O>"YP:'`Z,3<T"B,L(&9U>GIY
M"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
MQR#TX?7T_/3G].$@7"(E<UPB(.3IX>/QW/;GZN4N(@H*(SH@;&EB+U-P86TN
M<&AP.C$X,`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E
M<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*(M3O(.S>[?7LX2#A]?3\(.'MX?;=\>CGZN4@^?(@
M)U-P86TG(//T[R#DZ>'WY>GQZ?/TWB#T[_4@\_7S]-[LX?3O\B#SX?(N(@H*
M(SH@;&EB+U-P86TN<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E
M(&AA<R!B965N(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(B"B+4
M[R#LWNWU[.$@X?7T_"#A[>'VW?'HY^KE(/GR("=3<&%M)R#S].\@Y.GA]^7I
M\>GS]-X@]._U(//U\_3>[.'T[_(@\^'R+B(*"B,Z(&QI8B]3<&%M+G!H<#HQ
M-S(*(RP@9G5Z>GD*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(M3O(.S>[?7LX2#A]?3\(.'MX?;=\>CGZN4@^?(@)U-P86TG(//T
M[R#DZ>'WY>GQZ?/TWB#T[_4@\_7S]-[LX?3O\B#SX?(N(@H*(SH@;&EB+U-P
M86TN<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N
M(')E<&]R=&5D(&%S('-P86TN(@IM<V=S='(@(B(*(M3O(.S>[?7LX2#A]?3\
M(.'MX?;=\>CGZN4@^?(@)U-P86TG(//T[R#DZ>'WY>GQZ?/TWB#T[_4@\_7S
M]-[LX?3O\B#SX?(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Q.0HC
M+"!F=7IZ>0IM<V=I9"`B,3`P(&-H87)A8W1E<G,B"FUS9W-T<B`BQ>GDZ>KO
MWR#WX?'AZO3>\>7R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,@HC
M+"!F=7IZ>0IM<V=I9"`B,3`P,"!C:&%R86-T97)S(@IM<V=S='(@(L7IY.GJ
M[]\@]^'QX>KTWO'E\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C`*
M(RP@9G5Z>GD*;7-G:60@(C(U,"!C:&%R86-T97)S(@IM<V=S='(@(L7IY.GJ
M[]\@]^'QX>KTWO'E\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C$*
M(RP@9G5Z>GD*;7-G:60@(C4P,"!C:&%R86-T97)S(@IM<V=S='(@(L7IY.GJ
M[]\@]^'QX>KTWO'E\B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D
M("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@
M(B(*(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A
M(')E='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-0IM
M<V=I9"`B04Y$(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU.3`*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.#<*;7-G:60@(D%C8V5P="!R
M97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U,PIM<V=I9"`B06-C97!T
M960B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U
M-PIM<V=I9"`B06-C97!T960Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9F5T8VAM86EL+VUA;F%G92YI;F,Z-PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N
M="=S(&YA;64Z(@IM<V=S='(@(L_M[^SA].7P_NWU[.\Z(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C4R,"!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-S,P"B,L(&9U>GIY"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(L3QW//G
M(@H*(SH@;&EB+TU)344O2&5A9&5R<RYP:'`Z,C`P(&QI8B]-24U%+TAE861E
M<G,N<&AP.C(P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D("5S
M('1O(&UY($%D9')E<W,@0F]O:R(*;7-G<W1R("+0\>_SZ-[JYR#S].\@Q.GE
M]>CU[?/I[^/QW/;O("@E<RDB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,#,*(RP@9G5Z>GD*;7-G:60@(D%D9"!S;W5R8V4B"FUS
M9W-T<B`BT/'O\^C>ZN<@T.?CX=_O]2#*_N3IZN$B"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-3<W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M.#@*;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*
M"B,Z(&-O;7!O<V4N<&AP.C$R-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R("+0
M\>_S]-WHY^KE(-WMX2#S]>WG[.S=[>\N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S('1O(&1I
M<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E<B!E86-H
M(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9&ET:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I
M97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D%D9&ET:6]N86P@:6YF
M;W)M871I;VX@9&5T86EL<R(*;7-G<W1R("+0\>_S^?#IZMWR(-#KY_'O]N_Q
MW^7R(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.3,*;7-G:60@
M(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(&-A;B!B92!V:65W960@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C<X"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R(*
M;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I=&EO;F%L(&UE<W-A9V4@97)R;W(@
M9&5T86EL<R!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!C;VYT
M86-T<RYP:'`Z.#4@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHQ
M.#`*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S,Y('1E;7!L
M871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,@IM<V=I9"`B061D<F5S<R!"
M;V]K(@IM<V=S='(@(L3IY?7H]>WSZ>_C\=SV[_(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,T"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VMS
M(@IM<V=S='(@(L3IY?7H]>WSZ>_C\=SV[_(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3@Y"FUS9VED("(B"B)!9&1R97-S97,@=&\@0D-#(&%L;"!M
M97-S86=E<SH@/&5M/BAO<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N
M(&$@;F5W("(*(FQI;F4I/"]E;3XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$X,0IM<V=I9"`B(@HB061D<F5S<V5S('1O(&5X<&QI
M8VET;'D@=&EE('1O('1H:7,@:61E;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N
M=&5R(&5A8V@@(@HB861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3`@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R,PIM<V=I9"`B06QL(@IM<V=S='(@(D_K
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,*;7-G
M:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS
M*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B"B)F:6QE.B(*
M;7-G<W1R("(B"B*\Z^$@].$@[.?M_>SA].$@\_3O[2CO]?(I(.'J_.OO]>CO
M(/;<ZN7K[RCO]?(IZ.$@[.7TX?;=\>_U[2#SY2#=[>$@]MSJY>OO(#HB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP:'`Z.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB06QL(&UE<W-A9V5S(&EN('EO=7(@7"(E
M<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S(&1A>7,@=VEL;"!B92!P97)M86YE
M;G1L>2`B"B)D96QE=&5D+B(*;7-G<W1R("(B"B*\Z^$@].$@[.?M_>SA].$@
M\_3O(/;<ZN7K[R!<(B5S7"(@\._U(.7?[>'I(/#AZ^G\].7QX2#A\/P@)7,@
MY^S=\>7R(.CA("(*(N3IX>/QX?;O_>T@[/SMZ>SA+B(*"B,Z(&QI8B]-86EN
M=&5N86YC92]487-K+V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY+G!H<#HU
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(&]L9"!L:6YK960@
M871T86-H;65N=',@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@=VEL;"!B92!D
M96QE=&5D+B(*;7-G<W1R("(B"B*\Z^_I(._I(/;<ZN7K[^D@[.4@X?#E\_3A
MZ^S=[>$@\._U(.7?[>'I(/#AZ^G\].7Q[^D@X?#\("5S(.S>[>7R(.CA("(*
M(N3IX>/QX?;O_>TN(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E
M7W-E;G1M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D%L;"!O;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H
M<R!O;&0@=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("(B"B*\Z^_I(._I(/;<
MZN7K[^D@[.4@X?#E\_3AZ^S=[>$@\._U(.7?[>'I(/#AZ^G\].7Q[^D@X?#\
M("5S(.S>[>7R(.CA("(*(N3IX>/QX?;O_>TN(@H*(SH@86-L+G!H<#HX-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B06QL(')I9VAT<R!O;B!F;VQD
M97(@7"(E<UPB('-U8V-E<W-F=6QL>2!R96UO=F5D(&9O<B!U<V5R(%PB)7-<
M(BXB"FUS9W-T<B`BSR#VW.KEZ^_R(%PB)7-<(B#LY?3O[>_LW//TY^KE(.SE
M(.7PZ?3U]]_A(//E(%PB)7-<(BXB"@HC.B!L:6(O87!I+G!H<#HW-@IM<V=I
M9"`B06QL;W<@1F]L9&5R($-R96%T:6]N/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z-#@*;7-G:60@(D%L;&]W(&9I;'1E
M<B!R=6QE<R!T;R!B92!A<'!L:65D(&EN(&%N>2!M86EL8F]X/R(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP.C$Q,`IM
M<V=I9"`B06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO;CHB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3@T"FUS9VED(")!;'=A>7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U-PHC+"!F=7IZ>0IM<V=I9"`B
M06QW87ES('-A=F4@871T86-H;65N=',B"FUS9W-T<B`BT/'O\_3=Z.?JY2#=
M[>$@\_7MY^SLW>WO+B(*"B,Z(&QI8B]-97-S86=E+G!H<#HU,#4*;7-G:60@
M(B(*(D%N(&5R<F]R(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I
M<"!T:&4@871T86-H;65N="X@5&AE($E-05`@<V5R=F5R("(*(G-A:60Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O365S<V%G92YP:'`Z,S@X"B,L(&9U>GIY"FUS
M9VED(")!;B!U;FMN;W=N(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@
M=&AE(&YE=R!N;W1E+B(*;7-G<W1R("+0X?'O]?/IW//TY^KE(-SC[?GS].\@
MZ]SH[_(@ZN'TW"#TY^T@\/'O\^C>ZN<@[=WA\B#EX^/QX?;>\BXB"@HC.B!L
M:6(O365S<V%G92YP:'`Z,S@W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N
M(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+B(*
M;7-G<W1R("+0X?'O]?/IW//TY^KE(-SC[?GS].\@Z]SH[_(@ZN'TW"#TY^T@
M\/'O\^C>ZN<@[=WA\B#EX^/QX?;>\BXB"@HC.B!M97-S86=E+G!H<#HU,#`@
M;6%I;&)O>"YP:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$X
M('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*;7-G<W1R
M("+!\.'M].?LW>WA(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS
M,0IM<V=I9"`B06YS=V5R960@;65S<V%G97,B"FUS9W-T<B`BP?#A[?3G[-WM
MX2#LY^W][.'TX2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z
M-PHC+"!F=7IZ>0IM<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R("+%]N'Q
M[._CWB#T^>T@]M_K]/'Y[2#S].\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H
M96%D97(N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%P<&QY
M($9I;'1E<G,@=&\@)7,B"FUS9W-T<B`BQ?;A\>SOX]X@]/GM(/;?Z_3Q^>T@
M\_3O(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS9VED
M(")!<'!L>2!F:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R
M("+%]N'Q[._CWB#T^>T@ZN'M_.WY[2#VW^OT\?GM(.K<Z.4@]N_QW"#P[_4@
MZMSMY?3E(.7I\^'C^>/>.R(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S
M+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;'D@9FEL=&5R(')U;&5S('=H
M96YE=F5R($E.0D]8(&ES(&1I<W!L87EE9#\B"FUS9W-T<B`B(@HBQ?;A\>SO
MX]X@]/GM(.KA[?SM^>T@]M_K]/'Y[2#JW.CE(/;O\=P@\._U(.K<[>7TY2#A
M[>'MW?GSYR#T[_4@(@HBX_'A[.SA]._JZ>+^].GO]3LB"@HC.B!T96UP;&%T
M97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR
M-PHC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1E
M;&5T92!T:&ES('!U8FQI8R!K97D_(@IM<V=S='(@(L7?\_3E(//?X^_U\>_I
M(/#Y\B#HW>OE].4@[>$@Y>KTY>O=\^7TY2#A]?3>(/3G[2#E[=WQX^7IX3LB
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHX-0IM<V=I9"`B(@HB07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE
M;F1E9"$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER
M96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z-@IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&1O('1H:7,_(@IM<V=S='(@
M(L7?\_3E(//?X^_U\>_I(/#Y\B#HW>OE].4@[>$@Y>KTY>O=\^7TY2#A]?3>
M(/3G[2#E[=WQX^7IX3LB"@HC.B!M97-S86=E+G!H<#HT,#<@=&5M<&QA=&5S
M+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AE<V4@;65S<V%G
M97,_(@IM<V=S='(@(L7?\_3E(//?X^_U\>_I(/#Y\B#HW>OE].4@[>$@Y.GA
MX_'<^.7TY2#A]?3<(/3A(.SG[?WLX?3A(,S/S<G,P3LB"@HC.B!L:6(O34E-
M12]#;VYT96YT<RYP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@4$5234%.14Y43%D@9&5L971E('1H:7,@871T86-H
M;65N=#\B"FUS9W-T<B`BQ=_S].4@\]_C[_7Q[^D@\/GR(.C=Z^7TY2#MX2#D
MZ>'C\=SXY?3E(.'U]-P@].$@[.?M_>SA].$@S,_-R<S!.R(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@96UP='D@=&AI<R!F;VQD97(_(@IM<V=S='(@(L7?
M\_3E(//?X^_U\>_I(/#Y\B#HW>OE].4@[>$@X>3EZ=SSY?3E(.'U]/P@]._M
M(/;<ZN7K[SLB"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@9F]L
M9&5R/R(*;7-G<W1R("+%W_/TY2#SW^/O]?'OZ2#P^?(@Z-WKY?3E(.WA(.'D
MY>G<\^7TY2#T[^T@ZMSD[SLB"@HC.B!L:6(O24U0+G!H<#HY-C8*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O
M;&1E<C\B"FUS9W-T<B`BQ=_S].4@\]_C[_7Q[^D@\/GR(.C=Z^7TY2#MX2#A
MY.7IW//E].4@]._M(.K<Y.\[(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O('!E<FUA;F5N=&QY(&1E;&5T92!T:&5S92!M97-S86=E<S\B"FUS
M9W-T<B`BQ=_S].4@\]_C[_7Q[^D@\/GR(.C=Z^7TY2#MX2#DZ>'C\=SXY?3E
M(.'U]-P@].$@[.?M_>SA].$@S,_-R<S!.R(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VIA=F%S8W)I<'0N:6YC.C@P('1E;7!L871E<R]M86EL8F]X+VIA=F%S
M8W)I<'0N:6YC.C<Y"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@<F5P;W)T('1H:7,@;65S<V%G92!A<R!I;FYO8V5N=#\B"FUS
M9W-T<B`BQ=_S].4@\]_C[_7Q[^D@\/GR(.C=Z^7TY2#MX2#AY.7IW//E].4@
MX?7T_"#T[^T@]MSJY>OO.R(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S
M8W)I<'0N:6YC.C<U('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC
M.C<T"B,L(&9U>GIY"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M<F5P;W)T('1H:7,@;65S<V%G92!A<R!S<&%M/R(*;7-G<W1R("+%W_/TY2#S
MW^/O]?'OZ2#P^?(@Z-WKY?3E(.WA(.'DY>G<\^7TY2#A]?3\(/3O[2#VW.KE
MZ^\[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I9"`B07)R
M:79A;"!4:6UE(@IM<V=S='(@(K_QX2#+WOCG\B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,S$*;7-G:60@(D%S8V5N9&EN9R(*;7-G<W1R("+!_>[O
M]?/A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3@S"FUS9VED(")!<VLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$Y"FUS9VED(")!='1A8V@B
M"FUS9W-T<B`BQ?#I\_WMX?CG(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-#<U"B,L(&9U>GIY"FUS9VED(")!='1A8V@@1FEL97,B"FUS
M9W-T<B`BT_7MY^SLW>WA(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#4V"FUS9VED(")!='1A8V@@82!C;W!Y(&]F('EO=7(@4$=0('!U
M8FQI8R!K97D@=&\@>6]U<B!M97-S86=E/R(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O=&YE9BYP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")!='1A
M8VAE9"!&:6QE.B(*;7-G<W1R("+%\.GS_>WA^.<B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z-#4Q(&QI8B]#;VUP;W-E+G!H<#HU,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB071T86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T
M86-H;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HS-S8*;7-G:60@
M(D%T=&%C:&5D(&ES(&$@<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO
M=2!S96YT+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E
M;F0N:6YC.C$V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHQ
M-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,#8@=&5M<&QA
M=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.3<*;7-G:60@(D%T=&%C:&UE
M;G0B"FUS9W-T<B`BT_7MY^SLW>WO(@H*(SH@8V]M<&]S92YP:'`Z,3`V-R!L
M:6(O365S<V%G92YP:'`Z-#8V"FUS9VED(")!='1A8VAM96YT('-T<FEP<&5D
M.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0Y('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C0W,PHC.B!L:6(O0V]M<&]S92YP:'`Z,3`W,PIM
M<V=I9"`B071T86-H;65N=',B"FUS9W-T<B`BT_7MY^SLW>WA(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8X,@HC+"!F=7IZ>0IM<V=I9"`B071T
M96YD965S(@IM<V=S='(@(M/U[>?L[-WMX2(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]N;W1I9FEC871I;VXN<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!='1E;G1I
M;VXB"FUS9W-T<B`BQ/'<\^<B"@HC.B!L:6(O075T:"]I;7`N<&AP.C0T"FUS
M9VED(")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0P
M"FUS9VED("(B"B)!=71O;6%T:6-A;&QY('-H;W<@:6UA9V5S(&EN($A434P@
M;65S<V%G97,@=VAE;B!T:&4@<V5N9&5R(&ES(&EN(&UY("(*(F%D9')E<W-B
M;V]K/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L
M96-T+FEN8SHR.3@*(RP@9G5Z>GD*;7-G:60@(D%V86EL86)L92!!9&1R97-S
M(&)O;VMS.B(*;7-G<W1R("+$Z>'HW?/I[._I(,3IY?7H]>WSZ>_C\=SV[^DZ
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<Q.0IM<V=I9"`B07=A
M:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0F%C7VL@=&\@)7,B"FUS9W-T<B`BQ?#I\_3Q[_;>(//TX2`E
M<R(*"B,Z('1H<F5A9"YP:'`Z,3,W('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T
M;R`E<R(*;7-G<W1R("+%\.GS]/'O]MX@\_3A("5S(@H*(SH@=&AR96%D+G!H
M<#HQ,S0*;7-G:60@(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN
M9&5X(@IM<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,R"FUS9VED(")"86-K
M('1O(%1H<F5A9"!$:7-P;&%Y(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0+T-L
M:65N="YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(D)A9"!O<B!M86QF
M;W)M960@<F5Q=65S="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@;65S<V%G92YP:'`Z,C8V('1E;7!L871E<R]C;VYT86-T<R]C;VYT
M86-T<RYI;F,Z,C(R"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI
M;F,Z,C`@;&EB+U-E87)C:"YP:'`Z,S0*;7-G:60@(D)C8R(*;7-G<W1R("+*
M\?7VWB#*[^GM[_#OW^?SYR(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.C$V,0IM<V=I9"`B0F5L;W<@:7,@=&AE(')A=R!T97AT(&]F('1H92!S
M=&%T=7,@:6YF;W)M871I;VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C(Q('1E;7!L871E
M<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V"FUS9VED(")";&%C:VQI<W0B"FUS
M9W-T<B`BQ>WO]^OG].GJWB#!Z^OGZ^_C\>'VW^$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C(Y"FUS9VED(")";&]C:R!I;6%G97,@:6X@2%1-3"!M
M97-S86=E<R!U;FQE<W,@=&AE>2!A<F4@<W!E8VEF:6-A;&QY(')E<75E<W1E
M9#\B"FUS9W-T<B`B(@H*(SH@;&EB+U-E87)C:"YP:'`Z-#(*;7-G:60@(D)O
M9'DB"FUS9W-T<B`BRN7?[.7M[R#,Y^W][.'T[_(B"@HC.B!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C(S('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z
M,SD*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU-2!T96UP;&%T97,O
M<V5A<F-H+VUA:6XN:6YC.C<Q"FUS9VED(")";W1H(@IM<V=S='(@(LKAZ2#T
MX2#D_>\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@W"FUS9VED(")"
M;W1H($AE861E<B!,:7-T:6YG(&%N9"!";V1Y(&]F($UE<W-A9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C<R"FUS
M9VED(")#7VAA<G-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+V9I96QD<RYI;F,Z,S8*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,C`Q"FUS9VED(")#86X@;F]T(&-O
M;FYE8W0@=&\@=&AE(')E;6]T92!M86EL('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ.3D*;7-G:60@(D-A;B!N;W0@
M8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@
M)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT
M("(*(FUA:6QB;W@N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C(X-"!T
M96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-0HC.B!T96UP;&%T
M97,O9F]L9&5R<R]I;7!O<G0N:6YC.C(Q('1E;7!L871E<R]S879E:6UA9V4O
M<V%V96EM86=E+FEN8SHQ.0HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S
M92YI;F,Z,C$@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@V"B,Z
M('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`@=&5M<&QA=&5S
M+W!G<"]P87-S<&AR87-E+FEN8SHS,@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C8V"FUS9VED(")#86YC96PB"FUS9W-T<B`BP>K]\?GSYR(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C<Q('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S-0HC.B!T96UP;&%T97,O8V]M<&]S
M92]R961I<F5C="YI;F,Z,3$Q"FUS9VED(")#86YC96P@365S<V%G92(*;7-G
M<W1R("+!ZOWQ^?/G(,SG[?WLX?3O\B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+W)E9&ER96-T+FEN8SHU('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,Z
M-@IM<V=I9"`B0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@=VEL;"!P97)M86YE
M;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB"FUS9W-T<B`BP>KU\?[M[^WT
MX?(@X?7T_"#T[R#LWNWU[.$@Z.$@]^'H[_WM(._QZ?/TZ>K<(/3A(/#E\>GE
M]_SLY>WA(/3O]2XB"@HC.B!M97-S86=E+G!H<#HR-C4@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHR,C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<F5C;VUP;W-E+FEN8SHQ-2!L:6(O4V5A<F-H+G!H<#HS,`IM<V=I9"`B0V,B
M"FUS9W-T<B`BRN_I[>_P[]_G\^<B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.CDS"FUS9VED("(B"B)#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T
M(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI
M<R`B"B)S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HW,#$*(RP@9G5Z>GD*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G
M<W1R("+0\>_S^?#IZMPB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z.#`*;7-G:60@(D-H86YG92(*;7-G<W1R("+!Z^OAX]XB"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#$*;7-G:60@(D-H86YG
M92!!;&PB"FUS9W-T<B`BP>OKX>/>(+SK^>TB"@HC.B!T96UP;&%T97,O86-L
M+V%C;"YI;F,Z.3(*;7-G:60@(D-H86YG92!&;VQD97(B"FUS9W-T<B`BP>OK
MX>/>(-;AZMWK[_4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS
M9VED("(B"B)#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA
M;GD@;65S<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M
M97-S86=E<R!A<F4@<V]R=&5D+B(*;7-G<W1R("(B"B+,\._QY=_TY2#MX2#A
MZ^O<[N7TY2#TZ?(@Y?#IZ^_CW?(@Y>SVW.WI\^?R+"#\\/GR(.7?[>'I(.\@
MX?'IZ.S\\B#LY^WU[-ST^>T@(@HB\._U(.+KW?#E].4@X>W<(//EZ]_DX2#J
MX>D@[R#T\?SP[_(@].'NZ>W\[.?SY_(@]/GM(.SG[?7LW/3Y[2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0*(RP@9G5Z>GD*;7-G:60@(D-H86YG
M92!M86EL('-E<G9E<B!A;F0@9F]L9&5R('-E='1I;F=S+B(*;7-G<W1R("+!
MZ^OAX]X@]/GM(/'UZ.S?\^7Y[2#$Z>'J[^SI\_3>+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE+"!A
M9&1R97-S+"!A;F0@<VEG;F%T=7)E('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@(@HB<F5P;'D@=&\@>6]U<B!E;6%I;"XB"FUS9W-T<B`B
M(@HBS/#O\>7?].4@[>$@X>OKW.[E].4@].\@_.WO[.$L(/3G(.3IY?WH]>WS
MYR#JX>D@].?M(/7P[^/QX?;>(//A\BP@\_3OZ??EW^$@(@HB\._U(.+KW?#O
M]>T@[^D@\.'QX>O>\/3E\B#SX?(@_/3A[2#DZ>'BW.;O]>T@WB#A\.'M]-SM
MY2#S].$@[.?M_>SA]-P@\^'R+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,C0*;7-G:60@(D-H87)A8W1E<G,@=&\@9&ES<&QA>3HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,34*;7-G:60@
M(D-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`BN.OEX_?O
M\B#6X>K=Z^_U*/GM*2#CZ>$@S=WA(,SG[?WLX?3A(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,B!T96UP;&%T97,O;6%I;&)O>"]M97-S
M86=E7VAE861E<G,N:6YC.C<U"FUS9VED(")#:&5C:R!?06QL+TYO;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC
M.C$P('1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN8SHR,0IM<V=I
M9"`B0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M
M86EL(&9R;VTZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-C,*(RP@9G5Z>GD*;7-G:60@(D-H96-K('-P96QL:6YG(&)E9F]R92!S
M96YD:6YG(&$@;65S<V%G93\B"FUS9W-T<B`BU?#>\>[E(.O<Z._R(.KA]-P@
M].?M(.'P[_/T[^O>(/3O]2#LY^W][.'T[_(Z("5S(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z-`IM<V=I9"`B0VAO;W-E($%C=&EO;CHB
M"FUS9W-T<B`BQ?#IZ]WN].4@Q>W=\>/EZ>$Z(@H*(SH@8V]N9FEG+W-E<G9E
M<G,N<&AP+F1I<W0Z,3@R"FUS9VED(")#:&]O<V4@82!M86EL('-E<G9E<CHB
M"FUS9W-T<B`BQ?#IZ]WN].4@Q.GAZN_LZ?/TWB#!Z^OGZ^_C\>'VW^'R.B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z,C$W"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E
M9&ET('1H92!A9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,2!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S,Q"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@86-T:6]N
M.B(*;7-G<W1R("+%\.GKW>[TY2#%[=WQX^7IX3HB"@HC.B!T96UP;&%T97,O
M<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS-#D*(RP@9G5Z>GD*;7-G:60@(D-H
M;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N(&%D9&EN9R!A9&1R
M97-S97,N(@IM<V=S='(@(B(*(L7PZ>O=[O3E(/3O[2#$Z>7UZ/7M\^GOX_'<
M]N\@\._U(.CA(/?QY_/I[._P[^GEW_3E(/STX>T@\/'O\^C=].7TY2#MW>7R
M("(*(N3IY?7H_>WSY>GR+B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S
M96QE8W0N:6YC.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E('1H92!O<F1E
M<B!O9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A
M9&1R97-S97,N(@IM<V=S='(@(B(*(L7PZ>O=[O3E(/3G(//EZ?'<(.SE(/3G
M[2#O\._?X2#HX2#CW^WE].'I(.'MX>;>].?SYR#S]._U\B#DZ>7UZ/7M\^GO
MX_'<]N_U\BXB"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@
M:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE
M=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9&]W;FQO860@
M=&AE(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O1FEL=&5R+G!H<#HQ,#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@9V\@=&\@)7,@;6%N
M86=E;65N="!P86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3$V"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O
M('9I97<@2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!A('1H=6UB;F%I
M;"!O9B!T:&ES(&EM86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O<&MC<S<N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0VQI8VL@)7,@=&\@=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R871E
M('=I;F1O=RXB"FUS9W-T<B`BQR#S_>WHY?/G(/3Y[2#LY^WU[-ST^>T@[>$@
MX]_MY?3AZ2#SY2#MW>\@\.'QW.CU\>\[(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W)E;&%T960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S
M('1O('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P
M87)A=&4@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O
M:'1M;"YP:'`Z.34*;7-G:60@(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA
M9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE
M8W0N:6YC.C,R,0HC+"!F=7IZ>0IM<V=I9"`B(@HB0VQI8VL@;VX@;VYE(&]F
M('EO=7(@<V5L96-T960@861D<F5S<R!B;V]K<R!A;F0@=&AE;B!S96QE8W0@
M86QL(&9I96QD<R!T;R`B"B)S96%R8V@N(@IM<V=S='(@(B(*(L7PZ>O=[O3E
M(-WMX2#A\/P@]._U\B#DZ>'HW?/I[._U\B#DZ>7UZ/7M\^GOX_'<]N_U\BP@
MZN'T_/#I[2#E\.GKW>[TY2#TX2`B"B+PY>3?X2#S].$@[_#OW^$@Z.$@X]_M
MY?3AZ2#A[>'FWO3G\^<N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,3<Q"FUS9VED(")#;&EC:R!T;R!3879E(%!'4"!0=6)L:6,@2V5Y(&EN('EO
M=7(@061D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K('1O
M(%-A=F4@4R]-24U%(&-E<G1I9FEC871E(&]F("5S(&EN('EO=7(@061D<F5S
M<R!";V]K(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-3`*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@8V]M<&]S
M92!A(&YE=R!M97-S86=E('1O('1H92!S96YD97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDU,0IM<V=I9"`B0VQI8VMI;F<@;VX@
M=&AE(&%D9')E<W,@=VEL;"!O<&5N('1H92!M97-S86=E('1O(&)E(')E860B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN
M:6YC.C(X"B,L(&9U>GIY"FUS9VED(")#;&]S92(*;7-G<W1R("+3_>WHY?/G
M(@H*(SH@8V]M<&]S92YP:'`Z.#(X(&-O;7!O<V4N<&AP.C$Q-#@*;7-G:60@
M(D-L;W-E('1H:7,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP
M.C0R.0IM<V=I9"`B0VQO<V5D($9O;&1E<B(*;7-G<W1R("+*Z^7I\_3\\B#6
MW.KEZ^_R(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(")#
M;VQL87!S92(*;7-G<W1R("+![=SP]/7NYR#\Z_GM(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"(*
M;7-G<W1R("+![=SP]/7NYR#\Z_GM(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM
M<V=S='(@(L'MW/#T]>[G(/SK^>T@]/GM(-;AZMWK^>TB"@HC.B!F;VQD97)S
M+G!H<#HT-#D*;7-G:60@(D-O;&QA<'-E($9O;&1E<B(*;7-G<W1R("+![=SP
M]/7NYR#6X>K=Z^_U(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C4Q"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`S"FUS9VED(")#;VUM96YT(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-CD*(RP@
M9G5Z>GD*;7-G:60@(D-O;7!L971E9"(*;7-G<W1R("+3_>WHY?/G(@H*(SH@
M8V]M<&]S92YP:'`Z.#(W(&-O;7!O<V4N<&AP.C$Q-#<*(RP@9G5Z>GD*;7-G
M:60@(D-O;7!O<V4@86YO=&AE<B!M97-S86=E(@IM<V=S='(@(M/][>CE\^<@
MY>W\\B#LY^W][.'T[_(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,T
M"FUS9VED(")#;VUP;W-E(&UE<W-A9V5S(&EN(&$@<V5P87)A=&4@=VEN9&]W
M/R(*;7-G<W1R("+'(//][>CE\^<@]/GM(.SG[?7LW/3Y[2#MX2#CW^WE].'I
M(//E(.W=[R#PX?'<Z/7Q[SLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#0S"FUS9VED("(B"B)#;VUP;W-E(&UE<W-A9V5S('=I=&@@86X@2%1-3"!'
M54D@8GD@9&5F875L="`H:68@8G)O=W-E<B!S=7!P;W)T<R!T:&4@(@HB9F5A
M='5R92D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-PIM<V=I9"`B0V]N9FEG=7)E(&AO=R!M97-S86=E<R!A<F4@9&ES<&QA>65D
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*(RP@
M9G5Z>GD*;7-G:60@(D-O;F9I9W5R92!M86EL('!R979I97<@;W!T:6]N<RXB
M"FUS9W-T<B`BP>OKX>/>(/3Y[2#Q]>CLW_/E^>T@Q.GAZN_LZ?/TWBXB"@HC
M.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,W,`IM<V=I9"`B0V]N;F5C=&EO;B!D
M<F]P<&5D(&)Y($E-05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T
M8VAM86EL+VEM87`N<&AP.C(S-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!S97)V
M97(@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!01U`@<W5P<&]R
M="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3+TU)344@<W5P
M<&]R="!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C$*;7-G:60@(D-O;G1R;VP@;W!T:6]N<R!R96QA=&EN9R!T;R!M
M97-S86=E<R!S96%R8VAI;F<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.0IM<V=I9"`B(@HB0V]N=')O;"!W:&5N(&YE=R!M86EL
M('=I;&P@8F4@8VAE8VME9"!F;W(L(&%N9"!W:&5T:&5R(&]R(&YO="!T;R!N
M;W1I9GD@>6]U("(*(G=H96X@:70@87)R:79E<RXB"FUS9W-T<B`B(@HBQ?#I
MZ]WN].4@ZMSHY2#P_/3E(./?[>7TX>D@W>OEX_?O\B#CZ>$@[=WA(.SG[?WL
MX?3A+"#JX>D@X>T@Z.$@Y>GD[_#OZ>7?\_3E("(*(OSTX>T@W?'W[^WTX>DN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y-@IM<V=I9"`B0V]N=F5R
M="!T97AT=6%L(&5M;W1I8V]N<R!I;G1O(&=R87!H:6-A;"!O;F5S/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@
M(D-O<'DB"FUS9W-T<B`BP>WTZ>/QX?;>(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ.2!T96UP;&%T97,O;6%I;&)O>"]N
M879B87(N:6YC.C4Q"B,L(&9U>GIY"FUS9VED(")#;W!Y('1O(&9O;&1E<B(*
M;7-G<W1R("*BY.7IX?/LX2#6X>K=Z^_U(,3IX>/QX>SLW>WA(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S"FUS9VED(")#;W)R96-T
M(@IM<V=S='(@(M/Y\_3\(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI
M;F<N:6YC.C$T,`IM<V=I9"`B0V]R<F5C=&5D(%1E>'0B"FUS9W-T<B`BQ.GO
M\>CY[-WM[R#*Y=_LY>WO(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VUP;&5T
M92!R97%U97-T+B!296%S;VX@1VEV96XZ("5S(@IM<V=S='(@(L3E[2#>].'M
M(.3U[>'T_.T@[>$@Y.GAX_'A]N_][2#TX2#LY^W][.'TX2#A\/P@)7,Z("5S
M(@H*(SH@871T86-H;65N="YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!T:&4@5D93(&)A8VME;F0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV-#`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@;65S<V%G97,@9G)O;2`E<RX@
M5&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("+$Y>T@WO3A[2#D]>WA]/SM
M(.WA(.3IX>/QX?;O_>T@].$@[.?M_>SA].$@X?#\("5S.B`E<R(*"B,Z(&QI
M8B]397-S:6]N+G!H<#HS,3@*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!E
M>&5C=71E(&UA:6YT96YA;F-E(&]P97)A=&EO;G,N(@IM<V=S='(@(LOEZ?3O
M]?'CW^7R(-/U[?3>\>?SY_(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE9BYP
M:'`Z-30*;7-G:60@(D-O=6QD(&YO="!E>'1R86-T('1H92!R97%U97-T960@
M9FEL92!F<F]M('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#;W5L9"!N
M;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@6FEP(&%R
M8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]397-S:6]N+G!H<#HR-S,*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!N86UE<W!A8V4@:6YF;W)M871I;VX@
M9G)O;2!)34%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<V5A<F-H+G!H<#HS
M,30@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8W('1E;7!L871E
M<R]A8VPO86-L+FEN8SHS.0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38P
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BQ.?LZ>_U\>/?X2(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C8*;7-G:60@(D-R96%T92!&;VQD
M97(B"FUS9W-T<B`BQ.?LZ>_U\>/?X2#6X>K=Z^_U(@H*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C$S-PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E($ME>7,B
M"FUS9W-T<B`BQ.?LZ>_U\>/?X2(*"B,Z('1E;7!L871E<R]S96%R8V@O:&5A
M9&5R+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(%9I<G1U86P@1F]L
M9&5R(@IM<V=S='(@(L3G[.GO]?'CW^$@UN'JW>OO]2(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C(V"FUS9VED(")#<F5A
M=&4@82!.97<@06-C;W5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O<W!A;7-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+W-P86US96QE
M8W0N:6YC.C(T"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!N97<@4W!A;2!F
M;VQD97(B"FUS9W-T<B`BQ.?LZ>_U\>/?X2#-W>_U(-;AZMWK[_4@)\3IX>/Q
MX>SLW>WA)R(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC
M.C$R('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(T"FUS9VED
M(")#<F5A=&4@82!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R("+$Y^SI[_7Q
MX]_A(,W=[_4@UN'JW>OO]2`GT/'\]^7I\>$G(@H*(SH@=&5M<&QA=&5S+W!R
M969S+W-E;G1M86EL<V5L96-T+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N
M=&UA:6QS96QE8W0N:6YC.C0R"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M
M86EL(&9O;&1E<B(*;7-G<W1R("+$Y^SI[_7QX]_A(,W=[_4@UN'JW>OO]2`G
MP?#E\_3AZ^S=[>$G(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T
M+FEN8SHQ,B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS
M9VED(")#<F5A=&4@82!N97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(L3G[.GO
M]?'CW^$@S=WO]2#6X>K=Z^_U("?$Z>'C\>'L[-WMX2<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(X"FUS9VED("(B"B)#<F5A=&4@9FEL=&5R:6YG
M(')U;&5S('1O(&]R9V%N:7IE('EO=7(@:6YC;VUI;F<@;6%I;"P@<V]R="!I
M="!I;G1O(&9O;&1E<G,L("(*(F%N9"!D96QE=&4@<W!A;2XB"FUS9W-T<B`B
M(@HBQ.?LZ>_U\>/?X2#VW^OT\?GM(./IX2#TY^T@[_'CW.WY\^<@]/GM(.7I
M\^7Q]_SLY>WY[2#LY^WU[-ST^>T@\^4@]N'JW>OO]?(@(@HBZN'I(.3IX>/Q
MX?;>(.'MY?#IZ/WLY_3Y[2#LY^WU[-ST^>T@*'-P86TI+B(*"B,Z('1E;7!L
M871E<R]S=&%T:6]N97)Y+W!R969S+FEN8SHQ-`HC+"!F=7IZ>0IM<V=I9"`B
M0W)E871E(&YE=R!S=&%T:6]N97)Y(@IM<V=S='(@(L3G[.GO]?'CW^$@S=WO
M]2#6X>K=Z^_U("?!\.7S].'K[-WMX2<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#0Y"FUS9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A;F0@9F]R;2!R
M97-P;VYS97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN
M8SHY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7)R96YT(&%C8V5S<R!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`U"FUS
M9VED(")#=7-T;VUI>F4@86-C;W5N=',@9F]R(&9E=&-H:6YG(&UA:6P@9G)O
M;2!O=&AE<B!A8V-O=6YT<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4Q"B,L(&9U>GIY"FUS9VED(")#=7-T;VUI>F4@:&]W('EO
M=2!S96YD(&UA:6PN(@IM<V=S='(@(B(*(M']Z.SI\^<@]/GM(.7PZ>OOX_[M
M(./IX2#TY^T@X?#O\_3OZ]X@[.?M]>S<]/GM(.KAZ2#TY^T@X?#OZ-[JY?7S
MYR#T[_7R(/GR("(*(O#Q_/?EZ?'A(-X@X?#E\_3AZ^S=[>$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T
M<B`B(@HBT?WH[.GSYR#T^>T@Y>WE\>/EZ?[M(/#O]2#HX2#EZO3EZ^_][?3A
MZ2#JX?3<(/3G[2#EW_/OY.\@\_3G[2#U\.?QY?/?X2`E<RXB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$W"B,L(&9U>GIY
M"FUS9VED(")$871?92(*;7-G<W1R("+'[.7Q[^SG[=_A(@H*(SH@;65S<V%G
M92YP:'`Z,C8R('1H<F5A9"YP:'`Z,30X"FUS9VED(")$871E(@IM<V=S='(@
M(L?LY?'O[.?MW^$B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4W
M"B,L(&9U>GIY"FUS9VED(")$96-L:6YE9"(*;7-G<W1R("+$Z>'C\>'L[-WM
MX2(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C,*;7-G:60@(D1E
M8VQI;F5D.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4S-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R("+$Z>'C\>'V
MWB(*"B,Z('1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L96-T+FEN
M8SHQ.`IM<V=I9"`B1&5F875L="!396%R8V@@1FEE;&0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,PIM<V=I9"`B1&5F875L="!S
M;W)T:6YG(&-R:71E<FEA.B(*;7-G<W1R("+0\>_E\.GKY>/LW>WA(.KQZ?3>
M\>GA(/3A[NGM_.SG\^?R.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,S,*;7-G:60@(D1E9F%U;'0@<V]R=&EN9R!D:7)E8W1I;VXZ(@IM<V=S='(@
M(M#Q[^7PZ>OEX^S=[><@ZN'TY?WH]>WSYR#TX>[I[?SLY_/G\CHB"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U"B,L(&9U>GIY"FUS9VED(")$
M96QE9V%T960B"FUS9W-T<B`BQ.GAX_'A[.S=[>$B"@HC.B!F;VQD97)S+G!H
M<#HT,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M86EL
M8F]X+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`BQ.GAX_'A]MXB
M"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@)7,@
M4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<Y('1E;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B1&5L
M971E($-U<G)E;G0@2V5Y<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]A8W1I;VYS+FEN8SHY"FUS9VED(")$96QE=&4@1F]L9&5R*',I(@IM
M<V=S='(@(L3IX>/QX?;>(-;AZMWK[_4H^>TI(@H*(SH@9F]L9&5R<RYP:'`Z
M,C@U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4V5L96-T960@1F]L9&5R<R(*
M;7-G<W1R("+$Z>'C\>'VWB#6X>K=Z^_U*/GM*2(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHT,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(%-T871I;VYE<GDB"FUS9W-T<B`BQ.GAX_'A]MX@UN'JW>OO]2CY[2DB"@HC
M.B!F;VQD97)S+G!H<#HT,3D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!6:7)T
M=6%L($9O;&1E<B(*;7-G<W1R("+$Z>'C\>'VWB#6X>K=Z^_U*/GM*2(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,PIM<V=I9"`B1&5L
M971E(&9E=&-H960@;65S<V%G97,@9G)O;2!R96UO=&4@<V5R=F5R/R(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(X"FUS9VED
M(")$96QE=&4@9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S8X"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M(@IM<V=S='(@(LWA(.3IX>/QW/;O[?3AZ2#OZ2#PX>OI[]\@ZN'TW.OOX^_I
M(,'0Q=/4P<O,Q<W!(//TY^T@X?'WWB#JW.CE(.S>[>$_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B1&5L971E(&]L9"!S96YT+6UA
M:6P@9F]L9&5R<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(LWA
M(.3IX>/QW/;O[?3AZ2#OZ2#PX>OI[]\@ZN'TW.OOX^_I(,'0Q=/4P<O,Q<W!
M(//TY^T@X?'WWB#JW.CE(.S>[>$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-P86T@;65S<V%G97,B
M"FUS9W-T<B`BQ.GAX_'A]MX@S.?M]>S<]/GM(@H*(SH@;65S<V%G92YP:'`Z
M-3`S(&UA:6QB;W@N<&AP.C<T,"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C(P"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S@@=&5M
M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHX"FUS9VED(")$96QE=&5D(@IM
M<V=S='(@(L3IX>/QX>SLW>WA(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHV,PIM<V=I9"`B1&5L971E9"!M97-S86=E<R(*;7-G<W1R("+$Z>'C
M\>'L[-WMX2#LY^W][.'TX2(*"B,Z(&-O;7!O<V4N<&AP.C,P-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!T:&4@871T86-H;65N="!<
M(B5S7"(N(@IM<V=S='(@(L3IX>/QX?;>(//U[>?L[-WM[_4N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")$96QE=&EN9R!A;F0@36]V
M:6YG($UE<W-A9V5S(@IM<V=S='(@(L3IX>/QX?;>(.KAZ2#,Y?3A]N_QW"#,
MY^WU[-ST^>TB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DR"FUS
M9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4T,`IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E
M+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDS,@IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G<W1R("+6Z-_M
M[_7SX2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHR
M,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C8Y"B,L(&9U>GIY"FUS9VED
M(")$97-C<FEP=&EO;B(*;7-G<W1R("+%\.GK[^/=\B#7\=[S].<B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*
M;7-G:60@(D1E=&%I;',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8W-PIM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM<V=S='(@(L<@
M]?#OX_'A]MX@\^'R.R(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C,V"FUS9VED(")$:7-P;&%Y(@IM<V=S='(@(L7L]MSMZ?/G(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W.0IM<V=I9"`B1&ES<&QA>2!C
M;VYF:7)M871I;VX@869T97(@<V5N9&EN9R!A(&UE<W-A9V4_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#8*;7-G:60@(D1I<W!L
M87D@:6X@0F]D>2!O9B!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.3(*;7-G:60@(D1I<W!L87D@<&]P+75P(&YO=&EF
M:6-A=&EO;B!O9B!N97<@;6%I;#\B"FUS9W-T<B`BQ>SVW.WI\^<@Y>GD[_#O
MW^?SY_(@ZN'TW"#TY^T@\.'QX>OAXMX@[=WY[2#LY^WU[-ST^>T[(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U.`IM<V=I9"`B1&ES<&QA>2!T:&4@
M7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES<&QA
M>2!T:&4@7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VXB"FUS9W-T<B`BQ?#I
MZ^_CW?(@Q>SVW.WI\^?R(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C(V"FUS9VED(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,38*;7-G:60@(D1O($YO="!#
M:&5C:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(@IM<V=S='(@(LWA(.SG[2#C
MW^WE].'I(+CKY>/W[_(@\_3O[2CO]?(I(-;<ZN7K[RCO]?(I(./IX2#MW>$@
M[.?M_>SA].$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34R"FUS9VED
M(")$;R!N;W0@9V5N97)A=&4@82!L:6YK(&EN('1H92!&<F]M.B!C;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`W-0IM<V=I9"`B1&\@>6]U
M('=A;G0@=&\@;W!E;B!T:&%T(&9O;&1E<C\B"FUS9W-T<B`BR-WKY?3E(.WA
M(.'M[]_NY?3E(.'U]/SM(/3O[2#VW.KEZ^\[(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,S(*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C$R-@IM<V=I9"`B1&]N92(*;7-G<W1R("*XX^GMY2(*
M"B,Z(&QI8B]-24U%+T-O;G1E;G1S+G!H<#HQ.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&]W;FQO860@)7,@:6X@+GII<"!&;W)M870B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3(*;7-G:60@(D1O
M=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,`IM<V=I
M9"`B1&]W;FQO860@1F]L9&5R*',I(@IM<V=S='(@(M;<ZN7K[_(@P>WAZO3G
M[-WM^>TB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,0HC
M+"!F=7IZ>0IM<V=I9"`B1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA
M=%TB"FUS9W-T<B`BUMSJY>OO\B#![>'J].?LW>WY[2(*"B,Z(&QI8B]-24U%
M+T-O;G1E;G1S+G!H<#HQ.3(*;7-G:60@(D1O=VYL;V%D(&EN("YZ:7`@1F]R
M;6%T(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C4P,2!M86EL8F]X+G!H
M<#HW,3D@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ
M,0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(R('1E;7!L871E
M<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#$*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;&5G96YD+FEN8SHY"FUS9VED(")$<F%F="(*;7-G<W1R("+0\?SWY>GQX2(*
M"B,Z(&9O;&1E<G,N<&AP.C,Y,@HC+"!F=7IZ>0IM<V=I9"`B1')A9G0@9F]L
M9&5R(@IM<V=S='(@(M;<ZN7K[_(@T/'\]^7I\?GM.B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.C(S"FUS9VED(")$<F%F=',@9F]L
M9&5R.B(*;7-G<W1R("+6W.KEZ^_R(-#Q_/?EZ?'Y[3HB"@HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,3`X"B,L(&9U>GIY"FUS9VED(")%+6UA:6P@061D
M<F5S<R(*;7-G<W1R("+$Z>7]Z/7M\^<@P>OKY^OOX_'A]M_A\B(*"B,Z(&QI
M8B]-86EL8F]X+G!H<#HS,#D*;7-G:60@(D5.1"(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HW-`IM<V=I9"`B15)23U(Z(%EO
M=7(@;65S<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D+B(*;7-G<W1R("(B
M"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E
M9G,N:6YC.C$Y"FUS9VED(")%9&ET(@IM<V=S='(@(L7PY>[E\>/A\]_A(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C$X"B,L(&9U>GIY"FUS
M9VED(")%9&ET($)L86-K;&ES="(*;7-G<W1R("+%[>_WZ^?TZ>K>(,'KZ^?K
M[^/QX?;?X2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PHC
M+"!F=7IZ>0IM<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(M;?Z_3QX2#,
MY^WU[-ST^>TB"@HC.B!F;VQD97)S+G!H<#HT,C`@=&5M<&QA=&5S+W-E87)C
M:"]H96%D97(N:6YC.C$V"FUS9VED(")%9&ET(%9I<G1U86P@1F]L9&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B!$969I
M;FET:6]N(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ.`HC+"!F=7IZ
M>0IM<V=I9"`B161I="!Y;W5R(&)L86-K;&ES="(*;7-G<W1R("+%\.7NY?'C
MX?/?X2#T^>T@ZN'M_.WY[2#VW^OT\?GM(@H*(SH@=&5M<&QA=&5S+V9I;'1E
M<G,O<')E9G,N:6YC.C$S"FUS9VED(")%9&ET('EO=7(@9FEL=&5R(')U;&5S
M(@IM<V=S='(@(L7PY>[E\>/A\]_A(/3Y[2#JX>W\[?GM(/;?Z_3Q^>TB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8Q"FUS9VED(")%9&ET('EO=7(@
M<')E9F5R96YC97,@9F]R(&%C8V5S<VEN9R!O=&AE<B!M86EL(&%C8V]U;G1S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z
M,C,*(RP@9G5Z>GD*;7-G:60@(D5D:70@>6]U<B!W:&ET96QI<W0B"FUS9W-T
M<B`BQ?#E[N7QX^'SW^$@]/GM(.KA[?SM^>T@]M_K]/'Y[2(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C,Y"FUS9VED(")%;6%I;"!!
M9&1R97-S(@IM<V=S='(@(L3IY?WH]>WSYR#!Z^OGZ^_C\>'VW^'R(@H*(SH@
M;&EB+TUE<W-A9V4N<&AP.C8U-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RXB"FUS9W-T<B`BRN'H
MX?'I\^S\\B#\Z_GM(/3Y[2#LY^WU[-ST^>T@X?#\("5S+B(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(R"FUS9VED(")%;7!T>2!&;VQD
M97(H<RDB"FUS9W-T<B`BHN3EZ>'S[.$@UN'JW>OO]2CY[2DB"@HC.B!F;VQD
M97)S+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(%-E;&5C=&5D($9O
M;&1E<G,B"FUS9W-T<B`BHN3EZ>'S[.$@UN'JW>OO]2CY[2DB"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A
M<V@@9F]L9&5R(@IM<V=S='(@(J+DY>GA\^SA(-;AZMWK[_4@Q.GAX_'A[.S=
M[>$B"@HC.B!L:6(O24U0+G!H<#HY-S,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y
M(%]3<&%M(@IM<V=S='(@(J+DY>GA\^SA(,3IX>/QX>SLW>WY[2(*"B,Z(&QI
M8B])35`N<&AP.CDV-@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@7U1R87-H(@IM
M<V=S='(@(J+DY>GA\^SA(,3IX>/QX>SLW>WY[2(*"B,Z('1E;7!L871E<R]P
M9W`O<&=P+FEN8SHQ('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHV"FUS
M9VED(")%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,2!T96UP;&%T97,O<VUI;64O
M;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4R]-24U%(&9U;F-T:6]N
M86QI='D_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,3$*;7-G:60@(D5N86)L92!M97-S86=E('!R979I97=S/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT-#(*(RP@9G5Z
M>GD*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T<B`BQ?#I\_3Q
M[_;>(//TZ?(@Q?#IZ^_CW?(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3$W(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-3<*;7-G:60@(D5N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S@T"FUS9VED(")%
M;F0@9F]R=V%R9&5D(&UE<W-A9V4B"FUS9W-T<B`BU-WK[_(@\/'O^>CG[-WM
M[_4@[.?M_>SA]._R(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,T,0HC+"!F=7IZ
M>0IM<V=I9"`B16YD(&UE<W-A9V4B"FUS9W-T<B`BT.'KZ=P@S.?M_>SA].$B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%;F0@;65S<V%G92!F<F]M("5S(@IM<V=S='(@(M#Q[_[HY_/G
M(.SG[?WLX?3O\B#A\/P@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B16YT97(@
M4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O<W!A
M;7-E;&5C="YI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B16YT97(@=&AE(&YA;64@
M9F]R('EO=7(@;F5W(%-P86T@9F]L9&5R(@IM<V=S='(@(L3^\_3E(/3O(/SM
M[^SA(./IX2#T[R#MW>\@]MSJY>OO("?0\?SWY>GQX2<B"@HC.B!T96UP;&%T
M97,O<')E9G,O9F]L9&5R<V5L96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@
M;F%M92!F;W(@>6]U<B!N97<@9')A9G1S(&9O;&1E<B(*;7-G<W1R("+$_O/T
MY2#T[R#\[>_LX2#CZ>$@].\@[=WO(/;<ZN7K[R`GT/'\]^7I\>$G(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-E;G1M86EL<V5L96-T+FEN8SHR,PIM<V=I9"`B
M16YT97(@=&AE(&YA;64@9F]R('EO=7(@;F5W('-E;G0@;6%I;"!F;VQD97(B
M"FUS9W-T<B`BQ/[S].4@].\@_.WO[.$@X^GA(/3O(.W=[R#VW.KEZ^\@P?#E
M\_3AZ^S=[>$B"@HC.B!T96UP;&%T97,O<')E9G,O=')A<VAS96QE8W0N:6YC
M.CD*;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T<F%S:"!F
M;VQD97(B"FUS9W-T<B`BQ/[S].4@].\@_.WO[.$@X^GA(/3O(.W=[R#VW.KE
MZ^\@)]#Q_/?EZ?'A)R(*"B,Z(&QI8B]396%R8V@N<&AP.C0V"B,L(&9U>GIY
M"FUS9VED(")%;G1I<F4@365S<V%G92(*;7-G<W1R("+![>'JX?3E_>CU[?/G
M(,SG[?WLX?3O\B(*"B,Z(&UE<W-A9V4N<&AP.C$Y-"!C;VUP;W-E+G!H<#HQ
M,3,T('1H<F5A9"YP:'`Z-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D5N=')Y(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`BQR#DZ>7]Z/7M\^<@7"(E<UPB(.KA].'W
M^?'>Z.?JY2#E\.GT]??^\B#S].\@Y.GE]>CU[?/I[^/QW/;O(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ."!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z,C$*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HS-S8@;&EB+TU)
M344O5FEE=V5R+W!G<"YP:'`Z,S@V"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T
M=7,N<&AP.C<R(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$V,PIM<V=I
M9"`B17)R;W(B"FUS9W-T<B`BR]SH[_(B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C;VYN96-T:6YG
M('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R
M97!L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D5V96YT('-U8V-E<W-F=6QL>2!D
M96QE=&5D+B(*;7-G<W1R("+/(/;<ZN7K[_(@7"(E<UPB(.3IX>/QW/;GZN4@
M[.4@Y?#I]/7WW^$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,@IM
M<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("+*W.CE(#$U(,OE\/3<
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W.0IM<V=I9"`B179E<GD@
M,S`@<V5C;VYD<R(*;7-G<W1R("+*W.CE(#,P(,OE\/3<(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM
M<V=S='(@(LK<Z.4@-2#+Y?#TW"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.#,*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+*W.CE(.SI
M\]X@_O'A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,`IM<V=I9"`B
M179E<GD@;6EN=71E(@IM<V=S='(@(LK<Z.4@Z^7P]/PB"@HC.B!F;VQD97)S
M+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"(*;7-G<W1R("+![=SP
M]/7NYR"\Z_GM(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z
M,S@*;7-G:60@(D5X<&%N9"!!;&PB"FUS9W-T<B`BP>W<\/3U[N<@O.OY[2(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C,X"FUS9VED(")%
M>'!A;F0@06QL($9O;&1E<G,B"FUS9W-T<B`BP>W<\/3U[N<@O.OY[2#T^>T@
MUN'JW>OY[2(*"B,Z(&9O;&1E<G,N<&AP.C0U-PIM<V=I9"`B17AP86YD($9O
M;&1E<B(*;7-G<W1R("+![=SP]/7NYR#6X>K=Z^_U(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD($YA;65S(@IM<V=S='(@(L'M
MW/#T]>[G(,_M[^S<]/GM(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-C,*;7-G:60@(D5X<&%N9"!N86UE<R!I;B!T:&4@8V]M<&]S92!W:6YD;W<@
M875T;VUA=&EC86QL>2!I;B!T:&4@8F%C:V=R;W5N9#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX,`IM<V=I9"`B17AP86YD('1H
M92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@9F]L9&5R
M<R!V:65W/R(*;7-G<W1R("+-X2#CW^WE].'I(/#<[?3A(.'MW/#T]>[G(/SK
M[_4@]._U(.3=[?3Q[_4@]/GM(/;AZMWK^>T[(@H*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z,30T('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C$Y-`HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M-#4@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C$P,0HC+"!F=7IZ
M>0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(L'MW/#T]>[G(+SK^>TB"@HC
M.B!L:6(O24U0+G!H<#HY.#0@;&EB+TE-4"YP:'`Z.3@V"B,L(&9U>GIY"FUS
M9VED(")&7V5T8V@@36%I;"(*;7-G<W1R("+-W>\@S-[M]>SA(@H*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C(V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D9E=&-H($UA:6PB"FUS
M9W-T<B`BS=WO(,S>[?7LX2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-CD*(RP@9G5Z>GD*;7-G:60@(D9E=&-H($UA:6P@:6X@82!S97!A<F%T92!W
M:6YD;W<_(@IM<V=S='(@(L<@\_WMZ.7SYR#T^>T@[.?M]>S<]/GM(.WA(./?
M[>7TX>D@\^4@[=WO(/#A\=SH]?'O.R(*"B,Z('1E;7!L871E<R]F971C:&UA
M:6PO;6%N86=E+FEN8SHT-@HC+"!F=7IZ>0IM<V=I9"`B1F5T8V@@;65S<V%G
M97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R("+%]N'Q[._CWB#T^>T@ZN'M
M_.WY[2#VW^OT\?GM(.K<Z.4@]N_QW"#P[_4@ZMSMY?3E(.7I\^'C^>/>.R(*
M"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1F5T8VAE9"`E9"!M97-S86=E<R!F<F]M("5S(@IM<V=S='(@
M(LKAZ.'QZ?/L_/(@_.OY[2#T^>T@[.?M]>S<]/GM(.'P_"`E<RXB"@HC.B!L
M:6(O1F5T8VAM86EL+G!H<#HR.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9E=&-H960@,2!M97-S86=E(&9R;VT@)7,B"FUS9W-T<B`BT/'O_NCG
M\^<@[.?M_>SA]._R(.'P_"`E<R(*"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(X
M-2!L:6(O1F5T8VAM86EL+G!H<#HR.#<@;&EB+T9E=&-H;6%I;"YP:'`Z,C@Y
M"FUS9VED(")&971C:&UA:6PZ("(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM
M86EL+G!H<#HR.3$*(RP@9G5Z>GD*;7-G:60@(D9E=&-H;6%I;#H@;F\@;F5W
M(&UE<W-A9V5S+B(*;7-G<W1R("*X]^7TY2`E<R#-W>$@[.?M_>SA].$N(@H*
M(SH@;&EB+TE-4"YP:'`Z.3DP"B,L(&9U>GIY"FUS9VED(")&:5]L=&5R<R(*
M;7-G<W1R("+6W^OT\>$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHU,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:G,Z.#(*
M(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`BUM_K]/'O(@H*(SH@=&5M
M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")&
M:6QT97(@3W!T:6]N<R(*;7-G<W1R("+!Z^OE\B#%\.GK[^/=\B(*"B,Z('1E
M;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHY"B,L(&9U>GIY"FUS9VED(")&
M:6QT97(@4V5T=&EN9W,B"FUS9W-T<B`BRN'M_.WE\B#6W^OT\?GM(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8P,`IM<V=I9"`B1FEL=&5R(&UE<W-A
M9V4@8V]N=&5N="!F;W(@<')O9F%N:71Y/R(*;7-G<W1R("+-X2#6Z>OT\=SQ
MY?3AZ2#T[R#PY?'IY??\[.7M[R#T^>T@[.?M]>S<]/GM(./IX2#UXO'I\_3I
MZOP@\.7QZ>7W_.SE[>\[(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T
M:79E+FEN8SHQ,0IM<V=I9"`B1FEL=&5R('-U<'!O<G0@:7,@9&ES86)L960@
M;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C<*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`BUM_K]/'A(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHS"FUS9VED(")&
M:6QT97)S($Y/5"!!8W1I=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP
M:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(D9I;'1E<G,Z("5S(&UA;F%G
M96UE;G0@<&%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O
M8V]N=&%C=',N:6YC.C$X-@IM<V=I9"`B1FEN9"(*;7-G<W1R("+![>'FWO3G
M\^<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`U"B,L(&9U>GIY"FUS
M9VED(")&:7)S="!-86EL8F]X(%!A9V4B"FUS9W-T<B`BP?'WZ>K>(-/EZ]_D
MX2`B"@HC.B!M86EL8F]X+G!H<#HS-#4*;7-G:60@(D9I<G-T(%!A9V4B"FUS
M9W-T<B`BP?'WZ>K>(-/EZ]_DX2`B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(D9O7W)W87)D(@IM<V=S='(@(M#Q
M[_[HY_/G(@H*(SH@9F]L9&5R<RYP:'`Z,C8V('1E;7!L871E<R]F;VQD97)S
M+V9O;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G:60@(D9O;&1E<B!!8W1I;VYS
M("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,P
M,R!T96UP;&%T97,O9F]L9&5R<R]H96%D+FEN8SHY"B,Z('1E;7!L871E<R]P
M<F5F<R]I;FET:6%L<&%G97-E;&5C="YI;F,Z-@HC.B!T96UP;&%T97,O<')E
M9G,O:6YI=&EA;'!A9V5S96QE8W0N:6YC.C$P"FUS9VED(")&;VQD97(@3F%V
M:6=A=&]R(@IM<V=S='(@(M;<ZN7K[_(@3F%V:6=A=&]R(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D9O;&1E<B!3=6UM
M87)Y(@IM<V=S='(@(M;EXO'O]=SQZ>_R(@H*(SH@86-L+G!H<#HR-`IM<V=I
M9"`B1F]L9&5R('-H87)I;F<@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(B(*
M"B,Z(&9O;&1E<G,N<&AP.C8R"FUS9VED(")&;VQD97(@=7-E(&ES(&YO="!E
M;F%B;&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.38Y"FUS9VED(")&;W)M870@;V8@;65S<V%G92!D871E<R!I;B!T:&4@;6%I
M;&)O>"!V:65W(&9O<B!M97-S86=E<R!D871E9"!T;V1A>2(*;7-G<W1R("(B
M"@HC.B!C;VUP;W-E+G!H<#HW.#`@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C$U"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C(Q"FUS9VED(")&;W)W87)D(@IM<V=S='(@(M#Q[_[HY_/G(@H*(SH@
M8V]M<&]S92YP:'`Z-S8U"FUS9VED(")&;W)W87)D.B(*;7-G<W1R("+0\>_^
MZ.?SYSHB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8Y"B,L(&9U>GIY"FUS9VED
M(")&;W)W87)D960@;65S<V%G92(*;7-G<W1R("+4W>OO\B#P\>_YZ.?LW>WO
M]2#LY^W][.'T[_(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B"FUS9W-T
M<B`BT/'O_NCG\^<@[.?M_>SA]._R(.'P_"`E<R(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT.#,*(RP@9G5Z>GD*;7-G:60@(D9R964O0G5S>2!)
M;F9O<FUA=&EO;B(*;7-G<W1R("+0Z^?Q[_;O\=_E\B#$Z>'J[^SI\_3>(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Y-`IM<V=I9"`B1G)E92]"
M=7-Y(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HT.#@*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT,#$*;7-G:60@(D9R964O
M0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*(RP@9G5Z>GD*;7-G
M:60@(D9R;U]M(@IM<V=S='(@(L'P_"(*"B,Z(&UE<W-A9V4N<&AP.C(V,R!T
M:')E860N<&AP.C$T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHY
M.0HC.B!L:6(O4V5A<F-H+G!H<#HR,@IM<V=I9"`B1G)O;2(*;7-G<W1R("+!
M\/PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$X"FUS9VED(")&<F]M
M($%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G(,'P[_/T[^O=X2(*"B,Z(&-O
M;7!O<V4N<&AP.C<W-R!C;VUP;W-E+G!H<#HW.#$*;7-G:60@(D9W9#HB"FUS
M9W-T<B`BT/'O_N@N.B(*"B,Z(&-O;7!O<V4N<&AP.C$R.30*(RP@9G5Z>GD*
M;7-G:60@(D9W9#H@(@IM<V=S='(@(M#Q[_[H+CHB"@HC.B!C;VUP;W-E+G!H
M<#HQ,CDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&=V0Z("5U($9O
M<G=A<F1E9"!-97-S86=E<R(*;7-G<W1R("+4W>OO\B#P\>_YZ.?LW>WO]2#L
MY^W][.'T[_(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,`HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@*(RP@9G5Z>GD*;7-G:60@(D=E
M;F5R86P@3W!T:6]N<R(*;7-G<W1R("+%\.GK[^/=\B#7\=[S].<B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,S<*;7-G:60@(D=E="!O
M;FQY(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S$*;7-G:60@(D=O(@IM
M<V=S='(@(B(*"B,Z('1H<F5A9"YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")'
M;R!T;R!-97-S86=E(@IM<V=S='(@(L7P_.SE[>\@S-[M]>SA(@H*(SH@;&EB
M+TE-4"YP:'`Z-#DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")';R!T
M;R!A9&1R97-S(&)O;VL@96YT<GD@;V8@7"(E<UPB(@IM<V=S='(@(M#Q[_/H
MWNKG(//T[R#$Z>7UZ/7M\^GOX_'<]N\@*"5S*2(*"B,Z('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ,S4*;7-G:60@(D=R86YT(&%C8V5S<R(*;7-G<W1R("(B
M"@HC.B!M97-S86=E+G!H<#HU-#8@;&EB+T9I;'1E<BYP:'`Z,3`U(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.CDU"B,Z(&QI8B]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C$P,B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#0*
M(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HQ,38*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A
M=&EO;BYP:'`Z-C(@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z
M-C@*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP.C<Y(&QI8B]-24U%
M+U9I97=E<B]P:V-S-RYP:'`Z-#$X"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L
M961O=6)L92YP:'`Z-#$@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,3<S"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$R,"!L:6(O34E-12]6:65W
M97(O<W1A='5S+G!H<#HQ,C<*;7-G:60@(DA%4D4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,Q(&QI8B]-24U%+U9I
M97=E<B]H=&UL+G!H<#HQ,3<*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N
M<&AP.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP
M.C(U-@IM<V=I9"`B2%1-3"!697)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z-3@*;7-G:60@
M(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C
M;VUP;W-E+FEN8SHU"FUS9VED(")(97)E(&ES('1H92!M97-S86=E('EO=2!W
M97)E(&-O;7!O<VEN9SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V.`IM<V=I9"`B2&ED9&5N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-C<*(RP@9G5Z>GD*;7-G:60@(DAI9&1E;B!I
M;B!4:')E860@5FEE=R(*;7-G<W1R("+0\>_B[^O>(.WG[-ST^>TB"@HC.B!M
M86EL8F]X+G!H<#HS-C<*;7-G:60@(DAI9&4@1&5L971E9"(*;7-G<W1R("+!
M\/SJ\?7XYR#$Z>7C\>'L[-WM^>TB"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G
M:60@(DAI9&4@56YS=6)S8W)I8F5D(@IM<V=S='(@(L'P_.KQ]?CG(.S>(//U
M[>3E[-WM^>TB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR
M.30*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP:'`Z,CDW
M(&UA:6QB;W@N<&AP.C<R-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC
M.C$R"FUS9VED(")(:6=H(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,PIM<V=I9"`B2&EG:&5S="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@X"FUS9VED
M(")(;W<@9&\@>6]U('=A;G0@=&\@9&ES<&QA>2!A='1A8VAM96YT<S\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-`HC+"!F=7IZ
M>0IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN97,@:6X@82!R
M97!L>2(*;7-G<W1R("+0[^GO\B#WX?'AZO3>\>'R(.WA(/3O\._HY?3EW_3A
MZ2#P\>GM(.'P_"#JW.CE(./QX>SLWB#S].GR(.'PX>WTWO/EZ?(Z(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,S0*;7-G:60@(DE-05`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,CD*;7-G:60@(DE-
M05`@*$%U=&\@1&5T96-T(%!R;W1O8V]L<RDB"FUS9W-T<B`B(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!397)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B!397)V97(@4F5S<&]N
M9&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$V-B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$T-@IM<V=I9"`B24U!
M4"!O=F5R(%-33"(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$U,@IM<V=I9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N960@8V5R
M=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,38W"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE9"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS-C@*;7-G:60@
M(DE-05`@<V5R=F5R(&-L;W-E9"!T:&4@8V]N;F5C=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C4@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G<W1R
M("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C0Y"FUS9VED("))34%0
M+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@(B(*"B,Z(&QI8B])35`N<&AP
M.C@V-@IM<V=I9"`B24Y"3U@B"FUS9W-T<B`BQ>GSY?'W_.SE[>$B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C0Q,0IM<V=I9"`B268@=7-I;F<@4U-,(&]R
M(%1,4RP@>6]U(&UU<W0@:&%V92!T:&4@4$A0(&]P96YS<VP@97AT96YS:6]N
M(&QO861E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L
M9&5R<U]C;VYF:7)M+FAT;6PZ,3(*(RP@9G5Z>GD*;7-G:60@(DEF('EO=2!C
M;VYT:6YU92P@86QL(&UE<W-A9V5S(&EN('1H92!F;VQD97(H<RD@=VEL;"!B
M92!L;W-T(2(*;7-G<W1R("*\Z^$@].$@[.?M_>SA].$@\_3O[2CO]?(I(/;<
MZN7K[RCO]?(I(.CA(/?AZ._][2$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G<W1R("+0X?'<XNOE
M^.<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#,*;7-G
M:60@(DEG;F]R92!!;&PB"FUS9W-T<B`BT.'QW.+KY?CG(">\Z_GM(@H*(SH@
M=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C@*;7-G:60@(DEM
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI
M;F,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEM<&]R="(*;7-G<W1R("+3Y^SA[?3I
MZMPB"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.#4@=&5M
M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B
M26UP;W)T($ME>2(*;7-G<W1R("+3Y^SA[?3IZMPB"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z,3,Y"B,L(&9U>GIY"FUS9VED("));7!O<G0@2V5Y<&%I
M<B(*;7-G<W1R("+3Y^SA[?3IZMPB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A
M8W1I;VYS+FEN8SHR-PHC+"!F=7IZ>0IM<V=I9"`B26UP;W)T($UE<W-A9V5S
M(@IM<V=S='(@(M/G[.'M].GJW"#LY^W][.'TX2(*"B,Z('!G<"YP:'`Z-#(*
M;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S;6EM92]S;6EM92YI;F,Z.3$*;7-G:60@(DEM<&]R="!097)S;VYA;"!#
M97)T:69I8V%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R
M=%]K97DN:6YC.C$T"FUS9VED("));7!O<G0@4&5R<V]N86P@4')I=F%T92!0
M1U`@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME
M>2YI;F,Z.0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHT"FUS9VED("));7!O<G0@4&5R<V]N86P@4R]-24U%($-E<G1I9FEC871E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C0P
M('1E;7!L871E<R]P9W`O<&=P+FEN8SHT,@IM<V=I9"`B26UP;W)T(%!U8FQI
M8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y
M+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC(%!'4"!+97DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@*;7-G:60@
M(DEM<&]R="!0=6)L:6,@4R]-24U%($ME>2(*;7-G<W1R("(B"@HC.B!S;6EM
M92YP:'`Z,38*;7-G:60@(DEM<&]R="!3+TU)344@2V5Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z.0IM<V=I9"`B26UP
M;W)T(&UB;W@@1FEL92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]I;7!O<G0N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!M
M8F]X(&9I;&4@)7,@:6YT;R!F;VQD97(@)7,N(@IM<V=S='(@(B(*"B,Z(&UE
M<W-A9V4N<&AP.C4P,B!M86EL8F]X+G!H<#HW,S0@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7VYA=FEG871E+FEN8SHW"B,Z('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,38@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS
M,PHC.B!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C<*;7-G:60@(DEM
M<&]R=&%N="(*;7-G<W1R("+3Y^SA[?3IZMPB"@HC.B!T96UP;&%T97,O<V5A
M<F-H+VUA:6XN:6YC.C0W"FUS9VED("));7!O<G1A;G0@;65S<V%G97,B"FUS
M9W-T<B`BT^?LX>WTZ>K<(.SG[?WLX?3A(@H*(SH@9F]L9&5R<RYP:'`Z,38W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"`E9"!M97-S
M86=E<R!F<F]M("5S+B(*;7-G<W1R("+*X>CA\>GS[/SR(/SK^>T@]/GM(.SG
M[?7LW/3Y[2#A\/P@)7,N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C<W,PIM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R("(B"@HC.B!F;VQD97)S
M+G!H<#HS.#0@;&EB+T9O;&1E<BYP:'`Z.#8@;&EB+T9O;&1E<BYP:'`Z,C$T
M(&QI8B])35`N<&AP.C,Q,PHC.B!L:6(O24U!4"]4<F5E+G!H<#HQ,30@;&EB
M+TE-05`O5')E92YP:'`Z,C$Y"FUS9VED("));F)O>"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DR"B,L(&9U>GIY"FUS9VED("))
M;F-L=61E(&$@8G)I968@<W5M;6%R>2!O9B!T:&4@:&5A9&5R(&EN(&$@<F5P
M;'D_(@IM<V=S='(@(L7M\_GLW/3Y\^<@]._U(.'Q]^GJ[_T@[.?M_>SA]._R
M(//TZ?(@X?#A[?3>\^7I\CLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#@W"FUS9VED("));F-L=61E(&]R:6=I;F%L(&UE<W-A9V4@:6X@82!R97!L
M>3\B"FUS9W-T<B`BQ>WS^>S<]/GSYR#T[_4@X?'WZ>KO_2#LY^W][.'T[_(@
M\_3I\B#A\.'M]-[SY>GR.R(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC
M871I;VXN<&AP.C8Q(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C$S,`HC
M+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G<W1R("+0X?'<XNOE^.<B"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA=&EO;B!O;B`E
M<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW-PIM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T
M92!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHV."!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S(*;7-G:60@(DEN9F]R;6%T
M:6]N(&]N(%!E<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O8V]M<&]S92]A
M='1A8VAM96YT<RYJ<SHY.`HC+"!F=7IZ>0IM<V=I9"`B26YL:6YE(@IM<V=S
M='(@(NKA[=WMX2(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN
M8SHY"FUS9VED("));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C$U"FUS9VED("))
M;G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHQ,`IM<V=I9"`B
M26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE<F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O<G1?:V5Y+FEN8SHU"FUS9VED("))
M;G-E<G0@4'5B;&EC(%!'4"!+97D@2&5R92(*;7-G<W1R("(B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO
M;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*"B,Z
M(&UA:6QB;W@N<&AP.C4X-"!M86EL8F]X+G!H<#HV,C8*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@061D<F5S<R(*;7-G<W1R("+$Z>7]Z/7M\^<@P>OKY^OO
MX_'A]M_A\B(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM<V=S='(@(B(*"B,Z(&-O;7!O
M<V4N<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(&-H87)A
M8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N(@IM<V=S='(@(B(*"B,Z('-M
M:6UE+G!H<#HX,B!P9W`N<&AP.C$V"FUS9VED("));G9A;&ED(&ME>2(*;7-G
M<W1R("(B"@HC.B!P9W`N<&AP.C$Y-@IM<V=I9"`B26YV86QI9"!P97)S;VYA
M;"!01U`@<')I=F%T92!K97DN(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3<Q
M"FUS9VED("));G9A;&ED('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R"FUS
M9VED("));G9E<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-3<W"FUS9VED(")+0B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3$S"FUS9VED(")+97D@3&5N9W1H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,S<*;7-G:60@(B(*
M(DME>2!G96YE<F%T:6]N(&UA>2!T86ME(&$@;&]N9R!T:6UE('1O(&-O;7!L
M971E+B`@0V]N=&EN=64@=VET:"!K97D@(@HB9V5N97)A=&EO;C\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHS-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,S<*;7-G:60@(DME>2!I;7!O<G0@:7,@;F]T(&%V
M86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,S<@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C,Y"FUS9VED("(B"B)+97D@
M:6UP;W)T(&ES(&YO="!A=F%I;&%B;&4N(%EO=2!H879E(&YO(&%D9')E<W,@
M8F]O:R!D969I;F5D('1O(&%D9"!Y;W5R("(*(F-O;G1A8W1S+B(*;7-G<W1R
M("(B"@HC.B!P9W`N<&AP.C,Q.`IM<V=I9"`B2V5Y('-U8V-E<W-F=6QL>2!S
M96YT('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(Q-@IM<V=I9"`B3&%N9W5A9V4B
M"FUS9W-T<B`BP^O^\_/A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP
M-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!-86EL8F]X(%!A9V4B"FUS9W-T<B`B
MU.7KY?7TX=_A(-/EZ]_DX2(*"B,Z(&UA:6QB;W@N<&AP.C,U.`IM<V=I9"`B
M3&%S="!086=E(@IM<V=S='(@(M3EZ^7U].'?X2#3Y>O?Y.$B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS.#D*(RP@9G5Z>GD*;7-G:60@
M(DQI7VYK($%T=&%C:&UE;G1S(@IM<V=S='(@(M/U[>?L[-WMX2(*"B,Z(&%T
M=&%C:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H<#HQ,#8S"FUS9VED("),
M:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T-O;7!O<V4N<&AP.C$P.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&EN:W,@=VEL;"!E>'!I<F4@;VX@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P.#(*;7-G:60@(B(*(DQI<W0@86QL(&-O;G1A
M8W1S('=H96X@;&]A9&EN9R!T:&4@8V]N=&%C=',@<V-R965N/R`H:68@9&ES
M86)L960L('EO=2!W:6QL("(*(F]N;'D@<V5E(&-O;G1A8W1S('1H870@>6]U
M('-E87)C:"!F;W(@97AP;&EC:71L>2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8X-0IM<V=I9"`B3&ES=&EN9R!I;B!T:&4@2&5A
M9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E
M+FEN8SHS,`HC+"!F=7IZ>0IM<V=I9"`B3&]C86P@36%I;&)O>#HB"FUS9W-T
M<B`BP_'A[.SA]._JZ>+^].GO(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C8W-`HC+"!F=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BQ/'<
M\^<B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R-0IM<V=I9"`B
M3&]G(&EN(@IM<V=S='(@(L7?\^_D[_(B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*
M;7-G<W1R("+%W_/OY._R(//T[R`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3,W"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("+%
MW_/OY._R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED("),
M;V=I;B!487-K<R(*;7-G<W1R("+%[=WQX^7IY?(@\._U(.7J].7K[_WM].'I
M(.KA]-P@].?M(.7?\^_D[R(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C(Y-@IM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z(&UE<W-A9V4N
M<&AP.C(Y.2!M86EL8F]X+G!H<#HW,C<@=&5M<&QA=&5S+VUA:6QB;W@O;&5G
M96YD+FEN8SHQ,PIM<V=I9"`B3&]W(%!R:6]R:71Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y-PIM<V=I9"`B3&]W
M97-T(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]A<'!L961O=6)L
M92YP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@(DUA8VEN=&]S:"!&:6QE(@IM<V=S
M='(@(M;?Z_3QX2#,Y^WU[-ST^>TB"@HC.B!T96UP;&%T97,O<VUI;64O<&%S
M<W!H<F%S92YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(DUA:6PB"FUS9W-T<B`B
MP_'A[.SA]._JZ>+^].GO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M"B,L(&9U>GIY"FUS9VED(")-86EL(%!R979I97=S(@IM<V=S='(@(M;?Z_3Q
MX2#,Y^WU[-ST^>TB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S
M96QE8W0N:6YC.C$V"FUS9VED(")-86EL('-E<G9E<B!T>7!E('1O(&-O;FYE
M8W0@=&\Z(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B
M36%I;&)O>"(*;7-G<W1R("+#\>'L[.'T[^KIXO[TZ>\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$Q"B,L(&9U>GIY"FUS9VED(")-86EL8F]X(&%N
M9"!&;VQD97(@1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(L7PZ>OOX]WR(,7L
M]MSMZ?/G\B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$X
M"FUS9VED(")-87)K($%L;"!-97-S86=E<R!I;B!&;VQD97(@87,@4V5E;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ
M.0IM<V=I9"`B36%R:R!!;&P@365S<V%G97,@:6X@1F]L9&5R(&%S(%5N<V5E
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V
M:6=A=&4N:6YC.C4@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,`IM
M<V=I9"`B36%R:R!A<SHB"FUS9W-T<B`BU^'QX>KTY_'I\^S\\B#Y\CHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4P"FUS9VED(")-87)K(&1I9F9E
M<F5N="!L979E;',@;V8@<75O=&EN9R!W:71H(&1I9F9E<F5N="!C;VQO<G,_
M(@IM<V=S='(@(LWA(.7L]N'MW^;O[?3AZ2#OZ2#A\.'M]-[SY>GR(.SE(.3I
MX?;O\>7TZ>K<(/?Q_NSA].$[(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M
M86YA9V4N:6YC.C0P"FUS9VED(")-87)K(&UE<W-A9V5S(&%S('-E96X_("A)
M34%0(&]N;'DI(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-3@*;7-G:60@(DUA<FL@<VEM<&QE(&UA<FMU<#\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C0V"FUS9VED(")-871C
M:"!!;&P@475E<FEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VAE861E<BYI;F,Z-#(*;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,3,*(RP@
M9G5Z>GD*;7-G:60@(DUA>&EM=6T@071T86-H;65N="!3:7IE(@IM<V=S='(@
M(M/U[>?L[-WM[R(*"B,Z(&QI8B]A<&DN<&AP.C<Y"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!&;VQD97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0Y-`IM<V=I9"`B36%X:6UU;2!N=6UB97(@
M;V8@871T86-H;65N=',@<F5A8VAE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@Y"FUS9VED(")-87AI;75M('1O
M=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(V"FUS9VED(")-965T:6YG($-A
M;F-E;&QA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-3<U"B,L(&9U>GIY"FUS9VED(")-965T:6YG($EN9F]R;6%T:6]N
M(@IM<V=S='(@(M#KY_'O]N_QW^7R(,3IX>KO[.GS]-XB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3@U"FUS9VED(")-965T:6YG(%!R;W!O<V%L
M(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV,3<*
M;7-G:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B365E=&EN9R!5
M<&1A=&4B"FUS9W-T<B`BP?'WW^;O[?3A\B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,#,*;7-G:60@(DUE971I;F<@57!D871E(%)E<75E<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP:'`Z,PHC
M+"!F=7IZ>0IM<V=I9"`B365N=2!&;VQD97(@3&ES="(*;7-G<W1R("+![>_I
MX^SA(-;AZMWK[_4B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S,Q"FUS9VED(")-
M97-S86=E(@IM<V=S='(@(LS>[?7LX2(*"B,Z(&-O;7!O<V4N<&AP.C4V,"!C
M;VUP;W-E+G!H<#HU.#<@8V]M<&]S92YP:'`Z-C0Q(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,`IM<V=I9"`B365S<V%G92!#;VUP;W-I=&EO;B(*;7-G<W1R
M("+3_>WHY?/G(,SG[?WLX?3O\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,3<*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G<W1R("+'[.7Q[^SG[=_A
M(,SG[?WLX?3O\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.34@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,PHC+"!F=7IZ>0IM
M<V=I9"`B365S<V%G92!/<'1I;VYS(@IM<V=S='(@(O#Q[_(B"@HC.B!S96%R
M8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G92!396%R8V@B"FUS9W-T<B`BP>WA
MYM[TY_/G(,SG[?7LW/3Y[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,C$*;7-G:60@(DUE<W-A9V4@4VEZ92(*;7-G<W1R("+,W>/EZ._R(,SG[?WL
MX?3O\B(*"B,Z(&UE<W-A9V4N<&AP.C,X-`IM<V=I9"`B365S<V%G92!3;W5R
M8V4B"FUS9W-T<B`BT.?CX=_O\B#*_N3IZN'R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8V"FUS9VED(")-97-S86=E(%9I97=I;F<B"FUS9W-T<B`B
MT/'OXN_KWB#,Y^W][.'T[_(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`BP>WAYM[TY_/G
M(//][/;Y[>$@[.4@].<@\][LX>WSYR#T[_4@[.?M_>SA]._R(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX,PIM<V=I9"`B365S<V%G92!F;VQD
M97)S(@IM<V=S='(@(L'MX>;>].?SYR#S]._U\B#VX>K=Z^_U\B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DUE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("+![>'FWO3G\^<@\_3O]?(@]N'J
MW>OO]?(B"@HC.B!M86EL8F]X+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@:&%S(&%T=&%C:&UE;G1S(@IM<V=S='(@(L3IX>/QX?;>(//U[>?L
M[-WM[_4N(@H*(SH@;6%I;&)O>"YP:'`Z-C4X"B,L(&9U>GIY"FUS9VED(")-
M97-S86=E(&ES(&5N8W)Y<'1E9"(*;7-G<W1R("+![>'FWO3G\^<@\_3A(/#E
MY-_A(/3O]2#LY^W][.'T[_(B"@HC.B!M86EL8F]X+G!H<#HV-3,*(RP@9G5Z
M>GD*;7-G:60@(DUE<W-A9V4@:7,@<VEG;F5D(@IM<V=S='(@(L'MX>;>].?S
MYR#S].$@\.7DW^$@]._U(.SG[?WLX?3O\B(*"B,Z('1E;7!L871E<R]S96%R
M8V@O:&5A9&5R+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!M871C
M:&5S(@IM<V=S='(@(L?LY?'O[.?MW^$@S.?M_>SA]._R(@H*(SH@8V]M<&]S
M92YP:'`Z.#(T(&-O;7!O<V4N<&AP.C@S.`HC+"!F=7IZ>0IM<V=I9"`B365S
M<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@HBU.\@
MS-[M]>SA(//TW.OHY^KE(.7PZ?3U]_[R+"#DY>T@X?#OZ.?JY?WTY^KE(.'M
M]-_C\>'V_"#T[_4@\_3O[2#JX?3<Z^_C[R`B"@HC.B!C;VUP;W-E+G!H<#HQ
M,#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@
M<W5C8V5S<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@(B(*
M(M3O(,S>[?7LX2#S]-SKZ.?JY2#E\.GT]??^\BP@Y.7M(.'P[^CGZN7]].?J
MY2#A[?3?X_'A]OP@]._U(//T[^T@ZN'TW.OOX^\@(@H*(SH@8V]M<&]S92YP
M:'`Z,3$T,R!C;VUP;W-E+G!H<#HQ,34X"B,L(&9U>GIY"FUS9VED(")-97-S
M86=E('-E;G0@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"B+4[R#,WNWU[.$@
M\_3<Z^CGZN4@Y?#I]/7W_O(L(.3E[2#A\._HY^KE_?3GZN4@X>WTW^/QX?;\
M(/3O]2#S]._M(.KA]-SK[^/O("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-#$*;7-G:60@(DUE<W-A9V5S('!E<B!P86=E(&EN('1H92!M86EL8F]X
M('9I97<N(@IM<V=S='(@(LSG[?WLX?3A(.'MW"#SY>O?Y.$@\_3G[2#P\>_B
M[^O>(/3O]2##\>'L[.'T[^KIXO[TZ>_U+B(*"B,Z(&UA:6QB;W@N<&AP.C,R
M,@IM<V=I9"`B365S<V%G97,@=&\B"FUS9W-T<B`B\/'O\B(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHR.0IM<V=I9"`B36]D:69Y(@IM<V=S='(@(M3Q
M[_#O\._?Y_/G(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O97AP86YD+FEN8SHQ
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E('1H86X@;VYE(&%D9')E<W,@
M9F]U;F0@9F]R(&9I96QD(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ."!T96UP;&%T97,O
M;6%I;&)O>"]N879B87(N:6YC.C4P"FUS9VED(")-;W9E(@IM<V=S='(@(LSE
M].'V[_'<(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S$V"B,L(&9U>GIY"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`BS.7TX>K?
M[>?SYR#0\>_R(/3A(,K<]/DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C$X"FUS9VED(")-;W9E('-P86T@;65S<V%G97,@=&\@<W!A;2!F;VQD97(@
M86YD(&EN;F]C96YT(&UE<W-A9V5S('1O($E.0D]8(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3@@=&5M
M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`HC+"!F=7IZ>0IM<V=I9"`B
M36]V92!T;R!F;VQD97(B"FUS9W-T<B`BY?#IZ]WN].4@]MSJY>OO(@H*(SH@
M=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S$T"B,L(&9U>GIY
M"FUS9VED(")-;W9E('5P(@IM<V=S='(@(LSE].'JW^WG\^<@T/'O\B#TX2#%
M\-SM^2(*"B,Z(&QI8B]-24U%+U9I97=E<B]A;'1E<FYA=&EV92YP:'`Z,3(W
M"FUS9VED(")-=6QT:7!A<G0O86QT97)N871I=F4B"FUS9W-T<B`B(@H*(SH@
M=&AR96%D+G!H<#HW-B!T:')E860N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B
M375L=&EP;&4@365S<V%G92!6:65W(@IM<V=S='(@(M#Q[^+OZ]X@S.?M_>SA
M]._R(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N
M:6YC.C4*;7-G:60@(DY/3D4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C0X('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,@IM<V=I9"`B3D]412(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC
M.C(S."!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(").86UE
M(@IM<V=S='(@(KSM[^SA(@H*(SH@<&=P+G!H<#HQ,3`*;7-G:60@(DYA;64@
M86YD+V]R(&5M86EL(&-A;B!N;W0@8F4@96UP='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<W.`HC+"!F=7IZ>0IM<V=I9"`B
M3F5E9',@06-T:6]N(@IM<V=S='(@(L3QW//G(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4W,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3@R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-S@*;7-G:60@(DYE=F5R(@IM<V=S='(@
M(M#O]-TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-38P"B,L(&9U>GIY
M"FUS9VED(").979E<B!S879E(&%T=&%C:&UE;G1S(@IM<V=S='(@(L3IX>/Q
MX?;>(//U[>?L[-WM[_4N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$R
M-`IM<V=I9"`B3F5W(@IM<V=S='(@(LW=X2(*"B,Z(&QI8B])35`N<&AP.C4V
M,PIM<V=I9"`B3F5W($9O;&1E<B(*;7-G<W1R("+%Z?/AX_GCWB#6X>K=Z^_U
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@X"FUS9VED(").97<@36%I
M;"(*;7-G<W1R("+-W>\@S-[M]>SA(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C$Y(&QI8B]";&]C:R]T<F5E7V9O;&1E<G,N<&AP.C,S"B,L(&9U>GIY
M"FUS9VED(").97<@365S<V%G92(*;7-G<W1R("+%\/SLY>WO(,S>[?7LX2(*
M"B,Z(&UA:6QB;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ.3(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S
M(@IM<V=S='(@(LW=X2#LY^W][.'TX2(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z,3D*;7-G:60@(DYE=R!M97-S86=E<R(*;7-G<W1R("+-W>$@
M[.?M_>SA].$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z
M,3,S"FUS9VED(").97AT(@IM<V=S='(@(L7P_.SE[>\B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C,S"FUS9VED(").97AT
M($UE<W-A9V4B"FUS9W-T<B`BQ?#\[.7M[R#,WNWU[.$B"@HC.B!M86EL8F]X
M+G!H<#HS-38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R("+%\/SLY>WG(-/E
MZ]_DX2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4T,B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<W"FUS9VED(").;R(*;7-G<W1R("*\
M]^DB"@HC.B!S;6EM92YP:'`Z,C(V"FUS9VED(").;R!#97)T:69I8V%T92!F
M;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T
M7VQI<W0N:6YC.C4*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$Y"FUS9VED(").;R!+97ES(&EN
M($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@;6%I;&)O>"YP:'`Z,S<U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!-97-S86=E<R(*;7-G<W1R("+-
MW>$@[.?M_>SA].$B"@HC.B!P9W`N<&AP.C$S-PIM<V=I9"`B3F\@4$=0('!U
M8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z.#0*;7-G:60@(DYO(%!E<G-O;F%L($-E<G1I9FEC
M871E(%!R97-E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,R
M.0HC+"!F=7IZ>0IM<V=I9"`B3F\@4')E=FEE=R!497AT(@IM<V=S='(@(L3I
M[_'H^>S=[>\@RN7?[.7M[R(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z,34*;7-G:60@(DYO(%!U8FQI8R!+97ES($9O=6YD(@IM<V=S='(@(B(*
M"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L:6,@:V5Y
M(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O=&YE
M9BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DYO(&%T=&%C:&UE;G1S(&9O=6YD
M+B(*;7-G<W1R("+3]>WG[.S=[>$B"@HC.B!L:6(O0W)Y<'0O4TU)344N<&AP
M.C$T,`IM<V=I9"`B3F\@96UA:6P@:6YF;W)M871I;VX@;&]C871E9"!I;B!T
M:&4@<'5B;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@86-L+G!H<#HW,B!A8VPN
M<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97(@<V5L96-T960N(@IM
M<V=S='(@(N3E[2#=]^7I(.7PZ>OE]_3EWR#VW.KEZ^_R(@H*(SH@;&EB+T)L
M;V-K+W-U;6UA<GDN<&AP.C$T,0IM<V=I9"`B3F\@9F]L9&5R<R!A<F4@8F5I
M;F<@8VAE8VME9"!F;W(@;F5W(&UA:6PN(@IM<V=S='(@(B(*"B,Z(&9O;&1E
M<G,N<&AP.C(Q."!L:6(O1F]L9&5R+G!H<#HU,#`@;&EB+T9O;&1E<BYP:'`Z
M-34P"FUS9VED(").;R!F;VQD97)S('=E<F4@<W!E8VEF:65D(@IM<V=S='(@
M(L3E[2#=]^_U[2#O\>GS].7?(/;<ZN7K[^DB"@HC.B!L:6(O0FQO8VLO<W5M
M;6%R>2YP:'`Z,30W"B,L(&9U>GIY"FUS9VED(").;R!F;VQD97)S('=I=&@@
M;F5W(&UE<W-A9V5S(@IM<V=S='(@(LSG(,3IX>/QX>SLW>WA(.SG[?WLX?3A
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C$T-`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M97-S86=E<R(*;7-G<W1R("+,
MYR#$Z>'C\>'L[-WMX2#LY^W][.'TX2(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HS
M,C4*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@8F]D>2!T97AT(@IM<V=S
M='(@(NSE].'JW^WG\^<@]._U(.SG[?WLX?3O\B#S]._M(@H*(SH@;&EB+TUA
M:6QB;W@N<&AP.C,W,0HC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G97,@;6%T
M8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`BQ.7M(.+QW>CGZN'M(.SG[?WL
MX?3A(/#O]2#MX2#TX>GQZ=SF[_7M(//TX2#J\>GTWO'IX2#SX?(B"@HC.B!P
M9W`N<&AP.C$X.0IM<V=I9"`B3F\@<&5R<V]N86P@4$=0('!R:79A=&4@:V5Y
M(&EM<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$V-0IM<V=I9"`B
M3F\@<&5R<V]N86P@4$=0('!U8FQI8R!K97D@:6UP;W)T960N(@IM<V=S='(@
M(B(*"B,Z('-M:6UE+G!H<#HR,#$*;7-G:60@(DYO('!E<G-O;F%L(%,O34E-
M12!C97)T:69I8V%T97,@:6UP;W)T960N(@IM<V=S='(@(B(*"B,Z('-P96QL
M:6YG+G!H<#HR,C`*;7-G:60@(DYO('-P96QL8VAE8VMI;F<@<')O9W)A;2!C
M;VYF:6=U<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z-#@*;7-G:60@(DYO('-P96QL:6YG(&5R<F]R<R(*;7-G
M<W1R("+$Y>T@]?#<\??O]>T@[_'H[^/QX?;IZMP@Z]SHYR(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,#`*;7-G:60@(DYO('-U9V=E
M<W1I;VYS(@IM<V=S='(@(L3E[2#U\-SQ]^_U[2#0\>_TW//EZ?(B"@HC.B!L
M:6(O24U!4"]#;&EE;G0N<&AP.C4V-`IM<V=I9"`B3F\@<W5P<&]R=&5D($E-
M05`@875T:&5N=&EC871I;VX@;65T:&]D(&-O=6QD(&)E(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!A8VPN<&AP.C8X(&%C;"YP:'`Z.30*(RP@9G5Z>GD*;7-G
M:60@(DYO('5S97(@<W!E8VEF:65D+B(*;7-G<W1R("+$Y>T@W??O]>T@[_'I
M\_3EWR#VW.KEZ^_I(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<P
M.0IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,3$@=&5M<&QA=&5S+W!R969S+W-E
M;G1M86EL<V5L96-T+FEN8SHT,`HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS-2!T96UP;&%T97,O<')E9G,O<W!A;7-E;&5C="YI;F,Z
M,C0*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8V-`IM<V=I9"`B3F]N
M92(*;7-G<W1R("+*X>W=[>$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHR.34*;7-G:60@(DYO<FUA;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X
M+VYA=F)A<BYI;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S='(@(LSG
M(,3IX>/QX>SLW>WA(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA
M=FEG871E+FEN8SHQ,B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(S
M"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-#(*;7-G:60@(DYO
M="!$<F%F="(*;7-G<W1R("+,YR#0\?SWY>GQX2(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I;&)O
M>"]N879B87(N:6YC.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,S0*;7-G:60@(DYO="!);7!O<G1A;G0B"FUS9W-T<B`BS.<@\^?LX>WT
MZ>K<(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-0IM<V=I
M9"`B3F]T(%!E<G-O;F%L(@IM<V=S='(@(LSG(/#Q[_/Y\.GJW"(*"B,Z(&QI
M8B]#<GEP="]01U`N<&AP.C$S.2!L:6(O0W)Y<'0O4TU)344N<&AP.C$S-"!L
M:6(O0W)Y<'0O4TU)344N<&AP.C$T.0IM<V=I9"`B3F]T(&$@=F%L:60@<'5B
M;&EC(&ME>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHV-PIM<V=I9"`B3F]T(&1E;&5T960@;65S<V%G97,B"FUS9W-T<B`B
MS.<@Q.GAX_'A[.S=[>$@[.?M_>SA].$B"@HC.B!T96UP;&%T97,O<V5A<F-H
M+VUA:6XN:6YC.C4Q"FUS9VED(").;W0@:6UP;W)T86YT(&UE<W-A9V5S(@IM
M<V=S='(@(LSG(//G[.'M].GJW"#LY^W][.'TX2(*"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+V9E=&-H;6%I;%]L;V=I;BYP:'`Z-S$*;7-G:60@(DYO=&4@
M=&AA="!T:&ES(&-A;B!T86ME('-O;64@=&EM92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$V"B,L(&9U>GIY"FUS9VED(").;W1H
M:6YG(@IM<V=S='(@(L'Q]^GJ_"#LWNWU[.$@X?#\("(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S<*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!M
M;VYT:',@=&\@:V5E<"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&EF(&1E;&5T
M:6YG(&UO;G1H;'DN(@IM<V=S='(@(L'QZ>CL_/(@]N'JW>OY[2#!T,73U,'+
MS,7-P2#P[_4@Y.7M(.CA(.3IX>/QW/;O[?3AZ2#A[=P@[-[MX2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"FUS9VED(").=6UB97(@;V8@;VQD
M('-E;G0M;6%I;"!F;VQD97)S('1O(&ME97`@:68@9&5L971I;F<@;6]N=&AL
M>2XB"FUS9W-T<B`BP?'IZ.S\\B#VX>K=Z_GM(,'0Q=/4P<O,Q<W!(/#O]2#D
MY>T@Z.$@Y.GAX_'<]N_M].'I(.'MW"#LWNWA+B(*"B,Z('1E;7!L871E<R]C
M;VYT86-T<R]C;VYT86-T<RYI;F,Z,C4T(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HU-3(*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<S,PIM<V=I
M9"`B3TLB"FUS9W-T<B`BQ>WTW.[EZ2(*"B,Z('1E;7!L871E<R]S96%R8V@O
M9FEE;&1S+FEN8SHU('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHT
M.0HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C0X"FUS9VED(")/
M4B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$U
M"FUS9VED(")/;&0@;65S<V%G97,B"FUS9W-T<B`BT.'KZ=P@S.?M_>SA].$B
M"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N
M=&AL>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN
M9R!P=7)G960N(@IM<V=S='(@(M#AZ^GOWR#6W.KEZ^_I(.SE(.'PY?/TX>OL
MW>WA(/#O]2#DZ>'C\=SV[^WTX>DN(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN
M<&AP.C(U"FUS9VED(")/;FQY(&1I<W!L87D@9F]L9&5R<R!W:71H('5N<F5A
M9"!M97-S86=E<R!I;B!T:&5M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"B,L(&9U>GIY"FUS9VED(")/;FQY
M(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO
M;BXB"FUS9W-T<B`BT.'QX>KAZ_X@Y?#IZ]WN].4@[/SM[R#=[>$@]MSJY>OO
M(./IX2#A]?3>[2#TY^T@Z^7I]._U\>/?X2XB"@HC.B!T96UP;&%T97,O;65N
M=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY"FUS9VED
M(")/<&5N($9O7VQD97(B"FUS9W-T<B`BP>WOZ>/LX2#6X>K=Z^_U(@H*(SH@
M9F]L9&5R<RYP:'`Z-#(W"B,L(&9U>GIY"FUS9VED(")/<&5N960@1F]L9&5R
M(@IM<V=S='(@(L'M[^GC[.$@UN'JW>OO]2(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HW,#4*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM
M<V=S='(@(B(*"B,Z(&9E=&-H;6%I;"YP:'`Z,S,@=&5M<&QA=&5S+V9E=&-H
M;6%I;"]T;W`N:6YC.C,*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]F971C:&UA
M:6PN:6YC.C8*(RP@9G5Z>GD*;7-G:60@(D]T:&5R($UA:6P@06-C;W5N=',B
M"FUS9W-T<B`BP>OKY?(@Q?#IZ^_CW?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3D*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U,`IM<V=I9"`B3W1H97(@3W!T:6]N<R(*;7-G<W1R("+!Z^OE
M\B#%\.GK[^/=\B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`Q
M"FUS9VED(")/=71B;W5N9"!397)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ-B!L:6(O34E-12]6:65W97(O<&=P
M+G!H<#HQ-C4*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`T(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C(Y,`IM<V=I9"`B4$=0(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z-PHC+"!F
M=7IZ>0IM<V=I9"`B4$=0($5N8W)Y<'0@365S<V%G92(*;7-G<W1R("+!ZOWQ
M^?/G(,SG[?WLX?3O\B(*"B,Z(&-O;7!O<V4N<&AP.C,U.`HC+"!F=7IZ>0IM
M<V=I9"`B4$=0($5R<F]R.B`B"FUS9W-T<B`BR]SH[_(B"@HC.B!C;VUP;W-E
M+G!H<#HS,S<*;7-G:60@(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O
M<B!P97)S;VYA;"!P<FEV871E(&ME>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,@HC+"!F=7IZ>0IM<V=I9"`B4$=0($]P=&EO
M;G,B"FUS9W-T<B`BQ?#IZ^_CW?(B"@HC.B!P9W`N<&AP.C,P"FUS9VED(")0
M1U`@4&%S<W!H<F%S92!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&=P+W!G<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA;"!+97EP86ER('-U
M<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PIM<V=I9"`B
M4$=0(%!U8FQI8R!+97D@5&5X="(*;7-G<W1R("(B"@HC.B!P9W`N<&AP.C$T
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4$=0(%!U8FQI8R!+97D@
M9F]R(%PB)7,@*"5S*5PB('=A<R!S=6-C97-S9G5L;'D@861D960N(@IM<V=S
M='(@(L\@]MSJY>OO\B!<(B5S7"(@Y.?LZ>_U\>/>Z.?JY2#LY2#E\.GT]???
MX2XB"@HC.B!P9W`N<&AP.C(T-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY
M(&1E;&5T960N(@IM<V=S='(@(L\@]MSJY>OO\B!<(B5S7"(@Y.GAX_'<]N?J
MY2#LY2#E\.GT]???X2XB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y<FEN9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*(RP@9G5Z>GD*;7-G
M:60@(E!'4"!3:6=N($UE<W-A9V4B"FUS9W-T<B`BP?#O\_3OZ]X@S.?M_>SA
M]._R(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC<GEP=%]L:7-T+FEN8SHY
M"FUS9VED(")01U`@4VEG;B]%;F-R>7!T($UE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@<&=P+G!H<#HR,#(*(RP@9G5Z>GD*;7-G:60@(E!'4"!P<FEV871E(&ME
M>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S='(@(L<@]?#OX_'A]MX@X>WT
MZ>KA].'S]-SHY^KE(.SE(.7PZ?3U]]_A+B(*"B,Z('!G<"YP:'`Z,3<W"FUS
M9VED(")01U`@<'5B;&EC(&ME>2!S=6-C97-S9G5L;'D@861D960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHT"FUS9VED
M(")01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`X"FUS9VED
M("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T
M:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E("(*(G9E<FEF
M:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M.34*;7-G:60@(B(*(E!'4"!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@86-T
M:79E('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92!D96-R>7!T960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHR"FUS9VED
M("(B"B)01U`@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E
M('5S960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY("(*(G-E="!T
M;R!D:7-A8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES
M('-E='1I;F<@;W(@96QS92!T:&4@4$=0("(*(F9E871U<F5S('=I;&P@;F]T
M('=O<FL@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL
M+VEM87`N<&AP.C$P-0IM<V=I9"`B4$]0,R(*;7-G<W1R("(B"@HC.B!L:6(O
M1F5T8VAM86EL+VEM87`N<&AP.C$P,`IM<V=I9"`B4$]0,R`H075T;R!$971E
M8W0@4')O=&]C;VQS*2(*;7-G<W1R("(B"@HC.B!L:6(O1F5T8VAM86EL+VEM
M87`N<&AP.C$Q-PIM<V=I9"`B4$]0,R!O=F5R(%-33"(*;7-G<W1R("(B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$R,PIM<V=I9"`B4$]0,R!O=F5R
M(%-33"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38Y"FUS9VED(")03U`S(&]V
M97(@4U-,("AS96QF+7-I9VYE9"DB"FUS9W-T<B`B(@H*(SH@;&EB+T9E=&-H
M;6%I;"]I;6%P+G!H<#HQ,3$*;7-G:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`BT^7KW^3A
M("5D(.'P_"`E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#,*;7-G
M:60@(E!A9V4@=VET:"!T:&4@1FER<W0@56YS965N($UE<W-A9V4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-`IM<V=I9"`B4&%G
M92!W:71H('1H92!,87-T(%5N<V5E;B!-97-S86=E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC.C0S"FUS9VED(")087)T
M*',I(@IM<V=S='(@(LS=\>_R*.<I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$R,PIM<V=I9"`B4&%S<W!H<F%S92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,3(X"FUS9VED(")087-S<&AR87-E("A!9V%I
M;BDB"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(S-2!P9W`N<&AP.C,Q,`HC
M+"!F=7IZ>0IM<V=I9"`B4&%S<W!H<F%S92!S=6-C97-S9G5L;'D@=6YL;V%D
M960N(@IM<V=S='(@(B(*(M3O(,S>[?7LX2#S]-SKZ.?JY2#E\.GT]??^\BP@
MY.7M(.'P[^CGZN7]].?JY2#A[?3?X_'A]OP@]._U(//T[^T@ZN'TW.OOX^\@
M(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W!A<W-P:')A<V4N:6YC.C$X('1E;7!L
M871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,CD*;7-G:60@(E!A<W-P:')A<V4Z
M(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$R"FUS9VED(")087-S<&AR87-E
M<R!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3$T
M"FUS9VED(")087-S<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C(P('1E;7!L871E
M<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW,0HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$Y,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`BROGDZ>K\
M\B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHT.`IM<V=I
M9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*
M;7-G<W1R("+-X2#EZO3EZ^_][?3AZ2#KY>GT[_7QX]_E\B#S]>WTWO'G\^?R
M(.KA]-P@].?M(.7?\^_D[R#S].?M(/7PY_'E\]_A.R(*"B,Z(&%C;"YP:'`Z
M-S8@86-L+G!H<#HQ,#(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B!T:&ES('5S
M97(@8V%N(&YO="!B92!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!M97-S86=E
M+G!H<#HT.3,@;6%I;&)O>"YP:'`Z-S`S('1E;7!L871E<R]M86EL8F]X+VYA
M=F)A<BYI;F,Z,C0*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ
M,`IM<V=I9"`B4&5R<V]N86PB"FUS9W-T<B`BT/'O\_GPZ>K<(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T"FUS9VED(")097)S;VYA;"!);F9O<FUA
M=&EO;B(*;7-G<W1R("+0\>_S^?#IZMWR(-#KY_'O]N_QW^7R(@H*(SH@<&=P
M+G!H<#HQ,C`*;7-G:60@(E!E<G-O;F%L(%!'4"!K97EP86ER(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z('!G<"YP:'`Z,3(W"FUS
M9VED(")097)S;VYA;"!01U`@:V5Y<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@<VUI;64N<&AP.C(P-PIM<V=I9"`B4&5R<V]N86P@
M4R]-24U%(&-E<G1I9FEC871E<R!.3U0@:6UP;W)T960Z("(*;7-G<W1R("(B
M"@HC.B!S;6EM92YP:'`Z,3,R"FUS9VED(")097)S;VYA;"!3+TU)344@:V5Y
M<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B4&QA8V4@>6]U<B!S:6=N871U
M<F4@8F5F;W)E(')E<&QI97,@86YD(&9O<G=A<F1S/R(*;7-G<W1R("(B"B+-
MX2#T[_#OZ.7TY=_TX>D@YR#U\._C\>'VWB#SX?(@\/'I[2#A\/P@].GR(.'P
MX>WTWO/EZ?(@ZN'I(/3I\B#P\>_YZ-[SY>GR("(*(O3Y[2#LY^WU[-ST^>T@
M\^'R.R(*"B,Z(&-O;7!O<V4N<&AP.C(U-`IM<V=I9"`B4&QA:6YT97AT(%9E
M<G-I;VX@;V8@365S<V%G92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-SDY"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M86EL
M/R`@5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E
M9&1E9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W
M<R!A;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q=6ER
M92!A('!L=6=I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M:F%V87-C<FEP="YI;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,3DR"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&9O;&1E<CHB"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@W>WA(/SM[^SA
M(./IX2#T[^T@[=WO(/;<ZN7K[SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$P,B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S
M+FIS.C$P-`IM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N86UE(&]F('1H92!N
M97<@9F]L9&5R.B(*;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#T[R#\[>_LX2#T
M[_4@[=WO]2#VX>K=Z^_U.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O
M;&1E<G,N:G,Z,3,W"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YE=R!N86UE
M.B(*;7-G<W1R("+0X?'AZN'K_B#EZ?/<X^7TY2#T[R#MW>\@_.WO[.$Z(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHQ.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R
M('EO=7(@4$=0('!R:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@
M(@HB96YT97(@=&AI<R!P87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN
M8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT97(@=&AE
M('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y+B!9;W4@
M=VEL;"!O;FQY(&YE960@(@HB=&\@96YT97(@=&AI<R!P87-S<&AR87-E(&]N
M8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z(')E8V]M<&]S92YP
M:'`Z.3<*;7-G:60@(B(*(E!L96%S92!L;V<@:6X@86=A:6X@=&\@<F5S=6UE
M(&-O;7!O<VEN9R!Y;W5R(&UE<W-A9V4N($EF('EO=2!A<F4@3D]4('5S:6YG
M("(*(F-O;VMI97,@04Y$('EO=2!A<F4@8V]M<&]S:6YG(&UE<W-A9V5S(&EN
M('!O<'5P('=I;F1O=W,L('EO=2!W:6QL(&AA=F4@=&\@(@HB;&]G(&EN(&%G
M86EN(&EN('EO=7(@;6%I;B!W:6YD;W<@87,@=V5L;"X@5&AI<R!I<R!T;R!K
M965P(&%T=&%C:V5R<R!F<F]M("(*(FAI:F%C:VEN9R!Y;W5R('-E<W-I;VX@
M240N(%=E(&%P;VQO9VEZ92!F;W(@86YY(&EN8V]N=F5N:65N8V4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S$*(RP@9G5Z
M>GD*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N(@IM<V=S
M='(@(M#A\>'JX>O^(.3^\_3E(/3O(/SM[^SA(/?QWO/TYR#JX>D@]._M(.KY
MY.GJ_"#SX?(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8W"B,L
M(&9U>GIY"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE+B(*
M;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#T[R#\[>_LX2#W\=[S].<@ZN'I(/3O
M[2#J^>3IZOP@\^'R(@H*(SH@8V]M<&]S92YP:'`Z,3`V(&QI8B])35`N<&AP
M.C0U.0IM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L
M:60@861D<F5S<V5S+B(*;7-G<W1R("+0X?'AZN'K_B#DZ>_QZ/[S].4@].?M
M(.3IY?WH]>WSYRP@Y=_MX>D@\.GHX>W\].'TX2#KX>WHX?/LW>WG+B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*(E!L96%S
M92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@
M<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C8Q
M"FUS9VED(")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R
M9F]R;2!A;GD@86-T:6]N<RXB"FUS9W-T<B`BT.'QX>KAZ_X@Y?#IZ]WNY?3E
M(-WMX2#VW.KEZ^\@\/'I[2#JW.WE].4@[_#OZ>'DWO#O].4@Y>W=\>/EZ>$N
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4P,@HC+"!F=7IZ>0IM
M<V=I9"`B4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B
M96QO=RXB"FUS9W-T<B`BT.'QX>KAZ_X@Y?#IZ]WNY?3E(/3O]>O<]^GS]._M
M(-WMX2#JX?3<Z^_C[R#CZ>$@X>WAYM[TY_/G+B(*"B,Z('1E;7!L871E<R]S
M96%R8V@O:F%V87-C<FEP="YI;F,Z-#$*;7-G:60@(E!L96%S92!S96QE8W0@
M870@;&5A<W0@;VYE(&9O;&1E<B!T;R!S96%R8V@N(@IM<V=S='(@(M#A\>'J
MX>O^(.7PZ>O=[N7TY2#T[_7KW/?I\_3O[2#=[>$@ZN'TW.OOX^\@X^GA(.'M
MX>;>].?SYRXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$R"FUS9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E<B!F;W(@
M=&AI<R!O<&5R871I;VXN(@IM<V=S='(@(M#A\>'JX>O^(.7PZ>O=[O3E(.S\
M[>\@W>WA(/;<ZN7K[R#CZ>$@X?7TWNT@].?M(.OEZ?3O]?'CW^$N(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC.C<S"B,L(&9U>GIY"FUS
M9VED(")0;&5A<V4@<V5L96-T(&]R(&5D:70@:6X@=&AE(&)O>"!T;R!T:&4@
M<FEG:'0Z(@IM<V=S='(@(M#A\>'JX>O^(.7PZ>O=[O3E(-X@Y?#E[N7QX^'S
M].7?].4@].\@X>S=\_GR(.7P_.SE[>\Z(@H*(SH@8V]N9FEG+VUO=&0N<&AP
M+F1I<W0Z-#$*;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-`HC+"!F=7IZ>0IM<V=I9"`B
M4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*
M;7-G<W1R("+-X2#T[_#OZ.7T[_WM].'I(/#A_>OE\B#P\>GM(/3G[2#U\._C
M\>'VWB#SX?(H)RTM("<I(@H*(SH@<VUI;64N<&AP.C(T,2!P9W`N<&AP.C(U
M-R!F:6QT97)P<F5F<RYP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!R969E<F5N
M8V5S('-U8V-E<W-F=6QL>2!U<&1A=&5D+B(*;7-G<W1R("+/(/;<ZN7K[_(@
M7"(E<UPB(.3G[.GO]?'CWNCGZN4@[.4@Y?#I]/7WW^$N(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O871T86-H;65N=',N:6YC.C,*(RP@9G5Z>GD*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`BT/'OY^/O_>SE[><@T^7KW^3A(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHR.`IM<V=I9"`B
M4')E=FEO=7,@365S<V%G92(*;7-G<W1R("+0\>_GX^_][.7M[R#,WNWU[.$B
M"@HC.B!M86EL8F]X+G!H<#HS-#<*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS
M9W-T<B`BT/'OY^/O_>SE[><@T^7KW^3A(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")0<FEN="(*;7-G<W1R
M("+%ZO3]\/GSYR(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC
M.C,X"B,L(&9U>GIY"FUS9VED(")0<FEO<FET>2(*;7-G<W1R("+%ZO3]\/GS
MYR(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I
M9"`B4')I=F%T92!+97D@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4U.0IM<V=I9"`B4')O;7!T(&5V97)Y('1I;64@
M86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O($Y/(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-3@*;7-G:60@(E!R;VUP
M="!E=F5R>2!T:6UE(&%N(&%T=&%C:&UE;G0@:7,@<V5N=#L@9&5F875L="!T
M;R!915,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C$P"FUS9VED(")0<F]T;V-O;#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T-R>7!T+U!'4"YP:'`Z-#(Y"FUS9VED(")0=6)L:6,@4$=0(&ME>7-E<G9E
M<B!S=7!P;W)T(&AA<R!B965N(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHS-B!T96UP;&%T97,O;6%I
M;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E!U
M<E]G92!$96QE=&5D(@IM<V=S='(@(L_QZ?/TZ>K>(,3IX>/QX?;>(@H*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8SHX"FUS9VED(")0=7)G92!$96QE
M=&5D(@IM<V=S='(@(L_QZ?/TZ>K>(,3IX>/QX?;>(@H*(SH@=&5M<&QA=&5S
M+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!U<F=E
M($9O;&1E<BAS*2(*;7-G<W1R("+$Z>'C\>'VWB#6X>K=Z^_U*/GM*2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.38*;7-G:60@(E!U<F=E(%1R87-H
M(&AO=R!O9G1E;CHB"FUS9W-T<B`BS>$@P>3EZ=SFY>D@[R#JW.3O\B#JW.CE
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#4*;7-G:60@(E!U<F=E
M(&UE<W-A9V5S(&EN(%1R87-H(&9O;&1E<B!O;&1E<B!T:&%N('1H:7,@86UO
M=6YT(&]F(&1A>7,N(@IM<V=S='(@(B(*(LWA(.3IX>/QW/;O[?3AZ2#TX2#L
MY^W][.'TX2#A\/P@]._M(.K<Y.\@\._U(.7?[>'I(/#AZ^G\].7QX2#A\/P@
MX?7T_"#T[^T@(@HBX?'IZ.S\(.?LY?'^[2XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@V"B,L(&9U>GIY"FUS9VED(")0=7)G92!O;&0@;65S<V%G
M97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B"FUS9W-T<B`BQ.GAX_'A]MX@\.'K
MZ?[M(.SG[?7LW/3Y[2#A\/P@]._M(.K<Y.\[(@H*(SH@;&EB+TUA:6YT96YA
M;F-E+U1A<VLO<'5R9V5?=')A<V@N<&AP.C8U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L
M9&5R+B(*;7-G<W1R("+$Z>'C\>'VWB`E9"#LWNWU[.$H].$I(.'P_"#T[^T@
MZMSD[RXB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]P=7)G95]T<F%S:"YP
M:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E!U<F=I;F<@,2!M97-S86=E(&9R;VT@
M5')A<V@@9F]L9&5R+B(*;7-G<W1R("+$Z>'C\>'VWB`E9"#LWNWU[.$H].$I
M(.'P_"#T[^T@ZMSD[RXB"@HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC
M.C$W"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"
M("\@)2XR9DU"("`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<75O=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A
M('-T871U<SH@)2XR9DU"("\@3D\@3$E-250B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")1=6]T82!S=&%T=7,Z($Y/($Q)34E4(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(L'Q]^GJ_"#LWNWU[.$@X?#\("(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X-@IM<V=I9"`B
M4F5?<75E<W0@1&5L:79E<GD@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]396%R8V@N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")296-E:79E9"!/
M;B(*;7-G<W1R("+0X?'AZ][VZ.?JY2#S].GR(@H*(SH@;&EB+U-E87)C:"YP
M:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E)E8V5I=F5D(%-I;F-E(@IM<V=S='(@
M(M#A\>'KWO;HY^KE(//TZ?(B"@HC.B!L:6(O4V5A<F-H+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`BT.'QX>O>]NCG
MZN4@\_3I\B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5D:7)E8U]T(@IM<V=S='(@(L'M
MX>KA].7]Z/7M\^<B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T
M:6]N<RYI;F,Z,38*;7-G:60@(E)E9&ER96-T(@IM<V=S='(@(L'MX>KA].7]
MZ/7M\^<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I<F5C="YI;F,Z,3$P
M"FUS9VED(")2961I<F5C="!-97-S86=E(@IM<V=S='(@(L'MX>KA].7]Z/7M
M\^<@S.?M_>SA]._R(@H*(SH@8V]M<&]S92YP:'`Z-S@W"FUS9VED(")2961I
M<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T<B`BP>WAZN'TY?WH]>WSYR#A]?3O
M_2#T[_4@S.?M_>SA]._R(@H*(SH@8V]M<&]S92YP:'`Z.#0W"FUS9VED(")2
M961I<F5C=&EN9R!F86EL960N(@IM<V=S='(@(L<@X>WAZN'TY?WH]>WSYR#A
M\-WT]??E+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X
M,PIM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("+![>'MW?GSYR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E<V@@1F]L9&5R(%9I
M97=S.B(*;7-G<W1R("+![>'MW?GSYR#0\>_B[^O>\B#6X>K=Z_GM.B(*"B,Z
M('1E;7!L871E<R]F;VQD97)S+VAE860N:6YC.CD@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHT"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T
M<B`BP>WA[=WY\^<@T/'OXN_KWO(B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]H
M96%D+FEN8SHS"FUS9VED(")296QO860@5FEE=R(*;7-G<W1R("+![>'MW?GS
MYR#0\>_B[^O>\B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C8@
M;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-0IM<V=I9"`B4F5M96UB97(@
M=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDW.0IM<V=I9"`B4F5M96UB97(@=&AE(&QA
M<W0@=FEE=R(*;7-G<W1R("+-X2#PX?'A[-WMY>D@YR#TY>OE]?3AW^$@\/'O
MXN_KWB(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHR-PHC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W1E($UA:6QB;W@Z(@IM<V=S='(@(L/QX>SL
MX?3OZNGB_O3I[R(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN8SHT
M,0IM<V=I9"`B4F5M;W9E($9I96QD($9R;VT@4V5A<F-H(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,P-0HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E('-O=7)C92(*;7-G<W1R("+A]N'?\>7SYR#P
MY^/>\B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C@*(RP@
M9G5Z>GD*;7-G:60@(E)E;F%M92!&;VQD97(H<RDB"FUS9W-T<B`BS.7T[^WO
M[.'SW^$@UN'JW>OO]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*
M;7-G:60@(E)E;F%M92!S96YT+6UA:6P@9F]L9&5R(&%T(&)E9VEN;FEN9R!O
M9B!M;VYT:#\B"FUS9W-T<B`BS.7T[^WO[.'SW^$@]._U(/;AZMWK[_4@P=#%
MT]3!R\S%S<$@\_3G[2#A\??>(.K<Z.4@[-[MX3LB"@HC.B!L:6(O1F]L9&5R
M+G!H<#HT-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5N86UI;F<@7"(E<UPB
M('1O(%PB)7-<(B!F86EL960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60B"FUS9W-T<B`B(@HBQR#LY?3O[>_LX?/?X2#T[_4@]N'JW>OO]2!<(B5S
M7"(@\^4@7"(E<UPB(.'PW?3U]^4N(-3O(//]\_3G[.$@W>+CX>OE(/3O("(*
M(N'J_.OO]>CO(.S>[?7LX2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]A8W1I;VYS+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4F5P;%]Y('1O($QI
M<W0B"FUS9W-T<B`BP?#<[?3G\^<@\^4@_.OO]?(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")297!L86-E('=I=&@Z
M(@IM<V=S='(@(L'M].GJX?3<\_3A\^<@[.4Z(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@(E)E<&QY(@IM<V=S
M='(@(L'PW.WTY_/G(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q
M,2!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-#`Y"B,L(&9U>GIY"FUS9VED
M(")297!L>2!396YT+B(*;7-G<W1R("+!\-SM].?SYRWP\>_R(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$S"FUS9VED(")2
M97!L>2!T;R!!;&PB"FUS9W-T<B`BP?#<[?3G\^<@\^4@_.OO]?(B"@HC.B!C
M;VUP;W-E+G!H<#HW,S,*;7-G:60@(E)E<&QY('1O($%L;#HB"FUS9W-T<B`B
MP?#<[?3G\^<@\^4@_.OO]?(Z(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$P"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!,
M:7-T(@IM<V=S='(@(L'PW.WTY_/G(//E(/SK[_7R(@H*(SH@8V]M<&]S92YP
M:'`Z-S,U"B,L(&9U>GIY"FUS9VED(")297!L>2!T;R!,:7-T.B(*;7-G<W1R
M("+!\-SM].?SYR#SY2#\Z^_U\CHB"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E<&QY('1O
M(%]!;&PB"FUS9W-T<B`BP?#<[?3G\^<@\^4@_.OO]?(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z-3(X(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU,S<*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4T-PIM<V=I9"`B
M4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4S-0IM<V=I9"`B4F5P;'D@
M=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E<&QY
M('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;65S<V%G92YP:'`Z,C8W"B,L(&9U>GIY"FUS9VED(")297!L
M>2U4;R(*;7-G<W1R("+!\-SM].?SYRW0\>_R.B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HT,#D*;7-G:60@(E)E<&QY+51O.B`B"FUS9W-T<B`BP?#<[?3G\^<M
MT/'O\CHB"@HC.B!C;VUP;W-E+G!H<#HW,S$*;7-G:60@(E)E<&QY.B(*;7-G
M<W1R("+!\-SM].?SYSHB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?
M86-T:6]N<RYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z
M,C8*(RP@9G5Z>GD*;7-G:60@(E)E<&]R="!A<R!);FYO8V5N="(*;7-G<W1R
M("+![>'V[_'<(.SG[?WLX?3O\B#Y\B`G4W!A;2<B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3<&%M(@IM<V=S
M='(@(L'MX?;O\=P@[.?M_>SA]._R(/GR("=3<&%M)R(*"B,Z('1E;7!L871E
M<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X,PHC+"!F=7IZ>0IM<V=I9"`B4F5Q
M=65S="!A(%]296%D(%)E8V5I<'0B"FUS9W-T<B`BS>$@YN?TY^CEWR#%\.GB
MY>+AW_GSYR#0X?'AZ^'BWO(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3@U"FUS9VED(")297%U97-T(&1E;&EV97)Y(&-O;F9I<FUA=&EO;C\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4W,PHC+"!F=7IZ
M>0IM<V=I9"`B4F5Q=65S="!R96%D(')E8V5I<'1S/R(*;7-G<W1R("+-X2#F
MY_3GZ.7?(,7PZ>+EXN'?^?/G(-#A\>'KX>+>\B(*"B,Z(&UA:6QB;W@N<&AP
M.C$X.0IM<V=I9"`B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-CDW"FUS9VED
M(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$T,R!T96UP;&%T97,O<V5A<F-H+VAE861E
M<BYI;F,Z,C8*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V,0IM<V=I9"`B
M4F5S970B"FUS9W-T<B`BRN'HX?'I\^S\\B#6_/'LX?(B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3$U"FUS9VED(")297-P;VYD96YT(%-T871U
M<R!5<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]N
M879B87)?86-T:6]N<RYI;F,Z,S`*;7-G:60@(E)E<W5M92(*;7-G<W1R("+3
M]>W=]^7IX2(*"B,Z(')E8V]M<&]S92YP:'`Z.3@*;7-G:60@(E)E<W5M92!Y
M;W5R('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")2971U<FX@=&\@7")-
M97-S86=E($-O;7!O<VET:6]N7"(B"FUS9W-T<B`BT_WMZ.7SYR#,Y^W][.'T
M[_(B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V1R:79E<E]S96QE8W0N:6YC
M.C,Q('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV.0HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+V%C8V]U;G1?<V5L96-T+FEN8SHS,@HC+"!F=7IZ
M>0IM<V=I9"`B4F5T=7)N('1O($9E=&-H($UA:6PB"FUS9W-T<B`BQ?#I\_3Q
M[_;>(//TZ?(@Q?#IZ^_CW?(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F
M<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T86-T:79E+FEN8SHR,@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P,2!T96UP;&%T97,O<VUI
M;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z
M,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8SHQ-0HC.B!T96UP;&%T
M97,O86-L+V%C;"YI;F,Z,38R('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-S,*
M;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(L7PZ?/T\>_VWB#S
M].GR(,7PZ>OOX]WR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q.`IM
M<V=I9"`B(@HB4F5T=7)N('1O('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@
M9&5L971I;F<L(&UO=FEN9RP@;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S
M='(@(B(*(L7PZ?/T\>_VWB#S]._M(/;<ZN7K[R#%Z?/E\??\[.7MX2#LY?3<
M(.'P_"#DZ>'C\>'VWBP@[.7TX?;O\=P@WB#A[?3IX_'A]MX@(@HB[.?M_>SA
M]._R/R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.#@*;7-G:60@
M(E)O;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HQ-#(@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S<*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HT,3D*;7-G:60@(E,O34E-12(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$R
M"FUS9VED(")3+TU)344@16YC<GEP="!-97-S86=E(@IM<V=S='(@(B(*"B,Z
M(&-O;7!O<V4N<&AP.C,Y-`IM<V=I9"`B4R]-24U%($5R<F]R.B`B"FUS9W-T
M<B`B(@H*(SH@8V]M<&]S92YP:'`Z,S<S"FUS9VED(")3+TU)344@17)R;W(Z
M($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3$*(RP@9G5Z
M>GD*;7-G:60@(E,O34E-12!/<'1I;VYS(@IM<V=S='(@(L'P[^C>ZN7U\^<@
MQ?#IZ^_C_NTB"@HC.B!S;6EM92YP:'`Z-#D*;7-G:60@(E,O34E-12!087-S
M<&AR87-E($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S
M;6EM92YI;F,Z-30*;7-G:60@(E,O34E-12!097)S;VYA;"!+97EP86ER('-U
M<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(B(*"B,Z('-M:6UE+G!H<#HQ-#`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E,O34E-12!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@=V%S('-U8V-E
M<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("+/(/;<ZN7K[_(@7"(E<UPB(.3I
MX>/QW/;GZN4@[.4@Y?#I]/7WW^$N(@H*(SH@<VUI;64N<&AP.C$V,@IM<V=I
M9"`B4R]-24U%(%!U8FQI8R!+97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P"FUS9VED
M(")3+TU)344@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`B(@H*(SH@<VUI;64N
M<&AP.C(Q,0IM<V=I9"`B4R]-24U%(%!U8FQI8R]0<FEV871E($ME>7!A:7(@
M<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")3
M+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(L'P[_/T[^O>(,SG[?WLX?3O
M\B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z,30*
M;7-G:60@(E,O34E-12!3:6=N+T5N8W)Y<'0@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHT"FUS9VED(")3
M+TU)344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#$*;7-G
M:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!C=7)R96YT;'D@96YA8FQE
M9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@(@HB9&5C<GEP=&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$W
M,PIM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@<V\@
M=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO="`B
M"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,30V"FUS9VED("(B"B)3+TU)344@<W5P<&]R="!I<R!N
M;W0@96YA8FQE9"!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE
M('1O(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(')E
M<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@=7-E9"X@($EF('EO=7(@8G)O
M=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O(&1I<V%B;&4@<&]P=7`@=VEN
M9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@<V5T=&EN9R!O<B!E;'-E("(*
M(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N;W0@=V]R:R!C;W)R96-T;'DN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C`U
M"FUS9VED(")33510(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C(U-0HC+"!F=7IZ>0IM<V=I9"`B4U]U8FIE8W0B"FUS
M9W-T<B`BR-WLX2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C,V,PHC+"!F=7IZ>0IM<V=I9"`B4V%?=F4@82!C;W!Y(&EN("(*;7-G<W1R
M("+!\._HWNKE]?/G(.'M].GC\=SV[_4@\_3O[2#VW.KEZ^\@(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"B,L(&9U>GIY
M"FUS9VED(")385]V92!A<R(*;7-G<W1R("+!\._HWNKE]?/G(/GR(@H*(SH@
M<V5A<F-H+G!H<#HS,38@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC
M.C8W"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S='(@(L'P[^C>ZN7U\^<@
M^?(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU,S@*;7-G
M:60@(E-A=F4@071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I
M;"!F;VQD97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S
M,PIM<V=I9"`B4V%V92!$<F%F="(*;7-G<W1R("+!\._HWNKE]?/G(//T[R#0
M\?SWY>GQ[R(*"B,Z('-A=F5I;6%G92YP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@
M(E-A=F4@26UA9V4B"FUS9W-T<B`BP?#OZ-[JY?7SYR#Y\B(*"B,Z(&QI8B]-
M24U%+T-O;G1E;G1S+G!H<#HR,#0*;7-G:60@(E-A=F4@26UA9V4@:6X@1V%L
M;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI
M;F,Z-3D@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHQ,#`*(SH@=&5M<&QA
M=&5S+W-M:6UE+VYO=&%C=&EV92YI;F,Z,3(@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$T.`HC.B!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z,3,*;7-G
M:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("+!\._HWNKE]?/G(,7PZ>OOX_[M
M(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C0P"B,L(&9U
M>GIY"FUS9VED(")3879E(%-T871I;VYE<GDB"FUS9W-T<B`BP?#OZ-[JY?7S
MYR#%\.GK[^/^[2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C8Y('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0S,PHC+"!F=7IZ
M>0IM<V=I9"`B4V%V92!?1')A9G0B"FUS9W-T<B`BP?#OZ-[JY?7SYR#S].\@
MT/'\]^7I\>\B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T<B`BP?#OZ-[JY?7SYR#Y
M\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G:60@(E-A=F4@
M9')A9G1S(&%S('5N<V5E;C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-S(*;7-G:60@(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T
M:6-A;&QY('1O('1H92!D969A=6QT(&%D9')E<W,@8F]O:S\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,C<*;7-G:60@(E-A
M=F4@<V5A<F-H(&%S(&$@=FER='5A;"!F;VQD97(_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*(RP@9G5Z>GD*;7-G:60@(E-A
M=F4@<V5N="!M86EL/R(*;7-G<W1R("+!\._HWNKE]?/G(.'PY?/TX>OLW>WO
M]2#LY^W][.'T[_(B"@HC.B!C;VUP;W-E+G!H<#HQ,C(W"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=FEN9R!T:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`E<R(*;7-G<W1R("(B"B+'(.'P[^C>ZN7U
M\^<@]._U(/#Q_/?EZ?'O]2#LY^W][.'T[_(@X?#=]/7WY2X@U.\@\_WS].?L
MX2#=XN/AZ^4@].\@X>K\Z^_UZ.\@(@HB[-[M]>SA.B`E<R(*"B,Z('1E;7!L
M871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M86EL
M8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R<RYP
M:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R("+![>'FWO3G\^<B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB
M;W@O:&5A9&5R+FEN8SHQ,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4V5A<F-H("5S(@IM<V=S='(@(L'MX>;>].?SYR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!/<'1I;VYS
M(@IM<V=S='(@(L7PZ>OOX]WR(-?QWO/TYR(*"B,Z('-E87)C:"YP:'`Z,C8U
M"FUS9VED(")396%R8V@@4F5S=6QT<R(*;7-G<W1R("+!\._TY>O=\^SA].$@
MP>WAYM[TY_/G\B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,30@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,0IM<V=I9"`B4V5E
M;B(*;7-G<W1R("+$Z>'BX?/LW>WA(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;F%V8F%R+FEN8SHY"FUS9VED(")396QE8W0B"FUS9W-T<B`BQ?#IZ^_CWB(*
M"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHW,`HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T($%N;W1H97(@06-C;W5N="(*;7-G<W1R("+%\.GK
M[^/>(.KA[>7M_/(B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z
M,S8*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BQ?#I
MZ]WN].4@[-_A(/3A]?3\].?TX2(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE
M;&1S+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS
M9W-T<B`BQ?#IZ^_CWB#\Z_GM(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,S$W"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!S=&%T:6]N
M97)Y.B(*;7-G<W1R("+%\.GK[^/>(.KA[>7M_/(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,U"B,L(&9U>GIY"FUS9VED(")396QE8W0@861D<F5S
M<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A<F-H:6YG(&9O<B!A
M9&1R97-S97,N(@IM<V=S='(@(L7PZ>O=[O3E(.'P_"#T[_7R(.3IX>C=\^GL
M[_7R(.3IY?7H]>WSZ>_C\=SV[_7R+B(*"B,Z('1E;7!L871E<R]S96%R8V@O
M;6%I;BYI;F,Z.#@*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`BQ?#IZ^_C
MWB#\Z_GM(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S(S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&9I96QD<R!T;R!S96%R
M8V@@=VAE;B!E>'!A;F1I;F<@861D<F5S<V5S+B(*;7-G<W1R("(B"B+%\.GK
MW>[TY2#TYR#SY>GQW"#LY2#TY^T@[_#OW^$@Z.$@X]_MY?3AZ2#A[>'FWO3G
M\^<@\_3O]?(@Y.GE]>CU[?/I[^/QW/;O]?(N(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@(L7PZ>OOX]X@ZN'MY>W\\B(*
M"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.#D*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(L7PZ>OOX]X@ZN'MY>W\\B(*"B,Z('1E;7!L871E
M<R]S879E:6UA9V4O<V%V96EM86=E+FEN8SHY"FUS9VED(")396QE8W0@=&AE
M(&=A;&QE<GD@=&\@<V%V92!T:&4@:6UA9V4@:6XN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,Z,C$*;7-G
M:60@(E-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,#D*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C=&5D($%D9')E<W,@8F]O:W,Z(@IM<V=S='(@(L7P
MZ>OOX]X@Q.GE]>CU[?/I[^/QW/;O]3HB"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-S(*;7-G:60@(E-E;F0@2V5Y('1O(%!U8FQI8R!+97ES97)V97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P-`HC
M+"!F=7IZ>0IM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T
M<B`BT.OG\>_V[_'?Y?(@Q.GAZN_LZ?/TWB(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C0S,0IM<V=I9"`B4V5N9"!-97-S86=E(@IM<V=S='(@(L'P[_/T[^O>
M(,SG[?WLX?3O\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,#,*;7-G
M:60@(E-E;F0@<F5A9"!R96-E:7!T('=H96X@<F5Q=65S=&5D(&)Y('1H92!S
M96YD97(_(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PHC+"!F=7IZ
M>0IM<V=I9"`B4V5N="!M86EL(&9O;&1E<B(*;7-G<W1R("+6W.KEZ^_R(,'P
MY?/TX>OLW>WY[2#,Y^WU[-ST^>TZ(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E
M;G1M86EL<V5L96-T+FEN8SHS.`IM<V=I9"`B4V5N="!M86EL(&9O;&1E<CHB
M"FUS9W-T<B`BUMSJY>OO\B#!\.7S].'K[-WM^>T@S.?M]>S<]/GM.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3,R('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,34S"FUS9VED(")397)V97(B"FUS9W-T<B`BQ.GAZN_LZ?/TWO(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E
M<B!A;F0@1F]L9&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(M#KY_'O]N_QW^7R
M(,3IX>KO[.GS]-XB"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<CHB"FUS9W-T<B`BQ.GAZN_L
MZ?/TWO(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#`*;7-G:60@(E-E
M="!P<F5F97)E;F-E<R!F;W(@=VAA="!H87!P96YS('=H96X@>6]U(&UO=F4@
M86YD(&1E;&5T92!M97-S86=E<RXB"FUS9W-T<B`BT?7H[-_SY>GR(./IX2#T
MYR#LY?3A]N_QW"#JX>D@Y.GAX_'A]MX@[.?M]>S<]/GM+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-E="!T:&4@6"U0<FEO<FET
M>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S<V%G97,_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,0HC+"!F=7IZ>0IM<V=I9"`B
M4VAA<F4@1F]L9&5R<R(*;7-G<W1R("+!Z^OAX]X@UN'JW>OO]2(*"B,Z('1E
M;7!L871E<R]A8VPO86-L+FEN8SHX-@HC+"!F=7IZ>0IM<V=I9"`B4VAA<F4@
M;6%I;"!F;VQD97)S(@IM<V=S='(@(M;<ZN7K[_(@P?#E\_3AZ^S=[?GM(,SG
M[?7LW/3Y[3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(*;7-G:60@
M(E-H87)E('EO=7(@;6%I;"!F;VQD97)S('=I=&@@;W1H97(@=7-E<G,N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-CD*;7-G:60@
M(B(*(E-H;W5L9"!L87)G92!B;&]C:W,@;V8@<75O=&5D('1E>'0@8F4@<VAO
M=VX@;W(@:&ED9&5N(&)Y(&1E9F%U;'0_($ET(&-A;B!B92`B"B)T;V=G;&5D
M(&5A<VEL>2!W:&EC:&5V97(@>6]U(&-H;V]S92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D
M>2!O9B!T97AT+W!L86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D
M871A/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$S
M"FUS9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A
M9G1E<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`B(@HBS>$@ZNOEW^WEZ2#T
M[R#PX?'<Z/7Q[R#S_>WHY?/G\B#LY?3<(/3G[2#A\._HWNKE]?/G(/3O]2#L
MY^W][.'T[_(@\_3A("(*(O#Q_/?EZ?'A.R(*"B,Z('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHT"FUS9VED(")3:&]U;&0@>6]U<B!01U`@<'5B;&EC(&ME>2!T
M;R!B92!A='1A8VAE9"!T;R!Y;W5R(&UE<W-A9V5S(&)Y(&1E9F%U;'0_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@
M9G5Z>GD*;7-G:60@(E-H;W<@06QL($9O;&1E<G,B"FUS9W-T<B`BP>W<\/3U
M[N<@_.OY[2#T^>T@UN'JW>OY[2(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE
M861E<G,N:6YC.C8W"FUS9VED(")3:&]W($%L;"!(96%D97)S(@IM<V=S='(@
M(B(*"B,Z(&UA:6QB;W@N<&AP.C,V-0IM<V=I9"`B4VAO=R!$96QE=&5D(@IM
M<V=S='(@(L7L]MSMZ?/G(,3IX>/QX>SLW>WY[2(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VAE861E<G,N:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET960@2&5A
M9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S
M+FEN8SHW,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!-86EL:6YG($QI<W0@26YF
M;W)M871I;VXB"FUS9W-T<B`BT/'O\_GPZ>K=\B#0Z^?Q[_;O\=_E\B(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`BT_WMY.7S
MYR#S].\@UMSJY>OO*._U\BDB"@HC.B!F;VQD97)S+G!H<#HR.3@*;7-G:60@
M(E-H;W<@56YS=6)S8W)I8F5D(@IM<V=S='(@(L'P_.KQ]?CG(.'S_>WDY?3Y
M[2`H56YS=6)S8W)I8F5D*2#VX>K=Z_GM(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8P.`IM<V=I9"`B4VAO=R!A;B!I8V]N('1O(&%L;&]W('-T<FEP
M<&EN9R!O9B!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P,@IM<V=I9"`B4VAO=R!L
M96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\B"FUS9W-T<B`BS>$@Y>SVX>W?
MYN7TX>D@YR#E\.GC\>'VWB#S].?M(/#Q[^+OZ]X@]._U(,/QX>SLX?3OZNGB
M_O3I[_4[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T,`IM<V=I9"`B
M4VAO=R!P<F5V:65W<R!F;W(@=6YR96%D(&UE<W-A9V5S(&]N;'D_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-#@*;7-G:60@(E-H
M;W<@<')E=FEE=W,@:6X@=&]O;'1I<',_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-S<*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA
M:6P@:6-O;B!O;B!T:&4@;65N=6)A<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VAT;6PN<&AP.CDU"FUS9VED(")3:&]W('1H92!);6%G97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C4T
M"FUS9VED(")3:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N=6)A<C\B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(X"B,L(&9U
M>GIY"FUS9VED(")3:&]W('1O=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD
M97(_(@IM<V=S='(@(LSO[>_PW/3I(./IX2#T[^T@]MSJY>OO(.SE(/3A(.SG
M[?WLX?3A(//A\CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8V"FUS
M9VED(")3:&]W;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M
M97-S86=E7VAE861E<G,N:6YC.C0R"B,L(&9U>GIY"FUS9VED(")3:5]Z92(*
M;7-G<W1R("+,W>/EZ._R(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHQ-PHC+"!F=7IZ>0IM<V=I9"`B4VEG;F5D(@IM<V=S='(@(LS=X^7H
M[_(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,PIM
M<V=I9"`B4VEZ92(*;7-G<W1R("+,W>/EZ._R(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,0IM<V=I9"`B4V]R="!B>2!!
M<G)I=F%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,Z,38*;7-G:60@(E-O<G0@8GD@1&%T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC
M.C(V"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y($9R;VT@061D<F5S<R(*;7-G
M<W1R("+$Z>7]Z/7M\^<@P?#O\_3OZ]WA(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O;65S<V%G95]H96%D97)S+FEN8SHT,0HC+"!F=7IZ>0IM<V=I9"`B4V]R
M="!B>2!-97-S86=E(%-I>F4B"FUS9W-T<B`BS-WCY>CO\B#,Y^W][.'T[_(B
M"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,V
M"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y(%-U8FIE8W0B"FUS9W-T<B`BQ.7M
M(-7PW/'WY>D@R-WLX2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?
M:&5A9&5R<RYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(E-O<G0@8GD@5&AR96%D
M(@IM<V=S='(@(LW>[.$B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E
M7VAE861E<G,N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")3;W)T(&)Y(%1O($%D
M9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G(,'P[_/T[^O=X2(*"B,Z('1E;7!L
M871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B
M4W!A;2!F;VQD97(Z(@IM<V=S='(@(M;<ZN7K[_(@Q.GAX_'A[.S=[>$Z(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0V"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<G,B"FUS9W-T<B`BQ>GDZ>KOWR#WX?'AZO3>\>7R
M(@H*(SH@<V5A<F-H+G!H<#HQ,S,*;7-G:60@(E-P96-I86P@5FER='5A;"!&
M;VQD97)S(&-A;B!N;W0@8F4@961I=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#,*;7-G:60@(E-P96QL($-H
M96-K(@IM<V=S='(@(L_QZ._C\>'VZ>K\\B"XZ^7C]^_R(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")3<&5L;"!#:&5C
M:V5R(@IM<V=S='(@(L_QZ._C\>'VZ>K\\B#%Z^7CZO3>\B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHT."!T96UP;&%T97,O8V]M<&]S
M92]S<&5L;&EN9RYI;F,Z-38*;7-G:60@(E-P96QL(&-H96-K(&-O;7!L971E
M(@IM<V=S='(@(L_QZ._C\>'VZ>K\\B#=Z^7C]^_R(._K[^KKY_'^Z.?JY2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S$*;7-G:60@(E-P96QL:6YG
M(&5R<F]R<R!P97(@<V-R965N('=H96X@<W!E;&P@8VAE8VMI;F<N(@IM<V=S
M='(@(L_QZ._C\>'VZ>K<(.O<Z.<@X>W<(//EZ]_DX2#\].'M(./?[>7TX>D@
M[_'H[^/QX?;IZOSR(-WKY>/W[_(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C4Q,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C4R"FUS9VED
M(")3=&%R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P
M<F5F<RYI;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3$*
M;7-G:60@(E-T871I;VYE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-T
M871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3=&%T:6]N97)Y(&YA;64Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S+FEN
M8SHR.`IM<V=I9"`B4W1A=&EO;F5R>2!T>7!E.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z,S,*;7-G:60@(E-T871I
M;VYE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV.#@*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]#
M;VYT96YT<RYP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")3=')I<"!!='1A8VAM
M96YT(@IM<V=S='(@(M/U[>?L[-WM[R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,S(*;7-G:60@(E-T<FEP(&QI;F5B<F5A:W,_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S<*
M(RP@9G5Z>GD*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(LC=[.$B"@HC.B!M
M97-S86=E+G!H<#HR-C@@=&AR96%D+G!H<#HQ-3`@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM<V=I
M9"`B4W5B:F5C="(*;7-G<W1R("+(W>SA(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDR,`IM<V=I9"`B4W5B:F5C="!&:65L9"(*;7-G<W1R("+(W>SA
M(.SG[?WLX?3O\B(*"B,Z('-E87)C:"YP:'`Z,S$X('1E;7!L871E<R]S879E
M:6UA9V4O<V%V96EM86=E+FEN8SHQ.`HC.B!T96UP;&%T97,O<VUI;64O<&%S
M<W!H<F%S92YI;F,Z,C`@=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8SHS
M,0HC+"!F=7IZ>0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(LC=[.$B"@HC.B!T
M96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,0IM<V=I9"`B4W5B<V-R
M:6)E('1O($9O;&1E<BAS*2(*;7-G<W1R("+3_>WDY?/G(//T[R#6W.KEZ^\H
M[_7R*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,S@P(&QI8B]-
M24U%+U9I97=E<B]P9W`N<&AP.C,X.0HC.B!L:6(O34E-12]6:65W97(O<W1A
M='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+%\.GT]???X2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHX-@IM<V=I9"`B
M4W5G9V5S=&EO;G,B"FUS9W-T<B`BT/'O]-SSY>GR(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8V,B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C8T"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0P,"!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT,#,*;7-G:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z
M-#`T"FUS9VED(")3=VET8V@@=&\@2%1-3"!C;VUP;W-I=&EO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G
M:60@(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0Q.0HC+"!F
M=7IZ>0IM<V=I9"`B5&5?>'0B"FUS9W-T<B`BRN7?[.7M[R(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HR-CD*;7-G:60@(E1E;G1A=&EV93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU.3$*;7-G
M:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW-C$*;7-G:60@(E1E;G1A=&EV
M96QY($%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC92]4
M87-K+W1O<U]A9W)E96UE;G0N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N
M<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y+W!R969S
M+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R("+*Y=_LY>WO(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDU-`IM<V=I9"`B5&AE($9R;VTZ(&-O;'5M
M;B!O9B!T:&4@;65S<V%G92!S:&]U;&0@8F4@;&EN:V5D.B(*;7-G<W1R("(B
M"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C4S,@IM<V=I9"`B(@HB5&AE($E-
M05`@<V5R=F5R(&1O97,@;F]T(&%P<&5A<B!T;R!S=7!P;W)T('1H92!A=71H
M96YT:6-A=&EO;B!M971H;V0@(@HB<V5L96-T960N(%!L96%S92!C;VYT86-T
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]-24U%+U9I97=E<B]A<'!L961O=6)L92YP:'`Z-#$*;7-G:60@(E1H92!-
M86-I;G1O<V@@<F5S;W5R8V4@9F]R:R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!-86-I;G1O<V@@<F5S;W5R8V4@9F]R:R!C86X@8F4@9&]W;FQO
M861E9"`E<RXB"FUS9W-T<B`B(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BQR#TX?7T_/3G].$@7"(E
M<UPB(.3IX>/QW/;GZN4N(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@
M:&%S(&)E96X@<V%V960N(@IM<V=S='(@(M3A(//T[^GWY=_A(/3G\B#TX?7T
M_/3G].'R(%PB)7-<(B#=]^_U[2#A\._HY^KE]?3EWRXB"@HC.B!A='1A8VAM
M96YT+G!H<#HT,PIM<V=I9"`B5&AE(&%T=&%C:&UE;G0@=V%S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y
M"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V]M<&]S95]W:6XN
M:G,Z,S<*;7-G:60@(B(*(E1H92!C;VUP;W-E('=I;F1O=R!C86XG="!B92!O
M<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B
M"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0R"FUS9VED(")4:&4@8V]N=&5N
M=',@;V8@=&AE($UA8VEN=&]S:"!F:6QE(&%R92!B96QO=RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL7VUO
M;G1H;'DN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C=7)R96YT
M(&9O;&1E<BAS*2!<(B5S7"(@=VEL;"!B92!R96YA;65D('1O(%PB)7-<(BXB
M"FUS9W-T<B`BSR#T\=WW^>T@]MSJY>OO\BCOZ2D@7"(E<UPB(.CA(.SE]._M
M[^SA\_3EWR#SY2!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC
M.C$P-PIM<V=I9"`B(@HB5&AE(&-U<G)E;G0@;&ES="!O9B!U<V5R<R!W:71H
M(&%C8V5S<R!T;R!T:&ES(&9O;&1E<B!C;W5L9"!N;W0@8F4@<F5T<FEE=F5D
M(@IM<V=S='(@(B(*"B,Z(&-O;7!O<V4N<&AP.C$R,S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O('1H92!<(B5S
M7"(@9F]L9&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,3,Y"FUS9VED(")4:&4@979E;G0@=V%S(&%D9&5D('1O('EO=7(@
M8V%L96YD87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X
M<&%N9"YI;F,Z.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M96QD(%PB)7-<(B!C86XG="!B92!E>'!A;F1E9"XB"FUS9W-T<B`BQR#TX?7T
M_/3G].$@7"(E<UPB(.3IX>/QW/;GZN4N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z
M,S,W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E<UPB(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(L\@]MSJY>OO\B!<(B5S7"(@]?#<\??E
MZ2#>Y.<B"@HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A;"!C
M:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O8FQE
M;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HBU.\@_.WO[.$@]._U(/;AZMWK[_4@7"(E<UPB(/#E\>G=]^7I
M(.SG(.7PZ?3QY?#\[.7M[_7R(/?A\>'J]-[QY?(N(,SP[_'EWR#MX2`B"B+U
M\-SQ[N_U[2#P\>_BZ][LX?3A+B#%[>?LY?'^\_3E(/3O(.3IX??EZ?'I\_3>
M(/3O]2#S]?/TWNSA]._R+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@8W)E871E
M9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@:70N(@IM<V=S='(@
M(L\@]MSJY>OO\B!<(B5S7"(@Y.?LZ>_U\>/>Z.?JY2#AZ^O<(.3E[2#S]>WD
MY>C>ZN'TY2#SY2#A]?3\[2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T
M960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS
M9W-T<B`BSR#VW.KEZ^_R(%PB)7-<(B#DZ>'C\=SVY^KE(.'KZ]P@Y.7M(.'P
M[_/U[>3EZ-[JX?3E(.'P_"#A]?3\[2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S
M(&YO="!C<F5A=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM
M<V=S='(@(B(*(L\@]MSJY>OO\B!<(B5S7"(@Y.7M(.3G[.GO]?'CWNCGZN4N
M(-3O(//]\_3G[.$@W>+CX>OE(/3O(.'J_.OO]>CO(.S>[?7LX2(*"B,Z(&QI
M8B]&;VQD97(N<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L
M9&5R(%PB)7-<(B!W87,@;F]T(&1E;&5T960N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60B"FUS9W-T<B`BSR#VW.KEZ^_R(%PB)7-<(B#DY>T@Y.GA
MX_'<]N?JY2X@U.\@\_WS].?LX2#=XN/AZ^4@].\@X>K\Z^_UZ.\@[-[M]>SA
M(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S4Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB
M"FUS9W-T<B`BSR#VW.KEZ^_R(%PB)7-<(B#DY^SI[_7QX][HY^KE(.SE(.7P
MZ?3U]]_A+B(*"B,Z(&QI8B]&;VQD97(N<&AP.C(W-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E
M;&5T960N(@IM<V=S='(@(L\@]MSJY>OO\B!<(B5S7"(@Y.GAX_'<]N?JY2#L
MY2#E\.GT]???X2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HT-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`BSR#VW.KEZ^_R(%PB)7-<
M(B#LY?3O[>_LW//TY^KE(.SE(.7PZ?3U]]_A(//E(%PB)7-<(BXB"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z.3(*;7-G:60@(E1H92!F;VQL;W=I
M;F<@9FEL97,@=V5R92!A='1A8VAE9"!T;R!T:&ES('!A<G0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?<V%V96EM86=E7W=I
M;BYJ<SHQ,@IM<V=I9"`B(@HB5&AE(&EM86=E('-A=F4@=VEN9&]W(&-A;B!N
M;W0@8F4@;W!E;F5D+B!097)H87!S('EO=2!H879E('-E="!Y;W5R(&)R;W=S
M97(@(@HB=&\@8FQO8VL@<&]P=7`@=VEN9&]W<S\B"FUS9W-T<B`B(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"FUS9VED("(B"B)4:&4@:6UA
M9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P
M<F5S96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<U"FUS9VED(")4:&4@;6%I
M;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G
M93HB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-3$*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.CDP"FUS9VED(")4:&4@
M;6%I;"!S97)V97(@9V5N97)A=&5D('1H92!F;VQL;W=I;F<@;65S<V%G93HB
M"FUS9W-T<B`B(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C8U,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&UA:6QB;W@@)7,@:7,@86QR96%D>2!E
M;7!T>2XB"FUS9W-T<B`B)7,@Y=_MX>D@WN3G(-SDY>GO+B(*"B,Z(&QI8B]&
M971C:&UA:6PN<&AP.C(T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;65S
M<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S*2!E>&-E961S(&9E
M=&-H('-I>F4@;&EM:70N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z,3`S"B,L(&9U>GIY"FUS9VED(")4:&4@;65S
M<V%G92!B96EN9R!C;VUP;W-E9"!H87,@8F5E;B!C;&]S960N($5X:71I;F<N
M(@IM<V=S='(@(M3O(.S>[?7LX2#P[_4@\_7MZ-WTY?3AZ2#JZ^7?[>7I+B(*
M"B,Z(&UE<W-A9V4N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B5&AE(&UE<W-A
M9V4@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BQR#TX?7T_/3G].$@7"(E
M<UPB(.3IX>/QW/;GZN4N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,SDS"B,L(&9U>GIY"FUS9VED(")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I
M9FEE9"XB"FUS9W-T<B`BU.$@\_3OZ??EW^$@].?R(/3A]?3\].?TX?(@7"(E
M<UPB(-WW[_7M(.'P[^CGZN7U].7?+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!M97-S86=E
M(&AA<R!B965N('9E<FEF:65D+B!396YD97(Z("5S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O;W!E;E]S;6EM95]W:6XN:G,Z,3`@=&5M<&QA
M=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z,3`*;7-G:60@(B(*(E1H92!P87-S
M<&AR87-E('=I;F1O=R!C86XG="!B92!O<&5N960N(%!E<FAA<',@>6]U(&AA
M=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B;&]C:R!P;W!U<"!W:6YD;W=S
M/R(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(')A=R!T97AT(&]F('1H92!01U`@
M4'5B;&EC($ME>2!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O=&YE9BYP:'`Z-C`*;7-G:60@(E1H92!R97%U97-T
M960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@35,M5$Y%1B!A='1A8VAM
M96YT+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O>FEP+G!H<#HV
M-`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T(&5X:7-T(&EN
M('1H92!::7`@871T86-H;65N="XB"FUS9W-T<B`B(@H*(SH@;65S<V%G92YP
M:'`Z-30W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!S96YD97(@;V8@
M=&AI<R!M97-S86=E(&ES(')E<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B`B"B)F<F]M('EO=2!W:&5N('EO=2!H879E(')E
M860@=&AI<R!M97-S86=E+B!0;&5A<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@
M(@HB;F]T:69I8V%T:6]N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C8Y"FUS9VED(")4:&4@<V5R=F5R('=A
M<R!N;W0@86)L92!T;R!C<F5A=&4@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ
M<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(E1H92!S:6=N871U<F4@8V]U;&0@;F]T
M(&)E(')E<&QA8V5D+B(*;7-G<W1R("+'(/7P[^/QX?;>(.3E[2#L\._Q[_WS
MY2#MX2#A[?3IZN'TX?/TX>CEWRXB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FIS.C$P,@IM<V=I9"`B5&AE('-I9VYA='5R92!W87,@<W5C8V5S
M<V9U;&QY(')E<&QA8V5D+B(*;7-G<W1R("+'(/7P[^/QX?;>(.'M].GJX?3A
M\_3<Z.?JY2#LY2#E\.GT]???X2XB"@HC.B!A='1A8VAM96YT+G!H<#HU.0IM
M<V=I9"`B5&AE('-P96-I9FEE9"!F:6QE(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("(B"@HC.B!S=&%T:6]N97)Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N(&%D
M9&5D+B(*;7-G<W1R("+4X2#S]._I]^7?X2#TY_(@].'U]/STY_3A\B!<(B5S
M7"(@W??O]>T@X?#OZ.?JY?7TY=\N(@H*(SH@<W1A=&EO;F5R>2YP:'`Z-C,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S=&%T:6]N97)Y(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+'(/3A]?3\].?TX2!<
M(B5S7"(@Y.GAX_'<]N?JY2XB"@HC.B!S=&%T:6]N97)Y+G!H<#HX-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB
M(&AA<R!B965N('5P9&%T960N(@IM<V=S='(@(L<@].'U]/STY_3A(%PB)7-<
M(B#DZ>'C\=SVY^KE+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ
M-CD*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S
M:VQI<W0N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N
M<&AP.CDU"B,L(&9U>GIY"FUS9VED(")4:&4@=&5X="!O9B!T:&4@;65S<V%G
M92(*;7-G<W1R("+DZ>'C\>'VWB#LY^W][.'T[_(B"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX,`IM<V=I9"`B
M5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('1E>'0@;V8@=&AE(')E='5R;F5D(&UE<W-A9V4@8V%N
M(&)E('9I97=E9"`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VYO=&EF:6-A=&EO;BYP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E1H92!T97AT
M(&]F('1H92!S96YT(&UE<W-A9V4B"FUS9W-T<B`BP>WAZN'TY?WH]>WSYR#A
M]?3O_2#T[_4@S.?M_>SA]._R(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E>'0@
M;V8@=&AE('-E;G0@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34T"B,L(&9U>GIY
M"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@
M<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R("+'(/7P[^/QX?;>(.'M].GJ
MX?3A\_3<Z.?JY2#LY2#E\.GT]???X2XB"@HC.B!L:6(O34E-12]6:65W97(O
M86QT97)N871I=F4N<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N
M871I=F4@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI
M;F,Z,PIM<V=I9"`B5&AE<F4@87)E(&YO(&UE<W-A9V5S(&EN('1H:7,@;6%I
M;&)O>"XB"FUS9W-T<B`BQ.7M(/7PW/'W[_7M(.SG[?WLX?3A(//E(.'U]/P@
M].\@X_'A[.SA]._JZ>+^].GO+B(*"B,Z('1H<F5A9"YP:'`Z,3`Y"FUS9VED
M(")4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-97-S86=E+G!H<#HV,3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`B(@HB
MT.'Q[_7SZ=SS].?JY2#S]MSK[.$@\_3G(.3IX>/QX?;>("5S+B#4[R#S_?/T
MY^SA(-WBX^'KY2#T[R#AZOSK[_7H[R#LWNWU[.$B"@HC.B!L:6(O365S<V%G
M92YP:'`Z-C4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&5X<'5N9VEN9R!T:&4@;6%I;&)O>"X@5&AE('-E<G9E
M<B!S86ED.B`E<R(*;7-G<W1R("(B"B+0X?'O]?/IW//TY^KE(//VW.OLX2#S
M].<@Y.GAX_'A]MX@]._U(./QX>SLX?3OZNGB^?3?[_4N(-3O(//]\_3G[.$@
MW>+CX>OE(/3O("(*(N'J_.OO]>CO(.S>[?7LX3H@)7,B"@HC.B!L:6(O365S
M<V%G92YP:'`Z-C(Q"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&5X<'5N
M9VEN9R!T:&4@;6%I;&)O>"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9"(*;7-G<W1R("(B"B+0X?'O]?/IW//TY^KE(//VW.OLX2#S].<@Y.GAX_'A
M]MX@]._U(./QX>SLX?3OZNGB^?3?[_4N(-3O(//]\_3G[.$@W>+CX>OE(/3O
M("(*(N'J_.OO]>CO(.S>[?7LX2(*"B,Z(&QI8B]-97-S86=E+G!H<#HY,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&-O<'EI;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4
M:&ES(&ES('=H870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(M#A
M\>_U\^G<\_3GZN4@\_;<Z^SA(.KA]-P@].<@X>WTZ>/QX?;>(/3Y[2#LY^WU
M[-ST^>T@\_3O(%PB)7-<(BX@U.\@\_WS].?LX2`B"B+=XN/AZ^4@].\@X>K\
MZ^_UZ.\@[-[M]>SA(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C$Y."!L:6(O365S
M<V%G92YP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<R!F<F]M('1H92!F;VQD97(@
M7"(E<UPB+B!4:&ES(&ES('=H870@(@HB=&AE('-E<G9E<B!S86ED(@IM<V=S
M='(@(B(*(M#A\>_U\^G<\_3GZN4@\_;<Z^SA(.KA]-P@].<@Y.GAX_'A]MX@
M]/GM(.SG[?7LW/3Y[2#A\/P@].\@]MSJY>OO(%PB)7-<(BX@U.\@(@HB\_WS
M].?LX2#=XN/AZ^4@].\@X>K\Z^_UZ.\@[-[M]>SA(@H*(SH@;&EB+TUE<W-A
M9V4N<&AP.C(W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S
M7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B
M(@HBT.'Q[_7SZ=SS].?JY2#S]MSK[.$@ZN'TW"#TYR#DZ>'C\>'VWB#T^>T@
M[.?M]>S<]/GM(//T[R#VW.KEZ^\@7"(E<UPB+B#4[R`B"B+S_?/TY^SA(-WB
MX^'KY2#T[R#AZOSK[_7H[R#LWNWU[.$B"@HC.B!L:6(O365S<V%G92YP:'`Z
M,C$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&5L971I;F<@;65S<V%G97,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("5S(@IM<V=S='(@(B(*(M#A\>_U\^G<\_3GZN4@\_;<Z^SA
M(.KA]-P@].<@Y.GAX_'A]MX@]/GM(.SG[?7LW/3Y[2X@U.\@\_WS].?LX2#=
MXN/AZ^4@].\@(@HBX>K\Z^_UZ.\@[-[M]>SA(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.CDY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@=&AE(&5V96YT.B`E<RXB"FUS
M9W-T<B`BU?#>\>[E(/#Q_.+KY^SA(.KA]-P@].\@W.WOZ>/LX2#T[_4@[.?M
M_>SA]._R+B(*"B,Z(&QI8B]-24U%+U9I97=E<B]P;&%I;BYP:'`Z-3(@;&EB
M+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<#HS-PIM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T
M<B`BU?#>\>[E(.O<Z._R(.KA]-P@].?M(.7L]MSMZ?/G(.'U]._](/3O]2#L
MW?'O]?(@]._U(.SG[?WLX?3O\B(*"B,Z(&QI8B]-97-S86=E+G!H<#HU-#4@
M;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@;65S<V%G97,@:6X@=&AE(&9O
M;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T:&4@(@HB<V5R=F5R('-A:60B
M"FUS9W-T<B`B(@HBT.'Q[_7SZ=SS].?JY2#S]MSK[.$@ZN'TW"#TYR#SWNSA
M[?/G(/3Y[2#LY^WU[-ST^>T@\_3O(/;<ZN7K[R!<(B5S7"(N(-3O("(*(O/]
M\_3G[.$@W>+CX>OE(/3O(.'J_.OO]>CO(.S>[?7LX2(*"B,Z(&9O;&1E<G,N
M<&AP.C$V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R`E<RXB"FUS9W-T<B`BU?#>\>[E(.O<Z._R
M(//TY^T@X?#OZ-[JY?7SYR#T[_4@[.?M_>SA]._R(/GR(/#Q_/?EZ?'O+B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,S8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`BU?#>\>[E(/#Q_.+KY^SA(.KA]-P@
M].\@W.WOZ>/LX2#T[_4@[.?M_>SA]._R+B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HQ-C8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G
M<W1R("+5\-[Q[N4@\/'\XNOG[.$@ZN'TW"#T[R#<[>_IX^SA(/3O]2#LY^W]
M[.'T[_(N(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS
M9W-T<B`BU?#>\>[E(.O<Z._R(.KA]-P@].?M(.'P[_/T[^O>(/3O]2#LY^W]
M[.'T[_(Z("5S(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;6]V:6YG
M(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B+0X?'O]?/IW//TY^KE
M(//VW.OLX2#JX?3<(/3G(.SE].'V[_'<(/3Y[2#LY^WU[-ST^>T@\_3O(%PB
M)7-<(BX@U.\@\_WS].?LX2`B"B+=XN/AZ^4@].\@X>K\Z^_UZ.\@[-[M]>SA
M(@H*(SH@8V]M<&]S92YP:'`Z,3(T-`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R('-A=FEN9R!T:&ES(&UE<W-A9V4@87,@82!D<F%F="XB
M"FUS9W-T<B`BU?#>\>[E(.O<Z._R(.KA]-P@].?M(.7L]MSMZ?/G(.'U]._]
M(/3O]2#LW?'O]?(@]._U(.SG[?WLX?3O\B(*"B,Z(&-O;7!O<V4N<&AP.C$P
M,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R('-E
M;F1I;F<@>6]U<B!M97-S86=E.B`E<R(*;7-G<W1R("+5\-[Q[N4@Z]SH[_(@
MZN'TW"#TY^T@X?#O\_3OZ]X@]._U(.SG[?WLX?3O\CH@)7,B"@HC.B!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z,3$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT
M.B`E<RXB"FUS9W-T<B`BU?#>\>[E(.O<Z._R(.KA]-P@].?M(.'P[_/T[^O>
M(/3O]2#LY^W][.'T[_(Z("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+W!L86EN
M+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&YO('1E>'0@:6X@
M=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`BU?#>\>[E(.O<Z._R(.KA]-P@
M].?M(.7L]MSMZ?/G(.'U]._](/3O]2#LW?'O]?(@]._U(.SG[?WLX?3O\B(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B5&AI<R!(
M5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP"FUS9VED("(B
M"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D9&5D(&EN(&ET
M+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,38V"FUS9VED(")4
M:&ES(%!'4"!0=6)L:6,@2V5Y('=A<R!A='1A8VAE9"!T;R!T:&4@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$P
M-"!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$X"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HQ-#,@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$U
M-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3<S(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HS,30*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S
M=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-SD@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0Q.0IM<V=I9"`B
M5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I
M9"`B5&AI<R!M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!C;VYT:6YU93\B"FUS9W-T<B`B(@HBP?7TWB#G(.7MW?'CY>GA
M(.7MY-WWY?3AZ2#MX2#JX>CU\_3E\=[SY>DN(,7?\_3E(//?X^_U\>_R*.<I
M(/STZ2#HW>OE].4@[>$@(@HB\_7MY???\^7TY3LB"@HC.B!L:6(O34E-12]6
M:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED(")4:&ES(&UE<W-A9V4@
M8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TU)344O5FEE=V5R+W!K8W,W+G!H<#HT,3`*;7-G:60@(B(*(E1H:7,@;65S
M<V%G92!C;VYT86EN<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG
M:71A;&QY('-I9VYE9"!V:6$@4R\B"B)-24U%+B(*;7-G<W1R("(B"@HC.B!L
M:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C0Q-`IM<V=I9"`B5&AI<R!M97-S
M86=E(&-O;G1A:6YS(&%N(&%T=&%C:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R
M>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,38P"FUS9VED("(B"B)4:&ES(&UE<W-A9V4@8V]N
M=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF;W)M871I;VXL(&)U="!T
M:&4@9F]R;6%T(&]F("(*(G1H:7,@;65S<V%G92!I<R!U;FMN;W=N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,34*(RP@9G5Z
M>GD*;7-G:60@(B(*(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!01U`@96YC<GEP=&5D(&UE<W-A9V4N($5R<F]R.B`B"FUS
M9W-T<B`B)7,@Y.7M(.7?[>'I(-WCZO7Q[R#C\>'L[.'T[^KIXO[TZ>\N(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C0P(&QI8B]-24U%+U9I97=E
M<B]P9W`N<&AP.C,U,`IM<V=I9"`B(@HB5&AI<R!M97-S86=E(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T("AA8V-O
M<F1I;F<@=&\@(@HB4D9#(#(P,34I+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI<R!M97-S86=E(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R
M;6%T+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR
M,#4@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z-#$V"FUS9VED(")4:&ES(&UE
M<W-A9V4@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE9"!V:6$@4$=0+B(*;7-G
M<W1R("(B"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C$T,PIM<V=I
M9"`B5&AI<R!M97-S86=E(&AA<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA
M(%,O34E-12XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HQ,SD@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@
M(E1H:7,@;65S<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,C`Q(&QI
M8B]-24U%+U9I97=E<B]P9W`N<&AP.C(Y,0IM<V=I9"`B5&AI<R!M97-S86=E
M(&AA<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB"FUS9W-T<B`B(@H*(SH@
M;65S<V%G92YP:'`Z,C$Q"FUS9VED(")4:&ES(&UE<W-A9V4@=&\B"FUS9W-T
M<B`BP?7T_"#T[R#LWNWU[.$@\/'O\B(*"B,Z(&%C;"YP:'`Z-#8*;7-G:60@
M(E1H:7,@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A(&-O;7!O<V4@=VEN9&]W+B(*;7-G<W1R("+!]?3\(/3O
M(/#A\=SH]?'O(/#QW?#EZ2#MX2#A[>_?X^7I(.S\[>\@[-WSX2#A\/P@].\@
M\.'QW.CU\>\@\_WMZ.7SY_(B"@HC.B!T:')E860N<&AP.C$U,@HC+"!F=7IZ
M>0IM<V=I9"`B5&AR96%D($1I<W!L87DB"FUS9W-T<B`BQ>SVW.WI\^<B"@HC
M.B!T:')E860N<&AP.C<V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,C(*;7-G
M:60@(E1H<F5A9"!6:65W(@IM<V=S='(@(M#Q[^+OZ]X@[>?LW/3Y[2(*"B,Z
M(&UE<W-A9V4N<&AP.C(V-"!M86EL8F]X+G!H<#HV,#8@=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8SHR,3D*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M;65S<V%G95]H96%D97)S+FEN8SHR,B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-C$*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5C;VUP;W-E+FEN
M8SHQ,"!L:6(O4V5A<F-H+G!H<#HR-@IM<V=I9"`B5&\B"FUS9W-T<B`BT/'O
M\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,3D*(RP@9G5Z>GD*;7-G
M:60@(E1O($%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G(,'P[_/T[^O=X2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,R-@IM<V=I
M9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&9I96QD<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!W:&EL92`B"B)C;&EC
M:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HQ,S0*
M;7-G:60@(B(*(E1O('5S92!A(%1,4R!C;VYN96-T:6]N+"!Y;W4@;75S="!B
M92!R=6YN:6YG(&$@=F5R<VEO;B!O9B!02%`@-2XP+C8@;W(@(@HB:&EG:&5R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHU-S<*(RP@9G5Z>GD*;7-G:60@(E1O=&%L($%T=&%C:&UE;G1S(%-I>F4Z
M(@IM<V=S='(@(M/U[>?L[-WMX2(*"B,Z(&9O;&1E<G,N<&AP.C,X.`HC+"!F
M=7IZ>0IM<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(M;<ZN7K[_(@Q.GA
MX_'A[.S=[>$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN
M8SHR,PIM<V=I9"`B5')A<V@@9F]L9&5R.B(*;7-G<W1R("+6W.KEZ^_R(,3I
MX>/QX>SLW>WA.B(*"B,Z(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C4@;&EB+U%U
M;W1A+VUE<F-U<GDS,BYP:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N<&AP.C<R
M"B,Z(&QI8B]1=6]T82]L;V=F:6QE+G!H<#HX."!L:6(O475O=&$O8V]U<FEE
M<BYP:'`Z-3,@;&EB+U%U;W1A+VUD865M;VXN<&AP.C0X"FUS9VED(")5;F%B
M;&4@=&\@<F5T<FEE=F4@<75O=&$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8SHQ,"!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C$Y"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S8*;7-G:60@(E5N86YS=V5R960B"FUS9W-T<B`BS.<@X?#A[?3G
M[-WMX2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,S4*;7-G:60@
M(E5N86YS=V5R960@;65S<V%G97,B"FUS9W-T<B`BS.<@X?#A[?3G[-WMX2#L
MY^W][.'TX2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS
M+FEN8SHT('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED
M(")5;F1E;&5T92(*;7-G<W1R("+%\.'MX?;O\=PB"@HC.B!M86EL8F]X+G!H
M<#HU.#D@;6%I;&)O>"YP:'`Z-C`R(&QI8B]-24U%+TAE861E<G,N<&AP.C(Q
M,@IM<V=I9"`B56YD:7-C;&]S960@4F5C:7!I96YT<R(*;7-G<W1R("+,YR#5
M\.'QZO3OWR#0X?'AZ][P].7R(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N
M96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z(&UA:6QB;W@N<&AP.C4V
M-0IM<V=I9"`B56YK;F]W;B!$871E(@IM<V=S='(@(B(*"B,Z(&QI8B])34%0
M+T-L:65N="YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@
M24U!4"!R97-P;VYS92!F<F]M('1H92!S97)V97(N(%-E<G9E<B!297-P;VYD
M960Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HV,S4*;7-G:60@(E5N:VYO=VX@365E=&EN9R(*;7-G<W1R("(B"@HC.B!M
M86EL8F]X+G!H<#HV,3@*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@4F5C:7!I
M96YT(@IM<V=S='(@(LSG(-7PX?'J]._?(-#A\>'KWO#TY?(B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHW-PIM<V=I9"`B56YL;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`B(@H*(SH@
M9F5T8VAM86EL<')E9G,N<&AP.C8U"FUS9VED(")5;FYA;65D(@IM<V=S='(@
M(J+C[?GS].<@S._Q]MX@P?'WY=_O]2(*"B,Z(&UE<W-A9V4N<&AP.C0Y.2!M
M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG
M871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,34@
M=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*;7-G<W1R("+,
MYR#DZ>'BX?/LW>WA(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI
M;F,Z,3(*;7-G:60@(E5N<W5B<V-R:6)E(&9R;VT@1F]L9&5R*',I(@IM<V=S
M='(@(L'P[_/][>3E\^<@X?#\(/3O[2#VW.KEZ^\H[_7R*2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X-`IM<V=I9"`B57!D871E($%T
M=&%C:&UE;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8R,`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@
M<W1A='5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]I;7!O<G1?
M:V5Y+FEN8SHU."!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC.C4V"FUS
M9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E
M;G1M86EL<V5L96-T+FEN8SHT,0IM<V=I9"`B57-E($1E9F%U;'0@5F%L=64B
M"FUS9W-T<B`BU_'>\^<@\/'OZN'H[_'I\^S=[>?R(/3I[-[R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B57-E($E-05`@9F]L9&5R
M('-U8G-C<FEP=&EO;G,_(@IM<V=S='(@(M?QY_/I[._P[^G>\_3E(/3G(//U
M[>3Q[^S>(//T[_7R(.KA].'K_./O]?(@24U!4#LB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S,U"B,L(&9U>GIY"FUS9VED(")5<V4@5FER='5A;"!4
M<F%S:"!&;VQD97(_(@IM<V=S='(@(J+DY>GA\^SA(-;AZMWK[_4@Q.GAX_'A
M[.S=[>$B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,30R"B,L(&9U>GIY
M"FUS9VED(")5<V5R(@IM<V=S='(@(KSM[^SA(-?QWO/TYR(*"B,Z(&%C;"YP
M:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB57-E<B!<(B5S7"(@<W5C
M8V5S<V9U;&QY(&=I=F5N('1H92!S<&5C:69I960@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ-S<*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(KSM[^SA
M(-?QWO/TYR(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHQ
M-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(KSM[^SA(-?Q
MWO/TYR(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHV.`HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z-S(@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<W"B,L
M(&9U>GIY"FUS9VED(")6:65W(@IM<V=S='(@(L7L]MSMZ?/G("5S(@H*(SH@
M;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z.3(@;&EB+TU)344O5FEE=V5R+W1N
M968N<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(L7L]MSMZ?/G("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN
M8SHR-2!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M2%1-3"!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(L<@
M\_WMZ.7SYR#T^>T@[.?M]>S<]/GM(.WA(./?[>7TX>D@\^4@[=WO(/#A\=SH
M]?'O.R(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C(X"B,L
M(&9U>GIY"FUS9VED(")6:65W($UE<W-A9V5S(@IM<V=S='(@(LW=X2#LY^W]
M[.'TX2(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA
M=&5S+W!G<"]P9W`N:6YC.C<W"FUS9VED(")6:65W(%!E<G-O;F%L(%!R:79A
M=&4@2V5Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI
M;F,Z-C@@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C<R"FUS9VED(")6:65W(%!E
M<G-O;F%L(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE
M<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$X"B,L(&9U>GIY"FUS9VED(")6
M:65W(%1H<F5A9"(*;7-G<W1R("+-WNSA(@H*(SH@;&EB+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z,38S(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$V
M-0IM<V=I9"`B5FEE=R!4:'5M8FYA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W!K8W,W+G!H<#HT,3@*(RP@9G5Z>GD*;7-G:60@(E9I97<@
M871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=R(*;7-G<W1R("+'(//]
M[>CE\^<@]/GM(.SG[?7LW/3Y[2#MX2#CW^WE].'I(//E(.W=[R#PX?'<Z/7Q
M[SLB"@HC.B!L:6(O34E-12]6:65W97(O<F5L871E9"YP:'`Z-SD*(RP@9G5Z
M>GD*;7-G:60@(E9I97<@8V]N=&5N="!I;B!A('-E<&%R871E('=I;F1O=R(*
M;7-G<W1R("+'(//][>CE\^<@]/GM(.SG[?7LW/3Y[2#MX2#CW^WE].'I(//E
M(.W=[R#PX?'<Z/7Q[SLB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,30P"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N
M<&AP.C,X,"!M86EL8F]X+G!H<#HU,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E9I97<@;65S<V%G97,@:6X@)7,B"FUS9W-T<B`BQ>SVW.WI\^<@
M[.?M]>S<]/GM(//T[R`B"@HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A
M9V5S96QE8W0N:6YC.C(S"FUS9VED(")6:65W(&]R(&UA:6QB;W@@=&\@9&ES
M<&QA>2!A9G1E<B!L;V=I;CHB"FUS9W-T<B`B(@HBT/'OXN_KWB#>(,/QX>SL
MX?3OZNGB_O3I[R#P[_4@Z.$@Y>SVX>W?YN7TX>D@[.7TW"#TY^T@Y=_S[^3O
M(//TY^T@]?#G\>7SW^$Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$W,`HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(L7L]MSM
MZ?/G("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.C$P,0HC+"!F
M=7IZ>0IM<V=I9"`B5FEE=R!T:&4@26UA9V5S(@IM<V=S='(@(L7L]MSMZ?/G
M(.SG[?7LW/3Y[2#S].\@(@H*(SH@<V5A<F-H+G!H<#HR-C,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E9I<G1U86P@1F]L9&5R(%PB)7-<(B!C<F5A
M=&5D('-U8V-E<V9U;&QY+B(*;7-G<W1R("+/(/;<ZN7K[_(@7"(E<UPB(.3I
MX>/QW/;GZN4@[.4@Y?#I]/7WW^$N(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M
M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E92YP:'`Z,3,X(&QI8B])34%0+U1R
M964N<&AP.C$U,0HC.B!L:6(O24U!4"]4<F5E+G!H<#HQ-3,@;&EB+TE-05`O
M5')E92YP:'`Z,34W(&QI8B])34%0+U1R964N<&AP.C$U.`HC.B!L:6(O24U!
M4"]4<F5E+G!H<#HS-CD@;&EB+TE-05`O5')E92YP:'`Z,SDS(&QI8B])34%0
M+U1R964N<&AP.C0S,PHC+"!F=7IZ>0IM<V=I9"`B5FER='5A;"!&;VQD97)S
M(@IM<V=S='(@(L3G[.GO]?'CW^$@UN'JW>OO]2(*"B,Z('-E87)C:"YP:'`Z
M,C0U"FUS9VED(")6:7)T=6%L($9O;&1E<G,@<F5Q=6ER92!A(&QA8F5L+B(*
M;7-G<W1R("(B"@HC.B!L:6(O5D9O;&1E<BYP:'`Z,3<U(&QI8B]61F]L9&5R
M+G!H<#HQ.#`*;7-G:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`B(@H*(SH@
M9F]L9&5R<RYP:'`Z-#$V"FUS9VED(")6:7)T=6%L($E.0D]8($9O;&1E<B(*
M;7-G<W1R("(B"@HC.B!M86EL8F]X+G!H<#HT-3(@;&EB+U9&;VQD97(N<&AP
M.C$Q-"!L:6(O5D9O;&1E<BYP:'`Z,3$Y"FUS9VED(")6:7)T=6%L(%1R87-H
M(@IM<V=S='(@(B(*"B,Z(&9O;&1E<G,N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I
M9"`B5FER='5A;"!4<F%S:"!&;VQD97(B"FUS9W-T<B`BHN3EZ>'S[.$@UN'J
MW>OO]2#$Z>'C\>'L[-WMX2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,3,S"FUS9VED(")6:7)T=6%L(&9O;&1E<B!L86)E;"(*;7-G<W1R("(B
M"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W-`IM<V=I9"`B5V%R
M;FEN9R(*;7-G<W1R("+0\>_EZ>3O\._?Y_/G(@H*(SH@;&]G:6XN<&AP.C$S
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@
M(LKAZ_GSWO'HX?3E("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q
M.0IM<V=I9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A
M9V5S(&%F=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@(@HB
M;W(@:6YN;V-E;G0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW,C<*;7-G:60@(B(*(E=H96X@9&5L971I;F<@;65S<V%G97,L(&UO
M=F4@=&AE;2!T;R!Y;W5R(%1R87-H(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI
M;F<@(@HB=&AE;2!A<R!D96QE=&5D/R(*;7-G<W1R("(B"B*\].'M(.3IX>/Q
MW/;O[?3AZ2#LY^W][.'TX2P@[>$@[.7TX?;=\>_M].'I(//T[^T@]MSJY>OO
M(.3IX>/QX>SLW>WA(.'M]-\@[>$@(@HB]^'QX>KTY_'?YN_M].'I(/GR(.3I
MX>/QX>SLW>WA.R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*;7-G
M:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E(&1O
M('EO=2!W86YT('1O('-T87)T(&]N/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-38Q"FUS9VED(")7:&5N('-A=FEN9R!S96YT+6UA
M:6PL('-H;W5L9"!W92!S879E(&%T=&%C:&UE;G0@9&%T83\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-@IM<V=I9"`B(@HB5VAE
M;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D9')E<W-E<RP@=VAA="!D
M;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U;G%U86QI9FEE9"!A9&1R
M97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T(%PB0%PB*3\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC
M.C(T('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$Y"FUS9VED(")7
M:&ET96QI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-S@*;7-G:60@
M(EEE<R(*;7-G<W1R("+-X>DB"@HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]F
M971C:&UA:6Q?;&]G:6XN<&AP.C4X"B,L(&9U>GIY"FUS9VED(")9;W4@87)E
M(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN9R!A8V-O
M=6YT*',I.B(*;7-G<W1R("*X]^7TY2#E\.GKW>[EZ2#MX2#DZ>'C\=SXY?3E
M(/3O]?(@X>K\Z^_UZ._U\B#VX>K=Z^_U\CHB"@HC.B!T96UP;&%T97,O9F]L
M9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M;#HQ,`HC+"!F=7IZ>0IM<V=I9"`B
M(@HB66]U(&%R92!A='1E;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@
M8V]N=&%I;F5D(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R(@HB*',I+B(*;7-G
M<W1R("*X]^7TY2#E\.GKW>[EZ2#MX2#DZ>'C\=SXY?3E(/3O]?(@X>K\Z^_U
MZ._U\B#VX>K=Z^_U\CHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S
M7V-O;F9I<FTN:'1M;#HY"B,L(&9U>GIY"FUS9VED(")9;W4@87)E(&%T=&5M
M<'1I;F<@=&\@9&5L971E('1H92!F;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G
M<W1R("*X]^7TY2#E\.GKW>[EZ2#MX2#DZ>'C\=SXY?3E(/3O]?(@X>K\Z^_U
MZ._U\B#VX>K=Z^_U\CHB"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R
M:7!T+FEN8SHU-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ
M.3(*;7-G:60@(EEO=2!A<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L
M9&5R+B(*;7-G<W1R("+![?3IX_'<]N7TY2`O(.SE].'VW?'E].4@\^4@[=WO
M(/;<ZN7K[RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$P,@IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('-U8BUF;VQD97(@=&\@
M(@IM<V=S='(@(L3G[.GO]?'CY=_TY2#=[>$@]MSJY>OO(.K<]/D@X?#\(/3O
M[2`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS.C$P-`IM
M<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('1O<"UL979E;"!F;VQD97(N(@IM
M<V=S='(@(L3G[.GO]?'CY=_TY2#=[>$@]MSJY>OO(/#Q_O3O]2#E\.GPW>3O
M]2XB"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@
M(L3G[.GO]?'CY=_TY2#=[>$@]MSJY>OO(/#Q_O3O]2#E\.GPW>3O]2XB"@HC
M.B!L:6(O1F]L9&5R+G!H<#HS,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&9O;&1E
M<G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E
M<G,N:G,Z,3,U"FUS9VED(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z
M("(*;7-G<W1R("*X]^7TY2#E\.GKW>[EZ2#MX2#LY?3O[>_LW//E].4@].\@
M]MSJY>OO.B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(KCWY?3E(.7PZ?3U]_[R(.'P[_/U[>3EZ.7?(.'P
M_"!<(B5S7"(B"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI;F,Z
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&-A;B!U<V4@=&AE(&9O
M;&QO=VEN9R!P;&%C96AO;&1E<G,@:6X@=&AE('-T871I;VYE<GD@=&5X=#H@
M)6,@9F]R('1H92`B"B)C=7)R96YT(&UE<W-A9V4@8V]N=&5N=#L@)7,@9F]R
M('1H92!S:6=N871U<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EN=&5N86YC
M92]487-K+W1O<U]A9W)E96UE;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED
M(&YO="!A9W)E92!T;R!T:&4@5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L
M('-O('EO=2!W97)E(&YO="!A;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38Y"FUS9VED(")9;W4@
M9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C97-S('1O('1H
M:7,@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&9O<G=A<F1E9"!T:&ES(&UE<W-A
M9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EL8F]X+V%L97)T+FEN8SHS"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!H879E("5S(&YE=R!M97-S86=E<RXB
M"FUS9W-T<B`BN/?E].4@)7,@S=WA(.SG[?WLX?3A+B(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+V%L97)T+FEN8SHS"FUS9VED(")9;W4@:&%V92`Q(&YE=R!M
M97-S86=E+B(*;7-G<W1R("*X]^7TY2`Q(,W=[R#LWNWU[.$N(@H*(SH@8V]M
M<&]S92YP:'`Z-#DT"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!A;')E861Y
M('-U8FUI='1E9"!T:&ES('!A9V4N(@IM<V=S='(@(KCWY?3E(#$@S=WO(.S>
M[?7LX2XB"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ<SHQ
M,34*;7-G:60@(B(*(EEO=2!H879E(&%T(&QE87-T(&]N92!A='1A8VAM96YT
M('-E;&5C=&5D('1H870@>6]U(&1I9&XG="!U<&QO860@>65T+B!!<F4@(@HB
M>6]U('-U<F4@>6]U('=A;G0@=&\@<V5N9"!T:&ES(&UE<W-A9V4@=VET:&]U
M="!T:&5S92!A='1A8VAM96YT<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TE-4"YP
M:'`Z,3`W-`IM<V=I9"`B66]U(&AA=F4@;F5W(&UA:6P@:6X@=&AE(&9O;&QO
M=VEN9R!F;VQD97(Z(@IM<V=S='(@(KCWY?3E(.W=X2#LY^W][.'TX2#S]._M
M(.'J_.OO]>CO(/;<ZN7K[SHB"@HC.B!L:6(O24U0+G!H<#HQ,#<Y"FUS9VED
M(")9;W4@:&%V92!N97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<G,Z
M(@IM<V=S='(@(KCWY?3E(.W=X2#LY^W][.'TX2#S]._U\B#AZOSK[_7H[_7R
M(/;AZMWK[_7R.B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PHC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB"FUS
M9W-T<B`BT/'=\.7I(.WA(-WWY?3E(.7PZ>O=[N7I(/3O]>O<]^GS]._M(-WM
MX2#PX?'AZ][P].<N(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,S`R
M"FUS9VED("(B"B)9;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@
M>6]U<B!01U`@<')I=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR-#D*;7-G
M:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O<B!Y;W5R
M(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@(@HB;65S<V%G92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN
M8SHV-"!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHR,#$*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A('1A<F=E="!M86EL8F]X(&9I<G-T+B(*
M;7-G<W1R("+0\=WPY>D@\/'^].$@[>$@Y?#IZ]WNY?3E(-WMX2#VW.KEZ^\N
M(@H*(SH@9F5T8VAM86EL<')E9G,N<&AP.C@U"B,L(&9U>GIY"FUS9VED(")9
M;W4@;75S="!S96QE8W0@86X@86-C;W5N="!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R("+0\=WPY>D@\/'^].$@[>$@Y?#IZ]WNY?3E(.S?X2#TX?7T_/3G].$@
M\._U(.C=Z^7TY2#MX2#DZ>'C\=SXY?3E+B(*"B,Z('1E;7!L871E<R]C;VYT
M86-T<R]C;VYT86-T<RYI;F,Z.#$*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M;B!A9&1R97-S(&9I<G-T+B(*;7-G<W1R("+0\=WPY>D@\/'^].$@[>$@Y?#I
MZ]WNY?3E(.SIX2#DZ>7]Z/7M\^<N(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M:F%V87-C<FEP="YI;F,Z-C(@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP
M="YI;F,Z,C`X"B,Z('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC
M.C(V,PIM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S
M86=E(&9I<G-T+B(*;7-G<W1R("+0\=WPY>D@\/'^].$@[>$@Y?#IZ]WNY?3E
M(/3O]>O<]^GS]._M(-WMX2#LWNWU[.$N(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5D:7)E8W0N:6YC.C$S"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M<F5C:7!I96YT+B(*;7-G<W1R("+0\=WPY>D@[>$@\/'O\^3I[_'?\^7TY2#=
M[>$@\.'QX>O>\/3G+B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V%T=&%C:&UE
M;G1S+FIS.C(Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&%T
M(&QE87-T(&]N92!F:6QE('1O(&%T=&%C:"XB"FUS9W-T<B`BT/'=\.7I(/#Q
M_O3A(.WA(/#Q[_/DZ>_QW_/E].4@].\@X?'WY=_O(/#O]2#HW>OE].4@[>$@
MY?#I\_7MW/CE].4N(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N
M:6YC.C0X"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!N965D('1O(&AA=F4@
M7"(E<UPB(&5N86)L960@:6X@>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(*
M;7-G<W1R("(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,3,W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@<F5D:7)E8W1E9"!T:&ES(&UE<W-A9V4@
M=&\@)7,@;VX@)25S+B(*;7-G<W1R("+![>'JX?3E_>CU[?/G(.'U]._](/3O
M]2#,Y^W][.'T[_(B"@HC.B!L:6(O36%I;&QO9RYP:'`Z,30Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@<F5P;&EE9"!T;R!T:&ES(&UE<W-A
M9V4@;VX@)7,N(@IM<V=S='(@(L'MX>KA].7]Z/7M\^<@X?7T[_T@]._U(,SG
M[?WLX?3O\B(*"B,Z(&QI8B]&;VQD97(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE
M<F4@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BQ.7M(//U[>3E
MZ-[JX?3E(//T[R!<(B5S7"(N(-3O(//]\_3G[.$@W>+CX>OE(/3O(.'J_.OO
M]>CO(.S>[?7LX2(*"B,Z(&QI8B]&;VQD97(N<&AP.C4U.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@=V5R92!N;W0@=6YS=6)S8W)I8F5D(&9R;VT@7"(E
M<UPB+B!(97)E(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(L3E
M[2#A\._S]>WDY>C>ZN'TY2#A\/P@7"(E<UPB+B#4[R#S_?/TY^SA(-WBX^'K
MY2#T[R#AZOSK[_7H[R#LWNWU[.$B"@HC.B!L:6(O1F]L9&5R+G!H<#HU,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@<W5C8V5S<V9U;&QY('-U
M8G-C<FEB960@=&\@7"(E<UPB(@IM<V=S='(@(KCWY?3E(.7PZ?3U]_[R(//U
M[>3EZ.7?(//T[R!<(B5S7"(N(@H*(SH@;&EB+T9O;&1E<BYP:'`Z-38R"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E('-U8V-E<W-F=6QL>2!U;G-U
M8G-C<FEB960@9G)O;2!<(B5S7"(B"FUS9W-T<B`BN/?E].4@Y?#I]/7W_O(@
MX?#O\_7MY.7HY=\@X?#\(%PB)7-<(B(*"B,Z('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHY.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(M3O
M(._M[^SA].7P_NWU[.\@\^'R.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN
M8SHU,`IM<V=I9"`B66]U<B!01U`@4'5B;&EC+U!R:79A=&4@2V5Y<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Q('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHW-@IM<V=I9"`B66]U<B!0<FEV871E($ME>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8W('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHW,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!0
M=6)L:6,@2V5Y(@IM<V=S='(@(M3O(._M[^SA].7P_NWU[.\@\^'R.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C4*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3XB"FUS
M9W-T<B`B(@HBQR#DZ>7]Z/7M\]X@\^'R(/#O]2#HX2#T[_#OZ.7TY=_TX>D@
M\_3O(/#EY-_O(,'PW.WTY_/G+?#Q[_(Z(#QI/BCP\>_AZ?'E].GJ_"DB"B(\
M+VD^(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHT.0IM<V=I9"`B
M66]U<B!3+TU)344@4'5B;&EC+U!R:79A=&4@0V5R=&EF:6-A=&5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N
M:6YC.C$V"B,L(&9U>GIY"FUS9VED(")9;W5R(&%C8V]U;G1S.B(*;7-G<W1R
M("+/Z2#TX?7T_/3G].7R(//A\CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3<S"FUS9VED("(B"B)9;W5R(&%L:6%S(&%D9')E<W-E<SH@/&5M/BAO
M<'1I;VYA;"P@96YT97(@96%C:"!A9&1R97-S(&]N(&$@;F5W(&QI;F4I/"]E
M;3XB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M.3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T(&EN;&EN92!D:7-P;&%Y(&]F('1H:7,@:6UA9V4@='EP92XB"FUS9W-T
M<B`B(@HBSR!"<F]W<V5R("CP+O<N($EN=&5R;F5T($5X<&QO<F5R(-X@3F5T
M<V-A<&4I(//A\B#DY>T@]?#O\_3G\=_FY>D@].?M("(*(O#A\>_U\]_A\^<@
MX?7T[_T@]._U(/3]\._U(.7IZOSMX?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N
M9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V5N8W)Y<'1S96QE8W0N:6YC.C$*;7-G:60@(EEO=7(@9&5F875L="!E;F-R
M>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z.#D*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E
M9"XB"FUS9W-T<B`BSR#VW.KEZ^_R(%PB)7-<(B#DZ>'C\=SVY^KE(.SE(.7P
MZ?3U]]_A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#8*;7-G:60@
M(EEO=7(@<VEG;F%T=7)E.B(*;7-G<W1R("+'(/7P[^/QX?;>(//A\CHB"@HC
M.B!M97-S86=E+G!H<#HR.#@@8V]M<&]S92YP:'`Z,3(X-"!M86EL8F]X+G!H
M<#HU-#D@;&EB+T-O;7!O<V4N<&AP.C@Q.`IM<V=I9"`B6TYO(%-U8FIE8W1=
M(@IM<V=S='(@(EO$Y>T@]?#<\??EZ2#HW>SA72(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C(P-0HC+"!F=7IZ>0IM<V=I9"`B7T)C8R(*
M;7-G<W1R("+*\?7VWB#*[^GM[_#OW^?SYR(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T97,O;6%I;&)O>"]A
M8W1I;VYS+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B7T)L86-K;&ES="(*;7-G
M<W1R("+%[>_WZ^?TZ>K>(,'KZ^?K[^/QX?;?X2(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C$U-`HC+"!F=7IZ>0IM<V=I9"`B7T-C(@IM
M<V=S='(@(LKOZ>WO\._?Y_/G(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI
M;F,Z.`HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ,`HC+"!F
M=7IZ>0IM<V=I9"`B7T1E;&5T92(*;7-G<W1R("+$Z>'C\>'VWB(*"B,Z(&QI
M8B])35`N<&AP.CDW.0HC+"!F=7IZ>0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T
M<B`BUMSJY>OOZ2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C@Q"B,L(&9U>GIY"FUS9VED(")?261E;G1I='DB"FUS9W-T<B`BU.'U]/ST
MY_3A(@H*(SH@;&EB+TE-4"YP:'`Z.38Q"FUS9VED(")?26YB;W@B"FUS9W-T
M<B`B(@H*(SH@;&EB+TE-4"YP:'`Z,3`R,`HC+"!F=7IZ>0IM<V=I9"`B7TQO
M9R!O=70B"FUS9W-T<B`BN.[OY._R(@H*(SH@;65S<V%G92YP:'`Z,S@T"B,L
M(&9U>GIY"FUS9VED(")?365S<V%G92!3;W5R8V4B"FUS9W-T<B`BT.?CX=_O
M\B#*_N3IZN'R(@H*(SH@;&EB+TE-4"YP:'`Z.3<V"B,L(&9U>GIY"FUS9VED
M(")?3F5W($UE<W-A9V4B"FUS9W-T<B`BS=WA(.SG[?WLX?3A(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"B,L(&9U>GIY
M"FUS9VED(")?4')I;G0B"FUS9W-T<B`BQ>KT_?#Y\^<B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]C;VUP;W-E+FEN8SHR-S(@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C@Y"FUS9VED(")?4')I;W)I='DB"FUS9W-T<B`B(@H*
M(SH@;6%I;&)O>"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")?4F5F<F5S:"`E<R(*;7-G<W1R("+![>'MW?GSYR(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"B,L(&9U>GIY"FUS9VED
M(")?4F5P;'DB"FUS9W-T<B`BP?#<[?3G\^<B"@HC.B!L:6(O24U0+G!H<#HY
M.#$*(RP@9G5Z>GD*;7-G:60@(E]396%R8V@B"FUS9W-T<B`BP>WAYM[TY_/G
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-C<@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,Q"B,L(&9U>GIY"FUS9VED(")?
M4V5N9"!-97-S86=E(@IM<V=S='(@(L'P[_/T[^O>(,SG[?WLX?3O\B(*"B,Z
M('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,S(*(RP@
M9G5Z>GD*;7-G:60@(E]4:')E860B"FUS9W-T<B`BS=[LX2(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B
M7U1O(@IM<V=S='(@(M#Q[_(B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B7U5N9&5L971E(@IM<V=S='(@
M(L7PX>WA]N_QW"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I
M;VYS+FEN8SHQ.`HC+"!F=7IZ>0IM<V=I9"`B7U9I97<@5&AR96%D(@IM<V=S
M='(@(LW>[.$B"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N
M<RYI;F,Z,C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G
M:60@(E]7:&ET96QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP
M.C$W-@IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C0T,`HC+"!F=7IZ>0IM<V=I9"`B871T86-H;65N
M="(*;7-G<W1R("+3]>WG[.S=[>\B"@HC.B!V:65W+G!H<#HY.0HC+"!F=7IZ
M>0IM<V=I9"`B871T86-H;65N=',N>FEP(@IM<V=S='(@(M/U[>?L[-WMX2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4Q,PIM<V=I9"`B
M8GET97,B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P,`IM<V=I
M9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!L
M:6(O0V]M<&]S92YP:'`Z,3<R"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,38T"FUS9VED(")C;VUM
M86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O
M<V4N<&AP.C(R,`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3DV"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E
M+G!H<#HQ-C@*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,C0*;7-G:60@(F5N=')Y(&YO="!F;W5N
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C$Y,`IM<V=I9"`B9G)O;2(*;7-G<W1R("+!\/PB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,3@P"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C`T"FUS9VED(")I;G!U="]O=71P
M=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$X.`IM
M<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M<VUI;64N<&AP.C(Y('!G<"YP:'`Z-CD*;7-G:60@(FME>2(*;7-G<W1R("(B
M"@HC.B!F;VQD97)S+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(FUA:6QB;W@@
M9FEL92(*;7-G<W1R("+#\>'L[.'T[^KIXO[TZ>\B"@HC.B!C;VUP;W-E+G!H
M<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT-C8*(RP@9G5Z>GD*;7-G:60@(FYA
M;64B"FUS9W-T<B`BO.WO[.$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z-S8*;7-G:60@(FYO;F4B"FUS9W-T<B`BZN'MW>WA(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$P-0IM<V=I9"`B;W(B
M"FUS9W-T<B`BWB(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,38*;7-G:60@(G!E
M<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HR,3(*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@T"FUS9VED(")S97)V:6-E('5N
M879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHT-@IM<V=I9"`B<W!E;&QI;F<@97)R;W(B"FUS9W-T<B`B
M[_'H[^/QX?;IZOP@Z]SH[_(B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z-#8*;7-G:60@(G-P96QL:6YG(&5R<F]R<R(*;7-G<W1R("+O
M\>COX_'A]NGJW"#KW.CG(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y,@HC+"!F
M=7IZ>0IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(N_QZ._C\>'VZ>K\
M(.O<Z._R(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(P.`IM<V=I9"`B=&5M<&]R
M87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;'1E<BYP:'`Z-3$*
M(RP@9G5Z>GD*;7-G:60@(GEO=7(@8FQA8VML:7-T(@IM<V=S='(@(L7M[_?K
MY_3IZMX@P>OKY^OOX_'A]M_A(@H*(SH@;&EB+T9I;'1E<BYP:'`Z-C$*;7-G
M:60@(GEO=7(@=VAI=&5L:7-T(@IM<V=S='(@(B(*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+W!O+V9A7TE2+G!O````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0W-3,P,``Q,#0Q-S,V
M,C<V-@`P,3<Q-C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!097)S:6%N('1R86YS;&%T:6]N<R!F;W(@26UP('!A8VMA
M9V4N"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@"B,@0V]P>7)I9VAT
M("A#*2`R,#`T($AI9V@@0V]N8VEL(&]F($EN9F]R;6%T:6-S("AW=W<N<VAC
M:2YI<BD*(R!0<F]V:61E9"!B>2`@06UI<FMA8FER($UE=&%N971W;W)K:6YG
M($QT9"P@,C`P-"`\<&5R<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RYC;VT^
M"B,@36]H<V5N($YA9&5R+4)A9'(@("`@("`@/&YA9&5R:4!M971A;F5T=V]R
M:VEN9RYC;VT^"B,@8VAA:V%M96@@36]R=&5Z86YI82`@("`@/&UO<G1E>F%N
M:6%`;65T86YE='=O<FMI;F<N8V]M/@HC(%-A;&UA;B!.:6MS969A="`@("`@
M("`@(#QN:6MS969A=$!M971A;F5T=V]R:VEN9RYC;VT^"B,@2&%M960@1VAE
M>6)I("`@("`@("`@("`@/&=H97EB:4!M971A;F5T=V]R:VEN9RYC;VT^"B,@
M5F%H:60@1VAA9F%R<&]U<B`@("`@("`@/&=H869A<G!O=7)`;65T86YE='=O
M<FMI;F<N8V]M/@HC(%IA:')A($%H;6%D:2!&:7)O=7IJ865E(#QA:&UA9&E`
M;65T86YE='=O<FMI;F<N8V]M/@HC(`IM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@24U0(#0@04Q02$%<;B(*(E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO
M;BU$871E.B`R,#`U+3`W+3`Y(#$U.C(W*S`R,#!<;B(*(DQA<W0M5')A;G-L
M871O<CH@06UI<FMA8FER($UE=&%N971W;W)K:6YG(&QT9"X@/'!E<G-I86XM
M:&]R9&5`;65T86YE='=O<FMI;F<N(@HB8V]M/EQN(@HB3&%N9W5A9V4M5&5A
M;3H@4&5R<VEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E
M<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/5541BTX7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M7&XB"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#$X"FUS9VED("(@("`@("!#8SH@
M(@IM<V=S='(@(B#8L=F(V8;9B-BTV*H@V*C9ASHB"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z-#$U"FUS9VED("(@("`@("!4;SH@(@IM<V=S='(@(MBHV8<Z("`@
M("`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z-#`S"FUS9VED("(@("`@1&%T93H@
M(@IM<V=S='(@(MBJV*?8L=N,V*XZ("`B"@HC.B!L:6(O0V]M<&]S92YP:'`Z
M-#`V"FUS9VED("(@("`@1G)O;3H@(@IM<V=S='(@(MBGV+(Z("`@("`B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!M86EL8F]X+G!H<#HT,C(@=&5M<&QA=&5S+V9O;&1E<G,O:&5A
M9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB
M"FUS9W-T<B`B*-JIV83;C-BO(-BOV+/8JMBQV+/;C"`E<RDB"@HC.B!L:6(O
M0V]M<&]S92YP:'`Z-#$R"FUS9VED("(@4W5B:F5C=#H@(@IM<V=S='(@(MBY
MV8;9B-BGV88Z("`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI
M;F,Z-S`*;7-G:60@(B!I;B`B"FUS9W-T<B`B(-BOV+$@(@H*(SH@=&5M<&QA
M=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHQ,@IM<V=I9"`B(R(*
M;7-G<W1R("(C(@H*(R`*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB
M"FUS9W-T<B`B)2XR9DU"("\@)2XR9DU"("`H)2XR9B4E*2(*"B,Z('1H<F5A
M9"YP:'`Z,34Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"!-97-S
M86=E<R(*;7-G<W1R("(E<R#9OMN,V+K8I]F%(@H*(R`*(SH@;6%I;&)O>"YP
M:'`Z,3<V"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&UE<W-A9V5S(&AA=F4@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("(E9"#9OMN,V+K8I]F%(-BMV+#9@2#8
MM-BOV8<@V*?8L]BJ(@H*(SH@;&EB+U-P86TN<&AP.C$W.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@;F]T('-P86T@=&\@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B)60@V;[;C-BZV*?9A2#8J-BYV8;9B-BGV88@V8?8L=BRV8;8I]F%
MV8<@V*C9AR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'V90@V+39A=BG(-JO
MV++8I]BQV+0@V+38K]F'(-BGV+/8JB(*"B,@"B,Z(&QI8B]3<&%M+G!H<#HQ
M-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;65S<V%G97,@:&%V92!B965N
M(')E<&]R=&5D(&%S(&YO="!S<&%M+B(*;7-G<W1R("(E9"#9OMN,V+K8I]F%
M(-BHV+G9AMF(V*?9AB#8NMN,V+$@V8?8L=BRV8;8I]F%V8<@VJ_8LMBGV+'8
MM"#8M-BOV8<@V*?8L]BJ(@H*(SH@;&EB+U-P86TN<&AP.C$W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@
M87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(E9"#9OMN,V+K8I]F%(-BHV+G9AMF(V*?9AB#9A]BQV++9AMBGV879AR#8
MJ-F'(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8?9E"#8M-F%V*<@VJ_8LMBG
MV+'8M"#8M-BOV8<@V*?8L]BJ(@H*(R`*(SH@;&EB+U-P86TN<&AP.C$U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!M97-S86=E<R!H879E(&)E96X@<F5P
M;W)T960@87,@<W!A;2XB"FUS9W-T<B`B)60@V;[;C-BZV*?9A2#8J-BYV8;9
MB-BGV88@V8?8L=BRV8;8I]F%V8<@VJ_8LMBGV+'8M"#8M-BOV8<@V*?8L]BJ
M(@H*(R`*(SH@;6%I;&)O>"YP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D('1O("5D(&]F("5D($UE<W-A9V5S(@IM<V=S='(@(B5D(-BJV*<@)60@
MV*?8LB`E9"#9OMN,V+K8I]F%(@H*(SH@;6%I;&)O>"YP:'`Z-C0P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(MJIVXS9A-F(V*C8I]N,
MV*H@)7,B"@HC(`HC.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]R96YA;65?<V5N
M=&UA:6Q?;6]N=&AL>2YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M86QR96%D>2!E>&ES=',N(%EO=7(@)7,@9F]L9&5R('=A<R!N;W0@<F5N86UE
M9"XB"FUS9W-T<B`B)7,@V*_8L2#8K=BGV80@V*W8I]BVV+$@V879B-BLV8C8
MKR#9A=N,XH",V*C8I]BTV*\NV;[9B-BTV8<@)7,@V+39A=BG(-BJV8';C-N,
MV+$@V8;8I]F%(-F&VXS8I]F!V*K9AR#8I]BSV*HB"@HC(`HC.B!L:6(O365S
M<V%G92YP:'`Z-C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(&UA:6QB;W@N(@IM<V=S='(@(B5S(-BH
MV8<@V8;8N-BQ(-F&V87;C.*`C-BQV+/8KR#:J=F'(-F&V*?9A=F'XH",V*_8
MI]F&(-F%V+G8JMBHV+';C"#8J-BGV+38KR(*"B,@"B,Z(&QI8B]-86EN=&5N
M86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H<#HT,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!F;VQD97(@8F5I;F<@<F5N86UE9"!A="!T
M:&4@<W1A<G0@;V8@=&AE(&UO;G1H+B(*;7-G<W1R("+9OMF(V+39AR5S(-BO
MV+$@V*?8J-BJV*_8I]N,(-F%V*?9AR#8JMF!VXS;C-BQ(-F&V*?9A2#;C-BG
MV8'8JMF'(-BGV+/8JB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&%C8V5P=&5D+B(*;7-G
M<W1R("(E<R#9OMBPVXS8L=F!V*K9AR#8M-BOV8<@V*?8L]BJ(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8R-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!H87,@8V%N8V5L;&5D("5S+B(*;7-G<W1R("(E<R`E<R#8L=BG(-F$
MV+K9B"#:J=BQV*_9AR#8I]BSV*HB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!D96-L:6YE
M9"XB"FUS9W-T<B`B)7,@V+'8KR#8M-BOV8<@V*?8L]BJ(@H*(SH@;&EB+TU)
M344O5FEE=V5R+VET:7`N<&AP.C0Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R
M("(E<R#8J-F'(-N,VJD@V*_8L=BNV8C8I]BSV*H@V*+8LMBGV*\OV878M-BZ
MV8C9A"#9OMBGV+/8KB#8K]BGV*_9AR#8I]BSV*HB"@HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z-C$V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA
M<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E
M<R#8J-F'(-BOV+G9B-BJ("5S(-F^V*?8L]BN(-BOV*?8K]F'(-BGV+/8JB(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`B)7,@V*?8M]F$V*?8N=BGV*H@V*+8LMBGV*\OV878M-BZ
MV8C9A"#8L=BG(-BHV8<@V+39A=BG(-F!V+'8L]BJV*?8K]F'(-BGV+/8JB(*
M"B,@"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HR-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S('1E;G1A=&EV96QY(&%C8V5P=&5D+B(*;7-G
M<W1R("(E<R#8J-BWV8C8L2#8HMBRV878I]N,V+3;C"#9OMBPVXS8L=F!V*K9
MAR#8M-BOV8<@V*?8L]BJ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@V*?8M]F$V*?8N=BG
MV*H@V*+8LMBGV*\OV878M-BZV8C9A"#8M-F%V*<@V+'8IR#8K]BQV*[9B-BG
MV+/8JB#8K]BGV+'8KR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S
M96YC92!A="`E<RXB"FUS9W-T<B`B)7,@V*W8MMF(V+$@V+39A=BG(-BQV*<@
MV*_8L2`E<R#8KMF(V*?8L]BJV*?8L2#8I]BSV*HB"@HC.B!L:6(O365S<V%G
M92YP:'`Z-#$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB"FUS9W-T<B`B)7,@V*C8
MIR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@)7,@V*?8MMBGV8'9AR#8M-BO(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!W:7-H97,@=&\@86UM96YD("5S+B(*;7-G<W1R("(E<R#9
MA=BGVXS9A"#8I]BSV*H@("5S(-BQV*<@V*?8M=F$V*?8K2#8L]BGV++8KR(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*
M;7-G<W1R("(E<R#9A=BGVXS9A"#8I]BSV*H@V+39A=BG(-BQV*<@V*?8LB`E
M<R#8J-BGV*[8J-BQ(-BSV*?8LMBO(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@
M<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+B(*;7-G
M<W1R("(E<R#9A=BGVXS9A"#8I]BSV*H@V*+8KMBQVXS9AB#8I]BWV838I]BY
MV*?8JB#8L=BGV*S8N2#8J-F'("5S(-BQV*<@V*_8L=N,V*?9@=BJ(-JIV8;8
MKR(*"B,Z(&UE<W-A9V4N<&AP.C(X-2!M97-S86=E+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,@"B,Z
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC.C$S"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S.B`E<R`H)60F;F)S<#MO9B9N8G-P.R5D*2(*;7-G
M<W1R("(E<SH@)7,@*"5D(-BGV+(@)60I(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C$S,PIM<V=I9"`B*$%P<&QY('1H97-E(&-H86YG
M97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(*;7-G<W1R("(HV*?8N=F%
MV*?9A"#8I]N,V88@V*K9@=N,VXS8L=BGV*H@V8@@V*?9AMBJV8+8I]F$(-BH
MV8<@V+79@=BMV8<@V*C8N=BO*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P
M96QL:6YG+FEN8SHQ,C`*;7-G:60@(BA$:7-C87)D(&%L;"!C:&%N9V5S(&%N
M9"!R971U<FX@=&\@=&AE(&-O;7!O<V4@<V-R965N+BDB"FUS9W-T<B`B*-F%
MV838NMN,(-JIV+'8K]F&(-BJV878I]F%VXP@V*K8NMN,VXS8L=BGV*H@V8@@
MV*C8I]BRVJ_8M-BJ(-BHV8<@V+79@=BMV8?9E"#8I]N,V*S8I]BO(-F^VXS8
MNMBGV84I(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$V
M"FUS9VED("(H2%1-3"DB"FUS9W-T<B`B*$A434PI(@H*(SH@=&5M<&QA=&5S
M+W-T871I;VYE<GDO<')E9G,N:6YC.C$V"FUS9VED("(H4&QA:6X@5&5X="DB
M"FUS9W-T<B`B*-F%V*K9AB#8L]BGV*_9ARDB"@HC.B!S<&5L;&EN9RYP:'`Z
M,C@P"FUS9VED("(B"B(H4F5T=7)N('1O('1H92!C;VUP;W-E('-C<F5E;B!A
M9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R+B`@(@HB
M0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@8F4@87!P
M;&EE9"XI(@IM<V=S='(@(B(*(BC8J-BGV++:K]BTV*H@V*C9AR#8M=F!V*W9
MAR#8I]N,V*S8I]BO(-F^VXS8NMBGV84@V*C8N=BO(-BGV+(@V*?8N=F%V*?9
MA"#8JMF%V*?9A=N,(-BJV+K;C-N,V+'8I]BJVXP@VJG9AR#8JMBGVJG9AMF(
MV88@V*?9AMBLV*?9A2#8M-BOV8<@(@HBV*K8NMN,VXS8L=BGV*H@V*_8L2#8
MM=F!V*W9AR#:J=F&V8C9AMN,(-BGV+G9A=BGV80@V8;8KMF(V*?9A]BO(-BT
MV*\H(@H*(SH@<W!E;&QI;F<N<&AP.C(W-PIM<V=I9"`B(@HB*%-E;F0@;65S
M<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M861E('1H=7,@9F%R
M+B`@0VAA;F=E<R!O;B!T:&4@(@HB8W5R<F5N="!S8W)E96X@=VEL;"!.3U0@
M8F4@87!P;&EE9"XI(@IM<V=S='(@(B(*(MBGV+'8L]BGV80@V;[;C-BZV*?9
MA2#8J-BYV*\@V*?8LB#8I]BYV878I]F$(-BJV878I]F%VXP@V*K8NMN,VXS8
ML=BGV*K;C"#:J=F'(-BJV*?:J=F&V8C9AB#8I]F&V*S8I]F%(-BTV*_9AR#8
MJMBZVXS;C-BQV*?8JB#8K]BQV+79@=BMV8<I("(*(MJIV8;9B-F&VXP@V*?8
MN=F%V*?9A"#9AMBNV8C8I]F'V*\@V+38KR@B"@HC.B!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C(R-PIM<V=I9"`B*B!!9&0@=&AE<V4@8GD@
M8VQI8VMI;F<@3TL@*B(*;7-G<W1R("(J(-BGV+;8I]F!V8<@VJG8L=BOV88@
MV*?;C-F&V8?8IR#8J-BG(-F!V+38I]BQ(-BOV*?8K]F&(-BOVJG9A=F'(-BJ
MV*/;C-N,V*\@*B(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI
M;F,Z,C`V"FUS9VED("(J(%!L96%S92!S96QE8W0@861D<F5S<RAE<RD@*B(*
M;7-G<W1R("(J(-F$V+?9@=BGV8L@V*+8K]BQV+,HV8?8IRD@V+'8IR#8I]F&
MV*K8KMBGV*@@VJG9AMN,V*\@*B(*"B,Z(&UA:6QB;W@N<&AP.C$W-`IM<V=I
M9"`B,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(MN,VJD@
MV;[;C-BZV*?9A2#8K=BPV8$@V+38K]F'(-BGV+/8JB(*"B,Z(&QI8B]3<&%M
M+G!H<#HQ.#`*;7-G:60@(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A
M<R!N;W0@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("+;C-JI(-F^VXS8NMBGV84@V*C8N=F&V8C8I]F&(-BZVXS8L2#9A]BQ
MV++9AMBGV879AR#8J-F'(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8?9E"#8
MM-F%V*<@VJ_8LMBGV+'8M"#8M-BOV8<@V*?8L]BJ(@H*(SH@;&EB+U-P86TN
M<&AP.C$V,`IM<V=I9"`B,2!M97-S86=E(&AA<R!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M+B(*;7-G<W1R("+;C-JI(-F^VXS8NMBGV84@V*C8N=F&V8C8
MI]F&(-BZVXS8L2#9A]BQV++9AMBGV879AR#:K]BRV*?8L=BT(-BTV*_9AR#8
MI]BSV*HB"@HC.B!L:6(O4W!A;2YP:'`Z,3<R"FUS9VED("(Q(&UE<W-A9V4@
M:&%S(&)E96X@<F5P;W)T960@87,@<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("+;C-JI(-F^VXS8NMBGV84@V*C8N=F&V8C8
MI]F&(-F'V+'8LMF&V*?9A=F'(-BHV8<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BG
MV8;9A]F4(-BTV878IR#:K]BRV*?8L=BT(-BTV*_9AR#8I]BSV*HB"@HC.B!L
M:6(O4W!A;2YP:'`Z,34R"FUS9VED("(Q(&UE<W-A9V4@:&%S(&)E96X@<F5P
M;W)T960@87,@<W!A;2XB"FUS9W-T<B`BVXS:J2#9OMN,V+K8I]F%(-BHV+G9
MAMF(V*?9AB#9A]BQV++9AMBGV879AR#:K]BRV*?8L=BT(-BTV*_9AR#8I]BS
MV*HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#$Y"FUS9VED("(Q,#`@
M8VAA<F%C=&5R<R(*;7-G<W1R("+;L=NPV[`@V8;9B-N,V+/9AR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,C(*;7-G:60@(C$P,#`@8VAA<F%C=&5R
M<R(*;7-G<W1R("+;L=NPV[#;L"#9AMF(VXS8L]F'(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R,`IM<V=I9"`B,C4P(&-H87)A8W1E<G,B"FUS9W-T
M<B`BV[+;M=NP(-F&V8C;C-BSV8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#(Q"FUS9VED("(U,#`@8VAA<F%C=&5R<R(*;7-G<W1R("+;M=NPV[`@
MV8;9B-N,V+/9AR(*"B,@"B,Z(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C$V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!(&QA<F=E(&EM86=E(&YA;65D
M("5S(&ES(&%T=&%C:&5D('1O('1H:7,@;65S<V%G92XB"FUS9W-T<B`BVXS:
MJ2#8JMBUV8C;C-BQ(-BHV++8L=JO(-BHV8<@V8;8I]F%("5S(-BHV8<@V;[;
MC-BZV*?9A2#8M-F%V*<@V;[;C-F(V+/8JB#8M-BOV8<@V*?8L]BJ(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3`*;7-G:60@(B(*
M(D$@;65S<V%G92!Y;W4@:&%V92!S96YT(&AA<R!R97-U;'1E9"!I;B!A(')E
M='5R;B!N;W1I9FEC871I;VX@9G)O;2!T:&4@(@HB<F5C:7!I96YT+B(*;7-G
M<W1R("+9AMBJVXS8K-F'(-BGV+'8L]BGV80@V;[;C-BZV*?9A2#8M-F%V*<@
MVXS:J2#8L=BSVXS8KR#8I]BR(-BOV+';C-BGV8'8JB#:J=F&V8;8K]F'(-F%
MVXSB@(S8J-BGV+38KR(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE;&1S+FEN
M8SHU"FUS9VED(")!3D0B"FUS9W-T<B`BV8@B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-3DP"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R
M("+9OMBPVXS8L=F!V*K9AB#8K]BQV*[9B-BGV+/8JB(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.#<*(RP@9G5Z>GD*;7-G:60@(D%C8V5P="!R
M97%U97-T(&%N9"!A9&0@:70@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`BV+'9
MB-N,V*_8I]BO(-BHV8<@V*K9@MF(VXS9A2#8M-F%V*<@V*?8MMBGV8'9AR#8
MM-BOV8<@V*C9B-BO(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<U
M,PIM<V=I9"`B06-C97!T960B"FUS9W-T<B`BV;[8L-N,V+'9@=BJV8<@V+38
MK]F'(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C(U-PIM<V=I9"`B
M06-C97!T960Z("(*;7-G<W1R("+9OMBPVXS8L=F!V*K9AR#8M-BOV8<Z(@H*
M(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C<*;7-G:60@(D%C
M8V]U;G0G<R!N86UE.B(*;7-G<W1R("+9AMBGV84@V*W8L]BGV*CB@(PZ(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4R,"!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S,P"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(MF!V+G8
MI]F$VXS8JMF'V*<B"@HC.B!L:6(O34E-12](96%D97)S+G!H<#HR,#`@;&EB
M+TU)344O2&5A9&5R<RYP:'`Z,C`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@)7,@=&\@;7D@061D<F5S<R!";V]K(@IM<V=S='(@(MBGV+;8
MI]F!V8<@VJG8L=BOV88@V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR`H
M)7,I(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`S
M"FUS9VED(")!9&0@<V]U<F-E(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BO
MV88@V+/8L=J&V+39A=F'("(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HU-S<@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4X.`IM<V=I9"`B061D
M('1H:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQ
MV*_9AB#8I]N,V88@V*C9AR#8JMF"V8C;C-F%(-F%V88B"@HC(`HC.B!C;VUP
M;W-E+G!H<#HQ,C4V"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<
M(B!A<R!A;B!A='1A8VAM96YT+B(*;7-G<W1R(")<(B5S7"(@V*C8N=F&V8C8
MI]F&(-F^VXS9B-BSV*H@V*?8MMBGV8'9AR#8M-BO(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Y.`IM<V=I9"`B(@HB061D:71I;VYA;"!H96%D97)S
M('1O(&1I<W!L87D@=VAE;B!V:65W:6YG.B`\96T^*&]P=&EO;F%L+"!E;G1E
M<B!E86-H(&AE861E<B`B"B)O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@
M(B(*(MBSV+'8HMF%V*_9A]BGVXP@V*?8MMBGV8';C"#8J-BQV*?;C"#9AMF%
MV*?;C-BT(-BHV8<@V8?9AMJOV*?9A2#9A=BTV*?9A]BOV8<Z(#QE;3X@*-F'
MV+$@V+/8L=BBV878KR#8L=BG(-BOV+$@VXS:J2#8KMBW(-BLV*_;C-BO("(*
M(MF(V*?8L=BO(-JIV8;;C-BOV(P@V*?8KMBJVXS8I]BQVXPI(#PO96T^(@H*
M(R`*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D:71I;VYA;"!I;F9O<FUA=&EO;B!C86X@
M8F4@=FEE=V5D("5S+B(*;7-G<W1R("+8I]BWV838I]BYV*?8JB#8I]BVV*?9
M@=N,(-F%VXSB@(S8JMF(V*?9AMF&V*\@V*_8L2`E<R#8K]N,V*_9AR#8M-F(
MV8;8KR(*"B,Z(&QI8B]-24U%+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8R
M"FUS9VED(")!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&1E=&%I;',B"FUS9W-T
M<B`BV*S8LMBFVXS8I]BJ(-BGV+;8I]F!VXP@V*?8M]F$V*?8N=BGV*HB"@HC
M.B!L:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HY,PIM<V=I9"`B061D:71I
M;VYA;"!M97-S86=E(&1E=&%I;',B"FUS9W-T<B`BV*S8LMBFVXS8I]BJ(-BG
MV+;8I]F!VXP@V;[;C-BZV*?9A2(*"B,@"B,Z(&QI8B]-24U%+U9I97=E<B]S
M=&%T=7,N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&ET:6]N86P@
M;65S<V%G92!D971A:6QS(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(MBL
MV++8IMN,V*?8JB#8I]BVV*?9@=N,(-F^VXS8NMBGV84@V87;C.*`C-BJV8C8
MI]F&V8;8KR#8K]BQ("5S(-BOVXS8K]F'(-BTV8C9AMBO(@H*(SH@;&EB+TU)
M344O5FEE=V5R+W-T871U<RYP:'`Z-S@*;7-G:60@(D%D9&ET:6]N86P@;65S
M<V%G92!E<G)O<B!D971A:6QS(@IM<V=S='(@(MBLV++8IMN,V*?8JB#8I]BV
MV*?9@=N,(-BNV+?8I]N,(-F^VXS8NMBGV84B"@HC(`HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1I
M=&EO;F%L(&UE<W-A9V4@97)R;W(@9&5T86EL<R!C86X@8F4@=FEE=V5D("5S
M+B(*;7-G<W1R("+8K-BRV*;;C-BGV*H@V*?8MMBGV8';C"#8KMBWV*?;C"#9
MOMN,V+K8I]F%(-F%VXSB@(S8JMF(V*?9AMF&V*\@V*_8L2`E<R#8K]N,V*_9
MAR#8M-F(V8;8KR(*"B,Z(&-O;G1A8W1S+G!H<#HX-2!T96UP;&%T97,O8V]N
M=&%C=',O8V]N=&%C=',N:6YC.C$X,`HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHS,SD@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N:6YC
M.C4R"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`BVJG8JMBGV*C:AMF'
MV90@V*+8K]BQV+,@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`IM
M<V=I9"`B061D<F5S<R!";V]K<R(*;7-G<W1R("+:J=BJV*?8J-J&V8?B@(S9
MA]BGVXP@V*+8K]BQV+,@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B(@HB061D<F5S<V5S('1O($)#0R!A;&P@;65S<V%G97,Z(#QE
M;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@861D<F5S<R!O;B!A(&YE=R`B"B)L
M:6YE*3PO96T^(@IM<V=S='(@(B(*(MBBV*_8L=BSV8?8I]N,VXP@V*C8L=BG
MVXP@V+'9B-F&V8C8M-BJ(-F%V*[9@=N,(-BJV878I]F%(-F^VXS8NMBGV879
MA]BG.B`\96T^*-F'V+$@V+/8L=BBV878KR#8L=BG(-BOV+$@VXS:J2#8KMBW
M(-BLV*_;C-BO(-F(V*?8L=BO("(*(MJIV8;;C-BOV(P@V*?8KMBJVXS8I]BQ
MVXPI(#PO96T^(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,0IM<V=I
M9"`B(@HB061D<F5S<V5S('1O(&5X<&QI8VET;'D@=&EE('1O('1H:7,@:61E
M;G1I='DZ(#QE;3XH;W!T:6]N86PL(&5N=&5R(&5A8V@@(@HB861D<F5S<R!O
M;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*(MBBV*_8L=BSV8?8I]N,
MVXP@V*C8L=BGVXP@V878JMBUV80@V+38K]F&(-BHV8<@V*?;C-F&(-F%V+38
MKMBUV8<Z(#QE;3XHV8?8L2#8L]BQV*+9A=BO(-BQV*<@V*_8L2#;C-JI(-BN
MV+<@V*S8K]N,V*\@V8C8I]BQV*\@(@HBVJG9AMN,V*_8C"#8I]BNV*K;C-BG
MV+';C"D\+V5M/B(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z
M,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R,PIM<V=I9"`B06QL(@IM<V=S
M='(@(MF'V879AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N
M:G,Z,3,*;7-G:60@(B(*(D%L;"!M97-S86=E<R!I;B!T:&4@9F]L;&]W:6YG
M(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D960@:6YT;R!O;F4@34)/6"`B
M"B)F:6QE.B(*;7-G<W1R("+8JMF%V*?9A=N,(-F^VXS8NMBGV879A]BG(-BO
MV+$@V*?;C-F&(-F^V8C8M-F'*-F'V*<I(-BOV+$@VXS:J2`@V8;8I]F%V8?B
M@(S8K]BGV88@V*?8L]BJV8+8L=BGV+$@V*[9B-BGV8?8KR#;C-BGV8'8JB(*
M"B,@"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U<F=E7W1R87-H+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!;&P@;65S<V%G97,@:6X@>6]U
M<B!<(B5S7"(@9F]L9&5R(&]L9&5R('1H86X@)7,@9&%Y<R!W:6QL(&)E('!E
M<FUA;F5N=&QY("(*(F1E;&5T960N(@IM<V=S='(@(B(*(B#8JMF%V*?9A=N,
M(-F^VXS8NMBGV879A]BGVXP@V+39A=BG(-BOV+$@V;[9B-BTV8<@(%PB)7-<
M(B`@VJG9AR#9@MBOVXS9A=N,XH",V*K8L>*`C"#8I]BR("`E<R#8L=F(V+(@
MV*C8I]BTV8;8KR#8J-F'(-BWV8C8L2`B"B+9A]F%VXS8M-JOVXP@V*W8L-F!
M(-BNV8C8I]F'V8;8KR#8M-BO(@H*(R`*(SH@;&EB+TUA:6YT96YA;F-E+U1A
M<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP.C4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D%L;"!O;&0@;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@
M=&AA;B`E<R!M;VYT:',@;VQD('=I;&P@8F4@9&5L971E9"XB"FUS9W-T<B`B
MV*K9A=BGV87;C"#8MMF%VXS9A=F'XH",V8?8I]N,(-F"V*_;C-F%VXSB@(S8
MJMBQXH",(-BGV+(@("5S("#9A=BGV8<@V*W8L-F!(-BNV8C8I]F'V8;8KR#8
MM-BO(@H*(R`*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M
M86EL7VUO;G1H;'DN<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D%L;"!O
M;&0@<V5N="UM86EL(&9O;&1E<G,@;6]R92!T:&%N("5S(&UO;G1H<R!O;&0@
M=VEL;"!B92!D96QE=&5D+B(*;7-G<W1R("+8JMF%V*?9A=N,(-F&V*?9A=F'
MXH",V8?8I]N,(-BGV+'8L]BGV80@V+38K]F'V90@V8+8K]N,V87;C.*`C-BJ
MV+'B@(P@V*?8LB`@)7,@(-F%V*?9AR#8K=BPV8$@V*[9B-BGV8?9AMBO(-BT
MV*\B"@HC(`HC.B!A8VPN<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!;&P@<FEG:'1S(&]N(&9O;&1E<B!<(B5S7"(@<W5C8V5S<V9U;&QY
M(')E;6]V960@9F]R('5S97(@7"(E<UPB+B(*;7-G<W1R("+8JMF%V*?9A=N,
M(-BMV8+9B-F"(-BHV+$@V;[9B-BTV8<@)R5S)R#8J-BG(-F%V8C9@=F1V8+;
MC-F1V*H@V*C8L=BGVXP@VJG8I]BQV*C8L2`G)7,G(-BMV+#9@2#8M-BO(@H*
M(SH@;&EB+V%P:2YP:'`Z-S8*;7-G:60@(D%L;&]W($9O;&1E<B!#<F5A=&EO
M;C\B"FUS9W-T<B`BV*?;C-BLV*?8KR#9OMF(V+39AR#9A=BLV*?8LB#8I]BS
MV*K8GR(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHT.`IM<V=I
M9"`B06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA
M:6QB;W@_(@IM<V=S='(@(MBBVXS8IR#8J-BQV*?;C"#9A]BQ(-F&V*?9A=F'
MXH",V*_8I]F&(-F"V8C8I]F&VXS9AB#9@=N,V838JMBQ(-BGV+G9A=BGV80@
MV+39B-BOV)\B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP
M.C$Q,`IM<V=I9"`B06QT97)N871I=F4@<&%R=',@9F]R('1H:7,@<V5C=&EO
M;CHB"FUS9W-T<B`BV*C8KMBTV8?8I]N,(-BLV*?;C-JOV++;C-F&(-BHV+'8
MI]N,(-BGVXS9AB#9@MBSV878JCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3<R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU.#0*;7-G:60@(D%L=V%Y
M<R(*;7-G<W1R("+9A]F%VXS8M-F'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4U-PIM<V=I9"`B06QW87ES('-A=F4@871T86-H;65N=',B"FUS9W-T
M<B`BV8?9A=F(V*?8L=F'(-F^VXS9B-BSV*K9A]BG(-BMV8'8N"#8M-F(V8;8
MKR(*"B,Z(&QI8B]-97-S86=E+G!H<#HU,#4*;7-G:60@(B(*(D%N(&5R<F]R
M(&]C8W5R960@=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H
M;65N="X@5&AE($E-05`@<V5R=F5R("(*(G-A:60Z("(*;7-G<W1R("+:J=BG
MV+'8L]BGV+(@24U!4"#:K]F!V*K9AR#8I]BSV*HZ(-BNV+?8I]N,VXP@V*_8
ML2#:K]BQV8'8JMF&(-BVV87;C-F%V8<@V+'8KB#8K]BGV*_9AR#8I]BSV*H@
M(@H*(SH@;&EB+TUE<W-A9V4N<&AP.C,X.`HC+"!F=7IZ>0IM<V=I9"`B06X@
M=6YK;F]W;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@
M;F]T92XB"FUS9W-T<B`BV*[8M]BGVXS;C"#9AMBGV+39AMBGV+,@V*_8L2#8
MK=N,V88@V*?;C-BLV*?8KR#;C-JI(-F(V+C;C-F!V8?9E"#8K-BOVXS8KR#8
ML=BN(-BOV*?8K]F'(-BGV+/8JB(*"B,Z(&QI8B]-97-S86=E+G!H<#HS.#<*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@;V-C=7)E9"!W:&EL92!C<F5A=&EN
M9R!T:&4@;F5W('1A<VLN(@IM<V=S='(@(MBNV+?8I]N,VXP@V8;8I]BTV8;8
MI]BS(-BOV+$@V*W;C-F&(-BGVXS8K-BGV*\@VXS:J2#9B-BXVXS9@=F'V90@
MV*S8K]N,V*\@V+'8KB#8K]BGV*_9AR#8I]BSV*HB"@HC.B!M97-S86=E+G!H
M<#HU,#`@;6%I;&)O>"YP:'`Z-S$T('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N
M:6YC.C$X('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,S4*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHV"FUS9VED(")!;G-W97)E9"(*
M;7-G<W1R("+9OMBGV+/8KB#8K]BGV*_9AR#8M-BOV8<B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C,Q"FUS9VED(")!;G-W97)E9"!M97-S86=E
M<R(*;7-G<W1R("+9OMN,V+K8I]F%V8?8I]N,(-F^V*?8L]BN(-BOV*?8K]F'
M(-BTV*_9AR(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z-PIM
M<V=I9"`B07!P;'D@1FEL=&5R<R(*;7-G<W1R("+8I]BYV878I]F$(-F!VXS9
MA-BJV+'9A]BG(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:&5A9&5R+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%P<&QY($9I;'1E<G,@=&\@)7,B"FUS
M9W-T<B`BV*?8N=F%V*?9A"#9@=N,V838JMBQV8?8IR#8J-F'("5S(@H*(SH@
M=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,V"FUS9VED(")!<'!L>2!F
M:6QT97(@<G5L97,@=7!O;B!L;V=G:6YG(&]N/R(*;7-G<W1R("+8HMN,V*<@
MV8+9B-BGV8;;C-F&(-F!VXS9A-BJV+$@V*C9AR#9A]F&VJ_8I]F%(-F(V+'9
MB-BO(-BGV+G9A=BGV80@V+39B-BOV)\B"@HC.B!T96UP;&%T97,O9FEL=&5R
M<R]P<F5F<RYI;F,Z-#(*;7-G:60@(D%P<&QY(&9I;'1E<B!R=6QE<R!W:&5N
M979E<B!)3D)/6"!I<R!D:7-P;&%Y960_(@IM<V=S='(@(B(*(MBBVXS8IR#9
M@MF(V*?9AMN,V88@V8';C-F$V*K8L2#8K]BQ(-F'V8;:K]BGV87;C"#:J=F'
M(-F^VXS8NMBGV879A]BGVXP@V*_8L=N,V*?9@=BJVXP@V8;9A=BGVXS8M"#8
MK]BGV*_9AR#9A=N,XH",V+39B-BOV(P@V*?8N=F%V*?9A"#8M-F(V*_8GR(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,C4@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(W"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&5L971E('1H:7,@<'5B;&EC(&ME>3\B"FUS9W-T<B`BV*+;C-BG(-F%V+?9
MA=BFV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]N,V88@VJG9
MA-N,V*\@V+G9A=F(V87;C"#8L=BG(-BMV+#9@2#:J=F&VXS8K]B?(@H*(SH@
M=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW.2!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z.#4*;7-G:60@(B(*(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D
M96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD960A
M*2(*;7-G<W1R("(B"B+8HMN,V*<@V878M]F%V*;9AMN,V*\@VJG9AR#9A=N,
MXH",V*[9B-BGV8?;C-BO(-BLV8'8JB#:J=F$VXS8KR#8KMF(V*\@V+'8IR#8
MK=BPV8$@VJG9AMN,V*_8GR`HV*?;C-F&(-JIV*?8L2#9OMN,V+39AMF'V*?8
MKR#9AMF%VXSB@(S8M-F(V*\I(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@9&\@=&AI<S\B"FUS9W-T
M<B`BV878M]F%V*;9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BG
MVXS9AB#:J=BGV+$@V+'8IR#8I]F&V*S8I]F%(-BOV8?;C-BOV)\B"@HC.B!M
M97-S86=E+G!H<#HT,#<@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI
M;F,Z-C@*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!015)-04Y%
M3E1,62!D96QE=&4@=&AE<V4@;65S<V%G97,_(@IM<V=S='(@(MBBVXS8IR#9
MA=BWV878IMF&VXS8KR#:J=F'(-BHV8<@V+?9B-BQ(-F'V87;C-BTVJ_;C"#9
MA=N,XH",V*[9B-BGV8?;C-BO(-BGVXS9AB#9OMN,V+K8I]F%V8?8IR#8L=BG
M(-BMV+#9@2#:J=F&VXS8K]B?(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP
M.C(Q-0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.
M5$Q9(&1E;&5T92!T:&ES(&%T=&%C:&UE;G0_(@IM<V=S='(@(MBBVXS8IR#9
MA=BWV878IMF&VXS8KR#:J=F'(-BHV8<@V+?9B-BQ(-F'V87;C-BTVJ_;C"#9
MA=N,XH",V*[9B-BGV8?;C-BO(-BGVXS9AB#9OMN,V8C8L]BJ(-BQV*<@V*W8
ML-F!(-JIV8;;C-BOV)\B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHS.0IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y
M('1H:7,@9F]L9&5R/R(*;7-G<W1R("+8HMN,V*<@V878M]F%V*;9AMN,V*\@
MVJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGVXS9AB#9OMF(V+39AR#8L=BG
M(-BNV*?9A-N,(-JIV8;;C-BOV)\B"@HC.B!L:6(O24U0+G!H<#HY-S,*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!E;7!T>2!Y;W5R('-P86T@
M9F]L9&5R/R(*;7-G<W1R("+8HMN,V*<@V878M]F%V*;9AMN,V*\@VJG9AR#9
MA=N,XH",V*[9B-BGV8?;C-BO(-F^V8C8M-F'V90@V8?8L=BRV8;8I]F%V8?B
M@(S9A]BGVXP@V*[9B-BO(-BQV*<@V*[8I]F$VXP@VJG9AMN,V*_8GR`B"@HC
M.B!L:6(O24U0+G!H<#HY-C8*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!E;7!T>2!Y;W5R('1R87-H(&9O;&1E<C\B"FUS9W-T<B`BV*+;C-BG
M(-F%V+?9A=BFV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#9OMF(
MV+39A]F4(-BBV+38NMBGV80@V*[9B-BO(-BQV*<@V*[8I]F$VXP@VJG9AMN,
MV*_8GR`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHX"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<&5R;6%N96YT;'D@9&5L
M971E('1H97-E(&UE<W-A9V5S/R(*;7-G<W1R("+8HMN,V*<@V878M]F%V*;9
MAMN,V*\@VJG9AR#8J-F'(-BWV8C8L2#9A]F%VXS8M-JOVXP@V87;C.*`C-BN
MV8C8I]F'VXS8KR#8I]N,V88@V;[;C-BZV*?9A=F'V*<@V+'8IR#8K=BPV8$@
MVJG9AMN,V*_8GR(*"B,Z('1E;7!L871E<R]M97-S86=E+VIA=F%S8W)I<'0N
M:6YC.C@P('1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I<'0N:6YC.C<Y"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@<F5P;W)T('1H:7,@;65S
M<V%G92!A<R!I;FYO8V5N=#\B"FUS9W-T<B`BV*+;C-BG(-F%V+?9A=BFV8;;
MC-BO(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]N,V88@V;[;C-BZV*?9
MA2#8L=BG(-BHV+G9AMF(V*?9AB#8J-N,XH",V+;8L=BQ(-JOV++8I]BQV+0@
MVJG9AMN,V*_8GR`B"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T
M+FEN8SHW-2!T96UP;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHW-`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE
M<W-A9V4@87,@<W!A;3\B"FUS9W-T<B`BV*+;C-BG(-F%V+?9A=BFV8;;C-BO
M(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]N,V88@V;[;C-BZV*?9A2#8
ML=BG(-BHV+G9AMF(V*?9AB#9A]BQV++9AMBGV879AR#:K]BRV*?8L=BT(-JI
MV8;;C-BOV)\@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ-@IM<V=I
M9"`B07)R:79A;"!4:6UE(@IM<V=S='(@(MBRV878I]F&(-BQV+/;C-BOV88B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,Q"FUS9VED(")!<V-E;F1I
M;F<B"FUS9W-T<B`BV+78N=F(V*_;C"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X,PIM<V=I9"`B07-K
M(@IM<V=S='(@(MF^V+'8L]BT(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-3$Y"FUS9VED(")!='1A8V@B"FUS9W-T<B`BV;[;C-F(V+/8
MJB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C0W-0IM<V=I
M9"`B071T86-H($9I;&5S(@IM<V=S='(@(MF^VXS9B-BSV*H@VJG8L=BOV88@
MV;[8L=F(V8;8K]F'XH",V8?8IR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O
M;7!O<V4N:6YC.C0U-@IM<V=I9"`B071T86-H(&$@8V]P>2!O9B!Y;W5R(%!'
M4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G93\B"FUS9W-T<B`BV*+;C-BG
M(-N,VJD@V+'9B-F&V8C8M-BJ(-BGV+(@VJG9A-N,V*\@V+G9A=F(V87;C"!0
M1U`@V+39A=BG(-BHV8<@V;[;C-BZV*?9A=BJV*?9AB#9OMN,V8C8L]BJ(-BT
MV8C8K]B?(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N<&AP.C$P.0IM<V=I
M9"`B071T86-H960@1FEL93HB"FUS9W-T<B`BV;[8L=F(V8;8K]F'XH",V8?8
MI]N,(-F^VXS9B-BSV*H@V+38K]F'.B(*"B,@"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HT-3$@;&EB+T-O;7!O<V4N<&AP.C4S-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!='1A8VAE9"!F:6QE(%PB)7-<(B!E>&-E961S('1H92!A='1A8VAM
M96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A='1A8VAE9"XB"FUS9W-T<B`B
MV;[8L=F(V8;8K]F'V93B@(P@V;[;C-F(V+/8JB#8M-BOV8?9E"!<(B5S7"(@
MV*?8LB#8I]F&V*_8I]BRV8<@V878K-BGV+(@V*C;C-BTV*K8L2#8I]BSV*HN
M(-F^V+'9B-F&V*_9A^*`C"#9OMN,V8C8L]BJ(-F&V+38KR(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HS-S8*;7-G:60@(D%T=&%C:&5D(&ES(&$@
M<F5P;'D@=&\@82!C86QE;F1A<B!R97%U97-T('EO=2!S96YT+B(*;7-G<W1R
M("+9OMN,V8C8L]BJ(-F^V*?8L]BN(-BHV8<@V*_8L=BNV8C8I]BSV*H@V*K9
M@MF(VXS9A=N,(-BGV+/8JB#:J=F'(-BTV878IR#9@=BQV+/8JMBGV*_;C-BO
M(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-B!T96UP;&%T
M97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,30*(SH@=&5M<&QA=&5S+V-O
M;7!O<V4O8V]M<&]S92YI;F,Z-3`V('1E;7!L871E<R]C;VUP;W-E+V%T=&%C
M:&UE;G1S+FIS.CDW"FUS9VED(")!='1A8VAM96YT(@IM<V=S='(@(MF^VXS9
MB-BSV*HB"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT
M-C8*;7-G:60@(D%T=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C
M:&UE;G0@='EP92(*;7-G<W1R("+9OMN,V8C8L]BJ(-BGV*[8L"#8M-BO.B#9
MAMF(V+D@V*?8M=F$VXP@V;[;C-F(V+/8JB(*"B,Z('1E;7!L871E<R]C;VUP
M;W-E+V-O;7!O<V4N:6YC.C,T.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT-S,*(SH@;&EB+T-O;7!O<V4N<&AP.C$P-S,*;7-G:60@(D%T=&%C
M:&UE;G1S(@IM<V=S='(@(MF^VXS9B-BSV*K9A]BG(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C8X,@IM<V=I9"`B071T96YD965S(@IM<V=S='(@
M(MBTV+':J=BJ(-JIV8;9AMBOV8?B@(S9A]BG(@H*(SH@;&EB+TU)344O5FEE
M=V5R+VYO=&EF:6-A=&EO;BYP:'`Z-3,*;7-G:60@(D%T=&5N=&EO;B(*;7-G
M<W1R("+8JMF(V*S9AR(*"B,Z(&QI8B]!=71H+VEM<"YP:'`Z-#0*;7-G:60@
M(D%U=&A?:6UP.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&AI;7`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!)
M34%0(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-#`*;7-G:60@(B(*(D%U=&]M871I8V%L;'D@<VAO=R!I;6%G97,@:6X@
M2%1-3"!M97-S86=E<R!W:&5N('1H92!S96YD97(@:7,@:6X@;7D@(@HB861D
M<F5S<V)O;VL_(@IM<V=S='(@(B(*(MBBVXS8IR#9B-F"V*K;C"#9@=BQV+/8
MJMF&V*_9AR#8K]BQ(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F%V88@V*C8
MI]BTV*\@V*K8M=BGV8C;C-BQ(-BHV+?9B-BQ(-BNV8C8K]JIV*?8L2#8K]BQ
M(-F^VXS8NMBGV879A]BGVXP@2%1-3"`B"B+9AMBTV*?9AB#8K]BGV*_9AR#8
MM-F(V8;8K]B?(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI
M;F,Z,CDX"FUS9VED(")!=F%I;&%B;&4@061D<F5S<R!B;V]K<SHB"FUS9W-T
M<B`BVJG8JMBGV*C:AMF'XH",V8?8I]N,(-BBV*_8L=BS(-BOV+$@V*_8L]BJ
MV+'8LSHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S$Y"FUS9VED
M(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R("+9A=F&V*K8N-BQ(-F^V*?8
ML]BN(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8SHR-@HC+"!P:'`M9F]R;6%T"FUS9VED(")"86-?:R!T;R`E<R(*;7-G<W1R
M("+8J-BGV++:K]BTV*H@V*C9AR`E<R(*"B,@"B,Z('1H<F5A9"YP:'`Z,3,W
M('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,C8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%C:R!T;R`E<R(*;7-G<W1R("+8J-BGV++:
MK]BTV*H@V*C9AR`E<R(*"B,Z('1H<F5A9"YP:'`Z,3,T"FUS9VED(")"86-K
M('1O($UU;'1I<&QE($UE<W-A9V4@5FEE=R!);F1E>"(*;7-G<W1R("+8J-BG
MV++:K]BTV*H@V*C9AR#8M-BGV*[8M2#9AMF%V*?;C"#:AMF&V*_:K]BGV8;9
MA]F4(-F^VXS8NMBGV84B"@HC.B!T:')E860N<&AP.C$S,@IM<V=I9"`B0F%C
M:R!T;R!4:')E860@1&ES<&QA>2(*;7-G<W1R("+8J-BGV++:K]BTV*H@V*C9
MAR#9A=BO(-F&V878I]N,V+0@V+/9A-BSV8?B@(S8I]N,VXPB"@HC.B!L:6(O
M24U!4"]#;&EE;G0N<&AP.C,X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")"860@
M;W(@;6%L9F]R;65D(')E<75E<W0N(%-E<G9E<B!297-P;VYD960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&UE<W-A9V4N<&AP.C(V-B!T96UP;&%T97,O8V]N=&%C
M=',O8V]N=&%C=',N:6YC.C(R,@HC.B!T96UP;&%T97,O8V]M<&]S92]R96-O
M;7!O<V4N:6YC.C(P(&QI8B]396%R8V@N<&AP.C,T"FUS9VED(")"8V,B"FUS
M9W-T<B`BV+'9B-F&V8C8M-BJ(-F%V*[9@=N,(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,38Q"FUS9VED(")"96QO=R!I<R!T:&4@<F%W('1E
M>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+B(*;7-G<W1R
M("+8K]BQ(-BRVXS8L2#9A=BJV8;;C"#8I]BR(-BGV+?9A-BGV+G8I]BJ(-F(
MV+;8N=N,V*H@V;[;C-BZV*?9A2#9B-BLV8C8KR#8K]BGV+'8KR(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHR,2!T96UP;&%T
M97,O;6%I;&)O>"]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B0FQA8VML:7-T(@IM
M<V=S='(@(MF$VXS8L]BJ(-BSVXS8I]F'(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8R.0IM<V=I9"`B0FQO8VL@:6UA9V5S(&EN($A434P@;65S<V%G
M97,@=6YL97-S('1H97D@87)E('-P96-I9FEC86QL>2!R97%U97-T960_(@IM
M<V=S='(@(B(*(MBBVXS8IR#8JMBUV*?9B-N,V+$@V*_8L2#9OMN,V+K8I]F%
MV8?8I]N,($A434P@V*C8K-BR(-BOV+$@V879B-BGV+'8K]N,(-JIV8<@V878
MM-BNV+78I]F+(-BOV+'8KMF(V*?8L]BJ(-F&V+38K]F'XH",V*?9AMBOV(P@
MV*C9A-F(VJG9AR`B"B+8M-F(V8;8K]B?(@H*(SH@;&EB+U-E87)C:"YP:'`Z
M-#(*;7-G:60@(D)O9'DB"FUS9W-T<B`BV*C8K]F&V8<B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C(S('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z,SD*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHU-2!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C<Q"FUS9VED(")";W1H(@IM<V=S='(@(MF'
MV+$@V*_9B"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#<*;7-G:60@
M(D)O=&@@2&5A9&5R($QI<W1I;F<@86YD($)O9'D@;V8@365S<V%G92(*;7-G
M<W1R("+9@=F'V+'8L]BJ(-BSV+'8HMF%V*\@V8@@V*C8K]F&V8<@V;[;C-BZ
MV*?9A=B,(-F'V+'8K]F((@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C<R"FUS9VED(")#7VAA<G-E="(*;7-G<W1R("+9A=BLV879B-BY
MV8?9E"#9AMF(VXS8L]F'(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N
M:6YC.C,V"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+8JMF"V8C;C-F%(@H*
M(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HR,#$*;7-G:60@(D-A;B!N;W0@
M8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB#9OMBSV*H@V*?9
MA-JIV*K8L=F(V8;;C-JI(-BQV*?9AR#8K]F(V+$@V8C8M=F$(-BTV*\B"@HC
M.B!L:6(O1F5T8VAM86EL+VEM87`N<&AP.C$Y.0IM<V=I9"`B0V%N(&YO="!C
M;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(Z("(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB#9OMBSV*H@V*?9
MA-JIV*K8L=F(V8;;C-JI(-BQV*?9AR#8K]F(V+$@V8C8M=F$(-BTV*\Z(@H*
M(R`*(SH@;&EB+TU)344O5FEE=V5R+W!A<G1I86PN<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@
M)7,@;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT
M("(*(FUA:6QB;W@N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F&V878
MI]N,V+0@V*_8I]BO("T@V*K9AMF'V*<@)7,@V*?8LB`E<R#8J-BNV+0@V*?;
MC-F&(-F^VXS8NMBGV84@V*_8L2#8I]N,V88@V8;8I]F%V8?B@(S8K]BGV88@
MV;[;C-BOV*<@V+38KR(*"B,Z(&9O;&1E<G,N<&AP.C(X-"!T96UP;&%T97,O
M8V]N=&%C=',O8V]N=&%C=',N:6YC.C(U-0HC.B!T96UP;&%T97,O9F]L9&5R
M<R]I;7!O<G0N:6YC.C(Q('1E;7!L871E<R]S879E:6UA9V4O<V%V96EM86=E
M+FEN8SHQ.0HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,C$@
M=&5M<&QA=&5S+W-M:6UE+VEM<&]R=%]K97DN:6YC.C@V"B,Z('1E;7!L871E
M<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,C`@=&5M<&QA=&5S+W!G<"]P87-S
M<&AR87-E+FEN8SHS,@HC.B!T96UP;&%T97,O<&=P+VEM<&]R=%]K97DN:6YC
M.C8V"FUS9VED(")#86YC96PB"FUS9W-T<B`BV838NMF((@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-S$@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z-#,U"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T
M+FEN8SHQ,3$*;7-G:60@(D-A;F-E;"!-97-S86=E(@IM<V=S='(@(MF$V+K9
MB"#9OMN,V+K8I]F%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<F5D:7)E8W0N
M:6YC.C4@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHV"FUS9VED(")#
M86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA;F5N=&QY(&1I<V-A
M<F0@:71S(&-O;G1E;G1S+B(*;7-G<W1R("+9A-BZV8@@V*?;C-F&(-F^VXS8
MNMBGV84@V*C8M]F(V+$@VJG8I]F%V80@V*K9A=BGV87;C"#9A=BMV*K9B-BG
MVXP@V*+9AB#8L=BG(-BGV+(@V*C;C-F&(-BNV8C8I]F'V*\@V*C8L=BO(@H*
M(SH@;65S<V%G92YP:'`Z,C8U('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T
M<RYI;F,Z,C(Q"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E8V]M<&]S92YI;F,Z
M,34@;&EB+U-E87)C:"YP:'`Z,S`*;7-G:60@(D-C(@IM<V=S='(@(MBQV8C9
MAMF(V+38JB(*"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z.3,*;7-G
M:60@(B(*(D-E<G1I9FEC871E(&EM<&]R="!I<R!N;W0@879A:6QA8FQE+B!&
M:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES("(*(G-E<G9E<BXB
M"FUS9W-T<B`B(@HBV*_8L=F(V8;B@(S8J-BQV*\@VJ_9B-BGV8?;C"#8K]BQ
M(-BOV+/8JMBQV+,@V8;9A=N,XH",V*C8I]BTV*\N(-BGV+'8L]BGV80@V8'8
MI]N,V80@V*C8L2#8L=F(VXP@V*?;C-F&(-JIV*?8L=BSV*?8LB#9A=F%VJG9
MAB#9AMN,V+/8JBXB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S`Q
M"FUS9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`BV878K]N,V+$B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z.#`*;7-G:60@(D-H86YG
M92(*;7-G<W1R("+8JMBZVXS;C-BQ(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M<W!E;&QI;F<N:6YC.C@Q"FUS9VED(")#:&%N9V4@06QL(@IM<V=S='(@(MBJ
MV+K;C-N,V+$@V8?9A=F'(@H*(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.CDR
M"FUS9VED(")#:&%N9V4@1F]L9&5R(@IM<V=S='(@(MBJV+K;C-N,V+$@V;[9
MB-BTV8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$R"FUS9VED("(B
M"B)#:&%N9V4@9&ES<&QA>2!O<'1I;VYS('-U8V@@87,@:&]W(&UA;GD@;65S
M<V%G97,@>6]U('-E92!O;B!E86-H('!A9V4@86YD("(*(FAO=R!M97-S86=E
M<R!A<F4@<V]R=&5D+B(*;7-G<W1R("(B"B+8JMBZVXS;C-BQ(-JOV++;C-F&
MV8?B@(S9A]BGVXP@V8;9A=BGVXS8M"#9A=BGV8;9AMBO(-BJV+G8K]BGV*\@
MV;[;C-BZV*?9A=F'V*<@V*_8L2#9A]BQ(-BUV8'8K=F'(-F((-J&VJ_9B-F&
MVJ_;C"#9A=BQV*K8J"#8M-BOV88@V;[;C-BZV*?9A=F'V*<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C0*;7-G:60@(D-H86YG92!M86EL('-E<G9E
M<B!A;F0@9F]L9&5R('-E='1I;F=S+B(*;7-G<W1R("+8JMBZVXS;C-BQ(-BJ
MV8;8N-N,V878I]BJ(-JIV*?8L=BSV*?8LB#9OMBSV*H@V*?9A-JIV*K8L=F(
MV8;;C-JI(-F((-F^V8C8M-F'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64L(&%D9')E<W,L(&%N9"!S
M:6=N871U<F4@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"`B
M"B)R97!L>2!T;R!Y;W5R(&5M86EL+B(*;7-G<W1R("(B"B+8JMBZVXS;C-BQ
MV*_8I]BOV88@V8;8I]F%(-F((-BBV*_8L=BSVXP@VJG9AR#8I]F!V+'8I]BO
M(-F'V8;:K]BGV84@V*[9B-BGV8;8K]F&(-F((-F^V*?8L]BN(-BOV*?8K]F&
M(-BHV8<@V8;8I]F%V8?9E"#8M-F%V*<@V*[9B-BGV8?9AMBO("(*(MBOVXS8
MKR`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(T"FUS9VED(")#:&%R
M86-T97)S('1O(&1I<W!L87DZ(@IM<V=S='(@(MF&V8C;C-BSV8?B@(S9A]BG
M(-BHV+'8I]N,(-F&V878I]N,V+0Z("(*"B,Z('1E;7!L871E<R]F;VQD97)S
M+V%C=&EO;G,N:6YC.C$U"FUS9VED(")#:&5C:R!&;VQD97(H<RD@9F]R($YE
M=R!-86EL(@IM<V=S='(@(MBHV+'8L=BSVXP@V;[9B-BTV8<HV8?8IRD@V*C8
ML=BGVXP@V8;8I]F%V8?9E"#8K-BOVXS8KR(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C(@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHW-0IM<V=I9"`B0VAE8VL@7T%L;"].;VYE(@IM<V=S='(@
M(MBHV+'8L=BSVXP@V8?9A=F'+R#9A]N,VH;B@(S;C-JI(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC.C$P('1E;7!L871E<R]F971C
M:&UA:6PO9F5T8VAM86EL+FEN8SHR,0IM<V=I9"`B0VAE8VL@86QL(&UA:6P@
M<V5R=F5R<R!Y;W4@=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(@IM<V=S='(@
M(B(*(MBHV+'8L=BSVXP@V*K9A=BGV87;C"#:J=BGV+'8L]BGV++B@(S9A]BG
MVXP@V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C.*`C-BGVXS;C"#:
MJ=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V8;8I]F%V8?B@(P@V*?8LB#8HMF&
MV8?8IR#9B-BGVJG8M-N,(-JIV8;;C-BO.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-C,*;7-G:60@(D-H96-K('-P96QL:6YG(&)E9F]R92!S96YD
M:6YG(&$@;65S<V%G93\B"FUS9W-T<B`BV*+;C-BG(-F"V*C9A"#8I]BR(-BG
MVXS9AMJIV8<@V;[;C-BZV*?9A2#9@=BQV+/8JMBGV*_9AR#8M-F(V*\@V*?8
MLB#9AMBXV+$@V*?9A=F$V*?;C-N,(-BHV+'8L=BSVXP@V+39B-BOV)\B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHT"FUS9VED(")#:&]O
M<V4@06-T:6]N.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V+G9A=F$.B(*"B,Z
M(&-O;F9I9R]S97)V97)S+G!H<"YD:7-T.C$X,@IM<V=I9"`B0VAO;W-E(&$@
M;6%I;"!S97)V97(Z(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-JIV*?8
ML=BSV*?8LB#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI.B(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$R-2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHQ-C8*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,C$W"FUS9VED(")#:&]O<V4@82!M871C:"!O<B!E9&ET('1H92!A
M9&1R97-S('1O('1H92!R:6=H=#HB"FUS9W-T<B`BV838M]F!V*?9BR#8I]F&
MV*K8KMBGV*@@VJG9AMN,V*\@V8@@VXS8IR#8HMBOV+'8LR#8L=BG(-F(VXS8
ML=BGVXS8M"#:J=F&VXS8KSHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z-3(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,S$*;7-G:60@(D-H
M;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-BY
MV879A#HB"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS
M-#D*;7-G:60@(D-H;V]S92!T:&4@861D<F5S<R!B;V]K('1O('5S92!W:&5N
M(&%D9&EN9R!A9&1R97-S97,N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI
M(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BHV+'8I]N,(-F'V8;:K]BGV87;
MC"#:J=F'(-BBV*_8L=BSV8?8IR#8L=BG(-BGV+;8I]F!V8<@V87;C.*`C-JI
MV8;;C-BO(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,CDS"FUS9VED(")#:&]O<V4@=&AE(&]R9&5R(&]F(&%D9')E<W,@8F]O:W,@
M=&\@<V5A<F-H('=H96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`B
MV*?9AMBJV*[8I]BH(-BJV+'8JMN,V*C;C"#8J-BQV*?;C"#:J=BJV*?8J-J&
MV8?B@(S9A]BGVXP@V*+8K]BQV+,@V*_8L2#9A]F&VJ_8I]F%(-BLV+/8JMBL
MV8@B"@HC(`HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H<#HQ,#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@8V]N=F5R="!T:&4@:6UA
M9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@=FEE=RXB
M"FUS9W-T<B`B(@HBV*C8L=BGVXP@V*K8J-BOVXS9A"#9OMBQV8C9AMBOV8?9
ME.*`C"#8JMBUV8C;C-BQ(-BHV8<@V8+8I]F$V*C;C"#:J=F'(-F%V+'9B-BQ
MVJ_8L2#8M-F%V*<@V*C8JMF(V*?9AMBO(-BBV8;8L=BG(-BHV*C;C-F&V*\@
M)7,@V+'8IR#:J=F$VXS:J2`B"B+:J=F&VXS8KR`B"@HC(`HC.B!L:6(O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&EC:R`E<R!T;R!D;W=N;&]A9"!T:&4@:6UA9V4N(@IM<V=S='(@(MBHV+'8
MI]N,(-JOV+'9@=BJV88@V*K8M=F(VXS8L2`E<R`NV+'8IR#9@=BTV*?8L2#8
MK]F'VXS8KR(*"B,@"B,Z(&QI8B]&:6QT97(N<&AP.C$P-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&EC:R`E<R!T;R!G;R!T;R`E<R!M86YA9V5M96YT('!A
M9V4N(@IM<V=S='(@(MBHV+$@V+'9B-N,("5S(-JIV83;C-JI(-JIV8;;C-BO
M(-BJV*<@V*C9AR#8M=F!V*W9AR#9A=BOVXS8L=N,V*H@)7,@V*C8L=F(VXS8
MKR(*"B,@"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@=FEE=R!(5$U,(&-O;G1E;G0@
M:6X@82!S97!A<F%T92!W:6YD;W<N(@IM<V=S='(@(MBHV+'8I]N,(-BOVXS8
MK]F&(-F%V*W8JMF(V*?;C"!(5$U,(-BOV+$@VXS:J2#9OMF&V*S8L=F'V90@
MV*S8K]BGVJ_8I]F&V8?8C"`E<R#8L=BG(-JIV83;C-JI(-JIV8;;C-BO(@H*
M(R`*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,38S"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@
M=&AI<R!I;6%G92XB"FUS9W-T<B`B(-BHV+'8I]N,(-BOVXS8K]F&(-BJV+79
MB-N,V+$@VJG9B-J&VJD@V*?8LB#8I]N,V88@V*K8M=F(VXS8L2`E<R#8L=BG
M(-JIV83;C-JI(-JIV8;;C-BO(@H*(R`*(SH@;&EB+TU)344O5FEE=V5R+W!K
M8W,W+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQI8VL@)7,@=&\@
M=FEE=R!T:&4@871T86-H;65N="!I;B!A('-E<&%R871E('=I;F1O=RXB"FUS
M9W-T<B`BV*C8L=BGVXP@V*_;C-BOV88@V878K=BJV8C8I]N,($A434P@V*_8
ML2#;C-JI(-F^V8;8K-BQV8?9E"#8K-BOV*?:K]BGV8;9AR`E<R#8L=BG(-JI
MV83;C-JI(-JIV8;;C-BO(@H*(R`*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T
M960N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-L:6-K("5S('1O('9I
M97<@=&AI<R!M=6QT:7!A<G0O<F5L871E9"!P87)T(&EN(&$@<V5P87)A=&4@
M=VEN9&]W+B(*;7-G<W1R("+8J-BQV*?;C"#8K]N,V*_9AB#9@MBSV878JMF'
MV*?;C"#9A=BNV*K9A-F!(-BOV+$@VXS:J2#9OMF&V*S8L=F'V90@V*S8K]BG
MVJ_8I]F&V8<@)7,@V+'8IR#:J=F$VXS:J2#:J=F&VXS8KR(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]H=&UL+G!H<#HY-0IM<V=I9"`B0VQI8VL@:&5R92!T;R!3
M2$]7('1H92!);6%G97,B"FUS9W-T<B`BV*?;C-F&V*S8IR#8L=BG(-BHV+'8
MI]N,(-F&V878I]N,V+0@V*K8M=BGV8C;C-BQ(-JIV83;C-JI(-JIV8;;C-BO
M(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S(Q"FUS
M9VED("(B"B)#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE8W1E9"!A9&1R97-S
M(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S('1O("(*(G-E87)C
M:"XB"FUS9W-T<B`B(@HBV*C8L2#8L=F(VXP@VXS:J=N,(-BGV+(@VJG8JMBG
MV*C:AMF'XH",V8?8I]N,(-BBV*_8L=BS(-BGV8;8JMBNV*?8J"#8M-BOV8<@
MVJG9A-N,VJD@VJG9AMN,V*\@V8@@V+/9OMBS("#9@=N,V838K]F'V*?;C"#9
MA=F(V+'8KR#9AMBXV+$@V+'8IR`B"B+8J-BQV*?;C"#8K-BSV*K8K-F((-BG
MV8;8JMBNV*?8J"#:J=F&VXS8KR(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C$W,0IM<V=I9"`B0VQI8VL@=&\@4V%V92!01U`@4'5B;&EC($ME>2!I
M;B!Y;W5R($%D9')E<W,@8F]O:R(*;7-G<W1R("+8J-BQV*?;C"#8K=F!V+@@
MVJG9A-N,V*_9A]BGVXP@V+G9A=F(V87;C"!01U`@V*_8L2#:J=BJV*?8J-J&
MV8?9E"#8HMBOV+'8LR#8KMF(V*_8C"#:J=F$VXS:J2#:J=F&VXS8KR(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C`R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L:6-K('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC871E(&]F("5S
M(&EN('EO=7(@061D<F5S<R!";V]K(@IM<V=S='(@(MBHV+'8I]N,(-BMV8'8
MN"#:K]F(V*?9A]N,(%,O34E-12`E<R#8K]BQ(-JIV*K8I]BHVH;9A]F4(-BB
MV*_8L=BS(-BNV8C8K]B,(-JIV83;C-JI(-JIV8;;C-BO(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDU,`IM<V=I9"`B0VQI8VMI;F<@;VX@=&AE(&%D
M9')E<W,@=VEL;"!C;VUP;W-E(&$@;F5W(&UE<W-A9V4@=&\@=&AE('-E;F1E
M<B(*;7-G<W1R("(@VJG9A-N,VJD@VJG8L=BOV88@V+'9B-N,(-BBV*_8L=BS
MV(P@V+79@=BMV8<@V*?;C-BLV*?8KR#9OMN,V+K8I]F%(-BQV*<@V*C8I]F$
MV*<@V87;C.*`C-BBV8C8L=BO("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-3$*;7-G:60@(D-L:6-K:6YG(&]N('1H92!A9&1R97-S('=I;&P@;W!E
M;B!T:&4@;65S<V%G92!T;R!B92!R96%D(@IM<V=S='(@(MJIV83;C-JI(-JI
MV+'8K]F&(-BQV8C;C"#8HMBOV+'8L]B,(-F^VXS8NMBGV84@V+'8IR#8J-BQ
MV*?;C"#8KMF(V*?9AMBOV88@V*C8I]BR(-F%VXSB@(S:J=F&V*\B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z,C@*;7-G:60@(D-L
M;W-E(@IM<V=S='(@(MBHV+/8JMF&(@H*(SH@8V]M<&]S92YP:'`Z.#(X(&-O
M;7!O<V4N<&AP.C$Q-#@*;7-G:60@(D-L;W-E('1H:7,@=VEN9&]W(@IM<V=S
M='(@(MBHV+/8JMF&(-BGVXS9AB#9OMF&V*S8L=F'(@H*(SH@9F]L9&5R<RYP
M:'`Z-#(Y"FUS9VED(")#;&]S960@1F]L9&5R(@IM<V=S='(@(MF^V8C8M-F'
MV90@V*C8L]BJV8<@V+38K]F'(@H*(SH@9F]L9&5R<RYP:'`Z-#0Y"FUS9VED
M(")#;VQL87!S92(*;7-G<W1R("+8J-BSV*K9AB(*"B,Z('1E;7!L871E<R]F
M;VQD97)S+V%C=&EO;G,N:6YC.C,Y"FUS9VED(")#;VQL87!S92!!;&PB"FUS
M9W-T<B`BV*C8L]BJV88@V8?9A=F'(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O
M86-T:6]N<RYI;F,Z,SD*;7-G:60@(D-O;&QA<'-E($%L;"!&;VQD97)S(@IM
M<V=S='(@(MBHV+/8JMF&(-F'V879A]F4(-F^V8C8M-F'XH",V8?8IR(*"B,Z
M(&9O;&1E<G,N<&AP.C0T.0IM<V=I9"`B0V]L;&%P<V4@1F]L9&5R(@IM<V=S
M='(@(MBHV+/8JMF&(-F^V8C8M-F'(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I
M;"]M86YA9V4N:6YC.C4Q"FUS9VED(")#;VQO<B!);F1I8V%T;W(Z("(*;7-G
M<W1R("+8M-BGV*[8M2#8L=F&VJ\Z(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N
M:6YC.C$P,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("+8JMF(V+;;C-BM(@H*
M(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C<V.0IM<V=I9"`B0V]M<&QE
M=&5D(@IM<V=S='(@(MJIV*?9A=F$(-BTV*_9AR(*"B,Z(&-O;7!O<V4N<&AP
M.C@R-R!C;VUP;W-E+G!H<#HQ,30W"FUS9VED(")#;VUP;W-E(&%N;W1H97(@
M;65S<V%G92(*;7-G<W1R("+8I]N,V*S8I]BO(-N,VJD@V;[;C-BZV*?9A2#8
MK]N,VJ_8L2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S0*;7-G:60@
M(D-O;7!O<V4@;65S<V%G97,@:6X@82!S97!A<F%T92!W:6YD;W<_(@IM<V=S
M='(@(MBBVXS8IR#9OMN,V+K8I]F%V8?8IR#8K]BQ(-N,VJD@V;[9AMBLV+'9
MA]F4(-BLV*_8I]JOV*?9AMF'(-BGVXS8K-BGV*\@V+39B-F&V*_8GR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@(B(*(D-O;7!O<V4@
M;65S<V%G97,@=VET:"!A;B!(5$U,($=522!B>2!D969A=6QT("AI9B!B<F]W
M<V5R('-U<'!O<G1S('1H92`B"B)F96%T=7)E*3\B"FUS9W-T<B`B(@HB(-BB
MVXS8IR#9OMN,V+K8I]F%V8?8IR#8J-BWV8C8L2#9OMN,V+0@V8'8L=BV(-BH
MV*<@VXS:J2#9B-BGV+/8MR#:K]BQV*?9@=N,VJG;C"#9A=BHV*K9AMN,(-BH
MV+$@2%1-3"#8I]N,V*S8I]BO(-BTV8C8KRC8I]JOV+$@(@HBV878L=F(V+':
MK]BQ(-F%V+38KMBUV8<@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(.*`C-JIV8;8
MKRG8GR`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<*;7-G:60@(D-O
M;F9I9W5R92!H;W<@;65S<V%G97,@87)E(&1I<W!L87EE9"XB"FUS9W-T<B`B
MV;[;C-JIV+'8J-F&V*_;C"#:AMJOV8C9AMJOVXP@V8;9A=BGVXS8M"#9OMN,
MV+K8I]F%V8?8IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I
M9"`B0V]N9FEG=7)E(&UA:6P@<')E=FEE=R!O<'1I;VYS+B(*;7-G<W1R("+9
MOMN,VJG8L=BHV8;8K]N,(-JOV++;C-F&V8?B@(SB@(S9A]BGVXP@V;[;C-BT
MXH",V8;9A=BGVXS8M"`@V8;8I]F%V8<B"@HC.B!L:6(O24U!4"]#;&EE;G0N
M<&AP.C,W,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!D<F]P<&5D(&)Y
M($E-05`@<V5R=F5R+B(*;7-G<W1R("+8I]BJV+78I]F$(-BHV8<@VJG8I]BQ
MV+/8I]BR(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z(&QI8B]&971C:&UA
M:6PO:6UA<"YP:'`Z,C,T"FUS9VED(")#;VYN96-T:6]N('1O('-E<G9E<B!F
M86EL960B"FUS9W-T<B`BV*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB#9
MAMBGV879B-F!V9'9@B#8J-F(V*\B"@HC(`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30S"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1R;VP@4$=0('-U
M<'!O<G0@9F]R("5S+B(*;7-G<W1R("+:J=F&V*K8L=F$(-F^V+38JMN,V*C8
MI]F&VXP@4$=0(-BHV+'8I]N,("5S+B(*"B,@"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=')O;"!3+TU)
M344@<W5P<&]R="!F;W(@)7,N(@IM<V=S='(@(MJIV8;8JMBQV80@V;[8M-BJ
MVXS8J-BGV8;;C"!3+TU)344@V*C8L=BGVXP@)7,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(Q"FUS9VED(")#;VYT<F]L(&]P=&EO;G,@<F5L871I
M;F<@=&\@;65S<V%G97,@<V5A<F-H:6YG+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(B(*(D-O;G1R;VP@=VAE;B!N
M97<@;6%I;"!W:6QL(&)E(&-H96-K960@9F]R+"!A;F0@=VAE=&AE<B!O<B!N
M;W0@=&\@;F]T:69Y('EO=2`B"B)W:&5N(&ET(&%R<FEV97,N(@IM<V=S='(@
M(MJIV8;8JMBQV80@V8C8M=F(V80@V8;8I]F%V8?9E"#8K-BOVXS8KR#9B"#8
MI]BQV*?8IMF'V90@V*K8L-JIV+'9A]BGVXP@V878L=BJV*C8MR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV.38*;7-G:60@(D-O;G9E<G0@=&5X='5A
M;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC86P@;VYE<S\B"FUS9W-T<B`BV*+;
MC-BG(-BGV*W8L]BGV+/8I]BJ(-F&V8C8M-BJV*?8L=N,(-BHV8<@VJ_8L=BG
MV8';C-JIVXP@V*K8J-BOVXS9A"#8M-F(V*_8GR(*"B,Z('1E;7!L871E<R]M
M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z,3D@=&5M<&QA=&5S+VUA:6QB
M;W@O;F%V8F%R+FEN8SHU,0IM<V=I9"`B0V]P>2(*;7-G<W1R("+8L=F(V8;9
MB-BTV*HB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N
M:6YC.C$Y('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z-3$*;7-G:60@
M(D-O<'D@=&\@9F]L9&5R(@IM<V=S='(@(MBQV8C9AMF(V+38JB#8K]BQ(-F^
MV8C8M-F'(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C8S
M"FUS9VED(")#;W)R96-T(@IM<V=S='(@(MBUV*W;C-BM(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C$T,`IM<V=I9"`B0V]R<F5C=&5D
M(%1E>'0B"FUS9W-T<B`BV878JMF&V8?8I]N,(-BJV+78K=N,V*T@V+38K]F'
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@;&EB+TE-05`O0VQI96YT+G!H<#HS.#(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VUP;&5T92!R97%U97-T
M+B!296%S;VX@1VEV96XZ("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F^V+38JMN,V*?9AB!61E,@V+'8IR#8I]N,V*S8I]BO(-JIV+'8KSH@)7,B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!A='1A8VAM96YT+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E('1H92!61E,@8F%C:V5N9#H@)7,B"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8M-BJVXS8I]F&(%9&4R#8L=BG
M(-BGVXS8K-BGV*\@VJG8L=BO.B`E<R(*"B,@"B,Z(&QI8B]-97-S86=E+G!H
M<#HV-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!M
M97-S86=E<R!F<F]M("5S+B!4:&4@<V5R=F5R('-A:60Z("5S(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(-F^VXS8NMBGV879A]BG(-BQV*<@V*?8LB`E
M<R#8K=BPV8$@VJG8L=BO+B#:J=BGV+'8L]BGV+(@VJ_9@=BJV8<@V*?8L]BJ
M.B5S(@H*(SH@;&EB+U-E<W-I;VXN<&AP.C,Q.`IM<V=I9"`B0V]U;&0@;F]T
M(&5X96-U=&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<RXB"FUS9W-T<B`BV8;9
MA=N,XH",V*K9B-BGV88@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(-BQ
MV*<@V*?8K-BQV*<@VJG8L=BO(@H*(SH@;&EB+TU)344O5FEE=V5R+W1N968N
M<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D
M(&9I;&4@9G)O;2!T:&4@35,M5$Y%1B!A='1A8VAM96YT+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8?B@(P@V*[9B-BGV+/8JMF'
M(-BTV*_9AR#8L=BG(-BGV+(@V;[;C-F(V+/8JB!-4RU43D5&(-BHV*?8LMJI
MV+'8KR(*"B,Z(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C4X"FUS9VED(")#
M;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@
M6FEP(&%R8VAI=F4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9
MB-F&V*_9A^*`C"#8KMF(V*?8L]BJV8<@V+38K]F'(-BQV*<@V*?8LB#8HMBQ
MV+3;C-F((%II<"#8J-BGV++:J=BQV*\B"@HC.B!L:6(O4V5S<VEO;BYP:'`Z
M,C<S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@;F%M97-P86-E(&EN9F]R
M;6%T:6]N(&9R;VT@24U!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('-E87)C
M:"YP:'`Z,S$T('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN8SHV-R!T
M96UP;&%T97,O86-L+V%C;"YI;F,Z,SD*(SH@=&5M<&QA=&5S+V%C;"]A8VPN
M:6YC.C$V,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(MBGVXS8K-BGV*\B"@HC
M.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHV"FUS9VED(")#<F5A
M=&4@1F]L9&5R(@IM<V=S='(@(MBGVXS8K-BGV*\@V;[9B-BTV8<B"@HC.B!T
M96UP;&%T97,O<&=P+W!G<"YI;F,Z,3,W"FUS9VED(")#<F5A=&4@2V5Y<R(*
M;7-G<W1R("+8I]N,V*S8I]BO(-JIV83;C-BOV8?8IR(*"B,Z('1E;7!L871E
M<R]S96%R8V@O:&5A9&5R+FEN8SHQ-`IM<V=I9"`B0W)E871E(%9I<G1U86P@
M1F]L9&5R(@IM<V=S='(@(MBGVXS8K-BGV*\@V;[9B-BTV8<@V878K-BGV++;
MC"(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC
M.C(V"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!.97<@06-C;W5N="(*;7-G
M<W1R("+8J-F"VXS9AR#8K=BSV*?8J-F'V*?;C"#9OMBSV*K;C"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]S<&%M<V5L96-T+FEN8SHQ,B!T96UP;&%T97,O<')E
M9G,O<W!A;7-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!3<&%M
M(&9O;&1E<B(*;7-G<W1R("+8I]N,V*S8I]BO(-N,VJD@V;[9B-BTV8<@V*S8
MK]N,V*\@V8?8L=BRV8;8I]F%V8?B@(S9A]BG(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V9O;&1E<G-E;&5C="YI;F,Z,3(@=&5M<&QA=&5S+W!R969S+V9O;&1E
M<G-E;&5C="YI;F,Z,C0*;7-G:60@(D-R96%T92!A(&YE=R!D<F%F=',@9F]L
M9&5R(@IM<V=S='(@(MBGVXS8K-BGV*\@VXS:J2#9OMF(V+39AR#8K-BOVXS8
MKR#9OMN,V+0@V8;9B-N,V+/9A]BG(@H*(SH@=&5M<&QA=&5S+W!R969S+W-E
M;G1M86EL<V5L96-T+FEN8SHR-B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS
M96QE8W0N:6YC.C0R"FUS9VED(")#<F5A=&4@82!N97<@<V5N="!M86EL(&9O
M;&1E<B(*;7-G<W1R("+8I]N,V*S8I]BO(-N,VJD@V;[9B-BTV8<@V*S8K]N,
MV*\@V*C8L=BGVXP@V8;8I]F%V8?B@(S9A]BGVXP@V*?8L=BSV*?9A-N,(@H*
M(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T+FEN8SHQ,B!T96UP;&%T
M97,O<')E9G,O=')A<VAS96QE8W0N:6YC.C(T"FUS9VED(")#<F5A=&4@82!N
M97<@=')A<V@@9F]L9&5R(@IM<V=S='(@(MBGVXS8K-BGV*\@VXS:J2#9OMF(
MV+39AR#8K-BOVXS8KR#8HMBTV+K8I]F$(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R.`IM<V=I9"`B(@HB0W)E871E(&9I;'1E<FEN9R!R=6QE<R!T
M;R!O<F=A;FEZ92!Y;W5R(&EN8V]M:6YG(&UA:6PL('-O<G0@:70@:6YT;R!F
M;VQD97)S+"`B"B)A;F0@9&5L971E('-P86TN(@IM<V=S='(@(B(*(B#8I]N,
MV*S8I]BO(-F"V8C8I]F&VXS9AB#9@=N,V838JMBQ(-BHV+'8I]N,(-BSV*?8
MLMF%V*?9AMBOV8?;C"#9AMBGV879A^*`C-F'V*?;C"#8K]BQVXS8I]F!V*K;
MC-B,(-F%V+'8JMBH(-BSV*?8LMN,(-F&V*?9A=F'XH",V8?8IR#8K]BQ("(*
M(MF^V8C8M-F'XH",V8?8IR#9B"#8K=BPV8$@V8?8L=BRV8;8I]F%V8?B@(S9
MA]BG(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C$T"FUS
M9VED(")#<F5A=&4@;F5W('-T871I;VYE<GDB"FUS9W-T<B`BV*?;C-BLV*?8
MKR#9AMF(V+38JN*`C-BGV8'8LMBGV+$@V*S8K]N,V*\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#0Y"FUS9VED(")#<F5A=&4@<W1A=&EO;F5R>2!A
M;F0@9F]R;2!R97-P;VYS97,N(@IM<V=S='(@(MBGVXS8K-BGV*\@V8;9B-BT
MV*KB@(S8I]F!V++8I]BQ(-F((-F!V+'9A2#9OMBGV+/8KB(*"B,Z('1E;7!L
M871E<R]A8VPO86-L+FEN8SHY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7)R
M96YT(&%C8V5S<R!T;R`E<R(*;7-G<W1R("+8K]BSV*K8L=BSVXP@VJG9AMF(
MV8;;C"#8J-F'("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-0IM
M<V=I9"`B0W5S=&]M:7IE(&%C8V]U;G1S(&9O<B!F971C:&EN9R!M86EL(&9R
M;VT@;W1H97(@86-C;W5N=',N(@IM<V=S='(@(MBHV8?;C-F&V8<@V+/8I]BR
MVXP@V*W8L]BGV*C9A]BG(-BHV+'8I]N,(-F(V*?:J=BTVXP@V8;8I]F%V8?B
M@(S9A]BG(-BGV+(@V*W8L]BGV*C9A]BGVXP@V*_;C-JOV+$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$*;7-G:60@(D-U<W1O;6EZ92!H;W<@>6]U
M('-E;F0@;6%I;"XB"FUS9W-T<B`BV*C9A]N,V8;9AR#8L]BGV++;C"#:AMJO
MV8C9AMJOVXP@V*?8L=BSV*?9A"#9AMBGV879A^*`C-F'V*<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M("+8J-F'VXS9AMF'(-BSV*?8LMN,(-F(V+C8I]N,V8$@V*C8L=BGVXP@V*?8
MK-BQV*<@V*C9AR#9A]F&VJ_8I]F%(-F(V+'9B-BO(-BHV8<@)7,B"@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C$W"FUS9VED
M(")$871?92(*;7-G<W1R("+8JMBGV+';C-BN(@H*(SH@;65S<V%G92YP:'`Z
M,C8R('1H<F5A9"YP:'`Z,30X"FUS9VED(")$871E(@IM<V=S='(@(MBJV*?8
ML=N,V*XB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S4W"FUS9VED
M(")$96-L:6YE9"(*;7-G<W1R("+8L=BOV+38K]F'(@H*(SH@;&EB+TU)344O
M5FEE=V5R+VET:7`N<&AP.C(V,PIM<V=I9"`B1&5C;&EN960Z("(*;7-G<W1R
M("+8L=BOV+38K]F'.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*
M(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BV*W8L-F!(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V1E9F%U;'1S96%R8VAS96QE8W0N:6YC.C$X"FUS
M9VED(")$969A=6QT(%-E87)C:"!&:65L9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(S"FUS9VED(")$969A=6QT('-O<G1I;F<@
M8W)I=&5R:6$Z(@IM<V=S='(@(MF%V+G;C-BGV+'9A]BGVXP@V;[;C-BT(-F!
MV+'8MB#9A=BQV*K8J"#8L]BGV++;C#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3,S"FUS9VED(")$969A=6QT('-O<G1I;F<@9&ER96-T:6]N.B(*
M;7-G<W1R("+8K-F'V*H@V878L=BJV*@@V+/8I]BRVXP@V;[;C-BT(-F!V+'8
MMCHB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-S8U"FUS9VED(")$
M96QE9V%T960B"FUS9W-T<B`BV8;9A=BGVXS9AMBOV8<B"@HC.B!F;VQD97)S
M+G!H<#HT,3D@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C8X"B,Z
M('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,C0T('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHV"B,Z('1E;7!L871E<R]M
M86EL8F]X+V%C=&EO;G,N:6YC.C@@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N
M<RYI;F,Z,3`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP
M;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYI;F,Z,C@*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(W"FUS9VED(")$96QE=&4B"FUS9W-T<B`BV*W8L-F!
M(@H*(R`*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M("5S(%!U8FQI8R!+97DB"FUS9W-T<B`BV*W8L-F!(-JIV83;C-BO(-BYV879
MB-F%VXP@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C<Y('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHX-0IM<V=I9"`B1&5L971E($-U<G)E;G0@
M2V5Y<R(*;7-G<W1R("+8K=BPV8$@VJG9A-N,V*_B@(S9A]BGVXP@VJG9AMF(
MV8;;C"(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.CD*;7-G
M:60@(D1E;&5T92!&;VQD97(H<RDB"FUS9W-T<B`BV*W8L-F!(-F^V8C8M-F'
M*-F'V*<I(@H*(SH@9F]L9&5R<RYP:'`Z,C@U"FUS9VED(")$96QE=&4@4V5L
M96-T960@1F]L9&5R<R(*;7-G<W1R("+8K=BPV8$@V;[9B-BTV8?B@(S9A]BG
MVXP@V*?9AMBJV*[8I]BH(-BTV*_9AR(*"B,Z('1E;7!L871E<R]S=&%T:6]N
M97)Y+W!R969S+FEN8SHT,@IM<V=I9"`B1&5L971E(%-T871I;VYE<GDB"FUS
M9W-T<B`BV*W8L-F!(-F&V8C8M-BJXH",V*?9@=BRV*?8L2(*"B,Z(&9O;&1E
M<G,N<&AP.C0Q.0IM<V=I9"`B1&5L971E(%9I<G1U86P@1F]L9&5R(@IM<V=S
M='(@(MBMV+#9@2#9OMF(V+39AR#9A=BLV*?8LMN,(@H*(SH@=&5M<&QA=&5S
M+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0S"FUS9VED(")$96QE=&4@9F5T8VAE
M9"!M97-S86=E<R!F<F]M(')E;6]T92!S97)V97(_(@IM<V=S='(@(MBBVXS8
MIR#9OMN,V+K8I]F%V8?8I]N,(-F(V*?:J=BTVXP@V+38K]F'(-BGV+(@VJG8
MI]BQV+/8I]BR(-BMV+#9@2#8M-F(V*_8GR(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV,C@*;7-G:60@(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R
M(@IM<V=S='(@(MBGV+(@V*K9@MF(VXS9A2#9A=F&(-BMV+#9@2#8M-F(V*\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"FUS9VED(")$96QE=&4@
M;VQD(&QI;FME9"!A='1A8VAM96YT<R!A="!B96=I;FYI;F<@;V8@;6]N=&@_
M(@IM<V=S='(@(MBBVXS8IR#9OMN,V8C9AMBOV8?8I]N,(-F^VXS9B-BSV*H@
MV8+8K]N,V87;C-B,(-BOV+$@V*?8J-BJV*_8I]N,(-F'V+$@V878I]F'(-BM
MV+#9@2#8M-F(V8;8K]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M,`IM<V=I9"`B1&5L971E(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!A="!B96=I
M;FYI;F<@;V8@;6]N=&@_(@IM<V=S='(@(MBBVXS8IR#9AMBGV879A^*`C-F'
MV*?;C"#9@=BQV+/8JMBGV*_9AR#8M-BOV8?9E"#9@MBOVXS9A=N,V(P@V*_8
ML2#8I]BHV*K8K]BGVXP@V8?8L2#9A=BGV8<@V*W8L-F!(-BTV8C9AMBOV)\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C$W"FUS9VED(")$96QE=&4@
M<W!A;2!M97-S86=E<R(*;7-G<W1R("+8K=BPV8$@V8?8L=BRV8;8I]F%V8?B
M@(S9A]BG(@H*(SH@;65S<V%G92YP:'`Z-3`S(&UA:6QB;W@N<&AP.C<T,"!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C(P"B,Z('1E;7!L871E<R]M
M86EL8F]X+VYA=F)A<BYI;F,Z,S@@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD
M+FEN8SHX"FUS9VED(")$96QE=&5D(@IM<V=S='(@(MBMV+#9@2#8M-BOV8<B
M"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C8S"FUS9VED(")$96QE
M=&5D(&UE<W-A9V5S(@IM<V=S='(@(MF^VXS8NMBGV879A]BGVXP@V*W8L-F!
M(-BTV*_9AR(*"B,@"B,Z(&-O;7!O<V4N<&AP.C,P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&5D('1H92!A='1A8VAM96YT(%PB)7-<(BXB"FUS9W-T
M<B`BV;[;C-F(V+/8JB!<(B5S7"(@V*W8L-F!(-BTV*_9AR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B1&5L971I;F<@86YD($UO=FEN
M9R!-97-S86=E<R(*;7-G<W1R("+8K=BPV8$@V8@@V*?9AMBJV8+8I]F$(-F^
MVXS8NMBGV879A]BG(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C4Y
M,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(MBQV*\@V*K9@MBGV+;8
MIR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU-#`*;7-G:60@(D1E
M;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S='(@
M(MBOV+'8KMF(V*?8L]BJ(-BHV+'8I]N,(-BGV+?9A-BGV+G8I]BJ(-BBV++8
MI]BO+]F%V+38NMF(V80@V;[8L-N,V+'9@=BJV8<@V8;8M-BO(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDS,@IM<V=I9"`B1&5S8V5N9&EN9R(*;7-G
M<W1R("+9AMBRV8C9A-N,(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC.C(Q(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-CD*;7-G
M:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(MBJV8C8MMN,V*TB"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]S;6EM92]S;6EM
M92YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C(W('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G
M:60@(D1E=&%I;',B"FUS9W-T<B`BV*S8LMBFVXS8I]BJ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8W-PIM<V=I9"`B1&EM('-I9VYA='5R97,_(@IM
M<V=S='(@(MBGV878MMBGV*'B@(S9A]BG(-BJV*?8L2#8M-F(V8;8K]B?(@H*
M(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,S8*;7-G:60@
M(D1I<W!L87DB"FUS9W-T<B`BV8;9A=BGVXS8M"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-SD*;7-G:60@(D1I<W!L87D@8V]N9FER;6%T:6]N(&%F
M=&5R('-E;F1I;F<@82!M97-S86=E/R(*;7-G<W1R("+8HMN,V*<@V*C8N=BO
M(-BGV+(@V8'8L=BSV*K8I]BOV88@V;[;C-BZV*?9A=B,(-BJV*/;C-N,V*\@
MV*+9AB#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8X-@IM<V=I9"`B1&ES<&QA>2!I;B!";V1Y(&]F
M($UE<W-A9V4B"FUS9W-T<B`BV8;9A=BGVXS8M"#8K]BQ(-BHV*_9AMF'V90@
MV;[;C-BZV*?9A2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.3(*;7-G
M:60@(D1I<W!L87D@<&]P+75P(&YO=&EF:6-A=&EO;B!O9B!N97<@;6%I;#\B
M"FUS9W-T<B`BV*+;C-BG(-BJV+#:J=BQV8?8I]N,(-JOV+39B-BOV8;;C"#8
MJ-BQV*?;C"#9AMBGV879A^*`C-F4(-BLV*_;C-BO(-F&V878I]N,V+0@V*_8
MI]BOV8<@V+39B-BOV)\@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U
M.`IM<V=I9"`B1&ES<&QA>2!T:&4@7")%;7!T>2!3<&%M7"(@;&EN:R!I;B!T
M:&4@;65N=6)A<C\B"FUS9W-T<B`BV*+;C-BG(-F^VXS9B-F&V*\@)]BNV*?9
MA-N,(-JIV+'8K]F&(-F'V+'8LMF&V*?9A=F'XH",V8?8IR<@V*_8L2#:K]BR
MVXS9AMJOV*?9AB#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U,`IM<V=I9"`B1&ES<&QA>2!T:&4@
M7")%;7!T>2!4<F%S:%PB(&QI;FL@:6X@=&AE(&UE;G5B87(_(@IM<V=S='(@
M(MBBVXS8IR#9OMN,V8C9AMBO("?8KMBGV83;C"#:J=BQV*_9AB#8L]BWV80@
MV*+8M-BZV*?9A"<@V*_8L2#:K]BRVXS9AMJOV*?9AB#9AMF%V*?;C-BT(-BO
MV*?8K]F'(-BTV8C8K]B?(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC.C$Q"FUS9VED(")$:7-P;W-I=&EO;B(*;7-G<W1R("+8JMBQ
MV*K;C-BH(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]F:65L9',N:6YC.C(V"FUS
M9VED(")$;R!.3U0@;6%T8V@B"FUS9W-T<B`BV+G8K]F%(-BJV+?8I]BHV8(B
M"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B
M1&\@3F]T($-H96-K($9O;&1E<BAS*2!F;W(@3F5W($UA:6PB"FUS9W-T<B`B
MV+G8K]F%(-BHV+'8L=BSVXP@V;[9B-BTV8<HV8?8IRD@V*C8L=BGVXP@V8;8
MI]F%V8?9E"#8K-BOVXS8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-3(*;7-G:60@(D1O(&YO="!G96YE<F%T92!A(&QI;FL@:6X@=&AE($9R;VTZ
M(&-O;'5M;B(*;7-G<W1R("+8K]BQ(-BSV*K9B-F&(-F!V+'8L]BJV8;8K]F'
M(-F^VXS9B-F&V*_;C"#8I]N,V*S8I]BO(-F&VJG9AB(*"B,Z(&QI8B])35`N
M<&AP.C$P-S4*;7-G:60@(D1O('EO=2!W86YT('1O(&]P96X@=&AA="!F;VQD
M97(_(@IM<V=S='(@(MBBVXS8IR#9A=N,XH",V*[9B-BGV8?;C-BO(-BBV88@
MV;[9B-BTV8<@V+'8IR#8J-BGV+(@VJG9AMN,V*_8GR(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C,R"FUS9VED(")$;VXG="!H879E(&%N(&%C
M8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(MBBVXS8IR#8K=BSV*?8J-N,(-F&
MV*_8I]BQVXS8K]B?(-BKV*C8JB#9AMBGV84B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]S<&5L;&EN9RYI;F,Z,3(V"FUS9VED(")$;VYE(@IM<V=S='(@(MBG
MV8;8K-BGV84@V+38K]F'(@H*(R`*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP
M.C$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R!I;B`N>FEP
M($9O<FUA="(*;7-G<W1R("+8I]BSV*K9@MBQV*?8L2`E<R#8K]BQ(-F"V*?9
MA-BH("YZ:7`B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHU
M,@IM<V=I9"`B1&]W;FQO860@06QL($%T=&%C:&UE;G1S("AI;B`N>FEP(&9I
M;&4I(@IM<V=S='(@(MBGV+/8JMF"V+'8I]BQ(-BJV878I]F%VXP@V;[;C-F(
MV+/8JMF'V*<HV*_8L2#9OMBQV8C9AMBOV8?9E"`N>FEP*2(*"B,Z('1E;7!L
M871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C(P"FUS9VED(")$;W=N;&]A9"!&
M;VQD97(H<RDB"FUS9W-T<B`BV*?8L]BJV8+8L=BGV+$@V;[9B-BTV8<HV8?8
MIRDB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHR,0IM<V=I
M9"`B1&]W;FQO860@1F]L9&5R*',I(%LN>FEP(&9O<FUA=%TB"FUS9W-T<B`B
MV*?8L]BJV8+8L=BGV+$@V;[9B-BTV8<HV8?8IRD@6]F"V*?9A-BH("YZ:7!=
M(@H*(SH@;&EB+TU)344O0V]N=&5N=',N<&AP.C$Y,@IM<V=I9"`B1&]W;FQO
M860@:6X@+GII<"!&;W)M870B"FUS9W-T<B`BV*?8L]BJV8+8L=BGV+$@V*_8
ML2#9@MBGV838J"`N>FEP(@H*(SH@;65S<V%G92YP:'`Z-3`Q(&UA:6QB;W@N
M<&AP.C<Q.2!T96UP;&%T97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC
M.C$Q"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C(@=&5M<&QA
M=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHT,0HC.B!T96UP;&%T97,O;6%I;&)O
M>"]L96=E;F0N:6YC.CD*;7-G:60@(D1R869T(@IM<V=S='(@(MF^VXS8M"#9
MAMF(VXS8LR(*"B,Z(&9O;&1E<G,N<&AP.C,Y,@IM<V=I9"`B1')A9G0@9F]L
M9&5R(@IM<V=S='(@(MF^V8C8M-F'V90@V;[;C-BT(-F&V8C;C-BS(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V9O;&1E<G-E;&5C="YI;F,Z,C,*;7-G:60@(D1R
M869T<R!F;VQD97(Z(@IM<V=S='(@(MF^V8C8M-F'V90@V;[;C-BT(-F&V8C;
MC-BSV8?8ISHB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3`X"FUS9VED
M(")%+6UA:6P@061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#9AMBGV879A]F4
M(-BGV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@;&EB+TUA:6QB;W@N<&AP.C,P
M.0IM<V=I9"`B14Y$(@IM<V=S='(@(MBNV*?8JMF%V8<B"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HW-`IM<V=I9"`B15)23U(Z(%EO=7(@;65S
M<V%G92!C;W5L9"!N;W0@8F4@9&5L:79E<F5D+B(*;7-G<W1R("+8KMBWV*<Z
M(-F^VXS8NMBGV84@V+39A=BG(-BJV*W9B-N,V80@V*_8I]BOV8<@V8;8M-BO
M(@H*(SH@9F]L9&5R<RYP:'`Z-#(P('1E;7!L871E<R]S=&%T:6]N97)Y+W!R
M969S+FEN8SHQ.0IM<V=I9"`B161I="(*;7-G<W1R("+9B-N,V+'8I]N,V+0B
M"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z,3@*;7-G:60@(D5D
M:70@0FQA8VML:7-T(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#9A-N,V+/8JB#8
ML]N,V*?9AR(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM
M<V=I9"`B161I="!&:6QT97)S(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#9@=N,
MV838JMBQV8?8IR(*"B,Z(&9O;&1E<G,N<&AP.C0R,"!T96UP;&%T97,O<V5A
M<F-H+VAE861E<BYI;F,Z,38*;7-G:60@(D5D:70@5FER='5A;"!&;VQD97(B
M"FUS9W-T<B`BV8C;C-BQV*?;C-BT(-F^V8C8M-F'XH",V90@V878K-BGV++;
MC"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VAE861E<BYI;F,Z,3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!6:7)T=6%L($9O;&1E<B!$969I;FET:6]N
M(&9O<B`E<R(*;7-G<W1R("+9B-N,V+'8I]N,V+0@V*K8N=BQVXS9@2#9OMF(
MV+39A]F4(-F%V*S8I]BRVXP@)7,B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P
M<F5F<RYI;F,Z,C,*;7-G:60@(D5D:70@5VAI=&5L:7-T(@IM<V=S='(@(MF(
MVXS8L=BGVXS8M"#9@=F'V+'8L]BJ(-BSV8';C-BO(@H*(SH@=&5M<&QA=&5S
M+V9I;'1E<G,O<')E9G,N:6YC.C$X"FUS9VED(")%9&ET('EO=7(@8FQA8VML
M:7-T(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#9@=F'V+'8L]BJ(-BSVXS8I]F'
M(-BTV878IR(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN8SHQ,PIM
M<V=I9"`B161I="!Y;W5R(&9I;'1E<B!R=6QE<R(*;7-G<W1R("+9B-N,V+'8
MI]N,V+0@V8+9B-BGV8;;C-F&(-F!VXS9A-BJV+$@V+39A=BG(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V,0IM<V=I9"`B161I="!Y;W5R('!R969E
M<F5N8V5S(&9O<B!A8V-E<W-I;F<@;W1H97(@;6%I;"!A8V-O=6YT<RXB"FUS
M9W-T<B`BV8C;C-BQV*?;C-BT(-JOV++;C-F&V8?B@(S9A]BGVXP@V+39A=BG
M(-BHV+'8I]N,(-BOV+/8JMN,V*?8J-N,(-BHV8<@V*W8L]BGV*C9A]BGVXP@
MV8;8I]F%V8?9E"#8K]N,VJ_8L2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R
M969S+FEN8SHR,PIM<V=I9"`B161I="!Y;W5R('=H:71E;&ES="(*;7-G<W1R
M("+9B-N,V+'8I]N,V+0@V8'9A]BQV+/8JB#8L]F!VXS8KR#8M-F%V*<B"@HC
M.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S.0IM<V=I9"`B
M16UA:6P@061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#9AMBGV879A]F4(-BG
MV83:J=BJV+'9B-F&VXS:J=N,(@H*(R`*(SH@;&EB+TUE<W-A9V4N<&AP.C8U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;7!T:65D(&%L;"!M97-S86=E<R!F
M<F]M("5S+B(*;7-G<W1R("+8JMF%V*?9A=N,(-F^VXS8NMBGV879A]BG(-BG
MV+(@)7,@V*[8I]F$VXP@V+38K]F&V*\B"@HC.B!T96UP;&%T97,O9F]L9&5R
M<R]A8W1I;VYS+FEN8SHR,@IM<V=I9"`B16UP='D@1F]L9&5R*',I(@IM<V=S
M='(@(MBNV*?9A-N,(-JIV+'8K]F&(-F^V8C8M-F'*-F'V*<I(@H*(SH@9F]L
M9&5R<RYP:'`Z,C@V"FUS9VED(")%;7!T>2!396QE8W1E9"!&;VQD97)S(@IM
M<V=S='(@(MBNV*?9A-N,(-JIV+'8K]F&(-F^V8C8M-F'XH",V8?8I]N,(-BG
MV8;8JMBNV*?8J"#8M-BOV8<B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I
M;VYS+FEN8SHS.0IM<V=I9"`B16UP='D@5')A<V@@9F]L9&5R(@IM<V=S='(@
M(MBNV*?9A-N,(-JIV+'8K]F&(-F^V8C8M-F'V90@V*+8M-BZV*?9A"(*"B,Z
M(&QI8B])35`N<&AP.CDW,PIM<V=I9"`B16UP='D@7U-P86TB"FUS9W-T<B`B
MV*[8I]F$VXP@VJG8L=BOV88@V8?8L=BRV8;8I]F%V8?B@(S9A]BG(@H*(SH@
M;&EB+TE-4"YP:'`Z.38V"FUS9VED(")%;7!T>2!?5')A<V@B"FUS9W-T<B`B
MV*[8I]F$VXP@VJG8L=BOV88@V+/8M]F$(-BBV+38NMBGV80B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z,2!T96UP;&%T97,O<&=P+VYO=&%C=&EV92YI
M;F,Z-@IM<V=I9"`B16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(*;7-G<W1R
M("+8HMN,V*<@V8+8I]BHV83;C-BJ(%!'4"#9@=BYV*?9A"#8M-F(V*_8GR(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,2!T96UP;&%T97,O<VUI
M;64O;F]T86-T:79E+FEN8SHV"FUS9VED(")%;F%B;&4@4R]-24U%(&9U;F-T
M:6]N86QI='D_(@IM<V=S='(@(MBBVXS8IR#9@MBGV*C9A-N,V*H@4R]-24U%
M(-F!V+G8I]F$(-BTV8C8K]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@Q,0IM<V=I9"`B16YA8FQE(&UE<W-A9V4@<')E=FEE=W,_(@IM<V=S='(@
M(MBBVXS8IR#9OMN,V+3B@(S9AMF%V*?;C-BTV8?8I]N,(-F^VXS8NMBGV84@
MV8'8N=BGV80@V+39B-BOV)\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT-#(*;7-G:60@(D5N8W)?>7!T:6]N($]P=&EO;G,B"FUS9W-T
M<B`BVJ_8LMN,V8;9A^*`C.*`C-F'V*?;C"#8L=F%V++8J-F&V*_;C"(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3<@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C8U-PIM<V=I9"`B16YD(@IM<V=S='(@(MBGV8;8JMF'V*<B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S@T"FUS9VED(")%;F0@9F]R=V%R9&5D
M(&UE<W-A9V4B"FUS9W-T<B`BV*?9AMBJV8?8I]N,(-F^VXS8NMBGV87B@(P@
MV*?8L=BLV*?8N2#8M-BOV8<B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S0Q"FUS
M9VED(")%;F0@;65S<V%G92(*;7-G<W1R("+8I]F&V*K9A]BGVXP@V;[;C-BZ
MV*?9A2(*"B,@"B,Z(&QI8B]#;VUP;W-E+G!H<#HS,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16YD(&UE<W-A9V4@9G)O;2`E<R(*;7-G<W1R("+8I]F&V*K9
MA]BGVXP@V;[;C-BZV*?9A2#8I]BR("5S(@H*(SH@=&5M<&QA=&5S+W-M:6UE
M+W-M:6UE+FEN8SHW,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@
M(D5N=&5R(%!A<W-P:')A<V4B"FUS9W-T<B`BV8C8I]BQV*_:J=BQV*_9AB#8
MN=BHV*?8L=BJ(-JOV+#8L2(*"B,Z('1E;7!L871E<R]P<F5F<R]S<&%M<V5L
M96-T+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@
M4W!A;2!F;VQD97(B"FUS9W-T<B`BV8;8I]F%(-F^V8C8M-F'V90@V8?8L=BR
MV8;8I]F%V8?9E"#8K-BOVXS8KR#8KMF(V*\@V+'8IR#9B-BGV+'8KR#:J=F&
MVXS8KR(*"B,Z('1E;7!L871E<R]P<F5F<R]F;VQD97)S96QE8W0N:6YC.CD*
M;7-G:60@(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!D<F%F=',@9F]L
M9&5R(@IM<V=S='(@(MF&V*?9A2#9OMF(V+39A]F4(-F^VXS8M"#9AMF(VXS8
MLR#8K-BOVXS8KR#8KMF(V*\@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KR(*"B,Z
M('1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E;&5C="YI;F,Z,C,*;7-G:60@
M(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!S96YT(&UA:6P@9F]L9&5R
M(@IM<V=S='(@(MF&V*?9A2#9OMF(V+39A]F4(-F&V*?9A=F'XH",V8?8I]N,
M(-BGV+'8L]BGV80@V+38K]F'(-BLV*_;C-BO(-BNV8C8KR#8L=BG(-F(V*?8
ML=BO(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+W!R969S+W1R87-H<V5L96-T
M+FEN8SHY"FUS9VED(")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@=')A
M<V@@9F]L9&5R(@IM<V=S='(@(MF&V*?9A2#9OMF(V+39A]F4(-BBV+38NMBG
MV80@V*S8K]N,V*\@V*[9B-BO(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\B"@HC
M.B!L:6(O4V5A<F-H+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B16YT:7)E($UE
M<W-A9V4B"FUS9W-T<B`BV878M-BGV8?8K]F'V90@V;[;C-BZV*?9A=F'V*<B
M"@HC(`HC.B!M97-S86=E+G!H<#HQ.30@8V]M<&]S92YP:'`Z,3$S-"!T:')E
M860N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')Y(%PB)7-<(B!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('1H92!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`BV8C8L=F(V*_;C"`E<R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C9
MAR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8I]BVV*?9@=F'(-BTV*\B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$X('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHR,0HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP.C,W-B!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HS.#8*(SH@;&EB+TU)344O5FEE=V5R
M+W-T871U<RYP:'`Z-S(@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z,38S
M"FUS9VED(")%<G)O<B(*;7-G<W1R("+8KMBWV*<B"@HC.B!L:6(O24U!4"]#
M;&EE;G0N<&AP.C0U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C;VYN
M96-T:6YG('1O($E-05`@<V5R=F5R+B`E<R`Z("5S+B(*;7-G<W1R("(B"@HC
M(`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,S`Y(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(MBNV+?8IR#8K]BQ(-F!V+'8
ML]BJV*?8K]F&(-F^V*?8L]BN.B5S(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C$P,0IM<V=I9"`B179E;G0@<W5C8V5S<V9U;&QY(&1E;&5T960N
M(@IM<V=S='(@(MBQV8C;C-BOV*?8KR#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@
MV*W8L-F!(-BTV*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@R"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(MF'V+$@V;[8I]F&V++8
MK]F'(-BOV8+;C-F"V8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<Y
M"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(MF'V+$@V+/;C"#8
MK]F"VXS9@MF'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X,0IM<V=I
M9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(MF'V+$@V;[9AMBL(-BOV8+;
MC-F"V8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@S"FUS9VED(")%
M=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BV8?8L2#9AMN,V84@V+/8I]BYV*HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@P"FUS9VED(")%=F5R>2!M
M:6YU=&4B"FUS9W-T<B`BV8?8L2#8K]F"VXS9@MF'(@H*(SH@9F]L9&5R<RYP
M:'`Z-#4W"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BV*C8I]BR(-JIV+'8K]F&
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@
M(D5X<&%N9"!!;&PB"FUS9W-T<B`BV*C8I]BRVJG8L=BOV88@V8?9A=F'(@H*
M(SH@=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,S@*;7-G:60@(D5X
M<&%N9"!!;&P@1F]L9&5R<R(*;7-G<W1R("+8J-BGV++:J=BQV*_9AB#9A]F%
MV8<@V;[9B-BTV8?B@(S9A]BG(@H*(SH@9F]L9&5R<RYP:'`Z-#4W"FUS9VED
M(")%>'!A;F0@1F]L9&5R(@IM<V=S='(@(MBHV*?8LMJIV+'8K]F&(-F^V8C8
MM-F'(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S0P('1E
M;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8SHU,PIM<V=I9"`B17AP86YD
M($YA;65S(@IM<V=S='(@(MBHV*?8LMJIV+'8K]F&(-BGV+/9A=F'V*<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V,PIM<V=I9"`B17AP86YD(&YA
M;65S(&EN('1H92!C;VUP;W-E('=I;F1O=R!A=71O;6%T:6-A;&QY(&EN('1H
M92!B86-K9W)O=6YD/R(*;7-G<W1R("+8HMN,V*<@V*?8L]BGV87;C"#8J-BW
MV8C8L2#8KMF(V*_:J=BGV+$@V*_8L2#9OMBSXH",V++9A=N,V8;9A]F4(-BU
MV+K8K=F'V90@V*?;C-BLV*?8KR#9OMN,V+K8I]F%(-BHV*?8LB#8M-F(V8;8
MK]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX,`IM<V=I9"`B17AP
M86YD('1H92!E;G1I<F4@9F]L9&5R('1R964@8GD@9&5F875L="!I;B!T:&4@
M9F]L9&5R<R!V:65W/R(*;7-G<W1R("+8HMN,V*<@V*C8M]F(V+$@V;[;C-BT
M(-F!V+'8MB#8K]BQ(-BHV*[8M"#9AMF%V*?;C-BT(-F^V8C8M-F'XH",V8?8
MI]B,(-BJV878I]F%VXP@V*_8L=BNV*H@V;[9B-BTV8<@V*C8I]BR(-BTV8C8
MK]B?(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,30T('1E
M;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C$Y-`HC.B!T96UP;&%T97,O
M8V]M<&]S92]C;VUP;W-E+FEN8SHR-#4@=&5M<&QA=&5S+V-O;7!O<V4O<F5D
M:7)E8W0N:6YC.C$P,0IM<V=I9"`B17AP86YD:6YG(@IM<V=S='(@(MBHV*?8
MLB#:J=BQV*_9AB(*"B,Z(&QI8B])35`N<&AP.CDX-"!L:6(O24U0+G!H<#HY
M.#8*(RP@9G5Z>GD*;7-G:60@(D9?971C:"!-86EL(@IM<V=S='(@(MF(V*?:
MJ=BTVXP@V8;8I]F%V8<B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H
M;6%I;"YI;F,Z,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-`IM<V=I9"`B
M1F5T8V@@36%I;"(*;7-G<W1R("+9B-BGVJG8M-N,(-F&V*?9A=F'(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V.0IM<V=I9"`B1F5T8V@@36%I;"!I
M;B!A('-E<&%R871E('=I;F1O=S\B"FUS9W-T<B`BV*+;C-BG(-F&V*?9A=F'
M(-BOV+$@V;[9AMBLV+'9A]F4(-BLV*_8I]JOV*?9AMF'XH",V*?;C-N,(-F(
MV*?:J=BTVXP@V+39B-BOV)\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA
M;F%G92YI;F,Z-#8*;7-G:60@(D9E=&-H(&UE<W-A9V5S('5P;VX@;&]G9VEN
M9R!O;C\B"FUS9W-T<B`BV*+;C-BG(-F^VXS8NMBGV879A]BG(-BHV878K=BV
M(-F(V+'9B-BO(-F(V*?:J=BTVXP@V+39B-F&V*_8GR(*"B,@"B,Z(&QI8B]&
M971C:&UA:6PN<&AP.C(X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&971C:&5D
M("5D(&UE<W-A9V5S(&9R;VT@)7,B"FUS9W-T<B`B)60@V;[;C-BZV*?9A2#8
MI]BR("5S(-F(V*?:J=BTVXP@V+38K]F&V*\B"@HC(`HC.B!L:6(O1F5T8VAM
M86EL+G!H<#HR.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F5T8VAE9"`Q(&UE
M<W-A9V4@9G)O;2`E<R(*;7-G<W1R("+;C-JI(-F^VXS8NMBGV84@V*?8LB`E
M<R#9B-BGVJG8M-N,(-BTV*\B"@HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.#4@
M;&EB+T9E=&-H;6%I;"YP:'`Z,C@W(&QI8B]&971C:&UA:6PN<&AP.C(X.0IM
M<V=I9"`B1F5T8VAM86EL.B`B"FUS9W-T<B`BV8C8I]JIV+3;C"#9AMBGV879
MASHB"@HC(`HC.B!L:6(O1F5T8VAM86EL+G!H<#HR.3$*;7-G:60@(D9E=&-H
M;6%I;#H@;F\@;F5W(&UE<W-A9V5S+B(*;7-G<W1R("+9B-BGVJG8M-N,(-F&
MV*?9A=F'.B#9AMBGV879A]F4(-BLV*_;C-BOVXP@V8C8K-F(V*\@V8;8K]BG
MV+'8KR(*"B,Z(&QI8B])35`N<&AP.CDY,`IM<V=I9"`B1FE?;'1E<G,B"FUS
M9W-T<B`BV8';C-F$V*K8L=F'V*<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHU,#(@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H;65N=',N
M:G,Z.#(*;7-G:60@(D9I;&4B"FUS9W-T<B`BV;[8L=F(V8;8K]F'XH",(@H*
M(SH@=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC.C,Q"FUS9VED(")&:6QT
M97(@3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-F!VXS9
MA-BJV+$B"@HC.B!T96UP;&%T97,O9FEL=&5R<R]P<F5F<RYI;F,Z.0IM<V=I
M9"`B1FEL=&5R(%-E='1I;F=S(@IM<V=S='(@(MBJV8;8N-N,V878I]BJ(-F!
MVXS9A-BJV+$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C`P"FUS9VED
M(")&:6QT97(@;65S<V%G92!C;VYT96YT(&9O<B!P<F]F86YI='D_(@IM<V=S
M='(@(MBBVXS8IR#9A=BVV879B-F&(-F^VXS8NMBGV84@V*C8L=BGVXP@V*C;
MC.*`C-BMV+'9A=BJVXP@V*C9AR#9A=F"V*_8L]BGV*H@V8';C-F$V*K8L2#8
MM-F(V*_8GR(*"B,Z('1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,Z
M,3$*;7-G:60@(D9I;'1E<B!S=7!P;W)T(&ES(&1I<V%B;&5D(&]N('1H:7,@
M<WES=&5M+B(*;7-G<W1R("+9OMBTV*K;C-BHV*?9AMN,(-F!VXS9A-BJV+$@
MV*C8L2#8L=F(VXP@V*?;C-F&(-BSV*?9A=BGV8;9AR#9@=BYV*?9A"#9AMN,
MV+/8JB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(D9I
M;'1E<G,B"FUS9W-T<B`BV8';C-F$V*K8L=F'V*<B"@HC.B!T96UP;&%T97,O
M9FEL=&5R<R]N;W1A8W1I=F4N:6YC.C,*;7-G:60@(D9I;'1E<G,@3D]4($%C
M=&EV92(*;7-G<W1R("+9@=N,V838JMBQXH",V8?8IR#9@=BYV*?9A"#9AMN,
MV+/8JMF&V*\B"@HC(`HC.B!L:6(O1FEL=&5R+G!H<#HQ,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL=&5R<SH@)7,@;6%N86=E;65N="!P86=E(@IM<V=S
M='(@(MF!VXS9A-BJV+'9A]BG.B`E<R#8M=F!V*W9A]F4(-F%V*_;C-BQVXS8
MJB(*"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3@V"FUS
M9VED(")&:6YD(@IM<V=S='(@(MF^VXS8K]BGVJG8L=BOV88B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3`U"FUS9VED(")&:7)S="!-86EL8F]X(%!A
M9V4B"FUS9W-T<B`BV+79@=BMV8?9E"#8I]F(V80@V8;8I]F%V8?B@(S8K]BG
MV88@(@H*(SH@;6%I;&)O>"YP:'`Z,S0U"FUS9VED(")&:7)S="!086=E(@IM
M<V=S='(@(MBUV8'8K=F'V90@V*?9B-F$(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$U('1E;7!L871E<R]M86EL8F]X+V%C
M=&EO;G,N:6YC.C(Q"FUS9VED(")&;U]R=V%R9"(*;7-G<W1R("+8I]BQV*S8
MI]BY(@H*(SH@9F]L9&5R<RYP:'`Z,C8V('1E;7!L871E<R]F;VQD97)S+V9O
M;&1E<G-?8V]N9FER;2YH=&UL.C4*;7-G:60@(D9O;&1E<B!!8W1I;VYS("T@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(MBYV879A-N,V*?8JB#9OMF(V+39AR`M
M(-BJV*/;C-N,V*\B"@HC.B!F;VQD97)S+G!H<#HS,#,@=&5M<&QA=&5S+V9O
M;&1E<G,O:&5A9"YI;F,Z.0HC.B!T96UP;&%T97,O<')E9G,O:6YI=&EA;'!A
M9V5S96QE8W0N:6YC.C8*(SH@=&5M<&QA=&5S+W!R969S+VEN:71I86QP86=E
M<V5L96-T+FEN8SHQ,`IM<V=I9"`B1F]L9&5R($YA=FEG871O<B(*;7-G<W1R
M("+9AMBGV8C8M-JOV+$@V;[9B-BTV8<B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,PIM<V=I9"`B1F]L9&5R(%-U;6UA<GDB"FUS9W-T<B`BV*[9A-BG
MV+79A]F4(-F^V8C8M-F'(@H*(SH@86-L+G!H<#HR-`IM<V=I9"`B1F]L9&5R
M('-H87)I;F<@:7,@;F]T(&5N86)L960N(@IM<V=S='(@(MBHV8<@V*?8M-BJ
MV+'8I]JI(-JOV+#8I]BTV*K9AB#9OMF(V+39AR#9A=F"V*_9B-BQ(-F&VXS8
ML]BJ(@H*(SH@9F]L9&5R<RYP:'`Z-C(*;7-G:60@(D9O;&1E<B!U<V4@:7,@
M;F]T(&5N86)L960N(@IM<V=S='(@(MBGV+/8JMF!V*?8K]F'(-BGV+(@V;[9
MB-BTV8<@V879@MBOV8C8L2#9AMN,V+/8JB(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-CD*;7-G:60@(D9O<FUA="!O9B!M97-S86=E(&1A=&5S(&EN
M('1H92!M86EL8F]X('9I97<@9F]R(&UE<W-A9V5S(&1A=&5D('1O9&%Y(@IM
M<V=S='(@(MF!V+'9A=BJ(-BJV*?8L=N,V*X@V8;8I]F%V8<@V*_8L2#9AMBG
MV879A^*`C-BOV*?9AB#8J-BQV*?;C"#9AMBGV879A^*`C-F'V*?;C"#8I]F%
MV+'9B-BR("(*"B,Z(&-O;7!O<V4N<&AP.C<X,"!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,34*(SH@=&5M<&QA=&5S+VUA:6QB;W@O
M86-T:6]N<RYI;F,Z,C$*;7-G:60@(D9O<G=A<F0B"FUS9W-T<B`BV*?8L=BL
MV*?8N2(*"B,Z(&-O;7!O<V4N<&AP.C<V-0IM<V=I9"`B1F]R=V%R9#HB"FUS
M9W-T<B`B.MBGV+'8K-BGV+DB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,S8Y"FUS
M9VED(")&;W)W87)D960@;65S<V%G92(*;7-G<W1R("+9OMN,V+K8I]F%(-BG
MV+'8K-BGV+D@V+38K]F'(@H*(R`*(SH@;&EB+T-O;7!O<V4N<&AP.C,V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&;W)W87)D960@;65S<V%G92!F<F]M("5S
M(@IM<V=S='(@(MF^VXS8NMBGV84@V*?8L=BLV*?8N2#8M-BOV8<@V*?8LB`E
M<R(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HT.#,*;7-G:60@(D9R
M964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("+8I]BWV838I]BYV*?8JB#8
MHMBRV*?8KR_9A=BTV+K9B-F$(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N
M<&AP.C0Y-`IM<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(MF^V*?8
ML]BN(-BBV++8I]BO+]F%V+38NMF(V80B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#@X"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R
M("+8K]BQV*[9B-BGV+/8JB#8HMBRV*?8KR_9A=BTV+K9B-F$(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C0P,0IM<V=I9"`B1G)E92]"=7-Y(%)E
M<75E<W0@4F5S<&]N<V4B"FUS9W-T<B`BV;[8I]BSV*X@V*_8L=BNV8C8I]BS
MV*H@V*+8LMBGV*\OV878M-BZV8C9A"(*"B,Z('1E;7!L871E<R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C<*;7-G:60@(D9R;U]M(@IM<V=S='(@
M(MBGV+(B"@HC.B!M97-S86=E+G!H<#HR-C,@=&AR96%D+G!H<#HQ-#D@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z.3D*(SH@;&EB+U-E87)C:"YP
M:'`Z,C(*;7-G:60@(D9R;VTB"FUS9W-T<B`BV*?8LB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,3@*;7-G:60@(D9R;VT@061D<F5S<R(*;7-G<W1R
M("+8I]BR(-BBV*_8L=BS(@H*(SH@8V]M<&]S92YP:'`Z-S<W(&-O;7!O<V4N
M<&AP.C<X,0IM<V=I9"`B1G=D.B(*;7-G<W1R("+8I]BQV*S8I]BY.B(*"B,Z
M(&-O;7!O<V4N<&AP.C$R.30*;7-G:60@(D9W9#H@(@IM<V=S='(@(MBGV+'8
MK-BGV+DZ(@H*(R`*(SH@8V]M<&]S92YP:'`Z,3(Y-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&=V0Z("5U($9O<G=A<F1E9"!-97-S86=E<R(*;7-G<W1R("+8
MI]BQV*S8I]BY.B`E=2#9OMN,V+K8I]F%V8?8I]N,(-BGV+'8K-BGV+D@V+38
MK]F'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X"FUS9VED(")'96YE<F%L($]P=&EO;G,B
M"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"#8N=F%V8C9A=N,(@H*(SH@
M=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C,W"FUS9VED(")'970@
M;VYL>2!N97<@;65S<V%G97,_("A)34%0(&]N;'DI(@IM<V=S='(@(MBBVXS8
MIR#9@=F"V+<@V;[;C-BZV*?9A=F'V*?;C"#8K-BOVXS8KR#:K]BQV8'8JMF'
M(-BTV8C9AMBOV)\@*-F!V8+8MR!)34%0*2(*"B,Z('1E;7!L871E<R]F;VQD
M97)S+V%C=&EO;G,N:6YC.C,Q"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!T
M:')E860N<&AP.C$S-@IM<V=I9"`B1V\@=&\@365S<V%G92(*;7-G<W1R("+8
MJ-BGV++:K]BTV*H@V*C9AR#9OMN,V+K8I]F%(@H*(SH@;&EB+TE-4"YP:'`Z
M-#DX"B,L('!H<"UF;W)M870*;7-G:60@(D=O('1O(&%D9')E<W,@8F]O:R!E
M;G1R>2!O9B!<(B5S7"(B"FUS9W-T<B`BV*C8L=F((-BHV8<@V8C8L=F(V*_;
MC"#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR!<(B5S7"(@(@H*(SH@=&5M<&QA
M=&5S+V%C;"]A8VPN:6YC.C$S-0IM<V=I9"`B1W)A;G0@86-C97-S(@IM<V=S
M='(@(MF(V*?:K]BPV*?8L=N,(-BOV+/8JMBQV+/;C"(*"B,Z(&UE<W-A9V4N
M<&AP.C4T-B!L:6(O1FEL=&5R+G!H<#HQ,#4@;&EB+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.34*(SH@;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z,3`R
M(&QI8B]-24U%+U9I97=E<B]I;6%G97,N<&AP.C$P-`HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HQ-C,@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$Q-@HC.B!L:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV,B!L
M:6(O34E-12]6:65W97(O;F]T:69I8V%T:6]N+G!H<#HV.`HC.B!L:6(O34E-
M12]6:65W97(O<F5L871E9"YP:'`Z-SD@;&EB+TU)344O5FEE=V5R+W!K8W,W
M+G!H<#HT,3@*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT
M,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-S,*(SH@;&EB+TU)344O5FEE
M=V5R+W-T871U<RYP:'`Z,3(P(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP
M.C$R-PIM<V=I9"`B2$5212(*;7-G<W1R("+8I]N,V8;8K-BG(@H*(SH@=&5M
M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C,Q(&QI8B]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,3<*(SH@;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP
M.C@P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!C;VUP;W-E+G!H
M<#HR-38*;7-G:60@(DA434P@5F5R<VEO;B!O9B!-97-S86=E(@IM<V=S='(@
M(MF&V+/8KMF'V90@2%1-3"#8I]BR(-F^VXS8NMBGV84B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]H96%D97)S+FEN8SHU.`IM<V=I9"`B2&5A9&5R<R(*;7-G
M<W1R("+8L]BQV*+9A=BOV8?8IR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M8V]M<&]S92YI;F,Z-0IM<V=I9"`B2&5R92!I<R!T:&4@;65S<V%G92!Y;W4@
M=V5R92!C;VUP;W-I;F<Z(@IM<V=S='(@(MBGVXS9AMBLV*<@V;[;C-BZV*?9
MA=N,(-BGV+/8JB#:J=F'(-BTV878IR#9AMF(V+38JMF'XH",V*?B@(S;C-BO
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-C@*;7-G:60@(DAI9&1E
M;B(*;7-G<W1R("+9OMF&V8?8I]F&(-JIV+'8K]F&(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8V-PIM<V=I9"`B2&ED9&5N(&EN(%1H<F5A9"!6:65W
M(@IM<V=S='(@(MF^V8;9A]BGV88@VJG8L=BOV88@V*_8L2#9AMF%V*?;C-BT
M(-BSV838L]F$V8?B@(S8I]N,VXP@(@H*(SH@;6%I;&)O>"YP:'`Z,S8W"FUS
M9VED(")(:61E($1E;&5T960B"FUS9W-T<B`BXH"-V;[9AMF'V*?9AB#:J=BQ
MV*_9AB#8K=BPV8$@V+38K]F'XH",V8?8IR(*"B,Z(&9O;&1E<G,N<&AP.C(Y
M.`IM<V=I9"`B2&ED92!5;G-U8G-C<FEB960B"FUS9W-T<B`BV;[9AMF'V*?9
MAB#:J=BQV*_9AB#8NMN,V+'8N=BVV8CB@(S9A]BG(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDT"FUS9VED(")(:6=H(@IM<V=S='(@
M(MBHV*?9A-BG(@H*(SH@;65S<V%G92YP:'`Z,CDW(&UA:6QB;W@N<&AP.C<R
M-"!T96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$R"FUS9VED(")(:6=H
M(%!R:6]R:71Y(@IM<V=S='(@(MBGV8C9A-F(VXS8JB#8J-BGV838IR(*"B,Z
M('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C(Y,PIM<V=I9"`B2&EG
M:&5S="(*;7-G<W1R("+8J-BGV838I]BJV+';C-F&(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8X.`IM<V=I9"`B2&]W(&1O('EO=2!W86YT('1O(&1I
M<W!L87D@871T86-H;65N=',_(@IM<V=S='(@(MJ&VJ_9B-F&VJ_;C"#9AMF%
MV*?;C-BT(-F^VXS9B-BSV*KB@(S9A]BG(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P-`IM<V=I9"`B2&]W('1O(&%T=')I8G5T92!Q=6]T960@;&EN
M97,@:6X@82!R97!L>2(*;7-G<W1R("+:AMJOV8C9AMJOVXP@V878M-BNV+4@
MVJG8L=BOV88@V*[8M]F'V*?;C"#9AMF"V80@V8+9B-F$(-BOV+$@VXS:J2#9
MOMBGV+/8KB(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3,T"FUS9VED
M("))34%0(@IM<V=S='(@(DE-05`B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C$R.0IM<V=I9"`B24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*2(*
M;7-G<W1R("))34%0("C9OMN,V*_8IR#:J=BQV*_9AB#9OMBQV8C8JMJIV839
MA]BG(-BHV+?9B-BQ(-BNV8C8K]JIV*?8L2DB"@HC.B!L:6(O24U!4"]#;&EE
M;G0N<&AP.C,Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(%-E<G9E<B!C
M;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD960Z("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,38V(&QI
M8B]&971C:&UA:6PO:6UA<"YP:'`Z,30V"FUS9VED("))34%0(&]V97(@4U-,
M(@IM<V=S='(@(DE-05`@V+'9B-N,(%-33"(*"B,Z(&QI8B]&971C:&UA:6PO
M:6UA<"YP:'`Z,34R"FUS9VED("))34%0(&]V97(@4U-,("AS96QF+7-I9VYE
M9"!C97)T:69I8V%T92DB"FUS9W-T<B`B24U!4"#8J-BQ(%-33"`HVJ_9B-BG
MV8?;C"#8KMF(V*_8I]F%V+;8I]BA*2`B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$V-PIM<V=I9"`B24U!4"!O=F5R(%-33"`H<V5L9BUS:6=N
M960I(@IM<V=S='(@(DE-05`@V*C8L2!34TPHVJ_9B-BGV8?;C"#8KMF(V*_8
MI]F%V+;8I]BA*2`B"@HC.B!L:6(O24U!4"]#;&EE;G0N<&AP.C,V.`HC+"!F
M=7IZ>0IM<V=I9"`B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N
M+B(*;7-G<W1R("+9AMF(V+D@VJG8I]BQV+/8I]BR(-F&V*?9A=F'V90@V*?9
MA-JIV*K8L=F(V8;;C-JIVXP@V*C8L=BGVXP@V878JMBUV80@V+38K]F&(-BH
MV8<Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-C4@;&EB+T9E
M=&-H;6%I;"]I;6%P+G!H<#HQ-#`*;7-G:60@(DE-05`L(&YO(%1,4R(*;7-G
M<W1R("))34%0(-B,V8;9AR!43%,B"@HC.B!L:6(O1F5T8VAM86EL+VEM87`N
M<&AP.C0Y"FUS9VED("))34%0+U!/4#,@36%I;"!397)V97)S(@IM<V=S='(@
M(MJIV*?8L=BSV*?8LMF'V*?;C"#9AMBGV879A^*`C-F'V*?;C"#8I]F$VJG8
MJMBQV8C9AMN,VJG;C"!)34%0+U!/4#,B"@HC.B!L:6(O24U0+G!H<#HX-C8*
M;7-G:60@(DE.0D]8(@IM<V=S='(@(DE.0D]8(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HT,3$*;7-G:60@(DEF('5S:6YG(%-33"!O<B!43%,L('EO=2!M
M=7-T(&AA=F4@=&AE(%!(4"!O<&5N<W-L(&5X=&5N<VEO;B!L;V%D960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?8V]N9FER
M;2YH=&UL.C$R"FUS9VED("))9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E
M<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S="$B"FUS9W-T<B`BV*_8
ML2#8M=F(V+'8JB#8I]BOV*?9A=F'V(P@V*K9A=BGV87;C"#9OMN,V+K8I]F%
MV8?8IR#8K]BQ(-BGVXS9AB#9OMF(V+39ARC9A]BG*2#8I]BR(-BHVXS9AB#8
MKMF(V*?9A]BO(-BQV8'8JB$B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L
M;&EN9RYI;F,Z.#(*;7-G:60@(DEG;F]R92(*;7-G<W1R("+9AMBGV*_;C-BO
MV8<@VJ_8L=F!V*K9AB(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W-P96QL:6YG
M+FEN8SHX,PIM<V=I9"`B26=N;W)E($%L;"(*;7-G<W1R("+9AMBGV*_;C-BO
MV8<@VJ_8L=F!V*K9AB#9A]F%V8<B"@HC.B!T96UP;&%T97,O<V%V96EM86=E
M+W-A=F5I;6%G92YI;F,Z.`IM<V=I9"`B26UA9V4B"FUS9W-T<B`BV*K8M=F(
MVXS8L2(*"B,Z('1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,Z,C`*;7-G
M:60@(DEM<&]R="(*;7-G<W1R("+8K]BQV8C9AN*`C-BHV+'8KR(*"B,Z('1E
M;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHX-2!T96UP;&%T97,O<&=P
M+VEM<&]R=%]K97DN:6YC.C8U"FUS9VED("));7!O<G0@2V5Y(@IM<V=S='(@
M(MBOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C$S.0IM<V=I9"`B26UP;W)T($ME>7!A:7(B"FUS9W-T<B`B
MV*_8L=F(V8;B@(S8J-BQV*\@V*S9@=BJ(-JIV83;C-BO(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C<*;7-G:60@(DEM<&]R="!-97-S
M86=E<R(*;7-G<W1R("+8K]BQV8C9AN*`C-BHV+'8KR#9OMN,V+K8I]F%V8?8
MIR(*"B,Z('!G<"YP:'`Z-#(*;7-G:60@(DEM<&]R="!01U`@2V5Y(@IM<V=S
M='(@(MBOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(%!'4"(*"B,Z('1E;7!L
M871E<R]S;6EM92]S;6EM92YI;F,Z.3$*;7-G:60@(DEM<&]R="!097)S;VYA
M;"!#97)T:69I8V%T92(*;7-G<W1R("+8K]BQV8C9AN*`C-BHV+'8KR#:K]F(
MV*?9A]N,V8?8I]N,(-BTV*[8M=N,(@H*(SH@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHQ-`IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!R:79A=&4@
M4$=0($ME>2(*;7-G<W1R("+8K]BQV8C9AN*`C-BHV+'8KR#:J=F$VXS8KR#8
MKMBUV8C8M=N,(-BTV*[8M=N,(%!'4"(*"B,Z('1E;7!L871E<R]P9W`O:6UP
M;W)T7VME>2YI;F,Z.0IM<V=I9"`B26UP;W)T(%!E<G-O;F%L(%!U8FQI8R!0
M1U`@2V5Y(@IM<V=S='(@(MBOV+'9B-F&XH",V*C8L=BO(-JIV83;C-BO(-BY
MV879B-F%VXP@V+38KMBUVXP@4$=0("(*"B,Z('1E;7!L871E<R]S;6EM92]I
M;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4&5R<V]N86P@4R]-24U%
M($-E<G1I9FEC871E<R(*;7-G<W1R("+8K]BQV8C9AN*`C-BHV+'8KR#:K]F(
MV*?9A]N,V8?8I]N,(%,O34E-12#8M-BNV+7;C"(*"B,Z('1E;7!L871E<R]S
M;6EM92]S;6EM92YI;F,Z-#`@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C0R"FUS
M9VED("));7!O<G0@4'5B;&EC($ME>2(*;7-G<W1R("+8K]BQV8C9AN*`C-BH
MV+'8KR#:J=F$VXS8KR#8N=F%V8C9A=N,(@H*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHT"FUS9VED("));7!O<G0@4'5B;&EC(%!'4"!+97DB
M"FUS9W-T<B`BV*_8L=F(V8;B@(S8J-BQV*\@VJG9A-N,V*\@V+G9A=F(V87;
MC"!01U`B"@HC.B!T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z.`IM
M<V=I9"`B26UP;W)T(%!U8FQI8R!3+TU)344@2V5Y(@IM<V=S='(@(MBOV+'9
MB-F&XH",V*C8L=BO(-JIV83;C-BO(%,O34E-12#8N=F%V8C9A=N,("(*"B,Z
M('-M:6UE+G!H<#HQ-@IM<V=I9"`B26UP;W)T(%,O34E-12!+97DB"FUS9W-T
M<B`BV*_8L=F(V8;B@(S8J-BQV*\@VJG9A-N,V*\@4R]-24U%(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O:6UP;W)T+FEN8SHY"FUS9VED("));7!O<G0@;6)O
M>"!&:6QE(@IM<V=S='(@(MBOV+'9B-F&XH",V*C8L=BO(-F^V+'9B-F&V*_9
MA]F4XH",(&UB;W@B"@HC(`HC.B!T96UP;&%T97,O9F]L9&5R<R]I;7!O<G0N
M:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="!M8F]X(&9I;&4@
M)7,@:6YT;R!F;VQD97(@)7,N(@IM<V=S='(@(MBOV+'9B-F&XH",V*C8L=BO
M(-F^V+'9B-F&V*_9A]F4XH",("5S(&UB;W@@V*_8L2#9OMF(V+39A]F4("5S
M(@H*(SH@;65S<V%G92YP:'`Z-3`R(&UA:6QB;W@N<&AP.C<S-"!T96UP;&%T
M97,O;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C<*(SH@=&5M<&QA=&5S
M+VUA:6QB;W@O;F%V8F%R+FEN8SHQ-B!T96UP;&%T97,O;6%I;&)O>"]N879B
M87(N:6YC.C,S"B,Z('1E;7!L871E<R]M86EL8F]X+VQE9V5N9"YI;F,Z-PIM
M<V=I9"`B26UP;W)T86YT(@IM<V=S='(@(MF%V8?9A2(*"B,Z('1E;7!L871E
M<R]S96%R8V@O;6%I;BYI;F,Z-#<*;7-G:60@(DEM<&]R=&%N="!M97-S86=E
M<R(*;7-G<W1R("+9OMN,V+K8I]F%V8?8I]N,(-F%V8?9A2(*"B,@"B,Z(&9O
M;&1E<G,N<&AP.C$V-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"`E
M9"!M97-S86=E<R!F<F]M("5S+B(*;7-G<W1R("(E9"#9OMN,V+K8I]F%(-BG
MV+(@)7,@V*_8L=F(V8;B@(S8J-BQV*\@V+38KR(*"B,Z(&QI8B]-24U%+U9I
M97=E<B]I=&EP+G!H<#HW-S,*;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T<B`B
MV*_8L2#8K=BGV80@V*?9AMBLV*?9A2(*"B,Z(&9O;&1E<G,N<&AP.C,X-"!L
M:6(O1F]L9&5R+G!H<#HX-B!L:6(O1F]L9&5R+G!H<#HR,30@;&EB+TE-4"YP
M:'`Z,S$S"B,Z(&QI8B])34%0+U1R964N<&AP.C$Q-"!L:6(O24U!4"]4<F5E
M+G!H<#HR,3D*;7-G:60@(DEN8F]X(@IM<V=S='(@(DEN8F]X(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0Y,@IM<V=I9"`B26YC;'5D92!A(&)R:65F
M('-U;6UA<GD@;V8@=&AE(&AE861E<B!I;B!A(')E<&QY/R(*;7-G<W1R("+8
MHMN,V*<@V;[8I]BSV*X@V+38I]F%V80@VXS:J2#8KMF$V*?8M=F'(-BGV+(@
MV+/8L=BBV878KR#8J-BGV+38K]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0X-PIM<V=I9"`B26YC;'5D92!O<FEG:6YA;"!M97-S86=E(&EN(&$@
M<F5P;'D_(@IM<V=S='(@(MBBVXS8IR#9OMBGV+/8KB#8M-BGV879A"#9OMN,
MV+K8I]F%(-BGV+79A-N,(-BHV*?8M-BOV)\B"@HC.B!L:6(O34E-12]6:65W
M97(O;F]T:69I8V%T:6]N+G!H<#HV,2!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HQ,S`*;7-G:60@(DEN9F\B"FUS9W-T<B`BV*?8M]F$V*?8N=BGV*HB
M"@HC(`HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E
M<R]P9W`O<&=P+FEN8SHR-PHC+"!P:'`M9F]R;6%T"FUS9VED("));F9O<FUA
M=&EO;B!O;B`E<R!0=6)L:6,@2V5Y(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ
M(-BHV+$@V+'9B-N,(-JIV83;C-BO(-BYV879B-F%VXP@)7,B"@HC.B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(DEN9F]R;6%T:6]N(&]N(%!E
M<G-O;F%L(%!R:79A=&4@2V5Y(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ(-BH
MV+$@V+'9B-N,(-JIV83;C-BO(-BNV+79B-BUVXP@V+38KMBUVXPB"@HC.B!T
M96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P
M+FEN8SHW,@IM<V=I9"`B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC
M($ME>2(*;7-G<W1R("+8I]BWV838I]BYV*?8JB#8J-BQ(-BQV8C;C"#:J=F$
MVXS8KR#8N=F%V8C9A=N,(-BTV*[8M=N,(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O871T86-H;65N=',N:6YC.C$U('1E;7!L871E<R]C;VUP;W-E+V-O;7!O
M<V4N:6YC.C4P-PHC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT<RYJ
M<SHY.`IM<V=I9"`B26YL:6YE(@IM<V=S='(@(MBOV+$@V*[8MR(*"B,Z('1E
M;7!L871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHY"FUS9VED("));G-E<G0@
M0V5R=&EF:6-A=&4@2&5R92(*;7-G<W1R("+:K]F(V*?9A]N,(-BQV*<@V*?;
MC-F&V*S8IR#8K]BQV*P@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O<&=P+VEM
M<&]R=%]K97DN:6YC.C$U"FUS9VED("));G-E<G0@4&5R<V]N86P@4')I=F%T
M92!01U`@2V5Y($AE<F4B"FUS9W-T<B`BVJG9A-N,V*\@V878K=BQV878I]F&
MV8?9E"#8M-BNV+7;C"!01U`@V+'8IR#8I]N,V8;8K-BG(-BOV+'8K"#:J=F&
MVXS8KR(*"B,Z('1E;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,Z,3`*;7-G
M:60@(DEN<V5R="!097)S;VYA;"!0=6)L:6,@4$=0($ME>2!(97)E(@IM<V=S
M='(@(MJIV83;C-BO(-BYV879B-F%VXP@V+38KMBUVXP@4$=0(-BQV*<@V*?;
MC-F&V*S8IR#8K]BQV*P@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O<&=P+VEM
M<&]R=%]K97DN:6YC.C4*;7-G:60@(DEN<V5R="!0=6)L:6,@4$=0($ME>2!(
M97)E(@IM<V=S='(@(MJIV83;C-BO(-BYV879B-F%VXP@4$=0(-BQV*<@V*?;
MC-F&V*S8IR#8K]BQV*P@VJG9AMN,V*\B"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-#$R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E9"!F
M;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(MBYV879A"#8NMN,V+'9A=BY
MV*K8J-BQVXP@V*C8L=BGVXP@V*?;C-F&(-F%V*39A-F!V8<@V*?9AMBJV*[8
MI]BH(-BTV*_9AR#8I]BSV*HB"@HC.B!M86EL8F]X+G!H<#HU.#0@;6%I;&)O
M>"YP:'`Z-C(V"FUS9VED("));G9A;&ED($%D9')E<W,B"FUS9W-T<B`BV*+8
MK]BQV+,@V+K;C-BQV878N=BJV*C8L2(*"B,Z(&QI8B]&971C:&UA:6PO:6UA
M<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(%)E;6]T92!-86EL8F]X(@IM<V=S
M='(@(MF&V*?9A=F'XH",V*_8I]F&(-BQV*?9AR#8K]F(V+$@V+K;C-BQV878
MN=BJV*C8L2(*"B,Z(&-O;7!O<V4N<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("));G9A;&ED(&-H87)A8W1E<B!I;B!E+6UA:6P@861D<F5S<SH@)7,N
M(@IM<V=S='(@(MF&V8C;C-BSV8?9E"#8NMN,V+'9A=BYV*K8J-BQ(-BOV+$@
MV*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2`Z("5S(@H*(SH@
M<VUI;64N<&AP.C@R('!G<"YP:'`Z,38*;7-G:60@(DEN=F%L:60@:V5Y(@IM
M<V=S='(@(MJIV83;C-BO(-BZVXS8L=F%V+G8JMBHV+$B"@HC.B!P9W`N<&AP
M.C$Y-@IM<V=I9"`B26YV86QI9"!P97)S;VYA;"!01U`@<')I=F%T92!K97DN
M(@IM<V=S='(@(MJIV83;C-BO(-BZVXS8L=F%V+G8JMBHV+$@V878K=BQV878
MI]F&V8?9E"#8M-BNV+7;C"!01U`@(@H*(SH@<&=P+G!H<#HQ-S$*;7-G:60@
M(DEN=F%L:60@<&5R<V]N86P@4$=0('!U8FQI8R!K97DN(@IM<V=S='(@(MJI
MV83;C-BO(-BZVXS8L=F%V+G8JMBHV+$@V+G9A=F(V87;C"#8M-BNV+7;C"!0
M1U`B"@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C$R"FUS9VED
M("));G9E<G0B"FUS9W-T<B`BV878N=JIV8C8LR(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C4W-PIM<V=I9"`B2T(B"FUS9W-T<B`BVJG;
MC-F$V8C8J-BGVXS8JB(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHQ,3,*
M;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`BV+?9B-F$(-JIV83;C-BO(@H*
M(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$S-PIM<V=I9"`B(@HB2V5Y(&=E
M;F5R871I;VX@;6%Y('1A:V4@82!L;VYG('1I;64@=&\@8V]M<&QE=&4N("!#
M;VYT:6YU92!W:71H(&ME>2`B"B)G96YE<F%T:6]N/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C,U('1E;7!L871E<R]P9W`O
M<&=P+FEN8SHS-PIM<V=I9"`B2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE
M+B!&:6QE('5P;&]A9"!I<R!N;W0@96YA8FQE9"!O;B!T:&ES('-E<G9E<BXB
M"FUS9W-T<B`BV*_8L=F(V8;B@(S8J-BQV*\@VJG9A-N,V*\@V*_8L2#8K]BS
MV*K8L=BS(-F&VXS8L]BJ+B#8I]BQV+/8I]F$(-F!V*?;C-F$(-BHV+$@V+'9
MB-N,(-BGVXS9AB#:J=BGV+'8L]BGV+(@V879@MBOV8C8L2#9AMN,V+/8JB(*
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z,S<@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C,Y"FUS9VED("(B"B)+97D@:6UP;W)T(&ES(&YO="!A=F%I
M;&%B;&4N(%EO=2!H879E(&YO(&%D9')E<W,@8F]O:R!D969I;F5D('1O(&%D
M9"!Y;W5R("(*(F-O;G1A8W1S+B(*;7-G<W1R("(B"B+8K]BQV8C9AN*`C-BH
MV+'8KR#:J=F$VXS8KR#8K]BQ(-BOV+/8JMBQV+,@V8;;C-BSV*HN(-BTV878
MIR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8L]N,(-BHV+'8I]N,(-BJV878I]BS
MV8?8I]N,(-BNV8C8KR#9A=BTV*[8M2#9AMF&V879B-BOV8?B@(S8I]N,V*\B
M"@HC.B!P9W`N<&AP.C,Q.`IM<V=I9"`B2V5Y('-U8V-E<W-F=6QL>2!S96YT
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+:J=F$VXS8KR#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C9AR#:J=BGV+'8L]BGV+(@VJG9A-N,
MV*\@V+G9A=F(V87;C"#9@=BQV+/8JMBGV*_9AR#8M-BO(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,38*;7-G:60@(DQA;F=U86=E(@IM<V=S
M='(@(MBRV*C8I]F&(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP-@IM
M<V=I9"`B3&%S="!-86EL8F]X(%!A9V4B"FUS9W-T<B`BV+79@=BMV8?9E"#8
MHMBNV+$@V8;8I]F%V8?B@(S8K]BGV88B"@HC.B!M86EL8F]X+G!H<#HS-3@*
M;7-G:60@(DQA<W0@4&%G92(*;7-G<W1R("+8M=F!V*W9A]F4(-BBV*[8L2(*
M"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C,X.0IM<V=I9"`B
M3&E?;FL@071T86-H;65N=',B"FUS9W-T<B`BV;[;C-F(V8;8KR#9OMN,V8C8
ML]BJV8?8IR(*"B,Z(&%T=&%C:&UE;G0N<&AP.C,T(&QI8B]#;VUP;W-E+G!H
M<#HQ,#8S"FUS9VED("),:6YK960@871T86-H;65N=',@87)E(&9O<F)I9&1E
M;BXB"FUS9W-T<B`BV;[;C-F(V+/8JMF'V*?;C"#9OMN,V8C9AMBOVXP@V878
MK-BGV+(@V8;;C-BSV*HB"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3`X,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("),:6YK<R!W:6QL(&5X<&ER92!O;B`E<R(*;7-G
M<W1R("+9OMN,V8C9AMBOV8?8IR#8J-BQ(-BQV8C;C"`E<R#9A=F&V8+8MMN,
M(-BNV8C8I]F'V8;8KR#8M-BO+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#@R"FUS9VED("(B"B),:7-T(&%L;"!C;VYT86-T<R!W:&5N(&QO861I
M;F<@=&AE(&-O;G1A8W1S('-C<F5E;C\@*&EF(&1I<V%B;&5D+"!Y;W4@=VEL
M;"`B"B)O;FQY('-E92!C;VYT86-T<R!T:&%T('EO=2!S96%R8V@@9F]R(&5X
M<&QI8VET;'DI(@IM<V=S='(@(B(*(MBBVXS8IR#9A]F&VJ_8I]F%VXP@VJG9
MAR#8M=F!V*W9A]F4(-BJV878I]BSV8?8IR#8J-BGV+$@V87;C.*`C-BTV8C8
MKR#8JMF%V*?9A=N,(-BJV878I]BSV8?8IR#9@=F'V+'8L]BJ(-BTV8C9AMBO
MV)\@*-BOV+$@V+K;C-BQ(-BGVXS9AMBUV8C8L=BJ("(*(MBJV8;9A]BG(-BT
MV878IR#8JMF%V*?8L]F'V*?;C-N,(-BQV*<@V87;C.*`C-BHVXS9AMN,V*\@
MVJG9AR#8J-BWV8C8L2#8M=BQVXS8K2#8K-BSV*K8K-F((-JIV8;;C-BO*2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.#4*;7-G:60@(DQI<W1I;F<@
M:6X@=&AE($AE861E<B(*;7-G<W1R("+9@=F'V+'8L]BJ(-BTV*_9AB#8K]BQ
M(-BSV+'8HMF%V*\B"@HC.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI
M;F,Z,S`*;7-G:60@(DQO8V%L($UA:6QB;W@Z(@IM<V=S='(@(MF&V*?9A=F'
MXH",V*_8I]F&(-F%V*W9A-N,.B(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HV-S0*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(MF%V8C9@MBYVXS8
MJB(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(U"FUS9VED("),
M;V<@:6XB"FUS9W-T<B`BV8C8L=F(V*\B"@HC.B!L:6(O0FQO8VLO<W5M;6%R
M>2YP:'`Z,3$U"B,L('!H<"UF;W)M870*;7-G:60@(DQO9R!I;B!T;R`E<R(*
M;7-G<W1R("+9B-BQV8C8KR#8J-F'("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,S<*;7-G:60@(DQO9VEN(@IM<V=S='(@(MF(V+'9B-BO
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R("+9B-BXV*?;C-F!(-F(V+'9B-BO(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDV"FUS9VED("),;W<B"FUS9W-T
M<B`BV;[8I]N,VXS9AB(*"B,Z(&UE<W-A9V4N<&AP.C(Y.2!M86EL8F]X+G!H
M<#HW,C<@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ,PIM<V=I9"`B
M3&]W(%!R:6]R:71Y(@IM<V=S='(@(MBGV8C9A-F(VXS8JB#9OMBGVXS;C-F&
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDW"FUS9VED
M("),;W=E<W0B"FUS9W-T<B`BV;[8I]N,VXS9AN*`C-BJV+'B@(S;C-F&(@H*
M(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT-`IM<V=I9"`B
M36%C:6YT;W-H($9I;&4B"FUS9W-T<B`BV;[8L=F(V8;8K]F'XH",($UA8VEN
M=&]S:"`B"@HC.B!T96UP;&%T97,O<VUI;64O<&%S<W!H<F%S92YI;F,Z,3,*
M;7-G:60@(DUA:6PB"FUS9W-T<B`BV8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;
MC-JIVXPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38*;7-G:60@(DUA
M:6P@4')E=FEE=W,B"FUS9W-T<B`BV;[;C-BTXH",V8;9A=BGVXS8M-F'V*?;
MC"#9AMBGV879AR(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E
M;&5C="YI;F,Z,38*;7-G:60@(DUA:6P@<V5R=F5R('1Y<&4@=&\@8V]N;F5C
M="!T;SHB"FUS9W-T<B`BV8;9B-BY(-JIV*?8L=BSV*?8LB#9AMBGV879A]F4
M(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BHV+'8I]N,(-F%V*K8M=F$(-BTV*_9
MAB#8J-F'.B(*"B,Z(&9O;&1E<G,N<&AP.C0P,@IM<V=I9"`B36%I;&)O>"(*
M;7-G<W1R("+9AMBGV879A^*`C-BOV*?9AB(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3$*;7-G:60@(DUA:6QB;W@@86YD($9O;&1E<B!$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"#9AMF%V*?;
MC-BT(-F&V*?9A=F'XH",V*_8I]F&(-F((-F^V8C8M-F'(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3@*;7-G:60@(DUA<FL@06QL($UE
M<W-A9V5S(&EN($9O;&1E<B!A<R!3965N(@IM<V=S='(@(MBYV838I]F%V*H@
MVJ_8L-BGV+';C"#8JMF%V*?9A2#9OMN,V+K8I]F%V8?8I]N,(-F^V8C8M-F'
M(-BHV8<@V+G9AMF(V*?9AB#9A=BTV*?9A]BOV8<@V+38K]F'(@H*(SH@=&5M
M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,3D*;7-G:60@(DUA<FL@06QL
M($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB"FUS9W-T<B`BV+G9A-BG
MV878JB#:K]BPV*?8L=N,(-BJV878I]F%(-F^VXS8NMBGV879A]BGVXP@V;[9
MB-BTV8<@V*C9AR#8N=F&V8C8I]F&(-F%V+38I]F'V*_9AR#9AMBTV*_9AR(*
M"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z-2!T
M96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,P"FUS9VED(")-87)K(&%S
M.B(*;7-G<W1R("+8N=F$V*?9A=BJ(-JOV+#8I]BQVXP@V*C8N=F&V8C8I]F&
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3`*;7-G:60@(DUA<FL@
M9&EF9F5R96YT(&QE=F5L<R!O9B!Q=6]T:6YG('=I=&@@9&EF9F5R96YT(&-O
M;&]R<S\B"FUS9W-T<B`BV*+;C-BG(-BSV+?9B-BM(-F%V*[8JMF$V8$@V8;9
M@MF$(-F"V8C9A-F'V*?8C"#8J-BG(-BQV8;:K]F'V*?;C"#9A=BNV*K9A-F!
M(-BYV838I]F%V*H@VJ_8L-BGV+';C"#8M-F(V*_8GR(*"B,Z('1E;7!L871E
M<R]F971C:&UA:6PO;6%N86=E+FEN8SHT,`IM<V=I9"`B36%R:R!M97-S86=E
M<R!A<R!S965N/R`H24U!4"!O;FQY*2(*;7-G<W1R("+8HMN,V*<@V;[;C-BZ
MV*?9A=F'V*<@V*C8N=F&V8C8I]F&(-F%V+38I]F'V*_9AR#8M-BOV8<@V+G9
MA-BGV878JB#:K]BPV*?8L=N,(-BTV8C9AMBOV)\@*-F!V8+8MR!)34%0*2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-3@*;7-G:60@(DUA<FL@<VEM
M<&QE(&UA<FMU<#\B"FUS9W-T<B`BV+G9A-BGV*;9A2#8L]BGV*_9AR#8N=F$
MV*?9A=BJ(.*`C-JOV+#8I]BQVXP@V+39B-F&V*_8GR(*"B,Z('1E;7!L871E
M<R]S96%R8V@O:&5A9&5R+FEN8SHT-@IM<V=I9"`B36%T8V@@06QL(%%U97)I
M97,B"FUS9W-T<B`BV*K8M]BHVXS9@B#8JMF%V*?9A=N,(-F^V+'8L^*`C-F(
MV*S9B-F'V*<B"@HC.B!T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,Z-#(*
M;7-G:60@(DUA=&-H($%N>2!1=65R>2(*;7-G<W1R("+8JMBWV*C;C-F"(-F'
MV+$@V;[8L=BSXH",V8C8K-F((@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z-3$S"FUS9VED(")-87AI;75M($%T=&%C:&UE;G0@4VEZ92(*
M;7-G<W1R("+8J-N,V+3;C-F&V8?9E"#8I]F&V*_8I]BRV8?9E"#9OMN,V8C8
ML]BJ(@H*(SH@;&EB+V%P:2YP:'`Z-SD*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F($9O;&1E<G,B"FUS9W-T<B`BV*C;C-BTVXS9AMF'V90@V*K8N=BOV*?8
MKR#9OMF(V+39A^*`C-F'V*<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT.30*;7-G:60@(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE
M;G1S(')E86-H960N(@IM<V=S='(@(MBQV+/;C-BOV88@V*C9AR#8J-N,V+3;
MC-F&V8?9E"#8JMBYV*_8I]BO(-F^VXS9B-BSV*K9A]BG(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#@Y"FUS9VED(")-87AI;75M('1O
M=&%L(&%T=&%C:&UE;G0@<VEZ92!R96%C:&5D+B(*;7-G<W1R("+8L=BSVXS8
MK]F&(-BHV8<@V*C;C-BTVXS9AMF'V90@V878K-F%V8C8N2#8I]F&V*_8I]BR
MV8?9E"#9OMN,V8C8L]BJ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C8R-@IM<V=I9"`B365E=&EN9R!#86YC96QL871I;VXB"FUS9W-T<B`BV838
MNMF((-BTV*_9AB#9A=F$V*?9@MBGV*HB"@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-3<U"FUS9VED(")-965T:6YG($EN9F]R;6%T:6]N(@IM<V=S
M='(@(MBGV+?9A-BGV+G8I]BJ(-F%V838I]F"V*?8JB(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]I=&EP+G!H<#HU.#4*;7-G:60@(DUE971I;F<@4')O<&]S86PB
M"FUS9W-T<B`BV+?8L=BM(-F^VXS8M-F&V8?8I]BOVXP@V879A-BGV8+8I]BJ
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Q-PIM<V=I9"`B365E
M=&EN9R!297!L>2(*;7-G<W1R("+9OMBGV+/8KB#9A=F$V*?9@MBGV*HB"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3DX"FUS9VED(")-965T:6YG
M(%5P9&%T92(*;7-G<W1R("+8J-BQV8C8LMBQV+/8I]F&VXP@V879A-BGV8+8
MI]BJ(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8P,PIM<V=I9"`B
M365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R("+8K]BQV*[9B-BGV+/8
MJB#8J-BQV8C8LMBQV+/8I]F&VXP@V879A-BGV8+8I]BJ(@H*(SH@;&EB+T)L
M;V-K+W1R965?9F]L9&5R<RYP:'`Z,PIM<V=I9"`B365N=2!&;VQD97(@3&ES
M="(*;7-G<W1R("+:K]BRVXS9AMJOV*?9AB#9@=F'V+'8L]BJ(-F^V8C8M-F'
M(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,S,0IM<V=I9"`B365S<V%G92(*;7-G
M<W1R("+9OMN,V+K8I]F%(@H*(SH@8V]M<&]S92YP:'`Z-38P(&-O;7!O<V4N
M<&AP.C4X-R!C;VUP;W-E+G!H<#HV-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P"FUS9VED(")-97-S86=E($-O;7!O<VET:6]N(@IM<V=S='(@(MBGVXS8
MK-BGV*\@V;[;C-BZV*?9A2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,3<*;7-G:60@(DUE<W-A9V4@1&%T92(*;7-G<W1R("+8JMBGV+';C-BN(-F^
MVXS8NMBGV84B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#D@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDU(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#,*;7-G:60@(DUE<W-A
M9V4@3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-F^VXS8
MNMBGV84B"@HC.B!S96%R8V@N<&AP.C,Q,@IM<V=I9"`B365S<V%G92!396%R
M8V@B"FUS9W-T<B`BV*S8L]BJV*S9B-N,(-F^VXS8NMBGV84B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(Q"FUS9VED(")-97-S86=E(%-I>F4B"FUS
M9W-T<B`BV*?9AMBOV*?8LMF'V90@V;[;C-BZV*?9A2(*"B,Z(&UE<W-A9V4N
M<&AP.C,X-`IM<V=I9"`B365S<V%G92!3;W5R8V4B"FUS9W-T<B`BV+/8L=J&
MV+39A=F'V90@V;[;C-BZV*?9A2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-@IM<V=I9"`B365S<V%G92!6:65W:6YG(@IM<V=S='(@(MF%V+38I]F'
MV*_9A]F4(-F^VXS8NMBGV84B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN
M:6YC.C8*;7-G:60@(DUE<W-A9V4@9FQA9W,B"FUS9W-T<B`BV;[8L=J&V879
MA]BGVXP@V;[;C-BZV*?9A2(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI
M;F,Z.#,*;7-G:60@(DUE<W-A9V4@9F]L9&5R<R(*;7-G<W1R("+9OMF(V+39
MA^*`C-F'V*?;C"#9OMN,V+K8I]F%(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C,R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E(&9R;VT@)7,B"FUS9W-T
M<B`BV;[;C-BZV*?9A2#8I]BR("5S(@H*(SH@;6%I;&)O>"YP:'`Z-C8W"FUS
M9VED(")-97-S86=E(&AA<R!A='1A8VAM96YT<R(*;7-G<W1R("(@V;[;C-BZ
MV*?9A2#8K]BGV+'8I]N,(-F^VXS9B-BSV*H@V*?8L]BJ(@H*(SH@;6%I;&)O
M>"YP:'`Z-C4X"FUS9VED(")-97-S86=E(&ES(&5N8W)Y<'1E9"(*;7-G<W1R
M("(@V;[;C-BZV*?9A2#8L=F%V+(@V*C9AMBOVXP@V87;C.*`C-BTV8C8KR(*
M"B,Z(&UA:6QB;W@N<&AP.C8U,PIM<V=I9"`B365S<V%G92!I<R!S:6=N960B
M"FUS9W-T<B`B(-F^VXS8NMBGV84@V*?9A=BVV*?8H2#9A=N,XH",V+39B-BO
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C,S"FUS9VED(")-
M97-S86=E(&UA=&-H97,B"FUS9W-T<B`BV*K8M]BHVXS9@MF'V*?;C"#9OMN,
MV+K8I]F%(@H*(SH@8V]M<&]S92YP:'`Z.#(T(&-O;7!O<V4N<&AP.C@S.`IM
M<V=I9"`B365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`BV;[;C-BZV*?9A2#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*K8NMN,VXS8
ML2#9A=BSVXS8L2#8K]BGV*_9AR#8M-BO(@H*(R`*(SH@8V]M<&]S92YP:'`Z
M,3`X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97-S86=E('-E;G0@<W5C8V5S
M<V9U;&QY+"!B=70@;F]T('-A=F5D('1O("5S(@IM<V=S='(@(MF^VXS8NMBG
MV84@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BGV+'8L]BGV80@V+38K]B,(-BG
MV878IR#8K]BQ("5S(-BMV8'8N"#9AMBTV*\B"@HC.B!C;VUP;W-E+G!H<#HQ
M,30S(&-O;7!O<V4N<&AP.C$Q-3@*;7-G:60@(DUE<W-A9V4@<V5N="!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(MF^VXS8NMBGV84@V*C8IR#9A=F(V8'9D=F"
MVXS9D=BJ(-F!V+'8L]BJV*?8K]F'(-BTV*\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.30Q"FUS9VED(")-97-S86=E<R!P97(@<&%G92!I;B!T:&4@
M;6%I;&)O>"!V:65W+B(*;7-G<W1R("+8JMBYV*_8I]BO(-F^VXS8NMBGV879
MA]BG(-BOV+$@V8?8L2#8M=F!V*W9AR#9AMF%V*?;C-BT(-F&V*?9A=F'XH",
MV*_8I]F&(@H*(SH@;6%I;&)O>"YP:'`Z,S(R"FUS9VED(")-97-S86=E<R!T
M;R(*;7-G<W1R("+9OMN,V+K8I]F%V8?8IR#8J-F'(@H*(SH@=&5M<&QA=&5S
M+V%C;"]A8VPN:6YC.C(Y"FUS9VED(")-;V1I9GDB"FUS9W-T<B`BV*K8NMN,
MVXS8L2(*"B,@"B,Z('1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,Z,3(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUO<F4@=&AA;B!O;F4@861D
M<F5S<R!F;W5N9"!F;W(@9FEE;&0@7"(E<UPB+B(*;7-G<W1R("+8J-BQV*?;
MC"#9@=N,V838KR`G)7,G(-BHVXS8M"#8I]BR(-N,VJD@V*+8K]BQV+,@V;[;
MC-BOV*<@V+38KR(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I
M9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHU,`IM
M<V=I9"`B36]V92(*;7-G<W1R("+8I]F&V*K9@MBGV80B"@HC.B!T96UP;&%T
M97,O<')E9G,O<V]U<F-E<V5L96-T+FEN8SHS,38*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R("+8I]F&V*K9@MBGV80@V*C9AR#9OMBGVXS;C-F&(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.`IM<V=I9"`B36]V92!S<&%M(&UE
M<W-A9V5S('1O('-P86T@9F]L9&5R(&%N9"!I;FYO8V5N="!M97-S86=E<R!T
M;R!)3D)/6"(*;7-G<W1R("+8I]F&V*K9@MBGV80@V8?8L=BRV8;8I]F%V8?B
M@(S9A]BG(-F((-F&V*?9A=F'XH",V8?8IR#8J-F'(-F^V8C8M-F'XH",V8?8
MI]N,(-F%V+'8J-F(V+?9AR(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A
M<E]N879I9V%T92YI;F,Z,3@@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN
M8SHU,`IM<V=I9"`B36]V92!T;R!F;VQD97(B"FUS9W-T<B`BV*?9AMBJV8+8
MI]F$(-BHV8<@V;[9B-BTV8<B"@HC.B!T96UP;&%T97,O<')E9G,O<V]U<F-E
M<V5L96-T+FEN8SHS,30*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BV*?9AMBJ
MV8+8I]F$(-BHV8<@V*C8I]F$V*<B"@HC.B!L:6(O34E-12]6:65W97(O86QT
M97)N871I=F4N<&AP.C$R-PIM<V=I9"`B375L=&EP87)T+V%L=&5R;F%T:79E
M(@IM<V=S='(@(MJ&V8;8KR#8J-BNV+3;C"_8K-BGVXS:K]BRVXS9AB(*"B,Z
M('1H<F5A9"YP:'`Z-S8@=&AR96%D+G!H<#HQ-3(*;7-G:60@(DUU;'1I<&QE
M($UE<W-A9V4@5FEE=R(*;7-G<W1R("+9AMF%V*?;C"#:AMF&V*_:K]BGV8;9
MA]F4(-F^VXS8NMBGV84B"@HC.B!T96UP;&%T97,O<')E9G,O9&5F875L='-E
M87)C:'-E;&5C="YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B3D].12(*;7-G<W1R
M("+8JMF(V*S9AR(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO;6%N86=E+FEN
M8SHT."!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*(SH@=&5M<&QA=&5S
M+W!G<"]P9W`N:6YC.C(*;7-G:60@(DY/5$4B"FUS9W-T<B`BV*K9B-BLV8<B
M"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N:6YC.C(S."!L:6(O
M34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS9VED(").86UE(@IM<V=S='(@
M(MF&V*?9A2(*"B,Z('!G<"YP:'`Z,3$P"FUS9VED(").86UE(&%N9"]O<B!E
M;6%I;"!C86X@;F]T(&)E(&5M<'1Y(@IM<V=S='(@(MF&V*?9A2#9B"_;C-BG
M(-BBV*_8L=BS(-F&V*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V8;9
MA=N,XH",V*K9B-BGV8;8KR#8KMBGV83;C"#8J-BGV+38KR(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HW-S@*;7-G:60@(DYE961S($%C=&EO;B(*
M;7-G<W1R("+9AMN,V*?8LB#8J-F'(-F!V+G8I]F$VXS8JB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-S`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4X
M,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<X"FUS9VED(").979E<B(*
M;7-G<W1R("+9A]BQVJ_8LB(*"B,@"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-C`*;7-G:60@(DYE=F5R('-A=F4@871T86-H;65N=',B"FUS9W-T<B`B
MV8?8L=JOV+(@V;[;C-F(V+/8JMF'V*<@V*W9@=BX(-F&V+39B-F&V*\B"@HC
M.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3(T"FUS9VED(").97<B"FUS9W-T
M<B`BV*S8K]N,V*\B"@HC.B!L:6(O24U0+G!H<#HU-C,*;7-G:60@(DYE=R!&
M;VQD97(B"FUS9W-T<B`BV;[9B-BTV8?9E"#8K-BOVXS8KR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX.`IM<V=I9"`B3F5W($UA:6PB"FUS9W-T<B`B
MV8;8I]F%V8?9E"#8K-BOVXS8KR(*"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H
M<#HQ.2!L:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<#HS,PHC+"!F=7IZ>0IM
M<V=I9"`B3F5W($UE<W-A9V4B"FUS9W-T<B`BV;[;C-BZV*?9A2#8J-BYV*_;
MC"(*"B,Z(&UA:6QB;W@N<&AP.C<W-B!L:6(O34E-12](96%D97)S+G!H<#HQ
M.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O
M("5S(@IM<V=S='(@(MF^VXS8NMBGV879A]BGVXP@V*S8K]N,V*\B"@HC.B!T
M96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC.C$Y"FUS9VED(").97<@;65S<V%G
M97,B"FUS9W-T<B`BV;[;C-BZV*?9A=F'V*?;C"#8K-BOVXS8KR(*"B,Z('1E
M;7!L871E<R]C;VUP;W-E+W-P96QL:6YG+FEN8SHQ,S,*;7-G:60@(DYE>'0B
M"FUS9W-T<B`BV*C8N=BOVXPB"@HC.B!T96UP;&%T97,O;65S<V%G92]N879B
M87)?;F%V:6=A=&4N:6YC.C,S"FUS9VED(").97AT($UE<W-A9V4B"FUS9W-T
M<B`BV;[;C-BZV*?9A2#8J-BYV*_;C"(*"B,Z(&UA:6QB;W@N<&AP.C,U-@IM
M<V=I9"`B3F5X="!086=E(@IM<V=S='(@(MBUV8'8K=F'V90@V*C8N=BOVXPB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHU-#(@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDW-PIM<V=I9"`B3F\B"FUS9W-T<B`BV*[;C-BQ
M(@H*(SH@<VUI;64N<&AP.C(R-@IM<V=I9"`B3F\@0V5R=&EF:6-A=&4@9F]U
M;F0B"FUS9W-T<B`BVJ_9B-BGV8?;C.*`C-BGXH",VXS;C"#9OMN,V*_8IR#9
MAMBTV*\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC
M.C4*;7-G:60@(DYO($5N8W)Y<'1I;VXB"FUS9W-T<B`BV*C8K]F(V88@V+'9
MA=BRV*C9AMBOVXPB"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,3D*;7-G
M:60@(DYO($ME>7,@:6X@2V5Y<FEN9R(*;7-G<W1R("+9A]N,VH8@VJG9A-N,
MV*_;C"#8K]BQ(-BMV839@MF'V90@VJG9A-N,V*\@V8;;C-BSV*HB"@HC.B!M
M86EL8F]X+G!H<#HS-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@365S<V%G
M97,B"FUS9W-T<B`BV;[;C-BZV*?9A=N,(-F&VXS8L]BJ(@H*(SH@<&=P+G!H
M<#HQ,S<*;7-G:60@(DYO(%!'4"!P=6)L:6,@:V5Y(&EM<&]R=&5D+B(*;7-G
M<W1R("+9A]N,VH8@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@V*_8L=F(V8;B
M@(S8J-BQV*\@V8;8M-BOV8<B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N
M:6YC.C@T"FUS9VED(").;R!097)S;VYA;"!#97)T:69I8V%T92!0<F5S96YT
M(@IM<V=S='(@(MF'VXS:AB#:K]F(V*?9A]N,(-BTV*[8M=N,(-F(V*S9B-BO
M(-F&V*_8I]BQV*\B"@HC.B!L:6(O36%I;&)O>"YP:'`Z,S(Y"FUS9VED(").
M;R!0<F5V:65W(%1E>'0B"FUS9W-T<B`BV*C8K]F(V88@V;[;C-BTXH",V8;9
MA=BGVXS8M"#9A=BJV88B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C$U"FUS9VED(").;R!0=6)L:6,@2V5Y<R!&;W5N9"(*;7-G<W1R("+:J=F$
MVXS8KR#8N=F%V8C9A=N,XH",V*?B@(S;C-N,(-F^VXS8K]BG(-F&V+38KR(*
M"B,Z('-M:6UE+G!H<#HQ-3$*;7-G:60@(DYO(%,O34E-12!P=6)L:6,@:V5Y
M(&EM<&]R=&5D+B(*;7-G<W1R("+9A]N,VH8@VJG9A-N,V*\@V+G9A=F(V87;
MC"!3+TU)344@V*_8L=F(V8;B@(S8J-BQV*\@V8;8M-BOV8<B"@HC.B!L:6(O
M34E-12]6:65W97(O=&YE9BYP:'`Z.3`*;7-G:60@(DYO(&%T=&%C:&UE;G1S
M(&9O=6YD+B(*;7-G<W1R("+9A]N,VH8@V;[;C-F(V+/8JMN,(-F^VXS8K]BG
M(-F&V+38KR(*"B,@"B,Z(&QI8B]#<GEP="]334E-12YP:'`Z,30P"B,L(&9U
M>GIY"FUS9VED(").;R!E;6%I;"!I;F9O<FUA=&EO;B!L;V-A=&5D(&EN('1H
M92!P=6)L:6,@:V5Y+B(*;7-G<W1R("+8I]BWV838I]BYV*?8JB#8J-BQ(-BQ
MV8C;C"#:J=F$VXS8KR#8N=F%V8C9A=N,("5S(@H*(SH@86-L+G!H<#HW,B!A
M8VPN<&AP.CDX"FUS9VED(").;R!F;VQD97(@<V5L96-T960N(@IM<V=S='(@
M(MF'VXS:AB#9OMF(V+39A^*`C-BGVXP@V*?9AMBJV*[8I]BH(-F&V+38KR(*
M"B,Z(&QI8B]";&]C:R]S=6UM87)Y+G!H<#HQ-#$*;7-G:60@(DYO(&9O;&1E
M<G,@87)E(&)E:6YG(&-H96-K960@9F]R(&YE=R!M86EL+B(*;7-G<W1R("+9
MA]N,VH8@V;[9B-BTV8?B@(S8I]N,(-BHV+'8I]N,(-F&V*?9A=F'V90@V*S8
MK]N,V*\@V*S8L]BJV*S9B"#9AMBTV*\B"@HC.B!F;VQD97)S+G!H<#HR,3@@
M;&EB+T9O;&1E<BYP:'`Z-3`P(&QI8B]&;VQD97(N<&AP.C4U,`IM<V=I9"`B
M3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9"(*;7-G<W1R("+9A]N,VH8@V;[9
MB-BTV8?B@(S8I]N,(-F%V+38KMBU(-F&V+38KR(*"B,Z(&QI8B]";&]C:R]S
M=6UM87)Y+G!H<#HQ-#<*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!N97<@;65S
M<V%G97,B"FUS9W-T<B`BV;[9B-BTV8?B@(S8I]N,(-BHV*<@V;[;C-BZV*?9
MA=F'V*?;C"#8K-BOVXS8KR#9AMN,V+/8JB(*"B,Z(&QI8B]";&]C:R]S=6UM
M87)Y+G!H<#HQ-#0*;7-G:60@(DYO(&9O;&1E<G,@=VET:"!U;G-E96X@;65S
M<V%G97,B"FUS9W-T<B`BV;[9B-BTV8?B@(S8I]N,(-BHV*<@V;[;C-BZV*?9
MA2#9A=BTV*?9A]BOV8<@V8;8M-BOV8<@V8;;C-BSV*HB"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z,S(U"FUS9VED(").;R!M97-S86=E(&)O9'D@=&5X="(*;7-G
M<W1R("+9A=BJV88@V*C8K]F&V8?9E"#9OMN,V+K8I]F%(-F&VXS8L]BJ(@H*
M(SH@;&EB+TUA:6QB;W@N<&AP.C,W,0IM<V=I9"`B3F\@;65S<V%G97,@;6%T
M8VAE9"!Y;W5R('-E87)C:"XB"FUS9W-T<B`BV8?;C-J&(-F^VXS8NMBGV87;
MC"#8J-BG(-BLV+/8JMBLV8C;C"#8M-F%V*<@V*K8M]BGV*C9@B#9AMBOV*?8
ML=BO(@H*(SH@<&=P+G!H<#HQ.#D*;7-G:60@(DYO('!E<G-O;F%L(%!'4"!P
M<FEV871E(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`BV8?;C-J&(-JIV83;C-BO
M(%!'4"#8KMBUV8C8M=N,(-BTV*[8M=N,XH",V*?;C"#8K]BQV8C9AN*`C-BH
MV+'8KR#9AMBTV*_9AR(*"B,Z('!G<"YP:'`Z,38U"FUS9VED(").;R!P97)S
M;VYA;"!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB"FUS9W-T<B`BV8?;C-J&
M(-JIV83;C-BO(%!'4"#8N=F%V8C9A=N,(-BTV*[8M=N,(-BOV+'9B-F&XH",
MV*C8L=BO(-F&V+38K]F'(@H*(SH@<VUI;64N<&AP.C(P,0IM<V=I9"`B3F\@
M<&5R<V]N86P@4R]-24U%(&-E<G1I9FEC871E<R!I;7!O<G1E9"XB"FUS9W-T
M<B`BV8?;C-J&(-JOV8C8I]F'VXP@4R]-24U%(-BTV*[8M=N,(-BOV+'9B-F&
MXH",V*C8L=BO(-F&V+38K]F'(@H*(SH@<W!E;&QI;F<N<&AP.C(R,`IM<V=I
M9"`B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O;F9I9W5R960N(@IM<V=S
M='(@(MF'VXS:AB#8J-BQV8;8I]F%V8?9E"#8KMBWV*?;C-BGV*@@V*?9A=F$
MV*?;C-N,(-F^VXS:J=BQV*C9AMBOVXP@V8;8M-BOV8<B"@HC.B!T96UP;&%T
M97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@*;7-G:60@(DYO('-P96QL:6YG
M(&5R<F]R<R(*;7-G<W1R("+9A]N,VH8@V*[8M]BGVXP@V*?9A=F$V*?;C-N,
M(-F(V*S9B-BO(-F&V*_8I]BQV*\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]S
M<&5L;&EN9RYI;F,Z,3`P"FUS9VED(").;R!S=6=G97-T:6]N<R(*;7-G<W1R
M("+9OMN,V+39AMF'V*?8K]N,(-F&VXS8L]BJ(@H*(SH@;&EB+TE-05`O0VQI
M96YT+G!H<#HU-C0*;7-G:60@(DYO('-U<'!O<G1E9"!)34%0(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"!C;W5L9"!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M86-L+G!H<#HV."!A8VPN<&AP.CDT"FUS9VED(").;R!U<V5R('-P96-I9FEE
M9"XB"FUS9W-T<B`BV8?;C-J&(-JIV*?8L=BHV+';C"#9A=BTV*[8M2#9AMBT
MV*_9AR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#D*;7-G:60@
M(DYO;B!087)T:6-I<&%N="(*;7-G<W1R("+8J-BOV8C9AB#8M-BQVJG8JB#:
MJ=F&V8;8K]F'(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M,2!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0P"B,Z('1E
M;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N:6YC.C,U('1E;7!L871E<R]P
M<F5F<R]S<&%M<V5L96-T+FEN8SHR-`HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C8T"FUS9VED(").;VYE(@IM<V=S='(@(MF'VXS:AMJIV*_8I]F%
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,CDU"FUS9VED
M(").;W)M86PB"FUS9W-T<B`BV+G8I]BOVXPB"@HC.B!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI
M;F,Z,SD*;7-G:60@(DYO="!$96QE=&5D(@IM<V=S='(@(MBMV+#9@2#9AMBT
MV*_9AR(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI
M;F,Z,3(@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR,PHC.B!T96UP
M;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C0R"FUS9VED(").;W0@1')A9G0B
M"FUS9W-T<B`BV+K;C-BQ(-F^VXS8M"#9AMF(VXS8LR(*"B,Z('1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,Z."!T96UP;&%T97,O;6%I
M;&)O>"]N879B87(N:6YC.C$W"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,S0*;7-G:60@(DYO="!);7!O<G1A;G0B"FUS9W-T<B`BV+K;C-BQ
M(-F%V8?9A2(*"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A<BYI;F,Z,C4*
M;7-G:60@(DYO="!097)S;VYA;"(*;7-G<W1R("+8NMN,V+$@V+38KMBUVXPB
M"@HC.B!L:6(O0W)Y<'0O4$=0+G!H<#HQ,SD@;&EB+T-R>7!T+U--24U%+G!H
M<#HQ,S0@;&EB+T-R>7!T+U--24U%+G!H<#HQ-#D*;7-G:60@(DYO="!A('9A
M;&ED('!U8FQI8R!K97DN(@IM<V=S='(@(MJIV83;C-BO(-BYV879B-F%VXP@
MV8;8I]F%V+G8JMBHV+$B"@HC.B!T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC
M.C8W"FUS9VED(").;W0@9&5L971E9"!M97-S86=E<R(*;7-G<W1R("+9OMN,
MV+K8I]F%V8?8I]N,(-BMV+#9@2#9AMBTV*_9AR(*"B,Z('1E;7!L871E<R]S
M96%R8V@O;6%I;BYI;F,Z-3$*;7-G:60@(DYO="!I;7!O<G1A;G0@;65S<V%G
M97,B"FUS9W-T<B`BV;[;C-BZV*?9A=F'V*?;C"#8NMN,V+$@V879A]F%(@H*
M(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO9F5T8VAM86EL7VQO9VEN+G!H<#HW
M,0IM<V=I9"`B3F]T92!T:&%T('1H:7,@8V%N('1A:V4@<V]M92!T:6UE(@IM
M<V=S='(@(MBJV8C8K-F'(-JIV8;;C-BO(-JIV8<@V*?;C-F&(-F%VXSB@(S8
MJMF(V*?9AMBO(-BRV878I]F&(-BHV*C8L=BO(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8Q-@IM<V=I9"`B3F]T:&EN9R(*;7-G<W1R("+9A]N,VH8@
MVH;;C-BR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B
M3G5M8F5R(&]F(&UO;G1H<R!T;R!K965P(&]L9"!L:6YK960@871T86-H;65N
M=',@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`BV*K8N=BOV*?8KR#9
MA=BGV8?B@(S9A]BGVXP@V8;:K]F'V*_8I]BQVXP@V8;8I]F%V8?B@(S9A]BG
MVXP@V8+8K]N,V87;C-B,(-BGVJ_8L2#8HMF&V8?8IR#9A=BGV8?;C-BGV8;9
MAR#8K=BPV8$@V+39B-F&V*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S4Y"FUS9VED(").=6UB97(@;V8@;VQD('-E;G0M;6%I;"!F;VQD97)S('1O
M(&ME97`@:68@9&5L971I;F<@;6]N=&AL>2XB"FUS9W-T<B`B(@HBV*K8N=BO
MV*?8KR#9OMF(V+39A^*`C-F'V*?;C"#9AMBGV879A^*`C-F'V*?;C"#8I]BQ
MV+/8I]F$VXP@V8+8K]N,V87;C"#8J-BQV*?;C"#9AMJOV8?8K]BGV+';C-B,
M(-BGVJ_8L2#8HMF&V8?8IR#9A=BGV8?;C-BGV8;9AR#8K=BPV8$@V+39B-BO
M(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR-30@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C4U,@HC.B!L:6(O34E-12]6:65W97(O
M:71I<"YP:'`Z-S,S"FUS9VED(")/2R(*;7-G<W1R("+8M=BMVXS8K2#8I]BS
MV*HB"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI;F,Z-2!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!G<"]I
M;7!O<G1?:V5Y+FEN8SHT.`IM<V=I9"`B3U(B"FUS9W-T<B`BVXS8IR(*"B,Z
M('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z,34*;7-G:60@(D]L9"!M97-S
M86=E<R(*;7-G<W1R("+9OMN,V+K8I]F%V8?8I]N,(-F"V*_;C-F%VXPB"@HC
M.B!L:6(O36%I;G1E;F%N8V4O5&%S:R]D96QE=&5?<V5N=&UA:6Q?;6]N=&AL
M>2YP:'`Z-3(*;7-G:60@(D]L9"!S96YT+6UA:6P@9F]L9&5R<R!B96EN9R!P
M=7)G960N(@IM<V=S='(@(MF^V8C8M-F'V90@V8;8I]F%V8?B@(S9A]BGVXP@
MV8'8L=BSV*K8I]BOV8<@V+38K]F'(-BNV*?9A-N,(-BTV*\B"@HC.B!L:6(O
M0FQO8VLO<W5M;6%R>2YP:'`Z,C4*;7-G:60@(D]N;'D@9&ES<&QA>2!F;VQD
M97)S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN('1H96T_(@IM<V=S='(@(MBB
MVXS8IR#8JMF&V8?8IR#9OMF(V+39A^*`C-F'V*?;C-N,(-JIV8<@V;[;C-BZ
MV*?9A=F'V*?;C"#8KMF(V*?9AMBOV8<@V8;8M-BOV8<@V*_8I]BQV8;8KR#9
MAMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C9AMBOV)\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]F;VQD97)S+FIS.C<Y"FUS9VED(")/;FQY(&]N92!F;VQD
M97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO;BXB"FUS9W-T
M<B`BV*C8L=BGVXP@V*?;C-F&(-BYV879A"#8JMF&V8?8IR#;C-JI(-F^V8C8
MM-F'(-BHV*?;C-BO(-BGV8;8JMBNV*?8J"#8M-F(V*\B"@HC.B!T96UP;&%T
M97,O;65N=2YI;F,Z,3`@=&5M<&QA=&5S+VUE;G4N:6YC.C,P"B,L(&9U>GIY
M"FUS9VED(")/<&5N($9O7VQD97(B"FUS9W-T<B`BV*C8I]BR(-JIV+'8K]F&
M(-F^V8C8M-F'(@H*(SH@9F]L9&5R<RYP:'`Z-#(W"FUS9VED(")/<&5N960@
M1F]L9&5R(@IM<V=S='(@(MF^V8C8M-F'V90@V*C8I]BR(-BTV*_9AR(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HW,#4*;7-G:60@(D]P=&EO;F%L
M(%!A<G1I8VEP86YT(@IM<V=S='(@(MBTV+';C-JI(-BGV8;8JMBNV*?8J-N,
M(@H*(SH@9F5T8VAM86EL+G!H<#HS,R!T96UP;&%T97,O9F5T8VAM86EL+W1O
M<"YI;F,Z,PHC.B!T96UP;&%T97,O9F5T8VAM86EL+V9E=&-H;6%I;"YI;F,Z
M-@IM<V=I9"`B3W1H97(@36%I;"!!8V-O=6YT<R(*;7-G<W1R("+8J-F"VXS9
MAR#8K=BSV*?8J-F'V*?;C"#9OMBSV*K;C"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S,*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34P"FUS9VED(")/=&AE<B!/<'1I;VYS(@IM<V=S='(@(MJO
MV++;C-F&V8?B@(S9A]BGVXP@V*_;C-JOV+$B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C(P,0IM<V=I9"`B3W5T8F]U;F0@4V5R=F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P9W`O<&%S<W!H<F%S92YI;F,Z,38@;&EB
M+TU)344O5FEE=V5R+W!G<"YP:'`Z,38U"B,Z(&QI8B]-24U%+U9I97=E<B]P
M9W`N<&AP.C(P-"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3`*;7-G:60@
M(E!'4"(*;7-G<W1R(")01U`B"@HC.B!T96UP;&%T97,O8V]M<&]S92]E;F-R
M>7!T7VQI<W0N:6YC.C<*;7-G:60@(E!'4"!%;F-R>7!T($UE<W-A9V4B"FUS
M9W-T<B`BV;[;C-BZV*?9A2#8L=F%V++8J-F&V*_;C"#8M-BOV8?9E"!01U`B
M"@HC.B!C;VUP;W-E+G!H<#HS-3@*;7-G:60@(E!'4"!%<G)O<CH@(@IM<V=S
M='(@(MBNV+?8I]N,(%!'4#H@(@H*(SH@8V]M<&]S92YP:'`Z,S,W"FUS9VED
M(")01U`@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I
M=F%T92!K97DN(@IM<V=S='(@(MBNV+?8I]N,(%!'4#H@V*C9AR#8N=BHV*?8
ML=BJ(-JOV+#8L2#8J-BQV*?;C"#:J=F$VXS8KR#8KMBUV8C8M=N,(-BTV*[8
MM=N,(-F&VXS8I]BR(-F%VXSB@(S8J-BGV+38KR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E!'4"!/<'1I;VYS(@IM<V=S='(@(MJO
MV++;C-F&V8?B@(S9A]BGVXP@4$=0(@H*(SH@<&=P+G!H<#HS,`IM<V=I9"`B
M4$=0(%!A<W-P:')A<V4@26YP=70B"FUS9W-T<B`BV8C8I]BQV*_:J=BQV*_9
MAB#8N=BHV*?8L=BJ(-JOV+#8L5!'4"`B"@HC.B!T96UP;&%T97,O<&=P+W!G
M<"YI;F,Z-34*;7-G:60@(E!'4"!097)S;VYA;"!+97EP86ER('-U<'!O<G0@
M<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(MF^
MV+38JMN,V*C8I]F&VXP@V*S9@=BJ(-JIV83;C-BO(-BTV*[8M=N,(%!'4"#8
MJ-F'(-N,VJD@V*?8JMBUV*?9A"#8I]F%V88@V8C8J"#9AMN,V*?8LB#8K]BG
MV+'8KR(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C$W,PIM<V=I9"`B
M4$=0(%!U8FQI8R!+97D@5&5X="(*;7-G<W1R("+9A=BJV88@VJG9A-N,V*\@
MV+G9A=F(V87;C"!01U`B"@HC(`HC.B!P9W`N<&AP.C$T.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")01U`@4'5B;&EC($ME>2!F;W(@7"(E<R`H)7,I7"(@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS9W-T<B`BVJG9A-N,V*\@V+G9A=F(
MV87;C"!01U`@V*C8L=BGVXP@7"(E<R`H)7,I7"(@V*C8IR#9A=F(V8'9D=F"
MVXS9D=BJ(-BGV+;8I]F!V8<@V+38KR(*"B,@"B,Z('!G<"YP:'`Z,C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(&9O<B!<(B5S7"(@
M=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R("+:J=F$VXS8KR#8
MN=F%V8C9A=N,(%!'4"#8J-BQV*?;C"!<(B5S7"(@V*C8IR#9A=F(V8'9D=F"
MVXS9D=BJ(-BMV+#9@2#8M-BO(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC
M.C$T"FUS9VED(")01U`@4'5B;&EC($ME>7)I;F<B"FUS9W-T<B`BV*W9A-F"
MV8<@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`B"@HC.B!T96UP;&%T97,O8V]M
M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C@*;7-G:60@(E!'4"!3:6=N($UE<W-A
M9V4B"FUS9W-T<B`BV;[;C-BZV*?9A2#8I]F%V+;8I]BA(-BTV*_9A]F4(%!'
M4"(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V5N8W)Y<'1?;&ES="YI;F,Z.0IM
M<V=I9"`B4$=0(%-I9VXO16YC<GEP="!-97-S86=E(@IM<V=S='(@(MF^VXS8
MNMBGV84@V*?9A=BVV*?8H2#8M-BOV8<OV+'9A=BRV*C9AMBOVXP@V+38K]F'
M(%!'4"(*"B,Z('!G<"YP:'`Z,C`R"FUS9VED(")01U`@<')I=F%T92!K97D@
M<W5C8V5S<V9U;&QY(&%D9&5D+B(*;7-G<W1R("+:J=F$VXS8KR#8M-BNV+7;
MC"!01U`@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BGV+;8I]F!V8<@V+38KR(*
M"B,Z('!G<"YP:'`Z,3<W"FUS9VED(")01U`@<'5B;&EC(&ME>2!S=6-C97-S
M9G5L;'D@861D960N(@IM<V=S='(@(MJIV83;C-BO(-BYV879B-F%VXP@4$=0
M(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]BVV*?9@=F'(-BTV*\B"@HC.B!T
M96UP;&%T97,O<&=P+VYO=&%C=&EV92YI;F,Z-`IM<V=I9"`B4$=0('-U<'!O
M<G0@:7,@9&ES86)L960@;VX@=&AI<R!S>7-T96TN(@IM<V=S='(@(MF^V+38
MJMN,V*C8I]F&VXP@4$=0(-BQV8C;C"#8I]N,V88@V+/8I]F%V*?9AMF'(-F!
MV+G8I]F$(-F&VXS8L]BJ(@H*(SH@;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z
M,C`X"FUS9VED("(B"B)01U`@<W5P<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C
M=&EV92!S;R!T:&4@9&EG:71A;"!S:6=N871U<F4@:7,@=6YA8FQE('1O(&)E
M("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B+9OMBTV*K;C-BHV*?9AMN,(%!'
M4"#8K]BQ(-BMV*?9A"#8K=BGV+;8L2#9@=BYV*?9A"#9AMF%VXSB@(S8J-BG
MV+38KR#8I]BR(-BGVXS9AMBQV8@@V*?9A=BVV*?;C"#8K]N,V*S;C-BJV*?9
MA-N,(-F"V*?8J-F$(-BHV*?8LMBHVXS9AMN,("(*(MF&VXS8L]BJ(@H*(SH@
M;&EB+TU)344O5FEE=V5R+W!G<"YP:'`Z,CDU"FUS9VED("(B"B)01U`@<W5P
M<&]R="!I<R!N;W0@8W5R<F5N=&QY(&%C=&EV92!S;R!T:&4@;65S<V%G92!I
M<R!U;F%B;&4@=&\@8F4@9&5C<GEP=&5D+B(*;7-G<W1R("(B"B+9OMBTV*K;
MC-BHV*?9AMN,(%!'4"#8K]BQ(-BMV*?9A"#8K=BGV+;8L2#9@=BYV*?9A"#9
MAMF%VXSB@(S8J-BGV+38KR#8I]BR(-BGVXS9AMBQV8@@V;[;C-BZV*?9A2#9
M@MBGV*C9A"#8L=F%V++:K]BTV*?;C-N,(-F&VXS8L]BJ("(*"B,Z('1E;7!L
M871E<R]P9W`O<&=P+FEN8SHR"FUS9VED("(B"B)01U`@<W5P<&]R="!R97%U
M:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S960N("!)9B!Y;W5R(&)R;W=S
M97(@:7,@8W5R<F5N=&QY("(*(G-E="!T;R!D:7-A8FQE('!O<'5P('=I;F1O
M=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I;F<@;W(@96QS92!T:&4@
M4$=0("(*(F9E871U<F5S('=I;&P@;F]T('=O<FL@8V]R<F5C=&QY+B(*;7-G
M<W1R("(B"B)01U`@V*C8L=BGVXP@V+G9A=F$VJG8L=BO(-BUV*W;C-BM(-BN
MV8C8KR#8I]BR(-F^V8;8K-BQV8?B@(S9A]BGVXP@VJ_8M-F(V*_9AMN,(-BG
MV+/8JMF!V*?8K]F'(-F%VXSB@(S:J=F&V*\N(-F%V+'9B-BQVJ_8L2#8KMF(
MV*\@V+'8IR`B"B+8J-BQV*?;C"#8I]BSV*K9@=BGV*_9AR#8I]BR(-BGVXS9
MAB#9OMF&V*S8L=F'XH",V8?8IR#8JMF&V+C;C-F%(-JIV8;;C-BO(@H*(SH@
M;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,#4*;7-G:60@(E!/4#,B"FUS9W-T
M<B`B4$]0,R(*"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3`P"FUS9VED
M(")03U`S("A!=71O($1E=&5C="!0<F]T;V-O;',I(@IM<V=S='(@(E!/4#,@
M*-BJV+38KMN,V+4@V*[9B-BOVJG8I]BQ(-F^V+'9B-BJVJG9A-F'V*<I("(*
M"B,Z(&QI8B]&971C:&UA:6PO:6UA<"YP:'`Z,3$W"FUS9VED(")03U`S(&]V
M97(@4U-,(@IM<V=S='(@(E!/4#,@V+'9B-N,(%-33"(*"B,Z(&QI8B]&971C
M:&UA:6PO:6UA<"YP:'`Z,3(S"FUS9VED(")03U`S(&]V97(@4U-,("AS96QF
M+7-I9VYE9"!C97)T:69I8V%T92DB"FUS9W-T<B`B4$]0,R#8L=F(VXP@4U-,
M("C:K]F(V*?9A]N,(-BNV8C8K]BGV878MMBGV*$I(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHQ-CD*;7-G:60@(E!/4#,@;W9E<B!34TP@*'-E
M;&8M<VEG;F5D*2(*;7-G<W1R(")03U`S(-BQV8C;C"!34TP@*-BNV8C8K]BG
MV878MMBGV*$I(@H*(SH@;&EB+T9E=&-H;6%I;"]I;6%P+G!H<#HQ,3$*;7-G
M:60@(E!/4#,L(&YO(%1,4R(*;7-G<W1R(")03U`SV(P@V8;9AR!43%,B"@HC
M(`HC.B!T96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E!A9V4@)60@;V8@)60B"FUS9W-T<B`BV+79@=BMV8?9
ME"`E9"#8I]BR("5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP,PIM
M<V=I9"`B4&%G92!W:71H('1H92!&:7)S="!5;G-E96X@365S<V%G92(*;7-G
M<W1R("+8M=F!V*W9AR#8J-BG(-BGV8C9A-N,V88@V;[;C-BZV*?9A2#9A=BT
MV*?9A]BOV8<@V8;8M-BOV8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`T"FUS9VED(")086=E('=I=&@@=&AE($QA<W0@56YS965N($UE<W-A9V4B
M"FUS9W-T<B`BV+79@=BMV8<@V*C8IR#8HMBNV+';C-F&(-F^VXS8NMBGV84@
MV878M-BGV8?8K]F'(-F&V+38K]F'(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O
M:&5A9&5R<RYI;F,Z-#,*;7-G:60@(E!A<G0H<RDB"FUS9W-T<B`BV*C8KMBT
M*-F'V*<I(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C$R,PIM<V=I9"`B
M4&%S<W!H<F%S92(*;7-G<W1R("+8N=BHV*?8L=BJ(-JOV+#8L2(*"B,Z('1E
M;7!L871E<R]P9W`O<&=P+FEN8SHQ,C@*;7-G:60@(E!A<W-P:')A<V4@*$%G
M86EN*2(*;7-G<W1R("+8N=BHV*?8L=BJ(-JOV+#8L2`HV*_9B-BHV*?8L=F'
M*2(*"B,Z('-M:6UE+G!H<#HR,S4@<&=P+G!H<#HS,3`*;7-G:60@(E!A<W-P
M:')A<V4@<W5C8V5S<V9U;&QY('5N;&]A9&5D+B(*;7-G<W1R("(@V+G8J-BG
MV+'8JB#:K]BPV+$@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BGV+'8L]BGV80@
MV+38KR(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHQ."!T
M96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C(Y"FUS9VED(")087-S<&AR
M87-E.B(*;7-G<W1R("+8N=BHV*?8L=BJ(-JOV+#8L3HB"@HC.B!P9W`N<&AP
M.C$Q,@IM<V=I9"`B4&%S<W!H<F%S97,@8V%N(&YO="!B92!E;7!T>2(*;7-G
M<W1R("(@V+G8J-BGV+'8JB#:K]BPV+$@V8;9A=N,XH",V*K9B-BGV8;8KR#8
MKMBGV83;C"#8J-BGV+38KR(*"B,Z('!G<"YP:'`Z,3$T"FUS9VED(")087-S
M<&AR87-E<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`BV+G8J-BGV+'8I]BJ(-JO
MV+#8L2#9A=F&V+?8J-F"(-F&VXS8L]BJV8;8KR(*"B,Z('1E;7!L871E<R]F
M971C:&UA:6PO;6%N86=E+FEN8SHR,"!T96UP;&%T97,O<VUI;64O:6UP;W)T
M7VME>2YI;F,Z-S$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ.3(*
M;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(B"@HC.B!T
M96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-#@*;7-G:60@(E!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B
MV*+;C-BG(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C"#8J-F'(-F'V8;:
MK]BGV84@V8C8L=F(V*\@V*?8K-BQV*<@V+39B-BOV)\B"@HC.B!A8VPN<&AP
M.C<V(&%C;"YP:'`Z,3`R"FUS9VED(")097)M:7-S:6]N<R!F;W(@=&AI<R!U
M<V5R(&-A;B!N;W0@8F4@8VAA;F=E9"XB"FUS9W-T<B`BV878K-F(V++9A]BG
MVXP@V*?;C-F&(-JIV*?8L=BHV+$@V+'8IR#9AMF%VXSB@(S8JMF(V*?9AB#8
MJMBZVXS;C-BQ(-BOV*?8KR(*"B,Z(&UE<W-A9V4N<&AP.C0Y,R!M86EL8F]X
M+G!H<#HW,#,@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHR-`HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C$P"FUS9VED(")097)S;VYA
M;"(*;7-G<W1R("+8M-BNV+7;C"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`BV*?8
MM]F$V*?8N=BGV*H@V+38KMBUVXPB"@HC.B!P9W`N<&AP.C$R,`IM<V=I9"`B
M4&5R<V]N86P@4$=0(&ME>7!A:7(@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`BV*S9@=BJ(-JIV83;C-BO(-BTV*[8M=N,(%!'4"#8J-BG(-F%
MV8C9@=F1V8+;C-F1V*H@V*K9B-F$VXS8KR#8M-BO(@H*(SH@<&=P+G!H<#HQ
M,C<*;7-G:60@(E!E<G-O;F%L(%!'4"!K97ES(&1E;&5T960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R("+:J=F$VXS8K]F'V*?;C"#8M-BNV+7;C"!01U`@V*C8
MIR#9A=F(V8'9D=F"VXS9D=BJ(-BMV+#9@2#8M-BOV8;8KR(*"B,Z('-M:6UE
M+G!H<#HR,#<*;7-G:60@(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T97,@
M3D]4(&EM<&]R=&5D.B`B"FUS9W-T<B`BVJ_9B-BGV8?;C-F'V*?;C"#8M-BN
MV+7;C"!3+TU)344@V*_8L=F(V8;B@(S8J-BQV*\@V8;8M-BO.B(*"B,Z('-M
M:6UE+G!H<#HQ,S(*;7-G:60@(E!E<G-O;F%L(%,O34E-12!K97ES(&1E;&5T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+:J=F$VXS8K]F'V*?;C"#8M-BN
MV+7;C"!3+TU)344@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BMV+#9@2#8M-BO
MV8;8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G:60@(E!L
M86-E('EO=7(@<VEG;F%T=7)E(&)E9F]R92!R97!L:65S(&%N9"!F;W)W87)D
M<S\B"FUS9W-T<B`BV*+;C-BG(-F"V*C9A"#8I]BR(-F^V*?8L]BN(-F((-BG
MV+'8K-BGV+D@V*?9A=BVV*?;C"#8M-F%V*<@VJ_9AMBLV*?9AMBOV8<@V+39
MB-BOV)\B"@HC.B!C;VUP;W-E+G!H<#HR-30*;7-G:60@(E!L86EN=&5X="!6
M97)S:6]N(&]F($UE<W-A9V4B"FUS9W-T<B`BV8;8L]BNV8?9E"#9A=BJV88@
MV878N=F%V8C9A-N,(-F^VXS8NMBGV84B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-SDY"FUS9VED("(B"B)0;&%Y('-O=6YD(&]N(&YE=R!M86EL/R`@
M5&AI<R!R97%U:7)E<R!Y;W5R(&)R;W=S97(@=&\@<W5P<&]R="!E;6)E9&1E
M9"`B"B)S;W5N9"!F:6QE<RX@($%L;6]S="!A;&P@9&\@;VX@5VEN9&]W<R!A
M;F0@36%C+"!B=70@;W1H97(@<&QA=&9O<FUS('=I;&P@(@HB<F5Q=6ER92!A
M('!L=6=I;BXB"FUS9W-T<B`B(@HBV*+;C-BG(-F^V*[8M"#8M=BOV*<@V*C8
ML2#8L=F(VXP@V8;8I]F%V8?9E"#8K-BOVXS8KR#8M=F(V+'8JB#:K]N,V+'8
MK]B?(-BHV+'8I]N,(-BGVXS9AB#9A=F&V+C9B-BQ(-F%VXSB@(S8J-BGVXS8
ML]BJ(-F%V+'9B-BQVJ_8L2#8M-F%V*<@V*?8LB`B"B+8I]N,V8;:K]F(V8;9
MAR#9@=BGVXS9A-F'V*?;C"#8M=F(V*K;C"#9OMBTV*K;C-BHV*?9AMN,(-F&
MV878I]N,V*\N(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI
M;F,Z-34@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,3DR"FUS
M9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&9O;&1E<CHB
M"FUS9W-T<B`BV838M]F!V*?9BR#9AMBGV87;C"#8J-BQV*?;C"#9OMF(V+39
MA]F4(-BLV*_;C-BO(-F(V*?8L=BO(-JIV8;;C-BO.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3`R('1E;7!L871E<R]J879A<V-R
M:7!T+V9O;&1E<G,N:G,Z,3`T"FUS9VED(")0;&5A<V4@96YT97(@=&AE(&YA
M;64@;V8@=&AE(&YE=R!F;VQD97(Z(@IM<V=S='(@(MF$V+?9@=BGV8L@V8;8
MI]F%VXP@V*C8L=BGVXP@V;[9B-BTV8?9E"#8K-BOVXS8KR#9B-BGV+'8KR#:
MJ=F&VXS8KSHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M.C$S-PIM<V=I9"`B4&QE87-E(&5N=&5R('1H92!N97<@;F%M93HB"FUS9W-T
M<B`BV838M]F!V*?9BR#9AMBGV84@V*S8K]N,V*\@V+'8IR#9B-BGV+'8KR#:
MJ=F&VXS8KSHB"@HC.B!T96UP;&%T97,O<&=P+W!A<W-P:')A<V4N:6YC.C$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!01U`@<')I=F%T92!K97DN(%EO=2!W:6QL(&]N
M;'D@;F5E9"!T;R`B"B)E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@
M)7,@<V5S<VEO;BXB"FUS9W-T<B`B(@HBV838M]F!V*?9BR#8N=BHV*?8L=BJ
M(-JOV+#8L2#8L=BG(-BHV+'8I]N,(-JIV83;C-BO(-BNV+79B-BUVXP@4$=0
M(-BNV8C8KR#9B-BGV+'8KR#:J=F&VXS8KRX@V+39A=BG(-BHV8<@V*?;C-F&
M(-BYV879A"#8JMF&V8?8IR#8K]BQ("(*(MF'V+$@)7,@V8;8M-BSV*H@V8;;
MC-BGV+(@V*_8I]BQVXS8KR(*"B,Z('1E;7!L871E<R]S;6EM92]P87-S<&AR
M87-E+FEN8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@96YT
M97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4R]-24U%('!R:79A=&4@:V5Y
M+B!9;W4@=VEL;"!O;FQY(&YE960@(@HB=&\@96YT97(@=&AI<R!P87-S<&AR
M87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(@IM<V=S='(@(B(*(MF$V+?9@=BG
MV8L@V+G8J-BGV+'8JB#:K]BPV+$@V+'8IR#8J-BQV*?;C"#:J=F$VXS8KR#8
MKMBUV8C8M=N,(%,O34E-12#8KMF(V*\@V8C8I]BQV*\@VJG9AMN,V*\N(-BT
MV878IR#8J-F'(-BGVXS9AB#8N=F%V80@V*K9AMF'V*<@(@HBV*_8L2#9A]BQ
M("5S(-F&V+38L]BJ(-F&VXS8I]BR(-BOV*?8L=N,V*\B"@HC.B!R96-O;7!O
M<V4N<&AP.CDW"FUS9VED("(B"B)0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E
M<W5M92!C;VUP;W-I;F<@>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U
M<VEN9R`B"B)C;V]K:65S($%.1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E
M<R!I;B!P;W!U<"!W:6YD;W=S+"!Y;W4@=VEL;"!H879E('1O("(*(FQO9R!I
M;B!A9V%I;B!I;B!Y;W5R(&UA:6X@=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@
M=&\@:V5E<"!A='1A8VME<G,@9G)O;2`B"B)H:6IA8VMI;F<@>6]U<B!S97-S
M:6]N($E$+B!792!A<&]L;V=I>F4@9F]R(&%N>2!I;F-O;G9E;FEE;F-E+B(*
M;7-G<W1R("(B"B+9A-BWV8'8I]F+(-BHV+'8I]N,(-BGV*_8I]F%V8<@V+G9
MA=F$(-BGV+'8L]BGV80@V;[;C-BZV*?9A2#8K]F(V*C8I]BQV8<@V8C8I]BQ
MV*\@V+39B-N,V*\N(-BRVXS8L=BG(-BGVJ_8L2#8M-F%V*<@V*?8LB#:J=F(
MVJG;C-F'V*<@(@HBV*?8L]BJV8'8I]BOV8<@V8;:J=F&VXS8KR#9B"#8M=F!
MV*W9AR#8JMF(V83;C-BO(-F^VXS8NMBGV84@V+39A=BG(-BOV+$@VXS:J2#9
MOMF&V*S8L=F'(-JOV+39B-BOV8;;C"#8J-BGV+38K]B,(-BTV878IR#9A=BL
MV*C9B-BQ(-BHV8<@(@HBV8C8L=F(V*\@V*_9B-BHV*?8L=F'(-BOV+$@V;[9
MAMBLV+'9A]F4(-BGV+79A-N,(-BNV8C8I]F'VXS8KR#8J-F(V*\@V8@@V*?;
MC-F&(-BGV878L2#9A=N,XH",V*K9B-BGV8;8KR#8J-BGV+G8JR#8K]BRV*_;
MC-BOV88@240@V8;8M-BSV*H@("(*(MBTV878IR#8JMF(V+/8MR#9AMF!V8C8
ML-JOV+'8I]F&(-BTV8C8KR(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S$*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0N(@IM
M<V=S='(@(MF$V+?9@=BGV8L@V*?8L]F%(-BQV878LB#8KMF(V*\@V+'8IR#8
MHMF%V*?8K]F'(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHV-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB
M"FUS9W-T<B`BV838M]F!V*?9BR#9AMBGV84@VJG8I]BQV*C8L=N,(-BNV8C8
MKR#8L=BG(-BBV878I]BOV8<@VJG9AMN,V*\Z(@H*(SH@8V]M<&]S92YP:'`Z
M,3`V(&QI8B])35`N<&AP.C0U.0IM<V=I9"`B4&QE87-E(')E<V]L=F4@86UB
M:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+B(*;7-G<W1R("+9A-BWV8'8
MI]F+(-BGV*C9A]BGV84@VXS8IR#8HMBOV+'8LR#8NMN,V+'9A=BYV*K8J-BQ
M(-BQV*<@V*C8L=BWV+'9@2#:J=F&VXS8KR(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HV-#(*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE(&9O
M;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO
M;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"B+9A-BWV8'8
MI]F+(-BGV+?9A-BGV+G8I]BJ(-BRVXS8L2#8L=BG(-F%V+'9B-BQ(-JIV+'8
MK]F'V(P@V8@@V+/9OMBS(-N,VJD@V8'8N=BGV83;C-BJ(-BGV+(@VJ_8LMN,
MV8;:K]BGV88@V++;C-BQ(-BQV*<@V*C8L=JOV++;C-F&VXS8KR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z-C$*;7-G:60@(E!L96%S
M92!S96QE8W0@82!F;VQD97(@8F5F;W)E('EO=2!P97)F;W)M(&%N>2!A8W1I
M;VYS+B(*;7-G<W1R("+9A-BWV8'8I]F+(-F"V*C9A"#8I]BR(-BGV8;8K-BG
MV84@V8?8L2#:K]F(V8;9AR#9@=BYV*?9A-N,V*K;C"#;C-JI(-F^V8C8M-F'
M(-BGV8;8JMBNV*?8J"#:J=F&VXS8KR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU,#(*;7-G:60@(E!L96%S92!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N(@IM<V=S='(@(MF$V+?9@=BGV8L@VXS:J2#9
M@=BYV*?9A-N,V*H@V*?8LB#:K]BRVXS9AMJOV*?9AB#8LMN,V+$@V+'8IR#8
MJ-BQVJ_8LMN,V8;;C-BO(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]J879A<V-R
M:7!T+FEN8SHT,0IM<V=I9"`B4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@
M9F]L9&5R('1O('-E87)C:"XB"FUS9W-T<B`BV838M]F!V*?9BR#8K=BOV*?9
M@MF$(-N,VJD@V+38I]BNV8<@V*C8L=BGVXP@V*S8L]BJV*S9B"#8I]F&V*K8
MKMBGV*@@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]F;VQD
M97)S+FIS.C$R"FUS9VED(")0;&5A<V4@<V5L96-T(&]N;'D@;VYE(&9O;&1E
M<B!F;W(@=&AI<R!O<&5R871I;VXN(@IM<V=S='(@(MF$V+?9@=BGV8L@V*C8
ML=BGVXP@V*?;C-F&(-BYV879A"#9@=F"V+<@VXS:J2#9OMF(V+39AR#8I]F&
MV*K8KMBGV*@@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]R961I
M<F5C="YI;F,Z-S,*;7-G:60@(E!L96%S92!S96QE8W0@;W(@961I="!I;B!T
M:&4@8F]X('1O('1H92!R:6=H=#HB"FUS9W-T<B`BV838M]F!V*?9BR#8K]BQ
M(-BLV+G8J-F'V90@VH;9OB#8I]F&V*K8KMBGV*@@V8@@VXS8IR#9B-N,V+'8
MI]N,V+0@VJG9AMN,V*\Z(@H*(SH@8V]N9FEG+VUO=&0N<&AP+F1I<W0Z-#$*
M;7-G:60@(E!O=V5R960@8GD@2&]R9&4B"FUS9W-T<B`BV*_8L2#8I]BNV*K;
MC-BGV+$@V8?9B-BQV*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$T
M"FUS9VED(")0<F5C961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G
M+2T@)RD_(@IM<V=S='(@(MF"V*C9A"#8I]BR(-BGV878MMBGVXP@V+39A=BG
M(-BNV+<@V8'8I]BUV839AR`H)RTM("<I(-JOV+#8I]BTV*K9AR#8M-F(V*_8
MGR(*"B,Z('-M:6UE+G!H<#HR-#$@<&=P+G!H<#HR-3<@9FEL=&5R<')E9G,N
M<&AP.C0P"FUS9VED(")0<F5F97)E;F-E<R!S=6-C97-S9G5L;'D@=7!D871E
M9"XB"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*<@V*C8IR#9A=F(V8'9D=F"
MVXS9D=BJ(-BHV+'9B-BRV+'8L]BGV8;;C"#8M-BOV8;8KR(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")0<F5V:65W
M(@IM<V=S='(@(MF^VXS8M.*`C-F&V878I]N,V+0B"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?;F%V:6=A=&4N:6YC.C(X"FUS9VED(")0<F5V:6]U
M<R!-97-S86=E(@IM<V=S='(@(MF^VXS8NMBGV84@V8+8J-F$VXPB"@HC.B!M
M86EL8F]X+G!H<#HS-#<*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS9W-T<B`B
MV+79@=BMV8?9E"#9@MBHV83;C"(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHS,PIM<V=I9"`B4')I;G0B"FUS9W-T<B`BVH;8
MI]F^(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:&5A9&5R<RYI;F,Z,S@*;7-G
M:60@(E!R:6]R:71Y(@IM<V=S='(@(MBGV8C9A-F(VXS8JB(*"B,Z('1E;7!L
M871E<R]S;6EM92]I;7!O<G1?:V5Y+FEN8SHW-@IM<V=I9"`B4')I=F%T92!+
M97D@4&%S<W=O<F0B"FUS9W-T<B`BV*?8L]F%(-BQV878LB#:J=F$VXS8KR#8
MKMBUV8C8M=N,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U.0IM<V=I
M9"`B4')O;7!T(&5V97)Y('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D
M969A=6QT('1O($Y/(@IM<V=S='(@(MBGV+G9A-BGV88@V++9A=BGV8;;C"#:
MJ=F'(-N,VJD@V;[;C-F(V+/8JB#8I]BQV+/8I]F$(-F%VXSB@(S:K]BQV*_8
MKSH@V879@MBOV*?8L2#9OMN,V+0@V8'8L=BV(-F&V8<@V*?8L]BJ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U.`IM<V=I9"`B4')O;7!T(&5V97)Y
M('1I;64@86X@871T86-H;65N="!I<R!S96YT.R!D969A=6QT('1O(%E%4R(*
M;7-G<W1R("+8I]BYV838I]F&(-BRV878I]F&VXP@VJG9AR#;C-JI(-F^VXS9
MB-BSV*H@V*?8L=BSV*?9A"#9A=N,XH",VJ_8L=BOV*\Z(-F%V8+8K]BGV+$@
MV;[;C-BT(-F!V+'8MB#8J-F$V8<@V*?8L]BJ(@H*(SH@=&5M<&QA=&5S+V9E
M=&-H;6%I;"]M86YA9V4N:6YC.C$P"FUS9VED(")0<F]T;V-O;#HB"FUS9W-T
M<B`BV;[8L=F(V*K:J=F$.B(*"B,Z(&QI8B]#<GEP="]01U`N<&AP.C0R.0IM
M<V=I9"`B4'5B;&EC(%!'4"!K97ES97)V97(@<W5P<&]R="!H87,@8F5E;B!D
M:7-A8FQE9"XB"FUS9W-T<B`BV;[8M-BJVXS8J-BGV8;;C"#:J=BGV+'8L]BG
MV+(@VJG9A-N,V*\@V+G9A=F(V87;C"#B@(Q01U`@V+K;C-BQ(-F!V+G8I]F$
M(-BTV*_9AR#8I]BSV*HB"@HC.B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHS-B!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS7V1E;&5T960N:6YC
M.C@*;7-G:60@(E!U<E]G92!$96QE=&5D(@IM<V=S='(@(MF^V*?:J=BSV*?8
MLMN,(-BMV+#9@2#8M-BOV8?B@(S9A]BG(@H*(SH@=&5M<&QA=&5S+VUA:6QB
M;W@O86-T:6]N<RYI;F,Z,S8@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<U]D
M96QE=&5D+FEN8SHX"FUS9VED(")0=7)G92!$96QE=&5D(@IM<V=S='(@(MF^
MV*?:J=BSV*?8LMN,(-BMV+#9@2#8M-BOV8?B@(S9A]BG(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,Z,C0*;7-G:60@(E!U<F=E($9O;&1E
M<BAS*2(*;7-G<W1R("+9OMBGVJG8L]BGV++;C"#9OMF(V+39ARC9A]BG*2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.38*;7-G:60@(E!U<F=E(%1R
M87-H(&AO=R!O9G1E;CHB"FUS9W-T<B`B(-F^V*?:J=BSV*?8LMN,(-BSV+?9
MA"#8HMBTV+K8I]F$(-BOV+$@V*C8I]BRV8?B@(S9A]BGVXP@V++9A=BGV8;;
MC#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`U"FUS9VED(")0=7)G
M92!M97-S86=E<R!I;B!4<F%S:"!F;VQD97(@;VQD97(@=&AA;B!T:&ES(&%M
M;W5N="!O9B!D87ES+B(*;7-G<W1R("+9OMBGVJG8L]BGV++;C"#9OMN,V+K8
MI]F%V8?8I]N,(-F^V8C8M-F'V90@V+/8M]F$(-BBV+38NMBGV80@VJG9AR#8
MI]BR(-BGVXS9AB#:AMF&V*\@V+'9B-BR(-F"V*_;C-F%VXSB@(S8JMBQXH",
M(-BHV*?8M-F&V*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS
M9VED(")0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O;&1E<C\B
M"FUS9W-T<B`BV*+;C-BG(-F^VXS8NMBGV879A]BGVXP@V8+8K]N,V87;C"#8
MK]BQ(-F^V8C8M-F'V90@V+/8M]F$(-BBV+38NMBGV80@V;[8I]JIV+/8I]BR
MVXP@V+39B-F&V*_8GR(*"B,@"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U
M<F=E7W1R87-H+G!H<#HV-0HC+"!P:'`M9F]R;6%T"FUS9VED(")0=7)G:6YG
M("5D(&UE<W-A9V5S(&9R;VT@5')A<V@@9F]L9&5R+B(*;7-G<W1R("+9OMBG
MVJG8L]BGV++;C"`E9"#9OMN,V+K8I]F%(-BGV+(@V;[9B-BTV8?9E"#8L]BW
MV80@V*+8M-BZV*?9A"(*"B,@"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W!U
M<F=E7W1R87-H+G!H<#HV,PIM<V=I9"`B4'5R9VEN9R`Q(&UE<W-A9V4@9G)O
M;2!4<F%S:"!F;VQD97(N(@IM<V=S='(@(MF^V*?:J=BSV*?8LMN,(-N,VJD@
MV;[;C-BZV*?9A2#8I]BR(-F^V8C8M-F'V90@V+/8M]F$(-BBV+38NMBGV80B
M"@HC(`HC.B!T96UP;&%T97,O<75O=&$O<75O=&$N:6YC.C$W"B,L('!H<"UF
M;W)M870*;7-G:60@(E%U;W1A('-T871U<SH@)2XR9DU"("\@)2XR9DU"("`H
M)2XR9B4E*2(*;7-G<W1R("+9B-BVV+G;C-BJXH",(-BSV8?9A=N,V8<Z("4N
M,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB"@HC(`HC.B!T96UP;&%T97,O<75O
M=&$O<75O=&$N:6YC.C(Q"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1A('-T
M871U<SH@)2XR9DU"("\@3D\@3$E-250B"FUS9W-T<B`BV8C8MMBYVXS8JB#8
ML]F'V87;C-F'.B`E+C)F(-F%VJ_8I]BHV*?;C-BJ+]BHV*_9B-F&(-F%V*W8
MK]F(V*_;C-BJ(@H*(R`*(SH@=&5M<&QA=&5S+W%U;W1A+W%U;W1A+FEN8SHR
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")1=6]T82!S=&%T=7,Z($Y/($Q)34E4
M(@IM<V=S='(@(MF(V+;8N=N,V*KB@(P@V+/9A]F%VXS9ASH@V*C8K]F(V88@
MV878K=BOV8C8K]N,V*HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(E%U;W1I;F<@)68Z(@IM<V=S='(@(MF&
MV8+9A"#9@MF(V80@)68Z(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z,S@V"FUS9VED(")295]Q=65S="!$96QI=F5R>2!#;VYF:7)M871I
M;VXB"FUS9W-T<B`BV*_8L=BNV8C8I]BSV*H@V*K8I]BFVXS8K]N,V8?9E"#8
MJMBMV8C;C-F$(@H*(SH@;&EB+U-E87)C:"YP:'`Z-3`*;7-G:60@(E)E8V5I
M=F5D($]N(@IM<V=S='(@(MBOV+';C-BGV8'8JB#8M-BOV8<@V*C8L2(*"B,Z
M(&QI8B]396%R8V@N<&AP.C4X"FUS9VED(")296-E:79E9"!3:6YC92(*;7-G
M<W1R("+8K]BQVXS8I]F!V*H@V+38K]F'(-BGV+(B"@HC.B!L:6(O4V5A<F-H
M+G!H<#HU-`IM<V=I9"`B4F5C96EV960@56YT:6PB"FUS9W-T<B`BV*_8L=N,
MV*?9@=BJ(-BTV*_9AR#8JMBG(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$V"FUS9VED(")2961I<F5C7W0B"FUS9W-T<B`B
MV*K8NMN,VXS8L2#9A=BSVXS8L2(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHQ-@IM<V=I9"`B4F5D:7)E8W0B"FUS9W-T<B`B
MV*K8NMN,VXS8L2#9A=BSVXS8L2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E
M9&ER96-T+FEN8SHQ,3`*;7-G:60@(E)E9&ER96-T($UE<W-A9V4B"FUS9W-T
M<B`BV*K8NMN,VXS8L2#9A=BSVXS8L2#9OMN,V+K8I]F%(@H*(SH@8V]M<&]S
M92YP:'`Z-S@W"FUS9VED(")2961I<F5C="!T:&ES(&UE<W-A9V4B"FUS9W-T
M<B`BV*K8NMN,VXS8L2#9A=BSVXS8L2#8I]N,V88@V;[;C-BZV*?9A2(*"B,Z
M(&-O;7!O<V4N<&AP.C@T-PIM<V=I9"`B4F5D:7)E8W1I;F<@9F%I;&5D+B(*
M;7-G<W1R("+8JMBZVXS;C-BQ(-F%V+/;C-BQ(-F&V*?9A=F(V8'9D=F"(-BH
MV8C8KR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C4X,PIM
M<V=I9"`B4F5F<F5S:"(*;7-G<W1R("+8J-BGV++8HMF(V+';C"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.#0*;7-G:60@(E)E9G)E<V@@1F]L9&5R
M(%9I97=S.B(*;7-G<W1R("+8J-BGV++8HMF(V+';C"#9AMF%V*?9A]BGVXP@
MV;[9B-BTV8<Z(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O:&5A9"YI;F,Z.2!T
M96UP;&%T97,O;6%I;&)O>"]H96%D97(N:6YC.C0*;7-G:60@(E)E;&]A9"(*
M;7-G<W1R("+8J-BGV+':K]BPV*?8L=N,(-F%V*S8K]BO(@H*(SH@=&5M<&QA
M=&5S+V9O;&1E<G,O:&5A9"YI;F,Z,PIM<V=I9"`B4F5L;V%D(%9I97<B"FUS
M9W-T<B`BV*C8I]BQVJ_8L-BGV+';C"#9A=BLV*_8KR#9AMF%V*<B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z-3(V(&QI8B]-24U%+U9I97=E<B]I
M=&EP+G!H<#HU-#4*;7-G:60@(E)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN(@IM<V=S='(@(MBHV8<@VXS8I]BOV*+9B-BQVXP@V*?8M]F$
MV*?8N=BGV*H@V*+8LMBGV*\OV878M-BZV8C9A"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-SD*;7-G:60@(E)E;65M8F5R('1H92!L87-T('9I97<B
M"FUS9W-T<B`BV*C9AR#B@(S;C-BGV*_8HMF(V+';C"#8HMBNV+';C-F&(-F!
MV+'9A2#9AMF%V*?;C-BT(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]M86YA
M9V4N:6YC.C(W"FUS9VED(")296UO=&4@36%I;&)O>#HB"FUS9W-T<B`BV8;8
MI]F%V8?B@(S8K]BGV88@V+'8I]F'(-BOV8C8L3HB"@HC.B!T96UP;&%T97,O
M<V5A<F-H+V9I96QD<RYI;F,Z-#$*;7-G:60@(E)E;6]V92!&:65L9"!&<F]M
M(%-E87)C:"(*;7-G<W1R("+8K=BPV8$@V8';C-F$V*\@V*?8LB#8K-BSV*K8
MK-F((@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z,S`U
M"FUS9VED(")296UO=F4@<V]U<F-E(@IM<V=S='(@(MBMV+#9@2#8L]BQVH;8
MM-F%V8<B"@HC.B!T96UP;&%T97,O9F]L9&5R<R]A8W1I;VYS+FEN8SHX"FUS
M9VED(")296YA;64@1F]L9&5R*',I(@IM<V=S='(@(MBJV+K;C-N,V+$@V8;8
MI]F%(-F^V8C8M-F'*-F'V*<I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,0IM<V=I9"`B4F5N86UE('-E;G0M;6%I;"!F;VQD97(@870@8F5G:6YN
M:6YG(&]F(&UO;G1H/R(*;7-G<W1R("+8HMN,V*<@V;[9B-BTV8?9E"#9AMBG
MV879A^*`C-F'V*?;C"#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V*_8L2#8I]BH
MV*K8K]BGVXP@V878I]F'(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8K]F'(-BT
MV8C8K]B?(@H*(R`*(SH@;&EB+T9O;&1E<BYP:'`Z-#4U"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E;F%M:6YG(%PB)7-<(B!T;R!<(B5S7"(@9F%I;&5D+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(@IM<V=S='(@(MBJV+K;C-N,
MV+$@V8;8I]F%(%PB)7-<(B#8J-F'(%PB)7-<(B#9AMBGV879B-F!V9'9@B#8
MJ-F(V*\N(-BGVXS9AB#:AMN,V++;C"#8I]BSV*H@VJG9AR#:J=BGV+'8L]BG
MV+(@VJ_9@=BJV8<@V*?8L]BJ(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7V%C=&EO;G,N:6YC.C$P"FUS9VED(")297!L7WD@=&\@3&ES="(*;7-G
M<W1R("+9OMBGV+/8KB#8J-F'(-F!V8?8L=BSV*HB"@HC.B!T96UP;&%T97,O
M8V]M<&]S92]S<&5L;&EN9RYI;F,Z,3`U"FUS9VED(")297!L86-E('=I=&@Z
M(@IM<V=S='(@(MBLV*?;C-JOV++;C-F&(-JIV+'8K]F&(-BHV*<Z(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C@*;7-G:60@
M(E)E<&QY(@IM<V=S='(@(MF^V*?8L]BN("(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HS,3$@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0P.0IM
M<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`BV;[8I]BSV*X@V*?8L=BSV*?9
MA"#8M-BO(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N
M:6YC.C$S"FUS9VED(")297!L>2!T;R!!;&PB"FUS9W-T<B`BV;[8I]BSV*X@
MV*C9AR#9A]F%V8<B"@HC.B!C;VUP;W-E+G!H<#HW,S,*;7-G:60@(E)E<&QY
M('1O($%L;#HB"FUS9W-T<B`BV;[8I]BSV*X@V*C9AR#9A]F%V8<Z(@H*(SH@
M=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C$P"FUS9VED
M(")297!L>2!T;R!,:7-T(@IM<V=S='(@(MF^V*?8L]BN(-BHV8<@V8'9A]BQ
MV+/8JB(*"B,Z(&-O;7!O<V4N<&AP.C<S-0IM<V=I9"`B4F5P;'D@=&\@3&ES
M=#HB"FUS9W-T<B`B.MF^V*?8L]BN(-BHV8<@V8'9A]BQV+/8JB(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ,PIM<V=I9"`B
M4F5P;'D@=&\@7T%L;"(*;7-G<W1R("+9OMBGV+/8KB#8J-F'(-F'V879AR(*
M"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,C@@;&EB+TU)344O5FEE
M=V5R+VET:7`N<&AP.C4S-PHC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-30W"FUS9VED(")297!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*
M;7-G<W1R("+9OMBGV+/8KB#8J-BG(-F^VXS8NMBGV84@V;[8M-BJVXS8J-BG
MV8;;C"#9AMBTV*_9AR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU
M,S4*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N
M=&AS+B(*;7-G<W1R("+9OMBGV+/8KB#8J-BG(-BBV++8I]BO+]F%V+38NMF(
MV80@V*C8L=BGVXP@V*_9B"#9A=BGV8<@V*+;C-F&V*_9AR(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I=&EP+G!H<#HU,S0*;7-G:60@(E)E<&QY('=I=&@@<F5Q
M=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`BV;[8I]BS
MV*X@V*C8IR#8I]BWV838I]BYV*?8JB#8HMBRV*?8KR_9A=BTV+K9B-F$(-BN
MV8C8I]BSV*K9AR#8M-BOV8<B"@HC.B!M97-S86=E+G!H<#HR-C<*;7-G:60@
M(E)E<&QY+51O(@IM<V=S='(@(MF^V*?8L]BN(-BHV8<B"@HC.B!L:6(O0V]M
M<&]S92YP:'`Z-#`Y"FUS9VED(")297!L>2U4;SH@(@IM<V=S='(@(MF^V*?8
ML]BN(-BHV8<Z("(*"B,Z(&-O;7!O<V4N<&AP.C<S,0IM<V=I9"`B4F5P;'DZ
M(@IM<V=S='(@(MF^V*?8L]BN.B(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA
M=F)A<E]A8W1I;VYS+FEN8SHS."!T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS
M+FEN8SHR-@IM<V=I9"`B4F5P;W)T(&%S($EN;F]C96YT(@IM<V=S='(@(MJO
MV++8I]BQV+0@V*C8N=F&V8C8I]F&(-BHVXSB@(S8MMBQV+$B"@HC.B!T96UP
M;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,S4@=&5M<&QA=&5S
M+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C,*;7-G:60@(E)E<&]R="!A<R!3<&%M
M(@IM<V=S='(@(MJOV++8I]BQV+0@V*C8N=F&V8C8I]F&(-F'V+'8LMF&V*?9
MA=F'(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,S@S"FUS
M9VED(")297%U97-T(&$@7U)E860@4F5C96EP="(*;7-G<W1R("+8K]BQV*[9
MB-BGV+/8JB#;C-JI(-BQV+/;C-BO(-F%V+?8I]F$V+G9AR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU.#4*;7-G:60@(E)E<75E<W0@9&5L:79E<GD@
M8V]N9FER;6%T:6]N/R(*;7-G<W1R("(@V*+;C-BG(-BHV+'8I]N,(-BJV*W9
MB-N,V80@V*K8I]BFVXS8K]N,V8<@V*_8L=BNV8C8I]BSV*H@V+39B-BOV)\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3<S"FUS9VED(")297%U97-T
M(')E860@<F5C96EP=',_(@IM<V=S='(@(MBBVXS8IR#8L=BSVXS8KR#9A=BW
MV*?9A-BYV8<@V*_8L=BNV8C8I]BSV*H@V+39B-BOV)\B"@HC.B!M86EL8F]X
M+G!H<#HQ.#D*;7-G:60@(E)E<75E<W1E9"!M97-S86=E(&YO="!F;W5N9"XB
M"FUS9W-T<B`BV;[;C-BZV*?9A2#8KMF(V*?8L]BJV8<@V+38K]F'(-F^VXS8
MK]BG(-F&V+38KR(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV.3<*
M;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(MBTV+';C-JI
M(-F%V8C8L=BO(-F&VXS8I]BR(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN
M+FEN8SHQ-#,@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C(V"B,Z('1E
M;7!L871E<R]A8VPO86-L+FEN8SHQ-C$*;7-G:60@(E)E<V5T(@IM<V=S='(@
M(MBHV*?8LMF&V+38I]F&VXPB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP
M:'`Z,3$U"FUS9VED(")297-P;VYD96YT(%-T871U<R!5<&1A=&5D+B(*;7-G
M<W1R("+8K=BGV838I]BJ(-F^V*?8L]BNVJ_9B-N,VXP@V*C8L=F(V++8L=BS
MV*?9AMN,(-BTV*_9AMBO(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R
M7V%C=&EO;G,N:6YC.C,P"FUS9VED(")297-U;64B"FUS9W-T<B`BV*?8LB#8
ML]BQVJ_8L=F!V*K9AB(*"B,Z(')E8V]M<&]S92YP:'`Z.3@*;7-G:60@(E)E
M<W5M92!Y;W5R('-E<W-I;VXB"FUS9W-T<B`BV*?8LB#8L]BQ(-JOV+'9@=BJ
MV88@V8;8M-BSV*H@V+39A=BG(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO
M<')E9G,N:6YC.C0T"FUS9VED(")2971U<FX@=&\@7")-97-S86=E($-O;7!O
M<VET:6]N7"(B"FUS9W-T<B`BV*C8I]BRVJ_8M-BJ(-BHV8<@V*?;C-BLV*?8
MKR#9OMN,V+K8I]F%(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]D<FEV97)?
M<V5L96-T+FEN8SHS,2!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z
M-CD*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI;F,Z
M,S(*;7-G:60@(E)E='5R;B!T;R!&971C:"!-86EL(@IM<V=S='(@(MBHV*?8
MLMJOV+38JB#8J-F'(-F(V*?:J=BTVXP@V8;8I]F%V8<B"@HC.B!T96UP;&%T
M97,O9FEL=&5R<R]P<F5F<RYI;F,Z-C`@=&5M<&QA=&5S+V9I;'1E<G,O;F]T
M86-T:79E+FEN8SHR,@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C$P
M,2!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ-`HC.B!T96UP;&%T
M97,O<&=P+W!G<"YI;F,Z,30Y('1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN
M8SHQ-0HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,38R('1E;7!L871E<R]A
M8VPO86-L+FEN8SHQ-S,*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S
M='(@(MBHV*?8LMJOV+38JB#8J-F'(-JOV++;C-F&V8?B@(S9A]BG(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Q.`IM<V=I9"`B(@HB4F5T=7)N('1O
M('1H92!M86EL8F]X(&QI<W1I;F<@869T97(@9&5L971I;F<L(&UO=FEN9RP@
M;W(@8V]P>6EN9R!A(&UE<W-A9V4_(@IM<V=S='(@(B(*(MBBVXS8IR#8J-BY
MV*\@V*?8LB#8K=BPV8'8C"#8I]F&V*K9@MBGV80@V8@@VXS8IR#8L=F(V8;9
MB-BTV*H@VJ_8L=F!V*K9AB#8I]BR(-N,VJD@V;[;C-BZV*?9A=B,(-BHV8<@
MV8'9A]BQV+/8JB#9AMBGV879A^*`C-BOV*?9AB`B"B+8J-BGV++:K]BTV*H@
MV+39B-BOV)\B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C@X"FUS
M9VED(")2;VQE(@IM<V=S='(@(MF&V8+8M"(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]P:V-S-RYP:'`Z,30R(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z,C,W
M"B,Z(&QI8B]-24U%+U9I97=E<B]P:V-S-RYP:'`Z-#$Y"FUS9VED(")3+TU)
M344B"FUS9W-T<B`B4R]-24U%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O96YC
M<GEP=%]L:7-T+FEN8SHQ,@IM<V=I9"`B4R]-24U%($5N8W)Y<'0@365S<V%G
M92(*;7-G<W1R("+9OMN,V+K8I]F%(-BQV878LMBHV8;8K]N,(%,O34E-12`B
M"@HC.B!C;VUP;W-E+G!H<#HS.30*;7-G:60@(E,O34E-12!%<G)O<CH@(@IM
M<V=S='(@(MBNV+?8I]N,(%,O34E-13H@(@H*(SH@8V]M<&]S92YP:'`Z,S<S
M"FUS9VED(")3+TU)344@17)R;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R
M<V]N86P@<')I=F%T92!K97DN(@IM<V=S='(@(MBNV+?8I]N,(%,O34E-13H@
MV8;;C-BGV+(@V*C9AR#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#:J=F$
MVXS8KR#8KMBUV8C8M=N,(-BTV*[8M=N,(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U,0IM<V=I9"`B4R]-24U%($]P=&EO;G,B"FUS9W-T<B`BVJ_8
MLMN,V8;9A^*`C-F'V*?;C"!3+TU)344B"@HC.B!S;6EM92YP:'`Z-#D*;7-G
M:60@(E,O34E-12!087-S<&AR87-E($EN<'5T(@IM<V=S='(@(MF(V*?8L=BO
MVJG8L=BOV88@4R]-24U%(-BYV*C8I]BQV*H@VJ_8L-BQ(@H*(SH@=&5M<&QA
M=&5S+W-M:6UE+W-M:6UE+FEN8SHU-`IM<V=I9"`B4R]-24U%(%!E<G-O;F%L
M($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`BV;[8M-BJVXS8J-BGV8;;C"#8K-F!V*H@VJG9A-N,
MV*\@V+38KMBUVXP@4R]-24U%(-BHV8<@VXS:J2#8I]BJV+78I]F$(-BGV879
MAB#9B-BH(-F&VXS8I]BRV879AMBO(-BGV+/8JB(*"B,@"B,Z('-M:6UE+G!H
M<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4R]-24U%(%!U8FQI8R!+97D@
M9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(@IM<V=S='(@
M(MJIV83;C-BO(-BYV879B-F%VXP@4R]-24U%(-BHV+'8I]N,(%PB)7-<(B#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W8L-F!(-BTV*\B"@HC.B!S;6EM92YP
M:'`Z,38R"FUS9VED(")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@
M861D960N(@IM<V=S='(@(MJIV83;C-BO(-BYV879B-F%VXP@4R]-24U%(-BH
MV*<@V879B-F!V9'9@MN,V9'8JB#8I]BVV*?9@=F'(-BTV*\B"@HC.B!T96UP
M;&%T97,O<VUI;64O<VUI;64N:6YC.C$P"FUS9VED(")3+TU)344@4'5B;&EC
M($ME>7)I;F<B"FUS9W-T<B`BV*W9A-F"V8?9E"#:J=F$VXS8KR#8N=F%V8C9
MA=N,(%,O34E-12(*"B,Z('-M:6UE+G!H<#HR,3$*;7-G:60@(E,O34E-12!0
M=6)L:6,O4')I=F%T92!+97EP86ER('-U8V-E<W-F=6QL>2!A9&1E9"XB"FUS
M9W-T<B`BV*S9@=BJ(-JIV83;C-BO(-BYV879B-F%VXPOV+38KMBUVXP@4R]-
M24U%(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]BVV*?9@=F'(-BTV*\B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC.C$S"FUS9VED
M(")3+TU)344@4VEG;B!-97-S86=E(@IM<V=S='(@(MBGV878MMBGV*$@V+38
MK]F'(%,O34E-12#9OMN,V+K8I]F%(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M96YC<GEP=%]L:7-T+FEN8SHQ-`IM<V=I9"`B4R]-24U%(%-I9VXO16YC<GEP
M="!-97-S86=E(@IM<V=S='(@(MF^VXS8NMBGV84@V+'9A=BRV*C9AMBOVXP@
MV+38K]F'+]BGV878MMBGV*$@V+38K]F'(%,O34E-12`B"@HC.B!T96UP;&%T
M97,O<VUI;64O;F]T86-T:79E+FEN8SHT"FUS9VED(")3+TU)344@<W5P<&]R
M="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB"FUS9W-T<B`BV;[8M-BJ
MVXS8J-BGV8;;C"!3+TU)344@V+'9B-N,(-BGVXS9AB#8L]BGV878I]F&V8<@
MV8'8N=BGV80@V8;;C-BSV*HB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N
M<&AP.C(T,0IM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&-U<G)E
M;G1L>2!E;F%B;&5D('-O('1H92!M97-S86=E(&ES('5N86)L92!T;R!B92`B
M"B)D96-R>7!T960N(@IM<V=S='(@(B(*(MF^V+38JMN,V*C8I]F&VXP@4R]-
M24U%(-BOV+$@V*W8I]F$(-BMV*?8MMBQ(-F!V+G8I]F$(-F&VXS8L]BJ(-BG
MV+(@V*?;C-F&V+'9B"#9OMN,V+K8I]F%(-F"V*?8J-F$(-BQV878LMJOV+38
MI]N,VXP@V8;;C-BSV*HB"@HC.B!L:6(O34E-12]6:65W97(O<&MC<S<N<&AP
M.C$W,PIM<V=I9"`B(@HB4R]-24U%('-U<'!O<G0@:7,@;F]T(&5N86)L960@
M<V\@=&AE(&-O;G1E;G1S(&]F('1H:7,@<VEG;F5D(&UE<W-A9V4@8V%N(&YO
M="`B"B)B92!D:7-P;&%Y960N(@IM<V=S='(@(MF^V+38JMN,V*C8I]F&VXP@
M4R]-24U%(-F!V+G8I]F$(-F&VXS8L]BJ(-BGV+(@V*?;C-F&V+'9B"#9A=BJ
MV88@V;[;C-BZV*?9A2#9AMF%VXSB@(S8JMF(V*?9AMBO(-F&V878I]N,V+0@
MV*_8I]BOV8<@V+39B-BO(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H
M<#HQ-#8*;7-G:60@(B(*(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D
M('-O('1H92!D:6=I=&%L('-I9VYA='5R92!I<R!U;F%B;&4@=&\@8F4@(@HB
M=F5R:69I960N(@IM<V=S='(@(MF^V+38JMN,V*C8I]F&VXP@4R]-24U%(-F!
MV+G8I]F$(-F&VXS8L]BJ(-BGV+(@V*?;C-F&V+'9B"#8I]F%V+;8I]N,(-BO
MVXS8K-N,V*K8I]F$VXP@V8+8I]BHV80@V*C8I]BRV*C;C-F&VXP@V8;;C-BS
MV*HB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C(*;7-G:60@(B(*
M(E,O34E-12!S=7!P;W)T(')E<75I<F5S('!O<'5P('=I;F1O=W,@=&\@8F4@
M=7-E9"X@($EF('EO=7(@8G)O=W-E<B!I<R`B"B)C=7)R96YT;'D@<V5T('1O
M(&1I<V%B;&4@<&]P=7`@=VEN9&]W<RP@>6]U(&UU<W0@8VAA;F=E('1H:7,@
M<V5T=&EN9R!O<B!E;'-E("(*(G1H92!3+TU)344@9F5A='5R97,@=VEL;"!N
M;W0@=V]R:R!C;W)R96-T;'DN(@IM<V=S='(@(B(*(MF^V+38JMN,V*C8I]F&
MVXP@4R]-24U%(-BHV+'8I]N,(-BYV879A-JIV+'8KR#8M=BMVXS8K2#8KMF(
MV*\@V8;;C-BGV+(@V*C9AR#9OMF&V*S8L=F'XH",V8?8I]N,(-JOV+39B-BO
MV8;;C"#8K]BGV+'8KR#9A=BQV8C8L=JOV+'8KMF(V*\@(@HBV+'8IR#8J-BQ
MV*?;C"#8I]BSV*K9@=BGV*_9AR#8I]BR(-BGVXS9AB#9OMF&V*S8L=F'XH",
MV8?8IR#8JMF&V+C;C-F%(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,#4*;7-G:60@(E--5%`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z,C4U"FUS9VED(")37W5B:F5C
M="(*;7-G<W1R("+8N=F&V8C8I]F&(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,S8S"FUS9VED(")385]V92!A(&-O<'D@:6X@(@IM<V=S
M='(@(MBMV8'8N"#;C-JI(-BQV8C9AMF(V+38JB#8K]BQ(@H*(SH@=&5M<&QA
M=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,R"FUS9VED(")385]V
M92!A<R(*;7-G<W1R("+8K=F!V+@@V*C8IR#9AMBGV84B"@HC.B!S96%R8V@N
M<&AP.C,Q-B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-C<*;7-G
M:60@(E-A=F4B"FUS9W-T<B`BV*W9@=BX(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O8V]M<&]S92YI;F,Z-3,X"FUS9VED(")3879E($%T=&%C:&UE;G1S('=I
M=&@@;65S<V%G92!I;B!S96YT+6UA:6P@9F]L9&5R/R(*;7-G<W1R("+8HMN,
MV*<@V;[;C-F(V+/8JMF'V*?;C"#9OMN,V+K8I]F%(-BOV+$@V;[9B-BTV8?9
ME"#9AMBGV879A^*`C-F'V*?;C"#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V*W9
M@=BX(-BTV8C8K]B?(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI
M;F,Z-CD@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-#,S"FUS9VED
M(")3879E($1R869T(@IM<V=S='(@(MBMV8'8N"#9OMN,V+0@V8;9B-N,V+,B
M"@HC.B!S879E:6UA9V4N<&AP.C0R"FUS9VED(")3879E($EM86=E(@IM<V=S
M='(@(MBMV8'8N"#8JMBUV8C;C-BQ(@H*(SH@;&EB+TU)344O0V]N=&5N=',N
M<&AP.C(P-`IM<V=I9"`B4V%V92!);6%G92!I;B!'86QL97)Y(@IM<V=S='(@
M(MBMV8'8N"#8JMBUV8C;C-BQ(-BOV+$@VJ_8I]F$V+';C"(*"B,Z('1E;7!L
M871E<R]F:6QT97)S+W!R969S+FEN8SHU.2!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C$P,`HC.B!T96UP;&%T97,O<VUI;64O;F]T86-T:79E+FEN8SHQ
M,B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z,30X"B,Z('1E;7!L871E<R]P9W`O
M;F]T86-T:79E+FEN8SHQ,PIM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@
M(MBMV8'8N"#:K]BRVXS9AMF'XH",V8?8IR(*"B,Z('1E;7!L871E<R]S=&%T
M:6]N97)Y+W!R969S+FEN8SHT,`IM<V=I9"`B4V%V92!3=&%T:6]N97)Y(@IM
M<V=S='(@(MBMV8'8N"#9AMF(V+38JN*`C-BGV8'8LMBGV+$B"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV.2!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,S,*;7-G:60@(E-A=F4@7T1R869T(@IM<V=S='(@
M(MBMV8'8N"#9OMN,V+0@V8;9B-N,V+,B"@HC.B!T96UP;&%T97,O;65S<V%G
M92]N879B87)?86-T:6]N<RYI;F,Z,S(*;7-G:60@(E-A=F4@87,B"FUS9W-T
M<B`BV*W9@=BX(-BHV*<@V8;8I]F%(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4R,0IM<V=I9"`B4V%V92!D<F%F=',@87,@=6YS965N/R(*;7-G<W1R
M("+8HMN,V*<@V;[;C-BT(-F&V8C;C-BSV8?8IR#8J-BYV8;9B-BGV88@V;[;
MC-BZV*?9A=F'V*?;C"#9A=BTV*?9A]BOV8<@V8;8M-BOV8<@V*W9@=BX(-BT
MV8C8K]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-S(*;7-G:60@
M(E-A=F4@<F5C:7!I96YT<R!A=71O;6%T:6-A;&QY('1O('1H92!D969A=6QT
M(&%D9')E<W,@8F]O:S\B"FUS9W-T<B`BV*+;C-BG(-JOVXS8L=F&V*_9A^*`
MC-F'V*<@V*C9AR#8M]F(V+$@V*[9B-BOVJG8I]BQ(-BOV+$@VJG8JMBGV*C:
MAMF'V90@V*+8K]BQV+,@V*W9@=BX(-BTV8C9AMBOV)\B"@HC.B!T96UP;&%T
M97,O<V5A<F-H+VUA:6XN:6YC.C$R-PIM<V=I9"`B4V%V92!S96%R8V@@87,@
M82!V:7)T=6%L(&9O;&1E<C\B"FUS9W-T<B`BV*+;C-BG(-BLV+/8JMBLV8@@
MV*C9AR#8N=F&V8C8I]F&(-N,VJD@V;[9B-BTV8?9E"#9A=BLV*?8LMN,(-BM
MV8'8N"#8M-F(V*_8GR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*
M;7-G:60@(E-A=F4@<V5N="!M86EL/R(*;7-G<W1R("+8HMN,V*<@V8;8I]F%
MV8?9E"#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V*W9@=BX(-BTV8C8K]B?(@H*
M(R`*(SH@8V]M<&]S92YP:'`Z,3(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879I;F<@=&AE(&1R869T(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@)7,B"FUS9W-T<B`BV*W9@=BX(-F^VXS8M"#9AMF(VXS8LR#9
MAMBGV879B-F!V9'9@B#8J-F(V*\N(-BGVXS9AB#:AMN,V++;C"#8I]BSV*H@
MVJG9AR#:J=BGV+'8L]BGV+(@VJ_9@=BJV8<@V*?8L]BJ.B`E<R(*"B,Z('1E
M;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3DY('1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,Z,3$*(SH@;&EB+T)L;V-K+W1R965?9F]L9&5R
M<RYP:'`Z-#$*;7-G:60@(E-E87)C:"(*;7-G<W1R("+8K-BSV*K8K-F((@H*
M(SH@=&5M<&QA=&5S+W-E87)C:"]H96%D97(N:6YC.C$X('1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A
M<F-H("5S(@IM<V=S='(@(MBLV+/8JMBLV8@@)7,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(P"B,L(&9U>GIY"FUS9VED(")396%R8V@@3W!T:6]N
M<R(*;7-G<W1R("+8K=F!V+@@VJ_8LMN,V8;9A^*`C-F'V*<B"@HC.B!S96%R
M8V@N<&AP.C(V-0IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS9W-T<B`BV8;8
MJMBGVXS8K"#8K-BSV*K8K-F((@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;F%V
M8F%R+FEN8SHQ-"!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,Q"FUS
M9VED(")3965N(@IM<V=S='(@(MF%V+38I]F'V*_9AR#8M-BOV8<B"@HC(",M
M(RTC+2,M(R`@9F%?25(N<&\@*%1U<F)A(#$N,BXR*2`@(RTC+2,M(RTC"B,@
M;7-G:60@(E-E87)C:"!297-U;'1S(@HC(&US9W-T<B`BV8;8JMBGVXS8K"#8
MK-BSV*K8K-F((@HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.CD*
M;7-G:60@(E-E;&5C="(*;7-G<W1R("+8I]F&V*K8KMBGV*@B"@HC.B!T96UP
M;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z-S`*;7-G:60@(E-E;&5C="!!
M;F]T:&5R($%C8V]U;G0B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@V*W8
ML]BGV*@@V*_;C-JOV+$B"@HC.B!T96UP;&%T97,O<V5A<F-H+V9I96QD<RYI
M;F,Z,S8*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BV*?9AMBJV*[8
MI]BH(-N,VJD@V*K8I]BQVXS8KB(*"B,Z('1E;7!L871E<R]S96%R8V@O9FEE
M;&1S+FEN8SHQ,`IM<V=I9"`B4V5L96-T(&$@9FEE;&0B"FUS9W-T<B`BV*?9
MAMBJV*[8I]BH(-N,VJD@V8';C-F$V*\B"@HC.B!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHS,3<*;7-G:60@(E-E;&5C="!A('-T871I;VYE<GDZ
M(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-F&V8C8M-BJXH",V*?9@=BR
MV*?8L3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")3
M96QE8W0@861D<F5S<R!B;V]K('-O=7)C97,@9F]R(&%D9&EN9R!A;F0@<V5A
M<F-H:6YG(&9O<B!A9&1R97-S97,N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#:
MJ=BJV*?8J-J&V8?B@(S9A]BGVXP@V*+8K]BQV+,@V*?8M=F$VXP@V*C8L=BG
MVXP@V*S8L]BJV*S9B"#9B"#8I]BVV*?9@=F'(-JIV+'8K]F&(-BBV*_8L=BS
MV8?8IR(*"B,@(RTC+2,M(RTC("!F85])4BYP;R`H5'5R8F$@,2XR+C(I("`C
M+2,M(RTC+2,*(R!M<V=I9"`B4V5A<F-H(%)E<W5L=',B"B,@;7-G<W1R("+9
MAMBJV*?;C-BL(-BLV+/8JMBLV8@B"B,Z('1E;7!L871E<R]S96%R8V@O;6%I
M;BYI;F,Z.#@*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`BV*?9AMBJV*[8
MI]BH(-F'V879AR(*"B,Z('1E;7!L871E<R]P<F5F<R]S;W5R8V5S96QE8W0N
M:6YC.C,R,PIM<V=I9"`B4V5L96-T(&%L;"!F:65L9',@=&\@<V5A<F-H('=H
M96X@97AP86YD:6YG(&%D9')E<W-E<RXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH
M(-BJV878I]F%VXP@V8';C-F$V*_B@(S9A]BG(-BHV+'8I]N,(-BLV+/8JMBL
MV8@@V8C9@MBJVXP@V*+8K]BQV+/9A]BG(-BHV*?8LB#9A=N,XH",V+39B-F&
MV*\@(@H*(SH@=&5M<&QA=&5S+V9E=&-H;6%I;"]A8V-O=6YT7W-E;&5C="YI
M;F,Z,C$*;7-G:60@(E-E;&5C="!A;B!A8V-O=6YT(@IM<V=S='(@(MBGV8;8
MJMBNV*?8J"#;C-JI(-BMV+/8I]BH(@H*(R`C+2,M(RTC+2,@(&9A7TE2+G!O
M("A4=7)B82`Q+C(N,BD@(",M(RTC+2,M(PHC(&US9VED(")396%R8V@@4F5S
M=6QT<R(*(R!M<V=S='(@(MF&V*K8I]N,V*P@V*S8L]BJV*S9B"(*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHX.0IM<V=I9"`B4V5L96-T(&YO;F4B
M"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F'VXS:AN*`C-N,VJDB"@HC.B!T96UP
M;&%T97,O<V%V96EM86=E+W-A=F5I;6%G92YI;F,Z.0IM<V=I9"`B4V5L96-T
M('1H92!G86QL97)Y('1O('-A=F4@=&AE(&EM86=E(&EN+B(*;7-G<W1R("+8
MI]F&V*K8KMBGV*@@VJ_8I]F$V+';C"#8J-BQV*?;C"#8K=F!V+@@V*K8M=F(
MVXS8L2(*"B,Z('1E;7!L871E<R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI
M;F,Z,C$*;7-G:60@(E-E;&5C="!T:&4@;6%I;"!S97)V97(@='EP92(*;7-G
M<W1R("+8I]F&V*K8KMBGV*@@V8;9B-BY(-JIV*?8L=BSV*?8LB#9AMBGV879
MA]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@=&5M<&QA=&5S+W!R969S
M+W-O=7)C97-E;&5C="YI;F,Z,S`Y"FUS9VED(")396QE8W1E9"!!9&1R97-S
M(&)O;VMS.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VJG8JMBGV*C:AMF'XH",
MV8?8I]N,(-BBV*_8L=BS.B(*"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW
M,@IM<V=I9"`B4V5N9"!+97D@=&\@4'5B;&EC($ME>7-E<G9E<B(*;7-G<W1R
M("+8I]BQV+/8I]F$(-JIV83;C-BO(-BHV8<@VJG8I]BQV+/8I]BR(-JIV83;
MC-BO(-BYV879B-F%VXPB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M-C`T"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R("+8
MI]BQV+/8I]F$(-BBV*[8L=N,V88@V*?8M]F$V*?8N=BGV*HB"@HC.B!T96UP
M;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHV-R!T96UP;&%T97,O8V]M<&]S
M92]C;VUP;W-E+FEN8SHT,S$*;7-G:60@(E-E;F0@365S<V%G92(*;7-G<W1R
M("+8I]BQV+/8I]F$(-F^VXS8NMBGV84B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S`S"FUS9VED(")396YD(')E860@<F5C96EP="!W:&5N(')E<75E
M<W1E9"!B>2!T:&4@<V5N9&5R/R(*;7-G<W1R("(@V*+;C-BGV+'8L]N,V*\@
MV878M]BGV838N=F'(-F'V8;:K]BGV87;C"#:J=F'(-BGV+'8L]BGV80@VJG9
MAMF&V*_9AR#8K]BQV*[9B-BGV+/8JB#9A=N,XH",VJG9AMBOV(P@V*?8L=BS
MV*?9A"#8M-F(V*_8GR(*"B,Z(&9O;&1E<G,N<&AP.C,Y-PIM<V=I9"`B4V5N
M="!M86EL(&9O;&1E<B(*;7-G<W1R("+9OMF(V+39AR#9OMN,V+K8I]F%V8?8
MI]N,(-F!V+'8L]BJV*?8K]F'(-BTV*_9AR(*"B,Z('1E;7!L871E<R]P<F5F
M<R]S96YT;6%I;'-E;&5C="YI;F,Z,S@*;7-G:60@(E-E;G0@;6%I;"!F;VQD
M97(Z(@IM<V=S='(@(MF^V8C8M-F'(-F^VXS8NMBGV879A]BGVXP@V8'8L=BS
MV*K8I]BOV8<@V+38K]F'.B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,3,R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,30V"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,34S"FUS9VED(")397)V97(B"FUS9W-T
M<B`BVJG8I]BQV+/8I]BR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M"FUS9VED(")397)V97(@86YD($9O;&1E<B!);F9O<FUA=&EO;B(*;7-G<W1R
M("+8I]BWV838I]BYV*?8JB#:J=BGV+'8L]BGV+(@V8@@V;[9B-BTV8<B"@HC
M.B!T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,Z,C,*;7-G:60@(E-E
M<G9E<CHB"FUS9W-T<B`BVJG8I]BQV+/8I]BR.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,`IM<V=I9"`B4V5T('!R969E<F5N8V5S(&9O<B!W:&%T
M(&AA<'!E;G,@=VAE;B!Y;W4@;6]V92!A;F0@9&5L971E(&UE<W-A9V5S+B(*
M;7-G<W1R("+8JMF&V+C;C-F%(-JOV++;C-F&V8?B@(S9A]BG(-BHV+'8I]N,
M(-BRV878I]F&(-BMV+#9@2#9B"#;C-BG(-BGV8;8JMF"V*?9A"#9OMN,V+K8
MI]F%V8?8IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@
M(E-E="!T:&4@6"U0<FEO<FET>2!H96%D97(@=VAE;B!C;VUP;W-I;F<@;65S
M<V%G97,_(@IM<V=S='(@(MBBVXS8IR#8L]BQV*+9A=BO(%@M4')I;W)I='D@
MV8?9AMJOV*?9A2#8I]N,V*S8I]BO(-F^VXS8NMBGV879A]BG(-BJV8;8N-N,
MV84@V+39B-BOV)\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$*;7-G
M:60@(E-H87)E($9O;&1E<G,B"FUS9W-T<B`BV;[9B-BTV8?B@(S9A]BGVXP@
MV878M-BJV+':J2(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHX-@IM<V=I
M9"`B4VAA<F4@;6%I;"!F;VQD97)S(@IM<V=S='(@(MF^V8C8M-F'XH",V8?8
MI]N,(-F&V*?9A=F'V90@V878M-BJV+':J2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,@IM<V=I9"`B4VAA<F4@>6]U<B!M86EL(&9O;&1E<G,@=VET
M:"!O=&AE<B!U<V5R<RXB"FUS9W-T<B`BV*?8M-BJV+'8I]JI(-F^V8C8M-F'
MXH",V8?8I]N,(-F&V*?9A=F'V90@V+39A=BG(-BHV*<@VJG8I]BQV*C8L=BG
MV88@V*_;C-JOV+$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8Y"FUS
M9VED("(B"B)3:&]U;&0@;&%R9V4@8FQO8VMS(&]F('%U;W1E9"!T97AT(&)E
M('-H;W=N(&]R(&AI9&1E;B!B>2!D969A=6QT/R!)="!C86X@8F4@(@HB=&]G
M9VQE9"!E87-I;'D@=VAI8VAE=F5R('EO=2!C:&]O<V4N(@IM<V=S='(@(B(*
M(MBBVXS8IR#8J-F$V8C:J=F'V*?;C"#8J-BRV+':KR#9AMF"V80@V8+9B-F$
M(-F&V878I]N,V+0@V*_8I]BOV8<@V+39B-F&V*_8C"#;C-BG(-F^V8;9A]BG
MV88@V+39B-F&V*_8GR#8I]N,V88@(-BJV8;8N-N,V84@V*C9AR#8L=BGV*W8
MJMN,("(*(MBOV+$@V8?8L2#8LMF%V*?9AB#:J=F'(-BHV*[9B-BGV8?;C-BO
M(-F"V*?8J-F$(-BJV+K;C-N,V+$@V*?8L]BJ(@H*(SH@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C<*;7-G:60@(E-H;W5L9"!T:&4@8F]D>2!O9B!T97AT+W!L
M86EN(&UE<W-A9V5S(&)E('-C86YN960@9F]R(%!'4"!D871A/R(*;7-G<W1R
M("+8HMN,V*<@V*C8K]F&V8?9E"#9OMN,V+K8I]F%V8?8IR#8J-BG(-F%V*K9
MAB#8L]BGV*_9AR#8J-BQV*?;C"#8K]BGV*_9AR!01U`@V;[9B-N,VXS8K]F'
M(-BTV8C9AMBOV)\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$S"FUS
M9VED(")3:&]U;&0@=&AE(&-O;7!O<V4@=VEN9&]W(&)E(&-L;W-E9"!A9G1E
M<B!S879I;F<@82!D<F%F=#\B"FUS9W-T<B`BV*+;C-BG(-BUV8'8K=F'(-BG
MVXS8K-BGV*\@V;[;C-BZV*?9A2#8J-BGVXS8KR#8J-BYV*\@V*?8LB#8K=F!
MV+@@VXS:J2#9OMN,V+0@V8;9B-N,V+,@V*C8L]BJV8<@V+39B-BOV)\B"@HC
M.B!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-`IM<V=I9"`B4VAO=6QD('EO=7(@
M4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U<B!M97-S86=E
M<R!B>2!D969A=6QT/R(*;7-G<W1R("+8HMN,V*<@VJG9A-N,V*\@V+G9A=F(
MV87;C"!01U`@V*C8I]N,V*\@V*C8M]F(V+$@V*[9B-BOVJG8I]BQ(-BHV8<@
MV;[;C-BZV*?9A2#8M-F%V*<@V;[;C-F(V+/8JB#8M-F(V*_8GR(*"B,Z('1E
M;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H;W<@06QL($9O
M;&1E<G,B"FUS9W-T<B`BV8;9A=BGVXS8M"#9A]F%V8?9E"#9OMF(V+39A^*`
MC-F'V*<B"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHV-PIM
M<V=I9"`B4VAO=R!!;&P@2&5A9&5R<R(*;7-G<W1R("+9AMF%V*?;C-BT(-F'
MV879A]F4(-BSV+'8HMF%V*_9A]BG(@H*(SH@;6%I;&)O>"YP:'`Z,S8U"FUS
M9VED(")3:&]W($1E;&5T960B"FUS9W-T<B`BV8;9A=BGVXS8M"#8K=BPV8$@
MV+38K]F'XH",V8?8IR(*"B,Z('1E;7!L871E<R]M97-S86=E+VAE861E<G,N
M:6YC.C8Q"FUS9VED(")3:&]W($QI;6ET960@2&5A9&5R<R(*;7-G<W1R("+9
MAMF%V*?;C-BT(-BSV+'8HMF%V*_9A]BGVXP@V878K=BOV8C8KR#8M-BOV8<B
M"@HC.B!T96UP;&%T97,O;65S<V%G92]H96%D97)S+FEN8SHW,`IM<V=I9"`B
M4VAO=R!-86EL:6YG($QI<W0@26YF;W)M871I;VXB"FUS9W-T<B`BV8;9A=BG
MVXS8M"#8I]BWV838I]BYV*?8JB#9@=F'V+'8L]BJ(-F&V*?9A=F'XH",V8?8
MIR(*"B,Z('1E;7!L871E<R]S96%R8V@O;6%I;BYI;F,Z.3(*;7-G:60@(E-H
M;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B"FUS9W-T<B`BV8'9@MBW(-F&
MV878I]N,V+0@V;[9B-BTV8?B@(S9A]BGVXP@V+G8MMF((@H*(SH@9F]L9&5R
M<RYP:'`Z,CDX"FUS9VED(")3:&]W(%5N<W5B<V-R:6)E9"(*;7-G<W1R("+9
MAMF%V*?;C-BT(-BZVXS8L=BYV+;9B.*`C-F'V*<B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C`X"FUS9VED(")3:&]W(&%N(&EC;VX@=&\@86QL;W<@
M<W1R:7!P:6YG(&]F(&%T=&%C:&UE;G1S(&9R;VT@;65S<V%G97,_(@IM<V=S
M='(@(MBBVXS8IR#;C-JI(-BBVXS:J=F(V88@V*C8L=BGVXP@V*?8KMBP(-F^
MVXS9B-BSV*K9A]BG(-BGV+(@V;[;C-BZV*?9A=F'V*<@V8;8M-BGV88@V*_8
MI]BOV8<@V+39B-BOV)\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P
M,@IM<V=I9"`B4VAO=R!L96=E;F0@:6X@=&AE(&UA:6QB;W@@=FEE=S\B"FUS
M9W-T<B`BV*+;C-BG(-BTV+'8K2#9OMN,V+K8I]F%V8?8IR#8J-F'(-F'V8;:
MK]BGV84@V8;9A=BGVXS8M"#9AMBGV879A^*`C-BOV*?9AB#9AMBTV*?9AB#8
MK]BGV*_9AR#8M-F(V*_8GR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-#`*;7-G:60@(E-H;W<@<')E=FEE=W,@9F]R('5N<F5A9"!M97-S86=E<R!O
M;FQY/R(*;7-G<W1R("+8HMN,V*<@V;[;C-BTXH",V8;9A=BGVXS8M-F'V*<@
MV8'9@MBW(-BHV+'8I]N,(-F^VXS8NMBGV879A]BGVXP@V*[9B-BGV8;8K]F'
M(-F&V+38K]F'(-F&V+38I]F&(-BOV*?8K]F'(-BTV8C9AMBOV)\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0X"FUS9VED(")3:&]W('!R979I97=S
M(&EN('1O;VQT:7!S/R(*;7-G<W1R("+8HMN,V*<@V;[;C-BT(-F&V878I]N,
MV+39A]BG(-BOV+$@V+'8I]F'V8;9A=BGVXP@V*+9AMN,(-F&V878I]N,V+0@
MV*_8I]BOV8<@V+39B-F&V*_8GR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-S<*;7-G:60@(E-H;W<@=&AE($9E=&-H($UA:6P@:6-O;B!O;B!T:&4@
M;65N=6)A<C\B"FUS9W-T<B`BV*+;C-BG(-BBVXS:J=F(V88@V8C8I]JIV+3;
MC"#9AMBGV879AR#8K]BQ(-JOV++;C-F&VJ_8I]F&(-F&V878I]N,V+0@V*_8
MI]BOV8<@V+39B-BOV)\B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z
M.34*;7-G:60@(E-H;W<@=&AE($EM86=E<R(*;7-G<W1R("+9AMF%V*?;C-BT
M(-BJV+78I]F(VXS8L2(*"B,Z('1E;7!L871E<R]F:6QT97)S+W!R969S+FEN
M8SHU-`IM<V=I9"`B4VAO=R!T:&4@9FEL=&5R(&EC;VX@;VX@=&AE(&UE;G5B
M87(_(@IM<V=S='(@(MBBVXS8IR#8HMN,VJG9B-F&(-F!VXS9A-BJV+$@V*_8
ML2#:K]BRVXS9AMJOV*?9AB#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?
M(@H*(SH@;&EB+T)L;V-K+W-U;6UA<GDN<&AP.C(X"FUS9VED(")3:&]W('1O
M=&%L(&YU;6)E<B!O9B!M86EL<R!I;B!F;VQD97(_(@IM<V=S='(@(MBBVXS8
MIR#8JMBYV*_8I]BO(-JIV80@V8;8I]F%V8?B@(S9A]BG(-BOV+$@V;[9B-BT
MV8<@V8;8M-BGV88@V*_8I]BOV8<@V+39B-BOV)\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C8V"FUS9VED(")3:&]W;B(*;7-G<W1R("+9AMF%V*?;
MC-BT(-BOV*?8K]F&(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H
M96%D97)S+FEN8SHT,@IM<V=I9"`B4VE?>F4B"FUS9W-T<B`BV*?9AMBOV*?8
MLMF'(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;&5G96YD+FEN8SHQ-PIM<V=I
M9"`B4VEG;F5D(@IM<V=S='(@(MBGV878MMBG(-BTV*_9AR(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V%T=&%C:&UE;G1S+FEN8SHS"FUS9VED(")3:7IE(@IM
M<V=S='(@(MBGV8;8K]BGV++9AR(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE
M<W-A9V5?:&5A9&5R<RYI;F,Z,3$*;7-G:60@(E-O<G0@8GD@07)R:79A;"(*
M;7-G<W1R("+9A=BQV*K8J"#8L]BGV++;C"#8J-BQ(-BGV+/8I]BS(-F(V+'9
MB-BO(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN
M8SHQ-@IM<V=I9"`B4V]R="!B>2!$871E(@IM<V=S='(@(MF%V+'8JMBH(-BS
MV*?8LMN,(-BHV+$@V*?8L]BGV+,@V*K8I]BQVXS8KB(*"B,Z('1E;7!L871E
M<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI;F,Z,C8*;7-G:60@(E-O<G0@
M8GD@1G)O;2!!9&1R97-S(@IM<V=S='(@(MF%V+'8JMBH(-BSV*?8LMN,(-BH
MV+$@V*?8L]BGV+,@V*+8K]BQV+,@V8'8L=BSV*K9AMBOV8<B"@HC.B!T96UP
M;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C0Q"FUS9VED(")3
M;W)T(&)Y($UE<W-A9V4@4VEZ92(*;7-G<W1R("+9A=BQV*K8J"#8L]BGV++;
MC"#8J-BQ(-BGV+/8I]BS(-BGV8;8K]BGV++9A]F4(-F^VXS8NMBGV84B"@HC
M.B!T96UP;&%T97,O;6%I;&)O>"]M97-S86=E7VAE861E<G,N:6YC.C,V"FUS
M9VED(")3;W)T(&)Y(%-U8FIE8W0B"FUS9W-T<B`BV878L=BJV*@@V+/8I]BR
MVXP@V*C8L2#8I]BSV*?8LR#8N=F&V8C8I]F&(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,0IM<V=I9"`B4V]R="!B>2!4
M:')E860B"FUS9W-T<B`BV878L=BJV*@@V+/8I]BRVXP@V+/9A-BSV839A^*`
MC-BGVXS;C"(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R
M<RYI;F,Z,C$*;7-G:60@(E-O<G0@8GD@5&\@061D<F5S<R(*;7-G<W1R("+9
MA=BQV*K8J"#8L]BGV++;C"#8J-BQV*?8L]BGV+,@V*+8K]BQV+,@VJ_;C-BQ
MV8;8K]F'(@H*(SH@=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC.C(S
M"FUS9VED(")3<&%M(&9O;&1E<CHB"FUS9W-T<B`BV;[9B-BTV8?9E"#9A]BQ
MV++9AMBGV879ASHB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN
M8SHS-#8*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R<R(*;7-G<W1R("+9AMF(
MVXS8L]F'XH",V8?8I]N,(-BNV*?8M2(*"B,Z('-E87)C:"YP:'`Z,3,S"FUS
M9VED(")3<&5C:6%L(%9I<G1U86P@1F]L9&5R<R!C86X@;F]T(&)E(&5D:71E
M9"XB"FUS9W-T<B`BV;[9B-BTV8?B@(S9A]BGVXP@V878K-BGV++;C"#8KMBG
MV+4@V8+8I]BHV80@V8C;C-BQV*?;C-BT(-F&VXS8L]BJV8;8KR`B"@HC.B!T
M96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS-#,*;7-G:60@(E-P96QL
M($-H96-K(@IM<V=S='(@(MBHV+'8L=BSVXP@V*?9A=F$V*?;C-N,(@H*(SH@
M=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")3<&5L
M;"!#:&5C:V5R(@IM<V=S='(@(MBNV+?8I]N,V*?8J"#8I]F%V838I]N,VXPB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#@@=&5M<&QA
M=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C4V"FUS9VED(")3<&5L;"!C:&5C
M:R!C;VUP;&5T92(*;7-G<W1R("+8J-BQV+'8L]N,(-BGV879A-BGVXS;C"#:
MJ=BGV879A"#8M-BO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W,0IM
M<V=I9"`B4W!E;&QI;F<@97)R;W)S('!E<B!S8W)E96X@=VAE;B!S<&5L;"!C
M:&5C:VEN9RXB"FUS9W-T<B`BV*[8M]BGV8?8I]N,(-BGV879A-BGVXS;C"#8
MK]BQ(-F'V+$@V+79@=BMV8<@V8?9AMJOV*?9A2#8J-BQV+'8L]N,(-BGV879
MA-BGVXS;C"(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HU,3(@;&EB
M+TU)344O5FEE=V5R+VET:7`N<&AP.C8U,@IM<V=I9"`B4W1A<G0B"FUS9W-T
M<B`BV+38L=F(V+DB"@HC.B!T96UP;&%T97,O<W1A=&EO;F5R>2]P<F5F<RYI
M;F,Z.2!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHS,3$*;7-G:60@
M(E-T871I;VYE<GDB"FUS9W-T<B`BV8;9B-BTV*KB@(S8I]F!V++8I]BQ(@H*
M(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC.C(V"FUS9VED(")3
M=&%T:6]N97)Y(&YA;64Z(@IM<V=S='(@(MF&V*?9A2#9AMF(V+38JN*`C-BG
MV8'8LMBGV+$Z(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE<GDO<')E9G,N:6YC
M.C(X"FUS9VED(")3=&%T:6]N97)Y('1Y<&4Z(@IM<V=S='(@(MF&V8C8N2#9
MAMF(V+38JN*`C-BGV8'8LMBGV+$Z(@H*(SH@=&5M<&QA=&5S+W-T871I;VYE
M<GDO<')E9G,N:6YC.C,S"FUS9VED(")3=&%T:6]N97)Y.B(*;7-G<W1R("+9
MAMF(V+38JN*`C-BGV8'8LMBGV+$Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8X.`IM<V=I9"`B4W1A='5S(@IM<V=S='(@(MF(V+;8N=N,V*KB
M@(PB"@HC.B!L:6(O34E-12]#;VYT96YT<RYP:'`Z,C$U"FUS9VED(")3=')I
M<"!!='1A8VAM96YT(@IM<V=S='(@(MBMV+#9@2#9OMN,V8C8L]BJ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S,@IM<V=I9"`B4W1R:7`@;&EN96)R
M96%K<S\B"FUS9W-T<B`BV*W8L-F!(-BLV*_8I]JIV8;9AMBOV8?9E"#8KMBW
MV8C8MR(*"B,Z('1E;7!L871E<R]M86EL8F]X+VUE<W-A9V5?:&5A9&5R<RYI
M;F,Z,S<*;7-G:60@(E-U8E]J96-T(@IM<V=S='(@(MBYV8;9B-BGV88B"@HC
M.B!M97-S86=E+G!H<#HR-C@@=&AR96%D+G!H<#HQ-3`@=&5M<&QA=&5S+V-O
M;7!O<V4O<F5C;VUP;W-E+FEN8SHR-0HC.B!L:6(O4V5A<F-H+G!H<#HS.`IM
M<V=I9"`B4W5B:F5C="(*;7-G<W1R("+8N=F&V8C8I]F&(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDR,`IM<V=I9"`B4W5B:F5C="!&:65L9"(*;7-G
M<W1R("+9@=N,V838KR#8N=F&V8C8I]F&(@H*(SH@<V5A<F-H+G!H<#HS,3@@
M=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC.C$X"B,Z('1E;7!L
M871E<R]S;6EM92]P87-S<&AR87-E+FEN8SHR,"!T96UP;&%T97,O<&=P+W!A
M<W-P:')A<V4N:6YC.C,Q"FUS9VED(")3=6)M:70B"FUS9W-T<B`BV*?8L=BG
MV*;9AR(*"B,Z('1E;7!L871E<R]F;VQD97)S+V%C=&EO;G,N:6YC.C$Q"FUS
M9VED(")3=6)S8W)I8F4@=&\@1F]L9&5R*',I(@IM<V=S='(@(MBYV+;9B-N,
MV*H@V*_8L2#9OMF(V+39ARC9A]BG*2(*"B,Z(&QI8B]-24U%+U9I97=E<B]P
M:V-S-RYP:'`Z,S@P(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C,X.0HC.B!L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<#HX-PIM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R("+9A=F(V8'9D=F"VXS9D=BJ(@H*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<W!E;&QI;F<N:6YC.C@V"FUS9VED(")3=6=G97-T:6]N<R(*;7-G<W1R
M("+9OMN,V+39AMF'V*?8K]BGV*HB"@HC.B!L:6(O34E-12]6:65W97(O:71I
M<"YP:'`Z-C8R(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HV-C0*;7-G:60@
M(E-U;6UA<GDB"FUS9W-T<B`BV*[9A-BGV+79AR(*"B,Z('1E;7!L871E<R]C
M;VUP;W-E+V-O;7!O<V4N:6YC.C0P,"!T96UP;&%T97,O8V]M<&]S92]C;VUP
M;W-E+FEN8SHT,#,*;7-G:60@(E-W:71C:"!#;VUP;W-I=&EO;B!-971H;V0B
M"FUS9W-T<B`BV*K8N=F(VXS8MB#8M-N,V8C9A]F4(-BGV8;8M-BGV*$B"@HC
M.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHT,#0*;7-G:60@(E-W
M:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(@IM<V=S='(@(MBJV+G9B-N,V+8@
MV*C9AR#9A=BO($A434PB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHT,#0*;7-G:60@(E-W:71C:"!T;R!P;&%I;B!T97AT(&-O;7!O<VET
M:6]N(@IM<V=S='(@(MBJV+G9B-N,V+8@V*C9AR#9A=BO(-BGV8;8M-BGVXP@
MV878JMF&(-BSV*?8K]F'(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YI;F,Z-#$Y"FUS9VED(")495]X="(*;7-G<W1R("+9A=BJV88B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,C8Y"FUS9VED(")496YT871I=F4Z
M("(*;7-G<W1R("+8HMBRV878I]N,V+3;C"(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]I=&EP+G!H<#HU.3$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U
M97-T(@IM<V=S='(@(MBOV+'8KMF(V*?8L]BJ(-BHV+?9B-BQ(-BBV++9A=BG
MVXS8M-N,(-F^V+#;C-BQV8'8JMF'(-BTV*\B"@HC.B!L:6(O34E-12]6:65W
M97(O:71I<"YP:'`Z-S8Q"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*
M;7-G<W1R("+9OMBPVXS8L=F!V*K9AR#8M-BOV8?9E"#8HMBRV878I]N,V+3;
MC"(*"B,@"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE;G0N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1E<FUS(&]F(%-E<G9I8V4@
M9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N<&AP(@IM<V=S='(@(MF%V8C8
MI]BQV*\@V;[8L=F(V8;8K]F'V93B@(P@V+/8L=F(VXS8LR#8K]BQ(&-O;F8N
M<&AP(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JB(*"B,Z('1E;7!L871E<R]S
M=&%T:6]N97)Y+W!R969S+FEN8SHS,`IM<V=I9"`B5&5X="(*;7-G<W1R("+9
MA=BJV88B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.34T"FUS9VED(")4
M:&4@1G)O;3H@8V]L=6UN(&]F('1H92!M97-S86=E('-H;W5L9"!B92!L:6YK
M960Z(@IM<V=S='(@(MBSV*K9B-F&(-F!V+'8L]BJV8;8K]F'V90@V;[;C-BZ
MV*?9A2#8J-BGVXS8KR#9OMN,V8C9AMBO(-BTV8C8KSH@(@H*(SH@;&EB+TE-
M05`O0VQI96YT+G!H<#HU,S(*;7-G:60@(B(*(E1H92!)34%0('-E<G9E<B!D
M;V5S(&YO="!A<'!E87(@=&\@<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@
M;65T:&]D("(*(G-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E
M;2!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O34E-12]6:65W
M97(O87!P;&5D;W5B;&4N<&AP.C0Q"FUS9VED(")4:&4@36%C:6YT;W-H(')E
M<V]U<F-E(&9O<FLB"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P
M<&QE9&]U8FQE+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@36%C
M:6YT;W-H(')E<V]U<F-E(&9O<FL@8V%N(&)E(&1O=VYL;V%D960@)7,N(@IM
M<V=S='(@(B(*"B,@"B,Z(&9E=&-H;6%I;'!R969S+G!H<#HX,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@86-C;W5N="!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`BV*W8L]BGV*@@7"(E<UPB(-BMV+#9@2#8M-BOV8<@
MV*?8L]BJ(@H*(R`*(SH@9F5T8VAM86EL<')E9G,N<&AP.C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!A8V-O=6YT(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`BV*W8L]BGV*@@7"(E<UPB(-BMV8'8N"#8M-BOV8<@V*?8
ML]BJ(@H*(SH@871T86-H;65N="YP:'`Z-#,*;7-G:60@(E1H92!A='1A8VAM
M96YT('=A<R!N;W0@9F]U;F0N(@IM<V=S='(@(MF^VXS9B-BSV*H@V;[;C-BO
MV*<@V8;8M-BO(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C8Y"FUS
M9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(B#8
MK]BGV*_9A]F4(-BJV8+9B-N,V84@V8;8I]F%V+G8JMBHV+$@V*?8L]BJ("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V]M<&]S95]W:6XN:G,Z
M,S<*;7-G:60@(B(*(E1H92!C;VUP;W-E('=I;F1O=R!C86XG="!B92!O<&5N
M960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B"B)B
M;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"B+8M=F!V*W9A]F4(-BJ
MV8C9A-N,V*\@V;[;C-BZV*?9A2#9AMF%VXSB@(S8JMF(V*?9AMBO(-BHV*?8
MLB#8M-F(V*\N(-BTV*?;C-BO(-BTV878IR#9A=BQV8C8L=JOV+$@V*[9B-BQ
M(-BQV*<@V*C8L=BGVXP@V*C8I]BRV8;:J=BQV*_9AB`B"B+9OMF&V*S8L=F'
MXH",V8?8I]N,(-JOV+39B-BOV8;;C"#8JMF&V+C;C-F%(-JIV+'8K]F'XH",
MVXS8K]B?(@H*(SH@;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<#HT
M,@IM<V=I9"`B5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL92!A
M<F4@8F5L;W<N(@IM<V=S='(@(MF%V*W8JMF(VXS8I]BJ(-F^V+'9B-F&V*_9
MA]F4XH",($UA8VEN=&]S:"#8K]BQ(-BPVXS9A"#8HMF%V*_9AR#8I]BSV*HN
M(@H*(R`*(SH@;&EB+TUA:6YT96YA;F-E+U1A<VLO<F5N86UE7W-E;G1M86EL
M7VUO;G1H;'DN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!C=7)R
M96YT(&9O;&1E<BAS*2!<(B5S7"(@=VEL;"!B92!R96YA;65D('1O(%PB)7-<
M(BXB"FUS9W-T<B`BV;[9B-BTV8<HV8?8IRG;C"#8K-BGV+';C"!<(B5S7"(@
MV*C9AR!<(B5S7"(@V*K8NMN,VXS8L2#9AMBGV84@VXS8I]F!V*K9AR#8I]BS
MV*HB"@HC.B!T96UP;&%T97,O86-L+V%C;"YI;F,Z,3`W"FUS9VED("(B"B)4
M:&4@8W5R<F5N="!L:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@
M9F]L9&5R(&-O=6QD(&YO="!B92!R971R:65V960B"FUS9W-T<B`BV8'9A]BQ
MV+/8JB#:J=F&V8C9AMN,(-JIV*?8L=BHV+'8I]F&(-BHV*<@V*?8K-BGV++9
MA]F4(-BOV+/8JMBQV+/;C"#8J-F'(-BGVXS9AB#9OMF(V+39AR#9@MBGV*C9
MA"#8J-BGV++;C-BGV*C;C"#9AMN,V+/8JB(*"B,@"B,Z(&-O;7!O<V4N<&AP
M.C$R,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&1R869T(&AA<R!B965N
M('-A=F5D('1O('1H92!<(B5S7"(@9F]L9&5R+B(*;7-G<W1R("+9OMN,V+0@
MV8;9B-N,V+,@V*_8L2#9OMF(V+39A]F4(%PB)7-<(B#8K=F!V+@@V+38K]F'
M(-BGV+/8JB(*"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ,SD*;7-G
M:60@(E1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS
M9W-T<B`BV+'9B-N,V*_8I]BO(-BHV8<@V*K9@MF(VXS9A2#8M-F%V*<@V*?8
MMMBGV8'9AR#8M-BOV8<@V*C9B-BO(@H*(R`*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O97AP86YD+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEE;&0@7"(E<UPB(&-A;B=T(&)E(&5X<&%N9&5D+B(*;7-G<W1R("+9
M@=N,V838KR`G)7,G(-F"V*?8J-F$(-BHV*?8LB#8M-BOV88@V8;;C-BSV*HB
M"@HC(`HC.B!L:6(O1F]L9&5R+G!H<#HS,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9O;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B
MV;[9B-BTV8?9E"!<(B5S7"(@V*?8LB#9@MBHV80@V879B-BLV8C8KR#8I]BS
MV*HB"@HC(`HC.B!L:6(O1F]L9&5R+G!H<#HQ-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE(&9O;&1E<B!<(B5S7"(@8V]N=&%I;G,@:6QL96=A;"!C
M:&%R86-T97)S(&EN(&ET<R!N86UE+B!)="!M87D@8V%U<V4@(@HB<')O8FQE
M;7,N(%!L96%S92!S964@>6]U<B!S>7-T96T@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HBV8;8I]F%(-F^V8C8M-F'V90@7"(E<UPB(-BTV*?9A=F$(-F&
MV8C;C-BSV8?B@(S9A]BGVXP@V+K;C-BQ(-F%V*S8I]BR(-F%VXSB@(S8J-BG
MV+38KR#:J=F'(-BGVXS9AB#9A=BSV*;9A-F'(-F%VXSB@(S8JMF(V*?9AMBO
M(-F%V+3:J=F$V*?8JMN,("(*(MBQV*<@V*?;C-BLV*?8KR#:J=F&V*\N(-F$
MV+?9@=BGV8L@V*C8IR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'V90@V*[9
MB-BO(-BJV878I]BS(-BHVJ_;C-BQVXS8KR(*"B,@"B,Z(&QI8B]&;VQD97(N
M<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<
M(B!W87,@8W)E871E9"!B=70@>6]U('=E<F4@;F]T('-U8G-C<FEB960@=&\@
M:70N(@IM<V=S='(@(MF^V8C8M-F'V90@7"(E<UPB(-BGVXS8K-BGV*\@V+38
MK]F'(-BGV+/8JB#8I]F%V*<@V+39A=BG(-BOV+$@V*+9AB#8N=BVV8@@V8;9
MA=N,XH",V*C8I]BTVXS8KR`B"@HC.B!L:6(O1F]L9&5R+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&1E;&5T
M960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!I="XB"FUS
M9W-T<B`BV;[9B-BTV8?9E"!<(B5S7"(@V*W8L-F!(-BTV*_9AR#8I]BSV*H@
MV*?9A=BG(-BTV878IR#8N=BVV8C;C-BJ(-BNV8C8KR#8L=BG(-BOV+$@V*+9
MAB#9A-BZV8@@V8;:J=BQV*_9A^*`C-N,V*\@(@H*(R`*(SH@;&EB+T9O;&1E
M<BYP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F;VQD97(@7"(E
M<UPB('=A<R!N;W0@8W)E871E9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9"(*;7-G<W1R("+9OMF(V+39A]F4(%PB)7-<(B#8I]N,V*S8I]BO(-F&
MV+38K]F'(-BHV8C8KRX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JI
MV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*HB"@HC(`HC.B!L:6(O1F]L9&5R
M+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S
M7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(MF^V8C8M-F'V90@)R5S)R#8K=BPV8$@V8;8M-BOV8<@
MV*C9B-BO+B#8I]N,V88@VH;;C-BRVXP@V*?8L]BJ(-JIV8<@VJG8I]BQV+/8
MI]BR(-JOV8'8JMF'(-BGV+/8JB(*"B,Z(&QI8B]&;VQD97(N<&AP.C,U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9F]L9&5R(%PB)7-<(B!W87,@<W5C
M8V5S<V9U;&QY(&-R96%T960N(@IM<V=S='(@(MF^V8C8M-F'V90@7"(E<UPB
M(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]N,V*S8I]BO(-BTV*\B"@HC.B!L
M:6(O1F]L9&5R+G!H<#HR-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9O
M;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!D96QE=&5D+B(*;7-G<W1R
M("+9OMF(V+39A]F4(%PB)7-<(B#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W8
ML-F!(-BTV*\B"@HC(`HC.B!L:6(O1F]L9&5R+G!H<#HT-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9O;&1E<B!<(B5S7"(@=V%S('-U8V-E<W-F=6QL
M>2!R96YA;65D('1O(%PB)7-<(BXB"FUS9W-T<B`BV;[9B-BTV8?9E"!<(B5S
M7"(@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@7"(E<UPB(-BJV+K;C-N,
MV+$@V8;8I]F%(-N,V*?9@=BJV8<@V*?8L]BJ(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W1N968N<&AP.CDR"FUS9VED(")4:&4@9F]L;&]W:6YG(&9I;&5S('=E
M<F4@871T86-H960@=&\@=&AI<R!P87)T.B(*;7-G<W1R("+9OMBQV8C9AMBO
MV8?B@(SB@(S9A]BGVXP@V++;C-BQ(-BHV8<@V*?;C-F&(-F"V+/9A=BJ(-F^
MVXS9B-BSV*H@V+38K]F'XH",(-BGV+/8JCHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7W-A=F5I;6%G95]W:6XN:G,Z,3(*;7-G:60@(B(*(E1H
M92!I;6%G92!S879E('=I;F1O=R!C86X@;F]T(&)E(&]P96YE9"X@4&5R:&%P
M<R!Y;W4@:&%V92!S970@>6]U<B!B<F]W<V5R("(*(G1O(&)L;V-K('!O<'5P
M('=I;F1O=W,_(@IM<V=S='(@(B(*(MF^V8;8K-BQV8?9E"#8K=F!V+@@V*K8
MM=F(VXS8L2#9AMF%VXSB@(S8JMF(V*?9AMBO(-BHV*?8LB#8M-F(V*\N(-BT
MV*?;C-BO(-BTV878IR#9A=BQV8C8L=JOV+$@V*[9B-BQ(-BQV*<@V*C8L=BG
MVXP@V*C8I]BRV8;:J=BQV*_9AB`B"B+9OMF&V*S8L=F'XH",V8?8I]N,(-JO
MV+39B-BOV8;;C"#8JMF&V+C;C-F%(-JIV+'8K]F'XH",VXS8K]B?(@H*(SH@
M;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDW"FUS9VED("(B"B)4:&4@:6UA
M9V5S('=I;&P@8F4@9&ES<&QA>65D(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P
M<F5S96YT(&EN('EO=7(@(@HB861D<F5S<V)O;VLN(@IM<V=S='(@(MBJV+79
MB-N,V+'9A]BG(-F&V878I]N,V+0@V*_8I]BOV8<@V87;C.*`C-BTV8C9AMBO
M(-J&V8C9AB#9@=BQV+/8JMF&V*_9AR#8K]BQ(-JIV*K8I]BHVH;9A]F4(-BB
MV*_8LR#8M-F%V*<@V8C8K-F(V*\@V*_8I]BQV*\B"@HC.B!L:6(O34E-12]6
M:65W97(O<W1A='5S+G!H<#HW-0IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E
M;F5R871E9"!T:&4@9F]L;&]W:6YG(&5R<F]R(&UE<W-A9V4Z(@IM<V=S='(@
M(MJIV*?8L=BSV*?8LB#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,
M(-F^VXS8NMBGV879A]BGVXP@V*[8M]BGVXP@V++;C-BQ(-BQV*<@V*K9B-F$
MVXS8KR#:J=BQV*\Z(@H*(SH@;&EB+TU)344O5FEE=V5R+VYO=&EF:6-A=&EO
M;BYP:'`Z-3$*;7-G:60@(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;F%L(&UE<W-A9V4Z(@IM<V=S='(@(MJI
MV*?8L=BSV*?8LB#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,(-F^
MVXS8NMBGV879A]BGVXP@V*?8M]F$V*?8N=BGV*K;C"#8LMN,V+$@V+'8IR#8
MJMF(V83;C-BO(-JIV+'8KSHB"@HC.B!L:6(O34E-12]6:65W97(O<W1A='5S
M+G!H<#HY,`IM<V=I9"`B5&AE(&UA:6P@<V5R=F5R(&=E;F5R871E9"!T:&4@
M9F]L;&]W:6YG(&UE<W-A9V4Z(@IM<V=S='(@(MJIV*?8L=BSV*?8LB#9AMBG
MV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,(-F^VXS8NMBGV879A]BGVXP@
MV++;C-BQ(-BQV*<@V*K9B-F$VXS8KR#:J=BQV*\Z(@H*(R`*(SH@;&EB+TUE
M<W-A9V4N<&AP.C8U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@;6%I;&)O
M>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R("+9AMBGV879A^*`C-BO
MV*?9AB`E<R#9@MBHV838I]F+(-BNV*?9A-N,(-BHV8C8K]F'(-BGV+/8JB(*
M"B,@"B,Z(&QI8B]&971C:&UA:6PN<&AP.C(T-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@;65S<V%G92!<(B5S7"(@9G)O;2!<(B5S7"(@*"5D(&)Y=&5S
M*2!E>&-E961S(&9E=&-H('-I>F4@;&EM:70N(@IM<V=S='(@(MF^VXS8NMBG
MV84@7"(E<UPB(-BGV+(@7"(E<UPB("@E9"#8J-BGVXS8JBD@V*K8K-BGV8C8
MLB#8I]BR(-BMV*_8I]JIV*O8L2#8I]F&V*_8I]BRV8<@V8C8I]JIV+3;C"(*
M"B,Z('1E;7!L871E<R]C;VYT86-T<R]C;VYT86-T<RYI;F,Z,3`S"FUS9VED
M(")4:&4@;65S<V%G92!B96EN9R!C;VUP;W-E9"!H87,@8F5E;B!C;&]S960N
M($5X:71I;F<N(@IM<V=S='(@(MF^VXS8NMBGV84@V*?;C-BLV*?8KR#8M-BO
MV8<@V*C8L]BJV8<@V+38K]F'(-BGV+/8JCH@V*[8L=F(V*PB"@HC.B!M97-S
M86=E+G!H<#HQ-#@*;7-G:60@(E1H92!M97-S86=E(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(MF^VXS8NMBGV84@V*W8L-F!(-BTV*_9AR#8I]BSV*HB
M"@HC.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS.3,*;7-G:60@(E1H92!M
M97-S86=E(&AA<R!B965N('9E<FEF:65D+B(*;7-G<W1R("+9OMN,V+K8I]F%
M(-BHV*?8LMBHVXS9AMN,(-BTV*_9AR#8I]BSV*HB"@HC.B!L:6(O34E-12]6
M:65W97(O<&MC<S<N<&AP.C,X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"X@4V5N9&5R.B`E<RXB"FUS9W-T
M<B`BV;[;C-BZV*?9A2#8J-BGV++8J-N,V8;;C"#8M-BOV8<@V*?8L]BJ+B#9
M@=BQV+/8JMF&V*_9ASH@)7,B"@HC.B!T96UP;&%T97,O<VUI;64O;W!E;E]S
M;6EM95]W:6XN:G,Z,3`@=&5M<&QA=&5S+W!G<"]O<&5N7W!G<%]W:6XN:G,Z
M,3`*;7-G:60@(B(*(E1H92!P87-S<&AR87-E('=I;F1O=R!C86XG="!B92!O
M<&5N960N(%!E<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R`B
M"B)B;&]C:R!P;W!U<"!W:6YD;W=S/R(*;7-G<W1R("(B"B+9OMF&V*S8L=F'
MV90@V+G8J-BGV+'8JB#:K]BPV+$@V8+8I]BOV+$@V*C9AR#8J-BGV+(@V+38
MK]F&(-F&VXS8L]BJ+B#8M-BGVXS8KR#8M-F%V*<@V878L=F(V+':K]BQ(-BN
MV8C8KR#8L=BG(-BGVXS9AMJOV8C9AMF'(-BJV8;8N-N,V84@(@HBVJG8L=BO
MV8?B@(S8I^*`C-N,V*_8GR(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP
M.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<F%W('1E>'0@;V8@=&AE
M(%!'4"!0=6)L:6,@2V5Y(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(MF%
MV*K9AB#8KMBGV84@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@V87;C.*`C-BJ
MV8C8I]F&V*\@V878M-BGV8?8K]F'(-BTV8C8KR`E<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]T;F5F+G!H<#HV,`IM<V=I9"`B5&AE(')E<75E<W1E9"!F:6QE
M(&1O97,@;F]T(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(@IM
M<V=S='(@(MF^V+'9B-F&V*_9A]F4XH",(-BOV+'8KMF(V*?8L]BJVXP@V*_8
ML2#9OMN,V8C8L]BJ($U3+51.148@V8C8K-F(V*\@V8;8K]BGV+'8KR(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"FUS9VED(")4:&4@<F5Q=65S
M=&5D(&9I;&4@9&]E<R!N;W0@97AI<W0@:6X@=&AE(%II<"!A='1A8VAM96YT
M+B(*;7-G<W1R("+9OMBQV8C9AMBOV8?9E.*`C"#8K]BQ(-BNV8C8I]BSV*K;
MC"#8K]BQ(-F^VXS9B-BSV*H@6FEP(-F(V*S9B-BO(-F&V*_8I]BQV*\B"@HC
M.B!M97-S86=E+G!H<#HU-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('-E;F1E<B!O9B!T:&ES(&UE<W-A9V4@:7,@<F5Q=65S=&EN9R!A($UE<W-A
M9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N("(*(F9R;VT@>6]U('=H96X@
M>6]U(&AA=F4@<F5A9"!T:&ES(&UE<W-A9V4N(%!L96%S92!C;&EC:R`E<R!T
M;R!S96YD('1H92`B"B)N;W1I9FEC871I;VX@;65S<V%G92XB"FUS9W-T<B`B
M(@HBV8'8L=BSV*K9AMBOV8<@V*?;C-F&(-F^VXS8NMBGV84@V*K9@MBGV+;8
MIR#8K]BGV+'8KR#:J=F'(-N,VJD@V*K8H]BFVXS8K]N,V8<@V*C8L=BGVXP@
MV*[9B-BGV8;8K]F&(-F^VXS8NMBGV84@V*_8L=N,V*?9@=BJ(-JIV8;8KR#9
MA-BWV8'8I]F+("(*(MF'V8;:K]BGV87;C"#:J=F'(-BGVXS9AB#9OMN,V+K8
MI]F%(-BQV*<@V*[9B-BGV8;8K]N,V*\@V*C8L2#8L=F(VXP@)7,@VJG9A-N,
MVJD@VJG9AMN,V*\@V*K8IR#8I]N,V88@V*K8H]BFVXS8K]N,V8<@V*?8L=BS
MV*?9A"#8M-F(V*\B"@HC(`HC.B!L:6(O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HV.0IM<V=I9"`B5&AE('-E<G9E<B!W87,@;F]T(&%B;&4@=&\@8W)E871E
M(&$@=&AU;6)N86EL(&]F('1H:7,@:6UA9V4N(@IM<V=S='(@(B#:J=BGV+'8
ML]BGV+(@V8;9A=N,XH",V*K9B-BGV8;8KR#8JMBUV8C;C-BQ(-JIV8C:AMJI
MVXP@V*?8LB#8I]N,V88@V*K8M=F(VXS8L2#8L=BG(-BGVXS8K-BGV*\@VJG9
MAMBO(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YJ<SHQ,#0*;7-G
M:60@(E1H92!S:6=N871U<F4@8V]U;&0@;F]T(&)E(')E<&QA8V5D+B(*;7-G
M<W1R("+8I]F%V+;8I]BA(-BQV*<@V8;9A=N,XH",V*K9B-BGV88@V*S8I]N,
MVJ_8LMN,V88@VJG8L=BO(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S
M92YJ<SHQ,#(*;7-G:60@(E1H92!S:6=N871U<F4@=V%S('-U8V-E<W-F=6QL
M>2!R97!L86-E9"XB"FUS9W-T<B`BV*?9A=BVV*?8H2#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*S8I]N,VJ_8LMN,V88@V+38KR(*"B,Z(&%T=&%C:&UE;G0N
M<&AP.C4Y"FUS9VED(")4:&4@<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(MF^V+'9B-F&V*_9A]F4XH",(-F%V+38KMBU(-BTV*_9
MAR#9B-BLV8C8KR#9AMBOV*?8L=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@<W1A=&EO;F5R>2YP
M:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E
M<UPB(&AA<R!B965N(&%D9&5D+B(*;7-G<W1R("+9AMF(V+38JN*`C-BGV8'8
MLMBGV+$@7"(E<UPB(-BGV+;8I]F!V8<@V+38K]F'(-BGV+/8JB(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z('-T871I;VYE<GDN<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("+9AMF(V+38JN*`C-BGV8'8LMBGV+$@7"(E<UPB(-BMV+#9@2#8M-BOV8<@
MV*?8L]BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@<W1A=&EO;F5R>2YP:'`Z.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N('5P
M9&%T960N(@IM<V=S='(@(MF&V8C8M-BJXH",V*?9@=BRV*?8L2!<(B5S7"(@
MV*C8L=F(V++8L=BSV*?9AMN,(-BTV*_9AR#8I]BSV*HB"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,38Y"FUS9VED(")4:&4@=&%S:R!H87,@8F5E
M;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R("+9B-BXVXS9@=F'
MV90@V879B-BQV*\@V8;8N-BQ(-BHV8<@V8'9A]BQV+/8JB#9B-BXV*?;C-F!
M(-BTV878IR#8I]BVV*?9@=F'(-BTV*_9AR#8I]BSV*HB"@HC.B!L:6(O34E-
M12]6:65W97(O<W1A='5S+G!H<#HY-0IM<V=I9"`B5&AE('1E>'0@;V8@=&AE
M(&UE<W-A9V4B"FUS9W-T<B`BV878JMF&(-F^VXS8NMBGV84B"@HC.B!L:6(O
M34E-12]6:65W97(O<W1A='5S+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5X="!O9B!T:&4@;65S<V%G92!C86X@8F4@=FEE=V5D("5S+B(*
M;7-G<W1R("+9A=BJV88@V;[;C-BZV*?9A2#9@MBGV*C9A"#9A=BTV*?9A]BO
MV8<@V*?8L]BJ("5S(@H*(SH@;&EB+TU)344O5FEE=V5R+W-T871U<RYP:'`Z
M.#`*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E(@IM
M<V=S='(@(MF%V*K9AB#9OMN,V+K8I]F%(-BHV+':K]BQV8;8K]BGV8;8K]F'
M(-BTV*_9AR(*"B,Z(&QI8B]-24U%+U9I97=E<B]S=&%T=7,N<&AP.C<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M
M97-S86=E(&-A;B!B92!V:65W960@)7,N(@IM<V=S='(@(B#9A=BJV88@V;[;
MC-BZV*?9A2#8J-BQVJ_8L=F&V*_8I]F&V*_9AR#8M-BOV8<@V87;C.*`C-BJ
MV8C8I]F&V*\@V878M-BGV8?8K]F'(-BTV8C8KR`E<R(*"B,Z(&QI8B]-24U%
M+U9I97=E<B]N;W1I9FEC871I;VXN<&AP.C8X"FUS9VED(")4:&4@=&5X="!O
M9B!T:&4@<V5N="!M97-S86=E(@IM<V=S='(@(MF%V*K9AB#9OMN,V+K8I]F%
M(-F!V+'8L]BJV*?8K]F'(-BTV*_9AR(*"B,Z(&QI8B]-24U%+U9I97=E<B]N
M;W1I9FEC871I;VXN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M97AT(&]F('1H92!S96YT(&UE<W-A9V4@8V%N(&)E('9I97=E9"`E<RXB"FUS
M9W-T<B`BV878JMF&(-F^VXS8NMBGV84@V8'8L=BSV*K8I]BOV8<@V+38K]F'
M(-F%VXSB@(S8JMF(V*?9AMBO(-F%V+38I]F'V*_9AR#8M-F(V*\@)7,B"@HC
M.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,34T"FUS9VED(")4:&4@=7-E
M<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O
M<F5D+B(*;7-G<W1R("+8I]BWV838I]BYV*?8JB#8HMBRV*?8KR_9A=BTV+K9
MB-F$(-JIV*?8L=BHV+'8I]F&(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8L-BN
MVXS8L=F'(-BTV*\B"@HC.B!L:6(O34E-12]6:65W97(O86QT97)N871I=F4N
M<&AP.C@V"FUS9VED(")4:&5R92!A<F4@;F\@86QT97)N871I=F4@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`BV*C8KMBT
M(-BLV*?;C-JOV++;C-F&VXP@VJG9AR#8J-BJV8C8I]F&V*\@V*_8L=BNV+<@
MV8;9A=BGVXS8M"#8K]BGV*_9AR#8M-F(V*\@V879B-BLV8C8KR#9AMN,V+/8
MJB(*"B,Z('1E;7!L871E<R]M86EL8F]X+V5M<'1Y7VUA:6QB;W@N:6YC.C,*
M;7-G:60@(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA:6QB;W@N
M(@IM<V=S='(@(MF^VXS8NMBGV87;C"#8K]BQ(-BGVXS9AB#9AMBGV879A^*`
MC-BOV*?9AB#9AMN,V+/8JB(*"B,Z('1H<F5A9"YP:'`Z,3`Y"B,L(&9U>GIY
M"FUS9VED(")4:&5R92!I<R!N;R!T97AT('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(MBHV*[8M"#8K-BGVXS:K]BRVXS9AMN,(-JI
MV8<@V*C8JMF(V*?9AMBO(-BOV+'8KMBW(-F&V878I]N,V+0@V*_8I]BOV8<@
MV+39B-BO(-F%V8C8K-F(V*\@V8;;C-BSV*HB"@HC(`HC.B!L:6(O365S<V%G
M92YP:'`Z-C$R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@97AP=6YG:6YG("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8L2#9OMBGVJD@VJG8L=BOV88@
M)7,@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-BGVXS9AB#:AMN,V++;C"#8I]BS
MV*H@VJG9AR#:J=BGV+'8L]BGV+(@VJ_9@=BJV8<@V*?8L]BJ.B`B"@HC(`HC
M.B!L:6(O365S<V%G92YP:'`Z-C4S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@97AP=6YG:6YG('1H92!M86EL8F]X+B!4:&4@
M<V5R=F5R('-A:60Z("5S(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8L2#9OMBG
MVJD@VJG8L=BOV88@V8;8I]F%V8?B@(S8K]BGV88@V+'8KB#8K]BGV*_9AR#8
MI]BSV*HN(-JIV*?8L=BSV*?8LB#:K]F!V*HZ("5S(@H*(R`*(SH@;&EB+TUE
M<W-A9V4N<&AP.C8R,0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!E>'!U
M;F=I;F<@=&AE(&UA:6QB;W@N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60B"FUS9W-T<B`B(@HBV*[8M]BGVXS;C"#8K]BQ(-F^V*?:J2#:J=BQV*_9
MAB#9AMBGV879A^*`C-BOV*?9AB#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V*?;
MC-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JIV*?8L=BSV*?8LB#:K]F!V*K9
MAR#8I]BSV*HZ("5S(@H*(R`*(SH@;&EB+TUE<W-A9V4N<&AP.CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!C;W!Y:6YG
M(&UE<W-A9V5S(&9R;VT@7"(E<UPB('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T
M('1H92`B"B)S97)V97(@<V%I9"(*;7-G<W1R("(B"B+8KMBWV*?;C-N,(-BO
MV+$@V*K9A]N,V8?9E"#8L=F(V8;9B-BTV*H@V;[;C-BZV*?9A2#8I]BR(%PB
M)7-<(B#8J-F'(%PB)7-<(B#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V*?;C-F&
M(-J&VXS8LMN,(-BGV+/8JB#:J=F'("(*(MJIV*?8L=BSV*?8LB#:K]F!V*K9
MAR#8I]BSV*HB"@HC(`HC.B!L:6(O365S<V%G92YP:'`Z,3DX(&QI8B]-97-S
M86=E+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B!<
M(B5S7"(N(%1H:7,@:7,@=VAA="`B"B)T:&4@<V5R=F5R('-A:60B"FUS9W-T
M<B`B(@HBV*[8M]BGVXS;C"#8K]BQ(-BMV+#9@2#9OMN,V+K8I]F%V8?8IR#8
MI]BR(-F^V8C8M-F'V90@7"(E<UPB(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#8
MI]N,V88@VH;;C-BRVXP@V*?8L]BJ(-JIV8<@VJG8I]BQV+/8I]BR(-JOV8'8
MJMF'("(*(MBGV+/8JB(*"B,@"B,Z(&QI8B]-97-S86=E+G!H<#HR-S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T
M:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(MBNV+?8I]N,VXP@
MV*_8L2#8K=BPV8$@V;[;C-BZV*?9A=F'V*<@V*_8L2#9OMF(V+39A]F4(%PB
M)7-<(B#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V*?;C-F&(-J&VXS8LMN,(-BG
MV+/8JB#:J=F'(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR`B"B+8I]BSV*HB"@HC
M(`HC.B!L:6(O365S<V%G92YP:'`Z,C$Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M97-S86=E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B"FUS9W-T<B`BV*[8M]BGVXS;
MC"#8K]BQ(-BMV+#9@2#9OMN,V+K8I]F%V8?8IR#8L=BN(-BOV*?8K]F'(-BG
MV+/8JBX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JIV*?8L=BSV*?8
MLB#:K]F!V*K9AR#8I]BSV*HZ("5S(@H*(R`*(SH@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D96QE=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R("+8KMBW
MV*?;C-N,(-BOV+$@V*W8L-F!(-BQV8C;C-BOV*?8KR#8L=BN(-BOV*?8K]F'
M(-BGV+/8JCH@)7,B"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4R
M(&QI8B]-24U%+U9I97=E<B]E;G)I8VAE9"YP:'`Z,S<*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM
M<V=S='(@(MBNV+?8I]N,VXP@V*_8L2#9AMF%V*?;C-BT(-BGVXS9AB#8J-BN
MV+0@V;[;C-BZV*?9A2#8L=BN(-BOV*?8K]F'(-BGV+/8JB(*"B,@"B,Z(&QI
M8B]-97-S86=E+G!H<#HU-#4@;&EB+TUE<W-A9V4N<&AP.C4X-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@9FQA9V=I;F<@
M;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@:7,@=VAA="!T
M:&4@(@HB<V5R=F5R('-A:60B"FUS9W-T<B`B(@HBV*[8M]BGVXS;C"#8K]BQ
M(-F^V+':AMF%XH",VJ_8L-BGV+';C"#9OMN,V+K8I]F%V8?8IR#8K]BQ(-F^
MV8C8M-F'V90@7"(E<UPB(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#8I]N,V88@
MVH;;C-BRVXP@V*?8L]BJ(-JIV8<@(@HBVJG8I]BQV+/8I]BR(-JOV8'8JMF'
M(-BGV+/8JB(*"B,@"B,Z(&9O;&1E<G,N<&AP.C$V-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG("5S+B(*;7-G
M<W1R("+8KMBWV*?;C-N,(-BOV+$@V*_8L=F(V8;B@(S8J-BQV*\@VJG8L=BO
MV88@)7,@V+'8KB#8K]BGV*_9AR#8I]BSV*HB"@HC(`HC.B!L:6(O34E-12]6
M:65W97(O:71I<"YP:'`Z,3,V"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T
M<B`BV*[8M]BGVXS;C"#8K]BQ(-BOV+'9B-F&XH",V*C8L=BO(-JIV+'8K]F&
M(-BQV8C;C-BOV*?8KR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,B"@HC.B!L
M:6(O34E-12]6:65W97(O:71I<"YP:'`Z,38V"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S
M+B(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@V*_8L=F(V8;B@(S8J-BQV*\@
MVJG8L=BOV88@VJG8I]BQ(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<R(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`BV*[8M]BGVXS;C"#8
MK]BQ(-BOV+'9B-F&XH",V*C8L=BO(-JIV+'8K]F&(-BGV+?9A-BGV+G8I]BJ
M(-BBV++8I]BO+]F%V+38NMF(V80@VJG8I]BQV*C8L=BGV88@V+'8KB#8K]BG
MV*_9AR#8I]BSV*HZ("5S(@H*(R`*(SH@;&EB+TUE<W-A9V4N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!M;W9I
M;F<@;65S<V%G97,@9G)O;2!<(B5S7"(@=&\@7"(E<UPB+B!4:&ES(&ES('=H
M870@=&AE("(*(G-E<G9E<B!S86ED(@IM<V=S='(@(B(*(MBNV+?8I]N,VXP@
MV*_8L2#8I]F&V*K9@MBGV80@V;[;C-BZV*?9A=F'V*<@V*?8LB!<(B5S7"(@
MV*C9AR!<(B5S7"(@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-BGVXS9AB#:AMN,
MV++;C"#8I]BSV*H@VJG9AR`B"B+:J=BGV+'8L]BGV+(@VJ_9@=BJV8<@V*?8
ML]BJ(@H*(SH@8V]M<&]S92YP:'`Z,3(T-`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R('-A=FEN9R!T:&ES(&UE<W-A9V4@87,@82!D<F%F="XB"FUS9W-T
M<B`BV*[8M]BGVXS;C"#8K]BQ(-BMV8'8N"#9OMN,V+K8I]F%(-BHV+G9AMF(
MV*?9AB#;C-JI(-F^VXS8M"#9AMF(VXS8LR#8L=F(VXP@V*_8I]BOV8<@V*?8
ML]BJ(@H*(R`*(SH@8V]M<&]S92YP:'`Z,3`P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z
M("5S(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8L2#9@=BQV+/8JMBGV*_9AB#9
MOMN,V+K8I]F%(-BTV878IR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,B"@HC
M(`HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z,3$S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@979E
M;G0Z("5S+B(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@V*C8L=F(V++8L=BS
MV*?9AMN,(-BQV8C;C-BOV*?8KR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,B
M"@HC.B!L:6(O34E-12]6:65W97(O<&QA:6XN<&AP.C4Y"FUS9VED(")4:&5R
M92!W87,@;F\@=&5X="!I;B!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("+9
MA=BJV8;;C"#8K]BQ(-BGVXS9AB#8J-BNV+0@V;[;C-BZV*?9A2#9AMN,V+/8
MJB(*"B,Z(&QI8B]-24U%+U9I97=E<B]H=&UL+G!H<#HY-PIM<V=I9"`B5&AI
M<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I="XB"FUS
M9W-T<B`BV*?;C-F&(-F^VXS8NMBGV84@2%1-3"#8M-BGV879A"#8JMBUV*?9
MB-N,V+$@V*?8L]BJ(@H*(SH@;&EB+TU)344O5FEE=V5R+VAT;6PN<&AP.CDP
M"FUS9VED("(B"B)4:&ES($A434P@;65S<V%G92!H87,@:6UA9V5S(&5M8F5D
M9&5D(&EN(&ET+B!";&]C:V5D(&EM86=E<R!A<'!E87(@;&EK92`B"B)T:&ES
M.B`B"FUS9W-T<B`BV*?;C-F&(-F^VXS8NMBGV84@2%1-3"#8M-BGV879A"#8
MJMBUV*?9B-N,V+$@V*?8L]BJ+B#8J-F$V8C:J2#8JMBUV*?9B-N,V+$@V+38
MJ-N,V8<@V*C9AR#8I]N,V88@V+C8I]F'V+$@V87;C.*`C-BTV8C8KSHB"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HQ-C8*;7-G:60@(E1H:7,@4$=0
M(%!U8FQI8R!+97D@=V%S(&%T=&%C:&5D('1O('1H92!M97-S86=E+B(*;7-G
M<W1R("+8I]N,V88@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@V*C9AR#9OMN,
MV+K8I]F%(-F^VXS9B-BSV*H@(-BTV*_9AR#8J-F(V*\B"@HC.B!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,3`T(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H
M<#HQ,3@*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C$T,R!L:6(O34E-
M12]6:65W97(O:71I<"YP:'`Z,34W"B,Z(&QI8B]-24U%+U9I97=E<B]I=&EP
M+G!H<#HQ-S,@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C,Q-`IM<V=I9"`B
M5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BV*?;C-F&
M(-BYV879A"#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-BTV8C8KR(*"B,Z
M(&QI8B]-24U%+U9I97=E<B]I=&EP+G!H<#HQ-SD@;&EB+TU)344O5FEE=V5R
M+VET:7`N<&AP.C0Q.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I
M;7!L96UE;G1E9"XB"FUS9W-T<B`BV*?;C-F&(-BYV879A"#9A]F&V8C8LB#9
MOMN,V*?8K]F'XH",V+/8I]BRVXP@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ-`IM<V=I9"`B5&AI<R!M
M87D@=&%K92!S;VUE('1I;64N($%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!C
M;VYT:6YU93\B"FUS9W-T<B`BV*?;C-F&(-BYV879A"#:J=F%VXP@V++9A=BG
MV88@V87;C.*`C-BHV+'8KRX@V*+;C-BG(-F%V+?9A=BFV8;;C-BO(-JIV8<@
MV87;C.*`C-BNV8C8I]F'VXS8KR#8I]BOV*?9A=F'(-BOV8?;C-BOV)\B"@HC
M.B!L:6(O34E-12]6:65W97(O87!P;&5D;W5B;&4N<&AP.C0P"FUS9VED(")4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@82!-86-I;G1O<V@@9FEL92XB"FUS9W-T
M<B`BV*?;C-F&(-F^VXS8NMBGV84@V+38I]F%V80@VXS:J2#9OMBQV8C9AMBO
MV8?9E.*`C"!-86-I;G1O<V@@V*?8L]BJ(@H*(SH@;&EB+TU)344O5FEE=V5R
M+W!K8W,W+G!H<#HT,3`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN
M<R!A;B!A='1A8VAM96YT('1H870@:&%S(&)E96X@9&EG:71A;&QY('-I9VYE
M9"!V:6$@4R\B"B)-24U%+B(*;7-G<W1R("(B"B+8I]N,V88@V;[;C-BZV*?9
MA2#8M-BGV879A"#;C-JI(-F^VXS9B-BSV*H@V*?8L]BJ(-JIV8<@V*?8LB#8
MM]BQVXS9@B!3+TU)344@V*C8M]F(V+$@V*_;C-BLVXS8JMBGV83;C"#8I]F%
MV+;8I]BA(-BTV*_9AR#8I]BSV*HB"@HC.B!L:6(O34E-12]6:65W97(O<&MC
M<S<N<&AP.C0Q-`IM<V=I9"`B5&AI<R!M97-S86=E(&-O;G1A:6YS(&%N(&%T
M=&%C:&UE;G0@=&AA="!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB
M"FUS9W-T<B`BV*?;C-F&(-F^VXS8NMBGV84@V*W8I]F(VXP@VXS:J2#9OMN,
MV8C8L]BJ(-BGV+/8JB#:J=F'(-BGV+(@V+?8L=N,V8(@4R]-24U%(-BQV878
MLMBHV8;8K]N,(-BTV*_9AR#8I]BSV*HB"@HC.B!L:6(O34E-12]6:65W97(O
M<W1A='5S+G!H<#HQ-C`*;7-G:60@(B(*(E1H:7,@;65S<V%G92!C;VYT86EN
M<R!M86EL(&1E;&EV97)Y('-T871U<R!I;F9O<FUA=&EO;BP@8G5T('1H92!F
M;W)M870@;V8@(@HB=&AI<R!M97-S86=E(&ES('5N:VYO=VXN(@IM<V=S='(@
M(MBGVXS9AB#9OMN,V+K8I]F%(-BMV*?9B-N,(-BGV+?9A-BGV+G8I]BJ(-F(
MV+;8N=N,V*H@V*K8K=F(VXS9A"#9A=N,XH",V*C8I]BTV*\@V*?9A=BG(-F"
MV*?9A-BH(-F^VXS8NMBGV84@V8;8I]BTV8;8I]BNV*K9AR#8I]BSV*HB"@HC
M.B!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS,34*;7-G:60@(B(*(E1H:7,@
M;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!01U`@96YC
M<GEP=&5D(&UE<W-A9V4N($5R<F]R.B`B"FUS9W-T<B`BV*?;C-F&(-F^VXS8
MNMBGV84@V*C9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@VXS:J2#9OMN,
MV+K8I]F%(-F%V+G8JMBHV+$@V+'9A=BRV*C9AMBOVXP@V+38K]F'V90@4$=0
M(-BHV*?8M-BO+B#8KMBWV*<Z("(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N
M<&AP.C(T,"!L:6(O34E-12]6:65W97(O<&=P+G!H<#HS-3`*;7-G:60@(B(*
M(E1H:7,@;65S<V%G92!D;V5S(&YO="!A<'!E87(@=&\@8F4@:6X@=&AE(&-O
M<G)E8W0@4$=0(&9O<FUA="`H86-C;W)D:6YG('1O("(*(E)&0R`R,#$U*2XB
M"FUS9W-T<B`BV*C9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V*?;C-F&
M(-F^VXS8NMBGV84@V*_8L2#9@MBGV838J"#8M=BMVXS8K2!01U`@V*C8I]BT
MV*\@*"#8J-BGV*K9B-BLV8<@V*C9AU)&0R`R,#$U*2`B"@HC.B!L:6(O34E-
M12]6:65W97(O<&MC<S<N<&AP.C$W,`IM<V=I9"`B5&AI<R!M97-S86=E(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!3+TU)344@9F]R
M;6%T+B(*;7-G<W1R("+8J-F&V+C8L2#9AMF%VXSB@(S8L=BSV*\@VJG9AR#8
MI]N,V88@V;[;C-BZV*?9A2#8K]BQ(-F"V*?9A-BH(-BUV*W;C-BM(%,O34E-
M12#8J-BGV+38KR(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P-2!L
M:6(O34E-12]6:65W97(O<&=P+G!H<#HT,38*;7-G:60@(E1H:7,@;65S<V%G
M92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!01U`N(@IM<V=S='(@
M(MBGVXS9AB#9OMN,V+K8I]F%(-BGV+(@V+?8L=N,V8(@4$=0(-BHV+?9B-BQ
M(-BOVXS8K-N,V*K8I]F$VXP@V*?9A=BVV*?8H2#8M-BOV8<@V*?8L]BJ(@H*
M(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ-#,*;7-G:60@(E1H:7,@
M;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!3+TU)344N
M(@IM<V=S='(@(MBGVXS9AB#9OMN,V+K8I]F%(-BGV+(@V+?8L=N,V8(@4R]-
M24U%(-BHV+?9B-BQ(-BOVXS8K-N,V*K8I]F$VXP@V*?9A=BVV*?8H2#8M-BO
MV8<@V*?8L]BJ(@H*(SH@;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HQ,SD@
M;&EB+TU)344O5FEE=V5R+W!K8W,W+G!H<#HR,S@*;7-G:60@(E1H:7,@;65S
M<V%G92!H87,@8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB"FUS9W-T<B`B
MV*?;C-F&(-F^VXS8NMBGV84@V*C8IR!3+TU)344@V+'9A=BRV*C9AMBOVXP@
MV+38K]F'(-BGV+/8JB(*"B,Z(&QI8B]-24U%+U9I97=E<B]P9W`N<&AP.C(P
M,2!L:6(O34E-12]6:65W97(O<&=P+G!H<#HR.3$*;7-G:60@(E1H:7,@;65S
M<V%G92!H87,@8F5E;B!E;F-R>7!T960@=VET:"!01U`N(@IM<V=S='(@(MBG
MVXS9AB#9OMN,V+K8I]F%(-BHV*<@4$=0(-BQV878LMBHV8;8K]N,(-BTV*_9
MAR#8I]BSV*HB"@HC.B!M97-S86=E+G!H<#HR,3$*;7-G:60@(E1H:7,@;65S
M<V%G92!T;R(*;7-G<W1R("+8I]N,V88@V;[;C-BZV*?9A2#8J-F'(@H*(SH@
M86-L+G!H<#HT-@IM<V=I9"`B5&AI<R!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(MBGVXS9AB#:J=BGV+'8L]BG
MV+(@V;[9B-BTV8?B@(S9A]BGVXP@V878M-BJV+':J2#8L=BG(-F^V+38JMN,
MV*C8I]F&VXP@V8;9A=N,XH",VJG9AMBO(@H*(SH@=&5M<&QA=&5S+V-O;G1A
M8W1S+V-O;G1A8W1S+FEN8SHQ,#D*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O=RXB"FUS9W-T<B`BV*?;
MC-F&(-F^V8;8K-BQV8<@V*C8I]BHVXS8KR#8I]BR(-BWV+';C-F"(-N,VJD@
MV;[9AMBLV+'9A]F4(-BGVXS8K-BGV*\@V;[;C-BZV*?9A2#8M=BOV*<@V+39
MB-BO(@H*(SH@=&AR96%D+G!H<#HQ-3(*;7-G:60@(E1H<F5A9"!$:7-P;&%Y
M(@IM<V=S='(@(MF&V878I]N,V+0@V+/9A-BSV839A^*`C-BGVXS;C"(*"B,Z
M('1H<F5A9"YP:'`Z-S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR,@IM<V=I
M9"`B5&AR96%D(%9I97<B"FUS9W-T<B`BV8;9A=BGVXS8M"#8L]F$V+/9A-F'
MXH",V*?;C-N,("(*"B,Z(&UE<W-A9V4N<&AP.C(V-"!M86EL8F]X+G!H<#HV
M,#8@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S+FEN8SHR,3D*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHR,B!T96UP;&%T
M97,O8V]M<&]S92]R961I<F5C="YI;F,Z-C$*(SH@=&5M<&QA=&5S+V-O;7!O
M<V4O<F5C;VUP;W-E+FEN8SHQ,"!L:6(O4V5A<F-H+G!H<#HR-@IM<V=I9"`B
M5&\B"FUS9W-T<B`BV*C9AR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,3D*;7-G:60@(E1O($%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@VJ_;C-BQ
MV8;8K]F'(@H*(SH@=&5M<&QA=&5S+W!R969S+W-O=7)C97-E;&5C="YI;F,Z
M,S(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@9FEE;&1S+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I('=H:6QE
M("(*(F-L:6-K:6YG+B(*;7-G<W1R("(B"B+8J-BQV*?;C"#8I]F&V*K8KMBG
MV*@@VH;9AMBO(-F!VXS9A-BOV(P@V*_:J=F%V8<@0W1R;"#8L=BG(-BQV8C;
MC"`H4$,I(-N,V*<@0V]M;6%N9"#8L=BG(-BQV*<@V+'9B-N,("A-86,IV(P@
MV*_8L2`B"B+9A=BOV*H@VJG9A-N,VJD@VJG8L=BOV88@V8;:K]F'V*_8I]BQ
MVXS8KR(*"B,Z(&QI8B])34%0+T-L:65N="YP:'`Z,3,T"FUS9VED("(B"B)4
M;R!U<V4@82!43%,@8V]N;F5C=&EO;BP@>6]U(&UU<W0@8F4@<G5N;FEN9R!A
M('9E<G-I;VX@;V8@4$A0(#4N,"XV(&]R("(*(FAI9VAE<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3<W"FUS9VED
M(")4;W1A;"!!='1A8VAM96YT<R!3:7IE.B(*;7-G<W1R("+9A=BLV879B-BY
M(-BGV8;8K]BGV++9A]F4(-F^VXS9B-BSV*K9A]BG.B(*"B,Z(&9O;&1E<G,N
M<&AP.C,X.`IM<V=I9"`B5')A<V@@9F]L9&5R(@IM<V=S='(@(MF^V8C8M-F'
MV90@V*+8M-BZV*?9A"(*"B,Z('1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C
M="YI;F,Z,C,*;7-G:60@(E1R87-H(&9O;&1E<CHB"FUS9W-T<B`BV;[9B-BT
MV8?9E"#8HMBTV+K8I]F$.B(*"B,Z(&QI8B]1=6]T82]C>7)U<RYP:'`Z-C4@
M;&EB+U%U;W1A+VUE<F-U<GDS,BYP:'`Z-SD@;&EB+U%U;W1A+V-O;6UA;F0N
M<&AP.C<R"B,Z(&QI8B]1=6]T82]L;V=F:6QE+G!H<#HX."!L:6(O475O=&$O
M8V]U<FEE<BYP:'`Z-3,@;&EB+U%U;W1A+VUD865M;VXN<&AP.C0X"FUS9VED
M(")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V879@MBOV*?8L2#8L]F'V87;C-F'(-BQV*<@V*C8I]BRVXS8
MI]BHVXP@VJG8L=BO("(*"B,Z('1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N
M879I9V%T92YI;F,Z,3`@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHQ
M.0HC.B!T96UP;&%T97,O;6%I;&)O>"]N879B87(N:6YC.C,V"FUS9VED(")5
M;F%N<W=E<F5D(@IM<V=S='(@(MF^V*?8L]BN(-BOV*?8K]F'(-F&V+38K]F'
M(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHS-0IM<V=I9"`B56YA
M;G-W97)E9"!M97-S86=E<R(*;7-G<W1R("+9OMN,V+K8I]F%V8?8I]N,(-F^
MV*?8L]BN(-BOV*?8K]F'(-F&V+38K]F'(@H*(SH@=&5M<&QA=&5S+VUE<W-A
M9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C0@=&5M<&QA=&5S+VUA:6QB;W@O86-T
M:6]N<RYI;F,Z,3,*;7-G:60@(E5N9&5L971E(@IM<V=S='(@(MBHV*?8LMN,
MV*?8J-N,(@H*(SH@;6%I;&)O>"YP:'`Z-3@Y(&UA:6QB;W@N<&AP.C8P,B!L
M:6(O34E-12](96%D97)S+G!H<#HR,3(*;7-G:60@(E5N9&ES8VQO<V5D(%)E
M8VEP:65N=',B"FUS9W-T<B`BVJ_;C-BQV8;8K]F'V90@V8;8I]BTV8;8I]BS
M(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP.C0T-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM
M<V=S='(@(MF%V*39A-F!V8?9E"`@V*C8K]F(V88@V;[8M-BJVXS8J-BGV8;;
MC#H@)7,B"@HC.B!M86EL8F]X+G!H<#HU-C4*;7-G:60@(E5N:VYO=VX@1&%T
M92(*;7-G<W1R("+8JMBGV+';C-BN(-F&V*?9A=BYV839B-F%(@H*(SH@;&EB
M+TE-05`O0VQI96YT+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YK
M;F]W;B!)34%0(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E
M<W!O;F1E9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TU)344O5FEE=V5R+VET
M:7`N<&AP.C8S-0IM<V=I9"`B56YK;F]W;B!-965T:6YG(@IM<V=S='(@(MF%
MV838I]F"V*?8JB#9AMBGV878N=F$V8C9A2(*"B,Z(&UA:6QB;W@N<&AP.C8Q
M.`IM<V=I9"`B56YK;F]W;B!296-I<&EE;G0B"FUS9W-T<B`BVJ_;C-BQV8;8
MK]F'V90@V8;8I]F%V+G9A-F(V84B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B56YL
M;V%D(%!A<W-P:')A<V4B"FUS9W-T<B`BV*C8L=BOV*?8M-BJV88@V+G8J-BG
MV+'8JB#:K]BPV+$B"@HC.B!F971C:&UA:6QP<F5F<RYP:'`Z-C4*;7-G:60@
M(E5N;F%M960B"FUS9W-T<B`BV*C;C.*`C-F&V*?9A2(*"B,Z(&UE<W-A9V4N
M<&AP.C0Y.2!M86EL8F]X+G!H<#HW,#@@=&5M<&QA=&5S+VUE<W-A9V4O;F%V
M8F%R7VYA=FEG871E+FEN8SHV"B,Z('1E;7!L871E<R]M86EL8F]X+VYA=F)A
M<BYI;F,Z,34@=&5M<&QA=&5S+VUA:6QB;W@O;F%V8F%R+FEN8SHS,@HC.B!T
M96UP;&%T97,O;6%I;&)O>"]L96=E;F0N:6YC.C4*;7-G:60@(E5N<V5E;B(*
M;7-G<W1R("+9A=BTV*?9A]BOV8<@V8;8M-BOV8<B"@HC.B!T96UP;&%T97,O
M9F]L9&5R<R]A8W1I;VYS+FEN8SHQ,@IM<V=I9"`B56YS=6)S8W)I8F4@9G)O
M;2!&;VQD97(H<RDB"FUS9W-T<B`BV838NMF((-BYV+;9B-N,V*H@V*?8LB#9
MOMF(V+39ARC9A]BG*2(*"B,Z('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N
M:6YC.C4X-`IM<V=I9"`B57!D871E($%T=&%C:&UE;G0@26YF;W)M871I;VXB
M"FUS9W-T<B`BV*C8L=F(V++8L=BSV*?9AMN,(-BGV+?9A-BGV+G8I]BJ(-F^
MVXS9B-BSV*HB"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z-C(P"FUS
M9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`BV*C8L=F(
MV++8L=BSV*?9AMN,(-F(V+;8N=N,V*H@V;[8I]BSV*XB"@HC.B!T96UP;&%T
M97,O<VUI;64O:6UP;W)T7VME>2YI;F,Z-3@@=&5M<&QA=&5S+W!G<"]I;7!O
M<G1?:V5Y+FEN8SHU-@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(MBGV+'8L]BG
MV80B"@HC.B!T96UP;&%T97,O<')E9G,O<V5N=&UA:6QS96QE8W0N:6YC.C0Q
M"FUS9VED(")5<V4@1&5F875L="!686QU92(*;7-G<W1R("+8I]BSV*K9@=BG
MV*_9AR#8I]BR(-F%V8+8K]BGV+$@V;[;C-BT(-F!V+'8MB(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-38*;7-G:60@(E5S92!)34%0(&9O;&1E<B!S
M=6)S8W)I<'1I;VYS/R(*;7-G<W1R("+8HMN,V*<@V*?8LB#8N=BVV8C;C-BJ
M(-F^V8C8M-F'XH",V8?8I]N,($E-05`@V*?8L]BJV8'8I]BOV8<@V+39B-BO
MV)\@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<S-0IM<V=I9"`B57-E
M(%9I<G1U86P@5')A<V@@1F]L9&5R/R(*;7-G<W1R("+8HMN,V*<@V*?8LB#9
MOMF(V+39A]F4(-BBV+38NMBGV80@V878K-BGV++;C"#8I]BSV*K9@=BGV*_9
MAR#8M-F(V*_8GR(*"B,Z('1E;7!L871E<R]A8VPO86-L+FEN8SHQ-#(*;7-G
M:60@(E5S97(B"FUS9W-T<B`BVJG8I]BQV*C8L2(*"B,@"B,Z(&%C;"YP:'`Z
M.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E5S97(@7"(E<UPB
M('-U8V-E<W-F=6QL>2!G:79E;B!T:&4@<W!E8VEF:65D(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(MJIV*?8L=BHV+$@)R5S)R#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V*_8L]BJV+'8L]N,V8?8I]N,(-F%V+38
MKMBU(-BTV*_9AR#8J-BQV*?;C"#9OMF(V+39AR`G)7,G(-BQV*<@V*_8I]BO
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ-S<*;7-G:60@(E5S
M97)N86UE(@IM<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQ(@H*(SH@=&5M<&QA
M=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C$W"FUS9VED(")5<V5R;F%M93HB
M"FUS9W-T<B`BV8;8I]F%(-JIV*?8L=BHV+$Z(@H*(SH@=&5M<&QA=&5S+W-M
M:6UE+W-M:6UE+FEN8SHR-2!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC.C8X
M"B,Z('1E;7!L871E<R]S;6EM92]S;6EM92YI;F,Z-S(@=&5M<&QA=&5S+W!G
M<"]P9W`N:6YC.C(W"B,Z('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,B!T96UP
M;&%T97,O<&=P+W!G<"YI;F,Z-S<*;7-G:60@(E9I97<B"FUS9W-T<B`BV8;9
MA=BG(@H*(SH@;&EB+TU)344O5FEE=V5R+WII<"YP:'`Z.3(@;&EB+TU)344O
M5FEE=V5R+W1N968N<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M("5S(@IM<V=S='(@(MF&V878I]N,V+0@)7,B"@HC(`HC.B!T96UP;&%T97,O
M<VUI;64O<VUI;64N:6YC.C(U('1E;7!L871E<R]P9W`O<&=P+FEN8SHR-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(%!U8FQI8R!+97DB"FUS9W-T
M<B`BV8;9A=BGVXS8M"#:J=F$VXS8KR#8N=F%V8C9A=N,("5S(@H*(SH@;&EB
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C$Q-@IM<V=I9"`B5FEE=R!(5$U,(&-O
M;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B"FUS9W-T<B`BV8;9A=BGVXS8
MM"#9A=BJV88@2%1-3"#8K]BQ(-N,VJD@V;[9AMBLV+'9A]F4(-BLV*_8I]JO
MV*?9AMF'(@H*(SH@=&5M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,C@*
M;7-G:60@(E9I97<@365S<V%G97,B"FUS9W-T<B`BV878M-BGV8?8K]F'V90@
MV;[;C-BZV*?9A=F'V*<B"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C<R('1E;7!L871E<R]P9W`O<&=P+FEN8SHW-PIM<V=I9"`B5FEE=R!097)S
M;VYA;"!0<FEV871E($ME>2(*;7-G<W1R("+9AMF%V*?;C-BT(-JIV83;C-BO
M(-BNV+79B-BUVXP@V+38KMBUVXPB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI
M;64N:6YC.C8X('1E;7!L871E<R]P9W`O<&=P+FEN8SHW,@IM<V=I9"`B5FEE
M=R!097)S;VYA;"!0=6)L:6,@2V5Y(@IM<V=S='(@(MF&V878I]N,V+0@VJG9
MA-N,V*\@V+G9A=F(V87;C"#8M-BNV+7;C"(*"B,Z('1E;7!L871E<R]M97-S
M86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHQ.`IM<V=I9"`B5FEE=R!4:')E860B
M"FUS9W-T<B`BV8;9A=BGVXS8M"#8L]F$V+/9A-F'XH",("(*"B,Z(&QI8B]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C$V,R!L:6(O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HQ-C4*;7-G:60@(E9I97<@5&AU;6)N86EL(@IM<V=S='(@(MF&
MV878I]N,V+0@V*K8M=F(VXS8L2#:J=F(VH;:J2#8M-BOV8<B"@HC.B!L:6(O
M34E-12]6:65W97(O<&MC<S<N<&AP.C0Q.`IM<V=I9"`B5FEE=R!A='1A8VAM
M96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S='(@(MF&V878I]N,V+0@
MV;[;C-F(V+/8JMF'V*<@V*_8L2#;C-JI(-F^V8;8K-BQV8?9E"#8K-BOV*?:
MK]BGV8;9AR(*"B,Z(&QI8B]-24U%+U9I97=E<B]R96QA=&5D+G!H<#HW.0IM
M<V=I9"`B5FEE=R!C;VYT96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(@IM<V=S
M='(@(MF&V878I]N,V+0@V878JMF&(-BOV+$@VXS:J2#9OMF&V*S8L=F'V90@
MV*S8K]BGVJ_8I]F&V8<B"@HC.B!L:6(O34E-12]6:65W97(O:71I<"YP:'`Z
M,30P"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(MF&V878I]N,V+0@V+'9
MB-N,V*_8I]BO(@H*(R`*(SH@9F]L9&5R<RYP:'`Z,S@P(&UA:6QB;W@N<&AP
M.C4S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&UE<W-A9V5S(&EN("5S
M(@IM<V=S='(@(MF&V878I]N,V+0@V;[;C-BZV*?9A=F'V*<@V*_8L2`E<R(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z('1E;7!L871E<R]P<F5F<R]I;FET:6%L<&%G97-E;&5C="YI
M;F,Z,C,*;7-G:60@(E9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y(&%F=&5R
M(&QO9VEN.B(*;7-G<W1R("+9A=BTV*?9A]BOV8<@V8;8I]F%V8<@V8@@VXS8
MIR#9AMBGV879A^*`C-BOV*?9AB#8J-BQV*?;C"#9AMF%V*?;C-BT(-BHV+G8
MKR#8I]BR(-F(V+'9B-BO(@H*(SH@;&EB+TU)344O5FEE=V5R+VET:7`N<&AP
M.C$W,`IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(MF%V+38I]F'V*_9A]F4
M(-F(V+C;C-F!V8<B"@HC.B!L:6(O34E-12]6:65W97(O:'1M;"YP:'`Z,3`Q
M"FUS9VED(")6:65W('1H92!);6%G97,B"FUS9W-T<B`BV8;9A=BGVXS8M"#8
MJMBUV*?9B-N,V+$B"@HC.B!S96%R8V@N<&AP.C(V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:7)T=6%L($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F
M=6QL>2XB"FUS9W-T<B`BV;[9B-BTV8?9E"#9A=BLV*?8LMN,(%PB)7-<(B#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V*?;C-BLV*?8KR#8M-BO(@H*(SH@=&5M
M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ,3$@;&EB+TE-05`O5')E92YP:'`Z
M,3,X(&QI8B])34%0+U1R964N<&AP.C$U,0HC.B!L:6(O24U!4"]4<F5E+G!H
M<#HQ-3,@;&EB+TE-05`O5')E92YP:'`Z,34W(&QI8B])34%0+U1R964N<&AP
M.C$U.`HC.B!L:6(O24U!4"]4<F5E+G!H<#HS-CD@;&EB+TE-05`O5')E92YP
M:'`Z,SDS(&QI8B])34%0+U1R964N<&AP.C0S,PIM<V=I9"`B5FER='5A;"!&
M;VQD97)S(@IM<V=S='(@(MF^V8C8M-F')B-X,C`P8SO9A]BGVXP@V878K-BG
MV++;C"(*"B,Z('-E87)C:"YP:'`Z,C0U"FUS9VED(")6:7)T=6%L($9O;&1E
M<G,@<F5Q=6ER92!A(&QA8F5L+B(*;7-G<W1R("+9OMF(V+39A]F4(-F%V*S8
MI]BRVXP@V*C9AR#;C-JI(-BHV+':AMBSV*@@V8;;C-BGV+(@V*_8I]BQV*\B
M"@HC.B!L:6(O5D9O;&1E<BYP:'`Z,3<U(&QI8B]61F]L9&5R+G!H<#HQ.#`*
M;7-G:60@(E9I<G1U86P@24Y"3U@B"FUS9W-T<B`BV;[9B-BTV8?9E.*`C"#9
MA=BLV*?8LMN,(-F&V*?9A=F'XH",V8?8I]N,(-BOV+';C-BGV8'8JMN,(@H*
M(SH@9F]L9&5R<RYP:'`Z-#$V"FUS9VED(")6:7)T=6%L($E.0D]8($9O;&1E
M<B(*;7-G<W1R("+9OMF(V+39A^*`C-F4(-F%V*S8I]BRVXP@V8;8I]F%V8?B
M@(S9A]BGVXP@V*_8L=N,V*?9@=BJVXPB"@HC.B!M86EL8F]X+G!H<#HT-3(@
M;&EB+U9&;VQD97(N<&AP.C$Q-"!L:6(O5D9O;&1E<BYP:'`Z,3$Y"FUS9VED
M(")6:7)T=6%L(%1R87-H(@IM<V=S='(@(MBSV+?9A"#8HMBTV+K8I]F$(-F%
MV*S8I]BRVXPB"@HC.B!F;VQD97)S+G!H<#HT,3,*;7-G:60@(E9I<G1U86P@
M5')A<V@@1F]L9&5R(@IM<V=S='(@(MF^V8C8M-F'XH",V90@V878K-BGV++;
MC"#8HMBTV+K8I]F$(@H*(SH@=&5M<&QA=&5S+W-E87)C:"]M86EN+FEN8SHQ
M,S,*;7-G:60@(E9I<G1U86P@9F]L9&5R(&QA8F5L(@IM<V=S='(@(MBHV+':
MAMBSV*@@V;[9B-BTV8?9E"#9A=BLV*?8LMN,(@H*(SH@;&EB+TU)344O5FEE
M=V5R+W!K8W,W+G!H<#HS-S0*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BV*?8
MKMBWV*?8L3H@(@H*(SH@;&]G:6XN<&AP.C$S.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(MBHV8<@)7,@V*[9B-BT(-BB
MV878K]N,V*\@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Q.0IM<V=I
M9"`B(@HB5VAA="!S:&]U;&0@=V4@9&\@=VET:"!S<&%M(&UE<W-A9V5S(&%F
M=&5R('1H97D@:&%V92!B965N(')E<&]R=&5D(&%S('-P86T@(@HB;W(@:6YN
M;V-E;G0_(@IM<V=S='(@(MBBVXS8IR#9A]BQV++9AMBGV879A^*`C-F'V*<@
MV*C8N=BO(-BGV+(@V*?;C-F&VJG9AR#8J-F'(-BYV8;9B-BGV88@V8?8L=BR
MV8;8I]F%V8<@VJ_8LMBGV+'8M"#8M-BOV8;8KR#8K=BPV8$@V+39B-F&V*_8
MGR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW,C<*;7-G:60@(B(*(E=H
M96X@9&5L971I;F<@;65S<V%G97,L(&UO=F4@=&AE;2!T;R!Y;W5R(%1R87-H
M(&9O;&1E<B!I;G-T96%D(&]F(&UA<FMI;F<@(@HB=&AE;2!A<R!D96QE=&5D
M/R(*;7-G<W1R("(B"B+8HMN,V*<@V*_8L2#9A]F&VJ_8I]F%(-BMV+#9@2#9
MOMN,V+K8I]F%V8?8I]B,(-BHV*S8I]N,(-BYV838I]F%V*H@VJ_8L-BGV+';
MC"#8HMF&V8?8IR#8J-BYV8;9B-BGV88@V*W8L-F!(-BTV*_9AR#8J-F'(-BS
MV+?9A"#8HMBTV+K8I]F$("(*(MBTV878IR#8I]F&V*K9@MBGV80@V*_8I]BO
MV8<@V+39B-F&V*_8GR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,#<*
M;7-G:60@(E=H96X@;W!E;FEN9R!A(&YE=R!M86EL8F]X+"!W:&EC:"!P86=E
M(&1O('EO=2!W86YT('1O('-T87)T(&]N/R(*;7-G<W1R("+8K]BQ(-F'V8;:
MK]BGV84@V*C8I]BRVJG8L=BOV88@VXS:J2#9AMBGV879A^*`C-BOV*?9AB#8
MK-BOVXS8K]B,(-JIV*_8I]F%(-BUV8'8K=F'(-BHV+'8I]N,(-BTV+'9B-BY
M(-BHV*?8LB#8M-F(V*_8GR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-C$*;7-G:60@(E=H96X@<V%V:6YG('-E;G0M;6%I;"P@<VAO=6QD('=E('-A
M=F4@871T86-H;65N="!D871A/R(*;7-G<W1R("+8HMN,V*<@V8?9AMJOV*?9
MA=N,(-JIV8<@V8;8I]F%V8?9E"#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V*W9
M@=BX(-F%VXSB@(S8M-F(V*_8C"#8J-BGVXS8KR#9OMN,V8C8L]BJ(-F'V84@
MV*W9@=BX(-BTV8C8K]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M-@IM<V=I9"`B(@HB5VAE;B!S96YD:6YG(&UA:6P@;W(@97AP86YD:6YG(&%D
M9')E<W-E<RP@=VAA="!D;VUA:6X@<VAO=6QD('=E(&%P<&5N9"!T;R`B"B)U
M;G%U86QI9FEE9"!A9&1R97-S97,@*&5M86EL(&%D9')E<W-E<R!W:71H;W5T
M(%PB0%PB*3\B"FUS9W-T<B`B(@HBV*C9AR#9A]F&VJ_8I]F%(-BGV+'8L]BG
MV80@V;[;C-BZV*?9A=B,(-J&V8<@V8;8I]F%(-BMV8C8LMF'XH",V*?;C-N,
M(-BQV*<@V*C8I]N,V*\@V*C9AR#8HMBOV+'8L]F'V*?;C"#8NMN,V+$@VJG8
MI]F%V80@*-BHV*_9B-F&($`I("(*(MBGV+;8I]F!V8<@V8;9A=F(V*\B"@HC
M.B!T96UP;&%T97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M
M<&QA=&5S+VUA:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E=H:71E;&ES
M="(*;7-G<W1R("+9@=F'V+'8L]BJ(-BSV8';C-BO(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S92YI;F,Z-30Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-S@*;7-G:60@(EEE<R(*;7-G<W1R("+8J-F$V8<B"@HC.B!L:6(O36%I
M;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN<&AP.C4X"FUS9VED(")9
M;W4@87)E(&%B;W5T('1O(&9E=&-H(&5M86EL(&9R;VT@=&AE(&9O;&QO=VEN
M9R!A8V-O=6YT*',I.B(*;7-G<W1R("+8M-F%V*<@V*_8L2#8M=BOV*\@V8C8
MI]JIV+3;C"#9AMBGV879A^*`C-F'V*?;C"#8I]F$VJG8JMBQV8C9AMN,VJG;
MC"#8I]BR(-BMV+/8I]BHXH",*-F'V*?;C"D@V++;C-BQ(-F'V+/8JMN,V*\Z
M(@H*(SH@=&5M<&QA=&5S+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PZ
M,3`*;7-G:60@(B(*(EEO=2!A<F4@871T96UP=&EN9R!T;R!D96QE=&4@86QL
M(&UE<W-A9V5S(&-O;G1A:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<B(*
M(BAS*2XB"FUS9W-T<B`BV+39A=BG(-BOV+$@V;[;C"#8K=BPV8$@V;[;C-BZ
MV*?9A=F'V*?;C"#9OMF(V+39A^*`C-F'V*?;C"#8LMN,V+$@V8?8L]BJVXS8
MKSHB"@HC.B!T96UP;&%T97,O9F]L9&5R<R]F;VQD97)S7V-O;F9I<FTN:'1M
M;#HY"FUS9VED(")9;W4@87)E(&%T=&5M<'1I;F<@=&\@9&5L971E('1H92!F
M;VQL;W=I;F<@9F]L9&5R*',I+B(*;7-G<W1R("+8M-F%V*<@V*_8L2#9OMN,
M(-BMV+#9@2#9OMF(V+39A^*`C-F'V*?;C"#8LMN,V+$@V8?8L]BJVXS8KSHB
M"@HC.B!T96UP;&%T97,O;65S<V%G92]J879A<V-R:7!T+FEN8SHU-2!T96UP
M;&%T97,O;6%I;&)O>"]J879A<V-R:7!T+FEN8SHQ.3(*;7-G:60@(EEO=2!A
M<F4@8V]P>6EN9R]M;W9I;F<@=&\@82!N97<@9F]L9&5R+B(*;7-G<W1R("+8
MM-F%V*<@V*_8L2#8K=BGV80@V+'9B-F&V8C8M-BJ(-JOV+'9@=BJV88OV*?9
MAMBJV8+8I]F$(-BHV8<@VXS:J2#9OMF(V+39AR#8K-BOVXS8KR#9A]BSV*K;
MC-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O9F]L9&5R<RYJ<SHQ,#(*
M;7-G:60@(EEO=2!A<F4@8W)E871I;F<@82!S=6(M9F]L9&5R('1O("(*;7-G
M<W1R("+8M-F%V*<@V*_8L2#8K=BGV80@V+/8I]BNV*K9AB#;C-JI(-BRVXS8
ML=F^V8C8M-F'(-F'V+/8JMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]F;VQD97)S+FIS.C$P-`IM<V=I9"`B66]U(&%R92!C<F5A=&EN9R!A('1O
M<"UL979E;"!F;VQD97(N(@IM<V=S='(@(MBTV878IR#8K]BQ(-BMV*?9A"#8
MI]N,V*S8I]BO(-N,VJD@V;[9B-BTV8<@V+/8M]BM(-BHV*?9A-BG(-F'V+/8
MJMN,V*\B"@HC.B!L:6(O1F]L9&5R+G!H<#HS,C`*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&9O;&1E<G,N(@IM<V=S='(@(MBTV878
MIR#9A=BLV8C8LB#8I]N,V*S8I]BO(-F^V8C8M-F'(-BQV*<@V8;8K]BGV+';
MC-BO(@H*(SH@;&EB+T9O;&1E<BYP:'`Z,S(W"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!F;VQD97)S+B(*;7-G<W1R("+8M-F%V*<@V878K-F(V+(@V*?;C-BLV*?8
MKR#8J-N,V+0@V*?8LB`E9"#9OMF(V+39AR#8L=BG(-F&V*_8I]BQVXS8KR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V9O;&1E<G,N:G,Z,3,U"FUS9VED
M(")9;W4@87)E(')E;F%M:6YG('1H92!F;VQD97(Z("(*;7-G<W1R("+8M-F%
MV*<@V*_8L2#8K=BGV80@V*K8NMN,VXS8L2#9AMBGV84@V;[9B-BTV8<@V8?8
ML]BJVXS8KSHB"@HC.B!L:6(O1F]L9&5R+G!H<#HU-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U(&-A;B!N;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N
M(@IM<V=S='(@(MF$V+K9B"#8N=BVV8C;C-BJ(-BTV878IR#8I]BR(%PB)7-<
M(B#9A=F%VJG9AB#9AMN,V+/8JB(*"B,Z('1E;7!L871E<R]S=&%T:6]N97)Y
M+W!R969S+FEN8SHS-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@8V%N
M('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I;B!T:&4@<W1A=&EO
M;F5R>2!T97AT.B`E8R!F;W(@=&AE("(*(F-U<G)E;G0@;65S<V%G92!C;VYT
M96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB"FUS9W-T<B`B(@HBV+39A=BG
M(-BGV+(@V*K8L=JIVXS8J-BGV*H@V++;C-BQ(-BOV+$@V8;9B-BTV*KB@(S8
MI]F!V++8I]BQ(-F%VXSB@(S8JMF(V*?9AMN,V*\@V*?8L]BJV8'8I]BOV8<@
MV8;9A=BGVXS;C-BO.B`E8R#8J-BQV*?;C"#8I]BTV*?8L=F'(-BHV8<@(@HB
MV878JMF&(-F^VXS8NMBGV84@V8'8N=F$VXP@V8@@)7,@V*C8L=BGVXP@V*?9
MA=BVV*?8H2(*"B,Z(&QI8B]-86EN=&5N86YC92]487-K+W1O<U]A9W)E96UE
M;G0N<&AP.C,T"FUS9VED("(B"B)9;W4@9&ED(&YO="!A9W)E92!T;R!T:&4@
M5&5R;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O('EO=2!W97)E(&YO="!A
M;&QO=V5D("(*(G1O(&QO9VEN+B(*;7-G<W1R("(B"B+8M-F%V*<@V*C8IR#8
MM-BQVXS8MR#8JMF(V*?9@=F"VXP@V*[8K]F%V*K:K]BRV*?8L2#9A=F(V*?9
M@=F"V*H@V8;:J=BQV*_9A^*`C-BGXH",VXS8K]B,(-BHV8;8I]BHV+'8I]N,
MV88@V+39A=BG(-BGV*S8I]BRV8<@V8C8L=F(V*\@V8;8K]BGV+';C-BO(@H*
M(SH@=&5M<&QA=&5S+V%C;"]A8VPN:6YC.C$V.0IM<V=I9"`B66]U(&1O(&YO
M="!H879E('!E<FUI<W-I;VX@=&\@8VAA;F=E(&%C8V5S<R!T;R!T:&ES(&9O
M;&1E<B(*;7-G<W1R("+8M-F%V*<@V878K-F(V+(@V*K8NMN,VXS8L2#8K]BS
MV*K8L=BSVXP@V*?;C-F&(-F^V8C8M-F'(-BQV*<@V8;8K]BGV+';C-BO(@H*
M(R`*(SH@;&EB+TUA:6QL;V<N<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@9F]R=V%R9&5D('1H:7,@;65S<V%G92!O;B`E)7,@=&\@=&AE(&9O
M;&QO=VEN9R!R96-I<&EE;G1S.B`E<RXB"FUS9W-T<B`BV+39A=BG(-BGVXS9
MAB#9OMN,V+K8I]F%(-BQV*<@V*C8L2`E)7,@V*C9AR#:K]N,V+'9AMBOVJ_8
MI]F&(-BRVXS8L2#8I]BQV*S8I]BY(-JIV+'8K]N,V*\Z("5S(@H*(R`*(SH@
M=&5M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S+B(*;7-G<W1R("+8M-F%
MV*<@)7,@V;[;C-BZV*?9A2#8K-BOVXS8KR#8K]BGV+';C-BO(@H*(SH@=&5M
M<&QA=&5S+VUA:6QB;W@O86QE<G0N:6YC.C,*;7-G:60@(EEO=2!H879E(#$@
M;F5W(&UE<W-A9V4N(@IM<V=S='(@(MBTV878IR#;C-JI(-F^VXS8NMBGV84@
MV*S8K]N,V*\@V*_8I]BQVXS8KR(*"B,Z(&-O;7!O<V4N<&AP.C0Y-`HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&AA=F4@86QR96%D>2!S=6)M:71T960@=&AI<R!P
M86=E+B(*;7-G<W1R("+8M-F%V*<@VXS:J2#9OMN,V+K8I]F%(-BLV*_;C-BO
M(-BOV*?8L=N,V*\B"@HC.B!T96UP;&%T97,O8V]M<&]S92]A='1A8VAM96YT
M<RYJ<SHQ,34*;7-G:60@(B(*(EEO=2!H879E(&%T(&QE87-T(&]N92!A='1A
M8VAM96YT('-E;&5C=&5D('1H870@>6]U(&1I9&XG="!U<&QO860@>65T+B!!
M<F4@(@HB>6]U('-U<F4@>6]U('=A;G0@=&\@<V5N9"!T:&ES(&UE<W-A9V4@
M=VET:&]U="!T:&5S92!A='1A8VAM96YT<S\B"FUS9W-T<B`B(@HBV+39A=BG
M(-BMV*_8I]F"V80@VXS:J2#9OMN,V8C8L]BJ(-BGV8;8JMBNV*?8J"#8M-BO
MV8<@V*_8I]BQVXS8KR#:J=F'(-F'V8;9B-BR(-BBV8;8L=BG(-BGV+'8L]BG
MV80@V8;:J=BQV*_9A^*`C-BGXH",VXS8KRX@V*+;C-BG(-F%V+?9A=BFV8;;
MC-BO("(*(MJIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8J-BOV8C9AB#8I]N,
MV88@V;[;C-F(V+/8JMF'V*<@V;[;C-BZV*?9A2#8L=BG(-BHV8'8L=BSV*K;
MC-BOV)\B"@HC.B!L:6(O24U0+G!H<#HQ,#<T"FUS9VED(")9;W4@:&%V92!N
M97<@;6%I;"!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<CHB"FUS9W-T<B`BV+39
MA=BG(-BOV+$@V;[9B-BTV8?9E"#8LMN,V+$@V;[;C-BZV*?9A2#8K-BOVXS8
MKR#8K]BGV+';C-BO.B(*"B,Z(&QI8B])35`N<&AP.C$P-SD*;7-G:60@(EEO
M=2!H879E(&YE=R!M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R<SHB"FUS
M9W-T<B`BV+39A=BG(-BOV+$@V;[9B-BTV8?9E"#8LMN,V+$@V;[;C-BZV*?9
MA2#8K-BOVXS8KR#8K]BGV+';C-BO.B(*"B,Z(&-O;7!O<V4N<&AP.C$U,PIM
M<V=I9"`B66]U(&UU<W0@96YT97(@870@;&5A<W0@;VYE(')E8VEP:65N="XB
M"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-BMV*_8I]F"V80@VXS:J2#:K]N,
MV+'9AMBOV8<@V8C8I]BQV*\@VJG9AMN,V*\B"@HC.B!L:6(O34E-12]6:65W
M97(O<&=P+G!H<#HS,#(*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H
M:7,@;65S<V%G92(*;7-G<W1R("(B"B+8M-F%V*<@V*C8I]N,V*\@V+G8J-BG
MV+'8JB#:K]BPV+$@V+'8IR#8J-BQV*?;C"#:J=F$VXS8KR#8KMBUV8C8M=N,
M(%!'4"#8KMF(V*\@V8C8I]BQV*\@VJG9AMN,V*\@V*K8IR#9OMN,V+K8I]F%
M(-BQV*<@V878M-BGV8?8K]F'("(*(MJIV8;;C-BO(@H*(SH@;&EB+TU)344O
M5FEE=V5R+W!K8W,W+G!H<#HR-#D*;7-G:60@(B(*(EEO=2!M=7-T(&5N=&5R
M('1H92!P87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T
M;R!V:65W('1H:7,@(@HB;65S<V%G92(*;7-G<W1R("(B"B+8M-F%V*<@V*C8
MI]N,V*\@V+G8J-BGV+'8JB#:K]BPV+$@V+'8IR#8J-BQV*?;C"#:J=F$VXS8
MKR#8KMBUV8C8M=N,(%,O34E-12#8KMF(V*\@V8C8I]BQV*\@VJG9AMN,V*\@
MV*K8IR#9OMN,V+K8I]F%(-BQV*<@(@HBV878M-BGV8?8K]F'(-JIV8;;C-BO
M(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI;F,Z-C0@=&5M
M<&QA=&5S+VUA:6QB;W@O:F%V87-C<FEP="YI;F,Z,C`Q"FUS9VED(")9;W4@
M;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S="XB"FUS9W-T<B`B
MV+39A=BG(-BGV*C8JMBOV*<@V*C8I]N,V*\@VXS:J2#9AMBGV879AR#8K]BG
MV88@V879@MBUV*\@V878M-BNV+4@VJG9AMN,V*\B"@HC.B!F971C:&UA:6QP
M<F5F<RYP:'`Z.#4*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!A8V-O=6YT
M('1O(&)E(&1E;&5T960N(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR#;C-JI
M(-BMV+/8I]BH(-BHV+'8I]N,(-BMV+#9@2#:J=BQV*_9AB#8I]F&V*K8KMBG
MV*@@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O8V]N=&%C=',O8V]N=&%C=',N
M:6YC.C@Q"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@861D<F5S<R!F:7)S
M="XB"FUS9W-T<B`BV+39A=BG(-BGV*C8JMBOV*<@V*C8I]N,V*\@VXS:J2#8
MHMBOV+'8LR#8I]F&V*K8KMBGV*@@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O
M;6%I;&)O>"]J879A<V-R:7!T+FEN8SHV,B!T96UP;&%T97,O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8SHR,#@*(SH@=&5M<&QA=&5S+VUA:6QB;W@O:F%V87-C
M<FEP="YI;F,Z,C8S"FUS9VED(")9;W4@;75S="!S96QE8W0@870@;&5A<W0@
M;VYE(&UE<W-A9V4@9FER<W0N(@IM<V=S='(@(MBTV878IR#8I]BHV*K8K]BG
M(-BHV*?;C-BO(-BMV*_8I]F"V80@VXS:J2#9OMN,V+K8I]F%(-BGV8;8JMBN
MV*?8J"#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T
M+FEN8SHQ,PIM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A(')E8VEP:65N="XB
M"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-N,VJD@VJ_;C-BQV8;8K]F'(-F%
MV+38KMBU(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:G,Z,CD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@870@;&5A<W0@
M;VYE(&9I;&4@=&\@871T86-H+B(*;7-G<W1R("+8M-F%V*<@V*W8K]BGV8+9
MA"#8J-BGVXS8KR#;C-JI(-F^V+'9B-F&V*_9A^*`C"#8J-BQV*?;C"#9OMN,
MV8C8L]BJ(-JIV+'8K]F&(-F%V+38KMBU(-JIV8;;C-BO(@H*(R`*(SH@=&5M
M<&QA=&5S+V9E=&-H;6%I;"]M86YA9V4N:6YC.C0X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@;F5E9"!T;R!H879E(%PB)7-<(B!E;F%B;&5D
M(&EN('EO=7(@;6%I;G1E;F%N8V4@;W!T:6]N<RXB"FUS9W-T<B`BV+39A=BG
M(-F&VXS8I]BR(-BOV*?8L=N,V*\@VJG9AR`G)7,G(-BQV*<@V*_8L2#:K]BR
MVXS9AMF'XH",V8?8I]N,(-F&VJ_9A]BOV*?8L=N,V(P@V8'8N=BGV80@VJG9
MAMN,V*\B"@HC(`HC.B!L:6(O36%I;&QO9RYP:'`Z,3,W"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O
M;B`E)7,N(@IM<V=S='(@(MBTV878IR#8I]N,V88@V;[;C-BZV*?9A2#8L=BG
M(-BHV8<@)7,@V*C8L2`E)7,@V*K8NMN,VXS8L2#9A=BSVXS8L2#8K]BGV*_9
MA^*`C-BGXH",VXS8KR(*"B,Z(&QI8B]-86EL;&]G+G!H<#HQ-#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(')E<&QI960@=&\@=&AI<R!M97-S86=E(&]N
M("5S+B(*;7-G<W1R("+8M-F%V*<@V*C9AR#8I]N,V88@V;[;C-BZV*?9A2#8
MK]BQ("5S(-F^V*?8L]BN(-BOV*?8K]F'XH",V*?;C-BO(@H*(R`*(SH@;&EB
M+T9O;&1E<BYP:'`Z-3`W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W97)E
M(&YO="!S=6)S8W)I8F5D('1O(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S
M97)V97(@<V%I9"(*;7-G<W1R("+:J=BGV+'8L]BGV+(@VJ_9@=BJ(-JIV8<@
MV+39A=BG(-BYV+;9B"!<(B5S7"(@V8;8J-F(V*_B@(S;C-BO(@H*(R`*(SH@
M;&EB+T9O;&1E<BYP:'`Z-34Y"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!W
M97)E(&YO="!U;G-U8G-C<FEB960@9G)O;2!<(B5S7"(N($AE<F4@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60B"FUS9W-T<B`BVJG8I]BQV+/8I]BR(-JOV8'8
MJB#:J=F'(-BYV+;9B-N,V9'8JB#8M-F%V*<@V*_8L2!<(B5S7"(@V838NMF(
M(-F&V+38K]F'(-BHV8C8KR(*"B,Z(&QI8B]&;VQD97(N<&AP.C4Q,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@=V5R92!S=6-C97-S9G5L;'D@<W5B<V-R
M:6)E9"!T;R!<(B5S7"(B"FUS9W-T<B`BV+39A=BG(-BHV*<@V879B-F!V9'9
M@MN,V9'8JB#8K]BQ(%PB)7-<(B#8N=BVV8@@V+38K]N,V*\B"@HC.B!L:6(O
M1F]L9&5R+G!H<#HU-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U('=E<F4@
M<W5C8V5S<V9U;&QY('5N<W5B<V-R:6)E9"!F<F]M(%PB)7-<(B(*;7-G<W1R
M("+8N=BVV8C;C-BJ(-BTV878IR#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*?8
MLB!<(B5S7"(@V838NMF((-BTV*\B"@HC.B!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z.3@*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("+9AMBGV84@V+39A=BG
M(@H*(SH@=&5M<&QA=&5S+W!G<"]P9W`N:6YC.C4P"FUS9VED(")9;W5R(%!'
M4"!0=6)L:6,O4')I=F%T92!+97ES(@IM<V=S='(@(MJIV83;C-BOXH",V8?8
MI]N,(-BYV879B-F%VXPOV*[8M=F(V+7;C"!01U`@V+39A=BG(@H*(SH@=&5M
M<&QA=&5S+W-M:6UE+W-M:6UE+FEN8SHW,2!T96UP;&%T97,O<&=P+W!G<"YI
M;F,Z-S8*;7-G:60@(EEO=7(@4')I=F%T92!+97DB"FUS9W-T<B`BVJG9A-N,
MV*\@V+38KMBUVXP@V+39A=BG(@H*(SH@=&5M<&QA=&5S+W-M:6UE+W-M:6UE
M+FEN8SHV-R!T96UP;&%T97,O<&=P+W!G<"YI;F,Z-S$*;7-G:60@(EEO=7(@
M4'5B;&EC($ME>2(*;7-G<W1R("+:J=F$VXS8KR#8N=F%V8C9A=N,(-BTV878
MIR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C4*;7-G:60@(EEO=7(@
M4F5P;'DM=&\Z(&%D9')E<W,Z(#QE;3XH;W!T:6]N86PI/"]E;3XB"FUS9W-T
M<B`BV;[8I]BSV*X@V+39A=BG(-BHV8<Z(-BBV*_8L=BS(#QE;3XHV*?8KMBJ
MVXS8I]BQVXPI/"]E;3XB"@HC.B!T96UP;&%T97,O<VUI;64O<VUI;64N:6YC
M.C0Y"FUS9VED(")9;W5R(%,O34E-12!0=6)L:6,O4')I=F%T92!#97)T:69I
M8V%T97,B"FUS9W-T<B`BVJ_9B-BGV8?;C-F'V*?;C"#:J=F$VXS8K^*`C-F'
MV*?;C"#8N=F%V8C9A=N,+]BNV+79B-BUVXP@4R]-24U%(-BTV878IR(*"B,Z
M('1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC.C$V"FUS
M9VED(")9;W5R(&%C8V]U;G1S.B(*;7-G<W1R("+8K=BSV*?8J-F'V*?;C"#8
MM-F%V*<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$W,PIM<V=I9"`B
M(@HB66]U<B!A;&EA<R!A9&1R97-S97,Z(#QE;3XH;W!T:6]N86PL(&5N=&5R
M(&5A8V@@861D<F5S<R!O;B!A(&YE=R!L:6YE*3PO96T^(@IM<V=S='(@(B(*
M(MBBV*_8L=BS(-F%V+/8JMBYV*?8L2#8M-F%V*<Z(#QE;3XHV*?8KMBJVXS8
MI]BQVXS8C"#9A]BQ(-BBV*_8L=BS(-BQV*<@V*_8L2#;C-JI(-BNV+<@V*S8
MK]N,V*\@V8C8I]BQV*\@VJG9AMN,V*\I/"]E;3XB"@HC.B!L:6(O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HY,@IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@:6YL:6YE(&1I<W!L87D@;V8@=&AI<R!I;6%G92!T>7!E
M+B(*;7-G<W1R("+9A=BQV8C8L=JOV+$@V+39A=BG(-F&V878I]N,V+0@V*_8
ML=BNV+<@V*?;C-F&(-F&V8C8N2#8JMBUV8C;C-BQ(-BQV*<@V;[8M-BJVXS8
MJ-BGV8;;C"#9AMF%VXSB@(S:J=F&V*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,Y"FUS9VED(")9;W5R(&1E9F%U;'0@8VAA<G-E="!F;W(@<V5N
M9&EN9R!M97-S86=E<SHB"FUS9W-T<B`BV878K-F%V8C8N=F'(-F&V8C;C-BS
MV8?9E"#9OMN,V+0@V8'8L=BV(-BTV878IR#8J-BQV*?;C"#8I]BQV+/8I]F$
M(-F^VXS8NMBGV879A]BG.B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F-R>7!T
M<V5L96-T+FEN8SHQ"FUS9VED(")9;W5R(&1E9F%U;'0@96YC<GEP=&EO;B!M
M971H;V0@9F]R('-E;F1I;F<@;65S<V%G97,Z(@IM<V=S='(@(MBTVXS9B-F'
MV90@V+'9A=BRV*C9AMBOVXP@V;[;C-BT(-F!V+'8MB#8M-F%V*<@V*C8L=BG
MVXP@V*?8L=BSV*?9A"#9OMN,V+K8I]F%.B(*"B,Z(&QI8B]-24U%+U9I97=E
M<B]S=&%T=7,N<&AP.C@Y"FUS9VED(")9;W5R(&UE<W-A9V4@=V%S('-U8V-E
M<W-F=6QL>2!D96QI=F5R960N(@IM<V=S='(@(MF^VXS8NMBGV84@V+39A=BG
M(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]BQV+/8I]F$(-BTV*\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`V"FUS9VED(")9;W5R('-I9VYA='5R
M93HB"FUS9W-T<B`BV*?9A=BVV*?;C"#8M-F%V*<Z(@H*(SH@;65S<V%G92YP
M:'`Z,C@X(&-O;7!O<V4N<&AP.C$R.#0@;6%I;&)O>"YP:'`Z-30Y(&QI8B]#
M;VUP;W-E+G!H<#HX,3@*;7-G:60@(EM.;R!3=6)J96-T72(*;7-G<W1R(");
MV*C8K]F(V88@V+G9AMF(V*?9AETB"@HC.B!T96UP;&%T97,O8V]M<&]S92]C
M;VUP;W-E+FEN8SHR,#4*;7-G:60@(E]"8V,B"FUS9W-T<B`BV+'9B-F&V8C8
MM-BJ(-F%V*[9@=N,(@H*(SH@=&5M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C
M=&EO;G,N:6YC.C(Q('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$V
M"FUS9VED(")?0FQA8VML:7-T(@IM<V=S='(@(MF!V8?8L=BSV*H@V+/;C-BG
MV8<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E+FEN8SHQ-30*;7-G
M:60@(E]#8R(*;7-G<W1R("+8L=F(V8;9B-BTV*HB"@HC.B!T96UP;&%T97,O
M;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z-B!T96UP;&%T97,O;6%I;&)O
M>"]A8W1I;VYS+FEN8SHX"B,Z('1E;7!L871E<R]M86EL8F]X+V%C=&EO;G,N
M:6YC.C$P"FUS9VED(")?1&5L971E(@IM<V=S='(@(MBMV+#9@2(*"B,Z(&QI
M8B])35`N<&AP.CDW.0IM<V=I9"`B7T9O;&1E<G,B"FUS9W-T<B`BV;[9B-BT
MV8<F(W@R,#!C.]F'V*<B"@HC.B!T96UP;&%T97,O8V]M<&]S92]C;VUP;W-E
M+FEN8SHX,0IM<V=I9"`B7TED96YT:71Y(@IM<V=S='(@(MBGV+(B"@HC.B!L
M:6(O24U0+G!H<#HY-C$*;7-G:60@(E]);F)O>"(*;7-G<W1R("));F)O>"(*
M"B,Z(&QI8B])35`N<&AP.C$P,C`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(MBNV+'9B-BL(@H*(SH@;65S<V%G92YP:'`Z,S@T"FUS9VED(")?365S<V%G
M92!3;W5R8V4B"FUS9W-T<B`BV+/8L=J&V+39A=F'(-F^VXS8NMBGV84B"@HC
M.B!L:6(O24U0+G!H<#HY-S8*(RP@9G5Z>GD*;7-G:60@(E].97<@365S<V%G
M92(*;7-G<W1R("+9OMN,V+K8I]F%V8?8I]N,(-BLV*_;C-BO(@H*(SH@=&5M
M<&QA=&5S+VUE<W-A9V4O;F%V8F%R7V%C=&EO;G,N:6YC.C,S"FUS9VED(")?
M4')I;G0B"FUS9W-T<B`BVH;8I]F^(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O
M8V]M<&]S92YI;F,Z,C<R('1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M.C(X.0IM<V=I9"`B7U!R:6]R:71Y(@IM<V=S='(@(MBGV8C9A-F(VXS8JB(*
M"B,@"B,Z(&UA:6QB;W@N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")?
M4F5F<F5S:"`E<R(*;7-G<W1R("+8J-BGV++8HMF(V+';C"`E<R(*"B,Z('1E
M;7!L871E<R]M97-S86=E+VYA=F)A<E]A8W1I;VYS+FEN8SHX"FUS9VED(")?
M4F5P;'DB"FUS9W-T<B`BV;[8I]BSV*XB"@HC.B!L:6(O24U0+G!H<#HY.#$*
M;7-G:60@(E]396%R8V@B"FUS9W-T<B`BV*S8L]BJV*S9B"(*"B,Z('1E;7!L
M871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC.C8W('1E;7!L871E<R]C;VUP;W-E
M+V-O;7!O<V4N:6YC.C0S,0IM<V=I9"`B7U-E;F0@365S<V%G92(*;7-G<W1R
M("+9@=BQV+/8JMBGV*_9AB#9OMN,V+K8I]F%(@H*(SH@=&5M<&QA=&5S+VUA
M:6QB;W@O;65S<V%G95]H96%D97)S+FEN8SHS,@IM<V=I9"`B7U1H<F5A9"(*
M;7-G<W1R("+8L]F$V+/9A-F'(@H*(SH@=&5M<&QA=&5S+V-O;7!O<V4O8V]M
M<&]S92YI;F,Z,3$V"FUS9VED(")?5&\B"FUS9W-T<B`BV*C9AR(*"B,Z('1E
M;7!L871E<R]M86EL8F]X+V%C=&EO;G,N:6YC.C$S"FUS9VED(")?56YD96QE
M=&4B"FUS9W-T<B`BV*C8I]BRVXS8I]BHVXPB"@HC.B!T96UP;&%T97,O;65S
M<V%G92]N879B87)?86-T:6]N<RYI;F,Z,3@*;7-G:60@(E]6:65W(%1H<F5A
M9"(*;7-G<W1R("+9AMF%V*?;C-BT(-BSV838L]F$V8<B"@HC.B!T96UP;&%T
M97,O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,Z,C0@=&5M<&QA=&5S+VUA
M:6QB;W@O86-T:6]N<RYI;F,Z,3D*;7-G:60@(E]7:&ET96QI<W0B"FUS9W-T
M<B`BV8'9A]BQV+/8JB#8L]F!VXS8KR(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HQ
M-S8*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HT-#`*;7-G:60@(F%T=&%C:&UE;G0B"FUS9W-T<B`B
MV;[;C-F(V+/8JB(*"B,Z('9I97<N<&AP.CDY"FUS9VED(")A='1A8VAM96YT
M<RYZ:7`B"FUS9W-T<B`BV;[;C-F(V+/8JMF'V*<N>FEP(@H*(SH@=&5M<&QA
M=&5S+V-O;7!O<V4O8V]M<&]S92YI;F,Z-3$S"FUS9VED(")B>71E<R(*;7-G
M<W1R("+8J-BGVXS8JN*`C"(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#`*;7-G
M:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T-O;7!O<V4N<&AP.C$W,@IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B
M"FUS9W-T<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$V-`IM<V=I9"`B8V]M
M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP
M;W-E+G!H<#HR,C`*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y-@IM<V=I9"`B8W)I=&EC86P@
M<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S
M92YP:'`Z,38X"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0V]M<&]S92YP:'`Z,C(T"FUS9VED(")E;G1R>2!N;W0@9F]U
M;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V-O;G1A8W1S+V-O;G1A8W1S
M+FEN8SHQ.3`*;7-G:60@(F9R;VTB"FUS9W-T<B`BV*?8LB(*"B,Z(&QI8B]#
M;VUP;W-E+G!H<#HQ.#`*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H<#HR,#0*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0V]M<&]S92YP:'`Z,3@X
M"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!S;6EM92YP:'`Z,CD@<&=P+G!H<#HV.0IM<V=I9"`B:V5Y(@IM<V=S='(@
M(MJIV83;C-BO(@H*(SH@9F]L9&5R<RYP:'`Z,38Q"FUS9VED(")M86EL8F]X
M(&9I;&4B"FUS9W-T<B`BV;[8L=F(V8;8K]F'V93B@(P@V8;8I]F%V8?B@(S8
MK]BGV88B"@HC.B!C;VUP;W-E+G!H<#HQ,#8W(&QI8B]-97-S86=E+G!H<#HT
M-C8*;7-G:60@(FYA;64B"FUS9W-T<B`BV8;8I]F%(@H*(SH@=&5M<&QA=&5S
M+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C<V"FUS9VED(")N;VYE(@IM<V=S='(@
M(MF'VXS:AN*`C-N,VJDB"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN
M9RYI;F,Z,3`U"FUS9VED(")O<B(*;7-G<W1R("+;C-BG(@H*(SH@;&EB+T-O
M;7!O<V4N<&AP.C(Q-@IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T
M<B`B(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C(Q,@IM<V=I9"`B<F5M;W1E(&5R
M<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]#;VUP;W-E+G!H
M<#HQ.#0*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC.C0V"FUS9VED(")S
M<&5L;&EN9R!E<G)O<B(*;7-G<W1R("+8KMBWV*?;C"#8I]F%V838I]N,VXPB
M"@HC.B!T96UP;&%T97,O8V]M<&]S92]S<&5L;&EN9RYI;F,Z-#8*;7-G:60@
M(G-P96QL:6YG(&5R<F]R<R(*;7-G<W1R("+8KMBWV*?9A]BGVXP@V*?9A=F$
MV*?;C-N,(@H*(SH@;&EB+T-O;7!O<V4N<&AP.C$Y,@IM<V=I9"`B<WES=&5M
M(&5R<F]R(@IM<V=S='(@(MBNV+?8I]N,(-BSV*?9A=BGV8;9AR(*"B,Z(&QI
M8B]#;VUP;W-E+G!H<#HR,#@*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(MBTVJG8L]BJ(-F%V8C9@MBJVXPB"@HC.B!L:6(O1FEL=&5R+G!H
M<#HU,0IM<V=I9"`B>6]U<B!B;&%C:VQI<W0B"FUS9W-T<B`BV8'9A]BQV+/8
MJB#8L]N,V*?9AR#8M-F%V*<B"@HC.B!L:6(O1FEL=&5R+G!H<#HV,0IM<V=I
M9"`B>6]U<B!W:&ET96QI<W0B"FUS9W-T<B`BV8'9A]BQV+/8JB#8L]F!VXS8
MKR#8M-F%V*<B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M;&EB+P``````````````````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8V`#`Q-3<V,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEM<"]L:6(O24U!4"\`````````````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C8`
M,#$V-3$Q`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B])34%0+T-L
M:65N="YP:'``````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V
M-#,Q,0`Q,#0Q-S,V,C<V-@`P,C`T-#(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J*@H@*B!4:&4@24U07TE-
M05!#;&EE;G0Z.B!C;&%S<R!E;F%B;&5S(&-O;FYE8W1I;VX@=&\@86X@24U!
M4"!S97)V97(@=&AR;W5G:`H@*B!B=6EL="UI;B!02%`@9G5N8W1I;VYS+@H@
M*@H@*B!43T1/.B!4:&ES('-H;W5L9"!E=F5N='5A;&QY(&)E(&UO=F5D('1O
M($AO<F1E(#0N,"]F<F%M97=O<FLN"B`J"B`J("1(;W)D93H@:6UP+VQI8B])
M34%0+T-L:65N="YP:'`L=B`Q+C(Q+C(N,3<@,C`P-B\P,B\R,2`P-SHS.3HU
M-"!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H*("H@0F%S960@
M;VX@8V]D92!F<F]M.@H@*B`@("L@875T:"YP:'`@*#$N-#DI"B`J("`@*R!I
M;6%P7V=E;F5R86PN<&AP("@Q+C(Q,BD*("H@("`K('-T<FEN9W,N<&AP("@Q
M+C$X-"XR+C,U*0H@*B`@(&9R;VT@=&AE(%-Q=6ER<F5L;6%I;"!P<F]J96-T
M+@H@*B`@($-O<'ER:6=H="`H8RD@,3DY.2TR,#`U(%1H92!3<75I<G)E;$UA
M:6P@4')O:F5C="!496%M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M24U0(#0N,0H@*B!`<&%C:V%G92!)35`*("HO"F-L87-S($E-4%])34%00VQI
M96YT('L*"B`@("`O*BH*("`@("`J(%1H92!L:7-T(&]F(&-A<&%B:6QI=&EE
M<R!O9B!T:&4@24U!4"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]C87!A8FEL:71Y(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J(%1H92!H;W-T;F%M92!O9B!T:&4@24U!4"!S97)V97(@=&\@
M8V]N;F5C="!T;RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]H;W-T.PH*("`@("\J*@H@("`@("H@5&AE(&QA<W0@;65S
M<V%G92!R971U<FYE9"!F<F]M('1H92!S97)V97(N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;65S<V%G93L*"B`@("`O
M*BH*("`@("`J(%1H92!N86UE<W!A8V4@:6YF;W)M871I;VXN"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]N86UE<W!A8V4@
M/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE('!O<G0@;G5M8F5R(&]F('1H
M92!)34%0('-E<G9E<B!T;R!C;VYN96-T('1O+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!O<G0["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;&%S="!R97-P;VYS92!R971U<FYE9"!F<F]M('1H92!S97)V
M97(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?<F5S<&]N<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@=6YI<75E('-E<W-I
M;VX@:61E;G1I9FEE<B!)1"!T;R!U<V4@=VAE;B!M86MI;F<@86X@24U!4"!Q
M=65R>2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?<V5S<VEO;FED(#T@,3L*"B`@("`O*BH*("`@("`J(%1H92!S;V-K
M970@8V]N;F5C=&EO;B!T;R!T:&4@24U!4"!S97)V97(N"B`@("`@*@H@("`@
M("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]S=')E86T["@H@
M("`@+RHJ"B`@("`@*B!!<F4@=V4@=7-I;F<@4U-,('1O(&-O;FYE8W0@=&\@
M=&AE($E-05`@<V5R=F5R/PH@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W5S97-S;"`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@07)E('=E('5S:6YG(%1,4R!T;R!C;VYN96-T('1O('1H92!)34%0('-E
M<G9E<C\*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]U<V5T;',@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AO<W0@("`@("!4
M:&4@861D<F5S<R]H;W-T;F%M92!O9B!T:&4@24U!4"!S97)V97(N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P;W)T("`@("`@5&AE('!O<G0@=&\@8V]N;F5C
M="!T;R!O;B!T:&4@24U!4"!S97)V97(N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P<F]T;V-O;"`@5&AE('!R;W1O8V]L('-T<FEN9R`H4V5E+"!E+F<N+"!S
M97)V97)S+G!H<"DN"B`@("`@*B\*("`@(&9U;F-T:6]N($E-4%])34%00VQI
M96YT*"1H;W-T+"`D<&]R="P@)'!R;W1O8V]L*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?:&]S="`]("1H;W-T.PH@("`@("`@("1T:&ES+3Y?<&]R="`]("1P
M;W)T.PH*("`@("`@("`O*B!3<&QI="!A<&%R="!P<F]T;V-O;"!S=')I;F<@
M=&\@9&ES8V]V97(@:68@=V4@;F5E9"!T;R!U<V4@96ET:&5R"B`@("`@("`@
M("H@4U-,(&]R(%1,4RX@*B\*("`@("`@("`D=&UP(#T@97AP;&]D92@G+R<L
M('-T<G1O;&]W97(H)'!R;W1O8V]L*2D["B`@("`@("`@:68@*&EN7V%R<F%Y
M*"=T;',G+"`D=&UP*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W5S971L<R`]
M('1R=64["B`@("`@("`@?2!E;'-E:68@*&EN7V%R<F%Y*"=S<VPG+"`D=&UP
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W5S97-S;"`]('1R=64["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07)E('=E('5S:6YG(%1,4R!T
M;R!C;VYN96-T(&%N9"!I<R!I="!S=7!P;W)T960_"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@4F5T=7)N<R!T<G5E(&EF(%1,4R!I<R!B96EN9R!U
M<V5D('1O(&-O;FYE8W0L(&9A;'-E(&EF"B`@("`@*B`@("`@("`@("`@("`@
M("!I<R!N;W0L(&%N9"!014%27T5R<F]R(&EF('=E(&%R92!A='1E;7!T:6YG
M('1O('5S92!43%,*("`@("`J("`@("`@("`@("`@("`@(&%N9"!T:&ES('9E
M<G-I;VX@;V8@4$A0(&1O97-N)W0@<W5P<&]R="!I="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=7-E5$Q3*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]U
M<V5T;',I('L*("`@("`@("`@("`@+RH@5&AE<F4@:7,@;F\@=V%Y(&EN(%!(
M4"`T('1O(&]P96X@82!43%,@8V]N;F5C=&EO;B!T;R!A"B`@("`@("`@("`@
M("`J(&YO;BUS96-U<F5D('!O<G0N("!3964@:'1T<#HO+V)U9W,N<&AP+FYE
M="]B=6<N<&AP/VED/3(V,#0P("HO"B`@("`@("`@("`@(&EF("@A9G5N8W1I
M;VY?97AI<W1S*"=S=')E86U?<V]C:V5T7V5N86)L95]C<GEP=&\G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&\@
M=7-E(&$@5$Q3(&-O;FYE8W1I;VXL('EO=2!M=7-T(&)E(')U;FYI;F<@82!V
M97)S:6]N(&]F(%!(4"`U+C$N,"!O<B!H:6=H97(N(BDL("=H;W)D92YE<G)O
M<B<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/E]U<V5T;',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T
M97,@82!N97<@24U!4"!S97-S:6]N($E$(&)Y(&EN8W)E;65N=&EN9R!T:&4@
M;&%S="!O;F4@=7-E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@24U!4"!S97-S:6]N(&ED
M(&]F('1H92!F;W)M("=!,#`P)RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M;F5R871E4VED*"D*("`@('L*("`@("`@("!R971U<FX@<W!R:6YT9B@B024P
M,V0B+"`D=&AI<RT^7W-E<W-I;VYI9"LK*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%!E<F9O<FT@82!C;VUM86YD(&]N('1H92!)34%0('-E<G9E<BX*("`@
M("`J(%1H:7,@8V]M;6%N9"!S971S('1H92`D7W)E<W!O;G-E(&%N9"`D7VUE
M<W-A9V4@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@($E-05`@8V]M
M;6%N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2971U<FYS(%!%
M05)?17)R;W(@;VX@97)R;W(N("!/;B!S=6-C97-S+"!R971U<FYS(&%N"B`@
M("`@*B`@("`@("`@("`@("`@("!A<G)A>2!O9B!T:&4@24U!4"!R971U<FX@
M=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)U;D-O;6UA;F0H)'%U97)Y
M*0H@("`@>PH@("`@("`@("1M97-S86=E(#T@)')E<W!O;G-E(#T@87)R87DH
M*3L*"B`@("`@("`@)'-I9"`]("1T:&ES+3Y?9V5N97)A=&53:60H*3L*("`@
M("`@("!F=W)I=&4H)'1H:7,M/E]S=')E86TL("1S:60@+B`G("<@+B`D<75E
M<GD@+B`B7')<;B(I.PH@("`@("`@("1T86=?=6ED7V$@/2!E>'!L;V1E*"<@
M)RP@=')I;2@D<VED*2D["B`@("`@("`@)'1A9R`]("1T86=?=6ED7V%;,%T[
M"@H@("`@("`@("1R97,@/2`D=&AI<RT^7W)E=')I979E24U!4%)E<W!O;G-E
M*"1T86<L("1R97-P;VYS92P@)&UE<W-A9V4I.PH@("`@("`@(&EF("AI<U]A
M*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]M
M97-S86=E(#T@)'1H:7,M/E]R97-P;VYS92`]("<G.PH@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("\J(')E=')I979E('1H
M92!R97-P;VYS92!A;F0@=&AE(&UE<W-A9V4@*B\*("`@("`@("`D=&AI<RT^
M7W)E<W!O;G-E(#T@)')E<W!O;G-E6R1T86==.PH@("`@("`@("1T:&ES+3Y?
M;65S<V%G92`@/2`D;65S<V%G95LD=&%G73L*"B`@("`@("`@<F5T=7)N("@A
M96UP='DH)')E<ULD=&%G72DI(#\@)')E<ULD=&%G75LP72`Z("1R97-;)'1A
M9UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#=7-T;VT@9F=E=',@9G5N8W1I
M;VX@+2!G970@82!L:6YE(&9R;VT@=&AE($E-05`@<V5R=F5R(&YO(&UA='1E
M<B!H;W<*("`@("`J(&QA<F=E('1H92!L:6YE(&UA>2!B92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&YE>'0@;&EN92!I;B!T:&4@24U!4"!S=')E86TN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]F9V5T<R@I"B`@("!["B`@("`@("`@)&)U9F9E
M<B`](#0P.38["B`@("`@("`@)&]F9G-E="`](#`["B`@("`@("`@)')E<W5L
M=',@/2`G)SL*"B`@("`@("`@=VAI;&4@*'-T<G!O<R@D<F5S=6QT<RP@(EQR
M7&XB+"`D;V9F<V5T*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@:68@*"$H
M)')E860@/2!F9V5T<R@D=&AI<RT^7W-T<F5A;2P@)&)U9F9E<BDI*2!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT<R`]("<G.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1R97-U;'1S
M("$]("<G*2!["B`@("`@("`@("`@("`@("`D;V9F<V5T(#T@<W1R;&5N*"1R
M97-U;'1S*2`M(#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L
M=',@+CT@)')E860["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L
M=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!T:&4@;W5T<'5T(&9R
M;VT@=&AE($E-05`@<W1R96%M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A9R`@("`@(%1H
M92!)34%0(%-)1"!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)')E<W!O;G-E
M("!4:&4@<F5S<&]N<V4@:6YF;W)M871I;VXN"B`@("`@*B!`<&%R86T@87)R
M87D@)&UE<W-A9V4@("!4:&4@;65S<V%G92!I;F9O<FUA=&EO;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!014%27T5R<F]R(&]N(&5R<F]R+"!R
M97-P;VYS92!S=')I;F<@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W)E=')I979E24U!4%)E<W!O;G-E*"1T86<L("8D<F5S<&]N<V4L("8D
M;65S<V%G92D*("`@('L*("`@("`@("`D85)E<W!O;G-E(#T@)')E860@/2`G
M)SL*("`@("`@("`D9&%T82`]("1R97-U;'1L:7-T(#T@87)R87DH*3L*("`@
M("`@("`D:2`](#`["@H@("`@("`@("1R96%D(#T@)'1H:7,M/E]F9V5T<R@I
M.PH@("`@("`@('=H:6QE("@D<F5A9"D@>PH@("`@("`@("`@("`D8VAA<B`]
M("1R96%D>S!].PH@("`@("`@("`@("!S=VET8V@@*"1C:&%R*2!["B`@("`@
M("`@("`@(&-A<V4@)RLG.@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@)')E860@/2`D=&AI<RT^7V9G971S*"D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)'1A9WLP?3H*("`@("`@
M("`@("`@("`@("\J($=E="!T:&4@8V]M;6%N9"X@*B\*("`@("`@("`@("`@
M("`@("1A<F<@/2`G)SL*("`@("`@("`@("`@("`@("1I(#T@<W1R;&5N*"1T
M86<I("L@,3L*("`@("`@("`@("`@("`@("1S(#T@<W5B<W1R*"1R96%D+"`D
M:2D["B`@("`@("`@("`@("`@("!I9B`H*"1J(#T@<W1R<&]S*"1S+"`G("<I
M*2!\?"`H)&H@/2!S=')P;W,H)',L(")<;B(I*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1A<F<@/2!S=6)S='(H)',L(#`L("1J*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1F;W5N9%]T86<@/2!S=6)S='(H)')E
M860L(#`L("1I("T@,2D["B`@("`@("`@("`@("`@("!I9B`H)&9O=6YD7W1A
M9RD@>PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS95LD9F]U;F1?=&%G
M72`]("1A<F<["B`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V5;)&9O=6YD
M7W1A9UT@/2!T<FEM*'-U8G-T<B@D<F5A9"P@)&D@*R!S=')L96XH)&%R9RDI
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1D871A*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT;&ES=%M=(#T@)&1A=&$[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1A
M4F5S<&]N<V5;)&9O=6YD7W1A9UT@/2`D<F5S=6QT;&ES=#L*("`@("`@("`@
M("`@("`@("`@("`D9&%T82`]("1R97-U;'1L:7-T(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&9O=6YD7W1A9R`]/2`D=&%G*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K(#(["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1R96%D(#T@)'1H:7,M/E]F9V5T
M<R@I.PH@("`@("`@("`@("`@("`@:68@*"1R96%D(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K(#([("\J('-W:71C:"!W:&EL92`J
M+PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("<J)SH*("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7EPJ7'-<9"M<<T9%5$-(+R<L("1R96%D*2D@>PH@("`@("`@
M("`@("`@("`@("`@("\J(&-H96-K(&9O<B!L:71E<F%L("HO"B`@("`@("`@
M("`@("`@("`@("`@)',@/2!S=6)S='(H)')E860L("TS*3L*("`@("`@("`@
M("`@("`@("`@("`D9F5T8VA?9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@9&\@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!/=71E
M<B!L;V]P.B!C;VYT:6YU92!U;G1I;"!N97AT('5N=&%G9V5D(&9E=&-H"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]R('1A9V=E9"!R97!O;G-E+B`J
M+PH@("`@("`@("`@("`@("`@("`@("`@("!D;R!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O*B!);FYE<FQO;W`@9F]R(&9E=&-H:6YG(&QI=&5R
M86QS+B!W:71H('1H:7,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&QO;W`@=V4@<')O:&EB:70@=&AA="!L:71E<F%L(')E<W!O;G-E<R!A<'!E
M87(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN('1H92!O=71E
M<B!L;V]P('-O('=E(&-A;B!T<G5S="!T:&4@=6YT86=G960*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%N9"!T86=G960@:6YF;R!P<F]V:61E
M9"!B>2`D<F5A9"X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D<R`]/3T@(GU<<EQN(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1J(#T@<W1R<G!O<R@D<F5A9"P@)WLG*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:4QI="`]('-U8G-T<B@D<F5A9"P@)&H@
M*R`Q+"`M,RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9E
M=&-H7V1A=&%;72`]("1R96%D.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S3&ET97)A;"`](&9R96%D*"1T:&ES+3Y?<W1R96%M+"`D:4QI
M="D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1S3&ET
M97)A;"`]/3T@9F%L<V4I('L@+RH@97)R;W(@*B\*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L@-#L@+RH@=VAI;&4@=VAI;&4@
M<W=I=&-H('=H:6QE("HO"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\J(&)A8VMW
M87)D<R!C;VUP871T:6)I;&ET>2`J+PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A3&ET97)A;"`](&5X<&QO9&4H(EQN(BP@)'-,:71E<F%L
M*3L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'-,
M:71E<F%L*3L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&%,:71E<F%L(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F971C:%]D871A6UT@/2`D;&EN92`N(EQN
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1A3&ET97)A;"D["@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\J($YE>'0@9F=E=',@
M8F5L;VYG<R!T;R!T:&ES(&9E=&-H(&)E8V%U<V4*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!W92!J=7-T(&=O="!T:&4@97AA8W0@;&ET
M97)A;'-I>F4@86YD(&1A=&$*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!M=7-T(&9O;&QO=R!T;R!C;VUP;&5T92!T:&4@<F5S<&]N<V4N
M("HO"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E860@/2`D
M=&AI<RT^7V9G971S*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1R96%D(#T]/2!F86QS92D@>R`O*B!E<G)O<B`J+PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:R`T.R`O*B!W:&EL
M92!W:&EL92!S=VET8V@@=VAI;&4@*B\*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9F5T8VA?9&%T85M=(#T@)')E
M860["@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+RH@4F5T<FEE=F4@
M;F5X="!L:6YE(&%N9"!C:&5C:R!I;B!T:&4@=VAI;&4*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T871E;65N=',@:68@:70@8F5L;VYG<R!T
M;R!T:&ES(&9E=&-H"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M97-P;VYS92X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96%D
M(#T@)'1H:7,M/E]F9V5T<R@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1R96%D(#T]/2!F86QS92D@>R`O*B!E<G)O<B`J+PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K(#0[("\J('=H:6QE('=H
M:6QE('-W:71C:"!W:&EL92`J+PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+RH@0VAE8VL@9F]R
M(&YE>'0@=6YT86=G960@<F5P;VYS92!A;F0@8G)E86LN("HO"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)')E861[,'T@/3T@)RHG*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L@,CL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S(#T@<W5B<W1R*"1R96%D+"`M,RD["B`@("`@("`@("`@("`@
M("`@("`@("`@('T@=VAI;&4@*"1S(#T]/2`B?5QR7&XB*3L*"B`@("`@("`@
M("`@("`@("`@("`@("`@("1S(#T@<W5B<W1R*"1R96%D+"TS*3L*("`@("`@
M("`@("`@("`@("`@("!]('=H:6QE("@H)')E861[,'T@(3T]("<J)RD@)B8*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H<W5B<W1R*"1R96%D+"`P
M+"!S=')L96XH)'1A9RDI("$]/2`D=&%G*2D["@H@("`@("`@("`@("`@("`@
M("`@("1R97-U;'1L:7-T6UT@/2`D9F5T8VA?9&%T83L*("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D9F5T8VA?9&%T82D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1S(#T@<W5B<W1R*"1R96%D
M+"`M,RD["B`@("`@("`@("`@("`@("`@("`@9&\@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H)',@/3T](")]7')<;B(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1J(#T@<W1R<G!O<R@D<F5A9"P@)WLG*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I3&ET(#T@<W5B<W1R*"1R96%D
M+"`D:B`K(#$L("TS*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M871A6UT@/2`D<F5A9#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M3&ET97)A;"`](&9R96%D*"1T:&ES+3Y?<W1R96%M+"`D:4QI="D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'-,:71E<F%L(#T]/2!F86QS
M92D@>R`O*B!E<G)O<B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R96%D(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L@,SL@+RH@=VAI;&4@<W=I=&-H('=H:6QE("HO"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&%T85M=(#T@)'-,:71E<F%L.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1A=&%;72`]("1T:&ES+3Y?9F=E=',H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D871A6UT@/2`D<F5A9#L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5A9"`]("1T:&ES
M+3Y?9F=E=',H*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R96%D
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L@,SL@+RH@=VAI;&4@<W=I=&-H('=H:6QE("HO"B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("@D<F5A9'LP?2`]/2`G*B<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1S(#T@<W5B<W1R
M*"1R96%D+"TS*3L*("`@("`@("`@("`@("`@("`@("!]('=H:6QE("@D<R`]
M/3T@(GU<<EQN(BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@17)R;W(@<')O8V5S<VEN9R!I
M;B!C87-E("1R96%D(&ES(&9A;'-E+B`J+PH@("`@("`@(&EF("@D<F5A9"`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@+RH@5')Y('1O(')E=')I979E(&%N
M('5N=&%G9V5D(&)Y92!R97-P;VYS(&9R;VT@=&AE(')E<W5L=',N("HO"B`@
M("`@("`@("`@("1S4F5S<&]N<V4@/2!A<G)A>5]P;W`H)&1A=&$I.PH@("`@
M("`@("`@("!I9B`H*"1S4F5S<&]N<V4@(3T]($Y53$PI("8F"B`@("`@("`@
M("`@("`@("`H<W1R<&]S*"1S4F5S<&]N<V4L)RH@0EE%)RD@(3T](&9A;'-E
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B24U!4"!S97)V97(@8VQO<V5D('1H92!C;VYN96-T:6]N+B(I+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O;FYE8W1I;VX@9')O
M<'!E9"!B>2!)34%0('-E<G9E<BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)')E<W!O;G-E
M6R1T86==*2!["B`@("`@("`@8V%S92`G3TLG.@H@("`@("`@("`@("!R971U
M<FX@)&%297-P;VYS93L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)TY/)SH*("`@("`@("`@("`@+RH@26=N;W)E('1H:7,@97)R;W(@9G)O
M;2!-)"!E>&-H86YG92P@:70@:7,@;F]T(&9A=&%L("AA:V$@8G5G*2X@*B\*
M("`@("`@("`@("`@:68@*'-T<G-T<B@D;65S<V%G95LD=&%G72P@)V-O;6UA
M;F0@<F5S=6QT960@:6XG*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T
M(&-O;7!L971E(')E<75E<W0N(%)E87-O;B!':79E;CH@)7,B*2P@)&UE<W-A
M9V5;)'1A9UTI+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL+"`D<F5S<&]N
M<V5;)'1A9UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E("="040G.@H@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(D)A9"!O<B!M86QF;W)M960@<F5Q=65S
M="X@4V5R=F5R(%)E<W!O;F1E9#H@)7,B*2P@)&UE<W-A9V5;)'1A9UTI+"`G
M:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL+"`D<F5S<&]N<V5;)'1A9UTI.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G0EE%)SH*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*"))34%0
M(%-E<G9E<B!C;&]S960@=&AE(&-O;FYE8W1I;VXN(%-E<G9E<B!297-P;VYD
M960Z("5S(BDL("1M97-S86=E6R1T86==*2P@)VAO<F1E+F5R<F]R)RP@;G5L
M;"P@;G5L;"P@)')E<W!O;G-E6R1T86==*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YK;F]W;B!)34%0(')E<W!O;G-E(&9R
M;VT@=&AE('-E<G9E<BX@4V5R=F5R(%)E<W!O;F1E9#H@)7,B*2P@)&UE<W-A
M9V5;)'1A9UTI+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL+"`D<F5S<&]N
M<V5;)'1A9UTI.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T<R!T;R!T:&4@24U!4"!S97)V97(N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L(%!%05)?
M17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&53
M=')E86TH*0H@("`@>PH@("`@("`@(&EF("@H)'1H:7,M/E]U<V5S<VP@?'P@
M)'1H:7,M/E]U<V5T;',I("8F"B`@("`@("`@("`@("%5=&EL.CIE>'1E;G-I
M;VY%>&ES=',H)V]P96YS<VPG*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*"))9B!U<VEN9R!34TP@;W(@5$Q3+"!Y;W4@;75S
M="!H879E('1H92!02%`@;W!E;G-S;"!E>'1E;G-I;VX@;&]A9&5D+B(I+"`G
M:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5S(#T@
M)'1H:7,M/E5S951,4R@I*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]H;W-T(#T@)'1H:7,M/E]H;W-T("X@)SHG("X@)'1H:7,M/E]P;W)T.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]U
M<V5S<VPI('L*("`@("`@("`@("`@)'1H:7,M/E]H;W-T(#T@)W-S;#HO+R<@
M+B`D=&AI<RT^7VAO<W0["B`@("`@("`@?0H@("`@("`@("1E<G)O<E]N=6UB
M97(@/2`D97)R;W)?<W1R:6YG(#T@)R<["B`@("`@("`@)'1I;65O=70@/2`Q
M,#L*"B`@("`@("`@:68@*"1T:&ES+3Y?=7-E=&QS*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<W1R96%M(#T@<W1R96%M7W-O8VME=%]C;&EE;G0H)'1H:7,M
M/E]H;W-T+"`D97)R;W)?;G5M8F5R+"`D97)R;W)?<W1R:6YG+"`D=&EM96]U
M="D["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]S=')E86TI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M17)R;W(@8V]N;F5C=&EN9R!T;R!)34%0('-E<G9E<BX@)7,@.B`E<RXB*2P@
M)&5R<F]R7VYU;6)E<BP@)&5R<F]R7W-T<FEN9RDL("=H;W)D92YE<G)O<B<I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!$:7-R96=A<F0@86YY
M('-E<G9E<B!I;F9O<FUA=&EO;B!R971U<FYE9"X@*B\*("`@("`@("`@("`@
M9F=E=',H)'1H:7,M/E]S=')E86TL(#$P,C0I.PH*("`@("`@("`@("`@+RH@
M4V5N9"!T:&4@4U1!4E143%,@8V]M;6%N9"X@*B\*("`@("`@("`@("`@9G=R
M:71E*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E;F5R871E4VED*"D@+B`B
M(%-405)45$Q37')<;B(I.PH*("`@("`@("`@("`@+RH@1&ES<F5G87)D(&%N
M>2!S97)V97(@:6YF;W)M871I;VX@<F5T=7)N960N("HO"B`@("`@("`@("`@
M(&9G971S*"1T:&ES+3Y?<W1R96%M+"`Q,#(T*3L*"B`@("`@("`@("`@("\J
M(%-W:71C:"!O=F5R('1O(&$@5$Q3(&-O;FYE8W1I;VXN("HO"B`@("`@("`@
M("`@("1R97,@/2!S=')E86U?<V]C:V5T7V5N86)L95]C<GEP=&\H)'1H:7,M
M/E]S=')E86TL('1R=64L(%-44D5!35]#4EE05$]?34542$]$7U1,4U]#3$E%
M3E0I.PH@("`@("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!O<&5N('-E
M8W5R92!C;VYN96-T:6]N('1O('1H92!)34%0('-E<G9E<BX@)7,@.B`E<RXB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-T<F5A;2`](&9S;V-K;W!E;B@D
M=&AI<RT^7VAO<W0L("1T:&ES+3Y?<&]R="P@)&5R<F]R7VYU;6)E<BP@)&5R
M<F]R7W-T<FEN9RP@)'1I;65O=70I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1&\@<V]M92!E<G)O<B!C;W)R96-T:6]N("HO"B`@("`@("`@:68@*"$D=&AI
M<RT^7W-T<F5A;2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(D5R<F]R(&-O;FYE8W1I;F<@=&\@24U!4"!S97)V
M97(N("5S(#H@)7,N(BDL("1E<G)O<E]N=6UB97(L("1E<G)O<E]S=')I;F<I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J($1I<W)E
M9V%R9"!A;GD@<V5R=F5R(&EN9F]R;6%T:6]N+B`J+PH@("`@("`@(&9G971S
M*"1T:&ES+3Y?<W1R96%M+"`Q,#(T*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($QO9R!T:&4@=7-E<B!I;G1O('1H92!)34%0('-E<G9E<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92!U<V5R(&YA;64*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A<W-W;W)D(&5N8W)Y<'1E9"!P87-S=V]R9`H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@
M4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G
M:6XH)'5S97)N86UE+"`D<&%S<W=O<F0I"B`@("!["B`@("`@("`@)')E<R`]
M("1T:&ES+3Y?8W)E871E4W1R96%M*"D["B`@("`@("`@:68@*&ES7V$H)')E
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@D<F5S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@
M)&EM87!?875T:%]M96-H(#T@)VQO9VEN)SL*"B`@("`@("`@+R\@3F\@;F5E
M9"!T;R!U<V4@<W!E8VEA;"!A=71H96YT:6-A=&EO;B!I9B!W92!A<F4@86QR
M96%D>2!U<VEN9R!A;@H@("`@("`@("\O(&5N8W)Y<'1E9"!C;VYN96-T:6]N
M+@H@("`@("`@("\O($5L<V4L(&%U=&]D971E8W0@=&AE(&)E<W0@8V]N;F5C
M=&EO;B!M96-H86YI<VTN"B`@("`@("`@)&%U=&A?;65T:&]D<R`]("1T:&ES
M+3YQ=65R>4-A<&%B:6QI='DH)T%55$@G*3L*("`@("`@("!I9B`H)'1H:7,M
M/G%U97)Y0V%P86)I;&ET>2@G3$]'24Y$25-!0DQ%1"<I('Q\"B`@("`@("`@
M("`@("@A96UP='DH)&%U=&A?;65T:&]D<RD@)B8*("`@("`@("`@("`@("%I
M;E]A<G)A>2@G3$]'24XG+"`D875T:%]M971H;V1S*2DI('L*("`@("`@("`@
M("`@)&EM87!?875T:%]M96-H(#T@*&EN7V%R<F%Y*"=03$%)3B<L("1A=71H
M7VUE=&AO9',I*2`_("=P;&%I;B<@.B`G)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("@H(21T:&ES+3Y?=7-E<W-L('Q\("$D=&AI<RT^7W5S971L<RD@)B8@
M(65M<'1Y*"1A=71H7VUE=&AO9',I*2!["B`@("`@("`@("`@(&EF("AI;E]A
M<G)A>2@G0U)!32U-1#4G+"`D875T:%]M971H;V1S*2D@>PH@("`@("`@("`@
M("`@("`@)&EM87!?875T:%]M96-H(#T@)V-R86TM;60U)SL*("`@("`@("`@
M("`@?2!E;'-E:68@*&EN7V%R<F%Y*"=$24=%4U0M340U)RP@)&%U=&A?;65T
M:&]D<RDI('L*("`@("`@("`@("`@("`@("1I;6%P7V%U=&A?;65C:"`]("=D
M:6=E<W0M;60U)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*"@D:6UA<%]A=71H7VUE8V@@/3T@)V-R86TM;60U)RD@?'P*("`@("`@
M("`@("`@*"1I;6%P7V%U=&A?;65C:"`]/2`G9&EG97-T+6UD-2<I*2!["B`@
M("`@("`@("`@("\J($EF('=E(&1O;B=T(&AA=F4@075T:%]305-,('!A8VMA
M9V4@:6YS=&%L;"P@<F5T=7)N(&5R<F]R+B`J+PH@("`@("`@("`@("!I9B`H
M(4!I;F-L=61E7V]N8V4@)T%U=&@O4T%33"YP:'`G*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#4D%-+4U$-2!O<B!$
M24=%4U0M340U(')E<75I<F5S('1H92!!=71H7U-!4TP@<&%C:V%G92!T;R!B
M92!I;G-T86QL960N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=&%G(#T@)'1H:7,M/E]G96YE<F%T95-I9"@I.PH@
M("`@("`@("`@("!F=W)I=&4H)'1H:7,M/E]S=')E86TL("1T86<@+B`G($%5
M5$A%3E1)0T%412`G("X@<W1R=&]U<'!E<B@D:6UA<%]A=71H7VUE8V@I("X@
M(EQR7&XB*3L*("`@("`@("`@("`@)&-H86QL96YG92`](&5X<&QO9&4H)R`G
M+"`D=&AI<RT^7V9G971S*"DL(#,I.PH*("`@("`@("`@("`@:68@*"1I;6%P
M7V%U=&A?;65C:"`]/2`G8W)A;2UM9#4G*2!["B`@("`@("`@("`@("`@("`D
M875T:%]S87-L(#T@075T:%]305-,.CIF86-T;W)Y*"=C<F%M;60U)RD["B`@
M("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D875T:%]S87-L+3YG971297-P
M;VYS92@D=7-E<FYA;64L("1P87-S=V]R9"P@8F%S938T7V1E8V]D92@D8VAA
M;&QE;F=E6S%=*2D["B`@("`@("`@("`@("`@("!F=W)I=&4H)'1H:7,M/E]S
M=')E86TL(&)A<V4V-%]E;F-O9&4H)')E<W!O;G-E*2`N(")<<EQN(BD["B`@
M("`@("`@("`@("`@("`D<F5A9"`]("1T:&ES+3Y?9F=E=',H*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1I;6%P7V%U=&A?;65C:"`]/2`G9&EG97-T+6UD
M-2<I('L*("`@("`@("`@("`@("`@("1A=71H7W-A<VP@/2!!=71H7U-!4TPZ
M.F9A8W1O<GDH)V1I9V5S=&UD-2<I.PH@("`@("`@("`@("`@("`@)')E<W!O
M;G-E(#T@)&%U=&A?<V%S;"T^9V5T4F5S<&]N<V4H)'5S97)N86UE+"`D<&%S
M<W=O<F0L(&)A<V4V-%]D96-O9&4H)&-H86QL96YG95LQ72DL("1T:&ES+3Y?
M:&]S="P@)VEM87`G*3L*("`@("`@("`@("`@("`@(&9W<FET92@D=&AI<RT^
M7W-T<F5A;2P@8F%S938T7V5N8V]D92@D<F5S<&]N<V4I("X@(EQR7&XB*3L*
M("`@("`@("`@("`@("`@("1R97-P;VYS92`](&5X<&QO9&4H)R`G+"`D=&AI
M<RT^7V9G971S*"DI.PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@8F%S
M938T7V1E8V]D92@D<F5S<&]N<V5;,5TI.PH@("`@("`@("`@("`@("`@:68@
M*'-T<G!O<R@D<F5S<&]N<V4L("=R<W!A=71H/2<I(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\@1&EG97-T+4U$
M-2!R97-P;VYS92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!F=W)I=&4H)'1H:7,M/E]S=')E86TL(")<
M<EQN(BD["B`@("`@("`@("`@("`@("`D<F5A9"`]("1T:&ES+3Y?9F=E=',H
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E1H92!)34%0('-E<G9E<B!D;V5S(&YO
M="!A<'!E87(@=&\@<W5P<&]R="!T:&4@875T:&5N=&EC871I;VX@;65T:&]D
M('-E;&5C=&5D+B!0;&5A<V4@8V]N=&%C="!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS96EF("@D:6UA<%]A=71H7VUE8V@@/3T@)VQO9VEN)RD@>PH@
M("`@("`@("`@("`D=&%G(#T@)'1H:7,M/E]G96YE<F%T95-I9"@I.PH@("`@
M("`@("`@("`D<75E<GD@/2`D=&%G("X@(B!,3T=)3B`D=7-E<FYA;64@>R(@
M+B!S=')L96XH)'!A<W-W;W)D*2`N(")]7')<;B(["B`@("`@("`@("`@(&9W
M<FET92@D=&AI<RT^7W-T<F5A;2P@)'%U97)Y*3L*("`@("`@("`@("`@)')E
M860@/2`D=&AI<RT^7V9G971S*"D["B`@("`@("`@("`@(&EF("AS=6)S='(H
M)')E860L(#`L(#$I(#T]("<K)RD@>PH@("`@("`@("`@("`@("`@9G=R:71E
M*"1T:&ES+3Y?<W1R96%M+"`B)'!A<W-W;W)D7')<;B(I.PH@("`@("`@("`@
M("`@("`@)')E860@/2`D=&AI<RT^7V9G971S*"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O($Q/1TE.
M(&-O;6UA;F0N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E:68@*"1I;6%P7V%U=&A?;65C:"`]/2`G<&QA:6XG*2![
M"B`@("`@("`@("`@("1T86<@/2`D=&AI<RT^7V=E;F5R871E4VED*"D["B`@
M("`@("`@("`@("1S87-L(#T@)'1H:7,M/G%U97)Y0V%P86)I;&ET>2@G4T%3
M3"U)4B<I.PH@("`@("`@("`@("`D875T:"`](&)A<V4V-%]E;F-O9&4H(B1U
M<V5R;F%M95PP)'5S97)N86UE7#`D<&%S<W=O<F0B*3L*("`@("`@("`@("`@
M:68@*"1S87-L*2!["B`@("`@("`@("`@("`@("`O+R!)34%0($5X=&5N<VEO
M;B!F;W(@4T%33"!);FET:6%L($-L:65N="!297-P;VYS90H@("`@("`@("`@
M("`@("`@+R\@/&1R869T+7-I96UB;W)S:VDM:6UA<"US87-L+6EN:71I86PM
M<F5S<&]N<V4M,#%B+G1X=#X*("`@("`@("`@("`@("`@("1Q=65R>2`]("1T
M86<@+B`B($%55$A%3E1)0T%412!03$%)3B`D875T:%QR7&XB.PH@("`@("`@
M("`@("`@("`@9G=R:71E*"1T:&ES+3Y?<W1R96%M+"`D<75E<GDI.PH@("`@
M("`@("`@("`@("`@)')E860@/2`D=&AI<RT^7V9G971S*"D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<75E<GD@/2`D=&%G("X@
M(B!!551(14Y424-!5$4@4$Q!24Y<<EQN(CL*("`@("`@("`@("`@("`@(&9W
M<FET92@D=&AI<RT^7W-T<F5A;2P@)'%U97)Y*3L*("`@("`@("`@("`@("`@
M("1R96%D(#T@)'1H:7,M/E]F9V5T<R@I.PH@("`@("`@("`@("`@("`@:68@
M*'-U8G-T<B@D<F5A9"P@,"P@,2D@/3T@)RLG*2!["B`@("`@("`@("`@("`@
M("`@("`@9G=R:71E*"1T:&ES+3Y?<W1R96%M+"`B)&%U=&A<<EQN(BD["B`@
M("`@("`@("`@("`@("`@("`@)')E860@/2`D=&AI<RT^7V9G971S*"D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\@05542$5.5$E#051%(&-O;6UA;F0N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B3F\@<W5P<&]R=&5D($E-05`@875T:&5N=&EC871I;VX@;65T
M:&]D(&-O=6QD(&)E(&9O=6YD+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("!]"@H@("`@("`@("\J($-H96-K(&9O<B!F86EL960@;&]G:6XN("HO"B`@
M("`@("`@)')E<W5L=',@/2!E>'!L;V1E*"<@)RP@)')E860L(#,I.PH@("`@
M("`@("1R97-P;VYS92`]("1R97-U;'1S6S%=.PH*("`@("`@("!I9B`H)')E
M<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@)&UE<W-A9V4@/2`A96UP
M='DH)')E<W5L='-;,ETI(#\@:'1M;'-P96-I86QC:&%R<R@D<F5S=6QT<ULR
M72D@.B!?*").;R!M97-S86=E(')E='5R;F5D+B(I.PH*("`@("`@("`@("`@
M<W=I=&-H("@D<F5S<&]N<V4I('L*("`@("`@("`@("`@8V%S92`G3D\G.@H@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")"860@;&]G:6X@;F%M92!O<B!P87-S=V]R9"XB*2P@)&UE<W-A9V4I
M+"`G:&]R9&4N97)R;W(G*3L*"B`@("`@("`@("`@(&-A<V4@)T)!1"<Z"B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D)A9"!R97%U97-T.B`E<RXB*2P@
M)&UE<W-A9V4I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!,;V<@;W5T(&]F('1H92!)34%0('-E<W-I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QO9V]U="@I"B`@("!["B`@("`@("`@+RH@3&]G;W5T(&ES
M(&YO="!V86QI9"!U;G1I;"!T:&4@<V5R=F5R(')E='5R;G,@)T)912<*("`@
M("`@("`@*B!)9B!W92!D;VXG="!H879E(&%N(&EM87!?('-T<F5A;2!W92=R
M92!A;')E861Y(&QO9V=E9"!O=70@*B\*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]S=')E86TI("8F("1T:&ES+3Y?<W1R96%M*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<G5N0V]M;6%N9"@G3$]'3U54)RD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T('1H92!#05!!0DE,2519('-T<FEN9R!F
M<F]M('1H92!)34%0('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-A<&%B:6QI='DH*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7V-A<&%B:6QI='DI*2![
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?8V%P86)I;&ET>2`](&%R<F%Y*"D["B`@("`@("`@)')E860@/2`D=&AI
M<RT^7W)U;D-O;6UA;F0H)T-!4$%"24Q)5%DG*3L*("`@("`@("!I9B`H:7-?
M82@D<F5A9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@D<F5A9"P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@
M("`D8R`](&5X<&QO9&4H)R`G+"!T<FEM*"1R96%D6S!=*2D["B`@("`@("`@
M9F]R("@D:2`](#([("1I(#P@8V]U;G0H)&,I.R`D:2LK*2!["B`@("`@("`@
M("`@("1C87!?;&ES="`](&5X<&QO9&4H)STG+"`D8ULD:5TI.PH@("`@("`@
M("`@("!I9B`H:7-S970H)&-A<%]L:7-T6S%=*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7V-A<&%B:6QI='E;)&-A<%]L:7-T6S!=
M72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-A<&%B:6QI='E;
M)&-A<%]L:7-T6S!=72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-A<&%B:6QI='E;)&-A<%]L:7-T6S!=
M75M=(#T@)&-A<%]L:7-T6S%=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C87!A8FEL:71Y6R1C87!?;&ES=%LP75T@
M/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H92!)34%0('-E<G9E<B!S=7!P
M;W)T<R!T:&4@9VEV96X@8V%P86)I;&ET>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C87!A8FEL:71Y("!4:&4@8V%P86)I;&ET>2!S=')I;F<@
M=&\@<75E<GDN"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("!4<G5E(&EF
M('1H92!S97)V97(@<W5P<&]R=',@=&AE('%U97)I960@8V%P86)I;&ET>2P*
M("`@("`J("`@("`@("`@("`@("`@9F%L<V4@:68@:70@9&]E<VXG="P@;W(@
M86X@87)R87D@:68@=&AE(&-A<&%B:6QI='D@8V%N"B`@("`@*B`@("`@("`@
M("`@("`@(&-O;G1A:6X@;75L=&EP;&4@=F%L=65S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!Q=65R>4-A<&%B:6QI='DH)&-A<&%B:6QI='DI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]C87!A8FEL:71Y*"D["B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1T:&ES+3Y?8V%P86)I;&ET>5LD8V%P86)I;&ET>5TI(#\@)'1H:7,M
M/E]C87!A8FEL:71Y6R1C87!A8FEL:71Y72`Z(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T('1H92!.04U%4U!!0T4@:6YF;W)M871I;VX@9G)O
M;2!T:&4@24U!4"!S97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A9&1I=&EO;F%L("!)9B!T:&4@<V5R=F5R('-U<'!O<G1S(&YA;65S<&%C
M97,L(&%N>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!A9&1I
M=&EO;F%L(&YA;65S<&%C97,@=&\@861D('1O('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N86UE<W!A8V4@;&ES="!T:&%T(&%R92!N
M;W0@8G)O861C87-T(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H92!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M06X@87)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&9O<FUA=#H*("`@("`J(#QP
M<F4^"B`@("`@*B!!<G)A>0H@("`@("H@*`H@("`@("H@("!;9F]O72`]/B!!
M<G)A>0H@("`@("H@("`H"B`@("`@*B`@("`@6VYA;65=(#T^("AS=')I;F<I
M"B`@("`@*B`@("`@6V1E;&EM:71E<ET@/3X@*'-T<FEN9RD*("`@("`J("`@
M("!;='EP95T@/3X@)W!E<G-O;F%L)R!\("=O=&AE<G,G('P@)W-H87)E9"<*
M("`@("`J("`@("!;:&ED9&5N72`]/B`H8F]O;&5A;BD*("`@("`J("`@*0H@
M("`@("H*("`@("`J("`@6V9O;S)=(#T^($%R<F%Y"B`@("`@*B`@("@*("`@
M("`J("`@("`N+BX*("`@("`J("`@*0H@("`@("H@*0H@("`@("H@/"]P<F4^
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YA;65S<&%C92@D861D:71I;VYA;"`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?
M;F%M97-P86-E*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]N86UE
M<W!A8V4["B`@("`@("`@?0H*("`@("`@("`D;F%M97-P86-E7V%R<F%Y(#T@
M87)R87DH"B`@("`@("`@("`@(#$@/3X@)W!E<G-O;F%L)RP*("`@("`@("`@
M("`@,B`]/B`G;W1H97)S)RP*("`@("`@("`@("`@,R`]/B`G<VAA<F5D)PH@
M("`@("`@("D["@H@("`@("`@(&EF("@D=&AI<RT^<75E<GE#87!A8FEL:71Y
M*"=.04U%4U!!0T4G*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@
M*B!!8V-O<F1I;F<@=&\@<F9C,C,T,B!R97-P;VYS92!F<F]M($Y!34534$%#
M12!C;VUM86YD(&ES.@H@("`@("`@("`@("`@*B`J($Y!34534$%#12`H4$52
M4T].04P@3D%-15-004-%4RD@*$]42$527U5315)3($Y!34534$%#12D@*%-(
M05)%1"!.04U%4U!!0T53*0H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@
M)')E860@/2`D=&AI<RT^7W)U;D-O;6UA;F0H)TY!34534$%#12<I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F5A9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E860L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5A9#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&5R
M96=I*"=<7"H@3D%-15-004-%("LH7%PH("I<7"@N*UQ<*2`J7%PI?$Y)3"D@
M*RA<7"@@*EQ<*"XK7%PI("I<7"E\3DE,*2`K*%Q<*"`J7%PH+BM<7"D@*EQ<
M*7Q.24PI)RP@)')E861;,%TL("1D871A*2D@>PH@("`@("`@("`@("`@("`@
M9F]R("@D:2`](#$[("1I(#P](#,[("1I*RLI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&1A=&%;)&E=(#T]("=.24PG*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`D<&YA(#T@97AP;&]D92@G*2@G+"`D9&%T85LD
M:5TI.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("AL:7-T*"1K+"`D=BD@
M/2!E86-H*"1P;F$I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L<W0@
M/2!E>'!L;V1E*"<B)RP@)'8I.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5L:6UI=&5R(#T@*&ES<V5T*"1L<W1;,UTI*2`_("1L<W1;,UT@.B`G)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N86UE<W!A8V5;)&QS
M=%LQ75T@/2!A<G)A>2@G;F%M92<@/3X@)&QS=%LQ72P@)V1E;&EM:71E<B<@
M/3X@)&1E;&EM:71E<BP@)W1Y<&4G(#T^("1N86UE<W!A8V5?87)R87E;)&E=
M+"`G:&ED9&5N)R`]/B!F86QS92D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!F
M;W)E86-H("@D861D:71I;VYA;"!A<R`D=F%L*2!["B`@("`@("`@("`@("`@
M("`O*B!3:VEP(&YA;65S<&%C97,@:68@=V4@:&%V92!A;')E861Y(&%U=&\M
M9&5T96-T960@=&AE;2X*("`@("`@("`@("`@("`@("`J($%L<V\L(&AI9&1E
M;B!N86UE<W!A8V5S(&-A;B!N;W0@8F4@96UP='DN("HO"B`@("`@("`@("`@
M("`@("`D=F%L(#T@=')I;2@D=F%L*3L*("`@("`@("`@("`@("`@(&EF("AE
M;7!T>2@D=F%L*2!\?"!I<W-E="@D=&AI<RT^7VYA;65S<&%C95LD=F%L72DI
M('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1R96%D(#T@)'1H:7,M/E]R=6Y#;VUM
M86YD*"=,25-4("(B("(G("X@)'9A;"`N("<B)RD["B`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<F5A9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R96%D+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1R96%D*2`F)@H@("`@("`@("`@("`@("`@("`@('!R
M96=?;6%T8V@H(B]>7"H@3$E35"!<*"XJ7"D@7"(H+BHI7"(@7"(_*"XJ/RE<
M(C]<<RHD+R(L("1R96%D6S!=+"`D9&%T82D@)B8*("`@("`@("`@("`@("`@
M("`@("`H)&1A=&%;,ET@/3T@)'9A;"DI('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VYA;65S<&%C95LD=F%L72`](&%R<F%Y*"=N86UE)R`]/B`D
M=F%L+"`G9&5L:6UI=&5R)R`]/B`D9&%T85LQ72P@)W1Y<&4G(#T^("1N86UE
M<W!A8V5?87)R87E;,UTL("=H:61D96XG(#T^('1R=64I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)')E<R`]("1T:&ES+3Y?<G5N0V]M;6%N9"@G3$E35"`B(B`B(B<I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("`@
M("!R971U<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<75O
M=&5?<&]S:71I;VX@/2!S=')P;W,H)')E<ULP72P@)R(G*3L*("`@("`@("`@
M("`@)'1H:7,M/E]N86UE<W!A8V5;)R==(#T@87)R87DH)VYA;64G(#T^("<G
M+"`G9&5L:6UI=&5R)R`]/B!S=6)S='(H)')E<ULP72P@)'%U;W1E7W!O<VET
M:6]N("L@,2`L(#$I+"`G='EP92<@/3X@)&YA;65S<&%C95]A<G)A>5LQ72P@
M)VAI9&1E;B<@/3X@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?;F%M97-P86-E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T
M97)M:6YE<R!W:&5T:&5R('1H92!)34%0('-E87)C:"!C;VUM86YD('-U<'!O
M<G1S('1H92!O<'1I;VYA;`H@("`@("H@8VAA<G-E="!P<F]V:61E9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<F%C
M=&5R('-E="!T;R!T97-T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!T:&4@24U!4"!S96%R8V@@8V]M;6%N9"!S=7!P;W)T<R!T
M:&4@8VAA<G-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H0VAA<G-E
M="@D8VAA<G-E="D*("`@('L*("`@("`@("`D=&AI<RT^7W)U;D-O;6UA;F0H
M)U-%3$5#5"!)3D)/6"<I.PH@("`@("`@("1R96%D(#T@)'1H:7,M/E]R=6Y#
M;VUM86YD*"=314%20T@@0TA!4E-%5"`G("X@)&-H87)S970@+B`G(%1%6%0@
M(F-H87)S971T97-T(B`Q)RD["B`@("`@("`@<F5T=7)N("%I<U]A*"1R96%D
M+"`G4$5!4E]%<G)O<B<I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+VQI8B])34%0+U-E87)C:"YP:'``````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-#0W,``Q,#0Q-S,V,C<V-@`P,C`T,S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92`G2&]R9&4O24U!4"]396%R8V@N<&AP)SL*"B\J*@H@
M*B!4:&4@24U07TE-05!?4V5A<F-H.CH@8VQA<W,@97AT96YD<R!T:&4@24U!
M4%]396%R8V@@8VQA<W,@:6X@;W)D97(@=&\*("H@<')O=FED92!N96-E<W-A
M<GD@8G5G(&9I>&5S('1O(&5N<W5R92!B86-K=V%R9',@8V]M<&%T:6)I;&ET
M>2!W:71H($AO<F1E"B`J(#,N,"X*("H*("H@)$AO<F1E.B!I;7`O;&EB+TE-
M05`O4V5A<F-H+G!H<"QV(#$N,R`R,#`V+S`Q+S(X(#`S.C,P.C$Y('-L=7-A
M<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#8@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF
M('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!)35`@-"XQ"B`J($!P86-K86=E($AO<F1E7TE-05`*("HO"F-L87-S
M($E-4%])34%07U-E87)C:"!E>'1E;F1S($E-05!?4V5A<F-H('L*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!R969E<F5N8V4@=&\@=&AE(&=L;V)A;"!)
M35!?24U!4%]396%R8V@@;V)J96-T+"!O;FQY(&-R96%T:6YG"B`@("`@*B!I
M="!I9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N"B`@("`@*@H@("`@("H@
M0'-E92!)34%07U-E87)C:#HZ<VEN9VQE=&]N*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@)G-I;F=L971O;B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!S=&%T:6,@)&]B:F5C=#L*"B`@("`@("`@:68@*"%I<W-E="@D;V)J
M96-T*2D@>PH@("`@("`@("`@("`D;V)J96-T(#T@;F5W($E-4%])34%07U-E
M87)C:"@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V)J
M96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5A<F-H97,@;65S<V%G97,@
M8GD@04Q,(&AE861E<G,@*')A=&AE<B!T:&%N('1H92!L:6UI=&5D('-E="!P
M<F]V:61E9`H@("`@("H@8GD@:6UA<%]S96%R8V@H*2DN"B`@("`@*@H@("`@
M("H@0'-E92!)34%07U-E87)C:#HZ<V5A<F-H36%I;&)O>"@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E87)C:$UA:6QB;W@H)'%U97)Y+"`F)&EM87`L("1M
M8F]X*0H@("`@>PH@("`@("`@("\J($-L96%R('1H92!S96%R8V@@9FQA9RX@
M*B\*("`@("`@("`D=&AI<RT^7W-E87)C:&9L86<@/2`P.PH*("`@("`@("!I
M9B`H)%]315-324].6R=I;7`G75LG8F%S95]P<F]T;V-O;"==("$]("=P;W`S
M)RD@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI
M8B])34%0+G!H<"<["B`@("`@("`@("`@("1I;7!?:6UA<"`]("9)35!?24U!
M4#HZ<VEN9VQE=&]N*"D["B`@("`@("`@("`@("1I;7!?:6UA<"T^8VAA;F=E
M36)O>"@D;6)O>"P@3U!?4D5!1$].3%DI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<V5A<F-H36%I;&)O>"@D<75E<GDL("1I;6%P+"`D
M;6)O>"D["B`@("!]"@I]"@HO*BH*("H@5&AE($E-4%])34%07U-E87)C:%]1
M=65R>3HZ(&-L87-S(&5X=&5N9',@=&AE($E-05!?4V5A<F-H7U%U97)Y(&-L
M87-S(&EN"B`J(&]R9&5R('1O('!R;W9I9&4@;F5C97-S87)Y(&)U9R!F:7AE
M<R!T;R!E;G-U<F4@8F%C:W=A<F1S(&-O;7!A=&EB:6QI='D@=VET:`H@*B!(
M;W)D92`S+C`N"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!H;W)D92YO<F<^"B`J($!S:6YC92`@($E-4"`T+C$*("H@0'!A8VMA
M9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@24U07TE-05!?4V5A<F-H7U%U97)Y
M(&5X=&5N9',@24U!4%]396%R8VA?475E<GD@>PH*("`@("\J*@H@("`@("H@
M0G5I;&1S('1H92!)34%0('-E87)C:"!Q=65R>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8G5I;&0H*0H@("`@>PH@("`@("`@("1S96%R8V@@/2!P87)E;G0Z
M.F)U:6QD*"D["B`@("`@("`@:68@*&5M<'1Y*"1S96%R8V@I*2!["B`@("`@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]O<BDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<V5A<F-H.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1S96%R8V@@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@("`D<V5A<F-H
M+3YF;&%G<R`](&YU;&P["B`@("`@("`@("`@("1S96%R8V@M/FYO="`](&9A
M;'-E.PH@("`@("`@("`@("`D<V5A<F-H+3YF=6QL<75E<GD@/2`D<V5A<F-H
M+3YQ=65R>2`]("=!3$PG.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-E
M87)C:#L*("`@('T*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQI8B])34%0+U1R964N<&AP````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-S(S,``Q,#0Q-S,V,C<V
M-@`P,C`Q,C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O24U!4"]4<F5E+G!H
M<"<["@HO*BH@261E;G1I9GD@86X@96QE;65N="!A<R!A('9I<G1U86P@9F]L
M9&5R+B`J+PID969I;F4H)TE-4%12145?14Q47U9&3TQ$15(G+"`X,3DR*3L*
M"B\J*@H@*B!4:&4@24U07W1R964@8VQA<W,@<')O=FED97,@82!T<F5E('9I
M97<@;V8@=&AE(&9O;&1E<G,@:6X@86X@24U!4"]03U`S"B`J(')E<&]S:71O
M<GDN("!)="!P<F]V:61E<R!A8V-E<W,@9G5N8W1I;VYS('1O(&ET97)A=&4@
M=&AR;W5G:"!T:&ES('1R964@86YD"B`J('%U97)Y(&EN9F]R;6%T:6]N(&%B
M;W5T(&EN9&EV:61U86P@;6%I;&)O>&5S+@H@*@H@*B`D2&]R9&4Z(&EM<"]L
M:6(O24U!4"]4<F5E+G!H<"QV(#$N,C4N,BXS,2`R,#`V+S`R+S`Y(#`U.C4Q
M.C$R('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT
M(#(P,#`M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,C`P,"TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA=G-M0&AO<F1E
M+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@
M>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R("!!;FEL
M($UA9&AA=F%P961D>2`\879S;4!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($E-4"`R+C,*("H@0'!A8VMA9V4@24U0"B`J+PIC;&%S<R!)35!?5')E92!E
M>'1E;F1S($E-05!?5')E92!["@H@("`@+RHJ"B`@("`@*B!-87!P:6YG(&9O
M<B!V:7)T=6%L(&9O;&1E<G,@=&\@=&AE:7(@;&%B96PN"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]V9F]L9&5R<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!<F4@=V4@:6YH97)I=&EN9R!F<F]M
M('1H92!N97<@*&DN92X@2&]R9&4@,RXQ*RD@=F5R<VEO;B!O9B!)34%07U1R
M964_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7VYE=VEM87!T<F5E(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!3:6YG
M;&5T;VX@;65T:&]D+@H@("`@("H@0GD@9&5F875L="P@=&AE('1R964@=VEL
M;"!C;VYT86EN(&]N;'D@8W5R<F5N=&QY('9I97=A8FQE(&ET96US(&%N9`H@
M("`@("H@=VEL;"!B92!S=&]R960@:6X@=&AE('-E<W-I;VX@=6YD97(@)VEM
M<"<N("!(;W=E=F5R+"!I9B!Y;W4@=V]U;&0*("`@("`J(')A=&AE<B!P87-S
M(&1I9F9E<F5N="!P87)A;65T97)S('1O($E-05!?5')E92P@>6]U(&UA>2!D
M96-L87)E(&$*("`@("`J(&=L;V)A;"!V87)I86)L92!N86UE9"`D:6UP7W1R
M965?<VEN9VQE=&]N('=I=&@@=&AE(&%R<F%Y(&]F('!A<F%M971E<G,*("`@
M("`J('EO=2!W86YT('1O('!A<W,@=&\@24U!4%]4<F5E.CIS:6YG;&5T;VXH
M*2X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@("!["B`@
M("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=I;7!?=')E95]S:6YG;&5T;VXG
M72DI('L*("`@("`@("`@("`@<F5T=7)N($E-05!?5')E93HZ<VEN9VQE=&]N
M*"=I;7`G+"`G24U07U1R964G+"!T<G5E*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<F5T(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH
M)TE-05!?5')E92<L("=S:6YG;&5T;VXG*2P@)$=,3T)!3%-;)VEM<%]T<F5E
M7W-I;F=L971O;B==*3L*("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@
M*@H@("`@("H@0'-E92!)34%07U1R964Z.DE-05!?5')E92@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N($E-4%]4<F5E*"1I;FET(#T@24U!4%12145?24Y)5%]3
M54(L("1C86-H96YA;64@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M:6UP.PH*("`@("`@("`D=&AI<RT^7V%P<"`]("=I;7`G.PH@("`@("`@("1T
M:&ES+3Y?;6]D92`]($E-05!44D5%7TU/1$5?34%)3#L*("`@("`@("`D=&AI
M<RT^7W-E<G9E<B`]($E-4#HZ<V5R=F5R4W1R:6YG*"D["@H@("`@("`@(&EF
M("@D:6UP6R=B87-E7W!R;W1O8V]L)UT@(3T@)W!O<#,G*2!["B`@("`@("`@
M("`@("1P='(@/2!R97-E="@D7U-%4U-)3TY;)VEM<"==6R=N86UE<W!A8V4G
M72D["B`@("`@("`@("`@("1T:&ES+3Y?9&5L:6UI=&5R(#T@)'!T<ELG9&5L
M:6UI=&5R)UT["B`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES
M+"`G97AT96YD961.86UE<W!A8V53=7!P;W)T)RDI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;F5W:6UA<'1R964@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]N86UE<W!A8V5S(#T@)%]315-324].6R=I;7`G75LG;F%M
M97-P86-E)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^24U!4&-H:6QD<F5N
M4W5P<&]R="@D7U-%4U-)3TY;)VEM<"==6R=I;6%P7W-E<G9E<B==6R=C:&EL
M9')E;B==*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("\O($)#(&9O<B!(;W)D92`\(#,N,2XP"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1E;&EM:71E<B`]("1P=');)V1E;&EM:71E<B==.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P<F5F:7@@/2`D<'1R6R=N86UE)UT["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ24U!4%]4<F5E*&YU
M;&PI.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI=&%L:7IE<R!T:&4@;&ES
M="!A="!T:&4@=&]P(&QE=F5L(&]F('1H92!H:65R87)C:'DN"B`@("`@*@H@
M("`@("H@0'-E92!)34%07U1R964Z.E]I;FET*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@:6YI="@D:6YI="`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC
M("1A;')E861Y7VEN:70@/2!N=6QL.PH*("`@("`@("`D:6YI=&UA<VL@/2`H
M*"1'3$]"04Q36R=I;7`G75LG8F%S95]P<F]T;V-O;"==(#T]("=P;W`S)RD@
M?'P*("`@("`@("`@("`@("`@("`@("`@(21'3$]"04Q36R=P<F5F<R==+3YG
M971686QU92@G<W5B<V-R:6)E)RD@?'P*("`@("`@("`@("`@("`@("`@("`@
M)$=,3T)!3%-;)VEM<"==6R=S:&]W=6YS=6(G72D*("`@("`@("`@("`@/R!)
M34%05%)%15])3DE47U5.4U5"(#H@24U!4%12145?24Y)5%]354(["B`@("`@
M("`@:68@*"1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G<VAO=U]S:61E
M8F%R)RDI('L*("`@("`@("`@("`@)&EN:71M87-K('P]($E-05!44D5%7TE.
M251?1D540TA!3$P["B`@("`@("`@?0H*("`@("`@("!I9B`H)&%L<F5A9'E?
M:6YI="`]/2`D:6YI=&UA<VLI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1A;')E861Y7VEN:70@/2`D:6YI
M=&UA<VL["B`@("`@("`@?0H@("`@("`@('!A<F5N=#HZ:6YI="@D:6YI=&UA
M<VLI.PH*("`@("`@("`O*B!#;VYV97)T("=)3D)/6"<@=&\@;&]C86QI>F5D
M(&YA;64N("HO"B`@("`@("`@)'1H:7,M/E]T<F5E6R=)3D)/6"==6R=L)UT@
M/2!?*"));F)O>"(I.PH*("`@("`@("`O*B!!9&0@=FER='5A;"!F;VQD97)S
M('1O('1H92!T<F5E+B`J+PH@("`@("`@("1T:&ES+3Y?=F9O;&1E<G,@/2!A
M<G)A>2@I.PH@("`@("`@("1T:&ES+3YI;G-E<G161F]L9&5R<R@D1TQ/0D%,
M4ULG:6UP7W-E87)C:"==+3YL:7-T475E<FEE<RAT<G5E*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!);G-E<G1S('9I<G1U86P@9F]L9&5R<R!I;G1O('1H
M92!T<F5E+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D:61?;&ES="`@
M06X@87)R87D@=VET:"!T:&4@9F]L9&5R($E$<R!T;R!A9&0@87,@=&AE(&ME
M>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!A;F0@=&AE(&QA8F5L
M<R!A<R!T:&4@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN<V5R=%9&
M;VQD97)S*"1I9%]L:7-T*0H@("`@>PH@("`@("`@("1I9"`](&%R<F%Y*"D[
M"B`@("`@("`@9F]R96%C:"`H)&ED7VQI<W0@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@("1I9%M)35!?4T5!4D-(7TU"3U@@+B`D:V5Y72`]("1V
M86P["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]V9F]L
M9&5R<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]V9F]L9&5R<R`]("1I9#L*
M("`@("`@("`@("`@)&ED(#T@87)R87E?;65R9V4H87)R87DH7R@B5FER='5A
M;"!&;VQD97)S(BDI+"!A<G)A>5]K97ES*"1I9"DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?=F9O;&1E<G,@/2!A<G)A>5]M97)G
M92@D=&AI<RT^7W9F;VQD97)S+"`D:60I.PH@("`@("`@("`@("`D:60@/2!A
M<G)A>5]K97ES*"1I9"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VYO
M;FEM87!E;'0@/2!T<G5E.PH@("`@("`@("1T:&ES+3Y?:6YI=&UO9&4@/2!)
M34%05%)%15])3DE47U-50CL*("`@("`@("`D=&AI<RT^:6YS97)T*"1I9"D[
M"B`@("`@("`@)'1H:7,M/E]I;FET;6]D92`](#`["B`@("`@("`@)'1H:7,M
M/E]N;VYI;6%P96QT(#T@9F%L<V4["@H@("`@("`@("\J(%-O<G0@=&AE(%9I
M<G1U86P@1F]L9&5R(&QI<W0@:6X@=&AE(&]B:F5C="P@:68@;F5C97-S87)Y
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7VYE9613;W)T*"1T:&ES+3Y?=')E
M95M?*")6:7)T=6%L($9O;&1E<G,B*5TI*2!["B`@("`@("`@("`@("1V<V]R
M="`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R
M96YT6U\H(E9I<G1U86P@1F]L9&5R<R(I72!A<R`D=F%L*2!["B`@("`@("`@
M("`@("`@("`D=G-O<G1;)'9A;%T@/2`D=&AI<RT^7W1R965;)'9A;%U;)VPG
M73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!N871C87-E<V]R="@D=G-O
M<G0I.PH@("`@("`@("`@("`D=&AI<RT^7W!A<F5N=%M?*")6:7)T=6%L($9O
M;&1E<G,B*5T@/2!A<G)A>5]K97ES*"1V<V]R="D["B`@("`@("`@("`@("1T
M:&ES+3Y?<V5T3F5E9%-O<G0H)'1H:7,M/E]T<F5E6U\H(E9I<G1U86P@1F]L
M9&5R<R(I72P@9F%L<V4I.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG960@
M/2!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-U8F-L
M87-S('-P96-I9FEC(&EN:71I86QI>F%T:6]N('1A<VMS+@H@("`@("H*("`@
M("`J($!S964@24U!4%]4<F5E.CI?:6YI="@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]I;FET*"D*("`@('L*("`@("`@("`D8F]X97,@/2!A<G)A>2@I.PH*
M("`@("`@("!F;W)E86-H("@D7U-%4U-)3TY;)VEM<"==6R=N86UE<W!A8V4G
M72!A<R`D=F%L*2!["B`@("`@("`@("`@("1T;7`@/2`D=&AI<RT^7V=E=$QI
M<W0H)'9A;%LG;F%M92==("X@)R4G*3L*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&UP*2D@>PH@("`@("`@("`@("`@("`@:68@*"1V86Q;)W1Y<&4G72`]
M/2`G<&5R<V]N86PG*2!["B`@("`@("`@("`@("`@("`@("`@+RH@4V]M92!)
M34%0('-E<G9E<G,@<'5T('1H92!)3D)/6"!I;B!T:&4@<&5R<V]N86P*("`@
M("`@("`@("`@("`@("`@("`@*B!N86UE<W!A8V4@+2!I9B!W92!F:6YD(&ET
M(&EN(&AE<F4L('-I;7!L>2!R96YA;64@=&\*("`@("`@("`@("`@("`@("`@
M("`@*B`G24Y"3U@G('-I;F-E+"!P97(@4D9#<RP@=&AE($E.0D]8(&ES(&%L
M=V%Y<R!A8V-E<W-I8FQE"B`@("`@("`@("`@("`@("`@("`@("H@=FEA('1H
M:7,@<W1R:6YG("AA;'1H;W5G:"!I="!M87D@;F]T(&)E(&QI<W1E9"!I;B!T
M:&4*("`@("`@("`@("`@("`@("`@("`@*B!F;VQD97(@;&ES="!U;F1E<B!T
M:&ES('-T<FEN9RX@*B\*("`@("`@("`@("`@("`@("`@("`D:6YB;WA?<W1R
M(#T@)'9A;%LG;F%M92==("X@)TE.0D]8)SL*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'1M<%LD:6YB;WA?<W1R72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1M<"`](&%R<F%Y*"=)3D)/6"<@/3X@)'1M<%LD:6YB
M;WA?<W1R72D@*R`D=&UP.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&UP
M6R=)3D)/6"==+3YN86UE(#T@)TE.0D]8)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)'1M<%LD:6YB;WA?<W1R72D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&)O
M>&5S(#T@87)R87E?;65R9V4H)&)O>&5S+"`D=&UP*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D8F]X97-;)TE.0D]8
M)UTI*2!["B`@("`@("`@("`@("1B;WAE<ULG24Y"3U@G72`]("1T:&ES+3Y?
M9V5T36%I;&)O>"@G24Y"3U@G*3L*("`@("`@("!]"@H@("`@("`@("\J($1O
M(&$@<V]R="!T;R!M86ME('-U<F4@=&AA="`G24Y"3U@G(&%L=V%Y<R!A<'!E
M87)S(&%S('1H92!F:7)S=`H@("`@("`@("`J(&5L96UE;G0N("HO"B`@("`@
M("`@<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]V97)S:6]N+G!H
M<"<["B`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92A(3U)$15]615)324].
M+"`G,RXP+C0G*2`]/2`M,2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-O<G1,
M:7-T*"1B;WAE<RP@=')U92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&)O>&5S.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A;&EA<V5S('1O
M(&$@=')E92!E;&5M96YT(&%N9"!R971U<FYS('1H92!R97-U;'1I;F<@87)R
M87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!T<F5E(&5L96UE;G0@=VET:"!T
M:&4@86QI87-E<R!A9&1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$%L
M:6%S97,H)&5L="D*("`@('L*("`@("`@("`D96QT(#T@<&%R96YT.CI?861D
M06QI87-E<R@D96QT*3L*("`@("`@("!I9B`H)&5L=%LG;&%B96PG72`]/2`G
M24Y"3U@G*2!["B`@("`@("`@("`@("1E;'1;)VQA8F5L)UT@/2!?*"));F)O
M>"(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E;'0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O(&$@8W5R<F5N
M=&QY(&]P96X@24U!4"!S=')E86TN"B`@("`@*@H@("`@("H@0'-E92!)34%0
M7U1R964Z.E]G9713=')E86TH*0H@("`@("HO"B`@("!F=6YC=&EO;B`F7V=E
M=%-T<F5A;2@I"B`@("!["B`@("`@("`@<F5T=7)N("1?4T534TE/3ELG:6UP
M)UU;)W-T<F5A;2==.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA;&EZ
M97,@=&AE(&5X<&%N9&5D(&9O;&1E<B!L:7-T+@H@("`@("H*("`@("`J($!S
M964@24U!4%]4<F5E.CI?:6YI=$5X<&%N9&5D3&ES="@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]I;FET17AP86YD961,:7-T*"D*("`@('L*("`@("`@("!I
M9B`H:7-?;G5L;"@D=&AI<RT^7V5X<&%N9&5D*2D@>PH@("`@("`@("`@("`D
M<V5R:6%L:7IE9"`]("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G97AP
M86YD961?9F]L9&5R<R<I.PH@("`@("`@("`@("`D=&AI<RT^7V5X<&%N9&5D
M(#T@*"1S97)I86QI>F5D*2`_('5N<V5R:6%L:7IE*"1S97)I86QI>F5D*2`Z
M(&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D
M<R!A;B!E;&5M96YT('1O('1H92!E>'!A;F1E9"!L:7-T+@H@("`@("H*("`@
M("`J($!S964@24U!4%]4<F5E.CI?861D17AP86YD961,:7-T*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%D9$5X<&%N9&5D3&ES="@D:60I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I;FET17AP86YD961,:7-T*"D["B`@("`@("`@)'1H
M:7,M/E]E>'!A;F1E9%LD:61=(#T@=')U93L*("`@("`@("`D1TQ/0D%,4ULG
M<')E9G,G72T^<V5T5F%L=64H)V5X<&%N9&5D7V9O;&1E<G,G+"!S97)I86QI
M>F4H)'1H:7,M/E]E>'!A;F1E9"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5M;W9E<R!A;B!E;&5M96YT(&9R;VT@=&AE(&5X<&%N9&5D(&QI<W0N"B`@
M("`@*@H@("`@("H@0'-E92!)34%07U1R964Z.E]R96UO=F5%>'!A;F1E9$QI
M<W0H*0H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5M;W9E17AP86YD961,:7-T
M*"1I9"D*("`@('L*("`@("`@("`D=&AI<RT^7VEN:71%>'!A;F1E9$QI<W0H
M*3L*("`@("`@("!U;G-E="@D=&AI<RT^7V5X<&%N9&5D6R1I9%TI.PH@("`@
M("`@("1'3$]"04Q36R=P<F5F<R==+3YS971686QU92@G97AP86YD961?9F]L
M9&5R<R<L('-E<FEA;&EZ92@D=&AI<RT^7V5X<&%N9&5D*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!);FET:6%L:7IE<R!A;F0@<F5T=7)N<R!T:&4@;&ES
M="!O9B!M86EL8F]X97,@=&\@<&]L;"X@(%1H:7,@;&ES="!I<PH@("`@("H@
M<F5T=7)N960@<V]R=&5D('9I82!)34%07U-O<G0Z.BX*("`@("`J"B`@("`@
M*B!`<V5E($E-05!?5')E93HZ9V5T4&]L;$QI<W0H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9710;VQL3&ES="@I"B`@("!["B`@("`@("`@:68@*&ES7VYU
M;&PH)'1H:7,M/E]P;VQL*2D@>PH@("`@("`@("`@("`O*B!792!!3%=!65,@
M<&]L;"!T:&4@24Y"3U@N("HO"B`@("`@("`@("`@("1T:&ES+3Y?<&]L;"`]
M(&%R<F%Y*"=)3D)/6"<@/3X@,2D["@H@("`@("`@("`@("`O*B!!9&0@=&AE
M('5S97(G<R!L:7-T(&]F('!O;&QE9"!M86EL8F]X97,L(&EF(&YO="!L;V-K
M960N("HO"B`@("`@("`@("`@(&EF("@A)$=,3T)!3%-;)W!R969S)UTM/FES
M3&]C:V5D*"=N879?<&]L;"<I*2!["B`@("`@("`@("`@("`@("`D;F%V4&]L
M;$QI<W0@/2!`=6YS97)I86QI>F4H)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A
M;'5E*"=N879?<&]L;"<I*3L*("`@("`@("`@("`@("`@(&EF("@D;F%V4&]L
M;$QI<W0I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!O;&P@*ST@
M)&YA=E!O;&Q,:7-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]P;VQL.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D<R!E;&5M96YT*',I('1O('1H92!P;VQL
M(&QI<W0N"B`@("`@*@H@("`@("H@0'-E92!)34%07U1R964Z.F%D9%!O;&Q,
M:7-T*"D*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&]L;$QI<W0H)&ED*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&ED*2D@>PH@("`@("`@("`@
M("`D:60@/2!A<G)A>2@D:60I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E
M;7!T>2@D:60I("8F("$D1TQ/0D%,4ULG<')E9G,G72T^:7-,;V-K960H)VYA
M=E]P;VQL)RDI('L*("`@("`@("`@("`@)'1H:7,M/F=E=%!O;&Q,:7-T*"D[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!O;&Q;)'9A;%T@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S9710;VQL960H)'1H:7,M/E]T<F5E6R1V86Q=+"!T
M<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D1TQ/0D%,4ULG<')E
M9G,G72T^<V5T5F%L=64H)VYA=E]P;VQL)RP@<V5R:6%L:7IE*"1T:&ES+3Y?
M<&]L;"DI.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T<G5E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@96QE;65N
M="AS*2!F<F]M('1H92!P;VQL(&QI<W0N"B`@("`@*@H@("`@("H@0'-E92!)
M34%07U1R964Z.G)E;6]V95!O;&Q,:7-T*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E4&]L;$QI<W0H)&ED*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M87)R87DH)&ED*2D@>PH@("`@("`@("`@("`D:60@/2!A<G)A>2@D:60I.PH@
M("`@("`@('T*"B`@("`@("`@)')E;6]V960@/2!F86QS93L*"B`@("`@("`@
M:68@*"$D1TQ/0D%,4ULG<')E9G,G72T^:7-,;V-K960H)VYA=E]P;VQL)RDI
M('L*("`@("`@("`@("`@)'1H:7,M/F=E=%!O;&Q,:7-T*"D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("!I
M9B`H)'9A;"`A/2`G24Y"3U@G*2!["B`@("`@("`@("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]P;VQL6R1V86Q=*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]T<F5E6R1V86Q=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E=%!O;&QE9"@D=&AI<RT^7W1R965;)'9A
M;%TL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)')E;6]V960@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D<F5M;W9E9"D@>PH@("`@
M("`@("`@("`@("`@)$=,3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=N879?
M<&]L;"<L('-E<FEA;&EZ92@D=&AI<RT^7W!O;&PI*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R
M96YT;'D@<V5L96-T960@:6YI=&EA;&EZ871I;VX@97AP86YD960@;6]D92X*
M("`@("`J"B`@("`@*B!`<V5E($E-05!?5')E93HZ7V=E=$EN:71%>'!A;F1E
M9$UO9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T26YI=$5X<&%N9&5D
M36]D92@I"B`@("!["B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=P<F5F<R==
M+3YG971686QU92@G;F%V7V5X<&%N9&5D)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&5S('1H92!V:7)T=6%L(&9O;&1E<B!C;VYT86EN97(N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@02!M86EL8F]X(&5L96UE;G0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C<F5A=&561F]L9&5R0V]N=&%I;F5R*"D*("`@('L*("`@("`@
M("`D8F%S92`](%\H(E9I<G1U86P@1F]L9&5R<R(I.PH*("`@("`@("`D;V(@
M/2`F;F5W('-T9$-L87-S.PH@("`@("`@("1O8BT^9&5L:6UI=&5R(#T@)'1H
M:7,M/E]D96QI;6ET97(["B`@("`@("`@)&]B+3YA='1R:6)U=&5S(#T@3$%4
M5%].3U-%3$5#5"!\($Q!5%1?2$%30TA)3$1214X@?"!)34%05%)%15]%3%1?
M25-?1$E30T]615)%1"!\($E-05!44D5%7T5,5%])4U]354)30U))0D5$('P@
M24U05%)%15]%3%1?5D9/3$1%4CL*("`@("`@("`D;V(M/F9U;&Q397)V97)0
M871H(#T@)&]B+3YN86UE(#T@)&)A<V4["@H@("`@("`@("1E;'0@/2`D=&AI
M<RT^7VUA:V5-86EL8F]X5')E945L="@D;V(I.PH@("`@("`@("1E;'1;)VPG
M72`]("1E;'1;)W8G72`]("1B87-E.PH*("`@("`@("!R971U<FX@)&5L=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!V:7)T=6%L(&9O;&1E
M<B!E;&5M96YT+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'9F;VQD97(@(%9I<G1U86P@9F]L
M9&5R($E$+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@;6%I;&)O
M>"!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E5D9O;&1E
M<D5L="@D=F9O;&1E<BD*("`@('L*("`@("`@("`D8F%S92`](%\H(E9I<G1U
M86P@1F]L9&5R<R(I.PH*("`@("`@("`D;V(@/2`F;F5W('-T9$-L87-S.PH@
M("`@("`@("1O8BT^9&5L:6UI=&5R(#T@)'1H:7,M/E]D96QI;6ET97(["B`@
M("`@("`@)&]B+3YA='1R:6)U=&5S(#T@3$%45%](05-.3T-(24Q$4D5.('P@
M24U!4%12145?14Q47TE37T1)4T-/5D52140@?"!)34%05%)%15]%3%1?25-?
M4U5"4T-224)%1"!\($E-4%12145?14Q47U9&3TQ$15(["B`@("`@("`@)&]B
M+3YN86UE(#T@)&)A<V4@+B`D=&AI<RT^7V1E;&EM:71E<B`N("1V9F]L9&5R
M.PH@("`@("`@("1O8BT^9G5L;%-E<G9E<E!A=&@@/2`D;V(M/FYA;64["@H@
M("`@("`@("1E;'0@/2`D=&AI<RT^7VUA:V5-86EL8F]X5')E945L="@D;V(I
M.PH@("`@("`@("1E;'1;)VPG72`]("1T:&ES+3Y?=F9O;&1E<G-;)'9F;VQD
M97)=.PH@("`@("`@("1E;'1;)W8G72`]("1V9F]L9&5R.PH*("`@("`@("!R
M971U<FX@)&5L=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE
M=&AE<B!T:&ES(&5L96UE;G0@:7,@82!V:7)T=6%L(&9O;&1E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4<G5E(&EF('1H92!E;&5M
M96YT(&ES(&$@=FER='5A;"!F;VQD97(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES5D9O;&1E<B@D96QT*0H@("`@>PH@("`@("`@(')E='5R;B`D96QT6R=A
M)UT@)B!)35!44D5%7T5,5%]61D],1$52.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(&YO;BU)34%0(&UA:6QB;W@@96QE;65N="!G:79E;B!A
M;B!E;&5M96YT(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!E
M;&5M96YT(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@02!M86EL8F]X(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971.;VY)34%016QT*"1I9"D*("`@('L*("`@("`@("!I9B`H)&ED(#T](%\H
M(E9I<G1U86P@1F]L9&5R<R(I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V-R96%T959F;VQD97)#;VYT86EN97(H*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C<F5A=&569F]L9&5R16QT
M*"1I9"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E
M<R!A;B!E;&5M96YT(&9R;VT@=&AE('1R964N"B`@("`@*@H@("`@("H@0'-E
M92!)34%07U1R964Z.F1E;&5T92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E
M;&5T92@D:60I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D:60I("8F
M"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?=')E95M)35!?4T5!4D-(7TU"
M3U@@+B`D:61=*2`F)@H@("`@("`@("`@("`D=&AI<RT^:7-61F]L9&5R*"1T
M:&ES+3Y?=')E95M)35!?4T5!4D-(7TU"3U@@+B`D:61=*2D@>PH@("`@("`@
M("`@("`D:60@/2!)35!?4T5!4D-(7TU"3U@@+B`D:60["B`@("`@("`@("`@
M("1P87)E;G0@/2`D=&AI<RT^7W1R965;)&ED75LG<"==.PH@("`@("`@("`@
M("!U;G-E="@D=&AI<RT^7W9F;VQD97)S6R1I9%TI.PH@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^7W1R965;)&ED72D["@H@("`@("`@("`@("`O*B!$96QE
M=&4@=&AE(&5N=')Y(&9R;VT@=&AE('!A<F5N="!T<F5E+B`J+PH@("`@("`@
M("`@("`D:V5Y(#T@87)R87E?<V5A<F-H*"1I9"P@)'1H:7,M/E]P87)E;G1;
M)'!A<F5N=%TI.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A<F5N=%LD
M<&%R96YT75LD:V5Y72D["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]
M('1R=64["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@<&%R96YT.CID96QE=&4H)&ED*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;F%M92!A(&-U<G)E;G0@9F]L9&5R+@H@("`@("H*("`@
M("`J($!S:6YC92!)35`@-"XQ"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1O;&0@(%1H92!O;&0@9F]L9&5R(&YA;65S+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1N97<@(%1H92!N97<@9F]L9&5R(&YA;65S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96YA;64H)&]L9"P@)&YE=RD*("`@('L*("`@("`@("!F;W)E
M86-H("@D;VQD(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D<&]L
M;&5D(#T@*&ES<V5T*"1T:&ES+3Y?=')E95LD=F%L72DI(#\@)'1H:7,M/FES
M4&]L;&5D*"1T:&ES+3Y?=')E95LD=F%L72D@.B!F86QS93L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YD96QE=&4H)'9A;"DI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YI;G-E<G0H)&YE=ULD:V5Y72D["B`@("`@("`@("`@("`@("!I
M9B`H)'!O;&QE9"D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&10
M;VQL3&ES="@D;F5W6R1K97E=*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1O97,@
M=&AE(&5L96UE;G0@:&%V92!A;GD@8VAI;&1R96X_"B`@("`@*@H@("`@("H@
M0'-E92!)34%07U1R964Z.FAA<T-H:6QD<F5N*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@:&%S0VAI;&1R96XH)&5L="P@)'9I97=A8FQE(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3YI<U9&;VQD97(H)&5L="D@)B8@)'1H
M:7,M/FES0V]N=&%I;F5R*"1E;'0I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@<&%R96YT.CIH87-#:&EL
M9')E;B@D96QT+"`D=FEE=V%B;&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M26YI=&EA;&EZ97,@=&AE(&QI<W0@;V8@<W5B<V-R:6)E9"!M86EL8F]X97,N
M"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@<VEN8V4@2&]R9&4@,RXQ"B`@
M("`@*@H@("`@("H@0'-E92!)34%07U1R964Z.E]I;FET4W5B<V-R:6)E9"@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET4W5B<V-R:6)E9"@I"B`@("![
M"B`@("`@("`@)&AS=6(@/2`H:7-?;G5L;"@D=&AI<RT^7W-U8G-C<FEB960I
M*3L*("`@("`@("!P87)E;G0Z.E]I;FET4W5B<V-R:6)E9"@I.PH*("`@("`@
M("`O*B!!9&0@:6X@;W1H97(@:&EE<F%R8VAY('-U8G-C<FEP=&EO;B!I;F9O
M<FUA=&EO;BX@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?;F5W:6UA<'1R964@
M)B8@)&AS=6(I('L*("`@("`@("`@("`@9F]R96%C:"`H)%]315-324].6R=I
M;7`G75LG;F%M97-P86-E)UT@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@
M)'-U8FQI<W0@/2!`:6UA<%]L<W5B*"1T:&ES+3Y?9V5T4W1R96%M*"DL("1T
M:&ES+3Y?<V5R=F5R+"`D=F%L6R=N86UE)UT@+B`G*B<I.PH@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D<W5B;&ES="DI('L*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D<W5B;&ES="!A<R`D=F%L,BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-U8G-C<FEB961;<W5B<W1R*"1V86PR
M+"!S=')P;W,H)'9A;#(L("=])RD@*R`Q*5T@/2`Q.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T(&]F
M(&%L;"!)34%0(&9O;&1E<G,@:6X@=&AE('1R964@*&DN92X@;F]T(&-O;G1A
M:6YE<G,@;W(*("`@("`J(&YO;BUI;6%P(&5L96UE;G1S*2X*("`@("`J"B`@
M("`@*B!`=&]D;R!-;W9E(&-O<F4@8V]D92!T;R!F<F%M97=O<FLN"B`@("`@
M*B!`<VEN8V4@24U0(#,N,0H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%N(&%R<F%Y(&]F($E-05`@;6%I;&)O>"!N86UE<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9F]L9&5R3&ES="@I"B`@("!["B`@("`@("`@)')E=%]A<G)A
M>2`](&%R<F%Y*"D["@H@("`@("`@("1M86EL8F]X(#T@)'1H:7,M/G)E<V5T
M*"D["B`@("`@("`@9&\@>PH@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T-O
M;G1A:6YE<B@D;6%I;&)O>"D@)B8*("`@("`@("`@("`@("`@("$D=&AI<RT^
M:7-61F]L9&5R*"1M86EL8F]X*2D@>PH@("`@("`@("`@("`@("`@)')E=%]A
M<G)A>5M=(#T@)&UA:6QB;WA;)W8G73L*("`@("`@("`@("`@?0H@("`@("`@
M('T@=VAI;&4@*"@D;6%I;&)O>"`]("1T:&ES+3YN97AT*$E-05!44D5%7TY%
M6%1?4TA/5T-,3U-%1"DI*3L*"B`@("`@("`@<F5T=7)N("1R971?87)R87D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B])
M34%0+U1H<F5A9"YP:'``````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-C8R,P`Q,#0Q-S,V,C<V-@`P,C`T,S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O24U!4"]4:')E860N<&AP)SL*"B\J*@H@*B!4:&4@24U07U1H
M<F5A9"!C;&%S<R!E>'1E;F1S('1H92!)34%07U1H<F5A9"!C;&%S<R!T;R!I
M;F-L=61E(&$@9G5N8W1I;VX*("H@=&\@9V5N97)A=&4@=&AE('1H<F5A9"!T
M<F5E(&EM86=E<RX@(%1H:7,@8VQA<W,@:7,@;F5C97-S87)Y('1O(&5N<W5R
M90H@*B!B86-K=V%R9',@8V]M<&%T:6)I;&ET>2!W:71H($AO<F1E(#,N,"X*
M("H*("H@1F]R('1H92!N97AT("AM>71H:6-A;"D@<F5L96%S92!O9B!(;W)D
M92`T+G@L('1H:7,@8V]D92!S:&]U;&0@8F4@;65R9V5D"B`J(&EN=&\@=&AE
M($E-05!?5&AR96%D(&-L87-S+@H@*@H@*B`D2&]R9&4Z(&EM<"]L:6(O24U!
M4"]4:')E860N<&AP+'8@,2XU+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(X.C4W(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!C=7)E8V%N=&DN;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!C=7)E8V%N=&DN
M;W)G/@H@*B!`<VEN8V4@("!)35`@-"XQ"B`J($!P86-K86=E($E-4`H@*B\*
M8VQA<W,@24U07U1H<F5A9"!E>'1E;F1S($E-05!?5&AR96%D('L*"B`@("`O
M*BH*("`@("`J($-A8VAE9"!V86QU92!O9B!T:&4@2&]R9&4@9W)A<&AI8W,@
M9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V=R87!H:6-S9&ER.PH*("`@("\J*@H@("`@("H@0V%C:&5D
M('9A;'5E<R!O9B!T:&4@=&AR96%D(&EM86=E(&]B:F5C=',N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG8V%C:&4@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE('1H<F5A
M9"!R97!R97-E;G1A=&EO;B!I;6%G92!F;W(@=&AE(&=I=F5N(&EN9&5X(&QI
M<W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1I;F1I8V5S("`@(%1H
M92!L:7-T(&]F(&EN9&EC97,@=&\@8W)E871E(&$@=')E92!F;W(N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<V]R=&1I<B`@5')U92!F;W(@;F5W97-T(&9I
M<G-T+"!F86QS92!F;W(@;VQD97-T(&9I<G-T+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%N(&%R<F%Y('=I=&@@=&AE(&EN9&5X(&%S('1H92!K
M97D@86YD('1H92!T:')E860@:6UA9V4*("`@("`J("`@("`@("`@("`@("`@
M(')E<')E<V5N=&%T:6]N(&%S('1H92!V86QU92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5&AR96%D26UA9V54<F5E*"1I;F1I8V5S+"`D<V]R=&1I<BD*
M("`@('L*("`@("`@("`D8V]N=&%I;F5R(#T@)&QA<W1?;&5V96P@/2`D;&%S
M=%]T:')E860@/2!N=6QL.PH@("`@("`@("1T<F5E(#T@87)R87DH*3L*"B`@
M("`@("`@:68@*"1S;W)T9&ER*2!["B`@("`@("`@("`@("1I;F1I8V5S(#T@
M87)R87E?<F5V97)S92@D:6YD:6-E<RD["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D:6YD:6-E<R!A<R`D=F%L*2!["B`@("`@("`@("`@("1T<F5E
M6R1V86Q=(#T@)R<["@H@("`@("`@("`@("`D:6YD96YT0F%S92`]("1T:&ES
M+3YG9714:')E861"87-E*"1V86PI.PH@("`@("`@("`@("!I9B`H96UP='DH
M)&EN9&5N=$)A<V4I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&QI;F5S(#T@)R<["B`@("`@("`@
M("`@("1I;F1E;G1,979E;"`]("1T:&ES+3YG9714:')E861);F1E;G0H)'9A
M;"D["B`@("`@("`@("`@("1L87-T:6YL979E;"`]("1T:&ES+3YL87-T26Y,
M979E;"@D=F%L*3L*"B`@("`@("`@("`@(&EF("@D;&%S=&EN;&5V96P@)B8@
M*"1I;F1E;G1"87-E(#T]("1V86PI*2!["B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1L87-T:6YL
M979E;"D@>PH@("`@("`@("`@("`@("`@)&IO:6Y?:6UG(#T@*"1S;W)T9&ER
M*2`_("=J;VEN8F]T=&]M+61O=VXN<&YG)R`Z("=J;VEN8F]T=&]M+G!N9R<[
M"B`@("`@("`@("`@('T@96QS96EF("@H)&EN9&5N=$QE=F5L(#T](#$I("8F
M("@D:6YD96YT0F%S92`]/2`D=F%L*2D@>PH@("`@("`@("`@("`@("`@)&IO
M:6Y?:6UG(#T@*"1S;W)T9&ER*2`_("=J;VEN8F]T=&]M+G!N9R<@.B`G:F]I
M;F)O='1O;2UD;W=N+G!N9R<["B`@("`@("`@("`@("`@("`D8V]N=&%I;F5R
M(#T@)'9A;#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1J;VEN7VEM9R`]("=J;VEN+G!N9R<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H<F5A9$QE=F5L6R1I;F1E;G1,979E;%T@/2`D;&%S=&EN;&5V
M96P["B`@("`@("`@("`@(&9O<B`H)&D@/2`H)&-O;G1A:6YE<B`]/2`D:6YD
M96YT0F%S92D@/R`Q(#H@,CL@)&D@/"`D:6YD96YT3&5V96P[("1I*RLI('L*
M("`@("`@("`@("`@("`@("1L:6YE<R`N/2`D=&AI<RT^7VEM86=E*"%I<W-E
M="@D=&AR96%D3&5V96Q;)&E=*2!\?"`H)'1H<F5A9$QE=F5L6R1I72D@/R`G
M8FQA;FLN<&YG)R`Z("=L:6YE+G!N9R<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T<F5E6R1V86Q=(#T@)&QI;F5S("X@)'1H:7,M/E]I;6%G92@D
M:F]I;E]I;6<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T<F5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@571I;&ET>2!F=6YC=&EO;B!T;R!R971U
M<FX@82!U<FP@9F]R('1H92!V87)I;W5S('1H<F5A9"!I;6%G97,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@26UA9V4@9FEL96YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@($QI;FL@=&\@=&AE(&9O;&1E<B!I;6%G92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7VEM86=E*"1N86UE*0H@("`@>PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]I;6=C86-H95LD;F%M95TI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM9V-A8VAE6R1N86UE73L*("`@("`@
M("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V=R87!H:6-S9&ER*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V=R87!H:6-S9&ER(#T@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]I;6=C86-H95LD;F%M95T@/2!(;W)D93HZ:6UG
M*"=T<F5E+R<@+B`D;F%M92P@)R<L("=S='EL93TB=F5R=&EC86PM86QI9VXZ
M;6ED9&QE(B<L("1T:&ES+3Y?9W)A<&AI8W-D:7(I.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;6=C86-H95LD;F%M95T["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O
M24U!4"]3;W)T+G!H<```````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(R-C(`,3`T,3<S-C(W-C8`,#(P,34P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+TE-05`O4V]R="YP:'`G.PH*+RHJ"B`J(%1H92!)35!?24U!
M4%]3;W)T.CH@8VQA<W,@97AT96YD<R!T:&4@24U!4%]3;W)T(&-L87-S(&EN
M(&]R9&5R('1O"B`J('!R;W9I9&4@;F5C97-S87)Y(&)U9R!F:7AE<R!T;R!E
M;G-U<F4@8F%C:W=A<F1S(&-O;7!A=&EB:6QI='D@=VET:"!(;W)D90H@*B`S
M+C`N"B`J"B`J("1(;W)D93H@:6UP+VQI8B])34%0+U-O<G0N<&AP+'8@,2XQ
M+C(N,2`R,#`V+S`R+S$U(#$X.C$P.C`Y('-L=7-A<GH@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!)35`@-"XQ"B`J
M($!P86-K86=E($AO<F1E7TE-05`*("HO"F-L87-S($E-4%])34%07U-O<G0@
M97AT96YD<R!)34%07U-O<G0@>PH*("`@("\J*@H@("`@("H@4V]R="!A(&QI
M<W0@;V8@;6%I;&)O>&5S("AB>2!V86QU92DN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("8D;6)O>"`@("!4:&4@;&ES="!O9B!M86EL8F]X97,@=&\@
M<V]R="X*("`@("`J($!P87)A;2!B;V]L96%N("1I;F)O>"`@5VAE;B!S;W)T
M:6YG+"!A;'=A>7,@<'5T("=)3D)/6"<@870@=&AE(&AE860@;V8*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&QI<W0_"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D:6YD97@@($UA:6YT86EN(&EN9&5X(&%S<V]C:6%T:6]N
M/PH@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T36%I;&)O>&5S*"8D;6)O>"P@
M)&EN8F]X(#T@=')U92P@)&EN9&5X(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S;W)T:6YB;W@@/2`D:6YB;W@["B`@("`@("`@:68@*"1I;F1E
M>"D@>PH@("`@("`@("`@("!U87-O<G0H)&UB;W@L(&%R<F%Y*"8D=&AI<RP@
M)U]M8F]X7V-M<"<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U
M<V]R="@D;6)O>"P@87)R87DH)B1T:&ES+"`G7VUB;WA?8VUP)RDI.PH@("`@
M("`@('T*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-86EN=&5N86YC92\`````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V
M-@`P,C`R,#4`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+TUA:6YT
M96YA;F-E+U1A<VLO````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S8V`#`R,3$P-P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C:&UA:6Q?;&]G:6XN
M<&AP````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#0T-S$`,3`T,3<S-C(W-C8`,#(T-S0W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&EM<"]L:6(O36%I;G1E;F%N8V4O5&%S:R]F971C
M:&UA:6Q?;&]G:6XN<&AP+'8@,2XU+C$R+C<@,C`P-B\P,2\P,2`R,3HR.#HU
M.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!.=6YO($QO
M=7)E:7)O(#QN=6YO0&-O+G-A<&\N<'0^"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N
M961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O9W!L+FAT;6PN"B`J"B`J($UA:6YT96YA;F-E(&UO9'5L92!T:&%T
M(&9E=&-H(&UA:6P@=7!O;B!L;V=I;@H@*@H@*B!`875T:&]R("!.=6YO($QO
M=7)E:7)O(#QN=6YO0&-O+G-A<&\N<'0^"B`J($!A=71H;W(@($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I
M;F-E("`@24U0(#0N,`H@*B!`<&%C:V%G92!(;W)D95]-86EN=&5N86YC90H@
M*B\*8VQA<W,@36%I;G1E;F%N8V5?5&%S:U]F971C:&UA:6Q?;&]G:6X@97AT
M96YD<R!-86EN=&5N86YC95]487-K('L*"B`@("`O*BH*("`@("`J(%1H92!S
M='EL92!O9B!T:&4@;6%I;G1E;F%N8V4@<&%G92!O=71P=70N"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V1I<W!L87E?
M='EP92`]($U!24Y414Y!3D-%7T]55%!55%]#3TY&25)-.PH*("`@("\J*@H@
M("`@("H@1F5T8V@@96UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9&]-86EN=&5N86YC92@I"B`@("!["B`@("`@("`@
M+RH@268@=&AE('5S97(@=V%N=',@=&\@9F5T8V@@96UA:6QS(&9R;VT@;W1H
M97(@86-C;W5N=',@;VX@;&]G:6XL"B`@("`@("`@("H@9V\@9V5T('1H;W-E
M(&UE<W-A9V5S(&YO=RX@*B\*("`@("`@("!I9B`H)$=,3T)!3%-;)W!R969S
M)UTM/F=E=%9A;'5E*"=F;5]A8V-O=6YT<R<I*2!["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+T9E=&-H;6%I;"YP:'`G.PH@
M("`@("`@("`@("`D9FU?86-C;W5N="`]("9N97<@24U07T9E=&-H;6%I;%]!
M8V-O=6YT*"D["B`@("`@("`@("`@("1F;5]L:7-T(#T@87)R87DH*3L*"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1F;5]A8V-O=6YT+3YG971!;&PH)VQO9VEN
M9F5T8V@G*2!A<R`D:60@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@
M*"1V86PI('L*("`@("`@("`@("`@("`@("`@("`D9FU?;&ES=%M=(#T@)&ED
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1F;5]L:7-T*2D@>PH@("`@("`@("`@("`@("`@24U0
M7T9E=&-H;6%I;#HZ9F5T8VA-86EL*"1F;5]L:7-T*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('-U;6UA<GD@;V8@=&AE(&%C8V]U;G1S('1O(&9E=&-H(&5M86EL(&9R;VTN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=6UM87)Y(&]F
M('1H92!A8V-O=6YT<R!T;R!F971C:"!E;6%I;"!F<F]M+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!D97-C<FEB94UA:6YT96YA;F-E*"D*("`@('L*("`@("`@
M("`D<W1R("`](%\H(EEO=2!A<F4@86)O=70@=&\@9F5T8V@@96UA:6P@9G)O
M;2!T:&4@9F]L;&]W:6YG(&%C8V]U;G0H<RDZ(BD["B`@("`@("`@)'-T<B`N
M/2`B7&X\8FQO8VMQ=6]T93Y<;B(["@H@("`@("`@(&EF("@D1TQ/0D%,4ULG
M<')E9G,G72T^9V5T5F%L=64H)V9M7V%C8V]U;G1S)RDI('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O1F5T8VAM86EL+G!H
M<"<["B`@("`@("`@("`@("1F;5]A8V-O=6YT(#T@)FYE=R!)35!?1F5T8VAM
M86EL7T%C8V]U;G0H*3L*("`@("`@("`@("`@9F]R96%C:"`H)&9M7V%C8V]U
M;G0M/F=E=$%L;"@G;&]G:6YF971C:"<I(&%S("1I9"`]/B`D=F%L*2!["B`@
M("`@("`@("`@("`@("!I9B`H)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@
M("1S='(@+CT@(B`M("(@+B`D9FU?86-C;W5N="T^9V5T5F%L=64H)VED)RP@
M)&ED*2`N("(\8G(@+SY<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1S='(@+CT@(EQN/"]B;&]C:W%U
M;W1E/EQN/'-T<F]N9SXB("X@7R@B3F]T92!T:&%T('1H:7,@8V%N('1A:V4@
M<V]M92!T:6UE(BD@+B`B+CPO<W1R;VYG/EQN(CL*"B`@("`@("`@<F5T=7)N
M("1S='(["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O36%I;G1E;F%N8V4O5&%S:R]T;W-?
M86=R965M96YT+G!H<```````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,R-C<`,3`T,3<S-C(W
M-C8`,#(T-#8Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!-86EN=&5N86YC92!M;V1U;&4@=&AA="!P
M<F5S96YT<R!A(%1/4R!!9W)E96UE;G0@<&%G92!T;R!U<V5R+@H@*B!)9B!U
M<V5R(&1O97,@;F]T(&%C8V5P="!T97)M<RP@=7-E<B!I<R!N;W0@86QL;W=E
M9"!T;R!L;V=I;BX*("H*("H@)$AO<F1E.B!I;7`O;&EB+TUA:6YT96YA;F-E
M+U1A<VLO=&]S7V%G<F5E;65N="YP:'`L=B`Q+C$Q+C$P+C<@,C`P-B\P,2\P
M,2`R,3HR.#HU.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!)
M35`@-"XP"B`J($!P86-K86=E($AO<F1E7TUA:6YT96YA;F-E"B`J+PIC;&%S
M<R!-86EN=&5N86YC95]487-K7W1O<U]A9W)E96UE;G0@97AT96YD<R!-86EN
M=&5N86YC95]487-K('L*"B`@("`O*BH*("`@("`J(%1H92!S='EL92!O9B!T
M:&4@;6%I;G1E;F%N8V4@<&%G92!O=71P=70N"B`@("`@*@H@("`@("H@0'9A
M<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V1I<W!L87E?='EP92`]($U!
M24Y414Y!3D-%7T]55%!55%]!1U)%13L*"B`@("`O*BH*("`@("`J($1E=&5R
M;6EN92!I9B!U<V5R(&%G<F5E9"!W:71H('1H92!T97)M<R!O<B!N;W0N("!)
M9B!T:&4@=7-E<B!D;V5S(&YO=`H@("`@("H@86=R964L(&QO9R!H:6TO:&5R
M(&]U="!I;6UE9&EA=&5L>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9&]-86EN
M=&5N86YC92@I"B`@("!["B`@("`@("`@)')E<W5L="`](%5T:6PZ.F=E=$9O
M<FU$871A*"=N;W1?86=R964G*3L*("`@("`@("!I9B`H:7-S970H)')E<W5L
M="DI('L*("`@("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@075T:#HZ
M861D3&]G;W5T4&%R86UE=&5R<RA)35`Z.FQO9V]U=%5R;"@I+"!!551(7U)%
M05-/3E]-15-304=%+"!?*")9;W4@9&ED(&YO="!A9W)E92!T;R!T:&4@5&5R
M;7,@;V8@4V5R=FEC92!A9W)E96UE;G0L('-O('EO=2!W97)E(&YO="!A;&QO
M=V5D('1O(&QO9VEN+B(I*2D["B`@("`@("`@("`@97AI=#L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!43U,@86=R965M
M96YT(&9O<B!D:7-P;&%Y(&]N('1H92!M86EN=&5N86YC92!P86=E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5R;7,@;V8@<V5R=FEC
M92!A9W)E96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<V-R:6)E36%I
M;G1E;F%N8V4H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@
M("`@:68@*&5M<'1Y*"1C;VYF6R=T;W,G75LG9FEL92==*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(E1E<FUS(&]F(%-E<G9I8V4@9FEL92!N;W0@<W!E8VEF:65D(&EN(&-O;F8N
M<&AP(BDI*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!F:6QE7V=E=%]C;VYT96YT<R@D8V]N9ELG=&]S)UU;)V9I
M;&4G72D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O;&EB+TUA:6YT96YA;F-E+U1A<VLO<'5R9V5?=')A
M<V@N<&AP`````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,3<W`#$P-#$W,S8R-S8V`#`R
M-#$U,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AO<F1E.B!I;7`O;&EB+TUA:6YT96YA;F-E+U1A
M<VLO<'5R9V5?=')A<V@N<&AP+'8@,2XR,RXQ,"XY(#(P,#8O,#(O,#0@,3DZ
M,3,Z,3,@<VQU<V%R>B!%>'`@)`H@*@H@*B!-86EN=&5N86YC92!M;V1U;&4@
M=&AA="!P=7)G97,@;VQD(&UE<W-A9V5S(&EN('1H92!4<F%S:"!F;VQD97(N
M"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H@0'-I;F-E("`@24U0(#(N,RXW"B`J($!P86-K86=E
M($AO<F1E7TUA:6YT96YA;F-E"B`J+PIC;&%S<R!-86EN=&5N86YC95]487-K
M7W!U<F=E7W1R87-H(&5X=&5N9',@36%I;G1E;F%N8V5?5&%S:R!["@H@("`@
M+RHJ"B`@("`@*B!0=7)G92!O;&0@;65S<V%G97,@:6X@=&AE(%1R87-H(&9O
M;&1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@
M86YY(&UE<W-A9V5S('=E<F4@<'5R9V5D(&9R;VT@=&AE(%1R87-H(&9O;&1E
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9&]-86EN=&5N86YC92@I"B`@("![
M"B`@("`@("`@9VQO8F%L("1I;7`L("1P<F5F<RP@)&YO=&EF:6-A=&EO;CL*
M"B`@("`@("`@+RH@268@=V4@87)E;B=T('5S:6YG(&$@5')A<V@@9F]L9&5R
M(&]R(&EF('1H97)E(&ES(&YO(%1R87-H"B`@("`@("`@("`@9F]L9&5R('-E
M="P@:G5S="!R971U<FXN("HO"B`@("`@("`@)'1R87-H7V9O;&1E<B`]($E-
M4#HZ9F]L9&5R4')E9B@D<')E9G,M/F=E=%9A;'5E*"=T<F%S:%]F;VQD97(G
M*2P@=')U92D["B`@("`@("`@:68@*"$D<')E9G,M/F=E=%9A;'5E*"=U<V5?
M=')A<V@G*2!\?"`A)'1R87-H7V9O;&1E<BD@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=&AE
M(%1R87-H(&9O;&1E<B!E>&ES=',N("HO"B`@("`@("`@<F5Q=6ER95]O;F-E
M($E-4%]"05-%("X@)R]L:6(O1F]L9&5R+G!H<"<["B`@("`@("`@)&EM<%]F
M;VQD97(@/2`F24U07T9O;&1E<CHZ<VEN9VQE=&]N*"D["B`@("`@("`@:68@
M*"$D:6UP7V9O;&1E<BT^97AI<W1S*"1T<F%S:%]F;VQD97(I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($=E
M="!T:&4@8W5R<F5N="!53DE8('1I;65S=&%M<"!M:6YU<R!T:&4@;G5M8F5R
M(&]F(&1A>7,*("`@("`@("`@("!S<&5C:69I960@:6X@)W!U<F=E7W1R87-H
M7VME97`G+B`@268@82!M97-S86=E(&AA<R!A"B`@("`@("`@("`@=&EM97-T
M86UP('!R:6]R('1O('1H:7,@=F%L=64L(&ET('=I;&P@8F4@9&5L971E9"X@
M*B\*("`@("`@("`D9&5L7W1I;64@/2!D871E*")R(BP@=&EM92@I("T@*"1P
M<F5F<RT^9V5T5F%L=64H)W!U<F=E7W1R87-H7VME97`G*2`J(#@V-#`P*2D[
M"@H@("`@("`@("\J($]P96X@=&AE(%1R87-H(&UA:6QB;W@@86YD(&=E="!T
M:&4@;&ES="!O9B!M97-S86=E<R!O;&1E<@H@("`@("`@("`@('1H86X@)W!U
M<F=E7W1R87-H7VME97`G(&1A>7,N("HO"B`@("`@("`@<F5Q=6ER95]O;F-E
M($E-4%]"05-%("X@)R]L:6(O24U!4"YP:'`G.PH@("`@("`@(')E<75I<F5?
M;VYC92!)35!?0D%312`N("<O;&EB+TUE<W-A9V4N<&AP)SL*("`@("`@("`D
M:6UP7VEM87`@/2`F24U07TE-05`Z.G-I;F=L971O;B@I.PH@("`@("`@("1I
M;7!?;65S<V%G92`]("9)35!?365S<V%G93HZ<VEN9VQE=&]N*"D["B`@("`@
M("`@)&EM<%]I;6%P+3YC:&%N9V5-8F]X*"1T<F%S:%]F;VQD97(I.PH@("`@
M("`@("1M<V=?:61S(#T@0&EM87!?<V5A<F-H*"1I;7!;)W-T<F5A;2==+"`B
M0D5&3U)%(%PB)&1E;%]T:6UE7"(B+"!315]5240I.PH@("`@("`@(&EF("AE
M;7!T>2@D;7-G7VED<RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@1V\@=&AR;W5G:"!T:&4@;65S<V%G92!L
M:7-T(&%N9"!D96QE=&4@=&AE(&UE<W-A9V5S+B`J+PH@("`@("`@("1I;F1I
M8V5S(#T@87)R87DH)'1R87-H7V9O;&1E<B`]/B`D;7-G7VED<RD["B`@("`@
M("`@:68@*"1I;7!?;65S<V%G92T^9&5L971E*"1I;F1I8V5S+"!T<G5E*2D@
M>PH@("`@("`@("`@("`D;7-G8V]U;G0@/2!C;W5N="@D;7-G7VED<RD["B`@
M("`@("`@("`@(&EF("@D;7-G8V]U;G0@/3T@,2D@>PH@("`@("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")0=7)G:6YG(#$@;65S<V%G92!F
M<F]M(%1R87-H(&9O;&1E<BXB*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")0=7)G:6YG("5D(&UE<W-A9V5S(&9R;VT@5')A
M<V@@9F]L9&5R+B(I+"`D;7-G8V]U;G0I+"`G:&]R9&4N;65S<V%G92<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O<FUA=&EO;B!F;W(@
M=&AE(&UA:6YT96YA;F-E(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!$97-C<FEP=&EO;B!O9B!W:&%T('1H92!O<&5R871I;VX@
M:7,@9V]I;F<@=&\@9&\@9'5R:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@
M=&AI<R!L;V=I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9&5S8W)I8F5-86EN
M=&5N86YC92@I"B`@("!["B`@("`@("`@<F5T=7)N('-P<FEN=&8H7R@B06QL
M(&UE<W-A9V5S(&EN('EO=7(@7"(E<UPB(&9O;&1E<B!O;&1E<B!T:&%N("5S
M(&1A>7,@=VEL;"!B92!P97)M86YE;G1L>2!D96QE=&5D+B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@($E-4#HZ9&ES<&QA>49O;&1E<BA)35`Z.F9O;&1E
M<E!R968H)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=T<F%S:%]F;VQD
M97(G*2P@=')U92DI+`H@("`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q3
M6R=P<F5F<R==+3YG971686QU92@G<'5R9V5?=')A<VA?:V5E<"<I*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQI8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S
M96YT;6%I;%]M;VYT:&QY+G!H<``````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3$P-0`Q,#0Q-S,V,C<V-@`P
M,C8U,S``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($UA:6YT96YA;F-E(&UO9'5L92!T:&%T(')E;F%M
M97,@=&AE('-E;G0M;6%I;"!F;VQD97(N"B`J"B`J("1(;W)D93H@:6UP+VQI
M8B]-86EN=&5N86YC92]487-K+W)E;F%M95]S96YT;6%I;%]M;VYT:&QY+G!H
M<"QV(#$N,C@N,3`N-R`R,#`V+S`R+S(Q(#`Q.C,S.C,Q('-L=7-A<GH@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!)35`@,BXS+C<*("H@0'!A8VMA
M9V4@2&]R9&5?36%I;G1E;F%N8V4*("HO"F-L87-S($UA:6YT96YA;F-E7U1A
M<VM?<F5N86UE7W-E;G1M86EL7VUO;G1H;'D@97AT96YD<R!-86EN=&5N86YC
M95]487-K('L*"B`@("`O*BH*("`@("`J(%)E;F%M97,@=&AE(&]L9"!S96YT
M+6UA:6P@9F]L9&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@86QL('-E;G0M;6%I;"!F;VQD97)S('=E<F4@<F5N86UE9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&]-86EN=&5N86YC92@I"B`@("!["B`@
M("`@("`@)'-U8V-E<W,@/2!T<G5E.PH*("`@("`@("!I;F-L=61E7V]N8V4@
M)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`@("`@:6YC;'5D95]O;F-E($E-
M4%]"05-%("X@)R]L:6(O1F]L9&5R+G!H<"<["@H@("`@("`@("1I9&5N=&ET
M>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*&%R<F%Y*"=I;7`G+"`G:6UP)RDI
M.PH@("`@("`@("1I;7!?9F]L9&5R(#T@)DE-4%]&;VQD97(Z.G-I;F=L971O
M;B@I.PH@("`@("`@("1F;VQD97)?;&ES="`]("1I9&5N=&ET>2T^9V5T06QL
M4V5N=&UA:6QF;VQD97)S*"D["@H@("`@("`@("\J($=E="!R:60@;V8@9'5P
M;&EC871E<RX@*B\*("`@("`@("`D9F]L9&5R7VQI<W0@/2!A<G)A>5]U;FEQ
M=64H)&9O;&1E<E]L:7-T*3L*"B`@("`@("`@9F]R96%C:"`H)&9O;&1E<E]L
M:7-T(&%S("1S96YT7V9O;&1E<BD@>PH@("`@("`@("`@("`O*B!$:7-P;&%Y
M(&$@;65S<V%G92!T;R!T:&4@=7-E<B!A;F0@<F5N86UE('1H92!F;VQD97(N
M"B`@("`@("`@("`@("`@($]N;'D@9&\@=&AI<R!I9B!S96YT+6UA:6P@9F]L
M9&5R(&-U<G)E;G1L>2!E>&ES=',N("HO"B`@("`@("`@("`@(&EF("@D:6UP
M7V9O;&1E<BT^97AI<W1S*"1S96YT7V9O;&1E<BDI('L*("`@("`@("`@("`@
M("`@("1O;&1?9F]L9&5R(#T@36%I;G1E;F%N8V5?5&%S:U]R96YA;65?<V5N
M=&UA:6Q?;6]N=&AL>3HZ7W)E;F%M95-E;G1M86EL36]N=&AL>4YA;64H)'-E
M;G1?9F]L9&5R*3L*("`@("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC
M871I;VXG72T^<'5S:"AS<')I;G1F*%\H(B5S(&9O;&1E<B!B96EN9R!R96YA
M;65D(&%T('1H92!S=&%R="!O9B!T:&4@;6]N=&@N(BDL($E-4#HZ9&ES<&QA
M>49O;&1E<B@D<V5N=%]F;VQD97(I*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@
M("`@("`@("`@("`@(&EF("@D:6UP7V9O;&1E<BT^97AI<W1S*"1O;&1?9F]L
M9&5R*2D@>PH@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC
M871I;VXG72T^<'5S:"AS<')I;G1F*%\H(B5S(&%L<F5A9'D@97AI<W1S+B!9
M;W5R("5S(&9O;&1E<B!W87,@;F]T(')E;F%M960N(BDL($E-4#HZ9&ES<&QA
M>49O;&1E<B@D;VQD7V9O;&1E<BDL($E-4#HZ9&ES<&QA>49O;&1E<B@D<V5N
M=%]F;VQD97(I*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@
M("`@("`D<W5C8V5S<R`](&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&EM<%]F;VQD97(M/G)E;F%M
M92@D<V5N=%]F;VQD97(L("1O;&1?9F]L9&5R*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(21I;7!?9F]L9&5R+3YC<F5A=&4H)'-E;G1?9F]L
M9&5R+"`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W-U8G-C<FEB92<I
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-U8V-E<W,@/2!F
M86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1S=6-C
M97-S(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1S=6-C97-S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I
M;F9O<FUA=&EO;B!F;W(@=&AE(&UA:6YT96YA;F-E(&9U;F-T:6]N+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!$97-C<FEP=&EO;B!O9B!W:&%T
M('1H92!O<&5R871I;VX@:7,@9V]I;F<@=&\@9&\@9'5R:6YG"B`@("`@*B`@
M("`@("`@("`@("`@("`@=&AI<R!L;V=I;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&5S8W)I8F5-86EN=&5N86YC92@I"B`@("!["B`@("`@("`@:6YC;'5D
M95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@("1I9&5N=&ET
M>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*&%R<F%Y*"=I;7`G+"`G:6UP)RDI
M.PH@("`@("`@("1F;VQD97)?;&ES="`]("1I9&5N=&ET>2T^9V5T06QL4V5N
M=&UA:6QF;VQD97)S*"D["@H@("`@("`@("\J($=E="!R:60@;V8@9'5P;&EC
M871E<RX@*B\*("`@("`@("`D9F]L9&5R7VQI<W0@/2!A<G)A>5]U;FEQ=64H
M)&9O;&1E<E]L:7-T*3L*"B`@("`@("`@)&YE=U]F;VQD97)S(#T@)&]L9%]F
M;VQD97)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9F]L9&5R7VQI
M<W0@87,@)&9O;&1E<BD@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1F;VQD
M97(I*2!["B`@("`@("`@("`@("`@("`D;VQD7V9O;&1E<G-;72`]($E-4#HZ
M9&ES<&QA>49O;&1E<B@D9F]L9&5R*3L*("`@("`@("`@("`@("`@("1N97=?
M9F]L9&5R<UM=(#T@24U0.CID:7-P;&%Y1F]L9&5R*$UA:6YT96YA;F-E7U1A
M<VM?<F5N86UE7W-E;G1M86EL7VUO;G1H;'DZ.E]R96YA;65396YT;6%I;$UO
M;G1H;'E.86UE*"1F;VQD97(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('-P<FEN=&8H7R@B5&AE(&-U<G)E;G0@9F]L9&5R
M*',I(%PB)7-<(B!W:6QL(&)E(')E;F%M960@=&\@7"(E<UPB+B(I+"!I;7!L
M;V1E*"<L("<L("1O;&1?9F]L9&5R<RDL(&EM<&QO9&4H)RP@)RP@)&YE=U]F
M;VQD97)S*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H
M92!N86UE('1H92!S96YT+6UA:6P@9F]L9&5R('=I;&P@8F4@<F5N86UE9"!T
M;RX*("`@("`J(#QP<F4^"B`@("`@*B!&;VQD97(@;F%M93H@<V5N="UM86EL
M+6UO;G1H+7EE87(*("`@("`J("`@;6]N=&@@/2!%;F=L:7-H.B`@("`@("`@
M(#,@;&5T=&5R(&%B8G)E=FEA=&EO;@H@("`@("H@("`@("`@("`@($]T:&5R
M($QA;F=U86=E<SH@36]N=&@@=F%L=64@*#`Q+3$R*0H@("`@("H@("!Y96%R
M("`](#0@9&EG:70@>65A<@H@("`@("H@5&AE(&9O;&1E<B!N86UE(&YE961S
M('1O(&)E(&EN('1H:7,@<W!E8VEF:6,@9F]R;6%T("AA<R!O<'!O<V5D('1O
M(&$*("`@("`J("`@=7-E<BUD969I;F5D(&]N92D@=&\@96YS=7)E('1H870@
M)V1E;&5T95]S96YT;6%I;%]M;VYT:&QY)R!P<F]C97-S:6YG"B`@("`@*B`@
M(&-A;B!A8V-U<F%T96QY(&9I;F0@86QL('1H92!O;&0@<V5N="UM86EL(&9O
M;&1E<G,N"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;VQD97(@(%1H
M92!N86UE(&]F('1H92!S96YT+6UA:6P@9F]L9&5R('1O(')E;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@3F5W('-E;G0M;6%I;"!F;VQD
M97(@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E;F%M95-E;G1M86EL
M36]N=&AL>4YA;64H)&9O;&1E<BD*("`@('L*("`@("`@("`D;&%S=%]M86EN
M=&5N86YC92`]("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G;&%S=%]M
M86EN=&5N86YC92<I.PH@("`@("`@("1L87-T7VUA:6YT96YA;F-E(#T@96UP
M='DH)&QA<W1?;6%I;G1E;F%N8V4I(#\@;6MT:6UE*#`L(#`L(#`L(&1A=&4H
M)VTG*2`M(#$L(#$I(#H@)&QA<W1?;6%I;G1E;F%N8V4["@H@("`@("`@(&EF
M("AS=6)S='(H)$=,3T)!3%-;)VQA;F=U86=E)UTL(#`L(#(I(#T]("=E;B<I
M('L*("`@("`@("`@("`@<F5T=7)N("1F;VQD97(@+B!3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*'-T<G1O;&]W97(H<W1R9G1I;64H)RTE8BTE62<L("1L87-T
M7VUA:6YT96YA;F-E*2DL($Y,4SHZ9V5T17AT97)N86Q#:&%R<V5T*"DL("=5
M5$8W+4E-05`G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@)&9O;&1E<B`N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H<W1R9G1I;64H
M)RTE;2TE62<L("1L87-T7VUA:6YT96YA;F-E*2P@3DQ3.CIG971%>'1E<FYA
M;$-H87)S970H*2P@)U541C<M24U!4"<I.PH@("`@("`@('T*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O36%I;G1E;F%N8V4O5&%S:R]D
M96QE=&5?<V5N=&UA:6Q?;6]N=&AL>2YP:'``````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4R,#``,3`T,3<S
M-C(W-C8`,#(V-3(R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!-86EN=&5N86YC92!M;V1U;&4@=&AA
M="!D96QE=&5S(&]L9"!S96YT+6UA:6P@9F]L9&5R<RX*("H*("H@)$AO<F1E
M.B!I;7`O;&EB+TUA:6YT96YA;F-E+U1A<VLO9&5L971E7W-E;G1M86EL7VUO
M;G1H;'DN<&AP+'8@,2XQ."XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z-3D@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W
M;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@24U0(#(N,RXW"B`J($!P
M86-K86=E($AO<F1E7TUA:6YT96YA;F-E"B`J+PIC;&%S<R!-86EN=&5N86YC
M95]487-K7V1E;&5T95]S96YT;6%I;%]M;VYT:&QY(&5X=&5N9',@36%I;G1E
M;F%N8V5?5&%S:R!["@H@("`@+RHJ"B`@("`@*B!0=7)G92!T:&4@;VQD('-E
M;G0M;6%I;"!F;VQD97)S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!A;GD@<V5N="UM86EL(&9O;&1E<G,@=V5R92!D96QE=&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D;TUA:6YT96YA;F-E*"D*("`@('L*
M("`@("`@("!G;&]B86P@)&EM<"P@)&YO=&EF:6-A=&EO;BP@)'!R969S.PH*
M("`@("`@("`O*B!'970@;&ES="!O9B!A;&P@9F]L9&5R<RP@<&%R<V4@=&AR
M;W5G:"!A;F0@9V5T('1H92!L:7-T(&]F(&%L;`H@("`@("`@("`@(&]L9"!S
M96YT+6UA:6P@9F]L9&5R<RX@5&AE;B!S;W)T('1H:7,@87)R87D@86-C;W)D
M:6YG('1O"B`@("`@("`@("`@=&AE(&1A=&4N("HO"B`@("`@("`@:6YC;'5D
M95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@(&EN8VQU9&5?
M;VYC92!)35!?0D%312`N("<O;&EB+T9O;&1E<BYP:'`G.PH*("`@("`@("`D
M:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;BAA<G)A>2@G:6UP)RP@
M)VEM<"<I*3L*("`@("`@("`D:6UP7V9O;&1E<B`]("9)35!?1F]L9&5R.CIS
M:6YG;&5T;VXH*3L*("`@("`@("`D<V5N=%]M86EL7V9O;&1E<G,@/2`D:61E
M;G1I='DM/F=E=$%L;%-E;G1M86EL1F]L9&5R<R@I.PH*("`@("`@("`D9F]L
M9&5R7V%R<F%Y(#T@87)R87DH*3L*("`@("`@("`D;VQD7V9O;&1E<G,@/2`D
M:6UP7V9O;&1E<BT^9FQI<W0H*3L*"B`@("`@("`@9F]R96%C:"`H87)R87E?
M:V5Y<R@D;VQD7V9O;&1E<G,I(&%S("1K*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1S96YT7VUA:6Q?9F]L9&5R<R!A<R`D9F]L9&5R*2!["B`@("`@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UXG("X@<W1R7W)E<&QA8V4H)R\G
M+"`G7"\G+"`D9F]L9&5R*2`N("<M*%M>+5TK*2TH6S`M.5U[-'TI)"]I)RP@
M)&LL("1R96=S*2D@>PH@("`@("`@("`@("`@("`@("`@("1F;VQD97)?87)R
M87E;)&M=(#T@*&ES7VYU;65R:6,H)')E9W-;,5TI*2`_(&UK=&EM92@P+"`P
M+"`P+"1R96=S6S%=+"`Q+"`D<F5G<ULR72D@.B!S=')T;W1I;64H(B1R96=S
M6S%=(#$L("1R96=S6S)=(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@87)S;W)T*"1F;VQD97)?87)R87DL
M(%-/4E1?3E5-15))0RD["@H@("`@("`@("\J(%-E92!I9B!A;GD@9F]L9&5R
M<R!N965D('1O(&)E('!U<F=E9"X@*B\*("`@("`@("`D<'5R9V5?9F]L9&5R
M<R`](&%R<F%Y7W-L:6-E*&%R<F%Y7VME>7,H)&9O;&1E<E]A<G)A>2DL("1P
M<F5F<RT^9V5T5F%L=64H)V1E;&5T95]S96YT;6%I;%]M;VYT:&QY7VME97`G
M*2D["B`@("`@("`@:68@*&-O=6YT*"1P=7)G95]F;VQD97)S*2D@>PH@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D]L9"!S96YT+6UA:6P@
M9F]L9&5R<R!B96EN9R!P=7)G960N(BDL("=H;W)D92YM97-S86=E)RD["@H@
M("`@("`@("`@("`O*B!$96QE=&4@=&AE(&]L9"!F;VQD97)S(&YO=RX@*B\*
M("`@("`@("`@("`@:68@*"1I;7!?9F]L9&5R+3YD96QE=&4H)'!U<F=E7V9O
M;&1E<G,L("1P<F5F<RT^9V5T5F%L=64H)W-U8G-C<FEB92<I*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!I;F9O<FUA=&EO;B!F;W(@=&AE(&UA:6YT96YA;F-E(&9U
M;F-T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!$97-C<FEP
M=&EO;B!O9B!W:&%T('1H92!O<&5R871I;VX@:7,@9V]I;F<@=&\@9&\@9'5R
M:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@=&AI<R!L;V=I;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9&5S8W)I8F5-86EN=&5N86YC92@I"B`@("!["B`@
M("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@<F5T=7)N('-P<FEN=&8H
M7R@B06QL(&]L9"!S96YT+6UA:6P@9F]L9&5R<R!M;W)E('1H86X@)7,@;6]N
M=&AS(&]L9"!W:6QL(&)E(&1E;&5T960N(BDL("1P<F5F<RT^9V5T5F%L=64H
M)V1E;&5T95]S96YT;6%I;%]M;VYT:&QY7VME97`G*2D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+VQI8B]-86EN=&5N86YC92]487-K+V1E;&5T95]A='1A8VAM96YT
M<U]M;VYT:&QY+G!H<``````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-#$Q,P`Q,#0Q-S,V,C<V-@`P,C<R,C,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($UA:6YT96YA;F-E(&UO9'5L92!T:&%T(&1E;&5T97,@;VQD(&QI
M;FME9"!A='1A8VAM96YT<RX*("H*("H@)$AO<F1E.B!I;7`O;&EB+TUA:6YT
M96YA;F-E+U1A<VLO9&5L971E7V%T=&%C:&UE;G1S7VUO;G1H;'DN<&AP+'8@
M,2XT+C$P+C4@,C`P-2\Q,"\Q."`Q,CHQ,SHS-B!J86X@17AP("0*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!!;F1R97<@0V]L96UA;B`\;65R8W5R>4!A
M<'!I<V]L=71I;VYS+FYE=#X*("H@0'!A8VMA9V4@2&]R9&5?36%I;G1E;F%N
M8V4*("HO"F-L87-S($UA:6YT96YA;F-E7U1A<VM?9&5L971E7V%T=&%C:&UE
M;G1S7VUO;G1H;'D@97AT96YD<R!-86EN=&5N86YC95]487-K('L*"B`@("`O
M*BH*("`@("`J(%!U<F=E<R!T:&4@;VQD(&QI;FME9"!A='1A8VAM96YT(&9O
M;&1E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R
M(&%N>2!O;&0@871T86-H;65N=',@=V5R92!D96QE=&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!D;TUA:6YT96YA;F-E*"D*("`@('L*("`@("`@("!G;&]B
M86P@)&-O;F8L("1P<F5F<SL*"B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"
M05-%("X@)R]L:6(O0V]M<&]S92YP:'`G.PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O075T:"YP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G5D93
M+G!H<"<["@H@("`@("`@("\J($9I;F0@=&AE(%5.25@@=&EM97-T86UP(&]F
M('1H92!L87-T('-E8V]N9"!T:&%T('=E('=I;&P@;F]T"B`@("`@("`@("H@
M<'5R9V4N("HO"B`@("`@("`@)&1E;%]T:6UE(#T@9VUM:W1I;64H,"P@,"P@
M,"P@9&%T92@G;B<I("T@)'!R969S+3YG971686QU92@G9&5L971E7V%T=&%C
M:&UE;G1S7VUO;G1H;'E?:V5E<"<I+"`Q+"!D871E*"=9)RDI.PH*("`@("`@
M("`D=F9S(#T@)E9&4SHZ<VEN9VQE=&]N*"1C;VYF6R=V9G,G75LG='EP92==
M+"!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=V9G,G+"`D8V]N9ELG=F9S)UU;
M)W1Y<&4G72DI.PH@("`@("`@("1P871H(#T@24U07U9&4U],24Y+7T%45$%#
M2%]0051(("X@)R\G("X@075T:#HZ9V5T075T:"@I.PH*("`@("`@("`O*B!-
M86ME('-U<F4@8VQE86YI;F<@:7,@9&]N92!R96-U<G-I=F5L>2X@*B\*("`@
M("`@("`D9FEL97,@/2`D=F9S+3YL:7-T1F]L9&5R*"1P871H+"!N=6QL+"!T
M<G5E+"!F86QS92P@=')U92D["B`@("`@("`@:68@*&ES7V$H)&9I;&5S+"`G
M4$5!4E]%<G)O<B<I('Q\("%I<U]A<G)A>2@D9FEL97,I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1F:6QE<R!A<R`D9&ER*2!["B`@("`@("`@("`@("1F:6QE=&EM92`]("AI
M<W-E="@D9&ER6R=D871E)UTI*2`_("1D:7);)V1A=&4G72`Z(&EN='9A;"AB
M87-E;F%M92@D9&ER6R=N86UE)UTI*3L*("`@("`@("`@("`@:68@*"1D96Q?
M=&EM92`^("1F:6QE=&EM92D@>PH@("`@("`@("`@("`@("`@)'9F<RT^9&5L
M971E1F]L9&5R*"1P871H+"`D9&ER6R=N86UE)UTL('1R=64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@9F]R('1H92!M
M86EN=&5N86YC92!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@1&5S8W)I<'1I;VX@;V8@=VAA="!T:&4@;W!E<F%T:6]N(&ES(&=O
M:6YG('1O(&1O(&1U<FEN9PH@("`@("H@("`@("`@("`@("`@("`@('1H:7,@
M;&]G:6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<V-R:6)E36%I;G1E;F%N
M8V4H*0H@("`@>PH@("`@("`@(')E='5R;B!S<')I;G1F*%\H(D%L;"!O;&0@
M;&EN:V5D(&%T=&%C:&UE;G1S(&UO<F4@=&AA;B`E<R!M;VYT:',@;VQD('=I
M;&P@8F4@9&5L971E9"XB*2P@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E
M*"=D96QE=&5?871T86-H;65N='-?;6]N=&AL>5]K965P)RDI.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-86EN=&5N86YC92]I;7`N<&AP````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(S-``Q,#0Q-S,V,C<V
M-@`P,C$U,#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O36%I;G1E;F%N8V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)V9I;&5R;V]T)RP@)VEM<"<I("X@)R]L:6(O8F%S92YP:'`G.PH*+RHJ"B`J
M("1(;W)D93H@:6UP+VQI8B]-86EN=&5N86YC92]I;7`N<&AP+'8@,2XQ.2XQ
M,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z-3D@:F%N($5X<"`D"B`J"B`J(%1H92!-
M86EN=&5N86YC95])35`@8VQA<W,@9&5F:6YE<R!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!R=6X@=7!O;@H@*B!L;V=I;B!T;R!)35`N"B`J"B`J($-O
M<'ER:6=H="`R,#`Q+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($E-4"`S+C`*("H@0'!A8VMA9V4@2&]R9&5?36%I
M;G1E;F%N8V4*("HO"F-L87-S($UA:6YT96YA;F-E7TE-4"!E>'1E;F1S($UA
M:6YT96YA;F-E('L*"B`@("`O*BH*("`@("`J($AA<V@@:&]L9&EN9R!M86EN
M=&5N86YC92!P<F5F97)E;F-E(&YA;65S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1M86EN=%]T87-K<R`](&%R<F%Y*`H@
M("`@("`@("=T;W-?86=R965M96YT)R`@("`@("`@("`@("`@/3X@34%)3E1%
M3D%.0T5?1DE24U1?3$]'24XL"B`@("`@("`@)V9E=&-H;6%I;%]L;V=I;B<@
M("`@("`@("`@("`]/B!-04E.5$5.04Y#15]%5D5262P*("`@("`@("`G<F5N
M86UE7W-E;G1M86EL7VUO;G1H;'DG("`@(#T^($U!24Y414Y!3D-%7TU/3E1(
M3%DL"B`@("`@("`@)V1E;&5T95]S96YT;6%I;%]M;VYT:&QY)R`@("`]/B!-
M04E.5$5.04Y#15]-3TY42$Q9+`H@("`@("`@("=D96QE=&5?871T86-H;65N
M='-?;6]N=&AL>2<@/3X@34%)3E1%3D%.0T5?34].5$A,62P*("`@("`@("`G
M<'5R9V5?=')A<V@G("`@("`@("`@("`@("`@(#T^($U!24Y414Y!3D-%7TU/
M3E1(3%D*("`@("D["@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB
M+T)L;V-K+P``````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8V`#`Q-S`Q-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]L:6(O0FQO8VLO<W5M;6%R>2YP:'``````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34V-3``,3`T,3<S-C(W-C8`,#(Q
M,C(W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@HD8FQO8VM?;F%M92`](%\H(D9O;&1E<B!3=6UM87)Y(BD["@HO
M*BH*("H@)$AO<F1E.B!I;7`O;&EB+T)L;V-K+W-U;6UA<GDN<&AP+'8@,2XU
M-"XR+C8@,C`P-B\P,B\P-2`R,CHT-3HQ,R!J86X@17AP("0*("H*("H@0'!A
M8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7VEM<%]S
M=6UM87)Y(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]
M("=I;7`G.PH*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@<F5T=7)N($AO<F1E.CIL:6YK
M*$AO<F1E.CIU<FPH)')E9VES=')Y+3YG971);FET:6%L4&%G92@I+"!T<G5E
M*2D@+@H@("`@("`@("`@("`D<F5G:7-T<GDM/F=E="@G;F%M92<I("X@)SPO
M83X@.CH@/'-M86QL/B<@+@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@D<F5G
M:7-T<GDM/F-A;&PH)VUA:6PO8V]M<&]S92<I*2`N"B`@("`@("`@("`@($AO
M<F1E.CII;6<H)V-O;7!O<V4N<&YG)RP@7R@B3F5W($UE<W-A9V4B*2D@+B`G
M("<@+@H@("`@("`@("`@("!?*").97<@365S<V%G92(I("X@)SPO83X\+W-M
M86QL/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=S:&]W7W5N<F5A9"<@/3X@87)R87DH)W1Y
M<&4G(#T^("=B;V]L96%N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B3VYL>2!D:7-P;&%Y(&9O
M;&1E<G,@=VET:"!U;G)E860@;65S<V%G97,@:6X@=&AE;3\B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@/3X@,"DL"B`@("`@("`@("`@("`@("`@("`@("=S:&]W7W1O=&%L)R`]
M/B!A<G)A>2@G='EP92<@/3X@)V)O;VQE86XG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E-H;W<@
M=&]T86P@;G5M8F5R(&]F(&UA:6QS(&EN(&9O;&1E<C\B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]
M/B`P*0H@("`@("`@("`@("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]C;VYT96YT*"D*("`@('L*("`@("`@("!G;&]B86P@)&YO=&EF:6-A
M=&EO;BP@)'!R969S+"`D<F5G:7-T<GD["@H@("`@("`@("1'3$]"04Q36R=A
M=71H96YT:6-A=&EO;B==(#T@)VYO;F4G.PH@("`@("`@(')E<75I<F4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN+V)A<V4N<&AP)SL*"B`@("`@("`@)&AT
M;6P@/2`G/'1A8FQE(&)O<F1E<CTB,"(@8V5L;'!A9&1I;F<](C`B(&-E;&QS
M<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^)SL*"B`@("`@("`@)&%U=&@@/2!F
M86QS93L*("`@("`@("!I9B`H24U0.CIC:&5C:T%U=&AE;G1I8V%T:6]N*$]0
M7TA!3$9/4$5.+"!T<G5E*2`]/3T@=')U92D@>PH@("`@("`@("`@("`D875T
M:"`]('1R=64["@H@("`@("`@("`@("`O*B!'970@;&ES="!O9B!M86EL8F]X
M97,@=&\@<&]L;"X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"
M05-%("X@)R]L:6(O24U!4"]4<F5E+G!H<"<["B`@("`@("`@("`@("1I;7!T
M<F5E(#T@)DE-4%]4<F5E.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&9O
M;&1E<G,@/2`D:6UP=')E92T^9V5T4&]L;$QI<W0H*3L*"B`@("`@("`@("`@
M("\J(%%U;W1A(&EN9F\L(&EF(&%V86EL86)L92X@*B\*("`@("`@("`@("`@
M:68@*&ES<V5T*"1?4T534TE/3ELG:6UP)UU;)W%U;W1A)UTI("8F"B`@("`@
M("`@("`@("`@("!I<U]A<G)A>2@D7U-%4U-)3TY;)VEM<"==6R=Q=6]T82==
M*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@
M)R]L:6(O475O=&$N<&AP)SL*("`@("`@("`@("`@("`@("1Q=6]T841R:79E
M<B`]("9)35!?475O=&$Z.G-I;F=L971O;B@D7U-%4U-)3TY;)VEM<"==6R=Q
M=6]T82==6R=D<FEV97(G72P@)%]315-324].6R=I;7`G75LG<75O=&$G75LG
M<&%R86US)UTI.PH@("`@("`@("`@("`@("`@:68@*"1Q=6]T841R:79E<B`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D<75O=&$@/2`D<75O
M=&%$<FEV97(M/F=E=%%U;W1A*"D["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<U]A*"1Q=6]T82P@)U!%05)?17)R;W(G*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("!I<W-E="@D<75O=&%;)W5S86=E)UTI("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@(&ES<V5T*"1Q=6]T85LG;&EM:70G72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1Q=6]T85LG;&EM:70G72`A/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1R
M/CQT9"!C;VQS<&%N/2(T(B!A;&EG;CTB8V5N=&5R(B<["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<75O=&%;)W5S86=E)UT@/2`D<75O=&%;)W5S
M86=E)UT@+R`H,3`R-"`J(#$P,C0N,"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<75O=&%;)VQI;6ET)UT@/2`D<75O=&%;)VQI;6ET)UT@+R`H
M,3`R-"`J(#$P,C0N,"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&5R8V5N="`]("@D<75O=&%;)W5S86=E)UT@*B`Q,#`I("\@)'%U;W1A6R=L
M:6UI="==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1P97)C
M96YT(#X](#DP*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@)R!S='EL93TB8V]L;W(Z<F5D(B<["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:'1M;"`N/2`G/B<@+B!S<')I;G1F*%\H(B4N,F9-0B`O("4N,F9-0B`@*"4N
M,F8E)2DB*2P@)'%U;W1A6R=U<V%G92==+"`D<75O=&%;)VQI;6ET)UTL("1P
M97)C96YT*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]
M("<\+W1D/CPO='(^)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&YE=VUS9W,@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D86YY56YS965N(#T@9F%L<V4["@H@("`@("`@("`@("!F;W)E86-H
M("AA<G)A>5]K97ES*"1F;VQD97)S*2!A<R`D9F]L9&5R*2!["B`@("`@("`@
M("`@("`@("!I9B`H*"1F;VQD97(@/3T@)TE.0D]8)RD@?'P*("`@("`@("`@
M("`@("`@("`@("`H)%]315-324].6R=I;7`G75LG8F%S95]P<F]T;V-O;"==
M("$]("=P;W`S)RDI('L*("`@("`@("`@("`@("`@("`@("`O*B!&:6QT97(@
M;VX@24Y"3U@@9&ES<&QA>2P@:68@<F5Q=65S=&5D+B`J+PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=F:6QT97)?;VY?9&ES
M<&QA>2<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC
M92!)35!?0D%312`N("<O;&EB+T9I;'1E<BYP:'`G.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:6UP7V9I;'1E<B`]("9)35!?1FEL=&5R.CIS:6YG;&5T
M;VXH*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&EM<%]F:6QT97(M/F9I
M;'1E<B@G24Y"3U@G*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("1I;F9O(#T@)&EM<'1R964M/F=E=$5L96UE;G1);F9O
M*"1F;VQD97(I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&EN
M9F\I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7W!A<F%M<ULG<VAO=U]U;G)E860G72D@?'P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("%E;7!T>2@D:6YF;ULG=6YS965N)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R=N97=M
M<V<G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W
M;7-G<ULD9F]L9&5R72`]("1I;F9O6R=N97=M<V<G73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=M86EL8F]X+G!H<"<L('1R=64I+"`G;F]?;F5W;6%I;%]P;W!U<"<L
M(#$I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D=7)L+"`G;6%I;&)O>"<L("1F;VQD97(I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT<B!S='EL93TB
M8W5R<V]R.G!O:6YT97(B(&-L87-S/2)T97AT(B!O;F-L:6-K/2)S96QF+FQO
M8V%T:6]N/5PG)R`N("1U<FP@+B`G7"<B/CQT9#XG.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG=6YS965N)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQS
M=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D86YY
M56YS965N(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL
M:6YK*"1U<FPL($E-4#HZ9&ES<&QA>49O;&1E<B@D9F]L9&5R*2D@+B!)35`Z
M.F1I<W!L87E&;VQD97(H)&9O;&1E<BD@+B`G/"]A/B<["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R=U;G-E96XG72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G
M/"]S=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W1D/CQT9#XF
M;F)S<#LF;F)S<#LF;F)S<#L\+W1D/CQT9#XG.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@(65M<'1Y*"1I;F9O6R=U;G-E96XG72D@
M/R`G/'-T<F]N9SXG("X@)&EN9F];)W5N<V5E;B==("X@)SPO<W1R;VYG/B<@
M.B`G,"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`A
M96UP='DH)'1H:7,M/E]P87)A;7-;)W-H;W=?=&]T86PG72D@/R`G/"]T9#X\
M=&0^*"<@+B`D:6YF;ULG;65S<V%G97,G72`N("<I)R`Z("<G.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SPO=&0^/"]T<CXG.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0@8VQA<W,](G1E
M>'0B/B<@+B!(;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC871I;VY5<FPH)VEN
M9&5X+G!H<"<L('1R=64I+"!S<')I;G1F*%\H(DQO9R!I;B!T;R`E<R(I+"`D
M<F5G:7-T<GDM/F%P<&QI8V%T:6]N<ULG:6UP)UU;)VYA;64G72DI("X@<W!R
M:6YT9BA?*"),;V<@:6X@=&\@)7,B*2P@)')E9VES=')Y+3YA<'!L:6-A=&EO
M;G-;)VEM<"==6R=N86UE)UTI("X@)SPO83X\+W1D/CPO='(^)SL*("`@("`@
M("!]"@H@("`@("`@("1H=&UL("X]("<\+W1A8FQE/B<["@H@("`@("`@("\J
M($-H96-K('1O('-E92!I9B!U<V5R('=A;G1S(&YE=R!M86EL(&YO=&EF:6-A
M=&EO;BP@8G5T(&]N;'D*("`@("`@("`@*B!I9B!T:&4@=7-E<B!I<R!L;V=G
M960@:6YT;R!)35`N("HO"B`@("`@("`@:68@*"1A=71H("8F("1P<F5F<RT^
M9V5T5F%L=64H)VYA=E]P;W!U<"<I*2!["B`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H24U0.CIG971.97=-97-S86=E4&]P=7`H)&YE=VUS9W,I
M+"`G:F%V87-C<FEP="<I.PH@("`@("`@('T*("`@("`@("!I9B`H)&%U=&@@
M)B8*("`@("`@("`@("`@8VQA<W-?97AI<W1S*"=.;W1I9FEC871I;VY?3&ES
M=&5N97)?875D:6\G*2`F)@H@("`@("`@("`@("`D<')E9G,M/F=E=%9A;'5E
M*"=N879?875D:6\G*2D@>PH@("`@("`@("`@("`D9F]U;F0@/2!F86QS93L*
M("`@("`@("`@("`@9F]R96%C:"`H)&YE=VUS9W,@87,@)&UB;W@@/3X@)&YM
M*2!["B`@("`@("`@("`@("`@("!I9B`H)&YM(#X@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1F;W5N9"D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"@D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"D@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+V%U9&EO+W1H965T;VYE
M+G=A=B<L("=A=61I;R<I.PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@571I
M;#HZ8G5F9F5R3W5T<'5T*&%R<F%Y*"1N;W1I9FEC871I;VXL("=N;W1I9GDG
M*2P@87)R87DH)VQI<W1E;F5R<R<@/3X@)V%U9&EO)RDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&%U=&@@)B8@*&-O=6YT*"1N
M97=M<V=S*2`]/2`P("8F"B`@("`@("`@("`@("`@("`@("`@("`A96UP='DH
M)'1H:7,M/E]P87)A;7-;)W-H;W=?=6YR96%D)UTI*2D@>PH@("`@("`@("`@
M("!I9B`H8V]U;G0H)&9O;&1E<G,I(#T](#`I('L*("`@("`@("`@("`@("`@
M("1H=&UL("X](%\H(DYO(&9O;&1E<G,@87)E(&)E:6YG(&-H96-K960@9F]R
M(&YE=R!M86EL+B(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@:68@*"$D86YY56YS965N*2!["B`@("`@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@)SQE;3XG("X@7R@B3F\@9F]L9&5R<R!W:71H('5N<V5E;B!M
M97-S86=E<R(I("X@)SPO96T^)SL*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)VYA
M=E]P;W!U<"<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]
M("<\96T^)R`N(%\H(DYO(&9O;&1E<G,@=VET:"!N97<@;65S<V%G97,B*2`N
M("<\+V5M/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&AT;6P["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M:6(O0FQO8VLO=')E95]F;VQD97)S+G!H<```````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3<S-30`,3`T,3<S-C(W-C8`,#(R,C$R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@HD8FQO8VM?
M;F%M92`](%\H(DUE;G4@1F]L9&5R($QI<W0B*3L*)&)L;V-K7W1Y<&4@/2`G
M=')E92<["@HO*BH*("H@)$AO<F1E.B!I;7`O;&EB+T)L;V-K+W1R965?9F]L
M9&5R<RYP:'`L=B`Q+C(X+C(N,38@,C`P-B\P,2\Q."`Q,3HU.3HT."!J86X@
M17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO
M<F1E7T)L;V-K7VEM<%]T<F5E7V9O;&1E<G,@97AT96YD<R!(;W)D95]";&]C
M:R!["@H@("`@=F%R("1?87!P(#T@)VEM<"<["@H@("`@9G5N8W1I;VX@7V)U
M:6QD5')E92@F)'1R964L("1I;F1E;G0@/2`P+"`D<&%R96YT(#T@;G5L;"D*
M("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D<')E9G,["@H@("`@
M("`@("1'3$]"04Q36R=A=71H96YT:6-A=&EO;B==(#T@)VYO;F4G.PH@("`@
M("`@($!D969I;F4H)TE-4%]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN+RXN)RD["B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312`N
M("<O;&EB+TE-05`O5')E92YP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O261E;G1I='DN<&AP)SL*"B`@("`@("`@+RH@06)O<G0@:6UM961I
M871E;'D@:68@=V4G<F4@;F]T(&-U<G)E;G1L>2!L;V=G960@:6XN("HO"B`@
M("`@("`@:68@*$E-4#HZ8VAE8VM!=71H96YT:6-A=&EO;BA/4%](04Q&3U!%
M3BP@=')U92D@(3T]('1R=64I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0V%L;"!T:&4@;6%I;&)O>"!I8V]N(&AO;VLL
M(&EF(')E<75E<W1E9"X@*B\*("`@("`@("`D;6)O>%]I8V]N<R`](&%R<F%Y
M*"D["B`@("`@("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=H;V]K
M<R==6R=M8F]X7VEC;VXG72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@("`@("`@
M("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?;6)O>%]I8V]N<R<I
M*2!["B`@("`@("`@("`@("`@("`D;6)O>%]I8V]N<R`](&-A;&Q?=7-E<E]F
M=6YC*"=?:6UP7VAO;VM?;6)O>%]I8V]N<R<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!#86-H92!S;VUE(&%D9&ET:6]N86P@=F%L
M=65S+B`J+PH@("`@("`@("1I;6%G95]D:7(@/2`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"D["B`@("`@("`@)'5S95]V=')A<V@@/2`D<')E9G,M/F=E=%9A
M;'5E*"=U<V5?=G1R87-H)RD["@H@("`@("`@("\J($EN:71I86QI>F4@=&AE
M('5S97(G<R!I9&5N=&ET:65S+B`J+PH@("`@("`@("1I9&5N=&ET>2`]("9)
M9&5N=&ET>3HZ<VEN9VQE=&]N*&%R<F%Y*"=I;7`G+"`G:6UP)RDI.PH*("`@
M("`@("`D=')E92T^861D3F]D92@D<&%R96YT("X@)V-O;7!O<V4G+"`D<&%R
M96YT+"!?*").97<@365S<V%G92(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("1I;F1E;G0L(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=I8V]N)R`]/B`G8V]M<&]S92YP;F<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=I8V]N9&ER)R`]/B`D:6UA9V5?9&ER+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=U<FPG(#T^($E-4#HZ8V]M<&]S94QI;FLH
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&%R9V5T)R`]/B`D
M<')E9G,M/F=E=%9A;'5E*"=C;VUP;W-E7W!O<'5P)RD@/R`G:&]R9&5?;65N
M=2<@.B`G:&]R9&5?;6%I;B<I*3L*"B`@("`@("`@+RH@061D(&QI;FL@=&\@
M=&AE('-E87)C:"!P86=E+B`J+PH@("`@("`@("1T<F5E+3YA9&1.;V1E*"1P
M87)E;G0@+B`G<V5A<F-H)RP@)'!A<F5N="P@7R@B4V5A<F-H(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@)&EN9&5N="P@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)VEC;VXG(#T^("=S96%R8V@N<&YG)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;F1I<B<@/3X@)')E9VES
M=')Y+3YG971);6%G941I<B@G:&]R9&4G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=7)L)R`]/B!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E
M87)C:"YP:'`G*2DI.PH*("`@("`@("!I9B`H)%]315-324].6R=I;7`G75LG
M8F%S95]P<F]T;V-O;"==(#T]("=P;W`S)RD@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`O*B!'970@<W!E8VEA;"!F;VQD97)S
M+B`J+PH@("`@("`@("1T<F%S:"`]($E-4#HZ9F]L9&5R4')E9B@D<')E9G,M
M/F=E=%9A;'5E*"=T<F%S:%]F;VQD97(G*2P@=')U92D["B`@("`@("`@)&1R
M869T(#T@24U0.CIF;VQD97)0<F5F*"1P<F5F<RT^9V5T5F%L=64H)V1R869T
M<U]F;VQD97(G*2P@=')U92D["B`@("`@("`@)'-E;G0@/2`D:61E;G1I='DM
M/F=E=$%L;%-E;G1M86EL1F]L9&5R<R@I.PH*("`@("`@("`D;F%M95]U<FP@
M/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=M
M86EL8F]X+G!H<"<I+"`G;F]?;F5W;6%I;%]P;W!U<"<L(#$I.PH*("`@("`@
M("`O*B!);FET:6%L:7IE('1H92!)35!?5')E92!O8FIE8W0N("HO"B`@("`@
M("`@)&EM<'1R964@/2`F24U07U1R964Z.G-I;F=L971O;B@I.PH@("`@("`@
M("1M87-K(#T@24U!4%12145?3D585%]32$]70TQ/4T5$.PH@("`@("`@(&EF
M("@D<')E9G,M/F=E=%9A;'5E*"=S=6)S8W)I8F4G*2`F)@H@("`@("`@("`@
M("!D969I;F5D*"=)34%05%)%15].15A47U-(3U=354(G*2D@>PH@("`@("`@
M("`@("`D;6%S:R!\/2!)34%05%)%15].15A47U-(3U=354(["B`@("`@("`@
M?0H*("`@("`@("`O*B!3=&%R="!I=&5R871I;F<@=&AR;W5G:"!T:&4@;&ES
M="!O9B!M86EL8F]X97,L(&1I<W!L87EI;F<@=&AE;2X@*B\*("`@("`@("`D
M=6YS965N(#T@,#L*("`@("`@("`D:6YB;W@@/2!N=6QL.PH@("`@("`@("1M
M86EL8F]X(#T@)&EM<'1R964M/G)E<V5T*"D["B`@("`@("`@:68@*"1M86EL
M8F]X*2!["B`@("`@("`@("`@(&1O('L*("`@("`@("`@("`@("`@("1N;V1E
M7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@("`@("`@("`@("`@:68@*"$D:6UP
M=')E92T^:7-#;VYT86EN97(H)&UA:6QB;W@I*2!["B`@("`@("`@("`@("`@
M("`@("`@+RH@5V4@87)E(&1E86QI;F<@=VET:"!M86EL8F]X97,@:&5R92X@
M1&5T97)M:6YE(&EF('=E"B`@("`@("`@("`@("`@("`@("`@("H@;F5E9"!T
M;R!P;VQL('1H:7,@;6%I;&)O>"!F;W(@;F5W(&UE<W-A9V5S+B`J+PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D:6UP=')E92T^:7-0;VQL960H)&UA:6QB
M;W@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J($EF('=E(&YE960@
M;65S<V%G92!I;F9O<FUA=&EO;B!F;W(@=&AI<R!F;VQD97(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`J('5P9&%T92!I="!N;W<N("HO"B`@("`@("`@
M("`@("`@("`@("`@("`@("1M<V=S7VEN9F\@/2`D:6UP=')E92T^9V5T16QE
M;65N=$EN9F\H)&UA:6QB;WA;)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1M<V=S7VEN9F\I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O*B!(:6=H;&EG:'0@;6%I;&)O>&5S('=I=&@@
M=6YR96%D(&UE<W-A9V5S(&EN"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*B!B;VQD+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D;7-G<U]I;F9O6R=U;G-E96XG72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=6YS965N("L]("1M<V=S7VEN9F];)W5N
M<V5E;B==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M86EL
M8F]X6R=L86)E;"==(#T@)SQS<&%N(&1I<CTB;'1R(CX\<W1R;VYG/B<@+B`D
M;6%I;&)O>%LG;&%B96PG72`N("<\+W-T<F]N9SX@*"<@+B`D;7-G<U]I;F9O
M6R=U;G-E96XG72`N("<I(#PO<W!A;CXG.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O*B!)9B!T:&ES
M(&ES('1H92!)3D)/6"P@<V%V92!I="!T;R!L871E<B!R97=R:71E(&]U<B!P
M87)E;G0*("`@("`@("`@("`@("`@("`@("`@*B!N;V1E('1O(&EN8VQU9&4@
M;F5W(&UA:6P@;F]T:69I8V%T:6]N+B`J+PH@("`@("`@("`@("`@("`@("`@
M(&EF("AS=')C87-E8VUP*"1M86EL8F]X6R=V86QU92==+"`G24Y"3U@G*2`]
M/2`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F)O>"`]("1M86EL
M8F]X.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@
M("`@<W=I=&-H("@D;6%I;&)O>%LG=F%L=64G72D@>PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)TE.0D]8)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M)&1I<C(@/2`G:6YB;W@N<&YG)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)'1R87-H.@H@("`@
M("`@("`@("`@("`@("`@("`@("`D9&ER,B`]("@D=7-E7W9T<F%S:"D@/R`G
M9F]L9&5R+G!N9R<@.B`G=')A<V@N<&YG)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)&1R869T
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D9&ER,B`]("=D<F%F=',N<&YG
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D:6UP=')E92T^:7-61F]L9&5R*"1M86EL8F]X*2`F)@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VEM<%]S96%R8V@G72T^:7-6
M5')A<VA&;VQD97(H)&UA:6QB;WA;)W9A;'5E)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&ER,B`]("=T<F%S:"YP;F<G.PH@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&EM<'1R964M/FES5D9O;&1E
M<B@D;6%I;&)O>"D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES5DE.0D]81F]L9&5R*"1M
M86EL8F]X6R=V86QU92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1I<C(@/2`G:6YB;W@N<&YG)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*&EN7V%R<F%Y*"1M86EL8F]X6R=V86QU92==+"`D<V5N
M="DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D:7(R(#T@)W-E
M;G0N<&YG)SL*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D:7(R(#T@)V9O;&1E<BYP;F<G
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+RH@5V4@87)E
M(&1E86QI;F<@=VET:"!F;VQD97)S(&AE<F4N("HO"B`@("`@("`@("`@("`@
M("`@("`@)&1I<C(@/2`G9F]L9&5R+G!N9R<["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M8F]X7VEC;VYS6R1M86EL
M8F]X6R=V86QU92==72D@)B8*("`@("`@("`@("`@("`@("`@("!P<F5G7VUA
M=&-H*"<O<W)C/2(H6UXB72LI(B\G+"`D;6)O>%]I8V]N<ULD;6%I;&)O>%LG
M=F%L=64G75TL("1M871C:"DI('L*("`@("`@("`@("`@("`@("`@("`D:6-O
M;B`]("1M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("`D:6-O;F1I<B`]
M("<G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D:6-O;B`]("=F;VQD97)S+R<@+B`D9&ER,CL*("`@("`@("`@("`@
M("`@("`@("`D:6-O;F1I<B`]("1I;6%G95]D:7(["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)&YO9&5?<&%R86US("L](&%R<F%Y*"=I
M8V]N)R`]/B`D:6-O;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:6-O;F1I<B<@/3X@)&EC;VYD:7(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@*"1I;7!T<F5E+3YI
M<T-O;G1A:6YE<B@D;6%I;&)O>"DI(#\@;G5L;"`Z(%5T:6PZ.F%D9%!A<F%M
M971E<B@D;F%M95]U<FPL("=M86EL8F]X)RP@)&UA:6QB;WA;)W9A;'5E)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@
M("`@("`@("`@("`@("1T<F5E+3YA9&1.;V1E*"1P87)E;G0@+B`D;6%I;&)O
M>%LG=F%L=64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M87)E;G0@+B`D;6%I;&)O>%LG<&%R96YT)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;6%I;&)O>%LG;&%B96PG72P@)&EN9&5N="`K("1M
M86EL8F]X6R=L979E;"==+"!F86QS92P@)&YO9&5?<&%R86US*3L*("`@("`@
M("`@("`@?2!W:&EL92`H*"1M86EL8F]X(#T@)&EM<'1R964M/FYE>'0H)&UA
M<VLI*2D["B`@("`@("`@?0H*("`@("`@("`O*B!792!W86YT('1O(')E=W)I
M=&4@=&AE('!A<F5N="!N;V1E(&]F('1H92!)3D)/6"!T;R!I;F-L=61E(&YE
M=R!M86EL"B`@("`@("`@("H@;F]T:69I8V%T:6]N+B`J+PH@("`@("`@(&EF
M("@D:6YB;W@I('L*("`@("`@("`@("`@)'5R;"`]("1R96=I<W1R>2T^9V5T
M*"=U<FPG+"`D<&%R96YT*3L*("`@("`@("`@("`@:68@*&5M<'1Y*"1U<FPI
M*2!["B`@("`@("`@("`@("`@("!I9B`H*"1R96=I<W1R>2T^9V5T*"=S=&%T
M=7,G+"`D<&%R96YT*2`]/2`G:&5A9&EN9R<I('Q\"B`@("`@("`@("`@("`@
M("`@("`@(21R96=I<W1R>2T^9V5T*"=W96)R;V]T)RDI('L*("`@("`@("`@
M("`@("`@("`@("`D=7)L(#T@;G5L;#L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)')E
M9VES=')Y+3YG971);FET:6%L4&%G92@D<&%R96YT*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1N;V1E7W!A<F%M
M<R`](&%R<F%Y*"=U<FPG(#T^("1U<FPL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=I8V]N)R`]/B`D<F5G:7-T<GDM/F=E="@G:6-O;B<L
M("1P87)E;G0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:6-O;F1I<B<@/3X@)R<I.PH@("`@("`@("`@("`D;65N=5]P87)E;G0@/2`D
M<F5G:7-T<GDM/F=E="@G;65N=5]P87)E;G0G+"`D<&%R96YT*3L*("`@("`@
M("`@("`@)&YA;64@/2`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1P87)E;G0I
M.PH@("`@("`@("`@("!I9B`H)'5N<V5E;BD@>PH@("`@("`@("`@("`@("`@
M)&YO9&5?<&%R86US6R=I8V]N)UT@/2`G;F5W;6%I;"YP;F<G.PH@("`@("`@
M("`@("`@("`@)&YO9&5?<&%R86US6R=I8V]N9&ER)UT@/2`D:6UA9V5?9&ER
M.PH@("`@("`@("`@("`@("`@)'1R964M/F%D9$YO9&4H)'!A<F5N="P@)&UE
M;G5?<&%R96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R
M:6YT9B@G/'-T<F]N9SXE<SPO<W1R;VYG/B`H)7,I)RP@)&YA;64L("1U;G-E
M96XI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9&5N="`M
M(#$L(&9A;'-E+"`D;F]D95]P87)A;7,I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1R964M/F%D9$YO9&4H)'!A<F5N="P@)&UE
M;G5?<&%R96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA
M;64L("1I;F1E;G0@+2`Q+"!F86QS92P@)&YO9&5?<&%R86US*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O;&EB+T-R>7!T+P``````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8V
M`#`Q-S`V-``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O0W)Y<'0O
M4$=0+G!H<```````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M-38T,#,`,3`T,3<S-C(W-C8`,#(P,C,P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO
M<F1E+T-R>7!T+W!G<"YP:'`G.PH*+RHJ"B`J($YA;64@;V8@4$=0('!U8FQI
M8R!K97D@9FEE;&0@:6X@861D<F5S<V)O;VLN"B`J+PID969I;F4H)TE-4%]0
M1U!?4%5"2T597T9)14Q$)RP@)W!G<%!U8FQI8TME>2<I.PH*+RHJ"B`J(%1H
M92!)35!?4$=0.CH@8VQA<W,@8V]N=&%I;G,@86QL(&9U;F-T:6]N<R!R96QA
M=&5D('1O(&AA;F1L:6YG"B`J(%!'4"!M97-S86=E<R!W:71H:6X@24U0+@H@
M*@H@*B`D2&]R9&4Z(&EM<"]L:6(O0W)Y<'0O4$=0+G!H<"QV(#$N.3`N,BXQ
M-"`R,#`V+S`R+S(Q(#`P.C(Q.C(Q('-L=7-A<GH@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/@H@*B!`<VEN8V4@("!)35`@-"XP"B`J($!P86-K86=E($E-4`H@*B\*8VQA
M<W,@24U07U!'4"!E>'1E;F1S($AO<F1E7T-R>7!T7W!G<"!["@H@("`@+RHJ
M"B`@("`@*B!4:&4@;&ES="!O9B!A=F%I;&%B;&4@<V]U<F-E<R!T;R!S96%R
M8V@@9F]R(&ME>7,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]S;W5R8V5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($E-4%]01U`H*0H@
M("`@>PH@("`@("`@("\J($=E="!T:&4@;&ES=&EN9R!O9B!A;&P@<V]U<F-E
M<R!W92!S96%R8V@@9F]R('!U8FQI8R!K97ES+B`J+PH@("`@("`@(&EF("@H
M)'-O=7)C97,@/2`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W-E87)C
M:%]S;W5R8V5S)RDI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E<R`]
M(&5X<&QO9&4H(EQT(BP@)'-O=7)C97,I.PH@("`@("`@("`@("!I9B`H*&-O
M=6YT*"1T:&ES+3Y?<V]U<F-E<RD@/3T@,2D@)B8@96UP='DH)'1H:7,M/E]S
M;W5R8V5S6S!=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V5S
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<&%R96YT.CI(;W)D95]#<GEP=%]P9W`H87)R87DH)W!R;V=R86TG(#T^("1'
M3$]"04Q36R=C;VYF)UU;)W5T:6QS)UU;)V=N=7!G)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1E;7`G(#T^($AO<F1E.CIG
M971496UP1&ER*"DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E
M('1H92!P97)S;VYA;"!0=6)L:6,O4')I=F%T92!K97EP86ER(&%N9"!S=&]R
M92!I;B!P<F5F<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96%L
M;F%M92`@("`@("`@("`@(%-E92!(;W)D95]#<GEP=%]P9W`Z.@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D96UA:6P@("`@("`@("`@("`@("!3964@2&]R9&5?
M0W)Y<'1?<&=P.CH*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-P:')A<V4@
M("`@("`@("`@4V5E($AO<F1E7T-R>7!T7W!G<#HZ"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;VUM96YT("`@("`@("`@("`@(%-E92!(;W)D95]#<GEP=%]P
M9W`Z.@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y;&5N9W1H("`@("`@("`@
M("!3964@2&]R9&5?0W)Y<'1?<&=P.CH*("`@("`J"B`@("`@*B!`<F5T=7)N
M(%!%05)?17)R;W(@(%)E='5R;G,@82!014%27T5R<F]R(&]B:F5C="!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5097)S;VYA;$ME
M>7,H)&YA;64L("1E;6%I;"P@)'!A<W-P:')A<V4L("1C;VUM96YT(#T@)R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y;&5N9W1H
M(#T@,3`R-"D*("`@('L*("`@("`@("`D:V5Y<R`]("1T:&ES+3YG96YE<F%T
M94ME>2@D;F%M92P@)&5M86EL+"`D<&%S<W!H<F%S92P@)&-O;6UE;G0L("1K
M97EL96YG=&@I.PH@("`@("`@(&EF("AI<U]A*"1K97ES+"`G4$5!4E]%<G)O
M<B<I*2!R971U<FX@)&ME>7,["@H@("`@("`@("\J(%-T;W)E('1H92!K97ES
M(&EN('1H92!U<V5R)W,@<')E9F5R96YC97,N("HO"B`@("`@("`@)'1H:7,M
M/F%D9%!E<G-O;F%L4'5B;&EC2V5Y*"1K97ES6R=P=6)L:6,G72D["B`@("`@
M("`@)'1H:7,M/F%D9%!E<G-O;F%L4')I=F%T94ME>2@D:V5Y<ULG<')I=F%T
M92==*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!T:&4@<&5R<V]N86P@
M<'5B;&EC(&ME>2!T;R!T:&4@<')E9G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1P=6)L:6-?:V5Y("!4:&4@<'5B;&EC(&ME>2!T;R!A9&0@*&5I
M=&AE<B!S=')I;F<@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DI+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1097)S;VYA;%!U
M8FQI8TME>2@D<'5B;&EC7VME>2D*("`@('L*("`@("`@("`D1TQ/0D%,4ULG
M<')E9G,G72T^<V5T5F%L=64H)W!G<%]P=6)L:6-?:V5Y)RP@*&ES7V%R<F%Y
M*"1P=6)L:6-?:V5Y*2D@/R!I;7!L;V1E*"<G+"`D<'5B;&EC7VME>2D@.B`D
M<'5B;&EC7VME>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@=&AE('!E
M<G-O;F%L('!R:79A=&4@:V5Y('1O('1H92!P<F5F<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)'!R:79A=&5?:V5Y("!4:&4@<')I=F%T92!K97D@
M=&\@861D("AE:71H97(@<W1R:6YG(&]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9%!E<G-O;F%L4')I=F%T94ME>2@D<')I=F%T95]K97DI"B`@("!["B`@("`@
M("`@)$=,3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=P9W!?<')I=F%T95]K
M97DG+"`H:7-?87)R87DH)'!R:79A=&5?:V5Y*2D@/R!I;7!L;V1E*"<G+"`D
M<')I=F%T95]K97DI(#H@)'!R:79A=&5?:V5Y*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!T:&4@<&5R<V]N86P@<'5B;&EC(&ME>2!F<F]M('1H92!P
M<F5F<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!E<G-O
M;F%L(%!'4"!P=6)L:6,@:V5Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710
M97)S;VYA;%!U8FQI8TME>2@I"B`@("!["B`@("`@("`@<F5T=7)N("1'3$]"
M04Q36R=P<F5F<R==+3YG971686QU92@G<&=P7W!U8FQI8U]K97DG*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<&5R<V]N86P@<')I=F%T92!K
M97D@9G)O;2!T:&4@<')E9G,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!P97)S;VYA;"!01U`@<')I=F%T92!K97DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!E<G-O;F%L4')I=F%T94ME>2@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G<&=P7W!R
M:79A=&5?:V5Y)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H
M92!S<&5C:69I960@<&5R<V]N86P@:V5Y<R!F<F]M('1H92!P<F5F<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&5L971E4&5R<V]N86Q+97ES*"D*("`@('L*
M("`@("`@("`D1TQ/0D%,4ULG<')E9G,G72T^<V5T5F%L=64H)W!G<%]P=6)L
M:6-?:V5Y)RP@)R<I.PH@("`@("`@("1'3$]"04Q36R=P<F5F<R==+3YS9716
M86QU92@G<&=P7W!R:79A=&5?:V5Y)RP@)R<I.PH*("`@("`@("`D=&AI<RT^
M=6YS971087-S<&AR87-E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M82!P=6)L:6,@:V5Y('1O(&%N(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P=6)L:6-?:V5Y("!!;B!01U`@<'5B;&EC(&ME
M>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!3964@2&]R9&5?0W)Y
M<'1?<&=P.CIP9W!086-K971);F9O<FUA=&EO;B@I"B`@("`@*B`@("`@("`@
M("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;W(@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9%!U8FQI8TME>2@D<'5B;&EC7VME>2D*("`@('L*
M("`@("`@("`O*B!-86ME('-U<F4@=&AE(&ME>2!I<R!V86QI9"X@*B\*("`@
M("`@("`D:V5Y7VEN9F\@/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M871I;VXH
M)'!U8FQI8U]K97DI.PH@("`@("`@(&EF("@A:7-S970H)&ME>5]I;F9O6R=S
M:6=N871U<F4G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@?0H*("`@("`@("`O*B!296UO=F4@=&AE("=?4TE'
M3D%455)%)R!E;G1R>2X@*B\*("`@("`@("!U;G-E="@D:V5Y7VEN9F];)W-I
M9VYA='5R92==6R=?4TE'3D%455)%)UTI.PH*("`@("`@("`O*B!3=&]R92!A
M;&P@<VEG;F%T=7)E<R!T:&%T(&%P<&5A<B!I;B!T:&4@:V5Y+B`J+PH@("`@
M("`@(&9O<F5A8V@@*"1K97E?:6YF;ULG<VEG;F%T=7)E)UT@87,@)&ED(#T^
M("1S:6<I('L*("`@("`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E('1H
M92!K97D@9&]E<R!N;W0@86QR96%D>2!E>&ES="!I;B!!3ED*("`@("`@("`@
M("`@("`@861D<F5S<R!B;V]K(&%N9"!R96UO=F5S('1H92!I9"!F<F]M('1H
M92!K97E?:6YF;R!F;W(@80H@("`@("`@("`@("`@("!C;W)R96-T(&]U='!U
M="X@*B\*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YG9710=6)L:6-+
M97DH)'-I9ULG96UA:6PG72P@;G5L;"P@=')U92D["B`@("`@("`@("`@(&EF
M("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I("8F("%E;7!T>2@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)&ME>5]I;F9O6R=S:6=N
M871U<F4G75LD:61=*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O*B!!9&0@:V5Y('1O('1H92!U<V5R
M)W,@861D<F5S<R!B;V]K+B`J+PH@("`@("`@("`@("`D<F5S=6QT(#T@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)V-O;G1A8W1S+V%D9$9I96QD)RP@
M87)R87DH)'-I9ULG96UA:6PG72P@)'-I9ULG;F%M92==+"!)35!?4$=07U!5
M0DM%65]&245,1"P@)'!U8FQI8U]K97DL("1'3$]"04Q36R=P<F5F<R==+3YG
M971686QU92@G861D7W-O=7)C92<I*2D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&ME>5]I;F9O.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F5S(&$@<'5B;&EC(&ME>2!B>2!E+6UA:6PN"B`@("`@*B!&:7)S="P@
M=&AE(&ME>2!W:6QL(&)E(&%T=&5M<'1E9"!T;R!B92!R971R:65V960@9G)O
M;2!A('5S97(G<PH@("`@("H@861D<F5S<R!B;V]K*',I+@H@("`@("H@4V5C
M;VYD+"!I9B!U;G-U8V-E<W-F=6PL('1H92!K97D@:7,@871T96UP=&5D('1O
M(&)E(')E=')I979E9"!V:6$*("`@("`J(&$@<'5B;&EC(%!'4"!K97ES97)V
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<F5S<R`@("`@
M(%1H92!E+6UA:6P@861D<F5S<R!T;R!S96%R8V@@8GDN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F:6YG97)P<FEN="`@5&AE(&9I;F=E<G!R:6YT(&]F('1H
M92!U<V5R)W,@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@4$=0('!U8FQI8R!K97D@<F5Q=65S=&5D+B!2971U<FYS(%!%05)?17)R
M;W(@;V)J96-T"B`@("`@*B`@("`@("`@("`@("`@("`@;VX@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%!U8FQI8TME>2@D861D<F5S<RP@)&9I
M;F=E<G!R:6YT(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!4<GD@<F5T<FEE
M=FEN9R!B>2!E+6UA:6P@;VYL>2!F:7)S="X@*B\*("`@("`@("`D<F5S=6QT
M(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)V-O;G1A8W1S+V=E=$9I
M96QD)RP@87)R87DH)&%D9')E<W,L($E-4%]01U!?4%5"2T597T9)14Q$+"`D
M=&AI<RT^7W-O=7)C97,I*3L*"B`@("`@("`@+RH@5$]$3SH@4F5T<FEE=F4@
M8GD@240N("HO"@H@("`@("`@("\J(%1R>2!R971R:65V:6YG('9I82!A(%!'
M4"!P=6)L:6,@:V5Y<V5R=F5R+B`J+PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RD@)B8@(65M<'1Y*"1F:6YG97)P<FEN="DI('L*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YG971&<F]M4'5B;&EC2V5Y
M<V5R=F5R*"1F:6YG97)P<FEN="D["B`@("`@("`@?0H*("`@("`@("`O*B!3
M964@:68@=&AE(&%D9')E<W,@<&]I;G1S('1O('1H92!U<V5R)W,@<'5B;&EC
M(&ME>2X@*B\*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I
M='DN<&AP)SL*("`@("`@("`@("`@)&ED96YT:71Y(#T@)DED96YT:71Y.CIS
M:6YG;&5T;VXH87)R87DH)VEM<"<L("=I;7`G*2D["B`@("`@("`@("`@("1P
M97)S;VYA;%]P=6)K97D@/2`D=&AI<RT^9V5T4&5R<V]N86Q0=6)L:6-+97DH
M*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D<&5R<V]N86Q?<'5B:V5Y*2`F
M)B`D:61E;G1I='DM/FAA<T%D9')E<W,H)&%D9')E<W,I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'!E<G-O;F%L7W!U8FME>3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971R:65V97,@86QL('!U8FQI8R!K97ES(&9R;VT@
M82!U<V5R)W,@861D<F5S<R!B;V]K*',I+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($%L;"!01U`@<'5B;&EC(&ME>7,@879A:6QA8FQE+B!2971U
M<FYS(%!%05)?17)R;W(@;V)J96-T"B`@("`@*B`@("`@("`@("`@("`@("!O
M;B!E<G)O<BX*("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W10=6)L
M:6-+97ES*"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]S;W5R
M8V5S*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F-A;&PH)V-O;G1A8W1S+V=E=$%L;$%T=')I8G5T959A;'5E<R<L(&%R
M<F%Y*$E-4%]01U!?4%5"2T597T9)14Q$+"`D=&AI<RT^7W-O=7)C97,I*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<'5B
M;&EC(&ME>2!F<F]M(&$@=7-E<B=S(&%D9')E<W,@8F]O:RAS*2!B>2!E+6UA
M:6PN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D96UA:6P@(%1H92!E
M+6UA:6P@861D<F5S<R!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!014%27T5R<F]R("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&50=6)L:6-+97DH)&5M
M86EL*0H@("`@>PH@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^8V%L;"@G8V]N=&%C=',O9&5L971E1FEE;&0G+"!A<G)A>2@D96UA:6PL
M($E-4%]01U!?4%5"2T597T9)14Q$+"`D=&AI<RT^7W-O=7)C97,I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%!A<G-E(&$@;65S<V%G92!I;G1O(&ET<R!0
M1U`@8V]M<&]N96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M97AT("!3964@2&]R9&5?0W)Y<'1?<&=P.CIP87)S95!'4$1A=&$H*0H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%)E='5R;G,@86X@87)R87D@;V8@
M34E-15]087)T(&]B:F5C=',N"B`@("`@*B`@("`@("`@("`@("`@("!)9B!T
M:&5R92!W87,@;F\@4$=0(&1A=&$L(')E='5R;G,@9F%L<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9P87)S94UE<W-A9V4H)'1E>'0I"B`@("!["B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3YP87)S95!'4$1A=&$H)'1E>'0I.PH@("`@
M("`@(&EF("AE;7!T>2@D<F5S=6QT*2!\?`H@("`@("`@("`@("`H*&-O=6YT
M*"1R97-U;'0I(#T](#$I("8F("@D<F5S=6QT6S!=6R=T>7!E)UT@/3T@4$=0
M7T%234]27U1%6%0I*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@9F%L<V4[
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@:6YC;'5D95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*"B`@("`@
M("`@)')E='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@(')E<V5T*"1R
M97-U;'0I.PH@("`@("`@(&1O('L*("`@("`@("`@("`@)&)L;V-K(#T@8W5R
M<F5N="@D<F5S=6QT*3L*("`@("`@("`@("`@)'1E;7!?<&%R="`]("9N97<@
M34E-15]087)T*"D["B`@("`@("`@("`@("1T96UP7W!A<G0M/G-E=$-O;G1E
M;G1S*&EM<&QO9&4H(EQN(BP@)&)L;V-K6R=D871A)UTI*3L*"B`@("`@("`@
M("`@("\J(%-I;F-E('!R:79A=&4@:V5Y<R!S:&]U;&0@3D5615(@8F4@<V5N
M="!A8W)O<W,@96UA:6P@*&EN(&9A8W0L"B`@("`@("`@("`@("`@('1H97)E
M(&ES(&YO($U)344@='EP92!T;R!H86YD;&4@=&AE;2D@=V4@=VEL;"!R96YD
M97(@=&AE;2P@:68*("`@("`@("`@("`@("`@<V]M96]N92!I<R!F;V]L:7-H
M(&5N;W5G:"!T;R!S96YD(&]N92P@:6X@<VEM<&QE('1E>'0N("HO"B`@("`@
M("`@("`@(&EF("@H)&)L;V-K6R=T>7!E)UT@/3T@4$=07T%234]27U1%6%0I
M('Q\"B`@("`@("`@("`@("`@("`H)&)L;V-K6R=T>7!E)UT@/3T@4$=07T%2
M34]27U!2259!5$5?2T59*2D@>PH@("`@("`@("`@("`@("`@)'1E;7!?<&%R
M="T^<V5T5'EP92@G=&5X="]P;&%I;B<I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&)L;V-K6R=T>7!E)UT@/3T@4$=07T%234]27U!50DQ)0U]+15DI('L*
M("`@("`@("`@("`@("`@("1T96UP7W!A<G0M/G-E=%1Y<&4H)V%P<&QI8V%T
M:6]N+W!G<"UK97ES)RD["B`@("`@("`@("`@('T@96QS96EF("@D8FQO8VM;
M)W1Y<&4G72`]/2!01U!?05)-3U)?34534T%'12D@>PH@("`@("`@("`@("`@
M("`@)'1E;7!?<&%R="T^<V5T5'EP92@G87!P;&EC871I;VXO<&=P+65N8W)Y
M<'1E9"<I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&)L;V-K6R=T>7!E)UT@
M/3T@4$=07T%234]27U-)1TY%1%]-15-304=%*2!["B`@("`@("`@("`@("`@
M("`D=&5M<%]P87)T+3YS9714>7!E*"=A<'!L:6-A=&EO;B]P9W`M<VEG;F%T
M=7)E)RD["B`@("`@("`@("`@("`@("!I9B`H*"1B;&]C:R`](&YE>'0H)')E
M<W5L="DI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8FQO
M8VLI("8F("@D8FQO8VM;)W1Y<&4G72`]/2!01U!?05)-3U)?4TE'3D%455)%
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&5M<%]P87)T+3YA<'!E
M;F1#;VYT96YT<R@B7&XB("X@:6UP;&]D92@B7&XB+"`D8FQO8VM;)V1A=&$G
M72DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E:68@*"1B;&]C:ULG='EP92==(#T](%!'4%]!
M4DU/4E]324=.05154D4I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6UT@/2`D
M=&5M<%]P87)T.PH@("`@("`@('T@=VAI;&4@*&YE>'0H)')E<W5L="DI.PH*
M("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;F1E<G,@82!T97AT(&UE<W-A9V4@=VET:"!01U`@8V]M<&]N
M96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D<&%R="`@
M("`@("`@("!4:&4@34E-15]087)T(&-O;G1A:6YI;F<@=&AE(&1A=&$@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E;F1E
M<BX*("`@("`J($!P87)A;2!-24U%7T-O;G1E;G1S("8D8V]N=&5N=',@(%1H
M92!-24U%7T-O;G1E;G1S.CH@;6]D=6QE('1O('5S92!T;PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W5T<'5T('1H92!T97AT
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!2971U<FYS('1H92!R
M96YD97)E9"!T97AT+@H@("`@("H@("`@("`@("`@("`@("`@($EF('1H97)E
M('=A<R!N;R!01U`@9&%T82P@<F5T=7)N<R!F86QS92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<&%R<V5-97-S86=E3W5T<'5T*"8D<&%R="P@)B1C;VYT96YT
M<RD*("`@('L*("`@("`@("!I9B`H(2@D<&%R=',@/2`F)'1H:7,M/G!A<G-E
M365S<V%G92@D<&%R="T^9V5T0V]N=&5N=',H*2DI*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T97AT(#T@)R<[
M"@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]-97-S86=E+G!H
M<"<["@H@("`@("`@("1B87-E7V]B(#T@)B1C;VYT96YT<RT^9V5T0F%S94]B
M:F5C=%!T<B@I.PH@("`@("`@("1A9&1R(#T@)&)A<V5?;V(M/F=E=$9R;VU!
M9&1R97-S*"D["@H@("`@("`@("1M97-S86=E(#T@)FYE=R!-24U%7TUE<W-A
M9V4H*3L*("`@("`@("!F;W)E86-H("@D<&%R=',@87,@)'9A;"D@>PH@("`@
M("`@("`@("`D;65S<V%G92T^861D4&%R="@D=F%L*3L*("`@("`@("!]"@H@
M("`@("`@("1M8R`]("9N97<@34E-15]#;VYT96YT<R@D;65S<V%G92P@87)R
M87DH)V1O=VYL;V%D)R`]/B`G9&]W;FQO861?871T86-H)RP@)W9I97<G(#T^
M("=V:65W7V%T=&%C:"<I+"!A<G)A>2@F)&-O;G1E;G1S*2D["B`@("`@("`@
M)&UE<W-A9V4M/F)U:6QD365S<V%G92@I.PH*("`@("`@("!F;W)E86-H("@D
M;65S<V%G92T^9V5T4&%R=',H*2!A<R`D=F%L*2!["B`@("`@("`@("`@("\J
M($EF('1H92!P87)T(&%P<&5A<G,@=&\@8F4@;F]T:&EN9R!B=70@96UP='D@
M<W!A8V4L"B`@("`@("`@("`@("`@(&1O;B=T(&1I<W!L87D@:70N("HO"B`@
M("`@("`@("`@(&EF("@H)'9A;"T^9V5T0GET97,H*2`\(#4I("8F"B`@("`@
M("`@("`@("`@("`A*')T<FEM*"1V86PM/F=E=$-O;G1E;G1S*"DI*2D@>PH@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1E>'0@+CT@)&UC+3YR96YD97)-24U%4&%R="@D=F%L*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE('-I9VYE9"!D871A(&]N;'D@9F]R(&$@<&QA
M:6YT97AT('-I9VYE9"!-24U%7U!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M
M($U)345?4&%R="`F)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@
M=VET:"!A('!L86EN=&5X="!01U`*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-I9VYE9"!M97-S86=E(&EN('1H92!C;VYT96YT<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G1S(&]F
M('1H92!S:6=N960@;65S<V%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4VEG;F5D365S<V%G92@F)&UI;65?<&%R="D*("`@('L*("`@("`@("`D;7-G
M(#T@)R<["@H@("`@("`@("\J($IU<W0@;W5T<'5T('-I9VYE9"!D871A("T@
M<F5M;W9E(&%L;"!01U`@:&5A9&5R<RX@*B\*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/G!A<G-E4$=01&%T82@D;6EM95]P87)T+3YG971#;VYT96YT<R@I
M*3L*("`@("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1B;&]C:RD@>PH@("`@
M("`@("`@("!I9B`H)&)L;V-K6R=T>7!E)UT@/3T@4$=07T%234]27U-)1TY%
M1%]-15-304=%*2!["B`@("`@("`@("`@("`@("`D:&5A9&5R4V5E;B`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@)&AE861E<D1O;F4@/2!F86QS93L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1B;&]C:ULG9&%T82==(&%S("1L:6YE
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1H96%D97)$;VYE*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1M<V<@+CT@)&QI;F4@+B`B7&XB.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&QI;F4L("(M
M+2TM+2(I(#T]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H96%D
M97)3965N(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1H96%D97)3965N
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J(%1H97)E(&%R92!S;VUE
M('9E<G-I;VYS(&]F($=N=5!'("AL:6ME(%9E<G-I;VXZ"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@($=N=5!'('8Q+C(N,2`H36EN9U<S,BDI('=H:6-H
M('-E<&%R871E(&AE861E<G,@9G)O;0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT96YT('=I=&@@82!L:6YE(&-O;G1A:6YI;F<@82!B;&%N:RP@
M8G5T('1H:7,*("`@("`@("`@("`@("`@("`@("`@("`@("`@:7-N)W0@4D9#
M(&-O;F9O<FUI;F<L('-O('1H:7,@:7-N)W0@:&%N9&QE9"X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@270@<F5S=6QT<R!I;B!A(&=O;V0@<VEG;F%T
M=7)E('=I=&@@86X@96UP='D*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;65S<V%G92X*("`@("`@("`@("`@("`@("`@("`@("`@("`@5&AE('=R;VYG
M(&-O9&4@=V]U;&0@8F4Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&5L
M<V5I9B`H96UP='DH)&QI;F4I('Q\("AS=')C;7`H)&QI;F4L("<@)RD@/3T@
M,"DI"B`@("`@("`@("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;&EN92`]('1R:6TH)&QI;F4I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H96UP='DH)&QI;F4I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:&5A9&5R1&]N92`]('1R=64["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!R=')I;2@D;7-G*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M('!U8FQI8R!K97D@=FEA(&$@<'5B;&EC(%!'4"!K97ES97)V97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEN9V5R<')I;G0@(%1H92!F:6YG
M97)P<FEN="!O9B!T:&4@<F5Q=65S=&5D(&ME>2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@4V5E($AO<F1E7T-R>7!T7W!G<#HZ9V5T4'5B;&EC
M2V5Y<V5R=F5R*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G)O;5!U8FQI
M8TME>7-E<G9E<B@D9FEN9V5R<')I;G0I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:V5Y<V5R=F5R0V]N;F5C="@D9FEN9V5R<')I;G0L("=G970G
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@82!P=6)L:6,@:V5Y('1O
M(&$@<'5B;&EC(%!'4"!K97ES97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<'5B:V5Y("!4:&4@4$=0('!U8FQI8R!K97DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%-E92!(;W)D95]#<GEP=%]P9W`Z.G!U
M=%!U8FQI8TME>7-E<G9E<B@I"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F14
M;U!U8FQI8TME>7-E<G9E<B@D<'5B:V5Y*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VME>7-E<G9E<D-O;FYE8W0H)'!U8FME>2P@)W!U="<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@:V5Y<V5R=F5R
M<PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1A=&$@("`@5&AE(&1A=&$@=&\@<V5N9"!T;R!T
M:&4@:V5Y<V5R=F5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4
M:&4@;65T:&]D('1O('5S92`M(&5I=&AE<B`G9V5T)R!O<B`G<'5T)RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4V5E($AO<F1E7T-R>7!T7W!G
M<#HZ9V5T4'5B;&EC2V5Y<V5R=F5R*"D@("UO<BT*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@2&]R9&5?0W)Y<'1?<&=P.CIP=710=6)L:6-+97ES97)V
M97(H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7VME>7-E<G9E<D-O;FYE8W0H
M)&1A=&$L("1M971H;V0I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=U=&EL<R==6R=G;G5P9U]K97ES
M97)V97(G72DI('L*("`@("`@("`@("`@)'1I;65O=70@/2`H96UP='DH)&-O
M;F9;)W5T:6QS)UU;)V=N=7!G7W1I;65O=70G72DI(#\@4$=07TM%65-%4E9%
M4E]424U%3U54(#H@)&-O;F9;)W5T:6QS)UU;)V=N=7!G7W1I;65O=70G73L*
M("`@("`@("`@("`@:68@*"1M971H;V0@/3T@)V=E="<I('L*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1C;VYF6R=U=&EL<R==6R=G;G5P9U]K97ES97)V
M97(G72!A<R`D<V5R=F5R*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3YG9710=6)L:6-+97ES97)V97(H)&1A=&$L("1S97)V97(L
M("1T:6UE;W5T*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<'5T4'5B;&EC2V5Y<V5R=F5R*"1D871A+"`D8V]N9ELG=71I;',G
M75LG9VYU<&=?:V5Y<V5R=F5R)UU;,%TL("1T:6UE;W5T*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E!U8FQI8R!01U`@:V5Y<V5R=F5R('-U<'!O<G0@
M:&%S(&)E96X@9&ES86)L960N(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5F5R:69I97,@82!S:6=N960@
M;65S<V%G92!W:71H(&$@9VEV96X@<'5B;&EC(&ME>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("`@("`@(%1H92!T97AT('1O('9E<FEF
M>2X*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')E<W,@("`@12UM86EL(&%D
M9')E<W,@;V8@<'5B;&EC(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@)'-I
M9VYA='5R92`@02!01U`@<VEG;F%T=7)E(&)L;V-K+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!3964@2&]R9&5?0W)Y<'1?<&=P.CID96-R>7!T
M4VEG;F%T=7)E*"D*("`@("`J("`@("`@("`@("`@("`@("`M3U(M"B`@("`@
M*B`@("`@("`@("`@("`@("`@2&]R9&5?0W)Y<'1?<&=P.CID96-R>7!T1&5T
M86-H9613:6=N871U<F4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!V97)I9GE3
M:6=N871U<F4H)'1E>'0L("1A9&1R97-S+"`D<VEG;F%T=7)E(#T@)R<I"B`@
M("!["B`@("`@("`@)&9I;F=E<G!R:6YT(#T@;G5L;#L*"B`@("`@("`@+RH@
M1V5T(&9I;F=E<G!R:6YT(&]F(&ME>2X@*B\*("`@("`@("!I9B`H(65M<'1Y
M*"1S:6=N871U<F4I*2!["B`@("`@("`@("`@("1P86-K971?:6YF;R`]("1T
M:&ES+3YP9W!086-K971);F9O<FUA=&EO;B@D<VEG;F%T=7)E*3L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1P86-K971?:6YF;ULG9FEN9V5R<')I;G0G72DI
M('L*("`@("`@("`@("`@("`@("1F:6YG97)P<FEN="`]("1P86-K971?:6YF
M;ULG9FEN9V5R<')I;G0G73L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F:6YG97)P<FEN="`]("1T:&ES+3YG9713:6=N
M97)S1FEN9V5R<')I;G0H)'1E>'0I.PH@("`@("`@('T*"B`@("`@("`@)'!U
M8FQI8U]K97D@/2`D=&AI<RT^9V5T4'5B;&EC2V5Y*"1A9&1R97-S+"`D9FEN
M9V5R<')I;G0I.PH@("`@("`@(&EF("AI<U]A*"1P=6)L:6-?:V5Y+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<'5B;&EC7VME>3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'-I9VYA='5R92DI('L*
M("`@("`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G='EP92<@/3X@)V1E=&%C
M:&5D+7-I9VYA='5R92<L("=S:6=N871U<F4G(#T^("1S:6=N871U<F4I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH
M)W1Y<&4G(#T^("=S:6=N871U<F4G*3L*("`@("`@("!]"B`@("`@("`@)&]P
M=&EO;G-;)W!U8FME>2==(#T@)'!U8FQI8U]K97D["@H@("`@("`@("\J(&1E
M8W)Y<'0H*2!R971U<FYS(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N
M("HO"B`@("`@("`@<F5T=7)N("1T:&ES+3YD96-R>7!T*"1T97AT+"`D;W!T
M:6]N<RD["B`@("!]"@H*("`@("\J*@H@("`@("H@1&5C<GEP="!A(&UE<W-A
M9V4@=VET:"!U<V5R)W,@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!D96-R
M>7!T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP
M=&5D(&UE<W-A9V4N(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX*("`@
M("`J("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&5C<GEP=$UE<W-A9V4H)'1E>'0I"B`@("!["B`@("`@("`@+RH@9&5C
M<GEP="@I(')E='5R;G,@82!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX@
M*B\*("`@("`@("!R971U<FX@)'1H:7,M/F1E8W)Y<'0H)'1E>'0L(&%R<F%Y
M*"=T>7!E)R`]/B`G;65S<V%G92<L("=P=6)K97DG(#T^("1T:&ES+3YG9710
M97)S;VYA;%!U8FQI8TME>2@I+"`G<')I=FME>2<@/3X@)'1H:7,M/F=E=%!E
M<G-O;F%L4')I=F%T94ME>2@I+"`G<&%S<W!H<F%S92<@/3X@)'1H:7,M/F=E
M=%!A<W-P:')A<V4H*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T
M:&4@=7-E<B=S('!A<W-P:')A<V4@9G)O;2!T:&4@<V5S<VEO;B!C86-H92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A<W-P:')A<V4L
M(&EF('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%S<W!H<F%S92@I
M"B`@("!["B`@("`@("`@9VQO8F%L("1I;7`["@H@("`@("`@(&EF("AI<W-E
M="@D:6UP6R=P9W!?<&%S<W!H<F%S92==*2D@>PH@("`@("`@("`@("!R971U
M<FX@4V5C<F5T.CIR96%D*%-E8W)E=#HZ9V5T2V5Y*"=I;7`G*2P@)&EM<%LG
M<&=P7W!A<W-P:')A<V4G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4W1O<F4G<R!T:&4@=7-E<B=S('!A<W-P:')A<V4@:6X@=&AE('-E
M<W-I;VX@8V%C:&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S
M<W!H<F%S92`@5&AE('5S97(G<R!P87-S<&AR87-E+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&EF(&-O<G)E8W0@<&%S
M<W!H<F%S92P@9F%L<V4@:68@:6YC;W)R96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S=&]R95!A<W-P:')A<V4H)'!A<W-P:')A<V4I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3YV97)I9GE087-S<&AR87-E*"1T:&ES+3YG971097)S
M;VYA;%!U8FQI8TME>2@I+"`D=&AI<RT^9V5T4&5R<V]N86Q0<FEV871E2V5Y
M*"DL("1P87-S<&AR87-E*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)$=,3T)!3%-;)VEM<"==
M6R=P9W!?<&%S<W!H<F%S92==(#T@4V5C<F5T.CIW<FET92A396-R970Z.F=E
M=$ME>2@G:6UP)RDL("1P87-S<&AR87-E*3L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<B!T:&4@<&%S<W!H<F%S
M92!F<F]M('1H92!S97-S:6]N(&-A8VAE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!U;G-E=%!A<W-P:')A<V4H*0H@("`@>PH@("`@("`@('5N<V5T*"1'3$]"
M04Q36R=I;7`G75LG<&=P7W!A<W-P:')A<V4G72D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'96YE<F%T97,@=&AE(&IA=F%S8W)I<'0@8V]D92!F;W(@<V%V
M:6YG('!U8FQI8R!K97ES+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A
M<G0@)B1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@8V]N=&%I;FEN9R!T:&4@
M<'5B;&EC(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@)&-A8VAE("`@("`@
M("`@(%1H92!-24U%7U!A<G0@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(%523"!F;W(@<V%V:6YG('!U8FQI8R!K97ES
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S879E4'5B;&EC2V5Y55),*"8D;6EM
M95]P87)T+"`D8V%C:&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AE;7!T
M>2@D8V%C:&4I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M4V5S<VEO;D]B:F5C=',N<&AP)SL*("`@("`@("`@("`@)&-A8VAE4V5S<R`]
M("9(;W)D95]397-S:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D["B`@("`@("`@
M("`@("1O:60@/2`D8V%C:&5397-S+3YS=&]R94]I9"@D;6EM95]P87)T*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^9V5T2E-/<&5N5VEN
M0V]D92@G<V%V95]A='1A8VAM96YT7W!U8FQI8U]K97DG+"!F86QS92P@87)R
M87DH)VUI;65C86-H92<@/3X@)&]I9"DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4')I;G0@;W5T('1H92!L:6YK(&9O<B!T:&4@:F%V87-C<FEP="!01U`@
M<&]P=7`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-T:6]N:60@
M(%1H92!!8W1I;VY)1"!T;R!P97)F;W)M+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1R96QO860@("`@($EF('1R=64L(')E;&]A9"!B87-E('=I;F1O=R!O;B!C
M;&]S92X@268@=&5X="P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!R=6X@=&AI<R!*4R!O;B!C;&]S92X@268@9F%L<V4L(&1O;B=T(&1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@86YY=&AI;F<@;VX@8VQO
M<V4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@061D:71I;VYA
M;"!P87)A;65T97)S(&YE961E9"!F;W(@=&AE(')E;&]A9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@('!A9V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!J879A<V-R:7!T(&QI;FLN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$I33W!E;E=I;D-O9&4H)&%C=&EO;FED+"`D<F5L;V%D
M(#T@=')U92P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)'!O<'5P
M7W5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<&=P+G!H<"<I.PH@("`@
M("`@("1P;W!U<%]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'!O<'5P7W5R
M;"P@)V%C=&EO;DE$)RP@)&%C=&EO;FED+"!F86QS92D["B`@("`@("`@:68@
M*"%E;7!T>2@D<F5L;V%D*2D@>PH@("`@("`@("`@("!I9B`H:7-?8F]O;"@D
M<F5L;V%D*2D@>PH@("`@("`@("`@("`@("`@)'!O<'5P7W5R;"`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D<&]P=7!?=7)L+"`G<F5L;V%D)RP@571I;#HZ<F5M
M;W9E4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*'1R=64I+"!A<G)A>2@G86-T
M:6]N240G*2DL(&9A;'-E*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;D]B:F5C=',N
M<&AP)SL*("`@("`@("`@("`@("`@("1C86-H95-E<W,@/2`F2&]R9&5?4V5S
M<VEO;D]B:F5C=',Z.G-I;F=L971O;B@I.PH@("`@("`@("`@("`@("`@)'!O
M<'5P7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D<&]P=7!?=7)L+"`G<&%S
M<W!H<F%S95]A8W1I;VXG+"`D8V%C:&5397-S+3YS=&]R94]I9"@D<F5L;V%D
M+"!F86QS92DL(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1P87)A;7,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@
M("`@("`D<&]P=7!?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1P;W!U<%]U
M<FPL("1K97DL("1V86PL(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(")P;W!U<%]I;7`H)R(@+B`D<&]P=7!?=7)L
M("X@(B<L-#4P+#(P,"D[(CL*("`@('T*"B`@("`O*BH*("`@("`J(%!R;W9I
M9&4@=&AE(&QI<W0@;V8@<&%R86UE=&5R<R!N965D960@9F]R('-I9VYI;F<@
M82!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F('!A<F%M971E
M<G,@;F5E9&5D(&)Y(&5N8W)Y<'0H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W-I9VY087)A;65T97)S*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH
M)W!U8FME>2<@/3X@)'1H:7,M/F=E=%!E<G-O;F%L4'5B;&EC2V5Y*"DL("=P
M<FEV:V5Y)R`]/B`D=&AI<RT^9V5T4&5R<V]N86Q0<FEV871E2V5Y*"DL("=P
M87-S<&AR87-E)R`]/B`D=&AI<RT^9V5T4&%S<W!H<F%S92@I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%!R;W9I9&4@=&AE(&QI<W0@;V8@<&%R86UE=&5R
M<R!N965D960@9F]R(&5N8W)Y<'1I;F<@82!M97-S86=E+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D861D<F5S<V5S("!4:&4@92UM86EL(&%D9')E<W,@;V8@=&AE(&ME>7,@
M=&\@=7-E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&5N
M8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI
M<W0@;V8@<&%R86UE=&5R<R!N965D960@8GD@96YC<GEP="@I+@H@("`@("H@
M("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?96YC<GEP=%!A<F%M971E<G,H)&%D9')E
M<W-E<RD*("`@('L*("`@("`@("`D861D<E]L:7-T(#T@87)R87DH*3L*"B`@
M("`@("`@9F]R96%C:"`H)&%D9')E<W-E<R!A<R`D=F%L*2!["B`@("`@("`@
M("`@("\J(%=E(&-A;B!O;FQY(&5N8W)Y<'0@:68@=V4@87)E('-E;F1I;F<@
M=&\@82!S:6YG;&4@<&5R<V]N+B`J+PH@("`@("`@("`@("`D861D<D]B(#T@
M24U0.CIB87)E061D<F5S<R@D=F%L+"!T<G5E*3L*("`@("`@("`@("`@)&ME
M>5]A9&1R(#T@87)R87E?<&]P*"1A9&1R3V(I.PH*("`@("`@("`@("`@+RH@
M1V5T('1H92!P=6)L:6,@:V5Y(&9O<B!T:&4@861D<F5S<RX@*B\*("`@("`@
M("`@("`@)'!U8FQI8U]K97D@/2`D=&AI<RT^9V5T4'5B;&EC2V5Y*"1K97E?
M861D<BD["B`@("`@("`@("`@(&EF("AI<U]A*"1P=6)L:6-?:V5Y+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'!U8FQI8U]K
M97D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&%D9')?;&ES=%LD:V5Y
M7V%D9')=(#T@)'!U8FQI8U]K97D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3YM=6QT:7!L95)E8VEP:65N=$5N8W)Y<'1I;VXI*2![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G<F5C:7!S)R`]/B`D861D<E]L
M:7-T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R
M87DH)W!U8FME>2<@/3X@)'!U8FQI8U]K97DL("=E;6%I;"<@/3X@)&ME>5]A
M9&1R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:6=N(&$@
M34E-15]087)T('5S:6YG(%!'4"!U<VEN9R!)35`@9&5F875L="!P87)A;65T
M97)S+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)&UI;65?<&%R
M="`@5&AE($U)345?4&%R="!O8FIE8W0@=&\@<VEG;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N($U)345?4&%R="`@4V5E($AO<F1E7T-R>7!T7W!G<#HZ<VEG
M;DU)345087)T*"DN(%)E='5R;G,*("`@("`J("`@("`@("`@("`@("`@("`@
M("!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@24U0<VEG;DU)345087)T*"1M:6UE7W!A<G0I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YS:6=N34E-15!A<G0H)&UI;65?<&%R="P@)'1H
M:7,M/E]S:6=N4&%R86UE=&5R<R@I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($5N8W)Y<'0@82!-24U%7U!A<G0@=7-I;F<@4$=0('5S:6YG($E-4"!D969A
M=6QT('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R
M="`D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!E;F-R>7!T
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A9&1R97-S97,@("`@("!4:&4@92UM
M86EL(&%D9')E<W,@;V8@=&AE(&ME>7,@=&\@=7-E(&9O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!E;F-R>7!T:6]N+@H@("`@("H*
M("`@("`J($!R971U<FX@34E-15]087)T("!3964@2&]R9&5?0W)Y<'1?<&=P
M.CIE;F-R>7!T34E-15!A<G0H*2X@4F5T=7)N<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!)35!E;F-R>7!T34E-15!A<G0H)&UI;65?<&%R="P@
M)&%D9')E<W-E<RD*("`@('L*("`@("`@("`D<&%R86US(#T@)'1H:7,M/E]E
M;F-R>7!T4&%R86UE=&5R<R@D861D<F5S<V5S*3L*("`@("`@("!I9B`H:7-?
M82@D<&%R86US+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<&%R86US.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/F5N
M8W)Y<'1-24U%4&%R="@D;6EM95]P87)T+"`D<&%R86US*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-I9VX@86YD($5N8W)Y<'0@82!-24U%7U!A<G0@=7-I
M;F<@4$=0('5S:6YG($E-4"!D969A=6QT('!A<F%M971E<G,N"B`@("`@*@H@
M("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM95]P87)T("!4:&4@34E-15]0
M87)T(&]B:F5C="!T;R!S:6=N(&%N9"!E;F-R>7!T+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1A9&1R97-S97,@("`@("!4:&4@92UM86EL(&%D9')E<W,@;V8@
M=&AE(&ME>7,@=&\@=7-E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!E;F-R>7!T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@
M34E-15]087)T("!3964@2&]R9&5?0W)Y<'1?<&=P.CIS:6=N06YD96YC<GEP
M=$U)345087)T*"DN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@4F5T=7)N
M<R!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@24U0<VEG;D%N9$5N8W)Y<'1-24U%4&%R="@D;6EM95]P87)T+"`D
M861D<F5S<V5S*0H@("`@>PH@("`@("`@("1E;F-R>7!T7W!A<F%M<R`]("1T
M:&ES+3Y?96YC<GEP=%!A<F%M971E<G,H)&%D9')E<W-E<RD["B`@("`@("`@
M:68@*&ES7V$H)&5N8W)Y<'1?<&%R86US+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D96YC<GEP=%]P87)A;7,["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^<VEG;D%N9$5N8W)Y<'1-24U%4&%R="@D
M;6EM95]P87)T+"`D=&AI<RT^7W-I9VY087)A;65T97)S*"DL("1E;F-R>7!T
M7W!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!A($U)
M345?4&%R="!O8FIE8W0L(&EN(&%C8V]R9&%N8V4@=VET:"!21D,@,C`Q-2\S
M,34V+"!T:&%T"B`@("`@*B!C;VYT86EN<R!T:&4@=7-E<B=S('!U8FQI8R!K
M97DN"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@(%-E92!(;W)D
M95]#<GEP=%]P9W`Z.G!U8FQI8TME>4U)345087)T*"DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!U8FQI8TME>4U)345087)T*"D*("`@('L*("`@("`@("!R
M971U<FX@<&%R96YT.CIP=6)L:6-+97E-24U%4&%R="@D=&AI<RT^9V5T4&5R
M<V]N86Q0=6)L:6-+97DH*2D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O
M0W)Y<'0O4TU)344N<&AP````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-#`P,3``,3`T,3<S-C(W-C8`,#(P-#,W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+T-R>7!T+W-M:6UE+G!H<"<["@HO*BH*("H@3F%M92!O9B!T
M:&4@4R]-24U%('!U8FQI8R!K97D@9FEE;&0@:6X@861D<F5S<V)O;VLN"B`J
M+PID969I;F4H)TE-4%]334E-15]054)+15E?1DE%3$0G+"`G<VUI;650=6)L
M:6-+97DG*3L*"B\J*@H@*B!4:&4@24U07U--24U%.CH@8VQA<W,@8V]N=&%I
M;G,@86QL(&9U;F-T:6]N<R!R96QA=&5D('1O(&AA;F1L:6YG"B`J(%,O34E-
M12!M97-S86=E<R!W:71H:6X@24U0+@H@*@H@*B`D2&]R9&4Z(&EM<"]L:6(O
M0W)Y<'0O4TU)344N<&AP+'8@,2XT-2XR+C$S(#(P,#8O,#(O,C$@,#`Z,C$Z
M,C$@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@24U0(#0N,`H@*B!`<&%C:V%G92!)
M35`*("HO"F-L87-S($E-4%]334E-12!E>'1E;F1S($AO<F1E7T-R>7!T7W-M
M:6UE('L*"B`@("`O*BH*("`@("`J(%1H92!L:7-T(&]F(&%V86EL86)L92!S
M;W5R8V5S('1O('-E87)C:"!F;W(@:V5Y<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-O=7)C97,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($E-4%]334E-12@I"B`@("!["B`@("`@("`@+RH@1V5T('1H92!L:7-T
M:6YG(&]F(&%L;"!S;W5R8V5S('=E('-E87)C:"!F;W(@<'5B;&EC(&ME>7,N
M("HO"B`@("`@("`@:68@*"@D<V]U<F-E<R`]("1'3$]"04Q36R=P<F5F<R==
M+3YG971686QU92@G<V5A<F-H7W-O=7)C97,G*2DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]S;W5R8V5S(#T@97AP;&]D92@B7'0B+"`D<V]U<F-E<RD["B`@
M("`@("`@("`@(&EF("@H8V]U;G0H)'1H:7,M/E]S;W5R8V5S*2`]/2`Q*2`F
M)B!E;7!T>2@D=&AI<RT^7W-O=7)C97-;,%TI*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W-O=7)C97,@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!P87)E;G0Z.DAO<F1E7T-R>7!T7W-M:6UE*&%R
M<F%Y*"=T96UP)R`]/B!(;W)D93HZ9V5T5&5M<$1I<B@I*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&0@=&AE('!E<G-O;F%L('!U8FQI8R!K97D@=&\@
M=&AE('!R969S+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:V5Y("!4
M:&4@<'5B;&EC(&ME>2!T;R!A9&0@*&5I=&AE<B!S=')I;F<@;W(@87)R87DI
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1097)S;VYA;%!U8FQI8TME>2@D
M:V5Y*0H@("`@>PH@("`@("`@("1'3$]"04Q36R=P<F5F<R==+3YS971686QU
M92@G<VUI;65?<'5B;&EC7VME>2<L("AI<U]A<G)A>2@D:V5Y*2D@/R!I;7!L
M;V1E*"<G+"`D:V5Y*2`Z("1K97DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D('1H92!P97)S;VYA;"!P<FEV871E(&ME>2!T;R!T:&4@<')E9G,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1K97D@(%1H92!P<FEV871E(&ME
M>2!T;R!A9&0@*&5I=&AE<B!S=')I;F<@;W(@87)R87DI+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1097)S;VYA;%!R:79A=&5+97DH)&ME>2D*("`@('L*
M("`@("`@("`D1TQ/0D%,4ULG<')E9G,G72T^<V5T5F%L=64H)W-M:6UE7W!R
M:79A=&5?:V5Y)RP@*&ES7V%R<F%Y*"1K97DI*2`_(&EM<&QO9&4H)R<L("1K
M97DI(#H@)&ME>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@=&AE(&QI
M<W0@;V8@861D:71I;VYA;"!C97)T<R!T;R!T:&4@<')E9G,N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1K97D@(%1H92!P<FEV871E(&ME>2!T;R!A
M9&0@*&5I=&AE<B!S=')I;F<@;W(@87)R87DI+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&1!9&1I=&EO;F%L0V5R="@D:V5Y*0H@("`@>PH@("`@("`@("1'
M3$]"04Q36R=P<F5F<R==+3YS971686QU92@G<VUI;65?861D:71I;VYA;%]C
M97)T)RP@*&ES7V%R<F%Y*"1K97DI*2`_(&EM<&QO9&4H)R<L("1K97DI(#H@
M)&ME>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('!E<G-O;F%L
M('!U8FQI8R!K97D@9G)O;2!T:&4@<')E9G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!P97)S;VYA;"!3+TU)344@<'5B;&EC(&ME>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&5R<V]N86Q0=6)L:6-+97DH*0H@
M("`@>PH@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L
M=64H)W-M:6UE7W!U8FQI8U]K97DG*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!T:&4@<&5R<V]N86P@<')I=F%T92!K97D@9G)O;2!T:&4@<')E9G,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P97)S;VYA;"!3
M+TU)344@<')I=F%T92!K97DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!E
M<G-O;F%L4')I=F%T94ME>2@I"B`@("!["B`@("`@("`@<F5T=7)N("1'3$]"
M04Q36R=P<F5F<R==+3YG971686QU92@G<VUI;65?<')I=F%T95]K97DG*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;GD@861D:71I;VYA;"!C97)T
M:69I8V%T97,@9G)O;2!T:&4@<')E9G,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@($%D9&ET:6]N86P@<VEG;FEN9R!C97)T<R!F;W(@:6YC;'5S
M:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!9&1I=&EO;F%L0V5R="@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=P<F5F<R==+3YG9716
M86QU92@G<VUI;65?861D:71I;VYA;%]C97)T)RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96QE=&5S('1H92!S<&5C:69I960@<&5R<V]N86P@:V5Y<R!F
M<F]M('1H92!P<F5F<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E4&5R
M<V]N86Q+97ES*"D*("`@('L*("`@("`@("`D1TQ/0D%,4ULG<')E9G,G72T^
M<V5T5F%L=64H)W-M:6UE7W!U8FQI8U]K97DG+"`G)RD["B`@("`@("`@)$=,
M3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=S;6EM95]P<FEV871E7VME>2<L
M("<G*3L*("`@("`@("`D1TQ/0D%,4ULG<')E9G,G72T^<V5T5F%L=64H)W-M
M:6UE7V%D9&ET:6]N86Q?8V5R="<L("<G*3L*("`@("`@("`D=&AI<RT^=6YS
M971087-S<&AR87-E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!P
M=6)L:6,@:V5Y('1O(&%N(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C97)T("!!('!U8FQI8R!C97)T:69I8V%T92!T;R!A
M9&0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U
M8V-E<W-F=6P@861D+@H@("`@("H@("`@("`@("`@("`@("`@("!2971U<FYS
M(%!%05)?17)R;W(@;W(@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9%!U8FQI8TME>2@D8V5R="D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@
M=&AE(&-E<G1I9FEC871E(&ES('9A;&ED+B`J+PH@("`@("`@("1K97E?:6YF
M;R`](&]P96YS<VQ?>#4P.5]P87)S92@D8V5R="D["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D:V5Y7VEN9F\I('Q\("%I<W-E="@D:V5Y7VEN9F];)W-U8FIE
M8W0G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B3F]T(&$@=F%L:60@<'5B;&EC(&ME>2XB*2P@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!!9&0@:V5Y('1O('1H92!U<V5R)W,@
M861D<F5S<R!B;V]K+B`J+PH@("`@("`@("1E;6%I;"`]("1T:&ES+3YG971%
M;6%I;$9R;VU+97DH)&-E<G0I.PH@("`@("`@(&EF("AI<U]N=6QL*"1E;6%I
M;"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F\@96UA:6P@:6YF;W)M871I;VX@;&]C871E9"!I;B!T:&4@<'5B;&EC(&ME
M>2XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`O*B!'
M970@=&AE(&YA;64@8V]R<F5S<&]N9&EN9R!T;R!T:&ES(&ME>2X@*B\*("`@
M("`@("!I9B`H:7-S970H)&ME>5]I;F9O6R=S=6)J96-T)UU;)T]5)UTI*2![
M"B`@("`@("`@("`@("1N86UE(#T@)&ME>5]I;F9O6R=S=6)J96-T)UU;)T]5
M)UT["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1K97E?:6YF;ULG<W5B:F5C
M="==6R=#3B==*2D@>PH@("`@("`@("`@("`D;F%M92`]("1K97E?:6YF;ULG
M<W5B:F5C="==6R=#3B==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!A('9A;&ED('!U8FQI
M8R!K97DN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@
M)')E<R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=C;VYT86-T<R]A
M9&1&:65L9"<L(&%R<F%Y*"1E;6%I;"P@)&YA;64L($E-4%]334E-15]054)+
M15E?1DE%3$0L("1C97)T+"`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H
M)V%D9%]S;W5R8V4G*2DI.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&ME>5]I;F9O.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@<&%R86US(&YE961E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92!B96EN9R!S96YT('1O('1H90H@("`@("H@<W!E8VEF:65D(&5M
M86EL(&%D9')E<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<F5S<R`@5&AE(&4M;6%I
M;"!A9&1R97-S(&]F('1H92!R96-I<&EE;G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@<&%R86UE=&5R<R!N965D960@8GD@
M96YC<GEP="@I+@H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!014%2
M7T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V5N8W)Y<'1087)A;65T97)S*"1A9&1R97-S*0H@("`@>PH@("`@("`@("\J
M(%=E(&-A;B!O;FQY(&5N8W)Y<'0@:68@=V4@87)E('-E;F1I;F<@=&\@82!S
M:6YG;&4@<&5R<V]N+B`J+PH@("`@("`@("1A9&1R3V(@/2!)35`Z.F)A<F5!
M9&1R97-S*"1A9&1R97-S+"!T<G5E*3L*("`@("`@("`D:V5Y7V%D9'(@/2!A
M<G)A>5]P;W`H)&%D9')/8BD["@H@("`@("`@("1P=6)L:6-?:V5Y(#T@)'1H
M:7,M/F=E=%!U8FQI8TME>2@D:V5Y7V%D9'(I.PH@("`@("`@(&EF("AI<U]A
M*"1P=6)L:6-?:V5Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<'5B;&EC7VME>3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A
M<G)A>2@G='EP92<@/3X@)VUE<W-A9V4G+"`G<'5B:V5Y)R`]/B`D<'5B;&EC
M7VME>2P@)V5M86EL)R`@/3X@)&%D9')E<W,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F5S(&$@<'5B;&EC(&ME>2!B>2!E+6UA:6PN"B`@("`@
M*B!4:&4@:V5Y('=I;&P@8F4@<F5T<FEE=F5D(&9R;VT@82!U<V5R)W,@861D
M<F5S<R!B;V]K*',I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D
M9')E<W,@(%1H92!E+6UA:6P@861D<F5S<R!T;R!S96%R8V@@9F]R+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@4R]-24U%('!U8FQI8R!K
M97D@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%!U8FQI8TME>2@D861D<F5S<RD*("`@('L*("`@("`@("`D:V5Y
M(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)V-O;G1A8W1S+V=E=$9I
M96QD)RP@87)R87DH)&%D9')E<W,L($E-4%]334E-15]054)+15E?1DE%3$0L
M("1T:&ES+3Y?<V]U<F-E<RDI.PH@("`@("`@(&EF("AI<U]A*"1K97DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92])9&5N=&ET>2YP:'`G.PH@("`@("`@("`@("`D:61E;G1I='D@/2`F261E
M;G1I='DZ.G-I;F=L971O;BAA<G)A>2@G:6UP)RP@)VEM<"<I*3L*("`@("`@
M("`@("`@)'!E<G-O;F%L7W!U8FME>2`]("1T:&ES+3YG971097)S;VYA;%!U
M8FQI8TME>2@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1P97)S;VYA;%]P
M=6)K97DI("8F("1I9&5N=&ET>2T^:&%S061D<F5S<R@D861D<F5S<RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<&5R<V]N86Q?<'5B:V5Y.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:V5Y.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&%L;"!P=6)L:6,@:V5Y<R!F
M<F]M(&$@=7-E<B=S(&%D9')E<W,@8F]O:RAS*2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;&P@4$=0('!U8FQI8R!K97ES(&%V86EL86)L92X*
M("`@("`J("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@97)R;W(N"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T
M4'5B;&EC2V5Y<R@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M<V]U<F-E<RDI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I
M<W1R>2==+3YC86QL*"=C;VYT86-T<R]G971!;&Q!='1R:6)U=&5686QU97,G
M+"!A<G)A>2A)35!?4TU)345?4%5"2T597T9)14Q$+"`D=&AI<RT^7W-O=7)C
M97,I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S
M(&$@<'5B;&EC(&ME>2!F<F]M(&$@=7-E<B=S(&%D9')E<W,@8F]O:RAS*2!B
M>2!E+6UA:6PN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D96UA:6P@
M(%1H92!E+6UA:6P@861D<F5S<R!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!014%27T5R<F]R("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&50=6)L:6-+
M97DH)&5M86EL*0H@("`@>PH@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^8V%L;"@G8V]N=&%C=',O9&5L971E1FEE;&0G+"!A<G)A>2@D
M96UA:6PL($E-4%]334E-15]054)+15E?1DE%3$0L("1T:&ES+3Y?<V]U<F-E
M<RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE
M=&5R<R!N965D960@9F]R('-I9VYI;F<@82!M97-S86=E+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!L:7-T(&]F('!A<F%M971E<G,@;F5E9&5D(&)Y(&5N8W)Y<'0H
M*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-I9VY087)A;65T97)S*"D*("`@
M('L*("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]
M/B`G<VEG;F%T=7)E)RP*("`@("`@("`@("`@)W!U8FME>2<@/3X@)'1H:7,M
M/F=E=%!E<G-O;F%L4'5B;&EC2V5Y*"DL"B`@("`@("`@("`@("=P<FEV:V5Y
M)R`]/B`D=&AI<RT^9V5T4&5R<V]N86Q0<FEV871E2V5Y*"DL"B`@("`@("`@
M("`@("=P87-S<&AR87-E)R`]/B`D=&AI<RT^9V5T4&%S<W!H<F%S92@I+`H@
M("`@("`@("`@("`G<VEG='EP92<@/3X@)V1E=&%C:"<L"B`@("`@("`@("`@
M("=C97)T<R<@/3X@)'1H:7,M/F=E=$%D9&ET:6]N86Q#97)T*"D*("`@("`@
M("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@5F5R:69I97,@82!S:6=N960@
M;65S<V%G92!W:71H(&$@9VEV96X@<'5B;&EC(&ME>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!V97)I9GDN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@4V5E($AO<F1E7T-R>7!T
M7W-M:6UE.CIV97)I9GDH*2X*("`@("`J+PH@("`@9G5N8W1I;VX@=F5R:69Y
M4VEG;F%T=7)E*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M=F5R:69Y*"1T97AT+"`D1TQ/0D%,4ULG8V]N9B==6R=U=&EL<R==6R=O<&5N
M<W-L7V-A9FEL92==*3L*("`@('T*"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T
M(&$@;65S<V%G92!W:71H('5S97(G<R!P=6)L:6,O<')I=F%T92!K97EP86ER
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT
M('1O(&1E8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%-E
M92!(;W)D95]#<GEP=%]S;6EM93HZ9&5C<GEP="@I+@H@("`@("H@("`@("`@
M("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'1-97-S86=E*"1T97AT*0H@
M("`@>PH@("`@("`@("\J(&1E8W)Y<'0H*2!R971U<FYS(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@97)R;W(N("HO"B`@("`@("`@<F5T=7)N("1T:&ES+3YD
M96-R>7!T*"1T97AT+"!A<G)A>2@G='EP92<@/3X@)VUE<W-A9V4G+"`G<'5B
M:V5Y)R`]/B`D=&AI<RT^9V5T4&5R<V]N86Q0=6)L:6-+97DH*2P@)W!R:79K
M97DG(#T^("1T:&ES+3YG971097)S;VYA;%!R:79A=&5+97DH*2P@)W!A<W-P
M:')A<V4G(#T^("1T:&ES+3YG971087-S<&AR87-E*"DI*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE('5S97(G<R!P87-S<&AR87-E(&9R;VT@
M=&AE('-E<W-I;VX@8V%C:&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE('!A<W-P:')A<V4L(&EF('-E="X@(%)E='5R;G,@9F%L<V4@:68@
M=&AE('!A<W-P:')A<V4*("`@("`J("`@("`@("`@("`@("`@(&AA<R!N;W0@
M8F5E;B!L;V%D960@>65T+B`@4F5T=7)N<R!N=6QL(&EF(&YO('!A<W-P:')A
M<V4*("`@("`J("`@("`@("`@("`@("`@(&ES(&YE961E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%S<W!H<F%S92@I"B`@("!["B`@("`@("`@)'!R
M:79A=&5?:V5Y(#T@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=S;6EM
M95]P<FEV871E7VME>2<I.PH@("`@("`@(&EF("AE;7!T>2@D<')I=F%T95]K
M97DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG:6UP)UU;)W-M:6UE)UU;)W!A
M<W-P:')A<V4G72DI('L*("`@("`@("`@("`@<F5T=7)N(%-E8W)E=#HZ<F5A
M9"A396-R970Z.F=E=$ME>2@G:6UP)RDL("1'3$]"04Q36R=I;7`G75LG<VUI
M;64G75LG<&%S<W!H<F%S92==*3L*("`@("`@("!](&5L<V5I9B`H:7-S970H
M)$=,3T)!3%-;)VEM<"==6R=S;6EM92==6R=N=6QL7W!A<W-P:')A<V4G72DI
M('L*("`@("`@("`@("`@<F5T=7)N("@D1TQ/0D%,4ULG:6UP)UU;)W-M:6UE
M)UU;)VYU;&Q?<&%S<W!H<F%S92==*2`_(&YU;&P@.B!F86QS93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/G9E<FEF>5!A
M<W-P:')A<V4H)'!R:79A=&5?:V5Y+"!N=6QL*3L*("`@("`@("`@("`@:68@
M*"%I<W-E="@D1TQ/0D%,4ULG:6UP)UU;)W-M:6UE)UTI*2!["B`@("`@("`@
M("`@("`@("`D1TQ/0D%,4ULG:6UP)UU;)W-M:6UE)UT@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1'3$]"04Q36R=I;7`G75LG<VUI
M;64G75LG;G5L;%]P87-S<&AR87-E)UT@/2`H)')E<RD@/R!N=6QL(#H@9F%L
M<V4["B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG:6UP)UU;)W-M:6UE
M)UU;)VYU;&Q?<&%S<W!H<F%S92==.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%-T;W)E)W,@=&AE('5S97(G<R!P87-S<&AR87-E(&EN('1H
M92!S97-S:6]N(&-A8VAE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<W-P:')A<V4@(%1H92!U<V5R)W,@<&%S<W!H<F%S92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!I9B!C;W)R96-T
M('!A<W-P:')A<V4L(&9A;'-E(&EF(&EN8V]R<F5C="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<W1O<F5087-S<&AR87-E*"1P87-S<&AR87-E*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^=F5R:69Y4&%S<W!H<F%S92@D=&AI<RT^9V5T
M4&5R<V]N86Q0<FEV871E2V5Y*"DL("1P87-S<&AR87-E*2`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG:6UP)UU;)W-M:6UE)UTI*2!["B`@
M("`@("`@("`@("1'3$]"04Q36R=I;7`G75LG<VUI;64G72`](&%R<F%Y*"D[
M"B`@("`@("`@?0H@("`@("`@("1'3$]"04Q36R=I;7`G75LG<VUI;64G75LG
M<&%S<W!H<F%S92==(#T@4V5C<F5T.CIW<FET92A396-R970Z.F=E=$ME>2@G
M:6UP)RDL("1P87-S<&AR87-E*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<B!T:&4@<&%S<W!H<F%S92!F<F]M
M('1H92!S97-S:6]N(&-A8VAE+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;G-E
M=%!A<W-P:')A<V4H*0H@("`@>PH@("`@("`@('5N<V5T*"1'3$]"04Q36R=I
M;7`G75LG<VUI;64G75LG;G5L;%]P87-S<&AR87-E)UTI.PH@("`@("`@('5N
M<V5T*"1'3$]"04Q36R=I;7`G75LG<VUI;64G75LG<&%S<W!H<F%S92==*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@:F%V87-C<FEP
M="!C;V1E(&9O<B!S879I;F<@<'5B;&EC(&ME>7,N"B`@("`@*@H@("`@("H@
M0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@5&AE($U)345?4&%R="!C
M;VYT86EN:6YG('1H92!P=6)L:6,@:V5Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V%C:&4@("`@("`@("`@5&AE($U)345?4&%R="!I9&5N=&EF:65R+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@55),(&9O<B!S879I
M;F<@<'5B;&EC(&ME>7,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F50=6)L
M:6-+97E54DPH)&UI;65?<&%R="P@)&9R;VTI"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1C86-H92DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]397-S:6]N3V)J96-T<RYP:'`G.PH@("`@("`@("`@("`D8V%C:&53
M97-S(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@
M("`@("`@("`@)&]I9"`]("1C86-H95-E<W,M/G-T;W)E3VED*"1M:6UE7W!A
M<G0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YG971*4T]P
M96Y7:6Y#;V1E*"=S879E7V%T=&%C:&UE;G1?<'5B;&EC7VME>2<L(&9A;'-E
M+"!A<G)A>2@G9G)O;2<@/3X@)&9R;VTL("=C97)T)R`]/B`D;VED*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0<FEN="!O=70@=&AE(&QI;FL@9F]R('1H
M92!J879A<V-R:7!T(%--24U%('!O<'5P+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1A8W1I;VYI9"`@5&AE(&%C=&EO;DE$('1O('!E<F9O<FTN
M"B`@("`@*B!`<&%R86T@;6EX960@)')E;&]A9"`@("`@($EF('1R=64L(')E
M;&]A9"!B87-E('=I;F1O=R!O;B!C;&]S92X@268@=&5X="P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<G5N('1H:7,@2E,@;VX@8VQO<V4N
M($EF(&9A;'-E+"!D;VXG="!D;PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A;GET:&EN9R!O;B!C;&]S92X*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("`@("`@061D:71I;VYA;"!P87)A;65T97)S(&YE961E9"!F
M;W(@=&AE(')E;&]A9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!P86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@:F%V
M87-C<FEP="!L:6YK+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971*4T]P96Y7
M:6Y#;V1E*"1A8W1I;VYI9"P@)')E;&]A9"`]('1R=64L("1P87)A;7,@/2!N
M=6QL*0H@("`@>PH@("`@("`@("1P;W!U<%]U<FP@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)W-M:6UE+G!H<"<I.PH@("`@("`@("1P;W!U<%]U<FP@/2!5
M=&EL.CIA9&1087)A;65T97(H)'!O<'5P7W5R;"P@)V%C=&EO;DE$)RP@)&%C
M=&EO;FED+"!F86QS92D["B`@("`@("`@:68@*"%E;7!T>2@D<F5L;V%D*2D@
M>PH@("`@("`@("`@("!I9B`H:7-?8F]O;"@D<F5L;V%D*2D@>PH@("`@("`@
M("`@("`@("`@)'!O<'5P7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D<&]P
M=7!?=7)L+"`G<F5L;V%D)RP@571I;#HZ<F5M;W9E4&%R86UE=&5R*$AO<F1E
M.CIS96QF57)L*'1R=64I+"!A<G)A>2@G86-T:6]N240G*2DL(&9A;'-E*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O4V5S<VEO;D]B:F5C=',N<&AP)SL*("`@("`@("`@("`@
M("`@("1C86-H95-E<W,@/2`F2&]R9&5?4V5S<VEO;D]B:F5C=',Z.G-I;F=L
M971O;B@I.PH@("`@("`@("`@("`@("`@)'!O<'5P7W5R;"`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D<&]P=7!?=7)L+"`G<&%S<W!H<F%S95]A8W1I;VXG+"`D
M8V%C:&5397-S+3YS=&]R94]I9"@D<F5L;V%D+"!F86QS92DL(&9A;'-E*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P;W!U<%]U<FP@/2!5=&EL.CIA
M9&1087)A;65T97(H)'!O<'5P7W5R;"P@)'!A<F%M<RP@;G5L;"P@9F%L<V4I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(")P;W!U<%]I;7`H)R(@+B`D
M<&]P=7!?=7)L("X@(B<L-#4P+#(P,"D[(CL*("`@('T*"B`@("`O*BH*("`@
M("`J($5N8W)Y<'0@82!-24U%7U!A<G0@=7-I;F<@4R]-24U%('5S:6YG($E-
M4"!D969A=6QT<RX*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("1M
M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J96-T('1O(&5N8W)Y<'0N"B`@
M("`@*B!`<&%R86T@;6EX960@)'1O7V%D9')E<W,@("`@(%1H92!E+6UA:6P@
M861D<F5S<R!O9B!T:&4@:V5Y('1O('5S92!F;W(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@96YC<GEP=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N($U)345?4&%R="`@4V5E($AO<F1E7T-R>7!T7W-M:6UE.CIE
M;F-R>7!T34E-15!A<G0H*2X@4F5T=7)N<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($E-4&5N8W)Y<'1-24U%4&%R="@D;6EM95]P87)T+"`D=&]?861D<F5S
M<RD*("`@('L*("`@("`@("`D<&%R86US(#T@)'1H:7,M/E]E;F-R>7!T4&%R
M86UE=&5R<R@D=&]?861D<F5S<RD["B`@("`@("`@:68@*&ES7V$H)'!A<F%M
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'!A<F%M
M<SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YE;F-R>7!T34E-
M15!A<G0H)&UI;65?<&%R="P@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3:6=N(&$@34E-15]087)T('5S:6YG(%,O34E-12!U<VEN9R!)35`@
M9&5F875L=',N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM
M95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!S:6=N+@H@("`@("H*
M("`@("`J($!R971U<FX@34E-15]087)T("!3964@2&]R9&5?0W)Y<'1?<VUI
M;64Z.G-I9VY-24U%4&%R="@I+B!2971U<FYS"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@24U0<VEG;DU)345087)T*"1M:6UE7W!A<G0I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YS:6=N34E-15!A<G0H)&UI;65?<&%R="P@)'1H
M:7,M/E]S:6=N4&%R86UE=&5R<R@I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-I9VX@86YD(&5N8W)Y<'0@82!-24U%7U!A<G0@=7-I;F<@4R]-24U%('5S
M:6YG($E-4"!D969A=6QT<RX*("`@("`J"B`@("`@*B!`86-C8V5S<R!P=6)L
M:6,*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("1M:6UE7W!A<G0@
M(%1H92!-24U%7U!A<G0@;V)J96-T('1O('-I9VX@86YD(&5N8W)Y<'0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T;U]A9&1R97-S("`@(%1H92!E+6UA:6P@
M861D<F5S<R!O9B!T:&4@:V5Y('1O('5S92!F;W(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@96YC<GEP=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N($U)345?4&%R="`@4V5E($AO<F1E7T-R>7!T7W-M:6UE.CIS
M:6=N06YD96YC<GEP=$U)345087)T*"DN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!)35!S:6=N06YD16YC<GEP=$U)345087)T*"1M:6UE7W!A
M<G0L("1T;U]A9&1R97-S*0H@("`@>PH@("`@("`@("1E;F-R>7!T7W!A<F%M
M<R`]("1T:&ES+3Y?96YC<GEP=%!A<F%M971E<G,H)'1O7V%D9')E<W,I.PH@
M("`@("`@(&EF("AI<U]A*"1E;F-R>7!T7W!A<F%M<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5N8W)Y<'1?<&%R86US.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G-I9VY!;F1%;F-R>7!T34E-
M15!A<G0H)&UI;65?<&%R="P@)'1H:7,M/E]S:6=N4&%R86UE=&5R<R@I+"`D
M96YC<GEP=%]P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@
M=&AE('!U8FQI8R]P<FEV871E+V%D9&ET:6]N86P@8V5R=&EF:6-A=&5S(&EN
M('1H92!P<F5F97)E;F-E<PH@("`@("H@9G)O;2!A(&=I=F5N(%!+0U,@,3(@
M9FEL92X*("`@("`J"B`@("`@*B!`86-C8V5S<R!P=6)L:6,*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P:V-S,3(@("`@5&AE(%!+0U,@,3(@9&%T
M82X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("!4:&4@<&%S<W=O
M<F0@;V8@=&AE(%!+0U,@,3(@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)'!K<&%S<R`@("!4:&4@<&%S<W=O<F0@=&\@=7-E('1O(&5N8W)Y<'0@=&AE
M('!R:79A=&4@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A9&1&<F]M4$M#4S$R*"1P:V-S,3(L("1P87-S=V]R
M9"P@)'!K<&%S<R`](&YU;&PI"B`@("!["B`@("`@("`@)&]P96YS<VP@/2!)
M35!?4TU)344Z.F-H96-K1F]R3W!E;E-33"@I.PH@("`@("`@(&EF("AI<U]A
M*"1O<&5N<W-L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D;W!E;G-S;#L*("`@("`@("!]"@H@("`@("`@("1S<VQP871H(#T@*&5M
M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)W5T:6QS)UU;)V]P96YS<VQ?8FEN87)Y
M)UTI*2`_(&YU;&P@.B`D1TQ/0D%,4ULG8V]N9B==6R=U=&EL<R==6R=O<&5N
M<W-L7V)I;F%R>2==.PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@G<W-L<&%T
M:"<@/3X@)'-S;'!A=&@L("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D*3L*("`@
M("`@("!I9B`H(65M<'1Y*"1P:W!A<W,I*2!["B`@("`@("`@("`@("1P87)A
M;7-;)VYE=W!A<W-W;W)D)UT@/2`D<&MP87-S.PH@("`@("`@('T*("`@("`@
M("`D<F5S(#T@)'1H:7,M/G!A<G-E4$M#4S$R1&%T82@D<&MC<S$R+"`D<&%R
M86US*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/F%D9%!E<G-O;F%L4')I=F%T94ME>2@D<F5S+3YP<FEV871E*3L*
M("`@("`@("`D=&AI<RT^861D4&5R<V]N86Q0=6)L:6-+97DH)')E<RT^<'5B
M;&EC*3L*("`@("`@("`D=&AI<RT^861D061D:71I;VYA;$-E<G0H)')E<RT^
M8V5R=',I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($5X=')A8W0@=&AE(&-O;G1E;G1S(&9R;VT@<VEG;F5D(%,O34E-
M12!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@(%1H
M92!S:6=N960@4R]-24U%(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!C;VYT96YT<R!E;6)E9&1E9"!I;B!T:&4@<VEG;F5D(&1A
M=&$N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'1R86-T4VEG;F5D
M0V]N=&5N=',H)&1A=&$I"B`@("!["B`@("`@("`@)'-S;'!A=&@@/2`H96UP
M='DH)$=,3T)!3%-;)V-O;F8G75LG=71I;',G75LG;W!E;G-S;%]B:6YA<GDG
M72DI(#\@;G5L;"`Z("1'3$]"04Q36R=C;VYF)UU;)W5T:6QS)UU;)V]P96YS
M<VQ?8FEN87)Y)UT["B`@("`@("`@<F5T=7)N('!A<F5N=#HZ97AT<F%C=%-I
M9VYE9$-O;G1E;G1S*"1D871A+"`D<W-L<&%T:"D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]&971C:&UA
M:6PO````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<V-@`P,3<V-3<`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O;&EB+T9E=&-H;6%I;"]I;6%P+G!H<```````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#(T-#,R`#$P-#$W,S8R-S8V`#`R,3,R,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($E-4%]&971C:&UA:6Q?:6UA<"!D<FEV97(@:6UP;&5M96YT
M<R!T:&4@24U!4%]&971C:&UA:6P@8VQA<W,@9F]R('5S90H@*B!W:71H($E-
M05`O4$]0,R!S97)V97)S+@H@*@H@*B`D2&]R9&4Z(&EM<"]L:6(O1F5T8VAM
M86EL+VEM87`N<&AP+'8@,2XU+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HU-B!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!.=6YO($QO=7)E
M:7)O(#QN=6YO0&-O+G-A<&\N<'0^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($YU;F\@3&]U<F5I<F\@/&YU
M;F]`8V\N<V%P;RYP=#X*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!)35`@
M-"XP"B`J($!P86-K86=E($E-4`H@*B\*8VQA<W,@24U07T9E=&-H;6%I;%]I
M;6%P(&5X=&5N9',@24U07T9E=&-H;6%I;"!["@H@("`@+RHJ"B`@("`@*B!4
M:&4@:6YT97)N86P@<')O=&]C;VQS(&QI<W0N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P<F]T;V-O;',["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8W5R<F5N="!P<F]T;V-O;"!B96EN9R!U<V5D+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-U<G)P
M<F]T;V-O;#L*"B`@("`O*BH*("`@("`J(%1H92!S97)V97(@<W1R:6YG('1O
M('5S92!T;R!C;VYN96-T('1O('1H92!R96UO=&4@;6%I;"!S97)V97(N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V5R
M=F5R<W1R:6YG.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&1E<V-R:7!T
M:6]N(&]F('1H92!D<FEV97(N"B`@("`@*@H@("`@("H@0'-E92!)35!?1F5T
M8VAM86EL.CID97-C<FEP=&EO;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E
M<V-R:7!T:6]N*"D*("`@('L*("`@("`@("!R971U<FX@7R@B24U!4"]03U`S
M($UA:6P@4V5R=F5R<R(I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H
M92!C;VYF:6=U<F%T:6]N('!A<F%M971E<B!A<G)A>2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@24U07T9E=&-H;6%I;%]I;6%P*"1P87)A;7,I"B`@("!["B`@
M("`@("`@+RH@1&5F875L="!V86QU97,@9F]R(&$@8V]U<&QE(&]F('!A<F%M
M971E<G,N("HO"B`@("`@("`@)&1E9F%U;'1S(#T@87)R87DH"B`@("`@("`@
M("`@("=R;6%I;&)O>"<@/3X@)TE.0D]8)RP*("`@("`@("`@("`@)VQM86EL
M8F]X)R`]/B`G24Y"3U@G"B`@("`@("`@*3L*("`@("`@("`D<&%R86US(#T@
M87)R87E?;65R9V4H)&1E9F%U;'1S+"`D<&%R86US*3L*"B`@("`@("`@+RH@
M4V5T('5P('1H92!P<F]T;V-O;',@87)R87D@;F]W+B`J+PH@("`@("`@("1T
M:&ES+3Y?<')O=&]C;VQS(#T@)'1H:7,M/E]P<F]T;V-O;$QI<W0H*3L*"B`@
M("`@("`@<&%R96YT.CI)35!?1F5T8VAM86EL*"1P87)A;7,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N(&$@;&ES="!O9B!P<F]T;V-O;',@<W5P
M<&]R=&5D(&)Y('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!S964@24U0
M7T9E=&-H;6%I;#HZ9V5T4')O=&]C;VQ,:7-T*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4')O=&]C;VQ,:7-T*"D*("`@('L*("`@("`@("`D;W5T<'5T
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!R;W1O8V]L
M<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&]U='!U=%LD:V5Y
M72`]("1V86Q;)VYA;64G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O
M=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!L:7-T
M(&]F($E-05`O4$]0,R!P<F]T;V-O;',@=&AA="!T:&ES(&1R:79E<B!S=7!P
M;W)T<RP@86YD"B`@("`@*B!A<W-O8VEA=&5D(&-O;F9I9W5R871I;VX@;W!T
M:6]N<RX*("`@("`J(%1H:7,@;F5E9',@=&\@8F4@:6X@82!S97!A<F%T92!F
M=6YC=&EO;B!B96-A=7-E(%!(4"!W:6QL(&YO="!A;&QO=PH@("`@("H@9V5T
M=&5X="!S=')I;F=S('1O(&%P<&5A<B!I;B!M96UB97(@=F%R:6%B;&5S+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!P<F]T;V-O;"!C;VYF:6=U<F%T:6]N(&QI<W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P<F]T;V-O;$QI<W0H*0H@("`@>PH@
M("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@)W!O<#-A=71O)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")03U`S("A!
M=71O($1E=&5C="!0<F]T;V-O;',I(BDL"B`@("`@("`@("`@("`@("`G875T
M;R<@/3X@87)R87DH)W!O<#,G+"`G<&]P,VYO=&QS)RP@)W!O<#-S<VQV86QI
M9"<L("=P;W`S<W-L)RDL"B`@("`@("`@("`@("`@("`G8F%S92<@/3X@)U!/
M4#,G"B`@("`@("`@("`@("DL"B`@("`@("`@("`@("=P;W`S)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")03U`S(BDL"B`@("`@
M("`@("`@("`@("`G<W1R:6YG)R`]/B`G<&]P,R<L"B`@("`@("`@("`@("`@
M("`G<&]R="<@/3X@,3$P+`H@("`@("`@("`@("`@("`@)V)A<V4G(#T^("=0
M3U`S)PH@("`@("`@("`@("`I+`H@("`@("`@("`@("`G<&]P,VYO=&QS)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")03U`S+"!N
M;R!43%,B*2P*("`@("`@("`@("`@("`@("=S=')I;F<G(#T^("=P;W`S+VYO
M=&QS)RP*("`@("`@("`@("`@("`@("=P;W)T)R`]/B`Q,3`L"B`@("`@("`@
M("`@("`@("`G8F%S92<@/3X@)U!/4#,G"B`@("`@("`@("`@("DL"B`@("`@
M("`@("`@("=P;W`S<W-L=F%L:60G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)VYA;64G(#T^(%\H(E!/4#,@;W9E<B!34TPB*2P*("`@("`@("`@("`@
M("`@("=S=')I;F<G(#T^("=P;W`S+W-S;"<L"B`@("`@("`@("`@("`@("`G
M<&]R="<@/3X@.3DU+`H@("`@("`@("`@("`@("`@)V)A<V4G(#T^("=03U`S
M)PH@("`@("`@("`@("`I+`H@("`@("`@("`@("`G<&]P,W-S;"<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B4$]0,R!O=F5R(%-3
M3"`H<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I(BDL"B`@("`@("`@("`@("`@
M("`G<W1R:6YG)R`]/B`G<&]P,R]S<VPO;F]V86QI9&%T92UC97)T)RP*("`@
M("`@("`@("`@("`@("=P;W)T)R`]/B`Y.34L"B`@("`@("`@("`@("`@("`G
M8F%S92<@/3X@)U!/4#,G"B`@("`@("`@("`@("DL"B`@("`@("`@("`@("=I
M;6%P875T;R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@
M7R@B24U!4"`H075T;R!$971E8W0@4')O=&]C;VQS*2(I+`H@("`@("`@("`@
M("`@("`@)V%U=&\G(#T^(&%R<F%Y*"=I;6%P)RP@)VEM87!N;W1L<R<L("=I
M;6%P<W-L=F%L:60G+"`G:6UA<'-S;"<I+`H@("`@("`@("`@("`@("`@)V)A
M<V4G(#T^("=)34%0)PH@("`@("`@("`@("`I+`H@("`@("`@("`@("`G:6UA
M<"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B24U!
M4"(I+`H@("`@("`@("`@("`@("`@)W-T<FEN9R<@/3X@)VEM87`G+`H@("`@
M("`@("`@("`@("`@)W!O<G0G(#T^(#$T,RP*("`@("`@("`@("`@("`@("=B
M87-E)R`]/B`G24U!4"<*("`@("`@("`@("`@*2P*("`@("`@("`@("`@)VEM
M87!N;W1L<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@
M7R@B24U!4"P@;F\@5$Q3(BDL"B`@("`@("`@("`@("`@("`G<W1R:6YG)R`]
M/B`G:6UA<"]N;W1L<R<L"B`@("`@("`@("`@("`@("`G<&]R="<@/3X@,30S
M+`H@("`@("`@("`@("`@("`@)V)A<V4G(#T^("=)34%0)PH@("`@("`@("`@
M("`I+`H@("`@("`@("`@("`G:6UA<'-S;'9A;&ED)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*"))34%0(&]V97(@4U-,(BDL"B`@
M("`@("`@("`@("`@("`G<W1R:6YG)R`]/B`G:6UA<"]S<VPG+`H@("`@("`@
M("`@("`@("`@)W!O<G0G(#T^(#DY,RP*("`@("`@("`@("`@("`@("=B87-E
M)R`]/B`G24U!4"<*("`@("`@("`@("`@*2P*("`@("`@("`@("`@)VEM87!S
M<VPG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(DE-
M05`@;W9E<B!34TP@*'-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2(I+`H@("`@
M("`@("`@("`@("`@)W-T<FEN9R<@/3X@)VEM87`O<W-L+VYO=F%L:61A=&4M
M8V5R="<L"B`@("`@("`@("`@("`@("`G<&]R="<@/3X@.3DS+`H@("`@("`@
M("`@("`@("`@)V)A<V4G(#T^("=)34%0)PH@("`@("`@("`@("`I"B`@("`@
M("`@*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!T:&4@<F5M
M;W1E(&UA:6QB;W@@97AI<W1S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`F)'-T<F5A;2`@
M02!V86QI9"!)34%0(')E<V]U<F-E('-T<F5A;2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@($1O97,@=&AE(')E;6]T92!M86EL8F]X(&5X:7-T
M/PH@("`@("HO"B`@("!F=6YC=&EO;B!?<F5M;W1E36)O>$5X:7-T<R@F)'-T
M<F5A;2D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;
M)W)M86EL8F]X)UTI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<FUA:6QB;W@G
M72`]/2`G24Y"3U@G*2!["B`@("`@("`@("`@("\J($E.0D]8(&%L=V%Y<R!E
M>&ES=',@86YD(&ES(&$@<W!E8VEA;"!C87-E+B`J+PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(&EF("A`:6UA<%]L:7-T
M;6%I;&)O>"@D<W1R96%M+"`D=&AI<RT^7W-E<G9E<G-T<FEN9RP@)'1H:7,M
M/E]P87)A;7-;)W)M86EL8F]X)UTI*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&%T
M('1H92!R96UO=&4@<V5R=F5R(&ES('5P+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%)E='5R
M;G,@=')U92!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W-R=DQI=F5S*"D*("`@('L*("`@("`@
M("`D;6%I;'-E<G9E<B`]($!F<V]C:V]P96XH)'1H:7,M/E]P87)A;7-;)W-E
M<G9E<B==+"`D=&AI<RT^7W!R;W1O8V]L<ULD=&AI<RT^7V-U<G)P<F]T;V-O
M;%U;)W!O<G0G72P@)&5R<FYO+"`D97)R<W1R*3L*("`@("`@("!I9B`H(21M
M86EL<V5R=F5R*2!["B`@("`@("`@("`@(&EF("@D97)R;F\I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;B!N;W0@
M8V]N;F5C="!T;R!T:&4@<F5M;W1E(&UA:6P@<V5R=F5R.B`B*2`N("1E<G)S
M='(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N(&YO="!C;VYN96-T('1O('1H
M92!R96UO=&4@;6%I;"!S97)V97(N(BDI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!F8VQO<V4H)&UA:6QS97)V97(I.PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M8V]N;F5C="!T;R!T:&4@;6%I;"!S97)V97(*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2971U
M<FYS(&%N($E-05`@4W1R96%M(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@
M("1R97,@/2`D=&AI<RT^7W-R=DQI=F5S*"D["B`@("`@("`@:68@*&ES7V$H
M)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T:&4@<V5R=F5R('-T
M<FEN9R!N;W<N("HO"B`@("`@("`@)'1H:7,M/E]S97)V97)S=')I;F<@/2`G
M>R<@+B`D=&AI<RT^7W!A<F%M<ULG<V5R=F5R)UT@+B`G.B<@+B`D=&AI<RT^
M7W!R;W1O8V]L<ULD=&AI<RT^7V-U<G)P<F]T;V-O;%U;)W!O<G0G72`N("<O
M)RX@)'1H:7,M/E]P<F]T;V-O;'-;)'1H:7,M/E]C=7)R<')O=&]C;VQ=6R=S
M=')I;F<G72`N("=])SL*("`@("`@("`D<V5R=F5R7W-T<FEN9R`]("1T:&ES
M+3Y?<V5R=F5R<W1R:6YG.PH*("`@("`@("!I9B`H)'1H:7,M/E]P<F]T;V-O
M;'-;)'1H:7,M/E]C=7)R<')O=&]C;VQ=6R=B87-E)UT@/3T@)TE-05`G*2![
M"B`@("`@("`@("`@("1S97)V97)?<W1R:6YG("X]("1T:&ES+3Y?<&%R86US
M6R=R;6%I;&)O>"==.PH@("`@("`@('T*"B`@("`@("`@)'-T<F5A;2`]($!I
M;6%P7V]P96XH)'-E<G9E<E]S=')I;F<L("1T:&ES+3Y?<&%R86US6R=U<V5R
M;F%M92==+"`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["@H@("`@("`@
M(&EF("@D<W1R96%M(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")#;VYN96-T:6]N('1O('-E<G9E<B!F86EL
M960B*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-T<F5A;3L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&UA:6QB;V1Y(&%N9"!C86QL
M<R!T:&4@8W5S=&]M(&9I;'1E<B!F=6YC=&EO;BX*("`@("`J(%)E;6]V92!B
M87)E(&YE=VQI;F5S(&%N9"!S971S(&UE<W-A9V4@8V]L;W(N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("1S=')E86T@($E-05`@8V]N;F5C=&EO;B!S=')E86TN"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D:6YD97@@("`@365S<V%G92!T;R!F971C:"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@0V]R<F5C=&5D(&UA:6P@
M8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$UA:6Q-97-S86=E
M*"1S=')E86TL("1I;F1E>"D*("`@('L*("`@("`@("`O*B!'970@=&AE(&UE
M<W-A9V4@:&5A9&5R<RX@*B\*("`@("`@("`D:&5A9&5R(#T@0&EM87!?9F5T
M8VAH96%D97(H)'-T<F5A;2P@)&EN9&5X*3L*"B`@("`@("`@+RH@1V5T('1H
M92!M97-S86=E(&)O9'DN("HO"B`@("`@("`@)&)O9'D@/2!`:6UA<%]B;V1Y
M*"1S=')E86TL("1I;F1E>"P@1E1?4$5%2RD["@H@("`@("`@(')E='5R;B!P
M87)E;G0Z.E]P<F]C97-S36%I;$UE<W-A9V4H)&AE861E<BP@)&)O9'DI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;6%I;"!U<VEN9R!T:&4@
M9&%T82!I;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<V5E($E-4%]&
M971C:&UA:6PZ.F=E=$UA:6PH*0H@("`@("HO"B`@("!F=6YC=&EO;B!G971-
M86EL*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F]T;V-O
M;'-;)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UU=6R=A=71O)UTI*2!["B`@
M("`@("`@("`@("1P<F]T;V-O;',@/2`D=&AI<RT^7W!R;W1O8V]L<ULD=&AI
M<RT^7W!A<F%M<ULG<')O=&]C;VPG75U;)V%U=&\G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<')O=&]C;VQS(#T@87)R87DH)'1H:7,M/E]P
M87)A;7-;)W!R;W1O8V]L)UTI.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)'!R;W1O8V]L<R!A<R`D=F%L*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M8W5R<G!R;W1O8V]L(#T@)'9A;#L*("`@("`@("`@("`@)')E="`]("1T:&ES
M+3Y?9V5T36%I;"@I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)')E="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*
M("`@("\J*@H@("`@("H@26YT97)N86P@9G5N8W1I;VX@=7-E9"!T;R!G970@
M;6%I;"!F<F]M(&$@<VEN9VQE('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(L('1H92!N
M=6UB97(@;V8@;65S<V%G97,*("`@("`J("`@("`@("`@("`@("`@(&9E=&-H
M960@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$UA:6PH
M*0H@("`@>PH@("`@("`@("1N=6U-<V=S(#T@,#L*("`@("`@("`D<')O=&]C
M;VQS(#T@87)R87DH*3L*"B`@("`@("`@)'-T<F5A;2`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S=')E86TL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=')E86T["B`@("`@("`@?0H*
M("`@("`@("`O*B!#:&5C:R!T;R!S964@:68@<F5M;W1E(&UA:6QB;W@@97AI
M<W1S+B`J+PH@("`@("`@("1U<V5I;6%P(#T@*"1T:&ES+3Y?<')O=&]C;VQS
M6R1T:&ES+3Y?8W5R<G!R;W1O8V]L75LG8F%S92==(#T]("=)34%0)RD["B`@
M("`@("`@:68@*"1U<V5I;6%P*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]R96UO=&5-8F]X17AI<W1S*"1S=')E86TI*2!["B`@("`@("`@("`@("`@
M("!`:6UA<%]C;&]S92@D<W1R96%M*3L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@4F5M;W1E($UA:6QB;W@B
M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1M<V=?8V]U
M;G0@/2!`:6UA<%]N=6U?;7-G*"1S=')E86TI.PH@("`@("`@(&EF("@A)&US
M9U]C;W5N="D@>PH@("`@("`@("`@("!`:6UA<%]C;&]S92@D<W1R96%M*3L*
M("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H*("`@("`@("!F;W(@
M*"1I;F1E>"`](#$[("1I;F1E>"`\/2`D;7-G7V-O=6YT.R`D:6YD97@K*RD@
M>PH@("`@("`@("`@("`O*B!'970@=&AE(&9L86=S('-O('=E(&-A;B!S970@
M:70@8F%C:R!T;R!U;G-E96XN("HO"B`@("`@("`@("`@(&QI<W0H)&@I(#T@
M0&EM87!?9F5T8VA?;W9E<G9I97<H)'-T<F5A;2P@)&EN9&5X*3L*"B`@("`@
M("`@("`@(&EF("@H)'1H:7,M/E]P87)A;7-;)V]N;'EN97<G72`F)@H@("`@
M("`@("`@("`@("`@("@D:"T^<F5C96YT('Q\("$D:"T^<V5E;BD@)B8*("`@
M("`@("`@("`@("`@("`A)&@M/F1E;&5T960I('Q\"B`@("`@("`@("`@("`@
M("`H(21T:&ES+3Y?<&%R86US6R=O;FQY;F5W)UT@)B8@(21H+3YD96QE=&5D
M*2D@>PH*("`@("`@("`@("`@("`@("\J($-H96-K(&UE<W-A9V4@<VEZ92X@
M*B\*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]C:&5C:TUE<W-A9V53
M:7IE*"1H+3YS:7IE+"!I<W-E="@D:"T^<W5B:F5C="D@/R`D:"T^<W5B:F5C
M="`Z("<G+"`D:"T^9G)O;2DI('L*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!'
M970@=&AE(&-O;7!L971E(&UE<W-A9V4N("HO"B`@("`@("`@("`@("`@("`D
M;6%I;%]S;W5R8V4@/2`D=&AI<RT^7V=E=$UA:6Q-97-S86=E*"1S=')E86TL
M("1I;F1E>"D["@H@("`@("`@("`@("`@("`@+RH@07!P96YD('1O('1H92!S
M97)V97(N("HO"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]A9&1-97-S
M86=E*"1M86EL7W-O=7)C92DI('L*("`@("`@("`@("`@("`@("`@("`D;G5M
M37-G<RLK.PH*("`@("`@("`@("`@("`@("`@("`O*B!296UO=F4@=&AE(&UA
M:6P@:68@)V1E;"<@:7,@<V5T+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^7W!A<F%M<ULG9&5L)UTI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@0&EM87!?9&5L971E*"1S=')E86TL("1I;F1E>"D["B`@("`@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O*B!-87)K(&UE
M<W-A9V4@<V5E;B!I9B`G;6%R:W-E96XG(&ES('-E="X@*B\*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'5S96EM87`@)B8@)'1H:7,M/E]P87)A;7-;)VUA
M<FMS965N)UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@0&EM87!?<V5T
M9FQA9U]F=6QL*"1S=')E86TL("1I;F1E>"P@(EQ<4V5E;B(I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+RH@17AP=6YG92!A;&P@9&5L971E9"!M
M97-S86=E<R!N;W<N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=D
M96PG72D@>PH@("`@("`@("`@("!`:6UA<%]E>'!U;F=E*"1S=')E86TI.PH@
M("`@("`@('T*"B`@("`@("`@0&EM87!?8VQO<V4H)'-T<F5A;2D["@H@("`@
M("`@(')E='5R;B`D;G5M37-G<SL*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O075T:"\`````````````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-C8`,#$V-C8T`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]!=71H
M+VEM<"YP:'``````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R-#8P,P`Q,#0Q-S,V,C<V-@`P,C`Q-C0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H
M7VEM<#HZ(&-L87-S('!R;W9I9&5S(&%N($E-4"!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES=&5M+@H@*@H@*B!2
M97%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@3F]N92X\+W!R93X*("H*
M("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@($YO;F4N/"]P<F4^
M"B`J"B`J"B`J("1(;W)D93H@:6UP+VQI8B]!=71H+VEM<"YP:'`L=B`Q+C$V
M+C8N,30@,C`P-B\P,B\Q-2`P,3HR.3HR-B!S;'5S87)Z($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?075T:`H@*B\*8VQA<W,@075T:%]I;7`@97AT96YD<R!!=71H('L*"B`@
M("`O*BH*("`@("`J($E-4"!S<&5C:69I8R!A=71H96YT:6-A=&EO;B!P87)A
M;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?:6UP4&%R86US(#T@87)R87DH"B`@("`@("`@)V9L86=S)R`]/B`P
M+`H@("`@("`@("=S971U<"<@/3X@9F%L<V4*("`@("D["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1S(&$@;F5W($E-4"!A=71H96YT:6-A=&EO;B!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S
M:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@075T:%]I;7`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VEM87`G*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BA?
M*")!=71H7VEM<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(I*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D
M96YT:6%L<R!A<F4@=F%L:60L(&%N9"!I9@H@("`@("H@<F5Q=65S=&5D+"!M
M87)K('1H92!U<V5R(&%S(&QO9V=E9"!I;B!I;B!T:&4@8W5R<F5N="!S97-S
M:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))1"`@("`@
M(%1H92!U<V5R240@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R
M961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@8VAE8VLN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D;&]G:6X@("`@("!7:&5T:&5R('1O(&QO9R!T:&4@
M=7-E<B!I;BX@268@9F%L<V4L('=E)VQL"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!O;FQY('1E<W0@=&AE(&-R961E;G1I86QS(&%N9"!W
M;VXG="!M;V1I9GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!C=7)R96YT('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A
M;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71H96YT:6-A=&4H)'5S97))
M1"`](&YU;&PL("1C<F5D96YT:6%L<R`](&%R<F%Y*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&QO9VEN(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M+R\@0VAE8VL@9F]R(&9O<B!H;W)D96%U=&@N"B`@("`@("`@:68@*&5M<'1Y
M*"1?4T534TE/3ELG:6UP)UU;)W5N:7%U<V5R)UTI*2!["B`@("`@("`@("`@
M(&EF("A)35`Z.F-A;D%U=&],;V=I;B@I*2!["B`@("`@("`@("`@("`@("`D
M<V5R=F5R7VME>2`]($E-4#HZ9V5T075T;TQO9VEN4V5R=F5R*"D["@H@("`@
M("`@("`@("`@("`@<F5Q=6ER92!)35!?0D%312`N("<O8V]N9FEG+W-E<G9E
M<G,N<&AP)SL*("`@("`@("`@("`@("`@("1P='(@/2`F)'-E<G9E<G-;)'-E
M<G9E<E]K97E=.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P=');)VAO
M<F1E875T:"==*2D@>PH*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R8V%S
M96-M<"@D<'1R6R=H;W)D96%U=&@G72P@)V9U;&PG*2`]/2`P*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1I;6%P=7-E<B`]($%U=&@Z.F=E=$%U=&@H
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:6UA<'5S97(@/2!!=71H.CIG971"87)E075T:"@I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D<&%S
M<R`]($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RD["@H@("`@("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+U-E
M<W-I;VXN<&AP)SL*("`@("`@("`@("`@("`@("`@("!I9B`H24U07U-E<W-I
M;VXZ.F-R96%T95-E<W-I;VXH)&EM87!U<V5R+"`D<&%S<RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!T
M<ELG<V5R=F5R)UTL("1P='(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)%]315)615);)TA45%!?6%]&3U)705)$141?1D]2)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>2`]('-P<FEN
M=&8H)TQO9VEN('-U8V-E<W,@9F]R("5S(%LE<UT@*&9O<G=A<F1E9"!F;W(@
M6R5S72D@=&\@>R5S.B5S?2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&EM87!U<V5R+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1?4T525D526R=214U/5$5?
M041$4B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1?4T525D526R=(5%107UA?1D]25T%21$5$7T9/4B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P=');
M)W-E<G9E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P=');)W!O<G0G72D["B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R
M>2`]('-P<FEN=&8H)TQO9VEN('-U8V-E<W,@9F]R("5S(%LE<UT@=&\@>R5S
M.B5S?2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&EM87!U<V5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1?4T525D526R=214U/5$5?041$4B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P=');
M)W-E<G9E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P=');)W!O<G0G72D["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)&5N=')Y+"!?7T9)3$5?7RP@7U],24Y%7U\L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1U<V5R240I*2!["B`@
M("`@("`@("`@(&EF("AE;7!T>2@D7U-%4U-)3TY;)VEM<"==6R=U;FEQ=7-E
M<B==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1U<V5R240@/2`D7U-%4U-)3TY;)VEM<"==
M6R=U;FEQ=7-E<B==.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1C
M<F5D96YT:6%L<RDI('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1?4T534TE/
M3ELG:6UP)UU;)W!A<W,G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8W)E9&5N=&EA;',@
M/2!A<G)A>2@G<&%S<W=O<F0G(#T^(%-E8W)E=#HZ<F5A9"A396-R970Z.F=E
M=$ME>2@G:6UP)RDL("1?4T534TE/3ELG:6UP)UU;)W!A<W,G72DI.PH@("`@
M("`@('T*"B`@("`@("`@)&QO9VEN(#T@*"1L;V=I;B`F)B`H)'1H:7,M/F=E
M=%!R;W9I9&5R*"D@/3T@)VEM<"<I*3L*"B`@("`@("`@<F5T=7)N('!A<F5N
M=#HZ875T:&5N=&EC871E*"1U<V5R240L("1C<F5D96YT:6%L<RP@)&QO9VEN
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!)35`M<W!E8VEF:6,@875T
M:&5N=&EC871I;VX@;W!T:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@5&AE('!A<F%M<R!T;R!S970N"B`@("`@*B`\<')E/@H@
M("`@("H@2V5Y<SH*("`@("`J("TM+2TM"B`@("`@*B`G9FQA9W,G("`M+2`@
M*&EN=&5G97(I($9L86=S('1O('!A<W,@=&\@:6UA<%]O<&5N*"DN"B`@("`@
M*B`@("`@("`@("`@("`@1$5!1E5,5#H@,`H@("`@("H@("!/4%]214%$3TY,
M62`@.B!/<&5N('1H92!M86EL8F]X(')E860M;VYL>2X*("`@("`J("`@3U!?
M04Y/3EE-3U53(#H@*$Y.5%`@;VYL>2D@1&]N)W0@=7-E(&]R('5P9&%T92!A
M("YN97=R8R!F:6QE+@H@("`@("H@("!/4%](04Q&3U!%3B`@.B`H24U!4"!A
M;F0@3DY44"!O;FQY*2!/<&5N(&$@8V]N;F5C=&EO;BP@8G5T(&YO="!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@('-P96-I9FEC(&UA:6QB;W@N"B`@("`@
M*B`@($-,7T584%5.1T4@("`Z($5X<'5N9V4@=&AE(&UA:6QB;W@@875T;VUA
M=&EC86QL>2!W:&5N('1H92!S=')E86T@:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@8VQO<V5D+@H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%U=&AE;G1I8V%T94]P=&EO;G,H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I;7!087)A;7,@/2!A<G)A>5]M97)G92@D
M=&AI<RT^7VEM<%!A<F%M<RP@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A
M<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DE$("`@("`@5&AE('5S97))
M1"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@
M($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I86QS+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I
M86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I
M8V%T92@D=7-E<DE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@9VQO
M8F%L("1C;VYF+"`D<')E9G,["@H@("`@("`@(&EF("@A*&ES<V5T*"1?4T53
M4TE/3ELG:6UP)UTI("8F(&ES7V%R<F%Y*"1?4T534TE/3ELG:6UP)UTI*2D@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)'!R969S*2D@>PH@("`@("`@("`@
M("`@("`@)'!R969S+3YC;&5A;G5P*'1R=64I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7U-%
M4U-)3TXI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`O*B!3970@=&AE(&UA:6QD;VUA:6XN("HO"B`@("`@("`@)&UA
M:6QD;VUA:6X@/2!P<F5G7W)E<&QA8V4H)R];7BU<+F$M>C`M.5TO:2<L("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5F<RT^
M9V5T5F%L=64H)VUA:6Q?9&]M86EN)RDI.PH@("`@("`@(&EF("@A96UP='DH
M)&UA:6QD;VUA:6XI*2!["B`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;
M)VUA:6QD;VUA:6XG72`]("1M86EL9&]M86EN.PH@("`@("`@('T@96QS96EF
M("@A96UP='DH)%]315-324].6R=I;7`G75LG;6%I;&1O;6%I;B==*2D@>PH@
M("`@("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=M86EL7V1O;6%I;B<L("1?
M4T534TE/3ELG:6UP)UU;)VUA:6QD;VUA:6XG72D["B`@("`@("`@?0H*"B`@
M("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG:6UP)UTI*2!["B`@("`@("`@
M("`@("1'3$]"04Q36R=I;7`G72`]("8D7U-%4U-)3TY;)VEM<"==.PH@("`@
M("`@('T*"B`@("`@("`@)&-O;FYS='(@/2!N=6QL.PH@("`@("`@("1F;&%G
M<R`]("1T:&ES+3Y?:6UP4&%R86US6R=F;&%G<R==.PH*("`@("`@("`O*B!0
M<F]C97-S('1H92!M86EL8F]X('!A<F%M971E<B`H:68@<')E<V5N="DN("HO
M"B`@("`@("`@)&UA:6QB;W@@/2!5=&EL.CIG971&;W)M1&%T82@G;6%I;&)O
M>"<I.PH@("`@("`@(&EF("@A:7-?;G5L;"@D;6%I;&)O>"DI('L*("`@("`@
M("`@("`@)%]315-324].6R=I;7`G75LG;6%I;&)O>"==(#T@)&UA:6QB;W@[
M"B`@("`@("`@?2!E;'-E:68@*"%I<W-E="@D7U-%4U-)3TY;)VEM<"==6R=M
M86EL8F]X)UTI*2!["B`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)VUA
M:6QB;W@G72`]("=)3D)/6"<["B`@("`@("`@?0H@("`@("`@("1?4T534TE/
M3ELG:6UP)UU;)W1H:7-M86EL8F]X)UT@/2!5=&EL.CIG971&;W)M1&%T82@G
M=&AI<VUA:6QB;W@G+"`D7U-%4U-)3TY;)VEM<"==6R=M86EL8F]X)UTI.PH*
M("`@("`@("`O*B!)<R!T:&ES(&$@<V5A<F-H(&UA:6QB;W@_("HO"B`@("`@
M("`@)&EM<%]S96%R8VA?<&%R86US(#T@;G5L;#L*("`@("`@("!I9B`H<W1R
M<&]S*"1?4T534TE/3ELG:6UP)UU;)VUA:6QB;W@G72P@24U07U-%05)#2%]-
M0D]8*2`]/3T@,"D@>PH@("`@("`@("`@("`D:6UP7W-E87)C:%]P87)A;7,@
M/2!A<G)A>2@G:60G(#T^("1?4T534TE/3ELG:6UP)UU;)VUA:6QB;W@G72D[
M"B`@("`@("`@?0H@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O
M;&EB+U-E87)C:"YP:'`G.PH@("`@("`@("1'3$]"04Q36R=I;7!?<V5A<F-H
M)UT@/2!N97<@24U07U-E87)C:"@D:6UP7W-E87)C:%]P87)A;7,I.PH*("`@
M("`@("!S=VET8V@@*"1?4T534TE/3ELG:6UP)UU;)V)A<V5?<')O=&]C;VPG
M72D@>PH@("`@("`@(&-A<V4@)W!O<#,G.@H@("`@("`@("`@("`D9FQA9W,@
M)CT@?D]07T%.3TY934]54SL*("`@("`@("`@("`@)&9L86=S("8]('Y/4%](
M04Q&3U!%3CL*"B`@("`@("`@("`@("\J(%1U<FX@<V]M92!O<'1I;VYS(&]F
M9B!I9B!W92!A<F4@=V]R:VEN9R!W:71H(%!/4#,N("HO"B`@("`@("`@("`@
M("1C;VYF6R=U<V5R)UU;)V%L;&]W7V9O;&1E<G,G72`](&9A;'-E.PH@("`@
M("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=S879E7W-E;G1?;6%I;"<L(&9A
M;'-E*3L*("`@("`@("`@("`@)'!R969S+3YS971,;V-K960H)W-A=F5?<V5N
M=%]M86EL)RP@=')U92D["B`@("`@("`@("`@("1P<F5F<RT^<V5T3&]C:V5D
M*"=S96YT7VUA:6Q?9F]L9&5R)RP@=')U92D["B`@("`@("`@("`@("1P<F5F
M<RT^<V5T3&]C:V5D*"=D<F%F='-?9F]L9&5R)RP@=')U92D["B`@("`@("`@
M("`@("1P<F5F<RT^<V5T3&]C:V5D*"=T<F%S:%]F;VQD97(G+"!T<G5E*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@(&EF("@D1TQ/0D%,4ULG:6UP7W-E87)C:"==+3YI<U-E87)C:$UB;W@H
M)%]315-324].6R=I;7`G75LG=&AI<VUA:6QB;W@G72DI('L*("`@("`@("`@
M("`@("`@(&EF("AS=')S='(H571I;#HZ9V5T1F]R;41A=&$H)VEN9&5X)RDL
M("<Z)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@97AP;&]D92@G
M.B<L(%5T:6PZ.F=E=$9O<FU$871A*"=I;F1E>"<I*3L*("`@("`@("`@("`@
M("`@("`@("`D8V]N;G-T<B`]("1T;7!;,5T["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1A:6YD97@@/2!5=&EL.CIG
M971&;W)M1&%T82@G87)R87E?:6YD97@G*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&%I;F1E>"`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&UP(#T@97AP;&]D92A)35!?35-'7U-%4"P@)%]315-324].6R=I
M;7`G75LG;7-G;"==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&UB;W@@
M/2!S=6)S='(H)'1M<%LD86EN9&5X72P@<W1R<&]S*"1T;7!;)&%I;F1E>%TL
M($E-4%])1%A?4T50*2`K(#$I.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N;G-T<B`]("1M8F]X.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F;&%G<R!\/2!/4%](04Q&3U!%
M3CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8V]N;G-T<B`]
M("1?4T534TE/3ELG:6UP)UU;)W1H:7-M86EL8F]X)UT["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O*B!/
M<&5N(&%N($E-05`@<W1R96%M+B`J+PH@("`@("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+TE-05`N<&AP)SL*("`@("`@("`D:6UP7VEM87`@
M/2`F24U07TE-05`Z.G-I;F=L971O;B@I.PH@("`@("`@("1I;7!?:6UA<"T^
M8VAA;F=E36)O>"@D8V]N;G-T<BP@)&9L86=S*3L*"B`@("`@("`@:68@*"$D
M7U-%4U-)3TY;)VEM<"==6R=S=')E86TG72D@>PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1?4T534TE/3ELG:6UP)UU;)W-E<G9E<B==*2`F)@H@("`@("`@
M("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG:6UP)UU;)W!O<G0G72D@)B8*
M("`@("`@("`@("`@("`@("%E;7!T>2@D7U-%4U-)3TY;)VEM<"==6R=P<F]T
M;V-O;"==*2`F)@H@("`@("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG
M:6UP)UU;)W5S97(G72DI('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)%]315)615);)TA45%!?6%]&3U)705)$141?1D]2)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&5N=')Y(#T@<W!R:6YT9B@G1D%)3$5$($Q/1TE.("5S
M("AF;W)W87)D960@9F]R(%LE<UTI('1O("5S.B5S6R5S72!A<R`E<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D7U-%4E9%4ELG
M4D5-3U1%7T%$1%(G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1?4T525D526R=(5%107UA?1D]25T%21$5$7T9/4B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I
M;7`G75LG<V5R=F5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=P;W)T)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=P
M<F]T;V-O;"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)%]315-324].6R=I;7`G75LG=7-E<B==*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&5N=')Y(#T@<W!R:6YT
M9B@G1D%)3$5$($Q/1TE.("5S('1O("5S.B5S6R5S72!A<R`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D7U-%4E9%4ELG4D5-
M3U1%7T%$1%(G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1?4T534TE/3ELG:6UP)UU;)W-E<G9E<B==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG<&]R
M="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%]3
M15-324].6R=I;7`G75LG<')O=&]C;VPG72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W5S97(G72D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D96YT<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M15)2*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@=6YS970H)%]315-3
M24].6R=I;7`G72D["B`@("`@("`@("`@(&EF("AI<W-E="@D<')E9G,I*2![
M"B`@("`@("`@("`@("`@("`D<')E9G,M/F-L96%N=7`H=')U92D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H0554
M2%]214%33TY?1D%)3$5$*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3;VUE=VAA="!O9B!A(&AA8VL@=&\@86QL;W<@24U0('1O('-E
M="!A;B!A=71H96YT:6-A=&EO;B!E<G)O<B!M97-S86=E"B`@("`@*B!T:&%T
M(&UA>2!O8V-U<B!O=71S:61E(&]F('1H:7,@9FEL92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1M<V<@(%1H92!E<G)O<B!M97-S86=E('1O('-E
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@24U0<V5T075T:$5R<F]R37-G*"1M
M<V<I"B`@("!["B`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]2
M14%33TY?34534T%'12P@)&US9RD["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O;&EB+TU)344O````````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8V`#`Q-C4Q,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O34E-12]6:65W97(O````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-C8`,#$W-S4S`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,S8V,@`Q,#0Q-S,V,C<V-@`P,C$T-S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<"<["@HO*BH*("H@5&AE
M($E-4%]-24U%7U9I97=E<E]R9F,X,C(@8VQA<W,@<F5N9&5R<R!O=70@;65S
M<V%G97,@9G)O;0H@*B!M97-S86=E+W)F8S@R,B!C;VYT96YT('1Y<&5S+@H@
M*@H@*B`D2&]R9&4Z(&EM<"]L:6(O34E-12]6:65W97(O<F9C.#(R+G!H<"QV
M(#$N,C8N,3`N,3`@,C`P-B\P,B\Q,"`Q-CHU,#HS,2!S;'5S87)Z($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H@0'-I;F-E("`@24U0(#0N,`H@*B!`<&%C:V%G92!(
M;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@24U07TU)345?5FEE=V5R7W)F
M8S@R,B!E>'1E;F1S($U)345?5FEE=V5R7W)F8S@R,B!["@H@("`@+RHJ"B`@
M("`@*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!W
M:71H(&$@<F5F97)E;F-E('1O(&$@34E-15]#;VYT96YT<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D('1E>'0@:6X@2%1-3"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,I"B`@("!["B`@("`@("`@
M)&-O;G1E;G1S(#T@)B1P87)A;7-;,%T["@H@("`@("`@("\J($=E="!T:&4@
M96YT:7)E(&)O9'D@<&%R="!O9B!T:&4@;65S<V%G92]R9F,X,C(@8V]N=&5N
M=',N("HO"B`@("`@("`@:68@*&ES7V$H)&-O;G1E;G1S+"`G24U07T-O;G1E
M;G1S)RD@)B8*("`@("`@("`@("`@)'1H:7,M/FUI;65?<&%R="T^9V5T34E-
M14ED*"DI('L*("`@("`@("`@("`@)'1H:7,M/FUI;65?<&%R="`]("8D8V]N
M=&5N=',M/F=E=$1E8V]D961-24U%4&%R="@D=&AI<RT^;6EM95]P87)T+3YG
M971-24U%260H*2P@=')U92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M<&%R96YT.CIR96YD97(H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@871T86-H;65N="!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@=VET:"!A(')E9F5R96YC
M92!T;R!A($U)345?0V]N=&5N=',*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R96YD97)E9"!T97AT(&EN($A434PN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<D%T=&%C:&UE;G1);F9O*"1P87)A;7,I"B`@("!["B`@("`@("`@
M)&-O;G1E;G1S(#T@)B1P87)A;7-;,%T["@H@("`@("`@(&EF("AI<U]A*"1C
M;VYT96YT<RP@)TE-4%]#;VYT96YT<R<I("8F"B`@("`@("`@("`@("$D=&AI
M<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I*2!["B`@("`@("`@("`@("1I
M9"`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$U)345)9"@I.PH@("`@("`@("`@
M("`D:&1R7VED(#T@<W5B<W1R*"1I9"P@+3(I.PH@("`@("`@("`@("!I9B`H
M)&AD<E]I9"`A/2`G+C`G*2!["B`@("`@("`@("`@("`@("`D:60@+CT@)RXP
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^;6EM95]P87)T
M(#T@)B1C;VYT96YT<RT^9V5T1&5C;V1E9$U)345087)T*"1I9"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@<&%R96YT.CIR96YD97)!='1A8VAM96YT
M26YF;R@I.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O34E-12]6
M:65W97(O<&QA:6XN<&AP````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3,T,#4`,3`T,3<S-C(W-C8`,#(Q-38W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO
M<F1E+TU)344O5FEE=V5R+W!L86EN+G!H<"<["@HO*BH*("H@5&AE($E-4%]-
M24U%7U9I97=E<E]P;&%I;B!C;&%S<R!R96YD97)S(&]U="!T97AT+W!L86EN
M($U)344@<&%R=',*("H@=VET:"!54DQS(&UA9&4@:6YT;R!H>7!E<FQI;FMS
M+@H@*@H@*B`D2&]R9&4Z(&EM<"]L:6(O34E-12]6:65W97(O<&QA:6XN<&AP
M+'8@,2XU."XX+C$S(#(P,#8O,#(O,3,@,C`Z-#DZ-3,@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-
M15]6:65W97(*("HO"F-L87-S($E-4%]-24U%7U9I97=E<E]P;&%I;B!E>'1E
M;F1S($U)345?5FEE=V5R7W!L86EN('L*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@82!R969E
M<F5N8V4@=&\@82!-24U%7T-O;G1E;G1S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<F5N9&5R960@=&5X="!I;B!(5$U,+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H)'!A<F%M<RD*("`@('L*("`@("`@("`D8V]N=&5N=',@
M/2`F)'!A<F%M<ULP73L*"B`@("`@("`@9VQO8F%L("1C;VYF+"`D<')E9G,[
M"@H@("`@("`@("1F;&]W960@/2`H)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N
M=&5N=%1Y<&5087)A;65T97(H)V9O<FUA="<I(#T]("=F;&]W960G*3L*("`@
M("`@("`D=&5X="`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"D[
M"@H@("`@("`@("\O($EF(&-A;&QI;F<@87,@86X@871T86-H;65N="!F<F]M
M('9I97<N<&AP+"!W92!D;R!N;W0@=V%N="!T;R!A;'1E<@H@("`@("`@("\O
M('1H92!T97AT(&EN(&%N>2!W87D@=VET:"!(5$U,+@H@("`@("`@(&EF("@D
M8V]N=&5N=',M/G9I97=!<T%T=&%C:&UE;G0H*2D@>PH@("`@("`@("`@("`O
M+R!#:&5C:R!F;W(@)V9L;W=E9"<@=&5X="!D871A+@H@("`@("`@("`@("!I
M9B`H)&9L;W=E9"D@>PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D=&AI<RT^
M7V9O<FUA=$9L;W=E9"@D=&5X="P@.3`L(&YU;&PL("1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=D96QS<"<I*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1E>'0["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1E>'0@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E
M='5R;B`D8V]N=&5N=',M/F9O<FUA=%-T871U<TUS9RA?*")4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(I*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%1R:6T@97AT<F$@=VAI=&5S<&%C92!I;B!T
M:&4@=&5X="X*("`@("`@("`D=&5X="`](')T<FEM*"1T97AT*3L*("`@("`@
M("!I9B`H)'1E>'0@/3T@)R<I('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@
M("`@("`@('T*"B`@("`@("`@+R\@268@<F5Q=65S=&5D+"!S8V%N('1H92!M
M97-S86=E(&9O<B!01U`@9&%T82X*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF
M6R=U=&EL<R==6R=G;G5P9R==*2`F)@H@("`@("`@("`@("`D<')E9G,M/F=E
M=%9A;'5E*"=P9W!?<V-A;E]B;V1Y)RD@)B8*("`@("`@("`@("`@<')E9U]M
M871C:"@G+RTM+2TM0D5'24X@4$=0("A;7BU=*RDM+2TM+2\G+"`D=&5X="DI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O
M0W)Y<'0O4$=0+G!H<"<["B`@("`@("`@("`@("1I;7!?<&=P(#T@)FYE=R!)
M35!?4$=0*"D["B`@("`@("`@("`@(&EF("@H)&]U="`]("1I;7!?<&=P+3YP
M87)S94UE<W-A9V5/=71P=70H)'1H:7,M/FUI;65?<&%R="P@)&-O;G1E;G1S
M*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;W5T.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O+R!)9B!R97%U97-T960L('-C86X@
M=&AE(&UE<W-A9V4@9F]R(%5596YC;V1E9"!D871A+@H@("`@("`@(&EF("@D
M=&AI<RT^9V5T0V]N9FEG4&%R86TH)W5U96YC;V1E)RDI('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=-86EL+VUI;65$96-O9&4N<&AP)SL*("`@("`@
M("`@("`@)&9I;&5S(#T@)DUA:6Q?;6EM941E8V]D93HZ=75D96-O9&4H)'1E
M>'0I.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R("=F;&]W960G
M('1E>'0@9&%T82X*("`@("`@("!I9B`H)&9L;W=E9"D@>PH@("`@("`@("`@
M("`D=&5X="`]("1T:&ES+3Y?9F]R;6%T1FQO=V5D*"1T97AT+"`Y,"P@*$E-
M4#HZ<')I;G1-;V1E*"DI(#\@,"`Z(&YU;&PL("1T:&ES+3YM:6UE7W!A<G0M
M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=D96QS<"<I*3L*("`@("`@("!]
M"@H@("`@("`@("\O($)U:6QD(&9I;'1E<B!S=&%C:RX@4W1A<G1S('=I=&@@
M2%1-3"!M87)K=7`@86YD('1A8B!E>'!A;G-I;VXN"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH@("`@("`@("1F:6QT
M97)S(#T@87)R87DH)W1E>'0R:'1M;"<L("=T86)S,G-P86-E<R<I.PH@("`@
M("`@("1F:6QT97)?<&%R86US(#T@87)R87DH87)R87DH)W!A<G-E;&5V96PG
M(#T^(%1%6%1?2%1-3%]-24-23RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C:&%R<V5T)R`]/B`D=&AI<RT^;6EM95]P87)T+3YG
M971#:&%R<V5T*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH*2D["@H@("`@("`@("\J($$@(D9R;VTB(&QO8V%T960@870@=&AE
M(&)E9VEN;FEN9R!O9B!A(&QI;F4@:6X@=&AE(&)O9'D@=&5X="!W:6QL"B`@
M("`@("`@("H@8F4@97-C87!E9"!W:71H(&$@)SXG(&)Y('1H92!)34%0('-E
M<G9E<BX@(%)E;6]V92!T:&ES(&5S8V%P90H@("`@("`@("`J(&-H87)A8W1E
M<B!O<B!E;'-E('1H92!L:6YE('=I;&P@9&ES<&QA>2!A<R!B96EN9R!Q=6]T
M960N("HO"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H7&XK*3X@
M/T9R;VTH7',K*2\G+"`B)#%&<F]M)#(B+"`D=&5X="D["@H@("`@("`@("\O
M($AI9VAL:6=H="!Q=6]T960@<&%R=',@;V8@86X@96UA:6PN"B`@("`@("`@
M:68@*"1P<F5F<RT^9V5T5F%L=64H)VAI9VAL:6=H=%]T97AT)RDI('L*("`@
M("`@("`@("`@)&9I;'1E<G-;72`]("=H:6=H;&EG:'1Q=6]T97,G.PH@("`@
M("`@("`@("`D:&ED94)L;V-K<R`]("@D<')E9G,M/F=E=%9A;'5E*"=S:&]W
M7W%U;W1E8FQO8VMS)RD@/3T@)VAI9&1E;B<I('Q\"B`@("`@("`@("`@("`@
M("`H)'!R969S+3YG971686QU92@G<VAO=U]Q=6]T96)L;V-K<R<I(#T]("=T
M:')E860G("8F"B`@("`@("`@("`@("`@("`@8F%S96YA;64H2&]R9&4Z.G-E
M;&95<FPH*2D@/3T@)W1H<F5A9"YP:'`G*3L*("`@("`@("`@("`@+R\@3VYL
M>2!S:&]W('%U;W1E9"!T97AT(&EN("=C:71E(&)L;V-K)R!S='EL92!I9B!W
M92!A<F4@9&5A;&EN9PH@("`@("`@("`@("`O+R!W:71H(&$@9FQO=V5D('1E
M>'0@;65S<V%G92X*("`@("`@("`@("`@)&9I;'1E<E]P87)A;7-;72`](&%R
M<F%Y*"=H:61E0FQO8VMS)R`]/B`D:&ED94)L;V-K<RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C:71E8FQO8VLG(#T^("1F;&]W
M960I.PH@("`@("`@('T*"B`@("`@("`@+R\@2&EG:&QI9VAT('-I;7!L92!M
M87)K=7`@;V8@86X@96UA:6PN"B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L
M=64H)VAI9VAL:6=H=%]S:6UP;&5?;6%R:W5P)RDI('L*("`@("`@("`@("`@
M)&9I;'1E<G-;72`]("=S:6UP;&5M87)K=7`G.PH@("`@("`@("`@("`D9FEL
M=&5R7W!A<F%M<UM=(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\O
M($1I;2!S:6=N871U<F5S+@H@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E
M*"=D:6U?<VEG;F%T=7)E)RDI('L*("`@("`@("`@("`@)&9I;'1E<G-;72`]
M("=D:6US:6=N871U<F4G.PH@("`@("`@("`@("`D9FEL=&5R7W!A<F%M<UM=
M(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\O($9I;'1E<B!B860@
M;&%N9W5A9V4N"B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)V9I;'1E
M<FEN9R<I*2!["B`@("`@("`@("`@("1F:6QT97)S6UT@/2`G=V]R9',G.PH@
M("`@("`@("`@("`D9FEL=&5R7W!A<F%M<UM=(#T@87)R87DH)W=O<F1S7V9I
M;&4G(#T^("1C;VYF6R=M<V=S971T:6YG<R==6R=F:6QT97)I;F<G75LG=V]R
M9',G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M97!L86-E;65N="<@/3X@)&-O;F9;)VUS9W-E='1I;F=S)UU;)V9I;'1E<FEN
M9R==6R=R97!L86-E;65N="==*3L*("`@("`@("!]"@H@("`@("`@("\O(%)U
M;B!F:6QT97)S+@H@("`@("`@("1T97AT(#T@5&5X=%]&:6QT97(Z.F9I;'1E
M<B@D=&5X="P@)&9I;'1E<G,L("1F:6QT97)?<&%R86US*3L*"B`@("`@("`@
M+R\@5V]R9'=R87`N"B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G("`G
M+"`G("9N8G-P.R<L("1T97AT*3L*("`@("`@("`D=&5X="`]('-T<E]R97!L
M86-E*")<;B`B+"`B7&XF;F)S<#LB+"`D=&5X="D["B`@("`@("`@:68@*"1T
M97AT>S!](#T]("<@)RD@>PH@("`@("`@("`@("`D=&5X="`]("<F;F)S<#LG
M("X@<W5B<W1R*"1T97AT+"`Q*3L*("`@("`@("!]"B`@("`@("`@)'1E>'0@
M/2`G/&1I=B!C;&%S<STB9FEX960@;&5F=$%L:6=N(CXG("X@(EQN(B`N("1T
M97AT("X@)SPO9&EV/B<["@H@("`@("`@("\O(%)E<&QA8V4@555E;F-O9&5D
M(&1A=&$@=VET:"!L:6YK<R!N;W<N"B`@("`@("`@:68@*"1T:&ES+3YG971#
M;VYF:6=087)A;2@G=75E;F-O9&4G*2`F)B`A96UP='DH)&9I;&5S*2D@>PH@
M("`@("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@("`@
M("`@("`@("`@("1U=7!A<G0@/2`F;F5W($U)345?4&%R="@I.PH@("`@("`@
M("`@("`@("`@)'5U<&%R="T^<V5T0V]N=&5N=',H)&9I;&5;)V9I;&5D871A
M)UTI.PH@("`@("`@("`@("`@("`@)'5U<&%R="T^<V5T3F%M92AS=')I<%]T
M86=S*"1F:6QE6R=F:6QE;F%M92==*2D["@H@("`@("`@("`@("`@("`@)'5U
M;65S<V%G92`]("9-24U%7TUE<W-A9V4Z.F-O;G9E<G1-24U%4&%R="@D=75P
M87)T*3L*("`@("`@("`@("`@("`@("1M8R`]("9N97<@34E-15]#;VYT96YT
M<R@D=75M97-S86=E+"!A<G)A>2@G9&]W;FQO860G(#T^("=D;W=N;&]A9%]A
M='1A8V@G+"`G=FEE=R<@/3X@)W9I97=?871T86-H)RDL(&%R<F%Y*"8D8V]N
M=&5N=',I*3L*("`@("`@("`@("`@("`@("1M8RT^8G5I;&1-97-S86=E*"D[
M"@H@("`@("`@("`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H(B]B96=I
M;B`H6S`M-UU[,WTI("@N*RE<<C]<;B@N*RE<<C]<;F5N9"]5<R(L("<\=&%B
M;&4^)R`N("1M8RT^9V5T365S<V%G92AT<G5E*2`N("<\+W1A8FQE/B<L("1T
M97AT+"`Q*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T97AT.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-24U%+U9I97=E
M<B]I;6%G97,N<&AP````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#<W
M-0`Q,#0Q-S,V,C<V-@`P,C$W-#$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O
M34E-12]6:65W97(O:6UA9V5S+G!H<"<["@HO*BH*("H@5&AE($E-4%]-24U%
M7U9I97=E<E]I;6%G97,@8VQA<W,@86QL;W=S(&EM86=E<R!T;R!B92!D:7-P
M;&%Y960*("H@:6YL:6YE(&EN(&$@;65S<V%G92X*("H*("H@)$AO<F1E.B!I
M;7`O;&EB+TU)344O5FEE=V5R+VEM86=E<RYP:'`L=B`Q+C0S+C$P+C$Y(#(P
M,#8O,#$O,#(@,#8Z,#4Z,#0@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M($!S:6YC92`@($E-4"`S+C(*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W
M97(*("HO"F-L87-S($E-4%]-24U%7U9I97=E<E]I;6%G97,@97AT96YD<R!-
M24U%7U9I97=E<E]I;6%G97,@>PH*("`@("\J*@H@("`@("H@5&AE(&-O;G1E
M;G0M='EP92!O9B!T:&4@9V5N97)A=&5D(&1A=&$N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8V]N=&5N=%1Y<&4["@H@
M("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@<V5T(&-O
M;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M;B!A<G)A>2!W:71H(&$@<F5F97)E;F-E('1O(&$@34E-15]#;VYT96YT<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&EN9F]R;6%T:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<RD*("`@('L*
M("`@("`@("`D8V]N=&5N=',@/2`D<&%R86US6S!=.PH*("`@("`@("!G;&]B
M86P@)&)R;W=S97(["@H@("`@("`@("\J($EF(&-A;&QI;F<@<&%G92!I<R!A
M<VMI;F<@=7,@=&\@;W5T<'5T(&1A=&$L(&1O('1H870@=VET:&]U="!A;GD*
M("`@("`@("`@*B!F=7)T:&5R(&1E;&%Y(&%N9"!E>&ET+B`J+PH@("`@("`@
M(&EF("A5=&EL.CIG971&;W)M1&%T82@G:6UG7V1A=&$G*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V-O;G1E;G14>7!E(#T@<&%R96YT.CIG9714>7!E*"D[
M"B`@("`@("`@("`@(')E='5R;B!P87)E;G0Z.G)E;F1E<B@I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0V]N=F5R="!T:&4@:6UA9V4@=&\@8G)O=W-E<BUV
M:65W86)L92!F;W)M870@86YD(&1I<W!L87DN("HO"B`@("`@("`@:68@*%5T
M:6PZ.F=E=$9O<FU$871A*"=I;6%G97-?=FEE=U]C;VYV97)T)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=FEE=T-O;G9E<G0H*3L*("`@("`@
M("!]"@H@("`@("`@("\J($-R96%T92!T:&4@=&AU;6)N86EL(&%N9"!D:7-P
M;&%Y+B`J+PH@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G:6UA9V5S
M7W9I97=?=&AU;6)N86EL)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=FEE=T-O;G9E<G0H=')U92D["B`@("`@("`@?0H*("`@("`@("`O*B!4
M:&ES('!A9V4@:&%S(&)E96X@8V%L;&5D('=I=&@@=&AE('1H=6UB;F%I;"!P
M87)A;65T97(N(%-E92!I9B!W90H@("`@("`@("`J(&-A;B!C;VYV97)T('1O
M(&%N(&EN;&EN92!B<F]W<V5R('9I97=A8FQE(&9O<FTN("HO"B`@("`@("`@
M:68@*%5T:6PZ.F=E=$9O<FU$871A*"=V:65W7W1H=6UB;F%I;"<I*2!["B`@
M("`@("`@("`@("1I;6<@/2`D=&AI<RT^7V=E=$AO<F1E26UA9V5/8B@I.PH@
M("`@("`@("`@("!I9B`H)&EM9RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&]P=7!);6%G95=I;F1O=R@I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C;VYT96YT<RT^9F]R;6%T
M4W1A='5S37-G*%\H(E1H92!S97)V97(@=V%S(&YO="!A8FQE('1O(&-R96%T
M92!A('1H=6UB;F%I;"!O9B!T:&ES(&EM86=E+B(I*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=I
M;6%G97-?;&]A9%]C;VYV97)T)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&]P=7!);6%G95=I;F1O=R@I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1C;VYT96YT<RT^=FEE=T%S071T86-H;65N="@I*2!["B`@("`@("`@
M("`@(&EF("@A)&)R;W=S97(M/FAA<T9E871U<F4H)VIA=F%S8W)I<'0G*2!\
M?`H@("`@("`@("`@("`@("`@(21C;VYT96YT<RT^=FEE=T%S071T86-H;65N
M="AT<G5E*2D@>PH@("`@("`@("`@("`@("`@+RH@268@96ET:&5R.@H@("`@
M("`@("`@("`@("`@("`@*R!4:&4@8G)O=W-E<B!D;V5S;B=T('-U<'!O<G0@
M:F%V87-C<FEP=`H@("`@("`@("`@("`@("`@("`@*R!792!A<F4@;F]T('9I
M97=I;F<@:6X@82!P;W!U<"!W:6YD;W<*("`@("`@("`@("`@("`@("`@(%1H
M96X@<VEM<&QY(')E;F1E<B!T:&4@:6UA9V4@9&%T82X@*B\*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V]N=&5N=%1Y<&4@/2!P87)E;G0Z.F=E=%1Y<&4H
M*3L*("`@("`@("`@("`@("`@(')E='5R;B!P87)E;G0Z.G)E;F1E<B@I.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)&)R;W=S97(M/FES5FEE=V%B;&4H<&%R
M96YT.CIG9714>7!E*"DI*2!["B`@("`@("`@("`@("`@("`O*B!4:&4@8G)O
M=W-E<B!C86X@9&ES<&QA>2!T:&4@:6UA9V4@='EP92!D:7)E8W1L>2`M(&IU
M<W0*("`@("`@("`@("`@("`@("`@(&]U='!U="!T:&4@:F%V87-C<FEP="!C
M;V1E('1O(')E;F1E<B!T:&4@875T;R!R97-I>F4@<&]P=7`*("`@("`@("`@
M("`@("`@("`@(&EM86=E('=I;F1O=RX@*B\*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!O<'5P26UA9V57:6YD;W<H*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*"1B<F]W<V5R+3YI<U9I97=A8FQE
M*"1T:&ES+3YM:6UE7W!A<G0M/F=E=%1Y<&4H*2DI('L*("`@("`@("`@("`@
M+RH@268@=V4@87)E('9I97=I;F<@:6YL:6YE+"!A;F0@=&AE(&)R;W=S97(@
M8V%N(&AA;F1L92!T:&4@:6UA9V4*("`@("`@("`@("`@("`@='EP92!D:7)E
M8W1L>2P@;W5T<'5T(&%N(#QI;6<^('1A9R!T;R!L;V%D('1H92!I;6%G92X@
M*B\*("`@("`@("`@("`@)&%L="`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$YA
M;64H9F%L<V4L('1R=64I.PH@("`@("`@("`@("!R971U<FX@2&]R9&4Z.FEM
M9R@D8V]N=&5N=',M/G5R;%9I97<H)'1H:7,M/FUI;65?<&%R="P@)W9I97=?
M871T86-H)RDL("1A;'0L(&YU;&PL("<G*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O*B!)9B!W92!H879E(&UA9&4@:70@=&AI<R!F87(L('1H
M86X@=&AE(&)R;W=S97(@8V%N;F]T('9I97<@=&AI<PH@("`@("`@("`@("`@
M("!I;6%G92!I;FQI;F4N("!);F9O<FT@=&AE('5S97(@;V8@=&AI<R!A;F0L
M('!O<W-I8FQY+"!A<VL@=7-E<@H@("`@("`@("`@("`@("!I9B!W92!S:&]U
M;&0@8V]N=F5R="!T;R!A;F]T:&5R(&EM86=E('1Y<&4N("HO"B`@("`@("`@
M("`@("1M<V<@/2!?*")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I
M;FQI;F4@9&ES<&QA>2!O9B!T:&ES(&EM86=E('1Y<&4N(BD["@H@("`@("`@
M("`@("!I9B`H)&-O;G1E;G1S+3YV:65W07-!='1A8VAM96YT*"DI('L*("`@
M("`@("`@("`@("`@("1M<V<@+CT@)SQB<B`O/B<@+B!S<')I;G1F*%\H(D-L
M:6-K("5S('1O(&1O=VYL;V%D('1H92!I;6%G92XB*2P@)&-O;G1E;G1S+3YL
M:6YK5FEE=R@D=&AI<RT^;6EM95]P87)T+"`G9&]W;FQO861?871T86-H)RP@
M7R@B2$5212(I+"!A<G)A>2@G=FEE=W!A<F%M<R<@/3X@87)R87DH)VEM9U]D
M871A)R`]/B`Q*2DL('1R=64I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@4V5E(&EF('=E(&-A;B!C;VYV97)T('1O(&%N(&EN;&EN92!B<F]W
M<V5R('9I97=A8FQE(&9O<FTN("HO"B`@("`@("`@("`@("1I;6<@/2`D=&AI
M<RT^7V=E=$AO<F1E26UA9V5/8B@I.PH@("`@("`@("`@("!I9B`H)&EM9R`F
M)B`D8G)O=W-E<BT^:7-6:65W86)L92@D:6UG+3YG971#;VYT96YT5'EP92@I
M*2D@>PH@("`@("`@("`@("`@("`@:68@*"1C;VYT96YT<RT^=FEE=T%S071T
M86-H;65N="@I*2!["B`@("`@("`@("`@("`@("`@("`@)&-O;G9E<G1?;&EN
M:R`]($AO<F1E.CIL:6YK*"1C;VYT96YT<RT^=7)L5FEE=R@D=&AI<RT^;6EM
M95]P87)T+"`G=FEE=U]A='1A8V@G+"!A<G)A>2@G:6UA9V5S7VQO861?8V]N
M=F5R="<@/3X@,2P@)W!O<'5P7W9I97<G(#T^(#$I*2D@+B!?*")(15)%(BD@
M+B`G/"]A/B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1C;VYV97)T7VQI;FL@/2`D8V]N=&5N=',M/FQI;FM6:65W
M2E,H)'1H:7,M/FUI;65?<&%R="P@)W9I97=?871T86-H)RP@7R@B2$5212(I
M+"!N=6QL+"!N=6QL+"!A<G)A>2@G:6UA9V5S7VQO861?8V]N=F5R="<@/3X@
M,2DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&US9R`N
M/2`G/&)R("\^)R`N('-P<FEN=&8H7R@B0VQI8VL@)7,@=&\@8V]N=F5R="!T
M:&4@:6UA9V4@9FEL92!I;G1O(&$@9F]R;6%T('EO=7(@8G)O=W-E<B!C86X@
M=FEE=RXB*2P@)&-O;G9E<G1?;&EN:RD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(')E='5R;B`D8V]N=&5N=',M/F9O<FUA=%-T871U<TUS9R@D;7-G
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&-O;G1E;G0M='EP90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@8V]N=&5N="UT>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O
M;G1E;G14>7!E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;G1E
M;G14>7!E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G
M=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T(&%T=&%C
M:&UE;G0@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N(&%R<F%Y('=I=&@@82!R969E<F5N8V4@=&\@82!-24U%
M7T-O;G1E;G1S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@
M=&5X="!I;B!(5$U,+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)!='1A
M8VAM96YT26YF;R@D<&%R86US*0H@("`@>PH@("`@("`@("1C;VYT96YT<R`]
M("8D<&%R86US6S!=.PH*("`@("`@("`O*B!$:7-P;&%Y('1H92!T:'5M8FYA
M:6P@;&EN:R!O;FQY(&EF('-I>F4@:7,@9W)E871E<B!T:&%N(#4P($M"(&%N
M9`H@("`@("`@("`@('1H97)E(&ES(&%N(&EM86=E(&-O;G9E<G-I;VX@=71I
M;&ET>2!A=F%I;&%B;&4N("HO"B`@("`@("`@:68@*"1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$)Y=&5S*"D@/"`U,3(P,"D@>PH@("`@("`@("`@("!R971U<FX@
M)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D8V]N=&5N=',L("=)
M35!?0V]N=&5N=',G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;6EM95]P87)T
M(#T@)B1C;VYT96YT<RT^9V5T1&5C;V1E9$U)345087)T*"1T:&ES+3YM:6UE
M7W!A<G0M/F=E=$U)345)9"@I+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A)'1H:7,M/E]G971(;W)D94EM86=E3V(H*2D@>PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D<W1A='5S(#T@87)R
M87DH"B`@("`@("`@("`@('-P<FEN=&8H7R@B02!L87)G92!I;6%G92!N86UE
M9"`E<R!I<R!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N(BDL("1T:&ES+3YM
M:6UE7W!A<G0M/F=E=$YA;64H=')U92DI+`H@("`@("`@("`@("!S<')I;G1F
M*%\H(D-L:6-K("5S('1O('9I97<@82!T:'5M8FYA:6P@;V8@=&AI<R!I;6%G
M92XB*2P@)&-O;G1E;G1S+3YL:6YK5FEE=TI3*"1T:&ES+3YM:6UE7W!A<G0L
M("=V:65W7V%T=&%C:"<L(%\H(DA%4D4B*2P@7R@B5FEE=R!4:'5M8FYA:6PB
M*2P@;G5L;"P@87)R87DH)W9I97=?=&AU;6)N86EL)R`]/B`Q*2DI"B`@("`@
M("`@*3L*("`@("`@("!R971U<FX@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--
M<V<H)'-T871U<RP@2&]R9&4Z.FEM9R@G;6EM92]I;6%G92YP;F<G+"!?*")6
M:65W(%1H=6UB;F%I;"(I+"!N=6QL+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E('1H92!(5$U,(&]U='!U="!F;W(@=&AE($I3(&%U=&\M<F5S
M:7IE('9I97<@=VEN9&]W+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P
M=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P;W!U<$EM86=E5VEN9&]W*"D*
M("`@('L*("`@("`@("`D<&%R86US(#T@)')E;6]V95]P87)A;7,@/2!A<G)A
M>2@I.PH@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G=FEE=U]T:'5M
M8FYA:6PG*2D@>PH@("`@("`@("`@("`D<&%R86US6R=I;6%G97-?=FEE=U]T
M:'5M8FYA:6PG72`](#$["B`@("`@("`@("`@("1R96UO=F5?<&%R86US6UT@
M/2`G=FEE=U]T:'5M8FYA:6PG.PH@("`@("`@('T@96QS96EF("A5=&EL.CIG
M971&;W)M1&%T82@G:6UA9V5S7VQO861?8V]N=F5R="<I*2!["B`@("`@("`@
M("`@("1P87)A;7-;)VEM86=E<U]V:65W7V-O;G9E<G0G72`](#$["B`@("`@
M("`@("`@("1R96UO=F5?<&%R86US6UT@/2`G:6UA9V5S7VQO861?8V]N=F5R
M="<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A<F%M<ULG:6UG
M7V1A=&$G72`](#$["B`@("`@("`@?0H@("`@("`@("1S96QF7W5R;"`](%5T
M:6PZ.F%D9%!A<F%M971E<BA5=&EL.CIR96UO=F5087)A;65T97(H2&]R9&4Z
M.G-E;&95<FPH=')U92DL("1R96UO=F5?<&%R86US*2P@)'!A<F%M<RD["B`@
M("`@("`@)'1I=&QE(#T@34E-13HZ9&5C;V1E*"1T:&ES+3YM:6UE7W!A<G0M
M/F=E=$YA;64H9F%L<V4L('1R=64I*3L*("`@("`@("!R971U<FX@<&%R96YT
M.CI?<&]P=7!);6%G95=I;F1O=R@D<V5L9E]U<FPL("1T:71L92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!6:65W('1H=6UB;F%I;"!S:7IE9"!I;6%G92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D=&AU;6(@(%9I97<@=&AU;6)N86EL('-I>F4_"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!I;6%G92!D871A+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?=FEE=T-O;G9E<G0H)'1H=6UB(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)&UI;64@/2`D=&AI<RT^;6EM95]P87)T.PH@
M("`@("`@("1I;6<@/2`D=&AI<RT^7V=E=$AO<F1E26UA9V5/8B@I.PH*("`@
M("`@("!I9B`H)'1H=6UB*2!["B`@("`@("`@("`@("1I;6<M/G)E<VEZ92@Y
M-BP@.38L('1R=64I.PH@("`@("`@('T*("`@("`@("`D;6EM92T^<V5T5'EP
M92@D:6UG+3YG971#;VYT96YT5'EP92@I*3L*("`@("`@("`D;6EM92T^<V5T
M0V]N=&5N=',H)&EM9RT^<F%W*'1R=64I*3L*"B`@("`@("`@)'1H:7,M/E]C
M;VYT96YT5'EP92`]("1I;6<M/F=E=$-O;G1E;G14>7!E*"D["@H@("`@("`@
M(')E='5R;B`D;6EM92T^9V5T0V]N=&5N=',H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!A($AO<F1E7TEM86=E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N($AO
M<F1E7TEM86=E("!4:&4@<F5Q=65S=&5D(&]B:F5C="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V=E=$AO<F1E26UA9V5/8B@I"B`@("!["B`@("`@("`@:6YC
M;'5D95]O;F-E("=(;W)D92]);6%G92YP:'`G.PH@("`@("`@("1P87)A;7,@
M/2!A<G)A>2@G=&5M<"<@/3X@2&]R9&4Z.F=E=%1E;7!D:7(H*2D["B`@("`@
M("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=I;6%G92==6R=C;VYV
M97)T)UTI*2!["B`@("`@("`@("`@("1I;6<@/2`F2&]R9&5?26UA9V4Z.G-I
M;F=L971O;B@G:6TG+"`D<&%R86US*3L*("`@("`@("!](&5L<V5I9B`H571I
M;#HZ97AT96YS:6]N17AI<W1S*"=G9"<I*2!["B`@("`@("`@("`@("1I;6<@
M/2`F2&]R9&5?26UA9V4Z.G-I;F=L971O;B@G9V0G+"`D<&%R86US*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-?82@D:6UG+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("1R970@/2`D:6UG+3YL;V%D4W1R:6YG*#$L("1T:&ES+3YM:6UE7W!A<G0M
M/F=E=$-O;G1E;G1S*"DI.PH@("`@("`@(&EF("AI<U]A*"1R970L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;6<["B`@("!]"@I]"@```"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-24U%+U9I97=E<B]H=&UL+G!H
M<```````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C$S-P`Q,#0Q-S,V
M,C<V-@`P,C$T,S4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O34E-12]6:65W
M97(O:'1M;"YP:'`G.PH*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]H=&UL(&-L
M87-S(')E;F1E<G,@;W5T($A434P@=&5X="!W:71H(&%N(&5F9F]R="!T;PH@
M*B!R96UO=F4@<&]T96YT:6%L;'D@;6%L:6-I;W5S(&-O9&4N"B`J"B`J("1(
M;W)D93H@:6UP+VQI8B]-24U%+U9I97=E<B]H=&UL+G!H<"QV(#$N-S4N,BXQ
M,2`R,#`V+S`Q+S$Q(#`V.C,T.C`V('-L=7-A<GH@17AP("0*("H*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O
M:6PN;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO
M;D!R96-O:6PN;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@24U0(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E
M<@H@*B\*8VQA<W,@24U07TU)345?5FEE=V5R7VAT;6P@97AT96YD<R!-24U%
M7U9I97=E<E]H=&UL('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE
M(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@82!R969E<F5N8V4@=&\@
M82!-24U%7T-O;G1E;G1S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N
M9&5R960@=&5X="!I;B!(5$U,+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD
M97(H)'!A<F%M<RD*("`@('L*("`@("`@("`D8V]N=&5N=',@/2`F)'!A<F%M
M<ULP73L*"B`@("`@("`@)&%T=&%C:&UE;G0@/2`D8V]N=&5N=',M/G9I97=!
M<T%T=&%C:&UE;G0H*3L*"B`@("`@("`@+RH@4V%N:71I>F4@=&AE($A434PN
M("HO"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V-L96%N2%1-3"@D=&AI<RT^
M;6EM95]P87)T+3YG971#;VYT96YT<R@I*3L*"B`@("`@("`@+RH@4V5A<F-H
M(&9O<B!I;FQI;F5D(&EM86=E<R!T:&%T('=E(&-A;B!D:7-P;&%Y+B`J+PH@
M("`@("`@("1R96QA=&5D(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T26YF;W)M
M871I;VXH)W)E;&%T961?<&%R="<I.PH@("`@("`@(&EF("@D<F5L871E9"`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)')E;&%T961087)T(#T@)&-O;G1E
M;G1S+3YG971-24U%4&%R="@D<F5L871E9"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1R96QA=&5D4&%R="T^9V5T0TE$3&ES="@I(&%S("1R968@/3X@)&ED
M*2!["B`@("`@("`@("`@("`@("`D:60@/2!T<FEM*"1I9"P@)SP^)RD["B`@
M("`@("`@("`@("`@("`D8VED7W!A<G0@/2`D8V]N=&5N=',M/F=E=$1E8V]D
M961-24U%4&%R="@D<F5F*3L*("`@("`@("`@("`@("`@("1D871A(#T@<W1R
M7W)E<&QA8V4H(F-I9#HD:60B+"`D8V]N=&5N=',M/G5R;%9I97<H)&-I9%]P
M87)T+"`G=FEE=U]A='1A8V@G*2P@)&1A=&$I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!#;VYV97)T(&QI;FMS('1O(&]P96X@:6X@
M;F5W('=I;F1O=W,N($)U="!F:7)S="!W92!H:61E(&%L;`H@("`@("`@("`@
M(&QI;FMS('1H870@:&%V92!A;B`B(WAY>B(@86YC:&]R+B`J+PH@("`@("`@
M("1D871A(#T@<')E9U]R97!L86-E*"=\/&$@*%M>/ETJ:')E9CU;(EPG73\C
M*7QI)RP@(CQ<>#`Q7%PQ(BP@)&1A=&$I.PH@("`@("`@("1D871A(#T@<W1R
M7W)E<&QA8V4H)SQA("<L("<\82!T87)G970](E]B;&%N:R(@)RP@)&1A=&$I
M.PH@("`@("`@("1D871A(#T@<W1R7W)E<&QA8V4H)SQ!("<L("<\82!T87)G
M970](E]B;&%N:R(@)RP@)&1A=&$I.PH@("`@("`@("1D871A(#T@<')E9U]R
M97!L86-E*")\7'@P,7PB+"`G82`G+"`D9&%T82D["@H@("`@("`@("\J($9I
M;'1E<B!B860@;&%N9W5A9V4N("HO"B`@("`@("`@)&1A=&$@/2!)35`Z.F9I
M;'1E<E1E>'0H)&1A=&$I.PH*("`@("`@("!I9B`H)&%T=&%C:&UE;G0I('L*
M("`@("`@("`@("`@)&-H87)S970@/2`D=&AI<RT^;6EM95]P87)T+3YG971#
M:&%R<V5T*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-H87)S
M970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@("`@("`@("`@+RH@4'5T(&1I
M=B!A<F]U;F0@;65S<V%G92X@*B\*("`@("`@("`@("`@)&1A=&$@/2`G/&1I
M=B!I9#TB:'1M;"UM97-S86=E(CXG("X@)&1A=&$@+B`G/"]D:78^)SL*("`@
M("`@("!]"@H@("`@("`@("\J($]N;'D@9&ES<&QA>2!I;6%G97,@:68@<W!E
M8VEF:6-A;&QY(&%L;&]W960@8GD@=7-E<BX@*B\*("`@("`@("!I9B`H(4E-
M4#HZ<')I;G1-;V1E*"D@)B8*("`@("`@("`@("`@)$=,3T)!3%-;)W!R969S
M)UTM/F=E=%9A;'5E*"=H=&UL7VEM86=E7W)E<&QA8V5M96YT)RDI('L*"B`@
M("`@("`@("`@("\J($-H96-K('1O('-E92!I9B!I;6%G97,@97AI<W0N("HO
M"B`@("`@("`@("`@("1I;6=?<F5G97@@/2`G+R@\:6UG6UX^72IS<F,]?#QI
M;G!U=%M>/ETJ<W)C/7P\8F]D>5M>/ETJ8F%C:V=R;W5N9#U\/'1D6UX^72IB
M86-K9W)O=6YD/7P\=&%B;&5;7CY=*F)A8VMG<F]U;F0]?'-T>6QE/5M>/ETJ
M8F%C:V=R;W5N9"UI;6%G93HN*G5R;%PH*2@B*3\H/R@R*5M>(CY=*B(H6SXI
M72E\6UY<<UTJ*%QS*RDI+VE5<R<["B`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"1I;6=?<F5G97@L("1D871A*2D@>PH@("`@("`@("`@("`@("`@+RH@
M36%K92!S=7)E('1H92!54DP@<&%R86UE=&5R<R!A<F4@8V]R<F5C="!F;W(@
M=&AE(&-U<G)E;G0*("`@("`@("`@("`@("`@("`@(&UE<W-A9V4N("HO"B`@
M("`@("`@("`@("`@("`D=7)L(#T@571I;#HZ<F5M;W9E4&%R86UE=&5R*$AO
M<F1E.CIS96QF57)L*'1R=64I+"!A<G)A>2@G:6YD97@G*2D["B`@("`@("`@
M("`@("`@("!I9B`H(21A='1A8VAM96YT*2!["B`@("`@("`@("`@("`@("`@
M("`@)'5R;"`](%5T:6PZ.G)E;6]V95!A<F%M971E<B@D=7)L+"!A<G)A>2@G
M86-T:6]N240G*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D8F%S95]O8B`]("8D8V]N=&5N=',M/F=E=$)A<V5/8FIE8W10='(H*3L*
M("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R
M;"P@)VEN9&5X)RP@)&)A<V5?;V(M/F=E=$UE<W-A9V5);F1E>"@I*3L*"B`@
M("`@("`@("`@("`@("`D=FEE=U]I;6<@/2!5=&EL.CIG971&;W)M1&%T82@G
M=FEE=U]H=&UL7VEM86=E<R<I.PH@("`@("`@("`@("`@("`@)&%D9')?8VAE
M8VL@/2`H)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=H=&UL7VEM86=E
M7V%D9')B;V]K)RD@)B8@)'1H:7,M/E]I;D%D9')E<W-";V]K*"1C;VYT96YT
M<RDI.PH*("`@("`@("`@("`@("`@(&EF("@A)'9I97=?:6UG("8F("$D861D
M<E]C:&5C:RD@>PH@("`@("`@("`@("`@("`@("`@("1B;&]C:U]I;6<@/2`G
M<W!A8V5R7W)E9"YP;F<G.PH@("`@("`@("`@("`@("`@("`@("1M<V<@/2!A
M<G)A>2A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*%\H(E1H:7,@2%1-3"!M97-S
M86=E(&AA<R!I;6%G97,@96UB961D960@:6X@:70N($)L;V-K960@:6UA9V5S
M(&%P<&5A<B!L:6ME('1H:7,Z("(I+"!.3%,Z.F=E=$-H87)S970H*2P@)&-H
M87)S970I("X@2&]R9&4Z.FEM9R@D8FQO8VM?:6UG+"!N=6QL+"`G:&5I9VAT
M/2(Q,"(@=VED=&@](C$P(B<I*3L*("`@("`@("`@("`@("`@("`@("`D;F5W
M4W)C(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA
M9V5$:7(H)VEM<"<I("X@)R\G("X@)&)L;V-K7VEM9RD["B`@("`@("`@("`@
M("`@("`@("`@)&1A=&$@/2!P<F5G7W)E<&QA8V4H)&EM9U]R96=E>"P@)UQ<
M,2(G("X@)&YE=U-R8R`N("<B7%PS)RP@)&1A=&$I.PH@("`@("`@("`@("`@
M("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W9I97=?
M:'1M;%]I;6%G97,G+"`Q*3L*("`@("`@("`@("`@("`@("`@("`D871T<FEB
M=71E<R`]("1A='1A8VAM96YT(#\@87)R87DH)W-T>6QE)R`]/B`G8V]L;W(Z
M8FQU92<I(#H@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`D;7-G6UT@
M/2!(;W)D93HZ;&EN:R@D=7)L+"!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*%\H
M(E-H;W<@=&AE($EM86=E<R(I+"!.3%,Z.F=E=$-H87)S970H*2P@)&-H87)S
M970I+"!N=6QL+"!N=6QL+"!N=6QL+"!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T
M*%\H(E-H;W<@=&AE($EM86=E<R(I+"!.3%,Z.F=E=$-H87)S970H*2P@)&-H
M87)S970I+"!N=6QL+"`D871T<FEB=71E<RD@+B!3=')I;F<Z.F-O;G9E<G1#
M:&%R<V5T*%\H(D-L:6-K(&AE<F4@=&\@4TA/5R!T:&4@26UA9V5S(BDL($Y,
M4SHZ9V5T0VAA<G-E="@I+"`D8VAA<G-E="D@+B`G/"]A/BXG.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1A9&1R7V-H96-K*2!["B`@("`@("`@("`@
M("`@("`@("`@)&US9R`](&%R<F%Y*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M7R@B5&AI<R!(5$U,(&UE<W-A9V4@:&%S(&EM86=E<R!E;6)E9&1E9"!I;B!I
M="XB*2P@3DQ3.CIG971#:&%R<V5T*"DL("1C:&%R<V5T*2P@4W1R:6YG.CIC
M;VYV97)T0VAA<G-E="A?*")4:&4@:6UA9V5S('=I;&P@8F4@9&ES<&QA>65D
M(&)E8V%U<V4@=&AE('-E;F1E<B!I<R!P<F5S96YT(&EN('EO=7(@861D<F5S
M<V)O;VLN(BDL($Y,4SHZ9V5T0VAA<G-E="@I+"`D8VAA<G-E="DI.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;7-G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1M<V<@/2`D8V]N=&5N=',M/F9O
M<FUA=%-T871U<TUS9R@D;7-G+"!(;W)D93HZ:6UG*"=M:6UE+VEM86=E+G!N
M9R<L(%\H(E9I97<@=&AE($EM86=E<R(I*2P@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D871T86-H;65N="D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;7-G(#T@)SQS<&%N('-T>6QE/2)B86-K9W)O=6YD+6-O;&]R
M.G=H:71E.V-O;&]R.F)L86-K(CXG("X@;FPR8G(H)&US9RD@+B`G/"]S<&%N
M/CQB<B`O/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')I<W1R*"1D871A+"`G/&)O9'DG*2`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2`D;7-G("X@)&1A
M=&$["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&1A=&$@/2!P<F5G7W)E<&QA8V4H)R\H+BH\8F]D>2XJ
M/SXI*"XJ*2]I<R<L("<D,2<@+B`D;7-G("X@)R0R)RP@)&1A=&$I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@87)E('9I97=I;F<@
M:6YL:6YE+"!G:79E(&]P=&EO;B!T;R!V:65W(&EN('-E<&%R871E('=I;F1O
M=RX@*B\*("`@("`@("!I9B`H(21A='1A8VAM96YT("8F("1T:&ES+3YG971#
M;VYF:6=087)A;2@G97AT97)N86PG*2D@>PH@("`@("`@("`@("`D;7-G(#T@
M<W!R:6YT9BA?*")#;&EC:R`E<R!T;R!V:65W($A434P@8V]N=&5N="!I;B!A
M('-E<&%R871E('=I;F1O=RXB*2P@)&-O;G1E;G1S+3YL:6YK5FEE=TI3*"1T
M:&ES+3YM:6UE7W!A<G0L("=V:65W7V%T=&%C:"<L(%\H(DA%4D4B*2P@7R@B
M5FEE=R!(5$U,(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B*2DI.PH@
M("`@("`@("`@("`D9&%T82`]("1C;VYT96YT<RT^9F]R;6%T4W1A='5S37-G
M*"1M<V<L($AO<F1E.CII;6<H)VUI;64O:'1M;"YP;F<G+"!?*")(5$U,(BDI
M+"!F86QS92D@+B`D9&%T83L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!W:&5T:&5R
M('1H92!S96YD97(@87!P96%R<R!I;B!A;B!A=F%I;&%B;&4@861D<F5S<V)O
M;VLN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M($U)345?0V]N=&5N=',@)B1C;VYT96YT<R`@5&AE($U)345?
M0V]N=&5N=',@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@1&]E<R!T:&4@<V5N9&5R(&%P<&5A<B!I;B!A;B!A9&1R97-S8F]O:S\*
M("`@("`J+PH@("`@9G5N8W1I;VX@7VEN061D<F5S<T)O;VLH)B1C;VYT96YT
M<RD*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D<')E9G,["@H@
M("`@("`@("\J($EF('=E(&1O;B=T(&AA=F4@86-C97-S('1O('1H92!S96YD
M97(@:6YF;W)M871I;VXL(')E='5R;B!F86QS92X@*B\*("`@("`@("`D8F%S
M95]O8B`]("8D8V]N=&5N=',M/F=E=$)A<V5/8FIE8W10='(H*3L*"B`@("`@
M("`@+RH@268@=V4@9&]N)W0@:&%V92!A(&-O;G1A8W1S('!R;W9I9&5R(&%V
M86EL86)L92P@9VEV92!U<"X@*B\*("`@("`@("!I9B`H(21R96=I<W1R>2T^
M:&%S365T:&]D*"=C;VYT86-T<R]G971&:65L9"<I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1S;W5R8V5S(#T@
M97AP;&]D92@B7'0B+"`D<')E9G,M/F=E=%9A;'5E*"=S96%R8VA?<V]U<F-E
M<R<I*3L*("`@("`@("!I9B`H*&-O=6YT*"1S;W5R8V5S*2`]/2`Q*2`F)B!E
M;7!T>2@D<V]U<F-E<ULP72DI('L*("`@("`@("`@("`@)'-O=7)C97,@/2!A
M<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@+RH@5')Y('1O(&=E="!B86-K
M(&$@<F5S=6QT(&9R;VT@=&AE('-E87)C:"X@*B\*("`@("`@("`D<F5S=6QT
M(#T@)')E9VES=')Y+3YC86QL*"=C;VYT86-T<R]G971&:65L9"<L(&%R<F%Y
M*"1B87-E7V]B+3YG971&<F]M061D<F5S<R@I+"`G7U]K97DG+"`D<V]U<F-E
M<RDI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`H8V]U;G0H)')E<W5L="D@/R!T<G5E(#H@
M9F%L<V4I.PH@("`@("`@('T*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+TU)344O5FEE=V5R+VYO=&EF
M:6-A=&EO;BYP:'``````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-S4P`#$P-#$W
M,S8R-S8V`#`R,S$U-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AE($E-4%]-24U%7U9I97=E<E]N
M;W1I9FEC871I;VX@8VQA<W,@:&%N9&QE<R!M=6QT:7!A<G0O<F5P;W)T(&UE
M<W-A9V5S"B`J('1H870@<F5F97(@=&\@;6%I;"!N;W1I9FEC871I;VX@;65S
M<V%G97,@*%)&0R`R,CDX*2X*("H*("H@)$AO<F1E.B!I;7`O;&EB+TU)344O
M5FEE=V5R+VYO=&EF:6-A=&EO;BYP:'`L=B`Q+C$T+C$P+C<@,C`P-B\P,2\P
M,2`R,3HR.#HU."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P
M-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!)
M35`@-"XP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S
M<R!)35!?34E-15]6:65W97)?;F]T:69I8V%T:6]N(&5X=&5N9',@34E-15]6
M:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N
M=&QY('-E="!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@06X@87)R87D@=VET:"!A(')E9F5R96YC92!T;R!A($U)345?
M0V]N=&5N=',*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!T
M97AT(&EN($A434PN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R
M86US*0H@("`@>PH@("`@("`@("1C;VYT96YT<R`]("8D<&%R86US6S!=.PH*
M("`@("`@("`O*B!)9B!T:&ES(&ES(&$@<W1R86EG:'0@;65S<V%G92]D:7-P
M;W-I=&EO;BUN;W1I9FEC871I;VX@<&%R="P@:G5S=`H@("`@("`@("`@(&]U
M='!U="!T:&4@=&5X="X@*B\*("`@("`@("!I9B`H)'1H:7,M/FUI;65?<&%R
M="T^9V5T5'EP92@I(#T]("=M97-S86=E+V1I<W!O<VET:6]N+6YO=&EF:6-A
M=&EO;B<I('L*("`@("`@("`@("`@)'!A<G0@/2`F;F5W($U)345?4&%R="@G
M=&5X="]P;&%I;B<I.PH@("`@("`@("`@("`D<&%R="T^<V5T0V]N=&5N=',H
M)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*2D["B`@("`@("`@("`@
M(')E='5R;B`G/'!R93XG("X@:'1M;&5N=&ET:65S*"1C;VYT96YT<RT^<F5N
M9&5R34E-15!A<G0H)'!A<G0I*2`N("<\+W!R93XG.PH@("`@("`@('T*"B`@
M("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@4D9#(#(R.3@@
M6S-=.B!4:&5R92!A<F4@=&AR964@<&%R=',@=&\@82!D96QI=F5R>2!S=&%T
M=7,*("`@("`@("`@("!M=6QT:7!A<G0O<F5P;W)T(&UE<W-A9V4Z"B`@("`@
M("`@("`@("`H,2D@2'5M86X@<F5A9&%B;&4@;65S<V%G90H@("`@("`@("`@
M("`@*#(I($UA8VAI;F4@<&%R<V%B;&4@8F]D>2!P87)T("AM97-S86=E+V1I
M<W!O<VET:6]N+6YO=&EF:6-A=&EO;BD*("`@("`@("`@("`@("@S*2!/<FEG
M:6YA;"!M97-S86=E("AO<'1I;VYA;"D@*B\*"B`@("`@("`@+RH@4')I;G0@
M=&AE(&AU;6%N(')E861A8FQE(&UE<W-A9V4N("HO"B`@("`@("`@)'!A<G0@
M/2`D8V]N=&5N=',M/F=E=$1E8V]D961-24U%4&%R="@D=&AI<RT^;6EM95]P
M87)T+3YG971296QA=&EV94U)345)9"@Q*2D["B`@("`@("`@)'-T871U<R`]
M(&%R<F%Y*`H@("`@("`@("`@("!?*")!(&UE<W-A9V4@>6]U(&AA=F4@<V5N
M="!H87,@<F5S=6QT960@:6X@82!R971U<FX@;F]T:69I8V%T:6]N(&9R;VT@
M=&AE(')E8VEP:65N="XB*2P*("`@("`@("`@("`@7R@B5&AE(&UA:6P@<V5R
M=F5R(&=E;F5R871E9"!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N86P@;65S
M<V%G93HB*0H@("`@("`@("D["B`@("`@("`@)'-T871U<VEM9R`]($AO<F1E
M.CII;6<H)V%L97)T<R]M97-S86=E+G!N9R<L(%\H(D%T=&5N=&EO;B(I+"`G
M:&5I9VAT/2(Q-B(@=VED=&@](C$V(B<L("1R96=I<W1R>2T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI.PH@("`@("`@("1T97AT(#T@)&-O;G1E;G1S+3YF;W)M
M8713=&%T=7--<V<H)'-T871U<RP@)'-T871U<VEM9RD@+@H@("`@("`@("`@
M("`G/&)L;V-K<75O=&4^)R`N("1C;VYT96YT<RT^<F5N9&5R34E-15!A<G0H
M)'!A<G0I("X@)SPO8FQO8VMQ=6]T93XG("X@(EQN(CL*"B`@("`@("`@+RH@
M1&ES<&QA>2!A(&QI;FL@=&\@;6]R92!D971A:6QE9"!M97-S86=E+B`J+PH@
M("`@("`@("1P87)T(#T@)&-O;G1E;G1S+3YG971$96-O9&5D34E-15!A<G0H
M)'1H:7,M/FUI;65?<&%R="T^9V5T4F5L871I=F5-24U%260H,BDI.PH*("`@
M("`@("`D<W1A='5S(#T@87)R87DH*3L*("`@("`@("`D<W1A='5S:6UG(#T@
M2&]R9&4Z.FEM9R@G:6YF;U]I8V]N+G!N9R<L(%\H(DEN9F\B*2P@)VAE:6=H
M=#TB,38B('=I9'1H/2(Q-B(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*3L*("`@("`@("`D<W1A='5S6UT@/2!S<')I;G1F*%\H(D%D9&ET
M:6]N86P@:6YF;W)M871I;VX@8V%N(&)E('9I97=E9"`E<RXB*2P@)&-O;G1E
M;G1S+3YL:6YK5FEE=TI3*"1P87)T+"`G=FEE=U]A='1A8V@G+"!?*")(15)%
M(BDL(%\H(D%D9&ET:6]N86P@:6YF;W)M871I;VX@9&5T86EL<R(I*2D["@H@
M("`@("`@("\J($1I<W!L87D@82!L:6YK('1O('1H92!S96YT(&UE<W-A9V4N
M(%1R>2!T;R!D;W=N;&]A9"!T:&4@=&5X="!O9@H@("`@("`@("`@('1H92!M
M97-S86=E+W)F8S@R,B!P87)T(&9I<G-T+"!I9B!I="!E>&ES=',N("HO"B`@
M("`@("`@:68@*"@D<&%R="`]("1C;VYT96YT<RT^9V5T1&5C;V1E9$U)3450
M87)T*"1T:&ES+3YM:6UE7W!A<G0M/F=E=%)E;&%T:79E34E-14ED*"<S+C`G
M*2DI('Q\"B`@("`@("`@("`@("@D<&%R="`]("1C;VYT96YT<RT^9V5T1&5C
M;V1E9$U)345087)T*"1T:&ES+3YM:6UE7W!A<G0M/F=E=%)E;&%T:79E34E-
M14ED*#,I*2DI('L*("`@("`@("`@("`@)'-T871U<UM=(#T@<W!R:6YT9BA?
M*")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S86=E(&-A;B!B92!V:65W960@
M)7,N(BDL("1C;VYT96YT<RT^;&EN:U9I97=*4R@D<&%R="P@)W9I97=?871T
M86-H)RP@7R@B2$5212(I+"!?*")4:&4@=&5X="!O9B!T:&4@<V5N="!M97-S
M86=E(BDI*3L*("`@("`@("!]"@H@("`@("`@("1T97AT("X]("1C;VYT96YT
M<RT^9F]R;6%T4W1A='5S37-G*"1S=&%T=7,L("1S=&%T=7-I;6<L(&9A;'-E
M*3L*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@8V]N=&5N="UT>7!E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="UT>7!E(&]F('1H92!M97-S86=E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@
M("!R971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R
M<V5T*"D["B`@("!]"@I]"@```````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-24U%+U9I97=E<B]Z:7`N
M<&AP````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S(U,P`Q,#0Q
M-S,V,C<V-@`P,C$R-S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<"<["@HO*BH*("H@5&AE($U)345?5FEE=V5R7WII<"!C
M;&%S<R!R96YD97)S(&]U="!T:&4@8V]N=&5N=',@;V8@6DE0(&9I;&5S(&EN
M($A434P*("H@9F]R;6%T(&%N9"!A;&QO=W,@9&]W;FQO861I;F<@;V8@97AT
M<F%C=&%B;&4@9FEL97,N"B`J"B`J("1(;W)D93H@:6UP+VQI8B]-24U%+U9I
M97=E<B]Z:7`N<&AP+'8@,2XR-2XQ,"XW(#(P,#8O,#(O,3`@,30Z,#`Z,3@@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*B!`<VEN8V4@("!)35`@-"XP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE
M=V5R"B`J+PIC;&%S<R!)35!?34E-15]6:65W97)?>FEP(&5X=&5N9',@34E-
M15]6:65W97)?>FEP('L*"B`@("`O*BH*("`@("`J(%1H92!)35!?0V]N=&5N
M=',@;V)J96-T+"!N965D960@9F]R('1H92!?8V%L;&)A8VLH*2!F=6YC=&EO
M;BX*("`@("`J"B`@("`@*B!`=F%R($E-4%]#;VYT96YT<PH@("`@("HO"B`@
M("!V87(@)%]C;VYT96YT<SL*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@
M=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@82!R969E<F5N8V4@
M=&\@82`@34E-15]#;VYT96YT<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@16ET
M:&5R('1H92!L:7-T(&]F('II<"!F:6QE<R!O<B!T:&4@9&%T82!O9B!A;@H@
M("`@("H@("`@("`@("`@("`@("`@(&EN9&EV:61U86P@>FEP(&9I;&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US*0H@("`@>PH@("`@
M("`@("1C;VYT96YT<R`]("8D<&%R86US6S!=.PH*("`@("`@("`D9&%T82`]
M("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"D["B`@("`@("`@)'1E
M>'0@/2`G)SL*"B`@("`@("`@+RH@4V5N9"!T:&4@<F5Q=65S=&5D(&9I;&4N
M($ET<R!P;W-I=&EO;B!I;B!T:&4@>FEP(&%R8VAI=F4@:7,*("`@("`@("`@
M("!L;V-A=&5D(&EN("=Z:7!?871T86-H;65N="<N("HO"B`@("`@("`@:68@
M*%5T:6PZ.F=E=$9O<FU$871A*"=Z:7!?871T86-H;65N="<I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0V]M<')E<W,N<&AP)SL*("`@
M("`@("`@("`@)'II<"`]("9(;W)D95]#;VUP<F5S<SHZ<VEN9VQE=&]N*"=Z
M:7`G*3L*("`@("`@("`@("`@)&9I;&5+97D@/2!5=&EL.CIG971&;W)M1&%T
M82@G>FEP7V%T=&%C:&UE;G0G*2`M(#$["B`@("`@("`@("`@("1Z:7!);F9O
M(#T@)'II<"T^9&5C;VUP<F5S<R@D9&%T82P@87)R87DH)V%C=&EO;B<@/3X@
M2$]21$5?0T]-4%)%4U-?6DE07TQ)4U0I*3L*("`@("`@("`@("`@+RH@5F5R
M:69Y('1H870@=&AE(')E<75E<W1E9"!F:6QE(&5X:7-T<RX@*B\*("`@("`@
M("`@("`@:68@*&ES<V5T*"1Z:7!);F9O6R1F:6QE2V5Y72DI('L*("`@("`@
M("`@("`@("`@("1T97AT(#T@)'II<"T^9&5C;VUP<F5S<R@D9&%T82P@87)R
M87DH)V%C=&EO;B<@/3X@2$]21$5?0T]-4%)%4U-?6DE07T1!5$$L("=I;F9O
M)R`]/B`F)'II<$EN9F\L("=K97DG(#T^("1F:6QE2V5Y*2D["B`@("`@("`@
M("`@("`@("!I9B`H96UP='DH)'1E>'0I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1E>'0@/2`G/'!R93XG("X@7R@B0V]U;&0@;F]T(&5X=')A8W0@=&AE
M(')E<75E<W1E9"!F:6QE(&9R;VT@=&AE(%II<"!A<F-H:79E+B(I("X@)SPO
M<')E/B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YM:6UE7W!A<G0M/G-E=%1Y<&4H)V%P<&QI8V%T:6]N
M+V]C=&5T+7-T<F5A;2<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM
M:6UE7W!A<G0M/G-E=$YA;64H8F%S96YA;64H)'II<$EN9F];)&9I;&5+97E=
M6R=N86UE)UTI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T97AT(#T@)SQP<F4^)R`N(%\H(E1H
M92!R97%U97-T960@9FEL92!D;V5S(&YO="!E>&ES="!I;B!T:&4@6FEP(&%T
M=&%C:&UE;G0N(BD@+B`G/"]P<F4^)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=',@/2`D8V]N
M=&5N=',["B`@("`@("`@("`@("1T97AT(#T@<&%R96YT.CI?<F5N9&5R*"1D
M871A+"!A<G)A>2@D=&AI<RP@)U]C86QL8F%C:R<I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1H
M92!F=6YC=&EO;B!T;R!U<V4@87,@82!C86QL8F%C:R!T;R!P87)E;G0Z.E]R
M96YD97(H*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:V5Y("!4:&4@<&]S:71I;VX@;V8@
M=&AE(&9I;&4@:6X@=&AE('II<"!A<F-H:79E+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1V86P@("`@5&AE(&EN9F]R;6%T:6]N(&%R<F%Y(&9O<B!T:&4@87)C
M:&EV960@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&-O;G1E;G0M='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?8V%L;&)A8VLH)&ME>2P@)'9A;"D*("`@('L*("`@("`@("`D;F%M
M92`]('-T<E]R97!L86-E*"<F;F)S<#LG+"`G)RP@)'9A;%LG;F%M92==*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1V86Q;)W-I>F4G72D@)B8@*'-T<G-T<B@D
M=F%L6R=A='1R)UTL("=$)RD@/3T](&9A;'-E*2`F)@H@("`@("`@("`@("`H
M*"@D=F%L6R=?;65T:&]D)UT@/3T@,'@X*2`F)B!5=&EL.CIE>'1E;G-I;VY%
M>&ES=',H)WIL:6(G*2D@?'P*("`@("`@("`@("`@*"1V86Q;)U]M971H;V0G
M72`]/2`P>#`I*2D@>PH@("`@("`@("`@("`D;VQD7VYA;64@/2`D=&AI<RT^
M;6EM95]P87)T+3YG971.86UE*"D["B`@("`@("`@("`@("1T:&ES+3YM:6UE
M7W!A<G0M/G-E=$YA;64H8F%S96YA;64H)&YA;64I*3L*("`@("`@("`@("`@
M)'9A;%LG;F%M92==(#T@<W1R7W)E<&QA8V4H)&YA;64L("1T:&ES+3Y?8V]N
M=&5N=',M/FQI;FM6:65W*"1T:&ES+3YM:6UE7W!A<G0L("=D;W=N;&]A9%]R
M96YD97(G+"`D;F%M92P@87)R87DH)VIS=&5X="<@/3X@<W!R:6YT9BA?*")6
M:65W("5S(BDL("1N86UE*2P@)V-L87-S)R`]/B`G9FEX960G+"`G=FEE=W!A
M<F%M<R<@/3X@87)R87DH)WII<%]A='1A8VAM96YT)R`]/B`H=7)L96YC;V1E
M*"1K97DI("L@,2DI*2DL("1V86Q;)VYA;64G72D["B`@("`@("`@("`@("1T
M:&ES+3YM:6UE7W!A<G0M/G-E=$YA;64H)&]L9%]N86UE*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=F%L.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI
M8B]-24U%+U9I97=E<B]P87)T:6%L+G!H<```````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C8R-``Q,#0Q-S,V,C<V-@`P,C(Q,C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!)35!?34E-15]6:65W97)?<&%R=&EA;"!C;&%S<R!A;&QO=W,@;75L=&EP
M87)T+W!A<G1I86P@;65S<V%G97,@=&\@8F4*("H@9&ES<&QA>65D("A21D,@
M,C`T-B!;-2XR+C)=*2X*("H*("H@)$AO<F1E.B!I;7`O;&EB+TU)344O5FEE
M=V5R+W!A<G1I86PN<&AP+'8@,2XQ-RXQ,"XY(#(P,#8O,#$O,S`@,C`Z-34Z
M,3,@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($E-4"`T
M+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($E-
M4%]-24U%7U9I97=E<E]P87)T:6%L(&5X=&5N9',@34E-15]6:65W97(@>PH*
M("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N=&QY('-E="!C
M;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M06X@87)R87D@=VET:"!A(')E9F5R96YC92!T;R!A($U)345?0V]N=&5N=',*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!T97AT(&EN($A4
M34PN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US*0H@("`@
M>PH@("`@("`@("1C;VYT96YT<R`]("8D<&%R86US6S!=.PH*("`@("`@("!G
M;&]B86P@)&EM<#L*"B`@("`@("`@)&)A<V5?;V(@/2`F)&-O;G1E;G1S+3YG
M971"87-E3V)J96-T4'1R*"D["B`@("`@("`@)&-U<G)?:6YD97@@/2`D8F%S
M95]O8BT^9V5T365S<V%G94EN9&5X*"D["B`@("`@("`@)&ED(#T@)'1H:7,M
M/FUI;65?<&%R="T^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)VED)RD["B`@
M("`@("`@)'!A<G1S(#T@87)R87DH*3L*"B`@("`@("`@<F5Q=6ER95]O;F-E
M($E-4%]"05-%("X@)R]L:6(O24U!4"]396%R8V@N<&AP)SL*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<"<["@H@
M("`@("`@("\J(%!E<F9O<FT@=&AE('-E87)C:"!T;R!F:6YD('1H92!O=&AE
M<B!P87)T<R!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D:6UA<%]S96%R
M8V@@/2`F24U07TE-05!?4V5A<F-H.CIS:6YG;&5T;VXH87)R87DH)W!O<#,G
M(#T^("@D:6UP6R=B87-E7W!R;W1O8V]L)UT@/3T@)W!O<#,G*2DI.PH@("`@
M("`@("1Q=65R>2`]("9N97<@24U07TE-05!?4V5A<F-H7U%U97)Y*"D["B`@
M("`@("`@)'%U97)Y+3YH96%D97(H)T-O;G1E;G0M5'EP92<L("1I9"D["B`@
M("`@("`@)&EN9&EC97,@/2`D:6UA<%]S96%R8V@M/G-E87)C:$UA:6QB;W@H
M)'%U97)Y+"`D:6UP6R=S=')E86TG72P@24U0.CIS97)V97)3=')I;F<H)&EM
M<%LG;6%I;&)O>"==*2D["@H@("`@("`@("\J($EF(&YO="!A8FQE('1O(&9I
M;F0@=&AE(&]T:&5R('!A<G1S(&]F('1H92!M97-S86=E+"!P<FEN="!E<G)O
M<BX@*B\*("`@("`@("!I9B`H8V]U;G0H)&EN9&EC97,I("$]("1T:&ES+3YM
M:6UE7W!A<G0M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=T;W1A;"<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8V]N=&5N=',M/F9O<FUA=%-T871U<TUS
M9RAS<')I;G1F*%\H(D-A;B!N;W0@9&ES<&QA>2`M(&9O=6YD(&]N;'D@)7,@
M;V8@)7,@<&%R=',@;V8@=&AI<R!M97-S86=E(&EN('1H92!C=7)R96YT(&UA
M:6QB;W@N(BDL(&-O=6YT*"1I;F1I8V5S*2P@)'1H:7,M/FUI;65?<&%R="T^
M9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)W1O=&%L)RDI*3L*("`@("`@("!]
M"@H@("`@("`@("\J($=E="!T:&4@8V]N=&5N=',@;V8@96%C:"!O9B!T:&4@
M<&%R=',N("HO"B`@("`@("`@9F]R96%C:"`H)&EN9&EC97,@87,@)'9A;"D@
M>PH@("`@("`@("`@("`O*B!.;R!N965D('1O(&9E=&-H('1H92!C=7)R96YT
M('!A<G0@86=A:6XN("HO"B`@("`@("`@("`@(&EF("@D=F%L(#T]("1C=7)R
M7VEN9&5X*2!["B`@("`@("`@("`@("`@("`D<&%R='-;)'1H:7,M/FUI;65?
M<&%R="T^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)VYU;6)E<B<I72`]("1T
M:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@
M+B`G+VQI8B]-24U%+T-O;G1E;G1S+G!H<"<["B`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-24U%+TAE861E<G,N<&AP
M)SL*("`@("`@("`@("`@("`@("1I;7!?8V]N=&5N=',@/2`F24U07T-O;G1E
M;G1S.CIS:6YG;&5T;VXH)'9A;"`N($E-4%])1%A?4T50("X@)%]315-324].
M6R=I;7`G75LG=&AI<VUA:6QB;W@G72D["B`@("`@("`@("`@("`@("`D<&%R
M="`]("8D:6UP7V-O;G1E;G1S+3YG971-24U%4&%R="@P*3L*("`@("`@("`@
M("`@("`@("1P87)T<ULD<&%R="T^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H
M)VYU;6)E<B<I72`]("1I;7!?8V]N=&5N=',M/F=E=$)O9'DH*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4V]R="!T:&4@<&%R=',@
M:6X@;G5M97)I8V%L(&]R9&5R+B`J+PH@("`@("`@(&MS;W)T*"1P87)T<RP@
M4T]25%].54U%4DE#*3L*"B`@("`@("`@+RH@0V]M8FEN92!T:&4@<&%R=',@
M86YD(')E;F1E<B!T:&4@=6YD97)L>6EN9R!D871A+B`J+PH@("`@("`@("1M
M:6UE7VUE<W-A9V4@/2`F34E-15]3=')U8W1U<F4Z.G!A<G-E5&5X=$U)345-
M97-S86=E*&EM<&QO9&4H)R<L("1P87)T<RDI.PH@("`@("`@("1M8R`]("9N
M97<@34E-15]#;VYT96YT<R@D;6EM95]M97-S86=E+"!A<G)A>2@G9&]W;FQO
M860G(#T^("=D;W=N;&]A9%]A='1A8V@G+"`G=FEE=R<@/3X@)W9I97=?871T
M86-H)RDL(&%R<F%Y*"8D8V]N=&5N=',I*3L*("`@("`@("`D;6,M/F)U:6QD
M365S<V%G92@I.PH*("`@("`@("!R971U<FX@)SQT86)L93XG("X@)&UC+3YG
M971-97-S86=E*'1R=64I("X@)SPO=&%B;&4^)SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@8V]N=&5N="UT>7!E(&]F('1H92!R96YD97)E
M9"!O=71P=70N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M:6(O34E-12]6:65W97(O=&YE9BYP:'``````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3$V-#``,3`T,3<S-C(W-C8`,#(Q-#$W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP)SL*"B\J*@H@*B!4
M:&4@24U07TU)345?5FEE=V5R7W1N968@8VQA<W,@86QL;W=S($U3+51.148@
M871T86-H;65N=',@=&\@8F4@9&ES<&QA>65D+@H@*@H@*B`D2&]R9&4Z(&EM
M<"]L:6(O34E-12]6:65W97(O=&YE9BYP:'`L=B`Q+C(U+C$P+C@@,C`P-B\P
M,2\P,2`R,3HR.#HU."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@
M("!)35`@-"XP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC
M;&%S<R!)35!?34E-15]6:65W97)?=&YE9B!E>'1E;F1S($U)345?5FEE=V5R
M7W1N968@>PH*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G14>7!E(&]F('1H
M92!A='1A8VAM96YT+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V-O;G1E;G14>7!E(#T@)V%P<&QI8V%T:6]N+V]C=&5T
M+7-T<F5A;2<["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R
M96YT;'D@<V5T(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!!;B!A<G)A>2!W:71H(&$@<F5F97)E;F-E('1O(&$@34E-
M15]#;VYT96YT<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@16ET:&5R('1H92!L
M:7-T(&]F('1N968@9FEL97,@;W(@=&AE(&1A=&$@;V8@86X*("`@("`J("`@
M("`@("`@("`@("`@("!I;F1I=FED=6%L('1N968@9FEL92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,I"B`@("!["B`@("`@("`@)&-O
M;G1E;G1S(#T@)B1P87)A;7-;,%T["@H@("`@("`@("1T97AT(#T@)R<["@H@
M("`@("`@("\J($=E="!T:&4@9&%T82!F<F]M('1H92!A='1A8VAM96YT+B`J
M+PH@("`@("`@("1T;F5F1&%T82`]("1T:&ES+3Y?9V5T4W5B<&%R=',H*3L*
M"B`@("`@("`@+RH@1&ES<&QA>2!T:&4@<F5Q=65S=&5D(&9I;&4N($ET<R!P
M;W-I=&EO;B!I;B!T:&4@)'1N969$871A"B`@("`@("`@("`@87)R87D@8V%N
M(&)E(&9O=6YD(&EN("=T;F5F7V%T=&%C:&UE;G0G+B`J+PH@("`@("`@(&EF
M("A5=&EL.CIG971&;W)M1&%T82@G=&YE9E]A='1A8VAM96YT)RDI('L*("`@
M("`@("`@("`@)'1N969+97D@/2!5=&EL.CIG971&;W)M1&%T82@G=&YE9E]A
M='1A8VAM96YT)RD@+2`Q.PH@("`@("`@("`@("`O*B!697)I9GD@=&AA="!T
M:&4@<F5Q=65S=&5D(&9I;&4@97AI<W1S+B`J+PH@("`@("`@("`@("!I9B`H
M:7-S970H)'1N969$871A6R1T;F5F2V5Y72DI('L*("`@("`@("`@("`@("`@
M("1T97AT(#T@)'1N969$871A6R1T;F5F2V5Y75LG<W1R96%M)UT["B`@("`@
M("`@("`@("`@("!I9B`H96UP='DH)'1E>'0I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1E>'0@/2`D8V]N=&5N=',M/F9O<FUA=%-T871U<TUS9RA?*")#
M;W5L9"!N;W0@97AT<F%C="!T:&4@<F5Q=65S=&5D(&9I;&4@9G)O;2!T:&4@
M35,M5$Y%1B!A='1A8VAM96YT+B(I*3L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUI;65?<&%R="T^<V5T
M3F%M92@D=&YE9D1A=&%;)'1N969+97E=6R=N86UE)UTI.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YM:6UE7W!A<G0M/G-E=%1Y<&4H)'1N969$871A
M6R1T;F5F2V5Y75LG='EP92==("X@)R\G("X@)'1N969$871A6R1T;F5F2V5Y
M75LG<W5B='EP92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T97AT(#T@)&-O;G1E;G1S+3YF
M;W)M8713=&%T=7--<V<H7R@B5&AE(')E<75E<W1E9"!F:6QE(&1O97,@;F]T
M(&5X:7-T(&EN('1H92!-4RU43D5&(&%T=&%C:&UE;G0N(BDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1E>'0@/2`D
M=&AI<RT^<F5N9&5R071T86-H;65N=$EN9F\H87)R87DH)'!A<F%M<ULP72DI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5N9&5R(&]U="!43D5&(&%T=&%C:&UE;G0@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N
M(&%R<F%Y('=I=&@@82!R969E<F5N8V4@=&\@82!-24U%7T-O;G1E;G1S"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@=&5X="!I;B!(5$U,
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)!='1A8VAM96YT26YF;R@D
M<&%R86US*0H@("`@>PH@("`@("`@("1C;VYT96YT<R`]("8D<&%R86US6S!=
M.PH*("`@("`@("`D=&5X="`]("<G.PH*("`@("`@("`O*B!-86ME('-U<F4@
M=&AE(&-O;G1E;G1S(&%R92!I;B!T:&4@34E-15]087)T(&]B:F5C="X@*B\*
M("`@("`@("!I9B`H(21T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI
M('L*("`@("`@("`@("`@)'1H:7,M/FUI;65?<&%R="T^<V5T0V]N=&5N=',H
M)&-O;G1E;G1S+3YG971";V1Y4&%R="@D=&AI<RT^;6EM95]P87)T+3YG971-
M24U%260H*2DI.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T('1H92!D871A
M(&9R;VT@=&AE(&%T=&%C:&UE;G0N("HO"B`@("`@("`@)'1N969$871A(#T@
M)'1H:7,M/E]G9713=6)P87)T<R@I.PH*("`@("`@("!I9B`H(6-O=6YT*"1T
M;F5F1&%T82DI('L*("`@("`@("`@("`@)'1E>'0@/2`D8V]N=&5N=',M/F9O
M<FUA=%-T871U<TUS9RA?*").;R!A='1A8VAM96YT<R!F;W5N9"XB*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1E>'0@/2`D8V]N=&5N=',M
M/F9O<FUA=%-T871U<TUS9RA?*")4:&4@9F]L;&]W:6YG(&9I;&5S('=E<F4@
M871T86-H960@=&\@=&AI<R!P87)T.B(I*2`N("<\8G(@+SXG.PH@("`@("`@
M("`@("!F;W)E86-H("@D=&YE9D1A=&$@87,@)&ME>2`]/B`D9&%T82D@>PH@
M("`@("`@("`@("`@("`@)'1E;7!?<&%R="`]("1T:&ES+3YM:6UE7W!A<G0[
M"B`@("`@("`@("`@("`@("`D=&5M<%]P87)T+3YS971.86UE*"1D871A6R=N
M86UE)UTI.PH@("`@("`@("`@("`@("`@)'1E;7!?<&%R="T^<V5T1&5S8W)I
M<'1I;VXH)&1A=&%;)VYA;64G72D["@H@("`@("`@("`@("`@("`@+RH@4VAO
M<G0M8VER8W5I="!-24U%+71Y<&4@9W5E<W-I;F<@9F]R('=I;FUA:6PN9&%T
M('!A<G1S.PH@("`@("`@("`@("`@("`@("`@=V4G<F4@<VAO=VEN9R!E;F]U
M9V@@96YT<FEE<R!F;W(@=&AE;2!A;')E861Y+B`J+PH@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUA9VEC+G!H<"<["B`@("`@
M("`@("`@("`@("`D='EP92`]("1D871A6R=T>7!E)UT@+B`G+R<@+B`D9&%T
M85LG<W5B='EP92==.PH@("`@("`@("`@("`@("`@:68@*"@D='EP92`]/2`G
M87!P;&EC871I;VXO;V-T970M<W1R96%M)RD@?'P*("`@("`@("`@("`@("`@
M("`@("`H)'1Y<&4@/3T@)V%P<&QI8V%T:6]N+V)A<V4V-"<I*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1Y<&4@/2!-24U%7TUA9VEC.CIF:6QE;F%M951O
M34E-12@D9&%T85LG;F%M92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1T96UP7W!A<G0M/G-E=%1Y<&4H)'1Y<&4I.PH*("`@("`@
M("`@("`@("`@("1L:6YK(#T@)&-O;G1E;G1S+3YL:6YK5FEE=R@D=&5M<%]P
M87)T+"`G=FEE=U]A='1A8V@G+"`D9&%T85LG;F%M92==+"!A<G)A>2@G:G-T
M97AT)R`]/B!S<')I;G1F*%\H(E9I97<@)7,B*2P@)&1A=&%;)VYA;64G72DL
M("=V:65W<&%R86US)R`]/B!A<G)A>2@G=&YE9E]A='1A8VAM96YT)R`]/B`H
M)&ME>2`K(#$I*2DI.PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@7R@B071T
M86-H960@1FEL93HB*2`N("<F;F)S<#LF;F)S<#LG("X@)&QI;FL@+B`G)FYB
M<W`[)FYB<W`[*"<@+B`D9&%T85LG='EP92==("X@)R\G("X@)&1A=&%;)W-U
M8G1Y<&4G72`N("(I/&)R("\^7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!,:7-T(&%N>2!E;6)E9&1E9"!A='1A8VAM96YT<R!I;B!T:&4@5$Y%1B!P
M87)T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%N>2!E;6)E9&1E9"!A
M='1A8VAM96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%-U8G!A<G1S
M*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R97-S
M+G!H<"<["B`@("`@("`@)'1N968@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L
M971O;B@G=&YE9B<I.PH@("`@("`@(')E='5R;B`D=&YE9BT^9&5C;VUP<F5S
M<R@D=&AI<RT^;6EM95]P87)T+3YT<F%N<V9E<D1E8V]D92@I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@8V]N=&5N="UT>7!E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="UT>7!E(&]F
M('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@
M("`@>PH@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G=&YE9E]A='1A
M8VAM96YT)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N
M=%1Y<&4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("=T
M97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M("`@('T*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O;&EB+TU)344O5FEE=V5R+W)E;&%T960N<&AP````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`V,C0V`#$P-#$W,S8R-S8V`#`R,C$Q,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($E-4%]-24U%7U9I97=E<E]R96QA=&5D(&-L87-S(&AA;F1L
M97,@;75L=&EP87)T+W)E;&%T960@;65S<V%G97,*("H@87,@9&5F:6YE9"!B
M>2!21D,@,C,X-RX*("H*("H@)$AO<F1E.B!I;7`O;&EB+TU)344O5FEE=V5R
M+W)E;&%T960N<&AP+'8@,2XR,2XQ,"XQ,"`R,#`V+S`Q+S`Q(#(Q.C(X.C4X
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($E-4"`T+C`*("H@
M0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($E-4%]-24U%
M7U9I97=E<E]R96QA=&5D(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J
M*@H@("`@("H@5&AE(&-H87)A8W1E<B!S970@;V8@=&AE(')E;F1E<F5D($A4
M34P@<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]C:&%R<V5T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@82!R969E
M<F5N8V4@=&\@82!-24U%7T-O;G1E;G1S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<F5N9&5R960@=&5X="!I;B!(5$U,+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H)'!A<F%M<RD*("`@('L*("`@("`@("`D8V]N=&5N=',@
M/2`F)'!A<F%M<ULP73L*"B`@("`@("`@+RH@3&]O:R!A="!T:&4@)W-T87)T
M)R!P87)A;65T97(@=&\@9&5T97)M:6YE('=H:6-H('!A<G0@=&\@<W1A<G0*
M("`@("`@("`@("!W:71H+B!)9B!N;R`G<W1A<G0G('!A<F%M971E<BP@=7-E
M('1H92!F:7)S="!P87)T+@H@("`@("`@("`@(%)&0R`R,S@W(%LS+C%=("HO
M"B`@("`@("`@:68@*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G14>7!E
M4&%R86UE=&5R*"=S=&%R="<I("8F"B`@("`@("`@("`@("@D:V5Y(#T@87)R
M87E?<V5A<F-H*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G14>7!E4&%R
M86UE=&5R*"=S=&%R="<I+"`D=&AI<RT^;6EM95]P87)T+3YG971#241,:7-T
M*"DI*2D@>PH@("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')R<&]S*"1K97DL
M("<N)RDI*2!["B`@("`@("`@("`@("`@("`D:60@/2!S=6)S='(H)&ME>2P@
M)'!O<R`K(#$I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&ED(#T@)&ME>3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1I9"`](#$["B`@("`@("`@?0H@("`@("`@("1S=&%R
M="`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=%!A<G0H)'1H:7,M/FUI;65?<&%R
M="T^9V5T4F5L871I=F5-:6UE240H)&ED*2D["@H@("`@("`@("\J($]N;'D@
M9&ES<&QA>2!I9B!T:&4@<W1A<G0@<&%R="`H;F]R;6%L;'D@=&5X="]H=&UL
M*2!C86X@8F4@9&ES<&QA>65D"B`@("`@("`@("`@:6YL:6YE("U/4BT@=V4@
M87)E('9I97=I;F<@=&AI<R!P87)T(&%S(&%N(&%T=&%C:&UE;G0N("HO"B`@
M("`@("`@:68@*"1C;VYT96YT<RT^8V%N1&ES<&QA>4EN;&EN92@D<W1A<G0I
M('Q\"B`@("`@("`@("`@("1C;VYT96YT<RT^=FEE=T%S071T86-H;65N="@I
M*2!["B`@("`@("`@("`@("1T97AT(#T@)&-O;G1E;G1S+3YR96YD97)-24U%
M4&%R="@D<W1A<G0I.PH@("`@("`@("`@("`D=&AI<RT^7V-H87)S970@/2`D
M<W1A<G0M/F=E=$-H87)S970H*3L*("`@("`@("`@("`@)&-O;G1E;G1S+3YR
M96UO=F5);F1E>"@D<W1A<G0M/F=E=$U)345)9"@I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&5X="`]("<G.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T97AT.PH@("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@871T86-H;65N="!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@=VET:"!A(')E9F5R96YC
M92!T;R!A($U)345?0V]N=&5N=',*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R96YD97)E9"!T97AT(&EN($A434PN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<D%T=&%C:&UE;G1);F9O*"1P87)A;7,I"B`@("!["B`@("`@("`@
M)&-O;G1E;G1S(#T@)B1P87)A;7-;,%T["@H@("`@("`@("1M<V<@/2!S<')I
M;G1F*%\H(D-L:6-K("5S('1O('9I97<@=&AI<R!M=6QT:7!A<G0O<F5L871E
M9"!P87)T(&EN(&$@<V5P87)A=&4@=VEN9&]W+B(I+"`D8V]N=&5N=',M/FQI
M;FM6:65W2E,H)'1H:7,M/FUI;65?<&%R="P@)W9I97=?871T86-H)RP@7R@B
M2$5212(I+"!?*")6:65W(&-O;G1E;G0@:6X@82!S97!A<F%T92!W:6YD;W<B
M*2DI.PH@("`@("`@(')E='5R;B`D8V]N=&5N=',M/F9O<FUA=%-T871U<TUS
M9R@D;7-G+"!(;W)D93HZ:6UG*"=M:6UE+VAT;6PN<&YG)RP@7R@B2%1-3"(I
M*2P@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C
M;VYT96YT+71Y<&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!C;VYT96YT+71Y<&4@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H
M=&UL.R!C:&%R<V5T/2<@+B`D=&AI<RT^9V5T0VAA<G-E="@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<F%C=&5R('-E="!U<V5D
M(&9O<B!T:&4@5FEE=V5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@8VAA<F%C=&5R('-E="!U<V5D(&)Y('1H:7,@5FEE=V5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971#:&%R<V5T*"D*("`@('L*("`@("`@("!R
M971U<FX@*&ES7VYU;&PH)'1H:7,M/E]C:&%R<V5T*2D@/R!.3%,Z.F=E=$-H
M87)S970H*2`Z("1T:&ES+3Y?8VAA<G-E=#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+VQI8B]-24U%+U9I97=E<B]I=&EP+G!H<```````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#$P,3,T-``Q,#0Q-S,V,C<V-@`P,C$T,S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!)35!?34E-15]6:65W97)?:71I<"!C;&%S<R!D:7-P;&%Y
M<R!V0V%L96YD87(O:4-A;&5N9&%R(&1A=&$*("H@86YD('!R;W9I9&5S(&%N
M(&]P=&EO;B!T;R!I;7!O<G0@=&AE(&1A=&$@:6YT;R!A(&-A;&5N9&%R('-O
M=7)C92P*("H@:68@;VYE(&ES(&%V86EL86)L92X*("H*("H@)$AO<F1E.B!I
M;7`O;&EB+TU)344O5FEE=V5R+VET:7`N<&AP+'8@,2XS-RXR+C(P(#(P,#8O
M,#$O,#$@,C$Z,C@Z-3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@24U0(#0N,`H@*B!`<&%C
M:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@24U07TU)345?5FEE
M=V5R7VET:7`@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@
M*B!&;W)C92!V:65W:6YG(&]F(&$@<&%R="!I;FQI;F4L(')E9V%R9&QE<W,@
M;V8@=&AE($-O;G1E;G0M1&ES<&]S:71I;VX*("`@("`J(&]F('1H92!-24U%
M(%!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@
M('9A<B`D7V9O<F-E:6YL:6YE(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1H
M92!M97-S86=E<R!T;R!O=71P=70@=&\@=&AE('5S97(N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]M<V=S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J(%1H92!M971H;V0@87,@;6%R:V5D(&EN(&5I
M=&AE<B!T:&4@:4-A;"!S=')U8W1U<F4@;W(@;65S<V%G92!H96%D97(N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;65T
M:&]D(#T@)U!50DQ)4T@G.PH*("`@("\J*@H@("`@("H@5&AE(&AE861E<G,@
M;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?:&5A9&5R<SL*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@=&AE(&-U<G)E;G1L>2!S970@:4-A;&5N9&%R(&-O;G1E;G1S+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE
M=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O:4-A;&5N9&%R+G!H<"<["@H@("`@("`@("\O($5X=')A8W0@=&AE
M(&1A=&$N"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^;6EM95]P87)T+3YG971#
M;VYT96YT<R@I.PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VAE861E<G,I
M("8F(&ES7V$H)'!A<F%M<ULP72P@)TE-4%]#;VYT96YT<R<I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?:&5A9&5R<R`]("1P87)A;7-;,%TM/F=E=$AE861E
M<D]B*"D["B`@("`@("`@?0H*("`@("`@("`O+R!087)S92!T:&4@:4-A;"!F
M:6QE+@H@("`@("`@("1V0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*
M("`@("`@("!I9B`H(21V0V%L+3YP87)S979#86QE;F1A<B@D9&%T82DI('L*
M("`@("`@("`@("`@<F5T=7)N("<\:#$^)R`N(%\H(E1H92!C86QE;F1A<B!D
M871A(&ES(&EN=F%L:60B*2`N("<\+V@Q/B<@+@H@("`@("`@("`@("`@("`@
M)SQP<F4^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&1A=&$I("X@)SPO<')E/B<[
M"B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!I9B!W92!G;W0@=F-A<F0@
M9&%T82!W:71H('1H92!W<F]N9R!V8V%L96YD87(@;6EM90H@("`@("`@("\O
M('1Y<&4N"B`@("`@("`@)&,@/2`D=D-A;"T^9V5T0V]M<&]N96YT0VQA<W-E
M<R@I.PH@("`@("`@(&EF("AC;W5N="@D8RD@/3T@,2`F)B`A96UP='DH)&-;
M)VAO<F1E7VEC86QE;F1A<E]V8V%R9"==*2D@>PH@("`@("`@("`@("`D=F-A
M<F1?<F5N9&5R97(@/2`F36EM95]6:65W97(Z.F9A8W1O<GDH)'1H:7,M/FUI
M;65?<&%R="P@)W1E>'0O>"UV8V%R9"<I.PH@("`@("`@("`@("!R971U<FX@
M)'9C87)D7W)E;F1E<F5R+3YR96YD97(H)'!A<F%M<RD["B`@("`@("`@?0H*
M("`@("`@("`O+R!'970@=&AE(&UE=&AO9"!T>7!E+@H@("`@("`@("1T:&ES
M+3Y?;65T:&]D(#T@)'9#86PM/F=E=$%T=')I8G5T92@G34542$]$)RD["@H@
M("`@("`@("\O($=E="!T:&4@:4-A;&5N9&%R(&9I;&4@8V]M<&]N96YT<RX*
M("`@("`@("`D8V]M<&]N96YT<R`]("1V0V%L+3YG971#;VUP;VYE;G1S*"D[
M"@H@("`@("`@("\O($AA;F1L92!T:&4@86-T:6]N(')E<75E<W1S+@H@("`@
M("`@("1A8W1I;VYS(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO;B<L(&%R
M<F%Y*"DI.PH@("`@("`@(&9O<F5A8V@@*"1A8W1I;VYS(&%S("1K97D@/3X@
M)&%C=&EO;BD@>PH@("`@("`@("`@("`D=&AI<RT^7VUS9W-;)&ME>5T@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@("`@
M("`@("`@8V%S92`G9&5L971E)SH*("`@("`@("`@("`@("`@("\O('9%=F5N
M="!C86YC96QL871I;VXN"B`@("`@("`@("`@("`@("!I9B`H)')E9VES=')Y
M+3YH87--971H;V0H)V-A;&5N9&%R+V1E;&5T92<I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&=U:60@/2`D8V]M<&]N96YT<ULD:V5Y72T^9V5T071T<FEB
M=71E*"=5240G*3L*("`@("`@("`@("`@("`@("`@("`D979E;G0@/2`D<F5G
M:7-T<GDM/F-A;&PH)V-A;&5N9&%R+V1E;&5T92<L(&%R<F%Y*"=G=6ED)R`]
M/B`D9W5I9"DI.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1E=F5N
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7VUS9W-;)&ME>5U;72`](&%R<F%Y*"=E<G)O<B<L('-P<FEN=&8H
M7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&1E;&5T:6YG('1H92!E=F5N=#H@)7,N
M(BDL("1E=F5N="T^9V5T365S<V%G92@I*2D["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M
M<V=S6R1K97E=6UT@/2!A<G)A>2@G<W5C8V5S<R<L(%\H(D5V96YT('-U8V-E
M<W-F=6QL>2!D96QE=&5D+B(I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;7-G<ULD:V5Y75M=(#T@87)R87DH)W=A<FYI;F<G+"!?*")4:&ES
M(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+B(I*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M=7!D871E)SH*("`@("`@("`@("`@("`@("\O('9%=F5N="!R97!L>2X*("`@
M("`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G8V%L96YD
M87(O=7!D871E071T96YD964G*2D@>PH@("`@("`@("`@("`@("`@("`@("1E
M=F5N="`]("1R96=I<W1R>2T^8V%L;"@G8V%L96YD87(O=7!D871E071T96YD
M964G+"!A<G)A>2@G<F5S<&]N<V4G(#T^("1C;VUP;VYE;G1S6R1K97E=*2D[
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&5V96YT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;7-G
M<ULD:V5Y75M=(#T@87)R87DH)V5R<F]R)RP@<W!R:6YT9BA?*")4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&5V96YT.B`E<RXB*2P@)&5V96YT
M+3YG971-97-S86=E*"DI*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUS9W-;)&ME>5U;
M72`](&%R<F%Y*"=S=6-C97-S)RP@7R@B4F5S<&]N9&5N="!3=&%T=7,@57!D
M871E9"XB*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUS9W-;
M)&ME>5U;72`](&%R<F%Y*"=W87)N:6YG)RP@7R@B5&AI<R!A8W1I;VX@:7,@
M;F]T('-U<'!O<G1E9"XB*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VEM<&]R="<Z"B`@
M("`@("`@("`@(&-A<V4@)V%C8V5P="UI;7!O<G0G.@H@("`@("`@("`@("`@
M("`@+R\@=D9R965B=7-Y(')E<&QY+@H@("`@("`@("`@("`@("`@+R\@=D9R
M965B=7-Y('!U8FQI<V@N"B`@("`@("`@("`@("`@("`O+R!V179E;G0@<F5Q
M=65S="X*("`@("`@("`@("`@("`@("\O('9%=F5N="!P=6)L:7-H+@H@("`@
M("`@("`@("`@("`@+R\@=E1O9&\@<'5B;&ES:"X*("`@("`@("`@("`@("`@
M("\O('9*;W5R;F%L('!U8FQI<V@N"B`@("`@("`@("`@("`@("!S=VET8V@@
M*"1C;VUP;VYE;G1S6R1K97E=+3YG9714>7!E*"DI('L*("`@("`@("`@("`@
M("`@(&-A<V4@)W9%=F5N="<Z"B`@("`@("`@("`@("`@("`@("`@+R\@26UP
M;W)T(&EN=&\@2W)O;F]L:71H+@H@("`@("`@("`@("`@("`@("`@(&EF("@D
M<F5G:7-T<GDM/FAA<TUE=&AO9"@G8V%L96YD87(O:6UP;W)T)RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&=U:60@/2`D<F5G:7-T<GDM/F-A;&PH
M)V-A;&5N9&%R+VEM<&]R="<L(&%R<F%Y*"=C;VYT96YT)R`]/B`D8V]M<&]N
M96YT<ULD:V5Y72P@)V-O;G1E;G14>7!E)R`]/B`G=&5X="]C86QE;F1A<B<I
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&=U:60L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;7-G<ULD:V5Y75M=(#T@87)R87DH)V5R<F]R)RP@<W!R:6YT9BA?
M*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N
M(BDL("1G=6ED+3YG971-97-S86=E*"DI*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U
M<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^;&EN:R@G8V%L96YD87(O<VAO
M=R<L(&%R<F%Y*"=U:60G(#T^("1G=6ED*2DI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]M<V=S6R1K97E=6UT@/2!A<G)A>2@G<W5C
M8V5S<R<L(%\H(E1H92!E=F5N="!W87,@861D960@=&\@>6]U<B!C86QE;F1A
M<BXB*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G)FYB<W`[)R`N($AO<F1E.CIL:6YK*"1U<FPL
M(%\H(E9I97<@979E;G0B*2P@;G5L;"P@)U]B;&%N:R<I("X@2&]R9&4Z.FEM
M9R@G;6EM92]I8V%L96YD87(N<&YG)RP@7R@B5FEE=R!E=F5N="(I+"!N=6QL
M+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUS
M9W-;)&ME>5U;72`](&%R<F%Y*"=W87)N:6YG)RP@7R@B5&AI<R!A8W1I;VX@
M:7,@;F]T('-U<'!O<G1E9"XB*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A
M<V4@)W9&<F5E8G5S>2<Z"B`@("`@("`@("`@("`@("`@("`@+R\@26UP;W)T
M(&EN=&\@2W)O;F]L:71H+@H@("`@("`@("`@("`@("`@("`@(&EF("@D<F5G
M:7-T<GDM/FAA<TUE=&AO9"@G8V%L96YD87(O:6UP;W)T7W9F<F5E8G5S>2<I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R97,@/2`D<F5G:7-T<GDM
M/F-A;&PH)V-A;&5N9&%R+VEM<&]R=%]V9G)E96)U<WDG+"!A<G)A>2@D8V]M
M<&]N96YT<ULD:V5Y72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUS9W-;)&ME>5U;72`](&%R<F%Y*"=E<G)O
M<B<L('-P<FEN=&8H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U
M<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB*2P@)')E<RT^9V5T
M365S<V%G92@I*2D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUS9W-;)&ME
M>5U;72`](&%R<F%Y*"=S=6-C97-S)RP@7R@B5&AE('5S97(G<R!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB*2D["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUS9W-;
M)&ME>5U;72`](&%R<F%Y*"=W87)N:6YG)RP@7R@B5&AI<R!A8W1I;VX@:7,@
M;F]T('-U<'!O<G1E9"XB*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)W94;V1O)SH*("`@("`@("`@("`@("`@("`@("`O+R!);7!O<G0@:6YT;R!.
M86<N"B`@("`@("`@("`@("`@("`@("`@:68@*"1R96=I<W1R>2T^:&%S365T
M:&]D*"=T87-K<R]I;7!O<G0G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D9W5I9"`]("1R96=I<W1R>2T^8V%L;"@G=&%S:W,O:6UP;W)T)RP@87)R
M87DH)&-O;7!O;F5N='-;)&ME>5TL("=T97AT+W@M=G1O9&\G*2D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1G=6ED+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUS
M9W-;)&ME>5U;72`](&%R<F%Y*"=E<G)O<B<L('-P<FEN=&8H7R@B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(BDL("1G=6ED
M+3YG971-97-S86=E*"DI*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U<FP@/2!(;W)D
M93HZ=7)L*"1R96=I<W1R>2T^;&EN:R@G=&%S:W,O<VAO=R<L(&%R<F%Y*"=U
M:60G(#T^("1G=6ED*2DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]M<V=S6R1K97E=6UT@/2!A<G)A>2@G<W5C8V5S<R<L(%\H(E1H
M92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N(BD@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R9N8G-P.R<@+B!(;W)D93HZ;&EN:R@D=7)L+"!?*")6:65W
M('1A<VLB*2P@;G5L;"P@)U]B;&%N:R<I("X@2&]R9&4Z.FEM9R@G;6EM92]I
M8V%L96YD87(N<&YG)RP@7R@B5FEE=R!T87-K(BDL(&YU;&PL("1R96=I<W1R
M>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;7-G<ULD:V5Y75M=
M(#T@87)R87DH)W=A<FYI;F<G+"!?*")4:&ES(&%C=&EO;B!I<R!N;W0@<W5P
M<&]R=&5D+B(I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G=DIO=7)N
M86PG.@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VUS9W-;)&ME>5U;72`](&%R<F%Y*"=W87)N:6YG)RP@
M7R@B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB*2D["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1A8W1I;VX@
M(3T@)V%C8V5P="UI;7!O<G0G*2!["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("!C87-E("=A8V-E
M<'0G.@H@("`@("`@("`@("!C87-E("=A8V-E<'0M:6UP;W)T)SH*("`@("`@
M("`@("`@8V%S92`G9&5N>2<Z"B`@("`@("`@("`@(&-A<V4@)W1E;G1A=&EV
M92<Z"B`@("`@("`@("`@("`@("`O+R!V179E;G0@<F5Q=65S="X*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D8V]M<&]N96YT<ULD:V5Y72D@)B8*("`@
M("`@("`@("`@("`@("`@("`D8V]M<&]N96YT<ULD:V5Y72T^9V5T5'EP92@I
M(#T]("=V179E;G0G*2!["B`@("`@("`@("`@("`@("`@("`@)'9%=F5N="`]
M("1C;VUP;VYE;G1S6R1K97E=.PH*("`@("`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`@("`@("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["B`@("`@("`@
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TAE861E<G,N
M<&AP)SL*("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+TU)344O4&%R="YP:'`G.PH*("`@("`@("`@("`@("`@("`@("`O+R!'970@
M=&AE(&]R9V%N:7IE<B!D971A:6QS+@H@("`@("`@("`@("`@("`@("`@("1O
M<F=A;FEZ97(@/2!P87)S95]U<FPH)'9%=F5N="T^9V5T071T<FEB=71E*"=/
M4D=!3DE:15(G*2D["B`@("`@("`@("`@("`@("`@("`@)&]R9V%N:7IE<D5M
M86EL(#T@)&]R9V%N:7IE<ELG<&%T:"==.PH@("`@("`@("`@("`@("`@("`@
M("1O<F=A;FEZ97(@/2`D=D5V96YT+3YG971!='1R:6)U=&4H)T]21T%.25I%
M4B<L('1R=64I.PH@("`@("`@("`@("`@("`@("`@("1O<F=A;FEZ97).86UE
M(#T@:7-S970H)&]R9V%N:7IE<ELG8VXG72D@/R`D;W)G86YI>F5R6R=C;B==
M(#H@)R<["@H@("`@("`@("`@("`@("`@("`@("\O($)U:6QD('1H92!R97!L
M>2X*("`@("`@("`@("`@("`@("`@("`D=D-A;"`]("9N97<@2&]R9&5?:4-A
M;&5N9&%R*"D["B`@("`@("`@("`@("`@("`@("`@)'9#86PM/G-E=$%T=')I
M8G5T92@G4%)/1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J96-T+R\G("X@2$]2
M1$5?04=%3E1?2$5!1$52("X@)R\O14XG*3L*("`@("`@("`@("`@("`@("`@
M("`D=D-A;"T^<V5T071T<FEB=71E*"=-151(3T0G+"`G4D503%DG*3L*"B`@
M("`@("`@("`@("`@("`@("`@)'9%=F5N=%]R97!L>2`]("9(;W)D95]I0V%L
M96YD87(Z.FYE=T-O;7!O;F5N="@G=F5V96YT)RP@)'9#86PI.PH@("`@("`@
M("`@("`@("`@("`@("1V179E;G1?<F5P;'DM/G-E=$%T=')I8G5T92@G54E$
M)RP@)'9%=F5N="T^9V5T071T<FEB=71E*"=5240G*2D["B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<U]A*"1V179E;G0M/F=E=$%T=')I8G5T92@G4U5-
M34%262<I+"`G4$5!4E]E<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1V179E;G1?<F5P;'DM/G-E=$%T=')I8G5T92@G4U5-34%262<L("1V
M179E;G0M/F=E=$%T=')I8G5T92@G4U5-34%262<I*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A*"1V179E
M;G0M/F=E=$%T=')I8G5T92@G1$530U))4%1)3TXG*2P@)U!%05)?97)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=D5V96YT7W)E<&QY+3YS
M971!='1R:6)U=&4H)T1%4T-225!424].)RP@)'9%=F5N="T^9V5T071T<FEB
M=71E*"=$15-#4DE05$E/3B<I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)&1T<W1A<G0@/2`D=D5V96YT+3YG971!='1R
M:6)U=&4H)T144U1!4E0G+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@("`D
M=D5V96YT7W)E<&QY+3YS971!='1R:6)U=&4H)T144U1!4E0G+"`D=D5V96YT
M+3YG971!='1R:6)U=&4H)T144U1!4E0G*2P@87)R87E?<&]P*"1D='-T87)T
M*2D["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A*"1V179E;G0M/F=E
M=$%T=')I8G5T92@G1%1%3D0G*2P@)U!%05)?97)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D9'1E;F0@/2`D=D5V96YT+3YG971!='1R:6)U
M=&4H)T1414Y$)RP@=')U92D["B`@("`@("`@("`@("`@("`@("`@("`@("1V
M179E;G1?<F5P;'DM/G-E=$%T=')I8G5T92@G1%1%3D0G+"`D=D5V96YT+3YG
M971!='1R:6)U=&4H)T1414Y$)RDL(&%R<F%Y7W!O<"@D9'1E;F0I*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9'5R871I;VX@/2`D=D5V96YT+3YG971!='1R:6)U=&4H)T154D%4
M24].)RP@=')U92D["B`@("`@("`@("`@("`@("`@("`@("`@("1V179E;G1?
M<F5P;'DM/G-E=$%T=')I8G5T92@G1%52051)3TXG+"`D=D5V96YT+3YG971!
M='1R:6)U=&4H)T154D%424].)RDL(&%R<F%Y7W!O<"@D9'5R871I;VXI*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<U]A*"1V179E;G0M/F=E=$%T=')I8G5T92@G4T51545.0T4G*2P@)U!%
M05)?97)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=D5V96YT
M7W)E<&QY+3YS971!='1R:6)U=&4H)U-%455%3D-%)RP@)'9%=F5N="T^9V5T
M071T<FEB=71E*"=315%514Y#12<I("L@,2D["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9%=F5N=%]R
M97!L>2T^<V5T071T<FEB=71E*"=315%514Y#12<L(#`I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;W)G86YI>F5R(#T@
M)'9%=F5N="T^9V5T071T<FEB=71E*"=/4D=!3DE:15(G+"!T<G5E*3L*("`@
M("`@("`@("`@("`@("`@("`D=D5V96YT7W)E<&QY+3YS971!='1R:6)U=&4H
M)T]21T%.25I%4B<L("1V179E;G0M/F=E=$%T=')I8G5T92@G3U)'04Y)6D52
M)RDL(&%R<F%Y7W!O<"@D;W)G86YI>F5R*2D["@H@("`@("`@("`@("`@("`@
M("`@("\O($9I;F0@;W5T('=H;R!W92!A<F4@86YD('5P9&%T92!S=&%T=7,N
M"B`@("`@("`@("`@("`@("`@("`@)&ED96YT:71Y(#T@)DED96YT:71Y.CIS
M:6YG;&5T;VXH87)R87DH)VEM<"<L("=I;7`G*2D["B`@("`@("`@("`@("`@
M("`@("`@)&%T=&5N9&5E<R`]("1V179E;G0M/F=E=$%T=')I8G5T92@G0514
M14Y$144G*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A
M='1E;F1E97,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A='1E;F1E
M97,@/2!A<G)A>2@D871T96YD965S*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=&5N9&5E<R!A<R`D
M871T96YD964I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=&5N9&5E
M(#T@<W1R7W)E<&QA8V4H)TU!24Q43SHG+"`G)RP@)&%T=&5N9&5E*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1I9"`]("1I9&5N
M=&ET>2T^9V5T36%T8VAI;F=)9&5N=&ET>2@D871T96YD964I*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&ED96YT:71Y+3YS971$969A=6QT
M*"1I9"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D96UA:6P@/2`D:61E;G1I='DM/F=E=$9R
M;VU!9&1R97-S*"D["B`@("`@("`@("`@("`@("`@("`@)&-N(#T@)&ED96YT
M:71Y+3YG971686QU92@G9G5L;&YA;64G*3L*("`@("`@("`@("`@("`@("`@
M("`D<&%R86US(#T@87)R87DH)T-.)R`]/B`D8VXI.PH*("`@("`@("`@("`@
M("`@("`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@("`@("`@("`@("`@("`@
M("!C87-E("=A8V-E<'0G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V%C
M8V5P="UI;7!O<G0G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;65S<V%G
M92`]('-P<FEN=&8H7R@B)7,@:&%S(&%C8V5P=&5D+B(I+"`D8VXI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<W5B:F5C="`](%\H(D%C8V5P=&5D.B`B
M*2`N("1V179E;G0M/F=E=$%T=')I8G5T92@G4U5-34%262<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R86US6R=005)44U1!5"==(#T@)T%#0T50
M5$5$)SL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)V1E;GDG.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;65S<V%G92`]('-P<FEN=&8H7R@B)7,@:&%S(&1E8VQI;F5D+B(I
M+"`D8VXI.PH@("`@("`@("`@("`@("`@("`@("`@("`D<W5B:F5C="`](%\H
M(D1E8VQI;F5D.B`B*2`N("1V179E;G0M/F=E=$%T=')I8G5T92@G4U5-34%2
M62<I.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R=005)44U1!
M5"==(#T@)T1%0TQ)3D5$)SL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W1E;G1A=&EV92<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("1M97-S86=E(#T@<W!R:6YT9BA?*"(E
M<R!H87,@=&5N=&%T:79E;'D@86-C97!T960N(BDL("1C;BD["B`@("`@("`@
M("`@("`@("`@("`@("`@("1S=6)J96-T(#T@7R@B5&5N=&%T:79E.B`B*2`N
M("1V179E;G0M/F=E=$%T=')I8G5T92@G4U5-34%262<I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R86US6R=005)44U1!5"==(#T@)U1%3E1!5$E6
M12<["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)'9%=F5N=%]R97!L
M>2T^<V5T071T<FEB=71E*"=!5%1%3D1%12<L("=-04E,5$\Z)R`N("1E;6%I
M;"P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@)'9#86PM/F%D9$-O
M;7!O;F5N="@D=D5V96YT7W)E<&QY*3L*"B`@("`@("`@("`@("`@("`@("`@
M)&UI;64@/2`F;F5W($U)345?4&%R="@G;75L=&EP87)T+V%L=&5R;F%T:79E
M)RD["B`@("`@("`@("`@("`@("`@("`@)&)O9'D@/2`F;F5W($U)345?4&%R
M="@G=&5X="]P;&%I;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!3=')I;F<Z.G=R87`H)&UE<W-A9V4L(#<V+"`B7&XB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($Y,4SHZ9V5T0VAA<G-E="@I*3L*"B`@("`@("`@("`@("`@("`@("`@)&EC
M<R`]("9N97<@34E-15]087)T*"=T97AT+V-A;&5N9&%R)RP@)'9#86PM/F5X
M<&]R='9#86QE;F1A<B@I*3L*("`@("`@("`@("`@("`@("`@("`D:6-S+3YS
M971.86UE*"=E=F5N="UR97!L>2YI8W,G*3L*("`@("`@("`@("`@("`@("`@
M("`D:6-S+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G34542$]$)RP@)U)%
M4$Q9)RD["@H@("`@("`@("`@("`@("`@("`@("1M:6UE+3YA9&1087)T*"1B
M;V1Y*3L*("`@("`@("`@("`@("`@("`@("`D;6EM92T^861D4&%R="@D:6-S
M*3L*("`@("`@("`@("`@("`@("`@("`D;6EM92`]("9-24U%7TUE<W-A9V4Z
M.F-O;G9E<G1-:6UE4&%R="@D;6EM92D["@H@("`@("`@("`@("`@("`@("`@
M("\O($)U:6QD('1H92!R97!L>2!H96%D97)S+@H@("`@("`@("`@("`@("`@
M("`@("1M<V=?:&5A9&5R<R`]("9N97<@34E-15](96%D97)S*"D["B`@("`@
M("`@("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1296-E:79E9$AE861E
M<B@I.PH@("`@("`@("`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D365S
M<V%G94ED2&5A9&5R*"D["B`@("`@("`@("`@("`@("`@("`@)&US9U]H96%D
M97)S+3YA9&1(96%D97(H)T1A=&4G+"!D871E*"=R)RDI.PH@("`@("`@("`@
M("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=&<F]M)RP@)&5M
M86EL*3L*("`@("`@("`@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE
M861E<B@G5&\G+"`D;W)G86YI>F5R16UA:6PI.PH*("`@("`@("`@("`@("`@
M("`@("`D:61E;G1I='DM/G-E=$1E9F%U;'0H571I;#HZ9V5T1F]R;41A=&$H
M)VED96YT:71Y)RDI.PH@("`@("`@("`@("`@("`@("`@("1R97!L>71O(#T@
M)&ED96YT:71Y+3YG971686QU92@G<F5P;'ET;U]A9&1R)RD["B`@("`@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D<F5P;'ET;RD@)B8@*"1R97!L>71O
M("$]("1E;6%I;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&US9U]H
M96%D97)S+3YA9&1(96%D97(H)U)E<&QY+71O)RP@)')E<&QY=&\I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;7-G7VAE
M861E<G,M/F%D9$AE861E<B@G4W5B:F5C="<L($U)344Z.F5N8V]D92@D<W5B
M:F5C="P@3DQ3.CIG971#:&%R<V5T*"DI*3L*("`@("`@("`@("`@("`@("`@
M("`D;7-G7VAE861E<G,M/F%D9$U)345(96%D97)S*"1M:6UE*3L*"B`@("`@
M("`@("`@("`@("`@("`@+R\@4V5N9"!T:&4@<F5P;'DN"B`@("`@("`@("`@
M("`@("`@("`@)'-T871U<R`]("1M:6UE+3YS96YD*"1O<F=A;FEZ97)%;6%I
M;"P@)&US9U]H96%D97)S*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M82@D<W1A='5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;7-G<ULD:V5Y75M=(#T@87)R87DH)V5R<F]R)RP@
M<W!R:6YT9BA?*")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB*2P@)'-T871U
M<RT^9V5T365S<V%G92@I*2D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M<V=S6R1K97E=
M6UT@/2!A<G)A>2@G<W5C8V5S<R<L(%\H(E)E<&QY(%-E;G0N(BDI.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M<V=S6R1K97E=6UT@/2!A<G)A
M>2@G=V%R;FEN9R<L(%\H(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N
M(BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=S96YD)SH*("`@("`@("`@("`@("`@("\O
M('9%=F5N="!R969R97-H+@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C
M;VUP;VYE;G1S6R1K97E=*2`F)@H@("`@("`@("`@("`@("`@("`@("1C;VUP
M;VYE;G1S6R1K97E=+3YG9714>7!E*"D@/3T@)W9%=F5N="<I('L*("`@("`@
M("`@("`@("`@("`@("`D=D5V96YT(#T@)&-O;7!O;F5N='-;)&ME>5T["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@=E1O9&\@<F5F
M<F5S:"X*("`@("`@("`@("`@8V%S92`G<F5P;'DG.@H@("`@("`@("`@("!C
M87-E("=R97!L>3)M)SH*("`@("`@("`@("`@("`@("\O('9F<F5E8G5S>2!R
M97%U97-T+@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;VUP;VYE;G1S
M6R1K97E=*2`F)@H@("`@("`@("`@("`@("`@("`@("1C;VUP;VYE;G1S6R1K
M97E=+3YG9714>7!E*"D@/3T@)W9&<F5E8G5S>2<I('L*("`@("`@("`@("`@
M("`@("`@("`D=D9B(#T@)&-O;7!O;F5N='-;)&ME>5T["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1A8W1I;VX@/3T@)W)E<&QY,FTG*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1S=&%R=%-T86UP(#T@=&EM92@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D96YD4W1A;7`@/2`D<W1A<G13=&%M<"`K("@V
M,"`J(#(T("H@,S8P,"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-T87)T4W1A;7`@/2`D=D9B+3YG
M971!='1R:6)U=&4H)T144U1!4E0G*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7V$H)'-T87)T4W1A;7`L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S=&%R=%-T86UP(#T@=&EM92@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("1E;F13=&%M<"`]("1V1F(M/F=E=$%T=')I8G5T92@G1%1%3D0G
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&5N9%-T86UP
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9'5R871I;VX@/2`D=D9B+3YG971!='1R:6)U=&4H)T154D%424].)RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D9'5R871I
M;VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D96YD4W1A;7`@/2`D<W1A<G13=&%M<"`K("@V,"`J(#(T("H@
M,S8P,"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;F13=&%M<"`]("1S
M=&%R=%-T86UP("L@)&1U<F%T:6]N.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1V9F)?<F5P;'D@/2`D
M<F5G:7-T<GDM/F-A;&PH)V-A;&5N9&%R+V=E=$9R965"=7-Y)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=S=&%R=%-T86UP)R`]/B`D<W1A<G13=&%M<"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=E
M;F13=&%M<"<@/3X@)&5N9%-T86UP*2D["B`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@("`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G.PH@("`@
M("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12](96%D
M97)S+G!H<"<["B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]-24U%+U!A<G0N<&AP)SL*"B`@("`@("`@("`@("`@("`@("`@+R\@
M1FEN9"!O=70@=VAO('=E(&%R92!A;F0@=7!D871E('-T871U<RX*("`@("`@
M("`@("`@("`@("`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O
M;B@I.PH@("`@("`@("`@("`@("`@("`@("1E;6%I;"`]("1I9&5N=&ET>2T^
M9V5T1G)O;4%D9')E<W,H*3L*("`@("`@("`@("`@("`@("`@("`D8VX@/2`D
M:61E;G1I='DM/F=E=%9A;'5E*"=F=6QL;F%M92<I.PH*("`@("`@("`@("`@
M("`@("`@("`O+R!'970@=&AE(&]R9V%N:7IE<B!D971A:6QS+@H@("`@("`@
M("`@("`@("`@("`@("1O<F=A;FEZ97(@/2!P87)S95]U<FPH)'9&8BT^9V5T
M071T<FEB=71E*"=/4D=!3DE:15(G*2D["B`@("`@("`@("`@("`@("`@("`@
M)&]R9V%N:7IE<D5M86EL(#T@)&]R9V%N:7IE<ELG<&%T:"==.PH@("`@("`@
M("`@("`@("`@("`@("1O<F=A;FEZ97(@/2`D=D9B+3YG971!='1R:6)U=&4H
M)T]21T%.25I%4B<L('1R=64I.PH@("`@("`@("`@("`@("`@("`@("1O<F=A
M;FEZ97).86UE(#T@:7-S970H)&]R9V%N:7IE<ELG8VXG72D@/R`D;W)G86YI
M>F5R6R=C;B==(#H@)R<["@H@("`@("`@("`@("`@("`@("`@("\O($)U:6QD
M('1H92!R97!L>2X*("`@("`@("`@("`@("`@("`@("`D=D-A;"`]("9N97<@
M2&]R9&5?:4-A;&5N9&%R*"D["B`@("`@("`@("`@("`@("`@("`@)'9#86PM
M/G-E=$%T=')I8G5T92@G4%)/1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J96-T
M+R\G("X@2$]21$5?04=%3E1?2$5!1$52("X@)R\O14XG*3L*("`@("`@("`@
M("`@("`@("`@("`D=D-A;"T^<V5T071T<FEB=71E*"=-151(3T0G+"`G4D50
M3%DG*3L*("`@("`@("`@("`@("`@("`@("`D=D-A;"T^861D0V]M<&]N96YT
M*"1V9F)?<F5P;'DI.PH*("`@("`@("`@("`@("`@("`@("`D;6EM92`]("9N
M97<@34E-15]-97-S86=E*"D["B`@("`@("`@("`@("`@("`@("`@)&UE<W-A
M9V4@/2!?*")!='1A8VAE9"!I<R!A(')E<&QY('1O(&$@8V%L96YD87(@<F5Q
M=65S="!Y;W4@<V5N="XB*3L*("`@("`@("`@("`@("`@("`@("`D8F]D>2`]
M("9N97<@34E-15]087)T*"=T97AT+W!L86EN)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%-T<FEN9SHZ=W)A<"@D;65S
M<V%G92P@-S8L(")<;B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@3DQ3.CIG971#:&%R<V5T*"DI.PH*("`@("`@("`@
M("`@("`@("`@("`D:6-S(#T@)FYE=R!-24U%7U!A<G0H)W1E>'0O8V%L96YD
M87(G+"`D=D-A;"T^97AP;W)T=D-A;&5N9&%R*"DI.PH@("`@("`@("`@("`@
M("`@("`@("1I8W,M/G-E=$YA;64H)VEC86QE;F1A<BYI8W,G*3L*("`@("`@
M("`@("`@("`@("`@("`D:6-S+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G
M34542$]$)RP@)U)%4$Q9)RD["@H@("`@("`@("`@("`@("`@("`@("1M:6UE
M+3YA9&1087)T*"1B;V1Y*3L*("`@("`@("`@("`@("`@("`@("`D;6EM92T^
M861D4&%R="@D:6-S*3L*"B`@("`@("`@("`@("`@("`@("`@+R\@0G5I;&0@
M=&AE(')E<&QY(&AE861E<G,N"B`@("`@("`@("`@("`@("`@("`@)&US9U]H
M96%D97)S(#T@)FYE=R!-24U%7TAE861E<G,H*3L*("`@("`@("`@("`@("`@
M("`@("`D;7-G7VAE861E<G,M/F%D9%)E8V5I=F5D2&5A9&5R*"D["B`@("`@
M("`@("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1-97-S86=E261(96%D
M97(H*3L*("`@("`@("`@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE
M861E<B@G1&%T92<L(&1A=&4H)W(G*2D["B`@("`@("`@("`@("`@("`@("`@
M)&US9U]H96%D97)S+3YA9&1(96%D97(H)T9R;VTG+"`D96UA:6PI.PH@("`@
M("`@("`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=4;R<L
M("1O<F=A;FEZ97)%;6%I;"D["@H@("`@("`@("`@("`@("`@("`@("1I9&5N
M=&ET>2T^<V5T1&5F875L="A5=&EL.CIG971&;W)M1&%T82@G:61E;G1I='DG
M*2D["B`@("`@("`@("`@("`@("`@("`@)')E<&QY=&\@/2`D:61E;G1I='DM
M/F=E=%9A;'5E*"=R97!L>71O7V%D9'(G*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1R97!L>71O*2`F)B`H)')E<&QY=&\@(3T@)&5M86EL
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D
M9$AE861E<B@G4F5P;'DM=&\G+"`D<F5P;'ET;RD["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D
M2&5A9&5R*"=3=6)J96-T)RP@34E-13HZ96YC;V1E*%\H(D9R964O0G5S>2!2
M97%U97-T(%)E<W!O;G-E(BDL($Y,4SHZ9V5T0VAA<G-E="@I*2D["B`@("`@
M("`@("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1-24U%2&5A9&5R<R@D
M;6EM92D["@H@("`@("`@("`@("`@("`@("`@("\O(%-E;F0@=&AE(')E<&QY
M+@H@("`@("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D;6EM92T^<V5N9"@D
M;W)G86YI>F5R16UA:6PL("1M<V=?:&5A9&5R<RD["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)'-T871U<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUS9W-;)&ME>5U;72`](&%R
M<F%Y*"=E<G)O<B<L('-P<FEN=&8H7R@B17)R;W(@<V5N9&EN9R!R97!L>3H@
M)7,N(BDL("1S=&%T=7,M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;7-G<ULD:V5Y75M=(#T@87)R87DH)W-U8V-E<W,G+"!?*")297!L>2!3
M96YT+B(I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;7-G<ULD
M:V5Y75M=(#T@87)R87DH)W=A<FYI;F<G+"!?*"));G9A;&ED($%C=&EO;B!S
M96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(BDI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=N;W-U<"<Z"B`@("`@("`@("`@("`@("`O+R!V1G)E96)U<WD@<F5Q=65S
M="X*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;7-G<ULD:V5Y75M=(#T@87)R87DH)W=A<FYI;F<G+"!?*")4:&ES(&%C
M=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+B(I*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!#<F5A=&4@=&AE($A434P@=&\@9&ES<&QA>2!T:&4@:4-A;"!F:6QE+@H@
M("`@("`@("1H=&UL(#T@)R<["B`@("`@("`@:68@*$U)345?0V]N=&5N=',Z
M.G9I97=!<T%T=&%C:&UE;G0H*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2!5
M=&EL.CIB=69F97)/=71P=70H)W)E<75I<F4G+"`D<F5G:7-T<GDM/F=E="@G
M=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUH96%D97(N:6YC)RD[
M"B`@("`@("`@?0H@("`@("`@("1H=&UL("X]("<\9F]R;2!M971H;V0](G!O
M<W0B(&YA;64](FE#86PB(&%C=&EO;CTB)R`N($AO<F1E.CIS96QF57)L*'1R
M=64I("X@)R(^)SL*"B`@("`@("`@9F]R96%C:"`H)&-O;7!O;F5N=',@87,@
M)&ME>2`]/B`D8V]M<&]N96YT*2!["B`@("`@("`@("`@('-W:71C:"`H)&-O
M;7!O;F5N="T^9V5T5'EP92@I*2!["B`@("`@("`@("`@(&-A<V4@)W9%=F5N
M="<Z"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W9%=F5N="@D
M8V]M<&]N96YT+"`D:V5Y*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G=E1I;65:;VYE)SH*("`@("`@("`@("`@("`@("\O
M($EG;F]R92!T:&5M+@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=V1G)E96)U<WDG.@H@("`@("`@("`@("`@("`@)&AT;6P@
M+CT@)'1H:7,M/E]V1G)E96)U<WDH)&-O;7!O;F5N="P@)&ME>2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O($!T;V1O.B!H86YD
M;&4@<W1R87D@=F-A<F1S(&AE<F4@87,@=V5L;"X*("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B56YH
M86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(I+"`D8V]M<&]N96YT+3YG
M9714>7!E*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!.965D('1O('=O<FL@;W5T(&EF('=E(&%R92!I;FQI;F4@86YD(&%C='5A
M;&QY(&YE960@=&AI<RX*("`@("`@("`D:'1M;"`N/2`G/"]F;W)M/B<["B`@
M("`@("`@:68@*$U)345?0V]N=&5N=',Z.G9I97=!<T%T=&%C:&UE;G0H*2D@
M>PH@("`@("`@("`@("`D:'1M;"`N/2!5=&EL.CIB=69F97)/=71P=70H)W)E
M<75I<F4G+"`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@
M+B`G+V-O;6UO;BUF;V]T97(N:6YC)RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&AT;6P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&5X
M="]H=&UL(&%S('1H92!C;VYT96YT+71Y<&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(G1E>'0O:'1M;"(@8V]N<W1A;G0*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT
M+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!H=&UL(&9O<B!A('9&<F5E8G5S
M>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7W9&<F5E8G5S>2@D=F9B+"`D:60I
M"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>2P@)'!R969S.PH*("`@
M("`@("`D:'1M;"`]("<G.PH@("`@("`@("1D97-C(#T@)R<["B`@("`@("`@
M)'-E;F1E<B`]("1V9F(M/F=E=$YA;64H*3L*("`@("`@("!S=VET8V@@*"1T
M:&ES+3Y?;65T:&]D*2!["B`@("`@("`@8V%S92`G4%5"3$E32"<Z"B`@("`@
M("`@("`@("1D97-C(#T@7R@B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I
M;F9O<FUA=&EO;BXB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)U)%455%4U0G.@H@("`@("`@("`@("`D<V5N9&5R(#T@)'1H:7,M/E]H
M96%D97)S+3YG971686QU92@G1G)O;2<I.PH@("`@("`@("`@("`D9&5S8R`]
M(%\H(B5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G4D503%DG.@H@
M("`@("`@("`@("`D9&5S8R`](%\H(B5S(&AA<R!R97!L:65D('1O(&$@9G)E
M92]B=7-Y(')E<75E<W0N(BD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@)&AT;6P@+CT@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@
M<W!R:6YT9B@D9&5S8RP@)'-E;F1E<BD@+B`G/"]H,3XG.PH*("`@("`@("!I
M9B`H)'1H:7,M/E]M<V=S*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?;7-G<ULD:61=(&%S("1M<V<I('L*("`@("`@("`@("`@("`@("1H=&UL
M("X]("<\<"!C;&%S<STB;F]T:6-E(CXG("X@2&]R9&4Z.FEM9R@G86QE<G1S
M+R<@+B`D;7-G6S!=("X@)RYP;F<G+"`G)RP@;G5L;"P@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*2D@+B`D;7-G6S%=("X@)SPO<#XG.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W1A<G0@/2`D=F9B+3YG
M971!='1R:6)U=&4H)T144U1!4E0G*3L*("`@("`@("!I9B`H(6ES7V$H)'-T
M87)T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D<W1A<G0I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'`^/'-T
M<F]N9SXG("X@7R@B4W1A<G0B*2`N("<Z/"]S=')O;F<^("<@+B!S=')F=&EM
M92@D<')E9G,M/F=E=%9A;'5E*"=D871E7V9O<FUA="<I+"!M:W1I;64H,"P@
M,"P@,"P@)'-T87)T6R=M;VYT:"==+"`D<W1A<G1;)VUD87DG72P@)'-T87)T
M6R=Y96%R)UTI*2`N("<\+W`^)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\<#X\<W1R;VYG/B<@+B!?*")3=&%R
M="(I("X@)SH\+W-T<F]N9SX@)R`N('-T<F9T:6UE*"1P<F5F<RT^9V5T5F%L
M=64H)V1A=&5?9F]R;6%T)RD@+B`G("<@+B`D<')E9G,M/F=E=%9A;'5E*"=T
M:6UE7V9O<FUA="<I+"`D<W1A<G0I("X@)SPO<#XG.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D96YD(#T@)'9F8BT^9V5T071T<FEB=71E
M*"=$5$5.1"<I.PH@("`@("`@(&EF("@A:7-?82@D96YD+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D96YD*2D@>PH@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@)SQP/CQS=')O;F<^)R`N(%\H(D5N9"(I
M("X@)SH\+W-T<F]N9SX@)R`N('-T<F9T:6UE*"1P<F5F<RT^9V5T5F%L=64H
M)V1A=&5?9F]R;6%T)RDL(&UK=&EM92@P+"`P+"`P+"`D96YD6R=M;VYT:"==
M+"`D96YD6R=M9&%Y)UTL("1E;F1;)WEE87(G72DI("X@)SPO<#XG.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQP
M/CQS=')O;F<^)R`N(%\H(D5N9"(I("X@)SH\+W-T<F]N9SX@)R`N('-T<F9T
M:6UE*"(E>"`E6"(L("1E;F0I("X@)SPO<#XG.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D:'1M;"`N/2`G/&@R(&-L87-S/2)S;6%L;&AE
M861E<B(^)R`N(%\H(D%C=&EO;G,B*2`N("<\+V@R/B<@+@H@("`@("`@("`@
M("`G/'-E;&5C="!N86UE/2)A8W1I;VY;)R`N("1I9"`N("==(CXG.PH*("`@
M("`@("!S=VET8V@@*"1T:&ES+3Y?;65T:&]D*2!["B`@("`@("`@8V%S92`G
M4%5"3$E32"<Z"B`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO
M9"@G8V%L96YD87(O:6UP;W)T7W9F<F5E8G5S>2<I*2!["B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB:6UP;W)T(CXG("X@("!?
M*")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(I("X@)SPO
M;W!T:6]N/B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB;F]S=7`B/B<@+B!?*")297!L
M>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(I("X@)SPO;W!T:6]N/B<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)U)%455%4U0G.@H@("`@("`@("`@("!I9B`H)')E9VES=')Y+3YH87--
M971H;V0H)V-A;&5N9&%R+V=E=$9R965"=7-Y)RDI('L*("`@("`@("`@("`@
M("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2)R97!L>2(^)R`N("`@7R@B
M4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(I
M("X@)SPO;W!T:6]N/B<@+@H@("`@("`@("`@("`@("`@("`@("<\;W!T:6]N
M('9A;'5E/2)R97!L>3)M(CXG("X@7R@B4F5P;'D@=VET:"!F<F5E+V)U<WD@
M9F]R(&YE>'0@,B!M;VYT:',N(BD@+B`G/"]O<'1I;VX^)SL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<\;W!T:6]N
M('9A;'5E/2)N;W-U<"(^)R`N(%\H(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E
M9"!-97-S86=E(BD@+B`G/"]O<'1I;VX^)SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64](F1E;GDB/B<@+B!?
M*")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(I("X@
M)SPO;W!T:6]N/B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=215!,62<Z"B`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO
M9"@G8V%L96YD87(O:6UP;W)T7W9F<F5E8G5S>2<I*2!["B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB:6UP;W)T(CXG("X@("!?
M*")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(I("X@)SPO
M;W!T:6]N/B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB;F]S=7`B/B<@+B!?*")297!L
M>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(I("X@)SPO;W!T:6]N/B<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&AT;6P@+B`G/"]S96QE8W0^(#QI;G!U="!T>7!E
M/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(G("X@7R@B1V\B*2`N
M("<O/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&AT;6P@
M9F]R(&$@=D5V96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=D5V96YT*"1V
M979E;G0L("1I9"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D
M<')E9G,["@H@("`@("`@("1H=&UL(#T@)R<["B`@("`@("`@)&1E<V,@/2`G
M)SL*("`@("`@("`D<V5N9&5R(#T@)'9E=F5N="T^;W)G86YI>F5R3F%M92@I
M.PH@("`@("`@("1O<'1I;VYS(#T@87)R87DH*3L*"B`@("`@("`@<W=I=&-H
M("@D=&AI<RT^7VUE=&AO9"D@>PH@("`@("`@(&-A<V4@)U!50DQ)4T@G.@H@
M("`@("`@("`@("`D9&5S8R`](%\H(B5S('=I<VAE<R!T;R!M86ME('EO=2!A
M=V%R92!O9B!<(B5S7"(N(BD["B`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@G8V%L96YD87(O:6UP;W)T)RDI('L*("`@("`@("`@("`@
M("`@("1O<'1I;VYS6UT@/2`G/&]P=&EO;B!V86QU93TB:6UP;W)T(CXG("X@
M("!?*")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(I("X@)SPO;W!T:6]N/B<[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=215%515-4)SH*("`@("`@("`@("`@+R\@0VAE8VL@=&AA="!Y;W4@
M87)E(&]N92!O9B!T:&4@871T96YD965S(&AE<F4N"B`@("`@("`@("`@("1D
M97-C(#T@7R@B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="!<(B5S7"(N
M(BD["B`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G8V%L
M96YD87(O:6UP;W)T)RDI('L*("`@("`@("`@("`@("`@("1O<'1I;VYS6UT@
M/2`G/&]P=&EO;B!V86QU93TB86-C97!T+6EM<&]R="(^)R`N("`@7R@B06-C
M97!T(&%N9"!A9&0@=&\@;7D@8V%L96YD87(B*2`N("<\+V]P=&EO;CXG.PH@
M("`@("`@("`@("`@("`@)&]P=&EO;G-;72`]("<\;W!T:6]N('9A;'5E/2)I
M;7!O<G0B/B<@+B`@(%\H(D%D9"!T;R!M>2!C86QE;F1A<B(I("X@)SPO;W!T
M:6]N/B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]P=&EO;G-;72`]
M("<\;W!T:6]N('9A;'5E/2)A8V-E<'0B/B<@+B!?*")!8V-E<'0@<F5Q=65S
M="(I("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@("1O<'1I;VYS6UT@/2`G
M/&]P=&EO;B!V86QU93TB=&5N=&%T:79E(CXG("X@7R@B5&5N=&%T:79E;'D@
M06-C97!T(')E<75E<W0B*2`N("<\+V]P=&EO;CXG.PH@("`@("`@("`@("`D
M;W!T:6]N<UM=(#T@)SQO<'1I;VX@=F%L=64](F1E;GDB/B<@+B!?*")$96YY
M(')E<75E<W0B*2`N("<\+V]P=&EO;CXG.PH@("`@("`@("`@("`O+R`D;W!T
M:6]N<UM=(#T@)SQO<'1I;VX@=F%L=64](F1E;&5G871E(CXG("X@7R@B1&5L
M96=A=&4@<&]S:71I;VXB*2`N("<\+V]P=&EO;CXG.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G041$)SH*("`@("`@("`@("`@)&1E<V,@
M/2!?*"(E<R!W:7-H97,@=&\@86UM96YD(%PB)7-<(BXB*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)U)%1E)%4T@G.@H@("`@("`@("`@
M("`D9&5S8R`](%\H(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@
M:6YF;W)M871I;VX@86)O=70@7"(E<UPB+B(I.PH@("`@("`@("`@("`D;W!T
M:6]N<UM=(#T@)SQO<'1I;VX@=F%L=64](G-E;F0B/B<@+B!?*")396YD($QA
M=&5S="!);F9O<FUA=&EO;B(I("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@
M(&EF("@A)&9O=6YD("8F("1R96=I<W1R>2T^:&%S365T:&]D*"=C86QE;F1A
M<B]E=F5N=$9R;VU'54E$)RDI('L*("`@("`@("`@("`@("`@("1E>&ES=&EN
M9U]V979E;G0@/2`D<F5G:7-T<GDM/F-A;&PH)V-A;&5N9&%R+V5V96YT1G)O
M;4=5240G+"!A<G)A>2@G9W5I9"<@/3X@)'9E=F5N="T^9V5T071T<FEB=71E
M*"=5240G*2DI.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A*"1E>&ES=&EN
M9U]V979E;G0L("=096%R7V5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("`D97AI<W1I;F=?=F5V96YT+3YU<&1A=&5&<F]M=D5V96YT*"1V979E;G0I
M.PH@("`@("`@("`@("`@("`@("`@("1V979E;G0@/2`D97AI<W1I;F=?=F5V
M96YT.PH@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)U)%4$Q9)SH*("`@("`@("`@("`@)&1E<V,@/2!?
M*"(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R!<(B5S7"(N
M(BD["B`@("`@("`@("`@("1S96YD97(@/2`D=&AI<RT^7VAE861E<G,M/F=E
M=%9A;'5E*"=&<F]M)RD["B`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA
M<TUE=&AO9"@G8V%L96YD87(O=7!D871E071T96YD964G*2D@>PH@("`@("`@
M("`@("`@("`@)&]P=&EO;G-;72`]("<\;W!T:6]N('9A;'5E/2)U<&1A=&4B
M/B<@+B!?*")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B*2`N("<\+V]P=&EO
M;CXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=#04Y#14PG.@H@("`@("`@("`@("`D9&5S8R`](%\H(B5S(&AA
M<R!C86YC96QL960@7"(E<UPB+B(I.PH@("`@("`@("`@("!I9B`H)')E9VES
M=')Y+3YH87--971H;V0H)V-A;&5N9&%R+V1E;&5T92<I*2!["B`@("`@("`@
M("`@("`@("`D;W!T:6]N<UM=(#T@)SQO<'1I;VX@=F%L=64](F1E;&5T92(^
M)R`N(%\H(D1E;&5T92!F<F]M(&UY(&-A;&5N9&%R(BD@+B`G/"]O<'1I;VX^
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"@H@("`@("`@("1S=6UM87)Y(#T@)'9E=F5N="T^9V5T071T<FEB=71E*"=3
M54U-05)9)RD["B`@("`@("`@:68@*&ES7V$H)'-U;6UA<GDL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@)&1E<V,@/2!S<')I;G1F*"1D97-C+"`D
M<V5N9&5R+"!?*")5;FMN;W=N($UE971I;F<B*2D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&1E<V,@/2!S<')I;G1F*"1D97-C+"`D<V5N9&5R
M+"`D<W5M;6%R>2D["B`@("`@("`@?0H*("`@("`@("`D:'1M;"`N/2`G/&@R
M(&-L87-S/2)H96%D97(B/B<@+B`D9&5S8R`N("<\+V@R/B<["@H@("`@("`@
M(&EF("@D=&AI<RT^7VUS9W,I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]M<V=S6R1I9%T@87,@)&US9RD@>PH@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@)SQP(&-L87-S/2)N;W1I8V4B/B<@+B!(;W)D93HZ:6UG*"=A;&5R
M=',O)R`N("1M<V=;,%T@+B`G+G!N9R<L("<G+"!N=6QL+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("1M<V=;,5T@+B`G/"]P/B<["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S=&%R="`]("1V979E
M;G0M/F=E=$%T=')I8G5T92@G1%135$%25"<I.PH@("`@("`@(&EF("@A:7-?
M82@D<W1A<G0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1S=&%R="DI('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<\
M<#X\<W1R;VYG/B<@+B!?*")3=&%R="(I("X@)SH\+W-T<F]N9SX@)R`N('-T
M<F9T:6UE*"1P<F5F<RT^9V5T5F%L=64H)V1A=&5?9F]R;6%T)RDL(&UK=&EM
M92@P+"`P+"`P+"`D<W1A<G1;)VUO;G1H)UTL("1S=&%R=%LG;61A>2==+"`D
M<W1A<G1;)WEE87(G72DI("X@)SPO<#XG.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQP/CQS=')O;F<^)R`N(%\H
M(E-T87)T(BD@+B`G.CPO<W1R;VYG/B`G("X@<W1R9G1I;64H)'!R969S+3YG
M971686QU92@G9&%T95]F;W)M870G*2`N("<@)R`N("1P<F5F<RT^9V5T5F%L
M=64H)W1I;65?9F]R;6%T)RDL("1S=&%R="D@+B`G/"]P/B<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1E;F0@/2`D=F5V96YT+3YG971!
M='1R:6)U=&4H)T1414Y$)RD["B`@("`@("`@:68@*"%I<U]A*"1E;F0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E;F0I
M*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'`^/'-T<F]N9SXG("X@
M7R@B16YD(BD@+B`G.CPO<W1R;VYG/B`G("X@<W1R9G1I;64H)'!R969S+3YG
M971686QU92@G9&%T95]F;W)M870G*2P@;6MT:6UE*#`L(#`L(#`L("1E;F1;
M)VUO;G1H)UTL("1E;F1;)VUD87DG72P@)&5N9%LG>65A<B==*2D@+B`G/"]P
M/B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`G/'`^/'-T<F]N9SXG("X@7R@B16YD(BD@+B`G.CPO<W1R;VYG/B`G
M("X@<W1R9G1I;64H(B5X("58(BP@)&5N9"D@+B`G/"]P/B<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1S=6T@/2`D=F5V96YT+3YG971!
M='1R:6)U=&4H)U-534U!4EDG*3L*("`@("`@("!I9B`H(6ES7V$H)'-U;2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/'`^/'-T
M<F]N9SXG("X@7R@B4W5M;6%R>2(I("X@)SH\+W-T<F]N9SX@)R`N(&AT;6QS
M<&5C:6%L8VAA<G,H)'-U;2D@+B`G/"]P/B<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&AT;6P@+CT@)SQP/CQS=')O;F<^)R`N(%\H(E-U;6UA
M<GDB*2`N("<Z/"]S=')O;F<^(#QE;3XG("X@7R@B3F]N92(I("X@)SPO96T^
M/"]P/B<["B`@("`@("`@?0H*("`@("`@("`D9&5S8R`]("1V979E;G0M/F=E
M=$%T=')I8G5T92@G1$530U))4%1)3TXG*3L*("`@("`@("!I9B`H(6ES7V$H
M)&1E<V,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)SQP/CQS=')O;F<^)R`N(%\H(D1E<V-R:7!T:6]N(BD@+B`G.CPO<W1R;VYG
M/B`G("X@;FPR8G(H:'1M;'-P96-I86QC:&%R<R@D9&5S8RDI("X@)SPO<#XG
M.PH@("`@("`@('T*"B`@("`@("`@)&QO8R`]("1V979E;G0M/F=E=$%T=')I
M8G5T92@G3$]#051)3TXG*3L*("`@("`@("!I9B`H(6ES7V$H)&QO8RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/'`^/'-T<F]N
M9SXG("X@7R@B3&]C871I;VXB*2`N("<Z/"]S=')O;F<^)R`N(&AT;6QS<&5C
M:6%L8VAA<G,H)&QO8RD@+B`G/"]P/B<["B`@("`@("`@?0H*("`@("`@("`D
M871T96YD965S(#T@)'9E=F5N="T^9V5T071T<FEB=71E*"=!5%1%3D1%12<I
M.PH@("`@("`@("1P87)A;7,@/2`D=F5V96YT+3YG971!='1R:6)U=&4H)T%4
M5$5.1$5%)RP@=')U92D["@H@("`@("`@(&EF("@A:7-?82@D871T96YD965S
M+"`G4$5!4E]%<G)O<B<I("8F("%E;7!T>2@D871T96YD965S*2D@>PH@("`@
M("`@("`@("`D:'1M;"`N/2`G/&@R(&-L87-S/2)S;6%L;&AE861E<B(^)R`N
M(%\H(D%T=&5N9&5E<R(I("X@)SPO:#(^)SL*("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D871T96YD965S*2D@>PH@("`@("`@("`@("`@("`@)&%T=&5N
M9&5E<R`](&%R<F%Y*"1A='1E;F1E97,I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1A8FQE/CQT:&5A9"!C;&%S<STB;&5F=$%L
M:6=N(CX\='(^/'1H/B<@+B!?*").86UE(BD@+B`G/"]T:#X\=&@^)R`N(%\H
M(E)O;&4B*2`N("<\+W1H/CQT:#XG("X@7R@B4W1A='5S(BD@+B`G/"]T:#X\
M+W1R/CPO=&AE860^/'1B;V1Y/B<["B`@("`@("`@("`@(&9O<F5A8V@@*"1A
M='1E;F1E97,@87,@)&ME>2`]/B`D871T96YD964I('L*("`@("`@("`@("`@
M("`@("1A='1E;F1E92`]('!A<G-E7W5R;"@D871T96YD964I.PH@("`@("`@
M("`@("`@("`@)&%T=&5N9&5E(#T@)&%T=&5N9&5E6R=P871H)UT["@H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)&ME>5U;)T-.)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&%T=&5N9&5E(#T@)'!A<F%M<ULD:V5Y
M75LG0TXG73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M<F]L92`](%\H(E)E<75I<F5D(%!A<G1I8VEP86YT(BD["B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'!A<F%M<ULD:V5Y75LG4D],12==*2D@>PH@("`@
M("`@("`@("`@("`@("`@('-W:71C:"`H)'!A<F%M<ULD:V5Y75LG4D],12==
M*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G0TA!25(G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F]L92`](%\H(D-H86ER(%!E<G-O;B(I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G3U!4+5!!4E1)0TE004Y4)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)')O;&4@/2!?*")/<'1I;VYA;"!087)T:6-I<&%N="(I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G3D].+5!!4E1)0TE004Y4)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)')O;&4@/2!?*").;VX@4&%R=&EC:7!A;G0B*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)U)%42U005)424-)4$%.5"<Z"B`@("`@("`@("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`@("`@+R\@06QR96%D>2!S
M970@86)O=F4N"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`D<W1A='5S(#T@7R@B07=A:71I;F<@4F5S<&]N<V4B*3L*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86US6R1K97E=6R=005)44U1!
M5"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^
M7W!A<G1S=&%T5&]3=')I;F<H)'!A<F%M<ULD:V5Y75LG4$%25%-4050G72P@
M)'-T871U<RD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@)SQT<CX\=&0^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&%T=&5N
M9&5E*2`N("<\+W1D/CQT9#XG("X@:'1M;'-P96-I86QC:&%R<R@D<F]L92D@
M+B`G/"]T9#X\=&0^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'-T871U<RD@+B`G
M/"]T9#X\+W1R/B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@
M+CT@)SPO=&)O9'D^/"]T86)L93XG.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1O<'1I;VYS*2!["B`@("`@("`@("`@("1H=&UL("X]("<\:#(@8VQA<W,]
M(G-M86QL:&5A9&5R(CXG("X@7R@B06-T:6]N<R(I("X@)SPO:#(^)R`N"B`@
M("`@("`@("`@("`@("`G/'-E;&5C="!N86UE/2)A8W1I;VY;)R`N("1I9"`N
M("==(CXG("X*("`@("`@("`@("`@("`@(&EM<&QO9&4H(EQN(BP@)&]P=&EO
M;G,I("X*("`@("`@("`@("`@("`@("<\+W-E;&5C=#X@/&EN<'5T('1Y<&4]
M(G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](B<@+B!?*")';R(I("X@
M)R(@+SXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5')A;G-L871E('1H92!087)T:6-I<&%T:6]N
M('-T871U<R!T;R!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=F%L=64@("`@5&AE('9A;'5E(&]F(%!!4E135$%4+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&5F875L="`@5&AE('9A;'5E('1O(')E='5R;B!A<R!D
M969A=6QT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE('1R
M86YS;&%T960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R='-T
M8714;U-T<FEN9R@D=F%L=64L("1D969A=6QT(#T@;G5L;"D*("`@('L*("`@
M("`@("!S=VET8V@@*"1V86QU92D@>PH@("`@("`@(&-A<V4@)T%#0T505$5$
M)SH*("`@("`@("`@("`@<F5T=7)N(%\H(D%C8V5P=&5D(BD["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E("=$14-,24Y%1"<Z"B`@("`@("`@
M("`@(')E='5R;B!?*")$96-L:6YE9"(I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G5$5.5$%4259%)SH*("`@("`@("`@("`@<F5T=7)N
M(%\H(E1E;G1A=&EV96QY($%C8V5P=&5D(BD["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E("=$14Q%1T%4140G.@H@("`@("`@("`@("!R971U
M<FX@7R@B1&5L96=A=&5D(BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=#3TU03$54140G.@H@("`@("`@("`@("!R971U<FX@7R@B0V]M
M<&QE=&5D(BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=)
M3BU04D]#15-3)SH*("`@("`@("`@("`@<F5T=7)N(%\H(DEN(%!R;V-E<W,B
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)TY%1413+4%#
M5$E/3B<Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(&ES
M7VYU;&PH)&1E9F%U;'0I(#\@7R@B3F5E9',@06-T:6]N(BD@.B`D9&5F875L
M=#L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+TU)344O5FEE=V5R+VUU;'1I<&%R
M="YP:'``````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S(U`#$P-#$W,S8R
M-S8V`#`R,C4P-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($E-4%]-24U%7U9I97=E<E]M=6QT
M:7!A<G0@8VQA<W,@:&%N9&QE<R!M=6QT:7!A<G0@;65S<V%G97,@;F]T"B`J
M(')E;F1E<F5D(&)Y(&%N>2!S<&5C:69I8R!-24U%7U9I97=E<BX*("H*("H@
M)$AO<F1E.B!I;7`O;&EB+TU)344O5FEE=V5R+VUU;'1I<&%R="YP:'`L=B`Q
M+C$S+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HU."!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N
M961U/@H@*B!`<VEN8V4@("!)35`@-"XP"B`J($!P86-K86=E($AO<F1E7TU)
M345?5FEE=V5R"B`J+PIC;&%S<R!)35!?34E-15]6:65W97)?;75L=&EP87)T
M(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R
M(&]U="!T:&4@8W5R<F5N=&QY('-E="!C;VYT96YT<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@=VET:"!A(')E9F5R
M96YC92!T;R!A($U)345?0V]N=&5N=',*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!R96YD97)E9"!T97AT(&EN($A434PN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F1E<B@D<&%R86US*0H@("`@>PH@("`@("`@("1C;VYT96YT<R`]
M("8D<&%R86US6S!=.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^;6EM95]P
M87)T+3YG971087)T<R@I(&%S("1P87)T*2!["B`@("`@("`@("`@("1C;VYT
M96YT<RT^8G5I;&1-97-S86=E4&%R="@D<&%R="D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C;VYT96YT+71Y<&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT+71Y<&4@
M;V8@=&AE(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@
M+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M:6(O34E-12]6:65W97(O86QT97)N871I=F4N<&AP````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,34R,C4`,3`T,3<S-C(W-C8`,#(S,#`T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@24U07TU)345?5FEE=V5R7V%L=&5R;F%T:79E(&-L87-S(')E;F1E<G,@
M;W5T(&UE<W-A9V5S(&9R;VT*("H@;75L=&EP87)T+V%L=&5R;F%T:79E(&-O
M;G1E;G0@='EP97,N"B`J"B`J("1(;W)D93H@:6UP+VQI8B]-24U%+U9I97=E
M<B]A;'1E<FYA=&EV92YP:'`L=B`Q+C0U+C$P+C<@,C`P-B\P,2\P,2`R,3HR
M.#HU."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!)35`@-"XP
M"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!)35!?
M34E-15]6:65W97)?86QT97)N871I=F4@97AT96YD<R!-24U%7U9I97=E<B![
M"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="UT>7!E(&]F('1H92!P<F5F
M97)R960@<&%R="X*("`@("`J($1E9F%U;'0Z(&%P<&QI8V%T:6]N+V]C=&5T
M+7-T<F5A;0H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7V-O;G1E;G14>7!E(#T@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A
M;2<["@H@("`@+RHJ"B`@("`@*B!4:&4@86QT97)N871I=F4@240@9F]R('1H
M:7,@<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]A;'1)1"`]("<M)SL*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O
M=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@82!R969E<F5N
M8V4@=&\@82!-24U%7T-O;G1E;G1S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5N9&5R960@=&5X="!I;B!(5$U,+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96YD97(H)'!A<F%M<RD*("`@('L*("`@("`@("`D8V]N=&5N=',@/2`F
M)'!A<F%M<ULP73L*"B`@("`@("`@)&1I<W!L87D@/2!A<G)A>2@I.PH@("`@
M("`@("1D:7-P;&%Y7VED(#T@;G5L;#L*("`@("`@("`D<&%R=$QI<W0@/2`D
M=&AI<RT^;6EM95]P87)T+3YG971087)T<R@I.PH*("`@("`@("`O*B!$969A
M=6QT.B!.;W1H:6YG(&1I<W!L87EE9"X@*B\*("`@("`@("`D=&5X="`](&YU
M;&P["@H@("`@("`@("\J(%=E(&YE960@=&\@;W9E<G)I9&4@=&AE($U)344@
M:V5Y('1O(&5N<W5R92!T:&%T(&]N;'D@;VYE"B`@("`@("`@("`@86QT97)N
M871I=F4@<&%R="!I<R!D:7-P;&%Y960N("HO"B`@("`@("`@)'1H:7,M/E]G
M971!;'1)1"@D8V]N=&5N=',L("1P87)T3&ES="D["@H@("`@("`@("\J($YO
M=R!W92!N965D('1O(')E;6]V92!A;GD@;75L=&EP87)T+VUI>&5D(&5N=')I
M97,@=&AA="!M87D@8F4*("`@("`@("`@("!P<F5S96YT(&EN('1H92!P87)T
M<R!L:7-T+"!S:6YC92!T:&5Y(&%R92!S:6UP;&4@8V]N=&%I;F5R<PH@("`@
M("`@("`@(&9O<B!P87)T<RX@*B\*("`@("`@("`D<&%R=$QI<W0@/2`D=&AI
M<RT^7W)E;6]V94UU;'1I<&%R=$UI>&5D*"1P87)T3&ES="D["@H@("`@("`@
M("\J(%)&0R`R,#0V.B!792!S:&]W('1H92!,05-4(&-H;VEC92!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B`J+PH@("`@("`@(&9O<F5A8V@@*"1P
M87)T3&ES="!A<R`D<&%R="D@>PH@("`@("`@("`@("!I9B`H)&-O;G1E;G1S
M+3YC86Y$:7-P;&%Y26YL:6YE*"1P87)T*2D@>PH@("`@("`@("`@("`@("`@
M)&1I<W!L87E?;&ES=%M=(#T@)'!A<G0["B`@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O*B!792!N965D('1O('-E="!T:&4@<W5M;6%R>2!H
M97)E(&EF('=E(&AA=F4@82!D:7-P;&%Y('!A<G0N("HO"B`@("`@("`@:68@
M*"%E;7!T>2@D9&ES<&QA>5]L:7-T*2D@>PH@("`@("`@("`@("!W:&EL92`H
M(65M<'1Y*"1D:7-P;&%Y7VQI<W0I*2!["B`@("`@("`@("`@("`@("`D9&ES
M<&QA>2`](&%R<F%Y7W!O<"@D9&ES<&QA>5]L:7-T*3L*("`@("`@("`@("`@
M("`@("1T97AT(#T@)&-O;G1E;G1S+3YR96YD97)-24U%4&%R="@D9&ES<&QA
M>2D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T97AT*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=%1Y<&4@/2`D9&ES<&QA
M>2T^9V5T5'EP92@I.PH@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<RT^
M<V5T4W5M;6%R>2@D9&ES<&QA>2P@)W!A<G0G*3L*("`@("`@("`@("`@("`@
M("`@("`D9&ES<&QA>5]I9"`]("1D:7-P;&%Y+3YG971-24U%260H*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4VAO=R!L:6YK<R!T
M;R!A;'1E<FYA=&EV92!P87)T<RX@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D
M=&5X="D@?'P@*&-O=6YT*"1P87)T3&ES="D@/B`Q*2D@>PH@("`@("`@("`@
M("!I9B`H:7-?;G5L;"@D=&5X="DI('L*("`@("`@("`@("`@("`@("1T97AT
M(#T@)SQE;3XG("X@7R@B5&AE<F4@87)E(&YO(&%L=&5R;F%T:79E('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(BD@+B`G/"]E;3XG.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!'96YE<F%T92!T:&4@;&ES
M="!O9B!S=6UM87)I97,@=&\@=7-E+B`J+PH@("`@("`@("`@("`D<W5M;6%R
M>4QI<W0@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<&%R=$QI
M<W0@87,@)'!A<G0I('L*("`@("`@("`@("`@("`@("1I9"`]("1P87)T+3YG
M971-24U%260H*3L*("`@("`@("`@("`@("`@(&EF("@D:60@)B8@*&ES7VYU
M;&PH)&1I<W!L87DI('Q\("@D:60@(3T@)&1I<W!L87E?:60I*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1S=6UM87)Y(#T@)&-O;G1E;G1S+3YP87)T4W5M
M;6%R>2@D<&%R="D["@H@("`@("`@("`@("`@("`@("`@("\J(%=E(&1O;B=T
M('=A;G0@=&\@<VAO=R!T:&4@34E-12!)1"!F;W(@86QT('!A<G1S+B`J+PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'-U;6UA<GDI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D<W5M;6%R>2P@
M,2P@,2D["B`@("`@("`@("`@("`@("`@("`@("`@("1S=6UM87)Y3&ES=%M=
M(#T@)'-U;6UA<GD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!-86ME('-U
M<F4@=&AE<F4@:7,@870@;&5A<W0@;VYE('-U;6UA<GD@8F5F;W)E('-H;W=I
M;F<@=&AE"B`@("`@("`@("`@("`@(&%L=&5R;F%T:79E('!A<G1S+B`J+PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1S=6UM87)Y3&ES="D@)B8*("`@("`@
M("`@("`@("`@("$D8V]N=&5N=',M/G9I97=!<T%T=&%C:&UE;G0H*2`F)@H@
M("`@("`@("`@("`@("`@)'1H:7,M/F=E=$-O;F9I9U!A<F%M*"=S:&]W)RDI
M('L*("`@("`@("`@("`@("`@("1S=&%T=7-?87)R87D@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@)'-T871U<R`](%\H(D%L=&5R;F%T:79E('!A<G1S
M(&9O<B!T:&ES('-E8W1I;VXZ(BD["B`@("`@("`@("`@("`@("!I9B`H)&-O
M;G1E;G1S+3YS:&]W4W5M;6%R>4QI;FMS*"DI('L*("`@("`@("`@("`@("`@
M("`@("`D<W1A='5S("X]("<F;F)S<#LF;F)S<#LG("X@2&5L<#HZ;&EN:R@G
M:6UP)RP@)V%L=&5R;F%T:79E+6US9R<I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)'-T871U<U]A<G)A>5M=(#T@)'-T871U<SL*("`@
M("`@("`@("`@("`@("1S=&%T=7,@/2`G/'1A8FQE(&)O<F1E<CTB,"(@8V5L
M;'-P86-I;F<](C$B(&-E;&QP861D:6YG/2(Q(CXG.PH@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'-U;6UA<GE,:7-T(&%S("1S=6UM87)Y*2!["B`@("`@
M("`@("`@("`@("`@("`@)'-T871U<R`N/2`G/'1R('9A;&EG;CTB;6ED9&QE
M(CXG.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S=6UM87)Y(&%S
M("1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T871U<R`N
M/2`B/'1D/B1V86PF;F)S<#L\+W1D/EQN(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D<W1A='5S("X]("(\+W1R/EQN(CL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1S=&%T=7,@+CT@)SPO=&%B;&4^)SL*("`@("`@
M("`@("`@("`@("1S=&%T=7-?87)R87E;72`]("1S=&%T=7,["B`@("`@("`@
M("`@("`@("`D=&5X="`]("1C;VYT96YT<RT^9F]R;6%T4W1A='5S37-G*"1S
M=&%T=7-?87)R87DL($AO<F1E.CII;6<H)VUI;64O8FEN87)Y+G!N9R<L(%\H
M(DUU;'1I<&%R="]A;'1E<FYA=&EV92(I+"!N=6QL+"`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI+"!F86QS92D@+B`D=&5X
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@3F\@;&]N
M9V5R(&9O<F-E('1H92!A;'1E<FYA=&EV92!-24U%($E$(&9O<B!)35!?0V]N
M=&5N=',@;65T:&]D<RX@*B\*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M86QT240I*2!["B`@("`@("`@("`@("1C;VYT96YT<RT^<V5T34E-14ME>4]V
M97)R:61E*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@
M("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE('1H92!A;'1E<FYA=&EV
M92!)1`H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!-24U%7T-O;G1E;G1S("8D8V]N=&5N=',@($$@34E-15]#
M;VYT96YT<R!O8FIE8W0N"B`@("`@*B!`<&%R86T@87)R87D@)B1P87)T3&ES
M="`@("`@("`@("!4:&4@;&ES="!O9B!P87)T<R!I;B!T:&ES(&%L=&5R;F%T
M:79E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M96-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T06QT240H)B1C;VYT
M96YT<RP@)B1P87)T3&ES="D*("`@('L*("`@("`@("`D86QT240@/2!N=6QL
M.PH@("`@("`@("1O=F5R<FED92`]("1C;VYT96YT<RT^9V5T34E-14ME>4]V
M97)R:61E*"D["@H@("`@("`@(&EF("AI<U]N=6QL*"1O=F5R<FED92DI('L*
M("`@("`@("`@("`@)&%L=$E$(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T26YF
M;W)M871I;VXH)V%L=&5R;F%T:79E)RD["B`@("`@("`@("`@(&EF("@D86QT
M240@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%R
M=$QI<W0@87,@)'!A<G0I('L*("`@("`@("`@("`@("`@("`@("`D86QT240@
M/2`D<&%R="T^9V5T26YF;W)M871I;VXH)V%L=&5R;F%T:79E)RD["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1A;'1)1"`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&%L=$E$("$]/2!F86QS92D@>PH@("`@("`@("`@("`D
M8V]N=&5N=',M/G-E=$U)345+97E/=F5R<FED92@D86QT240I.PH@("`@("`@
M("`@("`D=&AI<RT^7V%L=$E$(#T@)&%L=$E$.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;6]V92!M=6QT:7!A<G0O;6EX960@96YT<FEE
M<R!F<F]M(&%N(&%R<F%Y(&]F($U)345?4&%R=',@86YD(')E<&QA8V4*("`@
M("`J('=I=&@@=&AE(&-O;G1E;G1S(&]F('1H870@<&%R="X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&QI<W0@($$@;&ES="!O9B!-24U%7U!A<G0@;V)J96-T<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!O8FIE8W1S('=I
M=&@@;75L=&EP87)T+VUI>&5D('!A<G1S(')E;6]V960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]R96UO=F5-=6QT:7!A<G1-:7AE9"@D;&ES="D*("`@('L*
M("`@("`@("`D;W5T<'5T(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H
M)&QI<W0@87,@)'!A<G0I('L*("`@("`@("`@("`@)&]U='!U="`](&%R<F%Y
M7VUE<F=E*"1O=71P=70L("@D<&%R="T^9V5T5'EP92@I(#T]("=M=6QT:7!A
M<G0O;6EX960G*2`_("1T:&ES+3Y?<F5M;W9E375L=&EP87)T36EX960H)'!A
M<G0M/F=E=%!A<G1S*"DI(#H@87)R87DH)'!A<G0I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!C;VYT96YT+71Y<&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&UE<W-A9V4N"B`@
M("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R`G87!P;&EC871I;VXO;V-T
M970M<W1R96%M)R!U;G1I;"!A8W1U86P*("`@("`J("`@("`@("`@("`@("`@
M("!C;VYT96YT('1Y<&4@;V8@=&AE(&UE<W-A9V4@8V%N(&)E(&1E=&5R;6EN
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-O;G1E;G14>7!E.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O34E-12]6:65W97(O
M<&MC<S<N<&AP````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#`V-#``
M,3`T,3<S-C(W-C8`,#(Q-3$T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@24U07T)!4T4@
M+B`G+VQI8B]#<GEP="]334E-12YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+TU)344O4W1R=6-T=7)E+G!H<"<["@HO*BH*("H@5&AE($E-4%]-24U%7U9I
M97=E<E]P:V-S-R!C;&%S<R!A;&QO=W,@=FEE=VEN9R]D96-R>7!T:6YG(&]F
M(%,O34E-10H@*B!M97-S86=E<RX*("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S
M('!A<G1S(&]F(%)&0R`R-C,P+"!21D,@,C8S,BP@86YD(%)&0R`R-C,S+@H@
M*@H@*B!4:&ES(&-L87-S(&AA;F1L97,@=&AE(&9O;&QO=VEN9R!-24U%('1Y
M<&5S.@H@*B`@(&%P<&QI8V%T:6]N+W!K8W,W+6UI;64*("H@("!A<'!L:6-A
M=&EO;B]P:V-S-RUS:6=N871U<F4*("H@("!A<'!L:6-A=&EO;B]X+7!K8W,W
M+6UI;64*("H@("!A<'!L:6-A=&EO;B]X+7!K8W,W+7-I9VYA='5R90H@*@H@
M*B`D2&]R9&4Z(&EM<"]L:6(O34E-12]6:65W97(O<&MC<S<N<&AP+'8@,2XV
M."XR+C$X(#(P,#8O,#,O,#(@,3@Z,C8Z-#$@<VQU<V%R>B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&-U<F5C86YT:2YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&-U<F5C86YT:2YO<F<^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA
M9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($E-4%]-24U%7U9I97=E
M<E]P:V-S-R!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J
M($E-4%]334E-12!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!)35!?4TU)
M344*("`@("`J+PH@("`@=F%R("1?:6UP4VUI;64["@H@("`@+RHJ"B`@("`@
M*B!#;&%S<W=I9&4@8V%C:&4@9F]R(&EC;VYS(&9O<B!S=&%T=7,@;65S<V%G
M97,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?:6-O;B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!0;VEN=&5R('1O('1H
M92!-24U%7T-O;G1E;G1S(&ET96TN"B`@("`@*@H@("`@("H@0'9A<B!-24U%
M7T-O;G1E;G1S"B`@("`@*B\*("`@('9A<B`D7V-O;G1E;G1S(#T@;G5L;#L*
M"B`@("`O*BH*("`@("`J($-L87-S=VED92!C86-H92!F;W(@<W1A='5S(&UE
M<W-A9V5S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?<W1A='5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!)
M35!?2&5A9&5R<R!O8FIE8W0@9F]R('1H92!M97-S86=E(&1A=&$N"B`@("`@
M*@H@("`@("H@0'9A<B!)35!?2&5A9&5R<PH@("`@("HO"B`@("!V87(@)%]H
M96%D97)S.PH*("`@("\J*@H@("`@("H@4V]M92!M86EL97)S('-E="!3+TU)
M344@;65S<V%G97,@=&\@86QW87ES(&)E(&%T=&%C:&UE;G1S+B`@2&]W979E
M<BP*("`@("`J(&UO<W0@;V8@=&AE('1I;64@4R]-24U%(&ES('5S960@=&\@
M<V5C=7)E('1H92!C;VYT96YT<R!O9B!T:&4@;65S<V%G92P*("`@("`J('-O
M(&1I<W!L87EI;F<@87,@86X@871T86-H;65N="!M86ME<R!N;R!S96YS92X@
M(%1H97)E9F]R92P@9F]R8V4*("`@("`J('9I97=I;F<@:6YL:6YE("AO<B!A
M="!L96%S="!L970@34E-15]6:65W97(O34E-15]#;VYT96YT<R!M86ME('1H
M90H@("`@("H@9&5T97)M:6YA=&EO;B!O;B!W:&5T:&5R('1H92!D871A(&-A
M;B!B92!V:65W960@:6YL:6YE(&]R(&YO="DN"B`@("`@*@H@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V9O<F-E:6YL:6YE(#T@=')U
M93L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S
M970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($%N(&%R<F%Y('=I=&@@82!R969E<F5N8V4@=&\@82!-24U%7T-O;G1E
M;G1S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@=&5X="!I
M;B!(5$U,+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<RD*
M("`@('L*("`@("`@("`O*B!3970@=&AE($U)345?0V]N=&5N=',@8VQA<W,@
M=F%R:6%B;&4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYT96YT<R`]("8D<&%R
M86US6S!=.PH*("`@("`@("`D;7-G(#T@)R<["@H@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7VEM<%-M:6UE*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VEM
M<%-M:6UE(#T@)FYE=R!)35!?4TU)344H*3L*("`@("`@("!]"@H@("`@("`@
M("\J($-H96-K('1O('-E92!I9B!3+TU)344@<W5P<&]R="!I<R!A=F%I;&%B
M;&4N("HO"B`@("`@("`@)&]P96YS<VQ?8VAE8VL@/2`D=&AI<RT^7VEM<%-M
M:6UE+3YC:&5C:T9O<D]P96Y34TPH*3L*("`@("`@("!I9B`H)$=,3T)!3%-;
M)W!R969S)UTM/F=E=%9A;'5E*"=U<V5?<VUI;64G*2`F)@H@("`@("`@("`@
M("`A:7-?82@D;W!E;G-S;%]C:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`O*B!792!N965D('1O(&EN<V5R="!*879A4V-R:7!T(&-O9&4@
M;F]W(&EF(%,O34E-12!S=7!P;W)T(&ES"B`@("`@("`@("`@("`@(&%C=&EV
M92X@*B\*("`@("`@("`@("`@)&US9R`](%5T:6PZ.F)U9F9E<D]U='!U="AA
M<G)A>2@G2&]R9&4G+"`G861D4V-R:7!T1FEL92<I+"`G<&]P=7`N:G,G*3L*
M("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@='EP92!O9B!M97-S86=E
M(&YO=RX@*B\*("`@("`@("`D='EP92`]("1T:&ES+3Y?9V5T4TU)3454>7!E
M*"D["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C87-E
M("=S:6=N960G.@H@("`@("`@("`@("`@("`@)&US9R`N/2`D=&AI<RT^7V]U
M='!U=%--24U%4VEG;F5D*"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)V5N8W)Y<'1E9"<Z"B`@("`@("`@("`@("`@("`D
M;7-G("X]("1T:&ES+3Y?;W5T<'5T4TU)345%;F-R>7!T960H*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M
M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@2%1-3"!O=71P
M=70@9F]R("=M=6QT:7!A<G0O<VEG;F5D)RP*("`@("`J("=A<'!L:6-A=&EO
M;B]P:V-S-RUS:6=N871U<F4G(&%N9`H@("`@("H@)V%P<&QI8V%T:6]N+W@M
M<&MC<S<M<VEG;F%T=7)E)R!-24U%7U!A<G1S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@2%1-3"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]O=71P=713
M34E-15-I9VYE9"@I"B`@("!["B`@("`@("`@)&-E<G0@/2`D=&5X="`]("<G
M.PH@("`@("`@("1M:6UE(#T@)B1T:&ES+3YM:6UE7W!A<G0["B`@("`@("`@
M)&UI;65T>7!E(#T@)&UI;64M/F=E=%1Y<&4H*3L*("`@("`@("`D86-T:79E
M(#T@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=U<V5?<VUI;64G*3L*
M"B`@("`@("`@)'-I9VYE;F,@/2`D;6EM92T^9V5T26YF;W)M871I;VXH)W-M
M:6UE7W-I9VYE;F,G*3L*("`@("`@("!I9B`H)'-I9VYE;F,I('L*("`@("`@
M("`@("`@)'1H:7,M/E]S=&%T=7-;72`](%\H(E1H:7,@;65S<V%G92!H87,@
M8F5E;B!E;F-R>7!T960@=FEA(%,O34E-12XB*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?:6YI=%-T871U<R@D=&AI<RT^9V5T26-O;B@D;6EM971Y
M<&4I+"!?*")3+TU)344B*2D["B`@("`@("`@)'1H:7,M/E]S=&%T=7-;72`]
M(%\H(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I
M82!3+TU)344N(BD["@H@("`@("`@(&EF("@A)&%C=&EV92D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-T871U<UM=(#T@7R@B4R]-24U%('-U<'!O<G0@:7,@
M;F]T(&5N86)L960@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L
M92!T;R!B92!V97)I9FEE9"XB*3L*("`@("`@("!]"@H@("`@("`@("\J(%-T
M;W)E(%,O34E-12!R97-U;'1S(&EN("1S:6=?<F5S=6QT+B`J+PH@("`@("`@
M("1S:6=?<F5S=6QT(#T@;G5L;#L*("`@("`@("!I9B`H)&UI;65T>7!E(#T]
M("=M=6QT:7!A<G0O<VEG;F5D)RD@>PH@("`@("`@("`@("!I9B`H(21S:6=N
M96YC*2!["B`@("`@("`@("`@("`@("!I9B`H*"1M:6UE240@/2`D;6EM92T^
M9V5T34E-14ED*"DI*2!["B`@("`@("`@("`@("`@("`@("`@)&UI;64M/G-E
M=$-O;G1E;G1S*"1T:&ES+3Y?8V]N=&5N=',M/F=E=$)O9'E087)T*"1M:6UE
M240I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)&UI;64M/G-E=$-O;G1E;G1S*"1T:&ES+3Y?8V]N=&5N=',M/F=E
M=$)O9'DH*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M;6EM92T^<W!L:71#;VYT96YT<R@I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!$871A('1H870@:7,@<VEG;F5D(&%P<&5A<G,@:6X@=&AE(&9I
M<G-T($U)344@<W5B<&%R="X@*B\*("`@("`@("`@("`@)'-I9VYE9%]P87)T
M(#T@)&UI;64M/F=E=%!A<G0H)&UI;64M/F=E=%)E;&%T:79E34E-14ED*#$I
M*3L*("`@("`@("`@("`@)'-I9VYE9%]D871A(#T@<G1R:6TH)'-I9VYE9%]P
M87)T+3YG971#86YO;FEC86Q#;VYT96YT<R@I+"`B7'(B*3L*("`@("`@("`@
M("`@)&UI;65?;65S<V%G92`]("9-24U%7U-T<G5C='5R93HZ<&%R<V5497AT
M34E-14UE<W-A9V4H)'-I9VYE9%]D871A*3L*"B`@("`@("`@("`@("\J(%1H
M92!3+TU)344@<VEG;F%T=7)E(&%P<&5A<G,@:6X@=&AE('-E8V]N9"!-24U%
M('-U8G!A<G0N("HO"B`@("`@("`@("`@("1S=6)P87)T(#T@)&UI;64M/F=E
M=%!A<G0H)&UI;64M/F=E=%)E;&%T:79E34E-14ED*#(I*3L*("`@("`@("`@
M("`@:68@*"$D<W5B<&%R="!\?`H@("`@("`@("`@("`@("`@(6EN7V%R<F%Y
M*"1S=6)P87)T+3YG9714>7!E*"DL(&%R<F%Y*"=A<'!L:6-A=&EO;B]P:V-S
M-RUS:6=N871U<F4G+"`G87!P;&EC871I;VXO>"UP:V-S-RUS:6=N871U<F4G
M*2DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A='5S6UT@/2!?*")4
M:&ES(&UE<W-A9V4@9&]E<R!N;W0@87!P96%R('1O(&)E(&EN('1H92!C;W)R
M96-T(%,O34E-12!F;W)M870N(BD["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H(21A8W1I=F4I('L*("`@("`@("`@("`@)'1H:7,M/E]S=&%T
M=7-;72`](%\H(E,O34E-12!S=7!P;W)T(&ES(&YO="!E;F%B;&5D('-O('1H
M92!C;VYT96YT<R!O9B!T:&ES('-I9VYE9"!M97-S86=E(&-A;FYO="!B92!D
M:7-P;&%Y960N(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&%C=&EV92D@
M>PH@("`@("`@("`@("`D<F%W7W1E>'0@/2`D=&AI<RT^7V=E=%)A=U--24U%
M5&5X="@I.PH@("`@("`@("`@("!I9B`H)'-I9VYE;F,@)B8@)&UI;64M/F=E
M=$EN9F]R;6%T:6]N*"=S;6EM95]F<F]M)RDI('L*("`@("`@("`@("`@("`@
M("1S;6EM95]F<F]M(#T@)&UI;64M/F=E=$EN9F]R;6%T:6]N*"=S;6EM95]F
M<F]M)RD["B`@("`@("`@("`@("`@("`D<F%W7W1E>'0@/2`B1G)O;3H@)'-M
M:6UE7V9R;VU<;B(@+B`D<F%W7W1E>'0["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'-I9U]R97-U;'0@/2`D=&AI<RT^7VEM<%-M:6UE+3YV97)I9GE3
M:6=N871U<F4H)')A=U]T97AT*3L*("`@("`@("`@("`@:68@*"%I<W-E="@D
M<W5B<&%R="DI('L*("`@("`@("`@("`@("`@("1M<V=?9&%T82`]("1T:&ES
M+3Y?:6UP4VUI;64M/F5X=')A8W13:6=N961#;VYT96YT<R@D<F%W7W1E>'0I
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&US9U]D871A+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T=7-;
M72`]("1M<V=?9&%T82T^9V5T365S<V%G92@I.PH@("`@("`@("`@("`@("`@
M("`@("1M:6UE7VUE<W-A9V4@/2`D;6EM93L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&UI;65?;65S<V%G92`]("9-
M24U%7U-T<G5C='5R93HZ<&%R<V5497AT34E-14UE<W-A9V4H)&US9U]D871A
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'1E>'0@/2`D=&AI<RT^7V]U='!U=%-T871U<R@I.PH@("`@("`@("`@
M("`D=&5X="`N/2`D=&AI<RT^7V]U='!U=%--24U%4VEG;F%T=7)E5&5S="@D
M<VEG7W)E<W5L="T^<F5S=6QT+"`D<VEG7W)E<W5L="T^96UA:6PI.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1S:6=?<F5S=6QT+3YC97)T*2D@>PH@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D<VUI;65?9G)O;2D@)B8@:7-S970H
M)'1H:7,M/E]H96%D97)S6R=F<F]M)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'-M:6UE7V9R;VT@/2`D=&AI<RT^7VAE861E<G-;)V9R;VTG73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<VUI
M;65?9G)O;2D@)B8*("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^:&%S365T:&]D*"=C;VYT86-T<R]A9&1&:65L9"<I("8F"B`@
M("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E
M*"=A9&1?<V]U<F-E)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-T871U<UM=(#T@2&]R9&4Z.FQI;FLH)R,G+"`G)RP@;G5L;"P@;G5L;"P@
M)'1H:7,M/E]I;7!3;6EM92T^<V%V95!U8FQI8TME>5523"@D<VEG7W)E<W5L
M="T^8V5R="P@)'-M:6UE7V9R;VTI("X@)R!R971U<FX@9F%L<V4[)RD@+B!S
M<')I;G1F*%\H(D-L:6-K('1O(%-A=F4@4R]-24U%(&-E<G1I9FEC871E(&]F
M("5S(&EN('EO=7(@061D<F5S<R!";V]K(BDL($!H=&UL<W!E8VEA;&-H87)S
M*"1S;6EM95]F<F]M+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H*2DI
M("X@)SPO83XN)SL*("`@("`@("`@("`@("`@("`@("`D=&5X="`N/2`D=&AI
M<RT^7V]U='!U=%-T871U<R@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&UI;65?;65S
M<V%G92DI('L*("`@("`@("`@("`@+RH@5V4@;F5E9"!T;R!S=&EC:R!T:&4@
M;W5T<'5T(&EN=&\@82!-24U%7T-O;G1E;G1S(&]B:F5C="X@*B\*("`@("`@
M("`@("`@)&UC(#T@)FYE=R!-24U%7T-O;G1E;G1S*"1M:6UE7VUE<W-A9V4L
M(&%R<F%Y*"=D;W=N;&]A9"<@/3X@)V1O=VYL;V%D7V%T=&%C:"<L("=V:65W
M)R`]/B`G=FEE=U]A='1A8V@G*2P@87)R87DH)B1T:&ES+3Y?8V]N=&5N=',I
M*3L*("`@("`@("`@("`@)&UC+3YB=6EL9$UE<W-A9V4H*3L*"B`@("`@("`@
M("`@("1T97AT("X]("<\=&%B;&4@8V5L;'!A9&1I;F<](C`B(&-E;&QS<&%C
M:6YG/2(P(CXG("X@)&UC+3YG971-97-S86=E*'1R=64I("X@)SPO=&%B;&4^
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&5X="`]("1T:&ES
M+3Y?;W5T<'5T4W1A='5S*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@2%1-3"!O
M=71P=70@9F]R("=M=6QT:7!A<G0O96YC<GEP=&5D)RP*("`@("`J("=A<'!L
M:6-A=&EO;B]P:V-S-RUM:6UE)R!A;F0*("`@("`J("=A<'!L:6-A=&EO;B]X
M+7!K8W,W+6UI;64G($U)345?4&%R=',N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(
M5$U,(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V]U='!U=%--24U%
M16YC<GEP=&5D*"D*("`@('L*("`@("`@("`D86-T:79E(#T@)$=,3T)!3%-;
M)W!R969S)UTM/F=E=%9A;'5E*"=U<V5?<VUI;64G*3L*("`@("`@("`D;6EM
M92`]("8D=&AI<RT^;6EM95]P87)T.PH@("`@("`@("1M:6UE='EP92`]("1M
M:6UE+3YG9714>7!E*"D["B`@("`@("`@)&US9R`]("<G.PH*("`@("`@("`D
M=&AI<RT^7VEN:713=&%T=7,H)'1H:7,M/F=E=$EC;VXH)&UI;64M/F=E=%1Y
M<&4H*2DL(%\H(E,O34E-12(I*3L*("`@("`@("`D=&AI<RT^7W-T871U<UM=
M(#T@7R@B5&AI<R!M97-S86=E(&AA<R!B965N(&5N8W)Y<'1E9"!V:6$@4R]-
M24U%+B(I.PH*("`@("`@("!I9B`H(21A8W1I=F4I('L*("`@("`@("`@("`@
M)'1H:7,M/E]S=&%T=7-;72`](%\H(E,O34E-12!S=7!P;W)T(&ES(&YO="!C
M=7)R96YT;'D@96YA8FQE9"!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@
M8F4@9&5C<GEP=&5D+B(I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]O
M=71P=713=&%T=7,H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M
M/E]I;7!3;6EM92T^9V5T4&5R<V]N86Q0<FEV871E2V5Y*"DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]S=&%T=7-;72`](%\H(DYO('!E<G-O;F%L('!R:79A
M=&4@:V5Y(&5X:7-T<R!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@
M9&5C<GEP=&5D+B(I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]O=71P
M=713=&%T=7,H*3L*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!W
M92!H879E(&$@<&%S<W!H<F%S92X@*B\*("`@("`@("`D<&%S<W!H<F%S92`]
M("1T:&ES+3Y?:6UP4VUI;64M/F=E=%!A<W-P:')A<V4H*3L*("`@("`@("!I
M9B`H)'!A<W-P:')A<V4@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1U<FP@
M/2`D=&AI<RT^7VEM<%-M:6UE+3YG971*4T]P96Y7:6Y#;V1E*"=O<&5N7W!A
M<W-P:')A<V5?9&EA;&]G)RD["B`@("`@("`@("`@("1T:&ES+3Y?<W1A='5S
M6UT@/2!(;W)D93HZ;&EN:R@G(R<L(%\H(EEO=2!M=7-T(&5N=&5R('1H92!P
M87-S<&AR87-E(&9O<B!Y;W5R(%,O34E-12!P<FEV871E(&ME>2!T;R!V:65W
M('1H:7,@;65S<V%G92(I+"!N=6QL+"!N=6QL+"`D=7)L("X@)R!R971U<FX@
M9F%L<V4[)RD@+B`G/&5M/B<@+B!?*")9;W4@;75S="!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97D@=&\@=FEE=R!T
M:&ES(&UE<W-A9V4B*2`N("<\+V5M/CPO83XN)SL*("`@("`@("`@("`@)&US
M9R`N/2`D=&AI<RT^7V]U='!U=%-T871U<R@I("X*("`@("`@("`@("`@("`@
M("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^)R`N("1U<FP@+B`G
M.SPO<V-R:7!T/B<["B`@("`@("`@("`@(')E='5R;B`D;7-G.PH@("`@("`@
M('T*"B`@("`@("`@)')A=U]T97AT(#T@)'1H:7,M/E]G971287=334E-151E
M>'0H*3L*("`@("`@("`D9&5C<GEP=&5D7V1A=&$@/2`D=&AI<RT^7VEM<%-M
M:6UE+3YD96-R>7!T365S<V%G92@D<F%W7W1E>'0I.PH*("`@("`@("!I9B`H
M:7-?82@D9&5C<GEP=&5D7V1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)'1H:7,M/E]S=&%T=7-;72`]("1D96-R>7!T961?9&%T82T^9V5T
M365S<V%G92@I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]O=71P=713
M=&%T=7,H*3L*("`@("`@("!]"@H@("`@("`@("\J(%=E(&YE960@=&\@8VAE
M8VL@:68@=&AI<R!I<R!A('-I9VYE9"]E;F-R>7!T960@;65S<V%G92X@*B\*
M("`@("`@("`D;6EM95]M97-S86=E(#T@)DU)345?4W1R=6-T=7)E.CIP87)S
M951E>'1-24U%365S<V%G92@D9&5C<GEP=&5D7V1A=&$I.PH@("`@("`@(&EF
M("@D;6EM95]M97-S86=E*2!["B`@("`@("`@("`@("\J($-H96-K(&9O<B!S
M:6=N960@86YD(&5N8V]D960@9&%T82X@*B\*("`@("`@("`@("`@:68@*&EN
M7V%R<F%Y*"1M:6UE7VUE<W-A9V4M/F=E=%1Y<&4H*2P@87)R87DH)VUU;'1I
M<&%R="]S:6=N960G+"`G87!P;&EC871I;VXO<&MC<S<M;6EM92<L("=A<'!L
M:6-A=&EO;B]X+7!K8W,W+6UI;64G*2DI('L*("`@("`@("`@("`@("`@("1M
M:6UE7VUE<W-A9V4M/G-E=$-O;G1E;G1S*"1D96-R>7!T961?9&%T82D["B`@
M("`@("`@("`@("`@("`D;6EM95]M97-S86=E+3YS<&QI=$-O;G1E;G1S*"D[
M"B`@("`@("`@("`@("`@("`D;6EM95]M97-S86=E+3YS971);F9O<FUA=&EO
M;B@G<VUI;65?<VEG;F5N8R<L('1R=64I.PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULG9G)O;2==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1M:6UE7VUE<W-A9V4M/G-E=$EN9F]R;6%T:6]N*"=S;6EM
M95]F<F]M)RP@)'1H:7,M/E]H96%D97)S6R=F<F]M)UTI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&US9R`N/2`D=&AI<RT^7V]U='!U=%-T871U<R@I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O*B!792!N965D('1O('-T:6-K('1H92!O=71P=70@
M:6YT;R!A($U)345?0V]N=&5N=',@;V)J96-T+B`J+PH@("`@("`@("`@("`D
M;6,@/2`F;F5W($U)345?0V]N=&5N=',H)&UI;65?;65S<V%G92P@87)R87DH
M)V1O=VYL;V%D)R`]/B`G9&]W;FQO861?871T86-H)RP@)W9I97<G(#T^("=V
M:65W7V%T=&%C:"<I+"!A<G)A>2@F)'1H:7,M/E]C;VYT96YT<RDI.PH@("`@
M("`@("`@("`D;6,M/F)U:6QD365S<V%G92@I.PH@("`@("`@("`@("`D;7-G
M("X]("<\=&%B;&4@8V5L;'!A9&1I;F<](C`B(&-E;&QS<&%C:6YG/2(P(CXG
M("X@)&UC+3YG971-97-S86=E*'1R=64I("X@)SPO=&%B;&4^)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E
M>'0O1FEL=&5R+G!H<"<["B`@("`@("`@("`@("1M<V<@+CT@)'1H:7,M/E]O
M=71P=713=&%T=7,H*2`N"B`@("`@("`@("`@("`@("`G/'-P86X@8VQA<W,]
M(F9I>&5D(CXG("X@5&5X=%]&:6QT97(Z.F9I;'1E<B@D9&5C<GEP=&5D7V1A
M=&$L("=T97AT,FAT;6PG+"!A<G)A>2@G<&%R<V5L979E;"<@/3X@5$585%](
M5$U,7U-93E1!6"DI("X@)SPO<W!A;CXG.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&5X
M="]H=&UL(&%S('1H92!C;VYT96YT+71Y<&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(")T97AT+VAT;6PB(&-O;G-T86YT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E
M>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&AE861E<G,@;V8@=&AE(%,O34E-
M12!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5T4F%W4TU)345497AT*"D*("`@('L*("`@
M("`@("`D;6EM92`]("8D=&AI<RT^;6EM95]P87)T.PH*("`@("`@("`D;6EM
M92T^<V5T0V]N=&5N=',H)'1H:7,M/E]C;VYT96YT<RT^9V5T0F]D>2@I*3L*
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V-O;G1E;G1S+"`G24U07T-O;G1E
M;G1S)RD@)B8*("`@("`@("`@("`@*"@D;6EM92T^9V5T34E-14ED*"D@/3T@
M,"D@?'P*("`@("`@("`@("`@("@D;6EM92T^<W!L:71#;VYT96YT<R@I(#T]
M(&9A;'-E*2DI('L*("`@("`@("`@("`@)&EM<%]H96%D97)S(#T@)B1T:&ES
M+3Y?8V]N=&5N=',M/F=E=$AE861E<D]B*"D["B`@("`@("`@("`@("1T:&ES
M+3Y?:&5A9&5R<R`]($U)345?4W1R=6-T=7)E.CIP87)S94U)345(96%D97)S
M*"1I;7!?:&5A9&5R<RT^9V5T2&5A9&5R5&5X="@I+"!T<G5E+"!T<G5E*3L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=',M/F9U;&Q-97-S
M86=E5&5X="@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92!)35!?0D%312`N("<O;&EB+TU)344O2&5A9&5R<RYP:'`G.PH@
M("`@("`@("`@("`D:&5A9&5R7W1E>'0@/2`D;6EM92T^9V5T0V%N;VYI8V%L
M0V]N=&5N=',H*3L*("`@("`@("`@("`@)&AE861E<E]T97AT(#T@<W5B<W1R
M*"1H96%D97)?=&5X="P@,"P@<W1R<&]S*"1H96%D97)?=&5X="P@(EQR7&Y<
M<EQN(BDI.PH@("`@("`@("`@("`D=&AI<RT^7VAE861E<G,@/2!-24U%7U-T
M<G5C='5R93HZ<&%R<V5-24U%2&5A9&5R<R@D:&5A9&5R7W1E>'0L('1R=64L
M('1R=64I.PH*("`@("`@("`@("`@)&EM<%]H96%D97)S(#T@;F5W($E-4%](
M96%D97)S*"D["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E
M<G-;)V-O;G1E;G0M='EP92==*2D@>PH@("`@("`@("`@("`@("`@)&EM<%]H
M96%D97)S+3YA9&1(96%D97(H)T-O;G1E;G0M5'EP92<L("1T:&ES+3Y?:&5A
M9&5R<ULG8V]N=&5N="UT>7!E)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)V9R;VTG72DI('L*("`@
M("`@("`@("`@("`@("1I;7!?:&5A9&5R<RT^861D2&5A9&5R*"=&<F]M)RP@
M)'1H:7,M/E]H96%D97)S6R=F<F]M)UTI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)W1O)UTI*2!["B`@
M("`@("`@("`@("`@("`D:6UP7VAE861E<G,M/F%D9$AE861E<B@G5&\G+"`D
M=&AI<RT^7VAE861E<G-;)W1O)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!R971U<FX@)&EM<%]H96%D97)S+3YT;U-T<FEN9R@I("X@)&UI;64M
M/G1O0V%N;VYI8V%L4W1R:6YG*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M(%9A<FEO=7,@9F]R;6%T=&EN9R!H96QP97(@9G5N8W1I;VYS+B`J+PH@("`@
M9G5N8W1I;VX@7VEN:713=&%T=7,H)'-R8RP@)&%L="`]("<G*0H@("`@>PH@
M("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?:6-O;BDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]I8V]N(#T@2&]R9&4Z.FEM9R@D<W)C+"`D86QT+"`G:&5I
M9VAT/2(Q-B(@=VED=&@](C$V(B<L("<G*2`N("<F;F)S<#LG.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!?;W5T<'5T4W1A='5S*"D*("`@('L*
M("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7W-T871U<RDI('L*("`@("`@("`@("`@)&]U='!U="`]("1T:&ES+3Y?
M8V]N=&5N=',M/F9O<FUA=%-T871U<TUS9R@D=&AI<RT^7W-T871U<RP@)'1H
M:7,M/E]I8V]N*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]I8V]N(#T@
M;G5L;#L*("`@("`@("`D=&AI<RT^7W-T871U<R`](&%R<F%Y*"D["B`@("`@
M("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE
M<F%T97,@2%1-3"!O=71P=70@9F]R('1H92!3+TU)344@<VEG;F%T=7)E('1E
M<W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<F5S=6QT("!297-U;'0@<W1R:6YG(&]F('1H
M92!3+TU)344@;W5T<'5T(&-O;F-E<FYI;F<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE('-I9VYA='5R92!T97-T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D96UA:6P@("!4:&4@96UA:6P@;V8@=&AE('-E;F1E<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@;W5T<'5T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?;W5T<'5T4TU)3453:6=N871U<F5497-T
M*"1R97-U;'0L("1E;6%I;"D*("`@('L*("`@("`@("`D=&5X="`]("<G.PH*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(&EF("@D<F5S=6QT+3YG971#;V1E*"D@/3T@)VAO<F1E+G=A
M<FYI;F<G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN:713=&%T=7,H
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I("X@
M)R]A;&5R=',O=V%R;FEN9RYP;F<G+"!?*")787)N:6YG(BDI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I;FET4W1A
M='5S*"1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G
M*2`N("<O86QE<G1S+V5R<F]R+G!N9R<L(%\H(D5R<F]R(BDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2`D<F5S=6QT+3YG971-97-S
M86=E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]I
M;FET4W1A='5S*"1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G
M:&]R9&4G*2`N("<O86QE<G1S+W-U8V-E<W,N<&YG)RP@7R@B4W5C8V5S<R(I
M*3L*("`@("`@("`@("`@+RH@5&AI<R!M97-S86=E(&AA<R!B965N('9E<FEF
M:65D(&)U="!T:&5R92!W87,@;F\@;W5T<'5T"B`@("`@("`@("`@("`@(&9R
M;VT@=&AE(%!'4"!P<F]G<F%M+B`J+PH@("`@("`@("`@("!I9B`H96UP='DH
M)')E<W5L="D@?'P@*"1R97-U;'0@/3T]('1R=64I*2!["B`@("`@("`@("`@
M("`@("1E;6%I;"`]("AI<U]A<G)A>2@D96UA:6PI*2`_(&EM<&QO9&4H)RP@
M)RP@)&5M86EL*3H@)&5M86EL.PH@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M<W!R:6YT9BA?*")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"X@4V5N
M9&5R.B`E<RXB*2P@:'1M;'-P96-I86QC:&%R<R@D96UA:6PI*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]497AT+T9I;'1E<BYP:'`G.PH*("`@("`@("`D=&AI<RT^7W-T871U<UM=
M(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D<F5S=6QT+"`G=&5X=#)H=&UL)RP@
M87)R87DH)W!A<G-E;&5V96PG(#T^(%1%6%1?2%1-3%].3TA434PI*3L*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T<'5T4W1A='5S*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296YD97(@;W5T(&%T=&%C:&UE;G0@:6YF;W)M871I
M;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R
M<F%Y('=I=&@@82!R969E<F5N8V4@=&\@82!-24U%7T-O;G1E;G1S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@=&5X="!I;B!(5$U,+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)!='1A8VAM96YT26YF;R@D<&%R
M86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N=&5N=',@/2`F)'!A<F%M
M<ULP73L*"B`@("`@("`@)'1Y<&4@/2`D=&AI<RT^7V=E=%--24U%5'EP92@I
M.PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G
M<VEG;F5D)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A='5S6UT@/2!?
M*")4:&ES(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA
M<R!B965N(&1I9VET86QL>2!S:6=N960@=FEA(%,O34E-12XB*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G96YC<GEP=&5D
M)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A='5S6UT@/2!?*")4:&ES
M(&UE<W-A9V4@8V]N=&%I;G,@86X@871T86-H;65N="!T:&%T(&AA<R!B965N
M(&5N8W)Y<'1E9"!V:6$@4R]-24U%+B(I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-T871U<UM=(#T@<W!R
M:6YT9BA?*")#;&EC:R`E<R!T;R!V:65W('1H92!A='1A8VAM96YT(&EN(&$@
M<V5P87)A=&4@=VEN9&]W+B(I+"`D=&AI<RT^7V-O;G1E;G1S+3YL:6YK5FEE
M=TI3*"1T:&ES+3YM:6UE7W!A<G0L("=V:65W7V%T=&%C:"<L(%\H(DA%4D4B
M*2P@7R@B5FEE=R!A='1A8VAM96YT(&EN(&$@<V5P87)A=&4@=VEN9&]W(BDI
M*3L*("`@("`@("`D=&AI<RT^7VEN:713=&%T=7,H)'1H:7,M/F=E=$EC;VXH
M)'1H:7,M/FUI;65?<&%R="T^9V5T5'EP92@I*2P@7R@B4R]-24U%(BDI.PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V]U='!U=%-T871U<R@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5T97)I;6YE('1H92!3+TU)344@='EP92!O9B!T
M:&4@;65S<V%G92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@16ET:&5R("=E;F-R>7!T960G
M(&]R("=S:6=N960G+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T4TU)3454
M>7!E*"D*("`@('L*("`@("`@("`D='EP92`]("1T:&ES+3YM:6UE7W!A<G0M
M/F=E=%1Y<&4H*3L*("`@("`@("!I9B`H:6Y?87)R87DH)'1Y<&4L(&%R<F%Y
M*"=A<'!L:6-A=&EO;B]P:V-S-RUM:6UE)RP@)V%P<&QI8V%T:6]N+W@M<&MC
M<S<M;6EM92<I*2D@>PH@("`@("`@("`@("`D<VUI;65?='EP92`]("1T:&ES
M+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=S;6EM92UT
M>7!E)RD["B`@("`@("`@("`@(&EF("@D<VUI;65?='EP92`]/2`G<VEG;F5D
M+61A=&$G*2!["B`@("`@("`@("`@("`@("!R971U<FX@)W-I9VYE9"<["B`@
M("`@("`@("`@('T@96QS96EF("@A)'-M:6UE7W1Y<&4@?'P@*"1S;6EM95]T
M>7!E(#T]("=E;G9E;&]P960M9&%T82<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)V5N8W)Y<'1E9"<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G;75L
M=&EP87)T+W-I9VYE9"<Z"B`@("`@("`@("`@(&-A<V4@)V%P<&QI8V%T:6]N
M+W!K8W,W+7-I9VYA='5R92<Z"B`@("`@("`@("`@(&-A<V4@)V%P<&QI8V%T
M:6]N+W@M<&MC<S<M<VEG;F%T=7)E)SH*("`@("`@("`@("`@("`@(')E='5R
M;B`G<VEG;F5D)SL*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-24U%+U9I97=E<B]A<'!L961O
M=6)L92YP:'``````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8Q,@`Q,#0Q-S,V
M,C<V-@`P,C(W-C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!)35!?34E-15]6:65W97)?87!P
M;&5D;W5B;&4@8VQA<W,@:&%N9&QE<R!M=6QT:7!A<G0O87!P;&5D;W5B;&4*
M("H@;65S<V%G97,@8V]N9F]R;6EN9R!T;R!21D,@,3<T,"X*("H*("H@)$AO
M<F1E.B!I;7`O;&EB+TU)344O5FEE=V5R+V%P<&QE9&]U8FQE+G!H<"QV(#$N
M,3,N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C4X(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-
M15]6:65W97(*("HO"F-L87-S($E-4%]-24U%7U9I97=E<E]A<'!L961O=6)L
M92!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@82!R969E
M<F5N8V4@=&\@82!-24U%7T-O;G1E;G1S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<F5N9&5R960@=&5X="!I;B!(5$U,+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H)'!A<F%M<RD*("`@('L*("`@("`@("`D8V]N=&5N=',@
M/2`F)'!A<F%M<ULP73L*("`@("`@("`D=&5X="`]("<G.PH*("`@("`@("`O
M*B!21D,@,3<T,"!;-%TZ(%1H97)E(&%R92!T=V\@<&%R=',@=&\@86X@87!P
M;&5D;W5B;&4@;65S<V%G93H*("`@("`@("`@("`@("@Q*2!A<'!L:6-A=&EO
M;B]A<'!L969I;&4*("`@("`@("`@("`@("@R*2!$871A(&5M8F5D9&5D(&EN
M('1H92!-86,@9FEL92`J+PH*("`@("`@("`O*B!$:7-P;&%Y('1H92!M86-I
M;G1O<V@@9&]W;FQO860@;&EN:RX@*B\*("`@("`@("`D<&%R="`]("1C;VYT
M96YT<RT^9V5T1&5C;V1E9$U)345087)T*"1T:&ES+3YM:6UE7W!A<G0M/F=E
M=%)E;&%T:79E34E-14ED*#$I*3L*("`@("`@("!I9B`H)'!A<G0I('L*("`@
M("`@("`@("`@)'-T871U<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@7R@B
M5&AI<R!M97-S86=E(&-O;G1A:6YS(&$@36%C:6YT;W-H(&9I;&4N(BDL"B`@
M("`@("`@("`@("`@("!S<')I;G1F*%\H(E1H92!-86-I;G1O<V@@<F5S;W5R
M8V4@9F]R:R!C86X@8F4@9&]W;FQO861E9"`E<RXB*2P@)&-O;G1E;G1S+3YL
M:6YK5FEE=TI3*"1P87)T+"`G9&]W;FQO861?871T86-H)RP@7R@B2$5212(I
M+"!?*")4:&4@36%C:6YT;W-H(')E<V]U<F-E(&9O<FLB*2DI+`H@("`@("`@
M("`@("`@("`@7R@B5&AE(&-O;G1E;G1S(&]F('1H92!-86-I;G1O<V@@9FEL
M92!A<F4@8F5L;W<N(BD*("`@("`@("`@("`@*3L*("`@("`@("`@("`@)'1E
M>'0@+CT@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--<V<H)'-T871U<RP@2&]R
M9&4Z.FEM9R@G87!P;&4N<&YG)RP@7R@B36%C:6YT;W-H($9I;&4B*2DL(&9A
M;'-E*3L*("`@("`@("!]"@H@("`@("`@("\J($1I<W!L87D@=&AE(&-O;G1E
M;G0@;V8@=&AE(&9I;&4N("HO"B`@("`@("`@)'!A<G0@/2`D8V]N=&5N=',M
M/F=E=$1E8V]D961-24U%4&%R="@D=&AI<RT^;6EM95]P87)T+3YG971296QA
M=&EV94U)345)9"@R*2D["B`@("`@("`@:68@*"1P87)T*2!["B`@("`@("`@
M("`@("1M:6UE7VUE<W-A9V4@/2`F34E-15]-97-S86=E.CIC;VYV97)T34E-
M15!A<G0H)'!A<G0I.PH@("`@("`@("`@("`D;6,@/2`F;F5W($U)345?0V]N
M=&5N=',H)&UI;65?;65S<V%G92P@87)R87DH)V1O=VYL;V%D)R`]/B`G9&]W
M;FQO861?871T86-H)RP@)W9I97<G(#T^("=V:65W7V%T=&%C:"<I+"!A<G)A
M>2@F)&-O;G1E;G1S*2D["B`@("`@("`@("`@("1M8RT^8G5I;&1-97-S86=E
M*"D["B`@("`@("`@("`@("1T97AT("X]("<\=&%B;&4@8V5L;'-P86-I;F<]
M(C`B/B<@+B`D;6,M/F=E=$UE<W-A9V4H=')U92D@+B`G/"]T86)L93XG.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!C;VYT96YT+71Y<&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&UE
M<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E
M=$-H87)S970H*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-24U%+U9I
M97=E<B]P9W`N<&AP````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T
M,3`S-P`Q,#0Q-S,V,C<V-@`P,C$R-30`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92!)35!?
M0D%312`N("<O;&EB+T-R>7!T+U!'4"YP:'`G.PH*+RHJ"B`J(%1H92!)35!?
M34E-15]6:65W97)?<&=P(&-L87-S(&%L;&]W<R!V:65W:6YG+V1E8W)Y<'1I
M;F<@;V8@4$=0"B`J(&9O<FUA='1E9"!M97-S86=E<RX@(%1H:7,@8VQA<W,@
M:6UP;&5M96YT<R!21D,@,S$U-BX*("H*("H@5&AI<R!C;&%S<R!H86YD;&5S
M('1H92!F;VQL;W=I;F<@34E-12!T>7!E<SH*("H@("!A<'!L:6-A=&EO;B]P
M9W`M96YC<GEP=&EO;@H@*B`@(&%P<&QI8V%T:6]N+W!G<"UK97ES"B`J("`@
M87!P;&EC871I;VXO<&=P+7-I9VYA='5R90H@*@H@*B!4:&ES(&-L87-S(&UA
M>2!A9&0@=&AE(&9O;&QO=VEN9R!P87)A;65T97)S('1O('1H92!54DPZ"B`J
M("`@)W)A=W!G<&ME>2<@+2T@1&ES<&QA>2!T:&4@4$=0(%!U8FQI8R!+97D@
M:6X@<F%W+"!T97AT(&9O<FUA=`H@*@H@*B`D2&]R9&4Z(&EM<"]L:6(O34E-
M12]6:65W97(O<&=P+G!H<"QV(#$N.38N-BXQ,2`R,#`V+S`R+S$P(#$V.C4P
M.C,Q('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!)35`@
M-"XP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!)
M35!?34E-15]6:65W97)?<&=P(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@
M("\J*@H@("`@("H@24U07U!'4"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A
M<B!)35!?4$=0"B`@("`@*B\*("`@('9A<B`D7VEM<%]P9W`["@H@("`@+RHJ
M"B`@("`@*B!4:&4@861D<F5S<R!O9B!T:&4@<V5N9&5R+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V%D9')E<W,["@H@
M("`@+RHJ"B`@("`@*B!0;VEN=&5R('1O('1H92!-24U%7T-O;G1E;G1S(&ET
M96TN"B`@("`@*@H@("`@("H@0'9A<B!-24U%7T-O;G1E;G1S"B`@("`@*B\*
M("`@('9A<B`D7V-O;G1E;G1S(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-L
M87-S=VED92!C86-H92!F;W(@:6-O;G,@9F]R('-T871U<R!M97-S86=E<RX*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I
M8V]N(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-L87-S=VED92!C86-H92!F
M;W(@<W1A='5S(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?<W1A='5S(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J(%1H92!-24U%(&-O;G1E;G0M='EP92!O9B!T:&ES('!A<G0N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?='EP
M92`]("=T97AT+VAT;6PG.PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T
M:&4@8W5R<F5N=&QY('-E="!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@=VET:"!A(')E9F5R96YC92!T
M;R!A($U)345?0V]N=&5N=',*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R
M96YD97)E9"!T97AT(&EN($A434PN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;F1E<B@D<&%R86US*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9BP@)'!R
M969S.PH*("`@("`@("`O*B!3970@=&AE($U)345?0V]N=&5N=',@8VQA<W,@
M=F%R:6%B;&4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYT96YT<R`]("8D<&%R
M86US6S!=.PH*("`@("`@("`D;7-G(#T@)R<["@H@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7VEM<%]P9W`I("8F("%E;7!T>2@D8V]N9ELG=71I;',G75LG
M9VYU<&<G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]I;7!?<&=P(#T@)FYE
M=R!)35!?4$=0*"D["B`@("`@("`@?0H*("`@("`@("`O*B!$971E<FUI;F4@
M=&AE(&%D9')E<W,@;V8@=&AE('-E;F1E<BX@*B\*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]A9&1R97-S*2D@>PH@("`@("`@("`@("`D8F%S95]O8B`]
M("8D=&AI<RT^7V-O;G1E;G1S+3YG971"87-E3V)J96-T4'1R*"D["B`@("`@
M("`@("`@("1T:&ES+3Y?861D<F5S<R`]("1B87-E7V]B+3YG971&<F]M061D
M<F5S<R@I.PH@("`@("`@('T*"B`@("`@("`@+RH@5V4@;F5E9"!T;R!I;G-E
M<G0@2F%V85-C<FEP="!C;V1E(&YO=R!I9B!01U`@<W5P<&]R="!I<R!A8W1I
M=F4N("HO"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG=71I;',G75LG9VYU
M<&<G72D@)B8*("`@("`@("`@("`@)'!R969S+3YG971686QU92@G=7-E7W!G
M<"<I("8F"B`@("`@("`@("`@("%5=&EL.CIG971&;W)M1&%T82@G<F%W<&=P
M:V5Y)RDI('L*("`@("`@("`@("`@)&US9R`](%5T:6PZ.F)U9F9E<D]U='!U
M="AA<G)A>2@G2&]R9&4G+"`G861D4V-R:7!T1FEL92<I+"`G<&]P=7`N:G,G
M*3L*("`@("`@("!]"@H@("`@("`@("\J($9O<B!21D,@,C`Q-2\S,34V+"!T
M:&5R92!A<F4@,R!T>7!E<R!O9B!M97-S86=E<SH*("`@("`@("`@("`@("L@
M(&UU;'1I<&%R="]E;F-R>7!T960*("`@("`@("`@("`@("L@(&UU;'1I<&%R
M="]S:6=N960*("`@("`@("`@("`@("L@(&%P<&QI8V%T:6]N+W!G<"UK97ES
M("HO"B`@("`@("`@<W=I=&-H("@D=&AI<RT^;6EM95]P87)T+3YG9714>7!E
M*"DI('L*("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]P9W`M:V5Y<R<Z"B`@
M("`@("`@("`@("1M<V<@+CT@)'1H:7,M/E]O=71P=7101U!+97DH*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)VUU;'1I<&%R="]S:6=N
M960G.@H@("`@("`@(&-A<V4@)V%P<&QI8V%T:6]N+W!G<"US:6=N871U<F4G
M.@H@("`@("`@("`@("`D;7-G("X]("1T:&ES+3Y?;W5T<'5T4$=04VEG;F5D
M*"D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=M=6QT:7!A
M<G0O96YC<GEP=&5D)SH*("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]P9W`M
M96YC<GEP=&5D)SH*("`@("`@("`@("`@)&US9R`N/2`D=&AI<RT^7V]U='!U
M=%!'4$5N8W)Y<'1E9"@I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D;7-G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@8V]N=&5N="!T>7!E
M(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1Y<&4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'96YE<F%T97,@2%1-3"!O=71P=70@9F]R("=A<'!L
M:6-A=&EO;B]P9W`M:V5Y<R<@34E-15]087)T<RXN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!(5$U,(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V]U='!U
M=%!'4$ME>2@I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF+"`D<')E9G,[
M"@H@("`@("`@("1M:6UE(#T@)B1T:&ES+3YM:6UE7W!A<G0["B`@("`@("`@
M)'!A<G0@/2`D=&AI<RT^7V-O;G1E;G1S+3YG971$96-O9&5D34E-15!A<G0H
M)&UI;64M/F=E=$U)345)9"@I*3L*"B`@("`@("`@:68@*&5M<'1Y*"1C;VYF
M6R=U=&EL<R==6R=G;G5P9R==*2D@>PH@("`@("`@("`@("`D=&5X="`]("<\
M<')E/B<@+B`D<&%R="T^9V5T0V]N=&5N=',H*2`N("<\+W!R93XG.PH@("`@
M("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G<F%W<&=P:V5Y)RDI
M('L*("`@("`@("`@("`@)'1E>'0@/2`D<&%R="T^9V5T0V]N=&5N=',H*3L*
M("`@("`@("`@("`@)'1H:7,M/E]T>7!E(#T@)W1E>'0O<&QA:6XG.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M5&5X="YP:'`G.PH*("`@("`@("`@("`@)'!G<%]K97D@/2`D;6EM92T^9V5T
M0V]N=&5N=',H*3L*"B`@("`@("`@("`@("\J($EN:71I86QI>F4@<W1A='5S
M(&UE<W-A9V4N("HO"B`@("`@("`@("`@("1T:&ES+3Y?:6YI=%-T871U<R@D
M=&AI<RT^9V5T26-O;B@D;6EM92T^9V5T5'EP92@I*2P@7R@B4$=0(BDI.PH@
M("`@("`@("`@("`D=&AI<RT^7W-T871U<UM=(#T@7R@B5&AI<R!01U`@4'5B
M;&EC($ME>2!W87,@871T86-H960@=&\@=&AE(&UE<W-A9V4N(BD["@H@("`@
M("`@("`@("!I9B`H)'!R969S+3YG971686QU92@G=7-E7W!G<"<I("8F"B`@
M("`@("`@("`@("`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^:&%S365T:&]D
M*"=C;VYT86-T<R]A9&1&:65L9"<I("8F"B`@("`@("`@("`@("`@("`D<')E
M9G,M/F=E=%9A;'5E*"=A9&1?<V]U<F-E)RDI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<W1A='5S6UT@/2!(;W)D93HZ;&EN:R@G(R<L(%\H(D-L:6-K
M('1O(%-A=F4@4$=0(%!U8FQI8R!+97D@:6X@>6]U<B!!9&1R97-S(&)O;VLB
M*2P@;G5L;"P@;G5L;"P@)'1H:7,M/E]I;7!?<&=P+3YS879E4'5B;&EC2V5Y
M55),*"1M:6UE*2`N("<@<F5T=7)N(&9A;'-E.R<I("X@7R@B0VQI8VL@=&\@
M4V%V92!01U`@4'5B;&EC($ME>2!I;B!Y;W5R($%D9')E<W,@8F]O:R(I("X@
M)SPO83XN)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W-T
M871U<UM=(#T@<W!R:6YT9BA?*")4:&4@<F%W('1E>'0@;V8@=&AE(%!'4"!0
M=6)L:6,@2V5Y(&-A;B!B92!V:65W960@)7,N(BDL("1T:&ES+3Y?8V]N=&5N
M=',M/FQI;FM6:65W2E,H)'!A<G0L("=V:65W7V%T=&%C:"<L(%\H(DA%4D4B
M*2P@7R@B4$=0(%!U8FQI8R!+97D@5&5X="(I+"!N=6QL+"!A<G)A>2@G<F%W
M<&=P:V5Y)R`]/B`Q*2DI.PH*("`@("`@("`@("`@)'1E>'0@/2`D=&AI<RT^
M7V]U='!U=%-T871U<RAF86QS92D@+@H@("`@("`@("`@("`@("`@)SQS<&%N
M(&-L87-S/2)F:7AE9"(^)R`N(&YL,F)R*'-T<E]R97!L86-E*"<@)RP@)R9N
M8G-P.R<L("1T:&ES+3Y?:6UP7W!G<"T^<&=P4')E='1Y2V5Y*"1P9W!?:V5Y
M*2DI("X@)SPO<W!A;CXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S($A434P@;W5T
M<'5T(&9O<B`G;75L=&EP87)T+W-I9VYE9"<@86YD"B`@("`@*B`G87!P;&EC
M871I;VXO<&=P+7-I9VYA='5R92<@34E-15]087)T<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE($A434P@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;W5T
M<'5T4$=04VEG;F5D*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8L("1P
M<F5F<SL*"B`@("`@("`@)&%C=&EV92`]("@D<')E9G,M/F=E=%9A;'5E*"=U
M<V5?<&=P)RD@)B8@(65M<'1Y*"1C;VYF6R=U=&EL<R==6R=G;G5P9R==*2D[
M"B`@("`@("`@)&UI;64@/2`F)'1H:7,M/FUI;65?<&%R=#L*("`@("`@("`D
M;6EM971Y<&4@/2`D;6EM92T^9V5T5'EP92@I.PH@("`@("`@("1T97AT(#T@
M)R<["@H@("`@("`@("1S:6=N96YC(#T@)&UI;64M/F=E=$EN9F]R;6%T:6]N
M*"=P9W!?<VEG;F5N8R<I.PH@("`@("`@(&EF("@D<VEG;F5N8RD@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-T871U<UM=(#T@7R@B5&AI<R!M97-S86=E(&AA
M<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?:6YI=%-T871U<R@D=&AI<RT^9V5T26-O;B@D;6EM971Y
M<&4I+"!?*")01U`B*2D["B`@("`@("`@)'1H:7,M/E]S=&%T=7-;72`](%\H
M(E1H:7,@;65S<V%G92!H87,@8F5E;B!D:6=I=&%L;'D@<VEG;F5D('9I82!0
M1U`N(BD["@H@("`@("`@(&EF("@A)&%C=&EV92D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W-T871U<UM=(#T@7R@B4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E
M;G1L>2!A8W1I=F4@<V\@=&AE(&1I9VET86P@<VEG;F%T=7)E(&ES('5N86)L
M92!T;R!B92!V97)I9FEE9"XB*3L*("`@("`@("!]"@H@("`@("`@("\J(%-T
M;W)E(%!'4"!R97-U;'1S(&EN("1S:6=?<F5S=6QT.R!S=&]R92!T97AT(&EN
M("1D871A+B`J+PH@("`@("`@("1S:6=?<F5S=6QT(#T@)R<["B`@("`@("`@
M:68@*"1M:6UE='EP92`]/2`G;75L=&EP87)T+W-I9VYE9"<I('L*("`@("`@
M("`@("`@+RH@268@=&AE($U)344@240@:7,@,"P@=V4@;F5E9"!T;R!S=&]R
M92!T:&4@8F]D>2!O9B!T:&4@;65S<V%G90H@("`@("`@("`@("`@("!I;B!T
M:&4@34E-15]087)T(&]B:F5C="X@*B\*("`@("`@("`@("`@:68@*"$D<VEG
M;F5N8RD@>PH@("`@("`@("`@("`@("`@:68@*"@D;6EM94E$(#T@)&UI;64M
M/F=E=$U)345)9"@I*2D@>PH@("`@("`@("`@("`@("`@("`@("1M:6UE+3YS
M971#;VYT96YT<R@D=&AI<RT^7V-O;G1E;G1S+3YG971";V1Y4&%R="@D;6EM
M94E$*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1M:6UE+3YS971#;VYT96YT<R@D=&AI<RT^7V-O;G1E;G1S+3YG
M971";V1Y*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&UI;64M/G-P;&ET0V]N=&5N=',H*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@1&%T82!T:&%T(&ES('-I9VYE9"!A<'!E87)S(&EN('1H92!F
M:7)S="!-24U%('-U8G!A<G0N("HO"B`@("`@("`@("`@("1S=6)P87)T(#T@
M)&UI;64M/F=E=%!A<G0H)&UI;64M/F=E=%)E;&%T:79E34E-14ED*#$I*3L*
M("`@("`@("`@("`@)'-I9VYA='5R95]D871A(#T@<G1R:6TH)'-U8G!A<G0M
M/F=E=$-A;F]N:6-A;$-O;G1E;G1S*"DL(")<<B(I.PH*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C='5R92YP:'`G.PH@("`@
M("`@("`@("`D;6EM95]M97-S86=E(#T@)DU)345?4W1R=6-T=7)E.CIP87)S
M951E>'1-24U%365S<V%G92@D<VEG;F%T=7)E7V1A=&$I.PH*("`@("`@("`@
M("`@+RH@5&AE(%!'4"!S:6=N871U<F4@87!P96%R<R!I;B!T:&4@<V5C;VYD
M($U)344@<W5B<&%R="X@*B\*("`@("`@("`@("`@)'-U8G!A<G0@/2`D;6EM
M92T^9V5T4&%R="@D;6EM92T^9V5T4F5L871I=F5-24U%260H,BDI.PH@("`@
M("`@("`@("!I9B`H)'-U8G!A<G0@)B8@)'-U8G!A<G0M/F=E=%1Y<&4H*2`]
M/2`G87!P;&EC871I;VXO<&=P+7-I9VYA='5R92<I('L*("`@("`@("`@("`@
M("`@(&EF("@D86-T:79E*2!["B`@("`@("`@("`@("`@("`@("`@)'-U8G!A
M<G0M/G1R86YS9F5R1&5C;V1E0V]N=&5N=',H*3L*("`@("`@("`@("`@("`@
M("`@("`D<VEG7W)E<W5L="`]("1T:&ES+3Y?:6UP7W!G<"T^=F5R:69Y4VEG
M;F%T=7)E*"1S:6=N871U<F5?9&%T82P@)'1H:7,M/E]A9&1R97-S+"`D<W5B
M<&%R="T^9V5T0V]N=&5N=',H*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T871U
M<UM=(#T@7R@B5&AI<R!M97-S86=E(&1O97,@;F]T(&%P<&5A<B!T;R!B92!I
M;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T("AA8V-O<F1I;F<@=&\@4D9#(#(P
M,34I+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1M:6UE
M='EP92`]/2`G87!P;&EC871I;VXO<&=P+7-I9VYA='5R92<I('L*("`@("`@
M("`@("`@+RH@1V5T('1H92!S:6=N960@;65S<V%G92!T;R!O=71P=70N("HO
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]-97-S86=E
M+G!H<"<["B`@("`@("`@("`@("1M:6UE7VUE<W-A9V4@/2`F;F5W($U)345?
M365S<V%G92@I.PH@("`@("`@("`@("`D;6EM95]M97-S86=E+3YS9714>7!E
M*"=T97AT+W!L86EN)RD["B`@("`@("`@("`@("1M:6UE+3YT<F%N<V9E<D1E
M8V]D94-O;G1E;G1S*"D["@H@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]I;7!?<&=P*2D@>PH@("`@("`@("`@("`@("`@)&UI;65?;65S<V%G92T^
M<V5T0V]N=&5N=',H)&UI;64M/F=E=$-O;G1E;G1S*"DI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UI;65?;65S<V%G92T^<V5T
M0V]N=&5N=',H)'1H:7,M/E]I;7!?<&=P+3YG9713:6=N961-97-S86=E*"1M
M:6UE*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%!A<W,@=&AE
M('-I9VYE9"!T97AT('-T<F%I9VAT('1H<F]U9V@@=&\@4$=0('!R;V=R86T@
M*B\*("`@("`@("`@("`@:68@*"1A8W1I=F4I('L*("`@("`@("`@("`@("`@
M("1S:6=?<F5S=6QT(#T@)'1H:7,M/E]I;7!?<&=P+3YV97)I9GE3:6=N871U
M<F4H)&UI;64M/F=E=$-O;G1E;G1S*"DL("1T:&ES+3Y?861D<F5S<RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T97AT(#T@)'1H:7,M
M/E]O=71P=713=&%T=7,H*3L*"B`@("`@("`@:68@*"1A8W1I=F4I('L*("`@
M("`@("`@("`@)'1E>'0@+CT@)'1H:7,M/E]O=71P=7101U!3:6=N871U<F54
M97-T*"1S:6=?<F5S=6QT*3L*("`@("`@("!]"@H@("`@("`@("\J(%=E(&YE
M960@=&\@<W1I8VL@=&AE(&]U='!U="!I;G1O(&$@34E-15]#;VYT96YT<R!O
M8FIE8W0N("HO"B`@("`@("`@)&UC(#T@)FYE=R!-24U%7T-O;G1E;G1S*"1M
M:6UE7VUE<W-A9V4L(&%R<F%Y*"=D;W=N;&]A9"<@/3X@)V1O=VYL;V%D7V%T
M=&%C:"<L("=V:65W)R`]/B`G=FEE=U]A='1A8V@G*2P@87)R87DH)B1T:&ES
M+3Y?8V]N=&5N=',I*3L*("`@("`@("`D;6,M/F)U:6QD365S<V%G92@I.PH*
M("`@("`@("!R971U<FX@)'1E>'0@+B`G/'1A8FQE(&-E;&QP861D:6YG/2(P
M(B!C96QL<W!A8VEN9STB,"(^)R`N("1M8RT^9V5T365S<V%G92AT<G5E*2`N
M("<\+W1A8FQE/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@
M2%1-3"!O=71P=70@9F]R("=M=6QT:7!A<G0O96YC<GEP=&5D)R!A;F0*("`@
M("`J("=A<'!L:6-A=&EO;B]P9W`M96YC<GEP=&5D)R!-24U%7U!A<G1S+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P=70N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]O=71P=7101U!%;F-R>7!T960H*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D8V]N9BP@)'!R969S.PH*("`@("`@("`D;6EM92`]("8D=&AI<RT^
M;6EM95]P87)T.PH@("`@("`@("1M:6UE='EP92`]("1M:6UE+3YG9714>7!E
M*"D["B`@("`@("`@)'1E>'0@/2`G)SL*"B`@("`@("`@)'1H:7,M/E]I;FET
M4W1A='5S*"1T:&ES+3YG971)8V]N*"1M:6UE='EP92DL(%\H(E!'4"(I*3L*
M("`@("`@("`D=&AI<RT^7W-T871U<UM=(#T@7R@B5&AI<R!M97-S86=E(&AA
M<R!B965N(&5N8W)Y<'1E9"!W:71H(%!'4"XB*3L*"B`@("`@("`@+RH@4')I
M;G0@;W5T(&UE<W-A9V4@;F]W(&EF(%!'4"!I<R!N;W0@86-T:79E+B`J+PH@
M("`@("`@(&EF("AE;7!T>2@D8V]N9ELG=71I;',G75LG9VYU<&<G72D@?'P@
M(21P<F5F<RT^9V5T5F%L=64H)W5S95]P9W`G*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W-T871U<UM=(#T@7R@B4$=0('-U<'!O<G0@:7,@;F]T(&-U<G)E
M;G1L>2!A8W1I=F4@<V\@=&AE(&UE<W-A9V4@:7,@=6YA8FQE('1O(&)E(&1E
M8W)Y<'1E9"XB*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T<'5T
M4W1A='5S*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?:6UP
M7W!G<"T^9V5T4&5R<V]N86Q0<FEV871E2V5Y*"DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]S=&%T=7-;72`](%\H(DYO('!E<G-O;F%L('!R:79A=&4@:V5Y
M(&5X:7-T<R!S;R!T:&4@;65S<V%G92!I<R!U;F%B;&4@=&\@8F4@9&5C<GEP
M=&5D+B(I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]O=71P=713=&%T
M=7,H*3L*("`@("`@("!]"@H@("`@("`@("1P87-S<&AR87-E(#T@)'1H:7,M
M/E]I;7!?<&=P+3YG971087-S<&AR87-E*"D["B`@("`@("`@:68@*&5M<'1Y
M*"1P87-S<&AR87-E*2D@>PH@("`@("`@("`@("`D=7)L(#T@)'1H:7,M/E]I
M;7!?<&=P+3YG971*4T]P96Y7:6Y#;V1E*"=O<&5N7W!A<W-P:')A<V5?9&EA
M;&]G)RD["B`@("`@("`@("`@("1T:&ES+3Y?<W1A='5S6UT@/2!(;W)D93HZ
M;&EN:R@G(R<L(%\H(EEO=2!M=7-T(&5N=&5R('1H92!P87-S<&AR87-E(&9O
M<B!Y;W5R(%!'4"!P<FEV871E(&ME>2!T;R!V:65W('1H:7,@;65S<V%G92(I
M+"!N=6QL+"!N=6QL+"`D=7)L("X@)R!R971U<FX@9F%L<V4[)RD@+B!?*")9
M;W4@;75S="!E;G1E<B!T:&4@<&%S<W!H<F%S92!F;W(@>6]U<B!01U`@<')I
M=F%T92!K97D@=&\@=FEE=R!T:&ES(&UE<W-A9V4B*2`N("<\+V$^)SL*("`@
M("`@("`@("`@)'1E>'0@+CT@)'1H:7,M/E]O=71P=713=&%T=7,H*2`N"B`@
M("`@("`@("`@("`@("`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B
M/B<@+B`D=7)L("X@)SPO<V-R:7!T/B<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@:68@*"1M:6UE='EP92`]/2`G;75L=&EP87)T+V5N8W)Y<'1E
M9"<I('L*("`@("`@("`@("`@("`@("\J(%!'4"!C;VYT<F]L(&EN9F]R;6%T
M:6]N(&%P<&5A<G,@:6X@=&AE(&9I<G-T($U)344*("`@("`@("`@("`@("`@
M("`@('-U8G!A<G0N(%=E(&1O;B=T(&-U<G)E;G1L>2!N965D('1O(&1O(&%N
M>71H:6YG('=I=&@*("`@("`@("`@("`@("`@("`@('1H:7,@:6YF;W)M871I
M;VXN(%1H92!E;F-R>7!T960@9&%T82!A<'!E87)S(&EN('1H90H@("`@("`@
M("`@("`@("`@("`@<V5C;VYD($U)344@<W5B<&%R="X@*B\*("`@("`@("`@
M("`@("`@("1S=6)P87)T(#T@)&UI;64M/F=E=%!A<G0H)&UI;64M/F=E=%)E
M;&%T:79E34E-14ED*#(I*3L*("`@("`@("`@("`@("`@(&EF("@D<W5B<&%R
M="T^9V5T5'EP92@I(#T]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2![
M"B`@("`@("`@("`@("`@("`@("`@)&1E8W)Y<'1E9%]D871A(#T@)'1H:7,M
M/E]I;7!?<&=P+3YD96-R>7!T365S<V%G92@D=&AI<RT^7V-O;G1E;G1S+3YG
M971";V1Y4&%R="@D<W5B<&%R="T^9V5T34E-14ED*"DI+"`D=&AI<RT^7V%D
M9')E<W,I.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1D96-R>7!T
M961?9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-T871U<UM=(#T@7R@B5&AI<R!M97-S86=E(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(%!'4"!E;F-R>7!T960@;65S<V%G
M92X@17)R;W(Z("(I("X@)&1E8W)Y<'1E9%]D871A+3YG971-97-S86=E*"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T97AT("X]("1T:&ES+3Y?;W5T
M<'5T4W1A='5S*"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@+RH@5V4@;F5E9"!T;R!C:&5C:R!I9B!T
M:&ES(&ES(&$@<VEG;F5D+V5N8W)Y<'1E9`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!M97-S86=E+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<"<["B`@("`@
M("`@("`@("`@("`@("`@("`@("1M:6UE7VUE<W-A9V4@/2`F34E-15]3=')U
M8W1U<F4Z.G!A<G-E5&5X=$U)345-97-S86=E*"1D96-R>7!T961?9&%T82T^
M;65S<V%G92D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A)&UI;65?
M;65S<V%G92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@)'1H:7,M/E]S:6=N961/=71P=70H
M)&1E8W)Y<'1E9%]D871A+3YS:6=?<F5S=6QT*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D96-R>7!T961?;65S<V%G92`](%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H)&1E8W)Y<'1E9%]D871A+3YM97-S86=E+"`D<W5B<&%R
M="T^9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T97AT("X]("<\<W!A;B!C;&%S<STB9FEX960B/B<@+B!497AT7T9I;'1E
M<CHZ9FEL=&5R*"1D96-R>7!T961?;65S<V%G92P@)W1E>'0R:'1M;"<L(&%R
M<F%Y*"=P87)S96QE=F5L)R`]/B!415A47TA434Q?4UE.5$%8*2D@+B`G/"]S
M<&%N/B<["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;6EM971Y<&4@/2`D;6EM95]M97-S
M86=E+3YG9714>7!E*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H*"1M:6UE='EP92`]/2`G;75L=&EP87)T+W-I9VYE9"<I('Q\"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1M:6UE='EP92`]/2`G87!P
M;&EC871I;VXO<&=P+7-I9VYA='5R92<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&UI;65?;65S<V%G92T^<V5T26YF;W)M871I;VXH
M)W!G<%]S:6=N96YC)RP@=')U92D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&UI;65?;65S<V%G92T^<V5T0V]N=&5N=',H)&1E8W)Y<'1E
M9%]D871A+3YM97-S86=E*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;6EM95]M97-S86=E+3YS<&QI=$-O;G1E;G1S*"D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T97AT("X]("1T:&ES+3Y?<VEG;F5D3W5T<'5T
M*"1D96-R>7!T961?9&%T82T^<VEG7W)E<W5L="D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+RH@5V4@;F5E9"!T;R!S=&EC:R!T:&4@;W5T<'5T(&EN=&\@80H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@34E-15]#;VYT96YT<R!O8FIE8W0N
M("HO"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;6,@/2`F;F5W($U)
M345?0V]N=&5N=',H)&UI;65?;65S<V%G92P@87)R87DH)V1O=VYL;V%D)R`]
M/B`G9&]W;FQO861?871T86-H)RP@)W9I97<G(#T^("=V:65W7V%T=&%C:"<I
M+"!A<G)A>2@F)'1H:7,M/E]C;VYT96YT<RDI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&UC+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D;6EM95]M97-S86=E+3YG971);F9O<FUA
M=&EO;B@G<&=P7W-I9VYE;F,G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T97AT("X]("1M8RT^9V5T365S<V%G92AT<G5E*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@)SQT86)L92!C96QL<&%D
M9&EN9STB,"(@8V5L;'-P86-I;F<](C`B/B<@+B`D;6,M/F=E=$UE<W-A9V4H
M=')U92D@+B`G/"]T86)L93XG.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-T871U<UM=(#T@7R@B5&AI<R!M97-S86=E(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!I;B!T:&4@8V]R<F5C="!01U`@9F]R;6%T
M("AA8V-O<F1I;F<@=&\@4D9#(#(P,34I+B(I.PH@("`@("`@("`@("`@("`@
M("`@("1T97AT("X]("1T:&ES+3Y?;W5T<'5T4W1A='5S*"D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D;6EM971Y<&4@/3T@
M)V%P<&QI8V%T:6]N+W!G<"UE;F-R>7!T960G*2!["B`@("`@("`@("`@("`@
M("`D9&5C<GEP=&5D7V1A=&$@/2`D=&AI<RT^7VEM<%]P9W`M/F1E8W)Y<'1-
M97-S86=E*"1M:6UE+3YG971#;VYT96YT<R@I+"`D=&AI<RT^7V%D9')E<W,I
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&1E8W)Y<'1E9%]D871A+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&1E8W)Y<'1E
M9%]M97-S86=E(#T@)&1E8W)Y<'1E9%]D871A+3YG971-97-S86=E*"D["B`@
M("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@)'1H:7,M/E]O=71P=713=&%T
M=7,H*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'1E>'0@+CT@)'1H:7,M/E]S:6=N961/=71P=70H)&1E8W)Y<'1E
M9%]D871A+3YS:6=?<F5S=6QT*3L*("`@("`@("`@("`@("`@("`@("`D9&5C
M<GEP=&5D7VUE<W-A9V4@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D96-R
M>7!T961?9&%T82T^;65S<V%G92P@)&UI;64M/F=E=$-H87)S970H*2D["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH@("`@("`@("`@("`@("`@)'1E
M>'0@+CT@)SQS<&%N(&-L87-S/2)F:7AE9"(^)R`N(%1E>'1?1FEL=&5R.CIF
M:6QT97(H)&1E8W)Y<'1E9%]M97-S86=E+"`G=&5X=#)H=&UL)RP@87)R87DH
M)W!A<G-E;&5V96PG(#T^(%1%6%1?2%1-3%]364Y405@I*2`N("<\+W-P86X^
M)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S($A434P@;W5T
M<'5T(&9O<B!T:&4@4$=0('-I9VYA='5R92!T97-T+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)')E<W5L="`@4F5S=6QT('-T<FEN9R!O9B!T:&4@4$=0(&]U='!U="!C;VYC
M97)N:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S:6=N
M871U<F4@=&5S="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M($A434P@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;W5T<'5T4$=0
M4VEG;F%T=7)E5&5S="@D<F5S=6QT*0H@("`@>PH@("`@("`@("1T97AT(#T@
M)R<["@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET4W1A='5S*"1'3$]"04Q36R=R
M96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2`N("<O86QE<G1S+V5R
M<F]R+G!N9R<L(%\H(D5R<F]R(BDI.PH@("`@("`@("`@("`D<F5S=6QT(#T@
M)')E<W5L="T^9V5T365S<V%G92@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3Y?:6YI=%-T871U<R@D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T26UA9V5$:7(H)VAO<F1E)RD@+B`G+V%L97)T<R]S=6-C97-S+G!N
M9R<L(%\H(E-U8V-E<W,B*2D["B`@("`@("`@("`@("\J(%1H:7,@;65S<V%G
M92!H87,@8F5E;B!V97)I9FEE9"!B=70@=&AE<F4@=V%S(&YO(&]U='!U=`H@
M("`@("`@("`@("`@("!F<F]M('1H92!01U`@<')O9W)A;2X@*B\*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("1R
M97-U;'0@/2!?*")4:&4@;65S<V%G92!H87,@8F5E;B!V97)I9FEE9"XB*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH*("`@("`@("`D=&AI<RT^7W-T
M871U<UM=(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D<F5S=6QT+"`G=&5X=#)H
M=&UL)RP@87)R87DH)W!A<G-E;&5V96PG(#T^(%1%6%1?2%1-3%].3TA434PI
M*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T<'5T4W1A='5S*"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=70@<VEG;F5D(&UE<W-A9V4@<W1A
M='5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)')E<W5L="`@5&AE('-I9VYA='5R92!R97-U
M;'0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($A434P@;W5T<'5T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<VEG;F5D3W5T<'5T*"1R97-U;'0I
M"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-T871U<UM=(#T@7R@B5&AI<R!M97-S86=E(&AA<R!B
M965N(&1I9VET86QL>2!S:6=N960@=FEA(%!'4"XB*3L*("`@("`@("`@("`@
M)'1E>'0@/2`D=&AI<RT^7V]U='!U=%-T871U<R@I("X*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;W5T<'5T4$=04VEG;F%T=7)E5&5S="@D<F5S=6QT*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&5X="`]("1T:&ES+3Y?
M;W5T<'5T4W1A='5S*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1E
M>'0["B`@("!]"@H@("`@+RH@5F%R:6]U<R!F;W)M871T:6YG(&AE;'!E<B!F
M=6YC=&EO;G,@*B\*("`@(&9U;F-T:6]N(%]I;FET4W1A='5S*"1S<F,L("1A
M;'0@/2`G)RD*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7VEC
M;VXI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6-O;B`]($AO<F1E.CII;6<H
M)'-R8RP@)&%L="P@)VAE:6=H=#TB,38B('=I9'1H/2(Q-B(G+"`G)RD@+B`G
M)FYB<W`[)SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7V]U='!U
M=%-T871U<R@D<')I;G1A8FQE(#T@=')U92D*("`@('L*("`@("`@("`D;W5T
M<'5T(#T@)R<["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W-T871U<RDI
M('L*("`@("`@("`@("`@)&]U='!U="`]("1T:&ES+3Y?8V]N=&5N=',M/F9O
M<FUA=%-T871U<TUS9R@D=&AI<RT^7W-T871U<RP@)'1H:7,M/E]I8V]N+"`D
M<')I;G1A8FQE*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]I8V]N(#T@
M;G5L;#L*("`@("`@("`D=&AI<RT^7W-T871U<R`](&%R<F%Y*"D["B`@("`@
M("`@<F5T=7)N("1O=71P=70["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L
M:6(O34E-12]6:65W97(O<W1A='5S+G!H<```````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,30V,#(`,3`T,3<S-C(W-C8`,#(R,#`W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@24U07TU)345?5FEE=V5R7W-T871U<R!C;&%S<R!H86YD;&5S(&UU;'1I
M<&%R="]R97!O<G0@;65S<V%G97,*("H@=&AA="!R969E<B!T;R!M86EL('-Y
M<W1E;2!A9&UI;FES=')A=&EV92!M97-S86=E<R`H4D9#(#,T-C0I+@H@*@H@
M*B`D2&]R9&4Z(&EM<"]L:6(O34E-12]6:65W97(O<W1A='5S+G!H<"QV(#$N
M,3<N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C4X(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-
M15]6:65W97(*("HO"F-L87-S($E-4%]-24U%7U9I97=E<E]S=&%T=7,@97AT
M96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T
M('1H92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!W:71H(&$@<F5F97)E;F-E
M('1O(&$@34E-15]#;VYT96YT<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(')E;F1E<F5D('1E>'0@:6X@2%1-3"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5N9&5R*"1P87)A;7,I"B`@("!["B`@("`@("`@)&-O;G1E;G1S(#T@)B1P
M87)A;7-;,%T["@H@("`@("`@("\J($EF('1H:7,@:7,@82!S=')A:6=H="!M
M97-S86=E+V1E;&EV97)Y+7-T871U<R!P87)T+"!J=7-T(&]U='!U=`H@("`@
M("`@("`@('1H92!T97AT+B`J+PH@("`@("`@(&EF("@D=&AI<RT^;6EM95]P
M87)T+3YG9714>7!E*"D@/3T@)VUE<W-A9V4O9&5L:79E<GDM<W1A='5S)RD@
M>PH@("`@("`@("`@("`D<&%R="`]("9N97<@34E-15]087)T*"=T97AT+W!L
M86EN)RD["B`@("`@("`@("`@("1P87)T+3YS971#;VYT96YT<R@D=&AI<RT^
M;6EM95]P87)T+3YG971#;VYT96YT<R@I*3L*("`@("`@("`@("`@<F5T=7)N
M("<\<')E/B<@+B`D8V]N=&5N=',M/G)E;F1E<DU)345087)T*"1P87)T*2`N
M("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@9VQO8F%L("1R96=I<W1R
M>3L*"B`@("`@("`@+RH@4D9#(#,T-C0@6S)=.B!4:&5R92!A<F4@=&AR964@
M<&%R=',@=&\@82!D96QI=F5R>2!S=&%T=7,*("`@("`@("`@("!M=6QT:7!A
M<G0O<F5P;W)T(&UE<W-A9V4Z"B`@("`@("`@("`@("`H,2D@2'5M86X@<F5A
M9&%B;&4@;65S<V%G90H@("`@("`@("`@("`@*#(I($UA8VAI;F4@<&%R<V%B
M;&4@8F]D>2!P87)T("AM97-S86=E+V1E;&EV97)Y+7-T871U<RD*("`@("`@
M("`@("`@("@S*2!2971U<FYE9"!M97-S86=E("AO<'1I;VYA;"D*"B`@("`@
M("`@("`@26YF;W)M871I;VX@;VX@=&AE(&UE<W-A9V4@<W1A='5S(&ES(&9O
M=6YD(&EN('1H92`G06-T:6]N)R!F:65L9`H@("`@("`@("`@(&QO8V%T960@
M:6X@<&%R="`C,B`H4D9#(#(T-C0@6S(N,RXS72DN($ET(&-A;B!B92!E:71H
M97(@)V9A:6QE9"<L"B`@("`@("`@("`@)V1E;&%Y960G+"`G9&5L:79E<F5D
M)RP@)W)E;&%Y960G+"!O<B`G97AP86YD960G+B`J+PH@("`@("`@("1A8W1I
M;VX@/2!N=6QL.PH@("`@("`@("1P87)T,B`]("1C;VYT96YT<RT^9V5T1&5C
M;V1E9$U)345087)T*"1T:&ES+3YM:6UE7W!A<G0M/F=E=%)E;&%T:79E34E-
M14ED*#(I*3L*("`@("`@("!I9B`H96UP='DH)'!A<G0R*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]E<G)O<DUS9R@D8V]N=&5N=',L("1T:&ES
M+3YM:6UE7W!A<G0I.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H97AP
M;&]D92@B7&XB+"`D<&%R=#(M/F=E=$-O;G1E;G1S*"DI(&%S("1L:6YE*2![
M"B`@("`@("`@("`@(&EF("AS=')S='(H)&QI;F4L("=!8W1I;VXZ)RD@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1L:6YE
M+"`G.B<I("L@,3L*("`@("`@("`@("`@("`@("1A8W1I;VX@/2!S=')T;VQO
M=V5R*'1R:6TH<W5B<W1R*"1L:6YE+"`D<&]S*2DI.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@
M*'-T<G!O<R@D86-T:6]N+"`G("<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`D86-T:6]N(#T@<W5B<W1R*"1A8W1I;VXL(#`L('-T<G!O<R@D86-T:6]N
M+"`G("<I*3L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@8V]R<F5C
M="!T97AT('-T<FEN9W,@9F]R('1H92!A8W1I;VX@='EP92X@*B\*("`@("`@
M("!S=VET8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E("=F86EL960G.@H@
M("`@("`@(&-A<V4@)V1E;&%Y960G.@H@("`@("`@("`@("`D9W)A<&AI8R`]
M("=A;&5R=',O97)R;W(N<&YG)SL*("`@("`@("`@("`@)&%L="`](%\H(D5R
M<F]R(BD["B`@("`@("`@("`@("1M<V<@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@(%\H(D524D]2.B!9;W5R(&UE<W-A9V4@8V]U;&0@;F]T(&)E(&1E;&EV
M97)E9"XB*2P*("`@("`@("`@("`@("`@(%\H(E1H92!M86EL('-E<G9E<B!G
M96YE<F%T960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S86=E.B(I"B`@("`@
M("`@("`@("D["B`@("`@("`@("`@("1D971A:6Q?;7-G(#T@(%\H(D%D9&ET
M:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(&-A;B!B92!V:65W960@)7,N
M(BD["B`@("`@("`@("`@("1D971A:6Q?;7-G7W-T871U<R`](%\H(D%D9&ET
M:6]N86P@;65S<V%G92!E<G)O<B!D971A:6QS(BD["B`@("`@("`@("`@("1M
M<V=?;&EN:R`](%\H(E1H92!T97AT(&]F('1H92!R971U<FYE9"!M97-S86=E
M(&-A;B!B92!V:65W960@)7,N(BD["B`@("`@("`@("`@("1M<V=?;&EN:U]S
M=&%T=7,@/2!?*")4:&4@=&5X="!O9B!T:&4@<F5T=7)N960@;65S<V%G92(I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G9&5L:79E<F5D
M)SH*("`@("`@("!C87-E("=E>'!A;F1E9"<Z"B`@("`@("`@8V%S92`G<F5L
M87EE9"<Z"B`@("`@("`@("`@("1G<F%P:&EC(#T@)V%L97)T<R]S=6-C97-S
M+G!N9R<["B`@("`@("`@("`@("1A;'0@/2!?*")3=6-C97-S(BD["B`@("`@
M("`@("`@("1M<V<@/2!A<G)A>2@*("`@("`@("`@("`@("`@(%\H(EEO=7(@
M;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&1E;&EV97)E9"XB*2P*("`@("`@
M("`@("`@("`@(%\H(E1H92!M86EL('-E<G9E<B!G96YE<F%T960@=&AE(&9O
M;&QO=VEN9R!M97-S86=E.B(I"B`@("`@("`@("`@("D["B`@("`@("`@("`@
M("1D971A:6Q?;7-G(#T@(%\H(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS
M(&-A;B!B92!V:65W960@)7,N(BD["B`@("`@("`@("`@("1D971A:6Q?;7-G
M7W-T871U<R`](%\H(D%D9&ET:6]N86P@;65S<V%G92!D971A:6QS(BD["B`@
M("`@("`@("`@("1M<V=?;&EN:R`](%\H(E1H92!T97AT(&]F('1H92!M97-S
M86=E(&-A;B!B92!V:65W960@)7,N(BD["B`@("`@("`@("`@("1M<V=?;&EN
M:U]S=&%T=7,@/2!?*")4:&4@=&5X="!O9B!T:&4@;65S<V%G92(I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M)&=R87!H:6,@/2`G)SL*("`@("`@("`@("`@)&%L="`]("<G.PH@("`@("`@
M("`@("`D;7-G(#T@)R<["B`@("`@("`@("`@("1D971A:6Q?;7-G(#T@)R<[
M"B`@("`@("`@("`@("1D971A:6Q?;7-G7W-T871U<R`]("<G.PH@("`@("`@
M("`@("`D;7-G7VQI;FL@/2`G)SL*("`@("`@("`@("`@)&US9U]L:6YK7W-T
M871U<R`]("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@4')I;G0@=&AE(&AU
M;6%N(')E861A8FQE(&UE<W-A9V4N("HO"B`@("`@("`@)'!A<G0@/2`D8V]N
M=&5N=',M/F=E=$1E8V]D961-24U%4&%R="@D=&AI<RT^;6EM95]P87)T+3YG
M971296QA=&EV94U)345)9"@Q*2D["B`@("`@("`@:68@*&5M<'1Y*"1P87)T
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]E<G)O<DUS9R@D8V]N
M=&5N=',L("1T:&ES+3YM:6UE7W!A<G0I.PH@("`@("`@('T*"B`@("`@("`@
M)'-T871U<VEM9R`]($AO<F1E.CII;6<H)&=R87!H:6,L("1A;'0L("=H96EG
M:'0](C$V(B!W:61T:#TB,38B)RP@)')E9VES=')Y+3YG971);6%G941I<B@G
M:&]R9&4G*2D["B`@("`@("`@)'1E>'0@/2`D8V]N=&5N=',M/F9O<FUA=%-T
M871U<TUS9R@D;7-G+"`D<W1A='5S:6UG*3L*("`@("`@("`D=&5X="`N/2`G
M/&)L;V-K<75O=&4^)R`N("1C;VYT96YT<RT^<F5N9&5R34E-15!A<G0H)'!A
M<G0I("X@)SPO8FQO8VMQ=6]T93XG("X@(EQN(CL*"B`@("`@("`@+RH@1&ES
M<&QA>2!A(&QI;FL@=&\@;6]R92!D971A:6QE9"!E<G)O<B!M97-S86=E+B`J
M+PH@("`@("`@("1D971A:6QE9%]M<V<@/2!A<G)A>2@*("`@("`@("`@("`@
M<W!R:6YT9B@D9&5T86EL7VUS9RP@)&-O;G1E;G1S+3YL:6YK5FEE=TI3*"1P
M87)T,BP@)W9I97=?871T86-H)RP@7R@B2$5212(I+"`D9&5T86EL7VUS9U]S
M=&%T=7,I*0H@("`@("`@("D["@H@("`@("`@("\J($1I<W!L87D@82!L:6YK
M('1O('1H92!R971U<FYE9"!M97-S86=E+B!4<GD@=&\@9&]W;FQO860@=&AE
M"B`@("`@("`@("`@=&5X="!O9B!T:&4@;65S<V%G92]R9F,X,C(@<&%R="!F
M:7)S="P@:68@:70@97AI<W1S+B`J+PH@("`@("`@(&EF("@H)'!A<G0@/2`D
M8V]N=&5N=',M/F=E=$1E8V]D961-24U%4&%R="@D=&AI<RT^;6EM95]P87)T
M+3YG971296QA=&EV94U)345)9"@S*2DI('Q\"B`@("`@("`@("`@("@D<&%R
M="`]("1C;VYT96YT<RT^9V5T1&5C;V1E9$U)345087)T*"1T:&ES+3YM:6UE
M7W!A<G0M/F=E=%)E;&%T:79E34E-14ED*"<S+C`G*2DI*2!["B`@("`@("`@
M("`@("1D971A:6QE9%]M<V=;72`]('-P<FEN=&8H)&US9U]L:6YK+"`D8V]N
M=&5N=',M/FQI;FM6:65W2E,H)'!A<G0L("=V:65W7V%T=&%C:"<L(%\H(DA%
M4D4B*2P@)&US9U]L:6YK7W-T871U<RP@;G5L;"P@87)R87DH)V-T>7!E)R`]
M/B`G;65S<V%G92]R9F,X,C(G*2DI.PH@("`@("`@('T*"B`@("`@("`@)&EN
M9F]I;6<@/2!(;W)D93HZ:6UG*"=I;F9O7VEC;VXN<&YG)RP@7R@B26YF;R(I
M+"`G:&5I9VAT/2(Q-B(@=VED=&@](C$V(B<L("1R96=I<W1R>2T^9V5T26UA
M9V5$:7(H)VAO<F1E)RDI.PH@("`@("`@("1T97AT("X]("1C;VYT96YT<RT^
M9F]R;6%T4W1A='5S37-G*"1D971A:6QE9%]M<V<L("1I;F9O:6UG+"!F86QS
M92D["@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE(&-O;G1E;G0M='EP92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0M='EP92!O9B!T:&4@;65S<V%G
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA
M<G-E="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!E<G)O
M<B!S=')I;F<@9F]R(&$@;6%L9F]R;65D(%)&0R`S-#8T(&UE<W-A9V4N"B`@
M("`@*@H@("`@("H@0'!A<F%M($U)345?0V]N=&5N=',@)B1C;VYT96YT<R`@
M5&AE($U)345?0V]N=&5N=',@;V)J96-T(&9O<B!T:&ES"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!M97-S86=E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@97)R;W(@;65S<V%G92!S=')I
M;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E<G)O<DUS9R@F)&-O;G1E;G1S
M+"`F)&UI;65?<&%R="D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y
M.PH*("`@("`@("`D97)R7VUS9R`](&%R<F%Y*`H@("`@("`@("`@("!?*")4
M:&ES(&UE<W-A9V4@8V]N=&%I;G,@;6%I;"!D96QI=F5R>2!S=&%T=7,@:6YF
M;W)M871I;VXL(&)U="!T:&4@9F]R;6%T(&]F('1H:7,@;65S<V%G92!I<R!U
M;FMN;W=N+B(I+`H@("`@("`@("`@("!?*")"96QO=R!I<R!T:&4@<F%W('1E
M>'0@;V8@=&AE('-T871U<R!I;F9O<FUA=&EO;B!M97-S86=E+B(I"B`@("`@
M("`@*3L*("`@("`@("`D:6UG(#T@2&]R9&4Z.FEM9R@G86QE<G1S+V5R<F]R
M+G!N9R<L(%\H(D5R<F]R(BDL("=H96EG:'0](C$V(B!W:61T:#TB,38B)RP@
M)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D["@H@("`@("`@("1T
M97AT(#T@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--<V<H)&5R<E]M<V<L("1I
M;6<I.PH@("`@("`@("1T97AT("X]("<\<')E/B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI("X@)SPO<')E
M/B<["@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O;&EB+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<```````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-3<V`#$P-#$W,S8R-S8V`#`R,C(U
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U9I97=E<B]E;G)I8VAE
M9"YP:'`G.PH*+RHJ"B`J(%1H92!)35!?34E-15]6:65W97)?96YR:6-H960@
M8VQA<W,@<F5N9&5R<R!O=70@<&QA:6X@=&5X="!F<F]M"B`J(&5N<FEC:&5D
M(&-O;G1E;G0@=&%G<RP@86QA(%)&0R`Q.#DV"B`J"B`J("1(;W)D93H@:6UP
M+VQI8B]-24U%+U9I97=E<B]E;G)I8VAE9"YP:'`L=B`Q+C,S+C$P+C8@,C`P
M-B\P,2\P,2`R,3HR.#HU."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#$M,C`P-B!%<FEC(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC
M<RYU=&5X87,N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($5R:6,@
M4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^
M"B`J($!S:6YC92`@($E-4"`S+C$*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6
M:65W97(*("HO"F-L87-S($E-4%]-24U%7U9I97=E<E]E;G)I8VAE9"!E>'1E
M;F1S($U)345?5FEE=V5R7V5N<FEC:&5D('L*"B`@("`O*BH*("`@("`J(%)E
M;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@82!R
M969E<F5N8V4@=&\@82!-24U%7T-O;G1E;G1S"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<F5N9&5R960@=&5X="!I;B!(5$U,+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96YD97(H)'!A<F%M<RD*("`@('L*("`@("`@("`D8V]N=&5N
M=',@/2`F)'!A<F%M<ULP73L*"B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@
M("`@("`@:68@*"@D=&5X="`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E
M;G1S*"DI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)&-O;G1E
M;G1S+3YF;W)M871087)T17)R;W(H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B*2D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H=')I;2@D=&5X="D@/3T@)R<I('L*("`@("`@("`@("`@<F5T
M=7)N("1T97AT.PH@("`@("`@('T*"B`@("`@("`@)'1E>'0@/2!P87)E;G0Z
M.G)E;F1E<B@I.PH*("`@("`@("`O+R!(:6=H;&EG:'0@<75O=&5D('!A<G1S
M(&]F(&%N(&5M86EL+@H@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=H
M:6=H;&EG:'1?=&5X="<I*2!["B`@("`@("`@("`@("1T97AT(#T@:6UP;&]D
M92@B7&XB+"!P<F5G7W)E<&QA8V4H)WQ>*%QS*B9G=#LN*RDD?"<L("<\<W!A
M;B!C;&%S<STB<75O=&5D,2(^7#$\+W-P86X^)RP@97AP;&]D92@B7&XB+"`D
M=&5X="DI*3L*("`@("`@("`@("`@)&EN9&5N="`](#$["B`@("`@("`@("`@
M('=H:6QE("AP<F5G7VUA=&-H*"=\)F=T.RA<<S\F9W0[*7LG("X@)&EN9&5N
M="`N("=]?"<L("1T97AT*2D@>PH@("`@("`@("`@("`@("`@)'1E>'0@/2!I
M;7!L;V1E*")<;B(L('!R96=?<F5P;&%C92@G?%X\<W!A;B!C;&%S<STB<75O
M=&5D)R`N("@H*"1I;F1E;G0@+2`Q*2`E(#4I("L@,2D@+B`G(CXH7',J)F=T
M.RA<<S\F9W0[*7LG("X@)&EN9&5N="`N("=]+BLI)'PG+"`G/'-P86X@8VQA
M<W,](G%U;W1E9"<@+B`H*"1I;F1E;G0@)2`U*2`K(#$I("X@)R(^7#$G+"!E
M>'!L;V1E*")<;B(L("1T97AT*2DI.PH@("`@("`@("`@("`@("`@)&EN9&5N
M="LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!$:6T@
M<VEG;F%T=7)E<RX*("`@("`@("!I9B`H)'!R969S+3YG971686QU92@G9&EM
M7W-I9VYA='5R92<I*2!["B`@("`@("`@("`@("1P87)T<R`]('!R96=?<W!L
M:70H)WPH7&XM+5QS*EQN*7PG+"`D=&5X="P@,BP@4%)%1U]34$Q)5%]$14Q)
M35]#05!455)%*3L*("`@("`@("`@("`@)'1E>'0@/2!A<G)A>5]S:&EF="@D
M<&%R=',I.PH@("`@("`@("`@("!I9B`H8V]U;G0H)'!A<G1S*2D@>PH@("`@
M("`@("`@("`@("`@)'1E>'0@+CT@)SQS<&%N(&-L87-S/2)S:6=N871U<F4B
M/B<@+B`D<&%R='-;,%T@+@H@("`@("`@("`@("`@("`@("`@('!R96=?<F5P
M;&%C92@G?&-L87-S/2);7B)=*R)\)RP@)V-L87-S/2)S:6=N871U<F4M9FEX
M960B)RP@)'!A<G1S6S%=*2`N"B`@("`@("`@("`@("`@("`@("`@)SPO<W!A
M;CXG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!&:6QT
M97(@8F%D(&QA;F=U86=E+@H@("`@("`@("1T97AT(#T@24U0.CIF:6QT97)4
M97AT*"1T97AT*3L*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+TU)344O0V]N=&5N=',N<&AP
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4U-S0U`#$P-#$W
M,S8R-S8V`#`R,3`S-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+T-O
M;G1E;G1S+G!H<"<["G)E<75I<F5?;VYC92!)35!?0D%312`N("<O8V]N9FEG
M+VUI;65?9')I=F5R<RYP:'`G.PH*+RHJ"B`J(%1H92!)35!?0V]N=&5N=',Z
M.B!C;&%S<R!E>'1E;F1S('1H92!-24U%7T-O;G1E;G1S.CH@8VQA<W,@86YD
M(&-O;G1A:6YS"B`J(&%L;"!F=6YC=&EO;G,@<F5L871E9"!T;R!H86YD;&EN
M9R!T:&4@8V]N=&5N="!A;F0@;W5T<'5T(&]F(&UA:6P@;65S<V%G97,*("H@
M:6X@24U0+@H@*@H@*B`D2&]R9&4Z(&EM<"]L:6(O34E-12]#;VYT96YT<RYP
M:'`L=B`Q+C$U,RXT+C0P(#(P,#8O,#(O,C,@,#$Z,3DZ-#`@<VQU<V%R>B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R
M;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA
M9V4@24U0"B`J+PIC;&%S<R!)35!?0V]N=&5N=',@97AT96YD<R!-24U%7T-O
M;G1E;G1S('L*"B`@("`O*BH*("`@("`J(%1H92!T97AT(&]F('1H92!B;V1Y
M(&]F('1H92!M97-S86=E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V)O9'D@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H
M92!-24U%('!A<G0@:60@;V8@=&AE(&UE<W-A9V4@8F]D>2X*("`@("`J"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8F]D>5]I9#L*
M"B`@("`O*BH*("`@("`J(%1H92!T97AT(&]F('9A<FEO=7,@34E-12!B;V1Y
M('!A<G1S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?8F]D>7!A<G0@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE
M($E-05`@:6YD97@@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'9A
M<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VEN9&5X.PH*("`@("\J*@H@
M("`@("H@5&AE(&UA:6QB;W@@;V8@=&AE(&-U<G)E;G0@;65S<V%G92X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]M86EL
M8F]X.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&%T=&%C:&UE;G0@<W1R:7!P
M:6YG(&QI;FMS(&)E(&=E;F5R871E9#\*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1?<W1R:7`@/2!F86QS93L*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A
M(&-O;F-R971E($E-4%]#;VYT96YT<R!I;G-T86YC92X*("`@("`J($EF(&%N
M($E-4%]#;VYT96YT<R!O8FIE8W0@:7,@8W5R<F5N=&QY('-T;W)E9"!I;B!T
M:&4@;&]C86P@8V%C:&4L"B`@("`@*B!R96-R96%T92!T:&%T(&]B:F5C="X@
M($5L<V4L(&-R96%T92!A(&YE=R!I;G-T86YC92X*("`@("`J($5N<W5R97,@
M=&AA="!O;FQY(&]N92!)35!?0V]N=&5N=',@:6YS=&%N8V4@9F]R(&%N>2!G
M:79E;B!M97-S86=E(&ES"B`@("`@*B!A=F%I;&%B;&4@870@86YY(&]N92!T
M:6UE+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME
M9"!A<SH*("`@("`J("`@)&EM<%]C;VYT96YT<R`]("9)35!?0V]N=&5N=',Z
M.G-I;F=L971O;B@D:6YD97@I.PH@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&EN9&5X("!4:&4@24U!4"!M97-S86=E(&UA:6QB;W@O:6YD97@N(%1H
M92!I;F1E>"!S:&]U;&0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!B
M92!I;B!T:&4@9F]L;&]W:6YG(&9O<FUA=#H*("`@("`J(#QP<F4^"B`@("`@
M*B!M<V=?:60@24U07TE$6%]315`@;7-G7V9O;&1E<@H@("`@("H@("!M<V=?
M:60@("`@("`]($UE<W-A9V4@:6YD97@@;V8@=&AE(&UE<W-A9V4*("`@("`J
M("`@24U07TE$6%]315`@/2!)35`@8V]N<W1A;G0@=7-E9"!T;R!S97!A<F%T
M92!I;F1E>"]F;VQD97(*("`@("`J("`@;7-G7V9O;&1E<B`@/2!4:&4@9G5L
M;"!F;VQD97(@;F%M92!C;VYT86EN:6YG('1H92!M97-S86=E(&EN9&5X"B`@
M("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N($E-4%]#;VYT96YT
M<R`@5&AE($E-4%]#;VYT96YT<R!O8FIE8W0@;W(@;G5L;"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)G-I;F=L971O;B@D:6YD97@I"B`@("!["B`@("`@("`@
M<W1A=&EC("1I;G-T86YC92`](&%R<F%Y*"D["@H@("`@("`@("1S:6=N871U
M<F4@/2!)35!?0V]N=&5N=',Z.E]C<F5A=&5#86-H94E$*"1I;F1E>"D["B`@
M("`@("`@:68@*&ES<V5T*"1I;G-T86YC95LD<VEG;F%T=7)E72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1I;G-T86YC95LD<VEG;F%T=7)E73L*("`@("`@
M("!]"@H@("`@("`@("1I;G-T86YC95LD<VEG;F%T=7)E72`]("9)35!?0V]N
M=&5N=',Z.F=E=$-A8VAE*"1S:6=N871U<F4I.PH@("`@("`@(&EF("AE;7!T
M>2@D:6YS=&%N8V5;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T
M86YC95LD<VEG;F%T=7)E72`]("9N97<@24U07T-O;G1E;G1S*"1I;F1E>"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E6R1S:6=N871U
M<F5=.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@)&EN("!%:71H97(@86X@:6YD97@@<W1R
M:6YG("AS964@24U07T-O;G1E;G1S.CIS:6YG;&5T;VXH*0H@("`@("H@("`@
M("`@("`@("`@("`@("`@9F]R('1H92!F;W)M870I(&]R(&$@34E-15]-97-S
M86=E(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@24U07T-O;G1E;G1S
M*"1I;BD*("`@('L*("`@("`@("!I9B`H:7-?82@D:6XL("=-24U%7TUE<W-A
M9V4G*2D@>PH@("`@("`@("`@("`D;V(@/2`D:6X["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@;&ES="@D=&AI<RT^7VEN9&5X+"`D=&AI<RT^7VUA
M:6QB;W@I(#T@97AP;&]D92A)35!?24187U-%4"P@)&EN*3L*"B`@("`@("`@
M("`@("\J($=E="!T:&4@34E-15]3=')U8W1U<F4@;V)J96-T(&9O<B!T:&4@
M9VEV96X@:6YD97@N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92!)35!?
M0D%312`N("<O;&EB+TE-05`N<&AP)SL*("`@("`@("`@("`@)&EM<%]I;6%P
M(#T@)DE-4%])34%0.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&EM<%]I
M;6%P+3YC:&%N9V5-8F]X*"1T:&ES+3Y?;6%I;&)O>"D["B`@("`@("`@("`@
M("1S=')U8W1U<F4@/2!`:6UA<%]F971C:'-T<G5C='5R92@D7U-%4U-)3TY;
M)VEM<"==6R=S=')E86TG72P@)'1H:7,M/E]I;F1E>"P@1E1?54E$*3L*("`@
M("`@("`@("`@:68@*"%I<U]O8FIE8W0H)'-T<G5C='5R92DI('L*("`@("`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<"<["B`@("`@
M("`@("`@("1O8B`]("9-24U%7U-T<G5C='5R93HZ<&%R<V4H)'-T<G5C='5R
M92D["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1'3$]"04Q36R=P<F5F
M<R==+3YG971686QU92@G871T86-H;65N=%]D:7-P;&%Y)RDI('L*("`@("`@
M("!C87-E("=L:7-T)SH*("`@("`@("`@("`@)'1H:7,M/E]D:7-P;&%Y5'EP
M92`]($U)345?0T].5$5.5%-?1$E34$Q!65]465!%7TQ)4U0["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E("=I;FQI;F4G.@H@("`@("`@("`@
M("`D=&AI<RT^7V1I<W!L87E4>7!E(#T@34E-15]#3TY414Y44U]$25-03$%9
M7U194$5?24Y,24Y%.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`G8F]T:"<Z"B`@("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>51Y<&4@/2!-
M24U%7T-/3E1%3E137T1)4U!,05E?5%E015]"3U1(.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ34E-15]#;VYT96YT
M<R@D;V(L(&%R<F%Y*"=D;W=N;&]A9"<@/3X@)V1O=VYL;V%D7V%T=&%C:"<L
M("=V:65W)R`]/B`G=FEE=U]A='1A8V@G*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!E;G1I<F4@8F]D>2!O9B!T:&4@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0@;V8@=&AE
M(&)O9'D@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$)O9'DH*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V)O9'DI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8F]D>2`]($!I;6%P7V)O9'DH)%]3
M15-324].6R=I;7`G75LG<W1R96%M)UTL("1T:&ES+3Y?:6YD97@L($947U5)
M1"!\($947U!%14LI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8F]D>3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(')A=R!T
M97AT(&9O<B!O;F4@<V5C=&EO;B!O9B!T:&4@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D:60@(%1H92!)1"!O9B!T:&4@34E-15]0
M87)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5X="!O
M9B!T:&4@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0F]D>5!A<G0H
M)&ED*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]B;V1Y<&%R
M=%LD:61=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V)O9'EP87)T6R1I9%T@
M/2!`:6UA<%]F971C:&)O9'DH)%]315-324].6R=I;7`G75LG<W1R96%M)UTL
M("1T:&ES+3Y?:6YD97@L("1I9"P@1E1?54E$('P@1E1?4$5%2RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]B;V1Y<&%R=%LD
M:61=*2`_("1T:&ES+3Y?8F]D>7!A<G1;)&ED72`Z("<G.PH@("`@?0H*("`@
M("\J*@H@("`@("H@06QL;W<@871T86-H;65N=',@=&\@8F4@<W1R:7!P960@
M8GD@<')O=FED:6YG(&$@;&EN:R!I;B!S=6UM87)Y('9I97<_"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'-T<FEP("!3:&]U;&0@=&AE('-T<FEP
M(&QI;FMS(&)E(&=E;F5R871E9#\*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M4W1R:7!,:6YK*"1S=')I<"`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<W1R:7`@/2`D<W1R:7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&%N(&%R<F%Y('-U;6UA<FEZ:6YG(&$@<&%R="!O9B!A($U)344@;65S
M<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P
M87)T("!3964@34E-15]#;VYT96YT<SHZ<&%R=%-U;6UA<GDH*2X*("`@("`J
M($!P87)A;2!B;V]L96%N("1G=65S<R`@("`@("`@(%-E92!-24U%7T-O;G1E
M;G1S.CIP87)T4W5M;6%R>2@I+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%-E92!-24U%7T-O;G1E;G1S.CIP87)T4W5M;6%R>2@I+@H@("`@("H@
M("`@("`@("`@("`@("`@061D<R!T:&4@9F]L;&]W:6YG(&ME>2!T;R!T:&%T
M(')E='5R;CH*("`@("`J("`@("`@("`@("`@("`@(%LV72`]($-O;7!R97-S
M960@1&]W;FQO860@3&EN:PH@("`@("H@("`@("`@("`@("`@("`@6S==(#T@
M26UA9V4@4V%V92!L:6YK("AI9B!A;&QO=V5D*0H@("`@("H@("`@("`@("`@
M("`@("`@6SA=(#T@4W1R:7`@071T86-H;65N="!,:6YK("AI9B!A;&QO=V5D
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!P87)T4W5M;6%R>2@F)&UI;65?<&%R
M="P@)&=U97-S(#T@9F%L<V4I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF
M+"`D<F5G:7-T<GD["@H@("`@("`@("1S=6UM87)Y(#T@<&%R96YT.CIP87)T
M4W5M;6%R>2@D;6EM95]P87)T+"`D9W5E<W,I.PH*("`@("`@("`O*B!$;VXG
M="!A9&0@97AT<F$@;&EN:W,@:68@;F]T(')E<75E<W1E9"!O<B!I9B!T:&ES
M(&ES(&$@9W5E<W-E9`H@("`@("`@("`@('!A<G0N("HO"B`@("`@("`@:68@
M*"1G=65S<R!\?"`A)'1H:7,M/E]L:6YK<RD@>PH@("`@("`@("`@("!R971U
M<FX@)'-U;6UA<GD["B`@("`@("`@?0H*("`@("`@("`O*B!$:7-P;&%Y('1H
M92!C;VUP<F5S<V5D(&1O=VYL;V%D(&QI;FL@;VYL>2!I9B!S:7IE(&ES(&=R
M96%T97(*("`@("`@("`@("!T:&%N(#(P,"!+0BX@*B\*("`@("`@("!I9B`H
M*"1M:6UE7W!A<G0M/F=E=$)Y=&5S*"D@/B`R,#0X,#`I("8F"B`@("`@("`@
M("`@(%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G>FQI8B<I("8F"B`@("`@("`@
M("`@("@D;6EM95]P87)T+3YG9714>7!E*"D@(3T@)V%P<&QI8V%T:6]N+WII
M<"<I("8F"B`@("`@("`@("`@("@D;6EM95]P87)T+3YG9714>7!E*"D@(3T@
M)V%P<&QI8V%T:6]N+W@M>FEP+6-O;7!R97-S960G*2D@>PH@("`@("`@("`@
M("`D<W5M;6%R>5M=(#T@)'1H:7,M/FQI;FM6:65W*"1M:6UE7W!A<G0L("=D
M;W=N;&]A9%]A='1A8V@G+"!(;W)D93HZ:6UG*"=C;VUP<F5S<V5D+G!N9R<L
M(%\H(D1O=VYL;V%D(&EN("YZ:7`@1F]R;6%T(BDL(&YU;&PL("1R96=I<W1R
M>2T^9V5T26UA9V5$:7(H)VAO<F1E)RD@+B`G+VUI;64G*2P@87)R87DH)VIS
M=&5X="<@/3X@<W!R:6YT9BA?*")$;W=N;&]A9"`E<R!I;B`N>FEP($9O<FUA
M="(I+"`D;6EM95]P87)T+3YG971$97-C<FEP=&EO;BAT<G5E+"!T<G5E*2DL
M("=V:65W<&%R86US)R`]/B!A<G)A>2@G>FEP)R`]/B`Q*2DL('1R=64I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=6UM87)Y6UT@/2!N=6QL
M.PH@("`@("`@('T*"B`@("`@("`@+RH@1&ES<&QA>2!T:&4@:6UA9V4@<V%V
M92!L:6YK(&EF('1H92!R97%U:7)E9"!R96=I<W1R>2!C86QL<R!A<F4*("`@
M("`@("`@*B!P<F5S96YT+B`J+PH@("`@("`@(&EF("@H)&UI;65?<&%R="T^
M9V5T4')I;6%R>51Y<&4H*2`]/2`G:6UA9V4G*2`F)@H@("`@("`@("`@("`D
M<F5G:7-T<GDM/FAA<TUE=&AO9"@G:6UA9V5S+W-E;&5C=$=A;&QE<FEE<R<I
M("8F"B`@("`@("`@("`@("@D:6UA9V5?87!P(#T@)')E9VES=')Y+3YH87--
M971H;V0H)VEM86=E<R]S879E26UA9V4G*2DI('L*("`@("`@("`@("`@2&]R
M9&4Z.F%D9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RD["B`@("`@("`@("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"=S879E:6UA9V4N<&AP)RDL(&%R<F%Y*"=I;F1E>"<@/3X@)'1H:7,M/E]I
M;F1E>"P@)VED)R`]/B`D;6EM95]P87)T+3YG971-24U%260H*2DI.PH@("`@
M("`@("`@("`D<W5M;6%R>5M=(#T@2&]R9&4Z.FQI;FLH)R,G+"!?*")3879E
M($EM86=E(&EN($=A;&QE<GDB*2P@;G5L;"P@;G5L;"P@(G!O<'5P7VEM<"@G
M(B`N("1U<FP@+B`B)RPT-3`L,C`P*3L@<F5T=7)N(&9A;'-E.R(I("X@)SQI
M;6<@<W)C/2(G("X@)')E9VES=')Y+3YG970H)VEC;VXG+"`D:6UA9V5?87!P
M*2`N("<B(&%L=#TB)R`N(%\H(E-A=F4@26UA9V4@:6X@1V%L;&5R>2(I("X@
M)R(@=&ET;&4](B<@+B!?*")3879E($EM86=E(&EN($=A;&QE<GDB*2`N("<B
M("\^/"]A/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-U;6UA
M<GE;72`](&YU;&P["B`@("`@("`@?0H*("`@("`@("`O*B!3=')I<"!T:&4@
M071T86-H;65N=#\@*B\*("`@("`@("!I9B`H)'1H:7,M/E]S=')I<"`F)@H@
M("`@("`@("`@("`A)&UI;65?<&%R="T^9V5T26YF;W)M871I;VXH)W)F8S@R
M,E]P87)T)RDI('L*("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIS96QF57)L
M*'1R=64I.PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ<F5M;W9E4&%R86UE
M=&5R*"1U<FPL(&%R<F%Y*"=A8W1I;VY)1"<L("=I;6%P:60G+"`G:6YD97@G
M*2D["B`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R
M;"P@87)R87DH)V%C=&EO;DE$)R`]/B`G<W1R:7!?871T86-H;65N="<L("=I
M;6%P:60G(#T^("1T:&ES+3Y?9V5T34E-14ME>2@D;6EM95]P87)T+"!F86QS
M92DL("=I;F1E>"<@/3X@)'1H:7,M/F=E=$UE<W-A9V5);F1E>"@I*2D["B`@
M("`@("`@("`@("1S=6UM87)Y6UT@/2!(;W)D93HZ;&EN:R@D=7)L+"!?*")3
M=')I<"!!='1A8VAM96YT(BDL(&YU;&PL(&YU;&PL(")R971U<FX@=VEN9&]W
M+F-O;F9I<FTH)R(@+B!A9&1S;&%S:&5S*%\H(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!015)-04Y%3E1,62!D96QE=&4@=&AI<R!A='1A8VAM96YT/R(I
M*2`N("(G*3LB*2`N($AO<F1E.CII;6<H)V1E;&5T92YP;F<G+"!?*")3=')I
M<"!!='1A8VAM96YT(BDL(&YU;&PL("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI("X@)SPO83XG.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1S=6UM87)Y6UT@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1S=6UM87)Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!54DP@=&\@=&AE('9I97<N<&AP('!A9V4N"B`@("`@*@H@("`@("H@0'!A
M<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@4V5E($U)345?0V]N=&5N=',Z
M.G5R;%9I97<H*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VY)1"`@
M("`@(%-E92!-24U%7T-O;G1E;G1S.CIU<FQ6:65W*"DN"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@("`@("`@("!3964@34E-15]#;VYT96YT<SHZ
M=7)L5FEE=R@I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1L;V%D("`@("`@
M("`@4V5E($U)345?0V]N=&5N=',Z.G5R;%9I97<H*2X*("`@("`J(%1H92!F
M;VQL;W=I;F<@<&%R86UE=&5R(&YA;65S('=I;&P@8F4@;W9E<G=R:71T96X@
M8GD@=&AI<R!F=6YC=&EO;CH*("`@("`J("`@:60L(&EN9&5X+"!M86EL8F]X
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!54DP@=&\@=FEE
M=RYP:'`N"B`@("`@*B\*("`@(&9U;F-T:6]N('5R;%9I97<H)B1M:6UE7W!A
M<G0L("1A8W1I;VY)1"P@)'!A<F%M<R`](&%R<F%Y*"DL("1D;&]A9"`](&9A
M;'-E*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O
M;&EB+U-E87)C:"YP:'`G.PH*("`@("`@("`O*B!!9&0@=&AE(&YE8V5S<V%R
M>2!L;V-A;"!P87)A;65T97)S+B`J+PH@("`@("`@("1P87)A;7,@/2!A<G)A
M>5]M97)G92@D<&%R86US+"!)35`Z.F=E=%-E87)C:%!A<F%M971E<G,H)%]3
M15-324].6R=I;7`G75LG=&AI<VUA:6QB;W@G72DI.PH@("`@("`@("1P87)A
M;7-;)VEN9&5X)UT@/2`D=&AI<RT^7VEN9&5X.PH@("`@("`@(&EF("@A:7-S
M970H)'!A<F%M<ULG;6%I;&)O>"==*2D@>PH@("`@("`@("`@("`D<&%R86US
M6R=M86EL8F]X)UT@/2`D7U-%4U-)3TY;)VEM<"==6R=M86EL8F]X)UT["B`@
M("`@("`@?0H*("`@("`@("`O*B!3:&]U;&0@=&AI<R!B92!A(&1O=VYL;V%D
M(&QI;FL_("HO"B`@("`@("`@)&1L;V%D(#T@*"@D86-T:6]N240@/3T@)V1O
M=VYL;V%D7V%T=&%C:"<I('Q\"B`@("`@("`@("`@("`@("`@("@D86-T:6]N
M240@/3T@)V1O=VYL;V%D7W)E;F1E<B<I('Q\"B`@("`@("`@("`@("`@("`@
M("@D86-T:6]N240@/3T@)W-A=F5?;65S<V%G92<I*3L*"B`@("`@("`@<F5T
M=7)N('!A<F5N=#HZ=7)L5FEE=R@D;6EM95]P87)T+"`D86-T:6]N240L("1P
M87)A;7,L("1D;&]A9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T
M92!A(&QI;FL@=&\@=&AE('9I97<N<&AP('!A9V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@4V5E($U)345?0V]N=&5N
M=',Z.FQI;FM6:65W*"DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D86-T:6]N
M240@("`@("!3964@34E-15]#;VYT96YT<SHZ;&EN:U9I97<H*2X*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@("`@(%-E92!-24U%7T-O;G1E
M;G1S.CIL:6YK5FEE=R@I+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M("`@("`@("`@4V5E($U)345?0V]N=&5N=',Z.FQI;FM6:65W*"DN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%-E92!-24U%7T-O;G1E;G1S.CIL
M:6YK5FEE=R@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YK5FEE=R@F)&UI
M;65?<&%R="P@)&%C=&EO;DE$+"`D=&5X="P@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"1M:6UE7W!A<G0M/F=E=$EN9F]R;6%T:6]N
M*"=A8W1I;VY)1"<I*2!["B`@("`@("`@("`@("1A8W1I;VY)1"`]("1M:6UE
M7W!A<G0M/F=E=$EN9F]R;6%T:6]N*"=A8W1I;VY)1"<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@=&AI<R!I<R!A("=D;W=N;&]A9%]A='1A8V@@;W(@
M)V1O=VYL;V%D7W)E;F1E<B<@;&EN:RP@=V4@9&\@;F]T"B`@("`@("`@("`@
M=V%N="!T;R!S:&]W(&EN(&$@;F5W('=I;F1O=RX@*B\*("`@("`@("`D9&QO
M860@/2`H*"1A8W1I;VY)1"`]/2`G9&]W;FQO861?871T86-H)RD@?'P*("`@
M("`@("`@("`@("`@("`@*"1A8W1I;VY)1"`]/2`G9&]W;FQO861?<F5N9&5R
M)RDI.PH*("`@("`@("`O*B!)9B!D;W=N;&]A9"!A='1A8VAM96YT+"!A9&0@
M=&AE("=T:&ES;6%I;&)O>"<@<&%R86TN("HO"B`@("`@("`@:68@*"1A8W1I
M;VY)1"`]/2`G9&]W;FQO861?871T86-H)RD@>PH@("`@("`@("`@("`D<&%R
M86US6R=V:65W<&%R86US)UU;)W1H:7-M86EL8F]X)UT@/2`D7U-%4U-)3TY;
M)VEM<"==6R=T:&ES;6%I;&)O>"==.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1M:6UE7W!A<G0M/F=E=$EN9F]R;6%T:6]N*"=V:65W<&%R86US)RDI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)&UI;65?<&%R="T^9V5T26YF;W)M871I
M;VXH)W9I97=P87)A;7,G*2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@("`@("1P87)A;7-;)W9I97=P87)A;7,G75LD:V5Y72`]("1V86P["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!P87)E;G0Z
M.FQI;FM6:65W*"1M:6UE7W!A<G0L("1A8W1I;VY)1"P@)'1E>'0L("1P87)A
M;7,L("1D;&]A9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!F=6QL(&UE<W-A9V4@=&5X="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&9U;&P@;65S<V%G92!T97AT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!F=6QL365S<V%G951E>'0H*0H@("`@>PH@("`@("`@("1I;7!?:&5A
M9&5R<R`]("8D=&AI<RT^9V5T2&5A9&5R3V(H*3L*("`@("`@("!R971U<FX@
M)&EM<%]H96%D97)S+3YG971(96%D97)497AT*"D@+B`D=&AI<RT^9V5T0F]D
M>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:&5A9&5R
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N($E-4%](96%D97)S("!4
M:&4@24U07TAE861E<G,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9V5T2&5A9&5R3V(H*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92!)35!?
M0D%312`N("<O;&EB+TU)344O2&5A9&5R<RYP:'`G.PH@("`@("`@("1I;7!?
M:&5A9&5R<R`]("9N97<@24U07TAE861E<G,H)'1H:7,M/E]I;F1E>"D["B`@
M("`@("`@<F5T=7)N("1I;7!?:&5A9&5R<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE($E-05`@:6YD97@@9F]R('1H92!C=7)R96YT(&UE
M<W-A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;65S
M<V%G92!I;F1E>"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T365S<V%G94EN
M9&5X*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]I;F1E>#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E8G5I;&0@=&AE($U)345?4&%R="!S=')U
M8W1U<F4@;V8@82!M97-S86=E(&9R;VT@24U!4"!D871A+@H@("`@("H@5&AI
M<R!W:6QL('-T;W)E($E-05`@9&%T82!I;B!A;&P@<&%R=',@;V8@=&AE(&UE
M<W-A9V4@+2!F;W(@97AA;7!L92P*("`@("`J(&%L;"!D871A(&9O<B!A(&UU
M;'1I<&%R="]M:7AE9"!P87)T('=I;&P@8F4@<W1O<F5D(&EN('1H92!B87-E
M('!A<G0L"B`@("`@*B!A;F0@96%C:"!P87)T('=I;&P@8V]N=&%I;B!I=',@
M;W=N(&1A=&$N("!.;W1E('1H870@:68@>6]U('=A;G0@=&\*("`@("`J(&)U
M:6QD(&$@;65S<V%G92!S=')I;F<@9G)O;2!T:&4@34E-15]087)T(&1A=&$@
M869T97(@8V%L;&EN9PH@("`@("H@<F5B=6EL9$UE<W-A9V4H*2P@>6]U('-H
M;W5L9"!U<V4@24U07T-O;G1E;G1S.CIT;U-T<FEN9R@I(&EN<W1E860@;V8*
M("`@("`J($U)345?4&%R=#HZ=&]3=')I;F<H*2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($U)345?365S<V%G92`@02!-24U%7TUE<W-A9V4@;V)J96-T('=I
M=&@@86QL(&]F('1H92!B;V1Y('1E>'0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!S=&]R960@:6X@=&AE(&EN9&EV:61U86P@34E-15]087)T<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5B=6EL9$UE<W-A9V4H*0H@("`@>PH@
M("`@("`@("1P87)T(#T@)'1H:7,M/E]M97-S86=E+3YG971"87-E4&%R="@I
M.PH@("`@("`@("1T:&ES+3Y?<F5B=6EL9$UE<W-A9V4H)'!A<G0I.PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7VUE<W-A9V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296-U<G-I=F4@9G5N8W1I;VX@=7-E9"!T;R!R96)U:6QD('1H92!-
M24U%7U!A<G0@<W1R=6-T=7)E(&]F(&$*("`@("`J(&UE<W-A9V4N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M($U)345?4&%R="`D<&%R="`@02!-24U%7U!A<G0@;V)J96-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<F5B=6EL9$UE<W-A9V4H)'!A<G0I"B`@("!["B`@
M("`@("`@)&ED(#T@)'!A<G0M/F=E=$U)345)9"@I.PH*("`@("`@("`D;6EM
M95]P87)T(#T@)'1H:7,M/F=E=$U)345087)T*"1I9"D["B`@("`@("`@)'1H
M:7,M/E]S971#;VYT96YT<R@D;6EM95]P87)T+"!T<G5E*3L*("`@("`@("!I
M9B`H)'1H:7,M/E]M97-S86=E+3YG971087)T*"1I9"D@/3T]("1T:&ES+3Y?
M;65S<V%G92D@>PH@("`@("`@("`@("`D=&AI<RT^7VUE<W-A9V4@/2`F)&UI
M;65?<&%R=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7VUE<W-A9V4M/F%L=&5R4&%R="@D:60L("1M:6UE7W!A<G0I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1P87)T+3YG9710<FEM87)Y5'EP92@I(#T]("=M
M=6QT:7!A<G0G*2!["B`@("`@("`@("`@("\J(%)E8W5R<VEV96QY('!R;V-E
M<W,@86YY('-U8G!A<G1S+B`J+PH@("`@("`@("`@("!F;W)E86-H("@D<&%R
M="T^9V5T4&%R=',H*2!A<R`D;6EM92D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R96)U:6QD365S<V%G92@D;6EM92D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@82!-24U%(%!A
M<G0N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R
M="`@02!-24U%7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<F5N9&5R960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5N9&5R34E-15!A<G0H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S971#;VYT96YT<R@D;6EM95]P87)T*3L*("`@("`@("`D=&5X
M="`]('!A<F5N=#HZ<F5N9&5R34E-15!A<G0H)&UI;65?<&%R="D["@H@("`@
M("`@("\J($-O;G9E<G0@=&5X='5A;"!E;6]T:6-O;G,@:6YT;R!G<F%P:&EC
M86P@;VYE<R`M(&)U="!O;FQY(&9O<@H@("`@("`@("`J('1E>'0@<&%R=',N
M("HO"B`@("`@("`@:68@*"@D;6EM95]P87)T+3YG9710<FEM87)Y5'EP92@I
M(#T]("=T97AT)RD@)B8*("`@("`@("`@("`@)$=,3T)!3%-;)W!R969S)UTM
M/F=E=%9A;'5E*"=E;6]T:6-O;G,G*2D@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<["B`@("`@("`@("`@("1T
M97AT(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D=&5X="P@)V5M;W1I8V]N<R<L
M(&%R<F%Y*"=E;G1I=&EE<R<@/3X@=')U92DI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4V%V97,@
M82!C;W!Y(&]F('1H92!-24U%7T-O;G1E;G1S(&]B:F5C="!A="!T:&4@96YD
M(&]F(&$@<F5Q=65S="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$-A8VAE4VAU=&1O=VXH*0H@("`@
M>PH@("`@("`@("\J($1O;B=T(&-A8VAE('1H92`D7V)O9'EP87)T(&%R<F%Y
M('-I;F-E('=E(&UO<W0@;&EK96QY('=I;&P@;F]T('5S90H@("`@("`@("`J
M('1H96T@:6X@=&AE(&-A8VAE9"!O8FIE8W0@*'-I;F-E('1H92!C86-H92!W
M:6QL(&=E;F5R86QL>2!B92!U<V5D"B`@("`@("`@("H@=&\@=FEE=R!P87)T
M<R!T:&%T('=E<F5N)W0@9&ES<&QA>65D(&]R:6=I;F%L;'DI+@H@("`@("`@
M("`J($AO=V5V97(L('=E('=I;&P@;&]S92!T:&4@8F5N969I="!O9B!N;W0@
M:&%V:6YG('1O"B`@("`@("`@("H@;6%K92!C86QL<R!T;R!T:&4@;6%I;"!S
M97)V97(@;VX@<W5B<V5Q=65N="!P86=E(&QO861S+"!S;R!A;&QO=PH@("`@
M("`@("`J('5S97)S('1O(&-H86YG92!T:&ES(&)E:&%V:6]R+B`@3VYL>2!C
M86-H92!S;6%L;"!M97-S86=E<R!A<PH@("`@("`@("`J('-T;W)I;F<@;&%R
M9V4@;65S<V%G97,@=VEL;"!M86ME('1H92!S97-S:6]N('-I>F4@=&]O(&QA
M<F=E(&%N9`H@("`@("`@("`J('=I;&P@=&%X('-T;W)A9V4@86YD('!E<F9O
M<FUA;F-E(&]N('1H92!S97)V97(N("HO"B`@("`@("`@:68@*&5M<'1Y*"1'
M3$]"04Q36R=C;VYF)UU;)W-E<G9E<B==6R=C86-H95]M<V=B;V1Y)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?8F]D>7!A<G0@/2!A<G)A>2@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1S:7IE(#T@,#L*("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]B;V1Y<&%R="!A<R`D:V5Y(#T^("1V86PI
M('L*("`@("`@("`@("`@("`@("1P87)T7W-I>F4@/2!S=')L96XH)'9A;"D[
M"B`@("`@("`@("`@("`@("!I9B`H*"1S:7IE("L@)'!A<G1?<VEZ92D@/"`Q
M,#(T,"D@>PH@("`@("`@("`@("`@("`@("`@("1S:7IE("L]("1P87)T7W-I
M>F4["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1T:&ES+3Y?8F]D>7!A<G1;)&ME>5TI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!.
M979E<B!C86-H92!T:&4@9G5L;"!B;V1Y('!A<G0@87,@=V4@=7-E('1H:7,@
M:71E;2!M=6-H(&QE<W,*("`@("`@("`@*B!O9G1E;B!T:&%N('-P96-I9FEC
M(&UE<W-A9V4@8F]D>2!P87)T<RX@*B\*("`@("`@("`D=&AI<RT^7V)O9'D@
M/2!N=6QL.PH*("`@("`@("!P87)E;G0Z.E]A9&1#86-H95-H=71D;W=N*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&9R;VT@861D<F5S<R!O
M9B!T:&4@;65S<V%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&9R;VT@861D<F5S<R!O9B!T:&4@;65S<V%G92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1G)O;4%D9')E<W,H*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92!)35!?0D%312`N("<O;&EB+TU)344O2&5A9&5R<RYP:'`G.PH@
M("`@("`@("1H96%D97)S(#T@)FYE=R!)35!?2&5A9&5R<R@D=&AI<RT^9V5T
M365S<V%G94EN9&5X*"DI.PH@("`@("`@(')E='5R;B`D:&5A9&5R<RT^9V5T
M1G)O;4%D9')E<W,H*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E
M('1H92!L:7-T(&]F($U)344@241S('1O('5S92!F;W(@9&]W;FQO860@86QL
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1F;W)W87)D("!'96YE
M<F%T92!A(&QI<W0@;V8@:71E;7,@=&AA="!C86X@8F4@9F]R=V%R9&5D+`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(')A=&AE<B!T:&%N(&1O
M=VYL;V%D960N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI
M<W0@;V8@34E-12!)1',@=&AA="!S:&]U;&0@8F4@9&]W;FQO861E9"!W:&5N
M"B`@("`@*B`@("`@("`@("`@("`@("!D;W=N;&]A9&EN9R!A;&P@871T86-H
M;65N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1O=VYL;V%D06QL3&ES
M="@D9F]R=V%R9"`](&9A;'-E*0H@("`@>PH@("`@("`@("1D;W=N;&]A9',@
M/2!A<G)A>2@I.PH*("`@("`@("`D8F]D>6ED(#T@)'1H:7,M/F9I;F1";V1Y
M*"D["@H@("`@("`@("\J($AE<F4@:7,@=VAA="!W92!C;VYS:61E<B`G9F]R
M=V%R9&%B;&4G.@H@("`@("`@("`J($%L;"!P87)T<R`^(#`*("`@("`@("`@
M*B!087)T(#`@:68@;F]T(&UU;'1I<&%R="]M:7AE9`H@("`@("`@("`J($Y/
M5"!T:&4@8F]D>2!P87)T("AI9B!O;F4@97AI<W1S*0H@("`@("`@("`J"B`@
M("`@("`@("H@2&5R92!I<R!W:&%T('=E(&-O;G-I9&5R("=D;W=N;&]A9&%B
M;&4G.@H@("`@("`@("`J($%L;"!P87)T<R!N;W0@)VUU;'1I<&%R="\J)R!A
M;F0@)VUE<W-A9V4O*B<@97AC97!T(&9O<@H@("`@("`@("`J("`G;65S<V%G
M92]R9F,X,C(G"B`@("`@("`@("H@06QL('!A<G1S('1H870@87)E(&YO="!0
M1U`@;W(@4R]-24U%('-I9VYA='5R92!I;F9O<FUA=&EO;@H@("`@("`@("`J
M($Y/5"!T:&4@8F]D>2!P87)T("AI9B!O;F4@97AI<W1S*2`J+PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?;65S<V%G92T^8V]N=&5N=%1Y<&5-87`H*2!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@:68@*"1K97D@/3T@)&)O
M9'EI9"D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@D9F]R=V%R9"D@>PH@("`@("`@("`@("`@
M("`@:68@*"1K97D@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M=F%L("$]("=M=6QT:7!A<G0O;6EX960G*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1D;W=N;&]A9'-;72`]("1K97D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T@96QS96EF("AS=')P;W,H)&ME>2P@)RXG*2`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("`@("`D9&]W;FQO861S6UT@/2`D:V5Y.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@:68@*'-T<G!O<R@D=F%L+"`G;65S<V%G92\G*2`]/3T@,"D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)'9A;"P@)VUE<W-A
M9V4O<F9C.#(R)RD@/3T](#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&1O=VYL;V%D<UM=(#T@)&ME>3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H*"AI;G1V86PH)&ME>2D@(3T@,2D@
M)B8@*'-T<G!O<R@D=F%L+"`G,2XG*2`]/3T@9F%L<V4I*2`F)@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("@H<W1R<&]S*"1V86PL("=M=6QT:7!A<G0O
M)RD@/3T](&9A;'-E*2D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`H
M<W1R<&]S*"1V86PL("=A<'!L:6-A=&EO;B]X+7!K8W,W+7-I9VYA='5R92<I
M(#T]/2!F86QS92D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`H<W1R
M<&]S*"1V86PL("=A<'!L:6-A=&EO;B]P:V-S-RUS:6=N871U<F4G*2`]/3T@
M9F%L<V4I*2!["B`@("`@("`@("`@("`@("`@("`@)&1O=VYL;V%D<UM=(#T@
M)&ME>3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1D;W=N;&]A9',["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'96YE<F%T92!A(&1O=VYL;V%D(&%L;"!L:6YK+"!I9B!P;W-S
M:6)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1O=VYL
M;V%D(&QI;FLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1O=VYL;V%D06QL
M3&EN:R@I"B`@("!["B`@("`@("`@)'5R;"`](&YU;&P["@H@("`@("`@("1D
M;W=N;&]A9'-?;&ES="`]("1T:&ES+3YG971$;W=N;&]A9$%L;$QI<W0H*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1D;W=N;&]A9'-?;&ES="DI('L*("`@("`@
M("`@("`@+RH@0W)E871E(&$@9'5M;7D@=F%R:6%B;&4@=&\@<&%S<R!T;R!U
M<FQ6:65W*"D@<VEN8V4@=V4@9&]N)W0*("`@("`@("`@("`@("`@:&%V92!A
M($U)345?4&%R="!A;F0@=V4@8V%N)W0@<&%S<R!N=6QL(&)Y(')E9F5R96YC
M92X@*B\*("`@("`@("`@("`@)&1U;6UY(#T@,#L*("`@("`@("`@("`@)'5R
M;"`]("1T:&ES+3YU<FQ6:65W*"1D=6UM>2P@)V1O=VYL;V%D7V%L;"<L(&%R
M<F%Y*"=I9"<@/3X@,2DI.PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ<F5M
M;W9E4&%R86UE=&5R*"1U<FPL(&%R<F%Y*"=I9"<I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=7)L.PH@("`@?0H*("`@("\J*@H@("`@("H@4')I
M;G1S(&]U="!T:&4@<W1A='5S(&UE<W-A9V4@9F]R(&$@9VEV96X@34E-12!0
M87)T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;7-G("`@("`@4V5E
M($U)345?0V]N=&5N=',Z.F9O<FUA=%-T871U<TUS9R@I+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:6UG("`@("!3964@34E-15]#;VYT96YT<SHZ9F]R;6%T
M4W1A='5S37-G*"DN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<')I;G0@($]U
M='!U="!T:&ES(&UE<W-A9V4@=VAE;B!I;B!A('!R:6YT('9I97<_"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@<W1A='5S
M(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O<FUA=%-T871U<TUS
M9R@D;7-G+"`D:6UG(#T@;G5L;"P@)'!R:6YT86)L92`]('1R=64I"B`@("![
M"B`@("`@("`@:68@*"$D<')I;G1A8FQE("8F($E-4#HZ<')I;G1-;V1E*"DI
M('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!P87)E;G0Z.F9O<FUA=%-T871U<TUS9R@D;7-G
M+"`D:6UG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD
M<R!T:&4@;6%I;B`B8F]D>2(@=&5X="!P87)T("AI9B!A;GDI(&EN(&$@;65S
M<V%G92X*("`@("`J(")";V1Y(B!D871A(&ES('1H92!F:7)S="!T97AT('!A
M<G0@:6X@=&AE(&)A<V4@34E-12!P87)T+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@34E-12!)1"!O9B!T:&4@;6%I;B`B8F]D>2(@<&%R
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEN9$)O9'DH*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V)O9'E?:60I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V)O9'E?:60["B`@("`@("`@?0H*("`@("`@("`O
M*B!,;V]K(&9O<B!P;W1E;G1I86P@8F]D>2!P87)T<RX@*B\*("`@("`@("`D
M<&%R="`]("1T:&ES+3Y?;65S<V%G92T^9V5T0F%S95!A<G0H*3L*("`@("`@
M("`D<')I;6%R>5]T>7!E(#T@)'!A<G0M/F=E=%!R:6UA<GE4>7!E*"D["B`@
M("`@("`@:68@*"@D<')I;6%R>5]T>7!E(#T]($U)344Z.G1Y<&4H5%E014U5
M3%1)4$%25"DI('Q\"B`@("`@("`@("`@("@D<')I;6%R>5]T>7!E(#T]($U)
M344Z.G1Y<&4H5%E0151%6%0I*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V)O
M9'E?:60@/2`D=&AI<RT^7V9I;F1";V1Y*"1P87)T*3L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?8F]D>5]I9#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S<V5S(&$@
M34E-12!087)T(&%N9"!L;V]K<R!F;W(@(F)O9'DB(&1A=&$N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!-24U%($E$(&]F('1H92!M86EN(")B;V1Y(B!P87)T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9FEN9$)O9'DH)&UI;65?<&%R="D*("`@
M('L*("`@("`@("!I9B`H:6YT=F%L*"1M:6UE7W!A<G0M/F=E=$U)345)9"@I
M*2`\(#(@?'P*("`@("`@("`@("`@)&UI;65?<&%R="T^9V5T26YF;W)M871I
M;VXH)V%L=&5R;F%T:79E)RD@/3T](#`I('L*("`@("`@("`@("`@:68@*"1M
M:6UE7W!A<G0M/F=E=%!R:6UA<GE4>7!E*"D@/3T@34E-13HZ='EP92A465!%
M355,5$E005)4*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UI;65?
M<&%R="T^9V5T4&%R=',H*2!A<R`D<&%R="D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@H)'!A<G1I9"`]("1T:&ES+3Y?9FEN9$)O9'DH)'!A<G0I*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!A<G1I9#L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS96EF("@D;6EM95]P87)T+3YG9710<FEM87)Y5'EP92@I(#T]
M($U)344Z.G1Y<&4H5%E0151%6%0I*2!["B`@("`@("`@("`@("`@("!I9B`H
M)&UI;65?<&%R="T^9V5T0GET97,H*2!\?`H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YG971";V1Y4&%R="@D;6EM95]P87)T+3YG971-24U%260H*2DI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&UI;65?<&%R="T^9V5T
M34E-14ED*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0W)E871E<R!A('5N:7%U92!C86-H92!)1"!F;W(@=&AI<R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("!4:&4@24U!4"!I;F1E>"!O9B!T
M:&4@8W5R<F5N="!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!!('5N:7%U92!C86-H92!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-R96%T94-A8VAE240H)&EN9&5X(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H:7-?;G5L;"@D:6YD97@I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RDI('L*("`@("`@("`@("`@("`@("1I;F1E>"`]("1T:&ES+3Y?:6YD
M97@["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U
M<FX@<&%R96YT.CI?8W)E871E0V%C:&5)1"@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!M9#4H:6UP;&]D92@G?"<L(&%R<F%Y
M*"1I;F1E>"P@)%]315-324].6R=I;7`G75LG=&AI<VUA:6QB;W@G72DI*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($UA:V4@<W5R92!T:&4@8V]N=&5N=',@
M;V8@=&AE(&-U<G)E;G0@<&%R="!A<F4@<V5T(&9R;VT@24U!4"!S97)V97(*
M("`@("`J(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B!`<VEN8V4@24U0(#,N,0H@("`@("H*("`@("`J($!P87)A;2!-24U%
M7U!A<G0@)B1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J96-T('1O('=O
M<FL@=VET:"X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&P@("`@("`@("`@
M($1O=VYL;V%D('1H92!E;G1I<F4@<&%R=',@8V]N=&5N=',_"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]S971#;VYT96YT<R@F)&UI;65?<&%R="P@)&%L;"`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A)&UI;65?<&%R="T^9V5T26YF
M;W)M871I;VXH)VEM<%]C;VYT96YT<U]S970G*2`F)@H@("`@("`@("`@("`A
M)&UI;65?<&%R="T^9V5T0V]N=&5N=',H*2D@>PH@("`@("`@("`@("`D:60@
M/2`D;6EM95]P87)T+3YG971-24U%260H*3L*("`@("`@("`@("`@:68@*"1A
M;&P@)B8@*"1M:6UE7W!A<G0M/F=E=%1Y<&4H*2`]/2`G;65S<V%G92]R9F,X
M,C(G*2D@>PH@("`@("`@("`@("`@("`@)&ED(#T@<W5B<W1R*"1M:6UE7W!A
M<G0M/F=E=$U)345)9"@I+"`P+"`M,BD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&UI;65?<&%R="T^<V5T0V]N=&5N=',H)'1H:7,M/F=E=$)O9'E0
M87)T*"1I9"DI.PH@("`@("`@('T*("`@("`@("`D;6EM95]P87)T+3YS971)
M;F9O<FUA=&EO;B@G:6UP7V-O;G1E;G1S7W-E="<L('1R=64I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1F5T8V@@<&%R="!O9B!A($U)344@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`<VEN8V4@24U0(#,N,0H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1I9"`@(%1H92!-24U%($E$(&]F('1H92!P87)T(')E
M<75E<W1E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&P@($EF('1H:7,@
M:7,@82!H96%D97(@<&%R="P@<VAO=6QD('=E(')E='5R;B!A;&P@=&5X=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&)O9'D_"B`@("`@
M*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@(%1H92!-24U%7U!A<G0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G971287=-24U%4&%R="@D:60L("1A;&P@
M/2!F86QS92D*("`@('L*("`@("`@("`D;6EM95]P87)T(#T@)'1H:7,M/F=E
M=$U)345087)T*"1I9"D["B`@("`@("`@:68@*"%I<U]A*"1M:6UE7W!A<G0L
M("=-24U%7U!A<G0G*2D@>PH@("`@("`@("`@("`D;6EM95]P87)T(#T@;G5L
M;#L*("`@("`@("`@("`@<F5T=7)N("1M:6UE7W!A<G0["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?<V5T0V]N=&5N=',H)&UI;65?<&%R="P@=')U92D[
M"B`@("`@("`@<F5T=7)N("1M:6UE7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&4@82!M97-S86=E('-T<FEN9R!F<F]M(&$@34E-12!M97-S
M86=E('1H870@:&%S('5S960*("`@("`J(')E8G5I;&1-97-S86=E*"D@=&\@
M8G5I;&0@=&AE(&1A=&$@9G)O;2!T:&4@24U!4"!S97)V97(N"B`@("`@*@H@
M("`@("H@0'-I;F-E($E-4"`T+C$*("`@("`J"B`@("`@*B!`<&%R86T@34E-
M15]-97-S86=E("1M97-S86=E("!!($U)345?365S<V%G92!O8FIE8W0N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D8V%N;VYI8V%L("`@("!2971U<FX@82!C
M86YO;FEC86P@<W1R:6YG/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@8V]N=&5N=',@;V8@=&AE($U)345?365S<V%G92!O8FIE8W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG*"1M97-S86=E+"`D8V%N;VYI
M8V%L(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1E>'0@/2`G)SL*"B`@("`@
M("`@)'!A<G0@/2`D;65S<V%G92T^9V5T0F%S95!A<G0H*3L*("`@("`@("!F
M;W)E86-H("@D<&%R="T^8V]N=&5N=%1Y<&5-87`H*2!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@:68@*"@D:V5Y("$](#`I("8F("AS=')P;W,H
M)'9A;"P@)VUU;'1I<&%R="\G*2`]/3T@,"DI('L*("`@("`@("`@("`@("`@
M("1O;&0@/2`D<&%R="T^9V5T4&%R="@D:V5Y*3L*("`@("`@("`@("`@("`@
M("1O;&0M/G-E=$-O;G1E;G1S*"<G*3L*("`@("`@("`@("`@("`@("1P87)T
M+3YA;'1E<E!A<G0H)&ME>2P@)&]L9"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@D;65S<V%G92T^9V5T34E-14ED*"D@/3T@,"D@
M>PH@("`@("`@("`@("`D<&%R="T^<V5T0V]N=&5N=',H)R<I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("@D8V%N;VYI8V%L*2`_("1P87)T+3YT;T-A
M;F]N:6-A;%-T<FEN9R@I(#H@)'!A<G0M/G1O4W1R:6YG*"D["B`@("!]"@I]
M"@```````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+VQI8B]-24U%+TAE861E<G,N<&AP````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,S$S-``Q,#0Q-S,V,C<V-@`P,C`U
M-S8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O34E-12](96%D97)S+G!H<"<[
M"G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+W9E<G-I;VXN<&AP)SL*
M"B\J*@H@*B!4:&4@9&5S8W)I<'1I;VX@;V8@=&AE($E-4"!P<F]G<F%M('1O
M('5S92!I;B!T:&4@)U5S97(M06=E;G0Z)R!H96%D97(N"B`J+PID969I;F4H
M)TE-4%]!1T5.5%](14%$15(G+"`G26YT97)N970@365S<V%G:6YG(%!R;V=R
M86T@*$E-4"D@)R`N($E-4%]615)324].*3L*"B\J*@H@*B!4:&4@24U07TAE
M861E<G,Z.B!C;&%S<R!C;VYT86EN<R!A;&P@9G5N8W1I;VYS(')E;&%T960@
M=&\@:&%N9&QI;F<*("H@=&AE(&AE861E<G,@;V8@;6%I;"!M97-S86=E<R!I
M;B!)35`N"B`J"B`J("1(;W)D93H@:6UP+VQI8B]-24U%+TAE861E<G,N<&AP
M+'8@,2XY,BXR+C(P(#(P,#8O,#(O,34@,#8Z,C$Z-#8@<VQU<V%R>B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC
M;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@
M24U0"B`J+PIC;&%S<R!)35!?2&5A9&5R<R!E>'1E;F1S($U)345?2&5A9&5R
M<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@57-E<BU!9V5N="!S=')I;F<@=&\@
M=7-E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7V%G96YT(#T@24U07T%'14Y47TA%041%4CL*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!R969E<F5N8V4@=&\@82!C=7)R96YT;'D@;W!E;B!)34%0
M('-T<F5A;2X*("`@("`J"B`@("`@*B!`<V5E($U)345?2&5A9&5R<SHZ7V=E
M=%-T<F5A;2@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9?9V5T4W1R96%M*"D*
M("`@('L*("`@("`@("!R971U<FX@)$=,3T)!3%-;)VEM<"==6R=S=')E86TG
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E(&%L;"!O9B!T:&4@879A
M:6QA8FQE(&UA:6QI;F<@;&ES="!H96%D97)S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P87)S94%L;$QI<W1(96%D97)S*"D*("`@('L*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^;&ES=$AE861E<G,H*2!A<R`D=F%L(#T^("1S='(I('L*
M("`@("`@("`@("`@)'1H:7,M/G!A<G-E3&ES=$AE861E<G,H)'9A;"D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@=&AE(&EN9F]R
M;6%T:6]N(&EN('1H92!M86EL:6YG(&QI<W0@:&5A9&5R<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@=&\@<')O
M8V5S<RX*("`@("`J($!P87)A;2!B;V]L96%N("1R87<@("`@4VAO=6QD('1H
M92!R87<@55),(&)E(')E='5R;F5D(&EN<W1E860@;V8@<V5T=&EN9PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!T:&4@:&5A9&5R('9A;'5E/PH@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@:&5A9&5R('9A;'5E
M("AI9B`D<F%W(#T]('1R=64I+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S
M94QI<W1(96%D97)S*"1H96%D97(L("1R87<@/2!F86QS92D*("`@('L*("`@
M("`@("!I9B`H(2@D9&%T82`]("1T:&ES+3YG971686QU92@D:&5A9&5R*2DI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&]U
M='!U="`]("<G.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0N
M<&AP)SL*"B`@("`@("`@+RH@4W!L:70@=&AE(&EN8V]M:6YG(&1A=&$@8GD@
M=&AE("<L)R!C:&%R86-T97(N("HO"B`@("`@("`@9F]R96%C:"`H<')E9U]S
M<&QI="@B+RPO(BP@)&1A=&$I(&%S("1E;G1R>2D@>PH@("`@("`@("`@("`O
M*B!'970@=&AE(&1A=&$@:6YS:61E(&]F('1H92!B<F%C:V5T<RX@268@=&AE
M<F4@:7,@;F\@8G)A8VME=',L"B`@("`@("`@("`@("`@('1H96X@<F5T=7)N
M('1H92!R87<@=&5X="X@*B\*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H
M*"(O7#PH6UY</ETK*5P^+R(L("1E;G1R>2P@)&UA=&-H97,I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@=')I;2@D96YT<GDI.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O*B!296UO=F4@86QL('=H:71E<W!A8V4@9G)O;2!B
M971W965N(&)R86-K971S("A21D,@,C,V.2!;,ETI+B`J+PH@("`@("`@("`@
M("`D;6%T8V@@/2!P<F5G7W)E<&QA8V4H(B]<<RLO(BP@)R<L("1M871C:&5S
M6S%=*3L*"B`@("`@("`@("`@("\J($1E=&5R;6EN92!I9B!T:&5R92!I<R!A
M;GD@8V]M;65N=',N("HO"B`@("`@("`@("`@('!R96=?;6%T8V@H(B\H7"@N
M*UPI*2\B+"`D96YT<GDL("1C;VUM96YT<RD["@H@("`@("`@("`@("`O*B!2
M1D,@,C,V.2!;,ET@<W1A=&5S('1H870@=V4@<VAO=6QD(&]N;'D@<VAO=R!T
M:&4@*D9)4E-4*B!54DP*("`@("`@("`@("`@("`@=&AA="!A<'!E87)S(&EN
M(&$@:&5A9&5R('1H870@=V4@8V%N(&%D97%U871E;'D@:&%N9&QE+B`J+PH@
M("`@("`@("`@("!I9B`H<W1R:7-T<B@D;6%T8V@L("=M86EL=&\Z)RD@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D;6%T8V@@/2!S=6)S='(H)&UA
M=&-H+"!S=')P;W,H)&UA=&-H+"`G.B<I("L@,2D["B`@("`@("`@("`@("`@
M("!I9B`H)')A=RD@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D;6%T
M8V@["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;W5T<'5T
M(#T@2&]R9&4Z.FQI;FLH24U0.CIC;VUP;W-E3&EN:R@D;6%T8V@I*2`N("1M
M871C:"`N("<\+V$^)SL*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-O
M;6UE;G1S6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M)R9N8G-P.R<@+B`D8V]M;65N='-;,5T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N
M<&AP)SL*("`@("`@("`@("`@("`@(&EF("@D=7)L(#T@5&5X=%]&:6QT97(Z
M.F9I;'1E<B@D;6%T8V@L("=L:6YK=7)L<R<L(&%R<F%Y*"=C86QL8F%C:R<@
M/3X@)TAO<F1E.CIE>'1E<FYA;%5R;"<I*2D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D<F%W*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D;6%T8V@["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("1O=71P=70@/2`D=7)L.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&-O;6UE;G1S6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("<F;F)S<#LG("X@)&-O;6UE;G1S6S%=.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M+RH@57-E('1H:7,@96YT<GD@=6YL97-S('=E(&-A;B!F:6YD(&$@8F5T=&5R
M(&]N92X@*B\*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T(#T@)&UA=&-H
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^<V5T5F%L=64H)&AE861E<BP@)&]U='!U="D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86YY('-I=&4M<W!E8VEF:6,@:&5A
M9&5R<R!D969I;F5D(&EN(&-O;F9I9R]H96%D97(N='AT('1O"B`@("`@*B!T
M:&4@:6YT97)N86P@:&5A9&5R(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&13:71E2&5A9&5R<R@I"B`@("!["B`@("`@("`@+RH@061D('1H92`G
M57-E<BU!9V5N="<@:&5A9&5R+B`J+PH@("`@("`@("1T:&ES+3YA9&1!9V5N
M=$AE861E<B@I.PH*("`@("`@("`O*B!486-K(&]N(&%N>2!S:71E+7-P96-I
M9FEC(&AE861E<G,N("HO"B`@("`@("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG
M8V]N9B==6R=M<V<G75LG<')E<&5N9%]H96%D97(G72D@)B8*("`@("`@("`@
M("`@0&ES7W)E861A8FQE*$E-4%]"05-%("X@)R]C;VYF:6<O:&5A9&5R+G!H
M<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O
M8V]N9FEG+VAE861E<BYP:'`G.PH@("`@("`@("`@("!F;W)E86-H("@D7VAE
M861E<B!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YA9&1(96%D97(H=')I;2@D:V5Y*2P@=')I;2@D=F%L*2D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@
M82!S=')I;F<@8V]N=&%I;FEN9R!A(&QI<W0@;V8@861D<F5S<V5S+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I96QD("`@(%1H92!A9&1R97-S
M(&9I96QD('1O('!A<G-E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%D9%52
M3"`@5&AE('-E;&8@55),+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-E="`@
M("`@4V5T('1H92!A<W-O8VEA=&5D(&AE861E<B!W:71H('1H92!R971U<FX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9S\*("`@("`J
M($!P87)A;2!B;V]L96%N("1L:6YK("`@($QI;FL@96%C:"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('-C<F5E;C\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9O<FUA='1E9"!A9&1R97-S
M(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD061D<F5S<TQI;FMS
M*"1F:65L9"P@)&%D9%523"P@)'-E="`](&9A;'-E+"`D;&EN:R`]('1R=64I
M"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<RP@)')E9VES=')Y.PH*("`@
M("`@("`D861D7VQI;FL@/2!N=6QL.PH*("`@("`@("`O*B!-86ME('-U<F4@
M=&AI<R!I<R!A('9A;&ED(&]B:F5C="!A9&1R97-S(&9I96QD+B`J+PH@("`@
M("`@("1A<G)A>2`]("1T:&ES+3YM>4=E=$]B*"1F:65L9"D["B`@("`@("`@
M:68@*&5M<'1Y*"1A<G)A>2D@?'P@(6ES7V%R<F%Y*"1A<G)A>2DI('L*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("`O*B!3
M970@=7`@=&AE(&%D9"!A9&1R97-S(&EC;VX@;&EN:R!I9B!C;VYT86-T(&UA
M;F%G97(@:7,*("`@("`@("`@("!A=F%I;&%B;&4N("HO"B`@("`@("`@:68@
M*"1L:6YK("8F"B`@("`@("`@("`@("1R96=I<W1R>2T^:&%S365T:&]D*"=C
M;VYT86-T<R]I;7!O<G0G*2`F)@H@("`@("`@("`@("`D<')E9G,M/F=E=%9A
M;'5E*"=A9&1?<V]U<F-E)RDI('L*("`@("`@("`@("`@)&%D9%]L:6YK(#T@
M571I;#HZ861D4&%R86UE=&5R*"1A9&154DPL("=A8W1I;VY)1"<L("=A9&1?
M861D<F5S<R<I.PH@("`@("`@('T*"B`@("`@("`@)&%D9')?87)R87D@/2!A
M<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T061D<F5S<V5S
M1G)O;4]B:F5C="@D87)R87DI(&%S("1O8BD@>PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1O8BT^861D<F5S<RD@)B8@(65M<'1Y*"1O8BT^:6YN97(I*2![
M"B`@("`@("`@("`@("`@("`D<F5T(#T@)R<["@H@("`@("`@("`@("`@("`@
M+RH@268@=&AI<R!I<R!A;B!I;F-O;7!L971E(&4M;6%I;"!A9&1R97-S+"!D
M;VXG="!L:6YK"B`@("`@("`@("`@("`@("`@("!T;R!A;GET:&EN9RX@*B\*
M("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1O8BT^:&]S="P@)U5.2TY/
M5TXG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@
M)&]B+3YA9&1R97-S.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D<F5T(#T@:'1M;'-P96-I86QC:&%R<RAS=')?<F5P
M;&%C92@G7"(G+"`G(B<L("1O8BT^861D<F5S<RDI.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D;&EN:RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5T(#T@2&]R9&4Z.FQI;FLH24U0.CIC;VUP;W-E3&EN:RAA<G)A>2@G=&\G
M(#T^(&%D9'-L87-H97,H)&]B+3YA9&1R97-S*2DI+"!S<')I;G1F*%\H(DYE
M=R!-97-S86=E('1O("5S(BDL("1O8BT^:6YN97(I*2`N("1R970@+B`G/"]A
M/B<["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@
M("`O*B!!<'!E;F0@=&AE(&%D9"!A9&1R97-S(&EC;VX@=&\@979E<GD@861D
M<F5S<R!I9@H@("`@("`@("`@("`@("`@("`@("`@(&-O;G1A8W0@;6%N86=E
M<B!I<R!A=F%I;&%B;&4N("HO"B`@("`@("`@("`@("`@("`@("`@:68@*"1A
M9&1?;&EN:RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<E]L:6YK
M(#T@571I;#HZ861D4&%R86UE=&5R*"1A9&1?;&EN:RP@87)R87DH)VYA;64G
M(#T^("1O8BT^<&5R<V]N86PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G861D<F5S<R<@/3X@)&]B+3YI;FYE<BDI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5T("X]($AO<F1E.CIL:6YK*"1C=7)R7VQI;FLL('-P<FEN
M=&8H7R@B061D("5S('1O(&UY($%D9')E<W,@0F]O:R(I+"`D;V(M/FEN;F5R
M*2D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.FEM9R@G
M861D<F5S<V)O;VM?861D+G!N9R<L('-P<FEN=&8H7R@B061D("5S('1O(&UY
M($%D9')E<W,@0F]O:R(I+"`D;V(M/FEN;F5R*2D@+B`G/"]A/B<["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1A9&1R7V%R<F%Y6UT@/2`D<F5T.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!)9B!L969T('=I=&@@86X@96UP='D@861D
M<F5S<R!L:7-T("@D<F5T*2P@:6YF;W)M('1H92!U<V5R('1H870*("`@("`@
M("`@("!T:&4@<F5C:7!I96YT(&QI<W0@:7,@<'5R<&]S96QY(")U;F1I<V-L
M;W-E9"(N("HO"B`@("`@("`@:68@*&5M<'1Y*"1A9&1R7V%R<F%Y*2D@>PH@
M("`@("`@("`@("`D<F5T(#T@7R@B56YD:7-C;&]S960@4F5C:7!I96YT<R(I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($)U:6QD('1H92!A
M9&1R97-S(&QI;F4N("HO"B`@("`@("`@("`@(&EF("AC;W5N="@D861D<E]A
M<G)A>2D@/B`R,"D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.F%D9%-C<FEP
M=$9I;&4H)VAI9&5A8FQE+FIS)RP@)VAO<F1E)RP@=')U92D["B`@("`@("`@
M("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G861D<F5S<V5S0FQO8VMS
M+FIS)RP@)VEM<"<I.PH@("`@("`@("`@("`*("`@("`@("`@("`@("`@("1R
M970@/2`G/&1I=B!I9#TB871?)R`N("1F:65L9"`N("<B/B<@+@H@("`@("`@
M("`@("`@("`@("`@($AO<F1E.CIL:6YK*"<C)RP@)R<L("=W:61G970G+"`G
M)RP@)W1O9V=L94%D9')E<W-E<T)L;V-K*%PG)R`N("1F:65L9"`N("=<)RP@
M7"<G("X@8V]U;G0H)&%D9')?87)R87DI("X@)UPG*3L@<F5T=7)N(&9A;'-E
M.R<L("<G+"`G)RD@+@H@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B
M6U-H;W<@861D<F5S<V5S("T@)7,@<F5C:7!I96YT<UTB*2P@8V]U;G0H)&%D
M9')?87)R87DI*2`N("<\+V$^/"]D:78^)R`N"B`@("`@("`@("`@("`@("`@
M("`@)SQD:78@:60](F%B7R<@+B`D9FEE;&0@+B`G(B!S='EL93TB9&ES<&QA
M>3IN;VYE.R(^/'-P86X@8VQA<W,](FYO=W)A<"(^)R`N(&EM<&QO9&4H)RP\
M+W-P86X^(#QS<&%N(&-L87-S/2)N;W=R87`B/B<L("1A9&1R7V%R<F%Y*2`N
M("<\+W-P86X^/"]D:78^)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1R970@/2`G/'-P86X@8VQA<W,](FYO=W)A<"(^)R`N(&EM
M<&QO9&4H)RP\+W-P86X^(#QS<&%N(&-L87-S/2)N;W=R87`B/B<L("1A9&1R
M7V%R<F%Y*2`N("<\+W-P86X^)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@4V5T('1H92!H96%D97(@=F%L=64L(&EF(')E<75E<W1E
M9"X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1S970I*2!["B`@("`@("`@("`@
M("1T:&ES+3YS971686QU92@D9FEE;&0L("1R970I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M=&AE(&QO8V%L('1I;64@<W1R:6YG('1O('1H92!D871E(&AE861E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871E("!4:&4@9&%T92!S=')I
M;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D871E('-T
M<FEN9R!W:71H('1H92!L;V-A;"!T:6UE(&%D9&5D(&]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1,;V-A;%1I;64H)&1A=&4I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1D871E*2D@>PH@("`@("`@("`@("`D;'1I;64@/2!F86QS
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%T92`]('!R96=?
M<F5P;&%C92@G+UQS*UPH7'<K7"DD+R<L("<G+"`D9&%T92D["B`@("`@("`@
M("`@("1L=&EM92`]('-T<G1O=&EM92@D9&%T92D["B`@("`@("`@?0H@("`@
M("`@(&EF("@D;'1I;64@(3T](&9A;'-E("8F("1L=&EM92`A/3T@+3$I('L*
M("`@("`@("`@("`@)&1A=&5?<W1R(#T@<W1R9G1I;64H)$=,3T)!3%-;)W!R
M969S)UTM/F=E=%9A;'5E*"=D871E7V9O<FUA="<I+"`D;'1I;64I.PH@("`@
M("`@("`@("`D=&EM95]S='(@/2!S=')F=&EM92@D1TQ/0D%,4ULG<')E9G,G
M72T^9V5T5F%L=64H)W1I;65?9F]R;6%T)RDL("1L=&EM92D["B`@("`@("`@
M("`@("1T>B`]('-T<F9T:6UE*"<E6B<I.PH@("`@("`@("`@("!I9B`H*&1A
M=&4H)UDG*2`A/2!`9&%T92@G62<L("1L=&EM92DI('Q\"B`@("`@("`@("`@
M("`@("`H9&%T92@G32<I("$]($!D871E*"=-)RP@)&QT:6UE*2D@?'P*("`@
M("`@("`@("`@("`@("AD871E*"=D)RD@(3T@0&1A=&4H)V0G+"`D;'1I;64I
M*2D@>PH@("`@("`@("`@("`@("`@+RH@3F]T('1O9&%Y+"!U<V4@=&AE(&1A
M=&4N("HO"B`@("`@("`@("`@("`@("`D9&%T92`N/2!S<')I;G1F*"<@/'-M
M86QL/ELE<R`E<R`E<UT\+W-M86QL/B<L("1D871E7W-T<BP@)'1I;65?<W1R
M+"`D='HI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M+RH@16QS92P@:70G<R!T;V1A>2P@=7-E('1H92!T:6UE(&]N;'DN("HO"B`@
M("`@("`@("`@("`@("`D9&%T92`N/2!S<')I;G1F*"<@/'-M86QL/ELE<R`E
M<UT\+W-M86QL/B<L("1T:6UE7W-T<BP@)'1Z*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D871E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T(&$@:&5A9&5R(&9R;VT@=&AE(&AE861E<B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'-I;F-E($E-4"`T+C$*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:65L9"`@5&AE(&AE861E<B!T;R!R971U<FX@87,@
M86X@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!F
M:65L9"!R97%U97-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UY1V5T3V(H
M)&9I96QD*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O8D-A
M8VAE6R1F:65L9%TI*2!["B`@("`@("`@("`@("1V86QU92`]("1T:&ES+3YG
M971686QU92@D9FEE;&0I.PH@("`@("`@("`@("`D=&AI<RT^7V]B0V%C:&5;
M)&9I96QD72`]($E-4#HZ<&%R<V5!9&1R97-S3&ES="@D=F%L=64I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]O8D-A8VAE6R1F:65L9%T[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+VQI8B])9&5N=&ET>2\`````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,3<U-30`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+TED96YT:71Y+VEM<"YP
M:'``````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,V,#,V`#$P
M-#$W,S8R-S8V`#`R,3`U-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N
M=&ET>2YP:'`G.PH*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@86X@24U0
M+7-P96-I9FEC(&EN=&5R9F%C92!T;R!A;&P@:61E;G1I=&EE<R!A"B`J('5S
M97(@;6EG:'0@:&%V92X@271S(&UE=&AO9',@=&%K92!C87)E(&]F(&%N>2!S
M:71E+7-P96-I9FEC"B`J(')E<W1R:6-T:6]N<R!C;VYF:6=U<F5D(&EN('!R
M969S+G!H<"!A;F0@8V]N9BYP:'`N"B`J"B`J("1(;W)D93H@:6UP+VQI8B])
M9&5N=&ET>2]I;7`N<&AP+'8@,2XT-"XR+C@@,C`P-B\P,2\P-2`P-SHU.#HR
M,B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#$M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@24U0(#(N,RXW"B`J($!P86-K86=E($AO<F1E
M7TED96YT:71Y"B`J+PIC;&%S<R!)9&5N=&ET>5]I;7`@97AT96YD<R!)9&5N
M=&ET>2!["@H@("`@+RHJ"B`@("`@*B!#86-H960@86QI87,@;&ES="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%L:6%S
M97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V%C:&5D(&9R;VT@861D
M<F5S<R!L:7-T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?9G)O;4QI<W0@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M0V%C:&5D(&YA;65S(&QI<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]N86UE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!#86-H960@<VEG;F%T=7)E(&QI<W0N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S:6=N871U<F5S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J(%)E861S(&%L;"!T:&4@=7-E<B=S(&ED96YT
M:71I97,@9G)O;2!T:&4@<')E9G,@;V)J96-T(&]R(&)U:6QD<PH@("`@("H@
M82!N97<@:61E;G1I='D@9G)O;2!T:&4@<W1A;F1A<F0@=F%L=65S(&=I=F5N
M(&EN('!R969S+G!H<"X*("`@("`J+PH@("`@9G5N8W1I;VX@261E;G1I='E?
M:6UP*"D*("`@('L*("`@("`@("!P87)E;G0Z.DED96YT:71Y*"D["B`@("`@
M("`@)'1H:7,M/E]P<F]P97)T:65S(#T@87)R87E?;65R9V4H"B`@("`@("`@
M("`@("1T:&ES+3Y?<')O<&5R=&EE<RP*("`@("`@("`@("`@87)R87DH)W)E
M<&QY=&]?861D<B<L("=A;&EA<U]A9&1R)RP@)W1I971O7V%D9'(G+"`G8F-C
M7V%D9'(G+`H@("`@("`@("`@("`@("`@("`G;6%I;%]H9'(G+"`G<VEG;F%T
M=7)E)RP@)W-I9U]F:7)S="<L("=S:6=?9&%S:&5S)RP*("`@("`@("`@("`@
M("`@("`@)W-A=F5?<V5N=%]M86EL)RP@)W-E;G1?;6%I;%]F;VQD97(G*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!697)I9FEE<R!A;F0@<V%N:71I>F5S
M(&%L;"!I9&5N=&ET>2!P<F]P97)T:65S+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I9&5N=&ET>2`@5&AE(&ED96YT:71Y('1O('9E<FEF>2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\;V)J96-T("!4<G5E(&EF
M('1H92!P<F]P97)T:65S(&%R92!V86QI9"!O<B!A(%!%05)?17)R;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('=I=&@@86X@97)R;W(@9&5S
M8W)I<'1I;VX@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!V97)I
M9GDH)&ED96YT:71Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@<&%R96YT.CIV97)I9GDH)&ED96YT:71Y*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A:7-S970H)&ED96YT:71Y*2D@>PH@("`@("`@("`@
M("`D:61E;G1I='D@/2`D=&AI<RT^7V1E9F%U;'0["B`@("`@("`@?0H*("`@
M("`@("`O*B!#;&5A;B!U<"!!;&EA<RP@5&EE+71O+"!A;F0@0D-#(&%D9')E
M<W-E<RX@*B\*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H
M<"<["B`@("`@("`@9F]R96%C:"`H87)R87DH)V%L:6%S7V%D9'(G+"`G=&EE
M=&]?861D<B<L("=B8V-?861D<B<I(&%S("1V86PI('L*("`@("`@("`@("`@
M)&1A=&$@/2`D=&AI<RT^9V5T5F%L=64H)'9A;"P@)&ED96YT:71Y*3L*("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1D871A*2D@>PH@("`@("`@("`@("`@
M("`@)&1A=&$@/2!I;7!L;V1E*")<;B(L("1D871A*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9&%T82`]('1R:6TH)&1A=&$I.PH@("`@("`@("`@
M("`D9&%T82`]("AE;7!T>2@D9&%T82DI(#\@87)R87DH*2`Z($AO<F1E7T%R
M<F%Y.CIP<F5P87)E061D<F5S<TQI<W0H<')E9U]S<&QI="@B+UM<;EQR72LO
M(BP@)&1A=&$I*3L*("`@("`@("`@("`@)'1H:7,M/G-E=%9A;'5E*"1V86PL
M("1D871A+"`D:61E;G1I='DI.PH@("`@("`@('T*"B`@("`@("`@+RH@4W!L
M:70@=&AE(&QI<W0@;V8@:&5A9&5R<R!B>2!N97<@;&EN97,@86YD('-O<G0@
M=&AE(&QI<W0@;V8@:&5A9&5R<PH@("`@("`@("`J('1O(&UA:V4@<W5R92!T
M:&5R92!A<F4@;F\@9'5P;&EC871E<RX@*B\*("`@("`@("`D;6%I;%]H9'(@
M/2`D=&AI<RT^9V5T5F%L=64H)VUA:6Q?:&1R)RP@)&ED96YT:71Y*3L*("`@
M("`@("!I9B`H:7-?87)R87DH)&UA:6Q?:&1R*2D@>PH@("`@("`@("`@("`D
M;6%I;%]H9'(@/2!I;7!L;V1E*")<;B(L("1M86EL7VAD<BD["B`@("`@("`@
M?0H@("`@("`@("1M86EL7VAD<B`]('1R:6TH)&UA:6Q?:&1R*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1M86EL7VAD<BDI('L*("`@("`@("`@("`@)&UA:6Q?
M:&1R(#T@<W1R7W)E<&QA8V4H)SHG+"`G)RP@)&UA:6Q?:&1R*3L*("`@("`@
M("`@("`@)&UA:6Q?:&1R(#T@<')E9U]S<&QI="@B+UM<;EQR72LO(BP@)&UA
M:6Q?:&1R*3L*("`@("`@("`@("`@)&UA:6Q?:&1R(#T@87)R87E?;6%P*"=T
M<FEM)RP@)&UA:6Q?:&1R*3L*("`@("`@("`@("`@)&UA:6Q?:&1R(#T@87)R
M87E?=6YI<75E*"1M86EL7VAD<BD["B`@("`@("`@("`@(&YA=&-A<V5S;W)T
M*"1M86EL7VAD<BD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YS971686QU
M92@G;6%I;%]H9'(G+"`D;6%I;%]H9'(L("1I9&5N=&ET>2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8V]M<&QE=&4@1G)O;3H@:&5A9&5R
M(&)A<V5D(&]N(&%L;"!R96QE=F5N="!F86-T;W)S("AF=6QL;F%M92P*("`@
M("`J(&9R;VT@861D<F5S<RP@:6YP=70@9FEE;&1S+"!L;V-K<R!E=&,N*0H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9&5N="`@("`@("`@5&AE
M(&ED96YT:71Y('1O(')E=')I979E('1H92!V86QU97,@9G)O;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&9R;VU?861D<F5S<R`@02!D969A=6QT(&9R;VT@
M861D<F5S<R!T;R!U<V4@:68@;F\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:61E;G1I='D@:7,@<V5L96-T960@86YD('1H92!F<F]M
M7V%D9'(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<')E
M9F5R96YC92!I<R!L;V-K960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@($$@9G5L;"!&<F]M.B!H96%D97(@:6X@=&AE(&9O<FUA=`H@("`@("H@
M("`@("`@("`@("`@("`@("=&=6QL;F%M92`\=7-E<D!E>&%M<&QE+F-O;3XG
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&<F]M3&EN92@D:61E;G0@/2!N
M=6QL+"`D9G)O;5]A9&1R97-S(#T@)R<I"B`@("!["B`@("`@("`@9VQO8F%L
M("1I;7`["B`@("`@("`@<W1A=&EC("1F<F]M<R`](&%R<F%Y*"D["@H@("`@
M("`@(&EF("AI<W-E="@D9G)O;7-;)&ED96YT72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1F<F]M<ULD:61E;G1=.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<W-E="@D:61E;G0I*2!["B`@("`@("`@("`@("1A9&1R97-S(#T@)&9R
M;VU?861D<F5S<SL*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D861D
M<F5S<RD@?'P@)'1H:7,M/E]P<F5F<RT^:7-,;V-K960H)V9R;VU?861D<B<I
M*2!["B`@("`@("`@("`@("1A9&1R97-S(#T@)'1H:7,M/F=E=$9R;VU!9&1R
M97-S*"1I9&5N="D["B`@("`@("`@("`@("1N86UE(#T@)'1H:7,M/F=E=$9U
M;&QN86UE*"1I9&5N="D["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1A9&1R97-S*2D@>PH@("`@("`@("`@("`D;V(@/2!I;6%P7W)F8S@R,E]P
M87)S95]A9')L:7-T*"1A9&1R97-S+"`D:6UP6R=M86EL9&]M86EN)UTI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1N86UE*2D@>PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1O8ELP72T^<&5R<V]N86PI*2!["B`@("`@("`@
M("`@("`@("`D;F%M92`]("1O8ELP72T^<&5R<V]N86P["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D;F%M92`]("1T:&ES+3YG971&
M=6QL;F%M92@D:61E;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D9G)O;2`]($U)344Z.G1R:6U%;6%I;$%D9')E<W,H34E-13HZ<F9C
M.#(R5W)I=&5!9&1R97-S*"1O8ELP72T^;6%I;&)O>"P@)&]B6S!=+3YH;W-T
M+"`D;F%M92DI.PH*("`@("`@("`D9G)O;7-;)&ED96YT72`]("1F<F]M.PH@
M("`@("`@(')E='5R;B`D9G)O;3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@86X@87)R87D@=VET:"!&<F]M.B!H96%D97)S(&9R;VT@86QL(&ED
M96YT:71I97,*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@1G)O
M;3H@:&5A9&5R<R!F<F]M(&%L;"!I9&5N=&ET:65S"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$%L;$9R;VU,:6YE<R@I"B`@("!["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]I9&5N=&ET:65S(&%S("1I9&5N="`]/B`D9'5M;7DI('L*
M("`@("`@("`@("`@)&QI<W1;)&ED96YT72`]("1T:&ES+3YG971&<F]M061D
M<F5S<R@D:61E;G0I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&QI<W0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y('=I=&@@
M=&AE(&YE8V5S<V%R>2!V86QU97,@9F]R('1H92!I9&5N=&ET>2!S96QE8W0*
M("`@("`J(&)O>"!I;B!T:&4@24U0(&-O;7!O<V4@=VEN9&]W+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!A<G)A>2!W:71H('1H92!N96-E
M<W-A<GD@<W1R:6YG<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971396QE8W1,
M:7-T*"D*("`@('L*("`@("`@("`D:61S(#T@)'1H:7,M/F=E=$%L;"@G:60G
M*3L*("`@("`@("!F;W)E86-H("@D:61S(&%S("1K97D@/3X@)&ED*2!["B`@
M("`@("`@("`@("1L:7-T6R1K97E=(#T@)'1H:7,M/F=E=$9R;VU!9&1R97-S
M*"1K97DI("X@)R`H)R`N("1I9"`N("<I)SL*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1L:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M<G5E(&EF('1H92!G:79E;B!A9&1R97-S(&)E;&]N9W,@=&\@;VYE(&]F('1H
M92!I9&5N=&ET:65S+@H@("`@("H@5&AI<R!F=6YC=&EO;B!W:6QL('-E87)C
M:"!A;&EA<V5S(&9O<B!A;B!I9&5N=&ET>2!A=71O;6%T:6-A;&QY+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')E<W,@(%1H92!A9&1R97-S
M('1O('-E87)C:"!F;W(@:6X@=&AE(&ED96YT:71I97,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!A9&1R97-S('=A<R!F
M;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S061D<F5S<R@D861D<F5S
M<RD*("`@('L*("`@("`@("!S=&%T:6,@)&QI<W0["@H@("`@("`@("1A9&1R
M97-S(#T@4W1R:6YG.CIL;W=E<B@D861D<F5S<RD["B`@("`@("`@:68@*"%I
M<W-E="@D;&ES="DI('L*("`@("`@("`@("`@)&QI<W0@/2`D=&AI<RT^9V5T
M06QL1G)O;4%D9')E<W-E<RAT<G5E*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!I<W-E="@D;&ES=%LD861D<F5S<UTI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@9G)O;2!A9&1R97-S(&)A<V5D(&]N('1H92!C
M:&]S96X@:61E;G1I='DN($EF(&YO"B`@("`@*B!A9&1R97-S(&-A;B!B92!F
M;W5N9"!I="!I<R!B=6EL="!F<F]M('1H92!C=7)R96YT('5S97(@;F%M92!A
M;F0*("`@("`J('1H92!S<&5C:69I960@;6%I;&1O;6%I;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D:61E;G0@(%1H92!I9&5N=&ET>2!T;R!R
M971R:65V92!T:&4@861D<F5S<R!F<F]M+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!!('9A;&ED(&9R;VT@861D<F5S<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1G)O;4%D9')E<W,H)&ED96YT(#T@;G5L;"D*("`@('L*
M("`@("`@("!G;&]B86P@)&EM<#L*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7V9R;VU,:7-T6R1I9&5N=%TI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V9R;VU,:7-T6R1I9&5N=%T["B`@("`@("`@?0H*("`@("`@("`D
M=F%L(#T@)'1H:7,M/F=E=%9A;'5E*"=F<F]M7V%D9'(G+"`D:61E;G0I.PH@
M("`@("`@(&EF("AE;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`D=F%L(#T@
M)&EM<%LG=7-E<B==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%S=')S='(H
M)'9A;"P@)T`G*2D@>PH@("`@("`@("`@("`D=F%L("X]("=`)R`N("1I;7!;
M)VUA:6QD;VUA:6XG73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9G)O
M;4QI<W1;)&ED96YT72`]("1V86P["@H@("`@("`@(')E='5R;B`D=F%L.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@86QI87-E<R!B87-E
M9"!O;B!T:&4@8VAO<V5N(&ED96YT:71Y+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I9&5N="`@5&AE(&ED96YT:71Y('1O(')E=')I979E('1H
M92!A;&EA<V5S(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M06QI87-E<R!F;W(@=&AE(&ED96YT:71Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971!;&EA<T%D9')E<W,H)&ED96YT*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7V%L:6%S97-;)&ED96YT72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]A;&EA<V5S6R1I9&5N=%T@/2!`87)R87E?;65R9V4H)'1H:7,M
M/F=E=%9A;'5E*"=A;&EA<U]A9&1R)RP@)&ED96YT*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)'1H:7,M/F=E=%9A;'5E*"=R97!L>71O7V%D9'(G+"`D:61E;G0I*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]A;&EA<V5S6R1I9&5N
M=%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y('=I
M=&@@86QL(&ED96YT:71I97,G(&9R;VT@861D<F5S<V5S+@H@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N("1A;&EA<R`@26YC;'5D92!A;&EA<V5S/PH@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!A<G)A>2!W:71H"B`@
M("`@*B`@("`@("`@("`@("`@("!+15D@+2!A9&1R97-S"B`@("`@*B`@("`@
M("`@("`@("`@("!604P@+2!I9&5N=&ET>2!N=6UB97(*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T06QL1G)O;4%D9')E<W-E<R@D86QI87,@/2!F86QS92D*
M("`@('L*("`@("`@("`D;&ES="`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?:61E;G1I=&EE<R!A<R`D:V5Y(#T^("1I9&5N=&ET>2D@
M>PH@("`@("`@("`@("`O*B!'970@1G)O;2!!9&1R97-S97,N("HO"B`@("`@
M("`@("`@("1A9&1R(#T@4W1R:6YG.CIL;W=E<B@D=&AI<RT^9V5T1G)O;4%D
M9')E<W,H)&ME>2DI.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1L:7-T6R1A
M9&1R72DI('L*("`@("`@("`@("`@("`@("1L:7-T6R1A9&1R72`]("1K97D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($=E="!!;&EA<V5S+B`J
M+PH@("`@("`@("`@("!I9B`H)&%L:6%S*2!["B`@("`@("`@("`@("`@("`D
M861D<G,@/2`D=&AI<RT^9V5T06QI87-!9&1R97-S*"1K97DI.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D861D<G,I*2!["B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&%D9')S(&%S("1V86PI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;"`](%-T<FEN9SHZ;&]W97(H)'9A;"D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&QI<W1;)'9A;%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&ES=%LD=F%L72`]("1K
M97D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;&ES=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!A;&P@)W1I92!T;R<@861D<F5S<R]I9&5N=&ET>2!P86ER<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@87)R87D@=VET:`H@
M("`@("H@("`@("`@("`@("`@("`@2T59("T@861D<F5S<PH@("`@("H@("`@
M("`@("`@("`@("`@5D%,("T@:61E;G1I='D@;G5M8F5R"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$%L;%1I94%D9')E<W-E<R@I"B`@("!["B`@("`@("`@
M)&QI<W0@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VED
M96YT:71I97,@87,@)&ME>2`]/B`D:61E;G1I='DI('L*("`@("`@("`@("`@
M)'1I96%D9'(@/2`D=&AI<RT^9V5T5F%L=64H)W1I971O7V%D9'(G+"`D:V5Y
M*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&EE861D<BDI('L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:65A9&1R(&%S("1V86PI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1L:7-T6R1V86Q=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;&ES=%LD=F%L72`]("1K97D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QI<W0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!"0T,@861D<F5S<V5S(&9O<B!A
M(&=I=F5N(&ED96YT:71Y+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1I9&5N="`@5&AE(&ED96YT:71Y('1O(')E=')I979E('1H92!"8V,@861D
M<F5S<V5S(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&%R<F%Y(&]F(&]B:F5C=',@*$E-05`@861D<F5S<V5S*2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0F-C061D<F5S<V5S*"1I9&5N="`](&YU;&PI"B`@
M("!["B`@("`@("`@)&)C8R`]("1T:&ES+3YG971686QU92@G8F-C7V%D9'(G
M+"`D:61E;G0I.PH@("`@("`@(&EF("AE;7!T>2@D8F-C*2D@>PH@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1B8V,I*2!["B`@("`@("`@("`@("`@("`D
M8F-C(#T@87)R87DH)&)C8RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&%D9')E<W-E<R`](&EM<&QO9&4H)RP@)RP@)&)C8RD["B`@("`@("`@("`@
M(')E='5R;B!I;6%P7W)F8S@R,E]P87)S95]A9')L:7-T*"1A9&1R97-S97,L
M("<G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!I9&5N=&ET>2=S(&ED('1H870@;6%T8VAE<R!T:&4@<&%S<V5D(&%D
M9')E<W-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&%D9')E<W-E
M<R`@("`@($5I=&AE<B!A;B!A<G)A>2!O<B!A('-I;F=L92!S=')I;F<@;W(@
M80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VUM82US
M97!A<F%T960@;&ES="!O9B!E;6%I;"!A9&1R97-S97,N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D<V5A<F-H7W1I97,@(%-E87)C:"!F;W(@82!M871C:&EN
M9R!I9&5N=&ET>2!I;B!T:65D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%D9')E<W-E<R!T;V\_"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@:60@;V8@=&AE(&9I<G-T(&ED96YT:71Y('1H870@
M9G)O;2!O<B!A;&EA<PH@("`@("H@("`@("`@("`@("`@("`@("!A9&1R97-S
M97,@;6%T8V@@*&]N92!O9BD@=&AE('!A<W-E9"!A9&1R97-S97,@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@;G5L;"!I9B!N;VYE(&UA=&-H97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$UA=&-H:6YG261E;G1I='DH)&%D9')E
M<W-E<RP@)'-E87)C:%]T:65S(#T@=')U92D*("`@('L*("`@("`@("!S=&%T
M:6,@)'1I95]A9&1R97-S97,L("1O=VY?861D<F5S<V5S.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1T:65?861D<F5S<V5S*2D@>PH@("`@("`@("`@("`D=&EE
M7V%D9')E<W-E<R`]("1T:&ES+3YG971!;&Q4:65!9&1R97-S97,H*3L*("`@
M("`@("`@("`@)&]W;E]A9&1R97-S97,@/2`D=&AI<RT^9V5T06QL1G)O;4%D
M9')E<W-E<RAT<G5E*3L*("`@("`@("!]"@H@("`@("`@("\J($YO<FUA;&EZ
M92!A9&1R97-S(&QI<W0N("HO"B`@("`@("`@:68@*"%I<U]A<G)A>2@D861D
M<F5S<V5S*2D@>PH@("`@("`@("`@("`D861D<F5S<V5S(#T@87)R87DH)&%D
M9')E<W-E<RD["B`@("`@("`@?0H@("`@("`@("1A9&1R97-S97,@/2!I;7!L
M;V1E*"<L("<L("1A9&1R97-S97,I.PH@("`@("`@("1A9&1R97-S97,@/2!I
M;6%P7W)F8S@R,E]P87)S95]A9')L:7-T*"1A9&1R97-S97,L("<G*3L*"B`@
M("`@("`@9F]R96%C:"`H)&%D9')E<W-E<R!A<R`D861D<F5S<RD@>PH@("`@
M("`@("`@("!I9B`H96UP='DH)&%D9')E<W,M/FUA:6QB;W@I*2!["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D9FEN9%]A9&1R97-S(#T@)&%D9')E<W,M/FUA:6QB;W@["B`@("`@("`@
M("`@(&EF("@A96UP='DH)&%D9')E<W,M/FAO<W0I*2!["B`@("`@("`@("`@
M("`@("`D9FEN9%]A9&1R97-S("X]("=`)R`N("1A9&1R97-S+3YH;W-T.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1F:6YD7V%D9')E<W,@/2!3=')I
M;F<Z.FQO=V5R*"1F:6YD7V%D9')E<W,I.PH*("`@("`@("`@("`@+RH@4V5A
M<F-H("=T:65T;R<@861D<F5S<V5S(&9I<G-T+B`J+PH@("`@("`@("`@("`O
M*B!#:&5C:R!F;W(@=&AI<R!A9&1R97-S(&5X<&QI8VET;'DN("HO"B`@("`@
M("`@("`@(&EF("@D<V5A<F-H7W1I97,@)B8@:7-S970H)'1I95]A9&1R97-S
M97-;)&9I;F1?861D<F5S<UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1I95]A9&1R97-S97-;)&9I;F1?861D<F5S<UT["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J($EF('=E(&1I9&XG="!F:6YD('1H92!A9&1R97-S
M+"!C:&5C:R!F;W(@=&AE(&1O;6%I;BX@*B\*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D861D<F5S<RT^:&]S="DI('L*("`@("`@("`@("`@("`@("1H;W-T
M(#T@)T`G("X@)&%D9')E<W,M/FAO<W0["B`@("`@("`@("`@("`@("!I9B`H
M)'-E87)C:%]T:65S("8F("1H;W-T("$]("=`)R`F)B!I<W-E="@D=&EE7V%D
M9')E<W-E<ULD:&]S=%TI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:65?861D<F5S<V5S6R1H;W-T73L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@3F5X="P@<V5A<F-H(&%L;"!F
M<F]M(&%D9')E<W-E<RX@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1O=VY?
M861D<F5S<V5S6R1F:6YD7V%D9')E<W-=*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1O=VY?861D<F5S<V5S6R1F:6YD7V%D9')E<W-=.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S97(G<R!F=6QL(&YA;64N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED96YT("!4:&4@:61E
M;G1I='D@=&\@<F5T<FEE=F4@=&AE(&YA;64@9G)O;2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('5S97(G<R!F=6QL(&YA;64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$9U;&QN86UE*"1I9&5N="`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F%M97-;)&ED96YT72DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;F%M97-;)&ED96YT73L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;F%M97-;)&ED96YT72`]("1T
M:&ES+3YG971686QU92@G9G5L;&YA;64G+"`D:61E;G0I.PH*("`@("`@("!R
M971U<FX@)'1H:7,M/E]N86UE<ULD:61E;G1=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@9G5L;"!S:6=N871U<F4@8F%S960@;VX@=&AE
M(&-U<G)E;G0@<V5T=&EN9W,@9F]R('1H90H@("`@("H@<VEG;F%T=7)E(&ET
M<V5L9BP@=&AE(&1A<VAE<R!A;F0@=&AE('!O<VET:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1I9&5N="`@5&AE(&ED96YT:71Y('1O(')E
M=')I979E('1H92!S:6=N871U<F4@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&9U;&P@<VEG;F%T=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9713:6=N871U<F4H)&ED96YT(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]S:6=N871U<F5S6R1I9&5N=%TI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W-I9VYA='5R97-;)&ED96YT
M73L*("`@("`@("!]"@H@("`@("`@("1V86P@/2`D=&AI<RT^9V5T5F%L=64H
M)W-I9VYA='5R92<L("1I9&5N="D["B`@("`@("`@:68@*"%E;7!T>2@D=F%L
M*2D@>PH@("`@("`@("`@("`D<VEG7V9I<G-T(#T@)'1H:7,M/F=E=%9A;'5E
M*"=S:6=?9FER<W0G+"`D:61E;G0I.PH@("`@("`@("`@("`D<VEG7V1A<VAE
M<R`]("1T:&ES+3YG971686QU92@G<VEG7V1A<VAE<R<L("1I9&5N="D["B`@
M("`@("`@("`@("1V86P@/2!S=')?<F5P;&%C92@B7')<;B(L(")<;B(L("1V
M86PI.PH@("`@("`@("`@("!I9B`H)'-I9U]D87-H97,I('L*("`@("`@("`@
M("`@("`@("1V86P@/2`B+2T@7&XD=F%L(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-S970H)'-I9U]F:7)S="D@)B8@)'-I9U]F:7)S="D@
M>PH@("`@("`@("`@("`@("`@)'9A;"`](")<;B(@+B`D=F%L("X@(EQN7&Y<
M;B(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=F%L
M(#T@(EQN(B`N("1V86P["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG:&]O:W,G75LG<VEG
M;F%T=7)E)UTI*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92!(3U)$15]"
M05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7W-I9VYA='5R92<I*2!["B`@("`@
M("`@("`@("`@("`D=F%L(#T@8V%L;%]U<V5R7V9U;F,H)U]I;7!?:&]O:U]S
M:6=N871U<F4G+"`D=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]S:6=N871U<F5S6R1I9&5N=%T@/2`D=F%L.PH*("`@
M("`@("!R971U<FX@)'9A;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@86X@87)R87D@=VET:"!T:&4@<VEG;F%T=7)E<R!F<F]M(&%L;"!I9&5N
M=&ET:65S"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&%R<F%Y
M('=I=&@@86QL('1H92!S:6=N871U<F5S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971!;&Q3:6=N871U<F5S*"D*("`@('L*("`@("`@("!S=&%T:6,@)&QI
M<W0["@H@("`@("`@(&EF("AI<W-E="@D;&ES="DI('L*("`@("`@("`@("`@
M<F5T=7)N("1L:7-T.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]I9&5N=&ET:65S(&%S("1K97D@/3X@)&ED96YT:71Y*2!["B`@("`@
M("`@("`@("1L:7-T6R1K97E=(#T@)'1H:7,M/F=E=%-I9VYA='5R92@D:V5Y
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&ES=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($!S964@261E;G1I='DZ.F=E=%9A;'5E*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T5F%L=64H)&ME>2P@)&ED96YT:71Y(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H)&ME>2`]/2`G<V5N=%]M86EL7V9O;&1E
M<B<I('L*("`@("`@("`@("`@<F5T=7)N($E-4#HZ9F]L9&5R4')E9BAP87)E
M;G0Z.F=E=%9A;'5E*"=S96YT7VUA:6Q?9F]L9&5R)RP@)&ED96YT:71Y*2P@
M=')U92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!P87)E;G0Z.F=E=%9A
M;'5E*"1K97DL("1I9&5N=&ET>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&%N(&%R<F%Y('=I=&@@=&AE('-E;G0M;6%I;"!F;VQD97(@;F%M
M97,@9G)O;2!A;&P@=&AE"B`@("`@*B!I9&5N=&ET:65S+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!A<G)A>2!W:71H('1H92!F;VQD97(@
M;F%M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%L;%-E;G1M86EL1F]L
M9&5R<R@I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I9&5N=&ET
M:65S(&%S("1K97D@/3X@)&ED96YT:71Y*2!["B`@("`@("`@("`@("1L:7-T
M6R1T:&ES+3YG971686QU92@G<V5N=%]M86EL7V9O;&1E<B<L("1K97DI72`]
M('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>5]K97ES*"1L
M:7-T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!I9B!T
M:&4@;6%I;"!S:&]U;&0@8F4@<V%V960@86YD('1H92!U<V5R(&ES(&%L;&]W
M960@=&\N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED96YT("!4
M:&4@:61E;G1I='D@=&\@<F5T<FEE=F4@=&AE('-E='1I;F<@9G)O;2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('-E;G0@
M;6%I;"!S:&]U;&0@8F4@<V%V960N"B`@("`@*B\*("`@(&9U;F-T:6]N('-A
M=F5396YT;6%I;"@D:61E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M)$=,3T)!3%-;)V-O;F8G75LG=7-E<B==6R=A;&QO=U]F;VQD97)S)UTI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YG971686QU92@G<V%V95]S96YT7VUA:6PG+"`D:61E
M;G0I.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B].;W1I9FEC871I
M;VXO````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<V-@`P,C`T,3$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O;&EB+TYO=&EF:6-A=&EO;B],:7-T96YE<B\`````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8V`#`R,C$W-@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'``````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W-3<`,3`T,3<S-C(W
M-C8`,#(T,C0R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP)SL*"B\J*@H@*B!4:&4@3F]T:69I8V%T
M:6]N7TQI<W1E;F5R7W-T871U<U]I;7`Z.B!C;&%S<R!E>'1E;F1S('1H90H@
M*B!.;W1I9FEC871I;VY?3&ES=&5N97)?<W1A='5S.CH@8VQA<W,@=&\@9&ES
M<&QA>2!T:&4@;65S<V%G97,@9F]R"B`J($E-4"=S('-P96-I86P@;65S<V%G
M92!T>7!E<R`G:6UP+F9O<G=A<F0G(&%N9"`G:6UP+G)E<&QY)RX*("H*("H@
M)$AO<F1E.B!I;7`O;&EB+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP+'8@,2XW+C$P+C,@,C`P-2\Q,"\Q."`Q,CHQ,SHS-B!J86X@17AP("0*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@2&]R9&5?3F]T
M:69I8V%T:6]N"B`J+PIC;&%S<R!.;W1I9FEC871I;VY?3&ES=&5N97)?<W1A
M='5S7VEM<"!E>'1E;F1S($YO=&EF:6-A=&EO;E],:7-T96YE<E]S=&%T=7,@
M>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N
M8W1I;VX@3F]T:69I8V%T:6]N7TQI<W1E;F5R7W-T871U<U]I;7`H*0H@("`@
M>PH@("`@("`@('!A<F5N=#HZ3F]T:69I8V%T:6]N7TQI<W1E;F5R7W-T871U
M<R@I.PH@("`@("`@("1T:&ES+3Y?:&%N9&QE<ULG:6UP+G)E<&QY)UT@/2!T
M<G5E.PH@("`@("`@("1T:&ES+3Y?:&%N9&QE<ULG:6UP+F9O<G=A<F0G72`]
M('1R=64["B`@("`@("`@)'1H:7,M/E]H86YD;&5S6R=I;7`N<F5D:7)E8W0G
M72`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S(&]N92!M
M97-S86=E(&EF(&ET)W,@86X@24U0(&UE<W-A9V4@;W(@8V%L;',@=&AE('!A
M<F5N=`H@("`@("H@;65T:&]D(&]T:&5R=VES92X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&UE<W-A9V4@($]N92!M97-S86=E(&AA<V@@9G)O;2!T
M:&4@<W1A8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@)&5V96YT(#T@)'1H:7,M/F=E=$5V96YT
M*"1M97-S86=E*3L*("`@("`@("!S=VET8V@@*"1M97-S86=E6R=T>7!E)UTI
M('L*("`@("`@("!C87-E("=I;7`N<F5P;'DG.@H@("`@("`@("`@("!R971U
M<FX@)SQP(&-L87-S/2)N;W1I8V4B/B<@+B!(;W)D93HZ:6UG*"=M86EL7V%N
M<W=E<F5D+G!N9R<I("X@)R9N8G-P.R9N8G-P.R<@+B`D979E;G0M/F=E=$UE
M<W-A9V4H*2`N("<\+W`^)SL*"B`@("`@("`@8V%S92`G:6UP+F9O<G=A<F0G
M.@H@("`@("`@(&-A<V4@)VEM<"YR961I<F5C="<Z"B`@("`@("`@("`@(')E
M='5R;B`G/'`@8VQA<W,](FYO=&EC92(^)R`N($AO<F1E.CII;6<H)VUA:6Q?
M9F]R=V%R9&5D+G!N9R<I("X@)R9N8G-P.R9N8G-P.R<@+B`D979E;G0M/F=E
M=$UE<W-A9V4H*2`N("<\+W`^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!P87)E;G0Z.F=E=$UE<W-A9V4H)&UE<W-A9V4I.PH@("`@?0H*?0H`````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI
M8B]1=6]T82\`````````````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,3<P-30`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O;&EB+U%U;W1A+V-Y<G5S+G!H<```````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,S(V`#$P-#$W,S8R-S8V`#`R
M,#<S-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@26UP;&5M96YT871I;VX@;V8@=&AE(%%U;W1A($%0
M22!F;W(@0WER=7,@24U!4"!S97)V97)S+@H@*@H@*B`D2&]R9&4Z(&EM<"]L
M:6(O475O=&$O8WER=7,N<&AP+'8@,2XR,BXQ,"XW(#(P,#8O,#$O,#(@,#DZ
M-30Z-#D@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@24U0(#0N,`H@*B!`<&%C:V%G
M92!)35!?475O=&$*("HO"F-L87-S($E-4%]1=6]T85]C>7)U<R!E>'1E;F1S
M($E-4%]1=6]T82!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!(87-H(&-O;G1A:6YI
M;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!)35!?475O=&%?8WER=7,H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH*("`@("`@("!F;W)E
M86-H("AA<G)A>2@G;&]G:6XG+"`G<&%S<W=O<F0G+"`G=7-E<FAI97)A<F-H
M>2<I(&%S("1V86PI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W!A<F%M<ULD=F%L72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R1V86Q=(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@<75O=&$@:6YF;W)M871I;VX@*'5S960O
M86QL;V-A=&5D*2P@:6X@8GET97,N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@06X@87-S;V-I871I=F4@87)R87DN"B`@("`@*B`@("`@("`@("`@
M("`@("`G;&EM:70G(#T@36%X:6UU;2!Q=6]T82!A;&QO=V5D"B`@("`@*B`@
M("`@("`@("`@("`@("`G=7-A9V4G(#T@0W5R<F5N=&QY('5S960@<&]R=&EO
M;B!O9B!Q=6]T82`H:6X@8GET97,I"B`@("`@*B`@("`@("`@("`@("`@("!2
M971U<FYS(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T475O=&$H*0H@("`@>PH@("`@("`@("1Q=6]T82`](&YU;&P[
M"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)VEM87!?9V5T7W%U;W1A
M<F]O="<I*2!["B`@("`@("`@("`@($`D<75O=&$@/2!I;6%P7V=E=%]Q=6]T
M87)O;W0H)%]315-324].6R=I;7`G75LG<W1R96%M)UTL("=)3D)/6"<I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=')E86T@/2!`:6UA<%]O
M<&5N*$E-4#HZ<V5R=F5R4W1R:6YG*"DL("1T:&ES+3Y?<&%R86US6R=L;V=I
M;B==+"`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72P@3U!?2$%,1D]014XI
M.PH@("`@("`@("`@("!I9B`H)'-T<F5A;2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1Q=6]T82`]($!I;6%P7V=E=%]Q=6]T82@D<W1R96%M+"`D
M=&AI<RT^7W!A<F%M<ULG=7-E<FAI97)A<F-H>2==("X@)%]315-324].6R=I
M;7`G75LG=7-E<B==*3L*("`@("`@("`@("`@("`@($!I;6%P7V-L;W-E*"1S
M=')E86TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AI
M<U]A<G)A>2@D<75O=&$I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D<75O
M=&%;)VQI;6ET)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M)W5S86=E)R`]/B`D<75O=&%;)W5S86=E)UT@*B`Q,#(T+"`G;&EM:70G(#T^
M("1Q=6]T85LG;&EM:70G72`J(#$P,C0I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H:7-S970H)'%U;W1A6R=35$]204=%)UU;)VQI;6ET)UTI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH)W5S86=E)R`]/B`D<75O=&%;)U-4
M3U)!1T4G75LG=7-A9V4G72`J(#$P,C0L("=L:6UI="<@/3X@)'%U;W1A6R=3
M5$]204=%)UU;)VQI;6ET)UT@*B`Q,#(T*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@87)R87DH)W5S86=E)R`]/B`P+"`G;&EM:70G(#T^
M(#`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O(')E=')I979E('%U;W1A(BDL("=H;W)D92YE<G)O
M<B<I.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+U%U;W1A+VUE<F-U<GDS
M,BYP:'``````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-#4U`#$P
M-#$W,S8R-S8V`#`R,30R-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@26UP;&5M96YT871I;VX@;V8@
M=&AE(%%U;W1A($%022!F;W(@365R8W5R>2\S,B!)34%0('-E<G9E<G,N"B`J
M($9O<B!R96%D:6YG(%%U;W1A+"!R96%D('-I>F4@9F]L9&5R('5S97(N"B`J
M"B`J(%)E<75I<F5S('1H92!F;VQL;W=I;F<@<&%R86UE=&5R('-E='1I;F=S
M(&EN(&EM<"]S97)V97)S+G!H<#H*("H@)W%U;W1A)R`]/B!A<G)A>2@*("H@
M("`@("=D<FEV97(G(#T^("=M97)C=7)Y,S(G+`H@*B`@("`@)W!A<F%M<R<@
M/3X@87)R87DH"B`J("`@("`@("`@)VUA:6Q?=7-E<E]F;VQD97(G(#T^("=C
M.B]M97)C<GDO;6%I;"<*("H@("`@("D*("H@*3L*("H*("H@;6%I;%]U<V5R
M7V9O;&1E<B`M+2`@5&AE('!A=&@@=&\@9F]L9&5R(&UA:6P@;65R8W5R>0H@
M*@H@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH*("H@4%)/0DQ%
M32!43R!!0T-%4U,@3D545T]22R!$25)%0T]44ED*("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ"B`J($UA='0@1W)I;6T*("H@,#8M2G5N+3(P
M,#,@,3`Z,C4*("H*("H@5&AO=6=H="!)(&-O=6QD(&AE;'`@8VQA<FEF>2!S
M;VUE=&AI;F<@=VET:"!A8V-E<W-I;F<@;F5T=V]R:R!S:&%R97,@;VX@80H@
M*B!7:6YD;W=S(&YE='=O<FL@*#(P,#`@:6X@=&AI<R!C87-E*2P@<G5N;FEN
M9R!02%`@-"XS+C(@=6YD97(@07!A8VAE(#(N,"XT-"X*("H@2&]W979E<B!Y
M;W4@87)E(&QO9V=E9"!I;G1O('1H92!7:6YD;W=S(&)O>"P@>6]U<B!!<&%C
M:&4@<V5R=FEC92!M=7-T(&)E"B`J(')U;FYI;F<@=6YD97(@86X@86-C;W5N
M="!W:&EC:"!H87,@86-C97-S('1O('1H92!S:&%R92X@(%1H92!E87-I97-T
M("AA;F0*("H@<')O8F%B;'D@;&5A<W0@<V%F92D@=V%Y(&9O<B!M92!W87,@
M=&\@8VAA;F=E('1H92!U<V5R(&9O<B!T:&4@07!A8VAE"B`J('-E<G9I8V4@
M=&\@=&AE(&-O;7!U=&5R(&%D;6EN:7-T<F%T;W(@*&1O('1H:7,@:6X@=&AE
M('-E<G9I8V4@<')O<&5R=&EE<RP*("H@=6YD97(@=&AE("),;V<@3VXB('1A
M8BDN("!!9G1E<B!R97-T87)T:6YG($%P86-H92P@22!C;W5L9"!A8V-E<W,@
M;6%P<&5D"B`J(&1R:79E<R!B>2!T:&5I<B!A<W-I9VYE9"!D<FEV92!L971T
M97(@*")Z.EQ<(BD@;W(@<F5G=6QA<B!S:&%R97,@8GD@=&AE:7(*("H@54Y#
M('!A=&@@*")<7%Q<<VAA<F5$<FEV95Q<<VAA<F5$:7(B*2X*("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ"B`J"B`J("1(;W)D93H@:6UP+VQI
M8B]1=6]T82]M97)C=7)Y,S(N<&AP+'8@,2XQ+C$P+C<@,C`P-B\P,2\P,2`R
M,3HR.#HU.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!&
M<F%N:R!,=7!O(#QF<F%N:U]L=7!O0&5M86EL+FET/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($9R86YK($QU<&\@/&9R86YK7VQU<&]`96UA:6PN:70^
M"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@24U07U%U;W1A"B`J
M+PIC;&%S<R!)35!?475O=&%?;65R8W5R>3,R(&5X=&5N9',@24U07U%U;W1A
M('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T
M:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($E-4%]1=6]T
M85]M97)C=7)Y,S(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('%U;W1A(&EN9F]R;6%T:6]N("AU<V5D+V%L;&]C871E9"DL(&EN
M(&)Y=&5S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($%N(&%S<V]C
M:6%T:79E(&%R<F%Y+@H@("`@("H@("`@("`@("`@("`@("`@)VQI;6ET)R`]
M($UA>&EM=6T@<75O=&$@86QL;W=E9`H@("`@("H@("`@("`@("`@("`@("`@
M)W5S86=E)R`]($-U<G)E;G1L>2!U<V5D('!O<G1I;VX@;V8@<75O=&$@*&EN
M(&)Y=&5S*0H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U;W1A
M*"D*("`@('L*("`@("`@("`D<75O=&$@/2!N=6QL.PH*("`@("`@("`D9&ER
M7W!A=&@@/2`D=&AI<RT^7W!A<F%M<ULG;6%I;%]U<V5R7V9O;&1E<B==("X@
M)R\G("X@)%]315-324].6R=I;7`G75LG=7-E<B==("X@)R\G.PH@("`@("`@
M(&EF("@D9&ER(#T@0&]P96YD:7(H)&1I<E]P871H*2D@>PH@("`@("`@("`@
M("!W:&EL92`H*"1F:6QE(#T@<F5A9&1I<B@D9&ER*2D@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`D<75O=&$@*ST@9FEL97-I>F4H)&1I<E]P871H
M("X@)&9I;&4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E9&ER
M*"1D:7(I.PH*("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1Q=6]T82DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@G=7-A9V4G(#T^("1Q=6]T
M82P@)VQI;6ET)R`]/B`P*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5T
M<FEE=F4@<75O=&$B*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]L:6(O475O=&$O8V]M;6%N9"YP:'``````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4U-#8`,3`T,3<S-C(W-C8`,#(Q,C$R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!);7!L96UE;G1A=&EO;B!O9B!T:&4@475O=&$@05!)(&9O
M<B!)34%0('-E<G9E<G,@=VET:"!A('5N:7@@<75O=&$@8V]M;6%N9"X*("H@
M5&AI<R!R97%U:7)E<R!A(&UO9&EF:65D(")Q=6]T82(@8V]M;6%N9"!T:&%T
M(&%L;&]W<R!T:&4@:'1T<&0@<V5R=F5R"B`J(&%C8V]U;G0@=&\@9V5T('%U
M;W1A<R!F;W(@;W1H97(@=7-E<G,N($ET(&%L<V\@<F5Q=6ER97,@=&AA="!Y
M;W5R"B`J('=E8B!S97)V97(@86YD(&EM87`@<V5R=F5R(&)E('1H92!S86UE
M('-E<G9E<B!O<B!A="!L96%S="!H879E('-H87)E9`H@*B!A=71H96YT:6-A
M=&EO;B!A;F0@9FEL92!S97)V97)S("AE+F<N('9I82!.25,O3D93*2X@($%N
M9"!L87-T+"!I="`H87,*("H@=W)I='1E;BD@<F5Q=6ER97,@=&AE(%!/4TE8
M(%!(4"!E>'1E;G-I;VYS+@H@*@H@*B!9;W4@;75S="!C;VYF:6=U<F4@=&AI
M<R!D<FEV97(@:6X@:&]R9&4O:6UP+V-O;F9I9R]S97)V97)S+G!H<"X@(%1H
M90H@*B!D<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!P87)A;65T97)S
M.@H@*B`@("=Q=6]T85]P871H)R`]/B!0871H('1O('1H92!Q=6]T82!B:6YA
M<GD@+2!215%525)%1`H@*B`@("=G<F5P7W!A=&@G("`]/B!0871H('1O('1H
M92!G<F5P(&)I;F%R>2`M(%)%455)4D5$"B`J("`@)W!A<G1I=&EO;B<@(#T^
M($EF(&%L;"!U<V5R(&UA:6QB;WAE<R!A<F4@;VX@82!S:6YG;&4@<&%R=&ET
M:6]N+"!T:&4*("H@("`@("`@("`@("`@("`@("`@<&%R=&ET:6]N(&QA8F5L
M+B`@0GD@9&5F875L="P@<75O=&$@=VEL;"!D971E<FUI;F4*("H@("`@("`@
M("`@("`@("`@("`@<75O=&$@:6YF;W)M871I;VX@=7-I;F<@=&AE('5S97(G
M<R!H;VUE(&1I<F5C=&]R>2!V86QU92X*("H*("H@)$AO<F1E.B!I;7`O;&EB
M+U%U;W1A+V-O;6UA;F0N<&AP+'8@,2XQ,2XQ,"XY(#(P,#8O,#(O,3`@,#0Z
M-3@Z,C8@<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M17)I8R!*;VX@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T
M97AA<RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@17)I8R!2;W-T
M971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@
M0'-I;F-E("`@24U0(#0N,`H@*B!`<&%C:V%G92!)35!?475O=&$*("HO"F-L
M87-S($E-4%]1=6]T85]C;VUM86YD(&5X=&5N9',@24U07U%U;W1A('L*"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($E-4%]1=6]T85]C;VUM
M86YD*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@87)R87DH"B`@("`@("`@("`@("=Q=6]T85]P871H)R`]/B`G
M<75O=&$G+`H@("`@("`@("`@("`G9W)E<%]P871H)R`@/3X@)V=R97`G+`H@
M("`@("`@("`@("`G<&%R=&ET:6]N)R`@/3X@;G5L;`H@("`@("`@("D["@H@
M("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H)'1H:7,M/E]P
M87)A;7,L("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('%U
M;W1A(&EN9F]R;6%T:6]N("AU<V5D+V%L;&]C871E9"DL(&EN(&)Y=&5S+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($%N(&%S<V]C:6%T:79E(&%R
M<F%Y+@H@("`@("H@("`@("`@("`@("`@("`@)VQI;6ET)R`]($UA>&EM=6T@
M<75O=&$@86QL;W=E9`H@("`@("H@("`@("`@("`@("`@("`@)W5S86=E)R`]
M($-U<G)E;G1L>2!U<V5D('!O<G1I;VX@;V8@<75O=&$@*&EN(&)Y=&5S*0H@
M("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U;W1A*"D*("`@('L*
M("`@("`@("`D:6UA<%]U<V5R(#T@<W1R=&]L;W=E<B@D1TQ/0D%,4ULG:6UP
M)UU;)W5S97(G72D["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=P87)T:71I;VXG72DI('L*("`@("`@("`@("`@)'!A<W-W9%]A<G)A>2`]
M('!O<VEX7V=E='!W;F%M*"1I;6%P7W5S97(I.PH@("`@("`@("`@("!L:7-T
M*"1J=6YK+"`D<V5A<F-H7W-T<FEN9RP@)&IU;FLI(#T@97AP;&]D92@G+R<L
M("1P87-S=V1?87)R87E;)V1I<B==*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<V5A<F-H7W-T<FEN9R`]("1T:&ES+3Y?<&%R86US6R=P87)T
M:71I;VXG73L*("`@("`@("!]"B`@("`@("`@)&-M9&QI;F4@/2`D=&AI<RT^
M7W!A<F%M<ULG<75O=&%?<&%T:"==("X@)R`M=2`G("X@)&EM87!?=7-E<B`N
M("<@?"`G("X*("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=G
M<F5P7W!A=&@G72`N("<@)R`N("1S96%R8VA?<W1R:6YG.PH@("`@("`@(&5X
M96,H)&-M9&QI;F4L("1Q=6]T85]D871A+"`D<F5T=7)N7V-O9&4I.PH@("`@
M("`@(&EF("@H)')E='5R;E]C;V1E(#T](#`I("8F("AC;W5N="@D<75O=&%?
M9&%T82D@/3T@,2DI('L*("`@("`@("`@("`D<75O=&$@/2!S<&QI="@B6ULZ
M8FQA;FLZ75TK(BP@=')I;2@D<75O=&%?9&%T85LP72DI.PH@("`@("`@("`@
M(')E='5R;B!A<G)A>2@G=7-A9V4G(#T^("1Q=6]T85LQ72`J(#$P,C0L("=L
M:6UI="<@/3X@)'%U;W1A6S)=("H@,3`R-"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R971R:65V
M92!Q=6]T82(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]1
M=6]T82]L;V=F:6QE+G!H<```````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-C4U-``Q,#0Q-S,V,C<V-@`P,C$R,34`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($EM<&QE
M;65N=&%T:6]N(&]F('1H92!1=6]T82!!4$D@9F]R('-E<G9E<G,@=VAE<F4@
M24U!4"!1=6]T82!I<R!N;W0*("H@<W5P<&]R=&5D+"!B=70@:70@87!P96%R
M<R!I;B!T:&4@<V5R=F5R<R!M97-S86=E<R!L;V<@9F]R('1H92!)34%0"B`J
M('-E<G9E<BX*("H*("H@4F5Q=6ER97,@=&AE(&9O;&QO=VEN9R!P87)A;65T
M97(@<V5T=&EN9W,@:6X@:6UP+W-E<G9E<G,N<&AP.@H@*B`G<75O=&$G(#T^
M(&%R<F%Y*`H@*B`@("`@)V1R:79E<B<@/3X@)VQO9V9I;&4G+`H@*B`@("`@
M)W!A<F%M<R<@/3X@87)R87DH"B`J("`@("`@("`@)VQO9V9I;&4G(#T^("<O
M<&%T:"]T;R]L;V<O9FEL92<L"B`J("`@("`@("`@)W1A:6QL:6YE<R<@/3X@
M,3`L"B`J("`@("`@("`@)T944&UA:6PG("`@/3X@)T944"<L"B`J("`@("`@
M("`@)V)E9VEN;V-C)R`@/3X@)W5S86=E(#T@)RP*("H@("`@("`@("`G;6ED
M;V-C)R`@("`]/B`G(&]F("<L"B`J("`@("`@("`@)V5N9&]C8R<@("`@/3X@
M)R!B>71E<R<*("H@("`@("D*("H@*3L*("H*("H@;&]G9FEL92`@("`M+2`@
M5&AE('!A=&@O=&\O9FEL96YA;64@;V8@=&AE(&QO9R!F:6QE('1O('5S92X*
M("H@=&%I;&QI;F5S("`M+2`@5&AE(&YU;6)E<B!O9B!L:6YE<R!T;R!L;V]K
M(&%T(&EN('1H92!T86EL(&]F('1H92!L;V=F:6QE+@H@*B!&5%!M86EL("`@
M("TM("!)9B!Y;W4@=V%N="!T;R!S:&]W('=H870@1E10('-P86-E(&ES(&%V
M86EL86)L92`H24U!4"!F;VQD97(I"B`J("`@("`@("`@("`@("`@(&]R('=H
M870@;6%I;"!S<&%C92!I<R!A=F%I;&%B;&4@*$E.0D]8*2X*("H@("`@("`@
M("`@("`@("`@1&5F:6YE<R!T:&4@<V5A<F-H('-T<FEN9R!T;R!U<V5R;F%M
M93H*("H@("`@("`@("`@("`@("`@("!&5%!M86EL('1O(&ED96YT:69Y('1H
M92!L:6YE('=I=&@@455/5$$@:6YF;RX*("H@8F5G:6YO8V,@("`M+2`@4W1R
M:6YG('1H870@9&5S:6=N871E<R!T:&4@8VAA<F%C=&5R<R!B969O<F4@=&AE
M('5S86=E"B`J("`@("`@("`@("`@("`@(&YU;6)E<BX*("H@;6ED;V-C("`@
M("`M+2`@4W1R:6YG(&)E='=E96X@=7-A9V4@86YD('1O=&%L('-T;W)A9V4@
M<W!A8V4N"B`J(&5N9&]C8R`@("`@+2T@(%-T<FEN9R!A9G1E<B!T:&4@<W1O
M<F%G92!N=6UB97(N"B`J"B`J("1(;W)D93H@:6UP+VQI8B]1=6]T82]L;V=F
M:6QE+G!H<"QV(#$N-2XQ,"XT(#(P,#4O,3`O,3@@,3(Z,3,Z,S8@:F%N($5X
M<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@5&EM($=O<G1E<B`\96UA
M:6Q`=&5L971E8VAN:6-S+F-O+FYZ/@H@*B!`<VEN8V4@("!)35`@-"XP"B`J
M($!P86-K86=E($E-4%]1=6]T80H@*B\*8VQA<W,@24U07U%U;W1A7VQO9V9I
M;&4@97AT96YD<R!)35!?475O=&$@>PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@2&%S
M:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@24U07U%U;W1A7VQO9V9I;&4H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>2@*("`@
M("`@("`@("`@)VQO9V9I;&4G("`@/3X@)R<L"B`@("`@("`@("`@("=T86EL
M;&EN97,G(#T^(#$P+`H@("`@("`@("`@("`G1E10;6%I;"<@("`]/B`G1E10
M)RP*("`@("`@("`@("`@)V)E9VEN;V-C)R`@/3X@)W5S86=E(#T@)RP*("`@
M("`@("`@("`@)VUI9&]C8R<@("`@/3X@)R!O9B`G+`H@("`@("`@("`@("`G
M96YD;V-C)R`@("`]/B`G(&)Y=&5S)PH@("`@("`@("D["@H@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H)'1H:7,M/E]P87)A;7,L("1P
M87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('%U;W1A(&EN9F]R
M;6%T:6]N("AU<V5D+V%L;&]C871E9"DL(&EN(&)Y=&5S+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($%N(&%S<V]C:6%T:79E(&%R<F%Y+@H@("`@
M("H@("`@("`@("`@("`@("`@)VQI;6ET)R`]($UA>&EM=6T@<75O=&$@86QL
M;W=E9`H@("`@("H@("`@("`@("`@("`@("`@)W5S86=E)R`]($-U<G)E;G1L
M>2!U<V5D('!O<G1I;VX@;V8@<75O=&$@*&EN(&)Y=&5S*0H@("`@("H@("`@
M("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U;W1A*"D*("`@('L*("`@("`@("!G
M;&]B86P@)&EM<#L*"B`@("`@("`@:68@*&ES7V9I;&4H)'1H:7,M/E]P87)A
M;7-;)VQO9V9I;&4G72DI('L*("`@("`@("`@("`@)&9U;&P@/2!F:6QE*"1T
M:&ES+3Y?<&%R86US6R=L;V=F:6QE)UTI.PH@("`@("`@("`@("!F;W(@*"`[
M("1T:&ES+3Y?<&%R86US6R=T86EL;&EN97,G72`^(#`@.R`D=&AI<RT^7W!A
M<F%M<ULG=&%I;&QI;F5S)UTM+2D@>PH@("`@("`@("`@("`@("`@)'1A:6Q;
M72`]("1F=6QL6V-O=6YT*"1F=6QL*2TD=&AI<RT^7W!A<F%M<ULG=&%I;&QI
M;F5S)UU=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1U;F%M92`@("`]
M("1I;7!;)W5S97(G73L*("`@("`@("`@("`@)$944&UA:6P@(#T@)'1H:7,M
M/E]P87)A;7-;)T944&UA:6PG73L*("`@("`@("`@("`@)'9I<G1L:6YE(#T@
M<')E9U]G<F5P*");)'5N86UE.B`D1E10;6%I;%TB+"`D=&%I;"D["B`@("`@
M("`@("`@("1V:7)T;&EN92`]("AA<G)A>5]V86QU97,H)'9I<G1L:6YE*2D[
M"B`@("`@("`@("`@("1U<V%G92`@("`]('-U8G-T<B@B)'9I<G1L:6YE6S!=
M(BP@<W1R<&]S*"(D=FER=&QI;F5;,%TB+"`D=&AI<RT^7W!A<F%M<ULG8F5G
M:6YO8V,G72D@*R!S=')L96XH)'1H:7,M/E]P87)A;7-;)V)E9VEN;V-C)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("!S=')P;W,H(B1V:7)T;&EN95LP
M72(L("1T:&ES+3Y?<&%R86US6R=M:61O8V,G72DI.PH@("`@("`@("`@("`D
M<W1O<F%G92`@/2!S=6)S='(H(B1V:7)T;&EN95LP72(L('-T<G!O<R@B)'9I
M<G1L:6YE6S!=(BP@)'1H:7,M/E]P87)A;7-;)VUI9&]C8R==*2`K('-T<FQE
M;B@D=&AI<RT^7W!A<F%M<ULG;6ED;V-C)UTI+`H@("`@("`@("`@("`@("`@
M("`@("`@("!S=')P;W,H(B1V:7)T;&EN95LP72(L("1T:&ES+3Y?<&%R86US
M6R=E;F1O8V,G72DI.PH@("`@("`@("`@("!R971U<FX@87)R87DH)W5S86=E
M)R`]/B`D=7-A9V4L("=L:6UI="<@/3X@)'-T;W)A9V4I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M<F5T<FEE=F4@<75O=&$B*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O
M475O=&$O8V]U<FEE<BYP:'``````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#,V,C$`,3`T,3<S-C(W-C8`,#(Q,C,T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!);7!L
M96UE;G1A=&EO;B!O9B!T:&4@475O=&$@05!)(&9O<B!#;W5R:65R($E-05`@
M<V5R=F5R<RX*("H*("H@)$AO<F1E.B!I;7`O;&EB+U%U;W1A+V-O=7)I97(N
M<&AP+'8@,2XR,2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z-3D@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK
M94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`
M<VEN8V4@("!)35`@-"XP"B`J($!P86-K86=E($E-4%]1=6]T80H@*B\*8VQA
M<W,@24U07U%U;W1A7V-O=7)I97(@97AT96YD<R!)35!?475O=&$@>PH*("`@
M("\J*@H@("`@("H@1V5T('%U;W1A(&EN9F]R;6%T:6]N("AU<V5D+V%L;&]C
M871E9"DL(&EN(&)Y=&5S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M($%N(&%S<V]C:6%T:79E(&%R<F%Y+@H@("`@("H@("`@("`@("`@("`@("`@
M)VQI;6ET)R`]($UA>&EM=6T@<75O=&$@86QL;W=E9`H@("`@("H@("`@("`@
M("`@("`@("`@)W5S86=E)R`]($-U<G)E;G1L>2!U<V5D('!O<G1I;VX@;V8@
M<75O=&$@*&EN(&)Y=&5S*0H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N
M<R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%%U;W1A*"D*("`@('L*("`@("`@("`D<75O=&$@/2!N=6QL.PH*("`@
M("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%P7V=E=%]Q=6]T87)O;W0G
M*2D@>PH@("`@("`@("`@("!`)'%U;W1A(#T@:6UA<%]G971?<75O=&%R;V]T
M*"1?4T534TE/3ELG:6UP)UU;)W-T<F5A;2==+"`G24Y"3U@G*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@
M+B`G+VQI8B])34%0+G!H<"<["B`@("`@("`@("`@("1I;7!?:6UA<"`]("9)
M35!?24U!4#HZ<VEN9VQE=&]N*"D["B`@("`@("`@("`@("1S=')E86T@/2`D
M:6UP7VEM87`M/F]P96Y)34%04W1R96%M*&YU;&PL($]07TA!3$9/4$5.*3L*
M"B`@("`@("`@("`@(&EF("@D<W1R96%M("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)'%U;W1A(#T@0&EM87!?9V5T7W%U;W1A*"1S=')E86TL("=2
M3T]4)RD["B`@("`@("`@("`@("`@("!`:6UA<%]C;&]S92@D<W1R96%M*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H:7-?87)R87DH
M)'%U;W1A*2D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)'%U;W1A*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D<75O=&%;)VQI;6ET)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=U<V%G92<@/3X@
M)'%U;W1A6R=U<V%G92==("H@,3`R-"P@)VQI;6ET)R`]/B`D<75O=&%;)VQI
M;6ET)UT@*B`Q,#(T*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@A96UP
M='DH)'%U;W1A6R=35$]204=%)UU;)VQI;6ET)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"=U<V%G92<@/3X@)'%U;W1A6R=35$]2
M04=%)UU;)W5S86=E)UT@*B`Q,#(T+"`G;&EM:70G(#T^("1Q=6]T85LG4U1/
M4D%'12==6R=L:6UI="==("H@,3`R-"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=U<V%G92<@
M/3X@,"P@)VQI;6ET)R`]/B`P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R971R:65V92!Q=6]T
M82(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+U%U;W1A
M+VUD865M;VXN<&AP````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`V-3,V`#$P-#$W,S8R-S8V`#`R,3(Q-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@26UP;&5M96YT
M871I;VX@;V8@=&AE(%%U;W1A($%022!F;W(@341A96UO;B!S97)V97)S+@H@
M*@H@*B!087)A;65T97)S(')E<75I<F5D.@H@*B`@("=A<'!?;&]C871I;VXG
M("`M+2`@5$]$3PH@*@H@*B`D2&]R9&4Z(&EM<"]L:6(O475O=&$O;61A96UO
M;BYP:'`L=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HU.2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J
M($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@24U07U%U;W1A"B`J+PIC
M;&%S<R!)35!?475O=&%?;61A96UO;B!E>'1E;F1S($E-4%]1=6]T82!["@H@
M("`@+RHJ"B`@("`@*B!'970@<75O=&$@:6YF;W)M871I;VX@*'5S960O86QL
M;V-A=&5D*2P@:6X@8GET97,N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@06X@87-S;V-I871I=F4@87)R87DN"B`@("`@*B`@("`@("`@("`@("`@
M("`G;&EM:70G(#T@36%X:6UU;2!Q=6]T82!A;&QO=V5D"B`@("`@*B`@("`@
M("`@("`@("`@("`G=7-A9V4G(#T@0W5R<F5N=&QY('5S960@<&]R=&EO;B!O
M9B!Q=6]T82`H:6X@8GET97,I"B`@("`@*B`@("`@("`@("`@("`@("!2971U
M<FYS(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T475O=&$H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D:6UP.PH*("`@
M("`@("`D=7-E<D1E=&%I;',@/2`D=&AI<RT^7V=E=%5S97)$971A:6QS*"1I
M;7!;)W5S97(G72P@)&EM<%LG;6%I;&1O;6%I;B==*3L*"B`@("`@("`@:68@
M*"1U<V5R1&5T86EL<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'5S97)(
M;VUE(#T@=')I;2AS=6)S='(H)'5S97)$971A:6QS+"`Q,#4L(#DP*2D["B`@
M("`@("`@("`@("1T;W1A;"`](&EN='9A;"AS=6)S='(H)'5S97)$971A:6QS
M+"`R,CDL(#8I*2`J(#$P,C0["@H@("`@("`@("`@("!I9B`H)'1O=&%L(#T]
M(#`I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@G=7-A9V4G(#T^
M(#`L("=L:6UI="<@/3X@,"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@H)'1A:V5N(#T@)'1H:7,M/E]M86EL8F]X4VEZ92@D=7-E<DAO;64I
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@G
M=7-A9V4G(#T^("1T86ME;BP@)VQI;6ET)R`]/B`D=&]T86PI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")5;F%B;&4@=&\@<F5T<FEE=F4@<75O=&$B*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('-I>F4@;V8@
M82!M86EL8F]X"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(&9U;&P@<&%T:"!O
M9B!T:&4@;6%I;&)O>"!T;R!F971C:"!T:&4@<75O=&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@9F]R(&EN8VQU9&EN9R!T<F%I;&EN9R!B86-K<VQA
M<V@N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&YU;6)E<B!O
M9B!B>71E<R!I;B!T:&4@;6%I;&)O>"`H:6YT96=E<BD@;W(@9F%L<V4*("`@
M("`J("`@("`@("`@("`@("`@("AB;V]L96%N*2!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7VUA:6QB;WA3:7IE*"1P871H*0H@("`@>PH@("`@
M("`@("1C;VYT96YT<R`](&9I;&5?9V5T7V-O;G1E;G1S*"1P871H("X@)UQI
M;6%P+FUR:R<I.PH*("`@("`@("`D<&]I;G1E<B`](#,V.PH@("`@("`@("1S
M:7IE(#T@,#L*("`@("`@("!W:&EL92`H)'!O:6YT97(@/"!S=')L96XH)&-O
M;G1E;G1S*2D@>PH@("`@("`@("`@("`D9&5T86EL<R`]('5N<&%C:R@G83$W
M1FEL96YA;64O83$Q0W)A<"]64VEZ92<L('-U8G-T<B@D8V]N=&5N=',L("1P
M;VEN=&5R+"`S-BDI.PH@("`@("`@("`@("`D<VEZ92`K/2`D9&5T86EL<ULG
M4VEZ92==.PH@("`@("`@("`@("`D<&]I;G1E<B`K/2`S-CL*("`@("`@("!]
M"@H@("`@("`@("\J(%)E8W5R<VEV;'D@8VAE8VL@<W5B9F]L9&5R<RX@*B\*
M("`@("`@("`D9"`](&1I<B@D<&%T:"D["B`@("`@("`@=VAI;&4@*"@D96YT
M<GD@/2`D9"T^<F5A9"@I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@:68@
M*"@D96YT<GD@(3T@)RXG*2`F)@H@("`@("`@("`@("`@("`@*"1E;G1R>2`A
M/2`G+BXG*2`F)@H@("`@("`@("`@("`@("`@*'-U8G-T<B@D96YT<GDL("TU
M+"`U*2`]/2`G+DE-05`G*2D@>PH@("`@("`@("`@("`@("`@)'-I>F4@*ST@
M)'1H:7,M/E]M86EL8F]X4VEZ92@D<&%T:"`N("1E;G1R>2`N("=<7"<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1D+3YC;&]S92@I.PH*
M("`@("`@("!R971U<FX@)'-I>F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V92!R96QE=F%N="!L:6YE(&9R;VT@=7-E<FQI<W0N9&%T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("!4:&4@=7-E<FYA;64@
M9F]R('=H:6-H('1O(')E=')I979E(&1E=&%L<RX*("`@("`J($!P87)A;2!S
M=')I;F<@)')E86QM("!4:&4@<F5A;&T@*&1O;6%I;BD@9F]R('1H92!U<V5R
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($QI;F4@9G)O;2!U<V5R
M;&ES="YD870@*'-T<FEN9RD@;W(@9F%L<V4@*&)O;VQE86XI+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9V5T57-E<D1E=&%I;',H)'5S97(L("1R96%L;2D*
M("`@('L*("`@("`@("`D<V5A<F-H4W1R:6YG(#T@<W1R7W!A9"@D<F5A;&TL
M(#0U*2`N('-T<E]P860H)'5S97(L(#,P*3L*"B`@("`@("`@:68@*"$H)&9P
M(#T@9F]P96XH)'1H:7,M/E]P87)A;7-;)V%P<%]L;V-A=&EO;B==("X@)R]U
M<V5R;&ES="YD870G+"`G<F(G*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*"%F96]F*"1F<"DI('L*
M("`@("`@("`@("`@)&QI;F4@/2!F9V5T<R@D9G`L(#0P.38I.PH@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1L:6YE+"`P+"!S=')L96XH)'-E87)C:%-T<FEN
M9RDI(#T]("1S96%R8VA3=')I;F<I('L*("`@("`@("`@("`@("`@(&9C;&]S
M92@D9G`I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1L:6YE.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]-86EL
M8F]X+G!H<```````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#$P,38W-@`Q,#0Q-S,V,C<V-@`P,C`P-S<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"F1E9FEN92@G24U07TU!
M24Q"3UA?34]612<L(#$I.PID969I;F4H)TE-4%]-04E,0D]87T-/4%DG+"`R
M*3L*9&5F:6YE*"=)35!?34%)3$)/6%]$14Q%5$4G+"`S*3L*9&5F:6YE*"=)
M35!?34%)3$)/6%]53D1%3$5412<L(#0I.PID969I;F4H)TE-4%]-04E,0D]8
M7T584%5.1T4G+"`U*3L*9&5F:6YE*"=)35!?34%)3$)/6%]%35!462<L(#8I
M.PID969I;F4H)TE-4%]-04E,0D]87U501$%412<L(#<I.PH*+RHJ"B`J(%1H
M92!)35!?36%I;&)O>#HZ(&-L87-S(&-O;G1A:6YS(&%L;"!C;V1E(')E;&%T
M960@=&\@:&%N9&QI;F<@;6%I;&)O>`H@*B!A8V-E<W,N"B`J"B`J("1(;W)D
M93H@:6UP+VQI8B]-86EL8F]X+G!H<"QV(#$N-S8N,3`N-30@,C`P-B\P,B\R
M,2`Q-SHQ-SHT.2!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E
M("`@24U0(#0N,`H@*B!`<&%C:V%G92!)35`*("HO"F-L87-S($E-4%]-86EL
M8F]X('L*"B`@("`O*BH*("`@("`J(%1H92!L;V-A=&EO;B!I;B!T:&4@<V]R
M=&5D(&%R<F%Y('=E(&%R92!A="X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G
M97(*("`@("`J+PH@("`@=F%R("1?87)R87E);F1E>"`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!4:&4@;&]C871I;VX@;V8@=&AE(&QA<W0@;65S<V%G92!W
M92!W97)E(&%T+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO
M"B`@("!V87(@)%]L87-T07)R87E);F1E>"`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!4:&4@87)R87D@;V8@<V]R=&5D(&EN9&EC97,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S;W)T960@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&%R<F%Y(&]F('-O<G1E9"!M86EL
M8F]X97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]S;W)T961-8F]X(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H
M92!T:')E861I;F<@:6YF;W)M871I;VX@9F]R('1H92!C=7)R96YT(&UA:6QB
M;W@N"B`@("`@*@H@("`@("H@0'9A<B!)35!?5&AR96%D"B`@("`@*B\*("`@
M('9A<B`D7W1H<F5A9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@
M=V4@<VAO=R!(:61E+W!U<F=E(&1E;&5T960@;65S<V%G92!L:6YK<S\*("`@
M("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<VAO
M=V1E;&5T92`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE(&YU;6)E<B!O
M9B!N97<@;65S<V%G97,@:6X@=&AE(&UA:6QB;W@N"B`@("`@*@H@("`@("H@
M0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VYE=VUS9W,@/2`P.PH*
M("`@("\J*@H@("`@("H@57-I;F<@4$]0('1O(&%C8V5S<R!M86EL8F]X97,_
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7W5S97!O<"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE('-O<G0@;65T
M:&]D(&9O<B!T:&ES(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D7W-O<G1B>3L*"B`@("`O*BH*("`@("`J
M($%R92!W92!H:61I;F<@9&5L971E9"!M97-S86=E<S\*("`@("`J"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?9&5L:&ED93L*"B`@
M("`O*BH*("`@("`J(%-P96-I86P@9F]L9&5R(&9L86<N"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W-P96-I86Q&;VQD
M97(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@2&%S('1H92!S;W)T:6YG(&QI
M;6ET(&)E96X@<F5A8VAE9#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?<V]R=$QI;6ET(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!687)I86)L97,@<F5L871I;F<@=&\@<VAO=VEN9R!M97-S86=E
M('!R979I97=S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?<')E=FEE=W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M5&AE("=N;U]N97=M86EL7W!O<'5P)R!F;&%G+@H@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]N;U]N97=M86EL7W!O<'5P
M(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@
M82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!)35!?36%I;&)O>"!I;G-T86YC
M92X*("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@
M:68@;F\@24U07TUA:6QB;W@@:6YS=&%N8V4@=VET:`H@("`@("H@=&AE('-A
M;64@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9)35!?
M36%I;&)O>#HZ<VEN9VQE=&]N*"D["B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&EN9&5X("!3964@24U07TUA:6QB;W@@8V]N<W1R=6-T;W(N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R8V4@($9O<F-E('1H92!C<F5A=&EO
M;B!O9B!A(&YE=R!I;G-T86YC92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@8W)E871E9"!C;VYC<F5T92!)35!?36%I;&)O>"!I;G-T86YC
M92P@;W(@9F%L<V4*("`@("`J("`@("`@("`@("`@("`@(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1I;F1E>"`](&YU;&PL
M("1F;W)C92`](&9A;'-E*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N
M8V5S(#T@87)R87DH*3L*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ
M92@D:6YD97@I.PH@("`@("`@(&EF("@D9F]R8V4@?'P@(6ES<V5T*"1I;G-T
M86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;
M)'-I9VYA='5R95T@/2`F;F5W($E-4%]-86EL8F]X*"1I;F1E>"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE(&EN9&5X(&]F('1H92!C
M=7)R96YT(&UE<W-A9V4N(%1H:7,@=VEL;"!C875S90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!)35!?365S<V%G92!T;R!U<&1A=&4@=&AE('9A
M<FEO=7,@;65S<V%G92!A<G)A>7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@869T97(@96%C:"!A8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N
M($E-4%]-86EL8F]X*"1I;F1E>"`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1I;F1E>"DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$YE
M=TEN9&5X*"1I;F1E>"D["B`@("`@("`@?0H*("`@("`@("!I9B`H)$=,3T)!
M3%-;)VEM<"==6R=B87-E7W!R;W1O8V]L)UT@/3T@)W!O<#,G*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?=7-E<&]P(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@("\J($1E=&5R;6EN92!W:&5T:&5R('=E)W)E(&AI9&EN9R!D96QE=&5D
M(&UE<W-A9V5S.R!L970@=&AE"B`@("`@("`@("`@=')A<V@@9F]L9&5R('1A
M:V4@<')E8V5D96YC92X@*B\*("`@("`@("!I9B`H)$=,3T)!3%-;)W!R969S
M)UTM/F=E=%9A;'5E*"=U<V5?=G1R87-H)RDI('L*("`@("`@("`@("`@)'1H
M:7,M/E]D96QH:61E(#T@(21'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES4V5A
M<F-H36)O>"@D1TQ/0D%,4ULG:6UP)UU;)VUA:6QB;W@G72D@?'P@*"1'3$]"
M04Q36R=I;7`G75LG<V5A<F-H)UU;)VQA8F5L)UT@(3T@7R@B5FER='5A;"!4
M<F%S:"(I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7V1E;&AI9&4@/2`H)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=D96QH
M:61E)RD@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("$D1TQ/
M0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W5S95]T<F%S:"<I("8F"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H)$=,3T)!3%-;)VEM<%]S96%R
M8V@G72T^:7-396%R8VA-8F]X*"D@?'P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("@D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W-O<G1B
M>2<I("$](%-/4E142%)%040I*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!T:&4@=F%L=64@;V8@=&AE("=N;U]N97=M86EL7W!O
M<'5P)R!F;&%G+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1N;W!O
M<'5P("!4:&4@=F%L=64@=&\@<V5T('1H92!F;&%G+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971.;TYE=VUA:6Q0;W!U<"@D;F]P;W!U<"D*("`@('L*("`@
M("`@("`D=&AI<RT^7VYO7VYE=VUA:6Q?<&]P=7`@/2`H8F]O;"D@)&YO<&]P
M=7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@;F5W(&EN9&5X+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE(&EN9&5X
M(&]F('1H92!N97<@8W5R<F5N="!M97-S86=E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971.97=);F1E>"@D:6YD97@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]S9713;W)T960H*3L*("`@("`@("`D=&AI<RT^7W-E=$%R<F%Y26YD97@H
M)&EN9&5X+"`G=6ED)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI
M;F5S(&EF(&UA:6P@<')E=FEE=W,@<VAO=6QD(&)E(&=E;F5R871E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@;6%I;"!P<F5V
M:65W<R!S:&]U;&0@8F4@9V5N97)A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S:&]W4')E=FEE=W,H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]P<F5V:65W<RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(21'3$]"04Q36R=C;VYF)UU;)VUA:6QB
M;W@G75LG<VAO=U]P<F5V:65W)UT@?'P*("`@("`@("`@("`@(21'3$]"04Q3
M6R=P<F5F<R==+3YG971686QU92@G<')E=FEE=U]E;F%B;&5D)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]P<F5V:65W<ULG=6YR96%D)UT@/2`D1TQ/0D%,4ULG<')E9G,G72T^
M9V5T5F%L=64H)W!R979I97=?<VAO=U]U;G)E860G*3L*("`@("`@("`D=&AI
M<RT^7W!R979I97=S6R=M87AL96XG72`]("1'3$]"04Q36R=P<F5F<R==+3YG
M971686QU92@G<')E=FEE=U]M87AL96XG*3L*("`@("`@("!I9B`H)'1H:7,M
M/E]P<F5V:65W<ULG;6%X;&5N)UT@(3T@+3$I('L*("`@("`@("`@("`@)'1H
M:7,M/E]P<F5V:65W<ULG;6%X;&5N)UT@/2!M87@H-2P@)'1H:7,M/E]P<F5V
M:65W<ULG;6%X;&5N)UT@+2`S*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/E]P<F5V:65W<ULG<W1R:7`G72`]("1'3$]"04Q36R=P<F5F<R==+3YG9716
M86QU92@G<')E=FEE=U]S=')I<%]N;"<I.PH@("`@("`@("1T:&ES+3Y?<')E
M=FEE=W-;)W1O;VQT:7`G72`]("1'3$]"04Q36R=P<F5F<R==+3YG971686QU
M92@G<')E=FEE=U]S:&]W7W1O;VQT:7`G*3L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9"!T:&4@87)R87D@;V8@
M;65S<V%G92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8F5G:6X@(%1H92!B96=I;FYI;F<@;65S<V%G92!N=6UB97(N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D96YD("`@(%1H92!E;F1I;F<@;65S<V%G
M92!N=6UB97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R
M87D@=VET:"!I;F9O<FUA=&EO;B!O;B!T:&4@<F5Q=65S=&5D(&UE<W-A9V5S
M+@H@("`@("H@/'!R93X*("`@("`J($ME>3H@87)R87D@:6YD97@@:6X@8W5R
M<F5N="!S;W)T960@;6%I;&)O>"!A<G)A>0H@("`@("H@)VAE861E<B<@("`@
M("TM("!(96%D97(@:6YF;W)M871I;VX@9G)O;2!I;6%P7V9E=&-H7V]V97)V
M:65W*"DN"B`@("`@*B`G;6)O>"<@("`@("`@+2T@($YA;64@;V8@=&AE(&UA
M:6QB;W@N"B`@("`@*B`G<')E=FEE=R<@("`@+2T@(%1H92!M97-S86=E('!R
M979I97<@*&EF('1H92`G<VAO=U]P<F5V:65W)R!P<F5F97)E;F-E"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&ES(&%C=&EV92DN"B`@("`@*B`G<W1R=6-T
M=7)E)R`@+2T@(%-T<G5C='5R92!O9B!T:&4@;65S<V%G92`H:68@=&AE("=S
M:&]W7V%T=&%C:&UE;G1S)PH@("`@("H@("`@("`@("`@("`@("`@("!C;VYF
M:6=U<F%T:6]N(&]P=&EO;B!I<R!A8W1I=F4I+@H@("`@("H@/"]P<F4^"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD36%I;&)O>$%R<F%Y*"1B96=I;BP@
M)&5N9"D*("`@('L*("`@("`@("`D=&AI<RT^7W-H;W=D96QE=&4@/2!F86QS
M93L*"B`@("`@("`@)&UB;WAE<R`](&%R<F%Y*"D["B`@("`@("`@)&]V97)V
M:65W(#T@87)R87DH*3L*("`@("`@("`D<VAO=U]P<F5V:65W(#T@)'1H:7,M
M/G-H;W=0<F5V:65W<R@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@;&ES="!O
M9B!M86EL8F]X97,@86YD(&UE<W-A9V5S+B`J+PH@("`@("`@(&9O<B`H)&D@
M/2`D8F5G:6X@+2`Q.R`D:2`\("1E;F0[("1I*RLI('L*("`@("`@("`@("`@
M+RH@36%K92!S=7)E('1H870@=&AE(&EN9&5X(&ES(&%C='5A;&QY(&EN('1H
M92!S;&EC92!O9B!M97-S86=E<PH@("`@("`@("`@("`@("!W92=R92!L;V]K
M:6YG(&%T+B!)9B!W92=R92!H:61I;F<@9&5L971E9"!M97-S86=E<RP@9F]R
M"B`@("`@("`@("`@("`@(&5X86UP;&4L('1H97)E(&UA>2!B92!G87!S(&AE
M<F4N("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-O<G1E9%LD
M:5TI*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]S;W)T
M961-8F]X6R1I72DI('L*("`@("`@("`@("`@("`@("`@("`D;6)O>&YA;64@
M/2`D=&AI<RT^7W-O<G1E9$UB;WA;)&E=.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D;6)O>&YA;64@/2`D1TQ/0D%,
M4ULG:6UP)UU;)VUA:6QB;W@G73L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1M8F]X97-;)&UB;WAN86UE72DI('L*
M("`@("`@("`@("`@("`@("`@("`D;6)O>&5S6R1M8F]X;F%M95T@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UB;WAE
M<ULD;6)O>&YA;65=6R1T:&ES+3Y?<V]R=&5D6R1I75T@/2`D:3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"
M05-%("X@)R]L:6(O24U!4"YP:'`G.PH@("`@("`@("1I;7!?:6UA<"`]("9)
M35!?24U!4#HZ<VEN9VQE=&]N*"D["@H@("`@("`@("\J(%)E=')I979E(&EN
M9F]R;6%T:6]N(&9R;VT@96%C:"!M86EL8F]X+B`J+PH@("`@("`@(&9O<F5A
M8V@@*"1M8F]X97,@87,@)&UB;W@@/3X@)&ED<RD@>PH@("`@("`@("`@("`D
M:6UP7VEM87`M/F-H86YG94UB;W@H)&UB;W@L($]07U)%041/3DQ9*3L*("`@
M("`@("`@("`@)&EM87!/=F5R=FEE=R`]($!I;6%P7V9E=&-H7V]V97)V:65W
M*"1'3$]"04Q36R=I;7`G75LG<W1R96%M)UTL(&EM<&QO9&4H)RPG+"!A<G)A
M>5]K97ES*"1I9',I*2P@1E1?54E$*3L*("`@("`@("`@("`@9F]R96%C:"`H
M)&EM87!/=F5R=FEE=R!A<R`D:&5A9&5R*2!["B`@("`@("`@("`@("`@("`D
M:V5Y(#T@)&ED<ULD:&5A9&5R+3YU:61=.PH@("`@("`@("`@("`@("`@)&]V
M97)V:65W6R1K97E=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1O=F5R
M=FEE=ULD:V5Y75LG:&5A9&5R)UT@/2`D:&5A9&5R.PH@("`@("`@("`@("`@
M("`@:68@*"1H96%D97(M/F1E;&5T960I('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W-H;W=D96QE=&4@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG8V]N9B==6R=F971C
M:&UA:6PG75LG<VAO=U]A8V-O=6YT7V-O;&]R<R==*2!["B`@("`@("`@("`@
M("`@("`@("`@)&AD<B`]($!I;6%P7V9E=&-H:&5A9&5R*"1'3$]"04Q36R=I
M;7`G75LG<W1R96%M)UTL("1H96%D97(M/G5I9"P@1E1?54E$*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B+U@M8V]L;W(Z*"XJ*5QN
M+R(L("1H9'(L("1C;VQO<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]V97)V:65W6R1K97E=6R=C;VQO<B==(#T@=')I;2@D8V]L;W);,5TI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D;W9E<G9I97=;)&ME>5U;)VUB;W@G72`]("1M8F]X.PH*
M("`@("`@("`@("`@("`@("\J($%D9"!P<F5V:65W(&EN9F]R;6%T:6]N+B`J
M+PH@("`@("`@("`@("`@("`@:68@*"1S:&]W7W!R979I97<@)B8*("`@("`@
M("`@("`@("`@("`@("`H(21T:&ES+3Y?<')E=FEE=W-;)W5N<F5A9"==('Q\
M"B`@("`@("`@("`@("`@("`@("`@("$D:&5A9&5R+3YS965N('Q\"B`@("`@
M("`@("`@("`@("`@("`@("1H96%D97(M/G)E8V5N="DI('L*("`@("`@("`@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-24U%
M+T-O;G1E;G1S+G!H<"<["B`@("`@("`@("`@("`@("`@("`@)&EM<%]C;VYT
M96YT<R`]("9)35!?0V]N=&5N=',Z.G-I;F=L971O;B@D:&5A9&5R+3YU:60@
M+B!)35!?24187U-%4"`N("1M8F]X*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H*"1M:6UE:60@/2`D:6UP7V-O;G1E;G1S+3YF:6YD0F]D>2AF86QS92DI
M("$]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P;6EM92`]
M("8D:6UP7V-O;G1E;G1S+3YG971$96-O9&5D34E-15!A<G0H)&UI;65I9"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1P;6EM92DI
M('!R95]D=6UP*"1H96%D97(M/G5I9"P@)&UI;65I9"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1P=&5X="`]("1P;6EM92T^9V5T0V]N=&5N=',H*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!T97AT(#T@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D<'1E>'0L("1P;6EM92T^9V5T0VAA<G-E="@I*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1P;6EM92T^9V5T5'EP92@I(#T]
M("=T97AT+VAT;6PG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<'1E>'0@/2!497AT7T9I;'1E<CHZ9FEL
M=&5R*"1P=&5X="P@)VAT;6PR=&5X="<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W!R
M979I97=S6R=M87AL96XG72`A/2`M,2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*%-T<FEN9SHZ;&5N9W1H*"1P=&5X="D@/B`D=&AI<RT^
M7W!R979I97=S6R=M87AL96XG72D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P=&5X="`](%-T<FEN9SHZ<W5B<W1R*"1P=&5X="P@,"P@
M)'1H:7,M/E]P<F5V:65W<ULG;6%X;&5N)UTI("X@)R`N+BXG.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<'1E>'0@+CT@)UM;)R`N(%\H(D5.1"(I("X@
M)UU=)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?<')E=FEE=W-;)W-T<FEP)UT@)B8*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("$D=&AI<RT^7W!R979I97=S6R=T;V]L=&EP)UTI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P=&5X="`]('-T<E]R97!L
M86-E*")<<B(L(")<;B(L("1P=&5X="D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<'1E>'0@/2!P<F5G7W)E<&QA8V4H)R]<;B\G+"`G("<L("1P
M=&5X="D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<'1E>'0@/2!P
M<F5G7W)E<&QA8V4H)R\H7',I*R\G+"`G)#$G+"`D<'1E>'0I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!T97AT(#T@<W1R7W)E<&QA8V4H(EQR(BP@)R<L("1P=&5X
M="D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7W!R979I97=S6R=T;V]L=&EP)UTI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P=&5X="`](%1E>'1?1FEL=&5R.CIF:6QT97(H)'!T97AT+"`G=&5X
M=#)H=&UL)RP@87)R87DH)W!A<G-E;&5V96PG(#T^(%1%6%1?2%1-3%].3TA4
M34PL("=C:&%R<V5T)R`]/B`G)RP@)V-L87-S)R`]/B`G)RDI.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!T97AT(#T@)UM;)R`N(%\H
M(DYO(%!R979I97<@5&5X="(I("X@)UU=)SL*("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@("1O=F5R=FEE=ULD:V5Y75LG<W1R
M=6-T=7)E)UT@/2`D:6UP7V-O;G1E;G1S+3YG971-24U%365S<V%G92@I.PH@
M("`@("`@("`@("`@("`@("`@("1O=F5R=FEE=ULD:V5Y75LG<')E=FEE=R==
M(#T@)'!T97AT.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T=7)E
M+G!H<"<["B`@("`@("`@("`@("`@("`@("`@)&]V97)V:65W6R1K97E=6R=S
M=')U8W1U<F4G72`]("@D1TQ/0D%,4ULG8V]N9B==6R=M86EL8F]X)UU;)W-H
M;W=?871T86-H;65N=',G72D@/R!-24U%7U-T<G5C='5R93HZ<&%R<V4H0&EM
M87!?9F5T8VAS=')U8W1U<F4H)$=,3T)!3%-;)VEM<"==6R=S=')E86TG72P@
M)&AE861E<BT^=6ED+"!&5%]5240I*2`Z(&YU;&P["B`@("`@("`@("`@("`@
M("`@("`@)&]V97)V:65W6R1K97E=6R=P<F5V:65W)UT@/2!N=6QL.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!3;W)T('9I82!T:&4@<V]R=&5D(&%R<F%Y(&EN9&5X+B`J+PH@("`@
M("`@(&MS;W)T*"1O=F5R=FEE=RD["@H@("`@("`@(')E='5R;B`D;W9E<G9I
M97<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@=&AE(&QI<W0@;V8@
M;65S<V%G97,@:6X@=&AE(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('-O
M<G1E9"!I;F1E>"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD36%I;&)O
M>"@I"B`@("!["B`@("`@("`@)'1H:7,M/E]N97=M<V=S(#T@,#L*"B`@("`@
M("`@:68@*"1'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES4V5A<F-H36)O>"@D
M1TQ/0D%,4ULG:6UP)UU;)VUA:6QB;W@G72DI('L*("`@("`@("`@("`@)'%U
M97)Y(#T@;G5L;#L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&5L:&ED92D@
M>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L
M:6(O24U!4"]396%R8V@N<&AP)SL*("`@("`@("`@("`@("`@("1Q=65R>2`]
M("9N97<@24U07TE-05!?4V5A<F-H7U%U97)Y*"D["B`@("`@("`@("`@("`@
M("`D<75E<GDM/F1E;&5T960H9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1S;W)T960@/2`D1TQ/0D%,4ULG:6UP7W-E87)C:"==+3YR=6Y3
M96%R8V@H)'%U97)Y+"`D1TQ/0D%,4ULG:6UP)UU;)VUA:6QB;W@G72D["@H@
M("`@("`@("`@("`O*B!2971U<FX@=&\@=&AE('-E87)C:"!P86=E(&EF('1H
M:7,@:7,@;F]T(&$@=FER='5A;"!F;VQD97(N("HO"B`@("`@("`@("`@(&EF
M("AE;7!T>2@D<V]R=&5D*2`F)@H@("`@("`@("`@("`@("`@(21'3$]"04Q3
M6R=I;7!?<V5A<F-H)UTM/FES5D9O;&1E<B@D1TQ/0D%,4ULG:6UP)UU;)VUA
M:6QB;W@G72DI('L*("`@("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC
M871I;VXG72T^<'5S:"A?*").;R!M97-S86=E<R!M871C:&5D('EO=7(@<V5A
M<F-H+B(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@:&5A
M9&5R*"=,;V-A=&EO;CH@)R`N(%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ
M87!P;&EC871I;VY5<FPH)W-E87)C:"YP:'`G+"!T<G5E*2P@)VYO7VUA=&-H
M)RP@,2DI.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?9V5T4V]R=&5D
M26YD97@H*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W-O<G1E
M9"D@)B8*("`@("`@("`@("`@("`@("@H)$=,3T)!3%-;)W!R969S)UTM/F=E
M=%9A;'5E*"=N879?<&]P=7`G*2!\?`H@("`@("`@("`@("`@("`@("`D1TQ/
M0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)VYA=E]A=61I;R<I*2`F)@H@("`@
M("`@("`@("`@("`@("$D=&AI<RT^7VYO7VYE=VUA:6Q?<&]P=7`I*2!["B`@
M("`@("`@("`@("`@("`D;F5W475E<GD@/2`G4D5#14Y4)SL*("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^7V1E;&AI9&4I('L*("`@("`@("`@("`@("`@
M("`@("`D;F5W475E<GD@+CT@)R!53D1%3$54140G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*"@D;F5W(#T@0&EM87!?<V5A<F-H
M*"1'3$]"04Q36R=I;7`G75LG<W1R96%M)UTL("1N97=1=65R>2DI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N97=M<V=S(#T@8V]U;G0H)&YE
M=RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'-O<G1E9"`]("1T:&ES+3Y?<V]R=&5D.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4W1O<F4@=&AE('-O<G1E9"!R86YG92!I;B!)35!?365S<V%G92X@
M*B\*("`@("`@("`D=&AI<RT^7W-E=%)A;F=E*"1S;W)T960I.PH*("`@("`@
M("!R971U<FX@)'-O<G1E9#L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!N
M=6UB97(@;V8@;F5W(&UE<W-A9V5S(&EN('1H92!M86EL8F]X("A)34%0(%)%
M0T5.5"!F;&%G+`H@("`@("H@=VET:"!53D1%3$54140@:68@=V4G<F4@:&ED
M:6YG(&1E;&5T960@;65S<V%G97,I+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B!4:&4@;G5M8F5R(&]F(&YE=R!M97-S86=E<R!I;B!T:&4@;6%I
M;&)O>"X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5W365S<V%G94-O=6YT*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]N97=M<V=S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!L:7-T(&]F('5N<V5E;B!M97-S86=E
M<R!I;B!T:&4@;6%I;&)O>"`H24U!4"!53E-%14X@9FQA9RDN"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@=6YS965N(&UE<W-A
M9V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;G-E96Y-97-S86=E<R@I"B`@
M("!["B`@("`@("`@)&YE=U%U97)Y(#T@)U5.4T5%3B<["B`@("`@("`@:68@
M*"1T:&ES+3Y?9&5L:&ED92D@>PH@("`@("`@("`@("`D;F5W475E<GD@+CT@
M)R!53D1%3$54140G.PH@("`@("`@('T*("`@("`@("`D<F5T(#T@0&EM87!?
M<V5A<F-H*"1'3$]"04Q36R=I;7`G75LG<W1R96%M)UTL("=!3$P@)R`N("1N
M97=1=65R>2P@4T5?54E$*3L*("`@("`@("!R971U<FX@*&5M<'1Y*"1R970I
M*2`_(&%R<F%Y*"D@.B`D<F5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4VAO
M=6QD(&1E;&5T92!M97-S86=E(&QI;FMS(&)E('-H;W=N/R!/;FQY('-H;W<@
M:68@=&AE"B`@("`@*B!C;VYF:6=U<F%T:6]N(')E<75I<F5S(&ET+"!O<B!D
M96QE=&5D(&UE<W-A9V5S(&5X:7-T(&EN('1H90H@("`@("H@8W5R<F5N="!M
M86EL8F]X+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y
M('=I=&@@=&AE(&9O;&QO=VEN9R!E;&5M96YT<SH*("`@("`J(#QP<F4^"B`@
M("`@*B`G:&ED92<@("T@5VAE=&AE<B!S:&]W+VAI9&4@9&5L971E(&UE<W-A
M9V4@;&EN:W,@<VAO=6QD(&)E('-H;W=N+@H@("`@("H@)W!U<F=E)R`M(%=H
M971H97(@<'5R9V4@9&5L971E(&QI;FMS('-H;W5L9"!B92!S:&]W;BX*("`@
M("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!S:&]W1&5L971E3&EN
M:W,H*0H@("`@>PH@("`@("`@(&EF("@A)$=,3T)!3%-;)W!R969S)UTM/F=E
M=%9A;'5E*"=U<V5?=')A<V@G*2`F)@H@("`@("`@("`@("`A)$=,3T)!3%-;
M)W!R969S)UTM/F=E=%9A;'5E*"=U<V5?=G1R87-H)RD@)B8*("`@("`@("`@
M("`@(21'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES5DE.0D]81F]L9&5R*"DI
M('L*("`@("`@("`@("`@)')E=%]A<G)A>2`](&%R<F%Y*"=P=7)G92<@/3X@
M=')U92D["B`@("`@("`@("`@("1R971?87)R87E;)VAI9&4G72`]("@D=&AI
M<RT^<V]R=&)Y*"D@(3T@4T]25%1(4D5!1"D["B`@("`@("`@?2!E;'-E:68@
M*"1T:&ES+3Y?<VAO=V1E;&5T92D@>PH@("`@("`@("`@("`D<F5T7V%R<F%Y
M(#T@87)R87DH)VAI9&4G(#T^(&9A;'-E+"`G<'5R9V4G(#T^('1R=64I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R971?87)R87D@/2!A<G)A
M>2@G:&ED92<@/3X@9F%L<V4L("=P=7)G92<@/3X@9F%L<V4I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R971?87)R87D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT(&%R<F%Y(&EN9&5X+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&%R<F%Y(&EN9&5X+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971!<G)A>4EN9&5X*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]A<G)A>4EN9&5X.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!M97-S86=E(&%R<F%Y(&EN
M9&5X+B!)9B!T:&4@87)R87D@:6YD97@@:&%S"B`@("`@*B!R=6X@;V9F('1H
M92!E;F0@;V8@=&AE(&UE<W-A9V4@87)R87DL('=I;&P@<F5T=7)N('1H92!L
M87-T(&EN9&5X+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE
M(&UE<W-A9V4@87)R87D@:6YD97@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$UE<W-A9V5);F1E>"@I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H
M:7,M/E]A<G)A>4EN9&5X*2D@>PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D
M=&AI<RT^7VQA<W1!<G)A>4EN9&5X*2D@>PH@("`@("`@("`@("`@("`@)&EN
M9&5X(#T@,#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1I;F1E>"`]("1T:&ES+3Y?;&%S=$%R<F%Y26YD97@["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:6YD97@@/2`D=&AI
M<RT^7V%R<F%Y26YD97@["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN
M9&5X("L@,3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U
M<G)E;G0@;65S<V%G92!C;W5N="!O9B!T:&4@;6%I;&)O>"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!M86EL8F]X(&UE<W-A9V4@8V]U
M;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V5#;W5N="@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&-O=6YT*"1T:&ES+3Y?<V]R=&5D*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@:68@=&AE(&-U<G)E
M;G0@:6YD97@@:7,@=F%L:60N"B`@("`@*B!4:&ES(&9U;F-T:6]N(&ES(&]N
M;'D@=7-E9G5L(&EF(&%N(&EN9&5X('=A<R!P87-S960@=&\@=&AE(&-O;G-T
M<G5C=&]R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!I;F1E>"!I<R!V86QI9"P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I<U9A;&ED26YD97@H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<V]R=$EF3F5E9&5D*"D["B`@("`@("`@<F5T=7)N("%I<U]N=6QL*"1T:&ES
M+3Y?87)R87E);F1E>"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M($E-05`@;6)O>"]5240@:6YF;W)M871I;VX@;VX@82!M97-S86=E+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1O9F9S970@(%1H92!O9F9S970@
M9G)O;2!T:&4@8W5R<F5N="!M97-S86=E+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@("=I;F1E>"<@("`M+2!4:&4@;65S<V%G92!I;F1E>"X*("`@
M("`J("`@("`@("`@("`@("`@("=M86EL8F]X)R`M+2!4:&4@;6%I;&)O>"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T24U!4$EN9&5X*"1O9F9S970@/2`P
M*0H@("`@>PH@("`@("`@("1R971U<FY?87)R87D@/2!A<G)A>2@I.PH@("`@
M("`@("1I;F1E>"`]("1T:&ES+3Y?87)R87E);F1E>"`K("1O9F9S970["@H@
M("`@("`@("\J($EF('1H92!O9F9S970@=V]U;&0@<'5T('5S(&]U="!O9B!A
M<G)A>2!I;F1E>"P@<F5T=7)N(&YO=RX@*B\*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<V]R=&5D6R1I;F1E>%TI*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5T=7)N7V%R<F%Y.PH@("`@("`@('T*"B`@("`@("`@)')E='5R;E]A
M<G)A>5LG:6YD97@G72`]("1T:&ES+3Y?<V]R=&5D6R1I;F1E>%T["B`@("`@
M("`@:68@*"1'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES4V5A<F-H36)O>"@D
M1TQ/0D%,4ULG:6UP)UU;)VUA:6QB;W@G72DI('L*("`@("`@("`@("`@)')E
M='5R;E]A<G)A>5LG;6%I;&)O>"==(#T@)'1H:7,M/E]S;W)T961-8F]X6R1I
M;F1E>%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E='5R;E]A
M<G)A>5LG;6%I;&)O>"==(#T@)$=,3T)!3%-;)VEM<"==6R=M86EL8F]X)UT[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!T:&4@8W5R<F5N="!M86EL8F]X
M(&EF(&%N(&%C=&EO;B!H87,@8F5E;B!P97)F;W)M960@;VX@=&AE"B`@("`@
M*B!C=7)R96YT(&UE<W-A9V4@:6YD97@N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&%C=&EO;B`@(%1H92!A8W1I;VX@=&\@<&5R9F]R;2X*("`@
M("`J($!P87)A;2!B;V]L96%N("1S=6-C97-S("!787,@=&AE(&%C=&EO;B!S
M=6-C97-S9G5L/PH@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5-86EL8F]X
M*"1A8W1I;VXL("1S=6-C97-S(#T@=')U92D*("`@('L*("`@("`@("!S=VET
M8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E($E-4%]-04E,0D]87T-/4%DZ
M"B`@("`@("`@("`@("\J($IU<W0@;6]V92!T;R!T:&4@;F5X="!M97-S86=E
M+B`J+PH@("`@("`@("`@("`D=&AI<RT^;6]V94YE>'0H*3L*"B`@("`@("`@
M("`@("\J($1E=&5R;6EN92!I9B!W92!N965D('1O(')E<V]R="X@*B\*("`@
M("`@("`@("`@)'1H:7,M/E]S;W)T269.965D960H*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@24U07TU!24Q"3UA?34]613H*("`@("`@
M("!C87-E($E-4%]-04E,0D]87T1%3$5413H*("`@("`@("`@("`@+RH@268@
M=V4@87)E('5S:6YG(%!/4"P@=V4@;F5E9"!T;R!R97-O<G0@979E<GD@=&EM
M92X@*B\*("`@("`@("`@("`@:68@*"1S=6-C97-S("8F("1T:&ES+3Y?=7-E
M<&]P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=%-O<G1E9$EN9&5X
M*"D["B`@("`@("`@("`@('T@96QS96EF("@D<W5C8V5S<R`F)@H@("`@("`@
M("`@("`@("`@("`@("`@*"1T:&ES+3Y?9&5L:&ED92!\?`H@("`@("`@("`@
M("`@("`@("`@("`@("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G=7-E
M7W1R87-H)RDI*2!["B`@("`@("`@("`@("`@("`O*B!.=6ME(&UE<W-A9V4@
M9G)O;2!S;W)T960@;&ES="!I9B!S96YT('1O('1R87-H(&]R"B`@("`@("`@
M("`@("`@("`@("!H:61D96XN("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W)E;6]V94-U<G)E;G0H*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("\J($5I=&AE<B!W92!F86EL960L(&]R('1H92!M97-S86=E
M(&ES('-T:6QL(&EN('1H90H@("`@("`@("`@("`@("`@("`@;6%I;&)O>"!A
M;F0@:&%S(&)E96X@;6%R:V5D(&%S(&1E;&5T960@+2!J=7-T(&UO=F4*("`@
M("`@("`@("`@("`@("`@('1O('1H92!N97AT(&UE<W-A9V4N("HO"B`@("`@
M("`@("`@("`@("`D=&AI<RT^;6]V94YE>'0H*3L*"B`@("`@("`@("`@("`@
M("`O*B!$971E<FUI;F4@:68@=V4@;F5E9"!T;R!R97-O<G0N("HO"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-O<G1)9DYE961E9"@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($E-4%]-04E,
M0D]87U5.1$5,151%.@H@("`@("`@("`@("`D=&AI<RT^;6]V94YE>'0H*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24U07TU!24Q"3UA?
M15A054Y'13H*("`@("`@("!C87-E($E-4%]-04E,0D]87T5-4%19.@H@("`@
M("`@(&-A<V4@24U07TU!24Q"3UA?55!$051%.@H@("`@("`@("`@("!I9B`H
M(21'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES4V5A<F-H36)O>"@D1TQ/0D%,
M4ULG:6UP)UU;)VUA:6QB;W@G72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T4V]R=&5D26YD97@H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<VEN
M9R!T:&4@<')E9F5R96YC97,@86YD('1H92!C=7)R96YT(&UA:6QB;W@L(&1E
M=&5R;6EN97,@=&AE(&UE<W-A9V5S"B`@("`@*B!T;R!V:65W(&]N('1H92!C
M=7)R96YT('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!A
M9V4@("!4:&4@<&%G92!N=6UB97(@8W5R<F5N=&QY(&)E:6YG(&1I<W!L87EE
M9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@5&AE('-T87)T:6YG
M(&UE<W-A9V4@;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1D0VQA
M<W,@($%N(&]B:F5C="!W:71H('1H92!F;VQL;W=I;F<@9FEE;&1S.@H@("`@
M("H@/'!R93X*("`@("`J("=A;GEM<V<G("`@("`M("!!<F4@=&AE<F4@86YY
M(&UE<W-A9V5S(&%T(&%L;"!I;B!M86EL8F]X/R!%+F<N($EF"B`@("`@*B`@
M("`@("`@("`@("`@("`@)VUS9V-O=6YT)R!I<R`P+"!T:&5R92!M87D@<W1I
M;&P@8F4@:&ED9&5N(&1E;&5T960*("`@("`J("`@("`@("`@("`@("`@("!M
M97-S86=E<RX*("`@("`J("=B96=I;B<@("`@("`M("!4:&4@8F5G:6YN:6YG
M(&UE<W-A9V4@;G5M8F5R(&]F('1H92!P86=E+@H@("`@("H@)V5N9"<@("`@
M("`@("T@(%1H92!E;F1I;F<@;65S<V%G92!N=6UB97(@;V8@=&AE('!A9V4N
M"B`@("`@*B`G:6YD97@G("`@("`@+2`@5&AE(&EN9&5X(&]F('1H92!S=&%R
M=&EN9R!M97-S86=E+@H@("`@("H@)VUS9V-O=6YT)R`@("T@(%1H92!N=6UB
M97(@;V8@=FEE=V%B;&4@;65S<V%G97,@:6X@=&AE(&-U<G)E;G0@;6%I;&)O
M>"X*("`@("`J("=P86=E)R`@("`@("`M("!4:&4@8W5R<F5N="!P86=E(&YU
M;6)E<BX*("`@("`J("=P86=E8V]U;G0G("`M("!4:&4@;G5M8F5R(&]F('!A
M9V5S(&EN('1H:7,@;6%I;&)O>"X*("`@("`J(#PO<')E/@H@("`@("HO"B`@
M("!F=6YC=&EO;B!B=6EL9$UA:6QB;WA086=E*"1P86=E(#T@,"P@)'-T87)T
M(#T@,"D*("`@('L*("`@("`@("`D<V]R=&5D(#T@)'1H:7,M/E]B=6EL9$UA
M:6QB;W@H*3L*("`@("`@("`D;7-G8V]U;G0@/2`D=&AI<RT^9V5T365S<V%G
M94-O=6YT*"D["@H@("`@("`@("1M87AM<V=S(#T@)$=,3T)!3%-;)W!R969S
M)UTM/F=E=%9A;'5E*"=M87A?;7-G<R<I.PH@("`@("`@("1S;W)T9&ER(#T@
M)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=S;W)T9&ER)RD["@H@("`@
M("`@("1T:&ES+3Y?9&5T97)M:6YE4V]R="@I.PH*("`@("`@("!I9B`H)&US
M9V-O=6YT(#X@)&UA>&US9W,I('L*("`@("`@("`@("`@)'!A9V5#;W5N="`]
M(&-E:6PH)&US9V-O=6YT("\@*"@D;6%X;7-G<R`^(#`I(#\@)&UA>&US9W,@
M.B`R,"DI.PH*("`@("`@("`@("`@+RH@1&5T97)M:6YE('=H:6-H('!A9V4@
M=&\@9&ES<&QA>2X@*B\*("`@("`@("`@("`@:68@*&5M<'1Y*"1P86=E*2!\
M?"!S=')C<W!N*"1P86=E+"`G,#$R,S0U-C<X.2<I*2!["B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1S=&%R="DI('L*("`@("`@("`@("`@("`@("`@
M("`O*B!-97-S86=E<R!S970@=&AI<R!W:&5N(')E='5R;FEN9R!T;R!A(&UA
M:6QB;W@N("HO"B`@("`@("`@("`@("`@("`@("`@)'!A9V4@/2!C96EL*"1S
M=&%R="`O("1M87AM<V=S*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'-T87)T<&%G92`]("1'3$]"04Q36R=P<F5F
M<R==+3YG971686QU92@G;6%I;&)O>%]S=&%R="<I.PH@("`@("`@("`@("`@
M("`@("`@('-W:71C:"`H)'-T87)T<&%G92D@>PH@("`@("`@("`@("`@("`@
M("`@(&-A<V4@24U07TU!24Q"3UA35$%25%]&25)35%!!1T4Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P86=E(#T@,3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@24U07TU!
M24Q"3UA35$%25%],05-44$%'13H*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A9V4@/2`D<&%G94-O=6YT.PH@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92!)35!?34%)3$)/6%-4
M05)47T9)4E-454Y3145..@H@("`@("`@("`@("`@("`@("`@(&-A<V4@24U0
M7TU!24Q"3UA35$%25%],05-454Y3145..@H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(21T:&ES+3YA8F]V95-O<G1,:6UI="@I("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`A)$=,3T)!3%-;)VEM<%]S96%R8V@G72T^
M:7-396%R8VA-8F]X*"1'3$]"04Q36R=I;7`G75LG;6%I;&)O>"==*2`F)@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1Q=65R>2`]("1T:&ES+3YU
M;G-E96Y-97-S86=E<R@I*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-O<G1E9&YE=R`](&%R<F%Y7VME>7,H87)R87E?:6YT97)S96-T*"1S
M;W)T960L("1Q=65R>2DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9I<G-T7VYE=R`]("@D<W1A<G1P86=E(#T]($E-4%]-04E,0D]84U1!4E1?
M1DE24U153E-%14XI(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>5]S:&EF="@D<V]R=&5D;F5W*2`Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87E?<&]P*"1S;W)T961N97<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A9V4@/2!C96EL*"@D9FER<W1?;F5W
M("L@,2D@+R`D;6%X;7-G<RD["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF
M("AE;7!T>2@D<&%G92DI('L*("`@("`@("`@("`@("`@("`@("`D<&%G92`]
M("1S;W)T9&ER(#\@,2`Z("1P86=E0V]U;G0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($UA:V4@<W5R92!W92=R
M92!N;W0@<&%S="!T:&4@96YD(&]R(&)E9F]R92!T:&4@8F5G:6YN:6YG+"!A
M;F0*("`@("`@("`@("`@("`@=&AA="!W92!H879E(&%N(&EN=&5G97(@=F%L
M=64N("HO"B`@("`@("`@("`@("1P86=E(#T@:6YT=F%L*"1P86=E*3L*("`@
M("`@("`@("`@:68@*"1P86=E(#X@)'!A9V5#;W5N="D@>PH@("`@("`@("`@
M("`@("`@)'!A9V4@/2`D<&%G94-O=6YT.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)'!A9V4@/"`Q*2!["B`@("`@("`@("`@("`@("`D<&%G92`](#$["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1B96=I;B`]("@H)'!A9V4@+2`Q
M*2`J("1M87AM<V=S*2`K(#$["B`@("`@("`@("`@("1E;F0@/2`D8F5G:6X@
M*R`D;6%X;7-G<R`M(#$["B`@("`@("`@("`@(&EF("@D96YD(#X@)&US9V-O
M=6YT*2!["B`@("`@("`@("`@("`@("`D96YD(#T@)&US9V-O=6YT.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)E9VEN
M(#T@,3L*("`@("`@("`@("`@)&5N9"`]("1M<V=C;W5N=#L*("`@("`@("`@
M("`@)'!A9V4@/2`Q.PH@("`@("`@("`@("`D<&%G94-O=6YT(#T@,3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D1TQ/0D%,4ULG:6UP7W-E87)C:"==+3YI
M<U-E87)C:$UB;W@H)$=,3T)!3%-;)VEM<"==6R=M86EL8F]X)UTI*2!["B`@
M("`@("`@("`@("1B96=I;DEN9&5X(#T@)&)E9VEN("T@,3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D8F5G:6Y);F1E>"`]("1T:&ES+3YG971!
M<G)A>4EN9&5X*"D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&5R92!A
M<F4@;F\@=FEE=V%B;&4@;65S<V%G97,L(&-H96-K(&9O<B!D96QE=&5D(&UE
M<W-A9V5S(&EN"B`@("`@("`@("`@=&AE(&UA:6QB;W@N("HO"B`@("`@("`@
M)&%N>6US9R`]('1R=64["B`@("`@("`@:68@*"@D;7-G8V]U;G0@/3T@,"D@
M)B8*("`@("`@("`@("`@(21'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES4V5A
M<F-H36)O>"@D1TQ/0D%,4ULG:6UP)UU;)VUA:6QB;W@G72DI('L*("`@("`@
M("`@("`@)'-T871U<R`]($!I;6%P7W-T871U<R@D1TQ/0D%,4ULG:6UP)UU;
M)W-T<F5A;2==+"!)35`Z.G-E<G9E<E-T<FEN9R@D1TQ/0D%,4ULG:6UP)UU;
M)VUA:6QB;W@G72DL(%-!7TU%4U-!1T53*3L*("`@("`@("`@("`@:68@*&ES
M7V]B:F5C="@D<W1A='5S*2`F)B`H)'-T871U<RT^;65S<V%G97,@/3T@,"DI
M('L*("`@("`@("`@("`@("`@("1A;GEM<V<@/2!F86QS93L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&]B(#T@;F5W('-T9$-L87-S.PH@
M("`@("`@("1O8BT^86YY;7-G("`@(#T@)&%N>6US9SL*("`@("`@("`D;V(M
M/F)E9VEN("`@("`]("1B96=I;CL*("`@("`@("`D;V(M/F5N9"`@("`@("`]
M("1E;F0["B`@("`@("`@)&]B+3YI;F1E>"`@("`@/2`D8F5G:6Y);F1E>#L*
M("`@("`@("`D;V(M/FUS9V-O=6YT("`]("1M<V=C;W5N=#L*("`@("`@("`D
M;V(M/G!A9V4@("`@("`]("1P86=E.PH@("`@("`@("1O8BT^<&%G96-O=6YT
M(#T@)'!A9V5#;W5N=#L*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@8W5R<F5N="!S;W)T(&UE=&AO9"!U
M<V5D+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('-O<G0@
M;65T:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T8GDH*0H@("`@>PH@
M("`@("`@('-T871I8R`D;W)I9U]S;W)T.PH*("`@("`@("`D<V]R='!R968@
M/2`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W-O<G1B>2<I.PH@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]S;W)T8GDI('Q\("@D;W)I9U]S;W)T
M("$]("1S;W)T<')E9BDI('L*("`@("`@("`@("`@)'1H:7,M/E]S;W)T8GD@
M/2`D;W)I9U]S;W)T(#T@)'-O<G1P<F5F.PH*("`@("`@("`@("`@+RH@5&AE
M('-E87)C:"!M86EL8F]X(&1O97-N)W0@<W5P<&]R="!T:')E860@<V]R="X@
M*B\*("`@("`@("`@("`@:68@*"1'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES
M4V5A<F-H36)O>"@D7U-%4U-)3TY;)VEM<"==6R=M86EL8F]X)UTI("8F"B`@
M("`@("`@("`@("`@("`H)'1H:7,M/E]S;W)T8GD@/3T@4T]25%1(4D5!1"DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]R=&)Y(#T@4T]25$1!5$4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7W-O<G1B>3L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!W
M:&5T:&5R('1H92!S;W)T(&QI;6ET(&AA<R!B965N(')E86-H960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!(87,@=&AE('-O<G0@;&EM:70@
M8F5E;B!R96%C:&5D/PH@("`@("HO"B`@("!F=6YC=&EO;B!A8F]V95-O<G1,
M:6UI="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V]R=$QI;6ET
M.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AI<R!A("=S<&5C:6%L)R!F
M;VQD97(@*&4N9RX@)V1R869T<R<@;W(@)W-E;G0M;6%I;"<@9F]L9&5R*3\*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($ES('1H:7,@82`G<W!E
M8VEA;"<@9F]L9&5R/PH@("`@("HO"B`@("!F=6YC=&EO;B!I<U-P96-I86Q&
M;VQD97(H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?<W!E
M8VEA;$9O;&1E<BDI('L*("`@("`@("`@("`@+RH@1V5T('1H92!I9&5N=&ET
M:65S+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT
M:71Y+G!H<"<["B`@("`@("`@("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ
M<VEN9VQE=&]N*&%R<F%Y*"=I;7`G+"`G:6UP)RDI.PH*("`@("`@("`@("`@
M)'1H:7,M/E]S<&5C:6%L1F]L9&5R(#T@*"@D1TQ/0D%,4ULG:6UP)UU;)VUA
M:6QB;W@G72`]/2!)35`Z.F9O;&1E<E!R968H)$=,3T)!3%-;)W!R969S)UTM
M/F=E=%9A;'5E*"=D<F%F='-?9F]L9&5R)RDL('1R=64I*2!\?"`H:6Y?87)R
M87DH)$=,3T)!3%-;)VEM<"==6R=M86EL8F]X)UTL("1I9&5N=&ET>2T^9V5T
M06QL4V5N=&UA:6Q&;VQD97)S*"DI*2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/E]S<&5C:6%L1F]L9&5R.PH@("`@?0H*("`@("\J*@H@
M("`@("H@57!D871E<R!T:&4@<V]R=&5D(&UE<W-A9V5S(&%R<F%Y+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<V5T4V]R=&5D*"D*("`@('L*("`@("`@("`D=&AI<RT^7W-O<G1E9"`]
M(&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]S;W)T961-8F]X(#T@87)R87DH
M*3L*"B`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=I;7`G75LG;7-G;"==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-O<G1E9"`](&%R<F%Y*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&US9VQI<W0@/2!E>'!L;V1E
M*$E-4%]-4T=?4T50+"`D1TQ/0D%,4ULG:6UP)UU;)VUS9VPG72D["B`@("`@
M("`@("`@(&EF("@D1TQ/0D%,4ULG:6UP7W-E87)C:"==+3YI<U-E87)C:$UB
M;W@H)$=,3T)!3%-;)VEM<"==6R=M86EL8F]X)UTI*2!["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;7-G;&ES="!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("`@("`@;&ES="@D:61X+"`D;6)O>"D@/2!E>'!L;V1E*$E-4%])1%A?
M4T50+"`D=F%L*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O<G1E
M9%M=(#T@)&ED>#L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O<G1E
M9$UB;WA;72`]("1M8F]X.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W)T960@/2`D
M;7-G;&ES=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%5P9&%T97,@=&AE(&UE<W-A9V4@87)R87D@:6YD97@N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&1A=&$@($EF("1T>7!E(&ES("=O9F9S970G+"!T:&4@
M;G5M8F5R(&]F(&UE<W-A9V5S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:6YC<F5A<V4@87)R87D@:6YD97@@8GDN("!)9B!T>7!E(&ES("=U
M:60G+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('-E=',@87)R87D@
M:6YD97@@=&\@=&AE('9A;'5E(&]F('1H92!C=7)R96YT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@8W5R<F5N="!M97-S86=E(&EN9&5X+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D='EP92`@($5I=&AE<B`G;V9F<V5T)R!O<B`G
M=6ED)RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$%R<F%Y26YD97@H)&1A
M=&$L("1T>7!E*0H@("`@>PH@("`@("`@(&EF("@D='EP92`]/2`G;V9F<V5T
M)RD@>PH@("`@("`@("`@("`D=&AI<RT^7VQA<W1!<G)A>4EN9&5X(#T@)'1H
M:7,M/E]A<G)A>4EN9&5X.PH@("`@("`@("`@("`D=&AI<RT^7V%R<F%Y26YD
M97@@*ST@)&1A=&$["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W-O
M<G1E9%LD=&AI<RT^7V%R<F%Y26YD97A=*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A<G)A>4EN9&5X(#T@;G5L;#L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS96EF("@D='EP92`]/2`G=6ED)RD@>PH@("`@("`@("`@("!I
M9B`H)$=,3T)!3%-;)VEM<%]S96%R8V@G72T^:7-396%R8VA-8F]X*"1'3$]"
M04Q36R=I;7`G75LG;6%I;&)O>"==*2D@>PH@("`@("`@("`@("`@("`@+RH@
M3F5E9"!T;R!C;VUP87)E(&)O=&@@;6)O>"!N86UE(&%N9"!M97-S86=E(%5)
M1"!T;PH@("`@("`@("`@("`@("`@("`@;V)T86EN('1H92!C;W)R96-T(&%R
M<F%Y(&EN9&5X('-I;F-E('1H97)E(&UA>2!B90H@("`@("`@("`@("`@("`@
M("`@9'5P;&EC871E(%5)1',N("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V%R<F%Y26YD97@@/2!N=6QL.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M87)R87E?:V5Y<R@D=&AI<RT^7W-O<G1E9"P@)&1A=&$I(&%S("1K97DI('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]S;W)T961-8F]X6R1K
M97E=(#T]("1?4T534TE/3ELG:6UP)UU;)W1H:7-M86EL8F]X)UTI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A<G)A>4EN9&5X(#T@)&ME
M>3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+RH@87)R87E?<V5A<F-H*"D@<F5T=7)N
M<R!F86QS92!O;B!N;R!R97-U;'0N(%=E('=I;&P*("`@("`@("`@("`@("`@
M("`@('-E="!A;B!U;G-U8V-E<W-F=6P@<F5S=6QT('1O($Y53$PN("HO"B`@
M("`@("`@("`@("`@("!I9B`H*"1T:&ES+3Y?87)R87E);F1E>"`](&%R<F%Y
M7W-E87)C:"@D9&%T82P@)'1H:7,M/E]S;W)T960I*2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%R<F%Y26YD97@@/2!N=6QL
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3Y?;&%S=$%R<F%Y26YD97@@/2`D=&AI<RT^7V%R<F%Y26YD97@[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7V%R<F%Y
M26YD97@I("8F("%E;7!T>2@D=&AI<RT^7VQA<W1!<G)A>4EN9&5X*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQA<W1!<G)A>4EN9&5X+2T["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!S;W)T960@;&ES="!O
M9B!M97-S86=E<R!F;W(@82!M86EL8F]X+B!4:&ES(&9U;F-T:6]N"B`@("`@
M*B!C;W)R96-T;'D@:&%N9&QE<R!S;W)T('!R969E<F5N8V5S+"!D96QE=&EO
M;B!P<F5F97)E;F-E<PH@("`@("H@*&4N9RX@:&ED92!D96QE=&5D(&UE<W-A
M9V5S*2P@86YD('!R;W1O8V]L("AE+F<N("=P;W`S)PH@("`@("H@=G,N("=I
M;6%P)RDN"B`@("`@*@H@("`@("H@5&AE(&9O;&QO=VEN9R!V87)I86)L97,@
M87)E('5P9&%T960@8GD@=&AI<R!M971H;V0Z"B`@("`@*B`@(&US9VP*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=%-O<G1E9$EN9&5X*"D*("`@('L*("`@("`@("`D<V]R=&1I<B`]
M("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G<V]R=&1I<B<I.PH@("`@
M("`@("1S;W)T960@/2!A<G)A>2@I.PH*("`@("`@("`D=&AI<RT^7V1E=&5R
M;6EN95-O<G0H=')U92D["@H@("`@("`@(&EF("@D=&AI<RT^<V]R=&)Y*"D@
M/3T@4T]25%1(4D5!1"D@>PH@("`@("`@("`@("`D<V]R=&5D(#T@)'1H:7,M
M/E]T:')E8613;W)T*"AB;V]L*21S;W)T9&ER*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D9&5L:&ED96-M9"`]("@A)'1H:7,M/E]U<V5P;W`@
M)B8@)'1H:7,M/E]D96QH:61E*2`_("=53D1%3$54140G(#H@)R<["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^<V]R=&)Y*"D@/3T@4T]25$%24DE604PI('L*
M("`@("`@("`@("`@("`@("1S;W)T960@/2!I;6%P7W-E87)C:"@D1TQ/0D%,
M4ULG:6UP)UU;)W-T<F5A;2==+"`H)&1E;&AI9&5C;60I(#\@)&1E;&AI9&5C
M;60@.B`G04Q,)RP@4T5?54E$*3L*("`@("`@("`@("`@("`@(&EF("@D<V]R
M=&5D(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D<V]R=&1I
M<BD@>PH@("`@("`@("`@("`@("`@("`@("1S;W)T960@/2!A<G)A>5]R979E
M<G-E*"1S;W)T960I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%
M("X@)R]L:6(O24U!4"]396%R8V@N<&AP)SL*("`@("`@("`@("`@("`@("1I
M;6%P7W-E87)C:"`]("9)35!?24U!4%]396%R8V@Z.G-I;F=L971O;BAA<G)A
M>2@G<&]P,R<@/3X@)'1H:7,M/E]U<V5P;W`I*3L*("`@("`@("`@("`@("`@
M("1Q=65R>2`]("9N97<@24U07TE-05!?4V5A<F-H7U%U97)Y*"D["B`@("`@
M("`@("`@("`@("!I9B`H)&1E;&AI9&5C;60I('L*("`@("`@("`@("`@("`@
M("`@("`D<75E<GDM/F1E;&5T960H9F%L<V4I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'-O<G1E9"`]("1I;6%P7W-E87)C:"T^<V5A
M<F-H4V]R=$UA:6QB;W@H)'%U97)Y+"`D7U-%4U-)3TY;)VEM<"==6R=S=')E
M86TG72P@)%]315-324].6R=I;7`G75LG;6%I;&)O>"==+"`D=&AI<RT^<V]R
M=&)Y*"DL("1S;W)T9&ER*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1S
M;W)T960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`D
M<V]R=&5D(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S971286YG92@D<V]R
M=&5D*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&-U<G)E;G0@
M<&%G92!O9B!M97-S86=E<R!B87-E9"!O;B!T:&4@8W5R<F5N="!I;F1E>"X*
M("`@("`J(%1H92!F;VQL;W=I;F<@<V5S<VEO;B!V87)I86)L97,@87)E('5P
M9&%T960@8GD@=&AI<R!M971H;V0Z"B`@("`@*B`@("=M<V=L)PH@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D87)R("!4:&4@87)R87D@;V8@;65S<V%G92!I;F1I8V5S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<V5T4F%N9V4H)&%R<BD*("`@('L*("`@("`@
M("`D1TQ/0D%,4ULG:6UP)UU;)VUS9VPG72`](&EM<&QO9&4H24U07TU31U]3
M15`L("1A<G(I.PH*("`@("`@("`O*B!3970@=&AE(&YE=R!S;W)T960@;65S
M<V%G92!L:7-T+B`J+PH@("`@("`@("1T:&ES+3Y?<V5T4V]R=&5D*"D["@H@
M("`@("`@("\J(%5P9&%T92!T:&4@8W5R<F5N="!A<G)A>2!I;F1E>"!T;R!I
M=',@;F5W('!O<VET:6]N(&EN('1H92!M97-S86=E"B`@("`@("`@("H@87)R
M87DN("HO"B`@("`@("`@)'1H:7,M/E]S971!<G)A>4EN9&5X*#`L("=O9F9S
M970G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O<FT@<F4M=&AR96%D
M:6YG('-O<G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YE=R`@(%1R=64@9F]R(&YE=V5S
M="!M97-S86=E<R!F:7)S="P@9F%L<V4@9F]R(&]L9&5S=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&UE<W-A9V5S(&9I<G-T+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!S;W)T960@;&ES="!O9B!M97-S86=E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W1H<F5A9%-O<G0H)&YE=RD*("`@
M('L*("`@("`@("`D<F5F7V%R<F%Y(#T@0&EM87!?=&AR96%D*"1'3$]"04Q3
M6R=I;7`G75LG<W1R96%M)UTL(%-%7U5)1"D["B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D<F5F7V%R<F%Y*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312`N
M("<O;&EB+TE-05`O5&AR96%D+G!H<"<["B`@("`@("`@)'1H:7,M/E]T:')E
M860@/2`F;F5W($E-4%]4:')E860H)')E9E]A<G)A>2D["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=&AR96%D+3YM97-S86=E3&ES="@D;F5W*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@24U07U1H<F5A9"!O8FIE8W0@9F]R
M('1H92!C=7)R96YT(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0')E='5R;B!)
M35!?5&AR96%D("!4:&4@24U07U1H<F5A9"!O8FIE8W0@9F]R('1H92!C=7)R
M96YT(&UA:6QB;W@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1H<F5A9$]B
M*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W1H<F5A9"DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]T:')E8613;W)T*&9A;'-E*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR96%D.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!A(')E<V]R="!I<R!N965D
M960L(&%N9"P@:68@;F5C97-S87)Y+"!P97)F;W)M<PH@("`@("H@=&AE(')E
M<V]R="X*("`@("`J"B`@("`@*B!4:&4@<V]R=&5D(')A;F=E(&YE961S('1O
M(&)E('5P9&%T960@:6X@=&AE(&9O;&QO=VEN9R!C87-E<SH*("`@("`J("`@
M*R!);F1E>&5S(&%R92!B96EN9R!T<F%C:V5D"B`@("`@*B`@("L@5&AE<F4@
M:7,@82!V86QI9"!A<G)A>2!I;F1E>`H@("`@("H@("`K(%1H:7,@:7,@;F]T
M(&$@<V5A<F-H(&UA:6QB;W@*("`@("`J("`@*R!4:&4@54E$<R!M87D@;F\@
M;&]N9V5R(&)E('9A;&ED("A/<'1I;VYA;"D*("`@("`J("`@*R!4:&ES(&ES
M('1H92!L87-T(&UE<W-A9V4@:6X@=&AE(&UA:6QB;W@*("`@("`J("`@*R!!
M('-O<G0@:&%S(&YO="!A;')E861Y(&]C8W5R<F5D(&)Y('-O;64@;65T:&]D
M(&EN('1H:7,@8VQA<W,*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W-O<G1)9DYE961E9"@I"B`@("!["B`@
M("`@("`@+RH@268@87)R87D@:6YD97@@:7,@;G5L;"P@=V4@:&%V92!R96%C
M:&5D('1H92!B96=I;FYI;F<O96YD"B`@("`@("`@("`@;V8@=&AE(&UA:6QB
M;W@@<V\@=V4@<VAO=6QD;B=T('-O<G0@86YY=&AI;F<N(%1H97)E(&ES(&%L
M<V\*("`@("`@("`@("!N;R!N965D('1O('-O<G0@=&AE('-E87)C:"!R97-U
M;'1S+B`J+PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7V%R<F%Y26YD
M97@I("8F"B`@("`@("`@("`@("$D1TQ/0D%,4ULG:6UP7W-E87)C:"==+3YI
M<U-E87)C:$UB;W@H)$=,3T)!3%-;)VEM<"==6R=M86EL8F]X)UTI("8F"B`@
M("`@("`@("`@("$D=&AI<RT^9V5T24U!4$EN9&5X*#$I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?9V5T4V]R=&5D26YD97@H*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT('-O<G1E9"!A
M<G)A>2!W:71H;W5T('1H92!C=7)R96YT(&EN9&5X(&UE<W-A9V4N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@5&AE('-O<G1E9"!A<G)A>2!W:71H;W5T('1H92!C=7)R96YT
M(&EN9&5X(&EN(&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5M;W9E0W5R
M<F5N="@I"B`@("!["B`@("`@("`@+RH@4F5M;W9E('1H92!C=7)R96YT(&5N
M=')Y(&%N9"!R96-A;&-U;&%T92!T:&4@<F%N9V4N("HO"B`@("`@("`@=6YS
M970H)'1H:7,M/E]S;W)T961;)'1H:7,M/E]A<G)A>4EN9&5X72D["B`@("`@
M("`@:68@*"1'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES4V5A<F-H36)O>"@D
M1TQ/0D%,4ULG:6UP)UU;)VUA:6QB;W@G72DI('L*("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]S;W)T961-8F]X6R1T:&ES+3Y?87)R87E);F1E>%TI.PH@
M("`@("`@("`@("`D87)R(#T@87)R87E?;6%P*&-R96%T95]F=6YC=&EO;B@G
M)&$L("1B)RP@)W)E='5R;B`D82`N($E-4%])1%A?4T50("X@)&([)RDL(&%R
M<F%Y7W9A;'5E<R@D=&AI<RT^7W-O<G1E9"DL(&%R<F%Y7W9A;'5E<R@D=&AI
M<RT^7W-O<G1E9$UB;W@I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D87)R(#T@87)R87E?=F%L=65S*"1T:&ES+3Y?<V]R=&5D*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?<V5T4F%N9V4H)&%R<BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$971E<FUI;F4@=&AE(&-O<G)E8W0@<V]R="!M971H
M;V0@9F]R('1H:7,@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@4G5N('1H92!S
M;W)T7VQI;6ET(&-H96-K/PH@("`@("HO"B`@("!F=6YC=&EO;B!?9&5T97)M
M:6YE4V]R="@D8VAE8VL@/2!F86QS92D*("`@('L*("`@("`@("`D<V]R=&)Y
M(#T@)'1H:7,M/G-O<G1B>2@I.PH@("`@("`@(&EF("@D8VAE8VL@)B8*("`@
M("`@("`@("`@*"1S;W)T8GD@(3T@4T]25$%24DE604PI("8F"B`@("`@("`@
M("`@("%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=S97)V97(G75LG<V]R=%]L
M:6UI="==*2`F)@H@("`@("`@("`@("`H0&EM87!?;G5M7VUS9R@D1TQ/0D%,
M4ULG:6UP)UU;)W-T<F5A;2==*2`^("1'3$]"04Q36R=C;VYF)UU;)W-E<G9E
M<B==6R=S;W)T7VQI;6ET)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V]R
M=$QI;6ET(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/E]S;W)T8GD@/2!3
M3U)405)2259!3#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H
M)&-H96-K*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-O<G1,:6UI="`]
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M:7-3<&5C:6%L1F]L9&5R*"DI('L*("`@("`@("`@("`@("`@("\J($EF('1H
M92!P<F5F97)E;F-E(&ES('1O('-O<G0@8GD@1G)O;2!!9&1R97-S+"!W:&5N
M('=E(&%R90H@("`@("`@("`@("`@("`@("`@:6X@=&AE($1R869T<R!O<B!3
M96YT(&9O;&1E<G,L('-O<G0@8GD@5&\@061D<F5S<RX@*B\*("`@("`@("`@
M("`@("`@(&EF("@D<V]R=&)Y(#T](%-/4E1&4D]-*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S;W)T8GD@/2!33U)45$\["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D<V]R=&)Y(#T](%-/4E14
M3RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W)T8GD@/2!33U)41E)/
M33L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($UO=F4@8W5R<F5N="!P;VEN=&5R('1O('1H92!N97AT(&EN9&5X+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!M;W9E3F5X="@I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S971!<G)A>4EN9&5X*#$L("=O9F9S970G*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O;&EB+TE-05`N<&AP````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$P-#<V`#$P-#$W,S8R-S8V`#`Q-S(R-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($E-4%])34%0.CH@8VQA<W,@9F%C:6QI=&%T97,@8V]N;F5C
M=&EO;G,@=&\@=&AE($E-05`O4$]0,R!S97)V97(*("H@=FEA('1H92!C+6-L
M:65N="!02%`@97AT96YS:6]N<RX*("H*("H@)$AO<F1E.B!I;7`O;&EB+TE-
M05`N<&AP+'8@,2XQ,2XQ,"XQ,B`R,#`V+S`R+S$U(#`V.C`T.C(R('-L=7-A
M<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!)35`@-"XP"B`J($!P
M86-K86=E($E-4`H@*B\*8VQA<W,@24U07TE-05`@>PH*("`@("\J*@H@("`@
M("H@5&AE('-E<G9E<B!S=')I;F<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?<V5R=F5R4W1R:6YG.PH*("`@("\J*@H@
M("`@("H@5&AE('5S97)N86UE(&9O<B!T:&4@<V5R=F5R+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W5S97(["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<&%S<W=O<F0@9F]R('1H92!M86EL('-E<G9E<BX*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P
M87-S.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G1L>2!O<&5N(&UA:6QB
M;W@N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?;W!E;DUB;W@@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE($E-05`@
M9FQA9W,@<V5T(&EN('1H92!C=7)R96YT;'D@;W!E;B!M86EL8F]X+@H@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]M8F]X
M1FQA9W,@/2!N=6QL.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@24U07TE-05`@:6YS=&%N
M8V4N"B`@("`@*B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E
M(&EF(&YO($E-4%])34%0(&EN<W1A;F-E(&-U<G)E;G1L>0H@("`@("H@97AI
M<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME
M9"!A<SH*("`@("`J("`@)&EM<%]I;6%P(#T@)DE-4%])34%0.CIS:6YG;&5T
M;VXH*3L*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@4&%R
M86UE=&5R<R!N965D960N"B`@("`@*@H@("`@("H@0')E='5R;B!)35!?24U!
M4"`@5&AE(&-O;F-R971E($E-4%])34%0(')E9F5R96YC92P@;W(@9F%L<V4@
M;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC
M93L*"B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V4I*2!["B`@("`@("`@
M("`@("1I;G-T86YC92`](&YE=R!)35!?24U!4"@D<&%R86US*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!N965D960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($E-4%])34%0*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5R=F5R4W1R:6YG(#T@24U0
M.CIS97)V97)3=')I;F<H;G5L;"P@)%]315-324].6R=I;7`G75LG<')O=&]C
M;VPG72D["B`@("`@("`@)'1H:7,M/E]U<V5R(#T@)%]315-324].6R=I;7`G
M75LG=7-E<B==.PH@("`@("`@("1T:&ES+3Y?<&%S<R`](%-E8W)E=#HZ<F5A
M9"A396-R970Z.F=E=$ME>2@G:6UP)RDL("1?4T534TE/3ELG:6UP)UU;)W!A
M<W,G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N(&%N($E-05`@<W1R
M96%M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UB;W@@("`@02!M
M86EL8F]X('1O(&]P96XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9FQA9W,@
M($%N>2!F;&%G<R!T:&%T(&YE960@=&\@8F4@<&%S<V5D('1O(&EM87!?;W!E
M;B@I+@H@("`@("H*("`@("`J($!R971U<FX@<F5S;W5R8V4@(%1H92!R971U
M<FX@9G)O;2!T:&4@:6UA<%]O<&5N*"D@8V%L;"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;W!E;DE-05!3=')E86TH)&UB;W@@/2!N=6QL+"`D9FQA9W,@/2`P
M*0H@("`@>PH@("`@("`@("1I(#T@+3$["B`@("`@("`@)')E="`](&9A;'-E
M.PH@("`@("`@('=H:6QE("@H)')E="`]/3T@9F%L<V4I("8F"B`@("`@("`@
M("`@("`@("%S=')S='(H<W1R=&]L;W=E<BAI;6%P7VQA<W1?97)R;W(H*2DL
M("=L;V=I;B!F86EL=7)E)RD@)B8*("`@("`@("`@("`@("`@*"LK)&D@/"`S
M*2D@>PH@("`@("`@("`@("!I9B`H)&D@(3T@,"D@>PH@("`@("`@("`@("`@
M("`@<VQE97`H,2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E="`]
M($!I;6%P7V]P96XH)'1H:7,M/E]S97)V97)3=')I;F<@+B`D;6)O>"P@)'1H
M:7,M/E]U<V5R+"`D=&AI<RT^7W!A<W,L("1F;&%G<RD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA
M;F=E('1H92!C=7)R96YT;'D@86-T:79E($E-4"!)34%0('-T<F5A;2!T;R!A
M(&YE=R!M86EL8F]X"B`@("`@*B`H:68@;F5C97-S87)Y*2X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M8F]X("`@(%1H92!N97<@;6%I;&)O>"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1F;&%G<R`@06YY(&9L86=S('1H870@
M;F5E9"!T;R!B92!P87-S960@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@:6UA<%]R96]P96XH*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-H86YG94UB;W@H)&UB;W@L("1F;&%G<R`](#`I
M"B`@("!["B`@("`@("`@+RH@3W!E;B!A(&-O;FYE8W1I;VX@:68@;F]N92!E
M>&ES=',N("HO"B`@("`@("`@:68@*&5M<'1Y*"1?4T534TE/3ELG:6UP)UU;
M)W-T<F5A;2==*2D@>PH@("`@("`@("`@("!I9B`H*"1?4T534TE/3ELG:6UP
M)UU;)W-T<F5A;2==(#T@)'1H:7,M/F]P96Y)34%04W1R96%M*"1M8F]X+"`D
M9FQA9W,I*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O<&5N36)O>"`]
M("1M8F]X.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M8F]X1FQA9W,@/2`D
M9FQA9W,["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1?4T534TE/3ELG
M:6UP)UU;)VEM87!?<V5R=F5R)UU;)W1I;65O=70G72DI('L*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D7U-%4U-)3TY;)VEM<"==6R=I;6%P7W-E
M<G9E<B==6R=T:6UE;W5T)UT@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EM87!?=&EM96]U="@D:V5Y+"`D=F%L*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"1?4T534TE/3ELG:6UP)UU;)V)A<V5?<')O
M=&]C;VPG72`]/2`G<&]P,R<I('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H*("`@("`@("`O*B!/;FQY(')E;W!E;B!M86EL8F]X(&EF
M('=E(&YE960@=&\@+2!E:71H97(@=V4@87)E(&-H86YG:6YG"B`@("`@("`@
M("`@;6%I;&)O>&5S(&]R('1H92!F;&%G<R!F;W(@=&AE(&-U<G)E;G0@;6%I
M;&)O>"!H87,@8VAA;F=E9"X@*B\*("`@("`@("!I9B`H*"1T:&ES+3Y?;W!E
M;DUB;W@@(3T@)&UB;W@I('Q\("@D=&AI<RT^7VUB;WA&;&%G<R`A/2`D9FQA
M9W,I*2!["B`@("`@("`@("`@("1R97-U;'0@/2!`:6UA<%]R96]P96XH)%]3
M15-324].6R=I;7`G75LG<W1R96%M)UTL("1T:&ES+3Y?<V5R=F5R4W1R:6YG
M("X@)&UB;W@L("1F;&%G<RD["B`@("`@("`@("`@(&EF("@D<F5S=6QT*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]P96Y-8F]X(#T@)&UB;W@["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VUB;WA&;&%G<R`]("1F;&%G<SL*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O
M<')E9G,N<&AP````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3$U-C8`,3`T,3<S-C(W-C8`,#$W-C(Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@ID969I;F4H)TE-
M4%]04D5&7TY/7T9/3$1%4B<L("<J*FYO9F]L9&5R)RD["@HO*BH*("H@)$AO
M<F1E.B!I;7`O;&EB+W!R969S+G!H<"QV(#$N,RXQ,"XQ,B`R,#`V+S`Q+S$X
M(#`T.C4X.C,Q('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O9W!L+FAT;6PN"B`J+PH*9G5N8W1I;VX@:&%N9&QE7W-E;G1M86EL
M<V5L96-T*"1U<&1A=&5D*0I["B`@("!G;&]B86P@)&-O;F8L("1I;7`L("1P
M<F5F<RP@)&ED96YT:71Y.PH*("`@(&EF("@D8V]N9ELG=7-E<B==6R=A;&QO
M=U]F;VQD97)S)UT@)B8*("`@("`@("`A)'!R969S+3YI<TQO8VME9"@G<V5N
M=%]M86EL7V9O;&1E<B<I*2!["B`@("`@("`@)'-E;G1?;6%I;%]F;VQD97(@
M/2!5=&EL.CIG971&;W)M1&%T82@G<V5N=%]M86EL)RD["B`@("`@("`@)'-E
M;G1?;6%I;%]N97<@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*%5T:6PZ.F=E
M=$9O<FU$871A*"=S96YT7VUA:6Q?;F5W)RDL($Y,4SHZ9V5T0VAA<G-E="@I
M+"`G551&-RU)34%0)RD["B`@("`@("`@)'-E;G1?;6%I;%]D969A=6QT(#T@
M)'!R969S+3YG971686QU92@G<V5N=%]M86EL7V9O;&1E<B<I.PH@("`@("`@
M(&EF("AE;7!T>2@D<V5N=%]M86EL7V9O;&1E<BD@)B8@(65M<'1Y*"1S96YT
M7VUA:6Q?;F5W*2D@>PH@("`@("`@("`@("`D<V5N=%]M86EL7V9O;&1E<B`]
M($E-4#HZ87!P96YD3F%M97-P86-E*"1S96YT7VUA:6Q?;F5W*3L*("`@("`@
M("!](&5L<V5I9B`H*"1S96YT7VUA:6Q?9F]L9&5R(#T]("<M,2<I("8F("%E
M;7!T>2@D<V5N=%]M86EL7V1E9F%U;'0I*2!["B`@("`@("`@("`@("1S96YT
M7VUA:6Q?9F]L9&5R(#T@)'-E;G1?;6%I;%]D969A=6QT.PH@("`@("`@('T*
M("`@("`@("`D<V5N=%]M86EL7V9O;&1E<B`]($E-4#HZ9F]L9&5R4')E9B@D
M<V5N=%]M86EL7V9O;&1E<BP@=')U92D["B`@("`@("`@:68@*"%E;7!T>2@D
M<V5N=%]M86EL7V9O;&1E<BDI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E
M($E-4%]"05-%("X@)R]L:6(O1F]L9&5R+G!H<"<["B`@("`@("`@("`@("1I
M;7!?9F]L9&5R(#T@)DE-4%]&;VQD97(Z.G-I;F=L971O;B@I.PH@("`@("`@
M("`@("!I9B`H(21I;7!?9F]L9&5R+3YE>&ES=',H)'-E;G1?;6%I;%]F;VQD
M97(I*2!["B`@("`@("`@("`@("`@("`D:6UP7V9O;&1E<BT^8W)E871E*"1S
M96YT7VUA:6Q?9F]L9&5R+"`D<')E9G,M/F=E=%9A;'5E*"=S=6)S8W)I8F4G
M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&ED96YT:71Y
M+3YS971686QU92@G<V5N=%]M86EL7V9O;&1E<B<L($E-4#HZ9F]L9&5R4')E
M9B@D<V5N=%]M86EL7V9O;&1E<BP@9F%L<V4I*3L*("`@("`@("`D=7!D871E
M9"`]('1R=64["B`@("!]"@H@("`@<F5T=7)N("1U<&1A=&5D.PI]"@IF=6YC
M=&EO;B!H86YD;&5F;VQD97)S*"1U<&1A=&5D+"`D<')E9BP@)&9O;&1E<BP@
M)&YE=RD*>PH@("`@9VQO8F%L("1C;VYF+"`D:6UP+"`D<')E9G,["@H@("`@
M:68@*"1C;VYF6R=U<V5R)UU;)V%L;&]W7V9O;&1E<G,G72D@>PH@("`@("`@
M("1F;VQD97(@/2!5=&EL.CIG971&;W)M1&%T82@D9F]L9&5R*3L*("`@("`@
M("!I9B`H:7-S970H)&9O;&1E<BD@)B8@(21P<F5F<RT^:7-,;V-K960H)'!R
M968I*2!["B`@("`@("`@("`@("1N97<@/2!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*%5T:6PZ.F=E=$9O<FU$871A*"1N97<I+"!.3%,Z.F=E=$-H87)S970H
M*2P@)U541C<M24U!4"<I.PH@("`@("`@("`@("!I9B`H)&9O;&1E<B`]/2!)
M35!?4%)%1E].3U]&3TQ$15(I('L*("`@("`@("`@("`@("`@("1P<F5F<RT^
M<V5T5F%L=64H)'!R968L("<G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D9F]L9&5R*2`F)B`A96UP='DH)&YE
M=RDI('L*("`@("`@("`@("`@("`@("`@("`D9F]L9&5R(#T@24U0.CIA<'!E
M;F1.86UE<W!A8V4H)&YE=RD["B`@("`@("`@("`@("`@("`@("`@:6YC;'5D
M95]O;F-E($E-4%]"05-%("X@)R]L:6(O1F]L9&5R+G!H<"<["B`@("`@("`@
M("`@("`@("`@("`@)&EM<%]F;VQD97(@/2`F24U07T9O;&1E<CHZ<VEN9VQE
M=&]N*"D["B`@("`@("`@("`@("`@("`@("`@:68@*"$D:6UP7V9O;&1E<BT^
M8W)E871E*"1F;VQD97(L("1P<F5F<RT^9V5T5F%L=64H)W-U8G-C<FEB92<I
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]L9&5R(#T@;G5L;#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1F;VQD97(I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'!R969S+3YS971686QU92@D<')E9BP@24U0.CIF;VQD97)0
M<F5F*"1F;VQD97(L(&9A;'-E*2D["B`@("`@("`@("`@("`@("`@("`@)'5P
M9&%T960@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@(')E='5R;B`D=7!D871E9#L*?0H*9G5N
M8W1I;VX@:&%N9&QE7V9O;&1E<G-E;&5C="@D=7!D871E9"D*>PH@("`@<F5T
M=7)N("1U<&1A=&5D('P@:&%N9&QE9F]L9&5R<R@D=7!D871E9"P@)V1R869T
M<U]F;VQD97(G+"`G9')A9G1S)RP@)V1R869T<U]N97<G*3L*?0H*9G5N8W1I
M;VX@:&%N9&QE7W1R87-H<V5L96-T*"1U<&1A=&5D*0I["B`@("!R971U<FX@
M)'5P9&%T960@?"!H86YD;&5F;VQD97)S*"1U<&1A=&5D+"`G=')A<VA?9F]L
M9&5R)RP@)W1R87-H)RP@)W1R87-H7VYE=R<I.PI]"@IF=6YC=&EO;B!H86YD
M;&5?<V]U<F-E<V5L96-T*"1U<&1A=&5D*0I["B`@("!G;&]B86P@)'!R969S
M.PH*("`@("1S96%R8VA?<V]U<F-E<R`](%5T:6PZ.F=E=$9O<FU$871A*"=S
M96%R8VA?<V]U<F-E<R<I.PH@("`@:68@*"%I<U]N=6QL*"1S96%R8VA?<V]U
M<F-E<RDI('L*("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=S96%R8VA?<V]U
M<F-E<R<L("1S96%R8VA?<V]U<F-E<RD["B`@("`@("`@)'5P9&%T960@/2!T
M<G5E.PH@("`@?0H*("`@("1S96%R8VA?9FEE;&1S7W-T<FEN9R`](%5T:6PZ
M.F=E=$9O<FU$871A*"=S96%R8VA?9FEE;&1S7W-T<FEN9R<I.PH@("`@:68@
M*"%I<U]N=6QL*"1S96%R8VA?9FEE;&1S7W-T<FEN9RDI('L*("`@("`@("`D
M<')E9G,M/G-E=%9A;'5E*"=S96%R8VA?9FEE;&1S)RP@)'-E87)C:%]F:65L
M9'-?<W1R:6YG*3L*("`@("`@("`D=7!D871E9"`]('1R=64["B`@("!]"@H@
M("`@)&%D9%]S;W5R8V4@/2!5=&EL.CIG971&;W)M1&%T82@G861D7W-O=7)C
M92<I.PH@("`@:68@*"%I<U]N=6QL*"1A9&1?<V]U<F-E*2D@>PH@("`@("`@
M("1P<F5F<RT^<V5T5F%L=64H)V%D9%]S;W5R8V4G+"`D861D7W-O=7)C92D[
M"B`@("`@("`@)'5P9&%T960@/2!T<G5E.PH@("`@?0H*("`@(')E='5R;B`D
M=7!D871E9#L*?0H*9G5N8W1I;VX@:&%N9&QE7VEN:71I86QP86=E<V5L96-T
M*"1U<&1A=&5D*0I["B`@("`D:6YI=&EA;%]P86=E(#T@571I;#HZ9V5T1F]R
M;41A=&$H)VEN:71I86Q?<&%G92<I.PH@("`@)$=,3T)!3%-;)W!R969S)UTM
M/G-E=%9A;'5E*"=I;FET:6%L7W!A9V4G+"`D:6YI=&EA;%]P86=E*3L*("`@
M(')E='5R;B!T<G5E.PI]"@IF=6YC=&EO;B!H86YD;&5?96YC<GEP='-E;&5C
M="@D=7!D871E9"D*>PH@("`@)&1E9F%U;'1?96YC<GEP="`](%5T:6PZ.F=E
M=$9O<FU$871A*"=D969A=6QT7V5N8W)Y<'0G*3L*("`@("1'3$]"04Q36R=P
M<F5F<R==+3YS971686QU92@G9&5F875L=%]E;F-R>7!T)RP@)&1E9F%U;'1?
M96YC<GEP="D["B`@("!R971U<FX@=')U93L*?0H*9G5N8W1I;VX@:&%N9&QE
M7W-P86US96QE8W0H)'5P9&%T960I"GL*("`@(')E='5R;B`D=7!D871E9"!\
M(&AA;F1L969O;&1E<G,H)'5P9&%T960L("=S<&%M7V9O;&1E<B<L("=S<&%M
M)RP@)W-P86U?;F5W)RD["GT*"F9U;F-T:6]N(&AA;F1L95]D969A=6QT<V5A
M<F-H<V5L96-T*"1U<&1A=&5D*0I["B`@("`D9&5F875L=%]S96%R8V@@/2!5
M=&EL.CIG971&;W)M1&%T82@G9&5F875L=%]S96%R8V@G*3L*("`@("1'3$]"
M04Q36R=P<F5F<R==+3YS971686QU92@G9&5F875L=%]S96%R8V@G+"`D9&5F
M875L=%]S96%R8V@I.PH@("`@<F5T=7)N('1R=64["GT*"F9U;F-T:6]N('!R
M969S7V-A;&QB86-K*"D*>PH@("`@:68@*"1'3$]"04Q36R=P<F5F<R==+3YI
M<T1I<G1Y*"=U<V5?=G1R87-H)RDI('L*("`@("`@("!R97%U:7)E7V]N8V4@
M24U07T)!4T4@+B`G+VQI8B]396%R8V@N<&AP)SL*("`@("`@("`D:6UP7W-E
M87)C:"`](&YE=R!)35!?4V5A<F-H*"D["B`@("`@("`@)&EM<%]S96%R8V@M
M/G-E<W-I;VY3971U<"@I.PH@("`@?0H*("`@(&EF("@D1TQ/0D%,4ULG<')E
M9G,G72T^:7-$:7)T>2@G<W5B<V-R:6)E)RDI('L*("`@("`@("!R97%U:7)E
M7V]N8V4@24U07T)!4T4@+B`G+VQI8B])34%0+U1R964N<&AP)SL*("`@("`@
M("`D:6UP=')E92`]("9)35!?5')E93HZ<VEN9VQE=&]N*"D["B`@("`@("`@
M)&EM<'1R964M/FEN:70H*3L*("`@('T*?0H*<F5Q=6ER95]O;F-E($E-4%]"
M05-%("X@)R]L:6(O36%I;G1E;F%N8V4O:6UP+G!H<"<["B1M86EN="`]("9N
M97<@36%I;G1E;F%N8V5?24U0*"D["F9O<F5A8V@@*"@D;6%I;G0M/F5X<&]R
M=$EN=&5R=F%L4')E9G,H*2D@87,@)'9A;"D@>PH@("`@)"1V86P@/2`F)&EN
M=&5R=F%L<SL*?0H*+RH@36%K92!S=7)E('=E(&AA=F4@86X@86-T:79E($E-
M05`@<W1R96%M+B`J+PHD1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G;6%I
M;"]G9713=')E86TG*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O;&EB+RYH=&%C8V5S<P``````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#$V`#$P-#$W,S8R-S8V`#`Q-S4U,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!$96YY(&9R;VT@
M86QL"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]V97)S
M:6]N+G!H<```````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`U,P`Q,#0Q-S,V,C<V-@`P,C`Q-30`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`@9&5F:6YE*"=)35!?5D52
M4TE/3B<L("=(,R`H-"XQ*2<I(#\^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O4V5S<VEO;BYP:'``````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#$P,#(`,3`T
M,3<S-C(W-C8`,#(P,3$Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!&=6YC=&EO;G,@<F5Q=6ER960@
M=&\@<W1A<G0@86X@24U0('-E<W-I;VXN"B`J"B`J("1(;W)D93H@:6UP+VQI
M8B]397-S:6]N+G!H<"QV(#$N-S0N,BXR,R`R,#`V+S`R+S$U(#`Q.C(Y.C(V
M('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y
M.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!)35`@-"XP"B`J($!P86-K86=E($E-4`H@*B\*8VQA<W,@
M24U07U-E<W-I;VX@>PH*("`@("\J*@H@("`@("H@5&%K92!I;F9O<FUA=&EO
M;B!P;W-T960@9G)O;2!A(&QO9VEN(&%T=&5M<'0@86YD('1R>2!S971T:6YG
M('5P"B`@("`@*B!A;B!I;FET:6%L($E-4"!S97-S:6]N+B!(86YD;&4@2&]R
M9&4@875T:&5N=&EC871I;VXL(&EF"B`@("`@*B!R97%U:7)E9"P@86YD(&]N
M;'D@9&\@96YO=6=H('=O<FL@=&\@<V5E(&EF('1H92!U<V5R(&-A;B!L;V<*
M("`@("`J(&EN+B!4:&ES(&9U;F-T:6]N('-H;W5L9"!O;FQY(&)E(&-A;&QE
M9"!O;F-E+"!W:&5N('1H92!U<V5R"B`@("`@*B!F:7)S="!L;V=S(&EN+@H@
M("`@("H*("`@("`J($-R96%T97,@=&AE("1I;7`@<V5S<VEO;B!V87)I86)L
M92!W:71H('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("=?;&]G:6YT
M87-K<R<@("`M+2!(879E('1H92!L;V=I;B!T87-K<R!B965N(&-O;7!L971E
M9#\*("`@("`J("=A8VPG("`@("`@("`@("`M+2!3964@8V]N9FEG+W-E<G9E
M<G,N<&AP+@H@("`@("H@)V%D;6EN)R`@("`@("`@("TM(%-E92!C;VYF:6<O
M<V5R=F5R<RYP:'`N"B`@("`@*B`G8F%S95]P<F]T;V-O;"<@+2T@16ET:&5R
M("=I;6%P)R!O<B`G<&]P,R<N"B`@("`@*B`G8V%C:&4G("`@("`@("`@+2T@
M5F%R:6]U<R!)35`@;&EB<F%R:65S(&-A;B!U<V4@=&AI<R!V87)I86)L92!T
M;R!C86-H90H@("`@("H@("`@("`@("`@("`@("`@("`@(&1A=&$N"B`@("`@
M*B`G9FEL95]U<&QO860G("`@+2T@268@9FEL92!U<&QO861S(&%R92!A;&QO
M=V5D+"!T:&4@;6%X('-I>F4N"B`@("`@*B`G9FEL=&5R879A:6PG("`@+2T@
M0V%N('=E(&%P<&QY(&9I;'1E<G,@;6%N=6%L;'D_"B`@("`@*B`G:6UA<%]S
M97)V97(G("`@+2T@24U!4"!S97)V97(@8V%P86)I;&ET:65S+@H@("`@("H@
M)VUA:6QB;W@G("`@("`@("TM(%1H92!C=7)R96YT('9I97=A8FQE(&UA:6QB
M;W@N"B`@("`@*B`G;6%I;&1O;6%I;B<@("`@+2T@4V5E(&-O;F9I9R]S97)V
M97)S+G!H<"X*("`@("`J("=N86UE<W!A8V4G("`@("`M+2!3964@8V]N9FEG
M+W-E<G9E<G,N<&AP+@H@("`@("H@)VYO=&5P861A=F%I;"<@("TM($ES(&QI
M<W1I;F<@;V8@;F]T97!A9',@879A:6QA8FQE/PH@("`@("H@)W!A<W,G("`@
M("`@("`@("TM(%1H92!E;F-R>7!T960@<&%S<W=O<F0N"B`@("`@*B`G<&]R
M="<@("`@("`@("`@+2T@4V5E(&-O;F9I9R]S97)V97)S+G!H<"X*("`@("`J
M("=P<F]T;V-O;"<@("`@("`M+2!3964@8V]N9FEG+W-E<G9E<G,N<&AP+@H@
M("`@("H@)W%U;W1A)R`@("`@("`@("TM(%-E92!C;VYF:6<O<V5R=F5R<RYP
M:'`N"B`@("`@*B`G<V5A<F-H)R`@("`@("`@+2T@4V5T=&EN9W,@=7-E9"!B
M>2!T:&4@24U07U-E87)C:"!L:6)R87)Y+@H@("`@("H@)W-E<G9E<B<@("`@
M("`@("TM(%1H92!N86UE(&]F('1H92!S97)V97(@96YT<GD@:6X@8V]N9FEG
M+W-E<G9E<G,N<&AP+@H@("`@("H@)W-M:6UE)R`@("`@("`@("TM(%-E='1I
M;F=S(')E;&%T960@=&\@=&AE(%,O34E-12!V:65W97(N"B`@("`@*B`G<VUT
M<&AO<W0G("`@("`@+2T@5&AE(%--5%`@:&]S="!T;R!U<V4@:6YS=&5A9"!O
M9B!T:&4@2&]R9&4@9&5F875L="X*("`@("`J("=S;71P<&]R="<@("`@("`M
M+2!4:&4@4TU44"!P;W)T('1O('5S92!I;G-T96%D(&]F('1H92!(;W)D92!D
M969A=6QT+@H@("`@("H@)W-H;W=U;G-U8B<@("`@("TM(%-H;W<@=6YS=7-U
M8G-C<FEB960@;6%I;&)O>&5S(&]N('1H92!F;VQD97)S('-C<F5E;BX*("`@
M("`J("=T87-K;&ES=&%V86EL)R`M+2!)<R!L:7-T:6YG(&]F('1A<VML:7-T
M<R!A=F%I;&%B;&4_"B`@("`@*B`G=&AI<VUA:6QB;W@G("`@+2T@5&AE(&UA
M:6QB;W@@8V]N=&%I;FEN9R!T:&4@8W5R<F5N="!V:65W86)L92!M97-S86=E
M+@H@("`@("H@)W5N:7%U<V5R)R`@("`@("TM(%1H92!U;FEQ=64@=7-E<B!N
M86UE+@H@("`@("H@)W5S97(G("`@("`@("`@("TM(%1H92!)34%0('5S97)N
M86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EM87!U<V5R("!4
M:&4@=7-E<FYA;64@;V8@=&AE('5S97(N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P87-S=V]R9"`@5&AE('!A<W-W;W)D(&]F('1H92!U<V5R+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V5R=F5R("`@(%1H92!S97)V97(@=&\@=7-E("AS
M964@8V]N9FEG+W-E<G9E<G,N<&AP*2X*("`@("`J($!P87)A;2!A<G)A>2`D
M87)G<R`@("`@("!4:&4@;F5C97-S87)Y('-E<G9E<B!I;F9O<FUA=&EO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E
M871E4V5S<VEO;B@D:6UA<'5S97(L("1P87-S=V]R9"P@)'-E<G9E<BP@)&%R
M9W,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9BP@)')E
M9VES=')Y.PH*("`@("`@("`O*B!792!N965D(&)O=&@@82!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0N("HO"B`@("`@("`@:68@*&5M<'1Y*"1I;6%P=7-E<BD@
M?'P@96UP='DH)'!A<W-W;W)D*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@86QL(&YE8V5S
M<V%R>2!P87)A;65T97)S(&%R92!S970N("HO"B`@("`@("`@)&1E9F%U;'1?
M87)G<R`](&%R<F%Y*`H@("`@("`@("`@("`G<F5A;&TG("`@("`@("`]/B`G
M)RP*("`@("`@("`@("`@)W!O<G0G("`@("`@("`@/3X@)R<L"B`@("`@("`@
M("`@("=P<F]T;V-O;"<@("`@(#T^("<G+`H@("`@("`@("`@("`G;6%I;&1O
M;6%I;B<@("`]/B`G)RP*("`@("`@("`@("`@)VEM87!?<V5R=F5R)R`@/3X@
M87)R87DH)V-H:6QD<F5N)R`]/B!F86QS92DL"B`@("`@("`@*3L*"B`@("`@
M("`@+RH@365R9V4@=VET:"!T:&4@<&%S<V5D+6EN('!A<F%M971E<G,N("HO
M"B`@("`@("`@)&%R9W,@/2!A<G)A>5]M97)G92@D9&5F875L=%]A<F=S+"`D
M87)G<RD["@H@("`@("`@("\J($-R96%T92!T:&4@)&EM<"!S97-S:6]N('9A
M<FEA8FQE+B`J+PH@("`@("`@("1?4T534TE/3ELG:6UP)UT@/2!A<G)A>2@I
M.PH@("`@("`@("1?4T534TE/3ELG:6UP)UU;)V-A8VAE)UT@/2!A<G)A>2@I
M.PH@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W!A<W,G72`](%-E8W)E=#HZ
M=W)I=&4H4V5C<F5T.CIG971+97DH)VEM<"<I+"`D<&%S<W=O<F0I.PH*("`@
M("`@("`O*B!3970@=&AE(&QO9VEN=&%S:W,@9FQA9RX@*B\*("`@("`@("!)
M35`Z.FQO9VEN5&%S:W-&;&%G*#$I.PH*("`@("`@("`O*B!2=6X@=&AE('5S
M97)N86UE('1H<F]U9V@@=FER='5A;&AO<W0@97AP86YS:6]N(&9U;F-T:6]N
M<R!I9@H@("`@("`@("`J(&YE8V5S<V%R>2X@*B\*("`@("`@("`D7U-%4U-)
M3TY;)VEM<"==6R=U<V5R)UT@/2`D:6UA<'5S97(["B`@("`@("`@:68@*"%E
M;7!T>2@D8V]N9ELG:&]O:W,G75LG=FEN9F\G72DI('L*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G
M.PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?
M=FEN9F\G*2D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG
M=7-E<B==(#T@8V%L;%]U<V5R7V9U;F,H)U]I;7!?:&]O:U]V:6YF;R<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!792!M:6=H="!N
M965D('1O(&]V97)R:61E('-O;64@;V8@=&AE(&1E9F%U;'1S('=I=&@*("`@
M("`@("`@*B!E;G9I<F]N;65N="UW:61E('-E='1I;F=S+B!$;R!.3U0@=7-E
M('1H92!G;&]B86P@)'-E<G9E<G,*("`@("`@("`@*B!V87)I86)L92!A<R!I
M="!M87D@;F]T(&5X:7-T+B`J+PH@("`@("`@(')E<75I<F4@24U07T)!4T4@
M+B`G+V-O;F9I9R]S97)V97)S+G!H<"<["@H@("`@("`@("\J(%!A=&-H(&9O
M<B!04T$Z($D@;F]T(&9O=6YD(&$@8V]N9FEG(&)A<V5D+7=A>2!T;R!D:7-A
M8FQE("`@"B`@("`@("`@("H@<VAO<G0@;F%M97,L('=I=&AO=70@0"!S;R!A
M<'!L>2!T:&ES('!A=&-H("HO"@H):68@*"%P<F5G7VUA=&-H*"<O7B@N*RE`
M*"XK*20O)RP@)&EM87!U<V5R+"`D;6%T8VAE<RDI>R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;6%P=7-E<B`N/2`G0"<@+B`D1&]M86EN
M3F%M93L*"2`@("`D7U-%4U-)3TY;)VEM<"==6R=U<V5R)UT@/2!T<FEM*"1I
M;6%P=7-E<BD["@E]"@H@("`@("`@("\J($1E=&5R;6EN92!T:&4@=6YI<75E
M('5S97(@;F%M92X@*B\*("`@("`@("!I9B`H075T:#HZ:7-!=71H96YT:6-A
M=&5D*"DI('L*("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG=6YI<75S
M97(G72`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=U;FEQ=7-E<B==(#T@)%]315-3
M24].6R=I;7`G75LG=7-E<B==.PH*("`@("`@("`@("`@:68@*"@D8V]N9ELG
M<V5R=F5R)UU;)W-E<G9E<E]L:7-T)UT@(3T@)VYO;F4G*2`F)@H@("`@("`@
M("`@("`@("`@(65M<'1Y*"1S97)V97)S6R1S97)V97)=6R=R96%L;2==*2D@
M>PH@("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG=6YI<75S97(G
M72`N/2`G0"<@+B`D<V5R=F5R<ULD<V5R=F5R75LG<F5A;&TG73L*("`@("`@
M("`@("`@?2!E;'-E:68@*"%E;7!T>2@D87)G<ULG<F5A;&TG72DI('L*("`@
M("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W5N:7%U<V5R)UT@+CT@
M)T`G("X@)&%R9W-;)W)E86QM)UT["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@H)&-O;F9;)W-E<G9E<B==6R=S97)V97)?;&ES="==
M("$]("=N;VYE)RD@)B8*("`@("`@("`@("`@(65M<'1Y*"1S97)V97)S6R1S
M97)V97)=*2`F)@H@("`@("`@("`@("!I<U]A<G)A>2@D<V5R=F5R<ULD<V5R
M=F5R72DI('L*("`@("`@("`@("`@)&9I96QD<R`](&%R<F%Y*"=S97)V97(G
M+"`G<')O=&]C;VPG+"`G<&]R="<L("=M86EL9&]M86EN)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=Q=6]T82<L("=A8VPG*3L*("`@("`@("`@
M("`@)&9I96QD<U]A<G)A>2`](&%R<F%Y*"=A9&UI;B<I.PH@("`@("`@("`@
M("`D<'1R(#T@)B1S97)V97)S6R1S97)V97)=.PH*("`@("`@("`@("`@9F]R
M96%C:"`H)&9I96QD<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D7U-%
M4U-)3TY;)VEM<"==6R1V86Q=(#T@:7-S970H)'!T<ELD=F%L72D@/R`D<'1R
M6R1V86Q=(#H@;G5L;#L*("`@("`@("`@("`@("`@("\J("=A9&UI;B<@86YD
M("=Q=6]T82<@:&%V92!P87-S=V]R9"!E;G1R:65S("T@96YC<GEP="!T:&5S
M90H@("`@("`@("`@("`@("`@("H@96YT<FEE<R!I;B!T:&4@<V5S<VEO;B!I
M9B!T:&5Y(&5X:7-T+B`J+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P
M=');)'9A;%U;)W!A<F%M<R==6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)'9A;%U;)W!A<F%M<R==6R=P
M87-S=V]R9"==(#T@4V5C<F5T.CIW<FET92A396-R970Z.F=E=$ME>2@G:6UP
M)RDL("1P=');)'9A;%U;)W!A<F%M<R==6R=P87-S=V]R9"==*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H
M("@D9FEE;&1S7V%R<F%Y(&%S("1V86PI('L*("`@("`@("`@("`@("`@("1?
M4T534TE/3ELG:6UP)UU;)'9A;%T@/2!I<W-E="@D<'1R6R1V86Q=*2`_("1P
M=');)'9A;%T@.B!A<G)A>2@I.PH@("`@("`@("`@("`@("`@+RH@)V%D;6EN
M)R!A;F0@)W%U;W1A)R!H879E('!A<W-W;W)D(&5N=')I97,@+2!E;F-R>7!T
M('1H97-E"B`@("`@("`@("`@("`@("`@*B!E;G1R:65S(&EN('1H92!S97-S
M:6]N(&EF('1H97D@97AI<W0N("HO"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'!T<ELD=F%L75LG<&%R86US)UU;)W!A<W-W;W)D)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LD=F%L75LG<&%R86US
M)UU;)W!A<W-W;W)D)UT@/2!396-R970Z.G=R:71E*%-E8W)E=#HZ9V5T2V5Y
M*"=I;7`G*2P@)'!T<ELD=F%L75LG<&%R86US)UU;)W!A<W-W;W)D)UTI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H)&-O;F9;)VUA:6QE<B==6R=T>7!E)UT@/3T@)W-M='`G*2!["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1P=');)W-M='!H;W-T)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG<VUT<&AO<W0G
M72`]("1P=');)W-M='!H;W-T)UT["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1P=');)W-M='!P;W)T)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG<VUT<'!O<G0G
M72`]("1P=');)W-M='!P;W)T)UT["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<V5R=F5R
M7VME>2`](&YU;&P["B`@("`@("`@("`@(&9O<F5A8V@@*"1S97)V97)S(&%S
M("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)'-E<G9E<E]K97DI("8F("AS=6)S='(H)&ME>2P@,"P@,2D@(3T@)U\G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1S97)V97)?:V5Y(#T@)&ME>3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("A)35`Z.FES4')E
M9F5R<F5D4V5R=F5R*"1V86PL("1K97DI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'-E<G9E<E]K97D@/2`D:V5Y.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1P='(@/2`F)'-E<G9E<G-;)'-E<G9E<E]K97E=.PH*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG<V5R=F5R)UU;)V-H86YG95]S97)V97(G
M72DI('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W-E<G9E
M<B==(#T@)'-E<G9E<CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1?4T534TE/3ELG:6UP)UU;)W-E<G9E<B==(#T@)'!T<ELG<V5R
M=F5R)UT["@H@("`@("`@("`@("`@("`@9F]R96%C:"`H87)R87DH)V%C;"<L
M("=A9&UI;B<L("=Q=6]T82<I(&%S("1V86PI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'!T<ELD=F%L72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)%]315-324].6R=I;7`G75LD=F%L72`]("1P=');)'9A;%T[
M"B`@("`@("`@("`@("`@("`@("`@("`@("\J("=A9&UI;B<@86YD("=Q=6]T
M82<@:&%V92!P87-S=V]R9"!E;G1R:65S("T@96YC<GEP=`H@("`@("`@("`@
M("`@("`@("`@("`@("`@*B!T:&5S92!E;G1R:65S(&EN('1H92!S97-S:6]N
M(&EF('1H97D@97AI<W0N("HO"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<'1R6R1V86Q=6R=P87)A;7,G75LG<&%S<W=O<F0G72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;
M)'9A;%U;)W!A<F%M<R==6R=P87-S=V]R9"==(#T@4V5C<F5T.CIW<FET92A3
M96-R970Z.F=E=$ME>2@G:6UP)RDL("1P=');)'9A;%U;)W!A<F%M<R==6R=P
M87-S=V]R9"==*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP)UU;)'9A;%T@/2!F86QS93L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=P;W)T)RP@)W!R;W1O8V]L)RP@
M)W-M='!H;W-T)RP@)W-M='!P;W)T)RD@87,@)'!A<F%M*2!["B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=S97)V97(G75LG8VAA;F=E7R<@
M+B`D<&%R86U=*2D@>PH@("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG
M:6UP)UU;)'!A<F%M72`](&ES<V5T*"1A<F=S6R1P87)A;5TI(#\@)&%R9W-;
M)'!A<F%M72`Z(&YU;&P["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)'!A<F%M72`](&ES
M<V5T*"1P=');)'!A<F%M72D@/R`D<'1R6R1P87)A;5T@.B!N=6QL.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D7U-%
M4U-)3TY;)VEM<"==6R=M86EL9&]M86EN)UT@/2`D87)G<ULG;6%I;&1O;6%I
M;B==.PH@("`@("`@('T*"B`@("`@("`@+RH@1&5T97)M:6YE('1H92!B87-E
M('!R;W1O8V]L+B`J+PH@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D7U-%
M4U-)3TY;)VEM<"==6R=P<F]T;V-O;"==+"`G+R<I*2D@>PH@("`@("`@("`@
M("`D7U-%4U-)3TY;)VEM<"==6R=B87-E7W!R;W1O8V]L)UT@/2!S=')T;VQO
M=V5R*'-U8G-T<B@D7U-%4U-)3TY;)VEM<"==6R=P<F]T;V-O;"==+"`P+"`D
M<&]S*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)%]315-324].
M6R=I;7`G75LG8F%S95]P<F]T;V-O;"==(#T@<W1R=&]L;W=E<B@D7U-%4U-)
M3TY;)VEM<"==6R=P<F]T;V-O;"==*3L*("`@("`@("!]"@H@("`@("`@("\J
M(%-E="!T:&4@:6YI=&EA;"!M86EL8F]X('1O(&)L86YK+B`J+PH@("`@("`@
M("1?4T534TE/3ELG:6UP)UU;)VUA:6QB;W@G72`]("1?4T534TE/3ELG:6UP
M)UU;)W1H:7-M86EL8F]X)UT@/2`G)SL*"B`@("`@("`@+RH@5')Y('1O(&%U
M=&AE;G1I8V%T92!W:71H('1H92!G:79E;B!I;F9O<FUA=&EO;BX@*B\*("`@
M("`@("`D875T:%]I;7`@/2`F075T:#HZ<VEN9VQE=&]N*&%R<F%Y*"=I;7`G
M+"`G:6UP)RDI.PH@("`@("`@("1A=71H7VEM<"T^875T:&5N=&EC871E3W!T
M:6]N<RAA<G)A>2@G9FQA9W,G(#T^($]07TA!3$9/4$5.*2D["B`@("`@("`@
M:68@*"1A=71H7VEM<"T^875T:&5N=&EC871E*&YU;&PL(&YU;&PL('1R=64I
M("$]/2!T<G5E*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\J(%-E="!T:&4@<V5S<VEO;B!V87)I86)L97,N(%1H
M97-E(&%R92!C86-H960N("HO"B`@("`@("`@)%]315-324].6R=I;7`G75LG
M;6%I;&)O>"==(#T@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=M86EL
M8F]X)RD["@H@("`@("`@("\J($1O97,@=&AE('-E<G9E<B!A;&QO=R!F:6QE
M('5P;&]A9',_($EF('EE<RP@<W1O<F4@=&AE"B`@("`@("`@("H@=F%L=64L
M(&EN(&)Y=&5S+"!O9B!T:&4@;6%X:6UU;2!F:6QE('-I>F4N("HO"B`@("`@
M("`@)%]315-324].6R=I;7`G75LG9FEL95]U<&QO860G72`]($)R;W=S97(Z
M.F%L;&]W1FEL955P;&]A9',H*3L*"B`@("`@("`@+RH@27,@=&AE("=M86EL
M+V-A;D%P<&QY1FEL=&5R<R<@05!)(&-A;&P@879A:6QA8FQE/R`J+PH@("`@
M("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G;6%I;"]C86Y!<'!L>49I
M;'1E<G,G*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=F:6QT
M97)A=F%I;"==(#T@)')E9VES=')Y+3YC86QL*"=M86EL+V-A;D%P<&QY1FEL
M=&5R<R<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1?4T534TE/
M3ELG:6UP)UU;)V9I;'1E<F%V86EL)UT@/2!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("\J($ES('1H92`G=&%S:W,O;&ES=%1A<VML:7-T<R<@8V%L;"!A
M=F%I;&%B;&4_("HO"B`@("`@("`@)%]315-324].6R=I;7`G75LG=&%S:VQI
M<W1A=F%I;"==(#T@*"1C;VYF6R=T87-K;&ES="==6R=U<V5?=&%S:VQI<W0G
M72`F)B`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G=&%S:W,O;&ES=%1A<VML:7-T
M<R<I*3L*"B`@("`@("`@+RH@27,@=&AE("=N;W1E<R]L:7-T3F]T97!A9',G
M(&-A;&P@879A:6QA8FQE/R`J+PH@("`@("`@("1?4T534TE/3ELG:6UP)UU;
M)VYO=&5P861A=F%I;"==(#T@*"1C;VYF6R=N;W1E<&%D)UU;)W5S95]N;W1E
M<&%D)UT@)B8@)')E9VES=')Y+3YH87--971H;V0H)VYO=&5S+VQI<W1.;W1E
M<&%D<R<I*3L*"B`@("`@("`@+RH@24U!4"!S<&5C:69I8R!V87)I86)L97,N
M("HO"B`@("`@("`@:68@*"1?4T534TE/3ELG:6UP)UU;)V)A<V5?<')O=&]C
M;VPG72`A/2`G<&]P,R<I('L*("`@("`@("`@("`@+RH@0VAE8VL@9F]R('1I
M;65O=71S+B`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1P=');)W1I;65O
M=70G72DI('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)VEM
M87!?<V5R=F5R)UU;)W1I;65O=70G72`]("1P=');)W1I;65O=70G73L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0VAE8VL@9F]R(&UA;G5A;"!C
M;VYF:6=U<F%T:6]N+B`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1P=');
M)VEM87!?8V]N9FEG)UTI*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;
M)VEM<"==6R=C:&EL9')E;B==(#T@)'!T<ELG:6UA<%]C;VYF:6<G75LG8VAI
M;&1R96XG73L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)VYA
M;65S<&%C92==(#T@)'!T<ELG:6UA<%]C;VYF:6<G75LG;F%M97-P86-E)UT[
M"B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=S96%R8VA?8VAA
M<G-E="==(#T@)'!T<ELG:6UA<%]C;VYF:6<G75LG<V5A<F-H7V-H87)S970G
M73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E<75I
M<F5?;VYC92!)35!?0D%312`N("<O;&EB+TE-05`O0VQI96YT+G!H<"<["B`@
M("`@("`@("`@("`@("`D:6UA<&-L:65N="`]("9N97<@24U07TE-05!#;&EE
M;G0H)%]315-324].6R=I;7`G75LG<V5R=F5R)UTL("1?4T534TE/3ELG:6UP
M)UU;)W!O<G0G72P@)%]315-324].6R=I;7`G75LG<')O=&]C;VPG72D["@H@
M("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG;F%M97-P86-E)UT@
M/2!A<G)A>2@I.PH*("`@("`@("`@("`@("`@("1U<V5?=&QS(#T@)&EM87!C
M;&EE;G0M/G5S951,4R@I.PH@("`@("`@("`@("`@("`@)'5S97)?;F%M97-P
M86-E(#T@*&ES<V5T*"1P=');)VYA;65S<&%C92==*2`F)B!I<U]A<G)A>2@D
M<'1R6R=N86UE<W!A8V4G72DI(#\@)'!T<ELG;F%M97-P86-E)UT@.B!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)'5S95]T;',L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1U
M<V5R7VYA;65S<&%C92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'!T<B!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O*B!4:&ES(&ES(&$@8V]R<F5C="!43%,@8V]N9FEG=7)A=&EO;B`M
M('=E(&]N;'D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`J(&YE960@
M=&\@9&5T97)M:6YE('1H92!D96QI;6ET97)S(&9O<B!E86-H"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*B!N86UE<W!A8V4N("!'970@=&AE(&1E
M9F%U;'0@9&5L:6UI=&5R('9A;'5E"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*B`H<&5R(%)&0R`S-3`Q(%LV+C,N.%TI+B`J+PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&)O>"`]($!I;6%P7V=E=&UA:6QB;WAE<R@D
M7U-%4U-)3TY;)VEM<"==6R=S=')E86TG72P@24U0.CIS97)V97)3=')I;F<H
M*2P@)'9A;"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1B;WA;,%TM/F1E;&EM:71E<BDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=N86UE<W!A8V4G75LD
M=F%L72`](&%R<F%Y*"=N86UE)R`]/B`D=F%L+"`G9&5L:6UI=&5R)R`]/B`D
M8F]X6S!=+3YD96QI;6ET97(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%U=&A?
M:6UP+3Y)35!S971!=71H17)R;W)-<V<H)'5S95]T;',M/F=E=$UE<W-A9V4H
M*2D["B`@("`@("`@("`@("`@("`@("`@("`@("1A=71H7VEM<"T^8VQE87)!
M=71H*"D["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("\J($%U=&\M9&5T96-T(&YA;65S<&%C
M92!P87)A;65T97)S(&9R;VT@24U!4"!S97)V97(N("HO"B`@("`@("`@("`@
M("`@("`@("`@)')E<R`]("1I;6%P8VQI96YT+3YL;V=I;B@D7U-%4U-)3TY;
M)VEM<"==6R=U<V5R)UTL("1P87-S=V]R9"D["B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D875T:%]I;7`M/DE-4'-E=$%U=&A%<G)O<DUS9R@D
M<F5S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)VYA;65S<&%C92==(#T@)&EM
M87!C;&EE;G0M/FYA;65S<&%C92@D=7-E<E]N86UE<W!A8V4I.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)%]315-324].6R=I;7`G75LG
M;F%M97-P86-E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A=71H
M7VEM<"T^24U0<V5T075T:$5R<F]R37-G*%\H(D-O=6QD(&YO="!R971R:65V
M92!N86UE<W!A8V4@:6YF;W)M871I;VX@9G)O;2!)34%0('-E<G9E<BXB*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)%]315-324].
M6R=I;7`G75LG:6UA<%]S97)V97(G75LG8VAI;&1R96XG72`]("1I;6%P8VQI
M96YT+3YQ=65R>4-A<&%B:6QI='DH)T-(24Q$4D5.)RD["@H@("`@("`@("`@
M("`@("`@("`@("\J($1E=&5R;6EN92!I9B!T:&4@<V5A<F-H(&-O;6UA;F0@
M<W5P<&]R=',@=&AE(&-U<G)E;G0*("`@("`@("`@("`@("`@("`@("`@*B!B
M<F]W<V5R)W,@8VAA<G-E="X@*B\*("`@("`@("`@("`@("`@("`@("`D8VAA
M<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP)UU;)VEM87!?<V5R=F5R)UU;)W-E87)C:%]C:&%R
M<V5T)UT@/2!A<G)A>2@D8VAA<G-E="`]/B`D:6UA<&-L:65N="T^<V5A<F-H
M0VAA<G-E="@D8VAA<G-E="DI.PH@("`@("`@("`@("`@("`@("`@("1I;6%P
M8VQI96YT+3YL;V=O=70H*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`O*B!);FET:6%L:7IE('1H92`G<VAO=W5N<W5B)R!V86QU92X@
M*B\*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W-H;W=U;G-U
M8B==(#T@9F%L<V4["@H@("`@("`@("`@("`@("`@+RH@26YI=&EA;&EZ92!T
M:&4@24U07U1R964@;V)J96-T+B`@5&AI<R!N965D<R!T;R!B92!D;VYE"B`@
M("`@("`@("`@("`@("`@*B!B969O<F4@:6YI=&EA;&EZ:6YG($E-4%]396%R
M8V@Z.BX@*B\*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%3
M12`N("<O;&EB+TE-05`O5')E92YP:'`G.PH@("`@("`@("`@("`@("`@24U0
M7TE-05`Z.G-I;F=L971O;B@I.PH*("`@("`@("`@("`@("`@("\J(%-E="!U
M<"!S96%R8V@@:6YF;W)M871I;VX@9F]R('1H92!S97-S:6]N+B`J+PH@("`@
M("`@("`@("`@("`@)$=,3T)!3%-;)VEM<%]S96%R8V@G72T^<V5S<VEO;E-E
M='5P*"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D7U-%4U-)3TY;)VEM<"==6R=N86UE<W!A8V4G72`](&YU;&P["B`@
M("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T:&4@)&EM<"!V87)I86)L92!G
M;&]B86QL>2X@*B\*("`@("`@("`D1TQ/0D%,4ULG:6UP)UT@/2`F)%]315-3
M24].6R=I;7`G73L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!097)F;W)M($E-4"!L;V=I;B!T87-K<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&]G:6Y487-K<R@I"B`@("!["B`@("`@("`@:68@*"%)
M35`Z.FQO9VEN5&%S:W-&;&%G*"DI('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@24U0.CIL;V=I;E1A<VMS1FQA9R@R*3L*"B`@
M("`@("`@:68@*&5M<'1Y*"1?4T534TE/3ELG:6UP)UU;)W-T<F5A;2==*2D@
M>PH@("`@("`@("`@("!)35`Z.F-H96-K075T:&5N=&EC871I;VXH3U!?2$%,
M1D]014XL('1R=64I.PH@("`@("`@('T*"B`@("`@("`@+RH@1&\@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<RX@*B\*("`@("`@("!I9B`H)$=,3T)!3%-;)W!R
M969S)UTM/F=E=%9A;'5E*"=D;U]M86EN=&5N86YC92<I*2!["B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O36%I;G1E;F%N8V4N<&AP)SL*("`@
M("`@("`@("`@)&UA:6YT(#T@)DUA:6YT96YA;F-E.CIF86-T;W)Y*"=I;7`G
M+"!A<G)A>2@G;&%S=%]M86EN=&5N86YC92<@/3X@)$=,3T)!3%-;)W!R969S
M)UTM/F=E=%9A;'5E*"=L87-T7VUA:6YT96YA;F-E)RDI*3L*("`@("`@("`@
M("`@:68@*"$D;6%I;G0I('L*("`@("`@("`@("`@("`@("1'3$]"04Q36R=N
M;W1I9FEC871I;VXG72T^<'5S:"A?*")#;W5L9"!N;W0@97AE8W5T92!M86EN
M=&5N86YC92!O<&5R871I;VYS+B(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UA:6YT+3YR=6Y-
M86EN=&5N86YC92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!T:&4@=7-E<B!W86YT<R!T;R!R=6X@9FEL=&5R<R!O;B!L;V=I
M;BP@;6%K92!S=7)E('1H97D@9V5T"B`@("`@("`@("`@<G5N+B`J+PH@("`@
M("`@(&EF("@D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)V9I;'1E<E]O
M;E]L;V=I;B<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%3
M12`N("<O;&EB+TE-05`N<&AP)SL*("`@("`@("`@("`@)&EM<%]I;6%P(#T@
M)DE-4%])34%0.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@("`@("\J($]P96X@
M=&AE($E.0D]8(')E860M=W)I=&4N("HO"B`@("`@("`@("`@("1I;7!?:6UA
M<"T^8VAA;F=E36)O>"@G24Y"3U@G*3L*"B`@("`@("`@("`@("\J(%)U;B!F
M:6QT97)S+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@
M+B`G+VQI8B]&:6QT97(N<&AP)SL*("`@("`@("`@("`@)&EM<%]F:6QT97(@
M/2`F24U07T9I;'1E<CHZ<VEN9VQE=&]N*"D["B`@("`@("`@("`@("1I;7!?
M9FEL=&5R+3YF:6QT97(H)TE.0D]8)RD["B`@("`@("`@?0H*("`@("`@("!)
M35`Z.FQO9VEN5&%S:W-&;&%G*#`I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@:6YI=&EA;"!54DPN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D86-T:6]N240@(%1H92!A8W1I;VX@240@=&\@<&5R9F]R;2!O
M;B!T:&4@:6YI=&EA;"!P86=E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&5N
M8V]D92`@($EF('1R=64@=&AE(&%R9W5M96YT('-E<&%R871O<B!G971S(&5N
M8V]D960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!I;FET
M:6%L(%523"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YI=&EA;%5R;"@D
M86-T:6]N240@/2!N=6QL+"`D96YC;V1E(#T@=')U92D*("`@('L*("`@("`@
M("`D:6YI=%]U<FP@/2`H)%]315-324].6R=I;7`G75LG8F%S95]P<F]T;V-O
M;"==(#T]("=P;W`S)RD@/R`G24Y"3U@G(#H@)$=,3T)!3%-;)W!R969S)UTM
M/F=E=%9A;'5E*"=I;FET:6%L7W!A9V4G*3L*"B`@("`@("`@:68@*"1I;FET
M7W5R;"`]/2`G9F]L9&5R<RYP:'`G*2!["B`@("`@("`@("`@("1U<FP@/2!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)&EN:71?=7)L+"`A)&5N8V]D92D["B`@
M("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@24U0
M.CIG971#;VUP;W-E07)G<R@I+"!N=6QL+"`D96YC;V1E*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=M86EL8F]X+G!H<"<L("$D96YC;V1E*3L*("`@("`@("`@("`@)'5R
M;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;6%I;&)O>"<L("1I;FET
M7W5R;"P@)&5N8V]D92D["B`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H)'5R;"P@24U0.CIG971#;VUP;W-E07)G<R@I+"!N=6QL+"`D
M96YC;V1E*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&%C=&EO
M;DE$*2D@>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL("=A8W1I;VY)1"<L("1A8W1I;VY)1"P@)&5N8V]D92D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'5R;#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+T9I;'1E
M<BYP:'``````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$P-S,R`#$P-#$W,S8R-S8V`#`Q-S<R,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($E-4%]&
M:6QT97(Z.B!C;&%S<R!C;VYT86EN<R!A;&P@9G5N8W1I;VYS(')E;&%T960@
M=&\@:&%N9&QI;F<*("H@9FEL=&5R:6YG(&UE<W-A9V5S(&EN($E-4"X*("H*
M("H@1F]R(&9U;&P@=7-E+"!T:&4@9F]L;&]W:6YG($AO<F1E($%022!C86QL
M<R!S:&]U;&0@8F4@9&5F:6YE9`H@*B`H5&AE<V4@05!)(&UE=&AO9',@87)E
M(&YO="!D969I;F5D(&EN($E-4"DZ"B`J("`@;6%I;"]A<'!L>49I;'1E<G,*
M("H@("!M86EL+V-A;D%P<&QY1FEL=&5R<PH@*B`@(&UA:6PO<VAO=T9I;'1E
M<G,*("H@("!M86EL+V)L86-K;&ES=$9R;VT*("H@("!M86EL+W-H;W=";&%C
M:VQI<W0*("H@("!M86EL+W=H:71E;&ES=$9R;VT*("H@("!M86EL+W-H;W=7
M:&ET96QI<W0*("H*("H@)$AO<F1E.B!I;7`O;&EB+T9I;'1E<BYP:'`L=B`Q
M+C4V+C$P+CD@,C`P-B\P,B\P-"`Q.3HP.3HU,2!S;'5S87)Z($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H@0'-I;F-E("`@24U0(#0N,`H@*B!`<&%C:V%G92!)35`*
M("HO"F-L87-S($E-4%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A(')E9F5R96YC92!T;R!T:&4@9VQO8F%L($E-4%]&:6QT97(@;V)J96-T
M+"!O;FQY(&-R96%T:6YG(&ET"B`@("`@*B!I9B!I="!D;V5S;B=T(&%L<F5A
M9'D@97AI<W0N(%1H:7,@96YS=7)E<R!T:&%T(&]N;'D@;VYE($E-4%]&:6QT
M97(*("`@("`J(&EN<W1A;F-E(&ES(&EN<W1A;G1I871E9"!F;W(@86YY(&=I
M=F5N('-E<W-I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B
M92!I;G9O:V5D(&%S.CQC;V1E/@H@("`@("H@("`D:6UP7V9I;'1E<B`]("9)
M35!?1FEL=&5R.CIS:6YG;&5T;VXH*3L*("`@("`J(#PO8V]D93X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($E-4%]&:6QT97(@(%1H92!)35!?1FEL=&5R(&EN
M<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"D*("`@
M('L*("`@("`@("!S=&%T:6,@)&9I;'1E<CL*"B`@("`@("`@:68@*"%I<W-E
M="@D9FEL=&5R*2D@>PH@("`@("`@("`@("`D9FEL=&5R(#T@;F5W($E-4%]&
M:6QT97(H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9FEL=&5R.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4G5N<R!T:&4@9FEL=&5R<R!I9B!T:&5Y
M(&%R92!A8FQE('1O(&)E(&%P<&QI960@;6%N=6%L;'DN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6)O>"`@5&AE(&UA:6QB;W@@=&\@87!P;'D@
M=&AE(&9I;'1E<G,@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I;'1E<B@D
M;6)O>"D*("`@('L*("`@("`@("!I9B`H)%]315-324].6R=I;7`G75LG9FEL
M=&5R879A:6PG72D@>PH@("`@("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;
M)VEM<%]S96%R8V@G72D@)B8*("`@("`@("`@("`@("`@("1'3$]"04Q36R=I
M;7!?<V5A<F-H)UTM/FES4V5A<F-H36)O>"@D;6)O>"DI('L*("`@("`@("`@
M("`@("`@("1M8F]X7VQI<W0@/2`D1TQ/0D%,4ULG:6UP7W-E87)C:"==+3YG
M971396%R8VA&;VQD97)S*"1M8F]X*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1M8F]X7VQI<W0@/2!A<G)A>2@D;6)O>"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&UB;WA?;&ES="!A
M<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH)VEM
M87`G(#T^("1'3$]"04Q36R=I;7`G75LG<W1R96%M)UTL("=M86EL8F]X)R`]
M/B!)35`Z.G-E<G9E<E-T<FEN9R@D=F%L*2D["B`@("`@("`@("`@("`@("`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G;6%I;"]A<'!L>49I;'1E<G,G
M+"!A<G)A>2@D<&%R86US*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S('1H92!&<F]M(&%D9')E<W,@9G)O
M;2!T:&4@;65S<V%G92AS*2!T;R!T:&4@8FQA8VML:7-T+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D:6YD:6-E<R`@4V5E($E-4#HZ<&%R<V5);F1I
M8V5S3&ES="@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!B;&%C:VQI<W1-97-S
M86=E*"1I;F1I8V5S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<')O8V5S<T)7
M;&ES="@D:6YD:6-E<RP@7R@B>6]U<B!B;&%C:VQI<W0B*2P@)V)L86-K;&ES
M=$9R;VTG+"`G<VAO=T)L86-K;&ES="<I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@061D<R!T:&4@1G)O;2!A9&1R97-S(&9R;VT@=&AE(&UE<W-A9V4H<RD@
M=&\@=&AE('=H:71E;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&EN9&EC97,@(%-E92!)35`Z.G!A<G-E26YD:6-E<TQI<W0H*2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=VAI=&5L:7-T365S<V%G92@D:6YD:6-E<RD*("`@
M('L*("`@("`@("`D=&AI<RT^7W!R;V-E<W-"5VQI<W0H)&EN9&EC97,L(%\H
M(GEO=7(@=VAI=&5L:7-T(BDL("=W:&ET96QI<W1&<F]M)RP@)W-H;W=7:&ET
M96QI<W0G*3L*("`@('T*"B`@("`O*BH*("`@("`J($EN=&5R;F%L(&9U;F-T
M:6]N('1O(&AA;F1L92!A9&1I;F<@861D<F5S<V5S('1O(%MB;&%C:WQW:&ET
M95UL:7-T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`@)&EN9&EC97,@(%-E92!)35`Z.G!A<G-E
M26YD:6-E<TQI<W0H*2X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<V-R:7`@
M(%1H92!T97AT=6%L(&1E<V-R:7!T:6]N('1O('5S92X*("`@("`J($!P87)A
M;2!S=')I;F<@)')E9S$@("`@(%1H92!N86UE(&]F('1H92!M86EL+R!R96=I
M<W1R>2!C86QL('1O('5S92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&%D9&EN9R!T:&4@861D<F5S<V5S+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F5G,B`@("`@5&AE(&YA;64@;V8@=&AE(&UA:6PO(')E9VES=')Y
M(&-A;&P@=&\@=7-E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@;&EN:VEN9R!T;R!T:&4@9FEL=&5R(&UA;F%G96UE;G0@<&%G92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W!R;V-E<W-"5VQI<W0H)&EN9&EC97,L("1D
M97-C<FEP+"`D<F5G,2P@)')E9S(I"B`@("!["B`@("`@("`@:68@*"$H)&US
M9TQI<W0@/2!)35`Z.G!A<G-E26YD:6-E<TQI<W0H)&EN9&EC97,I*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R
M97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B])34%0+G!H<"<["B`@("`@
M("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O34E-12](96%D97)S
M+G!H<"<["B`@("`@("`@)&EM<%]I;6%P(#T@)DE-4%])34%0.CIS:6YG;&5T
M;VXH*3L*"B`@("`@("`@+RH@1V5T('1H92!L:7-T(&]F(&9R;VT@861D<F5S
M<V5S+B`J+PH@("`@("`@("1A9&1R(#T@87)R87DH*3L*("`@("`@("!F;W)E
M86-H("@D;7-G3&ES="!A<R`D9F]L9&5R(#T^("1M<V=);F1I8V5S*2!["B`@
M("`@("`@("`@("\J(%-W:71C:"!F;VQD97)S+"!I9B!N96-E<W-A<GD@*&]N
M;'D@=F%L:60@9F]R($E-05`I+B`J+PH@("`@("`@("`@("`D:6UP7VEM87`M
M/F-H86YG94UB;W@H)&9O;&1E<BD["@H@("`@("`@("`@("!F;W)E86-H("@D
M;7-G26YD:6-E<R!A<R`D;7-G*2!["B`@("`@("`@("`@("`@("`D:6UP7VAE
M861E<G,@/2`F;F5W($E-4%](96%D97)S*"1M<V<I.PH@("`@("`@("`@("`@
M("`@)&9R;VT@/2`D:6UP7VAE861E<G,M/F=E=$9R;VU!9&1R97-S*"D["B`@
M("`@("`@("`@("`@("`D861D<EM=(#T@)&9R;VT["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL
M*"=M86EL+R<@+B`D<F5G,2P@87)R87DH)&%D9'(I*3L*"B`@("`@("`@+RH@
M061D(&QI;FL@=&\@9FEL=&5R(&UA;F%G96UE;G0@<&%G92X@*B\*("`@("`@
M("!I9B`H)$=,3T)!3%-;)W)E9VES=')Y)UTM/FAA<TUE=&AO9"@G;6%I;"\G
M("X@)')E9S(I*2!["B`@("`@("`@("`@("1M86YA9V5?;&EN:R`]($AO<F1E
M.CIL:6YK*$AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI;FLH
M)VUA:6PO)R`N("1R96<R*2DL('-P<FEN=&8H7R@B1FEL=&5R<SH@)7,@;6%N
M86=E;65N="!P86=E(BDL("1D97-C<FEP*2D@+B!?*")(15)%(BD@+B`G/"]A
M/B<["B`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S
M:"AS<')I;G1F*%\H(D-L:6-K("5S('1O(&=O('1O("5S(&UA;F%G96UE;G0@
M<&%G92XB*2P@)&UA;F%G95]L:6YK+"`D9&5S8W)I<"DL("=H;W)D92YM97-S
M86=E)RP@87)R87DH)V-O;G1E;G0N<F%W)RDI.PH@("`@("`@('T*("`@('T*
M"GT*```````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]L:6(O36%I;&QO9RYP:'``````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30U-S0`,3`T
M,3<S-C(W-C8`,#(P,#<P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TAI<W1O
M<GDN<&AP)SL*"B\J*@H@*B!4:&4@24U07TUA:6QL;V<Z.B!C;&%S<R!C;VYT
M86EN<R!A;&P@9G5N8W1I;VYS(')E;&%T960@=&\@:&%N9&QI;F<*("H@;&]G
M9VEN9R!O9B!R97-P;VYS97,@=&\@:6YD:79I9'5A;"!E+6UA:6P@;65S<V%G
M97,N"B`J"B`J("1(;W)D93H@:6UP+VQI8B]-86EL;&]G+G!H<"QV(#$N,34N
M,3`N,3(@,C`P-B\P,R\P,R`R,SHP,#HR."!C:'5C:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@24U0"B`J+PIC
M;&%S<R!)35!?36%I;&QO9R!["@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!L
M;V<@96YT<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M("!%:71H97(@)V9O<G=A<F0G+"`G<F5D:7)E8W0G+"`G<F5P;'DG+"!O<B`G
M;61N)RX*("`@("`J($!P87)A;2!M:7AE9"`D;7-G7VED<R`@16ET:&5R(&$@
M<VEN9VQE($UE<W-A9V4M240@;W(@86X@87)R87D@;V8*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@365S<V%G92U)1',@=&\@;&]G+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&%T82`@("!!;GD@861D:71I;VYA;"!D871A('1O
M('-T;W)E+B!&;W(@)V9O<G=A<F0G(&%N9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5D:7)E8W0G('1H:7,@:7,@=&AE(&QI<W0@;V8@<F5C
M:7!I96YT<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@;65S
M<V%G92!W87,@<V5N="!T;RX@1F]R("=M9&XG('1H:7,@:7,@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@($U$3BUT>7!E(&]F('1H92!M97-S
M86=E('1H870@=V%S('-E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D
M='EP92P@)&US9U]I9',L("1D871A(#T@;G5L;"D*("`@('L*("`@("`@("`D
M:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D;7-G7VED<RDI('L*("`@("`@("`@("`@)&US
M9U]I9',@/2!A<G)A>2@D;7-G7VED<RD["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D;7-G7VED<R!A<R`D=F%L*2!["B`@("`@("`@("`@("1I9"`]
M($E-4%]-86EL;&]G.CI?9V5T56YI<75E2&ES=&]R>4ED*"1V86PI.PH@("`@
M("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)V9O
M<G=A<F0G.@H@("`@("`@("`@("`@("`@)'(@/2`D:&ES=&]R>2T^;&]G*"1I
M9"P@87)R87DH)W)E8VEP:65N=',G(#T^("1D871A+"`G86-T:6]N)R`]/B`G
M9F]R=V%R9"<I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G;61N)SH*("`@("`@("`@("`@("`@("1R(#T@)&AI<W1O<GDM
M/FQO9R@D:60L(&%R<F%Y*"=T>7!E)R`]/B`D9&%T82P@)V%C=&EO;B<@/3X@
M)VUD;B<I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`G<F5D:7)E8W0G.@H@("`@("`@("`@("`@("`@)'(@/2`D:&ES=&]R
M>2T^;&]G*"1I9"P@87)R87DH)W)E8VEP:65N=',G(#T^("1D871A+"`G86-T
M:6]N)R`]/B`G<F5D:7)E8W0G*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)W)E<&QY)SH*("`@("`@("`@("`@("`@("1R
M(#T@)&AI<W1O<GDM/FQO9R@D:60L(&%R<F%Y*"=A8W1I;VXG(#T^("=R97!L
M>2<I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!/;B!E<G)O<BP@;&]G('1H92!E<G)O<B!M97-S86=E
M(&]N;'D@<VEN8V4@:6YF;W)M:6YG('1H92!U<V5R"B`@("`@("`@("`@("`J
M(&ES(&IU<W0@82!W87-T92!O9B!T:6UE(&%N9"!A('!O=&5N=&EA;"!P;VEN
M="!O9B!C;VYF=7-I;VXL"B`@("`@("`@("`@("`J(&5S<&5C:6%L;'D@<VEN
M8V4@=&AE>2!M;W-T(&QI:V5L>2!D;VXG="!E=F5N(&MN;W<@=&AE(&UE<W-A
M9V4*("`@("`@("`@("`@("H@:7,@8F5I;F<@;&]G9V5D+B`J+PH@("`@("`@
M("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@)&5N=')Y(#T@<W!R:6YT9B@G0V]U;&0@;F]T(&QO9R!M97-S86=E
M(&1E=&%I;',@=&\@2&]R9&5?2&ES=&]R>2X@17)R;W(@<F5T=7)N960Z("`E
M<R<L("1R+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)&5N=')Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971R:65V92!A;GD@:&ES=&]R>2!F;W(@=&AE(&=I=F5N
M($UE<W-A9V4M240N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;7-G
M7VED("!4:&4@365S<V%G92U)1"!O9B!T:&4@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T("!4:&4@1&%T851R965/8FIE
M8W0@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&QO9PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@:6YF;W)M871I;VXL(&]R(%!%05)?17)R;W(@;VX@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971,;V<H)&US9U]I9"D*
M("`@('L*("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG
M;&5T;VXH*3L*("`@("`@("`D;&]G(#T@)B1H:7-T;W)Y+3YG971(:7-T;W)Y
M*$E-4%]-86EL;&]G.CI?9V5T56YI<75E2&ES=&]R>4ED*"1M<V=?:60I*3L*
M("`@("`@("!R971U<FX@)&QO9SL*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN97,@:68@86X@341.(&YO=&EF:6-A=&EO;B!O9B!A(&-E<G1A:6X@
M='EP92!H87,@8F5E;B!S96YT"B`@("`@*B!P<F5V:6]U<VQY(&9O<B!T:&ES
M(&UE<W-A9V4M240N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;7-G
M7VED("!4:&4@365S<V%G92U)1"!O9B!T:&4@;65S<V%G92X*("`@("`J($!P
M87)A;2!S=')I;F<@)'1Y<&4@("`@5&AE('1Y<&4@;V8@341.+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!A($U$3B!H87,@8F5E
M;B!S96YT(&9O<B!T:&ES(&UE<W-A9V4@=VET:`H@("`@("H@("`@("`@("`@
M("`@("`@("!T:&4@9VEV96X@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5N=$U$3B@D;7-G7VED+"`D='EP92D*("`@('L*("`@("`@("`D;7-G7VAI
M<W1O<GD@/2!)35!?36%I;&QO9SHZ9V5T3&]G*"1M<V=?:60I.PH@("`@("`@
M(&EF("@D;7-G7VAI<W1O<GD@)B8@(6ES7V$H)&US9U]H:7-T;W)Y+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M<V=?:&ES=&]R
M>2T^9V5T1&%T82@I(&%S("1E;G1R>2D@>PH@("`@("`@("`@("`@("`@:68@
M*"@D96YT<GE;)V%C=&EO;B==(#T]("=M9&XG*2`F)B`H)&5N=')Y6R=T>7!E
M)UT@/3T@)'1Y<&4I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E=')I979E(&%N>2!H:7-T;W)Y(&9O<B!T:&4@9VEV96X@365S<V%G92U)
M1"!A;F0@9&ES<&QA>2!V:6$@=&AE"B`@("`@*B!(;W)D92!N;W1I9FEC871I
M;VX@<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&US9U]I
M9"`@5&AE($UE<W-A9V4M240@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1I<W!L87E,;V<H)&US9U]I9"D*("`@('L*("`@("`@("!G
M;&]B86P@)&YO=&EF:6-A=&EO;BP@)'!R969S.PH*("`@("`@("`D;7-G7VAI
M<W1O<GD@/2!)35!?36%I;&QO9SHZ9V5T3&]G*"1M<V=?:60I.PH@("`@("`@
M(&EF("@D;7-G7VAI<W1O<GD@)B8@(6ES7V$H)&US9U]H:7-T;W)Y+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M<V=?:&ES=&]R
M>2T^9V5T1&%T82@I(&%S("1E;G1R>2D@>PH@("`@("`@("`@("`@("`@)&US
M9R`](&YU;&P["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y6R=D
M97-C)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&US9R`]("1E;G1R>5LG
M9&5S8R==.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!S=VET8V@@*"1E;G1R>5LG86-T:6]N)UTI('L*("`@("`@("`@
M("`@("`@("`@("!C87-E("=F;W)W87)D)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@)&US9R`]('-P<FEN=&8H7R@B66]U(&9O<G=A<F1E9"!T:&ES(&UE
M<W-A9V4@;VX@)25S('1O('1H92!F;VQL;W=I;F<@<F5C:7!I96YT<SH@)7,N
M(BDL("1E;G1R>5LG<F5C:7!I96YT<R==*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VUD;B<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("\J(%=E(&1O;B=T(&1I<W!L87D@
M)VUD;B<@;&]G(&5N=')I97,N("HO"B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=R961I<F5C="<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("1M<V<@/2!S<')I;G1F*%\H(EEO
M=2!R961I<F5C=&5D('1H:7,@;65S<V%G92!T;R`E<R!O;B`E)7,N(BDL("1E
M;G1R>5LG<F5C:7!I96YT<R==*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W)E<&QY)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&US9R`](%\H(EEO=2!R97!L:65D('1O
M('1H:7,@;65S<V%G92!O;B`E<RXB*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1M<V<I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AH=&UL<W!E
M8VEA;&-H87)S*$!S<')I;G1F*"1M<V<L('-T<F9T:6UE*"1P<F5F<RT^9V5T
M5F%L=64H)V1A=&5?9F]R;6%T)RD@+B`G("<@+B`D<')E9G,M/F=E=%9A;'5E
M*"=T:6UE7V9O<FUA="<I+"`D96YT<GE;)W1S)UTI*2DL("=I;7`N)R`N("1E
M;G1R>5LG86-T:6]N)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E('1H
M92!L;V<@96YT<FEE<R!F;W(@82!G:79E;B!L:7-T(&]F($UE<W-A9V4M241S
M+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;7-G7VED<R`@16ET:&5R
M(&$@<VEN9VQE($UE<W-A9V4M240@;W(@86X@87)R87D*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@;V8@365S<V%G92U)1',@=&\@9&5L971E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5,;V<H)&US9U]I9',I"B`@("![
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;7-G7VED<RDI('L*("`@("`@("`@
M("`@)&US9U]I9',@/2!A<G)A>2A)35!?36%I;&QO9SHZ7V=E=%5N:7%U94AI
M<W1O<GE)9"@D;7-G7VED<RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1M<V=?:61S(&%S("1K97D@/3X@)&US9U]I9"D@>PH@
M("`@("`@("`@("`@("`@)&US9U]I9'-;)&ME>5T@/2!)35!?36%I;&QO9SHZ
M7V=E=%5N:7%U94AI<W1O<GE)9"@D;7-G7VED*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&AI<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ
M<VEN9VQE=&]N*"D["B`@("`@("`@<F5T=7)N("1H:7-T;W)Y+3YR96UO=F5"
M>4YA;65S*"1M<V=?:61S*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R
M871E('1H92!U;FEQ=64@;&]G($E$(&9O<B!A(&9O<G=A<F0O<F5P;'DO<F5D
M:7)E8W0@979E;G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;7-G:60@(%1H92!-97-S86=E
M+4E$(&]F('1H92!O<FEG:6YA;"!M97-S86=E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@=6YI<75E(&QO9R!)1"!T;R!U<V4@=VET:"!(
M;W)D95](:7-T;W)Y.CHN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9715;FEQ
M=65(:7-T;W)Y260H)&US9VED*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D;7-G:60I*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!I;7!L;V1E*"<N)RP@87)R87DH)VEM<"<L('-T
M<E]R97!L86-E*"<N)RP@)RHG+"!!=71H.CIG971!=71H*"DI+"`D;7-G:60I
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&EB+T9O
M;&1E<BYP:'``````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#8S,3<W`#$P-#$W,S8R-S8V`#`Q-S<R,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($E-
M4%]&;VQD97(Z.B!C;&%S<R!P<F]V:61E<R!A('-E="!O9B!M971H;V1S(&9O
M<B!D96%L:6YG('=I=&@@9F]L9&5R<RP*("H@86-C;W5N=&EN9R!F;W(@<W5B
M<V-R:7!T:6]N+"!E<G)O<G,L(&5T8RX*("H*("H@)$AO<F1E.B!I;7`O;&EB
M+T9O;&1E<BYP:'`L=B`Q+C$S,"XQ,"XS-2`R,#`V+S`S+S`Q(#$V.C,T.C(T
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,"TR
M,#`V($IO;B!087)I<V4@/&IO;D!C<V@N<FET+F5D=3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&-S:"YR:70N961U/@H@
M*B!`<VEN8V4@("!)35`@,BXS"B`J($!P86-K86=E($E-4`H@*B\*8VQA<W,@
M24U07T9O;&1E<B!["@H@("`@+RHJ"B`@("`@*B!+965P(&%R;W5N9"!I9&5N
M=&EC86P@;&ES=',@<V\@=&AA="!W92!D;VXG="!H:70@=&AE('-E<G9E<B!M
M;W)E('1H870*("`@("`J(&]N8V4@:6X@=&AE('-A;64@<&%G92!F;W(@=&AE
M('-A;64@=&AI;F<N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]L:7-T0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@2V5E<"!T<F%C:R!O9B!M86EL8F]X(&YA;65S('1H870@=V4@:&%V92!C
M;VUP;&%I;F5D(&%B;W5T('1O('!R979E;G0*("`@("`J(&=I=FEN9R!T:&4@
M=7-E<B!I9&5N=&EC86P@97)R;W(@;65S<V%G97,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]E<G)O<D-A8VAE(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-A8VAE9"!R97-U;'1S(&9R;VT@=&AE
M(&5X:7-T<R@I(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?97AI<W1S4F5S=6QT<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O('1H92!G;&]B
M86P@24U07T9O;&1E<B!O8FIE8W0L(&]N;'D@8W)E871I;F<@:70*("`@("`J
M(&EF(&ET(&1O97-N)W0@86QR96%D>2!E>&ES="X@5&AI<R!E;G-U<F5S('1H
M870@;VYL>2!O;F4@24U07T9O;&1E<@H@("`@("H@:6YS=&%N8V4@:7,@:6YS
M=&%N=&EA=&5D(&9O<B!A;GD@9VEV96X@<V5S<VEO;BX*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z/&-O9&4^"B`@("`@
M*B`@("1I;7!?9F]L9&5R(#T@)DE-4%]&;VQD97(Z.G-I;F=L971O;B@I.PH@
M("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!R971U<FX@24U07T9O;&1E
M<B`@5&AE($E-4%]&;VQD97(@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D9F]L9&5R
M.PH*("`@("`@("!I9B`H(6ES<V5T*"1F;VQD97(I*2!["B`@("`@("`@("`@
M("1F;VQD97(@/2!N97<@24U07T9O;&1E<B@I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1F;VQD97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T
M<R!F;VQD97)S+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=6(@
M("!3:&]U;&0@=V4@;&ES="!O;FQY('-U8G-C<FEB960@9F]L9&5R<S\*("`@
M("`J($!P87)A;2!A<G)A>2`D9FEL=&5R("!!;B!L:7-T(&]F(&UA:6QB;WAE
M<R!T:&%T('-H;W5L9"!B92!L969T(&]U="!O9@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('1H92!L:7-T+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(&%R<F%Y(&]F(&9O;&1E<G,L('=H97)E(&5A8V@@87)R87D@
M86QE;65N="!I<R!A;@H@("`@("H@("`@("`@("`@("`@("`@87-S;V-I871I
M=F4@87)R87D@8V]N=&%I;FEN9R!T:')E92!V86QU97,Z("=V86PG+"!W:71H
M"B`@("`@*B`@("`@("`@("`@("`@("!E;G1I<F4@9F]L9&5R(&YA;64@869T
M97(@=&AE('-E<G9E<B!S<&5C:69I8V%T:6]N.PH@("`@("H@("`@("`@("`@
M("`@("`@)VQA8F5L)RP@=VET:"!T:&4@9G5L;"UL96YG=&@@9F]L9&5R(&YA
M;64@;65A;G0@9F]R"B`@("`@*B`@("`@("`@("`@("`@("!D:7-P;&%Y(&%N
M9"`G86)B<F5V)RP@8V]N=&%I;FEN9R!A('-H;W)T96YE9"`H,C8*("`@("`J
M("`@("`@("`@("`@("`@(&-H87)A8W1E<G,@;6%X*2!L86)E;"!F;W(@9&ES
M<&QA>2!I;B!S:71U871I;VYS('=H97)E"B`@("`@*B`@("`@("`@("`@("`@
M("!S<&%C92!I<R!S:&]R="X*("`@("`J+PH@("`@9G5N8W1I;VX@9FQI<W0H
M)'-U8B`](&9A;'-E+"`D9FEL=&5R(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!G;&]B86P@)&-O;F8L("1N;W1I9FEC871I;VX["@H@("`@("`@("1I;F)O
M>%]E;G1R>2`](&%R<F%Y*"=)3D)/6"<@/3X@87)R87DH)W9A;"<@/3X@)TE.
M0D]8)RP@)VQA8F5L)R`]/B!?*"));F)O>"(I+"`G86)B<F5V)R`]/B!?*"))
M;F)O>"(I*2D["@H@("`@("`@(&EF("@D7U-%4U-)3TY;)VEM<"==6R=B87-E
M7W!R;W1O8V]L)UT@/3T@)W!O<#,G*2!["B`@("`@("`@("`@(')E='5R;B`D
M:6YB;WA?96YT<GD["B`@("`@("`@?0H*("`@("`@("`D;&ES="`](&%R<F%Y
M*"D["B`@("`@("`@)'-U8FED>"`](&EN='9A;"@D<W5B*3L*"B`@("`@("`@
M+RH@0V]M<'5T92!V86QU97,@=&AA="!W:6QL('5N:7%U96QY(&ED96YT:69Y
M('1H:7,@;&ES="X@*B\*("`@("`@("`D9G5L;%]S:6=N871U<F4@/2!M9#4H
M<V5R:6%L:7IE*&%R<F%Y*"1S=6)I9'@L("1F:6QT97(I*2D["@H@("`@("`@
M("\J($5I=&AE<B!G970@=&AE(&QI<W0@9G)O;2!T:&4@8V%C:&4L(&]R(&=O
M('1O('1H92!)34%0('-E<G9E<B!T;PH@("`@("`@("`@(&]B=&%I;B!I="X@
M*B\*("`@("`@("!I9B`H)&-O;F9;)W-E<G9E<B==6R=C86-H95]F;VQD97)S
M)UTI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397-S:6]N
M3V)J96-T<RYP:'`G.PH@("`@("`@("`@("`D<V5S<VEO;D]B(#T@)DAO<F1E
M7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@:68@
M*"%I<W-E="@D7U-%4U-)3TY;)VEM<"==6R=C86-H92==6R=F;VQD97)?8V%C
M:&4G72DI('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)V-A
M8VAE)UU;)V9O;&1E<E]C86-H92==(#T@87)R87DH*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9F]L9&5R7V-A8VAE(#T@)B1?4T534TE/3ELG:6UP
M)UU;)V-A8VAE)UU;)V9O;&1E<E]C86-H92==.PH@("`@("`@("`@("!I9B`H
M:7-S970H)&9O;&1E<E]C86-H95LD9G5L;%]S:6=N871U<F5=*2D@>PH@("`@
M("`@("`@("`@("`@)&1A=&$@/2`D<V5S<VEO;D]B+3YQ=65R>2@D9F]L9&5R
M7V-A8VAE6R1F=6QL7W-I9VYA='5R95TI.PH@("`@("`@("`@("`@("`@:68@
M*"1D871A*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1D871A.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]L:7-T0V%C:&5;)'-U8FED>%TI*2![
M"B`@("`@("`@("`@("1M86EL9&5L:6T@/2`D=&AI<RT^7VQI<W1#86-H95LD
M<W5B:61X75LG9"==.PH@("`@("`@("`@("`D;6%I;'-O<G0@/2`D=&AI<RT^
M7VQI<W1#86-H95LD<W5B:61X75LG<R==.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1M86EL9&5L:6T@/2`D;6%I;'-O<G0@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQI<W1&;VQD97)S*"1S=6(I
M(&%S("1V86PI('L*("`@("`@("`@("`@("`@("\J(%-T<FEP(&]F9B!T:&4@
M<')E9FEX(&]N;'D@:68@=V4@87)E(&1E86QI;F<@=VET:"!A('!E<G-O;F%L
M"B`@("`@("`@("`@("`@("`@*B!N86UE<W!A8V4N("HO"B`@("`@("`@("`@
M("`@("`D;&%B96P@/2`D<W1R:7!P960@/2!S=6)S='(H)'9A;"P@<W1R<&]S
M*"1V86PL("=])RD@*R`Q*3L*("`@("`@("`@("`@("`@("1N<U]I;F9O(#T@
M24U0.CIG971.86UE<W!A8V4H)&QA8F5L*3L*("`@("`@("`@("`@("`@(&EF
M("@D;G-?:6YF;ULG='EP92==(#T]("=P97)S;VYA;"<I('L*("`@("`@("`@
M("`@("`@("`@("`D;&%B96P@/2!S=6)S='(H)&QA8F5L+"!S=')L96XH)&YS
M7VEN9F];)VYA;64G72DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*'-T<F-A<V5C;7`H)TE.0D]8)RP@)&QA8F5L*2`]/2`P*2![
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D;6%I;&1E;&EM6R1S=')I<'!E9%T@/2`D
M;G-?:6YF;ULG9&5L:6UI=&5R)UT["B`@("`@("`@("`@("`@("`D;6%I;'-O
M<G1;)'-T<FEP<&5D72`]("1L86)E;#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^7VQI<W1#86-H95LD<W5B:61X72`](&%R<F%Y*"=D)R`]
M/B`D;6%I;&1E;&EM+"`G<R<@/3X@)&UA:6QS;W)T*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)&UA:6QS;W)T*2D@>PH@("`@("`@("`@("`O
M+R!43T1/.B!&:7@@=7-E(&]F(&1E;&EM:71E<B!H97)E"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TE-05`O4V]R="YP:'`G
M.PH@("`@("`@("`@("`D9&5L:6UI=&5R(#T@<F5S970H)%]315-324].6R=I
M;7`G75LG;F%M97-P86-E)UTI.PH@("`@("`@("`@("`D:6UA<%]S;W)T(#T@
M)FYE=R!)35!?24U!4%]3;W)T*"1D96QI;6ET97);)V1E;&EM:71E<B==*3L*
M("`@("`@("`@("`@)&EM87!?<V]R="T^<V]R=$UA:6QB;WAE<R@D;6%I;'-O
M<G0L('1R=64L('1R=64I.PH*("`@("`@("`@("`@9F]R96%C:"`H)&UA:6QS
M;W)T(&%S("1M8F]X7VYA;64@/3X@)&QA8F5L*2!["B`@("`@("`@("`@("`@
M("!I9B`H:6Y?87)R87DH)&UB;WA?;F%M92P@)&9I;'1E<BDI('L*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("!I9B`H(2@D9&5C;V1E9%]M86EL8F]X(#T@4W1R:6YG
M.CIC;VYV97)T0VAA<G-E="@D;6)O>%]N86UE+"`G551&-RU)34%0)RDI("8F
M"B`@("`@("`@("`@("`@("`@("`@96UP='DH)'1H:7,M/E]E<G)O<D-A8VAE
M6R1M8F]X7VYA;65=*2D@>PH@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@9F]L9&5R(%PB)7-<(B!C;VYT
M86EN<R!I;&QE9V%L(&-H87)A8W1E<G,@:6X@:71S(&YA;64N($ET(&UA>2!C
M875S92!P<F]B;&5M<RX@4&QE87-E('-E92!Y;W5R('-Y<W1E;2!A9&UI;FES
M=')A=&]R+B(I+"`D;&%B96PI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?97)R;W)#86-H95LD;6)O>%]N86UE72`]
M('1R=64["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'!A
M<G1S(#T@*"1M86EL9&5L:6U;)&UB;WA?;F%M95TI(#\@97AP;&]D92@D;6%I
M;&1E;&EM6R1M8F]X7VYA;65=+"`D;&%B96PI(#H@87)R87DH)&QA8F5L*3L*
M("`@("`@("`@("`@("`@("1P87)T8V]U;G0@/2!C;W5N="@D<&%R=',I.PH@
M("`@("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P]("1P87)T8V]U;G0[
M("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D:71E;2`](&EM<&QO9&4H
M)&UA:6QD96QI;5LD;6)O>%]N86UE72P@87)R87E?<VQI8V4H)'!A<G1S+"`P
M+"`D:2DI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&QI<W1;
M)&ET96U=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D86)B<F5V(#T@
M)&9O;&1E9"`]('-T<E]R97!E870H)R`G+"`T("H@*"1I("T@,2DI("X@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="@D<&%R='-;*"1I("T@,2E=+"`G551&-RU)
M34%0)RD["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&%B
M8G)E=BD@/B`R-BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%B
M8G)E=B`](%-T<FEN9SHZ<W5B<W1R*"1A8F)R978L(#`L(#$P*2`N("<N+BXG
M("X@4W1R:6YG.CIS=6)S='(H)&%B8G)E=BP@+3$S+"`Q,RD["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&QI
M<W1;)&ET96U=(#T@87)R87DH)W9A;"<@/3X@*"1I(#T]("1P87)T8V]U;G0I
M(#\@)&UB;WA?;F%M92`Z("<G+"`G;&%B96PG(#T^("1F;VQD960L("=A8F)R
M978G(#T^("1A8F)R978I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+RH@061D('1H92!)3D)/6"!O;B!T;W`@;V8@;&ES="!I9B!N;W0@:6X@=&AE
M(&9I;'1E<B!L:7-T+B`J+PH@("`@("`@(&EF("@A:6Y?87)R87DH)TE.0D]8
M)RP@)&9I;'1E<BDI('L*("`@("`@("`@("`@)&QI<W0@/2`D:6YB;WA?96YT
M<GD@*R`D;&ES=#L*("`@("`@("!]"@H@("`@("`@("\J(%-A=F4@:6X@8V%C
M:&4L(&EF(&YE961E9"X@*B\*("`@("`@("!I9B`H)&-O;F9;)W-E<G9E<B==
M6R=C86-H95]F;VQD97)S)UTI('L*("`@("`@("`@("`@)&9O;&1E<E]C86-H
M95LD9G5L;%]S:6=N871U<F5=(#T@)'-E<W-I;VY/8BT^<W1O<F5/:60H)&QI
M<W0L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&ES=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@9F]L
M9&5R<RX@5&AI<R!I<R!A('=R87!P97(@87)O=6YD('1H92!F;&ES="@I"B`@
M("`@*B!F=6YC=&EO;B!W:&EC:"!R961U8V5S('1H92!N=6UB97(@;V8@87)G
M=6UE;G1S(&YE961E9"!I9B!W92!C86X@87-S=6UE"B`@("`@*B!T:&%T($E-
M4"=S(&9U;&P@96YV:7)O;FUE;G0@:7,@<')E<V5N="X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&9I;'1E<B`@06X@87)R87D@;V8@;6%I;&)O>&5S
M('1O(&EG;F]R92X*("`@("`J($!P87)A;2!B;V]L96%N("1S=6(@("!)9B!S
M970L('=I;&P@8F4@=7-E9"!T;R!D971E<FUI;F4@:68@=V4@<VAO=6QD"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@;&ES="!O;FQY('-U8G-C<FEB
M960@9F]L9&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M87)R87D@;V8@;6%I;&)O>&5S(')E='5R;F5D(&)Y(&9L:7-T*"DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&9L:7-T7TE-4"@D9FEL=&5R(#T@87)R87DH*2P@
M)'-U8B`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YF;&ES
M="AI<U]N=6QL*"1S=6(I(#\@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E
M*"=S=6)S8W)I8F4G*2`Z("1S=6(L("1F:6QT97(I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5L971E<R!O;F4@;W(@;6]R92!F;VQD97)S+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D9F]L9&5R7V%R<F%Y("!!;B!A<G)A>2!O
M9B!F=6QL('5T9B!E;F-O9&5D(&9O;&1E<B!N86UE<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1O(&)E(&1E;&5T960N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<W5B<V-R:6)E("`@02!B;V]L96%N(&1E<V-R:6)I
M;F<@=VAE=&AE<B!O<B!N;W0@=&\@=7-E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]L9&5R('-U8G-C<FEP=&EO;G,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@9F]L
M9&5R<R!W97)E('-U8V-E<W-F=6QL>2!D96QE=&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D96QE=&4H)&9O;&1E<E]A<G)A>2P@)'-U8G-C<FEB92D*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8L("1N;W1I9FEC871I;VX["@H@("`@
M("`@("1S97)V97(@/2!)35`Z.G-E<G9E<E-T<FEN9R@I.PH@("`@("`@("1R
M971U<FY?=F%L=64@/2!T<G5E.PH@("`@("`@("1D96QE=&5D(#T@87)R87DH
M*3L*"B`@("`@("`@:68@*"1S=6)S8W)I8F4I('L*("`@("`@("`@("`@)'-U
M8E]F;VQD97)S(#T@)'1H:7,M/E]L:7-T1F]L9&5R<RAT<G5E*3L*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1F;VQD97)?87)R87D@87,@)&9O;&1E
M<BD@>PH@("`@("`@("`@("!I9B`H(6EM87!?9&5L971E;6%I;&)O>"@D7U-%
M4U-)3TY;)VEM<"==6R=S=')E86TG72P@)'-E<G9E<B`N("1F;VQD97(I*2![
M"B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B5&AE(&9O;&1E<B!<(B5S7"(@=V%S(&YO="!D96QE=&5D+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED(BDL($E-4#HZ9&ES<&QA>49O;&1E<B@D
M9F]L9&5R*2D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G.B`G("X@:6UA<%]L87-T7V5R<F]R*"DL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@("`@("`@("`@)')E='5R;E]V86QU92`](&9A;'-E.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"1S=6)S8W)I8F4@
M)B8*("`@("`@("`@("`@("`@("`@("!I;E]A<G)A>2@D<V5R=F5R("X@)&9O
M;&1E<BP@)'-U8E]F;VQD97)S*2`F)@H@("`@("`@("`@("`@("`@("`@("%I
M;6%P7W5N<W5B<V-R:6)E*"1?4T534TE/3ELG:6UP)UU;)W-T<F5A;2==+"`D
M<V5R=F5R("X@)&9O;&1E<BDI('L*("`@("`@("`@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&9O;&1E<B!<(B5S7"(@
M=V%S(&1E;&5T960@8G5T('EO=2!W97)E(&YO="!U;G-U8G-C<FEB960@9G)O
M;2!I="XB*2P@24U0.CID:7-P;&%Y1F]L9&5R*"1F;VQD97(I*2P@)VAO<F1E
M+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7W9A;'5E
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@
M9F]L9&5R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(BDL($E-
M4#HZ9&ES<&QA>49O;&1E<B@D9F]L9&5R*2DL("=H;W)D92YS=6-C97-S)RD[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&1E;&5T961;
M72`]("1F;VQD97(["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V5X
M:7-T<U)E<W5L='-;)&9O;&1E<ETI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H(65M<'1Y*"1D96QE=&5D*2D@>PH@("`@("`@("`@
M("`O*B!5<&1A=&4@=&AE($E-05!?5')E92!C86-H92X@*B\*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O24U!4"]4<F5E+G!H
M<"<["B`@("`@("`@("`@("1I;6%P=')E92`]("9)35!?5')E93HZ<VEN9VQE
M=&]N*"D["B`@("`@("`@("`@(&EF("@D:6UA<'1R964I('L*("`@("`@("`@
M("`@("`@("1I;6%P=')E92T^9&5L971E*"1D96QE=&5D*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@4F5S970@=&AE(&9O;&1E<B!C86-H92X@
M*B\*("`@("`@("`@("`@:68@*"1C;VYF6R=S97)V97(G75LG8V%C:&5?9F]L
M9&5R<R==*2!["B`@("`@("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)VEM
M<"==6R=C86-H92==6R=F;VQD97)?8V%C:&4G72D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J(%)E8W)E871E(%9I<G1U86P@1F]L9&5R<RX@*B\*
M("`@("`@("`@("`@)$=,3T)!3%-;)VEM<%]S96%R8V@G72T^<V5S<VEO;E-E
M='5P*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E='5R;E]V86QU
M93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A(&YE=R!)34%0(&9O
M;&1E<B!I9B!I="!D;V5S(&YO="!A;')E861Y(&5X:7-T+"!A;F0@<W5B8W)I
M8F4@=&\*("`@("`J(&ET(&%S('=E;&P@:68@<F5Q=65S=&5D+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@("`@(%1H92!F=6QL('5T
M9B!E;F-O9&5D(&9O;&1E<B!T;R!B92!C<F5A=&5D+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'-U8G-C<FEB92`@02!B;V]L96%N(&1E<V-R:6)I;F<@=VAE
M=&AE<B!O<B!N;W0@=&\@=7-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F;VQD97(@<W5B<V-R:7!T:6]N<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!F;VQD97(@=V%S
M('-U8V-E<W-F=6QL>2!C<F5A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M<F5A=&4H)&9O;&1E<BP@)'-U8G-C<FEB92D*("`@('L*("`@("`@("!G;&]B
M86P@)&-O;F8L("1N;W1I9FEC871I;VX["@H@("`@("`@("\J($-H96-K('!E
M<FUI<W-I;VYS+B`J+PH@("`@("`@(&EF("@A24U0.CIH87-097)M:7-S:6]N
M*"=C<F5A=&5?9F]L9&5R<R<I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@
M0&AT;6QS<&5C:6%L8VAA<G,H7R@B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@9F]L9&5R<RXB*2P@14Y47T-/35!!5"P@3DQ3.CIG971#:&%R<V5T
M*"DI.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P
M97)M<V1E;FEE9"==*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!(
M;W)D93HZ8V%L;$AO;VLH)U]P97)M<U]H;V]K7V1E;FEE9"<L(&%R<F%Y*"=I
M;7`Z8W)E871E7V9O;&1E<G,G*2P@)VAO<F1E)RP@)&UE<W-A9V4I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&UE
M<W-A9V4L("=H;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("@A
M24U0.CIH87-097)M:7-S:6]N*"=M87A?9F]L9&5R<R<I*2!["B`@("`@("`@
M("`@("1M97-S86=E(#T@0&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@9F]L
M9&5R<RXB*2P@24U0.CIH87-097)M:7-S:6]N*"=M87A?9F]L9&5R<R<L('1R
M=64I*2P@14Y47T-/35!!5"P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P97)M<V1E;FEE9"==
M*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!(;W)D93HZ8V%L;$AO
M;VLH)U]P97)M<U]H;V]K7V1E;FEE9"<L(&%R<F%Y*"=I;7`Z;6%X7V9O;&1E
M<G,G*2P@)VAO<F1E)RP@)&UE<W-A9V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&UE<W-A9V4L("=H;W)D92YE
M<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('=E
M(&%R92!N;W0@=')Y:6YG('1O(&-R96%T92!A(&1U<&QI8V%T92!F;VQD97(@
M*B\*("`@("`@("!I9B`H)'1H:7,M/F5X:7-T<R@D9F]L9&5R*2D@>PH@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&9O
M;&1E<B!<(B5S7"(@86QR96%D>2!E>&ES=',B*2P@24U0.CID:7-P;&%Y1F]L
M9&5R*"1F;VQD97(I*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@071T96UP="!T
M;R!C<F5A=&4@=&AE(&UA:6QB;W@@*B\*("`@("`@("!I9B`H(6EM87!?8W)E
M871E;6%I;&)O>"@D7U-%4U-)3TY;)VEM<"==6R=S=')E86TG72P@24U0.CIS
M97)V97)3=')I;F<H)&9O;&1E<BDI*2!["B`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@9F]L9&5R(%PB)7-<(B!W87,@
M;F]T(&-R96%T960N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B*2P@
M24U0.CID:7-P;&%Y1F]L9&5R*"1F;VQD97(I*2`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G.B`G("X@:6UA<%]L87-T7V5R<F]R*"DL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!297-E="!T:&4@9F]L9&5R(&-A8VAE+B`J+PH@("`@
M("`@(&EF("@D8V]N9ELG<V5R=F5R)UU;)V-A8VAE7V9O;&1E<G,G72D@>PH@
M("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)VEM<"==6R=C86-H92==6R=F
M;VQD97)?8V%C:&4G72D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&4@
M=7-E<B!U<V5S(%-50E-#4DE"12P@=&AE;B!A9&0@=&\@=&AE('-U8G-C<FEB
M92!L:7-T("HO"B`@("`@("`@:68@*"1S=6)S8W)I8F4@)B8*("`@("`@("`@
M("`@(6EM87!?<W5B<V-R:6)E*"1?4T534TE/3ELG:6UP)UU;)W-T<F5A;2==
M+"!)35`Z.G-E<G9E<E-T<FEN9R@D9F]L9&5R*2DI('L*("`@("`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!F;VQD97(@7"(E
M<UPB('=A<R!C<F5A=&5D(&)U="!Y;W4@=V5R92!N;W0@<W5B<V-R:6)E9"!T
M;R!I="XB*2P@24U0.CID:7-P;&%Y1F]L9&5R*"1F;VQD97(I*2P@)VAO<F1E
M+G=A<FYI;F<G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!4
M:&4@9F]L9&5R(&-R96%T:6]N(&AA<R!B965N('-U8V-E<W-F=6P@*B\*("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!F
M;VQD97(@7"(E<UPB('=A<R!S=6-C97-S9G5L;'D@8W)E871E9"XB*2P@24U0
M.CID:7-P;&%Y1F]L9&5R*"1F;VQD97(I*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T92!T:&4@24U!4%]4<F5E(&]B
M:F5C="X@*B\*("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI
M8B])34%0+U1R964N<&AP)SL*("`@("`@("`D:6UA<'1R964@/2`F24U07U1R
M964Z.G-I;F=L971O;B@I.PH@("`@("`@(&EF("@D:6UA<'1R964I('L*("`@
M("`@("`@("`@)&EM87!T<F5E+3YI;G-E<G0H)&9O;&1E<BD["B`@("`@("`@
M?0H*("`@("`@("`O*B!296-R96%T92!6:7)T=6%L($9O;&1E<G,N("HO"B`@
M("`@("`@)$=,3T)!3%-;)VEM<%]S96%R8V@G72T^<V5S<VEO;E-E='5P*"D[
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1FEN9',@;W5T(&EF(&$@<W!E8VEF:6,@9F]L9&5R(&5X:7-T<R!O<B!N;W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]L9&5R("!4:&4@9G5L
M;"!U=&8@96YC;V1E9"!F;VQD97(@;F%M92!T;R!B92!C:&5C:V5D+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE
M(&9O;&1E<B!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D
M9F]L9&5R*0H@("`@>PH@("`@("`@("\J(%1R>2!T:&4@24U!4%]4<F5E(&]B
M:F5C="!F:7)S="X@*B\*("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@
M+B`G+VQI8B])34%0+U1R964N<&AP)SL*("`@("`@("`D:6UA<'1R964@/2`F
M24U07U1R964Z.G-I;F=L971O;B@I.PH@("`@("`@(&EF("@D:6UA<'1R964I
M('L*("`@("`@("`@("`@)&5L="`]("1I;6%P=')E92T^9V5T*"1F;VQD97(I
M.PH@("`@("`@("`@("!I9B`H)&5L="`F)B`A)&EM87!T<F5E+3YI<T-O;G1A
M:6YE<B@D96QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]E>&ES='-297-U;'1S6R1F;VQD97)=*2D@>PH@("`@("`@("`@("`D
M<F5S(#T@0&EM87!?;&ES="@D7U-%4U-)3TY;)VEM<"==6R=S=')E86TG72P@
M24U0.CIS97)V97)3=')I;F<H*2P@)&9O;&1E<BD["B`@("`@("`@("`@("1T
M:&ES+3Y?97AI<W1S4F5S=6QT<ULD9F]L9&5R72`](&ES7V%R<F%Y*"1R97,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AI<W1S4F5S
M=6QT<ULD9F]L9&5R73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M97,@
M86X@24U!4"!F;VQD97(N(%1H92!S=6)S8W)I<'1I;VX@<W1A='5S(')E;6%I
M;G,@=&AE('-A;64N("!!;&P*("`@("`J('-U8F9O;&1E<G,@=VEL;"!A;'-O
M(&)E(')E;F%M960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD
M("!4:&4@;VQD('5T9B!E;F-O9&5D(&9O;&1E<B!N86UE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F5W("!4:&4@;F5W('5T9B!E;F-O9&5D(&9O;&1E<B!N
M86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O
M<B!N;W0@86QL(&9O;&1E<BAS*2!W97)E('-U8V-E<W-F=6QL>2!R96YA;65D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;64H)&]L9"P@)&YE=RD*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8L("1N;W1I9FEC871I;VX["@H@("`@
M("`@("1N86UE<W!A8V5?:6YF;R`]($E-4#HZ9V5T3F%M97-P86-E*"1O;&0I
M.PH@("`@("`@("1S97)V97(@/2!)35`Z.G-E<G9E<E-T<FEN9R@I.PH@("`@
M("`@("1S=6-C97-S(#T@=')U93L*("`@("`@("`D9&5L971E9"`]("1I;G-E
M<G1E9"`](&%R<F%Y*"D["@H@("`@("`@("\J($=E="!L:7-T(&]F(&%N>2!F
M;VQD97)S('1H870@87)E('5N9&5R;F5A=&@@=&AI<R!O;F4N("HO"B`@("`@
M("`@)&%L;%]F;VQD97)S(#T@87)R87DH)'-E<G9E<B`N("1O;&0I.PH@("`@
M("`@("1F;VQD97)?;&ES="`](&EM87!?;&ES="@D7U-%4U-)3TY;)VEM<"==
M6R=S=')E86TG72P@)'-E<G9E<BP@)&]L9"`N("1N86UE<W!A8V5?:6YF;ULG
M9&5L:6UI=&5R)UT@+B`G*B<I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D9F]L
M9&5R7VQI<W0I*2!["B`@("`@("`@("`@("1A;&Q?9F]L9&5R<R`](&%R<F%Y
M7VUE<F=E*"1F;VQD97)?;&ES="P@)&%L;%]F;VQD97)S*3L*"B`@("`@("`@
M("`@("\J(%-O<G0@=&AE(&9O;&1E<G,@:6X@<F5V97)S92!O<F1E<B!B96-A
M=7-E('-O;64@24U!4"!S97)V97)S"B`@("`@("`@("`@("`J('=I;&P@875T
M;VUA=&EC86QL>2!R96YA;64@86QL(&9O;&1E<G,@=VAE;B!T:&4@8F%S92!F
M;VQD97(@:7,*("`@("`@("`@("`@("H@<F5N86UE9"!W:&EC:"!W:6QL(')E
M<W5L="!I;B!E<G)O<B!M97-S86=E<R!I9B!W92!R96YA;64@9G)O;0H@("`@
M("`@("`@("`@*B!T:&4@8F]T=&]M('5P+B`J+PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B])34%0+U-O<G0N<&AP)SL*("`@
M("`@("`@("`@)&YS7VYE=R`]($E-4#HZ9V5T3F%M97-P86-E*"1N97<I.PH@
M("`@("`@("`@("`D:6UA<%]S;W)T(#T@)FYE=R!)35!?24U!4%]3;W)T*"1N
M<U]N97=;)V1E;&EM:71E<B==*3L*("`@("`@("`@("`@)&EM87!?<V]R="T^
M<V]R=$UA:6QB;WAE<R@D86QL7V9O;&1E<G,I.PH@("`@("`@("`@("`D86QL
M7V9O;&1E<G,@/2!A<G)A>5]R979E<G-E*"1A;&Q?9F]L9&5R<RD["B`@("`@
M("`@?0H*("`@("`@("`D<W5B7V9O;&1E<G,@/2`D=&AI<RT^7VQI<W1&;VQD
M97)S*'1R=64I.PH*("`@("`@("!F;W)E86-H("@D86QL7V9O;&1E<G,@87,@
M)&9O;&1E<E]O;&0I('L*("`@("`@("`@("`@)'-U8G-C<FEB92`](&9A;'-E
M.PH*("`@("`@("`@("`@)&]L9%]P;W,@/2!S=')P;W,H)&9O;&1E<E]O;&0L
M("=])RD@*R`Q.PH*("`@("`@("`@("`@+RH@1V5T('1H92!N97<@9F]L9&5R
M(&YA;64N("HO"B`@("`@("`@("`@("1F;VQD97)?;F5W(#T@<')E9U]R97!L
M86-E*"<O)R`N('!R96=?<75O=&4H)&]L9"P@)R\G*2`N("<O)RP@)&YE=RP@
M)&9O;&1E<E]O;&0L(#$I.PH*("`@("`@("`@("`@+RH@1V5T('1H92!F;VQD
M97(@;F%M97,@=VET:&]U="!T:&4@<V5R=F5R('!R969I>"X@*B\*("`@("`@
M("`@("`@)&YA;65?;VQD(#T@<W5B<W1R*"1F;VQD97)?;VQD+"`D;VQD7W!O
M<RD["B`@("`@("`@("`@("1N86UE7VYE=R`]('-U8G-T<B@D9F]L9&5R7VYE
M=RP@<W1R<&]S*"1F;VQD97)?;F5W+"`G?2<I("L@,2D["@H@("`@("`@("`@
M("`O*B!5;G-U8G-C<FEB92!F<F]M(&-U<G)E;G0@9F]L9&5R+B`J+PH@("`@
M("`@("`@("!I9B`H:6Y?87)R87DH)&9O;&1E<E]O;&0L("1S=6)?9F]L9&5R
M<RDI('L*("`@("`@("`@("`@("`@("1S=6)S8W)I8F4@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@:6UA<%]U;G-U8G-C<FEB92@D7U-%4U-)3TY;)VEM<"==
M6R=S=')E86TG72P@)&9O;&1E<E]O;&0I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H:6UA<%]R96YA;65M86EL8F]X*"1?4T534TE/3ELG:6UP
M)UU;)W-T<F5A;2==+"`D9F]L9&5R7V]L9"P@)&9O;&1E<E]N97<I*2!["B`@
M("`@("`@("`@("`@("!I9B`H)'-U8G-C<FEB92D@>PH@("`@("`@("`@("`@
M("`@("`@(&EM87!?<W5B<V-R:6)E*"1?4T534TE/3ELG:6UP)UU;)W-T<F5A
M;2==+"`D9F]L9&5R7VYE=RD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@)&1E;&5T961;72`]("1N86UE7V]L9#L*("`@("`@("`@("`@
M("`@("1I;G-E<G1E9%M=(#T@)&YA;65?;F5W.PH*("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@9F]L9&5R(%PB
M)7-<(B!W87,@<W5C8V5S<V9U;&QY(')E;F%M960@=&\@7"(E<UPB+B(I+"!)
M35`Z.F1I<W!L87E&;VQD97(H)&YA;65?;VQD*2P@24U0.CID:7-P;&%Y1F]L
M9&5R*"1N86UE7VYE=RDI+"`G:&]R9&4N<W5C8V5S<R<I.PH*("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?97AI<W1S4F5S=6QT<ULD;F%M95]O;&1=
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")296YA;6EN9R!<(B5S7"(@=&\@
M7"(E<UPB(&9A:6QE9"X@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(I
M+"!)35`Z.F1I<W!L87E&;VQD97(H)&YA;65?;VQD*2P@24U0.CID:7-P;&%Y
M1F]L9&5R*"1N86UE7VYE=RDI("X@)SH@)R`N(&EM87!?;&%S=%]E<G)O<B@I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@("1S=6-C97-S(#T@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A
M96UP='DH)&1E;&5T960I*2!["B`@("`@("`@("`@("\J(%5P9&%T92!T:&4@
M24U07U1R964@8V%C:&4N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+TE-05`O5')E92YP:'`G.PH@("`@("`@("`@("`D
M:6UA<'1R964@/2`F24U07U1R964Z.G-I;F=L971O;B@I.PH@("`@("`@("`@
M("!I9B`H)&EM87!T<F5E*2!["B`@("`@("`@("`@("`@("`D:6UA<'1R964M
M/G)E;F%M92@D9&5L971E9"P@)&EN<V5R=&5D*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@4F5S970@=&AE(&9O;&1E<B!C86-H92X@*B\*("`@
M("`@("`@("`@:68@*"1C;VYF6R=S97)V97(G75LG8V%C:&5?9F]L9&5R<R==
M*2!["B`@("`@("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)VEM<"==6R=C
M86-H92==6R=F;VQD97)?8V%C:&4G72D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J(%)E8W)E871E(%9I<G1U86P@1F]L9&5R<RX@*B\*("`@("`@
M("`@("`@)$=,3T)!3%-;)VEM<%]S96%R8V@G72T^<V5S<VEO;E-E='5P*"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-U8V-E<W,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3=6)S8W)I8F5S('1O(&]N92!O<B!M;W)E($E-05`@
M9F]L9&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&9O;&1E<E]A
M<G)A>2`@06X@87)R87D@;V8@9G5L;"!U=&8@96YC;V1E9"!F;VQD97(@;F%M
M97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!B92!S
M=6)S8W)I8F5D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE
M=&AE<B!O<B!N;W0@=&AE(&9O;&1E<G,@=V5R92!S=6-C97-S9G5L;'D*("`@
M("`J("`@("`@("`@("`@("`@("`@<W5B<V-R:6)E9"!T;RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<W5B<V-R:6)E*"1F;VQD97)?87)R87DI"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF+"`D;F]T:69I8V%T:6]N.PH*("`@("`@("`D
M<F5T=7)N7W9A;'5E(#T@=')U93L*("`@("`@("`D<W5B<V-R:6)E9"`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&9O;&1E<E]A<G)A>2DI
M('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*").;R!F;VQD
M97)S('=E<F4@<W!E8VEF:65D(BDL("=H;W)D92YM97-S86=E)RD["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1F;VQD97)?87)R87D@87,@)&9O;&1E<BD@>PH@("`@("`@("`@("!I
M9B`H)&9O;&1E<B`A/2`G("<I('L*("`@("`@("`@("`@("`@(&EF("@A:6UA
M<%]S=6)S8W)I8F4H)%]315-324].6R=I;7`G75LG<W1R96%M)UTL($E-4#HZ
M<V5R=F5R4W1R:6YG*"1F;VQD97(I*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")9;W4@=V5R92!N;W0@
M<W5B<V-R:6)E9"!T;R!<(B5S7"(N($AE<F4@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60B*2P@24U0.CID:7-P;&%Y1F]L9&5R*"1F;VQD97(I*2`N("<Z("<@
M+B!I;6%P7VQA<W1?97)R;W(H*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@
M("`@("`@("`@("`@)')E='5R;E]V86QU92`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*'-P<FEN=&8H7R@B66]U('=E<F4@<W5C8V5S<V9U;&QY('-U
M8G-C<FEB960@=&\@7"(E<UPB(BDL($E-4#HZ9&ES<&QA>49O;&1E<B@D9F]L
M9&5R*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("`@("`@
M)'-U8G-C<FEB961;72`]("1F;VQD97(["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'-U
M8G-C<FEB960I*2!["B`@("`@("`@("`@("\J($EN:71I86QI>F4@=&AE($E-
M05!?5')E92!O8FIE8W0N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+TE-05`O5')E92YP:'`G.PH@("`@("`@("`@("`D
M:6UA<'1R964@/2`F24U07U1R964Z.G-I;F=L971O;B@I.PH@("`@("`@("`@
M("!I9B`H)&EM87!T<F5E*2!["B`@("`@("`@("`@("`@("`D:6UA<'1R964M
M/G-U8G-C<FEB92@D<W5B<V-R:6)E9"D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J(%)E<V5T('1H92!F;VQD97(@8V%C:&4N("HO"B`@("`@("`@
M("`@(&EF("@D8V]N9ELG<V5R=F5R)UU;)V-A8VAE7V9O;&1E<G,G72D@>PH@
M("`@("`@("`@("`@("`@=6YS970H)%]315-324].6R=I;7`G75LG8V%C:&4G
M75LG9F]L9&5R7V-A8VAE)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)')E='5R;E]V86QU93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%5N<W5B<V-R:6)E<R!F<F]M(&]N92!O<B!M;W)E($E-05`@9F]L
M9&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&9O;&1E<E]A<G)A
M>2`@06X@87)R87D@;V8@9G5L;"!U=&8@96YC;V1E9"!F;VQD97(@;F%M97,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!B92!U;G-U
M8G-C<FEB960N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T
M:&5R(&]R(&YO="!T:&4@9F]L9&5R<R!W97)E('-U8V-E<W-F=6QL>0H@("`@
M("H@("`@("`@("`@("`@("`@("!U;G-U8G-C<FEB960@9G)O;2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=6YS=6)S8W)I8F4H)&9O;&1E<E]A<G)A>2D*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8L("1N;W1I9FEC871I;VX["@H@("`@
M("`@("1R971U<FY?=F%L=64@/2!T<G5E.PH@("`@("`@("1U;G-U8G-C<FEB
M960@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F;VQD97)?
M87)R87DI*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B
M3F\@9F]L9&5R<R!W97)E('-P96-I9FEE9"(I+"`G:&]R9&4N;65S<V%G92<I
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D9F]L9&5R7V%R<F%Y(&%S("1F;VQD97(I('L*("`@("`@
M("`@("`@:68@*"1F;VQD97(@(3T@)R`G*2!["B`@("`@("`@("`@("`@("!I
M9B`H<W1R8V%S96-M<"@D9F]L9&5R+"`G24Y"3U@G*2`]/2`P*2!["B`@("`@
M("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H
M(EEO=2!C86YN;W0@=6YS=6)S8W)I8F4@9G)O;2!<(B5S7"(N(BDL($E-4#HZ
M9&ES<&QA>49O;&1E<B@D9F]L9&5R*2DL("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"%I;6%P7W5N<W5B<V-R:6)E*"1?4T53
M4TE/3ELG:6UP)UU;)W-T<F5A;2==+"!)35`Z.G-E<G9E<E-T<FEN9R@D9F]L
M9&5R*2DI('L*("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*'-P<FEN=&8H7R@B66]U('=E<F4@;F]T('5N<W5B<V-R:6)E9"!F<F]M
M(%PB)7-<(BX@2&5R92!I<R!W:&%T('1H92!S97)V97(@<V%I9"(I+"!)35`Z
M.F1I<W!L87E&;VQD97(H)&9O;&1E<BDI("X@)SH@)R`N(&EM87!?;&%S=%]E
M<G)O<B@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@("`@("`D
M<F5T=7)N7W9A;'5E(#T@9F%L<V4["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")9;W4@=V5R92!S=6-C97-S9G5L;'D@=6YS=6)S8W)I8F5D(&9R
M;VT@7"(E<UPB(BDL($E-4#HZ9&ES<&QA>49O;&1E<B@D9F]L9&5R*2DL("=H
M;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("`@("`@)'5N<W5B<V-R
M:6)E9%M=(#T@)&9O;&1E<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=6YS=6)S8W)I
M8F5D*2D@>PH@("`@("`@("`@("`O*B!);FET:6%L:7IE('1H92!)34%07U1R
M964@;V)J96-T+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!
M4T4@+B`G+VQI8B])34%0+U1R964N<&AP)SL*("`@("`@("`@("`@)&EM87!T
M<F5E(#T@)DE-4%]4<F5E.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@:68@
M*"1I;6%P=')E92D@>PH@("`@("`@("`@("`@("`@)&EM87!T<F5E+3YU;G-U
M8G-C<FEB92@D=6YS=6)S8W)I8F5D*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@4F5S970@=&AE(&9O;&1E<B!C86-H92X@*B\*("`@("`@("`@
M("`@:68@*"1C;VYF6R=S97)V97(G75LG8V%C:&5?9F]L9&5R<R==*2!["B`@
M("`@("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)VEM<"==6R=C86-H92==
M6R=F;VQD97)?8V%C:&4G72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5T=7)N7W9A;'5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5N97)A=&5S(&$@<W1R:6YG('1H870@8V%N(&)E('-A=F5D(&]U
M="!T;R!A;B!M8F]X(&9O<FUA="!M86EL8F]X(&9I;&4*("`@("`J(&9O<B!A
M(&9O;&1E<B!O<B!S970@;V8@9F]L9&5R<RP@;W!T:6]N86QL>2!I;F-L=61I
M;F<@86QL('-U8F9O;&1E<G,@;V8*("`@("`J('1H92!S96QE8W1E9"!F;VQD
M97)S(&%S('=E;&PN($%L;"!F;VQD97)S('=I;&P@8F4@<'5T(&EN=&\@=&AE
M('-A;64*("`@("`J('-T<FEN9RX*("`@("`J"B`@("`@*B!`875T:&]R($1I
M9&D@4FEE9&5R(#QA9')I961E<D!S8F]X+G1U9W)A>BYA=#X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&9O;&1E<E]L:7-T("!!(&QI<W0@;V8@9G5L
M;"!U=&8@96YC;V1E9"!F;VQD97(@;F%M97,@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&=E;F5R871E(&%N(&UB;W@@9FEL92!F;W(N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E("!);F-L=61E('-U
M8F9O;&1E<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($%N(&UB
M;W@@9F]R;6%T(&UA:6QB;W@@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F=E;F5R871E36)O>"@D9F]L9&5R7VQI<W0L("1R96-U<G-I=F4@/2!F86QS
M92D*("`@('L*("`@("`@("`D8F]D>2`]("<G.PH*("`@("`@("!I9B`H:7-?
M87)R87DH)&9O;&1E<E]L:7-T*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@24U07T)!4T4@+B`G+VQI8B])34%0+G!H<"<["B`@("`@("`@("`@("1I
M;7!?:6UA<"`]("9)35!?24U!4#HZ<VEN9VQE=&]N*"D["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1F;VQD97)?;&ES="!A<R`D9F]L9&5R*2!["B`@("`@("`@
M("`@("`@("`D:6UP7VEM87`M/F-H86YG94UB;W@H)&9O;&1E<BP@3U!?4D5!
M1$].3%DI.PH@("`@("`@("`@("`@("`@)&-O=6YT(#T@:6UA<%]N=6U?;7-G
M*"1?4T534TE/3ELG:6UP)UU;)W-T<F5A;2==*3L*("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`Q.R`D:2`\/2`D8V]U;G0[("1I*RLI('L*("`@("`@("`@
M("`@("`@("`@("`D:"`](&EM87!?:&5A9&5R*"1?4T534TE/3ELG:6UP)UU;
M)W-T<F5A;2==+"`D:2D["B`@("`@("`@("`@("`@("`@("`@)&9R;VT@/2`G
M/#XG.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:"T^9G)O;5LP
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1H+3YF
M<F]M6S!=+3YM86EL8F]X*2`F)B!I<W-E="@D:"T^9G)O;5LP72T^:&]S="DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F<F]M(#T@)&@M/F9R
M;VU;,%TM/FUA:6QB;W@@+B`G0"<@+B`D:"T^9G)O;5LP72T^:&]S=#L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`@("`@+RH@5V4@;F5E9"!T:&ES(&QO;F<@8V]M
M;6%N9"!S:6YC92!S;VUE($U507,@*&4N9RX@<&EN92D*("`@("`@("`@("`@
M("`@("`@("`@("!R97%U:7)E(&$@<W!A8V4@:6X@9G)O;G0@;V8@<VEN9VQE
M(&1I9VET(&1A>7,N("HO"B`@("`@("`@("`@("`@("`@("`@)&1A=&4@/2!S
M<')I;G1F*"<E<R`E,G,@)7,G+"!D871E*"=$($TG+"`D:"T^=61A=&4I+"!D
M871E*"=J)RP@)&@M/G5D871E*2P@9&%T92@G2#II.G,@62<L("1H+3YU9&%T
M92DI.PH@("`@("`@("`@("`@("`@("`@("1B;V1Y("X]("=&<F]M("<@+B`D
M9G)O;2`N("<@)R`N("1D871E("X@(EQN(CL*("`@("`@("`@("`@("`@("`@
M("`D8F]D>2`N/2!I;6%P7V9E=&-H:&5A9&5R*"1?4T534TE/3ELG:6UP)UU;
M)W-T<F5A;2==+"`D:2P@1E1?4%)%1D540TA415A4*3L*("`@("`@("`@("`@
M("`@("`@("`D8F]D>2`N/2!I;6%P7V)O9'DH)%]315-324].6R=I;7`G75LG
M<W1R96%M)UTL("1I+"!&5%]0145+*2`N(")<;B(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1B;V1Y(#T@
M<W1R7W)E<&QA8V4H(EQR7&XB+"`B7&XB+"`D8F]D>2D["B`@("`@("`@<F5T
M=7)N("1B;V1Y.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP;W)T<R!M97-S
M86=E<R!I;G1O(&$@9VEV96X@9F]L9&5R(&9R;VT@82!M8F]X(&9O<FUA="!M
M86EL8F]X(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]L
M9&5R("!4:&4@9F]L9&5R('1O('!U="!T:&4@;65S<V%G97,@:6YT;RX*("`@
M("`J($!P87)A;2!S=')I;F<@)&UB;W@@("`@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&UB;W@@9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@1F%L<V4@*&)O;VQE86XI(&]N(&9A:6P@;W(@=&AE(&YU;6)E<B!O9B!M
M97-S86=E<PH@("`@("H@("`@("`@("`@("`@("`@:6UP;W)T960@*&EN=&5G
M97(I(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM<&]R=$UB
M;W@H)&9O;&1E<BP@)&UB;W@I"B`@("!["B`@("`@("`@)'1A<F=E="`]($E-
M4#HZ4V5R=F5R4W1R:6YG*"D@+B`D9F]L9&5R.PH*("`@("`@("`D;65S<V%G
M92`]("<G.PH@("`@("`@("1M<V=C;W5N="`](#`["@H@("`@("`@("1F9"`]
M(&9O<&5N*"1M8F]X+"`B<B(I.PH@("`@("`@('=H:6QE("@A9F5O9B@D9F0I
M*2!["B`@("`@("`@("`@("1L:6YE(#T@9F=E=',H)&9D+"`T,#DV*3L*"B`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O1G)O;2`H+BM`+BM\+2`I+T$G
M+"`D;&EN92DI('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&UE<W-A
M9V4I*2!["B`@("`@("`@("`@("`@("`@("`@+R\@36%K92!A8G-O;'5T96QY
M('-U<F4@=&AE<F4@87)E(&YO(&)A<F4@;F5W;&EN97,N"B`@("`@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@/2!P<F5G7W)E<&QA8V4H(GPH6UY<<ETI7&Y\
M(BP@(EQ<,5QR7&XB+"`D;65S<V%G92D["B`@("`@("`@("`@("`@("`@("`@
M)&UE<W-A9V4@/2!S=')?<F5P;&%C92@B7&Y<;B(L(")<;EQR7&XB+"`D;65S
M<V%G92D["@H@("`@("`@("`@("`@("`@("`@(&EF("AI;6%P7V%P<&5N9"@D
M7U-%4U-)3TY;)VEM<"==6R=S=')E86TG72P@)'1A<F=E="P@)&UE<W-A9V4I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M<V=C;W5N="LK.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1M97-S86=E(#T@)R<["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;65S<V%G92`N/2`D;&EN93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!F8VQO<V4H)&9D*3L*"B`@("`@("`@:68@
M*"%E;7!T>2@D;65S<V%G92DI('L*("`@("`@("`@("`@+R\@36%K92!A8G-O
M;'5T96QY('-U<F4@=&AE<F4@87)E(&YO(&)A<F4@;F5W;&EN97,N"B`@("`@
M("`@("`@("1M97-S86=E(#T@<')E9U]R97!L86-E*")\*%M>7')=*5QN?"(L
M(")<7#%<<EQN(BP@)&UE<W-A9V4I.PH@("`@("`@("`@("`D;65S<V%G92`]
M('-T<E]R97!L86-E*")<;EQN(BP@(EQN7')<;B(L("1M97-S86=E*3L*"B`@
M("`@("`@("`@(&EF("AI;6%P7V%P<&5N9"@D7U-%4U-)3TY;)VEM<"==6R=S
M=')E86TG72P@)'1A<F=E="P@)&UE<W-A9V4I*2!["B`@("`@("`@("`@("`@
M("`D;7-G8V]U;G0K*SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("@D;7-G8V]U;G0@/B`P*2`_("1M<V=C;W5N="`Z(&9A;'-E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!A;&P@9F]L
M9&5R<R!O;B!T:&4@<V5R=F5R("AI;F-L=61I;F<@86YY(&9O;&1E<G,@:6X*
M("`@("`J(&AI9&1E;B!N86UE<W!A8V5S*2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W5B
M("!,:7-T(&]N;'D@<W5B<V-R:6)E9"!F;VQD97)S/PH@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&9O;&1E<G,@;F%M97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]L:7-T1F]L9&5R<R@D<W5B(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@)&QI<W1C;60@/2`H)'-U8BD@/R`G:6UA<%]L<W5B
M)R`Z("=I;6%P7VQI<W0G.PH@("`@("`@("1S97)V97(@/2!)35`Z.G-E<G9E
M<E-T<FEN9R@I.PH*("`@("`@("`O*B!'970@86QL('9I<VEB;&4@96YT<FEE
M<R!I;B!O;F4@<V5R=F5R(&%C8V5S<RX@*B\*("`@("`@("`D;&ES="`]("1L
M:7-T8VUD*"1?4T534TE/3ELG:6UP)UU;)W-T<F5A;2==+"`D<V5R=F5R+"`G
M*B<I.PH@("`@("`@(&EF("@A:7-?87)R87DH)&QI<W0I*2!["B`@("`@("`@
M("`@("1L:7-T(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\J(%=E
M(&YE960@=&\@9&\@82!S97!A<F%T92!L:7-T(&-A;&P@9F]R(&5A8V@@:&ED
M9&5N(&YA;65S<&%C92X@*B\*("`@("`@("!F;W)E86-H("@D7U-%4U-)3TY;
M)VEM<"==6R=N86UE<W!A8V4G72!A<R`D=F%L*2!["B`@("`@("`@("`@(&EF
M("@D=F%L6R=H:61D96XG72D@>PH@("`@("`@("`@("`@("`@)&AI9&1E;F)O
M>&5S(#T@)&QI<W1C;60H)%]315-324].6R=I;7`G75LG<W1R96%M)UTL("1S
M97)V97(L("1V86Q;)VYA;64G72`N("<J)RD["B`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)&AI9&1E;F)O>&5S*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1L:7-T(#T@87)R87E?;65R9V4H)&QI<W0L("1H:61D96YB;WAE<RD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;&ES=#L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]3
M96%R8V@N<&AP````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`U,38P-0`Q,#0Q-S,V,C<V-@`P,3<W,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"B\J($1E9FEN97,@
M=7-E9"!T;R!D971E<FUI;F4@=VAA="!K:6YD(&]F(&9I96QD('%U97)Y('=E
M(&%R92!D96%L:6YG('=I=&@N("HO"F1E9FEN92@G24U07U-%05)#2%](14%$
M15(G+"`Q*3L*9&5F:6YE*"=)35!?4T5!4D-(7T)/1%DG+"`R*3L*9&5F:6YE
M*"=)35!?4T5!4D-(7T1!5$4G+"`S*3L*9&5F:6YE*"=)35!?4T5!4D-(7U1%
M6%0G+"`T*3L*"B\J($1E9FEN97,@=7-E9"!T;R!I9&5N=&EF>2!T:&4@9FQA
M9R!I;G!U="X@*B\*9&5F:6YE*"=)35!?4T5!4D-(7T9,04=?4T5%3B<L(#$I
M.PID969I;F4H)TE-4%]314%20TA?1DQ!1U]!3E-715)%1"<L(#(I.PID969I
M;F4H)TE-4%]314%20TA?1DQ!1U]&3$%'1T5$)RP@,RD["F1E9FEN92@G24U0
M7U-%05)#2%]&3$%'7T1%3$54140G+"`T*3L*"B\J($1E9FEN97,@=7-E9"!T
M;R!I9&5N=&EF>2!W:&5T:&5R('1O('-H;W<@=6YS=6)S8W)I8F5D(&9O;&1E
M<G,N("HO"F1E9FEN92@G24U07U-%05)#2%]32$]77U5.4U5"4T-224)%1"<L
M(#`I.PID969I;F4H)TE-4%]314%20TA?4TA/5U]354)30U))0D5$7T].3%DG
M+"`Q*3L*"B\J*@H@*B!4:&4@24U07U-E87)C:#HZ(&-L87-S(&-O;G1A:6YS
M(&%L;"!C;V1E(')E;&%T960@=&\@;6%I;&)O>"!S96%R8VAI;F<*("H@:6X@
M24U0+@H@*@H@*B!4:&4@8VQA<W,@=7-E<R!T:&4@)%]315-324].6R=I;7`G
M75LG<V5A<F-H)UT@=F%R:6%B;&4@=&\@<W1O<F4@:6YF;W)M871I;VX*("H@
M86-R;W-S('!A9V4@86-C97-S97,N(%1H92!F;W)M870@;V8@=&AA="!E;G1R
M>2!I<R!A<R!F;VQL;W=S.@H@*@H@*B`D7U-%4U-)3TY;)VEM<"==6R=S96%R
M8V@G72`](&%R<F%Y*`H@*B`@("`@)W$G(#T^(&%R<F%Y*`H@*B`@("`@("`@
M("=I9%\Q)R`]/B!A<G)A>2@*("H@("`@("`@("`@("`@)W%U97)Y)R`]/B!)
M34%07U-E87)C:%]1=65R>2!O8FIE8W0@*'-E<FEA;&EZ960I+`H@*B`@("`@
M("`@("`@("`G9F]L9&5R<R<@/3X@87)R87D@*$QI<W0@;V8@9F]L9&5R<R!T
M;R!S96%R8V@I+`H@*B`@("`@("`@("`@("`G=6EI;F9O)R`]/B!A<G)A>2`H
M26YF;R!U<V5D(&)Y('-E87)C:"YP:'`@=&\@<F5N9&5R('!A9V4I+`H@*B`@
M("`@("`@("`@("`G;&%B96PG(#T^('-T<FEN9R`H1&5S8W)I<'1I;VX@;V8@
M<V5A<F-H*2P*("H@("`@("`@("`@("`@)W9F;VQD97(G(#T^(&)O;VQE86X@
M*%1R=64@:68@=&AI<R!I<R!A(%9I<G1U86P@1F]L9&5R*0H@*B`@("`@("`@
M("DL"B`J("`@("`@("`@)VED7S(G(#T^(&%R<F%Y*`H@*B`@("`@("`@("`@
M("`N+BXN"B`J("`@("`@("`@*2P*("H@("`@("`@("`N+BXN"B`J("`@("`I
M+`H@*B`@("`@)W9T<F%S:%]I9"<@/3X@<W1R:6YG("A4:&4@5FER='5A;"!4
M<F%S:"!Q=65R>2!)1"DL"B`J("`@("`G=FEN8F]X7VED)R`]/B!S=')I;F<@
M*%1H92!6:7)T=6%L($EN8F]X('%U97)Y($E$*0H@*B`I.PH@*@H@*B`D2&]R
M9&4Z(&EM<"]L:6(O4V5A<F-H+G!H<"QV(#$N,S<N,3`N,C<@,C`P-B\P,B\P
M,2`P.3HQ,CHR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!)
M35`@-"XP"B`J($!P86-K86=E($E-4`H@*B\*8VQA<W,@24U07U-E87)C:"![
M"@H@("`@+RHJ"B`@("`@*B!4:&4@240@;V8@=&AE(&-U<G)E;G0@<V5A<F-H
M('%U97)Y(&EN('5S92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]I9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@
M24U07U1R964Z.B!O8FIE8W0@=&\@=7!D871E+@H@("`@("H*("`@("`J($!V
M87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D7VEM<'1R964["@H@("`@+RHJ
M"B`@("`@*B!3879E(%9I<G1U86P@1F]L9&5R(&EN9F]R;6%T:6]N('=H96X@
M861D:6YG(&5N=')I97,_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7W-A=F561F]L9&5R(#T@=')U93L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!!=F%I;&%B;&4@<&%R86UE=&5R<SH*("`@("`J(#QP<F4^
M"B`@("`@*B`G:60G("`M+2`@5&AE($E$(&]F('1H92!S96%R8V@@<75E<GD@
M:6X@=7-E+@H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N($E-
M4%]396%R8V@H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@
M*"%E;7!T>2@D<&%R86US6R=I9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7VED(#T@)'1H:7,M/E]S=')I<"@D<&%R86US6R=I9"==*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=7`@24U07U-E87)C:"!V87)I
M86)L97,@9F]R('1H92!C=7)R96YT('-E<W-I;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E<W-I;VY3971U<"@I"B`@("!["B`@("`@("`@:68@*"%I<W-E
M="@D7U-%4U-)3TY;)VEM<"==6R=S96%R8V@G72DI('L*("`@("`@("`@("`@
M)%]315-324].6R=I;7`G75LG<V5A<F-H)UT@/2!A<G)A>2@G<2<@/3X@87)R
M87DH*2D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9V5T
M5D9O;&1E<DQI<W0H*2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=F%L6R=V9F]L9&5R)UTI("8F"B`@("`@("`@("`@("`@
M("`A)'1H:7,M/FES5E1R87-H1F]L9&5R*"1K97DI("8F"B`@("`@("`@("`@
M("`@("`A)'1H:7,M/FES5DE.0D]81F]L9&5R*"1K97DI*2!["B`@("`@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=S96%R8V@G75LG<2==6R1K97E=
M(#T@)'9A;#L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=7!D871E24U05')E
M92@G861D)RP@)&ME>2P@)'9A;%LG;&%B96PG72D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/F-R96%T959)3D)/6$9O;&1E<B@I
M.PH@("`@("`@("1T:&ES+3YC<F5A=&565')A<VA&;VQD97(H*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)U;B!A('-E87)C:"X*("`@("`J"B`@("`@*B!`
M<&%R86T@24U!4%]396%R8VA?475E<GD@)B1O8B`@06X@;W!T:6]N86P@<V5A
M<F-H('%U97)Y('1O(&%D9"`H=FEA"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)T%.1"<I('1O('1H92!A8W1I=F4@<V5A<F-H+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("`@(%1H92!S96%R
M8V@@<75E<GD@:60@=&\@=7-E("AB>2!D969A=6QT+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('=I;&P@=7-E('1H92!C=7)R96YT
M($E$('-E="!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O8FIE8W0I+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!S;W)T960@;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N4V5A
M<F-H*"8D;V(L("1I9"`](&YU;&PI"B`@("!["B`@("`@("`@)&ED(#T@*&ES
M7VYU;&PH)&ED*2D@/R`D=&AI<RT^7VED(#H@)'1H:7,M/E]S=')I<"@D:60I
M.PH@("`@("`@("1M8F]X(#T@)R<["B`@("`@("`@)'-O<G1E9"`](&%R<F%Y
M*"D["B`@("`@("`@)'5S95]P;W`S(#T@*"1?4T534TE/3ELG:6UP)UU;)V)A
M<V5?<')O=&]C;VPG72`]/2`G<&]P,R<I.PH*("`@("`@("!I9B`H96UP='DH
M)%]315-324].6R=I;7`G75LG<V5A<F-H)UU;)W$G75LD:61=*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-O<G1E9#L*("`@("`@("!]"B`@("`@("`@)'-E
M87)C:"`]("8D7U-%4U-)3TY;)VEM<"==6R=S96%R8V@G75LG<2==6R1I9%T[
M"@H@("`@("`@("1C:&%R<V5T(#T@3DQ3.CIG971#:&%R<V5T*"D["B`@("`@
M("`@)'-E87)C:%]P87)A;7,@/2!A<G)A>2@G<&]P,R<@/3X@)'5S95]P;W`S
M+"`G8VAA<G-E="<@/3X@)&-H87)S970I.PH*("`@("`@("`O*B!#:&5C:R!I
M9B!T:&4@24U!4"!S97)V97(@<W5P<&]R=',@<V5A<F-H97,@:6X@=&AE(&-U
M<G)E;G0*("`@("`@("`@*B!C:&%R<V5T+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D7U-%4U-)3TY;)VEM<"==6R=I;6%P7W-E<G9E<B==6R=S96%R8VA?8VAA
M<G-E="==6R1C:&%R<V5T72DI('L*("`@("`@("`@("`@)'-E87)C:%]P87)A
M;7-;)VYO7VEM87!?8VAA<G-E="==(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TE-05`O4V5A<F-H
M+G!H<"<["B`@("`@("`@)&EM87!?<V5A<F-H(#T@)DE-4%])34%07U-E87)C
M:#HZ<VEN9VQE=&]N*"1S96%R8VA?<&%R86US*3L*"B`@("`@("`@+RH@4')E
M<&%R92!T:&4@<V5A<F-H('%U97)Y+B`J+PH@("`@("`@(&EF("@A96UP='DH
M)&]B*2D@>PH@("`@("`@("`@("`D;VQD7W%U97)Y(#T@=6YS97)I86QI>F4H
M)'-E87)C:%LG<75E<GDG72D["B`@("`@("`@("`@("1Q=65R>2`]("9N97<@
M24U07TE-05!?4V5A<F-H7U%U97)Y*"D["B`@("`@("`@("`@("1Q=65R>2T^
M:6UA<$%N9"AA<G)A>2@D;V(L("1O;&1?<75E<GDI*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<75E<GD@/2!U;G-E<FEA;&EZ92@D<V5A<F-H
M6R=Q=65R>2==*3L*("`@("`@("!]"@H@("`@("`@("\J($AO=R!D;R!W92!W
M86YT('1O('-O<G0@<F5S=6QT<S\@*B\*("`@("`@("`D<V]R=&)Y(#T@)$=,
M3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=S;W)T8GDG*3L*("`@("`@("!I
M9B`H)'-O<G1B>2`]/2!33U)45$A214%$*2!["B`@("`@("`@("`@("1S;W)T
M8GD@/2!33U)41$%413L*("`@("`@("!]"B`@("`@("`@)'-O<G1D:7(@/2`D
M1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W-O<G1D:7(G*3L*"B`@("`@
M("`@9F]R96%C:"`H)'-E87)C:%LG9F]L9&5R<R==(&%S("1V86PI('L*("`@
M("`@("`@("`@)')E<W5L=',@/2`D:6UA<%]S96%R8V@M/G-E87)C:%-O<G1-
M86EL8F]X*"1Q=65R>2P@)%]315-324].6R=I;7`G75LG<W1R96%M)UTL("1V
M86PL("1S;W)T8GDL("1S;W)T9&ER*3L*"B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<F5S=6QT<RDI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R
M97-U;'1S(&%S("1V86PR*2!["B`@("`@("`@("`@("`@("`@("`@)'-O<G1E
M9%M=(#T@)'9A;#(@+B!)35!?24187U-%4"`N("1V86P["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<V]R=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!T:&4@
M24U!4"!S96%R8V@@<75E<GD@:6X@=&AE($E-4"!S97-S:6]N+@H@("`@("H*
M("`@("`J($!P87)A;2!)34%07U-E87)C:%]1=65R>2`D<75E<GD@(%1H92!S
M96%R8V@@<75E<GD@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F;VQD
M97)S("`@("`@("`@("`@5&AE(&QI<W0@;V8@9F]L9&5R<R!T;R!S96%R8V@N
M"B`@("`@*B!`<&%R86T@87)R87D@)'-E87)C:"`@("`@("`@("`@("!4:&4@
M<V5A<F-H(&%R<F%Y('5S960@=&\@8G5I;&0@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S96%R8V@@54D@<V-R965N+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@("`@("`@("`@("`@5&AE(&QA
M8F5L('1O('5S92!F;W(@=&AE('-E87)C:`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5S=6QT<RX*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED("`@("`@("`@("`@("`@(%1H92!Q=65R>2!I9"!T;R!U<V4@
M*&]R(&5L<V4@;VYE(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A=71O;6%T:6-A;&QY(&=E;F5R871E9"DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%)E='5R;G,@=&AE('-E87)C:"!Q=65R
M>2!I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5A<F-H475E<GDH
M)'%U97)Y+"`D9F]L9&5R<RP@)'-E87)C:"P@)&QA8F5L+"`D:60@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1I9"`]("AI<U]N=6QL*"1I9"DI(#\@8F%S95]C
M;VYV97)T*&UI8W)O=&EM92@I("X@;71?<F%N9"@I+"`Q-BP@,S8I(#H@)'1H
M:7,M/E]S=')I<"@D:60I.PH@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W-E
M87)C:"==6R=Q)UU;)&ED72`](&%R<F%Y*`H@("`@("`@("`@("`G<75E<GDG
M(#T^('-E<FEA;&EZ92@D<75E<GDI+`H@("`@("`@("`@("`G9F]L9&5R<R<@
M/3X@)&9O;&1E<G,L"B`@("`@("`@("`@("=U:6EN9F\G(#T^("1S96%R8V@L
M"B`@("`@("`@("`@("=L86)E;"<@/3X@)&QA8F5L+`H@("`@("`@("`@("`G
M=F9O;&1E<B<@/3X@9F%L<V4*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D
M:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%N($E-05`@<V5A
M<F-H('%U97)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4
M:&4@<V5A<F-H('%U97)Y(&ED('1O('5S92`H8GD@9&5F875L="P@=VEL;"!U
M<V4*("`@("`J("`@("`@("`@("`@("`@("`@("!T:&4@8W5R<F5N="!)1"!S
M970@:6X@=&AE(&]B:F5C="DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%)E='5R;G,@=&AE('-E87)C:"!Q=65R>2!I9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&5L971E4V5A<F-H475E<GDH)&ED(#T@;G5L;"D*("`@('L*
M("`@("`@("`D:60@/2`H:7-?;G5L;"@D:60I*2`_("1T:&ES+3Y?:60@.B`D
M=&AI<RT^7W-T<FEP*"1I9"D["B`@("`@("`@)&ES7W9F;VQD97(@/2`A96UP
M='DH)%]315-324].6R=I;7`G75LG<V5A<F-H)UU;)W$G75LD:61=6R=V9F]L
M9&5R)UTI.PH@("`@("`@('5N<V5T*"1?4T534TE/3ELG:6UP)UU;)W-E87)C
M:"==6R=Q)UU;)&ED72D["@H@("`@("`@(&EF("@D:7-?=F9O;&1E<BD@>PH@
M("`@("`@("`@("`D=F9O;&1E<G,@/2`D=&AI<RT^7V=E=%9&;VQD97),:7-T
M*"D["B`@("`@("`@("`@('5N<V5T*"1V9F]L9&5R<ULD:61=*3L*("`@("`@
M("`@("`@)'1H:7,M/E]S879E5D9O;&1E<DQI<W0H)'9F;VQD97)S*3L*("`@
M("`@("`@("`@)'1H:7,M/E]U<&1A=&5)35!4<F5E*"=D96QE=&4G+"`D:60I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T
M:&4@<')E=FEO=7-L>2!S=&]R960@<V5A<F-H(%5)(&EN9F]R;6%T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5A<F-H('%U
M97)Y(&ED('1O('5S92`H8GD@9&5F875L="P@=VEL;"!U<V4*("`@("`J("`@
M("`@("`@("`@("`@("`@("!T:&4@8W5R<F5N="!)1"!S970@:6X@=&AE(&]B
M:F5C="DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&%R<F%Y
M(&YE8V5S<V%R>2!T;R!R96)U:6QD('1H92!S96%R8V@@54D@<&%G92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5T<FEE=F5525%U97)Y*"1I9"`](&YU;&PI
M"B`@("!["B`@("`@("`@)&ED(#T@*&ES7VYU;&PH)&ED*2D@/R`D=&AI<RT^
M7VED(#H@)'1H:7,M/E]S=')I<"@D:60I.PH@("`@("`@(')E='5R;B`H:7-S
M970H)%]315-324].6R=I;7`G75LG<V5A<F-H)UU;)W$G75LD:61=6R=U:6EN
M9F\G72DI"B`@("`@("`@("`@(#\@)$=,3T)!3%-;)VEM<"==6R=S96%R8V@G
M75LG<2==6R1I9%U;)W5I:6YF;R=="B`@("`@("`@("`@(#H@87)R87DH*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@;&%B96P@=&\@
M=7-E(&9O<B!S96%R8V@@<F5S=6QT<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9"`@5&AE('-E87)C:"!Q=65R>2!I9"!T;R!U<V4@*&)Y(&1E
M9F%U;'0L('=I;&P@=7-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@=&AE
M(&-U<G)E;G0@240@<V5T(&EN('1H92!O8FIE8W0I+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<V5A<F-H(')E<W5L=',@;&%B96PN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$QA8F5L*"1I9"`](&YU;&PI"B`@("![
M"B`@("`@("`@)&ED(#T@*&ES7VYU;&PH)&ED*2D@/R`D=&AI<RT^7VED(#H@
M)'1H:7,M/E]S=')I<"@D:60I.PH@("`@("`@(')E='5R;B`H:7-S970H)%]3
M15-324].6R=I;7`G75LG<V5A<F-H)UU;)W$G75LD:61=6R=L86)E;"==*2D*
M("`@("`@("`@("`@/R`D1TQ/0D%,4ULG:6UP)UU;)W-E87)C:"==6R=Q)UU;
M)&ED75LG;&%B96PG70H@("`@("`@("`@("`Z("<G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3V)T86EN<R!T:&4@;&ES="!O9B!V:7)T=6%L(&9O;&1E<G,@
M9F]R('1H92!C=7)R96YT('5S97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@
M;V8@=FER='5A;"!F;VQD97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T
M5D9O;&1E<DQI<W0H*0H@("`@>PH@("`@("`@("1V9F]L9&5R(#T@)$=,3T)!
M3%-;)W!R969S)UTM/F=E=%9A;'5E*"=V9F]L9&5R)RD["B`@("`@("`@:68@
M*&5M<'1Y*"1V9F]L9&5R*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@("1V9F]L9&5R(#T@0'5N<V5R:6%L:7IE
M*"1V9F]L9&5R*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V9F]L9&5R*2D@
M>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@
M("`@("1E;'0@/2!R97-E="@D=F9O;&1E<BD["B`@("`@("`@:68@*"%I<W-E
M="@D96QT6R=O8B==*2D@>PH@("`@("`@("`@("`O+R!!;')E861Y(&EN(#0N
M,2L@9F]R;6%T+@H@("`@("`@("`@("!R971U<FX@)'9F;VQD97(["B`@("`@
M("`@?0H*("`@("`@("`O+R!#;VYV97)T(&9R;VT@-"XP(&9O<FUA="!T;R`T
M+C$K(&9O<FUA="P@:68@;F5C97-S87)Y"B`@("`@("`@)&-O;G9E<G0@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1V9F]L9&5R(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`D8V]N=F5R=%LD:V5Y72`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@)W%U97)Y)R`]/B`D=F%L6R=O8B==+`H@("`@("`@
M("`@("`@("`@)V9O;&1E<G,G(#T^("1V86Q;)W-E87)C:"==6R=F;VQD97)S
M)UTL"B`@("`@("`@("`@("`@("`G=6EI;F9O)R`]/B`D=F%L6R=S96%R8V@G
M72P*("`@("`@("`@("`@("`@("=L86)E;"<@/3X@)'9A;%LG<V5A<F-H)UU;
M)W9F;VQD97)?;&%B96PG72P*("`@("`@("`@("`@("`@("=V9F]L9&5R)R`]
M/B!T<G5E"B`@("`@("`@("`@("D["B`@("`@("`@("`@('5N<V5T*"1C;VYV
M97)T6R1K97E=6R=S96%R8V@G75LG9F]L9&5R<R==+"`D8V]N=F5R=%LD:V5Y
M75LG<V5A<F-H)UU;)W9F;VQD97)?;&%B96PG72D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D8V]N=F5R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-A
M=F5S('1H92!L:7-T(&]F('9I<G1U86P@9F]L9&5R<R!F;W(@=&AE(&-U<G)E
M;G0@=7-E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@(%1H92!V:7)T=6%L(&9O;&1E<B!L:7-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V%V959&;VQD97),:7-T*"1V9F]L
M9&5R*0H@("`@>PH@("`@("`@("1'3$]"04Q36R=P<F5F<R==+3YS971686QU
M92@G=F9O;&1E<B<L('-E<FEA;&EZ92@D=F9O;&1E<BDI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D(&$@=FER='5A;"!F;VQD97(@9F]R('1H92!C=7)R
M96YT('5S97(N"B`@("`@*@H@("`@("H@0'!A<F%M($E-05!?4V5A<F-H7U%U
M97)Y("1Q=65R>2`@5&AE('-E87)C:"!Q=65R>2!O8FIE8W0N"B`@("`@*B!`
M<&%R86T@87)R87D@)&9O;&1E<G,@("`@("`@("`@("!4:&4@;&ES="!O9B!F
M;VQD97)S('1O('-E87)C:"X*("`@("`J($!P87)A;2!A<G)A>2`D<V5A<F-H
M("`@("`@("`@("`@(%1H92!S96%R8V@@87)R87D@=7-E9"!T;R!B=6EL9"!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-E
M87)C:"!522!S8W)E96XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@
M("`@("`@("`@("!4:&4@;&%B96P@=&\@=7-E(&9O<B!T:&4@<V5A<F-H"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97-U;'1S
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("`@("`@5&AE
M('9I<G1U86P@9F]L9&5R(&ED+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@=FER='5A;"!F;VQD97(@240N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9%9&;VQD97(H)'%U97)Y+"`D9F]L9&5R<RP@)'-E87)C:"P@)&QA
M8F5L+"`D:60@/2!N=6QL*0H@("`@>PH@("`@("`@("1I9"`]("1T:&ES+3YC
M<F5A=&5396%R8VA1=65R>2@D<75E<GDL("1F;VQD97)S+"`D<V5A<F-H+"`D
M;&%B96PL("1I9"D["B`@("`@("`@)%]315-324].6R=I;7`G75LG<V5A<F-H
M)UU;)W$G75LD:61=6R=V9F]L9&5R)UT@/2!T<G5E.PH@("`@("`@(&EF("@D
M=&AI<RT^7W-A=F561F]L9&5R*2!["B`@("`@("`@("`@("1V9F]L9&5R<R`]
M("1T:&ES+3Y?9V5T5D9O;&1E<DQI<W0H*3L*("`@("`@("`@("`@)'9F;VQD
M97)S6R1I9%T@/2`D7U-%4U-)3TY;)VEM<"==6R=S96%R8V@G75LG<2==6R1I
M9%T["B`@("`@("`@("`@("1T:&ES+3Y?<V%V959&;VQD97),:7-T*"1V9F]L
M9&5R<RD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?=7!D871E24U05')E
M92@G861D)RP@)&ED+"`D;&%B96PI.PH@("`@("`@(')E='5R;B`D:60["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!V:7)T=6%L('1R87-H(&9O;&1E
M<B!F;W(@=&AE(&-U<G)E;G0@=7-E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M8W)E871E5E1R87-H1F]L9&5R*"D*("`@('L*("`@("`@("`O*B!$96QE=&4@
M=&AE(&-U<G)E;G0@5FER='5A;"!4<F%S:"!F;VQD97(L(&EF(&ET(&5X:7-T
M<RX@*B\*("`@("`@("`D=G1R87-H7VED(#T@)$=,3T)!3%-;)W!R969S)UTM
M/F=E=%9A;'5E*"=V=')A<VA?:60G*3L*("`@("`@("!I9B`H(65M<'1Y*"1V
M=')A<VA?:60I*2!["B`@("`@("`@("`@("1T:&ES+3YD96QE=&5396%R8VA1
M=65R>2@D=G1R87-H7VED*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)$=,
M3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=U<V5?=G1R87-H)RDI('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E
M(%9I<G1U86P@5')A<V@@=VET:"!N97<@9F]L9&5R(&QI<W0N("HO"B`@("`@
M("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O1F]L9&5R+G!H<"<[
M"B`@("`@("`@)&EM<%]F;VQD97(@/2`F24U07T9O;&1E<CHZ<VEN9VQE=&]N
M*"D["B`@("`@("`@)&9L(#T@)&EM<%]F;VQD97(M/F9L:7-T7TE-4"@I.PH@
M("`@("`@("1F;&ES="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&9L
M(&%S("1M8F]X*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)&UB;WA;)W9A
M;"==*2D@>PH@("`@("`@("`@("`@("`@)&9L:7-T6UT@/2`D;6)O>%LG=F%L
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@87)R87E?=6YS
M:&EF="@D9FQI<W0L("=)3D)/6"<I.PH*("`@("`@("!R97%U:7)E7V]N8V4@
M24U07T)!4T4@+B`G+VQI8B])34%0+U-E87)C:"YP:'`G.PH@("`@("`@("1Q
M=65R>2`]("9N97<@24U07TE-05!?4V5A<F-H7W%U97)Y*"D["B`@("`@("`@
M)'%U97)Y+3YD96QE=&5D*'1R=64I.PH@("`@("`@("1L86)E;"`](%\H(E9I
M<G1U86P@5')A<V@B*3L*"B`@("`@("`@)'1H:7,M/E]S879E5D9O;&1E<B`]
M(&9A;'-E.PH@("`@("`@(&EF("AE;7!T>2@D=G1R87-H7VED*2D@>PH@("`@
M("`@("`@("`D=G1R87-H7VED(#T@)'1H:7,M/F%D9%9&;VQD97(H)'%U97)Y
M+"`D9FQI<W0L(&%R<F%Y*"DL("1L86)E;"D["B`@("`@("`@("`@("1'3$]"
M04Q36R=P<F5F<R==+3YS971686QU92@G=G1R87-H7VED)RP@)'9T<F%S:%]I
M9"D["B`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W-E87)C:"==6R=V
M=')A<VA?:60G72`]("1V=')A<VA?:60["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'9T<F%S:%]I9"`]("1T:&ES+3YA9&161F]L9&5R*"1Q=65R
M>2P@)&9L:7-T+"!A<G)A>2@I+"`D;&%B96PL("1V=')A<VA?:60I.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7W-A=F561F]L9&5R(#T@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=VAE=&AE<B!A('9I<G1U
M86P@9F]L9&5R($E$(&ES('1H92!6:7)T=6%L(%1R87-H($9O;&1E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E87)C:"!Q=65R
M>2!I9"!T;R!U<V4@*&)Y(&1E9F%U;'0L('=I;&P@=7-E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@=&AE(&-U<G)E;G0@240@<V5T(&EN('1H92!O8FIE
M8W0I+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T
M:&4@=FER=71A;"!F;VQD97(@240@:7,@=&AE(%9I<G1U86P@5')A<V@*("`@
M("`J("`@("`@("`@("`@("`@("`@9F]L9&5R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!I<U94<F%S:$9O;&1E<B@D:60@/2!N=6QL*0H@("`@>PH@("`@("`@
M("1I9"`]("AI<U]N=6QL*"1I9"DI(#\@)'1H:7,M/E]I9"`Z("1T:&ES+3Y?
M<W1R:7`H)&ED*3L*("`@("`@("!R971U<FX@*"1I9"`]/2`D1TQ/0D%,4ULG
M<')E9G,G72T^9V5T5F%L=64H)W9T<F%S:%]I9"<I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($%D9"!A('9I<G1U86P@24Y"3U@@9F]L9&5R(&9O<B!T:&4@
M8W5R<F5N="!U<V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5624Y"
M3UA&;VQD97(H*0H@("`@>PH@("`@("`@("\J($EN:71I86QI>F4@24U07U1R
M964N("HO"B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O
M24U!4"]4<F5E+G!H<"<["B`@("`@("`@)&EM<'1R964@/2`F24U07U1R964Z
M.G-I;F=L971O;B@I.PH*("`@("`@("`O*B!$96QE=&4@=&AE(&-U<G)E;G0@
M5FER='5A;"!4<F%S:"!F;VQD97(L(&EF(&ET(&5X:7-T<RX@*B\*("`@("`@
M("`D=FEN8F]X7VED(#T@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=V
M:6YB;WA?:60G*3L*("`@("`@("!I9B`H(65M<'1Y*"1V:6YB;WA?:60I*2![
M"B`@("`@("`@("`@("1T:&ES+3YD96QE=&5396%R8VA1=65R>2@D=FEN8F]X
M7VED*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!6:7)T=6%L($E.
M0D]8('=I=&@@;F%V7W!O;&P@;&ES="X@*B\*("`@("`@("`D9FP@/2`D:6UP
M=')E92T^9V5T4&]L;$QI<W0H*3L*("`@("`@("`D9FQI<W0@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)&9L*2!A<R`D;6)O>"D@
M>PH@("`@("`@("`@("`D9FQI<W1;72`]("1M8F]X.PH@("`@("`@('T*"B`@
M("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O24U!4"]396%R
M8V@N<&AP)SL*("`@("`@("`D<75E<GD@/2`F;F5W($E-4%])34%07U-E87)C
M:%]Q=65R>2@I.PH@("`@("`@("1Q=65R>2T^<V5E;BAF86QS92D["B`@("`@
M("`@)'%U97)Y+3YD96QE=&5D*&9A;'-E*3L*("`@("`@("`D;&%B96P@/2!?
M*")6:7)T=6%L($E.0D]8(BD["@H@("`@("`@("1T:&ES+3Y?<V%V959&;VQD
M97(@/2!F86QS93L*("`@("`@("!I9B`H96UP='DH)'9I;F)O>%]I9"DI('L*
M("`@("`@("`@("`@)'9T<F%S:%]I9"`]("1T:&ES+3YA9&161F]L9&5R*"1Q
M=65R>2P@)&9L:7-T+"!A<G)A>2@I+"`D;&%B96PI.PH@("`@("`@("`@("`D
M1TQ/0D%,4ULG<')E9G,G72T^<V5T5F%L=64H)W9I;F)O>%]I9"<L("1V:6YB
M;WA?:60I.PH@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=S96%R8V@G
M75LG=FEN8F]X7VED)UT@/2`D=FEN8F]X7VED.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1V=')A<VA?:60@/2`D=&AI<RT^861D5D9O;&1E<B@D
M<75E<GDL("1F;&ES="P@87)R87DH*2P@)&QA8F5L+"`D=FEN8F]X7VED*3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]S879E5D9O;&1E<B`]('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('=H971H97(@82!V
M:7)T=6%L(&9O;&1E<B!)1"!I<R!T:&4@5FER='5A;"!)3D)/6"!&;VQD97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S96%R8V@@
M<75E<GD@:60@=&\@=7-E("AB>2!D969A=6QT+"!W:6QL('5S90H@("`@("H@
M("`@("`@("`@("`@("`@("`@('1H92!C=7)R96YT($E$('-E="!I;B!T:&4@
M;V)J96-T*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=&AE('9I<G5T86P@9F]L9&5R($E$(&ES('1H92!6:7)T=6%L($E.0D]8
M"B`@("`@*B`@("`@("`@("`@("`@("`@(&9O;&1E<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-624Y"3UA&;VQD97(H)&ED(#T@;G5L;"D*("`@('L*("`@
M("`@("`D:60@/2`H:7-?;G5L;"@D:60I*2`_("1T:&ES+3Y?:60@.B`D=&AI
M<RT^7W-T<FEP*"1I9"D["B`@("`@("`@<F5T=7)N("@D:60@/3T@)$=,3T)!
M3%-;)W!R969S)UTM/F=E=%9A;'5E*"=V:6YB;WA?:60G*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!)<R!T:&4@8W5R<F5N="!A8W1I=F4@9F]L9&5R(&%N
M(&5D:71A8FQE(%9I<G1U86P@1F]L9&5R/PH@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ED("!4:&4@<V5A<F-H('%U97)Y(&ED('1O('5S92`H8GD@
M9&5F875L="P@=VEL;"!U<V4*("`@("`J("`@("`@("`@("`@("`@("`@("!T
M:&4@8W5R<F5N="!)1"!S970@:6X@=&AE(&]B:F5C="DN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!C=7)R96YT(&9O;&1E
M<B!I<R!B;W1H(&$@=FER='5A;"!F;VQD97(*("`@("`J("`@("`@("`@("`@
M("`@("`@86YD(&-A;B!B92!E9&ET960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES161I=&%B;&561F]L9&5R*"1I9"`](&YU;&PI"B`@("!["B`@("`@("`@
M)&ED(#T@*&ES7VYU;&PH)&ED*2D@/R`D=&AI<RT^7VED(#H@)'1H:7,M/E]S
M=')I<"@D:60I.PH@("`@("`@(')E='5R;B`H)'1H:7,M/FES5D9O;&1E<B@D
M:60I("8F("$D=&AI<RT^:7-65')A<VA&;VQD97(H)&ED*2`F)B`A)'1H:7,M
M/FES5DE.0D]81F]L9&5R*"1I9"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&$@;&ES="!O9B!)1',@86YD('%U97)Y(&QA8F5L<RP@<V]R=&5D
M(&)Y('1H92!L86)E;"X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M=F9O;&1E<B`@268@=')U92P@;VYL>2!R971U<FX@5FER='5A;"!&;VQD97)S
M/PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y('=I=&@@
M=&AE(&9O;&1E<B!)1',@87,@=&AE(&ME>2!A;F0@=&AE(&QA8F5L<PH@("`@
M("H@("`@("`@("`@("`@("`@87,@=&AE('9A;'5E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!L:7-T475E<FEE<R@D=F9O;&1E<B`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1V9F]L9&5R<R`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@
M*"1?4T534TE/3ELG:6UP)UU;)W-E87)C:"==6R=Q)UT@87,@)&ME>2`]/B`D
M=F%L*2!["B`@("`@("`@("`@(&EF("@A)'9F;VQD97(@?'P@(65M<'1Y*"1V
M86Q;)W9F;VQD97(G72DI('L*("`@("`@("`@("`@("`@("1V9F]L9&5R<ULD
M:V5Y72`]("1T:&ES+3YG971,86)E;"@D:V5Y*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!N871C87-E<V]R="@D=F9O;&1E<G,I.PH*("`@
M("`@("!R971U<FX@)'9F;VQD97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!L:7-T(&]F('-E87)C:&%B;&4@9F]L9&5R<R!F;W(@=&AE(&=I
M=F5N('-E87)C:"!Q=65R>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9"`@5&AE('-E87)C:"!Q=65R>2!I9"!T;R!U<V4@*&)Y(&1E9F%U;'0L
M('=I;&P@=7-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@=&AE(&-U<G)E
M;G0@240@<V5T(&EN('1H92!O8FIE8W0I+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%1H92!L:7-T(&]F('-E87)C:&%B;&4@9F]L9&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4V5A<F-H1F]L9&5R<R@D:60@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1I9"`]("AI<U]N=6QL*"1I9"DI(#\@)'1H:7,M
M/E]I9"`Z("1T:&ES+3Y?<W1R:7`H)&ED*3L*("`@("`@("!R971U<FX@*&ES
M<V5T*"1?4T534TE/3ELG:6UP)UU;)W-E87)C:"==6R=Q)UU;)&ED75LG9F]L
M9&5R<R==*2D@/R`D7U-%4U-)3TY;)VEM<"==6R=S96%R8V@G75LG<2==6R1I
M9%U;)V9O;&1E<G,G72`Z(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@;&EN:R!T;R!E9&ET(&$@9VEV96X@<V5A<F-H('%U97)Y
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5A<F-H
M('%U97)Y(&ED('1O('5S92`H8GD@9&5F875L="P@=VEL;"!U<V4*("`@("`J
M("`@("`@("`@("`@("`@("`@("!T:&4@8W5R<F5N="!)1"!S970@:6X@=&AE
M(&]B:F5C="DN"B`@("`@*@H@("`@("H@0')E<G1U<FX@<W1R:6YG("!4:&4@
M55),('1O('1H92!S96%R8V@@<&%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M961I=%523"@D:60@/2!N=6QL*0H@("`@>PH@("`@("`@("1I9"`]("AI<U]N
M=6QL*"1I9"DI(#\@)'1H:7,M/E]I9"`Z("1T:&ES+3Y?<W1R:7`H)&ED*3L*
M("`@("`@("!R971U<FX@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G<V5A<F-H+G!H<"<I+"!A<G)A>2@G961I=%]Q=65R>2<@
M/3X@)&ED*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&EN
M:R!T;R!D96QE=&4@82!G:79E;B!S96%R8V@@<75E<GDN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S96%R8V@@<75E<GD@:60@=&\@
M=7-E("AB>2!D969A=6QT+"!W:6QL('5S90H@("`@("H@("`@("`@("`@("`@
M("`@("`@('1H92!C=7)R96YT($E$('-E="!I;B!T:&4@;V)J96-T*2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%523"!T;R!A;&QO=R!D
M96QE=&EO;B!O9B!T:&4@<V5A<F-H('%U97)Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D96QE=&554DPH)&ED(#T@;G5L;"D*("`@('L*("`@("`@("`D:60@
M/2`H:7-?;G5L;"@D:60I*2`_("1T:&ES+3Y?:60@.B`D=&AI<RT^7W-T<FEP
M*"1I9"D["B`@("`@("`@<F5T=7)N(%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D
M93HZ87!P;&EC871I;VY5<FPH)V9O;&1E<G,N<&AP)RDL(&%R<F%Y*"=A8W1I
M;VY)1"<@/3X@)V1E;&5T95]S96%R8VA?<75E<GDG+"`G<75E<GEI9"<@/3X@
M)&ED*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&4@9VEV96X@;6%I
M;&)O>"!A('-E87)C:"!M86EL8F]X/PH@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED("!4:&4@<V5A<F-H('%U97)Y(&ED('1O('5S92`H8GD@9&5F
M875L="P@=VEL;"!U<V4*("`@("`J("`@("`@("`@("`@("`@("`@("!T:&4@
M8W5R<F5N="!)1"!S970@:6X@=&AE(&]B:F5C="DN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!7:&5T:&5R('1H92!G:79E;B!M86EL8F]X(&YA
M;64@:7,@82!S96%R8V@@;6%I;&)O>"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M:7-396%R8VA-8F]X*"1I9"`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N
M("AI<U]N=6QL*"1I9"DI(#\@(65M<'1Y*"1T:&ES+3Y?:60I(#H@:7-S970H
M)%]315-324].6R=I;7`G75LG<V5A<F-H)UU;)W$G75LD=&AI<RT^7W-T<FEP
M*"1I9"E=*3L*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H92!G:79E;B!M
M86EL8F]X(&$@=FER='5A;"!F;VQD97(_"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:60@(%1H92!S96%R8V@@<75E<GD@:60@=&\@=7-E("AB>2!D
M969A=6QT+"!W:6QL('5S90H@("`@("H@("`@("`@("`@("`@("`@("`@('1H
M92!C=7)R96YT($E$('-E="!I;B!T:&4@;V)J96-T*2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AE(&=I=F5N(&UA:6QB;W@@
M;F%M92!I<R!A('9I<G1U86P@9F]L9&5R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I<U9&;VQD97(H)&ED(#T@;G5L;"D*("`@('L*("`@("`@("`D:60@/2`H
M:7-?;G5L;"@D:60I*2`_("1T:&ES+3Y?:60@.B`D=&AI<RT^7W-T<FEP*"1I
M9"D["B`@("`@("`@<F5T=7)N("@A96UP='DH)%]315-324].6R=I;7`G75LG
M<V5A<F-H)UU;)W$G75LD:61=6R=V9F]L9&5R)UTI*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@240@9F]R('1H92!S96%R8V@@;6%I;&)O>"P@
M:68@=V4@87)E(&-U<G)E;G1L>2!I;B!A('-E87)C:`H@("`@("H@;6%I;&)O
M>"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<V5A<F-H($E$
M(&EF(&EN(&$@;6%I;&)O>"P@96QS92!F86QS92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5A<F-H36)O>$E$*"D*("`@('L*("`@("`@("!R971U<FX@*"%I
M<U]N=6QL*"1T:&ES+3Y?:60I*2`_("1T:&ES+3Y?:60@.B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-T<FEP('1H92!I9&5N=&EF>6EN9R!L86)E
M;"!F<F]M(&$@;6%I;&)O>"!)1"X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&UA
M:6QB;W@@<75E<GD@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!V:7)T=6%L(&9O;&1E<B!)1"P@=VET:"!A;GD@24U0('-P96-I9FEC
M(&ED96YT:69Y:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@:6YF;W)M871I
M;VX@<W1R:7!P960@;V9F+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<W1R:7`H
M)&ED*0H@("`@>PH@("`@("`@(')E='5R;B`H<W1R<&]S*"1I9"P@24U07U-%
M05)#2%]-0D]8*2`]/3T@,"D@/R!S=6)S='(H)&ED+"!S=')L96XH24U07U-%
M05)#2%]-0D]8*2D@.B`D:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@=&AE(&)A<V4@<V5A<F-H(&9I96QD<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@8F%S92!S96%R8V@@9FEE;&1S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S96%R8VA&:65L9',H*0H@("`@>PH@("`@("`@(')E='5R
M;B!A<G)A>2@*("`@("`@("`@("`@)V9R;VTG(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)VQA8F5L)R`]/B!?*")&<F]M(BDL"B`@("`@("`@("`@("`@
M("`G='EP92<@/3X@24U07U-%05)#2%](14%$15(*("`@("`@("`@("`@*2P*
M("`@("`@("`@("`@)W1O)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=L
M86)E;"<@/3X@7R@B5&\B*2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B!)
M35!?4T5!4D-(7TA%041%4@H@("`@("`@("`@("`I+`H@("`@("`@("`@("`G
M8V,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")#
M8R(I+`H@("`@("`@("`@("`@("`@)W1Y<&4G(#T^($E-4%]314%20TA?2$5!
M1$52"B`@("`@("`@("`@("DL"B`@("`@("`@("`@("=B8V,G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")"8V,B*2P*("`@("`@
M("`@("`@("`@("=T>7!E)R`]/B!)35!?4T5!4D-(7TA%041%4@H@("`@("`@
M("`@("`I+`H@("`@("`@("`@("`G<W5B:F5C="<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-U8FIE8W0B*2P*("`@("`@("`@
M("`@("`@("=T>7!E)R`]/B!)35!?4T5!4D-(7TA%041%4@H@("`@("`@("`@
M("`I+`H@("`@("`@("`@("`G8F]D>2<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("=L86)E;"<@/3X@7R@B0F]D>2(I+`H@("`@("`@("`@("`@("`G='EP
M92<@/3X@24U07U-%05)#2%]"3T19"B`@("`@("`@("`@("DL"B`@("`@("`@
M("`@("=T97AT)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@)VQA8F5L)R`]
M/B!?*")%;G1I<F4@365S<V%G92(I+`H@("`@("`@("`@("`@("`G='EP92<@
M/3X@24U07U-%05)#2%]415A4"B`@("`@("`@("`@("DL"B`@("`@("`@("`@
M("=R96-E:79E9%]O;B<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G;&%B
M96PG(#T^(%\H(E)E8V5I=F5D($]N(BDL"B`@("`@("`@("`@("`@("`G='EP
M92<@/3X@24U07U-%05)#2%]$051%"B`@("`@("`@("`@("DL"B`@("`@("`@
M("`@("=R96-E:79E9%]U;G1I;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`G;&%B96PG(#T^(%\H(E)E8V5I=F5D(%5N=&EL(BDL"B`@("`@("`@("`@
M("`@("`G='EP92<@/3X@24U07U-%05)#2%]$051%"B`@("`@("`@("`@("DL
M"B`@("`@("`@("`@("=R96-E:79E9%]S:6YC92<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`G;&%B96PG(#T^(%\H(E)E8V5I=F5D(%-I;F-E(BDL"B`@
M("`@("`@("`@("`@("`G='EP92<@/3X@24U07U-%05)#2%]$051%"B`@("`@
M("`@("`@("D*("`@("`@("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D
M871E($E-05!?5')E92!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-T:6]N("!%
M:71H97(@)V1E;&5T92<@;W(@)V%D9"<N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9"`@("`@(%1H92!Q=65R>2!)1"!T;R!U<&1A=&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1L86)E;"`@($EF("1A8W1I;VX@/2`G861D)RP@=&AE(&QA
M8F5L('1O('5S92!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@('%U97)Y($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=7!D871E24U0
M5')E92@D86-T:6]N+"`D:60L("1L86)E;"`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3Y?:6UP=')E92DI('L*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O24U!4"]4<F5E+G!H<"<[
M"B`@("`@("`@("`@("1T:&ES+3Y?:6UP=')E92`]("9)35!?5')E93HZ<VEN
M9VQE=&]N*"D["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1A8W1I;VXI
M('L*("`@("`@("!C87-E("=D96QE=&4G.@H@("`@("`@("`@("`D=&AI<RT^
M7VEM<'1R964M/F1E;&5T92@D:60I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92`G861D)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7!T<F5E
M+3YI;G-E<G161F]L9&5R<RAA<G)A>2@D:60@/3X@)&QA8F5L*2D["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O;&EB+V%P:2YP:'``````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#(Q,3$W`#$P-#$W,S8R-S8V`#`Q-S(T-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@24U0(&5X=&5R;F%L($%022!I;G1E<F9A8V4N"B`J"B`J(%1H:7,@
M9FEL92!D969I;F5S($E-4"=S(&5X=&5R;F%L($%022!I;G1E<F9A8V4N($]T
M:&5R(&%P<&QI8V%T:6]N<PH@*B!C86X@:6YT97)A8W0@=VET:"!)35`@=&AR
M;W5G:"!T:&ES($%022X*("H*("H@)$AO<F1E.B!I;7`O;&EB+V%P:2YP:'`L
M=B`Q+CDT+C$P+C$R(#(P,#4O,3`O,3@@,3(Z,3,Z,S$@:F%N($5X<"`D"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G
M<&PN:'1M;"X*("H*("H@0'!A8VMA9V4@24U0"B`J+PH*)%]S97)V:6-E<ULG
M<&5R;7,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@("`G
M='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG*3L*"B1?<V5R=FEC
M97-;)V%U=&AE;G1I8V%T92==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R
M87DH)W5S97))1"<@/3X@)W-T<FEN9R<L("=C<F5D96YT:6%L<R<@/3X@)WMU
M<FXZ:&]R9&5]:&%S:"<L("=P87)A;7,G(#T^("=[=7)N.FAO<F1E?6AA<V@G
M*2P*("`@("=C:&5C:W!E<FUS)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G
M8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)V=E=%-T<F5A;2==(#T@87)R87DH
M"B`@("`G87)G<R<@/3X@87)R87DH)VUA:6QB;W@G(#T^("=S=')I;F<G+"`G
M9FQA9W,G(#T^("=I;G0G*2P*("`@("=T>7!E)R`]/B`G<F5S;W5R8V4G"BD[
M"@HD7W-E<G9I8V5S6R=C;VUP;W-E)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]
M/B!A<G)A>2@G87)G<R<@/3X@)WMU<FXZ:&]R9&5]:&%S:"<L("=E>'1R82<@
M/3X@)WMU<FXZ:&]R9&5]:&%S:"<I+`H@("`@)W1Y<&4G(#T^("=S=')I;F<G
M"BD["@HD7W-E<G9I8V5S6R=B871C:$-O;7!O<V4G72`](&%R<F%Y*`H@("`@
M)V%R9W,G(#T^(&%R<F%Y*"=A<F=S)R`]/B`G>W5R;CIH;W)D97UH87-H)RP@
M)V5X=')A)R`]/B`G>W5R;CIH;W)D97UH87-H)RDL"B`@("`G='EP92<@/3X@
M)W-T<FEN9R<**3L*"B1?<V5R=FEC97-;)V9O;&1E<FQI<W0G72`](&%R<F%Y
M*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@("`G='EP92<@/3X@)WMU<FXZ
M:&]R9&5]<W1R:6YG07)R87DG"BD["@HD7W-E<G9I8V5S6R=C<F5A=&5&;VQD
M97(G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=F;VQD97(G(#T^
M("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G<W1R:6YG)PHI.PH*)%]S97)V
M:6-E<ULG<V5R=F5R)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@I
M+`H@("`@)W1Y<&4G(#T^("=S=')I;F<G"BD["@II9B`H(65M<'1Y*"1?4T53
M4TE/3ELG:6UP)UU;)V%D;6EN)UTI*2!["B`@("`D7W-E<G9I8V5S6R=U<V5R
M3&ES="==(#T@87)R87DH"B`@("`@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E
M?7-T<FEN9T%R<F%Y)PH@("`@*3L*"B`@("`D7W-E<G9I8V5S6R=A9&15<V5R
M)UT@/2!A<G)A>2@*("`@("`@("`G87)G<R<@/3X@87)R87DH)W5S97))9"<@
M/3X@)W-T<FEN9R<L("=C<F5D96YT:6%L<R<@/3X@)WMU<FXZ:&]R9&5]:&%S
M:"<I"B`@("`I.PH*("`@("1?<V5R=FEC97-;)W)E;6]V955S97(G72`](&%R
M<F%Y*`H@("`@("`@("=A<F=S)R`]/B!A<G)A>2@G=7-E<DED)R`]/B`G<W1R
M:6YG)RP@)V-R961E;G1I86QS)R`]/B`G>W5R;CIH;W)D97UH87-H)RD*("`@
M("D["GT*"@IF=6YC=&EO;B!?:6UP7W!E<FUS*"D*>PH@("`@)'!E<FUS(#T@
M87)R87DH*3L*"B`@("`D<&5R;7-;)W1R964G75LG:6UP)UU;)V-R96%T95]F
M;VQD97)S)UT@/2!F86QS93L*("`@("1P97)M<ULG=&ET;&4G75LG:6UP.F-R
M96%T95]F;VQD97)S)UT@/2!?*")!;&QO=R!&;VQD97(@0W)E871I;VX_(BD[
M"B`@("`D<&5R;7-;)W1Y<&4G75LG:6UP.F-R96%T95]F;VQD97)S)UT@/2`G
M8F]O;&5A;B<["B`@("`D<&5R;7-;)W1R964G75LG:6UP)UU;)VUA>%]F;VQD
M97)S)UT@/2!F86QS93L*("`@("1P97)M<ULG=&ET;&4G75LG:6UP.FUA>%]F
M;VQD97)S)UT@/2!?*")-87AI;75M($YU;6)E<B!O9B!&;VQD97)S(BD["B`@
M("`D<&5R;7-;)W1Y<&4G75LG:6UP.FUA>%]F;VQD97)S)UT@/2`G:6YT)SL*
M"B`@("!R971U<FX@)'!E<FUS.PI]"@HO*BH*("H@5$]$3PH@*@H@*B!`<&%R
M86T@<W1R:6YG("1U<V5R240@("`@("`@5$]$3PH@*B!`<&%R86T@87)R87D@
M("1C<F5D96YT:6%L<R`@5$]$3PH@*B!`<&%R86T@87)R87D@("1P87)A;7,@
M("`@("`@5$]$3PH@*@H@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@24U0
M(&%U=&AE;G1I8V%T:6]N('=A<R!S=6-C97-S9G5L+@H@*B\*9G5N8W1I;VX@
M7VEM<%]A=71H96YT:6-A=&4H)'5S97))1"P@)&-R961E;G1I86QS+"`D<&%R
M86US*0I["B`@("`D1TQ/0D%,4ULG875T:&5N=&EC871I;VXG72`]("=N;VYE
M)SL*("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O8F%S
M92YP:'`G.PH*("`@(&EF("@A96UP='DH)'!A<F%M<ULG<V5R=F5R)UTI*2![
M"B`@("`@("`@)'-E<G9E<B`]("1P87)A;7-;)W-E<G9E<B==.PH@("`@?2!E
M;'-E('L*("`@("`@("!R97%U:7)E($E-4%]"05-%("X@)R]C;VYF:6<O<V5R
M=F5R<RYP:'`G.PH@("`@("`@(&9O<F5A8V@@*"1S97)V97)S(&%S("1K97D@
M/3X@)&-U<E-E<G9E<BD@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1S97)V
M97(I("8F('-U8G-T<B@D:V5Y+"`P+"`Q*2`A/2`G7R<I('L*("`@("`@("`@
M("`@("`@("1S97)V97(@/2`D:V5Y.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("A)35`Z.FES4')E9F5R<F5D4V5R=F5R*"1C=7)397)V97(L("1K
M97DI*2!["B`@("`@("`@("`@("`@("`D<V5R=F5R(#T@)&ME>3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+U-E<W-I;VXN
M<&AP)SL*("`@(&EF("A)35!?4V5S<VEO;CHZ8W)E871E4V5S<VEO;B@D=7-E
M<DE$+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL("1S97)V97(I*2!["B`@
M("`@("`@9VQO8F%L("1I;7`["B`@("`@("`@)&5N=')Y(#T@<W!R:6YT9B@G
M3&]G:6X@<W5C8V5S<R!F;W(@)7,@6R5S72!T;R![)7,Z)7-])RP@)&EM<%LG
M=6YI<75S97(G72P@)%]315)615);)U)%34]415]!1$12)UTL("1I;7!;)W-E
M<G9E<B==+"`D:6UP6R=P;W)T)UTI.PH@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"1E;G1R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U].3U1)
M0T4I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(')E='5R;B!F
M86QS93L*?0H*+RHJ"B`J($%T=&5M<'1S('1O(&%U=&AE;G1I8V%T92!V:6$@
M24U0(&%N9"!R971U<FX@86X@24U!4"!S=')E86TN"B`J"B`J($!P87)A;2!S
M=')I;F<@)&UA:6QB;W@@(%1H92!M86EL8F]X(&YA;64N"B`J($!P87)A;2!I
M;G0@)&9L86=S("`@("`@($E-05`@8V]N;F5C=&EO;B!F;&%G<RX*("H*("H@
M0')E='5R;B!M:7AE9"`@06X@24U!4"!R97-O=7)C92!O;B!S=6-C97-S+"!F
M86QS92!O;B!F86EL=7)E+@H@*B\*9G5N8W1I;VX@7VEM<%]G9713=')E86TH
M)&UA:6QB;W@@/2!N=6QL+"`D9FQA9W,@/2`P*0I["B`@("`D1TQ/0D%,4ULG
M875T:&5N=&EC871I;VXG72`]("=N;VYE)SL*("`@(')E<75I<F5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH*("`@(&EF("A)35`Z
M.F-H96-K075T:&5N=&EC871I;VXH3U!?2$%,1D]014XL('1R=64I(#T]/2!T
M<G5E*2!["B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O
M24U!4"YP:'`G.PH@("`@("`@("1I;6%P(#T@)DE-4%])34%0.CIS:6YG;&5T
M;VXH*3L*("`@("`@("!I9B`H)&EM87`M/F-H86YG94UB;W@H)&UA:6QB;W@L
M("1F;&%G<RDI('L*("`@("`@("`@("`@<F5T=7)N("1?4T534TE/3ELG:6UP
M)UU;)W-T<F5A;2==.PH@("`@("`@('T*("`@('T*"B`@("!R971U<FX@9F%L
M<V4["GT*"B\J*@H@*B!2971U<FYS(&$@8V]M<&]S92!W:6YD;W<@;&EN:RX*
M("H*("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D87)G<R`@($QI<W0@;V8@87)G
M=6UE;G1S('1O('!A<W,@=&\@8V]M<&]S92YP:'`N"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!)9B!T:&ES(&ES('!A<W-E9"!I;B!A<R!A('-T
M<FEN9RP@:70@=VEL;"!B90H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<&%R<V5D(&%S(&$@=&]A9&1R97-S/W-U8FIE8W0]9F]O)F-C/6-C861D
M<F5S<PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&UA:6QT;RUS
M='EL92D@<W1R:6YG+@H@*B!`<&%R86T@87)R87D@)&5X=')A("`@("`@("`@
M2&%S:"!O9B!E>'1R82P@;F]N+7-T86YD87)D(&%R9W5M96YT<R!T;R!P87-S
M('1O"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VUP;W-E+G!H
M<"X*("H*("H@0')E='5R;B!S=')I;F<@(%1H92!L:6YK('1O('1H92!M97-S
M86=E(&-O;7!O<VET:6]N('-C<F5E;BX*("HO"F9U;F-T:6]N(%]I;7!?8V]M
M<&]S92@D87)G<R`](&%R<F%Y*"DL("1E>'1R82`](&%R<F%Y*"DI"GL*("`@
M("1L:6YK(#T@7VEM<%]B871C:$-O;7!O<V4H87)R87DH)&%R9W,I+"!A<G)A
M>2@D97AT<F$I*3L*("`@(')E='5R;B`D;&EN:ULP73L*?0H*+RHJ"B`J(%)E
M='5R;B!A(&QI<W0@;V8@8V]M<&]S92!W:6YD;W<@;&EN:W,N"B`J"B`J($!P
M87)A;2!M:7AE9"`D87)G<R`@($QI<W0@;V8@;&ES=',@;V8@87)G=6UE;G1S
M('1O('!A<W,@=&\@8V]M<&]S92YP:'`N($EF"B`J("`@("`@("`@("`@("`@
M("`@("`@('1H92!L:7-T<R!A<F4@<&%S<V5D(&EN(&%S('-T<FEN9W,L('1H
M97D@=VEL;"!B92!P87)S960*("H@("`@("`@("`@("`@("`@("`@("`@87,@
M=&]A9&1R97-S/W-U8FIE8W0]9F]O)F-C/6-C861D<F5S<R`H;6%I;'1O+7-T
M>6QE*0H@*B`@("`@("`@("`@("`@("`@("`@("!S=')I;F=S+@H@*B!`<&%R
M86T@87)R87D@)&5X=')A("!,:7-T(&]F(&AA<VAE<R!O9B!E>'1R82P@;F]N
M+7-T86YD87)D(&%R9W5M96YT<R!T;R!P87-S"B`J("`@("`@("`@("`@("`@
M("`@("`@('1O(&-O;7!O<V4N<&AP+@H@*@H@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&QI<W0@;V8@;&EN:W,@=&\@=&AE(&UE<W-A9V4@8V]M<&]S:71I;VX@
M<V-R965N+@H@*B\*9G5N8W1I;VX@7VEM<%]B871C:$-O;7!O<V4H)&%R9W,@
M/2!A<G)A>2@I+"`D97AT<F$@/2!A<G)A>2@I*0I["B`@("!G;&]B86P@)'!R
M969S.PH*("`@("1'3$]"04Q36R=A=71H96YT:6-A=&EO;B==(#T@)VYO;F4G
M.PH@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E
M+G!H<"<["@H@("`@)&QI;FMS(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1A
M<F=S(&%S("1I(#T^("1A<F<I('L*("`@("`@("`D;&EN:W-;)&E=(#T@24U0
M.CIC;VUP;W-E3&EN:R@D87)G+"!I<W-E="@D97AT<F%;)&E=*2`_("1E>'1R
M85LD:5T@.B!N=6QL*3L*("`@('T*"B`@("!R971U<FX@)&QI;FMS.PI]"@HO
M*BH*("H@4F5T=7)N<R!T:&4@;&ES="!O9B!F;VQD97)S+@H@*@H@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!)34%0(&9O;&1E<G,N"B`J+PIF=6YC
M=&EO;B!?:6UP7V9O;&1E<FQI<W0H*0I["B`@("`D1TQ/0D%,4ULG875T:&5N
M=&EC871I;VXG72`]("=N;VYE)SL*("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O8F%S92YP:'`G.PH*("`@("1R97-U;'0@/2!F86QS
M93L*"B`@("!I9B`H24U0.CIC:&5C:T%U=&AE;G1I8V%T:6]N*$]07TA!3$9/
M4$5.+"!T<G5E*2`]/3T@=')U92D@>PH@("`@("`@(&EF("@D7U-%4U-)3TY;
M)VEM<"==6R=B87-E7W!R;W1O8V]L)UT@/3T@)W!O<#,G*2!["@H@("`@("`@
M("`@("`D<F5S=6QT(#T@87)R87DH)TE.0D]8)R`]/B!A<G)A>2@G=F%L)R`]
M/B`G24Y"3U@G+"`G;&%B96PG(#T^("=)3D)/6"<L("=A8F)R978G(#T^("=)
M3D)/6"<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@24U07T)!4T4@+B`G+VQI8B]&;VQD97(N<&AP)SL*("`@("`@("`@
M("`@)&EM<%]F;VQD97(@/2`F24U07T9O;&1E<CHZ<VEN9VQE=&]N*"D["B`@
M("`@("`@("`@("1R97-U;'0@/2`D:6UP7V9O;&1E<BT^9FQI<W1?24U0*"D[
M"B`@("`@("`@?0H@("`@?0H*("`@(')E='5R;B`D<F5S=6QT.PI]"@HO*BH*
M("H@0W)E871E<R!A(&YE=R!F;VQD97(N"B`J"B`J($!P87)A;2!S=')I;F<@
M)&9O;&1E<B`@5&AE(%541C<M24U!4"!E;F-O9&5D(&YA;64@;V8@=&AE(&9O
M;&1E<B!T;R!C<F5A=&4N"B`J"B`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L
M;"!F;VQD97(@;F%M92!C<F5A=&5D(&]N('-U8V-E<W,L(&%N(&5M<'1Y('-T
M<FEN9PH@*B`@("`@("`@("`@("`@("`@;VX@9F%I;'5R92X*("HO"F9U;F-T
M:6]N(%]I;7!?8W)E871E1F]L9&5R*"1F;VQD97(I"GL*("`@("1'3$]"04Q3
M6R=A=71H96YT:6-A=&EO;B==(#T@)VYO;F4G.PH@("`@<F5Q=6ER95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R]B87-E+G!H<"<["B`@("!R97%U:7)E
M7V]N8V4@24U07T)!4T4@+B`G+VQI8B]&;VQD97(N<&AP)SL*"B`@("`D<F5S
M=6QT(#T@9F%L<V4["@H@("`@:68@*$E-4#HZ8VAE8VM!=71H96YT:6-A=&EO
M;BA/4%](04Q&3U!%3BP@=')U92D@/3T]('1R=64I('L*("`@("`@("`D:6UP
M7V9O;&1E<B`]("9)35!?1F]L9&5R.CIS:6YG;&5T;VXH*3L*("`@("`@("`D
M<F5S=6QT(#T@)&EM<%]F;VQD97(M/F-R96%T92@D9F]L9&5R+"`D1TQ/0D%,
M4ULG<')E9G,G72T^9V5T5F%L=64H)W-U8G-C<FEB92<I*3L*("`@('T*"B`@
M("!R971U<FX@*&5M<'1Y*"1R97-U;'0I*2`_("<G(#H@)&9O;&1E<CL*?0H*
M+RHJ"B`J(%)E='5R;G,@=&AE(&-U<G)E;G1L>2!L;V=G960@;VX@24U!4"!S
M97)V97(N"B`J"B`J($!R971U<FX@<W1R:6YG("!4:&4@<V5R=F5R(&AO<W1N
M86UE+@H@*B\*9G5N8W1I;VX@7VEM<%]S97)V97(H*0I["B`@("!R971U<FX@
M)%]315-324].6R=I;7`G75LG<V5R=F5R)UT["GT*"B\J*@H@*B!!9&1S(&$@
M<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@*@H@*B!`<&%R
M86T@<W1R:6YG("1U<V5R260@("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`J
M($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@("!4:&4@8W)E9&5N=&EA;',@
M=&\@=7-E+@H@*@H@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`J+PIF=6YC
M=&EO;B!?:6UP7V%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0I["B`@
M("`D<&%R86US(#T@)%]315-324].6R=I;7`G75LG861M:6XG75LG<&%R86US
M)UT["B`@("`D<&%R86US6R=A9&UI;E]U<V5R)UT@/2`D<&%R86US6R=L;V=I
M;B==.PH@("`@)'!A<F%M<ULG861M:6Y?<&%S<W=O<F0G72`](%-E8W)E=#HZ
M<F5A9"A396-R970Z.F=E=$ME>2@G:6UP)RDL("1P87)A;7-;)W!A<W-W;W)D
M)UTI.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92])34%0+T%D;6EN+G!H<"<[
M"B`@("`D:6UA<"`]("9N97<@24U!4%]!9&UI;B@D<&%R86US*3L*("`@(')E
M='5R;B`D:6UA<"T^861D36%I;&)O>"A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T
M*"1U<V5R260L($Y,4SHZ9V5T0VAA<G-E="@I+"`G=71F-RUI;6%P)RDI.PI]
M"@HO*BH*("H@1&5L971E<R!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D
M96YT:6%L<RX*("H*("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E
M<DED('1O(&1E;&5T92X*("H*("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M*B\*9G5N8W1I;VX@7VEM<%]R96UO=F55<V5R*"1U<V5R260I"GL*("`@("1P
M87)A;7,@/2`D7U-%4U-)3TY;)VEM<"==6R=A9&UI;B==6R=P87)A;7,G73L*
M("`@("1P87)A;7-;)V%D;6EN7W5S97(G72`]("1P87)A;7-;)VQO9VEN)UT[
M"B`@("`D<&%R86US6R=A9&UI;E]P87-S=V]R9"==(#T@4V5C<F5T.CIR96%D
M*%-E8W)E=#HZ9V5T2V5Y*"=I;7`G*2P@)'!A<F%M<ULG<&%S<W=O<F0G72D[
M"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TE-05`O061M:6XN<&AP)SL*("`@
M("1I;6%P(#T@)FYE=R!)34%07T%D;6EN*"1P87)A;7,I.PH@("`@<F5T=7)N
M("1I;6%P+3YR96UO=F5-86EL8F]X*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M)'5S97))9"P@3DQ3.CIG971#:&%R<V5T*"DL("=U=&8W+6EM87`G*2D["GT*
M"B\J*@H@*B!,:7-T<R!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("H*("H@
M0')E='5R;B!A<G)A>2`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("HO"F9U;F-T:6]N(%]I;7!?
M=7-E<DQI<W0H*0I["B`@("`D<&%R86US(#T@)%]315-324].6R=I;7`G75LG
M861M:6XG75LG<&%R86US)UT["B`@("`D<&%R86US6R=A9&UI;E]U<V5R)UT@
M/2`D<&%R86US6R=L;V=I;B==.PH@("`@)'!A<F%M<ULG861M:6Y?<&%S<W=O
M<F0G72`](%-E8W)E=#HZ<F5A9"A396-R970Z.F=E=$ME>2@G:6UP)RDL("1P
M87)A;7-;)W!A<W-W;W)D)UTI.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92])
M34%0+T%D;6EN+G!H<"<["B`@("`D:6UA<"`]("9N97<@24U!4%]!9&UI;B@D
M<&%R86US*3L*("`@(')E='5R;B`D:6UA<"T^;&ES=$UA:6QB;WAE<R@I.PI]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]L:6(O24U0+G!H<```````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S4W-3``,3`T,3<S-C(W-C8`,#$W
M,3,Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\O($-O;7!O<V4@96YC<GEP=&EO;B!O<'1I;VYS"B\J*@H@*B!3
M96YD($UE<W-A9V4@=R]N;R!E;F-R>7!T:6]N+@H@*B\*9&5F:6YE*"=)35!?
M14Y#4EE05%].3TY%)RP@,2D["@HO*BH*("H@4V5N9"!-97-S86=E("T@4$=0
M($5N8W)Y<'0N"B`J+PID969I;F4H)TE-4%]01U!?14Y#4EE05"<L(#(I.PH*
M+RHJ"B`J(%-E;F0@365S<V%G92`M(%!'4"!3:6=N+@H@*B\*9&5F:6YE*"=)
M35!?4$=07U-)1TXG+"`S*3L*"B\J*@H@*B!396YD($UE<W-A9V4@+2!01U`@
M4VEG;B]%;F-R>7!T+@H@*B\*9&5F:6YE*"=)35!?4$=07U-)1TY%3D,G+"`T
M*3L*"B\J*@H@*B!396YD($UE<W-A9V4@+2!3+TU)344@16YC<GEP="X*("HO
M"F1E9FEN92@G24U07U--24U%7T5.0U)94%0G+"`U*3L*"B\J*@H@*B!396YD
M($UE<W-A9V4@+2!3+TU)344@4VEG;BX*("HO"F1E9FEN92@G24U07U--24U%
M7U-)1TXG+"`V*3L*"B\J*@H@*B!396YD($UE<W-A9V4@+2!3+TU)344@4VEG
M;B]%;F-R>7!T+@H@*B\*9&5F:6YE*"=)35!?4TU)345?4TE'3D5.0R<L(#<I
M.PH*+R\@24U!4"!&;&%G<PHO*BH*("H@36%T8V@@86QL($E-05`@9FQA9W,N
M"B`J+PID969I;F4H)TE-4%]!3$PG+"`P*3L*"B\J*@H@*B!<7%5.4T5%3B!F
M;&%G"BXJ+PID969I;F4H)TE-4%]53E-%14XG+"`Q*3L*"B\J*@H@*B!<7$1%
M3$54140@9FQA9PHN*B\*9&5F:6YE*"=)35!?1$5,151%1"<L(#(I.PH*+RHJ
M"B`J(%Q<04Y35T52140@9FQA9RX*("HO"F1E9FEN92@G24U07T%.4U=%4D5$
M)RP@-"D["@HO*BH*("H@7%Q&3$%'1T5$(&9L86<N"B`J+PID969I;F4H)TE-
M4%]&3$%'1T5$)RP@."D["@HO*BH*("H@7%Q$4D%&5"!F;&%G+@H@*B\*9&5F
M:6YE*"=)35!?1%)!1E0G+"`Q-BD["@HO*BH*("H@06X@96UA:6P@:7,@<&5R
M<V]N86PN"B`J+PID969I;F4H)TE-4%]015)33TY!3"<L(#,R*3L*"B\O($E-
M05`@4V]R=&EN9R!#;VYS=&%N=`HO*BH*("H@4V]R="!">2!4:')E860N"B`J
M+PI`9&5F:6YE*"=33U)45$A214%$)RP@,38Q*3L*"B\O($E-4"!-86EL8F]X
M('9I97<@8V]N<W1A;G1S"B\J*@H@*B!3=&%R="!O;B!T:&4@<&%G92!W:71H
M('1H92!F:7)S="!U;G-E96X@;65S<V%G92X*("HO"F1E9FEN92@G24U07TU!
M24Q"3UA35$%25%]&25)35%5.4T5%3B<L(#$I.PH*+RHJ"B`J(%-T87)T(&]N
M('1H92!P86=E('=I=&@@=&AE(&QA<W0@=6YS965N(&UE<W-A9V4N"B`J+PID
M969I;F4H)TE-4%]-04E,0D]84U1!4E1?3$%35%5.4T5%3B<L(#(I.PH*+RHJ
M"B`J(%-T87)T(&]N('1H92!F:7)S="!P86=E+@H@*B\*9&5F:6YE*"=)35!?
M34%)3$)/6%-405)47T9)4E-44$%'12<L(#,I.PH*+RHJ"B`J(%-T87)T(&]N
M('1H92!L87-T('!A9V4N"B`J+PID969I;F4H)TE-4%]-04E,0D]84U1!4E1?
M3$%35%!!1T4G+"`T*3L*"B\O($E-4"!M86EL8F]X(&QA8F5L<PHO*BH*("H@
M5&AE(&UA:6QB;W@@;F%M92!T;R!U<V4@9F]R('-E87)C:"!R97-U;'1S+@H@
M*B\*9&5F:6YE*"=)35!?4T5!4D-(7TU"3U@G+"`G*BIS96%R8VA?)RD["@HO
M+R!)35`@:6YT97)N86P@:6YD97AI;F<@<W1R:6YG<PHO*BH*("H@4W1R:6YG
M('5S960@=&\@<V5P87)A=&4@;65S<V%G97,N"B`J+PID969I;F4H)TE-4%]-
M4T=?4T50)RP@(EPP(BD["@HO*BH*("H@4W1R:6YG('5S960@=&\@<V5P87)A
M=&4@:6YD97AE<RX*("HO"F1E9FEN92@G24U07TE$6%]315`G+"`B7#$B*3L*
M"B\J*@H@*B!)35`@0F%S92!#;&%S<RX*("H*("H@)$AO<F1E.B!I;7`O;&EB
M+TE-4"YP:'`L=B`Q+C0T.2XT+C4U(#(P,#8O,#(O,34@,#$Z-#$Z-3D@<VQU
M<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L
M;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U(&1I9"!N
M;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;VX@4&%R
M:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@
M($E-4"`R+C,N-0H@*B!`<&%C:V%G92!)35`*("HO"F-L87-S($E-4"!["@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!!=71O3&]G:6X@<V5R=F5R(&ME
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9FER<W0@(%)E='5R
M;B!T:&4@9FER<W0@=F%L=64_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!S97)V97(@:V5Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!
M=71O3&]G:6Y397)V97(H)&9I<G-T(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M<F5Q=6ER92!)35!?0D%312`N("<O8V]N9FEG+W-E<G9E<G,N<&AP)SL*("`@
M("`@("!F;W)E86-H("@D<V5R=F5R<R!A<R`D:V5Y(#T^("1C=7)397)V97(I
M('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1S97)V97)?:V5Y*2`F)B!S=6)S
M='(H)&ME>2P@,"P@,2D@(3T@)U\G*2!["B`@("`@("`@("`@("`@("`D<V5R
M=F5R7VME>2`]("1K97D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*$E-4#HZ:7-0<F5F97)R961397)V97(H)&-U<E-E<G9E<BP@*"1F:7)S="D@
M/R`D:V5Y(#H@;G5L;"DI('L*("`@("`@("`@("`@("`@("1S97)V97)?:V5Y
M(#T@)&ME>3L*("`@("`@("`@("`@("`@(&EF("@D9FER<W0I('L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S97)V97)?:V5Y
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('=E(&-A
M;B!L;V<@:6X@=VET:&]U="!A(&QO9VEN('-C<F5E;B!F;W(@)'-E<G9E<E]K
M97DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5R=F5R7VME>2`@
M5&AE('-E<G9E<B!T;R!C:&5C:RX@1&5F875L=',@=&\*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($E-4#HZ9V5T0W5R<F5N=%-E<G9E<B@I
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9O<F-E("`@("`@268@=')U92P@
M8VAE8VL@)'-E<G9E<E]K97D@979E;B!I9B!T:&5R92!I<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;6]R92!T:&%N(&]N92!S97)V97(@
M879A:6QA8FQE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O<B!F86QS92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V%N075T;TQO9VEN
M*"1S97)V97)?:V5Y(#T@;G5L;"P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@<F5Q=6ER92!)35!?0D%312`N("<O8V]N9FEG+W-E<G9E<G,N<&AP
M)SL*"B`@("`@("`@)&%U=&]?<V5R=F5R(#T@24U0.CIG971!=71O3&]G:6Y3
M97)V97(H*3L*("`@("`@("!I9B`H:7-?;G5L;"@D<V5R=F5R7VME>2DI('L*
M("`@("`@("`@("`@)'-E<G9E<E]K97D@/2`D875T;U]S97)V97(["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@*"@H8V]U;G0H)&%U=&]?<V5R=F5R*2`]
M/2`Q*2!\?"`D9F]R8V4I("8F"B`@("`@("`@("`@("`@("!!=71H.CIG971!
M=71H*"D@)B8*("`@("`@("`@("`@("`@("%E;7!T>2@D<V5R=F5R<ULD<V5R
M=F5R7VME>5U;)VAO<F1E875T:"==*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!-86ME<R!S=7)E('1H92!U<V5R(&AA<R!B965N(&%U=&AE;G1I8V%T960@
M=&\@=FEE=R!T:&4@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&9L86=S("`@("!!;GD@9FQA9W,@=&\@<&%S<R!T;R!I;6%P7V]P96XH*2X@
M4V5E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!!=71H7VEM<#HZ
M875T:&5N=&EC871E*"DN($AO=V5V97(L(&EF('1H:7,@:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!S=')I;F<@)VAO<F1E)RP@=V4@
M:G5S="!C:&5C:R!F;W(@2&]R9&4@875T:`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@86YD(&1O;B=T(&)O=&AE<B!T:&4@24U!4"!S97)V97(N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5T=7)N("!)9B!T:&ES(&ES('1R
M=64L(')E='5R;B!F86QS92!I;G-T96%D(&]F"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!E>&ET:6YG+W)E9&ER96-T:6YG(&EF(&%U=&AE;G1I
M8V%T:6]N(&9A:6QS+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8VAE8VM!=71H96YT:6-A=&EO;B@D9FQA9W,@/2`P+"`D<F5T
M=7)N(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1F;&%G<R`]/3T@)VAO
M<F1E)RD@>PH@("`@("`@("`@("`D<F5A<V]N(#T@075T:#HZ:7-!=71H96YT
M:6-A=&5D*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%U=&A?
M:6UP(#T@)D%U=&@Z.G-I;F=L971O;BAA<G)A>2@G:6UP)RP@)VEM<"<I*3L*
M("`@("`@("`@("`@)&%U=&A?:6UP+3YA=71H96YT:6-A=&5/<'1I;VYS*&%R
M<F%Y*"=F;&%G<R<@/3X@)&9L86=S*2D["B`@("`@("`@("`@("1R96%S;VX@
M/2`D875T:%]I;7`M/F%U=&AE;G1I8V%T92@I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1R96%S;VX@(3T]('1R=64I('L*("`@("`@("`@("`@:68@*"1R
M971U<FXI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=P
M;W!U<"<I*2!["B`@("`@("`@("`@("`@("!5=&EL.CIC;&]S95=I;F1O=TI3
M*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=7)L
M(#T@075T:#HZ861D3&]G;W5T4&%R86UE=&5R<RA)35`Z.FQO9V]U=%5R;"@I
M*3L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M)'5R;"P@)W5R;"<L($AO<F1E.CIS96QF57)L*'1R=64I*3L*("`@("`@("`@
M("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF
M('1H92!G:79E;B!M86EL('-E<G9E<B!I<R!T:&4@(G!R969E<G)E9"(@;6%I
M;"!S97)V97(@9F]R"B`@("`@*B!T:&ES('=E8B!S97)V97(N("!4:&ES(&1E
M8VES:6]N(&ES(&)A<V5D(&]N('1H92!G;&]B86P@)U-%4E9%4E].04U%)PH@
M("`@("H@86YD("=(5%107TA/4U0G('-E<G9E<B!V87)I86)L97,@86YD('1H
M92!C;VYT96YT<R!O9B!T:&4@)W!R969E<G)E9"<*("`@("`J(&5I=&AE<B!F
M:65L9"!I;B!T:&4@<V5R=F5R)W,@9&5F:6YI=&EO;BX@(%1H92`G<')E9F5R
M<F5D)R!F:65L9"!M87D*("`@("`J('1A:V4@82!S:6YG;&4@=F%L=64@;W(@
M86X@87)R87D@;V8@;75L=&EP;&4@=F%L=65S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'-E<G9E<B`@02!C;VUP;&5T92!S97)V97(@96YT<GD@
M9G)O;2!T:&4@)'-E<G9E<G,@:&%S:"X*("`@("`J($!P87)A;2!43T1/("1K
M97D@("`@("`@5$]$3PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!I9B!T:&ES(&5N=')Y(&ES(")P<F5F97)R960B+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<U!R969E<G)E9%-E<G9E<B@D<V5R=F5R+"`D:V5Y(#T@
M;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)'5R;%-E<G9E<CL*"B`@("`@
M("`@:68@*"%I<W-E="@D=7)L4V5R=F5R*2D@>PH@("`@("`@("`@("`D=7)L
M4V5R=F5R(#T@571I;#HZ9V5T1F]R;41A=&$H)W-E<G9E<B<I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%E;7!T>2@D=7)L4V5R=F5R*2D@>PH@("`@("`@
M("`@("!R971U<FX@*"1K97D@/3T@)'5R;%-E<G9E<BD["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(65M<'1Y*"1S97)V97);)W!R969E<G)E9"==*2D@>PH@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)'-E<G9E<ELG<')E9F5R<F5D)UTI
M*2!["B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)%]315)615);)U-%
M4E9%4E].04U%)UTL("1S97)V97);)W!R969E<G)E9"==*2!\?`H@("`@("`@
M("`@("`@("`@("`@(&EN7V%R<F%Y*"1?4T525D526R=(5%107TA/4U0G72P@
M)'-E<G9E<ELG<')E9F5R<F5D)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS96EF("@H)'-E<G9E<ELG<')E9F5R<F5D)UT@/3T@)%]315)615);)U-%
M4E9%4E].04U%)UTI('Q\"B`@("`@("`@("`@("`@("`@("`@("`H)'-E<G9E
M<ELG<')E9F5R<F5D)UT@/3T@)%]315)615);)TA45%!?2$]35"==*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E;F5R871E<R!A(&9U;&P@8RUC;&EE;G0@<V5R=F5R('-P96-I
M9FEC871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&UB;W@@("`@("!4:&4@;6%I;&)O>"!T;R!A<'!E;F0@=&\@96YD(&]F('1H
M92!S97)V97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I
M;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F]T;V-O;"`@3W9E<G)I9&4@
M=&AE('!R;W1O8V]L(&-U<G)E;G1L>2!B96EN9R!U<V5D+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"!S<&5C('-T<FEN9RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5R=F5R4W1R:6YG*"1M8F]X(#T@;G5L;"P@
M)'!R;W1O8V]L(#T@;G5L;"D*("`@('L*("`@("`@("`D<W)V<W1R(#T@)WLG
M("X@)%]315-324].6R=I;7`G75LG<V5R=F5R)UT["@H@("`@("`@("\J($EF
M('!O<G0@:7,@;F]T('-P96-I9FEE9"P@9&]N)W0@:6YC;'5D92!I="!I;B!T
M:&4@<W1R:6YG+B`J+PH@("`@("`@(&EF("@A96UP='DH)%]315-324].6R=I
M;7`G75LG<&]R="==*2D@>PH@("`@("`@("`@("`D<W)V<W1R("X]("<Z)R`N
M("1?4T534TE/3ELG:6UP)UU;)W!O<G0G73L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<U]N=6QL*"1P<F]T;V-O;"DI('L*("`@("`@("`@("`@)'!R;W1O
M8V]L(#T@)%]315-324].6R=I;7`G75LG<')O=&]C;VPG73L*("`@("`@("!]
M"@H@("`@("`@("\J($EF('!R;W1O8V]L(&ES(&YO="!S<&5C:69I960L(&1O
M;B=T(&EN8VQU9&4@:70@:6X@=&AE('-T<FEN9RX@*B\*("`@("`@("!I9B`H
M(65M<'1Y*"1P<F]T;V-O;"DI('L*("`@("`@("`@("`@)'-R=G-T<B`N/2`G
M+R<@+B`D<')O=&]C;VP["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-R
M=G-T<B`N("=])R`N("1M8F]X.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@<&QA:6X@=&5X="!L86)E;"!T:&%T(&ES(&1I<W!L87EE9"!F
M;W(@=&AE(&-U<G)E;G0@;6%I;&)O>"P*("`@("`J(')E<&QA8VEN9R!)35!?
M4T5!4D-(7TU"3U@@=VET:"!A;B!A<'!R;W!R:6%T92!S=')I;F<@86YD(')E
M;6]V:6YG"B`@("`@*B!N86UE<W!A8V4@86YD(&9O;&1E<B!P<F5F:7@@:6YF
M;W)M871I;VX@9G)O;2!W:&%T(&ES('-H;W=N('1O('1H92!U<V5R+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&QA:6X@=&5X="!L86)E
M;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&%B96PH*0H@("`@>PH@("`@
M("`@("1L86)E;"`]("<G.PH*("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;
M)VEM<%]S96%R8V@G72D@)B8*("`@("`@("`@("`@)$=,3T)!3%-;)VEM<%]S
M96%R8V@G72T^<V5A<F-H36)O>$E$*"DI('L*("`@("`@("`@("`@)&QA8F5L
M(#T@)$=,3T)!3%-;)VEM<%]S96%R8V@G72T^9V5T3&%B96PH*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;&%B96P@/2!)35`Z.F1I<W!L87E&
M;VQD97(H)%]315-324].6R=I;7`G75LG;6%I;&)O>"==*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D;&%B96P["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!B87)E(&%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D861D<F5S<R`@("!4:&4@861D<F5S<R!S=')I;F<N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D;75L=&EP;&4@(%-H;W5L9"!W92!R971U
M<FX@;75L=&EP;&4@<F5S=6QT<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!3964@>T!L:6YK($U)344Z.F)A<F5!9&1R97-S?2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8F%R94%D9')E<W,H)&%D9')E<W,L("1M=6QT:7!L92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@('-T871I8R`D861D<F5S<V5S.PH*("`@
M("`@("!I9B`H(6ES<V5T*"1A9&1R97-S97-;*'-T<FEN9RDD;75L=&EP;&5=
M6R1A9&1R97-S72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]-24U%+G!H<"<["B`@("`@("`@("`@("1A9&1R97-S97-;*'-T<FEN9RDD
M;75L=&EP;&5=6R1A9&1R97-S72`]($U)344Z.F)A<F5!9&1R97-S*"1A9&1R
M97-S+"`D7U-%4U-)3TY;)VEM<"==6R=M86EL9&]M86EN)UTL("1M=6QT:7!L
M92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%D9')E<W-E<ULH<W1R
M:6YG*21M=6QT:7!L95U;)&%D9')E<W-=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@57-E<R!T:&4@4F5G:7-T<GD@=&\@97AP86YD(&YA;65S(&%N9"!R971U
M<FYI;F<@97)R;W(@:6YF;W)M871I;VX@9F]R"B`@("`@*B!A;GD@861D<F5S
M<R!T:&%T(&ES(&5I=&AE<B!N;W0@=F%L:60@;W(@9F%I;',@=&\@97AP86YD
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')3=')I;F<@(%1H
M92!N86UE*',I(&]R(&%D9')E<W,H97,I('1O(&5X<&%N9"X*("`@("`J($!P
M87)A;2!B;V]L96%N("1F=6QL("`@("`@($EF('1R=64@9V5N97)A=&4@82!F
M=6QL+"!R9F,X,C(M=F%L:60@861D<F5S<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;&ES="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("`@16ET:&5R(&$@<W1R:6YG(&-O;G1A:6YI;F<@86QL(&5X<&%N9&5D
M(&%D9')E<W-E<R!O<B!A;@H@("`@("H@("`@("`@("`@("`@("`@(&%R<F%Y
M(&-O;G1A:6YI;F<@86QL(&UA=&-H:6YG(&%D9')E<W,@;W(@86X@97)R;W(*
M("`@("`J("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5X<&%N9$%D9')E<W-E<R@D861D<E-T<FEN9RP@)&9U;&P@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H(7!R96=?;6%T8V@H)WQ;7EQS77PG
M+"`D861D<E-T<FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@('T*"B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=-86EL+U)&0S@R,BYP:'`G.PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O34E-12YP:'`G.PH*("`@("`@("`D<&%R<V5R(#T@)FYE=R!-
M86EL7U)&0S@R,BAN=6QL+"`G0$E.5D%,240G*3L*("`@("`@("`D<V5A<F-H
M7V9I96QD<R`](&%R<F%Y*"D["@H@("`@("`@("1S<F,@/2!E>'!L;V1E*")<
M="(L("1P<F5F<RT^9V5T5F%L=64H)W-E87)C:%]S;W5R8V5S)RDI.PH@("`@
M("`@(&EF("@H8V]U;G0H)'-R8RD@/3T@,2D@)B8@96UP='DH)'-R8ULP72DI
M('L*("`@("`@("`@("`@)'-R8R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H*"1V86P@/2`D<')E9G,M/F=E=%9A;'5E*"=S96%R8VA?9FEE
M;&1S)RDI*2!["B`@("`@("`@("`@("1F:65L9%]A<G(@/2!E>'!L;V1E*")<
M;B(L("1V86PI.PH@("`@("`@("`@("!F;W)E86-H("@D9FEE;&1?87)R(&%S
M("1F:65L9"D@>PH@("`@("`@("`@("`@("`@)&9I96QD(#T@=')I;2@D9FEE
M;&0I.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9FEE;&0I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1M<"`](&5X<&QO9&4H(EQT(BP@)&9I96QD
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1M<"D@/B`Q*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S;W5R8V4@/2!A<G)A>5]S<&QI
M8V4H)'1M<"P@,"P@,2D["B`@("`@("`@("`@("`@("`@("`@("`@("1S96%R
M8VA?9FEE;&1S6R1S;W5R8V5;,%U=(#T@)'1M<#L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1A<G(@/2!-24U%.CIR9F,X,C)%>'!L;V1E*"1A9&1R
M4W1R:6YG+"`G+"<I.PH@("`@("`@("1A<G(@/2!A<G)A>5]M87`H)W1R:6TG
M+"`D87)R*3L*("`@("`@("`D87)R(#T@87)R87E?9FEL=&5R*"1A<G(I.PH*
M("`@("`@("`D<F5S=6QT<R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL
M*"=C;VYT86-T<R]S96%R8V@G+"!A<G)A>2@D87)R+"`D<W)C+"`D<V5A<F-H
M7V9I96QD<RDI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'1S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@("`@
M("!]"@H@("`@("`@("\J(%)E;6]V92!A;GD@<F5S=6QT<R!W:71H(&5M<'1Y
M(&5M86EL(&%D9')E<W-E<RX@*B\*("`@("`@("`D:V5Y<R`](&%R<F%Y7VME
M>7,H)')E<W5L=',I.PH@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI
M('L*("`@("`@("`@("`@)'-U8E1O=&%L(#T@8V]U;G0H)')E<W5L='-;)&ME
M>5TI.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<W5B5&]T86P[
M("LK)&DI('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<F5S=6QT<ULD
M:V5Y75LD:5U;)V5M86EL)UTI*2!["B`@("`@("`@("`@("`@("`@("`@=6YS
M970H)')E<W5L='-;)&ME>5U;)&E=*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&%M8FEG=6]U<R`](&9A
M;'-E.PH@("`@("`@("1E<G)O<B`](&9A;'-E.PH@("`@("`@("1M:7-S:6YG
M(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)&%R<B!A<R`D:2`]/B`D
M=&UP*2!["B`@("`@("`@("`@("1A9&1R97-S(#T@34E-13HZ96YC;V1E061D
M<F5S<R@D=&UP+"!N=6QL+"`G)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D
M861D<F5S<RP@)U!%05)?17)R;W(G*2`F)@H@("`@("`@("`@("`@("`@*"1P
M87)S97(M/G9A;&ED871E36%I;&)O>"@D861D<F5S<RD@?'P*("`@("`@("`@
M("`@("`@("`D<&%R<V5R+3Y?:7-'<F]U<"@D861D<F5S<RDI*2!["B`@("`@
M("`@("`@("`@("`O+R!N;V]P"B`@("`@("`@("`@('T@96QS96EF("@A:7-S
M970H)')E<W5L='-;)'1M<%TI('Q\("%C;W5N="@D<F5S=6QT<ULD=&UP72DI
M('L*("`@("`@("`@("`@("`@("\J($AA;F1L92!T:&4@;6ES<VEN9R]I;G9A
M;&ED(&-A<V4@+2!W92!S:&]U;&0@<F5T=7)N(&5R<F]R"B`@("`@("`@("`@
M("`@("`@*B!I;F9O(&]N(&5A8V@@861D<F5S<R!T:&%T(&-O=6QD;B=T(&)E
M"B`@("`@("`@("`@("`@("`@*B!E>'!A;F1E9"]V86QI9&%T960N("HO"B`@
M("`@("`@("`@("`@("`D97)R;W(@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M:68@*"$D86UB:6=U;W5S*2!["B`@("`@("`@("`@("`@("`@("`@)&%R<ELD
M:5T@/2!014%2.CIR86ES945R<F]R*&YU;&PL(&YU;&PL(&YU;&PL(&YU;&PL
M("1A<G);)&E=*3L*("`@("`@("`@("`@("`@("`@("`D;6ES<VEN9ULD:5T@
M/2`D87)R6R1I73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R97,@/2`D<F5S=6QT<ULD=&UP73L*
M("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<F5S*2`]/2`Q*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1F=6QL*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')P;W,H)')E<ULP75LG96UA:6PG72P@)RPG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<G);)&E=
M(#T@)')E<ULP75LG;F%M92==("X@)SH@)R`N("1R97-;,%U;)V5M86EL)UT@
M+B`G.R<["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1M8F]X+"`D:&]S="D@/2!E
M>'!L;V1E*"=`)RP@)')E<ULP75LG96UA:6PG72D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D87)R6R1I72`]($U)344Z.G)F8S@R,E=R:71E061D
M<F5S<R@D;6)O>"P@)&AO<W0L("1R97-;,%U;)VYA;64G72D["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D87)R6R1I72`]("1R97-;,%U;
M)VYA;64G73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J($AA;F1L92!T:&4@
M;75L=&EP;&4@8V%S92`M('=E(')E='5R;B!A;B!A<G)A>0H@("`@("`@("`@
M("`@("`@("`@("`J('=I=&@@86QL(&9O=6YD(&%D9')E<W-E<RX@*B\*("`@
M("`@("`@("`@("`@("`@("`D87)R6R1I72`](&%R<F%Y*"1A<G);)&E=*3L*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5S(&%S("1O;F5?<F5S
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9G5L;"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;VYE7W)E<ULG
M96UA:6PG72P@)RPG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D87)R6R1I75M=(#T@)&]N95]R97-;)VYA;64G72`N
M("<Z("<@+B`D;VYE7W)E<ULG96UA:6PG72`N("<[)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&UB;WA?:&]S="`](&5X<&QO9&4H)T`G+"`D;VYE7W)E
M<ULG96UA:6PG72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1M8F]X7VAO<W1;,5TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A<G);)&E=6UT@/2!-24U%.CIR9F,X,C)7
M<FET94%D9')E<W,H)&UB;WA?:&]S=%LP72P@)&UB;WA?:&]S=%LQ72P@)&]N
M95]R97-;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R<ELD:5U;72`]("1O;F5?<F5S6R=N86UE)UT["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)&%M8FEG=6]U<R`]('1R=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D
M86UB:6=U;W5S*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M:7-S:6YG(&%S
M("1I(#T^("1A9&1R*2!["B`@("`@("`@("`@("`@("`D87)R6R1I72`]("1A
M9&1R+3YG9715<V5R26YF;R@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B`D87)R.PH@("`@("`@('T@96QS96EF("@D97)R;W(I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&QE87-E(')E
M<V]L=F4@86UB:6=U;W5S(&]R(&EN=F%L:60@861D<F5S<V5S+B(I+"!N=6QL
M+"!N=6QL+"!N=6QL+"`D87)R*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;&ES="`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D87)R(&%S
M("1E;&TI('L*("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)&QI<W0L("TQ
M*2`]/2`G.R<I('L*("`@("`@("`@("`@("`@("`@("`D;&ES="`N/2`G("<[
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1L:7-T*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1L:7-T("X]("<L("<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D;&ES="`N/2`D96QM.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@8V]N=&%C="!T;R!T:&4@=7-E
M<B!D969I;F5D(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N97=!9&1R97-S("!4:&4@8V]N=&%C="=S(&5M86EL(&%D9')E
M<W,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=.86UE("`@("!4:&4@8V]N
M=&%C="=S(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@
M;&EN:R!O<B!M97-S86=E('1O('-H;W<@:6X@=&AE(&YO=&EF:6-A=&EO;B!A
M<F5A+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1!9&1R97-S*"1N97=!9&1R
M97-S+"`D;F5W3F%M92D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y
M+"`D<')E9G,["@H@("`@("`@(&EF("AE;7!T>2@D;F5W3F%M92DI('L*("`@
M("`@("`@("`@)&YE=TYA;64@/2`D;F5W061D<F5S<SL*("`@("`@("!]"@H@
M("`@("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/F-A;&PH)V-O;G1A8W1S+VEM
M<&]R="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2AA<G)A>2@G;F%M92<@/3X@)&YE=TYA;64L("=E;6%I;"<@/3X@)&YE=T%D
M9')E<W,I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V%R<F%Y)RP@)'!R969S+3YG971686QU92@G861D7W-O=7)C92<I*2D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8V]N=&%C=%]L:6YK(#T@)')E9VES=')Y+3YL:6YK*"=C
M;VYT86-T<R]S:&]W)RP@87)R87DH)W5I9"<@/3X@)')E<W5L="P@)W-O=7)C
M92<@/3X@)'!R969S+3YG971686QU92@G861D7W-O=7)C92<I*2D["B`@("`@
M("`@("`@(&EF("@A96UP='DH)&-O;G1A8W1?;&EN:RD@)B8@(6ES7V$H)&-O
M;G1A8W1?;&EN:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M)&-O;G1A8W1?;&EN:R`]($AO<F1E.CIL:6YK*$AO<F1E.CIU<FPH)&-O;G1A
M8W1?;&EN:RDL('-P<FEN=&8H7R@B1V\@=&\@861D<F5S<R!B;V]K(&5N=')Y
M(&]F(%PB)7-<(B(I+"`D;F5W3F%M92DI("X@0&AT;6QS<&5C:6%L8VAA<G,H
M)&YE=TYA;64L($5.5%]#3TU0050L($Y,4SHZ9V5T0VAA<G-E="@I*2`N("<\
M+V$^)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C
M;VYT86-T7VQI;FL@/2!`:'1M;'-P96-I86QC:&%R<R@D;F5W3F%M92P@14Y4
M7T-/35!!5"P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B`D8V]N=&%C=%]L:6YK.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A;B!A9&1R97-S(&]R(&%D9')E
M<W,@;&ES="!I;G1O('1H92!A9&1R97-S(&-O;7!O;F5N=',L"B`@("`@*B!A
M=71O;6%T:6-A;&QY(&-H;V]S:6YG('1H92!B97-T('-U:71E9"!P87)S:6YG
M(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R97-S
M("!!;B!A9&1R97-S(&]R(&%D9')E<W,@;&ES="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@861D<F5S<R!O8FIE8W1S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!P87)S94%D9')E<W-,:7-T*"1A9&1R97-S*0H@
M("`@>PH@("`@("`@('-T871I8R`D<&%R<V5R.PH*("`@("`@("!I9B`H571I
M;#HZ97AT96YS:6]N17AI<W1S*"=I;6%P)RD@)B8*("`@("`@("`@("`@<W1R
M<&]S*"1A9&1R97-S+"`G.B<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D
M<F5S=6QT(#T@0&EM87!?<F9C.#(R7W!A<G-E7V%D<FQI<W0H)&%D9')E<W,L
M("<G*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D<&%R<V5R*2D@>PH@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@
M("`@("`@("1P87)S97(@/2`F;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'!A<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D
M861D<F5S<RP@)R<L(&9A;'-E+"!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!7<F%P<&5R(&%R;W5N9"!)35!?1F]L9&5R.CIF;&ES="@I('=H:6-H
M(&=E;F5R871E<R!T:&4@8F]D>2!O9B!A"B`@("`@*B`F;'0[<V5L96-T)F=T
M.R!F;W)M(&EN<'5T(&9R;VT@=&AE(&=E;F5R871E9"!F;VQD97(@;&ES="X@
M5&AE"B`@("`@*B`F;'0[<V5L96-T)F=T.R!A;F0@)FQT.R]S96QE8W0F9W0[
M('1A9W,@87)E($Y/5"!I;F-L=61E9"!I;B!T:&4@;W5T<'5T"B`@("`@*B!O
M9B!T:&ES(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&AE861I;F<@("`@("`@("!4:&4@;&%B96P@9F]R(&%N(&5M<'1Y+79A;'5E
M(&]P=&EO;B!A=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H92!T;W`@;V8@=&AE(&QI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D86)B<F5V("`@("`@("`@268@=')U92P@86)B<F5V:6%T92!L;VYG(&UA
M:6QB;W@@;F%M97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B>2!R97!L86-I;F<@=&AE(&UI9&1L92!O9B!T:&4@;F%M92!W:71H
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RXN+B<N
M"B`@("`@*B!`<&%R86T@87)R87D@)&9I;'1E<B`@("`@("`@("`@06X@87)R
M87D@;V8@;6%I;&)O>&5S('1O(&EG;F]R92X@268@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9FER<W0@96QE;65N="!I;B!T
M:&4@87)R87D@:7,@;G5L;"P@=&AE;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!M86EL8F]X('=I;&P@8F4@<VAO=VX@:6X@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5S
M=6QT:6YG(&QI<W0L(&)U="!T:&5R92!W:6QL(&)E(&%N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@96UP='D@=F%L=64@87)G=6UE
M;G0@*&DN92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!N;VXM<V5L96-T86)L92DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1S96QE
M8W1E9"`@("`@("`@5&AE(&UA:6QB;W@@=&\@:&%V92!S96QE8W1E9"!B>2!D
M969A=6QT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YE=U]F;VQD97(@("`@
M($EF('1R=64L(&1I<W!L87D@86X@;W!T:6]N('1O(&-R96%T92!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;F5W(&9O;&1E<BX*
M("`@("`J($!P87)A;2!B;V]L96%N("1I;F-?=&%S:VQI<W1S("!3:&]U;&0@
M=&AE('5S97(G<R!E9&ET86)L92!T87-K;&ES=',@8F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E9"!I;B!T:&4@;&ES
M=#\*("`@("`J($!P87)A;2!B;V]L96%N("1I;F-?=F9O;&1E<B`@("!3:&]U
M;&0@=&AE('5S97(G<R!V:7)T=6%L(&9O;&1E<G,@8F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E9"!I;B!T:&4@;&ES
M=#\*("`@("`J($!P87)A;2!B;V]L96%N("1I;F-?=&%S:VQI<W1S("!3:&]U
M;&0@=&AE('5S97(G<R!E9&ET86)L92!N;W1E<&%D<R!B90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&5D(&EN('1H92!L
M:7-T/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!('-T<FEN9R!C
M;VYT86EN:6YG(#QO<'1I;VX^(&5L96UE;G1S(&9O<B!E86-H(&UA:6QB;W@*
M("`@("`J("`@("`@("`@("`@("`@("!I;B!T:&4@;&ES="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9FQI<W1396QE8W0H)&AE861I;F<@/2`G)RP@)&%B8G)E
M=B`]('1R=64L("1F:6QT97(@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-E;&5C=&5D(#T@;G5L;"P@)&YE=U]F;VQD97(@/2!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("1I;F-?=&%S:VQI<W1S(#T@
M9F%L<V4L("1I;F-?=F9O;&1E<B`](&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN8U]N;W1E<&%D<R`](&9A;'-E*0H@("`@>PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH@("`@("`@(')E<75I
M<F5?;VYC92!)35!?0D%312`N("<O;&EB+T9O;&1E<BYP:'`G.PH*("`@("`@
M("`D:6UP7V9O;&1E<B`]("9)35!?1F]L9&5R.CIS:6YG;&5T;VXH*3L*"B`@
M("`@("`@+RH@1&]N)W0@9FEL=&5R(&AE<F4@+2!S:6YC92!W92!A<F4@9V]I
M;F<@=&\@<&%R<V4@=&AR;W5G:"!E=F5R>0H@("`@("`@("`J(&UE;6)E<B!O
M9B!T:&4@9F]L9&5R(&QI<W0@8F5L;W<@86YY=V%Y+"!W92!C86X@9FEL=&5R
M(&%T('1H870@=&EM92X*("`@("`@("`@*B!4:&ES(&%L;&]W<R!U<R!T:&4@
M:&%V92!A('-I;F=L92!C86-H960@=F%L=64@9F]R('1H92!F;VQD97(@;&ES
M=`H@("`@("`@("`J(')A=&AE<B!T:&%N(&$@8V%C:&5D('9A;'5E(&9O<B!E
M86-H(&1I9F9E<F5N="!M86EL8F]X('=E(&UA>0H@("`@("`@("`J('9I<VET
M+B`J+PH@("`@("`@("1M86EL8F]X97,@/2`D:6UP7V9O;&1E<BT^9FQI<W1?
M24U0*"D["B`@("`@("`@)'1E>'0@/2`G)SL*"B`@("`@("`@:68@*'-T<FQE
M;B@D:&5A9&EN9RD@/B`P*2!["B`@("`@("`@("`@("1T97AT("X]("<\;W!T
M:6]N('9A;'5E/2(B/B<@+B`D:&5A9&EN9R`N("(\+V]P=&EO;CY<;B(["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&YE=U]F;VQD97(@)B8*("`@("`@("`@
M("`@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=H;V]K<R==6R=P97)M<V1E
M;FEE9"==*2!\?`H@("`@("`@("`@("`@*$E-4#HZ:&%S4&5R;6ES<VEO;B@G
M8W)E871E7V9O;&1E<G,G*2`F)@H@("`@("`@("`@("`@($E-4#HZ:&%S4&5R
M;6ES<VEO;B@G;6%X7V9O;&1E<G,G*2DI*2!["B`@("`@("`@("`@("1T97AT
M("X]("<\;W!T:6]N('9A;'5E/2(B/BTM+2T\+V]P=&EO;CXG("X@(EQN(CL*
M("`@("`@("`@("`@)'1E>'0@+CT@)SQO<'1I;VX@=F%L=64](BIN97<J(CXG
M("X@7R@B3F5W($9O;&1E<B(I("X@(CPO;W!T:6]N/EQN(CL*("`@("`@("`@
M("`@)'1E>'0@+CT@)SQO<'1I;VX@=F%L=64](B(^+2TM+3PO;W!T:6]N/B<@
M+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@+RH@061D('1H92!L:7-T(&]F
M(&UA:6QB;WAE<R!T;R!T:&4@;&ES=',N("HO"B`@("`@("`@)'-H;W=M8F]X
M(#T@9F%L<V4["B`@("`@("`@:68@*"%E;7!T>2@D9FEL=&5R*2`F)B!I<U]N
M=6QL*"1F:6QT97);,%TI*2!["B`@("`@("`@("`@("1S:&]W;6)O>"`]('1R
M=64["B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1F:6QT97(I.PH@("`@("`@
M('T*"B`@("`@("`@)&9I;'1E<B`](&%R<F%Y7V9L:7`H)&9I;'1E<BD["B`@
M("`@("`@9F]R96%C:"`H)&UA:6QB;WAE<R!A<R`D;6)O>"D@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)&9I;'1E<ELD;6)O>%LG=F%L)UU=*2`F)B`A)'-H
M;W=M8F]X*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'9A;"`](&ES<V5T*"1F:6QT97);)&UB;WA;
M)W9A;"==72D@/R`G)R`Z(&AT;6QS<&5C:6%L8VAA<G,H)&UB;WA;)W9A;"==
M*3L*("`@("`@("`@("`@)'-E;"`]("@D;6)O>%LG=F%L)UT@)B8@*"1M8F]X
M6R=V86PG72`]/3T@)'-E;&5C=&5D*2D@/R`G('-E;&5C=&5D/2)S96QE8W1E
M9"(G(#H@)R<["B`@("`@("`@("`@("1L86)E;"`]("@D86)B<F5V*2`_("1M
M8F]X6R=A8F)R978G72`Z("1M8F]X6R=L86)E;"==.PH@("`@("`@("`@("`D
M=&5X="`N/2!S<')I;G1F*"<\;W!T:6]N('9A;'5E/2(E<R(E<SXE<SPO;W!T
M:6]N/B5S)RP@)'9A;"P@)'-E;"P@5&5X=#HZ:'1M;%-P86-E<R@D;&%B96PI
M+"`B7&XB*3L*("`@("`@("!]"@H@("`@("`@("\J($%D9"!T:&4@;&ES="!O
M9B!V:7)T=6%L(&9O;&1E<G,@=&\@=&AE(&QI<W0N("HO"B`@("`@("`@:68@
M*"1I;F-?=F9O;&1E<BD@>PH@("`@("`@("`@("`D=F9O;&1E<G,@/2`D1TQ/
M0D%,4ULG:6UP7W-E87)C:"==+3YL:7-T475E<FEE<RAT<G5E*3L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=F9O;&1E<G,I*2!["B`@("`@("`@("`@("`@
M("`D=F9O;&1E<E]S96P@/2`D1TQ/0D%,4ULG:6UP7W-E87)C:"==+3YS96%R
M8VA-8F]X240H*3L*("`@("`@("`@("`@("`@("1T97AT("X]("<\;W!T:6]N
M('9A;'5E/2(B/BTM+2T\+V]P=&EO;CXG("X@(EQN(CL*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1V9F]L9&5R<R!A<R`D:60@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@("`@("1T97AT("X]('-P<FEN=&8H)SQO<'1I;VX@=F%L
M=64](B5S(B5S/B5S/"]O<'1I;VX^)7,G+"!)35!?4T5!4D-(7TU"3U@@+B`D
M:60L("@D=F9O;&1E<E]S96P@/3T@)&ED*2`_("<@<V5L96-T960](G-E;&5C
M=&5D(B<@.B`G)RP@5&5X=#HZ:'1M;%-P86-E<R@D=F%L*2P@(EQN(BD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J($%D9"!T:&4@;&ES="!O9B!E9&ET86)L92!T87-K;&ES=',@=&\@
M=&AE(&QI<W0N("HO"B`@("`@("`@:68@*"1I;F-?=&%S:VQI<W1S("8F("1?
M4T534TE/3ELG:6UP)UU;)W1A<VML:7-T879A:6PG72D@>PH@("`@("`@("`@
M("`D=&%S:VQI<W1S(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)W1A
M<VMS+VQI<W1487-K;&ES=',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH9F%L<V4L(%!%4DU3
M7T5$250I*3L*"B`@("`@("`@("`@(&EF("@A:7-?82@D=&%S:VQI<W1S+"`G
M4$5!4E]%<G)O<B<I("8F(&-O=6YT*"1T87-K;&ES=',I*2!["B`@("`@("`@
M("`@("`@("`D=&5X="`N/2`G/&]P=&EO;B!V86QU93TB(CXM+2TM/"]O<'1I
M;VX^)R`N(")<;B(["@H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1A<VML
M:7-T<R!A<R`D:60@/3X@)'1A<VML:7-T*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1E>'0@+CT@<W!R:6YT9B@G/&]P=&EO;B!V86QU93TB)7,B/B5S/"]O
M<'1I;VX^)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)U]T87-K;&ES=%\G("X@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@5&5X=#HZ:'1M;%-P86-E<R@D=&%S:VQI<W0M/F=E
M="@G;F%M92<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")<;B(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!!9&0@=&AE(&QI<W0@;V8@961I=&%B;&4@
M;F]T97!A9',@=&\@=&AE(&QI<W0N("HO"B`@("`@("`@:68@*"1I;F-?;F]T
M97!A9',@)B8@)%]315-324].6R=I;7`G75LG;F]T97!A9&%V86EL)UTI('L*
M("`@("`@("`@("`@)&YO=&5P861S(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F-A;&PH)VYO=&5S+VQI<W1.;W1E<&%D<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2AF86QS
M92P@4$5235-?141)5"DI.PH*("`@("`@("`@("`@:68@*"%I<U]A*"1N;W1E
M<&%D<RP@)U!%05)?17)R;W(G*2`F)B!C;W5N="@D;F]T97!A9',I*2!["B`@
M("`@("`@("`@("`@("`D=&5X="`N/2`G/&]P=&EO;B!V86QU93TB(CXM+2TM
M/"]O<'1I;VX^)R`N(")<;B(["@H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&YO=&5P861S(&%S("1I9"`]/B`D;F]T97!A9"D@>PH@("`@("`@("`@("`@
M("`@("`@("1T97AT("X]('-P<FEN=&8H)SQO<'1I;VX@=F%L=64](B5S(CXE
M<SPO;W!T:6]N/B5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=?;F]T97!A9%\G("X@)&ED+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@5&5X=#HZ:'1M;%-P86-E<R@D;F]T97!A9"T^
M9V5T*"=N86UE)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(EQN(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K<R!F;W(@5&\Z+"!3=6)J96-T.BP@0V,Z+"!A;F0@
M;W1H97(@8V]M<&]S92!W:6YD;W<@87)G=6UE;G1S(&%N9`H@("`@("H@<&%S
M<R!B86-K(&5I=&AE<B!A(%5222!F<F%G;65N="!O<B!A;B!A<W-O8VEA=&EV
M92!A<G)A>2!W:71H(&%N>2!O9@H@("`@("H@=&AE;2!W:&EC:"!A<F4@<')E
M<V5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@($5I
M=&AE<B`G=7)I)R!O<B`G87)R87DG+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!!(%5222!F<F%G;65N="!O<B!A;B!A<W-O8VEA=&EV92!A<G)A
M>2!W:71H(&%N>2!C;VUP;W-E"B`@("`@*B`@("`@("`@("`@("`@("`@87)G
M=6UE;G1S('!R97-E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;7!O
M<V5!<F=S*"D*("`@('L*("`@("`@("`D87)G<R`](&%R<F%Y*"D["B`@("`@
M("`@)&9I96QD<R`](&%R<F%Y*"=T;R<L("=C8R<L("=B8V,G+"`G;7-G)RP@
M)W-U8FIE8W0G*3L*"B`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A<R`D=F%L
M*2!["B`@("`@("`@("`@(&EF("@H)"1V86P@/2!5=&EL.CIG971&;W)M1&%T
M82@D=F%L*2DI('L*("`@("`@("`@("`@("`@("1A<F=S6R1V86Q=(#T@)"1V
M86P["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($1E8V]D
M92!M86EL=&\Z(%523',N("HO"B`@("`@("`@:68@*&ES<V5T*"1A<F=S6R=T
M;R==*2`F)B`H<W1R<&]S*"1A<F=S6R=T;R==+"`G;6%I;'1O.B<I(#T]/2`P
M*2D@>PH@("`@("`@("`@("`D;6%I;'1O(#T@0'!A<G-E7W5R;"@D87)G<ULG
M=&\G72D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;6%I;'1O*2D@>PH@
M("`@("`@("`@("`@("`@)&%R9W-;)W1O)UT@/2`D;6%I;'1O6R=P871H)UT[
M"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1M86EL=&];)W%U97)Y)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@<&%R<V5?<W1R*"1M86EL=&];)W%U
M97)Y)UTL("1V86QS*3L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9FEE;&1S(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1V86QS6R1V86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R9W-;)'9A;%T@/2`D=F%L<ULD=F%L73L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1A<F=S.PH@("`@?0H*("`@("\J*@H@("`@("H@3W!E;B!A(&-O;7!O
M<V4@=VEN9&]W+@H@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N0V]M<&]S95=I
M;B@D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1P
M<F5F<SL*"B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)V-O;7!O<V5?
M<&]P=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D;W!T:6]N<R`K/2!)35`Z.F=E=$-O;7!O
M<V5!<F=S*"D["B`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T
M97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=C;VUP;W-E+G!H<"<L('1R=64I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I
M;VYS+"!N=6QL+"!F86QS92D["B`@("`@("`@("`@(&AE861E<B@G3&]C871I
M;VXZ("<@+B`D=7)L*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%P<')O
M<')I871E(&QI;FL@=&\@8V%L;"!T:&4@;65S<V%G92!C;VUP;W-I=&EO;B!S
M8W)E96XN"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1A<F=S("`@3&ES
M="!O9B!A<F=U;65N=',@=&\@<&%S<R!T;R!C;VUP;W-E+G!H<"X@268@=&AI
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@:7,@<&%S<V5D(&EN(&%S
M(&$@<W1R:6YG+"!I="!W:6QL(&)E('!A<G-E9"!A<R!A"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!T;V%D9')E<W,_<W5B:F5C=#UF;V\F8V,]8V-A
M9&1R97-S("AM86EL=&\M<W1Y;&4I"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)&5X=')A("!(87-H
M(&]F(&5X=')A+"!N;VXM<W1A;F1A<F0@87)G=6UE;G1S('1O('!A<W,@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@(&-O;7!O<V4N<&AP+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&EN:R!T;R!T:&4@;65S
M<V%G92!C;VUP;W-I=&EO;B!S8W)E96XN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;7!O<V5,:6YK*"1A<F=S(#T@87)R87DH*2P@)&5X=')A(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S+"`D8G)O=W-E<CL*"B`@
M("`@("`@+RH@36%K92!S=7)E('1H92!C;VUP;W-E('=I;F1O=R!A;'=A>7,@
M:VYO=W,@=VAI8V@@;6%I;&)O>"!I="=S(&EN+`H@("`@("`@("`@(&9O<B!R
M97!L>6EN9RP@9F]R=V%R9&EN9RP@;6%R:VEN9R!A<R!A;G-W97)E9"P@971C
M+B`J+PH@("`@("`@("\J("1?4T534TE/3ELG:6UP)UT@;6%Y(&YO="!B92!A
M=F%I;&%B;&4@:&5R92X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1E>'1R85LG
M=&AI<VUA:6QB;W@G72D@)B8*("`@("`@("`@("`@:7-S970H)%]315-324].
M6R=I;7`G75LG=&AI<VUA:6QB;W@G72DI('L*("`@("`@("`@("`@)&5X=')A
M6R=T:&ES;6%I;&)O>"==(#T@)%]315-324].6R=I;7`G75LG=&AI<VUA:6QB
M;W@G73L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]S=')I;F<H)&%R9W,I
M*2!["B`@("`@("`@("`@("1S=')I;F<@/2`D87)G<SL*("`@("`@("`@("`@
M)&%R9W,@/2!A<G)A>2@I.PH@("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')P
M;W,H)'-T<FEN9RP@)S\G*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("!P87)S95]S='(H<W5B<W1R*"1S=')I;F<L("1P;W,@*R`Q*2P@)&%R9W,I
M.PH@("`@("`@("`@("`@("`@)&%R9W-;)W1O)UT@/2!S=6)S='(H)'-T<FEN
M9RP@,"P@)'!O<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D87)G<ULG=&\G72`]("1S=')I;F<["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\J($UE<F=E('1H92!T=V\@87)G=6UE;G0@87)R
M87ES+B`J+PH@("`@("`@(&EF("AI<U]A<G)A>2@D97AT<F$I*2!["B`@("`@
M("`@("`@("1A<F=S(#T@87)R87E?;65R9V4H)&%R9W,L("1E>'1R82D["B`@
M("`@("`@?0H*("`@("`@("`O*B!#;VYV97)T('1H92`D87)G<R!H87-H(&EN
M=&\@<')O<&5R(%523"!P87)A;65T97)S+B`J+PH@("`@("`@("1U<FP@/2!S
M=6)S='(H571I;#HZ861D4&%R86UE=&5R*"<G+"!A<G)A>5]D:69F*"1A<F=S
M+"!A<G)A>2@G)RDI+"!N=6QL+"!F86QS92DL(#$I.PH*("`@("`@("!I9B`H
M)'!R969S+3YG971686QU92@G8V]M<&]S95]P;W!U<"<I("8F"B`@("`@("`@
M("`@("1B<F]W<V5R+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@
M("`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RD["B`@
M("`@("`@("`@(')E='5R;B`B:F%V87-C<FEP=#IP;W!U<%]I;7`H)R(@+B!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)V-O;7!O<V4N<&AP)RD@+B`B)RPW,#`L
M-C4P+"<B("X@:'1M;'-P96-I86QC:&%R<R@D8G)O=W-E<BT^97-C87!E2E-#
M;V1E*&%D9'-L87-H97,H)'5R;"DI*2`N("(G*3LB.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!(;W)D93HZ87!P;&EC871I;VY5<FPH
M96UP='DH)'5R;"D@/R`G8V]M<&]S92YP:'`G(#H@)V-O;7!O<V4N<&AP/R<@
M+B`D=7)L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE
M<F%T97,@86X@55),('1O('1H92!L;V=O=70@<V-R965N('1H870@:6YC;'5D
M97,@86YY(&MN;W=N"B`@("`@*B!I;F9O<FUA=&EO;BP@<W5C:"!A<R!U<V5R
M;F%M92P@<V5R=F5R+"!E=&,N+"!T:&%T(&-A;B!B92!F:6QL960@:6X@;VX*
M("`@("`J('1H92!L;V=I;B!F;W)M+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!,;V=O=70@55),('=I=&@@;&]G;W5T('!A<F%M971E<G,@861D
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9V]U=%5R;"@I"B`@("!["B`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`G:6UA<'5S97(G
M(#T^(&ES<V5T*"1?4T534TE/3ELG:6UP)UU;)W5S97(G72D@/PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W5S97(G72`Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H
M)VEM87!U<V5R)RDL"B`@("`@("`@("`@("=S97)V97(G("`@/3X@:7-S970H
M)%]315-324].6R=I;7`G75LG<V5R=F5R)UTI(#\*("`@("`@("`@("`@("`@
M("`@("`@("`@("`D7U-%4U-)3TY;)VEM<"==6R=S97)V97(G72`Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)W-E<G9E
M<B<I+`H@("`@("`@("`@("`G<&]R="<@("`@(#T^(&ES<V5T*"1?4T534TE/
M3ELG:6UP)UU;)W!O<G0G72D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP)UU;)W!O<G0G72`Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)W!O<G0G*2P*("`@("`@("`@
M("`@)W!R;W1O8V]L)R`]/B!I<W-E="@D7U-%4U-)3TY;)VEM<"==6R=P<F]T
M;V-O;"==*2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@)%]315-324].
M6R=I;7`G75LG<')O=&]C;VPG72`Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@571I;#HZ9V5T1F]R;41A=&$H)W!R;W1O8V]L)RDL"B`@("`@("`@("`@
M("=L86YG=6%G92<@/3X@:7-S970H)%]315-324].6R=I;7`G75LG;&%N9W5A
M9V4G72D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG
M:6UP)UU;)VQA;F=U86=E)UT@.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M(%5T:6PZ.F=E=$9O<FU$871A*"=L86YG=6%G92<I+`H@("`@("`@("`@("`G
M<VUT<&AO<W0G(#T^(&ES<V5T*"1?4T534TE/3ELG:6UP)UU;)W-M='!H;W-T
M)UTI(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM
M<"==6R=S;71P:&]S="==(#H*("`@("`@("`@("`@("`@("`@("`@("`@("!5
M=&EL.CIG971&;W)M1&%T82@G<VUT<&AO<W0G*2P*("`@("`@("`@("`@)W-M
M='!P;W)T)R`]/B!I<W-E="@D7U-%4U-)3TY;)VEM<"==6R=S;71P<&]R="==
M*2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G
M75LG<VUT<'!O<G0G72`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@571I
M;#HZ9V5T1F]R;41A=&$H)W-M='!P;W)T)RDL"B`@("`@("`@*3L*"B`@("`@
M("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@G;&]G:6XN<&AP)RP@87)R
M87E?9&EF9B@D<&%R86US+"!A<G)A>2@G)RDI+"!N=6QL+"!F86QS92D["B`@
M("`@("`@<F5T=7)N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D=7)L+"!T<G5E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($EF('1H97)E(&ES(&EN9F]R;6%T
M:6]N(&%V86EL86)L92!T;R!T96QL('5S(&%B;W5T(&$@<')E9FEX(&EN(&9R
M;VYT(&]F"B`@("`@*B!M86EL8F]X(&YA;65S('1H870@<VAO=6QD;B=T(&)E
M(&1I<W!L87EE9"!T;R!T:&4@=7-E<BP@=&AE;B!U<V4@:70@=&\*("`@("`J
M('-T<FEP('1H870@<')E9FEX(&]U="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F;VQD97(@(%1H92!F;VQD97(@;F%M92!T;R!D:7-P;&%Y+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9F]L9&5R+"!W:71H
M(&%N>2!P<F5F:7@@9V]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES<&QA
M>49O;&1E<B@D9F]L9&5R*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4@
M/2!A<G)A>2@I.PH*("`@("`@("!I9B`H:7-S970H)&-A8VAE6R1F;VQD97)=
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&-A8VAE6R1F;VQD97)=.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1F;VQD97(@/3T@)TE.0D]8)RD@>PH@("`@
M("`@("`@("`D8V%C:&5;)&9O;&1E<ET@/2!?*"));F)O>"(I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1N86UE<W!A8V5?:6YF;R`]($E-4#HZ
M9V5T3F%M97-P86-E*"1F;VQD97(I.PH@("`@("`@("`@("!I9B`H(6ES7VYU
M;&PH)&YA;65S<&%C95]I;F9O*2`F)@H@("`@("`@("`@("`@("`@(65M<'1Y
M*"1N86UE<W!A8V5?:6YF;ULG;F%M92==*2`F)@H@("`@("`@("`@("`@("`@
M*"1N86UE<W!A8V5?:6YF;ULG='EP92==(#T]("=P97)S;VYA;"<I("8F"B`@
M("`@("`@("`@("`@("!S=6)S='(H)&9O;&1E<BP@,"P@<W1R;&5N*"1N86UE
M<W!A8V5?:6YF;ULG;F%M92==*2D@/3T@)&YA;65S<&%C95]I;F9O6R=N86UE
M)UTI('L*("`@("`@("`@("`@("`@("1C86-H95LD9F]L9&5R72`]('-U8G-T
M<B@D9F]L9&5R+"!S=')L96XH)&YA;65S<&%C95]I;F9O6R=N86UE)UTI*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C86-H95LD
M9F]L9&5R72`]("1F;VQD97(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1C86-H95LD9F]L9&5R72`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&-A
M8VAE6R1F;VQD97)=+"`G551&-RU)34%0)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&-A8VAE6R1F;VQD97)=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1FEL=&5R<R!A('-T<FEN9RP@:68@<F5Q=65S=&5D+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O(&9I;'1E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9I;'1E<F5D('1E
M>'0@*&EF(')E<75E<W1E9"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I;'1E
M<E1E>'0H)'1E>'0I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF+"`D<')E
M9G,["@H@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=F:6QT97)I;F<G
M*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL
M=&5R+G!H<"<["B`@("`@("`@("`@("1T97AT(#T@5&5X=%]&:6QT97(Z.F9I
M;'1E<B@D=&5X="P@)W=O<F1S)RP@87)R87DH)W=O<F1S7V9I;&4G(#T^("1C
M;VYF6R=M<V=S971T:6YG<R==6R=F:6QT97)I;F<G75LG=V]R9',G72P@)W)E
M<&QA8V5M96YT)R`]/B`D8V]N9ELG;7-G<V5T=&EN9W,G75LG9FEL=&5R:6YG
M)UU;)W)E<&QA8V5M96YT)UTI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-P
M96-I9FEE9"!P97)M:7-S:6]N(&9O<B!T:&4@8W5R<F5N="!U<V5R+@H@("`@
M("H*("`@("`J($!S:6YC92!)35`@-"XQ"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&5R;6ES<VEO;B`@02!P97)M:7-S:6]N+"!E:71H97(@)V-R
M96%T95]F;VQD97)S)R!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VUA>%]F;VQD97)S)RX*("`@("`J($!P87)A;2!B;V]L96%N("1V
M86QU92`@("`@($EF('1R=64L('1H92!M971H;V0@<F5T=7)N<R!T:&4@=F%L
M=64@;V8@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<V-A
M;&%R('!E<FUI<W-I;VXL(&]T:&5R=VES92!W:&5T:&5R('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<&5R;6ES<VEO;B!L:6UI="!H
M87,@8F5E;B!H:70@86QR96%D>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@=F%L=64@;V8@=&AE('-P96-I9FEE9"!P97)M:7-S:6]N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1P97)M:7-S:6]N
M+"`D=F%L=64@/2!F86QS92D*("`@('L*("`@("`@("!G;&]B86P@)'!E<FUS
M.PH*("`@("`@("!I9B`H(21P97)M<RT^97AI<W1S*"=I;7`Z)R`N("1P97)M
M:7-S:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1A;&QO=V5D(#T@)'!E<FUS+3YG971097)M:7-S:6]N<R@G
M:6UP.B<@+B`D<&5R;6ES<VEO;BD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1A
M;&QO=V5D*2D@>PH@("`@("`@("`@("!S=VET8V@@*"1P97)M:7-S:6]N*2![
M"B`@("`@("`@("`@(&-A<V4@)V-R96%T95]F;VQD97)S)SH*("`@("`@("`@
M("`@("`@("1A;&QO=V5D(#T@87)R87E?<F5D=6-E*"1A;&QO=V5D+"!C<F5A
M=&5?9G5N8W1I;VXH)R1A+"`D8B<L("=R971U<FX@)&$@?"`D8CLG*2P@9F%L
M<V4I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@
M)VUA>%]F;VQD97)S)SH*("`@("`@("`@("`@("`@("1A;&QO=V5D(#T@87)R
M87E?<F5D=6-E*"1A;&QO=V5D+"!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L
M("=R971U<FX@;6%X*"1A+"`D8BD[)RDL(#`I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1P
M97)M:7-S:6]N(#T]("=M87A?9F]L9&5R<R<@)B8@(21V86QU92D@>PH@("`@
M("`@("`@("`D9F]L9&5R(#T@)DE-4%]&;VQD97(Z.G-I;F=L971O;B@I.PH@
M("`@("`@("`@("`D86QL;W=E9"`]("1A;&QO=V5D(#X@8V]U;G0H)&9O;&1E
M<BT^9FQI<W1?24U0*&%R<F%Y*"DL(&9A;'-E*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&%L;&]W960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"
M=6EL9"!)35`G<R!L:7-T(&]F(&UE;G4@:71E;7,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$UE;G4H)')E='5R;E1Y<&4@/2`G;V)J96-T)RD*("`@('L*
M("`@("`@("!G;&]B86P@)&-O;F8L("1P<F5F<RP@)')E9VES=')Y.PH*("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*"B`@("`@("`@
M)&UE;G5?<V5A<F-H7W5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5A
M<F-H+G!H<"<I.PH@("`@("`@("1M96YU7VUA:6QB;WA?=7)L(#T@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=M86EL8F]X+G!H<"<I.PH@("`@("`@("1M96YU
M7V%L;&]W7V9O;&1E<G,@/2`H)&-O;F9;)W5S97(G75LG86QL;W=?9F]L9&5R
M<R==("8F(&ES<V5T*"1M96YU7V9O;&1E<G,I*3L*"B`@("`@("`@)'-P86U?
M9F]L9&5R(#T@24U0.CIF;VQD97)0<F5F*"1P<F5F<RT^9V5T5F%L=64H)W-P
M86U?9F]L9&5R)RDL('1R=64I.PH*("`@("`@("`D;65N=2`]("9N97<@365N
M=2A(3U)$15]-14Y57TU!4TM?04Q,("8@?DA/4D1%7TU%3E5?34%32U],3T=)
M3BD["@H@("`@("`@("1M96YU+3YA9&0H571I;#HZ861D4&%R86UE=&5R*"1M
M96YU7VUA:6QB;WA?=7)L+"`G;6%I;&)O>"<L("=)3D)/6"<I+"!?*")?26YB
M;W@B*2P@)V9O;&1E<G,O:6YB;W@N<&YG)RD["B`@("`@("`@:68@*"@D7U-%
M4U-)3TY;)VEM<"==6R=B87-E7W!R;W1O8V]L)UT@(3T@)W!O<#,G*2`F)@H@
M("`@("`@("`@("`H)'!R969S+3YG971686QU92@G=7-E7W1R87-H)RD@?'P@
M)'!R969S+3YG971686QU92@G=7-E7W9T<F%S:"<I*2`F)@H@("`@("`@("`@
M("`D<')E9G,M/F=E=%9A;'5E*"=E;7!T>5]T<F%S:%]M96YU)RDI('L*("`@
M("`@("`@("`@)&UA:6QB;W@@/2!N=6QL.PH@("`@("`@("`@("!I9B`H)'!R
M969S+3YG971686QU92@G=7-E7W9T<F%S:"<I*2!["B`@("`@("`@("`@("`@
M("`D;6%I;&)O>"`]($E-4%]314%20TA?34)/6"`N("`D<')E9G,M/F=E=%9A
M;'5E*"=V=')A<VA?:60G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T<F%S:%]F;VQD97(@/2!)35`Z.F9O;&1E<E!R968H)'!R
M969S+3YG971686QU92@G=')A<VA?9F]L9&5R)RDL('1R=64I.PH@("`@("`@
M("`@("`@("`@:68@*"%I<U]N=6QL*"1T<F%S:%]F;VQD97(I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&UA:6QB;W@@/2`D=')A<VA?9F]L9&5R.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M(6ES7VYU;&PH)&UA:6QB;W@I*2!["B`@("`@("`@("`@("`@("`D;65N=5]T
M<F%S:%]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&UE;G5?;6%I;&)O>%]U
M<FPL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)VUA:6QB;W@G(#T^("1M86EL8F]X+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=A8W1I;VY)1"<@/3X@)V5M<'1Y7VUA:6QB;W@G*2D["B`@
M("`@("`@("`@("`@("`D;65N=2T^861D*"1M96YU7W1R87-H7W5R;"P@7R@B
M16UP='D@7U1R87-H(BDL("=E;7!T>5]T<F%S:"YP;F<G+"!N=6QL+"!N=6QL
M+"`B<F5T=7)N('=I;F1O=RYC;VYF:7)M*"<B("X@861D<VQA<VAE<RA?*")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@96UP='D@>6]U<B!T<F%S:"!F;VQD
M97(_(BDI("X@(B<I.R(L("=?7VYO<V5L96-T:6]N)RD["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("@H)%]315-324].6R=I;7`G75LG
M8F%S95]P<F]T;V-O;"==("$]("=P;W`S)RD@)B8@*"1S<&%M7V9O;&1E<B`A
M/3T@;G5L;"D@)B8@)'!R969S+3YG971686QU92@G96UP='E?<W!A;5]M96YU
M)RDI('L*("`@("`@("`@("`@)&UE;G5?<W!A;5]U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H)&UE;G5?;6%I;&)O>%]U<FPL(&%R<F%Y*"=M86EL8F]X)R`]
M/B`D<W!A;5]F;VQD97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M86-T:6]N240G(#T^("=E;7!T>5]M86EL8F]X)RDI.PH@("`@("`@("`@("`D
M;65N=2T^861D*"1M96YU7W-P86U?=7)L+"!?*")%;7!T>2!?4W!A;2(I+"`G
M96UP='E?<W!A;2YP;F<G+"!N=6QL+"!N=6QL+"`B<F5T=7)N('=I;F1O=RYC
M;VYF:7)M*"<B("X@861D<VQA<VAE<RA?*")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@96UP='D@>6]U<B!S<&%M(&9O;&1E<C\B*2D@+B`B)RD[(BP@)U]?
M;F]S96QE8W1I;VXG*3L*("`@("`@("!]"@H@("`@("`@("1M96YU+3YA9&0H
M24U0.CIC;VUP;W-E3&EN:R@I+"!?*")?3F5W($UE<W-A9V4B*2P@)V-O;7!O
M<V4N<&YG)RD["@H@("`@("`@(&EF("@D8V]N9ELG=7-E<B==6R=A;&QO=U]F
M;VQD97)S)UTI('L*("`@("`@("`@("`@)&UE;G4M/F%D9"A5=&EL.CIN;V-A
M8VAE57)L*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9F]L9&5R<RYP:'`G*2DL
M(%\H(E]&;VQD97)S(BDL("=F;VQD97)S+V9O;&1E<BYP;F<G*3L*("`@("`@
M("!]"B`@("`@("`@)&UE;G4M/F%D9"@D;65N=5]S96%R8VA?=7)L+"!?*")?
M4V5A<F-H(BDL("=S96%R8V@N<&YG)RP@)')E9VES=')Y+3YG971);6%G941I
M<B@G:&]R9&4G*2D["B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)V9E
M=&-H;6%I;%]M96YU)RDI('L*("`@("`@("`@("`@:68@*"1P<F5F<RT^9V5T
M5F%L=64H)V9E=&-H;6%I;%]P;W!U<"<I*2!["B`@("`@("`@("`@("`@("`D
M;65N=2T^861D*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9F5T8VAM86EL+G!H
M<"<I+"!?*")&7V5T8V@@36%I;"(I+"`G9F5T8VAM86EL+G!N9R<L(&YU;&PL
M("=F971C:&UA:6PG+"`G=VEN9&]W+F]P96XH7"<G("X@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=F971C:&UA:6PN<&AP)RDN("=<)RP@7"=F971C:&UA:6Q<
M)RP@7"=T;V]L8F%R/6YO+&QO8V%T:6]N/6YO+'-T871U<SUY97,L<V-R;VQL
M8F%R<SUY97,L<F5S:7IA8FQE/7EE<RQW:61T:#TS,#`L:&5I9VAT/30U,"QL
M969T/3$P,"QT;W`],3`P7"<I.R!R971U<FX@9F%L<V4[)RD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;65N=2T^861D*$AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G9F5T8VAM86EL+G!H<"<I+"!?*")&7V5T8V@@
M36%I;"(I+"`G9F5T8VAM86EL+G!N9R<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=F:6QT97)?;65N
M=6ET96TG*2D@>PH@("`@("`@("`@("`D;65N=2T^861D*$AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G9FEL=&5R<')E9G,N<&AP)RDL(%\H(D9I7VQT97)S(BDL
M("=F:6QT97)S+G!N9R<I.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]G;W5T
M+B!)9B!)35`@8V%N(&%U=&\@;&]G:6X@;W(@24U0(&ES('!R;W9I9&EN9PH@
M("`@("`@("`J(&%U=&AE;G1I8V%T:6]N+"!T:&5N('=E(&]N;'D@<VAO=R!T
M:&4@;&]G;W5T(&QI;FL@:68@=&AE"B`@("`@("`@("H@<VED96)A<B!I<VXG
M="!S:&]W;B!O<B!I9B!T:&4@8V]N9FEG=7)A=&EO;B!S87ES('1O(&%L=V%Y
M<PH@("`@("`@("`J('-H;W<@=&AE(&-U<G)E;G0@=7-E<B!A(&QO9V]U="!L
M:6YK+B`J+PH@("`@("`@("1I;7!!=71H(#T@075T:#HZ9V5T4')O=FED97(H
M*2`]/2`G:6UP)SL*("`@("`@("`D:6UP075T;TQO9VEN(#T@24U0.CIC86Y!
M=71O3&]G:6XH*3L*("`@("`@("!I9B`H(2@D:6UP075T:"!\?"`D:6UP075T
M;TQO9VEN*2!\?`H@("`@("`@("`@("`A)'!R969S+3YG971686QU92@G<VAO
M=U]S:61E8F%R)RD@?'P*("`@("`@("`@("`@2&]R9&4Z.G-H;W=397)V:6-E
M*"=L;V=O=70G*2D@>PH*("`@("`@("`@("`@+RH@268@24U0('!R;W9I9&5S
M(&%U=&AE;G1I8V%T:6]N(&%N9"!T:&4@<VED96)A<B!I<VXG=`H@("`@("`@
M("`@("`@*B!A;'=A>7,@;VXL('1A<F=E="!T:&4@;6%I;B!F<F%M92!F;W(@
M;&]G;W5T('1O(&AI9&4@=&AE"B`@("`@("`@("`@("`J('-I9&5B87(@=VAI
M;&4@;&]G9V5D(&]U="X@*B\*("`@("`@("`@("`@)&QO9V]U=%]T87)G970@
M/2!N=6QL.PH@("`@("`@("`@("!I9B`H)&EM<$%U=&@@?'P@)&EM<$%U=&],
M;V=I;BD@>PH@("`@("`@("`@("`@("`@)&QO9V]U=%]T87)G970@/2`G7W!A
M<F5N="<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($EF($E-4"!D
M;V5S;B=T('!R;W9I9&4@2&]R9&4@875T:&5N=&EC871I;VX@=&AE;B!W90H@
M("`@("`@("`@("`@*B!N965D('1O('5S92!)35`G<R!L;V=O=70@<V-R965N
M('-I;F-E(&QO9V=I;F<@;W5T"B`@("`@("`@("`@("`J('-H;W5L9"`J;F]T
M*B!E;F0@82!(;W)D92!S97-S:6]N+B`J+PH@("`@("`@("`@("!I9B`H)&EM
M<$%U=&@@?'P@)&EM<$%U=&],;V=I;BD@>PH@("`@("`@("`@("`@("`@)&QO
M9V]U=%]U<FP@/2!(;W)D93HZ9V5T4V5R=FEC94QI;FLH)VQO9V]U="<L("=H
M;W)D92<L('1R=64I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&QO9V]U=%]U<FP@/2!!=71H.CIA9&1,;V=O=71087)A;65T97)S
M*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G;&]G:6XN<&AP)RDL($%55$A?4D5!
M4T].7TQ/1T]55"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1I9"`]
M("1M96YU+3YA9&0H)&QO9V]U=%]U<FPL(%\H(E],;V<@;W5T(BDL("=L;V=O
M=70N<&YG)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2P@)&QO
M9V]U=%]T87)G970I.PH@("`@("`@("`@("`D;65N=2T^<V5T4&]S:71I;VXH
M)&ED+"!(3U)$15]-14Y57U!/4U],05-4*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D<F5T=7)N5'EP92`]/2`G;V)J96-T)RD@>PH@("`@("`@("`@("!R
M971U<FX@)&UE;G4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("1M96YU+3YR96YD97(H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!/=71P=71S($E-4"=S('-T871U<R]N;W1I9FEC871I;VX@8F%R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&%T=7,H*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D;F]T:69I8V%T:6]N.PH*("`@("`@("!I9B`H:7-S970H)%]3
M15-324].6R=I;7`G75LG<W1R96%M)UTI*2!["B`@("`@("`@("`@("1A;&5R
M=',@/2!I;6%P7V%L97)T<R@I.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)&%L97)T<RDI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A;&5R=',@
M87,@)&%L97)T*2!["B`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"@D86QE<G0L("=H;W)D92YM97-S86=E)RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($)#
M(&-H96-K+B`J+PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)TYO=&EF:6-A
M=&EO;E],:7-T96YE<E]A=61I;R<I*2!["B`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B!A<G)A>2@G<W1A
M='5S)RP@)V%U9&EO)RDI*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!J879A<V-R:7!T(&9O<B!A(&YE=R!M97-S86=E
M(&YO=&EF:6-A=&EO;B!P;W!U<"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&YE=VUS9W,@($%S<V]C:6%T:79E(&%R<F%Y('=I=&@@;6%I;&)O>"!N
M86UE<R!A<R!T:&4@:V5Y<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!A;F0@=&AE(&UE<W-A9V4@8V]U;G0@87,@=&AE('9A;'5E<PH@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@:F%V87-C<FEP="!F;W(@=&AE
M('!O<'5P(&UE<W-A9V4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F5W365S
M<V%G95!O<'5P*"1N97=M<V=S*0H@("`@>PH@("`@("`@("1?86QE<G0@/2`G
M)SL*("`@("`@("`D8V]U;G0@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1N97=M
M<V=S(&%S("1M8B`]/B`D;FTI('L*("`@("`@("`@("`@)&-O=6YT*RL["B`@
M("`@("`@("`@("1?;6%I;&)O>%]M97-S86=E(#T@)&UB.PH@("`@("`@("`@
M("`D7V%L97)T("X]($E-4#HZ9&ES<&QA>49O;&1E<B@D7VUA:6QB;WA?;65S
M<V%G92D@+@H@("`@("`@("`@("`@("`@*"1N;2`^(#$@/R!?*"(@+2`D;FT@
M;F5W(&UE<W-A9V5S(BD@.B!?*"(@+2`D;FT@;F5W(&UE<W-A9V4B*2D@+B`G
M7&XG.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1?86QE<G0I*2![
M"B`@("`@("`@("`@(&EF("@D8V]U;G0@/3T@,2D@>PH@("`@("`@("`@("`@
M("`@)&UA:6QB;WA/<&5N57)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=M
M86EL8F]X+G!H<"<L('1R=64I.PH@("`@("`@("`@("`@("`@)&UA:6QB;WA/
M<&5N57)L(#T@571I;#HZ861D4&%R86UE=&5R*"1M86EL8F]X3W!E;E5R;"P@
M87)R87DH)VYO7VYE=VUA:6Q?<&]P=7`G(#T^(#$L("=M86EL8F]X)R`]/B`D
M7VUA:6QB;WA?;65S<V%G92DI.PH*("`@("`@("`@("`@("`@(')E='5R;B`B
M:68@*&-O;F9I<FTH)R(@+B!A9&1S;&%S:&5S*%\H(EEO=2!H879E(&YE=R!M
M86EL(&EN('1H92!F;VQL;W=I;F<@9F]L9&5R.B(I*2`N("=<;B<@+@H@("`@
M("`@("`@("`@("`@("`@("1?86QE<G0@+B!A9&1S;&%S:&5S*%\H(D1O('EO
M=2!W86YT('1O(&]P96X@=&AA="!F;VQD97(_(BDI("X*("`@("`@("`@("`@
M("`@("`@("`B)RDI('L@=VEN9&]W+FQO8V%T:6]N+FAR968@/2`G(B`N('-T
M<E]R97!L86-E*"<F86UP.R<L("<F)RP@)&UA:6QB;WA/<&5N57)L*2`N"B`@
M("`@("`@("`@("`@("`@("`@(B<[('=I;F1O=RYF;V-U<R@I.R!](CL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`B86QE
M<G0H)R(@+B!A9&1S;&%S:&5S*%\H(EEO=2!H879E(&YE=R!M86EL(&EN('1H
M92!F;VQL;W=I;F<@9F]L9&5R<SHB*2D@+@H@("`@("`@("`@("`@("`@("`@
M("=<;B<@+B`D7V%L97)T("XB)RD[(CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@55),('1O
M('1H92!P<F5F<R!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1F=6QL("!'96YE<F%T92!F=6QL(%523#\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(%523"!T;R!T:&4@24U0('!R969S('!A9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('!R969S55),*"1F=6QL(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@<F5T=7)N($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]P
M<F5F<RYP:'`_87!P/6EM<"<L("1F=6QL*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%R92!W92!C=7)R96YT;'D@:6X@(G!R:6YT(B!M;V1E/PH@("`@("H*
M("`@("`J($!P87)A;2!B;V]L96%N("1M;V1E("!4<G5E(&EF(&EN('!R:6YT
M(&UO9&4L(&9A;'-E(&EF(&YO="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%)E='5R;G,@=')U92!I9B!I;B`B<')I;G0B(&UO9&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!R:6YT36]D92@D;6]D92`](&YU;&PI"B`@("![
M"B`@("`@("`@<W1A=&EC("1P<FEN="`](&9A;'-E.PH@("`@("`@(&EF("@A
M:7-?;G5L;"@D;6]D92DI('L*("`@("`@("`@("`@)'!R:6YT(#T@)&UO9&4[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<')I;G0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@;65S<V%G92!I;F1I8V5S(&QI<W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1I;F1I8V5S("!4:&4@9F]L;&]W:6YG(&EN
M<'5T<R!A<F4@86QL;W=E9#H*("`@("`J(#QP<F4^"B`@("`@*B`Q+B!!;B!A
M<G)A>2!O9B!M97-S86=E<R!I;F1I8V5S(&EN('1H92!F;VQL;W=I;F<@9F]R
M;6%T.@H@("`@("H@("`@;7-G7VED($E-4%])1%A?4T50(&US9U]F;VQD97(*
M("`@("`J("`@(&US9U]I9"`]($UE<W-A9V4@:6YD97@@;V8@=&AE(&UE<W-A
M9V4*("`@("`J("`@($E-4%])1%A?4T50(#T@24U0(&-O;G-T86YT('5S960@
M=&\@<V5P87)A=&4@:6YD97@O9F]L9&5R"B`@("`@*B`@("!M<V=?9F]L9&5R
M(#T@5&AE(&9U;&P@9F]L9&5R(&YA;64@8V]N=&%I;FEN9R!T:&4@;65S<V%G
M92!I;F1E>`H@("`@("H@,BX@06X@87)R87D@=VET:"!T:&4@9G5L;"!F;VQD
M97(@;F%M92!A<R!K97ES(&%N9"!A;B!A<G)A>2!O9B!M97-S86=E"B`@("`@
M*B`@("!I;F1I8V5S(&%S('1H92!V86QU97,N"B`@("`@*B`S+B!!;B!)35!?
M36%I;&)O>"!O8FIE8W0L('=H:6-H('=I;&P@=7-E('1H92!C=7)R96YT(&EN
M9&5X+V9O;&1E<@H@("`@("H@("`@87,@9&5T97)M:6YE9"!B>2!T:&4@;V)J
M96-T+B!)9B!A;B!)35!?36%I;&)O>"!O8FIE8W0@:7,@=7-E9"P@:70*("`@
M("`J("`@('=I;&P@8F4@=7!D871E9"!A9G1E<B!T:&4@86-T:6]N(&ES('!E
M<F9O<FUE9"X*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%)E='5R;G,@86X@87)R87D@=VET:"!T:&4@9F]L9&5R(&%S(&ME
M>2!A;F0@86X@87)R87D*("`@("`J("`@("`@("`@("`@("`@(&]F(&UE<W-A
M9V4@:6YD:6-E<R!A<R!T:&4@=F%L=64@*%-E92`C,B!A8F]V92DN"B`@("`@
M*B`@("`@("`@("`@("`@("!%;'-E+"!R971U<FYS(&9A;'-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!P87)S94EN9&EC97-,:7-T*"1I;F1I8V5S*0H@("`@
M>PH@("`@("`@("1M<V=,:7-T(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES
M7V$H)&EN9&EC97,L("=)35!?36%I;&)O>"<I*2!["B`@("`@("`@("`@("1M
M<V=)9'@@/2`D:6YD:6-E<RT^9V5T24U!4$EN9&5X*"D["B`@("`@("`@("`@
M(&EF("AE;7!T>2@D;7-G261X*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1M<V=,:7-T6R1M
M<V=)9'A;)VUA:6QB;W@G75U;72`]("1M<V=)9'A;)VEN9&5X)UT["B`@("`@
M("`@("`@(')E='5R;B`D;7-G3&ES=#L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-?87)R87DH)&EN9&EC97,I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"%C;W5N="@D:6YD:6-E<RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("!R97-E="@D:6YD:6-E<RD["B`@("`@("`@:68@*&ES7V%R<F%Y*&-U
M<G)E;G0H)&EN9&EC97,I*2D@>PH@("`@("`@("`@("`O*B!"=6EL9"!T:&4@
M;&ES="!O9B!I;F1I8V5S+VUA:6QB;WAE<R!T;R!D96QE=&4@:68@:6YP=70*
M("`@("`@("`@("`@("`@:7,@;V8@9F]R;6%T(",Q+B`J+PH@("`@("`@("`@
M("!F;W)E86-H("@D:6YD:6-E<R!A<R`D;6)O>"`]/B`D;7-G<RD@>PH@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&US9W,@87,@)&US9TEN9&5X*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;7-G26YD97@L($E-4%])
M1%A?4T50*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&US9TQI<W1;)&UB;WA=6UT@/2`D;7-G26YD97@["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D
M=F%L+"`D:V5Y*2`](&5X<&QO9&4H24U07TE$6%]315`L("1M<V=);F1E>"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1M<V=,:7-T6R1K97E=6UT@/2`D
M=F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J
M(%=E(&%R92!D96%L:6YG('=I=&@@9F]R;6%T(",R+B!-86ME('-U<F4@=V4@
M9&]N)W0@:&%V90H@("`@("`@("`@("`@("!A;GD@9'5P;&EC871E(&ME>7,N
M("HO"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F1I8V5S(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M<V=,:7-T6R1K
M97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1M<V=,:7-T6R1K97E=(#T@
M87)R87E?=6YI<75E*&%R<F%Y7VUE<F=E*"1V86PL("1M<V=,:7-T6R1K97E=
M*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1M<V=,:7-T6R1K97E=(#T@:7-?87)R87DH)'9A;"D@/R`D=F%L(#H@
M87)R87DH)'9A;"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;7-G3&ES=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($5I=&AE<B!S971S(&]R(&-H96-K<R!T:&4@=F%L=64@
M;V8@=&AE(&QO9VEN=&%S:W,@9FQA9RX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<V5T("!4:&4@=F%L=64@;V8@=&AE(&9L86<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=F%L=64@;V8@=&AE(&9L86<N
M"B`@("`@*B`@("`@("`@("`@("`@("`@(#`@/2!.;R!L;V=I;B!T87-K<R!P
M96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@(#$@/2!,;V=I;B!T87-K
M<R!P96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@(#(@/2!,;V=I;B!T
M87-K<R!P96YD:6YG+"!P<F5V:6]U<R!T87-K<R!I;G1E<G)U<'1E9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!L;V=I;E1A<VMS1FQA9R@D<V5T(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)'-E="DI('L*("`@("`@("`@
M("`@)%]315-324].6R=I;7`G75LG7VQO9VEN=&%S:W,G72`]("1S970["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@:7-S970H)%]315-324].6R=I;7`G
M75LG7VQO9VEN=&%S:W,G72D@/R`D7U-%4U-)3TY;)VEM<"==6R=?;&]G:6YT
M87-K<R==(#H@,#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!N86UE<W!A
M8V4@:6YF;R!F;W(@82!F=6QL(&9O;&1E<B!P871H+@H@("`@("H*("`@("`J
M($!S:6YC92!)35`@-"XQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;6%I;&)O>"`@5&AE(&9O;&1E<B!P871H+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&5M<'1Y("`@268@=')U92!A;F0@;F\@;6%T8VAI;F<@;F%M97-P86-E
M(&ES(&9O=6YD+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N('1H92!E;7!T>2!N86UE<W!A8V4L(&EF(&ET(&5X:7-T<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@;F%M97-P86-E(&EN9F\@9F]R
M('1H92!F;VQD97(@<&%T:"!O<B!N=6QL(&EF('1H90H@("`@("H@("`@("`@
M("`@("`@("`@<&%T:"!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971.86UE<W!A8V4H)&UA:6QB;W@L("1E;7!T>2`]('1R=64I"B`@
M("!["B`@("`@("`@<W1A=&EC("1C86-H92`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("@D7U-%4U-)3TY;)VEM<"==6R=B87-E7W!R;W1O8V]L)UT@/3T@)W!O
M<#,G*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@
M("`@("`@)&ME>2`]("AI;G0I)&5M<'1Y.PH@("`@("`@(&EF("AI<W-E="@D
M8V%C:&5;)&ME>5U;)&UA:6QB;WA=*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&-A8VAE6R1K97E=6R1M86EL8F]X73L*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1?4T534TE/3ELG:6UP)UU;)VYA;65S<&%C92==(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1K97DI("8F("AS
M=')P;W,H)&UA:6QB;W@L("1K97DI(#T]/2`P*2D@>PH@("`@("`@("`@("`@
M("`@)&-A8VAE6R1K97E=6R1M86EL8F]X72`]("1V86P["B`@("`@("`@("`@
M("`@("!R971U<FX@)'9A;#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*"1E;7!T>2`F)B!I<W-E="@D7U-%4U-)3TY;)VEM<"==6R=N
M86UE<W!A8V4G75LG)UTI*2!["B`@("`@("`@("`@("1C86-H95LD:V5Y75LD
M;6%I;&)O>%T@/2`D7U-%4U-)3TY;)VEM<"==6R=N86UE<W!A8V4G75LG)UT[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A8VAE6R1K97E=6R1M
M86EL8F]X72`](&YU;&P["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A
M8VAE6R1K97E=6R1M86EL8F]X73L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@9&5F875L="!P97)S;VYA;"!N86UE<W!A8V4N"B`@("`@*@H@("`@
M("H@0'-I;F-E($E-4"`T+C$*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@9&5F875L="!P97)S;VYA;"!N86UE<W!A8V4@:6YF;RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9&5F875L=$YA;65S<&%C92@I"B`@("!["B`@("`@
M("`@<W1A=&EC("1D969A=6QT(#T@;G5L;#L*"B`@("`@("`@:68@*"1?4T53
M4TE/3ELG:6UP)UU;)V)A<V5?<')O=&]C;VPG72`]/2`G<&]P,R<I('L*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(21D969A=6QT*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1?4T534TE/3ELG
M:6UP)UU;)VYA;65S<&%C92==(&%S("1V86PI('L*("`@("`@("`@("`@("`@
M(&EF("@D=F%L6R=T>7!E)UT@/3T@)W!E<G-O;F%L)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1D969A=6QT(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1D969A=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0V]N=F5R="!A('!R969E<F5N8V4@=F%L=64@=&\O9G)O;2!T
M:&4@=F%L=64@<W1O<F5D(&EN('1H92!P<F5F97)E;F-E<RX*("`@("`J"B`@
M("`@*B!0<F5F97)E;F-E<R!T:&%T(&YE960@=&\@8V%L;"!T:&ES(&9U;F-T
M:6]N(&)E9F]R92!S=&]R:6YG+W)E=')I979I;F<Z"B`@("`@*B`@('1R87-H
M7V9O;&1E<BP@<W!A;5]F;VQD97(L(&1R869T<U]F;VQD97(L('-E;G1?;6%I
M;%]F;VQD97(*("`@("`J(%1O(&%L;&]W(&9O;&1E<G,@9G)O;2!T:&4@<&5R
M<V]N86P@;F%M97-P86-E('1O(&)E('-T;W)E9"!W:71H;W5T('1H:7,*("`@
M("`J('!R969I>"!F;W(@<&]R=&%B:6QI='DL('=E('-T<FEP('1H92!P97)S
M;VYA;"!N86UE<W!A8V4N(%1O('1E;&P@87!A<G0*("`@("`J(&9O;&1E<G,@
M9G)O;2!T:&4@<&5R<V]N86P@86YD(&%N>2!E;7!T>2!N86UE<W!A8V4L('=E
M('!R969I>"!F;VQD97)S"B`@("`@*B!F<F]M('1H92!E;7!T>2!N86UE<W!A
M8V4@=VET:"!T:&4@9&5L:6UI=&5R+@H@("`@("H*("`@("`J($!S:6YC92!)
M35`@-"XQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@
M5&AE(&9O;&1E<B!P871H+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%P<&5N
M9"`@5')U92`M(&-O;G9E<G0@9G)O;2!P<F5F97)E;F-E('9A;'5E+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@1F%L<V4@+2!C;VYV97)T('1O
M('!R969E<F5N8V4@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!F;VQD97(@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9F]L
M9&5R4')E9B@D9F]L9&5R+"`D87!P96YD*0H@("`@>PH@("`@("`@("1D969?
M;G,@/2!)35`Z.F1E9F%U;'1.86UE<W!A8V4H*3L*("`@("`@("`D96UP='E?
M;G,@/2!)35`Z.F=E=$YA;65S<&%C92@G)RD["B`@("`@("`@:68@*"1A<'!E
M;F0I('L*("`@("`@("`@("`@+RH@0V]N=F5R=&EN9R!F<F]M('!R969E<F5N
M8V4@=F%L=64N("HO"B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D96UP='E?
M;G,I("8F"B`@("`@("`@("`@("`@("!S=')P;W,H)&9O;&1E<BP@)&5M<'1Y
M7VYS6R=D96QI;6ET97(G72D@/3T](#`I('L*("`@("`@("`@("`@("`@("\J
M(%!R969I>&5D('=I=&@@9&5L:6UI=&5R(#T^(&9R;VT@96UP='D@;F%M97-P
M86-E+B`J+PH@("`@("`@("`@("`@("`@)&9O;&1E<B`]('-U8G-T<B@D9F]L
M9&5R+"!S=')L96XH)&5M<'1Y7VYS6R=D96QI;6ET97(G72DI.PH@("`@("`@
M("`@("!](&5L<V5I9B`H:7-?;G5L;"@D;G,@/2!)35`Z.F=E=$YA;65S<&%C
M92@D9F]L9&5R+"!F86QS92DI*2!["B`@("`@("`@("`@("`@("`O*B!.;R!N
M86UE<W!A8V4@<')E9FEX(#T^(&9R;VT@<&5R<V]N86P@;F%M97-P86-E+B`J
M+PH@("`@("`@("`@("`@("`@)&9O;&1E<B`]("1D969?;G-;)VYA;64G72`N
M("1F;VQD97(["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H(21A
M<'!E;F0@)B8@(6ES7VYU;&PH)&YS(#T@24U0.CIG971.86UE<W!A8V4H)&9O
M;&1E<BDI*2!["B`@("`@("`@("`@("\J($-O;G9E<G1I;F<@=&\@<')E9F5R
M96YC92!V86QU92X@*B\*("`@("`@("`@("`@:68@*"1N<ULG;F%M92==(#T]
M("1D969?;G-;)VYA;64G72D@>PH@("`@("`@("`@("`@("`@+RH@1G)O;2!P
M97)S;VYA;"!N86UE<W!A8V4@/3X@<W1R:7`@;F%M97-P86-E+B`J+PH@("`@
M("`@("`@("`@("`@)&9O;&1E<B`]('-U8G-T<B@D9F]L9&5R+"!S=')L96XH
M)&1E9E]N<ULG;F%M92==*2D["B`@("`@("`@("`@('T@96QS96EF("@D;G-;
M)VYA;64G72`]/2`D96UP='E?;G-;)VYA;64G72D@>PH@("`@("`@("`@("`@
M("`@+RH@1G)O;2!E;7!T>2!N86UE<W!A8V4@/3X@<')E9FEX('=I=&@@9&5L
M:6UI=&5R+B`J+PH@("`@("`@("`@("`@("`@)&9O;&1E<B`]("1E;7!T>5]N
M<ULG9&5L:6UI=&5R)UT@+B`D9F]L9&5R.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D9F]L9&5R.PH@("`@?0H*("`@("\J*@H@
M("`@("H@36%K92!S=7)E(&$@=7-E<BUE;G1E<F5D(&UA:6QB;W@@8V]N=&%I
M;G,@;F%M97-P86-E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!S:6YC
M92!)35`@-"XQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6)O>"`@
M5&AE('5S97(M96YT97)E9"!M86EL8F]X('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UA:6QB;W@@<W1R:6YG('=I=&@@86YY
M(&YE8V5S<V%R>2!N86UE<W!A8V4@:6YF;PH@("`@("H@("`@("`@("`@("`@
M("`@(&%D9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!E;F1.86UE<W!A
M8V4H)&UB;W@I"B`@("!["B`@("`@("`@)&YS7VEN9F\@/2!)35`Z.F=E=$YA
M;65S<&%C92@D;6)O>"P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]N=6QL*"1N
M<U]I;F9O*2D@>PH@("`@("`@("`@("`D;G-?:6YF;R`]($E-4#HZ9&5F875L
M=$YA;65S<&%C92@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&YS7VEN
M9F];)VYA;64G72`N("1M8F]X.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N
M97)A=&5S(&$@55),('=I=&@@86YY(&YE8V5S<V%R>2!I;F9O<FUA=&EO;B!R
M97%U:7)E9"!F;W(@:&%N9&QI;F<@80H@("`@("H@<V5A<F-H(&UA:6QB;W@@
M861D960@=&\@=&AE('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'-I;F-E
M($E-4"`T+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P86=E("`@
M("!086=E(&YA;64@=&\@;&EN:R!T;RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&UA:6QB;W@@(%1H92!M86EL8F]X('1O('5S92!O;B!T:&4@;&EN:V5D('!A
M9V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;F1E>"`@("!4:&4@:6YD97@@
M=&\@=7-E(&]N('1H92!L:6YK960@<&%G92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@55),('1O("1P86=E('=I=&@@86YY(&YE8V5S<V%R>2!S
M96%R8V@@:6YF;W)M871I;VX*("`@("`J("`@("`@("`@("`@("`@("!A9&1E
M9"!T;R!T:&4@<&%R86UE=&5R(&QI<W0@;V8@=&AE(%523"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5N97)A=&5396%R8VA5<FPH)'!A9V4L("1M86EL8F]X
M+"`D:6YD97@@/2!N=6QL*0H@("`@>PH@("`@("`@("1L:6YK(#T@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"1P86=E*3L*"B`@("`@("`@9F]R96%C:"`H24U0
M.CIG971396%R8VA087)A;65T97)S*"1M86EL8F]X+"`D:6YD97@I(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D;&EN:R`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D;&EN:RP@)&ME>2P@)'9A;"D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&QI;FL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@;&ES="!O9B!P87)A;65T97)S(&YE8V5S<V%R>2!F;W(@:&%N9&QI;F<@
M82!S96%R8V@@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`<VEN8V4@24U0(#0N
M,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UA:6QB;W@@(%1H92!M
M86EL8F]X('1O('5S92!O;B!T:&4@;&EN:V5D('!A9V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I;F1E>"`@("!4:&4@:6YD97@@=&\@=7-E(&]N('1H92!L
M:6YK960@<&%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M;&ES="!O9B!P87)A;65T97)S(&YE961E9"!F;W(@:&%N9&QI;F<@82!S96%R
M8V@*("`@("`J("`@("`@("`@("`@("`@(&UA:6QB;W@@*&UA>2!B92!E;7!T
M>2!I9B!N;W0@8W5R<F5N=&QY(&EN(&$@<V5A<F-H"B`@("`@*B`@("`@("`@
M("`@("`@("!M86EL8F]X*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5A
M<F-H4&%R86UE=&5R<R@D;6%I;&)O>"P@)&EN9&5X(#T@;G5L;"D*("`@('L*
M("`@("`@("`D<&%R86US(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES<V5T
M*"1'3$]"04Q36R=I;7!?<V5A<F-H)UTI("8F"B`@("`@("`@("`@("1'3$]"
M04Q36R=I;7!?<V5A<F-H)UTM/G-E87)C:$UB;WA)1"@I*2!["B`@("`@("`@
M("`@("1P87)A;7-;)W1H:7-M86EL8F]X)UT@/2`D;6%I;&)O>#L*("`@("`@
M("`@("`@)'!A<F%M<ULG;6%I;&)O>"==(#T@)$=,3T)!3%-;)VEM<"==6R=M
M86EL8F]X)UT["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L;"@D:6YD
M97@I*2!["B`@("`@("`@("`@("1P87)A;7-;)VEN9&5X)UT@/2`D:6YD97@[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"GT*
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O;&EB+U-P86TN<&AP````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#(Q-C,Q`#$P-#$W,S8R-S8V`#`Q-S,W-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PIR97%U:7)E
M7V]N8V4@24U07T)!4T4@+B`G+VQI8B]#;VUP;W-E+G!H<"<["@HO*BH*("H@
M5&AE($E-4%]3<&%M.CH@8VQA<W,@8V]N=&%I;G,@9G5N8W1I;VYS(')E;&%T
M960@=&\@<F5P;W)T:6YG('-P86T*("H@;65S<V%G97,@:6X@24U0+@H@*@H@
M*B`D2&]R9&4Z(&EM<"]L:6(O4W!A;2YP:'`L=B`Q+C,N-"XQ,R`R,#`V+S`Q
M+S,Q(#(R.C4X.C(X('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#0M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8W5R96-A;G1I+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8W5R96-A;G1I+F]R9SX*("H@0'-I;F-E("`@24U0(#0N,`H@
M*B!`<&%C:V%G92!)35`*("HO"F-L87-S($E-4%]3<&%M('L*"B`@("`O*BH*
M("`@("`J(%1H92!)35!?0V]M<&]S93HZ(&]B:F5C="!U<V5D(&)Y('1H92!C
M;&%S<RX*("`@("`J"B`@("`@*B!`=F%R($E-4%]#;VUP;W-E"B`@("`@*B\*
M("`@('9A<B`D7VEM<%]C;VUP;W-E.PH*("`@("\J*@H@("`@("H@5&AE($E-
M4%])9&5N=&ET>3HZ(&]B:F5C="!U<V5D(&)Y('1H92!C;&%S<RX*("`@("`J
M"B`@("`@*B!`=F%R($E-4%])9&5N=&ET>0H@("`@("HO"B`@("!V87(@)%]I
M9&5N=&ET>3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!)35!?4W!A;2@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]I;7!?8V]M<&]S92`]("9N97<@24U07T-O;7!O<V4H*3L*("`@("`@("`D
M=&AI<RT^7VED96YT:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH87)R87DH
M)VEM<"<L("=I;7`G*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297!O<G0@
M82!L:7-T(&]F(&UE<W-A9V5S(&%S('-P86TL(&)A<V5D(&]N('1H92!L;V-A
M;"!C;VYF:6=U<F%T:6]N"B`@("`@*B!P87)A;65T97)S+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`F)&EN9&EC97,@(%-E92!)35`Z.G!A<G-E26YD
M:6-E<TQI<W0H*2X*("`@("`J($!P87)A;2!S=')I;F<@)&%C=&EO;B`@($5I
M=&AE<B`G<W!A;2<@;W(@)VYO='-P86TG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R97!O<G13<&%M*"8D:6YD:6-E<RP@)&%C=&EO;BD*("`@('L*("`@("`@
M("`O*B!!8F]R="!I;6UE9&EA=&5L>2!I9B!S<&%M(')E<&]R=&EN9R!H87,@
M;F]T(&)E96X@96YA8FQE9"X@*B\*("`@("`@("!I9B`H96UP='DH)$=,3T)!
M3%-;)V-O;F8G75LD86-T:6]N75LG<F5P;W)T:6YG)UTI*2!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($5X:70@:68@=&AE
M<F4@87)E(&YO(&UE<W-A9V5S+B`J+PH@("`@("`@(&EF("@A*"1M<V=,:7-T
M(#T@24U0.CIP87)S94EN9&EC97-,:7-T*"1I;F1I8V5S*2DI('L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E
M($E-4%]"05-%("X@)R]L:6(O34E-12]#;VYT96YT<RYP:'`G.PH@("`@("`@
M(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TE-05`N<&AP)SL*("`@
M("`@("`D:6UP7VEM87`@/2`F24U07TE-05`Z.G-I;F=L971O;B@I.PH*("`@
M("`@("`O*B!792!C86X@<F5P;W)T("=P<F]G<F%M)R!A;F0@)V)O=6YC92<@
M;65S<V%G97,@87,@=&AE('-A;64@<VEN8V4*("`@("`@("`@*B!T:&5Y(&%R
M92!B;W1H(&UE86YT('1O(&EN9&EC871E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5P;W)T960*("`@("`@("`@*B!T;R!S;VUE('!R;V=R86T@9F]R
M(&%N86QY<VES+B`J+PH@("`@("`@("1E;6%I;%]M<V=?8V]U;G0@/2`D<F5P
M;W)T7VUS9U]C;W5N="`](#`["@H@("`@("`@(&9O<F5A8V@@*"1M<V=,:7-T
M(&%S("1F;VQD97(@/3X@)&US9TEN9&EC97,I('L*("`@("`@("`@("`@+RH@
M4W=I=&-H(&9O;&1E<G,L(&EF(&YE8V5S<V%R>2`H;VYL>2!V86QI9"!F;W(@
M24U!4"DN("HO"B`@("`@("`@("`@("1I;7!?:6UA<"T^8VAA;F=E36)O>"@D
M9F]L9&5R*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1M<V=);F1I8V5S(&%S
M("1M<V=N=6TI('L*("`@("`@("`@("`@("`@("\J($9E=&-H('1H92!R87<@
M;65S<V%G92!C;VYT96YT<R`H:&5A9&5R<R!A;F0@8V]M<&QE=&4*("`@("`@
M("`@("`@("`@("`J(&)O9'DI+B`J+PH@("`@("`@("`@("`@("`@)&EM<%]C
M;VYT96YT<R`]("9)35!?0V]N=&5N=',Z.G-I;F=L971O;B@D;7-G;G5M("X@
M24U07TE$6%]315`@+B`D9F]L9&5R*3L*"B`@("`@("`@("`@("`@("`D=&\@
M/2!N=6QL.PH@("`@("`@("`@("`@("`@)')E<&]R=%]F;&%G(#T@9F%L<V4[
M"B`@("`@("`@("`@("`@("`D<F%W7VUS9R`](&YU;&P["@H@("`@("`@("`@
M("`@("`@+RH@268@82`H;F]T*7-P86T@<F5P;W)T:6YG('!R;V=R86T@:&%S
M(&)E96X@<')O=FED960L('5S90H@("`@("`@("`@("`@("`@("H@:70N("HO
M"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;
M)&%C=&EO;EU;)W!R;V=R86TG72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<F%W7VUS9R`]("1I;7!?8V]N=&5N=',M/F9U;&Q-97-S86=E5&5X="@I.PH@
M("`@("`@("`@("`@("`@("`@("\J(%5S92!A('!I<&4@=&\@=W)I=&4@=&AE
M(&UE<W-A9V4@8V]N=&5N=',N(%1H:7,@<VAO=6QD"B`@("`@("`@("`@("`@
M("`@("`@("H@8F4@<V5C=7)E+B`J+PH@("`@("`@("`@("`@("`@("`@("1P
M<F]G(#T@<W1R7W)E<&QA8V4H)R5U)RP@97-C87!E<VAE;&QA<F<H075T:#HZ
M9V5T075T:"@I*2P@)$=,3T)!3%-;)V-O;F8G75LD86-T:6]N75LG<')O9W)A
M;2==*3L*("`@("`@("`@("`@("`@("`@("`D<')O8R`]('!R;V-?;W!E;B@D
M<')O9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@P(#T^(&%R<F%Y*"=P:7!E)RP@)W(G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q(#T^(&%R<F%Y*"=P:7!E
M)RP@)W<G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`R(#T^(&%R<F%Y*"=P:7!E)RP@)W<G*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!I<&5S*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1P<F]C*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G0V%N;F]T(&]P
M96X@<')O8V5S<R`G("X@)'!R;V<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!F=W)I
M=&4H)'!I<&5S6S!=+"`D<F%W7VUS9RD["B`@("`@("`@("`@("`@("`@("`@
M9F-L;W-E*"1P:7!E<ULP72D["B`@("`@("`@("`@("`@("`@("`@)'-T9&5R
M<B`]("<G.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("@A9F5O9B@D<&EP
M97-;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1S=&1E<G(@+CT@
M9F=E=',H)'!I<&5S6S)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@9F-L;W-E*"1P:7!E<ULR72D["B`@("`@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D<W1D97)R*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@<F5P;W)T:6YG
M('-P86TZ("<@+B`D<W1D97)R+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('!R;V-?8VQO<V4H)'!R;V,I.PH@("`@("`@("`@("`@("`@("`@
M("1R97!O<G1?;7-G7V-O=6YT*RL["B`@("`@("`@("`@("`@("`@("`@)')E
M<&]R=%]F;&%G(#T@=')U93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`O*B!)9B!A("AN;W0I<W!A;2!R97!O<G1I;F<@96UA:6P@861D
M<F5S<R!H87,@8F5E;B!P<F]V:61E9"P*("`@("`@("`@("`@("`@("`J('5S
M92!I="X@*B\*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)$=,3T)!3%-;
M)V-O;F8G75LD86-T:6]N75LG96UA:6PG72DI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1R87=?;7-G*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<F%W7VUS9R`]("1I;7!?8V]N=&5N=',M/F9U;&Q-97-S86=E
M5&5X="@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E;F13<&%M4F5P;W)T365S<V%G92@D86-T:6]N+"`D
M<F%W7VUS9RD["B`@("`@("`@("`@("`@("`@("`@)&5M86EL7VUS9U]C;W5N
M="LK.PH@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@268@
M82`H;F]T*7-P86T@8F]U;F-E(&5M86EL(&%D9')E<W,@:&%S(&)E96X@<')O
M=FED960L('5S90H@("`@("`@("`@("`@("`@("H@:70N("HO"B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)&%C=&EO;EU;
M)V)O=6YC92==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T;R`]("1'3$]"
M04Q36R=C;VYF)UU;)&%C=&EO;EU;)V)O=6YC92==.PH@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=H;V]K<R==
M6R=S<&%M7V)O=6YC92==*2D@>PH@("`@("`@("`@("`@("`@("`@("\J($-A
M;&P@=&AE(&)O=6YC92!E;6%I;"!G96YE<F%T:6]N(&AO;VLL(&EF(')E<75E
M<W1E9"X@*B\*("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("`@("`@("`@("`@
M("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7W-P86U?8F]U
M;F-E)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1O(#T@8V%L;%]U
M<V5R7V9U;F,H)U]I;7!?:&]O:U]S<&%M7V)O=6YC92<L("1A8W1I;VXI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("!I9B`H)'1O*2!["B`@("`@("`@("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O34E-12](96%D97)S+G!H<"<[
M"B`@("`@("`@("`@("`@("`@("`@)&EM<%]H96%D97)S(#T@)FYE=R!)35!?
M2&5A9&5R<R@D;7-G;G5M*3L*("`@("`@("`@("`@("`@("`@("`D:6UP7VAE
M861E<G,M/F)U:6QD2&5A9&5R<R@I.PH*("`@("`@("`@("`@("`@("`@("`D
M9G)O;5]A9&1R(#T@)'1H:7,M/E]I9&5N=&ET>2T^9V5T1G)O;4%D9')E<W,H
M*3L*("`@("`@("`@("`@("`@("`@("`D:6UP7VAE861E<G,M/F%D9%)E<V5N
M=$AE861E<G,H)&9R;VU?861D<BP@)'1O*3L*"B`@("`@("`@("`@("`@("`@
M("`@+RH@5V4@;F5E9"!T;R!S970@=&AE(%)E='5R;BU0871H(&AE861E<B!T
M;R!T:&4@8W5R<F5N=`H@("`@("`@("`@("`@("`@("`@("`J('5S97(@+2!S
M964@4D9#(#(X,C$@6S0N-%TN("HO"B`@("`@("`@("`@("`@("`@("`@)&EM
M<%]H96%D97)S+3YR96UO=F5(96%D97(H)W)E='5R;BUP871H)RD["B`@("`@
M("`@("`@("`@("`@("`@)&EM<%]H96%D97)S+3YA9&1(96%D97(H)U)E='5R
M;BU0871H)RP@)&9R;VU?861D<BD["@H@("`@("`@("`@("`@("`@("`@("1B
M;V1Y=&5X="`]("1I;7!?8V]N=&5N=',M/F=E=$)O9'DH*3L*"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]I;7!?8V]M<&]S92T^<V5N9$UE<W-A9V4H
M)'1O+"`D:6UP7VAE861E<G,L("1B;V1Y=&5X="P@3DQ3.CIG971#:&%R<V5T
M*"DI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A)')E<&]R=%]F;&%G*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R97!O<G1?;7-G7V-O=6YT*RL[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!297!O<G0@=VAA="!W
M92=V92!D;VYE+B`J+PH@("`@("`@(&EF("@D<F5P;W)T7VUS9U]C;W5N="D@
M>PH@("`@("`@("`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@("`@("`@("`@
M8V%S92`G<W!A;2<Z"B`@("`@("`@("`@("`@("!I9B`H)')E<&]R=%]M<V=?
M8V]U;G0@/B`Q*2!["B`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO
M=&EF:6-A=&EO;B==+3YP=7-H*'-P<FEN=&8H7R@B)60@;65S<V%G97,@:&%V
M92!B965N(')E<&]R=&5D(&%S('-P86TN(BDL("1R97!O<G1?;7-G7V-O=6YT
M*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==
M+3YP=7-H*%\H(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!S<&%M
M+B(I+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=N;W1S<&%M
M)SH*("`@("`@("`@("`@("`@(&EF("@D<F5P;W)T7VUS9U]C;W5N="`^(#$I
M('L*("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N
M)UTM/G!U<V@H<W!R:6YT9BA?*"(E9"!M97-S86=E<R!H879E(&)E96X@<F5P
M;W)T960@87,@;F]T('-P86TN(BDL("1R97!O<G1?;7-G7V-O=6YT*2P@)VAO
M<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H
M*%\H(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E9"!A<R!N;W0@<W!A;2XB
M*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H)&5M86EL7VUS9U]C;W5N="D@>PH@("`@("`@("`@("!S=VET
M8V@@*"1A8W1I;VXI('L*("`@("`@("`@("`@8V%S92`G<W!A;2<Z"B`@("`@
M("`@("`@("`@("!I9B`H)&5M86EL7VUS9U]C;W5N="`^(#$I('L*("`@("`@
M("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/G!U<V@H
M<W!R:6YT9BA?*"(E9"!M97-S86=E<R!H879E(&)E96X@<F5P;W)T960@87,@
M<W!A;2!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R+B(I+"`D96UA:6Q?
M;7-G7V-O=6YT*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF
M:6-A=&EO;B==+3YP=7-H*%\H(C$@;65S<V%G92!H87,@8F5E;B!R97!O<G1E
M9"!A<R!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(BDL("=H
M;W)D92YM97-S86=E)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VYO='-P86TG.@H@("`@
M("`@("`@("`@("`@:68@*"1E;6%I;%]M<V=?8V]U;G0@/B`Q*2!["B`@("`@
M("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H
M*'-P<FEN=&8H7R@B)60@;65S<V%G97,@:&%V92!B965N(')E<&]R=&5D(&%S
M(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(BDL("1E
M;6%I;%]M<V=?8V]U;G0I+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG
M;F]T:69I8V%T:6]N)UTM/G!U<V@H7R@B,2!M97-S86=E(&AA<R!B965N(')E
M<&]R=&5D(&%S(&YO="!S<&%M('1O('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(N(BDL("=H;W)D92YM97-S86=E)RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@82`H;F]T*7-P86T@;65S<V%G
M92!T;R!T:&4@<WES861M:6XN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-T:6]N("!4:&4@
M86-T:6]N('1Y<&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@(%1H
M92!M97-S86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96YD4W!A
M;5)E<&]R=$UE<W-A9V4H)&%C=&EO;BP@)&1A=&$I"B`@("!["B`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUE<W-A9V4N<&AP)SL*"B`@("`@
M("`@+RH@0G5I;&0@=&AE($U)344@<W1R=6-T=7)E+B`J+PH@("`@("`@("1M
M:6UE(#T@)FYE=R!-24U%7TUE<W-A9V4H*3L*("`@("`@("`D;6EM92T^<V5T
M5'EP92@G;75L=&EP87)T+V1I9V5S="<I.PH@("`@("`@("1M:6UE+3YA9&10
M87)T*&YE=R!-24U%7U!A<G0H)VUE<W-A9V4O<F9C.#(R)RP@)&1A=&$I*3L*
M"B`@("`@("`@)'-P86U?:&5A9&5R<R`]("9N97<@24U07TAE861E<G,H*3L*
M("`@("`@("`D<W!A;5]H96%D97)S+3YA9&1-97-S86=E261(96%D97(H*3L*
M("`@("`@("`D<W!A;5]H96%D97)S+3YA9&1(96%D97(H)T1A=&4G+"!D871E
M*"=R)RDI.PH@("`@("`@("1S<&%M7VAE861E<G,M/F%D9$AE861E<B@G5&\G
M+"`D1TQ/0D%,4ULG8V]N9B==6R1A8W1I;VY=6R=E;6%I;"==*3L*("`@("`@
M("`D<W!A;5]H96%D97)S+3YA9&1(96%D97(H)T9R;VTG+"`D=&AI<RT^7VED
M96YT:71Y+3YG971&<F]M3&EN92@I*3L*("`@("`@("`D<W!A;5]H96%D97)S
M+3YA9&1(96%D97(H)U-U8FIE8W0G+"!?*"(D86-T:6]N(%)E<&]R="!F<F]M
M(BD@+B`G("<@+B`D1TQ/0D%,4ULG:6UP)UU;)W5S97(G72D["B`@("`@("`@
M)'-P86U?:&5A9&5R<RT^861D34E-14AE861E<G,H)&UI;64I.PH*("`@("`@
M("`O*B!396YD('1H92!M97-S86=E+B`J+PH@("`@("`@("1T:&ES+3Y?:6UP
M7V-O;7!O<V4M/G-E;F1-97-S86=E*"1'3$]"04Q36R=C;VYF)UU;)&%C=&EO
M;EU;)V5M86EL)UTL("1S<&%M7VAE861E<G,L("1M:6UE+"!.3%,Z.F=E=$-H
M87)S970H*2D["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEM<"]L:6(O1F5T8VAM86EL+G!H<```````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S,S,S0`,3`T,3<S-C(W-C8`
M,#(P,S<S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@24U07T9E=&-H;6%I;#HZ(&-L87-S('!R
M;W9I9&5S(&%N(&EN=&5R9F%C92!T;R!D;W=N;&]A9"!M86EL(&9R;VT*("H@
M<F5M;W1E(&UA:6P@<V5R=F5R<RX*("H*("H@)$AO<F1E.B!I;7`O;&EB+T9E
M=&-H;6%I;"YP:'`L=B`Q+C0Q+C@N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C4T(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($YU;F\@3&]U<F5I
M<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@3G5N;R!,;W5R96ER;R`\;G5N
M;T!C;RYS87!O+G!T/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($E-4"`T
M+C`*("H@0'!A8VMA9V4@24U0"B`J+PIC;&%S<R!)35!?1F5T8VAM86EL('L*
M"B`@("`O*BH*("`@("`J(%!A<F%M971E<G,@=7-E9"!B>2!T:&4@9')I=F5R
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<&%R86US.PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@86-T:79E(&9E
M=&-H;6%I;"!P87)A;65T97)S(&9O<B!T:&4@8W5R<F5N="!D<FEV97(N"B`@
M("`@*B!!3$P@1%))5D524R!32$]53$0@54Y3150@04Y9($9%5$-(34%)3"!0
M05)!345415)3(%1(15D@1$\@3D]4(%5310H@("`@("H@3U(@14Q312!42$59
M(%=)3$P@05!014%2($E.(%1(12!04D5&15)%3D-%4R!004=%+@H@("`@("H@
M5&AE(&9O;&QO=VEN9R!P87)A;65T97)S(&%R92!A=F%I;&%B;&4Z"B`@("`@
M*B`@("=I9"<@("`@("`@("`@+2T@(%1H92!A8V-O=6YT(&YA;64N"B`@("`@
M*B`@("=D<FEV97(G("`@("`@+2T@(%1H92!D<FEV97(@=&\@=7-E+@H@("`@
M("H@("`G<')O=&]C;VPG("`@("TM("!4:&4@<')O=&]C;VP@='EP92X*("`@
M("`J("`@)W5S97)N86UE)R`@("`M+2`@5&AE('5S97)N86UE(&]N('1H92!R
M96UO=&4@<V5R=F5R+@H@("`@("H@("`G<&%S<W=O<F0G("`@("TM("!4:&4@
M<&%S<W=O<F0@;VX@=&AE(')E;6]T92!S97)V97(N"B`@("`@*B`@("=S97)V
M97(G("`@("`@+2T@(%1H92!R96UO=&4@<V5R=F5R(&YA;64O861D<F5S<RX*
M("`@("`J("`@)W)M86EL8F]X)R`@("`M+2`@5&AE(')E;6]T92!M86EL8F]X
M(&YA;64N"B`@("`@*B`@("=L;6%I;&)O>"<@("`@+2T@(%1H92!L;V-A;"!M
M86EL8F]X('1O(&1O=VYL;V%D(&UE<W-A9V5S('1O+@H@("`@("H@("`G;VYL
M>6YE=R<@("`@("TM("!/;FQY(')E=')I979E(&YE=R!M97-S86=E<S\*("`@
M("`J("`@)VUA<FMS965N)R`@("`M+2`@36%R:R!M97-S86=E<R!A<R!S965N
M/PH@("`@("H@("`G9&5L)R`@("`@("`@("TM("!$96QE=&4@;65S<V%G97,@
M869T97(@9F5T8VAI;F<_"B`@("`@*B`@("=L;V=I;F9E=&-H)R`@+2T@($9E
M=&-H(&UA:6P@9G)O;2!O=&AE<B!A8V-O=6YT<R!O;B!L;V=I;C\*("`@("`J
M("`@)V%C8W1C;VQO<B<@("`M+2`@4VAO=6QD('1H97-E(&UE<W-A9V5S(&)E
M(&-O;&]R960@9&EF9F5R96YT;'D*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@:6X@;6%I;&)O>"!V:65W/PH@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?86-T:79E<&%R86US(#T@87)R87DH"B`@("`@
M("`@)VED)RP@)V1R:79E<B<L("=T>7!E)RP@)W!R;W1O8V]L)RP@)W5S97)N
M86UE)RP@)W!A<W-W;W)D)RP@)W-E<G9E<B<L"B`@("`@("`@)W)M86EL8F]X
M)RP@)VQM86EL8F]X)RP@)V]N;'EN97<G+"`G;6%R:W-E96XG+"`G9&5L)RP@
M)VQO9VEN9F5T8V@G+`H@("`@("`@("=A8V-T8V]L;W(G"B`@("`I.PH*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@24U0
M7T9E=&-H;6%I;"!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N
M8W)E=&4@24U07T9E=&-H;6%I;"!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FXL(&)A<V5D(&]N('1H92!D<FEV97(@
M:6YD:6-A=&5D+B!4:&4@8V]D90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@(%1H92!C;VYF:6=U<F%T:6]N('!A<F%M
M971E<B!A<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M;F5W;'D@8W)E871E9"!C;VYC<F5T92!)35!?1F5T8VAM86EL(&EN<W1A;F-E
M+"!O<@H@("`@("H@("`@("`@("`@("`@("`@9F%L<V4@;VX@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D
M9')I=F5R*3L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+T9E=&-H;6%I;"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("`D8VQA<W,@/2`G24U07T9E=&-H;6%I;%\G("X@)&1R:79E<CL*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&9E
M=&-H;6%I;"`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F971C:&UA:6P@/2!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9F5T8VAM86EL.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(&QI<W0@;V8@879A:6QA8FQE(&1R:79E<G,L('=I
M=&@@82!D97-C<FEP=&EO;B!O9B!E86-H+@H@("`@("H@5&AI<R!F=6YC=&EO
M;B!C86X@8F4@8V%L;&5D('-T871I8V%L;'DZ"B`@("`@*B`@("1L:7-T(#T@
M24U07T9E=&-H;6%I;#HZ;&ES=$1R:79E<G,H*3L*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!A=F%I;&%B;&4@9')I=F5R<RP@
M=VET:"!T:&4@9')I=F5R(&YA;64@87,*("`@("`J("`@("`@("`@("`@("`@
M('1H92!K97D@86YD('1H92!D97-C<FEP=&EO;B!A<R!T:&4@=F%L=64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QI<W1$<FEV97)S*"D*("`@('L*("`@("`@
M("`D9')I=F5R<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("@H)&1I<B`](&]P
M96YD:7(H9&ER;F%M92A?7T9)3$5?7RD@+B`G+T9E=&-H;6%I;"<I*2D@>PH@
M("`@("`@("`@("!W:&EL92`H9F%L<V4@(3T]("@D9FEL92`](')E861D:7(H
M)&1I<BDI*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES7V1I<B@D9FEL92DI
M('L*("`@("`@("`@("`@("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&9I
M;&4L("<N<&AP)RD["B`@("`@("`@("`@("`@("`@("`@)&-L87-S(#T@)TE-
M4%]&971C:&UA:6Q?)R`N("1D<FEV97(["B`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]&971C:&UA:6PO
M)R`N("1F:6QE.PH@("`@("`@("`@("`@("`@("`@(&EF("@H)&1E<V-R:7`@
M/2!C86QL7W5S97)?9G5N8RAA<G)A>2@D8VQA<W,L("=D97-C<FEP=&EO;B<I
M*2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<G-;)&1R:79E
M<ET@/2`D9&5S8W)I<#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-L;W-E9&ER
M*"1D:7(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D<FEV97)S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@3&ES="!T:&4@8V]L;W)S(&%V86EL86)L
M92!F;W(@8V]L;W)I;F<@9F5T8VAE9"!M97-S86=E<RX*("`@("`J(%1H:7,@
M9G5N8W1I;VX@8V%N(&)E(&-A;&QE9"!S=&%T:6-A;&QY.@H@("`@("H@("`D
M;&ES="`]($E-4%]&971C:&UA:6PZ.FQI<W1#;VQO<G,H*3L*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!A=F%I;&%B;&4@8V]L
M;W)S.PH@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T0V]L;W)S*"D*("`@('L*
M("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("=P=7)P;&4G+"`G
M;&EM92<L("=T96%L)RP@)V)L=64G+"`G;VQI=F4G+"`G9G5C:'-I82<L("=N
M879Y)RP*("`@("`@("`@("`@)V%Q=6$G"B`@("`@("`@*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!D97-C<FEP=&EO;B!O9B!T:&4@9')I
M=F5R+@H@("`@("H@5&AI<R!F=6YC=&EO;B!C86X@8F4@8V%L;&5D('-T871I
M8V%L;'DZ"B`@("`@*B`@("1D97-C<FEP=&EO;B`]($E-4%]&971C:&UA:6PZ
M.F1E<V-R:7!T:6]N*"D["B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D97-C<FEP=&EO;B!O9B!T
M:&4@9')I=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-C<FEP=&EO;B@I
M"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@(%1H92!C;VYF:6=U<F%T:6]N('!A<F%M971E<B!A<G)A>2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@24U07T9E=&-H;6%I;"@D<&%R86US*0H@("`@
M>PH@("`@("`@("\J($-H96-K(&9O<B!M:7-S:6YG('!A<F%M<RX@*B\*("`@
M("`@("`D<&%R86UL:7-T(#T@)'1H:7,M/F=E=%!A<F%M971E<DQI<W0H*3L*
M("`@("`@("!I9B`H87)R87E?9&EF9B@D<&%R86UL:7-T+"!A<G)A>5]K97ES
M*"1P87)A;7,I*2D@>PH@("`@("`@("`@("`O+R!43T1/.B!%<G)O<B!M97-S
M86=E(&AE<F4*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;&ES
M="!O9B!P87)A;65T97)S('9A;&ED(&9O<B!T:&ES(&1R:79E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!A8W1I=F4@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86UE=&5R3&ES
M="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?86-T:79E<&%R86US
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@;&ES="!O9B!P<F]T
M;V-O;',@<W5P<&]R=&5D(&)Y('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L
M:7-T(&]F('!R;W1O8V]L<RX*("`@("`J("`@("`@("`@("`@("`@($M%63H@
M<')O=&]C;VP@240*("`@("`J("`@("`@("`@("`@("`@(%9!3#H@<')O=&]C
M;VP@9&5S8W)I<'1I;VX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')O=&]C
M;VQ,:7-T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE(&UA:6P@=7-I;F<@=&AE(&1A=&$@
M:6X@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@4F5T=7)N<R!T:&4@;G5M8F5R(&]F
M(&UE<W-A9V5S(')E=')I979E9"!O;B!S=6-C97-S+@H@("`@("H@("`@("`@
M("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971-86EL*"D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G;F]T(&EM<&QE;65N=&5D)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!0<F]C97-S97,@82!S:6YG;&4@;6%I;"!M97-S86=E
M(&)Y(&-A;&QI;F<@86YY('5S97(@9&5F:6YE9"!F=6YC=&EO;G,L"B`@("`@
M*B!S=')I<'!I;F<@8F%R92!N97=L:6YE<RP@86YD(&%D9&EN9R!C;VQO<B!I
M;F9O<FUA=&EO;B!T;R!T:&4@:&5A9&5R<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H96%D
M97(@(%1H92!M97-S86=E(&AE861E<B!T97AT+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8F]D>2`@("!4:&4@;65S<V%G92!B;V1Y('1E>'0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VUP;&5T92!M97-S86=E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<')O8V5S<TUA:6Q-97-S86=E*"1H96%D
M97(L("1B;V1Y*0H@("`@>PH@("`@("`@("1M<V<@/2!R=')I;2@D:&5A9&5R
M*3L*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=A8V-T8V]L
M;W(G72DI('L*("`@("`@("`@("`@)&US9R`N/2`B7&Y8+6-O;&]R.B`B("X@
M)'1H:7,M/E]P87)A;7-;)V%C8W1C;VQO<B==.PH@("`@("`@('T*("`@("`@
M("`D;7-G("X](")<;EQN(B`N("1B;V1Y.PH*("`@("`@("`O*B!)9B!T:&5R
M92!I<R!A('5S97(@9&5F:6YE9"!F=6YC=&EO;BP@8V%L;"!I="!W:71H('1H
M92!C=7)R96YT"B`@("`@("`@("H@;65S<V%G92!A<R!A;B!A<F=U;65N="X@
M*B\*("`@("`@("!I9B`H)$=,3T)!3%-;)V-O;F8G75LG:&]O:W,G75LG9F5T
M8VAM86EL7V9I;'1E<B==*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92!(
M3U)$15]"05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@
M:68@*&9U;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7V9E=&-H;6%I;%]F:6QT
M97(G*2D@>PH@("`@("`@("`@("`@("`@)&US9R`](&-A;&Q?=7-E<E]F=6YC
M*"=?:6UP7VAO;VM?9F5T8VAM86EL7V9I;'1E<B<L("1M<V<I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!-86ME(&%B<V]L=71E;'D@
M<W5R92!T:&5R92!A<F4@;F\@8F%R92!N97=L:6YE<RX@*B\*("`@("`@("`D
M;7-G(#T@<')E9U]R97!L86-E*")\*%M>7')=*5QN?"(L(")<7#%<<EQN(BP@
M)&US9RD["B`@("`@("`@)&US9R`]('-T<E]R97!L86-E*")<;EQN(BP@(EQN
M7')<;B(L("1M<V<I.PH*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@
M("`O*BH*("`@("`J($-H96-K<R!T:&4@;65S<V%G92!S:7IE('1O('-E92!I
M9B!I="!E>&-E961S('1H92!M87AI;75M('9A;'5E"B`@("`@*B!A;&QO=V%B
M;&4@:6X@=&AE(&-O;F9I9W5R871I;VX@9FEL92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<VEZ92`@("!4:&4@<VEZ92!O9B!T:&4@;65S<V%G92X*("`@("`J($!P87)A
M;2!S=')I;F<@)'-U8FIE8W0@(%1H92!S=6)J96-T(&]F('1H92!M97-S86=E
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9G)O;2`@("`@5&AE(&UE<W-A9V4@
M<V5N9&5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@1F%L<V4@
M:68@;65S<V%G92!I<R!T;V\@;&%R9V4L('1R=64@:68@3TLN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C:&5C:TUE<W-A9V53:7IE*"1S:7IE+"`D<W5B:F5C
M="P@)&9R;VTI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG
M8V]N9B==6R=F971C:&UA:6PG75LG<VEZ95]L:6UI="==*2`F)@H@("`@("`@
M("`@("`H)'-I>F4@/B`D1TQ/0D%,4ULG8V]N9B==6R=F971C:&UA:6PG75LG
M<VEZ95]L:6UI="==*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+TU)344N<&AP)SL*("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A
M=&EO;B==+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&UE<W-A9V4@7"(E<UPB(&9R
M;VT@7"(E<UPB("@E9"!B>71E<RD@97AC965D<R!F971C:"!S:7IE(&QI;6ET
M+B(I+"!-24U%.CI$96-O9&4H)'-U8FIE8W0I+"!-24U%.CI$96-O9&4H)&9R
M;VTI+"`D<VEZ92DL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M=&AE(&UE<W-A9V4@=&\@=&AE(')E<75E<W1E9"!L;V-A;"!M86EL8F]X+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&US9R`@5&AE(&UE<W-A9V4@=&5X="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$UE<W-A9V4H
M)&US9RD*("`@('L*("`@("`@("`D;F5W;6%I;&)O>"`]($E-4#HZ<V5R=F5R
M4W1R:6YG*"1T:&ES+3Y?<&%R86US6R=L;6%I;&)O>"==*3L*("`@("`@("!R
M971U<FX@0&EM87!?87!P96YD*"1'3$]"04Q36R=I;7`G75LG<W1R96%M)UTL
M("1N97=M86EL8F]X+"`D;7-G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!E
M<F9O<FT@9F5T8VAM86EL(&]N('1H92!L:7-T(&]F(&%C8V]U;G1S(&=I=F5N
M+B!/=71P=71S(&EN9F]R;6%T;VX*("`@("`J('1O('1H92!G;&]B86P@;F]T
M:69I8V%T:6]N(&1R:79E<BX*("`@("`J(%1H:7,@9G5N8W1I;VX@8V%N(&)E
M(&-A;&QE9"!S=&%T:6-A;&QY+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D86-C;W5N=',@(%1H92!L:7-T(&]F(&%C8V]U;G0@:61E;G1I9FEE<G,@
M=&\@9F5T8V@@;6%I;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!F971C:$UA:6PH)&%C8V]U;G1S
M*0H@("`@>PH@("`@("`@("1F;5]A8V-O=6YT(#T@)FYE=R!)35!?1F5T8VAM
M86EL7T%C8V]U;G0H*3L*"B`@("`@("`@9F]R96%C:"`H)&%C8V]U;G1S(&%S
M("1V86PI('L*("`@("`@("`@("`@)'!A<F%M<R`]("1F;5]A8V-O=6YT+3YG
M971!;&Q686QU97,H)'9A;"D["B`@("`@("`@("`@("1D<FEV97(@/2`F24U0
M7T9E=&-H;6%I;#HZ9F%C=&]R>2@D<&%R86US6R=D<FEV97(G72P@)'!A<F%M
M<RD["B`@("`@("`@("`@("1R97,@/2`D9')I=F5R+3YG971-86EL*"D["@H@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/G!U<V@H
M7R@B1F5T8VAM86EL.B`B*2`N("1R97,M/F=E=$UE<W-A9V4H*2P@)VAO<F1E
M+G=A<FYI;F<G*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1R97,@/3T@,2D@
M>PH@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP
M=7-H*%\H(D9E=&-H;6%I;#H@(BD@+B!S<')I;G1F*%\H(D9E=&-H960@,2!M
M97-S86=E(&9R;VT@)7,B*2P@)&9M7V%C8V]U;G0M/F=E=%9A;'5E*"=I9"<L
M("1V86PI*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1R97,@/CT@,"D@>PH@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO
M=&EF:6-A=&EO;B==+3YP=7-H*%\H(D9E=&-H;6%I;#H@(BD@+B!S<')I;G1F
M*%\H(D9E=&-H960@)60@;65S<V%G97,@9G)O;2`E<R(I+"`D<F5S+"`D9FU?
M86-C;W5N="T^9V5T5F%L=64H)VED)RP@)'9A;"DI+"`G:&]R9&4N<W5C8V5S
M<R<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)$=,
M3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*%\H(D9E=&-H;6%I;#H@;F\@
M;F5W(&UE<W-A9V5S+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J(%1H92!)35!?1F5T8VAM
M86EL7T%C8V]U;G0Z.B!C;&%S<R!P<F]V:61E<R!A;B!I;G1E<F9A8V4@=&\@
M86-C97-S:6YG"B`J(&9E=&-H;6%I;"!P<F5F97)E;F-E<R!F;W(@86QL(&UA
M:6P@86-C;W5N=',@82!U<V5R(&UI9VAT(&AA=F4N"B`J"B`J($!A=71H;W(@
M($YU;F\@3&]U<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H@0'-I;F-E("`@
M24U0(#0N,`H@*B!`<&%C:V%G92!)35`*("HO"F-L87-S($E-4%]&971C:&UA
M:6Q?06-C;W5N="!["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!C;VYT86EN:6YG
M(&%L;"!T:&4@=7-E<B=S(&%C8V]U;G1S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?86-C;W5N=',@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($E-4%]&971C:&UA:6Q?06-C;W5N="@I"B`@("!["B`@("`@("`@+RH@
M4F5A9"!A;&P@=&AE('5S97(G<R!A8V-O=6YT<R!F<F]M('1H92!P<F5F<R!O
M8FIE8W0@;W(@8G5I;&0*("`@("`@("`@*B!A(&YE=R!A8V-O=6YT(&9R;VT@
M=&AE('-T86YD87)D('9A;'5E<R!G:79E;B!I;B!P<F5F<RYP:'`N("HO"B`@
M("`@("`@)&%C8V]U;G1S(#T@0'5N<V5R:6%L:7IE*"1'3$]"04Q36R=P<F5F
M<R==+3YG971686QU92@G9FU?86-C;W5N=',G*2D["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1A8V-O=6YT<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]A8V-O
M=6YT<R`]("1A8V-O=6YT<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3879E<R!A;&P@86-C;W5N=',@:6X@=&AE('!R969S(&)A8VME;F0N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]S879E*"D*("`@('L*("`@("`@("`D1TQ/0D%,4ULG<')E9G,G
M72T^<V5T5F%L=64H)V9M7V%C8V]U;G1S)RP@<V5R:6%L:7IE*"1T:&ES+3Y?
M86-C;W5N=',I*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!N97<@
M96UP='D@86-C;W5N="!T;R!T:&4@87)R87D@;V8@86-C;W5N=',N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@<&]I;G1E<B!T;R!T:&4@
M8W)E871E9"!A8V-O=6YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?86-C;W5N='-;72`](&%R<F%Y*"D["B`@
M("`@("`@)'1H:7,M/E]S879E*"D["B`@("`@("`@<F5T=7)N(&-O=6YT*"1T
M:&ES+3Y?86-C;W5N=',I("T@,3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;6]V92!A;B!A8V-O=6YT(&9R;VT@=&AE(&%R<F%Y(&]F(&%C8V]U;G1S"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%C8V]U;G0@(%1H92!P;VEN
M=&5R('1O('1H92!A8V-O=6YT('1O(&)E(')E;6]V960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE(')E;6]V960@86-C;W5N="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9&5L971E*"1A8V-O=6YT*0H@("`@>PH@("`@("`@
M("1D96QE=&5D(#T@)'1H:7,M/E]A8V-O=6YT<ULD86-C;W5N=%T["B`@("`@
M("`@=6YS970H)'1H:7,M/E]A8V-O=6YT<ULD86-C;W5N=%TI.PH@("`@("`@
M("1T:&ES+3Y?86-C;W5N=',@/2!A<G)A>5]V86QU97,H)'1H:7,M/E]A8V-O
M=6YT<RD["B`@("`@("`@)'1H:7,M/E]S879E*"D["B`@("`@("`@<F5T=7)N
M("1D96QE=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('!R
M;W!E<G1Y(&9R;VT@;VYE(&]F('1H92!A8V-O=6YT<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1K97D@("`@("`@5&AE('!R;W!E<G1Y('1O(')E
M=')I979E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%C8V]U;G0@(%1H92!A
M8V-O=6YT('1O(')E=')I979E('1H92!P<F]P97)T>2!F<F]M+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!V86QU92!O9B!T:&4@<')O<&5R
M='D@;W(@9F%L<V4@:68@=&AE('!R;W!E<G1Y"B`@("`@*B`@("`@("`@("`@
M("`@("!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9716
M86QU92@D:V5Y+"`D86-C;W5N="D*("`@('L*("`@("`@("!R971U<FX@*&ES
M<V5T*"1T:&ES+3Y?86-C;W5N='-;)&%C8V]U;G1=6R1K97E=*2D@/R`D=&AI
M<RT^7V%C8V]U;G1S6R1A8V-O=6YT75LD:V5Y72`Z(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@<')O<&5R=&EE<R!F<F]M('1H
M92!R97%U97-T960@86-C;W5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&%C8V]U;G0@(%1H92!A8V-O=6YT('1O(')E=')I979E('1H92!P
M<F]P97)T:65S(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE(&5N=&ER92!P<F]P97)T:65S(&%R<F%Y+"!O<B!F86QS92!O;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06QL5F%L=65S*"1A8V-O=6YT
M*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]A8V-O=6YT
M<ULD86-C;W5N=%TI*2`_("1T:&ES+3Y?86-C;W5N='-;)&%C8V]U;G1=(#H@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y
M('=I=&@@=&AE('-P96-I9FEE9"!P<F]P97)T>2!F<F]M(&%L;"!E>&ES=&EN
M9R!A8V-O=6YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@
M(%1H92!P<F]P97)T>2!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@87)R87D@=VET:"!T:&4@=F%L=65S(&9R;VT@86QL
M(&%C8V]U;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!;&PH)&ME>2D*
M("`@('L*("`@("`@("`D;&ES="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C
M:"`H87)R87E?:V5Y<R@D=&AI<RT^7V%C8V]U;G1S*2!A<R`D86-C;W5N="D@
M>PH@("`@("`@("`@("`D;&ES=%LD86-C;W5N=%T@/2`D=&AI<RT^9V5T5F%L
M=64H)&ME>2P@)&%C8V]U;G0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1L:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A('!R;W!E<G1Y
M('=I=&@@82!S<&5C:69I960@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:V5Y("`@("`@(%1H92!P<F]P97)T>2!T;R!S970N"B`@("`@
M*B!`<&%R86T@;6EX960@)'9A;"`@("`@("`@5&AE('9A;'5E('1H92!P<F]P
M97)T>2!S:&]U;&0@8F4@<V5T('1O+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&%C8V]U;G0@(%1H92!A8V-O=6YT('1O('-E="!T:&4@<')O<&5R='D@:6XN
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%9A;'5E*"1K97DL("1V86PL("1A
M8V-O=6YT*0H@("`@>PH@("`@("`@("\J(%1H97-E('!A<F%M971E<G,@87)E
M(&-H96-K8F]X(&ET96US("T@;6%K92!S=7)E('1H97D@87)E('-T;W)E9`H@
M("`@("`@("`J(&%S(&)O;VQE86X@=F%L=65S+B`J+PH@("`@("`@("1L:7-T
M(#T@87)R87DH)V1E;"<L("=O;FQY;F5W)RP@)VUA<FMS965N)RP@)VQO9VEN
M9F5T8V@G*3L*("`@("`@("!I9B`H:6Y?87)R87DH)&ME>2P@)&QI<W0I("8F
M("%I<U]B;V]L*"1V86PI*2!["B`@("`@("`@("`@(&EF("@H)'9A;"`]/2`G
M>65S)RD@?'P@*&EN='9A;"@D=F%L*2`A/2`P*2D@>PH@("`@("`@("`@("`@
M("`@)'9A;"`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=F%L(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?86-C;W5N='-;)&%C8V]U;G1=6R1K97E=(#T@
M)'9A;#L*("`@("`@("`D=&AI<RT^7W-A=F4H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=')U92!I9B!T:&4@<&%I<B!K97DO=F%L=64@:7,@
M86QR96%D>2!I;B!T:&4@86-C;W5N=',@87)R87DN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:V5Y("!4:&4@86-C;W5N="!K97D@=&\@<V5A<F-H
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L("!4:&4@=F%L=64@=&\@<V5A
M<F-H(&9O<B!I;B`D:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!T:&4@=F%L=64@=V%S(&9O=6YD(&EN("1K97DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&AA<U9A;'5E*"1K97DL("1V86PI"B`@("!["B`@
M("`@("`@)&QI<W0@/2`D=&AI<RT^9V5T06QL*"1K97DI.PH@("`@("`@(&9O
M<F5A8V@@*"1L:7-T(&%S("1V86PR*2!["B`@("`@("`@("`@(&EF("AS=')P
M;W,H4W1R:6YG.CIL;W=E<B@D=F%L*2P@4W1R:6YG.CIL;W=E<B@D=F%L,BDI
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O;&EB+TUE<W-A9V4N<&AP````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8V,#4W`#$P-#$W,S8R-S8V`#`R
M,#`W,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+RH@0V]N<W1A;G1S('5S960@:6X@8V]P>2@I+B`J+PID969I
M;F4H)TE-4%]-15-304=%7TU/5D4G+"`Q*3L*9&5F:6YE*"=)35!?34534T%'
M15]#3U!9)RP@,BD["@HO*BH*("H@5&AE($E-4%]-97-S86=E.CH@8VQA<W,@
M8V]N=&%I;G,@86QL(&9U;F-T:6]N<R!R96QA=&5D('1O(&AA;F1L:6YG(&UE
M<W-A9V5S"B`J('=I=&AI;B!)35`N($%C=&EO;G,@<W5C:"!A<R!M;W9I;F<L
M(&-O<'EI;F<L(&%N9"!D96QE=&EN9R!M97-S86=E<R!A<F4*("H@:&%N9&QE
M9"!I;B!H97)E('-O('1H870@8V]D92!N965D(&YO="!B92!R97!E871E9"!B
M971W965N(&UA:6QB;W@L(&UE<W-A9V4L"B`J(&%N9"!O=&AE<B!P86=E<RX*
M("H*("H@26YD:6-E<R!F;W)M870Z"B`J(#T]/3T]/3T]/3T]/3T]/0H@*B!&
M;W(@86YY(&9U;F-T:6]N(&)E;&]W('1H870@<F5Q=6ER97,@86X@)&EN9&EC
M97,@<&%R86UE=&5R+"!S964*("H@24U0.CIP87)S94EN9&EC97-,:7-T*"D@
M9F]R('1H92!L:7-T(&]F(&%L;&]W86)L92!I;G!U=',N"B`J"B`J("1(;W)D
M93H@:6UP+VQI8B]-97-S86=E+G!H<"QV(#$N,38T+C@N,S0@,C`P-B\P,B\R
M,R`P,3HQ.3HT,"!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`P
M+3(P,#$@0VAR:7,@2'ED92`\8VAR:7-`:F5K<RYN970^"B`J($-O<'ER:6=H
M="`R,#`P+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H<FES($AY9&4@/&-H<FES0&IE:W,N;F5T/@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO
M<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N
M961U/@H@*B!`<VEN8V4@("!)35`@,BXS"B`J($!P86-K86=E($E-4`H@*B\*
M8VQA<W,@24U07TUE<W-A9V4@>PH*("`@("\J*@H@("`@("H@5&AE($E-4%])
M34%0(&]B:F5C="!F;W(@=&AE(&-U<G)E;G0@<V5R=F5R+@H@("`@("H*("`@
M("`J($!V87(@24U07TE-05`*("`@("`J+PH@("`@=F%R("1?:6UP26UA<#L*
M"B`@("`O*BH*("`@("`J(%5S:6YG(%!/4"!T;R!A8V-E<W,@;6%I;&)O>&5S
M/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)%]U<V5P;W`@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R
M969E<F5N8V4@=&\@=&AE(&=L;V)A;"!)35!?365S<V%G92!O8FIE8W0L(&]N
M;'D@8W)E871I;F<@:70*("`@("`J(&EF(&ET(&1O97-N)W0@86QR96%D>2!E
M>&ES="X@5&AI<R!E;G-U<F5S('1H870@;VYL>2!O;F4@24U07TUE<W-A9V4*
M("`@("`J(&EN<W1A;F-E(&ES(&EN<W1A;G1I871E9"!F;W(@86YY(&=I=F5N
M('-E<W-I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I
M;G9O:V5D(&%S.CQC;V1E/@H@("`@("H@("`D:6UP7VUE<W-A9V4@/2`F24U0
M7TUE<W-A9V4Z.G-I;F=L971O;B@I.PH@("`@("H@/"]C;V1E/@H@("`@("H*
M("`@("`J($!R971U<FX@24U07TUE<W-A9V4@(%1H92!)35!?365S<V%G92!I
M;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@
M("!["B`@("`@("`@<W1A=&EC("1M97-S86=E.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1M97-S86=E*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](&YE=R!)
M35!?365S<V%G92@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M97-S
M86=E.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($E-4%]-97-S86=E*"D*("`@('L*("`@("`@("!I
M9B`H)$=,3T)!3%-;)VEM<"==6R=B87-E7W!R;W1O8V]L)UT@/3T@)W!O<#,G
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=7-E<&]P(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TE-
M05`N<&AP)SL*("`@("`@("`D=&AI<RT^7VEM<$EM87`@/2`F24U07TE-05`Z
M.G-I;F=L971O;B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]P:65S(&]R
M(&UO=F5S(&$@;&ES="!O9B!M97-S86=E<R!T;R!A(&YE=R!F;VQD97(N"B`@
M("`@*B!(86YD;&5S('5S92!O9B!T:&4@24U07U-%05)#2%]-0D]8(&UA:6QB
M;W@@86YD('1H92!4<F%S:"!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&%R9V5T36)O>"`@5&AE(&UA:6QB;W@@=&\@;6]V92]C;W!Y
M(&UE<W-A9V5S('1O+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%C=&EO;B`@
M("`@16ET:&5R($E-4%]-15-304=%7TU/5D4@;W(@24U07TU%4U-!1T5?0T]0
M62X*("`@("`J($!P87)A;2!M:7AE9"`F)&EN9&EC97,@("`@(%-E92!A8F]V
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@<W5C
M8V5S<V9U;"P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;W!Y*"1T87)G971-8F]X+"`D86-T:6]N+"`F)&EN9&EC97,I"B`@("!["B`@
M("`@("`@9VQO8F%L("1I;7`L("1N;W1I9FEC871I;VXL("1P<F5F<SL*"B`@
M("`@("`@:68@*"$H)&US9TQI<W0@/2!)35`Z.G!A<G-E26YD:6-E<TQI<W0H
M)&EN9&EC97,I*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E
M($E-4%]-15-304=%7TU/5D4Z"B`@("`@("`@("`@("1I;6%P7V9L86=S(#T@
M0U!?54E$('P@0U!?34]613L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4
M:&5R92!W87,@86X@97)R;W(@;6]V:6YG(&UE<W-A9V5S(&9R;VT@7"(E<UPB
M('1O(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9"(I.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)35!?34534T%'15]#
M3U!9.@H@("`@("`@("`@("`D:6UA<%]F;&%G<R`]($-07U5)1#L*("`@("`@
M("`@("`@)&UE<W-A9V4@/2!?*")4:&5R92!W87,@86X@97)R;W(@8V]P>6EN
M9R!M97-S86=E<R!F<F]M(%PB)7-<(B!T;R!<(B5S7"(N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60B*3L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("`D<F5T=7)N7W9A;'5E(#T@=')U93L*"B`@("`@("`@
M9F]R96%C:"`H)&US9TQI<W0@87,@)&9O;&1E<B`]/B`D;7-G26YD:6-E<RD@
M>PH@("`@("`@("`@("`D;7-G261X4W1R:6YG(#T@:6UP;&]D92@G+"<L("1M
M<V=);F1I8V5S*3L*"B`@("`@("`@("`@("\J(%-W:71C:"!F;VQD97)S+"!I
M9B!N96-E<W-A<GD@*&]N;'D@=F%L:60@9F]R($E-05`I+B`J+PH@("`@("`@
M("`@("`D=&AI<RT^7VEM<$EM87`M/F-H86YG94UB;W@H)&9O;&1E<BD["@H@
M("`@("`@("`@("`O*B!!='1E;7!T('1O(&-O<'DO;6]V92!M97-S86=E<R!T
M;R!N97<@;6%I;&)O>"X@*B\*("`@("`@("`@("`@:68@*"%`:6UA<%]M86EL
M7V-O<'DH)&EM<%LG<W1R96%M)UTL("1M<V=)9'A3=')I;F<L("1T87)G971-
M8F]X+"`D:6UA<%]F;&%G<RDI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9B@D;65S<V%G92P@24U0.CID:7-P;&%Y1F]L
M9&5R*"1F;VQD97(I+"!)35`Z.F1I<W!L87E&;VQD97(H)'1A<F=E=$UB;W@I
M*2`N("<Z("<@+B!I;6%P7VQA<W1?97)R;W(H*2P@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@("`@("`@("`D<F5T=7)N7W9A;'5E(#T@9F%L<V4["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($EF(&UO=FEN9RP@86YD('5S:6YG
M('1H92!T<F%S:"P@97AP=6YG92!I;6UE9&EA=&5L>2X@*B\*("`@("`@("`@
M("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)W5S95]T<F%S:"<I("8F"B`@("`@
M("`@("`@("`@("`H)&%C=&EO;B`]/2!)35!?34534T%'15]-3U9%*2D@>PH@
M("`@("`@("`@("`@("`@0&EM87!?97AP=6YG92@D:6UP6R=S=')E86TG72D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T92!T
M:&4@;6%I;&)O>"X@*B\*("`@("`@("!I9B`H:7-?82@D:6YD:6-E<RP@)TE-
M4%]-86EL8F]X)RDI('L*("`@("`@("`@("`@:68@*"1A8W1I;VX@/3T@24U0
M7TU%4U-!1T5?0T]062D@>PH@("`@("`@("`@("`@("`@)&EN9&EC97,M/G5P
M9&%T94UA:6QB;W@H24U07TU!24Q"3UA?0T]062P@)')E='5R;E]V86QU92D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:6YD:6-E
M<RT^=7!D871E36%I;&)O>"A)35!?34%)3$)/6%]-3U9%+"`D<F5T=7)N7W9A
M;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1R971U<FY?=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S
M(&$@;&ES="!O9B!M97-S86=E<R!T86MI;F<@:6YT;R!A8V-O=6YT('=H971H
M97(@;W(@;F]T(&$*("`@("`J(%1R87-H(&9O;&1E<B!I<R!B96EN9R!U<V5D
M+@H@("`@("H@2&%N9&QE<R!U<V4@;V8@=&AE($E-4%]314%20TA?34)/6"!M
M86EL8F]X(&%N9"!T:&4@5')A<V@@9F]L9&5R+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`F)&EN9&EC97,@("!3964@86)O=F4N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D;G5K92`@("`@3W9E<G)I9&4@=7-E<B!P<F5F97)E;F-E
M<R!A;F0@;G5K92`H:2YE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@('!E<FUA;F5N=&QY(&1E;&5T92D@=&AE(&UE<W-A9V5S(&EN<W1E860_
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:V5E<&QO9R`@4VAO=6QD(&%N>2!H
M:7-T;W)Y(&EN9F]R;6%T:6]N(&]F('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&UE<W-A9V4@8F4@:V5P=#\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@<W5C8V5S<V9U;"P@9F%L<V4@:68@
M;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&4H)B1I;F1I8V5S+"`D
M;G5K92`](&9A;'-E+"`D:V5E<&QO9R`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D8V]N9BP@)&EM<"P@)&YO=&EF:6-A=&EO;BP@)'!R969S.PH*
M("`@("`@("!I9B`H(2@D;7-G3&ES="`]($E-4#HZ<&%R<V5);F1I8V5S3&ES
M="@D:6YD:6-E<RDI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("1R971U<FY?=F%L=64@/2!T<G5E.PH@("`@("`@
M("1T<F%S:"`]($E-4#HZ9F]L9&5R4')E9B@D<')E9G,M/F=E=%9A;'5E*"=T
M<F%S:%]F;VQD97(G*2P@=')U92D["B`@("`@("`@)'5S95]V=')A<V@@/2`D
M<')E9G,M/F=E=%9A;'5E*"=U<V5?=G1R87-H)RD["B`@("`@("`@)'5S95]T
M<F%S:"`]("1P<F5F<RT^9V5T5F%L=64H)W5S95]T<F%S:"<I.PH@("`@("`@
M("1M86EL;&]G7W5P9&%T92`]("@A)&ME97!L;V<@)B8@(65M<'1Y*"1C;VYF
M6R=M86EL;&]G)UU;)W5S95]M86EL;&]G)UTI*3L*"B`@("`@("`@+RH@268@
M=&AE(&9O;&1E<B!W92!A<F4@9&5L971I;F<@9G)O;2!H87,@8VAA;F=E9"X@
M*B\*("`@("`@("!F;W)E86-H("@D;7-G3&ES="!A<R`D9F]L9&5R(#T^("1M
M<V=);F1I8V5S*2!["B`@("`@("`@("`@("1S97%U96YC92`](&EM<&QO9&4H
M)RPG+"`D;7-G26YD:6-E<RD["@H@("`@("`@("`@("`O*B!3=VET8V@@9F]L
M9&5R<RP@:68@;F5C97-S87)Y("AO;FQY('9A;&ED(&9O<B!)34%0*2X@*B\*
M("`@("`@("`@("`@)'1H:7,M/E]I;7!);6%P+3YC:&%N9V5-8F]X*"1F;VQD
M97(I.PH*("`@("`@("`@("`@+RH@5')A<V@@:7,@;VYL>2!V86QI9"!F;W(@
M24U!4"!M86EL8F]X97,N("HO"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]U
M<V5P;W`@)B8*("`@("`@("`@("`@("`@("$D;G5K92`F)@H@("`@("`@("`@
M("`@("`@(21U<V5?=G1R87-H("8F"B`@("`@("`@("`@("`@("`D=7-E7W1R
M87-H("8F"B`@("`@("`@("`@("`@("`H)&9O;&1E<B`A/2`D=')A<V@I*2![
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;7!?9F]L9&5R*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92!)35!?0D%312`N("<O
M;&EB+T9O;&1E<BYP:'`G.PH@("`@("`@("`@("`@("`@("`@("1I;7!?9F]L
M9&5R(#T@)DE-4%]&;VQD97(Z.G-I;F=L971O;B@I.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@(&EF("@A)&EM<%]F;VQD97(M/F5X:7-T
M<R@D=')A<V@I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"$D:6UP7V9O
M;&1E<BT^8W)E871E*"1T<F%S:"P@)'!R969S+3YG971686QU92@G<W5B<V-R
M:6)E)RDI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@:68@*"%`:6UA<%]M86EL7VUO=F4H)&EM<%LG<W1R
M96%M)UTL("1S97%U96YC92P@)'1R87-H+"!#4%]5240I*2!["B`@("`@("`@
M("`@("`@("`@("`@)&5R<F]R7VUS9R`](&EM87!?;&%S=%]E<G)O<B@I.PH@
M("`@("`@("`@("`@("`@("`@("1E<G)O<B`]('1R=64["@H@("`@("`@("`@
M("`@("`@("`@("\J($AA;F1L92!T:&4@8V%S92!W:&5N('1H92!M86EL8F]X
M(&ES(&]V97)Q=6]T80H@("`@("`@("`@("`@("`@("`@("`@("AM;W9I;F<@
M;65S<V%G92!T;R!T<F%S:"!W;W5L9"!F86EL*2!B>2!F:7)S=`H@("`@("`@
M("`@("`@("`@("`@("`@(&1E;&5T:6YG('1H96X@8V]P>6EN9R!M97-S86=E
M('1O(%1R87-H+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R
M*"=O=F5R('%U;W1A)RP@)&5R<F]R7VUS9RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1E<G)O<B`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;7-G7W1E>'0@/2!A<G)A>2@I.PH*("`@("`@("`@
M("`@("`@("`@("`@("`@+RH@1V5T('1E>'0@;V8@9&5L971E9"!M97-S86=E
M<RX@*B\*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&US9TEN
M9&EC97,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&US9U]T97AT6UT@/2!I;6%P7V9E=&-H:&5A9&5R*"1I;7!;)W-T<F5A;2==
M+"`D=F%L+"!&5%]5240@?"!&5%]04D5&151#2%1%6%0I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@($!I;6%P
M7V1E;&5T92@D:6UP6R=S=')E86TG72P@)'-E<75E;F-E+"!&5%]5240I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!`:6UA<%]E>'!U;F=E*"1I;7!;)W-T
M<F5A;2==*3L*"B`@("`@("`@("`@("`@("`@("`@("`@("\J(%-A=F4@;65S
M<V%G97,@:6X@5')A<V@@9F]L9&5R+B`J+PH@("`@("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;7-G7W1E>'0@87,@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%`:6UA<%]A<'!E;F0H)&EM<%LG<W1R
M96%M)UTL("1T<F%S:"P@)'9A;"DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97)R;W(@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H)&5R<F]R*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")4:&5R92!W87,@86X@97)R;W(@9&5L971I;F<@;65S<V%G97,@
M9G)O;2!T:&4@9F]L9&5R(%PB)7-<(BX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9"(I+"!)35`Z.F1I<W!L87E&;VQD97(H)&9O;&1E<BDI("X@)SH@
M)R`N("1E<G)O<E]M<V<L("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5T=7)N7W9A;'5E(#T@9F%L<V4["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("!`:6UA<%]E>'!U;F=E*"1I;7!;)W-T<F5A;2==*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("\J($=E="!T:&4@;&ES="!O9B!-97-S86=E+4E$<R!F;W(@=&AE
M(&1E;&5T960@;65S<V%G97,@:68*("`@("`@("`@("`@("`@("`J('5S:6YG
M(&UA:6QL;V=G:6YG+B`J+PH@("`@("`@("`@("`@("`@:68@*"1M86EL;&]G
M7W5P9&%T92D@>PH@("`@("`@("`@("`@("`@("`@("1O=F5R=FEE=R`]($!I
M;6%P7V9E=&-H7V]V97)V:65W*"1I;7!;)W-T<F5A;2==+"`D<V5Q=65N8V4L
M($947U5)1"D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M+RH@1&5L971E('1H92!M97-S86=E<RX@*B\*("`@("`@("`@("`@("`@(&EF
M("@A0&EM87!?9&5L971E*"1I;7!;)W-T<F5A;2==+"`D<V5Q=65N8V4L($94
M7U5)1"DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]U<V5P
M;W`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"AS<')I;G1F*%\H(E1H97)E('=A<R!A;B!E<G)O<B!D96QE=&EN9R!M
M97-S86=E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@)7,B*2P@
M:6UA<%]L87-T7V5R<F]R*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&%N(&5R
M<F]R(&1E;&5T:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&9O;&1E<B!<(B5S7"(N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60B*2P@24U0.CID:7-P;&%Y
M1F]L9&5R*"1F;VQD97(I*2`N("<Z("<@+B!I;6%P7VQA<W1?97)R;W(H*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1R971U<FY?=F%L=64@/2!F86QS93L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&1E;$EN9&EC
M97,@/2!A<G)A>2@D9F]L9&5R(#T^("1M<V=);F1I8V5S*3L*("`@("`@("`@
M("`@("`@("`@("`D9FQA9U]S='(@/2`G7%Q$14Q%5$5$)SL*"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?=7-E<&]P('Q\"B`@("`@("`@("`@
M("`@("`@("`@("`@("1N=6ME('Q\"B`@("`@("`@("`@("`@("`@("`@("`@
M("@D=7-E7W1R87-H("8F("@D9F]L9&5R(#T]("1T<F%S:"DI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("\J(%!U<F=E(&UE<W-A9V5S(&EN('1H92!T
M<F%S:"!F;VQD97(@:6UM961I871E;'DN("HO"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YF;&%G*"1F;&%G7W-T<BP@)&1E;$EN9&EC97,I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!`:6UA<%]E>'!U;F=E*"1I;7!;)W-T
M<F5A;2==*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`O*B!)9B!W92!A<F4@=7-I;F<@=FET<G5A;"!T
M<F%S:"P@=V4@;75S="!M87)K('1H92`*("`@("`@("`@("`@("`@("`@("`@
M("`@("H@;65S<V%G92!A<R!S965N(&]R(&5L<V4@:70@=VEL;"!A<'!E87(@
M87,@86X*("`@("`@("`@("`@("`@("`@("`@("`@("H@)W5N<V5E;B<@;65S
M<V%G92!F;W(@<'5R<&]S97,@;V8@;F5W(&UE<W-A9V4*("`@("`@("`@("`@
M("`@("`@("`@("`@("H@8V]U;G1S+B`J+PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)'5S95]V=')A<V@I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YF;&%G*"1F;&%G7W-T<B`N("<@7%Q3145.)RP@)&1E
M;$EN9&EC97,I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O*B!'970@=&AE
M(&QI<W0@;V8@365S<V%G92U)1',@9&5L971E9"P@86YD(')E;6]V90H@("`@
M("`@("`@("`@("`@("`@("`J('1H92!I;F9O<FUA=&EO;B!F<F]M('1H92!M
M86EL(&QO9RX@*B\*("`@("`@("`@("`@("`@("`@("!I9B`H)&UA:6QL;V=?
M=7!D871E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M<V=?:61S(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&]V
M97)V:65W(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)'9A;"T^;65S<V%G95]I9"DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;7-G7VED<UM=(#T@)'9A;"T^;65S<V%G
M95]I9#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-86EL;&]G+G!H<"<["B`@("`@
M("`@("`@("`@("`@("`@("`@($E-4%]-86EL;&]G.CID96QE=&5,;V<H)&US
M9U]I9',I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@57!D871E
M('1H92!M86EL8F]X+B`J+PH@("`@("`@(&EF("AI<U]A*"1I;F1I8V5S+"`G
M24U07TUA:6QB;W@G*2D@>PH@("`@("`@("`@("`D:6YD:6-E<RT^=7!D871E
M36%I;&)O>"A)35!?34%)3$)/6%]$14Q%5$4L("1R971U<FY?=F%L=64I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FY?=F%L=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!5;F1E;&5T97,@82!L:7-T(&]F(&UE<W-A9V5S
M+@H@("`@("H@2&%N9&QE<R!T:&4@24U07U-%05)#2%]-0D]8(&UA:6QB;W@N
M"B`@("`@*B!4:&ES(&9U;F-T:6]N('=O<FMS('=I=&@@24U!4"!O;FQY+"!N
M;W0@4$]0,RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)B1I;F1I8V5S
M("!3964@86)O=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('-U8V-E<W-F=6PL(&9A;'-E(&EF(&YO="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=6YD96QE=&4H)B1I;F1I8V5S*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D:6UP+"`D;F]T:69I8V%T:6]N.PH*("`@("`@("!I9B`H(2@D;7-G
M3&ES="`]($E-4#HZ<&%R<V5);F1I8V5S3&ES="@D:6YD:6-E<RDI*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R
M971U<FY?=F%L=64@/2!T<G5E.PH*("`@("`@("!F;W)E86-H("@D;7-G3&ES
M="!A<R`D9F]L9&5R(#T^("1M<V=);F1I8V5S*2!["B`@("`@("`@("`@("1M
M<V=)9'A3=')I;F<@/2!I;7!L;V1E*"<L)RP@)&US9TEN9&EC97,I.PH*("`@
M("`@("`@("`@+RH@4W=I=&-H(&9O;&1E<G,L(&EF(&YE8V5S<V%R>2X@*B\*
M("`@("`@("`@("`@)'1H:7,M/E]I;7!);6%P+3YC:&%N9V5-8F]X*"1F;VQD
M97(I.PH*("`@("`@("`@("`@:68@*"1I;7!;)W-T<F5A;2==("8F"B`@("`@
M("`@("`@("`@("`A0&EM87!?=6YD96QE=&4H)&EM<%LG<W1R96%M)UTL("1M
M<V=)9'A3=')I;F<L($947U5)1"DI('L*("`@("`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R92!W87,@86X@97)R;W(@
M9&5L971I;F<@;65S<V%G97,@:6X@=&AE(&9O;&1E<B!<(B5S7"(N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60B*2P@24U0.CID:7-P;&%Y1F]L9&5R
M*"1F;VQD97(I*2`N("<Z("<@+B!I;6%P7VQA<W1?97)R;W(H*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@("`@("`@("`D<F5T=7)N7W9A;'5E(#T@9F%L
M<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T
M92!T:&4@;6%I;&)O>"X@*B\*("`@("`@("!I9B`H:7-?82@D:6YD:6-E<RP@
M)TE-4%]-86EL8F]X)RDI('L*("`@("`@("`@("`@)&EN9&EC97,M/G5P9&%T
M94UA:6QB;W@H24U07TU!24Q"3UA?54Y$14Q%5$4L("1R971U<FY?=F%L=64I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FY?=F%L=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;W!I97,@;W(@;6]V97,@82!L:7-T(&]F
M(&UE<W-A9V5S('1O(&$@=&%S:VQI<W0@;W(@;F]T97!A9"X*("`@("`J($AA
M;F1L97,@=7-E(&]F('1H92!)35!?4T5!4D-(7TU"3U@@;6%I;&)O>"!A;F0@
M=&AE(%1R87-H(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1L:7-T("`@("`@5&AE(&QI<W0@:6X@=VAI8V@@=&AE('1A<VL@;W(@;F]T
M92!W:6QL(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E
M871E9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VX@("!%:71H97(@
M24U07TU%4U-!1T5?34]612!O<B!)35!?34534T%'15]#3U!9+@H@("`@("H@
M0'!A<F%M(&UI>&5D("1I;F1I8V5S("`@(%-E92!A8F]V92X*("`@("`J($!P
M87)A;2!S=')I;F<@)'1Y<&4@("`@("!4:&4@;V)J96-T('1Y<&4@=&\@8W)E
M871E+"!D969A=6QT<R!T;R!T87-K+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!I9B!S=6-C97-S9G5L+"!F86QS92!I9B!N;W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-R96%T951A<VMS3W).;W1E<R@D;&ES="P@
M)&%C=&EO;BP@)B1I;F1I8V5S+"`D='EP92`]("=T87-K)RD*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y+"`D;F]T:69I8V%T:6]N+"`D<')E9G,[
M"@H@("`@("`@(&EF("@A*"1M<V=,:7-T(#T@24U0.CIP87)S94EN9&EC97-,
M:7-T*"1I;F1I8V5S*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L
M:6(O0V]M<&]S92YP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%3
M12`N("<O;&EB+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@("!R97%U:7)E
M7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-24U%+TAE861E<G,N<&AP)SL*("`@
M("`@("!R97%U:7)E7V]N8V4@)U1E>'0O1FQO=V5D+G!H<"<["B`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L96YD87(N<&AP)SL*"B`@("`@("`@
M9F]R96%C:"`H)&US9TQI<W0@87,@)&9O;&1E<B`]/B`D;7-G26YD:6-E<RD@
M>PH@("`@("`@("`@("!F;W)E86-H("@D;7-G26YD:6-E<R!A<R`D:6YD97@I
M('L*("`@("`@("`@("`@("`@("\J($9E=&-H('1H92!M97-S86=E(&AE861E
M<G,N("HO"B`@("`@("`@("`@("`@("`D:6UP7VAE861E<G,@/2`F;F5W($E-
M4%](96%D97)S*"1I;F1E>"D["B`@("`@("`@("`@("`@("`D:6UP7VAE861E
M<G,M/F)U:6QD2&5A9&5R<R@I.PH@("`@("`@("`@("`@("`@)'-U8FIE8W0@
M/2`D:6UP7VAE861E<G,M/F=E=%9A;'5E*"=S=6)J96-T)RD["@H@("`@("`@
M("`@("`@("`@+RH@1F5T8V@@=&AE(&UE<W-A9V4@8V]N=&5N=',N("HO"B`@
M("`@("`@("`@("`@("`D:6UP7V-O;G1E;G1S(#T@)DE-4%]#;VYT96YT<SHZ
M<VEN9VQE=&]N*"1I;F1E>"`N($E-4%])1%A?4T50("X@)&9O;&1E<BD["B`@
M("`@("`@("`@("`@("`D:6UP7V-O;G1E;G1S+3YB=6EL9$UE<W-A9V4H*3L*
M"B`@("`@("`@("`@("`@("`O*B!%>'1R86-T('1H92!M97-S86=E(&)O9'DN
M("HO"B`@("`@("`@("`@("`@("`D:6UP7V-O;7!O<V4@/2`F;F5W($E-4%]#
M;VUP;W-E*"D["B`@("`@("`@("`@("`@("`D;6EM95]M97-S86=E(#T@)&EM
M<%]C;VYT96YT<RT^9V5T34E-14UE<W-A9V4H*3L*("`@("`@("`@("`@("`@
M("1B;V1Y7VED(#T@)&EM<%]C;VUP;W-E+3YG971";V1Y260H)&EM<%]C;VYT
M96YT<RD["B`@("`@("`@("`@("`@("`D8F]D>2`]("1I;7!?8V]M<&]S92T^
M9FEN9$)O9'DH)&EM<%]C;VYT96YT<RD["@H@("`@("`@("`@("`@("`@+RH@
M4F4M9FQO=R!T:&4@;65S<V%G92!F;W(@<')E='1I97(@9F]R;6%T=&EN9RX@
M*B\*("`@("`@("`@("`@("`@("1F;&]W960@/2`F;F5W(%1E>'1?1FQO=V5D
M*"1M:6UE7VUE<W-A9V4M/G)E<&QA8V5%3TPH)&)O9'DL(")<;B(I*3L*("`@
M("`@("`@("`@("`@(&EF("@H)&UI;65?;65S<V%G92T^9V5T0V]N=&5N=%1Y
M<&5087)A;65T97(H)V1E;'-P)RD@/3T@)WEE<R<I("8F"B`@("`@("`@("`@
M("`@("`@("`@;65T:&]D7V5X:7-T<R@D9FQO=V5D+"`G<V5T1&5L4W`G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1F;&]W960M/G-E=$1E;%-P*'1R=64I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&)O9'D@/2`D
M9FQO=V5D+3YT;T9L;W=E9"AF86QS92D["@H@("`@("`@("`@("`@("`@+RH@
M0V]N=F5R="!T;R!C=7)R96YT(&-H87)S970@*B\*("`@("`@("`@("`@("`@
M("\J(%1/1$\Z(%=H96X@2&]R9&5?:4-A;&5N9&%R('-U<'!O<G1S('-E='1I
M;F<@;V8@8VAA<G-E=',*("`@("`@("`@("`@("`@("`J('=E(&YE960@=&\@
M<V5T(&ET('1H97)E(&EN<W1E860@;V8@<F5L>6EN9R!O;B!T:&4@9F%C=`H@
M("`@("`@("`@("`@("`@("H@=&AA="!B;W1H($YA9R!A;F0@24U0('5S92!T
M:&4@<V%M92!C:&%R<V5T+B`J+PH@("`@("`@("`@("`@("`@)&)O9'E?<&%R
M="`]("1M:6UE7VUE<W-A9V4M/F=E=%!A<G0H)&)O9'E?:60I.PH@("`@("`@
M("`@("`@("`@)&)O9'D@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1B;V1Y
M+"`D8F]D>5]P87)T+3YG971#:&%R<V5T*"DL($Y,4SHZ9V5T0VAA<G-E="@I
M*3L*"B`@("`@("`@("`@("`@("`O*B!#<F5A=&4@82!N97<@:4-A;&5N9&%R
M+B`J+PH@("`@("`@("`@("`@("`@)'9#86P@/2`F;F5W($AO<F1E7VE#86QE
M;F1A<B@I.PH@("`@("`@("`@("`@("`@)'9#86PM/G-E=$%T=')I8G5T92@G
M4%)/1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J96-T+R])35`@)R`N($E-4%]6
M15)324].("X@)R\O14XG*3L*("`@("`@("`@("`@("`@("1V0V%L+3YS971!
M='1R:6)U=&4H)TU%5$A/1"<L("=054),25-()RD["@H@("`@("`@("`@("`@
M("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("`@("`@8V%S92`G=&%S
M:R<Z"B`@("`@("`@("`@("`@("`@("`@+RH@0W)E871E(&$@;F5W('94;V1O
M(&]B:F5C="!U<VEN9R!T:&ES(&UE<W-A9V4G<PH@("`@("`@("`@("`@("`@
M("`@("`J(&-O;G1E;G1S+B`J+PH@("`@("`@("`@("`@("`@("`@("1V5&]D
M;R`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O;7!O;F5N="@G=G1O9&\G+"`D
M=D-A;"D["B`@("`@("`@("`@("`@("`@("`@)'94;V1O+3YS971!='1R:6)U
M=&4H)U-534U!4EDG+"`D<W5B:F5C="D["B`@("`@("`@("`@("`@("`@("`@
M)'94;V1O+3YS971!='1R:6)U=&4H)T1%4T-225!424].)RP@)&)O9'DI.PH@
M("`@("`@("`@("`@("`@("`@("1V5&]D;RT^<V5T071T<FEB=71E*"=04DE/
M4DE462<L("<S)RD["@H@("`@("`@("`@("`@("`@("`@("\J($=E="!T:&4@
M;&ES="!O9B!E9&ET86)L92!T87-K;&ES=',N("HO"B`@("`@("`@("`@("`@
M("`@("`@)&QI<W1S(#T@)')E9VES=')Y+3YC86QL*"=T87-K<R]L:7-T5&%S
M:VQI<W1S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH9F%L<V4L(%!%4DU37T5$250I*3L*"B`@("`@("`@
M("`@("`@("`@("`@+RH@071T96UP="!T;R!A9&0@=&AE(&YE=R!V5&]D;R!I
M=&5M('1O('1H92!R97%U97-T960*("`@("`@("`@("`@("`@("`@("`@*B!T
M87-K;&ES="X@*B\*("`@("`@("`@("`@("`@("`@("`D<F5S(#T@)')E9VES
M=')Y+3YC86QL*"=T87-K<R]I;7!O<G0G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'94;V1O+"`G=&5X="]X
M+79T;V1O)RP@)&QI<W0I*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=N;W1E)SH*("`@("`@("`@("`@("`@
M("`@("`O*B!#<F5A=&4@82!N97<@=DYO=&4@;V)J96-T('5S:6YG('1H:7,@
M;65S<V%G92=S"B`@("`@("`@("`@("`@("`@("`@("H@8V]N=&5N=',N("HO
M"B`@("`@("`@("`@("`@("`@("`@)'9.;W1E(#T@)DAO<F1E7VE#86QE;F1A
M<CHZ;F5W0V]M<&]N96YT*"=V;F]T92<L("1V0V%L*3L*("`@("`@("`@("`@
M("`@("`@("`D=DYO=&4M/G-E=$%T=')I8G5T92@G0D]$62<L("1S=6)J96-T
M("X@(EQN(BX@)&)O9'DI.PH*("`@("`@("`@("`@("`@("`@("`O*B!'970@
M=&AE(&QI<W0@;V8@961I=&%B;&4@;F]T97!A9',N("HO"B`@("`@("`@("`@
M("`@("`@("`@)&QI<W1S(#T@)')E9VES=')Y+3YC86QL*"=N;W1E<R]L:7-T
M3F]T97!A9',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2AF86QS92P@4$5235-?141)5"DI.PH*("`@("`@
M("`@("`@("`@("`@("`O*B!!='1E;7!T('1O(&%D9"!T:&4@;F5W('9.;W1E
M(&ET96T@=&\@=&AE(')E<75E<W1E9`H@("`@("`@("`@("`@("`@("`@("`J
M(&YO=&5P860N("HO"B`@("`@("`@("`@("`@("`@("`@)')E<R`]("1R96=I
M<W1R>2T^8V%L;"@G;F]T97,O:6UP;W)T)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1V3F]T92P@)W1E>'0O
M>"UV;F]T92<L("1L:7-T*2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES7V$H
M)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H)')E<RP@)')E<RT^9V5T0V]D92@I*3L*("`@
M("`@("`@("`@("`@('T@96QS96EF("@A)')E<RD@>PH@("`@("`@("`@("`@
M("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@("`@("`@("!C
M87-E("=T87-K)SH@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")!;B!U;FMN;W=N
M(&5R<F]R(&]C8W5R960@=VAI;&4@8W)E871I;F<@=&AE(&YE=R!T87-K+B(I
M+"`G:&]R9&4N97)R;W(G*3L@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M8V%S92`G;F]T92<Z("1N;W1I9FEC871I;VXM/G!U<V@H7R@B06X@=6YK;F]W
M;B!E<G)O<B!O8V-U<F5D('=H:6QE(&-R96%T:6YG('1H92!N97<@;F]T92XB
M*2P@)VAO<F1E+F5R<F]R)RD[(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2`G(B<@+B!H=&UL<W!E8VEA;&-H87)S*"1S=6)J96-T*2`N
M("<B)SL*"B`@("`@("`@("`@("`@("`@("`@+RH@071T96UP="!T;R!C;VYV
M97)T('1H92!O8FIE8W0@;F%M92!I;G1O(&$@:'EP97)L:6YK+B`J+PH@("`@
M("`@("`@("`@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@
M("`@("`@("!C87-E("=T87-K)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M)&QI;FL@/2`D<F5G:7-T<GDM/FQI;FLH)W1A<VMS+W-H;W<G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G=6ED)R`]/B`D<F5S*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VYO=&4G.@H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E9VES=')Y+3YH87--971H;V0H)VYO
M=&5S+W-H;W<G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QI
M;FL@/2`D<F5G:7-T<GDM/FQI;FLH)VYO=&5S+W-H;W<G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)W5I9"<@/3X@)')E<RDI.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QI;FL@/2!F
M86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1L:6YK("8F("%I<U]A*"1L:6YK+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M<W!R:6YT9B@G/&$@:')E9CTB)7,B/B5S/"]A/B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ=7)L*"1L:6YK*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*"(E<R!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O(%PB)7-<(BXB*2P@)&YA;64L(&AT;6QS<&5C:6%L
M8VAA<G,H)&QI<W1S6R1L:7-T72T^9V5T*"=N86UE)RDI*2P@)VAO<F1E+G-U
M8V-E<W,G+"!A<G)A>2@G8V]N=&5N="YR87<G*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($1E;&5T
M92!T:&4@;W)I9VEN86P@;65S<V%G97,@:68@=&AI<R!I<R!A(")M;W9E(B!O
M<&5R871I;VXN("HO"B`@("`@("`@:68@*"1A8W1I;VX@/3T@24U07TU%4U-!
M1T5?34]612D@>PH@("`@("`@("`@("`D=&AI<RT^9&5L971E*"1I;F1I8V5S
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4W1R:7!S(&$@34E-12!087)T(&]U="!O9B!A(&UE<W-A
M9V4N"B`@("`@*B!(86YD;&5S('1H92!)35!?4T5!4D-(7TU"3U@@;6%I;&)O
M>"X*("`@("`J"B`@("`@*B!`<&%R86T@24U07TUA:6QB;W@@)B1I;7!?;6%I
M;&)O>"`@5&AE($E-4%]-86EL8F]X(&]B:F5C="!W:71H('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-U<G)E;G0@:6YD
M97@@<V5T('1O('1H92!M97-S86=E('1O(&)E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<')O8V5S<V5D+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%R=&ED("`@("`@("`@("`@(%1H92!-24U%($E$(&]F
M('1H92!P87)T('1O('-T<FEP+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L(&]R(%!%05)?17)R;W(@
M;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<FEP4&%R="@F)&EM
M<%]M86EL8F]X+"`D<&%R=&ED*0H@("`@>PH@("`@("`@(&=L;V)A;"`D:6UP
M.PH*("`@("`@("`O*B!2971U<FX@97)R;W(@:68@;F\@:6YD97@@=V%S('!R
M;W9I9&5D+B`J+PH@("`@("`@(&EF("@A*"1M<V=,:7-T(#T@24U0.CIP87)S
M94EN9&EC97-,:7-T*"1I;7!?;6%I;&)O>"DI*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=.;R!I;F1E>"!P<F]V:61E9"!T;R!)
M35!?365S<V%G93HZ<W1R:7!087)T*"DN)RD["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!M;W)E('1H86X@;VYE(&EN9&5X('!R;W9I9&5D+"!R971U<FX@
M97)R;W(N("HO"B`@("`@("`@<F5S970H)&US9TQI<W0I.PH@("`@("`@(&QI
M<W0H)&9O;&1E<BP@)&EN9&5X*2`](&5A8V@H)&US9TQI<W0I.PH@("`@("`@
M(&EF("AE86-H*"1M<V=,:7-T*2!\?"`H8V]U;G0H)&EN9&5X*2`^(#$I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=-;W)E('1H
M86X@,2!I;F1E>"!P<F]V:61E9"!T;R!)35!?365S<V%G93HZ<W1R:7!087)T
M*"DN)RD["B`@("`@("`@?0H@("`@("`@("1I;F1E>"`](&EM<&QO9&4H)R<L
M("1I;F1E>"D["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]0
M87)T+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L
M:6(O34E-12]#;VYT96YT<RYP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+TU)344O2&5A9&5R<RYP:'`G.PH*("`@("`@("`O
M*B!'970@82!L;V-A;"!C;W!Y(&]F('1H92!M97-S86=E(&%N9"!S=')I<"!O
M=70@=&AE(&1E<VER960*("`@("`@("`@("!-24U%7U!A<G0@;V)J96-T+B`J
M+PH@("`@("`@("1C;VYT96YT<R`]("9)35!?0V]N=&5N=',Z.G-I;F=L971O
M;B@D:6YD97@@+B!)35!?24187U-%4"`N("1F;VQD97(I.PH@("`@("`@("1C
M;VYT96YT<RT^<F5B=6EL9$UE<W-A9V4H*3L*("`@("`@("`D;65S<V%G92`]
M("1C;VYT96YT<RT^9V5T34E-14UE<W-A9V4H*3L*("`@("`@("`D;VQD4&%R
M="`]("1M97-S86=E+3YG971087)T*"1P87)T:60I.PH@("`@("`@("1N97=0
M87)T(#T@;F5W($U)345?4&%R="@G=&5X="]P;&%I;B<I.PH@("`@("`@("1N
M97=087)T+3YS971#;VYT96YT<R@G6R<@+B!?*")!='1A8VAM96YT('-T<FEP
M<&5D.B!/<FEG:6YA;"!A='1A8VAM96YT('1Y<&4B*2`N("<Z("(G("X@)&]L
M9%!A<G0M/F=E=%1Y<&4H*2`N("<B+"`G("X@7R@B;F%M92(I("X@)SH@(B<@
M+B`D;VQD4&%R="T^9V5T3F%M92AT<G5E+"!T<G5E*2`N("<B72<L("<X8FET
M)RD["B`@("`@("`@)&UE<W-A9V4M/F%L=&5R4&%R="@D<&%R=&ED+"`D;F5W
M4&%R="D["@H@("`@("`@("\J(%=E(&YE960@=&\@;6%K92!S=7)E('=E(&%D
M9"`B7')<;B(@869T97(@979E<GD@;&EN92!F;W(*("`@("`@("`@("!I;6%P
M7V%P<&5N9"@I("T@<V]M92!S97)V97)S(')E<75I<F4@:70@*&4N9RX@0WER
M=7,I+B`J+PH@("`@("`@("1M97-S86=E+3YS971%3TPH34E-15]005)47U)&
M0U]%3TPI.PH*("`@("`@("`O*B!'970@=&AE(&AE861E<G,@9F]R('1H92!M
M97-S86=E+B`J+PH@("`@("`@("1H96%D97)S(#T@)FYE=R!)35!?2&5A9&5R
M<R@D:6YD97@I.PH@("`@("`@("1H96%D97)S+3YB=6EL9$9L86=S*"D["B`@
M("`@("`@)&9L86=S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("AA<G)A
M>2@G86YS=V5R960G+"`G9')A9G0G+"`G9FQA9V=E9"<L("=D96QE=&5D)RD@
M87,@)&9L86<I('L*("`@("`@("`@("`@:68@*"1H96%D97)S+3YG971&;&%G
M*"1F;&%G*2D@>PH@("`@("`@("`@("`@("`@)&9L86=S6UT@/2`G7%PG("X@
M4W1R:6YG.CIU8V9I<G-T*"1F;&%G*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`D9FQA9W,@/2!I;7!L;V1E*"<@)RP@)&9L86=S*3L*"B`@
M("`@("`@+RH@5&AI<R!I<R!A("AS;W)T+6]F*2!H86-K+B!2:6=H="!B969O
M<F4@=V4@87!P96YD('1H92!N97<@;65S<V%G90H@("`@("`@("`@('=E(&-H
M96-K(&EM87!?<W1A='5S*"D@=&\@9&5T97)M:6YE('1H92!N97AT(&%V86EL
M86)L92!5240N(%=E"B`@("`@("`@("`@=7-E('1H:7,@54E$(&%S('1H92!N
M97<@:6YD97@@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&9O;&1E<G-T
M<FEN9R`]($E-4#HZ<V5R=F5R4W1R:6YG*"1F;VQD97(I.PH@("`@("`@("1T
M:&ES+3Y?:6UP26UA<"T^8VAA;F=E36)O>"@D9F]L9&5R<W1R:6YG*3L*("`@
M("`@("`D<W1A='5S(#T@0&EM87!?<W1A='5S*"1I;7!;)W-T<F5A;2==+"`D
M9F]L9&5R<W1R:6YG+"!305]5241.15A4*3L*("`@("`@("!I9B`H0&EM87!?
M87!P96YD*"1I;7!;)W-T<F5A;2==+"`D9F]L9&5R<W1R:6YG+"`D:&5A9&5R
M<RT^9V5T2&5A9&5R5&5X="@I("X@)&-O;G1E;G1S+3YT;U-T<FEN9R@D;65S
M<V%G92P@=')U92DL("=<7%-%14XG*2D@>PH@("`@("`@("`@("`D:61X7V%R
M<F%Y(#T@87)R87DH)&9O;&1E<B`]/B`D:6YD97@I.PH@("`@("`@("`@("`D
M=&AI<RT^9&5L971E*"1I9'A?87)R87DL('1R=64L('1R=64I.PH@("`@("`@
M("`@("`D:61X7V%R<F%Y(#T@87)R87DH)&9O;&1E<B`]/B`D<W1A='5S+3YU
M:61N97AT*3L*("`@("`@("`@("`@)'1H:7,M/F9L86<H)&9L86=S+"`D:61X
M7V%R<F%Y*3L*("`@("`@("`@("`@)&EM<%]M86EL8F]X+3YU<&1A=&5-86EL
M8F]X*$E-4%]-04E,0D]87U501$%412D["B`@("`@("`@("`@("1I;7!?;6%I
M;&)O>"T^<V5T3F5W26YD97@H)'-T871U<RT^=6ED;F5X="D["@H@("`@("`@
M("`@("`O*B!792!N965D('1O(')E<&QA8V4@=&AE(&]L9"!I;F1E>"!I;B!T
M:&4@<75E<GD@<W1R:6YG('=I=&@@=&AE"B`@("`@("`@("`@("`@(&YE=R!I
M;F1E>"X@*B\*("`@("`@("`@("`@)%]315)615);)U%515)97U-44DE.1R==
M(#T@<')E9U]R97!L86-E*"<O)R`N("1I;F1E>"`N("<O)RP@)'-T871U<RT^
M=6ED;F5X="P@)%]315)615);)U%515)97U-44DE.1R==*3L*"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%N(&5R<F]R(&]C8W5R960@
M=VAI;&4@871T96UP=&EN9R!T;R!S=')I<"!T:&4@871T86-H;65N="X@5&AE
M($E-05`@<V5R=F5R('-A:60Z("(I("X@:6UA<%]L87-T7V5R<F]R*"DI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@;W(@8VQE87)S
M(&$@9VEV96X@9FQA9R!F;W(@82!L:7-T(&]F(&UE<W-A9V5S+@H@("`@("H@
M2&%N9&QE<R!U<V4@;V8@=&AE($E-4%]314%20TA?34)/6"!M86EL8F]X+@H@
M("`@("H@5&AI<R!F=6YC=&EO;B!W;W)K<R!W:71H($E-05`@;VYL>2P@;F]T
M(%!/4#,N"B`@("`@*@H@("`@("H@5F%L:60@9FQA9W,@87)E.@H@("`@("H@
M("!<7%-%14X*("`@("`J("`@7%Q&3$%'1T5$"B`@("`@*B`@(%Q<04Y35T52
M140*("`@("`J("`@7%Q$14Q%5$5$"B`@("`@*B`@(%Q<1%)!1E0*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;&%G("`@("!4:&4@24U!4"!F;&%G
M*',I('1O('-E="!O<B!C;&5A<BX*("`@("`J($!P87)A;2!M:7AE9"`F)&EN
M9&EC97,@(%-E92!A8F]V92X*("`@("`J($!P87)A;2!B;V]L96%N("1A8W1I
M;VX@($EF('1R=64L('-E="!T:&4@9FQA9RAS*2P@;W1H97)W:7-E(&-L96%R
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9FQA9RAS*2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@<W5C8V5S
M<V9U;"P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!F;&%G
M*"1F;&%G+"`F)&EN9&EC97,L("1A8W1I;VX@/2!T<G5E*0H@("`@>PH@("`@
M("`@(&EF("@A*"1M<V=,:7-T(#T@24U0.CIP87)S94EN9&EC97-,:7-T*"1I
M;F1I8V5S*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@)&9U;F-T:6]N(#T@*"1A8W1I;VXI(#\@)VEM87!?<V5T
M9FQA9U]F=6QL)R`Z("=I;6%P7V-L96%R9FQA9U]F=6QL)SL*("`@("`@("`D
M<F5T=7)N7W9A;'5E(#T@=')U93L*"B`@("`@("`@9F]R96%C:"`H)&US9TQI
M<W0@87,@)&9O;&1E<B`]/B`D;7-G26YD:6-E<RD@>PH@("`@("`@("`@("`D
M;7-G261X4W1R:6YG(#T@:6UP;&]D92@G+"<L("1M<V=);F1I8V5S*3L*"B`@
M("`@("`@("`@("\J(%-W:71C:"!F;VQD97)S+"!I9B!N96-E<W-A<GDN("HO
M"B`@("`@("`@("`@("1T:&ES+3Y?:6UP26UA<"T^8VAA;F=E36)O>"@D9F]L
M9&5R*3L*"B`@("`@("`@("`@("\J($9L86<O=6YF;&%G('1H92!M97-S86=E
M<R!N;W<N("HO"B`@("`@("`@("`@(&EF("@A8V%L;%]U<V5R7V9U;F,H)&9U
M;F-T:6]N+"`D1TQ/0D%,4ULG:6UP)UU;)W-T<F5A;2==+"`D;7-G261X4W1R
M:6YG+"`D9FQA9RP@4U1?54E$*2D@>PH@("`@("`@("`@("`@("`@)$=,3T)!
M3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S
M(&%N(&5R<F]R(&9L86=G:6YG(&UE<W-A9V5S(&EN('1H92!F;VQD97(@7"(E
M<UPB+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED(BDL($E-4#HZ9&ES
M<&QA>49O;&1E<B@D9F]L9&5R*2D@+B`G.B`G("X@:6UA<%]L87-T7V5R<F]R
M*"DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@)')E='5R;E]V
M86QU92`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)')E='5R;E]V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@;W(@8VQE87)S(&$@9VEV96X@9FQA9RAS*2!F;W(@86QL(&UE<W-A
M9V5S(&EN(&$@;&ES="!O9B!M86EL8F]X97,N"B`@("`@*B!4:&ES(&9U;F-T
M:6]N('=O<FMS('=I=&@@24U!4"!O;FQY+"!N;W0@4$]0,RX*("`@("`J"B`@
M("`@*B!3964@9FQA9R@I(&9O<B!T:&4@;&ES="!O9B!V86QI9"!F;&%G<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;&%G("`@("!4:&4@24U!
M4"!F;&%G*',I('1O('-E="!O<B!C;&5A<BX*("`@("`J($!P87)A;2!A<G)A
M>2`D;6)O>&5S("`@(%1H92!L:7-T(&]F(&UA:6QB;WAE<R!T;R!F;&%G+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%C=&EO;B`@268@=')U92P@<V5T('1H
M92!F;&%G*',I+"!O=&AE<G=I<V4L(&-L96%R('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@9FQA9RAS*2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@<W5C8V5S<V9U;"P@9F%L<V4@:68@;F]T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!F;&%G06QL26Y-86EL8F]X*"1F;&%G
M+"`D;6)O>&5S+"`D86-T:6]N(#T@=')U92D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)&UB;WAE<RD@?'P@(6ES7V%R<F%Y*"1M8F]X97,I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R971U
M<FY?=F%L=64@/2!T<G5E.PH*("`@("`@("!F;W)E86-H("@D;6)O>&5S(&%S
M("1V86PI('L*("`@("`@("`@("`@+RH@4W=I=&-H(&9O;&1E<G,L(&EF(&YE
M8V5S<V%R>2X@*B\*("`@("`@("`@("`@)'1H:7,M/E]I;7!);6%P+3YC:&%N
M9V5-8F]X*"1V86PI.PH@("`@("`@("`@("!I9B`H)'5I9',@/2!`:6UA<%]S
M96%R8V@H)$=,3T)!3%-;)VEM<"==6R=S=')E86TG72P@)T%,3"<L(%-%7U5)
M1"DI('L*("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@87)R87DH)'9A;"`]
M/B`D=6ED<RD["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YF;&%G*"1F
M;&%G+"`D:6YD:6-E<RP@)&%C=&EO;BDI('L*("`@("`@("`@("`@("`@("`@
M("`D<F5T=7)N7W9A;'5E(#T@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T=7)N
M7W9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP=6YG97,@86QL(&1E
M;&5T960@;65S<V%G97,@9G)O;2!T:&4@;&ES="!O9B!M86EL8F]X97,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M8F]X7VQI<W0@(%1H92!L:7-T
M(&]F(&UA:6QB;WAE<R!T;R!E;7!T>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M97AP=6YG94UA:6QB;W@H)&UB;WA?;&ES="D*("`@('L*("`@("`@("!G;&]B
M86P@)&EM<#L*"B`@("`@("`@9F]R96%C:"`H)&UB;WA?;&ES="!A<R`D=F%L
M*2!["B`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG:6UP7W-E87)C:"==+3YI
M<U-E87)C:$UB;W@H)'9A;"DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1'3$]"04Q36R=I;7!?<V5A<F-H)UTM/F=E=%-E87)C:$9O;&1E<G,H)'9A
M;"D@87,@)&9O;&1E<BD@>PH@("`@("`@("`@("`@("`@("`@("1S=')E86T@
M/2`D=&AI<RT^7VEM<$EM87`M/F]P96Y)34%04W1R96%M*"1F;VQD97(I.PH@
M("`@("`@("`@("`@("`@("`@($!I;6%P7V5X<'5N9V4H)'-T<F5A;2D["B`@
M("`@("`@("`@("`@("`@("`@0&EM87!?8VQO<V4H)'-T<F5A;2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VEM<$EM87`M/F-H86YG94UB;W@H)'9A;"D["B`@("`@
M("`@("`@("`@("!`:6UA<%]E>'!U;F=E*"1I;7!;)W-T<F5A;2==*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5M
M<'1I97,@86X@96YT:7)E(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1M8F]X7VQI<W0@(%1H92!L:7-T(&]F(&UA:6QB;WAE<R!T;R!E
M;7!T>2X*("`@("`J+PH@("`@9G5N8W1I;VX@96UP='E-86EL8F]X*"1M8F]X
M7VQI<W0I"B`@("!["B`@("`@("`@9VQO8F%L("1I;7`L("1N;W1I9FEC871I
M;VX["@H@("`@("`@(&9O<F5A8V@@*"1M8F]X7VQI<W0@87,@)&UB;W@I('L*
M("`@("`@("`@("`@:68@*"1'3$]"04Q36R=I;7!?<V5A<F-H)UTM/FES5E1R
M87-H1F]L9&5R*"1M8F]X*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F5X
M<'5N9V5-86EL8F]X*"1'3$]"04Q36R=I;7!?<V5A<F-H)UTM/F=E=%-E87)C
M:$9O;&1E<G,H)&UB;W@I*3L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H7R@B16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2!6:7)T=6%L
M(%1R87-H($9O;&1E<BXB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M9&ES<&QA>5]M8F]X(#T@24U0.CID:7-P;&%Y1F]L9&5R*"1M8F]X*3L*"B`@
M("`@("`@("`@(&EF("@H)'1H:7,M/E]I;7!);6%P+3YC:&%N9V5-8F]X*"1M
M8F]X*2D@(3T]('1R=64I('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@9&5L971E(&UE<W-A9V5S
M(&9R;VT@)7,N(%1H92!S97)V97(@<V%I9#H@)7,B*2P@)&1I<W!L87E?;6)O
M>"P@:6UA<%]L87-T7V5R<F]R*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!-86ME('-U<F4@=&AE<F4@:7,@870@;&5A<W0@,2!M97-S86=E(&)E
M9F]R92!A='1E;7!T:6YG('1O"B`@("`@("`@("`@("`@(&1E;&5T92X@*B\*
M("`@("`@("`@("`@)&-H96-K(#T@0&EM87!?8VAE8VLH)&EM<%LG<W1R96%M
M)UTI.PH@("`@("`@("`@("`D9&5L971E7V%R<F%Y(#T@87)R87DH)&UB;W@@
M/3X@)S$Z*B<I.PH@("`@("`@("`@("!I9B`H(6ES7V]B:F5C="@D8VAE8VLI
M*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN
M=&8H7R@B)7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@;6%I;&)O
M>"XB*2P@)&1I<W!L87E?;6)O>"DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@
M("`@("!](&5L<V5I9B`H96UP='DH)&-H96-K+3Y.;7-G<RDI('L*("`@("`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@
M;6%I;&)O>"`E<R!I<R!A;')E861Y(&5M<'1Y+B(I+"`D9&ES<&QA>5]M8F]X
M*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@?2!E;'-E:68@*"$D
M=&AI<RT^9&5L971E*"1D96QE=&5?87)R87DL('1R=64I*2!["B`@("`@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@
M=V%S(&$@<')O8FQE;2!E>'!U;F=I;F<@=&AE(&UA:6QB;W@N(%1H92!S97)V
M97(@<V%I9#H@)7,B*2P@:6UA<%]L87-T7V5R<F]R*"DI+"`G:&]R9&4N97)R
M;W(G*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@0&EM87!?97AP=6YG92@D:6UP6R=S
M=')E86TG72D["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B16UP=&EE9"!A;&P@;65S<V%G97,@9G)O;2`E<RXB*2P@
M)&1I<W!L87E?;6)O>"DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+VQI8B]#;VUP;W-E+G!H<```````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$Q-3(P-P`Q,#0Q-S,V
M,C<V-@`P,C`Q,#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G
M.PH*+RHJ"B`J(%1H92!V:7)T=6%L('!A=&@@=&\@=7-E(&9O<B!61E,@9&%T
M82X*("HO"F1E9FEN92@G24U07U9&4U]!5%1!0TA?4$%42"<L("<N:&]R9&4O
M:6UP+V-O;7!O<V4G*3L*"B\J*@H@*B!4:&4@=FER='5A;"!P871H('1O('-A
M=F4@;&EN:V5D(&%T=&%C:&UE;G1S+@H@*B\*9&5F:6YE*"=)35!?5D937TQ)
M3DM?051404-(7U!!5$@G+"`G+FAO<F1E+VEM<"]A='1A8VAM96YT<R<I.PH*
M+RHJ"B`J(%1H92!)35!?0V]M<&]S93HZ(&-L87-S(&-O;G1A:6YS(&9U;F-T
M:6]N<R!R96QA=&5D('1O(&=E;F5R871I;F<*("H@;W5T9V]I;F<@;6%I;"!M
M97-S86=E<RX*("H*("H@)$AO<F1E.B!I;7`O;&EB+T-O;7!O<V4N<&AP+'8@
M,2XQ,#<N,BXS,"`R,#`V+S`R+S`R(#`P.C$W.C$U(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J($!S:6YC92`@($E-4"`T+C`*("H@0'!A8VMA9V4@24U0"B`J
M+PIC;&%S<R!)35!?0V]M<&]S92!["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%C
M:&5D(&%T=&%C:&UE;G0@9&%T82X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($9O<B!F:6YD0F]D>2P@=&AE($U)344@240@;V8@=&AE(")B;V1Y
M(B!P87)T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7VUI;65I9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@86=G
M<F5G871E('-I>F4@;V8@86QL(&%T=&%C:&UE;G1S("AI;B!B>71E<RDN"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W-I
M>F4@/2`P.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@4&%R86UE=&5R<R!N965D960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($E-4%]#;VUP;W-E*"1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=C86-H
M94E$)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5T<FEE=F5-:6UE0V%C
M:&4H)'!A<F%M<ULG8V%C:&5)1"==*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!396YD<R!A(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D96UA:6P@("`@("`@("`@5&AE(&4M;6%I;"!L:7-T('1O
M('-E;F0@=&\N"B`@("`@*B!`<&%R86T@24U07TAE861E<G,@)B1H96%D97)S
M("!4:&4@24U07TAE861E<G,@;V)J96-T(&AO;&1I;F<@=&AI<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;65S<V%G97,@:&5A9&5R
M<RX*("`@("`J($!P87)A;2!M:7AE9"`F)&UE<W-A9V4@("`@("`@($5I=&AE
M<B!T:&4@;65S<V%G92!T97AT("AS=')I;F<I(&]R(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($U)345?365S<V%G92!O8FIE8W0@
M=&AA="!C;VYT86EN<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1E>'0@=&\@<V5N9"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&-H87)S970@("`@("`@(%1H92!C:&%R<V5T('1H870@=V%S('5S960@9F]R
M('1H92!H96%D97)S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5N9$UE<W-A9V4H)&5M86EL+"`F)&AE861E<G,L("8D
M;65S<V%G92P@)&-H87)S970I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF
M.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PN<&AP)SL*"B`@("`@("`@
M+RH@5V4@9&]N)W0@86-T=6%L;'D@=V%N="!T;R!A;'1E<B!T:&4@8V]N=&5N
M=',@;V8@=&AE("1C;VYF6R=M86EL97(G70H@("`@("`@("`J(&%R<F%Y+"!S
M;R!W92!M86ME(&$@8V]P>2!O9B!T:&4@8W5R<F5N="!S971T:6YG<RX@5V4@
M=VEL;"!A<'!L>2!O=7(*("`@("`@("`@*B!M;V1I9FEC871I;VYS("AI9B!A
M;GDI('1O('1H92!C;W!Y+"!I;G-T96%D+B`J+PH@("`@("`@("1P87)A;7,@
M/2`D8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==.PH@("`@("`@("1D<FEV97(@
M/2`D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G73L*"B`@("`@("`@+RH@268@=7-E
M<B!S<&5C:69I97,@86X@4TU44"!S97)V97(@;VX@;&]G:6XL(&9O<F-E(%--
M5%`@;6%I;&5R+B`J+PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;)W-E<G9E
M<B==6R=C:&%N9V5?<VUT<&AO<W0G72DI('L*("`@("`@("`@("`@)&1R:79E
M<B`]("=S;71P)SL*("`@("`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)VUA
M:6QE<B==6R=A=71H)UTI*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R=M
M86EL97(G75LG875T:"==(#T@)S$G.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O*B!&;W)C92!T:&4@4TU44"!H;W-T(&%N9"!P;W)T('9A
M;'5E('1O('1H92!C=7)R96YT(%--5%`@<V5R=F5R(&EF"B`@("`@("`@("H@
M;VYE(&AA<R!B965N('-E;&5C=&5D(&9O<B!T:&ES(&-O;FYE8W1I;VXN("HO
M"B`@("`@("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)VEM<"==6R=S;71P:&]S
M="==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=H;W-T)UT@/2`D7U-%4U-)
M3TY;)VEM<"==6R=S;71P:&]S="==.PH@("`@("`@('T*("`@("`@("!I9B`H
M(65M<'1Y*"1?4T534TE/3ELG:6UP)UU;)W-M='!P;W)T)UTI*2!["B`@("`@
M("`@("`@("1P87)A;7-;)W!O<G0G72`]("1?4T534TE/3ELG:6UP)UU;)W-M
M='!P;W)T)UT["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!33510(&%U=&AE
M;G1I8V%T:6]N(&AA<R!B965N(')E<75E<W1E9"P@=7-E(&5I=&AE<B!T:&4@
M=7-E<FYA;64*("`@("`@("`@*B!A;F0@<&%S<W=O<F0@<')O=FED960@:6X@
M=&AE(&-O;F9I9W5R871I;VX@;W(@<&]P=6QA=&4@=&AE('5S97)N86UE"B`@
M("`@("`@("H@86YD('!A<W-W;W)D(&9I96QD<R!B87-E9"!O;B!T:&4@8W5R
M<F5N="!V86QU97,@9F]R('1H92!U<V5R+B!.;W1E"B`@("`@("`@("H@=&AA
M="!W92!A<W-U;64@=&AA="!T:&4@=7-E<FYA;64@86YD('!A<W-W;W)D('9A
M;'5E<R!F<F]M('1H90H@("`@("`@("`J(&-U<G)E;G0@24U!4"`O(%!/4#,@
M8V]N;F5C=&EO;B!A<F4@=F%L:60@9F]R(%--5%`@875T:&5N=&EC871I;VX@
M87,*("`@("`@("`@*B!W96QL+B`J+PH@("`@("`@(&EF("@A96UP='DH)'!A
M<F%M<ULG875T:"==*2`F)B!E;7!T>2@D<&%R86US6R=U<V5R;F%M92==*2D@
M>PH@("`@("`@("`@("`D<&%R86US6R=U<V5R;F%M92==(#T@)%]315-324].
M6R=I;7`G75LG=7-E<B==.PH@("`@("`@("`@("`D<&%R86US6R=P87-S=V]R
M9"==(#T@4V5C<F5T.CIR96%D*%-E8W)E=#HZ9V5T2V5Y*"=I;7`G*2P@)%]3
M15-324].6R=I;7`G75LG<&%S<R==*3L*("`@("`@("!]"@H@("`@("`@("\J
M($%D9"!T:&4@<VET92!H96%D97)S+B`J+PH@("`@("`@("1H96%D97)S+3YA
M9&13:71E2&5A9&5R<R@I.PH*("`@("`@("`O*B!)9B`D;65S<V%G92!I<R!A
M('-T<FEN9RP@=V4@;F5E9"!T;R!G970@82!-24U%7TUE<W-A9V4@;V)J96-T
M('1O"B`@("`@("`@("H@96YC;V1E('1H92!H96%D97)S+B`J+PH@("`@("`@
M(&EF("AI<U]S=')I;F<H)&UE<W-A9V4I*2!["B`@("`@("`@("`@("1M<V<@
M/2`D;65S<V%G93L*("`@("`@("`@("`@)&UI;65?;65S<V%G92`]("9N97<@
M34E-15]-97-S86=E*"1?4T534TE/3ELG:6UP)UU;)VUA:6QD;VUA:6XG72D[
M"B`@("`@("`@("`@("1H96%D97)!<G)A>2`]("1M:6UE7VUE<W-A9V4M/F5N
M8V]D92@D:&5A9&5R<RT^=&]!<G)A>2@I+"`D8VAA<G-E="D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&US9R`]("1M97-S86=E+3YT;U-T<FEN
M9R@I.PH@("`@("`@("`@("`D:&5A9&5R07)R87D@/2`D;65S<V%G92T^96YC
M;V1E*"1H96%D97)S+3YT;T%R<F%Y*"DL("1C:&%R<V5T*3L*("`@("`@("!]
M"@H@("`@("`@("\J($UA:V4@<W5R92!T:&4@;65S<V%G92!H87,@82!T<F%I
M;&EN9R!N97=L:6YE+B`J+PH@("`@("`@(&EF("AS=6)S='(H)&US9RP@+3$I
M("$](")<;B(I('L*("`@("`@("`@("`@)&US9R`N/2`B7&XB.PH@("`@("`@
M('T*"B`@("`@("`@)&UA:6QE<B`]($UA:6PZ.F9A8W1O<GDH)&1R:79E<BP@
M)'!A<F%M<RD["B`@("`@("`@:68@*&ES7V$H)&UA:6QE<BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&UA:6QE<CL*("`@("`@("!]
M"@H@("`@("`@("\J(%!R;W!E<FQY(&5N8V]D92!T:&4@861D<F5S<V5S('=E
M)W)E('-E;F1I;F<@=&\N("HO"B`@("`@("`@)&5M86EL(#T@34E-13HZ96YC
M;V1E061D<F5S<R@D96UA:6PL(&YU;&PL("1?4T534TE/3ELG:6UP)UU;)VUA
M:6QD;VUA:6XG72D["B`@("`@("`@:68@*&ES7V$H)&5M86EL+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D96UA:6P["B`@("`@("`@
M?0H*("`@("`@("`O*B!686QI9&%T92!T:&4@<F5C:7!I96YT(&%D9')E<W-E
M<RX@*B\*("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<[
M"B`@("`@("`@)'!A<G-E<B`]("9N97<@36%I;%]21D,X,C(H*3L*("`@("`@
M("`D<F5S=6QT(#T@)'!A<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D96UA:6PL
M("1?4T534TE/3ELG:6UP)UU;)VUA:6QD;VUA:6XG72P@;G5L;"P@=')U92D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'0@/2`D;6%I;&5R+3YS96YD*"1E;6%I;"P@)&AE861E<D%R<F%Y
M+"`D;7-G*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2`F)@H@("`@("`@("`@("`D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G72`]
M/2`G<V5N9&UA:6PG*2!["B`@("`@("`@("`@("\O($EN=&5R<')E="!R971U
M<FX@=F%L=65S(&%S(&1E9FEN960@:6X@+W5S<B]I;F-L=61E+W-Y<V5X:71S
M+F@*("`@("`@("`@("`@<W=I=&-H("@D<F5S=6QT+3YG971#;V1E*"DI('L*
M("`@("`@("`@("`@8V%S92`V-#H@+R\@15A?55-!1T4*("`@("`@("`@("`@
M("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F-O;6UA;F0@;&EN92!U
M<V%G92!E<G)O<B(I("X@)R`H-C0I)SL*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`V-3H@+R\@15A?1$%404524@H@("`@("`@
M("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@7R@B9&%T82!F;W)M
M870@97)R;W(B*2`N("<@*#8U*2<["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@-C8Z("\O($587TY/24Y0550*("`@("`@("`@
M("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F-A;FYO="!O<&5N
M(&EN<'5T(BD@+B`G("@V-BDG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E(#8W.B`O+R!%6%].3U5315(*("`@("`@("`@("`@
M("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F%D9')E<W-E92!U;FMN
M;W=N(BD@+B`G("@V-RDG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E(#8X.B`O+R!%6%].3TA/4U0*("`@("`@("`@("`@("`@
M("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(FAO<W0@;F%M92!U;FMN;W=N
M(BD@+B`G("@V."DG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(#8Y.B`O+R!%6%]53D%604E,04),10H@("`@("`@("`@("`@
M("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@7R@B<V5R=FEC92!U;F%V86EL
M86)L92(I("X@)R`H-CDI)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`W,#H@+R\@15A?4T]&5%=!4D4*("`@("`@("`@("`@
M("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(FEN=&5R;F%L('-O9G1W
M87)E(&5R<F]R(BD@+B`G("@W,"DG.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E(#<Q.B`O+R!%6%]/4T524@H@("`@("`@("`@
M("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@7R@B<WES=&5M(&5R<F]R
M(BD@+B`G("@W,2DG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(#<R.B`O+R!%6%]/4T9)3$4*("`@("`@("`@("`@("`@("1E
M<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F-R:71I8V%L('-Y<W1E;2!F:6QE
M(&UI<W-I;F<B*2`N("<@*#<R*2<["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@-S,Z("\O($587T-!3E1#4D5!5`H@("`@("`@
M("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@7R@B8V%N;F]T(&-R
M96%T92!O=71P=70@9FEL92(I("X@)R`H-S,I)SL*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W-#H@+R\@15A?24]%4E(*("`@
M("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(FEN<'5T
M+V]U='!U="!E<G)O<B(I("X@)R`H-S0I)SL*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`W-3H@+R\@15A?5$5-4$9!24P*("`@
M("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(G1E;7!O
M<F%R>2!F86EL=7)E(BD@+B`G("@W-2DG.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E(#<V.B`O+R!%6%]04D]43T-/3`H@("`@
M("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@7R@B<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L(BD@+B`G("@W-BDG.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<W.B`O+R!%6%].3U!%4DT*
M("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(G!E
M<FUI<W-I;VX@9&5N:65D(BD@+B`G("@W-RDG.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(#<X.B`O+R!%6%]#3TY&24<*("`@
M("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F-O;F9I
M9W5R871I;VX@97)R;W(B*2`N("<@*#<X*2<["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-SDZ("\O($587TY/5$9/54Y$"B`@
M("`@("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?*")E;G1R
M>2!N;W0@9F]U;F0B*2`N("<@*#<Y*2<["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D97)R
M;W(@/2`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"1E<G)O<BD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S
M('1H92!M86EN(")B;V1Y(B!T97AT('!A<G0@*&EF(&%N>2D@:6X@82!M97-S
M86=E+@H@("`@("H*("`@("`J($!P87)A;2!)35!?0V]N=&5N=',@)B1I;7!?
M8V]N=&5N=',@($%N($E-4%]#;VYT96YT<R!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&]F('1H92`B8F]D>2(@<&%R
M="!O9B!T:&4@;65S<V%G92X*("`@("`J("`@("`@("`@("`@("`@("!2971U
M<FYS(&%N(&5M<'1Y('-T<FEN9R!I9B!N;R`B8F]D>2(@9F]U;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&9I;F1";V1Y*"8D:6UP7V-O;G1E;G1S*0H@("`@
M>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?;6EM96ED*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VUI;65I9"`]("1I;7!?8V]N=&5N=',M/F9I;F1"
M;V1Y*"D["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?;6EM96ED
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D;6EM95]P87)T(#T@)B1I;7!?8V]N=&5N
M=',M/F=E=$1E8V]D961-24U%4&%R="@D=&AI<RT^7VUI;65I9"D["B`@("`@
M("`@)&)O9'D@/2`D;6EM95]P87)T+3YG971#;VYT96YT<R@I.PH*("`@("`@
M("`O+VEF("@D;6EM95]M97-S86=E+3YG9714>7!E*"D@/3T@)VUU;'1I<&%R
M="]E;F-R>7!T960G*2!["B`@("`@("`@("`@("\J(%1/1$\Z($UA>6)E('-O
M;65D87D@22!C86X@9FEG=7)E(&]U="!H;W<@=&\@<VAO=R!E;6)E9&1E9`H@
M("`@("`@("`@("`@*B!T97AT('!A<G1S(&AE<F4N("!"=70@9F]R(&YO=RP@
M:G5S="!O=71P=70@=&AI<R!M97-S86=E+B`J+PH@("`@("`@("\O("`@(')E
M='5R;B`G6R<@+B!?*")/<FEG:6YA;"!M97-S86=E('=A<R!E;F-R>7!T960B
M*2`N("==)SL*("`@("`@("`O+WT*"B`@("`@("`@:68@*"1M:6UE7W!A<G0M
M/F=E=%-U8E1Y<&4H*2`]/2`G:'1M;"<I('L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH@("`@("`@("`@("!R
M971U<FX@5&5X=%]&:6QT97(Z.F9I;'1E<B@D8F]D>2P@)VAT;6PR=&5X="<L
M(&%R<F%Y*"=W<F%P)R`]/B`H)&UI;65?<&%R="T^9V5T0V]N=&5N=%1Y<&50
M87)A;65T97(H)V9O<FUA="<I("$]("=F;&]W960G*2P@)V-H87)S970G(#T^
M("1M:6UE7W!A<G0M/F=E=$-H87)S970H*2DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D8F]D>3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!)1"!O9B!T:&4@34E-12!P87)T
M(&-O;G1A:6YI;F<@=&AE(")B;V1Y(BX*("`@("`J"B`@("`@*B!`<&%R86T@
M24U07T-O;G1E;G1S("8D:6UP7V-O;G1E;G1S("!!;B!)35!?0V]N=&5N=',@
M;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@240@
M;V8@=&AE(&UI;64@<&%R="=S(&)O9'DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$)O9'E)9"@F)&EM<%]C;VYT96YT<RD*("`@('L*("`@("`@("!I9B`H
M:7-?;G5L;"@D=&AI<RT^7VUI;65I9"DI('L*("`@("`@("`@("`@)'1H:7,M
M/F9I;F1";V1Y*"1I;7!?8V]N=&5N=',I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'1H:7,M/E]M:6UE:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M971E<FUI;F4@=&AE(')E<&QY('1E>'0@9F]R(&$@;65S<V%G92X*("`@("`J
M"B`@("`@*B!`<&%R86T@24U07T-O;G1E;G1S("8D:6UP7V-O;G1E;G1S("!!
M;B!)35!?0V]N=&5N=',@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@("`@)&9R;VT@("`@("`@("`@5&AE(&5M86EL(&%D9')E<W,@;V8@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O
M<FEG:6YA;"!S96YD97(N"B`@("`@*B!`<&%R86T@24U07TAE861E<G,@("8D
M:"`@("`@("`@("`@("!4:&4@24U07TAE861E<G,@;V)J96-T(&9O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&UE
M<W-A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT
M(&]F('1H92!B;V1Y('!A<G0@;V8@=&AE(&UE<W-A9V4@=&\@=7-E"B`@("`@
M*B`@("`@("`@("`@("`@("`@9F]R('1H92!R97!L>2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5P;'E-97-S86=E*"8D:6UP7V-O;G1E;G1S+"`D9G)O;2P@
M)B1H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@(&EF
M("@A)'!R969S+3YG971686QU92@G<F5P;'E?<75O=&4G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D;6EM95]M97-S
M86=E(#T@)&EM<%]C;VYT96YT<RT^9V5T34E-14UE<W-A9V4H*3L*("`@("`@
M("`D;7-G(#T@)'1H:7,M/F9I;F1";V1Y*"1I;7!?8V]N=&5N=',I.PH@("`@
M("`@("1M<V<@/2`D;6EM95]M97-S86=E+3YR97!L86-E14],*"1M<V<L(")<
M;B(I.PH*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]M:6UE:60I*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G5&5X="]&;&]W960N<&AP)SL*
M("`@("`@("`@("`@)&]L9%]P87)T(#T@)&UI;65?;65S<V%G92T^9V5T4&%R
M="@D=&AI<RT^7VUI;65I9"D["B`@("`@("`@("`@(&EF("@D;VQD7W!A<G0M
M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=F;W)M870G*2`]/2`G9FQO=V5D
M)RD@>PH@("`@("`@("`@("`@("`@+RH@5V4@;F5E9"!T;R!C;VYV97)T('1H
M92!F;&]W960@=&5X="!T;R!F:7AE9"!T97AT(&)E9F]R90H@("`@("`@("`@
M("`@("`@("H@=V4@8F5G:6X@=V]R:VEN9R!O;B!I="X@*B\*("`@("`@("`@
M("`@("`@("1F;&]W960@/2`F;F5W(%1E>'1?1FQO=V5D*"1M<V<I.PH@("`@
M("`@("`@("`@("`@:68@*"@D;6EM95]M97-S86=E+3YG971#;VYT96YT5'EP
M95!A<F%M971E<B@G9&5L<W`G*2`]/2`G>65S)RD@)B8*("`@("`@("`@("`@
M("`@("`@("!M971H;V1?97AI<W1S*"1F;&]W960L("=S971$96Q3<"<I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&9L;W=E9"T^<V5T1&5L4W`H=')U92D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;7-G(#T@)&9L
M;W=E9"T^=&]&:7AE9"AF86QS92D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`O*B!)9B!T:&4@:6YP=70@:7,@*FYO="H@:6X@9FQO
M=V5D(&9O<FUA="P@;6%K92!S=7)E('1H97)E(&ES"B`@("`@("`@("`@("`@
M("`@*B!N;R!P861D:6YG(&%T('1H92!E;F0@;V8@;&EN97,N("HO"B`@("`@
M("`@("`@("`@("`D;7-G(#T@<')E9U]R97!L86-E*"(O7',J7&XO52(L(")<
M;B(L("1M<V<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;7-G(#T@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;7-G+"`D;VQD7W!A<G0M/F=E=$-H
M87)S970H*2D["@H@("`@("`@("`@("`D9FQO=V5D(#T@)FYE=R!497AT7T9L
M;W=E9"@D;7-G*3L*("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&9L
M;W=E9"P@)W-E=$1E;%-P)RDI('L*("`@("`@("`@("`@("`@("1F;&]W960M
M/G-E=$1E;%-P*'1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1M
M<V<@/2`D9FQO=V5D+3YT;T9L;W=E9"AT<G5E*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AE;7!T>2@D;7-G*2D@>PH@("`@("`@("`@("`D;7-G(#T@)ULG
M("X@7R@B3F\@;65S<V%G92!B;V1Y('1E>'0B*2`N("==)SL*("`@("`@("!]
M(&5L<V5I9B`H)'!R969S+3YG971686QU92@G<F5P;'E?:&5A9&5R<R<I("8F
M("%E;7!T>2@D:"DI('L*("`@("`@("`@("`@)&US9VAE860@/2`G+2TM+2T@
M)SL*("`@("`@("`@("`@:68@*"@D9G)O;2`]("1H+3YG971&<F]M061D<F5S
M<R@I*2D@>PH@("`@("`@("`@("`@("`@)&US9VAE860@+CT@<W!R:6YT9BA?
M*")-97-S86=E(&9R;VT@)7,B*2P@)&9R;VTI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&US9VAE860@+CT@7R@B365S<V%G92(I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!%>'1R82`G+2=S(&QI
M;F4@=7`@=VET:"`B16YD($UE<W-A9V4B(&)E;&]W+B`J+PH@("`@("`@("`@
M("`D;7-G:&5A9"`N/2`B("TM+2TM+2TM+5QN(CL*("`@("`@("`@("`@)&US
M9VAE860@+CT@)'1H:7,M/E]G971-<V=(96%D97)S*"1H*3L*("`@("`@("`@
M("`@)&US9R`]("1M<V=H96%D("X@(EQN7&XB("X@)&US9SL*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D9G)O;2DI('L*("`@("`@("`@("`@("`@("1M<V<@
M+CT@(EQN7&XB("X@)RTM+2TM("<@+B!S<')I;G1F*%\H(D5N9"!M97-S86=E
M(&9R;VT@)7,B*2P@)&9R;VTI("X@(B`M+2TM+5QN(CL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1M<V<@+CT@(EQN7&XB("X@)RTM
M+2TM("<@+B!?*")%;F0@;65S<V%G92(I("X@(B`M+2TM+5QN(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M<V<@/2`D
M=&AI<RT^7V5X<&%N9$%T=')I8G5T:6]N*"1P<F5F<RT^9V5T5F%L=64H)V%T
M=')I8E]T97AT)RDL("1F<F]M+"`D:"D@+B`B7&Y<;B(@+B`D;7-G.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1M<V<@+B`B7&XB.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5T97)M:6YE('1H92!T97AT(&9O<B!A(&9O<G=A<F1E
M9"!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2!)35!?0V]N=&5N=',@
M)B1I;7!?8V]N=&5N=',@($%N($E-4%]#;VYT96YT<R!O8FIE8W0N"B`@("`@
M*B!`<&%R86T@24U07TAE861E<G,@)B1H("`@("`@("`@("`@("!4:&4@24U0
M7TAE861E<G,@;V)J96-T(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!T97AT(&]F('1H92!B;V1Y('!A<G0@;V8@
M=&AE(&UE<W-A9V4@=&\@=7-E"B`@("`@*B`@("`@("`@("`@("`@("`@9F]R
M('1H92!F;W)W87)D+@H@("`@("HO"B`@("!F=6YC=&EO;B!F;W)W87)D365S
M<V%G92@F)&EM<%]C;VYT96YT<RP@)B1H*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH*("`@("`@("`D;7-G(#T@(EQN
M7&Y<;BTM+2TM("(["@H@("`@("`@(&EF("@H)&9R;VT@/2`D:"T^9V5T1G)O
M;4%D9')E<W,H*2DI('L*("`@("`@("`@("`@)&US9R`N/2!S<')I;G1F*%\H
M(D9O<G=A<F1E9"!M97-S86=E(&9R;VT@)7,B*2P@)&9R;VTI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1M<V<@+CT@7R@B1F]R=V%R9&5D(&UE
M<W-A9V4B*3L*("`@("`@("!]"@H@("`@("`@("1M<V<@+CT@(B`M+2TM+5QN
M(CL*("`@("`@("`D;7-G("X]("1T:&ES+3Y?9V5T37-G2&5A9&5R<R@D:"D[
M"B`@("`@("`@)&US9R`N/2`B7&XB.PH*("`@("`@("`D9G=D7VUS9R`]("1T
M:&ES+3YF:6YD0F]D>2@D:6UP7V-O;G1E;G1S*3L*("`@("`@("!I9B`H(6ES
M7VYU;&PH)'1H:7,M/E]M:6UE:60I*2!["B`@("`@("`@("`@("1M:6UE7VUE
M<W-A9V4@/2`D:6UP7V-O;G1E;G1S+3YG971-24U%365S<V%G92@I.PH@("`@
M("`@("`@("`D;VQD7W!A<G0@/2`D;6EM95]M97-S86=E+3YG971087)T*"1T
M:&ES+3Y?;6EM96ED*3L*("`@("`@("`@("`@)&9W9%]M<V<@/2!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1F=V1?;7-G+"`D;VQD7W!A<G0M/F=E=$-H87)S
M970H*2D["B`@("`@("`@?0H*("`@("`@("`D;7-G("X]("1F=V1?;7-G.PH@
M("`@("`@("1M<V<@+CT@(EQN7&XM+2TM+2`B("X@7R@B16YD(&9O<G=A<F1E
M9"!M97-S86=E(BD@+B`B("TM+2TM7&XB.PH*("`@("`@("!R971U<FX@)&US
M9SL*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!T:&4@:&5A9&5R
M(&EN9F]R;6%T:6]N('1O(&1I<W!L87D@:6X@=&AE(&9O<G=A<F0O<F5P;'DN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M($E-4%](96%D97)S("8D:"`@5&AE($E-4%](96%D97)S(&]B:F5C
M="!F;W(@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!H96%D97(@:6YF;W)M871I;VX@9F]R('1H92!O<FEG:6YA;"!M
M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T37-G2&5A9&5R<R@F
M)&@I"B`@("!["B`@("`@("`@)'1E>'0@/2`G)SL*"B`@("`@("`@:68@*"@D
M9&%T95]O8B`]("1H+3YG971/8B@G9&%T92<L('1R=64I*2D@>PH@("`@("`@
M("`@("`D=&5X="`N/2!?*"(@("`@1&%T93H@(BD@+B`D9&%T95]O8B`N(")<
M;B(["B`@("`@("`@?0H@("`@("`@(&EF("@H)&9R;VU?;V(@/2!-24U%.CIA
M9&1R07)R87DR4W1R:6YG*"1H+3YG971/8B@G9G)O;2<I*2DI('L*("`@("`@
M("`@("`@)'1E>'0@+CT@7R@B("`@($9R;VTZ("(I("X@)&9R;VU?;V(@+B`B
M7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H*"1R97!?;V(@/2!-24U%.CIA
M9&1R07)R87DR4W1R:6YG*"1H+3YG971/8B@G<F5P;'E?=&\G*2DI*2!["B`@
M("`@("`@("`@("1T97AT("X](%\H(E)E<&QY+51O.B`B*2`N("1R97!?;V(@
M+B`B7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H*"1S=6)?;V(@/2`D:"T^
M9V5T3V(H)W-U8FIE8W0G+"!T<G5E*2DI('L*("`@("`@("`@("`@)'1E>'0@
M+CT@7R@B(%-U8FIE8W0Z("(I("X@)'-U8E]O8B`N(")<;B(["B`@("`@("`@
M?0H@("`@("`@(&EF("@H)'1O7V]B(#T@34E-13HZ861D<D%R<F%Y,E-T<FEN
M9R@D:"T^9V5T3V(H)W1O)RDI*2D@>PH@("`@("`@("`@("`D=&5X="`N/2!?
M*"(@("`@("!4;SH@(BD@+B`D=&]?;V(@+B`B7&XB.PH@("`@("`@('T*("`@
M("`@("!I9B`H*"1C8U]O8B`]($U)344Z.F%D9')!<G)A>3)3=')I;F<H)&@M
M/F=E=$]B*"=C8R<I*2DI('L*("`@("`@("`@("`@)'1E>'0@+CT@7R@B("`@
M("`@0V,Z("(I("X@)&-C7V]B("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@86X@
M871T86-H;65N="!T;R!A($U)345?4&%R="!F<F]M(&%N('5P;&]A9&5D(&9I
M;&4N"B`@("`@*B!4:&4@86-T=6%L(&%T=&%C:&UE;G0@9&%T82!I<R!S=&]R
M960@:6X@82!S97!A<F%T92!F:6QE("T@=&AE"B`@("`@*B!-24U%7U!A<G0@
M:6YF;W)M871I;VX@96YT<FEE<R`G=&5M<%]F:6QE;F%M92<@86YD("=T96UP
M7V9I;&5T>7!E)PH@("`@("H@87)E('-E="!W:71H('1H:7,@:6YF;W)M871I
M;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@
M(%1H92!I;G!U="!F:65L9"!N86UE(&9R;VT@=&AE(&9O<FTN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D:7-P;W-I=&EO;B`@5&AE(&1I<W!O<VET:6]N('1O
M('5S92!F;W(@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@4F5T=7)N<R!T:&4@9FEL96YA;64@;VX@<W5C8V5S<RX*("`@("`J("`@
M("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D57!L;V%D071T86-H;65N="@D;F%M92P@
M)&1I<W!O<VET:6]N*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@
M("`@("`@)')E<R`]($)R;W=S97(Z.G=A<T9I;&55<&QO861E9"@D;F%M92P@
M7R@B871T86-H;65N="(I*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M('T*"B`@("`@("`@)&9I;&5N86UE(#T@)%]&24Q%4ULD;F%M95U;)VYA;64G
M73L*("`@("`@("`D=&5M<&9I;&4@/2`D7T9)3$536R1N86UE75LG=&UP7VYA
M;64G73L*"B`@("`@("`@+RH@0VAE8VL@9F]R(&9I;&5S:7IE(&QI;6ET871I
M;VYS+B`J+PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;)V-O;7!O<V4G75LG
M871T86-H7W-I>F5?;&EM:70G72D@)B8*("`@("`@("`@("`@*"@D8V]N9ELG
M8V]M<&]S92==6R=A='1A8VA?<VEZ95]L:6UI="==("T@)'1H:7,M/G-I>F5/
M9D%T=&%C:&UE;G1S*"D@+2`D7T9)3$536R1N86UE75LG<VEZ92==*2`\(#`I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B071T86-H960@9FEL92!<(B5S7"(@97AC965D<R!T:&4@871T86-H
M;65N="!S:7IE(&QI;6ET<RX@1FEL92!.3U0@871T86-H960N(BDL("1F:6QE
M;F%M92DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M4W1O<F4@=&AE(&1A=&$@:6X@82!-24U%7U!A<G0N(%-O;64@8G)O=W-E<G,@
M9&\@;F]T('-E;F0@=&AE($U)344*("`@("`@("`@("!T>7!E('-O('1R>2!A
M;B!E9'5C871E9"!G=65S<RX@*B\*("`@("`@("!I9B`H(65M<'1Y*"1?1DE,
M15-;)&YA;65=6R=T>7!E)UTI("8F"B`@("`@("`@("`@("@D7T9)3$536R1N
M86UE75LG='EP92==("$]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2D@
M>PH@("`@("`@("`@("`D<&%R="`]("9N97<@34E-15]087)T*"1?1DE,15-;
M)&YA;65=6R=T>7!E)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]-86=I8RYP:'`G.PH@("`@("`@
M("`@("`O*B!4<GD@=&\@9&5T97)M:6YE('1H92!-24U%('1Y<&4@9G)O;2`Q
M*2!A;F%L>7-I<R!O9B!T:&4@9FEL90H@("`@("`@("`@("`@*B`H:68@879A
M:6QA8FQE*2!A;F0L(&EF('1H870@9F%I;',L(#(I(&9R;VT@=&AE(&5X=&5N
M<VEO;BX@5V4*("`@("`@("`@("`@("H@9&\@:70@:6X@=&AI<R!O<F1E<B!H
M97)E(&)E8V%U<V4L(&UO<W0@;&EK96QY+"!I9B!A(&)R;W=S97(*("`@("`@
M("`@("`@("H@8V%N)W0@:61E;G1I9GD@=&AE('1Y<&4@;V8@82!F:6QE+"!I
M="!I<R!B96-A=7-E('1H92!F:6QE"B`@("`@("`@("`@("`J(&5X=&5N<VEO
M;G,@:7-N)W0@879A:6QA8FQE(&%N9"]O<B!R96-O9VYI>F5D+B`J+PH@("`@
M("`@("`@("!I9B`H(2@D='EP92`]($U)345?36%G:6,Z.F%N86QY>F5&:6QE
M*"1T96UP9FEL92P@(65M<'1Y*"1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UTI
M(#\@)&-O;F9;)VUI;64G75LG;6%G:6-?9&(G72`Z(&YU;&PI*2D@>PH@("`@
M("`@("`@("`@("`@)'1Y<&4@/2!-24U%7TUA9VEC.CIF:6QE;F%M951O34E-
M12@D9FEL96YA;64L(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<&%R="`]("9N97<@34E-15]087)T*"1T>7!E*3L*("`@("`@("!]"B`@
M("`@("`@)'!A<G0M/G-E=$-H87)S970H3DQ3.CIG971#:&%R<V5T*"DI.PH@
M("`@("`@("1P87)T+3YS971.86UE*"1F:6QE;F%M92D["B`@("`@("`@)'!A
M<G0M/G-E=$)Y=&5S*"1?1DE,15-;)&YA;65=6R=S:7IE)UTI.PH@("`@("`@
M(&EF("@D9&ES<&]S:71I;VXI('L*("`@("`@("`@("`@)'!A<G0M/G-E=$1I
M<W!O<VET:6]N*"1D:7-P;W-I=&EO;BD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&-O;F9;)V-O;7!O<V4G75LG=7-E7W9F<R==*2!["B`@("`@("`@("`@
M("1A='1A8VAM96YT(#T@)'1E;7!F:6QE.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1A='1A8VAM96YT(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=I
M;7!A='0G+"!F86QS92D["B`@("`@("`@("`@(&UO=F5?=7!L;V%D961?9FEL
M92@D=&5M<&9I;&4L("1A='1A8VAM96YT*3L*("`@("`@("!]"@H@("`@("`@
M("\J(%-T;W)E('1H92!D871A+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7W-T;W)E071T86-H;65N="@D<&%R="P@)&%T=&%C:&UE;G0I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&9I;&5N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A;B!A
M='1A8VAM96YT('1O(&$@34E-15]087)T(&9R;VT@9&%T82!E>&ES=&EN9R!I
M;B!T:&4@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D
M<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@=&AA="!C;VYT86EN<R!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!A='1A8VAM96YT(&1A
M=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!014%27T5R<F]R("!2971U<FYS
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$U)345087)T071T86-H;65N="@F)'!A<G0I"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D='EP92`]("1P87)T+3YG
M9714>7!E*"D["B`@("`@("`@)'9F<R`]("1C;VYF6R=C;VUP;W-E)UU;)W5S
M95]V9G,G73L*"B`@("`@("`@+RH@1&5C;V1E('1H92!C;VYT96YT<RX@*B\*
M("`@("`@("`D<&%R="T^=')A;G-F97)$96-O9&5#;VYT96YT<R@I.PH*("`@
M("`@("`O*B!4<GD@=&\@9&5T97)M:6YE('1H92!-24U%('1Y<&4@9G)O;2`Q
M*2!T:&4@97AT96YS:6]N(&%N9`H@("`@("`@("`J('1H96X@,BD@86YA;'ES
M:7,@;V8@=&AE(&9I;&4@*&EF(&%V86EL86)L92DN("HO"B`@("`@("`@:68@
M*"1T>7!E(#T]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]-86=I8RYP:'`G.PH@
M("`@("`@("`@("`D='EP92`]($U)345?36%G:6,Z.F9I;&5N86UE5&]-24U%
M*"1P87)T+3YG971.86UE*'1R=64I+"!F86QS92D["B`@("`@("`@?0H*("`@
M("`@("`O*B!%>'1R86-T('1H92!D871A(&9R;VT@=&AE(&-U<G)E;G1L>2!E
M>&ES=&EN9R!-24U%7U!A<G0@86YD('1H96X*("`@("`@("`@("!D96QE=&4@
M:70N($EF('1H:7,@:7,@86X@=6YK;F]W;B!-24U%('!A<G0L('=E(&UU<W0@
M<V%V92!T;R!A"B`@("`@("`@("`@=&5M<&]R87)Y(&9I;&4@=&\@<G5N('1H
M92!F:6QE(&%N86QY<VES(&]N(&ET+B`J+PH@("`@("`@(&EF("@A)'9F<RD@
M>PH@("`@("`@("`@("`D871T86-H;65N="`]($AO<F1E.CIG971496UP1FEL
M92@G:6UP871T)RP@)'9F<RD["B`@("`@("`@("`@("1F<"`](&9O<&5N*"1A
M='1A8VAM96YT+"`G=R<I.PH@("`@("`@("`@("!F=W)I=&4H)&9P+"`D<&%R
M="T^9V5T0V]N=&5N=',H*2D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH*
M("`@("`@("`@("`@:68@*"@D='EP92`]/2`G87!P;&EC871I;VXO;V-T970M
M<W1R96%M)RD@)B8*("`@("`@("`@("`@("`@("@D86YA;'EZ971Y<&4@/2!-
M24U%7TUA9VEC.CIA;F%L>7IE1FEL92@D871T86-H;65N="P@(65M<'1Y*"1C
M;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UTI(#\@)&-O;F9;)VUI;64G75LG;6%G
M:6-?9&(G72`Z(&YU;&PI*2D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D
M86YA;'EZ971Y<&4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H
M*"1T>7!E(#T]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2`F)@H@("`@
M("`@("`@("`@("`@("`H)&%N86QY>F5T>7!E(#T@34E-15]-86=I8SHZ86YA
M;'EZ941A=&$H)'!A<G0M/F=E=$-O;G1E;G1S*"DL("%E;7!T>2@D8V]N9ELG
M;6EM92==6R=M86=I8U]D8B==*2`_("1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B
M)UT@.B!N=6QL*2DI('L*("`@("`@("`@("`@)'1Y<&4@/2`D86YA;'EZ971Y
M<&4["B`@("`@("`@?0H*("`@("`@("`D<&%R="T^<V5T5'EP92@D='EP92D[
M"@H@("`@("`@("\J(%-E="!T:&4@<VEZ92!O9B!T:&4@4&%R="!E>'!L:6-I
M=&QY('-I;F-E('=E(&1E;&5T92!T:&4@8V]N=&5N=',*("`@("`@("`@("!L
M871E<B!O;B!I;B!T:&ES(&9U;F-T:6]N+B`J+PH@("`@("`@("1P87)T+3YS
M971">71E<R@D<&%R="T^9V5T0GET97,H*2D["@H@("`@("`@("\J($-H96-K
M(&9O<B!F:6QE<VEZ92!L:6UI=&%T:6]N<RX@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1C;VYF6R=C;VUP;W-E)UU;)V%T=&%C:%]S:7IE7VQI;6ET)UTI("8F
M"B`@("`@("`@("`@("@H)&-O;F9;)V-O;7!O<V4G75LG871T86-H7W-I>F5?
M;&EM:70G72`M("1T:&ES+3YS:7IE3V9!='1A8VAM96YT<R@I("T@)'!A<G0M
M/F=E=$)Y=&5S*"DI(#P@,"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")!='1A8VAE9"!F:6QE(%PB)7-<(B!E
M>&-E961S('1H92!A='1A8VAM96YT('-I>F4@;&EM:71S+B!&:6QE($Y/5"!A
M='1A8VAE9"XB*2P@)'!A<G0M/F=E=$YA;64H*2DL("=H;W)D92YE<G)O<B<I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O<F4@=&AE(&1A=&$N("HO"B`@
M("`@("`@:68@*"1V9G,I('L*("`@("`@("`@("`@)'9F<U]D871A(#T@)'!A
M<G0M/F=E=$-O;G1E;G1S*"D["B`@("`@("`@("`@("1P87)T+3YC;&5A<D-O
M;G1E;G1S*"D["B`@("`@("`@("`@("1T:&ES+3Y?<W1O<F5!='1A8VAM96YT
M*"1P87)T+"`D=F9S7V1A=&$L(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<&%R="T^8VQE87)#;VYT96YT<R@I.PH@("`@("`@("`@
M("`D=&AI<RT^7W-T;W)E071T86-H;65N="@D<&%R="P@)&%T=&%C:&UE;G0I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!T:&4@
M871T86-H;65N="!D871A(&EN(&ET<R!C;W)R96-T(&QO8V%T:6]N+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!-24U%7U!A<G0@)B1P87)T("`@5&AE($U)345?4&%R="!O9B!T:&4@871T
M86-H;65N="X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@16ET
M:&5R('1H92!F:6QE;F%M92!O9B!T:&4@871T86-H;65N="!O<BP@:68*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9F<U]F:6QE(&ES(&9A
M;'-E+"!T:&4@871T86-H;65N="!D871A+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'9F<U]F:6QE("!)9B!U<VEN9R!61E,L(&ES("1D871A(&$@9FEL96YA
M;64_"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S=&]R94%T=&%C:&UE;G0H)B1P
M87)T+"`D9&%T82P@)'9F<U]F:6QE(#T@=')U92D*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8["@H@("`@("`@("\J(%-T;W)E(&EN(%9&4RX@*B\*("`@
M("`@("!I9B`H)&-O;F9;)V-O;7!O<V4G75LG=7-E7W9F<R==*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G5D93+G!H<"<["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G5D93+T=#+G!H<"<["B`@("`@("`@("`@("1V9G,@/2`F
M5D93.CIS:6YG;&5T;VXH)&-O;F9;)W9F<R==6R=T>7!E)UTL($AO<F1E.CIG
M971$<FEV97)#;VYF:6<H)W9F<R<L("1C;VYF6R=V9G,G75LG='EP92==*2D[
M"B`@("`@("`@("`@(%9&4U]'0SHZ9V,H)'9F<RP@24U07U9&4U]!5%1!0TA?
M4$%42"P@.#8T,#`I.PH@("`@("`@("`@("`D8V%C:&5)1"`](&UD-2AM=%]R
M86YD*"D@+B!M:6-R;W1I;64H*2D["B`@("`@("`@("`@(&EF("@D=F9S7V9I
M;&4I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=F9S+3YW<FET92A)
M35!?5D937T%45$%#2%]0051(+"`D8V%C:&5)1"P@)&1A=&$L('1R=64I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1V9G,M/G=R:71E1&%T82A)35!?5D937T%45$%#2%]0051(+"`D8V%C:&5)
M1"P@)&1A=&$L('1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1P87)T+3YS971);F9O<FUA=&EO;B@G=&5M<%]F:6QE;F%M92<L("1C86-H
M94E$*3L*("`@("`@("`@("`@)'!A<G0M/G-E=$EN9F]R;6%T:6]N*"=T96UP
M7V9I;&5T>7!E)RP@)W9F<R<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&-H;6]D*"1D871A+"`P-C`P*3L*("`@("`@("`@("`@)'!A<G0M/G-E
M=$EN9F]R;6%T:6]N*"=T96UP7V9I;&5N86UE)RP@)&1A=&$I.PH@("`@("`@
M("`@("`D<&%R="T^<V5T26YF;W)M871I;VXH)W1E;7!?9FEL971Y<&4G+"`G
M9FEL92<I.PH@("`@("`@('T*"B`@("`@("`@+RH@061D('1H92!S:7IE(&EN
M9F]R;6%T:6]N('1O('1H92!C;W5N=&5R+B`J+PH@("`@("`@("1T:&ES+3Y?
M<VEZ92`K/2`D<&%R="T^9V5T0GET97,H*3L*"B`@("`@("`@)'1H:7,M/E]C
M86-H95M=(#T@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@
M871T86-H960@9FEL97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1N
M=6UB97(@($5I=&AE<B!A('-I;F=L92!I;G1E9V5R(&]R(&%N(&%R<F%Y(&]F
M(&EN=&5G97)S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]R<F5S
M<&]N9&EN9R!T;R!T:&4@871T86-H;65N="!P;W-I=&EO;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!D96QE=&5D(&9I;&5N
M86UE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E071T86-H;65N="@D
M;G5M8F5R*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@
M)&YA;65S(#T@87)R87DH*3L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;G5M
M8F5R*2D@>PH@("`@("`@("`@("`D;G5M8F5R(#T@87)R87DH)&YU;6)E<BD[
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D;G5M8F5R(&%S("1V86PI
M('L*("`@("`@("`@("`@)'9A;"TM.PH@("`@("`@("`@("`D<&%R="`]("8D
M=&AI<RT^7V-A8VAE6R1V86Q=.PH@("`@("`@("`@("`D9FEL96YA;64@/2`D
M<&%R="T^9V5T26YF;W)M871I;VXH)W1E;7!?9FEL96YA;64G*3L*("`@("`@
M("`@("`@:68@*"1P87)T+3YG971);F9O<FUA=&EO;B@G=&5M<%]F:6QE='EP
M92<I(#T]("=V9G,G*2!["B`@("`@("`@("`@("`@("`O*B!$96QE=&4@9G)O
M;2!61E,N("HO"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U9&4RYP
M:'`G.PH@("`@("`@("`@("`@("`@)'9F<R`]("961E,Z.G-I;F=L971O;B@D
M8V]N9ELG=F9S)UU;)W1Y<&4G72P@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G
M=F9S)RP@)&-O;F9;)W9F<R==6R=T>7!E)UTI*3L*("`@("`@("`@("`@("`@
M("1V9G,M/F1E;&5T949I;&4H24U07U9&4U]!5%1!0TA?4$%42"P@)&9I;&5N
M86UE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J
M($1E;&5T92!F<F]M(&9I;&5S>7-T96TN("HO"B`@("`@("`@("`@("`@("!`
M=6YL:6YK*"1F:6QE;F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1P87)T+3YS971);F9O<FUA=&EO;B@G=&5M<%]F:6QE;F%M92<L("<G*3L*
M("`@("`@("`@("`@)'!A<G0M/G-E=$EN9F]R;6%T:6]N*"=T96UP7V9I;&5T
M>7!E)RP@)R<I.PH*("`@("`@("`@("`@)&YA;65S6UT@/2`D<&%R="T^9V5T
M3F%M92AF86QS92P@=')U92D["@H@("`@("`@("`@("`O*B!296UO=F4@=&AE
M('-I>F4@:6YF;W)M871I;VX@9G)O;2!T:&4@8V]U;G1E<BX@*B\*("`@("`@
M("`@("`@)'1H:7,M/E]S:7IE("T]("1P87)T+3YG971">71E<R@I.PH*("`@
M("`@("`@("`@=6YS970H)'1H:7,M/E]C86-H95LD=F%L72D["B`@("`@("`@
M?0H*("`@("`@("`O*B!296]R9&5R('1H92!A='1A8VAM96YT<RX@*B\*("`@
M("`@("`D=&AI<RT^7V-A8VAE(#T@87)R87E?=F%L=65S*"1T:&ES+3Y?8V%C
M:&4I.PH*("`@("`@("!R971U<FX@)&YA;65S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5L971E<R!A;&P@871T86-H;65N=',N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E;&5T94%L;$%T=&%C:&UE;G1S*"D*("`@('L*("`@("`@("`D
M;G5M8F5R<R`](&%R<F%Y*"D["@H@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\
M/2`D=&AI<RT^;G5M8F5R3V9!='1A8VAM96YT<R@I.R`D:2LK*2!["B`@("`@
M("`@("`@("1N=6UB97)S6UT@/2`D:3L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3YD96QE=&5!='1A8VAM96YT*"1N=6UB97)S*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%5P9&%T97,@:6YF;W)M871I;VX@:6X@82!S<&5C:69I8R!A
M='1A8VAM96YT+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1N=6UB
M97(@(%1H92!A='1A8VAM96YT('1O('5P9&%T92X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("`@($%N(&%R<F%Y(&]F('5P9&%T92!I;F9O<FUA=&EO
M;BX*("`@("`J(#QP<F4^"B`@("`@*B`G9&ES<&]S:71I;VXG("`M+2`@5&AE
M($-O;G1E;G0M1&ES<&]S:71I;VX@=F%L=64N"B`@("`@*B`G9&5S8W)I<'1I
M;VXG("`M+2`@5&AE($-O;G1E;G0M1&5S8W)I<'1I;VX@=F%L=64N"B`@("`@
M*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E071T86-H;65N
M="@D;G5M8F5R+"`D<&%R86US*0H@("`@>PH@("`@("`@("1N=6UB97(M+3L*
M("`@("`@("`D=&AI<RT^7V-A8VAE6R1N=6UB97)=+3YS971$:7-P;W-I=&EO
M;B@D<&%R86US6R=D:7-P;W-I=&EO;B==*3L*("`@("`@("`D=&AI<RT^7V-A
M8VAE6R1N=6UB97)=+3YS971$97-C<FEP=&EO;B@D<&%R86US6R=D97-C<FEP
M=&EO;B==*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&QI
M<W0@;V8@8W5R<F5N="!A='1A8VAM96YT<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!A='1A8VAM96YT<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T071T86-H;65N=',H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V-A8VAE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(&-U<G)E;G1L>2!I;B!T
M:&ES(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(&EN('1H:7,@;65S<V%G92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;G5M8F5R3V9!='1A8VAM96YT<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&-O=6YT*"1T:&ES+3Y?8V%C:&4I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ92!O9B!T:&4@871T86-H
M;65N=',@:6X@8GET97,N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R
M("!4:&4@<VEZ92!O9B!T:&4@871T86-H;65N=',@*&EN(&)Y=&5S*2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<VEZ94]F071T86-H;65N=',H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!"=6EL9"!A('-I;F=L92!A='1A8VAM96YT('!A<G0@=VET:"!I=',@
M9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@(%1H92!)
M1"!O9B!T:&4@<&%R="!T;R!R96)U:6QD+@H@("`@("H*("`@("`J($!R971U
M<FX@34E-15]087)T("!4:&4@34E-15]087)T('=I=&@@:71S(&-O;G1E;G1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9$%T=&%C:&UE;G0H)&ED*0H@
M("`@>PH@("`@("`@("1P87)T(#T@)'1H:7,M/E]C86-H95LH)&ED("T@,2E=
M.PH@("`@("`@("1T:&ES+3Y?8G5I;&1087)T1&%T82@D<&%R="D["B`@("`@
M("`@<F5T=7)N("1P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&0@
M=&AE($U)345?4&%R="!A='1A8VAM96YT<R!F<F]M('1H92!T96UP;W)A<GD@
M9FEL92!D871A+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1B
M87-E("!4:&4@8F%S92!-24U%7U!A<G0@;V)J96-T('1O(&%D9"!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!A='1A8VAM96YT<R!T;RX*
M("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@("!4:&4@8VAA<G-E="!T
M;R!U<V4@9F]R('1H92!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8G5I;&1!;&Q!='1A8VAM96YT<R@F)&)A<V4L("1C:&%R<V5T(#T@;G5L;"D*
M("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-A8VAE(&%S("1P87)T
M*2!["B`@("`@("`@("`@("\J(%-T;W)E('1H92!D871A(&EN<VED92!T:&4@
M8W5R<F5N="!P87)T+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V)U:6QD4&%R
M=$1A=&$H)'!A<G0I.PH*("`@("`@("`@("`@+RH@0V]N=F5R="!T:&4@8VAA
M<G-E="!O9B!T:&4@9FEL96YA;64L(&EF(&YE8V5S<V%R>2X@*B\*("`@("`@
M("`@("`@:68@*"%I<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@
M("`@)&YA;64@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1P87)T+3YG971.
M86UE*"DL("1P87)T+3YG971#:&%R<V5T*"DL("1C:&%R<V5T*3L*("`@("`@
M("`@("`@("`@("1P87)T+3YS971.86UE*$U)344Z.F1E8V]D92@D;F%M92P@
M)&-H87)S970I*3L*("`@("`@("`@("`@("`@("1P87)T+3YS971#:&%R<V5T
M*"1C:&%R<V5T*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@061D
M('1O('1H92!B87-E('!A<G0N("HO"B`@("`@("`@("`@("1B87-E+3YA9&10
M87)T*"1P87)T*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M86ME<R!T:&4@=&5M<&]R87)Y(&1A=&$@9F]R(&$@<VEN9VQE('!A<G0@86YD
M('!U=',@:70@:6YT;R!T:&4*("`@("`J(&-O;G1E;G1S(&]F('1H870@<&%R
M="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@34E-15]087)T("8D<&%R="`@5&AE('!A<G0@=&\@<F5B=6EL
M9"!D871A(&EN=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9%!A<G1$
M871A*"8D<&%R="D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@("1F:6QE;F%M92`]("1P87)T+3YG971);F9O<FUA=&EO;B@G=&5M<%]F
M:6QE;F%M92<I.PH@("`@("`@(&EF("@D<&%R="T^9V5T26YF;W)M871I;VXH
M)W1E;7!?9FEL971Y<&4G*2`]/2`G=F9S)RD@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U9&4RYP:'`G.PH@("`@("`@("`@("`D=F9S(#T@)E9&4SHZ
M<VEN9VQE=&]N*"1C;VYF6R=V9G,G75LG='EP92==+"!(;W)D93HZ9V5T1')I
M=F5R0V]N9FEG*"=V9G,G+"`D8V]N9ELG=F9S)UU;)W1Y<&4G72DI.PH@("`@
M("`@("`@("`D9&%T82`]("1V9G,M/G)E860H24U07U9&4U]!5%1!0TA?4$%4
M2"P@)&9I;&5N86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE;F%M92D["B`@("`@("`@
M?0H*("`@("`@("`O*B!3970@=&AE('!A<G0G<R!C;VYT96YT<R!T;R!T:&4@
M<F%W(&%T=&%C:&UE;G0@9&%T82X@*B\*("`@("`@("`D<&%R="T^<V5T0V]N
M=&5N=',H)&1A=&$I.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP86YD(&UA
M8W)O<R!I;B!A='1R:6)U=&EO;B!T97AT('=H96X@<F5P;'EI;F<@=&\@;65S
M<V%G97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;&EN92`@("`@5&AE(&QI;F4@;V8@871T
M<FEB=71I;VX@=&5X="X*("`@("`J($!P87)A;2!S=')I;F<@)&9R;VT@("`@
M(%1H92!E;6%I;"!A9&1R97-S(&]F('1H92!O<FEG:6YA;`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@<V5N9&5R+@H@("`@("H@0'!A<F%M($E-
M4%](96%D97)S("8D:"`@5&AE($E-4%](96%D97)S(&]B:F5C="!F;W(@=&AE
M(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!A
M='1R:6)U=&EO;B!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP86YD
M071T<FEB=71I;VXH)&QI;F4L("1F<F]M+"`F)&@I"B`@("!["B`@("`@("`@
M)&%D9')E<W-,:7-T(#T@)R<["B`@("`@("`@)&YA;65,:7-T(#T@)R<["@H@
M("`@("`@("\J($9I<G-T('=E)VQL(&=E="!A(&-O;6UA('-E<&5R871E9"!L
M:7-T(&]F(&5M86EL(&%D9')E<W-E<PH@("`@("`@("`@(&%N9"!A(&-O;6UA
M('-E<&5R871E9"!L:7-T(&]F('!E<G-O;F%L(&YA;65S(&]U="!O9B`D9G)O
M;0H@("`@("`@("`@("AT:&5R92!J=7-T(&UI9VAT(&)E(&UO<F4@=&AA;B!O
M;F4@;V8@96%C:"DN("HO"B`@("`@("`@9F]R96%C:"`H24U0.CIP87)S94%D
M9')E<W-,:7-T*"1F<F]M*2!A<R`D96YT<GDI('L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1E;G1R>2T^;6%I;&)O>"D@)B8@:7-S970H)&5N=')Y+3YH;W-T
M*2D@>PH@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D861D<F5S<TQI<W0I
M(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("1A9&1R97-S3&ES="`N/2`G
M+"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&%D9')E
M<W-,:7-T("X]("1E;G1R>2T^;6%I;&)O>"`N("=`)R`N("1E;G1R>2T^:&]S
M=#L*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1E;G1R>2T^;6%I;&)O
M>"DI('L*("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&%D9')E<W-,:7-T
M*2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D861D<F5S<TQI<W0@+CT@
M)RP@)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1A9&1R
M97-S3&ES="`N/2`D96YT<GDM/FUA:6QB;W@["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1E;G1R>2T^<&5R<V]N86PI*2!["B`@("`@
M("`@("`@("`@("!I9B`H<W1R;&5N*"1N86UE3&ES="D@/B`P*2!["B`@("`@
M("`@("`@("`@("`@("`@)&YA;65,:7-T("X]("<L("<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D;F%M94QI<W0@+CT@)&5N=')Y+3YP
M97)S;VYA;#L*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1E;G1R>2T^
M;6%I;&)O>"DI('L*("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&YA;65,
M:7-T*2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D;F%M94QI<W0@+CT@
M)RP@)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1N86UE
M3&ES="`N/2`D96YT<GDM/FUA:6QB;W@["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J($1E9FEN92!T:&4@;6%C<F]S+B`J+PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D;65S<V%G95]I9"`]("1H+3YG971/8B@G;65S<V%G
M95]I9"<I*2D@>PH@("`@("`@("`@("`D;65S<V%G95]I9"`](')E<V5T*"1M
M97-S86=E7VED*3L*("`@("`@("!]"B`@("`@("`@:68@*"$H)'-U8FIE8W0@
M/2`D:"T^9V5T3V(H)W-U8FIE8W0G+"!T<G5E*2DI('L*("`@("`@("`@("`@
M)'-U8FIE8W0@/2!?*");3F\@4W5B:F5C=%TB*3L*("`@("`@("!]"B`@("`@
M("`@)'5D871E(#T@<W1R=&]T:6UE*"1H+3YG971/8B@G9&%T92<L('1R=64I
M*3L*"B`@("`@("`@)&UA=&-H(#T@87)R87DH"B`@("`@("`@("`@("\J($YE
M=R!L:6YE+B`J+PH@("`@("`@("`@("`G+R5N+R<@/3X@(EQN(BP*"B`@("`@
M("`@("`@("\J(%1H92`G)2<@8VAA<F%C=&5R+B`J+PH@("`@("`@("`@("`G
M+R4E+R<@/3X@)R4G+`H*("`@("`@("`@("`@+RH@3F%M92!A;F0@96UA:6P@
M861D<F5S<R!O9B!O<FEG:6YA;"!S96YD97(N("HO"B`@("`@("`@("`@("<O
M)68O)R`]/B`D9G)O;2P*"B`@("`@("`@("`@("\J(%-E;F1E<G,@96UA:6P@
M861D<F5S<RAE<RDN("HO"B`@("`@("`@("`@("<O)6$O)R`]/B`D861D<F5S
M<TQI<W0L"@H@("`@("`@("`@("`O*B!396YD97)S(&YA;64H<RDN("HO"B`@
M("`@("`@("`@("<O)7`O)R`]/B`D;F%M94QI<W0L"@H@("`@("`@("`@("`O
M*B!21D,@.#(R(&1A=&4@86YD('1I;64N("HO"B`@("`@("`@("`@("<O)7(O
M)R`]/B`D:"T^9V5T3V(H)V1A=&4G+"!T<G5E*2P*"B`@("`@("`@("`@("\J
M($1A=&4@87,@9&1D+"!D9"!M;6T@>7EY>2X@*B\*("`@("`@("`@("`@)R\E
M9"\G(#T^(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H0'-T<F9T:6UE*"(E82P@
M)60@)6(@)5DB+"`D=61A=&4I+"!.3%,Z.F=E=$5X=&5R;F%L0VAA<G-E="@I
M*2P*"B`@("`@("`@("`@("\J($1A=&4@:6X@;&]C86QE)W,@9&5F875L="X@
M*B\*("`@("`@("`@("`@)R\E>"\G(#T^(%-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H0'-T<F9T:6UE*"(E>"(L("1U9&%T92DL($Y,4SHZ9V5T17AT97)N86Q#
M:&%R<V5T*"DI+`H*("`@("`@("`@("`@+RH@1&%T92!A;F0@=&EM92!I;B!L
M;V-A;&4G<R!D969A=6QT+B`J+PH@("`@("`@("`@("`G+R5C+R<@/3X@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="A`<W1R9G1I;64H(B5C(BP@)'5D871E*2P@
M3DQ3.CIG971%>'1E<FYA;$-H87)S970H*2DL"@H@("`@("`@("`@("`O*B!-
M97-S86=E+4E$+B`J+PH@("`@("`@("`@("`G+R5M+R<@/3X@)&UE<W-A9V5?
M:60L"@H@("`@("`@("`@("`O*B!-97-S86=E('-U8FIE8W0N("HO"B`@("`@
M("`@("`@("<O)7,O)R`]/B`D<W5B:F5C=`H@("`@("`@("D["@H@("`@("`@
M(')E='5R;B`H<')E9U]R97!L86-E*&%R<F%Y7VME>7,H)&UA=&-H*2P@87)R
M87E?=F%L=65S*"1M871C:"DL("1L:6YE*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!/8G1A:6YS('1H92!C86-H960@87)R87D@;V8@34E-15]087)T<R!T
M;R!B92!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V%C:&5)1"`@5&AE(&-A8VAE240@;V8@=&AE('-E<W-I;VX@;V)J96-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<F5T<FEE=F5-:6UE0V%C:&4H)&-A8VAE
M240I"B`@("!["B`@("`@("`@:68@*"1C86-H94E$*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;D]B:F5C=',N<&AP)SL*("`@
M("`@("`@("`@)&-A8VAE4V5S<R`]("9(;W)D95]397-S:6]N3V)J96-T<SHZ
M<VEN9VQE=&]N*"D["B`@("`@("`@("`@("1R97-U;'0@/2`D8V%C:&5397-S
M+3YQ=65R>2@D8V%C:&5)1"D["B`@("`@("`@("`@("1C86-H95-E<W,M/G-E
M=%!R=6YE1FQA9R@D8V%C:&5)1"P@=')U92D["B`@("`@("`@("`@("1T:&ES
M+3Y?8V%C:&4@/2`F)')E<W5L=%LG8V%C:&4G73L*("`@("`@("`@("`@)'1H
M:7,M/E]S:7IE(#T@)B1R97-U;'1;)W-I>F4G73L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H92!C86-H92!)1"!F;W(@=&AE
M('-E<W-I;VX@;V)J96-T('1H870@8V]N=&%I;G,@=&AE"B`@("`@*B!-24U%
M7U!A<G0@;V)J96-T<R!T;R!B92!A='1A8VAE9"!T;R!T:&ES(&UE<W-A9V4N
M"B`@("`@*B!4:&ES(&9U;F-T:6]N(&YE961S('1O(&)E(')U;B!A="!L96%S
M="!O;F-E('!E<B!P86=E;&]A9"!T;R!S879E('1H90H@("`@("H@<V5S<VEO
M;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M
M97-S86=E(&-A8VAE($E$(&EF('1H92!O8FIE8W0@;F5E9',@=&\@8F4@<V%V
M960N"B`@("`@*B`@("`@("`@("`@("`@("`@16QS92P@9F%L<V4@:7,@<F5T
M=7)N960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V5#86-H94ED
M*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?8V%C:&4I*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;D]B:F5C
M=',N<&AP)SL*("`@("`@("`@("`@)&-A8VAE4V5S<R`]("9(;W)D95]397-S
M:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D["B`@("`@("`@("`@("1S=&]R92`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@)V-A8VAE)R`]/B`D=&AI<RT^7V-A
M8VAE+`H@("`@("`@("`@("`@("`@)W-I>F4G(#T^("1T:&ES+3Y?<VEZ90H@
M("`@("`@("`@("`I.PH@("`@("`@("`@("!R971U<FX@)&-A8VAE4V5S<RT^
M<W1O<F5/:60H)'-T;W)E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@2&]W(&UA;GD@;6]R92!A='1A8VAM96YT<R!A<F4@86QL;W=E9#\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2971U<FYS('1R=64@:68@;F\@
M871T86-H;65N="!L:6UI="X*("`@("`J("`@("`@("`@("`@("`@($5L<V4@
M<F5T=7)N<R!T:&4@;G5M8F5R(&]F(&%D9&ET:6]N86P@871T86-H;65N=',*
M("`@("`J("`@("`@("`@("`@("`@(&%L;&]W960N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9&ET:6]N86Q!='1A8VAM96YT<T%L;&]W960H*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N
M9ELG8V]M<&]S92==6R=A='1A8VA?8V]U;G1?;&EM:70G72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;VYF6R=C;VUP;W-E)UU;)V%T=&%C:%]C;W5N=%]L
M:6UI="==("T@)'1H:7,M/FYU;6)E<D]F071T86-H;65N=',H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7:&%T(&ES('1H92!M87AI;75M(&%T
M=&%C:&UE;G0@<VEZ92!A;&QO=V5D/PH@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5&AE(&UA>&EM=6T@871T86-H;65N="!S:7IE(&%L;&]W960@
M*&EN(&)Y=&5S*2X*("`@("`J+PH@("`@9G5N8W1I;VX@;6%X071T86-H;65N
M=%-I>F4H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9BP@)&EM<#L*"B`@
M("`@("`@)'-I>F4@/2`D:6UP6R=F:6QE7W5P;&]A9"==.PH*("`@("`@("!I
M9B`H(65M<'1Y*"1C;VYF6R=C;VUP;W-E)UU;)V%T=&%C:%]S:7IE7VQI;6ET
M)UTI*2!["B`@("`@("`@("`@("1S:7IE(#T@;6EN*"1S:7IE+"!M87@H)&-O
M;F9;)V-O;7!O<V4G75LG871T86-H7W-I>F5?;&EM:70G72`M("1T:&ES+3YS
M:7IE3V9!='1A8VAM96YT<R@I+"`P*2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'-I>F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S('1H92!A
M='1A8VAM96YT<R!T;R!T:&4@;65S<V%G92`H:6X@=&AE(&-A<V4@;V8@82!F
M;W)W87)D('=I=&@*("`@("`J(&%T=&%C:&UE;G1S*2X*("`@("`J(%1H:7,@
M9G5N8W1I;VX@35535"!B92!C86QL960@869T97(@24U07T-O;7!O<V4Z.F9O
M<G=A<F1-97-S86=E*"DN"B`@("`@*@H@("`@("H@0'!A<F%M($E-4%]#;VYT
M96YT<R`F)&-O;G1E;G1S("!!;B!)35!?0V]N=&5N=',@;V)J96-T+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(%!%05)?17)R
M;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("H@("`@("`@("`@("`@("`@06X@
M96UP='D@87)R87D@:68@<W5C8V5S<V9U;"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@871T86-H1FEL97-&<F]M365S<V%G92@F)&-O;G1E;G1S*0H@("`@>PH@
M("`@("`@("1E<G)O<G,@/2!A<G)A>2@I.PH*("`@("`@("`D9&Q?;&ES="`]
M("1C;VYT96YT<RT^9V5T1&]W;FQO861!;&Q,:7-T*'1R=64I.PH@("`@("`@
M("1M:6UE7VUE<W-A9V4@/2`D8V]N=&5N=',M/F=E=$U)345-97-S86=E*"D[
M"@H@("`@("`@(&9O<F5A8V@@*"1D;%]L:7-T(&%S("1V86PI('L*("`@("`@
M("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]M:6UE:60I('Q\("@D=F%L("$]
M("1T:&ES+3Y?;6EM96ED*2D@>PH@("`@("`@("`@("`@("`@)&UI;64@/2`D
M;6EM95]M97-S86=E+3YG971087)T*"1V86PI.PH@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D;6EM92DI('L*("`@("`@("`@("`@("`@("`@("`D<F5S
M(#T@)'1H:7,M/F%D9$U)345087)T071T86-H;65N="@D;6EM92D["B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D97)R;W)S6UT@/2`D<F5S.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E<G)O<G,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T(&$@=&5X="]H=&UL($U)345?
M4&%R="!M97-S86=E('=I=&@@96UB961D960@:6UA9V4@;&EN:W,@=&\*("`@
M("`J(&$@;75L=&EP87)T+W)E;&%T960@34E-15]087)T('=I=&@@=&AE(&EM
M86=E(&1A=&$@96UB961D960@:6X@=&AE('!A<G0N"B`@("`@*@H@("`@("H@
M0'!A<F%M($U)345?4&%R="`D;6EM95]P87)T("!4:&4@=&5X="]H=&UL($U)
M345?4&%R="!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A
M<G0@(%1H92!M;V1I9FEE9"!-24U%7U!A<G0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O;G9E<G14;TUU;'1I<&%R=%)E;&%T960H)&UI;65?<&%R="D*("`@
M('L*("`@("`@("`O*B!2971U<FX@:6UM961I871E;'D@:68@;F]T(&%N($A4
M34P@<&%R="X@*B\*("`@("`@("!I9B`H)&UI;65?<&%R="T^9V5T5'EP92@I
M("$]("=T97AT+VAT;6PG*2!["B`@("`@("`@("`@(')E='5R;B`D;6EM95]P
M87)T.PH@("`@("`@('T*"B`@("`@("`@+RH@4V-A;B!F;W(@)VEM9R<@=&%G
M<R`M('-P96-I9FEC86QL>2!T:&4@)W-R8R<@<&%R86UE=&5R+B!)9@H@("`@
M("`@("`J(&YO;F4L(')E='5R;B!T:&4@;W)I9VEN86P@34E-15]087)T+B`J
M+PH@("`@("`@(&EF("@A<')E9U]M871C:%]A;&PH)R\\:6UG6UX^72MS<F-<
M<RI</5QS*BA;7EQS72LI7',K+VE5)RP@)&UI;65?<&%R="T^9V5T0V]N=&5N
M=',H*2P@)')E<W5L=',I*2!["B`@("`@("`@("`@(')E='5R;B`D;6EM95]P
M87)T.PH@("`@("`@('T*"B`@("`@("`@+RH@1V\@=&AR;W5G:"!L:7-T(&]F
M(')E<W5L=',L(&1O=VYL;V%D('1H92!I;6%G92P@86YD(&-R96%T90H@("`@
M("`@("`J($U)345?4&%R="!O8FIE8W1S('=I=&@@=&AE(&1A=&$N("HO"B`@
M("`@("`@)&EM9U]D871A(#T@87)R87DH*3L*("`@("`@("`D:6UG7W!A<G1S
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D<F5S=6QT<ULQ72!A<R`D
M=7)L*2!["B`@("`@("`@("`@("\J(%-T<FEP(&%N>2!Q=6]T871I;VX@;6%R
M:W,N("HO"B`@("`@("`@("`@("1U<FP@/2!T<FEM*"1U<FPL("<B)RD["@H@
M("`@("`@("`@("`O*B!!='1E;7!T('1O(&1O=VYL;V%D('1H92!I;6%G92!D
M871A+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S
M="YP:'`G.PH@("`@("`@("`@("`D<F5Q=65S="`]("9N97<@2%144%]297%U
M97-T*"1U<FPL(&%R<F%Y*"=T:6UE;W5T)R`]/B`U*2D["B`@("`@("`@("`@
M("1R97%U97-T+3YS96YD4F5Q=65S="@I.PH*("`@("`@("`@("`@:68@*"1R
M97%U97-T+3YG971297-P;VYS94-O9&4H*2`]/2`G,C`P)RD@>PH@("`@("`@
M("`@("`@("`@+RH@5V4@;F5E9"!T;R!D971E<FUI;F4@=&AE(&EM86=E('1Y
M<&4N("!4<GD@9V5T=&EN9PH@("`@("`@("`@("`@("`@("H@=&AA="!I;F9O
M<FUA=&EO;B!F<F]M('1H92!R971U<FYE9"!(5%10"B`@("`@("`@("`@("`@
M("`@*B!C;VYT96YT+71Y<&4@:&5A9&5R+B`@5$]$3SH@57-E($U)345?36%G
M:6,@:68@=&AI<PH@("`@("`@("`@("`@("`@("H@9F%I;',@*#\I("HO"B`@
M("`@("`@("`@("`@("`D<&%R="`]("9N97<@34E-15]087)T*"1R97%U97-T
M+3YG971297-P;VYS94AE861E<B@G8V]N=&5N="UT>7!E)RDL("1R97%U97-T
M+3YG971297-P;VYS94)O9'DH*2P@;G5L;"P@)V%T=&%C:&UE;G0G+"`G.&)I
M="<I.PH@("`@("`@("`@("`@("`@)&EM9U]D871A6R1U<FQ=(#T@)V-I9#HG
M("X@)'!A<G0M/G-E=$-O;G1E;G1)1"@I.PH@("`@("`@("`@("`@("`@)&EM
M9U]P87)T<UM=(#T@)'!A<G0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\J($EF('=E(&-O=6QD(&YO="!S=6-C97-S9G5L;'D@9&]W;FQO
M860@86YY(&1A=&$L(')E='5R;B!T:&4*("`@("`@("`@*B!O<FEG:6YA;"!-
M24U%7U!A<G0@;F]W+B`J+PH@("`@("`@(&EF("AE;7!T>2@D:6UG7V1A=&$I
M*2!["B`@("`@("`@("`@(')E='5R;B`D;6EM95]P87)T.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4F5P;&%C92!T:&4@55),<R!W:71H('=I=&@@0TE$('1A
M9W,N("HO"B`@("`@("`@)'1E>'0@/2`D;6EM95]P87)T+3YG971#;VYT96YT
M<R@I.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H87)R87E?:V5Y<R@D
M:6UG7V1A=&$I+"!A<G)A>5]V86QU97,H)&EM9U]D871A*2P@)'1E>'0I.PH@
M("`@("`@("1M:6UE7W!A<G0M/G-E=$-O;G1E;G1S*"1T97AT*3L*"B`@("`@
M("`@+RH@0W)E871E(&YE=R!M=6QT:7!A<G0O<F5L871E9"!P87)T+B`J+PH@
M("`@("`@("1R96QA=&5D(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I<&%R="]R
M96QA=&5D)RD["@H@("`@("`@("\J($=E="!T:&4@0TE$(&9O<B!T:&4@)W)O
M;W0G('!A<G0N($%L=&AO=6=H(&)Y(&1E9F%U;'0@=&AE"B`@("`@("`@("H@
M9FER<W0@<&%R="!I<R!T:&4@<F]O="!P87)T("A21D,@,C,X-R!;,RXR72DL
M('=E(&UA>2!A<PH@("`@("`@("`J('=E;&P@8F4@97AP;&EC:70@86YD('!U
M="!T:&4@0TE$(&EN('1H92`G<W1A<G0G"B`@("`@("`@("H@<&%R86UE=&5R
M+B`J+PH@("`@("`@("1R96QA=&5D+3YS971#;VYT96YT5'EP95!A<F%M971E
M<B@G<W1A<G0G+"`D;6EM95]P87)T+3YS971#;VYT96YT240H*2D["@H@("`@
M("`@("\J($%D9"!T:&4@<F]O="!P87)T(&%N9"!T:&4@=F%R:6]U<R!I;6%G
M97,@=&\@=&AE(&UU;'1I<&%R=`H@("`@("`@("`J(&]B:F5C="X@*B\*("`@
M("`@("`D<F5L871E9"T^861D4&%R="@D;6EM95]P87)T*3L*("`@("`@("!F
M;W)E86-H("@D:6UG7W!A<G1S(&%S("1V86PI('L*("`@("`@("`@("`@)')E
M;&%T960M/F%D9%!A<G0H)'9A;"D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)')E;&%T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@86QL
M(&%T=&%C:&UE;G1S(&9R;VT@86X@96UA:6P@;65S<V%G92!A;F0@<F5P;&%C
M92!W:71H"B`@("`@*B!U<FQS('1O(&1O=VYL;V%D86)L92!L:6YK<RX@4VAO
M=6QD('!R;W!E<FQY('-A=F4@86QL"B`@("`@*B!A='1A8VAM96YT<R!T;R!A
M(&YE=R!F;VQD97(@86YD(')E;6]V92!T:&4@34E-15]087)T<R!F;W(@=&AE
M"B`@("`@*B!A='1A8VAM96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`@("1B87-E=7)L("`@(%1H92!B87-E(%523"!F;W(@8W)E871I;F<@
M=&AE(&QI;FMS+@H@("`@("H@0'!A<F%M($U)345?4&%R="`D8F%S95]P87)T
M("!4:&4@8F]D>2!O9B!T:&4@;65S<V%G92X*("`@("`J($!P87)A;2!S=')I
M;F<@("`@)&%U=&@@("`@("`@5&AE(&%U=&AO<FEZ960@=7-E<B!W:&\@;W=N
M<R!T:&4@871T86-H;65N=',N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%
M7U!A<G0@($UO9&EF:65D('!A<G0@=VET:"!L:6YK<R!T;R!A='1A8VAM96YT
M<RX@4F5T=7)N<PH@("`@("H@("`@("`@("`@("`@("`@("`@(%!%05)?17)R
M;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;FM!='1A8VAM
M96YT<R@D8F%S975R;"P@)&)A<V5?<&%R="P@)&%U=&@I"B`@("!["B`@("`@
M("`@9VQO8F%L("1C;VYF+"`D<')E9G,["@H@("`@("`@(&EF("@A)&-O;F9;
M)V-O;7!O<V4G75LG;&EN:U]A='1A8VAM96YT<R==*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DQI;FME9"!A='1A8VAM96YT
M<R!A<F4@9F]R8FED9&5N+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E<75I
M<F5?;VYC92`G5D93+G!H<"<["B`@("`@("`@)'9F<R`]("961E,Z.G-I;F=L
M971O;B@D8V]N9ELG=F9S)UU;)W1Y<&4G72P@2&]R9&4Z.F=E=$1R:79E<D-O
M;F9I9R@G=F9S)RP@)&-O;F9;)W9F<R==6R=T>7!E)UTI*3L*"B`@("`@("`@
M)'1S(#T@9VUM:W1I;64H*3L*("`@("`@("`D9G5L;'!A=&@@/2!S<')I;G1F
M*"<E<R\E<R\E9"<L($E-4%]61E-?3$E.2U]!5%1!0TA?4$%42"P@)&%U=&@L
M("1T<RD["@H@("`@("`@("1T<F%I;&5R(#T@4W1R:6YG.CIC;VYV97)T0VAA
M<G-E="A?*")!='1A8VAM96YT<R(I+"!.3%,Z.F=E=$-H87)S970H*2P@)&)A
M<V5?<&%R="T^9V5T0VAA<G-E="@I*3L*"B`@("`@("`@:68@*"1P<F5F<RT^
M9V5T5F%L=64H)V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY)RDI('L*("`@
M("`@("`@("`@+RH@1&5T97)M:6YE('1H92!F:7)S="!D87D@;V8@=&AE(&UO
M;G1H(&EN('=H:6-H('1H92!C=7)R96YT"B`@("`@("`@("`@("`J(&%T=&%C
M:&UE;G1S('=I;&P@8F4@<FEP92!F;W(@9&5L971I;VXL('1H96X@<W5B=')A
M8W0@,2!S96-O;F0*("`@("`@("`@("`@("H@=&\@;V)T86EN('1H92!L87-T
M(&1A>2!O9B!T:&4@<')E=FEO=7,@;6]N=&@N("HO"B`@("`@("`@("`@("1D
M96Q?=&EM92`](&=M;6MT:6UE*#`L(#`L(#`L(&1A=&4H)VXG*2`K("1P<F5F
M<RT^9V5T5F%L=64H)V1E;&5T95]A='1A8VAM96YT<U]M;VYT:&QY7VME97`G
M*2`K(#$L(#$L(&1A=&4H)UDG*2D@+2`Q.PH@("`@("`@("`@("`D=')A:6QE
M<B`N/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"<@*"<@+B!S<')I;G1F*%\H
M(DQI;FMS('=I;&P@97AP:7)E(&]N("5S(BDL(&1A=&4H)T8@:BP@62<L("1D
M96Q?=&EM92DI("X@)RDG+"!.3%,Z.F=E=$-H87)S970H*2P@)&)A<V5?<&%R
M="T^9V5T0VAA<G-E="@I*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?8V%C:&4@87,@)&%T="D@>PH@("`@("`@("`@("`D=')A:6QE
M<B`N/2`B7&XB("X@571I;#HZ861D4&%R86UE=&5R*"1B87-E=7)L+"!A<G)A
M>2@G=2<@/3X@)&%U=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T)R`]/B`D
M=',L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=F)R`]/B`D871T+3YG971.86UE
M*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&YU;&PL(&9A;'-E*3L*("`@("`@("`@("`@:68@*"1C;VYF
M6R=C;VUP;W-E)UU;)W5S95]V9G,G72D@>PH@("`@("`@("`@("`@("`@)'9F
M<RT^<F5N86UE*$E-4%]61E-?051404-(7U!!5$@L("1A='0M/F=E=$EN9F]R
M;6%T:6]N*"=T96UP7V9I;&5N86UE)RDL("1F=6QL<&%T:"P@97-C87!E<VAE
M;&QC;60H)&%T="T^9V5T3F%M92@I*2D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1A
M='0M/F=E=$EN9F]R;6%T:6]N*"=T96UP7V9I;&5N86UE)RDI.PH@("`@("`@
M("`@("`@("`@)')E<R`]("1V9G,M/G=R:71E1&%T82@D9G5L;'!A=&@L(&5S
M8V%P97-H96QL8VUD*"1A='0M/F=E=$YA;64H*2DL("1D871A+"!T<G5E*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/F1E;&5T94%L;$%T=&%C:&UE;G1S*"D["@H@("`@("`@(&EF("@D8F%S
M95]P87)T+3YG9710<FEM87)Y5'EP92@I(#T]("=M=6QT:7!A<G0G*2!["B`@
M("`@("`@("`@("1M:7AE9%]P87)T(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I
M<&%R="]M:7AE9"<I.PH@("`@("`@("`@("`D;6EX961?<&%R="T^861D4&%R
M="@D8F%S95]P87)T*3L*("`@("`@("`@("`@)&QI;FM?<&%R="`]("9N97<@
M34E-15]087)T*"=T97AT+W!L86EN)RP@)'1R86EL97(L("1B87-E7W!A<G0M
M/F=E=$-H87)S970H*2P@)VEN;&EN92<L("1B87-E7W!A<G0M/F=E=$-U<G)E
M;G1%;F-O9&EN9R@I*3L*("`@("`@("`@("`@)&QI;FM?<&%R="T^<V5T1&5S
M8W)I<'1I;VXH7R@B071T86-H;65N="!);F9O<FUA=&EO;B(I*3L*("`@("`@
M("`@("`@)&UI>&5D7W!A<G0M/F%D9%!A<G0H)&QI;FM?<&%R="D["B`@("`@
M("`@("`@(')E='5R;B`D;6EX961?<&%R=#L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8F%S95]P87)T+3YA<'!E;F1#;VYT96YT<R@B7&XM+2TM
M+5QN(B`N("1T<F%I;&5R+"`D8F%S95]P87)T+3YG971#=7)R96YT16YC;V1I
M;F<H*2D["B`@("`@("`@("`@(')E='5R;B`D8F%S95]P87)T.PH@("`@("`@
M('T*"B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O;&EB+U%U;W1A+G!H<```````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-3`W`#$P-#$W,S8R-S8V`#`Q
M-S4W,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@24U07U%U;W1A.CH@<')O=FED97,@86X@05!)(&9O
M<B!R971R:65V:6YG(%%U;W1A(&1E=&%I;',@9G)O;2!A(&UA:6P*("H@<V5R
M=F5R+@H@*@H@*B`D2&]R9&4Z(&EM<"]L:6(O475O=&$N<&AP+'8@,2XR,RXQ
M,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z-34@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!)35`@
M-"XP"B`J($!P86-K86=E($E-4%]1=6]T80H@*B\*8VQA<W,@24U07U%U;W1A
M('L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@475O=&$@:6YS=&%N8V4@
M8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%%U;W1A('-U8F-L87-S
M('1O(')E='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%%U
M;W1A(&EN<W1A;F-E+"!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@
M;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV
M97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D<FEV97(@
M/2!B87-E;F%M92@D9')I=F5R*3L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+U%U;W1A+R<@+B`D9')I=F5R("X@)RYP:'`G
M.PH@("`@("`@("1C;&%S<R`]("=)35!?475O=&%?)R`N("1D<FEV97(["B`@
M("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@
M("1Q=6]T82`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1Q=6]T82`](&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1Q=6]T83L*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E(%%U
M;W1A(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@*B`D9')I=F5R+@H@("`@("H*
M("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@
M;F\@475O=&$@:6YS=&%N8V4@=VET:"!T:&4@<V%M90H@("`@("H@<&%R86UE
M=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO
M=6QD(&)E('5S960@:68@;75L=&EP;&4@<75O=&$@<V]U<F-E<R!A<F4@<F5Q
M=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O
M:V5D(&%S.B`D=F%R(#T@)E%U;W1A.CIS:6YG;&5T;VXH*0H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E
M=&4@475O=&$@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA
M;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-R96%T960@
M8V]N8W)E=&4@475O=&$@:6YS=&%N8V4L(&]R(&9A;'-E(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S
M.PH*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@
M("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@
M)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US
M*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=
M*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DE-
M4%]1=6]T83HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T
M:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($E-4%]1=6]T
M82@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A
M<F%M<R`]("1P87)A;7,["@H@("`@("`@("\J($EF("=P87-S=V]R9"<@97AI
M<W1S(&EN('!A<F%M<RP@:70@:&%S(&)E96X@96YC<GEP=&5D(&EN('1H90H@
M("`@("`@("`J('-E<W-I;VX@<V\@=V4@;F5E9"!T;R!D96-R>7!T+B`J+PH@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT@/2!3
M96-R970Z.G)E860H4V5C<F5T.CIG971+97DH)VEM<"<I+"`D=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T('%U;W1A(&EN9F]R;6%T:6]N("AU<V5D+V%L;&]C871E9"DL
M(&EN(&)Y=&5S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($%N(&%S
M<V]C:6%T:79E(&%R<F%Y+@H@("`@("H@("`@("`@("`@("`@("`@)VQI;6ET
M)R`]($UA>&EM=6T@<75O=&$@86QL;W=E9`H@("`@("H@("`@("`@("`@("`@
M("`@)W5S86=E)R`]($-U<G)E;G1L>2!U<V5D('!O<G1I;VX@;V8@<75O=&$@
M*&EN(&)Y=&5S*0H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!014%2
M7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U
M;W1A*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)W5S86=E)R`]/B`P
M+"`G;&EM:70G(#T^(#`I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+VQI8B]B87-E+G!H<```````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3$Q,P`Q,#0Q-S,V,C<V-@`P
M,3<T,#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($E-4"!B87-E(&EN8VQU<VEO;B!F:6QE+B!4:&ES
M(&9I;&4@8G)I;F=S(&EN(&%L;"!O9B!T:&4@9&5P96YD96YC:65S('1H870*
M("H@979E<GD@24U0('-C<FEP="!W:6QL(&YE960L(&%N9"!S971S('5P(&]B
M:F5C=',@=&AA="!A;&P@<V-R:7!T<R!U<V4N"B`J"B`J(%1H92!F;VQL;W=I
M;F<@=F%R:6%B;&5S+"!D969I;F5D(&EN('1H92!S8W)I<'0@=&AA="!C86QL
M<R!T:&ES(&]N92P@87)E"B`J('5S960Z"B`J("`@)&%U=&AE;G1I8V%T:6]N
M("`@+2!4:&4@='EP92!O9B!A=71H96YT:6-A=&EO;B!T;R!U<V4*("H@("`D
M;F]?8V]M<')E<W,@("`@("`M($-O;G1R;VQS('=H971H97(@=&AE('!A9V4@
M<VAO=6QD(&)E(&-O;7!R97-S960*("H@("`D<V5S<VEO;E]C;VYT<F]L("`M
M(%-E=',@<W!E8VEA;"!S97-S:6]N(&-O;G1R;VP@;&EM:71A=&EO;G,*("H*
M("H@)$AO<F1E.B!I;7`O;&EB+V)A<V4N<&AP+'8@,2XW.2XQ,"XQ,2`R,#`V
M+S`R+S`U(#$X.C$Q.C,X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G
M<&PN:'1M;"X*("HO"@HO+R!#:&5C:R!F;W(@82!P<FEO<B!D969I;FET:6]N
M(&]F($A/4D1%7T)!4T4@*'!E<FAA<',@8GD@86X*+R\@875T;U]P<F5P96YD
M7V9I;&4@9&5F:6YI=&EO;B!F;W(@<VET92!C=7-T;VUI>F%T:6]N*2X*:68@
M*"%D969I;F5D*"=(3U)$15]"05-%)RDI('L*("`@($!D969I;F4H)TA/4D1%
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*?0H*+R\@
M3&]A9"!T:&4@2&]R9&4@1G)A;65W;W)K(&-O<F4L(&%N9"!S970@=7`@:6YC
M;'5S:6]N('!A=&AS+@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V-O<F4N<&AP)SL*"B1S97-S:6]N7V-O;G1R;VP@/2!5=&EL.CIN;VY);G!U
M=%9A<B@G<V5S<VEO;E]C;VYT<F]L)RD["G-W:71C:"`H)'-E<W-I;VY?8V]N
M=')O;"D@>PIC87-E("=N971S8V%P92<Z"B`@("!I9B`H)&)R;W=S97(M/FES
M0G)O=W-E<B@G;6]Z:6QL82<I*2!["B`@("`@("`@<V5S<VEO;E]C86-H95]L
M:6UI=&5R*"=P<FEV871E+"!M=7-T+7)E=F%L:61A=&4G*3L*("`@('T*("`@
M(&)R96%K.PI]"@HO+R!296=I<W1R>2X*:68@*"1S97-S:6]N7V-O;G1R;VP@
M/3T@)VYO;F4G*2!["B`@("`D<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L
M971O;BA(3U)$15]315-324].7TY/3D4I.PI](&5L<V5I9B`H)'-E<W-I;VY?
M8V]N=')O;"`]/2`G<F5A9&]N;'DG*2!["B`@("`D<F5G:7-T<GD@/2`F4F5G
M:7-T<GDZ.G-I;F=L971O;BA(3U)$15]315-324].7U)%041/3DQ9*3L*?2!E
M;'-E('L*("`@("1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*"D[
M"GT*"B\O(%=E(&5X<&QI8VET;'D@9&\@;F]T(&-H96-K(&%P<&QI8V%T:6]N
M('!E<FUI<W-I;VYS(&9O<B!T:&4@8V]M<&]S90HO+R!A;F0@<F5C;VUP;W-E
M('!A9V5S+"!S:6YC92!T:&]S92!A<F4@:&%N9&QE9"!B96QO=R!A;F0@;F5E
M9"!T;R!F86QL"B\O('1H<F]U9V@@=&\@24U0+7-P96-I9FEC(&-O9&4N"B1A
M=71H7V-H96-K(#T@(2AD969I;F5D*"=!551(7TA!3D1,15(G*2!\?"!S=')S
M='(H)%]315)615);)U!(4%]314Q&)UTL("=C;VUP;W-E+G!H<"<I*3L*:68@
M*&ES7V$H*"1P=7-H960@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)VEM<"<L("1A
M=71H7V-H96-K*2DL("=014%27T5R<F]R)RDI('L*("`@(&EF("@D<'5S:&5D
M+3YG971#;V1E*"D@/3T@)W!E<FUI<W-I;VY?9&5N:65D)RD@>PH@("`@("`@
M($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PH@("`@
M?0H@("`@2&]R9&4Z.F9A=&%L*"1P=7-H960L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@9F%L<V4I.PI]"B1C;VYF(#T@)B1'3$]"04Q36R=C;VYF)UT["D!D969I
M;F4H)TE-4%]414U03$%415,G+"`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S
M)RDI.PH*+R\@1FEN9"!T:&4@8F%S92!F:6QE('!A=&@@;V8@24U0+@I`9&5F
M:6YE*"=)35!?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PH*
M+R\@3F]T:69I8V%T:6]N('-Y<W1E;2X*<F5Q=6ER95]O;F-E($E-4%]"05-%
M("X@)R]L:6(O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`G.PHD
M;F]T:69I8V%T:6]N(#T@)DYO=&EF:6-A=&EO;CHZ<VEN9VQE=&]N*"D["B1N
M;W1I9FEC871I;VXM/F%T=&%C:"@G<W1A='5S)RP@;G5L;"P@)TYO=&EF:6-A
M=&EO;E],:7-T96YE<E]S=&%T=7-?:6UP)RD["B\O($)#(&-H96-K+@II9B`H
M0&EN8VQU9&5?;VYC92`G2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+V%U
M9&EO+G!H<"<I('L*("`@("1N;W1I9FEC871I;VXM/F%T=&%C:"@G875D:6\G
M*3L*?0H*+R\@24U0(&)A<V4@;&EB<F%R>2X*<F5Q=6ER95]O;F-E($E-4%]"
M05-%("X@)R]L:6(O24U0+G!H<"<["@HO+R!)9B!)35`@:7-N)W0@<F5S<&]N
M<VEB;&4@9F]R($AO<F1E(&%U=&@L(&%N9"!N;R!O;F4@:7,@;&]G9V5D(&EN
M=&\*+R\@2&]R9&4L(')E9&ER96-T('1O('1H92!L;V=I;B!S8W)E96XN($EF
M('1H:7,@:7,@82!C;VUP;W-E('=I;F1O=PHO+R!T:&%T(&IU<W0@=&EM960@
M;W5T+"!G:79E('1H92!U<V5R(&$@8VAA;F-E('1O(')E8V]V97(@=&AE:7(*
M+R\@;65S<V%G92X*:68@*"$H075T:#HZ:7-!=71H96YT:6-A=&5D*"D@?'P@
M*$%U=&@Z.F=E=%!R;W9I9&5R*"D@/3T@)VEM<"<I*2D@>PH@("`@:68@*'-T
M<G-T<B@D7U-%4E9%4ELG4$A07U-%3$8G72P@)W)E8V]M<&]S92YP:'`G*2D@
M>PH@("`@("`@("\O($QE="!T:&ES(&9A;&P@=&AR;W5G:#L@;W1H97)W:7-E
M('=E(&-R96%T92!A;B!I;F9I;FET90H@("`@("`@("\O(&EN8VQU<VEO;B!L
M;V]P+@H@("`@?2!E;'-E:68@*'-T<G-T<B@D7U-%4E9%4ELG4$A07U-%3$8G
M72P@)V-O;7!O<V4N<&AP)RDI('L*("`@("`@("!R97%U:7)E($E-4%]"05-%
M("X@)R]R96-O;7!O<V4N<&AP)SL*("`@("`@("!E>&ET.PH@("`@?2!E;'-E
M('L*("`@("`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E
M8W0H*3L*("`@('T*?0H*+R\@2&]R9&4@;&EB<F%R:65S+@IR97%U:7)E7V]N
M8V4@)TAO<F1E+U-E8W)E="YP:'`G.PH*+R\@2&5L<"X*<F5Q=6ER95]O;F-E
M("=(;W)D92](96QP+G!H<"<["@HO+R!3=&%R="!C;VUP<F5S<VEO;BX*:68@
M*"%5=&EL.CIN;VY);G!U=%9A<B@G;F]?8V]M<')E<W,G*2D@>PH@("`@2&]R
M9&4Z.F-O;7!R97-S3W5T<'5T*"D["GT*"B1A=71H96YT:6-A=&EO;B`](%5T
M:6PZ.FYO;DEN<'5T5F%R*"=A=71H96YT:6-A=&EO;B<I.PII9B`H)&%U=&AE
M;G1I8V%T:6]N(#T]/2!N=6QL*2!["B`@("`D875T:&5N=&EC871I;VX@/2`P
M.PI]"FEF("@D875T:&5N=&EC871I;VX@(3T]("=N;VYE)RD@>PH@("`@+R\@
M268@=V4G=F4@9V]T=&5N('1O('1H:7,@<&]I;G0@86YD(&AA=F4@=F%L:60@
M;&]G:6X@8W)E9&5N=&EA;',*("`@("\O(&)U="!D;VXG="!A8W1U86QL>2!H
M879E(&%N($E-4"!S97-S:6]N+"!T:&5N('=E(&YE960@=&\@9V\*("`@("\O
M('1H<F]U9V@@<F5D:7)E8W0N<&AP('1O(&5N<W5R92!T:&%T(&5V97)Y=&AI
M;F<@9V5T<R!S970@=7`*("`@("\O('!R;W!E<FQY+B!3:6YG;&4M<VEG;F]N
M(&%N9"!T<F%N<W!A<F5N="!A=71H96YT:6-A=&EO;B!S971U<',*("`@("\O
M(&%R92!L:6ME;'D@=&\@=')I9V=E<B!T:&ES(&-A<V4N"B`@("!I9B`H96UP
M='DH)%]315-324].6R=I;7`G72DI('L*("`@("`@("!I9B`H<W1R<W1R*"1?
M4T525D526R=02%!?4T5,1B==+"`G8V]M<&]S92YP:'`G*2D@>PH@("`@("`@
M("`@("!R97%U:7)E($E-4%]"05-%("X@)R]R96-O;7!O<V4N<&AP)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E($E-4%]"05-%("X@
M)R]R961I<F5C="YP:'`G.PH@("`@("`@('T*("`@("`@("!E>&ET.PH@("`@
M?0H*("`@(&EF("AS=')S='(H)%]315)615);)U!(4%]314Q&)UTL("=C;VUP
M;W-E+G!H<"<I*2!["B`@("`@("`@:68@*"%)35`Z.F-H96-K075T:&5N=&EC
M871I;VXH)&%U=&AE;G1I8V%T:6]N+"!T<G5E*2D@>PH@("`@("`@("`@("!R
M97%U:7)E($E-4%]"05-%("X@)R]R96-O;7!O<V4N<&AP)SL*("`@("`@("`@
M("`@97AI=#L*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@($E-4#HZ
M8VAE8VM!=71H96YT:6-A=&EO;B@D875T:&5N=&EC871I;VXI.PH@("`@?0I]
M"@II9B`H*$E-4#HZ;&]G:6Y487-K<T9L86<H*2`]/3T@,BD@)B8*("`@("%D
M969I;F5D*"=!551(7TA!3D1,15(G*2`F)@H@("`@(7-T<G-T<B@D7U-%4E9%
M4ELG4$A07U-%3$8G72P@)VUA:6YT96YA;F-E+G!H<"<I*2!["B`@("!R97%U
M:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]397-S:6]N+G!H<"<["B`@("!)
M35!?4V5S<VEO;CHZ;&]G:6Y487-K<R@I.PI]"@HO+R!#871C:"!C+6-L:65N
M="!E<G)O<G,N"G)E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*"=I;6%P7V5R
M<F]R<R<I.PIR96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;B@G:6UA<%]A;&5R
M=',G*3L*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O````````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-C8`,#$W,C$S`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L
M871E<R]P9W`O````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,C`P,#$`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O=&5M<&QA=&5S+W!G<"]P87-S<&AR87-E+FEN8P``````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S8U`#$P-#$W,S8R-S8V`#`R,C8U
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<"!I9B`H(6ES7V$H)'-E8W5R95]C:&5C:RP@)U!%05)?17)R;W(G*2DZ
M(#\^"CQF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB<&%S<W!H<F%S95]D:6%L
M;V<B(&%C=&EO;CTB/#]P:'`@96-H;R`D<W5B;6ET7W5R;"`_/B(^"CP_<&AP
M(&EF("@H)')E;&]A9"`](%5T:6PZ.F=E=$9O<FU$871A*"=R96QO860G*2DI
M.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)R96QO860B('9A;'5E
M/2(\/W!H<"!E8VAO("1R96QO860@/SXB("\^"CP_<&AP(&5N9&EF.R`_/@H\
M/W!H<"!I9B`H*"1A8W1I;VX@/2!5=&EL.CIG971&;W)M1&%T82@G<&%S<W!H
M<F%S95]A8W1I;VXG*2DI.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)P87-S<&AR87-E7V%C=&EO;B(@=F%L=64](CP_<&AP(&5C:&\@)&%C=&EO
M;B`_/B(@+SX*/#]P:'`@96YD:68[(#\^"@H\=&%B;&4@8F]R9&5R/2(P(B!C
M96QL<W!A8VEN9STB,"(@8V5L;'!A9&1I;F<](C(B/@H@/'1R/@H@(#QT9#X*
M("`@/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(@8V5L;'!A
M9&1I;F<](C(B/@H@("`@/'1R/@H@("`@(#QT9"!C;&%S<STB<VUA;&QH96%D
M97(@;&5F=$%L:6=N(CX*("`@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=L
M;V-K960N<&YG)RP@7R@B4$=0(BDL(&YU;&PL("1R96=I<W1R>2T^9V5T26UA
M9V5$:7(H)VAO<F1E)RDI(#\^"B`@("`@/"]T9#X*("`@("`\=&0@8VQA<W,]
M(G-M86QL:&5A9&5R(&QE9G1!;&EG;B(^"B`@("`@(#P_<&AP('!R:6YT9BA?
M*")0;&5A<V4@96YT97(@=&AE('!A<W-P:')A<V4@9F]R('EO=7(@4$=0('!R
M:79A=&4@:V5Y+B!9;W4@=VEL;"!O;FQY(&YE960@=&\@96YT97(@=&AI<R!P
M87-S<&AR87-E(&]N8V4@<&5R("5S('-E<W-I;VXN(BDL"B`@("`@("`@("`@
M("`@("`@("`D<F5G:7-T<GDM/F=E="@G;F%M92<I*2`_/@H@("`@(#PO=&0^
M"B`@("`\+W1R/@H@("`\+W1A8FQE/@H@(#PO=&0^"B`\+W1R/@H*(#QT<CX*
M("`\=&0@8VQA<W,](FQI9VAT(&QE9G1!;&EG;B(^"B`@(#QS=')O;F<^/#]P
M:'`@96-H;R!?*")087-S<&AR87-E.B(I(#\^/"]S=')O;F<^)FYB<W`["B`@
M(#QI;G!U="!T>7!E/2)P87-S=V]R9"(@;F%M93TB<&%S<W!H<F%S92(@<VEZ
M93TB,34B(&UA>&QE;F=T:#TB-C`B(&-L87-S/2)F:7AE9"(@+SXF;F)S<#L*
M("`@/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB<W5B;6ET(B!C;&%S<STB
M8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")3=6)M:70B*2`_/B(@+SXF
M;F)S<#L*("`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@
M;VYC;&EC:STB=VEN9&]W+F-L;W-E*"D[(B!V86QU93TB/#]P:'`@96-H;R!?
M*")#86YC96PB*2`_/B(@+SX*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*"CPO
M9F]R;3X*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*9&]C=6UE
M;G0N<&%S<W!H<F%S95]D:6%L;V<N<&%S<W!H<F%S92YF;V-U<R@I.PH\+W-C
M<FEP=#X*/#]P:'`@96YD:68[(#\^"@H\+V)O9'D^"CPO:'1M;#X*````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O
M<&=P+W!G<"YI;F,`````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,C$V,3<`,3`T,3<S-C(W-C8`,#(Q,C8V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@
M:60](G5S95]P9W`B(&YA;64](G5S95]P9W`B/#]P:'`@96-H;R`H)'!R969S
M+3YG971686QU92@G=7-E7W!G<"<I*2`_("<@8VAE8VME9#TB8VAE8VME9"(G
M(#H@)R<@/SX@+SX@/&QA8F5L(&9O<CTB=7-E7W!G<"(^/#]P:'`@96-H;R!?
M*")%;F%B;&4@4$=0(&9U;F-T:6]N86QI='D_(BD@/SX\+VQA8F5L/B9N8G-P
M.SP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W!G<"UO=F5R=FEE=R<I
M(#\^/&)R("\^"CQS=')O;F<@<W1Y;&4](F-O;&]R.G)E9"(^/#]P:'`@96-H
M;R!?*").3U1%(BD@/SXZ/"]S=')O;F<^(#P_<&AP(&5C:&\@7R@B4$=0('-U
M<'!O<G0@<F5Q=6ER97,@<&]P=7`@=VEN9&]W<R!T;R!B92!U<V5D+B`@268@
M>6]U<B!B<F]W<V5R(&ES(&-U<G)E;G1L>2!S970@=&\@9&ES86)L92!P;W!U
M<"!W:6YD;W=S+"!Y;W4@;75S="!C:&%N9V4@=&AI<R!S971T:6YG(&]R(&5L
M<V4@=&AE(%!'4"!F96%T=7)E<R!W:6QL(&YO="!W;W)K(&-O<G)E8W1L>2XB
M*2`_/CQB<B`O/@H\/W!H<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)W!G<%]A
M='1A8VA?<'5B:V5Y)RDI.B`_/@H\:6YP=70@='EP93TB8VAE8VMB;W@B(&ED
M/2)P9W!?871T86-H7W!U8FME>2(@;F%M93TB<&=P7V%T=&%C:%]P=6)K97DB
M(#P_<&AP(&5C:&\@*"1P<F5F<RT^9V5T5F%L=64H)W!G<%]A='1A8VA?<'5B
M:V5Y)RDI(#\@(F-H96-K960]7")C:&5C:V5D7"(B(#H@(B(@/SX@+SX@/&QA
M8F5L(&9O<CTB<&=P7V%T=&%C:%]P=6)K97DB/CP_<&AP(&5C:&\@7R@B4VAO
M=6QD('EO=7(@4$=0('!U8FQI8R!K97D@=&\@8F4@871T86-H960@=&\@>6]U
M<B!M97-S86=E<R!B>2!D969A=6QT/R(I(#\^/"]L86)E;#XF;F)S<#L\/W!H
M<"!E8VAO($AE;'`Z.FQI;FLH)VEM<"<L("=P9W`M;W!T:6]N+6%T=&%C:"UP
M=6)K97DG*2`_/CQB<B`O/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*"$D
M<')E9G,M/FES3&]C:V5D*"=P9W!?<V-A;E]B;V1Y)RDI.B`_/@H\:6YP=70@
M='EP93TB8VAE8VMB;W@B(&ED/2)P9W!?<V-A;E]B;V1Y(B!N86UE/2)P9W!?
M<V-A;E]B;V1Y(B`\/W!H<"!E8VAO("@D<')E9G,M/F=E=%9A;'5E*"=P9W!?
M<V-A;E]B;V1Y)RDI(#\@(F-H96-K960]7")C:&5C:V5D7"(B(#H@(B(@/SX@
M+SX@/&QA8F5L(&9O<CTB<&=P7W-C86Y?8F]D>2(^/#]P:'`@96-H;R!?*")3
M:&]U;&0@=&AE(&)O9'D@;V8@=&5X="]P;&%I;B!M97-S86=E<R!B92!S8V%N
M;F5D(&9O<B!01U`@9&%T83\B*2`_/CPO;&%B96P^)FYB<W`[/#]P:'`@96-H
M;R!(96QP.CIL:6YK*"=I;7`G+"`G<&=P+6]P=&EO;BUS8V%N+6)O9'DG*2`_
M/CQB<B`O/@H\/W!H<"!E;F1I9CL@/SX*/"]D:78^"@H\8G(@8VQA<W,](G-P
M86-E<B(@+SX*/&1I=B!C;&%S<STB:&5A9&5R(CX*("`\=6P^/&QI/CP_<&AP
M(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W!G<"UM86YA9V4M<'5B:V5Y)RD@
M/SX\+VQI/CPO=6P^"B`@/#]P:'`@96-H;R!?*")01U`@4'5B;&EC($ME>7)I
M;F<B*2`_/@H\+V1I=CX*"CQD:78@8VQA<W,](FET96TB/@H\/W!H<"!I9B`H
M96UP='DH)'!U8FME>5]L:7-T*2DZ(#\^"CQS=')O;F<^/#]P:'`@96-H;R!?
M*").;R!+97ES(&EN($ME>7)I;F<B*2`_/CPO<W1R;VYG/@H\/W!H<"!E;'-E
M:68@*&ES7V$H)'!U8FME>5]L:7-T+"`G4$5!4E]%<G)O<B<I*3H@/SX*/'-T
M<F]N9SX\/W!H<"!E8VAO(%\H(D5R<F]R(BD@/SXZ/"]S=')O;F<^(#P_<&AP
M(&5C:&\@)'!U8FME>5]L:7-T+3YG971-97-S86=E*"D@/SX*/#]P:'`@96QS
M93H@/SX*/'1A8FQE/@H\/W!H<"!F;W)E86-H("@D<'5B:V5Y7VQI<W0@87,@
M)'9A;"DZ("1L:6YK=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1S96QF55),
M+"`G96UA:6PG+"`D=F%L6R=E;6%I;"==*3L@/SX*("`\='(^"B`@("`\=&0^
M/#]P:'`@96-H;R`D=F%L6R=N86UE)UT@/SX@*#P_<&AP(&5C:&\@)'9A;%LG
M96UA:6PG72`_/BD\+W1D/@H@("`@/'1D/B9N8G-P.R9N8G-P.UL\/W!H<"!E
M8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<B@D;&EN:W5R;"P@
M)V%C=&EO;DE$)RP@)W9I97=?<'5B;&EC7VME>2<I+"!S<')I;G1F*%\H(E9I
M97<@)7,@4'5B;&EC($ME>2(I+"`D=F%L6R=N86UE)UTI+"!N=6QL+"`G=FEE
M=U]K97DG*3L@/SX\/W!H<"!E8VAO(%\H(E9I97<B*2`_/CPO83Y=)FYB<W`[
M6SP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*"1L
M:6YK=7)L+"`G86-T:6]N240G+"`G:6YF;U]P=6)L:6-?:V5Y)RDL('-P<FEN
M=&8H7R@B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC($ME>2(I+"`D=F%L6R=N
M86UE)UTI+"!N=6QL+"`G:6YF;U]K97DG*3L@/SX\/W!H<"!E8VAO(%\H(D1E
M=&%I;',B*2`_/CPO83Y=)FYB<W`[6SP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH
M571I;#HZ861D4&%R86UE=&5R*"1L:6YK=7)L+"`G86-T:6]N240G+"`G9&5L
M971E7W!U8FQI8U]K97DG*2P@<W!R:6YT9BA?*")$96QE=&4@)7,@4'5B;&EC
M($ME>2(I+"`D=F%L6R=N86UE)UTI+"!N=6QL+"!N=6QL+"`B:68@*&-O;F9I
M<FTH)R(@+B!A9&1S;&%S:&5S*%\H(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(I*2`N("(G*2D@>R!R971U<FX@
M=')U93L@?2!E;'-E('L@<F5T=7)N(&9A;'-E.R!](BD[(#\^/#]P:'`@96-H
M;R!?*")$96QE=&4B*2`_/CPO83Y=/"]T9#X*("`\+W1R/@H\/W!H<"!E;F1F
M;W)E86-H.R`_/@H\+W1A8FQE/@H\/W!H<"!E;F1I9CL@/SX*/"]D:78^"@H\
M8G(@8VQA<W,](G-P86-E<B(@+SX*/&1I=B!C;&%S<STB;F]W<F%P(CX*/#]P
M:'`@:68@*"$D:6UP6R=F:6QE7W5P;&]A9"==*3H@/SX*("`\<W!A;B!S='EL
M93TB8V]L;W(Z<F5D(CX\/W!H<"!E8VAO(%\H(DME>2!I;7!O<G0@:7,@;F]T
M(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI
M<R!S97)V97(N(BD@/SX\+W-P86X^"CP_<&AP(&5L<V5I9B`H(21'3$]"04Q3
M6R=P<F5F<R==+3YG971686QU92@G861D7W-O=7)C92<I*3H@/SX*("`\<W1R
M;VYG/CP_<&AP(&5C:&\@7R@B2V5Y(&EM<&]R="!I<R!N;W0@879A:6QA8FQE
M+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F:6YE9"!T;R!A9&0@>6]U
M<B!C;VYT86-T<RXB*2`_/CPO<W1R;VYG/@H\/W!H<"!E;'-E.B`_/@H@(#P_
M<&AP("1P=6)L:6-?:6UP;W)T7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<BA5
M=&EL.CIA9&1087)A;65T97(H)'-E;&954DPL("=A8W1I;VY)1"<L("=I;7!O
M<G1?<'5B;&EC7VME>2<I+"`G<F5L;V%D)RP@)'-E;&954DPI.R`_/@H@(#QI
M;G!U="!T>7!E/2)S=6)M:70B(&YA;64](G-A=F4B(&-L87-S/2)B=71T;VXB
M(&]N8VQI8VL](G!O<'5P7VEM<"@G/#]P:'`@96-H;R`D<'5B;&EC7VEM<&]R
M=%]U<FP@/SXG+#<U,"PR-S4I.R!R971U<FX@9F%L<V4[(B!V86QU93TB/#]P
M:'`@96-H;R!?*"));7!O<G0@4'5B;&EC($ME>2(I(#\^(B`O/@H@(#P_<&AP
M(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W!G<"UI;7!O<G0M<'5B:V5Y)RD@
M/SX*/#]P:'`@96YD:68[(#\^"CPO9&EV/@H*/&)R(&-L87-S/2)S<&%C97(B
M("\^"CQD:78@8VQA<W,](FAE861E<B(^"B`@/'5L/CQL:3X\/W!H<"!E8VAO
M($AE;'`Z.FQI;FLH)VEM<"<L("=P9W`M;W9E<G9I97<M<&5R<V]N86QK97DG
M*2`_/CPO;&D^/"]U;#X*("`\/W!H<"!E8VAO(%\H(EEO=7(@4$=0(%!U8FQI
M8R]0<FEV871E($ME>7,B*2`_/@H\+V1I=CX*"CQD:78@8VQA<W,](FET96TB
M/@H\/W!H<"!I9B`H:7-?82@D<V5C=7)E7V-H96-K+"`G4$5!4E]%<G)O<B<I
M*3H@/SX*/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E!'4"!097)S;VYA;"!+97EP
M86ER('-U<'!O<G0@<F5Q=6ER97,@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M(BD@/SX\+W-T<F]N9SX*/"]D:78^"@H\/W!H<`IE;'-E:68@*"1P<F5F<RT^
M9V5T5F%L=64H)W!G<%]P=6)L:6-?:V5Y)RD@)B8*("`@("`@("`D<')E9G,M
M/F=E=%9A;'5E*"=P9W!?<')I=F%T95]K97DG*2DZ"B`@("`D=FEE=W!U8FQI
M8U]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'-E;&954DPL("=A8W1I;VY)
M1"<L("=V:65W7W!E<G-O;F%L7W!U8FQI8U]K97DG*3L*("`@("1I;F9O<'5B
M;&EC7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D<V5L9E523"P@)V%C=&EO
M;DE$)RP@)VEN9F]?<&5R<V]N86Q?<'5B;&EC7VME>2<I.PH@("`@)'-E;F1P
M=6)L:6-?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1S96QF55),+"`G86-T
M:6]N240G+"`G<V5N9%]P=6)L:6-?:V5Y)RD["B`@("`D=6YL;V%D7W5R;"`]
M(%5T:6PZ.F%D9%!A<F%M971E<B@D<V5L9E523"P@)V%C=&EO;DE$)RP@)W5N
M<V5T7W!A<W-P:')A<V4G*3L*("`@("1V:65W<')I=F%T95]U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H)'-E;&954DPL("=A8W1I;VY)1"<L("=V:65W7W!E
M<G-O;F%L7W!R:79A=&5?:V5Y)RD["B`@("`D:6YF;W!R:79A=&5?=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1S96QF55),+"`G86-T:6]N240G+"`G:6YF
M;U]P97)S;VYA;%]P<FEV871E7VME>2<I.PH_/@H*/'1A8FQE/@H@(#QT<CX*
M("`@(#QT9#X\/W!H<"!E8VAO(%\H(EEO=7(@4'5B;&EC($ME>2(I(#\^.CPO
M=&0^"B`@("`\=&0^)FYB<W`[)FYB<W`[6SP_<&AP(&5C:&\@2&]R9&4Z.FQI
M;FLH)'9I97=P=6)L:6-?=7)L+"!?*")6:65W(%!E<G-O;F%L(%!U8FQI8R!+
M97DB*2P@;G5L;"P@)W9I97=?:V5Y)RD@+B!?*")6:65W(BD@/SX\+V$^729N
M8G-P.UL\/W!H<"!E8VAO($AO<F1E.CIL:6YK*"1I;F9O<'5B;&EC7W5R;"P@
M7R@B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4'5B;&EC($ME>2(I+"!N=6QL
M+"`G:6YF;U]K97DG*2`N(%\H(D1E=&%I;',B*2`_/CPO83Y=)FYB<W`[6SP_
M<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)'-E;F1P=6)L:6-?=7)L+"!?*")396YD
M($ME>2!T;R!0=6)L:6,@2V5Y<V5R=F5R(BDI("X@7R@B4V5N9"!+97D@=&\@
M4'5B;&EC($ME>7-E<G9E<B(I(#\^/"]A/ET\+W1D/@H@("`@/'1D/CP_<&AP
M(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W!G<"UP97)S;VYA;&ME>2UP=6)L
M:6,G*2`_/CPO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0^/#]P:'`@96-H
M;R!?*")9;W5R(%!R:79A=&4@2V5Y(BD@/SXZ/"]T9#X*("`@(#QT9#XF;F)S
M<#LF;F)S<#M;/#]P:'`@96-H;R`H96UP='DH)'!A<W-P:')A<V4I*2`_($AO
M<F1E.CIL:6YK*"<C)RP@7R@B16YT97(@4&%S<W!H<F%S92(I+"!N=6QL+"!N
M=6QL+"!H=&UL<W!E8VEA;&-H87)S*"1O<&5N<&=P=VEN*2`N("<@<F5T=7)N
M(&9A;'-E.R<I("X@7R@B16YT97(@4&%S<W!H<F%S92(I(#H@2&]R9&4Z.FQI
M;FLH)'5N;&]A9%]U<FPL(%\H(E5N;&]A9"!087-S<&AR87-E(BDI("X@7R@B
M56YL;V%D(%!A<W-P:')A<V4B*2`_/CPO83Y=)FYB<W`[6SP_<&AP(&5C:&\@
M2&]R9&4Z.FQI;FLH)'9I97=P<FEV871E7W5R;"P@7R@B5FEE=R!097)S;VYA
M;"!0<FEV871E($ME>2(I+"!N=6QL+"`G=FEE=U]K97DG*2`N(%\H(E9I97<B
M*2`_/CPO83Y=)FYB<W`[6SP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)&EN9F]P
M<FEV871E7W5R;"P@7R@B26YF;W)M871I;VX@;VX@4&5R<V]N86P@4')I=F%T
M92!+97DB*2P@;G5L;"P@)VEN9F]?:V5Y)RD@+B!?*")$971A:6QS(BD@/SX\
M+V$^73PO=&0^"B`@("`\=&0^/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G
M+"`G<&=P+7!E<G-O;F%L:V5Y+7!R:79A=&4G*2`_/CPO=&0^"B`@/"]T<CX*
M/"]T86)L93X*/"]D:78^"@H\8G(@8VQA<W,](G-P86-E<B(@+SX*/&1I=B!C
M;&%S<STB;F]W<F%P(CX*("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)D
M96QE=&4B(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](FEF("AC;VYF:7)M*"<\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(&1E;&5T92!Y;W5R(&ME>7!A:7(_("A4:&ES(&ES($Y/5"!R96-O;6UE
M;F1E9"$I(BDI(#\^)RDI('L@9&]C=6UE;G0N<')E9G,N86-T:6]N240N=F%L
M=64])V1E;&5T95]K97DG.R!R971U<FX@=')U93L@?2!E;'-E('L@<F5T=7)N
M(&9A;'-E.R!](B!V86QU93TB/#]P:'`@96-H;R!?*")$96QE=&4@0W5R<F5N
M="!+97ES(BD@/SXB("\^"B`@/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G
M+"`G<&=P+7!E<G-O;F%L:V5Y+61E;&5T92<I(#\^"CPO9&EV/@H*/#]P:'`@
M96QS93H@/SX*"CP_<&AP"G)E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN
M<&AP)SL*)&EM<%]I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*&%R
M<F%Y*"=I;7`G+"`G:6UP)RDI.PHD<&5R<V]N86Q?:6UP;W)T7W5R;"`](%5T
M:6PZ.F%D9%!A<F%M971E<B@D<V5L9E523"P@)V%C=&EO;DE$)RP@)VEM<&]R
M=%]P97)S;VYA;%]P=6)L:6-?:V5Y)RD["C\^"CQT86)L93X*("`\='(^"B`@
M("`\=&0^/#]P:'`@96-H;R!?*")9;W5R($YA;64B*2`_/CH\+W1D/@H@("`@
M/'1D/B9N8G-P.R9N8G-P.SQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)G96YE
M<F%T95]R96%L;F%M92(@<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B(&-L87-S
M/2)F:7AE9"(@=F%L=64](CP_<&AP(&5C:&\@)&EM<%]I9&5N=&ET>2T^9V5T
M1G5L;&YA;64H*3L@/SXB+SX\+W1D/@H@("`@/'1D/CP_<&AP(&5C:&\@2&5L
M<#HZ;&EN:R@G:6UP)RP@)W!G<"UP97)S;VYA;&ME>2UC<F5A=&4M;F%M92<I
M(#\^/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9#X\/W!H<"!E8VAO(%\H
M(D-O;6UE;G0B*2`_/CH\+W1D/@H@("`@/'1D/B9N8G-P.R9N8G-P.SQI;G!U
M="!T>7!E/2)T97AT(B!N86UE/2)G96YE<F%T95]C;VUM96YT(B!S:7IE/2(S
M,"(@;6%X;&5N9W1H/2(V,"(@8VQA<W,](F9I>&5D(B`O/CPO=&0^"B`@("`\
M=&0^/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G+"`G<&=P+7!E<G-O;F%L
M:V5Y+6-R96%T92UC;VUM96YT)RD@/SX\+W1D/@H@(#PO='(^"B`@/'1R/@H@
M("`@/'1D/CP_<&AP(&5C:&\@7R@B12UM86EL($%D9')E<W,B*2`_/CH\+W1D
M/@H@("`@/'1D/B9N8G-P.R9N8G-P.SQI;G!U="!T>7!E/2)T97AT(B!N86UE
M/2)G96YE<F%T95]E;6%I;"(@<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B(&-L
M87-S/2)F:7AE9"(@=F%L=64](CP_<&AP(&5C:&\@)&EM<%]I9&5N=&ET>2T^
M9V5T1G)O;4%D9')E<W,H*3L@/SXB+SX\+W1D/@H@("`@/'1D/CP_<&AP(&5C
M:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W!G<"UP97)S;VYA;&ME>2UC<F5A=&4M
M96UA:6PG*2`_/CPO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0^/#]P:'`@
M96-H;R!?*")+97D@3&5N9W1H(BD@/SXZ/"]T9#X*("`@(#QT9#XF;F)S<#L*
M("`@("`@/'-E;&5C="!N86UE/2)G96YE<F%T95]K97EL96YG=&@B/@H@("`@
M("`@(#QO<'1I;VX@=F%L=64](C$P,C0B/C$P,C0\+V]P=&EO;CX*("`@("`@
M("`\;W!T:6]N('9A;'5E/2(R,#0X(CXR,#0X/"]O<'1I;VX^"B`@("`@(#PO
M<V5L96-T/@H@("`@/"]T9#X*("`@(#QT9#X\/W!H<"!E8VAO($AE;'`Z.FQI
M;FLH)VEM<"<L("=P9W`M<&5R<V]N86QK97DM8W)E871E+6ME>6QE;F=T:"<I
M(#\^/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9#X\/W!H<"!E8VAO(%\H
M(E!A<W-P:')A<V4B*2`_/CH\+W1D/@H@("`@/'1D/B9N8G-P.R9N8G-P.SQI
M;G!U="!T>7!E/2)P87-S=V]R9"(@;F%M93TB9V5N97)A=&5?<&%S<W!H<F%S
M93$B('-I>F4](C,P(B!M87AL96YG=&@](C8P(B!C;&%S<STB9FEX960B("\^
M/"]T9#X*("`@(#QT9#X\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEM<"<L("=P
M9W`M<&5R<V]N86QK97DM8W)E871E+7!A<W-P:')A<V4G*2`_/CPO=&0^"B`@
M/"]T<CX*("`\='(^"B`@("`\=&0^/#]P:'`@96-H;R!?*")087-S<&AR87-E
M("A!9V%I;BDB*2`_/CH\+W1D/@H@("`@/'1D/B9N8G-P.R9N8G-P.SQI;G!U
M="!T>7!E/2)P87-S=V]R9"(@;F%M93TB9V5N97)A=&5?<&%S<W!H<F%S93(B
M('-I>F4](C,P(B!M87AL96YG=&@](C8P(B!C;&%S<STB9FEX960B("\^/"]T
M9#X*("`@(#QT9#XF;F)S<#L\+W1D/@H@(#PO='(^"CPO=&%B;&4^"CPO9&EV
M/@H*/&)R(&-L87-S/2)S<&%C97(B("\^"CQD:78@8VQA<W,](FYO=W)A<"(^
M"B`@/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB<V%V92(@8VQA<W,](F)U
M='1O;B(@;VYC;&EC:STB:68@*&-O;F9I<FTH)SP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")+97D@9V5N97)A=&EO;B!M87D@=&%K92!A(&QO;F<@=&EM92!T
M;R!C;VUP;&5T92X@($-O;G1I;G5E('=I=&@@:V5Y(&=E;F5R871I;VX_(BDI
M(#\^)RDI('L@9&]C=6UE;G0N<')E9G,N86-T:6]N240N=F%L=64])V=E;F5R
M871E7VME>2<[<F5T=7)N('1R=64[('T@96QS92![(')E='5R;B!F86QS93L@
M?2(@=F%L=64](CP_<&AP(&5C:&\@7R@B0W)E871E($ME>7,B*2`_/B(@+SX*
M("`\/W!H<"!I9B`H)&EM<%LG9FEL95]U<&QO860G72DZ(#\^"B`@/&EN<'5T
M('1Y<&4](G-U8FUI="(@;F%M93TB<V%V92(@8VQA<W,](F)U='1O;B(@;VYC
M;&EC:STB<&]P=7!?:6UP*"<\/W!H<"!E8VAO("1P97)S;VYA;%]I;7!O<G1?
M=7)L(#\^)RPW-3`L,C<U*3MR971U<FX@9F%L<V4[(B!V86QU93TB/#]P:'`@
M96-H;R!?*"));7!O<G0@2V5Y<&%I<B(I(#\^(B`O/@H@(#P_<&AP(&5N9&EF
M.R`_/@H@(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W!G<"UP97)S
M;VYA;&ME>2UC<F5A=&4M86-T:6]N<R<I(#\^"CPO9&EV/@H*/#]P:'`@96YD
M:68[(#\^"@H\8G(@8VQA<W,](G-P86-E<B(@+SX*/&1I=B!C;&%S<STB;F]W
M<F%P(CX*("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)S879E(B!C;&%S
M<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N="YP<F5F<RYA8W1I;VY)1"YV
M86QU93TG<V%V95]O<'1I;VYS)SMR971U<FX@=')U93LB('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(E-A=F4@3W!T:6]N<R(I(#\^(B`O/@H@(#QI;G!U="!T>7!E
M/2)B=71T;VXB(&YA;64](F)A8VLB(&-L87-S/2)B=71T;VXB(&]N8VQI8VL]
M(F1O8W5M96YT+FQO8V%T:6]N+FAR968])SP_<&AP(&5C:&\@24U0.CIP<F5F
M<U523"AT<G5E*2`_/B<B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E='5R;B!T
M;R!/<'1I;VYS(BD@/SXB("\^"CPO9&EV/@H*/"]F;W)M/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E
M;7!L871E<R]P9W`O:6UP;W)T7VME>2YI;F,`````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#(W-``Q,#0Q-S,V,C<V-@`P,C(V-C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*("`@('-W:71C
M:"`H)&%C=&EO;DE$*2!["B`@("!C87-E("=I;7!O<G1?<'5B;&EC7VME>2<Z
M"B`@("`@("`@)'1I=&QE(#T@7R@B26UP;W)T(%!U8FQI8R!01U`@2V5Y(BD[
M"B`@("`@("`@)&EN<V5R=%]T97AT(#T@7R@B26YS97)T(%!U8FQI8R!01U`@
M2V5Y($AE<F4B*3L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=I;7!O<G1?
M<&5R<V]N86Q?<'5B;&EC7VME>2<Z"B`@("`@("`@)'1I=&QE(#T@7R@B26UP
M;W)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y(BD["B`@("`@("`@)&EN<V5R
M=%]T97AT(#T@7R@B26YS97)T(%!E<G-O;F%L(%!U8FQI8R!01U`@2V5Y($AE
M<F4B*3L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=I;7!O<G1?<&5R<V]N
M86Q?<')I=F%T95]K97DG.@H@("`@("`@("1T:71L92`](%\H(DEM<&]R="!0
M97)S;VYA;"!0<FEV871E(%!'4"!+97DB*3L*("`@("`@("`D:6YS97)T7W1E
M>'0@/2!?*"));G-E<G0@4&5R<V]N86P@4')I=F%T92!01U`@2V5Y($AE<F4B
M*3L*("`@("`@("!B<F5A:SL*("`@('T*/SX*/&9O<FT@96YC='EP93TB;75L
M=&EP87)T+V9O<FTM9&%T82(@;65T:&]D/2)P;W-T(B!N86UE/2)I;7!O<G1?
M<&=P7VME>2(@86-T:6]N/2(\/W!H<"!E8VAO("1S96QF55),(#\^(CX*/#]P
M:'`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<U%U:7)K*"=B<F]K96Y?
M;75L=&EP87)T7V9O<FTG*2DZ(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](FUS:65?9F]R;61A=&%?:7-?8G)O:V5N(B!V86QU93TB(B`O/@H\/W!H
M<"!E;F1I9CL@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB<F5L;V%D
M(B!V86QU93TB/#]P:'`@96-H;R!5=&EL.CIG971&;W)M1&%T82@G<F5L;V%D
M)RD@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$
M(B!V86QU93TB/#]P:'`@96-H;R`D=&%R9V5T(#\^(B`O/@H\/W!H<"!5=&EL
M.CIP9F]R;4EN<'5T*"D[(#\^"@H\=&%B;&4@8F]R9&5R/2(P(B!C96QL<W!A
M8VEN9STB,"(@8V5L;'!A9&1I;F<](C(B('=I9'1H/2(Q,#`E(CX*(#QT<CX*
M("`\=&0@8VQA<W,](FAE861E<B!L969T06QI9VXB(&YO=W)A<#TB;F]W<F%P
M(CX\/W!H<"!E8VAO("1T:71L92`_/CPO=&0^"B`\+W1R/@H*(#QT<CX*("`\
M=&0@8VQA<W,](FET96T@;&5F=$%L:6=N(CX*("`@/'1A8FQE(&)O<F1E<CTB
M,"(@8V5L;'!A9&1I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@(#QT<CX*("`@
M("`\=&0@8VQA<W,](FET96T@;&5F=$%L:6=N(CX\<W1R;VYG/CP_<&AP(&5C
M:&\@)&EN<V5R=%]T97AT(#\^.CPO<W1R;VYG/CPO=&0^"B`@("`\+W1R/@H@
M("`@/'1R/@H@("`@(#QT9"!C;&%S<STB:71E;2!L969T06QI9VXB/@H@("`@
M("`\=&5X=&%R96$@;F%M93TB:6UP;W)T7VME>2(@<F]W<STB-B(@8V]L<STB
M.#`B(&-L87-S/2)F:7AE9"(^/"]T97AT87)E83X*("`@("`\+W1D/@H@("`@
M/"]T<CX*("`@/"]T86)L93X*("`\+W1D/@H@/"]T<CX*"B`\='(^"B`@/'1D
M(&-L87-S/2)I=&5M(&QE9G1!;&EG;B(^/&9O;G0@8V]L;W(](G)E9"(^/'-T
M<F]N9SXM+3P_<&AP(&5C:&\@7R@B3U(B*2`_/BTM/"]S=')O;F<^/"]F;VYT
M/CPO=&0^"B`\+W1R/@H*(#QT<CX*("`\=&0@8VQA<W,](FET96T@;&5F=$%L
M:6=N(CX*("`@/'1A8FQE(&)O<F1E<CTB,"(@8V5L;'!A9&1I;F<](C`B('=I
M9'1H/2(Q,#`E(CX*("`@(#QT<CX*("`@("`\=&0@8VQA<W,](FET96T@;&5F
M=$%L:6=N(CX*("`@("`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E5P;&]A9"(I
M(#\^.CPO<W1R;VYG/B9N8G-P.SQI;G!U="!N86UE/2)U<&QO861?:V5Y(B!T
M>7!E/2)F:6QE(B!S:7IE/2(T,"(@8VQA<W,](F9I>&5D(B`O/@H@("`@(#PO
M=&0^"B`@("`\+W1R/@H@("`\+W1A8FQE/@H@(#PO=&0^"B`\+W1R/@H*(#QT
M<CX*("`\=&0@;F]W<F%P/2)N;W=R87`B(&%L:6=N/2)C96YT97(B(&-L87-S
M/2)H96%D97(B('9A;&EG;CTB;6ED9&QE(CX*("`@/&EN<'5T('1Y<&4](G-U
M8FUI="(@;F%M93TB:6UP;W)T(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P
M:'`@96-H;R!?*"));7!O<G0@2V5Y(BD@/SXB("\^"B`@(#QI;G!U="!T>7!E
M/2)S=6)M:70B(&YA;64](FEM<&]R="(@8VQA<W,](F)U='1O;B(@;VYC;&EC
M:STB=VEN9&]W+F-L;W-E*"D[(B!V86QU93TB/#]P:'`@96-H;R!?*")#86YC
M96PB*2`_/B(@+SX*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*"CPO9F]R;3X*
M/"]B;V1Y/@H\+VAT;6P^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+W1E;7!L871E<R]P9W`O;F]T86-T:79E+FEN8P``````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,34V-0`Q,#0Q-S,V,C<V-@`P,C(T-S0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*("`D=7-E7W!G<%]L;V-K960@/2`D<')E9G,M/FES3&]C:V5D*"=U<V5?
M<&=P)RD["B`@:68@*"1U<V5?<&=P7VQO8VME9"DZ(#\^"CQS=')O;F<^/#]P
M:'`@96-H;R!?*")01U`@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y
M<W1E;2XB*2`_/CPO<W1R;VYG/@H\/W!H<"!E;'-E.B`_/@H\:6YP=70@='EP
M93TB8VAE8VMB;W@B(&ED/2)U<V5?<&=P(B!N86UE/2)U<V5?<&=P(CP_<&AP
M(&5C:&\@*"1P<F5F<RT^9V5T5F%L=64H)W5S95]P9W`G*2D@/R`G(&-H96-K
M960](F-H96-K960B)R`Z("<G(#\^("\^(#P_<&AP(&5C:&\@2&]R9&4Z.FQA
M8F5L*"=U<V5?<&=P)RP@7R@B16YA8FQE(%!'4"!F=6YC=&EO;F%L:71Y/R(I
M*2`_/B9N8G-P.SP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W!G<"UO
M=F5R=FEE=R<I(#\^/&)R("\^"CPO9&EV/@H\/W!H<"!E;F1I9CL@/SX*"CQB
M<B!C;&%S<STB<W!A8V5R(B`O/@H\9&EV(&-L87-S/2)N;W=R87`B/@H\/W!H
M<"!I9B`H(21U<V5?<&=P7VQO8VME9"DZ(#\^"B`@/&EN<'5T('1Y<&4](G-U
M8FUI="(@;F%M93TB<V%V92(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C
M=6UE;G0N<')E9G,N86-T:6]N240N=F%L=64])W!G<%]E;F%B;&4G.R!R971U
M<FX@=')U93LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-A=F4@3W!T:6]N<R(I
M(#\^(B`O/@H\/W!H<"!E;F1I9CL@/SX*("`\:6YP=70@='EP93TB8G5T=&]N
M(B!N86UE/2)B86-K(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N
M="YL;V-A=&EO;BYH<F5F/2<\/W!H<"!E8VAO($E-4#HZ<')E9G-54DPH=')U
M92D@/SXG(B!V86QU93TB/#]P:'`@96-H;R!?*")2971U<FX@=&\@3W!T:6]N
M<R(I(#\^(B`O/@H\+V1I=CX*"CPO9F]R;3X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]F971C:&UA:6PO````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P
M,C$Q-#<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+V9E
M=&-H;6%I;"]D<FEV97)?<V5L96-T+FEN8P``````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,C(U`#$P-#$W,S8R-S8V`#`R-#0W,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C
M<FEP="(^"CPA+2T*=F%R(&QO861I;F<["F9U;F-T:6]N(&1R:79E<E-U8FUI
M="@I"GL*("`@(&EF("AD;V-U;65N="YF;5]D<FEV97(N9FU?9')I=F5R6V1O
M8W5M96YT+F9M7V1R:79E<BYF;5]D<FEV97(N<V5L96-T961);F1E>%TN=F%L
M=64@(3T@)R<I('L*("`@("`@("!I9B`H;&]A9&EN9R`]/2!N=6QL*2!["B`@
M("`@("`@("`@(&QO861I;F<@/2!T<G5E.PH@("`@("`@("`@("!D;V-U;65N
M="YF;5]D<FEV97(N<W5B;6ET*"D["B`@("`@("`@?0H@("`@?0I]"B\O("TM
M/@H\+W-C<FEP=#X*"CP_<&AP(&5C:&\@7R@B36%I;"!S97)V97(@='EP92!T
M;R!C;VYN96-T('1O.B(I(#\^)FYB<W`[/&)R("\^"CQF;W)M(&YA;64](F9M
M7V1R:79E<B(@86-T:6]N/2(\/W!H<"!E8VAO("1F971C:%]U<FP@/SXB/@H\
M/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)F971C:&UA:6Q?8W)E871E(B`O
M/@H\<V5L96-T(&YA;64](F9M7V1R:79E<B(@;VYC:&%N9V4](FIA=F%S8W)I
M<'0Z9')I=F5R4W5B;6ET*"DB/@H@(#QO<'1I;VX@=F%L=64](B(^/#]P:'`@
M96-H;R!?*")396QE8W0@=&AE(&UA:6P@<V5R=F5R('1Y<&4B*2`_/CPO;W!T
M:6]N/@H\/W!H<"!F;W)E86-H("A)35!?1F5T8VAM86EL.CIL:7-T1')I=F5R
M<R@I(&%S("1K97D@/3X@)'9A;"DZ(#\^"B`@/&]P=&EO;B!V86QU93TB/#]P
M:'`@96-H;R`D:V5Y(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'9A;"D@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]S96QE
M8W0^"CPO9F]R;3X*/"]T9#X\+W1R/CPO=&%B;&4^/"]T9#X\+W1R/CPO=&%B
M;&4^"@H\8G(@+SX*/'1A8FQE(&)O<F1E<CTB,"(@86QI9VX](F-E;G1E<B(@
M=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(B!C96QL<&%D9&EN9STB,"(^
M/'1R/CQT9"!N;W=R87`](FYO=W)A<"(^"CQI;G!U="!T>7!E/2)B=71T;VXB
M(&YA;64](F)A8VLB(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F1O8W5M96YT
M+FQO8V%T:6]N+FAR968])SP_<&AP(&5C:&\@)'!R969S7W5R;"`_/B<B('9A
M;'5E/2(\/W!H<"!E8VAO(%\H(E)E='5R;B!T;R!&971C:"!-86EL(BD@/SXB
M("\^"CPO=&0^/"]T<CX\+W1A8FQE/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]T96UP;&%T97,O9F5T8VAM86EL+VUA;F%G92YI;F,`````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`R-C(`,3`T,3<S-C(W-C8`,#(S,#<P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QF
M;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB86-C;W5N=',B(&%C=&EO;CTB/#]P
M:'`@96-H;R`D9F5T8VA?=7)L(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U
M="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V
M86QU93TB9F5T8VAM86EL7W!R969?<V%V92(@+SX*/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB961I=%]A8V-O=6YT(B!V86QU93TB/#]P:'`@:68@*"%I
M<U]N=6QL*"1T;U]E9&ET*2D@96-H;R`D=&]?961I=#L@/SXB("\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](F9M7V1R:79E<B(@=F%L=64](CP_<&AP
M(&5C:&\@)&1R:79E<B`_/B(@+SX*"CP_<&AP(&5C:&\@7R@B06-C;W5N="=S
M(&YA;64Z(BD@/SX\8G(@+SX*/&EN<'5T(&YA;64](F9M7VED(B!S:7IE/2(S
M,"(@;6%X;&5N9W1H/2(V,"(@=F%L=64](CP_<&AP(&EF("@A:7-?;G5L;"@D
M=&]?961I="DI(&5C:&\@)&9M7V%C8V]U;G0M/F=E=%9A;'5E*"=I9"<L("1T
M;U]E9&ET*2`_/B(@+SX\8G(@+SX*"CP_<&AP(&5C:&\@7R@B4')O=&]C;VPZ
M(BD@/SX\8G(@+SX*/'-E;&5C="!N86UE/2)F;5]P<F]T;V-O;"(^"CP_<&AP
M(&9O<F5A8V@@*"1F971C:&UA:6PM/F=E=%!R;W1O8V]L3&ES="@I(&%S("1K
M97D@/3X@)'9A;"DZ(#\^"B`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D
M:V5Y(#\^(CP_<&AP(&EF("@A:7-?;G5L;"@D=&]?961I="D@)B8@*"1F;5]A
M8V-O=6YT+3YG971686QU92@G<')O=&]C;VPG+"`D=&]?961I="D@/3T@)&ME
M>2DI(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CX\/W!H<"!E8VAO
M("1V86P@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]S96QE
M8W0^/&)R("\^"@H\/W!H<"!E8VAO(%\H(E5S97)N86UE.B(I(#\^/&)R("\^
M"CQI;G!U="!N86UE/2)F;5]U<V5R;F%M92(@<VEZ93TB,S`B(&UA>&QE;F=T
M:#TB-C`B('9A;'5E/2(\/W!H<"!I9B`H(6ES7VYU;&PH)'1O7V5D:70I*2!E
M8VAO("1F;5]A8V-O=6YT+3YG971686QU92@G=7-E<FYA;64G+"`D=&]?961I
M="D@/SXB("\^/&)R("\^"@H\/W!H<"!E8VAO(%\H(E!A<W-W;W)D(BD@/SX\
M8G(@+SX*/&EN<'5T(&YA;64](F9M7W!A<W-W;W)D(B!S:7IE/2(S,"(@;6%X
M;&5N9W1H/2(V,"(@='EP93TB<&%S<W=O<F0B('9A;'5E/2(\/W!H<"!I9B`H
M(6ES7VYU;&PH)'1O7V5D:70I*2!E8VAO("1F;5]A8V-O=6YT+3YG971686QU
M92@G<&%S<W=O<F0G+"`D=&]?961I="D@/SXB("\^/&)R("\^"@H\/W!H<"!E
M8VAO(%\H(E-E<G9E<CHB*2`_/CQB<B`O/@H\:6YP=70@;F%M93TB9FU?<V5R
M=F5R(B!S:7IE/2(S,"(@;6%X;&5N9W1H/2(V,"(@=F%L=64](CP_<&AP(&EF
M("@A:7-?;G5L;"@D=&]?961I="DI(&5C:&\@)&9M7V%C8V]U;G0M/F=E=%9A
M;'5E*"=S97)V97(G+"`D=&]?961I="D@/SXB("\^/&)R("\^"@H\/W!H<"!I
M9B`H)&-O;F9;)W5S97(G75LG86QL;W=?9F]L9&5R<R==*3H@/SX*/#]P:'`@
M96-H;R!?*")296UO=&4@36%I;&)O>#HB*2`_/CQB<B`O/@H\:6YP=70@;F%M
M93TB9FU?<FUA:6QB;W@B('-I>F4](C,P(B!M87AL96YG=&@](C8P(B!V86QU
M93TB/#]P:'`@:68@*"%I<U]N=6QL*"1T;U]E9&ET*2D@96-H;R`D9FU?86-C
M;W5N="T^9V5T5F%L=64H)W)M86EL8F]X)RP@)'1O7V5D:70I(#\^(B`O/CQB
M<B`O/@H*/#]P:'`@96-H;R!?*"),;V-A;"!-86EL8F]X.B(I(#\^/&)R("\^
M"CQS96QE8W0@;F%M93TB9FU?;&UA:6QB;W@B/@H@(#P_<&AP(&5C:&\@24U0
M.CIF;&ES=%-E;&5C="@G)RP@9F%L<V4L(&%R<F%Y*"DL("%I<U]N=6QL*"1T
M;U]E9&ET*2`_("1F;5]A8V-O=6YT+3YG971686QU92@G;&UA:6QB;W@G+"`D
M=&]?961I="D@.B`G)RD@/SX*/"]S96QE8W0^/&)R("\^"CP_<&AP(&5N9&EF
M.R`_/@H*/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)F;5]O;FQY;F5W
M(B!V86QU93TB,2(\/W!H<"!I9B`H(6ES7VYU;&PH)'1O7V5D:70I("8F("1F
M;5]A8V-O=6YT+3YG971686QU92@G;VYL>6YE=R<L("1T;U]E9&ET*2D@96-H
M;R`G(&-H96-K960](F-H96-K960B)R`_/B`O/@H\/W!H<"!E8VAO(%\H(D=E
M="!O;FQY(&YE=R!M97-S86=E<S\@*$E-05`@;VYL>2DB*2`_/CQB<B`O/@H*
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)F;5]M87)K<V5E;B(@=F%L
M=64](C$B/#]P:'`@:68@*"%I<U]N=6QL*"1T;U]E9&ET*2`F)B`D9FU?86-C
M;W5N="T^9V5T5F%L=64H)VUA<FMS965N)RP@)'1O7V5D:70I*2!E8VAO("<@
M8VAE8VME9#TB8VAE8VME9"(G(#\^("\^"CP_<&AP(&5C:&\@7R@B36%R:R!M
M97-S86=E<R!A<R!S965N/R`H24U!4"!O;FQY*2(I(#\^/&)R("\^"@H\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](F9M7V1E;"(@=F%L=64](C$B/#]P
M:'`@:68@*"%I<U]N=6QL*"1T;U]E9&ET*2`F)B`D9FU?86-C;W5N="T^9V5T
M5F%L=64H)V1E;"<L("1T;U]E9&ET*2D@96-H;R`G(&-H96-K960](F-H96-K
M960B)R`_/B`O/@H\/W!H<"!E8VAO(%\H(D1E;&5T92!F971C:&5D(&UE<W-A
M9V5S(&9R;VT@<F5M;W1E('-E<G9E<C\B*2`_/CQB<B`O/@H*/&EN<'5T('1Y
M<&4](F-H96-K8F]X(B!N86UE/2)F;5]L;V=I;F9E=&-H(B!V86QU93TB,2(\
M/W!H<"!I9B`H(6ES7VYU;&PH)'1O7V5D:70I("8F("1F;5]A8V-O=6YT+3YG
M971686QU92@G;&]G:6YF971C:"<L("1T;U]E9&ET*2D@96-H;R`G(&-H96-K
M960](F-H96-K960B)R`_/B`O/@H\/W!H<"!E8VAO(%\H(D9E=&-H(&UE<W-A
M9V5S('5P;VX@;&]G9VEN9R!O;C\B*2`_/CQB<B`O/@H**#QF;VYT(&-O;&]R
M/2)R960B/CP_<&AP(&5C:&\@7R@B3D]412(I(#\^.CPO9F]N=#X@/#]P:'`@
M<')I;G1F*%\H(EEO=2!N965D('1O(&AA=F4@7"(E<UPB(&5N86)L960@:6X@
M>6]U<B!M86EN=&5N86YC92!O<'1I;VYS+B(I+"!?*")097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(BDI(#\^*0H*/#]P:'`@:68@
M*"1C;VYF6R=F971C:&UA:6PG75LG<VAO=U]A8V-O=6YT7V-O;&]R<R==*3H@
M/SX*/#]P:'`@96-H;R!?*")#;VQO<B!);F1I8V%T;W(Z("(I.R`_/CQB<B`O
M/@H\=&%B;&4^"B`@/'1R/@H\/W!H<"!F;W)E86-H("@D9FU?8V]L;W)S(&%S
M("1V86PI.B`_/@H@("`@/'1D(&)G8V]L;W(](CP_<&AP(&5C:&\@)'9A;"`_
M/B(^"B`@("`@(#QI;G!U="!T>7!E/2)R861I;R(@;F%M93TB9FU?86-C=&-O
M;&]R(B!V86QU93TB/#]P:'`@96-H;R`D=F%L(#\^(CP_<&AP(&EF("@A:7-?
M;G5L;"@D=&]?961I="D@)B8@)&9M7V%C8V]U;G0M/F=E=%9A;'5E*"=A8V-T
M8V]L;W(G+"`D=&]?961I="D@/3T@)'9A;"D@96-H;R`G(&-H96-K960](F-H
M96-K960B)R`_/B`O/@H@("`@/"]T9#X*/#]P:'`@96YD9F]R96%C:#L@/SX*
M("`\+W1R/@H\+W1A8FQE/@H\/W!H<"!E;F1I9CL@/SX*"CPO=&0^/"]T<CX\
M+W1A8FQE/CPO=&0^/"]T<CX\+W1A8FQE/@H*/&)R("\^"CQT86)L92!B;W)D
M97(](C`B(&%L:6=N/2)C96YT97(B('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN
M9STB,"(@8V5L;'!A9&1I;F<](C`B/CQT<CX\=&0@;F]W<F%P/2)N;W=R87`B
M/@H\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)S879E(B!C;&%S<STB8G5T
M=&]N(B!O;F-L:6-K/2)D;V-U;65N="YA8V-O=6YT<RYA8W1I;VY)1"YV86QU
M93TG9F5T8VAM86EL7W!R969S7W-A=F4G.W)E='5R;B!T<G5E(B!V86QU93TB
M/#]P:'`@96-H;R`H)&%C=&EO;DE$(#T]("=F971C:&UA:6Q?8W)E871E)RD@
M/R!?*")#<F5A=&4B*2`Z(%\H(E-A=F4B*2`_/B(@+SX*/&EN<'5T('1Y<&4]
M(G-U8FUI="(@;F%M93TB9&5L971E(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K
M/2)D;V-U;65N="YA8V-O=6YT<RYA8W1I;VY)1"YV86QU93TG9F5T8VAM86EL
M7W!R969S7V1E;&5T92<B('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1E;&5T92(I
M(#\^(B`O/@H\:6YP=70@='EP93TB8G5T=&]N(B!N86UE/2)B86-K(B!C;&%S
M<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N="YL;V-A=&EO;BYH<F5F/2<\
M/W!H<"!E8VAO("1P<F5F<U]U<FP@/SXG(B!V86QU93TB/#]P:'`@96-H;R!?
M*")2971U<FX@=&\@1F5T8V@@36%I;"(I(#\^(B`O/@H\:6YP=70@='EP93TB
M8G5T=&]N(B!N86UE/2)S96QE8W0B(&-L87-S/2)B=71T;VXB(&]N8VQI8VL]
M(F1O8W5M96YT+FQO8V%T:6]N+FAR968])SP_<&AP(&5C:&\@)&9E=&-H7W5R
M;"`_/B<B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-E;&5C="!!;F]T:&5R($%C
M8V]U;G0B*2`_/B(@+SX*/"]T9#X\+W1R/CPO=&%B;&4^"CPO9F]R;3X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+W1E;7!L871E<R]F971C:&UA:6PO86-C;W5N=%]S96QE8W0N:6YC````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C,U-P`Q,#0Q-S,V,C<V-@`P,C0V-#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"G9A<B!L;V%D:6YG.PIF=6YC=&EO
M;B!A8V-O=6YT4W5B;6ET*&ES;F5W*0I["B`@("!I9B`H*&ES;F5W("$](&YU
M;&PI('Q\("AD;V-U;65N="YF;5]S=VET8V@N86-C;W5N=%MD;V-U;65N="YF
M;5]S=VET8V@N86-C;W5N="YS96QE8W1E9$EN9&5X72YV86QU92`A/2`G)RDI
M('L*("`@("`@("!I9B`H;&]A9&EN9R`]/2!N=6QL*2!["B`@("`@("`@("`@
M(&QO861I;F<@/2!T<G5E.PH@("`@("`@("`@("!D;V-U;65N="YF;5]S=VET
M8V@N<W5B;6ET*"D["B`@("`@("`@?0H@("`@?0I]"B\O("TM/@H\+W-C<FEP
M=#X*"CP_<&AP(&5C:&\@7R@B66]U<B!A8V-O=6YT<SHB*2`_/B9N8G-P.SQB
M<B`O/@H\9F]R;2!N86UE/2)F;5]S=VET8V@B(&%C=&EO;CTB/#]P:'`@96-H
M;R`D9F5T8VA?=7)L(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^
M"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB
M9F5T8VAM86EL7W!R969S7V5D:70B("\^"CQS96QE8W0@;F%M93TB86-C;W5N
M="(@;VYC:&%N9V4](FIA=F%S8W)I<'0Z86-C;W5N=%-U8FUI="@I(CX*("`\
M;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B4V5L96-T(&%N(&%C8V]U
M;G0B*2`_/CPO;W!T:6]N/@H\/W!H<"!F;W(@*"1I(#T@,"P@)&E-87@@/2!C
M;W5N="@D86-C;W5N=',I.R`D:2`\("1I36%X.R`D:2LK*3H@/SX*("`\;W!T
M:6]N('9A;'5E/2(\/W!H<"!E8VAO("1I(#\^(CX\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&%C8V]U;G1S6R1I72D@/SX\+V]P=&EO;CX*/#]P:'`@
M96YD9F]R.R`_/@H\+W-E;&5C=#X@/#]P:'`@96-H;R!?*")O<B(I(#\^"CQI
M;G!U="!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F1O
M8W5M96YT+F9M7W-W:71C:"YA8W1I;VY)1"YV86QU93TG9F5T8VAM86EL7V-R
M96%T92<[86-C;W5N=%-U8FUI="AT<G5E*3MR971U<FX@=')U93LB('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(D-R96%T92!A($YE=R!!8V-O=6YT(BD@/SXB("\^
M"CPO9F]R;3X*/"]T9#X\+W1R/CPO=&%B;&4^/"]T9#X\+W1R/CPO=&%B;&4^
M"@H\<#X*(#QI;G!U="!T>7!E/2)B=71T;VXB(&YA;64](F)A8VLB(&-L87-S
M/2)B=71T;VXB(&]N8VQI8VL](F1O8W5M96YT+FQO8V%T:6]N+FAR968])SP_
M<&AP(&5C:&\@)'!R969S7W5R;"`_/B<B('9A;'5E/2(\/W!H<"!E8VAO(%\H
M(E)E='5R;B!T;R!&971C:"!-86EL(BD@/SXB("\^"CPO<#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+V9E=&-H;6%I;"]T
M;W`N:6YC````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#,P`#$P-#$W
M,S8R-S8V`#`R,C0S-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\9&EV(&-L87-S/2)H96%D97(B/@H@(#P_<&AP(%!R969S
M7U5).CIG96YE<F%T94YA=FEG871I;VY#96QL*"=F971C:&UA:6PG*2`_/@H@
M(#P_<&AP(&5C:&\@7R@B3W1H97(@36%I;"!!8V-O=6YT<R(I(#\^"CPO9&EV
M/@H\=&%B;&4@8F]R9&5R/2(P(B!A;&EG;CTB8V5N=&5R(B!W:61T:#TB,3`P
M)2(@8V5L;'-P86-I;F<](C`B(&-E;&QP861D:6YG/2(S(CX*/'1R/CQT9"!C
M;&%S<STB:71E;2(^/'1A8FQE(&)O<F1E<CTB,"(^/'1R('9A;&EG;CTB=&]P
M(CX\=&0@8VQA<W,](FET96TB/@H*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+W1E;7!L871E<R]F971C:&UA:6PO9F5T8VAM86EL+FEN
M8P`````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`P-@`Q,#0Q-S,V,C<V-@`P,C,U
M-S$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&9O<FT@;F%M93TB9FU?<&5R9F]R;2(@86-T:6]N/2(\/W!H<"!E8VAO("1F
M971C:%]U<FP@/SXB/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)F971C
M:&UA:6Q?9F5T8V@B("\^"@H\:#$@8VQA<W,](FAE861E<B(^"B`@/#]P:'`@
M96-H;R!?*")/=&AE<B!-86EL($%C8V]U;G1S(BD@/SX*/"]H,3X*/&1I=B!C
M;&%S<STB:71E;2(^"CP_<&AP(&EF("@D86-C;W5N=',I.B`_/@H@(#P_<&AP
M(&5C:&\@7R@B0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@=V%N="!T;R!F
M971C:"!M86EL(&9R;VTZ(BD@/SXF;F)S<#L\8G(@+SX*"B`@/'5L/@H\/W!H
M<"!F;W)E86-H("@D86-C;W5N=',@87,@)&ME>2`]/B`D=F%L*3H@/SX*("`@
M(#QL:3X*("`@("`@/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)A8V-O
M=6YT<UM=(B!C:&5C:V5D/2)C:&5C:V5D(B!V86QU93TB/#]P:'`@96-H;R`D
M:V5Y(#\^(B`O/@H@("`@("`\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&9M7V%C8V]U;G0M/F=E=%9A;'5E*"=I9"<L("1K97DI*2`_/@H@("`@/"]L
M:3X*/#]P:'`@96YD9F]R96%C:#L@/SX*("`\+W5L/@H\/W!H<"!E;'-E.B`_
M/@H@(#P_<&AP(&5C:&\@7R@B0VAE8VL@86QL(&UA:6P@<V5R=F5R<R!Y;W4@
M=V%N="!T;R!F971C:"!M86EL(&9R;VTZ(BD@/SXF;F)S<#L\8G(@+SX*/#]P
M:'`@96YD:68[(#\^"CPO9&EV/@H\9&EV(&-L87-S/2)N;W=R87`B/@H\/W!H
M<"!I9B`H)&%C8V]U;G1S*3H@/SX*("`\:6YP=70@='EP93TB<W5B;6ET(B!N
M86UE/2)F971C:"(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@
M7R@B1F5T8V@@36%I;"(I(#\^(B`O/@H\/W!H<"!E;F1I9CL@/SX*("`\:6YP
M=70@='EP93TB8G5T=&]N(B!N86UE/2)B86-K(B!C;&%S<STB8G5T=&]N(B!O
M;F-L:6-K/2(\/W!H<"!E8VAO("1C86YC96Q?:G,@/SXB('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(D-L;W-E(BD@/SXB("\^"CPO9&EV/@H\+V9O<FT^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S
M+V%C;"\`````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S8V`#`Q-S<U,@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]T96UP;&%T97,O86-L+V%C;"YI;F,`````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3,V-C(`,3`T,3<S-C(W-C8`,#(Q,C$Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QS8W)I
M<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H\/W!H<"!I9B`H:7-S
M970H)&IS7W)I9VAT*2DZ(#\^"G9A<B!U<V5R<R`](&YE=R!!<G)A>2@\/W!H
M<"!E8VAO("1J<U]U<V5R(#\^*3L*"CP_<&AP(&9O<F5A8V@@*"1J<U]R:6=H
M="!A<R`D:V5Y(#T^("1V86PI.B`_/@IV87(@/#]P:'`@96-H;R`D:V5Y(#\^
M(#T@;F5W($%R<F%Y*#P_<&AP(&5C:&\@)'9A;"`_/BD["CP_<&AP(&5N9&9O
M<F5A8V@[(#\^"CP_<&AP(&5N9&EF.R`_/@H*9G5N8W1I;VX@<V5L96-T4G5L
M92AN=6TI"GL*/#]P:'`@:68@*"1C86Y%9&ET*3H@/SX*("`@(&EF("AN=6T@
M/3T@/#]P:'`@96-H;R!C;W5N="@D8W5R<E]A8VPI(#\^*2!["B`@("`@("`@
M<F5S971&;W)M*"D["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M96YT+F%C
M;"YS:&%R95]U<V5R+G9A;'5E(#T@=7-E<G-;;G5M73L*("`@("`@("!D;V-U
M;65N="YA8VPN<VAA<F5?=7-E<BYD:7-A8FQE9"`]('1R=64["CP_<&AP(&EF
M("@A96UP='DH)&IS7W)I9VAT*2DZ(#\^"CP_<&AP(&9O<F5A8V@@*"1J<U]R
M:6=H="!A<R`D:V5Y(#T^("1V86PI.B`_/@H@("`@("`@(&EF("@\/W!H<"!E
M8VAO("1K97D@/SY;;G5M72`^(#`I('L*("`@("`@("`@("`@9&]C=6UE;G0N
M86-L+F5L96UE;G1S6R=A8VQ;/#]P:'`@96-H;R`D:V5Y(#\^72==+F-H96-K
M960@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&1O8W5M
M96YT+F%C;"YE;&5M96YT<ULG86-L6SP_<&AP(&5C:&\@)&ME>2`_/ETG72YC
M:&5C:V5D(#T@9F%L<V4["B`@("`@("`@?0H\/W!H<"!E;F1F;W)E86-H.R`_
M/@H\/W!H<"!E;F1I9CL@/SX*("`@("`@("!D;V-U;65N="YA8VPN86-T:6]N
M240N=F%L=64@/2`G:6UP7V%C;%]E9&ET)SL*("`@("`@("!D;V-U;65N="YA
M8VPN9F)U='1O;BYV86QU92`]("<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M36]D:69Y(BDI(#\^)SL*("`@('T*/#]P:'`@96YD:68[(#\^"GT*"F9U;F-T
M:6]N(')E<V5T1F]R;2@I"GL*("`@(&1O8W5M96YT+F%C;"YR97-E="@I.PH@
M("`@9&]C=6UE;G0N86-L+G-H87)E7W5S97(N9&ES86)L960@/2!F86QS93L*
M("`@(&1O8W5M96YT+F%C;"YA8W1I;VY)1"YV86QU92`]("=I;7!?86-L7W-E
M="<["B`@("!D;V-U;65N="YA8VPN9F)U='1O;BYV86QU92`]("<\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B0W)E871E(BDI(#\^)SL*("`@(&EF("AD;V-U
M;65N="YA8VPN;G5M8F5R*2!["B`@("`@("`@9F]R("AV87(@:2`](#`[(&D@
M/"!D;V-U;65N="YA8VPN;G5M8F5R+FQE;F=T:"`M,2`[(&DK*RD@>PH@("`@
M("`@("`@("!D;V-U;65N="YA8VPN;G5M8F5R6VE=+F-H96-K960@/2!F86QS
M93L*("`@("`@("!]"B`@("!]"GT*"G9A<B!L;V%D:6YG.PIF=6YC=&EO;B!!
M0TQ&;VQD97)#:&%N9V4H8VQE87(I"GL*("`@(&EF("AD;V-U;65N="YF;VQD
M97)S+F9O;&1E<EMD;V-U;65N="YF;VQD97)S+F9O;&1E<BYS96QE8W1E9$EN
M9&5X72YV86QU92`A/2`G)RD@>PH@("`@("`@(&EF("AL;V%D:6YG(#T](&YU
M;&P@?'P@8VQE87(@(3T@;G5L;"D@>PH@("`@("`@("`@("!L;V%D:6YG(#T@
M=')U93L*("`@("`@("`@("`@9&ES86)L94)U='1O;G,H*3L*("`@("`@("`@
M("`@9&]C=6UE;G0N9F]L9&5R<RYS=6)M:70H*3L*("`@("`@("!]"B`@("!]
M"GT*"F9U;F-T:6]N(&1I<V%B;&5"=71T;VYS*"D@>PH@("`@:68@*&1O8W5M
M96YT+F%C;"YF8G5T=&]N*2!["B`@("`@("`@9&]C=6UE;G0N86-L+F9B=71T
M;VXN9&ES86)L960@/2!T<G5E.PH@("`@?0H@("`@:68@*&1O8W5M96YT+F%C
M;"YR97-E=&)U="D@>PH@("`@("`@(&1O8W5M96YT+F%C;"YR97-E=&)U="YD
M:7-A8FQE9"`]('1R=64["B`@("!]"B`@("!I9B`H9&]C=6UE;G0N86-L+F)A
M8VLI('L*("`@("`@("!D;V-U;65N="YA8VPN8F%C:RYD:7-A8FQE9"`]('1R
M=64["B`@("!]"B`@("!I9B`H9&]C=6UE;G0N86-L+FYU;6)E<BD@>PH@("`@
M("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@9&]C=6UE;G0N86-L+FYU;6)E<BYL
M96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!D;V-U;65N="YA8VPN;G5M8F5R
M6VE=+F1I<V%B;&5D(#T@=')U93L*("`@("`@("!]"B`@("!]"B`@("!R971U
M<FX@=')U93L*?0H*"B\O("TM/@H\+W-C<FEP=#X*"CQF;W)M(&UE=&AO9#TB
M<&]S="(@;F%M93TB9F]L9&5R<R(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G86-L+G!H<"<I(#\^(CX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2(B("\^"CP_<&AP(%5T
M:6PZ.G!F;W)M26YP=70H*2`_/@H\9&EV(&-L87-S/2)H96%D97(B/@H@(#P_
M<&AP(%!R969S7U5).CIG96YE<F%T94YA=FEG871I;VY#96QL*"=A8VPG*2`_
M/@H@(#P_<&AP(&5C:&\@7R@B4VAA<F4@;6%I;"!F;VQD97)S(BD@/SX*/"]D
M:78^"@H\9&EV(&-L87-S/2)H96%D97(B/@H@(#QU;#X*("`@(#QL:3X*("`@
M("`@/#]P:'`@96-H;R!(;W)D93HZ;&EN:R@G(R<L(%\H(D-H86YG92!&;VQD
M97(B*2P@)W-M86QL:&5A9&5R)RP@)R<L("=!0TQ&;VQD97)#:&%N9V4H=')U
M92D[(')E='5R;B!F86QS93LG*2`_/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G
M<VAA<F5D+G!N9R<L(%\H(D-H86YG92!&;VQD97(B*2D@/SX\+V$^/'-E;&5C
M="!N86UE/2)F;VQD97(B(&]N8VAA;F=E/2)!0TQ&;VQD97)#:&%N9V4H*2(^
M/#]P:'`@96-H;R`D;W!T:6]N<R`_/CPO<V5L96-T/B9N8G-P.PH@("`@/"]L
M:3X*("`\+W5L/@H@(#P_<&AP('!R:6YT9BA?*")#=7)R96YT(&%C8V5S<R!T
M;R`E<R(I+"!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1F;VQD97(L("=55$8W
M+4E-05`G*2D@/SX*/"]D:78^"CPO9F]R;3X*"CQF;W)M(&UE=&AO9#TB<&]S
M="(@;F%M93TB86-L(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=A8VPN<&AP)RD@/SXB/@H@(#QI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB:6UP7V%C;%]S970B("\^"B`@
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB9F]L9&5R(B!V86QU93TB/#]P
M:'`@96-H;R`D9F]L9&5R(#\^(B`O/@H@(#P_<&AP(%5T:6PZ.G!F;W)M26YP
M=70H*2`_/@H\=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*
M/#]P:'`@:68@*"%C;W5N="@D8W5R<E]A8VPI*3H@/SX*("`\='(^"B`@("`\
M=&0@8V]L<W!A;CTB,B(@8VQA<W,](FET96T@;&5F=$%L:6=N(CX*("`@("`@
M/&5M/CQS=')O;F<^)FYB<W`[/#]P:'`@96-H;R!?*")4:&4@8W5R<F5N="!L
M:7-T(&]F('5S97)S('=I=&@@86-C97-S('1O('1H:7,@9F]L9&5R(&-O=6QD
M(&YO="!B92!R971R:65V960B*2`_/CPO<W1R;VYG/CPO96T^"B`@("`\+W1D
M/@H@(#PO='(^"CP_<&AP(&5L<V4Z(#\^"CP_<&AP("1I(#T@,3L@9F]R96%C
M:"`H)&-U<G)?86-L(&%S("1I;F1E>"`]/B`D<G5L92DZ(#\^"B`@/'1R/@H@
M("`@/'1D(&-L87-S/2)L:6=H="!R:6=H=$%L:6=N(CX*("`@("`@/'-T<F]N
M9SX\/W!H<"!E8VAO("1I*RL@/SXF;F)S<#L\+W-T<F]N9SX*("`@(#PO=&0^
M/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG;B(^"B`@("`@(#QI;G!U="!C;&%S
M<STB:71E;2(@='EP93TB<F%D:6\B(&YA;64](FYU;6)E<B(@=F%L=64](CP_
M<&AP(&5C:&\@)&DM,B`_/B(@/#]P:'`@:68@*&EN7V%R<F%Y*"1I;F1E>"P@
M)'!R;W1E8W1E9"DI(&5C:&\@)V1I<V%B;&5D("<@/SYO;F-L:6-K/2)S96QE
M8W12=6QE*#P_<&AP(&5C:&\@)&D@+2`R(#\^*2(@+SXF;F)S<#LF;F)S<#L*
M("`@("`@/'-T<F]N9SX\/W!H<"!E8VAO("1I;F1E>"`_/CPO<W1R;VYG/B9N
M8G-P.R9N8G-P.PH@("`@/#]P:'`@9F]R96%C:"`H)')U;&4@87,@)&ME>2`]
M/B`D=F%L*3H@/SX\/W!H<"!E8VAO("1K97D@/SXL)FYB<W`[/#]P:'`@96YD
M9F]R96%C:#L@/SX*("`@(#PO=&0^"B`@/"]T<CX*/#]P:'`@96YD9F]R96%C
M:#L@/SX*("`\='(^"B`@("`\=&0@8VQA<W,](FQI9VAT(')I9VAT06QI9VXB
M/@H@("`@("`\<W1R;VYG/CP_<&AP(&5C:&\@7R@B3F5W(BD@/SXF;F)S<#L\
M+W-T<F]N9SX*("`@(#PO=&0^/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG;B(^
M"B`@("`@(#QI;G!U="!C;&%S<STB:71E;2(@='EP93TB<F%D:6\B(&-H96-K
M960@;F%M93TB;G5M8F5R(B!V86QU93TB/#]P:'`@96-H;R`D:2`M(#$@/SXB
M(&]N8VQI8VL](G-E;&5C=%)U;&4H/#]P:'`@96-H;R`D:2`M(#$@/SXI(B`O
M/B9N8G-P.R9N8G-P.PH@("`@/"]T9#X*("`\+W1R/@H\/W!H<"!E;F1I9CL@
M/SX*"B`@/'1R/@H@("`@/'1D/B9N8G-P.SPO=&0^"B`@/"]T<CX*("`\='(^
M"B`@("`\=&0@8V]L<W!A;CTB,B(@8VQA<W,](FAE861E<B(^"B`@("`@(#QS
M<&%N(&-L87-S/2)S;6%L;&AE861E<B(^/#]P:'`@96-H;R!?*")'<F%N="!A
M8V-E<W,B*2`_/CPO<W!A;CX*("`@(#PO=&0^"B`@/"]T<CX*"CP_<&AP(&EF
M("@D8V%N161I="DZ(#\^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)L:6=H="!R
M:6=H=$%L:6=N(CX*("`@("`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E5S97(B
M*2`_/B9N8G-P.SPO<W1R;VYG/@H@("`@/"]T9#X\=&0@8VQA<W,](FET96T@
M;&5F=$%L:6=N(CX*("`@("`@)FYB<W`[/&EN<'5T(&-L87-S/2)F:7AE9"(@
M='EP93TB=&5X="(@;F%M93TB<VAA<F5?=7-E<B(@+SX*("`@(#PO=&0^"B`@
M/"]T<CX*/#]P:'`@9F]R96%C:"`H)')I9VAT<R!A<R`D<FEG:'0@/3X@)&1E
M<V,I.B`_/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!;&EG
M;B(^"B`@("`@(#QS=')O;F<^/#]P:'`@96-H;R`D<FEG:'0@/SXF;F)S<#LZ
M)FYB<W`[/"]S=')O;F<^"B`@("`\+W1D/CQT9"!C;&%S<STB:71E;2!L969T
M06QI9VXB/@H@("`@("`\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F%C
M;%L\/W!H<"!E8VAO("1R:6=H="`_/ETB("\^"B`@("`F;F)S<#L\/W!H<"!E
M8VAO("1D97-C(#\^"B`@("`\+W1D/@H@(#PO='(^"CP_<&AP(&5N9&9O<F5A
M8V@[(#\^"B`@/'1R/@H@("`@/'1D/B9N8G-P.SPO=&0^"B`@("`\=&0@8VQA
M<W,](FAE861E<B(@=F%L:6=N/2)M:61D;&4B/@H@("`@("`\:6YP=70@='EP
M93TB8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!N86UE/2)F8G5T=&]N(B!O;F-L
M:6-K/2)D:7-A8FQE0G5T=&]N<R@I.R!D;V-U;65N="YA8VPN<VAA<F5?=7-E
M<BYD:7-A8FQE9"`](&9A;'-E.R!D;V-U;65N="YA8VPN<W5B;6ET*"D[(B!V
M86QU93TB/#]P:'`@96-H;R!?*")#<F5A=&4B*2`_/B(@+SX*("`@("`@/&EN
M<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@;F%M93TB<F5S971B
M=70B(&]N8VQI8VL](G)E<V5T1F]R;2@I(B!V86QU93TB/#]P:'`@96-H;R!?
M*")297-E="(I(#\^(B`O/@H@("`@("`\:6YP=70@='EP93TB8G5T=&]N(B!C
M;&%S<STB8G5T=&]N(B!N86UE/2)B86-K(B!O;F-L:6-K/2)D:7-A8FQE0G5T
M=&]N<R@I.R!D;V-U;65N="YL;V-A=&EO;BYH<F5F/2<\/W!H<"!E8VAO("1P
M<F5F<U]U<FP@/SXG(B!V86QU93TB/#]P:'`@96-H;R!?*")2971U<FX@=&\@
M3W!T:6]N<R(I(#\^(B`O/@H@("`@/"]T9#X*("`\+W1R/@H*/#]P:'`@96QS
M93H@/SX*("`\='(^"B`@("`\=&0@8V]L<W!A;CTB,B(@8VQA<W,](FET96T@
M;&5F=$%L:6=N(CX*("`@("`@/&5M/CQS=')O;F<^)FYB<W`[/#]P:'`@96-H
M;R!?*")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!C:&%N9V4@86-C
M97-S('1O('1H:7,@9F]L9&5R(BD@/SX\+W-T<F]N9SX\+V5M/@H@("`@/"]T
M9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!C;VQS<&%N/2(R(B!C;&%S<STB
M:&5A9&5R(B!V86QI9VX](FUI9&1L92(^"B`@("`@(#QI;G!U="!T>7!E/2)B
M=71T;VXB(&-L87-S/2)B=71T;VXB(&YA;64](F)A8VLB(&]N8VQI8VL](F1I
M<V%B;&5"=71T;VYS*"D[(&1O8W5M96YT+FQO8V%T:6]N+FAR968])SP_<&AP
M(&5C:&\@)'!R969S7W5R;"`_/B<B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E
M='5R;B!T;R!/<'1I;VYS(BD@/SXB("\^"B`@("`\+W1D/@H@(#PO='(^"CP_
M<&AP(&5N9&EF.R`_/@H\+W1A8FQE/@H\+V9O<FT^"@``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+W1E;7!L871E<R]C;VUP;W-E+P``````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,C`V-C``(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+V-O;7!O<V4O871T86-H
M;65N=',N:6YC````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#,T`#$P-#$W,S8R
M-S8V`#`R,S8V-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\='(^"B`@/'1D(&-L87-S/2)L969T06QI9VXB/CQI;6<@<W)C
M/2(\/W!H<"!E8VAO("1V:65W97(M/F=E=$EC;VXH)&UI;64M/F=E=%1Y<&4H
M*2D@/SXB(&AE:6=H=#TB,38B('=I9'1H/2(Q-B(@8F]R9&5R/2(P(B!A;'0]
M(EM)8V]N72(@+SXF;F)S<#L\+W1D/@H@(#QT9"!C;&%S<STB;&5F=$%L:6=N
M(CX\<W1R;VYG/CP_<&AP(&5C:&\@*"1F:6QE7VYU;2D@/SXN(#P_<&AP(&5C
M:&\@)&UI;64M/F=E=$YA;64H=')U92P@=')U92D@/SX\+W-T<F]N9SXF;F)S
M<#LF;F)S<#LH/#]P:'`@96-H;R`D;6EM92T^9V5T5'EP92@I(#\^*29N8G-P
M.R9N8G-P.R9N8G-P.SQS=')O;F<^/#]P:'`@96-H;R!?*")3:7IE(BD@/SXZ
M/"]S=')O;F<^)FYB<W`[/#]P:'`@96-H;R`D;6EM92T^9V5T4VEZ92@I(#\^
M($M"/#]P:'`@:68@*&ES<V5T*"1P<F5V:65W7W5R;"DI.B`_/B9N8G-P.R9N
M8G-P.R9N8G-P.UL\/W!H<"!E8VAO($AO<F1E.CIL:6YK*"1P<F5V:65W7W5R
M;"P@7R@B4')E=FEE=R(I("X@)R`G("X@)&UI;64M/F=E=$YA;64H*2P@)VQI
M;FLG+"`G8V]M<&]S95]P<F5V:65W7W=I;F1O=R<I("X@7R@B4')E=FEE=R(I
M(#\^/"]A/ET\/W!H<"!E;F1I9CL@/SX\+W1D/@H\+W1R/@H*/'1R/@H@(#QT
M9#XF;F)S<#L\+W1D/@H@(#QT9#X*("`@(#QT86)L92!B;W)D97(](C`B('=I
M9'1H/2(Q,#`E(B!C96QL<&%D9&EN9STB,"(^"B`@("`@(#QT<CX*("`@("`@
M("`\=&0@8VQA<W,](FQE9G1!;&EG;B(@=F%L:6=N/2)M:61D;&4B/CQS=')O
M;F<^/#]P:'`@96-H;R!?*")$:7-P;W-I=&EO;B(I(#\^.CPO<W1R;VYG/B9N
M8G-P.SPO=&0^"B`@("`@("`@/'1D(&-L87-S/2)L969T06QI9VXB/@H@("`@
M("`@("`@/'-E;&5C="!N86UE/2)F:6QE7V1I<W!O<VET:6]N7SP_<&AP(&5C
M:&\@)&9I;&5?;G5M(#\^(CX*("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M871T86-H;65N="(\/W!H<"!I9B`H)&1I<W!O<VET:6]N(#T]("=A='1A8VAM
M96YT)RD@96-H;R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^/CP_<&AP(&5C
M:&\@7R@B071T86-H;65N="(I(#\^/"]O<'1I;VX^"B`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64](FEN;&EN92(\/W!H<"!I9B`H)&1I<W!O<VET:6]N(#T]
M("=I;FQI;F4G*2!E8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P
M:'`@96-H;R!?*"));FQI;F4B*2`_/CPO;W!T:6]N/@H@("`@("`@("`@/"]S
M96QE8W0^"B`@("`@("`@/"]T9#X*("`@("`@/"]T<CX*"B`@("`@(#QT<CX*
M("`@("`@("`\=&0@8VQA<W,](FQE9G1!;&EG;B(@=F%L:6=N/2)M:61D;&4B
M/CQS=')O;F<^/#]P:'`@96-H;R!?*")$97-C<FEP=&EO;B(I(#\^.CPO<W1R
M;VYG/B9N8G-P.SPO=&0^"B`@("`@("`@/'1D(&-L87-S/2)L969T06QI9VXB
M/@H@("`@("`@("`@/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C0P(B!N86UE
M/2)F:6QE7V1E<V-R:7!T:6]N7SP_<&AP(&5C:&\@)&9I;&5?;G5M(#\^(B!V
M86QU93TB/#]P:'`@96-H;R`D;6EM92T^9V5T1&5S8W)I<'1I;VXH*2`_/B(@
M+SX*("`@("`@("`\+W1D/@H@("`@("`\+W1R/@H*("`@("`@/'1R/@H@("`@
M("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N(B!V86QI9VX](FUI9&1L92(^/'-T
M<F]N9SX\/W!H<"!E8VAO(%\H(D1E;&5T92(I(#\^/SPO<W1R;VYG/B9N8G-P
M.SPO=&0^"B`@("`@("`@/'1D(&-L87-S/2)L969T06QI9VXB/CQI;G!U="!T
M>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5L871T86-H;65N='-;72(@=F%L=64]
M(CP_<&AP(&5C:&\@)&9I;&5?;G5M(#\^(B`O/CPO=&0^"B`@("`@(#PO='(^
M"B`@("`\+W1A8FQE/@H@(#PO=&0^"CPO='(^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:6YC
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W,C0T,``Q,#0Q-S,V,C<V-@`P
M,C,P,C0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`@)'1A8FEN9&5X(#T@,2`_/@H*/#]P:'`@:68@*"1P<F5F<RT^
M9V5T5F%L=64H)V%U=&]?97AP86YD)RDI.B`_/@H\:69R86UE(&ED/2)A=71O
M97AP86YD(B!N86UE/2)A=71O97AP86YD(B!S='EL93TB=VED=&@Z,#MH96EG
M:'0Z,#MB;W)D97(M=VED=&@Z,"(@<W)C/2(\/W!H<"!E8VAO($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G97AP86YD+G!H<"<I(#\^(CX\+VEF<F%M93X*/#]P
M:'`@96YD:68[(#\^"@H\9F]R;2!M971H;V0](G!O<W0B(&YA;64](F-O;7!O
M<V4B/#]P:'`@:68@*"1I;7!;)V9I;&5?=7!L;V%D)UTI(&5C:&\@)R!E;F-T
M>7!E/2)M=6QT:7!A<G0O9F]R;2UD871A(B<[(#\^(&%C=&EO;CTB/#]P:'`@
M96-H;R!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G5R;"@G8V]M<&]S92YP
M:'`G*2P@)W5N:7$G+"!B87-E7V-O;G9E<G0H;6EC<F]T:6UE*"DL(#$P+"`S
M-BDI(#\^(CX*/#]P:'`@:68@*"1I;7!;)V9I;&5?=7!L;V%D)UTI.B`_/@H\
M/W!H<"!I9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=B<F]K96Y?;75L=&EP87)T
M7V9O<FTG*2DZ(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FUS:65?
M9F]R;61A=&%?:7-?8G)O:V5N(B!V86QU93TB(B`O/@H\/W!H<"!E;F1I9CL@
M/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB34%87T9)3$5?4TE:12(@
M=F%L=64](CP_<&AP(&5C:&\@)&EM<%LG9FEL95]U<&QO860G72`_/B(@+SX*
M/#]P:'`@96YD:68[(#\^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](B(@
M+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB7U]F;W)M5&]K96Y?8V]M
M<&]S92(@=F%L=64](CP_<&AP(&5C:&\@2&]R9&5?5&]K96XZ.F=E;F5R871E
M260H)V-O;7!O<V4G*3L@/SXB("\^"CP_<&AP(&EF("AI<W-E="@D;65S<V%G
M94-A8VAE240I*3H@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB;65S
M<V%G94-A8VAE(B!V86QU93TB/#]P:'`@96-H;R`D;65S<V%G94-A8VAE240@
M/SXB("\^"CP_<&AP(&5N9&EF.R`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)S<&5L;&-H96-K(B!V86QU93TB(B`O/@H\:6YP=70@='EP93TB:&ED
M9&5N(B!N86UE/2)P86=E(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*%5T:6PZ.F=E=$9O<FU$871A*"=P86=E)RDI(#\^(B`O/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)S=&%R="(@=F%L=64](CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG971&;W)M1&%T82@G<W1A<G0G
M*2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G!O<'5P(B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F=E=$9O
M<FU$871A*"=P;W!U<"<I*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB=&AI<VUA:6QB;W@B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H571I;#HZ9V5T1F]R;41A=&$H)W1H:7-M86EL8F]X)RDI(#\^
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A='1A8VAM96YT06-T
M:6]N(B!V86QU93TB(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)R
M96QO861E9"(@=F%L=64](C$B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](F]L9')T96UO9&4B('9A;'5E/2(\/W!H<"!E8VAO("1R=&5M;V1E(#\^
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)R=&5M;V1E(B!V86QU
M93TB/#]P:'`@96-H;R`D<G1E;6]D92`_/B(@+SX*/#]P:'`*("`@(&EF("@A
M*"1R97!L>5]T>7!E(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E<&QY7W1Y<&4G
M*2DI('L*("`@("`@("!S=VET8V@@*"1A8W1I;VY)1"D@>PH@("`@("`@(&-A
M<V4@)W)E<&QY)SH*("`@("`@("!C87-E("=R97!L>5]A;&PG.@H@("`@("`@
M(&-A<V4@)W)E<&QY7VQI<W0G.@H@("`@("`@("`@("`D<F5P;'E?='EP92`]
M("=R97!L>2<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=F
M;W)W87)D)SH*("`@("`@("`@("`@)')E<&QY7W1Y<&4@/2`G9F]R=V%R9"<[
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*/SX*/#]P:'`@
M:68@*"1R97!L>5]T>7!E*3H@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB<F5P;'E?='EP92(@=F%L=64](CP_<&AP(&5C:&\@)')E<&QY7W1Y<&4@
M/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEN7W)E<&QY7W1O
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1H96%D97);
M)VEN<F5P;'ET;R==*2`_/B(@+SX*/#]P:'`@:68@*"1R97!L>5]T>7!E(#T]
M("=R97!L>2<I.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)R969E
M<F5N8V5S(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1H
M96%D97);)W)E9F5R96YC97,G72D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](G)E<&QY7VEN9&5X(B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1R97!L>5]I;F1E>"D@/SXB("\^"CP_<&AP(&5N9&EF
M.R`_/@H\/W!H<"!E;F1I9CL@/SX*"CQH,2!C;&%S<STB:&5A9&5R(CX\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'1I=&QE*2`_/CPO:#$^"@H\8G(@
M+SX*/#]P:'`@24U0.CIS=&%T=7,H*3L@/SX*"CQT86)L92!W:61T:#TB,3`P
M)2(@8V5L;'-P86-I;F<](C$B/@H@(#QT<CX*("`@(#QT9#XF;F)S<#L\+W1D
M/@H@("`@/'1D/@H@("`@("`\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C
M:6YG/2(P(CX*("`@("`@("`\='(^"B`@("`@("`@("`\=&0@8VQA<W,](FQE
M9G1!;&EG;B(@;F]W<F%P/2)N;W=R87`B/@H@("`@("`@("`@("`\:6YP=70@
M;F%M93TB8G1N7W-E;F1?;65S<V%G92(@='EP93TB<W5B;6ET(B`\/W!H<"!E
M8VAO($AO<F1E.CIG971!8V-E<W-+97E!;F14:71L92A?*")?4V5N9"!-97-S
M86=E(BDI(#\^(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](G)E='5R;B!U;FEQ
M4W5B;6ET*"=S96YD7VUE<W-A9V4G*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H
M(E-E;F0@365S<V%G92(I(#\^(B`O/@H\/W!H<"!I9B`H)&-O;F9;)W5S97(G
M75LG86QL;W=?9F]L9&5R<R==*3H@/SX*("`@("`@("`@("`@/&EN<'5T(&YA
M;64](F)T;E]S879E7V1R869T(B!T>7!E/2)S=6)M:70B(#P_<&AP(&5C:&\@
M2&]R9&4Z.F=E=$%C8V5S<TME>4%N9%1I=&QE*%\H(E-A=F4@7T1R869T(BDI
M(#\^(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](G5N:7%3=6)M:70H)W-A=F5?
M9')A9G0G*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-A=F4@1')A9G0B*2`_
M/B(@+SX*/#]P:'`@96YD:68[(#\^"B`@("`@("`@("`@(#QI;G!U="!N86UE
M/2)B=&Y?8V%N8V5L7V-O;7!O<V4B('1Y<&4](G-U8FUI="(@=&ET;&4](CP_
M<&AP(&5C:&\@7R@B0V%N8V5L($UE<W-A9V4B*2`_/B(@8VQA<W,](F)U='1O
M;B(@;VYC;&EC:STB<F5T=7)N(&-O;F9I<FU#86YC96PH*3LB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(D-A;F-E;"!-97-S86=E(BD@/SXB("\^"B`@("`@("`@
M("`\+W1D/@H@("`@("`@("`@/'1D(&-L87-S/2)R:6=H=$%L:6=N(B!S='EL
M93TB<&%D9&EN9SHR<'@B/CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@
M)V-O;7!O<V4M8G5T=&]N<R<I(#\^)FYB<W`[/"]T9#X*("`@("`@("`\+W1R
M/@H@("`@("`\+W1A8FQE/@H@("`@/"]T9#X*("`\+W1R/@H*("`\='(^"CP_
M<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G9&5F875L=%]I9&5N=&ET>2<I
M*3H@/SX*("`@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!;&EG;B(^/'-T<F]N
M9SX\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G:61E;G1I='DG+"!?*")?261E
M;G1I='DB*2D@/SXF;F)S<#L\+W-T<F]N9SX\+W1D/@H@("`@/'1D(&-L87-S
M/2)I=&5M(CX*("`@("`@/'1A8FQE('=I9'1H/2(Q,#`E(CX*("`@("`@("`\
M='(^"B`@("`@("`@("`\=&0@8VQA<W,](FQE9G1!;&EG;B(^"B`@("`@("`@
M("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FQA<W1?:61E;G1I='DB
M('9A;'5E/2(\/W!H<"!E8VAO("1I9&5N=&ET>2T^9V5T1&5F875L="@I(#\^
M(B`O/@H@("`@/#]P:'`@:68@*&-O=6YT*"1S96QE8W1?;&ES="D@/B`Q*3H@
M/SX*("`@("`@("`\<V5L96-T(&ED/2)I9&5N=&ET>2(@;F%M93TB:61E;G1I
M='DB('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(B!O;F-H
M86YG93TB8VAA;F=E7VED96YT:71Y*'1H:7,N<V5L96-T961);F1E>"DB('-T
M>6QE/2)D:7)E8W1I;VXZ;'1R(CX*("`@("`@("`\/W!H<"!F;W)E86-H("@D
M<V5L96-T7VQI<W0@87,@)&ME>2`]/B`D<V5L96-T*3H@/SX*("`@("`@("`\
M;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO("1K97D@/SXB/#]P:'`@:68@*"1K
M97D@/3T@)&ED96YT:71Y+3YG971$969A=6QT*"DI(&5C:&\@)R!S96QE8W1E
M9#TB<V5L96-T960B)R`_/CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'-E;&5C="D@/SX\+V]P=&EO;CX*("`@("`@("`\/W!H<"!E;F1F;W)E86-H
M.R`_/@H@("`@("`@(#PO<V5L96-T/@H@("`@/#]P:'`@96QS93H@/SX*("`@
M("`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I9&5N=&ET>2(@=F%L
M=64](CP_<&AP(&5C:&\@)&ED96YT:71Y+3YG971$969A=6QT*"D@/SXB("\^
M"B`@("`@("`@/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S96QE8W1?
M;&ES=%LP72D@/SX*("`@(#P_<&AP(&5N9&EF.R`_/@H@("`@("`@("`@/"]T
M9#X*/#]P:'`@96QS93H@/SX*("`@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!
M;&EG;B(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D9R;VTB*2`_/B9N8G-P.SPO
M<W1R;VYG/CPO=&0^"B`@("`\=&0@8VQA<W,](FET96TB/@H@("`@("`\=&%B
M;&4@=VED=&@](C$P,"4B/@H@("`@("`@(#QT<CX*/#]P:'`@:68@*"$D<')E
M9G,M/FES3&]C:V5D*"=F<F]M7V%D9'(G*2DZ(#\^"B`@("`@("`@("`\=&0@
M8VQA<W,](FQE9G1!;&EG;B(^/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C4U
M(B!T86)I;F1E>#TB/#]P:'`@96-H;R`D=&%B:6YD97@K*R`_/B(@8VQA<W,]
M(F9I>&5D(B!N86UE/2)F<F]M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1F<F]M*2`_/B(@<W1Y;&4](F1I<F5C=&EO;CIL='(B+SX\
M+W1D/@H\/W!H<"!E;'-E.B`_/@H@("`@("`@("`@/'1D(&-L87-S/2)L969T
M06QI9VXB/CQS=')O;F<^)FYB<W`[/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1F<F]M*2`_/CPO<W1R;VYG/CPO=&0^"CP_<&AP(&5N9&EF.R`_/@H\
M/W!H<"!E;F1I9CL@/SX*("`@("`@("`@(#QT9"!C;&%S<STB<FEG:'1!;&EG
M;B(^/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G+"`G8V]M<&]S92UF<F]M
M)RD@/SXF;F)S<#L\+W1D/@H@("`@("`@(#PO='(^"B`@("`@(#PO=&%B;&4^
M"B`@("`\+W1D/@H@(#PO='(^"@H@(#QT<CX*("`@(#QT9"!C;&%S<STB;&EG
M:'0@<FEG:'1!;&EG;B(^/'-T<F]N9SX\/W!H<"!E8VAO($AO<F1E.CIL86)E
M;"@G=&\G+"!?*")?5&\B*2D@/SXF;F)S<#L\+W-T<F]N9SX\+W1D/@H@("`@
M/'1D(&-L87-S/2)I=&5M(CX*("`@("`@/'1A8FQE('=I9'1H/2(Q,#`E(CX*
M/#]P:'`@:68@*&ES7V%R<F%Y*"1H96%D97);)W1O)UTI*3H@)&9I<G-T7W1O
M(#T@=')U93L@/SX*/#]P:'`@9F]R96%C:"`H)&AE861E<ELG=&\G72!A<R`D
M=&]?:71E;2DZ(#\^"B`@("`@("`@/'1R/@H\/W!H<"!I9B`H8V]U;G0H)'1O
M7VET96TI(#X@,2DZ(#\^"B`@("`@("`@("`\=&0@8VQA<W,](FQE9G1!;&EG
M;B(^"B`@("`@("`@("`@("`@("`@(#QS96QE8W0@:60](G1O(B!T86)I;F1E
M>#TB/#]P:'`@96-H;R`D=&%B:6YD97@K*R`_/B(@;F%M93TB=&]?;&ES=%L\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'1O7VET96U;,%TI(#\^72(@
M<W1Y;&4](G=I9'1H.C,U,'!X.V1I<F5C=&EO;CIL='(B/@H@("`@("`@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64](B(@<V5L96-T960](G-E;&5C=&5D
M(CX\/W!H<"!E8VAO(%\H(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D
M9')E<W,@=&\@=&AE(')I9VAT.B(I(#\^/"]O<'1I;VX^"CP_<&AP(&9O<B`H
M)&D@/2`Q.R`D:2`\(&-O=6YT*"1T;U]I=&5M*3L@)&DK*RDZ(#\^"B`@("`@
M("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1T;U]I=&5M6R1I72D@/SXB/CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D=&]?:71E;5LD:5TI(#\^/"]O<'1I;VX^"CP_<&AP
M(&5N9&9O<CL@/SX*("`@("`@("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@
M("`@("`@("`@("`@(#QI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(Q-2(@=&%B
M:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB(&-L87-S/2)F:7AE
M9"(@;F%M93TB=&]?9FEE;&1;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1T;U]I=&5M6S!=*2`_/ETB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'1O7VET96U;,%TI(#\^(B!S='EL93TB=VED=&@Z,34P<'@[
M9&ER96-T:6]N.FQT<B(@+SX*("`@("`@("`@(#PO=&0^"CP_<&AP(&5L<V4Z
M(#\^"B`@("`@("`@("`\=&0@8VQA<W,](FQE9G1!;&EG;B(^/&EN<'5T('1Y
M<&4](G1E>'0B(&ED/2)T;R(@<VEZ93TB-34B('1A8FEN9&5X/2(\/W!H<"!E
M8VAO("1T86)I;F1E>"LK(#\^(B!C;&%S<STB9FEX960B(&YA;64](G1O7V9I
M96QD6UTB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'1O
M7VET96TI(#\^(B!S='EL93TB9&ER96-T:6]N.FQT<B(@+SX\+W1D/@H\/W!H
M<"!E;F1I9CL@/SX*/#]P:'`@:68@*"1F:7)S=%]T;RDZ("1F:7)S=%]T;R`]
M(&9A;'-E.R`_/@H@("`@("`@("`@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX\
M/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEM<"<L("=C;VUP;W-E+71O)RD@/SXF
M;F)S<#L\+W1D/@H\/W!H<"!E;'-E.B`_/@H@("`@("`@("`@/'1D/B9N8G-P
M.SPO=&0^"CP_<&AP(&5N9&EF.R`_/@H@("`@("`@(#PO='(^"CP_<&AP(&5N
M9&9O<F5A8V@[(#\^"CP_<&AP(&5L<V4Z(#\^"B`@("`@("`@/'1R/@H@("`@
M("`@("`@/'1D(&-L87-S/2)L969T06QI9VXB/CQI;G!U="!T>7!E/2)T97AT
M(B!I9#TB=&\B('-I>F4](C4U(B!T86)I;F1E>#TB/#]P:'`@96-H;R`D=&%B
M:6YD97@K*R`_/B(@8VQA<W,](F9I>&5D(B!S='EL93TB9&ER96-T:6]N.FQT
M<B(@;F%M93TB=&\B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&AE861E<ELG=&\G72D@/SXB(#P_<&AP(&5C:&\@*"1B<F]W<V5R+3YH
M87-&96%T=7)E*"=I9G)A;65S)RDI(#\@)V]N8VAA;F=E/2)E>'!A;F1&:65L
M9"AT:&ES*3LB("\^(#QS<&%N(&ED/2)E>'!A;F1I;F=T;R(@8VQA<W,](FEN
M4')O9W)E<W,B('-T>6QE/2)V:7-I8FEL:71Y.FAI9&1E;B(^)R`N(%\H(D5X
M<&%N9&EN9R(I("X@)R9H96QL:7`[/"]S<&%N/B<@.B`G+SXG(#\^/"]T9#X*
M("`@("`@("`@(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(^/#]P:'`@96-H;R!(
M96QP.CIL:6YK*"=I;7`G+"`G8V]M<&]S92UT;R<I(#\^)FYB<W`[/"]T9#X*
M("`@("`@("`\+W1R/@H\/W!H<"!E;F1I9CL@/SX*("`@("`@/"]T86)L93X*
M("`@(#PO=&0^"B`@/"]T<CX*"CP_<&AP(&EF("@D8V]N9ELG8V]M<&]S92==
M6R=A;&QO=U]C8R==*3H@/SX*("`\='(^"B`@("`\=&0@8VQA<W,](FQI9VAT
M(')I9VAT06QI9VXB/CQS=')O;F<^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH
M)V-C)RP@7R@B7T-C(BDI(#\^)FYB<W`[/"]S=')O;F<^/"]T9#X*("`@(#QT
M9"!C;&%S<STB:71E;2(^"B`@("`@(#QT86)L92!W:61T:#TB,3`P)2(^"CP_
M<&AP(&EF("AI<U]A<G)A>2@D:&5A9&5R6R=C8R==*2DZ("1F:7)S=%]C8R`]
M('1R=64[(#\^"CP_<&AP(&9O<F5A8V@@*"1H96%D97);)V-C)UT@87,@)&-C
M7VET96TI.B`_/@H@("`@("`@(#QT<CX*/#]P:'`@:68@*&-O=6YT*"1C8U]I
M=&5M*2`^(#$I.B`_/@H@("`@("`@("`@/'1D(&-L87-S/2)L969T06QI9VXB
M/@H@("`@("`@("`@("`\=&%B;&4@8V5L;'-P86-I;F<](C`B/@H@("`@("`@
M("`@("`@(#QT<CX*("`@("`@("`@("`@("`@(#QT9"!W:61T:#TB,S4P(CX*
M("`@("`@("`@("`@("`@("`@/'-E;&5C="!I9#TB8V,B('1A8FEN9&5X/2(\
M/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(B!N86UE/2)C8U]L:7-T6SP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V-?:71E;5LP72D@/SY=(B!S='EL
M93TB=VED=&@Z,S4P<'@[9&ER96-T:6]N.FQT<B(^"B`@("`@("`@("`@("`@
M("`@("`@/&]P=&EO;B!V86QU93TB(B!S96QE8W1E9#TB<V5L96-T960B/CP_
M<&AP(&5C:&\@7R@B0VAO;W-E(&$@;6%T8V@@;W(@961I="!T:&4@861D<F5S
M<R!T;R!T:&4@<FEG:'0Z(BD@/SX\+V]P=&EO;CX*/#]P:'`@9F]R("@D:2`]
M(#$[("1I(#P@8V]U;G0H)&-C7VET96TI.R`D:2LK*3H@/SX*("`@("`@("`@
M("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&-C7VET96U;)&E=*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1C8U]I=&5M6R1I72D@/SX\+V]P=&EO;CX*/#]P:'`@96YD
M9F]R.R`_/@H@("`@("`@("`@("`@("`@("`\+W-E;&5C=#X*("`@("`@("`@
M("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@("`\=&0@=VED=&@](C$U,"(^
M"B`@("`@("`@("`@("`@("`@(#QI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(Q
M-2(@=&%B:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB(&-L87-S
M/2)F:7AE9"(@;F%M93TB8V-?9FEE;&1;/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1C8U]I=&5M6S!=*2`_/ETB('9A;'5E/2(\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)&-C7VET96U;,%TI(#\^(B!S='EL93TB=VED=&@Z
M,34P<'@[9&ER96-T:6]N.FQT<B(@+SX*("`@("`@("`@("`@("`@(#PO=&0^
M"B`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@("`@/"]T86)L93X*("`@
M("`@("`@(#PO=&0^"CP_<&AP(&5L<V4Z(#\^"B`@("`@("`@("`\=&0@8VQA
M<W,](FQE9G1!;&EG;B(^/&EN<'5T('1Y<&4](G1E>'0B(&ED/2)C8R(@<VEZ
M93TB-34B('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(B!C
M;&%S<STB9FEX960B(&YA;64](F-C7V9I96QD6UTB('9A;'5E/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-C7VET96TI(#\^(B!S='EL93TB9&ER
M96-T:6]N.FQT<B(@+SX\+W1D/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@
M*"1F:7)S=%]C8RDZ("1F:7)S=%]C8R`](&9A;'-E.R`_/@H@("`@("`@("`@
M/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX\/W!H<"!E8VAO($AE;'`Z.FQI;FLH
M)VEM<"<L("=C;VUP;W-E+6-C)RD@/SXF;F)S<#L\+W1D/@H\/W!H<"!E;'-E
M.B`_/@H@("`@("`@("`@/'1D/B9N8G-P.SPO=&0^"CP_<&AP(&5N9&EF.R`_
M/@H@("`@("`@(#PO='(^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`@("`@
M/'1R/@H@("`@("`@("`@/'1D(&-L87-S/2)L969T06QI9VXB/CQI;G!U="!T
M>7!E/2)T97AT(B!I9#TB8V,B('-I>F4](C4U(B!T86)I;F1E>#TB/#]P:'`@
M96-H;R`D=&%B:6YD97@K*R`_/B(@8VQA<W,](F9I>&5D(B!N86UE/2)C8U]N
M97<B('-T>6QE/2)D:7)E8W1I;VXZ;'1R(B`O/CPO=&0^"B`@("`@("`@("`\
M=&0^)FYB<W`[/"]T9#X*("`@("`@("`\+W1R/@H\/W!H<"!E;'-E.B`_/@H@
M("`@("`@(#QT<CX*("`@("`@("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N(CX\
M:6YP=70@='EP93TB=&5X="(@:60](F-C(B!S:7IE/2(U-2(@=&%B:6YD97@]
M(CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB(&-L87-S/2)F:7AE9"(@<W1Y
M;&4](F1I<F5C=&EO;CIL='(B(&YA;64](F-C(B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1H96%D97);)V-C)UTI(#\^(B`\/W!H<"!E
M8VAO("@D8G)O=W-E<BT^:&%S1F5A='5R92@G:69R86UE<R<I*2`_("=O;F-H
M86YG93TB97AP86YD1FEE;&0H=&AI<RD[(B`O/B`\<W!A;B!I9#TB97AP86YD
M:6YG8V,B(&-L87-S/2)I;E!R;V=R97-S(B!S='EL93TB=FES:6)I;&ET>3IH
M:61D96XB/B<@+B!?*")%>'!A;F1I;F<B*2`N("<F:&5L;&EP.SPO<W!A;CXG
M(#H@)R\^)R`_/CPO=&0^"B`@("`@("`@("`\=&0@8VQA<W,](G)I9VAT06QI
M9VXB/CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)V-O;7!O<V4M8V,G
M*2`_/B9N8G-P.SPO=&0^"B`@("`@("`@/"]T<CX*/#]P:'`@96YD:68[(#\^
M"B`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H@(#PO='(^"CP_<&AP(&5N9&EF
M.R`_/@H*/#]P:'`@:68@*"1C;VYF6R=C;VUP;W-E)UU;)V%L;&]W7V)C8R==
M*3H@/SX*("`\='(^"B`@("`\=&0@8VQA<W,](FQI9VAT(')I9VAT06QI9VXB
M/CQS=')O;F<^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)V)C8R<L(%\H(E]"
M8V,B*2D@/SXF;F)S<#L\+W-T<F]N9SX\+W1D/@H@("`@/'1D(&-L87-S/2)I
M=&5M(CX*("`@("`@/'1A8FQE('=I9'1H/2(Q,#`E(CX*/#]P:'`@:68@*&ES
M7V%R<F%Y*"1H96%D97);)V)C8R==*2DZ("1F:7)S=%]B8V,@/2!T<G5E.R`_
M/@H\/W!H<"!F;W)E86-H("@D:&5A9&5R6R=B8V,G72!A<R`D8F-C7VET96TI
M.B`_/@H@("`@("`@(#QT<CX*/#]P:'`@:68@*&-O=6YT*"1B8V-?:71E;2D@
M/B`Q*3H@/SX*("`@("`@("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N(CX*("`@
M("`@("`@("`@/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX*("`@("`@("`@("`@
M("`\='(^"B`@("`@("`@("`@("`@("`\=&0@=VED=&@](C,U,"(^"B`@("`@
M("`@("`@("`@("`@(#QS96QE8W0@:60](F)C8R(@=&%B:6YD97@](CP_<&AP
M(&5C:&\@)'1A8FEN9&5X*RL@/SXB(&YA;64](F)C8U]L:7-T6SP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D8F-C7VET96U;,%TI(#\^72(@<W1Y;&4]
M(G=I9'1H.C,U,'!X.V1I<F5C=&EO;CIL='(B/@H@("`@("`@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B(@<V5L96-T960](G-E;&5C=&5D(CX\/W!H
M<"!E8VAO(%\H(D-H;V]S92!A(&UA=&-H(&]R(&5D:70@=&AE(&%D9')E<W,@
M=&\@=&AE(')I9VAT.B(I(#\^/"]O<'1I;VX^"CP_<&AP(&9O<B`H)&D@/2`Q
M.R`D:2`\(&-O=6YT*"1B8V-?:71E;2D[("1I*RLI.B`_/@H@("`@("`@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D8F-C7VET96U;)&E=*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1B8V-?:71E;5LD:5TI(#\^/"]O<'1I;VX^"CP_<&AP(&5N
M9&9O<CL@/SX*("`@("`@("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@("`@
M("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@/'1D('=I9'1H/2(Q-3`B
M/@H@("`@("`@("`@("`@("`@("`\:6YP=70@='EP93TB=&5X="(@<VEZ93TB
M,34B('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(B!C;&%S
M<STB9FEX960B(&YA;64](F)C8U]F:65L9%L\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&)C8U]I=&5M6S!=*2`_/ETB('9A;'5E/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&)C8U]I=&5M6S!=*2`_/B(@<W1Y;&4](G=I
M9'1H.C$U,'!X.V1I<F5C=&EO;CIL='(B("\^"B`@("`@("`@("`@("`@("`\
M+W1D/@H@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@(#PO=&%B;&4^
M"B`@("`@("`@("`\+W1D/@H\/W!H<"!E;'-E.B`_/@H@("`@("`@("`@/'1D
M(&-L87-S/2)L969T06QI9VXB/CQI;G!U="!T>7!E/2)T97AT(B!I9#TB8F-C
M(B!S:7IE/2(U-2(@=&%B:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@
M/SXB(&-L87-S/2)F:7AE9"(@;F%M93TB8F-C7V9I96QD6UTB('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&)C8U]I=&5M*2`_/B(@<W1Y
M;&4](F1I<F5C=&EO;CIL='(B("\^/"]T9#X*/#]P:'`@96YD:68[(#\^"CP_
M<&AP(&EF("@D9FER<W1?8F-C*3H@)&9I<G-T7V)C8R`](&9A;'-E.R`_/@H@
M("`@("`@("`@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX\/W!H<"!E8VAO($AE
M;'`Z.FQI;FLH)VEM<"<L("=C;VUP;W-E+6)C8R<I(#\^)FYB<W`[/"]T9#X*
M/#]P:'`@96QS93H@/SX*("`@("`@("`@(#QT9#XF;F)S<#L\+W1D/@H\/W!H
M<"!E;F1I9CL@/SX*("`@("`@("`\+W1R/@H\/W!H<"!E;F1F;W)E86-H.R`_
M/@H@("`@("`@(#QT<CX*("`@("`@("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N
M(CX\:6YP=70@='EP93TB=&5X="(@:60](F)C8R(@<VEZ93TB-34B('1A8FEN
M9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(B!C;&%S<STB9FEX960B
M(&YA;64](F)C8U]N97<B('-T>6QE/2)D:7)E8W1I;VXZ;'1R(B`O/CPO=&0^
M"B`@("`@("`@("`\=&0^)FYB<W`[/"]T9#X*("`@("`@("`\+W1R/@H\/W!H
M<"!E;'-E.B`_/@H@("`@("`@(#QT<CX*("`@("`@("`@(#QT9"!C;&%S<STB
M;&5F=$%L:6=N(CX\:6YP=70@='EP93TB=&5X="(@:60](F)C8R(@<VEZ93TB
M-34B('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(B!C;&%S
M<STB9FEX960B('-T>6QE/2)D:7)E8W1I;VXZ;'1R(B!N86UE/2)B8V,B('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&AE861E<ELG8F-C
M)UTI.R`_/B(@/#]P:'`@96-H;R`H)&)R;W=S97(M/FAA<T9E871U<F4H)VEF
M<F%M97,G*2D@/R`G;VYC:&%N9V4](F5X<&%N9$9I96QD*'1H:7,I.R(@+SX@
M/'-P86X@:60](F5X<&%N9&EN9V)C8R(@8VQA<W,](FEN4')O9W)E<W,B('-T
M>6QE/2)V:7-I8FEL:71Y.FAI9&1E;B(^)R`N(%\H(D5X<&%N9&EN9R(I("X@
M)R9H96QL:7`[/"]S<&%N/B<@.B`G+SXG(#\^/"]T9#X*("`@("`@("`@(#QT
M9"!C;&%S<STB<FEG:'1!;&EG;B(^/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I
M;7`G+"`G8V]M<&]S92UB8V,G*2`_/B9N8G-P.SPO=&0^"B`@("`@("`@/"]T
M<CX*/#]P:'`@96YD:68[(#\^"B`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H@
M(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H*("`\='(^"B`@("`\=&0@8VQA<W,]
M(FQI9VAT(')I9VAT06QI9VXB/CQS=')O;F<^/#]P:'`@96-H;R!(;W)D93HZ
M;&%B96PH)W-U8FIE8W0G+"!?*")37W5B:F5C="(I*2`_/B9N8G-P.SPO<W1R
M;VYG/CPO=&0^"B`@("`\=&0@8VQA<W,](FET96TB/@H@("`@("`\=&%B;&4@
M=VED=&@](C$P,"4B/@H@("`@("`@(#QT<CX*("`@("`@("`@(#QT9"!C;&%S
M<STB;&5F=$%L:6=N(CX\:6YP=70@='EP93TB=&5X="(@:60](G-U8FIE8W0B
M('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(B!C;&%S<STB
M9FEX960B(&YA;64](G-U8FIE8W0B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&AE861E<ELG<W5B:F5C="==*2`_/B(@<VEZ93TB-34B
M(#P_<&AP(&EF("@D8G)O=W-E<BT^:7-"<F]W<V5R*"=M<VEE)RDI(&5C:&\@
M)V]N:V5Y9&]W;CTB<W5B:F5C=%1A8B@I.R(@)R`_/B\^/"]T9#X*("`@("`@
M("`@(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(^/#]P:'`@96-H;R!(96QP.CIL
M:6YK*"=I;7`G+"`G8V]M<&]S92US=6)J96-T)RD@/SXF;F)S<#L\+W1D/@H@
M("`@("`@(#PO='(^"B`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H@(#PO='(^
M"@H\/W!H<`HD<V5T7W!R:6]R:71Y(#T@)'!R969S+3YG971686QU92@G<V5T
M7W!R:6]R:71Y)RD["B1L;V-K961?8VAA<G-E="`]("1P<F5F<RT^:7-,;V-K
M960H)W-E;F1I;F=?8VAA<G-E="<I.PH_/@H\/W!H<"!I9B`H)'-E=%]P<FEO
M<FET>2!\?"`A)&QO8VME9%]C:&%R<V5T*3H@/SX*("`\='(^"B`@("`\=&0@
M8VQA<W,](FQI9VAT(')I9VAT06QI9VXB/CQS=')O;F<^/#]P:'`@96-H;R`H
M)&QO8VME9%]C:&%R<V5T*2`_($AO<F1E.CIL86)E;"@G<')I;W)I='DG+"!?
M*")?4')I;W)I='DB*2D@.B!(;W)D93HZ;&%B96PH)V-H87)S970G+"!?*")#
M7VAA<G-E="(I*2`_/B9N8G-P.SPO<W1R;VYG/CPO=&0^"B`@("`\=&0@8VQA
M<W,](FET96TB/@H@("`@("`\=&%B;&4@=VED=&@](C$P,"4B/@H@("`@("`@
M(#QT<CX*/#]P:'`@:68@*"$D;&]C:V5D7V-H87)S970I.B`_/@H@("`@("`@
M("`@/'1D/@H@("`@("`@("`@("`\<V5L96-T(&ED/2)C:&%R<V5T(B!N86UE
M/2)C:&%R<V5T(B!T86)I;F1E>#TB/#]P:'`@96-H;R`D=&%B:6YD97@K*R`_
M/B(@<W1Y;&4](F1I<F5C=&EO;CIL='(B/@H\/W!H<"!F;W)E86-H("@D;FQS
M6R=E;F-O9&EN9W,G72!A<R`D8VAA<G-E="`]/B`D;F%M92DZ(#\^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D8VAA<G-E="`_
M/B(\/W!H<"!I9B`H<W1R=&]L;W=E<B@D8VAA<G-E="D@/3T@<W1R=&]L;W=E
M<B@D96YC;V1I;F<I*2!E8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^
M/#]P:'`@96-H;R`D;F%M92`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W)E86-H
M.R`_/@H@("`@("`@("`@("`\+W-E;&5C=#X*("`@("`@("`@(#PO=&0^"CP_
M<&AP(&5N9&EF.R`_/@H*/#]P:'`@:68@*"1S971?<')I;W)I='DI.B`_/@H\
M/W!H<"`D<')I;W)I='D@/2!S=6)S='(H571I;#HZ9V5T1F]R;41A=&$H)WA?
M<')I;W)I='DG+"`G,R<I+"`P+"`Q*3L@/SX*/#]P:'`@:68@*"$D;&]C:V5D
M7V-H87)S970I.B`_/@H@("`@("`@("`@/'1D(&-L87-S/2)R:6=H=$%L:6=N
M(CX\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G<')I;W)I='DG+"!?*")?4')I
M;W)I='DB*2D@/SXF;F)S<#L\+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`@("`@
M("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N(CX*("`@("`@("`@("`@/'-E;&5C
M="!I9#TB<')I;W)I='DB(&YA;64](GA?<')I;W)I='DB('1A8FEN9&5X/2(\
M/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(CX*("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2(Q("A(:6=H97-T*2(\/W!H<"!I9B`H)'!R:6]R:71Y(#T]
M("<Q*2<I(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CXQ("@\/W!H
M<"!E8VAO(%\H(DAI9VAE<W0B*2`_/BD\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(R("A(:6=H*2(\/W!H<"!I9B`H)'!R:6]R:71Y
M(#T]("<R)RD@96-H;R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^/C(@*#P_
M<&AP(&5C:&\@7R@B2&EG:"(I(#\^*3PO;W!T:6]N/@H@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](C,@*$YO<FUA;"DB/#]P:'`@:68@*"1P<FEO<FET
M>2`]/2`G,R<I(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CXS("@\
M/W!H<"!E8VAO(%\H(DYO<FUA;"(I(#\^*3PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](C0@*$QO=RDB/#]P:'`@:68@*"1P<FEO<FET
M>2`]/2`G-"<I(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CXT("@\
M/W!H<"!E8VAO(%\H(DQO=R(I(#\^*3PO;W!T:6]N/@H@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](C4@*$QO=V5S="DB/#]P:'`@:68@*"1P<FEO<FET
M>2`]/2`G-2<I(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CXU("@\
M/W!H<"!E8VAO(%\H(DQO=V5S="(I(#\^*3PO;W!T:6]N/@H@("`@("`@("`@
M("`\+W-E;&5C=#X*("`@("`@("`@(#PO=&0^"B`@("`@("`@("`\=&0@8VQA
M<W,](G)I9VAT06QI9VXB/CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@
M)V-O;7!O<V4M<')I;W)I='DG*2`_/B9N8G-P.SPO=&0^"CP_<&AP(&5N9&EF
M.R`_/@H*("`@("`@("`\+W1R/@H@("`@("`\+W1A8FQE/@H@("`@/"]T9#X*
M("`\+W1R/@H\/W!H<"!E;F1I9CL@/SX*"CP_<&AP(&EF("@A)'!R969S+3YI
M<TQO8VME9"@G<W1A=&EO;F5R>2<I("8F("%E;7!T>2@D<W1A=&EO;F5R>5]L
M:7-T*2DZ(#\^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)L:6=H="!R:6=H=$%L
M:6=N(B!V86QI9VX](FUI9&1L92(^/'-T<F]N9SX\/W!H<"!E8VAO($AO<F1E
M.CIL86)E;"@G<W1A=&EO;F5R>2<L(%\H(E-T871I;VYE<GDB*2D@/SXF;F)S
M<#L\+W-T<F]N9SX\+W1D/@H@("`@/'1D(&-L87-S/2)I=&5M(CX*("`@("`@
M/'1A8FQE('=I9'1H/2(Q,#`E(CX*("`@("`@("`\='(^"B`@("`@("`@("`\
M=&0@8VQA<W,](FQE9G1!;&EG;B(^"B`@("`@("`@("`@("`\<V5L96-T(&YA
M;64](G-T871I;VYE<GDB(&ED/2)S=&%T:6]N97)Y(B!O;F-H86YG93TB=6YI
M<5-U8FUI="@G8VAA;F=E7W-T871I;VYE<GDG*3LB/@H@("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B4V5L96-T(&$@<W1A
M=&EO;F5R>3HB*2`_/CPO;W!T:6]N/@H\/W!H<"!F;W)E86-H("@D<W1A=&EO
M;F5R>5]L:7-T(&%S("1S=&%T:6]N97)Y7VED(#T^("1S=&%T:6]N97)Y7V-H
M;VEC92DZ(#\^"B`@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](CP_<&AP
M(&5C:&\@)'-T871I;VYE<GE?:60@/SXB/#]P:'`@:68@*"1S=&%T:6]N97)Y
M(#T]/2`D<W1A=&EO;F5R>5]I9"D@96-H;R`G('-E;&5C=&5D/2)S96QE8W1E
M9"(G(#\^/CP_<&AP(&5C:&\@)'-T871I;VYE<GE?8VAO:6-E6R=N)UT@/SX\
M+V]P=&EO;CX*/#]P:'`@96YD9F]R96%C:#L@/SX*("`@("`@("`@("`@/"]S
M96QE8W0^"B`@("`@("`@("`\+W1D/@H@("`@("`@(#PO='(^"B`@("`@(#PO
M=&%B;&4^"B`@("`\+W1D/@H@(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H*("`\
M='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`@(#QT9"!C;&%S<STB:71E;2(^
M"B`@("`@(#QT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/@H@
M("`@("`@(#QT<CX*("`@("`@("`@(#QT9#X*("`@("`@("`@("`@/'1A8FQE
M('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^"B`@("`@("`@("`@("`@
M/'1R/@H\/W!H<"!I9B`H)')E9VES=')Y+3YH87--971H;V0H)V-O;G1A8W1S
M+W-E87)C:"<I*3H@/SX*/#]P:'`@)&-O;G1A8W1S7W5R;"`]($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G8V]N=&%C=',N<&AP)RD[(#\^"B`@("`@("`@("`@
M("`@("`\=&0@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!(;W)D93HZ;&EN
M:R@G(R<L("<G+"`G=VED9V5T)RP@;G5L;"P@)W=I;F1O=RYO<&5N*%PG)R`N
M("1C;VYT86-T<U]U<FP@+B`G7"<L(%PG8V]N=&%C='-<)RP@7"=T;V]L8F%R
M/6YO+&QO8V%T:6]N/6YO+'-T871U<SUN;RQS8W)O;&QB87)S/7EE<RQR97-I
M>F%B;&4]>65S+'=I9'1H/34U,"QH96EG:'0],S`P+&QE9G0],3`P+'1O<#TQ
M,#!<)RD[(')E='5R;B!F86QS93LG*2`N($AO<F1E.CII;6<H)V%D9')E<W-B
M;V]K7V)R;W=S92YP;F<G*2`N("<\8G(@+SXG("X@7R@B061D<F5S<R!";V]K
M(BD@+B`G/"]A/B<@/SX\+W1D/@H@("`@("`@("`@("`@("`@/'1D(&%L:6=N
M/2)C96YT97(B/CP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)R,G+"`G)RP@)W=I
M9&=E="<L(&YU;&PL(")U;FEQ4W5B;6ET*"=C;VUP;W-E7V5X<&%N9%]A9&1R
M)RD[(')E='5R;B!F86QS93LB*2`N($AO<F1E.CII;6<H)V5X<&%N9"YP;F<G
M*2`N("<\8G(@+SXG("X@7R@B17AP86YD($YA;65S(BD@+B`G/"]A/B<@/SX\
M+W1D/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*"%E;7!T>2@D8V]N9ELG
M=71I;',G75LG<W!E;&QC:&5C:V5R)UTI*3H@/SX*("`@("`@("`@("`@("`@
M(#QT9"!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO($AO<F1E.CIL:6YK*"<C
M)RP@)R<L("=W:61G970G+"!N=6QL+"`B=6YI<5-U8FUI="@G<W!E;&Q?8VAE
M8VLG*3L@<F5T=7)N(&9A;'-E.R(I("X@2&]R9&4Z.FEM9R@G<W!E;&QC:&5C
M:RYP;F<G*2`N("<\8G(@+SXG("X@7R@B4W!E;&P@0VAE8VLB*2`N("<\+V$^
M)R`_/CPO=&0^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H)&)R;W=S97(M
M/FAA<T9E871U<F4H)VIA=F%S8W)I<'0G*2`F)B`D8V]N9ELG8V]M<&]S92==
M6R=S<&5C:6%L7V-H87)A8W1E<G,G72DZ(#\^"B`@("`@("`@("`@("`@("`\
M=&0@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!(;W)D93HZ;&EN:R@G(R<L
M("<G+"`G=VED9V5T)RP@;G5L;"P@)W=I;F1O=RYO<&5N*%PG)R`N($AO<F1E
M.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP)RD@+B`G7"<L(%PG8VAA<G-<)RP@7"=H
M96EG:'0],C(P+'=I9'1H/30P,%PG*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R
M9&4Z.FEM9R@G:V5Y8F]A<F0N<&YG)RP@;G5L;"P@;G5L;"P@)')E9VES=')Y
M+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/&)R("\^)R`N(%\H(E-P96-I
M86P@0VAA<F%C=&5R<R(I("X@)SPO83XG(#\^/"]T9#X*/#]P:'`@96YD:68[
M(#\^"CP_<&AP(&EF("@D:6UP6R=F:6QE7W5P;&]A9"==*3H@/SX*("`@("`@
M("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO($AO<F1E
M.CIL:6YK*"<C871T86-H;65N=',G+"`G)RP@)W=I9&=E="<L(&YU;&PL("=D
M;V-U;65N="YC;VUP;W-E+G5P;&]A9%\Q+F9O8W5S*"D[(')E='5R;B!F86QS
M93LG*2`N($AO<F1E.CII;6<H)VUA;F%G95]A='1A8VAM96YT<RYP;F<G*2`N
M("<\8G(@+SXG("X@7R@B071T86-H;65N=',B*2`N("<\+V$^)R`_/CPO=&0^
M"CP_<&AP(&5N9&EF.R`_/@H@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@
M("`@(#PO=&%B;&4^"B`@("`@("`@("`\+W1D/@H@("`@("`@("`@/'1D(&-L
M87-S/2)I=&5M(')I9VAT06QI9VXB(')O=W-P86X](C(B/CP_<&AP(&5C:&\@
M2&5L<#HZ;&EN:R@G:6UP)RP@)V-O;7!O<V4M;W!T:6]N<R<I(#\^)FYB<W`[
M/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@(#QT<CX*("`@("`@("`@(#QT
M9#X*("`@("`@("`@("`@/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN
M9STB,2(^"B`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@/'1D
M(&-L87-S/2)I=&5M(&QE9G1!;&EG;B(@=F%L:6=N/2)B;W1T;VTB/@H\/W!H
M<"!I9B`H)&-O;F9;)W5S97(G75LG86QL;W=?9F]L9&5R<R==("8F("$D<')E
M9G,M/FES3&]C:V5D*"=S879E7W-E;G1?;6%I;"<I*3H@/SX*("`@("`@("`@
M("`@("`@("`@/&EN<'5T(&ED/2)S<VTB('1Y<&4](F-H96-K8F]X(B!N86UE
M/2)S879E7W-E;G1?;6%I;"(\/W!H<"!I9B`H)'-S;5]C:&5C:RD@96-H;R`G
M(&-H96-K960](F-H96-K960B)SL@/SX@+SX*("`@("`@("`@("`@("`@("`@
M/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)W-S;2<L(%\H(E-A7W9E(&$@8V]P
M>2!I;B`B*2D@/SX*/#]P:'`*("`@("1S96YT7VUA:6Q?9F]L9&5R(#T@)&ED
M96YT:71Y+3YG971686QU92@G<V5N=%]M86EL7V9O;&1E<B<I.PH@("`@:68@
M*&5M<'1Y*"1S96YT7VUA:6Q?9F]L9&5R*2D@>PH@("`@("`@("1S96YT7VUA
M:6Q?9F]L9&5R(#T@571I;#HZ9V5T1F]R;41A=&$H)W-E;G1?;6%I;%]F;VQD
M97(G*3L*("`@('T*("`@(&EF("@D8V]N9ELG=7-E<B==6R=S96QE8W1?<V5N
M=&UA:6Q?9F]L9&5R)UT@)B8@(21P<F5F<RT^:7-,;V-K960H)W-E;G1?;6%I
M;%]F;VQD97(G*2D@>PH@("`@)&9O;&1E<G,@/2!)35`Z.F9L:7-T4V5L96-T
M*"<G+"!F86QS92P@87)R87DH)TE.0D]8)RDL("1S96YT7VUA:6Q?9F]L9&5R
M*3L*("`@(&5C:&\@)R`\<V5L96-T(&]N8VAA;F=E/2)D;V-U;65N="YC;VUP
M;W-E+G-A=F5?<V5N=%]M86EL+F-H96-K960]7"=C:&5C:V5D7"<B('1A8FEN
M9&5X/2(G("X@)'1A8FEN9&5X*RL@+B`G(B!N86UE/2)S96YT7VUA:6Q?9F]L
M9&5R(CXG("X@)&9O;&1E<G,@+B`G/"]S96QE8W0^)SL*?2!E;'-E('L*("`@
M(&EF("@A96UP='DH)'-E;G1?;6%I;%]F;VQD97(I*2!["B`@("`@("`@)'-E
M;G1?;6%I;%]F;VQD97(@/2`G)G%U;W0[)R`N($E-4#HZ9&ES<&QA>49O;&1E
M<B@D<V5N=%]M86EL7V9O;&1E<BD@+B`G)G%U;W0[)SL*("`@('T*("`@(&5C
M:&\@)SQS<&%N(&ED/2)S96YT7VUA:6Q?9F]L9&5R(CXG("X@)'-E;G1?;6%I
M;%]F;VQD97(@+B`G/"]S<&%N/B<["GT*/SX*/#]P:'`@96YD:68[(#\^"@H\
M/W!H<`H@("`@)&1?<F5A9"`]("1P<F5F<RT^9V5T5F%L=64H)V1I<W!O<VET
M:6]N7W)E<75E<W1?<F5A9"<I.PH@("`@)&1?9&5L:78@/2`D<')E9G,M/F=E
M=%9A;'5E*"=D:7-P;W-I=&EO;E]R97%U97-T7V1E;&EV97)Y)RD["C\^"CP_
M<&AP(&EF("@D8V]N9ELG8V]M<&]S92==6R=A;&QO=U]R96-E:7!T<R==("8F
M("@D9%]R96%D("$]("=N979E<B<I*3H@/SX*("`@("`@("`@("`@("`@(#QB
M<B`O/CQI;G!U="!I9#TB<G)R(B!T>7!E/2)C:&5C:V)O>"(@;F%M93TB<F5Q
M=65S=%]R96%D7W)E8V5I<'0B/#]P:'`@:68@*"@D9%]R96%D("$]("=A<VLG
M*2!\?"`H571I;#HZ9V5T1F]R;41A=&$H)W)E<75E<W1?<F5A9%]R96-E:7!T
M)RD@/3T@)V]N)RDI(&5C:&\@)R!C:&5C:V5D/2)C:&5C:V5D(B<[(#\^("\^
M(#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=R<G(G+"!?*")297%U97-T(&$@
M7U)E860@4F5C96EP="(I*2`_/@H\/W!H<"!E;F1I9CL@/SX*("`@("`@("`@
M("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@/"]T<CX*"CP_<&AP(&EF("@D
M8G)O=W-E<BT^:&%S1F5A='5R92@G<G1E)RD@)B8@(21P<F5F<RT^:7-,;V-K
M960H)V-O;7!O<V5?:'1M;"<I*3H@/SX*("`@("`@("`@("`@("`\='(^"B`@
M("`@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,B(^"B`@("`@("`@("`@("`@
M("`@(#QT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/@H@("`@
M("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`@(#QT
M9"!C;&%S<STB:71E;2!L969T06QI9VXB('=I9'1H/2(R,"(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G8V]M<&]S
M92YP;F<G+"!?*")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D(BDL("=A;&EG
M;CTB;6ED9&QE(B<I(#\^"B`@("`@("`@("`@("`@("`@("`@("`\+W1D/@H@
M("`@("`@("`@("`@("`@("`@("`@/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG
M;B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5C:&\@2&]R9&4Z
M.FQI;FLH)R,G+"!?*")3=VET8V@@0V]M<&]S:71I;VX@365T:&]D(BDL("<G
M+"`G)RP@(F1O8W5M96YT+F-O;7!O<V4N<G1E;6]D92YV86QU93TG(B`N("@D
M<G1E;6]D92`_(#`@.B`Q*2`N("(G.R!U;FEQ4W5B;6ET*"D[(')E='5R;B!F
M86QS93LB*2`_/@H@("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!E8VAO
M("1R=&5M;V1E(#\@7R@B4W=I=&-H('1O('!L86EN('1E>'0@8V]M<&]S:71I
M;VXB*2`Z(%\H(E-W:71C:"!T;R!(5$U,(&-O;7!O<VET:6]N(BD@/SX\+V$^
M"B`@("`@("`@("`@("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@
M("`@(#PO='(^"B`@("`@("`@("`@("`@("`@(#PO=&%B;&4^"B`@("`@("`@
M("`@("`@("`\+W1D/@H@("`@("`@("`@("`@(#PO='(^"CP_<&AP(&5N9&EF
M.R`_/@H@("`@("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@/"]T9#X*("`@
M("`@("`\+W1R/@H@("`@("`\+W1A8FQE/@H@("`@/"]T9#X*("`\+W1R/@H*
M("`\='(^"B`@("`\=&0@8VQA<W,](FQI9VAT(')I9VAT06QI9VXB('9A;&EG
M;CTB=&]P(CX\<W1R;VYG/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=M97-S
M86=E)RP@7R@B5&5?>'0B*2D@/SXF;F)S<#L\+W-T<F]N9SX\+W1D/@H@("`@
M/'1D(&-L87-S/2)I=&5M(CX*("`@("`@/'1E>'1A<F5A(&-L87-S/2)C;VUP
M;W-E8F]D>2(@=&%B:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB
M(&YA;64](FUE<W-A9V4B(&ED/2)M97-S86=E(B!R;W=S/2(R,"(@8V]L<STB
M.#`B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;7-G*2`_/CPO=&5X
M=&%R96$^"B`@("`\+W1D/@H@(#PO='(^"@H@(#QT<CX*("`@(#QT9#XF;F)S
M<#L\+W1D/@H@("`@/'1D/@H@("`@("`\=&%B;&4@=VED=&@](C$P,"4B(&-E
M;&QS<&%C:6YG/2(P(CX*("`@("`@("`\='(^"B`@("`@("`@("`\=&0@8VQA
M<W,](FQE9G1!;&EG;B(@;F]W<F%P/2)N;W=R87`B/@H@("`@("`@("`@("`\
M:6YP=70@;F%M93TB8G1N7W-E;F1?;65S<V%G92(@='EP93TB<W5B;6ET(B`\
M/W!H<"!E8VAO($AO<F1E.CIG971!8V-E<W-+97E!;F14:71L92A?*")?4V5N
M9"!-97-S86=E(BDL('1R=64I(#\^(&-L87-S/2)B=71T;VXB(&]N8VQI8VL]
M(G)E='5R;B!U;FEQ4W5B;6ET*"=S96YD7VUE<W-A9V4G*3LB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(E-E;F0@365S<V%G92(I(#\^(B`O/@H\/W!H<"!I9B`H
M)&-O;F9;)W5S97(G75LG86QL;W=?9F]L9&5R<R==*3H@/SX*("`@("`@("`@
M("`@/&EN<'5T(&YA;64](F)T;E]S879E7V1R869T(B!T>7!E/2)S=6)M:70B
M(#P_<&AP(&5C:&\@2&]R9&4Z.F=E=$%C8V5S<TME>4%N9%1I=&QE*%\H(E-A
M=F4@7T1R869T(BDL('1R=64I(#\^(&-L87-S/2)B=71T;VXB(&]N8VQI8VL]
M(G5N:7%3=6)M:70H)W-A=F5?9')A9G0G*3LB('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(E-A=F4@1')A9G0B*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^"B`@("`@
M("`@("`@(#QI;G!U="!N86UE/2)B=&Y?8V%N8V5L7V-O;7!O<V4B('1Y<&4]
M(G-U8FUI="(@=&ET;&4](CP_<&AP(&5C:&\@7R@B0V%N8V5L($UE<W-A9V4B
M*2`_/B(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB<F5T=7)N(&-O;F9I<FU#
M86YC96PH*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-A;F-E;"!-97-S86=E
M(BD@/SXB("\^"B`@("`@("`@("`\+W1D/@H@("`@("`@("`@/'1D(&-L87-S
M/2)R:6=H=$%L:6=N(B!S='EL93TB<&%D9&EN9SHR<'@B/CP_<&AP(&5C:&\@
M2&5L<#HZ;&EN:R@G:6UP)RP@)V-O;7!O<V4M8G5T=&]N<R<I(#\^/"]T9#X*
M("`@("`@("`\+W1R/@H\/W!H<"!I9B`H)'!R969S+3YG971686QU92@G=7-E
M7W!G<"<I('Q\("1P<F5F<RT^9V5T5F%L=64H)W5S95]S;6EM92<I*3H@/SX*
M("`@("`@("`\='(^"B`@("`@("`@("`\=&0@8VQA<W,](FET96T@;&5F=$%L
M:6=N(B!N;W=R87`](FYO=W)A<"(^"B`@("`@("`@("`@("9N8G-P.SP_<&AP
M(&5C:&\@2&]R9&4Z.FQA8F5L*"=E;F-R>7!T7V]P=&EO;G,G+"!?*")%;F-R
M7WEP=&EO;B!/<'1I;VYS(BDI(#\^.B9N8G-P.PH@("`@("`@("`@("`\<V5L
M96-T(&ED/2)E;F-R>7!T7V]P=&EO;G,B(&YA;64](F5N8W)Y<'1?;W!T:6]N
M<R(^"CP_<&AP"B`@("`D96YC<GEP=$]P="`](%5T:6PZ.F=E=$9O<FU$871A
M*"=E;F-R>7!T7V]P=&EO;G,G*3L*("`@(')E<75I<F4@24U07U1%35!,051%
M4R`N("<O8V]M<&]S92]E;F-R>7!T7VQI<W0N:6YC)SL*/SX*("`@("`@("`@
M("`@/"]S96QE8W0^"B`@("`@("`@("`\+W1D/@H@("`@("`@("`@/'1D(&-L
M87-S/2)I=&5M(')I9VAT06QI9VXB/CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G
M:6UP)RP@)V-O;7!O<V4M;W!T:6]N<RUE;F-R>7!T)RD@/SXF;F)S<#L\+W1D
M/@H@("`@("`@(#PO='(^"CP_<&AP(&EF("@D<')E9G,M/F=E=%9A;'5E*"=U
M<V5?<&=P)RD@)B8@)'!R969S+3YG971686QU92@G<&=P7W!U8FQI8U]K97DG
M*2DZ(#\^"B`@("`@("`@/'1R/@H@("`@("`@("`@/'1D(&-L87-S/2)I=&5M
M(&QE9G1!;&EG;B(@;F]W<F%P/2)N;W=R87`B/@H@("`@("`@("`@("`\:6YP
M=70@:60](G!A<"(@='EP93TB8VAE8VMB;W@B(&YA;64](G!G<%]A='1A8VA?
M<'5B:V5Y(B`\/W!H<"!I9B`H571I;#HZ9V5T1F]R;41A=&$H)W!G<%]A='1A
M8VA?<'5B:V5Y)RP@)'!R969S+3YG971686QU92@G<&=P7V%T=&%C:%]P=6)K
M97DG*2DI(&5C:&\@)V-H96-K960](F-H96-K960B("<@/SXO/@H@("`@("`@
M("`@("`\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G<&%P)RP@7R@B071T86-H
M(&$@8V]P>2!O9B!Y;W5R(%!'4"!P=6)L:6,@:V5Y('1O('EO=7(@;65S<V%G
M93\B*2D@/SX*("`@("`@("`@(#PO=&0^"B`@("`@("`@("`\=&0@8VQA<W,]
M(FET96T@<FEG:'1!;&EG;B(^/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G
M+"`G<&=P+6-O;7!O<V4M871T86-H+7!U8FME>2<I(#\^)FYB<W`[/"]T9#X*
M("`@("`@("`\+W1R/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@96YD:68[(#\^
M"B`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H@(#PO='(^"@H\/W!H<"!I9B`H
M)&EM<%LG9FEL95]U<&QO860G72DZ(#\^"B`@/'1R/@H@("`@/'1D(&-O;'-P
M86X](C(B/B9N8G-P.SPO=&0^"B`@/"]T<CX*"B`@/'1R(&-L87-S/2)H96%D
M97(B/@H@("`@/'1D(&-O;'-P86X](C(B(&AE:6=H=#TB,C4B(&-L87-S/2)H
M96%D97(B/@H@("`@("`\<W1R;VYG/B9N8G-P.SQA(&ED/2)A='1A8VAM96YT
M<R(^/"]A/CP_<&AP(&5C:&\@7R@B071T86-H;65N=',B*2`_/CPO<W1R;VYG
M/@H\/W!H<"!I9B`H)$=,3T)!3%-;)W)E9VES=')Y)UTM/FAA<TUE=&AO9"@G
M9FEL97,O<V5L96-T;&ES=$QI;FLG*2DZ(#\^"B9N8G-P.SP_<&AP(&5C:&\@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)V9I;&5S+W-E;&5C=&QI<W1,
M:6YK)RP@87)R87DH7R@B071T86-H($9I;&5S(BDL("=W:61G970G+"`G8V]M
M<&]S92<L('1R=64I*3L@/SX*("`@("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB<V5L96-T;&ES=%]S96QE8W1I9"(@=F%L=64](B(@+SX*/#]P:'`@
M96YD:68[(#\^"B`@("`\+W1D/@H@(#PO='(^"@H@(#QT<CX*("`@(#QT9#XF
M;F)S<#L\+W1D/@H@("`@/'1D(&-L87-S/2)I=&5M(CX*("`@("`@/'1A8FQE
M('=I9'1H/2(Q,#`E(CX*("`@("`@("`\='(^"CP_<&AP(&EF("@A)&EM<%]C
M;VUP;W-E+3YM87A!='1A8VAM96YT4VEZ92@I*3H@/SX*("`@("`@("`@(#QT
M9"!C;&%S<STB;&5F=$%L:6=N(B!C;VQS<&%N/2(R(CX*("`@("`@("`@("`@
M/#]P:'`@96-H;R!?*")-87AI;75M('1O=&%L(&%T=&%C:&UE;G0@<VEZ92!R
M96%C:&5D+B(I(#\^"B`@("`@("`@("`\+W1D/@H\/W!H<"!E;'-E.B!I9B`H
M(6ES<V5T*"1A='1A8VAM96YT<RDI.B`_/@H@("`@("`@("`@/'1D(&-L87-S
M/2)L969T06QI9VXB(&-O;'-P86X](C(B/@H@("`@("`@("`@("`\/W!H<"!E
M8VAO(%\H(DUA>&EM=6T@;G5M8F5R(&]F(&%T=&%C:&UE;G1S(')E86-H960N
M(BD@/SX*("`@("`@("`@(#PO=&0^"CP_<&AP(&5L<V4Z(#\^"B`@("`@("`@
M("`\=&0@8VQA<W,](FQE9G1!;&EG;B(^"B`@("`@("`@("`@(#QT86)L93X*
M("`@("`@("`@("`@("`\='(@:60](F%T=&%C:&UE;G1?<F]W7S$B/@H@("`@
M("`@("`@("`@("`@/'1D(&-L87-S/2)L969T06QI9VXB/@H@("`@("`@("`@
M("`@("`@("`\<W1R;VYG/CP_<&AP(&5C:&\@7R@B1FEL92(I(#\^(#$Z/"]S
M=')O;F<^)FYB<W`[/&EN<'5T(&YA;64](G5P;&]A9%\Q(B!T86)I;F1E>#TB
M/#]P:'`@96-H;R`D=&%B:6YD97@K*R`_/B(@='EP93TB9FEL92(@;VYC:&%N
M9V4](F%T=&%C:&UE;G1#:&%N9V5D*"DB('-I>F4](C(U(B!C;&%S<STB9FEX
M960B('-T>6QE/2)D:7)E8W1I;VXZ;'1R(B`O/@H@("`@("`@("`@("`@("`@
M/"]T9#X*("`@("`@("`@("`@("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N(CX*
M("`@("`@("`@("`@("`@("`@/'-E;&5C="!N86UE/2)U<&QO861?9&ES<&]S
M:71I;VY?,2(^"B`@("`@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M871T86-H;65N="(@<V5L96-T960](G-E;&5C=&5D(CX\/W!H<"!E8VAO(%\H
M(D%T=&%C:&UE;G0B*2`_/CPO;W!T:6]N/@H@("`@("`@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](FEN;&EN92(^/#]P:'`@96-H;R!?*"));FQI;F4B
M*2`_/CPO;W!T:6]N/@H@("`@("`@("`@("`@("`@("`\+W-E;&5C=#X*("`@
M("`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@/"]T<CX*("`@("`@
M("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,B(^
M"B`@("`@("`@("`@("`@("`@("@\/W!H<"!E8VAO(%\H(DUA>&EM=6T@071T
M86-H;65N="!3:7IE(BD@+B`G.B`G("X@;G5M8F5R7V9O<FUA="@D:6UP7V-O
M;7!O<V4M/FUA>$%T=&%C:&UE;G13:7IE*"DI("X@)R`G("X@7R@B8GET97,B
M*2`_/BD*("`@("`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@/"]T
M<CX*("`@("`@("`@("`@/"]T86)L93X*("`@("`@("`@(#PO=&0^"CP_<&AP
M(&5N9&EF.R`_/@H\/W!H<"!E;F1I9CL@/SX*("`@("`@("`@(#QT9#X*("`@
M("`@("`@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB8G1N7V%D9%]A
M='1A8VAM96YT(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)U;FEQ4W5B;6ET
M*"=A9&1?871T86-H;65N="<I.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B57!D
M871E(BD@/SXB("\^"B`@("`@("`@("`\+W1D/@H@("`@("`@("`@/'1D(&-L
M87-S/2)R:6=H=$%L:6=N(CX\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEM<"<L
M("=C;VUP;W-E+6%T=&%C:"<I(#\^)FYB<W`[/"]T9#X*("`@("`@("`\+W1R
M/@H@("`@("`\+W1A8FQE/@H@("`@/"]T9#X*("`\+W1R/@H*/#]P:'`*("`@
M("1S879E7V%T=&%C:"`]("1P<F5F<RT^9V5T5F%L=64H)W-A=F5?871T86-H
M;65N=',G*3L*("`@("1S:&]W7VQI;FM?871T86-H(#T@*"1C;VYF6R=C;VUP
M;W-E)UU;)VQI;FM?871T86-H;65N=',G72`F)B`A)&-O;F9;)V-O;7!O<V4G
M75LG;&EN:U]A;&Q?871T86-H;65N=',G72D["B`@("`D<VAO=U]S879E7V%T
M=&%C:"`]('-T<G!O<R@D<V%V95]A='1A8V@L("=P<F]M<'0G*2`]/3T@,#L*
M/SX*/#]P:'`@:68@*"1S:&]W7VQI;FM?871T86-H('Q\("1S:&]W7W-A=F5?
M871T86-H*3H@/SX*("`\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`@(#QT
M9"!C;&%S<STB:71E;2(^"B`@("`@(#QT86)L92!W:61T:#TB,3`P)2(@8V5L
M;'-P86-I;F<](C(B/@H\/W!H<"!I9B`H)'-H;W=?<V%V95]A='1A8V@I.B`_
M/@H\/W!H<"`D<V%V95]A='1A8VA?=F%L(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W-A=F5?871T86-H;65N='-?<V5L96-T)RP@*"1S879E7V%T=&%C:"`]/2`G
M<')O;7!T7WEE<R<I*3L@/SX*("`@("`@("`\='(^"B`@("`@("`@("`\=&0@
M8VQA<W,](FQE9G1!;&EG;B(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E-A=F4@
M071T86-H;65N=',@=VET:"!M97-S86=E(&EN('-E;G0M;6%I;"!F;VQD97(_
M(BD@/SX\+W-T<F]N9SXF;F)S<#L\+W1D/@H@("`@("`@("`@/'1D(&-L87-S
M/2)L969T06QI9VXB/@H@("`@("`@("`@("`\<V5L96-T(&YA;64](G-A=F5?
M871T86-H;65N='-?<V5L96-T(CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(Q(CP_<&AP(&EF("@D<V%V95]A='1A8VA?=F%L(#T](#$I(&5C:&\@
M)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CX\/W!H<"!E8VAO(%\H(EEE<R(I
M(#\^/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB,"(\
M/W!H<"!I9B`H)'-A=F5?871T86-H7W9A;"`]/2`P*2!E8VAO("<@<V5L96-T
M960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!?*").;R(I(#\^/"]O<'1I
M;VX^"B`@("`@("`@("`@(#PO<V5L96-T/@H@("`@("`@("`@/"]T9#X*("`@
M("`@("`@(#QT9"!C;&%S<STB:71E;2!R:6=H=$%L:6=N(CX\/W!H<"!E8VAO
M($AE;'`Z.FQI;FLH)VEM<"<L("=C;VUP;W-E+7-A=F4M871T86-H;65N=',G
M*2`_/B9N8G-P.SPO=&0^"B`@("`@("`@/"]T<CX*/#]P:'`@96YD:68[(#\^
M"CP_<&AP(&EF("@D<VAO=U]L:6YK7V%T=&%C:"DZ(#\^"CP_<&AP("1L:6YK
M7V%T=&%C:%]V86P@/2!5=&EL.CIG971&;W)M1&%T82@G;&EN:U]A='1A8VAM
M96YT<R<I.R`_/@H@("`@("`@(#QT<CX*("`@("`@("`@(#QT9"!C;&%S<STB
M;&5F=$%L:6=N(CX\<W1R;VYG/CP_<&AP(&5C:&\@7R@B3&EN:R!!='1A8VAM
M96YT<S\B*2`_/CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@("`@("`@("`\=&0@
M8VQA<W,](FQE9G1!;&EG;B(^"B`@("`@("`@("`@(#QS96QE8W0@;F%M93TB
M;&EN:U]A='1A8VAM96YT<R(^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU
M93TB,2(\/W!H<"!I9B`H)&QI;FM?871T86-H7W9A;"`]/2`Q*2!E8VAO("<@
M<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!?*")997,B*2`_
M/CPO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](C`B/#]P
M:'`@:68@*"1L:6YK7V%T=&%C:%]V86P@/3T@,"D@96-H;R`G('-E;&5C=&5D
M/2)S96QE8W1E9"(G(#\^/CP_<&AP(&5C:&\@7R@B3F\B*2`_/CPO;W!T:6]N
M/@H@("`@("`@("`@("`\+W-E;&5C=#X*("`@("`@("`@(#PO=&0^"B`@("`@
M("`@("`\=&0@8VQA<W,](FET96T@<FEG:'1!;&EG;B(^/#]P:'`@96-H;R!(
M96QP.CIL:6YK*"=I;7`G+"`G8V]M<&]S92UL:6YK+6%T=&%C:&UE;G1S)RD@
M/SXF;F)S<#L\+W1D/@H@("`@("`@(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H@
M("`@("`\+W1A8FQE/@H@("`@/"]T9#X*("`\+W1R/@H\/W!H<"!E;F1I9CL@
M/SX*/#]P:'`@:68@*"1I;7!?8V]M<&]S92T^;G5M8F5R3V9!='1A8VAM96YT
M<R@I*3H@/SX*("`\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`@(#QT9"!C
M;&%S<STB:71E;2(^"B`@("`@(#QT86)L92!W:61T:#TB,3`P)2(^"B`@("`@
M("`@/'1R/@H@("`@("`@("`@/'1D(&-L87-S/2)L969T06QI9VXB/@H@("`@
M("`@("`@("`\=&%B;&4@8VQA<W,](FET96TB(&-E;&QS<&%C:6YG/2(R(CX*
M/#]P:'`*("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`G.PH@("`@)&UI;65?8V]N=&5N=',@/2`F;F5W($U)345?0V]N=&5N=',H
M;F5W($U)345?4&%R="@I*3L*("`@("1L;V-A;&5I;F9O(#T@3DQ3.CIG971,
M;V-A;&5);F9O*"D["@H@("`@9F]R96%C:"`H)&EM<%]C;VUP;W-E+3YG971!
M='1A8VAM96YT<R@I(&%S("1F:6QE7VYU;2`]/B`D;6EM92D@>PH@("`@("`@
M("1F:6QE7VYU;2LK.PH@("`@("`@("1D:7-P;W-I=&EO;B`]("1M:6UE+3YG
M971$:7-P;W-I=&EO;B@I.PH@("`@("`@("1V:65W97(@/2`F)&UI;65?8V]N
M=&5N=',M/F=E=$U)3456:65W97(H)&UI;64I.PH@("`@("`@("1L:6YK960@
M/2!5=&EL.CIG971&;W)M1&%T82`H<W!R:6YT9B@G9FEL95]L:6YK961?)60G
M+"`D9FEL95]N=6TI*3L*("`@("`@("!I9B`H)&UI;64M/F=E=%1Y<&4H*2`A
M/2`G87!P;&EC871I;VXO;V-T970M<W1R96%M)RD@>PH@("`@("`@("`@("`D
M<')E=FEE=U]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=V:65W+G!H<"<I+"!A<G)A>2@G86-T:6]N240G(#T^("=C
M;VUP;W-E7V%T=&%C:%]P<F5V:65W)RP@)VED)R`]/B`D9FEL95]N=6TL("=M
M97-S86=E0V%C:&4G(#T^("1I;7!?8V]M<&]S92T^9V5T365S<V%G94-A8VAE
M260H*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P<F5V:65W
M7W5R;"`](&YU;&P["B`@("`@("`@?0H@("`@("`@(')E<75I<F4@24U07U1%
M35!,051%4R`N("<O8V]M<&]S92]A='1A8VAM96YT<RYI;F,G.PH@("`@?0H_
M/@H@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@(#QT9#XF;F)S
M<#L\+W1D/@H@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@/'1R
M/@H@("`@("`@("`@("`@("`@/'1D(&-O;'-P86X](C0B(&-L87-S/2)L969T
M06QI9VXB/CQS=')O;F<^/#]P:'`@96-H;R!?*")4;W1A;"!!='1A8VAM96YT
M<R!3:7IE.B(I(#\^/"]S=')O;F<^(#P_<&AP(&5C:&\@;G5M8F5R7V9O<FUA
M="@D:6UP7V-O;7!O<V4M/G-I>F5/9D%T=&%C:&UE;G1S*"D@+R`Q,#(T+"`R
M+"`D;&]C86QE:6YF;ULG9&5C:6UA;%]P;VEN="==+"`G)RD@/SX@/#]P:'`@
M96-H;R!?*")+0B(I(#\^/"]T:#X*("`@("`@("`@("`@("`\+W1R/@H@("`@
M("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@/"]T9#X*("`@("`@("`@(#QT
M9"!C;&%S<STB<FEG:'1!;&EG;B(@=F%L:6=N/2)T;W`B/CP_<&AP(&5C:&\@
M2&5L<#HZ;&EN:R@G:6UP)RP@)V-O;7!O<V4M871T86-H;65N=',G*2`_/B9N
M8G-P.SPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@/"]T86)L93X*("`@(#PO
M=&0^"B`@/"]T<CX*/#]P:'`@96YD:68[(#\^"CP_<&AP(&5N9&EF.R`_/@H*
M/"]T86)L93X*/"]F;W)M/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+W1E;7!L871E<R]C;VUP;W-E+W)E9&ER96-T+FEN8P``````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,S`W-@`Q,#0Q-S,V,C<V-@`P,C,Q-C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"F9U;F-T:6]N(&-O;F9I<FU#86YC
M96PH*0I["B`@("!I9B`H=VEN9&]W+F-O;F9I<FTH)SP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")#86YC96QL:6YG('1H:7,@;65S<V%G92!W:6QL('!E<FUA
M;F5N=&QY(&1I<V-A<F0@:71S(&-O;G1E;G1S+B(I*2`N("=<;B<@+B!A9&1S
M;&%S:&5S*%\H(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D;R!T:&ES/R(I
M*2`_/B<I*2!["B`@("`@("`@/#]P:'`@96-H;R`D8V%N8V5L7VIS(#\^"B`@
M("!]"GT*"F9U;F-T:6]N(')E9&ER96-T4W5B;6ET*"D*>PH@("`@:68@*&1O
M8W5M96YT+G)E9&ER96-T+G1O+G9A;'5E(#T]("<G*2!["B`@("`@("`@86QE
M<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")9;W4@;75S="!S<&5C:69Y
M(&$@<F5C:7!I96YT+B(I*2`_/B<I.PH@("`@("`@(&1O8W5M96YT+G)E9&ER
M96-T+G1O+F9O8W5S*"D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@(')E='5R;B!T<G5E.PI]"@IF=6YC=&EO;B!U;FEQ4W5B;6ET*"D*>PH@
M("`@;F]W(#T@;F5W($1A=&4H*3L*("`@(&1O8W5M96YT+G)E9&ER96-T+G-U
M8FUI=$)T;BYD:7-A8FQE9"`]('1R=64["B`@("!D;V-U;65N="YR961I<F5C
M="YC86YC96Q"=&XN9&ES86)L960@/2!T<G5E.PH@("`@:68@*&1O8W5M96YT
M+G)E9&ER96-T+G-T>6QE("8F(&1O8W5M96YT+G)E9&ER96-T+G-T>6QE+F-U
M<G-O<BD@>PH@("`@("`@(&1O8W5M96YT+G)E9&ER96-T+G-T>6QE+F-U<G-O
M<B`](")W86ET(CL*("`@('T*("`@(&1O8W5M96YT+G)E9&ER96-T+G-U8FUI
M="@I.PI]"B\O+2T^"CPO<V-R:7!T/@H*/&9O<FT@;65T:&]D/2)P;W-T(B!A
M8W1I;VX](CP_<&AP(&5C:&\@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU
M<FPH)V-O;7!O<V4N<&AP)RDL("=U;FEQ)RP@8F%S95]C;VYV97)T*&UI8W)O
M=&EM92@I+"`Q,"P@,S8I*2`_/B(@;F%M93TB<F5D:7)E8W0B/@H\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)M86EL8F]X(B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1M86EL8F]X*2`_/B(@+SX*/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB:6YD97@B('9A;'5E/2(\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)&EN9&5X*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)R961I<F5C=%]S96YD(B`O
M/@H*/#]P:'`@96-H;R!)35`Z.G-T871U<R@I.R`D=&%B:6YD97@@/2`P.R`_
M/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@(#P_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D=&ET;&4I(#\^"CPO:#$^"CQT86)L92!W:61T:#TB,3`P)2(@
M8F]R9&5R/2(P(B!C96QL<&%D9&EN9STB,"(@8V5L;'-P86-I;F<](C`B/@H\
M/W!H<"!I9B`H)$=,3T)!3%-;)W)E9VES=')Y)UTM/FAA<TUE=&AO9"@G8V]N
M=&%C=',O<V5A<F-H)RDI.B`_/@H\/W!H<"`D8V]N=&%C='-?=7)L(#T@571I
M;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G8V]N=&%C
M=',N<&AP)RDL(&%R<F%Y*"=F;W)M;F%M92<@/3X@)W)E9&ER96-T)RP@)W1O
M7V]N;'DG(#T^(#$I*3L@/SX*/'1R/@H@(#QT9#XF;F)S<#L\+W1D/@H@(#QT
M9"!C;&%S<STB:71E;2(^"B`@("`\=&%B;&4@8V5L;'-P86-I;F<](C`B('=I
M9'1H/2(Q,#`E(CX*("`@("`@/'1R/@H@("`@("`@(#QT9"!A;&EG;CTB8V5N
M=&5R(CX\/W!H<"!E8VAO($AO<F1E.CIL:6YK*"<C)RP@7R@B061D<F5S<R!"
M;V]K(BDL("=W:61G970G+"!N=6QL+"`G=VEN9&]W+F]P96XH7"<G("X@)&-O
M;G1A8W1S7W5R;"`N("=<)RP@7"=C;VYT86-T<UPG+"!<)W1O;VQB87(];F\L
M;&]C871I;VX];F\L<W1A='5S/6YO+'-C<F]L;&)A<G,]>65S+')E<VEZ86)L
M93UY97,L=VED=&@]-34P+&AE:6=H=#TS,#`L;&5F=#TQ,#`L=&]P/3$P,%PG
M*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G861D<F5S<V)O;VM?
M8G)O=W-E+G!N9R<I("X@)SQB<B`O/B<@+B!?*")!9&1R97-S($)O;VLB*2`N
M("<\+V$^)R`_/CPO=&0^"B`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B/CP_
M<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)R,G+"!?*")%>'!A;F0@3F%M97,B*2P@
M)W=I9&=E="<L(&YU;&PL(")D;V-U;65N="YR961I<F5C="YA8W1I;VY)1"YV
M86QU93TG<F5D:7)E8W1?97AP86YD7V%D9'(G.R!U;FEQ4W5B;6ET*"D[(')E
M='5R;B!F86QS93LB*2`N($AO<F1E.CII;6<H)V5X<&%N9"YP;F<G*2`N("<\
M8G(@+SXG("X@7R@B17AP86YD($YA;65S(BD@+B`G/"]A/B<@/SX\+W1D/@H@
M("`@("`\+W1R/@H@("`@/"]T86)L93X*("`\+W1D/@H\+W1R/@H\/W!H<"!E
M;F1I9CL@/SX*"CQT<CX*("`\=&0@8VQA<W,](FQI9VAT(')I9VAT06QI9VXB
M('9A;&EG;CTB;6ED9&QE(CX\<W1R;VYG/CP_<&AP(&5C:&\@2&]R9&4Z.FQA
M8F5L*"=T;R<L(%\H(E1O(BDI(#\^)FYB<W`[/"]S=')O;F<^/"]T9#X*("`\
M=&0@8VQA<W,](FET96T@;&5F=$%L:6=N(CX*("`@("`@/'1A8FQE(&)O<F1E
M<CTB,"(@=VED=&@](C$P,"4B(&-E;&QP861D:6YG/2(P(CX*/#]P:'`@:68@
M*&ES7V%R<F%Y*"1H96%D97);)W1O)UTI*3H@)&9I<G-T7W1O(#T@=')U93L@
M/SX*/#]P:'`@9F]R96%C:"`H)&AE861E<ELG=&\G72!A<R`D=&]?:71E;2DZ
M(#\^"B`@("`@("`@/'1R/@H\/W!H<"!I9B`H8V]U;G0H)'1O7VET96TI(#X@
M,2DZ(#\^"B`@("`@("`@("`\=&0@8VQA<W,](FQE9G1!;&EG;B(^"B`@("`@
M("`@("`@(#QT86)L92!B;W)D97(](C`B(&-E;&QS<&%C:6YG/2(P(B!C96QL
M<&%D9&EN9STB,"(^"B`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@
M("`@/'1D('=I9'1H/2(S-3`B/@H@("`@("`@("`@("`@("`@("`\<V5L96-T
M(&ED/2)T;R(@=&%B:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB
M(&YA;64](G1O7VQI<W1;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1T
M;U]I=&5M6S!=*2`_/ETB('-T>6QE/2)W:61T:#HS-3!P>"(^"B`@("`@("`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB(B!S96QE8W1E9#TB<V5L96-T
M960B/CP_<&AP(&5C:&\@7R@B4&QE87-E('-E;&5C="!O<B!E9&ET(&EN('1H
M92!B;W@@=&\@=&AE(')I9VAT.B(I(#\^/"]O<'1I;VX^"CP_<&AP(&9O<B`H
M)&D@/2`Q.R`D:2`\(&-O=6YT*"1T;U]I=&5M*3L@)&DK*RDZ(#\^"B`@("`@
M("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1T;U]I=&5M6R1I72D@/SXB/CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D=&]?:71E;5LD:5TI(#\^/"]O<'1I;VX^"CP_<&AP
M(&5N9&9O<CL@/SX*("`@("`@("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@
M("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@/'1D('=I9'1H/2(Q
M-3`B/@H@("`@("`@("`@("`@("`@("`\:6YP=70@='EP93TB=&5X="(@<VEZ
M93TB,34B('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^(B!C
M;&%S<STB9FEX960B(&YA;64](G1O7V9I96QD6SP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D=&]?:71E;5LP72D@/SY=(B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1T;U]I=&5M6S!=*2`_/B(@<W1Y;&4](G=I
M9'1H.C$U,'!X(B`O/@H@("`@("`@("`@("`@("`@/"]T9#X*("`@("`@("`@
M("`@("`\+W1R/@H@("`@("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@/"]T
M9#X*/#]P:'`@96QS93H@/SX*("`@("`@("`@(#QT9"!C;&%S<STB;&5F=$%L
M:6=N(CX\:6YP=70@='EP93TB=&5X="(@:60](G1O(B!S:7IE/2(U-2(@=&%B
M:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB(&-L87-S/2)F:7AE
M9"(@;F%M93TB=&]?9FEE;&1;72(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D=&]?:71E;2D@/SXB("\^/"]T9#X*/#]P:'`@96YD:68[
M(#\^"CP_<&AP(&EF("@D9FER<W1?=&\I.B`D9FER<W1?=&\@/2!F86QS93L@
M/SX*("`@("`@("`@(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(^/#]P:'`@96-H
M;R!(96QP.CIL:6YK*"=I;7`G+"`G8V]M<&]S92UT;R<I(#\^)FYB<W`[/"]T
M9#X*/#]P:'`@96QS93H@/SX*("`@("`@("`@(#QT9#XF;F)S<#L\+W1D/@H\
M/W!H<"!E;F1I9CL@/SX*("`@("`@("`\+W1R/@H\/W!H<"!E;F1F;W)E86-H
M.R`_/@H@("`@("`@(#QT<CX*("`@("`@("`@(#QT9"!C;&%S<STB;&5F=$%L
M:6=N(CX\:6YP=70@='EP93TB=&5X="(@:60](G1O(B!S:7IE/2(U-2(@=&%B
M:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB(&-L87-S/2)F:7AE
M9"(@;F%M93TB=&]?;F5W(B`O/CPO=&0^"B`@("`@("`@("`\=&0^)FYB<W`[
M/"]T9#X*("`@("`@("`\+W1R/@H\/W!H<"!E;'-E.B`_/@H@("`@("`@(#QT
M<CX*("`@("`@("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N(CX\:6YP=70@='EP
M93TB=&5X="(@:60](G1O(B!S:7IE/2(U-2(@=&%B:6YD97@](CP_<&AP(&5C
M:&\@)'1A8FEN9&5X*RL@/SXB(&-L87-S/2)F:7AE9"(@;F%M93TB=&\B('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&AE861E<ELG=&\G
M72D@/SXB(#P_<&AP(&5C:&\@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=I9G)A
M;65S)RDI(#\@)V]N8VAA;F=E/2)E>'!A;F1&:65L9"AT:&ES*2(@+SX\<W!A
M;B!I9#TB97AP86YD:6YG=&\B(&-L87-S/2)I;E!R;V=R97-S(B!S='EL93TB
M=FES:6)I;&ET>3IH:61D96X[(CXG("X@7R@B17AP86YD:6YG(BD@+B`G)FAE
M;&QI<#L\+W-P86X^)R`Z("<O/B<[(#\^/"]T9#X*("`@("`@("`@(#QT9"!C
M;&%S<STB<FEG:'1!;&EG;B(^/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G
M+"`G8V]M<&]S92UT;R<I(#\^)FYB<W`[/"]T9#X*("`@("`@("`\+W1R/@H\
M/W!H<"!E;F1I9CL@/SX*("`@("`@/"]T86)L93X*("`@(#PO=&0^"B`@/"]T
M<CX\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`@(#QT9#X*("`@("`@/&EN
M<'5T(&YA;64](G-U8FUI=$)T;B(@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T
M=&]N(B!O;F-L:6-K/2)R971U<FX@<F5D:7)E8W13=6)M:70H*3LB('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(E)E9&ER96-T($UE<W-A9V4B*2`_/B(@+SX*("`@
M("`@/&EN<'5T(&YA;64](F-A;F-E;$)T;B(@='EP93TB8G5T=&]N(B!C;&%S
M<STB8G5T=&]N(B!O;F-L:6-K/2)C;VYF:7)M0V%N8V5L*"D[(B!V86QU93TB
M/#]P:'`@96-H;R!?*")#86YC96P@365S<V%G92(I(#\^(B`O/@H@("`@/"]T
M9#X*("`\+W1R/@H\+W1A8FQE/@H\+V9O<FT^"@H\8G(@+SX*"CP_<&AP(&EF
M("@D8G)O=W-E<BT^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*3H@/SX*/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@ID;V-U;65N="YR
M961I<F5C="YT;RYF;V-U<R@I.PH*+R\M+3X*/"]S8W)I<'0^"CP_<&AP(&5N
M9&EF.R`_/@H*/#]P:'`@:68@*"1'3$]"04Q36R=P<F5F<R==+3YG971686QU
M92@G875T;U]E>'!A;F0G*2DZ(#\^"CQI9G)A;64@:60](F%U=&]E>'!A;F0B
M(&YA;64](F%U=&]E>'!A;F0B('-T>6QE/2)W:61T:#HP<'@[:&5I9VAT.C!P
M>#MB;W)D97(M=VED=&@Z,'!X(B!S<F,](CP_<&AP(&5C:&\@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=E>'!A;F0N<&AP)RD@/SXB/CPO:69R86UE/@H\/W!H
M<"!E;F1I9CL@/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M
M<&QA=&5S+V-O;7!O<V4O<W!E;&QI;F<N:6YC````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$T-C`T`#$P-#$W,S8R-S8V`#`R,S$W,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\9F]R;2!M971H;V0](G!O
M<W0B(&YA;64](F-O;7!O<V4B(&5N8W1Y<&4](FUU;'1I<&%R="]F;W)M+61A
M=&$B(&%C=&EO;CTB/#]P:'`@96-H;R!5=&EL.CIA9&1087)A;65T97(H2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"=C;VUP;W-E+G!H<"<I+"`G=6YI<2<L(&)A
M<V5?8V]N=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*2D@/SXB/@H\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)R96QO861E9"(@=F%L=64](C$B("\^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB(B`O
M/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)S<&5L;&-H96-K(B!V86QU
M93TB(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)D;VYE7V%C=&EO
M;B(@=F%L=64](CP_<&AP(&5C:&\@)&9?9&]N95]A8W1I;VX@/SXB("\^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](FUE<W-A9V4B('9A;'5E/2(\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&9?;65S<V%G92D@/SXB("\^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F]L9&US9R(@=F%L=64](CP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9E]O;&1M<V<I(#\^(B`O/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)C=7)R;7-G(B!V86QU93TB/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1F7V-U<G)M<V<I(#\^(B`O/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)N97=M<V<B('9A;'5E/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&9?;F5W;7-G*2`_/B(@+SX*/#]P:'`@
M:68@*"%E;7!T>2@D:6=N;W)E86QL*2DZ(#\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](FEG;F]R96%L;"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<RAS97)I86QI>F4H)&9?:6=N;W)E86QL*2D@/SXB("\^"CP_
M<&AP(&5N9&EF.R`_/@H*/"$M+2!-86EN=&%I;B!S=&%T92`M+3X*/#]P:'`*
M("`@(&9O<F5A8V@@*"1S7W9A<B!A<R`D=F%L*2!["B`@("`@("`@)&9O<FU?
M=F%L(#T@571I;#HZ9V5T1F]R;41A=&$H)'9A;"D["B`@("`@("`@:68@*"%E
M;7!T>2@D9F]R;5]V86PI*2!["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M9F]R;5]V86PI*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9F]R;5]V
M86P@87,@)&ME>3(@/3X@)'9A;#(I('L*("`@("`@("`@("`@("`@("`@("!E
M8VAO("<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(G("X@)'9A;"`N("=;
M)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>3(I("X@)UTB('9A;'5E/2(G("X@
M:'1M;'-P96-I86QC:&%R<R@D=F%L,BD@+B`G(B`O/B<@+B`B7&XB.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@96-H;R`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)R`N("1V
M86P@+B`G(B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&9O<FU?=F%L
M*2`N("<B("\^)R`N(")<;B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@)&-O=6YT(#T@)&D@/2`D;G5M97)R;W)S(#T@,#L*("`@(&EF
M("AI<W-E="@D97)R;W(I("8F(&ES7V%R<F%Y*"1E<G)O<BDI('L*("`@("`@
M("`D;G5M97)R;W)S(#T@8V]U;G0H)&5R<F]R*3L*("`@('T*("`@("1E<G)O
M<G-C;W5N="`]("1E<G)O<G-L969T(#T@)&YU;65R<F]R<SL*"B`@("!I9B`H
M)&YU;65R<F]R<R`^(#`I('L*("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"`D
M97)R;W)S8V]U;G0[("1K*RLI('L*("`@("`@("`@("`@:68@*&EN7V%R<F%Y
M*%-T<FEN9SHZ;&]W97(H)&5R<F]R6R1K75LP72P@=')U92DL("1I9VYO<F5A
M;&PI*2!["B`@("`@("`@("`@("`@("`D97)R;W)S;&5F="TM.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H_/@H*/&@Q(&-L87-S/2)H96%D97(B
M/@H\/W!H<"!I9B`H)&5R<F]R<VQE9G0@/B`P*3H@/SX*(#P_<&AP(&5C:&\@
M7R@B4W!E;&P@0VAE8VME<B(I(#\^("T@/&5M/CP_<&AP(&5C:&\@)&5R<F]R
M<VQE9G0@/SX@/#]P:'`@96-H;R`H)&5R<F]R<VQE9G0@/B`Q*2`_(%\H(G-P
M96QL:6YG(&5R<F]R<R(I(#H@7R@B<W!E;&QI;F<@97)R;W(B*3L@/SX\+V5M
M/@H\/W!H<"!E;'-E.B`_/@H@/#]P:'`@96-H;R!?*")3<&5L;"!C:&5C:R!C
M;VUP;&5T92(I(#\^("T@/#]P:'`@96-H;R!?*").;R!S<&5L;&EN9R!E<G)O
M<G,B*2`_/@H\/W!H<"!E;F1I9CL@/SX*/"]H,3X*"CQT86)L92!W:61T:#TB
M,3`P)2(@8F]R9&5R/2(P(B!C96QL<W!A8VEN9STB,"(@8V5L;'!A9&1I;F<]
M(C$B/@H\/W!H<`H@("`@=VAI;&4@*"@D8V]U;G0@/"`D<')E9G,M/F=E=%9A
M;'5E*"=N=6U?=V]R9',G*2D@)B8@*"1I(#P@)&YU;65R<F]R<RDI('L*("`@
M("`@("!I9B`H(6ES<V5T*"1E<G)O<BD@?'P@(6ES7V%R<F%Y*"1E<G)O<BDI
M('L*("`@("`@("`@("`@96-H;R!?*")3<&5L;"!C:&5C:R!C;VUP;&5T92(I
M.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(&EF("@A
M:6Y?87)R87DH4W1R:6YG.CIL;W=E<B@D97)R;W);)&E=6S!=+"!T<G5E*2P@
M)&EG;F]R96%L;"DI('L*/SX*(#QT<B!C;&%S<STB:71E;2(^"B`@/'1D(&-L
M87-S/2)I=&5M(CX\/W!H<"!E8VAO(%\H(D-O<G)E8W0B*2`_/CPO=&0^"B`@
M/'1D(&-O;'-P86X](C,B(&YO=W)A<#TB;F]W<F%P(CX*/#]P:'`*("`@("`@
M("`@("`@)&]F9G-E="`]("1E<G)O<ELD:5U;,5T["B`@("`@("`@("`@("1W
M;W)D(#T@)&5R<F]R6R1I75LP73L*("`@("`@("`@("`@)&%L="`]("1E<G)O
M<ELD:5U;,ET["B`@("`@("`@("`@(&5C:&\@)SQS<&%N('-T>6QE/2)C;VQO
M<CHC9F8P,#`P(CXB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'=O<F0I("X@)R(\
M+W-P86X^)SL*("`@("`@("`@("`@96-H;R!?*"(@:6X@(BD["B`@("`@("`@
M("`@("1C;VYT97AT(#T@7VAI9VAL:6=H=$5R<F]R*&AT;6QS<&5C:6%L8VAA
M<G,H)'=O<F0I+"!H=&UL<W!E8VEA;&-H87)S*"1F7V-U<G)M<V<I+"!H=&UL
M<W!E8VEA;&-H87)S*"1O9F9S970I*3L*"B`@("`@("`@("`@(&EF("@A96UP
M='DH)&-O;G1E>'0I*2!["B`@("`@("`@("`@("`@("!E8VAO("(\<W!A;B!C
M;&%S<SU<(F9I>&5D7"(^)&-O;G1E>'0\+W-P86X^(CL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&5C:&\@7R@B;F]N92(I.PH@("`@
M("`@("`@("!]"C\^"B`@/"]T9#X*("`\=&0^/'-T<F]N9SX\96T^/#]P:'`@
M96-H;R!?*")#:&%N9V4B*3L@/SX\+V5M/CPO<W1R;VYG/CPO=&0^"B`@/'1D
M/CQS=')O;F<^/&5M/CP_<&AP(&5C:&\@7R@B0VAA;F=E($%L;"(I.R`_/CPO
M96T^/"]S=')O;F<^/"]T9#X*("`\=&0^/#]P:'`@96-H;R!?*"))9VYO<F4B
M*2`_/CPO=&0^"B`@/'1D/CP_<&AP(&5C:&\@7R@B26=N;W)E($%L;"(I(#\^
M/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)I=&5M(CX\<W1R;VYG
M/CP_<&AP(&5C:&\@7R@B4W5G9V5S=&EO;G,B*2`_/CPO<W1R;VYG/CPO=&0^
M"B`@/'1D(&-L87-S/2)I=&5M(CX*("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB;VQD=V]R9%L\/W!H<"!E8VAO("1C;W5N="`_/ETB('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'=O<F0I(#\^(B`O/@H@("`\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)W;W)D;V9F<V5T6SP_<&AP(&5C
M:&\@)&-O=6YT(#\^72(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D;V9F<V5T*2`_/B(@+SX*("`@(#QS96QE8W0@;F%M93TB<W5B<UL\
M/W!H<"!E8VAO("1C;W5N="`_/ETB(&]N8VAA;F=E/2)C:&%N9V5?<V5L96-T
M960H/#]P:'`@96-H;R`D8V]U;G0@/SXI.R(^"CP_<&AP"B`@("`@("`@("`@
M(&EF("@A96UP='DH)&%L="DI('L*("`@("`@("`@("`@("`@("1C:&5C:V5D
M=F%L(#T@,SL*("`@("`@("`@("`@("`@("1A;'1W;W)D<R`](&5X<&QO9&4H
M)RP@)RP@)&%L="D["B`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@
M/"!C;W5N="@D86QT=V]R9',I.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@
M("`@96-H;R`G/&]P=&EO;B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H
M)&%L='=O<F1S6R1J72D@+B`G(CXG("X@:'1M;'-P96-I86QC:&%R<R@D86QT
M=V]R9'-;)&I=*2`N("<\+V]P=&EO;CXG.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-H96-K961V
M86P@/2`S.PH@("`@("`@("`@("`@("`@96-H;R`G/&]P=&EO;B!V86QU93TB
M,"(^)R`N(%\H(DYO('-U9V=E<W1I;VYS(BD@+B`G/"]O<'1I;VX^)SL*("`@
M("`@("`@("`@?0H_/@H@("`\+W-E;&5C=#X*("`\+W1D/@H@(#QT9"!C;&%S
M<STB:71E;2(^/'-T<F]N9SX\/W!H<"!E8VAO("@A96UP='DH)&%L="DI(#\@
M7R@B;W(B*2`Z(%\H(E)E<&QA8V4@=VET:#HB*3L@/SX\+W-T<F]N9SX\+W1D
M/@H@(#QT9"!C;&%S<STB:71E;2(^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64]
M(G-U8G1E>'1;/#]P:'`@96-H;R`D8V]U;G0@/SY=(B!S:7IE/2(Q,B(@;VYC
M:&%N9V4](F-H86YG95]S96QE8W1E9"@\/W!H<"!E8VAO("1C;W5N="`_/BD[
M(B`O/CPO=&0^"B`@/'1D(&-L87-S/2)I=&5M(CX\:6YP=70@='EP93TB<F%D
M:6\B('9A;'5E/2(Q(B!N86UE/2)O<'1;/#]P:'`@96-H;R`D8V]U;G0@/SY=
M(B`\/W!H<"!I9B`H)&-H96-K961V86P@/3T@,2D@96-H;R`G8VAE8VME9#TB
M8VAE8VME9"(G.R`_/B`O/CPO=&0^"B`@/'1D(&-L87-S/2)I=&5M(CX\:6YP
M=70@='EP93TB<F%D:6\B('9A;'5E/2(R(B!N86UE/2)O<'1;/#]P:'`@96-H
M;R`D8V]U;G0@/SY=(B`\/W!H<"!I9B`H)&-H96-K961V86P@/3T@,BD@96-H
M;R`G8VAE8VME9#TB8VAE8VME9"(G.R`_/B`O/CPO=&0^"B`@/'1D(&-L87-S
M/2)I=&5M(CX\:6YP=70@='EP93TB<F%D:6\B('9A;'5E/2(S(B!N86UE/2)O
M<'1;/#]P:'`@96-H;R`D8V]U;G0@/SY=(B`\/W!H<"!I9B`H)&-H96-K961V
M86P@/3T@,RD@96-H;R`G8VAE8VME9#TB8VAE8VME9"(G.R`_/B`O/CPO=&0^
M"B`@/'1D(&-L87-S/2)I=&5M(CX\:6YP=70@='EP93TB<F%D:6\B('9A;'5E
M/2(T(B!N86UE/2)O<'1;/#]P:'`@96-H;R`D8V]U;G0@/SY=(B`\/W!H<"!I
M9B`H)&-H96-K961V86P@/3T@-"D@96-H;R`G8VAE8VME9#TB8VAE8VME9"(G
M.R`_/B`O/CPO=&0^"B`\+W1R/@H\/W!H<`H@("`@("`@("`@("`D8V]U;G0K
M*SL*("`@("`@("!]"B`@("`@("`@)&DK*SL*("`@('T*/SX*(#QT<B!C;&%S
M<STB:71E;2(^"B`@/'1D(&-O;'-P86X](C@B(&-L87-S/2)I=&5M(CX*("`@
M/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB
M9&]C=6UE;G0N8V]M<&]S92YA8W1I;VY)1"YV86QU93TG<W!E;&Q?8VAE8VM?
M8V%N8V5L)SL@9&]C=6UE;G0N8V]M<&]S92YS=6)M:70H*3LB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(D-A;F-E;"(I(#\^(B`O/CQE;3XF;F)S<#L\/W!H<"!E
M8VAO(%\H(BA$:7-C87)D(&%L;"!C:&%N9V5S(&%N9"!R971U<FX@=&\@=&AE
M(&-O;7!O<V4@<V-R965N+BDB*2`_/CPO96T^"B`@/"]T9#X*(#PO='(^"CP_
M<&AP(&EF("@H)&%C=&EO;DE$(#T]("=S<&5L;%]C:&5C:U]F;W)W87)D)RD@
M?'P@*"1E<G)O<G-L969T(#T](#`I*3H@/SX*(#QT<B!C;&%S<STB:71E;2(^
M"B`@/'1D(&-O;'-P86X](C@B(&-L87-S/2)I=&5M(CX*("`@/&EN<'5T('1Y
M<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N
M8V]M<&]S92YA8W1I;VY)1"YV86QU93TG/#]P:'`@96-H;R`D<W!E;&Q?8VAE
M8VM?9&]N95]A8W1I;VX[(#\^)SL@9&]C=6UE;G0N8V]M<&]S92YS=6)M:70H
M*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1O;F4B*2`_/B(@+SX\96T^)FYB
M<W`[/#]P:'`@96-H;R`D<W!E;&Q?8VAE8VM?9&]N95]C87!T:6]N.R`_/CPO
M96T^"B`@/"]T9#X*(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H
M)&5R<F]R<VQE9G0@/B`P*3H@/SX*(#QT<B!C;&%S<STB:71E;2(^"B`@/'1D
M(&-O;'-P86X](C@B(&-L87-S/2)I=&5M(CX*("`@/&EN<'5T('1Y<&4](F)U
M='1O;B(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N8V]M<&]S
M92YA8W1I;VY)1"YV86QU93TG<W!E;&Q?8VAE8VM?9F]R=V%R9"<[(&1O8W5M
M96YT+F-O;7!O<V4N<W5B;6ET*"D[(B!V86QU93TB/#]P:'`@96-H;R!?*").
M97AT(BD@/SXB("\^/&5M/B9N8G-P.SP_<&AP(&5C:&\@7R@B*$%P<&QY('1H
M97-E(&-H86YG97,@86YD(&UO=F4@=&\@;F5X="!S8W)E96XN*2(I(#\^/"]E
M;3X*("`\+W1D/@H@/"]T<CX*/#]P:'`@96YD:68[(#\^"B`\='(^/'1D(&-O
M;'-P86X](C@B/B9N8G-P.SPO=&0^/"]T<CX*/"]T86)L93X*/&@Q(&-L87-S
M/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")#;W)R96-T960@5&5X="(I(#\^
M"CPO:#$^"CQD:78@8VQA<W,](FET96TB/@H@/'-P86X@8VQA<W,](F9I>&5D
M(B!S='EL93TB=VAI=&4M<W!A8V4Z<')E(CX*("`\/W!H<"!E8VAO("1D:7-P
M;&%Y7VUS9R`_/@H@/"]S<&%N/@H\+V1I=CX*"CPO9F]R;3X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+W1E;7!L871E<R]C;VUP;W-E+V-O;7!O<V4N:G,`````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#8S,``Q,#0Q-S,V,C<V-@`P,C(V-C``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IF=6YC=&EO;B!C
M;VYF:7)M0V%N8V5L*"D*>PH@("`@:68@*'=I;F1O=RYC;VYF:7)M*"<\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0V%N8V5L;&EN9R!T:&ES(&UE<W-A9V4@
M=VEL;"!P97)M86YE;G1L>2!D:7-C87)D(&ET<R!C;VYT96YT<RXB*2D@+B`G
M7&XG("X@861D<VQA<VAE<RA?*")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M9&\@=&AI<S\B*2D@/SXG*2D@>PH@("`@("`@(#P_<&AP(&5C:&\@)&-A;F-E
M;%]J<R`_/@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2!E;'-E('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"GT*"CP_<&AP(&EF("@D8G)O=W-E
M<BT^:7-"<F]W<V5R*"=M<VEE)RDI.B`_/@IF=6YC=&EO;B!S=6)J96-T5&%B
M*"D*>PH@("`@:68@*&5V96YT+FME>4-O9&4@/3T@.2`F)B`A979E;G0N<VAI
M9G1+97DI('L*("`@("`@("!E=F5N="YR971U<FY686QU92`](&9A;'-E.PH@
M("`@("`@(&1O8W5M96YT+F-O;7!O<V4N;65S<V%G92YF;V-U<R@I.PH@("`@
M?0I]"CP_<&AP(&5N9&EF.PH*)&IS(#T@(G9A<B!I9&5N=&ET:65S(#T@;F5W
M($%R<F%Y*%QN(CL*9F]R96%C:"`H)&ED96YT:71I97,@87,@)&ED96YT*2![
M"B`@("`D:G,@+CT@)R`@("!N97<@07)R87DH)SL*("`@("1J<R`N/2`G(B<@
M+B!S=')?<F5P;&%C92@B7&XB+"`H)')T96UO9&4@/R`G/&)R("\^)R`Z("<G
M*2`N("=<;B<L(&%D9'-L87-H97,H)&ED96YT6S!=*2D@+B`G(BP@)SL*("`@
M(&EF("@D:61E;G1;,5TI('L*("`@("`@("`D:G,@+CT@)W1R=64L("<["B`@
M("!](&5L<V4@>PH@("`@("`@("1J<R`N/2`G9F%L<V4L("<["B`@("!]"B`@
M("!I9B`H)&-O;F9;)W5S97(G75LG<V5L96-T7W-E;G1M86EL7V9O;&1E<B==
M("8F("$D<')E9G,M/FES3&]C:V5D*"=S96YT7VUA:6Q?9F]L9&5R)RDI('L*
M("`@("`@("`D:G,@+CT@*&ES<V5T*"1I9&5N=%LR72DI(#\@*"<B)R`N("1I
M9&5N=%LR72`N("<B+"`G*2`Z("=N=6QL+"`G.PH@("`@?2!E;'-E('L*("`@
M("`@("`D:G,@+CT@*&ES<V5T*"1I9&5N=%LR72DI(#\@)R)<(B<@+B!)35`Z
M.F1I<W!L87E&;VQD97(H)&ED96YT6S)=*2`N("=<(B(L("<@.B`G(B(L("<[
M"B`@("!]"B`@("!I9B`H)&ED96YT6S-=*2!["B`@("`@("`@)&IS("X]("=T
M<G5E+"`G.PH@("`@?2!E;'-E('L*("`@("`@("`D:G,@+CT@)V9A;'-E+"`G
M.PH@("`@?0H*("`@(&EF("AI<W-E="@D:61E;G1;-%TI*2!["B`@("`@("`@
M)&IS("X]("<B)R`N("1I9&5N=%LT72`N("<B)SL*("`@('T@96QS92!["B`@
M("`@("`@)&IS("X]("<B(B<["B`@("!]"@H@("`@)&IS("X]("(I+%QN(CL*
M?0HD:G,@/2!S=6)S='(H)&IS+"`P+"`M,BD@+B`B7&XB.PIE8VAO("1J<SL*
M/SX**3L*"F9U;F-T:6]N(&-H86YG95]I9&5N=&ET>2AI9"D*>PH@("`@=F%R
M('!O<SL*"B`@("!V87(@;&%S="`](&ED96YT:71I97-;9&]C=6UE;G0N8V]M
M<&]S92YL87-T7VED96YT:71Y+G9A;'5E73L*("`@('9A<B!N97AT(#T@:61E
M;G1I=&EE<UMI9%T["B`@("!V87(@;7-G(#T@9&]C=6UE;G0N8V]M<&]S92YM
M97-S86=E+G9A;'5E+G)E<&QA8V4H+UQR7&XO9RP@)UQN)RD["@H\/W!H<"!I
M9B`H)')T96UO9&4I.B`_/@H@("`@;F5X=%LP72`](&YE>'1;,%TN<F5P;&%C
M92@O7CQB<B!<+SY<;B\L("<G*2YR97!L86-E*"\@*R]G+"`G("<I.R`O+RYR
M97!L86-E*"\\8G(@7"\^+RP@)SQ"4CXG*3L*("`@(&QA<W1;,%T@/2!L87-T
M6S!=+G)E<&QA8V4H+UX\8G(@7"\^7&XO+"`G)RDN<F5P;&%C92@O("LO9RP@
M)R`G*3L@+R\N<F5P;&%C92@O/&)R(%PO/B\L("<\0E(^)RD["CP_<&AP(&5L
M<V4Z(#\^"B`@("!N97AT6S!=(#T@;F5X=%LP72YR97!L86-E*"]>7&XO+"`G
M)RD["B`@("!L87-T6S!=(#T@;&%S=%LP72YR97!L86-E*"]>7&XO+"`G)RD[
M"CP_<&AP(&5N9&EF.R`_/@H*("`@(&EF("AL87-T6S%=*2!["B`@("`@("`@
M<&]S(#T@;7-G+FEN9&5X3V8H;&%S=%LP72D["B`@("!](&5L<V4@>PH@("`@
M("`@('!O<R`](&US9RYL87-T26YD97A/9BAL87-T6S!=*3L*("`@('T*("`@
M(&EF("AP;W,@(3T@+3$I('L*("`@("`@("!I9B`H;F5X=%LQ72`]/2!L87-T
M6S%=*2!["B`@("`@("`@("`@(&US9R`](&US9RYS=6)S=')I;F<H,"P@<&]S
M*2`K(&YE>'1;,%T@*R!M<V<N<W5B<W1R:6YG*'!O<R`K(&QA<W1;,%TN;&5N
M9W1H+"!M<V<N;&5N9W1H*3L*("`@("`@("!](&5L<V4@:68@*&YE>'1;,5TI
M('L*("`@("`@("`@("`@;7-G(#T@;F5X=%LP72`K(&US9RYS=6)S=')I;F<H
M,"P@<&]S*2`K(&US9RYS=6)S=')I;F<H<&]S("L@;&%S=%LP72YL96YG=&@L
M(&US9RYL96YG=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&US
M9R`](&US9RYS=6)S=')I;F<H,"P@<&]S*2`K(&US9RYS=6)S=')I;F<H<&]S
M("L@;&%S=%LP72YL96YG=&@L(&US9RYL96YG=&@I("L@;F5X=%LP73L*("`@
M("`@("!]"B`@("`@("`@9&]C=6UE;G0N8V]M<&]S92YM97-S86=E+G9A;'5E
M(#T@;7-G+G)E<&QA8V4H+UQR7&XO9RP@)UQN)RDN<F5P;&%C92@O7&XO9RP@
M)UQR7&XG*3L*("`@("`@("!D;V-U;65N="YC;VUP;W-E+FQA<W1?:61E;G1I
M='DN=F%L=64@/2!I9#L*("`@("`@("!W:6YD;W<N<W1A='5S(#T@)SP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")4:&4@<VEG;F%T=7)E('=A<R!S=6-C97-S
M9G5L;'D@<F5P;&%C960N(BDI(#\^)SL*("`@('T@96QS92!["B`@("`@("`@
M=VEN9&]W+G-T871U<R`]("<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE
M('-I9VYA='5R92!C;W5L9"!N;W0@8F4@<F5P;&%C960N(BDI(#\^)SL*("`@
M('T*"CP_<&AP(&EF("@D8V]N9ELG=7-E<B==6R=S96QE8W1?<V5N=&UA:6Q?
M9F]L9&5R)UT@)B8@(21P<F5F<RT^:7-,;V-K960H)W-E;G1?;6%I;%]F;VQD
M97(G*2DZ(#\^"B`@("!V87(@9FEE;&0@/2!D;V-U;65N="YC;VUP;W-E+G-E
M;G1?;6%I;%]F;VQD97(["B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&9I96QD
M+F]P=&EO;G,N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H9FEE;&0N;W!T
M:6]N<UMI72YV86QU92`]/2!N97AT6S)=*2!["B`@("`@("`@("`@(&9I96QD
M+G-E;&5C=&5D26YD97@@/2!I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"B`@("!]"CP_<&AP(&5L<V4Z(#\^"B`@("!I9B`H9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260@)B8@9&]C=6UE;G0N8W)E871E5&5X=$YO9&4I('L*("`@
M("`@("!F;VQD97)?=&5X="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=S
M96YT7VUA:6Q?9F]L9&5R)RD["B`@("`@("`@:68@*&9O;&1E<E]T97AT*2![
M"B`@("`@("`@("`@(&EF("AF;VQD97)?=&5X="YF:7)S=$-H:6QD*2!["B`@
M("`@("`@("`@("`@("!F;VQD97)?=&5X="YR97!L86-E0VAI;&0H9&]C=6UE
M;G0N8W)E871E5&5X=$YO9&4H;F5X=%LR72DL(&9O;&1E<E]T97AT+F9I<G-T
M0VAI;&0I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M9F]L9&5R7W1E>'0N87!P96YD0VAI;&0H9&]C=6UE;G0N8W)E871E5&5X=$YO
M9&4H;F5X=%LR72DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2!E
M;'-E(&EF("AD;V-U;65N="YA;&PI('L*("`@("`@("!F;VQD97)?=&5X="`]
M(&1O8W5M96YT+F%L;"YS96YT7VUA:6Q?9F]L9&5R.PH@("`@("`@(&9O;&1E
M<E]T97AT+FEN;F5R5&5X="`](&YE>'1;,ET["B`@("!]"CP_<&AP(&5N9&EF
M.R`_/@H@("`@:68@*&1O8W5M96YT+F-O;7!O<V4N<V%V95]S96YT7VUA:6PI
M('L*("`@("`@("!D;V-U;65N="YC;VUP;W-E+G-A=F5?<V5N=%]M86EL+F-H
M96-K960@/2!N97AT6S-=.PH@("`@?0H@("`@9&]C=6UE;G0N8V]M<&]S92YB
M8V,N=F%L=64@/2!N97AT6S1=.PI]"@IF=6YC=&EO;B!U;FEQ4W5B;6ET*&%C
M=&EO;DE$*0I["B`@("!I9B`H*&%C=&EO;DE$(#T]("=S96YD7VUE<W-A9V4G
M*2`F)@H@("`@("`@("AD;V-U;65N="YC;VUP;W-E+G-U8FIE8W0N=F%L=64@
M/3T@)R<I("8F"B`@("`@("`@(7=I;F1O=RYC;VYF:7)M*"<\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B5&AE(&UE<W-A9V4@9&]E<R!N;W0@:&%V92!A(%-U
M8FIE8W0@96YT97)E9"XB*2D@+B`G7&XG("X@861D<VQA<VAE<RA?*")396YD
M(&UE<W-A9V4@=VET:&]U="!A(%-U8FIE8W0_(BDI(#\^)RDI('L*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@:68@*&1O8W5M96YT+F-O;7!O
M<V4N<W1Y;&4@)B8@9&]C=6UE;G0N8V]M<&]S92YS='EL92YC=7)S;W(I('L*
M("`@("`@("!D;V-U;65N="YC;VUP;W-E+G-T>6QE+F-U<G-O<B`](")W86ET
M(CL*("`@('T*("`@(&1O8W5M96YT+F-O;7!O<V4N86-T:6]N240N=F%L=64@
M/2!A8W1I;VY)1#L*/#]P:'`@:68@*"1R=&5M;V1E*3H@/SX*("`@(&1O8W5M
M96YT+F-O;7!O<V4N;VYS=6)M:70H*3L*/#]P:'`@96YD:68[(#\^"B`@("!D
M;V-U;65N="YC;VUP;W-E+G-U8FUI="@I.PI]"@HO+R`M+3X*/"]S8W)I<'0^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M=&5M<&QA=&5S+V-O;7!O<V4O<W5C8V5S<RYI;F,`````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#<W`#$P-#$W,S8R-S8V`#`R,S`R-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\9&EV(&ED/2)M96YU
M(CX*("`\/W!H<"!E8VAO("1M96YU+3YR96YD97(H*3L@/SX*/"]D:78^"CQB
M<B`O/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]C
M;VUP;W-E+W-P96QL:6YG+FIS````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#,S-@`Q,#0Q-S,V,C<V-@`P,C,P,S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@H\(2TM"@IF=6YC=&EO;B!C:&%N9V5?<V5L96-T960H<V5L*0I[
M"B`@("!I9B`H(61O8W5M96YT+F-O;7!O<V4N96QE;65N='-;-"`K(#@@*B!S
M96P@*R`Q72YC:&5C:V5D*2!["B`@("`@("`@9&]C=6UE;G0N8V]M<&]S92YE
M;&5M96YT<ULT("L@."`J('-E;%TN8VAE8VME9"`]('1R=64["B`@("!]"GT*
M"B\O("TM/@H\+W-C<FEP=#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O8V]M<&]S92]A='1A
M8VAM96YT<RYJ<P``````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4P,C,`,3`T,3<S
M-C(W-C8`,#(S-3(V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M
M+0H*9G5N8W1I;VX@871T86-H;65N=$-H86YG960H*0I["B`@("!V87(@=7-E
M9$9I96QD<R`](#`["B`@("!V87(@9FEE;&1S(#T@;F5W($%R<F%Y*"D["B`@
M("!F;W(@*'9A<B!I(#T@,#L@:2`\(&1O8W5M96YT+F-O;7!O<V4N96QE;65N
M=',N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H9&]C=6UE;G0N8V]M<&]S
M92YE;&5M96YT<UMI72YT>7!E(#T]("=F:6QE)R`F)@H@("`@("`@("`@("!D
M;V-U;65N="YC;VUP;W-E+F5L96UE;G1S6VE=+FYA;64N<W5B<W1R*#`L(#<I
M(#T]("=U<&QO861?)RD@>PH@("`@("`@("`@("!F:65L9'-;9FEE;&1S+FQE
M;F=T:%T@/2!D;V-U;65N="YC;VUP;W-E+F5L96UE;G1S6VE=.PH@("`@("`@
M('T*("`@('T*"CP_<&AP"B1M87A?871T86-H;65N=',@/2`D:6UP7V-O;7!O
M<V4M/F%D9&ET:6]N86Q!='1A8VAM96YT<T%L;&]W960H*3L*:68@*"1M87A?
M871T86-H;65N=',@(3T]('1R=64I.@H_/@H@("`@:68@*&9I96QD<RYL96YG
M=&@@/3T@/#]P:'`@96-H;R`D;6%X7V%T=&%C:&UE;G1S(#\^*2!["B`@("`@
M("`@<F5T=7)N.PH@("`@?0H\/W!H<"!E;F1I9CL@/SX*"B`@("!F;W(@*'9A
M<B!I(#T@,#L@:2`\(&9I96QD<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF
M("AF:65L9'-;:5TN=F%L=64N;&5N9W1H(#X@,"D@>PH@("`@("`@("`@("!U
M<V5D1FEE;&1S*RL["B`@("`@("`@?0H@("`@?0H*("`@(&EF("AU<V5D1FEE
M;&1S(#T](&9I96QD<RYL96YG=&@I('L*("`@("`@("!V87(@;&%S=%)O=R`]
M(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=A='1A8VAM96YT7W)O=U\G("L@
M=7-E9$9I96QD<RD["B`@("`@("`@:68@*&QA<W12;W<I('L*("`@("`@("`@
M("`@=F%R(&YE=U)O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD[
M"B`@("`@("`@("`@(&YE=U)O=RYI9"`]("=A='1A8VAM96YT7W)O=U\G("L@
M*'5S961&:65L9',@*R`Q*3L*("`@("`@("`@("`@=F%R('1D(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@("`@("`@("`@;F5W4F]W+F%P
M<&5N9$-H:6QD*'1D*3L*("`@("`@("`@("`@=&0N86QI9VX@/2`G;&5F="<[
M"B`@("`@("`@("`@('9A<B!S=')O;F<@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=35%)/3D<G*3L*("`@("`@("`@("`@=&0N87!P96YD0VAI;&0H<W1R
M;VYG*3L*("`@("`@("`@("`@<W1R;VYG+F%P<&5N9$-H:6QD*&1O8W5M96YT
M+F-R96%T951E>'1.;V1E*"<\/W!H<"!E8VAO(%\H(D9I;&4B*2`_/B`G("L@
M*'5S961&:65L9',@*R`Q*2`K("<Z)RDI.PH@("`@("`@("`@("!T9"YA<'!E
M;F1#:&EL9"AD;V-U;65N="YC<F5A=&5497AT3F]D92@G("<I*3L*("`@("`@
M("`@("`@=F%R(&9I;&4@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=)3E!5
M5"<I.PH@("`@("`@("`@("!F:6QE+G1Y<&4@/2`G9FEL92<["B`@("`@("`@
M("`@('1D+F%P<&5N9$-H:6QD*&9I;&4I.PH@("`@("`@("`@("!F:6QE+FYA
M;64@/2`G=7!L;V%D7R<@*R`H=7-E9$9I96QD<R`K(#$I.PH@("`@("`@("`@
M("!F:6QE+F]N8VAA;F=E(#T@9G5N8W1I;VXH*2![(&%T=&%C:&UE;G1#:&%N
M9V5D*"D[('T["B`@("`@("`@("`@(&9I;&4N<VEZ92`](#(U.PH@("`@("`@
M("`@("!F:6QE+F-L87-S3F%M92`]("=F:7AE9"<["B`@("`@("`@("`@('1D
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@("`@("`@("`@
M;F5W4F]W+F%P<&5N9$-H:6QD*'1D*3L*("`@("`@("`@("`@=&0N86QI9VX@
M/2`G;&5F="<["B`@("`@("`@("`@('9A<B!S96QE8W0@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*"=314Q%0U0G*3L*("`@("`@("`@("`@=&0N87!P96YD
M0VAI;&0H<V5L96-T*3L*("`@("`@("`@("`@<V5L96-T+FYA;64@/2`G=7!L
M;V%D7V1I<W!O<VET:6]N7R<@*R`H=7-E9$9I96QD<R`K(#$I.PH@("`@("`@
M("`@("!S96QE8W0N;W!T:6]N<ULP72`](&YE=R!/<'1I;VXH)SP_<&AP(&5C
M:&\@7R@B071T86-H;65N="(I(#\^)RP@)V%T=&%C:&UE;G0G+"!T<G5E*3L*
M("`@("`@("`@("`@<V5L96-T+F]P=&EO;G-;,5T@/2!N97<@3W!T:6]N*"<\
M/W!H<"!E8VAO(%\H(DEN;&EN92(I(#\^)RP@)VEN;&EN92<I.PH@("`@("`@
M("`@("!L87-T4F]W+G!A<F5N=$YO9&4N:6YS97)T0F5F;W)E*&YE=U)O=RP@
M;&%S=%)O=RYN97AT4VEB;&EN9RD["B`@("`@("`@?0H@("`@?0I]"@II9B`H
M9&]C=6UE;G0N8V]M<&]S92YT;R`F)B!D;V-U;65N="YC;VUP;W-E+G1O+G9A
M;'5E(#T]("(B*2!["B`@("!D;V-U;65N="YC;VUP;W-E+G1O+F9O8W5S*"D[
M"GT@96QS92!I9B`H9&]C=6UE;G0N8V]M<&]S92YS=6)J96-T+G9A;'5E(#T]
M("(B*2!["B`@("!D;V-U;65N="YC;VUP;W-E+G-U8FIE8W0N9F]C=7,H*3L*
M?2!E;'-E('L*/#]P:'`@:68@*"1R=&5M;V1E*3H@/SX*("`@(&1O8W5M96YT
M+F-O;7!O<V4N961I=&]R+F9O8W5S*"D["CP_<&AP(&5L<V4Z(#\^"B`@("!D
M;V-U;65N="YC;VUP;W-E+FUE<W-A9V4N9F]C=7,H*3L*/#]P:'`@96YD:68[
M(#\^"GT*"B\O("TM/@H\+W-C<FEP=#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+W1E;7!L871E<R]C;VUP;W-E+V5X<&%N9"YI;F,`````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C(Q,``Q,#0Q-S,V,C<V-@`P,C(V,C(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/"%$3T-4
M65!%(&AT;6P@4%5"3$E#("(M+R]7,T,O+T141"!82%1-3"`Q+C`@5')A;G-I
M=&EO;F%L+R]%3B(@(D141"]X:'1M;#$M=')A;G-I=&EO;F%L+F1T9"(^"CQH
M=&UL/@H\:&5A9#X\=&ET;&4^/"]T:71L93X\+VAE860^"CQB;V1Y/@H\<V-R
M:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*/#]P:'`@:68@*&ES
M<V5T*"1A9&1R97-S*2DZ(#\^"CP_<&AP(&EF("AI<U]A*"1A9&1R97-S+"`G
M4$5!4E]%<G)O<B<I*3H@/SX*=VEN9&]W+G!A<F5N="YD;V-U;65N="YG971%
M;&5M96YT0GE)9"@G97AP86YD:6YG/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1F:65L9%]N86UE*2`_/B<I+FEN;F5R2%1-3#TG/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*'-P<FEN=&8H7R@B5&AE(&9I96QD(%PB)7-<(B!C86XG="!B
M92!E>'!A;F1E9"XB*2P@:'1M;'-P96-I86QC:&%R<R@D9FEE;&1?;F%M92DI
M*2`_/B<["CP_<&AP(&5L<V5I9B`H:7-?87)R87DH)&%D9')E<W,I*3H@/SX*
M=VEN9&]W+G!A<F5N="YD;V-U;65N="YG971%;&5M96YT0GE)9"@G97AP86YD
M:6YG/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1F:65L9%]N86UE*2`_
M/B<I+FEN;F5R2%1-3#TG/#]P:'`@96-H;R!A9&1S;&%S:&5S*'-P<FEN=&8H
M7R@B36]R92!T:&%N(&]N92!A9&1R97-S(&9O=6YD(&9O<B!F:65L9"!<(B5S
M7"(N(BDL(&AT;6QS<&5C:6%L8VAA<G,H)&9I96QD7VYA;64I*2D@/SXG.PH\
M/W!H<"!E;'-E.B`_/@IW:6YD;W<N<V5T5&EM96]U="@G=F%R('-T871U<R`]
M('=I;F1O=RYP87)E;G0N9&]C=6UE;G0N9V5T16QE;65N=$)Y260H7"=E>'!A
M;F1I;F<\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&9I96QD7VYA;64I
M(#\^7"<I.R!S=&%T=7,N<W1Y;&4N=FES:6)I;&ET>2`](%PG:&ED9&5N7"<[
M=VEN9&]W+G!A<F5N="YD;V-U;65N="X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&9O<FU?;F%M92`N("<N)R`N("1F:65L9%]N86UE*2`_/BYV86QU
M92`](%PG/#]P:'`@96-H;R!A9&1S;&%S:&5S*&%D9'-L87-H97,H)&%D9')E
M<W,I*2`_/EPG.R<L(#$P*3L*/#]P:'`@96YD:68[(#\^"CP_<&AP(&5N9&EF
M.R`_/@IW:6YD;W<N<&%R96YT+F)U<WE%>'!A;F1I;F<@/2!F86QS93L*+R\M
M+3X*/"]S8W)I<'0^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+V-O;7!O
M<V4O96YC<GEP=%]L:7-T+FEN8P``````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3<T
M`#$P-#$W,S8R-S8V`#`R-#`W-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H@("`@:68@*&5M<'1Y*"1E;F-R>7!T
M3W!T*2D@>PH@("`@("`@("1E;F-R>7!T3W!T(#T@)'!R969S+3YG971686QU
M92@G9&5F875L=%]E;F-R>7!T)RD["B`@("!]"B`@("`D96YC7V]P=&EO;G,@
M/2!A<G)A>2A)35!?14Y#4EE05%].3TY%(#T^(%\H(DYO($5N8W)Y<'1I;VXB
M*2D["B`@("!I9B`H(65M<'1Y*"1C;VYF6R=U=&EL<R==6R=G;G5P9R==*2`F
M)B`D<')E9G,M/F=E=%9A;'5E*"=U<V5?<&=P)RDI('L*("`@("`@("`D96YC
M7V]P=&EO;G-;24U07U!'4%]%3D-265!472`](%\H(E!'4"!%;F-R>7!T($UE
M<W-A9V4B*3L*("`@("`@("`D96YC7V]P=&EO;G-;24U07U!'4%]324=.72`]
M(%\H(E!'4"!3:6=N($UE<W-A9V4B*3L*("`@("`@("`D96YC7V]P=&EO;G-;
M24U07U!'4%]324=.14Y#72`](%\H(E!'4"!3:6=N+T5N8W)Y<'0@365S<V%G
M92(I.PH@("`@?0H@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)W5S95]S;6EM
M92<I*2!["B`@("`@("`@)&5N8U]O<'1I;VYS6TE-4%]334E-15]%3D-265!4
M72`](%\H(E,O34E-12!%;F-R>7!T($UE<W-A9V4B*3L*("`@("`@("`D96YC
M7V]P=&EO;G-;24U07U--24U%7U-)1TY=(#T@7R@B4R]-24U%(%-I9VX@365S
M<V%G92(I.PH@("`@("`@("1E;F-?;W!T:6]N<UM)35!?4TU)345?4TE'3D5.
M0UT@/2!?*")3+TU)344@4VEG;B]%;F-R>7!T($UE<W-A9V4B*3L*("`@('T*
M("`@(&9O<F5A8V@@*"1E;F-?;W!T:6]N<R!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("!E8VAO("<\;W!T:6]N('9A;'5E/2(G("X@)&ME>2`N("<B)R`N
M("@H)&5N8W)Y<'1/<'0@/3T@)&ME>2D@/R`G('-E;&5C=&5D/2)S96QE8W1E
M9"(G(#H@)R<I("X@)SXG("X@)'9A;"`N("<\+V]P=&EO;CXG("X@(EQN(CL*
M("`@('T*/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S
M+V-O;7!O<V4O8V]M<&]S95]E>'!A;F0N:G,`````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S-#$T`#$P-#$W,S8R-S8V`#`R-#(R,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\<V-R:7!T('1Y<&4](G1E>'0O:F%V
M87-C<FEP="(^"CPA+2T*"G9A<B!B=7-Y17AP86YD:6YG(#T@9F%L<V4["G9A
M<B!S96%R8VA&:65L9',@(#T@;F5W($%R<F%Y*"D["G9A<B!S96%R8VA686QU
M97,@(#T@;F5W($%R<F%Y*"D["@IF=6YC=&EO;B!E>'!A;F1&:65L9"AF:65L
M9"D*>PH\/W!H<"!I9B`H)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=A
M=71O7V5X<&%N9"<I*3H@/SX*("`@(&EF("AD;V-U;65N="YF<F%M97,I('L*
M("`@("`@("!V87(@:69R86UE(#T@9&]C=6UE;G0N9G)A;65S6R=A=71O97AP
M86YD)UT["B`@("!](&5L<V4@:68@*&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*2!["B`@("`@("`@=F%R(&EF<F%M92`](&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*"=A=71O97AP86YD)RD["B`@("!](&5L<V4@>PH@("`@("`@(')E='5R
M;CL*("`@('T*("`@(&EF("@A:69R86UE*2!["B`@("`@("`@<F5T=7)N.PH@
M("`@?0H@("`@:68@*"%F:65L9"D@>PH@("`@("`@(&9I96QD(#T@;F5W($]B
M:F5C="@I.PH@("`@("`@(&9I96QD+FYA;64@(#T@<V5A<F-H1FEE;&1S+G-L
M:6-E*#`L(#$I.PH@("`@("`@(&9I96QD+G9A;'5E(#T@<V5A<F-H5F%L=65S
M+G-L:6-E*#`L(#$I.PH@("`@?0H@("`@:68@*&)U<WE%>'!A;F1I;F<I('L*
M("`@("`@('-E87)C:$9I96QD<UMS96%R8VA&:65L9',N;&5N9W1H72`](&9I
M96QD+FYA;64["B`@("`@("!S96%R8VA686QU97-;<V5A<F-H5F%L=65S+FQE
M;F=T:%T@/2!F:65L9"YV86QU93L*("`@("`@('=I;F1O=RYS9714:6UE;W5T
M*"=E>'!A;F1&:65L9"@I)RP@-3`P*3L*("`@("`@(')E='5R;CL*("`@('T*
M("`@(&)U<WE%>'!A;F1I;F<@/2!T<G5E.PH@("`@=F%R(&1O8SL*("`@(&EF
M("AI9G)A;64N8V]N=&5N=$1O8W5M96YT*2!["B`@("`@("`@9&]C(#T@:69R
M86UE+F-O;G1E;G1$;V-U;65N=#L*("`@('T@96QS92!I9B`H:69R86UE+F-O
M;G1E;G17:6YD;W<I('L*("`@("`@("!D;V,@/2!I9G)A;64N8V]N=&5N=%=I
M;F1O=RYD;V-U;65N=#L*("`@('T@96QS92!I9B`H:69R86UE+F1O8W5M96YT
M*2!["B`@("`@("`@9&]C(#T@:69R86UE+F1O8W5M96YT.PH@("`@?2!E;'-E
M('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*("`@('9A<B!U<FP@/2`G
M/#]P:'`@96-H;R!(;W)D93HZ=7)L*%5T:6PZ.F%D9%!A<F%M971E<B@G97AP
M86YD+G!H<"<L("=A8W1I;VY)1"<L("=E>'!A;F1?861D<F5S<V5S)RDL('1R
M=64I(#\^)SL*("`@('5R;"`K/2`G)F9I96QD7VYA;64])R`K(%]E<V-A<&4H
M9FEE;&0N;F%M92D["B`@("!U<FP@*ST@)R9F:65L9%]V86QU93TG("L@7V5S
M8V%P92AF:65L9"YV86QU92D["B`@("!U<FP@*ST@)R9F;W)M7VYA;64])R`K
M(%]E<V-A<&4H9FEE;&0N9F]R;2YN86UE*3L*"B`@("!V87(@<W1A='5S(#T@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)V5X<&%N9&EN9R<@*R!F:65L9"YN
M86UE*3L*("`@('-T871U<RYI;FYE<DA434P@/2`G/#]P:'`@96-H;R!?*")%
M>'!A;F1I;F<B*2`_/B<["B`@("!S=&%T=7,N<W1Y;&4N=FES:6)I;&ET>2`]
M("=V:7-I8FQE)SL*"B`@("!D;V,N;&]C871I;VXN<F5P;&%C92AU<FPI.PH\
M/W!H<"!E;F1I9CL@/SX*?0H*9G5N8W1I;VX@7V5S8V%P92AV86QU92D*>PH@
M("`@:68@*'1Y<&5O9B!E;F-O9&554DE#;VUP;VYE;G0@/3T@)W5N9&5F:6YE
M9"<I('L*("`@("`@("!R971U<FX@97-C87!E*'9A;'5E*3L*("`@('T@96QS
M92!["B`@("`@("`@<F5T=7)N(&5N8V]D955224-O;7!O;F5N="AV86QU92D[
M"B`@("!]"GT*"B\O("TM/@H\+W-C<FEP=#X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]C;VUP
M;W-E+W)E8V]M<&]S92YI;F,`````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(P
M,0`Q,#0Q-S,V,C<V-@`P,C,S,S<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/&)R("\^"CQT86)L92!A;&EG;CTB8V5N=&5R
M(B!W:61T:#TB,S`P(CX*/'1R/@H@(#QT9"!C;VQS<&%N/2(R(B!C;&%S<STB
M:&5A9&5R(CX\<W!A;B!C;&%S<STB<VUA;&QH96%D97(B/@H@("`@/#]P:'`@
M96-H;R!?*")(97)E(&ES('1H92!M97-S86=E('EO=2!W97)E(&-O;7!O<VEN
M9SHB*2`_/@H@(#PO=&0^"CPO='(^"@H\='(^"B`@/'1D('=I9'1H/2(U)2(@
M8VQA<W,](FQI9VAT(')I9VAT06QI9VXB('9A;&EG;CTB=&]P(CX\<W1R;VYG
M/CP_<&AP(&5C:&\@7R@B5&\B*2`_/CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@
M/'1D('=I9'1H/2(Y-24B(&-L87-S/2)T97AT(CX\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H7V=E=$9O<FU$871A*"=T;R<I*2`_/CPO=&0^"CPO='(^
M"@H\='(^"B`@/'1D(&-L87-S/2)L:6=H="!R:6=H=$%L:6=N(B!V86QI9VX]
M(G1O<"(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D-C(BD@/SX\+W-T<F]N9SXF
M;F)S<#L\+W1D/@H@(#QT9"!C;&%S<STB=&5X="(^/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*%]G971&;W)M1&%T82@G8V,G*2D@/SX\+W1D/@H\+W1R
M/@H*/'1R/@H@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!;&EG;B(@=F%L:6=N
M/2)T;W`B/CQS=')O;F<^/#]P:'`@96-H;R!?*")"8V,B*2`_/CPO<W1R;VYG
M/B9N8G-P.SPO=&0^"B`@/'1D(&-L87-S/2)T97AT(CX\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H7V=E=$9O<FU$871A*"=B8V,G*2D@/SX\+W1D/@H\
M+W1R/@H*/'1R/@H@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!;&EG;B(@=F%L
M:6=N/2)T;W`B/CQS=')O;F<^/#]P:'`@96-H;R!?*")3=6)J96-T(BD@/SX\
M+W-T<F]N9SXF;F)S<#L\+W1D/@H@(#QT9"!C;&%S<STB=&5X="(^/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*%]G971&;W)M1&%T82@G<W5B:F5C="<I
M*2`_/CPO=&0^"CPO='(^"@H\/W!H<"!I9B`H7V=E=$9O<FU$871A*"=M97-S
M86=E)RDI.B`_/@H\='(^"B`@/'1D(&-L87-S/2)T97AT(B!C;VQS<&%N/2(R
M(CX\<W!A;B!C;&%S<STB9FEX960B/CP_<&AP(&5C:&\@;FPR8G(H:'1M;'-P
M96-I86QC:&%R<RA?9V5T1F]R;41A=&$H)VUE<W-A9V4G*2DI(#\^/"]S<&%N
M/CPO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H*/"]T86)L93X*/&)R("\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O=&5M<&QA=&5S+VQO9VEN+P``````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8V`#`R,#,R,P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`U-S8`,3`T
M,3<S-C(W-C8`,#(R,3,V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B1S97)V97)?:V5Y(#T@24U0.CIG971!=71O
M3&]G:6Y397)V97(H=')U92D["B1R:6=H=$%L:6=N(#T@96UP='DH)&YL<ULG
M<G1L)UU;)&QA;F=U86=E72D@/R`G<FEG:'0G(#H@)VQE9G0G.PHD;&5F=$%L
M:6=N(#T@96UP='DH)&YL<ULG<G1L)UU;)&QA;F=U86=E72D@/R`G;&5F="<@
M.B`G<FEG:'0G.PHD=&%B:6YD97@@/2`Q.PH*+RH@0G5I;&0@=&AE(#QS96QE
M8W0^('=I9&=E="!F;W(@=&AE('-E<G9E<G,@86YD(&AO<F1E875T:"!S97)V
M97)S(&QI<W1S+B`J+PHD<VAO=U]L:7-T(#T@*"1C;VYF6R=S97)V97(G75LG
M<V5R=F5R7VQI<W0G72`]/2`G<VAO=VXG*3L*:68@*"1S:&]W7VQI<W0I('L*
M("`@("1H;W)D96%U=&A?<V5R=F5R<U]L:7-T(#T@)'-E<G9E<G-?;&ES="`]
M("<G.PH@("`@)&ES075T:"`]($%U=&@Z.FES075T:&5N=&EC871E9"@I.PH@
M("`@9F]R96%C:"`H)'-E<G9E<G,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@)'-E;"`]("A)35`Z.FES4')E9F5R<F5D4V5R=F5R*"1V86PL("1K97DI
M*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)SL*("`@("`@("`D<V5R
M=F5R<U]O<'1I;VX@/2`B/&]P=&EO;B!V86QU93U<(B1K97E<(B1S96P^(B`N
M("1V86Q;)VYA;64G72`N("<\+V]P=&EO;CXG.PH*("`@("`@("!I9B`H96UP
M='DH)&-U<E-E<G9E<ELG:&]R9&5A=71H)UTI('Q\("$D:7-!=71H*2!["B`@
M("`@("`@("`@("1S97)V97)S7VQI<W0@+CT@)'-E<G9E<G-?;W!T:6]N.PH@
M("`@("`@('T@96QS96EF("@D:7-!=71H*2!["B`@("`@("`@("`@("1H;W)D
M96%U=&A?<V5R=F5R<U]L:7-T("X]("1S97)V97)S7V]P=&EO;CL*("`@("`@
M("!]"B`@("!]"GT*"B\J($)U:6QD('1H92`\<V5L96-T/B!W:61G970@8V]N
M=&%I;FEN9R!T:&4@879A:6QA8FQE(&QA;F=U86=E<RX@*B\*:68@*"$D<')E
M9G,M/FES3&]C:V5D*"=L86YG=6%G92<I*2!["B`@("`D7U-%4U-)3TY;)VAO
M<F1E7VQA;F=U86=E)UT@/2!.3%,Z.G-E;&5C="@I.PH@("`@)&QA;F=S(#T@
M)R<["B`@("!F;W)E86-H("@D;FQS6R=L86YG=6%G97,G72!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`D<V5L(#T@*"1K97D@/3T@)%]315-324].6R=H
M;W)D95]L86YG=6%G92==*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G
M)SL*("`@("`@("`D;&%N9W,@+CT@(CQO<'1I;VX@=F%L=64]7"(D:V5Y7"(D
M<V5L/B1V86P\+V]P=&EO;CXB.PH@("`@?0I]"C\^"@H\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"F9U;F-T:6]N('-E=$9O8W5S*"D*
M>PH@("`@:68@*&1O8W5M96YT+FEM<%]L;V=I;BYI;6%P=7-E<BYV86QU92`]
M/2`B(BD@>PH@("`@("`@(&1O8W5M96YT+FEM<%]L;V=I;BYI;6%P=7-E<BYF
M;V-U<R@I.PH@("`@?2!E;'-E('L*("`@("`@("!D;V-U;65N="YI;7!?;&]G
M:6XN<&%S<RYF;V-U<R@I.PH@("`@?0I]"@H\/W!H<"!I9B`H)'-H;W=?;&ES
M="`F)B`A96UP='DH)&AO<F1E875T:%]S97)V97)S7VQI<W0I*3H@/SX*/#]P
M:'`@)')E;&]A9'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ<V5L
M9E5R;"@I+"!A<G)A>2@G875T;VQO9VEN)R`]/B`D875T;VQO9VEN+"`G<V5R
M=F5R7VME>2<@/3X@)R<I*3L@/SX*9G5N8W1I;VX@:6UP7W)E;&]A9"@I"GL*
M("`@('=I;F1O=RYT;W`N9&]C=6UE;G0N;&]C871I;VX@/2`G/#]P:'`@96-H
M;R`D<F5L;V%D=7)L(#\^)R`K(&1O8W5M96YT+FEM<%]L;V=I;BYS97)V97)?
M:V5Y6V1O8W5M96YT+FEM<%]L;V=I;BYS97)V97)?:V5Y+G-E;&5C=&5D26YD
M97A=+G9A;'5E.PI]"CP_<&AP(&5N9&EF.R`_/@H*9G5N8W1I;VX@<W5B;6ET
M7VQO9VEN*&4I"GL*("`@(&EF("AT>7!E;V8@92`A/2`G=6YD969I;F5D)R`F
M)B`A96YT97)?:V5Y7W1R87`H92DI('L*("`@("`@("!R971U<FX["B`@("!]
M"@H\/W!H<"!I9B`H)'-H;W=?;&ES="DZ(#\^"B`@("!I9B`H9&]C=6UE;G0N
M:6UP7VQO9VEN+G-E<G9E<EMD;V-U;65N="YI;7!?;&]G:6XN<V5R=F5R+G-E
M;&5C=&5D26YD97A=+G9A;'5E+G-U8G-T<B@P+"`Q*2`]/2`B7R(I('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"CP_<&AP(&5N9&EF.R`_/@H@("`@
M:68@*&1O8W5M96YT+FEM<%]L;V=I;BYI;6%P=7-E<BYV86QU92`]/2`B(BD@
M>PH@("`@("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE
M87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92XB*2D@/SXG*3L*("`@("`@("!D
M;V-U;65N="YI;7!?;&]G:6XN:6UA<'5S97(N9F]C=7,H*3L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!](&5L<V4@:68@*&1O8W5M96YT+FEM<%]L;V=I
M;BYP87-S+G9A;'5E(#T]("(B*2!["B`@("`@("`@86QE<G0H)SP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D
M+B(I*2`_/B<I.PH@("`@("`@(&1O8W5M96YT+FEM<%]L;V=I;BYP87-S+F9O
M8W5S*"D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E('L*("`@
M("`@("!D;V-U;65N="YI;7!?;&]G:6XN;&]G:6Y"=71T;VXN9&ES86)L960@
M/2!T<G5E.PH\/W!H<"!I9B`H(65M<'1Y*"1I95]C;&EE;G1C87!S*2DZ(#\^
M"B`@("`@("`@=')Y('L*("`@("`@("`@("`@9&]C=6UE;G0N:6UP7VQO9VEN
M+FEE7W9E<G-I;VXN=F%L=64@/2!O8FI#0V%P<RYG971#;VUP;VYE;G1697)S
M:6]N*")[.#DX,C`R,#`M14-"1"TQ,4-&+3A".#4M,#!!03`P-4(T,S@S?2(L
M(F-O;7!O;F5N=&ED(BD["B`@("`@("`@?2!C871C:"`H92D@>PH@("`@("`@
M('T*/#]P:'`@96YD:68[(#\^"B`@("`@("`@9&]C=6UE;G0N:6UP7VQO9VEN
M+G-U8FUI="@I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0I]"B\O+2T^
M"CPO<V-R:7!T/@H*/&9O<FT@;F%M93TB:6UP7VQO9VEN(B!A8W1I;VX](CP_
M<&AP(&5C:&\@)&9O<FU!8W1I;VX@/SXB(&UE=&AO9#TB<&]S="(\/W!H<"!E
M8VAO("1I;7!?875T:"`_("<@=&%R9V5T/2)?<&%R96YT(B<@.B`G)R`_/CX*
M/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1A8W1I;VY)1"D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](G5R;"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<RA5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI(#\^(B`O/@H\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)M86EL8F]X(B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F<RT^9V5T5F%L=64H)VUA:6QB;W@G
M*2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FQO861?9G)A
M;65S970B('9A;'5E/2(\/W!H<"!E8VAO("1I;7!?875T:"`_(#$@.B`P(#\^
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A=71O;&]G:6XB('9A
M;'5E/2(\/W!H<"!E8VAO("1A=71O;&]G:6X@/R`Q(#H@,"`_/B(@+SX*/#]P
M:'`@:68@*"%E;7!T>2@D9F]R;41A=&$I*3H@/SX*/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB9F]R;41A=&$B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&9O<FU$871A*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^
M"CP_<&AP(&EF("@A96UP='DH)&EE7V-L:65N=&-A<',I*3H@/SX*/&EN<'5T
M('1Y<&4](FAI9&1E;B(@;F%M93TB:65?=F5R<VEO;B(@=F%L=64](B(@+SX*
M/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("@A*"1S:&]W7VQI<W0@)B8@(65M
M<'1Y*"1H;W)D96%U=&A?<V5R=F5R<U]L:7-T*2DI.B`_/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)S97)V97)?:V5Y(B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1S97)V97)?:V5Y*2`_/B(@+SX*/#]P:'`@
M96YD:68[(#\^"CP_<&AP("1A<F=S(#T@24U0.CIG971#;VUP;W-E07)G<R@I
M.R!F;W)E86-H("@D87)G<R!A<R`D87)G(#T^("1V86QU92DZ(#\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D87)G*2`_/B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D=F%L=64I(#\^(B`O/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H*/&1I
M=B!I9#TB;65N=2(^"CP_<&AP"B1M96YU(#T@)FYE=R!-96YU*$A/4D1%7TU%
M3E5?34%32U].3TY%*3L*)&EM96YU(#T@)&UE;G4M/G)E;F1E<B@I.PII9B`H
M)&EM96YU*3H@/SX*(#QS<&%N('-T>6QE/2)F;&]A=#H\/W!H<"!E8VAO("1R
M:6=H=$%L:6=N(#\^(CX\/W!H<"!E8VAO("1I;65N=2`_/CPO<W!A;CX*/#]P
M:'`@96YD:68[(#\^"B`\:#$@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R`D
M=&ET;&4@/SX\+V@Q/@H\+V1I=CX*/#]P:'`@)&YO=&EF:6-A=&EO;BT^;F]T
M:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D@/SX*"CQT86)L
M92!W:61T:#TB,3`P)2(^"B`\='(^"B`@/'1D(&%L:6=N/2)C96YT97(B/@H@
M("`\=&%B;&4@86QI9VX](F-E;G1E<B(^"@H\/W!H<"!I9B`H(65M<'1Y*"1R
M96%S;VXI*3H@/SX*("`@(#QT<CX*("`@("`\=&0@8V]L<W!A;CTB,B(@8VQA
M<W,](FYO=&EC92(^/#]P:'`@96-H;R`D<F5A<V]N(#\^/"]T9#X*("`@(#PO
M='(^"CP_<&AP(&5N9&EF.R`_/@H*/#]P:'`@:68@*"1S:&]W7VQI<W0@)B8@
M(65M<'1Y*"1H;W)D96%U=&A?<V5R=F5R<U]L:7-T*2DZ(#\^"B`@("`\='(^
M"B`@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1R:6=H=$%L:6=N(#\^(B!C
M;&%S<STB;&EG:'0B/CQS=')O;F<^/#]P:'`@96-H;R!?*")397)V97(B*2`_
M/CPO<W1R;VYG/CPO=&0^"B`@("`@/'1D(&-L87-S/2)L:6=H="(@86QI9VX]
M(CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(^"B`@("`@(#QS96QE8W0@=&%B
M:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB(&YA;64](G-E<G9E
M<E]K97DB(&]N8VAA;F=E/2)I;7!?<F5L;V%D*"D[(CX*/#]P:'`@96-H;R`D
M:&]R9&5A=71H7W-E<G9E<G-?;&ES="`_/@H@("`@("`\+W-E;&5C=#X*("`@
M("`@/&EN<'5T('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^
M(B!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](FEM<%]R
M96QO860H*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(DQO9VEN(BD@/SXB("\^
M"B`@("`@/"]T9#X*("`@(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H*/#]P:'`@
M:68@*"1S:&]W7VQI<W0@)B8@(65M<'1Y*"1S97)V97)S7VQI<W0I*3H@/SX*
M("`@(#QT<CX*("`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)')I9VAT06QI
M9VX@/SXB(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E-E
M<G9E<B(I(#\^/"]S=')O;F<^/"]T9#X*("`@("`\=&0@8VQA<W,](FQI9VAT
M(B!A;&EG;CTB/#]P:'`@96-H;R`D;&5F=$%L:6=N(#\^(CX*("`@("`@/'-E
M;&5C="!T86)I;F1E>#TB/#]P:'`@96-H;R`D=&%B:6YD97@K*R`_/B(@;F%M
M93TB<V5R=F5R(CX\/W!H<"!E8VAO("1S97)V97)S7VQI<W0@/SX\+W-E;&5C
M=#X*("`@("`\+W1D/@H@("`@/"]T<CX*/#]P:'`@96QS96EF("@A96UP='DH
M)&-O;F9;)W-E<G9E<B==6R=C:&%N9V5?<V5R=F5R)UTI*3H@/SX*("`@(#QT
M<CX*("`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)')I9VAT06QI9VX@/SXB
M(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E-E<G9E<B(I
M(#\^/"]S=')O;F<^/"]T9#X*("`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@
M)&QE9G1!;&EG;B`_/B(@8VQA<W,](FQI9VAT(CX*("`@("`@/&EN<'5T('1Y
M<&4](G1E>'0B('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK(#\^
M(B!N86UE/2)S97)V97(B('9A;'5E/2(\/W!H<"!E8VAO(%5T:6PZ.F=E=$9O
M<FU$871A*"=S97)V97(G+"`D<V5R=F5R7VME>2D@/SXB(&]N8VAA;F=E/2)S
M97)V97)#:&%N9V5(86YD;&5R*"DB('-T>6QE/2)D:7)E8W1I;VXZ;'1R(B`O
M/@H*/#]P:'`@:68@*"%E;7!T>2@D8V]N9ELG<V5R=F5R)UU;)V-H86YG95]P
M;W)T)UTI*3H@/SX*("`@("`@/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C0B
M(&YA;64](G!O<G0B('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I;F1E>"LK
M(#\^(B!V86QU93TB/#]P:'`@96-H;R!5=&EL.CIG971&;W)M1&%T82@G<&]R
M="<L("1S97)V97)S6R1S97)V97)?:V5Y75LG<&]R="==*2`_/B(@<W1Y;&4]
M(F1I<F5C=&EO;CIL='(B("\^"CP_<&AP(&5N9&EF.R`_/@H*/#]P:'`@:68@
M*"%E;7!T>2@D8V]N9ELG<V5R=F5R)UU;)V-H86YG95]P<F]T;V-O;"==*2DZ
M(#\^"CP_<&AP("1P<F]T;V-O;"`](%5T:6PZ.F=E=$9O<FU$871A*"=P<F]T
M;V-O;"<L("1S97)V97)S6R1S97)V97)?:V5Y75LG<')O=&]C;VPG72D@/SX*
M("`@("`@/'-E;&5C="!T86)I;F1E>#TB/#]P:'`@96-H;R`D=&%B:6YD97@K
M*R`_/B(@;F%M93TB<')O=&]C;VPB(&]N8VAA;F=E/2)U<&1A=&50;W)T*"D[
M(CX*("`@("`@(#QO<'1I;VX@=F%L=64](FEM87`B/#]P:'`@:68@*"1P<F]T
M;V-O;"`]/2`G:6UA<"<I(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B)R`_
M/CY)34%0/"]O<'1I;VX^"B`@("`@("`\;W!T:6]N('9A;'5E/2)I;6%P+VYO
M=&QS(CP_<&AP(&EF("@D<')O=&]C;VP@/3T@)VEM87`O;F]T;',G*2!E8VAO
M("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!?*"))34%0
M+"!N;R!43%,B*2`_/CPO;W!T:6]N/@H@("`@("`@/&]P=&EO;B!V86QU93TB
M:6UA<"]S<VPB/#]P:'`@:68@*"1P<F]T;V-O;"`]/2`G:6UA<"]S<VPG*2!E
M8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!?*"))
M34%0(&]V97(@4U-,(BD@/SX\+V]P=&EO;CX*("`@("`@(#QO<'1I;VX@=F%L
M=64](FEM87`O<W-L+VYO=F%L:61A=&4M8V5R="(\/W!H<"!I9B`H)'!R;W1O
M8V]L(#T]("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G*2!E8VAO("<@<V5L
M96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!?*"))34%0(&]V97(@
M4U-,("AS96QF+7-I9VYE9"DB*2`_/CPO;W!T:6]N/@H@("`@("`@/&]P=&EO
M;B!V86QU93TB<&]P,R(\/W!H<"!I9B`H)'!R;W1O8V]L(#T]("=P;W`S)RD@
M96-H;R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^/E!/4#,\+V]P=&EO;CX*
M("`@("`@(#QO<'1I;VX@=F%L=64](G!O<#,O<W-L+VYO=F%L:61A=&4M8V5R
M="(\/W!H<"!I9B`H)'!R;W1O8V]L(#T]("=P;W`S+W-S;"]N;W9A;&ED871E
M+6-E<G0G*2!E8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@
M96-H;R!?*")03U`S(&]V97(@4U-,("AS96QF+7-I9VYE9"DB*2`_/CPO;W!T
M:6]N/@H@("`@("`\+W-E;&5C=#X*/#]P:'`@96YD:68[(#\^"@H@("`@(#PO
M=&0^"B`@("`\+W1R/@H\/W!H<"!E;F1I9CL@/SX*("`@(#QT<CX*("`@("`\
M=&0@86QI9VX](CP_<&AP(&5C:&\@)')I9VAT06QI9VX@/SXB(&-L87-S/2)L
M:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E5S97)N86UE(BD@/SX\+W-T
M<F]N9SX\+W1D/@H@("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H;R`D;&5F=$%L
M:6=N(#\^(B!C;&%S<STB;&EG:'0B(&YO=W)A<#TB;F]W<F%P(CX*("`@("`@
M/&EN<'5T('1Y<&4](G1E>'0B('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T86)I
M;F1E>"LK(#\^(B!N86UE/2)I;6%P=7-E<B(@=F%L=64](CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG971&;W)M1&%T82@G:6UA<'5S97(G
M*2D@/SXB('-T>6QE/2)D:7)E8W1I;VXZ;'1R(B`O/@H\/W!H<`H@("`@:68@
M*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG=FEN9F\G72DI('L*("`@("`@("!`
M:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G
M.PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)U]I;7!?:&]O:U]V:6YF
M;R<I*2!["B`@("`@("`@("`@(&5C:&\@)SQS=')O;F<^0"<@+B!C86QL7W5S
M97)?9G5N8R@G7VEM<%]H;V]K7W9I;F9O)RP@)W9D;VUA:6XG*2`N("<\+W-T
M<F]N9SXG.PH@("`@("`@('T*("`@('T*/SX*("`@("`\+W1D/@H@("`@/"]T
M<CX*"B`@("`\='(^"B`@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1R:6=H
M=$%L:6=N(#\^(B!C;&%S<STB;&EG:'0B/CQS=')O;F<^/#]P:'`@96-H;R!?
M*")087-S=V]R9"(I(#\^/"]S=')O;F<^/"]T9#X*("`@("`\=&0@86QI9VX]
M(CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(^"B`@("`@(#QI;G!U="!T>7!E
M/2)P87-S=V]R9"(@=&%B:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@
M/SXB(&YA;64](G!A<W,B('-T>6QE/2)D:7)E8W1I;VXZ;'1R(B`O/@H@("`@
M(#PO=&0^"B`@("`\+W1R/@H*/#]P:'`@:68@*"%E;7!T>2@D8V]N9ELG<V5R
M=F5R)UU;)V-H86YG95]S;71P:&]S="==*2DZ(#\^"B`@("`\='(@<W1Y;&4]
M(FAE:6=H=#H@,65M.R(^/'1D(&-O;'-P86X](C(B/CPO=&0^/"]T<CX*("`@
M(#QT<CX*("`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)')I9VAT06QI9VX@
M/SXB(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D]U=&)O
M=6YD(%-E<G9E<B(I(#\^/"]S=')O;F<^/"]T9#X*("`@("`\=&0@86QI9VX]
M(CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(@8VQA<W,](FQI9VAT(CX*("`@
M("`@/&EN<'5T('1Y<&4](G1E>'0B('1A8FEN9&5X/2(\/W!H<"!E8VAO("1T
M86)I;F1E>"LK(#\^(B!N86UE/2)S;71P:&]S="(@=F%L=64](CP_<&AP(&5C
M:&\@571I;#HZ9V5T1F]R;41A=&$H)W-M='!H;W-T)RP@)'-E<G9E<E]K97DI
M(#\^(B!S='EL93TB9&ER96-T:6]N.FQT<B(@+SX*/#]P:'`@:68@*"%E;7!T
M>2@D8V]N9ELG<V5R=F5R)UU;)V-H86YG95]S;71P<&]R="==*2DZ(#\^"B`@
M("`@(#QI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(T(B!N86UE/2)S;71P<&]R
M="(@=&%B:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB('9A;'5E
M/2(\/W!H<"!E8VAO(%5T:6PZ.F=E=$9O<FU$871A*"=S;71P<&]R="<L("1S
M97)V97)S6R1S97)V97)?:V5Y75LG<VUT<'!O<G0G72D@/SXB('-T>6QE/2)D
M:7)E8W1I;VXZ;'1R(B`O/B`\/W!H<"!E8VAO(%\H(E--5%`B*3L@/SX*/#]P
M:'`@96YD:68[(#\^"B`@("`@/"]T9#X*("`@(#PO='(^"CP_<&AP(&5N9&EF
M.R`_/@H*/#]P:'`@:68@*"%E;7!T>2@D8V]N9ELG<V5R=F5R)UU;)V-H86YG
M95]S;71P:&]S="==*2DZ(#\^"B`@("`\='(@<W1Y;&4](FAE:6=H=#H@,65M
M.R(^/'1D(&-O;'-P86X](C(B/CPO=&0^/"]T<CX*/#]P:'`@96YD:68[(#\^
M"CP_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G;&%N9W5A9V4G*2DZ(#\^
M"B`@("`\='(^"B`@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1R:6=H=$%L
M:6=N(#\^(B!C;&%S<STB;&EG:'0B/CQS=')O;F<^/#]P:'`@96-H;R!?*"),
M86YG=6%G92(I(#\^/"]S=')O;F<^/"]T9#X*("`@("`\=&0@86QI9VX](CP_
M<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(@8VQA<W,](FQI9VAT(CX*("`@("`@
M/'-E;&5C="!T86)I;F1E>#TB/#]P:'`@96-H;R`D=&%B:6YD97@K*R`_/B(@
M;F%M93TB;F5W7VQA;F<B(&]N8VAA;F=E/2)S96QE8W1,86YG*"DB('-T>6QE
M/2)D:7)E8W1I;VXZ;'1R(CX\/W!H<"!E8VAO("1L86YG<R`_/CPO<V5L96-T
M/B`\+W1D/@H@("`@/"]T<CX*/#]P:'`@96YD:68[(#\^"@H@("`@/'1R/@H@
M("`@(#QT9#XF;F)S<#L\+W1D/@H@("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H
M;R`D;&5F=$%L:6=N(#\^(B!C;&%S<STB;&EG:'0B/@H@("`@("`\:6YP=70@
M='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)L;V=I;D)U='1O
M;B(@=&%B:6YD97@](CP_<&AP(&5C:&\@)'1A8FEN9&5X*RL@/SXB('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(DQO9R!I;B(I(#\^(B!O;F-L:6-K/2)R971U<FX@
M<W5B;6ET7VQO9VEN*"D[(B`O/@H@("`@(#PO=&0^"B`@("`\+W1R/@H*/#]P
M:'`@:68@*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72`F)B!I<W-E="@D875T
M:"D@)B8@)&%U=&@M/FAA<T-A<&%B:6QI='DH)V%D9"<I*3H@/SX*("`@(#QT
M<CX*("`@("`\=&0^)FYB<W`[/"]T9#X*("`@("`\=&0@8VQA<W,](FQI9VAT
M(CX\/W!H<"!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<BA(
M;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@
M+B`G+W-I9VYU<"YP:'`G*2P@)W5R;"<L(%5T:6PZ.F=E=$9O<FU$871A*"=U
M<FPG*2DL(%\H(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB*2P@
M)VQI9VAT)RD@+B!?*")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(BD@/SX\+V$^/"]T9#X*("`@(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H*("`@
M/"]T86)L93X*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*/"]F;W)M/@H*/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@H\/W!H<"!I9B`H
M(65M<'1Y*"1C;VYF6R=S97)V97(G75LG8VAA;F=E7W!R;W1O8V]L)UTI*3H@
M/SX*9G5N8W1I;VX@=7!D871E4&]R="@I"GL*/#]P:'`@:68@*"%E;7!T>2@D
M8V]N9ELG<V5R=F5R)UU;)V-H86YG95]P;W)T)UTI*3H@/SX*("`@(&EF("AD
M;V-U;65N="YI;7!?;&]G:6XN<')O=&]C;VPN;W!T:6]N<UMD;V-U;65N="YI
M;7!?;&]G:6XN<')O=&]C;VPN<V5L96-T961);F1E>%TN=F%L=64@/3T@)VEM
M87`G*2!["B`@("`@("`@9&]C=6UE;G0N:6UP7VQO9VEN+G!O<G0N=F%L=64@
M/2`Q-#,["B`@("!](&5L<V4@:68@*&1O8W5M96YT+FEM<%]L;V=I;BYP<F]T
M;V-O;"YO<'1I;VYS6V1O8W5M96YT+FEM<%]L;V=I;BYP<F]T;V-O;"YS96QE
M8W1E9$EN9&5X72YV86QU92`]/2`G:6UA<"]S<VPG('Q\"B`@("`@("`@("`@
M("`@(&1O8W5M96YT+FEM<%]L;V=I;BYP<F]T;V-O;"YO<'1I;VYS6V1O8W5M
M96YT+FEM<%]L;V=I;BYP<F]T;V-O;"YS96QE8W1E9$EN9&5X72YV86QU92`]
M/2`G:6UA<"]S<VPO;F]V86QI9&%T92UC97)T)RD@>PH@("`@("`@(&1O8W5M
M96YT+FEM<%]L;V=I;BYP;W)T+G9A;'5E(#T@.3DS.PH@("`@?2!E;'-E(&EF
M("AD;V-U;65N="YI;7!?;&]G:6XN<')O=&]C;VPN;W!T:6]N<UMD;V-U;65N
M="YI;7!?;&]G:6XN<')O=&]C;VPN<V5L96-T961);F1E>%TN=F%L=64@/3T@
M)W!O<#,G*2!["B`@("`@("`@9&]C=6UE;G0N:6UP7VQO9VEN+G!O<G0N=F%L
M=64@/2`Q,3`["B`@("!](&5L<V4@:68@*&1O8W5M96YT+FEM<%]L;V=I;BYP
M<F]T;V-O;"YO<'1I;VYS6V1O8W5M96YT+FEM<%]L;V=I;BYP<F]T;V-O;"YS
M96QE8W1E9$EN9&5X72YV86QU92`]/2`G<&]P,R]S<VPG('Q\"B`@("`@("`@
M("`@("`@(&1O8W5M96YT+FEM<%]L;V=I;BYP<F]T;V-O;"YO<'1I;VYS6V1O
M8W5M96YT+FEM<%]L;V=I;BYP<F]T;V-O;"YS96QE8W1E9$EN9&5X72YV86QU
M92`]/2`G<&]P,R]S<VPO;F]V86QI9&%T92UC97)T)RD@>PH@("`@("`@(&1O
M8W5M96YT+FEM<%]L;V=I;BYP;W)T+G9A;'5E(#T@.3DU.PH@("`@?0H\/W!H
M<"!E;F1I9CL@/SX*?0H\/W!H<"!E;F1I9CL@/SX*"CP_<&AP(&EF("@A96UP
M='DH)&-O;F9;)W-E<G9E<B==6R=C:&%N9V5?<V5R=F5R)UTI*3H@/SX*9G5N
M8W1I;VX@<V5R=F5R0VAA;F=E2&%N9&QE<BAC=&PI"GL*/#]P:'`@:68@*"%E
M;7!T>2@D8V]N9ELG<V5R=F5R)UU;)V-H86YG95]S;71P:&]S="==*2DZ(#\^
M"B`@("!D;V-U;65N="YI;7!?;&]G:6XN<VUT<&AO<W0N=F%L=64@/2!D;V-U
M;65N="YI;7!?;&]G:6XN<V5R=F5R+G9A;'5E.PH\/W!H<"!E;F1I9CL@/SX*
M?0H\/W!H<"!E;F1I9CL@/SX*"CP_<&AP(&EF("@A)'!R969S+3YI<TQO8VME
M9"@G;&%N9W5A9V4G*2DZ(#\^"F9U;F-T:6]N('-E;&5C=$QA;F<H*0I["B`@
M("`O+R!792!N965D('1O(')E;&]A9"!T:&4@;&]G:6X@<&%G92!H97)E+"!B
M=70@;VYL>2!I9B!T:&4@=7-E<B!H87-N)W0*("`@("\O(&%L<F5A9'D@96YT
M97)E9"!A('5S97)N86UE(&%N9"!P87-S=V]R9"X*("`@(&EF("AD;V-U;65N
M="YI;7!?;&]G:6XN:6UA<'5S97(N=F%L=64@/3T@)R<@)B8*("`@("`@("!D
M;V-U;65N="YI;7!?;&]G:6XN<&%S<RYV86QU92`]/2`G)RD@>PH@("`@("`@
M('9A<B!L86YG7W!A9V4@/2`G;&]G:6XN<&AP/VYE=U]L86YG/2<@*R!D;V-U
M;65N="YI;7!?;&]G:6XN;F5W7VQA;F=;9&]C=6UE;G0N:6UP7VQO9VEN+FYE
M=U]L86YG+G-E;&5C=&5D26YD97A=+G9A;'5E.PH\/W!H<`H@("`@)'5R;"`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*3L*("`@(&EF("@A96UP='DH)'5R
M;"DI('L*("`@("`@("!E8VAO(")L86YG7W!A9V4@*ST@)R9U<FP](B`N('5R
M;&5N8V]D92@D=7)L*2`N("(G.R(["B`@("!]"C\^"B`@("`@("`@<V5L9BYL
M;V-A=&EO;B`](&QA;F=?<&%G93L*("`@('T*?0H\/W!H<"!E;F1I9CL@/SX*
M"CP_<&AP(&EF("@D:6UP7V%U=&@I.B`_/@II9B`H<&%R96YT+F9R86UE<RYH
M;W)D95]M86EN*2!["B`@("!D;V-U;65N="YI;7!?;&]G:6XN=&%R9V5T(#T@
M)U]P87)E;G0G.PI]"CP_<&AP(&5N9&EF.R`_/@H*+R\@4V5T('5P('1H92!E
M;G1E<B!K97ET<F%P(&-O9&4N"FEF("AT>7!E;V8@9&]C=6UE;G0N8V%P='5R
M945V96YT<R`A/2`G=6YD969I;F5D)RD@>PH@("`@9&]C=6UE;G0N8V%P='5R
M945V96YT<RA%=F5N="Y+15E04D534RD["B`@("!D;V-U;65N="YO;FME>7!R
M97-S(#T@<W5B;6ET7VQO9VEN.PI]"B\O+2T^"CPO<V-R:7!T/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+W!R969S+P``````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8V
M`#`R,#,S,@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O
M<')E9G,O9F]L9&5R<V5L96-T+FEN8P``````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(R-S8`,3`T,3<S-C(W-C8`,#(S-3`T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP(&EF("@A)'!R969S+3YI<TQO
M8VME9"@G9')A9G1S7V9O;&1E<B<I*3H@/SX*/'-C<FEP="!T>7!E/2)T97AT
M+VIA=F%S8W)I<'0B/@H\(2TM"@IF=6YC=&EO;B!N97=$<F%F='-&;VQD97).
M86UE*"D*>PH@("`@9&]C=6UE;G0N<')E9G,N9')A9G1S+F]N8VAA;F=E(#T@
M;G5L;#L*("`@(&EF("AD;V-U;65N="YP<F5F<RYD<F%F='-;9&]C=6UE;G0N
M<')E9G,N9')A9G1S+G-E;&5C=&5D26YD97A=+G9A;'5E(#T]("<G*2!["B`@
M("`@("`@=F%R(&9O;&1E<B`]('=I;F1O=RYP<F]M<'0H)SP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@9')A
M9G1S(&9O;&1E<B(I*2`_/B<L(&1O8W5M96YT+G!R969S+F1R869T<U]N97<@
M+B!V86QU92`_(&1O8W5M96YT+G!R969S+F1R869T<U]N97<N=F%L=64@.B`G
M)RD["B`@("`@("`@:68@*&9O;&1E<B`A/2`G)RD@>PH@("`@("`@("`@("!D
M;V-U;65N="YP<F5F<RYD<F%F='-?;F5W+G9A;'5E(#T@9F]L9&5R.PH@("`@
M("`@("`@("!D;V-U;65N="YP<F5F<RYD<F%F='-;,5TN=&5X="`]("<\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0W)E871E(&$@;F5W(&1R869T<R!F;VQD
M97(B*2D@/SX@6R<@*R!D;V-U;65N="YP<F5F<RYD<F%F='-?;F5W+G9A;'5E
M("L@)UTG.PH@("`@("`@('T*("`@('T*("`@(&1O8W5M96YT+G!R969S+F1R
M869T<RYO;F-H86YG92`](&YE=T1R869T<T9O;&1E<DYA;64["GT*"B\O("TM
M/@H\+W-C<FEP=#X*"CQT86)L92!B;W)D97(](C`B/@H@/'1R/@H@(#QT9#X\
M/W!H<"!E8VAO(%\H(D1R869T<R!F;VQD97(Z(BD@/SX\8G(@+SX*("`@/'-E
M;&5C="!N86UE/2)D<F%F=',B(&]N8VAA;F=E/2)N97=$<F%F='-&;VQD97).
M86UE*"D[(CX\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO($E-4%]04D5&7TY/
M7T9/3$1%4B`_/B(^/#]P:'`@96-H;R!?*").;VYE(BD@/SX\+V]P=&EO;CX\
M/W!H<"!E8VAO($E-4#HZ9FQI<W1396QE8W0H7R@B0W)E871E(&$@;F5W(&1R
M869T<R!F;VQD97(B*2P@=')U92P@87)R87DH)TE.0D]8)RDL($E-4#HZ9F]L
M9&5R4')E9B@D<')E9G,M/F=E=%9A;'5E*"=D<F%F='-?9F]L9&5R)RDL('1R
M=64I*2`_/CPO<V5L96-T/@H@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)D<F%F='-?;F5W(B!V86QU93TB(B`O/@H@(#PO=&0^"B`\+W1R/@H\+W1A
M8FQE/@H\/W!H<"!E;F1I9CL@/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+W1E;7!L871E<R]P<F5F<R]D969A=6QT<V5A<F-H<V5L
M96-T+FEN8P`````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,30W-0`Q,#0Q-S,V,C<V-@`P,C4P
M-#,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=D969A=6QT7W-E87)C:"<I
M*3H@/SX*/#]P:'`*("`@(&EF("@A:7-S970H)&EM<%]S96%R8V@I*2!["B`@
M("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O4V5A<F-H+G!H
M<"<["B`@("`@("`@)&EM<%]S96%R8V@@/2!N97<@24U07U-E87)C:"@I.PH@
M("`@?0H@("`@)&-U<G)?9&5F875L="`]("1P<F5F<RT^9V5T5F%L=64H)V1E
M9F%U;'1?<V5A<F-H)RD["B`@("`D<V5A<F-H7V9I96QD<R`](&%R<F%Y7VUE
M<F=E*&%R<F%Y*"<G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B3D].12(I*2DL
M("1I;7!?<V5A<F-H+3YS96%R8VA&:65L9',H*2D["B`@("`D9&5F7W-E;&5C
M="`]("<G.PH@("`@9F]R96%C:"`H)'-E87)C:%]F:65L9',@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@)&1E9E]S96QE8W0@+CT@)SQO<'1I;VX@=F%L
M=64](B<@+B`D:V5Y("X@)R(G.PH@("`@("`@(&EF("@D8W5R<E]D969A=6QT
M(#T]("1K97DI('L*("`@("`@("`@("`@)&1E9E]S96QE8W0@+CT@)R!S96QE
M8W1E9#TB<V5L96-T960B)SL*("`@("`@("!]"B`@("`@("`@)&1E9E]S96QE
M8W0@+CT@)SXG("X@)'9A;%LG;&%B96PG72`N("<\+V]P=&EO;CXG.PH@("`@
M?0H_/@H\=&%B;&4@8F]R9&5R/2(P(CX*(#QT<CX*("`\=&0^"B`@(#P_<&AP
M(&5C:&\@7R@B1&5F875L="!396%R8V@@1FEE;&0B*2`_/CH*("`@/&)R("\^
M"B`@(#QS96QE8W0@;F%M93TB9&5F875L=%]S96%R8V@B/CP_<&AP(&5C:&\@
M)&1E9E]S96QE8W0@/SX\+W-E;&5C=#X*("`\+W1D/@H@/"]T<CX*/"]T86)L
M93X*/#]P:'`@96YD:68[(#\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]P<F5F<R]S96YT;6%I;'-E
M;&5C="YI;F,````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`U,``Q,#0Q-S,V,C<V
M-@`P,C0P,S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=S96YT7VUA:6Q?
M9F]L9&5R)RDI.B`_/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^
M"CPA+2T*"F9U;F-T:6]N(&YE=T-H;VEC95]S96YT7VUA:6Q?9F]L9&5R*'9A
M;"D*>PH@("`@:68@*'9A;"`]/2`B(BD@>PH@("`@("`@(&1O8W5M96YT+G!R
M969S+G-E;G1?;6%I;"YS96QE8W1E9$EN9&5X(#T@,#L*("`@("`@("!R971U
M<FX["B`@("!]"B`@("!V87(@9FEE;&0@/2!D;V-U;65N="YP<F5F<RYS96YT
M7VUA:6P["B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&9I96QD+F]P=&EO;G,N
M;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H9FEE;&0N;W!T:6]N<UMI72YV
M86QU92`]/2!V86PI('L*("`@("`@("`@("`@9FEE;&0N<V5L96-T961);F1E
M>"`](&D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*?0H*
M9G5N8W1I;VX@;F5W1F]L9&5R3F%M92@I"GL*("`@(&EF("AD;V-U;65N="YP
M<F5F<RYS96YT7VUA:6PN<V5L96-T961);F1E>"`]/2`R*2!["B`@("`@("`@
M=F%R(&9O;&1E<B`]('=I;F1O=RYP<F]M<'0H)SP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N97<@<V5N="!M86EL
M(&9O;&1E<B(I*2`_/B<L(&1O8W5M96YT+G!R969S+G-E;G1?;6%I;%]N97<N
M=F%L=64@/R!D;V-U;65N="YP<F5F<RYS96YT7VUA:6Q?;F5W+G9A;'5E(#H@
M)R<I.PH@("`@("`@(&EF("AF;VQD97(@(3T@)R<@)B8@9F]L9&5R("$](&YU
M;&PI('L*("`@("`@("`@("`@9&]C=6UE;G0N<')E9G,N<V5N=%]M86EL7VYE
M=RYV86QU92`](&9O;&1E<CL*("`@("`@("`@("`@9&]C=6UE;G0N<')E9G,N
M<V5N=%]M86EL6S)=+G1E>'0@/2`G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R(BDI(#\^(%LG("L@9&]C
M=6UE;G0N<')E9G,N<V5N=%]M86EL7VYE=RYV86QU92`K("==)SL*("`@("`@
M("!]"B`@("!]"@H@("`@:68@*&1O8W5M96YT+G!R969S+G-E;G1?;6%I;"YS
M96QE8W1E9$EN9&5X(#T](#`I('L*("`@("`@("!D;V-U;65N="YP<F5F<RYS
M879E7W-E;G1?;6%I;"YC:&5C:V5D(#T@,#L*("`@('T*?0H*+R\M+3X*/"]S
M8W)I<'0^"@H\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G<V5N=%]M86EL)RP@
M7R@B4V5N="!M86EL(&9O;&1E<CHB*2D@/SX\8G(@+SX*/'-E;&5C="!N86UE
M/2)S96YT7VUA:6PB(&ED/2)S96YT7VUA:6PB(&]N8VAA;F=E/2)N97=&;VQD
M97).86UE*"D[(CX*("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B
M3F]N92(I(#\^/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB+3$B('-E;&5C
M=&5D/2)S96QE8W1E9"(^/#]P:'`@96-H;R!?*")5<V4@1&5F875L="!686QU
M92(I(#\^/"]O<'1I;VX^"B`@/#]P:'`@96-H;R!)35`Z.F9L:7-T4V5L96-T
M*%\H(D-R96%T92!A(&YE=R!S96YT(&UA:6P@9F]L9&5R(BDL('1R=64L(&%R
M<F%Y*"=)3D)/6"<I*2`_/@H\+W-E;&5C=#X*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB<V5N=%]M86EL7VYE=R(@=F%L=64](B(@+SX*/#]P:'`@96YD
M:68[(#\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O<')E9G,O<V]U<F-E<V5L96-T+FEN
M8P``````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`Q,S,`,3`T,3<S-C(W-C8`,#(S
M-3(R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"FEF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G8V]N=&%C=',O<V]U
M<F-E<R<I*2!["B`@("`D<V5L96-T960@/2!E>'!L;V1E*")<="(L("1P<F5F
M<RT^9V5T5F%L=64H)W-E87)C:%]S;W5R8V5S)RDI.PH@("`@)')E861A8FQE
M(#T@)')E9VES=')Y+3YC86QL*"=C;VYT86-T<R]S;W5R8V5S)RD["B`@("`D
M=W)I=&5A8FQE(#T@)')E9VES=')Y+3YC86QL*"=C;VYT86-T<R]S;W5R8V5S
M)RP@=')U92D["@H@("`@)&YB4F5A9%-O=7)C97,@/2!C;W5N="AA<G)A>5]K
M97ES*"1R96%D86)L92DI.PH@("`@)&YB5W)I=&53;W5R8V5S(#T@8V]U;G0H
M87)R87E?:V5Y<R@D=W)I=&5A8FQE*2D["@H@("`@:68@*&-O=6YT*"1S96QE
M8W1E9"D@/3T@,2`F)B!E;7!T>2@D<V5L96-T961;,%TI*2!["B`@("`@("`@
M)'-E;&5C=&5D(#T@87)R87DH*3L*("`@('T*"B`@("!I9B`H)&YB4F5A9%-O
M=7)C97,@/3T@,2D@>PH@("`@("`@("\O($]N;'D@;VYE('-O=7)C92P@;F\@
M;F5E9"!T;R!D:7-P;&%Y('1H92!S96QE8W1I;VX@=VED9V5T"B`@("`@("`@
M)'-E;&5C=&5D(#T@87)R87E?:V5Y<R@D<F5A9&%B;&4I.PH@("`@("`@("1R
M96%D4V5L96-T(#T@)R<["B`@("!]"@H@("`@)'!R969396QE8W0@/2`G)SL*
M("`@(&9O<F5A8V@@*"1S96QE8W1E9"!A<R`D<V]U<F-E*2!["B`@("`@("`@
M:68@*"%E;7!T>2@D<F5A9&%B;&5;)'-O=7)C95TI*2!["B`@("`@("`@("`@
M("1P<F5F4V5L96-T("X]("<\;W!T:6]N('9A;'5E/2(G("X@)'-O=7)C92`N
M("<B/B<@+B`D<F5A9&%B;&5;)'-O=7)C95T@+B`B/"]O<'1I;VX^7&XB.PH@
M("`@("`@('T*("`@('T*"B`@("`D<F5A9%-E;&5C="`]("<G.PH@("`@:68@
M*"%I<U]A*"1R96%D86)L92P@)U!%05)?17)R;W(G*2`F)B!I<U]A<G)A>2@D
M<F5A9&%B;&4I*2!["B`@("`@("`@9F]R96%C:"`H87)R87E?9&EF9BAA<G)A
M>5]K97ES*"1R96%D86)L92DL("1S96QE8W1E9"D@87,@)'-O=7)C92D@>PH@
M("`@("`@("`@("`D<F5A9%-E;&5C="`N/2`G/&]P=&EO;B!V86QU93TB)R`N
M("1S;W5R8V4@+B`G(CXG("X@)')E861A8FQE6R1S;W5R8V5=("X@(CPO;W!T
M:6]N/EQN(CL*("`@("`@("!]"B`@("!]"@H@("`@:68@*"%I<U]A*"1W<FET
M96%B;&4L("=014%27T5R<F]R)RD@)B8@:7-?87)R87DH)'=R:71E86)L92DI
M('L*("`@("`@("`D=W)I=&5396QE8W0@/2`G/&]P=&EO;B!V86QU93TB(CXG
M("X@7R@B3F]N92(I("X@)SPO;W!T:6]N/B<@+B`B7&XB.PH@("`@("`@("1W
M<FET95-O=7)C92`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1W<FET96%B;&4@
M87,@)'-O=7)C92`]/B`D;F%M92D@>PH@("`@("`@("`@("`D<V5L(#T@)'!R
M969S+3YG971686QU92@G861D7W-O=7)C92<I(#T]("1S;W5R8V4@/R`G('-E
M;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<["B`@("`@("`@("`@("1W<FET95-E
M;&5C="`N/2`G/&]P=&EO;B!V86QU93TB)R`N("1S;W5R8V4@+B`G(B<@+B`B
M)'-E;#XB("X@)&YA;64@+B`B/"]O<'1I;VX^7&XB.PH@("`@("`@("`@("`D
M=W)I=&53;W5R8V4@/2`D<V]U<F-E.PH@("`@("`@('T*("`@('T*"B`@("`D
M<V5L96-T961?9FEE;&1S(#T@87)R87DH*3L*("`@("1S96%R8VA?9FEE;&1?
M<')E9B`]("1P<F5F<RT^9V5T5F%L=64H)W-E87)C:%]F:65L9',G*3L*("`@
M(&EF("@A96UP='DH)'-E87)C:%]F:65L9%]P<F5F*2D@>PH@("`@("`@("1S
M96QE8W1E9%]F:65L9',@/2!E>'!L;V1E*")<;B(L("1P<F5F<RT^9V5T5F%L
M=64H)W-E87)C:%]F:65L9',G*2D["B`@("`@("`@9F]R96%C:"`H)'-E;&5C
M=&5D7V9I96QD<R!A<R`D9FEE;&0I('L*("`@("`@("`@("`@)&9I96QD(#T@
M=')I;2@D9FEE;&0I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1F:65L9"DI
M('L*("`@("`@("`@("`@("`@("1T;7`@/2!E>'!L;V1E*")<="(L("1F:65L
M9"D["B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1M<"D@/B`Q*2!["B`@
M("`@("`@("`@("`@("`@("`@)'-O=7)C92`](&%R<F%Y7W-P;&EC92@D=&UP
M+"`P+"`Q*3L*("`@("`@("`@("`@("`@("`@("`D<V5L96-T961?9FEE;&1S
M6R1S;W5R8V5;,%U=(#T@)'1M<#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`D<V5A<F-H7V9I96QD<R`]
M(&%R<F%Y*"D["B`@("!I9B`H(6ES7V$H)')E861A8FQE+"`G4$5!4E]%<G)O
M<B<I("8F(&ES7V%R<F%Y*"1R96%D86)L92DI('L*("`@("`@("!F;W)E86-H
M("@D<F5A9&%B;&4@87,@)'-O=7)C92`]/B`D;G5L;"D@>PH@("`@("`@("`@
M("`D<V5A<F-H7V9I96QD<ULD<V]U<F-E72`]("1R96=I<W1R>2T^8V%L;"@G
M8V]N=&%C=',O9FEE;&1S)RP@)'-O=7)C92D["B`@("`@("`@?0H@("`@?0H*
M("`@("1J<R`](")V87(@<V5A<F-H1FEE;&1S(#T@;F5W($%R<F%Y*"D[7&XB
M.PH@("`@)'-O=7)C95]C;W5N="`](#`["B`@("!F;W)E86-H("@D<V5A<F-H
M7V9I96QD<R!A<R`D<V]U<F-E(#T^("1F:65L9',I('L*("`@("`@("`D:G,@
M+CT@(G-E87)C:$9I96QD<ULD<V]U<F-E7V-O=6YT72`](&YE=R!!<G)A>2@I
M.UQN(CL*("`@("`@("`D:G,@+CT@(G-E87)C:$9I96QD<ULD<V]U<F-E7V-O
M=6YT75LP72`]("<D<V]U<F-E)SM<;B(["@H@("`@("`@("1F:65L9%]C;W5N
M="`](#$["B`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A<R`D9FEE;&0I('L*
M("`@("`@("`@("`@:68@*"1F:65L9%LG<V5A<F-H)UTI('L*("`@("`@("`@
M("`@("`@("1M87)K960@/2!I<W-E="@D<V5L96-T961?9FEE;&1S6R1S;W5R
M8V5=*2`F)B!I;E]A<G)A>2@D9FEE;&1;)VYA;64G72P@)'-E;&5C=&5D7V9I
M96QD<ULD<V]U<F-E72D@/R`G=')U92<@.B`G9F%L<V4G.PH@("`@("`@("`@
M("`@("`@)&IS("X](")S96%R8VA&:65L9'-;)'-O=7)C95]C;W5N=%U;)&9I
M96QD7V-O=6YT72`](&YE=R!!<G)A>2@G(B`N("1F:65L9%LG;F%M92==("X@
M(B<L("<B("X@)&9I96QD6R=L86)E;"==("X@(B<L("1M87)K960I.UQN(CL*
M("`@("`@("`@("`@("`@("1F:65L9%]C;W5N="LK.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D<V]U<F-E7V-O=6YT*RL["B`@("!]"GT*
M/SX*"CP_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G<V5A<F-H7W-O=7)C
M97,G*2`F)B`H(65M<'1Y*"1R96%D4V5L96-T*2!\?"`A96UP='DH)'!R9693
M96QE8W0I*2DZ(#\^"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*
M/"$M+0IF=6YC=&EO;B!D97-E;&5C=$AE861E<G,H*0I["B`@("!D;V-U;65N
M="YP<F5F<RYU;G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S6S!=+G-E;&5C=&5D
M(#T@9F%L<V4["B`@("!D;V-U;65N="YP<F5F<RYS96QE8W1E9%]S96%R8VA?
M<V]U<F-E<ULP72YS96QE8W1E9"`](&9A;'-E.PI]"@IF=6YC=&EO;B!R97-E
M=$AI9&1E;B@I"GL*("`@('9A<B!T;7`@/2`G)SL*("`@(&9O<B`H:2`](#$[
M(&D@/"!D;V-U;65N="YP<F5F<RYS96QE8W1E9%]S96%R8VA?<V]U<F-E<RYL
M96YG=&@[(&DK*RD@>PH@("`@("`@('1M<"`K/2!D;V-U;65N="YP<F5F<RYS
M96QE8W1E9%]S96%R8VA?<V]U<F-E<UMI72YV86QU93L*("`@("`@("!I9B`H
M:2`\(&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S+FQE
M;F=T:"`M(#$I"B`@("`@("`@("`@('1M<"`K/2`B7'0B.PH@("`@?0H*("`@
M(&1O8W5M96YT+G!R969S+G-E87)C:%]S;W5R8V5S+G9A;'5E(#T@=&UP.PI]
M"@IF=6YC=&EO;B!A9&13;W5R8V4H*0I["B`@("!F;W(@*&D@/2`Q.R!I(#P@
M9&]C=6UE;G0N<')E9G,N=6YS96QE8W1E9%]S96%R8VA?<V]U<F-E<RYL96YG
M=&@[(&DK*RD@>PH@("`@("`@(&EF("AD;V-U;65N="YP<F5F<RYU;G-E;&5C
M=&5D7W-E87)C:%]S;W5R8V5S6VE=+G-E;&5C=&5D*2!["B`@("`@("`@("`@
M(&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S6V1O8W5M
M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S+FQE;F=T:%T@/2!N
M97<@3W!T:6]N*&1O8W5M96YT+G!R969S+G5N<V5L96-T961?<V5A<F-H7W-O
M=7)C97-;:5TN=&5X="P@9&]C=6UE;G0N<')E9G,N=6YS96QE8W1E9%]S96%R
M8VA?<V]U<F-E<UMI72YV86QU92D["B`@("`@("`@("`@(&1O8W5M96YT+G!R
M969S+G5N<V5L96-T961?<V5A<F-H7W-O=7)C97-;:5T@/2!N=6QL.PH@("`@
M("`@("`@("!I+2T["B`@("`@("`@?0H@("`@?0H*("`@(')E<V5T2&ED9&5N
M*"D["GT*"F9U;F-T:6]N(')E;6]V95-O=7)C92@I"GL*("`@(&9O<B`H:2`]
M(#$[(&D@/"!D;V-U;65N="YP<F5F<RYS96QE8W1E9%]S96%R8VA?<V]U<F-E
M<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AD;V-U;65N="YP<F5F<RYS
M96QE8W1E9%]S96%R8VA?<V]U<F-E<UMI72YS96QE8W1E9"D@>PH@("`@("`@
M("`@("!D;V-U;65N="YP<F5F<RYU;G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S
M6V1O8W5M96YT+G!R969S+G5N<V5L96-T961?<V5A<F-H7W-O=7)C97,N;&5N
M9W1H72`](&YE=R!/<'1I;VXH9&]C=6UE;G0N<')E9G,N<V5L96-T961?<V5A
M<F-H7W-O=7)C97-;:5TN=&5X="P@9&]C=6UE;G0N<')E9G,N<V5L96-T961?
M<V5A<F-H7W-O=7)C97-;:5TN=F%L=64I"B`@("`@("`@("`@(&1O8W5M96YT
M+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S6VE=(#T@;G5L;#L*("`@
M("`@("`@("`@:2TM.PH@("`@("`@('T*("`@('T*"B`@("!R97-E=$AI9&1E
M;B@I.PI]"@IF=6YC=&EO;B!M;W9E4V]U<F-E57`H*0I["B`@("!V87(@<V5L
M(#T@9&]C=6UE;G0N<')E9G,N<V5L96-T961?<V5A<F-H7W-O=7)C97,N<V5L
M96-T961);F1E>#L*"B`@("!I9B`H<V5L(#T]("TQ('Q\(&1O8W5M96YT+G!R
M969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S+FQE;F=T:"`\/2`R*2!R971U
M<FX["@H@("`@+R\@9&5S96QE8W0@979E<GET:&EN9R!B=70@=&AE(&9I<G-T
M('-E;&5C=&5D(&ET96T*("`@(&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E
M87)C:%]S;W5R8V5S+G-E;&5C=&5D26YD97@@/2!S96P["@H@("`@:68@*'-E
M;"`]/2`Q*2!["B`@("`@("`@=&UP(#T@9&]C=6UE;G0N<')E9G,N<V5L96-T
M961?<V5A<F-H7W-O=7)C97-;<V5L73L*("`@("`@("!D;V-U;65N="YP<F5F
M<RYS96QE8W1E9%]S96%R8VA?<V]U<F-E<UMS96Q=(#T@;G5L;#L*("`@("`@
M("!D;V-U;65N="YP<F5F<RYS96QE8W1E9%]S96%R8VA?<V]U<F-E<UMD;V-U
M;65N="YP<F5F<RYS96QE8W1E9%]S96%R8VA?<V]U<F-E<RYL96YG=&A=(#T@
M=&UP.PH@("`@("`@(&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S
M;W5R8V5S+G-E;&5C=&5D26YD97@@/2!D;V-U;65N="YP<F5F<RYS96QE8W1E
M9%]S96%R8VA?<V]U<F-E<RYL96YG=&@@+2`Q.PH@("`@?2!E;'-E('L*("`@
M("`@("!T;7`@/2!N97<@07)R87DH*3L*"B`@("`@("`@9F]R("AI(#T@,3L@
M:2`\(&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S+FQE
M;F=T:#L@:2LK*2!["B`@("`@("`@("`@('1M<%MI("T@,5T@/2!N97<@3W!T
M:6]N*&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S6VE=
M+G1E>'0L(&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S
M6VE=+G9A;'5E*0H@("`@("`@('T*"B`@("`@("`@9F]R("AI(#T@,#L@:2`\
M('1M<"YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!I9B`H:2`K(#$@/3T@
M<V5L("T@,2D@>PH@("`@("`@("`@("`@("`@9&]C=6UE;G0N<')E9G,N<V5L
M96-T961?<V5A<F-H7W-O=7)C97-;:2`K(#%=(#T@=&UP6VD@*R`Q73L*("`@
M("`@("`@("`@?2!E;'-E(&EF("AI("L@,2`]/2!S96PI('L*("`@("`@("`@
M("`@("`@(&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S
M6VD@*R`Q72`]('1M<%MI("T@,5T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!D;V-U;65N="YP<F5F<RYS96QE8W1E9%]S96%R8VA?
M<V]U<F-E<UMI("L@,5T@/2!T;7!;:5T["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S
M;W5R8V5S+G-E;&5C=&5D26YD97@@/2!S96P@+2`Q.PH@("`@?0H*("`@(')E
M<V5T2&ED9&5N*"D["GT*"F9U;F-T:6]N(&UO=F53;W5R8V5$;W=N*"D*>PH@
M("`@=F%R('-E;"`](&1O8W5M96YT+G!R969S+G-E;&5C=&5D7W-E87)C:%]S
M;W5R8V5S+G-E;&5C=&5D26YD97@["@H@("`@:68@*'-E;"`]/2`M,2!\?"!D
M;V-U;65N="YP<F5F<RYS96QE8W1E9%]S96%R8VA?<V]U<F-E<RYL96YG=&@@
M/#T@,BD@<F5T=7)N.PH*("`@("\O(&1E<V5L96-T(&5V97)Y=&AI;F<@8G5T
M('1H92!F:7)S="!S96QE8W1E9"!I=&5M"B`@("!D;V-U;65N="YP<F5F<RYS
M96QE8W1E9%]S96%R8VA?<V]U<F-E<RYS96QE8W1E9$EN9&5X(#T@<V5L.PH*
M("`@(&EF("AS96P@/3T@9&]C=6UE;G0N<')E9G,N<V5L96-T961?<V5A<F-H
M7W-O=7)C97,N;&5N9W1H("T@,2D@>PH@("`@("`@('1M<"`](&YE=R!!<G)A
M>2@I.PH*("`@("`@("!F;W(@*&D@/2`Q.R!I(#P@9&]C=6UE;G0N<')E9G,N
M<V5L96-T961?<V5A<F-H7W-O=7)C97,N;&5N9W1H.R!I*RLI('L*("`@("`@
M("`@("`@=&UP6VD@+2`Q72`](&YE=R!/<'1I;VXH9&]C=6UE;G0N<')E9G,N
M<V5L96-T961?<V5A<F-H7W-O=7)C97-;:5TN=&5X="P@9&]C=6UE;G0N<')E
M9G,N<V5L96-T961?<V5A<F-H7W-O=7)C97-;:5TN=F%L=64I"B`@("`@("`@
M?0H*("`@("`@("!D;V-U;65N="YP<F5F<RYS96QE8W1E9%]S96%R8VA?<V]U
M<F-E<ULQ72`]('1M<%MT;7`N;&5N9W1H("T@,5T["B`@("`@("`@9F]R("AI
M(#T@,#L@:2`\('1M<"YL96YG=&@@+2`Q.R!I*RLI('L*("`@("`@("`@("`@
M9&]C=6UE;G0N<')E9G,N<V5L96-T961?<V5A<F-H7W-O=7)C97-;:2`K(#)=
M(#T@=&UP6VE=.PH@("`@("`@('T*"B`@("`@("`@9&]C=6UE;G0N<')E9G,N
M<V5L96-T961?<V5A<F-H7W-O=7)C97,N<V5L96-T961);F1E>"`](#$["B`@
M("!](&5L<V4@>PH@("`@("`@('1M<"`](&YE=R!!<G)A>2@I.PH*("`@("`@
M("!F;W(@*&D@/2`Q.R!I(#P@9&]C=6UE;G0N<')E9G,N<V5L96-T961?<V5A
M<F-H7W-O=7)C97,N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@=&UP6VD@
M+2`Q72`](&YE=R!/<'1I;VXH9&]C=6UE;G0N<')E9G,N<V5L96-T961?<V5A
M<F-H7W-O=7)C97-;:5TN=&5X="P@9&]C=6UE;G0N<')E9G,N<V5L96-T961?
M<V5A<F-H7W-O=7)C97-;:5TN=F%L=64I"B`@("`@("`@?0H*("`@("`@("!F
M;W(@*&D@/2`P.R!I(#P@=&UP+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@
M(&EF("AI("L@,2`]/2!S96PI('L*("`@("`@("`@("`@("`@(&1O8W5M96YT
M+G!R969S+G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S6VD@*R`Q72`]('1M<%MI
M("L@,5T["B`@("`@("`@("`@('T@96QS92!I9B`H:2`K(#$@/3T@<V5L("L@
M,2D@>PH@("`@("`@("`@("`@("`@9&]C=6UE;G0N<')E9G,N<V5L96-T961?
M<V5A<F-H7W-O=7)C97-;:2`K(#%=(#T@=&UP6VD@+2`Q73L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&1O8W5M96YT+G!R969S+G-E
M;&5C=&5D7W-E87)C:%]S;W5R8V5S6VD@*R`Q72`]('1M<%MI73L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@9&]C=6UE;G0N<')E9G,N<V5L
M96-T961?<V5A<F-H7W-O=7)C97,N<V5L96-T961);F1E>"`]('-E;"`K(#$[
M"B`@("!]"@H@("`@<F5S971(:61D96XH*3L*?0H*/#]P:'`@96-H;R`D:G,@
M/SX*"G9A<B!S96QE8W1E9$EN9&5X(#T@9F%L<V4["G9A<B!S96QE8W1E9%9A
M;'5E(#T@9F%L<V4["G9A<B!N8E-O=7)C97,@/2`\/W!H<"!E8VAO("1N8E)E
M8613;W5R8V5S(#\^.PH\/W!H<"!I9B`H)&YB4F5A9%-O=7)C97,@/3T@,2DZ
M(#\^"G-E;&5C=&5D26YD97@@/2`Q.PIS96QE8W1E9%9A;'5E(#T@(CP_<&AP
M(&5C:&\@)'-E;&5C=&5D6S!=(#\^(CL*/#]P:'`@96YD:68[(#\^"@IF=6YC
M=&EO;B!U<&1A=&5396%R8VA&:65L9',H*0I["B`@("!V87(@9B`](&1O8W5M
M96YT+G!R969S.PH@("`@/#]P:'`@:68@*"1N8E)E8613;W5R8V5S(#X@,2DZ
M(#\^"B`@("!S96QE8W1E9$EN9&5X(#T@9BYS96QE8W1E9%]S96%R8VA?<V]U
M<F-E<RYS96QE8W1E9$EN9&5X.PH@("`@/#]P:'`@96YD:68[(#\^"B`@("!V
M87(@9FEE;&13=')I;F<@/2`G)SL*"B`@("!W:&EL92`H9BYS96%R8VA?9FEE
M;&1S+FQE;F=T:"`^(#`I('L*("`@("`@("!F+G-E87)C:%]F:65L9',N;W!T
M:6]N<UMF+G-E87)C:%]F:65L9',N;&5N9W1H+3%=(#T@;G5L;#L*("`@('T*
M"B`@("!I9B`H<V5L96-T961);F1E>"`\(#$I('L*("`@("`@("!R971U<FX[
M"B`@("!]"@H@("`@/#]P:'`@:68@*"1N8E)E8613;W5R8V5S(#X@,2DZ(#\^
M"B`@("!S96QE8W1E9%9A;'5E(#T@9BYS96QE8W1E9%]S96%R8VA?<V]U<F-E
M<RYO<'1I;VYS6W-E;&5C=&5D26YD97A=+G9A;'5E.PH@("`@/#]P:'`@96YD
M:68[(#\^"@H@("`@9F]R("AV87(@:2`](#`[(&D@/"!S96%R8VA&:65L9',N
M;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H:2`^(#`I('L*("`@("`@("`@
M("`@9FEE;&13=')I;F<@*ST@(EQN(CL*("`@("`@("!]"B`@("`@("`@9FEE
M;&13=')I;F<@*ST@<V5A<F-H1FEE;&1S6VE=6S!=.PH@("`@("`@(&9O<B`H
M=F%R(&H@/2`Q.R!J(#P@<V5A<F-H1FEE;&1S6VE=+FQE;F=T:#L@:BLK*2![
M"B`@("`@("`@("`@(&EF("AS96%R8VA&:65L9'-;:5U;:EU;,ETI('L*("`@
M("`@("`@("`@("`@(&9I96QD4W1R:6YG("L](")<="(@*R!S96%R8VA&:65L
M9'-;:5U;:EU;,%T["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AS
M96%R8VA&:65L9'-;:5U;,%T@/3T@<V5L96-T961686QU92D@>PH@("`@("`@
M("`@("`@("`@9BYS96%R8VA?9FEE;&1S+F]P=&EO;G-;9BYS96%R8VA?9FEE
M;&1S+FQE;F=T:%T@/2!N97<@3W!T:6]N*'-E87)C:$9I96QD<UMI75MJ75LQ
M72P@<V5A<F-H1FEE;&1S6VE=6VI=6S!=*3L*("`@("`@("`@("`@("`@(&EF
M("AS96%R8VA&:65L9'-;:5U;:EU;,ETI('L*("`@("`@("`@("`@("`@("`@
M("!F+G-E87)C:%]F:65L9',N;W!T:6]N<UMF+G-E87)C:%]F:65L9',N;&5N
M9W1H("T@,5TN<V5L96-T960@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&8N<V5A<F-H7V9I
M96QD<U]S=')I;F<N=F%L=64@/2!F:65L9%-T<FEN9SL*?0H*9G5N8W1I;VX@
M8VAA;F=E4V5A<F-H1FEE;&1S*"D*>PH@("`@=F%R(&8@/2!D;V-U;65N="YP
M<F5F<SL*("`@(#P_<&AP(&EF("@D;F)296%D4V]U<F-E<R`^(#$I.B`_/@H@
M("`@<V5L96-T961);F1E>"`](&8N<V5L96-T961?<V5A<F-H7W-O=7)C97,N
M<V5L96-T961);F1E>#L*("`@('-E;&5C=&5D5F%L=64@/2!F+G-E;&5C=&5D
M7W-E87)C:%]S;W5R8V5S+F]P=&EO;G-;<V5L96-T961);F1E>%TN=F%L=64[
M"B`@("`\/W!H<"!E;F1I9CL@/SX*"B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\
M('-E87)C:$9I96QD<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AS96%R
M8VA&:65L9'-;:5U;,%T@/3T@<V5L96-T961686QU92D@>PH@("`@("`@("`@
M("!F;W(@*'9A<B!J(#T@,3L@:B`\('-E87)C:$9I96QD<UMI72YL96YG=&@[
M(&HK*RD@>PH@("`@("`@("`@("`@("`@<V5A<F-H1FEE;&1S6VE=6VI=6S)=
M(#T@9BYS96%R8VA?9FEE;&1S+F]P=&EO;G-;:B`M(#%=+G-E;&5C=&5D.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@('5P9&%T95-E87)C:$9I96QD<R@I
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0I]"@HO+R`M
M+3X*/"]S8W)I<'0^"@H\8G(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB<V5A<F-H7W-O=7)C97,B('9A;'5E/2(\/W!H<"!E8VAO(&EM<&QO9&4H
M(EQT(BP@)'-E;&5C=&5D*2`_/B(@+SX*/#]P:'`@:68@*"1N8E)E8613;W5R
M8V5S(#X@,2DZ(#\^"CP_<&AP(&5C:&\@7R@B0VAO;W-E('1H92!O<F1E<B!O
M9B!A9&1R97-S(&)O;VMS('1O('-E87)C:"!W:&5N(&5X<&%N9&EN9R!A9&1R
M97-S97,N(BD@/SX\8G(@+SX*/'1A8FQE/@H@/'1R/@H@(#QT9#X*("`@/'-E
M;&5C="!N86UE/2)U;G-E;&5C=&5D7W-E87)C:%]S;W5R8V5S(B!M=6QT:7!L
M93TB;75L=&EP;&4B('-I>F4](C4B('=I9'1H/2(R,"(@;VYC:&%N9V4](F1E
M<V5L96-T2&5A9&5R<R@I(CX*("`@(#QO<'1I;VX@=F%L=64](B(^/#]P:'`@
M96-H;R!?*")!=F%I;&%B;&4@061D<F5S<R!B;V]K<SHB*2`_/CPO;W!T:6]N
M/@H@("`@/#]P:'`@96-H;R`D<F5A9%-E;&5C="`_/@H@("`\+W-E;&5C=#X*
M("`\+W1D/@H@(#QT9#X*("`@/&$@:')E9CTB(B!O;F-L:6-K/2)A9&13;W5R
M8V4H*3L@<F5T=7)N(&9A;'-E.R(^/#]P:'`@96-H;R!(;W)D93HZ:6UG*&ES
M<V5T*"1'3$]"04Q36R=N;',G75LG<G1L)UU;)$=,3T)!3%-;)VQA;F=U86=E
M)UU=*2`_("=L:&%N9"YP;F<G(#H@)W)H86YD+G!N9R<L(%\H(D%D9"!S;W5R
M8V4B*2P@;G5L;"P@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@
M/SX\+V$^"B`@(#QB<B`O/@H@("`\82!H<F5F/2(B(&]N8VQI8VL](G)E;6]V
M95-O=7)C92@I.R!R971U<FX@9F%L<V4[(CX\/W!H<"!E8VAO($AO<F1E.CII
M;6<H:7-S970H)$=,3T)!3%-;)VYL<R==6R=R=&PG75LD1TQ/0D%,4ULG;&%N
M9W5A9V4G75TI(#\@)W)H86YD+G!N9R<@.B`G;&AA;F0N<&YG)RP@7R@B4F5M
M;W9E('-O=7)C92(I+"!N=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*2`_/CPO83X*("`\+W1D/@H@(#QT9#X*("`@/'-E;&5C="!N86UE
M/2)S96QE8W1E9%]S96%R8VA?<V]U<F-E<R(@;75L=&EP;&4](FUU;'1I<&QE
M(B!S:7IE/2(U(B!W:61T:#TB,C`B(&]N8VAA;F=E/2)D97-E;&5C=$AE861E
M<G,H*3MU<&1A=&5396%R8VA&:65L9',H*3LB/@H@("`@/&]P=&EO;B!V86QU
M93TB(CX\/W!H<"!E8VAO(%\H(E-E;&5C=&5D($%D9')E<W,@8F]O:W,Z(BD@
M/SX\+V]P=&EO;CX*("`@(#P_<&AP(&5C:&\@)'!R969396QE8W0@/SX*("`@
M/"]S96QE8W0^"B`@/"]T9#X*("`\=&0^"B`@(#QA(&AR968](B(@;VYC;&EC
M:STB;6]V95-O=7)C955P*"D[(')E='5R;B!F86QS93LB/CP_<&AP(&5C:&\@
M2&]R9&4Z.FEM9R@G;F%V+W5P+G!N9R<L(%\H(DUO=F4@=7`B*2P@;G5L;"P@
M)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX\+V$^"B`@(#QB
M<B`O/@H@("`\82!H<F5F/2(B(&]N8VQI8VL](FUO=F53;W5R8V5$;W=N*"D[
M(')E='5R;B!F86QS93LB/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G;F%V+V1O
M=VXN<&YG)RP@7R@B36]V92!D;W=N(BDL(&YU;&PL("1R96=I<W1R>2T^9V5T
M26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H@(#PO=&0^"B`\+W1R/@H\+W1A
M8FQE/@H*/#]P:'`@96-H;R!?*")#;&EC:R!O;B!O;F4@;V8@>6]U<B!S96QE
M8W1E9"!A9&1R97-S(&)O;VMS(&%N9"!T:&5N('-E;&5C="!A;&P@9FEE;&1S
M('1O('-E87)C:"XB*2`_/CQB<B`O/@H\/W!H<"!E;'-E.B`_/@H\/W!H<"!E
M8VAO(%\H(E-E;&5C="!A;&P@9FEE;&1S('1O('-E87)C:"!W:&5N(&5X<&%N
M9&EN9R!A9&1R97-S97,N(BD@/SX\8G(@+SX*/#]P:'`@96YD:68[(#\^"@H\
M/W!H<"!E8VAO(%\H(E1O('-E;&5C="!M=6QT:7!L92!F:65L9',L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@=VAI;&4@
M8VQI8VMI;F<N(BD@/SX\8G(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB<V5A<F-H7V9I96QD<U]S=')I;F<B("\^"CQT86)L93X*(#QT<CX*("`\
M=&0^"B`@(#QS96QE8W0@;F%M93TB<V5A<F-H7V9I96QD<R(@;75L=&EP;&4]
M(FUU;'1I<&QE(B!S:7IE/2(U(B!W:61T:#TB,C`B(&]N8VAA;F=E/2)C:&%N
M9V5396%R8VA&:65L9',H*2(^"B`@("`\;W!T:6]N/CP_<&AP(&5C:&\@<W1R
M7W)E<&5A="@G)FYB<W`[)RP@-3`I(#\^/"]O<'1I;VX^"B`@(#PO<V5L96-T
M/@H@(#PO=&0^"B`\+W1R/@H\+W1A8FQE/@H*/'-C<FEP="!T>7!E/2)T97AT
M+VIA=F%S8W)I<'0B/@H\(2TM"G5P9&%T95-E87)C:$9I96QD<R@I.PHO+R`M
M+3X*/"]S8W)I<'0^"@H\/W!H<"!E;F1I9CL@/SX*"@H\/W!H<"!I9B`H(21P
M<F5F<RT^:7-,;V-K960H)V%D9%]S;W5R8V4G*2`F)B`A96UP='DH)'=R:71E
M4V5L96-T*2DZ(#\^"@H@(#P_<&AP(&5C:&\@7R@B0VAO;W-E('1H92!A9&1R
M97-S(&)O;VL@=&\@=7-E('=H96X@861D:6YG(&%D9')E<W-E<RXB*2`_/CQB
M<B`O/@H@(#QB<B`O/@H@(#QS96QE8W0@;F%M93TB861D7W-O=7)C92(^/#]P
M:'`@96-H;R`D=W)I=&5396QE8W0@/SX\+W-E;&5C=#X*"CP_<&AP(&5N9&EF
M.R`_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O=&5M<&QA=&5S+W!R969S+W-P86US96QE8W0N:6YC````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,C(T`#$P-#$W,S8R-S8V`#`R,S$V,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<"!I
M9B`H(21P<F5F<RT^:7-,;V-K960H)W-P86U?9F]L9&5R)RDI.B`_/@H\<V-R
M:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"F9U;F-T:6]N(&YE
M=U-P86U&;VQD97).86UE*"D*>PH@("`@9&]C=6UE;G0N<')E9G,N<W!A;2YO
M;F-H86YG92`](&YU;&P["B`@("!I9B`H9&]C=6UE;G0N<')E9G,N<W!A;5MD
M;V-U;65N="YP<F5F<RYS<&%M+G-E;&5C=&5D26YD97A=+G9A;'5E(#T]("<G
M*2!["B`@("`@("`@=F%R(&9O;&1E<B`]('=I;F1O=RYP<F]M<'0H)SP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")%;G1E<B!T:&4@;F%M92!F;W(@>6]U<B!N
M97<@4W!A;2!F;VQD97(B*2D@/SXG+"!D;V-U;65N="YP<F5F<RYS<&%M7VYE
M=RYV86QU92`_(&1O8W5M96YT+G!R969S+G-P86U?;F5W+G9A;'5E(#H@)R<I
M.PH@("`@("`@(&EF("AF;VQD97(@(3T@)R<I('L*("`@("`@("`@("`@9&]C
M=6UE;G0N<')E9G,N<W!A;5]N97<N=F%L=64@/2!F;VQD97(["B`@("`@("`@
M("`@(&1O8W5M96YT+G!R969S+G-P86U;,5TN=&5X="`]("<\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B0W)E871E(&$@;F5W(%-P86T@9F]L9&5R(BDI(#\^
M(%LG("L@9&]C=6UE;G0N<')E9G,N<W!A;5]N97<N=F%L=64@*R`G72<["B`@
M("`@("`@?0H@("`@?0H@("`@9&]C=6UE;G0N<')E9G,N<W!A;2YO;F-H86YG
M92`](&YE=U-P86U&;VQD97).86UE.PI]"@HO+R`M+3X*/"]S8W)I<'0^"@H\
M=&%B;&4@8F]R9&5R/2(P(CX*(#QT<CX*("`\=&0^/#]P:'`@96-H;R!?*")3
M<&%M(&9O;&1E<CHB*2`_/CQB<B`O/@H@("`\<V5L96-T(&YA;64](G-P86TB
M(&]N8VAA;F=E/2)N97=3<&%M1F]L9&5R3F%M92@I.R(^/&]P=&EO;B!V86QU
M93TB/#]P:'`@96-H;R!)35!?4%)%1E].3U]&3TQ$15(@/SXB/CP_<&AP(&5C
M:&\@7R@B3F]N92(I(#\^/"]O<'1I;VX^/#]P:'`@96-H;R!)35`Z.F9L:7-T
M4V5L96-T*%\H(D-R96%T92!A(&YE=R!3<&%M(&9O;&1E<B(I+"!T<G5E+"!A
M<G)A>2@G24Y"3U@G*2P@24U0.CIF;VQD97)0<F5F*"1P<F5F<RT^9V5T5F%L
M=64H)W-P86U?9F]L9&5R)RDL('1R=64I*2`_/CPO<V5L96-T/@H@("`\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)S<&%M7VYE=R(@=F%L=64](B(@+SX*
M("`\+W1D/@H@/"]T<CX*/"]T86)L93X*/#]P:'`@96YD:68[(#\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O<')E9G,O
M:6YI=&EA;'!A9V5S96QE8W0N:6YC````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q,C,`
M,3`T,3<S-C(W-C8`,#(T-3`V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G
M:6YI=&EA;%]P86=E)RDI.B`_/@H\/W!H<`H@("`@:68@*"@D<')E9G,M/F=E
M=%9A;'5E*"=I;FET:6%L7W!A9V4G*2`]/2`G9F]L9&5R<RYP:'`G*2`F)@H@
M("`@("`@("1'3$]"04Q36R=C;VYF)UU;)W5S97(G75LG86QL;W=?9F]L9&5R
M<R==*2!["B`@("`@("`@)&9O;&1E<G-?;W!T:6]N(#T@)SQO<'1I;VX@=F%L
M=64](F9O;&1E<G,N<&AP(B!S96QE8W1E9#TB<V5L96-T960B/B<@+@H@("`@
M("`@("`@("!?*")&;VQD97(@3F%V:6=A=&]R(BD@+B`B/"]O<'1I;VX^7&XB
M.PH@("`@("`@("1M86EL8F]X7V]P=&EO;B`]($E-4#HZ9FQI<W1396QE8W0H
M*3L*("`@('T@96QS92!["B`@("`@("`@:68@*"1'3$]"04Q36R=C;VYF)UU;
M)W5S97(G75LG86QL;W=?9F]L9&5R<R==*2!["B`@("`@("`@("`@("1F;VQD
M97)S7V]P=&EO;B`]("<\;W!T:6]N('9A;'5E/2)F;VQD97)S+G!H<"(^)R`N
M(%\H(D9O;&1E<B!.879I9V%T;W(B*2`N("(\+V]P=&EO;CY<;B(["B`@("`@
M("`@("`@("1M86EL8F]X7W-E;&5C=&5D(#T@)'!R969S+3YG971686QU92@G
M:6YI=&EA;%]P86=E)RD["B`@("`@("`@("`@("1M86EL8F]X7V]P=&EO;B`]
M($E-4#HZ9FQI<W1396QE8W0H)R<L('1R=64L(&%R<F%Y*"DL("1M86EL8F]X
M7W-E;&5C=&5D+"!F86QS92P@9F%L<V4L('1R=64I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1M86EL8F]X7V]P=&EO;B`]("<\;W!T:6]N('9A
M;'5E/2))3D)/6"(@<V5L96-T960](G-E;&5C=&5D(CXG("X@7R@B26YB;W@B
M*2`N("<\+V]P=&EO;CXG.PH@("`@("`@("`@("`D9F]L9&5R<U]O<'1I;VX@
M/2`G)SL*("`@("`@("!]"B`@("!]"C\^"@H\=&%B;&4^"B`\='(^"B`@/'1D
M/@H@("`\/W!H<"!E8VAO(%\H(E9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN.B(I(#\^/&)R("\^"B`@(#QS96QE8W0@;F%M93TB:6YI
M=&EA;%]P86=E(CX*("`@(#P_<&AP(&5C:&\@)&9O;&1E<G-?;W!T:6]N(#\^
M"B`@("`\/W!H<"!E8VAO("1M86EL8F]X7V]P=&EO;B`_/@H@("`\+W-E;&5C
M=#X*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*/#]P:'`@96YD:68[(#\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+W1E;7!L871E<R]P<F5F<R]T<F%S:'-E;&5C="YI;F,`````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C,Q,P`Q,#0Q-S,V,C<V-@`P,C,S-#(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`@
M:68@*"$D<')E9G,M/FES3&]C:V5D*"=T<F%S:%]F;VQD97(G*2`F)B`A)'!R
M969S+3YG971686QU92@G=7-E7W9T<F%S:"<I*3H@/SX*/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IF=6YC=&EO;B!N97=4<F%S:$9O
M;&1E<DYA;64H*0I["B`@("!D;V-U;65N="YP<F5F<RYT<F%S:"YO;F-H86YG
M92`](&YU;&P["B`@("!I9B`H9&]C=6UE;G0N<')E9G,N=')A<VA;9&]C=6UE
M;G0N<')E9G,N=')A<V@N<V5L96-T961);F1E>%TN=F%L=64@/3T@)R<I('L*
M("`@("`@("!V87(@9F]L9&5R(#T@=VEN9&]W+G!R;VUP="@G/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D5N=&5R('1H92!N86UE(&9O<B!Y;W5R(&YE=R!T
M<F%S:"!F;VQD97(B*2D@/SXG+"!D;V-U;65N="YP<F5F<RYT<F%S:%]N97<N
M=F%L=64@/R!D;V-U;65N="YP<F5F<RYT<F%S:%]N97<N=F%L=64@.B`G)RD[
M"B`@("`@("`@:68@*&9O;&1E<B`A/2`G)RD@>PH@("`@("`@("`@("!D;V-U
M;65N="YP<F5F<RYT<F%S:%]N97<N=F%L=64@/2!F;VQD97(["B`@("`@("`@
M("`@(&1O8W5M96YT+G!R969S+G1R87-H6S%=+G1E>'0@/2`G/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D-R96%T92!A(&YE=R!T<F%S:"!F;VQD97(B*2D@
M/SX@6R<@*R!D;V-U;65N="YP<F5F<RYT<F%S:%]N97<N=F%L=64@*R`G72<[
M"B`@("`@("`@?0H@("`@?0H@("`@9&]C=6UE;G0N<')E9G,N=')A<V@N;VYC
M:&%N9V4@/2!N97=4<F%S:$9O;&1E<DYA;64["GT*"B\O("TM/@H\+W-C<FEP
M=#X*"CQT86)L92!B;W)D97(](C`B/@H@/'1R/@H@(#QT9#X\/W!H<"!E8VAO
M(%\H(E1R87-H(&9O;&1E<CHB*2`_/CQB<B`O/@H@("`\<V5L96-T(&YA;64]
M(G1R87-H(B!O;F-H86YG93TB;F5W5')A<VA&;VQD97).86UE*"D[(CX\;W!T
M:6]N('9A;'5E/2(\/W!H<"!E8VAO($E-4%]04D5&7TY/7T9/3$1%4B`_/B(^
M/#]P:'`@96-H;R!?*").;VYE(BD@/SX\+V]P=&EO;CX\/W!H<"!E8VAO($E-
M4#HZ9FQI<W1396QE8W0H7R@B0W)E871E(&$@;F5W('1R87-H(&9O;&1E<B(I
M+"!T<G5E+"!A<G)A>2@G24Y"3U@G*2P@24U0.CIF;VQD97)0<F5F*"1P<F5F
M<RT^9V5T5F%L=64H)W1R87-H7V9O;&1E<B<I+"!T<G5E*2D@/SX\+W-E;&5C
M=#X*("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB=')A<VA?;F5W(B!V
M86QU93TB(B`O/@H@(#PO=&0^"B`\+W1R/@H\+W1A8FQE/@H\/W!H<"!E;F1I
M9CL@/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+W!R969S
M+V5N8W)Y<'1S96QE8W0N:6YC````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S<P
M`#$P-#$W,S8R-S8V`#`R,S<P-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<"!E8VAO(%\H(EEO=7(@9&5F875L="!E
M;F-R>7!T:6]N(&UE=&AO9"!F;W(@<V5N9&EN9R!M97-S86=E<SHB*2`_/CQB
M<B`O/@H\<V5L96-T(&YA;64](F1E9F%U;'1?96YC<GEP="(^"CP_<&AP"B`@
M("`D96YC<GEP=$]P="`]("1P<F5F<RT^9V5T5F%L=64H)V1E9F%U;'1?96YC
M<GEP="<I.PH@("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]C;VUP;W-E
M+V5N8W)Y<'1?;&ES="YI;F,G.PH_/@H\+W-E;&5C=#X*/&)R("\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]Q=6]T82\`````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V
M-@`P,C`S-#0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S
M+W%U;W1A+W%U;W1A+FEN8P``````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,30W`#$P-#$W,S8R-S8V`#`R,C$W,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`II9B`H:7-?82@D<75O=&$L
M("=014%27T5R<F]R)RDI('L*("`@("1C;&%S<R`]("=Q=6]T87=A<FXG.PH@
M("`@)&UE<W-A9V4@/2`D<75O=&$M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*
M("`@(&EF("@D<75O=&%;)VQI;6ET)UT@(3T@,"D@>PH@("`@("`@("1Q=6]T
M85LG=7-A9V4G72`]("1Q=6]T85LG=7-A9V4G72`O("@Q,#(T("H@,3`R-"XP
M*3L*("`@("`@("`D<75O=&%;)VQI;6ET)UT@/2`D<75O=&%;)VQI;6ET)UT@
M+R`H,3`R-"`J(#$P,C0N,"D["B`@("`@("`@)'!E<F-E;G0@/2`H)'%U;W1A
M6R=U<V%G92==("H@,3`P*2`O("1Q=6]T85LG;&EM:70G73L*("`@("`@("!I
M9B`H)'!E<F-E;G0@/CT@.3`I('L*("`@("`@("`@("`@)&-L87-S(#T@)W%U
M;W1A86QE<G0G.PH@("`@("`@('T@96QS96EF("@D<&5R8V5N="`^/2`W-2D@
M>PH@("`@("`@("`@("`D8VQA<W,@/2`G<75O=&%W87)N)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D8VQA<W,@/2`G8V]N=')O;"<["B`@("`@
M("`@?0H@("`@("`@("1M97-S86=E(#T@<W!R:6YT9BA?*")1=6]T82!S=&%T
M=7,Z("4N,F9-0B`O("4N,F9-0B`@*"4N,F8E)2DB*2P@)'%U;W1A6R=U<V%G
M92==+"`D<75O=&%;)VQI;6ET)UTL("1P97)C96YT*3L*("`@('T@96QS96EF
M("@D<75O=&%;)W5S86=E)UT@(3T@,"D@>PH@("`@("`@("1Q=6]T85LG=7-A
M9V4G72`]("1Q=6]T85LG=7-A9V4G72`O("@Q,#(T("H@,3`R-"XP*3L*("`@
M("`@("`D8VQA<W,@/2`G8V]N=')O;"<["B`@("`@("`@)&UE<W-A9V4@/2!S
M<')I;G1F*%\H(E%U;W1A('-T871U<SH@)2XR9DU"("\@3D\@3$E-250B*2P@
M)'%U;W1A6R=U<V%G92==*3L*("`@('T@96QS92!["B`@("`@("`@)&-L87-S
M(#T@)V-O;G1R;VPG.PH@("`@("`@("1M97-S86=E(#T@<W!R:6YT9BA?*")1
M=6]T82!S=&%T=7,Z($Y/($Q)34E4(BDI.PH@("`@?0I]"C\^"CQT86)L92!W
M:61T:#TB,3`P)2(@8F]R9&5R/2(P(B!C96QL<&%D9&EN9STB,R(@8V5L;'-P
M86-I;F<](C`B/@H@(#QT<CX\=&0@8VQA<W,](CP_<&AP(&5C:&\@)&-L87-S
M(#\^(B!A;&EG;CTB8V5N=&5R(CX*("`@(#P_<&AP(&5C:&\@)&UE<W-A9V4@
M/SX*("`\+W1D/CPO='(^"CPO=&%B;&4^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O<VUI;64O````````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C8`,#(P
M,S(U`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]S;6EM
M92]S;6EM92YI;F,`````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S,W
M,0`Q,#0Q-S,V,C<V-@`P,C(Q,S0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/&EN<'5T(&ED/2)U<V5?<VUI;64B('1Y<&4]
M(F-H96-K8F]X(B!N86UE/2)U<V5?<VUI;64B/#]P:'`@96-H;R`H)'!R969S
M+3YG971686QU92@G=7-E7W-M:6UE)RDI(#\@)R!C:&5C:V5D/2)C:&5C:V5D
M(B<@.B`G)R`_/B`O/B`\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G=7-E7W-M
M:6UE)RP@7R@B16YA8FQE(%,O34E-12!F=6YC=&EO;F%L:71Y/R(I*2`_/B9N
M8G-P.SP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W-M:6UE+6]V97)V
M:65W)RD@/SX\8G(@+SX*/'-T<F]N9R!S='EL93TB8V]L;W(Z<F5D(CX\/W!H
M<"!E8VAO(%\H(DY/5$4B*2`_/CH\+W-T<F]N9SX@/#]P:'`@96-H;R!?*")3
M+TU)344@<W5P<&]R="!R97%U:7)E<R!P;W!U<"!W:6YD;W=S('1O(&)E('5S
M960N("!)9B!Y;W5R(&)R;W=S97(@:7,@8W5R<F5N=&QY('-E="!T;R!D:7-A
M8FQE('!O<'5P('=I;F1O=W,L('EO=2!M=7-T(&-H86YG92!T:&ES('-E='1I
M;F<@;W(@96QS92!T:&4@4R]-24U%(&9E871U<F5S('=I;&P@;F]T('=O<FL@
M8V]R<F5C=&QY+B(I(#\^/&)R("\^"CPO9&EV/@H*/&)R(&-L87-S/2)S<&%C
M97(B("\^"CQD:78@8VQA<W,](FAE861E<B(^"B`@/'5L/@H@("`@/&QI/CP_
M<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W-M:6UE+6UA;F%G92UP=6)K
M97DG*2`_/CPO;&D^"B`@/"]U;#X*("`\/W!H<"!E8VAO(%\H(E,O34E-12!0
M=6)L:6,@2V5Y<FEN9R(I(#\^"CPO9&EV/@H*/&1I=B!C;&%S<STB:71E;2(^
M"CP_<&AP(&EF("AE;7!T>2@D<'5B:V5Y7VQI<W0I*3H@/SX*/'-T<F]N9SX\
M/W!H<"!E8VAO(%\H(DYO(%!U8FQI8R!+97ES($9O=6YD(BD@/SX\+W-T<F]N
M9SX*"CP_<&AP(&5L<V5I9B`H:7-?82@D<'5B:V5Y7VQI<W0L("=014%27T5R
M<F]R)RDI.B`_/@H\<W1R;VYG/CP_<&AP(&5C:&\@7R@B17)R;W(B*2`_/CH\
M+W-T<F]N9SX@/#]P:'`@96-H;R`D<'5B:V5Y7VQI<W0M/F=E=$UE<W-A9V4H
M*2`_/@H*/#]P:'`@96QS93H@/SX*/'1A8FQE/@H\/W!H<"!F;W)E86-H("@D
M<'5B:V5Y7VQI<W0@87,@)'9A;"DZ("1L:6YK=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1S96QF55),+"`G96UA:6PG+"`D=F%L6R=E;6%I;"==*3L@/SX*
M("`\='(^"B`@("`\=&0^/#]P:'`@96-H;R`D=F%L6R=N86UE)UT@/SX@*#P_
M<&AP(&5C:&\@)'9A;%LG96UA:6PG72`_/BD\+W1D/@H@("`@/'1D/B9N8G-P
M.R9N8G-P.UL\/W!H<"!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M
M971E<B@D;&EN:W5R;"P@)V%C=&EO;DE$)RP@)W9I97=?<'5B;&EC7VME>2<I
M+"!S<')I;G1F*%\H(E9I97<@)7,@4'5B;&EC($ME>2(I+"`D=F%L6R=N86UE
M)UTI+"!N=6QL+"`G=FEE=U]K97DG*3L@/SX\/W!H<"!E8VAO(%\H(E9I97<B
M*2`_/CPO83Y=)FYB<W`[6SP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ
M861D4&%R86UE=&5R*"1L:6YK=7)L+"`G86-T:6]N240G+"`G:6YF;U]P=6)L
M:6-?:V5Y)RDL('-P<FEN=&8H7R@B26YF;W)M871I;VX@;VX@)7,@4'5B;&EC
M($ME>2(I+"`D=F%L6R=N86UE)UTI+"!N=6QL+"`G:6YF;U]K97DG*3L@/SX\
M/W!H<"!E8VAO(%\H(D1E=&%I;',B*2`_/CPO83Y=)FYB<W`[6SP_<&AP(&5C
M:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*"1L:6YK=7)L+"`G
M86-T:6]N240G+"`G9&5L971E7W!U8FQI8U]K97DG*2P@<W!R:6YT9BA?*")$
M96QE=&4@)7,@4'5B;&EC($ME>2(I+"`D=F%L6R=N86UE)UTI+"!N=6QL+"!N
M=6QL+"`B:68@*&-O;F9I<FTH)R(@+B!A9&1S;&%S:&5S*%\H(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!P=6)L:6,@:V5Y/R(I*2`N
M("(G*2D@>R!R971U<FX@=')U93L@?2!E;'-E('L@<F5T=7)N(&9A;'-E.R!]
M(BD[(#\^/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/CPO83Y=/"]T9#X*("`\
M+W1R/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H\/W!H<"!E;F1I
M9CL@/SX*/"]D:78^"@H\8G(@8VQA<W,](G-P86-E<B(@+SX*/&1I=B!C;&%S
M<STB;F]W<F%P(CX*/#]P:'`@:68@*"$D:6UP6R=F:6QE7W5P;&]A9"==*3H@
M/SX*("`\<W!A;B!S='EL93TB8V]L;W(Z<F5D(CX\/W!H<"!E8VAO(%\H(DME
M>2!I;7!O<G0@:7,@;F]T(&%V86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T
M(&5N86)L960@;VX@=&AI<R!S97)V97(N(BD@/SX\+W-P86X^"CP_<&AP(&5L
M<V5I9B`H(21'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G861D7W-O=7)C
M92<I*3H@/SX*("`\<W1R;VYG/CP_<&AP(&5C:&\@7R@B2V5Y(&EM<&]R="!I
M<R!N;W0@879A:6QA8FQE+B!9;W4@:&%V92!N;R!A9&1R97-S(&)O;VL@9&5F
M:6YE9"!T;R!A9&0@>6]U<B!C;VYT86-T<RXB*2`_/CPO<W1R;VYG/@H\/W!H
M<"!E;'-E.B`_/@H@(#P_<&AP("1P=6)L:6-?:6UP;W)T7W5R;"`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D<V5L9E523"P@87)R87DH)V%C=&EO;DE$)R`]/B`G
M:6UP;W)T7W!U8FQI8U]K97DG+"`G<F5L;V%D)R`]/B`D<V5L9E523"DI.R`_
M/@H@(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](G-A=F4B(&-L87-S/2)B
M=71T;VXB(&]N8VQI8VL](G!O<'5P7VEM<"@G/#]P:'`@96-H;R`D<'5B;&EC
M7VEM<&]R=%]U<FP@/SXG+#<U,"PR-S4I.R!R971U<FX@9F%L<V4[(B!V86QU
M93TB/#]P:'`@96-H;R!?*"));7!O<G0@4'5B;&EC($ME>2(I(#\^(B`O/@H\
M/W!H<"!E;F1I9CL@/SX*/"]D:78^"@H\8G(@8VQA<W,](G-P86-E<B(@+SX*
M/&1I=B!C;&%S<STB:&5A9&5R(CX*("`\=6P^"B`@("`\;&D^/#]P:'`@96-H
M;R!(96QP.CIL:6YK*"=I;7`G+"`G<VUI;64M;W9E<G9I97<M<&5R<V]N86QK
M97DG*2`_/CPO;&D^"B`@/"]U;#X*("`\/W!H<"!E8VAO(%\H(EEO=7(@4R]-
M24U%(%!U8FQI8R]0<FEV871E($-E<G1I9FEC871E<R(I(#\^"CPO9&EV/@H*
M/&1I=B!C;&%S<STB:71E;2(^"CP_<&AP(&EF("AI<U]A*"1S96-U<F5?8VAE
M8VLL("=014%27T5R<F]R)RDI.B`_/@H\<W1R;VYG/CP_<&AP(&5C:&\@7R@B
M4R]-24U%(%!E<G-O;F%L($ME>7!A:7(@<W5P<&]R="!R97%U:7)E<R!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BXB*2`_/CPO<W1R;VYG/@H\+V1I=CX*"CP_
M<&AP"F5L<V5I9B`H)'!R969S+3YG971686QU92@G<VUI;65?<'5B;&EC7VME
M>2<I("8F"B`@("`@("`@)'!R969S+3YG971686QU92@G<VUI;65?<')I=F%T
M95]K97DG*2DZ"B`@("`D=FEE=W!U8FQI8U]U<FP@/2!5=&EL.CIA9&1087)A
M;65T97(H)'-E;&954DPL("=A8W1I;VY)1"<L("=V:65W7W!E<G-O;F%L7W!U
M8FQI8U]K97DG*3L*("`@("1I;F9O<'5B;&EC7W5R;"`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D<V5L9E523"P@)V%C=&EO;DE$)RP@)VEN9F]?<&5R<V]N86Q?
M<'5B;&EC7VME>2<I.PH@("`@)'5N;&]A9%]U<FP@/2!5=&EL.CIA9&1087)A
M;65T97(H)'-E;&954DPL("=A8W1I;VY)1"<L("=U;G-E=%]P87-S<&AR87-E
M)RD["B`@("`D=FEE=W!R:79A=&5?=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1S96QF55),+"`G86-T:6]N240G+"`G=FEE=U]P97)S;VYA;%]P<FEV871E
M7VME>2<I.PH_/@H\=&%B;&4^"B`@/'1R/@H@("`@/'1D/CP_<&AP(&5C:&\@
M7R@B66]U<B!0=6)L:6,@2V5Y(BD@/SXZ/"]T9#X*("`@(#QT9#XF;F)S<#LF
M;F)S<#M;/#]P:'`@96-H;R!(;W)D93HZ;&EN:R@D=FEE=W!U8FQI8U]U<FPL
M(%\H(E9I97<@4&5R<V]N86P@4'5B;&EC($ME>2(I+"!N=6QL+"`G=FEE=U]K
M97DG*2`N(%\H(E9I97<B*2`_/CPO83Y=)FYB<W`[6SP_<&AP(&5C:&\@2&]R
M9&4Z.FQI;FLH)&EN9F]P=6)L:6-?=7)L+"!?*"));F9O<FUA=&EO;B!O;B!0
M97)S;VYA;"!0=6)L:6,@2V5Y(BDL(&YU;&PL("=I;F9O7VME>2<I("X@7R@B
M1&5T86EL<R(I(#\^/"]A/ET\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D
M/CP_<&AP(&5C:&\@7R@B66]U<B!0<FEV871E($ME>2(I(#\^.CPO=&0^"B`@
M("`\=&0^)FYB<W`[)FYB<W`[/#]P:'`@:68@*"1P87-S<&AR87-E("$]/2!N
M=6QL*3H@/SY;/#]P:'`@96-H;R`H96UP='DH)'!A<W-P:')A<V4I*2`_($AO
M<F1E.CIL:6YK*"<C)RP@7R@B16YT97(@4&%S<W!H<F%S92(I+"!N=6QL+"!N
M=6QL+"!H=&UL<W!E8VEA;&-H87)S*"1O<&5N<VUI;65W:6XI("X@)R!R971U
M<FX@9F%L<V4[)RD@+B!?*")%;G1E<B!087-S<&AR87-E(BD@.B!(;W)D93HZ
M;&EN:R@D=6YL;V%D7W5R;"P@7R@B56YL;V%D(%!A<W-P:')A<V4B*2D@+B!?
M*")5;FQO860@4&%S<W!H<F%S92(I(#\^/"]A/ETF;F)S<#L\/W!H<"!E;F1I
M9CL@/SY;/#]P:'`@96-H;R!(;W)D93HZ;&EN:R@D=FEE=W!R:79A=&5?=7)L
M+"!?*")6:65W(%!E<G-O;F%L(%!R:79A=&4@2V5Y(BDL(&YU;&PL("=V:65W
M7VME>2<I("X@7R@B5FEE=R(I(#\^/"]A/ET\+W1D/@H@(#PO='(^"CPO=&%B
M;&4^"CPO9&EV/@H*/&)R(&-L87-S/2)S<&%C97(B("\^"CQD:78@8VQA<W,]
M(FYO=W)A<"(^"B`@/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB9&5L971E
M(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)I9B`H8V]N9FER;2@G/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D
M96QE=&4@>6]U<B!K97EP86ER/R`H5&AI<R!I<R!.3U0@<F5C;VUM96YD960A
M*2(I*2`_/B<I*2![(&1O8W5M96YT+G!R969S+F%C=&EO;DE$+G9A;'5E/2=D
M96QE=&5?:V5Y)SL@<F5T=7)N('1R=64[('T@96QS92![(')E='5R;B!F86QS
M93L@?2(@=F%L=64](CP_<&AP(&5C:&\@7R@B1&5L971E($-U<G)E;G0@2V5Y
M<R(I(#\^(B`O/@H@(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)W-M
M:6UE+61E;&5T92UP97)S;VYA;"UC97)T<R<I(#\^"CPO9&EV/@H*/#]P:'`@
M96QS93H@/SX*/'-T<F]N9SX\/W!H<"!E8VAO(%\H(DYO(%!E<G-O;F%L($-E
M<G1I9FEC871E(%!R97-E;G0B*2`_/CPO<W1R;VYG/@H\+V1I=CX*"CQB<B!C
M;&%S<STB<W!A8V5R(B`O/@H\9&EV(&-L87-S/2)N;W=R87`B/@H\/W!H<"`@
M(&EF("@D:6UP6R=F:6QE7W5P;&]A9"==*3H@/SX*("`\/W!H<"`D<&5R<V]N
M86Q?:6UP;W)T7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D<V5L9E523"P@
M)V%C=&EO;DE$)RP@)VEM<&]R=%]P97)S;VYA;%]C97)T<R<I.R`_/@H@(#QI
M;G!U="!T>7!E/2)S=6)M:70B(&YA;64](G-A=F4B(&-L87-S/2)B=71T;VXB
M(&]N8VQI8VL](G!O<'5P7VEM<"@G/#]P:'`@96-H;R`D<&5R<V]N86Q?:6UP
M;W)T7W5R;"`_/B<L-S4P+#(W-2D[(')E='5R;B!F86QS93LB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(DEM<&]R="!097)S;VYA;"!#97)T:69I8V%T92(I(#\^
M(B`O/@H\/W!H<"`@(&5L<V4Z(#\^"B`@/'-P86X@<W1Y;&4](F-O;&]R.G)E
M9"(^/#]P:'`@96-H;R!?*")#97)T:69I8V%T92!I;7!O<G0@:7,@;F]T(&%V
M86EL86)L92X@1FEL92!U<&QO860@:7,@;F]T(&5N86)L960@;VX@=&AI<R!S
M97)V97(N(BD@/SX\+W-P86X^"CP_<&AP("`@96YD:68[(#\^"CPO9&EV/@H\
M/W!H<"!E;F1I9CL@/SX*"CQB<B!C;&%S<STB<W!A8V5R(B`O/@H\9&EV(&-L
M87-S/2)N;W=R87`B/@H@(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](G-A
M=F4B(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F1O8W5M96YT+G!R969S+F%C
M=&EO;DE$+G9A;'5E/2=S879E7V]P=&EO;G,G.W)E='5R;B!T<G5E.R(@=F%L
M=64](CP_<&AP(&5C:&\@7R@B4V%V92!/<'1I;VYS(BD@/SXB("\^)FYB<W`[
M"B`@/&EN<'5T('1Y<&4](F)U='1O;B(@;F%M93TB8F%C:R(@8VQA<W,](F)U
M='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N;&]C871I;VXN:')E9CTG/#]P:'`@
M96-H;R!)35`Z.G!R969S55),*'1R=64I(#\^)R(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B4F5T=7)N('1O($]P=&EO;G,B*2`_/B(@+SX*/"]D:78^"@H\+V9O
M<FT^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+W-M:6UE+W!A
M<W-P:')A<V4N:6YC````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S8R`#$P
M-#$W,S8R-S8V`#`R,S$W,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<"!I9B`H(6ES7V$H)'-E8W5R95]C:&5C:RP@
M)U!%05)?17)R;W(G*2DZ(#\^"CQF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB
M<&%S<W!H<F%S95]D:6%L;V<B(&%C=&EO;CTB/#]P:'`@96-H;R`D<W5B;6ET
M7W5R;"`_/B(^"CP_<&AP(&EF("@H)')E;&]A9"`](%5T:6PZ.F=E=$9O<FU$
M871A*"=R96QO860G*2DI.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)R96QO860B('9A;'5E/2(\/W!H<"!E8VAO("1R96QO860@/SXB("\^"CP_
M<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H*"1A8W1I;VX@/2!5=&EL.CIG971&
M;W)M1&%T82@G<&%S<W!H<F%S95]A8W1I;VXG*2DI.B`_/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)P87-S<&AR87-E7V%C=&EO;B(@=F%L=64](CP_
M<&AP(&5C:&\@)&%C=&EO;B`_/B(@+SX*/#]P:'`@96YD:68[(#\^"@H\=&%B
M;&4@8F]R9&5R/2(P(B!C96QL<W!A8VEN9STB,"(@8V5L;'!A9&1I;F<](C(B
M/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB<VUA;&QH96%D97(@;&5F=$%L:6=N
M(CX*("`@("`@/#]P:'`@<')I;G1F*%\H(E!L96%S92!E;G1E<B!T:&4@<&%S
M<W!H<F%S92!F;W(@>6]U<B!3+TU)344@<')I=F%T92!K97DN(%EO=2!W:6QL
M(&]N;'D@;F5E9"!T;R!E;G1E<B!T:&ES('!A<W-P:')A<V4@;VYC92!P97(@
M)7,@<V5S<VEO;BXB*2P@7R@B36%I;"(I*2`_/@H@("`@/"]T9#X*("`\+W1R
M/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB;&EG:'0@;&5F=$%L:6=N(CX*("`@
M("`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E!A<W-P:')A<V4Z(BD@/SX\+W-T
M<F]N9SXF;F)S<#L*("`@("`@/&EN<'5T('1Y<&4](G!A<W-W;W)D(B!N86UE
M/2)P87-S<&AR87-E(B!S:7IE/2(Q-2(@;6%X;&5N9W1H/2(V,"(@8VQA<W,]
M(F9I>&5D(B`O/B9N8G-P.PH@("`@("`\:6YP=70@='EP93TB<W5B;6ET(B!N
M86UE/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(E-U8FUI="(I(#\^(B`O/B9N8G-P.PH@("`@("`\:6YP=70@='EP93TB
M8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)W:6YD;W<N8VQO<V4H
M*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-A;F-E;"(I(#\^(B`O/@H@("`@
M/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H*/"]F;W)M/@H*/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/@ID;V-U;65N="YP87-S<&AR87-E7V1I86QO
M9RYP87-S<&AR87-E+F9O8W5S*"D["CPO<V-R:7!T/@H\/W!H<"!E;F1I9CL@
M/SX*"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]T96UP;&%T97,O<VUI;64O:6UP;W)T7VME>2YI;F,`````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#4R-C(`,3`T,3<S-C(W-C8`,#(S,C`T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B`@
M("!S=VET8V@@*"1A8W1I;VY)1"D@>PH@("`@8V%S92`G:6UP;W)T7W!E<G-O
M;F%L7V-E<G1S)SH*("`@("`@("`D=&ET;&4@/2!?*"));7!O<G0@4&5R<V]N
M86P@4R]-24U%($-E<G1I9FEC871E<R(I.PH@("`@("`@(&)R96%K.PH*("`@
M(&-A<V4@)VEM<&]R=%]P=6)L:6-?:V5Y)SH*("`@("`@("`D=&ET;&4@/2!?
M*"));7!O<G0@4'5B;&EC(%,O34E-12!+97DB*3L*("`@("`@("`D:6YS97)T
M7W1E>'0@/2!?*"));G-E<G0@0V5R=&EF:6-A=&4@2&5R92(I.PH@("`@("`@
M(&)R96%K.PH@("`@?0H@("`@)&-E<G1I;7!O<G0@/2`H)&%C=&EO;DE$(#T]
M("=I;7!O<G1?<&5R<V]N86Q?8V5R=',G*3L*/SX*/&9O<FT@96YC='EP93TB
M;75L=&EP87)T+V9O<FTM9&%T82(@;65T:&]D/2)P;W-T(B!N86UE/2)I;7!O
M<G1?<VUI;65?:V5Y(B!A8W1I;VX](CP_<&AP(&5C:&\@)'-E;&954DP@/SXB
M/@H\/W!H<"!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S475I<FLH)V)R
M;VME;E]M=6QT:7!A<G1?9F]R;2<I*3H@/SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB;7-I95]F;W)M9&%T85]I<U]B<F]K96XB('9A;'5E/2(B("\^
M"CP_<&AP(&5N9&EF.R`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)R
M96QO860B('9A;'5E/2(\/W!H<"!E8VAO(%5T:6PZ.F=E=$9O<FU$871A*"=R
M96QO860G*3L@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C
M=&EO;DE$(B!V86QU93TB/#]P:'`@96-H;R`D=&%R9V5T(#\^(B`O/@H\/W!H
M<"!5=&EL.CIP9F]R;4EN<'5T*"D[(#\^"@H\9&EV(&-L87-S/2)H96%D97(B
M/@H\/W!H<"!I9B`H)&-E<G1I;7!O<G0I.B`_/@H@(#QU;#X*("`@(#QL:3X\
M/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEM<"<L("=S;6EM92UI;7!O<G0M<&5R
M<V]N86PM8V5R=',G*2`_/CPO;&D^"B`@/"]U;#X*/#]P:'`@96YD:68[(#\^
M"B`@/#]P:'`@96-H;R`D=&ET;&4@/SX\+W1D/@H\+V1I=CX*"CQT86)L92!W
M:61T:#TB,3`P)2(@8F]R9&5R/2(P(B!C96QL<&%D9&EN9STB,"(@8V5L;'-P
M86-I;F<](C`B/@H\/W!H<"!I9B`H:7-S970H)&EN<V5R=%]T97AT*2DZ(#\^
M"B`\='(^"B`@/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG;B(^"B`@(#QT86)L
M92!B;W)D97(](C`B(&-E;&QP861D:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`@
M("`\='(^"B`@("`@/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG;B(^/'-T<F]N
M9SX\/W!H<"!E8VAO("1I;G-E<G1?=&5X="`_/CH\+W-T<F]N9SX\+W1D/@H@
M("`@/"]T<CX*("`@(#QT<CX*("`@("`\=&0@8VQA<W,](FET96T@;&5F=$%L
M:6=N(CX*("`@("`@/'1E>'1A<F5A(&YA;64](FEM<&]R=%]K97DB(')O=W,]
M(C8B(&-O;',](C@P(B!C;&%S<STB9FEX960B/CPO=&5X=&%R96$^"B`@("`@
M/"]T9#X*("`@(#PO='(^"B`@(#PO=&%B;&4^"B`@/"]T9#X*(#PO='(^"@H@
M/'1R/@H@(#QT9"!C;&%S<STB:71E;2!L969T06QI9VXB/CQF;VYT(&-O;&]R
M/2)R960B/CQS=')O;F<^+2T\/W!H<"!E8VAO(%\H(D]2(BD@/SXM+3PO<W1R
M;VYG/CPO9F]N=#X\+W1D/@H@/"]T<CX*/#]P:'`@96YD:68[(#\^"@H@/'1R
M/@H@(#QT9"!C;&%S<STB:71E;2!L969T06QI9VXB/#]P:'`@:68@*"1C97)T
M:6UP;W)T*3H@/SX@8V]L<W!A;CTB,B(\/W!H<"!E;F1I9CL@/SX^"B`@(#QT
M86)L92!B;W)D97(](C`B(&-E;&QP861D:6YG/2(P(B!W:61T:#TB,3`P)2(^
M"B`@("`\='(^"B`@("`@/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG;B(^"B`@
M("`@(#QS=')O;F<^/#]P:'`@96-H;R!?*")5<&QO860B*2`_/CH\+W-T<F]N
M9SXF;F)S<#L\:6YP=70@;F%M93TB=7!L;V%D7VME>2(@='EP93TB9FEL92(@
M<VEZ93TB-#`B(&-L87-S/2)F:7AE9"(@+SX*("`@("`\+W1D/@H@("`@/"]T
M<CX*("`@/"]T86)L93X*("`\+W1D/@H@/"]T<CX*"CP_<&AP(&EF("@D8V5R
M=&EM<&]R="DZ(#\^"B`\='(^"B`@/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG
M;B(@8V]L<W!A;CTB,B(^"B`@(#QT86)L92!B;W)D97(](C`B(&-E;&QP861D
M:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`@("`\='(^"B`@("`@/'1D(&-L87-S
M/2)I=&5M(&QE9G1!;&EG;B(^"B`@("`@(#QS=')O;F<^/#]P:'`@96-H;R!?
M*")087-S=V]R9"(I(#\^.CPO<W1R;VYG/B9N8G-P.SQI;G!U="!N86UE/2)U
M<&QO861?:V5Y7W!A<W,B('1Y<&4](G!A<W-W;W)D(B!S:7IE/2(S,"(@8VQA
M<W,](F9I>&5D(B`O/@H@("`@(#PO=&0^"B`@("`\+W1R/@H@("`@/'1R/@H@
M("`@(#QT9"!C;&%S<STB:71E;2!L969T06QI9VXB/@H@("`@("`\<W1R;VYG
M/CP_<&AP(&5C:&\@7R@B4')I=F%T92!+97D@4&%S<W=O<F0B*2`_/CH\+W-T
M<F]N9SXF;F)S<#L\:6YP=70@;F%M93TB=7!L;V%D7VME>5]P:U]P87-S(B!T
M>7!E/2)P87-S=V]R9"(@<VEZ93TB,S`B(&-L87-S/2)F:7AE9"(@+SX*("`@
M("`\+W1D/@H@("`@/"]T<CX*("`@/"]T86)L93X*("`\+W1D/@H@/"]T<CX*
M/#]P:'`@96YD:68[(#\^"CPO=&%B;&4^"@H\:6YP=70@='EP93TB<W5B;6ET
M(B!N86UE/2)I;7!O<G0B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E
M8VAO(%\H(DEM<&]R="!+97DB*2`_/B(@+SX*/&EN<'5T('1Y<&4](G-U8FUI
M="(@;F%M93TB:6UP;W)T(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)W:6YD
M;W<N8VQO<V4H*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-A;F-E;"(I(#\^
M(B`O/@H*/"]F;W)M/@H\+V)O9'D^"CPO:'1M;#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]S
M;6EM92]N;W1A8W1I=F4N:6YC````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,38R-``Q,#0Q-S,V,C<V-@`P,C,P,30`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*("`D=7-E7W-M:6UE7VQO8VME
M9"`]("1P<F5F<RT^:7-,;V-K960H)W5S95]S;6EM92<I.PH@(&EF("@D=7-E
M7W-M:6UE7VQO8VME9"DZ(#\^"CQS=')O;F<^/#]P:'`@96-H;R!?*")3+TU)
M344@<W5P<&]R="!I<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB*2`_/CPO
M<W1R;VYG/@H\/W!H<"!E;'-E.B`_/@H\:6YP=70@:60](G5S95]S;6EM92(@
M='EP93TB8VAE8VMB;W@B(&YA;64](G5S95]S;6EM92(\/W!H<"!E8VAO("@D
M<')E9G,M/F=E=%9A;'5E*"=U<V5?<VUI;64G*2D@/R`G(&-H96-K960](F-H
M96-K960B)R`Z("<G(#\^("\^(#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=U
M<V5?<VUI;64G+"!?*")%;F%B;&4@4R]-24U%(&9U;F-T:6]N86QI='D_(BDI
M(#\^)FYB<W`[/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G+"`G<VUI;64M
M;W9E<G9I97<G*2`_/CQB<B`O/@H\/W!H<"!E;F1I9CL@/SX*/"]D:78^"@H\
M8G(@8VQA<W,](G-P86-E<B(@+SX*/&1I=B!C;&%S<STB;F]W<F%P(CX*/#]P
M:'`@:68@*"$D=7-E7W-M:6UE7VQO8VME9"DZ(#\^"B`@/&EN<'5T('1Y<&4]
M(G-U8FUI="(@;F%M93TB<V%V92(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB
M9&]C=6UE;G0N<')E9G,N86-T:6]N240N=F%L=64])W-A=F5?;W!T:6]N<R<[
M(')E='5R;B!T<G5E.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B4V%V92!/<'1I
M;VYS(BD@/SXB("\^)FYB<W`["CP_<&AP(&5N9&EF.R`_/@H@(#QI;G!U="!T
M>7!E/2)B=71T;VXB(&YA;64](F)A8VLB(&-L87-S/2)B=71T;VXB(&]N8VQI
M8VL](F1O8W5M96YT+FQO8V%T:6]N+FAR968])SP_<&AP(&5C:&\@24U0.CIP
M<F5F<U523"AT<G5E*2`_/B<B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E='5R
M;B!T;R!/<'1I;VYS(BD@/SXB("\^"CPO9&EV/@H\+V9O<FT^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L
M871E<R]S879E:6UA9V4O````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,C$Q-30`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O=&5M<&QA=&5S+W-A=F5I;6%G92]S879E:6UA9V4N:6YC
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#<W`#$P-#$W,S8R-S8V`#`R,S8Q
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M9F]R;2!M971H;V0](G!O<W0B(&YA;64](G-A=F5?:6UA9V5?9&EA;&]G(B!A
M8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S879E
M:6UA9V4N<&AP)RD@/SXB/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A
M8W1I;VY)1"(@=F%L=64](G-A=F5?:6UA9V4B("\^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](FED(B!V86QU93TB/#]P:'`@96-H;R`D:60@/SXB("\^
M"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEN9&5X(B!V86QU93TB/#]P
M:'`@96-H;R`D:6YD97@@/SXB("\^"@H*/&@Q(&-L87-S/2)H96%D97(B/@H@
M(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G;6EM92]I;6%G92YP;F<G+"!?*"))
M;6%G92(I+"!N=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`_/@H@(#P_<&AP(&5C:&\@7R@B4V5L96-T('1H92!G86QL97)Y('1O('-A
M=F4@=&AE(&EM86=E(&EN+B(I(#\^"CPO:#$^"CQP(&-L87-S/2)I=&5M(CX*
M("`@/'-E;&5C="!I9#TB9V%L;&5R>2(@;F%M93TB9V%L;&5R>2(^"CP_<&AP
M(&5C:&\@)&=A;&QE<GEL:7-T(#\^"B`@(#PO<V5L96-T/@H\+W`^"@H\9&EV
M(&-L87-S/2)N;W=R87`B/@H@(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64]
M(G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M4W5B;6ET(BD@/SXB("\^)FYB<W`["B`@/&EN<'5T('1Y<&4](F)U='1O;B(@
M8VQA<W,](F)U='1O;B(@;VYC;&EC:STB=VEN9&]W+F-L;W-E*"D[(B!V86QU
M93TB/#]P:'`@96-H;R!?*")#86YC96PB*2`_/B(@+SX*/"]D:78^"@H\+V9O
M<FT^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+W-T871I;VYE<GDO````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8V
M`#`R,30Q-``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O
M<W1A=&EO;F5R>2]P<F5F<RYI;F,`````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#4R,#4`,3`T,3<S-C(W-C8`,#(S,C(U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M
M93TB<')E9G,B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"@I
M(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQI;G!U="!T>7!E
M/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB=7!D871E(B`O/@H\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)G<F]U<"(@=F%L=64](CP_<&AP
M(&5C:&\@)&=R;W5P(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)A<'`B('9A;'5E/2(\/W!H<"!E8VAO("1A<'`@/SXB("\^"@H\9&EV(&-L
M87-S/2)H96%D97(B/@H@(#P_<&AP(%!R969S7U5).CIG96YE<F%T94YA=FEG
M871I;VY#96QL*"=C;VUP;W-E)RD@/SX*("`\/W!H<"!E8VAO(%\H(E-T871I
M;VYE<GDB*2`_/@H\+V1I=CX*"CQP(&-L87-S/2)I=&5M(CX*/'-E;&5C="!N
M86UE/2)S=&%T:6]N97)Y(B!O;F-H86YG93TB9&]C=6UE;G0N<')E9G,N961I
M="YC;&EC:R@I(CX*("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B
M0W)E871E(&YE=R!S=&%T:6]N97)Y(BD@/SX\+V]P=&EO;CX*/#]P:'`@9F]R
M96%C:"`H)'-T871I;VYE<GE?;&ES="!A<R`D<W1A=&EO;F5R>5]I9"`]/B`D
M<W1A=&EO;F5R>5]C:&]I8V4I.B`_/@H@(#QO<'1I;VX@=F%L=64](CP_<&AP
M(&5C:&\@)'-T871I;VYE<GE?:60@/SXB/#]P:'`@:68@*"1S96QE8W1E9"`]
M/3T@)'-T871I;VYE<GE?:60I(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B
M)R`_/CX\/W!H<"!E8VAO("1S=&%T:6]N97)Y7V-H;VEC95LG;B==("X@)R`G
M("X@*"1S=&%T:6]N97)Y7V-H;VEC95LG="==(#T]("=H=&UL)R`_(%\H(BA(
M5$U,*2(I(#H@7R@B*%!L86EN(%1E>'0I(BDI(#\^/"]O<'1I;VX^"CP_<&AP
M(&5N9&9O<F5A8V@[(#\^"CPO<V5L96-T/@H\:6YP=70@='EP93TB<W5B;6ET
M(B!N86UE/2)E9&ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H
M;R!?*")%9&ET(BD@/SXB("\^"CQB<B`O/CQB<B`O/@H*/#]P:'`@:68@*"%I
M<U]N=6QL*"1S=&%T:6]N97)Y*2DZ(&EF("@A:7-?;G5L;"@D:60I*3H@/SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:60B('9A;'5E/2(\/W!H<"!E
M8VAO("1I9"`_/B(@+SX*/#]P:'`@96YD:68[(#\^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](FQA<W1?='EP92(@=F%L=64](CP_<&AP(&5C:&\@)'-T
M871I;VYE<GE;)W0G72`_/B(@+SX*/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH
M)VYA;64G+"!?*")3=&%T:6]N97)Y(&YA;64Z(BDI(#\^/&)R("\^"CQI;G!U
M="!T>7!E/2)T97AT(B!N86UE/2)N86UE(B!I9#TB;F%M92(@=F%L=64](CP_
M<&AP(&5C:&\@)'-T871I;VYE<GE;)VXG72`_/B(@+SX\8G(@+SX*/#]P:'`@
M96-H;R!(;W)D93HZ;&%B96PH)W1Y<&4G+"!?*")3=&%T:6]N97)Y('1Y<&4Z
M(BDI(#\^/&)R("\^"CQS96QE8W0@;F%M93TB='EP92(@:60](G1Y<&4B(&]N
M8VAA;F=E/2)D;V-U;65N="YP<F5F<RYS=6)M:70H*2(^"B`@/&]P=&EO;B!V
M86QU93TB<&QA:6XB/#]P:'`@:68@*"1S=&%T:6]N97)Y6R=T)UT@/3T@)W!L
M86EN)RD@96-H;R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^/CP_<&AP(&5C
M:&\@7R@B5&5X="(I(#\^/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB:'1M
M;"(\/W!H<"!I9B`H)'-T871I;VYE<GE;)W0G72`]/2`G:'1M;"<I(&5C:&\@
M)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CX\/W!H<"!E8VAO(%\H(DA434PB
M*2`_/CPO;W!T:6]N/@H\+W-E;&5C=#X\8G(@+SX*/#]P:'`@96-H;R!(;W)D
M93HZ;&%B96PH)V-O;G1E;G0G+"!?*")3=&%T:6]N97)Y.B(I*2`_/CQB<B`O
M/@H\=&5X=&%R96$@;F%M93TB8V]N=&5N="(@:60](F-O;G1E;G0B(')O=W,]
M(C$U(B!C;VQS/2(X,"(@8VQA<W,](F9I>&5D(CX\/W!H<"!E8VAO("1S=&%T
M:6]N97)Y6R=C)UT@/SX\+W1E>'1A<F5A/CQB<B`O/@H\96T^/#]P:'`@96-H
M;R!?*")9;W4@8V%N('5S92!T:&4@9F]L;&]W:6YG('!L86-E:&]L9&5R<R!I
M;B!T:&4@<W1A=&EO;F5R>2!T97AT.B`E8R!F;W(@=&AE(&-U<G)E;G0@;65S
M<V%G92!C;VYT96YT.R`E<R!F;W(@=&AE('-I9VYA='5R92XB*2`_/CPO96T^
M"CP_<&AP(&5N9&EF.R`_/@H\+W`^"@H\/W!H<"!I9B`H(6ES7VYU;&PH)'-T
M871I;VYE<GDI*3H@/SX*/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB<V%V
M92(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4V%V92!3
M=&%T:6]N97)Y(BD@/SXB("\^)FYB<W`[)FYB<W`["CP_<&AP(&EF("@A:7-?
M;G5L;"@D:60I*3H@/SX*/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB9&5L
M971E(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")$96QE
M=&4@4W1A=&EO;F5R>2(I(#\^(B`O/B9N8G-P.R9N8G-P.PH\/W!H<"!E;F1I
M9CL@96YD:68[(#\^"CQI;G!U="!T>7!E/2)B=71T;VXB(&YA;64](F)A8VLB
M(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F1O8W5M96YT+FQO8V%T:6]N+FAR
M968])SP_<&AP(&5C:&\@571I;#HZ861D4&%R86UE=&5R*"1C;VUP;W-E7W5R
M;"P@)V=R;W5P)RP@)V-O;7!O<V4G*2`_/B<B('9A;'5E/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H7R@B4F5T=7)N('1O(%PB365S<V%G92!#;VUP
M;W-I=&EO;EPB(BDL($5.5%]#3TU0050L($Y,4SHZ9V5T0VAA<G-E="@I*2`_
M/B(@+SX*"CPO9F]R;3X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]M86EL8F]X+P``````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V
M-@`P,C`V-#8`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S
M+VUA:6QB;W@O;65S<V%G95]H96%D97)S+FEN8P``````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`W,38T`#$P-#$W,S8R-S8V`#`R-#0V-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`II9B`H(6ES<V5T*"1H96%D
M97)S7VEN8U]C;W5N="DI('L*("`@("1H96%D97)S7VEN8U]C;W5N="`](#`[
M"GT@96QS92!["B`@("`D:&5A9&5R<U]I;F-?8V]U;G0K*SL*?0HD<V]R=$EM
M9R`]("@D<V]R=&1I<BD@/R`G>F$N<&YG)R`Z("=A>BYP;F<G.PHD<V]R=%1E
M>'0@/2`H)'-O<G1D:7(I(#\@)UPO)R`Z("<O7%PG.PHD:&5A9&5R<R`](&%R
M<F%Y*`H@("`@4T]25$%24DE604P@/3X@87)R87DH"B`@("`@("`@)W-T97AT
M)R`]/B!?*")3;W)T(&)Y($%R<FEV86PB*2P*("`@("`@("`G=&5X="<@/3X@
M7R@B(R(I+`H@("`@("`@("=W:61T:"<@/3X@)S0E)PH@("`@*2P*("`@(%-/
M4E1$051%(#T^(&%R<F%Y*`H@("`@("`@("=S=&5X="<@/3X@7R@B4V]R="!B
M>2!$871E(BDL"B`@("`@("`@)W1E>'0G(#T^(%\H(D1A=%]E(BDL"B`@("`@
M("`@)W=I9'1H)R`]/B`G,3`E)PH@("`@*2P*("`@(%-/4E143R`]/B!A<G)A
M>2@*("`@("`@("`G<W1E>'0G(#T^(%\H(E-O<G0@8GD@5&\@061D<F5S<R(I
M+`H@("`@("`@("=T97AT)R`]/B!?*")4;R(I+`H@("`@("`@("=W:61T:"<@
M/3X@)S(P)2<*("`@("DL"B`@("!33U)41E)/32`]/B!A<G)A>2@*("`@("`@
M("`G<W1E>'0G(#T^(%\H(E-O<G0@8GD@1G)O;2!!9&1R97-S(BDL"B`@("`@
M("`@)W1E>'0G(#T^(%\H(D9R;U]M(BDL"B`@("`@("`@)W=I9'1H)R`]/B`G
M,C`E)PH@("`@*2P*("`@(%-/4E142%)%040@/3X@87)R87DH"B`@("`@("`@
M)W-T97AT)R`]/B!?*")3;W)T(&)Y(%1H<F5A9"(I+`H@("`@("`@("=T97AT
M)R`]/B!?*")?5&AR96%D(BDL"B`@("`@("`@)W=I9'1H)R`]/B`G-3(E)PH@
M("`@*2P*("`@(%-/4E1354)*14-4(#T^(&%R<F%Y*`H@("`@("`@("=S=&5X
M="<@/3X@7R@B4V]R="!B>2!3=6)J96-T(BDL"B`@("`@("`@)W1E>'0G(#T^
M(%\H(E-U8E]J96-T(BDL"B`@("`@("`@)W=I9'1H)R`]/B`G-3(E)PH@("`@
M*2P*("`@(%-/4E1325I%(#T^(&%R<F%Y*`H@("`@("`@("=S=&5X="<@/3X@
M7R@B4V]R="!B>2!-97-S86=E(%-I>F4B*2P*("`@("`@("`G=&5X="<@/3X@
M7R@B4VE?>F4B*2P*("`@("`@("`G=VED=&@G(#T^("<V)2<*("`@("D**3L*
M"B\J($EF('1H:7,@:7,@=&AE($1R869T<R!O<B!396YT+4UA:6P@1F]L9&5R
M+"!S;W)T(&)Y(%1O(&EN<W1E860@;V8*("H@1G)O;2X@*B\*:68@*"1D<F%F
M='-?<VU?9F]L9&5R*2!["B`@("!U;G-E="@D:&5A9&5R<UM33U)41E)/35TI
M.PI](&5L<V4@>PH@("`@=6YS970H)&AE861E<G-;4T]25%1/72D["GT*"B\J
M($1E=&5R;6EN92!W:&EC:"!O9B!3=6)J96-T+U1H<F5A9"!T;R!E;7!H87-I
M>F4N("HO"FEF("@D<V5A<F-H7VUB;W@I('L*("`@('5N<V5T*"1H96%D97)S
M6U-/4E142%)%041=*3L*?2!E;'-E('L*("`@("1E>'1R82`](%-/4E142%)%
M040["B`@("`D<W1A;F1A<F0@/2!33U)44U5"2D5#5#L*("`@(&EF("@D=&AR
M96%D7W-O<G0I('L*("`@("`@("`D97AT<F$@/2!33U)44U5"2D5#5#L*("`@
M("`@("`D<W1A;F1A<F0@/2!33U)45$A214%$.PH@("`@?0H@("`@)&AE861E
M<G-;)'-T86YD87)D75LG97AT<F$G72`]("<F;F)S<#L\<W!A;B!S='EL93TB
M9F]N="US:7IE.B`Q,'!X.R(^6R<@+B!(;W)D93HZ=VED9V5T*%5T:6PZ.F%D
M9%!A<F%M971E<B@D;6%I;&)O>%]U<FPL(&%R<F%Y*"=S;W)T8GDG(#T^("1E
M>'1R82P@)V%C=&EO;DE$)R`]/B`G8VAA;F=E7W-O<G0G*2DL("1H96%D97)S
M6R1E>'1R85U;)W-T97AT)UTL("=W:61G970B('-T>6QE/2)F;VYT+7-I>F4Z
M(#$P<'@[(&9O;G0M=V5I9VAT.B!N;W)M86P[)RP@;G5L;"P@)VEF("AW:6YD
M;W<N979E;G0I('=I;F1O=RYE=F5N="YC86YC96Q"=6)B;&4@/2!T<G5E.R!E
M;'-E(&EF("AE=F5N="D@979E;G0N<W1O<%!R;W!A9V%T:6]N*"D[)RP@)&AE
M861E<G-;)&5X=')A75LG=&5X="==*2`N("==/"]S<&%N/B<["B`@("!U;G-E
M="@D:&5A9&5R<ULD97AT<F%=*3L*?0H_/@H\='(@8VQA<W,](F-O;G1R;VPB
M/CQT9"!C;VQS<&%N/2(V(CX*/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)M
M97-S86=E<R(@86-T:6]N/2(\/W!H<"!E8VAO("1M86EL8F]X7W5R;"`_/B(^
M"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\=&%B;&4@8VQA<W,](FUE
M<W-A9V5,:7-T(B!C96QL<W!A8VEN9STB,2(^"CQT<B!C;&%S<STB:71E;2(^
M"CP_<&AP(&EF("@A)&AE861E<G-?:6YC7V-O=6YT*3H@/SX*("`\=&@@;VYC
M;&EC:STB9&]C=6UE;G0N;65S<V%G97,N8VAE8VM!;&PN8VAE8VME9"`]("%D
M;V-U;65N="YM97-S86=E<RYC:&5C:T%L;"YC:&5C:V5D.R!M86ME4V5L96-T
M:6]N*"TQ*3LB('=I9'1H/2(X)2(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C
M;&%S<STB8VAE8VMB;W@B(&YA;64](F-H96-K06QL(B!O;F-L:6-K/2)M86ME
M4V5L96-T:6]N*"TQ*3L@:68@*'=I;F1O=RYE=F5N="D@=VEN9&]W+F5V96YT
M+F-A;F-E;$)U8F)L92`]('1R=64[(&5L<V4@:68@*&5V96YT*2!E=F5N="YS
M=&]P4')O<&%G871I;VXH*3LB(#P_<&AP(&5C:&\@2&]R9&4Z.F=E=$%C8V5S
M<TME>4%N9%1I=&QE*%\H(D-H96-K(%]!;&PO3F]N92(I*2`_/B`O/CPO=&@^
M"CP_<&AP(&5L<V4Z(#\^"B`@/'1H/B9N8G-P.SPO=&@^"CP_<&AP(&5N9&EF
M.R`_/@H*/#]P:'`@9F]R96%C:"`H)&AE861E<G,@87,@)&ME>2`]/B`D=F%L
M*3H@/SX*("`\=&@@8VQA<W,](CP_<&AP(&5C:&\@*"1S;W)T8GD@/3T@)&ME
M>2D@/R`G<V5L96-T960G(#H@)VET96TG(#\^(B!W:61T:#TB/#]P:'`@96-H
M;R`D=F%L6R=W:61T:"==(#\^(B`\/W!H<"!I9B`H(21S;W)T;&EM:70I.B`_
M/B!O;F-L:6-K/2)D;V-U;65N="YL;V-A=&EO;BYH<F5F/2<\/W!H<"!E8VAO
M(&%D9'-L87-H97,H571I;#HZ861D4&%R86UE=&5R*"@D<V]R=&)Y(#T]("1K
M97DI(#\@)'-O<G1?=7)L(#H@)&UA:6QB;WA?=7)L+"!A<G)A>2@G<V]R=&)Y
M)R`]/B`D:V5Y+"`G86-T:6]N240G(#T^("=C:&%N9V5?<V]R="<I*2D@/SXG
M.R(\/W!H<"!E;F1I9CL@/SX^"CP_<&AP(&EF("@D<V]R=&QI;6ET*3H@/SX*
M("`\/W!H<"!E8VAO($AO<F1E.CIS=')I<$%C8V5S<TME>2@D=F%L6R=T97AT
M)UTI(#\^"CP_<&AP(&5L<V4Z(#\^"B`@/#]P:'`@:68@*"1S;W)T8GD@/3T@
M)&ME>2DZ(#\^"B`@("`\/W!H<"!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D
M9%!A<F%M971E<B@D<V]R=%]U<FPL(&%R<F%Y*"=S;W)T8GDG(#T^("1K97DL
M("=A8W1I;VY)1"<@/3X@)V-H86YG95]S;W)T)RDI+"`D=F%L6R=S=&5X="==
M+"!N=6QL+"!N=6QL+"!N=6QL+"`D=F%L6R=S=&5X="==*2`N($AO<F1E.CII
M;6<H)'-O<G1);6<L("1S;W)T5&5X="P@)R<L("1R96=I<W1R>2T^9V5T26UA
M9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H@(#P_<&AP(&5N9&EF.R`_/@H@(#P_
M<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="A5=&EL.CIA9&1087)A;65T97(H*"1S
M;W)T8GD@/3T@)&ME>2D@/R`D<V]R=%]U<FP@.B`D;6%I;&)O>%]U<FPL(&%R
M<F%Y*"=S;W)T8GDG(#T^("1K97DL("=A8W1I;VY)1"<@/3X@)V-H86YG95]S
M;W)T)RDI+"`D=F%L6R=S=&5X="==+"`G=VED9V5T)RP@;G5L;"P@;G5L;"P@
M)'9A;%LG=&5X="==*2`_/@H\/W!H<"!I9B`H:7-S970H)'9A;%LG97AT<F$G
M72DI(&5C:&\@)'9A;%LG97AT<F$G73L@/SX*/#]P:'`@96YD:68[(#\^"B`@
M/"]T:#X*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]T<CX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O=&5M<&QA=&5S+VUA:6QB;W@O96UP='E?;6%I;&)O>"YI;F,`
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<T`#$P-#$W,S8R-S8V`#`R-#(Q,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\='(^
M"B`\=&0@8VQA<W,](G1E>'0B(&-O;'-P86X](C8B/@H@("9N8G-P.SQE;3X\
M/W!H<"!E8VAO(%\H(E1H97)E(&%R92!N;R!M97-S86=E<R!I;B!T:&ES(&UA
M:6QB;W@N(BD@/SX\+V5M/@H@/"]T9#X*/"]T<CX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E
M;7!L871E<R]M86EL8F]X+V%L97)T+FEN8P``````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#(W-0`Q,#0Q-S,V,C<V-@`P,C(T-3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/'-C<FEP="!T>7!E/2)T
M97AT+VIA=F%S8W)I<'0B/@H\(2TM"F%L97)T*"<\/W!H<"!E8VAO(&%D9'-L
M87-H97,H*"1N97=M<V=S(#T](#$I(#\@7R@B66]U(&AA=F4@,2!N97<@;65S
M<V%G92XB*2`Z('-P<FEN=&8H7R@B66]U(&AA=F4@)7,@;F5W(&UE<W-A9V5S
M+B(I+"`D;F5W;7-G<RDI(#\^)RD["B\O("TM/@H\+W-C<FEP=#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O;6%I
M;&)O>"]M86EL8F]X+FAT;6P`````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W
M-C4`,3`T,3<S-C(W-C8`,#(S,3<U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QL;V]P.FUE<W-A9V5S/@H@/'1R(&ED/2)R
M;W<\=&%G.FUE<W-A9V5S+G5I9"`O/B(@8VQA<W,](CQT86<Z;65S<V%G97,N
M8F<@+SXB/@H@(#QT9#X*("`@/'1A9SIO=F5R9FQO=U]B96=I;B`O/CQI;G!U
M="!I9#TB8VAE8VL\=&%G.FUE<W-A9V5S+G5I9"`O/B(@='EP93TB8VAE8VMB
M;W@B(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB:6YD:6-E<UM=(B!O;F-L:6-K
M/2)S96QE8W12;W<H/'1A9SIM97-S86=E<RYU:60@+SXI.R(@=F%L=64](CQT
M86<Z;65S<V%G97,N=6ED("\^/&EF.G-E87)C:%]M8F]X/CQT86<Z:61X7W-E
M<&%R871O<B`O/CQT86<Z;65S<V%G97,N;6)O>"`O/CPO:68Z<V5A<F-H7VUB
M;W@^(B`O/CQI9CIM97-S86=E<RYS=&%T=7,^/&QA8F5L(&9O<CTB8VAE8VL\
M=&%G.FUE<W-A9V5S+G5I9"`O/B(^/'1A9SIM97-S86=E<RYS=&%T=7,@+SX\
M+VQA8F5L/CPO:68Z;65S<V%G97,N<W1A='5S/CQT86<Z;W9E<F9L;W=?96YD
M("\^"B`@/"]T9#X*("`\=&0\:68Z;65S<V%G97,N8V]L;W(^('-T>6QE/2)B
M86-K9W)O=6YD+6-O;&]R.CQT86<Z;65S<V%G97,N8V]L;W(@+SX[(CPO:68Z
M;65S<V%G97,N8V]L;W(^/@H@("`\=&%G.F]V97)F;&]W7V)E9VEN("\^/'1A
M9SIM97-S86=E<RYN=6UB97(@+SX\=&%G.F]V97)F;&]W7V5N9"`O/@H@(#PO
M=&0^"B`@/'1D/CQT86<Z;W9E<F9L;W=?8F5G:6X@+SX\=&%G.FUE<W-A9V5S
M+F1A=&4@+SXF;F)S<#L\=&%G.F]V97)F;&]W7V5N9"`O/CPO=&0^"B`@/'1D
M/CQT86<Z;W9E<F9L;W=?8F5G:6X@+SX\=&%G.FUE<W-A9V5S+F9R;VT@+SXF
M;F)S<#L\=&%G.F]V97)F;&]W7V5N9"`O/CPO=&0^"B`@/'1D/CQT86<Z;W9E
M<F9L;W=?8F5G:6X@+SX\=&%G.FUE<W-A9V5S+G-U8FIE8W0@+SX\=&%G.F]V
M97)F;&]W7V5N9"`O/CPO=&0^"B`@/'1D(&%L:6=N/2)R:6=H="(^/'1A9SIO
M=F5R9FQO=U]B96=I;B`O/CQT86<Z;65S<V%G97,N<VEZ92`O/CQT86<Z;W9E
M<F9L;W=?96YD("\^/"]T9#X*(#PO='(^"CPO;&]O<#IM97-S86=E<SX*````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T
M97,O;6%I;&)O>"]N879B87(N:6YC````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#<T-#(`,3`T,3<S-C(W-C8`,#(R-C$V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QT<B!C;&%S<STB8V]N=')O;"(^
M"B`\=&0@8V]L<W!A;CTB-B(^"@H\=&%B;&4@=VED=&@](C$P,"4B/@H@/'1R
M/@H@(#QT9"!C;&%S<STB;&5F=$%L:6=N(B!N;W=R87`](FYO=W)A<"(@=VED
M=&@](C(P)2(^"B`@(#QF;W)M(&YA;64](G-E;&5C=#P_<&AP(&5C:&\@)&YA
M=F9O<FT@/SXB(&%C=&EO;CTB:F%V87-C<FEP=#IV;VED*#`I(B!O;G-U8FUI
M=#TB<F5T=7)N(&9A;'-E(CX*("`@/'-E;&5C="!N86UE/2)F:6QT97(B(&]N
M8VAA;F=E/2)M86ME4V5L96-T:6]N*#P_<&AP(&5C:&\@)&YA=F9O<FT@/SXI
M.R(^"B`@("`\;W!T:6]N('9A;'5E/2(B('-E;&5C=&5D/2)S96QE8W1E9"(^
M/#]P:'`@96-H;R!?*")396QE8W0B*2`_/CH\+V]P=&EO;CX*("`@(#QO<'1I
M;VX@=F%L=64](B$\/W!H<"!E8VAO($E-4%]!3$P@/SXB/CP_<&AP(&5C:&\@
M7R@B06QL(BD@/SX\+V]P=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](CP_<&AP
M(&5C:&\@24U07T%,3"`_/B(^/#]P:'`@96-H;R!?*").;VYE(BD@/SX\+V]P
M=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](BL\/W!H<"!E8VAO($E-4%]!3$P@
M/SXB/CP_<&AP(&5C:&\@7R@B26YV97)T(BD@/SX\+V]P=&EO;CX*/#]P:'`@
M:68@*"%S=')S='(H)&EM<%LG<')O=&]C;VPG72P@)W!O<#,G*2DZ(#\^"B`@
M("`\;W!T:6]N('9A;'5E/2(A/#]P:'`@96-H;R!)35!?54Y3145.(#\^(CX\
M/W!H<"!E8VAO(%\H(E-E96XB*2`_/CPO;W!T:6]N/@H@("`@/&]P=&EO;B!V
M86QU93TB/#]P:'`@96-H;R!)35!?54Y3145.(#\^(CX\/W!H<"!E8VAO(%\H
M(E5N<V5E;B(I(#\^/"]O<'1I;VX^"B`@("`\;W!T:6]N('9A;'5E/2(\/W!H
M<"!E8VAO($E-4%]&3$%'1T5$(#\^(CX\/W!H<"!E8VAO(%\H(DEM<&]R=&%N
M="(I(#\^/"]O<'1I;VX^"B`@("`\;W!T:6]N('9A;'5E/2(A/#]P:'`@96-H
M;R!)35!?1DQ!1T=%1"`_/B(^/#]P:'`@96-H;R!?*").;W0@26UP;W)T86YT
M(BD@/SX\+V]P=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@
M24U07T%.4U=%4D5$(#\^(CX\/W!H<"!E8VAO(%\H(D%N<W=E<F5D(BD@/SX\
M+V]P=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](B$\/W!H<"!E8VAO($E-4%]!
M3E-715)%1"`_/B(^/#]P:'`@96-H;R!?*")5;F%N<W=E<F5D(BD@/SX\+V]P
M=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@24U07T1%3$54
M140@/SXB/CP_<&AP(&5C:&\@7R@B1&5L971E9"(I(#\^/"]O<'1I;VX^"B`@
M("`\;W!T:6]N('9A;'5E/2(A/#]P:'`@96-H;R!)35!?1$5,151%1"`_/B(^
M/#]P:'`@96-H;R!?*").;W0@1&5L971E9"(I(#\^/"]O<'1I;VX^"B`@("`\
M;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO($E-4%]$4D%&5"`_/B(^/#]P:'`@
M96-H;R!?*")$<F%F="(I(#\^/"]O<'1I;VX^"B`@("`\;W!T:6]N('9A;'5E
M/2(A/#]P:'`@96-H;R!)35!?1%)!1E0@/SXB/CP_<&AP(&5C:&\@7R@B3F]T
M($1R869T(BD@/SX\+V]P=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](CP_<&AP
M(&5C:&\@24U07U!%4E-/3D%,(#\^(CX\/W!H<"!E8VAO(%\H(E!E<G-O;F%L
M(BD@/SX\+V]P=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](B$\/W!H<"!E8VAO
M($E-4%]015)33TY!3"`_/B(^/#]P:'`@96-H;R!?*").;W0@4&5R<V]N86PB
M*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1I9CL@/SX*("`@/"]S96QE8W0^"CP_
M<&AP(&EF("@D:6UP6R=B87-E7W!R;W1O8V]L)UT@(3T@)W!O<#,G*3H@/SX*
M("`@/'-E;&5C="!N86UE/2)F;&%G(B!O;F-H86YG93TB9FQA9TUE<W-A9V5S
M*#P_<&AP(&5C:&\@)&YA=F9O<FT@/SXI.R(^"B`@("`\;W!T:6]N('9A;'5E
M/2(B('-E;&5C=&5D/2)S96QE8W1E9"(^/#]P:'`@96-H;R!?*")-87)K(&%S
M.B(I(#\^/"]O<'1I;VX^"B`@("`\;W!T:6]N('9A;'5E/2)3965N(CX\/W!H
M<"!E8VAO(%\H(E-E96XB*2`_/CPO;W!T:6]N/@H@("`@/&]P=&EO;B!V86QU
M93TB,%-E96XB/CP_<&AP(&5C:&\@7R@B56YS965N(BD@/SX\+V]P=&EO;CX*
M("`@(#QO<'1I;VX@=F%L=64](D9L86=G960B/CP_<&AP(&5C:&\@7R@B26UP
M;W)T86YT(BD@/SX\+V]P=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](C!&;&%G
M9V5D(CX\/W!H<"!E8VAO(%\H(DYO="!);7!O<G1A;G0B*2`_/CPO;W!T:6]N
M/@H@("`@/&]P=&EO;B!V86QU93TB06YS=V5R960B/CP_<&AP(&5C:&\@7R@B
M06YS=V5R960B*2`_/CPO;W!T:6]N/@H@("`@/&]P=&EO;B!V86QU93TB,$%N
M<W=E<F5D(CX\/W!H<"!E8VAO(%\H(E5N86YS=V5R960B*2`_/CPO;W!T:6]N
M/@H\/W!H<"!I9B`H(21U<V5?=')A<V@@)B8@(21U<V5?=G1R87-H*3H@/SX*
M("`@(#QO<'1I;VX@=F%L=64](D1E;&5T960B/CP_<&AP(&5C:&\@7R@B1&5L
M971E9"(I(#\^/"]O<'1I;VX^"B`@("`\;W!T:6]N('9A;'5E/2(P1&5L971E
M9"(^/#]P:'`@96-H;R!?*").;W0@1&5L971E9"(I(#\^/"]O<'1I;VX^"CP_
M<&AP(&5N9&EF.R`_/@H@("`@/&]P=&EO;B!V86QU93TB1')A9G0B/CP_<&AP
M(&5C:&\@7R@B1')A9G0B*2`_/CPO;W!T:6]N/@H@("`@/&]P=&EO;B!V86QU
M93TB,$1R869T(CX\/W!H<"!E8VAO(%\H(DYO="!$<F%F="(I(#\^/"]O<'1I
M;VX^"B`@(#PO<V5L96-T/@H\/W!H<"!E;F1I9CL@/SX*("`@/"]F;W)M/@H@
M(#PO=&0^"B`@/'1D(&-L87-S/2)L969T06QI9VXB(&YO=W)A<#TB;F]W<F%P
M(B!W:61T:#TB,S`E(CX*/#]P:'`@:68@*"1C;VYF6R=U<V5R)UU;)V%L;&]W
M7V9O;&1E<G,G72DZ(#\^"B`@(#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB
M8V]P>6UO=F4\/W!H<"!E8VAO("1N879F;W)M(#\^(B!A8W1I;VX](CP_<&AP
M(&5C:&\@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=M86EL8F]X+G!H<"<I(#\^
M(CX*("`@/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*"<C)RP@7R@B36]V92!T
M;R!F;VQD97(B*2P@)W=I9&=E="<L("<G+"`B5')A;G-F97(H)VUO=F5?;65S
M<V%G97,G+"`D;F%V9F]R;2D[(')E='5R;B!F86QS93LB+"!?*")-;W9E(BDL
M('1R=64I(#\^('P*("`@/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*"<C)RP@
M7R@B0V]P>2!T;R!F;VQD97(B*2P@)W=I9&=E="<L("<G+"`B5')A;G-F97(H
M)V-O<'E?;65S<V%G97,G+"`D;F%V9F]R;2D[(')E='5R;B!F86QS93LB+"!?
M*")#;W!Y(BDL('1R=64I(#\^"B`@(#QS96QE8W0@;F%M93TB=&%R9V5T36%I
M;&)O>"(@;VYC:&%N9V4](G5P9&%T949O;&1E<G,H/#]P:'`@96-H;R`D;F%V
M9F]R;2`_/BD[(CX*("`@(#P_<&AP(&5C:&\@)&9O;&1E<E]O<'1I;VYS(#\^
M"B`@(#PO<V5L96-T/@H@("`\+V9O<FT^"CP_<&AP(&5N9&EF.R`_/@H@(#PO
M=&0^"@H@(#QT9"!W:61T:#TB-3`E(B!C;&%S<STB<FEG:'1!;&EG;B(@;F]W
M<F%P/2)N;W=R87`B/@H\/W!H<"!I9B`H)'!A9V5/8BT^<&%G96-O=6YT(#X@
M,2DZ(#\^"B`@(#QF;W)M(&UE=&AO9#TB9V5T(B!N86UE/2)P86=E;F%V/#]P
M:'`@96-H;R`D;F%V9F]R;2`_/B(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G;6%I;&)O>"YP:'`G*2`_/B(^"B`@(#P_<&AP
M(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H@("`\/W!H<"!E8VAO("1P86=E<U]F
M:7)S="`N("<F;F)S<#LG("X@)'!A9V5S7W!R978@/SX*("`@/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](G!A9V4B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'!A9V5/8BT^<&%G92D@/SXB('-I>F4](CP_<&AP(&5C
M:&\@4W1R:6YG.CIL96YG=&@H)'!A9V5/8BT^<&%G96-O=6YT*2`_/B(@+SX*
M("`@/#]P:'`@96-H;R`D<&%G97-?;F5X="`N("<F;F)S<#LG("X@)'!A9V5S
M7VQA<W0@/SX*("`@/"]F;W)M/@H\/W!H<"!E;F1I9CL@/SX*("`\+W1D/@H@
M/"]T<CX*/"]T86)L93X*"B`\+W1D/@H\+W1R/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]T96UP;&%T97,O;6%I;&)O>"]A8W1I;VYS+FEN8P``````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4S-#8`,3`T,3<S-C(W-C8`,#(S,#`V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QT
M<CX*(#QT9"!C;&%S<STB8V]N=')O;"(@8V]L<W!A;CTB-B(^"@H\=&%B;&4@
M=VED=&@](C$P,"4B/@H@/'1R/@H@(#QT9"!C;&%S<STB;&5F=$%L:6=N(CX*
M/#]P:'`@:68@*"1T<F%S:$UB;W@I.B`_/@H@("`\/W!H<"!E8VAO($AO<F1E
M.CIW:61G970H)R,G+"!?*")$96QE=&4B*2P@)W=I9&=E="<L("<G+"`B:68@
M*&-O;F9I<FTH)R(@+B!A9&1S;&%S:&5S*%\H(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!P97)M86YE;G1L>2!D96QE=&4@=&AE<V4@;65S<V%G97,_(BDI
M("X@(B<I*2![(%-U8FUI="@G9&5L971E7VUE<W-A9V5S)RD[('T@<F5T=7)N
M(&9A;'-E.R(L(%\H(E]$96QE=&4B*2D[(#\^"CP_<&AP(&5L<V4Z(#\^"B`@
M(#P_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="@G(R<L(%\H(D1E;&5T92(I+"`G
M=VED9V5T)RP@)R<L(")3=6)M:70H)V1E;&5T95]M97-S86=E<R<I.R!R971U
M<FX@9F%L<V4[(BP@7R@B7T1E;&5T92(I*3L@/SX*/#]P:'`@96YD:68[(#\^
M"CP_<&AP(&EF("@D<VAO=V1E;&5T95LG<'5R9V4G72!\?"`A:7-?;G5L;"@D
M=G1R87-H*2DZ(#\^"B`@('P@/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*"<C
M)RP@7R@B56YD96QE=&4B*2P@)W=I9&=E="<L("<G+"`B4W5B;6ET*"=U;F1E
M;&5T95]M97-S86=E<R<I.R!R971U<FX@9F%L<V4[(BP@7R@B7U5N9&5L971E
M(BDI.R`_/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*"1S:&]W7V)L86-K
M;&ES=%]L:6YK*3H@/SX*("`@?"`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H
M)R,G+"!?*")";&%C:VQI<W0B*2P@)W=I9&=E="<L("<G+"`B4W5B;6ET*"=B
M;&%C:VQI<W0G*3L@<F5T=7)N(&9A;'-E.R(L(%\H(E]";&%C:VQI<W0B*2D[
M(#\^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H)'-H;W=?=VAI=&5L:7-T
M7VQI;FLI.B`_/@H@("!\(#P_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="@G(R<L
M(%\H(E=H:71E;&ES="(I+"`G=VED9V5T)RP@)R<L(")3=6)M:70H)W=H:71E
M;&ES="<I.R!R971U<FX@9F%L<V4[(BP@7R@B7U=H:71E;&ES="(I*3L@/SX*
M/#]P:'`@96YD:68[(#\^"B`@('P@/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T
M*"<C)RP@7R@B1F]R=V%R9"(I+"`G=VED9V5T)RP@)R<L(")3=6)M:70H)V9W
M9%]D:6=E<W0G*3L@<F5T=7)N(&9A;'-E.R(L(%\H(D9O7W)W87)D(BDI(#\^
M"CP_<&AP(&EF("@D8V]N9ELG<W!A;2==6R=R97!O<G1I;F<G72`F)B`H)&-O
M;F9;)W-P86TG75LG<W!A;69O;&1E<B==('Q\("1I;7!;)VUA:6QB;W@G72`A
M/2!)35`Z.F9O;&1E<E!R968H)'!R969S+3YG971686QU92@G<W!A;5]F;VQD
M97(G*2P@=')U92DI*3H@/SX*("`@?"`\/W!H<"!E8VAO($AO<F1E.CIW:61G
M970H)R,G+"!?*")297!O<G0@87,@4W!A;2(I+"`G=VED9V5T)RP@)R<L(")3
M=6)M:70H)W-P86U?<F5P;W)T)RD[(')E='5R;B!F86QS93LB+"!?*")297!O
M<G0@87,@4W!A;2(I*3L@/SX*/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("@D
M8V]N9ELG;F]T<W!A;2==6R=R97!O<G1I;F<G72`F)B`H(21C;VYF6R=N;W1S
M<&%M)UU;)W-P86UF;VQD97(G72!\?"`D:6UP6R=M86EL8F]X)UT@/3T@24U0
M.CIF;VQD97)0<F5F*"1P<F5F<RT^9V5T5F%L=64H)W-P86U?9F]L9&5R)RDL
M('1R=64I*2DZ(#\^"B`@('P@/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*"<C
M)RP@7R@B4F5P;W)T(&%S($EN;F]C96YT(BDL("=W:61G970G+"`G)RP@(E-U
M8FUI="@G;F]T<W!A;5]R97!O<G0G*3L@<F5T=7)N(&9A;'-E.R(L(%\H(E)E
M<&]R="!A<R!);FYO8V5N="(I*3L@/SX*/#]P:'`@96YD:68[(#\^"B`@('P@
M/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*"<C)RP@7R@B5FEE=R!-97-S86=E
M<R(I+"`G=VED9V5T)RP@)R<L(")3=6)M:70H)W9I97=?;65S<V%G97,G*3L@
M<F5T=7)N(&9A;'-E.R(L(%\H(E9I97<@365S<V%G97,B*2D[(#\^"B`@/"]T
M9#X*("`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H\/W!H<"!I9B`H)'-H;W=D
M96QE=&5;)W!U<F=E)UTI.B`_/@H\/W!H<"`D;6%I;&)O>%]L:6YK(#T@571I
M;#HZ861D4&%R86UE=&5R*"1M86EL8F]X7W5R;"P@)W!A9V4G+"`D<&%G94]B
M+3YP86=E*3L@/SX*/#]P:'`@:68@*&ES<V5T*"1D96QE=&5D7W!R;VUP="DI
M.B`_/@H@("`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H571I;#HZ861D4&%R
M86UE=&5R*"1M86EL8F]X7VQI;FLL("=A8W1I;VY)1"<L("=H:61E7V1E;&5T
M960G*2P@)&1E;&5T961?<')O;7!T+"`G=VED9V5T)RP@)R<L("<G+"`D9&5L
M971E9%]P<F]M<'0I.R`_/B!\"CP_<&AP(&5N9&EF.R`_/@H@("`\/W!H<"!E
M8VAO($AO<F1E.CIW:61G970H571I;#HZ861D4&%R86UE=&5R*"1M86EL8F]X
M7VQI;FLL("=A8W1I;VY)1"<L("=E>'!U;F=E7VUA:6QB;W@G*2P@7R@B4'5R
M9V4@1&5L971E9"(I+"`G=VED9V5T)RP@)R<L("<G+"!?*")0=7)?9V4@1&5L
M971E9"(I*3L@/SX*/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("@D=')A<VA-
M8F]X*3H@/SX*("`@/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*%5T:6PZ.F%D
M9%!A<F%M971E<B@D;6%I;&)O>%]U<FPL("=A8W1I;VY)1"<L("=E;7!T>5]M
M86EL8F]X)RDL(%\H(D5M<'1Y(%1R87-H(&9O;&1E<B(I+"`G=VED9V5T)RP@
M)R<L(")R971U<FX@8V]N9FER;2@G(B`N(&%D9'-L87-H97,H7R@B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&5M<'1Y('1H:7,@9F]L9&5R/R(I*2`N("(G
M*3LB+"!?*")%;7!T>2!4<F%S:"!F;VQD97(B*2D[(#\^"CP_<&AP(&5N9&EF
M.R`_/@H@(#PO=&0^"B`\+W1R/@H\+W1A8FQE/@H*(#PO=&0^"CPO='(^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L
M871E<R]M86EL8F]X+VUE<W-A9V5?9F]O=&5R<RYI;F,`````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,30T-``Q,#0Q-S,V,C<V-@`P,C0U,C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/"]T86)L93X*/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB<&%G92(@=F%L=64](CP_<&AP(&5C:&\@)'!A
M9V5/8BT^<&%G92`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M86-T:6]N240B('9A;'5E/2(B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](G1A<F=E=$UB;W@B('9A;'5E/2(B("\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](FYE=TUB;W@B('9A;'5E/2(P(B`O/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)F;&%G(B!V86QU93TB(B`O/@H\+V9O<FT^"@H\<V-R
M:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"D9L86=S(#T@;F5W
M($%R<F%Y*#P_<&AP"FEF("AI<W-E="@D9FQA9W,I("8F(&ES7V%R<F%Y*"1F
M;&%G<RDI('L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1F;&%G<RD[
M("1I*RLI('L*("`@("`@("!I9B`H)&D@/B`P*2!["B`@("`@("`@("`@(&5C
M:&\@)RP@)SL*("`@("`@("!]"B`@("`@("`@96-H;R`G(B<@+B`D9FQA9W-;
M)&E=("X@)R(G.PH@("`@?0I]"C\^*3L*"G9A<B!M97-S86=E;&ES="`](&YE
M=R!!<G)A>2@\/W!H<`II9B`H:7-S970H)&UE<W-A9V5S*2`F)B!I<U]A<G)A
M>2@D;65S<V%G97,I*2!["B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D
M;65S<V%G97,I.R`D:2LK*2!["B`@("`@("`@:68@*"1I(#X@,"D@>PH@("`@
M("`@("`@("!E8VAO("<L("<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)R(G
M("X@)&UE<W-A9V5S6R1I72`N("<B)SL*("`@('T*?0H_/BD["@HO+RTM/@H\
M+W-C<FEP=#X*"CPO=&0^/"]T<CX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+W1E;7!L871E<R]M86EL8F]X+V%C=&EO;G-?9&5L971E9"YI;F,`````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#<Q-0`Q,#0Q-S,V,C<V-@`P,C0T-C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(#QT<CX*("`\=&0@
M8VQA<W,](F-O;G1R;VPB(&-O;'-P86X](C8B/@H@("`\=&%B;&4@=VED=&@]
M(C$P,"4B/@H@("`@/'1R/@H@("`@(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(^
M"B`@("`@(#P_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="A5=&EL.CIA9&1087)A
M;65T97(H)')E9G)E<VA?=7)L+"`G86-T:6]N240G+"`G:&ED95]D96QE=&5D
M)RDL("1D96QE=&5D7W!R;VUP="P@)W=I9&=E="<L("<G+"`G)RP@)&1E;&5T
M961?<')O;7!T*3L@/SX@?`H@("`@("`\/W!H<"!E8VAO($AO<F1E.CIW:61G
M970H571I;#HZ861D4&%R86UE=&5R*"1R969R97-H7W5R;"P@)V%C=&EO;DE$
M)RP@)V5X<'5N9V5?;6%I;&)O>"<I+"!?*")0=7)G92!$96QE=&5D(BDL("=W
M:61G970G+"`G)RP@)R<L(%\H(E!U<E]G92!$96QE=&5D(BDI.R`_/@H@("`@
M(#PO=&0^"B`@("`\+W1R/@H@("`\+W1A8FQE/@H@(#PO=&0^"B`\+W1R/@H`
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O
M;6%I;&)O>"]L96=E;F0N:6YC````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#,R-C``,3`T,3<S-C(W-C8`,#(R-3<U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QT<CX*(#QT9"!C;&%S<STB8V]N=')O
M;"(@8V]L<W!A;CTB-B(^"B`@/&1I=B!C;&%S<STB;6%I;&)O>$QE9V5N9"(^
M"B`@(#QU;#X*("`@(#QL:3X\9&EV/CQD:78@8VQA<W,](G5N<V5E;B(^/#]P
M:'`@96-H;R!(;W)D93HZ:6UG*"=M86EL7W5N<V5E;BYP;F<G+"!?*")5;G-E
M96XB*2D@/SX\+V1I=CX\/W!H<"!E8VAO(%\H(E5N<V5E;B(I(#\^/"]D:78^
M/"]L:3X*("`@(#QL:3X\9&EV/CQD:78@8VQA<W,](F%N<W=E<F5D(CX\/W!H
M<"!E8VAO($AO<F1E.CII;6<H)VUA:6Q?86YS=V5R960N<&YG)RP@7R@B06YS
M=V5R960B*2D@/SX\+V1I=CX\/W!H<"!E8VAO(%\H(D%N<W=E<F5D(BD@/SX\
M+V1I=CX\+VQI/@H@("`@/&QI/CQD:78^/&1I=B!C;&%S<STB:6UP;W)T86YT
M(CX\/W!H<"!E8VAO($AO<F1E.CII;6<H)VUA:6Q?9FQA9V=E9"YP;F<G+"!?
M*"));7!O<G1A;G0B*2D@/SX\+V1I=CX\/W!H<"!E8VAO(%\H(DEM<&]R=&%N
M="(I(#\^/"]D:78^/"]L:3X*("`@(#QL:3X\9&EV/CQD:78@8VQA<W,](F1E
M;&5T960B/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G;6%I;%]D96QE=&5D+G!N
M9R<L(%\H(D1E;&5T960B*2D@/SX\+V1I=CX\/W!H<"!E8VAO(%\H(D1E;&5T
M960B*2`_/CPO9&EV/CPO;&D^"B`@("`\;&D^/&1I=CX\9&EV/CP_<&AP(&5C
M:&\@2&]R9&4Z.FEM9R@G;6%I;%]D<F%F="YP;F<G+"!?*")$<F%F="(I*2`_
M/CPO9&EV/CP_<&AP(&5C:&\@7R@B1')A9G0B*2`_/CPO9&EV/CPO;&D^"B`@
M("`\;&D^/&1I=CX\9&EV/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G;6%I;%]P
M97)S;VYA;"YP;F<G+"!?*")097)S;VYA;"(I*2`_/CPO9&EV/CP_<&AP(&5C
M:&\@7R@B4&5R<V]N86PB*2`_/CPO9&EV/CPO;&D^"CP_<&AP(&EF("@D8V]N
M9ELG;6%I;&)O>"==6R=S:&]W7WAP<FEO<FET>2==*3H@/SX*("`@(#QL:3X\
M9&EV/CQD:78@8VQA<W,](FEM<&]R=&%N="(^/#]P:'`@96-H;R!(;W)D93HZ
M:6UG*"=M86EL7W!R:6]R:71Y7VAI9V@N<&YG)RP@7R@B2&EG:"!0<FEO<FET
M>2(I*2`_/CPO9&EV/CP_<&AP(&5C:&\@7R@B2&EG:"!0<FEO<FET>2(I(#\^
M/"]D:78^/"]L:3X*("`@(#QL:3X\9&EV/CQD:78^/#]P:'`@96-H;R!(;W)D
M93HZ:6UG*"=M86EL7W!R:6]R:71Y7VQO=RYP;F<G+"!?*"),;W<@4')I;W)I
M='DB*2D@/SX\+V1I=CX\/W!H<"!E8VAO(%\H(DQO=R!0<FEO<FET>2(I(#\^
M/"]D:78^/"]L:3X*/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("@D8V]N9ELG
M;6%I;&)O>"==6R=S:&]W7V%T=&%C:&UE;G1S)UTI.B`_/@H@("`@/&QI/CQD
M:78^/&1I=CX\/W!H<"!E8VAO($AO<F1E.CII;6<H)V%T=&%C:&UE;G0N<&YG
M)RP@7R@B071T86-H;65N="(I*2`_/CPO9&EV/CP_<&AP(&5C:&\@7R@B071T
M86-H;65N="(I(#\^/"]D:78^/"]L:3X*("`@(#QL:3X\9&EV/CQD:78^/#]P
M:'`@96-H;R!(;W)D93HZ:6UG*"=S:6=N960N<&YG)RP@7R@B4VEG;F5D(BDI
M(#\^/"]D:78^/#]P:'`@96-H;R!?*")3:6=N960B*2`_/CPO9&EV/CPO;&D^
M"B`@("`\;&D^/&1I=CX\9&EV/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G96YC
M<GEP=&5D+G!N9R<L(%\H(D5N8W)Y<'1E9"(I*2`_/CPO9&EV/CP_<&AP(&5C
M:&\@7R@B16YC<GEP=&5D(BD@/SX\+V1I=CX\+VQI/@H\/W!H<"!E;F1I9CL@
M/SX*("`@/"]U;#X*("`@/&1I=B!C;&%S<STB8VQE87(B/B9N8G-P.SPO9&EV
M/@H@(#PO9&EV/@H@/"]T9#X*/"]T<CX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+VUA:6QB
M;W@O9F]O=&5R+FEN8P``````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#(P
M`#$P-#$W,S8R-S8V`#`R,C8R-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\+W1A8FQE/@H\8G(@+SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]M86EL8F]X+VIA=F%S8W)I
M<'0N:6YC```````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,C`V,P`Q,#0Q-S,V,C<V
M-@`P,C,U,3``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@HO
M+R!3970@=7`@;&5F="`H,S<I(&%N9"!R:6=H="`H,SDI(&%R<F]W<R!T;R!G
M;R!T;R!T:&4@<')E=FEO=7,O;F5X="!P86=E+@IS971+97EB:6YD:6YG*#,W
M+"`G87)R;W=(86YD;&5R)RD["G-E=$ME>6)I;F1I;F<H,SDL("=A<G)O=TAA
M;F1L97(G*3L*"F9U;F-T:6]N(&%R<F]W2&%N9&QE<BAE+"!K97DI"GL*("`@
M(&EF("@A9&]C=6UE;G0N9V5T16QE;65N=$)Y260@?'P@92YA;'1+97D@?'P@
M92YS:&EF=$ME>2!\?"!E+F-T<FQ+97DI('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@=F%R(&QO8SL*("`@(&EF("AK97D@/3T@,S<I('L*
M("`@("`@("!L;V,@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G<')E=B<I
M.PH@("`@?2!E;'-E(&EF("AK97D@/3T@,SDI('L*("`@("`@("!L;V,@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@G;F5X="<I.PH@("`@?0H*("`@(&EF
M("AL;V,I('L*("`@("`@("!D;V-U;65N="YL;V-A=&EO;BYH<F5F(#T@;&]C
M+FAR968["B`@("!]"B`@("!R971U<FX@=')U93L*?0H*9G5N8W1I;VX@06YY
M4V5L96-T960H*0I["B`@("!F;W(@*&D@/2`P.R!I(#P@9&]C=6UE;G0N;65S
M<V%G97,N96QE;65N=',N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H9&]C
M=6UE;G0N;65S<V%G97,N96QE;65N='-;:5TN8VAE8VME9"D@<F5T=7)N('1R
M=64["B`@("!]"B`@("!R971U<FX@9F%L<V4["GT*"G9A<B!R;W=#;VQO<G,@
M/2!N97<@07)R87DH*3L*9G5N8W1I;VX@<V5L96-T4F]W*')O=TED*0I["B`@
M("!R;W=/8B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=R;W<G("L@<F]W
M260I.PH@("`@:68@*"%R;W=/8BD@>PH@("`@("`@(')E='5R;CL*("`@('T*
M"B`@("!I9B`H<F]W3V(N8VQA<W-.86UE+FEN9&5X3V8H)W-E;&5C=&5D4F]W
M)RD@(3T@+3$I('L*("`@("`@("!R;W=/8BYC;&%S<TYA;64@/2!R;W=#;VQO
M<G-;<F]W261=.PH@("`@?2!E;'-E('L*("`@("`@("!R;W=#;VQO<G-;<F]W
M261=(#T@<F]W3V(N8VQA<W-.86UE.PH@("`@("`@(')O=T]B+F-L87-S3F%M
M92`]("=S96QE8W1E9%)O=R<["B`@("!]"GT*"F9U;F-T:6]N(&=E=$EN9&5X
M0GE%;&5M96YT*&5L96TI"GL*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@96QE
M;2YF;W)M+F5L96UE;G1S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*&5L
M96T@/3T@96QE;2YF;W)M+F5L96UE;G1S6VE=*2!R971U<FX@:3L*("`@('T*
M("`@(')E='5R;B!N=6QL.PI]"@IF=6YC=&EO;B!3=6)M:70H86-T240I"GL*
M("`@(&EF("@A06YY4V5L96-T960H*2D@>PH@("`@("`@('=I;F1O=RYA;&5R
M="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO=2!M=7-T('-E;&5C="!A
M="!L96%S="!O;F4@;65S<V%G92!F:7)S="XB*2D@/SXG*3L*("`@("`@("!R
M971U<FX["B`@("!]"@H\/W!H<"!I9B`H)%]315-324].6R=I;7`G75LG8F%S
M95]P<F]T;V-O;"==(#T]("=P;W`S)RDZ(#\^"B`@("!I9B`H86-T240@/3T@
M)V1E;&5T95]M97-S86=E<R<I('L*("`@("`@("!I9B`H(7=I;F1O=RYC;VYF
M:7)M*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(%!%4DU!3D5.5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B
M*2D@/SXG*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@
M?0H\/W!H<"!E;F1I9CL@/SX*("`@(&EF("AA8W1)1"`]/2`G<W!A;5]R97!O
M<G0G*2!["B`@("`@("`@:68@*"%W:6YD;W<N8V]N9FER;2@G/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R97!O
M<G0@=&AI<R!M97-S86=E(&%S('-P86T_(BDI(#\^)RDI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*("`@(&EF("AA8W1)1"`]/2`G
M;F]T<W!A;5]R97!O<G0G*2!["B`@("`@("`@:68@*"%W:6YD;W<N8V]N9FER
M;2@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!R97!O<G0@=&AI<R!M97-S86=E(&%S(&EN;F]C96YT/R(I*2`_
M/B<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"B`@
M("!D;V-U;65N="YM97-S86=E<RYA8W1I;VY)1"YV86QU92`](&%C=$E$.PH@
M("`@9&]C=6UE;G0N;65S<V%G97,N<W5B;6ET*"D["GT*"F9U;F-T:6]N(&UA
M:V5396QE8W1I;VXH=VAI8VA&;W)M*0I["B`@("!S=VET8V@@*'!A<G-E26YT
M*'=H:6-H1F]R;2DI('L*("`@(&-A<V4@+3$Z"B`@("`@("`@:68@*&1O8W5M
M96YT+FUE<W-A9V5S+F-H96-K06QL+F-H96-K960I('L*("`@("`@("`@("`@
M9FQA9R`]("(A/#]P:'`@96-H;R!)35!?04Q,(#\^(CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!F;&%G(#T@(CP_<&AP(&5C:&\@24U07T%,3"`_
M/B(["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH*("`@(&-A<V4@,3H*("`@
M("`@("!F;&%G(#T@9&]C=6UE;G0N<V5L96-T,2YF:6QT97(N;W!T:6]N<UMD
M;V-U;65N="YS96QE8W0Q+F9I;'1E<BYS96QE8W1E9$EN9&5X72YV86QU93L*
M("`@("`@("!B<F5A:SL*"B`@("!D969A=6QT.@H@("`@("`@(&9L86<@/2!D
M;V-U;65N="YS96QE8W0R+F9I;'1E<BYO<'1I;VYS6V1O8W5M96YT+G-E;&5C
M=#(N9FEL=&5R+G-E;&5C=&5D26YD97A=+G9A;'5E.PH@("`@?0H*("`@(&EF
M("AF;&%G+G-U8G-T<FEN9R@P+"`Q*2`]/2`B(2(I('L*("`@("`@("!S96QE
M8W1&;&%G9V5D*'!A<G-E26YT*&9L86<N<W5B<W1R:6YG*#$I*2P@9F%L<V4I
M.PH@("`@?2!E;'-E(&EF("AF;&%G+G-U8G-T<FEN9R@P+"`Q*2`]/2`B*R(I
M('L*("`@("`@("!S96QE8W1&;&%G9V5D*&9L86<N<W5B<W1R:6YG*#`L,2DL
M(&YU;&PI.PH@("`@?2!E;'-E('L*("`@("`@("!S96QE8W1&;&%G9V5D*'!A
M<G-E26YT*&9L86<I+"!T<G5E*3L*("`@('T*"B`@("`O+R!297-E="!T:&4@
M9F]R;2X*("`@('-W:71C:"`H<&%R<V5);G0H=VAI8VA&;W)M*2D@>PH@("`@
M8V%S92`M,3H*("`@("`@("!B<F5A:SL*"B`@("!C87-E(#$Z"B`@("`@("`@
M9&]C=6UE;G0N<V5L96-T,2YR97-E="@I.PH@("`@("`@(&)R96%K.PH*("`@
M(&1E9F%U;'0Z"B`@("`@("`@9&]C=6UE;G0N<V5L96-T,BYR97-E="@I.PH@
M("`@?0I]"@IV87(@<W1A<G1R86YG92`]("TQ.PH*9G5N8W1I;VX@<V5L96-T
M4F%N9V4H92D*>PH@("`@=F%R(&-H96-K0F]X(#T@*&4N<W)C16QE;65N="!\
M?"!E+G1A<F=E="D["B`@("!V87(@96YD<F%N9V4@/2!G971);F1E>$)Y16QE
M;65N="AC:&5C:T)O>"D["@H@("`@:68@*'-T87)T<F%N9V4@/CT@,"`F)B!E
M+G-H:69T2V5Y*2!["B`@("`@("`@:68@*&1O8W5M96YT+FUE<W-A9V5S+F5L
M96UE;G1S6W-T87)T<F%N9V5=+F-H96-K960@/3T@9&]C=6UE;G0N;65S<V%G
M97,N96QE;65N='-;96YD<F%N9V5=+F-H96-K960I('L*("`@("`@("`@("`@
M:68@*'-T87)T<F%N9V4@/B!E;F1R86YG92D@>PH@("`@("`@("`@("`@("`@
M=F%R('1M<"`](&5N9')A;F=E.PH@("`@("`@("`@("`@("`@96YD<F%N9V4@
M/2!S=&%R=')A;F=E.PH@("`@("`@("`@("`@("`@<W1A<G1R86YG92`]('1M
M<#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W(@*'9A<B!I(#T@<W1A
M<G1R86YG92`K(#$[(&D@/"!E;F1R86YG93L@:2LK*2!["B`@("`@("`@("`@
M("`@("!D;V-U;65N="YM97-S86=E<RYE;&5M96YT<UMI72YC:&5C:V5D(#T@
M9&]C=6UE;G0N;65S<V%G97,N96QE;65N='-;<W1A<G1R86YG95TN8VAE8VME
M9#L*("`@("`@("`@("`@("`@('-E;&5C=%)O=RAD;V-U;65N="YM97-S86=E
M<RYE;&5M96YT<UMI72YI9"YR97!L86-E*"]C:&5C:R\L("<G*2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@<W1A<G1R86YG92`]("TQ.PH@
M("`@?2!E;'-E('L*("`@("`@("!S=&%R=')A;F=E(#T@9V5T26YD97A">45L
M96UE;G0H8VAE8VM";W@I.PH@("`@?0I]"@IF=6YC=&EO;B!O;D-L:6-K2&%N
M9&QE<BAE*0I["B`@("!V87(@92`](&4@?'P@=VEN9&]W+F5V96YT.PH@("`@
M=F%R(&5L96T@/2`H92YS<F-%;&5M96YT('Q\(&4N=&%R9V5T*3L*"B`@("`O
M+R!286YG92!S96QE8W1I;VXO9&5S96QE8W1I;VXN"B`@("!I9B`H96QE;2YN
M86UE(#T](")I;F1I8V5S6UTB*2!["B`@("`@("`@<V5L96-T4F%N9V4H92D[
M"B`@("!]"GT*"F1O8W5M96YT+F]N8VQI8VL@/2!O;D-L:6-K2&%N9&QE<CL*
M"CP_<&AP(&EF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG=7-E<B==6R=A
M;&QO=U]F;VQD97)S)UTI*3H@/SX*9G5N8W1I;VX@=7!D871E1F]L9&5R<RAW
M:&EC:$9O<FTI"GL*("`@(&EF("AD;V-U;65N="YC;W!Y;6]V93(I('L*("`@
M("`@("!I9B`H*'=H:6-H1F]R;2`]/2`Q("8F(&1O8W5M96YT+F-O<'EM;W9E
M,2YT87)G971-86EL8F]X+F]P=&EO;G-;9&]C=6UE;G0N8V]P>6UO=F4Q+G1A
M<F=E=$UA:6QB;W@N<V5L96-T961);F1E>%TN=F%L=64@(3T@(B(I('Q\"B`@
M("`@("`@("`@("AW:&EC:$9O<FT@/3T@,B`F)B!D;V-U;65N="YC;W!Y;6]V
M93(N=&%R9V5T36%I;&)O>"YO<'1I;VYS6V1O8W5M96YT+F-O<'EM;W9E,BYT
M87)G971-86EL8F]X+G-E;&5C=&5D26YD97A=+G9A;'5E("$]("(B*2D@>PH@
M("`@("`@("`@("!I9B`H=VAI8VA&;W)M(#T](#$I('L*("`@("`@("`@("`@
M("`@(&1O8W5M96YT+F-O<'EM;W9E,BYT87)G971-86EL8F]X+G-E;&5C=&5D
M26YD97@@/2!D;V-U;65N="YC;W!Y;6]V93$N=&%R9V5T36%I;&)O>"YS96QE
M8W1E9$EN9&5X.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@9&]C=6UE;G0N8V]P>6UO=F4Q+G1A<F=E=$UA:6QB;W@N<V5L96-T961)
M;F1E>"`](&1O8W5M96YT+F-O<'EM;W9E,BYT87)G971-86EL8F]X+G-E;&5C
M=&5D26YD97@["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"GT*"F9U
M;F-T:6]N(%1R86YS9F5R*&%C=$E$+"!W:&EC:$9O<FTI"GL*("`@(&EF("A!
M;GE396QE8W1E9"@I*2!["B`@("`@("`@:68@*'=H:6-H1F]R;2`]/2`Q*2![
M"B`@("`@("`@("`@(&1O8W5M96YT+FUE<W-A9V5S+G1A<F=E=$UB;W@N=F%L
M=64@/2!D;V-U;65N="YC;W!Y;6]V93$N=&%R9V5T36%I;&)O>"YO<'1I;VYS
M6V1O8W5M96YT+F-O<'EM;W9E,2YT87)G971-86EL8F]X+G-E;&5C=&5D26YD
M97A=+G9A;'5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&1O8W5M
M96YT+FUE<W-A9V5S+G1A<F=E=$UB;W@N=F%L=64@/2!D;V-U;65N="YC;W!Y
M;6]V93(N=&%R9V5T36%I;&)O>"YO<'1I;VYS6V1O8W5M96YT+F-O<'EM;W9E
M,BYT87)G971-86EL8F]X+G-E;&5C=&5D26YD97A=+G9A;'5E.PH@("`@("`@
M('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(&$@;6%I;&)O>"!A8W1U86QL>2!B
M96EN9R!S96QE8W1E9"X*("`@("`@("!I9B`H9&]C=6UE;G0N;65S<V%G97,N
M=&%R9V5T36)O>"YV86QU92`]/2`G*FYE=RHG*2!["B`@("`@("`@("`@('9A
M<B!N97=&;VQD97(@/2!W:6YD;W<N<')O;7!T*"<\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B66]U(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD
M97(N(BDI("X@)UQN)R`N(&%D9'-L87-H97,H7R@B4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!F;VQD97(Z(BDI(#\^7&XG+"`G)RD["B`@("`@
M("`@("`@(&EF("AN97=&;VQD97(@(3T@;G5L;"`F)B!N97=&;VQD97(@(3T@
M)R<I('L*("`@("`@("`@("`@("`@(&1O8W5M96YT+FUE<W-A9V5S+FYE=TUB
M;W@N=F%L=64@/2`Q.PH@("`@("`@("`@("`@("`@9&]C=6UE;G0N;65S<V%G
M97,N=&%R9V5T36)O>"YV86QU92`](&YE=T9O;&1E<CL*("`@("`@("`@("`@
M("`@(&1O8W5M96YT+FUE<W-A9V5S+F%C=&EO;DE$+G9A;'5E(#T@86-T240[
M"B`@("`@("`@("`@("`@("!D;V-U;65N="YM97-S86=E<RYS=6)M:70H*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF
M("AD;V-U;65N="YM97-S86=E<RYT87)G971-8F]X+G9A;'5E(#T]("<G*2![
M"B`@("`@("`@("`@("`@("!W:6YD;W<N86QE<G0H)SP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F
M:7)S="XB*2D@/SXG*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&1O8W5M96YT+FUE<W-A9V5S+F%C=&EO;DE$+G9A;'5E(#T@86-T
M240["B`@("`@("`@("`@("`@("!D;V-U;65N="YM97-S86=E<RYS=6)M:70H
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T@96QS92!["B`@("`@
M("`@=VEN9&]W+F%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U
M(&UU<W0@<V5L96-T(&%T(&QE87-T(&]N92!M97-S86=E(&9I<G-T+B(I*2`_
M/B<I.PH@("`@?0I]"CP_<&AP(&5N9&EF.R`_/@H*+R\@4'5T(&5V97)Y=&AI
M;F<@<F5L:6%N="!O;B!)34%0(&9L86=S(&EN('1H:7,@<V5C=&EO;BX*=F%R
M($9L86=S.PH*9G5N8W1I;VX@<V5L96-T1FQA9V=E9"AF;&%G+"!V86PI"GL*
M("`@('-H:69T(#T@,#L*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@9&]C=6UE
M;G0N;65S<V%G97,N96QE;65N=',N;&5N9W1H.R!I*RLI('L*("`@("`@("!W
M:&EL92`H9&]C=6UE;G0N;65S<V%G97,N96QE;65N='-;:5TN;F%M92`A/2`B
M:6YD:6-E<UM=(BD@>PH@("`@("`@("`@("!I*RL["B`@("`@("`@("`@('-H
M:69T*RL["B`@("`@("`@("`@(&EF("@A9&]C=6UE;G0N;65S<V%G97,N96QE
M;65N='-;:5TI('L*("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&9L86<@/3T@)RLG*2!["B`@
M("`@("`@("`@(&-H96-K(#T@(61O8W5M96YT+FUE<W-A9V5S+F5L96UE;G1S
M6VE=+F-H96-K960["B`@("`@("`@?2!E;'-E(&EF("AF;&%G("8@1FQA9W-;
M:2`M('-H:69T72D@>PH@("`@("`@("`@("!C:&5C:R`]('9A;#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!C:&5C:R`]("%V86P["B`@("`@("`@
M?0H*("`@("`@("!I9B`H9&]C=6UE;G0N;65S<V%G97,N96QE;65N='-;:5TN
M8VAE8VME9"`A/2!C:&5C:RD@>PH@("`@("`@("`@("!D;V-U;65N="YM97-S
M86=E<RYE;&5M96YT<UMI72YC:&5C:V5D(#T@8VAE8VL["B`@("`@("`@("`@
M('-E;&5C=%)O=RAD;V-U;65N="YM97-S86=E<RYE;&5M96YT<UMI72YI9"YR
M97!L86-E*"]C:&5C:R\L("<G*2D["B`@("`@("`@?0H@("`@?0I]"@H\/W!H
M<"!I9B`H)%]315-324].6R=I;7`G75LG8F%S95]P<F]T;V-O;"==("$]("=P
M;W`S)RDZ(#\^"F9U;F-T:6]N(&9L86=-97-S86=E<RAW:&EC:$9O<FTI"GL*
M("`@(&EF("@H=VAI8VA&;W)M(#T](#$@)B8@9&]C=6UE;G0N<V5L96-T,2YF
M;&%G+F]P=&EO;G-;9&]C=6UE;G0N<V5L96-T,2YF;&%G+G-E;&5C=&5D26YD
M97A=+G9A;'5E("$]("(B*2!\?`H@("`@("`@("AW:&EC:$9O<FT@/3T@,B`F
M)B!D;V-U;65N="YS96QE8W0R+F9L86<N;W!T:6]N<UMD;V-U;65N="YS96QE
M8W0R+F9L86<N<V5L96-T961);F1E>%TN=F%L=64@(3T@(B(I*2!["B`@("`@
M("`@:68@*$%N>5-E;&5C=&5D*"DI('L*("`@("`@("`@("`@:68@*'=H:6-H
M1F]R;2`]/2`Q*2!["B`@("`@("`@("`@("`@("!D;V-U;65N="YM97-S86=E
M<RYF;&%G+G9A;'5E(#T@9&]C=6UE;G0N<V5L96-T,2YF;&%G+F]P=&EO;G-;
M9&]C=6UE;G0N<V5L96-T,2YF;&%G+G-E;&5C=&5D26YD97A=+G9A;'5E.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9&]C=6UE;G0N
M;65S<V%G97,N9FQA9RYV86QU92`](&1O8W5M96YT+G-E;&5C=#(N9FQA9RYO
M<'1I;VYS6V1O8W5M96YT+G-E;&5C=#(N9FQA9RYS96QE8W1E9$EN9&5X72YV
M86QU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9&]C=6UE;G0N;65S
M<V%G97,N86-T:6]N240N=F%L=64@/2`G9FQA9U]M97-S86=E<R<["B`@("`@
M("`@("`@(&1O8W5M96YT+FUE<W-A9V5S+G-U8FUI="@I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&EF("AW:&EC:$9O<FT@/3T@,2D@>PH@("`@
M("`@("`@("`@("`@9&]C=6UE;G0N<V5L96-T,2YF;&%G+G-E;&5C=&5D26YD
M97@@/2`P.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M9&]C=6UE;G0N<V5L96-T,BYF;&%G+G-E;&5C=&5D26YD97@@/2`P.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@('=I;F1O=RYA;&5R="@G/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(EEO=2!M=7-T('-E;&5C="!A="!L96%S="!O;F4@
M;65S<V%G92!F:7)S="XB*2D@/SXG*3L*("`@("`@("!]"B`@("!]"GT*/#]P
M:'`@96YD:68[(#\^"@H\/W!H<"!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^
M:&%S1F5A='5R92@G9&]M)RDI.B`_/@IF=6YC=&EO;B!G971-97-S86=E*&ED
M+"!O9F9S970L(&EN9&5X*0I["B`@("!F;W(@*&D@/2`P.R!I(#P@;65S<V%G
M96QI<W0N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H;65S<V%G96QI<W1;
M:5T@/3T@:60I('L*("`@("`@("`@("`@:B`](&D@*R!O9F9S970["B`@("`@
M("`@("`@(&EF("AJ(#X](#`@)B8@:B`\(&UE<W-A9V5L:7-T+FQE;F=T:"D@
M>PH@("`@("`@("`@("`@("`@:68@*&EN9&5X*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&H["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!M97-S86=E;&ES=%MJ73L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@
M(')E='5R;B`G)SL*?0H*9G5N8W1I;VX@;VY+97E$;W=N2&%N9&QE<BAE*0I[
M"B`@("!V87(@92`](&4@?'P@=VEN9&]W+F5V96YT.PH@("`@=F%R(&\@/2`H
M92YS<F-%;&5M96YT('Q\(&4N=&%R9V5T*3L*("`@('9A<B!N97AT.PH@("`@
M=F%R(&]L9#L*("`@('9A<B!I9#L*"B`@("!I9B`H92YA;'1+97D@?'P@92YC
M=')L2V5Y*2!["B`@("`@("`@<W=I=&-H("AE+FME>4-O9&4I('L*("`@("`@
M("`O+R!5<`H@("`@("`@(&-A<V4@,S@Z"B`@("`@("`@("`@(&EF("AO+FED
M+G-U8G-T<B@P+"`U*2`]/2`G8VAE8VLG("8F(&\N=&%G3F%M92`]/2`G24Y0
M550G*2!["B`@("`@("`@("`@("`@("!O;&0@/2!O+FED+G-U8G-T<B@U+"!O
M+FED+FQE;F=T:"`M(#4I.PH@("`@("`@("`@("`@("`@:60@/2!G971-97-S
M86=E*&]L9"P@+3$I.PH@("`@("`@("`@("`@("`@;F5X="`](&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*"=C:&5C:R<@*R!I9"D["B`@("`@("`@("`@('T@
M96QS92!I9B`H;RYI9"YS=6)S='(H,"P@-RD@/3T@)W-U8FIE8W0G("8F(&\N
M=&%G3F%M92`]/2`G02<I('L*("`@("`@("`@("`@("`@(&EF("AE+F%L=$ME
M>2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&]L9"`](&\N:60N<W5B<W1R*#<L(&\N
M:60N;&5N9W1H("T@-RD["B`@("`@("`@("`@("`@("!I9"`](&=E=$UE<W-A
M9V4H;VQD+"`M,2D["B`@("`@("`@("`@("`@("!N97AT(#T@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)W-U8FIE8W0G("L@:60I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@:60@/2!M97-S86=E;&ES=%MM97-S
M86=E;&ES="YL96YG=&@@+2`Q73L*("`@("`@("`@("`@("`@(&EF("AE+F%L
M=$ME>2D@>PH@("`@("`@("`@("`@("`@("`@(&YE>'0@/2!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@G8VAE8VLG("L@:60I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!N97AT(#T@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)W-U8FIE8W0G("L@:60I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("\O($1O=VX*("`@("`@("!C87-E(#0P.@H@("`@("`@("`@("!I9B`H;RYI
M9"YS=6)S='(H,"P@-2D@/3T@)V-H96-K)R`F)B!O+G1A9TYA;64@/3T@)TE.
M4%54)RD@>PH@("`@("`@("`@("`@("`@;VQD(#T@;RYI9"YS=6)S='(H-2P@
M;RYI9"YL96YG=&@@+2`U*3L*("`@("`@("`@("`@("`@(&ED(#T@9V5T365S
M<V%G92AO;&0L(#$I.PH@("`@("`@("`@("`@("`@;F5X="`](&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*"=C:&5C:R<@*R!I9"D["B`@("`@("`@("`@('T@
M96QS92!I9B`H;RYI9"YS=6)S='(H,"P@-RD@/3T@)W-U8FIE8W0G("8F(&\N
M=&%G3F%M92`]/2`G02<I('L*("`@("`@("`@("`@("`@(&EF("AE+F%L=$ME
M>2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&]L9"`](&\N:60N<W5B<W1R*#<L(&\N
M:60N;&5N9W1H("T@-RD["B`@("`@("`@("`@("`@("!I9"`](&=E=$UE<W-A
M9V4H;VQD+"`Q*3L*("`@("`@("`@("`@("`@(&YE>'0@/2!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@G<W5B:F5C="<@*R!I9"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!I9"`](&UE<W-A9V5L:7-T6S!=.PH@
M("`@("`@("`@("`@("`@:68@*&4N86QT2V5Y*2!["B`@("`@("`@("`@("`@
M("`@("`@;F5X="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=C:&5C:R<@
M*R!I9"D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&YE>'0@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G<W5B:F5C
M="<@*R!I9"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@+R\@3&5F=`H@("`@("`@(&-A<V4@
M,S<Z"B`@("`@("`@("`@(&EF("AE+F%L=$ME>2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AO+FED
M+G-U8G-T<B@P+"`U*2`]/2`G8VAE8VLG("8F(&\N=&%G3F%M92`]/2`G24Y0
M550G*2!["B`@("`@("`@("`@("`@("!O;&0@/2!O+FED+G-U8G-T<B@U+"!O
M+FED+FQE;F=T:"`M(#4I.PH@("`@("`@("`@("`@("`@:60@/2!G971-97-S
M86=E*&]L9"P@+3$I.PH@("`@("`@("`@("`@("`@;F5X="`](&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*"=S=6)J96-T)R`K(&ED*3L*("`@("`@("`@("`@
M?2!E;'-E(&EF("AO+FED+G-U8G-T<B@P+"`W*2`]/2`G<W5B:F5C="<@)B8@
M;RYT86=.86UE(#T]("=!)RD@>PH@("`@("`@("`@("`@("`@:60@/2!O+FED
M+G-U8G-T<B@W+"!O+FED+FQE;F=T:"`M(#<I.PH@("`@("`@("`@("`@("`@
M;F5X="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=C:&5C:R<@*R!I9"D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9"`](&UE
M<W-A9V5L:7-T6VUE<W-A9V5L:7-T+FQE;F=T:"`M(#%=.PH@("`@("`@("`@
M("`@("`@;F5X="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=S=6)J96-T
M)R`K(&ED*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`O+R!2:6=H=`H@("`@("`@(&-A<V4@,SDZ"B`@("`@("`@("`@(&EF
M("AE+F%L=$ME>2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AO+FED+G-U8G-T<B@P+"`U*2`]/2`G
M8VAE8VLG("8F(&\N=&%G3F%M92`]/2`G24Y0550G*2!["B`@("`@("`@("`@
M("`@("!I9"`](&\N:60N<W5B<W1R*#4L(&\N:60N;&5N9W1H("T@-2D["B`@
M("`@("`@("`@("`@("!N97AT(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)W-U8FIE8W0G("L@:60I.PH@("`@("`@("`@("!](&5L<V4@:68@*&\N:60N
M<W5B<W1R*#`L(#<I(#T]("=S=6)J96-T)R`F)B!O+G1A9TYA;64@/3T@)T$G
M*2!["B`@("`@("`@("`@("`@("!O;&0@/2!O+FED+G-U8G-T<B@W+"!O+FED
M+FQE;F=T:"`M(#<I.PH@("`@("`@("`@("`@("`@:60@/2!G971-97-S86=E
M*&]L9"P@,2D["B`@("`@("`@("`@("`@("!N97AT(#T@9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H)V-H96-K)R`K(&ED*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&ED(#T@;65S<V%G96QI<W1;,%T["B`@("`@
M("`@("`@("`@("!N97AT(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)V-H
M96-K)R`K(&ED*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@?2!E;'-E(&EF("AE+FME>4-O9&4@/3T@,S(@)B8@;RYI9"YS=6)S
M='(H,"P@-RD@/3T@)W-U8FIE8W0G("8F(&\N=&%G3F%M92`]/2`G02<I('L*
M("`@("`@("!I9"`](&\N:60N<W5B<W1R*#<L(&\N:60N;&5N9W1H("T@-RD[
M"B`@("`@("`@=F%R(&-H96-K8F]X(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)V-H96-K)R`K(&ED*3L*("`@("`@("!C:&5C:V)O>"YC:&5C:V5D(#T@
M(6-H96-K8F]X+F-H96-K960["B`@("`@("`@<V5L96-T4F]W*&ED*3L*("`@
M('T@96QS92!["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&EF("AN97AT
M*2!["B`@("`@("`@;F5X="YF;V-U<R@I.PH@("`@("`@('9A<B!R;W<@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@G<F]W)R`K(&ED*3L*("`@("`@("!I
M9B`H92YA;'1+97D@)B8@;F5X="YT86=.86UE(#T]("=)3E!55"<I('L*("`@
M("`@("`@("`@;F5X="YC:&5C:V5D(#T@(6YE>'0N8VAE8VME9#L*("`@("`@
M("`@("`@<V5L96-T4F]W*&YE>'0N:60N<F5P;&%C92@O8VAE8VLO+"`G)RDI
M.PH@("`@("`@('T@96QS92!I9B`H;VQD("$](&YE>'0@)B8@<F]W+F-L87-S
M3F%M92YI;F1E>$]F*"<M;W9E<B<I(#T]("TQ*2!["B`@("`@("`@("`@(')O
M=RYC;&%S<TYA;64@/2!R;W<N8VQA<W-.86UE("L@)RUO=F5R)SL*("`@("`@
M("!]"B`@("`@("`@=F%R(&EN9&5X(#T@9V5T365S<V%G92AI9"P@,"P@=')U
M92D["B`@("`@("`@:68@*&]L9"D@>PH@("`@("`@("`@("!R;W<@/2!D;V-U
M;65N="YG971%;&5M96YT0GE)9"@G<F]W)R`K(&]L9"D["B`@("`@("`@("`@
M(&EF("AO;&0@(3T@;F5X="D@>PH@("`@("`@("`@("`@("`@<F]W+F-L87-S
M3F%M92`](')O=RYC;&%S<TYA;64N<F5P;&%C92@O+6]V97(O+"`G)RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:6YD97@@/2!G971-97-S86=E*&]L
M9"P@,"P@=')U92D["B`@("`@("`@?0H@("`@?0H*("`@(&4N<F5T=7)N5F%L
M=64@/2!F86QS93L*/#]P:'`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FES
M0G)O=W-E<B@G;6]Z:6QL82<I*3H@/SX*("`@(&4N<')E=F5N=$1E9F%U;'0H
M*3L*/#]P:'`@96YD:68[(#\^"GT*"F1O8W5M96YT+F]N:V5Y9&]W;B`](&]N
M2V5Y1&]W;DAA;F1L97(["CP_<&AP(&5N9&EF.R`_/@H*+R\M+3X*/"]S8W)I
M<'0^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M=&5M<&QA=&5S+VUA:6QB;W@O<V5A<F-H9F]L9&5R+FEN8P``````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,C0U`#$P-#$W,S8R-S8V`#`R-#`P,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<"!I9B`H(65M
M<'1Y*"1L87-T36)O>"DI.B`_/CPO=&0^/"]T<CX\+W1A8FQE/CP_<&AP(&5N
M9&EF.R`_/@H\='(@8VQA<W,](FAE861E<B(^/'1D(&-O;'-P86X](C8B(&-L
M87-S/2)S;6%L;&AE861E<B(^)FYB<W`[/#]P:'`@96-H;R`D9F]L9&5R7VQI
M;FL@/SX*/"]T9#X\+W1R/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]M
M86EL8F]X+VAE861E<BYI;F,`````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#(W,``Q,#0Q-S,V,C<V-@`P,C(U-S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&1I=B!C;&%S<STB:&5A9&5R(CX*(#QS
M<&%N('-T>6QE/2)W:61T:#HS,"4B(&-L87-S/2)L969T1FQO870B/@H@(#QS
M<&%N(&1I<CTB;'1R(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'1I
M=&QE*2`_/B9N8G-P.SPO<W!A;CX*("`\/W!H<"!E8VAO($AO<F1E.CIL:6YK
M*"1R969R97-H7W5R;"P@)')E9G)E<VA?=&ET;&4L("<G+"`G)RP@)R<L("<G
M+"`D<F5F<F5S:%]A:RD@+B!(;W)D93HZ:6UG*"=R96QO860N<&YG)RP@7R@B
M4F5L;V%D(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`_/CPO83X*"CP_<&AP(&EF("AI<W-E="@D9FEL=&5R7W5R;"DI.B`_/@H@
M(#P_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)&9I;'1E<E]U<FPL('-P<FEN=&8H
M7R@B07!P;'D@1FEL=&5R<R!T;R`E<R(I+"`D=&ET;&4I*2`N($AO<F1E.CII
M;6<H)V9I;'1E<G,N<&YG)RP@7R@B07!P;'D@1FEL=&5R<R(I*2`_/CPO83X*
M/#]P:'`@96YD:68[(#\^"@H\/W!H<"!I9B`H(21S96%R8VA?;6)O>"DZ(#\^
M"B`@/#]P:'`@96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S96%R8V@N<&AP)RDL("=S96%R8VA?
M;6%I;&)O>"<L("1I;7!;)VUA:6QB;W@G72DL('-P<FEN=&8H7R@B4V5A<F-H
M("5S(BDL("1T:71L92DI("X@2&]R9&4Z.FEM9R@G<V5A<F-H+G!N9R<L(%\H
M(E-E87)C:"(I+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G
M*2D@/SX\+V$^"CP_<&AP(&5L<V5I9B`H)&EM<%]S96%R8V@M/FES161I=&%B
M;&561F]L9&5R*"DI.B`_/@H@(#P_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)&EM
M<%]S96%R8V@M/F5D:7154DPH*2P@<W!R:6YT9BA?*")%9&ET(%9I<G1U86P@
M1F]L9&5R($1E9FEN:71I;VX@9F]R("5S(BDL(&AT;6QS<&5C:6%L8VAA<G,H
M)'1I=&QE*2DI("X@2&]R9&4Z.FEM9R@G961I="YP;F<G+"!S<')I;G1F*%\H
M(D5D:70@5FER='5A;"!&;VQD97(@1&5F:6YI=&EO;B!F;W(@)7,B*2P@)'1I
M=&QE*2P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^
M/"]A/@H@(#P_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)&EM<%]S96%R8V@M/F1E
M;&5T95523"@I+"!S<')I;G1F*%\H(D1E;&5T92!6:7)T=6%L($9O;&1E<B!$
M969I;FET:6]N(&9O<B`E<R(I+"!H=&UL<W!E8VEA;&-H87)S*"1T:71L92DI
M+"!N=6QL+"!N=6QL+"`B:68@*&-O;F9I<FTH)R(@+B!A9&1S;&%S:&5S*%\H
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!D96QE=&4@=&AI<R!6:7)T=6%L
M($9O;&1E<B!$969I;FET:6]N/R(I*2`N("(G*2D@>R!R971U<FX@=')U93L@
M?2!E;'-E('L@<F5T=7)N(&9A;'-E.R!](BD@+B!(;W)D93HZ:6UG*"=D96QE
M=&4N<&YG)RP@<W!R:6YT9BA?*")$96QE=&4@5FER='5A;"!&;VQD97(@1&5F
M:6YI=&EO;B!F;W(@)7,B*2P@)'1I=&QE*2P@)R<L("1R96=I<W1R>2T^9V5T
M26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H\/W!H<"!E;'-E:68@*"$D:6UP
M7W-E87)C:"T^:7-61F]L9&5R*"DI.B`_/@H@(#P_<&AP(&5C:&\@2&]R9&4Z
M.FQI;FLH)&EM<%]S96%R8V@M/F5D:7154DPH*2P@7R@B161I="!396%R8V@@
M475E<GDB*2D@+B!(;W)D93HZ:6UG*"=E9&ET+G!N9R<L(%\H(D5D:70@4V5A
M<F-H(%%U97)Y(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D
M92<I*2`_/CPO83X*/#]P:'`@96YD:68[(#\^"B`\+W-P86X^"@H\/W!H<"!I
M9B`H)'!A9V5/8BT^<&%G96-O=6YT(#X@,2DZ(#\^"B`\<W!A;B!S='EL93TB
M=VED=&@Z,S4E.R!T97AT+6%L:6=N.F-E;G1E<B(@8VQA<W,](FQE9G1&;&]A
M="!N;W=R87`B/@H@(#P_<&AP('!R:6YT9BA?*")086=E("5D(&]F("5D(BDL
M("1P86=E3V(M/G!A9V4L("1P86=E3V(M/G!A9V5C;W5N="D@/SX*(#PO<W!A
M;CX*(#QS<&%N('-T>6QE/2)W:61T:#HS-24B(&-L87-S/2)R:6=H=$9L;V%T
M(')I9VAT06QI9VX@;F]W<F%P(CX*("`\/W!H<"!E8VAO("1M<V=?8V]U;G0@
M/SX*(#PO<W!A;CX*/#]P:'`@96QS93H@/SX*(#QS<&%N('-T>6QE/2)W:61T
M:#HW,"4B(&-L87-S/2)R:6=H=$9L;V%T(')I9VAT06QI9VX@;F]W<F%P(CX*
M("`\/W!H<"!E8VAO("1M<V=?8V]U;G0@/SX*(#PO<W!A;CX*/#]P:'`@96YD
M:68[(#\^"@H@/&)R(&-L87-S/2)C;&5A<B(@+SX*/"]D:78^"@H\=&%B;&4@
M8VQA<W,](FYO<&%D9&EN9R(@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P
M(CX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+W1E;7!L871E<R]M97-S86=E+P``````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,C`V,S<`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+VUE<W-A9V4O;65S<V%G92YI
M;F,``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C0T`#$P-#$W,S8R-S8V
M`#`R,C<U,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\9&EV(&-L87-S/2)C;VYT<F]L(B!I9#TB;65S<V%G94)O9'DB/@H@
M/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,R(^"B`@/#]P:'`@
M96-H;R`D;7-G5&5X="`_/@H@/"]T86)L93X*/"]D:78^"CQI;G!U="!T>7!E
M/2)H:61D96XB(&YA;64](F9L86<B('9A;'5E/2(B("\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+W1E;7!L871E<R]M97-S86=E+VYA=F)A<E]N879I9V%T92YI;F,`
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-#<T-0`Q,#0Q-S,V,C<V-@`P,C0T-S``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/'1R(&-L
M87-S/2)C;VYT<F]L(CX*("`\=&0@;F]W<F%P/2)N;W=R87`B(&-L87-S/2)L
M969T06QI9VXB/@H\/W!H<"!I9B`H)&EM<%LG8F%S95]P<F]T;V-O;"==("$]
M("=P;W`S)RDZ(#\^"B`@("`\<V5L96-T(&YA;64](F9L86<\/W!H<"!E8VAO
M("1N879?:60@/SXB(&]N8VAA;F=E/2)F;&%G365S<V%G92@\/W!H<"!E8VAO
M("1N879?:60@/SXI.R(^"B`@("`@(#QO<'1I;VX@=F%L=64](B(@<V5L96-T
M960](G-E;&5C=&5D(CX\/W!H<"!E8VAO(%\H(DUA<FL@87,Z(BD@/SX\+V]P
M=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB,%-E96XB/CP_<&AP(&5C:&\@
M7R@B56YS965N(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB
M1FQA9V=E9"(^/#]P:'`@96-H;R!?*"));7!O<G1A;G0B*2`_/CPO;W!T:6]N
M/@H@("`@("`\;W!T:6]N('9A;'5E/2(P1FQA9V=E9"(^/#]P:'`@96-H;R!?
M*").;W0@26UP;W)T86YT(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V
M86QU93TB06YS=V5R960B/CP_<&AP(&5C:&\@7R@B06YS=V5R960B*2`_/CPO
M;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(P06YS=V5R960B/CP_<&AP
M(&5C:&\@7R@B56YA;G-W97)E9"(I(#\^/"]O<'1I;VX^"B`@("`@(#QO<'1I
M;VX@=F%L=64](D1R869T(CX\/W!H<"!E8VAO(%\H(D1R869T(BD@/SX\+V]P
M=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB,$1R869T(CX\/W!H<"!E8VAO
M(%\H(DYO="!$<F%F="(I(#\^/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X*("`\
M+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`\=&0@;F]W<F%P/2)N;W=R87`B(&-L
M87-S/2)L969T06QI9VXB/@H\/W!H<"!I9B`H)&-O;F9;)W5S97(G75LG86QL
M;W=?9F]L9&5R<R==*3H@/SX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E
M="@G(R<L(%\H(DUO=F4@=&\@9F]L9&5R(BDL("=W:61G970G+"`G)RP@(E1R
M86YS9F5R*"=M;W9E7VUE<W-A9V4G+"(@+B`D;F%V7VED("X@(BD[(')E='5R
M;B!F86QS93LB+"!?*")-;W9E(BDL('1R=64I(#\^('P*("`@(#P_<&AP(&5C
M:&\@2&]R9&4Z.G=I9&=E="@G(R<L(%\H(D-O<'D@=&\@9F]L9&5R(BDL("=W
M:61G970G+"`G)RP@(E1R86YS9F5R*"=C;W!Y7VUE<W-A9V4G+"(@+B`D;F%V
M7VED("X@(BD[(')E='5R;B!F86QS93LB+"!?*")#;W!Y(BDL('1R=64I(#\^
M"B`@("`\<V5L96-T(&YA;64](G1A<F=E=#P_<&AP(&5C:&\@)&YA=E]I9"`_
M/B(@;VYC:&%N9V4](G5P9&%T949O;&1E<G,H/#]P:'`@96-H;R`D;F%V7VED
M(#\^*3LB/@H@("`@("`\/W!H<"!E8VAO("1O<'1I;VYS(#\^"B`@("`\+W-E
M;&5C=#X*/#]P:'`@96YD:68[(#\^"B`@/"]T9#X*("`\=&0@=VED=&@](C8U
M)2(@8VQA<W,](G)I9VAT06QI9VXB(&YO=W)A<#TB;F]W<F%P(CX*("`@(#P_
M<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="@D;6%I;&)O>%]U<FPL('-P<FEN=&8H
M7R@B0F%C:R!T;R`E<R(I+"`D<&%G95]L86)E;"DL("=W:61G970G+"`G)RP@
M)R<L('-P<FEN=&8H7R@B0F%C7VL@=&\@)7,B*2P@)'!A9V5?;&%B96PI+"!T
M<G5E*2`_/B9N8G-P.R9N8G-P.PH\/W!H<"!I9B`H(65M<'1Y*"1P<F5V7W5R
M;"DI.B`_/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ;&EN:R@D<')E=E]U<FPL
M(%\H(E!R979I;W5S($UE<W-A9V4B*2P@)R<L("<G+"`G)RP@)R<L("<\)RP@
M96UP='DH)&YA=F)A<E]I;F-L=61E9"D@/R!A<G)A>2@G:60G(#T^("=P<F5V
M)RD@.B!A<G)A>2@I*2`N($AO<F1E.CII;6<H)VYA=B]L969T+G!N9R<L("<\
M)RP@87)R87DH)W=I9'1H)R`]/B`G,38G+"`G:&5I9VAT)R`]/B`G,38G+"`G
M86QI9VXG(#T^("=M:61D;&4G*2P@)')E9VES=')Y+3YG971);6%G941I<B@G
M:&]R9&4G*2D@/SX\+V$^"CP_<&AP(&5L<V4Z(#\^"B`@("`\/W!H<"!E8VAO
M($AO<F1E.CII;6<H)VYA=B]L969T+6=R97DN<&YG)RP@)R<L("=W:61T:#TB
M,38B(&AE:6=H=#TB,38B(&%L:6=N/2)M:61D;&4B)RP@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*2D@/SX*/#]P:'`@96YD:68[(#\^"CP_<&AP
M(&EF("@A96UP='DH)&YE>'1?=7)L*2DZ(#\^"B`@("`\/W!H<"!E8VAO($AO
M<F1E.CIL:6YK*"1N97AT7W5R;"P@7R@B3F5X="!-97-S86=E(BDL("<G+"`G
M)RP@)R<L("<G+"`G/B<L(&5M<'1Y*"1N879B87)?:6YC;'5D960I(#\@87)R
M87DH)VED)R`]/B`G;F5X="<I(#H@87)R87DH*2D@+B!(;W)D93HZ:6UG*"=N
M878O<FEG:'0N<&YG)RP@)SXG+"!A<G)A>2@G=VED=&@G(#T^("<Q-B<L("=H
M96EG:'0G(#T^("<Q-B<L("=A;&EG;B<@/3X@)VUI9&1L92<I+"`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*/#]P:'`@96QS93H@
M/SX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G;F%V+W)I9VAT+6=R97DN
M<&YG)RP@)R<L("=W:61T:#TB,38B(&AE:6=H=#TB,38B(&%L:6=N/2)M:61D
M;&4B)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX*/#]P
M:'`@96YD:68[("1N879B87)?:6YC;'5D960@/2!T<G5E.R`_/@H@(#PO=&0^
M"CPO='(^"@```````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]M97-S86=E+VYA=F)A<E]A
M8W1I;VYS+FEN8P`````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S`S,``Q,#0Q-S,V,C<V
M-@`P,C0S,C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/'1R/@H\=&0@8V]L<W!A;CTB,R(@8VQA<W,](F-O;G1R;VP@;&5F
M=$%L:6=N(CX*/#]P:'`@:68@*"1I;7!?:&5A9&5R<RT^9V5T1FQA9R@G9&5L
M971E9"<I*3H@/SX*/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*%5T:6PZ.F%D
M9%!A<F%M971E<B@D<V5L9E]L:6YK+"`G86-T:6]N240G+"`G=6YD96QE=&5?
M;65S<V%G92<I+"!?*")5;F1E;&5T92(I+"`G=VED9V5T)RP@)R<L("<G+"!?
M*")5;F1E;&5T92(I+"!T<G5E*2`_/@H\/W!H<"!E;'-E.B`_/@H\/W!H<"!E
M8VAO($AO<F1E.CIW:61G970H571I;#HZ861D4&%R86UE=&5R*"1S96QF7VQI
M;FLL("=A8W1I;VY)1"<L("=D96QE=&5?;65S<V%G92<I+"!?*")$96QE=&4B
M*2P@)W=I9&=E="<L("<G+"`D9&5L971E7W=A<FYI;F<L(%\H(E]$96QE=&4B
M*2P@=')U92D@/SX*/#]P:'`@96YD:68[(#\^"B!\(#P_<&AP(&5C:&\@2&]R
M9&4Z.G=I9&=E="A)35`Z.F-O;7!O<V5,:6YK*"1R97!L>5]A=71H;W(L(&%R
M<F%Y*"=A8W1I;VY)1"<@/3X@)W)E<&QY)RP@)VEN9&5X)R`]/B`D:6YD97@L
M("=I9&5N=&ET>2<@/3X@)&ED96YT:71Y+"`G87)R87E?:6YD97@G(#T^("1A
M<G)A>5]I;F1E>"DI+"!?*")297!L>2(I+"`G=VED9V5T)RP@)R<L("<G+"!?
M*")?4F5P;'DB*2P@=')U92D[(#\^"CP_<&AP(&EF("@A:7-?;G5L;"@D<F5P
M;'E?;&ES="DI.B`_/@H@?"`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H24U0
M.CIC;VUP;W-E3&EN:R@D<F5P;'E?;&ES="P@87)R87DH)V%C=&EO;DE$)R`]
M/B`G<F5P;'E?;&ES="<L("=I;F1E>"<@/3X@)&EN9&5X+"`G:61E;G1I='DG
M(#T^("1I9&5N=&ET>2P@)V%R<F%Y7VEN9&5X)R`]/B`D87)R87E?:6YD97@I
M*2P@7R@B4F5P;'D@=&\@3&ES="(I+"`G=VED9V5T)RP@)R<L("<G+"!?*")2
M97!L7WD@=&\@3&ES="(I+"!T<G5E*2`_/@H\/W!H<"!E;F1I9CL@/SX*/#]P
M:'`@:68@*"1S:&]W7W)E<&QY7V%L;"DZ(#\^"B!\(#P_<&AP(&5C:&\@2&]R
M9&4Z.G=I9&=E="A)35`Z.F-O;7!O<V5,:6YK*&%R<F%Y*"DL(&%R<F%Y*"=A
M8W1I;VY)1"<@/3X@)W)E<&QY7V%L;"<L("=I;F1E>"<@/3X@)&EN9&5X+"`G
M:61E;G1I='DG(#T^("1I9&5N=&ET>2P@)V%R<F%Y7VEN9&5X)R`]/B`D87)R
M87E?:6YD97@I*2P@7R@B4F5P;'D@=&\@06QL(BDL("=W:61G970G+"`G)RP@
M)R<L(%\H(E)E<&QY('1O(%]!;&PB*2P@=')U92D@/SX*/#]P:'`@96YD:68[
M(#\^"B!\(#P_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="A)35`Z.F-O;7!O<V5,
M:6YK*&%R<F%Y*"DL(&%R<F%Y*"=A8W1I;VY)1"<@/3X@)V9O<G=A<F0G+"`G
M:6YD97@G(#T^("1I;F1E>"P@)VED96YT:71Y)R`]/B`D:61E;G1I='DL("=A
M<G)A>5]I;F1E>"<@/3X@)&%R<F%Y7VEN9&5X*2DL(%\H(D9O<G=A<F0B*2P@
M)W=I9&=E="<L("<G+"`G)RP@7R@B1F]?<G=A<F0B*2P@=')U92D@/SX*('P@
M/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*$E-4#HZ8V]M<&]S94QI;FLH87)R
M87DH*2P@87)R87DH)V%C=&EO;DE$)R`]/B`G<F5D:7)E8W1?8V]M<&]S92<L
M("=I;F1E>"<@/3X@)&EN9&5X+"`G87)R87E?:6YD97@G(#T^("1A<G)A>5]I
M;F1E>"DI+"!?*")2961I<F5C="(I+"`G=VED9V5T)RP@)R<L("<G+"!?*")2
M961I<F5C7W0B*2P@=')U92D@/SX*/#]P:'`@:68@*&ES<V5T*"1I;7!?<V5A
M<F-H*2`F)B`A)&EM<%]S96%R8V@M/G-E87)C:$UB;WA)1"@I*3H@/SX*('P@
M/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*"1T:')E861?;&EN:RP@7R@B5FEE
M=R!4:')E860B*2P@)W=I9&=E="<L("<G+"`G)RP@7R@B7U9I97<@5&AR96%D
M(BDL('1R=64I(#\^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H)'-H;W=?
M8FQA8VML:7-T7VQI;FLI.B`_/@H@?"`\/W!H<"!E8VAO($AO<F1E.CIW:61G
M970H571I;#HZ861D4&%R86UE=&5R*"1S96QF7VQI;FLL("=A8W1I;VY)1"<L
M("=B;&%C:VQI<W0G*2P@7R@B0FQA8VML:7-T(BDL("=W:61G970G+"`G)RP@
M)R<L(%\H(E]";&%C:VQI<W0B*2P@=')U92D@/SX*/#]P:'`@96YD:68[(#\^
M"CP_<&AP(&EF("@D<VAO=U]W:&ET96QI<W1?;&EN:RDZ(#\^"B!\(#P_<&AP
M(&5C:&\@2&]R9&4Z.G=I9&=E="A5=&EL.CIA9&1087)A;65T97(H)'-E;&9?
M;&EN:RP@)V%C=&EO;DE$)RP@)W=H:71E;&ES="<I+"!?*")7:&ET96QI<W0B
M*2P@)W=I9&=E="<L("<G+"`G)RP@7R@B7U=H:71E;&ES="(I+"!T<G5E*2`_
M/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*&ES<V5T*"1S;W5R8V5?;&EN
M:RDI.B`_/@H@?"`\/W!H<"!E8VAO("1S;W5R8V5?;&EN:R`N("<@)R`_/@H\
M/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*"1C;VYF6R=U<V5R)UU;)V%L;&]W
M7W)E<W5M95]A;&PG72!\?"`H)&-O;F9;)W5S97(G75LG86QL;W=?<F5S=6UE
M7V%L;%]I;E]D<F%F=',G72`F)B`D;6%I;&)O>%]N86UE(#T]($E-4#HZ9F]L
M9&5R4')E9B@D<')E9G,M/F=E=%9A;'5E*"=D<F%F='-?9F]L9&5R)RDL('1R
M=64I*2!\?"`H)&EM<%]H96%D97)S+3YG971&;&%G*"=D<F%F="<I*2DZ(#\^
M"B!\(#P_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="A)35`Z.F-O;7!O<V5,:6YK
M*&%R<F%Y*"DL(&%R<F%Y*"=A8W1I;VY)1"<@/3X@)V1R869T)RP@)VUA:6QB
M;W@G(#T^("1M86EL8F]X7VYA;64L("=I;F1E>"<@/3X@)&EN9&5X+"`G87)R
M87E?:6YD97@G(#T^("1A<G)A>5]I;F1E>"DI+"!?*")297-U;64B*2P@)W=I
M9&=E="<L("<G+"`G)RP@7R@B4F5S=6UE(BDL('1R=64I(#\^"CP_<&AP(&5N
M9&EF.R`_/@H@?"`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H)'-A=F5?;&EN
M:RP@7R@B4V%V92!A<R(I+"`G=VED9V5T)RP@)R<L("<G+"!?*")385]V92!A
M<R(I+"`R*2`_/@H@?"`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H)'!R:6YT
M7VQI;FLL(%\H(E!R:6YT(BDL("=W:61G970G+"`G7V)L86YK)RP@)W!O<'5P
M*'1H:7,N:')E9BD[(')E='5R;B!F86QS93LG+"!?*")?4')I;G0B*2P@=')U
M92D@/SX*/#]P:'`@:68@*"1C;VYF6R=S<&%M)UU;)W)E<&]R=&EN9R==("8F
M("@D8V]N9ELG<W!A;2==6R=S<&%M9F]L9&5R)UT@?'P@)&UA:6QB;WA?;F%M
M92`A/2!)35`Z.F9O;&1E<E!R968H)'!R969S+3YG971686QU92@G<W!A;5]F
M;VQD97(G*2P@=')U92DI*3H@/SX*('P@/#]P:'`@96-H;R!(;W)D93HZ=VED
M9V5T*"<C)RP@7R@B4F5P;W)T(&%S(%-P86TB*2P@)W=I9&=E="<L("<G+"`B
M4W5B;6ET*"=S<&%M7W)E<&]R="<I.R!R971U<FX@9F%L<V4[(BP@7R@B4F5P
M;W)T(&%S(%-P86TB*2P@=')U92D@/SX*/#]P:'`@96YD:68[(#\^"CP_<&AP
M(&EF("@D8V]N9ELG;F]T<W!A;2==6R=R97!O<G1I;F<G72`F)B`H(21C;VYF
M6R=N;W1S<&%M)UU;)W-P86UF;VQD97(G72!\?"`D;6%I;&)O>%]N86UE(#T]
M($E-4#HZ9F]L9&5R4')E9B@D<')E9G,M/F=E=%9A;'5E*"=S<&%M7V9O;&1E
M<B<I+"!T<G5E*2DI.B`_/@H@?"`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H
M)R,G+"!?*")297!O<G0@87,@26YN;V-E;G0B*2P@)W=I9&=E="<L("<G+"`B
M4W5B;6ET*"=N;W1S<&%M7W)E<&]R="<I.R!R971U<FX@9F%L<V4[(BP@7R@B
M4F5P;W)T(&%S($EN;F]C96YT(BDL('1R=64I(#\^"CP_<&AP(&5N9&EF.R`_
M/@H\+W1D/@H\+W1R/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E
M<R]M97-S86=E+VYA=F)A<E]T;W`N:6YC````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C0R-P`Q,#0Q-S,V,C<V-@`P,C,T-C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/&9O<FT@;65T:&]D/2)G970B(&YA
M;64](FUE<W-A9V5S(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=M97-S86=E+G!H<"<I(#\^(CX*/#]P:'`@571I;#HZ<&9O
M<FU);G!U="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G1A<F=E
M=$UB;W@B('9A;'5E/2(B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(F%C=&EO;DE$(B!V86QU93TB(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)T:&ES;6%I;&)O>"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D;6%I;&)O>%]N86UE*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB<W1A<G0B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&US9VEN9&5X*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB:6YD97@B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&EN9&5X*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB;F5W36)O>"(@=F%L=64](C`B("\^"@H\=&%B;&4@8F]R9&5R/2(P(B!C
M96QL<&%D9&EN9STB,"(@8V5L;'-P86-I;F<](C`B(&%L:6=N/2)C96YT97(B
M('=I9'1H/2(Q,#`E(CX*(#QT<CX*("`\=&0@8VQA<W,](FAE861E<B!L969T
M06QI9VXB/@H\/W!H<`H@("`@+RH@268@=&AI<R!I<R!A('-E87)C:"!M86EL
M8F]X+"!D:7-P;&%Y(&$@;&EN:R!T;R!T:&4@<&%R96YT(&UA:6QB;W@@;V8@
M=&AE"B`@("`@*B!M97-S86=E(&EN('1H92!H96%D97(N("HO"B`@("`D:&5A
M9&5R7VQA8F5L(#T@:'1M;'-P96-I86QC:&%R<R@D<&%G95]L86)E;"D["B`@
M("!I9B`H:7-S970H)&EM<%]S96%R8V@I("8F("1I;7!?<V5A<F-H+3YI<U9)
M3D)/6$9O;&1E<B@I*2!["B`@("`@("`@)&AE861E<E]L86)E;"`N/2`G(%LG
M("X@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G;6%I;&)O>"YP:'`G*2P@)VUA:6QB;W@G+"`D;6%I;&)O
M>%]N86UE*2D@+B!)35`Z.F1I<W!L87E&;VQD97(H)&UA:6QB;WA?;F%M92D@
M+B`G/"]A/ETG.PH@("`@?0H@("`@<')I;G1F*%\H(B5S.B`E<R`H)60F;F)S
M<#MO9B9N8G-P.R5D*2(I+"`D:&5A9&5R7VQA8F5L+"`D<VAO<G1S=6(L("1M
M<V=I;F1E>"P@)&US9V-O=6YT*3L@96-H;R`G)FYB<W`[)FYB<W`[)R`N("1S
M=&%T=7,*/SX*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*/'1A8FQE(&)O<F1E
M<CTB,"(@86QI9VX](F-E;G1E<B(@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG
M/2(P(B!C96QL<&%D9&EN9STB,B(^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+VUE<W-A9V4O:F%V87-C<FEP="YI
M;F,``````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,C4T`#$P-#$W,S8R-S8V`#`R
M,S4P-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"B\O(%-E
M="!U<"!L969T("@S-RD@86YD(')I9VAT("@S.2D@87)R;W=S('1O(&=O('1O
M('1H92!P<F5V:6]U<R]N97AT"B\O(&UE<W-A9V4N"G-E=$ME>6)I;F1I;F<H
M,S<L("=A<G)O=TAA;F1L97(G*3L*<V5T2V5Y8FEN9&EN9R@S.2P@)V%R<F]W
M2&%N9&QE<B<I.PH*9G5N8W1I;VX@87)R;W=(86YD;&5R*&4L(&ME>2D*>PH@
M("`@:68@*"%D;V-U;65N="YG971%;&5M96YT0GE)9"!\?"!E+F%L=$ME>2!\
M?"!E+G-H:69T2V5Y('Q\(&4N8W1R;$ME>2D@>PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("!V87(@;&]C.PH@("`@:68@*&ME>2`]/2`S-RD@
M>PH@("`@("`@(&QO8R`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=P<F5V
M)RD["B`@("!](&5L<V4@:68@*&ME>2`]/2`S.2D@>PH@("`@("`@(&QO8R`]
M(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=N97AT)RD["B`@("!]"@H@("`@
M:68@*&QO8RD@>PH@("`@("`@(&1O8W5M96YT+FQO8V%T:6]N+FAR968@/2!L
M;V,N:')E9CL*("`@('T*("`@(')E='5R;B!T<G5E.PI]"@H\/W!H<"!I9B`H
M)%]315-324].6R=I;7`G75LG8F%S95]P<F]T;V-O;"==("$]("=P;W`S)RDZ
M(#\^"F9U;F-T:6]N(&9L86=-97-S86=E*&9O<FTI"GL*("`@(&EF("@H9F]R
M;2`]/2`Q("8F(&1O8W5M96YT+FUE<W-A9V5S+F9L86<Q+F]P=&EO;G-;9&]C
M=6UE;G0N;65S<V%G97,N9FQA9S$N<V5L96-T961);F1E>%TN=F%L=64@(3T@
M(B(I('Q\"B`@("`@("`@*&9O<FT@/3T@,B`F)B!D;V-U;65N="YM97-S86=E
M<RYF;&%G,BYO<'1I;VYS6V1O8W5M96YT+FUE<W-A9V5S+F9L86<R+G-E;&5C
M=&5D26YD97A=+G9A;'5E("$]("(B*2D@>PH@("`@("`@(&EF("AF;W)M(#T]
M(#$I('L*("`@("`@("`@("`@9&]C=6UE;G0N;65S<V%G97,N9FQA9RYV86QU
M92`](&1O8W5M96YT+FUE<W-A9V5S+F9L86<Q+F]P=&EO;G-;9&]C=6UE;G0N
M;65S<V%G97,N9FQA9S$N<V5L96-T961);F1E>%TN=F%L=64["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@9&]C=6UE;G0N;65S<V%G97,N9FQA9RYV
M86QU92`](&1O8W5M96YT+FUE<W-A9V5S+F9L86<R+F]P=&EO;G-;9&]C=6UE
M;G0N;65S<V%G97,N9FQA9S(N<V5L96-T961);F1E>%TN=F%L=64["B`@("`@
M("`@?0H*("`@("`@("!D;V-U;65N="YM97-S86=E<RYA8W1I;VY)1"YV86QU
M92`]("=F;&%G7VUE<W-A9V4G.PH@("`@("`@(&1O8W5M96YT+FUE<W-A9V5S
M+G-U8FUI="@I.PH@("`@?0I]"CP_<&AP(&5N9&EF.R`_/@H*9G5N8W1I;VX@
M5')A;G-F97(H86-T240L(&9O<FTI"GL*("`@(&EF("AF;W)M(#T](#$I('L*
M("`@("`@("!D;V-U;65N="YM97-S86=E<RYT87)G971-8F]X+G9A;'5E(#T@
M9&]C=6UE;G0N;65S<V%G97,N=&%R9V5T,2YO<'1I;VYS6V1O8W5M96YT+FUE
M<W-A9V5S+G1A<F=E=#$N<V5L96-T961);F1E>%TN=F%L=64["B`@("!](&5L
M<V4@>PH@("`@("`@(&1O8W5M96YT+FUE<W-A9V5S+G1A<F=E=$UB;W@N=F%L
M=64@/2!D;V-U;65N="YM97-S86=E<RYT87)G970R+F]P=&EO;G-;9&]C=6UE
M;G0N;65S<V%G97,N=&%R9V5T,BYS96QE8W1E9$EN9&5X72YV86QU93L*("`@
M('T*"B`@("`O+R!#:&5C:R!F;W(@82!M86EL8F]X(&%C='5A;&QY(&)E:6YG
M('-E;&5C=&5D+@H@("`@:68@*&1O8W5M96YT+FUE<W-A9V5S+G1A<F=E=$UB
M;W@N=F%L=64@/3T@)RIN97<J)RD@>PH@("`@("`@('9A<B!N97=&;VQD97(@
M/2!W:6YD;W<N<')O;7!T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U
M(&%R92!C;W!Y:6YG+VUO=FEN9R!T;R!A(&YE=R!F;VQD97(N(BDI("X@)UQN
M)R`N(&%D9'-L87-H97,H7R@B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!F;VQD97(Z(BDI(#\^7&XG+"`G)RD["B`@("`@("`@:68@*&YE=T9O
M;&1E<B`A/2!N=6QL("8F(&YE=T9O;&1E<B`A/2`G)RD@>PH@("`@("`@("`@
M("!D;V-U;65N="YM97-S86=E<RYN97=-8F]X+G9A;'5E(#T@,3L*("`@("`@
M("`@("`@9&]C=6UE;G0N;65S<V%G97,N=&%R9V5T36)O>"YV86QU92`](&YE
M=T9O;&1E<CL*("`@("`@("`@("`@9&]C=6UE;G0N;65S<V%G97,N86-T:6]N
M240N=F%L=64@/2!A8W1)1#L*("`@("`@("`@("`@9&]C=6UE;G0N;65S<V%G
M97,N<W5B;6ET*"D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!I
M9B`H9&]C=6UE;G0N;65S<V%G97,N=&%R9V5T36)O>"YV86QU92`]/2`G)RD@
M>PH@("`@("`@("`@("!W:6YD;W<N86QE<G0H)SP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")9;W4@;75S="!S96QE8W0@82!T87)G970@;6%I;&)O>"!F:7)S
M="XB*2D@/SXG*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!D;V-U
M;65N="YM97-S86=E<RYA8W1I;VY)1"YV86QU92`](&%C=$E$.PH@("`@("`@
M("`@("!D;V-U;65N="YM97-S86=E<RYS=6)M:70H*3L*("`@("`@("!]"B`@
M("!]"GT*"F9U;F-T:6]N(%-U8FUI="AA8W1)1"D*>PH@("`@:68@*&%C=$E$
M(#T]("=S<&%M7W)E<&]R="<I('L*("`@("`@("!I9B`H(7=I;F1O=RYC;VYF
M:7)M*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@<W!A;3\B*2D@/SXG
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H@("`@
M:68@*&%C=$E$(#T]("=N;W1S<&%M7W)E<&]R="<I('L*("`@("`@("!I9B`H
M(7=I;F1O=RYC;VYF:7)M*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(')E<&]R="!T:&ES(&UE<W-A9V4@87,@
M:6YN;V-E;G0_(BDI(#\^)RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*("`@('T*("`@(&1O8W5M96YT+FUE<W-A9V5S+F%C=&EO;DE$+G9A
M;'5E(#T@86-T240["B`@("!D;V-U;65N="YM97-S86=E<RYS=6)M:70H*3L*
M?0H*9G5N8W1I;VX@=7!D871E1F]L9&5R<RAF;W)M*0I["B`@("!I9B`H9F]R
M;2`]/2`Q*2!["B`@("`@("`@9&]C=6UE;G0N;65S<V%G97,N=&%R9V5T,BYS
M96QE8W1E9$EN9&5X(#T@9&]C=6UE;G0N;65S<V%G97,N=&%R9V5T,2YS96QE
M8W1E9$EN9&5X.PH@("`@?2!E;'-E('L*("`@("`@("!D;V-U;65N="YM97-S
M86=E<RYT87)G970Q+G-E;&5C=&5D26YD97@@/2!D;V-U;65N="YM97-S86=E
M<RYT87)G970R+G-E;&5C=&5D26YD97@["B`@("!]"GT*"B\O("TM/@H\+W-C
M<FEP=#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]M97-S86=E+VAE861E<G,N:6YC
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S,R-P`Q,#0Q-S,V,C<V-@`P
M,C(W-3,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`@)&D@/2`P.R`_/@H\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS
M<&%C:6YG/2(P(CX*/#]P:'`@:68@*"1A;&Q?:&5A9&5R<RDZ(#\^"B`@/#]P
M:'`@9F]R96%C:"`H)&9U;&Q?:"!A<R`D:&5A9"`]/B`D=F%L*3H@/SX\='(^
M"B`@/#]P:'`@:68@*&EN7V%R<F%Y*"1H96%D+"`D8F%S:6-?:&5A9&5R<RDI
M("1V86P@/2`D:6UP7VAE861E<G,M/F=E=%9A;'5E*"1H96%D*3L@/SX*("`\
M=&0@8VQA<W,](FET96T\/W!H<"!E8VAO("1I(#\^(')I9VAT06QI9VX@;F]W
M<F%P(B!V86QI9VX](G1O<"(^/'-T<F]N9SX\/W!H<"!E8VAO("1H96%D(#\^
M.CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@/'1D(&-L87-S/2)I=&5M/#]P:'`@
M96-H;R`D:2`_/B!M<V=H96%D97(B('=I9'1H/2(Q,#`E(CX\/W!H<"!E8VAO
M("1V86P@/SX\+W1D/@H\+W1R/CP_<&AP("1I(#T@*"1I("L@,2D@)2`R.R`_
M/@H@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"CP_<&AP(&5L<V4Z(#\^"B`@/#]P
M:'`@9F]R96%C:"`H)&)A<VEC7VAE861E<G,@87,@)&AE860@/3X@)'-T<BDZ
M(#\^"B`@("`\/W!H<"!I9B`H)'9A;"`]("1I;7!?:&5A9&5R<RT^9V5T5F%L
M=64H)&AE860I*3H@/SX*/'1R/@H@(#QT9"!C;&%S<STB:71E;3P_<&AP(&5C
M:&\@)&D@/SX@<FEG:'1!;&EG;B!N;W=R87`B('9A;&EG;CTB=&]P(CX\<W1R
M;VYG/CP_<&AP(&5C:&\@)'-T<B`_/CH\+W-T<F]N9SXF;F)S<#L\+W1D/@H@
M(#QT9"!C;&%S<STB:71E;3P_<&AP(&5C:&\@)&D@/SX@;7-G:&5A9&5R(B!W
M:61T:#TB,3`P)2(^/#]P:'`@96-H;R`D=F%L(#\^/"]T9#X*/"]T<CX*("`@
M(#P_<&AP("1I(#T@*"1I("L@,2D@)2`R.R!E;F1I9CL@/SX*("`\/W!H<"!E
M;F1F;W)E86-H.R`_/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*"%E;7!T
M>2@D=7-E<E]H9')S*2`F)B!C;W5N="@D8W5S=&]M7VAD<G,I(#X@,"DZ(#\^
M"B`@/#]P:'`@9F]R96%C:"`H)&-U<W1O;5]H9')S(&%S("1H96%D(#T^("1V
M86PI.B`_/CQT<CX*("`\=&0@8VQA<W,](FET96T\/W!H<"!E8VAO("1I(#\^
M(')I9VAT06QI9VX@;F]W<F%P(B!V86QI9VX](G1O<"(^/'-T<F]N9SX\/W!H
M<"!E8VAO("1H96%D(#\^.CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@/'1D(&-L
M87-S/2)I=&5M/#]P:'`@96-H;R`D:2`_/B!M<V=H96%D97(B('=I9'1H/2(Q
M,#`E(CX\/W!H<"!E8VAO("1V86P@/SX\+W1D/@H\+W1R/CP_<&AP("1I(#T@
M*"1I("L@,2D@)2`R.R`_/@H@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"CP_<&AP
M(&5N9&EF.R`_/@H\/W!H<"!I9B`H)&QI<W1?:&5A9&5R<R`F)B`D;&ES=%]E
M>&ES=',I.B`_/@H@(#P_<&AP(&9O<F5A8V@@*"1I;7!?:&5A9&5R<RT^;&ES
M=$AE861E<G,H*2!A<R`D:&5A9"`]/B`D<W1R*3H@/SX*("`@(#P_<&AP(&EF
M("@D=F%L(#T@)&EM<%]H96%D97)S+3YG971686QU92@D:&5A9"DI.B`_/@H\
M='(^"B`@/'1D(&-L87-S/2)I=&5M/#]P:'`@96-H;R`D:2`_/B!R:6=H=$%L
M:6=N(&YO=W)A<"(@=F%L:6=N/2)T;W`B/CQS=')O;F<^/#]P:'`@96-H;R`D
M<W1R(#\^.CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@/'1D(&-L87-S/2)I=&5M
M/#]P:'`@96-H;R`D:2`_/B!M<V=H96%D97(B('=I9'1H/2(Q,#`E(CX\/W!H
M<"!E8VAO("1V86P@/SX\+W1D/@H\+W1R/@H@("`@/#]P:'`@)&D@/2`H)&D@
M*R`Q*2`E(#([(&5N9&EF.R`_/@H@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"CP_
M<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H)'9A;"`]("1I;7!?:&5A9&5R<RT^
M9V5T5F%L=64H)W!R:6]R:71Y)RDI.B`_/CQT<CX*("`\=&0@8VQA<W,](FET
M96T\/W!H<"!E8VAO("1I(#\^(')I9VAT06QI9VXB('9A;&EG;CTB=&]P(CX\
M<W1R;VYG/CP_<&AP(&5C:&\@7R@B4')I;W)I='DB*2`_/CH\+W-T<F]N9SXF
M;F)S<#L\+W1D/@H@(#QT9"!C;&%S<STB:71E;3P_<&AP(&5C:&\@)&D@/SX@
M;7-G:&5A9&5R(B!W:61T:#TB,3`P)2(^/#]P:'`@96-H;R`D=F%L(#\^/"]T
M9#X*/"]T<CX\/W!H<"`D:2`]("@D:2`K(#$I("4@,CL@96YD:68[(#\^"CP_
M<&AP(&EF("@D<VAO=U]P87)T<R!\?"`H)&1O=VYL;V%D86QL7VQI;FL@)B8@
M(21P<FEN=&5R7V9R:65N9&QY*2DZ(#\^"CQT<CX*("`\=&0@8VQA<W,](FET
M96T\/W!H<"!E8VAO("1I(#\^(')I9VAT06QI9VXB('9A;&EG;CTB=&]P(CX\
M<W1R;VYG/CP_<&AP(&5C:&\@7R@B4&%R="AS*2(I(#\^.CPO<W1R;VYG/B9N
M8G-P.SPO=&0^"CP_<&AP(&EF("@D<VAO=U]P87)T<RDZ(#\^"B`@/'1D(&-L
M87-S/2)I=&5M/#]P:'`@96-H;R`D:2`_/B!M<V=H96%D97(B('=I9'1H/2(Q
M,#`E(CX\=&%B;&4@8V5L;'-P86-I;F<](C(B/CP_<&AP(&5C:&\@)&%T=&%C
M:&UE;G1S(#\^/"]T86)L93X\+W1D/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@
M:68@*"1D;W=N;&]A9&%L;%]L:6YK("8F("$D<')I;G1E<E]F<FEE;F1L>2DZ
M(#\^"CP_<&AP(&EF("@D<VAO=U]P87)T<RDZ(#\^"CQT<CX*("`\=&0@8VQA
M<W,](FET96T\/W!H<"!E8VAO("1I(#\^(')I9VAT06QI9VXB('9A;&EG;CTB
M=&]P(CX\+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`\=&0@8VQA<W,](FET96T\
M/W!H<"!E8VAO("1I(#\^(&US9VAE861E<B(@=VED=&@](C$P,"4B/CP_<&AP
M(&5C:&\@2&]R9&4Z.FQI;FLH)&1O=VYL;V%D86QL7VQI;FLL(%\H(D1O=VYL
M;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*2(I*2`N(%\H(D1O
M=VYL;V%D($%L;"!!='1A8VAM96YT<R`H:6X@+GII<"!F:6QE*2(I("X@)R`G
M("X@2&]R9&4Z.FEM9R@G8V]M<')E<W-E9"YP;F<G+"!?*")$;W=N;&]A9"!!
M;&P@071T86-H;65N=',@*&EN("YZ:7`@9FEL92DB*2P@)R<L("1R96=I<W1R
M>2T^9V5T26UA9V5$:7(H)VAO<F1E)RD@+B`G+VUI;64G*2`_/CPO83X\+W1D
M/@H\/W!H<"!E;F1I9CL@/SX*/"]T<CX*/#]P:'`@)&D@/2`H)&D@*R`Q*2`E
M(#([(&5N9&EF.R`_/@H\/W!H<"!I9B`H(21P<FEN=&5R7V9R:65N9&QY*3H@
M/SX*/'1R/@H@(#QT9"!C;&%S<STB:71E;3P_<&AP(&5C:&\@)&D@/SX@<FEG
M:'1!;&EG;B(@=F%L:6=N/2)T;W`B/CQS=')O;F<^/#]P:'`@96-H;R!?*")(
M96%D97)S(BD@/SXZ/"]S=')O;F<^)FYB<W`[/"]T9#X*("`\=&0@8VQA<W,]
M(FET96T\/W!H<"!E8VAO("1I(#\^(&US9VAE861E<B(@=VED=&@](C$P,"4B
M/@H@("`@/#]P:'`@:68@*"1A;&Q?:&5A9&5R<R!\?"`D;&ES=%]H96%D97)S
M*3H@/SX*("`@("`@/#]P:'`@96-H;R!(;W)D93HZ;&EN:R@D:&5A9&5R<U52
M3"D@+B!?*")3:&]W($QI;6ET960@2&5A9&5R<R(I(#\^/"]A/@H@("`@/#]P
M:'`@96YD:68[(#\^"B`@("`\/W!H<"!I9B`H(21A;&Q?:&5A9&5R<RDZ(#\^
M"B`@("`@(#P_<&AP(&EF("@D;&ES=%]H96%D97)S*3H@/SX*("`@("`@)FYB
M<W`[?"9N8G-P.PH@("`@("`\/W!H<"!E;F1I9CL@/SX*("`@("`@/#]P:'`@
M96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H)&AE861E<G-5
M4DPL("=S:&]W7V%L;%]H96%D97)S)RP@,2DI("X@7R@B4VAO=R!!;&P@2&5A
M9&5R<R(I(#\^/"]A/@H@("`@/#]P:'`@96YD:68[(#\^"B`@("`\/W!H<"!I
M9B`H)&QI<W1?97AI<W1S("8F("$D;&ES=%]H96%D97)S*3H@/SX*("`@("`@
M)FYB<W`[?"9N8G-P.R9N8G-P.SP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH571I
M;#HZ861D4&%R86UE=&5R*"1H96%D97)S55),+"`G<VAO=U]L:7-T7VAE861E
M<G,G+"`Q*2D@+B!?*")3:&]W($UA:6QI;F<@3&ES="!);F9O<FUA=&EO;B(I
M(#\^/"]A/@H@("`@/#]P:'`@96YD:68[(#\^"B`@/"]T9#X*/"]T<CX*/#]P
M:'`@96YD:68[(#\^"CPO=&%B;&4^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]F
M:6QT97)S+P``````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<V-@`P,C`V-C,`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O=&5M<&QA=&5S+V9I;'1E<G,O<')E9G,N:6YC````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`V-#,V`#$P-#$W,S8R-S8V`#`R,C4P,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\9F]R;2!M
M971H;V0](G!O<W0B(&YA;64](G!R969S(B!A8W1I;VX](CP_<&AP(&5C:&\@
M2&]R9&4Z.G-E;&95<FPH*2`_/B(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H
M*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L
M=64](G5P9&%T95]P<F5F<R(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB9W)O=7`B('9A;'5E/2(\/W!H<"!E8VAO("1G<F]U<"`_/B(@+SX*/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB87!P(B!V86QU93TB/#]P:'`@96-H
M;R`D87!P(#\^(B`O/@H*/&1I=B!C;&%S<STB:&5A9&5R(CX*("`\/W!H<"!0
M<F5F<U]523HZ9V5N97)A=&5.879I9V%T:6]N0V5L;"@G9FEL=&5R<R<I(#\^
M"B`@/#]P:'`@96-H;R!?*")&:6QT97(@4V5T=&EN9W,B*2`_/@H\+V1I=CX*
M/'`@8VQA<W,](FET96TB/@H\/W!H<"!I9B`H(65M<'1Y*"1F:6QT97)S7VQI
M;FLI*3H@/SX*/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=F:6QT97)S+G!N9R<L
M(%\H(D5D:70@1FEL=&5R<R(I*2`N("<F;F)S<#LF;F)S<#LG("X@2&]R9&4Z
M.FQI;FLH2&]R9&4Z.G5R;"@D9FEL=&5R<U]L:6YK*2P@7R@B161I="!Y;W5R
M(&9I;'1E<B!R=6QE<R(I*2`N(%\H(D5D:70@>6]U<B!F:6QT97(@<G5L97,B
M*2`_/CPO83XF;F)S<#L*/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G+"`G
M9FEL=&5R+65D:70M<G5L97,G*2`_/CQB<B`O/@H\/W!H<"!E;F1I9CL@/SX*
M"CP_<&AP(&EF("@A96UP='DH)&)L86-K;&ES=%]L:6YK*2DZ(#\^"CP_<&AP
M(&5C:&\@2&]R9&4Z.FEM9R@G9FEL=&5R<RYP;F<G+"!?*")%9&ET($)L86-K
M;&ES="(I*2`N("<F;F)S<#LF;F)S<#LG("X@2&]R9&4Z.FQI;FLH2&]R9&4Z
M.G5R;"@D8FQA8VML:7-T7VQI;FLI+"!?*")%9&ET('EO=7(@8FQA8VML:7-T
M(BDI("X@7R@B161I="!Y;W5R(&)L86-K;&ES="(I(#\^/"]A/B9N8G-P.PH\
M/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEM<"<L("=F:6QT97(M961I="UB;&%C
M:VQI<W0G*2`_/CQB<B`O/@H\/W!H<"!E;F1I9CL@/SX*"CP_<&AP(&EF("@A
M96UP='DH)'=H:71E;&ES=%]L:6YK*2DZ(#\^"CP_<&AP(&5C:&\@2&]R9&4Z
M.FEM9R@G9FEL=&5R<RYP;F<G+"!?*")%9&ET(%=H:71E;&ES="(I*2`N("<F
M;F)S<#LF;F)S<#LG("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.G5R;"@D=VAI=&5L
M:7-T7VQI;FLI+"!?*")%9&ET('EO=7(@=VAI=&5L:7-T(BDI("X@7R@B161I
M="!Y;W5R('=H:71E;&ES="(I(#\^/"]A/B9N8G-P.PH\/W!H<"!E8VAO($AE
M;'`Z.FQI;FLH)VEM<"<L("=F:6QT97(M961I="UW:&ET96QI<W0G*2`_/CQB
M<B`O/@H\/W!H<"!E;F1I9CL@/SX*/"]P/@H*/#]P:'`@:68@*"$D;&]G:6Y?
M;&]C:V5D('Q\("$D9&ES<&QA>5]L;V-K960@?'P@(21M96YU:71E;5]L;V-K
M960I.B`_/@H\8G(@+SX*/&@Q(&-L87-S/2)H96%D97(B/@H@(#P_<&AP(&5C
M:&\@7R@B1FEL=&5R($]P=&EO;G,B*2`_/@H\+V@Q/@H\<"!C;&%S<STB:71E
M;2(@<W1Y;&4](G!A9&1I;F<Z,7!X.R(^"CP_<&AP(&EF("@A)&QO9VEN7VQO
M8VME9"DZ(#\^"CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@:60](F9I;'1E<E]L
M;V=I;B(@;F%M93TB9FEL=&5R7VQO9VEN(B`\/W!H<"!E8VAO("@D<')E9G,M
M/F=E=%9A;'5E*"=F:6QT97)?;VY?;&]G:6XG*2D@/R`B8VAE8VME9#U<(F-H
M96-K961<(B(@.B`B(B`_/B`O/B9N8G-P.PH\/W!H<"!E8VAO($AO<F1E.CIL
M86)E;"@G9FEL=&5R7VQO9VEN)RP@7R@B07!P;'D@9FEL=&5R(')U;&5S('5P
M;VX@;&]G9VEN9R!O;C\B*2D@/SXF;F)S<#L*/#]P:'`@96-H;R!(96QP.CIL
M:6YK*"=I;7`G+"`G9FEL=&5R+6]N+6QO9VEN)RD@/SX\8G(@+SX*/#]P:'`@
M96YD:68[(#\^"@H\/W!H<"!I9B`H(21D:7-P;&%Y7VQO8VME9"DZ(#\^"CQI
M;G!U="!T>7!E/2)C:&5C:V)O>"(@:60](F9I;'1E<E]D:7-P;&%Y(B!N86UE
M/2)F:6QT97)?9&ES<&QA>2(@/#]P:'`@96-H;R`H)'!R969S+3YG971686QU
M92@G9FEL=&5R7V]N7V1I<W!L87DG*2D@/R`B8VAE8VME9#U<(F-H96-K961<
M(B(@.B`B(B`_/B`O/B9N8G-P.PH\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G
M9FEL=&5R7V1I<W!L87DG+"!?*")!<'!L>2!F:6QT97(@<G5L97,@=VAE;F5V
M97(@24Y"3U@@:7,@9&ES<&QA>65D/R(I*2`_/B9N8G-P.PH\/W!H<"!E8VAO
M($AE;'`Z.FQI;FLH)VEM<"<L("=F:6QT97(M;VXM9&ES<&QA>2<I(#\^/&)R
M("\^"CP_<&AP(&5N9&EF.R`_/@H*/#]P:'`@:68@*"$D86YY;6%I;&)O>%]L
M;V-K960I.B`_/@H\:6YP=70@='EP93TB8VAE8VMB;W@B(&ED/2)F:6QT97)?
M86YY7VUA:6QB;W@B(&YA;64](F9I;'1E<E]A;GE?;6%I;&)O>"(@/#]P:'`@
M96-H;R`H)'!R969S+3YG971686QU92@G9FEL=&5R7V%N>5]M86EL8F]X)RDI
M(#\@(F-H96-K960]7")C:&5C:V5D7"(B(#H@(B(@/SX@+SXF;F)S<#L*/#]P
M:'`@96-H;R!(;W)D93HZ;&%B96PH)V9I;'1E<E]A;GEM86EL8F]X)RP@7R@B
M06QL;W<@9FEL=&5R(')U;&5S('1O(&)E(&%P<&QI960@:6X@86YY(&UA:6QB
M;W@_(BDI(#\^)FYB<W`["CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@
M)V9I;'1E<BUA;GDM;6%I;&)O>"<I(#\^/&)R("\^"CP_<&AP(&5N9&EF.R`_
M/@H*/#]P:'`@:68@*"$D;65N=6ET96U?;&]C:V5D*3H@/SX*/&EN<'5T('1Y
M<&4](F-H96-K8F]X(B!I9#TB9FEL=&5R7VUE;G5I=&5M(B!N86UE/2)F:6QT
M97)?;65N=6ET96TB(#P_<&AP(&5C:&\@*"1P<F5F<RT^9V5T5F%L=64H)V9I
M;'1E<E]M96YU:71E;2<I*2`_(")C:&5C:V5D/5PB8VAE8VME9%PB(B`Z("(B
M(#\^("\^)FYB<W`["CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=F:6QT97)?
M;65N=6ET96TG+"!?*")3:&]W('1H92!F:6QT97(@:6-O;B!O;B!T:&4@;65N
M=6)A<C\B*2D@/SXF;F)S<#L*/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G
M+"`G9FEL=&5R+6UE;G5I=&5M)RD@/SX\8G(@+SX*/#]P:'`@96YD:68[(#\^
M"CPO<#X*"CQI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](G-A=F4B(&-L87-S
M/2)B=71T;VXB(&]N8VQI8VL](F1O8W5M96YT+F9I;'1E<G!R969S+F%C=&EO
M;DE$+G9A;'5E/2=F:6QT97)?<')E9G-?=7!D871E)SMR971U<FX@=')U93LB
M('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-A=F4@3W!T:6]N<R(I(#\^(B`O/B9N
M8G-P.R9N8G-P.PH\:6YP=70@='EP93TB8G5T=&]N(B!N86UE/2)B86-K(B!C
M;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N="YL;V-A=&EO;BYH<F5F
M/2<\/W!H<"!E8VAO($E-4#HZ<')E9G-54DPH=')U92D@/SXG(B!V86QU93TB
M/#]P:'`@96-H;R!?*")2971U<FX@=&\@3W!T:6]N<R(I(#\^(B`O/@H\/W!H
M<"!E;F1I9CL@/SX*"CPO9F]R;3X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+W1E;7!L871E<R]F:6QT97)S+VYO=&%C=&EV92YI;F,`````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,30S,P`Q,#0Q-S,V,C<V-@`P,C,S-3``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/&1I=B!C
M;&%S<STB:&5A9&5R(CX*("`\/W!H<"!0<F5F<U]523HZ9V5N97)A=&5.879I
M9V%T:6]N0V5L;"@G9FEL=&5R<R<I(#\^"B`@/#]P:'`@96-H;R!?*")&:6QT
M97)S($Y/5"!!8W1I=F4B*2`_/@H\+V1I=CX*/'1A8FQE(&)O<F1E<CTB,"(@
M86QI9VX](F-E;G1E<B(@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(B!C
M96QL<&%D9&EN9STB,R(^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)I=&5M(CX*
M("`@("`@/'1A8FQE(&)O<F1E<CTB,"(^"B`@("`@("`@/'1R('9A;&EG;CTB
M=&]P(CX*("`@("`@("`@(#QT9"!C;&%S<STB:71E;2(^"B`@("`@("`@("`@
M("9N8G-P.SQS=')O;F<^/#]P:'`@96-H;R!?*")&:6QT97(@<W5P<&]R="!I
M<R!D:7-A8FQE9"!O;B!T:&ES('-Y<W1E;2XB*2`_/CPO<W1R;VYG/@H@("`@
M("`@("`@/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`\+W1A8FQE/@H@("`@
M/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H\8G(@+SX*/'1A8FQE(&)O<F1E<CTB
M,"(@86QI9VX](F-E;G1E<B(@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P
M(B!C96QL<&%D9&EN9STB,"(^"B`@/'1R/@H@("`@/'1D(&YO=W)A<#TB;F]W
M<F%P(CX*("`@("`@/&EN<'5T('1Y<&4](F)U='1O;B(@;F%M93TB8F%C:R(@
M8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N;&]C871I;VXN:')E
M9CTG/#]P:'`@96-H;R!)35`Z.G!R969S55),*'1R=64I(#\^)R(@=F%L=64]
M(CP_<&AP(&5C:&\@7R@B4F5T=7)N('1O($]P=&EO;G,B*2`_/B(@+SX*("`@
M(#PO=&0^"B`@/"]T<CX*/"]T86)L93X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+W1E;7!L871E<R]F;VQD97)S+P``````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,C`V
M-3$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+V9O;&1E
M<G,O9F]L9&5R<RYH=&UL````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C8W
M`#$P-#$W,S8R-S8V`#`R,S(P,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\;&]O<#IR;W=S/@H\9&EV(&-L87-S/2(\=&%G
M.G)O=W,N8VQA<W,@+SXB/@H@)FYB<W`[/&EN<'5T('1Y<&4](F-H96-K8F]X
M(B!C;&%S<STB8VAE8VMB;W@B(&YA;64](F9O;&1E<E]L:7-T6UTB(#QI9CIR
M;W=S+FYO8VAE8VMB;W@^9&ES86)L960](F1I<V%B;&5D(B`\+VEF.G)O=W,N
M;F]C:&5C:V)O>#YV86QU93TB/'1A9SIR;W=S+FUB;WA?=F%L("\^(B`O/B`\
M=&%G.G)O=W,N;&EN92`O/B`\=&%G.G)O=W,N;F%M92`O/CQI9CIR;W=S+G-H
M;W=?;7-G<SX@*#QT86<Z<F]W<RYN97<@+SXO/'1A9SIR;W=S+FUS9W,@+SXI
M/"]I9CIR;W=S+G-H;W=?;7-G<SX@/&EF.G)O=W,N=F9O;&1E<CXF;F)S<#LF
M;F)S<#M;/'1A9SIR;W=S+F1E;'9F;VQD97(@+SY=(%L\=&%G.G)O=W,N961I
M='9F;VQD97(@+SY=/"]I9CIR;W=S+G9F;VQD97(^"CPO9&EV/@H\+VQO;W`Z
M<F]W<SX*````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]F;VQD97)S+V9O;&1E<G-?
M8V]N9FER;2YH=&UL```````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$W,@`Q,#0Q-S,V,C<V
M-@`P,C0W,3$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&9O<FT@;F%M93TB9FUA;F%G97(B(&UE=&AO9#TB<&]S="(@86-T
M:6]N/2(\=&%G.F9O;&1E<G-?=7)L("\^(CX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB86-T:6]N240B('9A;'5E/2(\:68Z9&5L971E/F1E;&5T95]F
M;VQD97(\+VEF.F1E;&5T93X\:68Z96UP='D^9F]L9&5R<U]E;7!T>5]M86EL
M8F]X/"]I9CIE;7!T>3XB("\^"@H\9&EV(&-L87-S/2)H96%D97(@;&5F=$%L
M:6=N(CX*(#QG971T97AT/D9O;&1E<B!!8W1I;VYS("T@0V]N9FER;6%T:6]N
M/"]G971T97AT/@H\+V1I=CX*"CQD:78@8VQA<W,](F-O;G1R;VP@;&5F=$%L
M:6=N(CX*(#QI9CID96QE=&4^/&=E='1E>'0^66]U(&%R92!A='1E;7!T:6YG
M('1O(&1E;&5T92!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2X\+V=E='1E>'0^
M/"]I9CID96QE=&4^"B`\:68Z96UP='D^/&=E='1E>'0^66]U(&%R92!A='1E
M;7!T:6YG('1O(&1E;&5T92!A;&P@;65S<V%G97,@8V]N=&%I;F5D(&EN('1H
M92!F;VQL;W=I;F<@9F]L9&5R*',I+CPO9V5T=&5X=#X\+VEF.F5M<'1Y/@H@
M/&)R("\^"B`\9V5T=&5X=#Y)9B!Y;W4@8V]N=&EN=64L(&%L;"!M97-S86=E
M<R!I;B!T:&4@9F]L9&5R*',I('=I;&P@8F4@;&]S="$\+V=E='1E>'0^"CPO
M9&EV/@H*/&QO;W`Z9F]L9&5R<SX*/&1I=B!C;&%S<STB/'1A9SIF;VQD97)S
M+F-L87-S("\^(CX*("9N8G-P.SQI;G!U="!T>7!E/2)C:&5C:V)O>"(@8VQA
M<W,](F-H96-K8F]X(B!N86UE/2)F;VQD97)?;&ES=%M=(B!V86QU93TB/'1A
M9SIF;VQD97)S+G9A;"`O/B(@8VAE8VME9#TB8VAE8VME9"(@+SX@/'1A9SIF
M;VQD97)S+FYA;64@+SX*/"]D:78^"CPO;&]O<#IF;VQD97)S/@H*/&1I=B!C
M;&%S<STB8V]N=')O;"!L969T06QI9VXB/@H@/&EN<'5T('1Y<&4](G-U8FUI
M="(@;F%M93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/&EF.F1E
M;&5T93X\=&%G.F1E;&5T92`O/CPO:68Z9&5L971E/CQI9CIE;7!T>3X\=&%G
M.F5M<'1Y("\^/"]I9CIE;7!T>3XB("\^)FYB<W`["B`\:6YP=70@='EP93TB
M8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)S96QF+FQO8V%T:6]N
M+FAR968])SQT86<Z9F]L9&5R<U]U<FP@+SXG.R(@=F%L=64](CQT86<Z8V%N
M8V5L("\^(B`O/@H\+V1I=CX*"CPO9F]R;3X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M
M<&QA=&5S+V9O;&1E<G,O9F]O="YI;F,`````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,3(U`#$P-#$W,S8R-S8V`#`R,C,P-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\:6YP=70@='EP93TB:&ED
M9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](B(@+SX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB;F5W7VUA:6QB;W@B('9A;'5E/2(B("\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](FYE=U]N86UE<R(@=F%L=64](B(@+SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB;VQD7VYA;65S(B!V86QU93TB
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)V:65W7W-U8G-C<FEB
M960B('9A;'5E/2(B("\^"CPO9F]R;3X*/"]D:78^"@H\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"F1I<W!L87E.86UE<R`](&YE=R!!
M<G)A>2@\/W!H<`II9B`H:7-S970H)&1I<W!L87E.86UE<RD@)B8@:7-?87)R
M87DH)&1I<W!L87E.86UE<RDI('L*("`@("1I36%X(#T@8V]U;G0H)&1I<W!L
M87E.86UE<RD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:4UA>#L@)&DK*RD@
M>PH@("`@("`@(&EF("@D:2`^(#`I('L*("`@("`@("`@("`@96-H;R`G+"`G
M.PH@("`@("`@('T*("`@("`@("!E8VAO("<B)R`N("1D:7-P;&%Y3F%M97-;
M)&E=("X@)R(G.PH@("`@?0I]"C\^*3L*"B\O+2T^"CPO<V-R:7!T/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O=&5M<&QA=&5S+V9O;&1E<G,O86-T:6]N<RYI;F,`````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`V,#<V`#$P-#$W,S8R-S8V`#`R,S`Q,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\9&EV(&-L87-S
M/2)C;VYT<F]L(CX*(#P_<&AP(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH
M87-&96%T=7)E*"=J879A<V-R:7!T)RDI.B`_/B9N8G-P.SQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N86UE/2)C:&5C:T%L;"(@
M;VYC;&EC:STB=&]G9VQE4V5L96-T:6]N*"DB(#P_<&AP(&5C:&\@2&]R9&4Z
M.F=E=$%C8V5S<TME>4%N9%1I=&QE*%\H(D-H96-K(%]!;&PO3F]N92(I*2`_
M/B`O/CP_<&AP(&5N9&EF.R`_/@H@/'-E;&5C="!N86UE/2)A8W1I;VY?8VAO
M;W-E/#]P:'`@96-H;R`H)&D@/B`P*2`_(#$@.B`P(#\^(B!O;F-H86YG93TB
M8VAO;W-E06-T:6]N*#P_<&AP(&5C:&\@*"1I(#X@,"D@/R`Q(#H@,"`_/BD[
M(&1O8W5M96YT+F9M86YA9V5R+F%C=&EO;E]C:&]O<V4\/W!H<"!E8VAO("@D
M:2`^(#`I(#\@,2`Z(#`@/SXN<V5L96-T961);F1E>"`](#`[(CX*("`@/&]P
M=&EO;B!S96QE8W1E9#TB<V5L96-T960B/CP_<&AP(&5C:&\@7R@B0VAO;W-E
M($%C=&EO;CHB*2`_/CPO;W!T:6]N/@H\/W!H<"!I9B`H(65M<'1Y*"1'3$]"
M04Q36R=C;VYF)UU;)VAO;VMS)UU;)W!E<FUS9&5N:65D)UTI('Q\("A)35`Z
M.FAA<U!E<FUI<W-I;VXH)V-R96%T95]F;VQD97)S)RD@)B8@24U0.CIH87-0
M97)M:7-S:6]N*"=M87A?9F]L9&5R<R<I*2DZ(#\^"B`@(#QO<'1I;VX@=F%L
M=64](F-R96%T95]F;VQD97(B/CP_<&AP(&5C:&\@7R@B0W)E871E($9O;&1E
M<B(I(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&EF.R`_/@H@("`\;W!T:6]N('9A
M;'5E/2)R96YA;65?9F]L9&5R(CX\/W!H<"!E8VAO(%\H(E)E;F%M92!&;VQD
M97(H<RDB*2`_/CPO;W!T:6]N/@H@("`\;W!T:6]N('9A;'5E/2)D96QE=&5?
M9F]L9&5R7V-O;F9I<FTB/CP_<&AP(&5C:&\@7R@B1&5L971E($9O;&1E<BAS
M*2(I(#\^/"]O<'1I;VX^"B`@(#P_<&AP(&EF("@D<')E9G,M/F=E=%9A;'5E
M*"=S=6)S8W)I8F4G*2DZ(#\^"B`@(#QO<'1I;VX@=F%L=64](G-U8G-C<FEB
M95]F;VQD97(B/CP_<&AP(&5C:&\@7R@B4W5B<V-R:6)E('1O($9O;&1E<BAS
M*2(I(#\^/"]O<'1I;VX^"B`@(#QO<'1I;VX@=F%L=64](G5N<W5B<V-R:6)E
M7V9O;&1E<B(^/#]P:'`@96-H;R!?*")5;G-U8G-C<FEB92!F<F]M($9O;&1E
M<BAS*2(I(#\^/"]O<'1I;VX^"B`@(#P_<&AP(&5N9&EF.R`_/@H@("`\/W!H
M<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)VYA=E]P;VQL)RDI.B`_/@H@("`\
M;W!T:6]N('9A;'5E/2)P;VQL7V9O;&1E<B(^/#]P:'`@96-H;R!?*")#:&5C
M:R!&;VQD97(H<RD@9F]R($YE=R!-86EL(BD@/SX\+V]P=&EO;CX*("`@/&]P
M=&EO;B!V86QU93TB;F]P;VQL7V9O;&1E<B(^/#]P:'`@96-H;R!?*")$;R!.
M;W0@0VAE8VL@1F]L9&5R*',I(&9O<B!.97<@36%I;"(I(#\^/"]O<'1I;VX^
M"B`@(#P_<&AP(&5N9&EF.R`_/@H@("`\;W!T:6]N('9A;'5E/2)M87)K7V9O
M;&1E<E]S965N(CX\/W!H<"!E8VAO(%\H(DUA<FL@06QL($UE<W-A9V5S(&EN
M($9O;&1E<B!A<R!3965N(BD@/SX\+V]P=&EO;CX*("`@/&]P=&EO;B!V86QU
M93TB;6%R:U]F;VQD97)?=6YS965N(CX\/W!H<"!E8VAO(%\H(DUA<FL@06QL
M($UE<W-A9V5S(&EN($9O;&1E<B!A<R!5;G-E96XB*2`_/CPO;W!T:6]N/@H@
M("`\;W!T:6]N('9A;'5E/2)D;W=N;&]A9%]F;VQD97(B/CP_<&AP(&5C:&\@
M7R@B1&]W;FQO860@1F]L9&5R*',I(BD@/SX\+V]P=&EO;CX*("`@/&]P=&EO
M;B!V86QU93TB9&]W;FQO861?9F]L9&5R7WII<"(^/#]P:'`@96-H;R!?*")$
M;W=N;&]A9"!&;VQD97(H<RD@6RYZ:7`@9F]R;6%T72(I(#\^/"]O<'1I;VX^
M"B`@(#QO<'1I;VX@=F%L=64](F9O;&1E<G-?96UP='E?;6%I;&)O>%]C;VYF
M:7)M(CX\/W!H<"!E8VAO(%\H(D5M<'1Y($9O;&1E<BAS*2(I(#\^/"]O<'1I
M;VX^"B`@(#P_<&AP(&EF("@A)'!R969S+3YG971686QU92@G=7-E7W1R87-H
M)RDI.B`_/@H@("`\;W!T:6]N('9A;'5E/2)E>'!U;F=E7V9O;&1E<B(^/#]P
M:'`@96-H;R!?*")0=7)G92!&;VQD97(H<RDB*2`_/CPO;W!T:6]N/@H@("`\
M/W!H<"!E;F1I9CL@/SX*("`@/#]P:'`@:68@*"1I;7!;)V9I;&5?=7!L;V%D
M)UTI.B`_/@H@("`\;W!T:6]N('9A;'5E/2)I;7!O<G1?;6)O>"(^/#]P:'`@
M96-H;R!?*"));7!O<G0@365S<V%G97,B*2`_/CPO;W!T:6]N/@H@("`\/W!H
M<"!E;F1I9CL@/SX*("`@/&]P=&EO;B!V86QU93TB<F5B=6EL9%]T<F5E(CX\
M/W!H<"!E8VAO(%\H(E)E8G5I;&0@1F]L9&5R(%1R964B*2`_/CPO;W!T:6]N
M/@H@/"]S96QE8W0^"B`\/W!H<"!I9B`H(21'3$]"04Q36R=B<F]W<V5R)UTM
M/FAA<T9E871U<F4H)VIA=F%S8W)I<'0G*2DZ(#\^"B`\:6YP=70@;F%M93TB
M8G1N7V%C=&EO;B(@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU
M93TB/#]P:'`@96-H;R!?*")';R(I.R`_/B(@+SX*(#P_<&AP(&5N9&EF.R`_
M/@H@/#]P:'`@96-H;R!(96QP.CIL:6YK*"=I;7`G+"`G9F]L9&5R+6]P=&EO
M;G,G*2`_/@H@)FYB<W`["B`\/W!H<"!I9B`H)'!R969S+3YG971686QU92@G
M<W5B<V-R:6)E)RDI.B`_/@H@/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*%5T
M:6PZ.F%D9%!A<F%M971E<B@D9F]L9&5R<U]U<FPL("=A8W1I;VY)1"<L("=T
M;V=G;&5?<W5B<V-R:6)E9%]V:65W)RDL("1S=6)4;V=G;&5497AT+"`G=VED
M9V5T)RP@)R<L("<G+"`D<W5B5&]G9VQE5&5X="P@=')U92D[(#\^)FYB<W`[
M?`H@/#]P:'`@96YD:68[(#\^"B`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H
M571I;#HZ861D4&%R86UE=&5R*"1F;VQD97)S7W5R;"P@)V%C=&EO;DE$)RP@
M)V5X<&%N9%]A;&Q?9F]L9&5R<R<I+"!?*")%>'!A;F0@06QL($9O;&1E<G,B
M*2P@)W=I9&=E="<L("<G+"`G)RP@7R@B17AP86YD($%L;"(I+"!T<G5E*3L@
M/SXF;F)S<#M\"B`\/W!H<"!E8VAO($AO<F1E.CIW:61G970H571I;#HZ861D
M4&%R86UE=&5R*"1F;VQD97)S7W5R;"P@)V%C=&EO;DE$)RP@)V-O;&QA<'-E
M7V%L;%]F;VQD97)S)RDL(%\H(D-O;&QA<'-E($%L;"!&;VQD97)S(BDL("=W
M:61G970G+"`G)RP@)R<L(%\H(D-O;&QA<'-E($%L;"(I+"!T<G5E*3L@/SXF
M;F)S<#L*(#P_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G:6UP)RP@)V9O;&1E<BUW
M:61G971S)RD@/SX*/"]D:78^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+W1E;7!L871E<R]F;VQD97)S+VEM<&]R="YI;F,`````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,3<U-0`Q,#0Q-S,V,C<V-@`P,C(V-C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/&9O<FT@;F%M
M93TB9FUA;F%G97(B(&UE=&AO9#TB<&]S="(@96YC='EP93TB;75L=&EP87)T
M+V9O<FTM9&%T82(@86-T:6]N/2(\/W!H<`IE8VAO("1F;VQD97)S7W5R;"`_
M/B(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]F;VQD97(B
M('9A;'5E/2(\/W!H<"!E8VAO("1F;VQD97)?;&ES=%LP72`_/B(@+SX*/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2(B("\^
M"@H\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(B!C96QL<&%D
M:6YG/2(P(CX*("`\='(^"B`@("`\=&0@8VQA<W,](FAE861E<B(^"B`@("`@
M(#P_<&AP(&5C:&\@7R@B26UP;W)T(&UB;W@@1FEL92(I(#\^"B`@("`@(#PO
M=&0^"B`@/"]T<CX*"B`@/'1R(&-L87-S/2)I=&5M(CX*("`@(#QT9#X*("`@
M("`@/&)R("\^)FYB<W`[)FYB<W`["B`@("`@(#P_<&AP('!R:6YT9BA?*"))
M;7!O<G0@;6)O>"!F:6QE("5S(&EN=&\@9F]L9&5R("5S+B(I+`H@("`@("`@
M("`@("`@("`@("`@)R9N8G-P.R9N8G-P.SQI;G!U="!N86UE/2)M8F]X7W5P
M;&]A9"(@='EP93TB9FEL92(@<VEZ93TB,S`B(&-L87-S/2)F:7AE9"(@+SXF
M;F)S<#LF;F)S<#LG+`H@("`@("`@("`@("`@("`@("`@)SQS=')O;F<^)R`N
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&9O;&1E<E]L:7-T6S!=+"`G551&
M-RU)34%0)RD@+B`G/"]S=')O;F<^)RD@/SX*("`@("`@)FYB<W`[)FYB<W`[
M"B`@("`@(#QI;G!U="!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB('9A
M;'5E/2(\/W!H<"!E8VAO(%\H(DEM<&]R="(I(#\^(B!O;F-L:6-K/2)S=6)M
M:71!8W1I;VXH)VEM<&]R=%]M8F]X)RDB+SX*("`@("`@/&EN<'5T('1Y<&4]
M(F)U='1O;B(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M0V%N8V5L(BD@/SXB(&]N8VQI8VL](G-U8FUI=$%C=&EO;B@P*2(O/@H@("`@
M("`\8G(@+SX\8G(@+SX*("`@(#PO=&0^"B`@/"]T<CX*/"]T86)L93X*"CPO
M9F]R;3X*`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+W1E;7!L871E<R]F;VQD97)S+VAE860N:6YC````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$U,@`Q,#0Q-S,V,C<V-@`P,C(R-#$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/&@Q
M(&-L87-S/2)H96%D97(B/@H@/#]P:'`*("`@("1R969R97-H7W1I=&QE(#T@
M7R@B4F5L;V%D(%9I97<B*3L*("`@("1R969R97-H7V%K(#T@2&]R9&4Z.F=E
M=$%C8V5S<TME>2@D<F5F<F5S:%]T:71L92D["B`@("`D<F5F<F5S:%]T:71L
M92`]($AO<F1E.CIS=')I<$%C8V5S<TME>2@D<F5F<F5S:%]T:71L92D["B`@
M("!I9B`H(65M<'1Y*"1R969R97-H7V%K*2D@>PH@("`@("`@("1R969R97-H
M7W1I=&QE("X]('-P<FEN=&8H7R@B("A!8V-E<W-K97D@)7,I(BDL("1R969R
M97-H7V%K*3L*("`@('T*("`@(&5C:&\@7R@B1F]L9&5R($YA=FEG871O<B(I
M("X@)R9N8G-P.R<@+B!(;W)D93HZ;&EN:R@D9F]L9&5R<U]U<FPL("1R969R
M97-H7W1I=&QE+"`G)RP@)R<L("<G+"`D<F5F<F5S:%]T:71L92P@)')E9G)E
M<VA?86LI("X@2&]R9&4Z.FEM9R@G<F5L;V%D+G!N9R<L(%\H(E)E;&]A9"(I
M+"!N=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\
M+V$^)SL*/SX*/"]H,3X*/&1I=B!C;&%S<STB:&5A9&5R8F]X(&9O;&1E<G,B
M/@H\9F]R;2!N86UE/2)F;6%N86=E<B(@;65T:&]D/2)P;W-T(B!A8W1I;VX]
M(CP_<&AP(&5C:&\@)&9O;&1E<G-?=7)L(#\^(CX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]C;VYT86-T<R\`````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P
M,C$P,S$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+V-O
M;G1A8W1S+V-O;G1A8W1S+FEN8P``````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(Q
M,S8W`#$P-#$W,S8R-S8V`#`R,S,U,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C
M<FEP="(^"CPA+2T*"F9U;F-T:6]N(&%D:G5S=%-I>F4H*0I["B`@("!I9B`H
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260I('L*("`@("`@("!V87(@=&%B;&4@
M/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G8V]N=&%C='-T86)L92<I.PH@
M("`@("`@(&EF("AT86)L92YO9F9S9717:61T:"`F)@H@("`@("`@("`@("!T
M86)L92YO9F9S9717:61T:"`^(#4U,"D@>PH@("`@("`@("`@("!W:6YD;W<N
M<F5S:7IE5&\H=&%B;&4N;V9F<V5T5VED=&@L(#,P,"D["B`@("`@("`@?0H@
M("`@?0I]"@IV87(@9&ES<&QA>2`]("(\/W!H<"!E8VAO("@A96UP='DH)&1I
M<W!L87DI(#\@)&1I<W!L87D@.B`B;F%M92(I(#\^(CL*"F9U;F-T:6]N(&-H
M86YG941I<W!L87DH*0I["B`@("!V87(@;&ES=$1I<W!L87D@/2!D;V-U;65N
M="YC;VYT86-T<RYD:7-P;&%Y.PH*("`@(&EF("AL:7-T1&ES<&QA>2YO<'1I
M;VYS6VQI<W1$:7-P;&%Y+G-E;&5C=&5D26YD97A=+G9A;'5E("$](&1I<W!L
M87DI('L*("`@("`@("!D:7-P;&%Y(#T@;&ES=$1I<W!L87DN;W!T:6]N<UML
M:7-T1&ES<&QA>2YS96QE8W1E9$EN9&5X72YV86QU93L*"B`@("`@("`@<R`]
M(&1O8W5M96YT+F-O;G1A8W1S+G-E87)C:%]R97-U;'1S.PH@("`@("`@(&9O
M<B`H=F%R(&D@/2`P.R!I(#P@<RYL96YG=&@[(&DK*RD@>PH@("`@("`@("`@
M("!V87(@=&5M<"`](',N;W!T:6]N<UMI72YV86QU93L*("`@("`@("`@("`@
M:68@*'1E;7`@/3T@(B(I('L@8V]N=&EN=64[('T*"B`@("`@("`@("`@(',N
M;W!T:6]N<UMI72YV86QU92`](&5S8V%P92AS+F]P=&EO;G-;:5TN=&5X="D[
M"B`@("`@("`@("`@(',N;W!T:6]N<UMI72YT97AT(#T@=6YE<V-A<&4H=&5M
M<"D["B`@("`@("`@?0H*("`@("`@("!D(#T@9&]C=6UE;G0N8V]N=&%C=',N
M<V5L96-T961?861D<F5S<V5S.PH@("`@("`@(&9O<B`H=F%R(&D@/2`P.R!I
M(#P@9"YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!V87(@=&5M<"`](&0N
M;W!T:6]N<UMI72YV86QU93L*("`@("`@("`@("`@:68@*'1E;7`@/3T@(B(I
M('L@8V]N=&EN=64[('T*"B`@("`@("`@("`@(&0N;W!T:6]N<UMI72YV86QU
M92`](&5S8V%P92AD+F]P=&EO;G-;:5TN=&5X="D["B`@("`@("`@("`@(&0N
M;W!T:6]N<UMI72YT97AT(#T@=6YE<V-A<&4H=&5M<"D["B`@("`@("`@?0H@
M("`@?0I]"@IF=6YC=&EO;B!P87-S061D<F5S<V5S*"D*>PH@("`@=F%R(&QI
M<W0@/2!D;V-U;65N="YC;VYT86-T<RYS96QE8W1E9%]A9&1R97-S97,["B`@
M("!V87(@<V$@/2`G)SL*"B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&QI<W0N
M;&5N9W1H.R!I*RLI('L*("`@("`@("!V87(@:71E;2`](&QI<W0N;W!T:6]N
M<UMI73L*("`@("`@("!I9B`H:71E;2YV86QU92`]/2`G)RD@>PH@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@<V$@*ST@:71E;2YV
M86QU92`K("=\)R`K(&ET96TN=&5X="`K("=\)SL*("`@('T*("`@(&1O8W5M
M96YT+F-O;G1A8W1S+G-A+G9A;'5E(#T@<V$["GT*"F9U;F-T:6]N('-A;65/
M<'1I;VXH9BP@:71E;2P@:71E;6HI"GL*("`@('9A<B!T97AT(#T@9B`K("(Z
M("(@*R!I=&5M+G1E>'0["B`@("!V87(@=F%L=64@/2!F("L@(CH@(B`K(&ET
M96TN=F%L=64["B`@("!V87(@=&5X=&H@/2!I=&5M:BYT97AT.PH@("`@=F%R
M('9A;'5E:B`](&ET96UJ+G9A;'5E.PH*("`@("\O($-A=&-H(&5X8V5P=&EO
M;B!W:71H($Y3(#<N,0H@("`@=')Y('L*("`@("`@("!R971U<FX@*"AT97AT
M(#T]('1E>'1J*2!\?"`H=6YE<V-A<&4H=&5X="D@/3T@=6YE<V-A<&4H=&5X
M=&HI*2D@)B8*("`@("`@("`@("`@*"AV86QU92`]/2!V86QU96HI('Q\("AU
M;F5S8V%P92AV86QU92D@/3T@=6YE<V-A<&4H=F%L=65J*2DI.PH@("`@?2!C
M871C:"AE*2!["B`@("`@("`@<F5T=7)N("AT97AT(#T]('1E>'1J("8F('9A
M;'5E(#T]('9A;'5E:BD["B`@("!]"GT*"F9U;F-T:6]N(&%D9$%D9')E<W,H
M9BD*>PH@("`@=F%R(',@/2!D;V-U;65N="YC;VYT86-T<RYS96%R8VA?<F5S
M=6QT<SL*("`@('9A<B!D(#T@9&]C=6UE;G0N8V]N=&%C=',N<V5L96-T961?
M861D<F5S<V5S.PH*("`@(&EF("AS+G-E;&5C=&5D26YD97@@/"`P*2!["B`@
M("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")9;W4@;75S
M="!S96QE8W0@86X@861D<F5S<R!F:7)S="XB*2D@/SXG*3L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!](&5L<V4@>PH@("`@("`@(&9O<B`H=F%R(&D@
M/2`P.R!I(#P@<RYL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!V87(@:71E
M;2`](',N;W!T:6]N<UMI73L*("`@("`@("`@("`@:68@*&ET96TN=F%L=64@
M/3T@(B(I('L@8V]N=&EN=64[('T*("`@("`@("`@("`@:68@*&ET96TN<V5L
M96-T960I('L*("`@("`@("`@("`@("`@(&9O<B`H=F%R(&H@/2`P.R!J(#P@
M9"YL96YG=&@[(&HK*RD@>PH@("`@("`@("`@("`@("`@("`@('9A<B!I=&5M
M:B`](&0N;W!T:6]N<UMJ73L*("`@("`@("`@("`@("`@("`@("!I9B`H<V%M
M94]P=&EO;BAF+"!I=&5M+"!I=&5M:BDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&0N;W!T:6]N<UMD+FQE
M;F=T:%T@/2!N97<@3W!T:6]N*&8@*R`G.B`G("L@:71E;2YT97AT+"!F("L@
M)SH@)R`K(&ET96TN=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0I]"@IF=6YC=&EO;B!U<&1A=&5-97-S86=E*"D*>PH@("`@:68@*'!A
M<F5N="YO<&5N97(N8VQO<V5D*2!["B`@("`@("`@86QE<G0H)SP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")4:&4@;65S<V%G92!B96EN9R!C;VUP;W-E9"!H
M87,@8F5E;B!C;&]S960N($5X:71I;F<N(BDI(#\^)RD["B`@("`@("`@=&AI
M<RYC;&]S92@I.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!I9B`H(7!A
M<F5N="YO<&5N97(N9&]C=6UE;G0N/#]P:'`@96-H;R`D9F]R;6YA;64@/SXI
M('L*("`@("`@("!A;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@82!C;VUP;W-E('=I;F1O
M=RXB*2D@/SXG*3L*("`@("`@("!T:&ES+F-L;W-E*"D["B`@("`@("`@<F5T
M=7)N.PH@("`@?0H*("`@('9A<B!L:7-T(#T@9&]C=6UE;G0N8V]N=&%C=',N
M<V5L96-T961?861D<F5S<V5S.PH@("`@9F]R("AV87(@:2`](#$[(&D@/"!L
M:7-T+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*&1I<W!L87D@/3T@(FYA
M;64B*2!["B`@("`@("`@("`@('9A<B!A9&1R97-S(#T@=6YE<V-A<&4H;&ES
M="YO<'1I;VYS6VE=+G9A;'5E*3L*("`@("`@("`@("`@=F%R(&9U;&QN86UE
M(#T@;&ES="YO<'1I;VYS6VE=+G1E>'0["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@=F%R(&%D9')E<W,@/2!L:7-T+F]P=&EO;G-;:5TN=&5X=#L*
M("`@("`@("`@("`@=F%R(&9U;&QN86UE(#T@=6YE<V-A<&4H;&ES="YO<'1I
M;VYS6VE=+G9A;'5E*3L*("`@("`@("!]"B`@("`@("`@=F%R('!O<R`](&%D
M9')E<W,N:6YD97A/9B@G.B<I.PH@("`@("`@('9A<B!F(#T@861D<F5S<RYS
M=6)S=')I;F<H,"P@<&]S*3L*("`@("`@("!V87(@9FEE;&0@/2!N=6QL.PH*
M("`@("`@("!F=6QL;F%M92`](&9U;&QN86UE+G-U8G-T<FEN9RAP;W,@*R`R
M+"!F=6QL;F%M92YL96YG=&@I.PH@("`@("`@(&9U;&QN86UE(#T@9G5L;&YA
M;64N<F5P;&%C92@O7%PO9RP@)UQ<7%PG*3L*("`@("`@("!F=6QL;F%M92`]
M(&9U;&QN86UE+G)E<&QA8V4H+R(O9RP@)UQ<(B<I.PH@("`@("`@(&EF("AA
M9&1R97-S+G-U8G-T<FEN9RAP;W,@*R`R+"!A9&1R97-S+FQE;F=T:"DN:6YD
M97A/9B@G+"<I(#X@,"D@>PH@("`@("`@("`@("!A9&1R97-S(#T@9G5L;&YA
M;64@*R`G.B`G("L@861D<F5S<RYS=6)S=')I;F<H<&]S("L@,BP@861D<F5S
M<RYL96YG=&@I("L@)SLG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&%D9')E<W,@/2`G(B<@*R!F=6QL;F%M92`K("<B(#PG("L@861D<F5S<RYS
M=6)S=')I;F<H<&]S("L@,BP@861D<F5S<RYL96YG=&@I("L@)SXG.PH@("`@
M("`@('T*("`@("`@("!I9B`H9B`]/2`G=&\G*2!["B`@("`@("`@("`@(&9I
M96QD(#T@<&%R96YT+F]P96YE<BYD;V-U;65N="X\/W!H<"!E8VAO("1F;W)M
M;F%M92`_/BYT;SL*/#]P:'`@:68@*"$D=&]?;VYL>2DZ(#\^"B`@("`@("`@
M?2!E;'-E(&EF("AF(#T]("=C8R<I('L*("`@("`@("`@("`@9FEE;&0@/2!P
M87)E;G0N;W!E;F5R+F1O8W5M96YT+CP_<&AP(&5C:&\@)&9O<FUN86UE(#\^
M+F-C.PH@("`@("`@('T@96QS92!I9B`H9B`]/2`G8F-C)RD@>PH@("`@("`@
M("`@("!F:65L9"`]('!A<F5N="YO<&5N97(N9&]C=6UE;G0N/#]P:'`@96-H
M;R`D9F]R;6YA;64@/SXN8F-C.PH\/W!H<"!E;F1I9CL@/SX*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@
M("`@("\O($]N;'D@9&5L:6UI="!W:71H(&-O;6UA<R!I9B!A="!L96%S="!T
M:&4@,FYD(&5N=')Y(&%N9"!N;W0@869T97(*("`@("`@("`O+R!A(&=R;W5P
M(&%D9')E<W,N"B`@("`@("`@:68@*&9I96QD+G9A;'5E*2!["B`@("`@("`@
M("`@(&EF("AF:65L9"YV86QU92YS=6)S='(H9FEE;&0N=F%L=64N;&5N9W1H
M("T@,2P@,2D@(3T@)SLG*2!["B`@("`@("`@("`@("`@("!F:65L9"YV86QU
M92`](&9I96QD+G9A;'5E("L@)RPG.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&9I96QD+G9A;'5E(#T@9FEE;&0N=F%L=64@*R`G("<@*R!A9&1R97-S
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9I96QD+G9A;'5E(#T@
M861D<F5S<SL*("`@("`@("!]"B`@("!]"B`@("!T:&ES+F-L;W-E*"D["GT*
M"F9U;F-T:6]N(')E;6]V94%D9')E<W,H*0I["B`@("!V87(@;&ES="`](&1O
M8W5M96YT+F-O;G1A8W1S+G-E;&5C=&5D7V%D9')E<W-E<SL*("`@(&9O<B`H
M=F%R(&D@/2!L:7-T+FQE;F=T:"`M(#$[(&D@/B`P.R!I+2TI('L*("`@("`@
M("!I9B`H;&ES="YO<'1I;VYS6VE=+G-E;&5C=&5D*2!["B`@("`@("`@("`@
M(&QI<W0N;W!T:6]N<UMI72`](&YU;&P["B`@("`@("`@?0H@("`@?0I]"@HO
M+RTM/@H\+W-C<FEP=#X*/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)C;VYT
M86-T<R(@;VYS=6)M:70](G!A<W-!9&1R97-S97,H*3LB(&%C=&EO;CTB/#]P
M:'`@96-H;R!(;W)D93HZ=7)L*%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ
M87!P;&EC871I;VY5<FPH)V-O;G1A8W1S+G!H<"<I+"`G=6YI<2<L(&)A<V5?
M8V]N=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*2DI(#\^(CX*/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB9F]R;6YA;64B('9A;'5E/2(\/W!H<"!E8VAO
M("1F;W)M;F%M92`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M<V5A<F-H960B('9A;'5E/2(Q(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)S82(@+SX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"@H\:#$@
M8VQA<W,](FAE861E<B(^"B`@/#]P:'`@96-H;R!?*")!9&1R97-S($)O;VLB
M*2`_/@H\+V@Q/@H*/&1I=B!I9#TB8V]N=&%C='-T86)L92(@8VQA<W,](FAE
M861E<F)O>"!I=&5M(CX*"B`\<"!C;&%S<STB8V]N=')O;"(^"B`@(#QS=')O
M;F<^/#]P:'`@96-H;R!?*")&:6YD(BD@/SX\+W-T<F]N9SX*("`@/&EN<'5T
M('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'-E87)C:"D@
M/SXB(&YA;64](G-E87)C:"(@<W1Y;&4](G=I9'1H.C$U,'!X(CX*"CP_<&AP
M(&EF("AC;W5N="@D<V]U<F-E7VQI<W0I(#X@,2DZ(#\^"B`@(#QS=')O;F<^
M/#]P:'`@96-H;R!?*")F<F]M(BD@/SX\+W-T<F]N9SX*("`@/'-E;&5C="!N
M86UE/2)S;W5R8V4B/@H@("`\/W!H<"!F;W)E86-H("@D<V]U<F-E7VQI<W0@
M87,@)&ME>2`]/B`D<V5L96-T*3H@/SX*("`@(#QO<'1I;VX@=F%L=64](CP_
M<&AP(&5C:&\@)&ME>2`_/B(\/W!H<"!I9B`H)&ME>2`]/2`D<V]U<F-E*2!E
M8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1S96QE8W0I(#\^/"]O<'1I;VX^"B`@(#P_<&AP(&5N
M9&9O<F5A8V@[(#\^"B`@(#PO<V5L96-T/@H\/W!H<"!E;'-E.B`_/@H@("`\
M:6YP=70@;F%M93TB<V]U<F-E(B!T>7!E/2)H:61D96XB('9A;'5E/2(\/W!H
M<"!E8VAO(&ME>2@D<V]U<F-E7VQI<W0I(#\^(B`O/@H\/W!H<"!E;F1I9CL@
M/SX*("`@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L
M=64](CP_<&AP(&5C:&\@7R@B4V5A<F-H(BD@/SXB("\^"B`\+W`^"@H@/'1A
M8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,B(^"B`@/'1R/@H@("`\
M=&0@=VED=&@](C,S)2(^"B`@("`\<V5L96-T(&YA;64](G-E87)C:%]R97-U
M;'1S(B!M=6QT:7!L93TB;75L=&EP;&4B('-I>F4](C$P(B!W:61T:#TB,C`P
M(B!O;F-H86YG93TB9&]C=6UE;G0N8V]N=&%C=',N<V5A<F-H7W)E<W5L='-;
M,%TN<V5L96-T960]9F%L<V4B/#]P:'`@96-H;R`D<V5L96-T7V5V96YT(#\^
M/@H@("`@(#QO<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?*"(J(%!L96%S
M92!S96QE8W0@861D<F5S<RAE<RD@*B(I(#\^/"]O<'1I;VX^"CP_<&AP"F9O
M<F5A8V@@*"1A9&1R97-S97,@87,@)&%D9'(I('L*("`@(&EF("@A96UP='DH
M)&%D9');)V5M86EL)UTI*2!["B`@("`@("`@:68@*"1D:7-P;&%Y(#T]("=E
M;6%I;"<I('L*/SX*("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(')A
M=W5R;&5N8V]D92@D861D<ELG;F%M92==*2`_/B(\/W!H<"!E8VAO("1O<'1I
M;VY?979E;G0@/SX^/#]P:'`@96-H;R`D861D<ELG96UA:6PG72`_/CPO;W!T
M:6]N/@H\/W!H<"!](&5L<V4@>R`_/@H@("`@(#QO<'1I;VX@=F%L=64](CP_
M<&AP(&5C:&\@<F%W=7)L96YC;V1E*"1A9&1R6R=E;6%I;"==*2`_/B(\/W!H
M<"!E8VAO("1O<'1I;VY?979E;G0@/SX^/#]P:'`@96-H;R`D861D<ELG;F%M
M92==(#\^/"]O<'1I;VX^"CP_<&AP('U]?2`_/@H@("`@/"]S96QE8W0^"B`@
M(#PO=&0^"B`@(#QT9"!W:61T:#TB,S,E(B!S='EL93TB=&5X="UA;&EG;CIC
M96YT97(B/@H@("`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O
M;B(@<W1Y;&4](G=I9'1H.C8P<'@B(&]N8VQI8VL](F%D9$%D9')E<W,H)W1O
M)RD[(B!V86QU93TB/#]P:'`@96-H;R!?*")4;R(I("X@(B`F9W0[)F=T.R(@
M/SXB("\^/&)R("\^)FYB<W`[/&)R("\^"CP_<&AP(&EF("@A)'1O7V]N;'DI
M.B`_/@H@("`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@
M<W1Y;&4](G=I9'1H.C8P<'@B(&]N8VQI8VL](F%D9$%D9')E<W,H)V-C)RD[
M(B!V86QU93TB/#]P:'`@96-H;R!?*")#8R(I("X@(B`F9W0[)F=T.R(@/SXB
M("\^/&)R("\^)FYB<W`[/&)R("\^"B`@("`\:6YP=70@='EP93TB8G5T=&]N
M(B!C;&%S<STB8G5T=&]N(B!S='EL93TB=VED=&@Z-C!P>"(@;VYC;&EC:STB
M861D061D<F5S<R@G8F-C)RD[(B!V86QU93TB/#]P:'`@96-H;R!?*")"8V,B
M*2`N("(@)F=T.R9G=#LB(#\^(B`O/@H@("`\+W1D/@H\/W!H<"!E;F1I9CL@
M/SX*("`@/'1D('=I9'1H/2(S,R4B/@H@("`@/'-E;&5C="!N86UE/2)S96QE
M8W1E9%]A9&1R97-S97,B(&UU;'1I<&QE/2)M=6QT:7!L92(@<VEZ93TB,3`B
M('=I9'1H/2(R,#`B(&]N8VAA;F=E/2)D;V-U;65N="YC;VYT86-T<RYS96QE
M8W1E9%]A9&1R97-S97-;,%TN<V5L96-T960@/2!F86QS93LB/@H@("`@(#QO
M<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?*"(J($%D9"!T:&5S92!B>2!C
M;&EC:VEN9R!/2R`J(BD@/SX\+V]P=&EO;CX*/#]P:'`@9F]R96%C:"`H)'-E
M;&5C=&5D7V%D9')E<W-E<R!A<R`D=F%L=64@/3X@)'1E>'0I.B`_/@H@("`@
M(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@)'9A;'5E(#\^(CX\/W!H<"!E
M8VAO("1T97AT(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@
M("`\+W-E;&5C=#X*("`@/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@/'1D(&-L
M87-S/2)N;W=R87`B/@H@("`@/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D1I<W!L
M87DB*2`_/CPO<W1R;VYG/@H@("`@/'-E;&5C="!N86UE/2)D:7-P;&%Y(B!O
M;F-H86YG93TB8VAA;F=E1&ES<&QA>2@I.R(^"B`@("`@/&]P=&EO;B!V86QU
M93TB;F%M92(\/W!H<"!E8VAO("1D:7-P;&%Y(#T]("=N86UE)R`_("<@<V5L
M96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(DYA;64B
M*2`_/CPO;W!T:6]N/@H@("`@(#QO<'1I;VX@=F%L=64](F5M86EL(CP_<&AP
M(&5C:&\@)&1I<W!L87D@/3T@)V5M86EL)R`_("<@<V5L96-T960](G-E;&5C
M=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(D5M86EL($%D9')E<W,B*2`_
M/CPO;W!T:6]N/@H@("`@/"]S96QE8W0^"B`@(#PO=&0^"B`@(#QT9#XF;F)S
M<#L\+W1D/@H@("`\=&0^"B`@("`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S
M<STB8G5T=&]N(B!O;F-L:6-K/2)R96UO=F5!9&1R97-S*"DB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(D1E;&5T92(I(#\^(B`O/@H@("`\+W1D/@H@(#PO='(^
M"B`\+W1A8FQE/@H*/"]D:78^"@H\8G(@8VQA<W,](G-P86-E<B(@+SX*"CQD
M:78^"B`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@;VYC
M;&EC:STB=7!D871E365S<V%G92@I.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M3TLB*2`_/B(@+SX*("`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T
M=&]N(B!O;F-L:6-K/2)W:6YD;W<N8VQO<V4H*3LB('9A;'5E/2(\/W!H<"!E
M8VAO(%\H(D-A;F-E;"(I(#\^(B`O/@H\+V1I=CX*"CPO9F]R;3X*/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"F%D:G5S=%-I>F4H*3L*
M+R\M+3X*/"]S8W)I<'0^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T96UP
M;&%T97,O:F%V87-C<FEP="\`````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-C8`,#(Q,S8Q`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+W1E;7!L871E<R]J879A<V-R:7!T+W!O<'5P+FIS````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8R,@`Q,#0Q-S,V,C<V-@`P,C,P
M-C(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+RHJ"B`J($E-4"!0;W!U<"!*879A4V-R:7!T+@H@*@H@*B!0<F]V:61E<R!T
M:&4@:F%V87-C<FEP="!T;R!O<&5N('!O<'5P('=I;F1O=W,N"B`J"B`J("1(
M;W)D93H@:6UP+W1E;7!L871E<R]J879A<V-R:7!T+W!O<'5P+FIS+'8@,2XQ
M+C(N,B`R,#`V+S`R+S$P(#(Q.C$P.C(V('-L=7-A<GH@17AP("0*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*+RHJ"B`J($]P96X@82!P;W!U<"!W:6YD;W<N"B`J"B`J
M($!P87)A;2!S=')I;F<@)'5R;"`@("`@("`@("`@("`@(%1H92!54DP@=&\@
M;W!E;B!I;B!T:&4@<&]P=7`@=VEN9&]W+@H@*B!`<&%R86T@;W!T:6]N86P@
M:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE('!O<'5P('=I;F1O
M=RX@*$1E9F%U;'0Z"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#8P,"!P>"D*("H@0'!A<F%M(&]P=&EO;F%L(&EN=&5G97(@)&AE:6=H
M="`@5&AE(&AE:6=H="!O9B!T:&4@<&]P=7`@=VEN9&]W+B`H1&5F875L=#H*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@-3`P('!X*0H@
M*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG("1A<F=S("`@("!!;GD@861D:71I
M;VYA;"!A<F=S('1O('!A<W,@=&\@=&AE('-C<FEP="X*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*$1E9F%U;'0Z(&YO(&%R9W,I"B`J
M+PIF=6YC=&EO;B!P;W!U<%]I;7`H=7)L+"!W:61T:"P@:&5I9VAT+"!A<F=S
M*0I["B`@("!I9B`H(7=I9'1H*2!["B`@("`@("`@=VED=&@@/2`V,#`["B`@
M("!]"B`@("!V87(@<V-R965N7W=I9'1H(#T@<V-R965N+G=I9'1H.PH@("`@
M:68@*'=I9'1H(#X@*'-C<F5E;E]W:61T:"`M(#<U*2D@>PH@("`@("`@('=I
M9'1H(#T@<V-R965N7W=I9'1H("T@-S4["B`@("!]"@H@("`@:68@*"%H96EG
M:'0I('L*("`@("`@("!H96EG:'0@/2`U,#`["B`@("!]"B`@("!V87(@<V-R
M965N7W=I9'1H(#T@<V-R965N+G=I9'1H.PH@("`@:68@*'=I9'1H(#X@*'-C
M<F5E;E]W:61T:"`M(#<U*2D@>PH@("`@("`@('=I9'1H(#T@<V-R965N7W=I
M9'1H("T@-S4["B`@("!]"@H@("`@=F%R(&YO=R`](&YE=R!$871E*"D["B`@
M("!V87(@;F%M92`](&YO=RYG9714:6UE*"D["@H@("`@:68@*'5R;"YI;F1E
M>$]F*"<_)RD@/3T@+3$I('L*("`@("`@("!V87(@9VQU92`]("<_)SL*("`@
M('T@96QS92!["B`@("`@("`@=F%R(&=L=64@/2`G)B<["B`@("!]"@H@("`@
M:68@*&%R9W,@(3T@(B(I('L*("`@("`@("!U<FP@/2!U<FP@*R!G;'5E("L@
M87)G<R`K("(F=6YI<3TB("L@;F%M93L*("`@('T@96QS92!["B`@("`@("`@
M=7)L(#T@=7)L("L@9VQU92`K(")U;FEQ/2(@*R!N86UE.PH@("`@?0H*("`@
M('!A<F%M(#T@(G1O;VQB87(];F\L;&]C871I;VX];F\L<W1A='5S/7EE<RQS
M8W)O;&QB87)S/7EE<RQR97-I>F%B;&4]>65S+'=I9'1H/2(@*R!W:61T:"`K
M("(L:&5I9VAT/2(@*R!H96EG:'0@*R`B+&QE9G0],"QT;W`],"(["B`@("!W
M:6X@/2!W:6YD;W<N;W!E;BAU<FPL(&YA;64L('!A<F%M*3L*("`@(&EF("@A
M=VEN*2!["B`@("`@("`@86QE<G0H(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")4:&4@:6UA9V4@<V%V92!W:6YD;W<@8V%N(&YO="!B92!O<&5N960N(%!E
M<FAA<',@>6]U(&AA=F4@<V5T('EO=7(@8G)O=W-E<B!T;R!B;&]C:R!P;W!U
M<"!W:6YD;W=S/R(I*2`_/B(I.PH@("`@?2!E;'-E('L*("`@("`@("!I9B`H
M(65V86PH(G=I;BYO<&5N97(B*2D@>PH@("`@("`@("`@("!W:6XN;W!E;F5R
M(#T@<V5L9CL*("`@("`@("!]"B`@("`@("`@=VEN+F9O8W5S*"D["B`@("!]
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]T96UP;&%T97,O:F%V87-C<FEP="]A9&1R97-S97-";&]C:W,N
M:G,`````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$S-S``,3`T,3<S-C(W-C8`,#(U,#,P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````&9U;F-T
M:6]N('1O9V=L94%D9')E<W-E<T)L;V-K*&9I96QD+"!C;W5N="D*>PH@("`@
M=F%R(&)L;V-K(#T@;F5W($AO<F1E7TAI9&5A8FQE*"=A8E\G("L@9FEE;&0I
M.PH*("`@(&)L;V-K+G1O9V=L92@I.PH@("`@=&5X="`](&1O8W5M96YT+F-R
M96%T951E>'1.;V1E*&)L;V-K+G-H;W=N*"D@/PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<\/W!H<"!E8VAO(%\H(EM(:61E($%D9')E
M<W-E<UTB*2`_/B<@.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<\/W!H<"!E8VAO(%\H(EM3:&]W($%D9')E<W-E<R`M(BD@/SX@)R`K
M(&-O=6YT("L@)R`\/W!H<"!E8VAO(%\H(G)E8VEP:65N='-=(BD@/SXG*3L*
M("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=!)RD["B`@("!L
M:6YK+FAR968@/2`G)SL*("`@(&QI;FLN8VQA<W-.86UE(#T@)W=I9&=E="<[
M"B`@("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*("`@("`@("!T;V=G
M;&5!9&1R97-S97-";&]C:RAF:65L9"P@8V]U;G0I.PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*("`@(&QI;FLN87!P96YD0VAI;&0H=&5X="D["@H@
M("`@=F%R('1O9V=L92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=A=%\G
M("L@9FEE;&0I.PH@("`@:68@*'1O9V=L92YF:7)S=$-H:6QD*2!["B`@("`@
M("`@=&]G9VQE+G)E;6]V94-H:6QD*'1O9V=L92YF:7)S=$-H:6QD*3L*("`@
M('T*("`@('1O9V=L92YA<'!E;F1#:&EL9"AL:6YK*3L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]T96UP;&%T97,O:F%V87-C<FEP="]F;VQD97)S+FIS
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,T-S0`,3`T,3<S-C(W-C8`,#(S
M,S8S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\J*@H@*B!)35`@1F]L9&5R<R!*879A<V-R:7!T"B`J"B`J(%!R;W9I9&5S
M('1H92!J879A<V-R:7!T('1O(&AE;'`@=&AE(&9O;&1E<G,N<&AP('-C<FEP
M="X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+V=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&EM<"]T96UP;&%T97,O:F%V
M87-C<FEP="]F;VQD97)S+FIS+'8@,2XQ+C(N,B`R,#`V+S`Q+S$Q(#`U.C0X
M.C(S('-L=7-A<GH@17AP("0*("HO"@IV87(@=&]O36%N>2`]("<\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B4&QE87-E('-E;&5C="!O;FQY(&]N92!F;VQD
M97(@9F]R('1H:7,@;W!E<F%T:6]N+B(I*2`_/B<["G9A<B!D;W=N;&]A9$-O
M;F9I<FT@/2`G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%L;"!M97-S86=E
M<R!I;B!T:&4@9F]L;&]W:6YG(&9O;&1E<BAS*2!W:6QL(&)E(&1O=VYL;V%D
M960@:6YT;R!O;F4@34)/6"!F:6QE.B(I*2`_/B<["G9A<B!D;W=N;&]A9%-U
M<F4@/2`G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H:7,@;6%Y('1A:V4@
M<V]M92!T:6UE+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8V]N=&EN=64_
M(BDI(#\^)SL*=F%R(&1I<W!L87E.86UE<SL*"F9U;F-T:6]N(&)U='1O;D-O
M=6YT*"D*>PH@("`@;G5M4V5L(#T@,#L*("`@(&9O<B`H=F%R(&D@/2`P.R!I
M(#P@9&]C=6UE;G0N9FUA;F%G97(N96QE;65N=',N;&5N9W1H.R!I*RLI('L*
M("`@("`@("!I9B`H9&]C=6UE;G0N9FUA;F%G97(N96QE;65N='-;:5TN8VAE
M8VME9"D@>PH@("`@("`@("`@("!N=6U396PK*SL*("`@("`@("!]"B`@("!]
M"B`@("!R971U<FX@;G5M4V5L.PI]"@IF=6YC=&EO;B!G971396QE8W1E9$9O
M;&1E<G,H*0I["B`@("!V87(@<V5L(#T@(B(["B`@("!V87(@9F]L9&5R(#T@
M,#L*("`@(&9O<B`H=F%R(&$@/2`P.R!A(#P@9&]C=6UE;G0N9FUA;F%G97(N
M96QE;65N=',N;&5N9W1H.R!A*RLI('L*("`@("`@("!I9B`H9&]C=6UE;G0N
M9FUA;F%G97(N96QE;65N='-;85TN;F%M92`]/2`G9F]L9&5R7VQI<W1;72<I
M('L*("`@("`@("`@("`@:68@*&1O8W5M96YT+F9M86YA9V5R+F5L96UE;G1S
M6V%=+F-H96-K960@/3T@,2D@>PH@("`@("`@("`@("`@("`@<V5L(#T@<V5L
M("L@9&ES<&QA>4YA;65S6V9O;&1E<ET@*R`B7&XB.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&9O;&1E<BLK.PH@("`@("`@('T*("`@('T*"B`@("!I
M9B`H<V5L+F-H87)!="AS96PN;&5N9W1H("T@,2D@/3T@(EQN(BD@>PH@("`@
M("`@('-E;"`]('-E;"YS=6)S=')I;F<H,"P@<V5L+FQE;F=T:"`M(#$I.PH@
M("`@?0H*("`@(')E='5R;B!S96P["GT*"F9U;F-T:6]N(&-H;V]S94%C=&EO
M;BAI*0I["B`@("!V87(@86-T:6]N.PH*("`@(&EF("AI(#T](#`I('L*("`@
M("`@("!A8W1I;VX@/2!D;V-U;65N="YF;6%N86=E<BYA8W1I;VY?8VAO;W-E
M,"YO<'1I;VYS6V1O8W5M96YT+F9M86YA9V5R+F%C=&EO;E]C:&]O<V4P+G-E
M;&5C=&5D26YD97A=+G9A;'5E.PH@("`@?2!E;'-E('L*("`@("`@("!A8W1I
M;VX@/2!D;V-U;65N="YF;6%N86=E<BYA8W1I;VY?8VAO;W-E,2YO<'1I;VYS
M6V1O8W5M96YT+F9M86YA9V5R+F%C=&EO;E]C:&]O<V4Q+G-E;&5C=&5D26YD
M97A=+G9A;'5E.PH@("`@?0H*("`@(&EF("AA8W1I;VX@/3T@)V-R96%T95]F
M;VQD97(G*2!["B`@("`@("`@8W)E871E36%I;&)O>"@I.PH@("`@?2!E;'-E
M(&EF("AA8W1I;VX@/3T@)W)E8G5I;&1?=')E92<I('L*("`@("`@("!S=6)M
M:71!8W1I;VXH86-T:6]N*3L*("`@('T@96QS92!I9B`H8G5T=&]N0V]U;G0H
M*2`]/2`P*2!["B`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")0;&5A<V4@<V5L96-T(&$@9F]L9&5R(&)E9F]R92!Y;W4@<&5R9F]R
M;2!T:&ES(&%C=&EO;BXB*2D@/SXG*3L*("`@('T@96QS92!I9B`H86-T:6]N
M(#T]("=R96YA;65?9F]L9&5R)RD@>PH@("`@("`@(')E;F%M94UA:6QB;W@H
M*3L*("`@('T@96QS92!I9B`H86-T:6]N(#T]("=S=6)S8W)I8F5?9F]L9&5R
M)R!\?`H@("`@("`@("`@("`@("!A8W1I;VX@/3T@)W5N<W5B<V-R:6)E7V9O
M;&1E<B<@?'P*("`@("`@("`@("`@("`@86-T:6]N(#T]("=P;VQL7V9O;&1E
M<B<@?'P*("`@("`@("`@("`@("`@86-T:6]N(#T]("=E>'!U;F=E7V9O;&1E
M<B<@?'P*("`@("`@("`@("`@("`@86-T:6]N(#T]("=N;W!O;&Q?9F]L9&5R
M)R!\?`H@("`@("`@("`@("`@("!A8W1I;VX@/3T@)VUA<FM?9F]L9&5R7W-E
M96XG('Q\"B`@("`@("`@("`@("`@(&%C=&EO;B`]/2`G;6%R:U]F;VQD97)?
M=6YS965N)R!\?`H@("`@("`@("`@("`@("!A8W1I;VX@/3T@)V1E;&5T95]F
M;VQD97)?8V]N9FER;2<@?'P*("`@("`@("`@("`@("`@86-T:6]N(#T]("=F
M;VQD97)S7V5M<'1Y7VUA:6QB;WA?8V]N9FER;2<I('L*("`@("`@("!S=6)M
M:71!8W1I;VXH86-T:6]N*3L*("`@('T@96QS92!I9B`H86-T:6]N(#T]("=D
M;W=N;&]A9%]F;VQD97(G('Q\"B`@("`@("`@("`@("`@(&%C=&EO;B`]/2`G
M9&]W;FQO861?9F]L9&5R7WII<"<I('L*("`@("`@("!D;W=N;&]A9$UA:6QB
M;W@H86-T:6]N*3L*("`@('T@96QS92!I9B`H86-T:6]N(#T]("=I;7!O<G1?
M;6)O>"<I('L*("`@("`@("!I9B`H8G5T=&]N0V]U;G0H*2`^(#$I('L*("`@
M("`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")/;FQY
M(&]N92!F;VQD97(@<VAO=6QD(&)E('-E;&5C=&5D(&9O<B!T:&ES(&%C=&EO
M;BXB*2D@/SXG*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!S=6)M
M:71!8W1I;VXH86-T:6]N*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N
M('-U8FUI=$%C=&EO;BAA*0I["B`@("!D;V-U;65N="YF;6%N86=E<BYA8W1I
M;VY)1"YV86QU92`](&$["B`@("!D;V-U;65N="YF;6%N86=E<BYS=6)M:70H
M*3L*?0H*9G5N8W1I;VX@8W)E871E36%I;&)O>"@I"GL*("`@('9A<B!C;W5N
M="`](&)U='1O;D-O=6YT*"D["B`@("!I9B`H8V]U;G0@/B`Q*2!["B`@("`@
M("`@=VEN9&]W+F%L97)T*'1O;TUA;GDI.PH@("`@("`@(')E='5R;CL*("`@
M('T*"B`@("!V87(@;6)O>#L*("`@(&EF("AC;W5N="`]/2`Q*2!["B`@("`@
M("`@;6)O>"`]('=I;F1O=RYP<F]M<'0H)SP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")9;W4@87)E(&-R96%T:6YG(&$@<W5B+69O;&1E<B!T;R`B*2D@/SXG
M("L@9V5T4V5L96-T961&;VQD97)S*"D@*R`G+EQN/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(E!L96%S92!E;G1E<B!T:&4@;F%M92!O9B!T:&4@;F5W(&9O
M;&1E<CHB*2D@/SY<;B<L("<G*3L*("`@('T@96QS92!["B`@("`@("`@;6)O
M>"`]('=I;F1O=RYP<F]M<'0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")9
M;W4@87)E(&-R96%T:6YG(&$@=&]P+6QE=F5L(&9O;&1E<BXB*2D@+B`G7&XG
M("X@861D<VQA<VAE<RA?*")0;&5A<V4@96YT97(@=&AE(&YA;64@;V8@=&AE
M(&YE=R!F;VQD97(Z(BDI(#\^7&XG+"`G)RD["B`@("!]"@H@("`@:68@*&UB
M;W@@(3T@;G5L;"`F)B!M8F]X("$]("<G*2!["B`@("`@("`@9&]C=6UE;G0N
M9FUA;F%G97(N;F5W7VUA:6QB;W@N=F%L=64@/2!M8F]X.PH@("`@("`@(&1O
M8W5M96YT+F9M86YA9V5R+F%C=&EO;DE$+G9A;'5E(#T@)V-R96%T95]F;VQD
M97(G.PH@("`@("`@(&1O8W5M96YT+F9M86YA9V5R+G-U8FUI="@I.PH@("`@
M?0I]"@IF=6YC=&EO;B!D;W=N;&]A9$UA:6QB;W@H86-T:6]N:60I"GL*("`@
M('9A<B!C;W5N="`](&)U='1O;D-O=6YT*"D["B`@("!I9B`H=VEN9&]W+F-O
M;F9I<FTH9&]W;FQO861#;VYF:7)M("L@(EQN(B`K(&=E=%-E;&5C=&5D1F]L
M9&5R<R@I("L@(EQN(B`K(&1O=VYL;V%D4W5R92DI('L*("`@("`@("!D;V-U
M;65N="YF;6%N86=E<BYA8W1I;VY)1"YV86QU92`](&%C=&EO;FED.PH@("`@
M("`@(&1O8W5M96YT+F9M86YA9V5R+G-U8FUI="@I.PH@("`@?0I]"@IF=6YC
M=&EO;B!R96YA;65-86EL8F]X*"D*>PH@("`@;F5W;F%M97,@/2`G)SL*("`@
M(&]L9&YA;65S(#T@)R<["@H@("`@=F%R(&H@/2`P.PH@("`@=VAI;&4@*&1O
M8W5M96YT+F9M86YA9V5R+F5L96UE;G1S6VI=+FYA;64@(3T@(F9O;&1E<E]L
M:7-T6UTB*2!["B`@("`@("`@:BLK.PH@("`@?0H*("`@(&9O<B`H=F%R(&D@
M/2!J.R!I(#P@9&]C=6UE;G0N9FUA;F%G97(N96QE;65N=',N;&5N9W1H.R!I
M*RLI('L*("`@("`@("!I9B`H9&]C=6UE;G0N9FUA;F%G97(N96QE;65N='-;
M:5TN='EP92`]/2`B8VAE8VMB;W@B("8F(&1O8W5M96YT+F9M86YA9V5R+F5L
M96UE;G1S6VE=+F-H96-K960I('L*("`@("`@("`@("`@=&UP(#T@=VEN9&]W
M+G!R;VUP="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO=2!A<F4@<F5N
M86UI;F<@=&AE(&9O;&1E<CH@(BDI(#\^)R`K"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9&ES<&QA>4YA;65S6VD@+2!J72`K(")<;B(@*PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B4&QE87-E(&5N=&5R('1H92!N97<@;F%M93HB*2D@/SXG
M+"!D:7-P;&%Y3F%M97-;:2`M(&I=*3L*("`@("`@("`@("`@:68@*'1M<"`]
M/2!N=6QL('Q\('1M<"`]/2`G)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&YE=VYA;65S(#T@
M;F5W;F%M97,@*R!T;7`@*R`B7&XB.PH@("`@("`@("`@("!O;&1N86UE<R`]
M(&]L9&YA;65S("L@9&]C=6UE;G0N9FUA;F%G97(N96QE;65N='-;:5TN=F%L
M=64@*R`B7&XB.PH@("`@("`@('T*("`@('T*("`@(&EF("AN97=N86UE<RYC
M:&%R070H;F5W;F%M97,N;&5N9W1H("T@,2D@/3T@(EQN(BD@>PH@("`@("`@
M(&YE=VYA;65S(#T@;F5W;F%M97,N<W5B<W1R:6YG*#`L(&YE=VYA;65S+FQE
M;F=T:"`M(#$I.PH@("`@?0H@("`@:68@*&]L9&YA;65S+F-H87)!="AO;&1N
M86UE<RYL96YG=&@@+2`Q*2`]/2`B7&XB*2!["B`@("`@("`@;VQD;F%M97,@
M/2!O;&1N86UE<RYS=6)S=')I;F<H,"P@;VQD;F%M97,N;&5N9W1H("T@,2D[
M"B`@("!]"B`@("!D;V-U;65N="YF;6%N86=E<BYN97=?;F%M97,N=F%L=64@
M/2!N97=N86UE<SL*("`@(&1O8W5M96YT+F9M86YA9V5R+F]L9%]N86UE<RYV
M86QU92`](&]L9&YA;65S.PH@("`@9&]C=6UE;G0N9FUA;F%G97(N86-T:6]N
M240N=F%L=64@/2`G<F5N86UE7V9O;&1E<B<["B`@("!D;V-U;65N="YF;6%N
M86=E<BYS=6)M:70H*3L*("`@(')E='5R;B!T<G5E.PI]"@IF=6YC=&EO;B!T
M;V=G;&5396QE8W1I;VXH*0I["B`@("!V87(@=&]T86P@/2`P.PH@("`@=F%R
M(&-H96-K960@/2`P.PH@("`@9F]R("AV87(@:2`](#`[(&D@/"!D;V-U;65N
M="YF;6%N86=E<BYE;&5M96YT<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF
M("AD;V-U;65N="YF;6%N86=E<BYE;&5M96YT<UMI72YN86UE(#T](")F;VQD
M97)?;&ES=%M=(BD@>PH@("`@("`@("`@("!T;W1A;"LK.PH@("`@("`@("`@
M("!I9B`H9&]C=6UE;G0N9FUA;F%G97(N96QE;65N='-;:5TN8VAE8VME9"D@
M>PH@("`@("`@("`@("`@("`@8VAE8VME9"LK.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?2`@"B`@("`*("`@('9A<B!N97=?=F%L=64@/2`H=&]T
M86P@(3T@8VAE8VME9"D["B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&1O8W5M
M96YT+F9M86YA9V5R+F5L96UE;G1S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@
M:68@*&1O8W5M96YT+F9M86YA9V5R+F5L96UE;G1S6VE=+FYA;64@/3T@(F9O
M;&1E<E]L:7-T6UTB*2!["B`@("`@("`@("`@(&1O8W5M96YT+F9M86YA9V5R
M+F5L96UE;G1S6VE=+F-H96-K960@/2!N97=?=F%L=64["B`@("`@("`@?0H@
M("`@?2`@"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+W1E;7!L871E<R]S96%R8V@O````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,C`T-C``
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&5M<&QA=&5S+W-E87)C:"]F
M:65L9',N:6YC````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S$W`#$P
M-#$W,S8R-S8V`#`R,C0S,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\='(^"CP_<&AP(&EF("@H)&D@/3T@,"D@)B8@(21L
M87-T7V9I96QD*3H@/SX*(#QT9#XF;F)S<#L\+W1D/@H\/W!H<"!E;'-E:68@
M*"1I(#X@,"DZ(#\^"B`\=&0^/'-T<F]N9SX\/W!H<"!E8VAO("AI<U]N=6QL
M*"1S96%R8VA;)VUA=&-H)UTI('Q\("@D<V5A<F-H6R=M871C:"==(#T]("=A
M;F0G*2D@/R!?*")!3D0B*2`Z(%\H(D]2(BD@/SX\+W-T<F]N9SXF;F)S<#L\
M+W1D/@H\/W!H<"!E;F1I9CL@/SX*(#QT9"!S='EL93TB<&%D9&EN9SHR<'@B
M/@H@(#QS96QE8W0@;VYC:&%N9V4](F1O8W5M96YT+G-E87)C:"YS=6)M:70H
M*3MR971U<FX@=')U93LB(&YA;64](F9I96QD6SP_<&AP(&5C:&\@)&D@/SY=
M(B!I9#TB9FEE;&1?/#]P:'`@96-H;R`D:2`_/B(^"CP_<&AP(&EF("@D;&%S
M=%]F:65L9"DZ(#\^"B`@(#QO<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?
M*")396QE8W0@82!F:65L9"(I(#\^/"]O<'1I;VX^"B`@(#QO<'1I;VX@=F%L
M=64](B(^("TM+2TM+2TM+2`\+V]P=&EO;CX*/#]P:'`@96YD:68[(#\^"CP_
M<&AP(&9O<F5A8V@@*"1I;7!?<V5A<F-H7V9I96QD<R!A<R`D:V5Y(#T^("1V
M86PI.B`_/@H@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO("1K97D@/SXB
M/#]P:'`@:68@*"1C=7)R7V9I96QD(#T]("1K97DI(&5C:&\@)R!S96QE8W1E
M9#TB<V5L96-T960B)SL@/SX^/#]P:'`@)&QA8F5L(#T@)'9A;%LG;&%B96PG
M73L@96-H;R!?*"1L86)E;"D@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R96%C
M:#L@/SX*("`\+W-E;&5C=#X*(#PO=&0^"CP_<&AP(&EF("AI<U]N=6QL*"1C
M=7)R7V9I96QD*2DZ(#\^"B`\=&0^)FYB<W`[/"]T9#X*/#]P:'`@96QS96EF
M("@H)&EM<%]S96%R8VA?9FEE;&1S6R1C=7)R7V9I96QD75LG='EP92==(#T]
M($E-4%]314%20TA?2$5!1$52*2!\?`H@("`@("`@("`@("`@("@D:6UP7W-E
M87)C:%]F:65L9'-;)&-U<G)?9FEE;&1=6R=T>7!E)UT@/3T@24U07U-%05)#
M2%]"3T19*2!\?`H@("`@("`@("`@("`@("@D:6UP7W-E87)C:%]F:65L9'-;
M)&-U<G)?9FEE;&1=6R=T>7!E)UT@/3T@24U07U-%05)#2%]415A4*2DZ(#\^
M"B`\=&0@8VQA<W,](FET96TP(&QE9G1!;&EG;B(^"B`@/&EN<'5T('1Y<&4]
M(G1E>'0B(&YA;64](G-E87)C:%]T97AT6SP_<&AP(&5C:&\@)&D@/SY=(B!S
M:7IE/2(T,"(@/#]P:'`@:68@*"%E;7!T>2@D<V5A<F-H6R=T97AT)UU;)&E=
M*2D@96-H;R`G=F%L=64](B<@+B`D<V5A<F-H6R=T97AT)UU;)&E=("X@)R(@
M)SL@/SXO/@H@(#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB<V5A<F-H
M7W1E>'1?;F]T6SP_<&AP(&5C:&\@)&D@/SY=(B`\/W!H<"!I9B`H(65M<'1Y
M*"1S96%R8VA;)W1E>'1?;F]T)UU;)&E=*2D@96-H;R`G8VAE8VME9#TB8VAE
M8VME9"(@)SL@/SXO/@H@("`@/&5M/CP_<&AP(&5C:&\@7R@B1&\@3D]4(&UA
M=&-H(BD@/SX\+V5M/@H@/"]T9#X*/#]P:'`@96QS96EF("@D:6UP7W-E87)C
M:%]F:65L9'-;)&-U<G)?9FEE;&1=6R=T>7!E)UT@/3T@24U07U-%05)#2%]$
M051%*3H@/SX*(#QT9"!C;&%S<STB:71E;3`@;&5F=$%L:6=N(B!N;W=R87`]
M(FYO=W)A<"(^"B`@/#]P:'`@96-H;R!B=6EL9$UO;G1H5VED9V5T*"=S96%R
M8VA?9&%T95LG("X@)&D@+B`G75MM;VYT:%TG+"!I<W-E="@D<V5A<F-H6R=D
M871E)UU;)&E=6R=M;VYT:"==*2`_("1S96%R8VA;)V1A=&4G75LD:5U;)VUO
M;G1H)UT@.B`D8W5R<E]D871E6R=M;VXG72D@/SX*("`\/W!H<"!E8VAO(&)U
M:6QD1&%Y5VED9V5T*"=S96%R8VA?9&%T95LG("X@)&D@+B`G75MD87E=)RP@
M:7-S970H)'-E87)C:%LG9&%T92==6R1I75LG9&%Y)UTI(#\@)'-E87)C:%LG
M9&%T92==6R1I75LG9&%Y)UT@.B`D8W5R<E]D871E6R=M9&%Y)UTL(")O;F-H
M86=E/5PB9&%T94-H96-K*"=O;B<I7"(B*2`_/@H@(#P_<&AP(&5C:&\@8G5I
M;&1996%R5VED9V5T*"=S96%R8VA?9&%T95LG("X@)&D@+B`G75MY96%R72<L
M("TR,"P@:7-S970H)'-E87)C:%LG9&%T92==6R1I75LG>65A<B==*2`_("1S
M96%R8VA;)V1A=&4G75LD:5U;)WEE87(G73H@)&-U<G)?9&%T95LG>65A<B==
M+"`B;VYC:&%N9V4]7")D871E0VAE8VLH)V]N)RE<(B(I(#\^"CP_<&AP(&EF
M("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=J879A<V-R:7!T
M)RDI('L*("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=O<&5N7V-A;&5N9&%R
M+FIS)RP@)VAO<F1E)RD["B`@("!E8VAO("<\9&EV(&ED/2)G;W1O(B!C;&%S
M<STB8V]N=')O;"(@<W1Y;&4](G!O<VET:6]N.F%B<V]L=71E.W9I<VEB:6QI
M='DZ:&ED9&5N.W!A9&1I;F<Z,7!X(CX\+V1I=CXG.PH@("`@96-H;R!(;W)D
M93HZ;&EN:R@G(R<L(%\H(E-E;&5C="!A(&1A=&4B*2P@)R<L("<G+"`G;W!E
M;D-A;&5N9&%R*%PG9&%T96EM9UPG+"!<)W-E87)C:%]D871E6R<@+B`D:2`N
M("==7"<I.R!R971U<FX@9F%L<V4[)RD@+B!(;W)D93HZ:6UG*"=C86QE;F1A
M<BYP;F<G+"!?*")#86QE;F1A<B(I+"`G86QI9VX](G1O<"(@:60](F1A=&5I
M;6<B)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D
M92<I*2`N("<\+V$^)SL*?2`_/@H@/"]T9#X*/#]P:'`@96YD:68[(#\^"CP_
M<&AP(&EF("@A)&QA<W1?9FEE;&0I.B`_/@H@/'1D/B9N8G-P.SQI;G!U="!T
M>7!E/2)I;6%G92(@<W)C/2(\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG971);6%G941I<B@G:&]R9&4G*2`N("<O8VQO<V4N<&YG)R`_/B(@
M;VYC;&EC:STB9&]C=6UE;G0N<V5A<F-H+F1E;&5T95]F:65L9%]I9"YV86QU
M93T\/W!H<"!E8VAO("1I(#\^.V1O8W5M96YT+G-E87)C:"YA8W1I;VY)1"YV
M86QU93TG9&5L971E7V9I96QD)SMD;V-U;65N="YS96%R8V@N<W5B;6ET*"D[
M<F5T=7)N('1R=64[(B!V86QU93TB/#]P:'`@96-H;R!?*")296UO=F4@1FEE
M;&0@1G)O;2!396%R8V@B*2`_/B(@+SX\+W1D/@H\/W!H<"!E;'-E:68@*"1L
M87-T7V9I96QD("8F("@D:2`A/2`P*2DZ(#\^"B`\=&0^)FYB<W`[/"]T9#X*
M/#]P:'`@96YD:68[(#\^"CPO='(^"@``````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]T96UP;&%T97,O<V5A<F-H+VUA:6XN:6YC````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38W-3(`,3`T,3<S-C(W-C8`,#(R,3`W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"`@
M(#PO=&%B;&4^"B`@/"]T9#X*(#PO='(^"@H@/'1R/@H@(#QT9"!C;&%S<STB
M<VUA;&QH96%D97(@;&5F=$%L:6=N(B!C;VQS<&%N/2(R(CX\/W!H<"!E8VAO
M(%\H(DUE<W-A9V4@9FQA9W,B*2`_/CPO=&0^"B`\+W1R/@H*(#QT<CX*("`\
M=&0@8VQA<W,](FET96TB(&-O;'-P86X](C(B/@H@("`\=&%B;&4@8V5L;'-P
M86-I;F<](C`B(&-E;&QP861D:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`@("`\
M='(^"B`@("`@/'1D(&-L87-S/2)I=&5M,2!L969T06QI9VXB(&YO=W)A<#TB
M;F]W<F%P(CX*("`@("`@/&EN<'5T('1Y<&4](G)A9&EO(B!I9#TB9FQA9U]S
M965N7S`B(&YA;64](G-E87)C:%]F;&%G6SP_<&AP(&5C:&\@24U07U-%05)#
M2%]&3$%'7U-%14X@/SY=(B!V86QU93TB,"(@/#]P:'`@:68@*"%E;7!T>2@D
M<V5A<F-H6R=F;&%G)UTI("8F("1S96%R8VA;)V9L86<G75M)35!?4T5!4D-(
M7T9,04=?4T5%3ET@/3T@,"D@96-H;R`G8VAE8VME9#TB8VAE8VME9"(@)SL@
M/SXO/@H@("`@("`\96T^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)V9L86=?
M<V5E;E\P)RP@7R@B3VQD(&UE<W-A9V5S(BDI(#\^/"]E;3X*("`@("`\+W1D
M/@H@("`@(#QT9"!C;&%S<STB:71E;3$@;&5F=$%L:6=N(B!N;W=R87`](FYO
M=W)A<"(^"B`@("`@(#QI;G!U="!T>7!E/2)R861I;R(@:60](F9L86=?<V5E
M;E\Q(B!N86UE/2)S96%R8VA?9FQA9UL\/W!H<"!E8VAO($E-4%]314%20TA?
M1DQ!1U]3145.(#\^72(@=F%L=64](C$B(#P_<&AP(&EF("@A96UP='DH)'-E
M87)C:%LG9FQA9R==*2`F)B`D<V5A<F-H6R=F;&%G)UU;24U07U-%05)#2%]&
M3$%'7U-%14Y=(#T](#$I(&5C:&\@)V-H96-K960](F-H96-K960B("<[(#\^
M+SX*("`@("`@/&5M/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=F;&%G7W-E
M96Y?,2<L(%\H(DYE=R!M97-S86=E<R(I*2`_/CPO96T^"B`@("`@/"]T9#X*
M("`@("`\=&0@8VQA<W,](FET96TQ(&QE9G1!;&EG;B(@;F]W<F%P/2)N;W=R
M87`B/@H@("`@("`\:6YP=70@='EP93TB<F%D:6\B(&ED/2)F;&%G7W-E96Y?
M,B(@;F%M93TB<V5A<F-H7V9L86=;/#]P:'`@96-H;R!)35!?4T5!4D-(7T9,
M04=?4T5%3B`_/ETB('9A;'5E/2(R(B`\/W!H<"!I9B`H96UP='DH)'-E87)C
M:%LG9FQA9R==*2!\?"`D<V5A<F-H6R=F;&%G)UU;24U07U-%05)#2%]&3$%'
M7U-%14Y=(#T](#(I(&5C:&\@)V-H96-K960](F-H96-K960B("<[(#\^("\^
M"B`@("`@(#QE;3X\/W!H<"!E8VAO(%\H(D)O=&@B*2`_/CPO96T^"B`@("`@
M/"]T9#X*("`@("`\=&0@8VQA<W,](FET96TQ(B!W:61T:#TB,3`P)2(^)FYB
M<W`[/"]T9#X*("`@(#PO='(^"@H@("`@/'1R/@H@("`@(#QT9"!C;&%S<STB
M:71E;3`@;&5F=$%L:6=N(B!N;W=R87`](FYO=W)A<"(^"B`@("`@(#QI;G!U
M="!T>7!E/2)R861I;R(@:60](F9L86=?86YS=V5R961?,"(@;F%M93TB<V5A
M<F-H7V9L86=;/#]P:'`@96-H;R!)35!?4T5!4D-(7T9,04=?04Y35T52140@
M/SY=(B!V86QU93TB,"(@/#]P:'`@:68@*"%E;7!T>2@D<V5A<F-H6R=F;&%G
M)UTI("8F("1S96%R8VA;)V9L86<G75M)35!?4T5!4D-(7T9,04=?04Y35T52
M141=(#T](#`I(&5C:&\@)V-H96-K960](F-H96-K960B("<[(#\^+SX*("`@
M("`@/&5M/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=F;&%G7V%N<W=E<F5D
M7S`G+"!?*")!;G-W97)E9"!M97-S86=E<R(I*2`_/CPO96T^"B`@("`@/"]T
M9#X*("`@("`\=&0@8VQA<W,](FET96TP(&QE9G1!;&EG;B(@;F]W<F%P/2)N
M;W=R87`B/@H@("`@("`\:6YP=70@='EP93TB<F%D:6\B(&ED/2)F;&%G7V%N
M<W=E<F5D7S$B(&YA;64](G-E87)C:%]F;&%G6SP_<&AP(&5C:&\@24U07U-%
M05)#2%]&3$%'7T%.4U=%4D5$(#\^72(@=F%L=64](C$B(#P_<&AP(&EF("@A
M96UP='DH)'-E87)C:%LG9FQA9R==*2`F)B`D<V5A<F-H6R=F;&%G)UU;24U0
M7U-%05)#2%]&3$%'7T%.4U=%4D5$72`]/2`Q*2!E8VAO("=C:&5C:V5D/2)C
M:&5C:V5D(B`G.R`_/B\^"B`@("`@(#QE;3X\/W!H<"!E8VAO($AO<F1E.CIL
M86)E;"@G9FQA9U]A;G-W97)E9%\Q)RP@7R@B56YA;G-W97)E9"!M97-S86=E
M<R(I*2`_/CPO96T^"B`@("`@/"]T9#X*("`@("`\=&0@8VQA<W,](FET96TP
M(&QE9G1!;&EG;B(@;F]W<F%P/2)N;W=R87`B/@H@("`@("`\:6YP=70@='EP
M93TB<F%D:6\B(&ED/2)F;&%G7V%N<W=E<F5D7S(B(&YA;64](G-E87)C:%]F
M;&%G6SP_<&AP(&5C:&\@24U07U-%05)#2%]&3$%'7T%.4U=%4D5$(#\^72(@
M=F%L=64](C(B(#P_<&AP(&EF("AE;7!T>2@D<V5A<F-H6R=F;&%G)UTI('Q\
M("1S96%R8VA;)V9L86<G75M)35!?4T5!4D-(7T9,04=?04Y35T52141=(#T]
M(#(I(&5C:&\@)V-H96-K960](F-H96-K960B("<[(#\^+SX*("`@("`@/&5M
M/CP_<&AP(&5C:&\@7R@B0F]T:"(I(#\^/"]E;3X*("`@("`\+W1D/@H@("`@
M(#QT9"!C;&%S<STB:71E;3`B('=I9'1H/2(Q,#`E(CXF;F)S<#L\+W1D/@H@
M("`@/"]T<CX*"B`@("`\='(^"B`@("`@/'1D(&-L87-S/2)I=&5M,2!L969T
M06QI9VXB(&YO=W)A<#TB;F]W<F%P(CX*("`@("`@/&EN<'5T('1Y<&4](G)A
M9&EO(B!I9#TB9FQA9U]F;&%G9V5D7S`B(&YA;64](G-E87)C:%]F;&%G6SP_
M<&AP(&5C:&\@24U07U-%05)#2%]&3$%'7T9,04='140@/SY=(B!V86QU93TB
M,"(@/#]P:'`@:68@*"%E;7!T>2@D<V5A<F-H6R=F;&%G)UTI("8F("1S96%R
M8VA;)V9L86<G75M)35!?4T5!4D-(7T9,04=?1DQ!1T=%1%T@/3T@,"D@96-H
M;R`G8VAE8VME9#TB8VAE8VME9"(@)SL@/SXO/@H@("`@("`\96T^/#]P:'`@
M96-H;R!(;W)D93HZ;&%B96PH)V9L86=?9FQA9V=E9%\P)RP@7R@B26UP;W)T
M86YT(&UE<W-A9V5S(BDI(#\^/"]E;3X*("`@("`\+W1D/@H@("`@(#QT9"!C
M;&%S<STB:71E;3$@;&5F=$%L:6=N(B!N;W=R87`](FYO=W)A<"(^"B`@("`@
M(#QI;G!U="!T>7!E/2)R861I;R(@:60](F9L86=?9FQA9V=E9%\Q(B!N86UE
M/2)S96%R8VA?9FQA9UL\/W!H<"!E8VAO($E-4%]314%20TA?1DQ!1U]&3$%'
M1T5$(#\^72(@=F%L=64](C$B(#P_<&AP(&EF("@A96UP='DH)'-E87)C:%LG
M9FQA9R==*2`F)B`D<V5A<F-H6R=F;&%G)UU;24U07U-%05)#2%]&3$%'7T9,
M04='141=(#T](#$I(&5C:&\@)V-H96-K960](F-H96-K960B("<[(#\^+SX*
M("`@("`@("`@("`@/&5M/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=F;&%G
M7V9L86=G961?,2<L(%\H(DYO="!I;7!O<G1A;G0@;65S<V%G97,B*2D@/SX\
M+V5M/@H@("`@("`\+W1D/@H@("`@(#QT9"!C;&%S<STB:71E;3$@;&5F=$%L
M:6=N(B!N;W=R87`](FYO=W)A<"(^"B`@("`@(#QI;G!U="!T>7!E/2)R861I
M;R(@:60](F9L86=?9FQA9V=E9%\R(B!N86UE/2)S96%R8VA?9FQA9UL\/W!H
M<"!E8VAO($E-4%]314%20TA?1DQ!1U]&3$%'1T5$(#\^72(@=F%L=64](C(B
M(#P_<&AP(&EF("AE;7!T>2@D<V5A<F-H6R=F;&%G)UTI('Q\("1S96%R8VA;
M)V9L86<G75M)35!?4T5!4D-(7T9,04=?1DQ!1T=%1%T@/3T@,BD@96-H;R`G
M8VAE8VME9#TB8VAE8VME9"(@)SL@/SXO/@H@("`@("`\96T^/#]P:'`@96-H
M;R!?*")";W1H(BD@/SX\+V5M/@H@("`@(#PO=&0^"B`@("`@/'1D(&-L87-S
M/2)I=&5M,2(@=VED=&@](C$P,"4B/B9N8G-P.SPO=&0^"B`@("`\+W1R/@H*
M("`@(#QT<CX*("`@("`\=&0@8VQA<W,](FET96TP(&QE9G1!;&EG;B(@;F]W
M<F%P/2)N;W=R87`B/@H@("`@("`\:6YP=70@='EP93TB<F%D:6\B(&ED/2)F
M;&%G7V1E;&5T961?,"(@;F%M93TB<V5A<F-H7V9L86=;/#]P:'`@96-H;R!)
M35!?4T5!4D-(7T9,04=?1$5,151%1"`_/ETB('9A;'5E/2(P(B`\/W!H<"!I
M9B`H(65M<'1Y*"1S96%R8VA;)V9L86<G72D@)B8@)'-E87)C:%LG9FQA9R==
M6TE-4%]314%20TA?1DQ!1U]$14Q%5$5$72`]/2`P*65C:&\@)V-H96-K960]
M(F-H96-K960B("<[(#\^+SX*("`@("`@/&5M/CP_<&AP(&5C:&\@2&]R9&4Z
M.FQA8F5L*"=F;&%G7V1E;&5T961?,"<L(%\H(D1E;&5T960@;65S<V%G97,B
M*2D@/SX\+V5M/@H@("`@(#PO=&0^"B`@("`@/'1D(&-L87-S/2)I=&5M,"!L
M969T06QI9VXB(&YO=W)A<#TB;F]W<F%P(CX*("`@("`@/&EN<'5T('1Y<&4]
M(G)A9&EO(B!I9#TB9FQA9U]D96QE=&5D7S$B(&YA;64](G-E87)C:%]F;&%G
M6SP_<&AP(&5C:&\@24U07U-%05)#2%]&3$%'7T1%3$54140@/SY=(B!V86QU
M93TB,2(@/#]P:'`@:68@*"%E;7!T>2@D<V5A<F-H6R=F;&%G)UTI("8F("1S
M96%R8VA;)V9L86<G75M)35!?4T5!4D-(7T9,04=?1$5,151%1%T@/3T@,2D@
M96-H;R`G8VAE8VME9#TB8VAE8VME9"(@)SL@/SXO/@H@("`@("`\96T^/#]P
M:'`@96-H;R!(;W)D93HZ;&%B96PH)V9L86=?9&5L971E9%\Q)RP@7R@B3F]T
M(&1E;&5T960@;65S<V%G97,B*2D@/SX\+V5M/@H@("`@(#PO=&0^"B`@("`@
M/'1D(&-L87-S/2)I=&5M,"!L969T06QI9VXB(&YO=W)A<#TB;F]W<F%P(CX*
M("`@("`@/&EN<'5T('1Y<&4](G)A9&EO(B!I9#TB9FQA9U]D96QE=&5D7S(B
M(&YA;64](G-E87)C:%]F;&%G6SP_<&AP(&5C:&\@24U07U-%05)#2%]&3$%'
M7T1%3$54140@/SY=(B!V86QU93TB,B(@/#]P:'`@:68@*&5M<'1Y*"1S96%R
M8VA;)V9L86<G72D@?'P@)'-E87)C:%LG9FQA9R==6TE-4%]314%20TA?1DQ!
M1U]$14Q%5$5$72`]/2`R*2!E8VAO("=C:&5C:V5D/2)C:&5C:V5D(B`G.R`_
M/B\^"B`@("`@(#QE;3X\/W!H<"!E8VAO(%\H(D)O=&@B*2`_/CPO96T^"B`@
M("`@/"]T9#X*("`@("`\=&0@8VQA<W,](FET96TP(B!W:61T:#TB,3`P)2(^
M)FYB<W`[/"]T9#X*("`@(#PO='(^"B`@(#PO=&%B;&4^"B`@/"]T9#X*(#PO
M='(^"@H\/W!H<"!I9B`H(65M<'1Y*"1S96%R8VA;)VUB;W@G72DI.B`_/@H@
M/&EN<'5T(&ED/2)P<F5S96QE8W1E9%]F;VQD97)S(B!T>7!E/2)H:61D96XB
M(&YA;64](G-E87)C:%]F;VQD97)S6UTB('9A;'5E/2(\/W!H<"!E8VAO("1S
M96%R8VA;)VUB;W@G72`_/B(@+SX*/#]P:'`@96QS93H@/SX*(#QT<CX*("`\
M=&0@8VQA<W,](G-M86QL:&5A9&5R(&QE9G1!;&EG;B(@8V]L<W!A;CTB,B(^
M/#]P:'`@96-H;R!?*")-97-S86=E(&9O;&1E<G,B*2`_/CPO=&0^"B`\+W1R
M/@H*(#QT<CX*("`\=&0@8VQA<W,](FET96TB(&-O;'-P86X](C(B/@H@("`\
M82!H<F5F/2(C(B!O;F-L:6-K/2)T;V=G;&5!;&PH=')U92D[(')E='5R;B!F
M86QS93LB(&]N;6]U<V5O=F5R/2)S=&%T=7,])SP_<&AP(&5C:&\@7R@B4V5L
M96-T(&%L;"(I(#\^)SL@<F5T=7)N('1R=64[(CX\/W!H<"!E8VAO(%\H(E-E
M;&5C="!A;&PB*2`_/CPO83X@?`H@("`\82!H<F5F/2(C(B!O;F-L:6-K/2)T
M;V=G;&5!;&PH9F%L<V4I.R!R971U<FX@9F%L<V4[(B!O;FUO=7-E;W9E<CTB
M<W1A='5S/2<\/W!H<"!E8VAO(%\H(E-E;&5C="!N;VYE(BD@/SXG.R!R971U
M<FX@=')U93LB/CP_<&AP(&5C:&\@7R@B4V5L96-T(&YO;F4B*2`_/CPO83X*
M/#]P:'`@:68@*"1S=6)S8W)I8F4I.B`_/@H\/W!H<"`D:6YV97)S95]S=6)S
M8W)I8F4@/2`H)'-H;W=N(#T]($E-4%]314%20TA?4TA/5U]53E-50E-#4DE"
M140I(#\@24U07U-%05)#2%]32$]77U-50E-#4DE"141?3TY,62`Z($E-4%]3
M14%20TA?4TA/5U]53E-50E-#4DE"140[(#\^"B!\(#QA(&AR968](B,B(&]N
M8VQI8VL](F1O8W5M96YT+G-E87)C:"YS:&]W7W-U8G-C<FEB961?;VYL>2YV
M86QU93TG/#]P:'`@96-H;R`D:6YV97)S95]S=6)S8W)I8F4@/SXG.V1O8W5M
M96YT+G-E87)C:"YS=6)M:70H*3L@<F5T=7)N(&9A;'-E.R(@;VYM;W5S96]V
M97(](G-T871U<STG/#]P:'`@96-H;R`H)&EN=F5R<V5?<W5B<V-R:6)E*2`_
M(%\H(E-H;W<@3VYL>2!3=6)S8W)I8F5D($9O;&1E<G,B*2`Z(%\H(E-H;W<@
M06QL($9O;&1E<G,B*2`_/B<[<F5T=7)N('1R=64[(CX\/W!H<"!E8VAO("@D
M:6YV97)S95]S=6)S8W)I8F4I(#\@7R@B4VAO=R!/;FQY(%-U8G-C<FEB960@
M1F]L9&5R<R(I(#H@7R@B4VAO=R!!;&P@1F]L9&5R<R(I(#\^/"]A/@H\/W!H
M<"!E;F1I9CL@/SX*("`\+W1D/@H@/"]T<CX*"B`\='(^"B`@/'1D(&-L87-S
M/2)C;VYT<F]L(B!V86QI9VX](G1O<"(@86QI9VX](F-E;G1E<B(@8V]L<W!A
M;CTB,B(^"B`@(#QT86)L92!C96QL<W!A8VEN9STB,"(@8V5L;'!A9&1I;F<]
M(C(B('=I9'1H/2(Q,#`E(CX*("`@(#QT<CX*("`@("`\=&0@8VQA<W,](FET
M96T@;&5F=$%L:6=N(B!V86QI9VX](G1O<"(^"B`@("`@(#P_<&AP(&5C:&\@
M)&9O;&1E<FQI<W0@/SX*("`@("`\+W1D/@H@("`@/"]T<CX*("`@/"]T86)L
M93X*("`\+W1D/@H@/"]T<CX*/#]P:'`@96YD:68[(#\^"@H\/W!H<"!I9B`H
M)%]315-324].6R=I;7`G75LG8F%S95]P<F]T;V-O;"==("$]("=P;W`S)RDZ
M(#\^"B`\='(^"B`@/'1D(&-L87-S/2)S;6%L;&AE861E<B!L969T06QI9VXB
M(&-O;'-P86X](C(B/CP_<&AP(&5C:&\@7R@B5FER='5A;"!&;VQD97)S(BD@
M/SX\+W1D/@H@/"]T<CX*"B`\='(^"B`@/'1D(&-L87-S/2)I=&5M(B!C;VQS
M<&%N/2(R(CX*("`@/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!C96QL<&%D9&EN
M9STB,"(@=VED=&@](C$P,"4B/@H\/W!H<"!I9B`H)&5D:71?<75E<GE?=F9O
M;&1E<BDZ(#\^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)S879E
M7W9F;VQD97(B('9A;'5E/2(Q(B`O/@H\/W!H<"!E;'-E.B`_/@H@("`@/'1R
M/@H@("`@(#QT9"!C;&%S<STB:71E;3`@;&5F=$%L:6=N(B!N;W=R87`](FYO
M=W)A<"(^"B`@("`@(#QE;3X\/W!H<"!E8VAO(%\H(E-A=F4@<V5A<F-H(&%S
M(&$@=FER='5A;"!F;VQD97(_(BD@/SX\+V5M/B9N8G-P.SQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@:60](G-A=F5?=F9O;&1E<B(@;F%M93TB<V%V95]V9F]L
M9&5R(B`\/W!H<"!I9B`H(65M<'1Y*"1S96%R8VA;)W-A=F5?=F9O;&1E<B==
M*2D@96-H;R`G8VAE8VME9#TB8VAE8VME9"(@)SL@/SXO/@H@("`@(#PO=&0^
M"B`@("`\+W1R/@H\/W!H<"!E;F1I9CL@/SX*("`@(#QT<CX*("`@("`\=&0@
M8VQA<W,](FET96TQ(&QE9G1!;&EG;B(@;F]W<F%P/2)N;W=R87`B/@H@("`@
M("`\96T^/#]P:'`@96-H;R!?*")6:7)T=6%L(&9O;&1E<B!L86)E;"(I(#\^
M.CPO96T^)FYB<W`[/&EN<'5T('1Y<&4](G1E>'0B(&ED/2)V9F]L9&5R7VQA
M8F5L(B!N86UE/2)V9F]L9&5R7VQA8F5L(B`\/W!H<"!I9B`H(65M<'1Y*"1S
M96%R8VA;)W9F;VQD97)?;&%B96PG72DI(&5C:&\@)W9A;'5E/2(G("X@)'-E
M87)C:%LG=F9O;&1E<E]L86)E;"==("X@)R(@)SL@/SXO/@H@("`@(#PO=&0^
M"B`@("`\+W1R/@H@("`\+W1A8FQE/@H@(#PO=&0^"B`\+W1R/@H\/W!H<"!E
M;F1I9CL@/SX*"B`\='(^"B`@/'1D('9A;&EG;CTB=&]P(B!C;VQS<&%N/2(R
M(CX*("`@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L
M=64](CP_<&AP(&5C:&\@)'-U8FUI=%]L86)E;"`_/B(@;VYC;&EC:STB<F5T
M=7)N(&9O<FU#:&5C:R@I.R(@+SX*("`@/&EN<'5T('1Y<&4](F)U='1O;B(@
M8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5S970B*2`_
M/B(@;VYC;&EC:STB9&]C=6UE;G0N<V5A<F-H+F%C=&EO;DE$+G9A;'5E(#T@
M)W)E<V5T7W-E87)C:"<[9&]C=6UE;G0N<V5A<F-H+G-U8FUI="@I.W)E='5R
M;B!T<G5E.R(@+SX*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*/"]D:78^"CPO
M9F]R;3X*`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+W1E;7!L871E<R]S96%R8V@O:F%V87-C<FEP="YI;F,`
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$S,@`Q,#0Q-S,V,C<V-@`P,C,S
M,34`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IF=6YC=&EO
M;B!T;V=G;&5!;&PH8VAE8VME9"D*>PH@("`@9F]R("AI(#T@,#L@:2`\(&1O
M8W5M96YT+G-E87)C:"YE;&5M96YT<RYL96YG=&@[(&DK*RD@>PH@("`@("`@
M(&EF("AD;V-U;65N="YS96%R8V@N96QE;65N='-;:5TN;F%M92YI;F1E>$]F
M*"=S96%R8VA?9F]L9&5R<R<I(#X](#`I('L*("`@("`@("`@("`@9&]C=6UE
M;G0N<V5A<F-H+F5L96UE;G1S6VE=+F-H96-K960@/2!C:&5C:V5D.PH@("`@
M("`@('T*("`@('T*?0H*9G5N8W1I;VX@9&%T94-H96-K*&9I96QD*0I["B`@
M("!I9B`H9&]C=6UE;G0N<V5A<F-H+F5L96UE;G1S6R=S96%R8VA?)R`K(&9I
M96QD("L@)U]M;VYT:"==+G-E;&5C=&5D26YD97@@/3T@,"D*("`@("`@("!D
M;V-U;65N="YS96%R8V@N96QE;65N='-;)W-E87)C:%\G("L@9FEE;&0@*R`G
M7VUO;G1H)UTN<V5L96-T961);F1E>"`]("(\/W!H<"!E8VAO(&1A=&4H)VTG
M*2`_/B(["@H@("`@:68@*&1O8W5M96YT+G-E87)C:"YE;&5M96YT<ULG<V5A
M<F-H7R<@*R!F:65L9"`K("=?9&%Y)UTN<V5L96-T961);F1E>"`]/2`P*0H@
M("`@("`@(&1O8W5M96YT+G-E87)C:"YE;&5M96YT<ULG<V5A<F-H7R<@*R!F
M:65L9"`K("=?9&%Y)UTN<V5L96-T961);F1E>"`]("(\/W!H<"!E8VAO(&1A
M=&4H)V0G*2`_/B(["@H@("`@:68@*&1O8W5M96YT+G-E87)C:"YE;&5M96YT
M<ULG<V5A<F-H7R<@*R!F:65L9"`K("=?>65A<B==+G9A;'5E(#T]("(B*0H@
M("`@("`@(&1O8W5M96YT+G-E87)C:"YE;&5M96YT<ULG<V5A<F-H7R<@*R!F
M:65L9"`K("=?>65A<B==+G9A;'5E(#T@(CP_<&AP(&5C:&\@9&%T92@G62<I
M(#\^(CL*?0H*9G5N8W1I;VX@9F]R;4-H96-K*"D*>PH\/W!H<"!I9B`H96UP
M='DH)'-E87)C:%LG;6)O>"==*2DZ(#\^"B`@("!V87(@;G5M7W-E;&5C=&5D
M(#T@,#L*"B`@("!F;W(@*&D@/2`P.R!I(#P@9&]C=6UE;G0N<V5A<F-H+F5L
M96UE;G1S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*&1O8W5M96YT+G-E
M87)C:"YE;&5M96YT<UMI72YI9"YI;F1E>$]F*"=P<F5S96QE8W1E9%]F;VQD
M97)S)RD@/CT@,"D@>PH@("`@("`@("`@("!N=6U?<V5L96-T960K*SL*("`@
M("`@("!](&5L<V4@:68@*&1O8W5M96YT+G-E87)C:"YE;&5M96YT<UMI72YN
M86UE+FEN9&5X3V8H)W-E87)C:%]F;VQD97)S)RD@/CT@,"D@>PH@("`@("`@
M("`@("!I9B`H9&]C=6UE;G0N<V5A<F-H+F5L96UE;G1S6VE=+F-H96-K960I
M('L*("`@("`@("`@("`@("`@(&YU;5]S96QE8W1E9"LK.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@(&EF("AN=6U?<V5L96-T960@/3T@
M,"D@>PH@("`@("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M4&QE87-E('-E;&5C="!A="!L96%S="!O;F4@9F]L9&5R('1O('-E87)C:"XB
M*2D@/SXG*3L*("`@("`@("!D;V-U;65N="YS96%R8V@N<V5A<F-H7V9R;VTN
M9F]C=7,H*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"CP_<&AP(&5N
M9&EF.R`_/@H*("`@(&1O8W5M96YT+G-E87)C:"YA8W1I;VY)1"YV86QU92`]
M("=D;U]S96%R8V@G.PH@("`@<F5T=7)N('1R=64["GT*"B\O("TM/@H\+W-C
M<FEP=#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]T96UP;&%T97,O<V5A<F-H+VAE861E<BYI;F,`````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#4T,#4`,3`T,3<S-C(W-C8`,#(R-#`T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QF;W)M
M(&UE=&AO9#TB<&]S="(@;F%M93TB<V5A<F-H(B!A8W1I;VX](CP_<&AP(&5C
M:&\@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S96%R8V@N<&AP)RD@/SXB/@H\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](G5P
M9&%T95]S96%R8V@B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F1E
M;&5T95]F:65L9%]I9"(@=F%L=64](B(@+SX*/#]P:'`@:68@*"1E9&ET7W%U
M97)Y7VED*3H@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB961I=%]Q
M=65R>5]I9"(@=F%L=64](CP_<&AP(&5C:&\@)&5D:71?<75E<GE?:60@/SXB
M("\^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H(65M<'1Y*"1S96%R8VA;
M)VUB;W@G72DI.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)M8F]X
M(B!V86QU93TB/#]P:'`@96-H;R`D<V5A<F-H6R=M8F]X)UT@/SXB("\^"CP_
M<&AP(&5L<V5I9B`H)'-U8G-C<FEB92DZ(#\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](G-H;W=?<W5B<V-R:6)E9%]O;FQY(B!V86QU93TB/#]P:'`@
M96-H;R`D<VAO=VX@/SXB("\^"CP_<&AP(&5N9&EF.R`_/@H\9&EV(&%L:6=N
M/2)C96YT97(B/@H\=&%B;&4@8F]R9&5R/2(P(B!C96QL<W!A8VEN9STB,"(@
M8V5L;'!A9&1I;F<](C(B('=I9'1H/2(Q,#`E(CX*(#QT<CX*("`\=&0@8VQA
M<W,](FAE861E<B!L969T06QI9VXB/@H\/W!H<"!I9B`H)&5D:71?<75E<GE?
M=F9O;&1E<BDZ(#\^"B`@(#QS=')O;F<^/#]P:'`@96-H;R!?*")%9&ET(%9I
M<G1U86P@1F]L9&5R(BD@/SX\+W-T<F]N9SX*/#]P:'`@96QS96EF("@D961I
M=%]Q=65R>5]I9"DZ(#\^"B`@(#QS=')O;F<^/#]P:'`@96-H;R!?*")%9&ET
M(%-E87)C:"!1=65R>2(I(#\^/"]S=')O;F<^"CP_<&AP(&5L<V4Z(#\^"B`@
M(#QS=')O;F<^/#]P:'`@<')I;G1F*%\H(E-E87)C:"`E<R(I+"`H(65M<'1Y
M*"1S96%R8VA;)VUB;W@G72DI(#\@:'1M;'-P96-I86QC:&%R<RA)35`Z.F1I
M<W!L87E&;VQD97(H)'-E87)C:%LG;6)O>"==*2D@.B`G)RD@/SX\+W-T<F]N
M9SX*/#]P:'`@96YD:68[(#\^"B`@/"]T9#X*("`\=&0@8VQA<W,](FAE861E
M<B!R:6=H=$%L:6=N(CX\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)VEM<"<L("=S
M96%R8V@G*2`_/CPO=&0^"B`\+W1R/@H@/'1R/@H@(#QT9"!V86QI9VX](G1O
M<"(@8V]L<W!A;CTB,B(^"B`@(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S
M/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO("1S=6)M:71?;&%B96P@/SXB
M(&]N8VQI8VL](G)E='5R;B!F;W)M0VAE8VLH*3LB("\^"B`@(#QI;G!U="!T
M>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(E)E<V5T(BD@/SXB(&]N8VQI8VL](F1O8W5M96YT+G-E87)C:"YA8W1I
M;VY)1"YV86QU92`]("=R97-E=%]S96%R8V@G.V1O8W5M96YT+G-E87)C:"YS
M=6)M:70H*3MR971U<FX@=')U93LB("\^"B`@/"]T9#X*(#PO='(^"@H@/'1R
M/CQT9"!C;VQS<&%N/2(R(CX\+W1D/CPO='(^"@H@/'1R/@H@(#QT9"!C;&%S
M<STB<VUA;&QH96%D97(@;&5F=$%L:6=N(B!C;VQS<&%N/2(R(CX\/W!H<"!E
M8VAO(%\H(DUE<W-A9V4@;6%T8VAE<R(I(#\^/"]T9#X*(#PO='(^"@H@/'1R
M/@H@(#QT9"!C;&%S<STB:71E;2(@8V]L<W!A;CTB,B(^"B`@(#QT86)L92!C
M96QL<W!A8VEN9STB,"(@8V5L;'!A9&1I;F<](C`B('=I9'1H/2(Q,#`E(CX*
M("`@(#QT<CX*("`@("`\=&0@8VQA<W,](FET96TQ(&QE9G1!;&EG;B(@;F]W
M<F%P/2)N;W=R87`B/@H@("`@("`\:6YP=70@='EP93TB<F%D:6\B(&YA;64]
M(G-E87)C:%]M871C:"(@:60](G-E87)C:%]M871C:%]O<B(@=F%L=64](F]R
M(CP_<&AP(&EF("@D<V5A<F-H6R=F:65L9%]E;F0G72`^(#`I(&5C:&\@)R!O
M;F-H86YG93TB9&]C=6UE;G0N<V5A<F-H+G-U8FUI="@I.W)E='5R;B!T<G5E
M.R(@;VYC;&EC:STB9&]C=6UE;G0N<V5A<F-H+G-U8FUI="@I.W)E='5R;B!T
M<G5E.R(G.R!I9B`H)'-E87)C:%LG;6%T8V@G72`]/2`G;W(G*2!E8VAO("<@
M8VAE8VME9#TB8VAE8VME9"(G.R`_/B`O/@H@("`@("`\96T^/#]P:'`@96-H
M;R!(;W)D93HZ;&%B96PH)W-E87)C:%]M871C:%]O<B<L(%\H(DUA=&-H($%N
M>2!1=65R>2(I*2`_/CPO96T^)FYB<W`["B`@("`@/"]T9#X*("`@("`\=&0@
M8VQA<W,](FET96TQ(&QE9G1!;&EG;B(@;F]W<F%P/2)N;W=R87`B/@H@("`@
M("`\:6YP=70@='EP93TB<F%D:6\B(&YA;64](G-E87)C:%]M871C:"(@:60]
M(G-E87)C:%]M871C:%]A;F0B('9A;'5E/2)A;F0B/#]P:'`@:68@*"1S96%R
M8VA;)V9I96QD7V5N9"==(#X@,"D@96-H;R`G(&]N8VAA;F=E/2)D;V-U;65N
M="YS96%R8V@N<W5B;6ET*"D[<F5T=7)N('1R=64[(B!O;F-L:6-K/2)D;V-U
M;65N="YS96%R8V@N<W5B;6ET*"D[<F5T=7)N('1R=64[(B<[(&EF("AI<U]N
M=6QL*"1S96%R8VA;)VUA=&-H)UTI('Q\("@D<V5A<F-H6R=M871C:"==(#T]
M("=A;F0G*2D@96-H;R`G(&-H96-K960](F-H96-K960B)SL@/SX@+SX*("`@
M("`@/&5M/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=S96%R8VA?;6%T8VA?
M86YD)RP@7R@B36%T8V@@06QL(%%U97)I97,B*2D@/SX\+V5M/@H@("`@(#PO
M=&0^"B`@("`@/'1D(&-L87-S/2)I=&5M,2(@=VED=&@](C$P,"4B/B9N8G-P
M.SPO=&0^"B`@("`\+W1R/@H@("`\+W1A8FQE/@H@(#PO=&0^"B`\+W1R/@H*
M(#QT<CX*("`\=&0@8VQA<W,](FET96TP(&QE9G1!;&EG;B(@8V]L<W!A;CTB
M,B(^"B`@(#QT86)L92!B;W)D97(](C`B(&-E;&QP861D:6YG/2(Q(B!C96QL
M<W!A8VEN9STB,2(@=VED=&@](C$P,"4B/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1E;7!L871E
M<R]T:')E860O````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,C`T-C(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O=&5M<&QA=&5S+W1H<F5A9"]T:')E860N:'1M;```````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#$Q`#$P-#$W,S8R-S8V`#`R,C8P-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\:#$@
M8VQA<W,](FAE861E<B(^"B`@/'1A9SIH96%D97(@+SXZ(#QT86<Z<W5B:F5C
M="`O/@H\+V@Q/@H\<"`O/@H*/&$@:60](F1I<W!L87DB/CPO83X*/&1I=B!C
M;&%S<STB<V]L:61B;W@B/@H\9&EV(&-L87-S/2)S;6%L;&AE861E<B(^/'1A
M9SIH96%D97(@+SX\+V1I=CX*/&QO;W`Z=')E93X*/&1I=B!C;&%S<STB/'1A
M9SIT<F5E+F-L87-S("\^(CXF;F)S<#L\=&%G.G1R964N<W5B:F5C="`O/CPO
M9&EV/@H\+VQO;W`Z=')E93X*/"]D:78^"@H\<"`O/@H*/'1A8FQE(&)O<F1E
M<CTB,"(@86QI9VX](F-E;G1E<B(@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG
M/2(P(B!C96QL<&%D9&EN9STB,R(^"@H\;&]O<#IM97-S86=E<SX*(#QT<CX*
M("`\=&0@8VQA<W,](FET96TB/@H@(#QA(&ED/2(\=&%G.FUE<W-A9V5S+FED
M>"`O/B(^/"]A/@H@("`\=&%B;&4@8F]R9&5R/2(P(B!W:61T:#TB,3`P)2(^
M"B`@("`\='(@=F%L:6=N/2)T;W`B/@H@("`@(#QT9"!C;&%S<STB:71E;2(^
M"B`@("`@(#QT86)L92!B;W)D97(](C`B(&%L:6=N/2)C96YT97(B('=I9'1H
M/2(Q,#`E(B!C96QL<&%D9&EN9STB,B(@8V5L;'-P86-I;F<](C`B/@H@("`@
M("`@/'1R/@H@("`@("`@(#QT9"!C;&%S<STB:71E;3`@<FEG:'1!;&EG;B(@
M=F%L:6=N/2)T;W`B(&YO=W)A<#TB;F]W<F%P(CX\<W1R;VYG/CQT86<Z9&%T
M95]S=')I;F<@+SXZ/"]S=')O;F<^)FYB<W`[/"]T9#X*("`@("`@("`\=&0@
M8VQA<W,](FET96TP(&QE9G1!;&EG;B(^/'1A9SIM97-S86=E<RYD871E("\^
M/"]T9#X*("`@("`@("`\=&0@8VQA<W,](FET96TP(')I9VAT06QI9VXB/CQT
M86<Z;65S<V%G97,N;&EN:R`O/CPO=&0^"B`@("`@("`\+W1R/@H@("`@("`@
M/'1R/@H@("`@("`@(#QT9"!C;&%S<STB:71E;3$@<FEG:'1!;&EG;B(@=F%L
M:6=N/2)T;W`B(&YO=W)A<#TB;F]W<F%P(CX\<W1R;VYG/CQT86<Z9G)O;5]S
M=')I;F<@+SXZ/"]S=')O;F<^)FYB<W`[/"]T9#X*("`@("`@("`\=&0@8VQA
M<W,](FET96TQ(&QE9G1!;&EG;B(@=VED=&@](C$P,"4B(&-O;'-P86X](C(B
M/CQT86<Z;65S<V%G97,N9G)O;2`O/CPO=&0^"B`@("`@("`\+W1R/@H\:68Z
M;65S<V%G97,N<W5B:F5C=#X*("`@("`@(#QT<CX*("`@("`@("`\=&0@8VQA
M<W,](FET96TP(')I9VAT06QI9VXB('9A;&EG;CTB=&]P(B!N;W=R87`](FYO
M=W)A<"(^/'-T<F]N9SX\=&%G.G-U8FIE8W1?<W1R:6YG("\^.CPO<W1R;VYG
M/B9N8G-P.SPO=&0^"B`@("`@("`@/'1D(&-L87-S/2)I=&5M,"!L969T06QI
M9VXB('=I9'1H/2(Q,#`E(B!C;VQS<&%N/2(R(CX\=&%G.FUE<W-A9V5S+G-U
M8FIE8W0@+SX\+W1D/@H@("`@("`@/"]T<CX*/"]I9CIM97-S86=E<RYS=6)J
M96-T/@H@("`@("`\+W1A8FQE/@H*("`@("`@/&1I=B!C;&%S<STB=&5X="(^
M"B`@("`@("`@/'1A9SIM97-S86=E<RYB;V1Y("\^"B`@("`@(#PO9&EV/@H@
M("`@(#PO=&0^"B`@("`\+W1R/@H@("`\+W1A8FQE/@H@(#PO=&0^"B`\+W1R
M/@H*(#QT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/@H\+VQO;W`Z;65S<V%G97,^
M"@H\+W1A8FQE/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+W1E;7!L871E<R]C;VUM;VXM:&5A9&5R+FEN8P``````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#(P,0`Q,#0Q-S,V,C<V-@`P,C(T,38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*9VQO
M8F%L("1L86YG=6%G93L*:68@*&ES<V5T*"1L86YG=6%G92DI('L*("`@(&AE
M861E<B@G0V]N=&5N="UT>7!E.B!T97AT+VAT;6P[(&-H87)S970])R`N($Y,
M4SHZ9V5T0VAA<G-E="@I*3L*("`@(&AE861E<B@G5F%R>3H@06-C97!T+4QA
M;F=U86=E)RD["GT*/SX*/"%$3T-465!%(&AT;6P@4%5"3$E#("(M+R]7,T,O
M+T141"!82%1-3"`Q+C`@5')A;G-I=&EO;F%L+R]%3B(@(D141"]X:'1M;#$M
M=')A;G-I=&EO;F%L+F1T9"(^"CPA+2T@24U0.B!#;W!Y<FEG:'0@,C`P,2TR
M,#`V+"!4:&4@2&]R9&4@4')O:F5C="X@24U0(&ES('5N9&5R('1H92!'4$PN
M("TM/@H\(2TM("`@2&]R9&4@4')O:F5C=#H@:'1T<#HO+VAO<F1E+F]R9R\@
M?"!)35`Z(&AT='`Z+R]H;W)D92YO<F<O:6UP+R`@("`M+3X*/"$M+2`@("`@
M($=.52!0=6)L:6,@3&EC96YS93H@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+V=P;"YH=&UL("`@("`@+2T^"CP_<&AP"F5C:&\@*"%E;7!T>2@D;&%N
M9W5A9V4I*2`_("<\:'1M;"!L86YG/2(G("X@<W1R='(H)&QA;F=U86=E+"`G
M7R<L("<M)RD@+B`G(B<@.B`G/&AT;6PG.PIE8VAO("@A96UP='DH)&EE7V-L
M:65N=&-A<',I*2`_("<@>&UL;G,Z244^)R`Z("<^)SL*/SX*/&AE860^"CP_
M<&AP"@HD<&%G95]T:71L92`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)VYA;64G*3L*:68@*"%E;7!T>2@D=&ET;&4I*2`D<&%G95]T:71L92`N/2`G
M(#HZ("<@+B`D=&ET;&4["FEF("@A96UP='DH)')E9G)E<VA?=&EM92D@)B8@
M(65M<'1Y*"1R969R97-H7W5R;"DI('L*("`@(&5C:&\@(CQM971A(&AT='`M
M97%U:78]7")R969R97-H7"(@8V]N=&5N=#U<(B1R969R97-H7W1I;64[=7)L
M/21R969R97-H7W5R;%PB("\^7&XB.PI]"DAO<F1E.CII;F-L=61E4V-R:7!T
M1FEL97,H*3L*/SX*/'1I=&QE/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D<&%G95]T:71L92D@/SX\+W1I=&QE/@H\;&EN:R!H<F5F/2(\/W!H<"!E
M8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@I(#\^+V9A
M=FEC;VXN:6-O(B!R96P](E-(3U)40U54($E#3TXB("\^"CP_<&AP(&EF("AI
M<W-E="@D;6%I;&)O>%]U<FPI*3H@/SX*/&QI;FL@:')E9CTB/#]P:'`@96-H
M;R`D;6%I;&)O>%]U<FP@/SXB(')E;#TB57`B("\^"CP_<&AP(&5L<V4Z(#\^
M"CQL:6YK(&AR968](CP_<&AP(&5C:&\@571I;#HZ861D4&%R86UE=&5R*$AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G;6%I;&)O>"YP:'`G*2P@)VUA:6QB;W@G
M+"`G24Y"3U@G*2`_/B(@<F5L/2)4;W`B("\^"CP_<&AP(&5N9&EF.R`_/@H\
M/W!H<"!I9B`H:7-S970H)&9I<G-T7W5R;"DI.B`_/@H\;&EN:R!H<F5F/2(\
M/W!H<"!E8VAO("1F:7)S=%]U<FP@/SXB(')E;#TB1FER<W0B("\^"CP_<&AP
M(&5N9&EF.R`_/@H\/W!H<"!I9B`H:7-S970H)'!R979?=7)L*2DZ(#\^"CQL
M:6YK(&AR968](CP_<&AP(&5C:&\@)'!R979?=7)L(#\^(B!R96P](E!R979I
M;W5S(B`O/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*&ES<V5T*"1N97AT
M7W5R;"DI.B`_/@H\;&EN:R!H<F5F/2(\/W!H<"!E8VAO("1N97AT7W5R;"`_
M/B(@<F5L/2).97AT(B`O/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*&ES
M<V5T*"1L87-T7W5R;"DI.B`_/@H\;&EN:R!H<F5F/2(\/W!H<"!E8VAO("1L
M87-T7W5R;"`_/B(@<F5L/2),87-T(B`O/@H\/W!H<"!E;F1I9CL@/SX*/&QI
M;FL@:')E9CTB/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E
M87)C:"YP:'`G*2`_/B(@<F5L/2)S96%R8V@B("\^"CP_<&AP(&5C:&\@2&]R
M9&4Z.G-T>6QE<VAE971,:6YK*"=I;7`G+"!E;7!T>2@D<')I;G1E<E]F<FEE
M;F1L>2D@/R`G)R`Z("=P<FEN="<I(#\^"CP_<&AP(&EF("@A96UP='DH)&EE
M7V-L:65N=&-A<',I*3H@/SX\<W1Y;&4^245<.F-L:65N=&-A<',@>V)E:&%V
M:6]R.G5R;"@C9&5F875L="-C;&EE;G1C87!S*7T\+W-T>6QE/CP_<&AP(&5N
M9&EF.R`_/@H\+VAE860^"@H\8F]D>3P_<&AP(&EF("A5=&EL.CIN;VY);G!U
M=%9A<B@G8F]D>4-L87-S)RDI(&5C:&\@)R!C;&%S<STB)R`N("1B;V1Y0VQA
M<W,@+B`G(B<[(#\^/@H\/W!H<"!I9B`H(65M<'1Y*"1I95]C;&EE;G1C87!S
M*2DZ(#\^/$E%.F-L:65N=&-A<',@240](F]B:D-#87!S(B`O/CP_<&AP(&5N
M9&EF.R`_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+W1E;7!L871E<R]M96YU+FEN8P``````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8R,@`Q,#0Q-S,V,C<V-@`P
M,C`V-3(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*)&UE;G5?=')A<V@@/2`H*"1I;7!;)V)A<V5?<')O=&]C;VPG
M72`A/2`G<&]P,R<I("8F"B`@("`@("`@("`@("`@("1P<F5F<RT^9V5T5F%L
M=64H)W5S95]T<F%S:"<I("8F"B`@("`@("`@("`@("`@("@D<')E9G,M/F=E
M=%9A;'5E*"=T<F%S:%]F;VQD97(G*2`A/3T@;G5L;"D@)B8*("`@("`@("`@
M("`@("`@)'!R969S+3YG971686QU92@G96UP='E?=')A<VA?;65N=2<I*3L*
M)&UE;G5?<W!A;2`]("@H)&EM<%LG8F%S95]P<F]T;V-O;"==("$]("=P;W`S
M)RD@)B8*("`@("`@("`@("`@("`@*"1P<F5F<RT^9V5T5F%L=64H)W-P86U?
M9F]L9&5R)RD@(3T](&YU;&PI("8F"B`@("`@("`@("`@("`@("1P<F5F<RT^
M9V5T5F%L=64H)V5M<'1Y7W-P86U?;65N=2<I*3L*)&UE;G5?=FEE=R`]("1P
M<F5F<RT^9V5T5F%L=64H)VUE;G5?=FEE=R<I.PHD86-C97-S:V5Y(#T@)'!R
M969S+3YG971686QU92@G=VED9V5T7V%C8V5S<VME>2<I(#\@2&]R9&4Z.F=E
M=$%C8V5S<TME>2A?*")/<&5N($9O7VQD97(B*2D@.B`G)SL*/SX*/&9O<FT@
M86-T:6]N/2)M86EL8F]X+G!H<"(@;65T:&]D/2)G970B(&YA;64](FUE;G5F
M;W)M(CX*/#]P:'`@96-H;R!5=&EL.CIF;W)M26YP=70H*2`_/@H\9&EV(&ED
M/2)M96YU(CX*/#]P:'`@:68@*"@D:6UP6R=B87-E7W!R;W1O8V]L)UT@(3T@
M)W!O<#,G*2`F)B`D8V]N9ELG=7-E<B==6R=A;&QO=U]F;VQD97)S)UTI.B`_
M/@H@/&1I=B!C;&%S<STB<FEG:'1&;&]A="(^"B`@/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB;F]?;F5W;6%I;%]P;W!U<"(@=F%L=64](C$B("\^"B`@
M/&QA8F5L(&9O<CTB;6%I;&)O>"(@86-C97-S:V5Y/2(\/W!H<"!E8VAO("1A
M8V-E<W-K97D@/SXB/@H@("`\<V5L96-T(&ED/2)M86EL8F]X(B!N86UE/2)M
M86EL8F]X(B!O;F-H86YG93TB9F]L9&5R4W5B;6ET*"DB/@H@("`@/#]P:'`@
M96-H;R!)35`Z.F9L:7-T4V5L96-T*"<G+"!T<G5E+"!A<G)A>2@I+"`D:6UP
M6R=M86EL8F]X)UTL(&9A;'-E+"!F86QS92P@=')U92D@/SX*("`@/"]S96QE
M8W0^"B`@/"]L86)E;#X*(#PO9&EV/@H@/&1I=B!C;&%S<STB<FEG:'1&;&]A
M="(^"B`@/#]P:'`*("`@)&QI;FL@/2!(;W)D93HZ;&EN:R@G(R<L("<G+"`G
M)RP@)R<L("=F;VQD97)3=6)M:70H=')U92D[(')E='5R;B!F86QS93LG*3L*
M("`@<')I;G1F*"<\=6P^/&QI/B5S)7,\8G(@+SXE<SPO83X\+VQI/CPO=6P^
M)RP*("`@("`@("`@("1L:6YK+`H@("`@("`@("`@*"1M96YU7W9I97<@(3T@
M)W1E>'0G*2`_($AO<F1E.CII;6<H)V9O;&1E<G,O9F]L9&5R7V]P96XN<&YG
M)RD@.B`G)RP*("`@("`@("`@("@D;65N=5]V:65W("$]("=I8V]N)RD@/R!(
M;W)D93HZ:&EG:&QI9VAT06-C97-S2V5Y*%\H(D]P96X@1F]?;&1E<B(I+"`D
M86-C97-S:V5Y*2`Z("<G*3L*("`_/@H@/"]D:78^"B`\/W!H<"!E;F1I9CL@
M/SX*(#QD:78@8VQA<W,](FQE9G1&;&]A="(^"B`@/#]P:'`@96-H;R!)35`Z
M.F=E=$UE;G4H)W-T<FEN9R<I(#\^"B`\+V1I=CX*(#QB<B!C;&%S<STB8VQE
M87(B("\^"CPO9&EV/@H\+V9O<FT^"@H\/W!H<"!I9B`H)&-O;F9;)W5S97(G
M75LG86QL;W=?9F]L9&5R<R==*3H@/SX*/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/@H\(2TM"G9A<B!L;V%D:6YG.PIF=6YC=&EO;B!F;VQD97)3
M=6)M:70H8VQE87(I"GL*("`@(&EF("AD;V-U;65N="YM96YU9F]R;2YM86EL
M8F]X6V1O8W5M96YT+FUE;G5F;W)M+FUA:6QB;W@N<V5L96-T961);F1E>%TN
M=F%L=64@(3T@)R<I('L*("`@("`@("!I9B`H*&QO861I;F<@/3T@;G5L;"D@
M?'P@*&-L96%R("$](&YU;&PI*2!["B`@("`@("`@("`@(&QO861I;F<@/2!T
M<G5E.PH@("`@("`@("`@("!D;V-U;65N="YM96YU9F]R;2YS=6)M:70H*3L*
M("`@("`@("!]"B`@("!]"GT*+R\@+2T^"CPO<V-R:7!T/@H\/W!H<"!E;F1I
M9CL@/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]T96UP;&%T97,O+FAT86-C97-S````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S-C(W-C8`,#(Q,#`S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$1E
M;GD@9G)O;2!A;&P*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M=&AE;65S+P``````````````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<P`#`Q-C0W-0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O;'5C+P``````````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-C8`
M,#$W,C8U`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]L=6,O
M<V-R965N+F-S<P``````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#(S-P`Q,#0Q-S,V,C<V-@`P,C$R-34`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+RHJ"B`J("1(;W)D93H@:6UP+W1H96UE
M<R]L=6,O<V-R965N+F-S<RQV(#$N,BXR+C(@,C`P-2\Q,"\Q."`Q,CHQ-#HQ
M-B!J86X@17AP("0*("HO"@HN9F]L9&5R<R!["B`@("!F;VYT+7-I>F4Z(#$Q
M<'@["GT*+F%N<W=E<F5D('L*("`@(&)A8VMG<F]U;F0Z("-C,61A8S$["GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O<G1L+P``````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-C8`,#$W,S`S`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE
M<R]R=&PO<V-R965N+F-S<P``````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#4R-P`Q,#0Q-S,V,C<V-@`P,C$R-S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J("1(;W)D93H@:6UP
M+W1H96UE<R]R=&PO<V-R965N+F-S<RQV(#$N,BXR+C$@,C`P-2\Q,"\Q."`Q
M,CHQ-#HQ-B!J86X@17AP("0*("H@4RY.:6MS969A="`F($,N36]R=&5Z86YI
M82!I;B!!;6ER:V%B:7(@365T84Y%5"!,=&0N"B`J+PH*+FQE9G1!;&EG;B![
M"B`@("`@("`@=&5X="UA;&EG;CH@<FEG:'0["GT*+G)I9VAT06QI9VX@>PH@
M("`@("`@('1E>'0M86QI9VXZ(&QE9G0["GT*"BYL969T1FQO870@>PH@("`@
M("`@(&9L;V%T.B!R:6=H=#L*?0HN<FEG:'1&;&]A="!["B`@("`@("`@9FQO
M870Z(&QE9G0["GT*+FUE<W-A9V5,:7-T('1H('L*("`@('1E>'0M86QI9VXZ
M(')I9VAT.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O<W5N+P``````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-C8`,#$W,S`W`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+W1H96UE<R]S=6XO<V-R965N+F-S<P``````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#(U-@`Q,#0Q-S,V,C<V-@`P,C$S,#``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J("1(;W)D
M93H@:6UP+W1H96UE<R]S=6XO<V-R965N+F-S<RQV(#$N,2`R,#`T+S$P+S$W
M(#(P.C,W.C0W(&UD:G5K:6,@17AP("0*("HO"@HN=6YS965N('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-E96-C,#`["GT*+F%N<W=E<F5D('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-F9F1D86$["GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O87IU
M<B\`````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-C8`,#$W-#8S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+W1H96UE<R]A>G5R+W-C<F5E;BYC<W,`````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,30U-0`Q,#0Q-S,V,C<V-@`P,C$T-38`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+RHJ"B`J
M($%U=&AO<CH@2F]O<W0@1&4@0V]C:R`\:F]O<W1`9&5C;V-K+F]R9SX*("H*
M("H@)$AO<F1E.B!I;7`O=&AE;65S+V%Z=7(O<V-R965N+F-S<RQV(#$N,2`R
M,#`T+S$P+S$W(#(P.C0Y.C,X(&UD:G5K:6,@17AP("0*("HO"@HN9&5L971E
M9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8F)B8F)B.PH@("`@8V]L;W(Z
M("-E965E964["GT*+FEM<&]R=&%N="!["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C9F-D,V9F.PH@("`@8V]L;W(Z("-F9C`P,#`["GT*+G5N<V5E;B!["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C8F5C,&1D.PH@("`@8V]L;W(Z(",P,#`P
M,#`["GT*+F%N<W=E<F5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E.&4X
M9F8["B`@("!C;VQO<CH@(S8V-C8V-CL*?0HN<75O=&5D,2!["B`@("!C;VQO
M<CH@(S8V,#`V-CL*?0HN<75O=&5D,B!["B`@("!C;VQO<CH@(S`P-S<W-SL*
M?0HN<75O=&5D,R!["B`@("!C;VQO<CH@(SDY,#`P,#L*?0HN<75O=&5D-"![
M"B`@("!C;VQO<CH@(S`P,#`Y.3L*?0HN<75O=&5D-2!["B`@("!C;VQO<CH@
M(V)B-C8P,#L*?0HN<VEG;F%T=7)E('L*("`@(&-O;&]R.B`C8F)B8F)B.PI]
M"BYS:6=N871U<F4M9FEX960@>PH@("`@8V]L;W(Z("-B8F)B8F(["B`@("!F
M;VYT+7-I>F4Z(#$S<'@["B`@("!F;VYT+69A;6EL>3H@;6]N;W-P86-E+"!F
M:7AE9#L*?0HN<75O=&%W87)N('L*("`@(&-O;&]R.B!B;&%C:SL*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z('EE;&QO=SL*?0HN<75O=&%A;&5R="!["B`@("!C
M;VQO<CH@=VAI=&4["B`@("!B86-K9W)O=6YD+6-O;&]R.B!R960["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+W1H96UE<R]G<F5Y+P``````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V-@`P,3<T
M-3``(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V=R97DO<V-R
M965N+F-S<P``````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S,U
M`#$P-#$W,S8R-S8V`#`R,30S-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````O*BH*("H@)$AO<F1E.B!I;7`O=&AE;65S+V=R
M97DO<V-R965N+F-S<RQV(#$N,2`R,#`T+S$P+S$W(#(P.C0Y.C,Y(&UD:G5K
M:6,@17AP("0*("HO"@HN:6UP;W)T86YT('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-A-38S-C,["GT*+G5N<V5E;B!["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C9#-D,V0S.PI]"BYA;G-W97)E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C8C=C8V(W.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]C;W)N9FQO=V5R+P``````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<V
M-P`P,C`V-C,`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V-O
M<FYF;&]W97(O<V-R965N+F-S<P``````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,3<W`#$P-#$W,S8R-S8W`#`R,C8U-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O*BH*("H@)$AO<F1E.B!I;7`O=&AE
M;65S+V-O<FYF;&]W97(O<V-R965N+F-S<RQV(#$N,2XR+C(@,C`P-2\Q,"\Q
M."`Q,CHQ-#HQ-"!J86X@17AP("0*("HO"@HN9F]L9&5R<R!["B`@("!F;VYT
M+7-I>F4Z(#$Q<'@["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]B<F]W;B\`````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<V-P`P,3<V,S(`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE
M;65S+V)R;W=N+W-C<F5E;BYC<W,`````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,C`S`#$P-#$W,S8R-S8W`#`R,38Q,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*BH*("H@)$AO<F1E.B!I
M;7`O=&AE;65S+V)R;W=N+W-C<F5E;BYC<W,L=B`Q+C$@,C`P-"\Q,"\Q-R`R
M,#HT.3HS."!M9&IU:VEC($5X<"`D"B`J+PH*+G5N<V5E;B!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C969E965E.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F5E;B\`
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<V-P`P,3<V,#,`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O=&AE;65S+V=R965N+W-C<F5E;BYC<W,`````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-#$R`#$P-#$W,S8R-S8W`#`R,34V-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*BH*("H@)$AO
M<F1E.B!I;7`O=&AE;65S+V=R965N+W-C<F5E;BYC<W,L=B`Q+C$@,C`P-"\Q
M,"\Q-R`R,#HT.3HS.2!M9&IU:VEC($5X<"`D"B`J+PH*+F1E;&5T960@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(T(X,C@R.#L*?0HN:6UP;W)T86YT('L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-&-SA%.$4["GT*+G5N<V5E;B!["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C9F%E-6,P.PI]"BYA;G-W97)E9"!["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C-D9$.3DR.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G
M<F%P:&EC<R\`````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<V-P`P,C`S,#,`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O=&AE;65S+V=R87!H:6-S+V9O;&1E<G,O````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8W`#`R,3<T,0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O9W)A<&AI8W,O9F]L
M9&5R<R]T<F%S:"YP;F<`````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,#8`,3`T
M,3<S-C(W-C<`,#(S-38R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P```,E03%1%```%%A@4'"`<)BLA+S$M-#DQ-3XV.D0X0DH\3%!(2E9$3UM,
M>U0B<U@C7&!88&U::6MF9'9<C&LT;'II;GYL<(1H>H)TAH:$?H]YH(9/GX=0
MOX0[B)1\OX4[OX@ZP(H[P8L[PHTZPY`\CY^$QI0^EJ:,H*^:KKJDO<>RX\."
MU\FL\]"#X-.OX=2PW].]]=:,^=MZ]MF6^]U]]]V?_..0^.&H^N2P_.FJ^^BY
M]^O+_.S"_N_!_?#+_?/4__73_?;<_/;F_O?D!@8$PC&A9`````%T4DY3`$#F
MV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'
MU`P4$Q\XI,AR>0```+9)1$%4>-IES]<.@C`4@&%&BU`<U19I%2>"N+>X4=[_
MH3S51$W\K]HOITF/IOTE5;_W699ETQ^1QRLDOW/RHK*1:1C.2^1I-/!I/*1N
M/2Q'"@[].TJ2.!!A%!5*`/O>PPQ!HC!@CH)=]T9M(;PJ)<A7L.F<S\C"&"%L
MSQ6LVFEJQ:+"&+'&"A:M[18#>(Q@7:=:8])<K@'*'B<XSW,8J16+\*3*F0N`
MWO^G@6"<NX;^V0@;*@JG)\7'%"9[3S+?`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O9W)A<&AI
M8W,O9F]L9&5R<R]I;F)O>"YP;F<`````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V
M,#,`,3`T,3<S-C(W-C<`,#(S-38R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P```&]03%1%````/S(M0#4M2#DQ5T0[:%A4D7=HJ(UMJ)!YJY2"
MMII[M9Z2O*.)NJ:8NZNFSK>7R[RFTKR;T,7#WLBDU\FWXLVEW]"TZ-BXY-C&
MY=S5]^2[Z^3@Z^7<]>C5^.G(].[C__'-_O/7_?7F_?GS/"\GC]K8D`````%T
M4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````
M!W1)344'U`P($B026,S6AP```(U)1$%4>-JMC4D6PC`,0P-MH`UUIU"<#G$S
M</\SHNQXK/G+;\E2Z@_H'Y3>]Q4XYYC9+A>E72ZD%%,,P4)0GXK(*48Q=XAS
M?!Q0"$Q-5RHYSSTAX+NF8ZZ0R/E%-$_-;=ED@]CSLS\]M=:U4^!:Z97IQ$;P
M7HPM8J14-C$2Q`P0=(C@*GBPL8&HOKC6[P_XA`[1J8E03@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V=R87!H:6-S+V9O;&1E<G,O
M9F]L9&5R+G!N9P``````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C4R`#$P-#$W,S8R
M-S8W`#`R,S<R,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```"K
M4$Q4104`%GM4(G-8(W9;)(QK-*"&3Y^'4+^$.[^%.[^(.L"*.\&+.\*-.L.0
M/,.1.\:4/L^M5<BRB->X8="^F]W">>/#@M?)K.7.E//0@^#3K^'4L-_3O?76
MC.K9K/G;>OG;>_;9EOO=?>7<R_?=G_SCD/CAJ/#DQOKDL/3FP.SFVNWGW?SI
MJOOHN??KR_SLPO[OP?;NWOWPR_WSU/_UT_WVW/SVYO[WY/_[\7=5(MX[U@P`
M```!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<
M&`````=T24U%!]0,"!(B.CLCV?L```!X241!5'C:8V`@#%A!`)DO96)B(HDD
MPJIK!`2L"'6LAG"@`19AU1/EYX,"1F:0@`ZOJ3D4&&@Q`074><Q@0$T3)*#*
M;0P#LDH@`64N?1@0EP8)*'!JPX"(&$A`AD,%!H2$@0)L$NQRBA`@+R#(!+*7
MA1$&+)BP^!4`.FT37^-M+@P`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+W1H96UE<R]G<F%P:&EC<R]F;VQD97)S+W-E;G0N<&YG````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<P,@`Q,#0Q-S,V,C<V-P`P,C,T,30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0"`,````H+0]3````L5!,5$4```5W52)[
M5")S6".,:S1F9LR@AD^?AU"_A#N_A3NEC5B_B#K`BCO!BSO"C3JIDV'#D#S#
MD3NLEF;&E#ZNGW^9F?^ZJ(+/K56^L9C(LHC7N&')NZ#0OIO`P,#=PGGCPX+7
MR:SST(/@TZ_AU+#UUHSYVWKYVWOVV9;[W7WWW9_\XY#XX:CZY+#\Z:K[Z+GW
MZ\O\[,+^[\']\,O]\]3_]=/]]MS\]N;^]^3_^_'___\S,V:HY[`"`````712
M3E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?4#!03(`#4%.#;````BDE$051XVH7-YP[",`Q&T4!QV)NRH>Q=()#0
MAO=_,/P5_)LK18J/Y$2I+**0N#?N':UUD\AS&?37SKD5>1;R@,KMR6'D`]`/
MA`V!>]2=M06&#-?6*TUE)6"X-)+$RZ.`<]U:*]\"CC5C#/T"[*NQ-%\`-N63
M-)XR%)>E[>';;C!BF.A"7LH%/?6_#X;0%]1E+Y^B`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T
M:&5M97,O9W)A<&AI8W,O9F]L9&5R<R]D<F%F=',N<&YG````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`V,C4`,3`T,3<S-C(W-C<`,#(S-S,R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P```)!03%1%````=U4B>U0B<U@CC&LT@("`
MH(9/GX=0OX0[OX4[OX@ZP(H[P8L[PHTZPY`\PY$[QI0^SZU5R+*(U[AAT+Z;
MX\."\]"#X-.OX=2P]=:,^=MZ^=M[]MF6^]U]]]V?_..0^.&H^N2P_.FJ^^BY
M]^O+_.S"_N_!_?#+_?/4__73_?;<_/;F_O?D__OQ____````9Z.B)`````%T
M4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````
M!W1)344'U`P4$R`8QWAXC0```'Y)1$%4>-IUS\<20B$,A>$HDFOGVGOO*.']
MW\X###,L]%ME,G\6(?I#)V'D@+2`%FQX::U=,&80\<37)W`L/!`_HE3H4-QF
MM3$F%A)/+L.W<ZXH3H,/%,6Q_X*BV/?N4!3;[AE\1KSJ'++)5!%5\_9ZEVQ&
M8Q5^:36SAOKQ]A<R+15NE0+:>@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V=R87!H
M:6-S+V9O;&1E<G,O9F]L9&5R7V]P96XN<&YG````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-C$R`#$P-#$W,S8R-S8W`#`R-#<S-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`(
M`P```"@M#U,```"04$Q410```'-8(XUL-(=O/<2,/<*0.\61/\:50L:60<RM
M7MBL4]JM7]FO8=ZW;<[!IN#!A^/"?^#(A>#3K]O3PN'4L.C4H?+4DOC:>_;<
MC?3:HOO>?N[@OOCAJ/SEENODU?KDL/3FP/OHN?WJL/OKO_?KR_SLPO7MV??M
MUO/OY_WPR__RR?WSU/WVW/_VW/_Z[7M4(BJ$_D@````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,"!(B
M'@<@/2H```!S241!5'C:8V`@#!A!`)DOHJ.C(X0DPJBB#02,"'6,FG"@`!9A
M5$4`B("BH@`'*P3H@[0QRDNRJ^M!@)J&,#,#HPP/ORX42,L!-3&*L2EK08$H
M'TB`FU<)!@1!IC*R2,C"`"=(@(E+"@;$(2[31P!&;'X%`&;%$,8?%+M&````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F%P:&EC<R]A=61I;R\`
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<V-P`P,C$T,#0`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S
M+V=R87!H:6-S+V%U9&EO+W1H965T;VYE+G=A=@``````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#8P,S$P`#$P-#$W,S8R-S8W`#`R,S<S,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!2249&P&```%=!5D5F;70@$```
M``$``0`1*P``$2L```$`"`!D871AFV```'Y^?WU^@']_?7Z`?W^`@("`@(&!
M@("`@H&`@(&!@8"!@H&!@8&"@8""@H&!@(*"@8&`@H&!@("!@8"`@("`@("`
M@(!_?H"`?W^`@(!_@("`@'^`@("`@(&!@8*"@X.$A8:%AH:&A8:&AH6&AH:%
MA86&A86%A(2#A86$@X.$@X.#@H.#@H*"@X&"@H*#@8*"@X&`@H*!@("!@8&!
M@H*!@(&!@H"!@(*!@8*"@X."@H.$@X.#@X.#@H.#@X.#@X.#@H*"@8"`@8"`
M@("`@']]?GU]?7U]?7U]?GU]?7Y^?WU]?G]_?7Z`?W]_?X"`@("`@8"`@(&`
M@("`@8"`@(&!@8""@8&!@H*!@8""@H&`@H*!@("`@8&`@("`@("`@(!_?H"`
M@']_@(!_?W^`@(!_@("`@("`@("`@8*#@X.%A8:%A86&AH:%A8:$A86$A(6%
MA82#A86$A(.#A(.#@H.#@8&!@H.!@8*#@8*"@H&!@(*"@8"`@H&`@("!@8"`
M@(&`@(&`@("`@H.#@8*#@X*"@H.#@X*#@X.#@H.#@X."@X."@X.#@("`@("`
M?W]_?GU^?7U]?7U]?7U]?W]]?7U_?7U^?W]_?G^`@']_@("`@("!@(""@H.`
M@(""@8"!@8&`@(*!@8"`@H&!@(*"@8.`@(*!@(""@8"`@("`@("`@(!_@("`
M?WU^@("`@("`@(""@X&`?WV`@(""@W]Z@(*+E)*,BH2#D9J-A'IH:WV`C(^`
M>'^%BZ"AC(9Y<X")AH!Z:&9Z@(Z6C("`@XB:G(9_=&MT@8"`?6YI?8>1FYB`
M@("`CI*#=VYE:("`A85Z=("+D9V>@8!\=X"*@WET:FB`AHR/AGV`B8R4F(!U
M<6MT@'UW=&MI?HF-DXQ]?8"`BX^`<VYH:("!@H-Z=H".E)R;@H!]>H"(@'=T
M;&N`AXR1C(&&C(N1E8![>&YT>WU^A8!X@(!^C)2/AGIK96YT='UQ8F1K=("'
M@'5X;'2`@H2`=&QT@("+B'J$BI2CK:J9G967J*2;F(V&C)V@J:N>H*>JM;RT
MI)N/C929DY2*?8&+D9><F(F-AHF4C(-Z<6MN>71Z>&MN='J`A(-Q<6UK='%J
M95]:7&QM<75K:W%Q=WYZ;FIH7VAK96AE6U]H;G)\>FYT;F][>6YH8%96:&-K
M<5]B<7>`E))Z@GIUBX-W?WIN=X=[BY2!BYZ8H*VACYV8CJ*>BI2/@9&CF)VG
MF)>IGIZLF(.'@'>`B71W>FIZBX.(CX!Q?7=N>&A354U'5F1:7&=>:(!Z?H-T
M:W5Y<7QT86AM;(".AH..B9&IJJ.IF(Z:HZ"IJIB7IJ&UP;FVLZVLN\*SN*25
MFYNCK*ZDF*"<J;RVLZJ8E)JEGIN/>GU_A9>:DH:(B(B:F(B&<6YT>GET?&QN
M@'6`A8!]>WQQ@(-T@'%G;VIM;'=L:'=K<7IS='%S:VYW:'%O9VAK<7-Z>G1]
M@'J`@8"`?'IX>H!R>W9S?7E[?H"`?8B`@(EU>71N;VMT96EJ7&ME8V5D9U==
M6%!<4%!02DA'5%!36U!55E%67%Q35E=17%]=96AA9W%Q=("`?8F&@9"+AX^2
MC(N8CY>FF:.JI:RXO[C"P+._O+.[N:VLLZVOO+"ON;"LN+.JKZJ;H:22EYN(
MCI.,CI62A9*)?(N`='IT:VAT8FAT8FYV;G%Z>G!^?&Y]=W!Z>G1W@'=XA8"`
MD8R(DHR#CI"&BXQ]@(E_B92/CY>8D:&>DZ"9DI:8C(B2AH63@X6,AH2+D(*+
MB7=^@'9Z?79Q>G1Q@(!Q>G1M='=N;G!B7&5:66%645934%E?4UQ<4%E?65E>
M54I64$U<651<85QH=VQT>6IN>G9T@'=N?H!\BY.$CIJ.G*>;FZ.;CJ.DE:FD
MF:.MIZR\I:.SI*.OI)N?F(:7G(F7F(>1F9*4HX^%E8:`D89X?79H>(!P>H!H
M;GUT?(-T:'1N9GUZ9W1O:GJ'@("0@("8C9.;C("`AG>+CW>`@'>`DY*,EXE^
ME8R(E(9Y?8!Z@)"`@(E]BYJ8DI*&=X"`>(5Z:&MM;G2!='1^;GB'@8!]=&9N
M<VAT;F%F:FYT@'QT>FYK=V]K:%]665]<:&MB:'%Q>H*`>GET;7-N:VME9&AQ
M>7J`@("'BI.4D8R#A(*&BHF'@XF.EZ.DHJ2@H:>MJJ:DF)>;FYV>F).7GIZF
MIY^?FYB9FI*+C(2!BXF*CHR'CI>2EIB'A8%[?8!W;'%K:'=Z>H!\=7J"?X.&
M>G1W='J"@'J`@("0F)::E8R/E)&2DH-]@'V`BX:#AX:%D9B3EY.)BHR&BXR`
M?H*`@HZ.BY&,@XF*@X:#=W-S:&AT;FUU;FYY?7N"@'%U=&YS<6EC95Y@;FMN
M<6MK<'-P=7-E:&)?96=F:6UK<'U^A8J&@X>&A(R)@8!\=X"&A8J.B(F2E9J@
MGI*4C8F3DHV.C(:(E9&;H)B;GIZ=H)N-D(:!B8:`@(!Y>XB#BHV#@H.`?8.`
M='=Q:71W='N`>GV#@(*)@'I\=&US<6ML:V5H='1]@X"`AH.%CX^'B8-_A(:%
MBY",CY:6EYZ>G9^8DI6.BHR,B8F*AHZ7DYN>G)N:GI>9DXF-AH6&AH6`AH.&
MD8F)AH!]>X!W=7%D:&AI<W=T;W1V=H"`>GIK9&AH:&5D7%EA7VYW<'1N<7%W
M?W1Y;F5Q<'I\?7MTA8B4HYB7DHR1EI^/C(-T@(>.F96/AY&8G:RDEY*&B)&4
MCXB&>H"/CIR9C(R)CHV2CWIZ:V9T<'1P;6EG>G>`B'E[='%T=GII:V);:&IQ
M=W1Q<'U]@(B`='%H;G1S:6MJ972`@HZ,A(F1DI:>DH6)@("1C(F,B861GIJ@
MI).5F).7F(^"A8.`CY".EI*.E9^;FIZ/B8R`@(1Z<G9V;WJ`>8"`=X"">G=Z
M;FAN:&5Q:&1O<6YX?75Z@'1X?6YK;F-@:&5A:VMD='AU@(2`@(6`@(=Z>H1Z
M?8B)A8Z4BY>AF:"<DI",B(F3AH*3@'N+C8F+HJ&9HIZ5@X"+AGV+F8!T@(!K
M?8^/B9"2@'%Q<6A?='IB:WIH6&AZ<7J/C8!T=VY<971Q971Z7%QN:&A]EY""
MD(V`='J&=WJ0C("%D8:`E)Z;H:ZEC8V/AH*)F(R"D8UZ@(Z2B9>KGI*6CX!W
MA8R`B)2)='N%>H".FY.)DX=T;G5T9FZ`=&MT<&)B=(!_B)6&:VUQ8F)S>6YI
M=&MB:VQN:G*%?H"&@&MB<&YNA8N#@'U[>'Z#EZ*<J:22B(!Z=(67EZ2>C(E^
MA9&=IZVLF)*,>GJ!B8N4H)*4C("$@HZCI:28C'1E<&YTA8F!?'=N:VML@(&!
MCH-Q95Y64&A_>H1Y:%]9:')Y@(B`:&AH4$U>:&M]BH!Y;FEP;H"=FYB/C'%N
M@'R`EYN2E):)A8N/EYVIL*22AX!Q=):8EZRDC(.+CX>7KZV>EYN#;GJ&='>7
MGH:(C(!B=(N$B96/=%QF:%!<@'IN@(ET8G1T9G>+AX%[=&)*7'!H<8N`;FYZ
M<&B(CX*0E(9X;FYL97V7F)67DGITAHB(IZ68D(-T<7)\B8^:H)N/BXR`@*.C
MH*^AAGUZ='B+G:"8DHB`=G>*BXN;C'IW:%9697%TA8=]<6MK;FY]DX-Z@'16
M7&1D:("+A(9_;FUH<86%BY&`;FQH9&B`BXZ2CHF#>H"4C8VAF(-]>G1N@(N2
MF9J;F(:+E8J/IJ&8EYB`=X.+BYVLJ*2:E9*$CYV3D)>2@'=W:VA]A8.'B8!T
M:&MR;7>$>G%Q8E-696AN@(F`>G9L:&Y[@H"#@VYE;&AE>I&5E9^?C(2+C8F1
MHZ&/BH9Q:GV%BY>AGI&)AGI]AXV/D9&&=&QP='V7IJ2CF8Q^@(Z/E*.;C(=]
M='!]C)&=J**8@'EQ96Z`@WI^<%945EYH?8R#@'UJ9%]H<6QW@GIH:&107'2`
MBY.>AG1Z=GJ`EZ62CYB`:WV+@8NOL)V5DH!K>HN2DI6<@&5Z=V^`HZ27H*&#
M>H"#@("=I)*!BX!?@)V;H[BPC(&'?'Z+EYB)B(9H5VAS:("FF(:!=%9.8FYW
M?7YZ7$M94E!QC8&`C7135EM<98"7E8F`?6AEBY^@M<6PC(Z#;X"7H*&AH8]W
M<H"`A:FYI)J5@%QH?7Z.G9B&<6EH8'&1G)JCI(!K;VMH@)>8F(R`=&)H@(R4
MHYZ&<FM?66M]@(J&=VY545]B=)&8AWMN5DA696Q]B(!T95]B8'25GJ&CGH-P
M<W5]D:.IIYF,?'%WBYFIN+.8A'QK8WJ0D9F;CX!H:G%TBZ"KGI*):UUH=X"4
MHYZ,>F]H8WJ4GJ:JI(-N<6IE?925CXF`959D='V+EYB`;6A636)T='^#@&A3
M6%9:=(N8D(F&:5EH?8&+HZJ3A(=]=)&CL+2VLY*`@'QZBZ.JGIB2<VAW?HV=
MJJJ2@'1C7VA^AHN0C7=H;&5N@)2AF)*&:%]G=("(G9N&?'1E872"CI>;DX!H
M8E9<:(")@X%W65%<97*`DHQY<6)35&)V?8N9E8!T=VYWD::RK:VD@'E^@HN7
MJ:>8DH=Z=("1EYVJI(EW<VAE>HR3C8^&:%]H=("+IJ2,C(!J972#@(NAFX9Z
M>G=W@*"HG)B2=&=M;G2`E(^`?6YB7F5Z@8./B7%?8%90971U>']W:&-H<7^(
MG:63D(EW<WZ-CYVOI)B-AH&#D::NJJ>DAGE^?7V+H9B,D(-Q<7B%BHZ;F(!T
M=VYE=(R'B)&&;FAN<7J(EYZ,B89W:G&`>GV5C(!Z<VME<8")A(6#;EQE:5]H
M@'IK='%<5F)N<7J+CX-V=W9H=(^-D)V8@WV&B8Z;IZ6>F).-@("+A8N@FXR'
M@71Q@(^2F)6,@&UO>'%WB(:`A89W<7Q[?HZ7F(^"?'EP>Y&5D)>2@'2`@'V(
MD8^,AH)Z:&-Q<'*`B71M:UY<;GI[>GIS:E]@;FAK@(B$B(R`='J`B9JCI:&2
MB(:!A9>=F)^>C(6,B861F9>;F(R)=W2`@(21F(9\?6YK@(N,CY2,@W=U?G1T
M@(R&AXR`;GV#@(N7DH9Z>79K<8"`='V`;F9S<6)N?WI[>W9H5EME8FMZ@&YH
M=&UJ@(F&B9"-@X"(A8"%E)F7FYZ,?8J1C9>CI)*'C8%Z@(N,A8N5@WR#@'1Z
MB(R%B8]Z:G1[=H"1DH%]@W9Q@(R)B)68A(6/@'1]BXF%DH^`;G=V<'J,C'AZ
M?&A@;G1N;WUY:&AK8E]H>7IXA8=Z='V`=("4CX>/D(:$CI65EZ.ADI27C8"(
ME8^/F96*@86$@8J7F(V*B8!R>H!]@HN)@("!?7=^AH:(CX^!?7UZ=8"/C8J)
M@79S>GM]@(2`>'=T;FEL;FUT>G=Q:F5?8FUR=G=S:V5H;G%X?X*#@X."@("`
M@HN7FYV;DHJ&B)&7GIN4CX.#B8Z-C).4C(Z/C()_@8""B(F#=W=W='Z(CHJ)
MAH"`@("#@(&#@X."AH!Z@(2)D)&-@7EV=WI^@X-X<W%O;W)Y=G=Z>'QT;6QG
M9VET>'9]=G%T>H."BI",AH2+CX>/E)".EYR2D9.,AH^<F96=F(.`BY6)CIB'
M>H"'@'J)B7E^BX^`@(J`>("1BH"+AG9T?8F"B9.,@X2*AGZ(C(!Z@(!W<71O
M:W-]>WE]=VMH;G1N<'=J9&-H95QP>G>`A8Q]>H%Z?8F1C(*+B7Z`D9>-EZ.8
MDI>9C("/EHR+E)*`>HJ#?I2<C(*+C'AWA8F`?HZ#='N%=W"(C82+D(Q[>H5]
M@(N1AGJ#@'%XA8!X@(R`>H!_<&MZ@'=Z@8!?97=H8WJ`=&Q\?6AN@(!V?92)
M=H")=&Z+E(F1HIZ&BYV2C9>BE8:7F'J`E(Q]BZ:8A9>8@'J1DH"`D8-H<H5W
M<8"2AH"4F("`CXEZ@)*&=X"%='&`C("`EYB`@(Z`;'J#=W&`>E]C<6UH=(:`
M;GEZ:&%T;F)H>G1J='=K;GV%AHB;F'F`CX!\D9Z,B)B,>H"1C(65H)B)EYB`
M@)>/?HN;@VR`@'!TBY*`@)B,=("7@'*+E7IWBX!H=(6"?XN>C'>+CW=TD8QK
M=(=N7FYZ;FZ`AGUV@(!H<8!W:G%]:%QQ:%]N?H>`AI6&=X".@'V1DGIZBX!T
MBY>2E)NJF(N>F(.`E)B`B).`=("%@(B:F(>'DH9X@(R`=WZ&='&`>G>`B9**
MDI*`?X"&@("/AG%Z@'1Q@(9\?8>'>H"'@'%T?71I?7I?97)N9'&&>FEZ?&YK
M?89Q<8.`:'&%@&R`CX:#G9Z&B9.2A(N=C'F%AW=QBY*`BZ&8AY28AH"+C'IZ
MBX!H=(-Z<8"<C(B<DH"`CXQZ@(F`:72%='&+CX"`FI*`@(9T:'2`=&MT=%Q?
M>GUP@(^`<'^`:VAZ=&)H?7IH=(1W<8N=CXN>DGJ`CXR%D9B,@(N3@X"7FXR7
MJIN&E)B#@(N3AG^(AG1TBXR`BYR,@8^/@("(AH"`AX9U=X!Z=X"4C8:4C("#
M@X!^?7UW;G%S;G-]@7V"C(-Z@'QT='-T<6YK:VEH;GIZ?8J'@(2"@'UW>7IT
M=GI]=WJ*B(N<G)B4DY*%AH>`@("+AWV`?X.&EZ2,D8F(C(BA@&YV=)>`B(9F
M@(NCI)&;@("/BY)T='9ZCX".@&6`>I&/AH-I@(:`C&AK:&B)@'UH7')NBYB`
M?&V`@(",:V]H=)6`@W1G<7JCF(N8@(N3G9Z`B("(F(N8@&Z(D:.>H9AZEYB7
MDGF!;H"8C89H<7EZHZ24@'Z5A)>8@'1E@(QZ@W1K98"IDHN,>GAZE8!E<VM^
M>H"'7&)Z@(^(EX!F@(J,@')T7'&'C(!?=&YNEZ&3='&!:X"8@&A@@(R%FH9T
M8H"GD)R8@'2`KYB`@&V`?:.G:&UHD9Z7O(!E>HNMC)2`5GJ1MXQK=%9TEZR8
M:'AO@*F>DE90>H":C'9<0H";EYAV;EYZJXQY7%EJ=*.,7$I0@(&7FVA?:)>D
MAX904&B`L8!K:%R`H\2P<8!XE["@F%QHA)2WF(EH7)VGMIZ`@&ZCMIN&5FAT
ME[.&<%-HEYBXF&1K:YV;BX!$7'*1L(!Q4%"&D:^&96IBEZ&2@$AE:8"J@'10
M7(F1KH!N:&*7F)&`4&!HEZJ`?5!0@)&VAG)H:*"8JXQ3:&Z7I)&`1VB%G;^8
MAVMNHZBP@&AN9:.SF(!9;G27MIB`7W2AGJF`5E!<EY*&@$1<=*.VC(!<:)&C
ML(!15V*7FYB`/E!TE["2@%!BE*"D=%!*4)&>C&A*8FZ7MH=V5FB/EZN`4$QB
MH9B@@%!H@*^PCXQ<>J.OO(!Q8FBLL;R`7'Z`N[RJC%.`EJ.P@&A$:*RAI&Y6
M7&*OI(EH4'I]J;!N7D5HDI&G@%I<=+62D(!0=("OI&MH1&B)H[!665ITHY6>
M:$I]B[68?V@Y=(^@F%QH4&BMGIY<:(!]NZ2!:$2`B:.D=G16@+:>I(!T@)?.
MI(EH68!XJ9Y<;5^1I)>P5EQW@+:`@%PX>H"OC&)T1X">H)Y0='2`NY*,4$2`
M=:.8='1*@*24F%QH8H"\@(!<4'9HJ9AB:E.1C)&>4&5J@+.!D%Q0@("[C'2`
M7Y>DK[!>@("7R)ZD:&B5B\>8B8!6HYZ@F&)]:)>\C)5<8G1ZKX!Q7%R@AJ.,
M5F]HHZ2+F%!H=X"M@'1<7(^1M8!<=VZCL*.,1VAL@*2`>E!<EI6E@&AK8J.G
ME(!+:&*`GG1Z4W2?E[.&<&IZN["FC&-T>J.DBH!E@*"OPHQS;H"BH:>`66MT
MEYB%@%EZBJ.>:&M3:)6:GFAE8FB<AHIT7(F+KYYV=%!ZFY>D;FYH=*6#D6A0
M@'NIF&]N1("2D:1H:&)HH8"&:%!X=*^8=&Y-@(FCL&AZ:("M@Z"`:(^+QZ2(
MC%R7JKO(@)%N@+"%HVABCX"[C("`08"#EZ17=U!HGG*/4%"`=,&8@(!0EX:I
ML&.`4("D=YA07'IZP8"`@$2+@*.84W90@)ATE5!B@("Z@(!H1)&`HYAB@%"`
MF("24'2`@,.,BX!BH(BOI'J/;ZFPE*1H@(:1PH"(@%R4AJ.,8G%:@(R`@%!<
M;H"?@'U<4(""HYAU@&F+F(N&7'1Z@*6,?&)H@("7AG=T:(N&>'!996Z+FW=Q
M:VB`D9B`96UU@(R$>EQ<?8^0AWIH:(";G)*`?7V1IY*`='V7H+6PAH"%D9R:
MGH!ZDY*8@&UH7WJ4EH-D<6AQE(9Z:&B(AI>,=&YHD9Z1F'1L=(NJC(B`;(6$
MEX!?=&*`DHN25FAT=)6`@'1EG8:+@%]M5H">A9)H=(!TI8!Z@'2@C*.87WUR
MEZJ.I("`FY>]C)>8@*^8H89BB'27I(*,5G&`=)MN=&YEEX"`:$=L78"8?9)B
M@(R`I'2`@'2IC*"`7'YED9AZC%R`AH">:'1H:)^`BX!0=VN7F'>&5G2&@)YH
M=(!TJ8R4@$I];I>DA9A<@)B(J("`@(#!I*R,;HITH["(CVN7F)&J:'%H=*6!
ME(!0<6:7@'&`4(",D9AH@'2`MIB<:%EV=*^DD8!<BX:1F&%Q7X"PC9AH4&1B
MH8!X=%F`@)>84VY?@*2,F%9<;G2M@(!N69&.J9AE>FJ7MJ.>7&Y]E\6>H(!T
MHZ"UC'!T<:^SJ)A07%Y]GH!\4%R(A9YN4%!0EYNAAE%H98"JC8!7=(.7MH!R
M5FBAF*B`55Q6EYN(@%!H;I&D7VA08IJ7MH!07%"7C)&&1'J`E[!N=#MHI)?#
M@&AN4*^;HXQ6E("OR("/4X"PG=*`;FY<NYB7C$AZ9)>P6GH^:)N1O&A07%"I
MAI>,1("`J;9R@#YHJJ/.@&YH7*^,EX!*@&NCL'1T.&B,D;QH8E!0HX&7@$UV
M:*^8;G0[=)*CO&AE4%RFDJ>`68"`N["+@$V`I;O(C'UH>JVFL(!N@("XIXQH
M372`HZ1T:$ETBY287%Q9=**/C%Q0=)&^I(%H4'24J9YT;F.`I)6,5D]E@+6A
MC&A*;GV7C&AB5H"8EXQ366:`KYB&7%!Z@*F,;FA9D9B=F%QQ;I?#GIMH:(N4
MQZ2(@&BCI*FP7'1QE\*8FUQ0>72L@&AH39>,EXP_:%6`LXR>7&B,@,&,@(!6
MHYZOF%I]8I>\D9A08GJ`MH!^:%"7@9>`36=4@*2+DE!H=("P;GI<7)>(KX!6
M;DV7I)>D8G1QD;"`HX!TKY*KC'J`?<&PHYY0@(:7O)*&4&B&=*^`8FY:@(^2
M@%Q]7X"D8WIH=)N=JH!E7&*OI*.85F)ND9B%C%!H@'V;@'%T@):(EH!0='R7
MI(QH2W1]D:>`:%Q<@)>8='IN8I2,='ETB)>IF'1T7X"VI:J,:VB`KINGC%^`
MAI&;AGIH@(!ZDEQE>W2.@WI04'ENEXQ?95-HB)V8>H]N=*F2D8R(C(NG@'J&
M:9&>AH-V=&B7I'&):%"`CX^!?59<G8"`I%QH?GI\E(Q5@(QNEX!B>(B,E["`
M:)YTD;F,@(N,@JFP;I&`99>8@8%]:&Z7:%QW1%R3AH"`;DQTDG>CC%9]@XF7
MI(!EEX"`K8!T@X*)EYA<=(9HEYAK;6YT@*F,7WI07)>,A7IN8G28=("`5H"2
MA8%W8E"`F(ND@&)]BYR>FVYTF8"CL'1T>XB1J:1K@("`P:2&@'=N@*V`=(!0
M=).`>7!K8I>D;H!H4("HJIB&5E"7C:.V@'&`CX^=F&*`F(*CAE-9=(J7LX!*
M95"`M9B`:&):@+"`@&Y-@(V$?'1<:*^,>H904)>TMJ>`1&B>E]"\;G2(DJ/'
MF&B7@Y>\AFAH=XBOL&AB7$V7OYZ`:%!<K[".F%!<BY6CF(!<=*2#G9A2=(^C
MIY)H.6B`E\*`7U96?9>K@%QH5H";@&Y*7'21I&AH5ER=IZ>`4E1<H[">AE!B
M@*.\DH!?:)>OOYAZ>GJOO*>,8G2+K[R;@U9HEZ"KC&A4:)>2CW0[4'&1FX-B
M16*`G;.,8V)TE*RP@%-H;I>YF'1=8GJCL(!S8F*7L9AT7DIBHYZ$>E!$@)N.
MCX!!:)F,EXQ02H"2H["`3G2+E\>P;GJ,CL'+@&]Z=)?,L'%R7&BOL("`7$J`
MIX!N;CAHK9*/@$0X@)N%IX`^@)*.IY)04(N#H\B`7'UQD;N85FAT:*^P7&53
M4("MC&AK/E"OC(",4%"`GH"`@#R`GHBIAE!0EYB1PH!0BX"+I(!07(!WK[QH
M=(!EE\*D<I>`:,&8:X!<69>P@("&/FBS@("87%:7GG27@#Z`CWVCC%!<E8"`
MO(!<EX"`JH!0=(-TK[!<=(!9@+:&>IJ`;KN88H!H7)>8='IT1VBA;GJ24&B;
M@'V4@%F7GH"MC%R`C(:7L("`MH:7MH!ND9.7K[!K@(!BEYAL@(9Q>IR`4(!<
M:)Z`?'UV;H">;HN88I>D@(N.@'2IL(NJ@'24B928CW2`E6AZ@%!B=7I_A(!:
M=&YHBW1H?8"`B8QH66A@@)B)C8!^A922@X^`@*^DF(QZ?(:7F)*#<(",AYV,
M<GV(BXZ,=&5W=(N;@'1Y:GB/C'>`C(NOL(.&=&B+IY*(CVABBX!T@VAEBY.`
MBX!2=(]NBXQ38H!T=)!N4("`>J.`6G2`=)>P;G25:(">@&*`@X"OI&)Z:%R7
ML(R4F&N`M8R`GFYTKZ2)EX!<E["!HYA<@*N/EYYH4(N`?::`1&YN:)>84VB,
M:("J:&B.@)?&F%-T7%"OL'>1@%>`L(!TAE!TN9B%CVA$@(QBD8`V=))VB(9$
M2I.`@+-H4("`@*^D4'22;JFP:X"2B*_7L'*1:&C'L(".=%2`I&YN=#YHK8R%
MC%!$@(QZEX!$@)*#EX!'7)&&H[:`7XN`D;F88GJ&@*FD8F)N9I&S@%EE2ERC
MF'1]:%"`F'1W:$ITIY*)C%90EY*1I(!EBZZ@K)A6:(R+K+"`87J`@*^88'2`
MB*FP@&)W;Y?"C&MH4VBCL(!Z:%.`GH:`:%ITK*61DE90@(F;DG=<:)>,H(Q0
M8G21K*2,7&AZ@*Z`:U]B@)>JAF)L99>PF8938FZ`L(9W7%!]@)>`7&%?E["?
MDEQB<9>VC(]N8I>:JXQQ:&*CL*FD8FA]E*J8C%QHFHBIC%A968"4G89&:&AZ
MNYAW:&AZB[B,;GICE[&AC&MQ;J/(CY>`7XNCI(!K4$2`F)&84$1<=X6)@%!<
MB("7C%]3:(N1HXQ6:'2+M:J&:'2`E\&>@(%WD:^WF'=W:)>VCXEN7'J@IX!]
M8E:7JJ*8;E!BBY2;DE9BAX^CI(!9=)*7NZ1J<72`IJ2`7FAF@*Z&;V)<=)VG
M@'!<4("9C8-H4&*4CWMT4%"`EZ",;E!HE)>MF%QH@)6CI8!0;GR+M)AT;'2+
MH[:`;GIQE[F8@&5K=Z.S@W]H99>GJ(QT7VB7F(Z`4&6`D9N&=%!BBHZGC&5N
M>IVDG(!3<8"7L))W7FZ%D9^`:&ANE)Z/;E]K<I>8=&537X"4C&Y84&*+F9*`
M86A]EZ&5@&EZD:">C(!VB:.HGH9W?I2SK9B`<'2(H9*`<&)TBX^&=&)B@)"*
MAVM@>HF2C'I<8H"1HYAT;76`G:V8='M]B*>8@71M=X65@&EH5W22@'AK8F6`
MF'1W:%1TB(V&>FA<@(R+FX!QBY26DI)T=)N2FYAT='N)EZ.2771\>JF>@'1O
M=8"7C'6`:'J0@WUT=W.`FX!T=&B+F9R,=W%B@)B1FX!Q?H"-@85N:(V&E(QW
M?72%CXN`7W1Y?I>&>6)B>GJ1AG5]:H")@(%N>':`CW1X:&B'@H^#=G=REYB5
MF'J`@(N?B8F`>HV/GXR'C'N4F(R/@(")EY*`BFABBX"`AW1K<81T@(QB@(QZ
MD8^`<8N,>YV,;HB#B)>9@'J,=("D@("`:W2+C'%]@%R`@&Q]=&ATB8!QBFAB
MCX9ZB(%N>I*`BY)Q@)B#D:2&=)>,?:.8=HN2@I2;@'Z)='V2@'&#=&Z.C'2`
M@&J`AG:`@&R`C'1]B6YND8F`EH9TD8R`EXQJ@)-WBYYT;H1Q=)2`<X!Z;I&,
M:("`8(",;FZ`:&B1@'>)=&B+AGB1C&B`F'2`DG1TE(:`FX!QE(9]H8QQD9B`
MEZ2`>I)T@*.&?HZ`=Y>8=(N&:XN8=GV&:'&7@'J-;FB1AH"7AFZ`F'J1DFY]
MCX&+F(!TBX"`EX!RA8"`D8QK;G=M@(QZ>G=L>H9Z>(!N;HN#=X2`=(62B8N)
M@(B5CY>8@("1D)&7C'N%DY*:E8>!@H.%C(!Z@'J`A'IV<75X@(1]?GEZB8!]
M>G1T?8B&@X!Q?86"C8F`@(B2AH6#<7V"BXQZ=W%N=(")='B`;WV`>G1L?8*(
M@WI_:&B(@'V)BH"`EX!ZAG>`DY&;CWIUBX9XEY)TD9B,C8R`=XN'BYZ`=(%N
M>I2&:H",:X"2='A[@(N;C("&:'&7@("7AGV1GH!ZAG"`FXZ3AFMTBX"`FH!K
MBXR`BX!H;'Y^B(QH;GEH?8QT:("`<8B`7VAN>I&3@'IT9H"?C(N8@8"=F(&`
M@'V4GI:8@&Z`CX"(DFYHD89\@&A:97J#B(!A;G=ND9AT<8"`?9>,;'V$D:68
M@X!T<8ND@(N8<8"DAGIY=&Z7I(2*;E9T=W:(@VATFX!]B6)<@(^4FX9B<7!T
MG8QUBXE]D9Z`;H6`BZV8@'QN<8N)>HN`;I&2=&YK6&B7E8:`7%-N<'J/@&N`
MC(")@%QHB(N=GH!T>GN+H89XBX!ZEXQH;G1]E*>8@8!H@):&E)B`@)>2<71N
M98":H9AT:&Y]>I&;;GJ/A(N,@%YH?X6CF'V`='J.F(.`EX"1JX9Z?7R%EZJ&
M>G1?@(>`DH!D=(Z`<8EH7(N3BX!T7&)Z<XN,9(",?9>5@&6`CWZAF'%W<WJ-
MBX:+B7:`I(!TB71]G9Z`=W=@>H9^BW1K@(9W=XEH7)>8AY>&<'1^A922@)>8
M>I>8:&B%AH6IGG:`='>+@(")=V>`@U9<=E]HD8]T?W9I@(F.FX9]D8QZBYAN
M=*.8E*2,=GA^B)>)A9V&=Y2,7&B'>H"FDG%U:W2)@XR5@'>4DFZ`DFEZH8^`
MB7=O@(.+G(!ZEXQZD8QH=)6`@)AT76UJ=XZ&@)&`=Y&`8G2&<8"B@VYT8FB+
MAHN4@("4C'R+C&Z`I(R1DG1N@(*%D(!WAG1TB8!C>HV`CI^`:W=O@).&C(9Z
M>HR`98"`=)>EDH!Z:G2)AI2,;GV#='2`=&6+FXN>C&YT?HN5E8"`@&^`CVYN
M?8:#EYAP;FANB8.*C'IP?89H:'=B=)><B8!T8WJ&EZN,B)6,BHZ2;FB5C)6;
M@&YH=X6.C(&+@'J;AG1L='%WG8!E959N?8B;B8!WBXQZD8!TCJ.IDH^`;H"/
MIYZ`CX"#CXN&7&B$@)V/@&A0;G.`@'1T672&<7=D<G>+K8^#=&Z+BJ.JC(:`
MEY*1FX"`CZ.SF(QV;GZ`EX!I=&%Q?7=K4&)N@**,@&A6=("/@(!W8H",@H%P
M='N4I8^);G20E*RDAX"`D8R+C&AN>HN>AG=B97&`HX9X@W1]BHEN67%T@)Z,
M>5Q<>HN2C(R`<9>;BH-T<7>7GX^&:&Z'B:.;@'B`C(&1AEQQ@Y&>CWIH:G&+
MI(!]@VIZC(!H971TE)Z)@%Q9=X"%BXQN=)V2D8^`@(ZIKZJ8=HB)BZB8=WJ`
M@XB6@&)T=(N8AGEH7&"`@&5T:%QZ>G%I:VN`HYZ=F&YWDY>=K)N`EZ64G9*`
M?HN9EYN`<8!T@)B`:W%U;("`5E988'V`>VUD66B1AH",>G>(D(-]@7:+J:&D
MF(""E*&<K)Z`EYF-C(!H8'J`@(9H96YD>H5T:'1W;HN`8FAK=(N9AGJ`:WJC
MCXZ8@'V4F(F7DGR7I)28AFAN?'1ZD&YH@'1XB'IH<7V`EYAT?71E>H=W>HQT
M=(^`=X"`B)>9CX^`<8N;A)*8@'B.C(B7C(".DY&8C'>`@'*+F'1]C'1RA8!B
M<7=XBX9X?6YB@(UW@(]N;H6`<H"`=X6/CIB,@Y>8AY>A@("7AH"1AG*`C(6,
MC'1W>F^+EH"`A&A<>G19;G1B='UK;6QH@(F`CHUT@)Z,BZ*,?9>DEZF;@)2)
M?IV2=("-='J8@&B$=&Z`=%9?659Z@&1]=%EQAGIZDX-]G8R(DH"#EYB/H)AY
MEYZ)EYB#=XN3B)B`;G1B<H!T:&YT672&:7%Z<W1^@'%X;W>7@("0@'*`FX:`
MGH:(HIN?F(^.E)B3H8QQB(!Q>H-N8H"`>XN`=&YLA8&`<&]N98",=WI_>G*`
MDH"`AHN5DI2'@8"(F8:%CX!ZBX^&?(!Y>(F1C8!X?GN`AXR`=HB&@H6#=VAT
M@X!^>'=S<HF,>GM_=&YZ@'-T>H"&AHN&?("2FH^6F("%CXR&@(-]?HJ(AG1Q
M?71Y@X!T<8"`=WUW;&5N>G1U<G1W=(N2@(>,C(61GHR1E968C9&,@(".E8.)
MDH!]BX:`@()\?GY]?6)<;EY@='9E:'UN<H2`=WV$C(J$BXZ#BZ.DDJ">C(N=
MF)"7FYB,B8R`<7J(@'B`=&!B<&MH;F]P:G2(=V^`@'%ZD8^(EY*)B8>-C(F4
MH9B,EY*`D9Z5D9*&;7%T='QW?H!K='QT;7V)=X"/@'5V=W1Z@(""=X"0@'J%
M@'6`FY61G(:`@(./@H.*@X!^B(!T@'Z%AXF'='1Z@()^B7IN?GEZ=W=Z>(2(
MBH9W@(!]D9.,A(N&>H!W<7E]D9F5CX-Z=(F5B9*,@(.+AX"`@(")C9&&=')Z
M>X"+@&QW?GI\=FME;'>`@'1J:&5TBXR)C(^,E)B2BH:4HZBGGH9Y>H:.E)*&
M@X6(AH!T<7J$B89T7%9?:WJ`>FIN>H"'AH&`@Y2@GH^#@("+HZ25CX^'B9:&
M=GJ%EY^>CW1?7'J!>(!T8VAW<6)G96B`C(R`:&5R@(61F'2`CX>1CX.`D:*C
MLIA[B("+HYZ&@(-J=(9?7&MK@).,;F%04("&>HZ`:WJ(>FZ`;H"BF9Z2='"`
MC(NCGH"7FX:,BG1K@(V/F'1E95]TD(QZA89K@(QJ;WN`BYV8=&M<7("`A9*#
M=8"/=&Z#<8"=GI)Z;F!Q@8NDC'V4C("(CX!WEYB7GH!T;G*`D8]Y@(!L@(!H
M;'J$D:&8?'%698"`B)*&=("`:W1Z>I6FII^/=&Z`@Y&GC(6/@WN#@'&`C(Z<
MF'IQ:VA]C8%[?VAE=&A?:W%YB)*&?&Y?=(B)HZJ8CI2&@(Z,D:>GHZ&&;W1X
M?92?B8:&<'%N8F%F;GJ#=&)C4%!T@("*B8!Z?W=Z@(67GIJ;C'1T@(R5K:>5
MC(2"@("$C8^,DH9K8V%?:("+@X)];FYJ<'5WA923@WMQ7VA]BY>;DH!^?'J(
MD92@I*&8C(!T=WJ(EH^`?7%G<7=T@(>*D8QZ;&5=;HN,E)B`:W)W=(".CIJ9
MDI&`<7>+BY>JC'J`=7)]B8:&CXR4AG!X<7J1HYN)D'1E@'R`AXN1C(QW;FA:
M@)B4HIAT8&YS;HF`?8F`CH1T<W>%BZFPC9&,?8"+DH.)CY&6@'MN77&(EHR)
MAEQH<6Y\=GZ!?'IO:%!0@(*1FXET:X!\BY:*E8F7JH^#=WIW@*^>CH]\>7B(
MC(.*B9>,='1<4&B`CH"#:U1H;7J`?8B&B(F(@%QTAXNCI).`@(J&E)*/EHRC
MI(R`:&YN@*2&@'%=8&5W<6QU>HF`>GI88H"7F928@'&`@H^'B)6-E9J8@&V(
MC)>OJI*`?7IT@'I]@'J1C'1M8V-ND:2,C'II<72`?7A]B)*`A8!9:("1F)N2
M='>`@(^#@(^'C).,;F5]>(NGF(-Z=G>`AH&%@("5AF]N95]TEYB%B71H>G^$
M@WZ"CY*"AG12:'^`D9F#;GV`?XR&A8R,EYZ&;'1Z=)>MC(6#='&`@7V#@(67
M@')W8ER`DH"%AF)B<V]Y?G5^D(F+E(!QBY*1J:>&A8R`A8R`@X:"E)N`:WUN
M:)28@']W8F)Q:'%W:X",='I\:&B5F(NAF'F`@X.2CX67FX:7FW1]CH.+HYZ%
MBX-U@X!TA'=QBX9B97!6:(N#@(EZ:7AY=Y2&>I>&=(6`:WJ7AY&GC(B/@8N9
MC(6=C'B7AF5W=&EZDH%]@VAH>FYZC'I]D8!I@(!B@)*'E)*`=8!W@)F`@)6`
M?I2`;8"&=HN8>GUZ:'2#=H"0@'J7@'"`=&Z+DH:.@V5Q>G&`DGJ`C8!ZB7=Q
MB8:%E89R>G=O@(R`A8]Z@)6`?XR!A9V8AHN`;H"#?HF&=GV&='>`:'2*AXF,
M@&AQ>G*`AG-]>F][@G1Q@("+I9B%B(%^CYN,D9)[BY"`AH:`A9N8A8N`;H"$
M@(:`;G1[;G1T7VZ`@(6,@&9Z@WR1DX.*AX:1DH.`CXF7JIB%B8-ZD9B$BX9X
MA8%Z>W1H=(1W='IH8GA]=X"`>("'A8Z`>8>,B8^8@&Z%@865CX2%A8:/AWR&
M@'Z1CX!Q=&MK@(!Q=FQT?7I\?7=Q@(^`B(9T=X6)@HN&@(V&A8R`@(N5DY:8
M@'V&@8N-@X!\=W>`>G2`>H")AG][?'1]B8!^?W=^@H!^@H!^CXV+CH-]?82$
M@X9Z?G]X@'YW?8.#A8N#>X*&B(^/BX:$@XF)@86&@XF,B8.`@'V`B(6&@H&&
M@'V`>GJ`@X!]?71W?7V'C(:)CXF&D8R&E(R+D8:#@(&`@HE]@(9U?X-Y>GY]
M>8"`=7YT<7QT=("$>H"*='V)@(N/C(N+B8*.C("2C(*/C(:#BX"`C("%@WJ`
M>'9Q=71H?7II=&MJ<GV#@(6`?H)_AX:"B(>)B(N)@(N.D9B/DHF%C8R,@8"`
M=X"#?71L;FUQ=WMV:W1W='I\>WN`B8R&@']_@)&8CX.&@'Z)C8F$A8:&C(>!
M?76`AX*`@'IP?8!V>G=X@(6-AGUW>H6#BY*`>GZ%AXF-@82)BY6,@X%]@(B0
MAGA^=7J#@(!W>7Z`B8-^=W>`B8Z,@7UV?8!^?W=[@(6*@7UW=XB-CX^#>GV#
MA(2`<71\?8"&=FY[@(61CX&"@X2/C(2#@8.+DH!Z?71ZCXR"@'9T>W]Z>G1L
M@(!Y>G1E:("`?81W='V`B8B`@(F2D)N8?8"'BY&;DX"%@(")@(.`=X""@'!Q
M<6AZ@'MV;G!M=WU\?72`BXF1B8-\@)*,D9.)AH&+CX:'AHN,D96&?7E]@(")
M@&]P;7%M='=I='I]?'5[=7J)D9*#B(9]BX^0AHB3B928BHJ`BY64EH^,@'J*
M@("`?7EU@'IS<6AW=GZ,@'IW?7UZC8!^B86-AHB'@HN/FYB&CH.`B(Z-@(B'
M?XF`@'=Q@(*(C(.`<'J`?H6#@WI]AH!]?'Y[?(N#?7YW?7V`AX!]@(F`>H)Z
M=("&@X"`='=]?8V,@(N/B8N2AH"*AH60B8!\=W:`A'Z*AGJ`AGI[?WMXA8%[
M@'1N=W=ZA()]A89\@(R&BI.2C9")@(B#AI:,AXF`?8"!>GV#>GV`>G9Q;VMR
M=7=_=')X<7A]@(*%C(J.CX6(AHN6E963D8F,EHV4F)"2D(V'@(!W?H!]@'%J
M;FAK<79Q='QQ=W=Q=WF`BY&/AHF`@(Z,CI62C(Z0AXF'A9&2D)*,@'Z#@'Z$
M>G=X<6UK:VEL='N&@WEZ=')]A8:%B(.`@'Z`@(*)DI6/C81]A8F(D)"'@X)]
M>79X>GV!@H%V;G1T>H6#@'U]>7I]>WU\@(:&AX!]>'J)BHR2B8!]@(!\A(&`
MB(F&@'=T>X"(EX^!B(-\?("`=X.&@()Y<'%W@(J/@X"`<'=^>'=^@'N%@W%T
M<W2`C8^+AH"`BX:+E8R.G9N-CXEZB)*4FX^`>WIT>H9W>HJ`>X!W8FAZ=8"&
M=75K:G1^=WJ,@86<C'Z#@H*7I)B7C("(AHB4E8V1GHQ[A&YH@(6'A(!H96AE
M='1L>GQW>G]N:(!]A9N/BX2`?X",AY&2BYJ8AH:&@(6=F)&2@')V<WM]>75Y
M=&-N:%IN>X"*C(!P<6UZA8")C("%BX%W@(6%G:&:F(:`@H:+D9*&CI"`?GUQ
M<8"(A8=Z:VMH=("`@(6#='V`:W2`@HJ1AWIZ<7J)@8N2AH..C7J`AGB+E9&3
M@WIV>GF`FX:+E8!_@'IR?8J!CXER>FQN@(F)B(^`=(9T=(&"AHB.@'IY;H"`
M?9&&@XB.AWZ+@("7FZ&8B8!T>'N+DH.+@'-U=7IU@(J"B8!V;FAT=WV!@H!N
M=W=T@("(BX^5C(F`@(B#D9F2C(>$?8"$@(>,CHR!?&YE:'1_?X)];FMK;FYQ
M=GM^?7]Z<71\@(B4E8F&B(:)BY21D9J8DXR)@X".DY6/@X!T<7AY>71^>G%Y
M;FEH:WI]A8:!>FUZ>G:#AX6#BHR`@H"$C8R;FXR&AX=_BYB%B8F"@7UZ='5X
M@(=W=WMK<8"#@("&>H"&?X!T=("&BY&3@'J(@(65CXN+C(F&@WV#A(B7C'V`
M?7J`D8R!AGI]@'EZ=V]T@(!W@'=I?82!A(:!@(6#@H!T>HF&CYB#=7Z!@(N8
MB8N)AHR)A(2&@HN8@WV!='.`@7IX>G9Z?7I[=&Y]@'V`@&YN?7I]@X!Z?8"#
MA8!^AHR.G9N&AHJ(C9>2B(>#A86#@7UZ?HF&>GIT:W1^?7EV='1T=WIQ;G1Z
M?82'@'E^@XB,CXV(B(^0AX>*AHB4F(^&@("`AHN'@'=Y=W)X=VMR?7U]?W=Q
M='N`AH&`@'^`BXE[@(:"CI22C(>)CI26DY*'B96,B(F!?("+AH%\='5S>H!Y
M<W)W<72`=&]Z@(.`@H!V=X"(AH6)@8..DHR#BXF)EYB2AX.)A(F,C(1\B(9]
M@H!Z=GV%>GMW='1T@'IS='-U<7V`='I_@(."AX!Z?X.&@(6,@(6-C(""AX&*
MDY22@X.$?8"'AWQZ@WIR>7=Q=WU]?GIZ?79Z@'MW>7QW>H.`>H"!A(F,D(R&
MB8Z,CY62B8F-B8"%AH"`A82`?7IW='=^?'=Y>G1O=W=N=GMZ>GV"?WR`@H&`
MB(R&BX^*AHN0C968E9*)B8N+D(^.AX"`?7^`?7MW>G=V=G!S;G)X>'IY>WIW
M@'QZ@H"#B8R'AXF`A8Z)CI*,BY&,AY&-BY2/B8J`>("#>H"#='%V;W1^=W-]
M>72`>G)Z=W%]AGI]@W=Z@7R`B(:&DHV'CX:`BXR&BX^`@(F`@(9]@(B$@8>`
M<'UZ<8"`<7=]<')_='2#?(")@'>`@'F1DH"+B8"`BH:(DHF.F(R.D(."CXV`
MBXEW@(!W>GIW>("`?H!N;G=P=X"`='Q\;GEZ=("!@(:&@7Z%@(6:DI"8CXN1
MDXR1E8F2DXR-AH!]A("`B8!Z?W9R=W=U@(!W>W=M;G-W?82`@(-Z?8F`A9&0
MBI&/A(N)AI&3D(^0B8F/@(*-@(6+AH&`>F]T='1^=G)W=&YP>7%ZBH"`@WQ[
M=W^#AXF$C(-]B8>"BY2/C92,B(F&B(B&B8:`?8!W;GIZ<X"`=W1T<71W=WZ`
M=GI^='2`?7B+C(.(AH.#A(6,C8B4F(:)C8"`D8R&CX:`@'Q\@(!\@(-X@(!K
M;GIW=X"`<'=Q<7UW>7Y\?("#>GV&?8B/B8F)AX.+C(B1C8N5CXZ)B8.%E(J)
MC'MZ?'I[?8!W?8!Y?W=O='M]@(:`=GUU?8)]@'^"@H>,@(6&A928DH^.B(B/
MB8F-A(6'AH)]?7B`AX.&?7-T=WA[?W=U>'=Z?'9Q='Y_AHJ`A(*`BXN'AHN)
MBY.,A8:`A928C(F#=8"&@X6`>G1[?'1W;FAW=WA[=&5H=72`@7I]?8&%AH!W
M@("(EXV&AH.%CI.,BXV)DI*,AH!_@I&/@'YN;GQ_A8!W<'%\>X!];W9Z@(-]
M=&MT=GZ+@("!@HN,C(.`B(N7F9&/@("(CHR&AX"`BX>&@'5[A8N)AGIM>7I]
MAH!Q<7I]@H9Z>G^`CI.&?8%\@)22AHF&@8N2AH6$@(N8DHR,@'J*AH*)@'>`
M@X!^=VIT@H&)AG1Q>7J`CH!S?GM]B(9Z?8.#BY*`@(1]BYV5C(^&@9&2A(6`
M>86,@H*`:7&`='J!='%]@'A\=&5W?7V'@&YQ>G6`D8!ZA8"%D8R%B(J)E9*`
MAH!ZBY6,AHN`?I"&@(-Z?86+A(%Z9G%Z<8"`<W-[?'=]=&]]@8F-@'E[?7J+
MD("`B(*+DXR&B(:)EHR'B7IXB(>`A(!T>H!X>G=T>X&$A8!N;GUW?8N#>GZ`
M@(.#@(6%BYJ8BXF)@(B9CXN/A(6)B8B`?7R#AH*&@'%W?7V`@WQV>75Y>G-X
M>GV`@X!P=WQZB8V(AH2(B(N,B(>#CYB2CH:`>("/B8R*@8%_@H!Z>'=\>GIZ
M;F=N='E]@'=Q=WF`@(""?("%B(-X?7IZBX^*AX.%A(B,BX:#BY*,B8-T;WJ#
M@8B&>GIY>X!\?7M^@("$=F]W=WN#@X!T>'J`@X.%@(2.CXR$@WV`D9./C(!^
M?8"(B(2`A8F%AH!T<7J"@XB`=G9R?7]Z>GA\@(B'>GUY>HB.D(F%@H6.B8R)
M@XN/E9*)@WN%CI&8AH"`>X.%AX![@'J`@'-Q:W2`AX1W?'1T@("`>'A]@(J$
M@(!XA8R4F)*,AI26D)6)B(F+E(J#=W1^?HN,>G=T>7B`@'1Y=WJ`=W-H:W1]
MB8!]?7-^A8B&@(>$CI.,B(!]A(Z2C(J`>HF&B(B`?7V(AH.`<7-V>8&`=W!T
M=GJ#@'IZ>H"#@7]Y>GR)D(F)@WZ%BXV)BH>)DI*0AX!]@HN+C(-V>GMZ?WQV
M<WA]@(!T<7!Q?X:"?'IY>H6&@(!Z@(6)C(:#@(B2DY6/B8:+D8R)@X"&B(R)
M@'IW@(B+CX%Z?7J`@(!Y=WU]@(!T<6YT@(6&@(!\@(N&AH.`@XB/C(>$@(:*
MCI.,AX6+C(:)@("%A(B$@'1R>GR!@'=W=G=[@(!V>GQ^@X![='1W>X*!@8!]
MA8F&AH6#A8Z2CHF`@(*#B8J&?7Y_>7Y_=WI]?GY^>G-W=WR`?79U='%]@GE\
M>WJ`B(R(AH"`CHR1F(^)CH^&B8F`A8R&BX9\>'U_@(N`=7QQ<7IV;G!S;WI^
M='=T<GZ$@X&$@'V.BH6,AH2+DY".B8"%CY&7F8R&C(>$C(-]@X&"AH!V='9W
M@(9[>GUU>H)[='IZ?8F'@'YT=(")BX^-@861C(V2B8J1CXV*@'U^@86.B7J`
M@'F`@7IW?H"`A8!Y=7!Z@8&`?GUT?X)Y@'V`BHN0B8!Z?8:&D9*#@'Z#@X.(
M@(.$AHZ`?WUT?H6*@WR`='1W=W1P=WV`@WQZ;G&`@(:&@'EX@(!_@'V%BH^3
MC(.`B(F1FY*)AH6(B8:`?W]]BHE\>G%M=X2#@(-W='ET=71S=8"#?(!T:WJ`
MAHN.AH"(AH>-AHB.D9.5CX"%AH.1DHR'AH:#AX!Z@7J`BH!W<6MK=(%[@(!T
M>GIZ>7M]?I&-B8R`?8.(CH^3AXB/A8N)@HB.DH^0AG9^>GV'@']Z>GIT>6YQ
M?'F%B8%Z<'5U@(J#B(!_@'V`>H"#A9>2CHZ!@X:/CXZ/@X*#>7YZ=GJ`A("&
M@&UY<72`?W]Z?79R=&AT>GJ%AH!V=WEZBXR-D8F)AX.`@(6%D9B,C(9\?H.(
MAXN)@(.`?7UZ>'V"@(*!='1W='>`@WV"@WU]=W1\@(6+C(!Y>G1]AH:)CHR#
MA8-Z@(2)EY*-B8-\?HB!A8R`@(%^>GI]>("#@(N`>GUW=WJ#@(",@("`=7^`
MB(^4C8**@("3C(Z1D(F"A7I]@7V+CX:*@WUZ@(!XA8!\A'IW='!O=(%]A89V
M?GUW@(>&@HZ,@8>`>H6&BY>2AHB&?8B2A(N2A(:'>W5Y='2%@'J!=&MT=&YZ
M@'9^AG9T=VQT@(.&CH%W@(!ZBXV&D92-D)*!@(R#BYB)@X-[=8"!>(6&>H6`
M=79T<7J*@X"'='%Z=7J`@WV%AWJ`@'*`BXR.D89\A8"`C8:#B(6$AX9X>H%Z
MA8Z&@X!]>8"`>H>#?H:`='-W=("/B8B,@'V#@X6+C(:,C("#@'J`C(R.DH>`
MA(*#AX:"AX:"B(!T=WAX@(J#?H!W>8!^@X>#@(6`=GQZ=X"&AH6$@'F`@(6,
MA(B,AX:)@WJ`B8:1D(:`?WY^A8:%B8&#AGIT=G9T?H:`>71M<7)Z@(!]?H)\
M>G]U>H.)C(J*@'U^@(N&A8R'@X:)@'J#@86.BH9Z=WEZ?7Z"@'F#@'5W=G1Z
MB(J&@GAZ>GN%AX&`B(1]AH!U@(B0DY6/@X!]B(R`B(>`?82`;W=W=X6'A(!T
M<GA]>H"'='V'@'Q_?'2`CXZ2AX*$@(61DH:+EXF*DH!W@(>)D9*!?W1QA8%\
MA81W>HEZ<7QT>(B'@W]X;WJ`?8N)?8B,A(*&>G>+C(^3@7U\>H".DH..C("+
MC'MZ?X.(D8R`?6]W@7V`@'QW@(=Z>W1M>H6*B8!U<7AY@(R`?8.`@(.`=WV(
MBY6/@'IT>(.+AX"!>WZ'@'9W=WZ.DXF#>G!Z@(&$@'E\@X!_@'%Q@(V0DH9Y
M>GV`CHR#AH:"BXQZ>H"`BY>,@'IW>HB)@X6`>8.`=G9T:WJ+AH&`;FYY@(.)
MA("(AX.*@W6`C8V3E8-]@("+DXV*C8>%D8Q[@(%_BX^$?'9P=X&`@H)Z>H:`
M>'UV<8"/BHR`<G1\@(N,@8")@X*+@'F%BHV7DH-_>GN%BH.&@WN`B8!Y@'I[
MBXF!@'1Q>G^`A(!Q?8!Y@(-W>HB.C8^`>GUY@(Z'@(*#>X6)=WJ`@(F1C8!Y
M<72#@("&>G>`@7IZ?W1]B(2&@'1X?H"%CH![AH"`B8-Z?HB)CX^`@'UZB9&,
MAHF`>HJ#>H!\?86*A'UW:W>`>H6"=W>`@'B`=VY]@(2'@'=W?W^)D(&'AH"+
MC(>"B(F)EXV#@WE]B(Z)B(9X@(F`@H![@(B+A(1Z;GIY?H:`>GR`@86)>GV#
M@X^2AH!\>8",B8.'@("+BH."@W^+E(F&@'1Z@H6&@WAV?7V`@WQU?(.%BH9W
M=7I[A(F$@H.`A8R#?("`A9&2@WUZ>(")AH:`>("%@7^`='2#AH.!=V]W@(&'
M@71Z?'J`@'=Q>H"%D(-W>'2`BXZ)@X-^B(V!@X!]B(^/@H!W=XN+BHE\?H*(
MB8.`='J#@HJ`=&YR?G^%@'%Z>8"(@7]W@(6+E8!Z=W2%BXZ)@("`CHV'B8""
MBY.3AH!V>(6%C(9Y>X"%A(.`='Z#B(J`=G)W@(F,@'I[?8B+AH!]@(F4DHB!
M=WV+CHR'@7V`CHJ#?7I_A8V,@71L>("%C(-Y=WU_?H!Z>7V%BXR`>7Z`AI6/
MA8."@XF/AGY_?8B/BH)]=W6`B(&#>GB`@X!Z=W%TA(.%@&ML=WR"BX%S?7U]
MB(-]?8*%B(^`>H!XB)*&@8*`?HN,@(*`?8N/AX%]<72)@86'>GJ%AH.#@':`
MAX&)@&MQ>GZ%C8!W?WJ`BX%]@(&`BXEW?'IV@(J`@(!Z@(V&@(-]@)&2B(F`
M=(")A8J&>H"$@(*#>7J%AH6*@')]@8./C("`@'N`C(!^A("%CX:`@H"`D8^%
MBX9\A8F`?8!X?HJ#@X-T<GZ`?X:`=X"!?8"!>GR"@X>)?'N`?X:/B8*%@X"+
MBH6$@X*'B8&`@'5^AH"!@WIW?X![?7IX?7V`@7EP<GAX@(9\@("`@X6&@X"#
MB(R&@H-Z?8F)@86&>H"(@X:`?H*!@X*#=W2%@("*@'I]@("`@7J`@X".B8!]
M@'V`DXQ^B'Q]A(*!?'QY@(9Z@(!T?X:!@(:`=("`@(>`@(2!A8N*?(",@(Z5
M@X.$@("(A(")@(".@W^`?7J%D(&#AG>`A8*$@'U]A82`B8!Y@(.$AXJ`@(>!
MAH:`@H&`@H2`=X"`?8J'@'Y_>H"&@(*#?8"%@'I^>GB&B8.(AH"%B8>)AX"%
MBH:(AH!W?X"`BX-[@'IZ@(!\?8%Z?8%W=WI\?H&&>GU\=H"`@(.`@H*)AGZ%
M@("*AXB&@WU^@WR`@'J`@X*`@(!V@("`AH!]?7I_@(.`@(-_A8:"@H"%A(F&
M@(-Y>X1^@8!_?X"&@'U\>("#A8:`?7I]?("#?8"#@(."@("`A8B-B8.(@X.*
MB(.$A("`B("`@'V`AH>%A(!]@H.`A8!\@(!]?'MX>H.#A8F!?8.#@XV)@HJ'
M@(6&@(""?X6)@'^#@'R&@'R$@'Z%@7Q]?GN`BH&%A'E[A82`B8:`B8:"AH&`
MA8F$B(QZ>X-Z?(-[=X"`>8"`=GM[>H2#=WM_<72"=W>$@("%@'R`@("+C(&(
M@W>`B8"`B(!^B(-^@'U_AH:%BH9Y@()Y@(1Z?8.`?X!Z>7]^@XN#?X6`>H.&
M?H"#@(.%@'Q\>X"&@X*&@'J`@GV"@7V"@X!^>WI^@X6(BH.`A82"B8>"A8:&
MB(-]@("#BXV&@()_?X6#@82`@HB#@'YZ?82&AX6!?7Z"@H.&@8*)AX:%@'Z`
MAHF)AH!^?W^`@X"`@X.%AH!]>X"$AX>`?'I\?H"`@8"`AHN'@X*`@HJ/C(:!
M?7V`@(!^?'^"@'U]=G9]@H2!@'EW?7U_?7=Z?'V`@GIT>W^$C(R&@H.!@HF$
MA(:"BXJ!?7M]?HF-B(>`?8"`@8!_>W^#?G]Y<7A]@H:&@WM^@("&@("!@(.%
MA'IZ?WZ(C(:$@'U]@H2`AH"`B(%_?7IZ?H:&AX1]@("`A(.`@HN,B(R`?(""
MB8V,AH"`?H6&@H6#@HB.B8"!@(*)B8>!>G=\?WV#@'J`AX&!@GQZA8:+C(!^
M?7I_@X!Z@(2`B(-Y>7N"B(^,@X!X@(:!@8!_?8B,@(!]>(")CHR%@'N`@(*)
M?7V#@7]]>W-Y@(.+AGUZ=WI]@GUW@'IZ@GUV=7I^A8R&A8!]AH:#@X!]@(N'
M@8%W>8"&C(J$?7Q]?8>#?H*$@8"!>G1Z@(6)@W]X=7V#A(*$@7^(BH2`?WN`
MB(F)A'Q]?W^`@X![A8F$AH!W>8"$B(>`>WEZ@(F#@H6#@(B'@(.#@XN.B8.`
M?H")AHB)@(.*B8.$@'B`AXB,@7QZ>GZ`@WI]@H"#AH!Y?8.%CHJ`@'I]A(2"
M?H!]@(F!@(%^@XN0C(6#?H2&A8>`>WV$@X"#>GJ#AHR*A(!Z@("&@WV`@'^#
M@GIW>WJ`B(-_>G=^@8.!@7U]A(2`?7IW?86&@WUW>'J`B(:`?8"$A(B!>GQ_
MA8F(@7MZ?86)AH2`@H:)C(!\>GJ%AX:#>GEZ@(2#A8"`B(F$@'MX@(F'A8!T
M=GN`AX2`=WV"@X>!>WM_A8J)@'IZ>X"'@H&`@(:,C(%_?8"+DH^)@'V`AH:&
MAGU^AH>&@WMZ@(J,C(1Z?'Z"B(-\>GV"AHF`>7I]A8Z)@WIZ?8.)@X*`?8:+
MB8!]>H"+CXR&>GJ`A8F'@WI^@X6'@'5V>H2)B8-Y>GR"B8-_?("#B(F`=W1T
M@(B)@'AZ>H"(AH-_@(:&AGUU<72`AH-[<G-W@(B#@'N`A(B)@7EU?8:(C(9Z
M>'Z#@X:`?("&BXR!>7I^A8N,@'I\>X"'@7Q\@(*(A'IX=7V(B8)]>7%X@X*`
M?7EZA(J#@'IW@(F,CX9Z=X"$A(F!?X6+CHR'?7^$AY&/@X!_?X"(A'V`@H2)
MAX!Z>X"'C(2"@'J`B(F!?X!^A(F#?7=W?86+BH:`>H"#A8B&@8.)AH6`=WA]
M@(B(@'M]?8")AX"`@H.%AH!X>7J`A8."@'U^A8J`@H*`B(J&@'UY?8B)AX-Z
M=WQ_@(*!?'Z#@H)]=G1X?X"#?79X=GN"@'Q]@H.(C(%]?'V#B(F#@'UZA(-_
M@H"`A8R'@8-]@(N)B89\=WU_?86!>(""@(&`>G5]@(.(@'U]>GZ"@'M^@H&(
MAH!Z=WN"BXN'AX"`B8:&B(2!A8J$@X%[@(:'B8:`?8.`@HN#?X*#A(2#>WI]
M?HB,A8:`?("$A(&&A(:*@X!]=WN%BXJ)AGV`@X2)A(&`@H6%AGUZ>WR$AH&`
M>GI]@H2`A(&"B8:"?7IZ@(J)B8-Z?8&$BHF&AHF)B8F`>7V`A8J&?'=U=GU^
M>GIZ>H"$@'=U='B`A8!Z='-\@("!@'V"B8:"@7I\AHR/BH%\?H.%B8:`A(:%
MB(1]=GJ`B(R'@'QV>H!^?'Q]?8.&@'EW>7^&BH:`?'V#A8.$@("$B8:`?7E[
M@(N-AH!]@("&B(.`@(:$@H!Z<G>$BHR,@7UZ?HB&@X2%A86*@WE]?8"(BX>`
M?G^%B82'A("&C(F`@'UX@(N'AGU[?8"$A8:`@(>#A8%W<GB#A(B$>G=U>X*#
M@("$@X>/@7M^?X*)CX:`@'Z%AX2(A(.(CXF`@'IZA8N&@'QU=WU]@8!T>W]\
M>WUT;GV`@H6!>G9Z>X"#>X"%@8:)@'N`A(61CX:&@X6'AX.`A("%C("`>G1Z
M@(:`@7UT?W]_@'U[>X"`?7UR>H"#B(B$@("#@HF&@H>#B8F#@'V`?8.*@(*`
M?8&`@'U]@("(@X"`='A]@8:"@WZ`@X"(A(.'A8N)AH."AH.)CXB(AH.#A8B#
MAH:%BX:"@GU_@(.!@(!\?8!\?7Q\?X.$@H2`=WZ`@(.&@8"!@("#@8.&@X>'
M@("&@X.)B86$@X*"@7^#@H"%AH""A(!^A8&`AX&"@7UY>'IX@(%Z@'QS>'I\
M@(*!@(1]?8!\@(.`@(&`>H"$?X:#@X>&B8:%@8"&@(6'@("`?GI^@'F`@'^%
M@'Q[>GV`AH!^@WI]@'U_?X*!B(F!A8"`B(>)AX:#@(6`@(%]@(&`@8"`>7Q_
M@(.`?GU]?GZ`?7V`?X.%@(!^@(.&B8B)B8F,B8B&AHB*CXR(A("`@XB(A(.!
M@(!_?WY]@("`?GMZ=WA]@']]?'Y_@(*"@8"%B86*B8.!@X:#B(>#AH:%AH&!
M@H6'AXF`?G]\@(*#@7]]?7U]?H!]@(2`@(!_>GN`?7Y_?8!_?X!]>WV`@X6&
M@7Y^?X"`@H"`?WZ`?GI]?H"#AH"`@(!_@X.!@8!^@8%_@'Y]@(2"@H2`@(*#
M@X.$@H2#?H!^?(.#A(6#@'Z$@("$@8.%AH."@'I_@G^%@'V`?W][@'UZ@X"`
MA'U]?8"`A(:`A8:`AH2"@H.(B(^,A8N#AHR+BHF*AHB*@("`?8*&AH*`?7B`
M@("#?7M^@'Q\?G=Z@X"%AH!_@X.%C(>"B(:%BH:`@(."B(R`@H2`@X>%@X2$
M@H6#>7IX>("$@'Y^=WB`@("`?X"%AX.`?7J`A(6*A'Q]@("!A("`@8.%A(!Z
M>GM]AH%Z>WAX>GU^>GQ]@(%]?'AZ?X2'@X.`?86%B(-^@X.(C(:">GV#A8V*
MA(![@H"`@'Y_?8:%@'UT=WV"BH.`>GA_?8.#?8!^@H!]>G1Z?H6)@86`?HB&
MB8&`@H..C(:#=WR#B(Z,AH"%AX6,@X"$A8N+AGQV?GV(C8!]>WM_A8:`@8"`
MBX:`?7IZ@(R&A8-Z@(6%AH.`@(F,B(:`=WV%B8V,@'V"@(6%@'Z!@X6(@'1W
M>GV&AH![?7J`AH"`@("(BXR`?GQZAXJ(AX!]?H2#@(%Z?H:&A(!Z='J#@(6`
M=7=Y?7IZ>W9]@("$?'IZ@(6(C(.`@X"(AX:$@(B'BXQ^?GM_AXN,@X.`?H6#
M@(!]@("$@'MY<7J`@(2`?'I]@'V`@'R"@H2#?7IZ@(2&BH*!@8*'B(F#@XB&
MBH:`@'U^@XB(A(.`@(2$@H"`@82'@X!^>GZ%AH:&@G^`AH6%A8.%A8B)@X!_
M@X:#AH-_?H"!@H2`@(6$AH:`?7U]@(6'@("`>H"!@(""@("(@X&!>X"%A(2&
M@WV`A(*'A("#A8:)B(&`A(""AX&`@(!]@(-[?8!]@(!Z>7=W>("!?7]Z>'I^
M?GU_>WV#@(*`?8""AH:)B8"#A86'@X"`@H2%B8!]@'V`B(>#?H!]@(-^@'UZ
M?X"`>GEW=X"#@H%^>WV"@H*!?("%A(:#?7J`AH:,B8"`@H*%@X"`@X.)B8!]
M?'R`AX>`?GU]@X2"@7]]@HF$@X!Z@(B)B(>!?(.'A8J#@(6)BHF&@'F"@HF/
M@WQ[?H"#@WR`?X")@WUZ=GB`BH-]?W=]A(*"?WI^B(R'B8!W@(F-C(J`>H.$
MBXF`@(*#B8F!>GV`@(Z)?7IW>G^`=W5V<8"%@'QT<72`BH.!>GB`@(*`>GA_
MB(>(@W=Z@(J2CXF`?8"%C(-^@("#B8B`=WIZA8N$@'EZ?H2!?'YW>XB(@WUT
M<GJ%B8F#>GV`@HB&@'Z(BHF,@'AZ@(:+B8!Z?7V%B8![?8"!BX=\>GA]A8J)
M@'U[@(>!@H-_A8Z/AH!\>(".D)"'@'^%AHB+@8")B8J)@7IZA(:+C(!\?7V!
M@WUW?7R`BX-\>GI[A8N#@(!Z@(:`@']Z@(N,A(:`>HN/CX^)@'V%@X6'?8"%
M@XB&@'=^@("+AGI[>WI_?W=W>G:`A'MY>79Z@X:`@'YZ@H)^@'U\A8F&A(!X
M>H6)B8R$@(*"@H:#?H*#@8.`=W9[?8"(@7U^?7Z`?WU^?X"%AH!]?'A]A(:#
MA8*!A82"@X""AH:&A(!\?8""@X.`>GM]?G]]?7^`@8*`?7Q\?H*&A(*`@("`
M@(&"@XB+BHJ&@X6'BXR.BH:$@8.$@X.$@X6'AH"`@'V"@X.`?7MZ?7Q\@'R`
M@X"`@'U[@(2#AX:`@'U_@(&#@XF&A8J`@(.#AHB.AX2&?H2$?8&`?H&&@WV`
M>G>`@X.#@'U\@'V`@7E_@'J`?7=U?8"`B89]@'I]@H2!@8-^@X9Z@(!Y@(:&
M@X2`>X2#?X-^?H6&@H*`='>`?H6'@'IZ>7V"@'Z$@(")@WV`@8"'C(.`@'F`
MAH.$A("`B8:`@X!X@(6$A8%Z>'QY?7]Z?8.`@H5Z=GZ`@XF)@'Z`?H6)A(:&
MA8N/B8:(A(:0CHJ'@8""B(2#@WZ%AX."@'IX@(B#AH!W>'I_?H!_>X!^@H1Z
M?8""AHJ,@X.&@HF&A(."A8>+AH"$@(",B8B`@7V`AX"!@'V#@(*`?'=WA8:%
MB8!Z>WV"@82`?8!\A8!Y?GV`@8B$?8.`?H6`?W]^@82$>GU\=("$@(!]>GJ`
M@X"">X"&@X2%@'>`AX&&AGEZ?H"$AX&`AH.%C89^@8&`AHR`@(![@(%_@(.!
M@XN!?H)]?(6&@(!]=GV`?7]]>G^#@("%>GF%A82&AH"`AH"(AX"%AH6(C(:`
MB(:%CXR&B8:#B(F`@X:`A8F`?8!]>H6%@(.`>H*`?8!^>H"&@("#>GV%A(:(
MAH"&@X*+AH&(AH*'B8"`A8"#B8&"AH!_A8!]@X!]A8-[?7UW?8!\?X!Z?H)]
M@(.`@(>$@H:`?("`@(.!?8"#>H"#?7Z$@(*&?7I_>GN`?7=]>G9^@'A]@'Z`
MAH"`@WI_B("`AX!^A89_A86`AXF%AX>`@(:`@X:`@(>`?8*`>'Z`?8&`=WU^
M>8"#>GZ#?7Z$@'F`@("&@7V`?W^%B(&$AH"%BH.$A8*%B8:$AX.`B(6#AH.#
MB(N&AH-]@(2#BH:`?X*#@(2`?8"`@X6!@'^`@H6&@("!?H.#@7]^@("%A(""
M?8")AHF&A("`AH"#@'V!@(6#@8!]@X"#B8!]@("`?X!\>H!^A82`@WZ`A(B&
M@(6`?X:!@']^?X"$@("`>H"&@(*`?'F`@'V`>GA]>GV`>W1Y?7>`AGN`@(&!
MA(-_A8.#CH>!@H*`A8R!@H:`@(>%@X.`?86#?8-\>8"`?'V`='>">H"#>GJ`
M@'Z%@W>`@'V%AG^`A8"`B("`AX"%C(:`AH6"CHR`B(-]A(>!@(-Z>HB`@XB`
M?X2&@(>'?86&@(:#?H"&@X.-@'Z&@X6+C(.%A'^#@WV"@'V`A8!\A(!_B(.`
M@H!_@H2`@(!X@(2`A8:`?X6!@8B#@86"@H:#@(2&@(6)@(""@("&@X"%@'V$
M@'V#@'V`@7I[?WEZ?WI]@'U[@'QZ@'IX@(!]@(!Z?']Z@(2`@(6`@(:`@(:#
M@(B&@(6#?H.&@(6&?8"#@("#@'V$@'^%@'V`@'Z"@'I^?G=_@'E]@'Q^A86`
MA(!]A8.!A8!]@()^@X:`@(B#AH>!@8:#@HN#>X*`>X.#?H"!?8"&@(.#?H6*
M@("&@("*AX"%@X"(BXB+AGV%B8&)C("`AH.!AX!\@("`@X!Y?7UZA89Z?(![
M@(F&@(%]?86%@X2`?H6)@X:'@(>-B(6&@("(BH>&@'J`@8.(@WEZ?WV`A'IV
M>GM]@(!X>GEX@H!W>7MZ@(>`?7UZ@(B(A(-]?86&@8.`?("&@X2#>WV%B(F&
M@'R`@8*%@'=Z?X"%@WIZ?G^#B8-^@("`B(1\?7M]A8:`?GUY@(J&@X!Z?H6&
M@X-]>H2%@X:`=WV"A(:&?7V`@(B)@7V`@X6,AGU^?("(AH2`@("%C8:$A8")
MCXV)A(!]B(R)B8!^@H:&AH1\@(>%BH-Z=WJ`AH>`>GQW?86`?'IZ?X6'@'YZ
M>H:&B(>`?H*)AH:&?8"*B8R'@'Z#B(N/@WV"@("%@WEX?WN`A'=V=W=_A8!Y
M?7=U@(!Z?'IX@(F!@(!Y@(:&B8>`?H6$@(:`>H*'A(.$>GJ"@(6&?7N`?7V%
M@7=_@'N%@WUZ?7N`B8"`AGV`B82`@X.`BX^`@H!W@(2$A(1]>H6`@(:`?(*#
M?X"`='M_>H"!?'M_?W^&@7^&@H.+AX""@X"(C8:)AX"%B82$B86$CXF$B8%_
MA8B&B(=]@(%]@()]?H"`@H>`>X!^?X2"@("`>X""?']_?8"%@X"%@(")B(:*
MA("#A8&#AH*%B8.%AH&!AH.$B8.`@H!_@(!^?W][@H%Z?7MW>H"`?8!]>GU]
M@("`@("!?H"!>G^!@(*#@X"`@8"&@8"#?X"#@X!]?WA^@WZ`?WUZ>X*`@8!^
MA(%_@7][?X:%A(F`@(.%AXF&@H.$@HN'@(*`@(6'@'V`?'J`@'Y_>GV"@'I]
M>G2`AH"`@'=X@("#AH"`B(:'C(6`B8R*D(R!@H:$BHR!@H2"B(Z&?X*`@(N)
M@(!\>G^"@("`=X"'@("`>GJ%AH.%@'F`@X6)@WR`B82(B8!]@H.+CXF`@H&"
MBH.`@X"`B(:`>GU[@XJ#@8!Y?8."@H2`>H6&@(!]=WV#@X2!>GM_@8.#@'J`
M@8.'@'=Y>X"(AH!^>GJ`@G^`@'V`A8!\>GA]@X."@'IW>X"`@H!]@(:)AH-^
M?("%B(J!?7V`A(:&@H*%AHR(@7U\@(6)AG][=GA^?GUZ>'N`@H!]=W5]@X."
M@'IX?H"`@8"`A(F+C(.`@XF)D8V&@X.&AXF&@X6$B8R$@'Q[?XB*AH*`>H"!
M@(!]?("$@("`>'J#AH:&A'^`A8.'AH"%AX>'AH!]@8"%BH-_@(*!@X:`@(.#
MAH2`>GEW?8>#@(%]?(""@8"#@(6)@X.`>X"$A(*%@'J`@'Z`?8"!A8:"@WU]
M@'V"@'U]?G]Z?7IW?H"`@X!_>GQ]@(:`@(%]@(!_@("!@(>&@X2`@H6&AH6%
M@X*%@(.`@(*$A82#@7V`?WZ"@']_@'U\>WE]@("`@'Y\>GU]@("`@H&`@X!_
M@(&"A8B$@X."A8:&A8F(AXR(A8:#@HB+AH2%@("#@("#@("&@X"#@'V%B8.%
MA'Y_@X"`A("`B(:$B(!]@X:#BXF`@H.`@(9]?H6`@X:`>H!]?8B&?X.!?X6&
M?8"!?("+@("!>GV(AH.)AGZ'AH"%@WJ`B8.!@W=W@'V`B(![@(!Z@X!V@(!\
M@(!W=GIW?81\>H!Z?H.`>GY]>HB)@82`=X"#@X6(@("&@(*&@("(BX:)@WJ`
M@("%A(!\?GV`@WU[@'^`B(-]?WUZ@(-]?WY^@(-]>GUZ@(B(A(%^>X"%AHB%
M@8&"A(.$@("(B(>)@X"`@X.%AX"`@X*#@'U[@("#B8-_@'^`AXF&@X>%AHF"
M@']^A8F'@X!]?8.&A86#@8&$A(!_>GV`@(*`>GI]?H""@X""A86&@X""@X6)
MB(&`@(""AX:#@X.&AH."@("`A8>#@X!]?7U^?7U]?8!]?7IW>GZ!@(&`>GU\
M>X!]?W]^@'U_>GV"@(.&A8."@X*%@W^#@("&@7]]@'^`B(6#@X""@("`@(&`
M@X-]@'Q[@(*#@(*!@(!_@(!]@(*`@(!]>7V`?8"`@("`@H&`@(*%@X>'@8"`
M@(""AH.#@X*#@("`@X2&B(.!@8"`A8:!@H.#AH:#@X.&AHN*AX>#@X6&@X2%
M@X2&@8*`?8"#A(.#@'J!@'Z$@'V`@("`@'AZ@H"%A("`@8.%BX:`B(B'C8F"
M@("`A8J&A8-\@(:!@H6#@(:#?8!Z=WU^?GQY<W1]>H"!>GR`@X.$@'E]@(.(
M@8"`?8"%AH!_@X&(C(.`?'V!AH>!@'IX@'^`?GI\@(6$@H!Y?H2%BH-^?8"`
M@X:`?("!A8F#?7Q^@HF'@8!]>H"$@'QZ>H"&@WY]=GJ%A8:&@'N`A(""@7N`
MB(>)AGU[@(6+D(:!A8.%C(F!@(6%BHR`@(!\A8R&@H.`?HN)@(.`@(:*AX!_
M=GN&@(.#>'J`@W^`@'J`AH6'@'=X?H"#BH!Z@7V`B8:`@(:%CHV`@H"`B8R%
M@8:`?HN#?8!^@(:)@(!Z<WV#?8!]='1]?'=^>'2`@H*%@'I]@H.)B7Q^@7^`
MA8!Y?X""B89]@'U[A8B`@(!Z?8%\>7MY?8.`?GYZ>H"'A8>#?8*&@X6&@("&
MAH6)@'V`@(*&AH"`@W^`@GU\?7V`@X!W>G9V?X"`?WU\?H!_@(*`A8B&A86!
M@(:)AXF&A8F)B8F(A(:)B(N)@7^`@8"#@X&`@("#@("!@H*&AX"`@'U_@H.!
M@("`@("`@H"!AH:&AX:`@(*!@8."@H"`@(&`@(:#A8N)@X2%@(*&A86#@("`
M?X"!?GZ%@8"$@WU^@("!@X"`?7E]?7E\?WV`A8!Z?GY_@X.$A(!]@(%]@(%[
M@(.`@(*`>GZ`@X:!@(%]?("`>WZ`?8"#@'M\?H&&AXB'@8"&A82)AH.%AX.`
M@'Z`@X.%@WU^@H&!@WQW?7]_@'UV<7)W@(!\?7QZ?8."@(.#A8N*AH&`@XF,
MC(N&@(:)B8J)AH6)C(F&@("`@(6&@'Q]@7^`@'Q\@(2'AH%\>GN`BH:#@'Y]
M@(:#@8."B(F)AH"`@8:)A86`>X""A(!_?8"%AH:"?'Q]@H6'@WU^@("!?G]_
M@(:&B8!]?H"%B8F&@(!_@()_?7I\@8&`>WIY>H.%A8!\?8""@X!]=W^!@()]
M=W9[@(6)@("`?H.#@'^`@8"(A'I[>GV%B8:%@X""B(.%@W^%B(F#@'QX@(*%
MA8![?H"!````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+P``````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<V-P`P,C$R,S(`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]I;7`O=&AE;65S+V=R87!H:6-S+VUI;64O8FEN87)Y+G!N9P``````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-34S`#$P-#$W,S8R-S8W`#`R,S(R-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,```!@4$Q410```#`P,$)"0EA8
M6&YN;G!P<+R><[RB>XR)AIF9F;VHA[RME+ZVK[RWL<"OD<*SFL.ZI\;!MN7,
MI^G5N,[.SM[>WNW=Q^[@R>CBV?'GUNKJZO3MXO?RZ_W]_0```````'\NN@\`
M```?=%).4________________________________________P#-&780````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```'E)1$%4*%--RN$6
M@B`,AF&-;Z:8)XT,B:W[O\QFIP'OX<=XMNZC.4OG[@?[V>(F5T"T-T2E`.E[
MRM0;$$1&PJ6`*,B^C,T%A/FXU0N-<YH;8.9T-$"ZIUB!F!+AY0T8F5)$J)"A
M?^!JD%.,(83'\(=M6]?[[/U@T->^=8H2J96!G?$`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE
M<R]G<F%P:&EC<R]M:6UE+VAT;6PN<&YG````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C(T-P`Q,#0Q-S,V,C<V-P`P,C(W,#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``
M@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4```#____J
MZNLS3VTU46](87Q6;89T@I%ZAY6*E)^XP,G`Q\\Q3FPU46X[5G(^6'-"77A#
M77A$77='7WA0:(!7;H9>=(MD>8^=JK>/F*&ZPLJ]Q<W*T-;0U=I\B).,EI_&
MS=/8W-_>X>/L[>U+2TG^_O[]_?W[^_OQ\?'N[N[M[>WL[.SKZ^OJZNKHZ.CF
MYN;EY>7DY.3CX^/@X.#%Q<7$Q,3#P\/"PL+!P<'`P,"_O[^^OKZ]O;V\O+R[
MN[NXN+BVMK:UM;6TM+2SL[.RLK*QL;&HJ*B@H*",C(R*BHJ%A85V=G9L;&Q=
M75U45%134U-`0$`G)R<F)B8='1T7%Q<6%A;___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!),<WO
M````5W123E/_________________________________________________
M____________________________________________________________
M_____P"^8S7C````"7!(67,```L2```+$@'2W7[\````KDE$050HST70U1:"
M0!2%X5EVC-W8+1:(K0-*V(B*ROL_B@C'Y7_YW>V-#`/],KXA`S6M6N,%^D$G
MF'*YL[/V'@%48E2]Z"E=KG=D0\:?"^-"\MQX`^`:SN,JIND)0+KLBX>P=].;
MVM"BH@$';=:?`73+"6=D*XJ#!4!_""T!Q)>D'35)EU<`#T91%95AGFL`65=N
MI]M.WQ$`AF79T8CC.,&&.2&$YP6S@P7_^=8!'PK-+=,D-RAA`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V=R87!H:6-S+VUI;64O96YC<GEP
M=&EO;BYP;F<``````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S`V`#$P-#$W,S8R-S8W
M`#`R-#$R-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```$.4$Q4
M10````0#`@4$`P@("`D)"0L+!Q,1#AH3"Q86%AP<'"`='!X>'B\I(2LK*RTM
M+2XN+C@X.$U-38%:*W)R<JIO*Z1Q-GIZ>JQQ+JUS,J!W1*-[2X2$A*1^3JB!
M3+1^/J>"4J>"4[B`/JJ$5:N'6*R'6+J$0JN(6+J&1[R'1KR(2;J)2Z^-7JV-
M9+R*3+"-7[V,3J61=KZ-4)N7E,:67<>;9*BCGLJ?:*JJJLND<<ZD<,VF;LVF
M=M"F=,RG>]"H=,^K?+&QL<^L>\VL@\ZM@]2L>=6N?M*RB=6RA-BUC+R\O+Z^
MOM:ZE,#`P,'`P,+"PMJ^FN#"GN'"G.#$H-_$H^'$H.+%H>/&HM+2TMO;VP``
M`'M`2!X````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``
M"Q,!`)J<&`````=T24U%!]0,%!(L!'X.`?D```",=$58=$-O;6UE;G0`365N
M=2US:7IE9"!I8V]N"CT]/3T]/3T]/3T*"BAC*2`R,#`S($IA:W5B("=J:6UM
M86,G(%-T96EN97(L(`IH='1P.B\O:FEM;6%C+FUU<VEC:&%L;"YC>@H*8W)E
M871E9"!W:71H('1H92!'24U0+`IH='1P.B\O=W=W+F=I;7`N;W)G9XK'1P``
M`)E)1$%4>-IC8,`.(H$`B<LM%AX1X2G,#!>0]A+@Y!1TD(;Q^?Q80!2_.4P7
MKP^8Q>$+$V`SXF)E9&3B,66'VF`0%!SL[^_O;2T$41(9ZF&F(B^O(*4I#A4(
M<]5SM[=WM-`0@0J$V)@HR<C(2*K"5`1:ZK@Y.3G;*DI`!0)<K+25E=5D->2@
M`G;&AH9:6OJZZJ*1")]!`#9_`P``XAT7BJ?_70````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V=R87!H:6-S+VUI;64O
M;6%I;"YP;F<`````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C8R`#$P-#$W
M,S8R-S8W`#`R,C8V,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,`
M```$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```
MZF```#J8```7;Y)?Q48```,`4$Q419.3CTM+2?O[^*6EH_?W]?KZ^<#`OXV,
MAKR[M_GX]+:TKMS:U-O9T]K8TI&0C?OZ]_KY]NGGXN+?V)"-A]W:U-K7T?GW
M\_CV\O?U\?+P[).2D-W9TMW:U>GFX>/?V8V+B/KX]??U\NOIYO?U\^_MZY>4
MDK*QL:&@H/____[^_OW]_?O[^_KZ^O'Q\>WM[>OKZ^KJZNCHZ.;FYN7EY>3D
MY./CX^+BXN#@X,_/S\K*RL3$Q,/#P\'!P;Z^OKV]O;R\O+N[NZVMK:BHJ*.C
MHZ"@H)^?GYZ>GIV=G9R<G)N;FYJ:FH6%A79V=FMK:UU=74!`0!X>'A86%@$!
M`0```/___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````+BU<1@```!5=%).4___________
M____________________________________________________________
M_________________________________________P"PH0?/````"7!(67,`
M``L3```+$P$`FIP8````NTE$050H4T7.UT+",!A`X1IF;64OV2,"+5:!IK*7
M+;0BHB1Y_V?A#U(XE]_5D3B[Q/TDIFF:/IK?!,"V[5GOTQ<`PS`VA^,OH_0*
MCK/]^'XX,=P4`O#V#O7'#.,(%:#O7-?UO"D`?J0"!B)S(0#_4`#O:V\2LA00
M"PH8$F)9UAJ@&,H`3):K->3\13NO+8#K.F,!E,X]EP`XI]VXA!"2Y5K2AQ=4
M2.3KC4HM]0_M)U55LXI2KH8OP.D]?@;N7CM)%@I+1`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM
M<"]T:&5M97,O9W)A<&AI8W,O;6EM92]C;VUP<F5S<V5D+G!N9P``````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$V-#``,3`T,3<S-C(W-C<`,#(T,3`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```BM03%1%!0!&!@$`"`````(.``4`
M"@````0'"P````0+``0,#0````<`"P(``003```S``<.$0$```4;``D'%0``
M``D,%``(``H,``4I&0````<?"P`G``<C&P````@?``X```@C'0``$@`>``T,
M``@I#0H``!`$``HF``@R``@S)`````PB``PK$0P```XF"@P9*P```!`K``\R
M`!$N`!,E&@X``!8F`!)`#!(@`!<F`!X4`"83#2`>/1H``#0]6A0,:Q,`%#M"
MBA8`'4<QIQX`+$M@'U57@"\<OQ0#G"@`+4YO'E9OAS8`+E)@H24==CHO%6!S
M5TD^>4`5J2P`QQL1H3,`1%);TQH(K2T@I#,C3U9@S2T)1V2,RS@NMT8D1F^%
MD%@WLTTV0W:17&YX6'^>:7Z/;8.8J7TT4Y2JOX4B<I.RB:6[<:W2BJ^W?K#3
MB++(D[C3T*]H]*1=J+VX\:\_D\C"LK/LX;=EB\SL_Z6$^K9'_[@SM[[;_[-2
MM,/*YKYF_;I%W,!_ZK]C]L!"M,'V_[Q%J-')_[U(H=+A_\%%DMW@_[.>_\1%
M_\8[_\%J_KJ5_\9;^\M/[,F/[<]O_\*'],69_]%2_[ZY^\UU_\"Q]-!Z_]!C
M],Z-_]!V[M*@[MJ$_]#*_]+&_]?(_]RP_^.:S.[M_^&S_^#!]NBW_^#1_^/#
M_^#:W.[__^7B_^G0__&]_^_,X/GV_^[D\_3F__':__G/[OW_\O_Z]/__``0`
M\4-%D@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+
M$P$`FIP8````!W1)344'U`P4$R$0T+C!_@```.Y)1$%4>-IC8`"#'2QL',SF
M>F!V@IL?`U-D:G)N=GFZ+9`?5=$UPTY?@IU75MO(O].*@2',/2;<,=8CQ#X^
M8+M8JQP#0_#\:0M63NZMF5.HL,FZB(6!P7?5FA5;%E=VMS6J;..O965@B%BX
M<?/R>1-ZFB9Q;Y"L%F5@<%ZV=OW$NHZJ^C*=K7REB@P,08OZILR>WC)U5AKC
M:K-F*08&[W5+YS;,["_.*&!98M$NPL`0J"G,92*@8"/#HZKD6N($<3@#9VA2
M2E9^7HXE`PQ(&ZIKJ"L;,Z``M4QDGI"#:9R\IW@T7,!'R\L@4==%D`$`?K9"
MS!JR]?<`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]T:&5M97,O9W)A<&AI8W,O;6EM92]T97AT+G!N9P``````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`S,34`,3`T,3<S-C(W-C<`,#(R-S(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`0#````[=WB4@````]03%1%````A(2$QL;&
M____````+&6H!@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,`
M``L3```+$P$`FIP8````!W1)344'U`P4$R`P\LW0=P```#=)1$%4>-IC8&!P
M``$&!@860R`P`3*$G4$`*"1L#`1&*`P3%Q-G=!$7,D1@#"$E$``R6%Q`@`$`
M^5P5:MR2Z^$`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE
M;65S+V=R87!H:6-S+VUI;64O:6UA9V4N<&YG````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-#$W`#$P-#$W,S8R-S8W`#`R,S`R,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`$`P```.W=XE(````>4$Q410```(0``/\```"$`(2$`(2$A`#_
M`,;&QO___P````1Y>K@````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP
M2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!,A";33:3X```!J241!5'C:
M8P@%`08@B.CHZ&@/@#%:&13!C,Z9DX",EI(2SW8E`8:(]IDS/9L4@6I:IJ5Y
M`@6`(M/27"=.`(E,+@^?#F*TSS">V0X6F='A"6:TN[M#&)TS9T*D.D!V`!GA
MY2``9,P$@PD,`$Z9,D/(G+DB`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F%P:&EC
M<R]M:6UE+VET:7`N<&YG````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4U
M,P`Q,#0Q-S,V,C<V-P`P,C(W,#4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3````=5!,5$4````6%A8K*RLO+R]#0T-555630CBG13YH:&C434%U
M=75_?7B`?WF"@7R%A'^*BHJ2D(J=FY6@GIBCH)JEI)VGIZ?GGCRLJ:.NK:6T
ML:NVMK;`P,#*RLK/S\_5U=78U<W>V]7@W]?BX=OEX]_FY>#___\````6>C>=
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":
MG!@````'=$E-10?4#!03(#ME'PG_````;TE$051XVF-@H`900P8@`491?BX.
M5E86%A9F)K"`FJJJC*JJM*JJE*H\1$!6@EM"@D\"2`I`52@*J2B+R,L+RDM`
M!.0D>24E.=G9V25A*I0$%>39Q<384%2PL[&QP53(2_)(2/`"#1475L/J,$(`
M`#(K#5CA?)=3`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O9W)A<&AI8W,O8V]M<&]S92YP
M;F<`````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R,#``,3`T,3<S-C(W
M-C<`,#(R-#0U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G
M04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```
M.I@``!=ODE_%1@```P!03%1%2TM)_.D[^^<[_.L]^=\Y]M(V95DP9ET^3T$5
M;%\T7$\K850N\K9-[[1-][5$][5%]+)$UZYT_O[^_?W]^_O[\?'Q\/#P[^_O
M[N[N[>WM[.SLZ^OKZNKJZ>GIZ.CHY^?GYN;FY>7EY.3DX^/CXN+BX.#@S,S,
MRLK*R<G)Q,3$P\/#PL+"P<'!P,#`O[^_OKZ^O;V]O+R\N[N[K:VMJ*BHH*"@
MA86%=G9V75U=0$!`````____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_&+%^````#QT4DY3________________
M____________________________________________________________
M__\`NXCKIP````EP2%ES```+$P``"Q,!`)J<&````*))1$%4*,]%T-<2@C`4
M15'LO2*"U`!*$4O`?O+__V6\!MV3E[LFR4RB"8$Z\4D36%+Z[H`:#&J_NJ*&
M)$D,X_)XON2QWX[U]JZA.09!*C/3#*WIB,`T34N&QFQ`1W0KR^1">]X#7:IO
M;-MVT)D,H<#)\]S'HHNC`M?U//2!X*3`+U@!,!:>%00!DU,815R!'.04QW'U
MA8)S7I:5[$;P?SY]P!N0LBH-\)*C)`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H
M96UE<R]G<F%P:&EC<R]E;7!T>5]T<F%S:"YP;F<`````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,30R-@`Q,#0Q-S,V,C<V-P`P,C,S-3``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3```!I%!,5$4````"`@(&!@8.#@X0$!`8&!@<
M'!P?'QLG)R$G)R4H*"0J*B,J*B8K*R0K*RLL+"4L+"PT-#`V-2XV-C`Y.#8\
M/#,^/CY"03I"0D)#0SU(1SU(1T!+241*2DI,2T%-34!244934D944T==7%-=
M75U>7E5A86%D8EMH9V)K:V1M;6UN;FYP;V9O;V]Q<&=S<65Q<7%Z>6=^?G5^
M?GE3G5-4G52%@W&'A7*&AH:*B'6*B76+B79=IEV+BW^-C8"/CH&.CH:0D)!N
MJVZ2DI)OK&^3DY-SLG-XM7B@GHB?G9&@H)6CH8JAH9*DHHNEHXREI)F*MXJ*
MN(J-NHVMK:.LK*ROKZ^SLIBYMZ*WMJZ;R)NYMZZZN;.\O+S!OZ7"P*6_O[_!
MP<&RS++$Q,3'QKK&QL:ZT[K)R<G/S\_3T;S1T<O5TK['X,?7U]?8V-'<VL39
MV=+:VM/>WM[BX,OBX,_DX<C4Y]3EXM+HY-/IY<_EY>7FYN;GY^?JZ=KQ[=+P
M[=CL[.SN[>3M[>WR\>3R\>GT\>GT]/3Y]>WX]^SX]^[[^.G___\```#1;T-G
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":
MG!@````'=$E-10?4#!03&06J^IGN````ZTE$051XVF-@``)F"5DQ@6X&&.CN
M-JMK;DA6[(8*L<3%&DIS"IE[>/N!1?@R\HK#U45$N[LMPWQ!BKK+6YIJRK*Z
MNQ*ZK96ZN[H9NJUJ.]LZVJ.ZNYP9NZM`*A3T/4LJBC*5NV.T&\&&L`O*:.AH
M2K'5I^N&@@6XO>2%>;BZ"[L*"]/``KS^$7H^<EI=0%#M"A+A#\ZWC69-RW:/
M[*I.@0@4V!NKE-ID=]D$55H`17B-<NVZD]RRN[K<G2H=@0(<D@ZJW3D@([I:
M3>)E@7J8F,2[Z]V[NK*[4@,##,#^8^H.J7=Q<3)-#'16`P#.>TB0&<39.@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+W1H96UE<R]G<F%P:&EC<R]M86EL7V1E;&5T960N<&YG````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,30V-@`Q,#0Q-S,V,C<V-P`P,C,T,C4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3```!@%!,5$4````("`@0$`@0$!`8
M&!`8&!@A(1@A(2$I*2$I*2DQ,2DY.2DQ,3$Y.3$Y.3E"0C%"0CE*2CE"0D)*
M0D)*2D)*2DI24D):4DI:6E)C8U)C8UIK8UIK:UIK8V-K:V-S:V-S<V-[<V-[
M>V-[>VM[>W-[>WL`_P"$A'.,C'.,C'N,C(24E(2<G(2<G(R<G)2EG(REI8RE
MI92EI9RMK92MK9RUM9R]M9REK:6MK:6UM:V]M:6UM;6]QKW&O:7&QJ7&QJW&
MQKW6UKW&QL;6UL[>WL;>WL[>WM;>WM[GY\[OY\[GY];OY];O[][W[];W[][O
M[^?W]^?W]^__]^______________________________________________
M____________________________________________________________
M____________________________________________________________
M______________^%HO<^````@'123E/_____________________________
M____________________________________________________________
M____________________________________________________________
M____________________`#@%2V<````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````PTE$0508TSW/_0^!8!`'\$OH*2*D%T)D(^\AP^:EH840
M_Y!_73U/N=MNWWU^N-O!-RJJ7"VP@&,T`7K/]^LH`1"@][M.A>%ZT]D,(F"=
ML[>M\;PZLNU0PKZ_`__F[!>[PZJ-H?_XA!7XE[$J1_"5](EW]4ZF7A<07IK)
MBXU64Y-Y.IW!@"PQCUB*2A6X+('Y1K?THI;3>(;`VC5/ICPL&1)*8.`N%4O\
M0S>!^`HC#)00AJ*"LLES@FD(&L?&SV&B`$C\`53`.ZYX:)DM`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:6UP+W1H96UE<R]G<F%P:&EC<R]A9&1R97-S8F]O:U]B<F]W<V4N
M<&YG```````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0W-@`Q,#0Q-S,V,C<V-P`P,C0V-S8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0"`,````H+0]3````5%!,5$4````5$Q,Q
M,3&8+!-*2DI*2TN$7U=I:FK?0AYU=75^?GZ/CX^>GIZMI::MK:VNKJZ_O[_3
MT]/EY>7GY^?HZ.CIZ>GL[.SU]?7V]O;X^/C___\```"MO!<?`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?4#`@2*`0`K2S:````8TE$051XVFV/60Z`(`P%<=\%W'7N?T\C!2.)\]?)
M>TVKU`]XWOG<'4LP'+/#$.4QL]08A0Y#53TANF`H0BD5$K\UGZQ#,XCI+T'3
M.,$JLVW];6S2L#F41)<$H<@\-?%SG_\^W/XA#2SJ^QT4`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T
M:&5M97,O9W)A<&AI8W,O<W!A8V5R7W)E9"YP;F<`````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`R,#``,3`T,3<S-C(W-C<`,#(S,3`U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````!`````0@&````'Q7$B0````=T24U%!]0*$`@0+L?5]8$````&8DM'
M1`#_`/\`_Z"]IY,````)<$A9<P``"Q,```L3`0":G!@````-241!5!C38_C/
MP/`?``4``?_%G<_"`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V=R87!H
M:6-S+V9I;'1E<G,N<&YG````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,S(U`#$P-#$W,S8R-S8W`#`R,C0U-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`$
M`P```.W=XE(````/4$Q410````"$A,;&QO___P```$^D_)D````!=%).4P!`
MYMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%
M!]0,"!(A-VZ_]H4````_241!5'C:8V#`#5A<P,"!@47(V$A)4="!@<%164E)
M400D)V2D!!(`"D$$@$)*B@X0C<XJ#&@,1Q%TAHL+5CL!;FD'HW@R1D<`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F%P:&EC<R]M86EL7V1R
M869T+G!N9P``````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<Q-@`Q,#0Q-S,V
M,C<V-P`P,C,Q,30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
MJU!,5$4%`!8!`0$O+R^%&2(U26.;/S9W;6"A9EQ]>WB!@'RA@QF2AW>J?VV2
MCXN5DXZ6E)&'EK7G=UJCFH:LI(^NJZ:PK:?;KSFULJRGMLR\MJ:JO=[_J7W>
MP5K!O[ZUP=24U__NS%K-R\K4U-'ZUG7,W?CAW]KBW]G\Y)+EX][<Z/KJZ./U
M\_#V]/'V]?'W]?+W]O+W]O3__[CY^/;[^OK[^_K[^_O\_/S___\````/WYY0
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":
MG!@````'=$E-10?4#`@2)#,4I<;9````G$E$051XVE7.V1:"(!2%84C*M-%&
ML[G(,JUT4^+[/UD0REK]=_M;Y^(00EO41E3T5-JV6F@Y_*`$!![=NP&,!(1`
MYF6W&C!X`T\/:0/YTF,V!?D,8%+ENC+1,$?ZTM!>!RY7<+S$<:Q@N@_ZC@+R
M^XC)27$>.WS'B(GYQ>90)8D%LSF/V/]NP%]=];V"T$!/+BK.=U$4UM#Q*_OI
M%R?Z%Q:H%Y:2`````$E%3D2N0F""````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]T:&5M97,O9W)A<&AI8W,O<VAA<F5D+G!N9P``````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-#4`,3`T,3<S-C(W-C<`,#(R,C4W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```#!03%1%``````"$
M,3'.2G_.G)P`JJJJSIR<SLYC_\Z<[];&[^_O__^<]_?W___.___W````.=-'
MR`````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`
MFIP8````!W1)344'U`P4$Q@<UXH`;P```&Y)1$%4>-IC8(`#%A>7#V"&S]W=
M_F"!\O+R$A<7!P:6NR!PNYZ!Y?9N(-@!971W0QD[@"(AMT$"0!%&06F@`%"$
MV5@T-#2T`\R8ES4SHIZ!24ELYM3X__^!:N339LY,^\_`___#MS0@#0+\0`D&
M``T0-=$,&OM^`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M=&AE;65S+V=R87!H:6-S+VUA:6Q?9FQA9V=E9"YP;F<`````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-C8V`#$P-#$W,S8R-S8W`#`R,S0Q,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```"Q4$Q410``!0,#`PT-#1(+##,H*CDO
M,TLR.4<V.E(_0TY!1%L_15Y!1UM%2F!$3&1%36M,5'!168)*66]67(A07W-?
M9(]797MH;95=:YIC<8!Q=7]T=:!I=Y=N>)QS?*=]B+*1:*B1EZJ6F[>6GZF=
MH-&<J;^PD]"CKLJIL<RNM="MMLZOML^RN=&TN]*ZP=^_Q]_`R-[&S.3$R^;/
MU.32UN37VNC7W.K9WNK;W^S<W^_CY@````MI_@P````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$@``"Q(!TMU^_`````=T24U%!]0,"!(C
M'AX[#&L```!^241!5'C:8V"``"L&9&!E9<6"+&*EKR#&QHX0L=(T,Y3AY^*P
M@@E9J1M8ZLD*<`MQ0H2LE,2E=4R-5&1X^7A8@2)6JE:"HA+:QA9JBE*2(B`E
M5O)6@L+B&EKF0+L@IH!$!.5TF9"L!8F8,#*@BBBCN!4HPLS`@";"0(8(1```
M,&@1,DLBL,``````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F%P
M:&EC<R]N97=M86EL+G!N9P``````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3$S-P`Q,#0Q-S,V,C<V-P`P,C(T-#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3```!"%!,5$4````_,BU`-2U(.3$$;@4;92-71#L%?04:?!L<
MAQQH6%0E@R4BAR$O?3<S?S,KC"HX@S@YB3A!A4`RD3)#AD-'@E`#M@(\CSM.
MA%I(D$<.Q`T,R@R1=V@ET"5KH6I/MD^HC6VHD'D]TCVKE()"V$*VFGNUGI*\
MHXFZIIARU7"%R(6[JZ9\U7R/T8[.MY>;TIN@TJ#+O*;2O)N#[H./YH_0Q<.B
MXZ+>R*37R;?BS:6A\*'?T+3HV+CDV,;EW-77[-?.\\[WY+OKY.#KY=S/]L_.
M^<[UZ-7XZ<C8^]C>^=[A]^'T[N/=_MWF^.;_\<W^\]?]]>;P_/#U^?7S^_/P
M_O#]^?/^_OX\+R=]CJ,G`````7123E,`0.;89@````%B2T=$`(@%'4@````)
M<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#`@2)0G+LBXJ````T$E$051X
MVFV,6UN"0!"&US1-K-34RHXB$JMH):5D+1B@K(HN6SGV__^)0S=YX??,Q;SO
M'`C9G]K1\<DNG]VWW\\S_WS7>7V>7U\=_H&"J:^'3Y/F2S'IB>+[[L7J>_SU
MLZPP>Y0BB@-PV5ML-K-620@;!34EE+N?T]M<S/4&BJC_$,AJ(7\:6ZJ1G``,
M3"I!AH9J,);&#8`/2@>6>C/RN(?"AS<S"JEF.YHE6)8H+J.1E+$(0Z[;B>A3
MB8P5"ZX_HJ`!YSCE^,!C.HKT3@ZROUL()R5B:A>PR0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE
M<R]G<F%P:&EC<R]F971C:&UA:6PN<&YG````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C$T,0`Q,#0Q-S,V,C<V-P`P,C(W-#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``
M@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$54@51]JGV"
MK(*CPZ.AP:&GQ:>5HI7U]?7S\_/R\O+Q\?'EY>7CX^/@X.#>WM[<W-S;V]O8
MV-C6UM;5U=74U-33T]/&QL:XN+BVMK:UM;6RLK*PL+"OKZ^MK:VLK*RKJZNJ
MJJI_?W][>WMY>7ET='1N;FYH:&AG9V=E965:6EI965E65E9*2DI$1$0@("``
M``#___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!+AKQL
M````,7123E/_________________________________________________
M______________\`'YI.(0````EP2%ES```+$P``"Q,!`)J<&````(Y)1$%4
M*,]=S]D2@C`,!=#4A52-6E#$E>*.=0G__W5J&Y#Q/G7.-!M4W["/?T(`I0!:
MP`'X!WW5`?DB)=UV";\^#7L@;:'B$R)&S!'BDSW@=4A(FN)[)D`7/1I0XI)-
M#51J,H[2!B9[A^X<+[8"XR.1,Z9<UG"@=#HS\^RQ"G`KK+5%GN_68:R<RLUB
M?WD#@/,C(ZO]U:(`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V=R87!H:6-S+V%D9')E<W-B;V]K
M7V%D9"YP;F<``````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3(R`#$P-#$W,S8R-S8W
M`#`R-#$Q-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````#`````P(`P```&&KK-4```!@4$Q4
M10```!LE*B(J+#0D)#$S-#XV-#@^0#]*3#9.5$]13V).3$=A:EU?7$UF;V9L
M:%9VA')V=%^`C'I]?&>(EH:&A)Z>G**BG**JJ*ZNK+:VM,JNK,[.S-;6U.;F
MY._N[!(6'$&OK-$````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$P``"Q,!`)J<&`````=T24U%!]0,%!,9%,!*N1P```!K241!5'C:18W;
M$L(P"$2W;2S2)$V)IC<U_?^_-."#YX$Y.\L`T'!]U[A@Q(>()#(?U24&]=D*
MZ8_<@C>_Y]4!I)H2%5TC*WPH#`S3R'/T;E]:,9RUODM>-J?';KR]/O4(OY=@
M"L_,^-/I^`*U5@6#8IZ"T@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+W1H96UE<R]G<F%P:&EC<R]A='1A8VAM96YT+G!N9P``````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#8S,P`Q,#0Q-S,V,C<V-P`P,C,Q-#``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3````AU!,5$4````\8FU=?H]<
M@8]E@I=BA95DA)5DA95JB)QOC:!UD*5UDJ5ZEJM\F:N"G;"#GK&&H;.'HK2*
MH[>+I+B*I;>-I;J/J+N/J;N1J+R1J;V7K,"6K<"7K<";L,.=M,6ENLO%T]S&
MU-W(U=W(U=[)UM[*UM[+U]_,U]_,V-_-V-_-V.#.V>````#:\>T>`````712
M3E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?4#`@2)`7;'U-`````C4E$051XVF6/YP[",!"#PRQ0RBJ4/4(S2O.]
M__,1I"2MQ/VP9.M\9POQ/YO!6@RW'4?K]HHK$W\#^H*\IP4\V()F'`3%#UV%
MBHH<"5%BGS3!13W!9-@*6<8S9VR&*W#[H+@<XUTW5%3,##WE17N(STU._9GC
MEBF?.OJ`)[/H&LC5[F$;^IV4-?1;>XOG7\&9$:]BILC?`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M
M97,O9W)A<&AI8W,O;6%I;%]A;G-W97)E9"YP;F<`````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`U-C4`,3`T,3<S-C(W-C<`,#(S-C(V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```'503%1%`````0$!"0D)&!@8`"5*`"A0`"Q9
M`#-F+R\O?7MX@8!\DH^+E9..EI21KJNFL*VGM;*LP;^^S<O*S,S,U-31X=_:
MXM_9Y>/>ZNCC[^_O]?/P]O3Q]O7Q]_7R]_;R]_;T^?CV^_KZ^_OZ^_O[_/S\
M____````01-0T@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,`
M``L3```+$P$`FIP8````!W1)344'U`P($B0HGL`/-0```'E)1$%4>-J-SML6
M@B`0A6'H1-)!3:-&*S>*O/\C)D.RN.R_FV_-Q1;BC^11IOAN7:H.(MUY@@,L
M7L4S`BX6UJ+7_>,'.(W`6Z-;8:BT7PLP7`$_QQA*=!\_JR5J`MSNQA@&8A"\
M*/N(+4!*'7(@HOTNAX;;)O";N.,+HR@0`<:!M!T`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+V=R87!H:6-S
M+VUA:6Q?9F]R=V%R9&5D+G!N9P``````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3`U
M`#$P-#$W,S8R-S8W`#`R,S<V,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I
M``!U,```ZF```#J8```7;Y)?Q48```,`4$Q418A_H\K&UL7!TO____7U]?/S
M\_+R\O'Q\>7EY>/CX^#@X-[>WMS<W-O;V]C8V-;6UM75U=/3T[BXN+"PL*RL
MK*NKJZJJJG]_?WM[>WEY>71T=&YN;FAH:&=G9V5E95I:6EE965965D1$1"`@
M(````/___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````*_@+GT````F=%).4___
M______________________________________________\`IWJ!O`````EP
M2%ES```+$P``"Q,!`)J<&````'U)1$%4*%-MS^L.PB`,AF$FX/Q4=E"99U>U
MWO\M2DF9R>+[KT_2!LQGEOD#_.92!KZXTHLSN'L-!X_FN5/`S:^6:*G=%\##
M(Q#Z"39'<G1M\E6!]1F@D$:K<$*_[0);NZA88!QBC,.!TYQ$'J95)B6@99"5
M"9A-/OI+_S+K"V?!&VQAF=*<`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]T:&5M97,O9W)A<&AI8W,O97AP86YD+G!N9P``````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`T,S,`,3`T,3<S-C(W-C<`,#(R,C8U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`0#````[=WB4@```"I03%1%``,`8&!@AFP`
M2W>X>)5?LY``FK"'GK;9L\2ET<*"Y]ZTTN#U____````3C<R#0````%T4DY3
M`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)
M344'U`P4$QD/2B]P\````&I)1$%4>-IC8$"`NQ<@-.^LN0QW[X(8*V-YS8N!
MHKQ3=2_7;+<%J;EXO7I[+5#D[MWKVZN!C&L=*9?+RVT9>&^DI=P%*>:=F^8;
M"]+.>]?E9BS$P+NS($;SWEP*9<R*A=H9>A4B<O<NV'H`"3(L:.BPORH`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE
M;65S+V=R87!H:6-S+VUA:6Q?<')I;W)I='E?;&]W+G!N9P``````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,S0Q`#$P-#$W,S8R-S8W`#`R-#4U,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`$`P```.W=XE(````;4$Q410H`!"0B)"0BY$1"1$1"Q&1B9(2"
MA,3"Q`0"_**JCLX````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$P``"Q,!`)J<&`````=T24U%!]0,"!(C-BN.I)$````_241!5'C:8V#`
M`IC3T@+`#+:.#@<B&8QIZ1T=;FD"#`Q!'4"@"A1BU>CH:`(;%`01``E!!(!"
MJE#+6`.0K08`%A@28,SW]-``````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F%P:&EC
M<R]I;7`N<&YG````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8P
M,P`Q,#0Q-S,V,C<V-P`P,C$U-S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3````;U!,5$4````_,BU`-2U(.3%71#MH6%21=VBHC6VHD'FKE(*V
MFGNUGI*\HXFZIIB[JZ;.MY?+O*;2O)O0Q</>R*37R;?BS:7?T+3HV+CDV,;E
MW-7WY+OKY.#KY=SUZ-7XZ<CT[N/_\<W^\]?]]>;]^?,\+R>/VMB0`````712
M3E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?4#`@2'S7!=(S4````C4E$051XVJV-21;",`Q#`VV@#76G4)P.<3-P
M_S.B['BL^<MOR5+J#^@?E-[W%3CGF-DN%Z5=+J044PS!0E"?BL@I1C%WB'-\
M'%`(3$U7*CG//2'@NZ9CKI#(^44T3\UMV62#V/.S/SVUUK53X%KIE>G$1O!>
MC"UBI%0V,1+$#!!TB.`J>+"Q@:B^N-;O#_B$#M&IB5!.`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O9W)A<&AI8W,O;6%I;%]U;G-E
M96XN<&YG````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,C,`,3`T,3<S-C(W
M-C<`,#(S,S`V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```)90
M3%1%````("`@;F98<FQ:?G1D?WAD@'AF@7EFAGUHB'YJB']KBX%LD(5OE8ES
MGIV5N:V3PK*3Q+.3Q+25Q;66R;F6R;J8PK^XS[^<T\*>U,2@R<C$WLJCX,ZH
M[-BM\-NS]=ZR]M^S^>*R^N.S_.:U_^BW_^BX_^FZ_^J]_^O"_^W'_>[-]>[N
M]?'Q^O/L^/3M]?7U_/7J````_?R[!0````%T4DY3`$#FV&8````!8DM'1`"(
M!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P($B0<OW3[@```
M`'9)1$%4>-J=SMT60D`8A6%,E"0S2JD4XZ?:D<_<_\VU,K)6A[QG^SG:AC$G
M9:JQ?A]H;/L514X-`MXHK%@#ELVK;9&S/!H`BPXH&6X_>&P8$7.+ZU[#<PW8
M=EFMD@$\I'<IJ^SB'WLX<R$$YV&X.P7ZB/H_-KD/9B83!#5#!N@`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O=&AE;65S+V=R87!H:6-S+VUA:6Q?<')I;W)I='E?:&EG:"YP
M;F<``````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-38W`#$P-#$W,S8R-S8W`#`R-#<P,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,```!+4$Q4104`"J`N%*PR
M%L,X&LP[&]`]'-]"'KI5/MA>0^%@0^1B1.9P5>E^9>J#;.N)<^R/>>R4?^V9
MAO"KF_&NG_.ZK/7$N?7(OO___P```!/N0#0````!=%).4P!`YMAF`````6)+
M1T0`B`4=2`````EP2%ES```+$@``"Q(!TMU^_`````=T24U%!]0,"!(C*::&
MJ60````^=$58=$-O;6UE;G0`0W)E871E9"!W:71H(%1H92!'24U0"@HH8RD@
M,C`P,R!*86MU8B`G:FEM;6%C)R!3=&5I;F5R)S/O6````%M)1$%4>-J5CDL2
M@"`,0T%I%/R#VM[_I(JCP,K1MVN:2:+4-R12WHUUMLJ*M&[8%ZHE_1TV7D'Z
M5L0"GCU@'L$!(\\`%8Z+Y#@S>@XY([9T8<HMT6/(:'E9^H\#\:`%'QVE51P`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H
M96UE<R]G<F%P:&EC<R]E;7!T>5]S<&%M+G!N9P``````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,30R-@`Q,#0Q-S,V,C<V-P`P,C,Q-C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3```!I%!,5$4````"`@(&!@8.#@X0$!`8&!@<
M'!P?'QLG)R$G)R4H*"0J*B,J*B8K*R0K*RLL+"4L+"PT-#`V-2XV-C`Y.#8\
M/#,^/CY"03I"0D)#0SU(1SU(1T!+241*2DI,2T%-34!244934D944T==7%-=
M75U>7E5A86%D8EMH9V)K:V1M;6UN;FYP;V9O;V]Q<&=S<65Q<7%Z>6=^?G5^
M?GE3G5-4G52%@W&'A7*&AH:*B'6*B76+B79=IEV+BW^-C8"/CH&.CH:0D)!N
MJVZ2DI)OK&^3DY-SLG-XM7B@GHB?G9&@H)6CH8JAH9*DHHNEHXREI)F*MXJ*
MN(J-NHVMK:.LK*ROKZ^SLIBYMZ*WMJZ;R)NYMZZZN;.\O+S!OZ7"P*6_O[_!
MP<&RS++$Q,3'QKK&QL:ZT[K)R<G/S\_3T;S1T<O5TK['X,?7U]?8V-'<VL39
MV=+:VM/>WM[BX,OBX,_DX<C4Y]3EXM+HY-/IY<_EY>7FYN;GY^?JZ=KQ[=+P
M[=CL[.SN[>3M[>WR\>3R\>GT\>GT]/3Y]>WX]^SX]^[[^.G___\```#1;T-G
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":
MG!@````'=$E-10?4#!03&06J^IGN````ZTE$051XVF-@``)F"5DQ@6X&&.CN
M-JMK;DA6[(8*L<3%&DIS"IE[>/N!1?@R\HK#U45$N[LMPWQ!BKK+6YIJRK*Z
MNQ*ZK96ZN[H9NJUJ.]LZVJ.ZNYP9NZM`*A3T/4LJBC*5NV.T&\&&L`O*:.AH
M2K'5I^N&@@6XO>2%>;BZ"[L*"]/``KS^$7H^<EI=0%#M"A+A#\ZWC69-RW:/
M[*I.@0@4V!NKE-ID=]D$55H`17B-<NVZD]RRN[K<G2H=@0(<D@ZJW3D@([I:
M3>)E@7J8F,2[Z]V[NK*[4@,##,#^8^H.J7=Q<3)-#'16`P#.>TB0&<39.@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:6UP+W1H96UE<R]G<F%P:&EC<R]M86YA9V5?871T86-H;65N=',N<&YG````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#8S-0`Q,#0Q-S,V,C<V-P`P,C0V,S4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````AU!,5$4````\8FU=?H]<@8]E
M@I=BA95DA)5DA95JB)QOC:!UD*5UDJ5ZEJM\F:N"G;"#GK&&H;.'HK2*H[>+
MI+B*I;>-I;J/J+N/J;N1J+R1J;V7K,"6K<"7K<";L,.=M,6ENLO%T]S&U-W(
MU=W(U=[)UM[*UM[+U]_,U]_,V-_-V-_-V.#.V>````#:\>T>`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?4#!03&#MR@+4$````CTE$051XVG6/QQ:",!1$HZ*HB`W$BAI)07+___N,
M%&'C6\V=\]H(\:]V8[$9;7M.'-=*:SK.)1<-O%HG*(FMU[0M@2)S7XFJC;SD
M84F$F,B:$TEF"0W3HN;4$3M"R[E9D"INOM\0N6;AH>+)3#,W[<658_$NB#H6
M2W/R#QW5[T=*>]^O)7T*C%6:84X_,>`/U,$1KW>?8\0`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O
M9W)A<&AI8W,O;6%I;%]P97)S;VYA;"YP;F<`````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(S-#(`,3`T,3<S-C(W-C<`,#(S-C,T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#
M``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%(B(C"@P0Q<;(
M#!`6YNCK)2@L#!`5*"PQ-T96&!XE;W^1?(J9EJ&MH*NWN\;216%^36J'4FZ+
M3FB#77F5"@T09H*>15AK:(2@56R#/4U>67"(;8FE6&Z$<XZJ"0L-8'*%?I6L
M'2(G9&]ZC9FEB9"7U=OAY^KM\O/T3F9]9X.>7'2+;XNF159F=9&L4&-U?)6M
MB9VPBIZPFJR]I[C';WJ$&1T@D9F?D)B>R=/;"0T/$A05$Q46#1$2$1$0&!@7
M2TA$$PH`&P\!020%-A\%FU@/RW49S'8:R'0:T7H=T'H=T7L>Q74<PG,<TWT?
MQ70=P7,=#@<`"@4`"`0`-1P"%0L!)A0",AL#938'1R8%6S$'-1T$-!P$DT\-
M+!@$I5P0?$4,*1<$K&`1BDP.>4,,M603)A4$'1`#OFH5MF84J5\3+1D%@TD/
MRG(8S'49S78:S'4:&`X$+A@#0B,%-!L$,1H$+QD$.A\%638512\:3#HI&A(,
M)!X:*28FS,S,1$1$)24E'1T=!@8&````____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````KX]Z*P``
M`(1T4DY3____________________________________________________
M____________________________________________________________
M____________________________________________________________
M__\`E](VO@````EP2%ES```+$@``"Q(!TMU^_````+Q)1$%4*,]C:`:!)A``
MLYH90(1MD[U](%0$)-#0:%]7#U1B"Q.P<Z@,"4A+=6Z$"3@Z>?OY^[C'!\$$
M8B,]O'P]\Y*S8`(EF;EN^:XY&:4P@3*7].S0PJ24(KBU$3%AB7$1X<$P`9N:
M\N*HZ(0*3CF(`*N9@4EU016#DHZD)4B`G5=65T^EEDF92T)&3*29P<I<7UI;
MBUM=S5A!55B#@Y'!FD=44UQ*GL7"2)5/55"(C<'44``)\#,S**(!`&EU5,O<
M[92W`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F%P:&EC<R]S:6=N960N<&YG````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<P-P`Q,#0Q-S,V,C<V-P`P
M,C(R-C,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````L5!,5$4`
M``40%AEB`0%F```?("$@("$A(2$S,S,Z.CH\/#P]/3V`+P:9,P!?;W2W70-W
M=W=Y>7G,9@#*;`[-;Q&#@X.#@X2%A87&>2V(B(B+BXN,C(R0D)#,F0"GIZ>U
MM;6VMK:YNKJ[N[O"PL+_S`#%Q<7.SL[5UM;9V=G;V]O=W=WAX>'BXN+__P#D
MY.3DY>7FYN;HZ.C__V;O\/'Q\?+S\_/T]/3V]O;__\S^_O[___\````.>HTM
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``#L,```[#`<=O
MJ&0````'=$E-10?4#!03&!3948A=````CTE$051XVIW.VQ*"(!"`8<K"SDD'
ML[*(L+.U48+9^S]8@@[<]P\W^PT[LPC]$^YBFYD39=MHP2K,0`%(N(SW%4`H
MG]E[V.L<=S7`3#XB5K"HT:[@M@Y>?O$M7\O`?0DP]YF#%9RNYRDIFYB5PY92
MNOCD0@C>-X?H1GG,8T*:]EPB4I%RXCG@YH<#-/!T"/T`X.82"`7,2W0`````
M245.1*Y"8((`````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]T:&5M97,O9W)A<&AI8W,O<W!E;&QC:&5C:RYP;F<`````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$W-S0`,3`T,3<S-C(W-C<`,#(S,3,T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@
M8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!0
M3%1%````____$RP3N-:X;9UL=Z9VD[Z26Y%9BKJ(G\6=J,NF____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````Z:)JK0````QT4DY3______________\`$M_.S@````EP2%ES```+
M$P``"Q,!`)J<&````$Y)1$%4*,]UCTL.@$`(0U_\,=K[W]<%A>A$6=%'*0%-
MA0`)P`"22KS!PP&?CI\5C/MFF-,Z'0Q*>V79L:[H:R-UA;)&>&9P'M75P6[F
M]V_X*`?QNE6UL`````!)14Y$KD)@@@`````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]T:&5M97,O9W)A<&AI8W,O9F%V:6-O;BYI8V\`````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-S8`,3`T,3<S-C(W-C<`,#(R-#,S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`0`!`!`0```!``@`:`4``!8````H````$````"`````!``@````````````1
M"P``$0L````!````````S?'_`-?S_@"[Y/<`R.GX`+C8Z`"ES>(`M-#?`.;U
M_0#C[O0`I,C>`)N\T@"FO,L`U>CU`,;8Y`#<Y>L`\_G]`)>WS@!MC:@`M\G7
M`'N:M@")H[P`>9"H`(*4JP#5W.4`+35``)BFN@`G+SP`:'>1`.#DZP`Q.4@`
MDIZU`#M$5P`M,C\`IJN[`%18:`##Q=``____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"0D)"0D)"0D)"0D)"0D)"0D)"0D)"0D)"0D)"0D)"0D(AT='1T='1T=
M'1T='1@?&B(9#@,##`P#`P(#`@($$Q\B"QD'!P<!!P<!`0`#$Q`?(A<$&0@'
M!P$`#`P#$PD$'R(<#Q(A"`P9%@D-%@H`!!\B"`\/!AD9(PH5&P4"`P(=(@\/
M(R$9!P\'#!05%`0$'2(("QX.!P\/`0<!"A44!2`B&2$'#P\/!P\'`0$#$Q$@
M(@T/#P\/#P<'`0<!```)("(<'!<7%Q<-#0T$!`0)!2`B(B(B(B(B(B(B(B(B
M(B(B)"0D)"0D)"0D)"0D)"0D)"0D)"0D)"0D)"0D)"0D)"0`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]G<F%P
M:&EC<R]E;F-R>7!T960N<&YG````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#<P-P`Q,#0Q-S,V,C<V-P`P,C,P,#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````L5!,5$4```40%AEB`0%F```?("$@("$A(2$S,S,Z.CH\
M/#P]/3V`+P:9,P!?;W2W70-W=W=Y>7G,9@#*;`[-;Q&#@X.#@X2%A87&>2V(
MB(B+BXN,C(R0D)#,F0"GIZ>UM;6VMK:YNKJ[N[O"PL+_S`#%Q<7.SL[5UM;9
MV=G;V]O=W=WAX>'BXN+__P#DY.3DY>7FYN;HZ.C__V;O\/'Q\?+S\_/T]/3V
M]O;__\S^_O[___\````.>HTM`````7123E,`0.;89@````%B2T=$`(@%'4@`
M```)<$A9<P``#L,```[#`<=OJ&0````'=$E-10?4#!03&!3948A=````CTE$
M051XVIW.VQ*"(!"`8<K"SDD'L[*(L+.U48+9^S]8@@[<]P\W^PT[LPC]$^YB
MFYD39=MHP2K,0`%(N(SW%4`HG]E[V.L<=S7`3#XB5K"HT:[@M@Y>?O$M7\O`
M?0DP]YF#%9RNYRDIFYB5PY92NOCD0@C>-X?H1GG,8T*:]EPB4I%RXCG@YH<#
M-/!T"/T`X.82"`7,2W0`````245.1*Y"8((`````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O9W)A<&AI8W,O87!P;&4N
M<&YG````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,S0`,3`T,3<S
M-C(W-C<`,#(R,3`W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````-````$`0#````/XWH"@``
M`!503%1%<```W```_0"8`+H`_64`_?T```#<,I!MZ`````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4
M$Q45&_C&A@```$!)1$%4>-IC8$`"QA"*V0!*0TAC!F.0@#$(,#"PA@(!`X)F
M<0$"&.W`P,`H"`)``2400*+9TM+2$D`&I@$A'```9$8+*KB9.?\`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]I;7`O=&AE;65S+V=E;FYE=FEL;&EE<G,O````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S8W`#`R,3,U
M,0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O9V5N;F5V:6QL
M:65R<R]S8W)E96XN8W-S````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V,S,`
M,3`T,3<S-C(W-C<`,#(S,S0R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\J*@H@*B!4:&ES('1H96UE(&%S(&)E96X@=W)I
M='1E;B!B>2!!241%($9L;W)E;G0@/&9A:61E0&%L<&AA8V5N="YC;VT^(&%N
M9`H@*B!-PZEL86YI92!'87)E874@/&UE;&%N:64N9V%R96%U0'9I;&QE+6=E
M;FYE=FEL;&EE<G,N9G(^"B`J"B`J(%1H92!T:&5M92!I9&5A('=A<R!T;R!I
M;F-O<G!O<F%T92!S;6]O=&AL>2!I;B!T:&4@26YT<F%N970N"B`J(%1H:7,@
M=&AE;64@:7,@<'5B;&ES:&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE(&AO<F1E('!A8VMA9V4N"B`J"B`J(%1H92!N86UE(&-O;65S(&9R;VT@
M=&AE(&-I='D@;V8@1V5N;F5V:6QL:65R<R!I;B!&<F%N8V4*("H*("H@)$AO
M<F1E.B!I;7`O=&AE;65S+V=E;FYE=FEL;&EE<G,O<V-R965N+F-S<RQV(#$N
M,2`R,#`T+S$P+S$W(#(P.C0Y.C,Y(&UD:G5K:6,@17AP("0*("HO"@HN=6YS
M965N('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-%145%1D8["GT*+F1E;&5T
M960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(SDY.3DY.3L*?0HN:6UP;W)T
M86YT('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-&1D-#0T,["GT*+F%N<W=E
M<F5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-D-F9F9F8["GT*+G%U;W1A
M=V%R;B!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N
M<RUS97)I9CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@9F]N="US:7IE
M.B`Q-W!X.PH@("`@8V]L;W(Z("-E835D,6,["B`@("!B86-K9W)O=6YD+6-O
M;&]R.B`C9C1E93=A.PI]"BYQ=6]T86%L97)T('L*("`@(&9O;G0M9F%M:6QY
M.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="UW96EG
M:'0Z(&)O;&0["B`@("!F;VYT+7-I>F4Z(#(P<'@["B`@("!C;VQO<CH@(V8T
M964W83L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E835D,6,["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O<VEM
M<&QE>"\`````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-C<`,#(P,38T`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+W1H96UE<R]S:6UP;&5X+W-C<F5E;BYC<W,`````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#,T,``Q,#0Q-S,V,C<V-P`P,C(Q-#<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+RHJ"B`J
M("1(;W)D93H@:6UP+W1H96UE<R]S:6UP;&5X+W-C<F5E;BYC<W,L=B`Q+C$@
M,C`P-"\Q,"\Q-R`R,#HS-SHT-R!M9&IU:VEC($5X<"`D"B`J+PH*+FEM<&]R
M=&%N="!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C14)#,D,R.PI]"BYU;G-E
M96X@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(T0S1#-$,SL*?0HN86YS=V5R
M960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(T-%1$9%0SL*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M
M97,O8G5R;G1O<F%N9V4O````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-C<`,#(Q,#,Q`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+W1H96UE<R]B=7)N=&]R86YG92]S8W)E96XN8W-S````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,S,0`Q,#0Q-S,V,C<V-P`P,C,P
M,34`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+RHJ"B`J(%1H96UE(&)Y(#H@17)I8R!*;VX@4D]35$545$52(#QE<FEC+G)O
M<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^"B`J(%!L96%S92!C;VYT86-T
M('1H92!4:&5M92=S(&%U=&AO<B!F;W(@86YY(&UI<W-I;F<@<W1Y;&4N"B`J
M"B`J("1(;W)D93H@:6UP+W1H96UE<R]B=7)N=&]R86YG92]S8W)E96XN8W-S
M+'8@,2XQ(#(P,#0O,3`O,3<@,C`Z-#DZ,SD@;61J=6MI8R!%>'`@)`H@*B\*
M"BYD96QE=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V-C8V,["GT*
M+FEM<&]R=&%N="!["B`@("!B86-K9W)O=6YD+6-O;&]R.B!Y96QL;W<["GT*
M+G5N<V5E;B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9&1F9F0U.PI]"BYA
M;G-W97)E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C965E93DP.PI]"BYQ
M=6]T87=A<FX@>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A
M+'-A;G,M<V5R:68["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*("`@(&9O;G0M
M<VEZ93H@,3=P>#L*?0HN<75O=&%A;&5R="!["B`@("!F;VYT+69A;6EL>3H@
M5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M=V5I9VAT
M.B!B;VQD.PH@("`@9F]N="US:7IE.B`Q-W!X.PI]"BYC;VYT<F]L('L*("`@
M(&)O<F1E<BUB;W1T;VTZ(#$@<'@@<V]L:60@(V9F9F9F9CL*?0HN<V5L96-T
M960M8V]N=')O;"!["B`@("!B;W)D97(M8F]T=&]M.B`Q('!X('-O;&ED("-F
M9F9F9F8["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]L=6-B;'5E+P``````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W
M,``P,C`Q,S``(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+VQU
M8V)L=64O<V-R965N+F-S<P``````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,3<T`#$P-#$W,S8R-S<P`#`R,C$R,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O*BH*("H@)$AO<F1E.B!I;7`O=&AE
M;65S+VQU8V)L=64O<V-R965N+F-S<RQV(#$N,2XR+C(@,C`P-2\Q,"\Q."`Q
M,CHQ-#HQ-B!J86X@17AP("0*("HO"@HN9F]L9&5R<R!["B`@("!F;VYT+7-I
M>F4Z(#$Q<'@["GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]P;W-T;G5K92\`````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<W,``P,C`S-#4`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE
M;65S+W!O<W1N=6ME+W-C<F5E;BYC<W,`````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-#4U`#$P-#$W,S8R-S<P`#`R,C,S-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*BH*("H@)$AO<F1E.B!I
M;7`O=&AE;65S+W!O<W1N=6ME+W-C<F5E;BYC<W,L=B`Q+C$@,C`P-"\Q,"\Q
M-R`R,#HS-SHT-R!M9&IU:VEC($5X<"`D"B`J+PH*+F1E;&5T960@>PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(SDY.3DY.3L*?0HN:6UP;W)T86YT('L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F-C8V,["GT*+G5N<V5E;B!["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C965E969F.PI]"BYA;G-W97)E9"!["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C1#E$0T,R.PI]"BYQ=6]T960@>PH@("`@8V]L
M;W(Z(",S,S`P-C8["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]C:&5R<GDO
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<W,``P,3<W-S$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I
M;7`O=&AE;65S+V-H97)R>2]S8W)E96XN8W-S````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,S,W`#$P-#$W,S8R-S<P`#`R,3<V,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*BH*("H@)$AO
M<F1E.B!I;7`O=&AE;65S+V-H97)R>2]S8W)E96XN8W-S+'8@,2XQ(#(P,#0O
M,3`O,3<@,C`Z-#DZ,SD@;61J=6MI8R!%>'`@)`H@*B\*"BYI;7!O<G1A;G0@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(T9&1D9!03L*?0HN=6YS965N('L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-&1D-#.3D["GT*+F%N<W=E<F5D('L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-$1$1$1$0["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W1H96UE<R]B
M;'5E;6]O;B\`````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<W,``P,C`S,34`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]I;7`O=&AE;65S+V)L=65M;V]N+W-C<F5E;BYC<W,`````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S$V`#$P-#$W,S8R-S<P`#`R,C,P-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH*
M("H@)$AO<F1E.B!I;7`O=&AE;65S+V)L=65M;V]N+W-C<F5E;BYC<W,L=B`Q
M+C$@,C`P-"\Q,"\Q-R`R,#HT.3HS."!M9&IU:VEC($5X<"`D"B`J+PH*+F-O
M;7!O<V5B;V1Y('L*("`@(&9O;G0M9F%M:6QY.B!#;W5R:65R($YE=RP@36]N
M;W-P86-E.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"BYD96QE=&5D('L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z(",Y.3DY.3D["GT*+F1E;&5T960M;W9E<B![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-S<W-S<W.PI]"BYI;7!O<G1A;G0@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F8V-C8SL*?0HN:6UP;W)T86YT
M+6]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F86%A83L*?0HN=6YS
M965N('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E965E9F8["GT*+G5N<V5E
M;BUO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V-C9F8["GT*+F%N
M<W=E<F5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V9F8V,["GT*+F%N
M<W=E<F5D+6]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(SDY964Y.3L*
M?0HN9F]L9&5R=6YS=6(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V)B8V-D
M9#L*?0HN<75O=&%W87)N('L*("`@(&-O;&]R.B!B;&%C:SL*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z('EE;&QO=SL*?0HN<75O=&%A;&5R="!["B`@("!C;VQO
M<CH@=VAI=&4["B`@("!B86-K9W)O=6YD+6-O;&]R.B!R960["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]I;7`O=&AE;65S+V)L=65W:&ET92\`````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<P`#`R
M,#0V-0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O8FQU97=H
M:71E+W-C<F5E;BYC<W,`````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R
M-#,`,3`T,3<S-C(W-S``,#(R-#4R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J*@H@*B`D2&]R9&4Z(&EM<"]T:&5M97,O
M8FQU97=H:71E+W-C<F5E;BYC<W,L=B`Q+C$N,3`N,B`R,#`U+S$P+S$X(#$R
M.C$T.C$S(&IA;B!%>'`@)`H@*B\*"BYF;VQD97)S('L*("`@(&9O;G0M<VEZ
M93H@,3%P>#L*?0HN86YS=V5R960@>PH@("`@8F%C:V=R;W5N9#H@(V%C83L*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+VQA=F%N9&5R+P``````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S<P`#`R,#(W,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:&5M97,O
M;&%V86YD97(O<V-R965N+F-S<P``````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`S,S0`,3`T,3<S-C(W-S``,#(R,C4W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&EM<"]T
M:&5M97,O;&%V86YD97(O<V-R965N+F-S<RQV(#$N,2`R,#`T+S$P+S$W(#(P
M.C,W.C0V(&UD:G5K:6,@17AP("0*("HO"@HN=&5X="!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C1C9%-T8X.PI]"BYA;G-W97)E9"!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C1C1$-T8X.PI]"BYU;G-E96X@>PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(T4Q0S)%-SL*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O=&AE;65S+W-C<F5E;BYC<W,`
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,C<P`#$P
M-#$W,S8R-S<P`#`R,#0V-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O*BH*("H@)$AO<F1E.B!I;7`O=&AE;65S+W-C<F5E
M;BYC<W,L=B`Q+C(N,BXQ,2`R,#`V+S`R+S$P(#(S.C(S.C$T(&-H=6-K($5X
M<"`D"B`J+PH*+RH@06QI9VX@<W1Y;&5S+"!A9&1E9"!F;W(@0D,N("HO"BYL
M969T06QI9VX@>PH@("!T97AT+6%L:6=N.B!L969T.PI]"BYR:6=H=$%L:6=N
M('L*("`@=&5X="UA;&EG;CH@<FEG:'0["GT*+FQE9G1&;&]A="!["B`@(&9L
M;V%T.B!L969T.PI]"BYR:6=H=$9L;V%T('L*("`@9FQO870Z(')I9VAT.PI]
M"@HO*B!-96YU(&)O='1O;2!M87)G:6XL(&%D9&5D(&9O<B!"0RX@*B\*(VUE
M;G4@>PH@("`@;6%R9VEN+6)O='1O;3H@.'!X.PI]"@HO*B!-97-S86=E(&QI
M<W0@=&%B;&4@<W1Y;&5S+B`J+PHN;65S<V%G94QI<W0@>PH@("`@=&%B;&4M
M;&%Y;W5T.B!F:7AE9#L*("`@('=I9'1H.B`Q,#`E.PI]"BYM97-S86=E3&ES
M="!T<B!["B`@("!H96EG:'0Z(#(P<'@["GT*+FUE<W-A9V5,:7-T('1H('L*
M("`@('1E>'0M86QI9VXZ(&QE9G0["B`@("!C=7)S;W(Z('!O:6YT97(["B`@
M("!W:&ET92US<&%C93H@;F]W<F%P.PI]"BYM97-S86=E3&ES="!T9"!["B`@
M("!W:&ET92US<&%C93H@;F]W<F%P.PH@("`@;W9E<F9L;W<Z(&AI9&1E;CL*
M("`@('1E>'0M;W9E<F9L;W<Z(&5L;&EP<VES.PI]"BYM97-S86=E3&ES="!I
M;6<@>PH@("`@=F5R=&EC86PM86QI9VXZ(&UI9&1L93L*?0H*+RH@4W1Y;&4@
M9F]R(&1I=B!T:&%T(&9I>&5S($M(5$U,(&)R;W=S97)S+B`J+PHN;VAI9&4@
M>PH@("`@;W9E<F9L;W<Z(&AI9&1E;CL*?0H*+RH@0F%S960@;VX@=&AE($UO
M>FEL;&$@9&5F875L="!D969I;G1I;VYS("HO"B-H=&UL+6UE<W-A9V4@=&0@
M>PH@("`@<&%D9&EN9SH@,#L*?0HC:'1M;"UM97-S86=E('5L+"`C:'1M;"UM
M97-S86=E(&UE;G4L("-H=&UL+6UE<W-A9V4@9&ER('L*("`@(&1I<W!L87DZ
M(&)L;V-K.PH@("`@;&ES="US='EL92UT>7!E.B!D:7-C.PH@("`@;6%R9VEN
M.B`Q96T@,#L*("`@("UM;WHM<&%D9&EN9RUS=&%R=#H@-#!P>#L*("`@("UM
M;WHM8V]U;G1E<BUR97-E=#H@+6AT;6PM8V]U;G1E<B`P.PI]"B-H=&UL+6UE
M<W-A9V4@;VP@>PH@("`@9&ES<&QA>3H@8FQO8VL["B`@("!L:7-T+7-T>6QE
M+71Y<&4Z(&1E8VEM86P["B`@("!M87)G:6XZ(#%E;2`P.PH@("`@+6UO>BUP
M861D:6YG+7-T87)T.B`T,'!X.PH@("`@+6UO>BUC;W5N=&5R+7)E<V5T.B`M
M:'1M;"UC;W5N=&5R(#`["GT*(VAT;6PM;65S<V%G92!L:2!["B`@("!D:7-P
M;&%Y.B!L:7-T+6ET96T["B`@("`M;6]Z+69L;V%T+65D9V4Z(&UA<F=I;BUB
M;W@["GT*(VAT;6PM;65S<V%G92!L:2!["B`@("!D:7-P;&%Y.B!L:7-T+6ET
M96T["B`@("!M87)G:6XM;&5F=#H@,39P>#L*("`@('!A9&1I;F<M;&5F=#H@
M,3!P>#L*("`@(&UA<F=I;BUB;W1T;VTZ(#1P>#L*?0HC:'1M;"UM97-S86=E
M('`@>PH@("`@9&ES<&QA>3H@8FQO8VL["B`@("!M87)G:6XZ(#%E;2`P.PI]
M"@HO*B!,96=E;F0@<W1Y;&5S+B`J+PHN;6%I;&)O>$QE9V5N9"!["B`@("!P
M861D:6YG.B`U<'@["GT*+FUA:6QB;WA,96=E;F0@;&D@>PH@("`@8V]L;W(Z
M(",P,#`["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@;&ES="US
M='EL93H@;F]N93L*("`@(&1I<W!L87DZ(&EN;&EN93L*?0HN;6%I;&)O>$QE
M9V5N9"!L:2!D:78@>PH@("`@9FQO870Z(&QE9G0["B`@("!M87)G:6XM<FEG
M:'0Z(#%E;3L*?0HN;6%I;&)O>$QE9V5N9"!L:2!D:78@9&EV('L*("`@('!A
M9&1I;F<Z(#)P>#L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-C8["B`@("!M
M87)G:6XM<FEG:'0Z("XS96T["GT*"BYC;VUP;W-E8F]D>2!["B`@("!F;VYT
M+69A;6EL>3H@;6]N;W-P86-E+&9I>&5D.PH@("`@9F]N="US:7IE.B`Q,G!X
M.PI]"BYF;VQD97)S('L*("`@(&9O;G0M<VEZ93H@,3)P>#L*?0HN9F]L9&5R
M<V5L96-T('L*("`@('!A9&1I;F<M=&]P.B`U<'@["GT*+G-E96X@>PH@("`@
M8F%C:V=R;W5N9#H@(V9F9CL*?0HN<V5E;CIH;W9E<BP@+G-E96XM;W9E<B![
M"B`@("!B86-K9W)O=6YD.B`C9C-F,V8S.PI]"BYD96QE=&5D('L*("`@(&)A
M8VMG<F]U;F0Z(",Y.3D["GT*='(N9&5L971E9#IH;W9E<BP@='(N9&5L971E
M9"UO=F5R('L*("`@(&)A8VMG<F]U;F0Z(",W-S<["GT*+FEM<&]R=&%N="![
M"B`@("!B86-K9W)O=6YD.B`C9F-C.PI]"G1R+FEM<&]R=&%N=#IH;W9E<BP@
M='(N:6UP;W)T86YT+6]V97(@>PH@("`@8F%C:V=R;W5N9#H@(V9A83L*?0HN
M=6YS965N('L*("`@(&)A8VMG<F]U;F0Z("-E968["GT*='(N=6YS965N.FAO
M=F5R+"!T<BYU;G-E96XM;W9E<B!["B`@("!B86-K9W)O=6YD.B`C8V-F.PI]
M"BYA;G-W97)E9"!["B`@("!B86-K9W)O=6YD.B`C8V9C.PI]"G1R+F%N<W=E
M<F5D.FAO=F5R+"!T<BYA;G-W97)E9"UO=F5R('L*("`@(&)A8VMG<F]U;F0Z
M(",Y93D["GT*+F9O;&1E<G5N<W5B('L*("`@(&9O;G0M<W1Y;&4Z(&ET86QI
M8SL*?0HN<75O=&%W87)N('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R
M;W5N9#H@>65L;&]W.PI]"BYQ=6]T86%L97)T('L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F%C:V=R;W5N9#H@(V8P,#L*?0H*+RH@4&%D('1H92!A9&1R97-S
M8F]O:R!I8V]N(&EN(&AE861E<B!C;VUP;W-E(&QI;FMS+B`J+PHN;7-G:&5A
M9&5R(&EM9R!["B`@("!V97)T:6-A;"UA;&EG;CH@;6ED9&QE.PH@("`@<&%D
M9&EN9SH@,7!X.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VEM<"]D;V-S+P``````````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S``,#$V,30P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+V1O8W,O55!'4D%$24Y'````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<V,0`Q
M,#0Q-S,V,C<W,``P,3<T,#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/3T]/3T]/3T]/3T]/3T]"B!5<&=R861I;F<@24U0
M"CT]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`V
M+S`Q+S`V(#$P.C(Y.C0U("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@
M,2XW+C@N."`D"CI#;VYT86-T.B`@("`@("!I;7!`;&ES=',N:&]R9&4N;W)G
M"@H*"E5P9W)A9&EN9R!)35`@1G)O;2`T+C`N>"!4;R`T+C$N>`H]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H:7,@:7,@82!N;VXM97AH
M875S=&EV92P@<75I8VL@97AP;&%N871I;VX@;V8@=VAA="!H87,@8VAA;F=E
M9"!B971W965N(&%N($E-4`HT+C`N>"!I;G-T86QL871I;VX@=&\@24U0(#0N
M,2YX+@H*"D%U=&]M871I8R!.86UE<W!A8V4@1&5T96-T:6]N"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I4:&4@8&!N86UE<W!A8V5@8"P@8&!H
M:65R87)C:&EE<V!@+"!@8&9O;&1E<G-@8"P@8&!D96QI;6ET97)@8"P@86YD
M"F!@9&]T9FEL97-@8"!P87)A;65T97)S('=E<F4@<F5M;W9E9"!F<F]M(&!@
M8V]N9FEG+W-E<G9E<G,N<&AP8&`N("!.86UE<W!A8V5S"F%R92!N;W<@875T
M;VUA=&EC86QL>2!C;VYF:6=U<F5D('!U<G-U86YT('1O(%)&0R`R,S0R+@H*
M268@=7-I;F<@=&AE(%57($E-05`@9&%E;6]N+"!Y;W4@;6%Y(&YO=&EC92!A
M(&)U;F-H(&]F(&%D9&ET:6]N86P@;F%M97-P86-E<PIT:&%T('=E<F4@;F]T
M(&1I<W!L87EE9"!B969O<F4@87,@=V5L;"!A<R!T:&4@86)I;&ET>2!O9B!T
M:&4@=7-E<B!T;PIV:65W(&%L;"!F:6QE<R!T:&%T(&QI=F4@:6X@=&AE:7(@
M:&]M92!D:7)E8W1O<GD@=FEA('1H92!F;VQD97)S('-C<F5E;BX*26YF;W)M
M871I;VX@;VX@:&]W('1O(&-O<G)E8W0@>6]U<B!)34%0('-E<G9E<B!C;VYF
M:6=U<F%T:6]N(&-A;B!B92!F;W5N9"!A=`H*("!H='1P.B\O=VEK:2YH;W)D
M92YO<F<O26UP55=)34%03F%M97-P86-E<PH*"E5S97(M1&5F:6YE9"!(96%D
M97)S"BTM+2TM+2TM+2TM+2TM+2TM+2TM"@I4:&4@8&!C;VYF:6<O:&5A9&5R
M<RYT>'1@8"!F:6QE(&AA<R!B965N(')E;6]V960@86YD(')E<&QA8V5D(&)Y
M"F!@8V]N9FEG+VAE861E<G,N<&AP8&`N("!!;GD@=7-E<BUD969I;F5D(&AE
M861E<G,@<VAO=6QD(&)E(&UI9W)A=&5D('1O('1H:7,*9FEL92X@(%1H92!N
M97<@9FEL92!H87,@=&AE(&%D=F%N=&%G92!O9B!A;&QO=VEN9R!A;GD@=F%L
M:60@4$A0(&5X<')E<W-I;VX*=&\@8F4@97AE8W5T960@870@<G5N+71I;64@
M=VAE;B!G96YE<F%T:6YG('1H92!H96%D97)S+B`@4V5E('1H92!T;W`@;V8*
M=&AE(&!@:&5A9&5R<RYP:'!@8"!F:6QE(&9O<B!T:&4@;F5W(&9O<FUA="!R
M97%U:7)E9"X*"@I296UO=F5D(%!R969E<F5N8V5S"BTM+2TM+2TM+2TM+2TM
M+2TM+2T*"E1H92!F;VQL;W=I;F<@<')E9F5R96YC97,@87)E(&YO(&QO;F=E
M<B!U<V5D(&%N9"!M87D@8F4@<V%F96QY(')E;6]V960@9G)O;0IY;W5R(&!@
M8V]N9FEG+W!R969S+G!H<&!@(&9I;&4@86YD('EO=7(@<')E9F5R96YC97,@
M8F%C:V5N9#HZ"@H@("`G9&ES<&]S:71I;VY?<F5Q=65S=%]D96QI=F5R>2<*
M("`@)V1I<W!O<VET:6]N7W-E;F1?;61N)PH@("`G=W)A<%]W:61T:"<*"@I5
M<&=R861I;F<@24U0($9R;VT@,RYX(%1O(#0N,"YX"CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*"E1H:7,@:7,@82!N;VXM97AH875S=&EV92P@
M<75I8VL@97AP;&%N871I;VX@;V8@=VAA="!H87,@8VAA;F=E9"!B971W965N
M(&%N($E-4`HS+G@@:6YS=&%L;&%T:6]N('1O($E-4"`T+C`N>"X*"@I&:6QT
M97)S"BTM+2TM+2T*"D9I;'1E<FEN9R!C;V1E(&AA<R!B965N(')E;6]V960@
M9G)O;2!)35`N("!4;R!H879E('1H92!S86UE(&9E871U<F5S(&%S('1H90IO
M;&0@8V]D92P@>6]U('-H;W5L9"!I;G-T86QL('1H92!);F=O7R!M;V1U;&4N
M("!3964@=&AE($E.4U1!3$Q?(&9I;&4@9F]R(&UO<F4*:6YF;W)M871I;VXN
M"@HN+B!?26YG;SH@:'1T<#HO+W=W=RYH;W)D92YO<F<O:6YG;R\*+BX@7TE.
M4U1!3$PZ(#]F/4E.4U1!3$PN:'1M;`H````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]D;V-S+U)%041-10``````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0W-S8`,3`T,3<S
M-C(W-S``,#$W,#,S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````%=H870@:7,@24U0/PH]/3T]/3T]/3T]/3T*"CI,87-T('5P
M9&%T93H@("`D1&%T93H@,C`P-2\Q,"\Q."`Q,CHQ,SHR-R`D"CI2979I<VEO
M;CH@("`@("`D4F5V:7-I;VXZ(#(N,C$N,3`N,2`D"CI#;VYT86-T.B`@("`@
M("!I;7!`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S
M"BXN('-E8W1I;VXM;G5M8F5R:6YG.CH*"DE-4"!I<R!T:&4@26YT97)N970@
M365S<V%G:6YG(%!R;V=R86T@*&9O<FUE<FQY+"!A;6]N9R!O=&AE<B!T:&EN
M9W,L('1H92!)34%0"G=E8DUA:6P@4')O9W)A;2DL(&$@4$A0+6)A<V5D('=E
M8FUA:6P@<WES=&5M(&%N9"!A(&-O;7!O;F5N="!O9B!T:&4@2&]R9&4*<')O
M:F5C="X@($E-4"P@;VYC92!I;G-T86QL960L(&%C8V5S<V5S(&UA:6P@;W9E
M<B!)34%0('1H=7,@<F5Q=6ER:6YG(&QI='1L90IT;R!N;R!S<&5C:6%L('!R
M97!A<F%T:6]N<R!O;B!T:&4@<V5R=F5R(&]N('=H:6-H(&UA:6P@:7,@<W1O
M<F5D+@H*24U0(&]F9F5R<R!M;W-T(&]F('1H92!F96%T=7)E<R!U<V5R<R!H
M879E(&-O;64@=&\@97AP96-T(&9R;VT@=&AE:7(*8V]N=F5N=&EO;F%L(&UA
M:6P@<')O9W)A;7,L(&EN8VQU9&EN9R!A='1A8VAM96YT<RP@<W!E;&PM8VAE
M8VLL(&%D9')E<W,@8F]O:W,L"FUU;'1I<&QE(&9O;&1E<G,L(&%N9"!M=6QT
M:7!L92UL86YG=6%G92!S=7!P;W)T+@H*5&AI<R!S;V9T=V%R92!I<R!/4TD@
M0V5R=&EF:65D($]P96X@4V]U<F-E(%-O9G1W87)E+B`@3U-)($-E<G1I9FEE
M9"!I<R!A"F-E<G1I9FEC871I;VX@;6%R:R!O9B!T:&4@8$]P96X@4V]U<F-E
M($EN:71I871I=F5@7RX*"BXN(%]@3W!E;B!3;W5R8V4@26YI=&EA=&EV96`Z
M(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O"@H*3V)T86EN:6YG($E-4`HM
M+2TM+2TM+2TM+2TM"@I&=7)T:&5R(&EN9F]R;6%T:6]N(&]N($E-4"!A;F0@
M=&AE(&QA=&5S="!V97)S:6]N(&-A;B!B92!O8G1A:6YE9"!A=#H@"@H@(&AT
M='`Z+R]W=W<N:&]R9&4N;W)G+VEM<"\*"@I$;V-U;65N=&%T:6]N"BTM+2TM
M+2TM+2TM+2T*"E1H92!F;VQL;W=I;F<@9&]C=6UE;G1A=&EO;B!I<R!A=F%I
M;&%B;&4@:6X@=&AE($E-4"!D:7-T<FEB=71I;VXZ"@HZ4D5!1$U%7SH@("`@
M("`@("`@("!4:&ES(&9I;&4*.D-/4%E)3D=?.B`@("`@("`@("`@0V]P>7)I
M9VAT(&%N9"!L:6-E;G-E(&EN9F]R;6%T:6]N"CI@9&]C<R]#2$%.1T538%\Z
M("`@($-H86YG97,@8GD@<F5L96%S90HZ8&1O8W,O0U)%1$E44V!?.B`@("!0
M<F]J96-T(&1E=F5L;W!E<G,*.F!D;V-S+TE.4U1!3$Q@7SH@("`@26YS=&%L
M;&%T:6]N(&EN<W1R=6-T:6]N<R!A;F0@;F]T97,*.F!D;V-S+U1/1$]@7SH@
M("`@("`@1&5V96QO<&UE;G0@5$]$3R!L:7-T"CI@9&]C<R]54$=2041)3D=@
M7SH@(%!O:6YT97)S(&]N('5P9W)A9&EN9R!F<F]M('!R979I;W5S($E-4"!V
M97)S:6]N<PH*"DEN<W1A;&QA=&EO;@HM+2TM+2TM+2TM+2T*"DEN<W1R=6-T
M:6]N<R!F;W(@:6YS=&%L;&EN9R!)35`@8V%N(&)E(&9O=6YD(&EN('1H92!F
M:6QE($E.4U1!3$Q?(&EN('1H90I@8&1O8W,O8&`@9&ER96-T;W)Y(&]F('1H
M92!)35`@9&ES=')I8G5T:6]N+@H*"D%S<VES=&%N8V4*+2TM+2TM+2TM+0H*
M268@>6]U(&5N8V]U;G1E<B!P<F]B;&5M<R!W:71H($E-4"P@:&5L<"!I<R!A
M=F%I;&%B;&4A(`H*5&AE($AO<F1E($9R97%U96YT;'D@07-K960@475E<W1I
M;VYS($QI<W0@*$9!42DL(&%V86EL86)L92!O;B!T:&4@5V5B(&%T"B`*("!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]F87$O"@I4:&4@2&]R9&4@4')O:F5C="!R
M=6YS(&$@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',L(&9O<B!I;F1I=FED=6%L
M(&%P<&QI8V%T:6]N<PIA;F0@9F]R(&ES<W5E<R!R96QA=&EN9R!T;R!T:&4@
M<')O:F5C="!A<R!A('=H;VQE+B`@26YF;W)M871I;VXL(&%R8VAI=F5S+"!A
M;F0*<W5B<V-R:7!T:6]N(&EN9F]R;6%T:6]N(&-A;B!B92!F;W5N9"!A=`H*
M("!H='1P.B\O=W=W+FAO<F1E+F]R9R]M86EL+PH*3&%S=&QY+"!(;W)D92!D
M979E;&]P97)S+"!C;VYT<FEB=71O<G,@86YD('5S97)S(&%L<V\@;6%K92!O
M8V-A<VEO;F%L"F%P<&5A<F%N8V5S(&]N($E20RP@;VX@=&AE(&-H86YN96P@
M(VAO<F1E(&]N('1H92!F<F5E;F]D92!.971W;W)K"BAI<F,N9G)E96YO9&4N
M;F5T*2X*"@I,:6-E;G-I;F<*+2TM+2TM+2TM"@I&;W(@;&EC96YS:6YG(&%N
M9"!C;W!Y<FEG:'0@:6YF;W)M871I;VXL('!L96%S92!S964@=&AE(&9I;&4@
M0T]064E.1U\@:6X@=&AE"DE-4"!D:7-T<FEB=71I;VXN"@I4:&%N:W,L"@I4
M:&4@24U0('1E86T*"@HN+B!?4D5!1$U%.B`_9CU214%$344N:'1M;`HN+B!?
M0T]064E.1SH@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O9W!L+G!H
M<`HN+B!?9&]C<R]#2$%.1T53.B`_9CU#2$%.1T53+FAT;6P*+BX@7V1O8W,O
M0U)%1$E44SH@/V8]0U)%1$E44RYH=&UL"BXN(%])3E-404Q,.@HN+B!?9&]C
M<R])3E-404Q,.B`_9CU)3E-404Q,+FAT;6P*+BX@7V1O8W,O5$]$3SH@/V8]
M5$]$3RYH=&UL"BXN(%]D;V-S+U501U)!1$E.1SH@/V8]55!'4D%$24Y'+FAT
M;6P*```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]D;V-S+T-(04Y'
M15,`````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R
M-3$R-C4`,3`T,3<S-C(W-S``,#$W,30S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM+2T*=C0N,0HM+2TM"@I;;6US72!#
M;W)R96-T;'D@97AP=6YG92!C=7)R96YT(&UA:6QB;W@@=VAE;B!D96QE=&EN
M9R!M97-S86=E<R!O;B!A(%!/4#,*("`@("`@<V5R=F5R("A"=6<@(S,Q-38I
M+@H*"BTM+2TM+2TM"G8T+C$M4D,S"BTM+2TM+2TM"@I;;6US72!!='1E;7!T
M('1O(&QO9VEN('1O(&UA:6P@<V5R=F5R(&UU;'1I<&QE('1I;65S(&]N(&YO
M;BUA=71H(&9A:6QU<F4@=&\*("`@("`@96QI;6EN871E('-O;64@(G)A;F1O
M;2(@<V5S<VEO;B!T:6UE;W5T<R`H86=`;F5T<VED92YD92P@0G5G(",S-#`T
M*2X*6VUM<UT@06QL;W<@8V]N9FEG=7)A=&EO;B!O9B!S97)V97(@=&EM96]U
M=',@:6X@<V5R=F5R<RYP:'`N"EMJ86Y=($QE<W,@:6YT<G5S:79E(&YO=&EF
M:6-A=&EO;B!W:&5N(&5X<&%N9&EN9R!O9B!A9&1R97-S97,@:6X@=&AE(&-O
M;7!O<V4*("`@("`@=FEE=R!F86EL<R`H1&UI=')I>2!-:6MS27(@/&UI:W-I
M<D!M86ME<BYR=3XI+@I;;6US72!)35!?24U!4$-L:65N=#HZ(&YO=R!U<V5S
M('1H92!!=71H7U-!4TP@4$5!4B!M;V1U;&4@9'5R:6YG($-204TM340U(&%N
M9`H@("`@("!$24=%4U0M340U(&%U=&AE;G1I8V%T:6]N+@H*"BTM+2TM+2TM
M"G8T+C$M4D,R"BTM+2TM+2TM"@I;:F%N72!!9&0@2VAM97(@=')A;G-L871I
M;VX@*$QE86YG($-H=6US;V)E;B`\<V]B96Y`:VAM97)O<RYI;F9O/BDN"EMM
M;7-=($UA:V4@3&EN:V5D(&%T=&%C:&UE;G1S('=O<FL@:6X@;75L=&EP87)T
M+V%L=&5R;F%T:79E(&UE<W-A9V5S"B`@("`@("A"=6<@(S,S,S4I+@I;;6US
M72!!;&QO=R!S96QE8W1I;VX@;V8@5FER='5A;"!&;VQD97(@9F]R(&QO9VEN
M(&UA:6QB;W@@*$)U9R`C,S,Q-2DN"EMM;7-=(%!R;VUP="!U<V5R(&)E9F]R
M92!S96YD:6YG(&UE<W-A9V5S('=I=&@@96UP='D@<W5B:F5C=',@*$)U9R`C
M,S,S,RDN"EMM;7-=($%D9"!A8FEL:71Y('1O(&5D:70@<V5A<F-H('%U97)I
M97,N"EMJ86Y=($QO9R!C;W)R96-T(&%D9')E<W,@:6X@;&]G:6X@<W5C8V5S
M<R!M97-S86=E(&EF(&-O;FYE8W1I;F<@=&AR;W5G:"!A"B`@("`@('!R;WAY
M("A"=6<@(S,R.#DI+@I;:F%N72!&:7@@9F]R=V%R9&EN9R!O9B!M=6QT:7!L
M92!M97-S86=E<RX*6VIA;ET@1FEX(&-O;F9I<FUA=&EO;G,@869T97(@<W5C
M8V5S<V9U;&QY('-E;F1I;F<@;65S<V%G97,@*$)U9R`C,S(S,RDN"EMJ86Y=
M($%P<&QY(%]I;7!?:&]O:U]M8F]X7VEC;VYS(&AO;VL@=&\@=&AE('-I9&5B
M87(@9F]L9&5R('1R964@*$)U9R`C,S$S,BDN"EMM;7-=(%)E+6%D9"!O<'1I
M;VX@=&\@<F5B=6EL9"!F;VQD97(@=')E92!F<F]M($E-05`@<V5R=F5R+@I;
M;6US72!&:7@@<V5N="UM86EL(&9O;&1E<B!S96QE8W1I;VX@:6X@8V]M<&]S
M92!V:65W("A"=6<@(S(X,#(I+@I;8VIH72!&:7@@<F5D:7)E8W1I;VX@=&\@
M:6YI=&EA;%]A<'!L:6-A=&EO;B!P<F5F97)E;F-E(&%F=&5R(')U;FYI;F<*
M("`@("`@36%I;G1E;F%N8V4@=&%S:W,N"@H*+2TM+2TM+2T*=C0N,2U20S$*
M+2TM+2TM+2T*"EMM;7-=(%)E;6]V960@)V1O=&9I;&5S)R!S97)V97(@<&%R
M86UE=&5R+@I;;6US72!!;&QO=R!02%`@97AP<F5S<VEO;G,@=&\@8F4@97AE
M8W5T960@9F]R('5S97(M9&5F:6YE9"!H96%D97)S("A"=6<*("`@("`@(S,P
M.3,I+@I;;6US72!3=7!P;W)T("=$96Q3<"<@<&%R86UE=&5R(&EN(&9L;W=E
M9"!T97AT(&UE<W-A9V5S("AR97%U:7)E<R!(;W)D92`S+C$I+@I;;6US72!2
M96UO=F4@;W5T9&%T960L(&YO;BUS=&%N9&%R9',@<F5Q=65S="!F;W(@9&5L
M:79E<GD@8V]N9FER;6%T:6]N+@I;;6US72!(:61E(&QE;F=T:'D@861D<F5S
M<R!L:7-T<R!B>2!D969A=6QT(&EN(&UE<W-A9V4@=FEE=R!A;F0@86QL;W<@
M=&AE('5S97(*("`@("`@=&\@=&]G9VQE('9I97=I;F<@*&9L86-H87!E;&QE
M0&EN=F5R<V4N8V$L($)U9R`C,S`R."DN"EMC:FA=($%C8V]U;G0@9F]R(&-H
M86YG97,@=&\@<W1R=&]T:6UE*"D@:6X@4$A0(#4N,2X*6VUM<UT@270@:7,@
M;F]T('!O<W-I8FQE('1O(&AI9&4@9&5L971E9"!M97-S86=E<R!W:&5N('5S
M:6YG('1H<F5A9"!S;W)T+@I;;6US72!/<'1I;VX@=&\@<V5N9"!N;W1I9FEC
M871I;VX@=&AA="!L:6YK960@871T86-H;65N="!H87,@8F5E;B!D;W=N;&]A
M9&5D+`H@("`@("!A;F0@;&EN:R!T;R!D96QE=&4@=&AE(&%T=&%C:&UE;G0@
M*$)U9R`C-CDV*2X*6VUM<UT@069T97(@9F5T8VAI;F<@;6%I;"P@<F5T=7)N
M('1O('1H92!L;V-A;"!M86EL8F]X('=H97)E(&UA:6P@:7,*("`@("`@9&]W
M;FQO861E9"!T;R`H0G5G(",R,C$Q*2X*6VUM<UT@0VAE8VL@=&AE($E-05`@
M<V5R=F5R('1O('-E92!I9B!I="!S=7!P;W)T<R!S96%R8VAE<R!I;B!T:&4@
M8W5R<F5N=`H@("`@("!C:&%R<V5T+@I;;6US72!$;R!N;W0@<F5Q=6ER92!U
M<V5R<R!T;R!C;&EC:R!O;B`G071T86-H)R!B=71T;VX@=VAE;B!A='1A8VAI
M;F<@9FEL97,*("`@("`@:6X@=&AE(&-O;7!O<V4@<V-R965N("A"=6<@(S(X
M-#@I+@I;;6US72!$;VXG="!D:7-P;&%Y('5N<W5B<V-R:6)E9"!F;VQD97)S
M(&EN('-I9&5B87(@*$)U9R`C,C@V.2DN"EMM;7-=(%)E;F%M92!F;VQD97)S
M(&9R;VT@=&]P(&]F('1R964@=&\@8F]T=&]M('1O('!R979E;G0@97)R;W)S
M(&]N($E-05`*("`@("`@<V5R=F5R<R!T:&%T(&%U=&]M871I8V%L;'D@<F5N
M86UE(&%L;"!C:&EL9"!F;VQD97)S("A"=6<@(S(X.#(I+@I;;6US72!&:7@@
M;W!E;FEN9R!C;VUP;W-E('!O<'5P<R!W:&5N('1H92!M86EL8F]X(&-O;G1A
M:6YS('5R;&5N8V]D960*("`@("`@8VAA<F%C=&5R<R`H0G5G(",R.#<R*2X*
M6VUM<UT@1FEX(')E9G)E<V@@;V8@9F]L9&5R<R!W:&5N(&YO="!U<VEN9R!)
M34%0('-U8G-C<FEP=&EO;G,@*$)U9R`C,C@W."DN"EMC:FA=(%-K:7`@<F5S
M=6QT<R!W:71H(&5M<'1Y(&5M86EL(&%D9')E<W-E<R!W:&5N(&5X<&%N9&EN
M9R!N86UE<PH@("`@("`H0G5G(",R-S4W*2X*6V-J:%T@4F5P;&%C92`E=2!W
M:71H('1H92!C=7)R96YT('5S97)N86UE(&EN('-P86T@<F5P;W)T:6YG('-H
M96QL(&-A;&QS"B`@("`@("A$;6ET<FEY($UI:W-)<B`\;6EK<VER0&UA:V5R
M+G)U/BDN"EMM;7-=($1O;B=T(&%S:R!F;W(@<&%S<W=O<F0@9F]R(&1E8W)Y
M<'1I;VX@=VAE;B!T:&4@=7-E<B!D;V5S(&YO="!H879E(&$*("`@("`@<&5R
M<V]N86P@<')I=F%T92!K97D@*$)U9R`C,C<W,2DN"EMM;7-=($%D9"!!4$D@
M;65T:&]D('1O(')E='5R;B!L;V=G960@:6X@<V5R=F5R(&AO<W1N86UE+@I;
M;6US72!01U`@96YC<GEP=&5D(&UE<W-A9V5S(&YO=R!E;F-R>7!T960@=&\@
M86QL(')E8VEP:65N=',@:6X@=&AE('-A;64*("`@("`@;65S<V%G92`H0G5G
M(",R-C<P*2`H<F5Q=6ER97,@2&]R9&4@,RXQ*2X*6VUM<UT@061D960@<')E
M9F5R96YC92!T;R!D969I;F4@=&AE(&1E9F%U;'0@<V5A<F-H(&9I96QD("A"
M=6<@(S(V-3`I+@I;:F%N72!!9&0@86)I;&ET>2!T;R!C<F5A=&4@;F]T97,@
M9G)O;2!E;6%I;"!M97-S86=E<RX*6VIM9ET@061D('-U<'!O<G0@9F]R(&-H
M86YG:6YG(%--5%`@<V5R=F5R+W!O<G0@;VX@;&]G:6X@*$)U9R`C,S(W*2X*
M6VUM<UT@4F5M;W9E9"`G9F]L9&5R<R<L("=N86UE<W!A8V4L(&%N9"`G:&EE
M<F%R8VAI97,G('-E<G9E<B!P87)A;65T97)S+@I;;6US72!!9&0@875T;RUD
M971E8W1I;VX@;V8@;F%M97-P86-E(&EN9F]R;6%T:6]N(&9R;VT@24U!4"!S
M97)V97(N"EMC:FA=(%-U<'!O<G0@8V]N9FEG=7)I;F<@=VAE<F4@=&AE(")2
M97!O<G0@87,B('-P86TO:6YN;V-E;G0@;&EN:W,@87!P96%R"B`@("`@("AD
M=7-T:6Y`>7=L8W,N;W)G+"!"=6<@(S$P.38I+@I;;6US72!!9&0@<')E9F5R
M96YC92!T;R!M;W9E('-P86TO:6YN;V-E;G0@;65S<V%G97,@=&\@87!P<F]P
M<FEA=&4@;6%I;&)O>`H@("`@("!A9G1E<B!R97!O<G1I;F<N"EMM;7-=($%D
M9"!M=6QT:7!L92!M97-S86=E('9I97<@<&%G92`H0G5G(",T.#$I+@I;:F%N
M72!!9&0@<W1A=&EO;F5R>2!A;F0@9F]R;2!R97-P;VYS97,N"EMC:FA=($1I
M9F9E<F5N=&EA=&4@8F5T=V5E;B!S:6=N960@86YD(&5N8W)Y<'1E9"!A='1A
M8VAM96YT<R`H0G5G(",Q-S$R*2X*6VIM9ET@06)I;&ET>2!T;R!P;&%Y('-O
M=6YD(&]N(&YE=R!M86EL+@I;:F%N72!!9&0@<&5R;6ES<VEO;G,@=&\@<F5S
M=')I8W0@8W)E871I;VX@;V8@9F]L9&5R<RX*6VUM<UT@061D(&-O;F9I9W5R
M871I;VX@;W!T:6]N('1O(&%L;&]W(&UE<W-A9V4@8F]D:65S('1O(&)E(&-A
M8VAE9"!A8W)O<W,*("`@("`@<&%G92!L;V%D<RX*6V)E;ET@2&]N;W(@:&]R
M9&4G<R!A;'1E<FYA=&5?;&]G:6X@86YD(')E9&ER96-T7V]N7VQO9V]U="!S
M971T:6YG<RX*6VIA;ET@061D(")%;7!T>2!3<&%M(B!M96YU(&ET96T@*$)U
M9R`C,3<V-2P@:F5N<T!P96EN;RYD92DN"EMM;7-=($%D9"!6:7)T=6%L($E.
M0D]8('1O(%9I<G1U86P@1F]L9&5R<RX*6VUM<UT@36%K92!S=7)E('-P96-I
M86P@5FER='5A;"!&;VQD97)S(&-A;B!N979E<B!B92!E9&ET960N"EMM;7-=
M($%L;&]W(&EM<&]R="!O9B!P:&]T;R!A='1A8VAM96YT<R!I;G1O(&$@9V%L
M;&5R>2!A<'!L:6-A=&EO;BX*6VUM<UT@1FEX($E-05`@=&AR96%D(&1I<W!L
M87D@=VAE;B!T:&4@8F%S92!L979E;"!C;VYT86EN<R!M;W)E('1H86X@;VYE
M"B`@("`@(&UE<W-A9V4N"EMM;7-=($)E='1E<B]M;W)E(&-O;7!L971E('!R
M979I97<@;65S<V%G92!G96YE<F%T:6]N+@I;;6US72!'<F%P:&EC86P@<F5P
M<F5S96YT871I;VX@;V8@=&AR96%D(&]N('1H<F5A9"!V:65W('-C<F5E;BX*
M6VUM<UT@5FER='5A;"!4<F%S:"!F;VQD97(@<W5P<&]R="`H5&]D9"!-97)R
M:71T(#QT;65R<FET=$!E;6%I;"YA<FEZ;VYA+F5D=3XI+@I;;6US72!!;&P@
M8V]M<&]S960@;65S<V%G97,@87)E(&YO=R!S96YT(&EN(")F;&]W960B(&9O
M<FUA="X@5&AE(")W<F%P7W=I9'1H(@H@("`@("!P<F5F97)E;F-E(&AA<R!B
M965N(&5L:6UI;F%T960N"EMM;7-=(%-U8V-E<W,@;65S<V%G97,@87)E(&YO
M="!S:&]W;B!W:&5N(&%D9&EN9R!A(&)L86-K;&ES="]W:&ET96QI<W0@861D
M<F5S<PH@("`@("!I9B!A;B!E<G)O<B!I;B!A9&1I;F<@=&AE(&%D9')E<W,H
M97,I(&]C8W5R<F5D+@I;;6US72!.;R!N965D('1O('-H;W<@82`B2&ED92!(
M5$U,(&EM86=E<R(@;&EN:R!I9B!T:&4@:6UA9V5S(&AA=F4@86QR96%D>0H@
M("`@("!B965N(&1I<W!L87EE9"X*6VUM<UT@26YC;'5D92!#8SH@:&5A9&5R
M(&EN9F]R;6%T:6]N(&EN('1H92!H96%D97(@=&5X="!W92!D:7-P;&%Y(&9O
M<B!F;W)W87)D"B`@("`@(&%N9"!R97!L>2!M97-S86=E<R`H0G5G(",Q,#<Y
M*2X*6VIA;ET@4VAO=R!:25`@:6-O;B!W:71H(")$;W=N;&]A9"!A;&P@871T
M86-H;65N=',B(&QI;FLN"EMM;7-=(%,O34E-12!P87)T<R!S:&]U;&0@86QW
M87ES(&%T=&5M<'0@=&\@8F4@=FEE=V5D(&EN;&EN92P@;F]T=VET:'-T86YD
M:6YG"B`@("`@('1H92!#;VYT96YT+41I<W!O<VET:6]N(&9O<B!T:&4@<&%R
M="`H<F5Q=6ER97,@2&]R9&4@,RXQ*2X*"@HM+2TM+2T*=C0N,"XT"BTM+2TM
M+0H*6VUM<UT@061D('=A<FYI;F<@=&AA="!01U`@:V5Y(&=E;F5R871I;VX@
M;6%Y('1A:V4@87=H:6QE("A"=6<@(S(V-S(I+@I;;6%S72!!9&0@8V]N9FER
M;6%T:6]N('=H96X@<F5P;W)T:6YG('-P86TO:6YN;V-E;G0@9G)O;2!M97-S
M86=E('9I97<N"B`@("`@("AK979I;E]M>65R0&EU,3,N;W)G+"!"=6<@(S(R
M.#4I"EMC:FA=($9I>"!C:&5C:R!F;W(@9'5P;&EC871E(&%D9')E<W-E<R!W
M:&5N(&%U=&]M871I8V%L;'D@<V%V:6YG"B`@("`@(')E8VEP:65N=',@*$)U
M9R`C,C8V,RDN"@H*+2TM+2TM+2TM+0IV-"XP+C0M4D,R"BTM+2TM+2TM+2T*
M"EMM;7-=($9I>"!A9&1I=&EO;F%L(&YE=VQI;F5S(&)E:6YG(&%D9&5D('1O
M(&9O<G=A<F1E9"!M97-S86=E<R!W:&5N('5S:6YG"B`@("`@('-E;F1M86EL
M(&]N("I.25@@*$)U9R`C,C0T.2P@="YZ96QL0&=M>"YD92DN"EMM;7-=($9I
M>"!"0T,@861D<F5S<V5S<R!D:7-A<'!E87)I;F<@=VAE;B!R97-U;6EN9R!A
M(&UE<W-A9V4@*$)U9R`C,C4U."DN"EMM87-=($9I>"!R97!O<G1I;F<@;75L
M=&EP;&4@;65S<V%G97,@87,@<W!A;2!A="!O;F-E+@H@("`@("`H:&]R9&4N
M;W)G0'-P86UV<FEJ+FMI8VMS+6%S<RYO<F<L($)U9R`C,C4T.2D*6VUM<UT@
M061D(&5N=&ER92!M97-S86=E('-E87)C:"!T;R!S96%R8V@@<&%G92X*6VIA
M;ET@1FEX('=A<FYI;F=S(&EF(&5X<&%N9&EN9R!N86UE<R!W:71H('-P86-E
M<R`H0G5G(",R,S,T*2X*6VUM<UT@1&]N)W0@9&ES<&QA>2!B;V1Y('1E>'0@
M:6X@=&AR96%D('9I97<@:68@:6YL:6YE('9I97=I;F<@;V8@=&AE(&-O;G1E
M;G0*("`@("`@:7,@9&ES86)L960N"EMJ=VU=(%)E;F%M960@06-C;W5N=',@
M;65N=2!I=&5M('1O($9E=&-H($UA:6P@9F]R(&UO<F4@8V]N<VES=&5N8WDN
M"@H*+2TM+2TM+2TM+0IV-"XP+C0M4D,Q"BTM+2TM+2TM+2T*"EMJ86Y=($1E
M8V]D92!F;VQD97(@;F%M92!W:&5N(&EM<&]R=&EN9R!M97-S86=E<R`H9&1I
M8F]X0&UA:6PN<G4L($)U9R`C,C0W.2DN"EMJ86Y=(%-E;F0@:51I<"!R97!L
M:65S('=I=&@@=&AE(&-O<G)E8W0@:61E;G1I='D@*$)U9R`C,34P-RDN"EMJ
M86Y=($YA;64@9&]W;FQO861E9"!:25`@9FEL92!W:71H(&%L;"!A='1A8VAM
M96YT<R!A9G1E<B!T:&4@;65S<V%G92!S=6)J96-T+@I;:F%N72!!;&QO=R!T
M;R!A8V-E<'0@:6YV:71A=&EO;G,@86YD(&%D9"!T:&5M('1O('1H92!C86QE
M;F1A<B!A="!O;F-E+@I;:F%N72!3:&]W(&E4:7`@871T86-H;65N=',@*&5V
M96YT(&EN=FET871I;VYS*2!I;FQI;F4@*%)E<75E<W0@(S(P,S(I+@I;;6US
M72!&:7@@9&ES<&QA>2!O9B!L;V-A;&EZ960@24Y"3U@@;F%M92!I;B!F;VQD
M97(@;&ES="]S:61E8F%R("A"=6<@(S(S-C@I+@I;;6US72!&:7@@9&ES<&QA
M>2!O9B!L:6YK960@871T86-H;65N=',@=VAE;B!T:&4@871T86-H;65N="!F
M:6QE;F%M92!C;VYT86EN<PH@("`@("!C:&%R86-T97)S('1H870@;F5E9"!T
M;R!B92!E<V-A<&5D+@I;;6US72!&:7@@3U(@<V5A<F-H97,@=VAE;B!U<V5R
M(&ES(&AI9&EN9R!D96QE=&5D(&UE<W-A9V5S+@I;;6US72!3879E(&1R869T
M<R!S;R!A;GD@:6UA9V5S(&%D9&5D('9I82!T:&4@2%1-3"!E9&ET;W(@=VEL
M;"!C;W)R96-T;'D*("`@("`@<F5A<'!E87(@=VAE;B!T:&4@;65S<V%G92!I
M<R!R97-U;65D("A"=6<@(S$Y-S<I+@I;;6US72!!;&QO=R!(5$U,(&9O<FUA
M='1I;F<@=&\@8F4@<F5T86EN960@=VAE;B!R97-U;6EN9R!A(&1R869T("A"
M=6<@(S(S,C@I+@I;;6US72!7;W)K(&%R;W5N9"!B<F]K96X@8RUC;&EE;G0@
M<V]R="!B>2!A<G)I=F%L+B!4=7)N<R!O=70@=&\@8F4@;6]R90H@("`@("!E
M9F9I8VEE;G0@86YY=V%Y("A"=6<@(S(Q,SDI+@I;:F%N72!!9&0@0F]S;FEA
M;B!T<F%N<VQA=&EO;B`H5F5D<F%N($QJ=6)O=FEC(#QV;&IU8F]V:6-`<VUA
M<G1N970N8F$^*2X*6VUM<UT@268@=7-E<B!S96QE8W1S(&$@;F]N+61E9F%U
M;'0@<V5N=&UA:6P@9F]L9&5R(&]N('1H92!C;VUP;W-E('-C<F5E;BP@;6%K
M90H@("`@("!S=7)E('1H:7,@:7,@<V%V960@=&AR;W5G:"!A;GD@:6YT97)V
M96YI;F<@<W!E;&QI;F<@8VAE8VL@*$)U9R`C,C`Y,RDN"EMM;7-=($5N<W5R
M92!T:&%T(&YO(&UA:6YT96YA;F-E('1A<VMS(&UA>2!B92!S:VEP<&5D("A"
M=6<@(S$Y,C8I+@I;;6%S72!0<F]T96-T(&%G86EN<W0@<W!E8VEA;"!C:&%R
M86-T97)S(&%T('1H92!B96=I;FYI;F<@;V8@82!L:6YE('=H96X@=7-I;F<*
M("`@("`@87-P96QL+B`H0G5G(",R,#8P*0I;8VIH72!'96YE<F%T92!O;FQY
M(&]N92!396QE8W0@06QL(&-H96-K8F]X(&]N('-E87)C:"!R97-U;'1S(&QI
M<W1I;F=S"B`@("`@('-P86YN:6YG(&UU;'1I<&QE(&UA:6QB;WAE<R`H0G5G
M(",Q.3DQ*2X*6VIA;ET@0FQO8VL@96UB961D960@:6UA9V5S(&EF('9I97=I
M;F<@2%1-3"!M97-S86=E<R!I;B!A('!O<'5P+@I;8VIH72!$;VXG="!L;W-E
M(&EN8V]M<&QE=&4@861D<F5S<V5S(&%F=&5R(&5X<&%N<VEO;B!I<R!A='1E
M;7!T960N"B`@("`@("A"=6<@(S$Y,#`I+@I;:F%N72!&:7@@8F%C:V=R;W5N
M9"!E>'!A;G-I;VX@;V8@;F]N+6%S8VEI(&YA;65S(&EN(&-O;7!O<V4@=FEE
M=R`H0G5G(",Q-3<U*2X*6VIA;ET@06QL;W<@;F]N+6%S8VEI('-E87)C:&5S
M("AR97%U:7)E<R!(;W)D92`S+C`N-2DN"EMM;7-=($1O;B=T('!A<W,@<V5R
M=F5R(&EN9F]R;6%T:6]N('9I82!L;V=I;B!P86=E(&EF(&YO="!B96EN9R!A
M;'1E<F5D(&)Y"B`@("`@('1H92!U<V5R+B`H0G5G(",Q.#@S*0I;;6US72!!
M9&0@<V5P87)A=&4@8V]N9FER;6%T:6]N('!A9V4@=VAE;B!D96QE=&EN9R]E
M;7!T>6EN9R!F;VQD97)S("A"=6<@(S<X,RDN"EMC:FA=($%L;&]W('-E;F1I
M;F<@8FQA;FL@<V5A<F-H97,@=&\@5'5R8F$@979E;B!I9B!T:&4@9&ES<&QA
M>5]C;VYT86-T"B`@("`@('!R969E<F5N8V4@:7,@9F%L<V4@*$)U9R`C,3@U
M-"DN"EMM;7-=($5N8V]D92!A='1A8VAM96YT('!A<F%M971E<G,@=VET:"!T
M:&4@<V%M92!C:&%R86-T97(@<V5T('5S960@:6X@=&AE"B`@("`@(&)A<V4@
M;65S<V%G92`H0G5G(",Q-3DQ*2X*6VUM<UT@1&]N)W0@86QL;W<@=7-E<B!T
M;R!U;G-U8G-C<FEB92!F<F]M($E.0D]8+@I;;6US72!$;VXG="!A;'1E<B!H
M96%D97(@96YC;V1I;F=S('=H96X@<F5D:7)E8W1I;F<@;65S<V%G97,@*$)U
M9R`C,3@R,RDN"EMM;7-=($9I>"!C:&%R<V5T(&ES<W5E<R!W:71H('-T<FEP
M(&%T=&%C:&UE;G0@;65S<V%G92`H0G5G(",Q.#8Q*2X*6V-J:%T@061D(&UI
M<W-I;F<@8FEN87)Y+G!N9R!F;W(@=&AE(%1.148@34E-12!6:65W97(@*$)U
M9R`C,3@W,RDN"EMJ86Y=($QO8V%L:7IE(&%L;"!R96UA:6YI;F<@24Y"3U@@
M<W1R:6YG<R!I;B!T:&4@:6YT97)F86-E+@I;;6US72!&:7@@9')O<"!D;W=N
M(&QI<W1S(&EN(&9O;&1E<B!P<F5F97)E;F-E<R`H0G5G(",Q-SDT*2X*6VIA
M;ET@1FEX(&-O;7!O<V4@;&EN:W,@=VET:"!N;VXM87-C:6D@8VAA<F%C=&5R
M<R!I;B!E;6%I;"!H96%D97(@;&EN:W,@;VX*("`@("`@26YT97)N970@17AP
M;&]R97(@*$)U9R`C,3<R-BDN"EMM;7-=($EG;F]R92!E;7!T>2!L:6YE<R!I
M;B!C;VYF:6<O:&5A9&5R+G1X="`H0G5G(",Q-S<P*2X*6V-J:%T@1&]N)W0@
M=')I9V=E<B!T:&4@;&5F="]R:6=H="!K97D@;65S<V%G92!N879I9V%T:6]N
M(&EF('1H92!U<V5R(&ES"B`@("`@(&AO;&1I;F<@9&]W;B!A;GD@;6]D:69I
M97(@:V5Y<R`M(&QE="!T:&]S92!B=6)B;&4@=7`@=&\@=&AE(&)R;W=S97(*
M("`@("`@*$)U9R`C,3<V,RDN"EMC:FA=($]N;'D@=7-E(&$@4F5F<F5S:#H@
M:&5A9&5R(&EF('=E(&YE960@=&\L(&%N9"!I9B!T:&4@55),(&ES('5N9&5R
M(#$V,`H@("`@("!C:&%R86-T97)S+"!T;R!P<F5V96YT('1R:6=G97)I;F<@
M8G)O=W-E<B!B=6=S('1H870@8V%U<V4@:&%N9W,*("`@("`@*$)U9R`C,3<R
M."DN"EMC:FA=(%!R979E;G0@244@9G)O;2!C;&5A<FEN9R!C;VUP;W-E('=I
M;F1O=R!F:65L9',@:68@=&AE('5S97(@<')E<W-E<PH@("`@("!%4T,@*$)U
M9R`C,38X-BDN"@H*+2TM+2TM"G8T+C`N,PHM+2TM+2T*"EMJ86Y=($EG;F]R
M92!Q=6]T960@=&5X="!I9B!S<&5L;&-H96-K:6YG('=I=&@@87-P96QL("A"
M=6<@(S$V-S,L"B`@("`@(&ME=FEN7VUY97)`:74Q,RYO<F<I+@I;8VIH72!&
M:7@@='EP;R!I;B!A='1A8VAM96YT+G!H<"!T:&%T(&-A=7-E9"!A(%!(4"!W
M87)N:6YG"B`@("`@("A8879I97(@36]N=&%G=71E;&QI(#QX879I97(N;6]N
M=&%G=71E;&QI0'5N:6QI;2YF<CXI+@I;;6US72!#;W)R96-T;'D@<W1O<F4@
M86QL(&1A=&$@9G)O;2!T:&4@8V]M<&]S92!S8W)E96X@=VAE;B!S<&5L;"!C
M:&5C:VEN9R!A"B`@("`@(&UE<W-A9V4@*$)U9R`C,30R-2DN"@H*+2TM+2TM
M+2TM+0IV-"XP+C,M4D,Q"BTM+2TM+2TM+2T*"EMC:FA=(%9A;&ED871E(&]U
M=&=O:6YG(&5M86EL(&%D9')E<W-E<R!B969O<F4@<V5N9&EN9R!M86EL("A"
M=6<@(S$U-#,I+@I;;6US72!!9&1E9"!A=71O;6%T:6,@9&5T96-T:6]N(&]F
M('-O;64@;6%I;"!S97)V97(@<&%R86UE=&5R<R!T;R!T:&4@=&5S=`H@("`@
M("!S8W)I<'0N"EMM;7-=($9I>"!3:&]W+TAI9&4@1&5L971E9"!L:6YK<R!O
M;B!S96%R8V@@<F5S=6QT<R!S8W)E96X@*$)U9R`C,34X-RDN"EMM;7-=($-O
M<G)E8W1L>2!P<F]C97-S("=297!O<G0@86YD(%-P86TG(&%N9"!";&%C:VQI
M<W0O5VAI=&5L:7-T(&%D9&ET:6]N<PH@("`@("!F<F]M(&$@<V5A<F-H(')E
M<W5L=',@;6%I;&)O>"!V:65W+@I;;6US72!#;W)R96-T;'D@<V]R="!T:&4@
M8V]N=&5N=',@;V8@=&AE(%9I<G1U86P@1F]L9&5R+@I;;6US72!&:7@@=FEE
M=VEN9R!M86EL8F]X97,@:6X@<VAA<F5D(&AI97)A<F-H:65S(&EN('-U8G-C
M<FEB92!M;V1E(&EN('1H90H@("`@("!)34%07U1R964@;&ES=',@*$)U9R`C
M,34U,"DN"EMJ86Y=(%)E='5R;B!T;R!C=7)R96YT(&9O;&1E<B!A9G1E<B!E
M;7!T>6EN9R!T:&4@=')A<V@@9F]L9&5R("A"=6<@(S$U-C,I+@I;;6US72!$
M:7-P;&%Y('1H92!A='1A8VAM96YT(&5X<&ER871I;VX@9&%T92!W:&5N('-E
M;F1I;F<@;&EN:V5D(&%T=&%C:&UE;G1S+@I;;6US72!&:7@@961I=&EN9R!V
M:7)T=6%L(&9O;&1E<G,@9G)O;2!T:&4@;6%I;&)O>"!S8W)E96X@*$)U9R`C
M,30Y,"DN"EMC:FA=($QO9R!L;V=O=71S(&%T('1H92!S86UE(&QE=F5L($AO
M<F1E(&1O97,@*$)U9R`C,30Y.2DN"EMJ86Y=($1O;B=T(&QO<V4@<V5S<VEO
M;B!I9B!C;&EC:VEN9R!O;B!L:6YK(&%F=&5R(&)L86-K;&ES=&EN9R!O<@H@
M("`@("!W:&ET96QI<W1I;F<@861D<F5S<V5S("A"=6<@(S$T,3<I+@I;;6US
M72!&:7@@<F5F<F5S:"!O9B!F;VQD97(@<V-R965N('=H96X@=FEE=VEN9R!U
M;G-U8G-C<FEB960@9F]L9&5R<RX*6VUM<UT@061D960@;W!T:6]N86P@)V1E
M;&EM:71E<B<@<&%R86UE=&5R('1O('-E<G9E<G,N<&AP('1O(&%I9"!L;V=I
M;B!T:6UE<PH@("`@("!F;W(@8V5R=&%I;B!)34%0('-E<G9E<G,@*'-E;'-K
M>4!C;VQU;6)I82YE9'4L($)U9R`C,30X-2DN"EMM;7-=($1O;B=T(&QI;FL@
M96UA:6QS(&EN($A434P@;65S<V%G92!C;VUP;W-I=&EO;G,@*$)U9R`C,30W
M,BDN"EMM;7-=($UA:V4@<W5R92!W92!C86X@8W)E871E('1H=6UB;F%I;',O
M8V]N=F5R="!I;6%G97,@8F5F;W)E('!R;VUP=&EN9R!U<V5R+@I;;6US72!%
M;G-U<F4@;75L=&EP87)T+W)E;&%T960@86YD(&UU;'1I<&%R="]A;'1E<FYA
M=&EV92!M97-S86=E<R!C86X@8F4@=FEE=V5D"B`@("`@(&EF(&YO="!V:65W
M86)L92!I;FQI;F4@;W(@:68@=&AE>2!C;VYT86EN(&]N;'D@;VYE('!A<G0[
M"B`@("`@(&UU;'1I<&%R="]R96QA=&5D('!A<G1S(&%R92!N;W<@=FEE=V5D
M('=I=&@@=&AE:7(@8V]R<F5C="!C:&%R<V5T"B`@("`@("A"=6<@(S$T,S,I
M+@I;;6US72!&:7@@9&ES<&QA>2!O9B!)34%0(&AI97)A<F-H:65S(&EN('1H
M92!F;VQD97(@=FEE=R`H0G5G(",Q-#`S*2X*6VIA;ET@1FEX('9I97=I;F<@
M;V8@;75L=&EP87)T(%,O34E-12!O<B!01U`@<VEG;F5D(&UE<W-A9V5S("A"
M=6<@(S$S.3,I+@I;:F%N72!-87)K('-E;G0M;6%I;"!C:&5C:V)O>"!W:&5N
M(&-H86YG:6YG('1H92!S96YT+6UA:6P@9F]L9&5R(&EN('1H90H@("`@("!C
M;VUP;W-E('-C<F5E;BX*6VUM<UT@0F4@<VUA<G1E<B!A8F]U="!W92!W92!C
M;VYS:61E<B!T;R!B92!D;W=N;&]A9&%B;&4O9F]R=V%R9&%B;&4N"B`@("`@
M($UA:V4@<W5R92!T97AT(&ES;B=T(&)O=&@@9F]R=V%R9&5D(&%N9"!A='1A
M8VAE9"!I;B!A(&9O<G=A<F0@;65S<V%G92X*6VIA;ET@1FEX('-U8V-E<W,@
M<V-R965N(&%F=&5R(')E9&ER96-T:6YG(&$@;65S<V%G92`H0G5G(",Q,S<T
M*2X*6VIA;ET@1FEX(")U;F1E9FEN960@:6YD97@B('=A<FYI;F<@*$)U9R`C
M,3,V-RDN"@H*+2TM+2TM"G8T+C`N,@HM+2TM+2T*"EMM;7-=($1O;B=T('=R
M87`@9FQO=V5D('1E>'0@:6X@<')I;G0@=FEE=R`H0G5G(",Q,S$X*2X*6VIA
M;ET@1&]N)W0@87!P96YD('1R86EL97(@=&5X="!T=VEC92!I9B!S96YD:6YG
M(&$@;65S<V%G92!R97-U;65D(&9R;VT@80H@("`@("!D<F%F="`H0G5G(",Q
M,S`V*2X*6VUM<UT@1FEX(&1I<W!L87D@;V8@871T86-H;65N="!N86UE<R!W
M:&5N(&9O<G=A<F1I;F<@;65S<V%G97,@*$)U9R`C,3,P,"DN"@H*+2TM+2TM
M+2TM+0IV-"XP+C(M4D,Q"BTM+2TM+2TM+2T*"EMM;7-=($1E8V]D92!T:&4@
M8V]N=&5N=',@;V8@<')E=FEE=R!M97-S86=E<RX*6VUM<UT@1FEX(')E;&]A
M9"!O9B!U;F1E<FQY:6YG('=I;F1O=R!A9G1E<B!E;G1E<FEN9R!01U`@;W(@
M4R]-24U%('!A<W-P:')A<V4*("`@("`@*$)U9R`C,3$T-2DN"EMC:FA=($9I
M>"!R96-O;7!O<V4@<F5C;W9E<GD@;V8@;65S<V%G97,@=W)I='1E;B!B969O
M<F4@82!S97-S:6]N('1I;65O=70*("`@("`@*$)U9R`C,3(P.2DN"EMM;7-=
M($1O;B=T(&5S8V%P92`G1G)O;2<@870@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M;&EN92!I;B!T97AT(&UE<W-A9V5S+@I;;6US72!&:7@@)W-M='!H;W-T)R!A
M;F0@)W-M='!P;W)T)R!C;VYF:6=U<F%T:6]N('!A<F%M971E<G,N"EMJ86Y=
M($%D9"!B871C:$-O;7!O<V4@05!)(&UE=&AO9"X*6VUM<UT@1FEX(&$@*'9E
M<GD@<F%R92D@<VET=6%T:6]N('=H97)E(&$@8F%S938T(&5N8V]D960@;65S
M<V%G92!I<R!N;W0@9&5C;V1E9`H@("`@("!C;W)R96-T;'D@:6X@9F]R=V%R
M9',O<F5P;&EE<R`H0G5G(",Q,#<W*2X*6VUM<UT@1FEX(&9O<G=A<F1I;F<@
M87,@82!D:6=E<W0@9G)O;2!S96%R8V@@9F]L9&5R<R`H0G5G(",Q,C8S*2X*
M6V-J:%T@1FEX(%!(4"!N;W1I8V4@869T97(@9F]R=V%R9&EN9R!A(&UE<W-A
M9V4@*$)U9R`C,3(X,RDN"EMM;7-=(%-H;W<L(&)U="!D;VXG="!A8W1I=F%T
M92!C=7)R96YT(&9O;&1E<B!I;B`B36]V92]#;W!Y(%1O(B!F;VQD97(@;&ES
M=`H@("`@("`H0G5G(",Q,C0P*2X*6VUM<UT@36%K92!S=7)E('=E('-H;W<@
M8V]N=&%I;F5R(&9O;&1E<G,@:6X@=&AE('-E87)C:"!S8W)E96X@9F]L9&5R
M(&QI<W0N"EMM;7-=($1O;B=T('-H;W<@861D<F5S<R!B;V]K('-A=F4@;&EN
M:R!F;W(@4$=0(&%N9"!3+TU)344@:V5Y<R!I9B!N;R!D969A=6QT"B`@("`@
M(&%D9')E<W,@8F]O:R!I<R!C;VYF:6=U<F5D("A"=6<@(S$Q-#0I+@I;;6US
M72!297%U:7)E('9I<G1U86P@9F]L9&5R<R!T;R!H879E(&$@;&%B96P@*$)U
M9R`C,3$V,"DN"EMJ86Y=(%-P965D('5P(&UA:6QB;W@@;&]A9&EN9R!B>2!C
M86-H:6YG('!R;V-E<W-E9"!E;6%I;"!A9&1R97-S97,N"EMJ86Y=($9I>"!N
M97<@;6%I;"!N;W1I9FEC871I;VX@<&]P=7!S(&EN(&UA:6QB;W@@=FEE=W,@
M*$)U9R`C.#<V*2X*6VIA;ET@1FEX(&-U<W1O;5]L;V=I;BYP:'`@97AA;7!L
M92!S8W)I<'0N"EMC:FA=($1O;B=T(&EN<V5R="!E;G1R:65S(&9O<B!E;6%I
M;',@=&AA="!A;')E861Y(&5X:7-T('=H96X@9V%T:&5R:6YG"B`@("`@(&%D
M9')E<W-E<R!F<F]M(&]U=&=O:6YG(&5M86EL<R`H0G5G(",Q,#4T*2X*6VIA
M;ET@1FEX('=R87!P:6YG(&]F(&AE861E<B!I;B!M86EL8F]X('9I97<@=VET
M:"!)12`H0G5G(",Q,3$P*2X*"@HM+2TM+2T*=C0N,"XQ"BTM+2TM+0H*6V-J
M:%T@1FEX(&-O;'5M;G,@<G5N;FEN9R!I;B!T;R!E86-H(&]T:&5R('=I=&@@
M4V%F87)I+TM(5$U,(&EN('1H92!M86EL8F]X"B`@("`@('9I97<@*')E<75I
M<F5S($AO<F1E(#,N,"XQ*2`H0G5G(",Q,#(V*2X*6VUM<UT@06QL;W<@<VEG
M;F5D(&UE<W-A9V5S('-E;G0@=FEA(&UU;'1I<&%R="]E;F-R>7!T960@=&\@
M8F4@9&ES<&QA>65D(&]N(&YO;@H@("`@("!3+TU)344@96YA8FQE9"!I;G-T
M86QL871I;VYS("A"=6<@(S$P,S<I+@I;8VIH72!&:7@@9F]R(&QO9VEN7V-O
M;7!O<V4@=VAE;B!)35`@9&]E<R!N;W0@<')O=FED92!A=71H96YT:6-A=&EO
M;@H@("`@("`H0G5G(",X.3(I+@H*"BTM+2T*=C0N,`HM+2TM"@I;;6US72!-
M97-S86=E<R!S96YT(&EN($A434P@9F]R;6%T(&YO(&QO;F=E<B!L:6YK(&5M
M86EL(&%D9')E<W-E<R!T;PH@("`@("!N;VXM97AI<W1A;G0@:F%V87-C<FEP
M="!C86QL<RX*6VIA;ET@57-E('-H;W)T+"!I;F1E;G1E9"!F;VQD97(@;F%M
M97,@:6X@<V5A<F-H(&9O<FTN"EMJ86Y=(%)E='5R;B!T;R!C;W)R96-T(&UA
M:6QB;W@@<&%G92!W:&5N(&-L:6-K:6YG(")"86-K('1O(B!L:6YK(&EN('1H
M<F5A9&5D"B`@("`@('9I97<N"EMJ86Y=($9I>"!S;W)T:6YG(&]F(&9O;&1E
M<B!N86UE<R!I;B!S=6UM87)Y(&)L;V-K("A"=6<@(SDX-RDN"EMM;7-=($1E
M=&5R;6EN92!T:&4@9&5F875L="!)34%0(&1E;&EM:71E<B!A8V-O<F1I;F<@
M=&\@4D9#(#,U,#$N"EMM;7-=($%D9&5D("=S;71P<&]R="<@<&%R86UE=&5R
M('1O('-E<G9E<B!C;VYF:6=U<F%T:6]N("AB97)G;VYZ0&QA8G,N:70I+@I;
M:F%N72!#;W)R96-T;'D@=W)A<"!Q=6]T960@:&5A9&5R<R!I;B!M97-S86=E
M(')E<&QI97,@*$)U9R`C.38R*2X*6VIA;ET@4VAO=R!B=71T;VYS(&]N(")M
M97-S86=E('-E;G0B('-C<F5E;B!A<R!M96YU(&%G86EN+@H*"BTM+2TM+2TM
M"G8T+C`M4D,S"BTM+2TM+2TM"@I;:F%N72!&:7@@;&EN:R!G96YE<F%T:6]N
M(&EN($A434P@8V]M<&]S97(@*$)U9R`C.30Q*2X*6V-J:%T@06QW87ES(&AO
M;F]R('1H92!L;V=I;E]C;VUP;W-E(&%C=&EO;B`H0G5G(",X.3(I+@I;8VIH
M72!3879E(&UE<W-A9V5S('=I=&@@82`B;65S<V%G92]R9F,X,C(B(&UI;64@
M='EP92`H0G5G(",Y,C(I+@I;;6US72!$;VXG="!R97%U:7)E('1O(&-O;F9I
M9W5R92!A;B!E+6UA:6P@861D<F5S<R!I9B!U<VEN9R!A('-P86T@:&]O:RX*
M6VUM<UT@1FEX(&5X<&%N<VEO;B!O9B!E+6UA:6P@861D<F5S<V5S("A"=6<@
M(S@X.2DN"EMM;7-=($9I>"!D:7-P;&%Y(&]F('5S97(M9&5F:6YE9"!H96%D
M97)S(&EF('1H92!M97-S86=E(&-O;G1A:6YS(&UO<F4@=&AA;@H@("`@("!O
M;F4@;V8@=&AO<V4@:&5A9&5R<R`H0G5G(",Y,3(I+@I;:F%N72!3970@;VYE
M(&=L;V)A;"!D871E(&9O<FUA="!I;B!(;W)D92=S('!R969E<F5N8V5S("A"
M=6<@(S<X."DN"EMJ86Y=($9I>"!S;VUE(&IA=F%S8W)I<'0@97)R;W)S('=I
M=&@@244@-2XP+@H*"BTM+2TM+2TM"G8T+C`M4D,R"BTM+2TM+2TM"@I;;6US
M72!!;&QO=R!M;W)E('1H86X@;VYE(')E8VEP:65N="!F;W(@96YC<GEP=&5D
M(&UE<W-A9V5S.R!S=&]R92!E;F-R>7!T960*("`@("`@;65S<V%G97,@;&]C
M86QL>2!U<VEN9R!T:&4@;&]C86P@=7-E<B=S(&5N8W)Y<'1I;VX@*$)U9R`C
M.#8U*2X*6VUM<UT@1FEX('9A<FEO=7,@4R]-24U%(&ES<W5E<R!A;F0@=7!D
M871E('1H92!C;V1E('1O(&UO<F4@8VQO<V5L>2!M871C:"!T:&4*("`@("`@
M;&]O:R!A;F0@9F5E;"!O9B!T:&4@4$=0(&-O9&4N"EMJ86Y=($9I>"!A=71O
M;6%T:6,@<W!E;&P@8VAE8VMI;F<@;VX@<V5N9"P@8W5T=&EN9R!O9F8@<&%R
M=',@;V8@=&AE(&UE<W-A9V4*("`@("`@*$)U9W,@(S(R-RP@(S(U.2DN"@H*
M+2TM+2TM+2T*=C0N,"U20S$*+2TM+2TM+2T*"EMJ86Y=($9I>"!(5$U,(&UE
M<W-A9V4@961I=&]R(&EN($E%("A"=6=S(",V.3(L(",W.3,I+@I;8VIH72!3
M96%R8V@@;VYL>2!T:&4@<')E9F5R<F5D(&%D9')E<W,@8F]O:W,@9F]R('-E
M;F1E<G,@86QL;W=E9"!T;R!S96YD($A434P*("`@("`@;65S<V%G97,@=VET
M:"!I;6%G97,N"EMJ86Y=($1I<V%B;&4@2V]L86(@<V5R=F5R<R!I9B!+;VQA
M8B!H87,@8F5E;B!D:7-A8FQE9"!G;&]B86QL>2X*6VUM<UT@06QL;W<@86QL
M('-U8G-C<FEB960@9F]L9&5R<R!T;R!B92!V:65W960@:6X@=&AE($E-4"!M
M96YU('1R964@:6YT97)F86-E+@I;;6US72!/;FQY('-C86X@9F]R(&5M;W1I
M8V]N<R!I;B!T:&4@8F]D>2!O9B!T97AT($U)344@<&%R=',N"EMM;7-=($9I
M>"!M97-S86=E('-A=FEN9R!A;F0@871T86-H;65N="!:25`@9FEL92!G96YE
M<F%T:6]N+@I;;6US72!!;&QO=R!T:&4@<W!A;2!R97!O<G1I;F<@<WES=&5M
M('1O(&)O=6YC92!A(&UE<W-A9V4@=&\@86X@96UA:6P@861D<F5S<RX*6VUM
M<UT@36]V92!S<&%M(&AA;F1L:6YG('1O(&$@<V5P87)A=&4@8VQA<W,N"@H*
M+2TM+2TM+2TM"G8T+C`M0D5400HM+2TM+2TM+2T*"EMM;7-=($%D9&5D('9I
M<G1U86P@9F]L9&5R('-U<'!O<G0N"EMM;7-=($%L;&]W(&%L;"!M97-S86=E
M<R!I;B!A;B!E;G1I<F4@9F]L9&5R('1O(&)E(&UA<FME9"!A<R!S965N(&]R
M('5N<V5E;BX*6VUM<UT@06QL;W<@871T86-H:6YG(&9I;&5S(&9R;VT@;&]C
M86P@5D93(&9I;&5S>7-T96US+@I;;6US72!!;&QO=R!Q=6EC:R!A;F0@96%S
M>2!A8V-E<W,@=&\@=6YS=6)S8W)I8F5D(&9O;&1E<G,@;VX@=&AE('-E87)C
M:`H@("`@("!S8W)E96XN"EMJ86Y=($%D9"!Q=6]T82!D<FEV97(@9F]R($UE
M<F-U<GDO,S(@<V5R=F5R<R`H1G)A;FL@3'5P;PH@("`@("`\9G)A;FM?;'5P
M;T!E;6%I;"YI=#XI+@I;;6US72!!9&0@<W5P<&]R="!F;W(@365S<V%G92!$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VYS("A21D,@,C(Y."DN"EMJ86Y=($1Y
M;F%M:6-A;&QY(&%D9"!N97<@871T86-H;65N="!F:65L9',@:68@86QL(&%R
M92!U<V5D+@I;:F%N72!!9&0@<W!E8VEA;"!B;&%C:RUO;BUW:&ET92!S='EL
M97,@9F]R(&UE<W-A9V4@<')I;G1I;F<N"EMM;7-=($%D9&5D('!R969E<F5N
M8V4@=&AA="!A;&QO=W,@=7-E<B!T;R!S=')I<"!A='1A8VAM96YT(&EN9F]R
M;6%T:6]N(&9O<@H@("`@("!M97-S86=E<R!S879E9"!I;B!T:&4@<V5N="UM
M86EL(&9O;&1E<B!A9G1E<B!C;VUP;W-I;F<@82!M97-S86=E+@I;;6US72!)
M;7!R;W9E(&UE<W-A9V4@=&AR96%D:6YG(&1I<W!L87D@:6X@=&AE(&UA:6QB
M;W@@<V-R965N+@I;:F%N72!!9&0@4&5R<VEA;B`H5V5S=&5R;BD@=')A;G-L
M871I;VX@*%9A:&ED($=H869A<G!O=7(*("`@("`@/'9A:&ED0&=H869A<G!O
M=7(N8V]M/BDN"EMC:FA=($%L;&]W('%U;W1E9"!P87)T<R!O9B!M97-S86=E
M<R!T;R!G970@:&ED9&5N+@I;;6US72!!9&0@;65S<V%G97,@=&AR96%D('9I
M97<N"EMJ86Y=($%L;&]W(&YA=FEG871I;VX@=&AR;W5G:"!M86EL8F]X('!A
M9V5S('=I=&@@;&5F="!A;F0@<FEG:'0@:V5Y<RX*6VIA;ET@06QL;W<@<'5R
M9VEN9R!O9B!M=6QT:7!L92!F;VQD97)S(&EN('1H92!F;VQD97)S('9I97<@
M*%1O9&0@365R<FET=`H@("`@("`\=&UE<G)I='1`96UA:6PN87)I>F]N82YE
M9'4^*2X*6VIA;ET@06QL;W<@='5R;FEN9R!O9F8@;V8@=&AE(&QI;FMS('1O
M(&%L=&5R;F%T:79E('!A<G1S(&EN"B`@("`@(&UU;'1I<&%R="]A;'1E<FYA
M=&EV92!M97-S86=E<RX*6V-J:%T@2&ED92!U;FYE8V5S<V%R>2!522!E;&5M
M96YT<R!W:&5N('1H97)E)W,@;VYL>2!O;F4@861D<F5S<R!B;V]K"B`@("`@
M("A&<F%N8V]I<R!-87)I97(@/&9R86YC;VES0&YI="YC83XI+@I;8VIH72!4
M<F%P(&%D9&EN9R!T:&4@<V%M92!A9&1R97-S(&UU;'1I<&QE('1I;65S(&EN
M('1H92!#;VYT86-T<R!W:6YD;W<*("`@("`@*$9R86YC;VES($UA<FEE<B`\
M9G)A;F-O:7-`;FET+F-A/BDN"EMC:FA=($UA:V4@=&AE(&AE861E<B!C:&5C
M:V)O>"!O;B!T:&4@9F]L9&5R<R!P86=E('1O9V=L92!S96QE8W1I;VX@;V8*
M("`@("`@86QL(&9O;&1E<G,@*$9R86YC;VES($UA<FEE<B`\9G)A;F-O:7-`
M;FET+F-A/BDN"EMC:FA=($%D9"!T:&4@8F%S:7,@9F]R('-E;F1I;F<@871T
M86-H;65N=',@87,@;&EN:W,@=&\@:&]S=&5D(&9I;&5S"B`@("`@("A!;F1R
M97<@0V]L96UA;B`\;65R8W5R>4!A<'!I<V]L=71I;VYS+FYE=#XI+@I;8VIH
M72!)3D)/6"!I<R!N;W<@;&]C86QI>F5D(&9O<B!D:7-P;&%Y+@I;:F%N72!3
M:&]W('=A<FYI;F<@=VAE;B!C;VUP;W-E(&]R('!A<W-P:')A<V4@<&]P=7!S
M(&%R92!B;&]C:V5D(&)Y('1H90H@("`@("!B<F]W<V5R+@I;;6US72!!;&QO
M=R!W:&EC:"!H96%D97)S('1O('9I97<@8GD@9&5F875L="!T;R!B92!D969I
M;F5D(&9O<B!E86-H(&ED96YT:71Y"B`@("`@("A6:6IA>2!-86AR<F$@/'9I
M:F%Y+FUA:')R84!E<RYE87-Y;F5T+FYE=#XI+@I;:F%N72!!9&0@;6%I;&)O
M>"!M86YA9V5M96YT(&9O<B!S=7!P;W)T960@<V5R=F5R<R!L:6ME($-Y<G5S
M+@I;8VIH72!!9&0@;W!T:6]N(&9O<B!R97!O<G1I;F<@96UA:6P@87,@;F]T
M('-P86T@*$QI86T@2&]E:V5N9V$*("`@("`@/&QI86UR0'5M:6-H+F5D=3XI
M+@I;:F]N72!!9&1E9"!A(&YE=R!P<F5F97)E;F-E('1H870@=VEL;"!C875S
M92!A(&UE<W-A9V4@=&\@8F4@<W!E;&P@8VAE8VME9`H@("`@("!B969O<F4@
M:70@:7,@<V5N="X*6VUA>%T@061D("=M86EL7V1O;6%I;B<@<')E9B!W:&EC
M:"!O=F5R<FED97,@=&AE('-E<G9E<B=S(&UA:6QD;VUA:6X@<V5T=&EN9RX*
M6VUM<UT@061D960@:&]O:W,@9F]R(&1Y;F%M:6,@;6%I;&)O>"!R961I<F5C
M=&EO;B!A;F0@8W5S=&]M(&UA:6QB;W@O9F]L9&5R"B`@("`@(&EC;VYS(&]N
M('1H92!F;VQD97(@<&%G92`H4W1U87)T($)I;F=E(#QS+F)I;F=E0&-O9&5F
M=7-I;VXN8V\N>F$^*2X*6VUM<UT@57-E('1H92!-24U%7U9I97=E<B!S>7-T
M96T@=&\@9V5N97)A=&4@)W!R979I97=S)R!F;W(@8V]M<&]S:71I;VX*("`@
M("`@871T86-H;65N=',N"@H*+2TM+2TM+2TM+0IV-"XP+4%,4$A!"BTM+2TM
M+2TM+2T*"EMM;7-=($%D9&5D(&%D9')E<W-B;V]K(&QO;VMU<"!A;F0@97AP
M86YD(&YA;65S(&9E871U<F4@=&\@=&AE(')E9&ER96-T('-C<F5E;BX*6VIO
M;ET@061D960@=&AE(&%B:6QI='D@=&\@8W)E871E(&YE=R!T87-K<R!F<F]M
M(')E8V5I=F5D(&5M86EL(&UE<W-A9V5S+@I;;6US72!297=R;W1E(&9E=&-H
M;6%I;"!T;R!U<V4@<W5B8VQA<W-E<R]D<FEV97)S('1O(&1O(&%L;"!T:&4@
M=V]R:R`M('1H:7,*("`@("`@86QL;W=S('-U<'!O<G0@9F]R(&%C8V5S<VEN
M9R!M;W)E(&UA:6P@<V5R=F5R('1Y<&5S(&EN('1H92!F=71U<F4N"EMM;7-=
M(%=H96X@<F5N86UI;F<@9F]L9&5R<RP@86QL('-U8F9O;&1E<G,@8F5L;W<@
M=&AE(&9O;&1E<B!B96EN9R!R96YN86UE9`H@("`@("!A<F4@;F]W(')E;F%M
M960@86QS;RX*6VUM<UT@2&%N9&QE(&-R96%T:6]N+V1I<W!L87D@;V8@4D9#
M(#(V-#8@9F]R;6%T('1E>'0@;65S<V%G97,@*&9L;W=E9"!T97AT*2X*6VUM
M<UT@4F5W<FET92!O9B!)35!?5')E92!C;V1E("T@;F]W('5S97,@8V%C:&4@
M<F5S=6QT<R!F;W(@86QL(&9O;&1E<B!A;F0*("`@("`@;6%I;&)O>"!U<&1A
M=&5S(&EN<W1E860@;V8@<F5Q=65R>6EN9R!T:&4@<V5R=F5R(&9O<B!T:&4@
M9F]L9&5R('1R964N"EMJ86Y=($%D9"!);F1O;F5S:6%N(&QA;F=U86=E("A3
M;&%M:6X@/'-L86UI;D!U;F5J+F%C+FED/BDN"EMJ86Y=($%D9"!C:&5C:R!I
M9B!T:&4@=7-E<B!H87,@<V5L96-T960@8G5T(&YO="!Y970@=7!L;V%D960@
M871T86-H;65N=',N"EMM;7-=($-O;F9I9W5R871I;VX@;W!T:6]N('1O(&1I
M<V%B;&4@36%I;"!L;V=G:6YG+@I;:F%N72!!9&0@<')E9F5R96YC92!T;R!A
M=71O;6%T:6-A;&QY('-A=F4@86QL(')E8VEP:65N=',@:6X@=&AE(&1E9F%U
M;'0*("`@("`@861D<F5S<R!B;V]K+@I;;6US72!5<V4@3DQ3.CH@:&]S=&YA
M;64M/F-O=6YT<GD@;&]O:W5P('1O('-H;W<@8V]U;G1R>2UO9BUO<FEG:6X@
M9F]R(&4M;6%I;`H@("`@("!M97-S86=E<R!O;B!T:&4@;65S<V%G92!S8W)E
M96XN"EMM;7-=(%-U<'!O<G0@9F]R(&%U=&\M0D-#(&%D9')E<W-E<R!D=7)I
M;F<@8V]M<&]S92!F;W(@96%C:"!I9&5N=&ET>0H@("`@("`H3FEC:&]L87,@
M4W5S:&MI;B`\;G-U<VAK:6Y`=7-E<G,N<V]U<F-E9F]R9V4N;F5T/BDN"EMM
M;7-=(%-U<'!O<G0@;75L=&EP;&4@9FEL92!U<&QO861S(&]N(&%N(&EN9&EV
M:61U86P@8V]M<&]S92!P86=E+@I;;6US72!(5$U,(&-O;7!O<V5D(&UE<W-A
M9V5S('=I=&@@:6UA9V4@;&EN:W,@;F]W(&AA=F4@=&AE(&EM86=E<R!D;W=N
M;&]A9&5D"B`@("`@(&%N9"!S96YT(&EN;&EN92!W:71H('1H92!M97-S86=E
M(&EN(&$@;75L=&EP87)T+W)E;&%T960@<&%R="X*6VIA;ET@4VAO=R!G<F%P
M:&EC86P@96UO=&EC;VYS+@I;;6US72!&;W(@:6UA9V5S('1H870@8V%N(&YO
M="!B92!V:65W960@9&ER96-T;'D@8GD@=&AE(&)R;W=S97(L($E-4"!C86X*
M("`@("`@875T;VUA=&EC86QL>2!C;VYV97)T('1O(&$@9F]R;6%T('1H870@
M8V%N(&)E('9I97=E9"X*6V-J:%T@3&]G(')E<&QY+V9O<G=A<F0O<F5D:7)E
M8W0@86-T:6]N<R!A;F0@9&ES<&QA>2!T:&5S92!L;V=S('=H96X@=FEE=VEN
M9PH@("`@("!T:&4@;65S<V%G97,N"EMC:FA=($E-4"!N;W<@<W5P<&]R=',@
M82!H;W)D96%U=&@@<V5T=&EN9R!I;B!S97)V97)S+G!H<"P@82!L82!';VQL
M96T@86YD"B`@("`@(&]T:&5R(&%P<&QI8V%T:6]N<R`H5FEJ87D@36%H<G)A
M(#QV:6IA>2YM86AR<F%`97,N96%S>6YE="YN970^*2X*6VUM<UT@061D(&]N
M+61E;6%N9"!G96YE<F%T:6]N(&]F('1H=6UB;F%I;',@9F]R(&EM86=E(&%T
M=&%C:&UE;G1S+@I;;6US72!!9&1E9"`G1&]W;FQO860@06QL($%T=&%C:&UE
M;G1S)R!L:6YK(&]N(&UE<W-A9V4@<&%G92!T;R!A;&QO=R!A;&P*("`@("`@
M871T86-H;65N=',@=&\@8F4@9&]W;FQO861E9"!I;B!A('-I;F=L92!Z:7`@
M9FEL92X*6VUM<UT@26UP<F]V960@2%1-3"!T;R!T97AT(&-O;G9E<G-I;VX@
M=VAE;B!R97!L>6EN9R]F;W)W87)D:6YG('1O(&$@2%1-3`H@("`@("!M97-S
M86=E+@I;;6US72!!9&0@)W1I92!T;R<@86)I;&ET>2!T;R!A;&QO=R!A('-P
M96-I9FEC(&ED96YT:71Y('1O(&)E(&5X<&QI8VET;'D@=&EE9`H@("`@("!T
M;R!A(&UE<W-A9V4@<V5N="!F<F]M(&$@8V5R=&%I;B!A9&1R97-S+@I;;6US
M72!-87AI;75M('-U8FIE8W0O9G)O;2!L96YG=&AS+"!&<F]M.B!F:65L9"!L
M:6YK(&]P=&EO;G,L(&%N9"!M86EL8F]X"B`@("`@('1I;64@9&ES<&QA>2!F
M;W)M871S(&%R92!N;W<@=7-E<B!C;VYF:6=U<F%B;&4@<')E9F5R96YC97,*
M("`@("`@*%)O8F5R="!2:6)N:71Z(#QR:6)N:71Z0&QI;G5X8F]U<F<N8V@^
M*2X*6VIA;ET@061D(&%L:6%S97,@=&\@=&AE('5S97(G<R!I9&5N=&ET:65S
M('1O(&9I;F0@;65S<V%G97,@<V5N="!T;R!O;F4@;V8*("`@("`@:&ES(&ED
M96YT:71I97,@8G5T(&YO="!D:7)E8W1L>2!T;R!O;F4@;V8@:&ES(&5M86EL
M(&%D9')E<W-E<RX*6VUM<UT@4')E9F5R96YC92!T;R!A;&QO=R!S<&%M(&UE
M<W-A9V5S('1O(&)E(&%U=&]M871I8V%L;'D@9&5L971E9"!A9G1E<@H@("`@
M("!R97!O<G1I;F<@*%)U9&D@2&5I=&)A=6T@/')U9&E`9&%R>"YC;VT^*2X*
M6VUM<UT@36]V960@24U0(&%U=&AE;G1I8V%T:6]N(&-O9&4@=&\@075T:%]I
M;7`Z.BX*6VUM<UT@061D960@8V]N9FEG=7)A=&EO;B!O<'1I;VYS(&%L;&]W
M:6YG(&%D;6EN('1O(&QI;6ET("AP97(@;65S<V%G92D@8F]T:`H@("`@("!T
M:&4@=&]T86P@<VEZ92!O9B!A='1A8VAM96YT<R!A;F0@=&AE(&YU;6)E<B!O
M9B!A='1A8VAM96YT<RX*6VUM<UT@061D960@<')E9F5R96YC92!A;&QO=VEN
M9R!U<V5R('1O(&-H;V]S92!W:&5R92!T;R!S=&%R="!B<F]W<VEN9R!I;B!A
M"B`@("`@(&UA:6QB;W@@=VAE;B!F:7)S="!O<&5N:6YG('1H92!M86EL8F]X
M+@I;;6US72!4:&4@9W5T<R!O9B!T:&4@24U0(&9I;'1E<FEN9R!C;V1E(&AA
M<R!B965N(')E;6]V960@86YD('!O<G1E9"!T;PH@("`@("`G:6YG;R<N(%1H
M=7,L(&9I;'1E<FEN9R!I<R!N;W<@:&%N9&QE9"!V:6$@2&]R9&4@05!)(&-A
M;&QS(&EN<W1E860*("`@("`@;V8@:6YT97)N86QL>2X*6VUM<UT@5&AE($E-
M4"!S96%R8V@@<&%G92!N;W<@:&%N9&QE<R!.3U0@<V5A<F-H97,L(&%S('=E
M;&P@87,@8F%S:6,@04Y$+T]2"B`@("`@('-E87)C:&5S('9I82!T:&4@24U!
M4%]396%R8V@Z.B!L:6)R87)Y+@I;8VIH72!!9&0@<VAI9G0M8VQI8VL@<V5L
M96-T:6]N+V1E<V5L96-T:6]N(&]F(')A;F=E<R!O9B!M97-S86=E<PH@("`@
M("`H06YD<F5W($IO:&YS;VX@/&AO<F1E0&QA<W1A8V-E<W,N8V]M/BDN"EMM
M;7-=($%L;&]W(&-A8VAI;F<@;V8@9F]L9&5R(&QI<W0@9V5N97)A=&EO;BX*
M6VUM<UT@061D960@24U07TE-05`Z.B!C;&%S<R!T;R!H86YD;&4@24U!4"]0
M3U`S(&-O;FYE8W1I;VYS+@I;:F%N72!!;&QO=R!S<&%M(')E<&]R=&EN9R!F
M<F]M('1H92!M86EL8F]X('9I97<@*$%H;65D(#QA<VAI:&%B0&%L8V%H97-T
M+F-O;3XI+@I;:F%N72!!9&0@<')E9F5R96YC92!T;R!S=&]R92!D<F%F=',@
M;6%R:V5D('5N<V5E;@H@("`@("`H06AM960@/&%S:&EH86)`86QC86AE<W0N
M8V]M/BDN"EMC:FA=(%1H92!L87-T7VQO9VEN('!R969E<F5N8V4@:7,@;F]W
M(&5N=&ER96QY(&AA;F1L960@8GD@2&]R9&4N"EMJ86Y=($QE="!T:&4@=7-E
M<G,@<V5L96-T('1H92!M97-S86=E)W,@8VAA<G-E="!W:&EL92!T:&5Y(&%R
M92!C;VUP;W-I;F<@80H@("`@("!M97-S86=E+@I;8VIH72!7:&5N(&$@=7-E
M<B=S('-E<W-I;VX@=&EM97,@;W5T('=H:6QE('1H97D@87)E(&-O;7!O<VEN
M9R!A(&UE<W-A9V4L"B`@("`@(&=I=F4@=&AE;2!A('-P96-I86P@;&]G:6X@
M<V-R965N('=H:6-H(&1I<W!L87ES('1H92!M97-S86=E(&%N9`H@("`@("!A
M;&QO=W,@=&AE;2!T;R!L;V<@:6X@86=A:6X@=&\@<F5S=6UE('1H96ER(&UE
M<W-A9V4@=VET:"!A;&P@9&%T80H@("`@("!I;G1A8W0N"EMC:FA=(%)E;6]V
M92!J879A<V-R:7!T(')E9G)E<V@@<&]P=7!S(&EN('1H92!C;VUP;W-E('=I
M;F1O=RX*6VUM<UT@06QL;W<@9&ES<&QA>2!O9B!U=65N8V]D960@871T86-H
M;65N=',N"EMC:FA=($%D9"!F;&%G+7-E='1I;F<@;W!T:6]N<R!O;B!T:&4@
M;65S<V%G92!V:65W"B`@("`@("A$86X@5VEL<V]N(#QD86Y`86-U8V]R92YC
M;VT^*2X*6VUM<UT@06QL;W<@8FQO8VMI;F<@;V8@:6UA9V5S(&EN($A434P@
M;65S<V%G97,@8GD@9&5F875L="`H06UI=&@@5F%R9VAE<V4*("`@("`@/&%M
M:71H0'AA;&%N+F-O;3XI+@I;;6US72!3=7!P;W)T(&9O<B!S:&]W:6YG(&UA
M:6P@<')E=FEE=W,@:6X@:F%V87-C<FEP="`G=&]O;'1I<',G+@I;;6US72!!
M9&1E9"!M97-S86=E+W!A<G1I86P@34E-15]6:65W97(N"EMC:FA=($%D9"!W
M:&ET96QI<W0@;&EN:W,@=&\@=&AE(&UA:6QB;W@@=FEE=PH@("`@("`H06UI
M=&@@5F%R9VAE<V4@/&%M:71H0'AA;&%N+F-O;3XI+@I;:F%N72!-86ME(&9E
M=&-H;6%I;"!O;B!L;V=I;B!A(&UA:6YT96YA;F-E('1A<VL@*$YU;F\@3&]U
M<F5I<F\*("`@("`@/&YU;F]`8V\N<V%P;RYP=#XI+@I;;6US72!!9&0@5D93
M(&=A<F)A9V4@8V]L;&5C=&EO;B!F;W(@=&5M<&]R87)Y(&%T=&%C:&UE;G0@
M9&%T82X*6VUM<UT@061D(&$@9&5F875L="!E;F-R>7!T:6]N('!R969E<F5N
M8V4@9F]R('-E;F1I;F<@;65S<V%G97,N"EMM;7-=($%D9"`G3G5K92!-97-S
M86=E)R!A8W1I;VX@=&\@9FEL=&5R<RX*6VUM<UT@061D('%U:6-K('-E87)C
M:"!L:6YK<R!T;R!S96%R8V@@=&AE(&-U<G)E;G0@;6%I;&)O>"X*6VUM<UT@
M4V-A;B!M97-S86=E<R!F;W(@6"U0<FEO<FET>2!A;F0@9&ES<&QA>2!R97-U
M;'1S(&EN('1H92!M86EL8F]X"B`@("`@('9I97<@*$9L;W)E;G0@04E$12`\
M9F%I9&5`86QP:&%C96YT+F-O;3XI+@I;;6US72!!;&QO=R!Q=6EC:V5R(&%C
M8V5S<R!T;R!L87)G92!M86EL8F]X97,@;VX@<VQO=V5R($E-05`@<WES=&5M
M<RX*6VUM<UT@061D960@;75L=&EP87)T+V%P<&QE9&]U8FQE($U)345?5FEE
M=V5R+@I;:F%N72!!9&0@<')E9F5R96YC92!T:&%T(&QE=',@=7-E<G,@8VAA
M;F=E('1H92!A8V-E<W,@8V]N=')O;"!L:7-T<R!O9@H@("`@("!T:&5I<B!I
M;6%P(&9O;&1E<G,@*$-H<FES($AA<W1I92`\;&ES='-`;V%K+7=O;V0N8V\N
M=6L^*2X*6VUM<UT@4W!L:70@<F5T=7)N(')E8V5I<'0@<F5Q=65S=',@:6YT
M;R`G9&5L:79E<F5D)R!A;F0@)W)E860G(&]P=&EO;G,*("`@("`@*%)Y86X@
M36%L;&]Y(#QR;6%L;&]Y0&UE<FED:6%N<V-H;V]L<RYO<F<^*2X*6VUM<UT@
M26UP;&5M96YT(&9E=&-H;6%I;"!O;B!L;V=I;B!A;F0@9F5T8VAM86EL(&-O
M;&]R:6YG('1O(&1I<W1I;F=U:7-H"B`@("`@(&)E='=E96X@<F5M;W1E('-E
M<G9E<G,@*$YU;F\@3&]U<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#XI+@I;;6US
M72!5<V5R(&-O;F9I9W5R86)L92!A='1R:6)U=&EO;B!T97AT(&9O<B!R97!L
M:65S"B`@("`@("A#:')I<R!(87-T:64@/&QI<W1S0&]A:RUW;V]D+F-O+G5K
M/BDN"EMM;7-=($%D9&5D('-U<'!O<G0@9F]R(&UE<W-A9V4O9&ES<&]S:71I
M;VXM;F]T:69I8V%T:6]N(&UE<W-A9V5S+@I;:F%N72!&;VQD97(@;F%M97,@
M:6X@86YY(&5N8V]D:6YG(&-A;B!N;W<@8F4@8W)E871E9"]R96%D('1H<F]U
M9V@@4$A0)W,*("`@("`@;75L=&EB>71E('-U<'!O<G0N"EMM;7-=(%1H92`B
M4F5P;'DB(&QI;FL@9F]R(&QI<W0@;65S<V%G97,@=VEL;"!A;'=A>7,@<V5N
M9"!A(&UE<W-A9V4@=&\@=&AE"B`@("`@(&]R:6=I;F%L('!O<W1E<BP@;F5V
M97(@=&AE(&QI<W0@*$-H<FES($AA<W1I92`\;&ES='-`;V%K+7=O;V0N8V\N
M=6L^*2X*6VUM<UT@1&]N)W0@<VAO=R`B4F5P;'D@06QL(B!L:6YK(&EF('5S
M97(@:7,@=&AE(&]N;'D@<F5C:7!I96YT+@I;;6US72!!9&1E9"!A(&UU;'1I
M<&%R="]R97!O<G0@34E-15]6:65W97(@=&\@;6%K92!U;F1E;&EV97)E9"!M
M86EL(')E<&]R=',*("`@("`@96%S:65R('1O(')E860N"EMJ86Y=($%D9"!4
M=7)K:7-H('1R86YS;&%T:6]N("A'96YC;R!9:6QM87H@/&=E;F-O>6EL;6%Z
M0'EA:&]O+F-O;3XI+@I;;6US72!#;VYV97)T($E-4%]&;VQD97(Z.B!I;G1O
M(&%N($]/+6EN=&5R9F%C92X*6VUM<UT@06QL;W<@871T86-H;65N="!D97-C
M<FEP=&EO;G,@=&\@8F4@86QT97)E9`H@("`@("`H0VQI9F8@1W)E96X@/&=R
M965N0%5-1$Y*+D5$53XI+@I;;6US72!3970@=&AE(&QO8V%L(&-H87)A8W1E
M<B!S970@9F]R(&%L;"!T97AT+RH@8V]M<&]S960@;65S<V%G97,N"EMM;7-=
M(%1H92!F=6QL($U)345?0V]N=&5N=',Z.B!O8FIE8W0@:7,@;F]W(&-A8VAE
M9"!W:&5N('9I97=I;F<@82!M97-S86=E"B`@("`@(')A=&AE<B!T:&%N('1H
M92!I;F1I=FED=6%L($U)345?4&%R=',N"EMJ86Y=($%D9"!55$8M."!S=7!P
M;W)T+B!!;GD@8V]N=&5N="!W:71H(&%N>2!C:&%R<V5T(&-A;B!N;W<@8F4@
M9&ES<&QA>65D('=I=&@*("`@("`@86YY('1R86YS;&%T:6]N+@I;8VIH72!4
M:&4@;6%I;"]C;VUP;W-E(&UE=&AO9"!I<R!N;W<@82!F=6QL(&-A;&PL(&YO
M="!A(&QI;FLN(%1H:7,@;65A;G,L"B`@("`@(&%S:61E(&9R;VT@82!B:70@
M;&5S<R!C;V1E(&1U<&QI8V%T:6]N+"!T:&%T('=E(&YO=R!H;VYO<B!T:&4*
M("`@("`@8V]M<&]S95]P;W!U<"!P<F5F97)E;F-E(&EN("1R96=I<W1R>2!C
M86QL<RX*6VUM<UT@061D960@:&]S=&YA;64@=&\@:6YF;W)M871I;VX@<V%V
M960@86)O=70@=7-E<B=S(&QA<W0@;&]G:6XN"EMM;7-=($%D9&5D('-U<'!O
M<G0@9F]R('-T<FEP<&EN9R!A='1A8VAM96YT<R!F<F]M(&UE<W-A9V5S+@I;
M;6US72!"971T97(@9&5T97)M:6YA=&EO;B!O9B!-24U%(&-O;G1E;G0M='EP
M92!F;W(@871T86-H;65N=',@=VAE;B!B<F]W<V5R"B`@("`@(&1O97,@;F]T
M('-E;F0@9V]O9"!I;F9O<FUA=&EO;B`H=7-I;F<@34E-15]-86=I8SHZ*2X*
M6VUM<UT@4$=0(&UE<W-A9V5S(&%R92!N;W<@<F5N9&5R960@=FEA('1H92!-
M24U%(&5M8F5D9&5D(&EN('1H92!M97-S86=E+@I;;6US72!-;W9E(&-O;7!O
M<VET:6]N(')E;&%T960@9G5N8W1I;VYS('1O($E-4%]#;VUP;W-E.CHN"EMM
M;7-=($YO=RP@=VAE;B!R96%C:&EN9R!T:&4@96YD(&]F('1H92!M86EL8F]X
M(&EN('1H92!M97-S86=E('-C<F5E;BP*("`@("`@9&ER96-T;'D@;&]A9"!T
M:&4@;6%I;&)O>"!S8W)I<'0@:6YS=&5A9"!O9B!R961I<F5C=&EN9R!V:6$@
M82!54DPN"EMM;7-=($%L;&]W('5S97(@=&\@8VAA;F=E(&1I<W!O<VET:6]N
M('1Y<&4@;V8@86QL(&%T=&%C:&UE;G1S+@I;:F%N72!!9&0@82!P<F5F97)E
M;F-E('1O(&1I<W!L87D@;65S<V%G92!P<F5V:65W<R!I;B!T:&4@;6%I;&)O
M>"!V:65W"B`@("`@("A3=&5P:&5N(%-H97)L;V-K(#QS=&5V97-H97)L;V-K
M0&5S+6YE="YC;RYU:SXI+@I;8VIH72!!9&0@82!P<F5F97)E;F-E(&9O<B!W
M:&5T:&5R(&]R(&YO="!T;R!D:7-P;&%Y('1H92!E;G1I<F4@861D<F5S<V)O
M;VL*("`@("`@=VAE;B!F:7)S="!L;V%D:6YG('1H92!C;VYT86-T<R!S8W)E
M96X*("`@("`@*$5T:65N;F4@1V]Y97(@/&5T:65N;F4N9V]Y97)`;&EN=7AQ
M=65B96,N8V]M/BDN"EME:G)=($%D9"!C;VUM86YD(&QI;F4@9')I=F5R(&9O
M<B!Q=6]T87,N"EMM;7-=($%L;&]W(&UU;'1I<&QE(&UE<W-A9V5S('1O(&)E
M(&9O<G=A<F1E9"!A<R!R9F,X,C(@<&%R=',@9G)O;2!T:&4*("`@("`@;6%I
M;&)O>"!S8W)E96XN"EMJ86Y=($%D9"!L;V=F:6QE(&1R:79E<B!F;W(@<75O
M=&%S("A4:6T@1V]R=&5R(#QE;6%I;$!T96QE=&5C:&YI8W,N8V]M/BDN"EMC
M:FA=($%D9"!S96%R8VAI;F<@8GD@0F-C(&AE861E<BX*6VUI<ET@061D(&AO
M;VL@;W!T:6]N('1O(&9I;'1E<B!M86EL(&9E=&-H960@8GD@=&AE($%C8V]U
M;G1S("AL:6(O1F5T8VAM86EL*0H@("`@("!F96%T=7)E+B`@17AA;7!L92!A
M9&1E9"!I;B!H;W)D92]C;VYF:6<O:&]O:W,N<&AP+F1I<W0*6V-J:%T@36EG
M<F%T92!T;R!T:&4@;F5W(&AO;VMS($%022P@<F5M;W9I;F<@=&AE(&QA<W0@
M;F5E9"!F;W(*("`@("`@8V]N9BYP:'`N9&ES="`H:6YS=&5A9"!O9B!C;VYF
M+GAM;"DN"EMM86-=($%D9"!3+TU)344@<W5P<&]R="X*6V%V<VU=($9O;&1E
M<G,@86-T:6]N(&)A<B!O;FQY('-H;W=S('5P(&%T(&)O='1O;2!I9B!M;W)E
M('1H86X@=&5N(&9O;&1E<G,*("`@("`@87)E(&1I<W!L87EE9"!O;B!T:&4@
M<V-R965N+@I;8VIH72!!;&P@:&]O:R!F=6YC=&EO;G,@=&AA="!S970@<')E
M9F5R96YC97,@87)E(&YO=R!H86YD;&5D(&)Y('1H92!G96YE<FEC"B`@("`@
M('!R969E<F5N8V5S(&AO;VL@<WES=&5M.R!S964@:&]R9&4O8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T+@I;;6%C72!$;VXG="!M;V1I9GD@=&AE(&%C='5A;"!F
M:65L9"!N86UE(&]N(&%U=&\M97AP86YD+@I;;6US72!#<F5A=&5D(&%N($E-
M4%]-86EL8F]X.CH@8VQA<W,@=&\@9&5A;"!W:71H(&)U:6QD:6YG(&UA:6QB
M;W@@:6YF;W)M871I;VX*("`@("`@86YD+"!E=F5N='5A;&QY+"!A;&P@;65S
M<V%G92!I;F1E>&EN9RX*6VUA8UT@475O=&$@9&ES<&QA>2!N;W<@:&%N9&QE
M9"!B>2!T:&4@24U07U%U;W1A($%022X*6VUM<UT@0V%N(&YO=R!F:6QT97(@
M8GD@86YY(&AE861E<BX*6V-J:%T@0VQE86X@=7`@=&AE(&9I;'1E<E]O;E]L
M;V=I;B!C;V1E+"!S;R!T:&%T(&ET(&ES(%]A;'=A>7-?(')U;B!O;B!L;V=I
M;BX*6VUA8UT@061D960@86X@24U0('-P96-I9FEC(%I)4"!-24U%7U9I97=E
M<BX*6V-J:%T@57-E(&YE=R`F261E;G1I='DZ.G-I;F=L971O;B@I(&UE=&AO
M9"!A;F0@87!P;&EC871I;VXM<W!E8VEF:6,*("`@("`@9')I=F5R(&EM<&QE
M;65N=&%T:6]N<R!T;R!L;V%D($E-4"=S($ED96YT:71Y7VEM<#HZ(&-L87-S
M+@I;;6US72!-;W9E9"!)35`@<V5S<VEO;B!C<F5A=&EO;B!F=6YC=&EO;G,@
M=&\@24U07U-E<W-I;VXZ.BX*6VUM<UT@061D960@86X@24U07U-E87)C:#HZ
M(&-L87-S('1O(&AA;F1L92!M86EL8F]X('-E87)C:&EN9RX*6VUM<UT@365S
M<V%G92!S96YD:6YG(&YO=R!H86YD;&5D(&)Y($E-4#HZ<V5N9$UE<W-A9V4H
M*2X*6VUM<UT@36]V92!T97AT(&9I;'1E<FEN9R!T;R!)35`Z.B!C;&%S<RX*
M6VUM<UT@061D960@86X@24U07T9I;'1E<CHZ(&-L87-S('1O(&AA;F1L92!A
M;&P@9FEL=&5R:6YG(&%C=&EV:71Y+@I;;6US72!3<&%M(')E<&]R=&EN9R!S
M96YD<R!A(&UE<W-A9V4@:6X@;65S<V%G92]R9F,X,C(@9F]R;6%T+@I;;6US
M72!!;&QO=R!T:&4@=7-E<G,@4$=0('!U8FQI8R!K97D@=&\@8F4@=7!L;V%D
M960@=&\@82!K97ES97)V97(N"EMM;7-=(%1H92!C;VUP;W-E('-C<FEP="!M
M86ME<R!S=7)E('1O(&-L96%N('5P(&%L;"!A='1A8VAM96YT(&9I;&5S('1H
M870*("`@("`@87)E(&=E;F5R871E9"!D=7)I;F<@82!M97-S86=E(&-O;7!O
M<VET:6]N+B!E=F5N(&EF(&-A;F-E;&QE9"X*6VUM<UT@071T86-H;65N="!D
M:7-P;W-I=&EO;B!C86X@;F]W(&)E('-E="!T;R!E:71H97(@:6YL:6YE(&]R
M(&%T=&%C:&UE;G0N"EMM;7-=($EM<')O=F5D(&AA;F1L:6YG(&]F(&%T=&%C
M:&UE;G0@9&%T82X*6VUM<UT@061D960@=&AE(&UU;'1I<&%R="]R96QA=&5D
M('9I97=E<BX*6VUM<UT@36]V960@=&AE(&UE<W-A9V4@:6YD97@@=')A8VMI
M;F<@;65C:&%N:7-M(&EN('1H92!M97-S86=E+G!H<"!S8W)I<'0@=&\*("`@
M("`@24U07TUE<W-A9V4Z.BX*6V-J:%T@061D(&%N(&]P=&EO;B`H<')E9F5R
M96YC92!C;VYT<F]L;&5D*2!T;R!U<V4@244G<R!D97-I9VYM;V1E"B`@("`@
M(&%N9"!S96YD(&UU;'1I<&%R="]A;'1E<FYA=&EV92!M97-S86=E<RX*6VIA
M;ET@57-E(&$@<V5P97)A=&4@=&5X=&%R96$@9FEE;&0@9F]R(&)L86-K;&ES
M=&5D(&5M86EL(&%D9')E<W-E<R!I;B!T:&4*("`@("`@9FEL=&5R<R!P<F5F
M97)E;F-E+@I;;6US72!!9&0@86X@;W!T:6]N('1O(&%L;&]W(&9O<B!H96%D
M97(@<W5M;6%R:65S('1O(&)E(&EN<V5R=&5D('=H96X@<F5P;'EI;F<*("`@
M("`@=&\@82!M97-S86=E("A1=6EN;B!7:6QS;VX@/'%W:6QS;VY`;6ED=V]R
M;&0N;W)G/BDN"EMM;7-=($-R96%T960@86X@24U07TAE861E<G,Z.B!C;&%S
M<R!T;R!D96%L('=I=&@@86QL(&AE861E<B!M86YI<'5L871I;VX*("`@("`@
M<F5Q=6ER960@:6X@24U0+@I;;6US72!!9&1E9"!A(&=E;F5R:6,@;75L=&EP
M87)T+RH@34E-15]6:65W97(N"EMM;7-=($%D9&5D(&$@;75L=&EP87)T+V%L
M=&5R;F%T:79E($U)345?5FEE=V5R+@I;;6US72!-;W9E9"!A;&P@8V]M;6]N
M(&9U;F-T:6]N<R!D96%L:6YG('=I=&@@9&ES<&QA>6EN9R!T:&4@8V]N=&5N
M="!O9@H@("`@("!M86EL(&UE<W-A9V5S('1O(&QI8B]#;VYT96YT<RYP:'`N
M"EMC:FA=($%D9"!A;B!O<'1I;VX@=&\@<V5E(&$@8V]N9FER;6%T:6]N('1H
M870@;65S<V%G97,@=V5R92!S=6-C97-F=6QL>2!S96YT+@I;8VIH72!!9&0@
M;W!T:6]N('1O(&1E;&5T92!F971C:&5D(&UE<W-A9V5S('=H96X@=7-I;F<@
M=&AE(&9E=&-H;6%I;"!C;V1E+@I;;6US72!!9&1E9"!A<'!L:6-A=&EO;B]M
M<RUT;F5F($U)345?5FEE=V5R+@I;;6US72!396%R8V@@9F]R(%!'4"!P=6)L
M:6,@:V5Y<R!O;B!A('!U8FQI8R!K97ES97)V97(@9F]R('-I9VYE9"!M97-S
M86=E<PH@("`@("!I9B!N;R!K97D@9F]U;F0@;&]C86QL>2X*6VUM<UT@0V%N
M(&YO=R!S96YD(&UE<W-A9V5S('=I=&@@(E@M4')I;W)I='DB('-E="X*6VUM
M<UT@061D(&]P=&EO;B!T;R!S96%R8V@@9F]R(%!'4"!D871A(&EN("=T97AT
M+W!L86EN)R!M97-S86=E<RX*6VUM<UT@061D(")3:&]W($%L;"],:6UI=&5D
M($AE861E<G,B('1O(&UE<W-A9V4@=FEE=RX*6VIA;ET@061D(&9E=&-H;6%I
M;"!F96%T=7)E("A.=6YO($QO=7)E:7)O(#QN=6YO0&-O+F5T:"YP=#XI+@I;
M;6US72!!9&1E9"!-24U%7U9I97=E<B!T;R!A;&QO=R!A='1A8VAE9"!I;6%G
M97,@=&\@8F4@=FEE=V5D(&EN;&EN92X*6VUM<UT@061D(&QI;FL@9F]R(")2
M97!L>2!T;R!,:7-T(B!F;W(@;6%I;&EN9R!L:7-T<RX*6VUM<UT@3F]W(')E
M8V]G;FEZ92!21D,@,C,V.2!H96%D97)S("AM97-S86=E<R!F<F]M(&UA:6QI
M;F<@;&ES=',I(&%N9"!O=71P=70*("`@("`@=&AE(')E;&5V86YT(&EN9F]R
M;6%T:6]N+@I;;6US72!!9&0@;65S<V%G92]R9F,X,C(@34E-15]6:65W97(N
M"EMJ;VY=(%-E="!T:&4@=7-E<FYA;64@86YD('!A<W-W;W)D('!A<F%M971E
M<G,@=VAE;B!33510(&%U=&AE;G1I8V%T:6]N(&ES"B`@("`@(')E<75E<W1E
M9"X*6VUM<UT@2&%N9&QE('1H92!N97<@8F5H879I;W(@;V8@34E-15]3=')U
M8W1U<F4Z.G!A<G-E*"DN"EMM;7-=($%D9"!/<&5N4$=0(&9U;F-T:6]N86QI
M='DN"EME:G)=($%D9"!T97AT+V5N<FEC:&5D($U)345?5FEE=V5R+@I;8VIH
M72!)9B!T:&4@<V5R=F5R(&QI<W0@:7,@8F5I;F<@=7-E9"P@=7-E<G,@<VAO
M=6QD;B=T(&)E(&-H86YG:6YG"B`@("`@('1H92!F;VQD97(@<')E9FEX+@I;
M;6%X72!!9&0@0G)O=VX@24U0('1H96UE("A-87)C;R!/8F%I9"`\;6%R8V]`
M;75W+F5D=3XI"EMC:FA=($UA:V4@:70@<&]S<VEB;&4@=&\@8V%L;"!)35`Z
M.F%U=&AE;G1I8V%T92@I('=I=&@@87)G=6UE;G1S(&-O;6EN9R!F<F]M"B`@
M("`@('-O;65W:&5R92!O=&AE<B!T:&%N($=%5"!O<B!03U-4('9A<G,N"EMJ
M86Y=(%)E+65N86)L92!T;R!S96QE8W0@;F\@<V5N="!M86EL(&9O;&1E<B!F
M;W(@86X@:61E;G1I='DN"EMJ86Y=($%D9"!M971H;V0@24U0.CIS=')I<%!R
M96%M8FQE4W1R:6YG*"DN"EMJ86Y=($9I>"!P<F]B;&5M<R!W:71H('-E;G0@
M;6%I;"!F;VQD97(@;6%I;G1E;F%N8V4@;F]T(&)E:6YG(&5X96-U=&5D+@I;
M8VIH72!&:7@@<')O8FQE;7,@=VET:"!T:&4@;6%I;&)O>"!D:7-P;&%Y960@
M869T97(@;&]G:6X@:68@=&AE<F4@:7,@80H@("`@("!F;VQD97)S('!R969I
M>"!S970N"EMC:FA=(%5S92!T:&4@;F5W(%!R969S54D@8VQA<W,N"EMC:FA=
M(%)E=F5R="!T;R!N;W0@<W1O<FEN9R!T:&4@9F]L9&5R('!R969I>"!A<R!P
M87)T(&]F('5S97(@<')E9F5R96YC97,N"EMC:FA=($9I>"!P<F]B;&5M<R!W
M:71H(&1O=6)L92!,87-T($QO9VEN.B!M97-S86=E(&%N9"!M86EN=&5N86YC
M92X*6VIO;ET@061A<'0@=&\@=&AE(&YE=R!(;W)D93HZ:6UG*"D@<WEN=&%X
M+@I;8VIH72!5<V4@=&AE(&YE=R!.;W1I9FEC871I;VX@<WES=&5M+@I;:F%N
M72!296UO=F4@=&AE('-T86YD87)D('9A;'5E(&9O<B!T:&4@;&%N9W5A9V4@
M<')E9F5R96YC92X@5&AE(&QA;F=U86=E('1O"B`@("`@(&9A;&P@8F%C:R!T
M;R!S:&]U;&0@8F4@<V5T($AO<F1E('=I9&4@:6X@;&%N9RYP:'`@:6YS=&5A
M9"X*6VIO;ET@2&]N;W(@=&AE(")S879E('-E;G0@;6%I;"(@8VAE8VMB;W@@
M;VX@=&AE(&-O;7!O<V4@<V-R965N+@I;:F]N72!0<FEN="!T:&4@;&%N9W5A
M9V4@='EP92!I;B!T:&4@/&AT;6P^(&5N=&ET>2X*6VIO;ET@061D(#QL:6YK
M/B!E;G1I='D@<W5P<&]R="X*6VIO;ET@061D(#QL:6YK/B!S=7!P;W)T('1O
M('1H92!M86EL8F]X(&%N9"!M97-S86=E('9I97=S+@I;;6US72!-;W9E('1H
M92!Q=6]T92!P<F5F:7@@8VAA<F%C=&5R(&9R;VT@8V]N9BYP:'`@=&\@=&AE
M('!R969E<F5N8V5S+@I;;6US72!-;W9E('1H92!M86EN=&5N86-E(&9R86UE
M=V]R:R!T;R!(;W)D92X*"@HM+2TM+2T*=C,N,BXX"BTM+2TM+0H*6VIA;ET@
M0VQO<V4@6%-3('=H96X@<V5T=&EN9R!T:&4@<&%R96YT(&9R86UE)W,@<&%G
M92!T:71L92!B>2!J879A<V-R:7!T("AC:F@I+@I;;6US72!&:7@@9&ES<&QA
M>2!O9B!-24U%('!A<G1S(&QE<W,@=&AA;B`Q2R!W:&5N(&QO8V%L(&YU;6)E
M<B!F;W)M870@=7-E<PH@("`@("`G+"<@87,@=&AE(&1E8VEM86P@<V5P87)A
M=&]R+@I;:F%N72!$;VXG="!U<V4@=')A<V@@9F]L9&5R(&]N(%!/4#,@<V5R
M=F5R<R!U;F1E<B!C97)T86EN(&-I<F-U;7-T86YC97,*("`@("`@*$)U9R`C
M,3,W,RDN"EMJ86Y=($9I>"`B4V%V92!A<R(@;&EN:R!T;R!S879E(&UE<W-A
M9V4@<V]U<F-E<R`H0G5G(",Q,C,S*2X*"@HM+2TM+2T*=C,N,BXW"BTM+2TM
M+0H*6VUM<UT@1&5T97)M:6YE('1H92!D969A=6QT($E-05`@9&5L:6UI=&5R
M(&%C8V]R9&EN9R!T;R!21D,@,S4P,2X*6VUM<UT@1FEX('1H92!F;VQD97)S
M('-C<F5E;B!H86YG:6YG(&EF('1H97)E('=A<R!O;FQY(&]N92!F;VQD97(@
M*$)U9R`C-3`T*2X*6VIA;ET@0V]R<F5C=&QY(&-A;F-E;"!M97-S86=E<R!C
M;VUP;W-I=&EO;B!I;B!A;&P@8V%S97,@*%)I8V@@0F%R=&5L;`H@("`@("`\
M<G=B0&)A<G1E;&QO;FQI;F4N8V]M*2X*6VUM<UT@1&]N)W0@8V]N=F5R="!C
M;VQO;G,@:6X@=7-E<BUD969I;F5D(&AE861E<G,@=&\@=6YD97)S8V]R97,@
M*$)U9R`C-C<V*2X*6VIA;ET@1&]N)W0@8FQA8VML:7-T(&%L<F5A9'D@8FQA
M8VML:7-T960@861D<F5S<V5S(&%G86EN("A"=6<@(S4S,"DN"@H*+2TM+2TM
M"G8S+C(N-@HM+2TM+2T*"EMJ86Y=(%-%0U522519.B!296UO=F4@=&%G<R!W
M:71H("UM;WHM8FEN9&EN9SH@<W1Y;&5S(&EN('1H92!(5$U,($U)344@=FEE
M=V5R+@I;8VIH72!314-54DE463H@4F5M;W9E('-C<FEP=',@9G)O;2`\8F%S
M93X@=&%G<R!I;B!T:&4@2%1-3"!-24U%('9I97=E<BX*6VIA;ET@4T5#55))
M5%DZ(%)E;6]V92!S8W)I<'1S(&9R;VT@;V)F=7-C871E9"`B;VXN+BXB(&%T
M=')I8G5T97,@:6X@=&AE($A434P*("`@("`@34E-12!V:65W97(N"@H*+2TM
M+2TM"G8S+C(N-0HM+2TM+2T*"EMJ86Y=(%-%0U522519.B!#;&]S92!A;B!8
M4U,@:&]L92!I;B!T:&4@2%1-3"!V:65W97(L(&$@=F%R:6%T:6]N('1O('1H
M92!O;F4*("`@("`@<F5P;W)T960@:6X@:'1T<#HO+W=W=RYG<F5Y;6%G:6,N
M8V]M+W-E8W5R:71Y+V%D=FES;W)I97,O9VTP,#4M;6,O+@I;8VIH72!&:7@@
M97-C87!E9"!D;W5B;&4@<75O=&5S(&]N('-O;64@8G)O:V5N(&UA:6P@<V5R
M=F5R<R`H0G5G(",R.3(I+@I;:F%N72!#;VUM96YT(&-O;7!L971E(#QS='EL
M93X@=&%G<R!O=70@:6X@=&AE($A434P@=FEE=V5R('1O(&%V;VED($-34R!C
M;V1E"B`@("`@(&%P<&5A<FEN9R!I;B!T:&4@;65S<V%G92X*"@HM+2TM+2T*
M=C,N,BXT"BTM+2TM+0H*6V-J:%T@4T5#55))5%DZ($-L;W-E(&%N(%A34R!H
M;VQE(&5X<&QO:71E9"!V:6$@=&AE($-O;G1E;G0M='EP92!H96%D97(*("`@
M("`@;V8@;6%L:6-I;W5S(&5M86EL<RX*6VIA;ET@1FEX(&-O;G9E<G-I;VX@
M;V8@9F]L9&5R(&YA;65S(&EN('-O;64@;F]N+6%S8VEI(&-H87)S971S('=I
M=&@@8G5G9WD*("`@("`@:6-O;G8@:6UP;&5M96YT871I;VYS("A796YZ:'5O
M(%IH86YG(#QW96YZ:'5O0'IH;6%I;"YC;VT^*2X*6VIA;ET@1FEL=&5R(&]U
M="`\8F%S93X@=&%G<R!W:&5N('9I97=I;F<@2%1-3"!M97-S86=E<R`H0G5G
M(",Q,"DN"EMM;7-=($5N8V]D92!S=6)J96-T('=H96X@<V%V:6YG(&%S(&1R
M869T("A497)O($UA=&EN;&%S<VD*("`@("`@/'1E<F\N;6%T:6YL87-S:4!E
M9'4N=F%N=&%A+F9I/BDN"@H*+2TM+2TM"G8S+C(N,PHM+2TM+2T*"EMJ86Y=
M($9I>"!T:&4@)W5N9&5F:6YE9"!I;F1E>"!D:7)E8W1?86-C97-S)R!E<G)O
M<B!S=&EL;"!O8V-U<FEN9R!I;B!O8G-C=7)E"B`@("`@(&-A<V5S+@I;:F%N
M72!!9&0@26YD;VYE<VEA;B!L86YG=6%G92`H4VQA;6EN(#QS;&%M:6Y`=6YE
M:BYA8RYI9#XI+@I;:F%N72`\<W1Y;&4^(&%N9"`\;&EN:SX@=&%G<R!G970@
M8V]M;65N=&5D(&]U="!I;B!(5$U,(&UE<W-A9V5S('1O(&YO=`H@("`@("!A
M;&QO=R!T:&5M(&)R96%K:6YG('1H92!P86=E(&QA>6]U="X*6VIA;ET@061D
M($=A;&EC:6%N('1R86YS;&%T:6]N("A2869A96P@5F%R96QA(%!E="`\<W)R
M869A0'5S8RYE<SXL($=U:6QL97)M;PH@("`@("!-96YD97H@/&=U:6QL94!U
M<V,N97,^*2X*6VIA;ET@4F5M;W9E($A434P@=&%G<R!S:&]W:6YG('5P(&EN
M('-O;64@97)R;W(@;65S<V%G97,N"EMM;7-=(%1H92!S<&5L;"!C:&5C:R!F
M96%T=7)E(&YO=R!K965P<R!L:6YE<R!W<F%P<&5D(&%N9"!C;W)R96-T;'D@
M:&%N9&QE<PH@("`@("!A<&]S=')O<&AE<R!I;B!W;W)D<R!O;B!A;&P@87)C
M:&ET96-T=7)E<RX*"@HM+2TM+2T*=C,N,BXR"BTM+2TM+0H*6VUM<UT@6%-3
M('9U;&YE<F%B:6QI=&EE<R!I;B!T:&4@2%1-3"!V:65W97(@9FEX960@*%5L
M9B!(87)N:&%M;6%R"B`@("`@(#QU;&9`=7!D871E+G5U+G-E/BDN"EMJ86Y=
M($%D9"!!<F%B:6,@*%-Y<FEA*2!T<F%N<VQA=&EO;B`H4&QA=&EN=6T@1&5V
M96QO<&UE;G0@5&5A;0H@("`@("`\9&5V=&5A;4!P;&%T:6YU;2US>2YN970^
M*2X*6VIA;ET@061D($%R86)I8R`H3VUA;BD@=')A;G-L871I;VX@*%-A:60@
M06PM2&]S;FD@/&%D;6EN0'=A8FAO<W1I;F<N8V]M/BDN"EMJ86Y=($%D9"!-
M86-E9&]N:6%N('1R86YS;&%T:6]N("A3=&]J86X@4&5S;W8@/'-S<$!E=7)E
M:V$N8V]M+FUK/BDN"EMJ;VY=($%L;&]W('1H92!S<&%M(')E<&]R=&EN9R!S
M>7-T96T@=&\@86QS;R!U<V4@86X@97AT97)N86P@<')O9W)A;2X*6VIA;ET@
M061D($E-4#HZ<F9C.#(R5W)I=&5!9&1R97-S*"D@87,@82!R97!L86-E;65N
M="!F;W(@=&AE(&)U9V=Y"B`@("`@(&EM87!?<F9C.#(R7W=R:71E7V%D9')E
M<W,H*2!F=6YC=&EO;BX*6VIA;ET@061D(%1H86D@=')A;G-L871I;VX@*%-U
M<F%S86L@4W)I<V%W86X@/'-U<F%S86M`<FER8RYA8RYT:#XI+@I;:F%N72!!
M9&0@26-E;&%N9&EC('1R86YS;&%T:6]N("A":F]R;B!$879I9'-S;VX@/&)J
M;W-S:4!S;F5R<&$N:7,^*2X*6VUM<UT@0V]R<F5C="!D:7-P;&%Y(&]F(&9I
M;'1E<B!R=6QE<R!W:71H(")S<&5C:6%L(B!(5$U,(&-H87)A8W1E<G,N"@H*
M+2TM+2TM"G8S+C(N,0HM+2TM+2T*"EMM;7-=(%-E87)C:"!R97-U;'1S('!A
M9V4@9FEX960@=&\@8V]R<F5C=&QY(&QI;FL@=&\@;65S<V%G92!C;VUP;W-E
M(&EF"B`@("`@(&9R;VU?;&EN:R!S970@=&\@)V-O;7!O<V4G+@I;;6US72!#
M86YC96P@;F]W('=O<FMS(&-O<G)E8W1L>2!O;B!T:&4@<F5D:7)E8W0@<V-R
M965N('=H96X@;F]T(&-O;7!O<VEN9PH@("`@("!I;B!A(&YE=R!W:6YD;W<N
M"EMJ86Y=($9I>"!A;B`G=6YD969I;F5D(&EN9&5X(&1I<F5C=%]A8V-E<W,G
M(&5R<F]R(&9O<B!F:7)S="!T:6UE('5S97)S(&EN"B`@("`@(&-O;FIU;F-T
M:6]N('=I=&@@2&]R9&4@,BXQ+@I;;6US72!$;VXG="!S:&]W('!O<'5P(&YE
M=R!M86EL('=I;F1O=W,@;VX@;&]G:6XN"EMJ86Y=($9I>"!B=6<@8V%U<VEN
M9R!S;VUE($U)344@<&%R=',@=&\@;F]T(&)E(&1I<W!L87EE9"!C;W)R96-T
M;'DN"@H*+2TM+0IV,RXR"BTM+2T*"EMJ86Y=($%D9"!#871A;&%N('1R86YS
M;&%T:6]N("A!;F=E;',@1W5I;65RX"`\86YG96QS+D=U:6UE<F%`=6%B+F5S
M/BDN"EMM;7-=($-H96-K(&9O<B!I;G9A;&ED(#AB:70@8VAA<F%C=&5R<R!I
M;B!E;6%I;"!A9&1R97-S97,N"EMM;7-=($EM<')O=F5D(&1O=VYL;V%D(&QI
M;FMS('1H870@:&%N9&QE<R!V87)I;W5S(&)R;W=S97(@<75I<FMS(&UU8V@*
M("`@("`@8F5T=&5R('1H86X@8F5F;W)E+@I;;6US72!7;W)K87)O=6YD(&9O
M<B!M=6QT:7!A<G0O9F]R;2UD871A(&%N9"!)12`V*R!B<F]W<V5R<R!O;B!T
M:&4@8V]M<&]S90H@("`@("!P86=E+@I;;6US72!$;R!N;W0@86QL;W<@=&AE
M("=<)R!C:&%R86-T97(@:6X@9G5L;"!N86UE<R`H<V5E(%)&0R`R.#(R(%LS
M+C(N-5TI+@I;:F%N72!!9&0@24U0.CIU=&8W6T5N?$1E76-O9&4H*2!M971H
M;V1S('1H870@86QL;W<@;F]T(&]N;'D@:7-O+3@X-3DM,2!E;F-O9&5D"B`@
M("`@(&9O;&1E<B!N86UE<R!B=70@979E<GD@;F%M92!I;B!T:&4@8VAA<G-E
M="!O9B!T:&4@8W5R<F5N="!L86YG=6%G92X*6VUM<UT@0VAE8VL@9F]R(&EN
M=F%L:60@8VAA<F%C=&5R('-E=',@=VAE;B!P87)S:6YG('1E>'0O<&QA:6X@
M;65S<V%G97,N"EMM;7-=($%L;&]W(&9I;'1E<B!O;B!R969R97-H(&9R;VT@
M24U0('-U;6UA<GD@=FEE=RX*6VIA;ET@1FEX(&%T=&%C:&UE;G0@9&]W;FQO
M861S('=I=&@@3W!E<F$N"EMJ86Y=($%D9"!,871V:6%N('1R86YS;&%T:6]N
M("A+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^*2X*6VUM<UT@
M1&]N)W0@<VAO=R!A9&1R97-S8F]O:R!I8V]N(&9O<B!E+6UA:6P@861D<F5S
M<V5S(&]N('!R:6YT('-C<F5E;BX*6VIA;ET@061D(%)O;6%N:6%N('1R86YS
M;&%T:6]N("A#;W)N96QI=2!-55-!5"`\8VUU<V%T0'1I86UA="YK97ES>7,N
M<F\^*2X*6V-J:%T@0VQO<V4@<V5V97)A;"!S;6%L;"!84U,@=G5L;F5R86)I
M;&ET:65S"B`@("`@("A-:71J82!+;VQS96L@/&UI=&IA+FMO;'-E:T!A8W)O
M<RYS:3XI+@I;:F%N72!&:7@@871T86-H;65N="!D;W=N;&]A9',@=VET:"!)
M12!O=F5R(&AT='!S"B`@("`@("A,965N82!(96EN;R`\3&5E;F$N2&5I;F]`
M=71A+F9I/BDN"EMC:FA=($%D9"!A;B!O<'1I;VX@=&\@=7-E(&$@5D93(&9O
M<B!A='1A8VAM96YT('-T;W)A9V4@:68@86X@87!P<F]P<FEA=&4*("`@("`@
M2&]R9&4@=F5R<VEO;B`H,BXR(&]R(&QA=&5R*2!I<R!I;G-T86QL960N"EMC
M:FA=($%D9"!A;B!O<'1I;VX@=&\@9&ES<&QA>2!A(&-O;F9I<FUA=&EO;B!O
M9B!S96YD:6YG(&UE<W-A9V5S+"!I9B!Y;W4@87)E"B`@("`@(&YO="!U<VEN
M9R!A('!O<"UU<"!C;VUP;W-E('=I;F1O=RX*6VIO;ET@5&AE('-P86T@<F5P
M;W)T:6YG(&QI;FL@;F]W('-E;F1S('1H92!C;VUP;&5T92!M97-S86=E(&)O
M9'DL(&YO="!J=7-T"B`@("`@('1H92!F:7)S="`Q,&LN"EMM86-=($%D9"!T
M:&4@86)I;&ET>2!T;R!M;W9E+V-O<'D@;65S<V%G97,@=&\@82!N97<@9F]L
M9&5R+@I;:F%N72!3:&]W('1I;65O=70@=V%R;FEN9R!I9B!S97-S:6]N(&ES
M(&%B;W5T('1O(&5X<&ER92X*6VIA;ET@061D($E-4#HZ861D4&%R86UE=&5R
M*"DN"EMJ86Y=($%D9"!,:71H=6%N:6%N('1R86YS;&%T:6]N("A$87)I=7,@
M36%T=6QI875S:V%S(#QD87)I=7-`;&YK+FQT/BDN"EMJ86Y=($%D9"!"=6QG
M87)I86X@=')A;G-L871I;VX@*$UI<F]S;&%V(%!E;F1E=B`\<&5N9&5V0&AO
M=&UA:6PN8V]M/BDN"EMM;7-=(%)E8V5I=F5D(&AE861E<B!G96YE<F%T:6]N
M(&YO=R!C;VUP;&EA;G0@=&\@=&AE('!S975D;RUS=&%N9&%R9"!D969I;F5D
M"B`@("`@(&EN(%)&0R`R,3@Q+@I;8VIH72!5<V5R('!R969E<F5N8V5S+"!U
M;FQE<W,@;&]C:V5D+"!O=F5R<FED92!T:&4@9G)O;2!A;F0@9G5L;&YA;64@
M:&]O:W,N"EMM;7-=($%D9&5D(&EM86=E<R!-24U%7U9I97=E<BX*6VUM<UT@
M26YV86QI9"!A9&1R97-S97,@:61E;G1I9FEE9"!B>2!T:&4@8RUC;&EE;G0@
M;&EB<F%R>2!A<F4@;F]W(&AA;F1L960*("`@("`@;6]R92!C;&5A;FQY+@I;
M;6US72!396%R8V@@<F5S=6QT<R!W97)E(&YO="!A;'=A>7,@=V]R:VEN9R!W
M:71H(&%L;"!F96%T=7)E<R`M('1H:7,@:&%S(&)E96X*("`@("`@9FEX960@
M*$=E;V9F($AO<G0@/&<N:&]R=$!U;G-W+F5D=2YA=3XI+@H*"BTM+2T*=C,N
M,0HM+2TM"@I;:F%N72!!9&0@2'5N9V%R:6%N('1R86YS;&%T:6]N("A,87-Z
M;&\@3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS;W1E+FAU/BDN"EMC:FA=
M($-L96%N('5P('1H92!%;7!T>2!4<F%S:"!A8W1I;VXL(&%N9"!R971U<FX@
M>6]U('1O('1H92!S8W)E96X@>6]U('=E<F4@;VX*("`@("`@=VAE;B!Y;W4@
M8VQI8VME9"!T:&4@;65N=2!I=&5M+@I;:F%N72!5<V4@4TU44"!A=71H96YT
M:6-A=&EO;B!I9B`D8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==6R=A=71H)UT@
M:6X*("`@("`@:&]R9&4O8V]N9FEG+VAO<F1E+G!H<"!I<R!S970N"EMJ86Y=
M($%D9"!)35`Z.G!R97!A<F5-86EL97)(96%D97)S*"DN"EMJ86Y=($%D9"!.
M;W)W96=I86X@3GEN;W)S:R!T<F%N<VQA=&EO;B`H4&5R+5-T:6%N(%9A=&YE
M(#QP<W9`;W)S=&$N;W)G/BDN"EMJ86Y=($%D9"!3;&]V96YI86X@=')A;G-L
M871I;VX@*$IU<F4@2W)A<V]V:6,@/&IU<F5K0')C8RUI<F,N<VD^*2X*6V-J
M:%T@061D(&%N(&]P=&EO;B!F;W(@86QL;W=I;F<@<F5S=6UI;F<@;V8@86QL
M(&UE<W-A9V5S(&EN('1H92!$<F%F=',@9F]L9&5R"B`@("`@("A,:6%M($AO
M96ME;F=A(#QL:6%M<D!U;6EC:"YE9'4^*2X*6V-J:%T@1FEX('!R;V)L96US
M('=I=&@@:F%V87-C<FEP="P@244L(&%N9"`C(&EN(&9O;&1E<B!N86UE<RX*
M6VUI<ET@061D($5M<'1Y(%1R87-H(&UE;G4@:71E;2X*6VUI<ET@061D(&]P
M=&EO;B!T;R!E;7!T>2!A(&UA:6QB;W@@;VX@=&AE(&9O;&1E<G,@<V-R965N
M+@I;:F%N72!!9&0@2F%P86YE<V4@=')A;G-L871I;VX@*$(N2BX@0FQA8VL@
M/'=I;&QI86TN8FQA8VM`<W5N+F-O;3XI+@I;8VIH72!0<F]T96-T(&%G86EN
M<W0@;6]D:69I960@;&]G:6X@9F]R;7,N"EMM:7)=($%D9"!P<F5F97)E;F-E
M<R!T;R!C;VYT<F]L('%U;W1E(&%N9"!S:6=N871U<F4@:&EG:&QI9VAT:6YG
M+@I;8VIH72!$;VXG="!M86ME('1H92!U<V5R('-E;&5C="!A;B!A9&1R97-S
M8F]O:R!I9B!T:&5R92=S(&IU<W0@;VYE(&EN"B`@("`@('1H92!C;VYT86-T
M<R!I;G1E<F9A8V4N"EMC:FA=($-L;W-E(&$@<&]T96YT:6%L('!R;V)L96T@
M=VET:"!R96=I<W1E<E]G;&]B86QS($]N(&%N9"`D:G-?;VY,;V%D+@I;8VIH
M72!!9&0@9&]?;6%I;G1E;F%N8V4@<')E9F5R96YC92`H2G5L:6%N($IA<F5S
M(#QJ=6QI86Y`:F%R97,N8V]M+F%R/BDN"EMC:FA=($9I>"!E<G)O<G,@=VAE
M;B!T:&5R92!A<F4@;F\@<W5B<V-R:6)E9"!F;VQD97)S+@I;8VIH72!&:7@@
M82!P<F]B;&5M('=I=&@@<V]R=&EN9R!B>2!T:')E860L(%!/4#,L(&%N9"!D
M96QE=&EN9R!M97-S86=E<RX*6V-J:%T@1FEX($E-4"!S=6UM87)Y('=I=&@@
M4$]0,R!I9B!T:&4@=7-E<B!P;VQL<R!F;VQD97)S(&]T:&5R('1H86X@24Y"
M3U@N"EMC:FA=($-H86YG92!T;R!L:6(O5')E92YP:'`@=&AA="!F:7AE<R!F
M;VQD97(@<')O8FQE;7,@9F]R('-O;64@0WER=7,@=7-E<G,*("`@("`@*$1A
M=FED($ME<G)Y(#QI;7!`<VYT:2YC;VT^*2X*6V-J:%T@061D(&-O;G-T86YT
M<RYP:'`@<V\@=&AA="!T:&4@4T]25%1(4D5!1"!C;VYS=&%N="!C86X@8F4@
M=7-E9"!I;@H@("`@("!C;VYF:6<O<')E9G,N<&AP+@I;:F]N72!-86ME(&1I
M<W!L87EI;F<@=&AE(&UA:6QB;W@@;&5G96YD(&$@<&5R<V]N86P@<')E9F5R
M96YC92X*6V-J:%T@061D(&-O;7!O<V4@;&EN:R!T;R!T:&4@<W5M;6%R>2`H
M475I;FX@5VEL<V]N(#QQ=VEL<V]N0&UI9'=O<FQD+F]R9SXI+@I;8VIH72!)
M;7!R;W9E('1H92!,3T=)3E]#3TU03U-%(&9U;F-T:6]N86QI='D@=&\@<&%S
M<R!A;&]N9R!4;SHL($-C.BP@971C+@I;;6ER72!!9&0@861D<F5S<V)O;VL@
M:6YT97)F86-E('!O<'5P('1O('1H92!C;VUP;W-E('=I;F1O=RX*6VUA8UT@
M061D('-O<G0M8GDM=&AR96%D+@I;:F]N72!!9&0@/&QI;FL^(&5N=&ET>2!S
M=7!P;W)T+@I;8VIH72!3:6UP;&EF>2!A(&QO="!O9B!T:&4@<W!E;&QI;F<@
M;&]G:6,@86YD(&9I>"!P<F]B;&5M<R!W:71H('1H92!#:&%N9V4*("`@("`@
M06QL(&]P=&EO;BX*6V-J:%T@57-E($AO<F1E.CIG971&;W)M1&%T82@I(&EN
M(&9O;&1E<G,N<&AP(&%N9"!F:7@@<')O8FQE;7,@=VET:"!F;VQD97(*("`@
M("`@;F%M97,@:6YV;VQV:6YG('%U;W1E<RX*6V-J:%T@1FEX($E-4%]&;VQD
M97(Z.F5X:7-T<R@I(&9O<B!N86UE<R!W:71H('=I;&1C87)D<R!I;B!T:&5M
M+@I;8VIH72!&:7@@82!P<F]B;&5M('=I=&@@<&%S<W=O<F1S('1H870@96YD
M(&]R(&)E9VEN('=I=&@@<W!A8V5S+@I;8VIH72!0<F5F:7@@;&EN97,@<&%S
M<V5D('1O(&ES<&5L;"!W:71H(&$@)UXG+@I;:F%N72!!9&0@<')E9F5R96YC
M92!T:&%T('-E;&5C=',@=&AE('9I97<@;W(@;6%I;&)O>"!T;R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN+@I;8VIH72!$;VXG="!I;6%P7W5T9C=?9&5C;V1E*"D@
M9F]L9&5R<R!U;G1I;"!T:&5Y(&%R92!D:7-P;&%Y960@=&\@=&AE('5S97([
M"B`@("`@(&%L=V%Y<R!P87-S(&%R;W5N9"!A;F0@<W1O<F4@96YC;V1E9"!V
M86QU97,N"EMC:FA=($1O;B=T(&-A;&P@<V5S<VEO;E]S=&%R="@I(&%G86EN
M(&EN(&QO9VEN+G!H<"X*6V-J:%T@1V5T(')I9"!O9B!T:&4@<V5R=F5R7VQI
M<W1?:&ED9&5N(&]P=&EO;B!A;F0@8VAA;F=E('1H92!S97)V97)?;&ES=`H@
M("`@("!O<'1I;VX@=&\@8F4@96ET:&5R("=S:&]W;B<L("=H:61D96XG+"!O
M<B`G;F]N92<N"EMC:FA=(%-E="!T:&4@86QI9VX@5&\Z+"!#8SHL(&%N9"!"
M8V,Z(&QA8F5L(&-E;&QS('1O('1O<"X*6VIA;ET@4F5M;W9E('1H92`G9F]L
M9&5R<R<@<')E9F5R96YC92!I;B!F879O=7(@;V8@82!N97<@)V-H86YG95]F
M;VQD97(G"B`@("`@(&-O;F9I9W5R871I;VX@=&AA="!S971S(&EF(&$@9F]L
M9&5R<R!F:65L9"!I<R!D:7-P;&%Y960@;VX@;&]G:6XN"EMC:FA=(%)E;6]V
M92!T:&4@(F]R.B`B(&9R;VT@8F]X(&EN('1H92!C;VUP;W-E('-C<F5E;B!I
M9B!I9&5N=&ET:65S(&%R90H@("`@("!B96EN9R!U<V5D+@I;8VIH72!&:7@@
M82!P<F]B;&5M('=I=&@@9F]L9&5R('!R969I>&5S(&)E9VEN;FEN9R!W:71H
M(&$@)RXG(&%N9`H@("`@("!S:&]W7V1O=&9I;&5S('-E="!T;R!F86QS92X*
M6VIA;ET@061D('!R969E<F5N8V4Z(&EN8VQU9&4@;65S<V%G92!I;B!R97!L
M>2`H4F%M;VX@2V%G86X@/')K86=A;D!Y;W)K=2YC83XI+@I;8VIH72!&:7@@
M=&AE('!R:6YT:6YG(&IA=F%S8W)I<'0N"EMJ86Y=($%D9"!%<W1O;FEA;B!T
M<F%N<VQA=&EO;B`H5&]O;6%S($%A<R`\=&]O;6%S+F%A<T!R86%D+G1A<G1U
M+F5E/BDN"EMC:FA=(%1R:6T@;&]N9R!S=6)J96-T<R!I;B!T:&4@;65S<V%G
M92!S8W)E96X@:&5A9&5R('-O('1H870@;F%V:6=A=&EO;@H@("`@("!E;&5M
M96YT<R!R96UA:6X@:6X@82!C;VYS:7-T96YT('!L86-E(&9R;VT@;65S<V%G
M92!T;R!M97-S86=E+@I;:F%N72!!9&0@4VQO=F%K('1R86YS;&%T:6]N("A,
M96\@37)A9FMO(#QL96]`;V5L+G-K/BDN"EMJ86Y=($9I>"!S:&EF=&EN9R!O
M9B!S96QE8W1E9"!C:&5C:V)O>&5S(&EF(&-O;VMI97,@87)E(&1I<V%B;&5D
M+@I;8VIH72!&:7@@;&]T<R!O9B!F;VQD97(@:7-S=65S(&%N9"!G970@<FED
M(&]F('5N;F5C97-S87)Y('5R;&5N8V]D:6YG*"DN"EMC:FA=($UA:V4@=&AE
M(&9O;&1E<B!N879I9V%T;W(@=V]R:R!W:71H(&%D9&ET:6]N86P@9F]L9&5R
M(&AI97)A<F-H:65S"B`@("`@("AS=6-H(&%S(%57)W,@(W-H87)E9"\I+@I;
M:F%N72!);F-L=61E('!R:6YT(&9U;F-T:6]N<R!A;F0@97)R;W(@:&%N9&QI
M;F<@;VYL>2!I;B!T:&4@<')I;G0@=VEN9&]W"B`@("`@('1O('!R979E;G0@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T
M:6]N(B!M97-S86=E<RX*6V-J:%T@061D(')F8S@R,E]E>'!L;V1E*"D@=&\@
M:&%N9&QE(&5X<&QO9&EN9R!O9B!A9&1R97-S97,@:6=N;W)I;F<@<75O=&5D
M"B`@("`@(&]R(&5S8V%P960@8V]M;6%S("T@92YG+BP@(DQA<W1N86UE+"!&
M:7)S=&YA;64B(#QA9&1R97-S0&5X86UP;&4N8V]M/BX*6V-J:%T@1F]L9&5R
M(&YA;65S(&YE960@=&\@8F4@=7)L96YC;V1E9"!I;B!C;VUP;W-E(&QI;FMS
M('-O('1H870@9F]L9&5R"B`@("`@(&YA;65S('=I=&@@)R,G(&%N9"!O=&AE
M<B!C:&%R86-T97)S(&EN('1H96T@+2!L:6ME(%57)W,@(W-H87)E9"\*("`@
M("`@:&EE<F%R8VAY("T@=V]R:R!C;W)R96-T;'DN"EMC:FA=($UA:V4@<W5R
M92`D8V]N9ELG<V5R=F5R)UU;)W-H;W=?9&]T9FEL97,G72!I<R!H;VYO<F5D
M(&)Y('1H92!F;VQD97)S"B`@("`@('-C<F5E;B!A<R!W96QL(&%S(&)Y('1H
M92!D<F]P+61O=VX@;&ES=',N"EMC:FA=(%-W:71C:"!O=71P=70@8V]M<')E
M<W-I;VX@=&\@;V)?9WIH86YD;&5R*"DN"EMC:FA=(%5S92!)35!?5$5-4$Q!
M5$53(&-O;G-T86YT(&9O<B!A;&P@=&5M<&QA=&4@<&%T:',N"EMC:FA=(%5S
M92`D<F5G:7-T<GDM/F=E="@I(&9O<B!A;&P@4F5G:7-T<GD@:6YF;W)M871I
M;VXN"EMC:FA=($=E="!R:60@;V8@=6YN96-E<W-A<GD@24U07TY!344@8V]N
M<W1A;G0N"EMJ86Y=($%D9"!0;W)T=6=U97,@=')A;G-L871I;VX@*$YU;F\@
M3&]U<F5I<F\@/&YU;F]`971H+G!T/BDN"EMJ86Y=($9I>"!B=6<@=VET:"!M
M86EN=&5N86YC92!A;F0@;&]G:6X@=&\@=&AE(&9R86UE=V]R:RX*6VIA;ET@
M1FEX('!R;V)L96US('=I=&@@9F]L9&5R(&YA;65S('1H870@8V]N=&%I;B!S
M<&5C:6%L(&-H87)A8W1E<G,N"EMJ86Y=($9I>"!S<&5L;"!C:&5C:VEN9R!T
M;R!W;W)K('=I=&@@=&AE(&-H86YG960@<W1R7W1O:R@I(&)E:&%V:6]U<BX*
M6VIA;ET@061D(&UA:6QB;W@@86-T:6]N(")%;7!T>2!4<F%S:"!F;VQD97(B
M+@I;:F%N72!!9&0@1&%T93H@:&5A9&5R('=H96X@<V%V:6YG(&$@9')A9G0N
M"EMJ86Y=($UO=F4@=&AE(&9O<FT@=F%R:6%B;&4@:&%N9&QI;F<@9G)O;2!T
M:&4@;&EB<F%R:65S('1O('1H92!P86=E<RX*6VIA;ET@4VAO=R!A(&UO<F4@
M9&5T86EL960@97)R;W(@;65S<V%G92!I9B!S96YD:6YG(&$@;65S<V%G92!F
M86EL<RX@*$UI8VAA96P*("`@("`@4F5D:6YG97(@/$UI8VAA96PN4F5D:6YG
M97)`=6EB:RYA8RYA=#XI"EMJ86Y=($5S8V%P92!L;V=I;B!D871A(&-O<G)E
M8W1L>2X*6VIA;ET@4')E<V5L96-T(&-O<G)E8W0@:61E;G1I='D@=VAE;B!R
M97-U;6EN9R!D<F%F=',N"EMJ86Y=($9I>"!B=6<@:68@24U0(&1O97-N)W0@
M(G)E;65M8F5R(B!T:&4@=')A<V@@9F]L9&5R(&EN('1H92!P<F5F97)E;F-E
M<RX*6VIA;ET@4')E9F5R96YC97,@87)E(&YO=R!C;VYS:7-T96YT;'D@8V%L
M;&5D(&]P=&EO;G,@:6X@=&AE('=H;VQE('5I+@I;:F%N72!!9&0@8V]M;65N
M=',@9F]R('-E87)C:%]S;W5R8V5S(&%N9"!S96%R8VA?9FEE;&1S('!R969E
M<F5N8V5S+@I;:F%N72!&:7@@8G5G(&EN('1H92!M86EN=&5N86YC92!S96-T
M:6]N(&EF($E-4"!I<R!N;W0@:6X@=&AE(&1E9F%U;'0@9&ER96-T;W)Y+@I;
M:F%N72!!9&0@1&%N:7-H('1R86YS;&%T:6]N("A-87)T:6X@3&ES="U0971E
M<G-E;B`\;6%R=&EN0&QI<W0M<&5T97)S96XN9&L^*2X*6VIA;ET@2V5E<"!T
M:&4@<W1A=&4@;V8@86QL(&9O<FT@96QE;65N=',@:6X@=&AE(&-O;7!O<V4@
M=VEN9&]W(&1U<FEN9R!P86=E"B`@("`@(')E;&]A9',@*&5X<&%N9&EN9R!N
M86UE+"!S<&5L;"!C:&5C:VEN9RDN"@H*+2TM+0IV,RXP"BTM+2T*"EMJ86Y=
M(%5S92!T:&4@)W5S95]T<F%S:"<@<')E9F5R96YC92!I;G-T96%D(&]F('1H
M92`G97AP=6YG95]O;E]M;W9E)PH@("`@("!C;VYF:6=U<F%T:6]N('1O(&1E
M8VED92!I9B!W92!H879E('1O(&5X<'5N9V4@=&AE(&9O;&1E<G,N"EMA=G-M
M72!!9&0@+FAT86-C97-S(&9I;&5S('1O(&1E;GD@86-C97-S('1O(&1A=&$@
M9&ER96-T;W)I97,N"EMJ86Y=($%D9"!3=V5D:7-H('1R86YS;&%T:6]N("A!
M;F1R96%S($1A:&SI;B`\86YD<F5A<T!D86AL96XN=W,^*2X*6VIA;ET@061D
M($9I;FYI<V@@=')A;G-L871I;VX@*$QE96YA($AE:6YO(#QL:6EN=4!U=&$N
M9FD^*2X*6V-J:%T@4F4M861D(%-A=F4@07,@9F5A='5R92X*6VIA;ET@061D
M(%-W961I<V@@=')A;G-L871I;VX@*$%N9')E87,@1&%H;.EN(#QA;F1R96%S
M0&1A:&QE;BYW<SXI+@I;8VIH72!&:7@@<')O8FQE;7,@=VAE;B`D<')E9FEX
M(&]R("1N86UE<W!A8V4@:7,@86QS;R!A('-U8G-T<FEN9R!W:71H:6X*("`@
M("`@9F]L9&5R(&YA;65S+@H*"BTM+2TM+2TM"G8S+C`M4D,T"BTM+2TM+2TM
M"@I;<FEC:%T@26YC;'5D92!R97=R:71T96X@86YD(')E;W)G86YI>F5D(&1O
M8W5M96YT871I;VXN"EMJ86Y=($%D9"!P<F5F97)E;F-E<SH@8VQO<V4@=VEN
M9&]W(&%F=&5R('-A=FEN9R!D<F%F="P@<75O=&4@<')E9FEX+@I;:F%N72!!
M9&0@8V]M;65N=',@;VX@:&]W('1O('5S92!T:&4@<75O=&$@:&]O:R!W:71H
M($-O=7)I97(@*$IO<VAU82!%(%=A<F-H;VP*("`@("`@/&IW87)C:&]L0&1S
M;"YN970^*2X*6V%V<VU=($1I<V%B;&4@;6]N=&AL>2!M86EN=&%I;F%N8V4@
M;W!E<F%T:6]N<R!B>2!D969A=6QT+@I;8FIN72!#:&%N9V4@)V5N)R!A;F0@
M)V5N7T5.)R!L;V-A;&5S('1O("=E;E]54R<@*&1E9F%U;'0I+@I;8VIH72!&
M:7@@9FER<W0@<&%G92!C86QC=6QA=&EO;BX*"@HM+2TM+2TM+0IV,RXP+5)#
M,PHM+2TM+2TM+0H*6V-J:%T@4F5M;W9E(&]N8VQI8VL@979E;G1S(&EN('1H
M92!M86EL8F]X('9I97<@9F]R(&-O;G-I<W1E;F-Y(&%N9`H@("`@("!S:6UP
M;&EC:71Y+@I;8VIH72!"971T97(@97)R;W(@<F5P;W)T:6YG('=H96X@86X@
M871T86-H;65N="!U<&QO860@9F%I;',N"EMC:FA=($EF(&$@=&5X="!P87)T
M(&ES(&EN(&$@9&EF9F5R96YT(&-H87)A8W1E<B!S970L('1R>2!D:7-P;&%Y
M:6YG(&ET"B`@("`@(&EN;&EN92P@8G5T(&=I=F4@=&AE('5S97(@82!L:6YK
M('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@I;8VIH72!&:6QT97(@;W5T
M(&EF<F%M97,@86YD(&UE=&$@=&%G<R!I;B!(5$U,(&%T=&%C:&UE;G1S+@I;
M8VIH72!#:&5C:R!T;R!S964@:68@<V5N="UM86EL+6UT:"UY96%R(&%L<F5A
M9'D@97AI<W1S+"!A;F0@9VEV92!A('=A<FYI;F<L"B`@("`@(&EN<W1E860@
M;V8@9F%I;&EN9R!T:&4@<F5N86UE+"!I9B!I="!D;V5S+@I;;6US72!!9&0@
M;F5W('!R969E<F5N8V4@=&\@9&ES<&QA>2!I9B!A;GD@9FEL=&5R<R!H879E
M(&)E96X@87!P;&EE9"!T;PH@("`@("!A;GD@;65S<V%G92X*"@HM+2TM+2TM
M+0IV,RXP+5)#,0HM+2TM+2TM+0H*6VIA;ET@061D($=R965K('1R86YS;&%T
M:6]N("A3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-D:6UI=')I0'1E:6%T:"YG
M<CXI+@I;:F%N72!!9&0@2V]R96%N('1R86YS;&%T:6]N("A*+DD@2VEM(#QA
M<&]R:65`;F5T:6%N+F-O;3XI+@H*"BTM+2TM+0IV,BXS+C<*+2TM+2TM"@I;
M:F]N72!296YA;64@=&AE("=A<'!E;F1?:&5A9&5R)R!C;VYF:6=U<F%T:6]N
M('9A<FEA8FQE('1O("=P<F5P96YD7VAE861E<B<N"EMC:FA=(%5S92`B<F5D
M:7)E8W0B(&EN<W1E860@;V8@(F)O=6YC92(N"EMC:FA=($EN=')O9'5C92!A
M;B!)9&5N=&ET>5])35`@<W5B8VQA<W,@=&\@:&ED92!A;&P@;V8@=&AE($E-
M4"US<&5C:69I8PH@("`@("!H;V]K<R!A;F0@=71I;&ET>2!F=6YC=&EO;G,N
M"EMC:FA=($AI9VAL:6=H="!M97-S86=E<R!I;B!T:&4@;6%I;&)O>"!V:65W
M(&%S('1H97D@87)E(&UO=7-E9"!O=F5R("A!;&5X"B`@("`@($QE=F5R:6YG
M=&]N(#QA9&UI;D!N971W;W)K97-S96YC92YN970^*2X*6V-J:%T@3&5A=F4@
M<V5S<VEO;E]S=&%R="@I('1O('1H92!296=I<W1R>2X*6V-J:%T@3&5T('1H
M92!296=I<W1R>2!H86YD;&4@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX*6V-J
M:%T@268@=7-I;F<@82!L86YG=6%G92!T:&%T(&YE961S(&ET+"!A;&QO=R!S
M96QE8W1I;VX@;V8@=&AE(&-H87)S970@=&\*("`@("`@=FEE=R!M97-S86=E
M<R!I;B`H/&%N=&]N0'9A;'5E:&]S="YR=3XI+@I;:F%N72!%>'1E;F0@)VYA
M=E]E>'!A;F1E9"<@<')E9F5R96YC93H@17AP86YD(&9O;&1E<G,@;&EK92!T
M:&5Y('=E<F4@=&AE"B`@("`@(&QA<W0@=&EM92X*6VIA;ET@36]V92!A;&P@
M=&AE(&ED96YT:71Y('-T=69F(&EN=&\@82!S97!E<F%T92!C;&%S<R!A;F0@
M861D('-E;G0M;6%I;`H@("`@("!O<'1I;VYS('1O('1H92!I9&5N=&ET:65S
M+@I;8VIH72!&:7@@8VAA;F=I;F<@:61E;G1I=&EE<R!A9G1E<B!U<VEN9R!%
M>'!A;F0@3F%M97,N"EMC:FA=($UA:V4@=&AE('1E>'1A<F5A<R!F;W(@<VEG
M;F%T=7)E(&%N9"!M97-S86=E(&)O9'D@=7-E('1H92!W:61T:"!S970@:6X*
M("`@("`@=&AE('5S97(G<R!P<F5F97)E;F-E<RX*6V-J:%T@1FEX($)O=6YC
M92P@36]V92P@86YD($-O<'D@9G)O;2!W:71H:6X@82!S96%R8V@@<F5S=6QT
M<R!S970N"EMC:FA=($E-4"!N;W<@=7-E<R!(;W)D93HZ;&]G365S<V%G92@I
M(&9O<B!A;&P@;&]G9VEN9R!A8W1I=FET>2X*6VIA;ET@4F5N86UE('-E;G0M
M;6%I;"!F;VQD97(@8F%S960@;VX@=&AE(&]L9"!N86UE(&%N9"!R96-R96%T
M92!S96YT+6UA:6P*("`@("`@9F]L9&5R(&%F=&5R(')E;F%M:6YG(&1U<FEN
M9R!T:&4@;6%I;G1E;F%N8V4@=&%S:W,N"EMJ86Y=($%D9"!S96QE8W1I;VX@
M9FEE;&1S(&%F=&5R(&5X<&%N9&EN9R!N86UE<R!O;B!#8SH@86YD($)C8SH*
M6V-J:%T@4F5M;W9E('1H92`G;6%I;&AO<W0G(&%N9"!A<W-O8VEA=&5D('!R
M969E<F5N8V5S+"!A;F0@861D"B`@("`@("1C;VYF6R=S97)V97(G75LG8VAA
M;F=E7SQF;V\^)UT@<W=I=&-H97,@<V\@86QL;W<@8V]N=')O;"!O9B!T:&4@
M;&]G:6X*("`@("`@<V-R965N+@I;:F%N72!!9&0@4G5S<VEA;B!T<F%N<VQA
M=&EO;B`H06YT;VX@3F5K:&]R;W-H:6@@/&%N=&]N0'9A;'5E:&]S="YR=3XI
M+@I;:F%N72!!9&0@82!N97<@9FEE;&0@869T97(@97AP96YD:6YG(&YA;65S
M('1O(&%L;&]W(&%D9&EN9R!M;W)E(&%D9')E<W-E<RX*6VUA>%T@061D('-E
M=F5R86P@<V5A<F-H(&-R:71E<FEA('1O(&%N9"!C:&%N9V4@=&AE(%5)(&]F
M('1H92!S96%R8V@@<V-R965N+@I;:F%N72!!9&0@271A;&EA;B!T<F%N<VQA
M=&EO;B`H1VEO=F%N;FD@365N96=H971T:2`\9VUE;F5G:&5T=&E`:6YF=FEC
M+FET/BDN"EMM;7-=($%D9"!M86EN=&5N86YC92!O<&5R871I;VYS+@I;8VIH
M72!!9&0@1G)E;F-H(&AE;'`@9FEL92X*6VIA;ET@061D('-E;&5C="!F:65L
M9"!I9B`B97AP86YD(&YA;65S(B!R971U<FYS(&UO<F4@=&AA;B!O;F4@;6%T
M8VAI;F<*("`@("`@;F%M92]A9&1R97-S+@I;:F%N72!#:&]O<V4@8V]R<F5C
M="!I9&5N=&ET>2!I9B!R97!L>6EN9R!T;RP@9F]R=V%R9&EN9R!O<B!R97-U
M;6EN9R!A"B`@("`@(&UE<W-A9V4N"EMJ86Y=($%D9"!0;VQI<V@@=')A;G-L
M871I;VXN"EMJ86Y=(%-H;W<@<&5R<V]N86P@9FQA9R!F;W(@86QL(&ED96YT
M:71I97,N"EMJ86Y=($%D9"!S=7!P;W)T(&9O<B!I9&5N=&ET:65S('1O('1H
M92!C;VUP;W-E('=I;F1O=RX*6V-J:%T@2&%N9&QE(&$@8V]U<&QE(&]F(&-A
M<V5S('=H97)E('1H92!M86EL8F]X(&EN('1H92!S97-S:6]N(&AA<R!C:&%N
M9V5D"B`@("`@(&UO<F4@9W)A8V5F=6QL>2X*6VIA;ET@061D($9R96YC:"!T
M<F%N<VQA=&EO;B`H1G)E9&5R:6,@5')U9&5A=2`\9G1R=61E875`0T%-+D]2
M1SXI+@I;8VIH72!&:7@@<W!A;2!R97!O<G1S+"!A;F0@9VEV92!T:&4@=7-E
M<B!A;B!E<G)O<B!M97-S86=E(&QE='1I;F<@=&AE;2!K;F]W"B`@("`@('1H
M870@=&AE(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!R97!O<G1E9"X*6V-J
M:%T@061D($-Z96-H('1R86YS;&%T:6]N("AP8VAY=&EL0&%S<"YO9VDN961U
M*2X*6VIA;ET@061D(&YE=R!T:6UE>F]N92!H86YD;&EN9R!W:71H('-E;&5C
M="!B;W@@:6X@<')E9G,N"EMC:FA=($AA;F1L92!M;W9I;F<@;65S<V%G97,@
M8V]R<F5C=&QY('=H96X@2&ED92!$96QE=&5D(&ES(&]N+@I;8VIH72!!9&0@
M8FQA8VML:7-T:6YG(&-A<&%B:6QI='D@*&=E;F5R871E<R!F:6QT97)S('1O
M(&)L;V-K('-E;F1E<G,I+@I;879S;5T@5&AE(")N;W0@8V]N9FEG=7)E9"(@
M<&%G92!N;R!L;VYG97(@9&5P96YD<R!O;B!(;W)D92X*6V-J:%T@5'=E86L@
M=&AE(&UE<W-A9V4@54D@82!B:70N"EMA=G-M72!297!L86-E("1C;VYF6R=P
M871H<R==('=I=&@@=&AE("1R96=I<W1R>2!E<75I=F%L96YT<RX*6V%V<VU=
M(%-W:71C:"!)35`@;W9E<B!T;R!T:&4@2&]R9&4@34E-15]6:65W97(@9G)A
M;65W;W)K+@I;879S;5T@261E;G1I='D@961I=&EN9R!N;W<@86QL;W=S('-W
M:71C:&EN9R!B971W965N(&-R96%T92]E9&ET(&UO9&4N"EMC:FA=($%D9"!Q
M=6]T82!H;V]K("A-87)C($IA=79I;B`\;6%R8T!R96=I<W1E<C1L97-S+F-O
M;3XI+@I;8VIH72!5<V4@;VYC;&EC:STB(B!F;W(@=&AE(&IA=F%S8W)I<'0@
M=&AA="!O<&5N<R!A='1A8VAM96YT('=I;F1O=W,N"EMC:FA=(%-U<'!O<G0@
M<')I;G1I;F<@:6X@;VQD97(@8G)O=W-E<G,@=&AR;W5G:"!60E-C<FEP="X*
M6V-J:%T@061D("1(5%107TA/4U0@8F%S960@=FER='5A;"!H;W-T:6YG(&AO
M;VMS("A-87)C($IA=79I;@H@("`@("`\;6%R8T!R96=I<W1E<C1L97-S+F-O
M;3XI+@I;8VIH72!#871C:"!A(&9E=R!M;W)E('-N96%K>2!T:&EN9W,@:6X@
M=&AE(&AT;6P@<V%N:71I>FEN9R!R96=E>'!S+@I;8VIH72!-86ME('-U<F4@
M=&\@96YC;V1E(#@M8FET(')E8VEP:65N=',N"EMC:FA=($UA:V4@=&AE(&9O
M;&1E<B!T<F5E(&UO<F4@<F]B=7-T(&EN(&1E86QI;F<@=VET:"!F;VQD97(@
M<')E9FEX97,N"EMC:FA=($%D9"!A('-I9VYA='5R92!H;V]K('1O(&1Y;F%M
M:6-A;&QY('-E="!P87)T(&]R(&%L;"!O9B!A('5S97(G<PH@("`@("!S:6=N
M871U<F4@*$UA<F,@2F%U=FEN(#QM87)C0')E9VES=&5R-&QE<W,N8V]M/BDN
M"EMJ;VY=($-H86YG960@)&-O;F9;)VAO;VMS)UU;)V9R;VU?:&]O:R==('1O
M("1C;VYF6R=H;V]K<R==6R=F<F]M)UTN("!)="!N;W<*("`@("`@86-C97!T
M<R!A(&9U;F-T:6]N(&YA;64@9F]R(&$@=F%L=64N"EMC:FA=($-L96%R('1H
M92!W:&]L92!S97-S:6]N('=H96X@=&AE('5S97(@;&]G<R!O=70@86YD($E-
M4"!I<R!T:&4@2&]R9&4*("`@("`@875T:"!C;VYT<F]L;&QE<BX*6VIO;ET@
M061D960@<W5P<&]R="!F;W(@86X@;W!T:6]N86P@)W-M='!H;W-T)R`D<V5R
M=F5R<R!P87)A;65T97(N"EMC:FA=(%5S92!T:&4@*G5R;"@I(&9U;F-T:6]N
M<R!M;W)E(&-O;G-I<W1E;G1L>2!T;R!M86ME('-U<F4@=&AA=`H@("`@("!C
M;V]K:64M;&5S<R!S97-S:6]N<R!W;W)K+@I;8VIH72!!9&0@4VEM<&QI9FEE
M9"!#:&EN97-E('1R86YS;&%T:6]N("A786YG2&5N9U=E;B`\=VAW0&UY,38Y
M+F-O;2DN"EMJ;VY=(%)E;F%M960@=&AE("=D96QE=&5?<F5T=7)N)R!U<V5R
M('!R969E<F5N8V4@=&\@)VUA:6QB;WA?<F5T=7)N)RX*6VIO;ET@2&]N;W(@
M=&AE("=D96QE=&5?<F5T=7)N)R!P<F5F97)E;F-E(&%F=&5R(&UO=FEN9R!A
M;F0@8V]P>6EN9R!M97-S86=E<RX*6V-J:%T@1&]N)W0@9&ES<&QA>2!T:&4@
M9F]L9&5R('!R969I>"!I;B!T:&4@9F]L9&5R('1R964@*$5G86X*("`@("`@
M/&5G86Y`<V5V96YK:6YG<RYN970^*2X*6V-J:%T@061D("1C;VYF6R=M96YU
M)UU;)V%P<',G72!T;R!A9&0@;&EN:W,@=&\@;W1H97(@2&]R9&4@87!P;&EC
M871I;VYS(&EN"B`@("`@('1H92!M96YU(&)A<BX*6V-J:%T@06QL;W<@9F]R
M('!R;VUP=',@:6X@=&AE('-E<G9E<B!L:7-T("AE;G1R:65S('=H;W-E(&ME
M>7,@8F5G:6X@=VET:`H@("`@("`G7R<I(&%N9"!C;&5A;B!U<"!S;VUE(&]F
M('1H92!S97)V97(@;&ES="]L;V=I;B!L;V=I8RX*6V-J:%T@1FEX('1H92!,
M3T=)3E]#3TU03U-%(&%C=&EO;BX*6V-J:%T@57-E(&EM87!?9F5T8VA?;W9E
M<G9I97<H*2!T;R!B=6EL9"!T:&4@;6%I;&)O>"!I;F1E>"X@4VAO=6QD(&)E
M(&$@;&]T"B`@("`@(&YI8V5R('1O('1H92!)34%0('-E<G9E<BX*6V-J:%T@
M4V]R="!T:&4@9F]L9&5R(&1R;W`M9&]W;B!W:71H(&$@;F%T=7)A;"UO<F1E
M<B!A;&=O<FET:&TL(&-A<V4*("`@("`@:6YS96YS:71I=F4L('1O(&UA=&-H
M('1H92!F;VQD97)S('-C<F5E;BX*6V-J:%T@061D(%5)(&9O<B!F;VQD97(@
M9&]W;FQO860N"EMC:FA=(%5S92!P<F5F<RYG:68@86YD(&=E;F5R:6,@<')E
M9G,@=&5M<&QA=&5S(&9R;VT@2&]R9&4N"EMC:FA=($1O;B=T('=R87`@9F]R
M=V%R9&5D(&UE<W-A9V5S.R!T:&5Y('-H;W5L9"!B92!A;')E861Y('=R87!P
M960N"EMC:FA=($%D9"!A8W1U86P@4W!A;FES:"!T<F%N<VQA=&EO;B`H4F%U
M;"!!;'9A<F5Z(%9E;F5G87,*("`@("`@/')A=D!T96-O;6%N+G5C;VPN;7@^
M*2X*6VIA;ET@06QL;W<@;W!E;FEN9R!F;VQD97)S('=I=&@@;F5W(&UA:6P@
M9G)O;2!T:&4@;F]T:69I8V%T:6]N('!O<'5P+@I;:F]N72!-97)G92!D;V-T
M>7!E+FEN8R!I;G1O(&-O;6UO;BUH96%D97(N:6YC+@I;8VIH72!5<V4@:7-?
M=7!L;V%D961?9FEL92@I(&%N9"!(;W)D92!T96UP(&9I;&4@<F]U=&EN97,@
M=&\@;6%K92!S=7)E('1H870*("`@("`@=7!L;V%D960@9FEL97,@87)E('9A
M;&ED(&%N9"!A<F4@<W1O<F5D(&EN(')A;F1O;2!T96UP(&9I;&4@;F%M97,N
M"EMJ;VY=($%L;&]W('1H92!R96=I<W1R>2!T;R!H86YD;&4@24U0)W,@8V]N
M9FEG=7)A=&EO;B!V86QU97,N"EMJ;VY=($A/4D1%7T)!4T4@:7,@;F]W(&1E
M9FEN960@:6X@;&EB+V)A<V4N<&AP(&EN<W1E860@;V8@8V]N9FEG+V-O;F8N
M<&AP+@I;;6%X72!!9&0@<V5A<F-H(&%N9"!A9&0@861D<F5S<V)O;VL@=7-E
M<B!P<F5F97)E;F-E<RX*6VIO;ET@061D($1U=&-H('1R86YS;&%T:6]N(&9R
M;VT@2F%N($MU:7!E<G,@/&IR:W5I<&5R<T!L875W97)S8V]L;&5G92YN;#XN
M"EMJ;VY=($%D9"!A(&YE=R!U<V5R('!R969E<F5N8V4@=&\@9&5T97)M:6YE
M('=H971H97(@82!U<V5R(&ES(')E='5R;F5D('1O"B`@("`@('1H92!M86EL
M8F]X(&QI<W1I;F<@869T97(@82!M97-S86=E(&ES(&1E;&5T960N"EMM87A=
M($%D9"!P;W=E<G!O:6YT+79I97=E<BX*6VIO;ET@061D(&$@=&EM92!Z;VYE
M('5S97(@<')E9F5R96YC92X@($ET(&ES(&]N;'D@=7-E9"!F;W(@;W5T8F]U
M;F0@;65S<V%G97,N"EMJ;VY=($UA:V4@=&AE('1E>'0@=W)A<'!I;F<@=VED
M=&@@8V]N9FEG=7)A8FQE(&]N(&$@<&5R+75S97(@8F%S:7,N"EMC:FA=($%D
M9"!&<F5N8V@@=')A;G-L871I;VX@*$-H<FES=&]P:&4@4G5E;&QE(#QR=65L
M;&5`96-H;RYF<CXI+@I;8VIH72!#;&5A;B!U<"!T:&4@<W!E;&QI;F<@8V]D
M92P@9FEX:6YG('-O;64@<')O8FQE;7,@=VET:"!F;W)M(&1A=&$L"B`@("`@
M(&UU;'1I<&QE(&AT;6QS<&5C:6%L8VAA<G,H*2!C86QL<RP@86YD(&QO<VEN
M9R!T97AT('=H96X@9FEN:7-H:6YG('1H90H@("`@("!S<&5L;"!C:&5C:RX*
M6V-J:%T@36%K92!W:&5T:&5R(&]R(&YO="!T;R!U<V4@82!T<F%S:"!F;VQD
M97(@82!U<V5R('!R969E<F5N8V4N"EMC:FA=($-H96-K(&9O<B!U;F1E9FEN
M960@)W-I>F4G(&%T=')I8G5T92!O9B!A='1A8VAM96YT<SL@;F]R;6%L;'D*
M("`@("`@:6YD:6-A=&5S('1H870@=&AE(&9I;&4@=V%S('1O;R!L87)G92!T
M;R!B92!U<&QO861E9"!S=6-E<W-F=6QL>2X*6V-J:%T@4VAO=R!+0B!F;W(@
M871T86-H;65N=',@:6X@=&AE(&-O;7!O<V4@=VEN9&]W+"!I;G-T96%D(&]F
M(&)Y=&5S+@I;:F]N72!#;&5A;G5P('!R969E<F5N8V5S('5P;VX@;&]G;W5T
M+@I;8VIH72!!9&0@0G)A>FEL:6%N(%!O<G1U9W5E<V4@=')A;G-L871I;VX@
M*&AO<W1M87-T97)`<V)S+G-R=BYB<BDN"EMC:FA=($%D9"!N97<@;6%I;"!P
M;W!U<"`H:68@=&AE('!R968@:7,@96YA8FQE9"D@:6X@=&AE(&UA:6QB;W@@
M=FEE=R`H3FEC:PH@("`@("!5<W1I;F]V(#Q.:6-K+E5S=&EN;W9`=FED96EN
M9G)A+FQV/BDN"EMM87A=($%D9"!T:&4@<F5A;&T@9FEE;&0@=&\@;6%K92!L
M;V=I;G,@=6YI<75E(&]N(&UU;'1I+7-E<G9E<B!C;VYF:6=U<F%T:6]N<PH@
M("`@("!F;W(@<')E9F5R96YC97,@86YD(&%U=&AE;G1I8V%T:6]N+@I;;6%X
M72!!;&QO=R!)35`@=&\@8F4@86X@875T:&5N=&EC871I;VX@:&%N9&QE<B!F
M;W(@2&]R9&4N"EMC:FA=($1E9FEN92!T:&4@2$]21$5?0D%312!C;VYS=&%N
M="!I;B!C;VYF:6<O8V]N9BYP:'`L(&%N9"!U<V4@:70@=VAE;@H@("`@("!R
M969E<G)I;F<@=&\@86YY(&]F($AO<F1E)W,@9FEL97,N"EMM87A=(%)E;6]V
M92!C;VYN96-T:6]N('1R86-K:6YG+"!M861E(&]B<V]L971E(&)Y(')E9&ER
M96-T+G!H<"X*6V-J:%T@2&%N9&QE(&UU;'1I<&%R="]A;'1E<FYA=&EV92!C
M;W)R96-T;'DN"EMJ;VY=($1O;B=T('!R:6YT('1H92!"8V,Z(&QI<W0@:6X@
M=&AE('9I97=A8FQE(&UE<W-A9V4@:&5A9&5R<RX*6VIO;ET@4F5T:7)E9"!C
M;VYF:6<O;65N=2YT>'0@:6X@9F%V;W(@;V8@8V]N9FEG+VUE;G4N<&AP+B`@
M5&AI<R!F:6QE(&9O;&QO=W,*("`@("`@82!N97<@9F]R;6%T(&)A<V5D(&]N
M(&YA=&EV92!02%`@9&%T82!S=')U8W1U<F5S+@I;:F]N72!#:&%N9V5D(&-O
M;7!O<V4N<&AP)W,@8V%C:&EN9R!T;R`G<')I=F%T92P@;75S="UR979A;&ED
M871E)R!F;W(@3F5T<V-A<&4N"EMM87A=(%5S92!(;W)D92=S(')A:7-E365S
M<V%G92!O;B!C;VUP;W-E('-C<F5E;BX*6VIO;ET@57-E($AO<F1E)W,@=&5M
M<&]R87)Y(&9I;&4@<F]U=&EN97,N"EMM87A=(%5S92!T:&4@;F5W(%)E9VES
M=')Y.CH@9G)A;65W;W)K('1O(&%D9"!A9&1R97-S97,@=&\@5'5R8F$N"EMC
M:FA=($%L;&]W('!U<F=I;F<@;V8@9&5L971E9"!M97-S86=E<R!F<F]M('-E
M87)C:"!R97-U;'1S+@I;8VIH72!5<V4@=&AE(&YE=R!296=I<W1R>3HZ(&9R
M86UE=V]R:R!T;R!E>'!A;F0@861D<F5S<V5S(&9R;VT@5'5R8F$*("`@("`@
M861D<F5S<V)O;VMS("AO<B!A;GET:&EN9R!E;'-E('1H870@:6UP;&5M96YT
M<R!T:&4@8V]N=&%C=',O97AP86YD($%022DN"EMC:FA=($9I>"!S;VUE('!R
M;V)L96US('=I=&@@;6%I;'1O.B!G96YE<F%T960@;&EN:W,L('-U<'!O<G0*
M("`@("`@;6%I;'1O.F%D9')E<W,_<W5B:F5C=#UF;V\L(&5T8RXL(&%N9"!M
M86ME(&-O;7!O<V4@;65S<V%G92!M;W5S96]V97)S"B`@("`@(&UO<F4@8V]N
M<VES=&5N="!I;B!A;&P@<&%R=',@;V8@=&AE(%5)+@I;8VIH72!296YA;64@
M34]41"YH=&UL('1O(&UO=&0N<&AP+"!A;F0@;6]V92!T;R!A("YD:7-T(&9I
M;&4N"EMC:FA=(%)E+6%D9&5D(&]N8VAA;F=E(&IA=F%S8W)I<'0@9F]R('1H
M92!M96YU('-E;&5C="P@8G5T('=I=&@@80H@("`@("!J879A<V-R:7!T(&=U
M87)D('1O(&%V;VED(')E<&5A=&5D('!A9V4@;&]A9',@=VAE;B!A8V-I9&5N
M=&%L;'D*("`@("`@<V-R;VQL:6YG('1H<F]U9V@@=VET:"!A('=H965L(&UO
M=7-E+@I;:F]N72!&:7AE9"!);BUR97!L>2UT;SH@86YD(%)E9F5R96YC97,Z
M(&AE861E<G,N("!297!L>2!T:')E861I;F<@=V]R:W,@86=A:6XN"EMC:FA=
M(%)E;6]V92!P87-S=V]R9"!C:&%N9VEN9R!C;V1E.R!I="!B96QO;F=S(&EN
M($=O;&QE;2X*6V-J:%T@0V]N=F5R="!T86)S(&EN('1E>'0@<&%R=',@=&\@
M."!S<&%C97,@9F]R('!R;W!E<B!D:7-P;&%Y+@I;8VIH72!&:7@@9&5L971I
M;VXO=6YD96QE=&EO;B!O9B!M97-S86=E<R!I;B!S96%R8V@@<F5S=6QT<R!F
M<F]M(&UE<W-A9V4@=FEE=RX*6V-J:%T@1FEX(&9I<G-T(&YE=R!M97-S86=E
M(&1E=&5C=&EO;BP@:&]P969U;&QY(&9O<B!R96%L('1H:7,@=&EM92X*6V-J
M:%T@5FES=6%L('1W96%K<R!T;R!T:&4@9F]L9&5R('1R964@=&\@;6%K92!T
M:&EN9W,@;&EN92!U<"!B971T97(N"EMC:FA=(%-O<G0@<V5A<F-H(')E<W5L
M=',@86-C;W)D:6YG('1O('!R969E<F5N8V5S+@I;8VIH72!296YA;64@9V5T
M7V9R;VTH*2!T;R!G971&<F]M061D<F5S<R@I+"!A;F0@8VQE86X@=7`@=&AE
M(&QO9VEC('-O('1H870*("`@("`@:68@=7-E<G,@87)E(&%L;&]W960@=&\@
M8VAA;F=E('1H96ER(&%D9')E<W-E<R!O<B!F=6QL;F%M97,L('1H97D@8V%N
M"B`@("`@(&1O('1H96T@;VX@82!O;F4M=&EM92!B87-I<R!B>2!E9&ET:6YG
M('1H92!&<F]M.B!L:6YE(&EN('1H92!C;VUP;W-E"B`@("`@('-C<F5E;BX*
M6VIO;ET@4F5T:7)E9"`D8V]N9ELG=7-E<B==6R=A;&QO=U]F:6QT97)S)UTN
M("!!9&UI;FES=')A=&EV96QY(&QO8VMI;F<@=&AE"B`@("`@("=F:6QT97)S
M)R!P<F5F97)E;F-E('!R;V1U8V5S('1H92!S86UE(&)E:&%V:6]R+@I;8VIH
M72`D8V]N9ELG=7-E<B==6R=A;&QO=U]D:7)E8W1O<GE?<V5A<F-H)UT@:7,@
M9V]N93L@=V4@;F]W(&IU<W0@8VAE8VL@86YD"B`@("`@('-E92!I9B!A(&-O
M;G1A8W0@;6%N86=E<B!I<R!R96=I<W1E<F5D('=I=&@@2&]R9&4L(&%N9"!L
M:6YK('1O(&ET(&EF"B`@("`@(&ET(&ES+@I;8VIH72!.=6ME(&%L;6]S="!A
M;&P@/&9O;G0^('1A9W,*6V-J:%T@1FEX(&%L;"!C:&5C:W,@86=A:6YS="!T
M:&4@<')O=&]C;VP@=&\@=7-E('-T<G-T<BP@<V\@=&AE>2!W;W)K"B`@("`@
M(&%G86EN<W0@96ET:&5R(&EM87`@;W(@:6UA<"]S<VP@86YD('!O<#,@;W(@
M<&]P,R]S<VPN"EMC:FA=(%-I;7!L:69Y(&$@8FET(&]F('1H92!-24U%('-T
M=69F("T@9V\@;V9F(&]F('1H92!#;VYT96YT+41I<W!O<VET:6]N"B`@("`@
M(&]F('!A<G1S(&UO<W0@;V8@=&AE('1I;64L('=I=&@@:G5S="!A;B!O<'1I
M;VX@=&\@;F5V97(@<VAO=R!P87)T<PH@("`@("!I;FQI;F4@:6X@=&AE(&-O
M;F8@9FEL92X@06QS;RP@<F5M;W9E('1H92!O=F5R<FED95]T97AT(&]P=&EO
M;BP@86YD(&$*("`@("`@9F5W(&]T:&5R(&-L96%N=7!S+@I;8VIH72!!(&9E
M=R!C:&%N9V5S('-O('1H870@=V4@8V%N('!R;W!E<FQY('-U<'!O<G0@=&AE
M(&YE=VQY+7=O<FMI;F<*("`@("`@:6UA<"]S<VP@86YD('!O<#,O<W-L('-U
M<'!O<G0@:6X@<&AP+@I;:F]N72!5<&1A=&5D('!R969E<F5N8V5S(&9U;F-T
M:6]N<R!T;R!M871C:"!T:&4@;F5W($AO<F1E('!R969E<F5N8V5S($%022X*
M6V-J:%T@5')I;2!S;VUE('5N=7-E9"!J879A<V-R:7!T(&9R;VT@=&AE(&-O
M;7!O<V4@<V-R965N+"!A;F0@9FEX('1H92!)10H@("`@("!S=6)J96-T(&9I
M96QD(&ME>7!R97-S(&AA8VLN"EMC:FA=($UO9&EF>2!T:&4@9&5F875L="!M
M:6UE+G!H<"!C;VYF:6=U<F%T:6]N('-O('1H870@=&AI;F=S(&QI:V4@:6-O
M;G,*("`@("`@87)E(&%S<VEG;F5D('1O(&9I;&4@='EP97,@979E;B!I9B!W
M92!D;VXG="!H879E(&$@=FEE=V5R(&9O<B!T:&%T"B`@("`@(&9I;&4@='EP
M92X*6V-J:%T@06QL;W<@)RLG('1O('1E<FUI;F%T92!54DQS+@I;8VIH72!4
M:&4@<')E9F5R96YC97,@1U5)(&ES(&YO=R!B=6EL="!A;&UO<W0@96YT:7)E
M;'D@;VX@=&AE(&9L>2P@=VET:"!O;FQY"B`@("`@(&$@9F5W(&)I=',@=&AA
M="!A<F4@<W!E8VEF:6,@=&\@24U0+@I;8VIH72!&:7@@86X@:6YF:6YI=&4@
M;&]O<"!W:71H(&EN=F%L:60@9F]L9&5R('!R969I>&5S(&EN('1H92!F;VQD
M97(@=FEE=RX*6V-J:%T@4F5O<F=A;FEZ92!T:&4@<')E9F5R96YC97,@:6YT
M;R!M=6QT:7!L92P@<VUA;&P@<V-R965N<RX@0VAA;F=E"B`@("`@('!A<W-W
M;W)D(&%N9"!&:6QT97)S(&%R92!B;W1H(&%C8V5S<VEB;&4@=&AR;W5G:"!T
M:&4@;W!T:6]N<R!S8W)E96X@;F]W+@I;8VIH72!#;&]S92!A(&AO;&4@:6X@
M=&AE(&AT;6P@871T86-H;65N="!C;&5A;FEN9R!C;V1E+@I;8VIH72!&:7@@
M<W!A;2!R97!O<G1I;F<@=&\@=7-E('1H92!N97<@34E-12!A<&DN"EMC:FA=
M(%5S92!A<G)A>5]S;&EC92@I(&EN<W1E860@;V8@82!F;W(@;&]O<"!I;B!)
M35!?365S<V%G93HZ<F%N9V4H*2X*6V-J:%T@57-E(&UE<W-A9V4@;&ES=',@
M86YD($947U5)1"!W:&5N(&1E;&5T:6YG+W5N9&5L971I;F<@;65S<V%G97,N
M"EMC:FA=(%-A9F5G=6%R9',@86=A:6YS="!E<G)O<G,@:68@82!M97-S86=E
M(&1O97,@;F]T(&5X:7-T(&]R(&ES"B`@("`@(&EN8V]R<F5C=&QY(')E<75E
M<W1E9"X*6V-J:%T@)&-O;F9;)W-E<G9E<B==6R=T;U]D;VUA:6XG72!I<R!N
M;W<@9V]N92P@86QO;F<@=VET:`H@("`@("`D<V5R=F5R<ULG9F]O)UU;)W1O
M7VAO<W0G72P@)'-E<G9E<G-;)V9O;R==6R=F<F]M7VAO<W0G72P@86YD"B`@
M("`@('1H92!M86EL9&]M86EN('!R969S('9A;'5E+B!4:&5S92!A<F4@86QL
M(&YO=R!R97!R97-E;G1E9"!B>0H@("`@("`D<V5R=F5R<ULG9F]O)UU;)VUA
M:6QD;VUA:6XG72X@57!D871E('EO=7(@8V]N9FEG=7)A=&EO;G,@86-C;W)D
M:6YG;'DN"EMC:FA=("1C;VYF6R=S97)V97(G75LG;F%M97-P86-E)UT@:7,@
M9V]N92P@:6X@9F%V;W(@;V8@=&AE('5S92!O9@H@("`@("`D<V5R=F5R<ULG
M9F]O)UU;)VYA;65S<&%C92==+@I;;6%X72!!;&QO=R!S96QE8W1I;F<@;75L
M=&EP;&4@9FEE;&1S(&EN(&9I;'1E<G,N"EMC:FA=(%=H96X@9F5T8VAI;F<@
M82!M:6UE('!A<G0@9G)O;2!T:&4@3V)J96-T4W1O<F4@9F%I;',L(&-O<G)E
M8W1L>2!F86QL"B`@("`@(&)A8VL@86YD('!A<G-E('1H92!M97-S86=E('1O
M(&9I;F0@:70N"EMC:FA=(%=H96X@<F5S=6UI;F<@;W(@9F]R=V%R9&EN9R!M
M97-S86=E<R!W:71H(&%T=&%C:&UE;G1S+"!D;VXG="!D=7!L:6-A=&4*("`@
M("`@<&%R=',N"EMC:FA=($5V97)Y=&AI;F<@:6X@;&EB+TE-4"YP:'`@;F]W
M(&QI=F5S(&EN<VED92!T:&4@24U0.CH@8VQA<W,L(&%N9"!T:&4*("`@("`@
M<&AP9&]C(&1O8W5M96YT871I;VX@:7,@=7`@=&\@<W!E8RX*6V-J:%T@1&5F
M:6YE(&%N($E-4%]"05-%(&-O;G-T86YT('5S960@=VAE<F5V97(@:6YC;'5D
M:6YG(&9I;&5S('1O(&UA:V4@<W5R90H@("`@("!T:&%T(&9I;&5S(&%R92!I
M;F-L=61E9"!R96QA=&EV92!T;R!W:&5R92!)35`@:7,@:6X@=&AE(&9I;&5S
M>7-T96TN(%1H:7,*("`@("`@86QL;W=S($E-4"!S8W)I<'1S('1O(&)E(&EN
M8VQU9&5D(&9R;VT@;W1H97(@<V-R:7!T<R!I;B!C;VUP;&5T96QY"B`@("`@
M(&1I9F9E<F5N="!H:65R87)C:&EE<R!A;F0@<W1I;&P@=V]R:RX*6VIO;ET@
M36%K92!S=7)E("XO8V]N9FEG+W1R86EL97(N='AT(&ES(')E861A8FQE(&)E
M9F]R92!W92!T<GD@=&\@=7-E(&ET+@I;8VIH72!&:7@@82!C;W5P;&4@;V8@
M<')O8FQE;7,@=VET:"!I;6%P('-U8G-C<FEP=&EO;G,@86YD('5T9C<M96YC
M;V1E9`H@("`@("!M86EL8F]X(&YA;65S+@I;8VIH72!-;W9E($E-4%]&;VQD
M97(Z.F1I<W!L87E.86UE*"D@=&\@24U07U5T:6PZ.F1I<W!L87E&;VQD97(H
M*2P@87,@:70@:7,*("`@("`@=7-E9"!I;B!P;&%C97,@=&AA="!D;VXG="!U
M<V4@=&AE(')E<W0@;V8@=&AE(&9O;&1E<G,@8V]D92X*6V-J:%T@5&AE(&QO
M9VEN(&9O<FT@;F]W('!O<W1S('1O(')E9&ER96-T+G!H<"`H<F5N86UE9"!F
M<F]M"B`@("`@(')E;6]T95]L;V=I;BYP:'`I('-O(&%S('1O(&%V;VED('!O
M<W1I;F<@9&ER96-T;'D@=&\@=&AE(&UA:6QB;W@@<&%G92X*("`@("`@5&AI
M<R!A=F]I9',@<V]M92!P<F]B;&5M<R!W:71H(")086=E($5X<&ER960B(&5R
M<F]R<RX*"@HM+2TM+2T*=C(N,RXV"BTM+2TM+0H*6VIO;ET@061D960@)&-O
M;F9;)V-O;7!O<V4G75LG86QL;W=?<F5C96EP=',G72!T;R!C;VYT<F]L('=H
M971H97(@82!U<V5R(&-A;@H@("`@("!R97%U97-T(&$@<F5T=7)N(')E8V5I
M<'0@9G)O;2!T:&4@8V]M<&]S92!S8W)E96XN"EMC:FA=(%)E=F%M<"!T:&4@
M871T86-H;65N="!D;W=N;&]A9&EN9R!C;V1E+B!!="!T:&4@;6]M96YT+"!I
M="!W;W)K<R!W:71H"B`@("`@(&5V97)Y(&)R;W=S97(@22!C86X@=&5S="X*
M6VUA>%T@36%K92!)35`@6$A434P@,2XP(&-O;7!L:6%N="X*6V-J:%T@4&%S
M<R!T:&4@<F5S=6QT<R!O9B!G971?8F%R969R;VTH*2!T;R!T:&4@<')O8FQE
M;2!R97!O<G1I;F<@<&%G92!A<PH@("`@("!T:&4@96UA:6P@861D<F5S<R!T
M;R!U<V4N"EMC:FA=($UO=F4@;F%V:6=A=&]R+G!H<"!T;R!F;VQD97)S+G!H
M<"X*6VUA>%T@061D(&YU;6)E<B!O9B!W;W)D<R!P97(@<W!E;&QI;F<@<V-R
M965N('5S97(@<')E9F5R96YC92!A;F0@8G)I;F<*("`@("`@<W!E;&QI;F<@
M=7`@=&\@:&]R9&4@8V]D:6YG('-T86YD87)D+@I;8VIH72!-86ME($E-4"!W
M;W)K('=I=&@@<F5G:7-T97)?9VQO8F%L<R`]($]F9B!A;F0@;6%G:6-?<75O
M=&5S7V=P8R`]($]N+@H@("`@("`H24X@4%)/1U)%4U,I"EMA=G-M72!-;W9E
M(&YA=FEG871O<B!R969R97-H:6YG('1O(&$@=7-E<BUP<F5F97)E;F-E+"!A
M;F0@87!P;'D@:70@=&\*("`@("`@('1H92!M86EL8F]X('9I97<@87,@=V5L
M;"X*6V-J:%T@1FEX('9I97=I;F<@2%1-3"!M97-S86=E<R!W:71H(&EN;&EN
M92!I;6%G97,N"EMC:FA=($%D9"!)35`Z.G!A<G13=6UM87)Y*"D@*&9O<FUE
M<FQY(&UI;65?<W5M;6%R>2@I*2!S:6YC92!I="!I<PH@("`@("!)35`M<W!E
M8VEF:6,N"EMC:FA=($%D9"!T:&4@86)I;&ET>2!T;R!S96%R8V@@8GD@5&\Z
M(&9I96QD+@I;8VIH72!!9&0@2&]R9&4Z.G)A:7-E365S<V%G92@I(&5R<F]R
M(')E<&]R=&EN9R!T;R!T:&4@24U07VUE<W-A9V4Z.B!C;&%S<RX*6V-J:%T@
M06QL;W<@8W)E871I;VX@;V8@=&]P+6QE=F5L(&9O;&1E<G,@:6X@;F%V:6=A
M=&]R+G!H<"X*6VUA>%T@36]V92!J879A<V-R:7!T(&9U;F-T:6]N<R!O;B!T
M:&4@9FEL=&5R<R!S8W)E96X@=&\@=&AE(&)E9VEN;FEN9PH@("`@("!O9B!T
M:&4@<&%G92X*6V%V<VU=($%L;&]W(&$@=7-E<BUD969I;F5D('-E="!O9B!F
M;VQD97)S('1O(&)E('!O;&QE9"!F;W(@;F5W(&UA:6P*("`@("`@:6X@=&AE
M(&YA=FEG871O<@I;:F]N72!-86ME(&EN;&EN92!E;6%I;"!A9&1R97-S97,@
M:6YT;R!C;VUP;W-E(&QI;FMS+@I;:F]N72!!9&1E9"`D8V]N9ELG=7-E<B==
M6R=A;&QO=U]R97-U;65?86QL)UTN("!5;FQE<W,@:70G<R!T<G5E+"!O;FQY
M"B`@("`@(&UE<W-A9V5S(&UA<FME9"!A<R`G9')A9G1S)R!C86X@8F4@<F5S
M=6UE9"X*6V%V<VU=($%D9"`G<W5B<V-R:6)E+W5N<W5B<V-R:6)E)R!T;R!T
M:&4@86-T:6]N<R!L:7-T(&EN('1H92!N879I9V%T;W(*6V%V<VU=(%=H96X@
M=7-I;F<@<W5B<V-R:6)E(&UO9&4L('-H;W<@82!T;V=G;&4@:6X@=&AE(&YA
M=FEG871O<B!T;R!A;&QO=PH@("`@("!T:&4@=7-E<B!T;R!V:65W('5N<W5B
M<V-R:6)E9"!F;VQD97)S(&%L<V\N"EMC:FA=(%)E;6]V92!.3E10('-U<'!O
M<G0@9F]R(&YO=R!S:6YC92!I="=S(&YO="!R96%L;'D@9G5N8W1I;VYA;"P@
M86YD('=E"B`@("`@(&AA=F4@5')O;&PN"EMC:FA=($%D9"!I;6%P+W-S;"!A
M<R!A('!R;W1O8V]L(&]P=&EO;BX*6V-J:%T@061D(&IA=F%S8W)I<'0@=&\@
M=&AE('!R969E<F5N8V5S('-C<F5E;B!T;R!L970@=7-E<G,@8W)E871E(&YE
M=PH@("`@("!F;VQD97)S(&9O<B!S96YT+6UA:6P@86YD(&1R869T<RX*6VUA
M>%T@2F%V87-C<FEP="!U<V%B:6QI='D@8VAA;F=E<R!T;R!T:&4@9FEL=&5R
M<R!S8W)E96XN"EMM87A=($%D9"!M86EL(&9I;'1E<FEN9R!R=6QE<R!F=6YC
M=&EO;F%L:71Y(&%N9"!T:&4@87-S;V-I871E9"!P<F5F97)E;F-E<RX*6V-J
M:%T@061D($E-4%]&;VQD97(Z.F1I<W!L87E.86UE*"D@86YD('5S92!I="!F
M;W(@86YY('5S97(@;65S<V%G97,N"EMC:FA=($AA;F1L92!M;W)E(&]P=&EO
M;G,@;VX@<V5A<F-H('-E=',@*')E<&QY:6YG+"!E=&,N*2!M;W)E(&=R86-E
M9G5L;'DN"EMC:FA=($AI9&4@=&AE(&9O;&1E<G,@<')E9FEX(&9R;VT@=&AE
M('5S97(@:6X@9F]L9&5R(&YA=FEG871O<B!J879A<V-R:7!T"B`@("`@(&UE
M<W-A9V5S+@I;8VIH72!296UO=F4@=&AE("1P<F5A;6)L92!A<F=U;65N="!F
M<F]M($E-4%]&;VQD97(Z.G)E;F%M92@I+@I;8VIH72!#;&5A;B!U<"!T<F%S
M:"!F;VQD97(@9G5N8W1I;VYA;&ET>3L@:70@7W-H;W5L9%\@=V]R:R!N;W<N
M"EMA=G-M72!!9&0@<W5C8V5S<R!M97-S86=E<R!F;W(@=&AE(&-R96%T92]R
M96YA;64O9&5L971E(&9O;&1E<B!O<&5R871I;VYS+@I;879S;5T@0V]N=F5R
M="!T:&4@;F%V:6=A=&]R('1O(&-H96-K8F]X97,@=&\@86QL;W<@;75L=&EP
M;&4@;W!E<F%T:6]N<RX*6V-J:%T@57-E('1H92!N97<@2&]R9&4Z.G)A:7-E
M365S<V%G92@I(&UE=&AO9"!I;B!T:&4@24U07T9O;&1E<CHZ(&-L87-S+"!A
M;F0*("`@("`@9&ES<&QA>2!M97-S86=E(&%N9"!)34%0(&%L97)T<R!R:6=H
M="!A9G1E<B!T:&4@;65N=2X*6V-J:%T@57-E('-E;&5C="!L:7-T<R!T;R!P
M:6-K('1H92!S96YT+6UA:6P@86YD(&1R869T<R!F;VQD97)S+@I;8VIH72!5
M22!T=V5A:W,@;VX@=&AE('!R969E<F5N8V5S('-C<F5E;BP@86YD('5S92!C
M;VUP<F5S<VEO;B!I9B!I="=S(&5N86)L960N"EMC:FA=(%5)('1W96%K<R!T
M;R!T:&4@9F]L9&5R(&YA=FEG871O<B!T;R!I;F-L=61E(&%C=&EO;G,@870@
M=&AE(&)O='1O;2!O9@H@("`@("!T:&4@<&%G92!A<R!W96QL+@I;8VIH72!-
M86ME('5S92!O9B!N97<@4F5G:7-T<GDZ.B!F96%T=7)E<R!T;R!N;W0@:&%R
M9&-O9&4@=&AE('!A=&@@=&\*("`@("`@8V]M<&]S92YP:'`@:6X@;&EB+VIS
M+V]P96Y?8V]M<&]S95]W:6XN:G,N"EMC:FA=($AE879I;'D@8V]M;65N=&5D
M(&-O;F9I9R]C;VYF+G!H<"YD:7-T+@I;879S;5T@36%K92!F;VQD97(@<W5B
M<V-R:7!T:6]N<R!A('!E<BUU<V5R('!R969E<F5N8V4L(&EN<W1E860@;V8@
M9VQO8F%L+@I;8VIH72!%;F-R>7!T('!A<W-W;W)D<R!I;B!S97-S:6]N(&1A
M=&$L('5S:6YG(&$@:V5Y('-T;W)E9"!I;B!A(&-O;VMI92!O<@H@("`@("!M
M:6QD;'D@;V)S8W5R960@9G)O;2!T:&4@<V5S<VEO;B!I9"!A;F0@<VET96YA
M;64@<V5T=&EN9RX*6V-J:%T@1FEX(&)O=6YC:6YG(&]F(&UE<W-A9V5S+@I;
M8VIH72!-86ME('-E87)C:&EN9R!W;W)K('5N9&5R('!O<#,N"EMC:FA=($%T
M=&5M<'0@=&\@<')O=FED92!B971T97(@8V]M<&]S92!W:6YD;W<@=&%B(&)E
M:&%V:6]R(&9O<B!-4TE%("A-87@*("`@("`@2V%L:6MA*2X*6V-J:%T@57-E
M(&EM87!?=71F-U]E;F-O9&5\9&5C;V1E('!R;W!E<FQY(&EN('1H92!F;VQD
M97(@;F%V:6=A=&]R+@I;:F]N72!#;&5A;FQY(&AA;F1L92!T:&4@)W5N9&ES
M8VQO<V5D+7)E8VEP:65N=',G(&-A<V4N"EMJ;VY=($-O;G-I9&5R(&$@8V]M
M<&]S960@;65S<V%G92!V86QI9"!I9B!I="!H87,@82!4;SH@9FEE;&0@;W(@
M82!#8SH@9FEE;&0*("`@("`@;W(@82!"8V,Z(&9I96QD(&1E9FEN960N"EMJ
M;VY=(%)E+6EN=')O9'5C960@=&AE("=S:6=?9&%S:&5S)R!P<F5F97)E;F-E
M+B`@268@96YA8FQE9"P@=&AE('5S97(G<PH@("`@("!S:6=N871U<F4@=VEL
M;"!B92!P<F5C961E9"!W:71H('1H92!S=&%N9&%R9"!C;W5R=&5S>2!D87-H
M97,@*"<M+2`G*2X*6VIO;ET@061D960@82`G<VEG7V9I<G-T)R!P<F5F97)E
M;F-E('1H870@=VEL;"!P;&%C92!T:&4@<VEG;F%T=7)E('1E>'0@86)O=F4*
M("`@("`@=&AE(&UE<W-A9V4@8F]D>2!I;B!R97!L:65S(&%N9"!F;W)W87)D
M<RX@*&UA>$!T:&4M=')I=6UV:7)A=&4N;F5T*0I;8VIH72!-86ME('-U<F4@
M=&\@:6UA<%]U=&8W7V5N8V]D92@I('1H92!S96YT+6UA:6P@86YD(&1R869T
M<R!F;VQD97)S+@I;8VIH72!&:7AE9"!D:7-P;&%Y(&]F('-E87)C:"!R97-U
M;'1S(&9R;VT@;75L=&EP;&4@;6%I;&)O>&5S+@I;8VIH72!3=&%R=&5D('1O
M(&-O;6UE;G0@;W5R(&-O;F9I9R!F:6QE<R!M;W)E('1H;W)O=6=H;'DN"EMC
M:FA=(%)E;6]V92`D8V]N9ELG=7-E7VAO<F1E7V%U=&@G72!F<F]M($E-4"`R
M+C,N"EMC:FA=($%D:G5S="!T:&4@8V]N9B!F:6QE<RP@;65S<V%G92YP:'`@
M*'-P86T@<F5P;W)T<RD@86YD(&-O;7!O<V4N<&AP('1O"B`@("`@('5S92!T
M:&4@4$5!4B!-86EL.CH@:6YT97)F86-E+@I;8VIH72!&:7AE9"!S96%R8V@N
M"EMC:FA=($9I>&5D('-E;&5C="!A;&PO<V5L96-T(&YO;F4@9F]R('!O<#,N
M"EMC:FA=($-L96%N960@=7`@=&AE('!A9VEN9R!L;V=I8R!A(&QI='1L92!B
M:70@86YD('1W96%K960@=&AE(&1E<V-E;F1I;F<*("`@("`@<V]R="!C;V1E
M('1O(&AO<&5F=6QL>2!F:7@@82!B=6<N"EMJ;VY=($%U=&]M871I8V%L;'D@
M<V5T('1H92!F;V-U<R!T;R!T:&4@=7-E<FYA;64@9FEE;&0@;VX@=&AE(&QO
M9VEN('-C<F5E;BX*6V-J:%T@57-E(&)U='1O;G,@9F]R($YE>'0L($-A;F-E
M;"P@86YD($1O;F4@:6X@<W!E;&QC:&5C:RP@86YD(&-H86YG92!T:&4*("`@
M("`@;F%M92!O9B!T:&4@8V]N9FEG(&]P=&EO;B!T;R`D8V]N9ELG=71I;',G
M75LG<W!E;&QC:&5C:V5R)UTN"EMC:FA=(%=H96X@=V4@9&5L971E(&$@9F]L
M9&5R(&EN('1H92!N879I9V%T;W(L(&IU<W0@<W!L:6-E('1H870@9F]L9&5R
M(&]U=`H@("`@("!O9B!T:&4@=')E92!I;G-T96%D(&]F(')E:6YI=&EA;&EZ
M:6YG(&5V97)Y=&AI;F<N"EMC:FA=(%5P9&%T97,@=&\@=&AE(&YA=FEG871O
M<B!T;R!H86YD;&4@;6]R92!S:71U871I;VYS("T@9F]L9&5R('!R969I>&5S
M+`H@("`@("!E=&,N(%-E96US('1O('=O<FL@=V5L;"!N;W<@=VET:"!55R!A
M;F0@17AC:&%N9V4L(&%T(&QE87-T+@I;8VIH72!296UO=F4@9F5T8VAM86EL
M(&9U;F-T:6]N86QI='D@=6YT:6P@82!L871E<B!R96QE87-E+@I;8VIH72!&
M:7@@82!B=6<@=VAE;B!F;W)W87)D:6YG(&-E<G1A:6X@:VEN9',@;V8@34E-
M12!M97-S86=E<RX*6V-J:%T@5VAE;B!C;VUP;W-I;F<@:6X@=&AE('-A;64@
M=VEN9&]W+"!C87)R>2!I;F9O<FUA=&EO;B!A8F]U="!W:&5R92!W90H@("`@
M("!A<F4@:6X@=&AE(&UA:6QB;W@@87)O=6YD('-O('1H870@=V4@8V%N(')E
M='5R;B!T;R!T:&4@<V%M92!P;&%C92X*6V-J:%T@1FEX960@82!S:6QL>2!B
M=6<@:6X@;6EM95]V:65W7W1E>'0H*2!T:&%T(&%D9&5D(&%M<&5R<V%N9',@
M=&\@=&AE"B`@("`@(&)E9VEN;FEN9R!O9B!S;VUE(&UE<W-A9V5S+@I;879S
M;5T@061D(&%N("=5;F1E;&5T92<@;W!T:6]N('1O('1H92!M97-S86=E('9I
M97<L(&9O<B!D96QE=&5D(&UE<W-A9V5S+@I;879S;5T@4VAI9G0@3F%V:6=A
M=&]R(%5)(&%R;W5N9"!T;R!B<FEN9R!I="!M;W)E(&EN(&QI;F4@=VET:"!T
M:&4@<F5S="!O9B!)35`N"EMJ;VY=($1O;B=T(&1I<W!L87D@=&AE("=3<&5L
M;"!#:&5C:R<@;&EN:R!I9B`D8V]N9ELG=71I;',G75LG:7-P96QL)UT@:7,@
M96UP='DN"EMC:FA=(%5S92!T:&4@;F5W(&]P=&EO;F%L(&%R9W5M96YT('1O
M(&EM87!?<V]R="`H861D960@=&\@<&AP-"`R,#`P+3$P+3$X*0H@("`@("!T
M;R!I;7!L96UE;G0@=&AE(")(:61E($1E;&5T960B(&9U;F-T:6]N86QI='D@
M8VQE86YL>2X*6V-J:%T@268@82!U<V5R(&ES(&)E:&EN9"!A('!R;WAY('1H
M870@<')O=FED97,@86X@2%144%]87T9/4E=!4D1%1%]&3U(*("`@("`@=F%R
M:6%B;&4L(&QO9R!I="!I;B!T:&4@8V%S92!O9B!F86EL960@;&]G:6YS+@I;
M8VIH72!!;&QO=R!S96QE8W1I;F<@;V8@<&5R<V]N86PO;F]T('!E<G-O;F%L
M(&UE<W-A9V5S+"!A;F0@9&5F:6YE(&-O;G1A;G1S"B`@("`@(&9O<B!A;&P@
M;V8@=&AE(&9L86=S('-O('1H870@=&AE>2=R92!N;W0@:&%R9&-O9&5D(&%N
M>7=H97)E+@I;8VIH72!!9&0@9G5N8W1I;VYA;&ET>2!T;R!R96UO=&5?;&]G
M:6XN<&AP(&%N9"!M86EL8F]X+G!H<"!T;R!A;&QO=R!A('5S97(*("`@("`@
M=&\@9V\@<FEG:'0@=&\@=&AE(&-O;7!O<V4@=VEN9&]W("AO<B!T;R!P;W`@
M;VYE('5P*2!O;B!L;V=I;BX*6V-J:%T@1F]R=V%R9"UP;W)T('1H92!E>&-E
M;"UV:65W:6YG(&-O9&4@9G)O;2`R+C(N"EMC:FA=($UA:V4@=&AE('=O<F1V
M:65W('5T:6QI='D@)&-O;F9;)W5T:6QS)UU;)W=O<F1V:65W97(G72!T;R!M
M86ME(&ET(&UO<F4*("`@("`@<')O9W)A;2!A9VYO<W1I8RX*6VIO;ET@061D
M:6YG($AE;'`@;&EN:R!T;R!T:&4@;65N=6)A<BX*6V-J:%T@1&5C;V1E($U)
M344@871T86-H;65N="!F:6QE;F%M97,N"EMC:FA=(%1W96%K(&UE<W-A9V4@
M<V%V:6YG('1O(&)E(&UO<F4@8V]R<F5C=#H@36%T:&EE=2!#3$%"0554"B`@
M("`@(#QM871H:65U+F-L86)A=71`9G)E92YF<CXN"EMC:FA=($UO=F5D('1H
M92!S97-S:6]N(&%N9"!A=71H96YT:6-A=&EO;B!F=6YC=&EO;G,@:6YS:61E
M($E-4#HZ+@I;8VIH72!3=&%R=&5D('5S:6YG($A45%!?4$]35%]605)3+"!(
M5%107T=%5%]605)3+"!E=&,N"EMC:FA=($%D9&5D(&%N(&]P=&EO;B!T;R!U
M<V4@36%X($MA;&EK82=S($-O;FYE8W1I;VXZ.B!T<F%C:VEN9R!C;&%S<RX*
M6VIO;ET@061D960@82!S:6UP;&4@<W!A;2!R97!O<G1I;F<@;65C:&%N:7-M
M("@D8V]N9ELG<W!A;2==6R=R97!O<G1I;F<G72DN"EMJ;VY=(%-T86YD87)D
M:7IE(&]N('1H92!R9F-D871E*"D@9G5N8W1I;VX@:6X@;&EB+TAO<F1E+G!H
M<"X*6VIO;ET@0VAA;F=E9"!S;VUE(&]F('1H92!W;W)D:6YG(&EN('1H92`B
M0VAA;F=E($9L86=S.B(@9')O<&1O=VX@;&ES="X*6V-J:%T@1F]R;2UU;FEQ
M:69Y:6YG(&IA=F%S8W)I<'0@=&\@<')E=F5N="!C86-H:6YG('!R;V)L96US
M('=I=&@@<W!E;&QC:&5C:RX*6V-J:%T@26YH97)I="!O<'1I;VYS(&9R;VT@
M2&]R9&4L(&UE<F=I;F<@)&AO<F1E(&EN=&\@)&-O;F8N"EMC:FA=($UA:V4@
M=7-E(&]F('1H92!(5%107T-A8VAE(&-L87-S+"!I9B`D8V]N9ELG8V]M<')E
M<W-?8V]N=&5N="==(&ES('1R=64N"EMC:FA=(%)E<&QA8V4@)&-O;F9;)VQO
M8V%L:&]S="==('=I=&@@)$A45%!?4T525D527U9!4E-;)U-%4E9%4E].04U%
M)UTN"EMC:FA=(%5S92!B=71T;VYS(&9O<B!S96YD(&UE<W-A9V4L('-A=F4@
M9')A9G0L(&%N9"!C86YC96PN"EMJ;VY=($UE<W-A9V4@8V]N=&5N="!F:6QT
M97)I;F<@:7,@;F]W(&$@=7-E<BUS<&5C:69I8R!P<F5F97)E;F-E+@I;8VIH
M72!R97-P96-T('1H92!V86QU92!O9B!T:&4@5$U01$E2(&5N=FER;VYM96YT
M('9A<FEA8FQE(&EN('1M<&1I<B@I+@I;8VIH72!V:65W+G!H<"!N;W<@8VAE
M8VMS(&9O<B!B<F]W<V5R<R!W:&EC:"!R97%U:7)E(&1O=VYL;V%D<R!T;R!B
M90H@("`@("!C86-H96%B;&4@*&QI:V4@35-)12DN"EMJ;VY=(%)E;6]V92!O
M=7(@861D<F5S<R!F<F]M('1H92!#8SH@;&ES="!W:&5N(")R97!L>6EN9R!T
M;R!A;&PB+@I;:F]N72!-;W9E('1H92!F:6QT97)I;F<@8V]D92!A<F]U;F0@
M82!B:70@86YD(&%D9"!A('-A;7!L92!F:6QT97(N='AT+F1I<W0N"EMJ;VY=
M($%D9&5D('-O;64@<VEM<&QE(&UE<W-A9V4@8V]N=&5N="!F:6QT97)I;F<@
M;W!T:6]N<RX*6VIO;ET@57-E('1H92`G<'5B;&EC)R!C86-H92!L:6UI=&5R
M(&9O<B!C;VUP;W-E+G!H<"X*6V-J:%T@061D(&$@<F5C96EV960@:&5A9&5R
M(&9O<B!T:&4@:&]P(&9R;VT@=&AE(&)R;W=S97(@=&\@=&AE('=E8B!S97)V
M97(N"EMC:FA=($1E;F]T92!P97)S;VYA;"!M86EL('=I=&@@86X@:6-O;B`H
M=VAA="!P:6YE(&UA<FMS('=I=&@@)RLG*2`H36%X"B`@("`@($MA;&EK82`\
M;6%X0'1H92UT<FEU;79I<F%T92YN970^*2X*6V-J:%T@4')O=&5C="!U<R!F
M<F]M('!O<W-I8FQE(&9I;&4M<F5A9&EN9R!E>'!L;VET<R!T:')O=6=H(&9I
M;&4@871T86-H;65N="X*6VIO;ET@4VEL96YC92!S97-S:6]N7W-T87)T('=A
M<FYI;F=S+@I;879S;5T@3F%V:6=A=&]R(&-O;G1R;VP@8F%R(&YO=R!H87,@
M;W!T:6]N<R!T;R!C<F5A=&4O9&5L971E+W)E;F%M92!F;VQD97)S"EMJ;VY=
M($-O;G1R;VP@;V8@=&AE(&-O;7!O<V4@=VEN9&]W(&ES(&YO=R!D971E<FUI
M;F5D(&)Y('1H92`G8V]M<&]S95]P;W!U<"<*("`@("`@=7-E<B!P<F5F97)E
M;F-E+@I;:F]N72!297!L86-E(&)U:6QD55),*"D@=VET:"!(;W)D93HZ=7)L
M*"DN"EMJ;VY=(%)E<W1R=6-T=7)E9"!T:&4@4U%,('!R969E<F5N8V5S('-C
M:&5M82X*6V-J:%T@57-E("1H;W)D95LG<V5S<VEO;E]N86UE)UTN"EMC:FA=
M(%-E<W-I;VXZ.B!D;V5S;B=T(')E86QL>2!B=7D@=7,@86YY=&AI;F<L('-O
M('=E)W9E(&UO=F5D('1H92!U=&EL:71Y"B`@("`@(&UE=&AO9',@=&AA="!D
M;R!I;G1O($AO<F1E.CHL(&%N9"!A<F4@:G5S="!U<VEN9R!P:'`T('-E<W-I
M;VX@8V%L;',*("`@("`@96QS97=H97)E+@I;:F]N72!5<&1A=&5D('-E<W-I
M;VX@9G5N8W1I;VYS('1O('5S92!(;W)D92=S(&YE=R!397-S:6]N(&EN<W1A
M;F-E<RX*6V-J:%T@061D(&$@;6EM92!F=6YC=&EO;B!F;W(@=FEE=VEN9R!P
M:'`@8V]D92X*6V-J:%T@061D960@=&AE(&)E9VEN;FEN9W,@;V8@82!F971C
M:"UM86EL+69R;VTM<F5M;W1E+7-E<G9E<B!P:65C92X*6VIO;ET@4F5M;W9E
M9"!T:&4@;&%S="!F97<@<F5F97)E;F-E<R!T;R!T:&4@;F5W=7-E<B!C;V1E
M+@I;:F]N72!296UO=F5D('1H92!-86EL4V5R=F5R(&-L87-S('5S960@:6X@
M8V]N9FEG+W-E<G9E<G,N<&AP(&EN(&9A=F]R(&]F(&$*("`@("`@:&%S:"UB
M87-E9"!S>7-T96TN("!3964@8V]N9FEG+W-E<G9E<G,N<&AP+F1I<W0@9F]R
M(&5X86UP;&5S+@I;879S;5T@061D960@)&-O;F9;)VYA=FEG871O<B==6R=A
M;&5R="==('1O('-U<'!O<G0@:F%V87-C<FEP="!A;&5R="!P;W!U<',*6VIO
M;ET@57-E('1H92!N97<@3&%N9R!C;&%S<R!T;R!S96QE8W0@=&AE(&-U<G)E
M;G0@;&%N9W5A9V4N"EMA=G-M72!!9&1E9"`D8V]N9ELG;F%V:6=A=&]R)UT@
M=&\@8V]N=')O;"!T:&4@875T;RUR969R97-H:6YG(&YA=FEG871O<@I;8VIH
M72!&:7AE9"!S<&5L;"!C:&5C:V5R(&IA=F%S8W)I<'0L(&%N9"!S<&5L;"!C
M:&5C:VEN9R!N;W<@;VYL>2!S:&]W<PH@("`@("!T:&4@<W!E;&P@8VAE8VMI
M;F<@9F]R;2X*6V-J:%T@4W!E;&P@8VAE8VMI;F<@;F\@;&]N9V5R(&QO<V5S
M(&%T=&%C:&UE;G1S+@I;8VIH72!3=&%R=&EN9R!T;R!R96UO=F4@86QL('5S
M97,@;V8@8V%L;"UT:6UE('!A<W,M8GDM<F5F97)E;F-E+@I;8VIH72!);F-L
M=61E('1H92!A8W1U86P@;6EM92!T>7!E(&EN('1H92!M=6YG960@;6EM92!T
M>7!E('=H96X@9&]W;FQO861I;F<*("`@("`@871T86-H;65N=',N"EMJ;VY=
M(%1U<FYE9"!T:&4@24U0('9E<G-I;VX@9F]O=&5R(&EN=&\@82!L:6YK('1O
M(&AT='`Z+R]H;W)D92YO<F<O:6UP+RX*6V-J:%T@5'=E86L@=&AE('=O<F1W
M<F%P<&EN9R!I;B!M:6UE7W9I97=?=&5X="@I(&$@;&ET=&QE(&)I="X*6V-J
M:%T@4F5M;W9E(&%L;"!R969E<F5N8V5S('1O("1D;V,@86YD('1H92!(5$U,
M1&]C=6UE;G0@8VQA<W,N"EMC:FA=(%5S92!T:&4@;F5W(&-S<RYP:'`@2&]R
M9&4@<V-R:7!T('1O(&=E;F5R871E(&]U<B!S='EL97-H965T<RX*6VIO;ET@
M4W!E8VEF>6EN9R!A;B!A8G-O;'5T92!54DP@9F]R("1C;VYF6R=U<V5R)UU;
M)V%L=&5R;F%T95]L;V=I;B==('=I;&P*("`@("`@<F5D:7)E8W0@82!N97<@
M=7-E<B!T;R!T:&%T(%523"!I;G-T96%D(&]F('1H92!L;V=I;B!S8W)E96XN
M("!4:&ES(&ES"B`@("`@('5S969U;"!I;B!P;W)T86P@<VET=6%T:6]N<R!I
M;B!C;VUB:6YA=&EO;B!W:71H(')E;6]T95]L;V=I;BYP:'`N"EMC:FA=($=R
M86-E9G5L;'D@:&%N9&QE(&5M<'1Y('-E87)C:"!R97-U;'1S+@I;8VIH72!/
M;FQY('-H;W<@=&AE('!E<G-O;F%L(&EN9F]R;6%T:6]N("AI9B!W92!H879E
M(&ET*2!W:&5N('=E('-H;W<@5&\Z(&EN"B`@("`@('1H92!&<F]M(&-O;'5M
M;BX*6VIO;ET@061D960@)&-O;F9;)W5S97(G75LG;VYL:6YE7VAE;'`G72!T
M;V=G;&4@=&\@9&ES86)L92!T:&4@;VYL:6YE(&AE;'`*("`@("`@;&EN:W,N
M"EMJ;VY=(%)E;6]V960@=&AE("1C;VYF6R=U<V5R)UU;)V-H86YG95\J)UT@
M<V5T=&EN9W,@:6X@9F%V;W(@;V8@=&AE"B`@("`@(")C:&%N9V5A8FQE(B!B
M:70@:6X@8V]N9FEG+W!R969S+G!H<"X*6VIO;ET@4F5T:7)E9"!T:&4@;F5W
M=7-E<BYP:'`@8V]D92X*6VIO;ET@17AP;&EC:71L>2!C:&%N9V4@=&AE('!E
M<FUI<W-I;VYS(&]N('5P;&]A9&5D(&%T=&%C:&UE;G1S('1O(#`V,#`N"EMJ
M;VY=($YE=R!834PM8F%S960@:&5L<"!S=6)S>7-T96TN"EMC:FA=(%)E;F%M
M960@<&%C:V%G92YI;7`N<&AP('1O($E-4"YP:'`N"EMC:FA=($UA9&4@9F]L
M9&5R(&YA=FEG871O<B!W;W)K('=I=&@@8V]O:VEE<R!D:7-A8FQE9"X*6V%V
M<VU=($YE=R!O<'1I;VX@=&\@:6YL:6YE($-34SL@=&]G9VQE9"!B>2`D8V]N
M9ELG;&%Y;W5T)UU;)V-S<U]I;FQI;F4G70I;:F]N72!!9&0@;6]U<V5O=F5R
M('-T871U<R!T97AT(&9O<B!T:&4@;65N=2!I=&5M<RX*6V-J:%T@0V5N=&5R
M('1H92!)35`@=F5R<VEO;B!F;V]T97(@86YD(&UA:V4@:70@;6]R92!R96%D
M86)L92!I;B!C;VQO<BX*6V-J:%T@5V]R:R!O;B!T:&4@;&]O:R!A;F0@<W1Y
M;&5S:&5E="!C;VYV97)S:6]N(&]F('1H92!C;VUP;W-E('-C<F5E;BX*6VIO
M;ET@57!D871E9"!T:&4@8V]P>7)I9VAT(&EN9F]R;6%T:6]N(&EN('1H92!H
M96%D97(@8V]M;65N=',N"EMJ;VY=(%)E;F%M960@8V]N9FEG+WMH96%D97(L
M=')A:6QE<GTN='AT('1O(&-O;F9I9R][:&5A9&5R+'1R86EL97)]+G1X="YD
M:7-T"B`@("`@(&EN('1H92!D:7-T<FEB=71I;VXN"EMJ;VY=($9O<F-E(&$@
M;&5A9&EN9R!P;'5S('-I9VX@;VX@=&AE($=-5"!O9F9S970@<&%R="!O9B!T
M:&4@<F9C9&%T92X*6VIO;ET@16YL87)G960@=&AE(&1E9F%U;'0@<VEZ92!O
M9B!T:&4@8V]M<&]S92!W:6YD;W<N"EMJ;VY=(%-E="!T:&4@9&5F875L="!C
M=7)S;W(@9F]C=7,@:6X@=&AE(&-O;7!O<V4@<V-R965N(&1E<&5N9&EN9R!O
M;B!T:&4*("`@("`@86-T:6]N+@I;:F]N72!296YA;65D("1C;VYF6R=M<V<G
M75LG87!P96YD7V9O;W1E<B==('1O("1C;VYF6R=M<V<G75LG87!P96YD7W1R
M86EL97(G72X*6VIO;ET@3F5W(&-O;F9I9W5R871I;VX@9&ER96-T:79E.B`D
M8V]N9ELG<VET96YA;64G70I;:F]N72!296YA;65D(&=E;F5R:6,M>VAE861E
M<BQF;V]T97)]+FEN8R!T;R!C;VUM;VXM>VAE861E<BQF;V]T97)]+FEN8RX*
M6VIO;ET@4')E9F5R96YC97,@=&AA="!A<F5N)W0@=7-E<BUC:&%N9V5A8FQE
M(&%R92!N;W<@9&ES86)L960@*&]N;'D@=V]R:W,*("`@("`@=6YD97(@26YT
M97)N970@17AP;&]R97(I+@I;:F]N72!5<V4@0VAR:7,@4G5S<V5L)W,@=V]R
M9'=R87`@9G5N8W1I;VXL(&EF(&ET(&5X:7-T<RX*6VIO;ET@4F5W<F]T92!A
M;F0@8VQE86YE9"UU<"!A(&QO="!O9B!T:&4@;65N=2YP:'`@8V]D92X@($EM
M<')O=F5D('1H90H@("`@("!U<V%G92!C;VUM96YT<R!I;B!C;VYF:6<O;65N
M=2YT>'0N"EMJ;VY=($EF('1H92!U<V5R(&1O97,@;F]T(&AA=F4@2F%V87-C
M<FEP="!C87!A8FEL:71I97,L(&$@<W5B;6ET(&)U='1O;@H@("`@("!W:6QL
M(&)E(&1I<W!L87EE9"!N97AT('1O('1H92!F;VQD97(@;&ES=&EN9R!I;B!T
M:&4@;65N=2X*6VIO;ET@1F]R(&EM<')O=F5D(&-O9&4@8VQA<FET>2P@<F5N
M86UE9"`D8V]N9ELG<V5R=F5R)UU;)W!E<G-O;F%L7V9O;&1E<G,G70H@("`@
M("!T;R`D8V]N9ELG<V5R=F5R)UU;)VYA;65S<&%C92==+@I;879S;5T@57!D
M871E9"!T:&4@;F%V:6=A=&]R('1O(&9I="!I;G1O('1H92!N97<@9G)A;65L
M97-S(&QA>6]U=`I;:F]N72!$:7-P;&%Y('1H92!)35`@=F5R<VEO;B!S=')I
M;F<@:6X@=&AE(&9O;W1E<BX*6VIO;ET@0V]N=F5R=&5D(&%L;"!O9B!T:&4@
M<&%G97,@=&\@=&AE(&YE=R!F<F%M96QE<W,@;&%Y;W5T+@I;:F]N72!)35`@
M;F]W('5S97,@=&AE(&=E='1E>'0@9G5N8W1I;VYS(&5X8VQU<VEV96QY+@I;
M8VIH72!7<F%P(&QO;F<@;&EN97,@:6X@;65S<V%G97,@=7-I;F<@<W1R7W)E
M<&QA8V4N(%-H;W5L9"!B92!E9F9I8VEE;G0N"EMC:FA=($-H86YG960@=FEE
M=RYP:'`@=&\@=7-E(&%N(&%R<F%Y(&9O<B!T:&4@8V%C:&5D(&UI;64@:6YF
M;R!I;G-T96%D(&]F"B`@("`@(&%N(&]B:F5C="P@=&\@;6%T8V@@2&]R9&4@
M8VAA;F=E+@I;:F]N72!$:7-C;VYT:6YU960@=&AE('5S92!O9B!T:&4@)%]H
M=&UL6R=C;VUP;W-E*B==('-I>FEN9R!P87)A;65T97)S+@I;:F]N72!3971T
M:6YG("1C;VYF6R=U<V5R)UU;)W-E;&5C=%]S96YT;6%I;%]F;VQD97(G72!T
M;R!T<G5E('=I;&P@86QL;W<@=&AE"B`@("`@('5S97(@=&\@8VAO;W-E('1H
M92!F;VQD97(@:6YT;R!W:&EC:"!T:&5Y)V0@;&EK92!T;R!S879E(&$@8V]P
M>2!O9B!T:&5I<@H@("`@("!C=7)R96YT(&UE<W-A9V4N"EMJ;VY=(%)E;F%M
M:6YG('1H92`B17AP=6YG92(@86-T:6]N('1O(")0=7)G92!$96QE=&5D(BX*
M6VIO;ET@4V%V:6YG('-E;G0@;6%I;"!I<R!S971T86)L92!O;B!A('!E<BUC
M;VUP;W-I=&EO;B!B87-I<RX@(%1H92!D969A=6QT"B`@("`@('-E='1I;F<@
M:7,@8F%S960@;VX@=&AE('5S97(G<R!C=7)R96YT('!R969E<F5N8V4@*"=S
M879E7W-E;G1?;6%I;"<I+@I;8VIH72!&:7AE9"!E<G)O<G,@=VAE;B!P;W-T
M<&]N:6YG(&$@;65S<V%G92!W:71H;W5T(&%T=&%C:&UE;G1S+@I;:F]N72!5
M<&=R861E9"!T:&4@9&]C='EP92!T;R!82%1-3"`Q+C`@5')A;G-I=&EO;F%L
M+@I;:F]N72!296YA;65D('1H92!)34%04V5R=F5R(&-L87-S('1O($UA:6Q3
M97)V97(N("!!;'-O(')E;F%M960@=&AE"@D@("1)34%04V5R=F5R<R!H87-H
M(&EN(&-O;F9I9R]S97)V97)S+G!H<"!T;R`D<V5R=F5R<RX*6V-J:%T@3&]T
M<R!O9B!N97<@:6-O;G,A"EMC:FA=($9I>"!T:&4@<')O8FQE;2!W:71H(&UA
M:6QB;WAE<R!S965M:6YG('1O(&]N;'D@:&%V92`Q,#`P(&UE<W-A9V5S(&EN
M"B`@("`@('1H92!M97-S86=E('9I97<N"EMC:FA=($9I>"!T:&4@<')E9F5R
M96YC97,@<WES=&5M('1O(&)E(&$@8FET(&UO<F4@8V]N<VES=&5N="P@86YD
M('1O('-T:6QL"B`@("`@(&%L;&]W('5S92!O9B!C;VYF:6<O<V5R=F5R<RYP
M:'`*6VIO;ET@02!N97=E<BP@8F5T=&5R('!R969E<F5N8V4@<WES=&5M(&EM
M<&QE;65N=&%T:6]N+B`@5&AI<R!U<V5S"B`@("`@('1H92!N97<@4')E9G,@
M8VQA<W-E<R!F<F]M($AO<F1E(#$N,RX*"BTM+2TM+0IV,BXS+C4*+2TM+2TM
M"@I;8VIH72!087-S(&%T=&%C:&UE;G0@='EP97,@=&AA="!H879E(&)E96X@
M;6%R:V5D('9I97=A8FQE(&]N('1O('1H92!B<F]W<V5R"B`@("`@('5N=&]U
M8VAE9"!I9B!T:&5R92!I<VXG="!A(&-U<W1O;2!V:65W(&9U;F-T:6]N(&1E
M9FEN960N"EMC:FA=($9I>"!B=6<@9&5L971I;F<@=&AE(&UO<W0@<F5C96YT
M;'D@<V5L96-T960@9F]L9&5R+@I;8VIH72!$;VXG="!R97%U:7)E(&$@;65S
M<V%G92!B;V1Y(&)E9F]R92!S96YD:6YG(&$@;65S<V%G92X*6V%V<VU=($%D
M9&5D(&$@<VEM<&QE('1E>'0@=&]O;&)A<B!T;R!T:&4@=&]P(&]F('1H92!N
M879I9V%T;W(@=FEE=RX*6V-J:%T@57-E('1H92`F<VEN9VQE=&]N*"D@<&%T
M=&5R;B!T;R!M86ME('-U<F4@=V4@;VYL>2!C<F5A=&4@;VYE("1L;V<*("`@
M("`@:6YS=&%N8V4N"EMJ;VY=($UA:V4@=7-E(&]F($AO<F1E)W,@3&]G(&%B
M<W1R86-T:6]N(&EN=&5R9F%C92X*6V-J:%T@:&%N9&QE("),87-T;F%M92P@
M1FER<W1N86UE(B!S='EL92!A9&1R97-S97,@8V]R<F5C=&QY('=H96X@<F5P
M;'EI;F<N"EMC:FA=(%5S92!L;V=I;BYI;F,@:6X@8F]T:"!L;V=I;BYP:'`@
M86YD(')E;6]T95]L;V=I;BYP:'`*6VIO;ET@5&AE(&-O;7!O<V4@=VEN9&]W
M)W,@9&%T92!F;W)M870@:7,@;F]W(&-O;F9I9W5R86)L92X*6VIO;ET@5&AE
M('1E>'0@9F]R(&EN=')O+G!H<"!I<R!N;W<@:6YL:6YE9"!U<VEN9R!G971T
M97AT*"DN"EMC:FA=($ML=61G92!T;R!F:7@@=&AE(&1E;&5T:6]N(&]F(&UE
M<W-A9V5S(&]V97(@<&]P,RX*6V-J:%T@57-E(&$@9&EF9F5R96YT(&EC;VX@
M=&\@9&5N;W1E(&UU;'1I<&%R="]A;'1E<FYA=&EV92!M97-S86=E<RX*6V-J
M:%T@36%K92!T:&4@9G)O;5]L:6YK('1O('9I97<@;65S<V%G97,@8V]N<VES
M=&5N="!W:71H('1H92!S=6)J96-T(&QI;FL*("`@("`@=&\@=FEE=R!M97-S
M86=E<RX*6V-J:%T@1&]N)W0@96YA8FQE('1H92!M<W=O<F1V:65W(&UI;65T
M>7!E(&EF("1C;VYF6R=U=&EL<R==6R=M<W=O<F1V:65W)UT*("`@("`@:7,@
M96UP='DL(&9A;'-E+"!O<B!U;G-E="X*6V-J:%T@061D(&%N(&]P=&EO;B!T
M;R!L;V<@<V5N9&EN9R!O9B!M86EL+"!F<F]M"@D@(%-A;75E;"!$+B!.:6-O
M;&%R>2`\<V1N0&ES8RYU<&5N;BYE9'4^"EMA=G-M72!!9&1E9"!C;V1E('1O
M('5P9&%T92!M97-S86=E(&EN9F\@:6X@;F%V:6=A=&]R+G!H<"X*6VIO;ET@
M5&AE('1I;64@86YD(&1A=&4@9F]R;6%T<R!F;W(@=&AE(&UA:6QB;W@@;&ES
M=&EN9R!A<F4@;F]W(&-O;F9I9W5R86)L92X*6V-J:%T@1&\@<V]M92!H86YD
M;&EN9R!O9B!B861L>2UT>7!E9"!A9&1R97-S97,@*'-E<&5R871E9"!B>2!S
M<&%C97,L(&5T8RDN"EMJ;VY=(%)E;6]V960@=&AE($-O;G1A8W1S(&QI;FMS
M(&9R;VT@=&AE(&-O;7!O<V4@=VEN9&]W+@I;:F]N72!4:&4@8V]N9FEG=7)A
M=&EO;B!T;V=G;&4@)&-O;F9;)W5S97(G75LG86QL;W=?;&1A<%]S96%R8V@G
M72!H87,@8F5E;@H@("`@("!R96YA;65D("1C;VYF6R=U<V5R)UU;)V%L;&]W
M7V1I<F5C=&]R>5]S96%R8V@G72!T;R!R969L96-T('1H90H@("`@("!A8G-T
M<F%C="!N871U<F4@;V8@5'5R8F$G<R!S96%R8V@@8V%P86)I;&ET:65S+@I;
M:F]N72!296UO=F5D('1H92!F;VQD97(M<F5P;'EI;F<@8V%P86)I;&ET:65S
M+@I;:F]N72!296UO=F5D($E-4"=S(&-O;G1A8W1S(&-O9&4N(%=E)VQL('5S
M92!4=7)B82=S(&9R;VT@;F]W(&]N+@I;8VIH72!5<V4@=&AE(&YE=R!H;W)D
M95]C;&5A;G5P*"D@9G5N8W1I;VX@=&\@;6%K92!S=7)E('1H870@9FEL97,@
M9V5N97)A=&5D"B`@("`@(&)Y('9I97=I;F<@;6EM92!P87)T<R!W:6QL(&%L
M=V%Y<R!B92!C;&5A;F5D('5P(&%T('1H92!E;F0@;V8@=&AE"B`@("`@(')E
M<75E<W0L(&YO(&UA='1E<B!H;W<@=&AE(')E<75E<W0@:7,@=&5R;6EN871E
M9"X*6V-J:%T@4F5M;W9E('!H<&QI8B!D97!E;F1A;F-Y(&EN(&9A=F]R(&]F
M('!H<#0@<V5S<VEO;G,O4$5!4BX*6VIO;ET@061D960@82`B4')I;G0B(&%C
M=&EO;B!T;R!T:&4@;65S<V%G92!V:65W+@I;8VIH72!297!L86-E('5S92!W
M:71H(')E<75I<F5?;VYC92!S:6YC92!U<V4@:7-N)W0@<W5P<&]R=&5D(&9O
M<B!P:'`T+@I;8VIH72!!;&P@)&@M/BIA9&1R97-S(')E9F5R96YC97,@87)E
M(&=O;F4L(&%N9"!W92!H879E('1W;R!N97<@9G5N8W1I;VYS(&EN"B`@("`@
M('!A8VMA9V4N:6UP+G!H<"`M($E-4#HZ861D<D]B:F5C=#)3=')I;F<H*2!A
M;F0@24U0.CIA9&1R07)R87DR4W1R:6YG*"D*("`@("`@+2!T;R!M86ME('=O
M<FMI;F<@=VET:"!T:&4@)&@M/F9R;VU;72P@971C(&%R<F%Y<R!E87-I97(N
M"EMC:FA=(%-E;&5C=&EN9R!A(&QA;F=U86=E(&]N('1H92!L;V=I;B!S8W)E
M96X@;F]W(&%C='5A;&QY(&AA<R!A;B!E9F9E8W0*6VIO;ET@4V5T=&EN9R`D
M8V]N9ELG=7-E<B==6R=I;FET:6%L7W-U8G-C<FEB92==('=I;&P@875T;VUA
M=&EC86QL>0H@("`@("!S=6)S8W)I8F4@86QL(&]F('1H92!F;VQD97)S(&EN
M('1H92!U<V5R)W,@9F]L9&5R('!A=&@@870@=&AE(&5N9`H@("`@("!O9B!T
M:&4@;F5W=7-E<B!W96QC;VUE('!R;V-E<W,N($YO=&4@=&AA="!T:&ES(&%L
M<V\@<F5Q=6ER97,*("`@("`@)&-O;F9;)W5S97(G75LG;F5W=7-E<E]S971U
M<"==('1O(&)E('1R=64N"EMJ;VY=(%-E="!T:&4@=6UA<VL@*"1C;VYF6R=U
M;6%S:R==*2!G;&]B86QL>2!I;B!P86-K86=E+FEM<"YP:'`N"EMJ;VY=(%1H
M92`B8V%N8V5L(&UE<W-A9V4B(&-O;F9I<FUA=&EO;B!N;W<@8V%N8V5L)W,@
M=&AE(&UE<W-A9V4@:68@=&AE('5S97(*("`@("`@8VAO;W-E<R`B3VLB(&EN
M<W1E860@;V8@(F-A;F-E;"(@:6X@=&AE(&%L97)T(&)O>"X*"BTM+2TM+0IV
M,BXS+C0*+2TM+2TM"@I;8VIH72!4:&4@;6%I;&)O>"!S96QE8W1S(&EN('1H
M92!M86EL8F]X(&%N9"!M97-S86=E('9I97=S(&YO=R!U<&1A=&4@:6X*("`@
M("`@=&%N9&5M("AI92P@:68@>6]U(&-H86YG92!O;F4L('1H92!O=&AE<B!U
M<&1A=&5S('1O('1H92!S86UE('-E;&5C=&EO;BDN"EMC:FA=(%1H92!L;V=I
M;B!S8W)E96X@9&]E<R!N;W0@<F5L;V%D('=H96X@>6]U(&-H;V]S92!A(&YE
M=R!L86YG=6%G92P@:68@80H@("`@("!U<V5R;F%M92!O<B!P87-S=V]R9"!H
M87,@8F5E;B!E;G1E<F5D+@I;8VIH72!#:&%N9VEN9R!T:&4@<')O=&]C;VP@
M<V5L96-T960@8VAA;F=E<R!T:&4@<&]R="!T;R!T:&4@9&5F875L="!P;W)T
M"B`@("`@(&9O<B!T:&%T('!R;W1O8V]L+@I;:F]N72!';W0@<FED(&]F('1H
M;W-E(&YA<W1Y("<M+2TM+2TM+2TG<R!I;B!T:&4@9F]L9&5R('-E;&5C=',@
M86YD(')E<&QA8V5D"B`@("`@('1H96T@=VET:"!B;&%N:R!S<&%C97,@:6YS
M=&5A9"X*6V-J:%T@365S<V%G92!F;&%G<R!A<F4@;F]W(&1I<W!L87EE9"!I
M;B!T:&4@;65S<V%G92YP:'`@<V-R965N+@I;8VIH72!4:&5R92!I<R!N;W<@
M82!M96YU('1O(&-H86YG92!T:&4@9FQA9W,@;V8@;65S<V%G97,N"EMC:FA=
M(%-I9VYE9"]%;F-R>7!T960@;65S<V%G97,@87)E('-H;W=N('=I=&@@82!D
M:69F97)E;G0@:6-O;B!T:&%N(&]T:&5R"B`@("`@(&UE<W-A9V5S('=I=&@@
M871T86-H;65N=',N"EMC:FA=($UA:6QB;W@@<V]R=&EN9R!W;W)K<R!A9V%I
M;B`H:6UP4V5T=7!397-S:6]N('=A<VXG="!C86QL:6YG(%]S9710<F5F*2X*
M6V-J:%T@1F]L9&5R('-U8G-C<FEP=&EO;G,@87)E(&-O<G)E8W1L>2!K97!T
M('5P('1O(&1A=&4@;VX@9F]L9&5R(')E;F%M:6YG+@I;8VIH72!/;F-E(&%G
M86EN('EO=2!A<F4@87-K960@=&\@8V]N9FER;2!B969O<F4@9&5L971I;F<@
M9F]L9&5R<PI;8VIH72!4:&4@;65N=2!N;W<@<')O<&5R;'D@<F5F<F5S:&5S
M(&]N($%,3"!F;VQD97(@8VAA;F=E<RX@/2D*6VIO;ET@5&AE(&UE;G4@;F]W
M('!R;W!E<FQY(')E9G)E<VAE<R!O;B!F;VQD97(@<W5B<V-R:7!T:6]N(&-H
M86YG97,N"EMC:FA=($EF(&%N(&%T=&%C:&UE;G0@:7,@;F]T('-E="!T;R!D
M:7-P;W-I=&EO;CH@:6YL:6YE+"!D;VXG="!D:7-P;&%Y(&ET"B`@("`@(&EN
M;&EN92!R96=A<F1L97-S(&]F(&]T:&5R('-E='1I;F=S+B`H=&5X=%]P87)T
M<U]I;FQI;F4L('1Y<&4L(&5T8RDN"EMJ;VY=(%1H92!4;SH@861D<F5S<R!I
M<R!N;W<@;&ES=&5D(&EN('1H92!W:6YD;W<N<W1A='5S(&]N(&UO=7-E(&]V
M97(N"EMC:FA=($%D9')E<W-E<R!A<F4@;F]W(&QI<W1E9"!I;F1I=FED=6%L
M;'D@:6X@=&AE(&UE<W-A9V4@<V-R965N+"!W:71H(&$*("`@("`@8V]M<&]S
M92!L:6YK(&%N9"`B861D('1O(&-O;G1A8W1S(B!L:6YK(&9O<B!E86-H+@I;
M8VIH72!!9&1E9"`D8V]N9ELG:&]O:W,G75LG9G)O;5]H;V]K)UT@=VAI8V@@
M:6UP;&5M96YT<R!B=6EL9&EN9R!A(&9R;VT*("`@("`@861D<F5S<R!B87-E
M9"!O;B!A('-I=&4M<W!E8VEF:6,@9G5N8W1I;VXN(%EE<RP@=&AE(&EM<&QI
M8V%T:6]N(&ES"B`@("`@('1H870@=&AE<F4@;6EG:'0@8F4@;6]R92`B:&]O
M:W,B(&EN('1H92!F=71U<F4N"EMC:FA=($%D9&5D("1C;VYF6R=C;VUP;W-E
M)UU;)V%L;&]W7RAB*6-C)UT@=&\@8V]N=')O;"!T:&4@879A:6QA8FEL:71Y
M(&]F"B`@("`@('1H92!C8SH@86YD(&)C8SH@9FEE;&1S+@I;8VIH72!!9&1E
M9"!J879A<V-R:7!T('1O('1H92!M97-S86=E('-C<F5E;B!T;R!M86ME('-U
M<F4@=&AA="!A(&9O;&1E<B!I<PH@("`@("!S96QE8W1E9"!B969O<F4@;6]V
M:6YG+V-O<'EI;F<@82!M97-S86=E"EMJ;VY=($%L;"!G96YE<F%T960@55),
M)W,@87)E(&YO=R!R96QA=&EV92`H55)))W,@;VYL>2DL(&5X8V5P="!F;W(@
M=&AE"B`@("`@($QO8V%T:6]N.B!H96%D97)S('5S960@9F]R(')E9&ER96-T
M:6]N+B`@5&AE>2!R97%U:7)E(&9U;&QY+7%U86QI9FEE9`H@("`@("!54DPG
M<RX*6V-J:%T@268@;6%I;&9R;VTH*2!R971U<FYS(&9A;'-E+"!C;VUP;W-E
M+G!H<#,@;F]W(&%T(&QE87-T('1E;&QS('1H92!U<V5R"B`@("`@('1H97)E
M('=A<R!A;B!E<G)O<B!I;G-T96%D(&]F('-I;&5N=&QY(')E;&]A9&EN9RX*
M6VIO;ET@26UP<F]V960@=&AE(&5N=&ER92!N97=U<V5R(&QO9VEN('!R;V-E
M9'5R92!S;R!T:&%T('=E(&-O<G)E8W1L>0H@("`@("!I;FET:6%L:7IE('1H
M96ER('!R969E<F5N8V5S('=I=&@@86QL(&]F('1H92!D969A=6QT('9A;'5E
M<RX*6VIO;ET@061D960@8VAE8VMS(&9O<B!N=6QL('!R969E<F5N8V4@<F5S
M=6QT<R!T:&%T('=O=6QD('!R979I;W5S;'D@8V%U<V4@80H@("`@("!A('!L
M971H;W)A(&]F('=A<FYI;F=S(&%N9"!E<G)O<G,N"EMC:FA=($%D9&5D(&$@
M)&-O;F9;)W-E<G9E<B==6R=S:&]W7W-H87)E9%]H:65R87)C:'DG72!O<'1I
M;VX@=&\@9&ES<&QA>2!T:&4*("`@("`@55<M:6UA<&0@(W-H87)E9"\@9F]L
M9&5R(&AI97)A<F-H>2X*6V-J:%T@4$]0,R!S=7!P;W)T('-H;W5L9"!N;W<@
M8F4@9G5L;'D@9G5N8W1I;VYA;"!F;W(@,BXS+@I;8VIH72!!9&1E9"`D8V]N
M9ELG=7-E<B==6R=R961I<F5C=%]O;E]L;V=O=70G72!A<R!A;B!O<'1I;VX@
M9F]R('-E;F1I;F<*("`@("`@=7-E<G,@=&\@86X@87)B:71R87)Y('!A9V4@
M=VAE;B!T:&5Y(&QO9R!O=70N"EMC:FA=($9I>&5D(&$@<')O8FQE;2!W:71H
M($E%(&-A8VAI;F<@=&AE(&)O=6YC92!F;W)M+@I;8VIH72!4:&4@871T86-H
M;65N="!I8V]N(&9O<B!M97-S86=E<R!W:71H(&%T=&%C:&UE;G1S(&ES(&)A
M8VL@:6X@=&AE"B`@("`@(&UA:6QB;W@@=FEE=R`H:6X@:70G<R!O=VX@;F5W
M(&-O;'5M;BDN"EMC:FA=(%-T87)T960@=V5E9&EN9R!O=70@=6YN96-C97-A
M<GD@=7-E<R!O9B!I;6%P7VUS9VYO*"D@=VAE;B!T:&4@9G5N8W1I;VX*("`@
M("`@:6X@<75E<W1I;VX@=&%K97,@=&AE($947U5)1"!F;&%G+@I;8VIH72!6
M87-T;'D@:6UP<F]V960@=&AE($U)344@871T86-H;65N="!C;V1E+B!)35`@
M;F]W('!A<W-E<R!T:&4@34E-10H@("`@("!T;W)T=7)E('1E<W0N"EMC:FA=
M($9I>&5D(&$@:F%V87-C<FEP="!P<F]B;&5M(&EN('1H92!C;VUP;W-E('=I
M;F1O=R!W:&5R92!T:&4@;&%S=`H@("`@("!C:&%R86-T97(@8F5F;W)E(&$@
M<W!A8V4@=V]U;&0@8F4@9&5L971E9"!I;F-O<G)E8W1L>2X*6V-J:%T@1&]C
M=&]R960@=&AE(&-L:6-K86)L92UU<FP@9G5N8W1I;VYS(&9O<B!P97)F;W)M
M86YC92P@86YD('1O(&YO=`H@("`@("!B=71C:&5R(&EN8VQU9&5D(&AT;6P@
M8V]D92X*6V-J:%T@4F5P;&%C960@86QL(&-A;&QS('1O(&5R96<J(&9U;F-T
M:6]N<R!W:71H('!R96<J(&9U;F-T:6]N<RP@9F]R('-P965D+@H@("`@("!"
M96-A=7-E(&]F('1H:7,@=V4@;F]W(')E<75I<F4@<&AP(#,N,"XQ,B!O<B!L
M871E<BX*"@HM+2TM+2T*=C(N,RXR"BTM+2TM+0H*0E5'.B!S=6)M:71T:6YG
M(&$@;F]N+65X:7-T86YT(&9I;&4@87,@86X@871T86-H;65N="!I<R!N;W<@
M<V%F96QY(&EG;F]R960@*&-J:"D*0E5'.B!T:&4@;65S<V%G92!S96QE8W0@
M<&]P=7`@:6X@=&AE(&UA:6QB;W@@=FEE=R!W;W)K<R!A9V%I;B!N;W<N($E%
M(&1O97-N)W0@;&5T('EO=2!U<V4@(G1Y<&4B(&%S(&$@9F]R;2!E;&5M96YT
M(&YA;64N("AC:F@I"D)51SH@96YC;V1I;F<@;V8@."UB:70@:&5A9&5R<R!S
M:&]U;&0@;F]W(&)E(%]V97)Y7R!C;&]S92!T;R!F;VQL;W=I;F<@=&AE(%)&
M0RP@:68@:70@9&]E<VXG="!C;VUP;&5T96QY+B!L;VYG(&AE861E<G,@87)E
M('-P;&ET('5P(&EN=&\@871O;7,@<VUA;&QE<B!T:&%N(#<V(&-H87)S("AC
M:F@I"D-(04Y'13H@=7-I;F<@65E962U-32U$1"!F;W(@9&%T97,@:6X@;6%I
M;&)O>"YP:'`S(&9O<B!D87ES(&]T:&5R('1H86X@=&]D87D@*&-J:"D*0TA!
M3D=%.B!M=6QT:7!L92!F;VQD97)S(&-A;B!N;W<@8F4@9&5L971E9"!A="!O
M;F-E("AJ;VXI"D-(04Y'13H@8V%N8V5L;&EN9R!A(&UE<W-A9V4@;F]W('=A
M:71S(&9O<B!T:&4@=7-E<B!T;R!C;VYF:7)M("AC:F@I"D-(04Y'13H@;F5W
M('5S97(@<')E9F5R96YC97,@<V-R965N('=I=&@@;6]R92!O<'1I;VYS("AJ
M;VXI"D-(04Y'13H@<F5T:7)E9"!T:&4@)&1E9F%U;'0@;V)J96-T("AI;B!F
M879O<B!O9B`D8V]N9BD@9G)O;2!)35`@*&IO;BD*0TA!3D=%.B!N97=U<V5R
M+G!H<#,@:&%S(&)E96X@<F5N86UE9"!I;G1R;RYP:'`S("AJ;VXI"D-(04Y'
M13H@:6UP<F]V960@=&AE('5N<W5B<V-R:6)E9"!F;VQD97(@;&ES=&EN9R!A
M(&)I="`H:F]N*0I,04Y'54%'13H@=7!D871E9"!)=&%L:6%N('1R86YS;&%T
M:6]N(&9R;VT@1F5D97)I8V\@1VEA;FYI8VD@/&=I86YN:6-I0&YE;VUE9&EA
M+FET/@I%3DA!3D-%345.5#H@861D:6YG('!A=&-H97,@9G)O;2!-:6-H865L
M(%-M:71H(#QM:6-H865L0&-S=6ET92YN<RYC83X@=&\@<V%V92!S;VUE(&EN
M9F]R;6%T:6]N(&]N(&9A:6QE9"!L;V=I;G,@*'5S97)N86UE+"!E=&,I"D5.
M2$%.0T5-14Y4.B!)35`@;F\@;&]N9V5R(')E<75I<F5S(&-O;VMI97,@=&\@
M8F4@96YA8FQE9"!O;B!T:&4@8VQI96YT("AJ;VXI"D5.2$%.0T5-14Y4.B!A
M9&1E9"`D8V]N9ELG=7-E7W-S;"==('1O(&9O<F-E("=H='1P<SHO+R<@:6X@
M9V5N97)A=&5D(%523"=S("AJ;VXI"D5.2$%.0T5-14Y4.B!I9B!L;V-A;&4O
M;&]C86PO:6YT<F\N>V)E9VEN+&UA:6XL96YD?2YT>'0@97AI<W1S+"!I="!W
M:6QL(&)E"G5S960@:6X@<&QA8V4@;V8@=&AE(&QO8V%L92\D;&%N9W5A9V4O
M('9E<G-I;VX@*&IO;BD*14Y(04Y#14U%3E0Z(&%D9&5D('1H92!A8FEL:71Y
M('1O(&AI9&4@=&AE('-E<G9E<B!L:7-T+"!P<F]V:61I;F<@;FEC92!T<F%N
M<W!A<F5N8WD@9F]R('9I<G1U86P@:&]S=&EN9RX*14Y(04Y#14U%3E0Z(&%D
M9&5D(&%B:6QI='D@=&\@9V5N97)A=&4@1G)O;3H@861D<F5S<V5S(&QI:V4@
M/'5S97(K9F]L9&5R/B`H:F]N*0I%3DA!3D-%345.5#H@;F5W('5S97(@<V5T
M=7`@<V-R965N(&9O<B!I;FET:6%L('!R969S(&-O;F9I9W5R871I;VX@*&IO
M;BD*14Y(04Y#14U%3E0Z('!R969E<F5N8V5S('-U<'!O<G0@8F]T:"!L9&%P
M(&%N9"!S<6P@<W1O<F%G92!S;W5R8V5S("AJ;VXI"@H*+2TM+2TM"G8R+C,N
M,0HM+2TM+2T*"DY%5SH@1&5B:6%N(%!A8VMA9V4@;6EM92!V:65W:6YG("AI
M96TI"DY%5SH@>"UT87(@;6EM92!V:65W:6YG("AI96TI"DY%5SH@1U!'('-I
M9VYA='5R92!C:&5C:VEN9R`H:65M*0I&25A%1#H@=&=Z(&UI;64@=FEE=VEN
M9R`H:65M*0I54$1!5$4Z(&YE=R!P:6YE,FEM<"YP;"!S8W)I<'0@9G)O;2!M
M=7)L97E`;75R;&5Y+F-O;0I#2$%.1T4Z(%)E;6]V960@8V]N9FEG+V1E9F%U
M;'1S+G!H<#,@86YD(')E<&QA8V5D(&ET('=I=&@@8V]N9FEG+V-O;F8N<&AP
M("AJ;VXI"D-(04Y'13H@4F5W;W)K960@=&AE('=A>2!S;VUE(&]F('1H92!C
M;VYT86-T<R!P;W!U<"!W;W)K<R`H:F]N*0I#2$%.1T4Z(%5S97(M06=E;G0Z
M("=)35`@4$A0+TE-05`@=V5B;6%I;"!P<F]G<F%M)R`^("=)35`@=V5B;6%I
M;"!P<F]G<F%M)R`H:F]N*0I#2$%.1T4Z($%D9&5D('1H92`B<VEG;F%T=7)E
M(&1A<VAE<R(@=7-E<B!P<F5F97)E;F-E("AJ;VXI"D-(04Y'13H@3F5W('!R
M969E<F5N8V5S('-Y<W1E;2!I;7!L96UE;G1E9"`H:F]N*0I#2$%.1T4Z(%)E
M;6]V960@86QL(&AE;'`@9G)O;2!T:&4@;&]G:6X@<V-R965N("AJ;VXI"D-(
M04Y'13H@5&AE(").97<@57-E<B!);G1R;V1U8W1I;VXB(&QI;FL@:7,@;F\@
M;&]N9V5R(&]P=&EO;F%L("AJ;VXI"D-(04Y'13H@)&1E9F%U;'0M/FQO8V%L
M:&]S="!I<R!D97!R96-A=&5D(&EN(&9A=F]R(&]F("1315)615)?3D%-10I#
M2$%.1T4Z($E.0D]8(&ES(&YO(&QO;F=E<B!S:&]W;B!O;B!T:&4@9F]L9&5R
M<R!P86=E"DQ!3D=504=%.B!#>F5C:"!U<&1A=&5D"DQ!3D=504=%.B!'97)M
M86X@=7!D871E9`I,04Y'54%'13H@1G)E;F-H('5P9&%T960*14Y!3D-%345.
M5#H@4F5B=6EL="!T:&4@<')E9F5R96YC97,@<W5B+7-Y<W1E;2`H<V5E(&-O
M;F9I9R]P<F5F<RYP:'`I("AJ;VXI"@H*+2TM+2TM"G8R+C,N,`HM+2TM+2T*
M"D-(04Y'13H@0VAA;F=E9"!A;&P@;V8@=&AE(%-13"!S8W)I<'1S('1O('5S
M92`B:&]R9&4B(&1B(&EN<W1E860@;V8@(FEM<"(@*&IC:"D*0TA!3D=%.B!&
M:7AE9"!'97)M86X@=')A;G-L871I;VX@8G5G<R!I;B!T:&4@;F5W=7-E<B!S
M=&%R="!F:6QE("AJ8V@I"D-(04Y'13H@06QL(&QO8V%L92\@<W1R:6YG<R!D
M969A=6QT('1O($5N9VQI<V@@*"=E;B<I(&YO=RX@($EF(&%N;W1H97(@;&%N
M9W5A9V4@:7,@<V5L96-T960L(&ET('=I;&P@8F4@;&]A9&5D(&]N('1O<"!O
M9B!T:&4@16YG;&ES:"!S=')I;F=S+B`@5&AI<R!S:&]U;&0@<V]L=F4@=&AE
M('!R;V)L96T@;V8@<V]M92!L;V-A;&EZ871I;VYS(&UI<W-I;F<@82!S=')I
M;F<@:&5R92!A;F0@=&AE<F4N("AJ;VXI"D-(04Y'13H@5&AE('1O<"!A;F0@
M8F]T=&]M(&UA:6QB;W@@;&ES=&EN9R!N879B87)S(&%R92!N;W<@<WEM;65T
M<FEC86P@*&IO;BD*0TA!3D=%.B!R96UO=F5D(&1E<')E8V%T960@17)R;W)S
M+51O.B!H96%D97(@*&-J:"D*0TA!3D=%.B!#:&%N9V5D(%@M36%I;&5R('1O
M(%5S97(M06=E;G0@*')E9CH@9')A9G0M:65T9BUU<V5F;W(M87)T:6-L92TP
M,BD@*&IO;BD*0TA!3D=%.B!296UO=F5D('-O;64@;6]R92!U;G5S960@9FEL
M97,@86YD(&-L96%N960@=7`@8G5I;&0@<V-R:7!T<R!A8V-O<F1I;F=L>2X@
M*&-J:"D*0TA!3D=%.B!-;W9E9"!C;VYF:6<O4D5!1$U%('1O(&1O8W,O0T].
M1DE'4PI#2$%.1T4Z(%)E;6]V960@;VQD(&-O;F9I9R]S8W)I<'1S+RHN='AT
M(&9I;&5S(&EN(&QE:74@;V8@9&]C<R]$051!0D%310I#2$%.1T4Z(%=E;G0@
M8F%C:R!T;R`D:"T^=61A=&4@9F]R(&UE<W-A9V4@9&%T97,@*&-J:"D*0E5'
M.B`X8FET(&AE861E<G,@<VAO=6QD(&YO=R!B92!P<F]P97)L>2!E;F-O9&5D
M("A2;WDM36%G;F4@36\@)B!C:F@I"D)51SH@4&]P<&%S<V0@<VAO=6QD('=O
M<FL@;F]W("@B0VAA<FQE<R!0+B!7<FEG:'0B(#QC<'=R:6=H=$!C<'=R:6=H
M="YC;VT^*0I"54<Z($Q$05`@<V5A<F-H97,@8V%N(&YO=R!B92!A9V%I;G-T
M(&9I96QD<R!O=&AE<B!T:&%N("=C;B<*0E5'.B!&:7AE9"!T:&4@9F]L9&5R
M<R!S8W)E96X@86YD('-O;64@;6%I;&)O>"!L:7-T:6YG(&-O9&4*0E5'.B!#
M:&%N9VEN9R!L86YG=6%G97,@;F]W(')E9G)E<VAE<R!L;V=I;B!S8W)E96X@
M=6YD97(@26YT97)N970@17AP;&]R97(*0E5'.B!&:7AE9"!S;6%L;"!B=6<@
M=VET:"`D=&]?9&]M86EN(&%N9"!E;7!T>2!A9&1R97-S('-T<FEN9W,@*&IO
M;BD*0E5'.B!-:7-I;G1E<G!R971T960@<F5S=6QT(&9R;VT@:6UP7V=E=%]L
M86YG*"D@9FEX960@/')M;T!W=W<N:&EV;VQD82YN;SX*0E5'.B!-:6UE+65N
M8V]D960@:&5A9&5R<R!A<F4@;F]W(&AA;F1L960@;75C:"!M;W)E(&-O;G-I
M<W1E;G1L>2X@5&AE<F4@*G-H;W5L9&XG="H@8F4@:7-S=65S('=I=&@@=&AE
M<V4@;&5F="X@4&QE87-E(')E<&]R="!A;GD@>6]U(&9I;F0N"D)51SH@475O
M=&5D('!R:6YT86)L92!M97-S86=E<R!A<F4@;F]W(&1E8V]D960@=VAE;B!B
M96EN9R!F;W)W87)D960@86YD(')E<&QI960@=&\N"D)51SH@1FEX960@1G)E
M;F-H(&%N9"!"<F%Z:6QI86X@4&]R='5G=65S92!L86YG=6%G92!P<F]B;&5M
M<PI"54<Z($9I>&5D(&$@8G5G('=H96X@9F]R=V%R9&EN9R!W:71H;W5T(&$@
M9G)O;2!A9&1R97-S(#QA;&%N0&AA;&%C:&UI+FYE=#X*0E5'.B!&:7AE9"!A
M(&)U9R!O<&5N:6YG(&-O;G1A8W1S('=I;F1O=R!O;B!C;VUP;W-E('!A9V4*
M0E5'.B!&:7AE9"!V:6]L871I;VX@;V8@=&AE('-P96,@9F]R(%523"!W:&5N
M(&1O=VYL;V%D:6YG(&9I;&5S('=I=&@@;F%M92!S<&%C97,*0E5'.B!&:7AE
M9"!A(&UI<VED96YT:69I8V%T:6]N(&]F($UI8W)O<V]F="!W96(@8G)O=W-E
M<G,*0E5'.B!&:7AE9"!A(&UI<W-I;F<@/"]404),13X@=&%G(&)R96%K:6YG
M(&UE;G4@<&]S:71I;VYI;F<*0E5'.B!";W5N8VEN9R!A(&UE<W-A9V4@9&]E
M<VXG="!R=6EN(&%T=&%C:&UE;G1S(&%N>6UO<F4*0E5'.B!#;W)R96-T;'D@
M:&%N9&QE<R!M:7-S:6YG('-U8FIE8W0@=VAE;B!Y;W4@9F]R=V%R9"!M86EL
M"D)51SH@1FEX960@3GEN;W)K<RU.;W)W96=I86X@;&%N9W5A9V4@*%)O>2U-
M86=N92!-;SQR;6]`=W=W+FAI=F]L9&$N;F\^*0I"54<Z($9I>&5D(&-O<VUE
M=&EC(&-O=6YT:6YG('!R;V)L96T@=VAE;B!D96QE=&EN9R!M97-S86=E<PI%
M3DA!3D-%345.5#H@;F]W('!R:6YT<R!A(&UE<W-A9V5S('=H96X@=&AE(&UA
M:6QB;W@@:7,@96UP='D@*&IO;BD*14Y(04Y#14U%3E0Z('-E=',@=&AE(&AT
M;6P@8VAA<G-E="!A8V-O<F1I;F<@=&\@=&AE(&QA;F=U86=E('-E;&5C=&EO
M;B`H:F]N*0I%3DA!3D-%345.5#H@861D960@<W5P<&]R="!F;W(@8V%S8V%D
M:6YG('-T>6QE<VAE971S("AJ;VXI"D5.2$%.0T5-14Y4.B!F:7@@9F]R(&5X
M=')E;65L>2!L;VYG(&9O;&1E<B!N86UE<R!I;B!S96QE8W0N<&AP,R`H:F]N
M*0I%3DA!3D-%345.5#H@861D960@=&AE(&]P=&EO;B!T;R!H:61E(&1E;&5T
M960@;65S<V%G97,@9G)O;2!M86EL8F]X(&QI<W1I;F<@*&IO;BD*14Y(04Y#
M14U%3E0Z('-Y<VQO9R!S=&%T<R!C;W5R=&5S>2!O9B!-:6-H865L(%-M:71H
M(#QM:6-H865L0&-S=6ET92YN<RYC83X*14Y(04Y#14U%3E0Z($9O<G=A<F1I
M;F<@82!M97-S86=E('=I=&@@871T86-H;65N=',@<V5N9',@=&AE(&%T=&%C
M:&UE;G1S(&%L;VYG+"!A;F0@>6]U(&-A;B!A;'-O(&1E;&5T92!P87)T<R!I
M9B!Y;W4@=VES:"X*14Y(04Y#14U%3E0Z(%5N:VYO=VX@8G)O=W-E<G,@87)E
M('-I;7!L>2!A<VME9"!T;R!S96YD(&EN9F\[($E-4"!A<W-U;65S('1H870@
M=&AE>2!W;W)K"D5.2$%.0T5-14Y4.B!-=6QT:7!L92!C;VUP;W-E('=I;F1O
M=W,@87)E(&YO=R!S=7!P;W)T960*14Y(04Y#14U%3E0Z($%D9&5D(&$@<VEM
M<&QE(&-R;VXN9&%I;'D@9FEL92!T:&%T('=I;&P@8VQE86X@=7`@<W1R86YD
M960@871T86-H;65N=',*14Y(04Y#14U%3E0Z($-H86YG960@<V5T=7`G<R!D
M969A=6QT<R!T;R!B92!M;W)E(&9O<B!I;G1E<FYA;"UU<V4@<VET97,*14Y(
M04Y#14U%3E0Z(%-Y8F%S92!S=7!P;W)T(&AA<R!B965N(&%D9&5D('1O($E-
M4"`\<VQA8VM`8V,N=71A:"YE9'4^"D5.2$%.0T5-14Y4.B!N97<@)&1E9F%U
M;'0M/G1O7V1O;6%I;B!T86-K960@;VYT;R!B87)E(&-O;7!O<V4@861D<F5S
M<V5S"D5.2$%.0T5-14Y4.B!,;V=I;B!L86YG=6%G92!P=6QL+61O=VX@8V%N
M(&YO=R!B92!D:7-A8FQE9"`H:F]N*0I%3DA!3D-%345.5#H@1&5B:6%N('!A
M8VMA9V4@8G5I;&0@<V-R:7!T<R!I;F-L=61E9`I%3DA!3D-%345.5#H@4V5N
M="UM86EL(&YO=R!M87)K960@87,@<F5A9"`H7%Q3965N*0I%3DA!3D-%345.
M5#H@3F5W($1A;FES:"!L;V-A;&5S"DQ!3D=504=%.B!.;W)W96=I86X@;&%N
M9W5A9V4@<W5P<&]R="`M($AA;G,@36]R=&5N($MI;F0@/$MI;F1`:70N=6EB
M+FYO/@I,04Y'54%'13H@17-T;VYI86X@;&%N9W5A9V4@<W5P<&]R="`H2F%A
M;G5S(%1O;VUS86QU(#QJ86%N=7-`;6%T=&DN964^"DQ!3D=504=%.B!&:6YN
M:7-H(&QA;F=U86=E('-U<'!O<G0@*&QE;RYJ86%S:V5L86EN96Y`:V]L=6UB
M=7,N9FDI"DQ!3D=504=%.B!#>F5C:"!L86YG=6%G92!S=7!P;W)T(%!E=&5R
M($-E8V@@/&-E8VA`871R97DN:V%R;&EN+FUF9BYC=6YI+F-Z/@I,04Y'54%'
M13H@4&]L:7-H(&QA;F=U86=E('-U<'!O<G0@+5\@<V5R9VEO(%\M(#QS97)`
M<V5R96LN87)C:"YP=W(N=W)O8RYP;#X*3$%.1U5!1T4Z($YO<G=E9VEA;B!"
M;VMMY6P@;&%N9W5A9V4@<W5P<&]R="`M(%1E<FIE($QU;FYD86P@/'1E<FIE
M+FQU;FYD86Q`;F]R=V%Y+F5U+FYE=#X*3$%.1U5!1T4Z($EC96QA;F1I8R!L
M86YG=6%G92!S=7!P;W)T("T@2W)I<W1O9F5R($%R;F%R($5I;F%R<W-O;B`\
M:W)I<W1O9F5`:W)I<W1O9F5R+F-O;3X*3$%.1U5!1T4Z($9R96YC:"!U<&1A
M=&5D("T@2F5A;B!#:&%R;&5S($1E;&5P:6YE(#QD96QE<&EN94!U+7!I8V%R
M9&EE+F9R/@I314-54DE463H@5V4@<VAO=6QD(&YO=R!B92!I;6UU;F4@=&\@
M=&AE('M](&%N9"!M;V-H82!J879A<V-R:7!T(&5X<&QO:71S(')E8V5N=&QY
M(&1E<V-R:6)E9"!O;B!"=6=T<F%Q("T@0VAA<FQE<R!7<FEG:'0N"@H*+2TM
M+2TM"G8R+C$N,@HM+2TM+2T*"F-J:#H@=VAO;7`N(&AE<F4@=V4@9V\N"@I"
M:6=G97-T(&-H86YG93H@<V5S<VEO;B!S=7!P;W)T('1H<F]U9V@@9&)M(&9I
M;&5S+B!93U4@35535"!T;W5C:"!T:&4@9&)M"F9I;&4@*&)Y(&1E9F%U;'0@
M:6UP+VQI8B]S97-S:6]N<RD@86YD(&=I=F4@=&AE('=E8G-E<G9E<B!U<V5R
M(')E860O=W)I=&4*<&5R;6ES<VEO;G,@=&\@:70@*&%C='5A;&QY+"!Y;W4@
M9&]N)W0@:&%V92!T;R!C<F5A=&4@:70@:68@=&AE('=E8G-E<G9E<@IH87,@
M=W)I=&4@86-C97-S('1O('1H92!L:6(O(&1I<F5C=&]R>2DN"@I))W9E('1E
M<W1E9"!T:&ES('=I;&P@979E<GET:&EN9R!)(&-A;B!T:&EN:R!O9B`M('-E
M<G9E<B!L:7-T+"!L86YG=6%G97,L"F5V97)Y('!A9V4L(&5T8RX@22!T:&EN
M:R!I="!W;W)K<RX@22!P<F]B86)L>2!M:7-S960@<V]M971H:6YG+B!3;R!P
M;&5A<V4L"G!O=6YD(&]N(&ET+"!F:7@@:70L(&UA:V4@<W5G9V5S=&EO;G,N
M"@H*06QS;SH@22=V92!T86ME;B!A(&QO="!O9B!C<G5F="!T:&%T('=A<VXG
M="!B96EN9R!U<V5D(&]U="X@:6UP+FQI8B!W87,*=6YD97(@,3`P,"!L:6YE
M<R!F;W(@=&AE(&9I<G-T('1I;64@:6X@82!W:&EL92!A9G1E<B!T:&ES(2!)
M(&UA>2!P<G5N92!M;W)E"G8R('-T=69F(&EF(&ET)W,@;F]T('5S960@<V]O
M;CL@=&AA="!W;W5L9"!T<FEM('5S(&5V96X@;6]R92X@22!D:61N)W0@=')I
M;0IA('=H;VQE(&QO="!F<F]M(&AO<F1E+@H*"D-O<VUE=&EC.B!T:&4@)V-H
M96-K(&EN8F]X)R!O<'1I;VX@;VX@=&AE(&UE;G4@:7,@9V]N92`H<VAO=6QD
M('!R;V)A8FQY"G)E;6]V92!T:&4@;&%N9R!S=')I;F=S("T@:&%V96XG="!D
M;VYE('1H870I(&%N9"!I="=S(')E<&QA8V5D('=I=&@@82!C=71E"FQI='1L
M92!R96QO860@9W)A<&AI8R!A="!T:&4@=&]P(&QE9G0@;V8@;6%I;&)O>"!P
M86=E<R!T:&%T(&QE=',@>6]U(')E9G)E<V@*86YY(&UA:6QB;W@@=&AA="!Y
M;W4G<F4@:6XN('1H:7,@:7,@;6]R92!C;VYS:7-T96YT(&9R;VT@82!U:2!P
M;VEN="!O9B!V:65W+@H*"D5V97)Y=&AI;F<@96QS93H@<F5F;W)M871T:6YG
M+"!M:6YO<B!C:&%N9V5S+V9I>&5S+V5T8RX@3F]T:&EN9R!N;W1E=V]R=&AY
M"F5N;W5G:"!T;R!R96UE;6)E<B!O9F8@;V8@=&AE('1O<"!O9B!M>2!H96%D
M+@H*"E1O(&1O.B!D=6UP('1H92!M86EL8F]X7VQI<W0@9G5N8W1I;VYS(&EN
M=&\@=&AE(&YE=R!);6%P4V5S<VEO;B!O8FIE8W0L(&]R"BIA="!L96%S="H@
M<F5W<FET92!T:&5M('1O('1A:V4@861V86YT86=E(&]F('1H92!N97<@;F%M
M97-P86-E(&]B:F5C=',@=&AA=`IA<F4@879A:6QA8FQE+B!)(&AA=F5N)W0@
M=&]U8VAE9"!T:&ES(&]N92!Y970N"@I#;VUM96YT<S\*"BTM+2TM+0IV,BXQ
M+C$*+2TM+2TM"@I%;FAA;F-E;65N=',Z"B`@*B!);7`@;F]W('5N9&5S=&%N
M9',@1G)E;F-H("AT:&%N:W,@=&\@36%T:&EE=2!#;&%B875T(#QC;&%B875L
M=$!M=6QT:6UA;FEA+F-O;3XI"B`@*B!!='1A8VAM96YT<R!A<F4@;F]W(&EN
M9&EC871E9"!W:71H(&$@<&%P97)C;&EP(&EN('1H92!R96=U;&%R('-T871U
M<R!C;VQU;6X*("`J($YE=R!M86EL(&9O<B!E86-H(&9O;&1E<B!I<R!L:7-T
M960@:6X@9F]L9&5R(&QI<W1I;F<*("`J(%EO=2!C86X@8V]N9FEG=7)E('1H
M92`B9G)O;2(@<V5R=F5R(&]N(&$@<&5R+7-E<G9E<B!B87-I<R!W+W-E<G9E
M<G,N<&AP,R!N;W<*("`J($EM<"!H87,@:&5L<"!L:6YK<R!I;B!T:&4@8V]N
M=&%C=',@=VEN9&]W"@I"=6<@1FEX97,Z"B`@*B!&:7AE9"!A(&)U9R!I;B!T
M:&4@8V]N=&%C=',@=&AA="!W87,@8V%U<VEN9R!*879A<V-R:7!T(&5R<F]R
M<PH@("H@1FEX960@8G5G(&EN(&9O<G=A<F0@;6%I;"!C87-E('=I=&@@;6%I
M;"!T:&%T('=A<R!M:7-S:6YG(&AE861E<G,*("`J($9I>&5D(&$@8G5G('=H
M97)E(')E<&QY:6YG('1O(&UA:6P@8V%U<V5D(&5R<F]R<R!A;F0@=V%R;FEN
M9W,*"BTM+2TM+0IV,BXP+C,*+2TM+2TM"@I4:&5R92!W97)E(&$@8G5N8V@@
M;V8@8VAA;F=E<RP@8G5T(&YO8F]D>2!U<&1A=&5D('1H:7,@9FEL90H*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I.97<@86YD(&YO=&%B;&4@:6X@,BXP
M+C$Z"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"E-E=F5R86P@<&EE8V5S
M(&]F($E-4"!H879E(&)E96X@;6]V960@:6YT;R!T:&4@2&]R9&4@;6]D=6QE
M+B`@5&AE>2!I;F-L=61E('1H90IS:6=N=7`@9F5A='5R92P@<')O8FQE;2!R
M97!O<G1I;F<L('1H92!H96QP(&9U;F-T:6]N<RP@86YD(&9A<2!M86YA9V5M
M96YT+@H*02!N97<@;6]T9"!F96%T=7)E(&AA<R!B965N(&%D9&5D+B`@66]U
M(&-A;B!N;W<@=7-E('1H92!F:6QE(&-A;&QE9"!-3U1$+FAT;6P*86YD('!U
M="!I;B!I;F9O<FUA=&EO;B!Y;W4@=V%N="!S:&]W;B!U;F1E<B!T:&4@;&]G
M:6X@<V-R965N+B`@5&AI<R!F:6QE('-I=',*:6X@=&AE(&-O;F9I9R!D:7)E
M8W1O<GDN"@I%>'1E;F1A8FQE(&UE;G5S+B`@66]U(&-A;B!N;W<@96%S:6QY
M(&%D9"!M96YU(&ET96US(&)Y(&%D9&EN9R!I=&5M<R!T;R!T:&4*;65N=2YT
M>'0@9FEL92!W:&EC:"!R97-I9&5S(&EN('1H92!C;VYF:6<@9&ER96-T;W)Y
M+@H*66]U(&-A;B!N;W<@<V5T('EO=7(@<V5S<VEO;B!L86YG=6%G92!A="!L
M;V=I;BX*"D$@(FYE=RUU<V5R(&EN9F]R;6%T:6]N(B!P:65C92!H87,@8F5E
M;B!A9&1E9"!T;R!T:&4@;&]G:6X@<V-R965N+B`@5&AI<PIF=6YC=&EO;B!P
M<F]V:61E<R!N97<@=7-E<G,@=VET:"!S;VUE(&)A<VEC(&)A8VMG<F]U;F0@
M;VX@=7-I;F<@24U0+@H*02!F=6YC=&EO;B!W87,@861D960@=&\@=&AE(&-O
M;7!O<V4@=VEN9&]W('=H:6-H(&1O97,@;F]T(&%L;&]W('EO=2!T;R!S96YD
M"F$@<&EE8V4@;V8@96UA:6P@:68@>6]U(&AA=F4@8G)O=W-E9"!A(&9I;&4@
M871T86-H;65N="!B=70@:&%V96XG="!A='1A8VAE9`II="!Y970N"@I(96QP
M(&ET96US('=E<F4@861D960@=&\@=&AE(&-O;7!O<V4@=VEN9&]W+@H*1FEX
M960@<V5V97)A;"!I<W-U97,@=VET:"!M=6QT:7!L92!R96%D+W=R:71E(&EM
M87`@;W!E;FEN9W,N($YO=R!O;FQY"F-A;&QS('1H870@<F5Q=6ER92!R96%D
M+W=R:71E('5S92!R96%D+W=R:71E+@H*1FEX960@;75L=&EP;&4@87!P96YD
M('1R86EL97(O9F]O=&5R(&)U9W,N"@I,;V-A;&EZ960@=&AE('-E='5P+G!H
M<#,@<')O8V5S<RX*"E5P9&%T960@;'EN>"!P86=E<R!S;R!L>6YX('=O<FMS
M(&%G86EN('=I=&@@24U0"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VEM<"]D;V-S+T-2141)5%,`````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,T,#(`,3`T,3<S-C(W-S``
M,#$W,34U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*($E-4"!$979E;&]P;65N="!4
M96%M"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D
M1&%T93H@,C`P-B\P,R\P-B`P.3HT,SHU-B`D"CI2979I<VEO;CH@("`@("`D
M4F5V:7-I;VXZ(#$N.#,N,BXR,2`D"CI#;VYT86-T.B`@("`@("!I;7!`;&ES
M=',N:&]R9&4N;W)G"@H*0V]R92!$979E;&]P97)S"CT]/3T]/3T]/3T]/3T]
M/0H*+2!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*+2!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@HM($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!C=7)E8V%N=&DN;W)G/@H*"DQO8V%L:7IA=&EO;@H]/3T]/3T]
M/3T]/3T*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I!<F%B
M:6,@*$]M86XI("`@("`@("`@("!386ED($%L+4AO<VYI(#QA9&UI;D!W86)H
M;W-T:6YG+F-O;3X*07)A8FEC("A3>7)I82D@("`@("`@("`@4&QA=&EN=6T@
M1&5V96QO<&UE;G0@5&5A;2`\9&5V=&5A;4!P;&%T:6YU;2US>2YN970^"D)O
M<VYI86X@("`@("`@("`@("`@("`@($%L96X@4V%R:VEN;W9I8R`\86QE;D!L
M:6YU>"YO<F<N8F$^"B`@("`@("`@("`@("`@("`@("`@("`@(%9E9')A;B!,
M:G5B;W9I8R`\=FQJ=6)O=FEC0'-M87)T;F5T+F)A/@I"<F%Z:6QI86X@4&]R
M='5G=65S92`@("`\:&]S=&UA<W1E<D!S8G,N<W)V+F)R/@H@("`@("`@("`@
M("`@("`@("`@("`@("!!;G1O;FEO($1I87,@/&%C8V1I87-`<W-T+F-O;2YB
M<CX*("`@("`@("`@("`@("`@("`@("`@("`@1F%B:6\@1V]M97,@/&9L9V]M
M<T!U;VPN8V]M+F)R/@I"=6QG87)I86X@("`@("`@("`@("`@("!-:7)O<VQA
M=B!096YD978@/'!E;F1E=D!H;W1M86EL+F-O;3X*0V%T86QA;B`@("`@("`@
M("`@("`@("`@06YG96QS($=U:6UE<N`@/&%N9V5L<RY'=6EM97)A0'5A8BYE
M<SX*0VAI;F5S92`H4VEM<&QI9FEE9"D@("`@5V%N9TAE;F=796X@/'=H=T!M
M>3$V.2YC;VT^"D-H:6YE<V4@*%1R861I=&EO;F%L*2`@($9,($M/1B`\:V]F
M7V9L0&AO=&UA:6PN8V]M/@H@("`@("`@("`@("`@("`@("`@("`@("!$879I
M9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SX*0WIE8V@@("`@("`@("`@("`@
M("`@("`@4&%V96P@0VAY=&EL(#QP8VAY=&EL0&%S<"YO9VDN961U/@I$86YI
M<V@@("`@("`@("`@("`@("`@("!-87)T:6X@3&ES="U0971E<G-E;B`\;6%R
M=&EN0&QI<W0M<&5T97)S96XN9&L^"B`@("`@("`@("`@("`@("`@("`@("`@
M($)R:6%N(%1R=65L<V5N(#QH;W)D92MI,3AN0&)R:6%N=')U96QS96XN9&L^
M"D1U=&-H("`@("`@("`@("`@("`@("`@($IA;B!+=6EP97)S(#QJ<FMU:7!E
M<G-`;&%U=V5R<V-O;&QE9V4N;FP^"B`@("`@("`@("`@("`@("`@("`@("`@
M(%!E=&5R($%R:65N(#QP971E<BYA<FEE;D!C8RYK=6QE=79E;BYA8RYB93X*
M("`@("`@("`@("`@("`@("`@("`@("`@2&%N(%-P<G5Y="`\:&%N+G-P<G5Y
M=$!I:G-S96QG<F]E<"YN;#X*17-T;VYI86X@("`@("`@("`@("`@("`@5&]O
M;6%S($%A<R`\=&]O;6%S+F%A<T!R86%D+G1A<G1U+F5E/@I&:6YN:7-H("`@
M("`@("`@("`@("`@("!,965N82!(96EN;R`\;&EI;G5`=71A+F9I/@I&<F5N
M8V@@("`@("`@("`@("`@("`@("!#:')I<W1O<&AE(%)U96QL92`\<G5E;&QE
M0&5C:&\N9G(^"B`@("`@("`@("`@("`@("`@("`@("`@($9R961E<FEC(%1R
M=61E874@/&9T<G5D96%U0$-!32Y/4D<^"B`@("`@("`@("`@("`@("`@("`@
M("`@($)E;F]I="!3="U!;F1RZ2`\8F5N0&)E;F]I='-T+6%N9')E+FYE=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@4&EE<G)E($QA8VAA;F-E(#QP;$!P
M:65R<F5L86-H86YC92YN970^"D=A;&EC:6%N("`@("`@("`@("`@("`@(%)A
M9F%E;"!687)E;&$@/')A9F%E;"YV87)E;&%`=7-C+F5S/@H@("`@("`@("`@
M("`@("`@("`@("`@("!'=6EL;&5R;6\@365N9&5Z(#QG=6EL;&5`=7-C+F5S
M/@I'97)M86X@("`@("`@("`@("`@("`@("!#87)S=&5N($=U96YT:&5R(#QC
M9W5E;G1H97)`9W5E;G1H97)S+FYE=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*1W)E96L@("`@("`@
M("`@("`@("`@("`@4W1E9F%N;W,@22X@1&EM:71R:6]U(#QS=7!P;W)T0'1E
M:6%T:"YG<CX*("`@("`@("`@("`@("`@("`@("`@("`@4VEL;&EG87)D;W,@
M6')I<W1O9F]R;W,*("`@("`@("`@("`@("`@("`@("`@("`@06YA9VYO<W1O
M<&]U;&]S($%P;W-T;VQI<PI(96)R97<@("`@("`@("`@("`@("`@("!-871T
M(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D=3X*2'5N9V%R:6%N("`@("`@
M("`@("`@("`@3&%S>FQO($PN(%1O<FYO8VD@/'1O<FQA<WI`>&5N:6$N<V]T
M92YH=3X*26-E;&%N9&EC("`@("`@("`@("`@("`@0FIO<FX@1&%V:61S<V]N
M(#QB:F]S<VE`<VYE<G!A+FES/@I);F1O;F5S:6%N("`@("`@("`@("`@("!3
M;&%M:6X@/'-L86UI;D!U;F5J+F%C+FED/@I)=&%L:6%N("`@("`@("`@("`@
M("`@("!':6]V86YN:2!-96YE9VAE='1I(#QG;65N96=H971T:4!I;F9V:6,N
M:70^"B`@("`@("`@("`@("`@("`@("`@("`@($UA<F-O(%!I<F]V86YO(#QM
M87)C;RYP:7)O=F%N;T!U;FEB;V-C;VYI+FET/@H@("`@("`@("`@("`@("`@
M("`@("`@("!#<FES=&EA;B!-86YO;FD@/&-R:7-T:6%N+FUA;F]N:4!N971H
M97-I<RYI=#X*2F%P86YE<V4@("`@("`@("`@("`@("`@0BY*+B!";&%C:R`\
M=VEL;&EA;2YB;&%C:T!S=6XN8V]M/@H@("`@("`@("`@("`@("`@("`@("`@
M("!486ME<VAI($UO<FES:&EM82`\=&U`;VYE<&]S="YN970^"B`@("`@("`@
M("`@("`@("`@("`@("`@($AI<F]M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U
M:W5B82YA8RYJ<#X*2VAM97(@("`@("`@("`@("`@("`@("`@3&5A;F<@0VAU
M;7-O8F5N(#QS;V)E;D!K:&UE<F]S+FEN9F\^"DMO<F5A;B`@("`@("`@("`@
M("`@("`@($HN22!+:6T@/&%P;W)I94!N971I86XN8V]M/@H@("`@("`@("`@
M("`@("`@("`@("`@("!*:6YH>6]K($AE;R`\;F]V96UB<F5`;W5R;F%T=7)E
M+F]R9SX*3&%T=FEA;B`@("`@("`@("`@("`@("`@2V%S<&%R<R!+87!E;FEE
M:W,@/&MA<W!A<G-`<F-C+FQV/@I,:71H=6%N:6%N("`@("`@("`@("`@("!$
M87)I=7,@36%T=6QI875S:V%S(#QD87)I=7-`;&YK+FQT/@H@("`@("`@("`@
M("`@("`@("`@("`@("!6:6QI=7,@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#X*
M36%C961O;FEA;B`@("`@("`@("`@("`@4W1O:F%N(%!E<V]V(#QS<W!`975R
M96MA+F-O;2YM:SX*3F]R=V5G:6%N($)O:VUA86P@("`@("`@V'EV:6YD($UO
M;G-L^'`@/&]M;VYS;&]P0&]N;&EN92YN;SX*("`@("`@("`@("`@("`@("`@
M("`@("`@3WES=&5I;B!3=&5I;6QE<B`\;WES=&5I;D!R97AT82YN970^"B`@
M("`@("`@("`@("`@("`@("`@("`@(%1O<F)J;W)N($=R:6YD:&%U9R`\9W)I
M;F1H875G0&=M86EL+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@5&]R
M<W1E:6X@4RX@2&%N<V5N(#QH=6QE8F]E<D!T96-H8F5E+FYO/@H@("`@("`@
M("`@("`@("`@("`@("`@("!!;F1R96%S($=U;FQE:6MS:V%A<R`\86YD<F5A
M<T!G=6YL96EK<VMA87,N;F\^"B`@("`@("`@("`@("`@("`@("`@("`@(%1R
M;VYD($)J^')S=&%D(#QT<F)`;F1N+FYO/@H@("`@("`@("`@("`@("`@("`@
M("`@("!4:&]M87,@0VAR+B!$86AL(#QT8V1`;F1N+FYO/@I.;W)W96=I86X@
M3GEN;W)S:R`@("`@("!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^
M"E!E<G-I86X@("`@("`@("`@("`@("`@($UE=&%.150@06UI<FMA8FER(#QP
M97)S:6%N+6AO<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*4&]L:7-H("`@("`@
M("`@("`@("`@("`@36%R:75S>B!:>6YE;"`\;6%R:75S>D!M871H+G5W8BYE
M9'4N<&P^"B`@("`@("`@("`@("`@("`@("`@("`@(%!I;W1R(%)O<WIA='EC
M:VD@/&1E>'1E<D!D96)I86XN;W)G/@H@("`@("`@("`@("`@("`@("`@("`@
M("!0<GIE;7ES;&%W(")0<FEM;R(@5VET96L@/'!R:6UO0&YP;"YP;#X*("`@
M("`@("`@("`@("`@("`@("`@("`@36%T975S>B!+86UI;G-K:2`\;6%T:7!L
M0'!L9"UL:6YU>"YO<F<^"B`@("`@("`@("`@("`@("`@("`@("`@($MR>GES
M>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#X*4&]R='5G=65S92`@("`@
M("`@("`@("`@3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N<'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@($UA;G5E;"!-96YE>F5S(&1E(%-E<75E:7)A(#Q-
M86YU96PN4V5Q=65I<F$^"E)O;6%N:6%N("`@("`@("`@("`@("`@($-O<FYE
M;&EU($UU<V%T(#QC;75S871`=&EA;6%T+FME>7-Y<RYR;SX*4G5S<VEA;B`@
M("`@("`@("`@("`@("`@06YT;VX@3F5K:&]R;W-H:6@@/&%N=&]N0'9A;'5E
M:&]S="YR=3X*("`@("`@("`@("`@("`@("`@("`@("`@1F5D;W(@02X@1F5T
M:7-O=B`\9F%F0'-S8RYR=3X*("`@("`@("`@("`@("`@("`@("`@("`@06QE
M>&5Y(%IA:VAA<F]V(#QA;&5X0&)K<RYB>3X*4VQO=F%K("`@("`@("`@("`@
M("`@("`@3&5O($UR869K;R`\;&5O0&]E;"YS:SX*("`@("`@("`@("`@("`@
M("`@("`@("`@279A;B!.;W)I<R`\;F]R:7-`8F=S+G-K/@I3;&]V96YI86X@
M("`@("`@("`@("`@("!*=7)E($MR87-O=FEC(#QJ=7)E:T!R8V,M:7)C+G-I
M/@H@("`@("`@("`@("`@("`@("`@("`@("!-871I8R!$;VQA<B`\;6%T:6-`
M;65D:75M+G-I/@I3<&%N:7-H("`@("`@("`@("`@("`@("!2875L($%L=F%R
M97H@5F5N96=A<R`\<F%V0'1E8V]M86XN=6-O;"YM>#X*("`@("`@("`@("`@
M("`@("`@("`@("`@36%N=65L(%!E<F5Z($%Y86QA(#QM<&5R87EA0&%L8V%Z
M86)A+G5N97@N97,^"E-W961I<V@@("`@("`@("`@("`@("`@($%N9')E87,@
M1&%H;.EN(#QA;F1R96%S0&1A:&QE;BYW<SX*("`@("`@("`@("`@("`@("`@
M("`@("`@2F]A<75I;2!(;VUR:6=H875S96X@/&IO:&]`=V5B8G!L871S96XN
M<V4^"E1H86D@("`@("`@("`@("`@("`@("`@(%-U<F%S86L@4W)I<V%W86X@
M/'-U<F%S86M`<FER8RYA8RYT:#X*5'5R:VES:"`@("`@("`@("`@("`@("`@
M1V5N8V\@66EL;6%Z(#QG96YC;WEI;&UA>D!Y86AO;RYC;VT^"B`@("`@("`@
M("`@("`@("`@("`@("`@($ES=&%N8G5L(%1E8VAN:6-A;"!5;FEV97)S:71Y
M($E4($1E<&%R=&UE;G0*("`@("`@("`@("`@("`@("`@("`@("`@/&ET=6)I
M;4!I='4N961U+G1R/@H@("`@("`@("`@("`@("`@("`@("`@("!397)V970@
M1_QN97D@/'-G=6YE>4!M971U+F5D=2YT<CX*("`@("`@("`@("`@("`@("`@
M("`@("`@06AM970@UGIT_')K(#QO86AM971`;65T=2YE9'4N='(^"E5K<F%I
M;FEA;B`@("`@("`@("`@("`@($%N9')I>2!+;W!Y<W1Y86YS:WD@/&%N<FE`
M<&]L>6YE="YL=FEV+G5A/@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T@("`]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"@I);F%C=&EV92!$979E;&]P97)S"CT]/3T]/3T]/3T]/3T]/3T]
M/3T*"BT@2F]N(%!A<FES92`\:F]N0&-S:"YR:70N961U/@HM($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"BT@06YI;"!-861H879A
M<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*+2!*87-O;B!/<F-U='0@/'IE<F]D
M:79`>F5R;V1I=FED92YN970^"BT@0G)I86X@2F]N97,@/&-B:D!G;G4N;W)G
M/@HM($UI:V4@2&%R9'D@/&UI:V5`:71S<')O:F5C=',N8V]M/@HM($EV86X@
M12X@36]O<F4@24D@/')K<G5S='E`=&1Y8RYC;VT^"BT@0VAR:7,@2'ED92`\
M8VAR:7-`:F5K<RYN970^("A);G1E<F%C=&EV92!3<&5L;"!#:&5C:V5R*0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:6UP+V1O8W,O24Y35$%,3```````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-3<V-@`Q,#0Q-S,V,C<W,``P,3<R
M,3``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/3T]/3T]/3T]/3T]/3T]/3T]/3T*($EN<W1A;&QI;F<@24U0(#0N,0H]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`V
M+S`R+S`U(#`W.C$W.C$T("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@
M,2XU-RXV+C$S("0*.D-O;G1A8W0Z("`@("`@(&EM<$!L:7-T<RYH;W)D92YO
M<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I
M;F<Z.@H*5&AI<R!D;V-U;65N="!C;VYT86EN<R!I;G-T<G5C=&EO;G,@9F]R
M(&EN<W1A;&QI;F<@=&AE($E-4"!W96(M8F%S960@;6%I;`IC;&EE;G0@;VX@
M>6]U<B!S>7-T96TN"@I&;W(@:6YF;W)M871I;VX@;VX@=&AE(&-A<&%B:6QI
M=&EE<R!A;F0@9F5A='5R97,@;V8@24U0+"!S964@=&AE(&9I;&4@4D5!1$U%
M7PII;B!T:&4@=&]P+6QE=F5L(&1I<F5C=&]R>2!O9B!T:&4@24U0(&1I<W1R
M:6)U=&EO;BX*"@I/8G1A:6YI;F<@24U0"CT]/3T]/3T]/3T]/3T*"DE-4"!C
M86X@8F4@;V)T86EN960@9G)O;2!T:&4@2&]R9&4@=V5B<VET92!A;F0@1E10
M('-E<G9E<BP@870*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VEM<"\*"B`@
M(&9T<#HO+V9T<"YH;W)D92YO<F<O<'5B+VEM<"\*"D]R('5S92!T:&4@;6ER
M<F]R(&-L;W-E<W0@=&\@>6]U.@H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M;6ER<F]R<RYP:'`*"D)L965D:6YG+65D9V4@9&5V96QO<&UE;G0@=F5R<VEO
M;G,@;V8@24U0(&%R92!A=F%I;&%B;&4@=FEA($-64SL@<V5E('1H92!F:6QE
M"F!H;W)D92]D;V-S+TA!0TM)3D=@7R!I;B!T:&4@2&]R9&4@9&ES=')I8G5T
M:6]N+"!O<B!T:&4@=V5B<VET90IH='1P.B\O=W=W+FAO<F1E+F]R9R]S;W5R
M8V4O+"!F;W(@:6YF;W)M871I;VX@;VX@86-C97-S:6YG('1H92!(;W)D92!#
M5E,*<F5P;W-I=&]R>2X*"@I0<F5R97%U:7-I=&5S"CT]/3T]/3T]/3T]/3T*
M"E1O(&9U;F-T:6]N('!R;W!E<FQY+"!)35`@*BIR97%U:7)E<RHJ('1H92!F
M;VQL;W=I;F<Z"@HQ+B!!('=O<FMI;F<@2&]R9&4@:6YS=&%L;&%T:6]N+@H*
M("`@24U0(')U;G,@=VET:&EN('1H92!@2&]R9&4@07!P;&EC871I;VX@1G)A
M;65W;W)K8%\L(&$@<V5T(&]F(&-O;6UO;B!T;V]L<PH@("!F;W(@5V5B(&%P
M<&QI8V%T:6]N<R!W<FET=&5N(&EN(%!(4"X@(%EO=2!M=7-T(&EN<W1A;&P@
M2&]R9&4@8F5F;W)E"B`@(&)E9F]R92!I;G-T86QL:6YG($E-4"X*"B`@("XN
M($EM<&]R=&%N=#HZ($E-4"`T+C`@<F5Q=6ER97,@=F5R<VEO;B`S+C`K(&]F
M('1H92!(;W)D92!&<F%M97=O<FL@+0H@("`@("`@("`@("`@("`@("!E87)L
M:65R('9E<G-I;VYS(&]F($AO<F1E('=I;&P@*BIN;W0J*B!W;W)K+@H*("`@
M+BX@7V!(;W)D92!!<'!L:6-A=&EO;B!&<F%M97=O<FM@.B!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]H;W)D92\*"B`@(%1H92!(;W)D92!&<F%M97=O<FL@8V%N
M(&)E(&]B=&%I;F5D(&9R;VT@=&AE($AO<F1E('=E8G-I=&4@86YD($944"!S
M97)V97(L"B`@(&%T"@H@("`@("!H='1P.B\O=W=W+FAO<F1E+F]R9R]H;W)D
M92\*"B`@("`@(&9T<#HO+V9T<"YH;W)D92YO<F<O<'5B+VAO<F1E+PH*("`@
M36%N>2!O9B!)35`G<R!P<F5R97%U:7-I=&5S(&%R92!A;'-O($AO<F1E('!R
M97)E<75I<VET97,N"@H@("`N+B!);7!O<G1A;G0Z.B!"92!S=7)E('1O(&AA
M=F4@8V]M<&QE=&5D(&%L;"!O9B!T:&4@<W1E<',@:6X@=&AE"B`@("`@("`@
M("`@("`@("`@(&!H;W)D92]D;V-S+TE.4U1!3$Q@7R!F:6QE(&9O<B!T:&4@
M2&]R9&4@1G)A;65W;W)K(&)E9F]R90H@("`@("`@("`@("`@("`@("!I;G-T
M86QL:6YG($E-4"X*"C(N(%1H92!F;VQL;W=I;F<@4$A0(&-A<&%B:6QI=&EE
M<SH*"B`@(&$N($E-05`@86YD(%!/4#,@<W5P<&]R="!@8"TM=VET:"UI;6%P
M8&`*"B`@("`@($E-4"`J*G)E<75I<F5S*BH@=&AE(%57+4E-05`@8RUC;&EE
M;G0@;&EB<F%R>2!T;R!P<F]V:61E($E-05`@86YD+V]R"B`@("`@(%!/4#,@
M<W5P<&]R="X@(%1H92!C+6-L:65N="!L:6)R87)Y(&ES(&%V86EL86)L92!F
M<F]M"@H@("`@("`@("!F='`Z+R]F='`N8V%C+G=A<VAI;F=T;VXN961U+VEM
M87`O"@H@("`@("!)35`@*BIR97%U:7)E<RHJ($E-05`@86YD(%!/4#,@<W5P
M<&]R="!I;B!02%`L(&%N9"!C86X@=7-E($E-05`M4U-,(&%N9`H@("`@("!0
M3U`S+5-33"!I9B!A=F%I;&%B;&4@*'-E92!T:&4@8&`M+7=I=&@M:6UA<"US
M<VQ@8"!C;VYF:6=U<F4@;W!T:6]N*2X*("`@("`@268@=7-I;F<@96ET:&5R
M(%1,4R!O<B!34TP@=&\@8V]N;F5C="!T;R!T:&4@24U!4"]03U`@<V5R=F5R
M+"!/<&5N4U-,"B`@("`@('-U<'!O<G0@:7,@*BIR97%U:7)E9"HJ(&EN(%!(
M4"X@4V5E(&!/<&5N4U-,(%-U<'!O<G1@7R!B96QO=RX*"B`@("`@("XN(%1I
M<#HZ($EF('EO=2!N;W1I8V4@<W1R86YG92!B96AA=FEO<B!W:&5N(')U;FYI
M;F<@24U0("AE+F<N(&)L86YK"B`@("`@("`@("`@("`@('-C<F5E;G,@=VAE
M;B!A8V-E<W-I;F<@8V5R=&%I;B!M97-S86=E<RP@8FQA;FL@;65S<V%G92!B
M;V1I97,I"B`@("`@("`@("`@("`@('EO=2!S:&]U;&0@86QW87ES('1R>2!R
M96-O;7!I;&EN9R!02%`@=VET:"!A(&1I9F9E<F5N="!V97)S:6]N"B`@("`@
M("`@("`@("`@(&]F(&,M8VQI96YT+B`@5&AE(&1I9F9E<F5N="!V97)S:6]N
M<R!O9B!T:&4@8RUC;&EE;G0@;&EB<F%R>2!A;F0*("`@("`@("`@("`@("`@
M4$A0(&1O(&YO="!A;'=A>7,@=V]R:R!W96QL('1O9V5T:&5R+"!A;F0@;V9T
M96X@86QL(&ET('1A:V5S(&ES"B`@("`@("`@("`@("`@('1O(')E8V]M<&EL
M92!W:71H(&$@9&EF9F5R96YT(&,M8VQI96YT('9E<G-I;VX@86YD('1H92!P
M<F]B;&5M<PH@("`@("`@("`@("`@("!W:6QL(&=O(&%W87DN"@H@("`@("`N
M+B!4:7`Z.B!)9B!R=6YN:6YG('1H92!W96)S97)V97(@8VAA;F=E<F]O=&5D
M("AI+F4N('1H92!D969A=6QT('-E='1I;F<*("`@("`@("`@("`@("`@;VX@
M3W!E;D)31"DL('EO=2!M87D@;F5E9"!A9&1I=&EO;F%L(&-O;F9I9W5R871I
M;VX@;VX@>6]U<@H@("`@("`@("`@("`@("!S>7-T96T@=&\@96YS=7)E('1H
M92!C+6-L:65N="!L:6)R87)Y('=O<FMS('!R;W!E<FQY+@H@("`@("`@("`@
M("`@("!3964Z(&!#;VYF:6=U<FEN9R!C+6-L:65N="!F;W(@8VAA;F=E<F]O
M=&5D('=E8G-E<G9E<G-@7PH*("`@("`@+BX@7V!#;VYF:6=U<FEN9R!C+6-L
M:65N="!F;W(@8VAA;F=E<F]O=&5D('=E8G-E<G9E<G-@.B!H='1P.B\O;&ES
M=',N:&]R9&4N;W)G+V%R8VAI=F5S+VEM<"]7965K+6]F+4UO;BTR,#`U,#,R
M,2\P-#$U,#(N:'1M;`H*("`@8BX@1FEL92!5<&QO860@4W5P<&]R=`H*("`@
M("`@1FEL92!U<&QO860@<W5P<&]R="!I<R`J*G)E<75I<F5D*BH@=&\@86QL
M;W<@871T86-H;65N=',@:6X@;6%I;`H@("`@("!C;VUP;W-I=&EO;B!A;F0@
M=&\@86QL;W<@=F%R:6]U<R!I;7!O<G1I;F<@9F5A='5R97,@=&\@=V]R:R`H
M92YG+@H@("`@("!I;7!O<G1I;F<@4$=0(&]R(%,O34E-12!K97ES+"!I;7!O
M<G1I;F<@;6)O>"!F:6QE<RDN("!4;R!E;F%B;&4@9FEL90H@("`@("!U<&QO
M860@<W5P<&]R=#H*"B`@("`@("`@("`Q+B!);B!Y;W5R('!H<"YI;FD@9FEL
M92P@=&AE(&9O;&QO=VEN9R!L:6YE("HJ;75S="HJ(&)E('!R97-E;G0Z.@H*
M("`@("`@("`@("`@("`@(&9I;&5?=7!L;V%D<R`]($]N"@H@("`@("`@("`@
M,BX@66]U<B!T96UP;W)A<GD@=7!L;V%D(&1I<F5C=&]R>2`J*FUU<W0J*B!B
M92!W<FET86)L92!T;R!T:&4@=7-E<@H@("`@("`@("`@("`@=&AE('=E8B!S
M97)V97(@:7,@<G5N;FEN9R!A<RX@($EF('EO=2!L96%V92!T:&4@8V]N9FEG
M=7)A=&EO;@H@("`@("`@("`@("`@;W!T:6]N(&!@=7!L;V%D7W1M<%]D:7)@
M8"!B;&%N:R!I;B!@8'!H<"YI;FE@8"P@4$A0('=I;&P@=7-E('1H90H@("`@
M("`@("`@("`@9&5F875L="!D:7)E8W1O<GD@8V]M<&EL960@:6YT;R!I="`H
M;F]R;6%L;'D@8&`O=&UP8&`@;VX*("`@("`@("`@("`@(%5N:7@M;&EK92!S
M>7-T96US*2X*"B`@("`@("`@("`S+B!3970@=&AE(&UA>&EM=6T@<VEZ92!O
M9B!T:&4@=7!L;V%D960@9FEL97,@=FEA('1H90H@("`@("`@("`@("`@8&!U
M<&QO861?;6%X7V9I;&5S:7IE8&`@8V]N9FEG=7)A=&EO;B!O<'1I;VX@:6X@
M8&!P:'`N:6YI8&`N("!&;W(*("`@("`@("`@("`@(&5X86UP;&4L('1O(&%L
M;&]W(#4@34(@871T86-H;65N=',L('!L86-E('1H92!F;VQL;W=I;F<@;&EN
M92!I;@H@("`@("`@("`@("`@>6]U<B!@8'!H<"YI;FE@8"!F:6QE.CH*"B`@
M("`@("`@("`@("`@("!U<&QO861?;6%X7V9I;&5S:7IE(#T@-4T*"B`@("`@
M("!)9B!E:71H97(@8&!F:6QE7W5P;&]A9'-@8"!I<R!T=7)N960@;V9F+"!O
M<B!Y;W5R('1E;7!O<F%R>2!U<&QO860*("`@("`@(&1I<F5C=&]R>2!I<R`J
M;F]T*B!W<FET86)L92!B>2!T:&4@<V5R=F5R+"!A;&P@9FEL92!U<&QO860*
M("`@("`@(&9U;F-T:6]N86QI='D@=VEL;"!B92!D:7-A8FQE9"!B>2!(;W)D
M92])35`@86YD('=I;&P@;F]T(&)E(&%V86EL86)L90H@("`@("`@=&\@=&AE
M('5S97(N"@H@("!4:&4@9F]L;&]W:6YG(%!(4"!O<'1I;VYS(&%R92`J*E)%
M0T]-345.1$5$*BH@=&\@96YA8FQE(&%D=F%N8V5D(&9E871U<F5S(&EN"B`@
M($E-4#H*"BXN(%]@3W!E;E-33"!3=7!P;W)T8#H*"B`@(&$N($]P96Y34TP@
M<W5P<&]R="!@8"TM=VET:"UO<&5N<W-L8&`*"B`@("`@(%1H92!/<&5N4U-,
M(&UO9'5L92!I<R!U<V5D(&)Y($E-4"!T;R!P<F]V:61E(%,O34E-12!F=6YC
M=&EO;F%L:71Y+@H@("`@("!7:71H;W5T('1H92!M;V1U;&4L(%,O34E-12!O
M<'1I;VYS('=I;&P@8F4@9&ES86)L960N"@H@("`@("!!9&1I=&EO;F%L;'DL
M('1H92!/<&5N4U-,(&UO9'5L92!I<R!215%525)%1"!I9B!U<VEN9R!E:71H
M97(@5$Q3(&]R(%-33`H@("`@("!T;R!C;VYN96-T('1O('1H92!)34%0+U!/
M4"!S97)V97(N"@H@("`@("!3964@:'1T<#HO+W=W=RYP:'`N;F5T+V]P96YS
M<VP@9F]R(&EN9F]R;6%T:6]N(&]N(&-O;7!I;&EN9R!/<&5N4U-,"B`@("`@
M(&EN=&\@4$A0+@H*,RX@5&AE(&9O;&QO=VEN9R!014%2(&UO9'5L97,Z"B`@
M("A3964@8&AO<F1E+V1O8W,O24Y35$%,3&!?(&9O<B!I;G-T<G5C=&EO;G,@
M;VX@:6YS=&%L;&EN9R!014%2(&UO9'5L97,I"@H@("!A+B!(5%107U)E<75E
M<W0@6T]05$E/3D%,70H*("`@("`@2%144%]297%U97-T(&ES(')E<75I<F5D
M('1O('5S92!T:&4@2%1-3"!C;VUP;W-I=&EO;B!M;V1E+@H*("`@8BX@075T
M:%]305-,(%M/4%1)3TY!3%T*"B`@("`@($%U=&A?4T%33"!I<R!R97%U:7)E
M9"!I9B!Y;W5R($E-05`@<V5R=F5R('5S97,@0U)!32U-1#4@;W(@1$E'15-4
M+4U$-0H@("`@("!A=71H96YT:6-A=&EO;BX*"C0N($%T(&QE87-T(&]N92!)
M34%0(&]R(%!/4#,@<V5R=F5R+@H*("`@5VAI;&4@24U0(&ES(&%N(&%P<&QI
M8V%T:6]N('1H870@:7,@:6YS=&%L;&5D(&]N(&$@5V5B('-E<G9E<B!A;F0@
M:7,@<G5N"B`@(&9R;VT@82!796(@8G)O=W-E<BP@:70@:7,@;VYL>2!A;B!)
M34%0(&%N9"!03U`S("IC;&EE;G0J+"!L:6ME($5U9&]R82!O<@H@("!/=71L
M;V]K($5X<')E<W,N("!9;W4@;75S="!H879E(&%C8V5S<R!T;R!A;B!)34%0
M(&]R(%!/4#,@<V5R=F5R("AO<@H@("!M=6QT:7!L92!S97)V97)S*2!O;B!W
M:&EC:"!Y;W5R('5S97)S)R!M86EL(&ES('-T;W)E9"!I;B!O<F1E<B!T;R!U
M<V4@24U0+@H*("`@24U!4"!I<R!R96-O;6UE;F1E9"!O=F5R(%!/4#,@:6X@
M;W)D97(@=&\@;&5T('5S97)S(&UA:6YT86EN(&UA:6P@9F]L9&5R<PH@("!O
M=&AE<B!T:&%N($E.0D]8(&%N9"!I<R!R97%U:7)E9"!T;R!A;&QO=R!M97-S
M86=E<R!T;R!B92!F;&%G9V5D+B!)34%0(&ES"B`@(&%L<V\@*FUU8V@J(&9A
M<W1E<B!T:&%N(%!/4#,@:6X@9&ES<&QA>6EN9R!A(&UA:6QB;W@@;V8@;65S
M<V%G97,N("!);@H@("!S:&]R="P@9&\@;F]T('5S92!03U`S('5N;&5S<R!)
M34%0(&ES(&YO="!A=F%I;&%B;&4N"@H@("!&<F5E;'D@879A:6QA8FQE($E-
M05`@<V5R=F5R<R`H9F]R(%PJ;FEX('-Y<W1E;7,I('1H870@:&%V92!B965N
M('9E<FEF:65D"B`@('1O('=O<FL@=VET:"!)35`@:6YC;'5D93H*"B`@("T@
M55<M24U!4"`H9G1P.B\O9G1P+F-A8RYW87-H:6YG=&]N+F5D=2]I;6%P+RD*
M("`@+2!#;W5R:65R+4E-05`@*&AT='`Z+R]W=W<N:6YT97(W+F-O;2]C;W5R
M:65R:6UA<"YH=&UL*0H@("`M($-Y<G5S("AH='1P.B\O87-G+G=E8BYC;74N
M961U+V-Y<G5S+RD*("`@+2!$;W9E8V]T("AH='1P.B\O9&]V96-O="YP<F]C
M;VYT<F]L+F9I+RD*"E1H92!F;VQL;W=I;F<@:71E;7,@87)E(&YO="!R97%U
M:7)E9"P@8G5T(&%R92!S=')O;F=L>2`J*E)%0T]-345.1$5$*BHZ"@HQ+B!3
M96YD;6%I;"!O<B!E<75I=F%L96YT+@H*("`@5VAI;&4@2&]R9&4@8V%N(&EN
M:F5C="!M86EL('9I82!E:71H97(@82!L;V-A;"!S96YD;6%I;"!O<B!A(')E
M;6]T92!33510"B`@('-E<G9E<BP@<V5N9&UA:6P@:7,@<F5C;VUM96YD960@
M9F]R('5S92!W:71H($E-4"!F;W(@:6UP<F]V960@<&5R9F]R;6%N8V4*("`@
M86YD(&5R<F]R(&AA;F1L:6YG+W)E<&]R=&EN9RP@87,@=V5L;"!A<R!A(&UO
M<F4@86-C=7)A=&4@;6%I;"!E;G9E;&]P92X*"B`@(%1H92!M86EL('1R86YS
M<&]R="!S971T:6YG<R!A<F4@<V5T(&EN('1H92!(;W)D92!C;VYF:6=U<F%T
M:6]N+"!S;R!F=7)T:&5R"B`@(&1O8W5M96YT871I;VX@8V%N(&)E(&9O=6YD
M('1H97)E+@H*,BX@5'5R8F$L('1H92!(;W)D92!C;VYT86-T<R!M86YA9V5R
M+@H*("`@5'5R8F$@:7,@=&AE($AO<F1E(&-O;G1A8W0@;6%N86=E;65N="!A
M<'!L:6-A=&EO;BP@9&5S:6=N960@=&\@8F4*("`@:6YT96=R871E9"!W:71H
M(&]T:&5R($AO<F1E(&%P<&QI8V%T:6]N<R!T;R!P<F]V:61E(&$@=6YI9FEE
M9"!I;G1E<F9A8V4@=&\*("`@8V]N=&%C="!M86YA9V5M96YT('1H<F]U9VAO
M=70@=&AE($AO<F1E('-U:71E+@H*("`@5'5R8F$@:7,@879A:6QA8FQE(&9R
M;VTZ"@H@("`@("!H='1P.B\O=W=W+FAO<F1E+F]R9R]T=7)B82\*"B`@("`@
M(&9T<#HO+V9T<"YH;W)D92YO<F<O<'5B+W1U<F)A+PH*("`@5'5R8F$@<')O
M=FED97,@82!L;V-A;"!A9&1R97-S(&)O;VL@86YD(&%N($Q$05`@9&ER96-T
M;W)Y('-E87)C:"!F=6YC=&EO;@H@("!T;R!)35`N"@H@("!9;W4@;75S="!U
M<V4@=&AE(#(N>"!B<F%N8V@@;V8@5'5R8F$@=VET:"!)35`@-"YX+@H*,RX@
M26YG;RP@=&AE($AO<F1E(&UA:6P@9FEL=&5R<R!M86YA9V5R+@H*("`@26YG
M;R!I<R!T:&4@2&]R9&4@;6%I;"!F:6QT97)S(&UA;F%G96UE;G0@87!P;&EC
M871I;VXL(&1E<VEG;F5D('1O(&)E"B`@(&EN=&5G<F%T960@=VET:"!O=&AE
M<B!(;W)D92!A<'!L:6-A=&EO;G,@=&\@<')O=FED92!A('5N:69I960@:6YT
M97)F86-E('1O"B`@(&9I;'1E<B!M86YA9V5M96YT('1H<F]U9VAO=70@=&AE
M($AO<F1E('-U:71E+@H*("`@26YG;R!I<R!A=F%I;&%B;&4@9G)O;3H*"B`@
M("`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VEN9V\O"@H@("`@("!F='`Z+R]F
M='`N:&]R9&4N;W)G+W!U8B]I;F=O+PH*("`@26YG;R!P<F]V:61E<R!T:&4@
M;6%I;"!F:6QT97)I;F<@:6YT97)F86-E<R!T;R!)35`@+2!T:&5R92!I<R!N
M;R!B=6EL="UI;@H@("!F:6QT97)I;F<@:6X@24U0+@H*("`@66]U(&UU<W0@
M=7-E('1H92`Q+G@@8G)A;F-H(&]F($EN9V\@=VET:"!)35`@-"YX+@H*("`@
M5&\@=7-E($E-05`@8VQI96YT+7-I9&4@9FEL=&5R:6YG("AI+F4N('1H92!F
M:6QT97)I;F<@<')O=FED960@8GD@24U0(#,N>"DL"B`@(&EN9V\@<VAO=6QD
M('5S92!T:&4@8&!N=6QL8&`@9')I=F5R(&%N9"!T:&4@8&!I;6%P8&`@<V-R
M:7!T('-E='1I;F=S("AS970*("`@:6X@8&!I;F=O+V-O;F9I9R]B86-K96YD
M<RYP:'!@8"DN"@HT+B!.86<L('1H92!(;W)D92!T87-K<R!M86YA9V5R+@H*
M("`@3F%G(&ES('1H92!(;W)D92!T87-K<R!M86YA9V5M96YT(&%P<&QI8V%T
M:6]N+"!D97-I9VYE9"!T;R!B92!I;G1E9W)A=&5D"B`@('=I=&@@;W1H97(@
M2&]R9&4@87!P;&EC871I;VYS('1O('!R;W9I9&4@82!U;FEF:65D(&EN=&5R
M9F%C92!T;R!T87-K"B`@(&UA;F%G96UE;G0@=&AR;W5G:&]U="!T:&4@2&]R
M9&4@<W5I=&4N"@H@("!.86<@:7,@879A:6QA8FQE(&9R;VTZ"@H@("`@("!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]N86<O"@H@("`@("!F='`Z+R]F='`N:&]R
M9&4N;W)G+W!U8B]N86<O"@H@("!)9B!N86<@:7,@879A:6QA8FQE(&]N('EO
M=7(@<WES=&5M+"!U<V5R<R!C86X@96%S:6QY(&-R96%T92!N97<@=&%S:W,@
M9G)O;0H@("!I;F1I=FED=6%L(&5M86EL(&UE<W-A9V5S+@H*("`@66]U(&UU
M<W0@=7-E('1H92`R+G@@8G)A;F-H(&]F($YA9R!W:71H($E-4"`T+G@N"@HU
M+B!';VQL96TL('1H92!(;W)D92!F:6QE(&UA;F%G97(N"@H@("!';VQL96T@
M:7,@=&AE($AO<F1E(&9I;&4@;6%N86=E;65N="!A<'!L:6-A=&EO;BP@9&5S
M:6=N960@=&\@8F4*("`@:6YT96=R871E9"!W:71H(&]T:&5R($AO<F1E(&%P
M<&QI8V%T:6]N<R!T;R!P<F]V:61E(&$@=6YI9FEE9"!I;G1E<F9A8V4@=&\*
M("`@86-C97-S(%9&4R!F:6QE<WES=&5M<R!T:')O=6=H;W5T('1H92!(;W)D
M92!S=6ET92X*"B`@($=O;&QE;2!I<R!A=F%I;&%B;&4@9G)O;3H*"B`@("`@
M(&AT='`Z+R]W=W<N:&]R9&4N;W)G+V=O;&QE;2\*"B`@("`@(&9T<#HO+V9T
M<"YH;W)D92YO<F<O<'5B+V=O;&QE;2\*"B`@($=O;&QE;2!A;&QO=W,@82!U
M<V5R('1O(&%T=&%C:"!F:6QE<R!F<F]M('9A<FEO=7,@5D93(&9I;&5S>7-T
M96US('1O"B`@(&]U=&=O:6YG(&UE<W-A9V5S(&EN($E-4"X*"B`@(%EO=2!M
M=7-T('5S92!T:&4@,2YX(&)R86YC:"!O9B!';VQL96T@=VET:"!)35`@-"YX
M+@H*-BX@27-P96QL+"!O<B!A(&1R;W`M:6X@<F5P;&%C96UE;G0N"@H@("!)
M<W!E;&PL(&]R(&ET<R!E;FAA;F-E9"!C;W5S:6X@87-P96QL+"!I<R!U<V5D
M(&%S($E-4"=S('-P96QL+6-H96-K:6YG"B`@(&5N9VEN92X@(%EO=2!M=7-T
M(&EN<W1A;&P@;VYE(&]F('1H97-E+"!O<B!A('-I;6EL87(@<')O9W)A;2!W
M:71H(&%N"B`@(&ES<&5L;"UC;VUP871I8FQE(&EN=&5R9F%C92P@=&\@=7-E
M($E-4"=S('-P96QL+6-H96-K(&9E871U<F4N"@H@("!4:&4@9&EF9F5R96YC
M97,@8F5T=V5E;B!I<W!E;&P@86YD(&%S<&5L;"!A<F4@<W5B=&QE(&)U="!I
M;7!O<G1A;G0N("!4:&4*("`@875T:&]R(&]F(&ES<&5L;"!W<FET97,Z"@H@
M("`@("!;07-P96QL)W-=('!R:6UA<GD@861V86YT86=E(&ES('1H870@:70@
M:7,@8F5T=&5R(&%T(&UA:VEN9R!S=6=G97-T:6]N<PH@("`@("!W:&5N(&$@
M=V]R9"!I<R!S97)I;W5S;'D@;6ES<W!E;&QE9"X@($9O<B!E>&%M<&QE+"!W
M:&5N(&=I=F5N(")T<G5B8FQE(BP*("`@("`@:7-P96QL('=I;&P@<W5G9V5S
M="!O;FQY(")R=6)B;&4B+"!W:&5R92!A<W!E;&P@<W5G9V5S=',@(G1R;W5B
M;&4B("AA<PH@("`@("!I=',@9FER<W0@8VAO:6-E*2!A<R!W96QL(&%S(")D
M<FEB8FQE(BP@(G)U8F)L92(L(&%N9"!A(&QO="!O9B!O=&AE<@H@("`@("!W
M;W)D<RX@($ET<R!D:7-A9'9A;G1A9V4@:7,@=&AA="!T:&4@87!P<F]X:6UA
M=&4M;6%T8VAI;F<@86QG;W)I=&AM(&ES"B`@("`@('-P96-I9FEC('1O($5N
M9VQI<V@N"@H@("!!<R!)35`@<W5P<&]R=',@;75L=&EP;&4@;&%N9W5A9V5S
M+"!T:&4@;&%N9W5A9V5S(')E<75I<F5D(&)Y('EO=7(@=7-E<@H@("!B87-E
M('=I;&P@<')O8F%B;'D@<')O=FED92!A;B!I;F-E;G1I=F4@=&\@=7-E(&]N
M92!O<B!T:&4@;W1H97(N("!9;W4@8V%N"B`@(&]B=&%I;B!);G1E<FYA=&EO
M;F%L($ES<&5L;"!F<F]M.@H*("`@("`@:'1T<#HO+V9M9RUW=W<N8W,N=6-L
M82YE9'4O9FUG+6UE;6)E<G,O9V5O9F8O:7-P96QL+FAT;6P*"B`@(&%N9"!A
M<W!E;&P@9G)O;3H*"B`@("`@(&AT='`Z+R]A<W!E;&PN<V]U<F-E9F]R9V4N
M;F5T+PH*("`@87-P96QL('9E<G-I;VX@,"XU,"P@;W(@:&EG:&5R+"!I<R!R
M96-O;6UE;F1E9"X*"@I);G-T86QL:6YG($E-4`H]/3T]/3T]/3T]/3T]/0H*
M24U0(&ES('=R:71T96X@:6X@4$A0+"!A;F0@;75S="!B92!I;G-T86QL960@
M:6X@82!W96(M86-C97-S:6)L92!D:7)E8W1O<GDN"E1H92!P<F5C:7-E(&QO
M8V%T:6]N(&]F('1H:7,@9&ER96-T;W)Y('=I;&P@9&EF9F5R(&9R;VT@<WES
M=&5M('1O('-Y<W1E;2X*0V]N=F5N=&EO;F%L;'DL($E-4"!I<R!I;G-T86QL
M960@9&ER96-T;'D@=6YD97)N96%T:"!(;W)D92!I;B!T:&4@=V5B('-E<G9E
M<B=S"F1O8W5M96YT('1R964N"@I3:6YC92!)35`@:7,@=W)I='1E;B!I;B!0
M2%`L('1H97)E(&ES(&YO(&-O;7!I;&%T:6]N(&YE8V5S<V%R>3L@<VEM<&QY
M(&5X<&%N9`IT:&4@9&ES=')I8G5T:6]N('=H97)E('EO=2!W86YT(&ET('1O
M(')E<VED92!A;F0@<F5N86UE('1H92!R;V]T(&1I<F5C=&]R>2!O9@IT:&4@
M9&ES=')I8G5T:6]N('1O('=H871E=F5R('EO=2!W:7-H('1O(&%P<&5A<B!I
M;B!T:&4@55),+B`@1F]R(&5X86UP;&4L('=I=&@*=&AE($%P86-H92!W96(@
M<V5R=F5R)W,@9&5F875L="!D;V-U;65N="!R;V]T(&]F(&!@+W5S<B]L;V-A
M;"]A<&%C:&4O:'1D;V-S8&`L"GEO=2!W;W5L9"!T>7!E.CH*"B`@(&-D("]U
M<W(O;&]C86PO87!A8VAE+VAT9&]C<R]H;W)D90H@("!T87(@>GAV9B`O<&%T
M:"]T;R]I;7`M>"YY+GHN=&%R+F=Z"B`@(&UV(&EM<"UX+GDN>B!I;7`*"F%N
M9"!W;W5L9"!T:&5N(&9I;F0@24U0(&%T('1H92!54DPZ.@H*("`@:'1T<#HO
M+WEO=7(M<V5R=F5R+VAO<F1E+VEM<"\*"@I#;VYF:6=U<FEN9R!)35`*/3T]
M/3T]/3T]/3T]/3T]"@HQ+B!#;VYF:6=U<FEN9R!(;W)D92!F;W(@24U0"@H@
M("!A+B!296=I<W1E<B!T:&4@87!P;&EC871I;VX*"B`@("`@($EN(&!@:&]R
M9&4O8V]N9FEG+W)E9VES=')Y+G!H<&!@+"!F:6YD('1H92!@8&%P<&QI8V%T
M:6]N<ULG:6UP)UU@8`H@("`@("!S=&%N>F$N("!4:&4@9&5F875L="!S971T
M:6YG<R!H97)E('-H;W5L9"!B92!O:V%Y+"!B=70@>6]U(&-A;B!C:&%N9V4*
M("`@("`@=&AE;2!I9B!D97-I<F5D+B`@268@>6]U(&AA=F4@8VAA;F=E9"!T
M:&4@;&]C871I;VX@;V8@24U0(')E;&%T:79E('1O"B`@("`@($AO<F1E+"!E
M:71H97(@:6X@=&AE(%523"P@:6X@=&AE(&9I;&5S>7-T96T@;W(@8F]T:"P@
M>6]U(&UU<W0@=7!D871E('1H90H@("`@("!@8&9I;&5R;V]T8&`@86YD(&!@
M=V5B<F]O=&!@('-E='1I;F=S('1O('1H96ER(&-O<G)E8W0@=F%L=65S+@H*
M("`@8BX@16YA8FQE($E-4"!A=71H96YT:6-A=&EO;B!;3U!424].04Q="@H@
M("`@("!)9B!Y;W4@=V]U;&0@<')E9F5R('1H870@>6]U<B!U<V5R<R!A=71H
M96YT:6-A=&4@9&ER96-T;'D@=VET:"!)35`L"B`@("`@('=I=&AO=70@:&%V
M:6YG('1O(&%U=&AE;G1I8V%T92!T:')O=6=H($AO<F1E(&9I<G-T+"!L;V%D
M('1H90H@("`@("!@8$%D;6EN:7-T<F%T:6]N+T-O;F9I9W5R871I;VXO075T
M:&5N=&EC871I;VY@8"!P86=E(&%N9"!F<F]M('1H92!@8%=H870*("`@("`@
M8F%C:V5N9"!S:&]U;&0@=V4@=7-E(&9O<B!A=71H96YT:6-A=&EN9R!U<V5R
M<R!T;R!(;W)D96!@('!U;&QD;W=N(&UE;G4*("`@("`@<V5L96-T(&!@3&5T
M(&$@2&]R9&4@87!P;&EC871I;VX@:&%N9&QE(&%U=&AE;G1I8V%T:6]N8&`N
M("`H4&QE87-E('-E90H@("`@("!T:&4@<V5C;VYD(&YO=&4@8F5L;W<N*2!3
M96QE8W0@8&!I;7!@8"!F<F]M('1H92!@8%1H92!A<'!L:6-A=&EO;B!W:&EC
M:`H@("`@("!I<R!P<F]V:61I;F<@875T:&5N=&EC871I;VY@8"!P=6QL9&]W
M;B!M96YU+@H*("`@("`@+BX@3F]T93HZ("HJ66]U('=I;&P@:&%V92!T;R!L
M;V<@:6X@='=I8V4@:68@>6]U(&1O;B=T(&1O('1H:7,J*B`M+2!/;F-E"B`@
M("`@("`@("`@("`@("!T;R!(;W)D92!A;F0@82!S96-O;F0@=&EM92!T;R!)
M35`N"@H@("`@("`N+B!.;W1E.CH@268@=&AI<R!I<R!A(&YE=R!I;G-T86QL
M+"!Y;W4@=VEL;"!N;W0@8F4@86)L92!T;R!C;VYF:6=U<F4*("`@("`@("`@
M("`@("`@($E-4"!U<VEN9R!T:&4@2&]R9&4@061M:6YI<W1R871I;VXO0V]N
M9FEG=7)A=&EO;B!P86=E(&EF('EO=0H@("`@("`@("`@("`@("`@9FER<W0@
M96YA8FQE9"!)35`@875T:&5N=&EC871I;VX@9F]R($AO<F1E+B`@66]U(&UU
M<W0@<V5T"B`@("`@("`@("`@("`@("!(;W)D92!T;R!U<V4@86YO=&AE<B!A
M=71H96YT:6-A=&EO;B!M971H;V0@*')E9F5R('1O('1H90H@("`@("`@("`@
M("`@("`@8&AO<F1E+V1O8W,O24Y35$%,3&!?(&9I;&4I+"!C;VYF:6=U<F4@
M24U0+"!T:&5N(')E<V5T($AO<F1E"B`@("`@("`@("`@("`@("!T;R!U<V4@
M24U0(&%U=&AE;G1I8V%T:6]N+B`@3VYE('=A>2!T;R!R97-E="!(;W)D92!I
M;B!O<F1E<B!T;PH@("`@("`@("`@("`@("`@<F5A8V@@=&AE($%D;6EN:7-T
M<F%T:6]N('!A9V4@:7,@=&\@<F5P;&%C92!T:&4@2&]R9&4*("`@("`@("`@
M("`@("`@(&-O;F9I9W5R871I;VX@9FEL92!@8&-O;F8N<&AP8&`@=VET:"!T
M:&4@;W)I9VEN86P@:6X*("`@("`@("`@("`@("`@(&!@:&]R9&4O8V]N9FEG
M+V-O;F8N<&AP+F1I<W1@8"X@(%EO=2!S:&]U;&0@;V8@8V]U<G-E(&)A8VL@
M=7`*("`@("`@("`@("`@("`@('EO=7(@8W5R<F5N="!S971T:6YG<R!S:6YC
M92!T:&5Y('=I;&P@;W1H97)W:7-E(&)E('!E<FUA;F5N=&QY"B`@("`@("`@
M("`@("`@("!L;W-T+@H*,BX@0V]N9FEG=7)I;F<@24U0"@H@("!4;R!C;VYF
M:6=U<F4@24U0+"!C:&%N9V4@=&\@=&AE(&!@:6UP+V-O;F9I9R]@8"!D:7)E
M8W1O<GD@;V8@=&AE(&EN<W1A;&QE9`H@("!D:7-T<FEB=71I;VXL(&%N9"!M
M86ME(&-O<&EE<R!O9B!A;&P@;V8@=&AE(&-O;F9I9W5R871I;VX@8&!D:7-T
M8&`@9FEL97,*("`@=VET:&]U="!T:&4@8&!D:7-T8&`@<W5F9FEX.CH*"B`@
M("`@(&-D(&-O;F9I9R\*("`@("`@9F]R(&9O;R!I;B`J+F1I<W0[(&1O(&-P
M("1F;V\@8&)A<V5N86UE("1F;V\@+F1I<W1@.R!D;VYE"@H@("!/<B!O;B!7
M:6YD;W=S.CH*"B`@("`@(&-O<'D@*BYD:7-T("HN"@H@("!$;V-U;65N=&%T
M:6]N(&]N('1H92!F;W)M870@86YD('!U<G!O<V4@;V8@=&AO<V4@9FEL97,@
M8V%N(&)E(&9O=6YD(&EN(&5A8V@*("`@9FEL92X@(%EO=2!M87D@961I="!T
M:&5S92!F:6QE<R!I9B!Y;W4@=VES:"!T;R!C=7-T;VUI>F4@24U0)W,@87!P
M96%R86YC90H@("!A;F0@8F5H879I;W(N("!7:71H('1W;R!E>&-E<'1I;VYS
M("A@8'-E<G9E<G,N<&AP8&`L(&%N9`H@("!@8&UI;65?9')I=F5R<RYP:'!@
M8"D@=&AE(&1E9F%U;'1S('=I;&P@8F4@8V]R<F5C="!F;W(@;6]S="!S:71E
M<RX*"B`@(%EO=2!M=7-T(&)E('-U<F4@=&\@;&ES="!Y;W5R($E-05`O4$]0
M,R!S97)V97(@;F%M97,@86YD(&-O;F9I9W5R871I;VX*("`@:6YF;W)M871I
M;VX@:6X@8&!S97)V97)S+G!H<&!@("AU;FQE<W,@>6]U(&1E;6%N9"!T:&%T
M('1H92!U<V5R('-P96-I9GD@:&ES"B`@(&]W;B!A="!L;V=I;BDN"@H@("!9
M;W4@;75S="!L;V=I;B!T;R!(;W)D92!A<R!A($AO<F1E($%D;6EN:7-T<F%T
M;W(@=&\@9FEN:7-H('1H90H@("!C;VYF:6=U<F%T:6]N(&]F($E-4"X@(%5S
M92!T:&4@2&]R9&4@8&!!9&UI;FES=')A=&EO;F!@(&UE;G4@:71E;2!T;R!G
M970@=&\*("`@=&AE(&%D;6EN:7-T<F%T:6]N('!A9V4L(&%N9"!T:&5N(&-L
M:6-K(&]N('1H92!@8$-O;F9I9W5R871I;VY@8"!I8V]N('1O"B`@(&=E="!T
M:&4@8V]N9FEG=7)A=&EO;B!P86=E+B`@4V5L96-T(&!@36%I;&!@(&9R;VT@
M=&AE('-E;&5C=&EO;B!L:7-T(&]F"B`@(&%P<&QI8V%T:6]N<RX@($9I;&P@
M:6X@;W(@8VAA;F=E(&%N>2!C;VYF:6=U<F%T:6]N('9A;'5E<R!A<R!N965D
M960N("!7:&5N"B`@(&1O;F4@8VQI8VL@;VX@8&!'96YE<F%T92!-86EL($-O
M;F9I9W5R871I;VY@8"!T;R!G96YE<F%T92!T:&4@8&!C;VYF+G!H<&!@"B`@
M(&9I;&4N("!)9B!Y;W5R('=E8B!S97)V97(@9&]E<VXG="!H879E('=R:71E
M('!E<FUI<W-I;VYS('1O('1H92!)35`*("`@8V]N9FEG=7)A=&EO;B!D:7)E
M8W1O<GD@;W(@9FEL92P@:70@=VEL;"!N;W0@8F4@86)L92!T;R!W<FET92!T
M:&4@9FEL92X@($EN"B`@('1H:7,@8V%S92P@9V\@8F%C:R!T;R!@8$-O;F9I
M9W5R871I;VY@8"!A;F0@8VAO;W-E(&]N92!O9B!T:&4@;W1H97(@;65T:&]D
M<PH@("!T;R!C<F5A=&4@=&AE(&-O;F9I9W5R871I;VX@9FEL92!@8&EM<"]C
M;VYF:6<O8V]N9BYP:'!@8"X*"B`@($YO=&4@9F]R(&EN=&5R;F%T:6]N86P@
M=7-E<G,Z($E-4"!U<V5S($=.52!G971T97AT('1O('!R;W9I9&4@;&]C86P*
M("`@=')A;G-L871I;VYS(&]F('1E>'0@9&ES<&QA>65D(&)Y(&%P<&QI8V%T
M:6]N<SL@=&AE('1R86YS;&%T:6]N<R!A<F4@9F]U;F0*("`@:6X@=&AE(&!@
M<&\O8&`@9&ER96-T;W)Y+B`@268@82!T<F%N<VQA=&EO;B!I<R!N;W0@>65T
M(&%V86EL86)L92!F;W(@>6]U<@H@("!L;V-A;&4@*&%N9"!Y;W4@=VES:"!T
M;R!C<F5A=&4@;VYE*2P@<V5E('1H92!@8&AO<F1E+W!O+U)%041-16!@(&9I
M;&4L(&]R"B`@(&EF('EO=2=R92!H879I;F<@=')O=6)L92!U<VEN9R!A('!R
M;W9I9&5D('1R86YS;&%T:6]N+"!P;&5A<V4@<V5E('1H90H@("!@:&]R9&4O
M9&]C<R]44D%.4TQ!5$E/3E-@7R!F:6QE(&9O<B!I;G-T<G5C=&EO;G,N"@H@
M("!)35`@0V]N9FEG=7)A=&EO;B!0;VEN=&5R<PH*("`@*B!)9B!Y;W4@=V]U
M;&0@;&EK92!)35`@=&\@<V-A;B!A;&P@=&5X="!M97-S86=E<R!F;W(@555E
M;F-O9&5D(&1A=&$L('EO=0H@("`@(&UU<W0@;6%K92!T:&ES(&-H86YG92!I
M;B!@8&EM<"]C;VYF:6<O;6EM95]D<FEV97)S+G!H<&!@.CH*"B`@("`@)&UI
M;65?9')I=F5R<ULG:6UP)UU;)W!L86EN)UU;)W5U96YC;V1E)UT@/2!T<G5E
M.PH*("`@("!.;W1E('1H870@=&AI<R!I<R!A('!E<F9O<FUA;F-E(&AI="!S
M:6YC92`J979E<GDJ('1E>'0@8F]D>2!M=7-T(&)E"B`@("`@<V-A;FYE9"!I
M;B!I=',@96YT<FEE='D@=&\@;&]O:R!F;W(@=75E;F-O9&5D(&1A=&$N("!4
M:&5R969O<F4L('1H:7,*("`@("!F96%T=7)E(&ES(&1I<V%B;&5D(&)Y(&1E
M9F%U;'0N"@H@("`J($)Y(&1E9F%U;'0L($E-4"!I<R!C;VYF:6=U<F5D('1O
M($Y/5"!D:7-P;&%Y('1E>'0O:'1M;"!M97-S86=E('!A<G1S"B`@("`@:6YL
M:6YE+B`@5&AI<R!I<R!D;VYE(&9O<B!V87)I;W5S('-E8W5R:71Y(')E87-O
M;G,N("!)9B!Y;W4@=V]U;&0@;&EK90H@("`@('1O('-E92!T97AT+VAT;6P@
M<&%R=',@:6YL:6YE+"!Y;W4@;75S="!M86ME('1H:7,@8VAA;F=E(&EN"B`@
M("`@8&!I;7`O8V]N9FEG+VUI;65?9')I=F5R<RYP:'!@8#HZ"@H@("`@("1M
M:6UE7V1R:79E<G-;)VEM<"==6R=H=&UL)UU;)VEN;&EN92==(#T@=')U93L*
M"C,N(%-E8W5R:6YG($E-4`H*("`@0F5F;W)E('EO=2!C86X@<V5C=7)E($E-
M4"P@>6]U(&YE960@82!S96-U<F4@2&]R9&4@:6YS=&%L;&%T:6]N+B`@4&QE
M87-E"B`@(')E860@=&AE(&9I;&4@:6X@8&AO<F1E+V1O8W,O4T5#55))5%E@
M7R!F;W(@2&]R9&4@<V5C=7)I='D@:6YF;W)M871I;VX*("`@8F5F;W)E('!R
M;V-E961I;F<N"@H@("!4:&5R92!A<F4@='=O(&-H86YN96QS(&)Y('=H:6-H
M+"!U;FQE<W,@<W1E<',@87)E('1A:V5N('1O(&%V;VED(&ET+"!)35`*("`@
M96YC;W5R86=E<R!U<V5R<R!T;R!P87-S('1H96ER($E-05`@86YD(%!/4#,@
M<&%S<W=O<F1S(&%R;W5N9"!T:&4@26YT97)N970*("`@=6YE;F-R>7!T960N
M"@H@("!4:&4@9FER<W0@8VAA;FYE;"!I<R!B971W965N('1H96ER(&)R;W=S
M97(@86YD('1H92!796(@<V5R=F5R+B`@5V4@<W1R;VYG;'D*("`@<F5C;VUM
M96YD('5S:6YG(&%N(%-33"UC87!A8FQE(%=E8B!S97)V97(@=&\@9VEV92!U
M<V5R<R!T:&4@;W!T:6]N(&]F"B`@(&5N8W)Y<'1I;F<@8V]M;75N:6-A=&EO
M;G,@8F5T=V5E;B!T:&5I<B!B<F]W<V5R(&%N9"!T:&4@5V5B('-E<G9E<B!O
M;B!W:&EC:`H@("!)35`@:7,@<G5N;FEN9SL@<V]M92!S:71E<R!M87D@=VES
M:"!T;R!D:7-A8FQE(&YO;BU34TP@86-C97-S(&5N=&ER96QY+@H*("`@5&AE
M('-E8V]N9"!C:&%N;F5L(&ES(&)E='=E96X@=&AE(%=E8B!S97)V97(@86YD
M('1H96ER($E-05`@;W(@4$]0,R!S97)V97(N"B`@(%1H92!S:6UP;&5S="!W
M87D@=&\@879O:60@=&AI<R!I<R!T;R!H879E('1H92!M86EL('-E<G9E<B!R
M=6YN:6YG(&]N('1H90H@("!S86UE('-Y<W1E;2!A<R!T:&4@5V5B('-E<G9E
M<BP@86YD(&-O;F9I9W5R:6YG($E-4"!T;R!C;VYN96-T('1O('1H92!)34%0
M"B`@(&]R(%!/4#,@<V5R=F5R(&]N(&!@;&]C86QH;W-T8&`@:6YS=&5A9"!O
M9B!O;B!T:&4@26YT97)N970@:&]S=&YA;64N("!);@H@("!C87-E<R!W:&5R
M92!T:&%T(&ES(&YO="!P;W-S:6)L92P@=V4@<F5C;VUM96YD('5S:6YG($E-
M05`M4U-,(&]R(%!/4#,M4U-,"B`@('1O(&5N<W5R92!T:&%T('5S97)S)R!P
M87-S=V]R9',@<F5M86EN('-A9F4@869T97(@=&AE>2!H879E(&5N=')U<W1E
M9"!T:&5M"B`@('1O($E-4"X*"B`@($]T:&5R('-E8W5R:71Y('-T97!S('EO
M=2!C86X@=&%K92!T;R!I;F-R96%S92!S96-U<FET>2!I;F-L=61E.@H*("`@
M*B!5<V4@<V5S<VEO;B!C;V]K:65S(&EN<W1E860@;W(@55),(&)A<V5D('-E
M<W-I;VYS+@H@("`J(%-E="!Y;W5R('!H<"!@8'-E<W-I;VXN96YT<F]P>5]L
M96YG=&A@8"!T;R!A(&QA<F=E<B!V86QU92`H92YG+B`Q-BD@86YD"B`@("`@
M8&!S97-S:6]N+F5N=')O<'E?9FEL96!@('1O(&$@<F%N9&]M('-O=7)C92`H
M92YG+B!@8"]D978O=7)A;F1O;6!@*0H@("`J($5N86)L92!A;F0@=7-E('1H
M92!P:'`@;7EC<GEP="!E>'1E;G-I;VXN"B`@("H@268@>6]U<B!D871A8F%S
M92P@;6%I;"!S97)V97(L(&%N9"!W96(@<V5R=F5R(&%R92!O;B!T:&4@<V%M
M92!H;W-T"B`@("`@;6%C:&EN92P@=&AE;CH*"B`@("`@*B!U<V4@=6YI>"!S
M;V-K970@9&%T86)A<V4@86-C97-S(&%N9"!D:7-A8FQE('1C<"!D871A8F%S
M92!A8V-E<W,N"B`@("`@*B!U<V4@8&!L;V-A;&AO<W1@8"!F;W(@86QL(%1#
M4"])4"!C;VYN96-T:6]N<R!T;R!A=F]I9"!T:&4@;F5T=V]R:RX*("`@("`J
M('5S92!T:&4@8V]M;6%N9"UL:6YE('-E;F1M86EL(&9O<B!S96YD:6YG(&UA
M:6P@:68@<&]S<VEB;&4N"@HT+B!497-T:6YG($E-4`H*("`@3VYC92!Y;W4@
M:&%V92!C;VYF:6=U<F5D($E-4"P@8G)I;F<@=7`@=&AE(&EN8VQU9&5D('1E
M<W0@<&%G92!I;B!Y;W5R(%=E8@H@("!B<F]W<V5R('1O(&5N<W5R92!T:&%T
M(&%L;"!N96-E<W-A<GD@<')E<F5Q=6ES:71E<R!H879E(&)E96X@;65T+B`@
M4V5E('1H90H@("!@:&]R9&4O9&]C<R])3E-404Q,8%\@9&]C=6UE;G0@9F]R
M(&9U<G1H97(@9&5T86EL<R!O;B!(;W)D92!T97-T"B`@('-C<FEP=',N($EF
M('EO=2!I;G-T86QL960@24U0(&%S(&1E<V-R:6)E9"!A8F]V92P@=&AE(%52
M3"!T;R!T:&4@=&5S="!P86=E"B`@('=O=6QD(&)E.CH*"B`@("`@(&AT='`Z
M+R]Y;W5R+7-E<G9E<B]H;W)D92]I;7`O=&5S="YP:'`*"B`@(%1H92!T97-T
M('-C<FEP="!W:6QL(&%L<V\@86QL;W<@>6]U('1O('1E<W0@>6]U<B!C;VYN
M96-T:6]N('1O('1H92!M86EL"B`@('-E<G9E<B!A;F0@<')O=FED92!S;VUE
M(&%U=&\M9&5T96-T960@8V]N9FEG=7)A=&EO;B!P87)A;65T97)S('1H870@
M8V%N"B`@('1H96X@8F4@:6YS97)T960@:6YT;R!T:&4@<V5R=F5R(&-O;F9I
M9W5R871I;VX@;&]C871E9"!I;@H@("!@8&EM<"]C;VYF:6<O<V5R=F5R<RYP
M:'!@8"X*"B`@($YE>'0L('5S92!)35`@=&\@;&]G:6X@=&\@82!K;F]W;B!W
M;W)K:6YG($E-05`@;W(@4$]0,R!S97)V97(N("!497-T(&%T"B`@(&QE87-T
M('1H92!F;VQL;W=I;F<Z"@H@("`M(%-E;F1I;F<@;6%I;"`H=FEA('1H92!@
M8$-O;7!O<V5@8"!I=&5M(&EN('1H92!M96YU(&)A<BDN"B`@("T@4V5T=&EN
M9R!P<F5F97)E;F-E<R`H8VAE8VL@=&\@<V5E(&EF('1H97D@<W5R=FEV92!A
M9G1E<B!L;V=G:6YG(&]U="!A;F0*("`@("!B86-K(&EN+"!I9B!Y;W4@87)E
M('5S:6YG(&%N(%-13"!O<B!,1$%0('!R969E<F5N8V5S('-Y<W1E;2DN"B`@
M("T@4F5A9&EN9R!M86EL+@H@("`M($1E;&5T:6YG(&UA:6PN"B`@("T@1FQA
M9V=I;F<@;6%I;"`H:68@=7-I;F<@24U!4"DN"B`@("T@0VAA;F=I;F<@9F]L
M9&5R<R`H:68@=7-I;F<@24U!4"DN"@HU+B!4=6YI;F<@24U0("A097)F;W)M
M86YC92D*"B`@(%-E92!@:&]R9&4O9&]C<R]015)&3U)-04Y#16!?+@H*"D]B
M=&%I;FEN9R!3=7!P;W)T"CT]/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W4@96YC
M;W5N=&5R('!R;V)L96US('=I=&@@24U0+"!H96QP(&ES(&%V86EL86)L92$*
M"E1H92!(;W)D92!&<F5Q=65N=&QY($%S:V5D(%%U97-T:6]N<R!,:7-T("A&
M05$I+"!A=F%I;&%B;&4@;VX@=&AE(%=E8B!A=`H*("!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]F87$O"@I4:&4@2&]R9&4@4')O:F5C="!R=6YS(&$@;G5M8F5R
M(&]F(&UA:6QI;F<@;&ES=',L(&9O<B!I;F1I=FED=6%L(&%P<&QI8V%T:6]N
M<PIA;F0@9F]R(&ES<W5E<R!R96QA=&EN9R!T;R!T:&4@<')O:F5C="!A<R!A
M('=H;VQE+B`@26YF;W)M871I;VXL(&%R8VAI=F5S+"!A;F0*<W5B<V-R:7!T
M:6]N(&EN9F]R;6%T:6]N(&-A;B!B92!F;W5N9"!A=`H*("!H='1P.B\O=W=W
M+FAO<F1E+F]R9R]M86EL+PH*3&%S=&QY+"!(;W)D92!D979E;&]P97)S+"!C
M;VYT<FEB=71O<G,@86YD('5S97)S(&%L<V\@;6%K92!O8V-A<VEO;F%L"F%P
M<&5A<F%N8V5S(&]N($E20RP@;VX@=&AE(&-H86YN96P@(VAO<F1E(&]N('1H
M92!&<F5E;F]D92!.971W;W)K"BAI<F,N9G)E96YO9&4N;F5T*2X*"E!L96%S
M92!K965P(&EN(&UI;F0@=&AA="!)35`@:7,@9G)E92!S;V9T=V%R92!W<FET
M=&5N(&)Y('9O;'5N=&5E<G,N("!&;W(*:6YF;W)M871I;VX@;VX@<F5A<V]N
M86)L92!S=7!P;W)T(&5X<&5C=&%T:6]N<RP@<&QE87-E(')E860*"B`@:'1T
M<#HO+W=W=RYH;W)D92YO<F<O<W5P<&]R="YP:'`*"E1H86YK<R!F;W(@=7-I
M;F<@24U0(0H*5&AE($E-4"!T96%M"@H*+BX@7U)%041-13H@/V8]4D5!1$U%
M+FAT;6P*+BX@7V!H;W)D92]D;V-S+TA!0TM)3D=@.B`N+B\N+B]H;W)D92]D
M;V-S+S]F/4A!0TM)3D<N:'1M;`HN+B!?8&AO<F1E+V1O8W,O24Y35$%,3&`Z
M("XN+RXN+VAO<F1E+V1O8W,O/V8]24Y35$%,3"YH=&UL"BXN(%]@:&]R9&4O
M9&]C<R]015)&3U)-04Y#16`Z("XN+RXN+VAO<F1E+V1O8W,O/V8]4$521D]2
M34%.0T4N:'1M;`HN+B!?8&AO<F1E+V1O8W,O4T5#55))5%E@.B`N+B\N+B]H
M;W)D92]D;V-S+S]F/5-%0U522519+FAT;6P*+BX@7V!H;W)D92]D;V-S+U12
M04Y33$%424].4V`Z("XN+RXN+VAO<F1E+V1O8W,O/V8]5%)!3E-,051)3TY3
M+FAT;6P*`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP
M+V1O8W,O4D5,14%315].3U1%4P``````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-3,Q,@`Q,#0Q-S,V,C<W,``P,C`Q,3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%)E;&5A<V4@9F]C=7,N(%!O<W-I8FQE('9A;'5E<SH*("H@,"`M($XO00H@
M*B`Q("T@26YI=&EA;"!F<F5S:&UE870@86YN;W5N8V5M96YT"B`J(#(@+2!$
M;V-U;65N=&%T:6]N"B`J(#,@+2!#;V1E(&-L96%N=7`*("H@-"`M($UI;F]R
M(&9E871U<F4@96YH86YC96UE;G1S"B`J(#4@+2!-86IO<B!F96%T=7)E(&5N
M:&%N8V5M96YT<PH@*B`V("T@36EN;W(@8G5G9FEX97,*("H@-R`M($UA:F]R
M(&)U9V9I>&5S"B`J(#@@+2!-:6YO<B!S96-U<FET>2!F:7AE<PH@*B`Y("T@
M36%J;W(@<V5C=7)I='D@9FEX97,*("HO"B1T:&ES+3YN;W1E<ULG9FTG75LG
M9F]C=7,G72`](#4["@HO*B!-86EL:6YG(&QI<W0@<F5L96%S92!N;W1E<RX@
M*B\*)'1H:7,M/FYO=&5S6R=M;"==6R=C:&%N9V5S)UT@/2`\/#Q-3`I4:&4@
M2&]R9&4@5&5A;2!I<R!P;&5A<V5D('1O(&%N;F]U;F-E('1H92!F:6YA;"!R
M96QE87-E(&]F('1H92!)35`@5V5B;6%I;`I#;&EE;G0@=F5R<VEO;B!(,R`H
M-"XQ*2X*"DE-4"P@=&AE($EN=&5R;F5T($UE<W-A9VEN9R!0<F]G<F%M+"!I
M<R!O;F4@;V8@=&AE(&UO<W0@<&]P=6QA<B!W96)M86EL"F%P<&QI8V%T:6]N
M<R!A=F%I;&%B;&4N("!)="!A;&QO=W,@=6YI=F5R<V%L+"!W96(M8F%S960@
M86-C97-S('1O($E-05`@86YD"E!/4#,@;6%I;"!S97)V97)S(&%N9"!P<F]V
M:61E<R!A(&9U;&P@<F%N9V4@;V8@9F5A='5R97,@;F]R;6%L;'D@9F]U;F0@
M;VYL>2!I;@ID97-K=&]P(&5M86EL(&-L:65N=',N"@I-86IO<B!C:&%N9V5S
M(&-O;7!A<F5D('1O('1H92!)35`@2#,@*#0N,2U20S,I('9E<G-I;VX@87)E
M.@H@("`@*B!3;6%L;"!B=6=F:7AE<RX*"DUA:F]R(&-H86YG97,@8V]M<&%R
M960@=&\@=&AE($E-4"!(,R`H-"XP*2!V97)S:6]N<R!A<F4Z"B`@("`J(%5S
M97(@8VAA;F=E<SH*("`@("`@+2!6:7)T=6%L($EN8F]X(&%N9"!6:7)T=6%L
M(%1R87-H(&9O;&1E<BX*("`@("`@+2`B16UP='D@4W!A;2(@;65N=2!I=&5M
M+@H@("`@("`M(%-T871I;VYE<GD@86YD(&9O<FT@<F5S<&]N<V5S+@H@("`@
M("`M($YO="!N96-E<W-A<GD@=&\@8VQI8VL@;VX@(D%T=&%C:"(@8G5T=&]N
M('=H96X@871T86-H:6YG(&9I;&5S+@H@("`@("`M(%!L87D@<V]U;F0@;VX@
M;F5W(&UA:6PN"B`@("`@("T@375L=&EP;&4@;65S<V%G92!V:65W+@H@("`@
M("`M($%B:6QI='D@=&\@8W)E871E(&YO=&5S(&9R;VT@96UA:6P@;65S<V%G
M97,N"B`@("`@("T@26UP<F]V960@;65S<V%G92!P<F5V:65W<RX*("`@("`@
M+2!);7!O<G0@;V8@<&AO=&\@871T86-H;65N=',@:6YT;R!A(&=A;&QE<GD@
M87!P;&EC871I;VXN"B`@("`@("T@4V5N9"!N;W1I9FEC871I;VX@=VAE;B!L
M:6YK960@871T86-H;65N=',@87)E(&1O=VYL;V%D960N"B`@("`@("T@1W)A
M<&AI8V%L(')E<')E<V5N=&%T:6]N(&]F('1H<F5A9"!O;B!T:')E860@=FEE
M=R!S8W)E96XN"B`@("`@("T@3&5S<R!I;G1R=7-I=F4@;F]T:69I8V%T:6]N
M<R!W:&5N(&5X<&%N9&EN9R!A9&1R97-S97,N"B`@("`@("T@16YC<GEP="!0
M1U`@;65S<V%G97,@9F]R(&%L;"!R96-I<&EE;G1S(&EN(&]N92!M97-S86=E
M+@H@("`@("`M($%L=V%Y<R!S96YD(&YE=R!M97-S86=E<R!I;B`B9FQO=V5D
M(B!F;W)M870N"B`@("`@("T@061D960@2&5B<F5W(&%N9"!+:&UE<B!T<F%N
M<VQA=&EO;BX*("`@("H@061M:6YI<W1R871O<B!C:&%N9V5S.@H@("`@("`M
M($-O;7!A=&EB;&4@=VET:"!02%`@-2XQ+@H@("`@("`M($%U=&\M9&5T96-T
M:6]N(&]F(&YA;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R
M+@H@("`@("`M(%!E<FUI<W-I;VX@=&\@<F5S=')I8W0@9F]L9&5R(&-R96%T
M:6]N+@H@("`@("`M(%-U<'!O<G0@9F]R(&-H86YG:6YG(%--5%`@<V5R=F5R
M+W!O<G0@;VX@;&]G:6XN"B`@("`@("T@36]R92!F;&5X:6)L92!C=7-T;VT@
M96UA:6P@:&5A9&5R<RX*34P["@HO*B!&<F5S:&UE870@<F5L96%S92!N;W1E
M<RP@;F]T(&UO<F4@=&AA;B`V,#`@8VAA<F%C=&5R<RX@*B\*)'1H:7,M/FYO
M=&5S6R=F;2==6R=C:&%N9V5S)UT@/2`\/#Q&30I6:7)T=6%L($EN8F]X97,L
M(%9I<G1U86P@5')A<V@@9F]L9&5R<RP@86X@(D5M<'1Y(%-P86TB(&UE;G4@
M:71E;2!A;F0@<W1A=&EO;F5R>2!S=7!P;W)T(&AA=F4@8F5E;B!A9&1E9"X@
M071T86-H:6YG(&9I;&5S(&AA<R!B965N('-I;7!L:69I960N($$@<V]U;F0@
M:7,@<&QA>65D(&]N(&YE=R!M86EL+B!!(&UU;'1I<&QE(&UE<W-A9V4@=FEE
M=R!A;F0@8W)E871I;F<@;F]T97,@9G)O;2!E;6%I;',@:&%V92!B965N(&%D
M9&5D+B!-97-S86=E('!R979I97=S(&AA=F4@8F5E;B!I;7!R;W9E9"X@4&AO
M=&\@871T86-H;65N=',@8V%N(&)E(&EM<&]R=&5D(&EN=&\@9V%L;&5R:65S
M+B!.97<@;65S<V%G97,@87)E(&%L=V%Y<R!S96YT(&EN(")F;&]W960B(&9O
M<FUA="X@075T;RUD971E8W1I;VX@;V8@;F%M97-P86-E(&EN9F]R;6%T:6]N
M(&9R;VT@24U!4"!S97)V97)S+"!A('!E<FUI<W-I;VX@=&\@<F5S=')I8W0@
M9F]L9&5R(&-R96%T:6]N+"!A;F0@<W5P<&]R="!F;W(@8VAA;F=I;F<@4TU4
M4"!S97)V97(O<&]R="!O;B!L;V=I;B!H879E(&)E96X@861D960@=&\@=&AE
M(&%D;6EN:7-T<F%T;W(@;W!T:6]N<RX*1DT["@HD=&AI<RT^;F]T97-;)VYA
M;64G72`]("=)35`G.PHD=&AI<RT^;F]T97-;)V9M)UU;)W!R;VIE8W0G72`]
M("=I;7`G.PHD=&AI<RT^;F]T97-;)V9M)UU;)V)R86YC:"==(#T@)TAO<F1E
M(#,G.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O9&]C<R]43T1/````````
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C<T
M`#$P-#$W,S8R-S<P`#`Q-C8S-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*
M($E-4"!$979E;&]P;65N="!43T1/($QI<W0@"CT]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`U+S$Q+S`S
M(#$Q.C(Q.C4P("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XR,BXX
M+C,@)`HZ0V]N=&%C=#H@("`@("`@:6UP0&QI<W1S+FAO<F1E+F]R9PH*26X@
M;F\@<&%R=&EC=6QA<B!O<F1E<CH*"BT@26UP;&5M96YT(&9U;&P@;6%I;&)O
M>"!C86-H:6YG(&EN($E-4%]-86EL8F]X.CHN"@HM($1O;B=T(')E;F1E<B!L
M87)G92!-24U%('!A<G1S+@H*+2!4:&4@9F]L9&5R<R!P86=E('-H;W5L9"!B
M92!R96YD97)E9"!B>2!T:&4@2&]R9&5?5')E93HZ(&AT;6P@<F5N9&5R97(N
M"@HM(%!R:6YT(&%L;"!M97-S86=E<R!I;B!A(&UA:6QB;W@N"@HM($%C8V5S
M<R!R96%D;VYL>2!)34%0(&UA:6QB;WAE<RX*"BT@061D('0M<')O="!L:6ME
M(&9E871U<F5S("AH='1P.B\O9G)E<VAM96%T+FYE="]A<G1I8VQE<R]V:65W
M+S$R,S4L"B`@:'1T<#HO+W=W=RYE<V-A<&4N9&4O=7-E<G,O=&]L;W0O;75T
M="\I(&9O<B!T97AT(&UA<W-A9VEN9RX@1F5A='5R97,@=V4*("!D;VXG="!A
M;')E861Y(&AA=F4@:6YC;'5D93H@4F5M;W9E(&UA:6QI;F<@;&ES="!F;V]T
M97)S.R!3:')I;FL@8FEG"B`@<75O=&%T:6]N<SL@4W%U965Z92!A('-E<75E
M;F-E(&]F(&)L86YK(&QI;F5S('1O(&IU<W0@='=O.R!#:&%N9V4@82!S97)I
M97,*("!O9B!F;W5R(&]R(&UO<F4@<&5R:6]D<R!O<B!E>&-L86UA=&EO;B!P
M;VEN=',@:6YT;R!J=7-T('1H<F5E.R!(:61E(&]V97)L;VYG"B`@<VEG;F%T
M=7)E<RX*"BT@26UP;&5M96YT(&-O;6)I;F%T:6]N<R!O9B!!3D0@86YD($]2
M(')U;&5S(&EN('1H92!)35`@<V5A<F-H('-C<F5E;BX*"BT@06QL;W<@=&AR
M96%D('-O<G0@:6X@<V5A<F-H(')E<W5L=',N"@``````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O9&]C<R]#3U!9
M24Y'````````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#0S,3`U`#$P-#$W,S8R-S<P`#`Q-S$W,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````)"2`@("!'3E4@1T5.15)!3"!054),
M24,@3$E#14Y310H)"2`@("`@("!697)S:6]N(#(L($IU;F4@,3DY,0H*($-O
M<'ER:6=H="`H0RD@,3DX.2P@,3DY,2!&<F5E(%-O9G1W87)E($9O=6YD871I
M;VXL($EN8RX*("`@("`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S
M=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!"B!%=F5R>6]N92!I<R!P97)M:71T
M960@=&\@8V]P>2!A;F0@9&ES=')I8G5T92!V97)B871I;2!C;W!I97,*(&]F
M('1H:7,@;&EC96YS92!D;V-U;65N="P@8G5T(&-H86YG:6YG(&ET(&ES(&YO
M="!A;&QO=V5D+@H*"0D)("`@(%!R96%M8FQE"@H@(%1H92!L:6-E;G-E<R!F
M;W(@;6]S="!S;V9T=V%R92!A<F4@9&5S:6=N960@=&\@=&%K92!A=V%Y('EO
M=7(*9G)E961O;2!T;R!S:&%R92!A;F0@8VAA;F=E(&ET+B`@0GD@8V]N=')A
M<W0L('1H92!'3E4@1V5N97)A;"!0=6)L:6,*3&EC96YS92!I<R!I;G1E;F1E
M9"!T;R!G=6%R86YT964@>6]U<B!F<F5E9&]M('1O('-H87)E(&%N9"!C:&%N
M9V4@9G)E90IS;V9T=V%R92TM=&\@;6%K92!S=7)E('1H92!S;V9T=V%R92!I
M<R!F<F5E(&9O<B!A;&P@:71S('5S97)S+B`@5&AI<PI'96YE<F%L(%!U8FQI
M8R!,:6-E;G-E(&%P<&QI97,@=&\@;6]S="!O9B!T:&4@1G)E92!3;V9T=V%R
M90I&;W5N9&%T:6]N)W,@<V]F='=A<F4@86YD('1O(&%N>2!O=&AE<B!P<F]G
M<F%M('=H;W-E(&%U=&AO<G,@8V]M;6ET('1O"G5S:6YG(&ET+B`@*%-O;64@
M;W1H97(@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N('-O9G1W87)E(&ES(&-O
M=F5R960@8GD*=&AE($=.52!,:6)R87)Y($=E;F5R86P@4'5B;&EC($QI8V5N
M<V4@:6YS=&5A9"XI("!9;W4@8V%N(&%P<&QY(&ET('1O"GEO=7(@<')O9W)A
M;7,L('1O;RX*"B`@5VAE;B!W92!S<&5A:R!O9B!F<F5E('-O9G1W87)E+"!W
M92!A<F4@<F5F97)R:6YG('1O(&9R965D;VTL(&YO=`IP<FEC92X@($]U<B!'
M96YE<F%L(%!U8FQI8R!,:6-E;G-E<R!A<F4@9&5S:6=N960@=&\@;6%K92!S
M=7)E('1H870@>6]U"FAA=F4@=&AE(&9R965D;VT@=&\@9&ES=')I8G5T92!C
M;W!I97,@;V8@9G)E92!S;V9T=V%R92`H86YD(&-H87)G92!F;W(*=&AI<R!S
M97)V:6-E(&EF('EO=2!W:7-H*2P@=&AA="!Y;W4@<F5C96EV92!S;W5R8V4@
M8V]D92!O<B!C86X@9V5T(&ET"FEF('EO=2!W86YT(&ET+"!T:&%T('EO=2!C
M86X@8VAA;F=E('1H92!S;V9T=V%R92!O<B!U<V4@<&EE8V5S(&]F(&ET"FEN
M(&YE=R!F<F5E('!R;V=R86US.R!A;F0@=&AA="!Y;W4@:VYO=R!Y;W4@8V%N
M(&1O('1H97-E('1H:6YG<RX*"B`@5&\@<')O=&5C="!Y;W5R(')I9VAT<RP@
M=V4@;F5E9"!T;R!M86ME(')E<W1R:6-T:6]N<R!T:&%T(&9O<F)I9`IA;GEO
M;F4@=&\@9&5N>2!Y;W4@=&AE<V4@<FEG:'1S(&]R('1O(&%S:R!Y;W4@=&\@
M<W5R<F5N9&5R('1H92!R:6=H=',N"E1H97-E(')E<W1R:6-T:6]N<R!T<F%N
M<VQA=&4@=&\@8V5R=&%I;B!R97-P;VYS:6)I;&ET:65S(&9O<B!Y;W4@:68@
M>6]U"F1I<W1R:6)U=&4@8V]P:65S(&]F('1H92!S;V9T=V%R92P@;W(@:68@
M>6]U(&UO9&EF>2!I="X*"B`@1F]R(&5X86UP;&4L(&EF('EO=2!D:7-T<FEB
M=71E(&-O<&EE<R!O9B!S=6-H(&$@<')O9W)A;2P@=VAE=&AE<@IG<F%T:7,@
M;W(@9F]R(&$@9F5E+"!Y;W4@;75S="!G:79E('1H92!R96-I<&EE;G1S(&%L
M;"!T:&4@<FEG:'1S('1H870*>6]U(&AA=F4N("!9;W4@;75S="!M86ME('-U
M<F4@=&AA="!T:&5Y+"!T;V\L(')E8V5I=F4@;W(@8V%N(&=E="!T:&4*<V]U
M<F-E(&-O9&4N("!!;F0@>6]U(&UU<W0@<VAO=R!T:&5M('1H97-E('1E<FUS
M('-O('1H97D@:VYO=R!T:&5I<@IR:6=H=',N"@H@(%=E('!R;W1E8W0@>6]U
M<B!R:6=H=',@=VET:"!T=V\@<W1E<',Z("@Q*2!C;W!Y<FEG:'0@=&AE('-O
M9G1W87)E+"!A;F0**#(I(&]F9F5R('EO=2!T:&ES(&QI8V5N<V4@=VAI8V@@
M9VEV97,@>6]U(&QE9V%L('!E<FUI<W-I;VX@=&\@8V]P>2P*9&ES=')I8G5T
M92!A;F0O;W(@;6]D:69Y('1H92!S;V9T=V%R92X*"B`@06QS;RP@9F]R(&5A
M8V@@875T:&]R)W,@<')O=&5C=&EO;B!A;F0@;W5R<RP@=V4@=V%N="!T;R!M
M86ME(&-E<G1A:6X*=&AA="!E=F5R>6]N92!U;F1E<G-T86YD<R!T:&%T('1H
M97)E(&ES(&YO('=A<G)A;G1Y(&9O<B!T:&ES(&9R964*<V]F='=A<F4N("!)
M9B!T:&4@<V]F='=A<F4@:7,@;6]D:69I960@8GD@<V]M96]N92!E;'-E(&%N
M9"!P87-S960@;VXL('=E"G=A;G0@:71S(')E8VEP:65N=',@=&\@:VYO=R!T
M:&%T('=H870@=&AE>2!H879E(&ES(&YO="!T:&4@;W)I9VEN86PL('-O"G1H
M870@86YY('!R;V)L96US(&EN=')O9'5C960@8GD@;W1H97)S('=I;&P@;F]T
M(')E9FQE8W0@;VX@=&AE(&]R:6=I;F%L"F%U=&AO<G,G(')E<'5T871I;VYS
M+@H*("!&:6YA;&QY+"!A;GD@9G)E92!P<F]G<F%M(&ES('1H<F5A=&5N960@
M8V]N<W1A;G1L>2!B>2!S;V9T=V%R90IP871E;G1S+B`@5V4@=VES:"!T;R!A
M=F]I9"!T:&4@9&%N9V5R('1H870@<F5D:7-T<FEB=71O<G,@;V8@82!F<F5E
M"G!R;V=R86T@=VEL;"!I;F1I=FED=6%L;'D@;V)T86EN('!A=&5N="!L:6-E
M;G-E<RP@:6X@969F96-T(&UA:VEN9R!T:&4*<')O9W)A;2!P<F]P<FEE=&%R
M>2X@(%1O('!R979E;G0@=&AI<RP@=V4@:&%V92!M861E(&ET(&-L96%R('1H
M870@86YY"G!A=&5N="!M=7-T(&)E(&QI8V5N<V5D(&9O<B!E=F5R>6]N92=S
M(&9R964@=7-E(&]R(&YO="!L:6-E;G-E9"!A="!A;&PN"@H@(%1H92!P<F5C
M:7-E('1E<FUS(&%N9"!C;VYD:71I;VYS(&9O<B!C;W!Y:6YG+"!D:7-T<FEB
M=71I;VX@86YD"FUO9&EF:6-A=&EO;B!F;VQL;W<N"@P*"0D@("`@1TY5($=%
M3D5204P@4%5"3$E#($Q)0T5.4T4*("`@5$5235,@04Y$($-/3D1)5$E/3E,@
M1D]2($-/4%E)3D<L($1)4U1224)55$E/3B!!3D0@34]$249)0T%424]."@H@
M(#`N(%1H:7,@3&EC96YS92!A<'!L:65S('1O(&%N>2!P<F]G<F%M(&]R(&]T
M:&5R('=O<FL@=VAI8V@@8V]N=&%I;G,*82!N;W1I8V4@<&QA8V5D(&)Y('1H
M92!C;W!Y<FEG:'0@:&]L9&5R('-A>6EN9R!I="!M87D@8F4@9&ES=')I8G5T
M960*=6YD97(@=&AE('1E<FUS(&]F('1H:7,@1V5N97)A;"!0=6)L:6,@3&EC
M96YS92X@(%1H92`B4')O9W)A;2(L(&)E;&]W+`IR969E<G,@=&\@86YY('-U
M8V@@<')O9W)A;2!O<B!W;W)K+"!A;F0@82`B=V]R:R!B87-E9"!O;B!T:&4@
M4')O9W)A;2(*;65A;G,@96ET:&5R('1H92!0<F]G<F%M(&]R(&%N>2!D97)I
M=F%T:79E('=O<FL@=6YD97(@8V]P>7)I9VAT(&QA=SH*=&AA="!I<R!T;R!S
M87DL(&$@=V]R:R!C;VYT86EN:6YG('1H92!0<F]G<F%M(&]R(&$@<&]R=&EO
M;B!O9B!I="P*96ET:&5R('9E<F)A=&EM(&]R('=I=&@@;6]D:69I8V%T:6]N
M<R!A;F0O;W(@=')A;G-L871E9"!I;G1O(&%N;W1H97(*;&%N9W5A9V4N("`H
M2&5R96EN869T97(L('1R86YS;&%T:6]N(&ES(&EN8VQU9&5D('=I=&AO=70@
M;&EM:71A=&EO;B!I;@IT:&4@=&5R;2`B;6]D:69I8V%T:6]N(BXI("!%86-H
M(&QI8V5N<V5E(&ES(&%D9')E<W-E9"!A<R`B>6]U(BX*"D%C=&EV:71I97,@
M;W1H97(@=&AA;B!C;W!Y:6YG+"!D:7-T<FEB=71I;VX@86YD(&UO9&EF:6-A
M=&EO;B!A<F4@;F]T"F-O=F5R960@8GD@=&AI<R!,:6-E;G-E.R!T:&5Y(&%R
M92!O=71S:61E(&ET<R!S8V]P92X@(%1H92!A8W0@;V8*<G5N;FEN9R!T:&4@
M4')O9W)A;2!I<R!N;W0@<F5S=')I8W1E9"P@86YD('1H92!O=71P=70@9G)O
M;2!T:&4@4')O9W)A;0II<R!C;W9E<F5D(&]N;'D@:68@:71S(&-O;G1E;G1S
M(&-O;G-T:71U=&4@82!W;W)K(&)A<V5D(&]N('1H90I0<F]G<F%M("AI;F1E
M<&5N9&5N="!O9B!H879I;F<@8F5E;B!M861E(&)Y(')U;FYI;F<@=&AE(%!R
M;V=R86TI+@I7:&5T:&5R('1H870@:7,@=')U92!D97!E;F1S(&]N('=H870@
M=&AE(%!R;V=R86T@9&]E<RX*"B`@,2X@66]U(&UA>2!C;W!Y(&%N9"!D:7-T
M<FEB=71E('9E<F)A=&EM(&-O<&EE<R!O9B!T:&4@4')O9W)A;2=S"G-O=7)C
M92!C;V1E(&%S('EO=2!R96-E:79E(&ET+"!I;B!A;GD@;65D:75M+"!P<F]V
M:61E9"!T:&%T('EO=0IC;VYS<&EC=6]U<VQY(&%N9"!A<'!R;W!R:6%T96QY
M('!U8FQI<V@@;VX@96%C:"!C;W!Y(&%N(&%P<')O<')I871E"F-O<'ER:6=H
M="!N;W1I8V4@86YD(&1I<V-L86EM97(@;V8@=V%R<F%N='D[(&ME97`@:6YT
M86-T(&%L;"!T:&4*;F]T:6-E<R!T:&%T(')E9F5R('1O('1H:7,@3&EC96YS
M92!A;F0@=&\@=&AE(&%B<V5N8V4@;V8@86YY('=A<G)A;G1Y.PIA;F0@9VEV
M92!A;GD@;W1H97(@<F5C:7!I96YT<R!O9B!T:&4@4')O9W)A;2!A(&-O<'D@
M;V8@=&AI<R!,:6-E;G-E"F%L;VYG('=I=&@@=&AE(%!R;V=R86TN"@I9;W4@
M;6%Y(&-H87)G92!A(&9E92!F;W(@=&AE('!H>7-I8V%L(&%C="!O9B!T<F%N
M<V9E<G)I;F<@82!C;W!Y+"!A;F0*>6]U(&UA>2!A="!Y;W5R(&]P=&EO;B!O
M9F9E<B!W87)R86YT>2!P<F]T96-T:6]N(&EN(&5X8VAA;F=E(&9O<B!A(&9E
M92X*"B`@,BX@66]U(&UA>2!M;V1I9GD@>6]U<B!C;W!Y(&]R(&-O<&EE<R!O
M9B!T:&4@4')O9W)A;2!O<B!A;GD@<&]R=&EO;@IO9B!I="P@=&AU<R!F;W)M
M:6YG(&$@=V]R:R!B87-E9"!O;B!T:&4@4')O9W)A;2P@86YD(&-O<'D@86YD
M"F1I<W1R:6)U=&4@<W5C:"!M;V1I9FEC871I;VYS(&]R('=O<FL@=6YD97(@
M=&AE('1E<FUS(&]F(%-E8W1I;VX@,0IA8F]V92P@<')O=FED960@=&AA="!Y
M;W4@86QS;R!M965T(&%L;"!O9B!T:&5S92!C;VYD:71I;VYS.@H*("`@(&$I
M(%EO=2!M=7-T(&-A=7-E('1H92!M;V1I9FEE9"!F:6QE<R!T;R!C87)R>2!P
M<F]M:6YE;G0@;F]T:6-E<PH@("`@<W1A=&EN9R!T:&%T('EO=2!C:&%N9V5D
M('1H92!F:6QE<R!A;F0@=&AE(&1A=&4@;V8@86YY(&-H86YG92X*"B`@("!B
M*2!9;W4@;75S="!C875S92!A;GD@=V]R:R!T:&%T('EO=2!D:7-T<FEB=71E
M(&]R('!U8FQI<V@L('1H870@:6X*("`@('=H;VQE(&]R(&EN('!A<G0@8V]N
M=&%I;G,@;W(@:7,@9&5R:79E9"!F<F]M('1H92!0<F]G<F%M(&]R(&%N>0H@
M("`@<&%R="!T:&5R96]F+"!T;R!B92!L:6-E;G-E9"!A<R!A('=H;VQE(&%T
M(&YO(&-H87)G92!T;R!A;&P@=&AI<F0*("`@('!A<G1I97,@=6YD97(@=&AE
M('1E<FUS(&]F('1H:7,@3&EC96YS92X*"B`@("!C*2!)9B!T:&4@;6]D:69I
M960@<')O9W)A;2!N;W)M86QL>2!R96%D<R!C;VUM86YD<R!I;G1E<F%C=&EV
M96QY"B`@("!W:&5N(')U;BP@>6]U(&UU<W0@8V%U<V4@:70L('=H96X@<W1A
M<G1E9"!R=6YN:6YG(&9O<B!S=6-H"B`@("!I;G1E<F%C=&EV92!U<V4@:6X@
M=&AE(&UO<W0@;W)D:6YA<GD@=V%Y+"!T;R!P<FEN="!O<B!D:7-P;&%Y(&%N
M"B`@("!A;FYO=6YC96UE;G0@:6YC;'5D:6YG(&%N(&%P<')O<')I871E(&-O
M<'ER:6=H="!N;W1I8V4@86YD(&$*("`@(&YO=&EC92!T:&%T('1H97)E(&ES
M(&YO('=A<G)A;G1Y("AO<B!E;'-E+"!S87EI;F<@=&AA="!Y;W4@<')O=FED
M90H@("`@82!W87)R86YT>2D@86YD('1H870@=7-E<G,@;6%Y(')E9&ES=')I
M8G5T92!T:&4@<')O9W)A;2!U;F1E<@H@("`@=&AE<V4@8V]N9&ET:6]N<RP@
M86YD('1E;&QI;F<@=&AE('5S97(@:&]W('1O('9I97<@82!C;W!Y(&]F('1H
M:7,*("`@($QI8V5N<V4N("`H17AC97!T:6]N.B!I9B!T:&4@4')O9W)A;2!I
M='-E;&8@:7,@:6YT97)A8W1I=F4@8G5T"B`@("!D;V5S(&YO="!N;W)M86QL
M>2!P<FEN="!S=6-H(&%N(&%N;F]U;F-E;65N="P@>6]U<B!W;W)K(&)A<V5D
M(&]N"B`@("!T:&4@4')O9W)A;2!I<R!N;W0@<F5Q=6ER960@=&\@<')I;G0@
M86X@86YN;W5N8V5M96YT+BD*#`I4:&5S92!R97%U:7)E;65N=',@87!P;'D@
M=&\@=&AE(&UO9&EF:65D('=O<FL@87,@82!W:&]L92X@($EF"FED96YT:69I
M86)L92!S96-T:6]N<R!O9B!T:&%T('=O<FL@87)E(&YO="!D97)I=F5D(&9R
M;VT@=&AE(%!R;V=R86TL"F%N9"!C86X@8F4@<F5A<V]N86)L>2!C;VYS:61E
M<F5D(&EN9&5P96YD96YT(&%N9"!S97!A<F%T92!W;W)K<R!I;@IT:&5M<V5L
M=F5S+"!T:&5N('1H:7,@3&EC96YS92P@86YD(&ET<R!T97)M<RP@9&\@;F]T
M(&%P<&QY('1O('1H;W-E"G-E8W1I;VYS('=H96X@>6]U(&1I<W1R:6)U=&4@
M=&AE;2!A<R!S97!A<F%T92!W;W)K<RX@($)U="!W:&5N('EO=0ID:7-T<FEB
M=71E('1H92!S86UE('-E8W1I;VYS(&%S('!A<G0@;V8@82!W:&]L92!W:&EC
M:"!I<R!A('=O<FL@8F%S960*;VX@=&AE(%!R;V=R86TL('1H92!D:7-T<FEB
M=71I;VX@;V8@=&AE('=H;VQE(&UU<W0@8F4@;VX@=&AE('1E<FUS(&]F"G1H
M:7,@3&EC96YS92P@=VAO<V4@<&5R;6ES<VEO;G,@9F]R(&]T:&5R(&QI8V5N
M<V5E<R!E>'1E;F0@=&\@=&AE"F5N=&ER92!W:&]L92P@86YD('1H=7,@=&\@
M96%C:"!A;F0@979E<GD@<&%R="!R96=A<F1L97-S(&]F('=H;R!W<F]T92!I
M="X*"E1H=7,L(&ET(&ES(&YO="!T:&4@:6YT96YT(&]F('1H:7,@<V5C=&EO
M;B!T;R!C;&%I;2!R:6=H=',@;W(@8V]N=&5S=`IY;W5R(')I9VAT<R!T;R!W
M;W)K('=R:71T96X@96YT:7)E;'D@8GD@>6]U.R!R871H97(L('1H92!I;G1E
M;G0@:7,@=&\*97AE<F-I<V4@=&AE(')I9VAT('1O(&-O;G1R;VP@=&AE(&1I
M<W1R:6)U=&EO;B!O9B!D97)I=F%T:79E(&]R"F-O;&QE8W1I=F4@=V]R:W,@
M8F%S960@;VX@=&AE(%!R;V=R86TN"@I);B!A9&1I=&EO;BP@;65R92!A9V=R
M96=A=&EO;B!O9B!A;F]T:&5R('=O<FL@;F]T(&)A<V5D(&]N('1H92!0<F]G
M<F%M"G=I=&@@=&AE(%!R;V=R86T@*&]R('=I=&@@82!W;W)K(&)A<V5D(&]N
M('1H92!0<F]G<F%M*2!O;B!A('9O;'5M92!O9@IA('-T;W)A9V4@;W(@9&ES
M=')I8G5T:6]N(&UE9&EU;2!D;V5S(&YO="!B<FEN9R!T:&4@;W1H97(@=V]R
M:R!U;F1E<@IT:&4@<V-O<&4@;V8@=&AI<R!,:6-E;G-E+@H*("`S+B!9;W4@
M;6%Y(&-O<'D@86YD(&1I<W1R:6)U=&4@=&AE(%!R;V=R86T@*&]R(&$@=V]R
M:R!B87-E9"!O;B!I="P*=6YD97(@4V5C=&EO;B`R*2!I;B!O8FIE8W0@8V]D
M92!O<B!E>&5C=71A8FQE(&9O<FT@=6YD97(@=&AE('1E<FUS(&]F"E-E8W1I
M;VYS(#$@86YD(#(@86)O=F4@<')O=FED960@=&AA="!Y;W4@86QS;R!D;R!O
M;F4@;V8@=&AE(&9O;&QO=VEN9SH*"B`@("!A*2!!8V-O;7!A;GD@:70@=VET
M:"!T:&4@8V]M<&QE=&4@8V]R<F5S<&]N9&EN9R!M86-H:6YE+7)E861A8FQE
M"B`@("!S;W5R8V4@8V]D92P@=VAI8V@@;75S="!B92!D:7-T<FEB=71E9"!U
M;F1E<B!T:&4@=&5R;7,@;V8@4V5C=&EO;G,*("`@(#$@86YD(#(@86)O=F4@
M;VX@82!M961I=6T@8W5S=&]M87)I;'D@=7-E9"!F;W(@<V]F='=A<F4@:6YT
M97)C:&%N9V4[(&]R+`H*("`@(&(I($%C8V]M<&%N>2!I="!W:71H(&$@=W)I
M='1E;B!O9F9E<BP@=F%L:60@9F]R(&%T(&QE87-T('1H<F5E"B`@("!Y96%R
M<RP@=&\@9VEV92!A;GD@=&AI<F0@<&%R='DL(&9O<B!A(&-H87)G92!N;R!M
M;W)E('1H86X@>6]U<@H@("`@8V]S="!O9B!P:'ES:6-A;&QY('!E<F9O<FUI
M;F<@<V]U<F-E(&1I<W1R:6)U=&EO;BP@82!C;VUP;&5T90H@("`@;6%C:&EN
M92UR96%D86)L92!C;W!Y(&]F('1H92!C;W)R97-P;VYD:6YG('-O=7)C92!C
M;V1E+"!T;R!B90H@("`@9&ES=')I8G5T960@=6YD97(@=&AE('1E<FUS(&]F
M(%-E8W1I;VYS(#$@86YD(#(@86)O=F4@;VX@82!M961I=6T*("`@(&-U<W1O
M;6%R:6QY('5S960@9F]R('-O9G1W87)E(&EN=&5R8VAA;F=E.R!O<BP*"B`@
M("!C*2!!8V-O;7!A;GD@:70@=VET:"!T:&4@:6YF;W)M871I;VX@>6]U(')E
M8V5I=F5D(&%S('1O('1H92!O9F9E<@H@("`@=&\@9&ES=')I8G5T92!C;W)R
M97-P;VYD:6YG('-O=7)C92!C;V1E+B`@*%1H:7,@86QT97)N871I=F4@:7,*
M("`@(&%L;&]W960@;VYL>2!F;W(@;F]N8V]M;65R8VEA;"!D:7-T<FEB=71I
M;VX@86YD(&]N;'D@:68@>6]U"B`@("!R96-E:79E9"!T:&4@<')O9W)A;2!I
M;B!O8FIE8W0@8V]D92!O<B!E>&5C=71A8FQE(&9O<FT@=VET:"!S=6-H"B`@
M("!A;B!O9F9E<BP@:6X@86-C;W)D('=I=&@@4W5B<V5C=&EO;B!B(&%B;W9E
M+BD*"E1H92!S;W5R8V4@8V]D92!F;W(@82!W;W)K(&UE86YS('1H92!P<F5F
M97)R960@9F]R;2!O9B!T:&4@=V]R:R!F;W(*;6%K:6YG(&UO9&EF:6-A=&EO
M;G,@=&\@:70N("!&;W(@86X@97AE8W5T86)L92!W;W)K+"!C;VUP;&5T92!S
M;W5R8V4*8V]D92!M96%N<R!A;&P@=&AE('-O=7)C92!C;V1E(&9O<B!A;&P@
M;6]D=6QE<R!I="!C;VYT86EN<RP@<&QU<R!A;GD*87-S;V-I871E9"!I;G1E
M<F9A8V4@9&5F:6YI=&EO;B!F:6QE<RP@<&QU<R!T:&4@<V-R:7!T<R!U<V5D
M('1O"F-O;G1R;VP@8V]M<&EL871I;VX@86YD(&EN<W1A;&QA=&EO;B!O9B!T
M:&4@97AE8W5T86)L92X@($AO=V5V97(L(&%S(&$*<W!E8VEA;"!E>&-E<'1I
M;VXL('1H92!S;W5R8V4@8V]D92!D:7-T<FEB=71E9"!N965D(&YO="!I;F-L
M=61E"F%N>71H:6YG('1H870@:7,@;F]R;6%L;'D@9&ES=')I8G5T960@*&EN
M(&5I=&AE<B!S;W5R8V4@;W(@8FEN87)Y"F9O<FTI('=I=&@@=&AE(&UA:F]R
M(&-O;7!O;F5N=',@*&-O;7!I;&5R+"!K97)N96PL(&%N9"!S;R!O;BD@;V8@
M=&AE"F]P97)A=&EN9R!S>7-T96T@;VX@=VAI8V@@=&AE(&5X96-U=&%B;&4@
M<G5N<RP@=6YL97-S('1H870@8V]M<&]N96YT"FET<V5L9B!A8V-O;7!A;FEE
M<R!T:&4@97AE8W5T86)L92X*"DEF(&1I<W1R:6)U=&EO;B!O9B!E>&5C=71A
M8FQE(&]R(&]B:F5C="!C;V1E(&ES(&UA9&4@8GD@;V9F97)I;F<*86-C97-S
M('1O(&-O<'D@9G)O;2!A(&1E<VEG;F%T960@<&QA8V4L('1H96X@;V9F97)I
M;F<@97%U:79A;&5N=`IA8V-E<W,@=&\@8V]P>2!T:&4@<V]U<F-E(&-O9&4@
M9G)O;2!T:&4@<V%M92!P;&%C92!C;W5N=',@87,*9&ES=')I8G5T:6]N(&]F
M('1H92!S;W5R8V4@8V]D92P@979E;B!T:&]U9V@@=&AI<F0@<&%R=&EE<R!A
M<F4@;F]T"F-O;7!E;&QE9"!T;R!C;W!Y('1H92!S;W5R8V4@86QO;F<@=VET
M:"!T:&4@;V)J96-T(&-O9&4N"@P*("`T+B!9;W4@;6%Y(&YO="!C;W!Y+"!M
M;V1I9GDL('-U8FQI8V5N<V4L(&]R(&1I<W1R:6)U=&4@=&AE(%!R;V=R86T*
M97AC97!T(&%S(&5X<')E<W-L>2!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N
M<V4N("!!;GD@871T96UP=`IO=&AE<G=I<V4@=&\@8V]P>2P@;6]D:69Y+"!S
M=6)L:6-E;G-E(&]R(&1I<W1R:6)U=&4@=&AE(%!R;V=R86T@:7,*=F]I9"P@
M86YD('=I;&P@875T;VUA=&EC86QL>2!T97)M:6YA=&4@>6]U<B!R:6=H=',@
M=6YD97(@=&AI<R!,:6-E;G-E+@I(;W=E=F5R+"!P87)T:65S('=H;R!H879E
M(')E8V5I=F5D(&-O<&EE<RP@;W(@<FEG:'1S+"!F<F]M('EO=2!U;F1E<@IT
M:&ES($QI8V5N<V4@=VEL;"!N;W0@:&%V92!T:&5I<B!L:6-E;G-E<R!T97)M
M:6YA=&5D('-O(&QO;F<@87,@<W5C:`IP87)T:65S(')E;6%I;B!I;B!F=6QL
M(&-O;7!L:6%N8V4N"@H@(#4N(%EO=2!A<F4@;F]T(')E<75I<F5D('1O(&%C
M8V5P="!T:&ES($QI8V5N<V4L('-I;F-E('EO=2!H879E(&YO=`IS:6=N960@
M:70N("!(;W=E=F5R+"!N;W1H:6YG(&5L<V4@9W)A;G1S('EO=2!P97)M:7-S
M:6]N('1O(&UO9&EF>2!O<@ID:7-T<FEB=71E('1H92!0<F]G<F%M(&]R(&ET
M<R!D97)I=F%T:79E('=O<FMS+B`@5&AE<V4@86-T:6]N<R!A<F4*<')O:&EB
M:71E9"!B>2!L87<@:68@>6]U(&1O(&YO="!A8V-E<'0@=&AI<R!,:6-E;G-E
M+B`@5&AE<F5F;W)E+"!B>0IM;V1I9GEI;F<@;W(@9&ES=')I8G5T:6YG('1H
M92!0<F]G<F%M("AO<B!A;GD@=V]R:R!B87-E9"!O;B!T:&4*4')O9W)A;2DL
M('EO=2!I;F1I8V%T92!Y;W5R(&%C8V5P=&%N8V4@;V8@=&AI<R!,:6-E;G-E
M('1O(&1O('-O+"!A;F0*86QL(&ET<R!T97)M<R!A;F0@8V]N9&ET:6]N<R!F
M;W(@8V]P>6EN9RP@9&ES=')I8G5T:6YG(&]R(&UO9&EF>6EN9PIT:&4@4')O
M9W)A;2!O<B!W;W)K<R!B87-E9"!O;B!I="X*"B`@-BX@16%C:"!T:6UE('EO
M=2!R961I<W1R:6)U=&4@=&AE(%!R;V=R86T@*&]R(&%N>2!W;W)K(&)A<V5D
M(&]N('1H90I0<F]G<F%M*2P@=&AE(')E8VEP:65N="!A=71O;6%T:6-A;&QY
M(')E8V5I=F5S(&$@;&EC96YS92!F<F]M('1H90IO<FEG:6YA;"!L:6-E;G-O
M<B!T;R!C;W!Y+"!D:7-T<FEB=71E(&]R(&UO9&EF>2!T:&4@4')O9W)A;2!S
M=6)J96-T('1O"G1H97-E('1E<FUS(&%N9"!C;VYD:71I;VYS+B`@66]U(&UA
M>2!N;W0@:6UP;W-E(&%N>2!F=7)T:&5R"G)E<W1R:6-T:6]N<R!O;B!T:&4@
M<F5C:7!I96YT<R<@97AE<F-I<V4@;V8@=&AE(')I9VAT<R!G<F%N=&5D(&AE
M<F5I;BX*66]U(&%R92!N;W0@<F5S<&]N<VEB;&4@9F]R(&5N9F]R8VEN9R!C
M;VUP;&EA;F-E(&)Y('1H:7)D('!A<G1I97,@=&\*=&AI<R!,:6-E;G-E+@H*
M("`W+B!)9BP@87,@82!C;VYS97%U96YC92!O9B!A(&-O=7)T(&IU9&=M96YT
M(&]R(&%L;&5G871I;VX@;V8@<&%T96YT"FEN9G)I;F=E;65N="!O<B!F;W(@
M86YY(&]T:&5R(')E87-O;B`H;F]T(&QI;6ET960@=&\@<&%T96YT(&ES<W5E
M<RDL"F-O;F1I=&EO;G,@87)E(&EM<&]S960@;VX@>6]U("AW:&5T:&5R(&)Y
M(&-O=7)T(&]R9&5R+"!A9W)E96UE;G0@;W(*;W1H97)W:7-E*2!T:&%T(&-O
M;G1R861I8W0@=&AE(&-O;F1I=&EO;G,@;V8@=&AI<R!,:6-E;G-E+"!T:&5Y
M(&1O(&YO=`IE>&-U<V4@>6]U(&9R;VT@=&AE(&-O;F1I=&EO;G,@;V8@=&AI
M<R!,:6-E;G-E+B`@268@>6]U(&-A;FYO=`ID:7-T<FEB=71E('-O(&%S('1O
M('-A=&ES9GD@<VEM=6QT86YE;W5S;'D@>6]U<B!O8FQI9V%T:6]N<R!U;F1E
M<B!T:&ES"DQI8V5N<V4@86YD(&%N>2!O=&AE<B!P97)T:6YE;G0@;V)L:6=A
M=&EO;G,L('1H96X@87,@82!C;VYS97%U96YC92!Y;W4*;6%Y(&YO="!D:7-T
M<FEB=71E('1H92!0<F]G<F%M(&%T(&%L;"X@($9O<B!E>&%M<&QE+"!I9B!A
M('!A=&5N=`IL:6-E;G-E('=O=6QD(&YO="!P97)M:70@<F]Y86QT>2UF<F5E
M(')E9&ES=')I8G5T:6]N(&]F('1H92!0<F]G<F%M(&)Y"F%L;"!T:&]S92!W
M:&\@<F5C96EV92!C;W!I97,@9&ER96-T;'D@;W(@:6YD:7)E8W1L>2!T:')O
M=6=H('EO=2P@=&AE;@IT:&4@;VYL>2!W87D@>6]U(&-O=6QD('-A=&ES9GD@
M8F]T:"!I="!A;F0@=&AI<R!,:6-E;G-E('=O=6QD(&)E('1O"G)E9G)A:6X@
M96YT:7)E;'D@9G)O;2!D:7-T<FEB=71I;VX@;V8@=&AE(%!R;V=R86TN"@I)
M9B!A;GD@<&]R=&EO;B!O9B!T:&ES('-E8W1I;VX@:7,@:&5L9"!I;G9A;&ED
M(&]R('5N96YF;W)C96%B;&4@=6YD97(*86YY('!A<G1I8W5L87(@8VER8W5M
M<W1A;F-E+"!T:&4@8F%L86YC92!O9B!T:&4@<V5C=&EO;B!I<R!I;G1E;F1E
M9"!T;PIA<'!L>2!A;F0@=&AE('-E8W1I;VX@87,@82!W:&]L92!I<R!I;G1E
M;F1E9"!T;R!A<'!L>2!I;B!O=&AE<@IC:7)C=6US=&%N8V5S+@H*270@:7,@
M;F]T('1H92!P=7)P;W-E(&]F('1H:7,@<V5C=&EO;B!T;R!I;F1U8V4@>6]U
M('1O(&EN9G)I;F=E(&%N>0IP871E;G1S(&]R(&]T:&5R('!R;W!E<G1Y(')I
M9VAT(&-L86EM<R!O<B!T;R!C;VYT97-T('9A;&ED:71Y(&]F(&%N>0IS=6-H
M(&-L86EM<SL@=&AI<R!S96-T:6]N(&AA<R!T:&4@<V]L92!P=7)P;W-E(&]F
M('!R;W1E8W1I;F<@=&AE"FEN=&5G<FET>2!O9B!T:&4@9G)E92!S;V9T=V%R
M92!D:7-T<FEB=71I;VX@<WES=&5M+"!W:&EC:"!I<PII;7!L96UE;G1E9"!B
M>2!P=6)L:6,@;&EC96YS92!P<F%C=&EC97,N("!-86YY('!E;W!L92!H879E
M(&UA9&4*9V5N97)O=7,@8V]N=')I8G5T:6]N<R!T;R!T:&4@=VED92!R86YG
M92!O9B!S;V9T=V%R92!D:7-T<FEB=71E9`IT:')O=6=H('1H870@<WES=&5M
M(&EN(')E;&EA;F-E(&]N(&-O;G-I<W1E;G0@87!P;&EC871I;VX@;V8@=&AA
M=`IS>7-T96T[(&ET(&ES('5P('1O('1H92!A=71H;W(O9&]N;W(@=&\@9&5C
M:61E(&EF(&AE(&]R('-H92!I<R!W:6QL:6YG"G1O(&1I<W1R:6)U=&4@<V]F
M='=A<F4@=&AR;W5G:"!A;GD@;W1H97(@<WES=&5M(&%N9"!A(&QI8V5N<V5E
M(&-A;FYO=`II;7!O<V4@=&AA="!C:&]I8V4N"@I4:&ES('-E8W1I;VX@:7,@
M:6YT96YD960@=&\@;6%K92!T:&]R;W5G:&QY(&-L96%R('=H870@:7,@8F5L
M:65V960@=&\*8F4@82!C;VYS97%U96YC92!O9B!T:&4@<F5S="!O9B!T:&ES
M($QI8V5N<V4N"@P*("`X+B!)9B!T:&4@9&ES=')I8G5T:6]N(&%N9"]O<B!U
M<V4@;V8@=&AE(%!R;V=R86T@:7,@<F5S=')I8W1E9"!I;@IC97)T86EN(&-O
M=6YT<FEE<R!E:71H97(@8GD@<&%T96YT<R!O<B!B>2!C;W!Y<FEG:'1E9"!I
M;G1E<F9A8V5S+"!T:&4*;W)I9VEN86P@8V]P>7)I9VAT(&AO;&1E<B!W:&\@
M<&QA8V5S('1H92!0<F]G<F%M('5N9&5R('1H:7,@3&EC96YS90IM87D@861D
M(&%N(&5X<&QI8VET(&=E;V=R87!H:6-A;"!D:7-T<FEB=71I;VX@;&EM:71A
M=&EO;B!E>&-L=61I;F<*=&AO<V4@8V]U;G1R:65S+"!S;R!T:&%T(&1I<W1R
M:6)U=&EO;B!I<R!P97)M:71T960@;VYL>2!I;B!O<B!A;6]N9PIC;W5N=')I
M97,@;F]T('1H=7,@97AC;'5D960N("!);B!S=6-H(&-A<V4L('1H:7,@3&EC
M96YS92!I;F-O<G!O<F%T97,*=&AE(&QI;6ET871I;VX@87,@:68@=W)I='1E
M;B!I;B!T:&4@8F]D>2!O9B!T:&ES($QI8V5N<V4N"@H@(#DN(%1H92!&<F5E
M(%-O9G1W87)E($9O=6YD871I;VX@;6%Y('!U8FQI<V@@<F5V:7-E9"!A;F0O
M;W(@;F5W('9E<G-I;VYS"F]F('1H92!'96YE<F%L(%!U8FQI8R!,:6-E;G-E
M(&9R;VT@=&EM92!T;R!T:6UE+B`@4W5C:"!N97<@=F5R<VEO;G,@=VEL;`IB
M92!S:6UI;&%R(&EN('-P:7)I="!T;R!T:&4@<')E<V5N="!V97)S:6]N+"!B
M=70@;6%Y(&1I9F9E<B!I;B!D971A:6P@=&\*861D<F5S<R!N97<@<')O8FQE
M;7,@;W(@8V]N8V5R;G,N"@I%86-H('9E<G-I;VX@:7,@9VEV96X@82!D:7-T
M:6YG=6ES:&EN9R!V97)S:6]N(&YU;6)E<BX@($EF('1H92!0<F]G<F%M"G-P
M96-I9FEE<R!A('9E<G-I;VX@;G5M8F5R(&]F('1H:7,@3&EC96YS92!W:&EC
M:"!A<'!L:65S('1O(&ET(&%N9"`B86YY"FQA=&5R('9E<G-I;VXB+"!Y;W4@
M:&%V92!T:&4@;W!T:6]N(&]F(&9O;&QO=VEN9R!T:&4@=&5R;7,@86YD(&-O
M;F1I=&EO;G,*96ET:&5R(&]F('1H870@=F5R<VEO;B!O<B!O9B!A;GD@;&%T
M97(@=F5R<VEO;B!P=6)L:7-H960@8GD@=&AE($9R964*4V]F='=A<F4@1F]U
M;F1A=&EO;BX@($EF('1H92!0<F]G<F%M(&1O97,@;F]T('-P96-I9GD@82!V
M97)S:6]N(&YU;6)E<B!O9@IT:&ES($QI8V5N<V4L('EO=2!M87D@8VAO;W-E
M(&%N>2!V97)S:6]N(&5V97(@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W
M87)E"D9O=6YD871I;VXN"@H@(#$P+B!)9B!Y;W4@=VES:"!T;R!I;F-O<G!O
M<F%T92!P87)T<R!O9B!T:&4@4')O9W)A;2!I;G1O(&]T:&5R(&9R964*<')O
M9W)A;7,@=VAO<V4@9&ES=')I8G5T:6]N(&-O;F1I=&EO;G,@87)E(&1I9F9E
M<F5N="P@=W)I=&4@=&\@=&AE(&%U=&AO<@IT;R!A<VL@9F]R('!E<FUI<W-I
M;VXN("!&;W(@<V]F='=A<F4@=VAI8V@@:7,@8V]P>7)I9VAT960@8GD@=&AE
M($9R964*4V]F='=A<F4@1F]U;F1A=&EO;BP@=W)I=&4@=&\@=&AE($9R964@
M4V]F='=A<F4@1F]U;F1A=&EO;CL@=V4@<V]M971I;65S"FUA:V4@97AC97!T
M:6]N<R!F;W(@=&AI<RX@($]U<B!D96-I<VEO;B!W:6QL(&)E(&=U:61E9"!B
M>2!T:&4@='=O(&=O86QS"F]F('!R97-E<G9I;F<@=&AE(&9R964@<W1A='5S
M(&]F(&%L;"!D97)I=F%T:79E<R!O9B!O=7(@9G)E92!S;V9T=V%R92!A;F0*
M;V8@<')O;6]T:6YG('1H92!S:&%R:6YG(&%N9"!R975S92!O9B!S;V9T=V%R
M92!G96YE<F%L;'DN"@H)"0D@("`@3D\@5T%24D%.5%D*"B`@,3$N($)%0T%5
M4T4@5$A%(%!23T=204T@25,@3$E#14Y3140@1E)%12!/1B!#2$%21T4L(%1(
M15)%($E3($Y/(%=!4E)!3E19"D9/4B!42$4@4%)/1U)!32P@5$\@5$A%($58
M5$5.5"!015)-2514140@0ED@05!03$E#04),12!,05<N("!%6$-%4%0@5TA%
M3@I/5$A%4E=)4T4@4U1!5$5$($E.(%=2251)3D<@5$A%($-/4%E224=(5"!(
M3TQ$15)3($%.1"]/4B!/5$A%4B!005)42453"E!23U9)1$4@5$A%(%!23T=2
M04T@(D%3($E3(B!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%251(
M15(@15A04D534T5$"D]2($E-4$Q)140L($E.0TQ51$E.1RP@0E54($Y/5"!,
M24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&"DU%4D-(04Y4
M04))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4N
M("!42$4@14Y425)%(%))4TL@05,*5$\@5$A%(%%504Q)5%D@04Y$(%!%4D9/
M4DU!3D-%($]&(%1(12!04D]'4D%-($E3(%=)5$@@64]5+B`@4TA/54Q$(%1(
M10I04D]'4D%-(%!23U9%($1%1D5#5$E612P@64]5($%34U5-12!42$4@0T]3
M5"!/1B!!3$P@3D5#15-305)9(%-%4E9)0TE.1RP*4D5004E2($]2($-/4E)%
M0U1)3TXN"@H@(#$R+B!)3B!.3R!%5D5.5"!53DQ%4U,@4D5154E2140@0ED@
M05!03$E#04),12!,05<@3U(@04=2145$(%1/($E.(%=2251)3D<*5TE,3"!!
M3ED@0T]065))1TA4($A/3$1%4BP@3U(@04Y9($]42$52(%!!4E19(%=(3R!-
M05D@34]$2499($%.1"]/4@I2141)4U1224)55$4@5$A%(%!23T=204T@05,@
M4$5234E45$5$($%"3U9%+"!"12!,24%"3$4@5$\@64]5($9/4B!$04U!1T53
M+`I)3D-,541)3D<@04Y9($=%3D5204PL(%-014-)04PL($E.0TE$14Y404P@
M3U(@0T].4T51545.5$E!3"!$04U!1T53($%225-)3D<*3U54($]&(%1(12!5
M4T4@3U(@24Y!0DE,2519(%1/(%5312!42$4@4%)/1U)!32`H24Y#3%5$24Y'
M($)55"!.3U0@3$E-251%1`I43R!,3U-3($]&($1!5$$@3U(@1$%402!"14E.
M1R!214Y$15)%1"!)3D%#0U52051%($]2($Q/4U-%4R!355-404E.140@0ED*
M64]5($]2(%1(25)$(%!!4E1)15,@3U(@02!&04E,55)%($]&(%1(12!04D]'
M4D%-(%1/($]015)!5$4@5TE42"!!3ED@3U1(15(*4%)/1U)!35,I+"!%5D5.
M($E&(%-50T@@2$],1$52($]2($]42$52(%!!4E19($A!4R!"145.($%$5DE3
M140@3T8@5$A%"E!/4U-)0DE,2519($]&(%-50T@@1$%-04=%4RX*"@D)("`@
M("!%3D0@3T8@5$5235,@04Y$($-/3D1)5$E/3E,*#`H)("`@($AO=R!T;R!!
M<'!L>2!4:&5S92!497)M<R!T;R!9;W5R($YE=R!0<F]G<F%M<PH*("!)9B!Y
M;W4@9&5V96QO<"!A(&YE=R!P<F]G<F%M+"!A;F0@>6]U('=A;G0@:70@=&\@
M8F4@;V8@=&AE(&=R96%T97-T"G!O<W-I8FQE('5S92!T;R!T:&4@<'5B;&EC
M+"!T:&4@8F5S="!W87D@=&\@86-H:65V92!T:&ES(&ES('1O(&UA:V4@:70*
M9G)E92!S;V9T=V%R92!W:&EC:"!E=F5R>6]N92!C86X@<F5D:7-T<FEB=71E
M(&%N9"!C:&%N9V4@=6YD97(@=&AE<V4@=&5R;7,N"@H@(%1O(&1O('-O+"!A
M='1A8V@@=&AE(&9O;&QO=VEN9R!N;W1I8V5S('1O('1H92!P<F]G<F%M+B`@
M270@:7,@<V%F97-T"G1O(&%T=&%C:"!T:&5M('1O('1H92!S=&%R="!O9B!E
M86-H('-O=7)C92!F:6QE('1O(&UO<W0@969F96-T:79E;'D*8V]N=F5Y('1H
M92!E>&-L=7-I;VX@;V8@=V%R<F%N='D[(&%N9"!E86-H(&9I;&4@<VAO=6QD
M(&AA=F4@870@;&5A<W0*=&AE(")C;W!Y<FEG:'0B(&QI;F4@86YD(&$@<&]I
M;G1E<B!T;R!W:&5R92!T:&4@9G5L;"!N;W1I8V4@:7,@9F]U;F0N"@H@("`@
M/&]N92!L:6YE('1O(&=I=F4@=&AE('!R;V=R86TG<R!N86UE(&%N9"!A(&)R
M:65F(&ED96$@;V8@=VAA="!I="!D;V5S+CX*("`@($-O<'ER:6=H="`H0RD@
M,3EY>2`@/&YA;64@;V8@875T:&]R/@H*("`@(%1H:7,@<')O9W)A;2!I<R!F
M<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(@
M;6]D:69Y"B`@("!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!'96YE
M<F%L(%!U8FQI8R!,:6-E;G-E(&%S('!U8FQI<VAE9"!B>0H@("`@=&AE($9R
M964@4V]F='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R('9E<G-I;VX@,B!O9B!T
M:&4@3&EC96YS92P@;W(*("`@("AA="!Y;W5R(&]P=&EO;BD@86YY(&QA=&5R
M('9E<G-I;VXN"@H@("`@5&AI<R!P<F]G<F%M(&ES(&1I<W1R:6)U=&5D(&EN
M('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@("!B=70@5TE4
M2$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W
M87)R86YT>2!O9@H@("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H90H@("`@1TY5($=E;F5R
M86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@("!9;W4@
M<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@1V5N97)A
M;"!0=6)L:6,@3&EC96YS90H@("`@86QO;F<@=VET:"!T:&ES('!R;V=R86T[
M(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@($9O=6YD
M871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T
M;VXL($U!("`P,C$Q,2TQ,S`W("!54T$*"@I!;'-O(&%D9"!I;F9O<FUA=&EO
M;B!O;B!H;W<@=&\@8V]N=&%C="!Y;W4@8GD@96QE8W1R;VYI8R!A;F0@<&%P
M97(@;6%I;"X*"DEF('1H92!P<F]G<F%M(&ES(&EN=&5R86-T:79E+"!M86ME
M(&ET(&]U='!U="!A('-H;W)T(&YO=&EC92!L:6ME('1H:7,*=VAE;B!I="!S
M=&%R=',@:6X@86X@:6YT97)A8W1I=F4@;6]D93H*"B`@("!';F]M;W9I<VEO
M;B!V97)S:6]N(#8Y+"!#;W!Y<FEG:'0@*$,I(#$Y>7D@;F%M92!O9B!A=71H
M;W(*("`@($=N;VUO=FES:6]N(&-O;65S('=I=&@@04)33TQ55$5,62!.3R!7
M05)204Y463L@9F]R(&1E=&%I;',@='EP92!@<VAO=R!W)RX*("`@(%1H:7,@
M:7,@9G)E92!S;V9T=V%R92P@86YD('EO=2!A<F4@=V5L8V]M92!T;R!R961I
M<W1R:6)U=&4@:70*("`@('5N9&5R(&-E<G1A:6X@8V]N9&ET:6]N<SL@='EP
M92!@<VAO=R!C)R!F;W(@9&5T86EL<RX*"E1H92!H>7!O=&AE=&EC86P@8V]M
M;6%N9',@8'-H;W<@=R<@86YD(&!S:&]W(&,G('-H;W5L9"!S:&]W('1H92!A
M<'!R;W!R:6%T90IP87)T<R!O9B!T:&4@1V5N97)A;"!0=6)L:6,@3&EC96YS
M92X@($]F(&-O=7)S92P@=&AE(&-O;6UA;F1S('EO=2!U<V4@;6%Y"F)E(&-A
M;&QE9"!S;VUE=&AI;F<@;W1H97(@=&AA;B!@<VAO=R!W)R!A;F0@8'-H;W<@
M8R<[('1H97D@8V]U;&0@979E;B!B90IM;W5S92UC;&EC:W,@;W(@;65N=2!I
M=&5M<RTM=VAA=&5V97(@<W5I=',@>6]U<B!P<F]G<F%M+@H*66]U('-H;W5L
M9"!A;'-O(&=E="!Y;W5R(&5M<&QO>65R("AI9B!Y;W4@=V]R:R!A<R!A('!R
M;V=R86UM97(I(&]R('EO=7(*<V-H;V]L+"!I9B!A;GDL('1O('-I9VX@82`B
M8V]P>7)I9VAT(&1I<V-L86EM97(B(&9O<B!T:&4@<')O9W)A;2P@:68*;F5C
M97-S87)Y+B`@2&5R92!I<R!A('-A;7!L93L@86QT97(@=&AE(&YA;65S.@H*
M("!9;WEO9'EN92P@26YC+BP@:&5R96)Y(&1I<V-L86EM<R!A;&P@8V]P>7)I
M9VAT(&EN=&5R97-T(&EN('1H92!P<F]G<F%M"B`@8$=N;VUO=FES:6]N)R`H
M=VAI8V@@;6%K97,@<&%S<V5S(&%T(&-O;7!I;&5R<RD@=W)I='1E;B!B>2!*
M86UE<R!(86-K97(N"@H@(#QS:6=N871U<F4@;V8@5'D@0V]O;CXL(#$@07!R
M:6P@,3DX.0H@(%1Y($-O;VXL(%!R97-I9&5N="!O9B!6:6-E"@I4:&ES($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@9&]E<R!N;W0@<&5R;6ET(&EN8V]R<&]R
M871I;F<@>6]U<B!P<F]G<F%M(&EN=&\*<')O<')I971A<GD@<')O9W)A;7,N
M("!)9B!Y;W5R('!R;V=R86T@:7,@82!S=6)R;W5T:6YE(&QI8G)A<GDL('EO
M=2!M87D*8V]N<VED97(@:70@;6]R92!U<V5F=6P@=&\@<&5R;6ET(&QI;FMI
M;F<@<')O<')I971A<GD@87!P;&EC871I;VYS('=I=&@@=&AE"FQI8G)A<GDN
M("!)9B!T:&ES(&ES('=H870@>6]U('=A;G0@=&\@9&\L('5S92!T:&4@1TY5
M($QI8G)A<GD@1V5N97)A;`I0=6)L:6,@3&EC96YS92!I;G-T96%D(&]F('1H
M:7,@3&EC96YS92X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]S96%R8V@N<&AP
M````````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,S`Q-S``,3`T,3<S-C(W-S``,#$W,38T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EM
M<"]S96%R8V@N<&AP+'8@,BXQ,C@N,BXQ.2`R,#`V+S`R+S$U(#`Q.C(Y.C(S
M('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!54DP@4&%R
M86UE=&5R<SH*("H@+2TM+2TM+2TM+2TM+2TM"B`J("=S96%R8VA?;6%I;&)O
M>"<@("TM("!)9B!E>&ES=',L(&1O;B=T('-H;W<@=&AE(&9O;&1E<B!S96QE
M8W1I;VX@;&ES=#L@=7-E"B`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M<&%S<V5D(&EN(&UA:6QB;W@@=F%L=64@:6YS=&5A9"X*("H@)V5D:71?<75E
M<GDG("`@("`@+2T@($EF(&5X:7-T<RP@=&AE('-E87)C:"!Q=65R>2!T;R!E
M9&ET+@H@*B\*"B\J*@H@*B!'96YE<F%T97,@=&AE($A434P@9F]R(&$@9&%Y
M('-E;&5C=&EO;B!W:61G970N"B`J"B`J($!P87)A;2!S=')I;F<@)&YA;64@
M("`@("!4:&4@;F%M92!O9B!T:&4@=VED9V5T+@H@*B!`<&%R86T@:6YT96=E
M<B`D9&5F875L="`@5&AE('9A;'5E('1O('-E;&5C="!B>2!D969A=6QT+B!2
M86YG93H@,2TS,0H@*B!`<&%R86T@<W1R:6YG("1P87)A;7,@("`@06YY(&%D
M9&ET:6]N86P@<&%R86UE=&5R<R!T;R!I;F-L=61E(&EN('1H92`\83X*("H@
M("`@("`@("`@("`@("`@("`@("`@("`@('1A9RX*("H*("H@0')E='5R;B!S
M=')I;F<@(%1H92!(5$U,(#QS96QE8W0^('=I9&=E="X*("HO"F9U;F-T:6]N
M(&)U:6QD1&%Y5VED9V5T*"1N86UE+"`D9&5F875L="`](&YU;&PL("1P87)A
M;7,@/2!N=6QL*0I["B`@("`D:'1M;"`]("<\<V5L96-T(&ED/2(G("X@)&YA
M;64@+B`G(B!N86UE/2(G("X@)&YA;64N("<B)SL*("`@(&EF("@A:7-?;G5L
M;"@D<&%R86US*2D@>PH@("`@("`@("1H=&UL("X]("<@)R`N("1P87)A;7,[
M"B`@("!]"B`@("`D:'1M;"`N/2`G/B<["@H@("`@9F]R("@D9&%Y(#T@,3L@
M)&1A>2`\/2`S,3L@)&1A>2LK*2!["B`@("`@("`@)&AT;6P@+CT@)SQO<'1I
M;VX@=F%L=64](B<@+B`D9&%Y("X@)R(G.PH@("`@("`@("1H=&UL("X]("@D
M9&%Y(#T]("1D969A=6QT*2`_("<@<V5L96-T960](G-E;&5C=&5D(CXG(#H@
M)SXG.PH@("`@("`@("1H=&UL("X]("1D87D@+B`G/"]O<'1I;VX^)SL*("`@
M('T*"B`@("!R971U<FX@)&AT;6P@+B`B/"]S96QE8W0^7&XB.PI]"@HO*BH*
M("H@1V5N97)A=&5S('1H92!(5$U,(&9O<B!A(&UO;G1H('-E;&5C=&EO;B!W
M:61G970N"B`J"B`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("!4:&4@;F%M
M92!O9B!T:&4@=VED9V5T+@H@*B!`<&%R86T@:6YT96=E<B`D9&5F875L="`@
M5&AE('9A;'5E('1O('-E;&5C="!B>2!D969A=6QT+@H@*B!`<&%R86T@<W1R
M:6YG("1P87)A;7,@("`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T;R!I
M;F-L=61E(&EN('1H92`\83X*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M('1A9RX*("H*("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(#QS96QE8W0^
M('=I9&=E="X*("HO"F9U;F-T:6]N(&)U:6QD36]N=&A7:61G970H)&YA;64L
M("1D969A=6QT(#T@;G5L;"P@)'!A<F%M<R`](&YU;&PI"GL*("`@("1H=&UL
M(#T@)SQS96QE8W0@:60](B<@+B`D;F%M92`N("<B(&YA;64](B<@+B`D;F%M
M92X@)R(G.PH@("`@:68@*"%I<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@
M)&AT;6P@+CT@)R`G("X@)'!A<F%M<SL*("`@('T*("`@("1H=&UL("X]("<^
M)SL*"B`@("!F;W(@*"1M;VYT:"`](#$[("1M;VYT:"`\/2`Q,CL@)&UO;G1H
M*RLI('L*("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB)R`N("1M
M;VYT:"`N("<B)SL*("`@("`@("`D:'1M;"`N/2`H)&UO;G1H(#T]("1D969A
M=6QT*2`_("<@<V5L96-T960](G-E;&5C=&5D(CXG(#H@)SXG.PH@("`@("`@
M("1H=&UL("X]('-T<F9T:6UE*"<E0B<L(&UK=&EM92@P+"`P+"`P+"`D;6]N
M=&@L(#$I*2`N("<\+V]P=&EO;CXG.PH@("`@?0H*("`@(')E='5R;B`D:'1M
M;"`N("(\+W-E;&5C=#Y<;B(["GT*"B\J*@H@*B!'96YE<F%T97,@=&AE($A4
M34P@9F]R(&$@>65A<B!S96QE8W1I;VX@=VED9V5T+@H@*@H@*B!`<&%R86T@
M:6YT96=E<B`D;F%M92`@("!4:&4@;F%M92!O9B!T:&4@=VED9V5T+@H@*B!`
M<&%R86T@:6YT96=E<B`D>65A<G,@("!4:&4@;G5M8F5R(&]F('EE87)S('1O
M(&EN8VQU9&4N"B`J("`@("`@("`@("`@("`@("`@("`@("`@($EF("@K*3H@
M9G5T=7)E('EE87)S"B`J("`@("`@("`@("`@("`@("`@("`@("`@($EF("@M
M*3H@<&%S="!Y96%R<PH@*B!`<&%R86T@<W1R:6YG("1D969A=6QT("!4:&4@
M=&EM97-T86UP('1O('-E;&5C="!B>2!D969A=6QT+@H@*B!`<&%R86T@<W1R
M:6YG("1P87)A;7,@("!!;GD@861D:71I;VYA;"!P87)A;65T97)S('1O(&EN
M8VQU9&4@:6X@=&AE(#QA/@H@*B`@("`@("`@("`@("`@("`@("`@("`@("!T
M86<N"B`J"B`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"`\<V5L96-T/B!W
M:61G970N"B`J+PIF=6YC=&EO;B!B=6EL9%EE87)7:61G970H)&YA;64L("1Y
M96%R<RP@)&1E9F%U;'0@/2!N=6QL+"`D<&%R86US(#T@;G5L;"D*>PH@("`@
M)&-U<G)?>65A<B`](&1A=&4H)UDG*3L*("`@("1Y96%R;&ES="`](&%R<F%Y
M*"D["@H@("`@)'-T87)T>65A<B`]("@A:7-?;G5L;"@D9&5F875L="D@)B8@
M*"1D969A=6QT(#P@)&-U<G)?>65A<BD@)B8@*"1Y96%R<R`^(#`I*2`_("1D
M969A=6QT(#H@)&-U<G)?>65A<CL*("`@("1S=&%R='EE87(@/2!M:6XH)'-T
M87)T>65A<BP@)'-T87)T>65A<B`K("1Y96%R<RD["B`@("!F;W(@*"1I(#T@
M,#L@)&D@/#T@86)S*"1Y96%R<RD[("1I*RLI('L*("`@("`@("`D>65A<FQI
M<W1;72`]("1S=&%R='EE87(K*SL*("`@('T*("`@(&EF("@D>65A<G,@/"`P
M*2!["B`@("`@("`@)'EE87)L:7-T(#T@87)R87E?<F5V97)S92@D>65A<FQI
M<W0I.PH@("`@?0H*("`@("1H=&UL(#T@)SQS96QE8W0@:60](B<@+B`D;F%M
M92`N("<B(&YA;64](B<@+B`D;F%M92X@)R(G.PH@("`@:68@*"%I<U]N=6QL
M*"1P87)A;7,I*2!["B`@("`@("`@)&AT;6P@+CT@)R`G("X@)'!A<F%M<SL*
M("`@('T*("`@("1H=&UL("X]("<^)SL*"B`@("!F;W)E86-H("@D>65A<FQI
M<W0@87,@)'EE87(I('L*("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU
M93TB)R`N("1Y96%R("X@)R(G.PH@("`@("`@("1H=&UL("X]("@D>65A<B`]
M/2`D9&5F875L="D@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(^)R`Z("<^)SL*
M("`@("`@("`D:'1M;"`N/2`D>65A<B`N("<\+V]P=&EO;CXG.PH@("`@?0H*
M("`@(')E='5R;B`D:'1M;"`N("(\+W-E;&5C=#Y<;B(["GT*"F1E9FEN92@G
M24U07T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["B1A=71H96YT:6-A=&EO
M;B`]($]07TA!3$9/4$5..PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI
M8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+T9O
M;&1E<BYP:'`G.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]396%R
M8V@N<&AP)SL*"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I
M;VY)1"<I.PHD961I=%]Q=65R>2`](%5T:6PZ.F=E=$9O<FU$871A*"=E9&ET
M7W%U97)Y)RD["B1E9&ET7W%U97)Y7VED(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V5D:71?<75E<GE?:60G+"`D961I=%]Q=65R>2D["B1E9&ET7W%U97)Y7W9F
M;VQD97(@/2!5=&EL.CIG971&;W)M1&%T82@G961I=%]Q=65R>5]V9F]L9&5R
M)RD["B1S96%R8VA?;6%I;&)O>"`](%5T:6PZ.F=E=$9O<FU$871A*"=S96%R
M8VA?;6%I;&)O>"<I.PH*)&EM<%]S96%R8VA?9FEE;&1S(#T@)&EM<%]S96%R
M8V@M/G-E87)C:$9I96QD<R@I.PH*+RH@1V5T(%523"!P87)A;65T97(@9&%T
M82X@*B\*)'-E87)C:"`](&%R<F%Y*"D["FEF("A5=&EL.CIG971&;W)M1&%T
M82@G;F]?;6%T8V@G*2D@>PH@("`@)'-E87)C:"`]("1I;7!?<V5A<F-H+3YR
M971R:65V955)475E<GDH*3L*?2!E;'-E:68@*"%I<U]N=6QL*"1E9&ET7W%U
M97)Y*2`F)B`D:6UP7W-E87)C:"T^:7-396%R8VA-8F]X*"1E9&ET7W%U97)Y
M*2D@>PH@("`@:68@*"1I;7!?<V5A<F-H+3YI<U9&;VQD97(H)&5D:71?<75E
M<GDI*2!["B`@("`@("`@)&5D:71?<75E<GE?=F9O;&1E<B`]('1R=64["B`@
M("`@("`@:68@*"$D:6UP7W-E87)C:"T^:7-%9&ET86)L959&;VQD97(H)&5D
M:71?<75E<GDI*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B4W!E8VEA;"!6:7)T=6%L($9O;&1E<G,@8V%N;F]T(&)E(&5D:71E9"XB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@(&AE861E<B@G3&]C871I
M;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)VUA:6QB;W@N<&AP)RP@
M=')U92DI.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*("`@('T*("`@
M("1S96%R8V@@/2`D:6UP7W-E87)C:"T^<F5T<FEE=F5525%U97)Y*"1E9&ET
M7W%U97)Y*3L*?2!E;'-E('L*("`@(&EF("AE;7!T>2@D86-T:6]N240I("8F
M"B`@("`@("`@*"1D969?<V5A<F-H(#T@)'!R969S+3YG971686QU92@G9&5F
M875L=%]S96%R8V@G*2DI('L*("`@("`@("`D<V5A<F-H6R=F:65L9"==(#T@
M87)R87DH)&1E9E]S96%R8V@I.PH@("`@?2!E;'-E('L*("`@("`@("`D<V5A
M<F-H6R=F:65L9"==(#T@571I;#HZ9V5T1F]R;41A=&$H)V9I96QD)RP@87)R
M87DH*2D["B`@("`@("`@:68@*"%E;7!T>2@D<V5A<F-H6R=F:65L9"==*2`F
M)B`A96YD*"1S96%R8VA;)V9I96QD)UTI*2!["B`@("`@("`@("`@(&%R<F%Y
M7W!O<"@D<V5A<F-H6R=F:65L9"==*3L*("`@("`@("!]"B`@("!]"B`@("`D
M<V5A<F-H6R=F:65L9%]E;F0G72`](&-O=6YT*"1S96%R8VA;)V9I96QD)UTI
M.PH@("`@)'-E87)C:%LG;6%T8V@G72`](%5T:6PZ.F=E=$9O<FU$871A*"=S
M96%R8VA?;6%T8V@G*3L*("`@("1S96%R8VA;)W1E>'0G72`](%5T:6PZ.F=E
M=$9O<FU$871A*"=S96%R8VA?=&5X="<I.PH@("`@)'-E87)C:%LG=&5X=%]N
M;W0G72`](%5T:6PZ.F=E=$9O<FU$871A*"=S96%R8VA?=&5X=%]N;W0G*3L*
M("`@("1S96%R8VA;)V1A=&4G72`](%5T:6PZ.F=E=$9O<FU$871A*"=S96%R
M8VA?9&%T92<I.PH@("`@)'-E87)C:%LG9FQA9R==(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W-E87)C:%]F;&%G)RD["B`@("`D<V5A<F-H6R=F;VQD97)S)UT@
M/2!5=&EL.CIG971&;W)M1&%T82@G<V5A<F-H7V9O;&1E<G,G+"!A<G)A>2@I
M*3L*("`@("1S96%R8VA;)W-A=F5?=F9O;&1E<B==(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W-A=F5?=F9O;&1E<B<I.PH@("`@)'-E87)C:%LG=F9O;&1E<E]L
M86)E;"==(#T@571I;#HZ9V5T1F]R;41A=&$H)W9F;VQD97)?;&%B96PG*3L*
M("`@("1S96%R8VA;)VUB;W@G72`](%5T:6PZ.F=E=$9O<FU$871A*"=M8F]X
M)RP@)'-E87)C:%]M86EL8F]X*3L*?0H*)&-U<G)?9&%T92`](&=E=&1A=&4H
M*3L*"B\J(%)U;B!T:')O=6=H('1H92!A8W1I;VX@:&%N9&QE<G,N("HO"G-W
M:71C:"`H)&%C=&EO;DE$*2!["F-A<V4@)V1O7W-E87)C:"<Z"B`@("`O*B!#
M<F5A=&4@=&AE('-E87)C:"!Q=65R>2X@*B\*("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+TE-05`O4V5A<F-H+G!H<"<["B`@("`D<75E<GD@
M/2`F;F5W($E-4%])34%07U-E87)C:%]1=65R>2@I.PH*("`@("\J($9L86<@
M<V5A<F-H97,N("HO"B`@("`D9FQA9U]N86UE<R`](&%R<F%Y*`H@("`@("`@
M($E-4%]314%20TA?1DQ!1U]3145.(#T^("=S965N)RP*("`@("`@("!)35!?
M4T5!4D-(7T9,04=?04Y35T52140@/3X@)V%N<W=E<F5D)RP*("`@("`@("!)
M35!?4T5!4D-(7T9,04=?1DQ!1T=%1"`]/B`G9FQA9V=E9"<L"B`@("`@("`@
M24U07U-%05)#2%]&3$%'7T1%3$54140@/3X@)V1E;&5T960G"B`@("`I.PH*
M("`@(&9O<F5A8V@@*"1S96%R8VA;)V9L86<G72!A<R`D:V5Y(#T^("1V86PI
M('L*("`@("`@("`D9FQA9R`]("1F;&%G7VYA;65S6R1K97E=.PH@("`@("`@
M('-W:71C:"`H)'9A;"D@>PH@("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@
M)'%U97)Y+3XD9FQA9RAT<G5E*3L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@8V%S92`Q.@H@("`@("`@("`@("`D<75E<GDM/B1F;&%G*&9A;'-E*3L*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J($9I
M96QD('-E87)C:&5S+B`J+PH@("`@)'-E87)C:%]A<G)A>2`](&%R<F%Y*"D[
M"B`@("!F;W)E86-H("@D<V5A<F-H6R=F:65L9"==(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("1O8B`]("9N97<@24U07TE-05!?4V5A<F-H7U%U97)Y
M*"D["B`@("`@("`@<W=I=&-H("@D:6UP7W-E87)C:%]F:65L9'-;)'9A;%U;
M)W1Y<&4G72D@>PH@("`@("`@(&-A<V4@24U07U-%05)#2%](14%$15(Z"B`@
M("`@("`@("`@(&EF("@A96UP='DH)'-E87)C:%LG=&5X="==6R1K97E=*2D@
M>PH@("`@("`@("`@("`@("`@)&]B+3YH96%D97(H)'9A;"P@)'-E87)C:%LG
M=&5X="==6R1K97E=+"`D<V5A<F-H6R=T97AT7VYO="==6R1K97E=*3L*("`@
M("`@("`@("`@("`@("1S96%R8VA?87)R87E;72`]("8D;V(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24U07U-%
M05)#2%]"3T19.@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1S96%R8VA;)W1E
M>'0G75LD:V5Y72DI('L*("`@("`@("`@("`@("`@("1O8BT^8F]D>2@D<V5A
M<F-H6R=T97AT)UU;)&ME>5TL("1S96%R8VA;)W1E>'1?;F]T)UU;)&ME>5TI
M.PH@("`@("`@("`@("`@("`@)'-E87)C:%]A<G)A>5M=(#T@)B1O8CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)
M35!?4T5!4D-(7U1%6%0Z"B`@("`@("`@("`@(&EF("@A96UP='DH)'-E87)C
M:%LG=&5X="==6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)&]B+3YT97AT
M*"1S96%R8VA;)W1E>'0G75LD:V5Y72P@)'-E87)C:%LG=&5X=%]N;W0G75LD
M:V5Y72D["B`@("`@("`@("`@("`@("`D<V5A<F-H7V%R<F%Y6UT@/2`F)&]B
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E($E-4%]314%20TA?1$%413H*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M<V5A<F-H6R=D871E)UU;)&ME>5U;)V1A>2==*2`F)@H@("`@("`@("`@("`@
M("`@(65M<'1Y*"1S96%R8VA;)V1A=&4G75LD:V5Y75LG;6]N=&@G72D@)B8*
M("`@("`@("`@("`@("`@("%E;7!T>2@D<V5A<F-H6R=D871E)UU;)&ME>5U;
M)WEE87(G72DI('L*("`@("`@("`@("`@("`@(&EF("@D=F%L(#T]("=R96-E
M:79E9%]O;B<I('L*("`@("`@("`@("`@("`@("`@("`D;V(M/F]N*"1S96%R
M8VA;)V1A=&4G75LD:V5Y75LG9&%Y)UTL("1S96%R8VA;)V1A=&4G75LD:V5Y
M75LG;6]N=&@G72P@)'-E87)C:%LG9&%T92==6R1K97E=6R=Y96%R)UTI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1V86P@/3T@)W)E8V5I=F5D7W5N
M=&EL)RD@>PH@("`@("`@("`@("`@("`@("`@("1O8BT^8F5F;W)E*"1S96%R
M8VA;)V1A=&4G75LD:V5Y75LG9&%Y)UTL("1S96%R8VA;)V1A=&4G75LD:V5Y
M75LG;6]N=&@G72P@)'-E87)C:%LG9&%T92==6R1K97E=6R=Y96%R)UTI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1V86P@/3T@)W)E8V5I=F5D7W-I
M;F-E)RD@>PH@("`@("`@("`@("`@("`@("`@("1O8BT^<VEN8V4H)'-E87)C
M:%LG9&%T92==6R1K97E=6R=D87DG72P@)'-E87)C:%LG9&%T92==6R1K97E=
M6R=M;VYT:"==+"`D<V5A<F-H6R=D871E)UU;)&ME>5U;)WEE87(G72D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<V5A<F-H7V%R<F%Y
M6UT@/2`F)&]B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*("`@('T*"B`@("`O*B!396%R8V@@;6%T8V@N("HO"B`@("!I
M9B`H)'-E87)C:%LG;6%T8V@G72`]/2`G86YD)RD@>PH@("`@("`@("1Q=65R
M>2T^:6UA<$%N9"@D<V5A<F-H7V%R<F%Y*3L*("`@('T@96QS96EF("@D<V5A
M<F-H6R=M871C:"==(#T]("=O<B<I('L*("`@("`@("`D<75E<GDM/FEM87!/
M<B@D<V5A<F-H7V%R<F%Y*3L*("`@('T*"B`@("`O*B!3879E('1H92!S96%R
M8V@@87,@82!V:7)T=6%L(&9O;&1E<B!I9B!R97%U97-T960N("HO"B`@("!I
M9B`H(65M<'1Y*"1S96%R8VA;)W-A=F5?=F9O;&1E<B==*2D@>PH@("`@("`@
M(&EF("AE;7!T>2@D<V5A<F-H6R=V9F]L9&5R7VQA8F5L)UTI*2!["B`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B5FER='5A;"!&;VQD97)S
M(')E<75I<F4@82!L86)E;"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@:68@*"1E9&ET7W%U97)Y
M7VED*2!["B`@("`@("`@("`@("1I;7!?<V5A<F-H+3YD96QE=&5396%R8VA1
M=65R>2@D961I=%]Q=65R>5]I9"D["B`@("`@("`@?0H@("`@("`@("1I9"`]
M("1I;7!?<V5A<F-H+3YA9&161F]L9&5R*"1Q=65R>2P@)'-E87)C:%LG9F]L
M9&5R<R==+"`D<V5A<F-H+"`D<V5A<F-H6R=V9F]L9&5R7VQA8F5L)UTI.PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")6:7)T=6%L
M($9O;&1E<B!<(B5S7"(@8W)E871E9"!S=6-C97-F=6QL>2XB*2P@)'-E87)C
M:%LG=F9O;&1E<E]L86)E;"==*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T@
M96QS92!["B`@("`@("`@+RH@4V5T('1H92!S96%R8V@@:6X@=&AE($E-4"!S
M97-S:6]N+B`J+PH@("`@("`@("1I9"`]("1I;7!?<V5A<F-H+3YC<F5A=&53
M96%R8VA1=65R>2@D<75E<GDL("1S96%R8VA;)V9O;&1E<G,G72P@)'-E87)C
M:"P@7R@B4V5A<F-H(%)E<W5L=',B*2D["B`@("!]"@H@("`@+RH@4F5D:7)E
M8W0@=&\@=&AE($UA:6QB;W@@4V-R965N+B`J+PH@("`@:&5A9&5R*"=,;V-A
M=&EO;CH@)R`N(%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ87!P;&EC871I
M;VY5<FPH)VUA:6QB;W@N<&AP)RP@=')U92DL("=M86EL8F]X)RP@24U07U-%
M05)#2%]-0D]8("X@)&ED+"!F86QS92DI.PH@("`@97AI=#L*"F-A<V4@)W)E
M<V5T7W-E87)C:"<Z"B`@("!I9B`H)&1E9E]S96%R8V@@/2`D<')E9G,M/F=E
M=%9A;'5E*"=D969A=6QT7W-E87)C:"<I*2!["B`@("`@("`@)'-E87)C:%LG
M9FEE;&0G72`](&%R<F%Y*"1D969?<V5A<F-H*3L*("`@("`@("`D<V5A<F-H
M6R=F:65L9%]E;F0G72`](#$["B`@("!](&5L<V4@>PH@("`@("`@("1S96%R
M8VA;)V9I96QD)UT@/2!A<G)A>2@I.PH@("`@("`@("1S96%R8VA;)V9I96QD
M7V5N9"==(#T@,#L*("`@('T*("`@("1S96%R8VA;)VUA=&-H)UT@/2!N=6QL
M.PH@("`@)'-E87)C:%LG9&%T92==(#T@)'-E87)C:%LG=&5X="==(#T@)'-E
M87)C:%LG=&5X=%]N;W0G72`]("1S96%R8VA;)V9L86<G72`](&%R<F%Y*"D[
M"B`@("`D<V5A<F-H6R=F;VQD97)S)UT@/2!A<G)A>2@I.PH@("`@8G)E86L[
M"@IC87-E("=D96QE=&5?9FEE;&0G.@H@("`@)&ME>2`](%5T:6PZ.F=E=$9O
M<FU$871A*"=D96QE=&5?9FEE;&1?:60G*3L*"B`@("`O*B!5;G-E="!A;&P@
M96YT<FEE<R!I;B!A<G)A>2!I;G!U="!A;F0@<F5A9&IU<W0@:61S+B`J+PH@
M("`@)'9A<G,@/2!A<G)A>2@G9FEE;&0G+"`G=&5X="<L("=T97AT7VYO="<L
M("=D871E)RD["B`@("!F;W)E86-H("@D=F%R<R!A<R`D=F%L*2!["B`@("`@
M("`@=6YS970H)'-E87)C:%LD=F%L75LD:V5Y72D["B`@("`@("`@:68@*"%E
M;7!T>2@D<V5A<F-H6R1V86Q=*2D@>PH@("`@("`@("`@("`D<V5A<F-H6R1V
M86Q=(#T@87)R87E?=F%L=65S*"1S96%R8VA;)'9A;%TI.PH@("`@("`@('T*
M("`@('T*("`@("1S96%R8VA;)V9I96QD7V5N9"==(#T@8V]U;G0H)'-E87)C
M:%LG9FEE;&0G72D["B`@("!B<F5A:SL*?0H*)'-U8G-C<FEB92`](#`["FEF
M("@A)&-O;F9;)W5S97(G75LG86QL;W=?9F]L9&5R<R==*2!["B`@("`D<V5A
M<F-H6R=M8F]X)UT@/2`G24Y"3U@G.PH@("`@)'-E87)C:%LG9F]L9&5R<R==
M6UT@/2`G24Y"3U@G.PH@("`@)'-U8G-C<FEB92`](&9A;'-E.PI](&5L<V5I
M9B`H)'-U8G-C<FEB92`]("1P<F5F<RT^9V5T5F%L=64H)W-U8G-C<FEB92<I
M*2!["B`@("`D<VAO=VX@/2!5=&EL.CIG971&;W)M1&%T82@G<VAO=U]S=6)S
M8W)I8F5D7V]N;'DG+"`D<W5B<V-R:6)E*3L*?0H*)'1I=&QE(#T@7R@B365S
M<V%G92!396%R8V@B*3L*:68@*"1E9&ET7W%U97)Y7VED*2!["B`@("`D<W5B
M;6ET7VQA8F5L(#T@7R@B4V%V92(I.PI](&5L<V4@>PH@("`@)'-U8FUI=%]L
M86)E;"`](%\H(E-U8FUI="(I.PI]"G)E<75I<F4@24U07U1%35!,051%4R`N
M("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($E-4%]414U03$%415,@
M+B`G+VUE;G4N:6YC)SL*24U0.CIS=&%T=7,H*3L*<F5Q=6ER92!)35!?5$5-
M4$Q!5$53("X@)R]S96%R8V@O:F%V87-C<FEP="YI;F,G.PIR97%U:7)E($E-
M4%]414U03$%415,@+B`G+W-E87)C:"]H96%D97(N:6YC)SL*"B\J(%!R;V-E
M<W,@=&AE(&QI<W0@;V8@9FEE;&1S+B`J+PIF;W(@*"1I(#T@,#L@)&D@/#T@
M)'-E87)C:%LG9FEE;&1?96YD)UT[("1I*RLI('L*("`@("1L87-T7V9I96QD
M(#T@*"1I(#T]("1S96%R8VA;)V9I96QD7V5N9"==*3L*("`@("1C=7)R7V9I
M96QD(#T@*&ES<V5T*"1S96%R8VA;)V9I96QD)UU;)&E=*2D@/R`D<V5A<F-H
M6R=F:65L9"==6R1I72`Z(&YU;&P["B`@("!R97%U:7)E($E-4%]414U03$%4
M15,@+B`G+W-E87)C:"]F:65L9',N:6YC)SL*?0H*)&YE=V-O;"`](#$["B1N
M=6UC;VQU;6YS(#T@,3L*)&9O;&1E<FQI<W0@/2`G)SL*)&EM<%]F;VQD97(@
M/2`F24U07T9O;&1E<CHZ<VEN9VQE=&]N*"D["@II9B`H96UP='DH)'-E87)C
M:%LG;6)O>"==*2D@>PH@("`@)&UA:6QB;WAE<R`]("1I;7!?9F]L9&5R+3YF
M;&ES=%])35`H87)R87DH*2P@*&ES<V5T*"1S:&]W;BDI(#\@*&)O;VPI("1S
M:&]W;B`Z(&YU;&PI.PH@("`@)'1O=&%L(#T@8V5I;"AC;W5N="@D;6%I;&)O
M>&5S*2`O(#,I.PH*("`@(&EF("AE;7!T>2@D<V5A<F-H6R=F;VQD97)S)UTI
M("8F("@D86-T:6]N240@(3T@)W5P9&%T95]S96%R8V@G*2D@>PH@("`@("`@
M("\J($1E9F%U;'0@=&\@26YB;W@@<V5A<F-H+B`J+PH@("`@("`@("1S96%R
M8VA;)V9O;&1E<G,G75M=(#T@)TE.0D]8)SL*("`@('T*"B`@("`D8V]U;G0@
M/2`P.PH@("`@9F]R96%C:"`H)&UA:6QB;WAE<R!A<R`D;6)O>"D@>PH@("`@
M("`@("1N97=C;VPK*SL*("`@("`@("!I9B`H(65M<'1Y*"1M8F]X6R=V86PG
M72DI('L*("`@("`@("`@("`@)&9O;&1E<FQI<W0@+CT@)SQI;G!U="!I9#TB
M9F]L9&5R)R`N("1C;W5N="`N("<B('1Y<&4](F-H96-K8F]X(B!N86UE/2)S
M96%R8VA?9F]L9&5R<UM=(B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H
M)&UB;WA;)W9A;"==*2`N("<B)SL*("`@("`@("`@("`@:68@*&EN7V%R<F%Y
M*"1M8F]X6R=V86PG72P@)'-E87)C:%LG9F]L9&5R<R==*2D@>PH@("`@("`@
M("`@("`@("`@)&9O;&1E<FQI<W0@+CT@)R!C:&5C:V5D/2)C:&5C:V5D(B<[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9F]L9&5R;&ES="`N/2`G/&EN<'5T(&ED/2)F;VQD97(G("X@)&-O=6YT("X@
M)R(@='EP93TB8VAE8VMB;W@B(&1I<V%B;&5D/2)D:7-A8FQE9"(G.PH@("`@
M("`@('T*"B`@("`@("`@)&9O;&1E<FQI<W0@+CT@(B`O/EQN(B`N($AO<F1E
M.CIL86)E;"@G9F]L9&5R)R`N("1C;W5N="LK+"!S=')?<F5P;&%C92@G("<L
M("<F;F)S<#LG+"`D;6)O>%LG;&%B96PG72DL("<G*2`N("(\8G(@+SY<;B([
M"@H@("`@("`@(&EF("@H)&YE=V-O;"`^("1T;W1A;"D@)B8@*"1N=6UC;VQU
M;6YS("$](#,I*2!["B`@("`@("`@("`@("1N97=C;VP@/2`Q.PH@("`@("`@
M("`@("`D;G5M8V]L=6UN<RLK.PH@("`@("`@("`@("`D9F]L9&5R;&ES="`N
M/2`B/"]T9#Y<;B(@+B`G/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG;B(@=F%L
M:6=N/2)T;W`B/B<["B`@("`@("`@?0H@("`@?0I]"@IR97%U:7)E($E-4%]4
M14U03$%415,@+B`G+W-E87)C:"]M86EN+FEN8R<["G)E<75I<F4@)')E9VES
M=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O
M=&5R+FEN8R<["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O<V%V96EM86=E+G!H<```````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#,W`#$P
M-#$W,S8R-S<P`#`Q-S8V,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!I;7`O<V%V96EM
M86=E+G!H<"QV(#$N,2XR+C,@,C`P-B\P,2\Q.2`P-SHP.#HP,"!S;'5S87)Z
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&)I9W=O<FTN8W5R96-A;G1I+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M
M;"X*("HO"@I`9&5F:6YE*"=)35!?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M*3L*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-24U%+T-O;G1E;G1S+G!H
M<"<["@HD:60@/2!5=&EL.CIG971&;W)M1&%T82@G:60G*3L*)&EN9&5X(#T@
M571I;#HZ9V5T1F]R;41A=&$H)VEN9&5X)RD["@HO*B!2=6X@=&AR;W5G:"!T
M:&4@86-T:6]N(&AA;F1L97)S+B`J+PHD86-T:6]N240@/2!5=&EL.CIG971&
M;W)M1&%T82@G86-T:6]N240G*3L*<W=I=&-H("@D86-T:6]N240I('L*8V%S
M92`G<V%V95]I;6%G92<Z"B`@("`D8V]N=&5N=',@/2`F24U07T-O;G1E;G1S
M.CIS:6YG;&5T;VXH)&EN9&5X("X@24U07TE$6%]315`@+B`D7U-%4U-)3TY;
M)VEM<"==6R=T:&ES;6%I;&)O>"==*3L*("`@("1M:6UE7W!A<G0@/2`D8V]N
M=&5N=',M/F=E=$1E8V]D961-24U%4&%R="@D:60I.PH@("`@)&EM86=E7V1A
M=&$@/2!A<G)A>2@*("`@("`@("`G9FEL96YA;64G(#T^("1M:6UE7W!A<G0M
M/F=E=$YA;64H=')U92P@=')U92DL"B`@("`@("`@)V1E<V-R:7!T:6]N)R`]
M/B`D;6EM95]P87)T+3YG971$97-C<FEP=&EO;BAT<G5E*2P*("`@("`@("`G
M9&%T82<@/3X@)&UI;65?<&%R="T^9V5T0V]N=&5N=',H*2P*("`@("`@("`G
M='EP92<@/3X@)&UI;65?<&%R="T^9V5T5'EP92@I"B`@("`I.PH@("`@)')E
M<R`]("1R96=I<W1R>2T^8V%L;"@G:6UA9V5S+W-A=F5);6%G92<L(&%R<F%Y
M*&YU;&PL(%5T:6PZ.F=E=$9O<FU$871A*"=G86QL97)Y)RDL("1I;6%G95]D
M871A*2D["B`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!B<F5A:SL*("`@('T*("`@(%5T:6PZ.F-L;W-E5VEN9&]W
M2E,H*3L*("`@(&5X:70["GT*"B\J($)U:6QD('1H92!L:7-T(&]F(&=A;&QE
M<FEE<RX@*B\*)&=A;&QE<GEL:7-T(#T@)')E9VES=')Y+3YC86QL*"=I;6%G
M97,O<V5L96-T1V%L;&5R:65S)RD["@HD=&ET;&4@/2!?*")3879E($EM86=E
M(BD["G)E<75I<F4@24U07U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI
M;F,G.PI)35`Z.G-T871U<R@I.PIR97%U:7)E($E-4%]414U03$%415,@+B`G
M+W-A=F5I;6%G92]S879E:6UA9V4N:6YC)SL*<F5Q=6ER92`D<F5G:7-T<GDM
M/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:6UP+W)E9&ER96-T+G!H<```````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S<T,@`Q,#0Q-S,V
M,C<W,``P,3<U,C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:6UP+W)E9&ER96-T+G!H
M<"QV(#$N,3$V+C(N,3$@,C`P-B\P,B\P,R`Q.3HR,#HQ,2!S;'5S87)Z($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*B\*
M"F9U;F-T:6]N(%]F<F%M97-E=%5R;"@D=7)L*0I["B`@("!I9B`H571I;#HZ
M9V5T1F]R;41A=&$H)VQO861?9G)A;65S970G*2D@>PH@("`@("`@("1F=6QL
M7W5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+VEN9&5X+G!H<"<L
M('1R=64I.PH@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&9U
M;&Q?=7)L+"`G=7)L)RP@)'5R;"P@9F%L<V4I.PH@("`@?0H@("`@<F5T=7)N
M("1U<FP["GT*"F9U;F-T:6]N(%]N97=397-S:6]N57)L*"1A8W1I;VY)1"P@
M)&ES3&]G:6XI"GL*("`@("1U<FP@/2`G)SL*"B`@("!I9B`H571I;#HZ9V5T
M1F]R;41A=&$H)W5R;"<I*2!["B`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH
M571I;#HZ<F5M;W9E4&%R86UE=&5R*%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG
M*2P@<V5S<VEO;E]N86UE*"DI+"!T<G5E*3L*("`@('T@96QS96EF("A!=71H
M.CIG9710<F]V:61E<B@I(#T]("=I;7`G*2!["B`@("`@("`@)'5R;"`]($AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+R<L('1R=64I.PH@("`@("`@("\J
M($9O<F-E('1H92!I;FET:6%L('!A9V4@=&\@24U0(&EF('=E)W)E(&QO9V=I
M;F<@:6X@=&\@8V]M<&]S92!A"B`@("`@("`@("H@;65S<V%G92X@*B\*("`@
M("`@("!I9B`H)&%C=&EO;DE$(#T]("=L;V=I;E]C;VUP;W-E)RD@>PH@("`@
M("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=U<FPG
M+"!)35!?4V5S<VEO;CHZ9V5T26YI=&EA;%5R;"@G;&]G:6Y?8V]M<&]S92<L
M(&9A;'-E*2D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`D=7)L
M(#T@24U07U-E<W-I;VXZ.F=E=$EN:71I86Q5<FPH)&%C=&EO;DE$+"!F86QS
M92D["B`@("`@("`@:68@*"1I<TQO9VEN*2!["B`@("`@("`@("`@("\J($1O
M;B=T('-H;W<@<&]P=7`@=VEN9&]W(&EN(&EN:71I86P@<&%G92X@*B\*("`@
M("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;F]?
M;F5W;6%I;%]P;W!U<"<L(#$L(&9A;'-E*3L*("`@("`@("!]"B`@("!]"@H@
M("`@:68@*"1A8W1I;VY)1"D@>PH@("`@("`@("\J(%!R97-E<G9E('1H92!A
M8W1I;VY)1"X@*B\*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL("=A8W1I;VY)1"<L("1A8W1I;VY)1"P@9F%L<V4I.PH@("`@?0H*
M("`@(')E='5R;B`D=7)L.PI]"@IF=6YC=&EO;B!?<F5D:7)E8W0H)'5R;"D*
M>PH@("`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FES0G)O=W-E<B@G;7-I
M92<I("8F"B`@("`@("`@)$=,3T)!3%-;)V-O;F8G75LG=7-E7W-S;"==(#T]
M(#,@)B8*("`@("`@("!S=')L96XH)'5R;"D@/"`Q-C`I('L*("`@("`@("!H
M96%D97(H)U)E9G)E<V@Z(#`[(%523#TG("X@)'5R;"D["B`@("!](&5L<V4@
M>PH@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@('T*
M("`@(&5X:70["GT*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`
M9&5F:6YE*"=)35!?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*)&%U=&AE
M;G1I8V%T:6]N(#T@)VYO;F4G.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB
M+U-E<W-I;VXN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-86EN=&5N86YC
M92YP:'`G.PH*)&%C=&EO;DE$(#T@*%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I
M;VXG*2`]/2`G8V]M<&]S92<I(#\@)VQO9VEN7V-O;7!O<V4G(#H@571I;#HZ
M9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD["B1A=71O;&]G:6X@/2!5=&EL.CIG
M971&;W)M1&%T82@G875T;VQO9VEN)RD["B1I;6%P=7-E<B`](&5M<'1Y*"1A
M=71O;&]G:6XI(#\@571I;#HZ9V5T4&]S="@G:6UA<'5S97(G*2`Z($%U=&@Z
M.F=E=$)A<F5!=71H*"D["B1P87-S(#T@96UP='DH)&%U=&]L;V=I;BD@/R!5
M=&EL.CIG9710;W-T*"=P87-S)RD@.B!!=71H.CIG971#<F5D96YT:6%L*"=P
M87-S=V]R9"<I.PHD:7-,;V=I;B`]($E-4#HZ;&]G:6Y487-K<T9L86<H*3L*
M"B\J($EF('=E(&%R92!R971U<FYI;F<@9G)O;2!-86EN=&5N86YC92!P<F]C
M97-S:6YG+B`J+PII9B`H571I;#HZ9V5T1F]R;41A=&$H34%)3E1%3D%.0T5?
M1$].15]005)!32DI('L*("`@("\J($9I;FES:"!U<"!A;GD@;&]G:6X@=&%S
M:W,@=V4@:&%V96XG="!C;VUP;&5T960@>65T+B`J+PH@("`@24U07U-E<W-I
M;VXZ.FQO9VEN5&%S:W,H*3L*"B`@("!?<F5D:7)E8W0H7V9R86UE<V5T57)L
M*%]N97=397-S:6]N57)L*"1A8W1I;VY)1"P@)&ES3&]G:6XI*2D["GT*"B\J
M($EF('=E(&%L<F5A9'D@:&%V92!A('-E<W-I;VXZ("HO"FEF("AI<W-E="@D
M7U-%4U-)3TY;)VEM<"==*2`F)B!I<U]A<G)A>2@D7U-%4U-)3TY;)VEM<"==
M*2D@>PH@("`@+RH@36%K92!S=7)E('1H870@:68@82!U<V5R;F%M92!W87,@
M<W!E8VEF:65D+"!I="!I<R!T:&4@8W5R<F5N=`H@("`@("H@=7-E<FYA;64N
M("HO"B`@("!I9B`H*"1I;6%P=7-E<B`A/3T@;G5L;"`F)B`H)&EM87!U<V5R
M(#T]("1?4T534TE/3ELG:6UP)UU;)W5S97(G72DI("8F"B`@("`@("`@*"1P
M87-S("$]/2!N=6QL("8F("@D<&%S<R`]/2!396-R970Z.G)E860H4V5C<F5T
M.CIG971+97DH)VEM<"<I+"`D7U-%4U-)3TY;)VEM<"==6R=P87-S)UTI*2DI
M('L*"B`@("`@("`@+RH@1&ES86)L92!T:&4@;VQD('-E<W-I;VXN("HO"B`@
M("`@("`@=6YS970H)%]315-324].6R=I;7`G72D["B`@("`@("`@7W)E9&ER
M96-T*$%U=&@Z.F%D9$QO9V]U=%!A<F%M971E<G,H24U0.CIL;V=O=715<FPH
M*2P@05542%]214%33TY?1D%)3$5$*2D["B`@("!]"@H@("`@+RH@1FEN:7-H
M('5P(&%N>2!L;V=I;B!T87-K<R!W92!H879E;B=T(&-O;7!L971E9"!Y970N
M("HO"B`@("!)35!?4V5S<VEO;CHZ;&]G:6Y487-K<R@I.PH*("`@("1U<FP@
M/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD["B`@("!I9B`H96UP='DH)'5R
M;"DI('L*("`@("`@("`D=7)L(#T@24U07U-E<W-I;VXZ.F=E=$EN:71I86Q5
M<FPH)&%C=&EO;DE$+"!F86QS92D["B`@("!](&5L<V5I9B`H(65M<'1Y*"1A
M8W1I;VY)1"DI('L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL("=A8W1I;VY)1"<L("1A8W1I;VY)1"P@9F%L<V4I.PH@("`@?0H*
M("`@("\J($1O;B=T('-H;W<@<&]P=7`@=VEN9&]W(&EN(&EN:71I86P@<&%G
M92X@*B\*("`@(&EF("@D:7-,;V=I;BD@>PH@("`@("`@("1U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H)'5R;"P@)VYO7VYE=VUA:6Q?<&]P=7`G+"`Q+"!F
M86QS92D["B`@("!]"@H@("`@7W)E9&ER96-T*%]F<F%M97-E=%5R;"@D=7)L
M*2D["GT*"B\J($-R96%T92!A(&YE=R!S97-S:6]N(&EF('=E)W)E(&=I=F5N
M('1H92!P<F]P97(@<&%R86UE=&5R<RX@*B\*:68@*"@A:7-?;G5L;"@D:6UA
M<'5S97(I("8F("%I<U]N=6QL*"1P87-S*2DI('L*("`@(&EF("A!=71H.CIG
M9710<F]V:61E<B@I(#T]("=I;7`G*2!["B`@("`@("`@+RH@1&5S=')O>2!A
M;GD@97AI<W1I;F<@<V5S<VEO;B!O;B!L;V=I;B!A;F0@;6%K92!S=7)E('1O
M('5S90H@("`@("`@("`J(&$@;F5W('-E<W-I;VX@240L('1O(&%V;VED('-E
M<W-I;VX@9FEX871I;VX@:7-S=65S+B`J+PH@("`@("`@($AO<F1E.CIG971#
M;&5A;E-E<W-I;VXH*3L*("`@('T*"B`@("`O*B!296%D('1H92!R97%U:7)E
M9"!S97)V97(@<&%R86UE=&5R<R!F<F]M('1H92!S97)V97)S+G!H<`H@("`@
M("H@9FEL92X@*B\*("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O8V]N
M9FEG+W-E<G9E<G,N<&AP)SL*("`@("1S97)V97)?:V5Y(#T@571I;#HZ9V5T
M1F]R;41A=&$H)W-E<G9E<E]K97DG+"!)35`Z.F=E=$%U=&],;V=I;E-E<G9E
M<BAT<G5E*2D["B`@("!I9B`H(65M<'1Y*"1S97)V97)S6R1S97)V97)?:V5Y
M72DI('L*("`@("`@("`D<V5S<T%R<F%Y(#T@)'-E<G9E<G-;)'-E<G9E<E]K
M97E=.PH@("`@?0H*("`@("\J($EF('=E)W)E(&YO="!U<VEN9R!H;W)D96%U
M=&@@9V5T('!A<F%M971E<G,@86QT97)E9"!F<F]M('1H92!D969A=6QT<PH@
M("`@("H@9G)O;2!T:&4@9F]R;2!D871A+B`J+PH@("`@:68@*&5M<'1Y*"1A
M=71O;&]G:6XI*2!["B`@("`@("`@9F]R96%C:"`H87)R87DH)W-E<G9E<B<L
M("=P;W)T)RP@)W!R;W1O8V]L)RP@)V9O;&1E<G,G+"`G<VUT<&AO<W0G+"`G
M<VUT<'!O<G0G*2!A<R`D=F%L*2!["B`@("`@("`@("`@("1D871A(#T@571I
M;#HZ9V5T1F]R;41A=&$H)'9A;"D["B`@("`@("`@("`@(&EF("@A96UP='DH
M)&1A=&$I*2!["B`@("`@("`@("`@("`@("`D<V5S<T%R<F%Y6R1V86Q=(#T@
M)&1A=&$["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!](&5L<V4@>PH@
M("`@("`@(&EF("@A96UP='DH)'-E<W-!<G)A>5LG:&]R9&5A=71H)UTI*2![
M"B`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1S97-S07)R87E;)VAO<F1E
M875T:"==+"`G9G5L;"<I(#T](#`I('L*("`@("`@("`@("`@("`@("1I;6%P
M=7-E<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1E;G1R>2`]('-P<FEN=&8H)TEN=F%L
M:60@<V5R=F5R(&ME>2`B)7,B(&9R;VT@8VQI96YT(%LE<UTG+"`D<V5R=F5R
M7VME>2P@)%]315)615);)U)%34]415]!1$12)UTI.PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@D96YT<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?24Y&3RD["B`@("`@("`@?0H@("`@?0H*("`@(&EF("@A96UP
M='DH)'-E<W-!<G)A>2D@)B8*("`@("`@("!)35!?4V5S<VEO;CHZ8W)E871E
M4V5S<VEO;B@D:6UA<'5S97(L("1P87-S+"`D<V5S<T%R<F%Y6R=S97)V97(G
M72P@)'-E<W-!<G)A>2DI('L*("`@("`@("`D96YT<GD@/2!S<')I;G1F*"=,
M;V=I;B!S=6-C97-S(&9O<B`E<R!;)7-=('1O('LE<SHE<WTG+"`D:6UP6R=U
M;FEQ=7-E<B==+"`D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72P@)&EM<%LG<V5R
M=F5R)UTL("1I;7!;)W!O<G0G72D["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)&5N=')Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TY/5$E#
M12D["@H@("`@("`@("1I95]V97)S:6]N(#T@571I;#HZ9V5T1F]R;41A=&$H
M)VEE7W9E<G-I;VXG*3L*("`@("`@("!I9B`H)&EE7W9E<G-I;VXI('L*("`@
M("`@("`@("`@)&)R;W=S97(M/G-E=$E%5F5R<VEO;B@D:65?=F5R<VEO;BD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H*"1H;W)D95]L86YG=6%G92`](%5T
M:6PZ.F=E=$9O<FU$871A*"=N97=?;&%N9R<I*2D@>PH@("`@("`@("`@("`D
M7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UT@/2`D:&]R9&5?;&%N9W5A9V4[
M"B`@("`@("`@?0H*("`@("`@("!)35!?4V5S<VEO;CHZ;&]G:6Y487-K<R@I
M.PH*("`@("`@("`D=7)L(#T@7VYE=U-E<W-I;VY5<FPH)&%C=&EO;DE$+"`D
M:7-,;V=I;BD["B`@("!](&5L<V4@>PH@("`@("`@("1U<FP@/2!!=71H.CIA
M9&1,;V=O=71087)A;65T97)S*$E-4#HZ;&]G;W5T57)L*"DI.PH@("`@?0H*
M("`@(%]R961I<F5C="A?9G)A;65S9715<FPH)'5R;"DI.PI]"@HO*B!.;R!S
M97-S:6]N+"!A;F0@;F\@;&]G:6X@871T96UP="X@2G5S="!G;R!T;R!T:&4@
M;&]G:6X@<&%G92X@*B\*<F5Q=6ER92!)35!?0D%312`N("<O;&]G:6XN<&AP
M)SL*````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]I;7`O<F5C;VUP;W-E+G!H<```````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,38V`#$P-#$W,S8R-S<P
M`#`Q-S<Q-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!I;7`O<F5C;VUP;W-E+G!H<"QV
M(#(N,3,N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C4R(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!?9V5T
M1F]R;41A=&$H)'9A;"D*>PH@("`@<W1A=&EC("1F9#L*("`@(&EF("@A:7-S
M970H)&9D*2D@>PH@("`@("`@(&=L;V)A;"`D9F]R;41A=&$["B`@("`@("`@
M)&9D(#T@0'5N<V5R:6%L:7IE*"1F;W)M1&%T82D["B`@("!]"@H@("`@:68@
M*"%E;7!T>2@D9F1;)W!O<W0G75LD=F%L72DI('L*("`@("`@("!R971U<FX@
M)&9D6R=P;W-T)UU;)'9A;%T["B`@("!](&5L<V5I9B`H(65M<'1Y*"1F9%LG
M9V5T)UU;)'9A;%TI*2!["B`@("`@("`@<F5T=7)N("1F9%LG9V5T)UU;)'9A
M;%T["B`@("!](&5L<V4@>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*?0H*
M0&1E9FEN92@G24U07T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["B1A=71H
M96YT:6-A=&EO;B`]("=N;VYE)SL*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@
M)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI
M8B]397-S:6]N+G!H<"<["G)E<75I<F4@24U07T)!4T4@+B`G+V-O;F9I9R]S
M97)V97)S+G!H<"<["@HO+R!)9B!W92!S;VUE:&]W(&=E="!T;R!T:&ES('!A
M9V4@=VET:"!A('9A;&ED('-E<W-I;VXL(&=O(&EM;65D:6%T96QY"B\O('1O
M(&-O;7!O<V4N<&AP+B!.;R!N965D('1O(&1O(&]T:&5R('9A;&ED:71Y(&-H
M96-K<R!I9B!T:&4@<V5S<VEO;@HO+R!A;')E861Y(&5X:7-T<RX*:68@*$%U
M=&@Z.F=E=$%U=&@H*2`F)B!)35`Z.F-H96-K075T:&5N=&EC871I;VXH3U!?
M2$%,1D]014XL('1R=64I*2!["B`@("`D7U-%4U-)3TY;)V9O<FU$871A)UT@
M/2!S97)I86QI>F4H87)R87DH)V=E="<@/3X@)%]'150L("=P;W-T)R`]/B`D
M7U!/4U0I*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!5=&EL.CIA9&10
M87)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=C;VUP;W-E+G!H<"<L
M('1R=64I+"`G86-T:6]N240G+"`G<F5C;VUP;W-E)RP@9F%L<V4I*3L*("`@
M(&5X:70["GT*"B\O($-H96-K(&9O<B!A(&QO9VEN(&%T=&5M<'0N"FEF("A5
M=&EL.CIG9710;W-T*"=I;6%P=7-E<B<I*2!["B`@("`D:6UA<'5S97(@/2!5
M=&EL.CIG9710;W-T*"=I;6%P=7-E<B<I.PH@("`@)'!A<W,@/2!5=&EL.CIG
M9710;W-T*"=P87-S)RD["@H@("`@+RH@0W)E871E(&$@;F5W('-E<W-I;VX@
M:68@=V4G<F4@9VEV96X@=&AE('!R;W!E<B!P87)A;65T97)S+B`J+PH@("`@
M:68@*"%I<U]N=6QL*"1I;6%P=7-E<BD@)B8@(6ES7VYU;&PH)'!A<W,I*2![
M"B`@("`@("`@:68@*$%U=&@Z.F=E=%!R;W9I9&5R*"D@/3T@)VEM<"<I('L*
M("`@("`@("`@("`@+RH@1&5S=')O>2!A;GD@97AI<W1I;F<@<V5S<VEO;B!O
M;B!L;V=I;B!A;F0@;6%K92!S=7)E('1O"B`@("`@("`@("`@("`J('5S92!A
M(&YE=R!S97-S:6]N($E$+"!T;R!A=F]I9"!S97-S:6]N(&9I>&%T:6]N"B`@
M("`@("`@("`@("`J(&ES<W5E<RX@*B\*("`@("`@("`@("`@2&]R9&4Z.F=E
M=$-L96%N4V5S<VEO;B@I.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5A9"!T
M:&4@<F5Q=6ER960@<V5R=F5R('!A<F%M971E<G,@9G)O;2!T:&4@<V5R=F5R
M<RYP:'`*("`@("`@("`@*B!F:6QE+B`J+PH@("`@("`@(')E<75I<F5?;VYC
M92!)35!?0D%312`N("<O8V]N9FEG+W-E<G9E<G,N<&AP)SL*("`@("`@("`D
M<V5R=F5R7VME>2`](%5T:6PZ.F=E=$9O<FU$871A*"=S97)V97)?:V5Y)RD[
M"B`@("`@("`@:68@*"%E;7!T>2@D<V5R=F5R<ULD<V5R=F5R7VME>5TI*2![
M"B`@("`@("`@("`@("1S97-S07)R87D@/2`D<V5R=F5R<ULD<V5R=F5R7VME
M>5T["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("AA<G)A>2@G<V5R=F5R
M)RP@)W!O<G0G+"`G<')O=&]C;VPG+"`G9F]L9&5R<R<I(&%S("1V86PI('L*
M("`@("`@("`@("`@)&1A=&$@/2!5=&EL.CIG971&;W)M1&%T82@D=F%L*3L*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D9&%T82DI('L*("`@("`@("`@("`@
M("`@("1S97-S07)R87E;)'9A;%T@/2`D9&%T83L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*$E-4%]397-S:6]N.CIC<F5A=&5397-S
M:6]N*"1I;6%P=7-E<BP@)'!A<W,L("1S97-S07)R87E;)W-E<G9E<B==+"`D
M<V5S<T%R<F%Y*2D@>PH@("`@("`@("`@("`D96YT<GD@/2!S<')I;G1F*"=2
M96QO9VEN('-U8V-E<W,@9F]R("5S(%LE<UT@=&\@>R5S.B5S?2<L("1I;7!;
M)W5N:7%U<V5R)UTL("1?4T525D526R=214U/5$5?041$4B==+"`D:6UP6R=S
M97)V97(G72P@)&EM<%LG<&]R="==*3L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)&5N=')Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7TY/5$E#12D["@H@("`@("`@("`@("!I9B`H*"1H;W)D95]L86YG=6%G92`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=N97=?;&%N9R<I*2D@>PH@("`@("`@("`@
M("`@("`@)%]315-324].6R=H;W)D95]L86YG=6%G92==(#T@)&AO<F1E7VQA
M;F=U86=E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3=&]R92!T
M:&4@=7-E<B=S(&UE<W-A9V4@9&%T82!I;B!T:&5I<B!S97-S:6]N+"!S;R!T
M:&%T"B`@("`@("`@("`@("\O('=E(&-A;B!R961I<F5C="!T;R!C;VUP;W-E
M+G!H<"X@5&AI<R!I;G-U<F5S('1H870*("`@("`@("`@("`@+R\@979E<GET
M:&EN9R!G971S(&QO861E9"!W:71H(&$@<')O<&5R('-E<W-I;VX@<')E<V5N
M="P*("`@("`@("`@("`@+R\@=VAI8V@@8V%N(&%F9F5C="!T:&EN9W,@;&EK
M92!T:&4@=7-E<B=S('!R969E<F5N8V5S+@H@("`@("`@("`@("`D7U-%4U-)
M3TY;)V9O<FU$871A)UT@/2!5=&EL.CIG9710;W-T*"=F;W)M1&%T82<I.PH@
M("`@("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@571I;#HZ861D4&%R
M86UE=&5R*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G8V]M<&]S92YP:'`G+"!T
M<G5E*2P@)V%C=&EO;DE$)RP@)W)E8V]M<&]S92<L(&9A;'-E*2D["B`@("`@
M("`@("`@(&5X:70["B`@("`@("`@?0H@("`@?0I]"@HD86-T:6]N240@/2!N
M=6QL.PHD:6UP7V%U=&@@/2`H075T:#HZ9V5T4')O=FED97(H*2`]/2`G:6UP
M)RD["B1F;W)M06-T:6]N(#T@)W)E8V]M<&]S92YP:'`G.PHD9F]R;41A=&$@
M/2!5=&EL.CIG9710;W-T*"=F;W)M1&%T82<L('-E<FEA;&EZ92AA<G)A>2@G
M9V5T)R`]/B`D7T=%5"P@)W!O<W0G(#T^("1?4$]35"DI*3L*"B1R96%S;VX@
M/2!?*")0;&5A<V4@;&]G(&EN(&%G86EN('1O(')E<W5M92!C;VUP;W-I;F<@
M>6]U<B!M97-S86=E+B!)9B!Y;W4@87)E($Y/5"!U<VEN9R!C;V]K:65S($%.
M1"!Y;W4@87)E(&-O;7!O<VEN9R!M97-S86=E<R!I;B!P;W!U<"!W:6YD;W=S
M+"!Y;W4@=VEL;"!H879E('1O(&QO9R!I;B!A9V%I;B!I;B!Y;W5R(&UA:6X@
M=VEN9&]W(&%S('=E;&PN(%1H:7,@:7,@=&\@:V5E<"!A='1A8VME<G,@9G)O
M;2!H:6IA8VMI;F<@>6]U<B!S97-S:6]N($E$+B!792!A<&]L;V=I>F4@9F]R
M(&%N>2!I;F-O;G9E;FEE;F-E+B(I.PHD=&ET;&4@/2!?*")297-U;64@>6]U
M<B!S97-S:6]N(BD["@IR97%U:7)E($E-4%]414U03$%415,@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)SL*:68@*$%U=&@Z.F=E=%!R;W9I9&5R*"D@/3T@)VEM
M<"<@?'P@075T:#HZ9V5T075T:"@I*2!["B`@("`D875T;VQO9VEN(#T@9F%L
M<V4["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*("`@(')E
M<75I<F4@24U07U1%35!,051%4R`N("<O;&]G:6XO;&]G:6XN:6YC)SL*?0IR
M97%U:7)E($E-4%]414U03$%415,@+B`G+V-O;7!O<V4O<F5C;VUP;W-E+FEN
M8R<["FEF("A`:7-?<F5A9&%B;&4H24U07T)!4T4@+B`G+V-O;F9I9R]M;W1D
M+G!H<"<I*2!["B`@("!R97%U:7)E($E-4%]"05-%("X@)R]C;VYF:6<O;6]T
M9"YP:'`G.PI]"G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L
M("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]P9W`N<&AP````````````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C<Q-3(`,3`T,3<S-C(W-S``,#$V-3$S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&EM<"]P9W`N<&AP+'8@,BXW.2XV+C<@,C`P-B\P
M,B\Q,"`Q-CHU,#HS,"!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L
M;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*B\*"F9U;F-T:6]N(%]P<FEN=$ME
M>4EN9F\H)&ME>2`]("<G*0I["B`@("`D:V5Y7VEN9F\@/2`D1TQ/0D%,4ULG
M:6UP7W!G<"==+3YP9W!0<F5T='E+97DH)&ME>2D["@H@("`@:68@*&5M<'1Y
M*"1K97E?:6YF;RDI('L*("`@("`@("!?=&5X=%=I;F1O=T]U='!U="@G4$=0
M($ME>2!);F9O<FUA=&EO;B<L(%\H(DEN=F%L:60@:V5Y(BDI.PH@("`@?2!E
M;'-E('L*("`@("`@("!?=&5X=%=I;F1O=T]U='!U="@G4$=0($ME>2!);F9O
M<FUA=&EO;B<L("1K97E?:6YF;RD["B`@("!]"GT*"F9U;F-T:6]N(%]O=71P
M=71087-S<&AR87-E1&EA;&]G*"D*>PH@("`@9VQO8F%L("1N;W1I9FEC871I
M;VXL("1P<F5F<RP@)')E9VES=')Y+"`D<V5C=7)E7V-H96-K+"`D<V5L9E52
M3#L*"B`@("!I9B`H:7-?82@D<V5C=7)E7V-H96-K+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<V5C=7)E7V-H96-K
M+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@?0H*("`@("1T:71L92`](%\H(E!'
M4"!087-S<&AR87-E($EN<'5T(BD["B`@("!R97%U:7)E($E-4%]414U03$%4
M15,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*("`@("1S=6)M:71?=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1S96QF55),+"`G86-T:6]N240G+"`G<')O
M8V5S<U]P87-S<&AR87-E7V1I86QO9R<I.PH@("`@24U0.CIS=&%T=7,H*3L*
M("`@(')E<75I<F4@24U07U1%35!,051%4R`N("<O<&=P+W!A<W-P:')A<V4N
M:6YC)SL*?0H*9G5N8W1I;VX@7VEM<&]R=$ME>41I86QO9R@D=&%R9V5T*0I[
M"B`@("!G;&]B86P@)&%C=&EO;DE$+"`D;F]T:69I8V%T:6]N+"`D<')E9G,L
M("1R96=I<W1R>2P@)'-E;&954DP["@H@("`@)'1I=&QE(#T@7R@B26UP;W)T
M(%!'4"!+97DB*3L*("`@(')E<75I<F4@24U07U1%35!,051%4R`N("<O8V]M
M;6]N+6AE861E<BYI;F,G.PH@("`@24U0.CIS=&%T=7,H*3L*("`@(')E<75I
M<F4@24U07U1%35!,051%4R`N("<O<&=P+VEM<&]R=%]K97DN:6YC)SL*?0H*
M9G5N8W1I;VX@7V%C=&EO;E=I;F1O=R@I"GL*("`@("1O:60@/2!5=&EL.CIG
M971&;W)M1&%T82@G<&%S<W!H<F%S95]A8W1I;VXG*3L*("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O4V5S<VEO;D]B:F5C=',N<&AP)SL*("`@("1C86-H95-E
M<W,@/2`F2&]R9&5?4V5S<VEO;D]B:F5C=',Z.G-I;F=L971O;B@I.PH@("`@
M)&-A8VAE4V5S<RT^<V5T4')U;F5&;&%G*"1O:60L('1R=64I.PH@("`@571I
M;#HZ8VQO<V57:6YD;W=*4R@D8V%C:&5397-S+3YQ=65R>2@D;VED*2D["GT*
M"F9U;F-T:6]N(%]R96QO8617:6YD;W<H*0I["B`@("!5=&EL.CIC;&]S95=I
M;F1O=TI3*"=O<&5N97(N9F]C=7,H*3MO<&5N97(N;&]C871I;VXN:')E9CTB
M)R`N(%5T:6PZ.F=E=$9O<FU$871A*"=R96QO860G*2`N("<B.R<I.PI]"@IF
M=6YC=&EO;B!?9V5T26UP;W)T2V5Y*"D*>PH@("`@)&ME>2`](%5T:6PZ.F=E
M=$9O<FU$871A*"=I;7!O<G1?:V5Y)RD["B`@("!I9B`H(65M<'1Y*"1K97DI
M*2!["B`@("`@("`@<F5T=7)N("1K97D["B`@("!]"@H@("`@)')E<R`]($)R
M;W=S97(Z.G=A<T9I;&55<&QO861E9"@G=7!L;V%D7VME>2<L(%\H(FME>2(I
M*3L*("`@(&EF("@A:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@<F5T=7)N(&9I;&5?9V5T7V-O;G1E;G1S*"1?1DE,15-;)W5P;&]A9%]K
M97DG75LG=&UP7VYA;64G72D["B`@("!](&5L<V4@>PH@("`@("`@("1'3$]"
M04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"@D<F5S+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!R971U<FX["B`@("!]"GT*"F9U;F-T:6]N(%]T97AT5VEN
M9&]W3W5T<'5T*"1F:6QE;F%M92P@)&US9RD*>PH@("`@)$=,3T)!3%-;)V)R
M;W=S97(G72T^9&]W;FQO861(96%D97)S*"1F:6QE;F%M92P@)W1E>'0O<&QA
M:6X[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I+"!T<G5E+"!S=')L
M96XH)&US9RDI.PH@("`@96-H;R`D;7-G.PI]"@H*0&1E9FEN92@G24U07T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!)35!?0D%3
M12`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@
M)R]L:6(O0W)Y<'0O4$=0+G!H<"<["@HD:6UP7W!G<"`]("9N97<@24U07U!'
M4"@I.PHD<V5C=7)E7V-H96-K(#T@)&EM<%]P9W`M/G)E<75I<F5396-U<F5#
M;VYN96-T:6]N*"D["B1S96QF55),(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"=P9W`N<&AP)RD["@HO*B!2=6X@=&AR;W5G:"!T:&4@86-T:6]N(&AA;F1L
M97)S("HO"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)
M1"<I.PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=G96YE<F%T95]K97DG
M.@H@("`@+RH@0VAE8VL@=&AA="!F:65L9',@87)E(&9I;&QE9"!O=70@*&5X
M8V5P="!F;W(@0V]M;65N="D@86YD('1H870@=&AE"B`@("`@("!P87-S<&AR
M87-E<R!M871C:"X@*B\*("`@("1R96%L;F%M92`](%5T:6PZ.F=E=$9O<FU$
M871A*"=G96YE<F%T95]R96%L;F%M92<I.PH@("`@)&5M86EL(#T@571I;#HZ
M9V5T1F]R;41A=&$H)V=E;F5R871E7V5M86EL)RD["B`@("`D8V]M;65N="`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=G96YE<F%T95]C;VUM96YT)RD["B`@("`D
M:V5Y;&5N9W1H(#T@571I;#HZ9V5T1F]R;41A=&$H)V=E;F5R871E7VME>6QE
M;F=T:"<I.PH@("`@)'!A<W-P:')A<V4Q(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V=E;F5R871E7W!A<W-P:')A<V4Q)RD["B`@("`D<&%S<W!H<F%S93(@/2!5
M=&EL.CIG971&;W)M1&%T82@G9V5N97)A=&5?<&%S<W!H<F%S93(G*3L*"B`@
M("!I9B`H96UP='DH)')E86QN86UE*2!\?"!E;7!T>2@D96UA:6PI*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*").86UE(&%N9"]O<B!E;6%I
M;"!C86YN;W0@8F4@96UP='DB*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L
M<V5I9B`H96UP='DH)'!A<W-P:')A<V4Q*2!\?"!E;7!T>2@D<&%S<W!H<F%S
M93(I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")087-S<&AR
M87-E<R!C86YN;W0@8F4@96UP='DB*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]
M(&5L<V5I9B`H)'!A<W-P:')A<V4Q("$]/2`D<&%S<W!H<F%S93(I('L*("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!A<W-P:')A<V5S(&1O(&YO
M="!M871C:"(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92!["B`@("`@
M("`@)')E<W5L="`]("1I;7!?<&=P+3YG96YE<F%T95!E<G-O;F%L2V5Y<R@D
M<F5A;&YA;64L("1E;6%I;"P@)'!A<W-P:')A<V4Q+"`D8V]M;65N="P@)&ME
M>6QE;F=T:"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1R97-U
M;'0L("1R97-U;'0M/F=E=$-O9&4H*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")097)S;VYA;"!01U`@
M:V5Y<&%I<B!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(I+"`G:&]R9&4N<W5C
M8V5S<R<I.PH@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G9&5L
M971E7VME>2<Z"B`@("`D:6UP7W!G<"T^9&5L971E4&5R<V]N86Q+97ES*"D[
M"B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!E<G-O;F%L(%!'4"!K97ES
M(&1E;&5T960@<W5C8V5S<V9U;&QY+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@
M("`@8G)E86L["@IC87-E("=I;7!O<G1?<'5B;&EC7VME>2<Z"B`@("!?:6UP
M;W)T2V5Y1&EA;&]G*"=P<F]C97-S7VEM<&]R=%]P=6)L:6-?:V5Y)RD["B`@
M("!E>&ET.PH*8V%S92`G<')O8V5S<U]I;7!O<G1?<'5B;&EC7VME>2<Z"B`@
M("`D<'5B;&EC2V5Y(#T@7V=E=$EM<&]R=$ME>2@I.PH@("`@:68@*&5M<'1Y
M*"1P=6)L:6-+97DI*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?
M*").;R!01U`@<'5B;&EC(&ME>2!I;7!O<G1E9"XB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@)&%C=&EO;DE$(#T@)VEM<&]R=%]P=6)L:6-?:V5Y)SL*
M("`@("`@("!?:6UP;W)T2V5Y1&EA;&]G*"=P<F]C97-S7VEM<&]R=%]P=6)L
M:6-?:V5Y)RD["B`@("!](&5L<V4@>PH@("`@("`@("\J($%D9"!T:&4@<'5B
M;&EC(&ME>2!T;R!T:&4@<W1O<F%G92!S>7-T96TN("HO"B`@("`@("`@)&ME
M>5]I;F9O(#T@)&EM<%]P9W`M/F%D9%!U8FQI8TME>2@D<'5B;&EC2V5Y*3L*
M("`@("`@("!I9B`H:7-?82@D:V5Y7VEN9F\L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D:V5Y7VEN9F\L("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`D86-T:6]N240@/2`G:6UP;W)T
M7W!U8FQI8U]K97DG.PH@("`@("`@("`@("!?:6UP;W)T2V5Y1&EA;&]G*"=P
M<F]C97-S7VEM<&]R=%]P=6)L:6-?:V5Y)RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@9F]R96%C:"`H)&ME>5]I;F9O6R=S:6=N871U<F4G72!A
M<R`D<VEG*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7,@*"5S*5PB('=A
M<R!S=6-C97-S9G5L;'D@861D960N(BDL("1S:6=;)VYA;64G72P@)'-I9ULG
M96UA:6PG72DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@7W)E;&]A9%=I;F1O=R@I.PH@("`@("`@('T*("`@('T*("`@
M(&5X:70["@IC87-E("=I;7!O<G1?<&5R<V]N86Q?<'5B;&EC7VME>2<Z"B`@
M("!?:6UP;W)T2V5Y1&EA;&]G*"=P<F]C97-S7VEM<&]R=%]P97)S;VYA;%]P
M=6)L:6-?:V5Y)RD["B`@("!E>&ET.PH*8V%S92`G<')O8V5S<U]I;7!O<G1?
M<&5R<V]N86Q?<'5B;&EC7VME>2<Z"B`@("`D86-T:6]N240@/2`G:6UP;W)T
M7W!E<G-O;F%L7W!U8FQI8U]K97DG.PH@("`@+RH@0VAE8VL@=&AE('!U8FQI
M8R!K97DN("HO"B`@("!I9B`H(2@D<'5B;&EC2V5Y(#T@7V=E=$EM<&]R=$ME
M>2@I*2D@>PH@("`@("`@("\J($YO('!U8FQI8R!K97D@:6UP;W)T960@+2!2
M961O('!U8FQI8R!K97D@:6UP;W)T('-C<F5E;BX@*B\*("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*%\H(DYO('!E<G-O;F%L(%!'4"!P=6)L:6,@:V5Y
M(&EM<&]R=&5D+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!?:6UP;W)T
M2V5Y1&EA;&]G*"=P<F]C97-S7VEM<&]R=%]P97)S;VYA;%]P=6)L:6-?:V5Y
M)RD["B`@("!](&5L<V4@>PH@("`@("`@(&EF("@A*"1K97E?:6YF;R`]("1I
M;7!?<&=P+3YP9W!086-K971);F9O<FUA=&EO;B@D<'5B;&EC2V5Y*2D@?'P*
M("`@("`@("`@("`@(6ES<V5T*"1K97E?:6YF;ULG<'5B;&EC7VME>2==*2D@
M>PH@("`@("`@("`@("`O*B!);G9A;&ED('!U8FQI8R!K97D@:6UP;W)T960@
M+2!2961O('!U8FQI8R!K97D@:6UP;W)T('-C<F5E;BX@*B\*("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*"));G9A;&ED('!E<G-O;F%L(%!'
M4"!P=6)L:6,@:V5Y+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@
M7VEM<&]R=$ME>41I86QO9R@G<')O8V5S<U]I;7!O<G1?<&5R<V]N86Q?<'5B
M;&EC7VME>2<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%-U
M8V-E<W,@:6X@:6UP;W)T:6YG('!U8FQI8R!K97D@+2!-;W9E(&]N('1O('!R
M:79A=&4@:V5Y"B`@("`@("`@("`@("`J(&YO=RX@*B\*("`@("`@("`@("`@
M)&EM<%]P9W`M/F%D9%!E<G-O;F%L4'5B;&EC2V5Y*"1P=6)L:6-+97DI.PH@
M("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!'4"!P=6)L:6,@
M:V5Y('-U8V-E<W-F=6QL>2!A9&1E9"XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@("`@("`@("`@)&%C=&EO;DE$(#T@)VEM<&]R=%]P97)S;VYA;%]P<FEV
M871E7VME>2<["B`@("`@("`@("`@(%]I;7!O<G1+97E$:6%L;V<H)W!R;V-E
M<W-?:6UP;W)T7W!E<G-O;F%L7W!R:79A=&5?:V5Y)RD["B`@("`@("`@?0H@
M("`@?0H@("`@97AI=#L*"F-A<V4@)W!R;V-E<W-?:6UP;W)T7W!E<G-O;F%L
M7W!R:79A=&5?:V5Y)SH*("`@("1A8W1I;VY)1"`]("=I;7!O<G1?<&5R<V]N
M86Q?<')I=F%T95]K97DG.PH@("`@+RH@0VAE8VL@=&AE('!R:79A=&4@:V5Y
M+B`J+PH@("`@:68@*"$H)'!R:79A=&5+97D@/2!?9V5T26UP;W)T2V5Y*"DI
M*2!["B`@("`@("`@+RH@3F\@<')I=F%T92!K97D@:6UP;W)T960@+2!2961O
M('!R:79A=&4@:V5Y(&EM<&]R="!S8W)E96XN("HO"B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"A?*").;R!P97)S;VYA;"!01U`@<')I=F%T92!K97D@
M:6UP;W)T960N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@(%]I;7!O<G1+
M97E$:6%L;V<H)W!R;V-E<W-?:6UP;W)T7W!E<G-O;F%L7W!R:79A=&5?:V5Y
M)RD["B`@("!](&5L<V4@>PH@("`@("`@(&EF("@A*"1K97E?:6YF;R`]("1I
M;7!?<&=P+3YP9W!086-K971);F9O<FUA=&EO;B@D<')I=F%T94ME>2DI('Q\
M"B`@("`@("`@("`@("%I<W-E="@D:V5Y7VEN9F];)W-E8W)E=%]K97DG72DI
M('L*("`@("`@("`@("`@+RH@26YV86QI9"!P<FEV871E(&ME>2!I;7!O<G1E
M9"`M(%)E9&\@<')I=F%T92!K97D@:6UP;W)T"B`@("`@("`@("`@("`J('-C
M<F5E;BX@*B\*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*"))
M;G9A;&ED('!E<G-O;F%L(%!'4"!P<FEV871E(&ME>2XB*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@("`@(%]I;7!O<G1+97E$:6%L;V<H)W!R;V-E<W-?
M:6UP;W)T7W!E<G-O;F%L7W!R:79A=&5?:V5Y)RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+RH@4&5R<V]N86P@<'5B;&EC(&%N9"!P<FEV871E
M(&ME>7,@:&%V92!B965N(&EM<&]R=&5D"B`@("`@("`@("`@("`J('-U8V-E
M<W-F=6QL>2`M(&-L;W-E('1H92!I;7!O<G0@<&]P=7`@=VEN9&]W+B`J+PH@
M("`@("`@("`@("`D:6UP7W!G<"T^861D4&5R<V]N86Q0<FEV871E2V5Y*"1P
M<FEV871E2V5Y*3L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?
M*")01U`@<')I=F%T92!K97D@<W5C8V5S<V9U;&QY(&%D9&5D+B(I+"`G:&]R
M9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("!?<F5L;V%D5VEN9&]W*"D["B`@
M("`@("`@?0H@("`@?0H@("`@97AI=#L*"F-A<V4@)W9I97=?<'5B;&EC7VME
M>2<Z"B`@("`D:V5Y(#T@)&EM<%]P9W`M/F=E=%!U8FQI8TME>2A5=&EL.CIG
M971&;W)M1&%T82@G96UA:6PG*2D["B`@("!I9B`H:7-?82@D:V5Y+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@)&ME>2`]("1K97DM/F=E=$UE<W-A9V4H
M*3L*("`@('T*("`@(%]T97AT5VEN9&]W3W5T<'5T*"=01U`@4'5B;&EC($ME
M>2<L("1K97DI.PH@("`@97AI=#L*"F-A<V4@)W9I97=?<&5R<V]N86Q?<'5B
M;&EC7VME>2<Z"B`@("!?=&5X=%=I;F1O=T]U='!U="@G4$=0(%!E<G-O;F%L
M(%!U8FQI8R!+97DG+"`D:6UP7W!G<"T^9V5T4&5R<V]N86Q0=6)L:6-+97DH
M*2D["B`@("!E>&ET.PH*8V%S92`G:6YF;U]P=6)L:6-?:V5Y)SH*("`@("1K
M97D@/2`D:6UP7W!G<"T^9V5T4'5B;&EC2V5Y*%5T:6PZ.F=E=$9O<FU$871A
M*"=E;6%I;"<I*3L*("`@(&EF("AI<U]A*"1K97DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`D:V5Y(#T@)&ME>2T^9V5T365S<V%G92@I.PH@("`@?0H@
M("`@7W!R:6YT2V5Y26YF;R@D:V5Y*3L*("`@(&5X:70["@IC87-E("=I;F9O
M7W!E<G-O;F%L7W!U8FQI8U]K97DG.@H@("`@7W!R:6YT2V5Y26YF;R@D:6UP
M7W!G<"T^9V5T4&5R<V]N86Q0=6)L:6-+97DH*2D["B`@("!E>&ET.PH*8V%S
M92`G=FEE=U]P97)S;VYA;%]P<FEV871E7VME>2<Z"B`@("!?=&5X=%=I;F1O
M=T]U='!U="@G4$=0(%!E<G-O;F%L(%!R:79A=&4@2V5Y)RP@)&EM<%]P9W`M
M/F=E=%!E<G-O;F%L4')I=F%T94ME>2@I*3L*("`@(&5X:70["@IC87-E("=I
M;F9O7W!E<G-O;F%L7W!R:79A=&5?:V5Y)SH*("`@(%]P<FEN=$ME>4EN9F\H
M)&EM<%]P9W`M/F=E=%!E<G-O;F%L4')I=F%T94ME>2@I*3L*("`@(&5X:70[
M"@IC87-E("=D96QE=&5?<'5B;&EC7VME>2<Z"B`@("`D<F5S=6QT(#T@)&EM
M<%]P9W`M/F1E;&5T95!U8FQI8TME>2A5=&EL.CIG971&;W)M1&%T82@G96UA
M:6PG*2D["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S=6QT+"`D<F5S=6QT
M+3YG971#;V1E*"DI.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*'-P<FEN=&8H7R@B4$=0(%!U8FQI8R!+97D@9F]R(%PB)7-<
M(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(BDL(%5T:6PZ.F=E=$9O<FU$
M871A*"=E;6%I;"<I*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T*("`@(&)R
M96%K.PH*8V%S92`G<&=P7V5N86)L92<Z"B`@("`D<')E9G,M/G-E=%9A;'5E
M*"=U<V5?<&=P)RP@571I;#HZ9V5T1F]R;41A=&$H)W5S95]P9W`G*2D["B`@
M("!B<F5A:SL*"F-A<V4@)W-A=F5?;W!T:6]N<R<Z"B`@("`D<')E9G,M/G-E
M=%9A;'5E*"=U<V5?<&=P)RP@571I;#HZ9V5T1F]R;41A=&$H)W5S95]P9W`G
M*2D["B`@("`D<')E9G,M/G-E=%9A;'5E*"=P9W!?871T86-H7W!U8FME>2<L
M(%5T:6PZ.F=E=$9O<FU$871A*"=P9W!?871T86-H7W!U8FME>2<I*3L*("`@
M("1P<F5F<RT^<V5T5F%L=64H)W!G<%]S8V%N7V)O9'DG+"!5=&EL.CIG971&
M;W)M1&%T82@G<&=P7W-C86Y?8F]D>2<I*3L*("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H7R@B4')E9F5R96YC97,@<W5C8V5S<V9U;&QY('5P9&%T960N(BDL
M("=H;W)D92YS=6-C97-S)RD["B`@("!B<F5A:SL*"F-A<V4@)W-A=F5?871T
M86-H;65N=%]P=6)L:6-?:V5Y)SH*("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M4V5S<VEO;D]B:F5C=',N<&AP)SL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M34E-12]087)T+G!H<"<["@H@("`@+RH@4F5T<FEE=F4@=&AE(&ME>2!F<F]M
M('1H92!C86-H92X@*B\*("`@("1C86-H92`]("9(;W)D95]397-S:6]N3V)J
M96-T<SHZ<VEN9VQE=&]N*"D["B`@("`D;6EM95]P87)T(#T@)&-A8VAE+3YQ
M=65R>2A5=&EL.CIG971&;W)M1&%T82@G;6EM96-A8VAE)RDI.PH@("`@)&UI
M;65?<&%R="T^=')A;G-F97)$96-O9&5#;VYT96YT<R@I.PH*("`@("\J($%D
M9"!T:&4@<'5B;&EC(&ME>2!T;R!T:&4@<W1O<F%G92!S>7-T96TN("HO"B`@
M("`D:V5Y7VEN9F\@/2`D:6UP7W!G<"T^861D4'5B;&EC2V5Y*"1M:6UE7W!A
M<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@:68@*&ES7V$H)&ME>5]I;F9O+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D
M:V5Y7VEN9F\L("1K97E?:6YF;RT^9V5T0V]D92@I*3L*("`@('T@96QS92![
M"B`@("`@("`@571I;#HZ8VQO<V57:6YD;W=*4R@I.PH@("`@?0H@("`@97AI
M=#L*"F-A<V4@)V]P96Y?<&%S<W!H<F%S95]D:6%L;V<G.@H@("`@:68@*"1I
M;7!?<&=P+3YG971087-S<&AR87-E*"DI('L*("`@("`@("!5=&EL.CIC;&]S
M95=I;F1O=TI3*"D["B`@("!](&5L<V4@>PH@("`@("`@(%]O=71P=71087-S
M<&AR87-E1&EA;&]G*"D["B`@("!]"B`@("!E>&ET.PH*8V%S92`G<')O8V5S
M<U]P87-S<&AR87-E7V1I86QO9R<Z"B`@("!I9B`H:7-?82@D<V5C=7)E7V-H
M96-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@7V]U='!U=%!A<W-P:')A
M<V5$:6%L;V<H*3L*("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G
M<&%S<W!H<F%S92<I*2!["B`@("`@("`@:68@*"1I;7!?<&=P+3YS=&]R95!A
M<W-P:')A<V4H571I;#HZ9V5T1F]R;41A=&$H)W!A<W-P:')A<V4G*2DI('L*
M("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=P87-S<&AR87-E
M7V%C=&EO;B<I*2!["B`@("`@("`@("`@("`@("!?86-T:6]N5VEN9&]W*"D[
M"B`@("`@("`@("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G<F5L
M;V%D)RDI('L*("`@("`@("`@("`@("`@(%]R96QO8617:6YD;W<H*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(%5T:6PZ.F-L;W-E
M5VEN9&]W2E,H*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H(DEN=F%L:60@<&%S<W!H
M<F%S92!E;G1E<F5D+B(L("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!?
M;W5T<'5T4&%S<W!H<F%S941I86QO9R@I.PH@("`@("`@('T*("`@('T@96QS
M92!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@B3F\@<&%S<W!H<F%S
M92!E;G1E<F5D+B(L("=H;W)D92YE<G)O<B<I.PH@("`@("`@(%]O=71P=710
M87-S<&AR87-E1&EA;&]G*"D["B`@("!]"B`@("!E>&ET.PH*8V%S92`G=6YS
M971?<&%S<W!H<F%S92<Z"B`@("`D:6UP7W!G<"T^=6YS971087-S<&AR87-E
M*"D["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!A<W-P:')A<V4@<W5C
M8V5S<V9U;&QY('5N;&]A9&5D+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@
M8G)E86L["@IC87-E("=S96YD7W!U8FQI8U]K97DG.@H@("`@)')E<W5L="`]
M("1I;7!?<&=P+3YS96YD5&]0=6)L:6-+97ES97)V97(H)&EM<%]P9W`M/F=E
M=%!E<G-O;F%L4'5B;&EC2V5Y*"DI.PH@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M)')E<W5L="P@)')E<W5L="T^9V5T0V]D92@I*3L*("`@('T@96QS92!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")+97D@<W5C8V5S<V9U;&QY
M('-E;G0@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(BDL("=H;W)D92YS=6-C
M97-S)RD["B`@("!]"B`@("!B<F5A:SL*?0H*+RH@1V5T(&QI<W0@;V8@4'5B
M;&EC($ME>7,@;VX@:V5Y<FEN9RX@*B\*)'!U8FME>5]L:7-T(#T@)&EM<%]P
M9W`M/FQI<W10=6)L:6-+97ES*"D["FEF("AI<U]A*"1P=6)K97E?;&ES="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<'5B
M:V5Y7VQI<W0L("1P=6)K97E?;&ES="T^9V5T0V]D92@I*3L*?0H*+RH@1V5T
M('!A<W-P:')A<V4@*&EF(&%V86EL86)L92DN("HO"B1P87-S<&AR87-E(#T@
M)&EM<%]P9W`M/F=E=%!A<W-P:')A<V4H*3L*"G)E<75I<F4@24U07T)!4T4@
M+B`G+V-O;F9I9R]P<F5F<RYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U!R
M969S+U5)+G!H<"<["B1A<'`@/2`G:6UP)SL*4')E9G-?54DZ.F=E;F5R871E
M2&5A9&5R*"=P9W`G*3L*"B\J($EF(%!'4"!P<F5F97)E;F-E(&YO="!A8W1I
M=F4L(&1O($Y/5"!S:&]W(%!'4"!!9&UI;B!S8W)E96XN("HO"FEF("@D<')E
M9G,M/F=E=%9A;'5E*"=U<V5?<&=P)RDI('L*("`@("1O<&5N<&=P=VEN(#T@
M)&EM<%]P9W`M/F=E=$I33W!E;E=I;D-O9&4H)V]P96Y?<&%S<W!H<F%S95]D
M:6%L;V<G*3L*("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<I
M.PH@("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]P9W`O<&=P+FEN8R<[
M"GT@96QS92!["B`@("!R97%U:7)E($E-4%]414U03$%415,@+B`G+W!G<"]N
M;W1A8W1I=F4N:6YC)SL*?0H*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M
M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VUE<W-A9V4N<&AP````````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U-#4P-0`Q
M,#0Q-S,V,C<W,``P,3<S-3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:6UP+VUE<W-A
M9V4N<&AP+'8@,BXU-C`N-"XS-"`R,#`V+S`R+S(V(#(Q.C0Q.C4Y('-L=7-A
M<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN
M"B`J+PH*+RHJ"B`J(%-E="!P97)T:6YE;G0@=F%R:6%B;&5S(&9O<B!T:&4@
M;6%I;&)O>"YP:'`@<V-R:7!T+@H@*@H@*B!`<&%R86T@:6YT96=E<B`D<W1A
M<G1);F1E>"`@5&AE('-T87)T(&EN9&5X('1O('5S92X*("H@0'!A<F%M('-T
M<FEN9R`D86-T240@("`@("`@(%1H92!A8W1I;VX@240@=&\@=7-E+@H@*B\*
M9G5N8W1I;VX@7W)E='5R;E1O36%I;&)O>"@D<W1A<G1);F1E>"`](&YU;&PL
M("1A8W1)1"`](&YU;&PI"GL*("`@(&=L;V)A;"`D86-T:6]N240L("1F<F]M
M7VUE<W-A9V5?<&%G92P@)'-T87)T.PH*("`@("1A8W1I;VY)1"`](&YU;&P[
M"B`@("`D9G)O;5]M97-S86=E7W!A9V4@/2!T<G5E.PH@("`@)'-T87)T(#T@
M;G5L;#L*"B`@("!I9B`H(6ES7VYU;&PH)'-T87)T26YD97@I*2!["B`@("`@
M("`@)'-T87)T(#T@)'-T87)T26YD97@["B`@("!]"B`@("!I9B`H(6ES7VYU
M;&PH)&%C=$E$*2D@>PH@("`@("`@("1A8W1I;VY)1"`]("1A8W1)1#L*("`@
M('T*?0H*0&1E9FEN92@G24U07T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D[
M"G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q
M=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O34E-12]#;VYT96YT<RYP:'`G
M.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-24U%+TAE861E<G,N
M<&AP)SL*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O36%I;&)O>"YP
M:'`G.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]396%R8V@N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH*+RH@36%K
M92!S=7)E('=E(&AA=F4@82!V86QI9"!I;F1E>"X@*B\*)&EM<%]M86EL8F]X
M(#T@)DE-4%]-86EL8F]X.CIS:6YG;&5T;VXH571I;#HZ9V5T1F]R;41A=&$H
M)VEN9&5X)RDI.PII9B`H(21I;7!?;6%I;&)O>"T^:7-686QI9$EN9&5X*"DI
M('L*("`@(%]R971U<FY4;TUA:6QB;W@H;G5L;"P@)VUE<W-A9V5?;6ES<VEN
M9R<I.PH@("`@<F5Q=6ER92!)35!?0D%312`N("<O;6%I;&)O>"YP:'`G.PH@
M("`@97AI=#L*?0H*+RH@07)E('=E('5S:6YG('!R:6YT97(M9G)I96YD;'D@
M9F]R;6%T=&EN9S\@*B\*)'!R:6YT97)?9G)I96YD;'D@/2!F86QS93L*"B\J
M(%-E="!T:&4@8W5R<F5N="!T:6UE('IO;F4N("HO"DY,4SHZ<V5T5&EM95IO
M;F4H*3L*"B\J($EN:71I86QI>F4@=&AE('5S97(G<R!I9&5N=&ET:65S+B`J
M+PHD=7-E<E]I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*&%R<F%Y
M*"=I;7`G+"`G:6UP)RDI.PH*+RH@4G5N('1H<F]U9V@@86-T:6]N(&AA;F1L
M97)S+B`J+PHD86-T:6]N240@/2!5=&EL.CIG971&;W)M1&%T82@G86-T:6]N
M240G*3L*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G8FQA8VML:7-T)SH*
M8V%S92`G=VAI=&5L:7-T)SH*("`@(')E<75I<F5?;VYC92!)35!?0D%312`N
M("<O;&EB+T9I;'1E<BYP:'`G.PH@("`@)&EM<%]F:6QT97(@/2`F24U07T9I
M;'1E<CHZ<VEN9VQE=&]N*"D["B`@("`D:61X(#T@)&EM<%]M86EL8F]X+3YG
M971)34%026YD97@H*3L*("`@(&EF("@D86-T:6]N240@/3T@)V)L86-K;&ES
M="<I('L*("`@("`@("`D:6UP7V9I;'1E<BT^8FQA8VML:7-T365S<V%G92AA
M<G)A>2@D:61X6R=I;F1E>"==*2D["B`@("!](&5L<V4@>PH@("`@("`@("1I
M;7!?9FEL=&5R+3YW:&ET96QI<W1-97-S86=E*&%R<F%Y*"1I9'A;)VEN9&5X
M)UTI*3L*("`@('T*("`@(&)R96%K.PH*8V%S92`G<')I;G1?;65S<V%G92<Z
M"B`@("`D<')I;G1E<E]F<FEE;F1L>2`]('1R=64["B`@("!)35`Z.G!R:6YT
M36]D92AT<G5E*3L*("`@(&)R96%K.PH*8V%S92`G9&5L971E7VUE<W-A9V4G
M.@IC87-E("=U;F1E;&5T95]M97-S86=E)SH*("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+TUE<W-A9V4N<&AP)SL*("`@("1I;7!?;65S<V%G
M92`]("9)35!?365S<V%G93HZ<VEN9VQE=&]N*"D["B`@("!I9B`H)&%C=&EO
M;DE$(#T]("=U;F1E;&5T95]M97-S86=E)RD@>PH@("`@("`@("1I;7!?;65S
M<V%G92T^=6YD96QE=&4H)&EM<%]M86EL8F]X*3L*("`@('T@96QS92!["B`@
M("`@("`@)&EM<%]M97-S86=E+3YD96QE=&4H)&EM<%]M86EL8F]X*3L*("`@
M("`@("!I9B`H)'!R969S+3YG971686QU92@G;6%I;&)O>%]R971U<FXG*2D@
M>PH@("`@("`@("`@("!?<F5T=7)N5&]-86EL8F]X*"1I;7!?;6%I;&)O>"T^
M9V5T365S<V%G94EN9&5X*"DI.PH@("`@("`@("`@("!R97%U:7)E($E-4%]"
M05-%("X@)R]M86EL8F]X+G!H<"<["B`@("`@("`@("`@(&5X:70["B`@("`@
M("`@?0H@("`@?0H@("`@8G)E86L["@IC87-E("=M;W9E7VUE<W-A9V4G.@IC
M87-E("=C;W!Y7VUE<W-A9V4G.@H@("`@:68@*"@D=&%R9V5T36)O>"`](%5T
M:6PZ.F=E=$9O<FU$871A*"=T87)G971-8F]X)RDI("$]/2!N=6QL*2!["B`@
M("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O365S<V%G92YP
M:'`G.PH@("`@("`@("1I;7!?;65S<V%G92`]("9)35!?365S<V%G93HZ<VEN
M9VQE=&]N*"D["@H@("`@("`@("1A8W1I;VX@/2`H)&%C=&EO;DE$(#T]("=M
M;W9E7VUE<W-A9V4G*2`_($E-4%]-15-304=%7TU/5D4@.B!)35!?34534T%'
M15]#3U!9.PH*("`@("`@("!I9B`H)&-O;F9;)W1A<VML:7-T)UU;)W5S95]T
M87-K;&ES="==("8F"B`@("`@("`@("`@("AS=')P;W,H)'1A<F=E=$UB;W@L
M("=?=&%S:VQI<W1?)RD@/3T](#`I*2!["B`@("`@("`@("`@("\J($EF('1H
M92!T87)G970@:7,@82!T87-K;&ES="P@:&%N9&QE('1H92!M;W9E+V-O<'D@
M<W!E8VEA;&QY+B`J+PH@("`@("`@("`@("`D=&%S:VQI<W0@/2!S=')?<F5P
M;&%C92@G7W1A<VML:7-T7R<L("<G+"`D=&%R9V5T36)O>"D["B`@("`@("`@
M("`@("1I;7!?;65S<V%G92T^8W)E871E5&%S:W-/<DYO=&5S*"1T87-K;&ES
M="P@)&%C=&EO;BP@)&EM<%]M86EL8F]X+"`G=&%S:R<I.PH@("`@("`@('T@
M96QS96EF("@D8V]N9ELG;F]T97!A9"==6R=U<V5?;F]T97!A9"==("8F"B`@
M("`@("`@("`@("AS=')P;W,H)'1A<F=E=$UB;W@L("=?;F]T97!A9%\G*2`]
M/3T@,"DI('L*("`@("`@("`@("`@+RH@268@=&AE('1A<F=E="!I<R!A(&YO
M=&5P860L(&AA;F1L92!T:&4@;6]V92]C;W!Y('-P96-I86QL>2X@*B\*("`@
M("`@("`@("`@)&YO=&5P860@/2!S=')?<F5P;&%C92@G7VYO=&5P861?)RP@
M)R<L("1T87)G971-8F]X*3L*("`@("`@("`@("`@)&EM<%]M97-S86=E+3YC
M<F5A=&5487-K<T]R3F]T97,H)&YO=&5P860L("1A8W1I;VXL("1I;7!?;6%I
M;&)O>"P@)VYO=&4G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*B!/=&AE<G=I<V4L('1H92!T87)G970@:7,@82!S=&%N9&%R9"!M86EL8F]X
M+B`J+PH@("`@("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)VYE=TUB
M;W@G+"`P*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`D;F5W7VUA:6QB;W@@
M/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*$E-4#HZ9F]L9&5R4')E9B@D=&%R
M9V5T36)O>"P@=')U92DL($Y,4SHZ9V5T0VAA<G-E="@I+"`G551&-RU)34%0
M)RD["B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G
M+VQI8B]&;VQD97(N<&AP)SL*("`@("`@("`@("`@("`@("1I;7!?9F]L9&5R
M(#T@)DE-4%]&;VQD97(Z.G-I;F=L971O;B@I.PH@("`@("`@("`@("`@("`@
M:68@*"1I;7!?9F]L9&5R+3YC<F5A=&4H)&YE=U]M86EL8F]X+"`D<')E9G,M
M/F=E=%9A;'5E*"=S=6)S8W)I8F4G*2DI('L*("`@("`@("`@("`@("`@("`@
M("`D:6UP7VUE<W-A9V4M/F-O<'DH)&YE=U]M86EL8F]X+"`D86-T:6]N+"`D
M:6UP7VUA:6QB;W@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&EM<%]M97-S86=E+3YC;W!Y*"1T
M87)G971-8F]X+"`D86-T:6]N+"`D:6UP7VUA:6QB;W@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H
M)VUA:6QB;WA?<F5T=7)N)RDI('L*("`@("`@("!?<F5T=7)N5&]-86EL8F]X
M*"1I;7!?;6%I;&)O>"T^9V5T365S<V%G94EN9&5X*"DI.PH@("`@("`@(')E
M<75I<F4@24U07T)!4T4@+B`G+VUA:6QB;W@N<&AP)SL*("`@("`@("!E>&ET
M.PH@("`@?0H@("`@8G)E86L["@IC87-E("=S<&%M7W)E<&]R="<Z"F-A<V4@
M)VYO='-P86U?<F5P;W)T)SH*("`@("1A8W1I;VX@/2!S=')?<F5P;&%C92@G
M7W)E<&]R="<L("<G+"`D86-T:6]N240I.PH*("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+U-P86TN<&AP)SL*("`@("1I;7!?<W!A;2`]("9N
M97<@24U07U-P86TH*3L*("`@("1I;7!?<W!A;2T^<F5P;W)T4W!A;2@D:6UP
M7VUA:6QB;W@L("1A8W1I;VXI.PH*("`@("\J($1E;&5T92!S<&%M(&%F=&5R
M(')E<&]R="X@*B\*("`@("1D96QE=&5?<W!A;2`]("1P<F5F<RT^9V5T5F%L
M=64H)V1E;&5T95]S<&%M7V%F=&5R7W)E<&]R="<I.PH@("`@:68@*"1A8W1I
M;VX@/3T@)W-P86TG("8F("@D9&5L971E7W-P86T@/3T@,2DI('L*("`@("`@
M("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-97-S86=E+G!H<"<[
M"B`@("`@("`@)&EM<%]M97-S86=E(#T@)DE-4%]-97-S86=E.CIS:6YG;&5T
M;VXH*3L*("`@("`@("`D:6UP7VUE<W-A9V4M/F1E;&5T92@D:6UP7VUA:6QB
M;W@I.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B5&AE(&UE<W-A
M9V4@:&%S(&)E96X@9&5L971E9"XB*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@
M("`@("!I9B`H)'!R969S+3YG971686QU92@G;6%I;&)O>%]R971U<FXG*2D@
M>PH@("`@("`@("`@("!?<F5T=7)N5&]-86EL8F]X*"1I;7!?;6%I;&)O>"T^
M9V5T365S<V%G94EN9&5X*"DI.PH@("`@("`@("`@("!R97%U:7)E($E-4%]"
M05-%("X@)R]M86EL8F]X+G!H<"<["B`@("`@("`@("`@(&5X:70["B`@("`@
M("`@?0H@("`@?2!E;'-E:68@*"1D96QE=&5?<W!A;2`]/2`R*2!["B`@("`@
M("`@)'1A<F=E=$UB;W@@/2`H)&%C=&EO;B`]/2`G<W!A;2<I(#\@24U0.CIF
M;VQD97)0<F5F*"1P<F5F<RT^9V5T5F%L=64H)W-P86U?9F]L9&5R)RDL('1R
M=64I(#H@)TE.0D]8)SL*("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@
M+B`G+VQI8B]-97-S86=E+G!H<"<["B`@("`@("`@)&EM<%]M97-S86=E(#T@
M)DE-4%]-97-S86=E.CIS:6YG;&5T;VXH*3L*("`@("`@("`D:6UP7VUE<W-A
M9V4M/F-O<'DH)'1A<F=E=$UB;W@L($E-4%]-15-304=%7TU/5D4L("1I;7!?
M;6%I;&)O>"D["B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)VUA:6QB
M;WA?<F5T=7)N)RDI('L*("`@("`@("`@("`@7W)E='5R;E1O36%I;&)O>"@D
M:6UP7VUA:6QB;W@M/F=E=$UE<W-A9V5);F1E>"@I*3L*("`@("`@("`@("`@
M<F5Q=6ER92!)35!?0D%312`N("<O;6%I;&)O>"YP:'`G.PH@("`@("`@("`@
M("!E>&ET.PH@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G9FQA
M9U]M97-S86=E)SH*("`@("1F;&%G(#T@571I;#HZ9V5T1F]R;41A=&$H)V9L
M86<G*3L*("`@(&EF("@D9FQA9RD@>PH@("`@("`@(&EF("@D9FQA9WLP?2`]
M/2`G,"<I('L*("`@("`@("`@("`@)&9L86<@/2`G7%PG("X@<W5B<W1R*"1F
M;&%G+"`Q*3L*("`@("`@("`@("`@)'-E="`](&9A;'-E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1F;&%G(#T@)UQ<)R`N("1F;&%G.PH@("`@
M("`@("`@("`D<V5T(#T@=')U93L*("`@("`@("!]"B`@("`@("`@<F5Q=6ER
M95]O;F-E($E-4%]"05-%("X@)R]L:6(O365S<V%G92YP:'`G.PH@("`@("`@
M("1I;7!?;65S<V%G92`]("9)35!?365S<V%G93HZ<VEN9VQE=&]N*"D["B`@
M("`@("`@)&EM<%]M97-S86=E+3YF;&%G*"1F;&%G+"`D:6UP7VUA:6QB;W@L
M("1S970I.PH@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=M86EL8F]X
M7W)E='5R;B<I*2!["B`@("`@("`@("`@(%]R971U<FY4;TUA:6QB;W@H)&EM
M<%]M86EL8F]X+3YG971-97-S86=E26YD97@H*2D["B`@("`@("`@("`@(')E
M<75I<F4@24U07T)!4T4@+B`G+VUA:6QB;W@N<&AP)SL*("`@("`@("`@("`@
M97AI=#L*("`@("`@("!]"B`@("`@("`@)&EM<%]M86EL8F]X+3YM;W9E3F5X
M="@I.PH@("`@?0H@("`@8G)E86L["@IC87-E("=A9&1?861D<F5S<R<Z"B`@
M("`D8V]N=&%C=%]L:6YK(#T@24U0.CIA9&1!9&1R97-S*%5T:6PZ.F=E=$9O
M<FU$871A*"=A9&1R97-S)RDL(%5T:6PZ.F=E=$9O<FU$871A*"=N86UE)RDI
M.PH@("`@:68@*&ES7V$H)&-O;G1A8W1?;&EN:RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&-O;G1A8W1?;&EN:RD[
M"B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")%;G1R>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!T:&4@861D<F5S<R!B;V]K(BDL("1C;VYT86-T7VQI;FLI+"`G:&]R9&4N
M<W5C8V5S<R<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@('T*("`@(&)R
M96%K.PH*8V%S92`G<W1R:7!?871T86-H;65N="<Z"B`@("!R97%U:7)E7V]N
M8V4@24U07T)!4T4@+B`G+VQI8B]-97-S86=E+G!H<"<["B`@("`D:6UP7VUE
M<W-A9V4@/2`F24U07TUE<W-A9V4Z.G-I;F=L971O;B@I.PH@("`@)')E<W5L
M="`]("1I;7!?;65S<V%G92T^<W1R:7!087)T*"1I;7!?;6%I;&)O>"P@571I
M;#HZ9V5T1F]R;41A=&$H)VEM87!I9"<I*3L*("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*"1R97-U;'0L("=H;W)D92YE<G)O<B<I.PH@("`@?0H*("`@(&)R96%K
M.PI]"@II9B`H)&-O;F9;)W5S97(G75LG86QL;W=?9F]L9&5R<R==*2!["B`@
M("`D;W!T:6]N<R`]($E-4#HZ9FQI<W1396QE8W0H7R@B5&AI<R!M97-S86=E
M('1O(BDL('1R=64L(&%R<F%Y*&YU;&PL("1I;7!;)VUA:6QB;W@G72DL(&YU
M;&PL('1R=64L('1R=64L(&9A;'-E+"!T<G5E*3L*?0H*+RH@5V4@;6%Y(&AA
M=F4@9&]N92!P<F]C97-S:6YG('1H870@:&%S('1A:V5N('5S('!A<W0@=&AE
M(&5N9"!O9B!T:&4*("H@;65S<V%G92!A<G)A>2P@<V\@=V4@=VEL;"!R971U
M<FX@=&\@;6%I;&)O>"YP:'`@:68@=&AA="!I<R!T:&4*("H@8V%S92X@*B\*
M:68@*"$D:6UP7VUA:6QB;W@M/FES5F%L:61);F1E>"@I*2!["B`@("!?<F5T
M=7)N5&]-86EL8F]X*"1I;7!?;6%I;&)O>"T^9V5T365S<V%G94EN9&5X*"DI
M.PH@("`@<F5Q=6ER92!)35!?0D%312`N("<O;6%I;&)O>"YP:'`G.PH@("`@
M97AI=#L*?0H*+RH@3F]W('1H870@=V4@87)E(&1O;F4@<')O8V5S<VEN9R!T
M:&4@;65S<V%G97,L(&=E="!T:&4@:6YD97@@86YD"B`J(&%R<F%Y(&EN9&5X
M(&]F('1H92!C=7)R96YT(&UE<W-A9V4N("HO"B1I;F1E>%]A<G)A>2`]("1I
M;7!?;6%I;&)O>"T^9V5T24U!4$EN9&5X*"D["B1I;F1E>"`]("1I;F1E>%]A
M<G)A>5LG:6YD97@G73L*)&UA:6QB;WA?;F%M92`]("1I;F1E>%]A<G)A>5LG
M;6%I;&)O>"==.PHD87)R87E?:6YD97@@/2`D:6UP7VUA:6QB;W@M/F=E=$%R
M<F%Y26YD97@H*3L*"B\J($EF('=E(&=R86(@=&AE(&AE861E<G,@8F5F;W)E
M(&=R86)B:6YG(&)O9'D@<&%R=',L('=E)VQL('-E92!W:&5N(&$*("H@;65S
M<V%G92!I<R!U;G)E860N("HO"B1I;7!?:&5A9&5R<R`]("9N97<@24U07TAE
M861E<G,H)&EN9&5X*3L*)&EM<%]H96%D97)S+3YB=6EL9$AE861E<G,H*3L*
M)&EM<%]H96%D97)S+3YB=6EL9$9L86=S*"D["B1I;7!?:&5A9&5R<U]C;W!Y
M(#T@)E5T:6PZ.F-L;VYE3V)J96-T*"1I;7!?:&5A9&5R<RD["@HO*B!087)S
M92!-24U%(&EN9F\@86YD(&-R96%T92!T:&4@8F]D>2!O9B!T:&4@;65S<V%G
M92X@*B\*)&EM<%]C;VYT96YT<R`]("9)35!?0V]N=&5N=',Z.G-I;F=L971O
M;B@D:6YD97@@+B!)35!?24187U-%4"`N("1M86EL8F]X7VYA;64I.PH*+RH@
M57!D871E('1H92!M97-S86=E(&9L86<L(&EF(&YE8V5S<V%R>2X@*B\*)'5S
M95]P;W`@/2`H)&EM<%LG8F%S95]P<F]T;V-O;"==(#T]("=P;W`S)RD["FEF
M("@A)'5S95]P;W`@)B8@(21I;7!?:&5A9&5R<RT^9V5T1FQA9R@G<V5E;B<I
M*2!["B`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-97-S86=E
M+G!H<"<["B`@("`D:6UP7VUE<W-A9V4@/2`F24U07TUE<W-A9V4Z.G-I;F=L
M971O;B@I.PH@("`@)&EM<%]M97-S86=E+3YF;&%G*"=<7%-%14XG+"`D:6UP
M7VUA:6QB;W@L('1R=64I.PI]"@HO*B!$971E<FUI;F4@:68@=V4@<VAO=6QD
M(&=E;F5R871E('1H92!A='1A8VAM96YT('-T<FEP(&QI;FMS(&]R"B`J(&YO
M="X@*B\*:68@*"1P<F5F<RT^9V5T5F%L=64H)W-T<FEP7V%T=&%C:&UE;G1S
M)RDI('L*("`@("1I;7!?8V]N=&5N=',M/G-E=%-T<FEP3&EN:RAT<G5E*3L*
M?0H*+RH@1&]N)W0@<VAO=R!S=6UM87)Y(&QI;FMS(&EF('=E(&%R92!P<FEN
M=&EN9R!T:&4@;65S<V%G92X@*B\*)&EM<%]C;VYT96YT<RT^<VAO=U-U;6UA
M<GE,:6YK<R@A)'!R:6YT97)?9G)I96YD;'DI.PH*:68@*"$D:6UP7V-O;G1E
M;G1S+3YB=6EL9$UE<W-A9V4H*2D@>PH@("`@7W)E='5R;E1O36%I;&)O>"AN
M=6QL+"`G;65S<V%G95]M:7-S:6YG)RD["B`@("!R97%U:7)E($E-4%]"05-%
M("X@)R]M86EL8F]X+G!H<"<["B`@("!E>&ET.PI]"@HD871T86-H;65N=',@
M/2`D:6UP7V-O;G1E;G1S+3YG971!='1A8VAM96YT<R@I.PHD;7-G5&5X="`]
M("1I;7!?8V]N=&5N=',M/F=E=$UE<W-A9V4H*3L*"B\J($1E=F5L;W`@=&AE
M(&QI<W0@;V8@2&5A9&5R<R!T;R!D:7-P;&%Y(&YO=RX@5V4@=VEL;"!D96%L
M('=I=&@@=&AE"B`J("=B87-I8R<@:&5A9&5R(&EN9F]R;6%T:6]N(&9I<G-T
M('-I;F-E('1H97)E(&%R92!V87)I;W5S"B`J(&UA;FEP=6QA=&EO;G,@=V4@
M9&\@=&\@=&AE;2X@*B\*)&)A<VEC7VAE861E<G,@/2!A<G)A>2@*("`@("=D
M871E)R`@("`@(#T^("!?*")$871E(BDL"B`@("`G9G)O;2<@("`@("`]/B`@
M7R@B1G)O;2(I+`H@("`@)W1O)R`@("`@("`@/3X@(%\H(E1O(BDL"B`@("`G
M8V,G("`@("`@("`]/B`@7R@B0V,B*2P*("`@("=B8V,G("`@("`@(#T^("!?
M*")"8V,B*2P*("`@("=R97!L>2UT;R<@(#T^("!?*")297!L>2U4;R(I+`H@
M("`@)W-U8FIE8W0G("`@/3X@(%\H(E-U8FIE8W0B*0HI.PHD;7-G061D<F5S
M<V5S(#T@87)R87DH*3L*"B1I;7!?:&5A9&5R<RT^<V5T5F%L=65">49U;F-T
M:6]N*"=D871E)RP@87)R87DH)VYL,F)R)RP@87)R87DH)&EM<%]H96%D97)S
M+"`G861D3&]C86Q4:6UE)RDL("=H=&UL<W!E8VEA;&-H87)S)RDI.PH*+RH@
M1V5T('1H92!T:71L92]M86EL8F]X(&QA8F5L(&]F('1H92!M86EL8F]X('!A
M9V4N("HO"B1P86=E7VQA8F5L(#T@24U0.CIG971,86)E;"@I.PH*+RH@4')O
M8V5S<R!T:&4@<W5B:F5C="!N;W<N("HO"FEF("@H)'-U8FIE8W0@/2`D:6UP
M7VAE861E<G,M/F=E=%9A;'5E*"=S=6)J96-T)RDI*2!["B`@("`O*B!&:6QT
M97(@=&AE('-U8FIE8W0@=&5X="P@:68@<F5Q=65S=&5D+B`J+PH@("`@)'-U
M8FIE8W0@/2!)35`Z.F9I;'1E<E1E>'0H)'-U8FIE8W0I.PH*("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH@("`@)&EM<%]H96%D97)S+3YS
M971686QU92@G<W5B:F5C="<L(%1E>'0Z.FAT;6Q3<&%C97,H)'-U8FIE8W0I
M*3L*"B`@("`D=&ET;&4@/2!S<')I;G1F*%\H(B5S.B`E<R(I+"`D<&%G95]L
M86)E;"P@)'-U8FIE8W0I.PH@("`@)'-H;W)T<W5B(#T@:'1M;'-P96-I86QC
M:&%R<R@D<W5B:F5C="D["GT@96QS92!["B`@("`D<VAO<G1S=6(@/2!?*");
M3F\@4W5B:F5C=%TB*3L*("`@("1I;7!?:&5A9&5R<RT^861D2&5A9&5R*"=3
M=6)J96-T)RP@)'-H;W)T<W5B*3L*("`@("1T:71L92`]('-P<FEN=&8H7R@B
M)7,Z("5S(BDL("1P86=E7VQA8F5L+"`D<VAO<G1S=6(I.PI]"@HO*B!3964@
M:68@=&AE("=8+5!R:6]R:71Y)R!H96%D97(@:&%S(&)E96X@<V5T+B`J+PII
M9B`H*"1P<FEO<FET>2`]("1I;7!?:&5A9&5R<RT^9V5T5F%L=64H)W@M<')I
M;W)I='DG*2DI('L*("`@(&EF("AP<F5G7VUA=&-H*"(O7',J*%QD*RE<<RHO
M(BP@)'!R:6]R:71Y+"`D;6%T8VAE<RDI('L*("`@("`@("!I9B`H*"1M871C
M:&5S6S%=(#T]("<Q)RD@?'P@*"1M871C:&5S6S%=(#T]("<R)RDI('L*("`@
M("`@("`@("`@)&EM<%]H96%D97)S+3YA9&1(96%D97(H)U!R:6]R:71Y)RP@
M2&]R9&4Z.FEM9R@G;6%I;%]P<FEO<FET>5]H:6=H+G!N9R<L(%\H(DAI9V@@
M4')I;W)I='DB*2D@+B`G)FYB<W`[)R`N("1P<FEO<FET>2D["B`@("`@("`@
M?2!E;'-E:68@*"@D;6%T8VAE<ULQ72`]/2`G-"<I('Q\("@D;6%T8VAE<ULQ
M72`]/2`G-2<I*2!["B`@("`@("`@("`@("1I;7!?:&5A9&5R<RT^861D2&5A
M9&5R*"=0<FEO<FET>2<L($AO<F1E.CII;6<H)VUA:6Q?<')I;W)I='E?;&]W
M+G!N9R<L(%\H(DQO=R!0<FEO<FET>2(I*2`N("<F;F)S<#LG("X@)'!R:6]R
M:71Y*3L*("`@("`@("!]"B`@("!]"GT*"B\J($1E=&5R;6EN92!I9B!A;&PO
M;&ES="!H96%D97)S(&YE961E9"X@*B\*)&%L;%]H96%D97)S(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W-H;W=?86QL7VAE861E<G,G*3L*)&QI<W1?:&5A9&5R
M<R`](%5T:6PZ.F=E=$9O<FU$871A*"=S:&]W7VQI<W1?:&5A9&5R<R<I.PH*
M+RH@1V5T('1H92!R97-T(&]F('1H92!H96%D97)S(&EF(&%L;"!H96%D97)S
M(&%R92!R97%U97-T960N("HO"B1U<V5R7VAD<G,@/2`D=7-E<E]I9&5N=&ET
M>2T^9V5T5F%L=64H)VUA:6Q?:&1R)RD["FEF("@D86QL7VAE861E<G,@?'P@
M(65M<'1Y*"1U<V5R7VAD<G,I*2!["B`@("`D9G5L;%]H(#T@)&EM<%]H96%D
M97)S+3YG971!;&Q(96%D97)S*"D["B`@("!F;W)E86-H("@D9G5L;%]H(&%S
M("1H96%D(#T^("1V86PI('L*("`@("`@("`O*B!3:VEP('1H92!8+5!R:6]R
M:71Y(&AE861E<B!I9B!W92!H879E(&%L<F5A9'D@9&5A;'0@=VET:`H@("`@
M("`@("`J(&ET+B`J+PH@("`@("`@(&EF("@H<W1R:7-T<B@D:&5A9"P@)W@M
M<')I;W)I='DG*2`A/3T@9F%L<V4I("8F"B`@("`@("`@("`@("1I;7!?:&5A
M9&5R<RT^9V5T5F%L=64H)W!R:6]R:71Y)RDI('L*("`@("`@("`@("`@=6YS
M970H)&9U;&Q?:%LD:&5A9%TI.PH@("`@("`@('T@96QS96EF("@D:6UP7VAE
M861E<G,M/F%L=&5R961(96%D97(H)&AE860I*2!["B`@("`@("`@("`@("1F
M=6QL7VA;)&AE861=(#T@)&EM<%]H96%D97)S+3YG971686QU92@D:&5A9"D[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@
M("`@("1V86P@/2!A<G)A>5]M87`H)VAT;6QS<&5C:6%L8VAA<G,G+"`D=F%L
M*3L*("`@("`@("`@("`@)&9U;&Q?:%LD:&5A9%T@/2`G/'5L('-T>6QE/2)M
M87)G:6XZ,'!X.W!A9&1I;F<M;&5F=#HQ-7!X(CX\;&D^)R`N(&EM<&QO9&4H
M(CPO;&D^7&X\;&D^(BP@)'9A;"D@+B`G/"]L:3X\+W5L/B<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&9U;&Q?:%LD:&5A9%T@/2!H=&UL<W!E
M8VEA;&-H87)S*"1V86PI.PH@("`@("`@('T*("`@('T*("`@(&MS;W)T*"1F
M=6QL7V@I.PI]"@HO*B!$:7-P;&%Y('1H92!U<V5R+7-P96-I9FEE9"!H96%D
M97)S(&9O<B!T:&4@8W5R<F5N="!I9&5N=&ET>2X@*B\*)&-U<W1O;5]H9')S
M(#T@87)R87DH*3L*:68@*"%E;7!T>2@D=7-E<E]H9')S*2`F)B`A)&%L;%]H
M96%D97)S*2!["B`@("!F;W)E86-H("@D=7-E<E]H9')S(&%S("1U<V5R7VAD
M<BD@>PH@("`@("`@(&9O<F5A8V@@*"1F=6QL7V@@87,@)&AE860@/3X@)'9A
M;"D@>PH@("`@("`@("`@("!I9B`H<W1R:7-T<B@D:&5A9"P@)'5S97)?:&1R
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1C=7-T;VU?:&1R<ULD
M:&5A9%T@/2`D=F%L.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0I]
M"@HO*B!'96YE<F%T92!T:&4@;&ES="!O9B!S96%R8V@@<&%R86UE=&5R<RX@
M*B\*)'-E87)C:%]P87)A;7,@/2!)35`Z.F=E=%-E87)C:%!A<F%M971E<G,H
M)&UA:6QB;WA?;F%M92P@)&EN9&5X*3L*"B\J($9O<B!T:&4@<V5L9B!54DP@
M;&EN:RP@=V4@8V%N)W0@=')U<W0@=&AE(&EN9&5X(&EN('1H92!Q=65R>2!S
M=')I;F<@87,@:70*("H@;6%Y(&AA=F4@8VAA;F=E9"!I9B!W92!D96QE=&5D
M+V-O<&EE9"]M;W9E9"!M97-S86=E<RX@5V4@;6%Y(&YE960@;W1H97(*("H@
M<W1U9F8@:6X@=&AE('%U97)Y('-T<FEN9RP@<V\@=V4@;F5E9"!T;R!D;R!A
M;B!A9&0O<F5M;W9E(&]F("=I;F1E>"<N("HO"B1S96QF55),(#T@571I;#HZ
M<F5M;W9E4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*'1R=64I+"!A<G)A>2@G
M:6YD97@G+"`G86-T:6]N240G*2D["B1S96QF55),(#T@571I;#HZ861D4&%R
M86UE=&5R*"1S96QF55),+"`G:6YD97@G+"`D:6YD97@I.PHD:&5A9&5R<U52
M3"`](%5T:6PZ.G)E;6]V95!A<F%M971E<B@D<V5L9E523"P@87)R87DH)W-H
M;W=?86QL7VAE861E<G,G+"`G<VAO=U]L:7-T7VAE861E<G,G+"`G;6%I;&)O
M>"<L("=T:&ES;6%I;&)O>"<I*3L*)&AE861E<G-54DP@/2!5=&EL.CIA9&10
M87)A;65T97(H)&AE861E<G-54DPL("1S96%R8VA?<&%R86US*3L*"B\J($1E
M=&5R;6EN92!P<F5V:6]U<R!M97-S86=E(&EN9&5X+B`J+PII9B`H*"1P<F5V
M7VUS9R`]("1I;7!?;6%I;&)O>"T^9V5T24U!4$EN9&5X*"TQ*2DI('L*("`@
M("1P<F5V7W5R;"`]($E-4#HZ9V5N97)A=&5396%R8VA5<FPH)VUE<W-A9V4N
M<&AP)RP@)'!R979?;7-G6R=M86EL8F]X)UTI.PH@("`@)'!R979?=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1P<F5V7W5R;"P@)VEN9&5X)RP@)'!R979?
M;7-G6R=I;F1E>"==*3L*?0H*+RH@1&5T97)M:6YE(&YE>'0@;65S<V%G92!I
M;F1E>"X@*B\*:68@*"@D;F5X=%]M<V<@/2`D:6UP7VUA:6QB;W@M/F=E=$E-
M05!);F1E>"@Q*2DI('L*("`@("1N97AT7W5R;"`]($E-4#HZ9V5N97)A=&53
M96%R8VA5<FPH)VUE<W-A9V4N<&AP)RP@)&YE>'1?;7-G6R=M86EL8F]X)UTI
M.PH@("`@)&YE>'1?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1N97AT7W5R
M;"P@)VEN9&5X)RP@)&YE>'1?;7-G6R=I;F1E>"==*3L*?0H*+RH@1V5T('1H
M92!S=&%R=&EN9R!I;F1E>"!F;W(@=&AE(&-U<G)E;G0@;65S<V%G92!A;F0@
M=&AE(&UE<W-A9V4*("H@8V]U;G0N("HO"B1M<V=I;F1E>"`]("1I;7!?;6%I
M;&)O>"T^9V5T365S<V%G94EN9&5X*"D["B1M<V=C;W5N="`]("1I;7!?;6%I
M;&)O>"T^9V5T365S<V%G94-O=6YT*"D["@HO*B!'96YE<F%T92!T:&4@;6%I
M;&)O>"!L:6YK+B`J+PHD;6%I;&)O>%]U<FP@/2!5=&EL.CIA9&1087)A;65T
M97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=M86EL8F]X+G!H<"<I+"`G<W1A
M<G0G+"`D;7-G:6YD97@I.PH*+RH@1V5N97)A=&4@=&AE('9I97<@;&EN:RX@
M*B\*)'9I97=?;&EN:R`]($E-4#HZ9V5N97)A=&5396%R8VA5<FPH)W9I97<N
M<&AP)RP@)&UA:6QB;WA?;F%M92D["B1V:65W7VQI;FL@/2!5=&EL.CIA9&10
M87)A;65T97(H)'9I97=?;&EN:RP@)VEN9&5X)RP@)&EN9&5X*3L*"B\J($=E
M;F5R871E('1H92!3879E($UE<W-A9V4@;&EN:RX@*B\*)'-A=F5?;&EN:U]A
M<G)A>2`](&%R<F%Y7VUE<F=E*&%R<F%Y*"=A8W1I;VY)1"<@/3X@)W-A=F5?
M;65S<V%G92<L("=I;F1E>"<@/3X@)&EN9&5X*2P@)'-E87)C:%]P87)A;7,I
M.PHD<V%V95]L:6YK(#T@2&]R9&4Z.F1O=VYL;V%D57)L*"1S=6)J96-T+"`D
M<V%V95]L:6YK7V%R<F%Y*3L*"B\J($=E;F5R871E('1H92!-97-S86=E(%-O
M=7)C92!L:6YK+B`J+PII9B`H)&-O;F9;)W5S97(G75LG86QL;W=?=FEE=U]S
M;W5R8V4G72D@>PH@("`@)&)A<V5?<&%R="`]("1I;7!?8V]N=&5N=',M/F=E
M=$U)345-97-S86=E*"D["B`@("`D<V]U<F-E7VQI;FL@/2`D:6UP7V-O;G1E
M;G1S+3YL:6YK5FEE=TI3*"1B87-E7W!A<G0L("=V:65W7W-O=7)C92<L(%\H
M(E]-97-S86=E(%-O=7)C92(I+"!?*")-97-S86=E(%-O=7)C92(I+"`G=VED
M9V5T)RP@87)R87DH*2P@=')U92D["GT*"B\J($=E;F5R871E('1H92!L:6YK
M('1O(&]U<G-E;'9E<RX@*B\*)'-E;&9?;&EN:R`]($E-4#HZ9V5N97)A=&53
M96%R8VA5<FPH)VUE<W-A9V4N<&AP)RP@)&UA:6QB;WA?;F%M92D["B1S96QF
M7VQI;FL@/2!5=&EL.CIA9&1087)A;65T97(H)'-E;&9?;&EN:RP@87)R87DH
M)VEN9&5X)R`]/B`D:6YD97@L("=S=&%R="<@/3X@)&US9VEN9&5X*2D["@HO
M*B!'96YE<F%T92!T:&4@<')I;G0@;&EN:RX@*B\*)'!R:6YT7W!A<F%M<R`]
M(&%R<F%Y*"=A8W1I;VY)1"<@/3X@)W!R:6YT7VUE<W-A9V4G+"`G:6YD97@G
M(#T^("1I;F1E>"D["B1P<FEN=%]L:6YK(#T@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=M97-S86=E+G!H<"<I.PHD<')I;G1?;&EN:R`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D<')I;G1?;&EN:RP@87)R87E?;65R9V4H)'!R:6YT7W!A<F%M
M<RP@)'-E87)C:%]P87)A;7,I*3L*"B\J($=E;F5R871E('1H92!T:')E860@
M=FEE=R!L:6YK+B`J+PHD=&AR96%D7VQI;FL@/2!5=&EL.CIA9&1087)A;65T
M97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=T:')E860N<&AP)RDL(&%R<F%Y
M*"=I;F1E>"<@/3X@)&EN9&5X+"`G<W1A<G0G(#T^("1M<V=I;F1E>"DI.PH*
M)&1E;&5T95]W87)N:6YG(#T@)R<["FEF("@D=7-E7W!O<"D@>PH@("`@)&1E
M;&5T95]W87)N:6YG(#T@(G)E='5R;B!W:6YD;W<N8V]N9FER;2@G(B`N(&%D
M9'-L87-H97,H7R@B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(%!%4DU!3D5.
M5$Q9(&1E;&5T92!T:&5S92!M97-S86=E<S\B*2D@+B`B)RD[(CL*?0H*2&]R
M9&4Z.F%D9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U92D[
M"DAO<F1E.CIA9&138W)I<'1&:6QE*"=K97EB:6YD:6YG<RYJ<R<L("=H;W)D
M92<I.PIR97%U:7)E($E-4%]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N
M:6YC)SL*"B\J($-H96-K(&9O<B!T:&4@<')E<V5N8V4@;V8@;6%I;&EN9R!L
M:7-T(&EN9F]R;6%T:6]N+B`J+PHD<F5P;'E?875T:&]R(#T@87)R87DH*3L*
M)')E<&QY7VQI<W0@/2!N=6QL.PII9B`H*"1L:7-T7V5X:7-T<R`]("1I;7!?
M:&5A9&5R<RT^;&ES=$AE861E<G-%>&ES="@I*2D@>PH@("`@+RH@4V5E(&EF
M('1H92!,:7-T+5!O<W0@:&5A9&5R('!R;W9I9&5S(&%N(&4M;6%I;"!A9&1R
M97-S(&9O<B!T:&4*("`@("`J(&QI<W0N("HO"B`@("!I9B`H)&EM<%]H96%D
M97)S+3YG971686QU92@G;&ES="UP;W-T)RDI('L*("`@("`@("`D<F5P;'E?
M;&ES="`]("1I;7!?:&5A9&5R<RT^<&%R<V5,:7-T2&5A9&5R<R@G;&ES="UP
M;W-T)RP@=')U92D["B`@("!]"@H@("`@+RH@268@=&AE(%)E<&QY+71O.B!A
M9&1R97-S(&ES('1H92!S86UE(&%S('1H92!L:7-T(&%D9')E<W,L('5S90H@
M("`@("H@=&AE('5S97(G<R!F<F]M(&%D9')E<W,@9F]R('1H92`B4F5P;'DB
M(&%C=&EO;BX@*B\*("`@(&EF("@A:7-?;G5L;"@D<F5P;'E?;&ES="D@)B8*
M("`@("`@("!)35`Z.F)A<F5!9&1R97-S*"1R97!L>5]L:7-T*2`]/2!)35`Z
M.F)A<F5!9&1R97-S*$U)344Z.F%D9')!<G)A>3)3=')I;F<H)&EM<%]H96%D
M97)S+3YG971/8B@G<F5P;'E?=&\G*2DI*2!["B`@("`@("`@)')E<&QY7V%U
M=&AO<B`]($U)344Z.F%D9')!<G)A>3)3=')I;F<H)&EM<%]H96%D97)S+3YG
M971/8B@G9G)O;2<I*3L*("`@('T*"B`@("`O*B!3964@:68@=&AE(&UA:6QI
M;F<@;&ES="!I;F9O<FUA=&EO;B!H87,@8F5E;B!R97%U97-T960@=&\@8F4*
M("`@("`J(&1I<W!L87EE9"X@*B\*("`@(&EF("@D;&ES=%]H96%D97)S('Q\
M("1A;&Q?:&5A9&5R<RD@>PH@("`@("`@("1I;7!?:&5A9&5R<RT^<&%R<V5!
M;&Q,:7-T2&5A9&5R<R@I.PH@("`@?0I]"@HO*B!"=6EL9"!&<F]M(&%D9')E
M<W,@;&EN:W,N("HO"B1I;7!?:&5A9&5R<RT^8G5I;&1!9&1R97-S3&EN:W,H
M)V9R;VTG+"`D<V5L9E]L:6YK+"!T<G5E+"`A)'!R:6YT97)?9G)I96YD;'DI
M.PH*+RH@061D(&-O=6YT<GDO9FQA9R!I;6%G92X@5')Y(%@M3W)I9VEN871I
M;F<M25`@9FER<W0L('1H96X@9F%L;"!B86-K"B`J(&]N('1H92!S96YD97(G
M<R!D;VUA:6X@;F%M92X@*B\*:68@*"$D<')I;G1E<E]F<FEE;F1L>2D@>PH@
M("`@)&9R;VU?:6UG(#T@)R<["B`@("`D;W)I9VEN7VAO<W0@/2!S=')?<F5P
M;&%C92AA<G)A>2@G6R<L("==)RDL("<G+"`D:6UP7VAE861E<G,M/F=E=%9A
M;'5E*"=8+4]R:6=I;F%T:6YG+4E0)RDI.PH@("`@:68@*&ES7V%R<F%Y*"1O
M<FEG:6Y?:&]S="DI('L*("`@("`@("`D9G)O;5]I;6<@/2`G)SL*("`@("`@
M("!F;W)E86-H("@D;W)I9VEN7VAO<W0@87,@)&AO<W0I('L*("`@("`@("`@
M("`@)&9R;VU?:6UG("X]($Y,4SHZ9V5N97)A=&5&;&%G26UA9V5">4AO<W0H
M)&AO<W0I("X@)R`G.PH@("`@("`@('T*("`@("`@("!T<FEM*"1F<F]M7VEM
M9RD["B`@("!](&5L<V5I9B`H)&]R:6=I;E]H;W-T*2!["B`@("`@("`@)&9R
M;VU?:6UG(#T@3DQ3.CIG96YE<F%T949L86=);6%G94)Y2&]S="@D;W)I9VEN
M7VAO<W0I.PH@("`@?0H@("`@:68@*&5M<'1Y*"1F<F]M7VEM9RDI('L*("`@
M("`@("`D9G)O;5]O8B`](&EM87!?<F9C.#(R7W!A<G-E7V%D<FQI<W0H)&EM
M<%]H96%D97)S+3YG971&<F]M061D<F5S<R@I+"`G)RD["B`@("`@("`@)&9R
M;VU?;V(@/2!A<G)A>5]S:&EF="@D9G)O;5]O8BD["B`@("`@("`@)&]R:6=I
M;E]H;W-T(#T@)&9R;VU?;V(M/FAO<W0["B`@("`@("`@)&9R;VU?:6UG(#T@
M3DQ3.CIG96YE<F%T949L86=);6%G94)Y2&]S="@D;W)I9VEN7VAO<W0I.PH@
M("`@?0H@("`@:68@*"%E;7!T>2@D9G)O;5]I;6<I*2!["B`@("`@("`@)&EM
M<%]H96%D97)S+3YS971686QU92@G9G)O;2<L("1I;7!?:&5A9&5R<RT^9V5T
M5F%L=64H)V9R;VTG*2`N("<F;F)S<#LG("X@)&9R;VU?:6UG*3L*("`@('T*
M?0H*+RH@0G5I;&0@5&\O0V,O0F-C(&QI;FMS+B`J+PHD861D<F5S<U]H96%D
M97)S(#T@87)R87DH)W1O)R`]/B`G=&]A9&1R97-S)RP@)V-C)R`]/B`G8V-A
M9&1R97-S)RP@)V)C8R<@/3X@)V)C8V%D9')E<W,G*3L*9F]R96%C:"`H)&%D
M9')E<W-?:&5A9&5R<R!A<R`D:V5Y(#T^("1V86PI('L*("`@(&EF("@D:6UP
M7VAE861E<G,M/F)U:6QD061D<F5S<TQI;FMS*"1K97DL("1S96QF7VQI;FLL
M('1R=64L("$D<')I;G1E<E]F<FEE;F1L>2DI('L*("`@("`@("`D;7-G061D
M<F5S<V5S6UT@/2`D:6UP7VAE861E<G,M/F=E=$]B*"1V86PI.PH@("`@?0I]
M"@HO*B!"=6EL9"!297!L>2U4;R!A9&1R97-S(&QI;FMS+B`J+PII9B`H*"1R
M97!L>5]T;R`]("1I;7!?:&5A9&5R<RT^8G5I;&1!9&1R97-S3&EN:W,H)W)E
M<&QY7W1O)RP@)'-E;&9?;&EN:RP@9F%L<V4L("$D<')I;G1E<E]F<FEE;F1L
M>2DI*2!["B`@("!I9B`H(2@D9G)O;2`]("1I;7!?:&5A9&5R<RT^9V5T5F%L
M=64H)V9R;VTG*2D@?'P@*"1F<F]M("$]("1R97!L>5]T;RDI('L*("`@("`@
M("`D:6UP7VAE861E<G,M/G-E=%9A;'5E*"=297!L>2UT;R<L("1R97!L>5]T
M;RD["B`@("!](&5L<V4@>PH@("`@("`@("1I;7!?:&5A9&5R<RT^<F5M;W9E
M2&5A9&5R*"=R97!L>2UT;R<I.PH@("`@?0I]"@HO*B!3970@=&AE('-T871U
M<R!I;F9O<FUA=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*)&%D9')E<W-E<R`]
M(&%R<F%Y7VME>7,H)'5S97)?:61E;G1I='DM/F=E=$%L;$9R;VU!9&1R97-S
M97,H=')U92DI.PHD:61E;G1I='D@/2!N=6QL.PHD<W1A='5S(#T@)R<["FEF
M("@A)'5S95]P;W`I('L*("`@(&EF("AC;W5N="@D;7-G061D<F5S<V5S*2D@
M>PH@("`@("`@("1I9&5N=&ET>2`]("1U<V5R7VED96YT:71Y+3YG971-871C
M:&EN9TED96YT:71Y*"1M<V=!9&1R97-S97,I.PH@("`@("`@(&EF("@A:7-?
M;G5L;"@D:61E;G1I='DI('Q\"B`@("`@("`@("`@("1U<V5R7VED96YT:71Y
M+3YG971-871C:&EN9TED96YT:71Y*"1M<V=!9&1R97-S97,L(&9A;'-E*2`A
M/3T@;G5L;"D@>PH@("`@("`@("`@("`D<W1A='5S("X]($AO<F1E.CII;6<H
M)VUA:6Q?<&5R<V]N86PN<&YG)RP@7R@B4&5R<V]N86PB*2D["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]N=6QL*"1I9&5N=&ET>2DI('L*("`@("`@("`@
M("`@)&ED96YT:71Y(#T@)'5S97)?:61E;G1I='DM/F=E=$1E9F%U;'0H*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RH@4V5T('-T871U<R!F;&%G<RX@*B\*
M("`@("1F;&%G7V%R<F%Y(#T@87)R87DH"B`@("`@("`@)W5N<V5E;B<@("`]
M/B!?*")5;G-E96XB*2P*("`@("`@("`G86YS=V5R960G(#T^(%\H(D%N<W=E
M<F5D(BDL"B`@("`@("`@)V1R869T)R`@("`]/B!?*")$<F%F="(I+`H@("`@
M("`@("=F;&%G9V5D)R`@/3X@7R@B26UP;W)T86YT(BDL"B`@("`@("`@)V1E
M;&5T960G("`]/B!?*")$96QE=&5D(BD*("`@("D["B`@("!F;W)E86-H("@D
M9FQA9U]A<G)A>2!A<R`D9FQA9R`]/B`D9&5S8RD@>PH@("`@("`@(&EF("@D
M:6UP7VAE861E<G,M/F=E=$9L86<H)&9L86<I*2!["B`@("`@("`@("`@("1S
M=&%T=7,@+CT@2&]R9&4Z.FEM9R@G;6%I;%\G("X@)&9L86<@+B`G+G!N9R<L
M("1D97-C*3L*("`@("`@("!]"B`@("!]"GT*"B\J(%-H;W<@=&AE(%MB;&%C
M:WQW:&ET95UL:7-T(&QI;FL@:68@=V4@:&%V92!T:&%T(&9U;F-T:6]N86QI
M='D*("H@96YA8FQE9"X@*B\*)'-H;W=?8FQA8VML:7-T7VQI;FL@/2!F86QS
M93L*)'-H;W=?=VAI=&5L:7-T7VQI;FL@/2!F86QS93L*:68@*"1R96=I<W1R
M>2T^:&%S365T:&]D*"=M86EL+V)L86-K;&ES=$9R;VTG*2D@>PH@("`@)'-H
M;W=?8FQA8VML:7-T7VQI;FL@/2!T<G5E.PI]"FEF("@D<F5G:7-T<GDM/FAA
M<TUE=&AO9"@G;6%I;"]W:&ET96QI<W1&<F]M)RDI('L*("`@("1S:&]W7W=H
M:71E;&ES=%]L:6YK(#T@=')U93L*?0H*+RH@1&5T97)M:6YE(&EF('=E(&YE
M960@=&\@<VAO=R!T:&4@4F5P;'D@=&\@06QL(&QI;FLN("HO"B1S:&]W7W)E
M<&QY7V%L;"`]('1R=64["FEF("@A34E-13HZ861D<D%R<F%Y,E-T<FEN9RAA
M<G)A>5]M97)G92@D:6UP7VAE861E<G,M/F=E=$]B*"=T;R<I+"`D:6UP7VAE
M861E<G,M/F=E=$]B*"=C8R<I*2P@)&%D9')E<W-E<RDI('L*("`@("1S:&]W
M7W)E<&QY7V%L;"`](&9A;'-E.PI]"@HO*B!2971R:65V92!A;GD@:&ES=&]R
M>2!I;F9O<FUA=&EO;B!F;W(@=&AI<R!M97-S86=E+B`J+PII9B`H(21P<FEN
M=&5R7V9R:65N9&QY("8F("%E;7!T>2@D8V]N9ELG;6%I;&QO9R==6R=U<V5?
M;6%I;&QO9R==*2D@>PH@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L
M:6(O36%I;&QO9RYP:'`G.PH@("`@)&US9U]I9"`]("1I;7!?:&5A9&5R<RT^
M9V5T3V(H)VUE<W-A9V5?:60G*3L*("`@($E-4%]-86EL;&]G.CID:7-P;&%Y
M3&]G*"1M<V=?:60I.PH*("`@("\J($1O($U$3B!P<F]C97-S:6YG(&YO=RX@
M*B\*("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=D:7-P;W-I=&EO;E]S96YD
M7VUD;B<I*2!["B`@("`@("`@+RH@0VAE8VL@=&\@<V5E(&EF(&%N($U$3B!H
M87,@8F5E;B!R97%U97-T960N("HO"B`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]-24U%+TU$3BYP:'`G.PH@("`@("`@("1M9&X@/2`F;F5W($U)345?
M341.*"1I;7!?:&5A9&5R<U]C;W!Y*3L*("`@("`@("!I9B`H)&UD;BT^9V5T
M341.4F5T=7)N061D<B@I*2!["B`@("`@("`@("`@("\J(%-E92!I9B!W92!H
M879E(&%L<F5A9'D@<')O8V5S<V5D('1H:7,@;65S<V%G92X@*B\*("`@("`@
M("`@("`@:68@*"%)35!?36%I;&QO9SHZ<V5N=$U$3B@D;7-G7VED+"`G9&ES
M<&QA>65D)RDI('L*("`@("`@("`@("`@("`@("1M9&Y?8V]N9FER;2`](%5T
M:6PZ.F=E=$9O<FU$871A*"=M9&Y?8V]N9FER;2<I.PH@("`@("`@("`@("`@
M("`@+RH@4V5E(&EF('=E(&YE960@=&\@<75E<GD@=&AE('5S97(N("HO"B`@
M("`@("`@("`@("`@("!I9B`H)&UD;BT^=7-E<D-O;F9I<FUA=&EO;DYE961E
M9"@I("8F("$D;61N7V-O;F9I<FTI('L*("`@("`@("`@("`@("`@("`@("`D
M8V]N9FER;5]L:6YK(#T@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R
M*"1S96QF55),+"`G;61N7V-O;F9I<FTG+"`Q*2D@+B!?*")(15)%(BD@+B`G
M/"]A/B<["B`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"AS<')I;G1F*%\H(E1H92!S96YD97(@;V8@=&AI<R!M97-S86=E(&ES(')E
M<75E<W1I;F<@82!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B!F
M<F]M('EO=2!W:&5N('EO=2!H879E(')E860@=&AI<R!M97-S86=E+B!0;&5A
M<V4@8VQI8VL@)7,@=&\@<V5N9"!T:&4@;F]T:69I8V%T:6]N(&UE<W-A9V4N
M(BDL("1C;VYF:7)M7VQI;FLI+"`G:&]R9&4N;65S<V%G92<L(&%R<F%Y*"=C
M;VYT96YT+G)A=R<I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@+RH@4V5N9"!O=70@=&AE($U$3B!N;W<N("HO"B`@
M("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1M9&XM/F=E;F5R871E*&9A
M;'-E+"`D;61N7V-O;F9I<FTL("=D:7-P;&%Y960G*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!)35!?36%I;&QO9SHZ;&]G*"=M9&XG
M+"`D;7-G7VED+"`G9&ES<&QA>65D)RD["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0I]"@II9B`H(21P<FEN=&5R7V9R:65N9&QY*2!["B`@("!R97%U:7)E
M($E-4%]414U03$%415,@+B`G+VUE;G4N:6YC)SL*("`@($E-4#HZ<W1A='5S
M*"D["@H@("`@+RH@4')I;G0@<75O=&$@:6YF;W)M871I;VXN("HO"B`@("!I
M9B`H:7-S970H)&EM<%LG<75O=&$G72D@)B8@:7-?87)R87DH)&EM<%LG<75O
M=&$G72DI('L*("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI
M8B]1=6]T82YP:'`G.PH@("`@("`@("1Q=6]T841R:79E<B`]("9)35!?475O
M=&$Z.G-I;F=L971O;B@D:6UP6R=Q=6]T82==6R=D<FEV97(G72P@)&EM<%LG
M<75O=&$G75LG<&%R86US)UTI.PH@("`@("`@(&EF("@D<75O=&%$<FEV97(@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("1Q=6]T82`]("1Q=6]T841R:79E
M<BT^9V5T475O=&$H*3L*("`@("`@("`@("`@<F5Q=6ER92!)35!?5$5-4$Q!
M5$53("X@)R]Q=6]T82]Q=6]T82YI;F,G.PH@("`@("`@('T*("`@('T*"B`@
M("!R97%U:7)E($E-4%]414U03$%415,@+B`G+VUE<W-A9V4O;F%V8F%R7W1O
M<"YI;F,G.PH@("`@)&YA=E]I9"`](#$["B`@("!R97%U:7)E($E-4%]414U0
M3$%415,@+B`G+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN8R<["@H@("`@
M+RH@0V%C:&4@=&AE(')E<W5L=',@;V8@=&AE(&YA=F)A<E]A8W1I;VYS+FEN
M8R!R97%U:7)E+B`J+PH@("`@;V)?<W1A<G0H*3L*("`@(')E<75I<F4@24U0
M7U1%35!,051%4R`N("<O;65S<V%G92]N879B87)?86-T:6]N<RYI;F,G.PH@
M("`@)&%C=&EO;G-?;W5T<'5T(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("!O
M8E]E;F1?8VQE86XH*3L*("`@(&5C:&\@)&%C=&EO;G-?;W5T<'5T("X@)SPO
M=&%B;&4^)SL*?0H*+RH@1V5N97)A=&4@<V]M92!V87)I86)L97,@;F5E9&5D
M(&9O<B!T:&4@=&5M<&QA=&5S+B`J+PHD9&]W;FQO861A;&Q?;&EN:R`]("1I
M;7!?8V]N=&5N=',M/F=E=$1O=VYL;V%D06QL3&EN:R@I.PHD871C7V1I<W!L
M87D@/2`D<')E9G,M/F=E=%9A;'5E*"=A='1A8VAM96YT7V1I<W!L87DG*3L*
M)'-H;W=?<&%R=',@/2`H(65M<'1Y*"1A='1A8VAM96YT<RD@)B8@*"@D871C
M7V1I<W!L87D@/3T@)VQI<W0G*2!\?"`H)&%T8U]D:7-P;&%Y(#T]("=B;W1H
M)RDI*3L*"G)E<75I<F4@24U07U1%35!,051%4R`N("<O;65S<V%G92]H96%D
M97)S+FEN8R<["G)E<75I<F4@24U07U1%35!,051%4R`N("<O;65S<V%G92]M
M97-S86=E+FEN8R<["@II9B`H(21P<FEN=&5R7V9R:65N9&QY*2!["B`@("!E
M8VAO("<\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(CXG("X@
M)&%C=&EO;G-?;W5T<'5T.PH@("`@)&YA=E]I9"`](#(["B`@("!R97%U:7)E
M($E-4%]414U03$%415,@+B`G+VUE<W-A9V4O;F%V8F%R7VYA=FEG871E+FEN
M8R<["B`@("!E8VAO("<\+W1A8FQE/CPO9F]R;3XG.PI]"FEF("@D8G)O=W-E
M<BT^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*2!["B`@("!R97%U:7)E7V]N
M8V4@24U07U1%35!,051%4R`N("<O;65S<V%G92]J879A<V-R:7!T+FEN8R<[
M"B`@("!R97%U:7)E7V]N8V4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L
M("=H;W)D92<I("X@)R]C;VYT96YT<R]O<&5N7W9I97=?=VEN+FIS)SL*("`@
M(&EF("@D<')I;G1E<E]F<FEE;F1L>2D@>PH@("`@("`@(')E<75I<F5?;VYC
M92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+VIA
M=F%S8W)I<'0O<')I;G0N:G,G.PH@("`@?0I]"@IR97%U:7)E("1R96=I<W1R
M>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E
M<BYI;F,G.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M;6%I;&)O>"YP:'``````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#<R,S(W`#$P-#$W,S8R-S<P`#`Q-S,V-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!I;7`O;6%I;&)O>"YP:'`L=B`R+C8Q-RXT+C4V(#(P,#8O,#(O
M,C$@,#<Z,S(Z,S0@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]G<&PN:'1M;"X*("HO"@HO*BH*("H@1&5L971E(&$@;&ES="!O
M9B!M97-S86=E<RX*("HO"F9U;F-T:6]N(%]D96QE=&5-97-S86=E<R@D:6YD
M:6-E<RD*>PH@("`@9VQO8F%L("1I;7`L("1M86EL8F]X7W5R;#L*"B`@("!I
M9B`H(65M<'1Y*"1I;F1I8V5S*2D@>PH@("`@("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+TUE<W-A9V4N<&AP)SL*("`@("`@("`D:6UP7VUE
M<W-A9V4@/2`F24U07TUE<W-A9V4Z.G-I;F=L971O;B@I.PH@("`@("`@("1I
M;7!?;65S<V%G92T^9&5L971E*"1I;F1I8V5S*3L*"B`@("`@("`@:68@*"1I
M;7!;)V)A<V5?<')O=&]C;VPG72`]/2`G<&]P,R<I('L*("`@("`@("`@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIU<FPH)&UA:6QB;WA?=7)L
M+"!T<G5E*2D["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("!R971U<FX@9F%L<V4["GT*"B\J
M*@H@*B!3='EL:7IE(&$@<W1R:6YG+@H@*B\*9G5N8W1I;VX@7W-T>6QI>F4H
M)'-T<FEN9RP@)'-T>6QE<RD*>PH@("`@:68@*"%I<U]A<G)A>2@D<W1Y;&5S
M*2D@>PH@("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@?0H*("`@(&9O<F5A
M8V@@*"1S='EL97,@87,@)'-T>6QE*2!["B`@("`@("`@:68@*"%E;7!T>2@D
M<W1Y;&4I*2!["B`@("`@("`@("`@("1S=')I;F<@/2`G/"<@+B`D<W1Y;&4@
M+B`G/B<@+B`D<W1R:6YG("X@)SPO)R`N("1S='EL92`N("<^)SL*("`@("`@
M("!]"B`@("!]"@H@("`@<F5T=7)N("1S=')I;F<["GT*"B\J*@H@*B!/=71P
M=70@=&AE(&UE<W-A9V4@<W5M;6%R:65S+@H@*B\*9G5N8W1I;VX@7V]U='!U
M=%-U;6UA<FEE<R@D<V5A<F-H7VUB;W@L("1M<V=S*0I["B`@("`D=&5M<&QA
M=&4@/2`F;F5W($AO<F1E7U1E;7!L871E*"D["B`@("`D=&5M<&QA=&4M/G-E
M="@G:61X7W-E<&%R871O<B<L($E-4%])1%A?4T50*3L*("`@("1T96UP;&%T
M92T^<V5T*"=S96%R8VA?;6)O>"<L("AB;V]L*2`D<V5A<F-H7VUB;W@L('1R
M=64I.PH@("`@)'1E;7!L871E+3YS970H)VUE<W-A9V5S)RP@)&US9W,L('1R
M=64I.PH*("`@("\O(%-O;64@8G)O=W-E<G,@:&%V92!T<F]U8FQE('=I=&@@
M:&ED9&5N(&]V97)F;&]W(&EN('1A8FQE(&-E;&QS"B`@("`O+R!B=70@;F]T
M(&EN(&1I=G,N"B`@("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S475I
M<FLH)VYO7VAI9&1E;E]O=F5R9FQO=U]T86)L97,G*2D@>PH@("`@("`@("1T
M96UP;&%T92T^<V5T*"=O=F5R9FQO=U]B96=I;B<L("<\9&EV(&-L87-S/2)O
M:&ED92(^)RD["B`@("`@("`@)'1E;7!L871E+3YS970H)V]V97)F;&]W7V5N
M9"<L("<\+V1I=CXG*3L*("`@('T@96QS92!["B`@("`@("`@)'1E;7!L871E
M+3YS970H)V]V97)F;&]W7V)E9VEN)RP@)R<I.PH@("`@("`@("1T96UP;&%T
M92T^<V5T*"=O=F5R9FQO=U]E;F0G+"`G)RD["B`@("!]"B`@("!E8VAO("1T
M96UP;&%T92T^9F5T8V@H24U07U1%35!,051%4R`N("<O;6%I;&)O>"]M86EL
M8F]X+FAT;6PG*3L*?0H*)&1O7V9I;'1E<B`](&9A;'-E.PHD;W!E;E]C;VUP
M;W-E7W=I;F1O=R`](&9A;'-E.PHD<V5T(#T@9F%L<V4["FEF("AI<W-E="@D
M;F5W7VQA;F<I*2!["B`@("`D;&%N9W5A9V4@/2`D;F5W7VQA;F<["B`@("`D
M<V5T(#T@=')U93L*?0H*0&1E9FEN92@G24U07T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2D["G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O36%I;&)O>"YP
M:'`G.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]396%R8V@N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O261E;G1I='DN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]4
M96UP;&%T92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0N<&AP)SL*
M"B\J($-A;&P@=&AE(&UA:6QB;W@@<F5D:7)E8W1I;VX@:&]O:RP@:68@<F5Q
M=65S=&5D+B`J+PII9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=M8F]X7W)E
M9&ER96-T)UTI*2!["B`@("!R97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O
M8V]N9FEG+VAO;VMS+G!H<"<["B`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?
M:6UP7VAO;VM?;6)O>%]R961I<F5C="<I*2!["B`@("`@("`@)')E9&ER96-T
M(#T@8V%L;%]U<V5R7V9U;F,H)U]I;7!?:&]O:U]M8F]X7W)E9&ER96-T)RP@
M)&EM<%LG;6%I;&)O>"==*3L*("`@("`@("!I9B`H(65M<'1Y*"1R961I<F5C
M="DI('L*("`@("`@("`@("`@)')E9&ER96-T(#T@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"1R961I<F5C="P@=')U92D["B`@("`@("`@("`@(&AE861E<B@G
M3&]C871I;VXZ("<@+B`D<F5D:7)E8W0I.PH@("`@("`@("`@("!E>&ET.PH@
M("`@("`@('T*("`@('T*?0H*+RH@5&AE<F4@:7,@82!C:&%N8V4@=&AA="!T
M:&ES('!A9V4@:7,@;&]A9&5D(&1I<F5C=&QY('9I80H@*B!M97-S86=E+G!H
M<"X@268@<V\L(&1O;B=T(')E+6EN8VQU9&4@8V]N9FEG(&9I;&5S+"!A;F0@
M=&AE"B`J(&9O;&QO=VEN9R!V87)I86)L97,@=VEL;"!A;')E861Y(&)E('-E
M=#H@)&%C=&EO;DE$+"`D<W1A<G0N("HO"FEF("AI<W-E="@D9G)O;5]M97-S
M86=E7W!A9V4I*2!["B`@("`D;6%I;&)O>%]U<FP@/2!(;W)D93HZ87!P;&EC
M871I;VY54DPH)VUA:6QB;W@N<&AP)RD["GT@96QS92!["B`@("`D;6%I;&)O
M>%]U<FP@/2!(;W)D93HZ<V5L9E5R;"@I.PH@("`@)&%C=&EO;DE$(#T@571I
M;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD["B`@("`D<W1A<G0@/2!5=&EL
M.CIG971&;W)M1&%T82@G<W1A<G0G*3L*?0H*:68@*"1A8W1I;VY)1"`]/2`G
M;&]G:6Y?8V]M<&]S92<I('L*("`@("1O<&5N7V-O;7!O<V5?=VEN9&]W(#T@
M24U0.CIO<&5N0V]M<&]S95=I;B@I.PI]"@HO*B!'970@9F]R;2!D871A(&%N
M9"!M86ME('-U<F4@:70G<R!T:&4@='EP92!T:&%T('=E)W)E(&5X<&5C=&EN
M9RX@*B\*)'1A<F=E=$UB;W@@/2!5=&EL.CIG971&;W)M1&%T82@G=&%R9V5T
M36)O>"<I.PHD;F5W36)O>"`](%5T:6PZ.F=E=$9O<FU$871A*"=N97=-8F]X
M)RD["FEF("@A:7-?87)R87DH*"1I;F1I8V5S(#T@571I;#HZ9V5T1F]R;41A
M=&$H)VEN9&EC97,G*2DI*2!["B`@("`D:6YD:6-E<R`](&%R<F%Y*"1I;F1I
M8V5S*3L*?0HD:6YD:6-E<U]M8F]X(#T@87)R87DH)&EM<%LG;6%I;&)O>"==
M(#T^("1I;F1I8V5S*3L*"B\J(%-E="!T:&4@8W5R<F5N="!T:6UE('IO;F4N
M("HO"DY,4SHZ<V5T5&EM95IO;F4H*3L*"B\J($-A8VAE('1H92!C:&%R<V5T
M+B`J+PHD8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH*+RH@26YI=&EA
M;&EZ92!T:&4@=7-E<B=S(&ED96YT:71I97,N("HO"B1I9&5N=&ET>2`]("9)
M9&5N=&ET>3HZ<VEN9VQE=&]N*&%R<F%Y*"=I;7`G+"`G:6UP)RDI.PH*+RH@
M4G5N('1H<F]U9V@@=&AE(&%C=&EO;B!H86YD;&5R<R`J+PIS=VET8V@@*"1A
M8W1I;VY)1"D@>PIC87-E("=C:&%N9V5?<V]R="<Z"B`@("!I9B`H*"1S;W)T
M8GD@/2!5=&EL.CIG971&;W)M1&%T82@G<V]R=&)Y)RDI("$]/2!N=6QL*2![
M"B`@("`@("`@)'!R969S+3YS971686QU92@G<V]R=&)Y)RP@)'-O<G1B>2D[
M"B`@("!]"B`@("!I9B`H*"1S;W)T9&ER(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W-O<G1D:7(G*2D@(3T](&YU;&PI('L*("`@("`@("`D<')E9G,M/G-E=%9A
M;'5E*"=S;W)T9&ER)RP@)'-O<G1D:7(I.PH@("`@?0H@("`@)&EM<%]M86EL
M8F]X(#T@)DE-4%]-86EL8F]X.CIS:6YG;&5T;VXH;G5L;"P@=')U92D["B`@
M("!B<F5A:SL*"F-A<V4@)V)L86-K;&ES="<Z"B`@("!R97%U:7)E7V]N8V4@
M24U07T)!4T4@+B`G+VQI8B]&:6QT97(N<&AP)SL*("`@("1I;7!?9FEL=&5R
M(#T@)DE-4%]&:6QT97(Z.G-I;F=L971O;B@I.PH@("`@)&EM<%]F:6QT97(M
M/F)L86-K;&ES=$UE<W-A9V4H)&EN9&EC97-?;6)O>"D["B`@("!B<F5A:SL*
M"F-A<V4@)W=H:71E;&ES="<Z"B`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@
M+B`G+VQI8B]&:6QT97(N<&AP)SL*("`@("1I;7!?9FEL=&5R(#T@)DE-4%]&
M:6QT97(Z.G-I;F=L971O;B@I.PH@("`@)&EM<%]F:6QT97(M/G=H:71E;&ES
M=$UE<W-A9V4H)&EN9&EC97-?;6)O>"D["B`@("!B<F5A:SL*"F-A<V4@)W-P
M86U?<F5P;W)T)SH*8V%S92`G;F]T<W!A;5]R97!O<G0G.@H@("`@)&%C=&EO
M;B`]('-T<E]R97!L86-E*"=?<F5P;W)T)RP@)R<L("1A8W1I;VY)1"D["B`@
M("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]3<&%M+G!H<"<["B`@
M("`D:6UP7W-P86T@/2`F;F5W($E-4%]3<&%M*"D["B`@("`D:6UP7W-P86TM
M/G)E<&]R=%-P86TH)&EN9&EC97-?;6)O>"P@)&%C=&EO;BD["@H@("`@+RH@
M1&5L971E('-P86T@869T97(@<F5P;W)T+B`J+PH@("`@)&1E;&5T95]S<&%M
M(#T@)'!R969S+3YG971686QU92@G9&5L971E7W-P86U?869T97)?<F5P;W)T
M)RD["B`@("!I9B`H*"1A8W1I;VX@/3T@)W-P86TG*2`F)B`H)&1E;&5T95]S
M<&%M(#T](#$I*2!["B`@("`@("`@:68@*%]D96QE=&5-97-S86=E<R@D:6YD
M:6-E<U]M8F]X*2D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)&EN9&EC97,I
M(#T](#$I('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B,2!M97-S86=E(&AA<R!B965N(&1E;&5T960N(BDL("=H;W)D92YM97-S
M86=E)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B)60@;65S<V%G97,@:&%V
M92!B965N(&1E;&5T960N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]U;G0H)&EN9&EC97,I*2P@)VAO<F1E+FUE
M<W-A9V4G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T@96QS96EF
M("@D9&5L971E7W-P86T@/3T@,BD@>PH@("`@("`@("1T87)G971-8F]X(#T@
M*"1A8W1I;VX@/3T@)W-P86TG*2`_($E-4#HZ9F]L9&5R4')E9B@D<')E9G,M
M/F=E=%9A;'5E*"=S<&%M7V9O;&1E<B<I+"!T<G5E*2`Z("=)3D)/6"<["B`@
M("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O365S<V%G92YP
M:'`G.PH@("`@("`@("1I;7!?;65S<V%G92`]("9)35!?365S<V%G93HZ<VEN
M9VQE=&]N*"D["B`@("`@("`@)&EM<%]M97-S86=E+3YC;W!Y*"1T87)G971-
M8F]X+"!)35!?34534T%'15]-3U9%+"`D:6YD:6-E<U]M8F]X*3L*("`@('T*
M("`@(&)R96%K.PH*8V%S92`G;65S<V%G95]M:7-S:6YG)SH*("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B4F5Q=65S=&5D(&UE<W-A9V4@;F]T(&9O=6YD
M+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&)R96%K.PH*8V%S92`G9G=D7V1I
M9V5S="<Z"B`@("`D;W!T:6]N<R`](&%R<F%Y*"=F=V1D:6=E<W0G(#T^('-E
M<FEA;&EZ92@D:6YD:6-E<RDL("=A8W1I;VY)1"<@/3X@)V9W9%]D:6=E<W0G
M*3L*("`@("1O<&5N7V-O;7!O<V5?=VEN9&]W(#T@24U0.CIO<&5N0V]M<&]S
M95=I;B@D;W!T:6]N<RD["B`@("!B<F5A:SL*"F-A<V4@)V1E;&5T95]M97-S
M86=E<R<Z"B`@("!?9&5L971E365S<V%G97,H)&EN9&EC97-?;6)O>"D["B`@
M("!B<F5A:SL*"F-A<V4@)W5N9&5L971E7VUE<W-A9V5S)SH*("`@(&EF("@A
M96UP='DH)&EN9&EC97-?;6)O>"DI('L*("`@("`@("!R97%U:7)E7V]N8V4@
M24U07T)!4T4@+B`G+VQI8B]-97-S86=E+G!H<"<["B`@("`@("`@)&EM<%]M
M97-S86=E(#T@)DE-4%]-97-S86=E.CIS:6YG;&5T;VXH*3L*("`@("`@("`D
M:6UP7VUE<W-A9V4M/G5N9&5L971E*"1I;F1I8V5S7VUB;W@I.PH@("`@?0H@
M("`@8G)E86L["@IC87-E("=M;W9E7VUE<W-A9V5S)SH*8V%S92`G8V]P>5]M
M97-S86=E<R<Z"B`@("!I9B`H(65M<'1Y*"1I;F1I8V5S*2`F)B`A96UP='DH
M)'1A<F=E=$UB;W@I*2!["B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%
M("X@)R]L:6(O365S<V%G92YP:'`G.PH@("`@("`@("1I;7!?;65S<V%G92`]
M("9)35!?365S<V%G93HZ<VEN9VQE=&]N*"D["B`@("`@("`@)&%C=&EO;B`]
M("@D86-T:6]N240@/3T@)VUO=F5?;65S<V%G97,G*2`_($E-4%]-15-304=%
M7TU/5D4@.B!)35!?34534T%'15]#3U!9.PH*("`@("`@("!I9B`H)&-O;F9;
M)W1A<VML:7-T)UU;)W5S95]T87-K;&ES="==("8F"B`@("`@("`@("`@("AS
M=')P;W,H)'1A<F=E=$UB;W@L("=?=&%S:VQI<W1?)RD@/3T](#`I*2!["B`@
M("`@("`@("`@("\J($EF('1H92!T87)G970@:7,@82!T87-K;&ES="P@:&%N
M9&QE('1H92!M;W9E+V-O<'D@<W!E8VEA;&QY+B`J+PH@("`@("`@("`@("`D
M=&%S:VQI<W0@/2!S=')?<F5P;&%C92@G7W1A<VML:7-T7R<L("<G+"`D=&%R
M9V5T36)O>"D["B`@("`@("`@("`@("1I;7!?;65S<V%G92T^8W)E871E5&%S
M:W-/<DYO=&5S*"1T87-K;&ES="P@)&%C=&EO;BP@)&EN9&EC97-?;6)O>"P@
M)W1A<VLG*3L*("`@("`@("!](&5L<V5I9B`H)&-O;F9;)VYO=&5P860G75LG
M=7-E7VYO=&5P860G72`F)@H@("`@("`@("`@("`H<W1R<&]S*"1T87)G971-
M8F]X+"`G7VYO=&5P861?)RD@/3T](#`I*2!["B`@("`@("`@("`@("\J($EF
M('1H92!T87)G970@:7,@82!N;W1E<&%D+"!H86YD;&4@=&AE(&UO=F4O8V]P
M>2!S<&5C:6%L;'DN("HO"B`@("`@("`@("`@("1N;W1E<&%D(#T@<W1R7W)E
M<&QA8V4H)U]N;W1E<&%D7R<L("<G+"`D=&%R9V5T36)O>"D["B`@("`@("`@
M("`@("1I;7!?;65S<V%G92T^8W)E871E5&%S:W-/<DYO=&5S*"1N;W1E<&%D
M+"`D86-T:6]N+"`D:6YD:6-E<U]M8F]X+"`G;F]T92<I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\J($]T:&5R=VES92P@=&AE('1A<F=E="!I
M<R!A('-T86YD87)D(&UA:6QB;W@N("HO"B`@("`@("`@("`@(&EF("@A96UP
M='DH)&YE=TUB;W@I("8F("@D;F5W36)O>"`]/2`Q*2D@>PH@("`@("`@("`@
M("`@("`@)&YE=U]M86EL8F]X(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="A)
M35`Z.F9O;&1E<E!R968H)'1A<F=E=$UB;W@L('1R=64I+"`D8VAA<G-E="P@
M)U541C<M24U!4"<I.PH*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+T9O;&1E<BYP:'`G.PH@("`@("`@("`@("`@("`@
M)&EM<%]F;VQD97(@/2`F24U07T9O;&1E<CHZ<VEN9VQE=&]N*"D["B`@("`@
M("`@("`@("`@("!I9B`H)&EM<%]F;VQD97(M/F-R96%T92@D;F5W7VUA:6QB
M;W@L("1P<F5F<RT^9V5T5F%L=64H)W-U8G-C<FEB92<I*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1I;7!?;65S<V%G92T^8V]P>2@D;F5W7VUA:6QB;W@L
M("1A8W1I;VXL("1I;F1I8V5S7VUB;W@I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&EM<%]M97-S
M86=E+3YC;W!Y*"1T87)G971-8F]X+"`D86-T:6]N+"`D:6YD:6-E<U]M8F]X
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*
M8V%S92`G9FQA9U]M97-S86=E<R<Z"B`@("`D9FQA9R`](%5T:6PZ.F=E=%!O
M<W0H)V9L86<G*3L*("`@(&EF("@A96UP='DH)&EN9&EC97,I("8F("%E;7!T
M>2@D9FQA9RDI('L*("`@("`@("!I9B`H)&9L86=[,'T@/3T@)S`G*2!["B`@
M("`@("`@("`@("1?4$]35%LG9FQA9R==(#T@)UQ<)R`N('-U8G-T<B@D9FQA
M9RP@,2D["B`@("`@("`@("`@("1S970@/2!F86QS93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D7U!/4U1;)V9L86<G72`]("=<7"<@+B`D9FQA
M9SL*("`@("`@("`@("`@)'-E="`]('1R=64["B`@("`@("`@?0H@("`@("`@
M(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TUE<W-A9V4N<&AP)SL*
M("`@("`@("`D:6UP7VUE<W-A9V4@/2`F24U07TUE<W-A9V4Z.G-I;F=L971O
M;B@I.PH@("`@("`@("1I;7!?;65S<V%G92T^9FQA9R@D7U!/4U1;)V9L86<G
M72P@)&EN9&EC97-?;6)O>"P@)'-E="D["B`@("!]"B`@("!B<F5A:SL*"F-A
M<V4@)VAI9&5?9&5L971E9"<Z"B`@("`D<')E9G,M/G-E=%9A;'5E*"=D96QH
M:61E)RP@(21P<F5F<RT^9V5T5F%L=64H)V1E;&AI9&4G*2D["B`@("!B<F5A
M:SL*"F-A<V4@)V5X<'5N9V5?;6%I;&)O>"<Z"B`@("!R97%U:7)E7V]N8V4@
M24U07T)!4T4@+B`G+VQI8B]-97-S86=E+G!H<"<["B`@("`D:6UP7VUE<W-A
M9V4@/2`F24U07TUE<W-A9V4Z.G-I;F=L971O;B@I.PH@("`@)&EM<%]M97-S
M86=E+3YE>'!U;F=E36%I;&)O>"AA<G)A>2@D:6UP6R=M86EL8F]X)UTI*3L*
M("`@(&)R96%K.PH*8V%S92`G9FEL=&5R)SH*("`@("1D;U]F:6QT97(@/2!T
M<G5E.PH@("`@8G)E86L["@IC87-E("=E;7!T>5]M86EL8F]X)SH*("`@(')E
M<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TUE<W-A9V4N<&AP)SL*("`@
M("1I;7!?;65S<V%G92`]("9)35!?365S<V%G93HZ<VEN9VQE=&]N*"D["B`@
M("`D:6UP7VUE<W-A9V4M/F5M<'1Y36%I;&)O>"AA<G)A>2@D:6UP6R=M86EL
M8F]X)UTI*3L*("`@(&)R96%K.PH*8V%S92`G=FEE=U]M97-S86=E<R<Z"B`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY/8FIE8W1S+G!H<"<["B`@
M("`D8V%C:&5397-S(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T
M;VXH*3L*("`@("1R961I<F5C="`](%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D
M93HZ87!P;&EC871I;VY5<FPH)W1H<F5A9"YP:'`G+"!T<G5E*2P@87)R87DH
M)VUO9&4G(#T^("=M<V=V:65W)RP@)VUS9VQI<W0G(#T^("1C86-H95-E<W,M
M/G-T;W)E3VED*"1I;F1I8V5S7VUB;W@I*2P@;G5L;"P@9F%L<V4I.PH@("`@
M:&5A9&5R*"),;V-A=&EO;CH@(B`N("1R961I<F5C="D["B`@("!E>&ET.PH@
M("`@8G)E86L["GT*"B\J($ES('1H:7,@82!S96%R8V@@;6%I;&)O>#\@*B\*
M)'-E87)C:%]M8F]X(#T@)&EM<%]S96%R8V@M/G-E87)C:$UB;WA)1"@I.PH*
M+RH@1&5A;"!W:71H(&9I;'1E<B!O<'1I;VYS+B`J+PII9B`H)&EM<%LG9FEL
M=&5R879A:6PG72D@>PH@("`@+RH@3VYL>2!A;&QO=R!F:6QT97(@;VX@9&ES
M<&QA>2!F;W(@24Y"3U@N("HO"B`@("!I9B`H*"1I;7!;)VUA:6QB;W@G72`]
M/2`G24Y"3U@G*2`F)B`D<')E9G,M/F=E=%9A;'5E*"=F:6QT97)?;VY?9&ES
M<&QA>2<I*2!["B`@("`@("`@)&1O7V9I;'1E<B`]('1R=64["B`@("!](&5L
M<V5I9B`H*"1I;7!;)VUA:6QB;W@G72`]/2`G24Y"3U@G*2!\?`H@("`@("`@
M("`@("`@("@D<')E9G,M/F=E=%9A;'5E*"=F:6QT97)?86YY7VUA:6QB;W@G
M*2`F)B`A)'-E87)C:%]M8F]X*2D@>PH@("`@("`@("1F:6QT97)?=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1M86EL8F]X7W5R;"P@)V%C=&EO;DE$)RP@
M)V9I;'1E<B<I.PH@("`@?0I]"@HO*B!2=6X@9FEL=&5R<R!N;W<N("HO"FEF
M("@D9&]?9FEL=&5R*2!["B`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G
M+VQI8B]&:6QT97(N<&AP)SL*("`@("1I;7!?9FEL=&5R(#T@)DE-4%]&:6QT
M97(Z.G-I;F=L971O;B@I.PH@("`@)&EM<%]F:6QT97(M/F9I;'1E<B@D:6UP
M6R=M86EL8F]X)UTI.PI]"@HO*B!'96YE<F%T92!F;VQD97(@;W!T:6]N<R!L
M:7-T+B`J+PII9B`H)&-O;F9;)W5S97(G75LG86QL;W=?9F]L9&5R<R==*2![
M"B`@("`D9F]L9&5R7V]P=&EO;G,@/2!)35`Z.F9L:7-T4V5L96-T*%\H(DUE
M<W-A9V5S('1O(BDL('1R=64L(&%R<F%Y*&YU;&PL("1I;7!;)VUA:6QB;W@G
M72DL(&YU;&PL('1R=64L('1R=64L(&9A;'-E+"!T<G5E*3L*?0H*+RH@0G5I
M;&0@=&AE(&QI<W0@;V8@;65S<V%G97,@:6X@=&AE(&UA:6QB;W@N("HO"FEF
M("@A:7-S970H)&EM<%]M86EL8F]X*2D@>PH@("`@)&EM<%]M86EL8F]X(#T@
M)DE-4%]-86EL8F]X.CIS:6YG;&5T;VXH*3L*?0HD:6UP7VUA:6QB;W@M/G-E
M=$YO3F5W;6%I;%!O<'5P*%5T:6PZ.F=E=$9O<FU$871A*"=N;U]N97=M86EL
M7W!O<'5P)RDI.PHD<&%G94]B(#T@)&EM<%]M86EL8F]X+3YB=6EL9$UA:6QB
M;WA086=E*%5T:6PZ.F=E=$9O<FU$871A*"=P86=E)RDL("1S=&%R="D["B1M
M86EL8F]X3W9E<G9I97<@/2`D:6UP7VUA:6QB;W@M/F)U:6QD36%I;&)O>$%R
M<F%Y*"1P86=E3V(M/F)E9VEN+"`D<&%G94]B+3YE;F0I.PH*+RH@0V%C:&4@
M=&AI<R!V86QU92!S:6YC92!W92!U<V4@:70@86QO="!O;B!T:&ES('!A9V4N
M("HO"B1G<F%P:&EC<V1I<B`]("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO
M<F1E)RD["@HO*B!'96YE<F%T92!&:7)S="]0<F5V:6]U<R!P86=E(&QI;FMS
M+B`J+PII9B`H)'!A9V5/8BT^<&%G92`]/2`Q*2!["B`@("`D<&%G97-?9FER
M<W0@/2!(;W)D93HZ:6UG*"=N878O9FER<W0M9W)E>2YP;F<G+"!N=6QL+"!N
M=6QL+"`D9W)A<&AI8W-D:7(I.PH@("`@)'!A9V5S7W!R978@/2!(;W)D93HZ
M:6UG*"=N878O;&5F="UG<F5Y+G!N9R<L(&YU;&PL(&YU;&PL("1G<F%P:&EC
M<V1I<BD["GT@96QS92!["B`@("`D9FER<W1?=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1M86EL8F]X7W5R;"P@)W!A9V4G+"`Q*3L*("`@("1P86=E<U]F
M:7)S="`]($AO<F1E.CIL:6YK*"1F:7)S=%]U<FPL(%\H(D9I<G-T(%!A9V4B
M*2D@+B!(;W)D93HZ:6UG*"=N878O9FER<W0N<&YG)RP@)SP\)RP@;G5L;"P@
M)&=R87!H:6-S9&ER*2`N("<\+V$^)SL*("`@("1P<F5V7W5R;"`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D;6%I;&)O>%]U<FPL("=P86=E)RP@)'!A9V5/8BT^
M<&%G92`M(#$I.PH@("`@)'!A9V5S7W!R978@/2!(;W)D93HZ;&EN:R@D<')E
M=E]U<FPL(%\H(E!R979I;W5S(%!A9V4B*2P@)R<L("<G+"`G)RP@)R<L("<G
M+"!A<G)A>2@G:60G(#T^("=P<F5V)RDI("X@2&]R9&4Z.FEM9R@G;F%V+VQE
M9G0N<&YG)RP@)SPG+"!N=6QL+"`D9W)A<&AI8W-D:7(I("X@)SPO83XG.PI]
M"@HO*B!'96YE<F%T92!.97AT+TQA<W0@<&%G92!L:6YK<RX@*B\*:68@*"1P
M86=E3V(M/G!A9V4@/3T@)'!A9V5/8BT^<&%G96-O=6YT*2!["B`@("`D<&%G
M97-?;&%S="`]($AO<F1E.CII;6<H)VYA=B]L87-T+6=R97DN<&YG)RP@;G5L
M;"P@;G5L;"P@)&=R87!H:6-S9&ER*3L*("`@("1P86=E<U]N97AT(#T@2&]R
M9&4Z.FEM9R@G;F%V+W)I9VAT+6=R97DN<&YG)RP@;G5L;"P@;G5L;"P@)&=R
M87!H:6-S9&ER*3L*?2!E;'-E('L*("`@("1N97AT7W5R;"`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D;6%I;&)O>%]U<FPL("=P86=E)RP@)'!A9V5/8BT^<&%G
M92`K(#$I.PH@("`@)'!A9V5S7VYE>'0@/2!(;W)D93HZ;&EN:R@D;F5X=%]U
M<FPL(%\H(DYE>'0@4&%G92(I+"`G)RP@)R<L("<G+"`G)RP@)R<L(&%R<F%Y
M*"=I9"<@/3X@)VYE>'0G*2D@+B!(;W)D93HZ:6UG*"=N878O<FEG:'0N<&YG
M)RP@)SXG+"!N=6QL+"`D9W)A<&AI8W-D:7(I("X@)SPO83XG.PH@("`@)&QA
M<W1?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1M86EL8F]X7W5R;"P@)W!A
M9V4G+"`D<&%G94]B+3YP86=E8V]U;G0I.PH@("`@)'!A9V5S7VQA<W0@/2!(
M;W)D93HZ;&EN:R@D;&%S=%]U<FPL(%\H(DQA<W0@4&%G92(I*2`N($AO<F1E
M.CII;6<H)VYA=B]L87-T+G!N9R<L("<^/B<L(&YU;&PL("1G<F%P:&EC<V1I
M<BD@+B`G/"]A/B<["GT*"B\J($1E=&5R;6EN92!I9B!W92!A<F4@9V]I;F<@
M=&\@<VAO=R!T:&4@2&ED92]0=7)G92!$96QE=&5D($UE<W-A9V4@;&EN:W,N
M("HO"B1S:&]W9&5L971E(#T@)&EM<%]M86EL8F]X+3YS:&]W1&5L971E3&EN
M:W,H*3L*:68@*"1S:&]W9&5L971E6R=H:61E)UT@)B8@(21P<F5F<RT^:7-,
M;V-K960H)V1E;&AI9&4G*2D@>PH@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H
M)V1E;&AI9&4G*2D@>PH@("`@("`@("1D96QE=&5D7W!R;VUP="`](%\H(E-H
M;W<@1&5L971E9"(I.PH@("`@?2!E;'-E('L*("`@("`@("`D9&5L971E9%]P
M<F]M<'0@/2!?*")(:61E($1E;&5T960B*3L*("`@('T*?0H*+RH@1V5N97)A
M=&4@;6%I;&)O>"!S=6UM87)Y('-T<FEN9RX@*B\*:68@*"%E;7!T>2@D<&%G
M94]B+3YE;F0I*2!["B`@("`D;7-G7V-O=6YT(#T@<W!R:6YT9BA?*"(E9"!T
M;R`E9"!O9B`E9"!-97-S86=E<R(I+"`D<&%G94]B+3YB96=I;BP@)'!A9V5/
M8BT^96YD+"`D<&%G94]B+3YM<V=C;W5N="D["GT@96QS92!["B`@("`D;7-G
M7V-O=6YT(#T@<W!R:6YT9BA?*").;R!-97-S86=E<R(I*3L*?0H*+RH@268@
M=7-E<B!W86YT<R!T:&4@;6%I;&)O>"!T;R!B92!R969R97-H960L('-E="!T
M:6UE(&AE<F4N("HO"B1R969R97-H7W1I;64@/2`D<')E9G,M/F=E=%9A;'5E
M*"=R969R97-H7W1I;64G*3L*)')E9G)E<VA?=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1M86EL8F]X7W5R;"P@)W!A9V4G+"`D<&%G94]B+3YP86=E*3L*
M:68@*&ES<V5T*"1F:6QT97)?=7)L*2D@>PH@("`@)&9I;'1E<E]U<FP@/2!5
M=&EL.CIA9&1087)A;65T97(H)&9I;'1E<E]U<FPL("=P86=E)RP@)'!A9V5/
M8BT^<&%G92D["GT*"B\J(%-E="!T:&4@9F]L9&5R(&9O<B!T:&4@<V]R="!L
M:6YK<RX@*B\*)'-O<G1D:7(@/2`D<')E9G,M/F=E=%9A;'5E*"=S;W)T9&ER
M)RD["B1S;W)T7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D;6%I;&)O>%]U
M<FPL("=S;W)T9&ER)RP@*"1S;W)T9&ER*2`_(#`@.B`Q*3L*"B\J($1E=&5R
M;6EN92!I9B!W92!A<F4@<VAO=VEN9R!P<F5V:65W<RX@*B\*)'-H;W=?<')E
M=FEE=R`]("1I;7!?;6%I;&)O>"T^<VAO=U!R979I97=S*"D["B1P<F5V:65W
M7W1O;VQT:7`@/2`H)'-H;W=?<')E=FEE=RD@/R`D<')E9G,M/F=E=%9A;'5E
M*"=P<F5V:65W7W-H;W=?=&]O;'1I<"<I(#H@9F%L<V4["FEF("@D<')E=FEE
M=U]T;V]L=&EP*2!["B`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G=&]O;'1I
M<"YJ<R<L("=H;W)D92<L('1R=64I.PI](&5L<V4@>PH@("`@)'-T<FEP7W!R
M979I97<@/2`D<')E9G,M/F=E=%9A;'5E*"=P<F5V:65W7W-T<FEP7VYL)RD[
M"GT*"B1V=')A<V@@/2!N=6QL.PII9B`H)'-E87)C:%]M8F]X*2!["B`@("`D
M=6YR96%D(#T@,#L*("`@(&EF("@D:6UP7W-E87)C:"T^:7-624Y"3UA&;VQD
M97(H*2D@>PH@("`@("`@("1U;G)E860@/2`D:6UP7VUA:6QB;W@M/F=E=$UE
M<W-A9V5#;W5N="@I.PH@("`@?2!E;'-E:68@*"1I;7!?<V5A<F-H+3YI<U94
M<F%S:$9O;&1E<B@I*2!["B`@("`@("`@)'9T<F%S:"`]($E-4%]314%20TA?
M34)/6"`N("1S96%R8VA?;6)O>#L*("`@('T*?2!E;'-E('L*("`@("1U;G)E
M860@/2!C;W5N="@D:6UP7VUA:6QB;W@M/G5N<V5E;DUE<W-A9V5S*"DI.PI]
M"@HO*B!0;&%Y(&%U9&EO+B`J+PII9B`H)'!R969S+3YG971686QU92@G;F%V
M7V%U9&EO)RD@)B8*("`@("@D;F5W;7-G<R`]("1I;7!?;6%I;&)O>"T^;F5W
M365S<V%G94-O=6YT*"DI("8F"B`@("`H)&YE=VUS9W,@/B`P*2`F)@H@("`@
M(55T:6PZ.F=E=$9O<FU$871A*"=N;U]N97=M86EL7W!O<'5P)RDI('L*("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H)')E9VES=')Y+3YG971);6%G941I<B@I
M("X@)R]A=61I;R]T:&5E=&]N92YW878G+"`G875D:6\G*3L*?0H*)'1I=&QE
M(#T@24U0.CIG971,86)E;"@I.PHD<F5F<F5S:%]T:71L92`]('-P<FEN=&8H
M7R@B7U)E9G)E<V@@)7,B*2P@)'1I=&QE*3L*)')E9G)E<VA?86L@/2!(;W)D
M93HZ9V5T06-C97-S2V5Y*"1R969R97-H7W1I=&QE*3L*)')E9G)E<VA?=&ET
M;&4@/2!(;W)D93HZ<W1R:7!!8V-E<W-+97DH)')E9G)E<VA?=&ET;&4I.PII
M9B`H(65M<'1Y*"1R969R97-H7V%K*2D@>PH@("`@)')E9G)E<VA?=&ET;&4@
M+CT@<W!R:6YT9BA?*"(@*$%C8V5S<VME>2`E<RDB*2P@)')E9G)E<VA?86LI
M.PI]"FEF("@D=6YR96%D*2!["B`@("`D=&ET;&4@+CT@)R`H)R`N("1U;G)E
M860@+B`G*2<["GT*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VME>6)I;F1I;F=S
M+FIS)RP@)VAO<F1E)RD["G)E<75I<F4@24U07U1%35!,051%4R`N("<O8V]M
M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($E-4%]414U03$%415,@+B`G+VUE
M;G4N:6YC)SL*:68@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=J879A<V-R:7!T
M)RDI('L*("`@(')E<75I<F4@24U07U1%35!,051%4R`N("<O;6%I;&)O>"]J
M879A<V-R:7!T+FEN8R<["GT*24U0.CIS=&%T=7,H*3L*"B\J(%!R:6YT('%U
M;W1A(&EN9F]R;6%T:6]N+B`J+PII9B`H:7-S970H)&EM<%LG<75O=&$G72D@
M)B8@:7-?87)R87DH)&EM<%LG<75O=&$G72DI('L*("`@(')E<75I<F5?;VYC
M92!)35!?0D%312`N("<O;&EB+U%U;W1A+G!H<"<["B`@("`D<75O=&%$<FEV
M97(@/2`F24U07U%U;W1A.CIS:6YG;&5T;VXH)&EM<%LG<75O=&$G75LG9')I
M=F5R)UTL("1I;7!;)W%U;W1A)UU;)W!A<F%M<R==*3L*("`@(&EF("@D<75O
M=&%$<FEV97(@(3T](&9A;'-E*2!["B`@("`@("`@)'%U;W1A(#T@)'%U;W1A
M1')I=F5R+3YG9711=6]T82@I.PH@("`@("`@(')E<75I<F4@24U07U1%35!,
M051%4R`N("<O<75O=&$O<75O=&$N:6YC)SL*("`@('T*?0H*+RH@07)E('=E
M(&-U<G)E;G1L>2!I;B!T:&4@=')A<V@@;6%I;&)O>#\@*B\*)'5S95]T<F%S
M:"`]("1P<F5F<RT^9V5T5F%L=64H)W5S95]T<F%S:"<I.PHD=7-E7W9T<F%S
M:"`]("1P<F5F<RT^9V5T5F%L=64H)W5S95]V=')A<V@G*3L*)'1R87-H36)O
M>"`]("@D=7-E7W1R87-H("8F("@D:6UP6R=M86EL8F]X)UT@/3T@*$E-4#HZ
M9F]L9&5R4')E9B@D<')E9G,M/F=E=%9A;'5E*"=T<F%S:%]F;VQD97(G*2P@
M=')U92DI*2D@?'P*("`@("`@("`@("`@("@D=7-E7W9T<F%S:"`F)B`A:7-?
M;G5L;"@D=G1R87-H*2D["@HO*B!3:&]W('1H92!;8FQA8VM\=VAI=&5=;&ES
M="!L:6YK(&EF('=E(&AA=F4@9G5N8W1I;VYA;&ET>2!E;F%B;&5D+B`J+PHD
M<VAO=U]B;&%C:VQI<W1?;&EN:R`]("1R96=I<W1R>2T^:&%S365T:&]D*"=M
M86EL+V)L86-K;&ES=$9R;VTG*3L*)'-H;W=?=VAI=&5L:7-T7VQI;FL@/2`D
M<F5G:7-T<GDM/FAA<TUE=&AO9"@G;6%I;"]W:&ET96QI<W1&<F]M)RD["@IR
M97%U:7)E($E-4%]414U03$%415,@+B`G+VUA:6QB;W@O:&5A9&5R+FEN8R<[
M"@HO*B!)9B!N;R!M97-S86=E<RP@97AI="!I;6UE9&EA=&5L>2X@*B\*:68@
M*&5M<'1Y*"1P86=E3V(M/F5N9"DI('L*("`@(&EF("@D<&%G94]B+3YA;GEM
M<V<@)B8@:7-S970H)&1E;&5T961?<')O;7!T*2D@>PH@("`@("`@("\J(%-H
M;W<@)U-H;W<@1&5L971E9"<@<')O;7!T(&EF(&UA:6QB;W@@:&%S(&YO('9I
M97=A8FQE(&UE<W-A9V4@8G5T"B`@("`@("`@("`@:&%S(&AI9&1E;BP@9&5L
M971E9"!M97-S86=E<RX@*B\*("`@("`@("!R97%U:7)E($E-4%]414U03$%4
M15,@+B`G+VUA:6QB;W@O86-T:6]N<U]D96QE=&5D+FEN8R<["B`@("!]"B`@
M("!R97%U:7)E($E-4%]414U03$%415,@+B`G+VUA:6QB;W@O96UP='E?;6%I
M;&)O>"YI;F,G.PH@("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]M86EL
M8F]X+V9O;W1E<BYI;F,G.PH@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G
M=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*
M("`@(&5X:70["GT*"B\J($EF('1H97)E(&%R92!M;W)E('1H86X@,34@;65S
M<V%G97,L(&-A8VAE('1H92!A8W1I;VYS(&]U='!U="X@*B\*:68@*"1P86=E
M3V(M/FUS9V-O=6YT("$](#`I('L*("`@("1N879F;W)M(#T@,3L*("`@(')E
M<75I<F4@24U07U1%35!,051%4R`N("<O;6%I;&)O>"]N879B87(N:6YC)SL*
M("`@(&EF("@D<&%G94]B+3YM<V=C;W5N="`^(#$U*2!["B`@("`@("`@;V)?
M<W1A<G0H*3L*("`@("`@("!R97%U:7)E($E-4%]414U03$%415,@+B`G+VUA
M:6QB;W@O86-T:6]N<RYI;F,G.PH@("`@("`@("1A8W1I;VYS7V]U='!U="`]
M(&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH@
M("`@("`@(&5C:&\@)&%C=&EO;G-?;W5T<'5T.PH@("`@?2!E;'-E('L*("`@
M("`@("!R97%U:7)E($E-4%]414U03$%415,@+B`G+VUA:6QB;W@O86-T:6]N
M<RYI;F,G.PH@("`@?0I]"@HO*B!$969I;F4@<V]M92!V87)I86)L97,@;F]W
M('-O('=E(&1O;B=T(&AA=F4@=&\@:V5E<"!R961E9FEN:6YG(&EN('1H90H@
M("!F;W)E86-H*"D@;&]O<"!O<B!T:&4@=&5M<&QA=&5S+B`J+PHD8W5R<E]T
M:6UE(#T@=&EM92@I.PHD8W5R<E]T:6UE("T]("1C=7)R7W1I;64@)2`V,#L*
M)&QT:6UE7W9A;"`](&QO8V%L=&EM92@I.PHD=&]D87E?<W1A<G0@/2!M:W1I
M;64H,"P@,"P@,"P@)&QT:6UE7W9A;%LT72`K(#$L("1L=&EM95]V86Q;,UTL
M(#$Y,#`@*R`D;'1I;65?=F%L6S5=*3L*)'1O9&%Y7V5N9"`]("1T;V1A>5]S
M=&%R="`K(#@V-#`P.PHD9')A9G1S7W-M7V9O;&1E<B`]("1I;7!?;6%I;&)O
M>"T^:7-3<&5C:6%L1F]L9&5R*"D["B1L87-T36)O>"`]("<G.PHD;65S<V%G
M97,@/2!A<G)A>2@I.PHD=&AR96%D;&5V96P@/2!A<G)A>2@I.PH*+RH@1&5T
M97)M:6YE('-O<G1I;F<@<')E9F5R96YC97,N("HO"B1S;W)T8GD@/2`D:6UP
M7VUA:6QB;W@M/G-O<G1B>2@I.PHD=&AR96%D7W-O<G0@/2`H)'-O<G1B>2`]
M/2!33U)45$A214%$*3L*)'-O<G1L:6UI="`]("1I;7!?;6%I;&)O>"T^86)O
M=F53;W)T3&EM:70H*3L*"B\J($=E="!T:')E860@;V)J96-T+"!I9B!N96-E
M<W-A<GDN("HO"FEF("@D=&AR96%D7W-O<G0I('L*("`@("1T:')E861O8B`]
M("1I;7!?;6%I;&)O>"T^9V5T5&AR96%D3V(H*3L*("`@("1U:61?;&ES="`]
M(&%R<F%Y*"D["B`@("!F;W)E86-H("@D;6%I;&)O>$]V97)V:65W(&%S("1V
M86PI('L*("`@("`@("`D=6ED7VQI<W1;72`]("1V86Q;)VAE861E<B==+3YU
M:60["B`@("!]"B`@("`D=&AR96%D=')E92`]("1T:')E861O8BT^9V5T5&AR
M96%D26UA9V54<F5E*"1U:61?;&ES="P@)'-O<G1D:7(I.PI]"@HO*B!$;VXG
M="!S:&]W(&AE861E<B!R;W<@:68@=&AI<R!I<R!A('-E87)C:"!M86EL8F]X
M(&]R(&EF(&YO(&UE<W-A9V5S(&EN('1H90H@("!C=7)R96YT(&UA:6QB;W@N
M("HO"FEF("@A)'-E87)C:%]M8F]X("8F("@D<&%G94]B+3YM<V=C;W5N="`A
M/2`P*2D@>PH@("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]M86EL8F]X
M+VUE<W-A9V5?:&5A9&5R<RYI;F,G.PI]"@HO*B!#86-H92!S;VUE(')E<&5T
M:71I=F5L>2!U<V5D('9A<FEA8FQE<RX@*B\*)&1A=&5F;70@/2`D<')E9G,M
M/F=E=%9A;'5E*"=D871E7V9O<FUA="<I.PHD=&EM969M="`]("1P<F5F<RT^
M9V5T5F%L=64H)W1I;65?9F]R;6%T)RD["B1F<F]M;&EN:W-T>6QE(#T@)'!R
M969S+3YG971686QU92@G9G)O;5]L:6YK)RD["B1L;V-A;&5I;F9O(#T@3DQ3
M.CIG971,;V-A;&5);F9O*"D["@HO*B!$:7-P;&%Y(&UE<W-A9V4@:6YF;W)M
M871I;VXN("HO"B1M<V=S(#T@87)R87DH*3L*9F]R96%C:"`H)&UA:6QB;WA/
M=F5R=FEE=R!A<R`D;7-G26YD97@@/3X@)&UE<W-A9V4I('L*("`@(&EF("@D
M<V5A<F-H7VUB;W@I('L*("`@("`@("!I9B`H96UP='DH)&QA<W1-8F]X*2!\
M?"`H)&UE<W-A9V5;)VUB;W@G72`A/2`D;&%S=$UB;W@I*2!["B`@("`@("`@
M("`@(&EF("@A96UP='DH)&QA<W1-8F]X*2D@>PH@("`@("`@("`@("`@("`@
M7V]U='!U=%-U;6UA<FEE<R@D<V5A<F-H7VUB;W@L("1M<V=S*3L*("`@("`@
M("`@("`@("`@("1M<V=S(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D9F]L9&5R7VQI;FL@/2!(;W)D93HZ=7)L*%5T:6PZ.F%D9%!A
M<F%M971E<B@G;6%I;&)O>"YP:'`G+"`G;6%I;&)O>"<L("1M97-S86=E6R=M
M8F]X)UTI*3L*("`@("`@("`@("`@)&9O;&1E<E]L:6YK(#T@2&]R9&4Z.FQI
M;FLH)&9O;&1E<E]L:6YK+"!S<')I;G1F*%\H(E9I97<@;65S<V%G97,@:6X@
M)7,B*2P@24U0.CID:7-P;&%Y1F]L9&5R*"1M97-S86=E6R=M8F]X)UTI*2P@
M)W-M86QL:&5A9&5R)RD@+B!)35`Z.F1I<W!L87E&;VQD97(H)&UE<W-A9V5;
M)VUB;W@G72D@+B`G/"]A/B<["B`@("`@("`@("`@(')E<75I<F4@24U07U1%
M35!,051%4R`N("<O;6%I;&)O>"]S96%R8VAF;VQD97(N:6YC)SL*("`@("`@
M("`@("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]M86EL8F]X+VUE<W-A
M9V5?:&5A9&5R<RYI;F,G.PH@("`@("`@('T*("`@("`@("`D;&%S=$UB;W@@
M/2`D;65S<V%G95LG;6)O>"==.PH@("`@?0H*("`@("\J($EN:71I86QI>F4@
M=&AE(&AE861E<B!F:65L9',N("HO"B`@("`D;7-G(#T@87)R87DH"B`@("`@
M("`@)V-O;&]R)R`]/B`H:7-S970H)&UE<W-A9V5;)V-O;&]R)UTI*2`_("1M
M97-S86=E6R=C;VQO<B==(#H@)R<L"B`@("`@("`@)V1A=&4G(#T^("<F;F)S
M<#LG+`H@("`@("`@("=F<F]M)R`]/B`G)FYB<W`[)RP*("`@("`@("`G;6)O
M>"<@/3X@)&UE<W-A9V5;)VUB;W@G72P*("`@("`@("`G<')E=FEE=R<@/3X@
M)R<L"B`@("`@("`@)W-I>F4G(#T^("<_)RP*("`@("`@("`G<W5B:F5C="<@
M/3X@7R@B6TYO(%-U8FIE8W1=(BD*("`@("D["@H@("`@+RH@26YI=&EA;&EZ
M92!S;VUE(&]T:&5R('9A<FEA8FQE<RX@*B\*("`@("1A='1A8VAM96YT(#T@
M9F%L<V4["B`@("`D9G)O;5]A9'(@/2!N=6QL.PH@("`@)&UA:6QT;U]L:6YK
M(#T@9F%L<V4["B`@("`D<VAO=V9R;VUL:6YK(#T@=')U93L*"B`@("`O*B!.
M;W<@<'5L;"!T:&4@24U!4"!H96%D97(@=F%L=65S(&EN=&\@=&AE;2P@9&5C
M;V1I;F<@=&AE;2!A=`H@("`@("`@=&AE('-A;64@=&EM92X@*B\*("`@("1H
M(#T@)&UE<W-A9V5;)VAE861E<B==.PH@("`@)&UE<W-A9V5S6UT@/2`D:"T^
M=6ED.PH*("`@("\J($9O<FUA=',@=&AE(&AE861E<B!D871E('-T<FEN9R!N
M:6-E;'DN("HO"B`@("!I9B`H96UP='DH)&@M/F1A=&4I*2!["B`@("`@("`@
M)'5D871E(#T@9F%L<V4["B`@("!](&5L<V4@>PH@("`@("`@("1H+3YD871E
M(#T@<')E9U]R97!L86-E*"<O7',K7"A<=RM<*20O)RP@)R<L("1H+3YD871E
M*3L*("`@("`@("`D=61A=&4@/2!S=')T;W1I;64H)&@M/F1A=&4L("1C=7)R
M7W1I;64I.PH@("`@?0H@("`@:68@*"1U9&%T92`]/3T@9F%L<V4@?'P@)'5D
M871E(#T]/2`M,2D@>PH@("`@("`@("1M<V=;)V1A=&4G72`](%\H(E5N:VYO
M=VX@1&%T92(I.PH@("`@?2!E;'-E:68@*"@D=61A=&4@/"`D=&]D87E?<W1A
M<G0I('Q\("@D=61A=&4@/B`D=&]D87E?96YD*2D@>PH@("`@("`@("\J($YO
M="!T;V1A>2P@=7-E('1H92!D871E+B`J+PH@("`@("`@("1M<V=;)V1A=&4G
M72`]('-T<F9T:6UE*"1D871E9FUT+"`D=61A=&4I.PH@("`@?2!E;'-E('L*
M("`@("`@("`O*B!%;'-E+"!I="=S('1O9&%Y+"!U<V4@=&AE('1I;64N("HO
M"B`@("`@("`@)&US9ULG9&%T92==(#T@<W1R9G1I;64H)'1I;65F;70L("1U
M9&%T92D["B`@("!]"@H@("`@+RH@1F]R;6%T('1H92!F<F]M(&AE861E<BX@
M*B\*("`@(&EF("AI<W-E="@D:"T^9G)O;2DI('L*("`@("`@("`D9G)O;5]A
M9'(@/2!)35`Z.F)A<F5!9&1R97-S*"1H+3YF<F]M*3L*("`@("`@("`D9G)O
M;5]O8B`]($E-4#HZ<&%R<V5!9&1R97-S3&ES="@D:"T^9G)O;2P@)R<I.PH@
M("`@("`@(&EF("@A:7-?82@D9G)O;5]O8BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`D9G)O;5]O8B`](&%R<F%Y7W-H:69T*"1F<F]M7V]B*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&ES7VYU;&PH)&9R;VU?861R*2D@>PH@
M("`@("`@("`@("`D;7-G6R=F<F]M)UT@/2!?*"));G9A;&ED($%D9')E<W,B
M*3L*("`@("`@("`@("`@)'-H;W=F<F]M;&EN:R`](&9A;'-E.PH@("`@("`@
M('T@96QS96EF("@D:61E;G1I='DM/FAA<T%D9')E<W,H)&9R;VU?861R*2D@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)&@M/G1O*2D@>PH@("`@("`@("`@
M("`@("`@:68@*'-T<G-T<B@D:"T^=&\L("=U;F1I<V-L;W-E9"UR96-I<&EE
M;G1S.B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&US9ULG9G)O;2==(#T@
M7R@B56YD:7-C;&]S960@4F5C:7!I96YT<R(I.PH@("`@("`@("`@("`@("`@
M("`@("1S:&]W9G)O;6QI;FL@/2!F86QS93L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]($E-4#HZ<&%R<V5!
M9&1R97-S3&ES="@D:"T^=&\L("<G*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES7V$H)'1M<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&UP(#T@87)R87E?<VAI9G0H)'1M<"D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&UP+3YP97)S;VYA;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&US
M9ULG9G)O;2==(#T@<W1R:7!S;&%S:&5S*$U)344Z.F1E8V]D92@D=&UP+3YP
M97)S;VYA;"P@)&-H87)S970I*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;7-G6R=F<F]M)UT@/2!)
M35`Z.F)A<F5!9&1R97-S*"1H+3YT;RD["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1M<V=;)V9U;&QF<F]M)UT@/2!-24U%
M.CID96-O9&4H)&@M/G1O+"`D8VAA<G-E="D["B`@("`@("`@("`@("`@("`@
M("`@:68@*&5M<'1Y*"1M<V=;)V9R;VTG72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&US9ULG9G)O;2==(#T@)&US9ULG9G5L;&9R;VTG73L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;7-G6R=F<F]M)UT@/2!?
M*")5;F1I<V-L;W-E9"!296-I<&EE;G1S(BD["B`@("`@("`@("`@("`@("`D
M<VAO=V9R;VUL:6YK(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"$D9')A9G1S7W-M7V9O;&1E<BD@>PH@("`@("`@("`@("`@("`@
M)&US9ULG9G)O;2==(#T@7R@B5&\B*2`N("<Z("<@+B`D;7-G6R=F<F]M)UT[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&UA:6QT;U]L:6YK(#T@=')U
M93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)&9R;VU?;V(M/G!E<G-O;F%L
M*2D@>PH@("`@("`@("`@("`D;7-G6R=F<F]M)UT@/2!T<FEM*'-T<FEP<VQA
M<VAE<RA-24U%.CID96-O9&4H)&9R;VU?;V(M/G!E<G-O;F%L+"`D8VAA<G-E
M="DI+"`G(B<I.PH@("`@("`@("`@("!I9B`H(71R:6TH)&US9ULG9G)O;2==
M+"!C:'(H,38P*2`N("<@)RDI('L*("`@("`@("`@("`@("`@("1M<V=;)V9R
M;VTG72`]("1F<F]M7V%D<CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;7-G6R=F=6QL9G)O;2==(#T@34E-13HZ9&5C;V1E*"1H+3YF<F]M+"`D8VAA
M<G-E="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%I<W-E
M="@D9G)O;5]O8BT^:&]S="D@?'P*("`@("`@("`@("`@("`@("AS=')S='(H
M)&9R;VU?;V(M/FAO<W0L("=364Y405@M15)23U(G*2`A/3T@9F%L<V4I*2![
M"B`@("`@("`@("`@("`@("`D;7-G6R=F<F]M)UT@/2`H(65M<'1Y*"1F<F]M
M7V%D<BDI(#\@)&9R;VU?861R(#H@7R@B56YK;F]W;B!296-I<&EE;G0B*3L*
M("`@("`@("`@("`@("`@("1S:&]W9G)O;6QI;FL@/2!F86QS93L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M<V=;)V9R;VTG72`]
M("1F<F]M7V%D<CL*("`@("`@("`@("`@("`@("1M<V=;)V9U;&QF<F]M)UT@
M/2!-24U%.CID96-O9&4H)&@M/F9R;VTL("1C:&%R<V5T*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@)&US9ULG9G)O
M;2==(#T@7R@B26YV86QI9"!!9&1R97-S(BD["B`@("`@("`@)'-H;W=F<F]M
M;&EN:R`](&9A;'-E.PH@("`@?0H*("`@(&EF("@A96UP='DH)&@M/G-U8FIE
M8W0I*2!["B`@("`@("`@)'-U8FIE8W0@/2!-24U%.CID96-O9&4H)&@M/G-U
M8FIE8W0L("1C:&%R<V5T*3L*("`@("`@("!I9B`H(65M<'1Y*"1S=6)J96-T
M*2D@>PH@("`@("`@("`@("`D;7-G6R=S=6)J96-T)UT@/2!S=')T<B@D<W5B
M:F5C="P@(EQT(BP@)R`G*3L*("`@("`@("!]"B`@("!]"B`@("`D;7-G6R=F
M=6QL<W5B:F5C="==(#T@)&US9ULG<W5B:F5C="==.PH*("`@(&EF("AI<W-E
M="@D:"T^<VEZ92DI('L*("`@("`@("`D;7-G6R=S:7IE)UT@/2`H)&@M/G-I
M>F4@/B`Q,#(T*0H@("`@("`@("`@("`_('-P<FEN=&8H7R@B)7,@2T(B*2P@
M;G5M8F5R7V9O<FUA="@D:"T^<VEZ92`O(#$P,C0L(#`L("1L;V-A;&5I;F9O
M6R=D96-I;6%L7W!O:6YT)UTL("1L;V-A;&5I;F9O6R=T:&]U<V%N9'-?<V5P
M)UTI*0H@("`@("`@("`@("`Z("1H+3YS:7IE.PH@("`@?0H*("`@("\J($9I
M;'1E<B!T:&4@<W5B:F5C="!T97AT+"!I9B!R97%U97-T960N("HO"B`@("`D
M;7-G6R=S=6)J96-T)UT@/2!)35`Z.F9I;'1E<E1E>'0H)&US9ULG<W5B:F5C
M="==*3L*("`@("1M<V=;)V9U;&QS=6)J96-T)UT@/2!)35`Z.F9I;'1E<E1E
M>'0H)&US9ULG9G5L;'-U8FIE8W0G72D["@H@("`@:68@*&ES<V5T*"1M97-S
M86=E6R=S=')U8W1U<F4G72D@)B8*("`@("`@("`H)&UE<W-A9V5;)W-T<G5C
M='5R92==+3YG9710<FEM87)Y5'EP92@I(#T]("=M=6QT:7!A<G0G*2D@>PH@
M("`@("`@('-W:71C:"`H)&UE<W-A9V5;)W-T<G5C='5R92==+3YG9713=6)4
M>7!E*"DI('L*("`@("`@("!C87-E("=S:6=N960G.@H@("`@("`@("`@("`D
M871T86-H;65N="`]("=S:6=N960G.PH@("`@("`@("`@("`D871T86-H;65N
M=%]A;'0@/2!?*")-97-S86=E(&ES('-I9VYE9"(I.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G96YC<GEP=&5D)SH*("`@("`@("`@("`@
M)&%T=&%C:&UE;G0@/2`G96YC<GEP=&5D)SL*("`@("`@("`@("`@)&%T=&%C
M:&UE;G1?86QT(#T@7R@B365S<V%G92!I<R!E;F-R>7!T960B*3L*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V%L=&5R;F%T:79E)SH*("`@
M("`@("`@("`@+RH@5')E870@=&AI<R!A<R!N;R!A='1A8VAM96YT<RX@*B\*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("1A='1A8VAM96YT(#T@)V%T=&%C:&UE;G0G.PH@("`@("`@("`@("`D
M871T86-H;65N=%]A;'0@/2!?*")-97-S86=E(&AA<R!A='1A8VAM96YT<R(I
M.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+RH@
M1V5N97)A=&4@=&AE('1A<F=E="!L:6YK+B`J+PH@("`@)&US9TUB;W@@/2!I
M<W-E="@D;65S<V%G95LG;6)O>"==*2`_("1M97-S86=E6R=M8F]X)UT@.B`G
M)SL*("`@("1T87)G970@/2!)35`Z.F=E;F5R871E4V5A<F-H57)L*"=M97-S
M86=E+G!H<"<L("1M<V=-8F]X*3L*("`@("1T87)G970@/2!5=&EL.CIA9&10
M87)A;65T97(H)'1A<F=E="P@)VEN9&5X)RP@)&@M/G5I9"D["@H@("`@+RH@
M1V5T(&%L;"!T:&4@9FQA9R!I;F9O<FUA=&EO;BX@*B\*("`@("1M<V=;)V)G
M)UT@/2`G<V5E;B<["B`@("`D;7-G6R=S=&%T=7,G72`]("<G.PH@("`@)&9L
M86=B:71S(#T@,#L*("`@("1S='EL92`](&%R<F%Y*"D["B`@("`D>'!R:6\@
M/2!F86QS93L*"B`@("`O*B!#:&5C:R!F;W(@6"U0<FEO<FET>2!I;F9O<FUA
M=&EO;BX@*B\*("`@(&EF("@D8V]N9ELG;6%I;&)O>"==6R=S:&]W7WAP<FEO
M<FET>2==*2!["B`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L
M:6(O34E-12](96%D97)S+G!H<"<["B`@("`@("`@)&EM<%]H96%D97)S(#T@
M)FYE=R!)35!?2&5A9&5R<R@D:"T^=6ED*3L*("`@("`@("`D:6UP7VAE861E
M<G,M/F)U:6QD2&5A9&5R<R@I.PH@("`@("`@(&EF("@H)'!R:6]R:71Y(#T@
M)&EM<%]H96%D97)S+3YG971686QU92@G>"UP<FEO<FET>2<I*2D@>PH@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UQS*BA<9"LI7',J+R<L("1P<FEO
M<FET>2P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("!I9B`H*"1M871C
M:&5S6S%=(#T]("<Q)RD@?'P@*"1M871C:&5S6S%=(#T]("<R)RDI('L*("`@
M("`@("`@("`@("`@("`@("`D>'!R:6\@/2`G:&EG:"<["B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H*"1M871C:&5S6S%=(#T]("<T)RD@?'P@*"1M871C
M:&5S6S%=(#T]("<U)RDI('L*("`@("`@("`@("`@("`@("`@("`D>'!R:6\@
M/2`G;&]W)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("!I9B`H)&EM<%LG8F%S95]P<F]T;V-O;"==("$]
M("=P;W`S)RD@>PH@("`@("`@(&EF("@A96UP='DH)&@M/G1O*2`F)B`D:61E
M;G1I='DM/FAA<T%D9')E<W,H24U0.CIB87)E061D<F5S<R@D:"T^=&\I*2D@
M>PH@("`@("`@("`@("`D;7-G6R=S=&%T=7,G72`N/2!(;W)D93HZ:6UG*"=M
M86EL7W!E<G-O;F%L+G!N9R<L(%\H(E!E<G-O;F%L(BDI.PH@("`@("`@("`@
M("`D9FQA9V)I=',@?#T@24U07U!%4E-/3D%,.PH@("`@("`@('T*("`@("`@
M("!I9B`H(21H+3YS965N('Q\("1H+3YR96-E;G0I('L*("`@("`@("`@("`@
M)&9L86=B:71S('P]($E-4%]53E-%14X["B`@("`@("`@("`@("1M<V=;)W-T
M871U<R==("X]($AO<F1E.CII;6<H)VUA:6Q?=6YS965N+G!N9R<L(%\H(E5N
M<V5E;B(I*3L*("`@("`@("`@("`@)'-T>6QE6UT@/2`G8B<["B`@("`@("`@
M("`@("1M<V=;)V)G)UT@/2`G=6YS965N)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"1H+3YA;G-W97)E9"D@>PH@("`@("`@("`@("`D9FQA9V)I=',@?#T@
M24U07T%.4U=%4D5$.PH@("`@("`@("`@("`D;7-G6R=S=&%T=7,G72`N/2!(
M;W)D93HZ:6UG*"=M86EL7V%N<W=E<F5D+G!N9R<L(%\H(D%N<W=E<F5D(BDI
M.PH@("`@("`@("`@("`D;7-G6R=B9R==(#T@)V%N<W=E<F5D)SL*("`@("`@
M("!]"B`@("`@("`@:68@*"1H+3YD<F%F="D@>PH@("`@("`@("`@("`D9FQA
M9V)I=',@?#T@24U07T120494.PH@("`@("`@("`@("`D;7-G6R=S=&%T=7,G
M72`N/2!(;W)D93HZ:6UG*"=M86EL7V1R869T+G!N9R<L(%\H(D1R869T(BDI
M.PH@("`@("`@("`@("`D=&%R9V5T(#T@24U0.CIC;VUP;W-E3&EN:RAA<G)A
M>2@I+"!A<G)A>2@G86-T:6]N240G(#T^("=D<F%F="<L("=M86EL8F]X)R`]
M/B`D:6UP6R=M86EL8F]X)UTL("=I;F1E>"<@/3X@)&@M/G5I9"DI.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'AP<FEO(#T]("=H:6=H)RD@>PH@("`@("`@
M("`@("`D9FQA9V)I=',@?#T@24U07T9,04='140["B`@("`@("`@("`@("1M
M<V=;)W-T871U<R==("X]($AO<F1E.CII;6<H)VUA:6Q?<')I;W)I='E?:&EG
M:"YP;F<G+"!?*")(:6=H(%!R:6]R:71Y(BDI.PH@("`@("`@("`@("`D;7-G
M6R=B9R==(#T@)VEM<&]R=&%N="<["B`@("`@("`@?2!E;'-E:68@*"1X<')I
M;R`]/2`G;&]W)RD@>PH@("`@("`@("`@("`D;7-G6R=S=&%T=7,G72`N/2!(
M;W)D93HZ:6UG*"=M86EL7W!R:6]R:71Y7VQO=RYP;F<G+"!?*"),;W<@4')I
M;W)I='DB*2D["B`@("`@("`@("`@(&EF("AI<W-E="@D<W1Y;&5;,%TI("8F
M("1S='EL95LP72`]/2`G8B<I('L*("`@("`@("`@("`@("`@("1S='EL92`]
M(&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@
M*"1H+3YF;&%G9V5D*2!["B`@("`@("`@("`@("1F;&%G8FET<R!\/2!)35!?
M1DQ!1T=%1#L*("`@("`@("`@("`@)&US9ULG<W1A='5S)UT@+CT@2&]R9&4Z
M.FEM9R@G;6%I;%]F;&%G9V5D+G!N9R<L(%\H(DEM<&]R=&%N="(I*3L*("`@
M("`@("`@("`@)'-T>6QE6UT@/2`G:2<["B`@("`@("`@("`@("1M<V=;)V)G
M)UT@/2`G:6UP;W)T86YT)SL*("`@("`@("!]"B`@("`@("`@:68@*"1H+3YD
M96QE=&5D*2!["B`@("`@("`@("`@("1F;&%G8FET<R!\/2!)35!?1$5,151%
M1#L*("`@("`@("`@("`@)&US9ULG<W1A='5S)UT@+CT@2&]R9&4Z.FEM9R@G
M;6%I;%]D96QE=&5D+G!N9R<L(%\H(D1E;&5T960B*2D["B`@("`@("`@("`@
M("1S='EL95M=(#T@)W-T<FEK92<["B`@("`@("`@("`@("1M<V=;)V)G)UT@
M/2`G9&5L971E9"<["B`@("`@("`@?0H@("`@("`@("1F;&%G<UM=(#T@)&9L
M86=B:71S.PH@("`@?2!E;'-E('L*("`@("`@("`D9FQA9W-;72`](#`["B`@
M("!]"@H@("`@:68@*"1C;VYF6R=M86EL8F]X)UU;)W-H;W=?871T86-H;65N
M=',G72`F)B`D871T86-H;65N="D@>PH@("`@("`@("1M<V=;)W-T871U<R==
M("X]($AO<F1E.CII;6<H)&%T=&%C:&UE;G0@+B`G+G!N9R<L("1A='1A8VAM
M96YT7V%L="D["B`@("!]"@H@("`@+RH@4VAO=R!M97-S86=E('!R979I97<_
M("HO"B`@("!I9B`H)'-H;W=?<')E=FEE=RD@>PH@("`@("`@("1M<V=;)W!R
M979I97<G72`]("1M97-S86=E6R=P<F5V:65W)UT["B`@("!]"@H@("`@+RH@
M4V5T('1H92!M97-S86=E(&YU;6)E<BX@*B\*("`@("1M<V=;)VYU;6)E<B==
M(#T@7W-T>6QI>F4H)&@M/FUS9VYO+"`D<W1Y;&4I.PH*("`@("\J($9O<FUA
M="!T:&4@1&%T93H@2&5A9&5R+B`J+PH@("`@)&US9ULG9&%T92==(#T@7W-T
M>6QI>F4H)&US9ULG9&%T92==+"`D<W1Y;&4I.PH*("`@("\J($9O<FUA="!M
M97-S86=E('-I>F4N("HO"B`@("`D;7-G6R=S:7IE)UT@/2!?<W1Y;&EZ92@D
M;7-G6R=S:7IE)UTL("1S='EL92D["@H@("`@+RH@1F]R;6%T('1H92!&<F]M
M.B!(96%D97(N("HO"B`@("`D;7-G6R=F<F]M)UT@/2!?<W1Y;&EZ92AH=&UL
M<W!E8VEA;&-H87)S*"1M<V=;)V9R;VTG72DL("1S='EL92D["B`@("!S=VET
M8V@@*"1F<F]M;&EN:W-T>6QE*2!["B`@("!C87-E(#`Z"B`@("`@("`@:68@
M*"1S:&]W9G)O;6QI;FLI('L*("`@("`@("`@("`@)&5X=')A(#T@87)R87DH
M)V%C=&EO;DE$)R`]/B`G;6%I;'1O)RP@)VUA:6QB;W@G(#T^("1I;7!;)VUA
M:6QB;W@G72P@)VEN9&5X)R`]/B`D:"T^=6ED+"`G;6%I;'1O)R`]/B`D;6%I
M;'1O7VQI;FLI.PH@("`@("`@("`@("!I9B`H)'-E87)C:%]M8F]X*2!["B`@
M("`@("`@("`@("`@("`D97AT<F%;)W1H:7-M86EL8F]X)UT@/2`D;6%I;&)O
M>$]V97)V:65W6R1M<V=);F1E>%U;)VUB;W@G73L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D;7-G6R=F<F]M)UT@/2!(;W)D93HZ;&EN:RA)35`Z.F-O
M;7!O<V5,:6YK*&%R<F%Y*"DL("1E>'1R82DL('-P<FEN=&8H7R@B3F5W($UE
M<W-A9V4@=&\@)7,B*2P@<W1R:7!S;&%S:&5S*"1M<V=;)V9U;&QF<F]M)UTI
M*2D@+B`D;7-G6R=F<F]M)UT@+B`G/"]A/B<["B`@("`@("`@?0H@("`@("`@
M(&)R96%K.PH*("`@(&-A<V4@,3H*("`@("`@("!I9B`H(6ES<V5T*"1M<V=;
M)V9U;&QF<F]M)UTI*2!["B`@("`@("`@("`@("1M<V=;)V9U;&QF<F]M)UT@
M/2`D;7-G6R=F<F]M)UT["B`@("`@("`@?0H@("`@("`@("1F<F]M7W5R:2`]
M($E-4#HZ9V5N97)A=&5396%R8VA5<FPH)VUE<W-A9V4N<&AP)RP@)&US9TUB
M;W@I.PH@("`@("`@("1F<F]M7W5R:2`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M9G)O;5]U<FDL("=I;F1E>"<L("1H+3YU:60I.PH@("`@("`@("1M<V=;)V9R
M;VTG72`]($AO<F1E.CIL:6YK*"1F<F]M7W5R:2P@)&US9ULG9G5L;&9R;VTG
M72D@+B`D;7-G6R=F<F]M)UT@+B`G/"]A/B<["B`@("`@("`@8G)E86L["B`@
M("!]"@H@("`@+RH@1F]R;6%T('1H92!3=6)J96-T.B!(96%D97(N("HO"B`@
M("`D;7-G6R=S=6)J96-T)UT@/2!?<W1Y;&EZ92A497AT.CIH=&UL4W!A8V5S
M*"1M<V=;)W-U8FIE8W0G72DL("1S='EL92D["B`@("!I9B`H)'!R979I97=?
M=&]O;'1I<"D@>PH@("`@("`@("1M<V=;)W-U8FIE8W0G72`]('-U8G-T<BA(
M;W)D93HZ;&EN:U1O;VQT:7`H)'1A<F=E="P@)&US9ULG9G5L;'-U8FIE8W0G
M72P@)R<L("<G+"`G)RP@)&US9ULG<')E=FEE=R==*2P@,"P@+3$I("X@)R!I
M9#TB<W5B:F5C="<@+B`D:"T^=6ED("X@)R(^)R`N("1M<V=;)W-U8FIE8W0G
M72`N("<\+V$^)SL*("`@('T@96QS92!["B`@("`@("`@)&US9ULG<W5B:F5C
M="==(#T@<W5B<W1R*$AO<F1E.CIL:6YK*"1T87)G970L("1M<V=;)V9U;&QS
M=6)J96-T)UTI+"`P+"`M,2D@+B`G(&ED/2)S=6)J96-T)R`N("1H+3YU:60@
M+B`G(CXG("X@)&US9ULG<W5B:F5C="==("X@)SPO83XG("X@*"%E;7!T>2@D
M;7-G6R=P<F5V:65W)UTI(#\@)SQB<B`O/CQS;6%L;#XG("X@)&US9ULG<')E
M=FEE=R==("X@)SPO<VUA;&P^)R`Z("<G*3L*("`@('T*"B`@("`O*B!3970@
M=7`@=&AR96%D:6YG('1R964@;F]W+B`J+PH@("`@:68@*"1T:')E861?<V]R
M="D@>PH@("`@("`@(&EF("@A96UP='DH)'1H<F5A9'1R965;)&@M/G5I9%TI
M*2!["B`@("`@("`@("`@("1M<V=;)W-U8FIE8W0G72`]("1T:')E861T<F5E
M6R1H+3YU:61=("X@)R`G("X@)&US9ULG<W5B:F5C="==.PH@("`@("`@('T*
M("`@('T*"B`@("`O*B!792!N965D('1H92!U:60@<V\@=&AE(&-H96-K8F]X
M97,@=VEL;"!W;W)K+B`J+PH@("`@)&US9ULG=6ED)UT@/2`D:"T^=6ED.PH*
M("`@("1M<V=S6UT@/2`D;7-G.PI]"@I?;W5T<'5T4W5M;6%R:65S*"1S96%R
M8VA?;6)O>"P@)&US9W,I.PIR97%U:7)E($E-4%]414U03$%415,@+B`G+VUA
M:6QB;W@O;65S<V%G95]F;V]T97)S+FEN8R<["@II9B`H)'!R969S+3YG9716
M86QU92@G<VAO=U]L96=E;F0G*2`F)B`H)&EM<%LG8F%S95]P<F]T;V-O;"==
M("$]("=P;W`S)RDI('L*("`@(')E<75I<F4@24U07U1%35!,051%4R`N("<O
M;6%I;&)O>"]L96=E;F0N:6YC)SL*?0H*+RH@268@=&AE<F4@87)E(#$U(&UE
M<W-A9V5S(&]R(&QE<W,L(&1O;B=T('-H;W<@=&AE(&%C=&EO;G,O;F%V8F%R
M"B`J(&%G86EN+B`J+PII9B`H:7-S970H)&%C=&EO;G-?;W5T<'5T*2D@>PH@
M("`@96-H;R`D86-T:6]N<U]O=71P=70["B`@("`D;F%V9F]R;2`](#(["B`@
M("!R97%U:7)E($E-4%]414U03$%415,@+B`G+VUA:6QB;W@O;F%V8F%R+FEN
M8R<["GT@96QS92!["B`@("!E8VAO("<\='(^/'1D(&-L87-S/2)C;VYT<F]L
M(B!C;VQS<&%N/2(V(CX\+W1D/CPO='(^)SL*?0H*<F5Q=6ER92!)35!?5$5-
M4$Q!5$53("X@)R]M86EL8F]X+V9O;W1E<BYI;F,G.PH*:68@*"1P<F5F<RT^
M9V5T5F%L=64H)VYA=E]P;W!U<"<I("8F"B`@("`H)&YE=VUS9W,@/2`D:6UP
M7VUA:6QB;W@M/FYE=TUE<W-A9V5#;W5N="@I*0H@("`@)B8@*"1N97=M<V=S
M(#X@,"D@)B8*("`@("%5=&EL.CIG971&;W)M1&%T82@G;F]?;F5W;6%I;%]P
M;W!U<"<I*2!["B`@("!R97%U:7)E($E-4%]414U03$%415,@+B`G+VUA:6QB
M;W@O86QE<G0N:6YC)SL*?0H*:68@*"%E;7!T>2@D;W!E;E]C;VUP;W-E7W=I
M;F1O=RDI('L*("`@("1A<F=S(#T@)W!O<'5P/3$G.PH@("`@:68@*"%I<W-E
M="@D;W!T:6]N<RDI('L*("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"D["B`@
M("!]"B`@("!F;W)E86-H("AA<G)A>5]M97)G92@D;W!T:6]N<RP@24U0.CIG
M971#;VUP;W-E07)G<R@I*2!A<R`D87)G(#T^("1V86QU92D@>PH@("`@("`@
M("1A<F=S("X]("%E;7!T>2@D=F%L=64I(#\@)R8G("X@)&%R9R`N("<])R`N
M('5R;&5N8V]D92@D=F%L=64I(#H@)R<["B`@("!]"B`@("!(;W)D93HZ861D
M4V-R:7!T1FEL92@G<&]P=7`N:G,G*3L*("`@(&5C:&\@(CQS8W)I<'0@='EP
M93TG=&5X="]J879A<V-R:7!T)SYP;W!U<%]I;7`H)R(@+B!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)V-O;7!O<V4N<&AP)RD@+B`B)RPW,#`L-C4P+"<B("X@
M861D<VQA<VAE<R@D87)G<RD@+B`B)RD[/"]S8W)I<'0^(CL*?0H*<F5Q=6ER
M92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O
M;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O;&]G:6XN<&AP````````
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T,3<R
M`#$P-#$W,S8R-S<P`#`Q-S`S,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@3&]G:6X@<V-R965N(&9O
M<B!)35`N"B`J"B`J("1(;W)D93H@:6UP+VQO9VEN+G!H<"QV(#(N,C(R+C(N
M.2`R,#`V+S`Q+S$V(#$V.C`R.C,S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!
M3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G24U07T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2D["B1A=71H96YT:6-A=&EO;B`]("=N;VYE)SL*<F5Q=6ER95]O
M;F-E($E-4%]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E($E-4%]"
M05-%("X@)R]C;VYF:6<O<V5R=F5R<RYP:'`G.PH*+RH@1V5T(&%N($%U=&@@
M;V)J96-T+B`J+PHD:6UP7V%U=&@@/2`H075T:#HZ9V5T4')O=FED97(H*2`]
M/2`G:6UP)RD["B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T
M:"==6R=D<FEV97(G72D["B1L;V=O=71?<F5A<V]N(#T@)&%U=&@M/F=E=$QO
M9V]U=%)E87-O;B@I.PH*)&%U=&]L;V=I;B`](%5T:6PZ.F=E=$9O<FU$871A
M*"=A=71O;&]G:6XG+"!F86QS92D["B1A8W1I;VY)1"`]("A5=&EL.CIG971&
M;W)M1&%T82@G86-T:6]N)RD@/3T@)V-O;7!O<V4G*2`_("=L;V=I;E]C;VUP
M;W-E)R`Z(%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PHD<V5R=F5R
M7VME>2`](%5T:6PZ.F=E=$9O<FU$871A*"=S97)V97)?:V5Y)RD["B1U<FQ?
M<&%R86T@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD["@HO*B!(86YD;&4@
M8V%S97,@=VAE<F4@=V4@86QR96%D>2!H879E(&$@<V5S<VEO;BX@*B\*:68@
M*"%E;7!T>2@D7U-%4U-)3TY;)VEM<"==*2`F)B!I<U]A<G)A>2@D7U-%4U-)
M3TY;)VEM<"==*2D@>PH@("`@:68@*"1L;V=O=71?<F5A<V]N*2!["B`@("`@
M("`@+RH@3&]G(&QO9V]U="!R97%U97-T<R!N;W<N("HO"B`@("`@("`@:68@
M*"1L;V=O=71?<F5A<V]N(#T]($%55$A?4D5!4T].7TQ/1T]55"D@>PH@("`@
M("`@("`@("`D96YT<GD@/2!S<')I;G1F*"=,;V=O=70@9F]R("5S(%LE<UT@
M9G)O;2![)7,Z)7-])RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M7U-%4U-)3TY;)VEM<"==6R=U;FEQ=7-E<B==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1?4T525D526R=214U/5$5?041$4B==+"`D7U-%4U-)
M3TY;)VEM<"==6R=S97)V97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D7U-%4U-)3TY;)VEM<"==6R=P;W)T)UTI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1E;G1R>2`]("1?4T525D526R=214U/5$5?041$
M4B==("X@)R`G("X@)&%U=&@M/F=E=$QO9V]U=%)E87-O;E-T<FEN9R@I.PH@
M("`@("`@('T*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D96YT<GDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?3D]424-%*3L*"B`@("`@("`@
M)&QA;F=U86=E(#T@*&ES<V5T*"1P<F5F<RDI(#\@)'!R969S+3YG971686QU
M92@G;&%N9W5A9V4G*2`Z($Y,4SHZ<V5L96-T*"D["@H@("`@("`@('5N<V5T
M*"1?4T534TE/3ELG:6UP)UTI.PH*("`@("`@("`O*B!#;&5A;G5P('!R969E
M<F5N8V5S+B`J+PH@("`@("`@(&EF("AI<W-E="@D<')E9G,I*2!["B`@("`@
M("`@("`@("1P<F5F<RT^8VQE86YU<"@D:6UP7V%U=&@I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1I;7!?875T:"D@>PH@("`@("`@("`@("!!=71H.CIC
M;&5A<D%U=&@H*3L*("`@("`@("`@("`@0'-E<W-I;VY?9&5S=')O>2@I.PH@
M("`@("`@("`@("!(;W)D93HZ<V5T=7!397-S:6]N2&%N9&QE<B@I.PH@("`@
M("`@("`@("!`<V5S<VEO;E]S=&%R="@I.PH@("`@("`@('T*"B`@("`@("`@
M3DQ3.CIS971,86YG*"1L86YG=6%G92D["@H@("`@("`@("\J($AO;VL@=&\@
M<')E<V5L96-T('1H92!C;W)R96-T(&QA;F=U86=E(&EN('1H92!W:61G970N
M("HO"B`@("`@("`@)%]'151;)VYE=U]L86YG)UT@/2`D;&%N9W5A9V4["@H@
M("`@("`@("1R96=I<W1R>2T^;&]A9%!R969S*"=H;W)D92<I.PH@("`@("`@
M("1R96=I<W1R>2T^;&]A9%!R969S*"D["B`@("!](&5L<V4@>PH@("`@("`@
M(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+U-E<W-I;VXN<&AP)SL*
M("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@24U07U-E<W-I;VXZ.F=E
M=$EN:71I86Q5<FPH)&%C=&EO;DE$+"!F86QS92DI.PH@("`@("`@(&5X:70[
M"B`@("!]"GT*"B\J($QO9R!S97-S:6]N('1I;65O=71S+B`J+PII9B`H)&QO
M9V]U=%]R96%S;VX@/3T@05542%]214%33TY?4T534TE/3BD@>PH@("`@)&5N
M=')Y(#T@<W!R:6YT9B@G4V5S<VEO;B!T:6UE;W5T(&9O<B!C;&EE;G0@6R5S
M72<L("1?4T525D526R=214U/5$5?041$4B==*3L*("`@($AO<F1E.CIL;V=-
M97-S86=E*"1E;G1R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U].
M3U1)0T4I.PH*("`@("\J($UA:V4@<W5R92!E=F5R>71H:6YG(&ES(')E86QL
M>2!C;&5A<F5D+B`J+PH@("`@075T:#HZ8VQE87)!=71H*"D["B`@("!U;G-E
M="@D7U-%4U-)3TY;)VEM<"==*3L*?0H*+RH@4F5D:7)E8W0@=&AE('5S97(@
M;VX@;&]G;W5T(&EF(')E9&ER96-T:6]N(&ES(&5N86)L960N("HO"FEF("@D
M;&]G;W5T7W)E87-O;B`]/2!!551(7U)%05-/3E],3T=/550@)B8*("`@("@D
M8V]N9ELG=7-E<B==6R=R961I<F5C=%]O;E]L;V=O=70G72!\?`H@("`@("%E
M;7!T>2@D8V]N9ELG875T:"==6R=R961I<F5C=%]O;E]L;V=O=70G72DI*2![
M"B`@("!I9B`H(65M<'1Y*"1C;VYF6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO
M9V]U="==*2D@>PH@("`@("`@("1U<FP@/2!!=71H.CIA9&1,;V=O=71087)A
M;65T97)S*"1C;VYF6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO9V]U="==+"!!
M551(7U)%05-/3E],3T=/550I.PH@("`@?2!E;'-E('L*("`@("`@("`D=7)L
M(#T@075T:#HZ861D3&]G;W5T4&%R86UE=&5R<R@D8V]N9ELG=7-E<B==6R=R
M961I<F5C=%]O;E]L;V=O=70G72P@05542%]214%33TY?3$]'3U54*3L*("`@
M('T*("`@(&EF("@A:7-S970H)%]#3T]+245;<V5S<VEO;E]N86UE*"E=*2D@
M>PH@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@<V5S
M<VEO;E]N86UE*"DL('-E<W-I;VY?:60H*2D["B`@("!]"B`@("!H96%D97(H
M)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HO*B!2961I<F5C
M="!T:&4@=7-E<B!I9B!A;B!A;'1E<FYA=&4@;&]G:6X@<&%G92!H87,@8F5E
M;B!S<&5C:69I960N("HO"FEF("@A96UP='DH)&-O;F9;)V%U=&@G75LG86QT
M97)N871E7VQO9VEN)UTI*2!["B`@("`D=7)L(#T@075T:#HZ861D3&]G;W5T
M4&%R86UE=&5R<R@D8V]N9ELG875T:"==6R=A;'1E<FYA=&5?;&]G:6XG72D[
M"B`@("!I9B`H(6ES<V5T*"1?0T]/2TE%6W-E<W-I;VY?;F%M92@I72DI('L*
M("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL('-E<W-I
M;VY?;F%M92@I+"!S97-S:6]N7VED*"DL(&9A;'-E*3L*("`@('T*("`@(&EF
M("@D=7)L7W!A<F%M*2!["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<B@D=7)L+"`G=7)L)RP@)'5R;%]P87)A;2P@9F%L<V4I.PH@("`@?0H@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?2!E
M;'-E:68@*"1C;VYF6R=U<V5R)UU;)V%L=&5R;F%T95]L;V=I;B==*2!["B`@
M("`D=7)L(#T@075T:#HZ861D3&]G;W5T4&%R86UE=&5R<R@D8V]N9ELG=7-E
M<B==6R=A;'1E<FYA=&5?;&]G:6XG72D["B`@("!I9B`H(6ES<V5T*"1?0T]/
M2TE%6W-E<W-I;VY?;F%M92@I72DI('L*("`@("`@("`D=7)L(#T@571I;#HZ
M861D4&%R86UE=&5R*"1U<FPL('-E<W-I;VY?;F%M92@I+"!S97-S:6]N7VED
M*"DL(&9A;'-E*3L*("`@('T*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D
M=7)L*3L*("`@(&5X:70["GT*"B\J($EN:71I86QI>F4@=&AE('!A<W-W;W)D
M(&ME>2AS*2X@268@=V4@87)E(&1O:6YG($AO<F1E(&%U=&@@87,@=V5L;"P*
M("H@;6%K92!S=7)E('1H870@=&AE($AO<F1E(&%U=&@@:V5Y(&=E=',@<V5T
M+B`J+PI396-R970Z.G-E=$ME>2@G:6UP)RD["FEF("@D:6UP7V%U=&@I('L*
M("`@(%-E8W)E=#HZ<V5T2V5Y*"=A=71H)RD["GT*"B1U<V5D7W-E<G9E<G,@
M/2`D<V5R=F5R<SL*:68@*"1C;VYF6R=S97)V97(G75LG<V5R=F5R7VQI<W0G
M72`A/2`G<VAO=VXG*2!["B`@("`D<V5R=F5R7VME>2`](%5T:6PZ.F=E=$9O
M<FU$871A*"=S97)V97)?:V5Y)RD["B`@("!I9B`H:7-?;G5L;"@D<V5R=F5R
M7VME>2DI('L*("`@("`@("`O*B!'<F%B('-O;64@9&5F875L="!V86QU97,@
M9G)O;2!T:&4@9FER<W0@96YT<GD@:6X*("`@("`@("`@*B!C;VYF:6<O<V5R
M=F5R<RYP:'`N("HO"B`@("`@("`@)'-E<G9E<E]K97D@/2!)35`Z.F=E=$%U
M=&],;V=I;E-E<G9E<BAT<G5E*3L*("`@('T*("`@("1U<V5D7W-E<G9E<G,@
M/2!A<G)A>2@D<V5R=F5R7VME>2`]/B`D<V5R=F5R<ULD<V5R=F5R7VME>5TI
M.PH@("`@)&%U=&]L;V=I;B`](%5T:6PZ.F=E=$9O<FU$871A*"=A=71O;&]G
M:6XG*3L*?0H*:68@*"$D;&]G;W5T7W)E87-O;B`F)B!)35`Z.F-A;D%U=&],
M;V=I;B@D<V5R=F5R7VME>2P@)&%U=&]L;V=I;BDI('L*("`@("1U<FP@/2!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)W)E9&ER96-T+G!H<"<L('1R=64I.PH@
M("`@)'!A<F%M<R`](&%R<F%Y*"=A8W1I;VY)1"<@/3X@)VQO9VEN)RP@)V%U
M=&]L;V=I;B<@/3X@=')U92D["B`@("!I9B`H8V]U;G0H)'5S961?<V5R=F5R
M<RD@/3T@,2D@>PH@("`@("`@(')E<V5T*"1U<V5D7W-E<G9E<G,I.PH@("`@
M("`@(&QI<W0H)'-E<G9E<E]K97DL("1C=7)397)V97(I(#T@96%C:"@D=7-E
M9%]S97)V97)S*3L*("`@("`@("`D<&%R86US6R=S97)V97)?:V5Y)UT@/2`D
M<V5R=F5R7VME>3L*("`@('T*("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T
M97(H)'5R;"P@)'!A<F%M<RP@;G5L;"P@9F%L<V4I.PH@("`@:&5A9&5R*"=,
M;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?0H*)'1I=&QE(#T@<W!R
M:6YT9BA?*")796QC;VUE('1O("5S(BDL("1R96=I<W1R>2T^9V5T*"=N86UE
M)RP@*"1I;7!?875T:"D@/R`G:&]R9&4G(#H@;G5L;"DI.PH*:68@*"1L;V=O
M=71?<F5A<V]N("8F("1I;7!?875T:"`F)B`D8V]N9ELG;65N=2==6R=A;'=A
M>7,G72D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G<V5T1F]C=7,H*3MI
M9B`H=VEN9&]W+G!A<F5N="YF<F%M97,N:&]R9&5?;65N=2D@=VEN9&]W+G!A
M<F5N="YF<F%M97,N:&]R9&5?;65N=2YL;V-A=&EO;BYR96QO860H*3LG+"`G
M:F%V87-C<FEP="<I.PI](&5L<V4@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"@G<V5T1F]C=7,H*2<L("=J879A<V-R:7!T)RD["GT*"B1F;W)M06-T:6]N
M(#T@2&]R9&4Z.G5R;"@G<F5D:7)E8W0N<&AP)RP@9F%L<V4L("TQ+"!T<G5E
M*3L*)&9O<FU$871A(#T@;G5L;#L*"B1R96%S;VX@/2`D875T:"T^9V5T3&]G
M;W5T4F5A<V]N4W1R:6YG*"D["@HO*B!!9&0@<V]M92!J879A<V-R:7!T+B`J
M+PI(;W)D93HZ861D4V-R:7!T1FEL92@G96YT97)?:V5Y7W1R87`N:G,G+"`G
M:&]R9&4G+"!T<G5E*3L*"B\J($1O('=E(&YE960@=&\@9&\@244@=F5R<VEO
M;B!D971E8W1I;VX_("HO"FEF("@A075T:#HZ9V5T075T:"@I("8F"B`@("`H
M)&)R;W=S97(M/F=E=$)R;W=S97(H*2`]/2`G;7-I92<I("8F"B`@("`H)&)R
M;W=S97(M/F=E=$UA:F]R*"D@/CT@-2DI('L*("`@("1I95]C;&EE;G1C87!S
M(#T@=')U93L*?0H*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E
M<75I<F4@24U07U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR
M97%U:7)E($E-4%]414U03$%415,@+B`G+VQO9VEN+VQO9VEN+FEN8R<["FEF
M("A`:7-?<F5A9&%B;&4H24U07T)!4T4@+B`G+V-O;F9I9R]M;W1D+G!H<"<I
M*2!["B`@("!R97%U:7)E($E-4%]"05-%("X@)R]C;VYF:6<O;6]T9"YP:'`G
M.PI]"G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D
M92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+VEN
M9&5X+G!H<```````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`R-``Q,#0Q-S,V,C<W,``P,3<P,C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:6UP+VEN9&5X+G!H<"QV(#(N-S,N,3`N,R`R,#`V+S`Q+S`Q(#(Q
M.C(X.C4P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G
M<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=)35!?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I*3L*)&EM<%]C;VYF:6=U<F5D(#T@*$!I<U]R96%D86)L92A)35!?
M0D%312`N("<O8V]N9FEG+V-O;F8N<&AP)RD@)B8*("`@("`@("`@("`@("`@
M("`@($!I<U]R96%D86)L92A)35!?0D%312`N("<O8V]N9FEG+VUI;65?9')I
M=F5R<RYP:'`G*2`F)@H@("`@("`@("`@("`@("`@("`@0&ES7W)E861A8FQE
M*$E-4%]"05-%("X@)R]C;VYF:6<O<')E9G,N<&AP)RD@)B8*("`@("`@("`@
M("`@("`@("`@($!I<U]R96%D86)L92A)35!?0D%312`N("<O8V]N9FEG+W-E
M<G9E<G,N<&AP)RDI.PH*:68@*"$D:6UP7V-O;F9I9W5R960I('L*("`@(')E
M<75I<F4@24U07T)!4T4@+B`G+RXN+VQI8B]497-T+G!H<"<["B`@("!(;W)D
M95]497-T.CIC;VYF:6=&:6QE<TUI<W-I;F<H)TE-4"<L($E-4%]"05-%+`H@
M("`@("`@(&%R<F%Y*"=C;VYF+G!H<"<L("=M:6UE7V1R:79E<G,N<&AP)RP@
M)W!R969S+G!H<"<I+`H@("`@("`@(&%R<F%Y*"=S97)V97)S+G!H<"<@/3X@
M)U1H:7,@9FEL92!C;VYT<F]L<R!T:&4@9&5F875L="!S971T:6YG<R!F;W(@
M24U0+"!A;F0@86QS;R!D969I;F5S('1H92!L:7-T(&]F(&%V86EL86)L92!S
M97)V97)S(&EF('EO=2!A<F4@=7-I;F<@=&AE('-E<G9E<B!L:7-T+B<I*3L*
M?0H*<F5Q=6ER92!)35!?0D%312`N("<O<F5D:7)E8W0N<&AP)SL*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;7`O9F]L9&5R<RYP:'``````````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0S,38U`#$P-#$W,S8R
M-S<P`#`Q-S,V-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!I;7`O9F]L9&5R<RYP:'`L
M=B`R+C,P.2XR+C,P(#(P,#8O,#(O,C$@,#<Z,3(Z,#(@<VQU<V%R>B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($-H87)L97,@2BX@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@
M2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#`M
M,C`P-B!!;FEL($UA9&AA=F%P961D>2`\879S;4!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*B\*"B\J*@H@*B!5
M=&EL:71Y(&9U;F-T:6]N('1O(')E='5R;B!A('5R;"!F;W(@=&AE('9A<FEO
M=7,@:6UA9V5S+@H@*B\*9G5N8W1I;VX@7VEM86=E*"1N86UE+"`D86QT+"`D
M='EP92D*>PH@("`@<W1A=&EC("1C86-H93L*"B`@("!I9B`H(6ES<V5T*"1C
M86-H92DI('L*("`@("`@("`D8V%C:&4@/2!A<G)A>2@I.PH@("`@?2!E;'-E
M:68@*"%E;7!T>2@D8V%C:&5;)'1Y<&5=6R1N86UE72DI('L*("`@("`@("!R
M971U<FX@)&-A8VAE6R1T>7!E75LD;F%M95T["B`@("!]"@H@("`@:68@*"1T
M>7!E(#T]("=F;VQD97(G*2!["B`@("`@("`@)&-A8VAE6R1T>7!E75LD;F%M
M95T@/2!(;W)D93HZ:6UG*"=F;VQD97)S+R<@+B`D;F%M92P@)&%L="P@)W-T
M>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RD["B`@("!](&5L<V4@>PH@
M("`@("`@("1C86-H95LD='EP95U;)&YA;65=(#T@2&]R9&4Z.FEM9R@G=')E
M92\G("X@)&YA;64L("1A;'0L("=S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED
M9&QE(B<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R
M9&4G*2D["B`@("!]"@H@("`@<F5T=7)N("1C86-H95LD='EP95U;)&YA;65=
M.PI]"@HD875T:&5N=&EC871I;VX@/2!/4%](04Q&3U!%3CL*0&1E9FEN92@G
M24U07T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E($E-4%]"
M05-%("X@)R]L:6(O24U!4"]4<F5E+G!H<"<["G)E<75I<F5?;VYC92!)35!?
M0D%312`N("<O;&EB+T9O;&1E<BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+TED96YT:71Y+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5&5M<&QA=&4N
M<&AP)SL*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V9O;&1E<G,N:G,G+"`G:6UP
M)RD["@HO*B!2961I<F5C="!B86-K('1O('1H92!M86EL8F]X(&EF(&9O;&1E
M<B!U<V4@:7,@;F]T(&%L;&]W960N("HO"FEF("@A)&-O;F9;)W5S97(G75LG
M86QL;W=?9F]L9&5R<R==*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H
M(D9O;&1E<B!U<V4@:7,@;F]T(&5N86)L960N(BDL("=H;W)D92YE<G)O<B<I
M.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G;6%I;&)O>"YP:'`G+"!T<G5E*2D["B`@("!E>&ET.PI]"@HO*B!'
M970@<75O=&$@:6YF;W)M871I;VXN("HO"FEF("AI<W-E="@D:6UP6R=Q=6]T
M82==*2`F)B!I<U]A<G)A>2@D:6UP6R=Q=6]T82==*2D@>PH@("`@<F5Q=6ER
M95]O;F-E($E-4%]"05-%("X@)R]L:6(O475O=&$N<&AP)SL*("`@("1Q=6]T
M841R:79E<B`]("9)35!?475O=&$Z.G-I;F=L971O;B@D:6UP6R=Q=6]T82==
M6R=D<FEV97(G72P@)&EM<%LG<75O=&$G75LG<&%R86US)UTI.PH@("`@:68@
M*"1Q=6]T841R:79E<B`A/3T@9F%L<V4I('L*("`@("`@("`D<75O=&$@/2`D
M<75O=&%$<FEV97(M/F=E=%%U;W1A*"D["B`@("!]"B`@("!)35`Z.F-H96-K
M075T:&5N=&EC871I;VXH3U!?2$%,1D]014XL('1R=64I.PI]"@HO*B!);FET
M:6%L:7IE('1H92!U<V5R)W,@:61E;G1I=&EE<RX@*B\*)&ED96YT:71Y(#T@
M)DED96YT:71Y.CIS:6YG;&5T;VXH87)R87DH)VEM<"<L("=I;7`G*2D["@HO
M*B!$96-I9&4@=VAE=&AE<B!O<B!N;W0@=&\@<VAO=R!A;&P@=&AE('5N<W5B
M<V-R:6)E9"!F;VQD97)S("HO"B1S=6)S8W)I8F4@/2`D<')E9G,M/F=E=%9A
M;'5E*"=S=6)S8W)I8F4G*3L*)'-H;W=!;&P@/2`H(21S=6)S8W)I8F4@?'P@
M)&EM<%LG<VAO=W5N<W5B)UTI.PH*+RH@1V5T('1H92!B87-E(%523"!F;W(@
M=&AI<R!P86=E+B`J+PHD9F]L9&5R<U]U<FP@/2!(;W)D93HZ<V5L9E5R;"@I
M.PH*+RH@26YI=&EA;&EZ92!T:&4@24U07T9O;&1E<B!O8FIE8W0N("HO"B1I
M;7!?9F]L9&5R(#T@)DE-4%]&;VQD97(Z.G-I;F=L971O;B@I.PH*+RH@26YI
M=&EA;&EZ92!T:&4@24U07U1R964@;V)J96-T+B`J+PHD:6UP=')E92`]("9)
M35!?5')E93HZ<VEN9VQE=&]N*"D["@HD9F]L9&5R7VQI<W0@/2!5=&EL.CIG
M971&;W)M1&%T82@G9F]L9&5R7VQI<W0G+"!A<G)A>2@I*3L*)')E9G)E<VA?
M=&EM92`]("1P<F5F<RT^9V5T5F%L=64H)W)E9G)E<VA?=&EM92<I.PH*+RH@
M4G5N('1H<F]U9V@@=&AE(&%C=&EO;B!H86YD;&5R<RX@*B\*)&%C=&EO;DE$
M(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD["G-W:71C:"`H)&%C
M=&EO;DE$*2!["F-A<V4@)V-O;&QA<'-E7V9O;&1E<B<Z"F-A<V4@)V5X<&%N
M9%]F;VQD97(G.@H@("`@)&9O;&1E<B`](%5T:6PZ.F=E=$9O<FU$871A*"=F
M;VQD97(G*3L*("`@(&EF("@A96UP='DH)&9O;&1E<BDI('L*("`@("`@("`H
M)&%C=&EO;DE$(#T]("=E>'!A;F1?9F]L9&5R)RD@/R`D:6UP=')E92T^97AP
M86YD*"1F;VQD97(I(#H@)&EM<'1R964M/F-O;&QA<'-E*"1F;VQD97(I.PH@
M("`@?0H@("`@8G)E86L["@IC87-E("=E>'!A;F1?86QL7V9O;&1E<G,G.@H@
M("`@)&EM<'1R964M/F5X<&%N9$%L;"@I.PH@("`@8G)E86L["@IC87-E("=C
M;VQL87!S95]A;&Q?9F]L9&5R<R<Z"B`@("`D:6UP=')E92T^8V]L;&%P<V5!
M;&PH*3L*("`@(&)R96%K.PH*8V%S92`G<F5B=6EL9%]T<F5E)SH*("`@("1I
M;7!T<F5E+3YI;FET*"D["B`@("!B<F5A:SL*"F-A<V4@)V5X<'5N9V5?9F]L
M9&5R)SH*("`@(&EF("@A96UP='DH)&9O;&1E<E]L:7-T*2D@>PH@("`@("`@
M(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TUE<W-A9V4N<&AP)SL*
M("`@("`@("`D:6UP7VUE<W-A9V4@/2`F24U07TUE<W-A9V4Z.G-I;F=L971O
M;B@I.PH@("`@("`@("1I;7!?;65S<V%G92T^97AP=6YG94UA:6QB;W@H)&9O
M;&1E<E]L:7-T*3L*("`@('T*("`@(&)R96%K.PH*8V%S92`G9&5L971E7V9O
M;&1E<B<Z"B`@("!I9B`H(65M<'1Y*"1F;VQD97)?;&ES="DI('L*("`@("`@
M("`D:6UP7V9O;&1E<BT^9&5L971E*"1F;VQD97)?;&ES="P@)'-U8G-C<FEB
M92D["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V1E;&5T95]S96%R8VA?<75E
M<GDG.@H@("`@)'%U97)Y:60@/2!5=&EL.CIG971&;W)M1&%T82@G<75E<GEI
M9"<I.PH@("`@:68@*"%E;7!T>2@D<75E<GEI9"DI('L*("`@("`@("`D:6UP
M7W-E87)C:"T^9&5L971E4V5A<F-H475E<GDH)'%U97)Y:60I.PH@("`@?0H@
M("`@8G)E86L["@IC87-E("=D;W=N;&]A9%]F;VQD97(G.@IC87-E("=D;W=N
M;&]A9%]F;VQD97)?>FEP)SH*("`@(&EF("@A96UP='DH)&9O;&1E<E]L:7-T
M*2D@>PH@("`@("`@("1M8F]X(#T@)&EM<%]F;VQD97(M/F=E;F5R871E36)O
M>"@D9F]L9&5R7VQI<W0L(&9A;'-E*3L*("`@("`@("!I9B`H)&%C=&EO;DE$
M(#T]("=D;W=N;&]A9%]F;VQD97(G*2!["B`@("`@("`@("`@("1B<F]W<V5R
M+3YD;W=N;&]A9$AE861E<G,H)&9O;&1E<E]L:7-T6S!=("X@)RYM8F]X)RP@
M;G5L;"P@9F%L<V4L('-T<FQE;B@D;6)O>"DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0V]M<')E<W,N<&AP
M)SL*("`@("`@("`@("`@)&AO<F1E7V-O;7!R97-S(#T@)DAO<F1E7T-O;7!R
M97-S.CIS:6YG;&5T;VXH)WII<"<I.PH@("`@("`@("`@("`D;6)O>"`]("1H
M;W)D95]C;VUP<F5S<RT^8V]M<')E<W,H87)R87DH87)R87DH)V1A=&$G(#T^
M("1M8F]X+"`G;F%M92<@/3X@)&9O;&1E<E]L:7-T6S!=("X@)RYM8F]X)RDI
M*3L*("`@("`@("`@("`@)&)R;W=S97(M/F1O=VYL;V%D2&5A9&5R<R@D9F]L
M9&5R7VQI<W1;,%T@+B`G+GII<"<L("=A<'!L:6-A=&EO;B]Z:7`G+"!F86QS
M92P@<W1R;&5N*"1M8F]X*2D["B`@("`@("`@?0H@("`@("`@(&5C:&\@)&UB
M;W@["B`@("`@("`@97AI=#L*("`@('T*("`@(&)R96%K.PH*8V%S92`G:6UP
M;W)T7VUB;W@G.@H@("`@)&EM<&]R=%]F;VQD97(@/2!5=&EL.CIG971&;W)M
M1&%T82@G:6UP;W)T7V9O;&1E<B<I.PH@("`@:68@*"%E;7!T>2@D:6UP;W)T
M7V9O;&1E<BDI('L*("`@("`@("`D<F5S(#T@0G)O=W-E<CHZ=V%S1FEL955P
M;&]A9&5D*"=M8F]X7W5P;&]A9"<L(%\H(FUA:6QB;W@@9FEL92(I*3L*("`@
M("`@("!I9B`H(6ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`D<F5S(#T@)&EM<%]F;VQD97(M/FEM<&]R=$UB;W@H)&EM<&]R=%]F
M;VQD97(L("1?1DE,15-;)VUB;WA?=7!L;V%D)UU;)W1M<%]N86UE)UTI.PH@
M("`@("`@("`@("!I9B`H)')E<R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG("5S+B(I+"!B87-E;F%M92@D7T9)3$536R=M
M8F]X7W5P;&]A9"==6R=N86UE)UTI*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B26UP;W)T960@)60@;65S<V%G97,@9G)O;2`E
M<RXB*2P@)')E<RP@(&)A<V5N86UE*"1?1DE,15-;)VUB;WA?=7!L;V%D)UU;
M)VYA;64G72DI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"@D<F5S+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"B`@("`@("`@)&%C
M=&EO;DE$(#T@;G5L;#L*("`@('T@96QS92!["B`@("`@("`@)')E9G)E<VA?
M=&EM92`](&YU;&P["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V-R96%T95]F
M;VQD97(G.@H@("`@)&YE=U]M86EL8F]X(#T@571I;#HZ9V5T1F]R;41A=&$H
M)VYE=U]M86EL8F]X)RD["B`@("!I9B`H(65M<'1Y*"1N97=?;6%I;&)O>"DI
M('L*("`@("`@("`D;F5W7VUA:6QB;W@@/2!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"1N97=?;6%I;&)O>"P@3DQ3.CIG971#:&%R<V5T*"DL("=55$8W+4E-
M05`G*3L*("`@("`@("!I9B`H8V]U;G0H)&9O;&1E<E]L:7-T*2`]/2`Q*2![
M"B`@("`@("`@("`@("1N86UE<W!A8V5?:6YF;R`]($E-4#HZ9V5T3F%M97-P
M86-E*"1F;VQD97)?;&ES=%LP72D["B`@("`@("`@("`@("1N97=?;6%I;&)O
M>"`]("1F;VQD97)?;&ES=%LP72`N("1N86UE<W!A8V5?:6YF;ULG9&5L:6UI
M=&5R)UT@+B`D;F5W7VUA:6QB;W@["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&YE=U]M86EL8F]X(#T@24U0.CIA<'!E;F1.86UE<W!A8V4H)&YE
M=U]M86EL8F]X*3L*("`@("`@("!]"B`@("`@("`@)&EM<%]F;VQD97(M/F-R
M96%T92@D;F5W7VUA:6QB;W@L("1S=6)S8W)I8F4I.PH@("`@?0H@("`@8G)E
M86L["@IC87-E("=R96YA;65?9F]L9&5R)SH*("`@("1N97=?;F%M97,@/2!E
M>'!L;V1E*")<;B(L(%5T:6PZ.F=E=$9O<FU$871A*"=N97=?;F%M97,G*2D[
M"B`@("`D;VQD7VYA;65S(#T@97AP;&]D92@B7&XB+"!5=&EL.CIG971&;W)M
M1&%T82@G;VQD7VYA;65S)RDI.PH@("`@)&E-87@@/2!C;W5N="@D;F5W7VYA
M;65S*3L*("`@(&EF("@A96UP='DH)&YE=U]N86UE<RD@)B8*("`@("`@("`A
M96UP='DH)&]L9%]N86UE<RD@)B8*("`@("`@("`H)&E-87@@/3T@8V]U;G0H
M)&]L9%]N86UE<RDI*2!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&E-
M87@[("1I*RLI('L*("`@("`@("`@("`@)&]L9&YA;64@/2!T<FEM*"1O;&1?
M;F%M97-;)&E=+"`B7')<;B(I.PH@("`@("`@("`@("`D;F5W;F%M92`]('1R
M:6TH)&YE=U]N86UE<ULD:5TL(")<<EQN(BD["B`@("`@("`@("`@("1N97=N
M86UE(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;F5W;F%M92P@3DQ3.CIG
M971#:&%R<V5T*"DL("=55$8W+4E-05`G*3L*("`@("`@("`@("`@)&EM<%]F
M;VQD97(M/G)E;F%M92@D;VQD;F%M92P@24U0.CIA<'!E;F1.86UE<W!A8V4H
M)&YE=VYA;64I*3L*("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@
M)W-U8G-C<FEB95]F;VQD97(G.@IC87-E("=U;G-U8G-C<FEB95]F;VQD97(G
M.@H@("`@:68@*"%E;7!T>2@D9F]L9&5R7VQI<W0I*2!["B`@("`@("`@:68@
M*"1A8W1I;VY)1"`]/2`G<W5B<V-R:6)E7V9O;&1E<B<I('L*("`@("`@("`@
M("`@)&EM<%]F;VQD97(M/G-U8G-C<FEB92@D9F]L9&5R7VQI<W0I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1I;7!?9F]L9&5R+3YU;G-U8G-C
M<FEB92@D9F]L9&5R7VQI<W0I.PH@("`@("`@('T*("`@('T@96QS92!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*").;R!F;VQD97)S('=E<F4@
M<W!E8VEF:65D(BDL("=H;W)D92YM97-S86=E)RD["B`@("!]"B`@("!B<F5A
M:SL*"F-A<V4@)W1O9V=L95]S=6)S8W)I8F5D7W9I97<G.@H@("`@:68@*"1S
M=6)S8W)I8F4I('L*("`@("`@("`D<VAO=T%L;"`]("$D<VAO=T%L;#L*("`@
M("`@("`D:6UP6R=S:&]W=6YS=6(G72`]("1S:&]W06QL.PH@("`@("`@("1I
M;7!T<F5E+3YS:&]W56YS=6)S8W)I8F5D*"1S:&]W06QL*3L*("`@('T*("`@
M(&)R96%K.PH*8V%S92`G<&]L;%]F;VQD97(G.@H@("`@:68@*"%E;7!T>2@D
M9F]L9&5R7VQI<W0I*2!["B`@("`@("`@)&EM<%]F;VQD97(M/G-U8G-C<FEB
M92@D9F]L9&5R7VQI<W0I.PH@("`@("`@("1I;7!T<F5E+3YA9&10;VQL3&ES
M="@D9F]L9&5R7VQI<W0I.PH@("`@("`@("1I;7!?<V5A<F-H+3YC<F5A=&56
M24Y"3UA&;VQD97(H*3L*("`@('T*("`@(&)R96%K.PH*8V%S92`G;F]P;VQL
M7V9O;&1E<B<Z"B`@("!I9B`H(65M<'1Y*"1F;VQD97)?;&ES="DI('L*("`@
M("`@("`D:6UP=')E92T^<F5M;W9E4&]L;$QI<W0H)&9O;&1E<E]L:7-T*3L*
M("`@("`@("`D:6UP7W-E87)C:"T^8W)E871E5DE.0D]81F]L9&5R*"D["B`@
M("!]"B`@("!B<F5A:SL*"F-A<V4@)V9O;&1E<G-?96UP='E?;6%I;&)O>"<Z
M"B`@("!I9B`H(65M<'1Y*"1F;VQD97)?;&ES="DI('L*("`@("`@("!I;F-L
M=61E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-97-S86=E+G!H<"<["B`@("`@
M("`@)&EM<%]M97-S86=E(#T@)DE-4%]-97-S86=E.CIS:6YG;&5T;VXH*3L*
M("`@("`@("`D:6UP7VUE<W-A9V4M/F5M<'1Y36%I;&)O>"@D9F]L9&5R7VQI
M<W0I.PH@("`@?0H@("`@8G)E86L["@IC87-E("=M87)K7V9O;&1E<E]S965N
M)SH*8V%S92`G;6%R:U]F;VQD97)?=6YS965N)SH*("`@(&EF("@A96UP='DH
M)&9O;&1E<E]L:7-T*2D@>PH@("`@("`@(&EN8VQU9&5?;VYC92!)35!?0D%3
M12`N("<O;&EB+TUE<W-A9V4N<&AP)SL*("`@("`@("`D:6UP7VUE<W-A9V4@
M/2`F24U07TUE<W-A9V4Z.G-I;F=L971O;B@I.PH@("`@("`@("1I;7!?;65S
M<V%G92T^9FQA9T%L;$EN36%I;&)O>"@B7%Q3145.(BP@)&9O;&1E<E]L:7-T
M+"`H)&%C=&EO;DE$(#T]("=M87)K7V9O;&1E<E]S965N)RDI.PH@("`@?0H@
M("`@8G)E86L["@IC87-E("=L;V=I;E]C;VUP;W-E)SH*("`@("1O<&5N7V-O
M;7!O<V5?=VEN9&]W(#T@24U0.CIO<&5N0V]M<&]S95=I;B@I.PH@("`@8G)E
M86L["@IC87-E("=D96QE=&5?9F]L9&5R7V-O;F9I<FTG.@IC87-E("=F;VQD
M97)S7V5M<'1Y7VUA:6QB;WA?8V]N9FER;2<Z"B`@("!I9B`H(65M<'1Y*"1F
M;VQD97)?;&ES="DI('L*("`@("`@("`D=&ET;&4@/2!?*")&;VQD97(@06-T
M:6]N<R`M($-O;F9I<FUA=&EO;B(I.PH@("`@("`@(')E<75I<F4@24U07U1%
M35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PH@("`@("`@(')E<75I
M<F4@24U07U1%35!,051%4R`N("<O;65N=2YI;F,G.PH*("`@("`@("`D;&]O
M<"`](&%R<F%Y*"D["B`@("`@("`@)')O=V-T(#T@,#L*"B`@("`@("`@9F]R
M96%C:"`H)&9O;&1E<E]L:7-T(&%S("1V86PI('L*("`@("`@("`@("`@)&1A
M=&$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=C;&%S<R<@/3X@*"LK)')O
M=V-T("4@,BD@/R`G:71E;3`G(#H@)VET96TQ)RP*("`@("`@("`@("`@("`@
M("=N86UE)R`]/B!)35`Z.F1I<W!L87E&;VQD97(H)'9A;"DL"B`@("`@("`@
M("`@("`@("`G=F%L)R`]/B`D=F%L"B`@("`@("`@("`@("D["B`@("`@("`@
M("`@("1L;V]P6UT@/2`D9&%T83L*("`@("`@("!]"@H@("`@("`@("1T96UP
M;&%T92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*("`@("`@("`D=&5M<&QA
M=&4M/G-E=$]P=&EO;B@G9V5T=&5X="<L('1R=64I.PH@("`@("`@("1T96UP
M;&%T92T^<V5T*"=C86YC96PG+"!?*")#86YC96PB*2D["B`@("`@("`@)'1E
M;7!L871E+3YS970H)V1E;&5T92<L("@D86-T:6]N240@/3T@)V1E;&5T95]F
M;VQD97)?8V]N9FER;2<I(#\@7R@B1&5L971E(%-E;&5C=&5D($9O;&1E<G,B
M*2`Z("<G+"!T<G5E*3L*("`@("`@("`D=&5M<&QA=&4M/G-E="@G96UP='DG
M+"`H)&%C=&EO;DE$(#T]("=F;VQD97)S7V5M<'1Y7VUA:6QB;WA?8V]N9FER
M;2<I(#\@7R@B16UP='D@4V5L96-T960@1F]L9&5R<R(I(#H@)R<L('1R=64I
M.PH@("`@("`@("1T96UP;&%T92T^<V5T*"=F;VQD97)S)RP@)&QO;W`I.PH@
M("`@("`@("1T96UP;&%T92T^<V5T*"=F;VQD97)S7W5R;"<L("1F;VQD97)S
M7W5R;"D["B`@("`@("`@96-H;R`D=&5M<&QA=&4M/F9E=&-H*$E-4%]414U0
M3$%415,@+B`G+V9O;&1E<G,O9F]L9&5R<U]C;VYF:7)M+FAT;6PG*3L*"B`@
M("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO
M<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*("`@("`@("!E>&ET.PH@
M("`@?0H@("`@8G)E86L["GT*"B\J($1I<W!L87D@=&AE(&-O<G)E8W0@;65S
M<V%G92!O;B!T:&4@86-T:6]N(&)A<B`J+PHD<W5B5&]G9VQE5&5X="`]("1S
M:&]W06QL(#\@7R@B2&ED92!5;G-U8G-C<FEB960B*2`Z(%\H(E-H;W<@56YS
M=6)S8W)I8F5D(BD["@HO*B!3970@=&AE(%523"!T;R!R969R97-H('1H92!P
M86=E('1O(&EN('1H92!-151!('1A9R`J+PHD<F5F<F5S:%]U<FP@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)V9O;&1E<G,N<&AP)RP@=')U92D["@HD=&ET
M;&4@/2!?*")&;VQD97(@3F%V:6=A=&]R(BD["G)E<75I<F4@24U07U1%35!,
M051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($E-4%]414U0
M3$%415,@+B`G+VUE;G4N:6YC)SL*24U0.CIS=&%T=7,H*3L*"B\J(%!R:6YT
M('%U;W1A(&EN9F]R;6%T:6]N+B`J+PII9B`H:7-S970H)'%U;W1A*2D@>PH@
M("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]Q=6]T82]Q=6]T82YI;F,G
M.PI]"@HD:2`]("1R;W=C="`](#`["B1D:7-P;&%Y3F%M97,@/2`D;F5W;7-G
M<R`](&%R<F%Y*"D["@II9B`H)&EM<%LG9FEL95]U<&QO860G72`F)B`H)&%C
M=&EO;DE$(#T]("=I;7!O<G1?;6)O>"<I*2!["B`@("!R97%U:7)E($E-4%]4
M14U03$%415,@+B`G+V9O;&1E<G,O:6UP;W)T+FEN8R<["B`@("!R97%U:7)E
M("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M
M;6]N+69O;W1E<BYI;F,G.PH@("`@97AI=#L*?2!E;'-E('L*("`@(')E<75I
M<F4@24U07U1%35!,051%4R`N("<O9F]L9&5R<R]H96%D+FEN8R<["B`@("!R
M97%U:7)E($E-4%]414U03$%415,@+B`G+V9O;&1E<G,O86-T:6]N<RYI;F,G
M.PI]"@HO*B!'970@<W!E8VEA;"!F;VQD97)S+B`J+PHD=')A<V@@/2!)35`Z
M.F9O;&1E<E!R968H)'!R969S+3YG971686QU92@G=')A<VA?9F]L9&5R)RDL
M('1R=64I.PHD9')A9G0@/2!)35`Z.F9O;&1E<E!R968H)'!R969S+3YG9716
M86QU92@G9')A9G1S7V9O;&1E<B<I+"!T<G5E*3L*)'-E;G0@/2`D:61E;G1I
M='DM/F=E=$%L;%-E;G1M86EL1F]L9&5R<R@I.PH*)&YA;65?=7)L(#T@571I
M;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G;6%I;&)O
M>"YP:'`G*2P@)VYO7VYE=VUA:6Q?<&]P=7`G+"`Q*3L*"B1M8F]X7VEC;VYS
M(#T@)&UO<F5M8F]X(#T@)')O=W,@/2!A<G)A>2@I.PH*+RH@0V%L;"!T:&4@
M;6%I;&)O>"!I8V]N(&AO;VLL(&EF(')E<75E<W1E9"X@*B\*:68@*"%E;7!T
M>2@D8V]N9ELG:&]O:W,G75LG;6)O>%]I8V]N)UTI*2!["B`@("!R97%U:7)E
M7V]N8V4@2$]21$5?0D%312`N("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?;6)O>%]I8V]N<R<I*2![
M"B`@("`@("`@)&UB;WA?:6-O;G,@/2!C86QL7W5S97)?9G5N8R@G7VEM<%]H
M;V]K7VUB;WA?:6-O;G,G*3L*("`@('T*?0H*+RH@4W1A<G0@:71E<F%T:6YG
M('1H<F]U9V@@=&AE(&QI<W0@;V8@;6%I;&)O>&5S+"!D:7-P;&%Y:6YG('1H
M96TN("HO"B1M86EL8F]X(#T@)&EM<'1R964M/G)E<V5T*"D["F1O('L*("`@
M("1M<V=S7VEN9F\@/2`D<F]W(#T@87)R87DH*3L*("`@("1R;W=;)W-H;W=?
M;7-G<R==(#T@9F%L<V4["B`@("`D<F]W6R=N;V-H96-K8F]X)UT@/2!F86QS
M93L*("`@("1R;W=;)W9F;VQD97(G72`](&9A;'-E.PH*("`@(&EF("@A)&EM
M<'1R964M/FES0V]N=&%I;F5R*"1M86EL8F]X*2D@>PH@("`@("`@("\J(%=E
M(&%R92!D96%L:6YG('=I=&@@;6%I;&)O>&5S(&AE<F4N"B`@("`@("`@("H@
M1&5T97)M:6YE(&EF('=E(&YE960@=&\@<&]L;"!T:&ES(&UA:6QB;W@@9F]R
M(&YE=R!M97-S86=E<RX@*B\*("`@("`@("!I9B`H)&EM<'1R964M/FES4&]L
M;&5D*"1M86EL8F]X*2D@>PH@("`@("`@("`@("`D<F]W6R=S:&]W7VUS9W,G
M72`]('1R=64["B`@("`@("`@("`@("\J($EF('=E(&YE960@;65S<V%G92!I
M;F9O<FUA=&EO;B!F;W(@=&AI<R!F;VQD97(L('5P9&%T92!I=`H@("`@("`@
M("`@("`@*B!N;W<N("HO"B`@("`@("`@("`@("1M<V=S7VEN9F\@/2`D:6UP
M=')E92T^9V5T16QE;65N=$EN9F\H)&UA:6QB;WA;)W9A;'5E)UTI.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1M<V=S7VEN9F\I*2!["B`@("`@("`@("`@
M("`@("`O*B!0;W!U;&%T92!T:&4@)&YE=VUS9W,@:&%S:"!W:71H('1H92!N
M97<@;7-G<R!C;W5N="X@*B\*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)&US9W-?:6YF;ULG;F5W;7-G)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&YE=VUS9W-;)&UA:6QB;WA;)W9A;'5E)UU=(#T@)&US9W-?:6YF;ULG;F5W
M;7-G)UT["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@
M261E;G1I9GD@=&AE(&YU;6)E<B!O9B!M97-S86=E<R!I;B!T:&4@9F]L9&5R
M+B`J+PH@("`@("`@("`@("`@("`@)')O=ULG;7-G<R==(#T@)&US9W-?:6YF
M;ULG;65S<V%G97,G73L*"B`@("`@("`@("`@("`@("`O*B!(:6=H;&EG:'0@
M;6%I;&)O>&5S('=I=&@@=6YR96%D(&UE<W-A9V5S(&EN(&)O;&0N("HO"B`@
M("`@("`@("`@("`@("`D<F]W6R=N97<G72`]("1M<V=S7VEN9F];)W5N<V5E
M;B==.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D<F]W6R=N97<G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D;6%I;&)O>%LG;&%B96PG72`]("<\
M<W1R;VYG/B<@+B`D;6%I;&)O>%LG;&%B96PG72`N("<\+W-T<F]N9SXG.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D<F]W6R=N86UE)UT@/2!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A
M;65T97(H)&YA;65?=7)L+"`G;6%I;&)O>"<L("1M86EL8F]X6R=V86QU92==
M*2P@<W!R:6YT9BA?*")6:65W(&UE<W-A9V5S(&EN("5S(BDL("@D:6UP=')E
M92T^:7-61F]L9&5R*"1M86EL8F]X*2D@/R`D;6%I;&)O>%LG;&%B96PG72`Z
M($E-4#HZ9&ES<&QA>49O;&1E<B@D;6%I;&)O>%LG=F%L=64G72DI*2`N("1M
M86EL8F]X6R=L86)E;"==("X@)SPO83XG.PH*("`@("`@("!S=VET8V@@*"1M
M86EL8F]X6R=V86QU92==*2!["B`@("`@("`@8V%S92`G24Y"3U@G.@H@("`@
M("`@("`@("`D9&ER,B`](%]I;6%G92@G:6YB;W@N<&YG)RP@7R@B26YB;W@B
M*2P@)V9O;&1E<B<I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`D=')A<V@Z"B`@("`@("`@("`@("1D:7(R(#T@*"1P<F5F<RT^9V5T5F%L
M=64H)W5S95]V=')A<V@G*2D@/R!?:6UA9V4H*"1I;7!T<F5E+3YI<T]P96XH
M)&UA:6QB;W@I*2`_("=F;VQD97)?;W!E;BYP;F<G(#H@)V9O;&1E<BYP;F<G
M+"!?*")-86EL8F]X(BDL("=F;VQD97(G*2`Z7VEM86=E*"=T<F%S:"YP;F<G
M+"!?*")4<F%S:"!F;VQD97(B*2P@)V9O;&1E<B<I.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`D9')A9G0Z"B`@("`@("`@("`@("1D:7(R
M(#T@7VEM86=E*"=D<F%F=',N<&YG)RP@7R@B1')A9G0@9F]L9&5R(BDL("=F
M;VQD97(G*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D;6%I;&)O>%LG=F%L=64G72P@
M)'-E;G0I*2!["B`@("`@("`@("`@("`@("`D9&ER,B`](%]I;6%G92@G<V5N
M="YP;F<G+"!?*")396YT(&UA:6P@9F]L9&5R(BDL("=F;VQD97(G*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M;6)O>%]I8V]N<ULD;6%I;&)O>%LG=F%L=64G75TI*2!["B`@("`@("`@("`@
M("`@("`@("`@)&1I<C(@/2`D;6)O>%]I8V]N<ULD;6%I;&)O>%LG=F%L=64G
M75T["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1D:7(R(#T@7VEM86=E*"@D:6UP=')E92T^:7-/<&5N*"1M86EL8F]X
M*2D@/R`G9F]L9&5R7V]P96XN<&YG)R`Z("=F;VQD97(N<&YG)RP@7R@B36%I
M;&)O>"(I+"`G9F]L9&5R)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O
M*B!6:7)T=6%L(&9O;&1E<G,N("HO"B`@("`@("`@:68@*"1I;7!T<F5E+3YI
M<U9&;VQD97(H)&UA:6QB;W@I*2!["B`@("`@("`@("`@("1R;W=;)VYO8VAE
M8VMB;W@G72`]('1R=64["B`@("`@("`@("`@(&EF("@D:6UP7W-E87)C:"T^
M:7-65')A<VA&;VQD97(H)&UA:6QB;WA;)W9A;'5E)UTI*2!["B`@("`@("`@
M("`@("`@("`D<F]W6R=V9F]L9&5R)UT@/2!F86QS93L*("`@("`@("`@("`@
M("`@("1D:7(R(#T@7VEM86=E*"=T<F%S:"YP;F<G+"!?*")6:7)T=6%L(%1R
M87-H($9O;&1E<B(I+"`G9F]L9&5R)RD["B`@("`@("`@("`@('T@96QS96EF
M("@D:6UP7W-E87)C:"T^:7-624Y"3UA&;VQD97(H)&UA:6QB;WA;)W9A;'5E
M)UTI*2!["B`@("`@("`@("`@("`@("`D<F]W6R=V9F]L9&5R)UT@/2!F86QS
M93L*("`@("`@("`@("`@("`@("1D:7(R(#T@7VEM86=E*"=I;F)O>"YP;F<G
M+"!?*")6:7)T=6%L($E.0D]8($9O;&1E<B(I+"`G9F]L9&5R)RD["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F]W6R=V9F]L9&5R
M)UT@/2!T<G5E.PH@("`@("`@("`@("`@("`@)')O=ULG9&5L=F9O;&1E<B==
M(#T@2&]R9&4Z.FQI;FLH)&EM<%]S96%R8V@M/F1E;&5T95523"@D;6%I;&)O
M>%LG=F%L=64G72DL(%\H(D1E;&5T92!6:7)T=6%L($9O;&1E<B(I*2`N(%\H
M(D1E;&5T92(I("X@)SPO83XG.PH@("`@("`@("`@("`@("`@)')O=ULG961I
M='9F;VQD97(G72`]($AO<F1E.CIL:6YK*"1I;7!?<V5A<F-H+3YE9&ET55),
M*"1M86EL8F]X6R=V86QU92==*2P@7R@B161I="!6:7)T=6%L($9O;&1E<B(I
M*2`N(%\H(D5D:70B*2`N("<\+V$^)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@+RH@5V4@87)E(&1E86QI;F<@=VET
M:"!F;VQD97)S(&AE<F4N("HO"B`@("`@("`@)')O=ULG;F%M92==(#T@)&UA
M:6QB;WA;)VQA8F5L)UT["B`@("`@("`@:68@*"1I;7!T<F5E+3YI<T]P96XH
M)&UA:6QB;W@I*2!["B`@("`@("`@("`@("1D:7(R(#T@7VEM86=E*"=F;VQD
M97)?;W!E;BYP;F<G+"!?*")/<&5N960@1F]L9&5R(BDL("=F;VQD97(G*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&ER,B`](%]I;6%G92@G
M9F]L9&5R+G!N9R<L(%\H(D-L;W-E9"!&;VQD97(B*2P@)V9O;&1E<B<I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@5FER='5A;"!F;VQD97)S+B`J+PH@("`@
M("`@(&EF("@D:6UP=')E92T^:7-61F]L9&5R*"1M86EL8F]X*2D@>PH@("`@
M("`@("`@("`D<F]W6R=N;V-H96-K8F]X)UT@/2!T<G5E.PH@("`@("`@('T*
M("`@('T*"B`@("`D<&5E:R`]("1I;7!T<F5E+3YP965K*"D["@H@("`@:68@
M*"1I;7!T<F5E+3YH87-#:&EL9')E;B@D;6%I;&)O>"P@=')U92DI('L*("`@
M("`@("`D9&ER(#T@571I;#HZ861D4&%R86UE=&5R*"1F;VQD97)S7W5R;"P@
M)V9O;&1E<B<L("1M86EL8F]X6R=V86QU92==*3L*("`@("`@("!I9B`H)&EM
M<'1R964M/FES3W!E;B@D;6%I;&)O>"DI('L*("`@("`@("`@("`@)&1I<B`]
M(%5T:6PZ.F%D9%!A<F%M971E<B@D9&ER+"`G86-T:6]N240G+"`G8V]L;&%P
M<V5?9F]L9&5R)RD["B`@("`@("`@("`@(&EF("@D;6%I;&)O>%LG=F%L=64G
M72`]/2`G24Y"3U@G*2!["B`@("`@("`@("`@("`@("`D;6EN=7-?:6UG(#T@
M)VUI;G5S=&]P+G!N9R<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D;6EN=7-?:6UG(#T@*"1P965K*2`_("=M:6YU<RYP;F<G(#H@
M)VUI;G5S8F]T=&]M+G!N9R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&1I<B`]($AO<F1E.CIL:6YK*"1D:7(L(%\H(D-O;&QA<'-E($9O;&1E<B(I
M*2`N(%]I;6%G92@D;6EN=7-?:6UG+"!?*")#;VQL87!S92(I+"`G=')E92<I
M("X@(CPO83XD9&ER,B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&1I<B`](%5T:6PZ.F%D9%!A<F%M971E<B@D9&ER+"`G86-T:6]N240G+"`G
M97AP86YD7V9O;&1E<B<I.PH@("`@("`@("`@("!I9B`H)&UA:6QB;WA;)W9A
M;'5E)UT@/3T@)TE.0D]8)RD@>PH@("`@("`@("`@("`@("`@)'!L=7-?:6UG
M(#T@)W!L=7-T;W`N<&YG)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1P;'5S7VEM9R`]("@D<&5E:RD@/R`G<&QU<RYP;F<G(#H@
M)W!L=7-B;W1T;VTN<&YG)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M9&ER(#T@2&]R9&4Z.FQI;FLH)&1I<BP@7R@B17AP86YD($9O;&1E<B(I*2`N
M(%]I;6%G92@D<&QU<U]I;6<L(%\H(D5X<&%N9"(I+"`G=')E92<I("X@(CPO
M83XD9&ER,B(["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!I9B`H
M)&UA:6QB;WA;)W9A;'5E)UT@/3T@)TE.0D]8)RD@>PH@("`@("`@("`@("`D
M:F]I;E]I;6<@/2`H)'!E96LI(#\@)VIO:6YB;W1T;VTM9&]W;BYP;F<G(#H@
M)V)L86YK+G!N9R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&IO
M:6Y?:6UG(#T@*"1P965K*2`_("=J;VEN+G!N9R<@.B`G:F]I;F)O='1O;2YP
M;F<G.PH@("`@("`@('T*("`@("`@("`D9&ER(#T@7VEM86=E*"1J;VEN7VEM
M9RP@)R<L("=T<F5E)RD@+B`D9&ER,CL*("`@('T*"B`@("`O*B!(:6=H;&EG
M:'0@;&EN92!D:69F97)E;G1L>2!I9B!F;VQD97(O;6%I;&)O>"!I<PH@("`@
M("H@=6YS=6)S8W)I8F5D+B`J+PH@("`@)')O=ULG8VQA<W,G72`]("@K*R1R
M;W=C="`E(#(I(#\@)VET96TP)R`Z("=I=&5M,2<["B`@("!I9B`H)'-H;W=!
M;&P@)B8@)'-U8G-C<FEB92`F)B`A)&EM<'1R964M/FES4W5B<V-R:6)E9"@D
M;6%I;&)O>"D@)B8@(21I;7!T<F5E+3YI<T-O;G1A:6YE<B@D;6%I;&)O>"DI
M('L*("`@("`@("`D<F]W6R=C;&%S<R==("X]("<@9F]L9&5R=6YS=6(G.PH@
M("`@?0H*("`@("1R;W=;)VUB;WA?=F%L)UT@/2!H=&UL<W!E8VEA;&-H87)S
M*"1M86EL8F]X6R=V86QU92==*3L*("`@("1R;W=;)VQI;F4G72`]("<G.PH@
M("`@)&UO<F5M8F]X6R1M86EL8F]X6R=L979E;"==72`]("1P965K.PH@("`@
M9F]R("@D:2`](#`[("1I(#P@)&UA:6QB;WA;)VQE=F5L)UT[("1I*RLI('L*
M("`@("`@("`D<F]W6R=L:6YE)UT@+CT@7VEM86=E*"@D;6]R96UB;WA;)&E=
M*2`_("=L:6YE+G!N9R<@.B`G8FQA;FLN<&YG)RP@)R<L("=T<F5E)RD["B`@
M("!]"B`@("`D<F]W6R=L:6YE)UT@+CT@)&1I<CL*"B`@("`O*B!(:61E(&9O
M;&1E<B!P<F5F:7AE<R!F<F]M('1H92!U<V5R+B`J+PH@("`@:68@*"1M86EL
M8F]X6R=L979E;"==(#X](#`I('L*("`@("`@("`D<F]W<UM=(#T@)')O=SL*
M("`@("`@("`D9&ES<&QA>4YA;65S6UT@/2!A9&1S;&%S:&5S*$E-4#HZ9&ES
M<&QA>49O;&1E<B@D;6%I;&)O>%LG=F%L=64G72DI.PH@("`@?0H*?2!W:&EL
M92`H*"1M86EL8F]X(#T@)&EM<'1R964M/FYE>'0H*2DI.PH*+RH@0VAE8VL@
M=&\@<V5E(&EF('5S97(@=V%N=',@;F5W(&UA:6P@;F]T:69I8V%T:6]N("HO
M"FEF("@D<')E9G,M/F=E=%9A;'5E*"=N879?<&]P=7`G*2D@>PH@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"A)35`Z.F=E=$YE=TUE<W-A9V50;W!U<"@D;F5W
M;7-G<RDL("=J879A<V-R:7!T)RD["GT*:68@*"1P<F5F<RT^9V5T5F%L=64H
M)VYA=E]A=61I;R<I*2!["B`@("`D<&QA>2`](&9A;'-E.PH@("`@9F]R96%C
M:"`H)&YE=VUS9W,@87,@)&UB(#T^("1N;2D@>PH@("`@("`@(&EF("@D;FT@
M/B`P*2!["B`@("`@("`@("`@("1P;&%Y(#T@=')U93L*("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@?0H@("`@?0H@("`@:68@*"1P;&%Y*2!["B`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"D@+B`G+V%U9&EO+W1H965T;VYE+G=A=B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G875D:6\G*3L*("`@('T*?0H*+RH@4F5N9&5R('1H92!R
M;W=S(&YO=RX@*B\*)'1E;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T92@I
M.PHD=&5M<&QA=&4M/G-E="@G<F]W<R<L("1R;W=S+"!T<G5E*3L*96-H;R`D
M=&5M<&QA=&4M/F9E=&-H*$E-4%]414U03$%415,@+B`G+V9O;&1E<G,O9F]L
M9&5R<RYH=&UL)RD["FEF("@D<F]W8W0@/B`Q,"D@>PH@("`@)&DK*SL*("`@
M(')E<75I<F4@24U07U1%35!,051%4R`N("<O9F]L9&5R<R]A8W1I;VYS+FEN
M8R<["GT*"G)E<75I<F4@24U07U1%35!,051%4R`N("<O9F]L9&5R<R]F;V]T
M+FEN8R<["@II9B`H(65M<'1Y*"1O<&5N7V-O;7!O<V5?=VEN9&]W*2D@>PH@
M("`@)&%R9W,@/2`G<&]P=7`],2<["B`@("!I9B`H(6ES<V5T*"1O<'1I;VYS
M*2D@>PH@("`@("`@("1O<'1I;VYS(#T@87)R87DH*3L*("`@('T*("`@(&9O
M<F5A8V@@*&%R<F%Y7VUE<F=E*"1O<'1I;VYS+"!)35`Z.F=E=$-O;7!O<V5!
M<F=S*"DI(&%S("1A<F<@/3X@)'9A;'5E*2!["B`@("`@("`@)&%R9W,@+CT@
M(65M<'1Y*"1V86QU92D@/R`G)B<@+B`D87)G("X@)STG("X@=7)L96YC;V1E
M*"1V86QU92D@.B`G)SL*("`@('T*("`@($AO<F1E.CIA9&138W)I<'1&:6QE
M*"=P;W!U<"YJ<R<I.PH@("`@96-H;R`B/'-C<FEP="!T>7!E/2=T97AT+VIA
M=F%S8W)I<'0G/G!O<'5P7VEM<"@G(B`N($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G8V]M<&]S92YP:'`G*2`N("(G+#<P,"PV-3`L)R(@+B!A9&1S;&%S:&5S
M*"1A<F=S*2`N("(G*3L\+W-C<FEP=#XB.PI]"@HO*B!"0R!C:&5C:RX@*B\*
M:68@*&-L87-S7V5X:7-T<R@G3F]T:69I8V%T:6]N7TQI<W1E;F5R7V%U9&EO
M)RDI('L*("`@("1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N
M97)S)R`]/B`G875D:6\G*2D["GT*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G
M=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEM<"]F:6QT97)P<F5F<RYP:'``````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0V,C,`,3`T,3<S-C(W
M-S``,#(P,C4P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EM<"]F:6QT97)P<F5F<RYP
M:'`L=B`R+C$V+C$P+C4@,C`P-B\P,B\P-"`Q.3HP,CHP-"!S;'5S87)Z($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@
M*B\*"D!D969I;F4H)TE-4%]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PHD
M875T:&5N=&EC871I;VX@/2!/4%](04Q&3U!%3CL*<F5Q=6ER95]O;F-E($E-
M4%]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+U!R969S+U5)+G!H<"<["G)E<75I<F4@24U07T)!4T4@+B`G+V-O;F9I9R]P
M<F5F<RYP:'`G.PH*+RH@07)E('!R969E<F5N8V5S(&QO8VME9#\@*B\*)&QO
M9VEN7VQO8VME9"`]("1P<F5F<RT^:7-,;V-K960H)V9I;'1E<E]O;E]L;V=I
M;B<I('Q\(&5M<'1Y*"1?4T534TE/3ELG:6UP)UU;)V9I;'1E<F%V86EL)UTI
M.PHD9&ES<&QA>5]L;V-K960@/2`D<')E9G,M/FES3&]C:V5D*"=F:6QT97)?
M;VY?9&ES<&QA>2<I('Q\(&5M<'1Y*"1?4T534TE/3ELG:6UP)UU;)V9I;'1E
M<F%V86EL)UTI.PHD86YY;6%I;&)O>%]L;V-K960@/2`D<')E9G,M/FES3&]C
M:V5D*"=F:6QT97)?86YY7VUA:6QB;W@G*2!\?"!E;7!T>2@D7U-%4U-)3TY;
M)VEM<"==6R=F:6QT97)A=F%I;"==*3L*)&UE;G5I=&5M7VQO8VME9"`]("1P
M<F5F<RT^:7-,;V-K960H)V9I;'1E<E]M96YU:71E;2<I.PH*+RH@4G5N('1H
M<F]U9V@@=&AE(&%C=&EO;B!H86YD;&5R<RX@*B\*)&%C=&EO;DE$(#T@571I
M;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD["G-W:71C:"`H)&%C=&EO;DE$
M*2!["F-A<V4@)W5P9&%T95]P<F5F<R<Z"B`@("!I9B`H(21L;V=I;E]L;V-K
M960I('L*("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=F:6QT97)?;VY?;&]G
M:6XG+"!5=&EL.CIG971&;W)M1&%T82@G9FEL=&5R7VQO9VEN)RDI.PH@("`@
M?0H@("`@:68@*"$D9&ES<&QA>5]L;V-K960I('L*("`@("`@("`D<')E9G,M
M/G-E=%9A;'5E*"=F:6QT97)?;VY?9&ES<&QA>2<L(%5T:6PZ.F=E=$9O<FU$
M871A*"=F:6QT97)?9&ES<&QA>2<I*3L*("`@('T*("`@(&EF("@A)&%N>6UA
M:6QB;WA?;&]C:V5D*2!["B`@("`@("`@)'!R969S+3YS971686QU92@G9FEL
M=&5R7V%N>5]M86EL8F]X)RP@571I;#HZ9V5T1F]R;41A=&$H)V9I;'1E<E]A
M;GE?;6%I;&)O>"<I*3L*("`@('T*("`@(&EF("@A)&UE;G5I=&5M7VQO8VME
M9"D@>PH@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)V9I;'1E<E]M96YU:71E
M;2<L(%5T:6PZ.F=E=$9O<FU$871A*"=F:6QT97)?;65N=6ET96TG*2D["B`@
M("!]"B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!R969E<F5N8V5S('-U
M8V-E<W-F=6QL>2!U<&1A=&5D+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@
M8G)E86L["GT*"B\J($=E="!F:6QT97(@;&EN:W,N("HO"FEF("@D<F5G:7-T
M<GDM/FAA<TUE=&AO9"@G;6%I;"]S:&]W0FQA8VML:7-T)RDI('L*("`@("1B
M;&%C:VQI<W1?;&EN:R`]("1R96=I<W1R>2T^;&EN:R@G;6%I;"]S:&]W0FQA
M8VML:7-T)RD["GT*:68@*"1R96=I<W1R>2T^:&%S365T:&]D*"=M86EL+W-H
M;W=7:&ET96QI<W0G*2D@>PH@("`@)'=H:71E;&ES=%]L:6YK(#T@)')E9VES
M=')Y+3YL:6YK*"=M86EL+W-H;W=7:&ET96QI<W0G*3L*?0II9B`H)')E9VES
M=')Y+3YH87--971H;V0H)VUA:6PO<VAO=T9I;'1E<G,G*2D@>PH@("`@)&9I
M;'1E<G-?;&EN:R`]("1R96=I<W1R>2T^;&EN:R@G;6%I;"]S:&]W1FEL=&5R
M<R<I.PI]"@HO*B!3:&]W('1H92!H96%D97(N("HO"G)E<75I<F5?;VYC92`G
M2&]R9&4O4')E9G,O54DN<&AP)SL*<F5Q=6ER92!)35!?0D%312`N("<O8V]N
M9FEG+W!R969S+G!H<"<["B1A<'`@/2`G:6UP)SL*)&=R;W5P(#T@)V9I;'1E
M<G,G.PH*4')E9G-?54DZ.F=E;F5R871E2&5A9&5R*"D["@HO*B!)9B!F:6QT
M97)S(&%R92!D:7-A8FQE9"X@*B\*:68@*&5M<'1Y*"1B;&%C:VQI<W1?;&EN
M:RD@)B8@96UP='DH)'=H:71E;&ES=%]L:6YK*2`F)B!E;7!T>2@D9FEL=&5R
M<U]L:6YK*2D@>PH@("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]F:6QT
M97)S+VYO=&%C=&EV92YI;F,G.PI](&5L<V4@>PH@("`@)'-E;&954DP@/2!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)V9I;'1E<G!R969S+G!H<"<I.PH@("`@
M<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]F:6QT97)S+W!R969S+FEN8R<[
M"GT*"G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D
M92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]F971C:&UA:6QP<F5F
M<RYP:'``````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<R
M-#<`,3`T,3<S-C(W-S``,#(P-S(T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EM<"]F
M971C:&UA:6QP<F5F<RYP:'`L=B`Q+C,Y+C0N,R`R,#`V+S`Q+S`Q(#(Q.C(X
M.C4P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($YU;F\@
M3&]U<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G24U07T)!4T4G+"!D
M:7)N86UE*%]?1DE,15]?*2D["B1A=71H96YT:6-A=&EO;B`]($]07TA!3$9/
M4$5..PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]B87-E+G!H<"<[
M"G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+T9E=&-H;6%I;"YP:'`G
M.PH*+RH@26YI=&EA;&EZ92!&971C:&UA:6P@;&EB<F%R:65S+B`J+PHD9FU?
M86-C;W5N="`]("9N97<@24U07T9E=&-H;6%I;%]!8V-O=6YT*"D["@HD9')I
M=F5R(#T@571I;#HZ9V5T1F]R;41A=&$H)V9M7V1R:79E<B<I.PHD9F5T8VA?
M=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=F971C:&UA:6QP<F5F<RYP
M:'`G*3L*)'!R969S7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<BA)35`Z.G!R
M969S55),*'1R=64I+"`G9W)O=7`G+"`G9F5T8VAM86EL)RP@9F%L<V4I.PHD
M=&]?961I="`](&YU;&P["@HO*B!(86YD;&4@8VQI96YT<R!W:71H;W5T(&IA
M=F%S8W)I<'0N("HO"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A
M8W1I;VY)1"<I.PII9B`H:7-?;G5L;"@D86-T:6]N240I*2!["B`@("!I9B`H
M571I;#HZ9V5T4&]S="@G961I="<I*2!["B`@("`@("`@)&%C=&EO;DE$(#T@
M)V9E=&-H;6%I;%]P<F5F<U]E9&ET)SL*("`@('T@96QS96EF("A5=&EL.CIG
M9710;W-T*"=S879E)RDI('L*("`@("`@("`D86-T:6]N240@/2`G9F5T8VAM
M86EL7W!R969S7W-A=F4G.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=%!O<W0H
M)V1E;&5T92<I*2!["B`@("`@("`@)&%C=&EO;DE$(#T@)V9E=&-H;6%I;%]P
M<F5F<U]D96QE=&4G.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=%!O<W0H)V)A
M8VLG*2D@>PH@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D<')E9G-?
M=7)L*3L*("`@("`@("!E>&ET.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=%!O
M<W0H)W-E;&5C="<I*2!["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M("1F971C:%]U<FPI.PH@("`@("`@(&5X:70["B`@("!]"GT*"B\J(%)U;B!T
M:')O=6=H('1H92!A8W1I;VX@:&%N9&QE<G,@*B\*<W=I=&-H("@D86-T:6]N
M240I('L*8V%S92`G9F5T8VAM86EL7V-R96%T92<Z"B`@("!I9B`H)&1R:79E
M<BD@>PH@("`@("`@("1F971C:&UA:6P@/2`F24U07T9E=&-H;6%I;#HZ9F%C
M=&]R>2@D9')I=F5R+"!A<G)A>2@I*3L*("`@('T*("`@(&)R96%K.PH*8V%S
M92`G9F5T8VAM86EL7W!R969S7V5D:70G.@H@("`@)'1O7V5D:70@/2!5=&EL
M.CIG971&;W)M1&%T82@G86-C;W5N="<I.PH@("`@)&1R:79E<B`]("1F;5]A
M8V-O=6YT+3YG971686QU92@G9')I=F5R)RP@)'1O7V5D:70I.PH@("`@)&9E
M=&-H;6%I;"`]("9)35!?1F5T8VAM86EL.CIF86-T;W)Y*"1D<FEV97(L(&%R
M<F%Y*"DI.PH@("`@8G)E86L["@IC87-E("=F971C:&UA:6Q?<')E9G-?<V%V
M92<Z"B`@("`D=&]?961I="`](%5T:6PZ.F=E=$9O<FU$871A*"=E9&ET7V%C
M8V]U;G0G*3L*("`@(&EF("@D=&]?961I="`]/2`G)RD@>PH@("`@("`@("1T
M;U]E9&ET(#T@)&9M7V%C8V]U;G0M/F%D9"@I.PH@("`@?0H*("`@("1F971C
M:&UA:6P@/2`F24U07T9E=&-H;6%I;#HZ9F%C=&]R>2@D9')I=F5R+"!A<G)A
M>2@I*3L*"B`@("`D:60@/2!5=&EL.CIG971&;W)M1&%T82@G9FU?:60G+"!?
M*")5;FYA;65D(BDI.PH@("`@)&9M7V%C8V]U;G0M/G-E=%9A;'5E*"=I9"<L
M("1I9"P@)'1O7V5D:70I.PH*("`@(&9O<F5A8V@@*"1F971C:&UA:6PM/F=E
M=%!A<F%M971E<DQI<W0H*2!A<R`D=F%L*2!["B`@("`@("`@)&9M7V%C8V]U
M;G0M/G-E=%9A;'5E*"1V86PL(%5T:6PZ.F=E=$9O<FU$871A*"=F;5\G("X@
M)'9A;"DL("1T;U]E9&ET*3L*("`@('T*"B`@("`D<')E9G,M/G-E=%9A;'5E
M*"=F971C:&UA:6Q?;&]G:6XG+"`H87)R87E?<W5M*"1F;5]A8V-O=6YT+3YG
M971!;&PH)VQO9VEN9F5T8V@G*2DI(#\@=')U92`Z(&9A;'-E*3L*"B`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&%C8V]U;G0@7"(E
M<UPB(&AA<R!B965N('-A=F5D+B(I+"`D:60I+"`G:&]R9&4N<W5C8V5S<R<I
M.PH@("`@8G)E86L["@IC87-E("=F971C:&UA:6Q?<')E9G-?9&5L971E)SH*
M("`@("1T;U]D96QE=&4@/2!5=&EL.CIG971&;W)M1&%T82@G961I=%]A8V-O
M=6YT)RD["B`@("!I9B`H(6ES7VYU;&PH)'1O7V1E;&5T92DI('L*("`@("`@
M("`D9&5L971E9%]A8V-O=6YT(#T@)&9M7V%C8V]U;G0M/F1E;&5T92@D=&]?
M9&5L971E*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B5&AE(&%C8V]U;G0@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(BDL("1D
M96QE=&5D7V%C8V]U;G1;)VED)UTI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@
M("`@("1P<F5F<RT^<V5T5F%L=64H)V9E=&-H;6%I;%]L;V=I;B<L("AA<G)A
M>5]S=6TH)&9M7V%C8V]U;G0M/F=E=$%L;"@G;&]G:6YF971C:"<I*2D@/R!T
M<G5E(#H@9F%L<V4I.PH@("`@("`@("1A8W1I;VY)1"`](&YU;&P["B`@("!]
M(&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&UU
M<W0@<V5L96-T(&%N(&%C8V]U;G0@=&\@8F4@9&5L971E9"XB*2P@)VAO<F1E
M+G=A<FYI;F<G*3L*("`@('T*("`@(&)R96%K.PI]"@HO*B!3:&]W('1H92!H
M96%D97(N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O4')E9G,O54DN<&AP)SL*
M<F5Q=6ER92!)35!?0D%312`N("<O8V]N9FEG+W!R969S+G!H<"<["B1A<'`@
M/2`G:6UP)SL*"E!R969S7U5).CIG96YE<F%T94AE861E<B@I.PIR97%U:7)E
M($E-4%]414U03$%415,@+B`G+V9E=&-H;6%I;"]T;W`N:6YC)SL*"FEF("AE
M;7!T>2@D86-T:6]N240I*2!["B`@("`O*B!)9B!A8W1I;VY)1"!I<R!S=&EL
M;"!E;7!T>2P@=V4@:&%V96XG="!S96QE8W1E9"!A;B!A8V-O=6YT"B`@("`@
M*B!Y970N("HO"B`@("`D86-C;W5N=',@/2`D9FU?86-C;W5N="T^9V5T06QL
M*"=I9"<I.PH@("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]F971C:&UA
M:6PO86-C;W5N=%]S96QE8W0N:6YC)SL*?2!E;'-E:68@*"@D86-T:6]N240@
M/3T@)V9E=&-H;6%I;%]C<F5A=&4G*2`F)B!E;7!T>2@D9')I=F5R*2D@>PH@
M("`@+RH@5V4@87)E(&-R96%T:6YG(&%N(&%C8V]U;G0@86YD(&YE960@=&\@
M<V5L96-T('1H92!T>7!E+B`J+PH@("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53
M("X@)R]F971C:&UA:6PO9')I=F5R7W-E;&5C="YI;F,G.PI](&5L<V4@>PH@
M("`@)&9M7V-O;&]R<R`]($E-4%]&971C:&UA:6PZ.FQI<W1#;VQO<G,H*3L*
M("`@(')E<75I<F4@24U07U1%35!,051%4R`N("<O9F5T8VAM86EL+VUA;F%G
M92YI;F,G.PI]"@IR97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G
M+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VEM<"]F971C:&UA:6PN<&AP````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,W,34`,3`T,3<S-C(W-S``,#$W-C8P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&EM<"]F971C:&UA:6PN<&AP+'8@,2XT,"XX+C0@,C`P
M-B\P,2\P,2`R,3HR.#HU,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!.=6YO($QO=7)E:7)O(#QN=6YO0&-O+G-A<&\N<'0^"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*B\*"D!D969I;F4H
M)TE-4%]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@
M24U07T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92!)35!?
M0D%312`N("<O;&EB+T9E=&-H;6%I;"YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U!R969S+U5)+G!H<"<["@HO*B!);FET:6%L:7IE($9E=&-H;6%I;"!L
M:6)R87)I97,N("HO"B1F;5]A8V-O=6YT(#T@)FYE=R!)35!?1F5T8VAM86EL
M7T%C8V]U;G0H*3L*"B\J(%)U;B!T:')O=6=H('1H92!A8W1I;VX@:&%N9&QE
M<G,N("HO"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)
M1"<I.PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=F971C:&UA:6Q?9F5T
M8V@G.@H@("`@)&9E=&-H7VQI<W0@/2!5=&EL.CIG971&;W)M1&%T82@G86-C
M;W5N=',G*3L*("`@(&EF("@A96UP='DH)&9E=&-H7VQI<W0I*2!["B`@("`@
M("`@24U07T9E=&-H;6%I;#HZ9F5T8VA-86EL*"1F971C:%]L:7-T*3L*"B`@
M("`@("`@+RH@1V\@=&\@=&AE(&1O=VYL;V%D(&9O;&1E<BX@*B\*("`@("`@
M("`D;&UA:6QB;W@@/2`D9FU?86-C;W5N="T^9V5T5F%L=64H)VQM86EL8F]X
M)RP@)&9E=&-H7VQI<W1;,%TI.PH@("`@("`@("1U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=M86EL8F]X+G!H<"<I
M+"`G;6%I;&)O>"<L("1L;6%I;&)O>"D["B`@("`@("`@:68@*"1P<F5F<RT^
M9V5T5F%L=64H)V9E=&-H;6%I;%]P;W!U<"<I*2!["B`@("`@("`@("`@(%5T
M:6PZ.F-L;W-E5VEN9&]W2E,H)V]P96YE<BYF;V-U<R@I.V]P96YE<BYL;V-A
M=&EO;BYH<F5F/2(G("X@)'5R;"`N("<B.R<I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@
M("`@("!]"B`@("`@("`@97AI=#L*("`@('T*("`@(&)R96%K.PI]"@HD86-C
M;W5N=',@/2`D9FU?86-C;W5N="T^9V5T06QL*"=I9"<I.PHD9F5T8VA?=7)L
M(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=F971C:&UA:6PN<&AP)RD["B1T
M:71L92`](%\H(D]T:&5R($UA:6P@06-C;W5N=',B*3L*"G)E<75I<F4@24U0
M7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PH*:68@*"1P<F5F
M<RT^9V5T5F%L=64H)V9E=&-H;6%I;%]P;W!U<"<I*2!["B`@("`D8V%N8V5L
M7VIS(#T@)W=I;F1O=RYC;&]S92@I.R<["GT@96QS92!["B`@("!R97%U:7)E
M($E-4%]414U03$%415,@+B`G+VUE;G4N:6YC)SL*"B`@("!I9B`H(55T:6PZ
M.F=E=$9O<FU$871A*"=L;6%I;&)O>"<I*2!["B`@("`@("`@)&UB;W@@/2`G
M24Y"3U@G.PH@("`@?2!E;'-E('L*("`@("`@("`D;6)O>"`](%5T:6PZ.F=E
M=$9O<FU$871A*"=L;6%I;&)O>"<I.PH@("`@?0H@("`@)&-A;F-E;%]J<R`]
M("=W:6YD;W<N;&]C871I;VX@/2!<)R<@+B!5=&EL.CIA9&1087)A;65T97(H
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=M86EL8F]X+G!H<"<I+"`G;6%I;&)O
M>"<L("1M8F]X*2`N("=<)SLG.PI]"@IR97%U:7)E($E-4%]414U03$%415,@
M+B`G+V9E=&-H;6%I;"]F971C:&UA:6PN:6YC)SL*<F5Q=6ER92`D<F5G:7-T
M<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T
M97(N:6YC)SL*````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M97AP86YD+G!H<```````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,3`P`#$P-#$W,S8R-S<P`#`Q-S$V-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!I;7`O97AP86YD+G!H<"QV(#$N,38N,3`N-"`R,#`V+S`Q+S`Q
M(#(Q.C(X.C4P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J
M+PH*)&YO7V-O;7!R97-S(#T@=')U93L*)&%U=&AE;G1I8V%T:6]N(#T@)VAO
M<F1E)SL*"D!D969I;F4H)TE-4%]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI
M.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HD
M86-T:6]N240@/2!5=&EL.CIG971&;W)M1&%T82@G86-T:6]N240G*3L*"FEF
M("@D86-T:6]N240@/3T@)V5X<&%N9%]A9&1R97-S97,G*2!["B`@("`D9F]R
M;5]N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)V9O<FU?;F%M92<I.PH@("`@
M)&9I96QD7VYA;64@/2!5=&EL.CIG971&;W)M1&%T82@G9FEE;&1?;F%M92<I
M.PH@("`@)&9I96QD7W9A;'5E(#T@571I;#HZ9V5T1F]R;41A=&$H)V9I96QD
M7W9A;'5E)RD["@H@("`@)&%D9')E<W,@/2!)35`Z.F5X<&%N9$%D9')E<W-E
M<R@D9FEE;&1?=F%L=64L('1R=64I.PH@("`@:68@*&ES7V$H)&%D9')E<W,L
M("=014%27T5R<F]R)RD@)B8*("`@("`@("`D8V]N9ELG8V]M<&]S92==6R=A
M9&1?;6%I;&1O;6%I;E]T;U]U;F5X<&%N9&%B;&4G72D@>PH@("`@("`@("1A
M9&1R4W1R:6YG(#T@<')E9U]R97!L86-E*"<O+%QS*R\G+"`G+"<L("1F:65L
M9%]V86QU92D["B`@("`@("`@)&%D9')3=')I;F<@/2!P<F5G7W)E<&QA8V4H
M)R]<<RLO)RP@)RXG+"`D861D<E-T<FEN9RD["B`@("`@("`@)&%D9')E<W,@
M/2!-24U%.CIE;F-O9&5!9&1R97-S*"1A9&1R4W1R:6YG+"!N=6QL+"`D7U-%
M4U-)3TY;)VEM<"==6R=M86EL9&]M86EN)UTI.PH@("`@?0I]"@IR97%U:7)E
M($E-4%]414U03$%415,@+B`G+V-O;7!O<V4O97AP86YD+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]C;VYT86-T<RYP:'``````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4T,S,`,3`T,3<S
M-C(W-S``,#$W-30Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EM<"]C;VYT86-T<RYP
M:'`L=B`R+C8W+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HU,"!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-87)C=7,@22X@4GEA;B`\;6%R
M8W5S0')I8F]F;&%V:6XN;F5T/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF
M('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*B\*"D!D969I;F4H
M)TE-4%]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@
M24U07T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HO*B!'970@=&AE(&QI<W1S
M(&]F(&%D9')E<W,@8F]O:W,@=&AR;W5G:"!T:&4@05!)+B`J+PHD<V]U<F-E
M7VQI<W0@/2`D<F5G:7-T<GDM/F-A;&PH)V-O;G1A8W1S+W-O=7)C97,G*3L*
M"B\J($EF('=E('-E;&8M<W5B;6ET=&5D+"!U<V4@=&AA="!S;W5R8V4N($]T
M:&5R=VES92P@8VAO;W-E(&$@9V]O9`H@*B!S;W5R8V4N("HO"B1S;W5R8V4@
M/2!5=&EL.CIG971&;W)M1&%T82@G<V]U<F-E)RD["FEF("AE;7!T>2@D<V]U
M<F-E*2!\?"`A:7-S970H)'-O=7)C95]L:7-T6R1S;W5R8V5=*2D@>PH@("`@
M+RH@5V4@9&]N)W0@:G5S="!P87-S('1H92!S96-O;F0@87)G=6UE;G0@=&\@
M9V5T1F]R;41A=&$H*2!B96-A=7-E"B`@("`@*B!W92!W86YT('1O('1R87`@
M9F]R(&EN=F%L:60@<V]U<F-E<RP@;F]T(&IU<W0@;F\@<V]U<F-E+B`J+PH@
M("`@)'-O=7)C92`](&ME>2@D<V]U<F-E7VQI<W0I.PI]"@HO*B!'970@=&AE
M('-E87)C:"!A<R!S=6)M:71T960@*&1E9F%U;'1S('1O("<G('=H:6-H('-H
M;W5L9"!L:7-T(&5V97)Y;VYE*2X@*B\*)'-E87)C:"`](%5T:6PZ.F=E=$9O
M<FU$871A*"=S96%R8V@G*3L*"B\J($=E="!T:&4@;F%M92!O9B!T:&4@8V%L
M;&EN9R!F;W)M("A$969A=6QT<R!T;R`G8V]M<&]S92<I+B`J+PHD9F]R;6YA
M;64@/2!5=&EL.CIG971&;W)M1&%T82@G9F]R;6YA;64G+"`G8V]M<&]S92<I
M.PH*+RH@07)E('=E(&QI;6ET:6YG('1O(&]N;'D@=&AE("=4;SHG(&9I96QD
M/R`J+PHD=&]?;VYL>2`](%5T:6PZ.F=E=$9O<FU$871A*"=T;U]O;FQY)RD[
M"@HD87!I87)G<R`](&%R<F%Y*`H@("`@)V%D9')E<W-E<R<@/3X@87)R87DH
M)'-E87)C:"DL"B`@("`G861D<F5S<V)O;VMS)R`]/B!A<G)A>2@D<V]U<F-E
M*2P*("`@("=F:65L9',G(#T^(&%R<F%Y*"D**3L*"FEF("@D<V5A<F-H7V9I
M96QD<U]P<F5F(#T@)'!R969S+3YG971686QU92@G<V5A<F-H7V9I96QD<R<I
M*2!["B`@("!F;W)E86-H("AE>'!L;V1E*")<;B(L("1S96%R8VA?9FEE;&1S
M7W!R968I(&%S("1S*2!["B`@("`@("`@)',@/2!T<FEM*"1S*3L*("`@("`@
M("`D<R`](&5X<&QO9&4H(EQT(BP@)',I.PH@("`@("`@(&EF("@A96UP='DH
M)'-;,%TI("8F("@D<ULP72`]/2`D<V]U<F-E*2D@>PH@("`@("`@("`@("`D
M87!I87)G<ULG9FEE;&1S)UU;87)R87E?<VAI9G0H)',I72`]("1S.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"GT*"B1R97-U;'1S(#T@
M87)R87DH*3L*:68@*%5T:6PZ.F=E=$9O<FU$871A*"=S96%R8VAE9"<I('Q\
M("1P<F5F<RT^9V5T5F%L=64H)V1I<W!L87E?8V]N=&%C="<I*2!["B`@("`D
M<F5S=6QT<R`]("1R96=I<W1R>2T^8V%L;"@G8V]N=&%C=',O<V5A<F-H)RP@
M)&%P:6%R9W,I.PI]"@HO*B!4:&4@<F5S=6QT<R!L:7-T(')E='5R;G,@86X@
M87)R87D@9F]R(&5A8V@@<V]U<F-E('-E87)C:&5D("T@870@;&5A<W0*("H@
M=&AA="=S(&AO=R!I="!L;V]K<R!T;R!M92X@36%K92!I="!A;&P@;VYE(&%R
M<F%Y(&EN<W1E860N("HO"B1A9&1R97-S97,@/2!A<G)A>2@I.PIF;W)E86-H
M("@D<F5S=6QT<R!A<R`D<BD@>PH@("`@)&%D9')E<W-E<R`](&%R<F%Y7VUE
M<F=E*"1A9&1R97-S97,L("1R*3L*?0H*+RH@268@<V5L9BUS=6)M:71T960L
M('!R97-E<G9E('1H92!C=7)R96YT;'D@<V5L96-T960@=7-E<G,@96YC;V1E
M9"!B>0H@*B!J879A<V-R:7!T('1O('!A<W,@87,@=F%L=65\=&5X="X@*B\*
M)'-E;&5C=&5D7V%D9')E<W-E<R`](&%R<F%Y*"D["B1S82`](&5X<&QO9&4H
M)WPG+"!5=&EL.CIG971&;W)M1&%T82@G<V$G*2D["F9O<B`H)&D@/2`P.R`D
M:2`\(&-O=6YT*"1S82D@+2`Q.R`D:2`K/2`R*2!["B`@("`D<V5L96-T961?
M861D<F5S<V5S6R1S85LD:5U=(#T@)'-A6R1I("L@,5T["GT*"B\J(%)E9VES
M=&5R('1H92!D;W5B;&4@8VQI8VL@979E;G1S+B`J+PII9B`H)&)R;W=S97(M
M/FES0G)O=W-E<B@G;7-I92<I*2!["B`@("`D<V5L96-T7V5V96YT(#T@)R!O
M;F1B;&-L:6-K/2)A9&1!9&1R97-S*%PG=&]<)RDB)SL*("`@("1O<'1I;VY?
M979E;G0@/2`G)SL*?2!E;'-E('L*("`@("1S96QE8W1?979E;G0@/2`G)SL*
M("`@("1O<'1I;VY?979E;G0@/2`G(&]N9&)L8VQI8VL](F%D9$%D9')E<W,H
M7"=T;UPG*2(G.PI]"@HO*B!3970@=&AE(&1E9F%U;'0@;&ES="!D:7-P;&%Y
M("AN86UE(&]R(&5M86EL*2X@*B\*)&1I<W!L87D@/2!5=&EL.CIG971&;W)M
M1&%T82@G9&ES<&QA>2<L("=N86UE)RD["@HO*B!$:7-P;&%Y('1H92!F;W)M
M+B`J+PHD=&ET;&4@/2!?*")!9&1R97-S($)O;VLB*3L*<F5Q=6ER92!)35!?
M5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@24U0
M7U1%35!,051%4R`N("<O8V]N=&%C=',O8V]N=&%C=',N:6YC)SL*<F5Q=6ER
M92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O
M;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:6UP+V-O;7!O<V4N<&AP````````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#$V-#0Q-@`Q,#0Q-S,V,C<W,``P,3<S-S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:6UP+V-O;7!O<V4N<&AP+'8@,BXX,#`N,BXV-B`R
M,#`V+S`R+S$V(#$S.C0V.C$X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO
M<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN
M"B`J+PH*+RHJ"B`J($1E=&5R;6EN97,@=&AE(&%C=&EO;DE$+@H@*B\*9G5N
M8W1I;VX@7V=E=$%C=&EO;DE$*"D*>PH@("`@:68@*"1A:60@/2!5=&EL.CIG
M971&;W)M1&%T82@G86-T:6]N240G*2D@>PH@("`@("`@(')E='5R;B!S=')?
M<F5P;&%C92@G8G1N7R<L("<G+"`D86ED*3L*("`@('T*"B`@("!I9B`H571I
M;#HZ9V5T1F]R;41A=&$H)V)T;E]S96YD7VUE<W-A9V4G*2D@>PH@("`@("`@
M("\J($%L=&5R('1H92`G4V5N9"!-97-S86=E)R!A8W1I;VX@:68@=&AE(")3
M<&5L;"!C:&5C:R!B969O<F4@<V5N9&EN9PH@("`@("`@("H@;65S<V%G93\B
M('!R969E<F5N8V4@:&%S(&)E96X@96YA8FQE9"X@*B\*("`@("`@("!I9B`H
M(65M<'1Y*"1C;VYF6R=U=&EL<R==6R=S<&5L;&-H96-K97(G72D@)B8*("`@
M("`@("`@("`@)'!R969S+3YG971686QU92@G8V]M<&]S95]S<&5L;&-H96-K
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("=S<&5L;%]C:&5C:U]S96YD)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)W-E;F1?;65S
M<V%G92<["B`@("`@("`@?0H@("`@?2!E;'-E:68@*%5T:6PZ.F=E=$9O<FU$
M871A*"=B=&Y?<V%V95]D<F%F="<I*2!["B`@("`@("`@<F5T=7)N("=S879E
M7V1R869T)SL*("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G8G1N
M7V-A;F-E;%]C;VUP;W-E)RDI('L*("`@("`@("!R971U<FX@)V-A;F-E;%]C
M;VUP;W-E)SL*("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G8G1N
M7V%D9%]A='1A8VAM96YT)RDI('L*("`@("`@("!R971U<FX@)V%D9%]A='1A
M8VAM96YT)SL*("`@('T*?0H*+RHJ"B`J(%)E='5R;B!A;B!U<FP@9F]R(&UA
M:6QB;W@N<&AP(&1E<&5N9&EN9R!O;B!W:&%T(&MI;F0@;V8@<W1A<G0O<&%G
M90H@*B!I;F9O<FUA=&EO;B!W92!H879E+@H@*@H@*B!`<&%R86T@8F]O;&5A
M;B`D96YC;V1E("!7:&5T:&5R(&]R(&YO="!T;R!E;F-O9&4@96YT:71I97,@
M:6X@=&AE(%523"X*("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("`@5&AE(&)A
M<V4@55),+@H@*B\*9G5N8W1I;VX@7VUA:6QB;WA2971U<FY54DPH)&5N8V]D
M92P@)'5R;"`](&YU;&PI"GL*("`@(&EF("AE;7!T>2@D=7)L*2D@>PH@("`@
M("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)VUA:6QB;W@N<&AP
M)RD["B`@("!]"@H@("`@9F]R96%C:"`H87)R87DH)W-T87)T)RP@)W!A9V4G
M*2!A<R`D:V5Y*2!["B`@("`@("`@:68@*"@D<&%R86T@/2!5=&EL.CIG971&
M;W)M1&%T82@D:V5Y*2DI('L*("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D=7)L+"`D:V5Y+"`D<&%R86TL("1E;F-O9&4I.PH@("`@
M("`@('T*("`@('T*"B`@("!R971U<FX@)'5R;#L*?0H*+RHJ"B`J(%)E='5R
M;G,@82!4;SHL($-C.B!O<B!"8V,Z(&QI<W0@8G5I;&0@9G)O;2!A('-E;&5C
M=&EO;B!B87-E9"!O;B`G97AP86YD"B`J(&YA;65S)RX*("HO"F9U;F-T:6]N
M(%]G971!9&1R97-S3&ES="@D9FEE;&0L("1E>'!A;F0@/2!F86QS92D*>PH@
M("`@)'1O(#T@=')I;2A5=&EL.CIG971&;W)M1&%T82@D9FEE;&0I*3L*("`@
M(&EF("@A96UP='DH)'1O*2D@>PH@("`@("`@("1T;R`](&EM<&QO9&4H)RP@
M)RP@7V-L96%N061D<DQI<W0H87)R87DH)'1O*2DI.PH@("`@("`@(')E='5R
M;B`D97AP86YD(#\@)'1O(#H@7V9O<FUA=$%D9'(H)'1O*3L*("`@('T*"B`@
M("`D=&]?;&ES="`](%5T:6PZ.F=E=$9O<FU$871A*"1F:65L9"`N("=?;&ES
M="<I.PH@("`@)'1O(#T@571I;#HZ9V5T1F]R;41A=&$H)&9I96QD("X@)U]F
M:65L9"<I.PH*("`@("1T;7`@/2!A<G)A>2@I.PH@("`@:68@*&ES7V%R<F%Y
M*"1T;RDI('L*("`@("`@("!F;W)E86-H("@D=&\@87,@)&ME>2`]/B`D861D
M<F5S<RD@>PH@("`@("`@("`@("`D=&UP6R1K97E=(#T@)&%D9')E<W,["B`@
M("`@("`@?0H@("`@?0H@("`@:68@*&ES7V%R<F%Y*"1T;U]L:7-T*2D@>PH@
M("`@("`@(&9O<F5A8V@@*"1T;U]L:7-T(&%S("1K97D@/3X@)&%D9')E<W,I
M('L*("`@("`@("`@("`@:68@*"1A9&1R97-S("$]("<G*2!["B`@("`@("`@
M("`@("`@("`D=&UP6R1K97E=(#T@)&%D9')E<W,["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@)'1O7VYE=R`]('1R:6TH571I;#HZ9V5T
M1F]R;41A=&$H)&9I96QD("X@)U]N97<G*2D["B`@("!I9B`H(65M<'1Y*"1T
M;U]N97<I*2!["B`@("`@("`@)'1M<%M=(#T@)'1O7VYE=SL*("`@('T*("`@
M(')E='5R;B!I;7!L;V1E*"<L("<L("1T;7`I.PI]"@HO*BH*("H@17AP86YD
M(&%D9')E<W-E<R!I;B!A(&AE861E<BX*("HO"F9U;F-T:6]N(%]E>'!A;F1!
M9&1R97-S97,H)&AE861E<BD*>PH@("`@)')E<W5L="`]($E-4#HZ97AP86YD
M061D<F5S<V5S*%]G971!9&1R97-S3&ES="@D:&5A9&5R+"!T<G5E*2P@=')U
M92D["@H@("`@:68@*&ES7V%R<F%Y*"1R97-U;'0I*2!["B`@("`@("`@)$=,
M3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*%\H(E!L96%S92!R97-O;'9E
M(&%M8FEG=6]U<R!O<B!I;G9A;&ED(&%D9')E<W-E<RXB*2P@)VAO<F1E+G=A
M<FYI;F<G*3L*("`@('T@96QS96EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`D97)R;W(@/2`D<F5S=6QT.PH@("`@("`@("1R
M97-U;'0@/2!A<G)A>2@I.PH*("`@("`@("`D;&ES="`]("1E<G)O<BT^9V5T
M57-E<DEN9F\H*3L*("`@("`@("!I9B`H:7-?87)R87DH)&QI<W0I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1E;G1R>2D@>PH@("`@("`@
M("`@("`@("`@:68@*&ES7V]B:F5C="@D96YT<GDI*2!["B`@("`@("`@("`@
M("`@("`@("`@)')E<W5L=%M=(#T@)&5N=')Y+3YG9715<V5R26YF;R@I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M<F5S=6QT6UT@/2`D96YT<GD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO
M;B==+3YP=7-H*"1E<G)O<BP@)VAO<F1E+G=A<FYI;F<G*3L*("`@('T*"B`@
M("!R971U<FX@)')E<W5L=#L*?0H*+RHJ"B`J($-H96-K<R!F;W(@;F]N+7-T
M86YD87)D(&%D9')E<W,@9F]R;6%T<RP@<W5C:"!A<R!S97!A<F%T:6YG('=I
M=&@@<W!A8V5S"B`J(&]R('-E;6EC;VQO;G,L(&%N9"!R971U<FX@82`B8VQE
M86YE9"!A9&1R97-S('-T<FEN9R(N"B`J+PIF=6YC=&EO;B!?9F]R;6%T061D
M<B@D861D<BD*>PH@("`@+RH@268@=&AE<F4@87)E(&%N9VQE(&)R86-K971S
M("@\/BDL(&]R(&$@8V]L;VX@*&=R;W5P(&YA;64*("`@("`@(&1E;&EM:71E
M<BDL(&%S<W5M92!T:&4@=7-E<B!K;F5W('=H870@=&AE>2!W97)E(&1O:6YG
M+B`J+PH@("`@:68@*"%E;7!T>2@D861D<BD@)B8*("`@("`@("`H<W1R<&]S
M*"1A9&1R+"`G/B<I(#T]/2!F86QS92D@)B8*("`@("`@("`H<W1R<&]S*"1A
M9&1R+"`G.B<I(#T]/2!F86QS92DI('L*("`@("`@("`D861D<B`]('1R:6TH
M<W1R='(H)&%D9'(L("<[+"<L("<@("<I*3L*("`@("`@("`D861D<B`]('!R
M96=?<F5P;&%C92@G?%QS*WPG+"`G+"`G+"`D861D<BD["B`@("!]"@H@("`@
M<F5T=7)N("1A9&1R.PI]"@HO*BH*("H@1V5N97)A=&4@82!R96-I<&EE;G0@
M;&ES="X*("HO"F9U;F-T:6]N(%]R96-I<&EE;G1,:7-T*"1A9&1R*0I["B`@
M("`D861D<FQI<W0@/2!?8VQE86Y!9&1R3&ES="@D861D<BD["@H@("`@:68@
M*&5M<'1Y*"1A9&1R;&ES="DI('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@<F5C:7!I
M96YT+B(I*3L*("`@('T*"B`@("!F;W)E86-H("A-24U%.CIB87)E061D<F5S
M<RAI;7!L;V1E*"<L("<L("1A9&1R;&ES="DL("1'3$]"04Q36R=I;7`G75LG
M;6%I;&1O;6%I;B==+"!T<G5E*2!A<R`D=F%L*2!["B`@("`@("`@:68@*$U)
M344Z.FES.&)I="@D=F%L*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(DEN=F%L:60@8VAA<F%C=&5R(&EN(&4M
M;6%I;"!A9&1R97-S.B`E<RXB*2P@)'9A;"DI.PH@("`@("`@('T*("`@('T*
M"B`@("!R971U<FX@)&%D9')L:7-T.PI]"@HO*BH*("H@4F5T=7)N<R!T:&4@
M8VAA<G-E="!T;R!U<V4@9F]R(&]U=&=O:6YG(&UE<W-A9V5S(&)A<V5D(&]N
M("AB>2!R97!L>6EN9PH@*B!T;R!O<B!F;W)W87)D:6YG*2!T:&4@9VEV96X@
M34E-12!M97-S86=E(&%N9"!T:&4@=7-E<B=S(&1E9F%U;'0@<V5T=&EN9W,*
M("H@86YD(&%N>2!P<F5V:6]U<VQY('-E;&5C=&5D(&-H87)S970N"B`J+PIF
M=6YC=&EO;B!?9V5T16YC;V1I;F<H)&UI;65?;65S<V%G92`](&YU;&PI"GL*
M("`@(&EF("@D1TQ/0D%,4ULG8VAA<G-E="==*2!["B`@("`@("`@<F5T=7)N
M("1'3$]"04Q36R=C:&%R<V5T)UT["B`@("!]"@H@("`@)&5N8V]D:6YG(#T@
M3DQ3.CIG971%;6%I;$-H87)S970H*3L*"B`@("!I9B`H:7-S970H)&UI;65?
M;65S<V%G92DI('L*("`@("`@("`D;6EM95]M97-S86=E(#T@)E5T:6PZ.F-L
M;VYE3V)J96-T*"1M:6UE7VUE<W-A9V4I.PH@("`@("`@("1M:6UE7W!A<G0@
M/2`D;6EM95]M97-S86=E+3YG971"87-E4&%R="@I.PH@("`@("`@(&EF("@D
M;6EM95]P87)T+3YG9710<FEM87)Y5'EP92@I(#T]($U)344Z.G1Y<&4H5%E0
M14U53%1)4$%25"DI('L*("`@("`@("`@("`@9F]R96%C:"`H)&UI;65?<&%R
M="T^9V5T4&%R=',H*2!A<R`D<&%R="D@>PH@("`@("`@("`@("`@("`@:68@
M*"1P87)T+3YG9710<FEM87)Y5'EP92@I(#T]($U)344Z.G1Y<&4H5%E0151%
M6%0I*2!["B`@("`@("`@("`@("`@("`@("`@)&UI;65?<&%R="`]("1P87)T
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("A.3%,Z.F=E
M=$-H87)S970H*2`]/2`G551&+3@G*2!["B`@("`@("`@("`@("1C:&%R<V5T
M7W5P<&5R(#T@4W1R:6YG.CIU<'!E<B@D;6EM95]P87)T+3YG971#:&%R<V5T
M*"DI.PH@("`@("`@("`@("!I9B`H*"1C:&%R<V5T7W5P<&5R("$]("=54RU!
M4T-)22<I("8F"B`@("`@("`@("`@("`@("`H)&-H87)S971?=7!P97(@(3T@
M4W1R:6YG.CIU<'!E<B@D96YC;V1I;F<I*2D@>PH@("`@("`@("`@("`@("`@
M)&5N8V]D:6YG(#T@)U541BTX)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("!R971U<FX@)&5N8V]D:6YG.PI]"@HO*BH*("H@4V5T=7`@
M=&AE(&)A<V4@;65S<V%G92!-24U%7U!A<G0@;V)J96-T+@H@*B\*9G5N8W1I
M;VX@7V)A<V5-97-S86=E*"8D:6UP7V-O;7!O<V4L("1C:&%R<V5T+"`D9FEN
M86Q?;7-G(#T@=')U92D*>PH@("`@)&UE<W-A9V4@/2!3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*%5T:6PZ.F=E=$9O<FU$871A*"=M97-S86=E)RP@)R<I+"!.
M3%,Z.F=E=$-H87)S970H*2P@)&-H87)S970I.PH*("`@(&EF("@D1TQ/0D%,
M4ULG<G1E;6]D92==*2!["B`@("`@("`@)&UE<W-A9V5?:'1M;"`]("1M97-S
M86=E.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N
M<&AP)SL*("`@("`@("`D;65S<V%G92`](%1E>'1?1FEL=&5R.CIF:6QT97(H
M)&UE<W-A9V4L("=H=&UL,G1E>'0G*3L*("`@('T*"B`@("`O*B!'970@=')A
M:6QE<B!M97-S86=E("AI9B!A;GDI+B`J+PH@("`@)'1R86EL97(@/2!N=6QL
M.PH@("`@:68@*"1F:6YA;%]M<V<@)B8*("`@("`@("`D1TQ/0D%,4ULG8V]N
M9B==6R=M<V<G75LG87!P96YD7W1R86EL97(G72`F)@H@("`@("`@($!I<U]R
M96%D86)L92A)35!?0D%312`N("<O8V]N9FEG+W1R86EL97(N='AT)RDI('L*
M("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<[
M"B`@("`@("`@)'1R86EL97(@/2!497AT7T9I;'1E<CHZ9FEL=&5R*")<;B(@
M+B!F:6QE7V=E=%]C;VYT96YT<RA)35!?0D%312`N("<O8V]N9FEG+W1R86EL
M97(N='AT)RDL("=E;G9I<F]N;65N="<I.PH@("`@("`@("\J($EF('1H97)E
M(&ES(&$@=7-E<B!D969I;F5D(&9U;F-T:6]N+"!C86QL(&ET('=I=&@@=&AE
M(&-U<G)E;G0*("`@("`@("`@("!T<F%I;&5R(&%S(&%N(&%R9W5M96YT+B`J
M+PH@("`@("`@(&EF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG:&]O:W,G
M75LG=')A:6QE<B==*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("`@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)U]I;7!?:&]O:U]T<F%I;&5R)RDI('L*("`@
M("`@("`@("`@("`@("1T<F%I;&5R(#T@8V%L;%]U<V5R7V9U;F,H)U]I;7!?
M:&]O:U]T<F%I;&5R)RP@)'1R86EL97(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J(%-E="!U<"!T:&4@8F]D>2!P87)T(&YO=RX@
M*B\*("`@("1T97AT0F]D>2`]("9N97<@34E-15]087)T*"=T97AT+W!L86EN
M)RD["B`@("`D=&5X=$)O9'DM/G-E=$-O;G1E;G1S*"1T97AT0F]D>2T^<F5P
M;&%C945/3"@D;65S<V%G92DI.PH@("`@)'1E>'1";V1Y+3YS971#:&%R<V5T
M*"1C:&%R<V5T*3L*("`@(&EF("@A:7-?;G5L;"@D=')A:6QE<BDI('L*("`@
M("`@("`D=&5X=$)O9'DM/F%P<&5N9$-O;G1E;G1S*"1T<F%I;&5R*3L*("`@
M('T*"B`@("`O*B!396YD(&EN(&9L;W=E9"!F;W)M870N("HO"B`@("!R97%U
M:7)E7V]N8V4@)U1E>'0O1FQO=V5D+G!H<"<["B`@("`D9FQO=V5D(#T@)FYE
M=R!497AT7T9L;W=E9"@D=&5X=$)O9'DM/F=E=$-O;G1E;G1S*"DL("1C:&%R
M<V5T*3L*("`@(&EF("AM971H;V1?97AI<W1S*"1F;&]W960L("=S971$96Q3
M<"<I*2!["B`@("`@("`@)&9L;W=E9"T^<V5T1&5L4W`H=')U92D["B`@("`@
M("`@)'1E>'1";V1Y+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G1&5L4W`G
M+"`G665S)RD["B`@("!]"B`@("`D=&5X=$)O9'DM/G-E=$-O;G1E;G1S*"1F
M;&]W960M/G1O1FQO=V5D*"DI.PH@("`@)'1E>'1";V1Y+3YS971#;VYT96YT
M5'EP95!A<F%M971E<B@G9F]R;6%T)RP@)V9L;W=E9"<I.PH*("`@("\J($1E
M=&5R;6EN92!W:&5T:&5R(&]R(&YO="!T;R!S96YD(&$@;75L=&EP87)T+V%L
M=&5R;F%T:79E"B`@("`@*B!M97-S86=E('=I=&@@86X@2%1-3"!P87)T+B`J
M+PH@("`@:68@*"%E;7!T>2@D;65S<V%G95]H=&UL*2D@>PH@("`@("`@("1H
M=&UL0F]D>2`]("9N97<@34E-15]087)T*"=T97AT+VAT;6PG+"!3=')I;F<Z
M.G=R87`H)&UE<W-A9V5?:'1M;"DL(&YU;&PL("=I;FQI;F4G*3L*("`@("`@
M("!I9B`H(6ES7VYU;&PH)'1R86EL97(I*2!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`@("`@
M)&AT;6Q";V1Y+3YA<'!E;F1#;VYT96YT<RA497AT7T9I;'1E<CHZ9FEL=&5R
M*"1T<F%I;&5R+"`G=&5X=#)H=&UL)RP@87)R87DH)W!A<G-E;&5V96PG(#T^
M(%1%6%1?2%1-3%]-24-23U],24Y+55),+"`G8VQA<W,G(#T^(&YU;&PL("=C
M86QL8F%C:R<@/3X@;G5L;"DI*3L*("`@("`@("!]"B`@("`@("`@)&)A<V5P
M87)T(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I<&%R="]A;'1E<FYA=&EV92<I
M.PH@("`@("`@("1T97AT0F]D>2T^<V5T1&5S8W)I<'1I;VXH7R@B4&QA:6YT
M97AT(%9E<G-I;VX@;V8@365S<V%G92(I*3L*("`@("`@("`D8F%S97!A<G0M
M/F%D9%!A<G0H)'1E>'1";V1Y*3L*("`@("`@("`D:'1M;$)O9'DM/G-E=$1E
M<V-R:7!T:6]N*%\H(DA434P@5F5R<VEO;B!O9B!-97-S86=E(BDI.PH@("`@
M("`@("1H=&UL0F]D>2T^<V5T0VAA<G-E="@D8VAA<G-E="D["@H@("`@("`@
M(&EF("@D9FEN86Q?;7-G*2!["B`@("`@("`@("`@("\J($%N>2!I;6%G92!L
M:6YK<R!W:6QL(&)E(&1O=VYL;V%D960@86YD(&%P<&5N9&5D('1O('1H90H@
M("`@("`@("`@("`@*B!M97-S86=E(&)O9'DN("HO"B`@("`@("`@("`@("1H
M=&UL0F]D>2`]("1I;7!?8V]M<&]S92T^8V]N=F5R=%1O375L=&EP87)T4F5L
M871E9"@D:'1M;$)O9'DI.PH@("`@("`@('T*("`@("`@("`D8F%S97!A<G0M
M/F%D9%!A<G0H)&AT;6Q";V1Y*3L*("`@('T@96QS92!["B`@("`@("`@)&)A
M<V5P87)T(#T@)'1E>'1";V1Y.PH@("`@?0H*("`@("\J($%D9"!A='1A8VAM
M96YT<R!N;W<N("HO"B`@("!I9B`H)&EM<%]C;VUP;W-E+3YN=6UB97)/9D%T
M=&%C:&UE;G1S*"DI('L*("`@("`@("!I9B`H*%5T:6PZ.F=E=$9O<FU$871A
M*"=L:6YK7V%T=&%C:&UE;G1S)RD@)B8@)$=,3T)!3%-;)V-O;F8G75LG8V]M
M<&]S92==6R=L:6YK7V%T=&%C:&UE;G1S)UTI('Q\"B`@("`@("`@("`@("%E
M;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=C;VUP;W-E)UU;)VQI;FM?86QL7V%T
M=&%C:&UE;G1S)UTI*2!["B`@("`@("`@("`@("1B;V1Y(#T@)&EM<%]C;VUP
M;W-E+3YL:6YK071T86-H;65N=',H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A
M='1A8VAM96YT+G!H<"<L('1R=64I+"`D8F%S97!A<G0L($%U=&@Z.F=E=$%U
M=&@H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)O9'D@/2`F
M;F5W($U)345?4&%R="@G;75L=&EP87)T+VUI>&5D)RD["B`@("`@("`@("`@
M("1B;V1Y+3YA9&1087)T*"1B87-E<&%R="D["B`@("`@("`@("`@("1I;7!?
M8V]M<&]S92T^8G5I;&1!;&Q!='1A8VAM96YT<R@D8F]D>2P@)&-H87)S970I
M.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@)&)O9'D@/2`D8F%S
M97!A<G0["B`@("!]"@H@("`@<F5T=7)N("1B;V1Y.PI]"@HO*BH*("H@0W)E
M871E('1H92!B87-E($U)345?365S<V%G92!F;W(@<V5N9&EN9RX*("HO"F9U
M;F-T:6]N(%]C<F5A=&5-:6UE365S<V%G92@D=&\L("1B;V1Y*0I["B`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344O365S<V%G92YP:'`G.PH@("`@)&UI
M;65?;65S<V%G92`]("9N97<@34E-15]-97-S86=E*"1'3$]"04Q36R=I;7`G
M75LG;6%I;&1O;6%I;B==*3L*"B`@("`O*B!3970@=7`@=&AE(&)A<V4@;65S
M<V%G92!N;W<N("HO"B`@("!I9B`H)$=,3T)!3%-;)W5S95!'4"==("8F"B`@
M("`@("`@:6Y?87)R87DH)$=,3T)!3%-;)V5N8W)Y<'0G72P@87)R87DH24U0
M7U!'4%]%3D-265!4+"!)35!?4$=07U-)1TXL($E-4%]01U!?4TE'3D5.0RDI
M*2!["B`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=I;7!?<&=P)UTI*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312`N)R]L:6(O0W)Y
M<'0O4$=0+G!H<"<["B`@("`@("`@("`@("1'3$]"04Q36R=I;7!?<&=P)UT@
M/2`F;F5W($E-4%]01U`H*3L*("`@("`@("!]"B`@("`@("`@)&EM<%]P9W`@
M/2`F)$=,3T)!3%-;)VEM<%]P9W`G73L*"B`@("`@("`@+RH@1V5T('1H92!U
M<V5R)W,@<&%S<W!H<F%S92P@:68@=V4@;F5E9"!I="X@*B\*("`@("`@("`D
M<&%S<W!H<F%S92`]("<G.PH@("`@("`@(&EF("AI;E]A<G)A>2@D1TQ/0D%,
M4ULG96YC<GEP="==+"!A<G)A>2A)35!?4$=07U-)1TXL($E-4%]01U!?4TE'
M3D5.0RDI*2!["B`@("`@("`@("`@("\J($-H96-K('1O('-E92!I9B!W92!H
M879E('1H92!U<V5R)W,@<&%S<W!H<F%S92!Y970N("HO"B`@("`@("`@("`@
M("1P87-S<&AR87-E(#T@)&EM<%]P9W`M/F=E=%!A<W-P:')A<V4H*3L*("`@
M("`@("`@("`@:68@*&5M<'1Y*"1P87-S<&AR87-E*2D@>PH@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)W!G<%]P87-S<&AR87-E7V1I86QO9R==(#T@=')U
M93L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E!'4"!%<G)O<CH@3F5E9"!P87-S<&AR87-E(&9O<B!P97)S;VYA;"!P<FEV
M871E(&ME>2XB*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($1O('1H92!E;F-R>7!T:6]N+W-I9VYI;F<@<F5Q=65S=&5D+B`J+PH@
M("`@("`@('-W:71C:"`H)$=,3T)!3%-;)V5N8W)Y<'0G72D@>PH@("`@("`@
M(&-A<V4@24U07U!'4%]324=..@H@("`@("`@("`@("`D8F]D>2`]("1I;7!?
M<&=P+3Y)35!S:6=N34E-15!A<G0H)&)O9'DI.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92!)35!?4$=07T5.0U)94%0Z"B`@("`@("`@("`@
M("1B;V1Y(#T@)&EM<%]P9W`M/DE-4&5N8W)Y<'1-24U%4&%R="@D8F]D>2P@
M)'1O*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24U07U!'
M4%]324=.14Y#.@H@("`@("`@("`@("`D8F]D>2`]("1I;7!?<&=P+3Y)35!S
M:6=N06YD16YC<GEP=$U)345087)T*"1B;V1Y+"`D=&\I.PH@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O<B!E<G)O
M<G,N("HO"B`@("`@("`@:68@*&ES7V$H)&)O9'DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4$=0
M($5R<F]R.B`B*2`N("1B;V1Y+3YG971-97-S86=E*"DI.PH@("`@("`@('T*
M("`@('T@96QS96EF("@D1TQ/0D%,4ULG=7-E4TU)344G72`F)@H@("`@("`@
M("`@("`@(&EN7V%R<F%Y*"1'3$]"04Q36R=E;F-R>7!T)UTL(&%R<F%Y*$E-
M4%]334E-15]%3D-265!4+"!)35!?4TU)345?4TE'3BP@24U07U--24U%7U-)
M1TY%3D,I*2D@>PH@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG:6UP7W-M
M:6UE)UTI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!)35!?0D%312X@
M)R]L:6(O0W)Y<'0O4TU)344N<&AP)SL*("`@("`@("`@("`@)$=,3T)!3%-;
M)VEM<%]S;6EM92==(#T@)FYE=R!)35!?4TU)344H*3L*("`@("`@("!]"B`@
M("`@("`@)&EM<%]S;6EM92`]("8D1TQ/0D%,4ULG:6UP7W-M:6UE)UT["@H@
M("`@("`@("\J($-H96-K('1O('-E92!I9B!W92!H879E('1H92!U<V5R)W,@
M<&%S<W!H<F%S92!Y970N("HO"B`@("`@("`@:68@*&EN7V%R<F%Y*"1'3$]"
M04Q36R=E;F-R>7!T)UTL(&%R<F%Y*$E-4%]334E-15]324=.+"!)35!?4TU)
M345?4TE'3D5.0RDI*2!["B`@("`@("`@("`@("1P87-S<&AR87-E(#T@)&EM
M<%]S;6EM92T^9V5T4&%S<W!H<F%S92@I.PH@("`@("`@("`@("!I9B`H)'!A
M<W-P:')A<V4@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D1TQ/0D%,
M4ULG<VUI;65?<&%S<W!H<F%S95]D:6%L;V<G72`]('1R=64["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3+TU)344@17)R
M;W(Z($YE960@<&%S<W!H<F%S92!F;W(@<&5R<V]N86P@<')I=F%T92!K97DN
M(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!$;R!T
M:&4@96YC<GEP=&EO;B]S:6=N:6YG(')E<75E<W1E9"X@*B\*("`@("`@("!S
M=VET8V@@*"1'3$]"04Q36R=E;F-R>7!T)UTI('L*("`@("`@("!C87-E($E-
M4%]334E-15]324=..@H@("`@("`@("`@("`D8F]D>2`]("1I;7!?<VUI;64M
M/DE-4'-I9VY-24U%4&%R="@D8F]D>2D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E($E-4%]334E-15]%3D-265!4.@H@("`@("`@("`@("`D
M8F]D>2`]("1I;7!?<VUI;64M/DE-4&5N8W)Y<'1-24U%4&%R="@D8F]D>2P@
M)'1O6S!=*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24U0
M7U--24U%7U-)1TY%3D,Z"B`@("`@("`@("`@("1B;V1Y(#T@)&EM<%]S;6EM
M92T^24U0<VEG;D%N9$5N8W)Y<'1-24U%4&%R="@D8F]D>2P@)'1O6S!=*3L*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C
M:R!F;W(@97)R;W)S+B`J+PH@("`@("`@(&EF("AI<U]A*"1B;V1Y+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E,O34E-12!%<G)O<CH@(BD@+B`D8F]D>2T^9V5T365S<V%G92@I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RH@061D(&1A=&$@=&\@34E-15]-
M97-S86=E(&]B:F5C="X@*B\*("`@("1M:6UE7VUE<W-A9V4M/F%D9%!A<G0H
M)&)O9'DI.PH*("`@("\J($%P<&5N9"!01U`@<VEG;F%T=7)E(&EF('-E="!I
M;B!T:&4@<')E9F5R96YC97,N("HO"B`@("!I9B`H)$=,3T)!3%-;)W5S95!'
M4"==("8F(%5T:6PZ.F=E=$9O<FU$871A*"=P9W!?871T86-H7W!U8FME>2<I
M*2!["B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG:6UP7W!G<"==*2D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]#
M<GEP="]01U`N<&AP)SL*("`@("`@("`@("`@)$=,3T)!3%-;)VEM<%]P9W`G
M72`]("9N97<@24U07U!'4"@I.PH@("`@("`@('T*("`@("`@("`D;6EM95]M
M97-S86=E+3YA9&1087)T*"1'3$]"04Q36R=I;7!?<&=P)UTM/G!U8FQI8TME
M>4U)345087)T*"DI.PH@("`@?0H*("`@(')E='5R;B!A<G)A>2@G=&\G(#T^
M(&EM<&QO9&4H)RP@)RP@)'1O*2P@)VUS9R<@/3X@)B1M:6UE7VUE<W-A9V4I
M.PI]"@IF=6YC=&EO;B!?8VQE86Y!9&1R3&ES="@D861D<G,I"GL*("`@("1A
M9&1R;&ES="`](&%R<F%Y*"D["@H@("`@9F]R96%C:"`H)&%D9')S(&%S("1V
M86PI('L*("`@("`@("`D861D<E]A<G)A>2`]($U)344Z.G)F8S@R,D5X<&QO
M9&4H)'9A;"P@)RPG*3L*("`@("`@("`D861D<E]A<G)A>2`](&%R<F%Y7VUA
M<"@G=')I;2<L("1A9&1R7V%R<F%Y*3L*("`@("`@("!F;W)E86-H("@D861D
M<E]A<G)A>2!A<R`D96UA:6PI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M96UA:6PI*2!["B`@("`@("`@("`@("`@("`D=6YI<75E(#T@24U0.CIB87)E
M061D<F5S<R@D96UA:6PI.PH@("`@("`@("`@("`@("`@:68@*"1U;FEQ=64@
M)B8@)'5N:7%U92`A/2`G54Y%6%!%0U1%1%]$051!7T%&5$527T%$1%)%4U-`
M+E-93E1!6"U%4E)/4BXG*2!["B`@("`@("`@("`@("`@("`@("`@)&%D9')L
M:7-T6R1U;FEQ=65=(#T@)&5M86EL.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D861D<FQI<W1;)&5M86EL72`]("1E
M;6%I;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("!R971U<FX@87)R87E?=F%L=65S*"1A9&1R;&ES="D[
M"GT*"F9U;F-T:6]N(%]P;W!U<%-U8V-E<W,H*0I["B`@("!G;&]B86P@)')E
M9VES=')Y.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["B`@
M("`D;65N=2`]("9N97<@365N=2A(3U)$15]-14Y57TU!4TM?3D].12D["B`@
M("`D;65N=2T^861D*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G8V]M<&]S92YP
M:'`G*2P@7R@B0V]M<&]S92!A;F]T:&5R(&UE<W-A9V4B*2P@)V-O;7!O<V4N
M<&YG)RD["B`@("`D;65N=2T^861D*"<G+"!?*")#;&]S92!T:&ES('=I;F1O
M=R(I+"`G8VQO<V4N<&YG)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2P@)R<L("=W:6YD;W<N8VQO<V4H*3LG*3L*("`@(')E<75I<F4@24U0
M7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PH@("`@<F5Q=6ER
M92!)35!?5$5-4$Q!5$53("X@)R]C;VUP;W-E+W-U8V-E<W,N:6YC)SL*("`@
M($E-4#HZ<W1A='5S*"D["B`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T
M96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PI]
M"@IF=6YC=&EO;B!?;6EM945N8V]D9613=6)J96-T*"1S=6)J96-T+"`D96YC
M;V1E7V9R;VTL("1E;F-O9&5?=&\];G5L;"D*>PH):68@*"!I<U]N=6QL*"1E
M;F-O9&5?=&\I("D@>PH)"7)E='5R;B`D<W5B:F5C=#L*"7T*"21E;F-O9&5?
M9G)O;2`]('-T<G1O;&]W97(H)&5N8V]D95]F<F]M*3L*"21E;F-O9&5?=&\@
M/2!S=')T;VQO=V5R*"1E;F-O9&5?=&\I.PH):68@*"`D96YC;V1E7V9R;VT@
M/3T@)&5N8V]D95]T;R`I('L*"0ER971U<FX@)'-U8FIE8W0["@E]"@EI9B`H
M("1E;F-O9&5?=&\@/3T@)VES;RTX.#4Y+3$G(&]R("1E;F-O9&5?=&\@/3T@
M)W5T9BTX)R!O<B`D96YC;V1E7W1O(#T]("=U=&8X)RD@>PH)"7)E='5R;B`D
M<W5B:F5C=#L*"7T*"21O9F9S970@/2`S-CL*"21M:6UE9"`](&%R<F%Y*"D[
M"@EF;W(@*"`D:2`](#`[("1I(#P@<W1R;&5N*"1S=6)J96-T*3L@)&D@*ST@
M)&]F9G-E="`I('L*"0DD<W1R(#T@;6)?<W1R8W5T*"1S=6)J96-T+"`D:2P@
M)&]F9G-E="P@)&5N8V]D95]F<F]M*3L*"0DD<W1R(#T@;6)?8V]N=F5R=%]E
M;F-O9&EN9R@D<W1R+"`D96YC;V1E7W1O+"`D96YC;V1E7V9R;VTI.PH)"21M
M:6UE9%M=(#T@;6)?96YC;V1E7VUI;65H96%D97(H)'-T<BP@)&5N8V]D95]T
M;RD["@E]"@ER971U<FX@:6UP;&]D92@B7&XB+"`D;6EM960I.PI]"@I`9&5F
M:6YE*"=)35!?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*)'-E<W-I;VY?
M8V]N=')O;"`]("=N971S8V%P92<["G)E<75I<F5?;VYC92!)35!?0D%312`N
M("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L
M:6(O0V]M<&]S92YP:'`G.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI
M8B]&;VQD97(N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TU)344N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*"B\J(%1H92!L:7-T(&]F('-T
M871E(&EN9F]R;6%T:6]N(&9R;VT@8V]M<&]S92YP:'`@=&AA="!N965D<R!T
M;R!P97)S:7-T(&%C<F]S<PH@*B!A8W)O<W,@<&%G92!L;V%D<RX@*B\*)'-?
M=F%R(#T@87)R87DH)W1O)RP@)V-C)RP@)V)C8R<L("=T;U]L:7-T)RP@)V-C
M7VQI<W0G+"`G8F-C7VQI<W0G+`H@("`@("`@("`@("`@("`G=&]?9FEE;&0G
M+"`G8V-?9FEE;&0G+"`G8F-C7V9I96QD)RP@)W1O7VYE=R<L("=C8U]N97<G
M+`H@("`@("`@("`@("`@("`G8F-C7VYE=R<L("=L:6YK7V%T=&%C:&UE;G1S
M)RP@)W)T96UO9&4G+"`G<&=P7V%T=&%C:%]P=6)K97DG+`H@("`@("`@("`@
M("`@("`G:6Y?<F5P;'E?=&\G+"`G<F5F97)E;F-E<R<L("=I9&5N=&ET>2<L
M("=C:&%R<V5T)RP*("`@("`@("`@("`@("`@)VUE<W-A9V5#86-H92<L("=P
M;W!U<"<L("=O;&1R=&5M;V1E)RP@)VUA:6QT;R<L("=F<F]M)RP*("`@("`@
M("`@("`@("`@)V5N8W)Y<'1?;W!T:6]N<R<L("=X7W!R:6]R:71Y)RP@)W)E
M<75E<W1?<F5A9%]R96-E:7!T)RP*("`@("`@("`@("`@("`@)W-U8FIE8W0G
M+"`G<F5P;'E?:6YD97@G+"`G<F5P;'E?='EP92<L("=S879E7W-E;G1?;6%I
M;"<L"B`@("`@("`@("`@("`@("=S879E7V%T=&%C:&UE;G1S7W-E;&5C="<L
M("=R96QO861E9"<L("=S96YT7VUA:6Q?9F]L9&5R)RD["@HO*B!4:&4@;65S
M<V%G92!T97AT+B`J+PHD;7-G(#T@)R<["@HO*B!4:&4@:&5A9&5R<R!O9B!T
M:&4@;65S<V%G92X@*B\*)&AE861E<B`](&%R<F%Y*"D["B1H96%D97);)W1O
M)UT@/2`G)SL*)&AE861E<ELG8V,G72`]("<G.PHD:&5A9&5R6R=B8V,G72`]
M("<G.PHD:&5A9&5R6R=S=6)J96-T)UT@/2`G)SL*)&AE861E<ELG:6YR97!L
M>71O)UT@/2!5=&EL.CIG971&;W)M1&%T82@G:6Y?<F5P;'E?=&\G*3L*)&AE
M861E<ELG<F5F97)E;F-E<R==(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E9F5R
M96YC97,G*3L*"B1G971?<VEG(#T@=')U93L*)'!G<%]P87-S<&AR87-E7V1I
M86QO9R`](&9A;'-E.PHD<VUI;65?<&%S<W!H<F%S95]D:6%L;V<@/2!F86QS
M93L*"B\J(%-O;64@9VQO8F%L('9A;'5E<RX@*B\*)&EM<%]P9W`@/2`D:6UP
M7W-M:6UE(#T@)'5S95!'4"`]("1U<V5334E-12`](&YU;&P["@HD:61E;G1I
M='D@/2`F261E;G1I='DZ.G-I;F=L971O;BAA<G)A>2@G:6UP)RP@)VEM<"<I
M*3L*)'-E;G1?;6%I;%]F;VQD97(@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=S
M96YT7VUA:6Q?9F]L9&5R)RP@571I;#HZ9V5T1F]R;41A=&$H)VED96YT:71Y
M)RDI.PHD86-T:6]N240@/2!?9V5T06-T:6]N240H*3L*)')E<&QY7VEN9&5X
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E<&QY7VEN9&5X)RD["B1T:&ES;6%I
M;&)O>"`](%5T:6PZ.F=E=$9O<FU$871A*"=T:&ES;6%I;&)O>"<L("1I;7!;
M)VUA:6QB;W@G72D["@HO*B!#:&5C:R!F;W(@9'5P;&EC871E('-U8FUI=',N
M("HO"G)E<75I<F5?;VYC92`G2&]R9&4O5&]K96XN<&AP)SL*:68@*&ES<V5T
M*"1C;VYF6R=T;VME;B==*2D@>PH@("`@+RH@268@=&AE<F4@:7,@82!C;VYF
M:6=U<F5D('1O:V5N('-Y<W1E;2P@<V5T(&ET('5P+B`J+PH@("`@)'1O:V5N
M4V]U<F-E(#T@)DAO<F1E7U1O:V5N.CIS:6YG;&5T;VXH)&-O;F9;)W1O:V5N
M)UU;)V1R:79E<B==+"!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=T;VME;B<L
M("1C;VYF6R=T;VME;B==6R=D<FEV97(G72DI.PI](&5L<V4@>PH@("`@+RH@
M1&5F875L="!T;R!T:&4@9FEL92!S>7-T96T@:68@;F\@8V]N9FEG+B`J+PH@
M("`@)'1O:V5N4V]U<F-E(#T@)DAO<F1E7U1O:V5N.CIS:6YG;&5T;VXH)V9I
M;&4G*3L*?0II9B`H*"1T;VME;B`](%5T:6PZ.F=E=$9O<FU$871A*"=?7V9O
M<FU4;VME;E]C;VUP;W-E)RDI("8F"B`@("`A)'1O:V5N4V]U<F-E+3YV97)I
M9GDH)'1O:V5N*2D@>PH@("`@+RH@3F]T:69Y(&%N9"!R97-E="!T:&4@86-T
M:6]N240N("HO"B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=2!H879E
M(&%L<F5A9'D@<W5B;6ET=&5D('1H:7,@<&%G92XB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("`D86-T:6]N240@/2`G)SL*?0H*:68@*"@D:6YD97@@/2!5=&EL
M.CIG971&;W)M1&%T82@G:6YD97@G*2DI('L*("`@(')E<75I<F5?;VYC92!)
M35!?0D%312`N("<O;&EB+TU)344O0V]N=&5N=',N<&AP)SL*("`@(')E<75I
M<F5?;VYC92!)35!?0D%312`N("<O;&EB+TU)344O2&5A9&5R<RYP:'`G.PH@
M("`@)&EM<%]C;VYT96YT<R`]("9)35!?0V]N=&5N=',Z.G-I;F=L971O;B@D
M:6YD97@@+B!)35!?24187U-%4"`N("1?4T534TE/3ELG:6UP)UU;)W1H:7-M
M86EL8F]X)UTI.PH@("`@)&EM<%]H96%D97)S(#T@)FYE=R!)35!?2&5A9&5R
M<R@D:6YD97@I.PI]"B1I;7!?9F]L9&5R(#T@)DE-4%]&;VQD97(Z.G-I;F=L
M971O;B@I.PH*+RH@4V5T('1H92!C=7)R96YT('1I;64@>F]N92X@*B\*3DQ3
M.CIS9714:6UE6F]N92@I.PH*+RH@4V5T('1H92!D969A=6QT(&-H87)S970@
M)B!E;F-O9&EN9RX*("H@)&-H87)S970@:&]L9',@=&AE(&-H87)S970@=&\@
M=7-E('=H96X@<V5N9&EN9R!M97-S86=E<RP@)&5N8V]D:6YG('1H92!B97-T
M"B`J(&=U97-S960@8VAA<G-E="!O9F9E<F5D('1O('1H92!U<V5R(&%S('1H
M92!D969A=6QT('9A;'5E(&EN('1H92!C:&%R<V5T"B`J(&1R;W!D;W=N(&QI
M<W0N("HO"FEF("@D<')E9G,M/FES3&]C:V5D*"=S96YD:6YG7V-H87)S970G
M*2D@>PH@("`@)&-H87)S970@/2!.3%,Z.F=E=$5M86EL0VAA<G-E="@I.PI]
M(&5L<V4@>PH@("`@)&-H87)S970@/2!5=&EL.CIG971&;W)M1&%T82@G8VAA
M<G-E="<I.PI]"B1E;F-O9&EN9R`](%]G971%;F-O9&EN9R@I.PH*+RH@26YI
M=&EA;&EZ92!T:&4@24U07T-O;7!O<V4Z.B!O8FIE8W0N("HO"B1O;&1-97-S
M86=E0V%C:&5)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=M97-S86=E0V%C:&4G
M*3L*)&EM<%]C;VUP;W-E(#T@)FYE=R!)35!?0V]M<&]S92AA<G)A>2@G8V%C
M:&5)1"<@/3X@)&]L9$UE<W-A9V5#86-H94E$*2D["@HO*B!)<R!T:&ES(&$@
M<&]P=7`@=VEN9&]W/R`J+PHD:7-0;W!U<"`]("@H)'!R969S+3YG971686QU
M92@G8V]M<&]S95]P;W!U<"<I('Q\(%5T:6PZ.F=E=$9O<FU$871A*"=P;W!U
M<"<I*2`F)B`D8G)O=W-E<BT^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*3L*
M"B\J($1E=&5R;6EN92!T:&4@8V]M<&]S:71I;VX@='EP92`M('1E>'0@;W(@
M2%1-3"X@*B\*)')T96UO9&4@/2!F86QS93L*:68@*"1B<F]W<V5R+3YH87-&
M96%T=7)E*"=R=&4G*2D@>PH@("`@:68@*"1P<F5F<RT^:7-,;V-K960H)V-O
M;7!O<V5?:'1M;"<I*2!["B`@("`@("`@)')T96UO9&4@/2`D<')E9G,M/F=E
M=%9A;'5E*"=C;VUP;W-E7VAT;6PG*3L*("`@('T@96QS92!["B`@("`@("`@
M)')T96UO9&4@/2!5=&EL.CIG971&;W)M1&%T82@G<G1E;6]D92<I.PH@("`@
M("`@(&EF("AI<U]N=6QL*"1R=&5M;V1E*2D@>PH@("`@("`@("`@("`D<G1E
M;6]D92`]("1P<F5F<RT^9V5T5F%L=64H)V-O;7!O<V5?:'1M;"<I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1O;&1R=&5M;V1E(#T@571I;#HZ
M9V5T1F]R;41A=&$H)V]L9')T96UO9&4G*3L*("`@("`@("`@("`@)&=E=%]S
M:6<@/2!F86QS93L*("`@("`@("!]"B`@("!]"GT*"B\J($QO860@<W1A=&EO
M;F5R>2X@*B\*:68@*"$D<')E9G,M/FES3&]C:V5D*"=S=&%T:6]N97)Y)RDI
M('L*("`@("1S=&%T:6]N97)Y(#T@;G5L;#L*("`@("1A;&Q?<W1A=&EO;F5R
M>2`]($!U;G-E<FEA;&EZ92@D<')E9G,M/F=E=%9A;'5E*"=S=&%T:6]N97)Y
M)RP@9F%L<V4I*3L*("`@(&EF("AI<U]A<G)A>2@D86QL7W-T871I;VYE<GDI
M*2!["B`@("`@("`@)&%L;%]S=&%T:6]N97)Y(#T@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D86QL7W-T871I;VYE<GDL("1P<F5F<RT^9V5T0VAA<G-E="@I
M*3L*("`@("`@("`D<W1A=&EO;F5R>5]L:7-T(#T@87)R87DH*3L*("`@("`@
M("!F;W)E86-H("@D86QL7W-T871I;VYE<GD@87,@)'-T871I;VYE<GE?:60@
M/3X@)'-T871I;VYE<GE?8VAO:6-E*2!["B`@("`@("`@("`@(&EF("@D<W1A
M=&EO;F5R>5]C:&]I8V5;)W0G72`]/2`G<&QA:6XG('Q\"B`@("`@("`@("`@
M("`@("`H)'-T871I;VYE<GE?8VAO:6-E6R=T)UT@/3T@)VAT;6PG("8F("1R
M=&5M;V1E*2D@>PH@("`@("`@("`@("`@("`@)'-T871I;VYE<GE?;&ES=%LD
M<W1A=&EO;F5R>5]I9%T@/2`D<W1A=&EO;F5R>5]C:&]I8V4["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("1S=&%T:6]N
M97)Y7VQI<W0@/2!N=6QL.PH@("`@?0I]"@HO*B!5<&1A=&4@=&AE(&9I;&4@
M871T86-H;65N="!I;F9O<FUA=&EO;BX@*B\*:68@*"1I;7!;)V9I;&5?=7!L
M;V%D)UTI('L*("`@("\J($]N;'D@;F]T:69Y(&EF('=E(&%R92!R96QO861I
M;F<@=&AE(&-O;7!O<V4@<V-R965N+B`J+PH@("`@)&YO=&EF>2`]("@D86-T
M:6]N240@(3T@)W-E;F1?;65S<V%G92<I("8F("@D86-T:6]N240@(3T@)W-A
M=F5?9')A9G0G*3L*"B`@("`D9&5L971E3&ES="`](%5T:6PZ.F=E=%!O<W0H
M)V1E;&%T=&%C:&UE;G1S)RP@87)R87DH*2D["@H@("`@+RH@57!D871E('1H
M92!A='1A8VAM96YT(&EN9F]R;6%T:6]N+B`J+PH@("`@9F]R("@D:2`](#$[
M("1I(#P]("1I;7!?8V]M<&]S92T^;G5M8F5R3V9!='1A8VAM96YT<R@I.R`D
M:2LK*2!["B`@("`@("`@:68@*"%I;E]A<G)A>2@D:2P@)&1E;&5T94QI<W0I
M*2!["B`@("`@("`@("`@("1D:7-P;W-I=&EO;B`](%5T:6PZ.F=E=$9O<FU$
M871A*"=F:6QE7V1I<W!O<VET:6]N7R<@+B`D:2D["B`@("`@("`@("`@("1D
M97-C<FEP=&EO;B`](%5T:6PZ.F=E=$9O<FU$871A*"=F:6QE7V1E<V-R:7!T
M:6]N7R<@+B`D:2D["B`@("`@("`@("`@("1I;7!?8V]M<&]S92T^=7!D871E
M071T86-H;65N="@D:2P@87)R87DH)V1I<W!O<VET:6]N)R`]/B`D9&ES<&]S
M:71I;VXL("=D97-C<FEP=&EO;B<@/3X@)&1E<V-R:7!T:6]N*2D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J($1E;&5T92!A='1A8VAM96YT<RX@*B\*("`@
M(&EF("@A96UP='DH)&1E;&5T94QI<W0I*2!["B`@("`@("`@)&9I;&5N86UE
M<R`]("1I;7!?8V]M<&]S92T^9&5L971E071T86-H;65N="@D9&5L971E3&ES
M="D["B`@("`@("`@:68@*"1N;W1I9GDI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)&9I;&5N86UE<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B1&5L971E9"!T:&4@871T86-H
M;65N="!<(B5S7"(N(BDL("1V86PI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J($%D9"!N97<@871T
M86-H;65N=',N("HO"B`@("!F;W(@*"1I(#T@,3L@)&D@/#T@8V]U;G0H)%]&
M24Q%4RD[("1I*RLI('L*("`@("`@("`D:V5Y(#T@)W5P;&]A9%\G("X@)&D[
M"B`@("`@("`@:68@*&ES<V5T*"1?1DE,15-;)&ME>5TI("8F"B`@("`@("`@
M("`@("@D7T9)3$536R1K97E=6R=E<G)O<B==("$](#0I*2!["B`@("`@("`@
M("`@(&EF("@D7T9)3$536R1K97E=6R=S:7IE)UT@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@)&%C=&EO;DE$(#T@;G5L;#L*("`@("`@("`@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")$:60@;F]T(&%T=&%C:"!<
M(B5S7"(@87,@=&AE(&9I;&4@=V%S(&5M<'1Y+B(I+"`D7T9)3$536R1K97E=
M6R=N86UE)UTI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1I;7!?8V]M<&]S92T^
M861D57!L;V%D071T86-H;65N="@D:V5Y+"!5=&EL.CIG971&;W)M1&%T82@G
M=7!L;V%D7V1I<W!O<VET:6]N7R<@+B`D:2DI.PH@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("\J($1O;B=T('-E;F0@;65S<V%G92!I;6UE9&EA=&5L>2!I
M9B!W92!H:70@86X@97)R;W(N("HO"B`@("`@("`@("`@("`@("`@("`@)&%C
M=&EO;DE$(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*"1R97-U;'0L("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1N;W1I9GDI('L*("`@("`@("`@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B061D960@7"(E<UPB
M(&%S(&%N(&%T=&%C:&UE;G0N(BDL("1R97-U;'0I+"`G:&]R9&4N<W5C8V5S
M<R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0I]"@HO*B!2=6X@=&AR;W5G:"!T:&4@86-T:6]N(&AA;F1L97)S
M+B`J+PHD=&ET;&4@/2!?*")-97-S86=E($-O;7!O<VET:6]N(BD["G-W:71C
M:"`H)&%C=&EO;DE$*2!["F-A<V4@)W)E8V]M<&]S92<Z"B`@("`O+R!%>'1R
M86-T('1H92!S=&]R960@9F]R;2!D871A+@H@("`@)&9O<FU$871A(#T@0'5N
M<V5R:6%L:7IE*"1?4T534TE/3ELG9F]R;41A=&$G72D["B`@("!U;G-E="@D
M7U-%4U-)3TY;)V9O<FU$871A)UTI.PH*("`@(&EF("@A96UP='DH)&9O<FU$
M871A6R=P;W-T)UTI*2!["B`@("`@("`@)%]03U-4(#T@)&9O<FU$871A6R=P
M;W-T)UT["B`@("!]"B`@("!I9B`H(65M<'1Y*"1F;W)M1&%T85LG9V5T)UTI
M*2!["B`@("`@("`@)%]'150@/2`D9F]R;41A=&%;)V=E="==.PH@("`@?0H*
M("`@("1G971?<VEG(#T@9F%L<V4["B`@("!B<F5A:SL*"F-A<V4@)VUA:6QT
M;R<Z"B`@("!I9B`H(65M<'1Y*"1I;F1E>"DI('L*("`@("`@("`D:&5A9&5R
M6R=T;R==(#T@)R<["B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=M
M86EL=&\G*2D@>PH@("`@("`@("`@("`D:&5A9&5R6R=T;R==(#T@)&EM<%]H
M96%D97)S+3YG971/8B@G=&]A9&1R97-S)RP@=')U92D["B`@("`@("`@?0H@
M("`@("`@(&EF("AE;7!T>2@D:&5A9&5R6R=T;R==*2D@>PH@("`@("`@("`@
M("`H)&AE861E<ELG=&\G72`]($U)344Z.F%D9')!<G)A>3)3=')I;F<H)&EM
M<%]H96%D97)S+3YG971/8B@G9G)O;2<I*2D@?'P*("`@("`@("`@("`@*"1H
M96%D97);)W1O)UT@/2!-24U%.CIA9&1R07)R87DR4W1R:6YG*"1I;7!?:&5A
M9&5R<RT^9V5T3V(H)W)E<&QY7W1O)RDI*3L*("`@("`@("!]"B`@("`@("`@
M)'1I=&QE(#T@7R@B365S<V%G92!#;VUP;W-I=&EO;B(I.PH@("`@?0H@("`@
M8G)E86L["@IC87-E("=D<F%F="<Z"B`@("!I9B`H(65M<'1Y*"1I;F1E>"DI
M('L*("`@("`@("`D;6EM95]M97-S86=E(#T@)&EM<%]C;VYT96YT<RT^<F5B
M=6EL9$UE<W-A9V4H*3L*("`@("`@("`D:6UP7V-O;7!O<V4M/F9O<G=A<F1-
M97-S86=E*"1I;7!?8V]N=&5N=',L("1I;7!?:&5A9&5R<RD["B`@("`@("`@
M)')E<R`]("1I;7!?8V]M<&]S92T^871T86-H1FEL97-&<F]M365S<V%G92@D
M:6UP7V-O;G1E;G1S*3L*("`@("`@("!I9B`H(65M<'1Y*"1R97,I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1R97,@87,@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D=F%L+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&)O9'E?=&5X
M="`](&YU;&P["B`@("`@("`@:68@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=R
M=&4G*2`F)@H@("`@("`@("`@("`H)&UI;65?;65S<V%G92T^9V5T5'EP92@I
M(#T]("=M=6QT:7!A<G0O86QT97)N871I=F4G*2D@>PH@("`@("`@("`@("`D
M='EP95]M87`@/2`D;6EM95]M97-S86=E+3YC;VYT96YT5'EP94UA<"@I.PH@
M("`@("`@("`@("`D:'1M;%]K97D@/2!A<G)A>5]S96%R8V@H)W1E>'0O:'1M
M;"<L("1T>7!E7VUA<"D["B`@("`@("`@("`@(&EF("@D:'1M;%]K97D@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D8F]D>5]P87)T(#T@)B1I;7!?
M8V]N=&5N=',M/F=E=$1E8V]D961-24U%4&%R="@D:'1M;%]K97DI.PH@("`@
M("`@("`@("`@("`@)&)O9'E?=&5X="`]("1B;V1Y7W!A<G0M/F=E=$-O;G1E
M;G1S*"D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:6UP7V-O;7!O<V4M
M/F=E=$%T=&%C:&UE;G1S*"D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1V86PM/F=E=$U)345)9"@I(#T]("1H=&UL7VME
M>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:6UP7V-O;7!O<V4M/F1E
M;&5T94%T=&%C:&UE;G0H*RLD:V5Y*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)')T96UO9&4@/2!T<G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D8F]D>5]T
M97AT*2D@>PH@("`@("`@("`@("`D8F]D>5]I9"`]("1I;7!?8V]M<&]S92T^
M9V5T0F]D>4ED*"1I;7!?8V]N=&5N=',I.PH@("`@("`@("`@("`D8F]D>5]P
M87)T(#T@)&UI;65?;65S<V%G92T^9V5T4&%R="@D8F]D>5]I9"D["B`@("`@
M("`@("`@("1B;V1Y7W1E>'0@/2`D:6UP7V-O;7!O<V4M/F9I;F1";V1Y*"1I
M;7!?8V]N=&5N=',I.PH@("`@("`@('T*("`@("`@("`D;7-G(#T@(EQN(B`N
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&)O9'E?=&5X="P@)&)O9'E?<&%R
M="T^9V5T0VAA<G-E="@I*3L*"B`@("`@("`@:68@*"1R=&5M;V1E("8F("@D
M8F]D>5]P87)T+3YG9714>7!E*"D@(3T@)W1E>'0O:'1M;"<I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*
M("`@("`@("`@("`@)&US9R`](%1E>'1?1FEL=&5R.CIF:6QT97(H)&US9RP@
M)W1E>'0R:'1M;"<L(&%R<F%Y*"=P87)S96QE=F5L)R`]/B!415A47TA434Q?
M34E#4D]?3$E.2U523"P@)V-L87-S)R`]/B!N=6QL+"`G8V%L;&)A8VLG(#T^
M(&YU;&PI*3L*("`@("`@("!]"@H@("`@("`@(&EF("@H)&9R;VUA9&1R(#T@
M)&EM<%]H96%D97)S+3YG971/8B@G9G)O;6%D9')E<W,G*2DI('L*("`@("`@
M("`@("`@)%]'151;)VED96YT:71Y)UT@/2`D:61E;G1I='DM/F=E=$UA=&-H
M:6YG261E;G1I='DH)&9R;VUA9&1R*3L*("`@("`@("`@("`@)'-E;G1?;6%I
M;%]F;VQD97(@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=S96YT7VUA:6Q?9F]L
M9&5R)RP@571I;#HZ9V5T1F]R;41A=&$H)VED96YT:71Y)RDI.PH@("`@("`@
M('T*("`@("`@("`D:&5A9&5R6R=T;R==(#T@34E-13HZ861D<D%R<F%Y,E-T
M<FEN9R@D:6UP7VAE861E<G,M/F=E=$]B*"=T;R<I*3L*("`@("`@("`D:&5A
M9&5R6R=C8R==(#T@34E-13HZ861D<D%R<F%Y,E-T<FEN9R@D:6UP7VAE861E
M<G,M/F=E=$]B*"=C8R<I*3L*("`@("`@("`D:&5A9&5R6R=B8V,G72`]($U)
M344Z.F%D9')!<G)A>3)3=')I;F<H)&EM<%]H96%D97)S+3YG971/8B@G8F-C
M)RDI.PH@("`@("`@("1H96%D97);)W-U8FIE8W0G72`]("1I;7!?:&5A9&5R
M<RT^9V5T3V(H)W-U8FIE8W0G+"!T<G5E*3L*"B`@("`@("`@)'1I=&QE(#T@
M7R@B365S<V%G92!#;VUP;W-I=&EO;B(I.PH@("`@?0H@("`@)&=E=%]S:6<@
M/2!F86QS93L*("`@(&)R96%K.PH*8V%S92`G8V]M<&]S95]E>'!A;F1?861D
M<B<Z"B`@("`D:&5A9&5R6R=T;R==(#T@7V5X<&%N9$%D9')E<W-E<R@G=&\G
M*3L*("`@("1H96%D97);)V-C)UT@/2!?97AP86YD061D<F5S<V5S*"=C8R<I
M.PH@("`@)&AE861E<ELG8F-C)UT@/2!?97AP86YD061D<F5S<V5S*"=B8V,G
M*3L*("`@("1G971?<VEG(#T@9F%L<V4["B`@("!B<F5A:SL*"F-A<V4@)W)E
M9&ER96-T7V5X<&%N9%]A9&1R)SH*("`@("1H96%D97);)W1O)UT@/2!?97AP
M86YD061D<F5S<V5S*"=T;R<I.PH@("`@)&=E=%]S:6<@/2!F86QS93L*("`@
M(&)R96%K.PH*8V%S92`G<F5P;'DG.@IC87-E("=R97!L>5]A;&PG.@IC87-E
M("=R97!L>5]L:7-T)SH*("`@(&EF("@A96UP='DH)&EN9&5X*2D@>PH@("`@
M("`@("\J(%-E="!T:&4@;65S<V%G95]I9"!A;F0@<F5F97)E;F-E<R!H96%D
M97)S+B`J+PH@("`@("`@(&EF("@H)&US9U]I9"`]("1I;7!?:&5A9&5R<RT^
M9V5T3V(H)VUE<W-A9V5?:60G*2DI('L*("`@("`@("`@("`@)&AE861E<ELG
M:6YR97!L>71O)UT@/2!C:&]P*"1M<V=?:60I.PH@("`@("`@("`@("!I9B`H
M*"1H96%D97);)W)E9F5R96YC97,G72`]("1I;7!?:&5A9&5R<RT^9V5T3V(H
M)W)E9F5R96YC97,G*2DI('L*("`@("`@("`@("`@("`@("1H96%D97);)W)E
M9F5R96YC97,G72`N/2`G("<@+B`D:&5A9&5R6R=I;G)E<&QY=&\G73L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H96%D97);)W)E
M9F5R96YC97,G72`]("1H96%D97);)VEN<F5P;'ET;R==.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&%C=&EO;DE$(#T]("=R97!L
M>2<I('L*("`@("`@("`@("`@*"1H96%D97);)W1O)UT@/2!5=&EL.CIG971&
M;W)M1&%T82@G=&\G*2D@?'P*("`@("`@("`@("`@*"1H96%D97);)W1O)UT@
M/2!-24U%.CIA9&1R07)R87DR4W1R:6YG*"1I;7!?:&5A9&5R<RT^9V5T3V(H
M)W)E<&QY7W1O)RDI*2!\?`H@("`@("`@("`@("`H)&AE861E<ELG=&\G72`]
M($U)344Z.F%D9')!<G)A>3)3=')I;F<H)&EM<%]H96%D97)S+3YG971/8B@G
M9G)O;2<I*2D["B`@("`@("`@?2!E;'-E:68@*"1A8W1I;VY)1"`]/2`G<F5P
M;'E?86QL)RD@>PH@("`@("`@("`@("`O*B!&:6QT97(@;W5T(&]U<B!O=VX@
M861D<F5S<R!F<F]M('1H92!A9&1R97-S97,@=V4@<F5P;'D@=&\N("HO"B`@
M("`@("`@("`@("1M92`](&%R<F%Y7VME>7,H)&ED96YT:71Y+3YG971!;&Q&
M<F]M061D<F5S<V5S*'1R=64I*3L*"B`@("`@("`@("`@("\J($)U:6QD('1H
M92!4;SH@:&5A9&5R+B`J+PH@("`@("`@("`@("`D9G)O;5]A<G(@/2`D:6UP
M7VAE861E<G,M/F=E=$]B*"=F<F]M)RD["B`@("`@("`@("`@("1T;U]A<G(@
M/2`D:6UP7VAE861E<G,M/F=E=$]B*"=R97!L>5]T;R<I.PH@("`@("`@("`@
M("`D<F5P;'D@/2`G)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&]?87)R
M*2D@>PH@("`@("`@("`@("`@("`@)')E<&QY(#T@34E-13HZ861D<D%R<F%Y
M,E-T<FEN9R@D=&]?87)R*3L*("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T
M>2@D9G)O;5]A<G(I*2!["B`@("`@("`@("`@("`@("`D<F5P;'D@/2!-24U%
M.CIA9&1R07)R87DR4W1R:6YG*"1F<F]M7V%R<BD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&AE861E<ELG=&\G72`]($U)344Z.F%D9')!<G)A>3)3
M=')I;F<H87)R87E?;65R9V4H)'1O7V%R<BP@)&9R;VU?87)R*2D["B`@("`@
M("`@("`@("1M95M=(#T@24U0.CIB87)E061D<F5S<R@D:&5A9&5R6R=T;R==
M*3L*"B`@("`@("`@("`@("\J($)U:6QD('1H92!#8SH@:&5A9&5R+B`J+PH@
M("`@("`@("`@("`D8V-?87)R(#T@)&EM<%]H96%D97)S+3YG971/8B@G=&\G
M*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D8V-?87)R*2`F)@H@("`@("`@
M("`@("`@("`@*"1R97!L>2`A/2!-24U%.CIA9&1R07)R87DR4W1R:6YG*"1C
M8U]A<G(I*2D@>PH@("`@("`@("`@("`@("`@)&-C7V%R<B`](&%R<F%Y7VUE
M<F=E*"1C8U]A<G(L("1I;7!?:&5A9&5R<RT^9V5T3V(H)V-C)RDI.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-C7V%R<B`]("1I
M;7!?:&5A9&5R<RT^9V5T3V(H)V-C)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&AE861E<ELG8V,G72`]($U)344Z.F%D9')!<G)A>3)3=')I;F<H
M)&-C7V%R<BP@)&UE*3L*"B`@("`@("`@("`@("\J($)U:6QD('1H92!"8V,Z
M(&AE861E<BX@*B\*("`@("`@("`@("`@)&AE861E<ELG8F-C)UT@/2!-24U%
M.CIA9&1R07)R87DR4W1R:6YG*"1I;7!?:&5A9&5R<RT^9V5T3V(H)V)C8R<I
M("L@)&ED96YT:71Y+3YG971"8V-!9&1R97-S97,H*2P@)&UE*3L*("`@("`@
M("!](&5L<V5I9B`H)&%C=&EO;DE$(#T]("=R97!L>5]L:7-T)RD@>PH@("`@
M("`@("`@("`D:&5A9&5R6R=T;R==(#T@571I;#HZ9V5T1F]R;41A=&$H)W1O
M)RD["B`@("`@("`@?0H*("`@("`@("`D<69R;VT@/2!-24U%.CIA9&1R07)R
M87DR4W1R:6YG*"1I;7!?:&5A9&5R<RT^9V5T3V(H)V9R;VTG*2D["B`@("`@
M("`@:68@*&5M<'1Y*"1Q9G)O;2DI('L*("`@("`@("`@("`@)'%F<F]M(#T@
M)R9L=#LF9W0[)SL*("`@("`@("!]"@H@("`@("`@("1M:6UE7VUE<W-A9V4@
M/2`D:6UP7V-O;G1E;G1S+3YG971-24U%365S<V%G92@I.PH@("`@("`@("1E
M;F-O9&EN9R`](%]G971%;F-O9&EN9R@D;6EM95]M97-S86=E*3L*("`@("`@
M("`D;7-G(#T@)&EM<%]C;VUP;W-E+3YR97!L>4UE<W-A9V4H)&EM<%]C;VYT
M96YT<RP@)'%F<F]M+"`D:6UP7VAE861E<G,I.PH@("`@("`@(&EF("@D<G1E
M;6]D92D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O
M1FEL=&5R+G!H<"<["B`@("`@("`@("`@("1M<V<@/2!497AT7T9I;'1E<CHZ
M9FEL=&5R*"1M<V<L("=T97AT,FAT;6PG+"!A<G)A>2@G<&%R<V5L979E;"<@
M/3X@5$585%](5$U,7TU)0U)/7TQ)3DM54DPL("=C;&%S<R<@/3X@;G5L;"P@
M)V-A;&QB86-K)R`]/B!N=6QL*2D["B`@("`@("`@?0H*("`@("`@("`D:&5A
M9&5R6R=S=6)J96-T)UT@/2`D:6UP7VAE861E<G,M/F=E=$]B*"=S=6)J96-T
M)RP@=')U92D["B`@("`@("`@:68@*"%E;7!T>2@D:&5A9&5R6R=S=6)J96-T
M)UTI*2!["B`@("`@("`@("`@(&EF("A3=')I;F<Z.FQO=V5R*%-T<FEN9SHZ
M<W5B<W1R*"1H96%D97);)W-U8FIE8W0G72P@,"P@,RDI("$]("=R93HG*2![
M"B`@("`@("`@("`@("`@("`D:&5A9&5R6R=S=6)J96-T)UT@/2`G4F4Z("<@
M+B`D:&5A9&5R6R=S=6)J96-T)UT["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D:&5A9&5R6R=S=6)J96-T)UT@/2`G4F4Z
M("<["B`@("`@("`@?0H*("`@("`@("!I9B`H)&%C=&EO;DE$(#T]("=R97!L
M>2<I('L*("`@("`@("`@("`@)'1I=&QE(#T@7R@B4F5P;'DZ(BD@+B`G("<@
M+B`D:&5A9&5R6R=S=6)J96-T)UT["B`@("`@("`@?2!E;'-E:68@*"1A8W1I
M;VY)1"`]/2`G<F5P;'E?86QL)RD@>PH@("`@("`@("`@("`D=&ET;&4@/2!?
M*")297!L>2!T;R!!;&PZ(BD@+B`G("<@+B`D:&5A9&5R6R=S=6)J96-T)UT[
M"B`@("`@("`@?2!E;'-E:68@*"1A8W1I;VY)1"`]/2`G<F5P;'E?;&ES="<I
M('L*("`@("`@("`@("`@)'1I=&QE(#T@7R@B4F5P;'D@=&\@3&ES=#HB*2`N
M("<@)R`N("1H96%D97);)W-U8FIE8W0G73L*("`@("`@("!]"@H@("`@("`@
M("1R97!L>5]I;F1E>"`]("1I;F1E>#L*("`@('T*("`@(&)R96%K.PH*8V%S
M92`G9F]R=V%R9"<Z"B`@("!I9B`H(65M<'1Y*"1I;F1E>"DI('L*("`@("`@
M("`D;6EM95]M97-S86=E(#T@)&EM<%]C;VYT96YT<RT^<F5B=6EL9$UE<W-A
M9V4H*3L*("`@("`@("`D96YC;V1I;F<@/2!?9V5T16YC;V1I;F<H)&UI;65?
M;65S<V%G92D["B`@("`@("`@)&US9R`]("1I;7!?8V]M<&]S92T^9F]R=V%R
M9$UE<W-A9V4H)&EM<%]C;VYT96YT<RP@)&EM<%]H96%D97)S*3L*("`@("`@
M("!I9B`H)')T96UO9&4I('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]497AT+T9I;'1E<BYP:'`G.PH@("`@("`@("`@("`D;7-G(#T@5&5X
M=%]&:6QT97(Z.F9I;'1E<B@D;7-G+"`G=&5X=#)H=&UL)RP@87)R87DH)W!A
M<G-E;&5V96PG(#T^(%1%6%1?2%1-3%]-24-23U],24Y+55),+"`G8VQA<W,G
M(#T^(&YU;&PL("=C86QL8F%C:R<@/3X@;G5L;"DI.PH@("`@("`@('T*"B`@
M("`@("`@)')E<R`]("1I;7!?8V]M<&]S92T^871T86-H1FEL97-&<F]M365S
M<V%G92@D:6UP7V-O;G1E;G1S*3L*("`@("`@("!I9B`H(65M<'1Y*"1R97,I
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1R97,@87,@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D=F%L+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M5V4@;F5E9"!T:&4@365S<V%G92U)9"!S;R!W92!C86X@;&]G('1H:7,@979E
M;G0N("HO"B`@("`@("`@:68@*&ES7V%R<F%Y*"1M97-S86=E7VED(#T@)&EM
M<%]H96%D97)S+3YG971/8B@G;65S<V%G95]I9"<I*2D@>PH@("`@("`@("`@
M("`D;65S<V%G95]I9"`](')E<V5T*"1M97-S86=E7VED*3L*("`@("`@("!]
M"B`@("`@("`@)&AE861E<ELG:6YR97!L>71O)UT@/2!C:&]P*"1M97-S86=E
M7VED*3L*"B`@("`@("`@)&AE861E<ELG<W5B:F5C="==(#T@)&EM<%]H96%D
M97)S+3YG971/8B@G<W5B:F5C="<L('1R=64I.PH@("`@("`@(&EF("@A96UP
M='DH)&AE861E<ELG<W5B:F5C="==*2D@>PH@("`@("`@("`@("`D=&ET;&4@
M/2!?*")&;W)W87)D.B(I("X@)R`G("X@)&AE861E<ELG<W5B:F5C="==.PH@
M("`@("`@("`@("`O*B!)9B!T:&4@<W5B:F5C="!L:6YE(&%L<F5A9'D@:&%S
M('-I9VYA;',@:6YD:6-A=&EN9R!T:&ES"B`@("`@("`@("`@("`@(&UE<W-A
M9V4@:7,@82!F;W)W87)D+"!D;R!N;W0@861D(&%N(&%D9&ET:6]N86P*("`@
M("`@("`@("`@("`@<VEG;F%L+B`J+PH@("`@("`@("`@("`D9G=D7W-I9VYA
M;"`](&9A;'-E.PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G9G=D.B<L
M("=F=SHG+"`G*&9W9"DG+"`G6V9W9%TG*2!A<R`D<VEG;F%L*2!["B`@("`@
M("`@("`@("`@("!I9B`H<W1R:7-T<B@D:&5A9&5R6R=S=6)J96-T)UTL("1S
M:6=N86PI("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1F=V1?
M<VEG;F%L(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(21F=V1?<VEG;F%L*2!["B`@("`@("`@("`@("`@("`D:&5A9&5R6R=S=6)J
M96-T)UT@/2!?*")&=V0Z(BD@+B`G("<@+B`D:&5A9&5R6R=S=6)J96-T)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&ET;&4@/2!?*")&;W)W87)D(BD["B`@("`@("`@("`@("1H96%D97);)W-U
M8FIE8W0G72`](%\H(D9W9#HB*3L*("`@("`@("!]"B`@("!]"B`@("!B<F5A
M:SL*"F-A<V4@)W)E9&ER96-T7V-O;7!O<V4G.@H@("`@)'1I=&QE(#T@7R@B
M4F5D:7)E8W0@=&AI<R!M97-S86=E(BD["B`@("!B<F5A:SL*"F-A<V4@)W)E
M9&ER96-T7W-E;F0G.@H@("`@)&9?=&\@/2!5=&EL.CIG971&;W)M1&%T82@G
M=&\G+"!?9V5T061D<F5S<TQI<W0H)W1O)RDI.PH@("`@:68@*"%E;7!T>2@D
M:6YD97@I("8F("1F7W1O*2!["B`@("`@("`@)')E8VEP:65N=',@/2!?<F5C
M:7!I96YT3&ES="AA<G)A>2@D9E]T;RDI.PH@("`@("`@(&EF("AI<U]A*"1R
M96-I<&EE;G1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H)')E8VEP:65N=',L("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@("`@("`D9V5T7W-I9R`](&9A;'-E.PH@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!]"B`@("`@("`@)')E8VEP:65N=',@/2!I;7!L;V1E*"<L
M("<L("1R96-I<&EE;G1S*3L*"B`@("`@("`@)&EM<%]H96%D97)S+3YB=6EL
M9$AE861E<G,H9F%L<V4I.PH@("`@("`@("1I;7!?:&5A9&5R<RT^861D4F5S
M96YT2&5A9&5R<R@D:61E;G1I='DM/F=E=$9R;VU!9&1R97-S*"DL("1F7W1O
M*3L*"B`@("`@("`@+RH@5V4@;F5E9"!T;R!S970@=&AE(%)E='5R;BU0871H
M(&AE861E<B!T;R!T:&4@8W5R<F5N="!U<V5R("T@<V5E"B`@("`@("`@("`@
M4D9#(#(X,C$@6S0N-%TN("HO"B`@("`@("`@)&EM<%]H96%D97)S+3YR96UO
M=F5(96%D97(H)W)E='5R;BUP871H)RD["B`@("`@("`@)&EM<%]H96%D97)S
M+3YA9&1(96%D97(H)U)E='5R;BU0871H)RP@)&ED96YT:71Y+3YG971&<F]M
M061D<F5S<R@I*3L*"B`@("`@("`@)&)O9'ET97AT(#T@<W1R7W)E<&QA8V4H
M(EQR7&XB+"`B7&XB+"`D:6UP7V-O;G1E;G1S+3YG971";V1Y*"DI.PH@("`@
M("`@("1S=&%T=7,@/2`D:6UP7V-O;7!O<V4M/G-E;F1-97-S86=E*"1R96-I
M<&EE;G1S+"`D:6UP7VAE861E<G,L("1B;V1Y=&5X="P@*&ES<V5T*"1C:&%R
M<V5T*2`_("1C:&%R<V5T(#H@)&5N8V]D:6YG*2D["B`@("`@("`@:68@*"%I
M<U]A*"1S=&%T=7,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&5N
M=')Y(#T@<W!R:6YT9B@B)7,@4F5D:7)E8W1E9"!M97-S86=E('-E;G0@=&\@
M)7,@9G)O;2`E<R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%]3
M15)615);)U)%34]415]!1$12)UTL("1R96-I<&EE;G1S+"`D:6UP6R=U<V5R
M)UTI.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D96YT<GDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["@H@("`@("`@("`@
M("`O*B!3=&]R92!H:7-T;W)Y(&EN9F]R;6%T:6]N+B`J+PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1C;VYF6R=M86EL;&]G)UU;)W5S95]M86EL;&]G)UTI
M*2!["B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G
M+VQI8B]-86EL;&]G+G!H<"<["B`@("`@("`@("`@("`@("!)35!?36%I;&QO
M9SHZ;&]G*"=R961I<F5C="<L("1I;7!?:&5A9&5R<RT^9V5T3V(H)VUE<W-A
M9V5?:60G*2P@)')E8VEP:65N=',I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H)&ES4&]P=7`I('L*("`@("`@("`@("`@("`@(&EF("@D<')E
M9G,M/F=E=%9A;'5E*"=C;VUP;W-E7V-O;F9I<FTG*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B365S<V%G92!R961I
M<F5C=&5D('-U8V-E<W-F=6QL>2XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@
M("`@("`@("`@("`@("`@("!?<&]P=7!3=6-C97-S*"D["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(%5T:6PZ.F-L;W-E
M5VEN9&]W2E,H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=C
M;VUP;W-E7V-O;F9I<FTG*2D@>PH@("`@("`@("`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B365S<V%G92!R961I<F5C=&5D('-U8V-E<W-F
M=6QL>2XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!?;6%I;&)O
M>%)E='5R;E523"AF86QS92DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5X:70["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)'-T871U<RT^9V5T365S<V%G92@I+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@?0H@("`@("`@("1A8W1I
M;VY)1"`]("=R961I<F5C=%]C;VUP;W-E)SL*("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*%\H(E)E9&ER96-T:6YG(&9A:6QE9"XB*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)W-E;F1?;65S<V%G92<Z
M"B`@("`D9E]C8R`]("1F7V)C8R`](&YU;&P["@H@("`@)&9?=&\@/2!?9V5T
M061D<F5S<TQI<W0H)W1O)RD["B`@("!I9B`H)&-O;F9;)V-O;7!O<V4G75LG
M86QL;W=?8V,G72D@>PH@("`@("`@("1F7V-C(#T@7V=E=$%D9')E<W-,:7-T
M*"=C8R<I.PH@("`@?0H@("`@:68@*"1C;VYF6R=C;VUP;W-E)UU;)V%L;&]W
M7V)C8R==*2!["B`@("`@("`@)&9?8F-C(#T@7V=E=$%D9')E<W-,:7-T*"=B
M8V,G*3L*("`@('T*"B`@("`O*B!792!N965D(&%T(&QE87-T(&]N92!R96-I
M<&EE;G0@)B!21D,@,C@R,B!R97%U:7)E<R!T:&%T(&YO"B`@("`@*B`X+6)I
M="!C:&%R86-T97)S(&-A;B!B92!I;B!T:&4@861D<F5S<R!F:65L9',N("HO
M"B`@("`D<F5C:7!I96YT07)R87D@/2!?<F5C:7!I96YT3&ES="AA<G)A>2@D
M9E]T;RP@)&9?8V,L("1F7V)C8RDI.PH@("`@:68@*&ES7V$H)')E8VEP:65N
M=$%R<F%Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"@D<F5C:7!I96YT07)R87DL("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@("1G971?<VEG(#T@9F%L<V4["B`@("`@("`@8G)E86L["B`@("!]"B`@
M("`D<F5C:7!I96YT<R`](&EM<&QO9&4H)RP@)RP@)')E8VEP:65N=$%R<F%Y
M*3L*"B`@("`O*B!'970@:61E;G1I='D@:6YF;W)M871I;VX@;F]W(&%S(&ET
M(&ES(&YE961E9"!F;W(@<V]M92!O9B!T:&4@96YC<GEP=&EO;@H@("`@("H@
M8V]D92X@*B\*("`@("1I9&5N=&ET>5]F;W)M(#T@571I;#HZ9V5T1F]R;41A
M=&$H)VED96YT:71Y)RD["B`@("`D9G)O;2`]("1I9&5N=&ET>2T^9V5T1G)O
M;4QI;F4H)&ED96YT:71Y7V9O<FTL(%5T:6PZ.F=E=$9O<FU$871A*"=F<F]M
M)RDI.PH@("`@)&)A<F5F<F]M(#T@24U0.CIB87)E061D<F5S<R@D9G)O;2D[
M"B`@("`D:61E;G1I='DM/G-E=$1E9F%U;'0H)&ED96YT:71Y7V9O<FTI.PH@
M("`@)')E<&QY=&\@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=R97!L>71O7V%D
M9'(G*3L*"B`@("`O*B!3970@=7`@=&AE(&)A<V4@;65S<V%G92!N;W<N("HO
M"B`@("`D8F]D>2`](%]B87-E365S<V%G92@D:6UP7V-O;7!O<V4L("1C:&%R
M<V5T*3L*("`@(&EF("AI<U]A*"1B;V1Y+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!B<F5A:SL*("`@('T*"B`@("`O*B!0<F5P87)E('1H92!A
M<G)A>2!O9B!M97-S86=E<R!T;R!S96YD(&]U="X@($UA>2!B92!M;W)E('1H
M86X@;VYE(&EF"B`@("`@*B!W92!A<F4@96YC<GEP=&EN9R!F;W(@;75L=&EP
M;&4@<F5C:7!I96YT<R!A<F4@<W1O<FEN9R!A;B!E;F-R>7!T960*("`@("`J
M(&UE<W-A9V4@;&]C86QL>2X@*B\*("`@("1M97-S86=E<U1O4V5N9"`](&%R
M<F%Y*"D["@H@("`@+RH@1&\@96YC<GEP=&EO;BX@*B\*("`@("1E;F-R>7!T
M(#T@571I;#HZ9V5T1F]R;41A=&$H)V5N8W)Y<'1?;W!T:6]N<R<I.PH@("`@
M)'5S95!'4"`]("@D<')E9G,M/F=E=%9A;'5E*"=U<V5?<&=P)RD@)B8@(65M
M<'1Y*"1C;VYF6R=U=&EL<R==6R=G;G5P9R==*2D["B`@("`D=7-E4TU)344@
M/2`D<')E9G,M/F=E=%9A;'5E*"=U<V5?<VUI;64G*3L*("`@("1M=6QT:7!L
M95]P9W!?;7-G(#T@9F%L<V4["@H@("`@:68@*"1U<V501U`@)B8*("`@("`@
M("!I;E]A<G)A>2@D96YC<GEP="P@87)R87DH24U07U!'4%]%3D-265!4+"!)
M35!?4$=07U-)1TY%3D,I*2D@>PH@("`@("`@(&EF("AE;7!T>2@D:6UP7W!G
M<"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("XG+VQI
M8B]#<GEP="]01U`N<&AP)SL*("`@("`@("`@("`@)&EM<%]P9W`@/2`F;F5W
M($E-4%]01U`H*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1I;7!?
M<&=P+3YM=6QT:7!L95)E8VEP:65N=$5N8W)Y<'1I;VXI*2!["B`@("`@("`@
M("`@("1M=6QT:7!L95]P9W!?;7-G(#T@=')U93L*("`@("`@("!]"B`@("!]
M"@H@("`@:68@*"1M=6QT:7!L95]P9W!?;7-G('Q\"B`@("`@("`@*"1U<V53
M34E-12`F)@H@("`@("`@("!I;E]A<G)A>2@D96YC<GEP="P@87)R87DH24U0
M7U--24U%7T5.0U)94%0L($E-4%]334E-15]324=.14Y#*2DI*2!["B`@("`@
M("`@+RH@375S="!E;F-R>7!T("8@<V5N9"!T:&4@;65S<V%G92!O;F4@<F5C
M:7!I96YT(&%T(&$@=&EM92X@*B\*("`@("`@("!F;W)E86-H("@D<F5C:7!I
M96YT07)R87D@87,@)'9A;"D@>PH@("`@("`@("`@("`D<F5S(#T@7V-R96%T
M94UI;65-97-S86=E*&%R<F%Y*"1V86PI+"`D8F]D>2D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("1G971?<VEG(#T@9F%L<V4["B`@("`@("`@("`@("`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*"1R97,L("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("`@("`@8G)E86L@,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;65S
M<V%G97-4;U-E;F1;72`]("1R97,["B`@("`@("`@?0H*("`@("`@("`O*B!-
M=7-T('1A<F=E="!T:&4@96YC<GEP=&EO;B!F;W(@=&AE('-E;F1E<B!B969O
M<F4@<V%V:6YG(&UE<W-A9V4@:6X*("`@("`@("`@*B!S96YT+6UA:6PN("HO
M"B`@("`@("`@)&UE<W-A9V54;U-A=F4@/2!?8W)E871E36EM94UE<W-A9V4H
M87)R87DH)&9R;VTI+"`D8F]D>2D["B`@("`@("`@:68@*&ES7V$H)&UE<W-A
M9V54;U-A=F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&=E=%]S
M:6<@/2!F86QS93L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D
M;65S<V%G951O4V%V92P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@+RH@3F\@96YC
M<GEP=&EO;B`M(&-A;B!S96YD(&EN(&-L96%R+71E>'0@86QL(&%T(&]N8V4N
M("HO"B`@("`@("`@)')E<R`](%]C<F5A=&5-:6UE365S<V%G92@D<F5C:7!I
M96YT07)R87DL("1B;V1Y*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1G971?<VEG(#T@9F%L<V4["B`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<RP@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@("`@("`D
M;65S<V%G97-4;U-E;F1;72`]("1M97-S86=E5&]3879E(#T@)')E<SL*("`@
M('T*"B`@("`O*B!);FET86QI>F4@82!H96%D97(@;V)J96-T(&9O<B!T:&4@
M;W5T9V]I;F<@;65S<V%G92X@*B\*("`@(')E<75I<F5?;VYC92!)35!?0D%3
M12`N("<O;&EB+TU)344O2&5A9&5R<RYP:'`G.PH@("`@)&US9U]H96%D97)S
M(#T@)FYE=R!)35!?2&5A9&5R<R@I.PH*("`@("\J($%D9"!A(%)E8V5I=F5D
M(&AE861E<B!F;W(@=&AE(&AO<"!F<F]M(&)R;W=S97(@=&\@<V5R=F5R+B`J
M+PH@("`@)&US9U]H96%D97)S+3YA9&1296-E:79E9$AE861E<B@I.PH@("`@
M)&US9U]H96%D97)S+3YA9&1-97-S86=E261(96%D97(H*3L*"B`@("`O*B!!
M9&0@=&AE(%@M4')I;W)I='D@:&5A9&5R+"!I9B!R97%U97-T960N(%1H:7,@
M87!P96%R<R!H97)E('-I;F-E"B`@("`@("!T:&ES(&ES('1H92`B9V5N97)A
M;"(@;&]C871I;VX@=&AA="!O=&AE<B!M86EL(&-L:65N=',@:6YS97)T"B`@
M("`@("!T:&ES(&AE861E<BX@*B\*("`@(&EF("@D<')E9G,M/F=E=%9A;'5E
M*"=S971?<')I;W)I='DG*2`F)@H@("`@("`@(%5T:6PZ.F=E=$9O<FU$871A
M*"=X7W!R:6]R:71Y)RDI('L*("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE
M861E<B@G6"U0<FEO<FET>2<L(%5T:6PZ.F=E=$9O<FU$871A*"=X7W!R:6]R
M:71Y)RDI.PH@("`@?0H*("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=$
M871E)RP@9&%T92@G<B<I*3L*"B`@("`O*B!!9&0@4F5T=7)N(%)E8V5I<'0@
M2&5A9&5R<RX@*B\*("`@(&EF("@D8V]N9ELG8V]M<&]S92==6R=A;&QO=U]R
M96-E:7!T<R==*2!["B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=R
M97%U97-T7W)E861?<F5C96EP="<I*2!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O34E-12]-1$XN<&AP)SL*("`@("`@("`@("`@)&UD;B`]
M("9N97<@34E-15]-1$XH*3L*("`@("`@("`@("`@)&UD;BT^861D341.4F5Q
M=65S=$AE861E<G,H)&US9U]H96%D97)S+"`D8F%R969R;VTI.PH@("`@("`@
M('T*("`@('T*"B`@("`D8G)O=W-E<E]C:&%R<V5T(#T@3DQ3.CIG971#:&%R
M<V5T*"D["@H@("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H)T9R;VTG+"!3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1F<F]M+"`D8G)O=W-E<E]C:&%R<V5T
M+"`D8VAA<G-E="DI.PH*("`@(&EF("@A96UP='DH)')E<&QY=&\I("8F("@D
M<F5P;'ET;R`A/2`D8F%R969R;VTI*2!["B`@("`@("`@)&US9U]H96%D97)S
M+3YA9&1(96%D97(H)U)E<&QY+71O)RP@4W1R:6YG.CIC;VYV97)T0VAA<G-E
M="@D<F5P;'ET;RP@)&)R;W=S97)?8VAA<G-E="P@)&-H87)S970I*3L*("`@
M('T*("`@(&EF("@A96UP='DH)&9?=&\I*2!["B`@("`@("`@)&US9U]H96%D
M97)S+3YA9&1(96%D97(H)U1O)RP@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M9E]T;RP@)&)R;W=S97)?8VAA<G-E="P@)&-H87)S970I*3L*("`@('T@96QS
M96EF("AE;7!T>2@D9E]T;RD@)B8@96UP='DH)&9?8V,I*2!["B`@("`@("`@
M)&US9U]H96%D97)S+3YA9&1(96%D97(H)U1O)RP@)W5N9&ES8VQO<V5D+7)E
M8VEP:65N=',Z.R<I.PH@("`@?0H@("`@:68@*"%E;7!T>2@D9E]C8RDI('L*
M("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E<B@G0V,G+"!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1F7V-C+"`D8G)O=W-E<E]C:&%R<V5T+"`D8VAA
M<G-E="DI.PH@("`@?0H*"21J<%]E;F-O9&EN9W-?;&ES="`](&%R<F%Y*"=E
M=6,M:G`G+"`G:7-O+3(P,C(M:G`G+"`G<VAI9G1?:FES)RD["@EI9B`H:6Y?
M87)R87DH<W1R=&]L;W=E<B@D8VAA<G-E="DL("1J<%]E;F-O9&EN9W-?;&ES
M="D@?'P@:6Y?87)R87DH<W1R=&]L;W=E<BA.3%,Z.F=E=$-H87)S970H*2DL
M("1J<%]E;F-O9&EN9W-?;&ES="DI"@D))&US9U]H96%D97)S+3YA9&1(96%D
M97(H)U-U8FIE8W0G+"!?;6EM945N8V]D9613=6)J96-T*%5T:6PZ.F=E=$9O
M<FU$871A*"=S=6)J96-T)RP@)R<I+"!.3%,Z.F=E=$-H87)S970H*2P@)&-H
M87)S970I*3L*"65L<V4*"0DD;7-G7VAE861E<G,M/F%D9$AE861E<B@G4W5B
M:F5C="<L(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H571I;#HZ9V5T1F]R;41A
M=&$H)W-U8FIE8W0G+"`G)RDL($Y,4SHZ9V5T0VAA<G-E="@I+"`D8VAA<G-E
M="DI.PH@("`@"@DO*B!!9&0@;F5C97-S87)Y(&AE861E<G,@9F]R(')E<&QI
M97,N("HO"B`@("`D<F5P;'E?='EP92`](%5T:6PZ.F=E=$9O<FU$871A*"=R
M97!L>5]T>7!E)RD["B`@("`D:7)T(#T@571I;#HZ9V5T1F]R;41A=&$H)VEN
M7W)E<&QY7W1O)RD["B`@("!I9B`H)')E<&QY7W1Y<&4@/3T@)W)E<&QY)RD@
M>PH@("`@("`@(&EF("@D<F5F(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E9F5R
M96YC97,G*2D@>PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E
M<B@G4F5F97)E;F-E<R<L(&EM<&QO9&4H)R`G+"!P<F5G7W-P;&ET*"=\7',K
M?"<L('1R:6TH)')E9BDI*2D["B`@("`@("`@?0H@("`@("`@(&EF("@D:7)T
M*2!["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=);BU2
M97!L>2U4;R<L("1I<G0I.PH@("`@("`@('T*("`@('T*"B`@("`O*B!396YD
M('1H92!M97-S86=E<R!O=70@;F]W+B`J+PH@("`@9F]R96%C:"`H)&UE<W-A
M9V5S5&]396YD(&%S("1V86PI('L*("`@("`@("`D:&5A9&5R<R`]("95=&EL
M.CIC;&]N94]B:F5C="@D;7-G7VAE861E<G,I.PH@("`@("`@("1H96%D97)S
M+3YA9&1-24U%2&5A9&5R<R@D=F%L6R=M<V<G72D["B`@("`@("`@)')E<R`]
M("1I;7!?8V]M<&]S92T^<V5N9$UE<W-A9V4H)'9A;%LG=&\G72P@)&AE861E
M<G,L("1V86Q;)VUS9R==+"`D8VAA<G-E="D["B`@("`):68@*&ES7V$H)')E
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`O*B!5;G-U8V-E<W-F
M=6P@<V5N9"X@*B\*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E
M<RT^9V5T365S<V%G92@I+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")4:&5R92!W87,@86X@97)R;W(@<V5N9&EN9R!Y;W5R(&UE<W-A9V4Z
M("5S(BDL("1R97,M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@("`@("`D9V5T7W-I9R`](&9A;'-E.PH@("`@("`@("`@("!B<F5A
M:R`R.PH@("`@("`@('T*("`@('T*"B`@("`D<V5N=%]S879E9"`]('1R=64[
M"@H@("`@+RH@3&]G('1H92!R97!L>2X@*B\*("`@(&EF("@D<F5P;'E?='EP
M92`F)B`D:7)T*2!["B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG;6%I;&QO
M9R==6R=U<V5?;6%I;&QO9R==*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@24U07T)!4T4@+B`G+VQI8B]-86EL;&]G+G!H<"<["B`@("`@("`@("`@
M($E-4%]-86EL;&]G.CIL;V<H)')E<&QY7W1Y<&4L("1I<G0L("1R96-I<&EE
M;G1S*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5P;'E?:6YD97@@)B8@
M*"1R97!L>5]T>7!E(#T]("=R97!L>2<I*2!["B`@("`@("`@("`@("\J($UA
M:V4@<W5R92!T;R!S970@=&AE($E-05`@<F5P;'D@9FQA9RX@*B\*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O365S<V%G92YP
M:'`G.PH@("`@("`@("`@("`D:6UP7VUE<W-A9V4@/2`F24U07TUE<W-A9V4Z
M.G-I;F=L971O;B@I.PH@("`@("`@("`@("`D9FQA9R`](&%R<F%Y*"1?4T53
M4TE/3ELG:6UP)UU;)W1H:7-M86EL8F]X)UT@/3X@87)R87DH)')E<&QY7VEN
M9&5X*2D["B`@("`@("`@("`@("1I;7!?;65S<V%G92T^9FQA9R@G7%Q!3E-7
M15)%1"<L("1F;&%G*3L*("`@("`@("!]"B`@("!]"@H@("`@)&5N=')Y(#T@
M<W!R:6YT9B@B)7,@365S<V%G92!S96YT('1O("5S(&9R;VT@)7,B+"`D7U-%
M4E9%4ELG4D5-3U1%7T%$1%(G72P@)')E8VEP:65N=',L("1I;7!;)W5S97(G
M72D["B`@("!(;W)D93HZ;&]G365S<V%G92@D96YT<GDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["@H@("`@+RH@1&5L971E('1H92!A
M='1A8VAM96YT(&1A=&$N("HO"B`@("`D;G5M7V%T=&%C:&UE;G1S(#T@)&EM
M<%]C;VUP;W-E+3YN=6UB97)/9D%T=&%C:&UE;G1S*"D["B`@("`D:6UP7V-O
M;7!O<V4M/F1E;&5T94%L;$%T=&%C:&UE;G1S*"D["@H@("`@+RH@4VAO=6QD
M('=E('-A=F4@=&AI<R!M97-S86=E(&EN('1H92!S96YT(&UA:6P@9F]L9&5R
M/R`J+PH@("`@:68@*"1S;68@/2!5=&EL.CIG971&;W)M1&%T82@G<V5N=%]M
M86EL7V9O;&1E<B<I*2!["B`@("`@("`@)'-E;G1?;6%I;%]F;VQD97(@/2`D
M<VUF.PH@("`@?0H@("`@:68@*"%E;7!T>2@D<V5N=%]M86EL7V9O;&1E<BD@
M)B8*("`@("`@("`H*"$D<')E9G,M/FES3&]C:V5D*"=S879E7W-E;G1?;6%I
M;"<I("8F"B`@("`@("`@("!5=&EL.CIG971&;W)M1&%T82@G<V%V95]S96YT
M7VUA:6PG*2D@?'P*("`@("`@("`@*"1P<F5F<RT^:7-,;V-K960H)W-A=F5?
M<V5N=%]M86EL)RD@)B8*("`@("`@("`@("1P<F5F<RT^9V5T5F%L=64H)W-A
M=F5?<V5N=%]M86EL)RDI*2D@>PH*("`@("`@("`D;6EM95]M97-S86=E(#T@
M)&UE<W-A9V54;U-A=F5;)VUS9R==.PH@("`@("`@("1M<V=?:&5A9&5R<RT^
M861D34E-14AE861E<G,H)&UI;65?;65S<V%G92D["@H@("`@("`@("\J($ME
M97`@0F-C.B!H96%D97)S(&]N('-A=F5D(&UE<W-A9V5S+B`J+PH@("`@("`@
M(&EF("@A96UP='DH)&9?8F-C*2D@>PH@("`@("`@("`@("`D;7-G7VAE861E
M<G,M/F%D9$AE861E<B@G0F-C)RP@)&9?8F-C*3L*("`@("`@("!]"@H@("`@
M("`@("\J($QO;W`@=&AR;W5G:"!T:&4@96YV96QO<&4@86YD(&%D9"!H96%D
M97)S+B`J+PH@("`@("`@("1H96%D97)!<G)A>2`]("1M:6UE7VUE<W-A9V4M
M/F5N8V]D92@D;7-G7VAE861E<G,M/G1O07)R87DH*2P@)&-H87)S970I.PH@
M("`@("`@(&9O<F5A8V@@*"1H96%D97)!<G)A>2!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E<B@D:V5Y
M+"`D=F%L=64I.PH@("`@("`@('T*("`@("`@("`D9F-C(#T@)&US9U]H96%D
M97)S+3YT;U-T<FEN9R@I.PH*("`@("`@("`O*B!3=')I<"!A='1A8VAM96YT
M<R!I9B!R97%U97-T960N("HO"B`@("`@("`@)'-A=F5?871T86-H(#T@)'!R
M969S+3YG971686QU92@G<V%V95]A='1A8VAM96YT<R<I.PH@("`@("`@(&EF
M("@H)'-A=F5?871T86-H(#T]("=N979E<B<I('Q\"B`@("`@("`@("`@("@H
M<W1R<&]S*"1S879E7V%T=&%C:"P@)W!R;VUP="<I(#T]/2`P*2`F)@H@("`@
M("`@("`@("`@*%5T:6PZ.F=E=$9O<FU$871A*"=S879E7V%T=&%C:&UE;G1S
M7W-E;&5C="<I(#T](#`I*2D@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,3L@
M)&D@/#T@)&YU;5]A='1A8VAM96YT<SL@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)&]L9%!A<G0@/2`F)&UI;65?;65S<V%G92T^9V5T4&%R="@D:2`K(#$I
M.PH@("`@("`@("`@("`@("`@:68@*"1O;&1087)T("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@("`@("1R97!L86-E7W!A<G0@/2`F;F5W($U)345?
M4&%R="@G=&5X="]P;&%I;B<I.PH@("`@("`@("`@("`@("`@("`@("1R97!L
M86-E7W!A<G0M/G-E=$-H87)S970H)&-H87)S970I.PH@("`@("`@("`@("`@
M("`@("`@("1R97!L86-E7W!A<G0M/G-E=$-O;G1E;G1S*"=;)R`N(%\H(D%T
M=&%C:&UE;G0@<W1R:7!P960Z($]R:6=I;F%L(&%T=&%C:&UE;G0@='EP92(I
M("X@)SH@(B<@+B`D;VQD4&%R="T^9V5T5'EP92@I("X@)R(L("<@+B!?*")N
M86UE(BD@+B`G.B`B)R`N("1O;&1087)T+3YG971.86UE*'1R=64L('1R=64I
M("X@)R)=)RP@)SAB:70G*3L*("`@("`@("`@("`@("`@("`@("`D;6EM95]M
M97-S86=E+3YA;'1E<E!A<G0H)&D@*R`Q+"`D<F5P;&%C95]P87)T*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@061D('1H92!B;V1Y('1E>'0@=&\@=&AE(&UE<W-A9V4@<W1R:6YG
M+B`J+PH@("`@("`@("1F8V,@+CT@)&UI;65?;65S<V%G92T^=&]3=')I;F<H
M*3L*"B`@("`@("`@+RH@36%K92!A8G-O;'5T96QY('-U<F4@=&AE<F4@87)E
M(&YO(&)A<F4@;F5W;&EN97,N("HO"B`@("`@("`@)&9C8R`]('!R96=?<F5P
M;&%C92@B?"A;7EQR72E<;GPB+"`B7%PQ7')<;B(L("1F8V,I.PH@("`@("`@
M("1F8V,@/2!S=')?<F5P;&%C92@B7&Y<;B(L(")<;EQR7&XB+"`D9F-C*3L*
M"B`@("`@("`@:68@*"$D:6UP7V9O;&1E<BT^97AI<W1S*"1S96YT7VUA:6Q?
M9F]L9&5R*2D@>PH@("`@("`@("`@("`D:6UP7V9O;&1E<BT^8W)E871E*"1S
M96YT7VUA:6Q?9F]L9&5R+"`D<')E9G,M/F=E=%9A;'5E*"=S=6)S8W)I8F4G
M*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A0&EM87!?87!P96YD*"1I;7!;
M)W-T<F5A;2==+"!)35`Z.G-E<G9E<E-T<FEN9R@D<V5N=%]M86EL7V9O;&1E
M<BDL("1F8V,L("=<7%-E96XG*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*'-P<FEN=&8H7R@B365S<V%G92!S96YT('-U8V-E<W-F=6QL
M>2P@8G5T(&YO="!S879E9"!T;R`E<R(I+"!)35`Z.F1I<W!L87E&;VQD97(H
M)'-E;G1?;6%I;%]F;VQD97(I*2D["B`@("`@("`@("`@("1S96YT7W-A=F5D
M(#T@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J(%-A=F4@<F5C:7!I
M96YT<R!T;R!A9&1R97-S(&)O;VL_("HO"B`@("!I9B`H)'!R969S+3YG9716
M86QU92@G<V%V95]R96-I<&EE;G1S)RD@)B8*("`@("`@("`D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@G8V]N=&%C=',O:6UP;W)T)RD@)B8*("`@("`@("`D<F5G
M:7-T<GDM/FAA<TUE=&AO9"@G8V]N=&%C=',O<V5A<F-H)RDI('L*"B`@("`@
M("`@)&%B;V]K(#T@)'!R969S+3YG971686QU92@G861D7W-O=7)C92<I.PH@
M("`@("`@(&EF("@A96UP='DH)&%B;V]K*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@("`@("1P87)S
M97(@/2`F;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@("`@("1R96-I<&EE
M;G1!<G)A>2`]("1P87)S97(M/G!A<G-E061D<F5S<TQI<W0H34E-13HZ96YC
M;V1E061D<F5S<R@D<F5C:7!I96YT<RP@;G5L;"P@)%]315-324].6R=I;7`G
M75LG;6%I;&1O;6%I;B==*2D["@H@("`@("`@("`@("`O*B!&:6QT97(@;W5T
M(&%N>6]N92!T:&%T(&UA=&-H97,@86X@96UA:6P@861D<F5S<R!A;')E861Y
M"B`@("`@("`@("`@("`J(&EN('1H92!A9&1R97-S(&)O;VLN("HO"B`@("`@
M("`@("`@("1E;6%I;',@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H
M("@D<F5C:7!I96YT07)R87D@87,@)')E8VEP:65N="D@>PH@("`@("`@("`@
M("`@("`@)&5M86EL<UM=(#T@)')E8VEP:65N="T^;6%I;&)O>"`N("=`)R`N
M("1R96-I<&EE;G0M/FAO<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)')E<W5L=',@/2`D<F5G:7-T<GDM/F-A;&PH)V-O;G1A8W1S+W-E87)C:"<L
M(&%R<F%Y*"1E;6%I;',L(&%R<F%Y*"1A8F]O:RDL(&%R<F%Y*"1A8F]O:R`]
M/B!A<G)A>2@G96UA:6PG*2DI*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1R
M96-I<&EE;G1!<G)A>2!A<R`D<F5C:7!I96YT*2!["B`@("`@("`@("`@("`@
M("`O*B!3:VEP(&5M86EL(&%D9')E<W-E<R!T:&%T(&%L<F5A9'D@97AI<W0@
M:6X@=&AE"B`@("`@("`@("`@("`@("`@*B!A9&1?<V]U<F-E+B`J+PH@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1R97-U;'1S6R1R96-I<&EE;G0M/FUA
M:6QB;W@@+B`G0"<@+B`D<F5C:7!I96YT+3YH;W-T72D@)B8*("`@("`@("`@
M("`@("`@("`@("!C;W5N="@D<F5S=6QT<ULD<F5C:7!I96YT+3YM86EL8F]X
M("X@)T`G("X@)')E8VEP:65N="T^:&]S=%TI*2!["B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@+RH@4F5M;W9E('-U<G)O=6YD:6YG('%U;W1E<R!A;F0@;6%K92!S
M=7)E('1H870@)&YA;64*("`@("`@("`@("`@("`@("`J(&ES(&YO;BUE;7!T
M>2X@*B\*("`@("`@("`@("`@("`@("1N86UE(#T@=')I;2@D<F5C:7!I96YT
M+3YP97)S;VYA;"D["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UXH6R)<)UTI+BI<,20O)RP@)&YA;64I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2!S=6)S='(H)&YA;64L(#$L("TQ*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@
M("`@("`@("`@("`@("`@("`D;F%M92`]("1R96-I<&EE;G0M/FUA:6QB;W@[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;F%M92`]($U)
M344Z.F1E8V]D92@D;F%M92P@)&)R;W=S97)?8VAA<G-E="D["@H@("`@("`@
M("`@("`@("`@)')E<W5L="`]("1R96=I<W1R>2T^8V%L;"@G8V]N=&%C=',O
M:6UP;W)T)RP@87)R87DH87)R87DH)VYA;64G(#T^("1N86UE+"`G96UA:6PG
M(#T^("1R96-I<&EE;G0M/FUA:6QB;W@@+B`G0"<@+B`D<F5C:7!I96YT+3YH
M;W-T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A<G)A>2<L("1A8F]O:RDI
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT+3YG971#
M;V1E*"D@/3T@)VAO<F1E+F5R<F]R)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1R97-U;'0L("1R97-U;'0M/F=E
M=$-O9&4H*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B16YT<GD@7"(E<UPB('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@=&AE(&%D9')E<W,@8F]O:R(I+"`D;F%M92DL("=H;W)D
M92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@:68@*"1I<U!O<'5P*2!["B`@("`@("`@
M:68@*"1P<F5F<RT^9V5T5F%L=64H)V-O;7!O<V5?8V]N9FER;2<I('Q\("$D
M<V5N=%]S879E9"D@>PH@("`@("`@("`@("!I9B`H)'-E;G1?<V%V960I('L*
M("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B365S<V%G
M92!S96YT('-U8V-E<W-F=6QL>2XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!?<&]P=7!3=6-C97-S*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@571I;#HZ8VQO<V57:6YD;W=*4R@I
M.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@:68@*"1P<F5F<RT^
M9V5T5F%L=64H)V-O;7!O<V5?8V]N9FER;2<I("8F("1S96YT7W-A=F5D*2![
M"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B365S<V%G92!S
M96YT('-U8V-E<W-F=6QL>2XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@
M("!]"B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N(%]M86EL8F]X4F5T
M=7)N55),*&9A;'-E*2D["B`@("!]"B`@("!E>&ET.PH*8V%S92`G<V%V95]D
M<F%F="<Z"B`@("`D9')A9G1S7V9O;&1E<B`]($E-4#HZ9F]L9&5R4')E9B@D
M<')E9G,M/F=E=%9A;'5E*"=D<F%F='-?9F]L9&5R)RDL('1R=64I.PH@("`@
M:68@*"%E;7!T>2@D9')A9G1S7V9O;&1E<BDI('L*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344O365S<V%G92YP:'`G.PH@("`@("`@("1M:6UE
M(#T@)FYE=R!-24U%7TUE<W-A9V4H)&EM<%LG;6%I;&1O;6%I;B==*3L*"B`@
M("`@("`@+RH@5V4@;F5E9"!T;R!M86ME('-U<F4@=V4@861D(")<<EQN(B!A
M9G1E<B!E=F5R>2!L:6YE(&9O<@H@("`@("`@("`J(&EM87!?87!P96YD*"D@
M+2!S;VUE('-E<G9E<G,@<F5Q=6ER92!I="`H92YG+B!#>7)U<RDN("HO"B`@
M("`@("`@)&UI;64M/G-E=$5/3"A-24U%7U!!4E1?4D9#7T5/3"D["@H@("`@
M("`@("\J(%-E="!U<"!T:&4@8F%S92!M97-S86=E(&YO=RX@*B\*("`@("`@
M("`D8F]D>2`](%]B87-E365S<V%G92@D:6UP7V-O;7!O<V4L("1C:&%R<V5T
M+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)&)O9'DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S+"`G
M:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*
M("`@("`@("`D;6EM92T^861D4&%R="@D8F]D>2D["B`@("`@("`@)&)O9'D@
M/2`D;6EM92T^=&]3=')I;F<H*3L*"B`@("`@("`@)&9R;VT@/2`D:61E;G1I
M='DM/F=E=$9R;VU,:6YE*%5T:6PZ.F=E=$9O<FU$871A*"=I9&5N=&ET>2<I
M+"!5=&EL.CIG971&;W)M1&%T82@G9G)O;2<I*3L*"B`@("`@("`@+RH@26YI
M=&%L:7IE(&$@:&5A9&5R(&]B:F5C="!F;W(@=&AE(&1R869T+B`J+PH@("`@
M("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TU)344O2&5A9&5R
M<RYP:'`G.PH@("`@("`@("1D<F%F=%]H96%D97)S(#T@)FYE=R!)35!?2&5A
M9&5R<R@I.PH*("`@("`@("`D9')A9G1?:&5A9&5R<RT^861D2&5A9&5R*"=$
M871E)RP@9&%T92@G<B<I*3L*("`@("`@("!I9B`H(65M<'1Y*"1F<F]M*2D@
M>PH@("`@("`@("`@("`D9')A9G1?:&5A9&5R<RT^861D2&5A9&5R*"=&<F]M
M)RP@)&9R;VTI.PH@("`@("`@('T*("`@("`@("!I9B`H*"1H96%D97);)W1O
M)UT@/2!5=&EL.CIG971&;W)M1&%T82@G=&\G*2DI('L*("`@("`@("`@("`@
M)&1R869T7VAE861E<G,M/F%D9$AE861E<B@G5&\G+"!-24U%.CIE;F-O9&5!
M9&1R97-S*%]F;W)M871!9&1R*"1H96%D97);)W1O)UTI+"!N=6QL+"`D:6UP
M6R=M86EL9&]M86EN)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@*"@D:&5A
M9&5R6R=C8R==(#T@571I;#HZ9V5T1F]R;41A=&$H)V-C)RDI*2!["B`@("`@
M("`@("`@("1D<F%F=%]H96%D97)S+3YA9&1(96%D97(H)T-C)RP@34E-13HZ
M96YC;V1E061D<F5S<RA?9F]R;6%T061D<B@D:&5A9&5R6R=C8R==*2P@;G5L
M;"P@)&EM<%LG;6%I;&1O;6%I;B==*2D["B`@("`@("`@?0H@("`@("`@(&EF
M("@H)&AE861E<ELG8F-C)UT@/2!5=&EL.CIG971&;W)M1&%T82@G8F-C)RDI
M*2!["B`@("`@("`@("`@("1D<F%F=%]H96%D97)S+3YA9&1(96%D97(H)T)C
M8R<L($U)344Z.F5N8V]D94%D9')E<W,H7V9O<FUA=$%D9'(H)&AE861E<ELG
M8F-C)UTI+"!N=6QL+"`D:6UP6R=M86EL9&]M86EN)UTI*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"@D<W5B(#T@571I;#HZ9V5T1F]R;41A=&$H)W-U8FIE
M8W0G*2DI('L*("`@("`@("`@("`@)&1R869T7VAE861E<G,M/F%D9$AE861E
M<B@G4W5B:F5C="<L($U)344Z.F5N8V]D92@D<W5B+"!.3%,Z.F=E=$-H87)S
M970H*2DI.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)&UI;64I*2![
M"B`@("`@("`@("`@("1D<F%F=%]H96%D97)S+3YA9&1-24U%2&5A9&5R<R@D
M;6EM92D["B`@("`@("`@?0H*("`@("`@("`D8F]D>2`]("1D<F%F=%]H96%D
M97)S+3YT;U-T<FEN9R@I("X@)&)O9'D["@H@("`@("`@("\O($UA:V4@86)S
M;VQU=&5L>2!S=7)E('1H97)E(&%R92!N;R!B87)E(&YE=VQI;F5S+@H@("`@
M("`@("1B;V1Y(#T@<')E9U]R97!L86-E*")\*%M>7')=*5QN?"(L(")<7#%<
M<EQN(BP@)&)O9'DI.PH@("`@("`@("1B;V1Y(#T@<W1R7W)E<&QA8V4H(EQN
M7&XB+"`B7&Y<<EQN(BP@)&)O9'DI.PH*("`@("`@("!I9B`H)'!R969S+3YG
M971686QU92@G=6YS965N7V1R869T<R<I*2!["B`@("`@("`@("`@("1A<'!E
M;F1?9FQA9W,@/2`G7%Q$<F%F="<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&%P<&5N9%]F;&%G<R`]("=<7$1R869T(%Q<4V5E;B<["B`@("`@
M("`@?0H*("`@("`@("`D9')A9G1?<W5C8V5S<R`](&9A;'-E.PH*("`@("`@
M("!I9B`H)&EM<%]F;VQD97(M/F5X:7-T<R@D9')A9G1S7V9O;&1E<BDI('L*
M("`@("`@("`@("`@)&1R869T7W-U8V-E<W,@/2!T<G5E.PH@("`@("`@('T@
M96QS96EF("@D:6UP7V9O;&1E<BT^8W)E871E*"1D<F%F='-?9F]L9&5R+"`D
M<')E9G,M/F=E=%9A;'5E*"=S=6)S8W)I8F4G*2DI('L*("`@("`@("`@("`@
M)&1R869T7W-U8V-E<W,@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1D<F%F=%]S=6-C97-S*2!["B`@("`@("`@("`@(&EF("@A0&EM87!?87!P
M96YD*"1I;7!;)W-T<F5A;2==+"!)35`Z.G-E<G9E<E-T<FEN9R@D9')A9G1S
M7V9O;&1E<BDL("1B;V1Y+"`D87!P96YD7V9L86=S*2D@>PH@("`@("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-A=FEN9R!T
M:&4@9')A9G0@9F%I;&5D+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`E<R(I+"!I;6%P7VQA<W1?97)R;W(H*2DL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)'!R969S+3YG971686QU92@G8VQO<V5?
M9')A9G0G*2D@>PH@("`@("`@("`@("`@("`@:68@*"1I<U!O<'5P*2!["B`@
M("`@("`@("`@("`@("`@("`@571I;#HZ8VQO<V57:6YD;W=*4R@I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!H96%D
M97(H)TQO8V%T:6]N.B`G("X@7VUA:6QB;WA2971U<FY54DPH9F%L<V4I*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5X:70["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&1R869T(&AA<R!B965N('-A=F5D('1O
M('1H92!<(B5S7"(@9F]L9&5R+B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($E-4#HZ9&ES<&QA>49O;&1E<B@D9')A
M9G1S7V9O;&1E<BDI*3L*("`@("`@("`@("`@("`@("1G971?<VEG(#T@9F%L
M<V4["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*("`@("1G971?<VEG(#T@9F%L<V4["B`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*%\H(E1H97)E('=A<R!A;B!E<G)O<B!S879I;F<@=&AI
M<R!M97-S86=E(&%S(&$@9')A9G0N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@
M8G)E86L["@IC87-E("=F=V1?9&EG97-T)SH*("`@("1I;F1I8V5S(#T@571I
M;#HZ9V5T1F]R;41A=&$H)V9W9&1I9V5S="<I.PH@("`@:68@*"%E;7!T>2@D
M:6YD:6-E<RDI('L*("`@("`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G
M+VQI8B]-24U%+T-O;G1E;G1S+G!H<"<["B`@("`@("`@)&US9VQI<W0@/2!U
M;G-E<FEA;&EZ92AU<FQD96-O9&4H)&EN9&EC97,I*3L*("`@("`@("!F;W)E
M86-H("@D;7-G;&ES="!A<R`D:6YD97@I('L*("`@("`@("`@("`@:68@*'-T
M<G-T<B@D:6YD97@L($E-4%])1%A?4T50*2D@>PH@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH@("`@
M("`@("`@("`@("`@)&EM<%]I;6%P(#T@)DE-4%])34%0.CIS:6YG;&5T;VXH
M*3L*("`@("`@("`@("`@("`@(&QI<W0H)&EN9&5X+"`D;6%I;&)O>"D@/2!E
M>'!L;V1E*$E-4%])1%A?4T50+"`D:6YD97@I.PH@("`@("`@("`@("`@("`@
M)&EM<%]I;6%P+3YC:&%N9V5-8F]X*"1M86EL8F]X*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1M86EL8F]X(#T@)%]315-324].
M6R=I;7`G75LG=&AI<VUA:6QB;W@G73L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<&%R="`]("9N97<@34E-15]087)T*"=M97-S86=E+W)F8S@R,B<I
M.PH@("`@("`@("`@("`D8V]N=&5N=',@/2`F24U07T-O;G1E;G1S.CIS:6YG
M;&5T;VXH)&EN9&5X("X@24U07TE$6%]315`@+B`D;6%I;&)O>"D["B`@("`@
M("`@("`@("1D:6=E<W1?:&5A9&5R<R`]("8D8V]N=&5N=',M/F=E=$AE861E
M<D]B*"D["B`@("`@("`@("`@(&EF("@A*"1N86UE(#T@)&1I9V5S=%]H96%D
M97)S+3YG971/8B@G<W5B:F5C="<L('1R=64I*2D@>PH@("`@("`@("`@("`@
M("`@)&YA;64@/2!?*");3F\@4W5B:F5C=%TB*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<&%R="T^<V5T3F%M92@D;F%M92D["B`@("`@("`@("`@
M("1P87)T+3YS971#;VYT96YT<R@D8V]N=&5N=',M/F9U;&Q-97-S86=E5&5X
M="@I*3L*("`@("`@("`@("`@)')E<R`]("1I;7!?8V]M<&]S92T^861D34E-
M15!A<G1!='1A8VAM96YT*"1P87)T*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"@D<F5S+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H8V]U;G0H)&US9VQI<W0I(#T]
M(#$I('L*("`@("`@("`@("`@)&AE861E<ELG<W5B:F5C="==(#T@7R@B1G=D
M.B`B*2`N("1N86UE.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H
M96%D97);)W-U8FIE8W0G72`]('-P<FEN=&8H7R@B1G=D.B`E=2!&;W)W87)D
M960@365S<V%G97,B*2P@8V]U;G0H)&US9VQI<W0I*3L*("`@("`@("!]"B`@
M("!]"B`@("!B<F5A:SL*"F-A<V4@)V-A;F-E;%]C;VUP;W-E)SH*("`@("1I
M;7!?8V]M<&]S92T^9&5L971E06QL071T86-H;65N=',H*3L*("`@(&EF("@D
M:7-0;W!U<"D@>PH@("`@("`@(%5T:6PZ.F-L;W-E5VEN9&]W2E,H*3L*("`@
M('T@96QS92!["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N(%]M86EL
M8F]X4F5T=7)N55),*&9A;'-E*2D["B`@("!]"B`@("!E>&ET.PH*8V%S92`G
M<W!E;&Q?8VAE8VM?8V%N8V5L)SH*("`@("1M<V<@/2`B7&XB("X@571I;#HZ
M9V5T1F]R;41A=&$H)VUE<W-A9V4G*3L*("`@("1E>'!A;F1E9"`](%5T:6PZ
M.F=E=$9O<FU$871A*"=T;U]L:7-T)RD["B`@("!I9B`H(65M<'1Y*"1E>'!A
M;F1E9"DI('L*("`@("`@("`D:&5A9&5R6R=T;R==(#T@7V5X<&%N9$%D9')E
M<W-E<R@G=&\G*3L*("`@("`@("`D:&5A9&5R6R=C8R==(#T@7V5X<&%N9$%D
M9')E<W-E<R@G8V,G*3L*("`@("`@("`D:&5A9&5R6R=B8V,G72`](%]E>'!A
M;F1!9&1R97-S97,H)V)C8R<I.PH@("`@?0H@("`@)&=E=%]S:6<@/2!F86QS
M93L*("`@(&)R96%K.PH*8V%S92`G<W!E;&Q?8VAE8VM?9&]N92<Z"B`@("`D
M;7-G(#T@(EQN(CL*("`@("1M<V<@+CT@571I;#HZ9V5T1F]R;41A=&$H)VYE
M=VUS9R<I.PH@("`@)&US9R`N/2!5=&EL.CIG971&;W)M1&%T82@G8W5R<FUS
M9R<I.PH@("`@)&5X<&%N9&5D(#T@571I;#HZ9V5T1F]R;41A=&$H)W1O7VQI
M<W0G*3L*("`@(&EF("@A96UP='DH)&5X<&%N9&5D*2D@>PH@("`@("`@("1H
M96%D97);)W1O)UT@/2!?97AP86YD061D<F5S<V5S*"=T;R<I.PH@("`@("`@
M("1H96%D97);)V-C)UT@/2!?97AP86YD061D<F5S<V5S*"=C8R<I.PH@("`@
M("`@("1H96%D97);)V)C8R==(#T@7V5X<&%N9$%D9')E<W-E<R@G8F-C)RD[
M"B`@("!]"B`@("`D9V5T7W-I9R`](&9A;'-E.PH@("`@8G)E86L["@IC87-E
M("=S<&5L;%]C:&5C:R<Z"F-A<V4@)W-P96QL7V-H96-K7W-E;F0G.@IC87-E
M("=S<&5L;%]C:&5C:U]F;W)W87)D)SH*("`@(')E<75I<F4@24U07T)!4T4@
M+B`G+W-P96QL:6YG+G!H<"<["B`@("!B<F5A:SL*"F-A<V4@)W-E;&5C=&QI
M<W1?<')O8V5S<R<Z"B`@("`D<V5L96-T7VED(#T@571I;#HZ9V5T1F]R;41A
M=&$H)W-E;&5C=&QI<W1?<V5L96-T:60G*3L*("`@(&EF("@A96UP='DH)'-E
M;&5C=%]I9"DI('L*("`@("`@("!I9B`H)')E9VES=')Y+3YH87--971H;V0H
M)V9I;&5S+W-E;&5C=&QI<W1297-U;'1S)RD@)B8*("`@("`@("`@("`@)')E
M9VES=')Y+3YH87--971H;V0H)V9I;&5S+W)E='5R;D9R;VU396QE8W1L:7-T
M)RDI('L*("`@("`@("`@("`@)&9I;&5L:7-T(#T@)')E9VES=')Y+3YC86QL
M*"=F:6QE<R]S96QE8W1L:7-T4F5S=6QT<R<L(&%R<F%Y*"1S96QE8W1?:60I
M*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D9FEL96QI<W0I*2!["B`@("`@
M("`@("`@("`@("`D:2`](#`["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9FEL96QI<W0@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("1D871A
M(#T@)')E9VES=')Y+3YC86QL*"=F:6QE<R]R971U<FY&<F]M4V5L96-T;&ES
M="<L(&%R<F%Y*"1S96QE8W1?:60L("1I*RLI*3L*("`@("`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1D871A*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R="`]("9N97<@34E-15]087)T*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1P87)T+3YS971#;VYT96YT<R@D9&%T82D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)T+3YS971.86UE*')E<V5T*"1V86PI*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E<R`]("1I;7!?8V]M<&]S92T^
M861D34E-15!A<G1!='1A8VAM96YT*"1P87)T*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D
M<F5S+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G
M8VAA;F=E7W-T871I;VYE<GDG.@H@("`@:68@*"$D<')E9G,M/FES3&]C:V5D
M*"=S=&%T:6]N97)Y)RDI('L*("`@("`@("`D<W1A=&EO;F5R>2`](%5T:6PZ
M.F=E=$9O<FU$871A*"=S=&%T:6]N97)Y)RD["B`@("`@("`@:68@*'-T<FQE
M;B@D<W1A=&EO;F5R>2DI('L*("`@("`@("`@("`@)'-T871I;VYE<GD@/2`H
M:6YT*21S=&%T:6]N97)Y.PH@("`@("`@("`@("`D<W1A=&EO;F5R>5]C;VYT
M96YT(#T@)'-T871I;VYE<GE?;&ES=%LD<W1A=&EO;F5R>5U;)V,G73L*("`@
M("`@("`@("`@)&US9R`](%5T:6PZ.F=E=$9O<FU$871A*"=M97-S86=E)RP@
M)R<I.PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1S=&%T:6]N97)Y7V-O;G1E
M;G0L("<E<R<I("$]/2!F86QS92D@>PH*("`@("`@("`@("`@("`@(&EF("@A
M:7-?;G5L;"@D<V5L96-T961?:61E;G1I='D@/2!5=&EL.CIG971&;W)M1&%T
M82@G:61E;G1I='DG*2DI('L*("`@("`@("`@("`@("`@("`@("`D<VEG(#T@
M)&ED96YT:71Y+3YG9713:6=N871U<F4H)'-E;&5C=&5D7VED96YT:71Y*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'-I9R`]("1I9&5N=&ET>2T^9V5T4VEG;F%T=7)E*"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)')T96UO9&4I('L*("`@("`@
M("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R
M+G!H<"<["B`@("`@("`@("`@("`@("`@("`@)'-I9R`](%1E>'1?1FEL=&5R
M.CIF:6QT97(H)'-I9RP@)W1E>'0R:'1M;"<L(&%R<F%Y*"=P87)S96QE=F5L
M)R`]/B!415A47TA434Q?34E#4D]?3$E.2U523"P@)V-L87-S)R`]/B!N=6QL
M+"`G8V%L;&)A8VLG(#T^(&YU;&PI*3L*("`@("`@("`@("`@("`@("`@("`D
M<W1A=&EO;F5R>5]C;VYT96YT(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D<W1A
M=&EO;F5R>5]C;VYT96YT+"`G=&5X=#)H=&UL)RP@87)R87DH)W!A<G-E;&5V
M96PG(#T^(%1%6%1?2%1-3%]-24-23U],24Y+55),+"`G8VQA<W,G(#T^(&YU
M;&PL("=C86QL8F%C:R<@/3X@;G5L;"DI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&US9R`]('-T<E]R97!L86-E*&%R<F%Y*")<<EQN
M(BP@)'-I9RDL(&%R<F%Y*")<;B(L("<G*2P@)&US9RD["B`@("`@("`@("`@
M("`@("`D<W1A=&EO;F5R>5]C;VYT96YT(#T@<W1R7W)E<&QA8V4H)R5S)RP@
M)'-I9RP@)'-T871I;VYE<GE?8V]N=&5N="D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*'-T<G!O<R@D<W1A=&EO;F5R>5]C;VYT96YT+"`G)6,G
M*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1M<V<@+CT@)'-T871I
M;VYE<GE?8V]N=&5N=#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1M<V<@/2!S=')?<F5P;&%C92@G)6,G+"`D;7-G+"`D<W1A=&EO
M;F5R>5]C;VYT96YT*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M("`@("1G971?<VEG(#T@9F%L<V4["B`@("!B<F5A:SL*"F-A<V4@)V%D9%]A
M='1A8VAM96YT)SH*("`@("1G971?<VEG(#T@9F%L<V4["B`@("!B<F5A:SL*
M"GT*"FEF("@D<G1E;6]D92D@>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]%
M9&ET;W(N<&AP)SL*("`@("1E9&ET;W(@/2`F2&]R9&5?161I=&]R.CIS:6YG
M;&5T;VXH)VAT;6QA<F5A)RP@87)R87DH)VED)R`]/B`G;65S<V%G92<I*3L*
M?0H*+RH@1V5T('1H92!M97-S86=E(&-A8VAE($E$+B`J+PHD;65S<V%G94-A
M8VAE240@/2`D:6UP7V-O;7!O<V4M/F=E=$UE<W-A9V5#86-H94ED*"D["@HO
M*B!(87,@=&AI<R!P86=E(&)E96X@<F5L;V%D960_("HO"B1R96QO861E9"`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=R96QO861E9"<I.PH*+RH@4V5T('1H92`G
M<V%V95]S96YT7VUA:6PG(&-H96-K8F]X(&9O<B!T:&4@9F]R;2X@*B\*:68@
M*"1R96QO861E9"D@>PH@("`@)'-S;5]C:&5C:R`](%5T:6PZ.F=E=$9O<FU$
M871A*"=S879E7W-E;G1?;6%I;"<I(#T]("=O;B<["GT@96QS92!["B`@("`D
M<W-M7V-H96-K(#T@)&ED96YT:71Y+3YS879E4V5N=&UA:6PH571I;#HZ9V5T
M1F]R;41A=&$H)VED96YT:71Y)RDI.PI]"@II9B`H)&)R;W=S97(M/FES0G)O
M=W-E<B@G;7-I92<I*2!["B`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G:65%
M<V-'=6%R9"YJ<R<L("=I;7`G+"!T<G5E*3L*?0IR97%U:7)E($E-4%]414U0
M3$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*"FEF("@D:7-0;W!U<"D@
M>PH@("`@+RH@268@=&AE(&%T=&%C:&UE;G1S(&-A8VAE(&ES(&YO="!E;7!T
M>2P@=V4@;75S="!R96QO860@=&AI<R!P86=E"B`@("`@*B!A;F0@9&5L971E
M('1H92!A='1A8VAM96YT<RX@*B\*("`@(&EF("@D;65S<V%G94-A8VAE240I
M('L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS
M96QF57)L*"DL(&%R<F%Y*"=A8W1I;VY)1"<@/3X@)V-A;F-E;%]C;VUP;W-E
M)RP@)VUE<W-A9V5#86-H92<@/3X@)&UE<W-A9V5#86-H94E$+"`G<&]P=7`G
M(#T^(#$I+"!N=6QL+"!F86QS92D["B`@("`@("`@)&-A;F-E;%]J<R`]("=S
M96QF+FQO8V%T:6]N+FAR968]7"<G("X@)'5R;"`N("=<)SLG.PH@("`@?2!E
M;'-E('L*("`@("`@("`D8V%N8V5L7VIS(#T@)W-E;&8N8VQO<V4H*3LG.PH@
M("`@?0I](&5L<V4@>PH@("`@+RH@268@=&AE(&%T=&%C:&UE;G1S(&-A8VAE
M(&ES(&YO="!E;7!T>2P@=V4@;75S="!R96QO860@=&AI<R!P86=E(&%N9`H@
M("`@("`@9&5L971E('1H92!A='1A8VAM96YT<RX@*B\*("`@(&EF("@D;65S
M<V%G94-A8VAE240I('L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE
M=&5R*%]M86EL8F]X4F5T=7)N55),*'1R=64L($AO<F1E.CIS96QF57)L*"DI
M+"!A<G)A>2@G86-T:6]N240G(#T^("=C86YC96Q?8V]M<&]S92<L("=M97-S
M86=E0V%C:&4G(#T^("1M97-S86=E0V%C:&5)1"DL(&YU;&PL(&9A;'-E*3L*
M("`@("`@("`D8V%N8V5L7VIS(#T@)W=I;F1O=RYL;V-A=&EO;B`](%PG)R`N
M("1U<FP@+B`G7"<[)SL*("`@('T@96QS92!["B`@("`@("`@)&-A;F-E;%]J
M<R`]("=W:6YD;W<N;&]C871I;VX@/2!<)R<@+B!?;6%I;&)O>%)E='5R;E52
M3"AT<G5E*2`N("=<)SLG.PH@("`@?0H@("`@<F5Q=6ER92!)35!?5$5-4$Q!
M5$53("X@)R]M96YU+FEN8R<["GT*"B1S96QE8W1?;&ES="`]("1I9&5N=&ET
M>2T^9V5T4V5L96-T3&ES="@I.PH*:68@*%5T:6PZ.F=E=$9O<FU$871A*"=F
M<F]M)RD@?'P@)'!R969S+3YI<TQO8VME9"@G9&5F875L=%]I9&5N=&ET>2<I
M*2!["B`@("`D9G)O;2`]("1I9&5N=&ET>2T^9V5T1G)O;4QI;F4H571I;#HZ
M9V5T1F]R;41A=&$H)VED96YT:71Y)RDL(%5T:6PZ.F=E=$9O<FU$871A*"=F
M<F]M)RDI.PI](&5L<V4@>PH@("`@)&9R;VU?<V5L96-T960@/2!5=&EL.CIG
M971&;W)M1&%T82@G:61E;G1I='DG*3L*("`@(&EF("AI<W-E="@D9G)O;5]S
M96QE8W1E9"DI('L*("`@("`@("`D:61E;G1I='DM/G-E=$1E9F%U;'0H)&9R
M;VU?<V5L96-T960I.PH@("`@?0I]"@HO*B!'<F%B(&%N>2!D871A('1H870@
M=V4@=V5R92!S=7!P;&EE9"!W:71H+B`J+PII9B`H96UP='DH)&US9RDI('L*
M("`@("1M<V<@/2!5=&EL.CIG971&;W)M1&%T82@G;65S<V%G92<L("<G*3L*
M("`@(&EF("@D8G)O=W-E<BT^:&%S475I<FLH)V1O=6)L95]L:6YE8G)E86M?
M=&5X=&%R96$G*2D@>PH@("`@("`@("1M<V<@/2!P<F5G7W)E<&QA8V4H)R\H
M7'(_7&XI>S-]+R<L("<D,2<L("1M<V<I.PH@("`@?0H@("`@)&US9R`](")<
M;B(@+B`D;7-G.PH*("`@("\J($-O;G9E<G0@9G)O;2!497AT("T^($A434P@
M;W(@=FEC92!V97)S82!I9B!25$4@;6]D92!C:&%N9V5D+B`J+PH@("`@:68@
M*&ES<V5T*"1O;&1R=&5M;V1E*2`F)B`H)&]L9')T96UO9&4@(3T@)')T96UO
M9&4I*2!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]497AT+T9I;'1E
M<BYP:'`G.PH@("`@("`@(&EF("@D<G1E;6]D92D@>PH@("`@("`@("`@("`D
M;7-G(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D;7-G+"`G=&5X=#)H=&UL)RP@
M87)R87DH)W!A<G-E;&5V96PG(#T^(%1%6%1?2%1-3%]-24-23U],24Y+55),
M+"`G8VQA<W,G(#T^(&YU;&PL("=C86QL8F%C:R<@/3X@;G5L;"DI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1M<V<@/2!497AT7T9I;'1E<CHZ
M9FEL=&5R*"1M<V<L("=H=&UL,G1E>'0G*3L*("`@("`@("!]"B`@("!]"GT*
M"B\J($EF('1H:7,@:7,@=&AE(&9I<G-T('!A9V4@;&]A9"!F;W(@=&AI<R!C
M;VUP;W-E(&ET96TL(&%D9"!A=71O($)#0PH@*B!A9&1R97-S97,N("HO"FEF
M("AE;7!T>2@D<F5L;V%D960I("8F("@D86-T:6]N240@(3T@)V1R869T)RDI
M('L*("`@("1H96%D97);)V)C8R==(#T@34E-13HZ861D<D%R<F%Y,E-T<FEN
M9R@D:61E;G1I='DM/F=E=$)C8T%D9')E<W-E<R@I*3L*?0H*9F]R96%C:"`H
M87)R87DH)W1O)RP@)V-C)RP@)V)C8R<L("=S=6)J96-T)RD@87,@)'9A;"D@
M>PH@("`@:68@*&5M<'1Y*"1H96%D97);)'9A;%TI*2!["B`@("`@("`@)&AE
M861E<ELD=F%L72`](%5T:6PZ.F=E=$9O<FU$871A*"1V86PL(%]G971!9&1R
M97-S3&ES="@D=F%L*2D["B`@("!]"GT*"B1A;&Q?<VEG<R`]("1I9&5N=&ET
M>2T^9V5T06QL4VEG;F%T=7)E<R@I.PIF;W)E86-H("@D86QL7W-I9W,@87,@
M)&ED96YT(#T^("1S:6<I('L*("`@("1I9&5N=&ET:65S6R1I9&5N=%T@/2!A
M<G)A>2@D<VEG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M9&5N=&ET>2T^9V5T5F%L=64H)W-I9U]F:7)S="<L("1I9&5N="DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ED96YT:71Y+3YG971686QU
M92@G<V5N=%]M86EL7V9O;&1E<B<L("1I9&5N="DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&ED96YT:71Y+3YS879E4V5N=&UA:6PH)&ED
M96YT*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!-24U%.CIA
M9&1R07)R87DR4W1R:6YG*"1I9&5N=&ET>2T^9V5T0F-C061D<F5S<V5S*"1I
M9&5N="DI*3L*?0HD<VEG(#T@)&ED96YT:71Y+3YG9713:6=N871U<F4H*3L*
M"FEF("@D9V5T7W-I9R`F)B!I<W-E="@D;7-G*2`F)B`A96UP='DH)'-I9RDI
M('L*("`@(&EF("@D<G1E;6]D92D@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`D<VEG(#T@5&5X=%]&
M:6QT97(Z.F9I;'1E<B@D<VEG+"`G=&5X=#)H=&UL)RP@87)R87DH)W!A<G-E
M;&5V96PG(#T^(%1%6%1?2%1-3%]-24-23U],24Y+55),+"`G8VQA<W,G(#T^
M(&YU;&PL("=C86QL8F%C:R<@/3X@;G5L;"DI.PH@("`@?0H*("`@(&EF("@D
M:61E;G1I='DM/F=E=%9A;'5E*"=S:6=?9FER<W0G*2D@>PH@("`@("`@("1M
M<V<@/2`B7&XB("X@)'-I9R`N("1M<V<["B`@("!](&5L<V4@>PH@("`@("`@
M("1M<V<@+CT@(EQN(B`N("1S:6<["B`@("!]"GT*"B\J($1E9FEN92!S;VUE
M('9A<FEA8FQE<R!U<V5D(&EN('1H92!T96UP;&%T97,N("HO"B1T:6UE;W5T
M(#T@:6YI7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH*+RH@4F5L
M;V%D(&YL<RYP:'`@=&\@9V5T('1H92!T<F%N<VQA=&5D(&-H87)S970@;F%M
M97,N("HO"G)E<75I<F4@2$]21$5?0D%312`N("<O8V]N9FEG+VYL<RYP:'`G
M.PH*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G<F5D:7)E8W1?8V]M<&]S
M92<Z"F-A<V4@)W)E9&ER96-T7V5X<&%N9%]A9&1R)SH*("`@("1M86EL8F]X
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W1H:7-M86EL8F]X)RP@)&EM<%LG;6%I
M;&)O>"==*3L*("`@(')E<75I<F5?;VYC92!)35!?5$5-4$Q!5$53("X@)R]C
M;VUP;W-E+V-O;7!O<V5?97AP86YD+FIS)SL*("`@(')E<75I<F4@24U07U1%
M35!,051%4R`N("<O8V]M<&]S92]R961I<F5C="YI;F,G.PH@("`@8G)E86L[
M"@IC87-E("=S<&5L;%]C:&5C:R<Z"F-A<V4@)W-P96QL7V-H96-K7W-E;F0G
M.@IC87-E("=S<&5L;%]C:&5C:U]F;W)W87)D)SH*("`@(')E<75I<F5?;VYC
M92!)35!?5$5-4$Q!5$53("X@)R]C;VUP;W-E+W-P96QL:6YG+FIS)SL*("`@
M(')E<75I<F4@24U07U1%35!,051%4R`N("<O8V]M<&]S92]S<&5L;&EN9RYI
M;F,G.PH@("`@8G)E86L["@ID969A=6QT.@H@("`@+RH@5V4@;F5E9"!T;R!D
M969I;F4@)&YU;5]A='1A8VAM96YT<R!A;F0@)'5P;&]A9%]L:7-T(&%S(&ET
M(&ES('5S960@:6X*("`@("`@(&)O=&@@8V]M<&]S92YI;F,@86YD(&%T=&%C
M:&UE;G1S+FIS+B`J+PH@("`@:68@*"1I;7!;)V9I;&5?=7!L;V%D)UTI('L*
M("`@("`@("`D871T86-H;65N=',@/2`D:6UP7V-O;7!O<V4M/F%D9&ET:6]N
M86Q!='1A8VAM96YT<T%L;&]W960H*3L*("`@('T*"B`@("!R97%U:7)E7V]N
M8V4@24U07U1%35!,051%4R`N("<O8V]M<&]S92]C;VUP;W-E+FIS)SL*("`@
M(')E<75I<F5?;VYC92!)35!?5$5-4$Q!5$53("X@)R]C;VUP;W-E+V-O;7!O
M<V5?97AP86YD+FIS)SL*("`@(')E<75I<F4@24U07U1%35!,051%4R`N("<O
M8V]M<&]S92]C;VUP;W-E+FEN8R<["@H@("`@+RH@26YS97)T(&IA=F%S8W)I
M<'0@8V]D92X@*B\*("`@(&EF("@D:6UP6R=F:6QE7W5P;&]A9"==*2!["B`@
M("`@("`@<F5Q=6ER95]O;F-E($E-4%]414U03$%415,@+B`G+V-O;7!O<V4O
M871T86-H;65N=',N:G,G.PH@("`@?0H@("`@8G)E86L["GT*"B\J($]P96X@
M=&AE('!A<W-P:')A<V4@=VEN9&]W(&AE<F4N("HO"FEF("@D<&=P7W!A<W-P
M:')A<V5?9&EA;&]G*2!["B`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G<&]P
M=7`N:G,G*3L*("`@(&5C:&\@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CXG("X@)&EM<%]P9W`M/F=E=$I33W!E;E=I;D-O9&4H)V]P96Y?<&%S
M<W!H<F%S95]D:6%L;V<G+"`B;W!E;F5R+F9O8W5S*"D[;W!E;F5R+F1O8W5M
M96YT+F-O;7!O<V4N86-T:6]N240N=F%L=64])W-E;F1?;65S<V%G92<[;W!E
M;F5R+G5N:7%3=6)M:70H*3LB*2`N("<\+W-C<FEP=#XG.PI](&5L<V5I9B`H
M)'-M:6UE7W!A<W-P:')A<V5?9&EA;&]G*2!["B`@("!(;W)D93HZ861D4V-R
M:7!T1FEL92@G<&]P=7`N:G,G*3L*("`@(&5C:&\@)SQS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(CXG("X@)&EM<%]S;6EM92T^9V5T2E-/<&5N5VEN
M0V]D92@G;W!E;E]P87-S<&AR87-E7V1I86QO9R<L(")O<&5N97(N9F]C=7,H
M*3MO<&5N97(N9&]C=6UE;G0N8V]M<&]S92YA8W1I;VY)1"YV86QU93TG<V5N
M9%]M97-S86=E)SMO<&5N97(N=6YI<5-U8FUI="@I.R(I("X@)SPO<V-R:7!T
M/B<["GT*"G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O871T86-H;65N="YP
M:'``````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q
M,S`Q`#$P-#$W,S8R-S<P`#`R,#`T,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!I;7`O
M871T86-H;65N="YP:'`L=B`R+C4N,3`N,3`@,C`P-B\P,2\R-"`P-CHP,#HS
M-B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@06YD
M<F5W($-O;&5M86X@/&UE<F-U<GE`87!P:7-O;'5T:6]N<RYN970^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L
M+FAT;6PN"B`J"B`J(%1H:7,@9FEL92!S:&]U;&0@8F4@=&AE(&)A<VES(&9O
M<B!S97)V:6YG(&AO<W1E9"!A='1A8VAM96YT<RX@($ET"B`J('-H;W5L9"!F
M971C:"!T:&4@9FEL92!F<F]M('1H92!61E,@86YD(&9U;FYE;"!I="!T;R!T
M:&4@8VQI96YT"B`J('=I<VAI;F<@=&\@9&]W;FQO860@=&AE(&%T=&%C:&UE
M;G0N(%1H:7,@=VEL;"!A;&QO=R!F;W(@=&AE"B`J(&5X8VAA;F=E(&]F(&UA
M<W-I=F4@871T86-H;65N=',@=VET:&]U="!C875S:6YG(&UA:6P@<V5R=F5R
M(&AA=F]C+@H@*B\*"B\O(%-E="!U<"!I;FET:6%L(&EN8VQU9&5S+@HO+R!4
M:&ES(&1O97,@*FYO="H@:6YC;'5D92!)35`G<R!B87-E+G!H<"!B96-A=7-E
M('=E(&1O(&YO="!N965D('1O(&)E"B\O(&%U=&AE;G1I8V%T960@=&\@9V5T
M('1H92!F:6QE+B!-;W-T('5S97)S('=O;B=T('-E;F0@;&EN:V5D"B\O(&%T
M=&%C:&UE;G1S(&IU<W0@=&\@;W1H97(@24U0('5S97)S+@II9B`H(61E9FEN
M960H)TA/4D1%7T)!4T4G*2D@>PH@("`@0&1E9FEN92@G2$]21$5?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PI]"D!D969I;F4H)TE-4%]"
M05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=61E,N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUA9VEC+G!H<"<["B1R96=I
M<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*"D["B1R96=I<W1R>2T^:6UP
M;W)T0V]N9FEG*"=I;7`G*3L*"B1?<V5L9E]U<FP@/2!(;W)D93HZ<V5L9E5R
M;"AF86QS92P@=')U92P@=')U92D["@HO+R!,971S('-E92!I9B!W92!A<F4@
M979E;B!A8FQE('1O('-E;F0@=&AE('5S97(@86X@871T86-H;65N="X*:68@
M*"$D8V]N9ELG8V]M<&]S92==6R=L:6YK7V%T=&%C:&UE;G1S)UTI('L*("`@
M($AO<F1E.CIF871A;"A?*"),:6YK960@871T86-H;65N=',@87)E(&9O<F)I
M9&1E;BXB*2P@)%]S96QF7W5R;"P@7U],24Y%7U\I.PI]"@HO+R!'871H97(@
M<F5Q=6ER960@9F]R;2!V87)I86)L97,N"B1M86EL7W5S97(@/2!5=&EL.CIG
M971&;W)M1&%T82@G=2<I.PHD=&EM95]S=&%M<"`](%5T:6PZ.F=E=$9O<FU$
M871A*"=T)RD["B1F:6QE7VYA;64@/2!5=&EL.CIG971&;W)M1&%T82@G9B<I
M.PII9B`H(6ES<V5T*"1M86EL7W5S97(I('Q\("%I<W-E="@D=&EM95]S=&%M
M<"D@?'P@(6ES<V5T*"1F:6QE7VYA;64I('Q\"B`@("`D;6%I;%]U<V5R(#T]
M("<G('Q\("1T:6UE7W-T86UP(#T]("<G('Q\("1F:6QE7VYA;64@/3T@)R<I
M('L*("`@($AO<F1E.CIF871A;"A?*")4:&4@871T86-H;65N="!W87,@;F]T
M(&9O=6YD+B(I+`H@("`@("`@("1?<V5L9E]U<FPL(%]?3$E.15]?*3L*?0H*
M+R\@26YI=&EA;&EZ92!T:&4@5D93+@HD=F9S<F]O="`]("961E,Z.G-I;F=L
M971O;B@D8V]N9ELG=F9S)UU;)W1Y<&4G72P@2&]R9&4Z.F=E=$1R:79E<D-O
M;F9I9R@G=F9S)RP@)&-O;F9;)W9F<R==6R=T>7!E)UTI*3L*:68@*&ES7V$H
M)'9F<W)O;W0L("=014%27T5R<F]R)RDI('L*("`@($AO<F1E.CIF871A;"AS
M<')I;G1F*%\H(D-O=6QD(&YO="!C<F5A=&4@=&AE(%9&4R!B86-K96YD.B`E
M<R(I+"`D=F9S<F]O="T^9V5T365S<V%G92@I*2P@)%]S96QF7W5R;"P@7U],
M24Y%7U\I.PI]"@HO+R!#:&5C:R!I9B!T:&4@9FEL92!E>&ES=',N"B1M86EL
M7W5S97(@/2!B87-E;F%M92@D;6%I;%]U<V5R*3L*)'1I;65?<W1A;7`@/2!B
M87-E;F%M92@D=&EM95]S=&%M<"D["B1F:6QE7VYA;64@/2!E<V-A<&5S:&5L
M;&-M9"AB87-E;F%M92@D9FEL95]N86UE*2D["B1F=6QL7W!A=&@@/2!S<')I
M;G1F*"(N:&]R9&4O:6UP+V%T=&%C:&UE;G1S+R5S+R5D(BP@)&UA:6Q?=7-E
M<BP@)'1I;65?<W1A;7`I.PII9B`H(21V9G-R;V]T+3YE>&ES=',H)&9U;&Q?
M<&%T:"P@)&9I;&5?;F%M92DI('L*("`@($AO<F1E.CIF871A;"A?*")4:&4@
M<W!E8VEF:65D(&9I;&4@9&]E<R!N;W0@97AI<W0N(BDL("1?<V5L9E]U<FPL
M(%]?3$E.15]?*3L*?0H*+R\@0VAE8VL@=&\@<V5E(&EF('=E(&YE960@=&\@
M<V5N9"!A('9E<FEF:6-A=&EO;B!M97-S86=E+@II9B`H)&-O;F9;)V-O;7!O
M<V4G75LG;&EN:U]A='1A8VAM96YT<U]N;W1I9GDG72D@>PH@("`@:68@*"1V
M9G-R;V]T+3YE>&ES=',H)&9U;&Q?<&%T:"P@)&9I;&5?;F%M92`N("<N;F]T
M:69Y)RDI('L*("`@("`@("`D9&5L971E7VED(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V0G*3L*("`@("`@("`D<F5A9%]I9"`]("1V9G-R;V]T+3YR96%D*"1F
M=6QL7W!A=&@L("1F:6QE7VYA;64@+B`G+FYO=&EF>2<I.PH@("`@("`@(&EF
M("@A:7-?82@D<F5A9%]I9"P@)U!%05)?17)R;W(G*2`F)B`H)&1E;&5T95]I
M9"`]/2`D<F5A9%]I9"DI('L*("`@("`@("`@("`@)'9F<W)O;W0M/F1E;&5T
M949I;&4H)&9U;&Q?<&%T:"P@)&9I;&5?;F%M92D["B`@("`@("`@("`@("1V
M9G-R;V]T+3YD96QE=&5&:6QE*"1F=6QL7W!A=&@L("1F:6QE7VYA;64@+B`G
M+FYO=&EF>2<I.PH@("`@("`@("`@("!P<FEN=&8@*%\H(D%T=&%C:&UE;G0@
M)7,@9&5L971E9"XB*2P@)&9I;&5?;F%M92D["B`@("`@("`@("`@(&5X:70[
M"B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`O*B!#<F5A=&4@82!R
M86YD;VT@:61E;G1I9FEE<B!F;W(@=&AI<R!F:6QE+B`J+PH@("`@("`@("1I
M9"`](&)A<V5?8V]N=F5R="@D9FEL95]N86UE("X@;6EC<F]T:6UE*"DL(#$P
M+"`S-BD["B`@("`@("`@)')E<R`]("1V9G-R;V]T+3YW<FET941A=&$H)&9U
M;&Q?<&%T:"P@)&9I;&5?;F%M92`N("<N;F]T:69Y)R`L("1I9"P@=')U92D[
M"B`@("`@("`@:68@*"%I<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TAE861E<G,N<&AP
M)SL*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUE<W-A
M9V4N<&AP)SL*"B`@("`@("`@("`@("\J(%-E="!U<"!T:&4@;6%I;"!H96%D
M97)S(&%N9"!R96%D('1H92!L;V<@9FEL92X@*B\*("`@("`@("`@("`@)&US
M9U]H96%D97)S(#T@)FYE=R!-24U%7TAE861E<G,H*3L*("`@("`@("`@("`@
M)&US9U]H96%D97)S+3YA9&1296-E:79E9$AE861E<B@I.PH@("`@("`@("`@
M("`D;7-G7VAE861E<G,M/F%D9$UE<W-A9V5)9$AE861E<B@I.PH@("`@("`@
M("`@("`D;7-G7VAE861E<G,M/F%D9$%G96YT2&5A9&5R*"D["B`@("`@("`@
M("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=$871E)RP@9&%T92@G<B<I
M*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H)T9R;VTG
M+"`D;6%I;%]U<V5R*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1(
M96%D97(H)U1O)RP@)&UA:6Q?=7-E<BD["B`@("`@("`@("`@("1M<V=?:&5A
M9&5R<RT^861D2&5A9&5R*"=3=6)J96-T)RP@7R@B3F]T:69I8V%T:6]N.B!,
M:6YK960@871T86-H;65N="!D;W=N;&]A9&5D(BDI.PH*("`@("`@("`@("`@
M)&US9R`]("9N97<@34E-15]-97-S86=E*"D["B`@("`@("`@("`@("1M<V<M
M/G-E=%1Y<&4H)W1E>'0O<&QA:6XG*3L*("`@("`@("`@("`@)&US9RT^<V5T
M0VAA<G-E="A.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@("1M<V<M
M/G-E=$-O;G1E;G1S*%-T<FEN9SHZ=W)A<"AS<')I;G1F*%\H(EEO=7(@;&EN
M:V5D(&%T=&%C:&UE;G0@:&%S(&)E96X@9&]W;FQO861E9"!B>2!A="!L96%S
M="!O;F4@=7-E<BY<;EQN071T86-H;65N="!N86UE.B`E<UQN071T86-H;65N
M="!D871E.B`E<UQN7&Y#;&EC:R!O;B!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@
M<&5R;6%N96YT;'D@9&5L971E('1H92!A='1A8VAM96YT.EQN)7,B*2P@)&9I
M;&5?;F%M92P@9&%T92@G<B<L("1T:6UE7W-T86UP*2P@571I;#HZ861D4&%R
M86UE=&5R*$AO<F1E.CIS96QF57)L*'1R=64L(&9A;'-E+"!T<G5E*2P@)V0G
M+"`D:60I*2DI.PH*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1-24U%
M2&5A9&5R<R@D;7-G*3L*"B`@("`@("`@("`@("1M<V<M/G-E;F0H)&UA:6Q?
M=7-E<BP@)&US9U]H96%D97)S*3L*("`@("`@("!]"B`@("!]"GT*"B\O($9I
M;F0@=&AE(&9I;&4G<R!M:6UE+71Y<&4N"B1F:6QE7V1A=&$@/2`D=F9S<F]O
M="T^<F5A9"@D9G5L;%]P871H+"`D9FEL95]N86UE*3L*)&UI;65?='EP92`]
M($U)345?36%G:6,Z.F%N86QY>F5$871A*"1F:6QE7V1A=&$L(&ES<V5T*"1C
M;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UTI(#\@)&-O;F9;)VUI;64G75LG;6%G
M:6-?9&(G72`Z(&YU;&PI.PII9B`H)&UI;65?='EP92`]/3T@9F%L<V4I('L*
M("`@("1T>7!E(#T@34E-15]-86=I8SHZ9FEL96YA;654;TU)344H)&9I;&5?
M;F%M92P@9F%L<V4I.PI]"@HO+R!396YD('1H92!C;&EE;G0@=&AE(&9I;&4N
M"B1B<F]W<V5R+3YD;W=N;&]A9$AE861E<G,H)&9I;&5?;F%M92P@)&UI;65?
M='EP92P@9F%L<V4L('-T<FQE;B@D9FEL95]D871A*2D["F5C:&\@)&9I;&5?
M9&%T83L*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W9I97<N
M<&AP````````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q-#0Q,0`Q,#0Q-S,V,C<W,``P,38V-S$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@
M<V-R:7!T(&1I<W!L87ES(&$@<F5N9&5R960@34E-15]087)T(&]B:F5C="X*
M("H@5&AE(&9O;&QO=VEN9R!A<F4@<&]T96YT:6%L(%523"!P87)A;65T97)S
M('1H870@=V4@<VAO=6QD(&AO;F]R.@H@*B`@("=A8W1I;VY)1"<@+2T@5&AE
M(&%C=&EO;B!)1"!T;R!P97)F;W)M"B`J("`@("`M/B`G8V]M<&]S95]A='1A
M8VA?<')E=FEE=R<*("H@("`@("T^("=D;W=N;&]A9%]A;&PG"B`J("`@("`M
M/B`G9&]W;FQO861?871T86-H)PH@*B`@("`@+3X@)V1O=VYL;V%D7W)E;F1E
M<B<*("H@("`@("T^("=S879E7VUE<W-A9V4G"B`J("`@("`M/B`G=FEE=U]A
M='1A8V@G"B`J("`@("`M/B`G=FEE=U]S;W5R8V4G"B`J("`@)V-T>7!E)R`@
M("`M+2!4:&4@8V]N=&5N="UT>7!E('1O('5S92!I;G-T96%D(&]F('1H92!C
M;VYT96YT+71Y<&4*("H@("`@("`@("`@("`@("`@(&9O=6YD(&EN('1H92!O
M<FEG:6YA;"!-24U%7U!A<G0@;V)J96-T"B`J("`@)VED)R`@("`@("`M+2!4
M:&4@34E-12!P87)T('1O(&1I<W!L87D*("H@("`G:6YD97@G("`@("TM(%1H
M92!I;F1E>"!O9B!T:&4@;65S<V%G93L@;VYL>2!U<V5D(&9O<B!)35!?0V]N
M=&5N=',*("H@("`@("`@("`@("`@("`@(&]B:F5C=',*("H@("`G>FEP)R`@
M("`@("TM($1O=VYL;V%D(&EN("YZ:7`@9F]R;6%T/PH@*@H@*B`D2&]R9&4Z
M(&EM<"]V:65W+G!H<"QV(#(N,3DY+C0N.2`R,#`V+S`Q+S(W(#$Y.C0S.C(X
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@
M2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R
M;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J+PH*+RH@5V4@8V%N)W0@
M<F5G:7-T97(@=&AI<R!S97-S:6]N(&%S("=R96%D;VYL>2<@:68@=V4@87)E
M(&1O:6YG(&$*("H@)W9I97=?871T86-H)R!S:6YC92!S;VUE($U)345?1')I
M=F5R<R!M87D@;F5E9"!T;R!C<F5A=&4@=&5M<&]R87)Y(&-A8VAE"B`J(&9I
M;&5S('1O(&-O<G)E8W1L>2!G96YE<F%T92!L:6YK<RX@*B\*:68@*&ES<V5T
M*"1?1T546R=A8W1I;VY)1"==*2`F)B`D7T=%5%LG86-T:6]N240G72`A/2`G
M=FEE=U]A='1A8V@G*2!["B`@("`D<V5S<VEO;E]C;VYT<F]L(#T@)W)E861O
M;FQY)SL*?0H*)&YO7V-O;7!R97-S(#T@=')U93L*0&1E9FEN92@G24U07T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!)35!?0D%3
M12`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@
M)R]L:6(O34E-12]#;VYT96YT<RYP:'`G.PH*)&EN9&5X(#T@571I;#HZ9V5T
M1F]R;41A=&$H)VEN9&5X)RD["B1I9"`](%5T:6PZ.F=E=$9O<FU$871A*"=I
M9"<I.PHD86-T:6]N240@/2!5=&EL.CIG971&;W)M1&%T82@G86-T:6]N240G
M*3L*"B\J("=C;VUP;W-E7V%T=&%C:%]P<F5V:65W)R!D;V5S;B=T('5S92!)
M35!?0V]N=&5N=',@<VEN8V4@=&AE<F4@:7,@;F\*("H@24U!4"!M97-S86=E
M(&1A=&$@+2!R871H97(L('=E(&UU<W0@=7-E('1H92!)35!?0V]M<&]S92!O
M8FIE8W0@=&\*("H@9V5T('1H92!N96-E<W-A<GD@34E-15]087)T+B`J+PII
M9B`H)&%C=&EO;DE$(#T]("=C;VUP;W-E7V%T=&%C:%]P<F5V:65W)RD@>PH@
M("`@+RH@26YI=&EA;&EZ92!T:&4@24U07T-O;7!O<V4Z.B!O8FIE8W0N("HO
M"B`@("!R97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]#;VUP;W-E+G!H
M<"<["B`@("`D:6UP7V-O;7!O<V4@/2`F;F5W($E-4%]#;VUP;W-E*&%R<F%Y
M*"=C86-H94E$)R`]/B!5=&EL.CIG971&;W)M1&%T82@G;65S<V%G94-A8VAE
M)RDI*3L*("`@("1M:6UE(#T@)&EM<%]C;VUP;W-E+3YB=6EL9$%T=&%C:&UE
M;G0H)&ED*3L*"B`@("`O*B!#<F5A=&4@82!D=6UM>2!-24U%7T-O;G1E;G1S
M*"D@;V)J96-T('-O('=E(&-A;B!U<V4@=&AE('9I97<*("`@("`J(&-O9&4@
M8F5L;W<N("!4:&5N('5S92!T:&4@)W9I97=?871T86-H)R!H86YD;&5R('1O
M(&]U='!U="!T;PH@("`@("H@=&AE('5S97(N("HO"B`@("`D8V]N=&5N=',@
M/2`F;F5W($E-4%]#;VYT96YT<RAN97<@34E-15]-97-S86=E*"DI.PH@("`@
M)&%C=&EO;DE$(#T@)W9I97=?871T86-H)SL*?2!E;'-E('L*("`@("\J(%!R
M979E;G0@8FQI;F0@9F5T8VAI;F<@;V8@871T86-H;65N=',@=VET:&]U="!K
M;F]W:6YG('1H92!-24U%($E$+@H@("`@("H@26YD97@@*F-A;BH@8F4@96UP
M='D@*'1H:6YK(&5M8F5D9&5D($U)344@<&%R=',@+2!T:&5R92!I<R!N;PH@
M("`@("H@8V]R<F5S<&]N9&EN9R!M97-S86=E(&EN9&5X*2`M(&)U="!S964@
M8F5L;W<[(&ED(&-A;B!B92!P87)T(#`@*'=H;VQE"B`@("`@*B!M97-S86=E
M*2!S;R!J=7-T(&UA:V4@<W5R92!T:&%T(&ET)W,@<W!E8VEF:65D+B`J+PH@
M("`@:68@*"%I;E]A<G)A>2@D86-T:6]N240L(&%R<F%Y*"=S879E7VUE<W-A
M9V4G+"`G9&]W;FQO861?86QL)RDI"B`@("`@("`@)B8@:7-?;G5L;"@D:60I
M*2!["B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*B!'970@8V%C:&5D(&ET
M96TL(&EF(&%V86EL86)L92X@*B\*("`@(&EF("@A*"1C;VYT96YT<R`]("9)
M35!?0V]N=&5N=',Z.F=E=$-A8VAE*"DI*2!["B`@("`@("`@+RH@268@=V4@
M;6%K92!I="!T;R!H97)E('=I=&AO=70@86X@:6YD97@L('1H96X@<V]M971H
M:6YG(&ES(&)R;VME;@H@("`@("`@("`J('-I;F-E('1H97)E(&ES(&YO=&AI
M;F<@:6X@=&AE(&-A8VAE(&%N9"!W92!H879E(&YO('=A>2!T;R!C<F5A=&4*
M("`@("`@("`@*B!A('9I97=A8FQE(&]B:F5C="X@*B\*("`@("`@("!I9B`H
M96UP='DH)&EN9&5X*2D@>PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*
M("`@("`@("`D8V]N=&5N=',@/2`F24U07T-O;G1E;G1S.CIS:6YG;&5T;VXH
M)&EN9&5X("X@24U07TE$6%]315`@+B`D7U-%4U-)3TY;)VEM<"==6R=T:&ES
M;6%I;&)O>"==*3L*("`@('T*"B`@("!I9B`H(6EN7V%R<F%Y*"1A8W1I;VY)
M1"P@87)R87DH)V1O=VYL;V%D7V%T=&%C:"<L("=D;W=N;&]A9%]A;&PG+"`G
M<V%V95]M97-S86=E)RP@)W9I97=?<V]U<F-E)RDI*2!["B`@("`@("`@)&UI
M;64@/2`D8V]N=&5N=',M/F=E=$1E8V]D961-24U%4&%R="@D:60I.PH@("`@
M("`@(&EF("@H)&-T>7!E(#T@571I;#HZ9V5T1F]R;41A=&$H)V-T>7!E)RDI
M*2!["B`@("`@("`@("`@("1M:6UE+3YS9714>7!E*"1C='EP92D["B`@("`@
M("`@?0H@("`@?0I]"@HO*B!2=6X@=&AR;W5G:"!A8W1I;VX@:&%N9&QE<G,@
M*B\*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G9&]W;FQO861?86QL)SH*
M("`@("1T;W-A=F4@/2!A<G)A>2@I.PH@("`@)&AE861E<G,@/2`F)&-O;G1E
M;G1S+3YG971(96%D97)/8B@I.PH@("`@)&AE861E<G,M/F)U:6QD2&5A9&5R
M<R@I.PH@("`@)'II<&9I;&4@/2!T<FEM*"1H96%D97)S+3YG971686QU92@G
M<W5B:F5C="<I*3L*("`@(&EF("AE;7!T>2@D>FEP9FEL92DI('L*("`@("`@
M("`D>FEP9FEL92`](%\H(F%T=&%C:&UE;G1S+GII<"(I.PH@("`@?2!E;'-E
M('L*("`@("`@("`D>FEP9FEL92`N/2`G+GII<"<["B`@("!]"B`@("!F;W)E
M86-H("@D8V]N=&5N=',M/F=E=$1O=VYL;V%D06QL3&ES="@I(&%S("1V86PI
M('L*("`@("`@("`D;6EM92`]("1C;VYT96YT<RT^9V5T1&5C;V1E9$U)3450
M87)T*"1V86PI.PH@("`@("`@("1T;W-A=F5;72`](&%R<F%Y*"=D871A)R`]
M/B`D;6EM92T^9V5T0V]N=&5N=',H*2P@)VYA;64G(#T^("1M:6UE+3YG971.
M86UE*'1R=64L('1R=64I*3L*("`@('T*("`@(&EF("AI<U]A*"1C;VYT96YT
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@($AO<F1E.CIF871A;"@D8V]N
M=&5N=',L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]"@H@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]#;VUP<F5S<RYP:'`G.PH@("`@)&AO<F1E7V-O;7!R
M97-S(#T@)DAO<F1E7T-O;7!R97-S.CIS:6YG;&5T;VXH)WII<"<I.PH@("`@
M)&)O9'D@/2`D:&]R9&5?8V]M<')E<W,M/F-O;7!R97-S*"1T;W-A=F4I.PH@
M("`@)&)R;W=S97(M/F1O=VYL;V%D2&5A9&5R<R@D>FEP9FEL92P@)V%P<&QI
M8V%T:6]N+WII<"<L(&9A;'-E+"!S=')L96XH)&)O9'DI*3L*("`@(&5C:&\@
M)&)O9'D["B`@("!E>&ET.PH*8V%S92`G9&]W;FQO861?871T86-H)SH*8V%S
M92`G9&]W;FQO861?<F5N9&5R)SH*("`@('-W:71C:"`H)&%C=&EO;DE$*2![
M"B`@("!C87-E("=D;W=N;&]A9%]A='1A8V@G.@H@("`@("`@("\J($UA:V4@
M<W5R92!W92!G970@=&AE(&5N=&ER92!C;VYT96YT<R!O9B!T:&4@<&%R="X@
M*B\*("`@("`@("`D;6EM92`]("1C;VYT96YT<RT^9V5T1&5C;V1E9$U)3450
M87)T*"1I9"P@=')U92D["B`@("`@("`@)&)O9'D@/2`D;6EM92T^9V5T0V]N
M=&5N=',H*3L*("`@("`@("`D='EP92`]("1M:6UE+3YG9714>7!E*'1R=64I
M.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)V1O=VYL;V%D7W)E;F1E<B<Z
M"B`@("`@("`@)&)O9'D@/2`D8V]N=&5N=',M/G)E;F1E<DU)345087)T*"1M
M:6UE*3L*("`@("`@("`D='EP92`]("1C;VYT96YT<RT^9V5T34E-159I97=E
M<E1Y<&4H)&UI;64I.PH@("`@("`@(&)R96%K.PH@("`@?0H*("`@("1N86UE
M(#T@)&UI;64M/F=E=$YA;64H=')U92P@=')U92D["@H@("`@+RH@0V]M<')E
M<W,@;W5T<'5T/R`J+PH@("`@:68@*"@D86-T:6]N240@/3T@)V1O=VYL;V%D
M7V%T=&%C:"<I("8F(%5T:6PZ.F=E=$9O<FU$871A*"=Z:7`G*2D@>PH@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O0V]M<')E<W,N<&AP)SL*("`@("`@
M("`D:&]R9&5?8V]M<')E<W,@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L971O
M;B@G>FEP)RD["B`@("`@("`@)&)O9'D@/2`D:&]R9&5?8V]M<')E<W,M/F-O
M;7!R97-S*&%R<F%Y*&%R<F%Y*"=D871A)R`]/B`D8F]D>2P@)VYA;64G(#T^
M("1N86UE*2DI.PH@("`@("`@("1N86UE("X]("<N>FEP)SL*("`@("`@("`D
M='EP92`]("=A<'!L:6-A=&EO;B]Z:7`G.PH@("`@?0H@("`@)&)R;W=S97(M
M/F1O=VYL;V%D2&5A9&5R<R@D;F%M92P@)'1Y<&4L(&9A;'-E+"!S=')L96XH
M)&)O9'DI*3L*("`@(&5C:&\@)&)O9'D["B`@("!E>&ET.PH*8V%S92`G=FEE
M=U]A='1A8V@G.@H@("`@)&)O9'D@/2`D8V]N=&5N=',M/G)E;F1E<DU)3450
M87)T*"1M:6UE*3L*("`@("1T>7!E(#T@)&-O;G1E;G1S+3YG971-24U%5FEE
M=V5R5'EP92@D;6EM92D["B`@("`D8G)O=W-E<BT^9&]W;FQO861(96%D97)S
M*"1M:6UE+3YG971.86UE*'1R=64L('1R=64I+"`D='EP92P@=')U92P@<W1R
M;&5N*"1B;V1Y*2D["B`@("!E8VAO("1B;V1Y.PH@("`@97AI=#L*"F-A<V4@
M)W9I97=?<V]U<F-E)SH*("`@("1M<V<@/2`D8V]N=&5N=',M/F9U;&Q-97-S
M86=E5&5X="@I.PH@("`@)&)R;W=S97(M/F1O=VYL;V%D2&5A9&5R<R@G365S
M<V%G92!3;W5R8V4G+"`G=&5X="]P;&%I;B<L('1R=64L('-T<FQE;B@D;7-G
M*2D["B`@("!E8VAO("1M<V<["B`@("!E>&ET.PH*8V%S92`G<V%V95]M97-S
M86=E)SH*("`@(')E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TU)344O
M2&5A9&5R<RYP:'`G.PH@("`@)&EM<%]H96%D97)S(#T@)FYE=R!)35!?2&5A
M9&5R<R@D:6YD97@I.PH*("`@("1N86UE(#T@)W-A=F5D7VUE<W-A9V4G.PH@
M("`@:68@*"@D<W5B:F5C="`]("1I;7!?:&5A9&5R<RT^9V5T3V(H)W-U8FIE
M8W0G+"!T<G5E*2DI('L*("`@("`@("`D;F%M92`]('1R:6TH<')E9U]R97!L
M86-E*"<O6UY<=RTK7UPN(%TO)RP@)U\G+"`D<W5B:F5C="DL("<@7R<I.PH@
M("`@?0H*("`@(&EF("@A*"1F<F]M(#T@)&EM<%]H96%D97)S+3YG971&<F]M
M061D<F5S<R@I*2D@>PH@("`@("`@("1F<F]M(#T@)SP^)SL*("`@('T*("`@
M("1D871E(#T@<W1R9G1I;64H)R5A("5B("5D("5(.B5-.B53("59)RP@)&EM
M<%]H96%D97)S+3YG971/8B@G=61A=&4G*2D["B`@("`D8F]D>2`]("=&<F]M
M("<@+B`D9G)O;2`N("<@)R`N("1D871E("X@(EQN(B`N("1C;VYT96YT<RT^
M9G5L;$UE<W-A9V5497AT*"D["B`@("`D8F]D>2`]('-T<E]R97!L86-E*")<
M<EQN(BP@(EQN(BP@)&)O9'DI.PH*("`@("1B<F]W<V5R+3YD;W=N;&]A9$AE
M861E<G,H)&YA;64@+B`G+F5M;"<L("=M97-S86=E+W)F8S@R,B<L(&9A;'-E
M+"!S=')L96XH)&)O9'DI*3L*("`@(&5C:&\@)&)O9'D["B`@("!E>&ET.PI]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VEM<"]C;VYF:6<`````````````````````````````````````````
M````````````````````````````````````````````,#$R,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S``,#(T,S`R`"`R
M+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]I;7``````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+V%C;"YP:'``````````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,34T,@`Q,#0Q
M-S,V,C<W,``P,38T-C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:6UP+V%C;"YP:'`L
M=B`Q+C(S+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HT.2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#`M,C`P-B!#:')I<R!(87-T:64@/&EM<$!O86LM
M=V]O9"YC;RYU:SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=)35!?0D%3
M12<L(&1I<FYA;64H7U]&24Q%7U\I*3L*)&%U=&AE;G1I8V%T:6]N(#T@3U!?
M2$%,1D]014X["G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O1F]L9&5R+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O24U!4"]!0TPN<&AP)SL*"B1P<F5F
M<U]U<FP@/2!)35`Z.G!R969S55),*'1R=64I.PH*+RH@4F5D:7)E8W0@8F%C
M:R!T;R!T:&4@;W!T:6]N<R!S8W)E96X@:68@04-,(&ES(&YO="!E;F%B;&5D
M+B`J+PII9B`H)'!R969S+3YI<TQO8VME9"@G86-L)RD@?'P*("`@("$H:7-S
M970H)%]315-324].6R=I;7`G75LG86-L)UTI("8F"B`@("`@(&ES7V%R<F%Y
M*"1?4T534TE/3ELG:6UP)UU;)V%C;"==*2DI('L*("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H7R@B1F]L9&5R('-H87)I;F<@:7,@;F]T(&5N86)L960N(BDL
M("=H;W)D92YE<G)O<B<I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1P
M<F5F<U]U<FPI.PH@("`@97AI=#L*?0H*)'!A<F%M<R`](&%R<F%Y*`H@("`@
M)VAO<W1S<&5C)R`]/B`D7U-%4U-)3TY;)VEM<"==6R=S97)V97(G72P*("`@
M("=P;W)T)R`]/B`D7U-%4U-)3TY;)VEM<"==6R=P;W)T)UTL"B`@("`G<')O
M=&]C;VPG(#T^("1?4T534TE/3ELG:6UP)UU;)W!R;W1O8V]L)UTL"B`@("`G
M=7-E<FYA;64G(#T^("1?4T534TE/3ELG:6UP)UU;)W5S97(G72P*("`@("=P
M87-S=V]R9"<@/3X@4V5C<F5T.CIR96%D*%-E8W)E=#HZ9V5T2V5Y*"=I;7`G
M*2P@)%]315-324].6R=I;7`G75LG<&%S<R==*0HI.PH*:68@*&ES<V5T*"1?
M4T534TE/3ELG:6UP)UU;)V%C;"==6R=P87)A;7,G72DI('L*("`@("1P87)A
M;7,@/2!A<G)A>5]M97)G92@D<&%R86US+"`D7U-%4U-)3TY;)VEM<"==6R=A
M8VPG75LG<&%R86US)UTI.PI]"B1!0TQ$<FEV97(@/2!)34%07T%#3#HZ<VEN
M9VQE=&]N*"1?4T534TE/3ELG:6UP)UU;)V%C;"==6R=D<FEV97(G72P@)'!A
M<F%M<RD["@HO*B!#:&5C:R!S96QE8W1E9"!D<FEV97(@:7,@<W5P<&]R=&5D
M+B!2961I<F5C="!T;R!O<'1I;VYS('-C<F5E;B!W:71H"B`J(&5R<F]R(&UE
M<W-A9V4@:68@;F]T("HO"B1E<G)O<B`](&YU;&P["FEF("@A)$%#3$1R:79E
M<BT^:7-3=7!P;W)T960H*2D@>PH@("`@)&5R<F]R(#T@7R@B5&AI<R!S97)V
M97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(BD["GT@96QS
M92!["B`@("`D97)R;W(@/2`D04-,1')I=F5R+3YG971%<G)O<B@I.PI]"@II
M9B`H)&5R<F]R*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1E<G)O<BP@
M)VAO<F1E+F5R<F]R)RD["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'!R
M969S7W5R;"D["B`@("!E>&ET.PI]"@HD86-L(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V%C;"<I.PHD9F]L9&5R(#T@571I;#HZ9V5T1F]R;41A=&$H)V9O;&1E
M<B<I.PHD<')O=&5C=&5D("`]("1!0TQ$<FEV97(M/F=E=%!R;W1E8W1E9"@I
M.PHD<VAA<F5?=7-E<B`](%5T:6PZ.F=E=$9O<FU$871A*"=S:&%R95]U<V5R
M)RD["B1O:U]F;W)M(#T@=')U93L*"B\J(%)U;B!T:')O=6=H('1H92!A8W1I
M;VX@:&%N9&QE<G,N("HO"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A
M*"=A8W1I;VY)1"<I.PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=I;7!?
M86-L7W-E="<Z"B`@("!I9B`H(21S:&%R95]U<V5R*2!["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"A?*").;R!U<V5R('-P96-I9FEE9"XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@)&]K7V9O<FT@/2!F86QS93L*("`@('T*
M("`@(&EF("@A)&9O;&1E<BD@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H7R@B3F\@9F]L9&5R('-E;&5C=&5D+B(I+"`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("`D;VM?9F]R;2`](&9A;'-E.PH@("`@?0H@("`@:68@*&EN7V%R
M<F%Y*"1S:&%R95]U<V5R+"`D<')O=&5C=&5D*2D@>PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B4&5R;6ES<VEO;G,@9F]R('1H:7,@=7-E<B!C
M86YN;W0@8F4@8VAA;F=E9"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@
M)&]K7V9O<FT@/2!F86QS93L*("`@('T*"B`@("!I9B`H)&]K7V9O<FTI('L*
M("`@("`@("`D<F5S=6QT(#T@)$%#3$1R:79E<BT^8W)E871E04-,*"1F;VQD
M97(L("1S:&%R95]U<V5R+"`D86-L*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H)')E<W5L="D["B`@("`@("`@?2!E;'-E:68@*"%C;W5N="@D
M86-L*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN
M=&8H7R@B06QL(')I9VAT<R!O;B!F;VQD97(@7"(E<UPB('-U8V-E<W-F=6QL
M>2!R96UO=F5D(&9O<B!U<V5R(%PB)7-<(BXB*2P@)&9O;&1E<BP@)'-H87)E
M7W5S97(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")5<V5R
M(%PB)7-<(B!S=6-C97-S9G5L;'D@9VEV96X@=&AE('-P96-I9FEE9"!R:6=H
M=',@9F]R('1H92!F;VQD97(@7"(E<UPB+B(I+"`D<VAA<F5?=7-E<BP@)&9O
M;&1E<BDL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@?0H@("`@?0H@("`@
M8G)E86L["@IC87-E("=I;7!?86-L7V5D:70G.@H@("`@:68@*"$D<VAA<F5?
M=7-E<BD@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B3F\@=7-E
M<B!S<&5C:69I960N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("1O:U]F
M;W)M(#T@9F%L<V4["B`@("!]"B`@("!I9B`H(21F;VQD97(I('L*("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(DYO(&9O;&1E<B!S96QE8W1E9"XB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@)&]K7V9O<FT@/2!F86QS93L*
M("`@('T*("`@(&EF("AI;E]A<G)A>2@D<VAA<F5?=7-E<BP@)'!R;W1E8W1E
M9"DI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!E<FUI<W-I
M;VYS(&9O<B!T:&ES('5S97(@8V%N;F]T(&)E(&-H86YG960N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("1O:U]F;W)M(#T@9F%L<V4["B`@("!]"@H@
M("`@:68@*"1O:U]F;W)M*2!["B`@("`@("`@)')E<W5L="`]("1!0TQ$<FEV
M97(M/F5D:71!0TPH)&9O;&1E<BP@)'-H87)E7W5S97(L("1A8VPI.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S=6QT*3L*("`@("`@("!]
M"B`@("!]"B`@("!B<F5A:SL*?0H*)&EM<%]F;VQD97(@/2`F24U07T9O;&1E
M<CHZ<VEN9VQE=&]N*"D["B1R:6=H=',@/2`D04-,1')I=F5R+3YG9712:6=H
M=',H*3L*"FEF("AE;7!T>2@D9F]L9&5R*2D@>PH@("`@)&9O;&1E<B`]("=)
M3D)/6"<["GT*"FEF("AC;W5N="@D:6UP7V9O;&1E<BT^9FQI<W1?24U0*"DI
M*2!["B`@("`D;W!T:6]N<R`]($E-4#HZ9FQI<W1396QE8W0H)R<L('1R=64L
M(&%R<F%Y*"DL("1F;VQD97(I.PI]"@HD8W5R<E]A8VP@/2`D04-,1')I=F5R
M+3YG971!0TPH)&9O;&1E<BD["B1C86Y%9&ET(#T@)$%#3$1R:79E<BT^8V%N
M161I="@D9F]L9&5R+"`D7U-%4U-)3TY;)VEM<"==6R=U<V5R)UTI.PH*:68@
M*&ES7V$H)&-U<G)?86-L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*"1C=7)R7V%C;"P@)VAO<F1E7V5R<F]R)RD["B`@("`D
M8W5R<E]A8VP@/2!A<G)A>2@I.PI](&5L<V4@>PH@("`@+RH@4V5T('5P(&IA
M=F%S8W)I<'0@87)R87ES+B`J+PH@("`@:68@*&-O=6YT*"1C=7)R7V%C;"DI
M('L*("`@("`@("`D:G-?=7-E<B`]("<G.PH@("`@("`@(&9O<F5A8V@@*&%R
M<F%Y7VME>7,H)')I9VAT<RD@87,@)')I9VAT*2!["B`@("`@("`@("`@("1J
M<U]R:6=H=%LD<FEG:'1=(#T@)R<["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D8W5R<E]A8VP@87,@)&-U<G)?=7-E<B`]/B`D9W)A;G1E9"D@>PH@
M("`@("`@("`@("!I9B`H<W1R;&5N*"1J<U]U<V5R*2`^(#`I('L*("`@("`@
M("`@("`@("`@("1J<U]U<V5R("X]("<L("<["B`@("`@("`@("`@("`@("!F
M;W)E86-H("AA<G)A>5]K97ES*"1R:6=H=',I(&%S("1R:6=H="D@>PH@("`@
M("`@("`@("`@("`@("`@("1J<U]R:6=H=%LD<FEG:'1=("X]("<L("<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1J
M<U]U<V5R("X]("<B)R`N("1C=7)R7W5S97(@+B`G(B<["@H@("`@("`@("`@
M("!F;W)E86-H("AA<G)A>5]K97ES*"1R:6=H=',I(&%S("1R:6=H="D@>PH@
M("`@("`@("`@("`@("`@)&IS7W)I9VAT6R1R:6=H=%T@+CT@*&5M<'1Y*"1G
M<F%N=&5D6R1R:6=H=%TI*2`_("<B,"(G(#H@)R(Q(B<["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"GT*"G)E<75I<F5?;VYC92`G2&]R9&4O4')E
M9G,O54DN<&AP)SL*<F5Q=6ER92!)35!?0D%312`N("<O8V]N9FEG+W!R969S
M+G!H<"<["B1A<'`@/2`G:6UP)SL*"E!R969S7U5).CIG96YE<F%T94AE861E
M<B@I.PIR97%U:7)E($E-4%]414U03$%415,@+B`G+V%C;"]A8VPN:6YC)SL*
M<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@
M+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]T:')E860N<&AP````
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30R
M,3$`,3`T,3<S-C(W-S``,#$W,38T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EM<"]T
M:')E860N<&AP+'8@,BXQ,"XR+C$T(#(P,#8O,#(O,C$@,#<Z,S(Z,S8@<VQU
M<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@
M32!3;'5S87)Z(#QS;'5S87)Z0&UA:6PN8W5R96-A=&DN;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH
M=&UL+@H@*B\*"D!D969I;F4H)TE-4%]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RDI.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]B87-E+G!H<"<[
M"G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB+TE-05`N<&AP)SL*<F5Q
M=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O34E-12]#;VYT96YT<RYP:'`G
M.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]-24U%+TAE861E<G,N
M<&AP)SL*<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O36%I;&)O>"YP
M:'`G.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G+VQI8B]396%R8V@N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]496UP;&%T92YP:'`G.PH*+RH@5VAA
M="!M;V1E(&%R92!W92!I;C\*("H@1$5&055,5"\G=&AR96%D)R`M(%1H<F5A
M9"!M;V1E"B`J("=M<V=V:65W)R`M($UU;'1I<&QE(&UE<W-A9V4@=FEE=PH@
M*B\*)&UO9&4@/2!5=&EL.CIG971&;W)M1&%T82@G;6]D92<L("=T:')E860G
M*3L*"B1I;7!?;6%I;&)O>"`]("9)35!?36%I;&)O>#HZ<VEN9VQE=&]N*%5T
M:6PZ.F=E=$9O<FU$871A*"=I;F1E>"<I*3L*"B1E<G)O<B`](&9A;'-E.PII
M9B`H)&UO9&4@/3T@)W1H<F5A9"<I('L*("`@("\J(%1(4D5!1"!-3T1%.B!-
M86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&EN9&5X+B`J+PH@("`@:68@*"$D
M:6UP7VUA:6QB;W@M/FES5F%L:61);F1E>"@I*2!["B`@("`@("`@)&5R<F]R
M(#T@=')U93L*("`@('T*?2!E;'-E('L*("`@("\J($U31U9)15<@34]$13H@
M36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!L:7-T(&]F(&UE<W-A9V5S+B`J
M+PH@("`@)&-A8VAE240@/2!5=&EL.CIG971&;W)M1&%T82@G;7-G;&ES="<I
M.PH@("`@:68@*"$D8V%C:&5)1"D@>PH@("`@("`@("1E<G)O<B`]('1R=64[
M"B`@("!]"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY/8FIE8W1S
M+G!H<"<["B`@("`D8V%C:&5397-S(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S
M.CIS:6YG;&5T;VXH*3L*("`@("1M<V=L:7-T(#T@)&-A8VAE4V5S<RT^<75E
M<GDH)&-A8VAE240I.PH@("`@:68@*"1M<V=L:7-T*2!["B`@("`@("`@)&-A
M8VAE4V5S<RT^<V5T4')U;F5&;&%G*"1C86-H94E$+"!T<G5E*3L*("`@('T@
M96QS92!["B`@("`@("`@)&5R<F]R(#T@=')U93L*("`@('T*?0H*:68@*"1E
M<G)O<BD@>PH@("`@)&%C=&EO;DE$(#T@)VUE<W-A9V5?;6ES<VEN9R<["B`@
M("`D9G)O;5]M97-S86=E7W!A9V4@/2!T<G5E.PH@("`@)'-T87)T(#T@;G5L
M;#L*("`@(')E<75I<F4@24U07T)!4T4@+B`G+VUA:6QB;W@N<&AP)SL*("`@
M(&5X:70["GT*"B\J(%-E="!T:&4@8W5R<F5N="!T:6UE('IO;F4N("HO"DY,
M4SHZ<V5T5&EM95IO;F4H*3L*"B1I;7!?:6UA<"`]("9)35!?24U!4#HZ<VEN
M9VQE=&]N*"D["@HO*B!2=6X@=&AR;W5G:"!A8W1I;VX@:&%N9&QE<G,N("HO
M"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PIS
M=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=A9&1?861D<F5S<R<Z"B`@("`D
M8V]N=&%C=%]L:6YK(#T@24U0.CIA9&1!9&1R97-S*%5T:6PZ.F=E=$9O<FU$
M871A*"=A9&1R97-S)RDL(%5T:6PZ.F=E=$9O<FU$871A*"=N86UE)RDI.PH@
M("`@:68@*&ES7V$H)&-O;G1A8W1?;&EN:RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&-O;G1A8W1?;&EN:RD["B`@
M("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")%;G1R>2!<(B5S7"(@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!T
M:&4@861D<F5S<R!B;V]K(BDL("1C;VYT86-T7VQI;FLI+"`G:&]R9&4N<W5C
M8V5S<R<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@('T*("`@(&)R96%K
M.PI]"@HD=&ET;&4@/2`H)&UO9&4@/3T@)W1H<F5A9"<I(#\@7R@B5&AR96%D
M(%9I97<B*2`Z(%\H(DUU;'1I<&QE($UE<W-A9V4@5FEE=R(I.PIR97%U:7)E
M($E-4%]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*)&US9W,@
M/2`D=')E92`](&%R<F%Y*"D["B1R;W=C="`](#`["@IR97%U:7)E($E-4%]4
M14U03$%415,@+B`G+VUE;G4N:6YC)SL*24U0.CIS=&%T=7,H*3L*"B1S=6)J
M96-T(#T@)R<["B1P86=E7VQA8F5L(#T@24U0.CIG971,86)E;"@I.PH*:68@
M*"1M;V1E(#T]("=T:')E860G*2!["B`@("`D=&AR96%D;V(@/2`D:6UP7VUA
M:6QB;W@M/F=E=%1H<F5A9$]B*"D["B`@("`D:6YD97A?87)R87D@/2`D:6UP
M7VUA:6QB;W@M/F=E=$E-05!);F1E>"@I.PH@("`@)'1H<F5A9"`]("1T:')E
M861O8BT^9V5T5&AR96%D*"1I;F1E>%]A<G)A>5LG:6YD97@G72D["B`@("`D
M=&AR96%D=')E92`]("1T:')E861O8BT^9V5T5&AR96%D26UA9V54<F5E*"1T
M:')E860L(&9A;'-E*3L*("`@("1L;V]P7V%R<F%Y(#T@87)R87DH)&EM<%LG
M;6%I;&)O>"==(#T^("1T:')E860I.PI](&5L<V4@>PH@("`@)&QO;W!?87)R
M87D@/2!)35`Z.G!A<G-E26YD:6-E<TQI<W0H)&US9VQI<W0I.PI]"@IF;W)E
M86-H("@D;&]O<%]A<G)A>2!A<R`D;6)O>"`]/B`D:61X;&ES="D@>PH@("`@
M)&EM<%]I;6%P+3YC:&%N9V5-8F]X*"1M8F]X*3L*"B`@("!F;W)E86-H("@D
M:61X;&ES="!A<R`D:61X*2!["B`@("`@("`@+RH@1V5T('1H92!B;V1Y(&]F
M('1H92!M97-S86=E+B`J+PH@("`@("`@("1C=7)R7VUS9R`]("1C=7)R7W1R
M964@/2!A<G)A>2@I.PH@("`@("`@("1I;7!?;6%I;&)O>"T^<V5T3F5W26YD
M97@H)&ED>"D["B`@("`@("`@)&-O;G1E;G1S(#T@)DE-4%]#;VYT96YT<SHZ
M<VEN9VQE=&]N*"1I9'@@+B!)35!?24187U-%4"`N("1M8F]X*3L*("`@("`@
M("`D;6EM95]I9"`]("1C;VYT96YT<RT^9FEN9$)O9'DH*3L*("`@("`@("`D
M;6EM95]P87)T(#T@)&-O;G1E;G1S+3YG971$96-O9&5D34E-15!A<G0H)&UI
M;65?:60I.PH@("`@("`@(&EF("@D8V]N=&5N=',M/F-A;D1I<W!L87E);FQI
M;F4H)&UI;65?<&%R="DI('L*("`@("`@("`@("`@)&-U<G)?;7-G6R=B;V1Y
M)UT@/2`D8V]N=&5N=',M/G)E;F1E<DU)345087)T*"1M:6UE7W!A<G0I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C=7)R7VUS9ULG8F]D>2==
M(#T@)SQE;3XG("X@7R@B5&AE<F4@:7,@;F\@=&5X="!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(I("X@)SPO96T^)SL*("`@("`@("!]"B`@("`@
M("`@)&-U<G)?;7-G6R=I9'@G72`]("1I9'@["@H@("`@("`@("\J($=E="!H
M96%D97)S(&9O<B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D:&5A9&5R<R`]
M("9N97<@24U07TAE861E<G,H)&ED>"D["B`@("`@("`@)&AE861E<G,M/F)U
M:6QD2&5A9&5R<R@I.PH@("`@("`@("1H96%D97)S+3YS971686QU94)Y1G5N
M8W1I;VXH)V1A=&4G+"!A<G)A>2@G;FPR8G(G+"!A<G)A>2@D:&5A9&5R<RP@
M)V%D9$QO8V%L5&EM92<I+"`G:'1M;'-P96-I86QC:&%R<R<I*3L*("`@("`@
M("`D9G)O;2`]("1H96%D97)S+3YG971686QU92@G9G)O;2<I.PH@("`@("`@
M("1H96%D97)S+3YB=6EL9$%D9')E<W-,:6YK<R@G9G)O;2<L($AO<F1E.CIS
M96QF57)L*'1R=64I+"!T<G5E+"!T<G5E*3L*("`@("`@("`D8W5R<E]M<V=;
M)V1A=&4G72`]("1H96%D97)S+3YG971686QU92@G9&%T92<I.PH@("`@("`@
M("1C=7)R7VUS9ULG9G)O;2==(#T@)&AE861E<G,M/F=E=%9A;'5E*"=F<F]M
M)RD["B`@("`@("`@)'-U8FIE8W1?:&5A9&5R(#T@)&AE861E<G,M/F=E=%9A
M;'5E*"=S=6)J96-T)RD["B`@("`@("`@:68@*"1M;V1E(#T]("=T:')E860G
M*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D<W5B:F5C="DI('L*("`@("`@
M("`@("`@("`@("1S=6)J96-T(#T@<')E9U]R97!L86-E*"<O7G)E.EQS*B]I
M)RP@)R<L("1S=6)J96-T7VAE861E<BD["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@)&-U<G)?;7-G6R=S=6)J96-T)UT@/2`D<W5B:F5C=%]H
M96%D97(["@H@("`@("`@("\J($-R96%T92!L:6YK<R!T;R!C=7)R96YT(&UE
M<W-A9V4@86YD(&UA:6QB;W@N("HO"B`@("`@("`@:68@*"1M;V1E(#T]("=T
M:')E860G*2!["B`@("`@("`@("`@("1C=7)R7VUS9ULG;&EN:R==(#T@2&]R
M9&4Z.G=I9&=E="@G(V1I<W!L87DG+"!?*")"86-K('1O(%1H<F5A9"!$:7-P
M;&%Y(BDL("=W:61G970G+"`G)RP@)R<L(%\H(D)A8VL@=&\@5&AR96%D($1I
M<W!L87DB*2P@=')U92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&-U<G)?;7-G6R=L:6YK)UT@/2!(;W)D93HZ=VED9V5T*"<C9&ES<&QA>2<L
M(%\H(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6:65W($EN9&5X(BDL("=W
M:61G970G+"`G)RP@)R<L(%\H(D)A8VL@=&\@375L=&EP;&4@365S<V%G92!6
M:65W($EN9&5X(BDL('1R=64I.PH@("`@("`@('T*("`@("`@("`D8W5R<E]M
M<V=;)VQI;FLG72`N/2`G('P@)R`N($AO<F1E.CIW:61G970H571I;#HZ861D
M4&%R86UE=&5R*$E-4#HZ9V5N97)A=&5396%R8VA5<FPH)VUE<W-A9V4N<&AP
M)RP@)&UB;W@I+"!A<G)A>2@G:6YD97@G(#T^("1I9'@I*2P@7R@B1V\@=&\@
M365S<V%G92(I+"`G=VED9V5T)RP@)R<L("<G+"!?*")';R!T;R!-97-S86=E
M(BDL('1R=64I.PH@("`@("`@("1C=7)R7VUS9ULG;&EN:R==("X]("<@?"`G
M("X@2&]R9&4Z.G=I9&=E="A5=&EL.CIA9&1087)A;65T97(H24U0.CIG96YE
M<F%T95-E87)C:%5R;"@G;6%I;&)O>"YP:'`G+"`D;6)O>"DL(&%R<F%Y*"=S
M=&%R="<@/3X@)&EM<%]M86EL8F]X+3YG971-97-S86=E26YD97@H*2DI+"!S
M<')I;G1F*%\H(D)A8VL@=&\@)7,B*2P@)'!A9V5?;&%B96PI+"`G=VED9V5T
M)RP@)R<L("<G+"!S<')I;G1F*%\H(D)A8VL@=&\@)7,B*2P@)'!A9V5?;&%B
M96PI+"!T<G5E*3L*"B`@("`@("`@)&-U<G)?=')E95LG8VQA<W,G72`]("@K
M*R1R;W=C="`E(#(I(#\@)W1E>'0G(#H@)VET96TP)SL*("`@("`@("`D8W5R
M<E]T<F5E6R=S=6)J96-T)UT@/2`H*"1M;V1E(#T]("=T:')E860G*2`_("1T
M:')E861T<F5E6R1I9'A=(#H@;G5L;"D@+B`G("<@+B!(;W)D93HZ;&EN:R@G
M(R<@+B`D:61X*2`N("1S=6)J96-T7VAE861E<B`N("<\+V$^("@G("X@:'1M
M;'-P96-I86QC:&%R<R@D9G)O;2D@+B`G*2<["@H@("`@("`@("1M<V=S6UT@
M/2`D8W5R<E]M<V<["B`@("`@("`@)'1R965;72`]("1C=7)R7W1R964["B`@
M("!]"GT*"B\J($9L86<@;65S<V%G97,@87,@<V5E;BX@*B\*<F5Q=6ER95]O
M;F-E($E-4%]"05-%("X@)R]L:6(O365S<V%G92YP:'`G.PHD:6UP7VUE<W-A
M9V4@/2`F24U07TUE<W-A9V4Z.G-I;F=L971O;B@I.PHD:6UP7VUE<W-A9V4M
M/F9L86<H)UQ<4T5%3B<L("1L;V]P7V%R<F%Y*3L*"B1T96UP;&%T92`]("9N
M97<@2&]R9&5?5&5M<&QA=&4H*3L*)'1E;7!L871E+3YS970H)V1A=&5?<W1R
M:6YG)RP@7R@B1&%T92(I+"!T<G5E*3L*)'1E;7!L871E+3YS970H)V9R;VU?
M<W1R:6YG)RP@7R@B1G)O;2(I+"!T<G5E*3L*)'1E;7!L871E+3YS970H)W-U
M8FIE8W1?<W1R:6YG)RP@7R@B4W5B:F5C="(I+"!T<G5E*3L*)'1E;7!L871E
M+3YS970H)W-U8FIE8W0G+"`H)&UO9&4@/3T@)W1H<F5A9"<I(#\@0&AT;6QS
M<&5C:6%L8VAA<G,H)'-U8FIE8W0L($5.5%]#3TU0050L($Y,4SHZ9V5T0VAA
M<G-E="@I*2`Z('-P<FEN=&8H7R@B)60@365S<V%G97,B*2P@8V]U;G0H)&US
M9W,I*2D["B1T96UP;&%T92T^<V5T*"=H96%D97(G+"`H)&UO9&4@/3T@)W1H
M<F5A9"<I(#\@7R@B5&AR96%D($1I<W!L87DB*2`Z(%\H(DUU;'1I<&QE($UE
M<W-A9V4@5FEE=R(I*3L*)'1E;7!L871E+3YS970H)VUE<W-A9V5S)RP@)&US
M9W,L('1R=64I.PHD=&5M<&QA=&4M/G-E="@G=')E92<L("1T<F5E+"!T<G5E
M*3L*"F5C:&\@)'1E;7!L871E+3YF971C:"A)35!?5$5-4$Q!5$53("X@)R]T
M:')E860O=&AR96%D+FAT;6PG*3L*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G
M=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;7`O
M=&5S="YP:'``````````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(T-C`U`#$P-#$W,S8R-S<P`#`Q-C<P-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!I;7`O=&5S="YP:'`L=B`Q+C,S+C8N.2`R,#`V+S`R+S(V(#(R
M.C0P.C0T('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!"<F5N="!*+B!.;W)D<75I<W0@/&)J;D!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ
M;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*+RH@26YC;'5D92!(
M;W)D92=S(&-O<F4N<&AP(&9I;&4N("HO"FEN8VQU9&5?;VYC92`G+BXO;&EB
M+V-O<F4N<&AP)SL*"B\J(%=E('-H;W5L9"!H879E(&QO861E9"!T:&4@4W1R
M:6YG(&-L87-S+"!F<F]M('1H92!(;W)D95]5=&EL"B`J('!A8VMA9V4L(&EN
M(&-O<F4N<&AP+B!)9B!3=')I;F<Z.B!I<VXG="!D969I;F5D+"!T:&5N('=E
M)W)E(&YO=`H@*B!F:6YD:6YG('-O;64@8W)I=&EC86P@;&EB<F%R:65S+B`J
M+PII9B`H(6-L87-S7V5X:7-T<R@G4W1R:6YG)RDI('L*("`@(&5C:&\@)SQB
M<B`O/CQS<&%N('-T>6QE/2)C;VQO<CH@<F5D.R!F;VYT+7-I>F4Z(#$X<'@[
M(&9O;G0M=V5I9VAT.B!B;VQD.R(^5&AE($AO<F1E7U5T:6P@<&%C:V%G92!W
M87,@;F]T(&9O=6YD+B!)9B!02%!<)W,@97)R;W)?<F5P;W)T:6YG('-E='1I
M;F<@:7,@:&EG:"!E;F]U9V@L('1H97)E('-H;W5L9"!B92!E<G)O<B!M97-S
M86=E<R!P<FEN=&5D(&%B;W9E('1H870@;6%Y(&AE;'`@>6]U(&EN(&1E8G5G
M9VEN9R!T:&4@<')O8FQE;2X@268@>6]U(&%R92!S:6UP;'D@;6ES<VEN9R!T
M:&5S92!F:6QE<RP@=&AE;B!Y;W4@;F5E9"!T;R!G970@=&AE(#QA(&AR968]
M(FAT='`Z+R]C=G,N:&]R9&4N;W)G+V-V<RYP:'`O9G)A;65W;W)K(CYF<F%M
M97=O<FL\+V$^(&UO9'5L92!F<F]M(#QA(&AR968](FAT='`Z+R]H;W)D92YO
M<F<O<V]U<F-E+R(^2&]R9&4@0U93/"]A/BP@86YD(&EN<W1A;&P@=&AE('!A
M8VMA9V5S(&EN(&ET('=I=&@@=&AE(&EN<W1A;&PM<&%C:V%G97,N<&AP('-C
M<FEP="X\+W-P86X^)SL*("`@(&5X:70["GT*"B\J($EN:71I86QI>F4@=&AE
M($AO<F1E7U1E<W0Z.B!C;&%S<RX@*B\*:68@*"$H0&ES7W)E861A8FQE*"<N
M+B]L:6(O5&5S="YP:'`G*2DI('L*("`@(&5C:&\@)T524D]2.B!9;W4@;75S
M="!I;G-T86QL($AO<F1E(&)E9F]R92!R=6YN:6YG('1H:7,@<V-R:7!T+B<[
M"B`@("!E>&ET.PI]"G)E<75I<F5?;VYC92`G+BXO;&EB+U1E<W0N<&AP)SL*
M)&AO<F1E7W1E<W0@/2`F;F5W($AO<F1E7U1E<W0["@HO*B!)35`@=F5R<VEO
M;BX@*B\*)&UO9'5L92`]("=)35`G.PIR97%U:7)E7V]N8V4@)RXO;&EB+W9E
M<G-I;VXN<&AP)SL*)&UO9'5L95]V97)S:6]N(#T@24U07U9%4E-)3TX["@IR
M97%U:7)E(%1%4U1?5$5-4$Q!5$53("X@)VAE861E<BYI;F,G.PIR97%U:7)E
M(%1%4U1?5$5-4$Q!5$53("X@)W9E<G-I;VXN:6YC)SL*"B\J($1I<W!L87D@
M=F5R<VEO;G,@;V8@;W1H97(@2&]R9&4@87!P;&EC871I;VYS+B`J+PHD87!P
M7VQI<W0@/2!A<G)A>2@*("`@("=G;VQL96TG(#T^(&%R<F%Y*`H@("`@("`@
M("=E<G)O<B<@/3X@)T=O;&QE;2!P<F]V:61E<R!A8V-E<W,@=&\@;&]C86P@
M5D93(&9I;&5S>7-T96US('1O(&%T=&%C:"!F:6QE<RXG+`H@("`@("`@("=V
M97)S:6]N)R`]/B`G,2XP)PH@("`@*2P*("`@("=I;F=O)R`]/B!A<G)A>2@*
M("`@("`@("`G97)R;W(G(#T^("=);F=O('!R;W9I9&5S(&)A<VEC(&UA:6P@
M9FEL=&5R:6YG(&-A<&%B:6QI=&EE<R!T;R!)35`N)RP*("`@("`@("`G=F5R
M<VEO;B<@/3X@)S$N,"<*("`@("DL"B`@("`G;F%G)R`]/B!A<G)A>2@*("`@
M("`@("`G97)R;W(G(#T^("=.86<@86QL;W=S('1A<VMS('1O(&)E(&1I<F5C
M=&QY(&-R96%T960@9G)O;2!E+6UA:6P@9&%T82XG+`H@("`@("`@("=V97)S
M:6]N)R`]/B`G,BXP)PH@("`@*2P*("`@("=T=7)B82<@/3X@87)R87DH"B`@
M("`@("`@)V5R<F]R)R`]/B`G5'5R8F$@<')O=FED97,@861D<F5S<V)O;VLO
M8V]N=&%C=',@8V%P86)I;&ET:65S('1O($E-4"XG+`H@("`@("`@("=V97)S
M:6]N)R`]/B`G,BXP)PH@("`@*0HI.PHD87!P7V]U='!U="`]("1H;W)D95]T
M97-T+3YR97%U:7)E9$%P<$-H96-K*"1A<'!?;&ES="D["@H_/@H\:#$^3W1H
M97(@2&]R9&4@07!P;&EC871I;VYS/"]H,3X*/'5L/@H@("`@/#]P:'`@96-H
M;R`D87!P7V]U='!U="`_/@H\+W5L/@H\/W!H<`H*+RH@1&ES<&QA>2!02%`@
M5F5R<VEO;B!I;F9O<FUA=&EO;BX@*B\*)'!H<%]I;F9O(#T@)&AO<F1E7W1E
M<W0M/F=E=%!H<%9E<G-I;VY);F9O<FUA=&EO;B@I.PIR97%U:7)E(%1%4U1?
M5$5-4$Q!5$53("X@)W!H<%]V97)S:6]N+FEN8R<["@HO*B!02%`@;6]D=6QE
M<RX@*B\*)&UO9'5L95]L:7-T(#T@87)R87DH"B`@("`G:6UA<"<@/3X@87)R
M87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=)34%0(%-U<'!O<G0G+`H@("`@
M("`@("=E<G)O<B<@/3X@)TE-4"!R97%U:7)E<R!T:&4@:6UA<"!M;V1U;&4@
M=&\@:6YT97)A8W0@=VET:"!T:&4@;6%I;"!S97)V97(N("!)="!I<R!R97%U
M:7)E9"!E=F5N(&EF('EO=2!O;FQY('5S92!P;W`S(&%C8V5S<RXG+`H@("`@
M("`@("=F871A;"<@/3X@=')U90H@("`@*2P*("`@("=O<&5N<W-L)R`]/B!A
M<G)A>2@*("`@("`@("`G9&5S8W)I<"<@/3X@)T]P96Y34TP@4W5P<&]R="<L
M"B`@("`@("`@)V5R<F]R)R`]/B`G5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E
M<75I<F5D('1O('5S92!3+TU)344@:6X@24U0+B!#;VUP:6QE(%!(4"!W:71H
M(#QC;V1E/BTM=VET:"UO<&5N<W-L/"]C;V1E/B!T;R!A8W1I=F%T92XG+`H@
M("`@("`@("=F871A;"<@/3X@9F%L<V4*("`@("D**3L*"B\J(%!(4"!S971T
M:6YG<RX@*B\*)'-E='1I;F=?;&ES="`](&%R<F%Y*`H@("`@)V9I;&5?=7!L
M;V%D<R<@(#T^("!A<G)A>2@*("`@("`@("`G<V5T=&EN9R<@/3X@=')U92P*
M("`@("`@("`G97)R;W(G(#T^("=F:6QE7W5P;&]A9',@;75S="!B92!E;F%B
M;&5D('1O('5S92!V87)I;W5S(&9E871U<F5S(&]F($E-4"X@4V5E('1H92!)
M3E-404Q,(&9I;&4@9F]R(&UO<F4@:6YF;W)M871I;VXN)PH@("`@*0HI.PH*
M+RH@24U0(&-O;F9I9W5R871I;VX@9FEL97,N("HO"B1F:6QE7VQI<W0@/2!A
M<G)A>2@*("`@("=C;VYF:6<O8V]N9BYP:'`G(#T^("=4:&4@9FEL92`\8V]D
M93XN+V-O;F9I9R]C;VYF+G!H<#PO8V]D93X@87!P96%R<R!T;R!B92!M:7-S
M:6YG+B!9;W4@;75S="!G96YE<F%T92!T:&ES(&9I;&4@87,@86X@861M:6YI
M<W1R871O<B!V:6$@2&]R9&4N("!3964@:&]R9&4O9&]C<R])3E-404Q,+B<L
M"B`@("`G8V]N9FEG+VUI;65?9')I=F5R<RYP:'`G(#T^(&YU;&PL"B`@("`G
M8V]N9FEG+W!R969S+G!H<"<@/3X@;G5L;"P*("`@("=C;VYF:6<O<V5R=F5R
M<RYP:'`G(#T^(&YU;&P**3L*"B\J(%!%05(@;6]D=6QE<RX@*B\*)'!E87)?
M;&ES="`](&%R<F%Y*`H@("`@)TA45%!?4F5Q=65S="<@/3X@87)R87DH"B`@
M("`@("`@)W!A=&@G(#T^("=(5%10+U)E<75E<W0N<&AP)RP*("`@("`@("`G
M97)R;W(G(#T^("=4:&4@2%1-3"!C;VUP;W-I=&EO;B!M;V1E(')E<75I<F5S
M($A45%!?4F5Q=65S="XG"B`@("`I+`H@("`@)T%U=&A?4T%33"<@/3X@87)R
M87DH"B`@("`@("`@)W!A=&@G(#T^("=!=71H+U-!4TPN<&AP)RP*("`@("`@
M("`G97)R;W(G(#T^("=)9B!Y;W5R($E-05`@<V5R=F5R('5S97,@0U)!32U-
M1#4@;W(@1$E'15-4+4U$-2!A=71H96YT:6-A=&EO;BP@=&AI<R!M;V1U;&4@
M:7,@<F5Q=6ER960N)PH@("`@*0HI.PH*+RH@1V5T('1H92!S=&%T=7,@;W5T
M<'5T(&YO=RX@*B\*)&UO9'5L95]O=71P=70@/2`D:&]R9&5?=&5S="T^<&AP
M36]D=6QE0VAE8VLH)&UO9'5L95]L:7-T*3L*)'-E='1I;F=?;W5T<'5T(#T@
M)&AO<F1E7W1E<W0M/G!H<%-E='1I;F=#:&5C:R@D<V5T=&EN9U]L:7-T*3L*
M)&9I;&5?;W5T<'5T(#T@)&AO<F1E7W1E<W0M/G)E<75I<F5D1FEL94-H96-K
M*"1F:6QE7VQI<W0I.PHD<&5A<E]O=71P=70@/2`D:&]R9&5?=&5S="T^4$5!
M4DUO9'5L94-H96-K*"1P96%R7VQI<W0I.PH*/SX*"CQH,3Y02%`@36]D=6QE
M($-A<&%B:6QI=&EE<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)&UO9'5L
M95]O=71P=70@/SX*/"]U;#X*"CQH,3Y-:7-C96QL86YE;W5S(%!(4"!3971T
M:6YG<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)'-E='1I;F=?;W5T<'5T
M(#\^"CPO=6P^"@H\:#$^4F5Q=6ER960@24U0($-O;F9I9W5R871I;VX@1FEL
M97,\+V@Q/@H\=6P^"B`@("`\/W!H<"!E8VAO("1F:6QE7V]U='!U="`_/@H\
M+W5L/@H*/&@Q/E!%05(\+V@Q/@H\=6P^"B`@("`\/W!H<"!E8VAO("1P96%R
M7V]U='!U="`_/@H\+W5L/@H*/&@Q/E!(4"!-86EL(%-E<G9E<B!3=7!P;W)T
M(%1E<W0\+V@Q/@H\/W!H<`H*)'-E<G9E<B`](&ES<V5T*"1?4$]35%LG<V5R
M=F5R)UTI(#\@)%]03U-46R=S97)V97(G72`Z("<G.PHD<&]R="`](&ES<V5T
M*"1?4$]35%LG<&]R="==*2`_("1?4$]35%LG<&]R="==(#H@)R<["B1U<V5R
M(#T@:7-S970H)%]03U-46R=U<V5R)UTI(#\@)%]03U-46R=U<V5R)UT@.B`G
M)SL*)'!A<W-W9"`](&ES<V5T*"1?4$]35%LG<&%S<W=D)UTI(#\@)%]03U-4
M6R=P87-S=V0G72`Z("<G.PHD='EP92`](&ES<V5T*"1?4$]35%LG<V5R=F5R
M7W1Y<&4G72D@/R`D7U!/4U1;)W-E<G9E<E]T>7!E)UT@.B`G)SL*"FEF("@A
M96UP='DH)'-E<G9E<BD@)B8@(65M<'1Y*"1U<V5R*2`F)B`A96UP='DH)'!A
M<W-W9"D@)B8@(65M<'1Y*"1T>7!E*2D@>PH@("`@:68@*"1T>7!E(#T]("=P
M;W`G*2!["B`@("`@("`@)&-O;FX@/2!A<G)A>2@*("`@("`@("`@("`@)W!O
M<#,G(#T^(#$Q,"P*("`@("`@("`@("`@)W!O<#,O;F]T;',G(#T^(#$Q,"P*
M("`@("`@("`@("`@)W!O<#,O<W-L)R`]/B`Y.34L"B`@("`@("`@("`@("=P
M;W`S+W-S;"]N;W9A;&ED871E+6-E<G0G(#T^(#DY-2P*("`@("`@("`@("`@
M)W!O<#,O=&QS+VYO=F%L:61A=&4M8V5R="<@/3X@,3$P"B`@("`@("`@*3L*
M("`@('T@96QS92!["B`@("`@("`@)&-O;FX@/2!A<G)A>2@*("`@("`@("`@
M("`@)VEM87`G(#T^(#$T,RP*("`@("`@("`@("`@)VEM87`O;F]T;',G(#T^
M(#$T,RP*("`@("`@("`@("`@)VEM87`O<W-L)R`]/B`Y.3,L"B`@("`@("`@
M("`@("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G(#T^(#DY,RP*("`@("`@
M("`@("`@)VEM87`O=&QS+VYO=F%L:61A=&4M8V5R="<@/3X@,30S"B`@("`@
M("`@*3L*("`@('T*"B`@("`D<W5C8V5S<R`](&%R<F%Y*"D["@H@("`@96-H
M;R`B/'-T<F]N9SY!='1E;7!T:6YG('1O(&%U=&]M871I8V%L;'D@9&5T97)M
M:6YE('1H92!C;W)R96-T(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!F;W(@>6]U
M<B!S97)V97(Z/"]S=')O;F<^7&XB.PH*("`@(&9O<F5A8V@@*"1C;VYN(&%S
M("1K97D@/3X@)'9A;"D@>PH@("`@("`@("1S97)V97)?<&]R="`]("%E;7!T
M>2@D<&]R="D@/R`D<&]R="`Z("1V86P["B`@("`@("`@)&UB;F%M92`]("=[
M)R`N("1S97)V97(@+B`G.B<@+B`D<V5R=F5R7W!O<G0@+B`G+R<@+B`D:V5Y
M("X@)WU)3D)/6"<["B`@("`@("`@96-H;R`B/'5L/CQL:3X\96T^5')Y:6YG
M('!R;W1O8V]L(#QT=#XB("X@)&ME>2`N("(\+W1T/BP@4&]R="`\='0^(B`N
M("1S97)V97)?<&]R="`N("(\+W1T/CH\+V5M/EQN/&)L;V-K<75O=&4^7&XB
M.PH@("`@("`@("1M8F]X(#T@0&EM87!?;W!E;B@D;6)N86UE+"`D=7-E<BP@
M)'!A<W-W9"D["B`@("`@("`@:68@*"1M8F]X*2!["B`@("`@("`@("`@("1M
M:6YF;R`]($!I;6%P7VUA:6QB;WAM<V=I;F9O*"1M8F]X*3L*("`@("`@("`@
M("`@:68@*"1M:6YF;RD@>PH@("`@("`@("`@("`@("`@96-H;R`G/&9O;G0@
M8V]L;W(](F=R965N(CY354-#15-3/"]F;VYT/B`M($E.0D]8(&AA<R`G+"`D
M;6EN9F\M/DYM<V=S+"`G(&UE<W-A9V5S("@G("X@)&UI;F9O+3Y5;G)E860L
M("<@;F5W("<L("1M:6YF;RT^4F5C96YT+"`G(')E8V5N="DG.PH@("`@("`@
M("`@("`@("`@)'-U8V-E<W-;72`](&%R<F%Y*"=S97)V97(G(#T^("1S97)V
M97(L("=P<F]T;V-O;"<@/3X@)&ME>2P@)W!O<G0G(#T^("1S97)V97)?<&]R
M="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!E8VAO
M("<\9F]N="!C;VQO<CTB<F5D(CY%4E)/4CPO9F]N=#X@+2!4:&4@<V5R=F5R
M(')E='5R;F5D('1H92!F;VQL;W=I;F<@97)R;W(@;65S<V%G93HG("X@(EQN
M(B`N("<\<')E/B<["B`@("`@("`@("`@("`@("!F;W)E86-H("AI;6%P7V5R
M<F]R<R@I(&%S("1E<G)O<BD@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@
M=V]R9'=R87`H)&5R<F]R*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&5C:&\@)SPO<')E/B<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@0&EM87!?8VQO<V4H)&UB;W@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&5C:&\@)SQF;VYT(&-O;&]R/2)R960B/D524D]2/"]F;VYT/B`M
M(%1H92!S97)V97(@<F5T=7)N960@=&AE(&9O;&QO=VEN9R!E<G)O<B!M97-S
M86=E.B<@+B`B7&XB("X@)SQP<F4^)SL*("`@("`@("`@("`@9F]R96%C:"`H
M:6UA<%]E<G)O<G,H*2!A<R`D97)R;W(I('L*("`@("`@("`@("`@("`@(&5C
M:&\@=V]R9'=R87`H)&5R<F]R*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E8VAO("<\+W!R93XG.PH@("`@("`@('T*("`@("`@("!E8VAO("(\+V)L
M;V-K<75O=&4^7&X\+VQI/CPO=6P^7&XB.PH@("`@?0H*("`@(&EF("@A96UP
M='DH)'-U8V-E<W,I*2!["B`@("`@("`@96-H;R`B/'-T<F]N9SY4:&4@9F]L
M;&]W:6YG(&-O;F9I9W5R871I;VYS('=E<F4@<W5C8V5S<V9U;"!A;F0@;6%Y
M(&)E('5S960@:6X@>6]U<B!I;7`O8V]N9FEG+W-E<G9E<G,N<&AP(&9I;&4Z
M/"]S=')O;F<^7&XB.PH@("`@("`@("1I(#T@,3L*("`@("`@("!F;W)E86-H
M("@D<W5C8V5S<R!A<R`D=F%L*2!["B`@("`@("`@("`@(&5C:&\@(CQB;&]C
M:W%U;W1E/CQE;3Y#;VYF:6=U<F%T:6]N("(@+B`D:2LK("X@(CPO96T^/&)L
M;V-K<75O=&4^/'!R93XB.PH@("`@("`@("`@("!F;W)E86-H("@D=F%L(&%S
M("1K97D@/3X@)&5N=')Y*2!["B`@("`@("`@("`@("`@("!E8VAO("(G(B`N
M("1K97D@+B`B)R`]/B`G(B`N("1E;G1R>2`N("(G7&XB.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5C:&\@(CPO8FQO8VMQ=6]T93X\+W!R93X\+V)L
M;V-K<75O=&4^7&XB.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T>7!E(#T]
M("=I;6%P)RD@>PH@("`@("`@("`@("!E8VAO("(\<W1R;VYG/E1H92!F;VQL
M;W=I;F<@24U!4"!S97)V97(@:6YF;W)M871I;VX@=V%S(&1I<V-O=F5R960@
M9G)O;2!T:&4@<F5M;W1E('-E<G9E<CH\+W-T<F]N9SY<;B(["B`@("`@("`@
M("`@("1C;VYF:6<@/2!R97-E="@D<W5C8V5S<RD["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G+B]L:6(O24U!4"]#;&EE;G0N<&AP)SL*("`@("`@("`@
M("`@)&EM87!C;&EE;G0@/2`F;F5W($E-4%])34%00VQI96YT*"1C;VYF:6=;
M)W-E<G9E<B==+"`D8V]N9FEG6R=P;W)T)UTL("1C;VYF:6=;)W!R;W1O8V]L
M)UTI.PH@("`@("`@("`@("`D=7-E7W1L<R`]("1I;6%P8VQI96YT+3YU<V54
M3%,H*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1U<V5?=&QS+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@)&EM87!C;&EE;G0M
M/FQO9VEN*"1U<V5R+"`D<&%S<W=D*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H:7-S970H)')E<RD@)B8@(6ES7V$H)')E<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@96-H;R`B/&)L;V-K<75O=&4^/&5M
M/DYA;65S<&%C92!);F9O<FUA=&EO;CPO96T^/'!R93X\8FQO8VMQ=6]T93XB
M.PH@("`@("`@("`@("`@("`@)&YA;65S<&%C92`]("1I;6%P8VQI96YT+3YN
M86UE<W!A8V4H*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;F%M
M97-P86-E*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1N86UE
M<W!A8V4@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!E8VAO
M(").04U%4U!!0T4Z(%PB(B`N("1V86Q;)VYA;64G72`N(")<(EQN(CL*("`@
M("`@("`@("`@("`@("`@("`@("`@96-H;R`B1$5,24U)5$52.B`B("X@)'9A
M;%LG9&5L:6UI=&5R)UT@+B`B7&XB.PH@("`@("`@("`@("`@("`@("`@("`@
M("!E8VAO(")465!%.B`B("X@)'9A;%LG='EP92==("X@(EQN7&XB.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@96-H;R`B0V]U;&0@;F]T(')E=')I979E(&YA
M;65S<&%C92!I;F9O<FUA=&EO;B!F<F]M($E-05`@<V5R=F5R+EQN(CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5C:&\@(CPO8FQO8VMQ
M=6]T93X\+W!R93X\+V)L;V-K<75O=&4^7&XB.PH*("`@("`@("`@("`@("`@
M(&5C:&\@(CQB;&]C:W%U;W1E/CQE;3Y)34%0($-(24Q$4D5.('-U<'!O<G0Z
M/"]E;3X\<')E/CQB;&]C:W%U;W1E/B(["B`@("`@("`@("`@("`@("!E8VAO
M("@D:6UA<&-L:65N="T^<75E<GE#87!A8FEL:71Y*"=#2$E,1%)%3B<I*2`_
M("=355!03U)4140G(#H@)TYO="!S=7!P;W)T960G.PH@("`@("`@("`@("`@
M("`@96-H;R`B/"]B;&]C:W%U;W1E/CPO<')E/CPO8FQO8VMQ=6]T93Y<;B([
M"@H@("`@("`@("`@("`@("`@96-H;R`B/&)L;V-K<75O=&4^/&5M/DE-05`@
M0VAA<G-E="!396%R8V@@4W5P<&]R=#H\+V5M/CQP<F4^/&)L;V-K<75O=&4^
M(CL*("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@3DQ3.CIG971#:&%R<V5T
M*"D["B`@("`@("`@("`@("`@("!I9B`H)&EM87!C;&EE;G0M/G-E87)C:$-H
M87)S970H)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`B
M4V5R=F5R('-U<'!O<G1S('-E87)C:&EN9R!W:71H('1H92`D8VAA<G-E="!C
M:&%R86-T97(@<V5T+EQN(CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@96-H;R`B4V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<V5A<F-H:6YG('=I=&@@=&AE("1C:&%R<V5T(&-H87)A8W1E<B!S970N
M7&XB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96-H;R`B
M/"]B;&]C:W%U;W1E/CPO<')E/CPO8FQO8VMQ=6]T93Y<;B(["B`@("`@("`@
M("`@("`@("`D:6UA<&-L:65N="T^;&]G;W5T*"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!E8VAO("(\8FQO8VMQ=6]T93X\96T^
M0V]U;&0@;F]T(')E=')I979E($E-05`@:6YF;W)M871I;VX@9G)O;2!T:&4@
M<F5M;W1E('-E<G9E<BX\+V5M/CPO8FQO8VMQ=6]T93XB.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!E8VAO("(\<W1R
M;VYG/D-O=6QD(&YO="!D971E<FUI;F4@82!S=6-C97-S9G5L(&-O;FYE8W1I
M;VX@<')O=&]C;VPN("!-86ME('-U<F4@>6]U<B!M86EL('-E<G9E<B!I<R!R
M=6YN:6YG(&%N9"!Y;W4@:&%V92!S<&5C:69I960@=&AE(&-O<G)E8W0@<&]R
M="X\+W-T<F]N9SY<;B(["B`@("!]"GT@96QS92!["B`@("`_/@H\9F]R;2!N
M86UE/2)F;W)M,2(@;65T:&]D/2)P;W-T(B!A8W1I;VX](G1E<W0N<&AP(CX*
M/'1A8FQE/@H\='(^/'1D(&%L:6=N/2)R:6=H="(^4V5R=F5R.CPO=&0^/'1D
M/CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)S97)V97(B("\^/"]T9#X\+W1R
M/@H\='(^/'1D(&%L:6=N/2)R:6=H="(^4&]R=#H\+W1D/CQT9#X\:6YP=70@
M='EP93TB=&5X="(@;F%M93TB<&]R="(@+SX\+W1D/CQT9#XH268@;F]N+7-T
M86YD87)D('!O<G0[(&QE879E(&)L86YK('1O(&%U=&\M9&5T96-T('5S:6YG
M('-T86YD87)D('!O<G1S*3PO=&0^/"]T<CX*/'1R/CQT9"!A;&EG;CTB<FEG
M:'0B/E5S97(Z/"]T9#X\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G5S
M97(B("\^/"]T9#X\+W1R/@H\='(^/'1D(&%L:6=N/2)R:6=H="(^4&%S<W=O
M<F0Z/"]T9#X\=&0^/&EN<'5T('1Y<&4](G!A<W-W;W)D(B!N86UE/2)P87-S
M=V0B("\^/"]T9#X\+W1R/@H\='(^/'1D(&%L:6=N/2)R:6=H="(^4V5R=F5R
M(%1Y<&4Z/"]T9#X\=&0^/'-E;&5C="!N86UE/2)S97)V97)?='EP92(^/&]P
M=&EO;B!V86QU93TB:6UA<"(^24U!4#PO;W!T:6]N/CQO<'1I;VX@=F%L=64]
M(G!O<"(^4$]0/"]O<'1I;VX^/"]S96QE8W0^/"]T9#X\+W1R/@H\='(^/'1D
M/CPO=&0^/'1D/CQI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](F9?<W5B;6ET
M(B!V86QU93TB4W5B;6ET(B`O/CQI;G!U="!T>7!E/2)R97-E="(@;F%M93TB
M9E]R97-E="(@=F%L=64](E)E<V5T(B`O/CPO=&0^/"]T<CX*/"]T86)L93X*
M/"]F;W)M/@H\/W!H<"!](#\^"@H\+W1D/CPO='(^"CPO=&%B;&4^"@H\/W!H
M<`IR97%U:7)E(%1%4U1?5$5-4$Q!5$53("X@)V9O;W1E<BYI;F,G.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VEM<"]S=&%T:6]N97)Y+G!H<```````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<W-#$`,3`T,3<S-C(W-S``,#(P
M,3,P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EM<"]S=&%T:6]N97)Y+G!H<"QV(#(N
M,2XR+C,@,C`P-B\P,B\R,"`Q-3HP.#HU,"!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF('EO=2!D:60*("H@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+V=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TE-4%]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RDI.PHD875T:&5N=&EC871I;VX@/2!/4%](04Q&3U!%3CL*
M<F5Q=6ER95]O;F-E($E-4%]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+U!R969S+U5)+G!H<"<["@HD8V]M<&]S95]U<FP@
M/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E
M="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]P<F5F<RYP:'`G
M+"!T<G5E*2P@)V%P<"<L("=I;7`G+"!F86QS92D["@HO*B!)<R!T:&4@<')E
M9F5R96YC92!L;V-K960_("HO"FEF("@D<')E9G,M/FES3&]C:V5D*"=S=&%T
M:6]N97)Y)RDI('L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D8V]M<&]S
M95]U<FPI.PH@("`@97AI=#L*?0H*+RH@4F5T<FEE=F4@<W1A=&EO;F5R>2X@
M*B\*)'-T871I;VYE<GE?;&ES="`]($!U;G-E<FEA;&EZ92@D<')E9G,M/F=E
M=%9A;'5E*"=S=&%T:6]N97)Y)RP@9F%L<V4I*3L*:68@*&ES7V%R<F%Y*"1S
M=&%T:6]N97)Y7VQI<W0I*2!["B`@("`D<W1A=&EO;F5R>5]L:7-T(#T@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="@D<W1A=&EO;F5R>5]L:7-T+"`D<')E9G,M
M/F=E=$-H87)S970H*2D["GT@96QS92!["B`@("`D<W1A=&EO;F5R>5]L:7-T
M(#T@87)R87DH*3L*?0HD<W1A=&EO;F5R>2`](&YU;&P["@HO*B!'970@9F]R
M;2!D871A+B`J+PHD:60@/2!5=&EL.CIG971&;W)M1&%T82@G:60G*3L*:68@
M*"%I<U]N=6QL*"1I9"DI('L*("`@("1I9"`]("AI;G0I)&ED.PI]"B1S96QE
M8W1E9"`](%5T:6PZ.F=E=$9O<FU$871A*"=S=&%T:6]N97)Y)RD["FEF("AS
M=')L96XH)'-E;&5C=&5D*2D@>PH@("`@)'-E;&5C=&5D(#T@*&EN="DD<V5L
M96-T960["GT*"B\J(%)U;B!T:')O=6=H('1H92!A8W1I;VX@:&%N9&QE<G,N
M("HO"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I
M.PHD=7!D871E9"`](&9A;'-E.PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E
M("=U<&1A=&4G.@H@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=E9&ET)RDI
M('L*("`@("`@("`O*B!3=&%T:6]N97)Y(&AA<R!B965N('-W:71C:&5D+B`J
M+PH@("`@("`@(&EF("AS=')L96XH)'-E;&5C=&5D*2D@>PH@("`@("`@("`@
M("`O*B!%9&ET(&5X:7-T:6YG+B`J+PH@("`@("`@("`@("`D<W1A=&EO;F5R
M>2`](&%R<F%Y*"=N)R`]/B`D<W1A=&EO;F5R>5]L:7-T6R1S96QE8W1E9%U;
M)VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G="<@/3X@
M)'-T871I;VYE<GE?;&ES=%LD<V5L96-T961=6R=T)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V,G(#T^("1S=&%T:6]N97)Y7VQI<W1;
M)'-E;&5C=&5D75LG8R==*3L*("`@("`@("`@("`@)&ED(#T@)'-E;&5C=&5D
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($-R96%T92!N97<N
M("HO"B`@("`@("`@("`@("1S=&%T:6]N97)Y(#T@87)R87DH)VXG(#T^("<G
M+"`G="<@/3X@)W!L86EN)RP@)V,G(#T^("<G*3L*("`@("`@("!]"B`@("!]
M(&5L<V5I9B`H571I;#HZ9V5T1F]R;41A=&$H)V1E;&5T92<I*2!["B`@("`@
M("`@+RH@1&5L971E('-T871I;VYE<GDN("HO"B`@("`@("`@:68@*&ES<V5T
M*"1S=&%T:6]N97)Y7VQI<W1;)&ED72DI('L*("`@("`@("`@("`@)'5P9&%T
M960@/2!S<')I;G1F*%\H(E1H92!S=&%T:6]N97)Y(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(I+"`D<W1A=&EO;F5R>5]L:7-T6R1I9%U;)VXG72D["B`@
M("`@("`@("`@('5N<V5T*"1S=&%T:6]N97)Y7VQI<W1;)&ED72D["B`@("`@
M("`@?0H@("`@?2!E;'-E('L*("`@("`@("`D;&%S=%]T>7!E(#T@571I;#HZ
M9V5T1F]R;41A=&$H)VQA<W1?='EP92<I.PH@("`@("`@("1T>7!E(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W1Y<&4G+"`G<&QA:6XG*3L*("`@("`@("`D;F%M
M92`](%5T:6PZ.F=E=$9O<FU$871A*"=N86UE)RP@)R<I.PH@("`@("`@("1C
M;VYT96YT(#T@571I;#HZ9V5T1F]R;41A=&$H)V-O;G1E;G0G+"`G)RD["B`@
M("`@("`@)'-T871I;VYE<GD@/2!A<G)A>2@G;B<@/3X@)&YA;64L("=T)R`]
M/B`D='EP92P@)V,G(#T^("1C;VYT96YT*3L*("`@("`@("!I9B`H(65M<'1Y
M*"1L87-T7W1Y<&4I*2!["B`@("`@("`@("`@(&EF("@D;&%S=%]T>7!E("$]
M("1T>7!E*2!["B`@("`@("`@("`@("`@("`O*B!3=VET8VAI;F<@=&5X="!F
M;W)M870N("HO"B`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)W!L86EN
M)RD@>PH@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`@("`@("`@("`@("`D8V]N=&5N
M="`](%1E>'1?1FEL=&5R.CIF:6QT97(H)&-O;G1E;G0L("=H=&UL,G1E>'0G
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S=&%T:6]N
M97)Y6R=C)UT@/2`D8V]N=&5N=#L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("\J(%-A=FEN9R!S=&%T:6]N97)Y+B`J+PH@("`@("`@
M("`@("`@("`@:68@*&ES7VYU;&PH)&ED*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1I9"`](&-O=6YT*"1S=&%T:6]N97)Y7VQI<W0I.PH@("`@("`@("`@
M("`@("`@("`@("1S=&%T:6]N97)Y7VQI<W1;72`]("1S=&%T:6]N97)Y.PH@
M("`@("`@("`@("`@("`@("`@("1U<&1A=&5D(#T@<W!R:6YT9BA?*")4:&4@
M<W1A=&EO;F5R>2!<(B5S7"(@:&%S(&)E96X@861D960N(BDL("1S=&%T:6]N
M97)Y6R=N)UTI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D<W1A=&EO;F5R>5]L:7-T6R1I9%T@/2`D<W1A=&EO;F5R
M>3L*("`@("`@("`@("`@("`@("`@("`D=7!D871E9"`]('-P<FEN=&8H7R@B
M5&AE('-T871I;VYE<GD@7"(E<UPB(&AA<R!B965N('5P9&%T960N(BDL("1S
M=&%T:6]N97)Y6R=N)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E:68@*"%I<U]N=6QL*"1I9"DI('L*("`@("`@
M("`@("`@)'-T871I;VYE<GD@/2`D<W1A=&EO;F5R>5]L:7-T6R1I9%T["B`@
M("`@("`@?0H@("`@?0H*("`@(&)R96%K.PI]"@II9B`H)'5P9&%T960I('L*
M("`@("1P<F5F<RT^<V5T5F%L=64H)W-T871I;VYE<GDG+"!S97)I86QI>F4H
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D<W1A=&EO;F5R>5]L:7-T+"!.3%,Z
M.F=E=$-H87)S970H*2P@)'!R969S+3YG971#:&%R<V5T*"DI*2P@9F%L<V4I
M.PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D=7!D871E9"P@)VAO<F1E+G-U
M8V-E<W,G*3L*?0H*:68@*"%I<U]N=6QL*"1S=&%T:6]N97)Y*2`F)B`D<W1A
M=&EO;F5R>5LG="==(#T]("=H=&UL)RD@>PH@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]%9&ET;W(N<&AP)SL*("`@("1E9&ET;W(@/2`F2&]R9&5?161I=&]R
M.CIS:6YG;&5T;VXH)WAI;FAA)RP@87)R87DH)VED)R`]/B`G8V]N=&5N="<I
M*3L*?0H*+RH@4VAO=R!T:&4@:&5A9&5R+B`J+PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U!R969S+U5)+G!H<"<["G)E<75I<F4@24U07T)!4T4@+B`G+V-O;F9I
M9R]P<F5F<RYP:'`G.PHD87!P(#T@)VEM<"<["B1G<F]U<"`]("=C;VUP;W-E
M)SL*"E!R969S7U5).CIG96YE<F%T94AE861E<B@I.PIR97%U:7)E($E-4%]4
M14U03$%415,@+B`G+W-T871I;VYE<GDO<')E9G,N:6YC)SL*"G)E<75I<F4@
M)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM
M;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEM<"]S<&5L;&EN9RYP:'``
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$W
M-#(`,3`T,3<S-C(W-S``,#$W-30Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&EM<"]S
M<&5L;&EN9RYP:'`L=B`R+C8W+C8N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C4R(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*
M("HO"@ID969I;F4H)TE-4%]34$5,3%]#2$%.1T4G+"`@("`@,2D["F1E9FEN
M92@G24U07U-014Q,7T-(04Y'15]!3$PG+"`R*3L*9&5F:6YE*"=)35!?4U!%
M3$Q?24=.3U)%)RP@("`@(#,I.PID969I;F4H)TE-4%]34$5,3%])1TY/4D5?
M04Q,)RP@-"D["@HO*B!"87-E(&QI<W0@;V8@=V]R9',@=&\@:6=N;W)E+B`J
M+PHD:6=N;W)E7VQI<W0@/2!A<G)A>2@*("`@("=C;VTG+"`G8V,G+"`G=W=W
M)RP@)VIA;B<L("=F96(G+"`G;6%R)RP@)V%P<B<L("=M87DG+"`G:G5N)RP@
M)VIU;"<L"B`@("`G875G)RP@)W-E<"<L("=O8W0G+"`G;F]V)RP@)V1E8R<L
M("=F=V0G+"`G9&YS)RP@)VAT='`G+"`G8V$G+"`G:'1M;"<L"B`@("`G=&TG
M+"`G;6UU;FET>2<L("=C;R<L("=O<"<L("=H='1P<R<L("=N971S8V%P92<L
M("=W96)M86EL)RP@)V)C8R<L"B`@("`G:G!G)RP@)V=I9B<L("=E;6%I;"<L
M("=T96PG+"`G:64G+"`G96<G"BD["@HO*BH*("H@1FEN9"!T:&4@;V9F<V5T
M(&]F(&$@9VEV96X@=V]R9"X*("H*("H@0'!A<F%M('-T<FEN9R`D;65S<V%G
M92`@5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4N"B`J($!P87)A;2!S=')I;F<@
M)'=O<F0@("`@(%1H92!W;W)D('1O(&9I;F0N"B`J($!P87)A;2!I;G1E9V5R
M("1S=&%R="`@(%1H92!O9F9S970N"B`J"B`J($!R971U<FX@:6YT96=E<B`@
M5&AE(&]F9G-E="!O9B!T:&4@=V]R9"X*("HO"F9U;F-T:6]N(%]F:6YD3V9F
M<V5T*"1M97-S86=E+"`D=V]R9"P@)'-T87)T*0I["B`@("`D;V9F<V5T(#T@
M)'-T87)T.PH@("`@)'!O<R`]("TQ.PH*("`@("\J($EF(&%L;"!T:&EN9W,@
M87)E(')I9VAT('1H92!W;W)D(&ES(&%T(&]F9G-E="`M(#$@*B\*("`@(&EF
M("@D<W1A<G0@/B`S*2!["B`@("`@("`@)'-T87)T("T](#,["B`@("!](&5L
M<V4@>PH@("`@("`@("1S=&%R="`](#`["B`@("!]"B`@("!W:&EL92`H*"1P
M;W,@/3T@+3$I("8F("@D<W1A<G0@/CT@,"DI('L*("`@("`@("`D<&]S(#T@
M4W1R:6YG.CIP;W,H)&UE<W-A9V4L("1W;W)D+"`D<W1A<G0I.PH@("`@("`@
M(&EF("@H)'!O<R`]/2`G)RD@)B8@(6ES7VEN="@D<&]S*2D@>PH@("`@("`@
M("`@("`D<W1A<G0M+3L*("`@("`@("`@("`@)'!O<R`]("TQ.PH@("`@("`@
M('T*("`@('T*"B`@("!R971U<FX@)'!O<SL*?0H*"B\J*@H@*B!(:6=H;&EG
M:'0@:6X@97)R;W(@:6X@82!G:79E;B!M97-S86=E+@H@*@H@*B!`<&%R86T@
M<W1R:6YG("1E<G)O<B`@("!4:&4@;6ES<W!E;&QE9"!W;W)D+@H@*B!`<&%R
M86T@<W1R:6YG("1M97-S86=E("!4:&4@=&5X="!O9B!T:&4@;65S<V%G92X*
M("H@0'!A<F%M(&EN=&5G97(@)'-T87)T("`@5&AE(&]F9G-E="X*("H*("H@
M0')E='5R;B!S=')I;F<@(%1H92!S=')I;F<@=VET:"!T:&4@97)R;W(@:&EG
M:&QI9VAT960N"B`J+PIF=6YC=&EO;B!?:&EG:&QI9VAT17)R;W(H)&5R<F]R
M+"`D;65S<V%G92P@)&]F9G-E="D*>PH@("`@)'!O<R`]('-T<G!O<R@D;65S
M<V%G92P@)&5R<F]R+"`H*"@D;V9F<V5T("T@,2D@/B`P*2`_("@D;V9F<V5T
M("T@,2D@.B`P*2D["B`@("!I9B`H*"1P;W,@+2`Q-2D@/B`P*2!["B`@("`@
M("`@)'-T87)T(#T@)'!O<R`M(#$U.PH@("`@?2!E;'-E('L*("`@("`@("`D
M<W1A<G0@/2`P.PH@("`@?0H@("`@)&QE;F=T:"`](%-T<FEN9SHZ;&5N9W1H
M*"1E<G)O<BD@*R`S,#L*"B`@("`D;65S<V%G92`]('-U8G-T<E]R97!L86-E
M*"1M97-S86=E+"`G/'-P86X@<W1Y;&4](F-O;&]R.B-F9C`P,#`B/B<@+B`D
M97)R;W(@+B`G/"]S<&%N/B<L("1P;W,L(%-T<FEN9SHZ;&5N9W1H*"1E<G)O
M<BDI.PH@("`@)&UE<W-A9V4@/2!3=')I;F<Z.G-U8G-T<B@D;65S<V%G92P@
M)'-T87)T+"`D;&5N9W1H("L@,C@I.PH*("`@(')E='5R;B`D;65S<V%G93L*
M?0H*+RH@1F5T8V@@86YD(&-L96%N(&9O<FT@9&%T82X@(%1H97-E(&%R92!S
M<&5L;&EN9RYP:'`@<W!E8VEF:6,@9F]R;2!V87)I86)L97,*("H@;VYL>2X@
M*B\*)&9?;W!T(#T@571I;#HZ9V5T1F]R;41A=&$H)V]P="<I.PHD9E]S=6)S
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W-U8G,G*3L*)&9?;VQD=V]R9"`](%5T
M:6PZ.F=E=$9O<FU$871A*"=O;&1W;W)D)RD["B1F7W-U8G1E>'0@/2!5=&EL
M.CIG971&;W)M1&%T82@G<W5B=&5X="<I.PHD9E]W;W)D;V9F<V5T(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W=O<F1O9F9S970G*3L*)&9?;VQD;7-G(#T@571I
M;#HZ9V5T1F]R;41A=&$H)V]L9&US9R<L(%5T:6PZ.F=E=$9O<FU$871A*"=M
M97-S86=E)RDI.PHD9E]C=7)R;7-G(#T@571I;#HZ9V5T1F]R;41A=&$H)V-U
M<G)M<V<G+"`D9E]O;&1M<V<I.PHD9E]N97=M<V<@/2!5=&EL.CIG971&;W)M
M1&%T82@G;F5W;7-G)RD["B1F7V1O;F5?86-T:6]N(#T@571I;#HZ9V5T1F]R
M;41A=&$H)V1O;F5?86-T:6]N)RD["@HO*B!'970@9G)O;2!D871A(&9R;VT@
M8V]M<&]S92YP:'`@:6YP=70@=&AA="!I<R!U<V5D(&QO8V%L;'D@:6X*("H@
M<W!E;&QI;F<N<&AP+B`J+PHD9E]R=&5M;V1E(#T@571I;#HZ9V5T1F]R;41A
M=&$H)W)T96UO9&4G*3L*"B\J("1F7VEG;F]R96%L;"!I<R!A;B!A<G)A>2`M
M('=E(&YE960@=&\@=6YS97)I86QI>F4@=&AE(&1A=&$N("HO"B1I9VYO<F5A
M;&P@/2!A<G)A>2@I.PII9B`H*"1F7VEG;F]R96%L;"`](%5T:6PZ.F=E=$9O
M<FU$871A*"=I9VYO<F5A;&PG*2DI('L*("`@("1F7VEG;F]R96%L;"`]('5N
M<V5R:6%L:7IE*"1F7VEG;F]R96%L;"D["GT@96QS92!["B`@("`D9E]I9VYO
M<F5A;&P@/2!A<G)A>2@I.PI]"@IS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E
M("=S<&5L;%]C:&5C:U]F;W)W87)D)SH*("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1F7V]P="D[("1I*RLI('L*("`@("`@("`D<VMI<'=O<F0@/2!F
M86QS93L*"B`@("`@("`@+RH@268@=&AE>2!H879E(&%N('=O<F0@=VET:"!N
M;R!S=6=G97-T:6]N<R!A;F0@=&AE>0H@("`@("`@("`@(&1O;G0@='EP92!I
M;B!A(')E<&QA8V5M96YT+"!I9VYO<F4@:70N("HO"B`@("`@("`@:68@*"%E
M;7!T>2@D9E]S=6)T97AT6R1I72DI('L*("`@("`@("`@("`@)')E<&QA8V5M
M96YT(#T@)&9?<W5B=&5X=%LD:5T["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@:68@*"1F7W-U8G-;)&E=(#T]("<P)RD@>PH@("`@("`@("`@("`@
M("`@)&EG;F]R96%L;"`]("1F7VEG;F]R96%L;#L*("`@("`@("`@("`@("`@
M("1I9VYO<F5A;&Q;72`](%-T<FEN9SHZ;&]W97(H)&9?;VQD=V]R9%LD:5TL
M('1R=64I.PH@("`@("`@("`@("`@("`@)'-K:7!W;W)D(#T@=')U93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97!L86-E;65N
M="`]("1F7W-U8G-;)&E=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H(21S:VEP=V]R9"D@>PH@("`@("`@("`@("`D<&]S(#T@+3$[
M"@H@("`@("`@("`@("`D<F5A;&]F9G-E="`]("1F7W=O<F1O9F9S971;)&E=
M.PH*("`@("`@("`@("`@+RH@2G5S="!I;B!C87-E('1H:6YG<R!A<F4@=VAA
M8VMI;'D@;W5T+B`J+PH@("`@("`@("`@("`D;7-G7VQE;F=T:"`](%-T<FEN
M9SHZ;&5N9W1H*"1F7V-U<G)M<V<I.PH@("`@("`@("`@("!I9B`H)')E86QO
M9F9S970@/B`D;7-G7VQE;F=T:"D@>PH@("`@("`@("`@("`@("`@)')E86QO
M9F9S970@/2`D;7-G7VQE;F=T:"`M(#$["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1P;W,@/2!?9FEN9$]F9G-E="@D9E]C=7)R;7-G+"`D9E]O;&1W
M;W)D6R1I72P@)')E86QO9F9S970I.PH*("`@("`@("`@("`@<W=I=&-H("@D
M9E]O<'1;)&E=*2!["B`@("`@("`@("`@(&-A<V4@24U07U-014Q,7TE'3D]2
M13H*("`@("`@("`@("`@("`@("1C;VYS=6UE(#T@)'!O<R`K(%-T<FEN9SHZ
M;&5N9W1H*"1F7V]L9'=O<F1;)&E=*3L*("`@("`@("`@("`@("`@("1A9&1I
M=&EO;B`](%-T<FEN9SHZ<W5B<W1R*"1F7V-U<G)M<V<L(#`L("1C;VYS=6UE
M*3L*("`@("`@("`@("`@("`@("1F7VYE=VUS9R`N/2`D861D:71I;VX["B`@
M("`@("`@("`@("`@("`D9E]C=7)R;7-G(#T@4W1R:6YG.CIS=6)S='(H)&9?
M8W5R<FUS9RP@)&-O;G-U;64I.PH*("`@("`@("`@("`@("`@("\J($%D:G5S
M="!O9F9S971S+"!A<R!T:&5Y(&-O=6QD(&)E('=I;&1L>2!O=70@*B\*("`@
M("`@("`@("`@("`@(&9O<B`H)&US9VYU;2`](#`[("1M<V=N=6T@/"!C;W5N
M="@D9E]W;W)D;V9F<V5T*3L@)&US9VYU;2LK*2!["B`@("`@("`@("`@("`@
M("`@("`@)&9?=V]R9&]F9G-E=%LD;7-G;G5M72`M/2`D8V]N<W5M93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92!)35!?4U!%3$Q?24=.3U)%7T%,3#H*("`@("`@("`@("`@
M("`@("1I9VYO<F5A;&P@/2`D9E]I9VYO<F5A;&P["B`@("`@("`@("`@("`@
M("`D:6=N;W)E86QL6UT@/2!3=')I;F<Z.FQO=V5R*"1F7V]L9'=O<F1;)&E=
M+"!T<G5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92!)35!?4U!%3$Q?0TA!3D=%7T%,3#H*("`@("`@("`@("`@("`@("1F
M7V-U<G)M<V<@/2!S=')?<F5P;&%C92@D9E]O;&1W;W)D6R1I72P@)')E<&QA
M8V5M96YT+"`D9E]C=7)R;7-G*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92!)35!?4U!%3$Q?0TA!3D=%.@H@("`@("`@("`@
M("`@("`@:68@*"%I;E]A<G)A>2A3=')I;F<Z.FQO=V5R*"1F7V]L9'=O<F1;
M)&E=+"!T<G5E*2P@)&9?:6=N;W)E86QL*2D@>PH@("`@("`@("`@("`@("`@
M("`@("\J($QE="=S('1R>2!A;F0@:V5E<"!T:&]S92!O9F9S971S('-E;6D@
M8V]R<F5C="X@*B\*("`@("`@("`@("`@("`@("`@("`D861J;V9F<V5T(#T@
M4W1R:6YG.CIL96YG=&@H)')E<&QA8V5M96YT*2`M(%-T<FEN9SHZ;&5N9W1H
M*"1F7V]L9'=O<F1;)&E=*3L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1M
M<V=N=6T@/2`P.R`D;7-G;G5M(#P@8V]U;G0H)&9?=V]R9&]F9G-E="D[("1M
M<V=N=6TK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9E]W;W)D;V9F
M<V5T6R1M<V=N=6U=("L]("1A9&IO9F9S970["B`@("`@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("`@("`D=&5M<&UE<W-A9V4@(#T@4W1R
M:6YG.CIS=6)S='(H)&9?8W5R<FUS9RP@,"P@)'!O<RD["B`@("`@("`@("`@
M("`@("`@("`@)'1E;7!M97-S86=E("X]("1R97!L86-E;65N=#L*("`@("`@
M("`@("`@("`@("`@("`D=&5M<&UE<W-A9V4@+CT@4W1R:6YG.CIS=6)S='(H
M)&9?8W5R<FUS9RP@)'!O<R`K(%-T<FEN9SHZ;&5N9W1H*"1F7V]L9'=O<F1;
M)&E=*2D["B`@("`@("`@("`@("`@("`@("`@)&9?8W5R<FUS9R`]("1T96UP
M;65S<V%G93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@8G)E86L[
M"@IC87-E("=S<&5L;%]C:&5C:U]S96YD)SH*("`@("1F7V1O;F5?86-T:6]N
M(#T@)W-E;F0G.PH@("`@+RH@1D%,3%1(4D]51T@@*B\*"F1E9F%U;'0Z"B`@
M("`D9E]M97-S86=E(#T@)&9?8W5R<FUS9SL*"B`@("`O*B!(879E('1O('-T
M87)T(&%N;W1H97(@=V]R9&QI<W0@=&\@:6YC;W)P;W)A=&4@:6YT;R!T:&4@
M<W!E;&P*("`@("`@(&-H96-K(&1I8W1I;VYA<GD@;65T:&EN:W,N("HO"B`@
M("`D:6=N;W)E86QL(#T@)&EG;F]R95]L:7-T.PH@("`@8G)E86L["GT*"B\J
M(%-P96-I86P@=')E871M96YT(&1E<&5N9&EN9R!O;B!L86YG=6%G92`H<75O
M=&5S(&%R92!N;W0@97%U86QL>2!T<F5A=&5D"B`@(&)Y(&ES<&5L;"!I;B!E
M;F=L:7-H(&%N9"!I;B!F<F5N8V@I+B`J+PIS=VET8V@@*"1L86YG=6%G92D@
M>PIC87-E("=F<E]&4B<Z"B`@("`D=&]C:&5C:R`]('-T<E]R97!L86-E*"(G
M(BP@(EQ<)R(L(&5S8V%P95-H96QL0VUD*"1F7V-U<G)M<V<I*3L*("`@(&)R
M96%K.PH*9&5F875L=#H*("`@("1T;V-H96-K(#T@)&9?8W5R<FUS9SL*("`@
M(&)R96%K.PI]"@HD<W!E;&QC:&5C:V5R(#T@)&-O;F9;)W5T:6QS)UU;)W-P
M96QL8VAE8VME<B==.PH*+RH@4')O=&5C="!A9V%I;G-T(&QI;F5S(&)E9VEN
M;FEN9R!W:71H(")S<&5C:6%L(B!C:&%R86-T97)S(&%S(&1E9FEN960@870*
M("`@:'1T<#HO+V%S<&5L;"YN970O;6%N+6AT;6PO5&AR;W5G:"U!+5!I<&4N
M:'1M;"-4:')O=6=H)3(P024R,%!I<&4@*B\*:68@*'-T<G!O<R@D<W!E;&QC
M:&5C:V5R+"`G87-P96QL)RD@(3T](&9A;'-E*2!["B`@("`D=&]C:&5C:R`]
M("=>)R`N('-T<E]R97!L86-E*")<;B(L(")<;EXB+"`D=&]C:&5C:RD["GT*
M"B\J(%-A=F4@=&AE(&UE<W-A9V4@=&\@82!T96UP;W)A<GD@9FEL92X@*B\*
M)'-P96QL1FEL92`]($AO<F1E.CIG971496UP1FEL92@G<W!E;&PG*3L*)&9P
M(#T@9F]P96XH)'-P96QL1FEL92P@)W<G*3L*9G=R:71E*"1F<"P@)'1O8VAE
M8VLI.PIF8VQO<V4H)&9P*3L*"B\J(%)U;B!T:&4@86-T=6%L('-P96QL(&-H
M96-K+B`J+PII9B`H96UP='DH)'-P96QL8VAE8VME<BDI('L*("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B3F\@<W!E;&QC:&5C:VEN9R!P<F]G<F%M(&-O
M;F9I9W5R960N(BDL("=H;W)D92YE<G)O<B<I.PI](&5L<V4@>PH@("`@+RH@
M4F5T<FEE=F4@86YY('-P96QL:6YG(&]P=&EO;G,N("HO"B`@("`D<W!E;&Q?
M;W!T(#T@)R<["B`@("!I9B`H:7-S970H)&YL<ULG<W!E;&QI;F<G75LD;&%N
M9W5A9V5=*2D@>PH@("`@("`@("1S<&5L;%]O<'0@/2`D;FQS6R=S<&5L;&EN
M9R==6R1L86YG=6%G95T["B`@("!]"B`@("!I9B`H<W1R<&]S*"1S<&5L;&-H
M96-K97(L("=A<W!E;&PG*2`A/2!F86QS92D@>PH@("`@("`@("1S<&5L;%]O
M<'0@+CT@)R`M92<["B`@("!]"B`@("!I9B`H)&9?<G1E;6]D92D@>PH@("`@
M("`@("\O(%1R>2!T;R!U<V4@=&AE(%-P96QL8VAE8VME<B=S($A434P@;6]D
M90H@("`@("`@(&EF("AS=')P;W,H)'-P96QL8VAE8VME<BP@)VES<&5L;"<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<W!E;&Q?;W!T("X]("<@+6@G
M.PH@("`@("`@('T@96QS96EF("AS=')P;W,H)'-P96QL8VAE8VME<BP@)V%S
M<&5L;"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<W!E;&Q?;W!T("X]
M("<@+4@G.PH@("`@("`@('T*("`@('T*"B`@("!E>&5C*&5S8V%P97-H96QL
M8VUD*"1S<&5L;&-H96-K97(@+B`G("UA("<@+B`D<W!E;&Q?;W!T*2`N("<@
M/"`G("X@)'-P96QL1FEL92P@)'=A<FYI;F=S*3L*?0H*)&US9R`]("<G.PIF
M;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=V%R;FEN9W,I.R`D:2LK*2!["B`@
M("!I9B`H<W5B<W1R*"1W87)N:6YG<ULD:5TL(#`L(#$I(#T]("<F)RD@>PH@
M("`@("`@("1P87)T<R`](&5X<&QO9&4H)SH@)RP@)'=A<FYI;F=S6R1I72D[
M"B`@("`@("`@)&EN9F\@/2!E>'!L;V1E*"<@)RP@)'!A<G1S6S!=*3L*("`@
M("`@("!I9B`H<')E9U]M871C:"@G?%Y;02U:72HD?"<L("1I;F9O6S%=*2D@
M>PH@("`@("`@("`@("`D:6=N;W)E86QL6UT@/2!3=')I;F<Z.FQO=V5R*"1I
M;F9O6S%=+"!T<G5E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M97)R;W);72`](&%R<F%Y*"1I;F9O6S%=+"`D:6YF;ULS72P@)'!A<G1S6S%=
M*3L*("`@("`@("!]"B`@("!]"B`@("!I9B`H<')E9U]M871C:"@G?%XC?"<L
M("1W87)N:6YG<ULD:5TI*2!["B`@("`@("`@)&EN9F\@/2!E>'!L;V1E*"<@
M)RP@)'=A<FYI;F=S6R1I72D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>
M6T$M6ETJ)'PG+"`D:6YF;ULQ72DI('L*("`@("`@("`@("`@)&EG;F]R96%L
M;%M=(#T@4W1R:6YG.CIL;W=E<B@D:6YF;ULQ72P@=')U92D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&5R<F]R6UT@/2!A<G)A>2@D:6YF;ULQ
M72P@)&EN9F];,ETL("<G*3L*("`@("`@("!]"B`@("!]"GT*"B\J($=E;F5R
M871E(&$@<')E='1Y('=O<F0M=W)A<'!E9"!V97)S:6]N(&9O<B!D:7-P;&%Y
M:6YG+B`J+PHD9&ES<&QA>5]M<V<@/2`D9E]M97-S86=E(#T@(EQN(B`N("1F
M7VYE=VUS9R`N("1F7V-U<G)M<V<["FEF("@A)&9?<G1E;6]D92D@>PH@("`@
M)&1I<W!L87E?;7-G(#T@:'1M;'-P96-I86QC:&%R<R@D9&ES<&QA>5]M<V<I
M.PH@("`@)&1I<W!L87E?;7-G(#T@4W1R:6YG.CIW<F%P*"1D:7-P;&%Y7VUS
M9RP@.#`L(")<;B(L($Y,4SHZ9V5T0VAA<G-E="@I+"!T<G5E*3L*?0II9B`H
M)&)R;W=S97(M/FAA<U%U:7)K*"=D;W5B;&5?;&EN96)R96%K7W1E>'1A<F5A
M)RDI('L*("`@("1D:7-P;&%Y7VUS9R`]('!R96=?<F5P;&%C92@G+RA<<C]<
M;BE[,WTO)RP@)R0Q)RP@)&1I<W!L87E?;7-G*3L*?0H*+RH@06QT97(@=&AE
M(")$;VYE(B!B96AA=FEO<B!I9B!W92=R92!S96YD:6YG('1H92!M97-S86=E
M(&%F=&5R('-P96QL(&-H96-K+B`J+PII9B`H)&9?9&]N95]A8W1I;VX@/3T]
M("=S96YD)RD@>PH@("`@)'-P96QL7V-H96-K7V1O;F5?86-T:6]N(#T@)W-E
M;F1?;65S<V%G92<["B`@("`D<W!E;&Q?8VAE8VM?9&]N95]C87!T:6]N(#T@
M7R@B*%-E;F0@;65S<V%G92!A9G1E<B!A<'!L>6EN9R!A;&P@8VAA;F=E<R!M
M861E('1H=7,@9F%R+B`@0VAA;F=E<R!O;B!T:&4@8W5R<F5N="!S8W)E96X@
M=VEL;"!.3U0@8F4@87!P;&EE9"XI(BD["GT@96QS92!["B`@("`D<W!E;&Q?
M8VAE8VM?9&]N95]A8W1I;VX@/2`G<W!E;&Q?8VAE8VM?9&]N92<["B`@("`D
M<W!E;&Q?8VAE8VM?9&]N95]C87!T:6]N(#T@7R@B*%)E='5R;B!T;R!T:&4@
M8V]M<&]S92!S8W)E96X@869T97(@87!P;'EI;F<@86QL(&-H86YG97,@;6%D
M92!T:'5S(&9A<BX@($-H86YG97,@;VX@=&AE(&-U<G)E;G0@<V-R965N('=I
M;&P@3D]4(&)E(&%P<&QI960N*2(I.PI]"@``````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:6UP+W-M:6UE
M+G!H<```````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R,#<V,P`Q,#0Q-S,V,C<W,``P,3<P-#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:6UP+W-M:6UE+G!H<"QV(#(N-#@N-"XV(#(P,#8O,#(O,3`@,38Z-3`Z
M,S`@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*B\*"F9U;F-T:6]N(%]I
M;7!O<G1+97E$:6%L;V<H)'1A<F=E="D*>PH@("`@9VQO8F%L("1A8W1I;VY)
M1"P@)&YO=&EF:6-A=&EO;BP@)'!R969S+"`D<F5G:7-T<GDL("1S96QF55),
M.PH*("`@("1T:71L92`](%\H(DEM<&]R="!3+TU)344@2V5Y(BD["B`@("!R
M97%U:7)E($E-4%]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*
M("`@($E-4#HZ<W1A='5S*"D["B`@("!R97%U:7)E($E-4%]414U03$%415,@
M+B`G+W-M:6UE+VEM<&]R=%]K97DN:6YC)SL*?0H*9G5N8W1I;VX@7V=E=$EM
M<&]R=$ME>2@I"GL*("`@("1K97D@/2!5=&EL.CIG971&;W)M1&%T82@G:6UP
M;W)T7VME>2<I.PH@("`@:68@*"%E;7!T>2@D:V5Y*2D@>PH@("`@("`@(')E
M='5R;B`D:V5Y.PH@("`@?0H*("`@("1R97,@/2!"<F]W<V5R.CIW87-&:6QE
M57!L;V%D960H)W5P;&]A9%]K97DG+"!?*")K97DB*2D["B`@("!I9B`H(6ES
M7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B!F:6QE
M7V=E=%]C;VYT96YT<R@D7T9)3$536R=U<&QO861?:V5Y)UU;)W1M<%]N86UE
M)UTI.PH@("`@?2!E;'-E('L*("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T
M:6]N)UTM/G!U<V@H)')E<RP@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@<F5T
M=7)N.PH@("`@?0I]"@IF=6YC=&EO;B!?;W5T<'5T4&%S<W!H<F%S941I86QO
M9R@I"GL*("`@(&=L;V)A;"`D;F]T:69I8V%T:6]N+"`D<')E9G,L("1R96=I
M<W1R>2P@)'-E8W5R95]C:&5C:RP@)'-E;&954DP["@H@("`@:68@*&ES7V$H
M)'-E8W5R95]C:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H)'-E8W5R95]C:&5C:RP@)VAO<F1E+F5R<F]R)RD[
M"B`@("!]"@H@("`@)'1I=&QE(#T@7R@B4R]-24U%(%!A<W-P:')A<V4@26YP
M=70B*3L*("`@(')E<75I<F4@24U07U1%35!,051%4R`N("<O8V]M;6]N+6AE
M861E<BYI;F,G.PH@("`@)'-U8FUI=%]U<FP@/2!5=&EL.CIA9&1087)A;65T
M97(H)'-E;&954DPL("=A8W1I;VY)1"<L("=P<F]C97-S7W!A<W-P:')A<V5?
M9&EA;&]G)RD["B`@("!)35`Z.G-T871U<R@I.PH@("`@<F5Q=6ER92!)35!?
M5$5-4$Q!5$53("X@)R]S;6EM92]P87-S<&AR87-E+FEN8R<["GT*"F9U;F-T
M:6]N(%]A8W1I;VY7:6YD;W<H*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+U-E<W-I;VY/8FIE8W1S+G!H<"<["B`@("`D;VED(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W!A<W-P:')A<V5?86-T:6]N)RD["B`@("`D8V%C:&5397-S(#T@
M)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@("1C86-H
M95-E<W,M/G-E=%!R=6YE1FQA9R@D;VED+"!T<G5E*3L*("`@(%5T:6PZ.F-L
M;W-E5VEN9&]W2E,H)&-A8VAE4V5S<RT^<75E<GDH)&]I9"DI.PI]"@IF=6YC
M=&EO;B!?<F5L;V%D5VEN9&]W*"D*>PH@("`@571I;#HZ8VQO<V57:6YD;W=*
M4R@G;W!E;F5R+F9O8W5S*"D[;W!E;F5R+FQO8V%T:6]N+FAR968](B<@+B!5
M=&EL.CIG971&;W)M1&%T82@G<F5L;V%D)RD@+B`G(CLG*3L*?0H*9G5N8W1I
M;VX@7W1E>'17:6YD;W=/=71P=70H)&9I;&5N86UE+"`D;7-G+"`D:'1M;"`]
M(&9A;'-E*0I["B`@("`D='EP92`]("@D:'1M;"`_("=T97AT+VAT;6PG(#H@
M)W1E>'0O<&QA:6XG*2`N("<[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E
M="@I.PH@("`@)$=,3T)!3%-;)V)R;W=S97(G72T^9&]W;FQO861(96%D97)S
M*"1F:6QE;F%M92P@)'1Y<&4L('1R=64L('-T<FQE;B@D;7-G*2D["B`@("!E
M8VAO("1M<V<["GT*"F9U;F-T:6]N(%]P<FEN=$ME>4EN9F\H)&-E<G0I"GL*
M("`@("1K97E?:6YF;R`]("1'3$]"04Q36R=I;7!?<VUI;64G72T^8V5R=%1O
M2%1-3"@D8V5R="D["B`@("!I9B`H96UP='DH)&ME>5]I;F9O*2D@>PH@("`@
M("`@(%]T97AT5VEN9&]W3W5T<'5T*"=3+TU)344@2V5Y($EN9F]R;6%T:6]N
M)RP@7R@B26YV86QI9"!K97DB*2D["B`@("!](&5L<V4@>PH@("`@("`@(%]T
M97AT5VEN9&]W3W5T<'5T*"=3+TU)344@2V5Y($EN9F]R;6%T:6]N)RP@)&ME
M>5]I;F9O+"!T<G5E*3L*("`@('T*?0H*"D!D969I;F4H)TE-4%]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@24U07T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92!)35!?0D%312`N("<O;&EB
M+T-R>7!T+U--24U%+G!H<"<["@HD:6UP7W-M:6UE(#T@)FYE=R!)35!?4TU)
M344H*3L*)'-E8W5R95]C:&5C:R`]("1I;7!?<VUI;64M/G)E<75I<F5396-U
M<F5#;VYN96-T:6]N*"D["B1S96QF55),(#T@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=S;6EM92YP:'`G*3L*"B\J(%)U;B!T:')O=6=H('1H92!A8W1I;VX@
M:&%N9&QE<G,@*B\*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C
M=&EO;DE$)RD["G-W:71C:"`H)&%C=&EO;DE$*2!["F-A<V4@)V]P96Y?<&%S
M<W!H<F%S95]D:6%L;V<G.@H@("`@:68@*"1I;7!?<VUI;64M/F=E=%!A<W-P
M:')A<V4H*2`A/3T@9F%L<V4I('L*("`@("`@("!5=&EL.CIC;&]S95=I;F1O
M=TI3*"D["B`@("!](&5L<V4@>PH@("`@("`@(%]O=71P=71087-S<&AR87-E
M1&EA;&]G*"D["B`@("!]"B`@("!E>&ET.PH*8V%S92`G<')O8V5S<U]P87-S
M<&AR87-E7V1I86QO9R<Z"B`@("!I9B`H:7-?82@D<V5C=7)E7V-H96-K+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@7V]U='!U=%!A<W-P:')A<V5$:6%L
M;V<H*3L*("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G<&%S<W!H
M<F%S92<I*2!["B`@("`@("`@:68@*"1I;7!?<VUI;64M/G-T;W)E4&%S<W!H
M<F%S92A5=&EL.CIG971&;W)M1&%T82@G<&%S<W!H<F%S92<I*2D@>PH@("`@
M("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)W!A<W-P:')A<V5?86-T
M:6]N)RDI('L*("`@("`@("`@("`@("`@(%]A8W1I;VY7:6YD;W<H*3L*("`@
M("`@("`@("`@?2!E;'-E:68@*%5T:6PZ.F=E=$9O<FU$871A*"=R96QO860G
M*2D@>PH@("`@("`@("`@("`@("`@7W)E;&]A9%=I;F1O=R@I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@571I;#HZ8VQO<V57:6YD
M;W=*4R@I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@B26YV86QI9"!P87-S<&AR87-E
M(&5N=&5R960N(BP@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@(%]O=71P
M=71087-S<&AR87-E1&EA;&]G*"D["B`@("`@("`@?0H@("`@?2!E;'-E('L*
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*").;R!P87-S<&AR87-E(&5N
M=&5R960N(BP@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@7V]U='!U=%!A<W-P
M:')A<V5$:6%L;V<H*3L*("`@('T*("`@(&5X:70["@IC87-E("=D96QE=&5?
M:V5Y)SH*("`@("1I;7!?<VUI;64M/F1E;&5T95!E<G-O;F%L2V5Y<R@I.PH@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")097)S;VYA;"!3+TU)344@:V5Y
M<R!D96QE=&5D('-U8V-E<W-F=6QL>2XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@(&)R96%K.PH*8V%S92`G9&5L971E7W!U8FQI8U]K97DG.@H@("`@)')E
M<W5L="`]("1I;7!?<VUI;64M/F1E;&5T95!U8FQI8TME>2A5=&EL.CIG971&
M;W)M1&%T82@G96UA:6PG*2D["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S
M=6QT+"`D<F5S=6QT+3YG971#;V1E*"DI.PH@("`@?2!E;'-E('L*("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4R]-24U%(%!U8FQI
M8R!+97D@9F]R(%PB)7-<(B!W87,@<W5C8V5S<V9U;&QY(&1E;&5T960N(BDL
M(%5T:6PZ.F=E=$9O<FU$871A*"=E;6%I;"<I*2P@)VAO<F1E+G-U8V-E<W,G
M*3L*("`@('T*("`@(&)R96%K.PH*8V%S92`G:6UP;W)T7W!U8FQI8U]K97DG
M.@H@("`@7VEM<&]R=$ME>41I86QO9R@G<')O8V5S<U]I;7!O<G1?<'5B;&EC
M7VME>2<I.PH@("`@97AI=#L*"F-A<V4@)W!R;V-E<W-?:6UP;W)T7W!U8FQI
M8U]K97DG.@H@("`@)'!U8FQI8TME>2`](%]G971);7!O<G1+97DH*3L*("`@
M(&EF("AE;7!T>2@D<'5B;&EC2V5Y*2D@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H7R@B3F\@4R]-24U%('!U8FQI8R!K97D@:6UP;W)T960N(BDL
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@("1A8W1I;VY)1"`]("=I;7!O<G1?
M<'5B;&EC7VME>2<["B`@("`@("`@7VEM<&]R=$ME>41I86QO9R@G<')O8V5S
M<U]I;7!O<G1?<'5B;&EC7VME>2<I.PH@("`@?2!E;'-E('L*("`@("`@("`O
M*B!!9&0@=&AE('!U8FQI8R!K97D@=&\@=&AE('-T;W)A9V4@<WES=&5M+B`J
M+PH@("`@("`@("1K97E?:6YF;R`]("1I;7!?<VUI;64M/F%D9%!U8FQI8TME
M>2@D<'5B;&EC2V5Y*3L*("`@("`@("!I9B`H:7-?82@D:V5Y7VEN9F\L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"@D:V5Y7VEN9F\L("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`D86-T
M:6]N240@/2`G:6UP;W)T7W!U8FQI8U]K97DG.PH@("`@("`@("`@("!?:6UP
M;W)T2V5Y1&EA;&]G*"=P<F]C97-S7VEM<&]R=%]P=6)L:6-?:V5Y)RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"A?*")3+TU)344@4'5B;&EC($ME>2!S=6-C97-S9G5L;'D@861D960N(BDL
M("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@(%]R96QO8617:6YD;W<H
M*3L*("`@("`@("!]"B`@("!]"B`@("!E>&ET.PH*8V%S92`G=FEE=U]P=6)L
M:6-?:V5Y)SH*("`@("1K97D@/2`D:6UP7W-M:6UE+3YG9710=6)L:6-+97DH
M571I;#HZ9V5T1F]R;41A=&$H)V5M86EL)RDI.PH@("`@:68@*&ES7V$H)&ME
M>2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1K97D@/2`D:V5Y+3YG971-
M97-S86=E*"D["B`@("!]"B`@("!?=&5X=%=I;F1O=T]U='!U="@G4R]-24U%
M(%!U8FQI8R!+97DG+"`D:V5Y*3L*("`@(&5X:70["@IC87-E("=I;F9O7W!U
M8FQI8U]K97DG.@H@("`@)&ME>2`]("1I;7!?<VUI;64M/F=E=%!U8FQI8TME
M>2A5=&EL.CIG971&;W)M1&%T82@G96UA:6PG*2D["B`@("!I9B`H:7-?82@D
M:V5Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&ME>2`]("1K97DM/F=E
M=$UE<W-A9V4H*3L*("`@('T*("`@(%]P<FEN=$ME>4EN9F\H)&ME>2D["B`@
M("!E>&ET.PH*8V%S92`G=FEE=U]P97)S;VYA;%]P=6)L:6-?:V5Y)SH*("`@
M(%]T97AT5VEN9&]W3W5T<'5T*"=3+TU)344@4&5R<V]N86P@4'5B;&EC($ME
M>2<L("1I;7!?<VUI;64M/F=E=%!E<G-O;F%L4'5B;&EC2V5Y*"DI.PH@("`@
M97AI=#L*8V%S92`G:6YF;U]P97)S;VYA;%]P=6)L:6-?:V5Y)SH*("`@(%]P
M<FEN=$ME>4EN9F\H)&EM<%]S;6EM92T^9V5T4&5R<V]N86Q0=6)L:6-+97DH
M*2D["B`@("!E>&ET.PH*8V%S92`G=FEE=U]P97)S;VYA;%]P<FEV871E7VME
M>2<Z"B`@("!?=&5X=%=I;F1O=T]U='!U="@G4R]-24U%(%!E<G-O;F%L(%!R
M:79A=&4@2V5Y)RP@)&EM<%]S;6EM92T^9V5T4&5R<V]N86Q0<FEV871E2V5Y
M*"DI.PH@("`@97AI=#L*"F-A<V4@)VEM<&]R=%]P97)S;VYA;%]C97)T<R<Z
M"B`@("!?:6UP;W)T2V5Y1&EA;&]G*"=P<F]C97-S7VEM<&]R=%]P97)S;VYA
M;%]C97)T<R<I.PH@("`@97AI=#L*"F-A<V4@)W!R;V-E<W-?:6UP;W)T7W!E
M<G-O;F%L7V-E<G1S)SH*("`@(&EF("@A*"1P:V-S,3(@/2!?9V5T26UP;W)T
M2V5Y*"DI*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*").;R!P
M97)S;VYA;"!3+TU)344@8V5R=&EF:6-A=&5S(&EM<&]R=&5D+B(I+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("`D86-T:6]N240@/2`G:6UP;W)T7W!E<G-O
M;F%L7V-E<G1S)SL*("`@("`@("!?:6UP;W)T2V5Y1&EA;&]G*"=P<F]C97-S
M7VEM<&]R=%]P97)S;VYA;%]C97)T<R<I.PH@("`@?2!E;'-E('L*("`@("`@
M("`D<F5S(#T@)&EM<%]S;6EM92T^861D1G)O;5!+0U,Q,B@D<&MC<S$R+"!5
M=&EL.CIG971&;W)M1&%T82@G=7!L;V%D7VME>5]P87-S)RDL(%5T:6PZ.F=E
M=$9O<FU$871A*"=U<&QO861?:V5Y7W!K7W!A<W,G*2D["B`@("`@("`@:68@
M*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*%\H(E!E<G-O;F%L(%,O34E-12!C97)T:69I8V%T
M97,@3D]4(&EM<&]R=&5D.B`B*2`N("1R97,M/F=E=$UE<W-A9V4H*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@("`@("1A8W1I;VY)1"`]("=I;7!O<G1?
M<&5R<V]N86Q?8V5R=',G.PH@("`@("`@("`@("!?:6UP;W)T2V5Y1&EA;&]G
M*"=P<F]C97-S7VEM<&]R=%]P97)S;VYA;%]C97)T<R<I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B4R]-
M24U%(%!U8FQI8R]0<FEV871E($ME>7!A:7(@<W5C8V5S<V9U;&QY(&%D9&5D
M+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("!?<F5L;V%D5VEN
M9&]W*"D["B`@("`@("`@?0H@("`@?0H@("`@97AI=#L*"F-A<V4@)W-A=F5?
M871T86-H;65N=%]P=6)L:6-?:V5Y)SH*("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O4V5S<VEO;D]B:F5C=',N<&AP)SL*"B`@("`D8V%C:&5397-S(#T@)DAO
M<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@("1C97)T(#T@
M)&-A8VAE4V5S<RT^<75E<GDH571I;#HZ9V5T1F]R;41A=&$H)V-E<G0G*2D[
M"@H@("`@+RH@061D('1H92!P=6)L:6,@:V5Y('1O('1H92!S=&]R86=E('-Y
M<W1E;2X@*B\*("`@("1C97)T(#T@)&EM<%]S;6EM92T^861D4'5B;&EC2V5Y
M*"1C97)T+"!5=&EL.CIG971&;W)M1&%T82@G9G)O;2<I*3L*("`@(&EF("@D
M8V5R="`]/2!F86QS92D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B3F\@0V5R=&EF:6-A=&4@9F]U;F0B*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("!](&5L<V4@>PH@("`@("`@(%5T:6PZ.F-L;W-E5VEN9&]W2E,H*3L*("`@
M('T*("`@(&5X:70["@IC87-E("=U;G-E=%]P87-S<&AR87-E)SH*("`@(&EF
M("@D:6UP7W-M:6UE+3YG971087-S<&AR87-E*"D@(3T](&9A;'-E*2!["B`@
M("`@("`@)&EM<%]S;6EM92T^=6YS971087-S<&AR87-E*"D["B`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")087-S<&AR87-E('-U8V-E<W-F=6QL
M>2!U;FQO861E9"XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T*("`@(&)R
M96%K.PH*8V%S92`G<V%V95]O<'1I;VYS)SH*("`@("1P<F5F<RT^<V5T5F%L
M=64H)W5S95]S;6EM92<L(%5T:6PZ.F=E=$9O<FU$871A*"=U<V5?<VUI;64G
M*2D["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!R969E<F5N8V5S('-U
M8V-E<W-F=6QL>2!U<&1A=&5D+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@
M8G)E86L["GT*"B\J($=E="!L:7-T(&]F(%!U8FQI8R!+97ES+B`J+PHD<'5B
M:V5Y7VQI<W0@/2`D:6UP7W-M:6UE+3YL:7-T4'5B;&EC2V5Y<R@I.PII9B`H
M:7-?82@D<'5B:V5Y7VQI<W0L("=014%27T5R<F]R)RDI('L*("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H)'!U8FME>5]L:7-T+"`D<'5B:V5Y7VQI<W0M/F=E
M=$-O9&4H*2D["GT*"B\J($=E="!P87-S<&AR87-E("AI9B!A=F%I;&%B;&4I
M+B`J+PHD<&%S<W!H<F%S92`]("1I;7!?<VUI;64M/F=E=%!A<W-P:')A<V4H
M*3L*"G)E<75I<F4@24U07T)!4T4@+B`G+V-O;F9I9R]P<F5F<RYP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+U5)+G!H<"<["B1A<'`@/2`G:6UP
M)SL*4')E9G-?54DZ.F=E;F5R871E2&5A9&5R*"=S;6EM92<I.PH*+RH@268@
M4R]-24U%('!R969E<F5N8V4@;F]T(&%C=&EV92P@;W(@;W!E;G-S;"!02%`@
M97AT96YS:6]N(&YO="!A=F%I;&%B;&4L(&1O"B`J($Y/5"!S:&]W(%,O34E-
M12!!9&UI;B!S8W)E96XN("HO"B1O<&5N<W-L7V-H96-K(#T@)&EM<%]S;6EM
M92T^8VAE8VM&;W)/<&5N4U-,*"D["FEF("@A:7-?82@D;W!E;G-S;%]C:&5C
M:RP@)U!%05)?17)R;W(G*2`F)B`D<')E9G,M/F=E=%9A;'5E*"=U<V5?<VUI
M;64G*2D@>PH@("`@)&]P96YS;6EM97=I;B`]("1I;7!?<VUI;64M/F=E=$I3
M3W!E;E=I;D-O9&4H)V]P96Y?<&%S<W!H<F%S95]D:6%L;V<G*3L*("`@($AO
M<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<I.PH@("`@<F5Q=6ER92!)
M35!?5$5-4$Q!5$53("X@)R]S;6EM92]S;6EM92YI;F,G.PI](&5L<V4@>PH@
M("`@<F5Q=6ER92!)35!?5$5-4$Q!5$53("X@)R]S;6EM92]N;W1A8W1I=F4N
M:6YC)SL*?0H*<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@
M)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+P``````````````````
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,C<W-@`P,34Q-S<`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O4WEN8TU,+P``````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<P`#`Q-C,S-@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+P``````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-S``,#$W-3,U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$
M979I8V4O4#@P,"YP:'``````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q-S`V,0`Q,#0Q-S,V,C<W,``P,C`V-S<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%`X,#`O4#DP
M,"]0.3$P.@H@*B`M+2TM+2TM+2TM+2TM+2T*("H@0VAA<G-E=#H*("H@5&AI
M<R!D979I8V4@:7,@86)L92!T;R!H86YD;&4@551&+3@@86YD('-E;F1S(&ET
M<R!834P@<&%C:V%G97,@:6X@551&."X*("H@2&]W979E<B!E=F5N('1H;W5G
M:"!T:&4@6$U,(&ET<V5L9B!I<R!55$8M."P@:70@97AP96-T<R!T:&4@96YC
M;&]S960*("H@=F-A<F0M9&%T82!T;R!B92!)4T\M.#@U.2TQ('5N;&5S<R!E
M>'!L:6-I=&QY('-T871E9"!O=&AE<G=I<V4@*'5S:6YG('1H90H@*B!#2$%2
M4T54(&]P=&EO;BP@=VAI8V@@:7,@9&5P<F5C871E9"!F;W(@5D-!4D0@,RXP
M*0H@*@H@*B!%;F-O9&EN9SH*("H@4W1R:6YG('9A;'5E<R!A<F4@96YC;V1E
M9"`B455/5$5$+5!224Y404),12(*("H*("H@3W1H97(Z"B`J(%1H:7,@9&5V
M:6-E<R!H86YD;&5S('1A<VMS(&%N9"!E=F5N=',@:6X@;VYE(&1A=&%B87-E
M+@H@*@H@*B!!<R!T:&4@4#@P,"!W87,@=&AE(&9I<G-T(&1E=FEC92!T;R!W
M;W)K('=I=&@@<&%C:V%G92P@;6]S="!O9B!T:&4*("H@<F5Q=6ER960@8V]N
M=F5R<VEO;G,@87)E(&EN($1E=FEC92YP:'`G<R!D969A=6QT(&AA;F1L:6YG
M+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]$979I8V4O4#@P,"YP:'`L=B`Q
M+C<N,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z,S<@:F%N($5X<"`D"B`J"B`J($!A
M=71H;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@
M*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]$979I8V5?4#@P
M,"!E>'1E;F1S(%-Y;F--3%]$979I8V4@>PH*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@<')E9F5R<F5D(&-O;G1E;G1T>7!E(&]F('1H92!C;&EE;G0@
M9F]R('1H92!G:79E;@H@("`@("H@<WEN8R!D871A('1Y<&4@*&-O;G1A8W1S
M+W1A<VMS+VYO=&5S+V-A;&5N9&%R*2X*("`@("`J"B`@("`@*B!4:&4@<F5S
M=6QT(&ES('!A<W-E9"!A<R!A;B!O<'1I;VX@=&\@=&AE($AO<F1E($%022!E
M>'!O<G0@9G5N8W1I;VYS+@H@("`@("H@4&QE87-E(&YO=&4@=&AA="!T:&ES
M(&ES(&YO="!T:&4@8V]N=&5N=%1Y<&4@=6QT:6UA=&5L>2!P87-S960@=&\@
M=&AE"B`@("`@*B!C;&EE;G0@8G5T(')A=&AE<B!T:&4@8V]N=&5N=%1Y<&4@
M<')E<V5N=&5D('1O('1H92!(;W)D92!!4$D@97AP;W)T"B`@("`@*B!F=6YC
M=&EO;G,N"B`@("`@*@H@("`@("H@069T97(@=&AE(&1A=&$@:7,@<F5T<FEE
M=F5D(&9R;VT@:&]R9&4L(&-O;G9E<G1397)V97(R0VQI96YT(&-A;B!D;PH@
M("`@("H@<V]M92!P;W-T+7!R;V-E<W-I;F<@86YD('-E="!T:&4@8V]R<F5C
M="!C;VYT96YT5'EP92!A8V-E<'1A8FQE(&9O<@H@("`@("H@=&AE(&-L:65N
M="X*("`@("`J"B`@("`@*B!4:&ES(&ES(&$@;&EK96QY(&-A;F1I9&%T92!F
M;W(@;6]D:69I8V%T:6]N(&EN(&-O;F-R971E('-U8F-L87-S97,Z"B`@("`@
M*B!I;F1I=FED=6%L(&1E=FEC97,@;6EG:'0@<')E9F5R(&]T:&5R(&-H87)S
M971S(&]R(&]T:&5R(&5N8V]D:6YG<PH@("`@("H@*&-U<G)E;G1L>3H@455/
M5$5$+5!224Y404),12D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')E9F5R
M<F5D0V]N=&5N=%1Y<&5#;&EE;G0H)'1Y<&4I"B`@("!["B`@("`@("`@:68@
M*"1T>7!E(#T]("=C;VYT86-T<R<I('L*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=#;VYT96YT5'EP92<@/3X@)W1E>'0O>"UV8V%R9"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`G14Y#3T1)3D<G(#T^("=154]4140M4%))3E1!
M0DQ%)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=#2$%24T54)R`]/B`D
M1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UTI.PH@("`@("`@('T@
M96QS96EF("@D='EP92`]/2`G;F]T97,G*2!["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@G0V]N=&5N=%1Y<&4G(#T^("=T97AT+W@M=FYO=&4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)T5.0T]$24Y')R`]/B`G455/5$5$+5!2
M24Y404),12<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G0TA!4E-%5"<@
M/3X@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==*3L*("`@("`@
M("!](&5L<V5I9B`H)'1Y<&4@/3T@)W1A<VMS)RD@>PH@("`@("`@("`@("!R
M971U<FX@87)R87DH)T-O;G1E;G14>7!E)R`]/B`G=&5X="]X+79T;V1O)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("=%3D-/1$E.1R<@/3X@)U%53U1%
M1"U04DE.5$%"3$4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)T-(05)3
M150G(#T^("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72D["B`@
M("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=C86QE;F1A<B<I('L*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=#;VYT96YT5'EP92<@/3X@)W1E>'0O>"UV
M8V%L96YD87(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)T5.0T]$24Y'
M)R`]/B`G455/5$5$+5!224Y404),12<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G0TA!4E-%5"<@/3X@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!
M4E-%5"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)U9%4E-)3TXG(#T^
M("<Q+C`G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV
M97)T('1H92!C;VYT96YT+@H@("`@("H*("`@("`J($-U<G)E;G1L>2!S=')I
M<',@=6ED("AP<FEM87)Y(&ME>2D@:6YF;W)M871I;VX@87,@8VQI96YT(&%N
M9`H@("`@("H@<V5R=F5R(&UI9VAT('5S92!D:69F97)E;G0@;VYE<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@(%1H92!C
M;VYT96YT('1O(&-O;G9E<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT
M96YT5'EP92`@(%1H92!C;VYT96YT5'EP92!O9B!T:&4@8V]N=&5N="X*("`@
M("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@87)R87DH)&YE=V-O
M;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!C;VYV97)T960@8V]N=&5N="!A;F0@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AP;W-S:6)L
M>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O;G9E<G1#;&EE;G0R4V5R=F5R*"1C;VYT96YT+"`D8V]N=&5N=%1Y
M<&4I"B`@("!["B`@("`@("`@;&ES="@D8V]N=&5N="P@)&-O;G1E;G14>7!E
M*2`]"B`@("`@("`@("`@('!A<F5N=#HZ8V]N=F5R=$-L:65N=#)397)V97(H
M)&-O;G1E;G0L("1C;VYT96YT5'EP92D["@H@("`@("`@("\J(%`X,#`@<V5N
M9',@8V%T96=O<FEE<R!A<R`B6"U#871E9V]R>2(N(%)E;6]V92!T:&4@(E@M
M(CH@*B\*("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN
M?%QR?%QN*4-!5$5'3U))15,Z6"TO)RP@)UPQ0T%414=/4DE%4SHG+"`D8V]N
M=&5N="P@,2D["@H@("`@("`@("\J(%`X,#`@<V5N9',@86QL(&1A>2!E=F5N
M=',@87,@<RYT:"X@;&EK90H@("`@("`@("`J($144U1!4E0Z,C`P-3`U,#54
M,#`P,#`P6EY-"B`@("`@("`@("H@1%1%3D0Z,C`P-3`U,#54,C0P,#`P6EY-
M"B`@("`@("`@("H@5&AI<R!I<R!N;R!L;VYG97(@86X@86QL(&1A>2!E=F5N
M="!W:&5N(&-O;G9E<G1E9"!T;R!L;V-A;"!T:6UE>F]N92X*("`@("`@("`@
M*B!3;R!M86YU86QL>2!H86YD;&4@=&AI<RX*("`@("`@("`@*B`J+PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI1%135$%25#HN*E0P
M,#`P,#!:*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;G1E;G0I"B`@("`@("`@("`@("8F('!R96=?;6%T8V@H)R\H7')<;GQ<
M<GQ<;BE$5$5.1#HH7&1<9%QD7&0I*%QD7&0I*%QD7&0I5#(T,#`P,%HH7')<
M;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N
M="P@)&TI*2!["B`@("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E
M*"<O*%QR7&Y\7')\7&XI1%135$%25#HH+BHI5#`P,#`P,%HH7')<;GQ<<GQ<
M;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B0Q
M1%135$%25#M604Q513U$051%.B0R)#,B+"`D8V]N=&5N="D["B`@("`@("`@
M("`@("\J($5N9"!T:6UE<W1A;7`@;75S="!B92!C;VYV97)T960@=&\@;F5X
M="!D87DG<R!D871E+B`J+PH@("`@("`@("`@("`D<R`](&1A=&4H)UEM9"<L
M(&UK=&EM92@P+"`P+"`P+"`D;5LS72P@)&U;-%TL("1M6S)=*2`K(#(T*C,V
M,#`I.PH@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<
M<EQN?%QR?%QN*41414Y$.B@N*BE4,C0P,#`P6BA<<EQN?%QR?%QN*2\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B)#%$5$5.1#M6
M04Q513U$051%.B1S)#,B+"`D8V]N=&5N="D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@("`@("`D
M9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@("`@
M("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L
M(")<;FEN<'5T(&-O;G9E<G1E9"!F;W(@<V5R=F5R.B`D8V]N=&5N=%1Y<&5<
M;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L)&-O;G1E;G0@+B`B
M7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H)&9P*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1C;VYT96YT
M+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R
M=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@8F%C:V5N9"!T;R!A(&9O<FUA="!S
M=6ET86)L92!F;W(@=&AE"B`@("`@*B!C;&EE;G0@9&5V:6-E+@H@("`@("H*
M("`@("`J(%-T<FEP<R!T:&4@=6ED("AP<FEM87)Y(&ME>2D@:6YF;W)M871I
M;VX@87,@8VQI96YT(&%N9"!S97)V97(@;6EG:'0@=7-E"B`@("`@*B!D:69F
M97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT
M96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O;G9E<G0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VYT96YT5'EP92`@(%1H92!C;VYT96YT5'EP92!O9B!C
M;VYT96YT(&%S(')E='5R;F5D(&9R;VT*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(&)A8VME;F0N"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("`@("`@("`@("`@("`@(&%R<F%Y*"1N97=C;VYT96YT+"`D;F5W8V]N
M=&5N=%1Y<&4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@8V]N=F5R=&5D(&-O;G1E;G0@86YD('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`H<&]S<VEB;'D@8VAA;F=E9"D@;F5W
M($-O;G1E;G14>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T4V5R
M=F5R,D-L:65N="@D8V]N=&5N="P@)&-O;G1E;G14>7!E*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@("`@;&ES="@D8V]N=&5N="P@
M)&-O;G1E;G14>7!E*2`]"B`@("`@("`@("`@('!A<F5N=#HZ8V]N=F5R=%-E
M<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D["@H@("`@("`@
M("\J($-O;G9E<G0@86QL(&1A>2!E=F5N=',N("HO"B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)R\H7')<;GQ<<GQ<;BE$5%-405)4.U9!3%5%/41!5$4Z*%QD
M>SA]*2\G+`H@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT*0H@("`@
M("`@("`@("`F)B!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI1%1%3D0[5D%,
M544]1$%413HH7&1<9%QD7&0I*%QD7&0I*%QD7&0I+R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;G1E;G0L("1M*2D@>PH@("`@("`@("`@("`D
M8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*4144U1!4E0[
M5D%,544]1$%413HH7&1[.'TI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("(D,4144U1!4E0Z)#)4,#`P,#`P6B(L("1C;VYT96YT
M*3L*("`@("`@("`@("`@+RH@16YD(&1A=&4@;75S="!B92!C;VYV97)T960@
M=&\@=&EM97-T86UP+B`J+PH@("`@("`@("`@("`D<R`](&1A=&4H)UEM9"<L
M(&UK=&EM92@P+"`P+"`P+"`D;5LS72P@)&U;-%TL("1M6S)=*2`M(#(T*C,V
M,#`I.PH@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<
M<EQN?%QR?%QN*41414Y$.U9!3%5%/41!5$4Z*%QD>SA]*2\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B)#%$5$5.1#LZ)'MS?50R
M-#`P,#!:(BP@)&-O;G1E;G0I.PH@("`@("`@('T*"B`@("`@("`@:68@*$1%
M0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@("`@("`@("`@)&9P(#T@0&9O
M<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A)RD["B`@("`@("`@("`@(&EF
M("@D9G`I('L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`B7&YO=71P
M=70@8V]N=F5R=&5D(&9O<B!C;&EE;G0@*"1C;VYT96YT5'EP92DZ7&XB*3L*
M("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`D8V]N=&5N="`N(")<;B(I
M.PH@("`@("`@("`@("`@("`@0&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)&-O;G1E;G0L("1C
M;VYT96YT5'EP92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;VUE(&1E=FEC
M97,@;&EK92!T:&4@4V]N>2!%<FEC<W-O;B!0.#`P+U`Y,#`O4#DQ,"!H86YD
M;&4@=G1O9&]S("AT87-K<RD*("`@("`J(&%N9"!V979E;G1S(&EN('1H92!S
M86UE(")C86QE;F1A<B(@<WEN8RX*("`@("`J(%1H:7,@<F5Q=6ER97,@<W!E
M8VEA;"!A8W1I;VYS(&]N(&]U<B!S:61E(&%S('=E('-T;W)E('1H:7,@:6X@
M9&EF9F5R96YT"B`@("`@*B!D871A8F%S97,@*&YA9R!A;F0@:W)O;F]L:71H
M*2X*("`@("`J(%1H:7,@9G5N8W1I;VX@8V]U;&0@9&ER96-T;'D@<F5T=7)N
M('1R=64@8G5T('1R:65S('1O(&)E(&$@8FET(&UO<F4*("`@("`J(&=E;F5R
M:6,@<V\@:70@;6EG:'0@=V]R:R!F;W(@;W1H97(@<&AO;F5S(&%S('=E;&PN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L951A<VMS26Y#86QE;F1A<B@I
M"B`@("!["B`@("`@("`@)&1I(#T@)'1H:7,M/F1E=FEC94EN9F\H*3L*"B`@
M("`@("`@:68@*"%E;7!T>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C86QE;F1A
M<B==6R="14=)3B==+3Y?5F%L16YU;5LG5D5614Y4)UTI("8F"B`@("`@("`@
M("`@("%E;7!T>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C86QE;F1A<B==6R="
M14=)3B==+3Y?5F%L16YU;5LG5E1/1$\G72DI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<&%R96YT.CIH
M86YD;&5487-K<TEN0V%L96YD87(H*3L*("`@('T*"B`@("!F=6YC=&EO;B!N
M965D<T-A=&5G;W)Y36%P<&EN9R@I"B`@("!["B`@("`@("`@+R\@4#@P,"!U
M<V5S(&YU;65R:6,@8V%T96=O<GD@8V]D97,N"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+U-Y;F,T:BYP:'``````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-30U-C,`,3`T,3<S-C(W-S``,#(Q-#,R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH*+RHJ
M"B`J(%-Y;F,T:B`H=W=W+G-Y;F,T:BYO<F<I"B`J"B`J(%1H92!3>6YC-$H@
M;W5T;&]O:R!C;VYV97)T97(@=7-E<R!I=',@;F%T:79E(%-)1B!F;W)M870@
M9F]R(&1A=&$*("H@97AC:&%N9V4N($-O;G9E<G-I;VX@=&\@=&5X="]V8V%L
M96YD87(@971C+B!I<R!D;VYE(&)Y"B`J(%-I9D-O;G9E<G1E<BYP:'`@5&AE
M(&-O;FYE8W1O<B!S965M<R!N;W0@<W5P<&]R="!$979);F8*("H@:6YF;W)M
M871I;VXL('-O(%-Y;F--3%]$979I8V4@8V%N(&]N;'D@9&5T96-T(&ET(&)Y
M('1H92!D96-I8V4@240Z"B`J('-O(&EN('1H92!C;VYN96-T;W(@8V]N9FEG
M=7)A=&EO;B!T:&4@9&5V:6-E($E$(&UU<W0@8F4@<V5T('1O"B`J("=S8RUP
M:6TM/'1Y<&4^)R!W:&EC:"!S:&]U;&0@8F4@=&AE(&1E9F%U;'0@86YY:&]W
M+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]$979I8V4O4WEN8S1J+G!H<"QV
M(#$N."XR+C0@,C`P-B\P,2\P,2`R,3HR.#HS-R!J86X@17AP("0*("H*("H@
M0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^
M"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T1E=FEC95]S
M>6YC-&H@97AT96YD<R!3>6YC34Q?1&5V:6-E('L*"B`@("`O*BH*("`@("`J
M($-O;G9E<G0@=&AE(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0W5R<F5N=&QY
M('-T<FEP<R!U:60@*'!R:6UA<GD@:V5Y*2!I;F9O<FUA=&EO;B!A<R!C;&EE
M;G0@86YD"B`@("`@*B!S97)V97(@;6EG:'0@=7-E(&1I9F9E<F5N="!O;F5S
M+@H@("`@("H*("`@("`J($-H87)S970@8V]N=F5R<VEO;G,@;6EG:'0@8F4@
M861D960@:&5R92!T;V\N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1#
M;&EE;G0R4V5R=F5R*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@
M("`@("`@;&ES="@D8V]N=&5N="P@)&-O;G1E;G14>7!E*2`]"B`@("`@("`@
M("`@('!A<F5N=#HZ8V]N=F5R=$-L:65N=#)397)V97(H)&-O;G1E;G0L("1C
M;VYT96YT5'EP92D["@H@("`@("`@('-W:71C:"`H)&-O;G1E;G14>7!E*2![
M"B`@("`@("`@8V%S92`G<VEF+VYO=&4G(#H*("`@("`@("!C87-E("=T97AT
M+W@M<S1J+7-I9FXG(#H*("`@("`@("`@("`@)&-O;G1E;G0@/2`D=&AI<RT^
M<VEF,G9N;W1E*&)A<V4V-%]D96-O9&4H)&-O;G1E;G0I*3L*("`@("`@("`@
M("`@)&-O;G1E;G14>7!E(#T@)W1E>'0O>"UV;F]T92<["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=S:68O8V]N=&%C="<@.@H@("`@("`@
M(&-A<V4@)W1E>'0O>"US-&HM<VEF8R<@.@H@("`@("`@("`@("`D8V]N=&5N
M="`]("1T:&ES+3YS:68R=F-A<F0H8F%S938T7V1E8V]D92@D8V]N=&5N="DI
M.PH@("`@("`@("`@("`D8V]N=&5N=%1Y<&4@/2`G=&5X="]X+79C87)D)SL*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-I9B]C86QE;F1A
M<B<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"US-&HM<VEF92<@.@H@("`@("`@
M("`@("`D8V]N=&5N="`]("1T:&ES+3YS:68R=F5V96YT*&)A<V4V-%]D96-O
M9&4H)&-O;G1E;G0I*3L*("`@("`@("`@("`@)&-O;G1E;G14>7!E(#T@)W1E
M>'0O>"UV979E;G0G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`G<VEF+W1A<VLG(#H*("`@("`@("!C87-E("=T97AT+W@M<S1J+7-I9G0G
M(#H*("`@("`@("`@("`@)&-O;G1E;G0@/2`D=&AI<RT^<VEF,G9T;V1O*&)A
M<V4V-%]D96-O9&4H)&-O;G1E;G0I*3L*("`@("`@("`@("`@)&-O;G1E;G14
M>7!E(#T@)W1E>'0O>"UV=&]D;R<["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*
M("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L
M("=A)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@
M($!F=W)I=&4H)&9P+"`B7&YI;G!U="!C;VYV97)T960@9F]R('-E<G9E<CH@
M)&-O;G1E;G14>7!E7&XB*3L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P
M+"1C;VYT96YT("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F
M<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A
M<G)A>2@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-O;G9E<G1S('1H92!C;VYT96YT(&9R;VT@=&AE(&)A8VME;F0@
M=&\@82!F;W)M870@<W5I=&%B;&4@9F]R('1H90H@("`@("H@8VQI96YT(&1E
M=FEC92X*("`@("`J"B`@("`@*B!3=')I<',@=&AE('5I9"`H<')I;6%R>2!K
M97DI(&EN9F]R;6%T:6]N(&%S(&-L:65N="!A;F0@<V5R=F5R(&UI9VAT('5S
M90H@("`@("H@9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]N=&5N="`@("`@("!4:&4@8V]N=&5N="!T;R!C;VYV97)T
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@(%1H92!C;VYT
M96YT5'EP92!O9B!C;VYT96YT(&%S(')E='5R;F5D(&9R;VT*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&)A8VME;F0*("`@("`J
M($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@87)R87DH)&YE=V-O;G1E
M;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1H92!C;VYV97)T960@8V]N=&5N="!A;F0@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AP;W-S:6)L>2!C
M:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I
M"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@("!L:7-T
M*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@<&%R96YT
M.CIC;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N="P@)&-O;G1E;G14>7!E
M*3L*"B`@("`@("`@<W=I=&-H("@D8V]N=&5N=%1Y<&4I('L*("`@("`@("!C
M87-E("=T97AT+V-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+6EC
M86QE;F1A<B<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"UV8V%L96YD87(G(#H*
M("`@("`@("!C87-E("=T97AT+W@M=F5V96YT)R`Z"B`@("`@("`@("`@("1C
M;VYT96YT(#T@)'1H:7,M/G9E=F5N=#)S:68H)&-O;G1E;G0I.PH@("`@("`@
M("`@("`D8V]N=&5N="`](&)A<V4V-%]E;F-O9&4H)&-O;G1E;G0I.PH@("`@
M("`@("`@("`D8V]N=&5N=%1Y<&4@/2`G<VEF+V-A;&5N9&%R)SL*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W1E>'0O>"UV=&]D;R<@.@H@
M("`@("`@("`@("`D8V]N=&5N="`]("1T:&ES+3YV=&]D;S)S:68H)&-O;G1E
M;G0I.PH@("`@("`@("`@("`D8V]N=&5N="`](&)A<V4V-%]E;F-O9&4H)&-O
M;G1E;G0I.PH@("`@("`@("`@("`D8V]N=&5N=%1Y<&4@/2`G<VEF+W1A<VLG
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G=&5X="]X+79C
M87)D)R`Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)'1H:7,M/G9C87)D,G-I
M9B@D8V]N=&5N="D["B`@("`@("`@("`@("1C;VYT96YT(#T@8F%S938T7V5N
M8V]D92@D8V]N=&5N="D["B`@("`@("`@("`@("1C;VYT96YT5'EP92`]("=S
M:68O8V]N=&%C="<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=T97AT+W@M=FYO=&4G.@H@("`@("`@("`@("`D8V]N=&5N="`]("1T:&ES
M+3YV;F]T93)S:68H)&-O;G1E;G0I.PH@("`@("`@("`@("`D8V]N=&5N="`]
M(&)A<V4V-%]E;F-O9&4H)&-O;G1E;G0I.PH@("`@("`@("`@("`D8V]N=&5N
M=%1Y<&4@/2`G<VEF+VYO=&4G.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"@H@("`@("`@(&EF("A$14)51TQ/1U])0T%,14Y$05)$051!*2!["B`@
M("`@("`@("`@("1F<"`]($!F;W!E;B@G+W1M<"]S>6YC+VQO9RYT>'0G+"`G
M82<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@("!`
M9G=R:71E*"1F<"P@<V5R:6%L:7IE*"1C;VYT96YT5'EP92DI.PH@("`@("`@
M("`@("`@("`@0&9W<FET92@D9G`L(")<;F-O;G9E<G1E9"!F;W(@<WEN8S1J
M(&-L:65N=#H@)&-O;G1E;G14>7!E7&XB*3L*("`@("`@("`@("`@("`@($!F
M=W)I=&4H)&9P+"!B87-E-C1?9&5C;V1E*"1C;VYT96YT*2`N(")<;B(I.PH@
M("`@("`@("`@("`@("`@0&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)&-O;G1E;G0L("1C;VYT
M96YT5'EP92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-O9&5S(&$@<VEF
M('AM;"!S=')I;F<@=&\@86X@87-S;V-I871I=F4@87)R87DN"B`@("`@*@H@
M("`@("H@475I8VL@:&%C:R!T;R!C;VYV97)T(&9R;VT@=&5X="]V8V%R9"!A
M;F0@=&5X="]V8V%L96YD87(@=&\*("`@("`J(%-Y;F,T2B=S('!R;W!R:65T
M97)Y('-I9B!D871A='EP97,@86YD('9I8V4@=F5R<V$N("!&;W(@9&5T86EL
M<PH@("`@("H@86)O=70@=&AE('-I9B!F;W)M870@<V5E('1H92!A<'!E;F1I
M>"!O9B!T:&4@9&5V96QO<&5R(&=U:61E(&]N"B`@("`@*B!W=W<N<WEN8S1J
M+F]R9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S:68@($$@<VEF('-T<FEN9R!L:6ME(#QK
M,3YV,29G=#L\+VLQ/CQK,CYV,CPO:S(^"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@07-S;V,@87)R87D@:6X@=71F."!L:6ME(&%R<F%Y("@G:S$G
M(#T^("=V,3XG+"`G:S(G(#T^("=V,B<I.PH@("`@("HO"B`@("!F=6YC=&EO
M;B!S:68R87)R87DH)'-I9BD*("`@('L*("`@("`@("`D<B`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<O/"A;7CY=*BD^*%M>/%TJ
M*3Q<+UPQ/B]S:2<L("1S:68L("1M871C:&5S+"!04D5'7U-%5%]/4D1%4BDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&UA=&-H97,@87,@)&UA=&-H*2![
M"B`@("`@("`@("`@("`@("`D<ELD;6%T8VA;,5U=(#T@:'1M;%]E;G1I='E?
M9&5C;V1E*"1M871C:%LR72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1R.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC;V1E
M<R!A;B!A<W-O8RX@87)R87D@=&\@<VEF('AM;`H@("`@("H*("`@("`J(%%U
M:6-K(&AA8VL@=&\@8V]N=F5R="!F<F]M('1E>'0O=F-A<F0@86YD('1E>'0O
M=F-A;&5N9&%R('1O"B`@("`@*B!3>6YC-$HG<R!P<F]P<FEE=&5R>2!S:68@
M9&%T871Y<&5S(&%N9"!V:6-E('9E<G-A+B`@1F]R(&1E=&%I;',*("`@("`J
M(&%B;W5T('1H92!S:68@9F]R;6%T('-E92!T:&4@87!P96YD:7@@;V8@=&AE
M(&1E=F5L;W!E<B!G=6ED92!O;@H@("`@("H@=W=W+G-Y;F,T:BYO<F<N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1A<G)A>2`@06X@87-S;V,@87)R87DN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!R97-U;'1I;F<@6$U,('-T<FEN9RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@87)R87DR<VEF*"1A<G)A>2P@)'!R93TG
M)RP@)'!O<W0])R<I"B`@("!["B`@("`@("`@)'-E87)C:"`](&%R<F%Y*"<\
M)RP@)SXG*3L*("`@("`@("`D<F5P;&%C92`](&%R<F%Y*"<F;'0[)RP@)R9G
M=#LG*3L*"B`@("`@("`@)'(@/2`D<')E.PH@("`@("`@(&9O<F5A8V@@*"1A
M<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D<B`N/2`G
M/"<@+B`D:V5Y("X@)SXG("X*("`@("`@("`@("`@("`@('-T<E]R97!L86-E
M*"1S96%R8V@L("1R97!L86-E+"`D=F%L=64I("X*("`@("`@("`@("`@("`@
M("<\+R<@+B`D:V5Y("X@)SXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1R("X@)'!O<W0["B`@("!]"@H@("`@9G5N8W1I;VX@<VEF,G9N;W1E*"1S
M:68I"B`@("!["B`@("`@("`@)&$@/2`D=&AI<RT^<VEF,F%R<F%Y*"1S:68I
M.PH*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["B`@
M("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G5D524TE/3B<L("<Q+C$G*3L*
M("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=04D]$240G+"`G+2\O5&AE
M($AO<F1E(%!R;VIE8W0O+TUN96UO("\O14XG*3L*("`@("`@("`D:4-A;"T^
M<V5T071T<FEB=71E*"=-151(3T0G+"`G4%5"3$E32"<I.PH*("`@("`@("`D
M=FYO=&4@/2`F2&]R9&5?:4-A;&5N9&%R.CIN97=#;VUP;VYE;G0H)W9N;W1E
M)RP@)&E#86PI.PH@("`@("`@("1V;F]T92T^<V5T071T<FEB=71E*"="3T19
M)RP@:7-S970H)&%;)T)O9'DG72D@/R`D85LG0F]D>2==(#H@)R<I.PH*("`@
M("`@("!R971U<FX@)'9N;W1E+3YE>'!O<G1V0V%L96YD87(H*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!S:68R=F-A<F0H)'-I9BD*("`@('L*("`@("`@("`D
M82`]("1T:&ES+3YS:68R87)R87DH)'-I9BD["@H@("`@("`@("1I0V%L(#T@
M)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("`D:4-A;"T^<V5T071T
M<FEB=71E*"=615)324].)RP@)S(N,2<I.PH@("`@("`@("1I0V%L+3YS971!
M='1R:6)U=&4H)U!23T1)1"<L("<M+R]4:&4@2&]R9&4@4')O:F5C="\O36YE
M;6\@+R]%3B<I.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)TU%5$A/
M1"<L("=054),25-()RD["@H@("`@("`@("1V8V%R9"`]("9(;W)D95]I0V%L
M96YD87(Z.FYE=T-O;7!O;F5N="@G=F-A<F0G+"`D:4-A;"D["@H@("`@("`@
M("1V8V%R9"T^<V5T071T<FEB=71E*"=&3B<L("1A6R=&:6QE07,G72D["B`@
M("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)TY)0TM.04U%)RP@)&%;)TYI
M8VM.86UE)UTI.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=414PG
M+"`D85LG2&]M951E;&5P:&]N94YU;6)E<B==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=465!%)ST^)TA/344G*2D["B`@("`@("`@
M)'9C87)D+3YS971!='1R:6)U=&4H)U1%3"<L("1A6R="=7-I;F5S<U1E;&5P
M:&]N94YU;6)E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=465!%)ST^)U=/4DLG*2D["B`@("`@("`@)'9C87)D+3YS971!='1R
M:6)U=&4H)U1%3"<L("1A6R=-;V)I;&5496QE<&AO;F5.=6UB97(G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G5%E012<]/B=#14Q,
M)RDI.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=414PG+"`D85LG
M0G5S:6YE<W-&87A.=6UB97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G5%E012<]/B=&05@G*2D["B`@("`@("`@)'9C87)D+3YS
M971!='1R:6)U=&4H)T5-04E,)RP@)&%;)T5M86EL,4%D9')E<W,G72D["B`@
M("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)U1)5$Q%)RP@)&%;)TIO8E1I
M=&QE)UTI.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=/4D<G+"`D
M85LG0V]M<&%N>4YA;64G72D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U
M=&4H)TY/5$4G+"`D85LG0F]D>2==*3L*("`@("`@("`D=F-A<F0M/G-E=$%T
M=')I8G5T92@G55),)RP@)&%;)U=E8E!A9V4G72D["@H@("`@("`@("1V(#T@
M87)R87DH"B`@("`@("`@("`@(%9#05)$7TY?1D%-24Q9("`@("`@/3X@)&%;
M)TQA<W1.86UE)UTL"B`@("`@("`@("`@(%9#05)$7TY?1TE614X@("`@("`@
M/3X@)&%;)T9I<G-T3F%M92==+`H@("`@("`@("`@("!60T%21%].7T%$1$P@
M("`@("`@(#T^("1A6R=-:61D;&5.86UE)UTL"B`@("`@("`@("`@(%9#05)$
M7TY?4%)%1DE8("`@("`@/3X@)&%;)U1I=&QE)UTL"B`@("`@("`@("`@(%9#
M05)$7TY?4U5&1DE8("`@("`@/3X@)&%;)U-U9F9I>"=="B`@("`@("`@*3L*
M("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G3B<L(&EM<&QO9&4H)SLG
M+"`D=BDL(&%R<F%Y*"DL(&9A;'-E+"`D=BD["@H@("`@("`@("1V(#T@87)R
M87DH"B`@("`@("`@("`@(%9#05)$7T%$4E]03T(@("`@("`@("`@(#T^("1A
M6R=(;VUE061D<F5S<U!O<W1/9F9I8V5";W@G72P*("`@("`@("`@("`@5D-!
M4D1?04127T585$5.1"`@("`@("`@/3X@)R<L"B`@("`@("`@("`@(%9#05)$
M7T%$4E]35%)%150@("`@("`@(#T^("1A6R=(;VUE061D<F5S<U-T<F5E="==
M+`H@("`@("`@("`@("!60T%21%]!1%)?3$]#04Q)5%D@("`@("`]/B`D85LG
M2&]M94%D9')E<W-#:71Y)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E]214=)
M3TX@("`@("`@(#T^("1A6R=(;VUE061D<F5S<U-T871E)UTL"B`@("`@("`@
M("`@(%9#05)$7T%$4E]03U-40T]$12`@("`@(#T^("1A6R=(;VUE061D<F5S
M<U!O<W1A;$-O9&4G72P*("`@("`@("`@("`@5D-!4D1?04127T-/54Y44ED@
M("`@("`@/3X@)&%;)TAO;65!9&1R97-S0V]U;G1R>2==+`H@("`@("`@("D[
M"B`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)T%$4B<L(&EM<&QO9&4H
M)SLG+"`D=BDL(&%R<F%Y*"=465!%)R`]/B`G2$]-12<@*2P@=')U92P@)'8I
M.PH*("`@("`@("`D=B`](&%R<F%Y*`H@("`@("`@("`@("!60T%21%]!1%)?
M4$]"("`@("`@("`@("`]/B`D85LG0G5S:6YE<W-!9&1R97-S4&]S=$]F9FEC
M94)O>"==+`H@("`@("`@("`@("!60T%21%]!1%)?15A414Y$("`@("`@("`]
M/B`G)RP*("`@("`@("`@("`@5D-!4D1?04127U-44D5%5"`@("`@("`@/3X@
M)&%;)T)U<VEN97-S061D<F5S<U-T<F5E="==+`H@("`@("`@("`@("!60T%2
M1%]!1%)?3$]#04Q)5%D@("`@("`]/B`D85LG0G5S:6YE<W-!9&1R97-S0VET
M>2==+`H@("`@("`@("`@("!60T%21%]!1%)?4D5'24].("`@("`@("`]/B`D
M85LG0G5S:6YE<W-!9&1R97-S4W1A=&4G72P*("`@("`@("`@("`@5D-!4D1?
M04127U!/4U1#3T1%("`@("`@/3X@)&%;)T)U<VEN97-S061D<F5S<U!O<W1A
M;$-O9&4G72P*("`@("`@("`@("`@5D-!4D1?04127T-/54Y44ED@("`@("`@
M/3X@)&%;)T)U<VEN97-S061D<F5S<T-O=6YT<GDG72P*("`@("`@("`I.PH*
M("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G0412)RP@:6UP;&]D92@G
M.R<L("1V*2P@87)R87DH)U194$4G(#T^("=73U)+)R`I+"!T<G5E+"`D=BD[
M"@H@("`@("`@(')E='5R;B`D=F-A<F0M/F5X<&]R='9#86QE;F1A<B@I.PH@
M("`@?0H*("`@(&9U;F-T:6]N('-I9C)V979E;G0H)'-I9BD*("`@('L*("`@
M("`@("`D82`]("1T:&ES+3YS:68R87)R87DH)'-I9BD["@H@("`@("`@("1I
M0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("`D:4-A;"T^
M<V5T071T<FEB=71E*"=615)324].)RP@)S$N,"<I.PH@("`@("`@("1I0V%L
M+3YS971!='1R:6)U=&4H)U!23T1)1"<L("<M+R]4:&4@2&]R9&4@4')O:F5C
M="\O36YE;6\@+R]%3B<I.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H
M)TU%5$A/1"<L("=054),25-()RD["@H@("`@("`@("1V179E;G0@/2`F2&]R
M9&5?:4-A;&5N9&%R.CIN97=#;VUP;VYE;G0H)W9E=F5N="<L("1I0V%L*3L*
M"B`@("`@("`@:68@*"1A6R=!;&Q$87E%=F5N="==(#T]("=4<G5E)RD@>PH@
M("`@("`@("`@("`D="`]("1I0V%L+3Y?<&%R<V5$871E5&EM92@D85LG4W1A
M<G0G72D["B`@("`@("`@("`@("1V179E;G0M/G-E=$%T=')I8G5T92@G1%13
M5$%25"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G>65A<B<@/3X@9&%T92@G62<L("1T*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@/3X@9&%T92@G;2<L("1T
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M9&%Y)R`]/B!D871E*"=D)RPD="DI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)U9!3%5%)R`]/B`G1$%412<I*3L*("`@("`@
M("`@("`@)'0@/2`D:4-A;"T^7W!A<G-E1&%T951I;64H)&%;)T5N9"==*3L*
M("`@("`@("`@("`@)'9%=F5N="T^<V5T071T<FEB=71E*"=$5$5.1"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G>65A<B<@
M/3X@9&%T92@G62<L("1T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=M;VYT:"<@/3X@9&%T92@G;2<L("1T*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B!D
M871E*"=D)RPD="DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)U9!3%5%)R`]/B`G1$%412<I*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)T144U1!4E0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&E#86PM/E]P
M87)S941A=&54:6UE*"1A6R=3=&%R="==*2D["B`@("`@("`@("`@("1V179E
M;G0M/G-E=$%T=')I8G5T92@G1%1%3D0G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&E#86PM/E]P87)S941A=&54:6UE*"1A6R=%;F0G
M72DI.PH@("`@("`@('T*"B`@("`@("`@)'9%=F5N="T^<V5T071T<FEB=71E
M*"=$5%-404U0)RP@=&EM92@I*3L*("`@("`@("`D=D5V96YT+3YS971!='1R
M:6)U=&4H)U-534U!4EDG+"`D85LG4W5B:F5C="==*3L*("`@("`@("`D=D5V
M96YT+3YS971!='1R:6)U=&4H)T1%4T-225!424].)RP@)&%;)T)O9'DG72D[
M"B`@("`@("`@+R\@)'9%=F5N="T^<V5T071T<FEB=71E*"=#051%1T]22453
M)RP@)&%;)R==*3L*("`@("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)TQ/
M0T%424].)RP@)&%;)TQO8V%T:6]N)UTI.PH*("`@("`@("!R971U<FX@)'9%
M=F5N="T^97AP;W)T=D-A;&5N9&%R*"D["B`@("!]"@H@("`@9G5N8W1I;VX@
M<VEF,G9T;V1O*"1S:68I"B`@("!["B`@("`@("`@)&$@/2`D=&AI<RT^<VEF
M,F%R<F%Y*"1S:68I.PH*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A
M;&5N9&%R*"D["B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G5D524TE/
M3B<L("<Q+C`G*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=04D]$
M240G+"`G+2\O5&AE($AO<F1E(%!R;VIE8W0O+TUN96UO("\O14XG*3L*("`@
M("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=-151(3T0G+"`G4%5"3$E32"<I
M.PH*("`@("`@("`D=G1O9&\@/2`F2&]R9&5?:4-A;&5N9&%R.CIN97=#;VUP
M;VYE;G0H)W9T;V1O)RP@)&E#86PI.PH*("`@("`@("`D=G1O9&\M/G-E=$%T
M=')I8G5T92@G4U5-34%262<L("1A6R=3=6)J96-T)UTI.PH@("`@("`@("1V
M=&]D;RT^<V5T071T<FEB=71E*"=$15-#4DE05$E/3B<L("1A6R=";V1Y)UTI
M.PH@("`@("`@(&EF("@D85LG26UP;W)T86YC92==(#T](#`I('L*("`@("`@
M("`@("`@)'9T;V1O+3YS971!='1R:6)U=&4H)U!224]22519)RP@-2D["B`@
M("`@("`@?2!E;'-E:68@*"1A6R=);7!O<G1A;F-E)UT@/3T@,BD@>PH@("`@
M("`@("`@("`D=G1O9&\M/G-E=$%T=')I8G5T92@G4%))3U))5%DG+"`Q*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=G1O9&\M/G-E=$%T=')I
M8G5T92@G4%))3U))5%DG+"`S*3L*("`@("`@("!]"B`@("`@("`@:68@*"1A
M6R=$=65$871E)UT@(3T@)S0U,#`Q,C,Q5#(S,#`P,%HG*2!["B`@("`@("`@
M("`@("1V=&]D;RT^<V5T071T<FEB=71E*"=$544G+"`D:4-A;"T^7W!A<G-E
M1&%T951I;64H)&%;)T1U941A=&4G72DI.PH@("`@("`@('T*("`@("`@("`D
M=G1O9&\M/G-E=$%T=')I8G5T92@G0T]-4$Q%5$5$)RP@)&%;)T-O;7!L971E
M)UT@/3T@)U1R=64G(#\@,2`Z(#`I.PH*("`@("`@("!R971U<FX@)'9T;V1O
M+3YE>'!O<G1V0V%L96YD87(H*3L*("`@('T*"B`@("!F=6YC=&EO;B!V;F]T
M93)S:68H)'9N;W1E*0H@("`@>PH@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D
M95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21I0V%L+3YP87)S979#86QE
M;F1A<B@D=FYO=&4I*2!["B`@("`@("`@("`@(&1I92@B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T82XB*3L*("`@("`@("!]"@H@("`@
M("`@("1C;VUP;VYE;G1S(#T@)&E#86PM/F=E=$-O;7!O;F5N=',H*3L*"B`@
M("`@("`@<W=I=&-H("AC;W5N="@D8V]M<&]N96YT<RDI('L*("`@("`@("!C
M87-E(#`Z"B`@("`@("`@("`@(&1I92@B3F\@9&%T82!W87,@9F]U;F0N(BD[
M"@H@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@)&-O;G1E;G0@/2`D8V]M
M<&]N96YT<ULP73L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@(&1I92@B375L=&EP;&4@8V]M<&]N96YT<R!F;W5N
M9#L@;VYL>2!O;F4@:7,@<W5P<&]R=&5D+B(I.PH@("`@("`@('T*"B`@("`@
M("`@)&$@/2!A<G)A>2@G0F]D>2<@/3X@)&-O;G1E;G0M/F=E=$%T=')I8G5T
M92@G0D]$62<I*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YA<G)A>3)S:68H
M"B`@("`@("`@("`@("1A+`H@("`@("`@("`@("`G/#]X;6P@=F5R<VEO;CTB
M,2XP(C\^/&YO=&4^)RP*("`@("`@("`@("`@)SQ#871E9V]R:65S/CPO0V%T
M96=O<FEE<SXG"B`@("`@("`@("`@("X@)SQ3=6)J96-T/CPO4W5B:F5C=#X\
M0V]L;W(^/"]#;VQO<CX\2&5I9VAT/CPO2&5I9VAT/CQ7:61T:#X\+U=I9'1H
M/CQ,969T/CPO3&5F=#X\5&]P/CPO5&]P/B<*("`@("`@("`@("`@+B`G/"]N
M;W1E/B<I.PH@("`@?0H*("`@(&9U;F-T:6]N('9C87)D,G-I9B@D=F-A<F0I
M"B`@("!["B`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I
M.PH@("`@("`@(&EF("@A)&E#86PM/G!A<G-E=D-A;&5N9&%R*"1V8V%R9"DI
M('L*("`@("`@("`@("`@9&EE*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!D871A+B(I.PH@("`@("`@('T*"B`@("`@("`@)&-O;7!O;F5N
M=',@/2`D:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH*("`@("`@("!S=VET8V@@
M*&-O=6YT*"1C;VUP;VYE;G1S*2D@>PH@("`@("`@(&-A<V4@,#H*("`@("`@
M("`@("`@9&EE*").;R!D871A('=A<R!F;W5N9"XB*3L*"B`@("`@("`@8V%S
M92`Q.@H@("`@("`@("`@("`D8V]N=&5N="`]("1C;VUP;VYE;G1S6S!=.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@
M("`@9&EE*")-=6QT:7!L92!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!I
M<R!S=7!P;W)T960N(BD["B`@("`@("`@?0H*("`@("`@("`O+R!F<F]M(&AE
M<F4@;VXL('1H92!C;V1E(&ES('1A:V5N(&9R;VT*("`@("`@("`O+R!4=7)B
M85]$<FEV97(Z.G1O2&%S:"P@=B`Q+C8U(#(P,#4O,#,O,3(*("`@("`@("`O
M+R!A;F0@;6]D:69I960@9F]R('1H92!3>6YC-$H@871T<FEB=71E(&YA;65S
M+@H@("`@("`@("1A='1R(#T@)&-O;G1E;G0M/F=E=$%L;$%T=')I8G5T97,H
M*3L*("`@("`@("!F;W)E86-H("@D871T<B!A<R`D:71E;2D@>PH@("`@("`@
M("`@("!S=VET8V@@*"1I=&5M6R=N86UE)UTI('L*("`@("`@("`@("`@8V%S
M92`G1DXG.@H@("`@("`@("`@("`@("`@)&AA<VA;)T9I;&5!<R==(#T@)&ET
M96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)TXG.@H@("`@("`@("`@("`@("`@)&YA;64@/2`D:71E;5LG
M=F%L=65S)UT["B`@("`@("`@("`@("`@("`D:&%S:%LG3&%S=$YA;64G72`]
M("1N86UE6U9#05)$7TY?1D%-24Q973L*("`@("`@("`@("`@("`@("1H87-H
M6R=&:7)S=$YA;64G72`]("1N86UE6U9#05)$7TY?1TE614Y=.PH@("`@("`@
M("`@("`@("`@)&AA<VA;)TUI9&1L94YA;64G72`]("1N86UE6U9#05)$7TY?
M041$3%T["B`@("`@("`@("`@("`@("`D:&%S:%LG5&ET;&4G72`]("1N86UE
M6U9#05)$7TY?4%)%1DE873L*("`@("`@("`@("`@("`@("1H87-H6R=3=69F
M:7@G72`]("1N86UE6U9#05)$7TY?4U5&1DE873L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G3DE#2TY!344G.@H@("`@("`@
M("`@("`@("`@)&AA<VA;)TYI8VM.86UE)UT@/2`D:71E;5LG=F%L=64G73L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@1F]R('9#
M87)D(#,N,"X*("`@("`@("`@("`@8V%S92`G0412)SH*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D:71E;5LG<&%R86US)UU;)U194$4G72DI('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I=&5M6R=P87)A;7,G
M75LG5%E012==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:71E;5LG
M<&%R86US)UU;)U194$4G72`](&%R<F%Y*"1I=&5M6R=P87)A;7,G75LG5%E0
M12==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1I=&5M6R=P87)A;7,G75LG
M5%E012==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&ET96U;)W!A<F%M<R==6R=73U)+)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E012==6UT@/2`G5T]22R<[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D:71E;5LG<&%R86US)UU;)TA/344G72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UU;72`]("=(
M3TU%)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)&%D9')E<W,@/2`D:71E;5LG=F%L=65S)UT[
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D:71E;5LG<&%R86US)UU;)U19
M4$4G72!A<R`D861R*2!["B`@("`@("`@("`@("`@("`@("`@<W=I=&-H("A3
M=')I;F<Z.G5P<&5R*"1A9'(I*2!["B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G2$]-12<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1P<F5F:7@@/2`G
M2&]M94%D9')E<W,G.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G5T]22R<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P<F5F:7@@/2`G5V]R:T%D9')E<W,G.PH@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]("=(
M;VUE061D<F5S<R<["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'!R969I>"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D:&%S:%LD<')E9FEX("X@)U-T<F5E="==(#T@:7-S970H)&%D9')E
M<W-;5D-!4D1?04127U-44D5%5%TI(#\@)&%D9')E<W-;5D-!4D1?04127U-4
M4D5%5%T@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LD
M<')E9FEX("X@)T-I='DG72`](&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E],
M3T-!3$E465TI(#\@)&%D9')E<W-;5D-!4D1?04127TQ/0T%,251972`Z(&YU
M;&P["B`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G
M4W1A=&4G72`](&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]214=)3TY=*2`_
M("1A9&1R97-S6U9#05)$7T%$4E]214=)3TY=(#H@;G5L;#L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N("=0;W-T86Q#;V1E)UT@
M/2!I<W-E="@D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=*2`_("1A9&1R
M97-S6U9#05)$7T%$4E]03U-40T]$15T@.B!N=6QL.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:&%S:%LD<')E9FEX("X@)T-O=6YT<GDG72`](&ES<V5T
M*"1A9&1R97-S6U9#05)$7T%$4E]#3U5.5%)972D@/R`D861D<F5S<UM60T%2
M1%]!1%)?0T]53E1265T@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D:&%S:%LD<')E9FEX("X@)U!O<W1/9F9I8V5";W@G72`](&ES<V5T*"1A
M9&1R97-S6U9#05)$7T%$4E]03T)=*2`_("1A9&1R97-S6U9#05)$7T%$4E]0
M3T)=(#H@;G5L;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)U1%3"<Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A
M<F%M<R==6R=&05@G72DI('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG
M0G5S:6YE<W-&87A.=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG5%E0
M12==*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&ET
M96U;)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1I=&5M6R=P87)A;7,G75LG5%E012==(#T@87)R87DH)&ET96U;)W!A
M<F%M<R==6R=465!%)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`O+R!&;W(@=D-A<F0@,RXP+@H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1I=&5M6R=P87)A;7,G75LG5%E012==(&%S("1T
M96PI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*%-T<FEN9SHZ=7!P
M97(H)'1E;"D@/3T@)U=/4DLG*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:&%S:%LG0G5S:6YE<W-496QE<&AO;F5.=6UB97(G72`]("1I=&5M
M6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M4W1R:6YG.CIU<'!E<B@D=&5L*2`]/2`G2$]-12<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1H87-H6R=(;VUE5&5L97!H;VYE3G5M8F5R)UT@
M/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*%-T<FEN9SHZ=7!P97(H)'1E;"D@/3T@)T-%3$PG*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LG36]B:6QE5&5L97!H;VYE
M3G5M8F5R)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*%-T<FEN9SHZ=7!P97(H)'1E;"D@/3T@)T9!6"<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R="=7-I;F5S
M<T9A>$YU;6)E<B==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M:71E;5LG<&%R86US)UU;)TA/344G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&AA<VA;)TAO;65496QE<&AO;F5.=6UB97(G72`]("1I=&5M6R=V
M86QU92==.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D
M:71E;5LG<&%R86US)UU;)U=/4DLG72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&AA<VA;)T)U<VEN97-S5&5L97!H;VYE3G5M8F5R)UT@/2`D:71E
M;5LG=F%L=64G73L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S
M970H)&ET96U;)W!A<F%M<R==6R=#14Q,)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1H87-H6R=-;V)I;&5496QE<&AO;F5.=6UB97(G72`]("1I
M=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1H87-H6R=(;VUE5&5L97!H;VYE3G5M
M8F5R)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)T5-04E,)SH*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D:71E;5LG<&%R86US)UU;)U!2148G72D@?'P@(6ES<V5T*"1H87-H
M6R=E;6%I;"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=%;6%I
M;#%!9&1R97-S)UT@/2!(;W)D95]I0V%L96YD87)?=F-A<F0Z.F=E=$)A<F5%
M;6%I;"@D:71E;5LG=F%L=64G72D["B`@("`@("`@("`@("`@("`@("`@)&AA
M<VA;)T5M86EL,4%D9')E<W-4>7!E)UT@/2`G4TU44"<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)U1)5$Q%)SH*("`@("`@("`@("`@("`@("1H87-H6R=*;V)4:71L92==
M(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)T]21R<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG
M0V]M<&%N>4YA;64G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=.3U1%)SH*("`@("`@("`@
M("`@("`@("1H87-H6R=";V1Y)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G55),)SH*("`@
M("`@("`@("`@("`@("1H87-H6R=796)086=E)UT@/2`D:71E;5LG=F%L=64G
M73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/F%R<F%Y,G-I9B@*("`@("`@
M("`@("`@)&AA<V@L"B`@("`@("`@("`@("<\/WAM;"!V97)S:6]N/2(Q+C`B
M/SX\8V]N=&%C=#XG+`H@("`@("`@("`@("`G/"]C;VYT86-T/B<I.PH@("`@
M?0H*("`@(&9U;F-T:6]N('9E=F5N=#)S:68H)'9C87)D*0H@("`@>PH@("`@
M("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I
M9B`H(21I0V%L+3YP87)S979#86QE;F1A<B@D=F-A<F0I*2!["B`@("`@("`@
M("`@(&1I92@B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T
M82XB*3L*("`@("`@("!]"@H@("`@("`@("1C;VUP;VYE;G1S(#T@)&E#86PM
M/F=E=$-O;7!O;F5N=',H*3L*"B`@("`@("`@<W=I=&-H("AC;W5N="@D8V]M
M<&]N96YT<RDI('L*("`@("`@("!C87-E(#`Z"B`@("`@("`@("`@(&1I92@B
M3F\@9&%T82!W87,@9F]U;F0N(BD["@H@("`@("`@(&-A<V4@,3H*("`@("`@
M("`@("`@)&-O;G1E;G0@/2`D8V]M<&]N96YT<ULP73L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&1I92@B375L
M=&EP;&4@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@:7,@<W5P<&]R=&5D
M+B(I.PH@("`@("`@('T*"B`@("`@("`@+R\@27,@=&AE<F4@82!R96%L(&YE
M960@=&\@<')O=FED92!T:&4@8V]R<F5C="!V86QU93\*("`@("`@("`D9'5R
M871I;VX@/2`P.PH*("`@("`@("`D871T<B`]("1C;VYT96YT+3YG971!;&Q!
M='1R:6)U=&5S*"D["B`@("`@("`@9F]R96%C:"`H)&%T='(@87,@)&ET96TI
M('L*("`@("`@("`@("`@<W=I=&-H("@D:71E;5LG;F%M92==*2!["B`@("`@
M("`@("`@(&-A<V4@)T144U1!4E0G.@H@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D:71E;5LG<&%R86US)UU;)U9!3%5%)UTI("8F("1I=&5M6R=P87)A
M;7,G75LG5D%,544G72`]/2`B1$%412(I('L*("`@("`@("`@("`@("`@("`@
M("`D:&%S:%LG06QL1&%Y179E;G0G72`](")4<G5E(CL*("`@("`@("`@("`@
M("`@("`@("`D:&%S:%LG4W1A<G0G72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X
M<&]R=$1A=&54:6UE*"1I=&5M6R=V86QU92==*3L*("`@("`@("`@("`@("`@
M("`@("`D9'5R871I;VX@/2`Q-#0P.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG06QL1&%Y179E;G0G72`]
M(")&86QS92(["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)U-T87)T)UT@
M/2!(;W)D95]I0V%L96YD87(Z.E]E>'!O<G1$871E5&EM92@D:71E;5LG=F%L
M=64G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)T1414Y$)SH*("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)&ET96U;)W!A<F%M<R==6R=604Q512==*2`F)B`D:71E
M;5LG<&%R86US)UU;)U9!3%5%)UT@/3T@(D1!5$4B*2!["B`@("`@("`@("`@
M("`@("`@("`@)&AA<VA;)T%L;$1A>45V96YT)UT@/2`B5')U92(["B`@("`@
M("`@("`@("`@("`@("`@)&AA<VA;)T5N9"==(#T@2&]R9&5?:4-A;&5N9&%R
M.CI?97AP;W)T1&%T951I;64H)&ET96U;)W9A;'5E)UTI.PH@("`@("`@("`@
M("`@("`@("`@("1D=7)A=&EO;B`](#$T-#`["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=!;&Q$87E%=F5N
M="==(#T@(D9A;'-E(CL*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG16YD
M)UT@/2!(;W)D95]I0V%L96YD87(Z.E]E>'!O<G1$871E5&EM92@D:71E;5LG
M=F%L=64G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U-534U!4EDG.@H@("`@("`@("`@
M("`@("`@)&AA<VA;)U-U8FIE8W0G72`]("1I=&5M6R=V86QU92==.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=$15-#4DE0
M5$E/3B<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG0F]D>2==(#T@)&ET96U;
M)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)TQ/0T%424].)SH*("`@("`@("`@("`@("`@("1H87-H6R=,;V-A
M=&EO;B==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YA<G)A>3)S:68H"B`@("`@("`@("`@("1H87-H+`H@("`@("`@("`@
M("`G/#]X;6P@=F5R<VEO;CTB,2XP(C\^/&%P<&]I;G1M96YT/CQ$=7)A=&EO
M;CXG"B`@("`@("`@("`@("X@)&1U<F%T:6]N("X@)SPO1'5R871I;VX^)RP*
M("`@("`@("`@("`@)SQ)<U)E8W5R<FEN9SY&86QS93PO27-296-U<G)I;F<^
M/$UE971I;F=3=&%T=7,^,#PO365E=&EN9U-T871U<SX\0G5S>5-T871U<SXR
M/"]"=7-Y4W1A='5S/CPO87!P;VEN=&UE;G0^)RD["B`@("!]"@H@("`@9G5N
M8W1I;VX@=G1O9&\R<VEF*"1V8V%R9"D*("`@('L*("`@("`@("`D:4-A;"`]
M("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["B`@("`@("`@:68@*"$D:4-A;"T^
M<&%R<V5V0V%L96YD87(H)'9C87)D*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@9&%T82XG*3L*("`@("`@("!]"@H@("`@("`@("1C;VUP;VYE;G1S
M(#T@)&E#86PM/F=E=$-O;7!O;F5N=',H*3L*"B`@("`@("`@<W=I=&-H("AC
M;W5N="@D8V]M<&]N96YT<RDI('L*("`@("`@("!C87-E(#`Z"B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;R!D871A('=A<R!F;W5N
M9"<I.PH*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("1C;VYT96YT(#T@
M)&-O;7!O;F5N='-;,%T["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M375L=&EP;&4@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@:7,@<W5P<&]R
M=&5D+B<I.PH@("`@("`@('T*"B`@("`@("`@)&AA<VA;)T-O;7!L971E)UT@
M/2`G1F%L<V4G.PH@("`@("`@("\O($]U=&QO;VLG<R!D969A=6QT(&9O<B!N
M;R!D=64@9&%T90H@("`@("`@("1H87-H6R=$=65$871E)UT@/2`G-#4P,#$R
M,S%4,C,P,#`P6B<["@H@("`@("`@("1A='1R(#T@)&-O;G1E;G0M/F=E=$%L
M;$%T=')I8G5T97,H*3L*("`@("`@("!F;W)E86-H("@D871T<B!A<R`D:71E
M;2D@>PH@("`@("`@("`@("!S=VET8V@@*"1I=&5M6R=N86UE)UTI('L*("`@
M("`@("`@("`@8V%S92`G1%5%)SH*("`@("`@("`@("`@("`@("1H87-H6R=$
M=65$871E)UT@/2!(;W)D95]I0V%L96YD87(Z.E]E>'!O<G1$871E5&EM92@D
M:71E;5LG=F%L=64G72D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)U-534U!4EDG.@H@("`@("`@("`@("`@("`@)&AA<VA;
M)U-U8FIE8W0G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=$15-#4DE05$E/3B<Z"B`@("`@
M("`@("`@("`@("`D:&%S:%LG0F]D>2==(#T@)&ET96U;)W9A;'5E)UT["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U!224]2
M2519)SH*("`@("`@("`@("`@("`@(&EF("@D:71E;5LG=F%L=64G72`]/2`Q
M*2!["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)TEM<&]R=&%N8V4G72`]
M(#(["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&ET96U;)W9A;'5E)UT@
M/3T@-2D@>PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=);7!O<G1A;F-E
M)UT@/2`P.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:&%S:%LG26UP;W)T86YC92==(#T@,3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G0T]-4$Q%5$5$)SH*("`@("`@("`@("`@("`@("1H87-H6R=#;VUP;&5T
M92==(#T@)&ET96U;)W9A;'5E)UT@/R`G5')U92<@.B`G1F%L<V4G.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^87)R87DR<VEF*`H@("`@("`@("`@("`D
M:&%S:"P*("`@("`@("`@("`@)SP_>&UL('9E<G-I;VX](C$N,"(_/CQT87-K
M/B<L"B`@("`@("`@("`@("<\+W1A<VL^)RD["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4O4WEN
M=&AE<VES+G!H<```````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S`V,P`Q
M,#0Q-S,V,C<W,``P,C(R-#(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!3>6YC34Q?1&5V:6-E
M7U-Y;G1H97-I<SHZ(&-L87-S('!R;W9I9&5S(&9U;F-T:6]N86QI='D@=&AA
M="!I<PH@*B!S<&5C:69I8R!T;R!T:&4@4WEN=&AE<VES+F-H(%-Y;F--3"!C
M;&EE;G1S+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U
M<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]$979I8V4O4WEN=&AE
M<VES+G!H<"QV(#$N,BXR+C0@,C`P-B\P,2\P,2`R,3HR.#HS-R!J86X@17AP
M("0*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H
M;W)D92YO<F<^"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,
M7T1E=FEC95]3>6YT:&5S:7,@97AT96YD<R!3>6YC34Q?1&5V:6-E('L*"B`@
M("`O*BH*("`@("`J($-O;G9E<G1S('1H92!C;VYT96YT(&9R;VT@=&AE(&)A
M8VME;F0@=&\@82!F;W)M870@<W5I=&%B;&4@9F]R('1H90H@("`@("H@8VQI
M96YT(&1E=FEC92X*("`@("`J"B`@("`@*B!3=')I<',@=&AE('5I9"`H<')I
M;6%R>2!K97DI(&EN9F]R;6%T:6]N(&%S(&-L:65N="!A;F0@<V5R=F5R(&UI
M9VAT('5S90H@("`@("H@9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@("!4:&4@8V]N=&5N="!T;R!C
M;VYV97)T"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@(%1H
M92!C;VYT96YT5'EP92!O9B!C;VYT96YT(&%S(')E='5R;F5D(&9R;VT*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&)A8VME;F0*
M("`@("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@87)R87DH)&YE
M=V-O;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H92!C;VYV97)T960@8V]N=&5N="!A;F0@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AP;W-S
M:6)L>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N
M=%1Y<&4I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@
M("!L:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@
M<&%R96YT.CIC;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N="P@)&-O;G1E
M;G14>7!E*3L*"B`@("`@("`@+R\@1DE8344Z(&IU<W0@<W=A<'!I;F<@;W5T
M('1H92!V97)S:6]N(&YU;6)E<B!I;B!T:&4@:&5A9&5R"B`@("`@("`@+R\@
M<V\@=&AA="!T:&4@8VQI96YT(&1O97-N)W0@:6UM961I871E;'D@9&5N>2!W
M:71H(&$@(D9O<FUA=`H@("`@("`@("\O(&YO="!S=7!P;W)T960B+B!3964@
M:'1T<#HO+V)U9W,N:&]R9&4N;W)G+W1I8VME="\_:60],3@X,2X*("`@("`@
M("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*59%4E-)
M3TXZ,BXP+R<L("=<,59%4E-)3TXZ,2XP)RP@)&-O;G1E;G0L(#$I.PH*("`@
M("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@
M("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET92@D
M9G`L(")<;F]U='!U="!C;VYV97)T960@9F]R(&-L:65N="`H)&-O;G1E;G14
M>7!E*3I<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L("1C;VYT
M96YT("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D
M8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-Y;G1H97-I<R!C=7)R96YT;'D@97AP96-T<R!N;W1E<R!A<R!T97AT+W!L
M86EN+B!-87EB92!W92!C86X*("`@("`J(&5X=')A8W0@=&AI<R!F<F]M($1E
M=DEN9B!R871H97(@=&AA;B!H87)D8V]D92!I="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4')E9F5R<F5D0V]N=&5N=%1Y<&4H)'1Y<&4I"B`@("!["B`@
M("`@("`@:68@*"1T>7!E(#T]("=N;W1E<R<I('L*("`@("`@("`@("`@<F5T
M=7)N("=T97AT+W!L86EN)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N('!A
M<F5N=#HZ9V5T4')E9F5R<F5D0V]N=&5N=%1Y<&4H)'1Y<&4I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<')E9F5R<G)E9"!C;VYT96YT
M='EP92!O9B!T:&4@8VQI96YT(&9O<B!T:&4@9VEV96X*("`@("`J('-Y;F,@
M9&%T82!T>7!E("AC;VYT86-T<R]T87-K<R]N;W1E<R]C86QE;F1A<BDN"B`@
M("`@*@H@("`@("H@4WEN=&AE<VES(&-U<G)E;G1L>2!S96YD<R!N;W1E<R!A
M<R!T97AT+W!L86EN+B!-87EB92!W92!C86X@97AT<F%C=`H@("`@("H@=&AI
M<R!F<F]M($1E=DEN9B!R871H97(@=&AA;B!H87)D8V]D92!I="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4')E9F5R<F5D0V]N=&5N=%1Y<&5#;&EE;G0H
M)'1Y<&4I"B`@("!["B`@("`@("`@:68@*"1T>7!E(#T]("=N;W1E<R<I('L*
M("`@("`@("`@("`@<F5T=7)N("=T97AT+W!L86EN)SL*("`@("`@("!](&5L
M<V5I9B`H)'1Y<&4@/3T@)W1A<VMS)RD@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH)T-O;G1E;G14>7!E)R`]/B`G=&5X="]X+79C86QE;F1A<B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`G14Y#3T1)3D<G(#T^("=154]4140M
M4%))3E1!0DQ%)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=#2$%24T54
M)R`]/B`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G5D524TE/3B<@/3X@)S$N,"<I.PH@("`@
M("`@('T@96QS96EF("@D='EP92`]/2`G8V%L96YD87(G*2!["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@G0V]N=&5N=%1Y<&4G(#T^("=T97AT+W@M=F-A
M;&5N9&%R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=%3D-/1$E.1R<@
M/3X@)U%53U1%1"U04DE.5$%"3$4G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)T-(05)3150G(#T^("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3
M150G72P*("`@("`@("`@("`@("`@("`@("`@("`@("=615)324].)R`]/B`G
M,2XP)RD["B`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=C;VYT86-T<R<I
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=#;VYT96YT5'EP92<@/3X@
M)W1E>'0O>"UV8V%R9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G14Y#
M3T1)3D<G(#T^("=154]4140M4%))3E1!0DQ%)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("=#2$%24T54)R`]/B`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.
M1U]#2$%24T54)UTI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('!A<F5N
M=#HZ9V5T4')E9F5R<F5D0V]N=&5N=%1Y<&5#;&EE;G0H)'1Y<&4I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U-Y;F--3"]$979I8V4O3F]K:6$N<&AP````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-C<W-@`Q,#0Q-S,V,C<W,``P,C$S,C0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!3>6YC34Q?1&5V:6-E7TYO:VEA.CH@8VQA<W,@<')O=FED97,@9G5N
M8W1I;VYA;&ET>2!T:&%T(&ES"B`J('-P96-I9FEC('1O('1H92!.;VMI82!3
M>6YC34P@8VQI96YT<RX*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!+87)S
M=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO1&5V:6-E
M+TYO:VEA+G!H<"QV(#$N,BXR+C(@,C`P-B\P,2\P,2`R,3HR.#HS-R!J86X@
M17AP("0*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E
M;D!H;W)D92YO<F<^"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN
M8TU,7T1E=FEC95].;VMI82!E>'1E;F1S(%-Y;F--3%]$979I8V4@>PH*("`@
M("\J*@H@("`@("H@0V]N=F5R=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@8F%C
M:V5N9"!T;R!A(&9O<FUA="!S=6ET86)L92!F;W(@=&AE"B`@("`@*B!C;&EE
M;G0@9&5V:6-E+@H@("`@("H*("`@("`J(%-T<FEP<R!T:&4@=6ED("AP<FEM
M87)Y(&ME>2D@:6YF;W)M871I;VX@87,@8VQI96YT(&%N9"!S97)V97(@;6EG
M:'0@=7-E"B`@("`@*B!D:69F97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O
M;G9E<G0*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE
M(&-O;G1E;G14>7!E(&]F(&-O;G1E;G0@87,@<F5T=7)N960@9G)O;0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8F%C:V5N9`H@
M("`@("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W
M8V]N=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*'!O<W-I
M8FQY(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT
M5'EP92D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["@H@("`@("`@
M(&QI<W0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D@/0H@("`@("`@("`@("!P
M87)E;G0Z.F-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N
M=%1Y<&4I.PH*("`@("`@("`O+R!&25A-13H@:G5S="!S=V%P<&EN9R!O=70@
M=&AE('9E<G-I;VX@;G5M8F5R(&EN('1H92!H96%D97(*("`@("`@("`O+R!S
M;R!T:&%T('1H92!C;&EE;G0@9&]E<VXG="!I;6UE9&EA=&5L>2!D96YY('=I
M=&@@82`B1F]R;6%T"B`@("`@("`@+R\@;F]T('-U<'!O<G1E9"(N(%-E92!H
M='1P.B\O8G5G<RYH;W)D92YO<F<O=&EC:V5T+S]I9#TQ.#@Q+@H@("`@("`@
M("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI5D524TE/
M3CHR+C`O)RP@)UPQ5D524TE/3CHQ+C`G+"`D8V]N=&5N="P@,2D["@H@("`@
M("`@(&EF("A$14)51TQ/1U])0T%,14Y$05)$051!*2!["B`@("`@("`@("`@
M("1F<"`]($!F;W!E;B@G+W1M<"]S>6YC+VQO9RYT>'0G+"`G82<I.PH@("`@
M("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F
M<"P@(EQN;W5T<'5T(&-O;G9E<G1E9"!F;W(@8VQI96YT("@D8V]N=&5N=%1Y
M<&4I.EQN(BD["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@)&-O;G1E
M;G0@+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H)&9P*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1C
M;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J($YO:VEA(&-U
M<G)E;G1L>2!E>'!E8W1S(&YO=&5S(&%S('1E>'0O<&QA:6XN($UA>6)E('=E
M(&-A;B!E>'1R86-T"B`@("`@*B!T:&ES(&9R;VT@1&5V26YF(')A=&AE<B!T
M:&%N(&AA<F1C;V1E(&ET+@H@("`@("HO"@H@("!F=6YC=&EO;B!G9710<F5F
M97)R961#;VYT96YT5'EP92@D='EP92D*("`@('L*("`@("`@("`@:68@*"1T
M>7!E(#T]("=N;W1E<R<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT+W!L
M86EN)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ9V5T4')E
M9F5R<F5D0V]N=&5N=%1Y<&4H)'1Y<&4I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<')E9F5R<G)E9"!C;VYT96YT='EP92!O9B!T:&4@
M8VQI96YT(&9O<B!T:&4@9VEV96X*("`@("`J('-Y;F,@9&%T82!T>7!E("AC
M;VYT86-T<R]T87-K<R]N;W1E<R]C86QE;F1A<BDN"B`@("`@*@H@("`@("H@
M3F]K:6$@8W5R<F5N=&QY('-E;F1S(&YO=&5S(&%S('1E>'0O<&QA:6XN($UA
M>6)E('=E(&-A;B!E>'1R86-T"B`@("`@*B!T:&ES(&9R;VT@1&5V26YF(')A
M=&AE<B!T:&%N(&AA<F1C;V1E(&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9710<F5F97)R961#;VYT96YT5'EP94-L:65N="@D='EP92D*("`@('L*("`@
M("`@("!I9B`H)'1Y<&4@/3T@)VYO=&5S)RD@>PH@("`@("`@("`@("!R971U
M<FX@)W1E>'0O<&QA:6XG.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`G
M=&%S:W,G*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G0V]N=&5N=%1Y
M<&4G(#T^("=T97AT+W@M=F-A;&5N9&%R)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("=%3D-/1$E.1R<@/3X@)U%53U1%1"U04DE.5$%"3$4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)T-(05)3150G(#T^("1'3$]"04Q36R=?
M2$]21$5?4U1224Y'7T-(05)3150G72D["B`@("`@("`@?2!E;'-E:68@*"1T
M>7!E(#T]("=C86QE;F1A<B<I('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=#;VYT96YT5'EP92<@/3X@)W1E>'0O>"UV8V%L96YD87(G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)T5.0T]$24Y')R`]/B`G455/5$5$+5!224Y4
M04),12<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G0TA!4E-%5"<@/3X@
M)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==*3L*("`@("`@("!]
M(&5L<V5I9B`H)'1Y<&4@/3T@)V-O;G1A8W1S)RD@>PH@("`@("`@("`@("!R
M971U<FX@87)R87DH)T-O;G1E;G14>7!E)R`]/B`G=&5X="]X+79C87)D)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("=%3D-/1$E.1R<@/3X@)U%53U1%
M1"U04DE.5$%"3$4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)T-(05)3
M150G(#T^("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@<&%R96YT.CIG9710<F5F97)R961#
M;VYT96YT5'EP94-L:65N="@D='EP92D["B`@("!]"@H@("!F=6YC=&EO;B!H
M86YD;&5487-K<TEN0V%L96YD87(H*0H@("!["B`@("`@(')E='5R;B!T<G5E
M.R`@("`@(`H@("!]"GT*```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]3>6YC34PO0V]M;6%N9"\`````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S``,#$W-S$T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+T%L97)T+G!H<```
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-3`R-0`Q,#0Q-S,V,C<W
M,``P,C$T-S4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0N<&AP
M)SL*"B\J*@H@*B!4:&4@4WEN8TU,7T%L97)T(&-L87-S('!R;W9I9&5S(&$@
M4WEN8TU,(&EM<&QE;65N=&%T:6]N(&]F"B`J('1H92!!;&5R="!C;VUM86YD
M(&%S(&1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L
M+`H@*B!V97)S:6]N(#$N,2`U+C4N,BX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+T%L97)T+G!H<"QV(#$N,3@N,3`N
M.2`R,#`V+S`Q+S,Q(#$W.C4U.C,Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC
M;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS
M(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]M;6%N9%]!
M;&5R="!E>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@("`O*BH*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]A;&5R=#L*"B`@("`O
M*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O=7)C
M94QO8U5223L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7W1A<F=E=$QO8U5223L*"B`@("`O*BH*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUE=&%!;F-H;W).97AT.PH*("`@
M("\J*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VUE
M=&%!;F-H;W),87-T.PH*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!I
M;G-T86YC92!O9B!!;&5R="X*("`@("`J+PH@("`@9G5N8W1I;VX@4WEN8TU,
M7T-O;6UA;F1?06QE<G0H)&%L97)T(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H)&%L97)T("$](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/E]A;&5R
M="`]("1A;&5R=#L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@;W5T
M<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D8F%C:V5N9#L*"B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*("`@
M("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*"B`@
M("`@("`@+R\@2&%N9&QE('5N875T:&]R:7IE9"!F:7)S="X*("`@("`@("!I
M9B`H(21S=&%T92T^:7-!=71H;W)I>F5D*"DI('L*("`@("`@("`@("`@)'-T
M871U<R`]("9N97<@4WEN8TU,7T-O;6UA;F1?4W1A='5S*%)%4U!/3E-%7TE.
M5D%,241?0U)%1$5.5$E!3%,L("=!;&5R="<I.PH@("`@("`@("`@("`D<W1A
M='5S+3YS971#;612968H)'1H:7,M/E]C;61)1"D["B`@("`@("`@("`@("1C
M=7)R96YT0VUD240@/2`D<W1A='5S+3YO=71P=70H)&-U<G)E;G1#;61)1"P@
M)&]U='!U="D["B`@("`@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@
M("`@("`@('T*"B`@("`@("`@)&1A=&%B87-E(#T@)'1H:7,M/E]T87)G971,
M;V-54DD["@H@("`@("`@("\O(%-T;W)E(&-L:65N="=S($YE>'0@06YC:&]R
M(&EN(%-T871E+B`@069T97(@<W5C8V5S<V9U;"!S>6YC"B`@("`@("`@+R\@
M=&AI<R!I<R!T:&5N('=R:71T96X@=&\@<&5R<VES=&5N8V4@9F]R(&YE9V]T
M:6%T:6]N(&]F"B`@("`@("`@+R\@9G5R=&AE<B!S>6YC<RX*("`@("`@("`D
M<W1A=&4M/G-E=$-L:65N=$%N8VAO<DYE>'0H)&1A=&%B87-E+"`D=&AI<RT^
M7VUE=&%!;F-H;W).97AT*3L*"B`@("`@("`@)&EN9F\@/2`D8F%C:V5N9"T^
M9V5T4WEN8U-U;6UA<GDH)'-T871E+3YG9713>6YC261E;G1I9FEE<B@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&%R9V5T3&]C55))*3L*"B`@("`@("`@:68@*&ES7V$H)&EN9F\L("=$
M871A5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1X(#T@)&EN9F\M/F=E
M="@G0VQI96YT06YC:&]R)RD["B`@("`@("`@("`@("1C;&EE;G1L87-T(#T@
M)'A;)&1A=&%B87-E73L*("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A
M9V4H<W!R:6YT9B@G<')E=FEO=7,@<WEN8R!F;W5N9"!F;W(@9&%T86)A<V4Z
M("5S.R!C;&EE;G0M=',Z("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-L:65N=&QA<W0I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)'@@/2`D:6YF;RT^9V5T
M*"=397)V97)!;F-H;W(G*3L*("`@("`@("`@("`@)'-T871E+3YS971397)V
M97)!;F-H;W),87-T*"1D871A8F%S92P@)'A;)&1A=&%B87-E72D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H
M<W!R:6YT9B@G4WEN8TU,.B!.;R!I;F9O(&%B;W5T('!R979I;W5S('-Y;F-S
M(&9O=6YD(&9O<B!I9"`E<R!A;F0@9&%T86)A<V4@)7,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92T^9V5T4WEN
M8TED96YT:69I97(H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&%T86)A<V4I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("`@("`@)&-L:65N=&QA<W0@/2`P.PH@("`@("`@("`@("`D
M<W1A=&4M/G-E=%-E<G9E<D%N8VAO<DQA<W0H)&1A=&%B87-E+"`P*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%-E="!397)V97(@06YC:&]R(&9O<B!T:&ES
M('-Y;F,@=&\@8W5R<F5N="!T:6UE+@H@("`@("`@("1S=&%T92T^<V5T4V5R
M=F5R06YC:&]R3F5X="@D9&%T86)A<V4L('1I;64H*2D["B`@("`@("`@:68@
M*"@D8VQI96YT;&%S="!\?"`D8VQI96YT;&%S="`]/3T@)S`G*0H@("`@("`@
M("`@("`@("`@("8F("1C;&EE;G1L87-T(#T]("1T:&ES+3Y?;65T84%N8VAO
M<DQA<W0I('L*("`@("`@("`@("`@+R\@3&%S="!3>6YC($%N8VAO<B!M871C
M:&5S+"!4=V]787E3>6YC('=I;&P@9&\N"B`@("`@("`@("`@("1C;V1E(#T@
M4D534$].4T5?3TL["B`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E
M*")3>6YC34PZ($%N8VAO<B!M871C:"P@5'=O5V%Y4WEN8R!S:6YC92`B"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D8VQI96YT;&%S="P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&EF("@D8VQI96YT;&%S="D@>PH@("`@("`@("`@("`@("`@)&)A
M8VME;F0M/FQO9TUE<W-A9V4H)V-L:65N="!R97%U97-T960@<WEN8R!W:71H
M(&%N8VAO<B!T<R`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;65T84%N8VAO<DQA<W0@+B`G(&)U="!S97)V97(@
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&%S
M('1I;65S=&%M<"<@+B`D8VQI96YT;&%S="`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G(&]N(&9I;&4G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U])3D9/*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8F%C
M:V5N9"T^;&]G365S<V%G92@B4WEN8TU,.B!!;F-H;W(@;6ES;6%T8V@L(&5N
M9F]R8VEN9R!3;&]W4WEN8R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("`@("`D8VQI96YT;&%S="`](#`["B`@("`@("`@("`@("1S=&%T
M92T^<V5T4V5R=F5R06YC:&]R3&%S="@D9&%T86)A<V4L(#`I.PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]A;&5R="`]/2`R,#$I('L*("`@("`@("`@("`@
M("`@("\J(%-L;W=S>6YC(')E<75E<W1E9"!F<F]M(&-L:65N="!A;GEW87DZ
M(&IU<W0@86-K;F]W;&5D9V4N("HO"B`@("`@("`@("`@("`@("`D8V]D92`]
M(%)%4U!/3E-%7T]+.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@+RH@36ES;6%T8V@L(&5N9F]R8V4@<VQO=R!S>6YC+B`J+PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A;&5R="`](#(P,3L*("`@("`@("`@("`@
M("`@("1C;V1E(#T@-3`X.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D<W1A='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H)&-O
M9&4L("=!;&5R="<I.PH@("`@("`@("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI
M<RT^7V-M9$E$*3L*("`@("`@("!I9B`H)'1H:7,M/E]S;W5R8V5,;V-54DD@
M(3T@;G5L;"D@>PH@("`@("`@("`@("`D<W1A='5S+3YS9713;W5R8V52968H
M)'1H:7,M/E]S;W5R8V5,;V-54DDI.PH@("`@("`@('T*("`@("`@("!I9B`H
M)'1H:7,M/E]T87)G971,;V-54DD@(3T@;G5L;"D@>PH@("`@("`@("`@("`D
M<W1A='5S+3YS971487)G9712968H)'1H:7,M/E]T87)G971,;V-54DDI.PH@
M("`@("`@('T*"B`@("`@("`@+R\@36ER<F]R($YE>'0@06YC:&]R(&9R;VT@
M8VQI96YT(&)A8VL@=&\@8VQI96YT+@H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7VUE=&%!;F-H;W).97AT*2D@>PH@("`@("`@("`@("`D<W1A='5S+3YS
M971)=&5M1&%T84%N8VAO<DYE>'0H)'1H:7,M/E]M971A06YC:&]R3F5X="D[
M"B`@("`@("`@?0H*("`@("`@("`O+R!-:7)R;W(@3&%S="!!;F-H;W(@9G)O
M;2!C;&EE;G0@8F%C:R!T;R!C;&EE;G0N"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?;65T84%N8VAO<DQA<W0I*2!["B`@("`@("`@("`@("1S=&%T=7,M
M/G-E=$ET96U$871A06YC:&]R3&%S="@D=&AI<RT^7VUE=&%!;F-H;W),87-T
M*3L*("`@("`@("!]"@H@("`@("`@("1C=7)R96YT0VUD240@/2`D<W1A='5S
M+3YO=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["@H@("`@("`@(&EF
M("@D<W1A=&4M/FES075T:&]R:7IE9"@I*2!["B`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G06QE<G0G+"`D
M871T<G,I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=#;61)1"<L("1A='1R<RD["B`@("`@("`@("`@
M("1C:&%R<R`]("1C=7)R96YT0VUD240["B`@("`@("`@("`@("1O=71P=70M
M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G*3L*"B`@("`@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G
M1&%T82<L("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]("1T:&ES+3Y?
M86QE<G0["B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S
M*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G1&%T82<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RP@)&%T=')S*3L*"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7W-O=7)C94QO8U5222`A/2!N=6QL*2![
M"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)U1A<F=E="<L("1A='1R<RD["B`@("`@("`@("`@("`@
M("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO
M8U5222<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D8VAA<G,@/2`D=&AI
M<RT^7W-O=7)C94QO8U5223L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H
M87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<I.PH@("`@("`@
M("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G5&%R9V5T)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W1A<F=E=$QO8U5222`A/2!N=6QL*2!["B`@("`@("`@("`@("`@
M("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U-O
M=7)C92<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A='1R<RD[
M"B`@("`@("`@("`@("`@("`D8VAA<G,@/2`D=&AI<RT^7W1A<F=E=$QO8U52
M23L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S
M*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)TQO8U5222<I.PH@("`@("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E)RD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G365T82<L("1A='1R<RD["@H@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE-971A
M*"DL("=!;F-H;W(G+"`D871T<G,I.PH*("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))365T82@I+"`G3&%S="<L("1A
M='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]("1S=&%T92T^9V5T4V5R=F5R
M06YC:&]R3&%S="@D9&%T86)A<V4I.PH@("`@("`@("`@("`D;W5T<'5T+3YC
M:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L
M96UE;G0H)'-T871E+3YG97154DE-971A*"DL("=,87-T)RD["@H@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE-971A
M*"DL("=.97AT)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@)'-T
M871E+3YG971397)V97)!;F-H;W).97AT*"1D871A8F%S92D["B`@("`@("`@
M("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5224UE=&$H*2P@)TYE
M>'0G*3L*"B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DE-971A*"DL("=!;F-H;W(G*3L*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T82<I.PH@("`@
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=)=&5M)RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)T%L97)T)RD["@H@("`@("`@("`@("`D8W5R<F5N
M=$-M9$E$*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-U<G)E;G1#
M;61)1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R
M='D@<V]U<F-E55))+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-O
M=7)C955222`@3F5W('9A;'5E(&]F('!R;W!E<G1Y('-O=7)C955222X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T4V]U<F-E3&]C55))*"1S;W5R8V554DDI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]S;W5R8V554DD@/2`D<V]U<F-E55))
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1A<F=E=$QO8U5222@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&%R9V5T55)).PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!T87)G97154DDN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T55))("!.97<@=F%L
M=64@;V8@<')O<&5R='D@=&%R9V5T55))+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971487)G97154DDH)'1A<F=E=%5222D*("`@('L*("`@("`@("`D=&AI
M<RT^7W1A<F=E=%5222`]("1T87)G97154DD["B`@("!]"@H@("`@9G5N8W1I
M;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("![
M"B`@("`@("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L
M("1A='1R<RD["@H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*
M("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@
M("`@8V%S92`Q.@H@("`@("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3
M>6YC34PN<W1A=&4G73L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?=&%R9V5T
M3&]C55))("$]("=T87-K<R<*("`@("`@("`@("`@("`@("8F("1T:&ES+3Y?
M=&%R9V5T3&]C55))("$]("=C86QE;F1A<B<*("`@("`@("`@("`@("`@("8F
M("1T:&ES+3Y?=&%R9V5T3&]C55))("$]("=N;W1E<R<*("`@("`@("`@("`@
M("`@("8F("1T:&ES+3Y?=&%R9V5T3&]C55))("$]("=C;VYT86-T<R<I('L*
M("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=%<G)O<B$@
M26YV86QI9"!D871A8F%S93H@)PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`D=&AI<RT^7W1A<F=E=$QO8U5220H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G+B!/;FQY('1A<VMS+"!C
M86QE;F1A<BP@;F]T97,L)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G(&%N9"!C;VYT86-T<R!A;&QO=V5D(2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("`@("!D:64H(F5R<F]R
M.B!I;G9A;&ED(&1A=&%B87-E(2(I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G;&]O:VEN9R!F;W(@<WEN8R!F
M;W(@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&%R9V5T3&]C55))+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`@("`@)'-Y;F,@/2`F("1S=&%T92T^9V5T4WEN8R@D=&AI<RT^7W1A
M<F=E=$QO8U5222D["@H@("`@("`@("`@("!I9B`H(21S>6YC*2!["B`@("`@
M("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G0W)E871E(&YE=R!S
M>6YC(&9O<B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=&%R9V5T3&]C55))+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["@H@("`@("`@("`@("`@("`@)'-Y;F,@/2`F;F5W(%-Y;F--
M3%]3>6YC*"1T:&ES+3Y?86QE<G0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T87)G971,;V-54DDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S
M;W5R8V5,;V-54DDI.PH@("`@("`@("`@("`@("`@)'-T871E+3YS9713>6YC
M*"1T:&ES+3Y?=&%R9V5T3&]C55))+"`D<WEN8RD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@
M("`@:68@*"1E;&5M96YT(#T]("=$871A)RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A;&5R="`](&EN='9A;"AT<FEM*"1T:&ES+3Y?8VAA<G,I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`T.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)TQO8U5222<I('L*
M("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T86-K6S)=(#T]("=3;W5R
M8V4G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V5,;V-5
M4DD@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1T:&ES+3Y?4W1A8VM;,ET@/3T@)U1A<F=E="<I('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W1A<F=E=$QO8U5222`](&)A<V5N86UE
M*'!R96=?<F5P;&%C92@G+UP_+BHD+R<L("<G+"!T<FEM*"1T:&ES+3Y?8VAA
M<G,I*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@-3H*("`@("`@("`@("`@:68@
M*"1E;&5M96YT(#T]("=.97AT)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M971A06YC:&]R3F5X="`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@
M("`@("`@('T@96QS96EF("@D96QE;65N="`]/2`G3&%S="<I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;65T84%N8VAO<DQA<W0@/2!T<FEM*"1T:&ES
M+3Y?8VAA<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@<&%R96YT.CIE;F1%;&5M96YT*"1U<FDL("1E
M;&5M96YT*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971!;&5R="@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?86QE<G0["B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T06QE="@D86QE<G0I"B`@("!["B`@("`@("`@)'1H:7,M/E]A
M;&5R="`]("1A;&5R=#L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]3>6YC34PO0V]M;6%N9"]&:6YA;"YP:'``````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#<U,3$`,3`T,3<S-C(W-S``,#(Q-#4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@II
M;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<["@HO*BH*("H@5&AE
M(%-Y;F--3%]#;VUM86YD7T9I;F%L(&-L87-S+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA;F0O1FEN86PN<&AP+'8@,2XQ
M,"XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M
M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N=&AO;GD@
M36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E
M(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM
M86YD7T9I;F%L(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@>PH*("`@("\J*@H@
M("`@("H@0W)E871E('1H92!R97-P;VYS92!F;W(@82!F:6YA;"!T86<*("`@
M("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T
M<'5T*0H@("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--
M3"YS=&%T92==.PH@("`@("`@("1A='1R<R`](&%R<F%Y*"D["@H@("`@("`@
M("\O($EF('1H92!C;&EE;G0@:&%S;B=T('-E;G0@=7,@9&5V:6-E(&EN9F\L
M(')E<75E<W0@:70@;F]W+@H@("`@("`@("1D:2`](%-Y;F--3%]$979I8V4Z
M.F1E=FEC94EN9F\H*3L*("`@("`@("!I9B`H96UP='DH)&1I+3Y?36%N*2D@
M>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)T=E="<L("1A='1R<RD["@H@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9$E$)RP@)&%T
M=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@)&-U<G)E;G1#;61)1#L*("`@
M("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#
M;61)1"<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=-971A)RP@)&%T=')S*3L*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))365T82@I+"`G
M5'EP92<L("1A='1R<RD["B`@("`@("`@("`@("1A='1R<R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1O=71P=70L("=834Q?5T)834Q?16YC
M;V1E<B<I*2!["B`@("`@("`@("`@("`@("`D8VAA<G,@/2!-24U%7U-93D--
M3%]$159)0T5?24Y&3U]70EA-3#L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1C:&%R<R`]($U)345?4UE.0TU,7T1%5DE#15])3D9/
M7UA-3#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T<'5T+3YC:&%R
M86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)U1Y<&4G*3L*("`@("`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T82<I.PH*
M("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=)=&5M)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G970G+"`D871T
M<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@("`@("1C
M:&%R<R`]("@D<W1A=&4M/F=E=%9E<G-I;VXH*2`]/2`P*2`_("<N+V1E=FEN
M9C$P)R`Z("<N+V1E=FEN9C$Q)SL*("`@("`@("`@("`@)&]U='!U="T^8VAA
M<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG*3L*("`@("`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G5&%R9V5T
M)RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)TET96TG*3L*"B`@("`@("`@("`@("1O=71P=70M/F5N9$5L
M96UE;G0H)'-T871E+3YG97154DDH*2P@)T=E="<I.PH*("`@("`@("`@("`@
M+R\@36%R:R!T:&ES(&ED(&1O=VX@87,@;F5E9&EN9R!A(')E<W5L=',@<&%C
M:V5T(')O=71E9"!T;PH@("`@("`@("`@("`O+R!T:&4@4'5T(&-O;6UA;F0N
M"B`@("`@("`@("`@("1S=&%T92T^<V5T17AP96-T961297-U;'14>7!E*"1C
M=7)R96YT0VUD240L("=0=70G*3L*"B`@("`@("`@("`@("1C=7)R96YT0VUD
M240K*SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240[
M"B`@("!]"B`@("`O*BH*("`@("`J($-R96%T92!A("9L=#M&:6YA;"9G=#L@
M;W5T<'5T+@H@("`@("H@0F5F;W)E('1H870@8V]N=&EN=64@82!S>6YC(&EF
M('1H97)E(&%R92!P96YD:6YG(&5N=')I97,N"B`@("`@*B!3=&%T:6,@;65T
M:&]D"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U=$9I;F%L*"1C=7)R96YT
M0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%
M4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("1A='1R<R`](&%R<F%Y
M*"D["@H@("`@("`@(&=L;V)A;"`D;65S<V%G949U;&P["B`@("`@("`@+RH@
M268@=&AE<F4G<R!P96YD:6YG('-Y;F,@9&%T82!A;F0@<W!A8V4@;&5F="!I
M;B!T:&4@;65S<V%G93H*("`@("`@("`@*B!S96YD(&1A=&$@;F]W+B`J+PH@
M("`@("`@(&EF("@A)&UE<W-A9V5&=6QL("8F"B`@("`@("`@("`@("`@("!C
M;W5N="@D<"`]("1S=&%T92T^9V5T4&5N9&EN9U-Y;F-S*"DI(#X@,"D@>PH@
M("`@("`@("`@("!F;W)E86-H("@D<"!A<R`D<&5N9&EN9U-Y;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@A)&UE<W-A9V5&=6QL*2!["B`@("`@("`@("`@
M("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S86=E*"=C;VYT
M:6YU92!S>6YC(&9O<B!S>6YC5'EP93TG("X@)'!E;F1I;F=3>6YC+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("`@("`@
M)'-Y;F,@/2`F("1S=&%T92T^9V5T4WEN8R@D<&5N9&EN9U-Y;F,I.PH@("`@
M("`@("`@("`@("`@("`@("1C=7)R96YT0VUD240@/2`D<WEN8RT^8W)E871E
M4WEN8T]U='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@("`@("`@+RH*("`@
M("`@("`@*B!$;VXG="!S96YD('1H92!F:6YA;"!T86<@:68@=V4@:&%V96XG
M="!S96YT(&%L;"!S>6YC(&1A=&$@>65T+@H@("`@("`@("`J+PH@("`@("`@
M(&EF("@A)'-T871E+3YH87-096YD:6YG16QE;65N=',H*2D@>PH@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)T9I;F%L)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G1FEN86PG*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S
M86=E*"=P96YD:6YG(&5L96UE;G1S+"!N;W0@<V5N9&EN9R!F:6YA;"!T86<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]'970N<&AP
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`T,#$`,3`T,3<S
M-C(W-S``,#(Q,3,V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD
M+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--3%]#;VUM86YD7T=E="!C;&%S<RX*
M("H*("H@5&AI<R!C;&%S<R!R97-P;VYD<R!T;R!A(&-L:65N="!G970@<F5Q
M=65S="!A;F0@<F5T=7)N<R!T:&4@1&5V26YF"B`J(&EN9F]R;6%T:6]N(&9O
M<B!T:&4@4WEN8TU,('-E<G9E<BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M4WEN8TU,+U-Y;F--3"]#;VUM86YD+T=E="YP:'`L=B`Q+C$T+C$P+C<@,C`P
M-B\P,2\P,2`R,3HR.#HS-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\
M9F]U<FUO;G1`9VUX+F1E/@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA
M;6EL;'-`<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]M;6%N9%]'970@
M97AT96YD<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@9G5N8W1I;VX@;W5T<'5T
M*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S=&%T
M92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`D<F5F
M(#T@*"1S=&%T92T^9V5T5F5R<VEO;B@I(#T](#`I(#\@)RXO9&5V:6YF,3`G
M(#H@)RXO9&5V:6YF,3$G.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC
M34Q?0V]M;6%N9%]3=&%T=7,H*"1S=&%T92T^:7-!=71H;W)I>F5D*"D@/R!2
M15-03TY315]/2R`Z(%)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,I+"`G
M1V5T)RD["B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD
M240I.PH@("`@("`@("1S=&%T=7,M/G-E=%1A<F=E=%)E9B@D<F5F*3L*("`@
M("`@("`D8W5R<F5N=$-M9$E$(#T@)'-T871U<RT^;W5T<'5T*"1C=7)R96YT
M0VUD240L("1O=71P=70I.PH*("`@("`@("!I9B`H)'-T871E+3YI<T%U=&AO
M<FEZ960H*2D@>PH@("`@("`@("`@("`D871T<G,@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)U)E<W5L=',G+"`D871T<G,I.PH*("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<L("1A='1R
M<RD["B`@("`@("`@("`@("1C:&%R<R`]("1C=7)R96YT0VUD240["B`@("`@
M("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@
M("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD
M240G*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G37-G4F5F)RP@)&%T=')S*3L*("`@("`@("`@("`@
M)&-H87)S(#T@)'-T871E+3YG971-<V=)1"@I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUS9U)E9B<I.PH*("`@
M("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=#;612968G+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D
M=&AI<RT^7V-M9$E$.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)T-M9%)E9B<I.PH*("`@("`@("`@("`@)&]U='!U
M="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-971A)RP@)&%T
M=')S*3L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T
M92T^9V5T55))365T82@I+"`G5'EP92<L("1A='1R<RD["B`@("`@("`@("`@
M(&EF("AI<U]A*"1O=71P=70L("=834Q?5T)834Q?16YC;V1E<B<I*2!["B`@
M("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*$U)345?4UE.0TU,
M7T1%5DE#15])3D9/7U="6$U,*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H34E-15]364Y#34Q?
M1$5624-%7TE.1D]?6$U,*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5224UE=&$H*2P@)U1Y
M<&4G*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G365T82<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RP@)&%T=')S*3L*
M("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=3;W5R8V4G+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A
M='1R<RD["B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)')E9BD[
M"B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)TQO8U5222<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))*"DL("=3;W5R8V4G*3L*"B`@("`@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T
M82<L("1A='1R<RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=$979);F8G+"`D871T<G,I
M.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DE$979);F8H*2`L("=697)$5$0G+"`D871T<G,I.PH@("`@("`@("`@
M("`D;W5T<'5T+3YC:&%R86-T97)S*"@D<W1A=&4M/F=E=%9E<G-I;VXH*2`]
M/2`P*2`_("<Q+C`G(#H@)S$N,2<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G5F5R1%1$)RP@
M)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G36%N)RP@)&%T=')S*3L*("`@("`@
M("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@G=W=W+FAO<F1E+F]R9R<I.PH@
M("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M1&5V26YF*"D@+"`G36%N)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U
M="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G1&5V
M240G+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1?4T525D526R=(5%107TA/4U0G72D["B`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=$979)1"<L
M("1A='1R<RD["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M<W1A=&4M/F=E=%52241E=DEN9B@I("P@)T1E=E1Y<"<L("1A='1R<RD["B`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)W-E<G9E<B<I.PH@("`@
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V
M26YF*"D@+"`G1&5V5'EP)RP@)&%T=')S*3L*("`@("`@("`@("`@)'1H:7,M
M/E]W<FET941A=&%3=&]R92@G;F]T97,G+"`G=&5X="]X+79N;W1E)RP@)S$N
M,2<L("1O=71P=70L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W1E>'0O<&QA:6XG(#T^("<Q+C`G*2D["B`@("`@("`@("`@
M("1T:&ES+3Y?=W)I=&5$871A4W1O<F4H)V-O;G1A8W1S)RP@)W1E>'0O>"UV
M8V%R9"<L("<R+C$G+"`D;W5T<'5T*3L*("`@("`@("`@("`@)'1H:7,M/E]W
M<FET941A=&%3=&]R92@G=&%S:W,G+"`G=&5X="]X+79C86QE;F1A<B<L("<Q
M+C`G+"`D;W5T<'5T*3L*("`@("`@("`@("`@)'1H:7,M/E]W<FET941A=&%3
M=&]R92@G8V%L96YD87(G+"`G=&5X="]X+79C86QE;F1A<B<L("<Q+C`G+"`D
M;W5T<'5T*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%52241E=DEN9B@I("P@)T1E=DEN9B<L("1A='1R<RD["@H@("`@
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=$871A)RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)TET96TG*3L*("`@("`@("`@("`@)&]U='!U="T^
M96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4F5S=6QT<R<I.PH*("`@
M("`@("`@("`@)&-U<G)E;G1#;61)1"LK.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7
M<FET97,@1&5V26YF(&1A=&$@9F]R(&]N92!$871A4W1O<F4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<V]U<F-E<F5F.B!D871A(&9O<B!3;W5R
M8V52968@96QE;65N="X*("`@("`J($!P87)A;2!S=')I;F<@)&UI;65T>7!E
M.B!D871A(&9O<B`F;'0[*%)\5"EX+5!R968F9W0[)FQT.T-45'EP929G=#L*
M("`@("`J($!P87)A;2!S=')I;F<@)'9E<G-I;VXZ(&1A=&$@9F]R("9L=#LH
M4GQ4*7@M4')E9B9G=#LF;'0[5F5R0U0F9W0["B`@("`@*B!`<&%R86T@<W1R
M:6YG("8D;W5T<'5T(&-O;G1E;G1H86YD;&5R('1H870@=VEL;"!R96-E:79E
M9"!T:&4@;W5T<'5T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A9&1I=&EO;F%L
M='EP97,Z(&%R<F%Y(&]F(&%D9&ET:6]N86P@='EP97,@9F]R(%1X(&%N9"!2
M>#L*("`@("`J("`@("`@("`@("`@("!F;W)M870@87)R87DH)W1E>'0O=F-A
M<F0G(#T^("<R+C`G*0H@("`@("HO"B`@("!F=6YC=&EO;B!?=W)I=&5$871A
M4W1O<F4H)'-O=7)C97)E9BP@)&UI;65T>7!E+"`D=F5R<VEO;BP@)B1O=71P
M=70L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%D9&ET:6]N86QT
M>7!E<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1A='1R<R`](&%R<F%Y*"D[
M"@H@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==
M.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DE$979);F8H*2`L("=$871A4W1O<F4G+"`D871T<G,I.PH@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@
M)U-O=7)C95)E9B<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C
M=&5R<R@D<V]U<F-E<F5F*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4V]U<F-E4F5F)RP@)&%T=')S
M*3L*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))1&5V26YF*"D@+"`G4G@M4')E9B<L("1A='1R<RD["B`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G
M0U14>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1M:6UE='EP92D["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%52241E=DEN9B@I("P@)T-45'EP92<L("1A='1R<RD["B`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF
M*"D@+"`G5F5R0U0G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H87)A
M8W1E<G,H)'9E<G-I;VXI.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=697)#5"<L("1A='1R<RD["B`@
M("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN
M9B@I("P@)U)X+5!R968G+"`D871T<G,I.PH*("`@("`@("!I9B`H:7-?87)R
M87DH)&%D9&ET:6]N86QT>7!E<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)&%D9&ET:6]N86QT>7!E<R!A<R`D8W0@/3X@)&-T=F5R*7L*("`@("`@("`@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E
M=DEN9B@I("P@)U)X)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)T-4
M5'EP92<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R
M86-T97)S*"1C="D["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G0U14>7!E)RP@)&%T=')S
M*3L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4)RP@)&%T=')S*3L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-T=F5R*3L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$
M979);F8H*2`L("=697)#5"<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G
M4G@G+"`D871T<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H
M*2`L("=4>"U0<F5F)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=#5%1Y<&4G+"`D
M871T<G,I.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&UI;65T>7!E
M*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M1&5V26YF*"D@+"`G0U14>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=697)#
M5"<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D=F5R
M<VEO;BD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%52241E=DEN9B@I("P@)U9E<D-4)RP@)&%T=')S*3L*("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G5'@M
M4')E9B<L("1A='1R<RD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D861D:71I
M;VYA;'1Y<&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D861D:71I;VYA
M;'1Y<&5S(&%S("1C="`]/B`D8W1V97(I>PH@("`@("`@("`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G
M5'@G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%
M;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G0U14>7!E)RP@)&%T
M=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-T
M*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DE$979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I.PH@("`@("`@
M("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M1&5V26YF*"D@+"`G5F5R0U0G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8W1V97(I.PH@("`@("`@("`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@
M)U9E<D-4)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=4>"<L("1A='1R
M<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1O=71P=70M
M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U-Y;F-#
M87`G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U-Y;F-4>7!E)RP@)&%T=')S*3L*
M("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"<Q)RD["B`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U-Y
M;F-4>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=3>6YC5'EP92<L("1A='1R
M<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@G,B<I.PH@("`@("`@
M("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L
M("=3>6YC5'EP92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U-Y;F-#87`G+"`D871T
M<G,I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG9715
M4DE$979);F8H*2`L("=$871A4W1O<F4G+"`D871T<G,I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]-87`N<&AP````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`U,C(`,3`T,3<S-C(W-S``,#(Q
M,3,W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<["@HO
M*BH*("H@5&AE(%-Y;F--3%]-87`@8VQA<W,@<')O=FED97,@82!3>6YC34P@
M:6UP;&5M96YT871I;VX@;V8*("H@=&AE($UA<"!C;VUM86YD(&%S(&1E9FEN
M960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+`H@*B!V97)S
M:6]N(#$N,"XQ(#4N-2XX+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC
M34PO4WEN8TU,+T-O;6UA;F0O36%P+G!H<"QV(#$N,2XQ,"XV(#(P,#8O,#$O
M,#$@,C$Z,C@Z,S8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S
M=&5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?36%P(&5X=&5N
M9',@4WEN8TU,7T-O;6UA;F0@>PH*("`@("\J*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?<V]U<F-E3&]C55)).PH*("`@("\J*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=&%R9V5T3&]C
M55)).PH*("`@('9A<B`D7VUA<%1A<F=E=#L*("`@('9A<B`D7VUA<%-O=7)C
M93L*"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P
M=70I"B`@("!["B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@
M)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@
M("1S=&%T=7,@/2`F;F5W(%-Y;F--3%]#;VUM86YD7U-T871U<R@D<W1A=&4M
M/FES075T:&]R:7IE9"@I(#\@4D534$].4T5?3TL@.B!215-03TY315])3E9!
M3$E$7T-2141%3E1)04Q3+"`G36%P)RD["B`@("`@("`@)'-T871U<RT^<V5T
M0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH@("`@("`@(&EF("@D=&AI<RT^7W-O
M=7)C94QO8U5222`A/2!N=6QL*2!["B`@("`@("`@("`@("1S=&%T=7,M/G-E
M=%-O=7)C95)E9B@D=&AI<RT^7W-O=7)C94QO8U5222D["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^7W1A<F=E=$QO8U5222`A/2!N=6QL*2!["B`@
M("`@("`@("`@("1S=&%T=7,M/G-E=%1A<F=E=%)E9B@D=&AI<RT^7W1A<F=E
M=$QO8U5222D["B`@("`@("`@?0H*("`@("`@("`D8W5R<F5N=$-M9$E$(#T@
M)'-T871U<RT^;W5T<'5T*"1C=7)R96YT0VUD240L("1O=71P=70I.PH*("`@
M("`@("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E='1E<B!F;W(@<')O<&5R='D@<V]U<F-E55))+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-O=7)C955222`@3F5W('9A;'5E(&]F('!R
M;W!E<G1Y('-O=7)C955222X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4V]U
M<F-E3&]C55))*"1S;W5R8V554DDI"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M;W5R8V554DD@/2`D<V]U<F-E55)).PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%1A<F=E=$QO8U5222@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=&%R9V5T55)).PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P
M<F]P97)T>2!T87)G97154DDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&%R9V5T55))("!.97<@=F%L=64@;V8@<')O<&5R='D@=&%R9V5T55))
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971487)G97154DDH)'1A<F=E=%52
M22D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<F=E=%5222`]("1T87)G9715
M4DD["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E
M;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@("`@<&%R96YT.CIS=&%R=$5L
M96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["@H@("`@("`@('-W:71C
M:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#(Z"B`@
M("`@("`@("`@(&EF("@D96QE;65N="`]/2`G36%P271E;2<I('L*("`@("`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?;6%P5&%R9V5T*3L*("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?;6%P4V]U<F-E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@96YD16QE;65N="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@
M("!G;&]B86P@)&)A8VME;F0["@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H
M:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("1S
M=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("`@
M("`D<WEN8R`]("8@)'-T871E+3YG9713>6YC*"1T:&ES+3Y?=&%R9V5T3&]C
M55))*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@
M("`@("`@("`@:68@*"1E;&5M96YT(#T]("=-87!)=&5M)RD@>PH@("`@("`@
M("`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT[
M"B`@("`@("`@("`@("`@("`D<WEN8R`]("8@)'-T871E+3YG9713>6YC*"1T
M:&ES+3Y?=&%R9V5T3&]C55))*3L*("`@("`@("`@("`@("`@(&EF("@A)'-T
M871E+3YI<T%U=&AO<FEZ960H*2D@>PH@("`@("`@("`@("`@("`@("`@("1B
M86-K96YD+3YL;V=-97-S86=E*"=.;W0@075T:&]R:7IE9"!I;B!-87!)=&5M
M(2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!/=F5R=W)I
M=&4@97AI<W1I;F<@9&%T82!B>2!R96UO=FEN9R!I="!F:7)S="X*("`@("`@
M("`@("`@("`@("`@("`D8F%C:V5N9"T^8W)E871E56ED36%P*"1S=&%T92T^
M9V5T4WEN8TED96YT:69I97(H*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%R9V5T3&]C55))+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M87!3;W5R8V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUA<%1A<F=E="D["@H@("`@("`@("`@("`@
M("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=C<F5A=&5D($UA<"!F;W(@
M<V]U<F-E/2<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`N("1T:&ES+3Y?;6%P4V]U<F-E"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B`G(&%N9"!T87)G970])R`N("1T:&ES
M+3Y?;6%P5&%R9V5T"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G(&EN(&1B("<@+B`D=&AI<RT^7W1A<F=E=$QO8U5222P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@,SH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=,;V-5
M4DDG*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C:ULQ72`]
M/2`G4V]U<F-E)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U
M<F-E3&]C55))(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@('T@96QS96EF("@D=&AI<RT^7U-T86-K6S%=(#T]("=487)G970G*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T87)G971,;V-54DD@/2!T
M<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#0Z"B`@
M("`@("`@("`@(&EF("@D96QE;65N="`]/2`G3&]C55)))RD@>PH@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,ET@/3T@)U-O=7)C92<I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUA<%-O=7)C92`]('1R:6TH
M)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H
M:7,M/E]3=&%C:ULR72`]/2`G5&%R9V5T)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;6%P5&%R9V5T(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D
M=7)I+"`D96QE;65N="D["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+U-Y;F--3"]#;VUM86YD+U!U="YP:'``````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`R,#0Q,P`Q,#0Q-S,V,C<W,``P,C$Q-S(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"FEN
M8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA;F0O4'5T+G!H<"QV
M(#$N,3(N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,V(&IA;B!%>'`@)`H@*@H@
M*B!4:&4@4WEN8TU,7T-O;6UA;F1?4'5T.CH@8VQA<W,@:&%N9&QE<R!$979)
M;F8@9&5V:6-E(&EN9F]R;6%T:6]N"B`J('-E;G0@8GD@=&AE(&-L:65N="X@
M5&AE(&1A=&$@:7,@<W1O<F5D(&EN(&$@4WEN8TU,7T1E=FEC94EN9F\*("H@
M;V)J96-T('=H:6-H(&ES(&1E9FEN960@:6X@1&5V:6-E+G!H<"!A;F0@=&AE
M;B!S=&]R960@:6X*("H@4WEN8TU,7T1E=FEC92!A<R!A;B!A='1R:6)U=&4N
M"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@0W5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($MA
M<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC
M34Q?0V]M;6%N9%]0=70@97AT96YD<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@
M=F%R("1?9&5V:6YF.PH*("`@("\J*@H@("`@("H@3&]C86P@=F%R<R!T;R!R
M96UE;6)E<B!S=&%T92X*("`@("`J+PH@("`@=F%R("1?8W5R<F5N=$13.PH@
M("`@=F%R("1?0U14>7!E.PH@("`@=F%R("1?5F5R0U0["@H@("`@=F%R("1?
M8W5R<F5N=%!R;W!.86UE.PH@("`@=F%R("1?8W5R<F5N=%!A<F%M3F%M93L*
M("`@('9A<B`D7V-U<G)E;G1#5%1Y<&4["@H@("`@=F%R("1?8W5R<F5N=%A.
M86T["@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT
M+"`D871T<G,I"B`@("!["B`@("`@("`@<&%R96YT.CIS=&%R=$5L96UE;G0H
M)'5R:2P@)&5L96UE;G0L("1A='1R<RD["B`@("`@("`@<W=I=&-H("AC;W5N
M="@D=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@
M("`@)'1H:7,M/E]D979I;F8@/2`F;F5W(%-Y;F--3%]$979I8V5);F9O*"D[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#4Z"B`@("`@("`@
M("`@(&EF("@D96QE;65N="`]/2`G1&%T85-T;W)E)RD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C=7)R96YT1%,@/2`F;F5W(%-Y;F--3%]$871A4W1O
M<F4H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I+"`D96QE
M;65N="D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["@H@("`@("`@
M("1D:2`]("8D=&AI<RT^7V1E=FEN9CL*("`@("`@("!S=VET8V@@*&-O=6YT
M*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@
M("`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==+3YS971$979I8V5);F9O*"1D
M:2D["@H@("`@("`@(&-A<V4@-3H*("`@("`@("`@("`@<W=I=&-H("@D96QE
M;65N="D@>PH@("`@("`@("`@("!C87-E("=697)$5$0G.@H@("`@("`@("`@
M("`@("`@)&1I+3Y?5F5R1%1$(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G36%N)SH*
M("`@("`@("`@("`@("`@("1D:2T^7TUA;B`]('1R:6TH)'1H:7,M/E]C:&%R
M<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)TUO9"<Z"B`@("`@("`@("`@("`@("`D9&DM/E]-;V0@/2!T<FEM*"1T:&ES
M+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E("=/14TG.@H@("`@("`@("`@("`@("`@)&1I+3Y?3T5-(#T@=')I
M;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G1G=6)SH*("`@("`@("`@("`@("`@("1D:2T^7T9W
M5B`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)U-W5B<Z"B`@("`@("`@("`@("`@("`D
M9&DM/E]3=U8@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=(=U8G.@H@("`@("`@("`@
M("`@("`@)&1I+3Y?2'=6(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G1&5V240G.@H@
M("`@("`@("`@("`@("`@)&1I+3Y?1&5V240@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=$9794>7`G.@H@("`@("`@("`@("`@("`@)&1I+3Y?1&5V5'EP(#T@=')I
M;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G551#)SH*("`@("`@("`@("`@("`@("1D:2T^7U54
M0R`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)U-U<'!O<G1,87)G94]B:G,G.@H@("`@("`@("`@("`@("`@)&1I
M+3Y?4W5P<&]R=$QA<F=E3V)J<R`]('1R=64["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U-U<'!O<G1.=6UB97)/9D-H86YG
M97,G.@H@("`@("`@("`@("`@("`@)&1I+3Y?4W5P<&]R=$YU;6)E<D]F0VAA
M;F=E<R`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)T1A=&%3=&]R92<Z"B`@("`@("`@("`@("`@("`D9&DM/E]$
M871A4W1O<F5;72`]("1T:&ES+3Y?8W5R<F5N=$13.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=#5$-A<"<Z"B`@("`@("`@
M("`@(&-A<V4@)T5X="<Z"B`@("`@("`@("`@("`@("`O+R!!=71O;6%T:6-A
M;&QY(&AA;F1L960@8GD@<W5B96QE;65N=',N"B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`V.@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C:ULT72`]
M/2`G1&%T85-T;W)E)RD@>PH@("`@("`@("`@("`@("`@<W=I=&-H("@D96QE
M;65N="D@>PH@("`@("`@("`@("`@("`@8V%S92`G4V]U<F-E4F5F)SH*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1$4RT^7U-O=7)C95)E
M9B`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G1&ES<&QA>4YA;64G.@H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?1&ES<&QA
M>4YA;64@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)TUA>$=52413:7IE
M)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1$4RT^7TUA
M>$=52413:7IE(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=$4TUE;2<Z
M"B`@("`@("`@("`@("`@("`@("`@+R\@0W5R<F5N=&QY(&EG;F]R960L('1O
M(&)E(&1O;F4N"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`G4WEN8T-A<"<Z"B`@("`@("`@("`@("`@("`@("`@
M+R\@075T;VUA=&EC86QL>2!H86YD;&5D(&)Y(%-Y;F-4>7!E('-U8F5L96UE
M;G0N"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@8V%S92`G4G@M4')E9B<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C=7)R96YT1%,M/E]2>%]0<F5F6R1T:&ES+3Y?0U14>7!E72`]("1T:&ES
M+3Y?5F5R0U0["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`G4G@G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=$13+3Y?4GA;)'1H:7,M/E]#5%1Y<&5=(#T@)'1H:7,M/E]6
M97)#5#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M("`@("!C87-E("=4>"U0<F5F)SH*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-U<G)E;G1$4RT^7U1X7U!R969;)'1H:7,M/E]#5%1Y<&5=(#T@)'1H
M:7,M/E]697)#5#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!C87-E("=4>"<Z"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C=7)R96YT1%,M/E]4>%LD=&AI<RT^7T-45'EP95T@/2`D=&AI<RT^
M7U9E<D-4.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]3=&%C:ULT72`]/2`G0U1#87`G*2!["B`@("`@("`@("`@("`@("!S=VET
M8V@@*"1E;&5M96YT*2!["B`@("`@("`@("`@("`@("!C87-E("=#5%1Y<&4G
M.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-45'EP92`]
M('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G4')O<$YA;64G.@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE(#T@=')I;2@D
M=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("`O+R!297-E="!P
M87)A;2!S=&%T92X*("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M7V-U<G)E;G1087)A;4YA;64I.PH@("`@("`@("`@("`@("`@("`@("1D:2T^
M7T-40V%P6R1T:&ES+3Y?8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT
M4')O<$YA;65=(#T@)FYE=R!3>6YC34Q?4')O<&5R='DH*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=087)A
M;4YA;64G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!A
M<F%M3F%M92`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@
M("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M/E]C=7)R96YT0U14>7!E75LD=&AI
M<RT^7V-U<G)E;G10<F]P3F%M95TM/E]P87)A;7-;)'1H:7,M/E]C=7)R96YT
M4&%R86U.86UE72`]("9N97<@4WEN8TU,7U!R;W!E<G1Y4&%R86UE=&5R*"D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G5F%L16YU;2<Z"B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M971E<B!M;V1E+@H@("`@("`@
M("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U<G)E;G1#
M5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A<F%M<ULD=&AI
M<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?5F%L16YU;5MT<FEM*"1T:&ES+3Y?
M8VAA<G,I72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M/E]C
M=7)R96YT0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM/E]686Q%
M;G5M6W1R:6TH)'1H:7,M/E]C:&%R<RE=(#T@=')U93L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`G1&%T851Y<&4G.@H@("`@("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]C=7)R96YT4&%R86U.86UE*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!792=R92!I;B!P87)A;65T97(@;6]D
M92X*("`@("`@("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M
M/E]C=7)R96YT0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM/E]P
M87)A;7-;)'1H:7,M/E]C=7)R96YT4&%R86U.86UE72T^7T1A=&%4>7!E(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI
M<RT^7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^
M7T1A=&%4>7!E(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`G4VEZ92<Z"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M971E<B!M;V1E+@H@
M("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U
M<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A<F%M
M<ULD=&AI<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?4VEZ92`]('1R:6TH)'1H
M:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M/E]C=7)R
M96YT0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM/E]3:7IE(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`G1&ES<&QA>4YA;64G.@H@("`@("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]C=7)R96YT4&%R86U.86UE*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!792=R92!I;B!P87)A;65T97(@;6]D92X*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M/E]C=7)R96YT
M0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM/E]P87)A;7-;)'1H
M:7,M/E]C=7)R96YT4&%R86U.86UE72T^7T1I<W!L87E.86UE(#T@=')I;2@D
M=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U
M<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7T1I<W!L
M87E.86UE(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7U-T86-K6S1=(#T]("=%>'0G("8F("1E;&5M96YT(#T]("=83F%M)RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT6$YA;2`]('1R:6TH)'1H
M:7,M/E]C:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?4W1A8VM;-%T@/3T@)T5X="<@)B8@)&5L96UE;G0@/3T@)UA686PG
M*2!["B`@("`@("`@("`@("`@("`D9&DM/E]%>'1;)'1H:7,M/E]C=7)R96YT
M6$YA;5U;72`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@-SH*("`@("`@("`@
M("`@:68@*"1E;&5M96YT(#T]("=697)#5"<I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?5F5R0U0@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@)T-45'EP92<I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?0U14>7!E(#T@=')I;2@D=&AI<RT^7V-H87)S
M*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT(#T]("=3>6YC5'EP
M92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?4WEN
M8T-A<%MT<FEM*"1T:&ES+3Y?8VAA<G,I72`]('1R=64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!P87)E
M;G0Z.F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&]U='!U="@D8W5R<F5N=$-M9$E$+"`F)&]U='!U="`I"B`@("![
M"B`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT[
M"@H@("`@("`@("1S=&%T=7,@/2`F;F5W(%-Y;F--3%]#;VUM86YD7U-T871U
M<R@H*"1S=&%T92T^:7-!=71H;W)I>F5D*"DI(#\@4D534$].4T5?3TL@.B!2
M15-03TY315])3E9!3$E$7T-2141%3E1)04Q3*2P@)U!U="<I.PH@("`@("`@
M("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI<RT^7V-M9$E$*3L*"B`@("`@("`@
M)')E9B`]("@D<W1A=&4M/F=E=%9E<G-I;VXH*2`]/2`P*2`_("<N+V1E=FEN
M9C$P)R`Z("<N+V1E=FEN9C$Q)SL*"B`@("`@("`@)'-T871U<RT^<V5T4V]U
M<F-E4F5F*"1R968I.PH*("`@("`@("!R971U<FX@)'-T871U<RT^;W5T<'5T
M*"1C=7)R96YT0VUD240L("1O=71P=70I.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--
M3"]#;VUM86YD+U)E<W5L=',N<&AP````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-S$V,P`Q,#0Q-S,V,C<W,``P,C(P-S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC
M92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA;F0O4F5S=6QT<RYP:'`L=B`Q+C$Q
M+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HS-B!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI
M9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@3F%T:&%N(%`@
M4VAA<G`*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y;F--
M3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?4F5S=6QT<R!E>'1E;F1S(%-Y
M;F--3%]#;VUM86YD('L*"B`@("!V87(@)%]S=6)#;VUM86YD.PH@("`@=F%R
M("1?<V%V9615<FD["B`@("!V87(@)%]S879E9$5L96UE;G0["B`@("!V87(@
M)%]S879E9$%T=')S.PH@("`@=F%R("1?<V%V961#;61)1#L*("`@('9A<B`D
M7V-H87)S.PH*("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE
M;65N="P@)&%T=')S*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%;&5M
M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH*("`@("`@("!S=VET8V@@
M*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@("`@
M("`@("`@("`O+R!3879E('1H92!I;F9O+"!W92!M87D@:&%V92!T;R!R92US
M96YD('1H:7,@<W1A<G1%;&5M96YT"B`@("`@("`@("`@("\O('1O('1H92!S
M=6(M8V]M;6%N9"!L871E<BX*("`@("`@("`@("`@)'1H:7,M/E]S879E9%5R
M:2`]("1U<FD["B`@("`@("`@("`@("1T:&ES+3Y?<V%V961%;&5M96YT(#T@
M)&5L96UE;G0["B`@("`@("`@("`@("1T:&ES+3Y?<V%V961!='1R<R`]("1A
M='1R<SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]S=6)#;VUM86YD*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W-U8D-O;6UA;F0M/G-T87)T16QE;65N="@D=7)I+"`D96QE;65N
M="P@)&%T=')S*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@96YD
M16QE;65N="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@("!S=VET8V@@
M*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`R.@H@("`@
M("`@("`@("!I9B`H)&5L96UE;G0@/3T@)T-M9$E$)R`F)B`A:7-S970H)'1H
M:7,M/E]S=6)#;VUM86YD*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S
M879E9$-M9$E$(#T@:6YT=F%L*'1R:6TH)'1H:7,M/E]C:&%R<RDI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)T-M9%)E
M9B<I('L*("`@("`@("`@("`@("`@("1C;612968@/2!I;G1V86PH=')I;2@D
M=&AI<RT^7V-H87)S*2D["B`@("`@("`@("`@("`@("`D<W1A=&4@/2`F)%]3
M15-324].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@("`@("`@("`O+R!)
M9B!T:&ES(')E<W5L="!P86-K970@:7,@<F5L871E9"!T;R!S;VUE=&AI;F<@
M86YD"B`@("`@("`@("`@("`@("`O+R!N965D<R!T;R!B92!R;W5T960@=&\@
M82!P87)T:6-U;&%R(&-O;6UA;F0@;V)J96-T+`H@("`@("`@("`@("`@("`@
M+R\@9&\@:70@;F]W+@H@("`@("`@("`@("`@("`@)&-M9%1Y<&4@/2`D<W1A
M=&4M/F=E=$5X<&5C=&5D4F5S=6QT5'EP92@D8VUD4F5F*3L*("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)&-M9%1Y<&4I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S=6)#;VUM86YD(#T@)E-Y;F--3%]#;VUM86YD.CIF
M86-T;W)Y*"1C;614>7!E*3L*("`@("`@("`@("`@("`@("`@("`O+R!4:&ES
M(&ES;B=T('1O=&%L;'D@=&5C:&YI8V%L;'D@8V]R<F5C="!B96-A=7-E"B`@
M("`@("`@("`@("`@("`@("`@+R\@=&AE(%A-3"!C;W5L9"!H879E(&)E96X@
M;W5T(&]F(&]R9&5R(&%N9"!W90H@("`@("`@("`@("`@("`@("`@("\O(&UI
M9VAT(&AA=F4@;6ES<V5D('-O;64@<W1U9F8L(&)U="!I;B!R96%L:71Y+`H@
M("`@("`@("`@("`@("`@("`@("\O(&ET('!R;V)A8FQY('=O;B=T(&AA<'!E
M;BX*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-U8D-O;6UA;F0M/G-T
M87)T16QE;65N="@*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S
M879E9%5R:2P*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S879E
M9$5L96UE;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V%V
M961!='1R<RD["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<V%V961#;61)1"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M1DE8344Z(%-H;W5L9&XG="!B92!A8V-E<W-I;F<@=&AI<R!P<FEV871E"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(&UE;6)E<BX*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S=6)#;VUM86YD+3Y?8VUD240@/2`D=&AI
M<RT^7W-A=F5D0VUD240["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`O+R!&86QL('1H<F]U9V@@=&\@=&AE
M(&1E9F%U;'0@8V%S92X*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<W5B0V]M;6%N9"DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<W5B0V]M;6%N9"T^96YD16QE;65N="@D=7)I+"`D96QE
M;65N="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!P87)E;G0Z.F5N9$5L96UE;G0H)'5R:2P@)&5L96UE
M;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-H87)A8W1E<G,H)'-T<BD*("`@
M('L*("`@("`@("!P87)E;G0Z.F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<W5B0V]M;6%N9"DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]S=6)#;VUM86YD+3YC:&%R86-T97)S*"1S='(I.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@
M)B1O=71P=70I"B`@("!["B`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG
M4WEN8TU,+G-T871E)UT["@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-U
M8D-O;6UA;F0I*2!["B`@("`@("`@("`@("\O($YO=&4@=&AA="!T:&4@<W1A
M='5S('!A8VME="!T:&4@<W5B(&-O;6UA;F0@=VEL;"!S96YD"B`@("`@("`@
M("`@("\O('=I;&P@8F4@=&5C:&YI8V%L;'D@:6YC;W)R96-T(&1U92!T;R!T
M:&ES(')E9&ER96-T:6]N+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]S
M=6)#;VUM86YD+3YO=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T871U<R`]("9N97<@4WEN
M8TU,7T-O;6UA;F1?4W1A='5S*%)%4U!/3E-%7T]++"`G4F5S=6QT<R<I.PH@
M("`@("`@("`@("`D<W1A='5S+3YS971#;612968H)'1H:7,M/E]C;61)1"D[
M"@H@("`@("`@("`@("!R971U<FX@)'-T871U<RT^;W5T<'5T*"1C=7)R96YT
M0VUD240L("1O=71P=70I.PH@("`@("`@('T*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U-T871U<RYP:'``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C$Q,``Q,#0Q-S,V,C<W,``P,C$W
M,#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*<F5Q
M=6ER95]O;F-E("=3>6YC34PO0V]N<W1A;G1S+G!H<"<["@HO*BH*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+U-T871U<RYP
M:'`L=B`Q+C$U+C$P+C8@,C`P-B\P,2\S,2`Q-SHU-3HQ.2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL
M;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN
M8TU,7T-O;6UA;F1?4W1A='5S(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@>PH*
M("`@('9A<B`D7W)E<W!O;G-E.PH*("`@('9A<B`D7V-M9%)E9CL*"B`@("`O
M*BH*("`@("`J($UU<W0@8F4@<')E<V5N="X*("`@("`J+PH@("`@=F%R("1?
M8VUD.PH*("`@('9A<B`D7W-O=7)C95)E9CL*"B`@("!V87(@)%]T87)G9712
M968["@H@("`@=F%R("1?8VAA;$UE=&%&;W)M870["@H@("`@=F%R("1?8VAA
M;$UE=&%4>7!E.PH*("`@('9A<B`D7V-H86Q-971A3F5X=$YO;F-E.PH*("`@
M('9A<B`D7VET96U$871A06YC:&]R3F5X=#L*"B`@("!V87(@)%]I=&5M1&%T
M84%N8VAO<DQA<W0["@H@("`@9G5N8W1I;VX@4WEN8TU,7T-O;6UA;F1?4W1A
M='5S*"1R97-P;VYS92`](&YU;&PL("1C;60@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("@D<F5S<&]N<V4@(3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W)E<W!O;G-E(#T@)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1C;60@(3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V-M9"`]
M("1C;60["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&]U='!U="@D
M8W5R<F5N=$-M9$E$+"`F)&]U='!U="D*("`@('L*("`@("`@("`D871T<G,@
M/2!A<G)A>2@I.PH*("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC
M34PN<W1A=&4G73L*"B`@("`@("`@:68@*"1T:&ES+3Y?8VUD("$](&YU;&PI
M('L*("`@("`@("`@("`@)&%T=')S(#T@87)R87DH*3L*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3=&%T
M=7,G+"`D871T<G,I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M
M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<L("1A='1R<RD["B`@("`@
M("`@("`@("1C:&%R<R`]("1C=7)R96YT0VUD240["B`@("`@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G*3L*"B`@
M("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G37-G4F5F)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@
M)'-T871E+3YG971-<V=)1"@I.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R
M86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)TUS9U)E9B<I.PH*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;612
M968G+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D=&AI<RT^7V-M
M9%)E9CL*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I
M.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=#;612968G*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD)RP@)&%T=')S*3L*("`@
M("`@("`@("`@)&-H87)S(#T@)'1H:7,M/E]C;60["B`@("`@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD)RD["@H@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T87)G9712968I*2!["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)U1A<F=E=%)E9B<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D
M8VAA<G,@/2`D=&AI<RT^7W1A<F=E=%)E9CL*("`@("`@("`@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U1A<F=E=%)E
M9B<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]S;W5R8V52968I*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U-O=7)C95)E9B<L("1A
M='1R<RD["B`@("`@("`@("`@("`@("`D8VAA<G,@/2`D=&AI<RT^7W-O=7)C
M95)E9CL*("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H
M87)S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)U-O=7)C95)E9B<I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O+R!)9B!W92!A<F4@<F5S<&]N9&EN9R!T;R!T:&4@4WEN
M8TAD<B!A;F0@=V4@87)E(&YO=`H@("`@("`@("`@("`O+R!A=71H;W)I>F5D
M('1H96X@<F5Q=65S="!B87-I8R!A=71H;W)I>F%T:6]N+@H@("`@("`@("`@
M("`O+PH@("`@("`@("`@("`O+R!&25A-13H@4FEG:'0@;F]W('=E(&%L=V%Y
M<R!S96YD('1H:7,L(&EG;F]R:6YG('1H90H@("`@("`@("`@("`O+R!I<T%U
M=&AO<FEZ960H*2!T97-T+B!)<R!T:&%T(&-O<G)E8W0_"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7V-M9"`]/2`G4WEN8TAD<B<@)B8@(21S=&%T92T^:7-!
M=71H;W)I>F5D*"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;$UE
M=&%&;W)M870@/2`G8C8T)SL*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;$UE=&%4>7!E(#T@)W-Y;F-M;#IA=71H+6)A<VEC)SL*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<F5S<&]N<V4@/2!215-03TY315]#4D5$14Y424%,4U]-
M25-324Y'.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]C:&%L365T849O<FUA="D@)B8@:7-S970H)'1H:7,M/E]C:&%L
M365T851Y<&4I*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)'-T871E+3YG97154DDH*2P@)T-H86PG+"`D871T<G,I.PH@("`@
M("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=-971A)RP@)&%T=')S*3L*"B`@("`@("`@("`@("`@("`D;65T
M86EN9G5R:2`]("1S=&%T92T^9V5T55))365T82@I.PH*("`@("`@("`@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D;65T86EN9G5R:2P@)U1Y<&4G
M+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&-H87)S(#T@)'1H:7,M/E]C
M:&%L365T851Y<&4["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T
M97)S*"1C:&%R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1M971A:6YF=7)I+"`G5'EP92<I.PH*("`@("`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D;65T86EN9G5R:2P@)T9O<FUA="<L("1A
M='1R<RD["B`@("`@("`@("`@("`@("`D8VAA<G,@/2`D=&AI<RT^7V-H86Q-
M971A1F]R;6%T.PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R
M<R@D8VAA<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D;65T86EN9G5R:2P@)T9O<FUA="<I.PH*("`@("`@("`@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUE=&$G*3L*
M("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)T-H86PG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=$871A
M)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@)'1H:7,M/E]R97-P
M;VYS93L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I
M.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=$871A)RD["@H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]I=&5M1&%T84%N8VAO<DYE>'0I('Q\(&ES<V5T*"1T:&ES+3Y?:71E;41A
M=&%!;F-H;W),87-T*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RP@)&%T=')S*3L*
M("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G1&%T82<L("1A='1R<RD["@H@("`@("`@("`@("`@("`@
M)&UE=&%I;F9U<FD@/2`D<W1A=&4M/F=E=%5224UE=&$H*3L*("`@("`@("`@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D;65T86EN9G5R:2P@)T%N
M8VAO<B<L("1A='1R<RD["@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?:71E;41A=&%!;F-H;W),87-T*2D@>PH*("`@("`@("`@("`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1M971A:6YF=7)I+"`G3&%S="<L
M("1A='1R<RD["B`@("`@("`@("`@("`@("`@("1C:&%R<R`]("1T:&ES+3Y?
M:71E;41A=&%!;F-H;W),87-T.PH@("`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)&UE=&%I;F9U<FDL("=,87-T)RD["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M:71E;41A=&%!;F-H;W).97AT*2D@>PH*("`@("`@("`@("`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1M971A:6YF=7)I+"`G3F5X="<L("1A='1R
M<RD["B`@("`@("`@("`@("`@("`@("1C:&%R<R`]("1T:&ES+3Y?:71E;41A
M=&%!;F-H;W).97AT.PH@("`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R
M86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)&UE=&%I;F9U<FDL("=.97AT)RD["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D;65T
M86EN9G5R:2P@)T%N8VAO<B<I.PH*("`@("`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G*3L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)TET96TG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4W1A='5S)RD["@H@
M("`@("`@("`@("`D8W5R<F5N=$-M9$E$*RL["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E='1E<B!F;W(@<')O<&5R='D@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<F5S<&]N<V4@($YE=R!V86QU92!O9B!P<F]P97)T
M>2!R97-P;VYS92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4F5S<&]N<V4H
M)')E<W!O;G-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5S<&]N<V4@/2`D
M<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R
M;W!E<G1Y(&-M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;60@
M($YE=R!V86QU92!O9B!P<F]P97)T>2!C;60N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$-M9"@D8VUD*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VUD(#T@
M)&-M9#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R
M='D@8VUD4F5F+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-M9%)E
M9B`@3F5W('9A;'5E(&]F('!R;W!E<G1Y(&-M9%)E9BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T0VUD4F5F*"1C;612968I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]C;612968@/2`D8VUD4F5F.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T=&5R(&9O<B!P<F]P97)T>2!S;W5R8V52968N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V]U<F-E4F5F("!.97<@=F%L=64@;V8@<')O<&5R
M='D@<V]U<F-E4F5F+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9713;W5R8V52
M968H)'-O=7)C95)E9BD*("`@('L*("`@("`@("`D=&AI<RT^7W-O=7)C95)E
M9B`]("1S;W5R8V52968["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@
M9F]R('!R;W!E<G1Y('1A<F=E=%)E9BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T87)G9712968@($YE=R!V86QU92!O9B!P<F]P97)T>2!T87)G
M9712968N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1A<F=E=%)E9B@D=&%R
M9V5T4F5F*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&%R9V5T4F5F(#T@)'1A
M<F=E=%)E9CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O
M<&5R='D@:71E;41A=&%!;F-H;W).97AT+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ET96U$871A06YC:&]R3F5X="`@3F5W('9A;'5E(&]F('!R
M;W!E<G1Y(&ET96U$871A06YC:&]R3F5X="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T271E;41A=&%!;F-H;W).97AT*"1I=&5M1&%T84%N8VAO<DYE>'0I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]I=&5M1&%T84%N8VAO<DYE>'0@/2`D
M:71E;41A=&%!;F-H;W).97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M=&5R(&9O<B!P<F]P97)T>2!I=&5M1&%T84%N8VAO<DQA<W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:71E;41A=&%!;F-H;W),87-T("!.97<@
M=F%L=64@;V8@<')O<&5R='D@:71E;41A=&%!;F-H;W),87-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971)=&5M1&%T84%N8VAO<DQA<W0H)&ET96U$871A
M06YC:&]R3&%S="D*("`@('L*("`@("`@("`D=&AI<RT^7VET96U$871A06YC
M:&]R3&%S="`]("1I=&5M1&%T84%N8VAO<DQA<W0["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O4WEN8T5L96UE;G0N<&AP
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-C,T`#$P-#$W,S8R-S<P`#`R
M,C8U-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M;6%N9"YP:'`G.PH*
M+RHJ"B`J(%1H92!C;&%S<R!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N="!S
M=&]R97,@:6YF;W)M871I;VX@9G)O;2!T:&4@061D+`H@*B!$96QE=&4@86YD
M(%)E<&QA8V4@96QE;65N=',@9F]U;F0@:6YS:61E(&$@<WEN8R!C;VUM86YD
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA
M;F0O4WEN8T5L96UE;G0N<&AP+'8@,2XS+C(N,R`R,#`V+S`Q+S`Q(#(Q.C(X
M.C,V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V(%1H92!H
M;W)D92!P<F]J96-T("AW=W<N:&]R9&4N;W)G*0H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*
M("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7U-Y;F-%;&5M96YT(&5X=&5N9',@
M4WEN8TU,7T-O;6UA;F0@>PH*("`@("\J*@H@("`@("H@061D+"!$96QE=&4@
M;W(@4F5P;&%C92X*("`@("`J+PH@("`@=F%R("1?96QE;65N=%1Y<&4["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!O9B!3>6YC34Q?4WEN8TET96T@96YT<FEE
M<RX*("`@("`J+PH@("`@=F%R("1?:71E;7,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@36EM971Y<&4@9F]R(&%L;"!I=&5M<RX*("`@("`J+PH@("`@
M=F%R("1?8V]N=&5N=%1Y<&4["@H@("`@+RHJ"B`@("`@*B!496UP(&1A=&$@
M9F]R(&-R96%T:6]N(&]F(&EN9&EV:61U86P@:71E;7,N"B`@("`@*B\*("`@
M('9A<B`D7V-O;G1E;G0["@H@("`@=F%R("1?8W5I9#L*"B`@("`O*BH*("`@
M("`J($UI;65T>7!E(&9O<B!I;F1I=FED=6%L(&ET96TN"B`@("`@*B\*("`@
M('9A<B`D7VET96U#;VYE;G14>7!E.PH*("`@("\J*@H@("`@("H@0W)E871E
M<R!A(%-Y;F,@16QE;65N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&5L96UE;G14>7!E(&5I=&AE<B!!9&0L($1E;&5T92!O<B!297!L86-E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%-Y;F--3%]#;VUM86YD7U-Y;F-%;&5M96YT
M*"1E;&5M96YT5'EP92D*("`@('L*("`@("`@("`D=&AI<RT^7V5L96UE;G14
M>7!E(#T@)&5L96UE;G14>7!E.PH@("`@?0H*("`@(&9U;F-T:6]N(&]U='!U
M="@D8W5R<F5N=$-M9$E$+"`F)&]U='!U="D*("`@('L*("`@("`@("!S=VET
M8V@@*"1T:&ES+3Y?96QE;65N=%1Y<&4I('L*("`@("`@("!C87-E("=!9&0G
M.@H@("`@("`@("`@("`D<F5S<&]N<V4@/2!215-03TY315])5$5-7T%$1$5$
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G1&5L971E)SH*
M("`@("`@("`@("`@)')E<W!O;G-E(#T@4D534$].4T5?3TL["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E("=297!L86-E)SH*("`@("`@("`@
M("`@)')E<W!O;G-E(#T@4D534$].4T5?3TL["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*"B`@("`@("`@)'-T871U<R`]("9N97<@4WEN8TU,7T-O
M;6UA;F1?4W1A='5S*"1R97-P;VYS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E;&5M96YT5'EP92D[
M"B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH*
M("`@("`@("!R971U<FX@)'-T871U<RT^;W5T<'5T*"1C=7)R96YT0VUD240L
M("1O=71P=70I.PH@("`@?0H*("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D
M=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@>PH@("`@("`@('!A<F5N=#HZ
M<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH@("`@("`@
M('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E
M(#(Z"B`@("`@("`@("`@("1T:&ES+3Y?8W5I9"`](&YU;&P["B`@("`@("`@
M("`@("1T:&ES+3Y?8V]N=&5N="`](&YU;&P["B`@("`@("`@("`@("1T:&ES
M+3Y?:71E;4-O;G1E;G14>7!E(#T@;G5L;#L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI
M<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@*"1E;&5M96YT
M(#T]("=)=&5M)RD@>PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES
M+3Y?:71E;4-O;G1E;G14>7!E*0H@("`@("`@("`@("`@("`@("`@("8F("%E
M;7!T>2@D=&AI<RT^7V-O;G1E;G14>7!E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:71E;4-O;G1E;G14>7!E(#T@)'1H:7,M/E]C;VYT96YT
M5'EP93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VET96US6UT@/2`F;F5W(%-Y;F--3%]3>6YC271E;2@D=&AI<RT^7V5L
M96UE;G14>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I=&5M0V]N=&5N=%1Y<&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-U:60I.PH@("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@,SH*("`@("`@
M("`@("`@:68@*"1E;&5M96YT(#T]("=4>7!E)RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C;VYT96YT5'EP92`]('1R:6TH)'1H:7,M/E]C:&%R<RD[
M"B`@("`@("`@("`@('T@96QS96EF("@D96QE;65N="`]/2`G1&%T82<I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N="`]('1R:6TH)'1H:7,M
M/E]C:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@-#H*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=,
M;V-54DDG*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C:ULR
M72`]/2`G4V]U<F-E)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8W5I9"`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)'1H:7,M/E]3=&%C:ULR72`]/2`G5&%R9V5T)RD@>PH@("`@
M("`@("`@("`@("`@("`@("\O($YO="!U<V5D.B!W92!I9VYO<F4@(G-U:60@
M<')O<&]S86QS(B!F<F]M"B`@("`@("`@("`@("`@("`@("`@+R\@8VQI96YT
M+@H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E(#4Z"B`@("`@("`@("`@(&EF("@D96QE
M;65N="`]/2`G5'EP92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:71E
M;4-O;G1E;G14>7!E(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A
M<F5N=#HZ96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T271E;7,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7VET96US.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14>7!E
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT5'EP93L*
M("`@('T*"GT*"B\J*@H@*B!4:&4@8VQA<W,@4WEN8TU,7T-O;6UA;F1?4WEN
M8T5L96UE;G0@<W1O<F5S(&EN9F]R;6%T:6]N(&%B;W5T"B`J('1H92!I=&5M
M<R!I;G-I9&4@82!S>6YC(&5L96UE;G0@*$%D9'Q$96QE=&5\4F5P;&%C92DN
M"B`J"B`J($$@<VEN9VQE(%-Y;F-%;&5M96YT(&-A;B!C;VYT86EN(&UU;'1I
M<&QE(&ET96US+@H@*@H@*B!);G-T86YC97,@;V8@=&AI<R!C;&%S<R!A<F4@
M8W)E871E9"!D=7)I;F<@=&AE(%A-3"!P87)S:6YG(&)Y"B`J(%-Y;F--3%]#
M;VUM86YD7U-Y;F-%;&5M96YT+@H@*@H@*B!`<&%C:V%G92!3>6YC34P*("HO
M"F-L87-S(%-Y;F--3%]3>6YC271E;2!["@H@("`@+RHJ"B`@("`@*B!!9&0L
M($1E;&5T92!O<B!297!L86-E+"!I;FAE<FET960@9G)O;0H@("`@("H@4WEN
M8TU,7T-O;6UA;F1?4WEN8T5L96UE;G0N"B`@("`@*B\*("`@('9A<B`D7V5L
M96UE;G14>7!E.PH*("`@('9A<B`D7V-U:60["@H@("`@+RHJ"B`@("`@*B!/
M<'1I;VYA;"P@;6%Y(&)E('!R;W9I9&5D(&)Y('!A<F5N="!E;&5M96YT(&]R
M(&5V96X@;F]T(&%T(&%L;"X*("`@("`J+PH@("`@=F%R("1?8V]N=&5N=%1Y
M<&4["@H@("`@=F%R("1?8V]N=&5N=#L*"B`@("!F=6YC=&EO;B!3>6YC34Q?
M4WEN8TET96TH)&5L96UE;G14>7!E+"`D8V]N=&5N="`](&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G14>7!E(#T@;G5L;"P@
M)&-U:60@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?96QE;65N=%1Y
M<&4@/2`D96QE;65N=%1Y<&4["B`@("`@("`@)'1H:7,M/E]C=6ED(#T@)&-U
M:60["B`@("`@("`@)'1H:7,M/E]C;VYT96YT5'EP92`]("1C;VYT96YT5'EP
M93L*("`@("`@("`D=&AI<RT^7V-O;G1E;G0@/2`D8V]N=&5N=#L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971#=6ED*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]C=6ED.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G0H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;G1E;G0["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-O;G1E;G14>7!E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$5L96UE;G14>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]E;&5M96YT5'EP93L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U-Y;F,N<&AP
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3(R-@`Q,#0Q-S,V
M,C<W,``P,C$S-#``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0N
M<&AP)SL*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M;6%N9"]3>6YC16QE;65N
M="YP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC
M34PO0V]M;6%N9"]3>6YC+G!H<"QV(#$N,3<N,3`N."`R,#`V+S`Q+S$Q(#$X
M.C,Y.C(X('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V
M($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!4
M:&4@8V]M;6%N9"!H86YD;&5R(&9O<B!T:&4@)F=T.U-Y;F,F;'0[(&-O;6UA
M;F0@:7,@=&AE(&-E;G1R86P*("H@8VQA<W,@=&\@9&ES<&%T8V@@<WEN8R!M
M97-S86=E<RX*("H*("H@1'5R:6YG('!A<G-I;F<@;V8@=&AE(')E8V5I=F5D
M(%A-3"P@=&AE(&%C='5A;"!S>6YC(&-O;6UA;F1S("A!9&0L"B`J(%)E<&QA
M8V4L($1E;&5T92D@9G)O;2!T:&4@8VQI96YT(&%R92!S=&]R960@:6X@=&AE
M(%]S>6YC16QE;65N=',*("H@871T<FEB=71E+B`@5VAE;B!T:&4@;W5T<'5T
M(&UE=&AO9"!O9B!3>6YC34Q?0V]M;6%N9%]3>6YC(&ES"B`J(&-A;&QE9"P@
M=&AE<V4@96QE;65N=',@87)E('!R;V-E<W-E9"!A;F0@=&AE(')E<W5L=&EN
M9R!S=&%T=7,*("H@;65S<V%G97,@8W)E871E9"X*("H*("H@5&AE;B!T:&4@
M<V5R=F5R(&UO9&EF:6-A=&EO;G,@87)E('-E;G0@8F%C:R!T;R!T:&4@8VQI
M96YT(&)Y('1H90H@*B!H86YD;&53>6YC(&UE=&AO9"!W:&EC:"!I<R!C86QL
M960@9G)O;2!W:71H:6X@=&AE(&]U='!U="!M971H;V0N"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y
M;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?4WEN8R!E>'1E;F1S(%-Y
M;F-M;%]#;VUM86YD"GL*("`@("\J*@H@("`@("H@0'9A<B!3>6YC34Q?0V]M
M;6%N9%]3>6YC16QE;65N=`H@("`@("HO"B`@("!V87(@)%]C=7)R96YT4WEN
M8T5L96UE;G0["@H@("`@+RHJ"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W-Y;F-%;&5M96YT<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!C;VYT86-T<RP@8V%L96YD87(L('1A<VMS(&]R(&YO=&5S"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=&%R9V5T
M55)).PH*("`@("\J*@H@("`@("H@0W)E871E<R!A(')E<W!O;G-E('1O(&$@
M<WEN8R!C;VUM86YD+@H@("`@("H@0W5R<F5N=&QY('1H870G<R!T:&4@<&QA
M8V4@=VAE<F4@=V4@86QS;R!C<F5A=&4*("`@("`J('1H92`F;'0[<WEN8R9G
M=#L@=VET:"!T:&4@<V5R=F5R(&-H86YG97,@=&AA=`H@("`@("H@;F5E9',@
M=&\@8F4@<V5N9"!T;R!T:&4@8VQI96YT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@("!["B`@("`@
M("`@)'-T871E(#TF("1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["B`@("`@
M("`@)'-Y;F,@/28@)'-T871E+3YG9713>6YC*"1T:&ES+3Y?=&%R9V5T55))
M*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D<WEN8RDI('L*("`@("`@("`@
M("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G92@G3F\@<WEN8R!O
M8FIE8W0@9F]U;F0@9F]R(%5222`]("<@+B`D=&AI<RT^7W1A<F=E=%5222P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M("\O($!43T1/.B!C<F5A=&4@;65A;FEN9V9U;"!S=&%T=7,@8V]D92!H97)E
M+@H@("`@("`@('T*"B`@("`@("`@+R\@2&5R92=S('=H97)E(&-L:65N="!M
M;V1I9FEC871I;VYS(&%R92!P<F]C97-S960Z"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]S>6YC16QE;65N=',@87,@)&5L96UE;G0I('L*("`@("`@("`@
M("`@9F]R96%C:"`H)&5L96UE;G0M/F=E=$ET96US*"D@87,@)&ET96TI('L*
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D<WEN8RT^:&%N9&QE4WEN8TET
M96TH)&ET96TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C=7)R96YT
M0VUD240@/2`D96QE;65N="T^;W5T<'5T*"1C=7)R96YT0VUD240L("1O=71P
M=70I.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]W('-E;F0@8VQI96YT(&-H
M86YG97,@=&\@<V5R=F5R.B!T:&ES('=I;&P@<')E8V5D92!T:&4*("`@("`@
M("`@*B`\<WEN8SX@<F5S<&]N<V4Z("HO"B`@("`@("`@)&-U<G)E;G1#;61)
M1"`]("1S>6YC+3YC<F5A=&53>6YC3W5T<'5T*"1C=7)R96YT0VUD240L("1O
M=71P=70I.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N
M9%]3=&%T=7,H4D534$].4T5?3TLL("=3>6YC)RD["B`@("`@("`@)'-T871U
M<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH*("`@("`@("!I9B`H)'1H
M:7,M/E]T87)G97154DD@(3T@;G5L;"D@>PH@("`@("`@("`@("`D<W1A='5S
M+3YS971487)G9712968H)'1H:7,M/E]T87)G97154DDI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1T:&ES+3Y?<V]U<F-E55))("$](&YU;&PI('L*("`@
M("`@("`@("`@)'-T871U<RT^<V5T4V]U<F-E4F5F*"1T:&ES+3Y?<V]U<F-E
M55))*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<W1A='5S+3YO=71P
M=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T5&%R9V5T55))*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]T87)G97154DD["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT
M*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@("`@<&%R96YT
M.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["@H@("`@
M("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C
M87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G4F5P;&%C92<@
M?'P@)&5L96UE;G0@/3T@)T%D9"<@?'P@)&5L96UE;G0@/3T@)T1E;&5T92<I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M96YT
M(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N="@D96QE;65N="D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C=7)R96YT4WEN8T5L96UE;G0I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M96YT+3YS
M=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE
M;G0I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8W5R<F5N=%-Y
M;F-%;&5M96YT*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G13>6YC
M16QE;65N="T^96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("`@("`@
M?0H*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@
M("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)U)E
M<&QA8V4G('Q\("1E;&5M96YT(#T]("=!9&0G('Q\("1E;&5M96YT(#T]("=$
M96QE=&4G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-Y;F-%;&5M96YT
M<UM=(#T@)'1H:7,M/E]C=7)R96YT4WEN8T5L96UE;G0["B`@("`@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^7V-U<G)E;G13>6YC16QE;65N="D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,SH*
M("`@("`@("`@("`@:68@*"1E;&5M96YT(#T@)TQO8U5222<@)B8@(6ES<V5T
M*"1T:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M96YT*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U-O=7)C92<I('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C955222`]('1R:6TH)'1H:7,M
M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]3
M=&%C:ULQ72`]/2`G5&%R9V5T)RD@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=&%R9V5T55))(#T@8F%S96YA;64H<')E9U]R97!L86-E*"<O7#\N
M*B0O)RP@)R<L('1R:6TH)'1H:7,M/E]C:&%R<RDI*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D=7)I+"`D96QE;65N
M="D["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R<R@D<W1R*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-U<G)E;G13>6YC16QE;65N
M="DI('L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT4WEN8T5L96UE;G0M
M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA<G,I*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H87)S(#T@)'1H:7,M/E]C:&%R<R`N("1S='(["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H87)S
M(#T@)'-T<CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]N<W1A;G1S
M+G!H<```````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(R,C0`
M,3`T,3<S-C(W-S``,#(Q,#(Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;G-T86YT<RYP
M:'`L=B`Q+C$N,BXS(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X<"`D"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK
M87)S=&5N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PID969I
M;F4H)T%,15)47T1)4U!,05DG+"`Q,#`I.PH*+R\@3F]T(&EM<&QE;65N=&5D
M+@ID969I;F4H)T%,15)47U173U]705DG+"`R,#`I.PID969I;F4H)T%,15)4
M7U-,3U=?4UE.0R<L(#(P,2D["F1E9FEN92@G04Q%4E1?3TY%7U=!65]&4D]-
M7T-,245.5"<L(#(P,BD["F1E9FEN92@G04Q%4E1?4D5&4D532%]&4D]-7T-,
M245.5"<L(#(P,RD["F1E9FEN92@G04Q%4E1?3TY%7U=!65]&4D]-7U-%4E9%
M4B<L(#(P-"D["F1E9FEN92@G04Q%4E1?4D5&4D532%]&4D]-7U-%4E9%4B<L
M(#(P-2D["@HO+R!.;W0@:6UP;&5M96YT960N"F1E9FEN92@G04Q%4E1?5%=/
M7U=!65]"65]315)615(G+"`R,#8I.PID969I;F4H)T%,15)47T].15]705E?
M1E)/35]#3$E%3E1?0EE?4T525D52)RP@,C`W*3L*9&5F:6YE*"=!3$525%]2
M149215-(7T923TU?0TQ)14Y47T)97U-%4E9%4B<L(#(P."D["F1E9FEN92@G
M04Q%4E1?3TY%7U=!65]&4D]-7U-%4E9%4E]"65]315)615(G+"`R,#DI.PID
M969I;F4H)T%,15)47U)%1E)%4TA?1E)/35]315)615)?0EE?4T525D52)RP@
M,C$P*3L*"F1E9FEN92@G04Q%4E1?4D5354Q47T%,15)4)RP@,C(Q*3L*9&5F
M:6YE*"=!3$525%].15A47TU%4U-!1T4G+"`R,C(I.PID969I;F4H)T%,15)4
M7TY/7T5.1%]/1E]$051!)RP@,C(S*3L*"F1E9FEN92@G34E-15]364Y#34Q?
M6$U,)RP@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PK>&UL)RD["F1E9FEN92@G
M34E-15]364Y#34Q?5T)834PG+"`G87!P;&EC871I;VXO=FYD+G-Y;F-M;"MW
M8GAM;"<I.PH*9&5F:6YE*"=-24U%7U-93D--3%]$159)0T5?24Y&3U]834PG
M+"`G87!P;&EC871I;VXO=FYD+G-Y;F-M;"UD979I;F8K>&UL)RD["F1E9FEN
M92@G34E-15]364Y#34Q?1$5624-%7TE.1D]?5T)834PG+"`G87!P;&EC871I
M;VXO=FYD+G-Y;F-M;"UD979I;F8K=V)X;6PG*3L*"F1E9FEN92@G34E-15]4
M15A47U!,04E.)RP@)W1E>'0O<&QA:6XG*3L*9&5F:6YE*"=-24U%7U9#05)$
M7U8R,2<L("=T97AT+W@M=F-A<F0G*3L*9&5F:6YE*"=-24U%7U9#05)$7U8S
M,"<L("=T97AT+W9C87)D)RD["@ID969I;F4H)TU)345?5D-!3$5.1$%2)RP@
M)W1E>'0O>"UV8V%L96YD87(G*3L*9&5F:6YE*"=-24U%7TE#04Q%3D1!4B<L
M("=T97AT+V-A;&5N9&%R)RD["F1E9FEN92@G34E-15]834Q?24-!3$5.1$%2
M)RP@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PM>&-A;"<I.PH*9&5F:6YE*"=-
M24U%7TU%4U-!1T4G+"`G=&5X="]M97-S86=E)RD["@ID969I;F4H)TU)345?
M4UE.0TU,7UA-3%]%34%)3"<L("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL+7AM
M<V<G*3L*9&5F:6YE*"=-24U%7U-93D--3%]834Q?0D]/2TU!4DLG+"`G87!P
M;&EC871I;VXO=FYD+G-Y;F-M;"UX8F]O:VUA<FLG*3L*9&5F:6YE*"=-24U%
M7U-93D--3%]214Q!5$E/3D%,7T]"2D5#5"<L("=A<'!L:6-A=&EO;B]V;F0N
M<WEN8VUL+7AR96QA=&EO;F%L)RD["@ID969I;F4H)U)%4U!/3E-%7TE.7U!2
M3T=215-3)RP@,3`Q*3L*"F1E9FEN92@G4D534$].4T5?3TLG+"`R,#`I.PID
M969I;F4H)U)%4U!/3E-%7TE414U?041$140G+"`R,#$I.PID969I;F4H)U)%
M4U!/3E-%7T%#0T505$5$7T9/4E]04D]#15-324Y')RP@,C`R*3L*9&5F:6YE
M*"=215-03TY315].3TY!551(3U))051!5$E615]215-03TY312<L(#(P,RD[
M"F1E9FEN92@G4D534$].4T5?3D]?0T].5$5.5"<L(#(P-"D["F1E9FEN92@G
M4D534$].4T5?4D53151?0T].5$5.5"<L(#(P-2D["F1E9FEN92@G4D534$].
M4T5?4$%25$E!3%]#3TY414Y4)RP@,C`V*3L*9&5F:6YE*"=215-03TY315]#
M3TY&3$E#5%]215-/3%9%1%]7251(7TU%4D=%)RP@,C`W*3L*9&5F:6YE*"=2
M15-03TY315]#3TY&3$E#5%]215-/3%9%1%]7251(7T-,245.5%]724Y.24Y'
M)RP@,C`X*3L*9&5F:6YE*"=215-03TY315]#3TY&24Q#5%]215-/3%9%1%]7
M251(7T154$Q)0T%412<L(#(P.2D["F1E9FEN92@G4D534$].4T5?1$5,151%
M7U=)5$A/551?05)#2$E612<L(#(Q,"D["F1E9FEN92@G4D534$].4T5?251%
M35].3U]$14Q%5$5$)RP@,C$Q*3L*9&5F:6YE*"=215-03TY315]!551(14Y4
M24-!5$E/3E]!0T-%4%1%1"<L(#(Q,BD["F1E9FEN92@G4D534$].4T5?0TA5
M3DM%1%])5$5-7T%#0T505$5$7T%.1%]"549&15)%1"<L(#(Q,RD["F1E9FEN
M92@G4D534$].4T5?3U!%4D%424].7T-!3D-%3$Q%1"<L(#(Q-"D["F1E9FEN
M92@G4D534$].4T5?3D]?15A%0U54140G+"`R,34I.PID969I;F4H)U)%4U!/
M3E-%7T%43TU)0U]23TQ,7T)!0TM?3TLG+"`R,38I.PH*9&5F:6YE*"=215-0
M3TY315]-54Q425!,15]#2$])0T53)RP@,S`P*3L*+R\@3F5E9"!T;R!C:&%N
M9V4@;F%M97,N"B\O(&1E9FEN92@G4D534$].4T5?355,5$E03$5?0TA/24-%
M4R<L(#,P,2D["B\O(&1E9FEN92@G4D534$].4T5?355,5$E03$5?0TA/24-%
M4R<L(#,P,BD["B\O(&1E9FEN92@G4D534$].4T5?355,5$E03$5?0TA/24-%
M4R<L(#,P,RD["B\O(&1E9FEN92@G4D534$].4T5?355,5$E03$5?0TA/24-%
M4R<L(#,P-"D["F1E9FEN92@G4D534$].4T5?55-%7U!23UA9)RP@,S`U*3L*
M"F1E9FEN92@G4D534$].4T5?0D%$7U)%455%4U0G+"`T,#`I.PID969I;F4H
M)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#$I.PHO+R!.965D
M('1O(&-H86YG92!N86UE<RX*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$
M7T-2141%3E1)04Q3)RP@-#`R*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!
M3$E$7T-2141%3E1)04Q3)RP@-#`S*3L*9&5F:6YE*"=215-03TY315].3U1?
M1D]53D0G+"`T,#0I.PHO+R!.965D('1O(&-H86YG92!N86UE<RX*+R\@9&5F
M:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)04Q3)RP@-#`U*3L*+R\@
M9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)04Q3)RP@-#`V*3L*
M9&5F:6YE*"=215-03TY315]#4D5$14Y424%,4U]-25-324Y')RP@-#`W*3L*
M+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)04Q3)RP@-#`X
M*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)04Q3)RP@
M-#`Y*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)04Q3
M)RP@-#$P*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)
M04Q3)RP@-#$Q*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%
M3E1)04Q3)RP@-#$R*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2
M141%3E1)04Q3)RP@-#$S*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$
M7T-2141%3E1)04Q3)RP@-#$T*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!
M3$E$7T-2141%3E1)04Q3)RP@-#$U*3L*9&5F:6YE*"=215-03TY315]215%5
M15-47U-)6D5?5$]/7T))1R<L(#0Q-BD["B\O($YE960@=&\@8VAA;F=E(&YA
M;65S+@HO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G
M+"`T,3<I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!
M3%,G+"`T,3@I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.
M5$E!3%,G+"`T,3DI.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%
M1$5.5$E!3%,G+"`T,C`I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?
M0U)%1$5.5$E!3%,G+"`T,C$I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,
M241?0U)%1$5.5$E!3%,G+"`T,C(I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.
M5D%,241?0U)%1$5.5$E!3%,G+"`T,C,I.PID969I;F4H)U)%4U!/3E-%7U-)
M6D5?34E334%40T@G+"`T,C0I.PH*9&5F:6YE*"=215-03TY315]#3TU-04Y$
M7T9!24Q%1"<L(#4P,"D["B\O($YE960@=&\@8VAA;F=E(&YA;65S+@HO+R!D
M969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`Q*3L*+R\@9&5F
M:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4P,BD["B\O(&1E9FEN
M92@G4D534$].4T5?0T]-34%.1%]&04E,140G+"`U,#,I.PHO+R!D969I;F4H
M)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`T*3L*+R\@9&5F:6YE*"=2
M15-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4P-2D["B\O(&1E9FEN92@G4D53
M4$].4T5?0T]-34%.1%]&04E,140G+"`U,#8I.PHO+R!D969I;F4H)U)%4U!/
M3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`W*3L*+R\@9&5F:6YE*"=215-03TY3
M15]#3TU-04Y$7T9!24Q%1"<L(#4P."D["B\O(&1E9FEN92@G4D534$].4T5?
M0T]-34%.1%]&04E,140G+"`U,#DI.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/
M34U!3D1?1D%)3$5$)RP@-3$P*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-
M04Y$7T9!24Q%1"<L(#4Q,2D["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.
M1%]&04E,140G+"`U,3(I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?
M1D%)3$5$)RP@-3$S*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$7T9!
M24Q%1"<L(#4Q-"D["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&04E,
M140G+"`U,34I.PHO+R!D969I;F4H)U)%4U!/3E-%7T%43TU)0U]23TQ,7T)!
M0TM?1D%)3$5$)RP@-3$V*3L*"F1E9FEN92@G3D%-15]34$%#15]54DE?4UE.
M0TU,7S%?,2<L("=S>6YC;6PZ<WEN8VUL,2XQ)RD["F1E9FEN92@G3D%-15]3
M4$%#15]54DE?4UE.0TU,)RP@)W-Y;F-M;#IS>6YC;6PG*3L*9&5F:6YE*"=.
M04U%7U-004-%7U5225]-151)3D8G+"`G<WEN8VUL.FUE=&EN9B<I.PID969I
M;F4H)TY!345?4U!!0T5?55))7TU%5$E.1E\Q7S$G+"`G<WEN8VUL.FUE=&EN
M9B<I.PID969I;F4H)TY!345?4U!!0T5?55))7T1%5DE.1B<L("=S>6YC;6PZ
M9&5V:6YF)RD["F1E9FEN92@G3D%-15]34$%#15]54DE?1$5624Y&7S%?,2<L
M("=S>6YC;6PZ9&5V:6YF)RD["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]3>6YC34PO1&5V:6-E26YF;RYP:'``````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#8W-3<`,3`T,3<S-C(W-S``,#(Q,#<V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!3>6YC34Q?1&5V:6-E26YF;R!R97!R97-E;G1S(&$@9&5V:6-E
M(&EN9F]R;6%T:6]N('-E="!A8V-O<F1I;F<@=&\*("H@=&AE(%-Y;F--3"!S
M<&5C+@H@*@H@*B!3964@:'1T<#HO+W=W=RYS>6YC;6PN;W)G+V1O8W,O<WEN
M8VUL7V1E=FEN9E]V,3%?,C`P,C`R,34N<&1F"B`J"B`J($$@1&5V:6-E26YF
M;R!O8FIE8W0@:7,@8W)E871E9"!B>2!#;VUM86YD+U!U=#HZ4WEN8TU,7T-O
M;6UA;F1?4'5T"B`J(&9R;VT@86X@87!P<F]P<FEA=&4@6$U,(&UE<W-A9V4N
M(%-Y;F--3%]#;VUM86YD7U!U="!D:7)E8W1L>0H@*B!P;W!U;&%T97,@=&AE
M(&UE;6)E<G,@=F%R:6%B;&5S+@H@*@H@*B!4:&4@8W5R<F5N="!I;7!L96UE
M;G1A=&EO;B!S:&]U;&0@:&%N9&QE(&%L;"!$979);F8@,2XQ($141`H@*B!E
M;&5M96YT<R!E>'!C97!T($13365M(&5N=')I97,N"B`J"B`J($-O<'ER:6=H
M="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC
M34PO4WEN8TU,+T1E=FEC94EN9F\N<&AP+'8@,2XR+C(N,R`R,#`V+S`Q+S`Q
M(#(Q.C(X.C,V(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!+87)S=&5N($9O
M=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@4WEN8TU,
M"B`J+PIC;&%S<R!3>6YC34Q?1&5V:6-E26YF;R!["@H@("`@=F%R("1?5F5R
M1%1$.PH@("`@=F%R("1?36%N.PH@("`@=F%R("1?36]D.PH@("`@=F%R("1?
M3T5-.PH@("`@=F%R("1?1G=6.PH@("`@=F%R("1?4W=6.PH@("`@=F%R("1?
M2'=6.PH@("`@=F%R("1?1&5V240["B`@("!V87(@)%]$9794>7`["@H@("`@
M+RHJ"B`@("`@*B!!<G)A>2!O9B!3>6YC34Q?1&%T85-T;W)E(&]B:F5C=',N
M"B`@("`@*B\*("`@('9A<B`D7T1A=&%3=&]R93L*"B`@("`O*BH*("`@("`J
M($%R<F%Y.B!#5%1Y<&4@/3X@87)R87DZ(%!R;W!E<G1Y3F%M92`]/B!3>6YC
M34Q?4')O<&5R='D@;V)J96-T+@H@("`@("HO"B`@("!V87(@)%]#5$-A<#L*
M"B`@("`O*BH*("`@("`J($%R<F%Y(%A.86T@/3X@87)R87D@;V8@6'9A;"!E
M;G1R:65S+@H@("`@("HO"B`@("!V87(@)%]%>'0["@H@("`@+RHJ"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?551#.PH*("`@("\J
M*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7U-U<'!O
M<G1,87)G94]B:G,["@H@("`@+RHJ"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?4W5P<&]R=$YU;6)E<D]F0VAA;F=E<SL*"GT*"B\J
M*@H@*B!4:&4@4WEN8TU,7T1A=&%3=&]R92!C;&%S<R!D97-C<FEB97,@;VYE
M(&]F('1H92!P;W-S:6)L90H@*B!D871A<W1O<F5S("AI+F4N(&1A=&%B87-E
M<RD@;V8@=&AE(&1E=FEC92X@($UO<W0@:6UP;W)T86YT"B`J(&%T=')I8G5T
M97,@87)E('1H92!P<F5F97)R960@36EM92!4>7!E<R!F;W(@<V5N9&EN9R!A
M;F0@<F5C96EV:6YG"B`J(&1A=&$@9F]R('1H:7,@9&%T87-T;W)E.B!?5'@M
M4')E9B!A;F0@7U)X+5!R968*("H*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC
M;&%S<R!3>6YC34Q?1&%T85-T;W)E('L*"B`@("`O*BH*("`@("`J(%1H92!L
M;V-A;"!54DD@;V8@=&AE(&1A=&%S=&]R92X*("`@("`J+PH@("`@=F%R("1?
M4V]U<F-E4F5F.PH*("`@("\J*@H@("`@("H@3W!T:6]N86PN"B`@("`@*B\*
M("`@('9A<B`D7T1I<W!L87E.86UE.PH*("`@("\J*@H@("`@("H@3W!T:6]N
M86PN"B`@("`@*B\*("`@('9A<B`D7TUA>$=52413:7IE.PH*("`@("\J*@H@
M("`@("H@3VYE(&5L96UE;G0@87)R87D@;V8@0U14>7!E(#T^(%9E<D-4"B`@
M("`@*B\*("`@('9A<B`D7U)X7U!R968["@H@("`@+RHJ"B`@("`@*B!!<G)A
M>2!O9B!#5%1Y<&4@/3X@5F5R0U0*("`@("`J+PH@("`@=F%R("1?4G@["@H@
M("`@+RHJ"B`@("`@*B!/;F4@96QE;65N="!A<G)A>2!O9B!#5%1Y<&4@/3X@
M5F5R0U0*("`@("`J+PH@("`@=F%R("1?5'A?4')E9CL*"B`@("`O*BH*("`@
M("`J($%R<F%Y(&]F($-45'EP92`]/B!697)#5`H@("`@("HO"B`@("!V87(@
M)%]4>#L*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+@H@("`@("HO"B`@("!V
M87(@)%]$4TUE;3L*"B`@("`O*BH*("`@("`J($%R<F%Y(%-Y;F-4>7!E(#T^
M('1R=64*("`@("`J+PH@("`@=F%R("1?4WEN8T-A<#L*"GT*"B\J*@H@*B!4
M:&4@8VQA<W,@4WEN8TU,7U!R;W!E<G1Y(&ES('5S960@=&\@9&5F:6YE(&$@
M<VEN9VQE('!R;W!E<G1Y"B`J(&]F(&$@=F-A<F0@96QE;65N="X@(%1H92!C
M;VYT96YT<R!O9B!A(%!R;W!E<G1Y(&-A;B!B92!D969I;F5D(&)Y"B`J(&%N
M(&5N=6UE<F%T:6]N(&]F('9A;&ED('9A;'5E<R`H7U9A;$5N=6TI(&]R(&)Y
M(&$@1&%T851Y<&4O4VEZ90H@*B!C;VUB:6YA=&EO;BP@;W(@;F]T(&%T(&%L
M;"X*("H*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?4')O
M<&5R='D@>PH*("`@("\J*@H@("`@("H@07)R87D@;V8@=F%L:60@=F%L=65S
M(#T^('1R=64*("`@("`J+PH@("`@=F%R("1?5F%L16YU;3L*"B`@("`O*BH*
M("`@("`J($EF(&YO="!686Q%;G5M+@H@("`@("HO"B`@("!V87(@)%]$871A
M5'EP93L*"B`@("`O*BH*("`@("`J($EF(&YO="!686Q%;G5M+"!O<'1I;VYA
M;"X*("`@("`J+PH@("`@=F%R("1?4VEZ93L*"B`@("`O*BH*("`@("`J($]P
M=&EO;F%L+@H@("`@("HO"B`@("!V87(@)%]$:7-P;&%Y3F%M93L*"B`@("`O
M*BH*("`@("`J($%R<F%Y(&]F(%!A<F%M3F%M92`]/B!3>6YC34Q?4')O<&5R
M='E087)A;65T97(*("`@("`J+PH@("`@=F%R("1?<&%R86US.PH*?0H*+RHJ
M"B`J(%1H92!C;&%S<R!3>6YC34Q?4')O<&5R='E087)A;65T97(@:7,@=7-E
M9"!T;R!D969I;F4@82!S:6YG;&4*("H@<&%R86UE=&5R(&]F(&$@<')O<&5R
M='D@;V8@82!V8V%R9"!E;&5M96YT+B`@5&AE(&-O;G1E;G1S(&]F(&$*("H@
M4')O<&5R='E087)A;65T97(@8V%N(&)E(&1E9FEN960@8GD@86X@96YU;65R
M871I;VX@;V8@=F%L:60@=F%L=65S"B`J("A?5F%L16YU;2D@;W(@8GD@82!$
M871A5'EP92]3:7IE(&-O;6)I;F%T:6]N+"!O<B!N;W0@870@86QL+@H@*@H@
M*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]0<F]P97)T>5!A
M<F%M971E<B!["@H@("`@+RHJ"B`@("`@*B!)9B!P<F]V:61E9#H@87)R87D@
M;V8@5F%L16YU;2`]/B!T<G5E"B`@("`@*B\*("`@('9A<B`D7U9A;$5N=6T[
M"@H@("`@+RHJ"B`@("`@*B!)9B!N;W0@5F%L16YU;2X*("`@("`J+PH@("`@
M=F%R("1?1&%T851Y<&4["@H@("`@+RHJ"B`@("`@*B!)9B!N;W0@5F%L16YU
M;2P@;W!T:6]N86PN"B`@("`@*B\*("`@('9A<B`D7U-I>F4["@H@("`@+RHJ
M"B`@("`@*B!/<'1I;VYA;"X*("`@("`J+PH@("`@=F%R("1?1&ES<&QA>4YA
M;64["@I]"@``````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0N<&AP````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-38U`#$P-#$W,S8R-S<P`#`R,#0S,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*:6YC;'5D95]O;F-E("=3>6YC34PO4W1A=&4N<&AP)SL*"B\J*@H@*B!4
M:&4@4WEN8TU,7T-O;6UA;F0@8VQA<W,@<')O=FED97,@82!S=7!E<B!C;&%S
M<R!F;R!3>6YC0F]D>0H@*B!C;VUM86YD<RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+G!H<"QV(#$N-"XQ,"XW(#(P
M,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@/&%M
M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD('L*"B`@
M("`O*BH*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]C
M;61)1#L*"B`@("`O*BH*("`@("`J($EN=&5R;F%L('-T<G5C='5R92!U<V5D
M(&1U<FEN9R!834P@<&%R<VEN9RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7U-T86-K(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-H87)S.PH*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"1C;VUM86YD+"`D<&%R86US(#T@;G5L
M;"D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD
M+R<@+B`D8V]M;6%N9"`N("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G4WEN
M8TU,7T-O;6UA;F1?)R`N("1C;VUM86YD.PH@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D8VUD(#T@)FYE=R`D8VQA
M<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)$=,
M3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G92@G0VQA<W,@9&5F:6YI=&EO
M;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(&EN8VQU9&5?;VYC
M92`G4$5!4BYP:'`G.PH@("`@("`@("`@("`D8VUD(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@
M9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-M9#L*("`@
M('T*"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U
M="D*("`@('L*("`@('T*"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE;G0H)'5R
M:2P@)&QO8V%L3F%M92P@)&%T=')S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M4W1A8VM;72`]("1L;V-A;$YA;64["B`@("!]"@H@("`@9G5N8W1I;VX@96YD
M16QE;65N="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@("!S=VET8V@@
M*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`R.@H@("`@
M("`@("`@("!I9B`H)&5L96UE;G0@/3T@)T-M9$E$)RD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C;61)1"`](&EN='9A;"AT<FEM*"1T:&ES+3Y?8VAA
M<G,I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?8VAA<G,@/2`G)SL*("`@("`@("!A<G)A
M>5]P;W`H)'1H:7,M/E]3=&%C:RD["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA
M<F%C=&5R<R@D<W1R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VAA<G,@+CT@
M)'-T<CL*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+U-Y;F--3"]3=&%T92YP:'``````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`R-#$Q-``Q,#0Q-S,V,C<W,``P,C`Q,C8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92`G4WEN8TU,+T1E=FEC94EN9F\N<&AP)SL*<F5Q=6ER95]O
M;F-E("=3>6YC34PO1&5V:6-E+G!H<"<["G)E<75I<F5?;VYC92`G4WEN8TU,
M+T-O;G-T86YT<RYP:'`G.PH*+RHJ"B`J(%1H92!3>6YC34Q?4W1A=&4@8VQA
M<W,@<')O=FED97,@82!3>6YC34P@<W1A=&4@;V)J96-T+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+U-T871E+G!H<"QV(#$N,3<N
M,BXX(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N=&AO;GD@36EL
M;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]3=&%T92![
M"@H@("`@+RHJ"B`@("`@*B!397-S:6]N(&ED(&]F('1H:7,@<V5S<VEO;BX*
M("`@("`J+PH@("`@=F%R("1?<V5S<VEO;DE$.PH*("`@("\J*@H@("`@("H@
M260@;V8@8W5R<F5N="!M97-S86=E+@H@("`@("HO"B`@("!V87(@)%]M<V=)
M1#L*"B`@("`O*BH*("`@("`J(%1H92!T87)G970@55))(&%S('-E;G0@8GD@
M=&AE(&-L:65N="X@5&AI<R!I<R!N;W)M86QL>2!T:&4@55),"B`@("`@*B!O
M9B!T:&4@2&]R9&4@<G!C('-E<G9E<BX@2&]W979E<B!T:&4@8VQI96YT(&ES
M(&9R964@=&\@<V5N9`H@("`@("H@86YY=&AI;F<Z('-Y;F,T:B!F;W(@97AA
M;7!L92!D;V5S(&YO="!S96YD('1H92!P871H('!A<G0N"B`@("`@*B\*("`@
M('9A<B`D7W1A<F=E=%5223L*"B`@("`O*BH*("`@("`J(%1H92!S;W5R8V4@
M55))(&%S('-E;G0@8GD@=&AE(&-L:65N="X@0V%N(&)E('5S960@=&\@:61E
M;G1I9GD*("`@("`J('1H92!C;&EE;G0[('1H92!S97-S:6]N(&ED(&ES(&-O
M;G-T<G5C=&5D(&UA:6YL>2!F<F]M('1H:7,*("`@("`J(&1A=&$N"B`@("`@
M*B\*("`@('9A<B`D7W-O=7)C955223L*"B`@("`O*BH*("`@("`J(#`@9F]R
M('-Y;F-M;"`Q+C`L(#$@9F]R('-Y;F-M;"`Q+C$N"B`@("`@*B\*("`@('9A
M<B`D7W9E<G-I;VX["@H@("`@+RHJ"B`@("`@*B!5<V5R;F%M92!U<V5D('1O
M(&%U=&@@=VET:"!T:&4@8F%C:V5N9"X*("`@("`J+PH@("`@=F%R("1?;&]C
M3F%M93L*"B`@("`O*BH*("`@("`J(%!A<W-W;W)D('5S960@=&\@875T:"!W
M:71H('1H92!B86-K96YD+@H@("`@("HO"B`@("!V87(@)%]P87-S=V]R9#L*
M"B`@("`O*BH*("`@("`J(%1R=64@;65A;G,@=&AA="!T:&ES('-E<W-I;VX@
M:&%S(&%U=&AE;G1I8V%T960@<W5C8V5S<V9U;&QY+@H@("`@("HO"B`@("!V
M87(@)%]I<T%U=&AO<FEZ960["@H@("`@+RHJ"B`@("`@*B!.86UE<W!A8V4@
M:6YF;W)M871I;VXN"B`@("`@*B\*("`@('9A<B`D7W5R:3L*"B`@("`O*BH*
M("`@("`J($YA;65S<&%C92!I;F9O<FUA=&EO;BX*("`@("`J+PH@("`@=F%R
M("1?=7)I365T83L*"B`@("`O*BH*("`@("`J($YA;65S<&%C92!I;F9O<FUA
M=&EO;BX*("`@("`J+PH@("`@=F%R("1?=7)I1&5V26YF.PH*("`@('9A<B`D
M7W=B>&UL.R`O+R!B;V]L96%N"@H@("`@=F%R("1?;6%X37-G4VEZ93L*"B`@
M("!V87(@)%]S>6YC<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!7<FET
M=&5N('1O(&1B(&%F=&5R('-U8V-E<W-F=6P@<WEN8RX*("`@("`J+PH@("`@
M=F%R("1?8VQI96YT06YC:&]R3F5X="`](&%R<F%Y*"D["@H@("`@=F%R("1?
M<V5R=F5R06YC:&]R3&%S="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!7
M<FET=&5N('1O(&1B(&%F=&5R('-U8V-E<W-F=6P@<WEN8RX*("`@("`J+PH@
M("`@=F%R("1?<V5R=F5R06YC:&]R3F5X="`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!3;6%L;"!H87-H('1O('-T;W)E('1H92!N=6UB97(@;V8@861D
M<RP@9&5L971E<RP@971C+B!D=7)I;F<@80H@("`@("H@<V5S<VEO;B!F;W(@
M8W)E871I;VX@;V8@<W5M;6%R>2!F;W(@;&]G9FEL92X*("`@("`J+PH@("`@
M=F%R("1?;&]G(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!3>6YC
M34Q?1&5V:6-E(&-L87-S(&1E9FEN960@:6X@1&5V:6-E+G!H<"X@5&AI<R!C
M;&%S<PH@("`@("H@:&%N9&QE<R!D96-I8V4@<W!E8VEF:6,@<W1U9F8N"B`@
M("`@*B\*("`@('9A<B`D7V1E=FEC93L*"B`@("`O*BH*("`@("`J($1E=FEC
M92!I;F9O('!R;W9I9&5D(&)Y('1H92!3>6YC34P@1&5V26YF(&1A=&$N($UA
M:6YL>2!U<V5D(&)Y"B`@("`@*B!T:&4@4WEN8TU,7T1E=FEC92!C;&%S<RX*
M("`@("`J+PH@("`@=F%R("1?9&5V:6-E26YF;SL*"B`@("`O*BH*("`@("`J
M($EF('=E(&%R92!E>'!E8W1I;F<@82!297-U;'0@<&%C:V5T+"!T:&ES('-T
M;W)E<R!W:&5R92!T;PH@("`@("H@<F]U=&4@:70N"B`@("`@*B\*("`@('9A
M<B`D7V5X<&5C=&5D4F5S=6QT(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-R96%T97,@82!N97<@:6YS=&%N8V4@;V8@4WEN8TU,7U-T871E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!3>6YC34Q?4W1A=&4H)'-O=7)C955222P@)&QO
M8TYA;64L("1S97-S:6]N240L("1P87-S=V]R9"`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1T:&ES+3YS9713;W5R8V554DDH)'-O=7)C955222D["B`@("`@
M("`@)'1H:7,M/G-E=$QO8TYA;64H)&QO8TYA;64I.PH@("`@("`@("1T:&ES
M+3YS971397-S:6]N240H)'-E<W-I;VY)1"D["B`@("`@("`@:68@*"1P87-S
M=V]R9"D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T4&%S<W=O<F0H)'!A<W-W
M;W)D*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YI<T%U=&AO<FEZ960@
M/2!F86QS93L*"B`@("`@("`@+R\@0W)E871E(&5M<'1Y(&1U;6UY(&1E=FEC
M92!I;F9O+B!7:6QL(&)E(')E<&QA8V5D('=I=&@@<F5A;`H@("`@("`@("\O
M($1E=DEN9B!I;F9O<FUA=&EO;B!I9B!T:&5Y(&%R92!T<F%N<V9E<G)E9"X*
M("`@("`@("`D=&AI<RT^7V1E=FEC94EN9F\@/2`F;F5W(%-Y;F--3%]$979I
M8V5);F9O*"D["@H@("`@("`@("\J(&%L;&]W('9E<GD@8FEG(&UE<W-A9V5S
M('5N;&5S<R!T;VQD(&]T:&5R=VES93H@*B\*("`@("`@("`D=&AI<RT^<V5T
M36%X37-G4VEZ92@Q,#`P,#`P,#`P*3L*("`@('T*"B`@("!F=6YC=&EO;B!S
M971$979I8V5);F9O*"1D:2D*("`@('L*("`@("`@("`D=&AI<RT^7V1E=FEC
M94EN9F\@/2`D9&D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&5V:6-E26YF
M;R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&5V:6-E26YF;SL*
M("`@('T*"B`@("!F=6YC=&EO;B!G971,;V-.86UE*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]L;V-.86UE.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%-O=7)C955222@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<V]U<F-E55)).PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1A<F=E=%5222@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&%R9V5T55)).PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=%9E<G-I;VXH*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W9E<G-I;VX["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M37-G240H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUS9TE$.PH@
M("`@?0H*("`@(&9U;F-T:6]N('-E=%="6$U,*"1W8GAM;"D*("`@('L*("`@
M("`@("`D=&AI<RT^7W=B>&UL(#T@)'=B>&UL.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&ES5T)834PH*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH)'1H
M:7,M/E]W8GAM;"D["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T36%X37-G4VEZ
M92@D<RD*("`@('L*("`@("`@("`D=&AI<RT^7VUA>$US9U-I>F4@/2`D<SL*
M("`@('T*"B`@("!F=6YC=&EO;B!G971-87A-<V=3:7IE*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]M87A-<V=3:7IE.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!M<V=)1"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M<V=)1"`@3F5W('9A;'5E(&]F('!R;W!E
M<G1Y(&US9TE$+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971-<V=)1"@D;7-G
M240I"B`@("!["B`@("`@("`@)'1H:7,M/E]M<V=)1"`]("1M<V=)1#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@;&]C3F%M
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L;V-.86UE("!.97<@
M=F%L=64@;V8@<')O<&5R='D@;&]C3F%M92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T3&]C3F%M92@D;&]C3F%M92D*("`@('L*("`@("`@("`D=&AI<RT^
M7VQO8TYA;64@/2`D;&]C3F%M93L*("`@('T*"B`@("!F=6YC=&EO;B!S9710
M87-S=V]R9"@D<&%S<W=O<F0I"B`@("!["B`@("`@("`@)'1H:7,M/E]P87-S
M=V]R9"`]("1P87-S=V]R9#L*("`@('T*"B`@("!F=6YC=&EO;B!S9713;W5R
M8V554DDH)'-O=7)C955222D*("`@('L*("`@("`@("`D=&AI<RT^7W-O=7)C
M955222`]("1S;W5R8V554DD["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T5&%R
M9V5T55))*"1T87)G97154DDI"B`@("!["B`@("`@("`@)'1H:7,M/E]T87)G
M97154DD@/2`D=&%R9V5T55)).PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%9E
M<G-I;VXH)'9E<G-I;VXI"B`@("!["B`@("`@("`@)'1H:7,M/E]V97)S:6]N
M(#T@)'9E<G-I;VX["@H@("`@("`@(&EF("@D=F5R<VEO;B`]/2`P*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?=7)I(#T@3D%-15]34$%#15]54DE?4UE.0TU,
M.PH@("`@("`@("`@("`D=&AI<RT^7W5R:4UE=&$@/2!.04U%7U-004-%7U52
M25]-151)3D8["B`@("`@("`@("`@("1T:&ES+3Y?=7)I1&5V26YF(#T@3D%-
M15]34$%#15]54DE?1$5624Y&.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?=7)I(#T@3D%-15]34$%#15]54DE?4UE.0TU,7S%?,3L*
M("`@("`@("`@("`@)'1H:7,M/E]U<FE-971A(#T@3D%-15]34$%#15]54DE?
M345424Y&7S%?,3L*("`@("`@("`@("`@)'1H:7,M/E]U<FE$979);F8@/2!.
M04U%7U-004-%7U5225]$159)3D9?,5\Q.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!S971397-S:6]N240H)'-E<W-I;VY)1"D*("`@('L*("`@
M("`@("`D=&AI<RT^7W-E<W-I;VY)1"`]("1S97-S:6]N240["B`@("!]"@H@
M("`@9G5N8W1I;VX@:7-!=71H;W)I>F5D*"D*("`@('L*("`@("`@("!I9B`H
M(21T:&ES+3Y?:7-!=71H;W)I>F5D("8F("%E;7!T>2@D=&AI<RT^7W!A<W-W
M;W)D*2D@>PH@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-
M97-S86=E*"=C:&5C:VEN9R!A=71H(&9O<B!U<V5R/2<*("`@("`@("`@("`@
M+B`D=&AI<RT^7VQO8TYA;64L"B`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("1A=71H(#T@
M)D%U=&@Z.G-I;F=L971O;B@D1TQ/0D%,4ULG8V]N9B==6R=A=71H)UU;)V1R
M:79E<B==*3L*("`@("`@("`@("`@)'1H:7,M/E]I<T%U=&AO<FEZ960@/2`D
M875T:"T^875T:&5N=&EC871E*"1T:&ES+3Y?;&]C3F%M92P@87)R87DH)W!A
M<W-W;W)D)R`]/B`D=&AI<RT^7W!A<W-W;W)D*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]I<T%U=&AO<FEZ960["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5T4WEN8R@D=&%R9V5T+"`F)'-Y;F,I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]S>6YC<ULD=&%R9V5T72`]("8D<WEN8SL*("`@('T*"B`@
M("!F=6YC=&EO;B`F9V5T4WEN8R@D=&%R9V5T*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W-Y;F-S6R1T87)G971=*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]S>6YC<ULD=&%R9V5T73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D9F%L<V4@/2!F86QS93L*("`@("`@("`@("`@
M<F5T=7)N("1F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T55))*"D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J(%1H92!N;VX@
M5T)834P@9&5V:6-E<R`H;F]T86)L>2!0.3`P(&%N9"!3>6YC-&H@<V5E;2!T
M;R!G970@8V]N9G5S960*("`@("`@("`@*B!B>2!A(#Q3>6YC34P@>&UL;G,]
M(G-Y;F-M;#I364Y#34PQ+C$B/B!E;&5M96YT+B!4:&5Y(')E<75I<F4*("`@
M("`@("`@*B!J=7-T(#Q3>6YC34P^+B!3;R!D;VXG="!U<V4@86X@;G,@9F]R
M(&YO;B!W8GAM;"!D979I8V5S+@H@("`@("`@("`J+PH@("`@("`@(&EF("@D
M=&AI<RT^:7-70EA-3"@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W5R:3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)R<[
M"B`@("`@("`@?0H@("`@?0H@("`@9G5N8W1I;VX@9V5T55))365T82@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=7)I365T83L*("`@('T*"B`@
M("!F=6YC=&EO;B!G97154DE$979);F8H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W5R:41E=DEN9CL*("`@('T*"B`@("!F=6YC=&EO;B!S971#
M;&EE;G1!;F-H;W).97AT*"1T>7!E+"`D82D*("`@('L*("`@("`@("`D=&AI
M<RT^7V-L:65N=$%N8VAO<DYE>'1;)'1Y<&5=(#T@)&$["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5T4V5R=F5R06YC:&]R3&%S="@D='EP92P@)&$I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]S97)V97)!;F-H;W),87-T6R1T>7!E72`]("1A
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-E<G9E<D%N8VAO<DYE>'0H)'1Y
M<&4L("1A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5R=F5R06YC:&]R3F5X
M=%LD='EP95T@/2`D83L*("`@('T*"B`@("!F=6YC=&EO;B!G971#;&EE;G1!
M;F-H;W).97AT*"1T>7!E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-L:65N=$%N8VAO<DYE>'1;)'1Y<&5=.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%-E<G9E<D%N8VAO<DYE>'0H)'1Y<&4I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<V5R=F5R06YC:&]R3F5X=%LD='EP95T["B`@("!]"@H@
M("`@9G5N8W1I;VX@9V5T4V5R=F5R06YC:&]R3&%S="@D='EP92D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]S97)V97)!;F-H;W),87-T6R1T>7!E
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!L;V<@<VEM<&QY(&-O=6YT
M<R!T:&4@96YT<FEE<R!F;W(@96%C:"!T;W!I8RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&]G*"1T;W!I8RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]L;V=;)'1O<&EC72DI('L*("`@("`@("`@("`@)'1H:7,M/E]L;V=;
M)'1O<&EC72`K/2`Q.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&]G6R1T;W!I8UT@/2`Q.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%1H92!,;V<@:7,@86X@87)R87D@=VAE<F4@=&AE(&ME>2!I
M<R!T:&4@979E;G0@;F%M92!A;F0@=&AE"B`@("`@*B!V86QU92!S87ES(&AO
M=R!O9G1E;B!T:&ES(&5V96YT(&]C8W5R960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$QO9R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&]G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!I9&5N=&EF:65R
M('5S960@=&\@:61E;G1I9GD@=&AE('-Y;F,@9&5V:6-E(&EN('1H90H@("`@
M("H@;6%P+B!#=7)R96YT;'D@(FQO8VYA;64Z<V]U<F-E55))(BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4WEN8TED96YT:69I97(H*0H@("`@>PH@("`@
M("`@(')E='5R;B!S=')?<F5P;&%C92@G.B<L("=?)RP@)'1H:7,M/E]L;V-.
M86UE*0H@("`@("`@("`@("`@("`@+B`G.B<*("`@("`@("`@("`@("`@("X@
M<W1R7W)E<&QA8V4H)SHG+"`G7R<L("1T:&ES+3Y?<V]U<F-E55))*3L*("`@
M('T*"B`@("!F=6YC=&EO;B`F9V5T1&5V:6-E*"D*("`@('L*("`@("`@("!R
M971U<FX@4WEN8TU,7T1E=FEC93HZ<VEN9VQE=&]N*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!E>'!E8W1E9"!R97-U;'0@='EP92!F
M;W(@82!297-U;'1S('1A9RP@=7-E9"!T;R!R961I<F5C="!T:&4*("`@("`J
M(&EN8V]M:6YG(&-O;6UA;F0@<V]M97=H97)E('-P96-I86PN("!&;W(@97AA
M;7!L92P@:68@=V4@:&%V92!R97%U97-T960*("`@("`J(&1E=FEC92!I;F9O
M+"!T:&4@4F5S=6QT<R!T86<@<VAO=6QD(&)E('-E;G0@=&\@=&AE(%!U="!C
M;VUM86YD('-O('=E(&-A;@H@("`@("H@<F5A9"!I="!I;BX*("`@("`J"B`@
M("`@*B!#;&5A<G,@=&AE(&AA<V@@;V8@=&AI<R!#;VUM86YD(%)E9F5R96YC
M92!B969O<F4@<F5T=7)N:6YG(&$@=F%L=64N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-M9%)E9B`@5&AE($-M9%)E9B!O9B!T:&4@:6YC;VUI
M;F<@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&-O;6UA;F0@='EP92!T;R!R961I<F5C="!T;RP@;W(*("`@("`J("`@("`@
M("`@("`@("`@("!U;F1E9FEN960@:68@;F\@<F5D:7)E8W0@<F5G:7-T97)E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T17AP96-T961297-U;'14>7!E
M*"1C;612968I"B`@("!["B`@("`@("`@:68@*"!I<W-E="@D=&AI<RT^7V5X
M<&5C=&5D4F5S=6QT6R1C;612969=*2`I('L*("`@("`@("`@("`@)&-M9%1Y
M<&4@/2`D=&AI<RT^7V5X<&5C=&5D4F5S=6QT6R1C;612969=.PH@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^7V5X<&5C=&5D4F5S=6QT6R1C;612969=*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;614>7!E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!U<"!A(&-O;6UA;F0@<F5D:7)E8W1I;VX@9F]R
M(&$@9G5T=7)E(%)E<W5L="!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C;61)1"`@("!4:&4@0VUD240@;V8@=&AE(&-O;6UA;F0@
M=V4@87)E('-E;F1I;F<@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@8VQI96YT+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-M9%1Y
M<&4@(%1H92!T>7!E(&]F(&-O;6UA;F0@=&\@<F5D:7)E8W0@=&\@=VAE;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!297-U;'1S(&-O
M;6UA;F0@:7,@<F5C96EV960N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$5X
M<&5C=&5D4F5S=6QT5'EP92@D8VUD240L("1C;614>7!E*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?97AP96-T961297-U;'1;)&-M9$E$72`]("1C;614>7!E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@=&AE<F4@87)E(&%N
M>2!P96YD:6YG(&5L96UE;G1S('1H870@:&%V92!N;W0@8F5E;B!S96YT('1O
M(&1U90H@("`@("H@=&\@;65S<V%G92!S:71Z92!R97-T<FEC=&EO;G,N(%1H
M97-E('=I;&P@8F4@<V5N="!I;G0@=&AE(&YE>'0@;7-G+@H@("`@("H*("`@
M("`J+PH@("`@9G5N8W1I;VX@:&%S4&5N9&EN9T5L96UE;G1S*"D*("`@('L*
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?<WEN8W,I*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<WEN8W,@87,@)'-Y;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D<WEN8RT^:&%S4&5N9&EN9T5L96UE;G1S*"DI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!S
M>6YC<R!W:&EC:"!H879E('!E;F1I;F<@96QE;65N=',@;&5F="X*("`@("`J
M(%)E='5R;G,@86X@87)R87D@;V8@5&%R9V5T3&]C55))<R!W:&EC:"!C86X@
M8F4@=7-E9`H@("`@("H@87,@82!K97D@:6X@9V5T4WEN8R!C86QL<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4&5N9&EN9U-Y;F-S*"D*("`@('L*("`@
M("`@("`D<B`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES
M+3Y?<WEN8W,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<WEN
M8W,@87,@)'1A<F=E="`]/B`D<WEN8RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1S>6YC+3YH87-096YD:6YG16QE;65N=',H*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1R6UT@/2`D=&%R9V5T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<CL*("`@('T*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+U-Y;F,N<&AP````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0P-C$U`#$P-#$W,S8R-S<P
M`#`Q-S<V-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y
M;F--3"]3>6YC+G!H<"QV(#$N."XT+C@@,C`P-B\P,2\P,2`R,3HR.#HS-B!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI
M;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y;F--3`H@*B\*
M8VQA<W,@4WEN8TU,7U-Y;F,@>PH*("`@("\J*@H@("`@("H@5&%R9V5T.B!C
M;VYT86-T<RP@;F]T97,L(&-A;&5N9&%R+"!T87-K<RP*("`@("`J+PH@("`@
M=F%R("1?=&%R9V5T3&]C55)).R`O+R!T87)G970@;65A;G,@<V5R=F5R(&AE
M<F4*"B`@("!V87(@)%]S;W5R8V5,;V-54DD[("\O('-O=7)C92!M96%N<R!C
M;&EE;G0@:&5R90H*("`@('9A<B`D7V%L97)T.PH*("`@("\J*@H@("`@("H@
M5')U92!I;F1I8V%T97,@=&AA="!T:&5R92!A<F4@<W1I;&P@<WEN8R!E;&5M
M96YT<R!T:&%T(&AA=F4@;F]T(&)E96X*("`@("`J('-E;G0@>65T(&1U92!T
M;R!M97-S86=E('-I>F4@;&EM:71A=&EO;G,@86YD(&AA=F4@=&\@8F4@<V5N
M="!I;B!T:&4@;F5X=`H@("`@("H@;65S<V%G92X*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<&5N9&EN9T5L96UE;G1S
M.PH*("`@("\J*@H@("`@("H@4F5M96UB97(@96YT<FEE<R!W92!H879E(&AA
M;F1L960@86QR96%D>3H@;VYC92!W92!S96YD(&$@9&5L971E(&9O<B!A;@H@
M("`@("H@96YT<GDL('=E(&1O;B=T('=A;G0@=&\@<V5N9"!A;B!A9&0@869T
M97)W87)D<RX@5&AI<R!A<G)A>2!I<R!A;'-O('5S960*("`@("`J(&EF(&$@
M<WEN8R!I<R!S96YT(&EN(&UU;'1I<&QE(&UE<W-A9V5S(&1U92!T;R!M97-S
M86=E('-I>F4@<F5S=')I8W1I;VYS+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?9&]N93L*"B`@("!F=6YC=&EO;B!3>6YC
M34Q?4WEN8R@D86QE<G0L("1S97)V97)54DDL("1C;&EE;G154DDI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]A;&5R="`]("1A;&5R=#L*("`@("`@("`D=&AI
M<RT^7W!E;F1I;F=%;&5M96YT<R`](&9A;'-E.PH@("`@("`@("1T:&ES+3Y?
M9&]N92`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]T87)G971,;V-54DD@
M/2!B87-E;F%M92@D<V5R=F5R55))*3L*("`@("`@("`D=&AI<RT^7W-O=7)C
M94QO8U5222`]("1C;&EE;G154DD["B`@("`@("`@9VQO8F%L("1B86-K96YD
M.PH@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*")C<F5A=&4@9F]R('-Y
M;F-4>7!E/21S97)V97)54DDB+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@('T*"B`@("`O*BH*("`@("`J($AE<F4G<R!W:&5R
M92!T:&4@86-T=6%L('!R;V-E<W-I;F<@;V8@82!C;&EE;G0M<V5N="!3>6YC
M"B`@("`@*B!)=&5M('1A:V5S('!L86-E+B!%;G1R:65S(&%R92!A9&1E9"P@
M9&5L971E9"!O<B!R97!L86-E9`H@("`@("H@9G)O;2!T:&4@<V5R=F5R(&1A
M=&%B87-E(&)Y('5S:6YG($AO<F1E($%022`H4F5G:7-T<GDI(&-A;&QS+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&53>6YC271E;2@D:71E;2D*("`@
M('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["@H@("`@("`@("1S=&%T92`]
M("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("1D979I8V4@
M/2`F)'-T871E+3YG971$979I8V4H*3L*("`@("`@("`D<WEN8TED96YT:69I
M97(@/2`D<W1A=&4M/F=E=%-Y;F-)9&5N=&EF:65R*"D["@H@("`@("`@("1H
M;W)D951Y<&4@/2`D='EP92`]("1T:&ES+3Y?=&%R9V5T3&]C55)).PH*("`@
M("`@("`O+R!5<V4@8V]N=&5N=%1Y<&4@97AP;&EC:71L>2!S<&5C:69I960@
M:6X@=&AI<R!S>6YC(&-O;6UA;F0N"B`@("`@("`@)&-O;G1E;G14>7!E(#T@
M)&ET96TM/F=E=$-O;G1E;G14>7!E*"D["@H@("`@("`@("\O($EF(&YO="!P
M<F]V:61E9"P@=7-E(&1E9F%U;'0@9G)O;2!D979I8V4@:6YF;RX*("`@("`@
M("!I9B`H(21C;VYT96YT5'EP92D@>PH@("`@("`@("`@("`D8V]N=&5N=%1Y
M<&4@/2`D9&5V:6-E+3YG9710<F5F97)R961#;VYT96YT5'EP92@D='EP92D[
M"B`@("`@("`@?0H*("`@("`@("!L:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y
M<&4I(#T*("`@("`@("`@("`@)&1E=FEC92T^8V]N=F5R=$-L:65N=#)397)V
M97(H)&ET96TM/F=E=$-O;G1E;G0H*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G14>7!E*3L*("`@("`@("`D
M8W5I9"`]("1I=&5M+3YG971#=6ED*"D["B`@("`@("`@)'-U:60@/2!F86QS
M93L*"B`@("`@("`@+R\@2&%N9&QE(&-L:65N="!A9&0@<F5Q=65S=',N"B`@
M("`@("`@:68@*"1I=&5M+3YG971%;&5M96YT5'EP92@I(#T])T%D9"<I('L*
M("`@("`@("`@("`@)'-U:60@/2`D8F%C:V5N9"T^:6UP;W)T16YT<GDH)'-Y
M;F-)9&5N=&EF:65R+"`D:&]R9&54>7!E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@)&-O;G1E;G14>7!E
M+"`D8W5I9"D["B`@("`@("`@("`@(&EF("@A:7-?82@D<W5I9"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'-T871E+3YL;V<H(D-L:65N
M="U!9&0B*3L*("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E
M*"=A9&1E9"!C;&EE;G0@96YT<GD@87,@)R`N("1S=6ED+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<W1A=&4M/FQO9R@B0VQI96YT+4%D9$9A:6QU<F4B*3L*
M("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=%<G)O<B!I
M;B!A9&1I;F<@8VQI96YT(&5N=')Y.B<@+B`D<W5I9"T^;65S<V%G92P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("\O($AA;F1L92!C;&EE;G0@9&5L971E(')E<75E<W1S+@H@
M("`@("`@('T@96QS96EF("@D:71E;2T^9V5T16QE;65N=%1Y<&4H*2`]/2=$
M96QE=&4G*2!["B`@("`@("`@("`@("1S=6ED(#T@)&)A8VME;F0M/F1E;&5T
M945N=')Y*"1S>6YC261E;G1I9FEE<BP@)'1Y<&4L("1C=6ED*3L*("`@("`@
M("`@("`@:68@*"1T>7!E(#T]("=C86QE;F1A<B<*("`@("`@("`@("`@("`@
M("8F("1D979I8V4M/FAA;F1L951A<VMS26Y#86QE;F1A<B@I*2!["B`@("`@
M("`@("`@("`@("`O+R!D96QE=&5%;G1R>2!D;V5S(&YO="!N965D('1O(')E
M='5R;B!A;B!E<G)O<B!O;@H@("`@("`@("`@("`@("`@+R\@9&5L971I;VX@
M;V8@;F]N97AI<W1E;G0@96YT<FEE<RX@4V\@:G5S="!T;R!B92!S=7)E"B`@
M("`@("`@("`@("`@("`O+R!W92!H879E('1O(&1E;&5T92!F<F]M('1H92!T
M87-K<R!D871A8F%S92!A<R!W96QL.@H@("`@("`@("`@("`@("`@)&)A8VME
M;F0M/FQO9TUE<W-A9V4H)W-P96-I86P@=&%S:W,@9&5L971E("<@+B`D<W5I
M9"`N("<@9'5E('1O(&-L:65N="!R97%U97-T)RP@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("`D<W5I9"`]
M("1B86-K96YD+3YD96QE=&5%;G1R>2@D<WEN8TED96YT:69I97(L("=T87-K
M<R<L("1C=6ED*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES
M7V$H)'-U:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1S
M=&%T92T^;&]G*")#;&EE;G0M1&5L971E(BD["B`@("`@("`@("`@("`@("`D
M8F%C:V5N9"T^;&]G365S<V%G92@G9&5L971E9"!E;G1R>2`G("X@)'-U:60@
M+B`G(&1U92!T;R!C;&EE;G0@<F5Q=65S="<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'-T871E+3YL;V<H(D-L:65N="U$96QE=&5&86EL=7)E
M(BD["B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@G1F%I;'5R
M92!D96QE=&EN9R!C;&EE;G0@96YT<GDL(&UA>6)E(&=O;F4@86QR96%D>2!O
M;B!S97)V97(N(&US9SHG+B`D<W5I9"T^;65S<V%G92P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("\O($AA;F1L92!C;&EE;G0@<F5P;&%C92!R97%U97-T<RX*("`@("`@("!]
M(&5L<V5I9B`H)&ET96TM/F=E=$5L96UE;G14>7!E*"D@/3T@)U)E<&QA8V4G
M*2!["B`@("`@("`@("`@("1S=6ED(#T@)&)A8VME;F0M/G)E<&QA8V5%;G1R
M>2@D<WEN8TED96YT:69I97(L("1H;W)D951Y<&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@)&-O;G1E
M;G14>7!E+"`D8W5I9"D["@H@("`@("`@("`@("!I9B`H(6ES7V$H)'-U:60L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1S=&%T92T^;&]G
M*")#;&EE;G0M4F5P;&%C92(I.PH@("`@("`@("`@("`@("`@)&)A8VME;F0M
M/FQO9TUE<W-A9V4H)W)E<&QA8V5D(&5N=')Y("<@+B`D<W5I9"`N("<@9'5E
M('1O(&-L:65N="!R97%U97-T)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@D<W5I9"T^;65S<V%G92P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@D<W5I9"P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`@("`@+R\@
M16YT<GD@;6%Y(&AA=F4@8F5E;B!D96QE=&5D.R!T<GD@861D:6YG(&ET+@H@
M("`@("`@("`@("`@("`@)'-U:60@/2`D8F%C:V5N9"T^:6UP;W)T16YT<GDH
M)'-Y;F-)9&5N=&EF:65R+"`D:&]R9&54>7!E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0L("1C;VYT
M96YT5'EP92P@)&-U:60I.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A*"1S
M=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@)'-T
M871E+3YL;V<H(D-L:65N="U!9&1297!L86-E(BD["B`@("`@("`@("`@("`@
M("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)V%D9&5D(&-L:65N="!E;G1R
M>2!D=64@=&\@<F5P;&%C92!R97%U97-T(&%S("<@+B`D<W5I9"P@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*")#
M;&EE;G0M061D1F%I;'5R92(I.PH@("`@("`@("`@("`@("`@("`@("1B86-K
M96YD+3YL;V=-97-S86=E*"=%<G)O<B!I;B!A9&1I;F<@8VQI96YT(&5N=')Y
M(&1U92!T;R!R97!L86-E(')E<75E<W0Z)R`N("1S=6ED+3YM97-S86=E+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G56YE>'!E8W1E9"!E;&5M96YT
M5'EP93H@)R`N("1I=&5M+3YG971%;&5M96YT5'EP92@I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-U:60[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@)FQT.U-Y;F,F9W0[
M(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4WEN8T]U='!U
M="@D8W5R<F5N=$-M9$E$+"`F)&]U='!U="D*("`@('L*("`@("`@("`D<W1A
M=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*("`@("`@("`D871T
M<G,@/2!A<G)A>2@I.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)U-Y;F,G+"`D871T<G,I.PH@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G
M+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-U<G)E
M;G1#;61)1"D["B`@("`@("`@)&-U<G)E;G1#;61)1"LK.PH@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9$E$)RD[
M"@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G5&%R9V5T)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A='1R<RD[
M"B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D=&AI<RT^7W-O=7)C94QO
M8U5222D["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G3&]C55)))RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G5&%R9V5T)RD["@H@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E)RP@
M)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@)&]U='!U
M="T^8VAA<F%C=&5R<R@D=&AI<RT^7W1A<F=E=$QO8U5222D["B`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55))
M)RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G4V]U<F-E)RD["@H@("`@("`@("1S>6YC5'EP92`]("1T:&ES+3Y?
M=&%R9V5T3&]C55)).PH*("`@("`@("!G;&]B86P@)&)A8VME;F0["B`@("`@
M("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H(FAA;F1L95-Y;F,@9F]R('-Y;F-4
M>7!E/21S>6YC5'EP92(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`O+R!(97)E)W,@=VAE<F4@<V5R=F5R(&UO9&EF
M:6-A=&EO;G,@87)E('-E;G0@=&\@=&AE(&-L:65N=#H*("`@("`@("`D<F5F
M=',@/2`D<W1A=&4M/F=E=%-E<G9E<D%N8VAO<DQA<W0H)'-Y;F-4>7!E*3L*
M("`@("`@("`D8W5R<F5N=$-M9$E$(#T@)'1H:7,M/FAA;F1L95-Y;F,H)&-U
M<G)E;G1#;61)1"P@)'-Y;F-4>7!E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T+"`D<F5F=',I.PH*("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3>6YC
M)RD["@H@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5N9',@<V5R=F5R(&-H86YG97,@=&\@=&AE(&-L:65N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE4WEN8R@D8W5R<F5N=$-M
M9$E$+"`D<WEN8U1Y<&4L("8D;W5T<'5T+"`D<F5F=',L("1E;F1?=',@/2`P
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*("`@("`@("!G;&]B
M86P@)&UE<W-A9V5&=6QL.PH*("`@("`@("`O*B`D;65S<V%G949U;&P@=VEL
M;"!B92!S970@=&\@=')U92!T;R!I;F1I8V%T92!T:&%T('1H97)E)W,@;F\@
M<F]O;0H@("`@("`@("`J(&9O<B!O=&AE<B!D871A(&EN('1H:7,@;65S<V%G
M92X@268@:70G<R!F86QS92`H96UP='DI(&%N9"!T:&5R90H@("`@("`@("`J
M(&%R92!P96YD:6YG(%-Y;F,@9&%T82P@=&AE(&9I;F%L(&-O;6UA;F0@=VEL
M;"!S96YT('1H92!P96YD:6YG(&1A=&$N"B`@("`@("`@("H@5&AI<R!G;&]B
M86P@9&%T82!S:&]U;&0@8F4@;6]V960@=&\@82!G;&]B86P@;V)J96-T+"!T
M;V=E=&AE<@H@("`@("`@("`J('=I=&@@8W5R<F5N=$-M9$E$(&%N9"`D;W5T
M<'5T+B`J+PH@("`@("`@("1M97-S86=E1G5L;"`](&9A;'-E.PH*("`@("`@
M("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*("`@("`@
M("`D9&5V:6-E(#T@)B1S=&%T92T^9V5T1&5V:6-E*"D["B`@("`@("`@)'-Y
M;F-)9&5N=&EF:65R(#T@)'-T871E+3YG9713>6YC261E;G1I9FEE<B@I.PH@
M("`@("`@("1C;VYT96YT5'EP92`]("1D979I8V4M/F=E=%!R969E<G)E9$-O
M;G1E;G14>7!E0VQI96YT*"1S>6YC5'EP92D["@H@("`@("`@("\J(%=E(&9A
M:71H9G5L;'D@97AP96-T('1O(&1E86P@=VET:"!A;&P@<F5M86EN:6YG(&5L
M96UE;G1S+B!7:6QL(&)E"B`@("`@("`@("H@<V5T('1O('1R=64@:68@=V4@
M<G5N(&]U="!O9B!S<&%C92!F;W(@;65S<V%G92!C<F5A=&EO;BX@*B\*("`@
M("`@("`D=&AI<RT^<V5T4&5N9&EN9T5L96UE;G1S*&9A;'-E*3L*"B`@("`@
M("`@+R\@2&%N9&QE(&1E;&5T:6]N<RX*("`@("`@("`D9&5L971I;VYS(#T@
M)&)A8VME;F0M/F=E=%-E<G9E<D1E;&5T:6]N<R@D<WEN8TED96YT:69I97(L
M("1S>6YC5'EP92P@)')E9G1S+"`D96YD7W1S*3L*"B`@("`@("`@:68@*"1R
M969T<R`^(#`I('L*("`@("`@("`@("`@+R\@1&]N)W0@<V5N9"!D96QE=&5S
M(&]N(%-L;W=3>6YC+@H@("`@("`@("`@("!F;W)E86-H("@D9&5L971I;VYS
M(&%S("1S=6ED(#T^("1C=6ED*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1O;F5;)'-U:61=(#T@=')U93L*("`@("`@("`@("`@("`@("1B86-K96YD
M+3YL;V=-97-S86=E*")D96QE=&4Z(&-U:60])&-U:60@<W5I9#TD<W5I9"!R
M969T<SH@)')E9G1S(BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@("`@("`@("`O+R!#<F5A=&4@82!$96QE=&4@<F5Q
M=65S="!F;W(@8VQI96YT+@H@("`@("`@("`@("`@("`@)&-U<G)E;G1#;61)
M1"`]("1T:&ES+3YO=71P=71#;VUM86YD*"1C=7)R96YT0VUD240L("1O=71P
M=70L("=$96QE=&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL("1C=6ED+"!N=6QL
M*3L*("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*"=397)V97(M1&5L971E
M)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@2&%N9&QE
M(&%D9&ET:6]N<RX*("`@("`@("`D861D<R`]("1B86-K96YD+3YG971397)V
M97)!9&1I=&EO;G,H)'-Y;F-)9&5N=&EF:65R+"`D<WEN8U1Y<&4L("1R969T
M<RP@)&5N9%]T<RD["B`@("`@("`@9F]R96%C:"`H)&%D9',@87,@)'-U:60@
M/3X@)&-U:60I('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V1O
M;F5;)'-U:61=*2D@>PH@("`@("`@("`@("`@("`@+R\@06QR96%D>2!S96YT
M(&1E;&5T92P@;F\@;F5E9"!T;R!A9&0N"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8F%C:V5N9"T^;&]G
M365S<V%G92@B861D.B`D<W5I9"(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@)&,@/2`D8F%C:V5N9"T^<F5T
M<FEE=F5%;G1R>2@D<WEN8U1Y<&4L("1S=6ED+"`D8V]N=&5N=%1Y<&4I.PH@
M("`@("`@("`@("!I9B`H(6ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("\O($ET96T@:6X@:&ES=&]R>2!B=70@;F]T(&EN(&1A
M=&%B87-E+B!3=')A;F=E+"!B=70@8V%N(&AA<'!E;BX*("`@("`@("`@("`@
M("`@(&QI<W0H)&-L:65N=$-O;G1E;G0L("1C;&EE;G1#;VYT96YT5'EP92D@
M/0H@("`@("`@("`@("`@("`@("`@("1D979I8V4M/F-O;G9E<G1397)V97(R
M0VQI96YT*"1C+"`D8V]N=&5N=%1Y<&4I.PH@("`@("`@("`@("`@("`@+R\@
M0VAE8VL@:68@=V4@:&%V92!S<&%C92!L969T(&EN('1H92!M97-S86=E+@H@
M("`@("`@("`@("`@("`@:68@*"@D<W1A=&4M/F=E=$UA>$US9U-I>F4H*0H@
M("`@("`@("`@("`@("`@("`@("T@)&]U='!U="T^9V5T3W5T<'5T4VEZ92@I
M"B`@("`@("`@("`@("`@("`@("`@+2!S=')L96XH)&-L:65N=$-O;G1E;G0I
M*2`\(#4P*2!["B`@("`@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE
M<W-A9V4H)VUA>"!M97-S86=E('-I>F4@<F5A8VAE9"!C=7)S:7IE/2<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1O=71P
M=70M/F=E=$]U='!U=%-I>F4H*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G949U;&P@/2!T
M<G5E.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971096YD:6YG16QE
M;65N=',H=')U92D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1C=7)R
M96YT0VUD240["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1O;F5;)'-U:61=(#T@=')U93L*("`@("`@("`@("`@("`@("1C
M=7)R96YT0VUD240@/2`D=&AI<RT^;W5T<'5T0V]M;6%N9"@D8W5R<F5N=$-M
M9$E$+"`D;W5T<'5T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=!9&0G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&EE;G1#
M;VYT96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;&EE;G1#;VYT96YT5'EP92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S=6ED*3L*("`@("`@("`@("`@("`@("1S=&%T92T^
M;&]G*"=397)V97(M061D)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G87!I(&5X<&]R="!C
M86QL(&9O<B`G("X@)'-U:60@+B`G(&9A:6QE9#H@("<@+B`D8RT^9V5T365S
M<V%G92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O($AA;F1L92!C:&%N9V5S+@H@
M("`@("`@(&EF("@D<F5F=',@(3T@,"D@>PH@("`@("`@("`@("`O+R!$;VXG
M="!S96YD(&-H86YG97,@9F]R(%-L;W=3>6YC+"!C;VYF=7-E<R!S;VUE(&-L
M:65N=',N"B`@("`@("`@("`@("1E;F1?=',@/2!T:6UE*"D["B`@("`@("`@
M("`@("1C:&%N9V5S(#T@)&)A8VME;F0M/F=E=%-E<G9E<DUO9&EF:6-A=&EO
M;G,H)'-Y;F-)9&5N=&EF:65R+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S>6YC5'EP92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5F=',L("1E;F1?=',I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D8VAA;F=E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M)&)A8VME;F0M/FQO9TUE<W-A9V4H)&-H86YG97,L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R;B`D
M8VAA;F=E<SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H
M)&-H86YG97,@87,@)'-U:60@/3X@)&-U:60I('L*("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]D;VYE6R1S=6ED72DI('L*("`@("`@("`@
M("`@("`@("`@("`O+R!!;')E861Y('-E;G0@9&5L971E(&]R(&%D9"P@;F\@
M;F5E9"!T;R!M;V1I9GDN"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"$D8W5I
M9"D@>PH@("`@("`@("`@("`@("`@("`@("\O(%1/1$\Z(&-R96%T92!A;B`B
M861D(B!H97)E(&EN<W1E860_"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&,@/2`D
M8F%C:V5N9"T^<F5T<FEE=F5%;G1R>2@D<WEN8U1Y<&4L("1S=6ED+"`D8V]N
M=&5N=%1Y<&4I.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A*"1C+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO
M9TUE<W-A9V4H(F-H86YG93H@)'-U:60B+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)&-L:65N
M=$-O;G1E;G0L("1C;&EE;G1#;VYT96YT5'EP92D@/0H@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5V:6-E+3YC;VYV97)T4V5R=F5R,D-L:65N="@D8RP@
M)&-O;G1E;G14>7!E*3L*("`@("`@("`@("`@("`@("`@("`O+R!#:&5C:R!I
M9B!W92!H879E('-P86-E(&QE9G0@:6X@=&AE(&UE<W-A9V4N"B`@("`@("`@
M("`@("`@("`@("`@:68@*"@D<W1A=&4M/F=E=$UA>$US9U-I>F4H*0H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2`D;W5T<'5T+3YG971/=71P=713:7IE
M*"D*("`@("`@("`@("`@("`@("`@("`@("`@("T@<W1R;&5N*"1C;&EE;G1#
M;VYT96YT*2D@/"`U,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8F%C
M:V5N9"T^;&]G365S<V%G92@G;6%X(&UE<W-A9V4@<VEZ92!R96%C:&5D(&-U
M<G-I>F4])PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("1O=71P=70M/F=E=$]U='!U=%-I>F4H*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("`@
M("`@("`@("1M97-S86=E1G5L;"`]('1R=64["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971096YD:6YG16QE;65N=',H=')U92D["B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1O;F5;)'-U:61=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`D8W5R
M<F5N=$-M9$E$(#T@)'1H:7,M/F]U='!U=$-O;6UA;F0H)&-U<G)E;G1#;61)
M1"P@)&]U='!U="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)U)E<&QA8V4G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8VQI96YT0V]N=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L:65N=$-O;G1E;G14
M>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8W5I9"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"D["B`@
M("`@("`@("`@("`@("`@("`@)'-T871E+3YL;V<H)U-E<G9E<BU297!L86-E
M)RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("\O($ET96T@:6X@:&ES=&]R>2!B=70@;F]T(&EN(&1A=&%B87-E+B!3
M=')A;F=E+"!B=70*("`@("`@("`@("`@("`@("`@("`O+R!C86X@:&%P<&5N
M+@H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!)9B!T87-K<R!A<F4@:&%N9&QE9"!I;G-I9&4@8V%L96YD
M87(L(&1O('1H92!S86UE(&%G86EN(&9O<@H@("`@("`@("\O('1A<VMS+@H@
M("`@("`@(&EF("@D<WEN8U1Y<&4@/3T@)V-A;&5N9&%R)R`F)B`D9&5V:6-E
M+3YH86YD;&5487-K<TEN0V%L96YD87(H*2D@>PH@("`@("`@("`@("`D8F%C
M:V5N9"T^;&]G365S<V%G92@B:&%N9&QI;F<@=&%S:W,@:6X@8V%L96YD87(@
M<WEN8R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@
M)&-U<G)E;G1#;61)1"`]("1T:&ES+3YH86YD;&53>6YC*"1C=7)R96YT0VUD
M240L("=T87-K<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;W5T<'5T+"`D<F5F=',L("1E;F1?=',I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!/=71P=70@82!S:6YG;&4@4WEN8R!C;VUM86YD("A!
M9&0L($1E;&5T92P@4F5P;&%C92DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U
M='!U=$-O;6UA;F0H)&-U<G)E;G1#;61)1"P@)B1O=71P=70L("1C;VUM86YD
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@)&-O;G1E
M;G14>7!E(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-U
M:60@/2!N=6QL+"`D<W5I9"`](&YU;&PI"B`@("!["B`@("`@("`@)'-T871E
M(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("1A='1R
M<R`](&%R<F%Y*"D["B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("1C;VUM86YD+"`D871T<G,I.PH*("`@("`@("`D
M;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9$E$
M)RP@)&%T=')S*3L*("`@("`@("`D8VAA<G,@/2`D8W5R<F5N=$-M9$E$.PH@
M("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<I
M.PH*("`@("`@("!I9B`H:7-S970H)&-O;G1E;G14>7!E*2D@>PH@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)TUE=&$G+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)'-T871E+3YG97154DE-971A*"DL("=4>7!E)RP@)&%T=')S*3L*
M("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8V]N=&5N=%1Y<&4I
M.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))365T82@I+"`G5'EP92<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-971A)RD["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-S970H)&-O;G1E;G0I"B`@("`@("`@("`@('Q\(&ES
M<V5T*"1C=6ED*2!\?"!I<W-E="@D<W5I9"DI('L*("`@("`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RP@
M)&%T=')S*3L*("`@("`@("`@("`@:68@*"1S=6ED("$](&YU;&PI('L*("`@
M("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G4V]U<F-E)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55))
M)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E
M<G,H)'-U:60I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RD["B`@("`@("`@("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3;W5R
M8V4G*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1C=6ED("$]
M(&YU;&PI('L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G5&%R9V5T)RP@)&%T=')S*3L*("`@("`@
M("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G3&]C55)))RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&-U:60I.PH@("`@("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RD["B`@
M("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=487)G970G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H:7-S970H)&-O;G1E;G0I*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G+"`D871T
M<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8V]N
M=&5N="D["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=$871A)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G
M271E;2<I.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`D8V]M;6%N9"D["@H@("`@("`@("1C=7)R
M96YT0VUD240K*SL*"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@
M("!]"@H@("`@9G5N8W1I;VX@<V5T4&5N9&EN9T5L96UE;G1S*"1E*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?<&5N9&EN9T5L96UE;G1S(#T@)&4["B`@("!]
M"@H@("`@9G5N8W1I;VX@:&%S4&5N9&EN9T5L96UE;G1S*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]P96YD:6YG16QE;65N=',["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]3>6YC34PO0F%C:V5N9"YP:'``````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-38V-3(`,3`T,3<S-C(W-S``,#(P-#$Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!3>6YC34P@0F%C:V5N9"!F;W(@=&AE($AO<F1E($%P<&QI
M8V%T:6]N(&9R86UE=V]R:RX*("H*("H@5&AE(&)A8VME;F0@<')O=FED97,@
M=&AE(&9O;&QO=VEN9R!F=6YC=&EO;F%L:71Y.@H@*@H@*B`Q*2!H86YD;&EN
M9R!O9B!T:&4@86-T=6%L(&1A=&$L(&DN92X*("H@("`@82D@861D+W)E<&QA
M8V4O9&5L971E(&5N=')I97,@=&\@86YD(')E=')I979E(&5N=')I97,@9G)O
M;2!T:&4*("H@("`@("`@8F%C:V5N9`H@*B`@("!B*2!R971R:65V92!H:7-T
M;W)Y('1O(&9I;F0@;W5T('=H870@96YT<FEE<R!H879E(&)E96X@8VAA;F=E
M9`H@*B`R*2!M86YA9VEN9R!O9B!T:&4@;6%P(&)E='=E96X@8VQI96YD($E$
M<R!A;F0@<V5R=F5R($E$<PH@*B`S*2!S=&]R92!I;F9O<FUA=&EO;B!A8F]U
M="!S>6YC(&%N8VAO<G,@*'1I;65S=&%M<',I(&]F('!R979I;W5S"B`J("`@
M('-U8V-E<W-F=6QS('-Y;F,@<V5S<VEO;G,*("H@-"D@<V5S<VEO;B!H86YD
M;&EN9R`H;F]T('EE="P@<W1I;&P@=&\@8F4@9&]N92D*("H@-2D@875T:&]R
M:7-A=&EO;B`H;F]T('EE="P@<W1I;&P@=&\@8F4@9&]N92D*("H@-BD@;&]G
M9VEN9PH@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO
M;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]"86-K96YD+G!H<"QV(#$N
M."XR+C4@,C`P-B\P,R\P-B`Q-#HP,CHU,R!J86X@17AP("0*("H*("H@0&%U
M=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J
M($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T)A8VME;F1?2&]R
M9&4@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@87,@=F%L=64@:6YD:6-A
M=&5S('1H870@9F]R('1H:7,@8VQI96YT(&-A=&5G;W)Y(&YO"B`@("`@*B!S
M97)V97(@8V%T96=O<GD@:7,@9&5F:6YE9"!Y970N(%1H92!A<G)A>2!C;VYT
M96YT(&ES('1H90H@("`@("H@<W5M;6%R>2!T97AT(&]F('1H92!L87-T(&5N
M8V]U;G1E<F5D(&-L:65N="!E;G1R>2!T:&%T('5S960*("`@("`J('1H:7,@
M8V%T96=O<GDN"B`@("`@*@H@("`@("H@("!K97DZ("`@8VQI96YT0V%T96=O
M<GD*("`@("`J("`@=F%L=64Z('-E<G9E<D-A=&5G;W)Y"B`@("`@*B\*("`@
M('9A<B`D7V-A=&5G;W)I97--87`["@H@("`@+RHJ"B`@("`@*B!397)V97(@
M8V%T96=O<FEE<R!M:7-S:6YG(&]N('1H92!C;&EE;G0N"B`@("`@*@H@("`@
M("H@("!K97DZ("`@<V5R=F5R0V%T96=O<GD*("`@("`J("`@=F%L=64Z('-U
M;6UA<GD@;V8@;&%S="!E;G1R>2!W:71H('1H:7,@8V%T96=O<GD*("`@("`J
M+PH@("`@=F%R("1?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,["@H@("`@=F%R
M("1?9&%T871R964["@H@("`@9G5N8W1I;VX@4WEN8TU,7T)A8VME;F1?2&]R
M9&4H*0H@("`@>PH@("`@("`@("1D<FEV97(@/2`D1TQ/0D%,4ULG8V]N9B==
M6R=D871A=')E92==6R=D<FEV97(G73L*("`@("`@("`D<&%R86US(#T@2&]R
M9&4Z.F=E=$1R:79E<D-O;F9I9R@G9&%T871R964G+"`D9')I=F5R*3L*("`@
M("`@("`D<&%R86US(#T@87)R87E?;65R9V4H)'!A<F%M<RP@87)R87DH)V=R
M;W5P)R`]/B`G<WEN8VUL)RDI.PH*("`@("`@("`D=&AI<RT^7V1A=&%T<F5E
M(#TF($1A=&%4<F5E.CIS:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@86X@96YT<GD@9G)O;2!T
M:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A
M8F%S92`@($1A=&%B87-E('1O('-C86XN(&DN92X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V%L96YD87(O=&%S:W,O8V]N=&%C=',O;F]T
M97,*("`@("`J($!P87)A;2!S=')I;F<@)'-U:60@("`@("`@4V5R=F5R('5N
M:7%U92!I9"!O9B!T:&4@96YT<GDZ(&9O<B!H;W)D90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&ES(&ES('1H92!G=6ED+@H@("`@("H@
M0'!A<F%M('-T<FEN9R!C;VYT96YT5'EP92!#;VYT96YT+51Y<&4Z('1H92!M
M:6UE('1Y<&4@:6X@=VAI8V@@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9U;F-T:6]N('-H86QL(')E='5R;B!T:&4@9&%T80H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@("`@("`@("`@("`@02!S=')I;F<@
M=VET:"!T:&4@9&%T82!E;G1R>2!O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!O<B!A(%!%05)?17)R;W(@;V)J96-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R971R:65V945N=')Y*"1D871A8F%S92P@)'-U:60L("1C
M;VYT96YT5'EP92D*("`@('L*("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F-A;&PH)&1A=&%B87-E("X@)R]E>'!O<G0G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9W5I
M9"<@/3X@)'-U:60L("=C;VYT96YT5'EP92<@/3X@)&-O;G1E;G14>7!E*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@96YT<FEE<R!T:&%T(&AA=F4@
M8F5E;B!M;V1I9FEE9"!I;B!T:&4@<V5R=F5R(&1A=&%B87-E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'-Y;F-)9&5N=&EF:65R("!)9&5N=&EF
M:65S('1H92!C;&EE;G0@9&5V:6-E('1O(&%L;&]W('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('5S97(@=&\@<WEN8R!W:71H
M(&1I9F9E<F5N="!D979I8V5S+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($YO<FUA;&QY('1H92!3;W5R8V554DD@9G)O;2!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!3>6YC2&5A
M9&5R"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A8F%S92`@("`@("`@1&%T
M86)A<V4@=&\@<V-A;BX@:2YE+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-A;&5N9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;5]T<R`@("`@("`@4W1A<G0@=&EM
M97-T86UP+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'1O7W1S("`@("`@("`@
M($5X8VQU<VEV92!E;F0@=&EM97-T86UP+B!.;W0@>65T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&5M96YT960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@4$5!4E]%<G)O<B!O<B!A<W-O8R!A
M<G)A>2!O9B!C:&%N9V5S('=I=&@@:V5Y/7-U:60L"B`@("`@*B`@("`@("`@
M("`@("`@("!V86QU93UC=6ED+B!)9B!N;R!C=6ED(&-A;B!B92!F;W5N9"!F
M;W(@82!S=6ED+"!V86QU92!I<PH@("`@("H@("`@("`@("`@("`@("`@;G5L
M;"X@5&AE;B!A(%-Y;F,@061D(&-O;6UA;F0@:&%S('1O(&)E(&-R96%T960@
M=&\@861D"B`@("`@*B`@("`@("`@("`@("`@("!T:&ES(&5N=')Y(&EN('1H
M92!C;&EE;G0@9&%T86)A<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E
M<G9E<DUO9&EF:6-A=&EO;G,H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L
M("1F<F]M7W1S+"`D=&]?=',I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*"B`@("`@("`@:68@*"1F<F]M7W1S(#T](#`I('L*("`@("`@("`@
M("`@+R\@0V]M<&QE=&4@<WEN8SH@979E<GET:&EN9R!I<R!S96YT(&1U<FEN
M9PH@("`@("`@("`@("`O+R!G971397)V97)!9&1I=&EO;G,N($YO(&YE960@
M=&\@<V5N9"!M;V1I9FEC871I;VYS+@H@("`@("`@("`@("!R971U<FX@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@("\O($=E="!C:&%N9V5S+@H@("`@
M("`@("1C:&%N9V5S(#T@)')E9VES=')Y+3YC86QL*"1D871A8F%S92X@)R]L
M:7-T0GDG+"!A<G)A>2@G86-T:6]N)R`]/B`G;6]D:69Y)RP@)W1I;65S=&%M
M<"<@/3X@)&9R;VU?=',I*3L*("`@("`@("!I9B`H:7-?82@D8VAA;F=E<RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G
M92@B4WEN8TU,.B`D9&%T86)A<V4O;&ES=$)Y(&9A:6QE9"!F;W(@;6]D:69Y
M.B(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D8VAA;F=E<RT^
M9V5T365S<V%G92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1R(#T@
M87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)&-H86YG97,@87,@)'-U:60I
M('L*("`@("`@("`@("`@)'-U:61?=',@/2`D<F5G:7-T<GDM/F-A;&PH)&1A
M=&%B87-E("X@)R]G971!8W1I;VY4:6UE<W1A;7`G+"!A<G)A>2@D<W5I9"P@
M)VUO9&EF>2<I*3L*("`@("`@("`@("`@)'-Y;F-?=',@/2`D=&AI<RT^9V5T
M0VAA;F=E5%,H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1S=6ED*3L*
M("`@("`@("`@("`@:68@*"1S>6YC7W1S("8F("1S>6YC7W1S(#X]("1S=6ED
M7W1S*2!["B`@("`@("`@("`@("`@("`O+R!#:&%N9V4@=V%S(&1O;F4@8GD@
M=7,@=7!O;B!R97%U97-T(&]F(&-L:65N="X*("`@("`@("`@("`@("`@("\O
M($1O;B=T(&UI<G)O<B!T:&%T(&)A8VL@=&\@=&AE(&-L:65N="X*("`@("`@
M("`@("`@("`@("1T:&ES+3YL;V=-97-S86=E*")C:&%N9V4Z("1S=6ED(&EG
M;F]R960L(&-A;64@9G)O;2!C;&EE;G0B+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1C=6ED(#T@)'1H:7,M/F=E=$-U
M:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1S=6ED*3L*("`@("`@
M("`@("`@:68@*"$D8W5I9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9TUE<W-A9V4H(E5N86)L92!T;R!C<F5A=&4@8VAA;F=E(&9O<B`D<W5I9#H@
M8VQI96YT+6ED(&YO="!F;W5N9"!I;B!M87`N(%1R>6EN9R!A9&0@:6YS=&5A
M9"XB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]705).24Y'*3L*("`@("`@("`@("`@
M("`@("1R6R1S=6ED72`](&YU;&P["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<ELD<W5I9%T@/2`D8W5I9#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T(&5N=')I97,@=&AA="!H879E(&)E96X@9&5L971E9"!F
M<F]M('1H92!S97)V97(@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&%T86)A<V4@($1A=&%B87-E('1O('-C86XN(&DN92X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T87-K<R]C
M;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M(&EN=&5G97(@)&9R;VU?=',*
M("`@("`J($!P87)A;2!I;G1E9V5R("1T;U]T<R`@("!%>&-L=7-I=F4*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!014%27T5R<F]R(&]R(&%S<V]C
M(&%R<F%Y(&]F(&1E;&5T:6]N<R!W:71H(&ME>3US=6ED+`H@("`@("H@("`@
M("`@("`@("`@("`@=F%L=64]8W5I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4V5R=F5R1&5L971I;VYS*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E
M+"`D9G)O;5]T<RP@)'1O7W1S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G
M:7-T<GD["@H@("`@("`@(&EF("@D9G)O;5]T<R`]/2`P*2!["B`@("`@("`@
M("`@("\O($-O;7!L971E('-Y;F,Z(&5V97)Y=&AI;F<@:7,@<V5N="!D=7)I
M;F<*("`@("`@("`@("`@+R\@9V5T4V5R=F5R061D:71I;VYS+B`@3F\@;F5E
M9"!T;R!S96YD(&1E;&5T:6]N<RX*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"D["B`@("`@("`@?0H*("`@("`@("`O+R!'970@9&5L971I;VYS+@H@("`@
M("`@("1D96QE=&5S(#T@)')E9VES=')Y+3YC86QL*"1D871A8F%S92X@)R]L
M:7-T0GDG+"!A<G)A>2@G86-T:6]N)R`]/B`G9&5L971E)RP@)W1I;65S=&%M
M<"<@/3X@)&9R;VU?=',I*3L*"B`@("`@("`@:68@*&ES7V$H)&1E;&5T97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A
M9V4H(E-Y;F--3#H@)&1A=&%B87-E+VQI<W1">2!F86EL960@9F]R(&1E;&5T
M93HB"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)&1E;&5T97,M
M/F=E=$UE<W-A9V4H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]705).24Y'*3L*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<B`]
M(&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1D96QE=&5S(&%S("1S=6ED
M*2!["B`@("`@("`@("`@("1S=6ED7W1S(#T@)')E9VES=')Y+3YC86QL*"1D
M871A8F%S92X@)R]G971!8W1I;VY4:6UE<W1A;7`G+"!A<G)A>2@D<W5I9"P@
M)V1E;&5T92<I*3L*("`@("`@("`@("`@)'-Y;F-?=',@/2`D=&AI<RT^9V5T
M0VAA;F=E5%,H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1S=6ED*3L*
M("`@("`@("`@("`@:68@*"1S>6YC7W1S("8F("1S>6YC7W1S(#X]("1S=6ED
M7W1S*2!["B`@("`@("`@("`@("`@("`O+R!#:&%N9V4@=V%S(&1O;F4@8GD@
M=7,@=7!O;B!R97%U97-T(&]F(&-L:65N="X*("`@("`@("`@("`@("`@("\O
M($1O;B=T(&UI<G)O<B!T:&%T(&)A8VL@=&\@=&AE(&-L:65N="X*("`@("`@
M("`@("`@("`@("1T:&ES+3YL;V=-97-S86=E*")3>6YC34PZ(&1E;&5T92`D
M<W5I9"!I9VYO<F5D+"!C86UE(&9R;VT@8VQI96YT(BP@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8W5I9"`]("1T:&ES
M+3YG971#=6ED*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D<W5I9"D[
M"B`@("`@("`@("`@(&EF("@A)&-U:60I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V=-97-S86=E*")5;F%B;&4@=&\@8W)E871E(&1E;&5T92!F;W(@
M)'-U:60Z(&QO8VED(&YO="!F;W5N9"!I;B!M87`B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]705).24Y'*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<ELD<W5I9%T@/2`D8W5I9#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<CL*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!E;G1R:65S('1H870@:&%V92!B965N(&%D9&5D('1O('1H92!S
M97)V97(@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&%T86)A<V4@($1A=&%B87-E('1O('-C86XN(&DN92X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T87-K<R]C;VYT86-T<R]N
M;W1E<PH@("`@("H@0'!A<F%M(&EN=&5G97(@)&9R;VU?=',*("`@("`J($!P
M87)A;2!I;G1E9V5R("1T;U]T<R`@("!%>&-L=7-I=F4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!014%27T5R<F]R(&]R(&%S<V]C(&%R<F%Y(&]F
M(&1E;&5T:6]N<R!W:71H(&ME>3US=6ED+`H@("`@("H@("`@("`@("`@("`@
M("`@=F%L=64],"X@*&%R<F%Y('-T>6QE(&ES(&-H;W-E;B!T;R!M871C:"!C
M:&%N9V4@)B!D96PI"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<G9E<D%D
M9&ET:6]N<R@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&9R;VU?=',L
M("1T;U]T<RD*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@
M("`@("!I9B`H)&9R;VU?=',@/3T@,"D@>PH@("`@("`@("`@("`O+R!2971U
M<FX@86QL(&1B(&5N=')I97,@9&ER96-T;'D@<F%T:&5R('1H86X@8F]T:&5R
M"B`@("`@("`@("`@("\O(&AI<W1O<GDZ"B`@("`@("`@("`@("1A9&1S(#T@
M)')E9VES=')Y+3YC86QL*"1D871A8F%S92X@)R]L:7-T)RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&%D9',@/2`D<F5G:7-T<GDM/F-A;&PH
M)&1A=&%B87-E+B`G+VQI<W1">2<L(&%R<F%Y*"=A8W1I;VXG(#T^("=A9&0G
M+"`G=&EM97-T86UP)R`]/B`D9G)O;5]T<RDI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES7V$H)&%D9',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)'1H:7,M/FQO9TUE<W-A9V4H(E-Y;F--3#H@)&1A=&%B87-E+VQI<W1"
M>2!F86EL960@9F]R(&%D9#HB"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@)&%D9',M/F=E=$UE<W-A9V4H*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]705).
M24Y'*3L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^;&]G365S<V%G92@G861D(&UO9&EF:6-A=&EO;G,@
M<F5T<FEE=F5D+B!C;W5N=#TG"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B!C;W5N="@D861D<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R
M(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)&%D9',@87,@)'-U:60I
M('L*("`@("`@("`@("`@)'-U:61?=',@/2`D<F5G:7-T<GDM/F-A;&PH)&1A
M=&%B87-E("X@)R]G971!8W1I;VY4:6UE<W1A;7`G+"!A<G)A>2@D<W5I9"P@
M)V%D9"<I*3L*("`@("`@("`@("`@)'-Y;F-?=',@/2`D=&AI<RT^9V5T0VAA
M;F=E5%,H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1S=6ED*3L*("`@
M("`@("`@("`@:68@*"1S>6YC7W1S("8F("1S>6YC7W1S(#X]("1S=6ED7W1S
M*2!["B`@("`@("`@("`@("`@("`O+R!#:&%N9V4@=V%S(&1O;F4@8GD@=7,@
M=7!O;B!R97%U97-T(&]F(&-L:65N="X*("`@("`@("`@("`@("`@("\O($1O
M;B=T(&UI<G)O<B!T:&%T(&)A8VL@=&\@=&AE(&-L:65N="X*("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V=-97-S86=E*")A9&0Z("1S=6ED(&EG;F]R960L
M(&-A;64@9G)O;2!C;&EE;G0B+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D8W5I9"`]("1T:&ES+3YG971#=6ED*"1S
M>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D<W5I9"D["@H@("`@("`@("`@
M("!I9B`H)&-U:60@)B8@)&9R;VU?=',@/3T@,"D@>PH@("`@("`@("`@("`@
M("`@+R\@1F]R('-L;W<@<WEN8R`H=',@/2`P*2P@9&\@;F]T(&%D9"!D871A
M(&9O<B!W:&EC:`H@("`@("`@("`@("`@("`@+R\@=V4@:&%V92!A(&QO8VED
M(&%G86EN+B!4:&ES(&ES(&$@:&5U<FES=&EC('1O"B`@("`@("`@("`@("`@
M("`O+R!A=F]I9"!D=7!L:6-A=&EO;B!O9B!E;G1R:65S+@H@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(G-K:7!P:6YG(&%D9"!O9B!G=6ED
M("1S=6ED(&%S('1H97)E(&%L<F5A9'D@:7,@82!C=6ED("1C=6ED(BP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<ELD
M<W5I9%T@/2`P.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D<R!A;B!E;G1R>2!I;G1O('1H92!S97)V
M97(@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T
M86)A<V4@("`@($1A=&%B87-E('=H97)E('1O(&%D9"X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T87-K<R]C;VYT86-T
M<R]N;W1E<PH@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@(%1H
M92!A8W1U86P@9&%T80H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=%1Y
M<&4@($UI;65T>7!E(&]F("1C;VYT96YT"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C=6ED("`@("`@("`@0VQI96YT($E$(&]F('1H:7,@96YT<GD@*&9O<B!M
M87`I"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4$5!4E]%<G)O<B!O
M<B!S=6ED("A(;W)D92!G=6ED*2!O9B!N97<@96YT<GD*("`@("`J+PH@("`@
M9G5N8W1I;VX@:6UP;W)T16YT<GDH)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A
M<V4L("1C;VYT96YT+"`D8V]N=&5N=%1Y<&4L("1C=6ED*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1T87-K<V%N9&-A;&5N
M9&%R8V]M8FEN960@/2!F86QS93L*"B`@("`@("`@+R\@0VAE8VMS(&EF('1H
M92!C;&EE;G0@<V5N9',@=7,@82!V=&]D;R!I;B!A(&-A;&5N9&%R('-Y;F,Z
M"B`@("`@("`@:68@*"1D871A8F%S92`]/2`G8V%L96YD87(G"B`@("`@("`@
M("`@("`F)B!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI0D5'24Y;7CI=*CI6
M5$]$3R\G+"`B7&XB("X@)&-O;G1E;G0I*2!["B`@("`@("`@("`@("1S97)V
M97)D871A8F%S92`]("=T87-K<R<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'-E<G9E<F1A=&%B87-E(#T@)&1A=&%B87-E.PH@("`@("`@('T*
M"B`@("`@("`@)'-U:60@/2`D<F5G:7-T<GDM/F-A;&PH)'-E<G9E<F1A=&%B
M87-E("X@)R]I;7!O<G0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I*3L*"B`@("`@("`@
M)'1H:7,M/FQO9TUE<W-A9V4H(F%D9"!T;R!S97)V97(@9&(@)'-E<G9E<F1A
M=&%B87-E(&-U:60@)&-U:60@+3X@<W5I9"`D<W5I9"(L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("!I9B`H(6ES7V$H
M)'-U:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1S(#T@)')E
M9VES=')Y+3YC86QL*"1S97)V97)D871A8F%S92X@)R]G971!8W1I;VY4:6UE
M<W1A;7`G+"!A<G)A>2@D<W5I9"P@)V%D9"<I*3L*("`@("`@("`@("`@:68@
M*"$D=',I('L*("`@("`@("`@("`@("`@("1T:&ES+3YL;V=-97-S86=E*"=3
M>6YC34PZ('5N86)L92!T;R!F:6YD(&%D9"UT<R!F;W(@)R`N("1S=6ED("X@
M)R!A="`G("X@)'1S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F-R96%T955I
M9$UA<"@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&-U:60L("1S=6ED
M+"`D=',I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S=6ED.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!E;G1R>2!F<F]M('1H92!S
M97)V97(@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&%T86)A<V4@($1A=&%B87-E('=H97)E('1O(&%D9"X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T87-K<R]C;VYT86-T<R]N
M;W1E<PH@("`@("H@0'!A<F%M('-T<FEN9R`D8W5I9"`@("`@($-L:65N="!)
M1"!O9B!T:&4@96YT<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0
M14%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U:60I(&]F(&1E;&5T960@96YT
M<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T945N=')Y*"1S>6YC261E
M;G1I9FEE<BP@)&1A=&%B87-E+"`D8W5I9"D*("`@('L*("`@("`@("!G;&]B
M86P@)')E9VES=')Y.PH*("`@("`@("`O+R!&:6YD('-E<G9E<B!)1"!F;W(@
M=&AI<R!E;G1R>3H*("`@("`@("`D<W5I9"`]("1T:&ES+3YG9713=6ED*"1S
M>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D8W5I9"D["B`@("`@("`@:68@
M*"%I<U]A*"1S=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1R
M96=I<W1R>2T^8V%L;"@D9&%T86)A<V4N("<O9&5L971E)RP@87)R87DH)'-U
M:60I*3L*("`@("`@("`@("`@)'1S(#T@)')E9VES=')Y+3YC86QL*"1D871A
M8F%S92`N("<O9V5T06-T:6]N5&EM97-T86UP)RP@87)R87DH)'-U:60L("=D
M96QE=&4G*2D["B`@("`@("`@("`@("\O(%=E(&-A;B=T(')E;6]V92!T:&4@
M;6%P<&EN9R!E;G1R>2!A<R!W92!N965D('1O(&ME97`*("`@("`@("`@("`@
M+R\@=&AE('1I;65S=&%M<"!I;F9O<FUA=&EO;BX*("`@("`@("`@("`@)'1H
M:7,M/F-R96%T955I9$UA<"@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@
M)&-U:60L("1S=6ED+"`D=',I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1S=6ED.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P;&%C97,@86X@96YT
M<GD@:6X@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A8F%S92`@("`@1&%T86)A<V4@=VAE<F4@=&\@<F5P
M;&%C92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C86QE
M;F1A<B]T87-K<R]C;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V]N=&5N="`@("`@(%1H92!A8W1U86P@9&%T80H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]N=&5N=%1Y<&4@($UI;65T>7!E(&]F("1C;VYT96YT"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C=6ED("`@("`@("`@0VQI96YT($E$(&]F
M('1H:7,@96YT<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!014%2
M7T5R<F]R(&]R('-U:60@*$AO<F1E(&=U:60I(&]F(&UO9&EF:65D(&5N=')Y
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97!L86-E16YT<GDH)'-Y;F-)9&5N
M=&EF:65R+"`D9&%T86)A<V4L("1C;VYT96YT+"`D8V]N=&5N=%1Y<&4L("1C
M=6ED*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@
M("\O($-H96-K<R!I9B!T:&4@8VQI96YT('-E;F1S('5S(&$@=G1O9&\@:6X@
M82!C86QE;F1A<B!S>6YC.@H@("`@("`@(&EF("@D9&%T86)A<V4@/3T@)V-A
M;&5N9&%R)PH@("`@("`@("`@("`@)B8@<')E9U]M871C:"@G+RA<<EQN?%QR
M?%QN*4)%1TE.6UXZ72HZ5E1/1$\O)RP@(EQN(B`N("1C;VYT96YT*2D@>PH@
M("`@("`@("`@("`D<V5R=F5R9&%T86)A<V4@/2`G=&%S:W,G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1S97)V97)D871A8F%S92`]("1D871A
M8F%S93L*("`@("`@("!]"@H@("`@("`@("1S=6ED(#T@)'1H:7,M/F=E=%-U
M:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1C=6ED*3L*"B`@("`@
M("`@)'1H:7,M/FQO9TUE<W-A9V4H(G)E<&QA8V4@:6X@9&(@)'-E<G9E<F1A
M=&%B87-E(&-U:60@)&-U:60@<W5I9"`D<W5I9"(L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("!I9B`H)'-U:60I('L*
M("`@("`@("`@("`@+R\@16YT<GD@97AI<W1S.B!R97!L86-E(&-U<G)E;G0@
M;VYE+@H@("`@("`@("`@("`D;VL@/2`D<F5G:7-T<GDM/F-A;&PH)'-E<G9E
M<F1A=&%B87-E("X@)R]R97!L86-E)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"1S=6ED+"`D8V]N=&5N="P@)&-O;G1E;G14
M>7!E*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1O:RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1O:SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=',@/2`D<F5G:7-T<GDM/F-A;&PH)'-E<G9E<F1A
M=&%B87-E("X@)R]G971!8W1I;VY4:6UE<W1A;7`G+"!A<G)A>2@D<W5I9"P@
M)VUO9&EF>2<I*3L*("`@("`@("`@("`@)'1H:7,M/F-R96%T955I9$UA<"@D
M<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&-U:60L("1S=6ED+"`D=',I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=.;R!M87`@96YT<GD@9F]U;F0G*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<W5I9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E<R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@<')E=FEO=7,@<WEN8R!I
M9B!A;GDN(%)E='5R;G,*("`@("`J(&9A;'-E(&EF(&YO(&EN9F\@9F]U;F0@
M;W(@82!$871E5')E94]B:F5C="!W:71H(&%T(&QE87-T('1H90H@("`@("H@
M9F]L;&]W:6YG(&%T=')I8G5T97,Z"B`@("`@*@H@("`@("H@0VQI96YT06YC
M:&]R.B!T:&4@8VQI96YT<R!.97AT($%N8VAO<B!O9B!T:&4@<')E=FEO=7,@
M<WEN8RX*("`@("`J(%-E<G9E<D%N8VAO<CH@=&AE(%-E<G9E<B!.97AT($%N
M8VAO<B!O9B!T:&4@<')E=FEO=7,@<WEN8RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F=E=%-Y;F-3=6UM87)Y*"1S>6YC261E;G1I9FEE<BP@)'1Y<&4I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T3V(H)'-Y;F-)9&5N=&EF
M:65R("X@)SIS=6UM87)Y.B<@+B`D='EP92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9G1E<B!A('-U8V-E<W-F=6P@<WEN8RP@=&AE(&-L:65N="!A;F0@
M<V5R=F5R)W,@3F5X="!!;F-H;W)S"B`@("`@*B!A<F4@=W)I='1E;B!T;R!T
M:&4@9&%T86)A<V4@<V\@=&AE>2!C86X@8F4@=7-E9"!T;R!N96=O=&EA=&4*
M("`@("`J('5P8V]M:6YG('-Y;F-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M<FET95-Y;F-3=6UM87)Y*"1S>6YC261E;G1I9FEE<BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-L:65N=$%N8VAO<DYE>'0L("1S97)V97)!
M;F-H;W).97AT*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'-E<G9E<D%N
M8VAO<DYE>'0I('Q\("%I<U]A<G)A>2@D<V5R=F5R06YC:&]R3F5X="DI('L*
M("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H)U-Y;F--3"!I;G1E<FYA
M;"!E<G)O<CH@;F\@86YC:&]R('!R;W9I9&5D("<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G:6X@=W)I=&53>6YC4W5M;6%R>2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@9&EE*"=3>6YC34P@:6YT97)N
M86P@97)R;W(Z(&YO(&%N8VAO<B!P<F]V:61E9"!I;B!W<FET95-Y;F-3=6UM
M87)Y)RD["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES
M*"1S97)V97)!;F-H;W).97AT*2!A<R`D='EP92D@>PH@("`@("`@("`@("`D
M<R`]("1S>6YC261E;G1I9FEE<B`N("<Z<W5M;6%R>3HG("X@)'1Y<&4["@H@
M("`@("`@("`@("`O+R!3970@)&QO8VED+@H@("`@("`@("`@("`D:6YF;R`]
M("9N97<@1&%T851R965/8FIE8W0H)',I.PH@("`@("`@("`@("`D:6YF;RT^
M<V5T*"=#;&EE;G1!;F-H;W(G+"`D8VQI96YT06YC:&]R3F5X="D["B`@("`@
M("`@("`@("1I;F9O+3YS970H)U-E<G9E<D%N8VAO<B<L("1S97)V97)!;F-H
M;W).97AT*3L*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E+3YA
M9&0H)&EN9F\I.PH@("`@("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@+R\@3V)J96-T(&%L<F5A9'D@97AI
M<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&%T871R964M/G5P9&%T941A=&$H)&EN9F\I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&$@;6%P(&5N
M=')I97,@=&\@;6%P(&)E='=E96X@<V5R=F5R(&%N9"!C;&EE;G0@241S+@H@
M("`@("H*("`@("`J(%!U=',@82!G:79E;B!C;&EE;G0@)&-U:60@86YD($AO
M<F1E('-E<G9E<B`D<W5I9"!P86ER(&EN=&\@=&AE"B`@("`@*B!M87`@=&%B
M;&4@=&\@86QL;W<@;6%P<&EN9R!B971W965N('1H92!C;&EE;G0G<R!A;F0@
M<V5R=F5R)W,*("`@("`J($E$<RX@($%C='5A;&QY('1H97)E(&%R92!T=V\@
M;6%P<SH@9G)O;2!T:&4@<W5I9"!T;R!T:&4@8W5I9`H@("`@("H@86YD('9I
M8V4@=F5R<V$N"B`@("`@*B!)9B!A;B!E;G1R>2!A;')E861Y(&5X:7-T<RP@
M:70@:7,@;W9E<G=R:71T96XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T
M955I9$UA<"@D<WEN8TED96YT:69I97(L("1T>7!E+"`D8W5I9"P@)'-U:60L
M("1T<STP*0H@("`@>PH@("`@("`@("\O(%-E="`D8W5I9"X*("`@("`@("`D
M9VED(#T@)FYE=R!$871A5')E94]B:F5C="@D<WEN8TED96YT:69I97(@+B`G
M.B<@+B`D='EP90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)SIS=6ED,F-U:60Z)R`N("1S=6ED*3L*("`@("`@("`D9VED+3YS970H
M)V1A=&%S=&]R92<L("1T>7!E*3L*("`@("`@("`D9VED+3YS970H)V-U:60G
M+"`D8W5I9"D["B`@("`@("`@)&=I9"T^<V5T*"=T<R<L("1T<RD["@H@("`@
M("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^861D*"1G:60I.PH@("`@("`@
M(&EF("AI<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("\O
M($]B:F5C="!A;')E861Y(&5X:7-T<SH@=7!D871E(&EN<W1E860N"B`@("`@
M("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^=7!D871E1&%T82@D9VED
M*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F1I94]N17)R;W(H)'(L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("\O(%-E="`D9VQO8F%L=6ED
M"B`@("`@("`@)&QI9"`]("9N97<@1&%T851R965/8FIE8W0H)'-Y;F-)9&5N
M=&EF:65R("X@)SHG("X@)'1Y<&4*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("<Z8W5I9#)S=6ED.B<@+B`D8W5I9"D["B`@("`@("`@
M)&QI9"T^<V5T*"=S=6ED)RP@)'-U:60I.PH@("`@("`@("1R(#T@)'1H:7,M
M/E]D871A=')E92T^861D*"1L:60I.PH@("`@("`@(&EF("AI<U]A*"1R+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("\O($]B:F5C="!A;')E861Y
M(&5X:7-T<SH@=7!D871E(&EN<W1E860N"B`@("`@("`@("`@("1R(#T@)'1H
M:7,M/E]D871A=')E92T^=7!D871E1&%T82@D;&ED*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/F1I94]N17)R;W(H)'(L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["@H@("`@("`@("\O($EF('1A<VMS(&%N9"!E=F5N=',@87)E(&AA;F1L
M960@870@;VYC92P@=V4@;F5E9"!T;R!S=&]R90H@("`@("`@("\O('1H92!M
M87`@96YT<GD@:6X@8F]T:"!D871A8F%S97,Z"B`@("`@("`@)'-E<W-I;VX@
M/28@)%]315-324].6R=3>6YC34PN<W1A=&4G73L*("`@("`@("`D9&5V:6-E
M(#TF("1S97-S:6]N+3YG971$979I8V4H*3L*"B`@("`@("`@:68@*"1D979I
M8V4M/FAA;F1L951A<VMS26Y#86QE;F1A<B@I"B`@("`@("`@("`@("8F("@D
M='EP92`]/2`G=&%S:W,G('Q\("1T>7!E(#T]("=C86QE;F1A<B<I("D@>PH@
M("`@("`@("`@("`D='EP92`]("1T>7!E(#T]("=T87-K<R<@/R`G8V%L96YD
M87(G(#H@)W1A<VMS)R`[("\O('1H92!O=&AE<B!O;F4*"B`@("`@("`@("`@
M("\O(%-E="`D8W5I9"X*("`@("`@("`@("`@)&=I9"`]("9N97<@1&%T851R
M965/8FIE8W0H)'-Y;F-)9&5N=&EF:65R("X@)SHG("X@)'1Y<&4*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G.G-U:60R8W5I
M9#HG("X@)'-U:60I.PH@("`@("`@("`@("`D9VED+3YS970H)V1A=&%S=&]R
M92<L("1T>7!E*3L*("`@("`@("`@("`@)&=I9"T^<V5T*"=C=6ED)RP@)&-U
M:60I.PH@("`@("`@("`@("`D9VED+3YS970H)W1S)RP@)'1S*3L*"B`@("`@
M("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^861D*"1G:60I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@+R\@3V)J96-T(&%L<F5A9'D@97AI<W1S.B!U<&1A=&4@:6YS
M=&5A9"X*("`@("`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^
M=7!D871E1&%T82@D9VED*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^9&EE3VY%<G)O<B@D<BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@
M("`@("`@("`@("\O(%-E="`D9VQO8F%L=6ED"B`@("`@("`@("`@("1L:60@
M/2`F;F5W($1A=&%4<F5E3V)J96-T*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N
M("1T>7!E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)SIC=6ED,G-U:60Z)R`N("1C=6ED*3L*("`@("`@("`@("`@)&QI9"T^
M<V5T*"=S=6ED)RP@)'-U:60I.PH@("`@("`@("`@("`D<B`]("1T:&ES+3Y?
M9&%T871R964M/F%D9"@D;&ED*3L*("`@("`@("`@("`@:68@*&ES7V$H)'(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("\O($]B:F5C="!A
M;')E861Y(&5X:7-T<SH@=7!D871E(&EN<W1E860N"B`@("`@("`@("`@("`@
M("`D<B`]("1T:&ES+3Y?9&%T871R964M/G5P9&%T941A=&$H)&QI9"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F1I94]N17)R;W(H)'(L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=&EM97-T86UP("AI9B!S970I(&]F('1H
M92!L87-T(&-H86YG92!T;R!T:&4*("`@("`J(&]B:CIG=6ED+"!T:&%T('=A
M<R!C875S960@8GD@=&AE(&-L:65N="X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!4:&ES(&ES('-T;W)E9"!T;PH@("`@
M("H@879O:60@;6ER<F]R:6YG('1H97-E(&-H86YG97,@8F%C:R!T;R!T:&4@
M8VQI96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#:&%N9V544R@D<WEN
M8TED96YT:69I97(L("1D871A8F%S92P@)'-U:60I"B`@("!["B`@("`@("`@
M)&=I9"`])B`D=&AI<RT^7V=E=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N
M("1D871A8F%S92`N("<Z<W5I9#)C=6ED.B<@+B`D<W5I9"D["B`@("`@("`@
M:68@*&ES7V$H)&=I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&=I9"T^
M9V5T*"=T<R<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H
M92!(;W)D92!S97)V97(@9W5I9"`H;&EK90H@("`@("H@:W)O;F]L:71H.C!D
M,6(T,35F8S$R-&0S-#(W-S(R93DU9C!E.3(V8C<U*2!F;W(@82!G:79E;B!C
M;&EE;G0*("`@("`J(&-U:60N(%)E='5R;G,@9F%L<V4@:68@;F\@<W5C:"!I
M9"!I<R!S=&]R960@>65T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($]P<&]S:71E(&]F(&=E=$QO8TED('=H:6-H(')E
M='5R;G,@=&AE(&QO8VED(&9O<B!A(&=I=F5N(&=U:60N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-U:60H)'-Y;F-)9&5N=&EF:65R+"`D='EP92P@)&-U
M:60I"B`@("!["B`@("`@("`@)&QI9"`])B`D=&AI<RT^7V=E=$]B*"1S>6YC
M261E;G1I9FEE<B`N("<Z)R`N("1T>7!E("X@)SIC=6ED,G-U:60Z)R`N("1C
M=6ED*3L*("`@("`@("!I9B`H:7-?82@D;&ED+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D;&ED+3YG970H)W-U:60G*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G9E<G1S(&$@<W5I9"!S97)V97(@:60@*&DN92X@2&]R9&4@1U5)
M1"D@=&\@82!C=6ED(&-L:65N="!)1`H@("`@("H@87,@=7-E9"!B>2!T:&4@
M<WEN8R!C;&EE;G0@*&QI:V4@,3(I(')E='5R;G,@9F%L<V4@:68@;F\@<W5C
M:`H@("`@("H@:60@:7,@<W1O<F5D('EE="X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5I9"@D<WEN
M8TED96YT:69I97(L("1D871A8F%S92P@)'-U:60I"B`@("!["B`@("`@("`@
M)&=I9"`])B`D=&AI<RT^7V=E=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N
M("1D871A8F%S92`@+B`G.G-U:60R8W5I9#HG("X@)'-U:60I.PH@("`@("`@
M(&EF("AI<U]A*"1G:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G:60M
M/F=E="@G8W5I9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]G<R!A(&UE
M<W-A9V4@:6X@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1M97-S86=E("`@("!%:71H97(@82!S=')I;F<@;W(@82!014%27T5R
M<F]R(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("`@("`@
M5VAA="!F:6QE('=A<R!T:&4@;&]G(&9U;F-T:6]N(&-A;&QE9"!F<F]M"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("AE+F<N(%]?1DE,15]?
M*3\*("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YE("`@("`@5VAA="!L:6YE
M('=A<R!T:&4@;&]G(&9U;F-T:6]N(&-A;&QE9"!F<F]M"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("AE+F<N(%]?3$E.15]?*3\*("`@("`J
M($!P87)A;2!I;G1E9V5R("1P<FEO<FET>2`@5&AE('!R:6]R:71Y(&]F('1H
M92!M97-S86=E+B!/;F4@;V8Z"B`@("`@*B`\<')E/@H@("`@("H@4$5!4E],
M3T=?14U%4D<*("`@("`J(%!%05)?3$]'7T%,15)4"B`@("`@*B!014%27TQ/
M1U]#4DE4"B`@("`@*B!014%27TQ/1U]%4E(*("`@("`J(%!%05)?3$]'7U=!
M4DY)3D<*("`@("`J(%!%05)?3$]'7TY/5$E#10H@("`@("H@4$5!4E],3T=?
M24Y&3PH@("`@("H@4$5!4E],3T=?1$5"54<*("`@("`J(#PO<')E/@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L;V=-97-S86=E*"1M97-S86=E+"`D9FEL92`]
M(%]?1DE,15]?+"`D;&EN92`](%]?3$E.15]?+`H@("`@("`@("`@("`@("`@
M("`@("`@("`D<')I;W)I='D@/2!014%27TQ/1U])3D9/*0H@("`@>PH@("`@
M("`@(&EF("AI<U]S=')I;F<H)&UE<W-A9V4I*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@(E-Y;F--3#H@(B`N("1M97-S86=E.PH@("`@("`@('T*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@D;65S<V%G92P@)&9I;&4L("1L:6YE
M+"`D<')I;W)I='DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&UA<$-L:65N=$-A
M=&5G;W)Y,E-E<G9E<B@D8VQI96YT0V%T96=O<GDL("1S=6UM87)Y("`]("=U
M;FMN;W=N)RD@>PH*("`@("`@("!I9B`H96UP='DH)&-L:65N=$-A=&5G;W)Y
M*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?;&]A9$-A=&5G;W)I97--87`H*3L*"B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7V-A=&5G;W)I97--87!;)&-L:65N=$-A=&5G;W)Y72D@
M)B8*("`@("`@("`@("`@(6ES7V%R<F%Y*"1T:&ES+3Y?8V%T96=O<FEE<TUA
M<%LD8VQI96YT0V%T96=O<GE=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]C871E9V]R:65S36%P6R1C;&EE;G1#871E9V]R>5T["B`@("`@("`@
M?0H*("`@("`@("`O*B!S=&]R92!T:&4@8VQI96YT0V%T96=O<GD@87,@;&%C
M:VEN9R!A(&UA<"X@*B\*("`@("`@("`D=&AI<RT^7V-A=&5G;W)I97--87!;
M)&-L:65N=$-A=&5G;W)Y72`](&%R<F%Y*"1S=6UM87)Y*3L*("`@("`@("`D
M=&AI<RT^7W-T;W)E0V%T96=O<FEE<TUA<"@I.PH@("`@("`@(')E='5R;B`D
M8VQI96YT0V%T96=O<GD["B`@("!]"@H@("`@9G5N8W1I;VX@;6%P4V5R=F5R
M0V%T96=O<GDR0VQI96YT*"1S97)V97)#871E9V]R>2P@)'-U;6UA<GD@/2`G
M=6YK;F]W;B<I('L*"B`@("`@("`@:68@*&5M<'1Y*"1S97)V97)#871E9V]R
M>2DI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]L;V%D0V%T96=O<FEE<TUA<"@I.PH*("`@("`@("`D8R`]
M(&%R<F%Y7W-E87)C:"@D<V5R=F5R0V%T96=O<GDL("1T:&ES+3Y?8V%T96=O
M<FEE<TUA<"D["B`@("`@("`@:68@*"%E;7!T>2@D8RD@)B8@(6ES7V%R<F%Y
M*"1C*2D@>PH@("`@("`@("`@("!R971U<FX@)&,["B`@("`@("`@?0H*("`@
M("`@("`O*B!3=&]R92!T:&4@<V5R=F5R0V%T96=O<GD@87,@;&%C:VEN9R!A
M(&UA<"X@*B\*("`@("`@("`D=&AI<RT^7VUI<W-I;F=397)V97)#871E9V]R
M:65S6R1S97)V97)#871E9V]R>5T@/2`D<W5M;6%R>3L*("`@("`@("`D=&AI
M<RT^7W-T;W)E0V%T96=O<FEE<TUA<"@I.PH*("`@("`@("!R971U<FX@)'-E
M<G9E<D-A=&5G;W)Y.PH@("`@?0H*("`@(&9U;F-T:6]N(%]L;V%D0V%T96=O
M<FEE<TUA<"@I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?
M8V%T96=O<FEE<TUA<"DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@)&UA<"`])B`D=&AI<RT^7V=E=$]B*"1?4T534TE/3ELG
M4WEN8TU,+G-T871E)UTM/F=E=%-Y;F-)9&5N=&EF:65R*"D@+B`G.F-A=&5G
M;W)I97,G*3L*("`@("`@("!I9B`H:7-?82@D;6%P+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V%T96=O<FEE<TUA<"`](&%R<F%Y
M*"D["B`@("`@("`@("`@("1T:&ES+3Y?;6ES<VEN9U-E<G9E<D-A=&5G;W)I
M97,@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?8V%T96=O<FEE<TUA<"`]("1M87`M/F=E="@G;6%P)RD["B`@("`@
M("`@("`@("1T:&ES+3Y?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,@/2`D;6%P
M+3YG970H)VUI<W-I;F=397)V97)#871E9V]R:65S)RD["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]S=&]R94-A=&5G;W)I97--87`H*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]C871E9V]R:65S36%P
M*2D@>PH@("`@("`@("`@("!R971U<FX[("\O(&YO=&AI;F<@=&\@9&\*("`@
M("`@("!]"@H@("`@("`@("1M87`@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1?
M4T534TE/3ELG4WEN8TU,+G-T871E)UTM/F=E=%-Y;F-)9&5N=&EF:65R*"D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<Z8V%T96=O
M<FEE<R<I.PH@("`@("`@("1M87`M/G-E="@G;6%P)RP@)'1H:7,M/E]C871E
M9V]R:65S36%P*3L*("`@("`@("`D;6%P+3YS970H)VUI<W-I;F=397)V97)#
M871E9V]R:65S)RP@)'1H:7,M/E]M:7-S:6YG4V5R=F5R0V%T96=O<FEE<RD[
M"@H@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^861D*"1M87`I.PH@
M("`@("`@(&EF("AI<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("\O($]B:F5C="!A;')E861Y(&5X:7-T<SH@=7!D871E(&EN<W1E860N
M"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^=7!D871E1&%T
M82@D;6%P*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F1I94]N17)R;W(H
M)'(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!4:&ES(&ES(&$@<VUA;&P@:&5L<&5R(&9U;F-T:6]N('1H870@8V%N(&)E
M(&EN8VQU9&5D('1O(&-H96-K"B`@("`@*B!W:&5T:&5R(&$@9VEV96X@)&]B
M:B!I<R!A(%!%05)?17)R;W(@;W(@;F]T+B!)9B!S;RP@:70@;&]G<PH@("`@
M("H@=&\@9&5B=6<L('9A<E]D=6UP<R!T:&4@)&]B:B!A;F0@97AI=',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1I94]N17)R;W(H)&]B:BP@)&9I;&4@/2!?
M7T9)3$5?7RP@)&QI;F4@/2!?7TQ)3D5?7RD*("`@('L*("`@("`@("!I9B`H
M(6ES7V$H)&]B:BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^;&]G365S<V%G92@G4WEN
M8TU,.B!014%2($5R<F]R.B`G("X@)&]B:BT^9V5T365S<V%G92@I+"`D9FEL
M92P@)&QI;F4L(%!%05)?3$]'7T524BD["B`@("`@("`@<')I;G0@(E!%05(@
M15)23U)<;EQN(CL*("`@("`@("!V87)?9'5M<"@D;V)J*3L*("`@('T*"B`@
M("!F=6YC=&EO;B`F7V=E=$]B*"1N86UE*0H@("`@>PH@("`@("`@('-T871I
M8R`D8V%C:&4@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-S970H)&-A8VAE
M6R1N86UE72DI('L*("`@("`@("`@("`@)&-A8VAE6R1N86UE72`])B`D=&AI
M<RT^7V1A=&%T<F5E+3YG971/8FIE8W0H)&YA;64I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&-A8VAE6R1N86UE73L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+G!H<```````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`W-C0`,3`T,3<S-C(W-S``
M,#(P,C4U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*BH*("H@268@<V5T('1O('1R=64L(&QO9W,@86QL(&EN
M8V]M:6YG(&%N9"!O=71G;W5N9"!I8V%L96YD87(O=F-A<F0@9&%T80H@*B!T
M;R`O=&UP+W-Y;F,O;&]G+G1X="X@5&AE('=E8B!S97)V97(@=7-E<B`H;&EK
M92!W=W=R=6XI(&UU<W0@:&%V90H@*B!W<FET92!A8V-E<W,@=&\@=&AI<R!F
M:6QE+@H@*B\*9&5F:6YE*"=$14)51TQ/1U])0T%,14Y$05)$051!)RP@=')U
M92D["@HO*BH*("H@5&AE(%-Y;F--3%]$979I8V4Z.B!C;&%S<R!P<F]V:61E
M<R!F=6YC=&EO;F%L:71Y('1H870@:7,*("H@<&]T96YT:6%L;'D@*&-L:65N
M="D@9&5V:6-E(&1E<&5N9&%N="X*("H*("H@4V\@:68@82!S>6YC(&-L:65N
M="!N965D<R!A;GD@:VEN9"!O9B!S<&5C:6%L(&1A=&$@;V8@=&AE(&1A=&$@
M<V5N=`H@*B!T;R!I="!O<B!R96-E:79E9"!F<F]M(&ET+"!T:&ES(&ES(&1O
M;F4@:&5R92X@5&AE<F4@87)E('1W;R!S;W5R8V4*("H@;V8@:6YF;W)M871I
M;VX@=&\@:61E;G1I9GD@86X@9&5V:6-E.B!4:&4@9FER<W0@*&%N9"!B971T
M97(I(&]N92!I<PH@*B!T:&4@1&5V26YF(&1E=FEC92!I;F9O('-E;G0@8GD@
M=&AE(&1E=FEC92!U<&]N(&$@9V5T(')E<75E<W0N($EF"B`J($1E=DEN9B!I
M<R!N;W0@<W5P<&]R=&5D(&]R('-E;G0@8GD@=&AE(&-L:65N="P@=&AE(%-O
M=7)C955222!O9B!T:&4*("H@9&5V:6-E(&UA>2!B92!S=69F:6-E;G0@=&\@
M:61E;G1I9GD@:70N"B`J"B`J($EN9F]R;6%T:6]N(&%B;W5T(&$@9F5W(&1E
M=FEC97,@86QR96%D>2!W;W)K:6YG('=I=&@@4WEN8TU,.CH*("H*("H@4#@P
M,"]0.3`P+U`Y,3`Z"B`J("TM+2TM+2TM+2TM+2TM+0H@*B!#:&%R<V5T.@H@
M*B!4:&ES(&1E=FEC92!I<R!A8FQE('1O(&AA;F1L92!55$8M."!A;F0@<V5N
M9',@:71S(%A-3"!P86-K86=E<R!I;B!55$8X+@H@*B!(;W=E=F5R(&5V96X@
M=&AO=6=H('1H92!834P@:71S96QF(&ES(%541BTX+"!I="!E>'!E8W1S('1H
M92!E;F-L;W-E9`H@*B!V8V%R9"UD871A('1O(&)E($E33RTX.#4Y+3$@=6YL
M97-S(&5X<&QI8VET;'D@<W1A=&5D(&]T:&5R=VES92`H=7-I;F<@=&AE"B`J
M($-(05)3150@;W!T:6]N+"!W:&EC:"!I<R!D97!R96-A=&5D(&9O<B!60T%2
M1"`S+C`I"B`J"B`J($5N8V]D:6YG.@H@*B!3=')I;F<@=F%L=65S(&%R92!E
M;F-O9&5D(")154]4140M4%))3E1!0DQ%(@H@*@H@*B!/=&AE<CH*("H@5&AI
M<R!D979I8V5S(&AA;F1L97,@=&%S:W,@86YD(&5V96YT<R!I;B!O;F4@9&%T
M86)A<V4N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R
M;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T1E=FEC92YP:'`L=B`Q
M+C<N,BXV(#(P,#8O,#(O,3`@,#0Z-3@Z,C8@<V5L<VMY($5X<"`D"B`J"B`J
M($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G
M/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]$979I8V4@
M>PH*("`@(&9U;F-T:6]N("9F86-T;W)Y*"D*("`@('L*("`@("`@("`D<VD@
M/2!3>6YC34Q?1&5V:6-E.CIS;W5R8V554DDH*3L*("`@("`@("`D9&D@/2!3
M>6YC34Q?1&5V:6-E.CID979I8V5);F9O*"D["@H@("`@("`@(&EF("AS=')I
M<W1R*"1S:2P@)W-Y;F,T:B<I("$]/2!F86QS92!\?"!S=')I<W1R*"1S:2P@
M)W-C+7!I;2<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!I;F-L=61E7V]N
M8V4@)U-Y;F--3"]$979I8V4O4WEN8S1J+G!H<"<["B`@("`@("`@("`@("1D
M979I8V4@/2`F;F5W(%-Y;F--3%]$979I8V5?<WEN8S1J*"D["B`@("`@("`@
M?2!E;'-E:68@*"%E;7!T>2@D9&DM/E]-86XI("8F('-T<FES='(H)&1I+3Y?
M36%N+"`G4V]N>2!%<FEC<W-O;B<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("!I;F-L=61E7V]N8V4@)U-Y;F--3"]$979I8V4O4#@P,"YP:'`G.PH@("`@
M("`@("`@("`D9&5V:6-E(#T@)FYE=R!3>6YC34Q?1&5V:6-E7U`X,#`H*3L*
M("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1D:2T^7TUA;BD@)B8@<W1R:7-T
M<B@D9&DM/E]-86XL("=S>6YT:&5S:7,G*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@:6YC;'5D95]O;F-E("=3>6YC34PO1&5V:6-E+U-Y;G1H97-I<RYP
M:'`G.PH@("`@("`@("`@("`D9&5V:6-E(#T@)FYE=R!3>6YC34Q?1&5V:6-E
M7U-Y;G1H97-I<R@I.PH@("`@("`@('T@96QS96EF("@A96UP='DH)&1I+3Y?
M36%N*2`F)B!S=')I<W1R*"1D:2T^7TUA;BP@)VYO:VEA)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G4WEN8TU,+T1E=FEC92].
M;VMI82YP:'`G.PH@("`@("`@("`@("`D9&5V:6-E(#T@)FYE=R!3>6YC34Q?
M1&5V:6-E7TYO:VEA*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&1E=FEC92`]("9N97<@4WEN8TU,7T1E=FEC92@I.PH@("`@("`@('T*"B`@
M("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G92@G57-I;F<@
M9&5V:6-E(&-L87-S("<@+B!G971?8VQA<W,H)&1E=FEC92DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N("1D979I
M8V4["B`@("!]"@H@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@("!["B`@
M("`@("`@<W1A=&EC("1I;G-T86YC93L*"B`@("`@("`@:68@*"%I<W-E="@D
M:6YS=&%N8V4I*2!["B`@("`@("`@("`@("1I;G-T86YC92`](%-Y;F--3%]$
M979I8V4Z.F9A8W1O<GDH*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:6YS=&%N8V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!3
M;W5R8V554DD@9G)O;2!S=&%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V]U
M<F-E55))*"D*("`@('L*("`@("`@("!R971U<FX@)%]315-324].6R=3>6YC
M34PN<W1A=&4G72T^9V5T4V]U<F-E55))*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!$979);F8@8VQA<W,@9G)O;2!S=&%T92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&5V:6-E26YF;R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1?4T534TE/3ELG4WEN8TU,+G-T871E)UTM/F=E=$1E=FEC94EN
M9F\H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=H96X@82!C;&EE;G0@<V5N
M9',@9&%T82!D=7)I;F<@82!S>6YC(&)U="!D;V5S(&YO="!P<F]V:61E"B`@
M("`@*B!I;F9O<FUA=&EO;B!A8F]U="!T:&4@8V]N=&5N='1Y<&4@=VET:"!T
M:&ES(&EN9&EV:61U86P@:71E;2P*("`@("`J('1H:7,@9G5N8W1I;VX@<F5T
M=7)N<R!T:&4@8V]N=&5N='1Y<&4@=&AE(&ET96T@:7,@<W5P<&]S960@=&\@
M8F4@:6XN"B`@("`@*@H@("`@("H@07,@=&AI<R!I<R!O;FQY('5S960@=&\@
M<&%R<V4@=&\@=&AE(&AO<F1E)W,@:6UP;W)T9&%T82!A<&D@9G5N8W1I;VYS
M+`H@("`@("H@<V]M92!S:6UP;&4@9W5E<W-E<R!F;W(@=&AE(&-O;G1E;G1T
M>7!E(&%R92!C;VUP;&5T96QY('-U9F9I8VEE;G0Z"B`@("`@*B!(;W)D92!D
M;V5S(&YO="!C87)E('=H971H97(@9&%T82!I<R!T97AT+W@M=F-A;&5N9&%R
M(&]R('1E>'0O:6-A;&5N9&%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710
M<F5F97)R961#;VYT96YT5'EP92@D='EP92D*("`@('L*("`@("`@("!I9B`H
M)'1Y<&4@/3T@)V-O;G1A8W1S)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E
M>'0O>"UV8V%R9"<["B`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=N;W1E
M<R<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT+W@M=FYO=&4G.PH@("`@
M("`@('T@96QS96EF("@D='EP92`]/2`G=&%S:W,G*2!["B`@("`@("`@("`@
M(')E='5R;B`G=&5X="]C86QE;F1A<B<["B`@("`@("`@?2!E;'-E:68@*"1T
M>7!E(#T]("=C86QE;F1A<B<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT
M+V-A;&5N9&%R)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!P<F5F97)R<F5D(&-O;G1E;G1T>7!E(&]F('1H92!C;&EE
M;G0@9F]R('1H92!G:79E;@H@("`@("H@<WEN8R!D871A('1Y<&4@*&-O;G1A
M8W1S+W1A<VMS+VYO=&5S+V-A;&5N9&%R*2X*("`@("`J"B`@("`@*B!4:&4@
M<F5S=6QT(&ES('!A<W-E9"!A<R!A;B!O<'1I;VX@=&\@=&AE($AO<F1E($%0
M22!E>'!O<G0@9G5N8W1I;VYS+@H@("`@("H@4&QE87-E(&YO=&4@=&AA="!T
M:&ES(&ES(&YO="!T:&4@8V]N=&5N=%1Y<&4@=6QT:6UA=&5L>2!P87-S960@
M=&\@=&AE"B`@("`@*B!C;&EE;G0@8G5T(')A=&AE<B!T:&4@8V]N=&5N=%1Y
M<&4@<')E<V5N=&5D('1O('1H92!(;W)D92!!4$D@97AP;W)T"B`@("`@*B!F
M=6YC=&EO;G,N"B`@("`@*@H@("`@("H@069T97(@=&AE(&1A=&$@:7,@<F5T
M<FEE=F5D(&9R;VT@:&]R9&4L(&-O;G9E<G1397)V97(R0VQI96YT(&-A;B!D
M;PH@("`@("H@<V]M92!P;W-T+7!R;V-E<W-I;F<@86YD('-E="!T:&4@8V]R
M<F5C="!C;VYT96YT5'EP92!A8V-E<'1A8FQE(&9O<@H@("`@("H@=&AE(&-L
M:65N="X*("`@("`J"B`@("`@*B!4:&ES(&ES(&$@;&EK96QY(&-A;F1I9&%T
M92!F;W(@;6]D:69I8V%T:6]N(&EN(&-O;F-R971E('-U8F-L87-S97,Z"B`@
M("`@*B!I;F1I=FED=6%L(&1E=FEC97,@;6EG:'0@<')E9F5R(&]T:&5R(&-H
M87)S971S(&]R(&]T:&5R(&5N8V]D:6YG<PH@("`@("H@*&-U<G)E;G1L>3H@
M455/5$5$+5!224Y404),12D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')E
M9F5R<F5D0V]N=&5N=%1Y<&5#;&EE;G0H)'1Y<&4I"B`@("!["B`@("`@("`@
M:68@*"1T>7!E(#T]("=C;VYT86-T<R<I('L*("`@("`@("`@("`@<F5T=7)N
M("=T97AT+W@M=F-A<F0G.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`G
M;F]T97,G*2!["B`@("`@("`@("`@(')E='5R;B`G=&5X="]X+79N;W1E)SL*
M("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)W1A<VMS)RD@>PH@("`@("`@
M("`@("!R971U<FX@)W1E>'0O>"UV=&]D;R<["B`@("`@("`@?2!E;'-E:68@
M*"1T>7!E(#T]("=C86QE;F1A<B<I('L*("`@("`@("`@("`@<F5T=7)N("=T
M97AT+V-A;&5N9&%R)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T('1H92!C;VYT96YT(')E8V5I=F5D(&9R;VT@=&AE(&-L:65N
M="!F;W(@=&AE(&AO<F1E(&)A8VME;F0N"B`@("`@*@H@("`@("H@0W5R<F5N
M=&QY('-T<FEP<R!U:60@*'!R:6UA<GD@:V5Y*2!I;F9O<FUA=&EO;B!A<R!C
M;&EE;G0@86YD"B`@("`@*B!S97)V97(@;6EG:'0@=7-E(&1I9F9E<F5N="!O
M;F5S+@H@("`@("H*("`@("`J($-H87)S970@8V]N=F5R<VEO;G,@;6EG:'0@
M8F4@861D960@:&5R92!T;V\N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V]N=&5N="`@("`@("!4:&4@8V]N=&5N="!T;R!C;VYV97)T"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@(%1H92!C;VYT96YT5'EP
M92!O9B!T:&4@8V]N=&5N=`H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M("`@("`@("`@("`@("`@87)R87DH)&YE=V-O;G1E;G0L("1N97=C;VYT96YT
M5'EP92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!C;VYV97)T960@8V]N=&5N="!A;F0@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("AP;W-S:6)L>2!C:&%N9V5D*2!N97<@0V]N
M=&5N=%1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1#;&EE;G0R
M4V5R=F5R*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@("`@("`@
M9VQO8F%L("1B86-K96YD.PH@("`@("`@(&EF("A$14)51TQ/1U])0T%,14Y$
M05)$051!*2!["B`@("`@("`@("`@("1F<"`]($!F;W!E;B@G+W1M<"]S>6YC
M+VQO9RYT>'0G+"`G82<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@
M("`@("`@("`@("!`9G=R:71E*"1F<"P@(EQN:6YP=70@<F5C96EV960@9G)O
M;2!C;&EE;G0@*"1C;VYT96YT5'EP92E<;B(I.PH@("`@("`@("`@("`@("`@
M:68@*'-T<G-T<B@D8V]N=&5N=%1Y<&4L)W-I9B\G*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("`@("`O+R!S>6YC-&9J('-I9B\J(&1A=&$@:7,@
M8F%S938T7V5N8V]D960N"B`@("`@("`@("`@("`@("`@("`@0&9W<FET92@D
M9G`L(&)A<V4V-%]D96-O9&4H)&-O;G1E;G0I("X@(EQN(BD["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@($!F=W)I=&4H
M)&9P+"`D8V]N=&5N="`N(")<;B(I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@0&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!!;'=A>7,@<F5M;W9E(&-L:65N="!5240N(%5)
M1"!W:6QL(&)E('-E<&5R871E;'D@<&%S<V5D(&EN"B`@("`@("`@+R\@6$U,
M+@H@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\
M7&XI54E$.BXJ/RA<<EQN?%QR?%QN*2\G+"`G7#$G+"`D8V]N=&5N="P@,2D[
M"@H@("`@("`@(&EF("@D=&AI<RT^;F5E9'-#871E9V]R>4UA<'!I;F<H*2`F
M)@H@("`@("`@("`@("!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI0T%414=/
M4DE%4UM>7#I=*CHH+BH_*2A<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT+"`D;2DI('L*("`@("`@("`@("`@)&-A=',@
M/2!E>'!L;V1E*"<L)RP@)&U;,ETI.PH@("`@("`@("`@("!I9B@@<')E9U]M
M871C:"@G+RA<<EQN?%QR?%QN*5-534U!4EE;7EPZ72HZ*"XJ/RDH7')<;GQ<
M<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@)&TI
M*2!["B`@("`@("`@("`@("`@("`D<W5M;6%R>2`]("1M6S)=.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-U;6UA<GD@/2`G=6YK
M;F]W;B<["B`@("`@("`@("`@('T*"@H@("`@("`@("`@("!F;W)E86-H("@D
M8V%T<R!A<R`D8V%T*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT<UM=(#T@
M)&)A8VME;F0M/FUA<$-L:65N=$-A=&5G;W)Y,E-E<G9E<B@D8V%T+"`D<W5M
M;6%R>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-O;G1E;G0@/2!P
M<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;D-!5$5'3U))15-;7EPZ72HZ*2@N
M*C\I*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<D,2<@+B!I;7!L;V1E*"<L)RPD<F5S=6QT<RD@+B`G)#,G
M+"`D8V]N=&5N="D["@H@("`@("`@('T*("`@("`@("`O+R!%;G-U<F4@=F%L
M:60@;F5W;&EN92!T97)M:6YA=&EO;BX*("`@("`@("!I9B`H<W5B<W1R*"1C
M;VYT96YT+"`M,2D@(3T@(EQN(B`F)B!S=6)S='(H)&-O;G1E;G0L("TQ*2`A
M/2`B7'(B*2!["B`@("`@("`@("`@("1C;VYT96YT("X](")<<EQN(CL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D8V]N=&5N="P@)&-O;G1E
M;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1H92!C
M;VYT96YT(&9R;VT@=&AE(&)A8VME;F0@=&\@82!F;W)M870@<W5I=&%B;&4@
M9F]R('1H90H@("`@("H@8VQI96YT(&1E=FEC92X*("`@("`J"B`@("`@*B!3
M=')I<',@=&AE('5I9"`H<')I;6%R>2!K97DI(&EN9F]R;6%T:6]N(&%S(&-L
M:65N="!A;F0@<V5R=F5R(&UI9VAT('5S90H@("`@("H@9&EF9F5R96YT(&]N
M97,N"B`@("`@*@H@("`@("H@0VAA<G-E="!C;VYV97)S:6]N<R!M:6=H="!B
M92!A9&1E9"!H97)E('1O;RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;VYT96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O;G9E<G0*("`@("`J
M($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O;G1E;G14>7!E
M(&]F(&-O;G1E;G0@87,@<F5T=7)N960@9G)O;0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@8F%C:V5N9`H@("`@("H@0')E='5R
M;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W8V]N=&5N="P@)&YE
M=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*'!O<W-I8FQY(&-H86YG960I
M(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R
M=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D*("`@('L*
M("`@("`@("!G;&]B86P@)&)A8VME;F0["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1C;VYT96YT5'EP92DI('L*("`@("`@("`@("`@)&-O;G1E;G14>7!E(#T@
M)&-O;G1E;G14>7!E6R=#;VYT96YT5'EP92==.PH@("`@("`@('T*"B`@("`@
M("`@:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@("`@("`@("`@
M)&9P(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A)RD["B`@("`@
M("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P
M+"`B7&YO=71P=70@<F5C96EV960@9G)O;2!H;W)D92!B86-K96YD("(@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`B*"1C;VYT96YT5'EP92DZ7&XB*3L*
M("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"1C;VYT96YT("X@(EQN(BD[
M"B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\O($%L=V%Y<R!R96UO=F4@<V5R=F5R(%5)
M1"X@54E$('=I;&P@8F4@<V5P97)A=&5L>2!P87-S960@:6X*("`@("`@("`O
M+R!834PN"B`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<
M;GQ<<GQ<;BE5240Z+BH_*%QR7&Y\7')\7&XI+R<L("=<,2<L("1C;VYT96YT
M+"`Q*3L*"B`@("`@("`@)&1I(#T@)'1H:7,M/F1E=FEC94EN9F\H*3L*"B`@
M("`@("`@:68@*"1T:&ES+3YN965D<T-A=&5G;W)Y36%P<&EN9R@I("8F"B`@
M("`@("`@("`@('!R96=?;6%T8V@H)R\H7')<;GQ<<GQ<;BE#051%1T]22453
M6UY<.ETJ.B@N*C\I*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E;G0L("1M*2D@>PH@("`@("`@("`@("`D8V%T<R`](&5X
M<&QO9&4H)RPG+"`D;5LR72D["@H@("`@("`@("`@("!I9B@@<')E9U]M871C
M:"@G+RA<<EQN?%QR?%QN*5-534U!4EE;7EPZ72HZ*"XJ/RDH7')<;GQ<<GQ<
M;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D<W5M;6%R>2`]("1M6S)=.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-U;6UA<GD@/2`G=6YK;F]W
M;B<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@*"1C871S
M(&%S("1C870I('L*("`@("`@("`@("`@("`@("1R97-U;'1S6UT@/2`D8F%C
M:V5N9"T^;6%P4V5R=F5R0V%T96=O<GDR0VQI96YT*"1C870L("1S=6UM87)Y
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!P<F5G7W)E<&QA8V4H)R\H
M7')<;GQ<<GQ<;D-!5$5'3U))15-;7EPZ72HZ*2@N*C\I*%QR7&Y\7')\7&XI
M+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)#$G("X@:6UP;&]D92@G
M+"<L)')E<W5L=',I("X@)R0R)RP@)&-O;G1E;G0I.PH@("`@("`@('T*"B`@
M("`@("`@<W=I=&-H("@D8V]N=&5N=%1Y<&4I('L*("`@("`@("!C87-E("=T
M97AT+V-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+6EC86QE;F1A
M<B<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"UV8V%L96YD87(G(#H*("`@("`@
M("!C87-E("=T97AT+W@M=F5V96YT)R`Z"B`@("`@("`@8V%S92`G=&5X="]X
M+79T;V1O)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+79N;W1E)SH*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W1E>'0O>"UV8V%R9"<@.@H@
M("`@("`@("`@("`O+R!)9B!W92!C86X@97AT<F%C="!F<F]M('1H92!$979I
M8V4@26YF;RP@=&AA="!T:&4@8VQI96YT"B`@("`@("`@("`@("\O('5S97,@
M5$5,.U=/4DLZ(#`X,#`@,3(S(&EN<W1E860@;V8@5$5,.U194$4]5T]22SH*
M("`@("`@("`@("`@+R\@,#@P,#$R,RP@8V]N=F5R="!T:&4@9&%T82!A8V-O
M<F1I;F=L>2X*("`@("`@("`@("`@:68@*"%E;7!T>2@D9&DM/E]#5$-A<%LG
M=&5X="]X+79C87)D)UU;)U1%3"==*2`F)@H@("`@("`@("`@("`@("`@96UP
M='DH)&1I+3Y?0U1#87!;)W1E>'0O>"UV8V%R9"==6R=414PG72T^7W!A<F%M
M<ULG5%E012==*2`F)@H@("`@("`@("`@("`@("`@(65M<'1Y*"1D:2T^7T-4
M0V%P6R=T97AT+W@M=F-A<F0G75LG5$5,)UTM/E]P87)A;7-;)U9/24-%)UTI
M*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G
M+RA<<EQN?%QR?%QN*51%3#M465!%/4A/344O)RP@)UPQ5$5,.TA/344[5D])
M0T4G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M465!%/5=/4DLO)RP@
M)UPQ5$5,.U=/4DL[5D])0T4G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%
M3#M465!%/4-%3$PO)RP@)UPQ5$5,.U9/24-%.T-%3$PG+"`D8V]N=&5N="P@
M,2D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G
M+RA<<EQN?%QR?%QN*51%3#M465!%/49!6"\G+"`G7#%414P[5T]22SM&05@G
M+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R
M96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M465!%/5!!1T52+R<L("=<
M,51%3#M004=%4CM73U)+)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O+R!)9B!W92!C86X@97AT<F%C="!F<F]M('1H92!$
M979I8V4@26YF;RP@=&AA="!T:&4@8VQI96YT"B`@("`@("`@("`@("\O('5S
M97,@0412.U=/4DLZ("XN+B!I;G-T96%D(&]F($%$4CM465!%/5=/4DLZ(#`X
M,#`Q,C,L"B`@("`@("`@("`@("\O(&-O;G9E<G0@=&AE(&1A=&$@86-C;W)D
M:6YG;'DN"B`@("`@("`@("`@(&EF("@A96UP='DH)&1I+3Y?0U1#87!;)W1E
M>'0O>"UV8V%R9"==6R=!1%(G72D@)B8*("`@("`@("`@("`@("`@(&5M<'1Y
M*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A<F0G75LG0412)UTM/E]P87)A;7-;
M)U194$4G72D@)B8*("`@("`@("`@("`@("`@("%E;7!T>2@D9&DM/E]#5$-A
M<%LG=&5X="]X+79C87)D)UU;)T%$4B==+3Y?<&%R86US6R=73U)+)UTI*2![
M"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<
M<EQN?%QR?%QN*4%$4CM465!%/5=/4DLO)RP@)UPQ0412.U=/4DLG+"`D8V]N
M=&5N="P@,2D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P
M;&%C92@G+RA<<EQN?%QR?%QN*4%$4CM465!%/4A/344O)RP@)UPQ0412.TA/
M344G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1C;VYT
M96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]M
M92!D979I8V5S(&QI:V4@=&AE(%-O;GD@17)I8W-S;VX@4#@P,"]0.3`P+U`Y
M,3`@:&%N9&QE"B`@("`@*B!V=&]D;W,@*'1A<VMS*2!A;F0@=F5V96YT<R!I
M;B!T:&4@<V%M92`B8V%L96YD87(B('-Y;F,N("!4:&ES"B`@("`@*B!R97%U
M:7)E<R!S<&5C:6%L(&%C=&EO;G,@;VX@;W5R('-I9&4@87,@=V4@<W1O<F4@
M=&AI<R!I;@H@("`@("H@9&EF9F5R96YT(&1A=&%B87-E<R`H;F%G(&%N9"!K
M<F]N;VQI=&@I+B`@5&AI<R!F=6YC=&EO;@H@("`@("H@9&5T97)M:6YE<R!W
M:&5T:&5R('1H92!C;&EE;G0@9&]E<R!I="!L:6ME('1H870N("!#=7)R96YT
M;'D*("`@("`J('1H:7,@:7,@9&]N92!B>2!C:&5C:VEN9R!T:&4@1&5V26YF
M(&EN9F]R;6%T:6]N+B!&;W(@9&EF9F5R96YT"B`@("`@*B!C;&EE;G1S('1H
M97)E(&UA>2!B92!D:69F97)E;G0@=V%Y<R!T;R!F:6YD(&]U="!H;W<@=&AE
M(&-L:65N=`H@("`@("H@;&EK97,@:71S('1A<VMS+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!H86YD;&5487-K<TEN0V%L96YD87(H*0H@("`@>PH@("`@("`@
M("\O($1E9F%U;'0Z('1A<VMS(&%N9"!E=F5N=',@87)E('-E<&5R871E(&1A
M=&%B87-E<RX*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3;VUE(&1E=FEC97,@;F5E9"!A(&UA<'!I;F<@;V8@8VQI96YT
M('9S+B!S97)V97(@8V%T96=O<FEE(&YA;65S+@H@("`@("H@5&AE(&)A8VME
M;F0@<')O=FED97,@82!M96-H86YI<VT@9F]R('1H:7,@;6%P<&EN9RX@270@
M:7,@=7-E9`H@("`@("H@=VAE;B!T:&ES(&YE961S0V%T96=O<GE-87!P:6YG
M(')E='5R;G,@=')U92X*("`@("`J($9O<B!S<&5C:6%L(&-A<V5S('1H92!M
M87!P:6YG(&UA>2!A;'-O(&)E(&EM<&QE;65N=&5D(&1I<F5C=&QY(&EN"B`@
M("`@*B!C;VYV97)T0VQI96YT,E-E<G9E<B!A;F0@8V]N=F5R=%-E<G9E<C)#
M;&EE;G0N($EN('1H:7,@8V%S90H@("`@("H@;F5E9'-#871E9V]R>4UA<'!I
M;F<@;6%Y(')E='5R;B!F86QS92X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5E
M9'-#871E9V]R>4UA<'!I;F<H*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"GT*````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O9&%T82\`````````````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<P`#`Q-C$P,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O````````````````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-S``,#$U-C(W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&
M4R]T97-T<R\`````````````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,``P,38W-S$`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B\`````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<P`#`Q
M-S0U-@`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+P``````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-S``,#(S,3`T`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'``
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,34Q-@`Q,#0Q-S,V,C<W,``P,C0U-S``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"B\J
M*@H@*B!3=')A=&5G>2!F;W(@8V]P>6EN9R!I;G!U="!T<F5E(&]U="!O9B!A
M(%9&4PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<"QV(#$N,2XX+C4@
M,C`P-B\P,2\P,2`R,3HR.#HT-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES
M+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&
M96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!61E-?
M25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D937TE33U=R
M:71E<E]296%L26YP=713=')A=&5G>5]C;W!Y(&5X=&5N9',@5D937TE33U=R
M:71E<E]296%L26YP=713=')A=&5G>2!["@H@("`@=F%R("1?=&5M<%!A=&@@
M/2!N=6QL.PH*("`@(&9U;F-T:6]N(&=E=%)E86Q0871H*"D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W1E;7!0871H*2D@>PH@("`@("`@
M("`@("`D=&UP7VQO8V%T:6]N<R`](&%R<F%Y*"<O=&UP)RP@)R]V87(O=&UP
M)RP@)V,Z7%=55&5M<"<L("=C.EQT96UP)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G8SI<=VEN9&]W<UQT96UP)RP@)V,Z7'=I;FYT
M7'1E;7`G*3L*"B`@("`@("`@("`@("\J($9I<G-T+"!T<GD@4$A0)W,@=7!L
M;V%D7W1M<%]D:7(@9&ER96-T:79E+B`J+PH@("`@("`@("`@("`D=&UP(#T@
M:6YI7V=E="@G=7!L;V%D7W1M<%]D:7(G*3L*"B`@("`@("`@("`@("\J($]T
M:&5R=VES92P@=')Y('1O(&1E=&5R;6EN92!T:&4@5$U01$E2(&5N=FER;VYM
M96YT"B`@("`@("`@("`@("`J('9A<FEA8FQE+B`J+PH@("`@("`@("`@("!I
M9B`H96UP='DH)'1M<"DI('L*("`@("`@("`@("`@("`@("1T;7`@/2!G971E
M;G8H)U1-4$1)4B<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)
M9B!W92!S=&EL;"!C86YN;W0@9&5T97)M:6YE(&$@=F%L=64L('1H96X@8WEC
M;&4@=&AR;W5G:"!A"B`@("`@("`@("`@("`J(&QI<W0@;V8@<')E<V5T('!O
M<W-I8FEL:71I97,N("HO"B`@("`@("`@("`@('=H:6QE("AE;7!T>2@D=&UP
M*2`F)B!C;W5N="@D=&UP7VQO8V%T:6]N<RDI('L*("`@("`@("`@("`@("`@
M("1T;7!?8VAE8VL@/2!A<G)A>5]S:&EF="@D=&UP7VQO8V%T:6]N<RD["B`@
M("`@("`@("`@("`@("!I9B`H0&ES7V1I<B@D=&UP7V-H96-K*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T;7`@/2`D=&UP7V-H96-K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H96UP='DH
M)'1M<"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB*2D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?=&5M<%!A=&@@
M/2!T96UP;F%M*"1T;7`L("=I<V]D)RD["B`@("`@("`@("`@($!U;FQI;FLH
M)'1H:7,M/E]T96UP4&%T:"D["@H@("`@("`@("`@("`D<F5S(#T@)'1H:7,M
M/E]C;W!Y5&]496UP4&%T:"@I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=&5M<%!A=&@["B`@("!]"@H@("`@9G5N8W1I;VX@9FEN:7-H960H
M*0H@("`@>PH@("`@("`@(')E='5R;B!61E-?25-/5W)I=&5R7U)E86Q);G!U
M=%-T<F%T96=Y7V-O<'DZ.E]R96UO=F5296-U<G-I=F4H)'1H:7,M/E]T96UP
M4&%T:"D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;6]V95)E8W5R<VEV92@D
M<&%T:"D*("`@('L*("`@("`@("`D9&@@/2!`;W!E;F1I<B@D<&%T:"D["B`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D9&@I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y(%PB)7-<(BXB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%T:"DI.PH@("`@("`@('T*("`@
M("`@("!W:&EL92`H*"1E;G0@/2!R96%D9&ER*"1D:"DI("$]/2!F86QS92D@
M>PH@("`@("`@("`@("!I9B`H)&5N="`]/2`G+B<@?'P@)&5N="`]/2`G+BXG
M*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&9U;&P@/2!S<')I;G1F*"<E<R\E<R<L("1P871H+"`D
M96YT*3L*("`@("`@("`@("`@:68@*&ES7V1I<B@D9G5L;"DI('L*("`@("`@
M("`@("`@("`@("1R97,@/2!61E-?25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T
M96=Y7V-O<'DZ.E]R96UO=F5296-U<G-I=F4H)&9U;&PI.PH@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"%`=6YL
M:6YK*"1F=6QL*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T('5N;&EN:R!<(B5S
M7"(N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9G5L;"DI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&-L;W-E9&ER*"1D:"D["@H@
M("`@("`@(&EF("@A0')M9&ER*"1P871H*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!R;61I
M<B!<(B5S7"(N(BDL("1F=6QL*2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(%]C;W!Y5&]496UP4&%T:"@I"B`@("!["B`@("`@("`@)&1I<E-T
M86-K(#T@87)R87DH)R<I.PH*("`@("`@("!W:&EL92`H8V]U;G0H)&1I<E-T
M86-K*2`^(#`I('L*("`@("`@("`@("`@)&1I<B`](&%R<F%Y7W-H:69T*"1D
M:7)3=&%C:RD["B`@("`@("`@("`@(&EF("AE;7!T>2@D9&ER*2D@>PH@("`@
M("`@("`@("`@("`@)'1A<F=E="`]("1T:&ES+3Y?=&5M<%!A=&@["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&%R9V5T(#T@<W!R
M:6YT9B@G)7,O)7,G+"`D=&AI<RT^7W1E;7!0871H+"`D9&ER*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(4!M:V1I<B@D=&%R9V5T*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(I+"`D=&%R9V5T*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1S;W5R8V50871H(#T@)'1H:7,M
M/E]S;W5R8V52;V]T.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1D:7(I*2![
M"B`@("`@("`@("`@("`@("`D<V]U<F-E4&%T:"`N/2`G+R<@+B`D9&ER.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&ES="`]("1T:&ES+3Y?<V]U
M<F-E5F9S+3YL:7-T1F]L9&5R*"1S;W5R8V50871H+"!N=6QL+"!T<G5E*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&5N=')Y*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&5N=')Y6R=T>7!E)UT@/3T@)RHJ9&ER)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D9&ER*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D9&ER4W1A8VM;72`]("1E;G1R>5LG;F%M92==
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1D:7)3=&%C:UM=(#T@<W!R:6YT9B@G)7,O)7,G+"`D9&ER
M+"`D96YT<GE;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9&%T
M82`]("1T:&ES+3Y?<V]U<F-E5F9S+3YR96%D*"1S;W5R8V50871H+"`D96YT
M<GE;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&1A
M=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1D871A.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`@("`@)'1A<F=E=$9I;&4@/2!S<')I;G1F*"<E<R\E<R<L("1T
M87)G970L("1E;G1R>5LG;F%M92==*3L*("`@("`@("`@("`@("`@("`@("`D
M9F@@/2!`9F]P96XH)'1A<F=E=$9I;&4L("=W)RD["B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D9F@I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(I+"`D=&%R9V5T
M1FEL92DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H9G=R:71E*"1F:"P@)&1A=&$I("$]('-T<FQE;B@D9&%T82DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")%<G)O<B!W<FET:6YG(%PB)7-<(BXB*2P@)'1A
M<F=E=$9I;&4I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@9F-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V1I
M<F5C="YP:'``````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S-#8`,3`T,3<S-C(W-S``,#(U,#<P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*BH*("H@4W1R871E9WD@9F]R(&1I<F5C=&QY(&%C8V5S<VEN9R!I
M;G!U="!T<F5E(&EN(&$@)V9I;&4G(%9&4PH@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]D:7)E8W0N<&AP+'8@,2XQ+C@N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C0T(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,
M3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y
M<RYC;VT^"B`J($!P86-K86=E(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J+PIC;&%S<R!61E-?25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T96=Y
M7V1I<F5C="!E>'1E;F1S(%9&4U])4T]7<FET97)?4F5A;$EN<'5T4W1R871E
M9WD@>PH*("`@(&9U;F-T:6]N(&=E=%)E86Q0871H*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]S;W5R8V569G,M/E]G971.871I=F50871H*"1T
M:&ES+3Y?<V]U<F-E4F]O="D["B`@("!]"@H@("`@9G5N8W1I;VX@9FEN:7-H
M960H*0H@("`@>PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2\`````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S``
M,#(S,S`U`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#<V,0`Q,#0Q-S,V,C<W,``P,C0W-S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J*@H@*B!3=')A=&5G>2!F
M;W(@=W)I=&EN9R!F:6QE('1O('1E;7!O<F%R>2!D:7)E8W1O<GDL('1H96X@
M8V]P>6EN9R!T;R!61E,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H
M<"QV(#$N,2XX+C0@,C`P-B\P,2\P,2`R,3HR.#HT-"!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O
M=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`
M<&%C:V%G92!61E-?25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA
M<W,@5D937TE33U=R:71E<E]296%L3W5T<'5T4W1R871E9WE?8V]P>2!E>'1E
M;F1S(%9&4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T96=Y('L*"B`@("!V
M87(@)%]T96UP1FEL96YA;64@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1V5T
M(&$@<F5A;"!F:6QE;F%M92!T;R!W:&EC:"!W92!C86X@=W)I=&4N"B`@("`@
M*@H@("`@("H@26X@=&AI<R!I;7!L96UE;G1A=&EO;BP@=V4@8W)E871E(&%N
M9"!S=&]R92!A('1E;7!O<F%R>2!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@('L*("`@("`@("!I9B`H:7-?
M;G5L;"@D=&AI<RT^7W1E;7!&:6QE;F%M92DI('L*"B`@("`@("`@("`@("1T
M;7!?;&]C871I;VYS(#T@87)R87DH)R]T;7`G+"`G+W9A<B]T;7`G+"`G8SI<
M5U5496UP)RP@)V,Z7'1E;7`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=C.EQW:6YD;W=S7'1E;7`G+"`G8SI<=VEN;G1<=&5M<"<I
M.PH*("`@("`@("`@("`@+RH@1FER<W0L('1R>2!02%`G<R!U<&QO861?=&UP
M7V1I<B!D:7)E8W1I=F4N("HO"B`@("`@("`@("`@("1T;7`@/2!I;FE?9V5T
M*"=U<&QO861?=&UP7V1I<B<I.PH*("`@("`@("`@("`@+RH@3W1H97)W:7-E
M+"!T<GD@=&\@9&5T97)M:6YE('1H92!435!$25(@96YV:7)O;FUE;G0*("`@
M("`@("`@("`@("H@=F%R:6%B;&4N("HO"B`@("`@("`@("`@(&EF("AE;7!T
M>2@D=&UP*2D@>PH@("`@("`@("`@("`@("`@)'1M<"`](&=E=&5N=B@G5$U0
M1$E2)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($EF('=E('-T
M:6QL(&-A;FYO="!D971E<FUI;F4@82!V86QU92P@=&AE;B!C>6-L92!T:')O
M=6=H(&$*("`@("`@("`@("`@("H@;&ES="!O9B!P<F5S970@<&]S<VEB:6QI
M=&EE<RX@*B\*("`@("`@("`@("`@=VAI;&4@*&5M<'1Y*"1T;7`I("8F(&-O
M=6YT*"1T;7!?;&]C871I;VYS*2D@>PH@("`@("`@("`@("`@("`@)'1M<%]C
M:&5C:R`](&%R<F%Y7W-H:69T*"1T;7!?;&]C871I;VYS*3L*("`@("`@("`@
M("`@("`@(&EF("A`:7-?9&ER*"1T;7!?8VAE8VLI*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1M<"`]("1T;7!?8VAE8VL["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(I*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]T96UP1FEL96YA;64@/2!T
M96UP;F%M*"1T;7`L("=I<V\G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1E;7!&:6QE;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B!F
M:6YI<VAE9"@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=&5M
M<$9I;&5N86UE*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@
M("`@("`@(&EF("@A9FEL95]E>&ES=',H)'1H:7,M/E]T96UP1FEL96YA;64I
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<A7B@N*BDO*%M>+UTJ*20A)RP@)'1H:7,M/E]T87)G
M971&:6QE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)&1I<B`]("1M871C
M:&5S6S%=.PH@("`@("`@("`@("`D9FEL92`]("1M871C:&5S6S)=.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1D:7(@/2`G)SL*("`@("`@("`@
M("`@)&9I;&4@/2`D=&AI<RT^7W1A<F=E=$9I;&4["B`@("`@("`@?0H*("`@
M("`@("`D<F5S(#T@)'1H:7,M/E]T87)G97169G,M/G=R:71E*"1D:7(L("1F
M:6QE+"`D=&AI<RT^7W1E;7!&:6QE;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1R=64I.PH@("`@("`@($!U;FQI;FLH
M)'1H:7,M/E]T96UP1FEL96YA;64I.PH@("`@("`@("1T:&ES+3Y?=&5M<$9I
M;&5N86UE(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"GT*
M"@```````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'``
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C4Q-``Q,#0Q-S,V,C<W,``P,C4R-C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!3=')A=&5G>2!F;W(@9&ER96-T;'D@=W)I=&EN9R!O=71P=70@9FEL92!T
M;R!61E,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP+'8@,2XQ
M+C@N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C0T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O
M;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N
M($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E
M(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!61E-?
M25-/5W)I=&5R7U)E86Q/=71P=713=')A=&5G>5]D:7)E8W0@97AT96YD<R!6
M1E-?25-/5W)I=&5R7U)E86Q/=71P=713=')A=&5G>2!["@H@("`@9G5N8W1I
M;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@('L*("`@("`@("`O*B!3;R!W92!S
M:&]U;&1N)W0@8F4@86-C97-S:6YG(%]G971.871I=F50871H*"DN("!)9B!W
M92!H860@<F5A;`H@("`@("`@("`J(&%C8V5S<R!C;VYT<F]L+"!T:&%T('=O
M=6QD(&)E('!R;W1E8W1E9"!A;F0@=V4G9"!B92!A(&9R:65N9"P@87,*("`@
M("`@("`@*B!T:&%T(&ES('1H92!P;VEN="!O9B!T:&ES(&5X8V5R8VES92X@
M*B\*("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^7W1A<F=E=%9F<RT^7V=E
M=$YA=&EV95!A=&@H)'1H:7,M/E]T87)G971&:6QE*3L*"B`@("`@("`@+RH@
M36%K92!S=7)E('1H92!P871H('1O('1H92!F:6QE(&5X:7-T<RX@*B\*("`@
M("`@("`D9&ER(#T@9&ER;F%M92@D9FEL96YA;64I.PH@("`@("`@('=H:6QE
M("@A0&ES7V1I<B@D9&ER*2D@>PH@("`@("`@("`@("!I9B`H(4!M:V1I<B@D
M9&ER+"`P-S4U*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&ER*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1I<B`]
M(&1I<FYA;64H)&1I<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I
M;&5N86UE.PH@("`@?0H*("`@(&9U;F-T:6]N(&9I;FES:&5D*"D*("`@('L*
M("`@("`@("`O*B!.;W1H:6YG('1O(&1O+B`J+PH@("`@?0H*?0H*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]M:VES;V9S
M+G!H<```````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S`W`#$P-#$W
M,S8R-S<P`#`R,38T-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J($1R:79E<B!F;W(@=7-I;F<@;6MI
M<V]F<R!F;W(@8W)E871I;F<@25-/(&EM86=E<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`L
M=B`Q+C$N."XU(#(P,#8O,#$O,#$@,C$Z,C@Z-#,@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@0W)O;F]S>7,L($Q,0R`\:'1T<#HO+W=W
M=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'!A
M8VMA9V4@5D937TE33PH@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F-L87-S
M(%9&4U])4T]7<FET97)?;6MI<V]F<R!E>'1E;F1S(%9&4U])4T]7<FET97(@
M>PH*("`@(&9U;F-T:6]N('!R;V-E<W,H*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4F5A;$EN<'5T4W1R871E
M9WDN<&AP)SL*("`@("`@("`D:6YP=713=')A=&5G>2`]("961E-?25-/5W)I
M=&5R7U)E86Q);G!U=%-T<F%T96=Y.CIF86-T;W)Y*"1T:&ES+3Y?<V]U<F-E
M5F9S+"`D=&AI<RT^7W!A<F%M<ULG<V]U<F-E4F]O="==*3L*("`@("`@("!I
M9B`H:7-?82@D:6YP=713=')A=&5G>2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&EN<'5T4W1R871E9WD["B`@("`@("`@?0H*("`@
M("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E86Q/
M=71P=713=')A=&5G>2YP:'`G.PH@("`@("`@("1O=71P=713=')A=&5G>2`]
M("961E-?25-/5W)I=&5R7U)E86Q/=71P=713=')A=&5G>3HZ9F%C=&]R>2@D
M=&AI<RT^7W1A<F=E=%9F<RP@)'1H:7,M/E]P87)A;7-;)W1A<F=E=$9I;&4G
M72D["B`@("`@("`@:68@*&ES7V$H)&]U='!U=%-T<F%T96=Y+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;W5T<'5T4W1R871E9WD[
M"B`@("`@("`@?0H*("`@("`@("`D8VUD(#T@<W!R:6YT9B@G;6MI<V]F<R`M
M<75I970@+7(@+4H@+6\@)7,@)7,@/B]D978O;G5L;"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@97-C87!E<VAE;&QA<F<H)&]U='!U=%-T<F%T96=Y+3YG
M971296%L1FEL96YA;64H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@97-C
M87!E<VAE;&QA<F<H)&EN<'5T4W1R871E9WDM/F=E=%)E86Q0871H*"DI*3L*
M("`@("`@("`D<F5S(#T@<WES=&5M*"1C;60L("1E8RD["@H@("`@("`@("\J
M($-O=6QD(&)E(&$@;&]T(&]F('-P86-E('5S960N("!':79E(&)O=&@@82!C
M:&%N8V4@=&\@8VQE86X@=7`@979E;@H@("`@("`@("`J(&EF(&]N92!E<G)O
M<G,@;W5T+B`J+PH@("`@("`@("1F:6Y297,Q(#T@)&EN<'5T4W1R871E9WDM
M/F9I;FES:&5D*"D["B`@("`@("`@)&9I;E)E<S(@/2`D;W5T<'5T4W1R871E
M9WDM/F9I;FES:&5D*"D["B`@("`@("`@:68@*&ES7V$H)&9I;E)E<S$L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F:6Y297,Q.PH@
M("`@("`@('T*("`@("`@("!I9B`H:7-?82@D9FEN4F5S,BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;E)E<S(["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)')E<R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')U;B`G;6MI
M<V]F<R<N(BDI.PH@("`@("`@('T*("`@("`@("!I9B`H)&5C("$](#`I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB*2P@
M)&5C*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M
M:6YE(&EF('=E(&-A;B!U<V4@=&AI<R!D<FEV97(@=&\@;6%K92!I;6%G97,*
M("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R('=E(&-A;B!U<V4@=&AI<R!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<F%T
M96=Y079A:6QA8FQE*"D*("`@('L*("`@("`@("`O*B!#:&5C:R!I9B!W92!C
M86X@9FEN9"!A;F0@97AE8W5T92!T:&4@8&UK:7-O9G,G(&-O;6UA;F0N("HO
M"B`@("`@("`@)')E<R`]('-Y<W1E;2@B;6MI<V]F<R`M:&5L<"`^+V1E=B]N
M=6QL(#(^)C$B+"`D96,I.PH@("`@("`@(&EF("@D<F5S(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M(&EF("@D96,@(3T@,"D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H*````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'``````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`T-C<W`#$P-#$W,S8R-S<P`#`R,S8S,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*+RHJ"B`J($5N8V%P<W5L
M871E('-T<F%T96=I97,@9F]R(&=E='1I;F<@82!R96%L+"!L;V-A;"!F:6QE
M<WES=&5M('-T<G5C='5R92!F<F]M"B`J(&$@5D93+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`L=B`Q+C$N."XW(#(P,#8O,#$O,#$@,C$Z,C@Z-#,@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0W)O;F]S>7,L($Q,
M0R`\:'1T<#HO+W=W=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES
M+F-O;3X*("H@0'!A8VMA9V4@5D937TE33PH@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("HO"F-L87-S(%9&4U])4T]7<FET97)?4F5A;$EN<'5T4W1R871E9WD@
M>PH*("`@("\J*@H@("`@("H@02!R969E<F5N8V4@=&\@=&AE('-O=7)C92!6
M1E,@=V4@=V%N="!T;R!R96%D+@H@("`@("H*("`@("`J($!V87(@5D93"B`@
M("`@*B\*("`@('9A<B`D7W-O=7)C959F<R`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!4:&4@<F]O="!D:7)E8W1O<GD@=VET:&EN('1H92!S;W5R8V4@5D93
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M<V]U<F-E4F]O=#L*"B`@("!F=6YC=&EO;B!61E-?25-/5W)I=&5R7U)E86Q)
M;G!U=%-T<F%T96=Y*"8D<V]U<F-E5F9S+"`D<V]U<F-E4F]O="D*("`@('L*
M("`@("`@("`D=&AI<RT^7W-O=7)C959F<R`]("8D<V]U<F-E5F9S.PH@("`@
M("`@("1T:&ES+3Y?<V]U<F-E4F]O="`]("8D<V]U<F-E4F]O=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!A(')E86P@<&%T:"!T;R!T:&4@:6YP=70@
M=')E92X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J($!R971U<FX@
M;6EX960@("`@02!S=')I;F<@=VET:"!T:&4@<F5A;"!P871H+"!O<B!014%2
M7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E
M86Q0871H*"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*").;W0@:6UP;&5M96YT960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@26YD:6-A=&4@=V4@87)E(&9I;FES:&5D('=I=&@@=&AI<R!I;G!U="!S
M=')A=&5G>2X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J($!R971U
M<FX@;6EX960@("`@("`@($YU;&P@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6YI<VAE9"@I"B`@("!["B`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T(&EM<&QE;65N=&5D
M+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E8VED92!W:&EC:"!S=')A
M=&5G>2!T;R!U<V4@=&\@9V5T(&$@<F5A;"!&4R!A;F0@8W)E871E(&ET+@H@
M("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T("8D<V]U<F-E5F9S("`@("`@("!4:&4@5D93('=E('=A;G0@=&\@<F5A
M9"!F<F]M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V]U<F-E4F]O="`@("`@
M("`@5&AE(')O;W0@9&ER96-T;W)Y(&EN('1H870@5D93+@H@("`@("H@0')E
M='5R;B!O8FIE8W0@("!!(&-O;F-R971E('-T<F%T96=Y(&]R(%!%05)?17)R
M;W(@:68@;F\@<W1R871E9WD@:7,*("`@("`J("`@("`@("`@("`@("`@("`@
M879A:6QA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!F86-T;W)Y*"8D<V]U
M<F-E5F9S+"`D<V]U<F-E4F]O="D*("`@('L*("`@("`@("!I9B`H<W1R=&]L
M;W=E<BAG971?8VQA<W,H)'-O=7)C959F<RDI(#T]("=V9G-?9FEL92<I('L*
M("`@("`@("`@("`@)&UE=&AO9"`]("=D:7)E8W0G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1M971H;V0@/2`G8V]P>2<["B`@("`@("`@?0H*
M("`@("`@("!`:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]2
M96%L26YP=713=')A=&5G>2\G("X@)&UE=&AO9"`N"B`@("`@("`@("`@("`@
M("`@("`@("`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)U9&4U])4T]7<FET
M97)?4F5A;$EN<'5T4W1R871E9WE?)R`N("1M971H;V0["B`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!L;V%D('-T
M<F%T96=Y(%PB)7-<(BXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;65T:&]D*2D["B`@("`@("`@?0H*("`@("`@
M("`D<W1R871E9WD@/2`F;F5W("1C;&%S<R@D<V]U<F-E5F9S+"`D<V]U<F-E
M4F]O="D["B`@("`@("`@<F5T=7)N("1S=')A=&5G>3L*("`@('T*"GT*"@``
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`U,S4U`#$P-#$W,S8R-S<P`#`R-#`R,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RHJ
M"B`J($5N8V%P<W5L871E('-T<F%T96=I97,@9F]R(&%B:6QI='D@=&\@=W)I
M=&4@;W5T<'5T('1O(')E86P@9FEL92X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<"QV(#$N,2XX+C<@,C`P-B\P,2\P,2`R,3HR.#HT,R!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P
M.B\O=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@
M*B!`<&%C:V%G92!61E-?25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*
M8VQA<W,@5D937TE33U=R:71E<E]296%L3W5T<'5T4W1R871E9WD@>PH*("`@
M("\J*@H@("`@("H@5&AE(%9&4R!T;R!W:&EC:"!W92!W:6QL('=R:71E('1H
M92!F:6QE+@H@("`@("H*("`@("`J($!V87(@5D93"B`@("`@*B\*("`@('9A
M<B`D7W1A<F=E=%9F<SL*"B`@("`O*BH*("`@("`J(%=H97)E('1O('-T;W)E
M('1H92!F:6QE(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?=&%R9V5T1FEL93L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F
M)'1A<F=E=%9F<R`@("`@("`@5&AE(%9&4R!T;R!W:&EC:"!W92!W:6QL('=R
M:71E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)'1A<F=E=$9I;&4@("`@
M("`@(%1H92!P871H(&%N9"!N86UE(&]F(&9I;&4@=&\@=W)I=&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%9&4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T
M96=Y*"8D=&%R9V5T5F9S+"`D=&%R9V5T1FEL92D*("`@('L*("`@("`@("`D
M=&AI<RT^7W1A<F=E=%9F<R`]("8D=&%R9V5T5F9S.PH@("`@("`@("1T:&ES
M+3Y?=&%R9V5T1FEL92`]("1T87)G971&:6QE.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5L96-T(&%N9"!C<F5A=&4@82!C;VYC<F5T92!S=')A=&5G>2!F
M;W(@=7-I;F<@82!R96%L(&]U='!U="!F:6QE+@H@("`@("H*("`@("`J($!P
M87)A;2!O8FIE8W0@)B1T87)G97169G,@("`@("`@(%1H92!61E,@=&\@=VAI
M8V@@=V4@=VEL;"!W<FET92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E<W5L="X*("`@("`J($!P87)A;2!S=')I;F<@
M)'1A<F=E=$9I;&4@("`@("`@(%1H92!P871H(&%N9"!F:6QE;F%M92!O9B!T
M:&4@=&%R9V5T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F:6QE('=I=&AI;B!T:&4@5D93+@H@("`@("H@0')E='5R;B!O8FIE
M8W0@("!!(&-O;F-R971E(&]U='!U="!S=')A=&5G>2!O8FIE8W0@;W(@4$5!
M4E]%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@F)'1A<F=E=%9F<RP@)'1A
M<F=E=$9I;&4I"B`@("!["B`@("`@("`@:68@*'-T<G1O;&]W97(H9V5T7V-L
M87-S*"1T87)G97169G,I*2`]/2`G=F9S7V9I;&4G*2!["B`@("`@("`@("`@
M("1M971H;V0@/2`G9&ER96-T)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;65T:&]D(#T@)V-O<'DG.PH@("`@("`@('T*"B`@("`@("`@:6YC
M;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]296%L3W5T<'5T4W1R
M871E9WDO)R`N("1M971H;V0@+@H@("`@("`@("`@("`@("`@("`@("`@)RYP
M:'`G.PH@("`@("`@("1C;&%S<R`]("=61E-?25-/5W)I=&5R7U)E86Q/=71P
M=713=')A=&5G>5\G("X@)&UE=&AO9#L*("`@("`@("!I9B`H(6-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E
M<UPB+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1M971H;V0I*3L*("`@("`@("!]"@H@("`@("`@("1S=')A=&5G
M>2`]("9N97<@)&-L87-S*"1T87)G97169G,L("1T87)G971&:6QE*3L*("`@
M("`@("!R971U<FX@)'-T<F%T96=Y.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T(&$@<F5A;"!F:6QE<WES=&5M(&9I;&5N86UE('=E(&-A;B!W<FET92!T
M;RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J($!R971U<FX@<W1R
M:6YG("`@5&AE(&9I;&5N86UE(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@('L*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@:6UP;&5M
M96YT960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@26YD:6-A=&4@=&AA
M="!W92=R92!D;VYE('=R:71I;F<@=&\@=&AE(')E86P@9FEL92X*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J($!R971U<FX@;6EX960@("`@3G5L
M;"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9I;FES:&5D*"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*").;W0@:6UP;&5M96YT960N(BDI.PH@("`@?0H*?0H*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O3&ES=$ET96TN
M<&AP````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0U
M-38`,3`T,3<S-C(W-S``,#(P,3`Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!!;B!I=&5M(')E='5R
M;F5D(&9R;VT@82!F;VQD97(@;&ES="X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5D93+U9&4R],:7-T271E;2YP:'`L=B`Q+C$Q+C$P+C8@,C`P-B\P,2\P
M,2`R,3HR.#HT,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!*;VX@5V]O9"`\:F]N0&IE;&QY8F]B+F-O+G5K/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F]N(%=O;V0@/&IO;D!J96QL>6)O8BYC;RYU:SX*
M("H@0'!A8VMA9V4@5D93"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B\*8VQA
M<W,@5D937TQI<W1)=&5M('L*"B`@("`O*BH*("`@("`J(%9&4R!P871H"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<&%T
M:#L*"B`@("`O*BH*("`@("`J($9I;&5N86UE"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;F%M93L*"B`@("`O*BH*("`@
M("`J($9I;&4@<&5R;6ES<VEO;G,@*"IN:7@@9F]R;6%T.B!D<G=X<G=X<G=X
M*0H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W!E<FUS.PH*("`@("\J*@H@("`@("H@3W=N97(@=7-E<@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V]W;F5R.PH*("`@
M("\J*@H@("`@("H@3W=N97(@9W)O=7`*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]G<F]U<#L*"B`@("`O*BH*("`@("`J
M(%-I>F4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?<VEZ93L*"B`@("`O*BH*("`@("`J($QA<W0@;6]D:69I960@9&%T
M92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]D871E.PH*("`@("\J*@H@("`@("H@5'EP90H@("`@("H@("`N*B`@("`@
M("TM("!&:6QE(&5X=&5N<VEO;@H@("`@("H@("`J*FYO;F4@("TM("!5;G)E
M8V]G;FEZ960@='EP90H@("`@("H@("`J*G-Y;2`@("TM("!3>6UL:6YK"B`@
M("`@*B`@("HJ9&ER("`@+2T@($1I<F5C=&]R>0H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1Y<&4["@H@("`@+RHJ"B`@
M("`@*B!4>7!E(&]F('1A<F=E="!I9B!T>7!E(&ES("<J*G-Y;2<N"B`@("`@
M*B!.0BX@3F]T(&%L;"!B86-K96YD<R!A<F4@8V%P86)L92!O9B!D:7-T:6YG
M=6ES:&EN9R!A;&P@;V8@=&AE<V4N"B`@("`@*B`@("XJ("`@("`@("`M+2`@
M1FEL92!E>'1E;G-I;VX*("`@("`J("`@*BIN;VYE("`@("TM("!5;G)E8V]G
M;FEZ960@='EP90H@("`@("H@("`J*G-Y;2`@("`@+2T@(%-Y;6QI;FL@=&\@
M82!S>6UL:6YK"B`@("`@*B`@("HJ9&ER("`@("`M+2`@1&ER96-T;W)Y"B`@
M("`@*B`@("HJ8G)O:V5N("`M+2`@5&%R9V5T(&YO="!F;W5N9"`M(&)R;VME
M;B!L:6YK"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?;&EN:W1Y<&4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@
M("`@("H*("`@("`J(%)E<75I<F5S('1H92!P871H('1O('1H92!F:6QE+"!A
M;F0@:70G<R!A<G)A>2!O9B!P<F]P97)T:65S+`H@("`@("H@<F5T=7)N960@
M9G)O;2!A('-T86YD87)D(%9&4SHZ;&ES=$9O;&1E<B@I(&-A;&PN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@(%1H92!P871H('1O
M('1H92!F:6QE+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:6QE07)R87D@($%N
M(&%R<F%Y(&]F(&9I;&4@<')O<&5R=&EE<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@5D937TQI<W1)=&5M*"1P871H+"`D9FEL94%R<F%Y*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<&%T:"`]("1P871H("X@)R\G("X@)&9I;&5!<G)A>5LG
M;F%M92==.PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1F:6QE07)R87E;)VYA
M;64G73L*("`@("`@("`D=&AI<RT^7V1I<FYA;64@/2`D<&%T:#L*("`@("`@
M("`D=&AI<RT^7W!E<FUS(#T@)&9I;&5!<G)A>5LG<&5R;7,G73L*("`@("`@
M("`D=&AI<RT^7V]W;F5R(#T@)&9I;&5!<G)A>5LG;W=N97(G73L*("`@("`@
M("`D=&AI<RT^7V=R;W5P(#T@)&9I;&5!<G)A>5LG9W)O=7`G73L*("`@("`@
M("`D=&AI<RT^7W-I>F4@/2`D9FEL94%R<F%Y6R=S:7IE)UT["B`@("`@("`@
M)'1H:7,M/E]D871E(#T@)&9I;&5!<G)A>5LG9&%T92==.PH@("`@("`@("1T
M:&ES+3Y?='EP92`]("1F:6QE07)R87E;)W1Y<&4G73L*("`@("`@("`D=&AI
M<RT^7VQI;FMT>7!E(#T@)&9I;&5!<G)A>5LG;&EN:W1Y<&4G73L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]6
M1E,O9FEL92YP:'``````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P-38R-S,`,3`T,3<S-C(W-S``,#$W,C<Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!6
M1E,@:6UP;&5M96YT871I;VX@9F]R(&$@<W1A;F1A<F0@9FEL97-Y<W1E;2X*
M("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=V9G-R;V]T
M)R`@5&AE(')O;W0@<&%T:#PO<')E/@H@*@H@*B!.;W1E.B!4:&4@=7-E<B!T
M:&%T('EO=7(@=V5B<V5R=F5R(')U;G,@87,@*&-O;6UO;FQY("=N;V)O9'DG
M+`H@*B`G87!A8VAE)RP@;W(@)W=W=RUD871A)RD@35535"!H879E(')E860O
M=W)I=&4@<&5R;6ES<VEO;B!T;R!T:&4*("H@9&ER96-T;W)Y('EO=2!S<&5C
M:69Y(&%S('1H92`G=F9S<F]O="<N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`L=B`Q+C8S+C0N,3@@,C`P-B\P,R\R-"`Q-CHT
M,3HT."!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@*("H@0'-I;F-E("`@
M2&]R9&4@,BXR"B`J($!P86-K86=E(%9&4PH@*B\*8VQA<W,@5D937V9I;&4@
M97AT96YD<R!61E,@>PH*("`@("\J*@H@("`@("H@3&ES="!O9B!P97)M:7-S
M:6]N<R!A;F0@:68@=&AE>2!C86X@8F4@8VAA;F=E9"!I;B!T:&ES(%9&4PH@
M("`@("H@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W!E<FUI<W-I;VYS(#T@87)R87DH"B`@("`@("`@)V]W
M;F5R)R`]/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@)W=R:71E)R`]/B!T<G5E
M+"`G97AE8W5T92<@/3X@=')U92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A
M>2@G<F5A9"<@/3X@=')U92P@)W=R:71E)R`]/B!T<G5E+"`G97AE8W5T92<@
M/3X@=')U92DL"B`@("`@("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@
M=')U92P@)W=R:71E)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@=')U92D*("`@
M("D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($9I;&5S>7-T
M96T@8F%S960@5D93(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A
M;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!61E-?9FEL92@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!P87)E;G0Z.E9&4R@D<&%R86US
M*3L*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O
M="==*2D@>PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1T:&ES+3Y?<&%R86US
M6R=V9G-R;V]T)UTL("TQ*2`]/2`G+R<@?'P*("`@("`@("`@("`@("`@('-U
M8G-T<B@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==+"`M,2D@/3T@)UQ<)RD@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72`]
M('-U8G-T<B@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==+"`P+"!S=')L96XH
M)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72D@+2`Q*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T
M:&4@9FEL97-I>F4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!R971R
M:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@5&AE(&9I;&4@
M<VEZ92X*("`@("`J+PH@("`@9G5N8W1I;VX@<VEZ92@D<&%T:"P@)&YA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N(&9I;&5S:7IE*"1T:&ES+3Y?9V5T3F%T
M:79E4&%T:"@D<&%T:"P@)&YA;64I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E=')I979E(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE('1O('1H92!F:6QE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O
M(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M9FEL92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1P871H+"`D
M;F%M92D*("`@('L*("`@("`@("`D9FEL92`]("1T:&ES+3Y?9V5T3F%T:79E
M4&%T:"@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@)&1A=&$@
M/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@
M("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FEL97-I>F4@/2!F:6QE<VEZ
M92@D9FEL92D["B`@("`@("`@("`@(&EF("@D9FEL97-I>F4@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1D871A(#T@9G)E860H)&9P+"`D9FEL97-I
M>F4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T<FEE=F5S(&$@<&%R="!O9B!A(&9I;&4@9G)O;2!T:&4@
M5D93+B!087)T:6-U;&%R;'D@=7-E9G5L('=H96X*("`@("`J(')E861I;F<@
M;&%R9V4@9FEL97,@=VAI8V@@=V]U;&0@97AC965D('1H92!02%`@;65M;W)Y
M(&QI;6ET<R!I9B!T:&5Y"B`@("`@*B!W97)E('-T;W)E9"!I;B!A('-T<FEN
M9RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D<&%T:"`@("`@("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;F%M92`@("`@("!4:&4@9FEL
M96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;V9F
M<V5T("`@("!4:&4@;V9F<V5T(&]F('1H92!P87)T+B`H5&AE(&YE=R!O9F9S
M970@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F4@
M<W1O<F5D(&EN(&AE<F4I+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QE;F=T
M:"`@("`@5&AE(&QE;F=T:"!O9B!T:&4@<&%R="X@268@=&AE(&QE;F=T:"`]
M("TQ+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('=H
M;VQE('!A<G0@869T97(@=&AE(&]F9G-E="!I<R!R971R:65V960N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!M;W)E(&)Y=&5S(&%R
M92!G:79E;B!A<R!E>&ES=',@869T97(@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!G:79E;B!O9F9S970N($]N;'D@=&AE(&%V86EL
M86)L92!B>71E<R!A<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E860N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F5M86EN:6YG("!4
M:&4@8GET97,@=&AA="!A<F4@;&5F="P@869T97(@=&AE('!A<G0@=&AA=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7,@<F5T<FEE=F5D
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%1H92!F:6QE(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861">71E4F%N9V4H)'!A=&@L("1N
M86UE+"`F)&]F9G-E="P@)&QE;F=T:"`]("TQ+"`F)')E;6%I;FEN9RD*("`@
M('L*("`@("`@("!I9B`H)&]F9G-E="`\(#`I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")7<F]N9R!O9F9S970@
M)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(I+"`D;V9F<V5T*2D["B`@
M("`@("`@?0H*("`@("`@("`O+R!#86QC=6QA=&4@:&]W(&UA;GD@8GET97,@
M35535"!B92!R96%D+"!S;R!T:&4@<F5M86EN9VEN9PH@("`@("`@("\O(&)Y
M=&5S(&%N9"!T:&4@;F5W(&]F9G-E="!C86X@8F4@8V%L8W5L871E9"!C;W)R
M96-T;'DN"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H
M)'!A=&@L("1N86UE*3L*("`@("`@("`D<VEZ92`](&9I;&5S:7IE("@D9FEL
M92D["B`@("`@("`@:68@*"1L96YG=&@@/3T@+3$@?'P@*"@D;&5N9W1H("L@
M)&]F9G-E="D@/B`D<VEZ92DI('L*("`@("`@("`@("`@)&QE;F=T:"`]("1S
M:7IE("T@)&]F9G-E=#L*("`@("`@("!]"B`@("`@("`@:68@*"1R96UA:6YI
M;F<@/"`P*2!["B`@("`@("`@("`@("1R96UA:6YI;F<@/2`P.PH@("`@("`@
M('T*"B`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@
M("!I9B`H(21F<"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB*2D["B`@("`@("`@
M?0H@("`@("`@(&9S965K*"1F<"P@)&]F9G-E="D["B`@("`@("`@)&1A=&$@
M/2!F<F5A9"@D9G`L("1L96YG=&@I.PH@("`@("`@("1O9F9S970@/2!F=&5L
M;"@D9G`I.PH@("`@("`@("1R96UA:6YI;F<@/2`D<VEZ92`M("1O9F9S970[
M"@H@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("!R971U<FX@)&1A=&$[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A(&9I;&4@:6X@=&AE(%9&
M4RP@=VET:"!T:&4@9&%T82!C;W!I960@9G)O;2!A('1E;7!O<F%R>0H@("`@
M("H@9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@
M("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S
M92X*("`@("`J($!P87)A;2!S=')I;F<@)'1M<$9I;&4@("`@("!4:&4@=&5M
M<&]R87)Y(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T82!T;R!B90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T;W)E9"X*("`@("`J($!P
M87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T
M92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA;64L
M("1T;7!&:6QE+"`D875T;V-R96%T92`]('1R=64I"B`@("!["B`@("`@("`@
M:68@*"%`:7-?9&ER*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"DI*2![
M"B`@("`@("`@("`@(&EF("@D875T;V-R96%T92D@>PH@("`@("`@("`@("`@
M("`@)')E<R`]("1T:&ES+3YA=71O8W)E871E4&%T:"@D<&%T:"D["B`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T85=R:71E*"=F:6QE)RP@)'1M<$9I
M;&4I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("`O
M+R!3:6YC92!W92!A;')E861Y(&AA=F4@=&AE(&1A=&$@:6X@82!F:6QE+"!D
M;VXG="!R96%D(&ET"B`@("`@("`@+R\@:6YT;R!02%`G<R!M96UO<GD@870@
M86QL("T@:G5S="!C;W!Y*"D@:70@=&\@=&AE(&YE=PH@("`@("`@("\O(&QO
M8V%T:6]N+B!792!L96%V92!I="!T;R!T:&4@8V%L;&5R('1O(&-L96%N('5P
M('1H90H@("`@("`@("\O('1E;7!O<F%R>2!F:6QE+"!S;R!W92!D;VXG="!U
M<V4@<F5N86UE*"DN"B`@("`@("`@:68@*$!C;W!Y*"1T;7!&:6QE+"`D=&AI
M<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB*2D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@36]V97,@82!F:6QE(&EN('1H92!D871A8F%S92!A
M;F0@=&AE(&9I;&4@<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!M;W9E*"1P871H+"`D;F%M92P@)&1E<W0I"B`@("!["B`@
M("`@("`@)&]R:6<@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N
M86UE*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G?%XG("X@<')E9U]Q=6]T
M92@D;W)I9RD@+B`G6R0O77PG+"`D9&5S="DI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N(&YO="!M;W9E(&9I;&4H<RD@
M+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+B(I*3L*("`@("`@("!]
M"@H@("`@("`@("1F:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S
M="P@9F%L<V4I.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I
M;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"%`<F5N86UE*"1O<FEG+"`D=&AI<RT^
M7V=E=$YA=&EV95!A=&@H)&1E<W0L("1N86UE*2DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;W!I97,@82!F:6QE('1H<F]U9V@@=&AE
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&5S="`@5&AE(&1E<W1I;F%T:6]N(&]F('1H92!F:6QE
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-O<'DH)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*
M("`@("`@("`D;W)I9R`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@
M)&YA;64I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@+B!P<F5G7W%U
M;W1E*"1O<FEG*2`N("=;)"]=?"<L("1D97-T*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86X@;F]T(&-O<'D@9FEL92AS
M*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE+B(I*3L*
M("`@("`@("!]"@H@("`@("`@("1F:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O
M;&1E<B@D9&5S="P@9F%L<V4I.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE0VAE
M8VL@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@
M/3T@)&YA;64I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(I*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%`8V]P>2@D;W)I9RP@
M)'1H:7,M/E]G971.871I=F50871H*"1D97-T+"`D;F%M92DI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@82!F:6QE(&EN('1H
M92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@
M:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I
M;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@
M("`@("!4:&4@9FEL92!D871A+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U
M=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@)&YA;64L("1D871A+"`D875T
M;V-R96%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%`:7-?9&ER*"1T
M:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"DI*2!["B`@("`@("`@("`@(&EF
M("@D875T;V-R96%T92D@>PH@("`@("`@("`@("`@("`@)')E<R`]("1T:&ES
M+3YA=71O8W)E871E4&%T:"@D<&%T:"D["B`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(I*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@5')E870@86X@871T
M96UP="!T;R!W<FET92!A;B!E;7!T>2!F:6QE(&%S(&$@=&]U8V@H*2!C86QL
M+`H@("`@("`@("\O('-I;F-E(&]T:&5R=VES92!T:&4@9FEL92!W:6QL(&YO
M="!B92!C<F5A=&5D(&%T(&%L;"X*("`@("`@("!I9B`H(7-T<FQE;B@D9&%T
M82DI('L*("`@("`@("`@("`@:68@*$!T;W5C:"@D=&AI<RT^7V=E=$YA=&EV
M95!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92XB*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%7<FET92@G<W1R:6YG
M)RP@)&1A=&$I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@
M("`@("`O+R!/=&AE<G=I<V4@=V4@9V\@86AE860@86YD('1R>2!T;R!W<FET
M92!O=70@=&AE(&9I;&4N"B`@("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES+3Y?
M9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I+"`G=R<I.PH@("`@("`@(&EF
M("@A)&9P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(I*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A0&9W<FET92@D9G`L("1D871A*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T
M92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE*"1P871H+"`D;F%M92D*("`@('L*
M("`@("`@("`D<F5S(#T@)'1H:7,M/E]C:&5C:U%U;W1A1&5L971E*"1P871H
M+"`D;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@
M("`@(&EF("@A0'5N;&EN:R@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L
M("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($1E;&5T92!A(&9O;&1E<B!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE('!A=&@@=&\@9&5L971E
M('1H92!F;VQD97(@9G)O;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M("`@("`@(%1H92!F;VQD97)N86UE('1O('5S92X*("`@("`J($!P87)A;2!B
M;V]L96%N("1R96-U<G-I=F4@($9O<F-E(&$@<F5C=7)S:79E(&1E;&5T93\*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1E;&5T949O;&1E<B@D<&%T:"P@)&YA;64L("1R96-U<G-I
M=F4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)')E8W5R<VEV92D@>PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F5M<'1Y1F]L9&5R*"1P871H
M("X@)R\G("X@)&YA;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'!A=&@@+B`G+R<@+B`D
M;F%M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1L:7-T+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&QI<W0["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&-O=6YT*"1L:7-T*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%T:"`N("<O)R`N("1N86UE*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("@A0')M9&ER*"1T:&ES+3Y?9V5T3F%T
M:79E4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDN(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@9F]L9&5R(&]N('1H92!6
M1E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M=&@@=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!F;VQD97)N86UE('1O('5S92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C<F5A=&5&;VQD97(H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(&EF
M("@A0&UK9&ER*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(BDI.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&5C:R!I9B!A(&=I=F5N('!A=&AN86UE(&ES(&$@9F]L9&5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('1H92!F
M;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL92]F
M;VQD97(@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@:70@:7,@82!F;VQD97(L(&9A;'-E(&]T:&5R=VES92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:7-&;VQD97(H)'!A=&@L("1N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B!`:7-?9&ER*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D
M<&%T:"P@)&YA;64I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG97,@
M<&5R;6ES<VEO;G,@9F]R(&%N(&ET96T@:6X@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@
M9&ER96-T;W)Y(&]F('1H92!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@("`@("`@(%1H92!N86UE(&]F('1H92!I=&5M+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'!E<FUI<W-I;VX@(%1H92!O8W1A;"!V86QU92!O9B!T
M:&4@;F5W('!E<FUI<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAA;F=E4&5R;6ES<VEO
M;G,H)'!A=&@L("1N86UE+"`D<&5R;6ES<VEO;BD*("`@('L*("`@("`@("!I
M9B`H(4!C:&UO9"@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE
M*2P@)'!E<FUI<W-I;VXI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB*2P@)'!A=&@L("1N86UE*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!A(&QI<W0@;V8@=&AE(&-O;G1E;G1S(&]F(&$@9F]L
M9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@
M5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2!M:7AE
M9"`D9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@=&\@9FEL=&5R(&9I;&4O9&ER
M;F%M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@4VAO
M=R!D;W1F:6QE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@
M4VAO=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($9I;&4@;&ES="!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&ES=$9O;&1E<B@D<&%T:"P@
M)&9I;'1E<B`](&YU;&PL("1D;W1F:6QE<R`]('1R=64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&ER;VYL>2`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1F:6QE<R`](&%R<F%Y*"D["B`@("`@("`@)'!A=&@@/2!I<W-E="@D<&%T
M:"D@/R`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@I(#H@)'1H:7,M/E]G
M971.871I=F50871H*"D["@H@("`@("`@(&EF("@A0&ES7V1I<B@D<&%T:"DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T
M(&$@9&ER96-T;W)Y(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`8VAD
M:7(H)'!A=&@I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB*2D["B`@
M("`@("`@?0H*("`@("`@("`D:&%N9&QE(#T@;W!E;F1I<B@D<&%T:"D["B`@
M("`@("`@=VAI;&4@*"@D96YT<GD@/2!R96%D9&ER*"1H86YD;&4I*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@+R\@1FEL=&5R(&]U="`G+B<@86YD("<N
M+B<@96YT<FEE<RX*("`@("`@("`@("`@:68@*"1E;G1R>2`]/2`G+B<@?'P@
M)&5N=')Y(#T]("<N+B<I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!&:6QT97(@;W5T(&1O=&9I
M;&5S(&EF('1H97D@87)E;B=T('=A;G1E9"X*("`@("`@("`@("`@:68@*"$D
M9&]T9FEL97,@)B8@<W5B<W1R*"1E;G1R>2P@,"P@,2D@/3T@)RXG*2!["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+R\@1FEL92!N86UE"B`@("`@("`@("`@("1F:6QE6R=N86UE)UT@
M/2`D96YT<GD["@H@("`@("`@("`@("`O+R!5;FEX('-T>6QE(&9I;&4@<&5R
M;6ES<VEO;G,*("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`D=&AI<RT^
M7V=E=%5N:7A097)M<RAF:6QE<&5R;7,H)&5N=')Y*2D["@H@("`@("`@("`@
M("`O+R!/=VYE<@H@("`@("`@("`@("`D9FEL95LG;W=N97(G72`](&9I;&5O
M=VYE<B@D96YT<GDI.PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"=P;W-I>%]G971P=W5I9"<I*2!["B`@("`@("`@("`@("`@("`D;W=N97(@
M/2!P;W-I>%]G971P=W5I9"@D9FEL95LG;W=N97(G72D["B`@("`@("`@("`@
M("`@("`D9FEL95LG;W=N97(G72`]("1O=VYE<ELG;F%M92==.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O+R!'<F]U<`H@("`@("`@("`@("`D9FEL
M95LG9W)O=7`G72`](&9I;&5G<F]U<"@D96YT<GDI.PH@("`@("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=P;W-I>%]G971G<F=I9"<I*2!["B`@("`@
M("`@("`@("`@("`D9W)O=7`@/2!P;W-I>%]G971G<F=I9"@D9FEL95LG9W)O
M=7`G72D["B`@("`@("`@("`@("`@("`D9FEL95LG9W)O=7`G72`]("1G<F]U
M<%LG;F%M92==.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3:7IE
M"B`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2!F:6QE<VEZ92@D96YT<GDI
M.PH*("`@("`@("`@("`@+R\@1&%T90H@("`@("`@("`@("`D9FEL95LG9&%T
M92==(#T@9FEL96UT:6UE*"1E;G1R>2D["@H@("`@("`@("`@("`O+R!4>7!E
M"B`@("`@("`@("`@(&EF("A`:7-?9&ER*"1E;G1R>2D@)B8@(6ES7VQI;FLH
M)&5N=')Y*2D@>PH@("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G
M9"<@+B`D9FEL95LG<&5R;7,G73L*("`@("`@("`@("`@("`@("1F:6QE6R=T
M>7!E)UT@/2`G*BID:7(G.PH@("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G
M72`]("TQ.PH@("`@("`@("`@("!](&5L<V5I9B`H:7-?;&EN:R@D96YT<GDI
M*2!["B`@("`@("`@("`@("`@("`D9FEL95LG<&5R;7,G72`]("=L)R`N("1F
M:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]
M("<J*G-Y;2<["B`@("`@("`@("`@("`@("`D9FEL95LG;&EN:R==(#T@<F5A
M9&QI;FLH)&5N=')Y*3L*("`@("`@("`@("`@("`@("1F:6QE6R=L:6YK='EP
M92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("!I9B`H9FEL95]E>&ES
M=',H)&9I;&5;)VQI;FLG72DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?9&ER*"1F:6QE6R=L:6YK)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1F:6QE6R=L:6YK='EP92==(#T@)RHJ9&ER)SL*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H:7-?;&EN:R@D9FEL95LG;&EN:R==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG;&EN:W1Y<&4G72`]("<J
M*G-Y;2<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V9I;&4H
M)&9I;&5;)VQI;FLG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M="`](&5X<&QO9&4H)RXG+"`D9FEL95LG;&EN:R==*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"$H8V]U;G0H)&5X="D@/3T@,2!\?"`H)&5X=%LP
M72`]/3T@)R<@)B8@8V]U;G0H)&5X="D@/3T@,BDI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEL95LG;&EN:W1Y<&4G72`](%9&4SHZ<W1R
M=&]L;W=E<B@D97AT6V-O=6YT*"1E>'0I("T@,5TI.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG;&EN
M:W1Y<&4G72`]("<J*F)R;VME;B<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS96EF("AI<U]F:6QE*"1E;G1R>2DI('L*("`@("`@("`@
M("`@("`@("1F:6QE6R=P97)M<R==(#T@)RTG("X@)&9I;&5;)W!E<FUS)UT[
M"B`@("`@("`@("`@("`@("`D97AT(#T@97AP;&]D92@G+B<L("1E;G1R>2D[
M"@H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1E>'0I(#T](#$@?'P@*'-U
M8G-T<B@D9FEL95LG;F%M92==+"`P+"`Q*2`]/3T@)RXG("8F(&-O=6YT*"1E
M>'0I(#T](#(I*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G
M72`]("<J*FYO;F4G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@5D93.CIS=')T;VQO=V5R
M*"1E>'1;8V]U;G0H)&5X="D@+2`Q72D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9FEL95LG='EP
M92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("!I9B`H*&9I;&5P97)M
M<R@D96YT<GDI("8@,'A#,#`P*2`]/2`P>$,P,#`I('L*("`@("`@("`@("`@
M("`@("`@("`D9FEL95LG<&5R;7,G72`]("=S)R`N("1F:6QE6R=P97)M<R==
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"AF:6QE<&5R;7,H)&5N=')Y
M*2`F(#!X-C`P,"D@/3T@,'@V,#`P*2!["B`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)W!E<FUS)UT@/2`G8B<@+B`D9FEL95LG<&5R;7,G73L*("`@("`@
M("`@("`@("`@('T@96QS96EF("@H9FEL97!E<FUS*"1E;G1R>2D@)B`P>#(P
M,#`I(#T](#!X,C`P,"D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=P
M97)M<R==(#T@)V,G("X@)&9I;&5;)W!E<FUS)UT["B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H*&9I;&5P97)M<R@D96YT<GDI("8@,'@Q,#`P*2`]/2`P
M>#$P,#`I('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG<&5R;7,G72`]
M("=P)R`N("1F:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG<&5R;7,G72`]("<_)R`N
M("1F:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O+R!&:6QT97)I;F<N"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F:6QE6R=N86UE)UTI
M*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)&1I<F]N;'D@)B8@)&9I;&5;)W1Y<&4G72`A/3T@)RHJ9&ER)RD@>PH@("`@
M("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE<ULD9FEL
M95LG;F%M92==72`]("1F:6QE.PH@("`@("`@("`@("!U;G-E="@D9FEL92D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A('-O<G1E9"!L:7-T(&]F(&9O;&1E<G,@
M:6X@<W!E8VEF:65D(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R
M>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@0'!A<F%M(&UI>&5D("1F
M:6QT97(@("`@("`@($AA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A<V5D(&]N
M(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9F]L9&5R
M<R`@26YC;'5D92!D;W1F;VQD97)S/PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T
M1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9O;&1E
M<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN
M96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@
M("`@)&9O;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@("1F;VQD97)S6V1I<FYA
M;64H)'!A=&@I72`](&%R<F%Y*"=V86PG(#T^(&1I<FYA;64H)'!A=&@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A8F)R
M978G(#T^("<N+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VQA8F5L)R`]/B`G+BXG*3L*"B`@("`@("`@)&9O;&1E<DQI
M<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L;"P@)&1O=&9O;&1E
M<G,L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1F;VQD97),:7-T+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9F]L9&5R3&ES=#L*
M("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1F;VQD97),:7-T(&%S("1N
M86UE(#T^("1F:6QE<RD@>PH@("`@("`@("`@("`D9F]L9&5R<ULD;F%M95T@
M/2!A<G)A>2@G=F%L)R`]/B`D<&%T:"`N("<O)R`N("1F:6QE<ULG;F%M92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G86)B<F5V
M)R`]/B`D9FEL97-;)VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VQA8F5L)R`]/B`D<&%T:"`N("<O)R`N("1F:6QE<ULG
M;F%M92==*3L*("`@("`@("!]"@H@("`@("`@(&MS;W)T*"1F;VQD97)S*3L*
M"B`@("`@("`@<F5T=7)N("1F;VQD97)S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(%5N:7@@<W1Y;&4@<&5R;7,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E
M<FUS("!4:&4@<&5R;6ES<VEO;G,@=&\@<V5T+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!5;FEX('-T>6QE('!E<FUS+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T56YI>%!E<FUS*"1P97)M<RD*("`@('L*("`@("`@("`O
M+R!$971E<FUI;F4@<&5R;6ES<VEO;G,*("`@("`@("`D;W=N97);)W)E860G
M72`@("`]("@D<&5R;7,@)B`P,#0P,"D@/R`G<B<@.B`G+2<["B`@("`@("`@
M)&]W;F5R6R=W<FET92==("`@/2`H)'!E<FUS("8@,#`R,#`I(#\@)W<G(#H@
M)RTG.PH@("`@("`@("1O=VYE<ELG97AE8W5T92==(#T@*"1P97)M<R`F(#`P
M,3`P*2`_("=X)R`Z("<M)SL*("`@("`@("`D9W)O=7!;)W)E860G72`@("`]
M("@D<&5R;7,@)B`P,#`T,"D@/R`G<B<@.B`G+2<["B`@("`@("`@)&=R;W5P
M6R=W<FET92==("`@/2`H)'!E<FUS("8@,#`P,C`I(#\@)W<G(#H@)RTG.PH@
M("`@("`@("1G<F]U<%LG97AE8W5T92==(#T@*"1P97)M<R`F(#`P,#$P*2`_
M("=X)R`Z("<M)SL*("`@("`@("`D=V]R;&1;)W)E860G72`@("`]("@D<&5R
M;7,@)B`P,#`P-"D@/R`G<B<@.B`G+2<["B`@("`@("`@)'=O<FQD6R=W<FET
M92==("`@/2`H)'!E<FUS("8@,#`P,#(I(#\@)W<G(#H@)RTG.PH@("`@("`@
M("1W;W)L9%LG97AE8W5T92==(#T@*"1P97)M<R`F(#`P,#`Q*2`_("=X)R`Z
M("<M)SL*"B`@("`@("`@+R\@061J=7-T(&9O<B!354E$+"!31TE$(&%N9"!S
M=&EC:WD@8FET"B`@("`@("`@:68@*"1P97)M<R`F(#!X.#`P*2!["B`@("`@
M("`@("`@("1O=VYE<ELG97AE8W5T92==(#T@*"1O=VYE<ELG97AE8W5T92==
M(#T]("=X)RD@/R`G<R<@.B`G4R<["B`@("`@("`@?0H@("`@("`@(&EF("@D
M<&5R;7,@)B`P>#0P,"D@>PH@("`@("`@("`@("`D9W)O=7!;)V5X96-U=&4G
M72`]("@D9W)O=7!;)V5X96-U=&4G72`]/2`G>"<I(#\@)W,G(#H@)U,G.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'!E<FUS("8@,'@R,#`I('L*("`@("`@
M("`@("`@)'=O<FQD6R=E>&5C=71E)UT@/2`H)'=O<FQD6R=E>&5C=71E)UT@
M/3T@)W@G*2`_("=T)R`Z("=4)SL*("`@("`@("!]"@H@("`@("`@("1U;FEX
M4&5R;7,@/2`D;W=N97);)W)E860G72`N("1O=VYE<ELG=W)I=&4G72`N("1O
M=VYE<ELG97AE8W5T92==("X*("`@("`@("`@("`@("`@("`@("`@)&=R;W5P
M6R=R96%D)UT@+B`D9W)O=7!;)W=R:71E)UT@+B`D9W)O=7!;)V5X96-U=&4G
M72`N"B`@("`@("`@("`@("`@("`@("`@("1W;W)L9%LG<F5A9"==("X@)'=O
M<FQD6R=W<FET92==("X@)'=O<FQD6R=E>&5C=71E)UT["@H@("`@("`@(')E
M='5R;B`D=6YI>%!E<FUS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE
M(&$@9FEL92!O<B!F;VQD97(@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD('!A=&@@=&\@=&AE(&9I
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N86UE("!4:&4@;VQD(&9I
M;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<&%T:"`@5&AE(&YE
M=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W
M;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;64H)&]L
M9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I"B`@("!["B`@
M("`@("`@:68@*"%`:7-?9&ER*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;F5W
M<&%T:"DI*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1R97,@/2`D=&AI<RT^
M875T;V-R96%T95!A=&@H)&YE=W!A=&@I+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"%`<F5N86UE*"1T:&ES+3Y?9V5T3F%T:79E
M4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I+`H@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&YE=W!A=&@L("1N97=N86UE*2DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(I+"`D;VQD
M<&%T:"P@)&]L9&YA;64I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@9G5L;"!F:6QE
M;F%M92!O;B!T:&4@;F%T:79E(&9I;&5S>7-T96TL(&9R;VT@82!61E,*("`@
M("`J('!A=&@@86YD(&YA;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(%9&
M4R!F:6QE('!A=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M5D93(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@9G5L;"!N871I=F4@9FEL96YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971.871I=F50871H*"1P871H(#T@)R<L("1N86UE(#T@)R<I"B`@("![
M"B`@("`@("`@)&YA;64@/2!B87-E;F%M92@D;F%M92D["B`@("`@("`@:68@
M*"%E;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@)&YA;64@/2!S=')?<F5P
M;&%C92@G+BXG+"`G)RP@)&YA;64I.PH@("`@("`@("`@("!I9B`H<W5B<W1R
M*"1N86UE+"`P+"`Q*2`A/2`G+R<I('L*("`@("`@("`@("`@("`@("1N86UE
M(#T@)R\G("X@)&YA;64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@A96UP='DH)'!A=&@I*2!["B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A<F%M<ULG:&]M92==*2`F)@H@("`@("`@("`@("`@("`@
M<')E9U]M871C:"@G?%Y^+S\H+BHI)'PG+"`D<&%T:"P@)&UA=&-H97,I*2![
M"B`@("`@("`@("`@("`@("`D<&%T:"`]("1T:&ES+3Y?<&%R86US6R=H;VUE
M)UT@+B`G+R<@+B`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'!A=&@@/2!S=')?<F5P;&%C92@G+BXG+"`G)RP@)'!A=&@I.PH@
M("`@("`@("`@("!I9B`H<W5B<W1R*"1P871H+"`P+"`Q*2`]/2`G+R<I('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A<F%M<ULG=F9S<F]O
M="==("X@)'!A=&@@+B`D;F%M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==
M("X@)R\G("X@)'!A=&@@+B`D;F%M93L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A<F%M<ULG
M=F9S<F]O="==("X@)&YA;64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4W1U8B!T;R!C:&5C:R!I9B!W92!H879E(&$@=F%L:60@8V]N;F5C
M=&EO;BX@36%K97,@<W5R92!T:&%T"B`@("`@*B!T:&4@=F9S<F]O="!I<R!R
M96%D86)L92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&EF('9F<W)O;W0@:7,@<F5A
M9&%B;&4L(%!%05)?17)R;W(@:68@:70@:7-N)W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H*$!I<U]D:7(H
M)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72D@)B8*("`@("`@("`@("`@($!I
M<U]R96%D86)L92@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==*2D@?'P*("`@
M("`@("`@("`@0&UK9&ER*"1T:&ES+3Y?<&%R86US6R=V9G-R;V]T)UTI*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB*2D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ92!O9B!A(&9I
M;&4N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('1H92!F:6QE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE
M(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@<VEZ
M92!O9B!T:&4@9FEL92P@:6X@8GET97,L(&]R(%!%05)?17)R;W(@;VX*("`@
M("`J("`@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1FEL95-I>F4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@
M("1S:7IE(#T@0&9I;&5S:7IE*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T
M:"P@)&YA;64I*3L*("`@("`@("!I9B`H)'-I>F4@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(BDL("1P
M871H+"`D;F%M92DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-I>F4[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]61E,O9G1P+G!H<```````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-S4R-S4`,3`T,3<S-C(W-S``,#$W,30V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!61E,@:6UP;&5M96YT871I;VX@9F]R(&%N($944"!S97)V97(N"B`J
M"B`J(%)E<75I<F5D('9A;'5E<R!F;W(@)'!A<F%M<SH\<')E/@H@*B`@("`@
M("=U<V5R;F%M92<@("`@("`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9G1P('-E<G9E<BX*("H@("`@("`G<&%S<W=O<F0G
M("`@("`@(%1H92!P87-S=V]R9"!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@
M=&AE(&9T<"!S97)V97(N"B`J("`@("`@)VAO<W1S<&5C)R`@("`@("!4:&4@
M9G1P('-E<G9E<B!T;R!C;VYN96-T('1O+CPO<')E/@H@*@H@*B!/<'1I;VYA
M;"!V86QU97,@9F]R("1P87)A;7,Z/'!R93X*("H@("`@("`G;6%P;&]C86QI
M9',G("`@($EF('1R=64@86YD('1H92!03U-)6"!E>'1E;G-I;VX@:7,@879A
M:6QA8FQE+"!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@(&1R:79E<B!W
M:6QL(&UA<"!T:&4@=7-E<B!A;F0@9W)O=7`@241S(')E='5R;F5D(&9R;VT*
M("H@("`@("`@("`@("`@("`@("`@("`@('1H92!&5%`@<V5R=F5R('=I=&@@
M=&AE(&QO8V%L($E$<R!F<F]M('1H92!L;V-A;`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@<&%S<W=O<F0@9FEL92X@(%1H:7,@:7,@=7-E9G5L(&]N;'D@
M:68@=&AE($944"!S97)V97(*("H@("`@("`@("`@("`@("`@("`@("`@(&ES
M(')U;FYI;F<@;VX@;&]C86QH;W-T(&]R(&EF('1H92!L;V-A;"!U<V5R+V=R
M;W5P"B`J("`@("`@("`@("`@("`@("`@("`@("!)1',@87)E(&ED96YT:6-A
M;"!T;R!T:&4@<F5M;W1E($944"!S97)V97(N"B`J("`@("`@)W!A<W8G("`@
M("`@("`@("!)9B!T<G5E+"!C;VYN96-T:6]N('=I;&P@8F4@<V5T('1O('!A
M<W-I=F4@;6]D92X*("H@("`@("`G<&]R="<@("`@("`@("`@(%1H92!P;W)T
M('5S960@=&\@8V]N;F5C="!T;R!T:&4@9G1P('-E<G9E<B!I9B!O=&AE<@H@
M*B`@("`@("`@("`@("`@("`@("`@("`@=&AA;B`R,2X*("H@("`@("`G<W-L
M)R`@("`@("`@("`@($EF('1R=64L(&%N9"!02%`@:&%D(&)E96X@8V]M<&EL
M960@=VET:"!/<&5N4U-,"B`J("`@("`@("`@("`@("`@("`@("`@("!S=7!P
M;W)T+"!43%,@=')A;G-P;W)T+6QE=F5L(&5N8W)Y<'1I;VX@=VEL;"!B90H@
M*B`@("`@("`@("`@("`@("`@("`@("`@;F5G;W1I871E9"!W:71H('1H92!S
M97)V97(N"B`J("`@("`@)W1I;65O=70G("`@("`@("!)9B!D969I;F5D+"!U
M<V4@=&AI<R!V86QU92!A<R!T:&4@=&EM96]U="!F;W(@=&AE"B`J("`@("`@
M("`@("`@("`@("`@("`@("!S97)V97(N/"]P<F4^"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<"QV(#$N-S4N-"XQ."`R,#`V+S`S
M+S(T(#$V.C0Q.C0Y('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%9A<F=H97-E(#QM:6ME+G9A
M<F=H97-E0&%S8V5L;&%T96-H+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!-:6-H865L(%9A<F=H97-E(#QM:6ME+G9A<F=H97-E0&%S8V5L
M;&%T96-H+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E
M(%9&4PH@*B\*8VQA<W,@5D937V9T<"!E>'1E;F1S(%9&4R!["@H@("`@+RHJ
M"B`@("`@*B!,:7-T(&]F(&%D9&ET:6]N86P@8W)E9&5N=&EA;',@<F5Q=6ER
M960@9F]R('1H:7,@5D93(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]C<F5D96YT:6%L<R`](&%R<F%Y*"=U
M<V5R;F%M92<L("=P87-S=V]R9"<I.PH*("`@("\J*@H@("`@("H@3&ES="!O
M9B!P97)M:7-S:6]N<R!A;F0@:68@=&AE>2!C86X@8F4@8VAA;F=E9"!I;B!T
M:&ES(%9&4R!B86-K96YD+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?<&5R;6ES<VEO;G,@/2!A<G)A>2@*("`@("`@("`G
M;W=N97(G(#T^(&%R<F%Y*"=R96%D)R`]/B!T<G5E+"`G=W)I=&4G(#T^('1R
M=64L("=E>&5C=71E)R`]/B!T<G5E*2P*("`@("`@("`G9W)O=7`G(#T^(&%R
M<F%Y*"=R96%D)R`]/B!T<G5E+"`G=W)I=&4G(#T^('1R=64L("=E>&5C=71E
M)R`]/B!T<G5E*2P*("`@("`@("`G86QL)R`@(#T^(&%R<F%Y*"=R96%D)R`]
M/B!T<G5E+"`G=W)I=&4G(#T^('1R=64L("=E>&5C=71E)R`]/B!T<G5E*2D[
M"@H@("`@+RHJ"B`@("`@*B!687)I86)L92!H;VQD:6YG('1H92!C;VYN96-T
M:6]N('1O('1H92!F='`@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@<F5S
M;W5R8V4*("`@("`J+PH@("`@=F%R("1?<W1R96%M(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!,;V-A;"!C86-H92!A<G)A>2!F;W(@=7-E<B!)1',N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]U:61S
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($QO8V%L(&-A8VAE(&%R<F%Y
M(&9O<B!G<F]U<"!)1',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]G:61S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%)E=')I979E<R!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T;R!T:&4@9FEL
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T
M;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D<&%T:"P@
M)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D
M=&UP1FEL92`]("1T:&ES+3Y?9V5T5&5M<$9I;&4H*3L*("`@("`@("`D9F5T
M8V@@/2!`9G1P7V=E="@D=&AI<RT^7W-T<F5A;2P@)'1M<$9I;&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9710871H*"1P871H+"`D
M;F%M92DL($944%]"24Y!4EDI.PH@("`@("`@(&EF("@D9F5T8V@@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(I+"`D
M=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*"B`@
M("`@("`@)'-I>F4@/2!F:6QE<VEZ92@D=&UP1FEL92D["B`@("`@("`@:68@
M*"1S:7IE(#T]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!]"@H@("`@("`@(&EF("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1M
M;V1E(#T@)W)B)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6]D
M92`]("=R)SL*("`@("`@("!]"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@)&1A=&$@
M/2!F:6QE7V=E=%]C;VYT96YT<R@D=&UP1FEL92D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&9P(#T@9F]P96XH)'1M<$9I;&4L("1M;V1E*3L*
M("`@("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L("1S:7IE*3L*("`@("`@
M("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H@("`@("`@('5N;&EN:R@D
M=&UP1FEL92D["@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-T;W)E<R!A(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S
M=')I;F<@)'1M<$9I;&4@("`@("!4:&4@=&5M<&]R87)Y(&9I;&4@8V]N=&%I
M;FEN9R!T:&4@9&%T82!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)E('-T;W)E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O
M8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA;64L("1T;7!&:6QE+"`D875T;V-R
M96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C
M;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@
M("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T85=R:71E*"=F:6QE)RP@
M)'1M<$9I;&4I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(4!F='!?<'5T*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E
M=%!A=&@H)'!A=&@L("1N86UE*2P@)'1M<$9I;&4L($944%]"24Y!4EDI*2![
M"B`@("`@("`@("`@(&EF("@D875T;V-R96%T92D@>PH@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3YA=71O8W)E871E4&%T:"@D<&%T:"D["B`@
M("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(4!F='!?<'5T*"1T
M:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2P@
M)'1M<$9I;&4L($944%]"24Y!4EDI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A
M=&@L("1N86UE*2DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB
M+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&9I;&4@:6X@=&AE(%9&4R!F<F]M
M(')A=R!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL96YA;64@=&\@
M=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@("`@(%1H92!F
M:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@
M075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=W)I=&5$871A*"1P871H+"`D;F%M92P@)&1A=&$L("1A=71O8W)E871E(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T
M85=R:71E*"=S=')I;F<G+"`D9&%T82D["B`@("`@("`@:68@*&ES7V$H)')E
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*
M("`@("`@("!]"@H@("`@("`@("1T;7!&:6QE(#T@)'1H:7,M/E]G971496UP
M1FEL92@I.PH@("`@("`@("1F<"`](&9O<&5N*"1T;7!&:6QE+"`G=V(G*3L*
M("`@("`@("!F=W)I=&4H)&9P+"`D9&%T82D["B`@("`@("`@9F-L;W-E*"1F
M<"D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^=W)I=&4H)'!A=&@L("1N
M86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4I.PH@("`@("`@('5N;&EN:R@D
M=&UP1FEL92D["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$96QE=&5S(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@9&5L
M971E('1H92!F:6QE(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@9FEL96YA;64@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949I
M;&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^
M7V-H96-K475O=&%$96QE=&4H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O
M;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(4!F='!?9&5L971E*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^
M7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D
M;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ92!O9B!A(&9I;&4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@9FEL92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!S:7IE(&]F('1H92!F:6QE
M(&EN(&)Y=&5S(&]R(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@
M("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1FEL95-I
M>F4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"@D<VEZ92`]($!F='!?<VEZ92@D=&AI<RT^7W-T<F5A
M;2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*2`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB*2P@
M)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<VEZ93L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K<R!I9B!A(&=I=F5N(&ET96T@:7,@82!F;VQD97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A<F5N="!F;VQD97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@:71E;2!N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!I="!I<R!A(&9O
M;&1E<BP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I
M<T9O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D
M=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@9F%L<V4["B`@("`@("`@)&]L9&1I
M<B`]("1T:&ES+3YG971#=7)R96YT1&ER96-T;W)Y*"D["@H@("`@("`@("\J
M(%-E92!I9B!W92!C86X@8VAA;F=E('1O('1H92!G:79E;B!P871H+B`J+PH@
M("`@("`@(&EF("A`9G1P7V-H9&ER*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^
M7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@)')E<W5L
M="`]('1R=64["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E=%!A=&@H
M)&]L9&1I<BD["@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A(&9O;&1E<B!F<F]M('1H92!61E,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE('!A
M<F5N="!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@
M("!4:&4@;F%M92!O9B!T:&4@9F]L9&5R('1O(&1E;&5T92X*("`@("`J($!P
M87)A;2!B;V]L96%N("1R96-U<G-I=F4@($9O<F-E(&$@<F5C=7)S:79E(&1E
M;&5T93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD97(H)'!A=&@L("1N86UE+"`D
M<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI
M<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@
M?0H*("`@("`@("`D:7-$:7(@/2!F86QS93L*("`@("`@("`D9&ER0VAE8VL@
M/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"D["B`@("`@("`@9F]R96%C:"`H
M)&1I<D-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG
M;F%M92==(#T]("1N86UE("8F("1F:6QE6R=T>7!E)UT@/3T@)RHJ9&ER)RD@
M>PH@("`@("`@("`@("`@("`@)&ES1&ER(#T@=')U93L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&ES1&ER*2!["B`@("`@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^
M;&ES=$9O;&1E<B@D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1F:6QE7VQI<W0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D9FEL95]L:7-T.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9B`H8V]U;G0H)&9I;&5?;&ES="D@)B8@
M(21R96-U<G-I=F4I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!F;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&9I;&5;)W1Y<&4G72`]/2`G*BID:7(G*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YD96QE=&5&;VQD97(H
M)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTL
M("1R96-U<G-I=F4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T949I;&4H)'1H
M:7,M/E]G9710871H*"1P871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H(4!F='!?<FUD:7(H)'1H:7,M/E]S=')E86TL
M("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H(4!F='!?9&5L971E*"1T:&ES+3Y?<W1R
M96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H
M*"1P871H+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA
M;65S(&$@9FEL92!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&]L9&YA;64@(%1H92!O;&0@9FEL96YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@
M;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4
M:&4@;F5W(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@
M)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92D*("`@('L*("`@("`@("!I
M9B`H:7-?82@D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^875T;V-R96%T95!A
M=&@H)&YE=W!A=&@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`9G1P7W)E
M;F%M92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1O;&1P871H
M+"`D;VQD;F%M92DL("1T:&ES+3Y?9V5T4&%T:"@D;F5W<&%T:"P@)&YE=VYA
M;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(I
M+"`D=&AI<RT^7V=E=%!A=&@H)&]L9'!A=&@L("1O;&1N86UE*2DI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&5S(&$@9F]L9&5R(&]N('1H92!61E,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A<F5N="!F;VQD97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@;F5W
M(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5&;VQD97(H)'!A=&@L("1N86UE
M*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`
M9G1P7VUK9&ER*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A
M=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&%N9V5S('!E<FUI<W-I;VYS(&9O<B!A;B!I=&5M(&]N
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M("`@("`@5&AE('!A<F5N="!F;VQD97(@;V8@=&AE(&ET96TN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@;F%M92!O9B!T:&4@:71E
M;2X*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@(%1H92!P97)M
M:7-S:6]N('1O('-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&%N9V5097)M:7-S:6]N<R@D
M<&%T:"P@)&YA;64L("1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@("1C;VYN
M(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%`9G1P7W-I=&4H)'1H:7,M/E]S=')E
M86TL("=#2$U/1"`G("X@)'!E<FUI<W-I;VX@+B`G("<@+B`D=&AI<RT^7V=E
M=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710
M871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A;B!U
M;G-O<G1E9"!F:6QE(&QI<W0@;V8@=&AE('-P96-I9FEE9"!D:7)E8W1O<GDN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@
M<&%T:"!O9B!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M(&UI>&5D("1F
M:6QT97(@("`@("!3=')I;F<O:&%S:"!T;R!F:6QT97(@9FEL92]D:7)N86UE
M(&]N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9I;&5S("!3:&]W(&1O
M=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<F]N;'D@("!3:&]W
M(&]N;'D@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@1FEL92!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&ES=$9O;&1E<B@D<&%T:"`]
M("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1D:7)O;FQY(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H
M:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9FEL97,@/2!A<G)A>2@I
M.PH@("`@("`@("1T>7!E(#T@5D93.CIS=')T;VQO=V5R*$!F='!?<WES='EP
M92@D=&AI<RT^7W-T<F5A;2DI.PH@("`@("`@(&EF("@D='EP92`]/2`G=6YK
M;F]W;B<I('L*("`@("`@("`@("`@+R\@1V\@=VET:"!U;FEX+7-T>6QE(&QI
M<W1I;F=S(&)Y(&1E9F%U;'0N"B`@("`@("`@("`@("1T>7!E(#T@)W5N:7@G
M.PH@("`@("`@('T@96QS96EF("AS=')P;W,H)'1Y<&4L("=W:6XG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@)'1Y<&4@/2`G=VEN)SL*("`@("`@("!]
M(&5L<V5I9B`H<W1R<&]S*"1T>7!E+"`G;F5T=V%R92<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`D='EP92`]("=N971W87)E)SL*("`@("`@("!]"@H@
M("`@("`@("1O;&1D:7(@/2`D=&AI<RT^9V5T0W5R<F5N=$1I<F5C=&]R>2@I
M.PH@("`@("`@(&EF("@A96UP='DH)'!A=&@I*2!["B`@("`@("`@("`@("1R
M97,@/2`D=&AI<RT^7W-E=%!A=&@H)'!A=&@I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*"1T>7!E(#T]("=U;FEX)RD@>PH@("`@("`@("`@("`O+R!)9B!W92!D
M;VXG="!W86YT(&1O=&9I;&5S+"!792!C86X@<V%V92!W;W)K(&AE<F4@8GD@
M;F]T"B`@("`@("`@("`@("\O(&1O:6YG(&%N(&QS("UA(&%N9"!T:&5N(&YO
M="!D;VEN9R!T:&4@8VAE8VL@;&%T97(@*&)Y"B`@("`@("`@("`@("\O('-E
M='1I;F<@)&1O=&9I;&5S('1O('1R=64L('1H92!I9B!I<R!S:&]R="UC:7)C
M=6ET960I+@H@("`@("`@("`@("!I9B`H)&1O=&9I;&5S*2!["B`@("`@("`@
M("`@("`@("`D;&ES="`](&9T<%]R87=L:7-T*"1T:&ES+3Y?<W1R96%M+"`G
M+6%L)RD["B`@("`@("`@("`@("`@("`D9&]T9FEL97,@/2!T<G5E.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QI<W0@/2!F='!?
M<F%W;&ES="@D=&AI<RT^7W-T<F5A;2P@)RUL)RD["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("1L:7-T(#T@9G1P7W)A=VQI
M<W0H)'1H:7,M/E]S=')E86TL("<G*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-?87)R87DH)&QI<W0I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M;VQD9&ER*2D@>PH@("`@("`@("`@("`@("`@)')E<R`]("1T:&ES+3Y?<V5T
M4&%T:"@D;VQD9&ER*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)')E<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\J($EF
M("=M87!L;V-A;&ED<R<@:7,@<V5T+"!C:&5C:R!F;W(@=&AE(%!/4TE8(&5X
M=&5N<VEO;BX@*B\*("`@("`@("`D;6%P:61S(#T@9F%L<V4["B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG;6%P;&]C86QI9',G72D@)B8*
M("`@("`@("`@("`@97AT96YS:6]N7VQO861E9"@G<&]S:7@G*2D@>PH@("`@
M("`@("`@("`D;6%P:61S(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("1C
M=7)R=&EM92`]('1I;64H*3L*"B`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@
M)&QI;F4I('L*("`@("`@("`@("`@)&9I;&4@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D:71E;2`]('!R96=?<W!L:70H)R]<<RLO)RP@)&QI;F4I.PH@("`@
M("`@("`@("!I9B`H)'1Y<&4@/3T@)W5N:7@G('Q\("@D='EP92`]/2`G=VEN
M)R`F)B`A<')E9U]M871C:"@G?%QD7&0M7&1<9"U<9%QD?"<L("1I=&5M6S!=
M*2DI('L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D:71E;2D@/"`X('Q\
M('-U8G-T<B@D;&EN92P@,"P@-2D@/3T@)W1O=&%L)RD@>PH@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`D:71E;5LP73L*("`@("`@("`@
M("`@("`@(&EF("@D;6%P:61S*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W5I9'-;)&ET96U;,EU=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D96YT<GD@/2!P;W-I>%]G971P=W5I9"@D:71E;5LR
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=6ED<ULD:71E
M;5LR75T@/2`H96UP='DH)&5N=')Y*2D@/R`D:71E;5LR72`Z("1E;G1R>5LG
M;F%M92==.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG;W=N97(G72`]("1T:&ES+3Y?=6ED<ULD:71E;5LR75T[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W5I9'-;
M)&ET96U;,UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GD@
M/2!P;W-I>%]G971G<F=I9"@D:71E;5LS72D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=6ED<ULD:71E;5LS75T@/2`H96UP='DH)&5N=')Y
M*2D@/R`D:71E;5LS72`Z("1E;G1R>5LG;F%M92==.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D9FEL95LG9W)O=7`G72`]
M("1T:&ES+3Y?=6ED<ULD:71E;5LS75T["@H@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG;W=N97(G72`]("1I
M=&5M6S)=.PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=G<F]U<"==(#T@
M)&ET96U;,UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M9FEL95LG;F%M92==(#T@<W5B<W1R*"1L:6YE+"!S=')P;W,H)&QI;F4L('-P
M<FEN=&8H(B5S("4R<R`E-7,B+"`D:71E;5LU72P@)&ET96U;-ETL("1I=&5M
M6S==*2D@*R`Q,RD["@H@("`@("`@("`@("`@("`@+R\@1FEL=&5R(&]U="`G
M+B<@86YD("<N+B<@96YT<FEE<RX*("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7EPN7"X_7"\_)"\G+"`D9FEL95LG;F%M92==*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("\O($9I;'1E<B!O=70@9&]T9FEL97,@:68@=&AE
M>2!A<F5N)W0@=V%N=&5D+@H@("`@("`@("`@("`@("`@:68@*"$D9&]T9FEL
M97,@)B8@<W5B<W1R*"1F:6QE6R=N86UE)UTL(#`L(#$I(#T]("<N)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1P,2`]('-U8G-T<B@D9FEL95LG<&5R;7,G
M72P@,"P@,2D["B`@("`@("`@("`@("`@("!I9B`H)'`Q(#T]/2`G;"<I('L*
M("`@("`@("`@("`@("`@("`@("`D9FEL95LG;&EN:R==(#T@<W5B<W1R*"1F
M:6QE6R=N86UE)UTL('-T<G!O<R@D9FEL95LG;F%M92==+"`G+3XG*2`K(#,I
M.PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@/2!S=6)S='(H
M)&9I;&5;)VYA;64G72P@,"P@<W1R<&]S*"1F:6QE6R=N86UE)UTL("<M/B<I
M("T@,2D["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J
M*G-Y;2<["@H@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI<T9O;&1E
M<B@G)RP@)&9I;&5;)VQI;FLG72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@/2`G*BID:7(G.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)R\G+"`D9FEL95LG
M;&EN:R==*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE(#T@97AP;&]D92@G+B<L(&%R<F%Y7W!O
M<"@D<&%R=',I*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D;F%M92D@/3T@,2!\?"`H
M)&YA;65;,%T@/3T]("<G("8F(&-O=6YT*"1N86UE*2`]/2`R*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F:6QE6R=L:6YK='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@
M/2!61E,Z.G-T<G1O;&]W97(H87)R87E?<&]P*"1N86UE*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T@96QS96EF("@D<#$@/3T]("=D)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1F:6QE6R=T>7!E)UT@/2`G*BID:7(G.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F%M92`](&5X<&QO9&4H
M)RXG+"`D9FEL95LG;F%M92==*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M8V]U;G0H)&YA;64I(#T](#$@?'P@*'-U8G-T<B@D9FEL95LG;F%M92==+"`P
M+"`Q*2`]/3T@)RXG("8F(&-O=6YT*"1N86UE*2`]/2`R*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ;F]N92<["B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&9I;&5;)W1Y<&4G72`](%9&4SHZ<W1R=&]L;W=E<B@D;F%M95MC
M;W5N="@D;F%M92D@+2`Q72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1F:6QE6R=T>7!E
M)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=S
M:7IE)UT@/2`M,3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]("1I=&5M6S1=.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D:71E;5LW
M72P@)SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D9FEL
M95LG9&%T92==(#T@<W1R=&]T:6UE*"1I=&5M6S==("X@)SHP,"<@+B`D:71E
M;5LU72`N("<@)R`N("1I=&5M6S9=("X@)R`G("X@9&%T92@G62<L("1C=7)R
M=&EM92DI.PH@("`@("`@("`@("`@("`@("`@("\O($EF('1H92!F='`@<V5R
M=F5R(')E<&]R=',@82!F:6QE(&UO9&EF:6-A=&EO;B!D871E(&UO<F4*("`@
M("`@("`@("`@("`@("`@("`O+R!L97-S('1H86X@;VYE(&1A>2!I;B!T:&4@
M9G5T=7)E+"!D;VXG="!T<GD@=&\@<W5B=')A8W0*("`@("`@("`@("`@("`@
M("`@("`O+R!A('EE87(@9G)O;2!T:&4@9&%T92X@(%1H97)E(&ES(&YO('=A
M>2!T;R!K;F]W+"!F;W(*("`@("`@("`@("`@("`@("`@("`O+R!E>&%M<&QE
M+"!I9B!T:&4@5D93('-E<G9E<B!A;F0@=&AE(&9T<"!S97)V97(@<F5S:61E
M"B`@("`@("`@("`@("`@("`@("`@+R\@:6X@9&EF9F5R96YT('1I;65Z;VYE
M<RX@(%=E('-H;W5L9"!S:6UP;'D@<F5P;W)T('1O('1H90H@("`@("`@("`@
M("`@("`@("`@("\O("!U<V5R('=H870@=&AE($944"!S97)V97(@:7,@<F5T
M=7)N:6YG+@H@("`@("`@("`@("`@("`@("`@(&EF("@D9FEL95LG9&%T92==
M(#X@*"1C=7)R=&EM92`K(#@V-#`P*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG9&%T92==(#T@<W1R=&]T:6UE*"1I=&5M6S==("X@)SHP
M,"<@+B`D:71E;5LU72`N("<@)R`N("1I=&5M6S9=("X@)R`G("X@*&1A=&4H
M)UDG+"`D8W5R<G1I;64I("T@,2DI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)V1A=&4G72`]('-T<G1O=&EM92@G,#`Z,#`Z,#`G("X@)&ET96U;
M-5T@+B`G("<@+B`D:71E;5LV72`N("<@)R`N("1I=&5M6S==*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=N
M971W87)E)RD@>PH@("`@("`@("`@("`@("`@)&9I;&4@/2!!<G)A>2@I.PH@
M("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`D:71E;5LQ73L*("`@
M("`@("`@("`@("`@("1F:6QE6R=O=VYE<B==(#T@)&ET96U;,ET["B`@("`@
M("`@("`@("`@("!I9B`H)&ET96U;,%T@/3T@)V0G*2!["B`@("`@("`@("`@
M("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E
M)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1F:6QE6R=S:7IE)UT@/2`D:71E;5LS73L*("`@("`@("`@("`@("`@
M("1F:6QE6R=N86UE)UT@/2`D:71E;5LW73L*("`@("`@("`@("`@("`@("1I
M;F1E>"`](#@["B`@("`@("`@("`@("`@("!W:&EL92`H)&EN9&5X(#P@8V]U
M;G0H)&ET96TI*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)VYA;64G
M72`N/2`G("<@+B`D:71E;5LD:6YD97A=.PH@("`@("`@("`@("`@("`@("`@
M("1I;F1E>"LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+RH@2&%N9&QE(%=I;F1O=W,@1E10('-E
M<G9E<G,@<F5T=7)N:6YG($1/4RUS='EL92!F:6QE"B`@("`@("`@("`@("`@
M("`@*B!L:7-T:6YG<RX@*B\*("`@("`@("`@("`@("`@("1F:6QE6R=P97)M
M<R==(#T@)R<["B`@("`@("`@("`@("`@("`D9FEL95LG;W=N97(G72`]("<G
M.PH@("`@("`@("`@("`@("`@)&9I;&5;)V=R;W5P)UT@/2`G)SL*("`@("`@
M("`@("`@("`@("1F:6QE6R=N86UE)UT@/2`D:71E;5LS73L*("`@("`@("`@
M("`@("`@("1I;F1E>"`](#0["B`@("`@("`@("`@("`@("!W:&EL92`H)&EN
M9&5X(#P@8V]U;G0H)&ET96TI*2!["B`@("`@("`@("`@("`@("`@("`@)&9I
M;&5;)VYA;64G72`N/2`G("<@+B`D:71E;5LD:6YD97A=.PH@("`@("`@("`@
M("`@("`@("`@("1I;F1E>"LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&9I;&5;)V1A=&4G72`]('-T<G1O=&EM92@D:71E;5LP72`N
M("<@)R`N("1I=&5M6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D:71E;5LR
M72`]/2`G/$1)4CXG*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y
M<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W-I
M>F4G72`]("TQ.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@)&ET96U;,ET["B`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2!E>'!L;V1E*"<N)RP@)&9I;&5;)VYA;64G
M72D["B`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1N86UE*2`]/2`Q
M('Q\("AS=6)S='(H)&9I;&5;)VYA;64G72P@,"P@,2D@/3T]("<N)R`F)B!C
M;W5N="@D;F%M92D@/3T@,BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)W1Y<&4G72`]("<J*FYO;F4G.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E
M)UT@/2!61E,Z.G-T<G1O;&]W97(H)&YA;65;8V]U;G0H)&YA;64I("T@,5TI
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\@1FEL=&5R:6YG+@H@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]F:6QT97)-871C:"@D9FEL=&5R+"`D9FEL95LG
M;F%M92==*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1D:7)O;FQY("8F("1F:6QE6R=T>7!E)UT@(3T]("<J*F1I<B<I
M('L*("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL
M97-;)&9I;&5;)VYA;64G75T@/2`D9FEL93L*("`@("`@("`@("`@=6YS970H
M)&9I;&4I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1O;&1D:7(I
M*2!["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^7W-E=%!A=&@H)&]L9&1I
M<BD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L9&5R<R!I
M;B!T:&4@<W!E8VEF:65D(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C
M=&]R>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1F:6QT97(@("`@("`@($AA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A<V5D
M(&]N(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9F]L
M9&5R<R`@26YC;'5D92!D;W1F;VQD97)S/PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M:7-T1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9O
M;&1E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C
M;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@
M("`@("`@)&9O;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@("1F;VQD97(@/2!A
M<G)A>2@I.PH*("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3YL:7-T1F]L
M9&5R*"1P871H+"!N=6QL+"`D9&]T9F]L9&5R<RP@=')U92D["B`@("`@("`@
M:68@*&ES7V$H)&9O;&1E<DQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1F;VQD97),:7-T.PH@("`@("`@('T*"B`@("`@("`@
M)&9O;&1E<ELG=F%L)UT@/2`D=&AI<RT^7W!A<F5N=$1I<B@D<&%T:"D["B`@
M("`@("`@)&9O;&1E<ELG86)B<F5V)UT@/2`G+BXG.PH@("`@("`@("1F;VQD
M97);)VQA8F5L)UT@/2`G+BXG.PH*("`@("`@("`D9F]L9&5R<ULD9F]L9&5R
M6R=V86PG75T@/2`D9F]L9&5R.PH*("`@("`@("!F;W)E86-H("@D9F]L9&5R
M3&ES="!A<R`D9FEL97,I('L*("`@("`@("`@("`@)&9O;&1E<ELG=F%L)UT@
M/2`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1F:6QE<ULG;F%M92==*3L*("`@
M("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@/2`D9FEL97-;)VYA;64G73L*
M("`@("`@("`@("`@)&9O;&1E<ELG;&%B96PG72`]("1F;VQD97);)W9A;"==
M.PH*("`@("`@("`@("`@)&9O;&1E<G-;)&9O;&1E<ELG=F%L)UU=(#T@)&9O
M;&1E<CL*("`@("`@("!]"@H@("`@("`@(&MS;W)T*"1F;VQD97)S*3L*("`@
M("`@("!R971U<FX@)&9O;&1E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;W!I97,@82!F:6QE('1H<F]U9V@@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@=&AE(&]R:6=I
M;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M
M92!O9B!T:&4@;W)I9VEN86P@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&1E<W0@(%1H92!N86UE(&]F('1H92!D97-T:6YA=&EO;B!D:7)E8W1O<GDN
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]P>2@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@>PH@
M("`@("`@("1O<FEG(#T@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92D[
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>)R`N('!R96=?<75O=&4H)&]R
M:6<I("X@)ULD+UU\)RP@)&1E<W0I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(D-A;B!N;W0@8V]P>2!F:6QE*',I("T@<V]U
M<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N(BDI.PH@("`@("`@
M('T*"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@
M("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H96-K
M(#T@)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L(&YU;&PL('1R=64I.PH@("`@
M("`@(&EF("AI<U]A*"1F:6QE0VAE8VLL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1F:6QE0VAE8VL["B`@("`@("`@?0H@("`@("`@
M(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@("`@
M:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B)7,@86QR96%D
M>2!E>&ES=',N(BDL("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1I<T1I<B`](&9A
M;'-E.PH@("`@("`@("1D:7)#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1P
M871H+"!N=6QL+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)&1I<D-H96-K
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9&ER0VAE
M8VL["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1D:7)#:&5C:R!A<R`D
M9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M
M92`F)B`D9FEL95LG='EP92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@
M("`@("1I<T1I<B`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1I<T1I<BD@>PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T949O;&1E<B@D9&5S
M="P@)&YA;64I.PH*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI
M<RT^;&ES=$9O;&1E<B@D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2D[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE7VQI<W0@87,@)&9I;&4I('L*
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8V]P>2@D=&AI<RT^
M7V=E=%!A=&@H)'!A=&@L("1N86UE*2P@)&9I;&5;)VYA;64G72P@)'1H:7,M
M/E]G9710871H*"1D97-T+"`D;F%M92DI.PH@("`@("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1M<$9I
M;&4@/2`D=&AI<RT^7V=E=%1E;7!&:6QE*"D["B`@("`@("`@("`@("1F971C
M:"`]($!F='!?9V5T*"1T:&ES+3Y?<W1R96%M+"`D=&UP1FEL92P@)&]R:6<L
M($944%]"24Y!4EDI.PH@("`@("`@("`@("!I9B`H(21F971C:"D@>PH@("`@
M("`@("`@("`@("`@=6YL:6YK*"1T;7!&:6QE*3L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1F%I;&5D('1O
M(&-O<'D@9G)O;2!<(B5S7"(N(BDL("1O<FEG*2D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@A0&9T<%]P=70H)'1H:7,M/E]S=')E86TL("1T
M:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I+"`D=&UP1FEL92P@1E107T))
M3D%262DI('L*("`@("`@("`@("`@("`@('5N;&EN:R@D=&UP1FEL92D["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710
M871H*"1D97-T+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@=6YL:6YK*"1T;7!&:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V97,@82!F:6QE('1H
M<F]U9V@@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@5&AE('!A=&@@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@;W)I9VEN
M86P@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!D97-T
M:6YA=&EO;B!F:6QE(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V92@D<&%T:"P@)&YA
M;64L("1D97-T*0H@("`@>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G9710
M871H*"1P871H+"`D;F%M92D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>
M)R`N('!R96=?<75O=&4H)&]R:6<I("X@)ULD+UU\)RP@)&1E<W0I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;B!N;W0@
M;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92XB
M*2D["B`@("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C
M="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@
M("1F:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@;G5L;"P@
M=')U92D["B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C:R!A<R`D9FEL92D@
M>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*"(E<R!A;')E861Y(&5X:7-T<RXB*2P@)'1H:7,M/E]G9710871H*"1D
M97-T+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*"%`9G1P7W)E;F%M92@D=&AI<RT^7W-T<F5A;2P@)&]R:6<L("1T
M:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9A:6QE9"!T;R!M
M;W9E('1O(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1D97-T+"`D;F%M
M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!W;W)K:6YG(&1I
M<F5C=&]R>2!O;B!T:&4@1E10('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&-U<G)E;G0@=V]R:VEN9R!D:7)E8W1O<GDN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$-U<G)E;G1$:7)E8W1O<GDH*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A*"1C;VYN96-T960@/2`D=&AI<RT^7V-O;FYE
M8W0H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O
M;FYE8W1E9#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9T<%]P=V0H)'1H
M:7,M/E]S=')E86TI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E<R!T
M:&4@8W5R<F5N="!D:7)E8W1O<GD@;VX@=&AE('-E<G9E<BX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%T:"!T;R!C:&%N9V4@=&\N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!O<B!A(%!%05)?
M17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=%!A
M=&@H)'!A=&@I"B`@("!["B`@("`@("`@:68@*"%`9G1P7V-H9&ER*"1T:&ES
M+3Y?<W1R96%M+"`D<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+B(I+"`D<&%T:"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&9U;&P@<&%T:"!O
M9B!A;B!I=&5M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!D:7)E8W1O<GD@
M;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M;F%M92!O9B!T:&4@:71E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!&=6QL('!A=&@@=&\@=&AE(&9I;&4@=VAE;B`D<&%T:"!I<R!N;W0@96UP
M='D@86YD(&IU<W0*("`@("`J("`@("`@("`@("`@("`@("1N86UE('=H96X@
M;F]T('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%!A=&@H)'!A=&@L
M("1N86UE*0H@("`@>PH@("`@("`@(&EF("@D<&%T:"`A/3T@)R<I('L*("`@
M("`@("`@("`@<F5T=7)N("@D<&%T:"`N("<O)R`N("1N86UE*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("@D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!P87)E;G0@9&ER96-T;W)Y(&]F('1H92!S<&5C
M:69I960@<&%T:"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!G
M970@=&AE('!A<F5N="!O9BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('!A<F5N="!D:7)E8W1O<GD@*'-T<FEN9RD@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@("!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<F5N=$1I<B@D
M<&%T:"D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I
M.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1O
M;&1D:7(@/2`D=&AI<RT^9V5T0W5R<F5N=$1I<F5C=&]R>2@I.PH@("`@("`@
M($!F='!?8V1U<"@D=&AI<RT^7W-T<F5A;2D["@H@("`@("`@("1P87)E;G0@
M/2`D=&AI<RT^9V5T0W5R<F5N=$1I<F5C=&]R>2@I.PH@("`@("`@("1T:&ES
M+3Y?<V5T4&%T:"@D;VQD9&ER*3L*"B`@("`@("`@:68@*"$D<&%R96YT*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(BDI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1P87)E;G0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N;F5C=&EO;B!T;R!T:&4@1E10
M('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<W1R
M96%M(#T]/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H(65X=&5N<VEO;E]L
M;V%D960H)V9T<"<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA
M8FQE+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D=&AI<RT^7W!A<F%M<RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(I*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)')E<75I<F5D(#T@87)R87DH)VAO<W1S<&5C)RP@
M)W5S97)N86UE)RP@)W!A<W-W;W)D)RD["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1R97%U:7)E9"!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%R86US6R1V86Q=*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M(BDL("1V86PI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@9G1P('-E<G9E<B!U<VEN
M9R!T:&4@<W5P<&QI960@<&%R86UE=&5R<RX@*B\*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<W-L)UTI*2!["B`@("`@("`@("`@
M("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F='!?<W-L7V-O;FYE8W0G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1R96%M(#T@0&9T<%]S
M<VQ?8V]N;F5C="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P@)'1H:7,M
M/E]P87)A;7-;)W!O<G0G72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(I*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<W1R96%M(#T@0&9T<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H
M;W-T<W!E8R==+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<W1R96%M*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(I*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&-O;FYE8W1E9"`]($!F='!?;&]G:6XH)'1H:7,M/E]S
M=')E86TL("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==+"`D=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@("`@(&EF("@A)&-O;FYE8W1E
M9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D:7-C;VYN96-T*"D["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB*2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;
M)W!A<W8G72DI('L*("`@("`@("`@("`@("`@($!F='!?<&%S=B@D=&AI<RT^
M7W-T<F5A;2P@=')U92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W1I;65O=70G72DI('L*("`@("`@
M("`@("`@("`@(&9T<%]S971?;W!T:6]N*"1T:&ES+3Y?<W1R96%M+"!&5%!?
M5$E-14]55%]314,L("1T:&ES+3Y?<&%R86US6R=T:6UE;W5T)UTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE($944"!S
M97)V97(@86YD(&-L96%N<R!U<"!T:&4@8V]N;F5C=&EO;BX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I
M<V-O;FYE8W0H*0H@("`@>PH@("`@("`@($!F='!?<75I="@D=&AI<RT^7W-T
M<F5A;2D["B`@("`@("`@)'1H:7,M/E]S=')E86T@/2!F86QS93L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O
M0G)O=W-E<BYP:'``````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(V-C``,3`T,3<S-C(W-S``,#$W-S8T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!#;&%S
M<R!F;W(@<')O=FED:6YG(&$@9V5N97)I8R!522!F;W(@86YY(%9&4R!I;G-T
M86YC92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&4R]"<F]W<V5R
M+G!H<"QV(#$N."XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z-#(@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,BXR"B`J($!P86-K86=E(%9&4PH@*B\*8VQA<W,@5D937T)R;W=S
M97(@>PH*("`@("\J*@H@("`@("H@5&AE(%9&4R!I;G-T86YC92!T:&%T('=E
M(&%R92!B<F]W<VEN9RX*("`@("`J"B`@("`@*B!`=F%R(%9&4PH@("`@("HO
M"B`@("!V87(@)%]V9G,["@H@("`@+RHJ"B`@("`@*B!4:&4@9&ER96-T;W)Y
M('=H97)E('1H92!T96UP;&%T97,@=&\@=7-E(&%R92X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T96UP;&%T97,["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A
M;2!61E,@)B1V9G,@("`@("`@("`@02!61E,@;V)J96-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5M<&QA=&5S("!43T1/"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%9&4U]"<F]W<V5R*"8D=F9S+"`D=&5M<&QA=&5S*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=F9S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W9F
M<R`]("1V9G,["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?=&5M<&QA=&5S
M(#T@)'1E;7!L871E<SL*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@
M5D93(&]B:F5C="!I;B!T:&4@;&]C86P@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!61E,@)B1V9G,@($$@5D93(&]B:F5C="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T5D933V)J96-T*"8D=F9S*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?=F9S(#T@)B1V9G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!43T1/
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%1/1$\*("`@("`J
M($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@5$]$3PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971522@D<&%T:"P@)&1O=&9I;&5S(#T@9F%L<V4L("1D:7)O
M;FQY(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]V9G,M/FQI<W1&
M;VQD97(H)'!A=&@L("1D;W1F:6QE<RP@)&1I<F]N;'DI.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]S;6(N<&AP````````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U-3,S-0`Q,#0Q-S,V,C<W
M,``P,3<Q,S$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%-T871E;&5S<R!61E,@:6UP;&5M96YT871I
M;VX@9F]R(&$@4TU"('-E<G9E<BP@8F%S960@;VX@<VUB8VQI96YT+@H@*@H@
M*B!297%U:7)E9"!V86QU97,@9F]R("1P87)A;7,Z"B`J(#QP<F4^"B`J("`@
M)W5S97)N86UE)R`@+2!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN
M96-T('1O('1H92!334(@<V5R=F5R+@H@*B`@("=P87-S=V]R9"<@("T@5&AE
M('!A<W-W;W)D('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@4TU"('-E
M<G9E<BX*("H@("`G:&]S='-P96,G("`M(%1H92!334(@<V5R=F5R('1O(&-O
M;FYE8W0@=&\N"B`J("`@)W!O<G0G("`@("`@+2!4:&4@4TU"('!O<G0@;G5M
M8F5R('1O(&-O;FYE8W0@=&\N"B`J("`@)W-H87)E)R`@("`@+2!4:&4@<VAA
M<F4@=&\@86-C97-S(&]N('1H92!334(@<V5R=F5R+@H@*B`@("=S;6)C;&EE
M;G0G("T@5&AE('!A=&@@=&\@=&AE("=S;6)C;&EE;G0G(&5X96-U=&%B;&4N
M"B`J(#PO<')E/@H@*@H@*B!/<'1I;VYA;"!V86QU97,@9F]R("1P87)A;7,Z
M"B`J(#QP<F4^"B`J("`@)VEP861D<F5S<R<@+2!4:&4@861D<F5S<R!O9B!T
M:&4@<V5R=F5R('1O(&-O;FYE8W0@=&\N"B`J(#PO<')E/@H@*@H@*B!&=6YC
M=&EO;G,@;F]T(&EM<&QE;65N=&5D.@H@*B`@("T@8VAA;F=E4&5R;6ES<VEO
M;G,H*3H@5&AE(%--0B!P97)M:7-S:6]N('-T>6QE(&1O97,@;F]T(&9I="!W
M:71H('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@;6]D=6QE+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`L=B`Q+C$Q
M+C(N-2`R,#`V+S`S+S(T(#$V.C0Q.C0Y('-L=7-A<GH@17AP("0*("H*("H@
M0V]D96)A<V4@8V]P>7)I9VAT(#(P,#(@4&%U;"!'87)E874@/'!A=6Q`>&AA
M=VLN;F5T/BX@($%D87!T960@=VET:`H@*B!P97)M:7-S:6]N(&)Y(%!A=')I
M8V4@3&5V97-Q=64@/'=A>6YE0'!T869F+F-A/B!F<F]M('!H<'-M8BTP+C@@
M8V]D92P@86YD"B`J(&-O;G9E<G1E9"!T;R!T:&4@3$=03"X@(%!L96%S92!D
M;R!N;W0@=&%U;G0@;W)I9VEN86P@875T:&]R+"!C;VYT86-T"B`J(%!A=')I
M8V4@3&5V97-Q=64@;W(@9&5V0&QI<W1S+FAO<F1E+F]R9RX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@(%!A=6P@1V%R96%U(#QP875L0'AH87=K+FYE
M=#X*("H@0&%U=&AO<B`@4&%T<FEC92!,979E<W%U92`\=V%Y;F5`<'1A9F8N
M8V$^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!61E,*("HO
M"F-L87-S(%9&4U]S;6(@97AT96YD<R!61E,@>PH*("`@("\J*@H@("`@("H@
M3&ES="!O9B!A9&1I=&EO;F%L(&-R961E;G1I86QS(')E<75I<F5D(&9O<B!T
M:&ES(%9&4R!B86-K96YD+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?8W)E9&5N=&EA;',@/2!A<G)A>2@G=7-E<FYA;64G
M+"`G<&%S<W=O<F0G*3L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@<&5R;6ES
M<VEO;G,@86YD(&EF('1H97D@8V%N(&)E(&-H86YG960@:6X@=&AI<R!61E,@
M8F%C:V5N9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7W!E<FUI<W-I;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R)R`]
M/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E
M>&5C=71E)R`]/B!F86QS92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@G
M<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]
M/B!F86QS92DL"B`@("`@("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@
M9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DI
M.PH*("`@("\J*@H@("`@("H@075T:&5N=&EC871E<R!A('5S97(@;VX@=&AE
M(%--0B!S97)V97(@86YD('-H87)E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R
M<F]R("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@
M("`@("`D8VUD(#T@87)R87DH)W%U:70G*3L*("`@("`@("`D97)R(#T@)'1H
M:7,M/E]C;VUM86YD*"<G+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D97)R
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R
M(&9A:6QE9"XB*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@9FEL92!F<F]M('1H
M92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE
M('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96%D*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!L:7-T
M*"1P871H+"`D;F%M92D@/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N9"@D
M<&%T:"P@)&YA;64I.PH@("`@("`@("1T96UP(#T@)'1H:7,M/E]G971496UP
M1FEL92@I.PH@("`@("`@("1C;60@/2!A<G)A>2@G9V5T(%PB)R`N("1N86UE
M("X@)UPB("<@+B`D=&5M<"D["B`@("`@("`@)&5R<B`]("1T:&ES+3Y?8V]M
M;6%N9"@D<&%T:"P@)&-M9"D["B`@("`@("`@:68@*&ES7V$H)&5R<BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@("`@
M("!]"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D=&5M<"DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H@("`@("`@(&EF("AF=6YC
M=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*("`@("`@("`@
M("`@)&9I;&4@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&5M<"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&9P(#T@9F]P96XH)'1E;7`L("=R)RD[
M"B`@("`@("`@("`@("1F:6QE(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D=&5M
M<"DI.PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"B`@("`@
M("`@=6YL:6YK*"1T96UP*3L*("`@("`@("!I9B`H)&9I;&4I('L*("`@("`@
M("`@("`@<F5T=7)N("1F:6QE.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H
M)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%-T;W)E<R!A(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@
M=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@
M("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@
M)'1M<$9I;&4@("`@("!4:&4@=&5M<&]R87)Y(&9I;&4@8V]N=&%I;FEN9R!T
M:&4@9&%T82!T;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T;W)E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E871E
M("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA;64L("1T;7!&:6QE+"`D875T;V-R
M96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@(&QI<W0H)'!A=&@L("1N86UE
M*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM86YD*"1P871H+"`D;F%M92D[
M"B`@("`@("`@)&-M9"`](&%R<F%Y*"=P=70@7"(G("X@)'1M<$9I;&4@+B`G
M7"(@7"(G("X@)&YA;64@+B`G7"(G*3L*("`@("`@("`O+R!D;R!W92!N965D
M('1O(&9I<G-T(&%U=&]C<F5A=&4@=&AE(&1I<F5C=&]R>3\*("`@("`@("!I
M9B`H)&%U=&]C<F5A=&4I('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YA=71O8W)E871E4&%T:"@D<&%T:"D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M("1E<G(@/2`D=&AI<RT^7V-O;6UA;F0H)'!A=&@L("1C;60I.PH@("`@("`@
M(&EF("AI<U]A*"1E<G(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1E<G(["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93
M(&9R;VT@<F%W(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M
M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("`@("`@
M5&AE(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E
M871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!W<FET941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@)&%U
M=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("`D=&UP1FEL92`]("1T
M:&ES+3Y?9V5T5&5M<$9I;&4H*3L*("`@("`@("`D9G`@/2!F;W!E;B@D=&UP
M1FEL92P@)W=B)RD["B`@("`@("`@9G=R:71E*"1F<"P@)&1A=&$I.PH@("`@
M("`@(&9C;&]S92@D9G`I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^=W)I
M=&4H)'!A=&@L("1N86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4I.PH@("`@
M("`@('5N;&EN:R@D=&UP1FEL92D["B`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@9FEL92!F<F]M('1H
M92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE
M('!A=&@@=&\@9&5L971E('1H92!F:6QE(&9R;VTN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E;&5T949I;&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@
M(&QI<W0H)'!A=&@L("1N86UE*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM
M86YD*"1P871H+"`D;F%M92D["B`@("`@("`@)&-M9"`](&%R<F%Y*"=D96P@
M7"(G("X@)&YA;64@+B`G7"(G*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C
M;VUM86YD*"1P871H+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D97)R+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H96-K<R!I9B!A(&=I=F5N('!A=&AN86UE(&ES(&$@9F]L9&5R+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O
M('1H92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M9FEL92!O<B!F;VQD97(@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@:70@:7,@82!F;VQD97(L(&9A;'-E(&]T:&5R=VES
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-&;VQD97(H)'!A=&@L("1N86UE
M*0H@("`@>PH@("`@("`@(&QI<W0H)'!A=&@L("1N86UE*2`]("1T:&ES+3Y?
M97-C87!E4VAE;&Q#;VUM86YD*"1P871H+"`D;F%M92D["B`@("`@("`@)&-M
M9"`](&%R<F%Y*"=Q=6ET)RD["B`@("`@("`@)&5R<B`]("1T:&ES+3Y?8V]M
M;6%N9"@D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2P@)&-M9"D["B`@
M("`@("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&9O;&1E<B!F
M<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@("`@("`@5&AE('!A=&@@=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H92!N86UE(&]F
M('1H92!F;VQD97(@=&\@9&5L971E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)')E8W5R<VEV92`@1F]R8V4@82!R96-U<G-I=F4@9&5L971E/PH@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1E;&5T949O;&1E<B@D<&%T:"P@)&YA;64L("1R96-U<G-I
M=F4@/2!F86QS92D*("`@('L*("`@("`@("`D:7-$:7(@/2!F86QS93L*("`@
M("`@("`D9&ER0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"D["B`@
M("`@("`@9F]R96%C:"`H)&1I<D-H96-K(&%S("1F:6QE*2!["B`@("`@("`@
M("`@(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE("8F("1F:6QE6R=T>7!E
M)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@)&ES1&ER(#T@=')U
M93L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H(21I<T1I<BD@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(EPB)7-<(B!I<R!N;W0@
M82!D:7)E8W1O<GDN(BDL("1P871H("X@)R\G("X@)&YA;64I*3L*("`@("`@
M("!]"@H@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D
M=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2D["B`@("`@("`@:68@*&ES
M7V$H)&9I;&5?;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&9I;&5?;&ES=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D9FEL
M95]L:7-T("8F("$D<F5C=7)S:79E*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!<
M(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF
M("@D9FEL95LG='EP92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^9&5L971E1F]L9&5R*"1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I+"`D9FEL95LG;F%M92==+"`D<F5C=7)S:79E*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^9&5L971E1FEL92@D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N
M86UE*2P@)&9I;&5;)VYA;64G72D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\O(%)E86QL>2!D96QE=&4@=&AE(&9O;&1E<BX*("`@
M("`@("!L:7-T*"1P871H+"`D;F%M92D@/2`D=&AI<RT^7V5S8V%P95-H96QL
M0V]M;6%N9"@D<&%T:"P@)&YA;64I.PH@("`@("`@("1C;60@/2!A<G)A>2@G
M<FUD:7(@7"(G("X@)&YA;64@+B`G7"(G*3L*("`@("`@("`D97)R(#T@)'1H
M:7,M/E]C;VUM86YD*"1P871H+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D
M97)R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92DI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;65S(&$@
M9FEL92!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&]L9'!A=&@@(%1H92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&]L9&YA;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE
M(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4:&4@;F5W
M(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%2
M7T5R<F]R("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@
M)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92D*("`@('L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1N97=P
M871H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(&QI<W0H)&9I;&4L("1N86UE*2`]
M("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM86YD*"1O;&1N86UE+"`D;F5W;F%M
M92D["B`@("`@("`@)&-M9"`](&%R<F%Y*"=R96YA;64@7"(G("X@('-T<E]R
M97!L86-E*"<O)RP@)UQ<7%PG+"`D;VQD<&%T:"D@+B`G7%PG("X@)&9I;&4@
M+B`G7"(@7"(G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1R7W)E<&QA8V4H)R\G+"`G7%Q<7"<L("1N97=P871H*2`N("=<7"<@
M+B`D;F%M92`N("=<(B<I.PH@("`@("`@(&EF("AI<U]A*"1E<G(@/2`D=&AI
M<RT^7V-O;6UA;F0H)R<L("1C;60I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T
M4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!F;VQD
M97(@;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("!4:&4@<&%T:"!O9B!D:7)E8W1O<GD@=&\@8W)E871E(&9O;&1E<BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!N
M97<@9F]L9&5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%2
M7T5R<F]R("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D<&%T
M:"P@)&YA;64I"B`@("!["B`@("`@("`@;&ES="@D9&ER+"`D;6MD:7(I(#T@
M)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@L("1N86UE*3L*("`@
M("`@("`D8VUD(#T@87)R87DH)VUK9&ER(%PB)R`N("1M:V1I<B`N("=<(B<I
M.PH@("`@("`@("1E<G(@/2`D=&AI<RT^7V-O;6UA;F0H)&1I<BP@)&-M9"D[
M"B`@("`@("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(BDL("1T:&ES+3Y?
M9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!U
M;G-O<G1E9"!F:6QE(&QI<W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('1O(&=E
M="!T:&4@9FEL92!L:7-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<BX*("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@2&%S
M:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@;VX@9FEL96YA;64N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_(%1H
M:7,@:7,@:7)R96QE=F%N="!W:71H"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-M8F-L:65N="X*("`@("`J($!P87)A;2!B;V]L96%N("1D
M:7)O;FQY("`@4VAO=R!D:7)E8W1O<FEE<R!O;FQY/PH@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!&:6QE(&QI<W0@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M:7-T1F]L9&5R*"1P871H(#T@)R<L("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL
M97,@/2!T<G5E+"`D9&ER;VYL>2`](&9A;'-E*0H@("`@>PH@("`@("`@(&QI
M<W0H)'!A=&@I(#T@)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@I
M.PH@("`@("`@("1C;60@/2!A<G)A>2@G;',G*3L*("`@("`@("`D<F5S(#T@
M)'1H:7,M/E]C;VUM86YD*"1P871H+"`D8VUD*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S.PH@("`@("`@('T*("`@("`@("`D;G5M7VQI;F5S(#T@8V]U;G0H)')E
M<RD["B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1R
M(#T@,#L@)'(@/"`D;G5M7VQI;F5S.R`D<BLK*2!["B`@("`@("`@("`@("\O
M($UA=&-H(&9I;&4@;&ES=&EN9RX*("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R]>*%QS7',N*UQS>S8L?2DO)RP@)')E<ULD<ETI*2!["B`@("`@("`@
M("`@("`@("`O+R!3<&QI="!I;G1O(&-O;'5M;G,@870@979E<GD@<VEX('-P
M86-E<PH@("`@("`@("`@("`@("`@)'-P;&ET,2`]('!R96=?<W!L:70H)R]<
M<WLV+'TO)RP@=')I;2@D<F5S6R1R72DI.PH@("`@("`@("`@("`@("`@+R\@
M268@=&AE(&9I;&4@;F%M92!I<VXG="`N(&]R("XN"B`@("`@("`@("`@("`@
M("!I9B`H)'-P;&ET,5LP72`A/2`G+B<@)B8@)'-P;&ET,5LP72`A/2`G+BXG
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1S<&QI=#%;,ETI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O($EF('1H97)E(&ES(&$@
M<VUA;&P@9FEL92!S:7IE+"!I;F8@8V]U;&0@8F4@<W!L:70*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@:6YT;R`S(&-O;',N"B`@("`@("`@("`@("`@
M("`@("`@("`@("1S<&QI=#%;,5T@+CT@)R`G("X@)'-P;&ET,5LR73L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@4W!L
M:70@9FEL92!I;F8@870@979E<GD@;VYE(&]R(&UO<F4@<W!A8V5S+@H@("`@
M("`@("`@("`@("`@("`@("1S<&QI=#(@/2!P<F5G7W-P;&ET*"<O7',K+R<L
M("1S<&QI=#%;,5TI.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE
M<FEC*"1S<&QI=#);,%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O
M($EF('1H97)E(&ES(&YO(&9I;&4@871T<BP@<VAI9G0@8V]L<R!O=F5R+@H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1S<&QI=#(L
M("<G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&UY7VYA;64@/2`D<W!L:70Q6S!=.PH*("`@("`@("`@("`@("`@("`@
M("`O+R!&:6QT97(@;W5T(&1O=&9I;&5S(&EF('1H97D@87)E;B=T('=A;G1E
M9"X*("`@("`@("`@("`@("`@("`@("!I9B`H(21D;W1F:6QE<R`F)B!S=6)S
M='(H)&UY7VYA;64L(#`L(#$I(#T]("<N)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@("`@("1M>5]S:7IE(#T@)'-P;&ET,ELQ73L*("`@("`@
M("`@("`@("`@("`@("`D97AT7VYA;64@/2!E>'!L;V1E*"<N)RP@)&UY7VYA
M;64I.PH*("`@("`@("`@("`@("`@("`@("!I9B`H*'-T<G!O<R@D<W!L:70R
M6S!=+"`G1"<I("$]/2!F86QS92DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&UY7W1Y<&4@/2`G*BID:7(G.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D;7E?<VEZ92`]("TQ.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1M>5]T>7!E(#T@5D93.CIS=')T
M;VQO=V5R*"1E>'1?;F%M95MC;W5N="@D97AT7VYA;64I("T@,5TI.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;7E?9&%T
M92`]('-T<G1O=&EM92@D<W!L:70R6S1=("X@)R`G("X@)'-P;&ET,ELS72`N
M("<@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-P;&ET,ELV72`N("<@)R`N("1S<&QI=#);-5TI.PH@("`@("`@("`@
M("`@("`@("`@("1F:6QE9&%T82`](&%R<F%Y*"=O=VYE<B<@/3X@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=R;W5P)R`]
M/B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&5R;7,G(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=N86UE)R`]/B`D;7E?;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)&UY7W1Y<&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&4G(#T^("1M
M>5]D871E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=S:7IE)R`]/B`D;7E?<VEZ92D["B`@("`@("`@("`@("`@("`@("`@+R\@
M=V%T8V@@9F]R(&9I;'1E<G,@86YD(&1I<F]N;'D*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]F:6QT97)-871C:"@D9FEL=&5R+"`D;7E?;F%M
M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"1D:7)O;FQY("8F
M("1M>5]T>7!E("$]/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("`@("`D9FEL97-;)&9I;&5D871A6R=N86UE)UU=(#T@)&9I;&5D871A.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D9FEL97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L9&5R<R!I;B!S<&5C:69I960@9&ER
M96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@
M("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('1O(&=E="!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D:7)E8W1O<GD@;&ES
M="!F;W(N"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@("`@2&%S
M:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@;VX@9F]L9&5R;&ES="X*("`@
M("`J($!P87)A;2!B;V]L96%N("1D;W1F;VQD97)S("!);F-L=61E(&1O=&9O
M;&1E<G,_($ER<F5L979A;G0@9F]R(%--0BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@1F]L9&5R(&QI<W0@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T
M1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9O;&1E
M<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1F;VQD97)S(#T@87)R87DH*3L*
M("`@("`@("`D9F]L9&5R(#T@87)R87DH*3L*"B`@("`@("`@)&9O;&1E<DQI
M<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L;"P@)&1O=&9O;&1E
M<G,L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1F;VQD97),:7-T+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9F]L9&5R3&ES=#L*
M("`@("`@("!]"@H@("`@("`@("\O(&1I<FYA;64@=VEL;"!S=')I<"!L87-T
M(&-O;7!O;F5N="!F<F]M('!A=&@L(&5V96X@;VX@82!D:7)E8W1O<GD*("`@
M("`@("`D9F]L9&5R6R=V86PG72`](&1I<FYA;64H)'!A=&@I.PH@("`@("`@
M("1F;VQD97);)V%B8G)E=B==(#T@)RXN)SL*("`@("`@("`D9F]L9&5R6R=L
M86)E;"==(#T@)RXN)SL*"B`@("`@("`@)&9O;&1E<G-;)&9O;&1E<ELG=F%L
M)UU=(#T@)&9O;&1E<CL*"B`@("`@("`@9F]R96%C:"`H)&9O;&1E<DQI<W0@
M87,@)&9I;&5S*2!["B`@("`@("`@("`@("1F;VQD97);)W9A;"==(#T@)'1H
M:7,M/E]G9710871H*"1P871H+"`D9FEL97-;)VYA;64G72D["B`@("`@("`@
M("`@("1F;VQD97);)V%B8G)E=B==(#T@)&9I;&5S6R=N86UE)UT["B`@("`@
M("`@("`@("1F;VQD97);)VQA8F5L)UT@/2`D9F]L9&5R6R=V86PG73L*"B`@
M("`@("`@("`@("1F;VQD97)S6R1F;VQD97);)W9A;"==72`]("1F;VQD97([
M"B`@("`@("`@?0H*("`@("`@("!K<V]R="@D9F]L9&5R<RD["B`@("`@("`@
M<F5T=7)N("1F;VQD97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]P:65S
M(&$@9FEL92!T:')O=6=H('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE
M(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE
M('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!D97-T
M:6YA=&EO;B!O9B!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W!Y*"1P
M871H+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI
M<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H<')E9U]M
M871C:"@G?%XG("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G6R0O77PG+"`D9&5S
M="DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V%N(&YO="!C;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E<W1I;F%T:6]N
M(&%R92!T:&4@<V%M92XB*2D["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H
M96-K(#T@)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L(&YU;&PL('1R=64I.PH@
M("`@("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@
M("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B)7,@
M86QR96%D>2!E>&ES=',N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@
M)&YA;64I*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1I
M<T1I<B`](&9A;'-E.PH@("`@("`@("1D:7)#:&5C:R`]("1T:&ES+3YL:7-T
M1F]L9&5R*"1P871H+"!N=6QL+"!F86QS92D["B`@("`@("`@9F]R96%C:"`H
M)&1I<D-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG
M;F%M92==(#T]("1N86UE("8F("1F:6QE6R=T>7!E)UT@/3T@)RHJ9&ER)RD@
M>PH@("`@("`@("`@("`@("`@)&ES1&ER(#T@=')U93L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&ES1&ER*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E
M871E1F]L9&5R*"1D97-T+"`D;F%M92D["@H@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I
M;&5?;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1O<FEG*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)&9I;&5?;&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YC;W!Y*"1O<FEG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M9710871H*"1D97-T+"`D;F%M92DI.PH@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1M<$9I;&4@
M/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"1P871H+"`D;F%M92D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1T;7!&:6QE+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(D9A:6QE9"!T;R!R971R:65V93H@)7,B*2P@)&]R:6<I*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)')E<R`]("1T:&ES+3YW<FET92@D9&5S
M="P@)&YA;64L("1T;7!&:6QE*3L*("`@("`@("`@("`@=6YL:6YK*"1T;7!&
M:6QE*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")#;W!Y(&9A:6QE9#H@)7,B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9710
M871H*"1D97-T+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-
M;W9E<R!A(&9I;&4@=&AR;W5G:"!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@
M9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE
M;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D97-T("!4:&4@
M9&5S=&EN871I;VX@;V8@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N?%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V
M92@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@>PH@("`@("`@("1O<FEG(#T@
M)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92D["B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)WQ>)R`N('!R96=?<75O=&4H)&]R:6<I("X@)ULD+UU\)RP@
M)&1E<W0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(D-A;B!N;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET
M:&EN('-O=7)C92XB*2D["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H96-K
M(#T@)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L(&YU;&PL('1R=64I.PH@("`@
M("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@
M("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B)7,@86QR
M96%D>2!E>&ES=',N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA
M;64I*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1E<G(@
M/2`D=&AI<RT^<F5N86UE*"1P871H+"`D;F%M92P@)&1E<W0L("1N86UE*3L*
M("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1F%I
M;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T:"@D9&5S
M="P@)&YA;64I*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9G5L;"!P871H(&]F
M(&%N(&ET96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A=&@@;V8@9&ER96-T;W)Y(&]F('1H92!I=&5M+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&ET96TN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@1G5L;"!P871H('=H96X@)'!A=&@@
M:7-S970@86YD(&IU<W0@)&YA;64@=VAE;B!N;W0@<V5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T4&%T:"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@
M("`@:68@*"1P871H("$]/2`G)RD@>PH@("`@("`@("`@("`@<F5T=7)N("@D
M<&%T:"`N("<O)R`N("1N86UE*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P;&%C96UE;G0@9F]R
M(&5S8V%P97-H96QL8VUD*"DL('9A<FEA8FQE(&QE;F=T:"!A<F=S+"!A<R!W
M92!O;FQY('=A;G0*("`@("`J(&-E<G1A:6X@8VAA<F%C=&5R<R!E<V-A<&5D
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D87)R87D@(%-T<FEN9W,@=&\@97-C87!E+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V5S8V%P95-H96QL0V]M;6%N9"@I"B`@("!["B`@("`@("`@)')E="`](&%R
M<F%Y*"D["B`@("`@("`@)&%R9W,@/2!F=6YC7V=E=%]A<F=S*"D["B`@("`@
M("`@9F]R96%C:"`H)&%R9W,@87,@)&%R9RD@>PH@("`@("`@("`@("`D<F5T
M6UT@/2!S=')?<F5P;&%C92AA<G)A>2@G.R<L("=<7"<I+"!A<G)A>2@G7#LG
M+"`G7%Q<7"<I+"`D87)G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R
M970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A(&-O;6UA;F0@
M86YD(')E='5R;G,@;W5T<'5T(&QI;F5S(&EN(&%R<F%Y+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-M9"`@0V]M;6%N9"!T;R!B92!E>&5C=71E9`H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($%R<F%Y(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E>&5C=71E*"1C;60I"B`@
M("!["B`@("`@("`@)&-M9"`]('-T<E]R97!L86-E*"<B+54E(B<L("<M3B<L
M("1C;60I.PH@("`@("`@(&5X96,H)&-M9"P@)&]U="P@)')E="D["@H@("`@
M("`@("\O($EN('-O;64@8V%S97,L("AL:6ME('1R>6EN9R!T;R!D96QE=&4@
M82!N;VYE>&ES=&%N="!F:6QE*2P*("`@("`@("`O+R!S;6)C;&EE;G0@=VEL
M;"!R971U<FX@<W5C8V5S<R`H870@;&5A<W0@;VX@,BXR+C<@=F5R<VEO;B!)
M)VT*("`@("`@("`O+R!T97-T:6YG(&]N*2X@4V\@=')Y('1O(&UA=&-H(&5R
M<F]R('-T<FEN9W,L(&5V96X@869T97(@<W5C8V5S<RX*("`@("`@("!I9B`H
M)')E="`A/2`P*2!["B`@("`@("`@("`@("1E<G(@/2`G)SL*("`@("`@("`@
M("`@9F]R96%C:"`H)&]U="!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@
M:68@*'-T<G!O<R@D;&EN92P@)U5S86=E.B<I(#T]/2`P*2!["B`@("`@("`@
M("`@("`@("`@("`@)&5R<B`]("=#;VUM86YD('-Y;G1A>"!I;F-O<G)E8W0G
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;&EN92P@)T524E-25B<I
M("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@("`@('-T<G!O<R@D;&EN
M92P@)T524D1/4R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M("1E<G(@/2!P<F5G7W)E<&QA8V4H)R\N*EPH*"XK*5PI+BHO)RP@)UQ<,2<L
M("1L:6YE*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(21E<G(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<B`]("1L:6YE.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21E
M<G(I('L*("`@("`@("`@("`@("`@("1E<G(@/2`D;W5T(#\@)&]U=%MC;W5N
M="@D;W5T*2`M(#%=(#H@)')E=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R*3L*("`@("`@("!]"@H@
M("`@("`@("\O($-H96-K(&9O<B!E<G)O<G,@979E;B!O;B!S=6-C97-S+@H@
M("`@("`@("1E<G(@/2`G)SL*("`@("`@("!F;W)E86-H("@D;W5T(&%S("1L
M:6YE*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H)&QI;F4L("=.5%]35$%4
M55-?3D]?4U5#2%]&24Q%)RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@
M("!S=')P;W,H)&QI;F4L("=.5%]35$%455-?3T)*14-47TY!345?3D]47T9/
M54Y$)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D97)R(#T@7R@B
M3F\@<W5C:"!F:6QE(BD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?2!E;'-E:68@*'-T<G!O<R@D;&EN92P@)TY47U-405154U]!0T-%
M4U-?1$5.245$)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D97)R
M(#T@7R@B4&5R;6ES<VEO;B!$96YI960B*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&5R
M<BD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@17AE8W5T97,@4TU"(&-O;6UA;F1S("T@=VET:&]U="!A
M=71H96YT:6-A=&EO;B`M(&%N9"!R971U<FYS(&]U='!U=`H@("`@("H@;&EN
M97,@:6X@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P871H("!"87-E('!A=&@@9F]R
M(&-O;6UA;F0N"B`@("`@*B!`<&%R86T@87)R87D@)&-M9"`@($-O;6UA;F1S
M('1O(&)E(&5X96-U=&5D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M($%R<F%Y(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;VUM86YD*"1P871H+"`D8VUD*0H@("`@>PH@("`@
M("`@(&QI<W0H)'-H87)E*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM86YD
M*"1T:&ES+3Y?<&%R86US6R=S:&%R92==*3L*("`@("`@("!P=71E;G8H)U!!
M4U-71#TG("X@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI.PH@("`@("`@
M("1I<&]P=&EO;B`]("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG:7!A9&1R97-S
M)UTI*2`_("@G("U)("<@+B`D=&AI<RT^7W!A<F%M<ULG:7!A9&1R97-S)UTI
M(#H@;G5L;#L*("`@("`@("`D9G5L;&-M9"`]("1T:&ES+3Y?<&%R86US6R=S
M;6)C;&EE;G0G72`N"B`@("`@("`@("`@("<@(B\O)R`N("1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==("X@)R\G("X@)'-H87)E("X@)R(G("X*("`@("`@
M("`@("`@)R`B+7`G("X@)'1H:7,M/E]P87)A;7-;)W!O<G0G72`N("<B)R`N
M"B`@("`@("`@("`@("<@(BU5)R`N("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M
M92==("X@)R(G("X*("`@("`@("`@("`@)R`M1"`B)R`N("1P871H("X@)R(@
M)R`N"B`@("`@("`@("`@("1I<&]P=&EO;B`N"B`@("`@("`@("`@("<@+6,@
M(B<["B`@("`@("`@9F]R96%C:"`H)&-M9"!A<R`D8RD@>PH@("`@("`@("`@
M("`D9G5L;&-M9"`N/2`D8R`N("([(CL*("`@("`@("!]"B`@("`@("`@)&9U
M;&QC;60@+CT@)R(G.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5X96-U=&4H
M)&9U;&QC;60I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@
M9FEL92!F<F]M('1H92!61E,@86YD('-T;W)E<R!I="!T;R!A('1E;7!O<F%R
M>2!F:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T;R!T
M:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE
M;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@=&5M<&]R87)Y(&9I;&5N86UE(&]R(&$@4$5!4E]%<G)O<B!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E5&5M<$9I;&4H
M)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(&QI<W0H)'!A=&@L("1N86UE
M*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM86YD*"1P871H+"`D;F%M92D[
M"B`@("`@("`@)'1E;7`@/2`D=&AI<RT^7V=E=%1E;7!&:6QE*"D["B`@("`@
M("`@)&-M9"`](&%R<F%Y*"=G970@7"(G("X@)&YA;64@+B`G7"(@)R`N("1T
M96UP*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C;VUM86YD*"1P871H+"`D
M8VUD*3L*("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T*("`@("`@("!I
M9B`H(69I;&5?97AI<W1S*"1T96UP*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92DI*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T96UP.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]61E,O<W%L+G!H<```````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`Q,#8S-30`,3`T,3<S-C(W-S``,#$W,30U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@HO*BH*("H@1FEL92!V86QU92!F;W(@=F9S7W1Y<&4@8V]L=6UN+@H@*B\*
M9&5F:6YE*"=61E-?1DE,12<L(#$I.PH*+RHJ"B`J($9O;&1E<B!V86QU92!F
M;W(@=F9S7W1Y<&4@8V]L=6UN+@H@*B\*9&5F:6YE*"=61E-?1D],1$52)RP@
M,BD["@HO*BH*("H@5D93(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2
M(&1A=&%B87-E(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!V
M86QU97,@9F]R("1P87)A;7,Z/'!R93X*("H@("`@("`G<&AP='EP92<@("`@
M("`@5&AE(&1A=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E
M=&,N*2X\+W!R93X*("H*("H@3W!T:6]N86P@=F%L=65S.CQP<F4^"B`J("`@
M("`@)W1A8FQE)R`@("`@("`@(%1H92!N86UE(&]F('1H92!V9G,@=&%B;&4@
M:6X@)V1A=&%B87-E)RX@1&5F875L=',@=&\*("H@("`@("`@("`@("`@("`@
M("`@("`@)VAO<F1E7W9F<R<N/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O
M;64@9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J("`@("`@)VAO
M<W1S<&5C)R`@("`@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R
M=F5R+@H@*B`@("`@("=P<F]T;V-O;"<@("`@("!4:&4@8V]M;75N:6-A=&EO
M;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@("`@)V1A
M=&%B87-E)R`@("`@(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`@
M("`G=7-E<FYA;64G("`@("`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W!A<W-W;W)D)R`@
M("`@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*
M("H@("`@("`G;W!T:6]N<R<@("`@("`@061D:71I;VYA;"!O<'1I;VYS('1O
M('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("`@("=T='DG("`@("`@("`@
M("!4:&4@5%19(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E
M+@H@*B`@("`@("=P;W)T)R`@("`@("`@("!4:&4@<&]R="!O;B!W:&EC:"!T
M;R!C;VYN96-T('1O('1H92!D871A8F%S92X\+W!R93X*("H*("H@5&AE('1A
M8FQE('-T<G5C='5R92!F;W(@=&AE(%9&4R!C86X@8F4@9F]U;F0@:6X*("H@
M9&%T82]V9G,N<W%L+@H@*@H@*B!$871A8F%S92!S<&5C:69I8R!N;W1E<SH*
M("H*("H@35-344PZ"B`J(#QP<F4^"B`J("T@5&AE('9F<U]D871A(&9I96QD
M(&UU<W0@8F4@;V8@='EP92!)34%'12X*("H@+2!9;W4@;F5E9"!T:&4@9F]L
M;&]W:6YG('!H<"YI;FD@<V5T=&EN9W,Z"B`J("`@(#L@5F%L:60@<F%N9V4@
M,"`M(#(Q-#<T.#,V-#<N($1E9F%U;'0@/2`T,#DV+@H@*B`@("!M<W-Q;"YT
M97AT;&EM:70@/2`P(#L@>F5R;R!T;R!P87-S('1H<F]U9V@*("H*("H@("`@
M.R!686QI9"!R86YG92`P("T@,C$T-S0X,S8T-RX@1&5F875L="`](#0P.38N
M"B`J("`@(&US<W%L+G1E>'1S:7IE(#T@,"`[('IE<F\@=&\@<&%S<R!T:')O
M=6=H"B`J(#PO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`L=B`Q+C@U+C0N,C0@,C`P-B\P,R\Q,B`Q.#HT.#HR-B!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?
M<W%L(&5X=&5N9',@5D93('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@
M=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@
M*B!`=F%R($1""B`@("`@*B\*("`@('9A<B`D7V1B(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!2971R:65V97,@=&AE(&9I;&5S:7IE(&9R;VT@=&AE(%9&
M4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T
M:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@5&AE(&9I;&4@<VEZ92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<VEZ92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI
M<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@<W1R;&5N*"1T:&ES+3Y?<F5A9$)L;V(H)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL("=V9G-?9&%T82<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=V9G-?<&%T:"<@
M/3X@)'1H:7,M/E]C;VYV97)T4&%T:"@D<&%T:"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V9G-?;F%M92<@/3X@
M)&YA;64I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!A(&9I
M;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9I;&4@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D<&%T:"P@)&YA;64I"B`@("!["B`@
M("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H
M:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]R
M96%D0FQO8B@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)W9F<U]D871A)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=F9S7W!A
M=&@G(#T^("1T:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V9G-?;F%M92<@/3X@)&YA
M;64I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!A('!A<G0@
M;V8@82!F:6QE(&9R;VT@=&AE(%9&4RX@4&%R=&EC=6QA<FQY('5S969U;`H@
M("`@("H@=VAE;B!R96%D:6YG(&QA<F=E(&9I;&5S('=H:6-H('=O=6QD(&5X
M8V5E9"!T:&4@4$A0(&UE;6]R>0H@("`@("H@;&EM:71S(&EF('1H97D@=V5R
M92!S=&]R960@:6X@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)'!A=&@@("`@("`@5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&YA;64@("`@("`@5&AE(&9I;&5N86UE
M('1O(')E=')I979E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&]F9G-E="`@
M("`@5&AE(&]F9G-E="!O9B!T:&4@<&%R="X@*%1H92!N97<@;V9F<V5T('=I
M;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T;W)E
M9"!I;B!H97)E*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1L96YG=&@@("`@
M(%1H92!L96YG=&@@;V8@=&AE('!A<G0N($EF('1H92!L96YG=&@@/2`M,2P@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!W:&]L92!P
M87)T(&%F=&5R('1H92!O9F9S970@:7,@<F5T<FEE=F5D+B!)9@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;6]R92!B>71E<R!A<F4@9VEV
M96X@87,@97AI<W1S(&%F=&5R('1H92!G:79E;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;V9F<V5T+B!/;FQY('1H92!A=F%I;&%B;&4@
M8GET97,@87)E(')E860N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F5M86EN
M:6YG("!4:&4@8GET97,@=&AA="!A<F4@;&5F="P@869T97(@=&AE('!A<G0@
M=&AA="!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M<FEE=F5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%1H92!F:6QE
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861087)T*"1P871H+"`D
M;F%M92P@)B1O9F9S970L("1L96YG=&@@/2`M,2P@)B1R96UA:6YI;F<I"B`@
M("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@
M("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9&%T82`]("1T
M:&ES+3Y?<F5A9$)L;V(H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL("=V9G-?
M9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=V9G-?<&%T:"<@/3X@)'1H:7,M/E]C;VYV97)T4&%T:"@D<&%T:"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V9G-?;F%M
M92<@/3X@)&YA;64I*3L*"B`@("`@("`@+R\@0V%L8W5L871E(&AO=R!M86YY
M(&)Y=&5S($U54U0@8F4@<F5A9"P@<V\@=&AE(')E;6%I;F=I;F<*("`@("`@
M("`O+R!B>71E<R!A;F0@=&AE(&YE=R!O9F9S970@8V%N(&)E(&-A;&-U;&%T
M960@8V]R<F5C=&QY+@H@("`@("`@("1S:7IE(#T@<W1R;&5N("@D9&%T82D[
M"B`@("`@("`@:68@*"1L96YG=&@@/3T@+3$@?'P@*"@D;&5N9W1H("L@)&]F
M9G-E="D@/B`D<VEZ92DI('L*("`@("`@("`@("`@)&QE;F=T:"`]("1S:7IE
M("T@)&]F9G-E=#L*("`@("`@("!]"B`@("`@("`@:68@*"1R96UA:6YI;F<@
M/"`P*2!["B`@("`@("`@("`@("1R96UA:6YI;F<@/2`P.PH@("`@("`@('T*
M"B`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L("1O9F9S970L("1L96YG
M=&@I.PH@("`@("`@("1O9F9S970@/2`D;V9F<V5T("L@)&QE;F=T:#L*("`@
M("`@("`D<F5M86EN:6YG(#T@)'-I>F4@+2`D;V9F<V5T.PH*("`@("`@("!R
M971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@82!F
M:6QE(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M
M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;7!&:6QE("`@("`@
M5&AE('1E;7!O<F%R>2!F:6QE(&-O;G1A:6YI;F<@=&AE(&1A=&$@=&\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B92!S=&]R960N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL
M>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)'!A=&@L
M("1N86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*
M("`@("`@("`O*B!$;VXG="!N965D('1O(&-H96-K('%U;W1A(&AE<F4@<VEN
M8V4@:70@=VEL;"!B92!C:&5C:V5D('=H96X*("`@("`@("`@*B!W<FET941A
M=&$H*2!I<R!C86QL960N("HO"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PH@("`@("`@("`@("`D9&%T82`]
M(&9I;&5?9V5T7V-O;G1E;G1S*"1T;7!&:6QE*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<VEZ92`](&9I;&5S:7IE*"1T;7!&:6QE*3L*("`@
M("`@("`@("`@:68@*"1S:7IE(#T]/2`P*2!["B`@("`@("`@("`@("`@("`D
M9&%T82`]("<G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1D871A1E`@/2!`9F]P96XH)'1M<$9I;&4L("=R8B<I.PH@("`@
M("`@("`@("`@("`@:68@*"$D9&%T8490*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")4:&4@=&5M
M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(I+"`D=&UP1FEL
M92DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&$@
M/2!`9G)E860H)&1A=&%&4"P@)'-I>F4I.PH@("`@("`@("`@("`@("`@0&9C
M;&]S92@D9&%T8490*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YW<FET941A=&$H)'!A=&@L("1N86UE+"`D9&%T
M82P@)&%U=&]C<F5A=&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@
M82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O
M<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I
M<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@)&YA;64L
M("1D871A+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1R
M97,@/2`D=&AI<RT^7V-H96-K475O=&%7<FET92@G<W1R:6YG)RP@)&1A=&$I
M.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("`D8V]N
M;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*
M("`@("`@("!]"@H@("`@("`@("1P871H(#T@)'1H:7,M/E]C;VYV97)T4&%T
M:"@D<&%T:"D["@H@("`@("`@("\J($-H96-K('1O('-E92!I9B!T:&4@9&%T
M82!A;')E861Y(&5X:7-T<RX@*B\*("`@("`@("`D<W%L(#T@<W!R:6YT9B@G
M4T5,14-4('9F<U]I9"!&4D]-("5S(%=(15)%('9F<U]P871H("5S($%.1"!V
M9G-?;F%M92`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("AE;7!T
M>2@D<&%T:"D@)B8@)'1H:7,M/E]D8BT^9&)S>6YT87@@/3T@)V]C:3@G*2`_
M("<@25,@3E5,3"<@.B`G(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1P871H
M*2D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1N86UE*3L*("`@("`@("`D
M=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D:60@
M/2`D=&AI<RT^7V1B+3YG971/;F4H)'-Q;"P@)'9A;'5E<RD["@H@("`@("`@
M(&EF("AI<U]A*"1I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^;&]G*"1I9"P@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T
M=7)N("1I9#L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?;G5L;"@D:60I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W5P9&%T94)L;V(H)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL("=V9G-?9&%T82<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$L(&%R<F%Y*"=V9G-?
M:60G(#T^("1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W9F<U]M;V1I9FEE9"<@/3X@=&EM92@I*2D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@0VAE8VL@=&\@<V5E(&EF('1H
M92!F;VQD97(@86QR96%D>2!E>&ES=',N("HO"B`@("`@("`@("`@("1D:7)S
M(#T@97AP;&]D92@G+R<L("1P871H*3L*("`@("`@("`@("`@)'!A=&A?;F%M
M92`](&%R<F%Y7W!O<"@D9&ER<RD["B`@("`@("`@("`@("1P87)E;G0@/2!I
M;7!L;V1E*"<O)RP@)&1I<G,I.PH@("`@("`@("`@("!I9B`H(21T:&ES+3YI
M<T9O;&1E<B@D<&%R96YT+"`D<&%T:%]N86UE*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"$D875T;V-R96%T92D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T(BDL("1P871H*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)'!A=&@I.PH@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH@("`@("`@("`@("!I9B`H:7-?82@D
M:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H)&ED+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1I9#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;G-E<G1";&]B*"1T:&ES+3Y?<&%R86US6R=T86)L92==+"`G=F9S7V1A
M=&$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M871A+"!A<G)A>2@G=F9S7VED)R`]/B`D:60L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V9G-?='EP92<@
M/3X@5D937T9)3$4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=V9G-?<&%T:"<@/3X@)'!A=&@L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=V9G-?;F%M92<@/3X@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V9G-?;6]D:69I960G(#T^
M('1I;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W9F<U]O=VYE<B<@/3X@)'1H:7,M/E]P87)A;7-;
M)W5S97(G72DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M;&5T92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O
M('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE*"1P871H+"`D;F%M92D*("`@
M('L*("`@("`@("`D<F5S(#T@)'1H:7,M/E]C:&5C:U%U;W1A1&5L971E*"1P
M871H+"`D;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@
M("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@
M*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)'!A=&@@/2`D=&AI<RT^
M7V-O;G9E<G10871H*"1P871H*3L*"B`@("`@("`@)'-Q;"`]('-P<FEN=&8H
M)T1%3$5412!&4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A
M=&@@)7,@04Y$('9F<U]N86UE(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@*&5M<'1Y*"1P871H*2`F)B`D=&AI<RT^7V1B+3YD8G-Y;G1A>"`]
M/2`G;V-I."<I(#\@)R!)4R!.54Q,)R`Z("<@/2`G("X@)'1H:7,M/E]D8BT^
M<75O=&4H)'!A=&@I*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH5D937T9)
M3$4L("1N86UE*3L*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'
M7T1%0E5'*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH
M)'-Q;"P@)'9A;'5E<RD["@H@("`@("`@(&EF("@D=&AI<RT^7V1B+3YA9F9E
M8W1E9%)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296YA;64@82!F:6QE(&]R(&9O;&1E<B!I;B!T:&4@5D93
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H92!O
M;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&]L
M9&YA;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N97=N86UE("!4:&4@;F5W(&9I;&5N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D
M;F5W;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C
M="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@
M(&EF("AS=')P;W,H)&YE=W!A=&@L("<O)RD@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1P87)E;G0@/2`G)SL*("`@("`@("`@("`@)'!A=&@@/2`D;F5W
M<&%T:#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!L:7-T*"1P87)E
M;G0L("1P871H*2`](&5X<&QO9&4H)R\G+"`D;F5W<&%T:"P@,BD["B`@("`@
M("`@?0H@("`@("`@(&EF("@A)'1H:7,M/FES1F]L9&5R*"1P87)E;G0L("1P
M871H*2D@>PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M
M/F%U=&]C<F5A=&50871H*"1N97=P871H*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1O;&1P871H(#T@)'1H:7,M/E]C;VYV97)T
M4&%T:"@D;VQD<&%T:"D["B`@("`@("`@)&YE=W!A=&@@/2`D=&AI<RT^7V-O
M;G9E<G10871H*"1N97=P871H*3L*"B`@("`@("`@)'-Q;"`@/2`G55!$051%
M("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G73L*("`@("`@("`D<W%L("X]
M("<@4T54('9F<U]P871H(#T@/RP@=F9S7VYA;64@/2`_+"!V9G-?;6]D:69I
M960@/2`_(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64@/2`_)SL*
M("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"1N97=P871H+"`D;F5W;F%M92P@=&EM
M92@I+"`D;VQD<&%T:"P@)&]L9&YA;64I.PH*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^<75E<GDH)'-Q;"P@)'9A;'5E<RD["@H@("`@("`@(&EF
M("@D=&AI<RT^7V1B+3YA9F9E8W1E9%)O=W,H*2`]/2`P*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@)')E;F%M92`]
M("1T:&ES+3Y?<F5C=7)S:79E4F5N86UE*"1O;&1P871H+"`D;VQD;F%M92P@
M)&YE=W!A=&@L("1N97=N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5N86UE
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YL;V<H)')E
M;F%M92P@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(I+"`D<F5N86UE+3YG971-97-S86=E*"DI*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A(&9O;&1E<B!O;B!T:&4@5D93+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@($AO;&1S('1H92!P871H(&]F
M(&1I<F5C=&]R>2!T;R!C<F5A=&4@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@2&]L9',@=&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8W)E871E1F]L9&5R*"1P871H+"`D;F%M92D*("`@('L*
M("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF
M("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1I9"`]("1T:&ES+3Y?
M9&(M/FYE>'1)9"@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@
M:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T
M:&ES+3YL;V<H)&ED+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U
M<FX@)&ED.PH@("`@("`@('T*"B`@("`@("`@)'-Q;"`@/2`G24Y315)4($E.
M5$\@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==.PH@("`@("`@("1S<6P@
M+CT@)R`H=F9S7VED+"!V9G-?='EP92P@=F9S7W!A=&@L('9F<U]N86UE+"!V
M9G-?;6]D:69I960L('9F<U]O=VYE<BD@5D%,5453("@_+"`_+"`_+"`_+"`_
M+"`_*2<["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("1V86QU97,@/2!A<G)A>2@D:60L(%9&4U]&3TQ$15(L
M("1T:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I+"`D;F%M92P@=&EM92@I+"`D
M=&AI<RT^7W!A<F%M<ULG=7-E<B==*3L*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&(M/G%U97)Y*"1S<6PL("1V86QU97,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5L971E(&$@9F]L9&5R(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("!4:&4@<&%T:"!O9B!T
M:&4@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@
M5&AE(&9O;&1E<B!N86UE('1O('5S92X*("`@("`J($!P87)A;2!B;V]L96%N
M("1R96-U<G-I=F4@($9O<F-E(&$@<F5C=7)S:79E(&1E;&5T93\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D96QE=&5&;VQD97(H)'!A=&@L("1N86UE+"`D<F5C=7)S:79E(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D
M<&%T:"`]("1T:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I.PH*("`@("`@("`D
M9F]L9&5R4&%T:"`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA
M;64I.PH*("`@("`@("`O*B!#:&5C:R!I9B!N;W0@<F5C=7)S:79E(&%N9"!F
M86EL(&EF(&1I<F5C=&]R>2!N;W0@96UP='D@*B\*("`@("`@("!I9B`H(21R
M96-U<G-I=F4I('L*("`@("`@("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^
M;&ES=$9O;&1E<B@D9F]L9&5R4&%T:"P@;G5L;"P@=')U92D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1F;VQD97),:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G*"1F;VQD97),:7-T+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1F;VQD97),:7-T.PH@
M("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1F;VQD97),:7-T*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%T:"`N("<O)R`N("1N86UE*2D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J($9I<G-T(&1E;&5T92!E=F5R
M>71H:6YG(&)E;&]W('1H92!F;VQD97(L('-O(&EF(&5R<F]R('=E"B`@("`@
M("`@("H@9V5T(&YO(&]R<&AA;G,@*B\*("`@("`@("`D<W%L(#T@<W!R:6YT
M9B@G1$5,151%($923TT@)7,@5TA%4D4@=F9S7W!A=&@@)7,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("AE;7!T>2@D9F]L9&5R4&%T:"D@)B8@)'1H
M:7,M/E]D8BT^9&)S>6YT87@@/3T@)V]C:3@G*2`_("<@25,@3E5,3"<@.B`G
M($Q)2T4@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES+3Y?9V5T3F%T:79E
M4&%T:"@D9F]L9&5R4&%T:"P@)R4G*2DI.PH@("`@("`@("1T:&ES+3YL;V<H
M)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1D96QE=&5#;VYT96YT
M<R`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PI.PH@("`@("`@(&EF("AI<U]A
M*"1D96QE=&5#;VYT96YT<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^;&]G*"1D96QE=&5#;VYT96YT<RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(BDL("1D
M96QE=&5#;VYT96YT<RT^9V5T365S<V%G92@I*2D["B`@("`@("`@?0H*("`@
M("`@("`O*B!.;W<@9&5L971E(&5V97)Y=&AI;F<@:6YS:61E('1H92!F;VQD
M97(N("HO"B`@("`@("`@)'-Q;"`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S
M(%=(15)%('9F<U]P871H("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@
M("`H96UP='DH)'!A=&@I("8F("1T:&ES+3Y?9&(M/F1B<WEN=&%X(#T]("=O
M8VDX)RD@/R`G($E3($Y53$PG(#H@)R`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T
M92@D9F]L9&5R4&%T:"DI.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@("1D96QE=&4@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<W%L*3L*("`@("`@("!I9B`H:7-?82@D9&5L971E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YL;V<H)&1E;&5T92P@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ
M("5S+B(I+"`D9&5L971E+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@
M("`@("`@("\J($%L;"!O:R!N;W<@9&5L971E('1H92!A8W1U86P@9F]L9&5R
M("HO"B`@("`@("`@)'-Q;"`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(
M15)%('9F<U]P871H("5S($%.1"!V9G-?;F%M92`](#\G+`H@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@
M("`@("`@("`@("`@("`@("AE;7!T>2@D<&%T:"D@)B8@)'1H:7,M/E]D8BT^
M9&)S>6YT87@@/3T@)V]C:3@G*2`_("<@25,@3E5,3"<@.B`G(#T@)R`N("1T
M:&ES+3Y?9&(M/G%U;W1E*"1P871H*2D["B`@("`@("`@)'9A;'5E<R`](&%R
M<F%Y*"1N86UE*3L*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'
M7T1%0E5'*3L*("`@("`@("`D9&5L971E(#T@)'1H:7,M/E]D8BT^<75E<GDH
M)'-Q;"P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)&1E;&5T92P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G*"1D96QE=&4L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y.B`E<RXB*2P@)&1E;&5T92T^9V5T365S<V%G92@I*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&1E;&5T93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!A(&QI<W0@;V8@=&AE(&-O;G1E;G1S(&]F(&$@9F]L9&5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@5&AE
M(&1I<F5C=&]R>2!P871H+@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@
M("`@("!3=')I;F<O:&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@;VX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9FEL96YA;64N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER;VYL>2`@(%-H;W<@9&ER96-T
M;W)I97,@;VYL>3\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&:6QE
M(&QI<W0@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?;&ES=$9O;&1E<B@D<&%T:"P@)&9I;'1E<B`](&YU
M;&PL("1D;W1F:6QE<R`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&ER;VYL>2`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H
M:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@
M('T*"B`@("`@("`@)'!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H*"1P871H
M*3L*"B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*("`@("`@("`D9FEL94QI
M<W0@/2!A<G)A>2@I.PH*("`@("`@("`O+R!&:7@@9F]R($]R86-L92!N;W0@
M9&EF9F5R96YT:6%T:6YG(&)E='=E96X@)R<@86YD($Y53$PN"B`@("`@("`@
M:68@*&5M<'1Y*"1P871H*2`F)B`D=&AI<RT^7V1B+3YD8G-Y;G1A>"`]/2`G
M;V-I."<I('L*("`@("`@("`@("`@)'=H97)E(#T@)W9F<U]P871H($E3($Y5
M3$PG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1W:&5R92`]("=V
M9G-?<&%T:"`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D<&%T:"D["B`@("`@
M("`@?0H*("`@("`@("`D<W%L(#T@<W!R:6YT9B@G4T5,14-4('9F<U]N86UE
M+"!V9G-?='EP92P@=F9S7V1A=&$L('9F<U]M;V1I9FEE9"P@=F9S7V]W;F5R
M($923TT@)7,@5TA%4D4@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=VAE<F4I.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1F:6QE3&ES="`]("1T:&ES+3Y?
M9&(M/F=E=$%L;"@D<W%L*3L*("`@("`@("!I9B`H:7-?82@D9FEL94QI<W0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE3&ES
M=#L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D
M;&EN92D@>PH@("`@("`@("`@("`O+R!&:6QT97(@;W5T(&1O=&9I;&5S(&EF
M('1H97D@87)E;B=T('=A;G1E9"X*("`@("`@("`@("`@:68@*"$D9&]T9FEL
M97,@)B8@<W5B<W1R*"1L:6YE6S!=+"`P+"`Q*2`]/2`G+B<I('L*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D9FEL95LG;F%M92==(#T@)&QI;F5;,%T["@H@("`@("`@("`@("!I9B`H
M)&QI;F5;,5T@/3T@5D937T9)3$4I('L*("`@("`@("`@("`@("`@("1N86UE
M(#T@97AP;&]D92@G+B<L("1L:6YE6S!=*3L*"B`@("`@("`@("`@("`@("!I
M9B`H8V]U;G0H)&YA;64I(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL95LG='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2!61E,Z
M.G-T<G1O;&]W97(H)&YA;65;8V]U;G0H)&YA;64I("T@,5TI.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2!6
M1E,Z.G-T<FQE;B@D;&EN95LR72D["B`@("`@("`@("`@('T@96QS96EF("@D
M;&EN95LQ72`]/2!61E-?1D],1$52*2!["B`@("`@("`@("`@("`@("`D9FEL
M95LG='EP92==(#T@)RHJ9&ER)SL*("`@("`@("`@("`@("`@("1F:6QE6R=S
M:7IE)UT@/2`M,3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5;
M)V1A=&4G72`]("1L:6YE6S-=.PH@("`@("`@("`@("`D9FEL95LG;W=N97(G
M72`]("1L:6YE6S1=.PH@("`@("`@("`@("`D9FEL95LG<&5R;7,G72`]("<G
M.PH@("`@("`@("`@("`D9FEL95LG9W)O=7`G72`]("<G.PH*("`@("`@("`@
M("`@+R\@9FEL=&5R:6YG"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V9I;'1E
M<DUA=&-H*"1F:6QT97(L("1F:6QE6R=N86UE)UTI*2!["B`@("`@("`@("`@
M("`@("!U;G-E="@D9FEL92D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&1I<F]N;'D@)B8@)&9I
M;&5;)W1Y<&4G72`A/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@=6YS
M970H)&9I;&4I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1F:6QE<ULD9FEL95LG;F%M92==72`]("1F
M:6QE.PH@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9FEL97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L9&5R<R!I;B!S<&5C:69I960@9&ER
M96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@
M("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('1O(&=E="!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D:7)E8W1O<GD@;&ES
M="!F;W(N"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@("`@4W1R
M:6YG+VAA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A<V5D(&]N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]L9&5R;&ES="X*("`@("`J
M($!P87)A;2!B;V]L96%N("1D;W1F;VQD97)S("!);F-L=61E(&1O=&9O;&1E
M<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1F]L9&5R(&QI<W0@
M;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R<R@D<&%T:"`]("<G+"`D
M9FEL=&5R(#T@87)R87DH*2P@)&1O=&9O;&1E<G,@/2!T<G5E*0H@("`@>PH@
M("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@
M*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)'!A=&@@/2`D=&AI<RT^
M7V-O;G9E<G10871H*"1P871H*3L*"B`@("`@("`@)'-Q;"`@/2`G4T5,14-4
M('9F<U]N86UE+"!V9G-?<&%T:"!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G73L*("`@("`@("`D<W%L("X]("<@5TA%4D4@=F9S7W!A=&@@/2`_
M($%.1"!V9G-?='EP92`](#\G.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH)'!A
M=&@L(%9&4U]&3TQ$15(I.PH*("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES
M+3Y?9&(M/F=E=$%L;"@D<W%L+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?
M82@D9F]L9&5R3&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&9O;&1E<DQI<W0["B`@("`@("`@?0H*("`@("`@("`D9F]L9&5R
M<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&9O;&1E<DQI<W0@87,@
M)&QI;F4I('L*("`@("`@("`@("`@)&9O;&1E<ELG=F%L)UT@/2`D=&AI<RT^
M7V=E=$YA=&EV95!A=&@H)&QI;F5;,5TL("1L:6YE6S!=*3L*("`@("`@("`@
M("`@)&9O;&1E<ELG86)B<F5V)UT@/2`G)SL*("`@("`@("`@("`@)&9O;&1E
M<ELG;&%B96PG72`]("<G.PH*("`@("`@("`@("`@)&-O=6YT(#T@<W5B<W1R
M7V-O=6YT*"1F;VQD97);)W9A;"==+"`G+R<I.PH*("`@("`@("`@("`@)'@@
M/2`P.PH@("`@("`@("`@("!W:&EL92`H)'@@/"`D8V]U;G0I('L*("`@("`@
M("`@("`@("`@("1F;VQD97);)V%B8G)E=B==("X]("<@("`@)SL*("`@("`@
M("`@("`@("`@("1F;VQD97);)VQA8F5L)UT@+CT@)R`@("`G.PH@("`@("`@
M("`@("`@("`@)'@K*SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9O
M;&1E<ELG86)B<F5V)UT@+CT@)&QI;F5;,%T["B`@("`@("`@("`@("1F;VQD
M97);)VQA8F5L)UT@+CT@)&QI;F5;,%T["@H@("`@("`@("`@("`D<W1R;&5N
M(#T@5D93.CIS=')L96XH)&9O;&1E<ELG;&%B96PG72D["B`@("`@("`@("`@
M(&EF("@D<W1R;&5N(#X@,C8I('L*("`@("`@("`@("`@("`@("1F;VQD97);
M)V%B8G)E=B==(#T@<W5B<W1R*"1F;VQD97);)VQA8F5L)UTL(#`L("@D8V]U
M;G0@*B`T*2D["B`@("`@("`@("`@("`@("`D;&5N9W1H(#T@*#(Y("T@*"1C
M;W5N="`J(#0I*2`O(#(["B`@("`@("`@("`@("`@("`D9F]L9&5R6R=A8F)R
M978G72`N/2!S=6)S='(H)&9O;&1E<ELG;&%B96PG72P@*"1C;W5N="`J(#0I
M+"`D;&5N9W1H*3L*("`@("`@("`@("`@("`@("1F;VQD97);)V%B8G)E=B==
M("X]("<N+BXG.PH@("`@("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@
M+CT@<W5B<W1R*"1F;VQD97);)VQA8F5L)UTL("TQ("H@)&QE;F=T:"P@)&QE
M;F=T:"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F;W5N9"`](&9A
M;'-E.PH@("`@("`@("`@("!F;W)E86-H("@D9FEL=&5R(&%S("1F;'1R*2![
M"B`@("`@("`@("`@("`@("!I9B`H)&9O;&1E<ELG=F%L)UT@/3T@)&9L='(I
M('L*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(21F
M;W5N9"D@>PH@("`@("`@("`@("`@("`@)&9O;&1E<G-;)&9O;&1E<ELG=F%L
M)UU=(#T@)&9O;&1E<CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:W-O<G0H)&9O;&1E<G,I.PH@("`@("`@(')E='5R;B`D9F]L9&5R<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M97,@86QL(&-H:6QD('!A=&AS
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!F;VQD97(@
M=&\@<F5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9O
M;&1E<FYA;64@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96-U<G-I=F5296YA;64H
M)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I"B`@("![
M"B`@("`@("`@)&]L9'!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H*"1O;&1P
M871H*3L*("`@("`@("`D;F5W<&%T:"`]("1T:&ES+3Y?8V]N=F5R=%!A=&@H
M)&YE=W!A=&@I.PH*("`@("`@("`D<W%L("`]("=314Q%0U0@=F9S7VYA;64@
M1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT["B`@("`@("`@)'-Q
M;"`N/2`G(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A=&@@/2`_)SL*
M("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*%9&4U]&3TQ$15(L("1T:&ES+3Y?9V5T
M3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I*3L*"B`@("`@("`@)&9O
M;&1E<DQI<W0@/2`D=&AI<RT^7V1B+3YG971#;VPH)'-Q;"P@,"P@)'9A;'5E
M<RD["@H@("`@("`@(&9O<F5A8V@@*"1F;VQD97),:7-T(&%S("1F;VQD97(I
M('L*("`@("`@("`@("`@)'1H:7,M/E]R96-U<G-I=F5296YA;64H)'1H:7,M
M/E]G971.871I=F50871H*"1O;&1P871H+"`D;VQD;F%M92DL("1F;VQD97(L
M("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;F5W<&%T:"P@)&YE=VYA;64I+"`D
M9F]L9&5R*3L*("`@("`@("!]"@H@("`@("`@("1S<6P@/2`G55!$051%("<@
M+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N("<@4T54('9F<U]P871H(#T@
M/R!72$5212!V9G-?<&%T:"`](#\G.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q
M;"P@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH
M)'1H:7,M/E]G971.871I=F50871H*"1N97=P871H+"`D;F5W;F%M92DL("1T
M:&ES+3Y?9V5T3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I*3L*"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V86QU
M97,I.PH*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!A(&9U;&P@9FEL96YA;64@;VX@=&AE(&YA=&EV92!F
M:6QE<WES=&5M+"!F<F]M(&$@5D93"B`@("`@*B!P871H(&%N9"!N86UE+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@(%1H92!61E,@9FEL92!P871H+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(%9&4R!F:6QE;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@;F%T:79E(&9I;&5N
M86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3F%T:79E4&%T:"@D<&%T
M:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P871H*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&YA;64["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1P871H*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P87)A;7-;)VAO;64G72D@)B8*("`@("`@("`@("`@("`@('!R96=?
M;6%T8V@H)WQ>?B\_*"XJ*21\)RP@)'!A=&@L("1M871C:&5S*2D@>PH@("`@
M("`@("`@("`@("`@)'!A=&@@/2`D=&AI<RT^7W!A<F%M<ULG:&]M92==("X@
M)R\G("X@)&UA=&-H97-;,5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<&%T:"`N("<O)R`N("1N86UE.PH@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A('!E<G-I<W1E;G0@8V]N
M;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?9&(@/3T](&9A;'-E*2!["B`@("`@("`@("`@(&EF
M("@A:7-?87)R87DH)'1H:7,M/E]P87)A;7,I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB*2D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1R97%U:7)E9"`](&%R<F%Y*"=P:'!T
M>7!E)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9"!A<R`D=F%L
M*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US
M6R1V86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(BDL("1V86PI*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M
M<ULG=7-E<FYA;64G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@
M)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E7W9F<R<["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V97(@
M=7-I;F<@=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]D
M8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES=&5N="<@
M/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H)'1H:7,M/E]D8BP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@("`@("1E<G)O<B`]("1T:&ES+3Y?
M9&(["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B(#T@9F%L<V4["B`@("`@
M("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`*("`@("`@("`@("`@+R\@4V5T($1"('!O<G1A8FEL:71Y(&]P
M=&EO;G,N"B`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^<&AP='EP
M92D@>PH@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]2
M5$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3('P@
M1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@("`@("`@
M("`@?0H*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&ES8V]N;F5C="!F<F]M('1H92!344P@<V5R=F5R
M(&%N9"!C;&5A;B!U<"!T:&4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE
M8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V1B*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?9&(M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@)'1H
M:7,M/E]D8B`](&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@5$]$3PH@("`@("H@
M0'!A<F%M('-T<FEN9R`D9FEE;&0@("`@(%1/1$\*("`@("`J($!P87)A;2!S
M=')I;F<@)&-R:71E<FEA("!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?<F5A9$)L;V(H)'1A
M8FQE+"`D9FEE;&0L("1C<FET97)I82D*("`@('L*("`@("`@("!I9B`H(6-O
M=6YT*"1C<FET97)I82DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)UEO=2!M=7-T('-P96-I9GD@=&AE(&9E=&-H(&-R:71E<FEA
M)RD["B`@("`@("`@?0H*("`@("`@("`D=VAE<F4@/2`G)SL*"B`@("`@("`@
M<W=I=&-H("@D=&AI<RT^7V1B+3YD8G-Y;G1A>"D@>PH@("`@("`@(&-A<V4@
M)V]C:3@G.@H@("`@("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME
M>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H
M97)E*2D@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R92`N/2`G($%.1"`G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y
M*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("`D=VAE<F4@+CT@)&ME
M>2`N("<@25,@3E5,3"<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1W:&5R92`N/2`D:V5Y("X@)R`]("<@+B`D=&AI
M<RT^7V1B+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H
M)'1H:7,M/E]D8BT^8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%
M("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9I96QD+"`D=&%B;&4L("1W:&5R92DI.PH@("`@("`@("`@("!/0TE%
M>&5C=71E*"1S=&%T96UE;G0I.PH@("`@("`@("`@("!I9B`H3T-)1F5T8VA)
M;G1O*"1S=&%T96UE;G0L("1L;V(I*2!["B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)&QO8ELP72T^;&]A9"@I.PH@("`@("`@("`@("`@("`@:68@*&ES
M7VYU;&PH)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@G56YA8FQE('1O(&QO860@4U%,(&1A=&$N
M)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@4$5!4CHZ<F%I<V5%<G)O<B@G56YA
M8FQE('1O(&QO860@4U%,(&1A=&$N)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1C<FET97)I82!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=VAE<F4I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'=H97)E("X]("<@04Y$("<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D=VAE<F4@+CT@)&ME>2`N("<@/2`G("X@)'1H:7,M/E]D
M8BT^<75O=&4H)'9A;'5E*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'-Q;"`]('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD+"`D=&%B;&4L("1W
M:&5R92D["B`@("`@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?
M1$5"54<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T
M3VYE*"1S<6PI.PH*("`@("`@("`@("`@:68@*&ES7VYU;&PH)')E<W5L="DI
M('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!014%2.CIR86ES945R<F]R
M*"=5;F%B;&4@=&\@;&]A9"!344P@9&%T82XG*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S
M>6YT87@I('L*("`@("`@("`@("`@("`@(&-A<V4@)W!G<W%L)SH*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@<&%C:R@G2"<@+B!S=')L96XH)')E
M<W5L="DL("1R97-U;'0I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1/
M1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@("!43T1/"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F:65L9"`@("`@("!43T1/"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D871A("`@("`@("!43T1/"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M='1R:6)U=&5S("!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?:6YS97)T0FQO8B@D=&%B;&4L
M("1F:65L9"P@)&1A=&$L("1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@("1F
M:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@I.PH*
M("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X*2!["B`@("`@
M("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U
M=&5S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D9FEE
M;&1S6UT@/2`D:V5Y.PH@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'1H
M:7,M/E]D8BT^<75O=&53;6%R="@D=F%L=64I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BT^
M8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-P<FEN=&8H)TE.4T525"!)3E1/("5S("@E<RP@)7,I)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@5D%,5453("@E
M<RP@14U05%E?0DQ/0B@I*2!215154DY)3D<@)7,@24Y43R`Z8FQO8B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T86)L
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:6UP;&]D92@G+"`G+"`D9FEE;&1S*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I96QD+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1V86QU
M97,I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9FEE;&0I*3L*"B`@("`@("`@("`@("1L;V(@/2!/0TE.97=$97-C<FEP
M=&]R*"1T:&ES+3Y?9&(M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("!/0TE"
M:6YD0GE.86UE*"1S=&%T96UE;G0L("<Z8FQO8B<L("1L;V(L("TQ+"!344Q4
M7T),3T(I.PH@("`@("`@("`@("!/0TE%>&5C=71E*"1S=&%T96UE;G0L($]#
M25]$149!54Q4*3L*("`@("`@("`@("`@)&QO8BT^<V%V92@D9&%T82D["B`@
M("`@("`@("`@("1R97-U;'0@/2!/0TE#;VUM:70H)'1H:7,M/E]D8BT^8V]N
M;F5C=&EO;BD["B`@("`@("`@("`@("1L;V(M/F9R964H*3L*("`@("`@("`@
M("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0@/R!T<G5E(#H@4$5!4CHZ<F%I<V5%<G)O<B@G56YK
M;F]W;B!%<G)O<B<I.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!F
M;W)E86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@)&9I96QD<UM=(#T@)&ME>3L*("`@("`@("`@("`@("`@
M("1V86QU97-;72`]("1V86QU93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*"5S+"`E<RD@
M5D%,5453("@E<RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L
M("<L("1F:65L9',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M:65L9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/R<@+B!S=')?
M<F5P96%T*"<L(#\G+"!C;W5N="@D=F%L=65S*2DI.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^
M9&)S>6YT87@I('L*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@8V%S
M92`G<&=S<6PG.@H@("`@("`@("`@("`D=F%L=65S6UT@/2!B:6XR:&5X*"1D
M871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("1V86QU97-;72`]("1D871A.PH@("`@("`@('T*"B`@("`@
M("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)'1H:7,M/FQO
M9R@D<75E<GDL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@(%1/1$\*
M("`@("`J($!P87)A;2!S=')I;F<@)&9I96QD("`@("`@5$]$3PH@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&%T82`@("`@("!43T1/"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1W:&5R92`@("`@(%1/1$\*("`@("`J($!P87)A;2!A<G)A>2`D
M86QS;W5P9&%T92`@5$]$3PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7W5P9&%T94)L;V(H)'1A8FQE
M+"`D9FEE;&0L("1D871A+"`D=VAE<F4L("1A;'-O=7!D871E*0H@("`@>PH@
M("`@("`@("1F:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V86QU97,@/2!A
M<G)A>2@I.PH*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X
M*2!["B`@("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@("1W:&5R97-T
M<FEN9R`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D=VAE<F4@87,@)&ME
M>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H
M97)E<W1R:6YG*2D@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R97-T<FEN
M9R`N/2`G($%.1"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'=H97)E<W1R:6YG("X]("1K97D@+B`G(#T@)R`N("1T:&ES+3Y?9&(M
M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S
M=&%T96UE;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+3YC;VYN96-T:6]N+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G4T5,
M14-4("5S($923TT@)7,@5TA%4D4@)7,@1D]2(%501$%412<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:65L9"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=VAE<F5S=')I;F<I*3L*"B`@("`@("`@("`@($]#245X96-U=&4H)'-T871E
M;65N="P@3T-)7T1%1D%53%0I.PH@("`@("`@("`@("!/0TE&971C:$EN=&\H
M)'-T871E;65N="P@)&QO8BD["B`@("`@("`@("`@("1L;V);,%TM/G-A=F4H
M)&1A=&$I.PH@("`@("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET*"1T:&ES
M+3Y?9&(M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D;&]B6S!=+3YF<F5E
M*"D["B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D[
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT(#\@=')U92`Z(%!%05(Z.G)A
M:7-E17)R;W(H)U5N:VYO=VX@17)R;W(G*3L*"B`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@)'5P9&%T97-T<FEN9R`]("<G.PH@("`@("`@("`@("`D
M=F%L=65S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&%L<V]U
M<&1A=&4@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("1U
M<&1A=&5S=')I;F<@+CT@)&ME>2`N("<@/2`_+"`G.PH@("`@("`@("`@("`@
M("`@)'9A;'5E<UM=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1U<&1A=&5S=')I;F<@+CT@)&9I96QD("X@)R`](#\G.PH@("`@("`@
M("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X*2!["B`@("`@("`@
M("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@8V%S92`G<&=S<6PG.@H@
M("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@8FEN,FAE>"@D9&%T82D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`D=F%L=65S6UT@/2`D9&%T83L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'=H97)E<W1R:6YG(#T@)R<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1W:&5R92!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=VAE<F5S=')I;F<I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'=H97)E<W1R:6YG("X]("<@04Y$("<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D=VAE<F5S=')I;F<@+CT@)&ME
M>2`N("<@/2`_)SL*("`@("`@("`@("`@("`@("1V86QU97-;72`]("1V86QU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G55!$051%("5S(%-%5"`E<R!72$5212`E<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1U<&1A=&5S=')I;F<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'=H97)E<W1R:6YG*3L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@
M("`D=&AI<RT^;&]G*"1Q=65R>2P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T:&4@<&%T:&YA;64@9G)O
M;2!R96=U;&%R(&9I;&5S>7-T96T@9F]R;2!T;R!T:&4@:6YT97)N86P*("`@
M("`J(&9O<FUA="!N965D960@=&\@86-C97-S('1H92!F:6QE(&EN('1H92!D
M871A8F%S92X*("`@("`J($YA;65L>2P@=V4@=VEL;"!T<F5A="`G+R<@87,@
M82!B87-E(&1I<F5C=&]R>2!A<R!T:&ES(&ES('!R971T>2!M=6-H"B`@("`@
M*B!T:&4@<W1A;F1A<F0@=V%Y('1O(&%C8V5S<R!B87-E(&1I<F5C=&]R:65S
M(&]V97(@;6]S="!F:6QE<WES=&5M<RX*?2`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!!
M(%9&4R!P871H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M<&%T:"!W:71H(&%N>2!B96=I;FYI;F<@<VQA<V@@<W1R:7!P960@;V9F+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=%!A=&@H)'!A=&@I"B`@("![
M"B`@("`@("`@:68@*"%E;7!T>2@D<&%T:"D@)B8@*'-T<G!O<R@D<&%T:"P@
M)R\G*2`]/3T@,"DI('L*("`@("`@("`@("`@)'!A=&@@/2!S=')V86PH<W5B
M<W1R*"1P871H+"`Q*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A
M=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S:7IE(&]F
M(&$@9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!F
M:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('-I>F4@;V8@
M=&AE(&9I;&4@:6X@8GET97,@;W(@4$5!4E]%<G)O<B!O;@H@("`@("H@("`@
M("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971&:6QE4VEZ92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@
M/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X
M*2!["B`@("`@("`@8V%S92`G;7ES<6PG.@H@("`@("`@("`@("`D;&5N9W1H
M(#T@)TQ%3D=42"<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=O8VDX)SH*("`@("`@("`@("`@)&QE;F=T:"`]("=,14Y'5$A")SL*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@
M("!C87-E("=S>6)A<V4G.@H@("`@("`@("`@("`D;&5N9W1H(#T@)T1!5$%,
M14Y'5$@G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G<&=S
M<6PG.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1L96YG=&@@/2`G
M3T-4151?3$5.1U1()SL*("`@("`@("!]"@D*("`@("`@("`D<W%L(#T@<W!R
M:6YT9B@*("`@("`@("`@("`@)U-%3$5#5"`E<RAV9G-?9&%T82D@1E)/32`E
M<R!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE(#T@/R<L"B`@("`@
M("`@("`@("1L96YG=&@L"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92=="B`@("`@("`@*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H
M:7,M/E]C;VYV97)T4&%T:"@D<&%T:"DL("1N86UE*3L*("`@("`@("`D=&AI
M<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D<VEZ92`]
M("1T:&ES+3Y?9&(M/F=E=$]N92@D<W%L+"`D=F%L=65S*3L*"B`@("`@("`@
M:68@*&ES7VYU;&PH)'-I>F4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S+R5S7"(N(BDL("1P871H+"`D;F%M92DI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<VEZ92!O9B!A(&9I;&4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("!4:&4@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!S:7IE(&]F('1H92!F;VQD97(@:6X@8GET97,@;W(@
M4$5!4E]%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&;VQD97)3:7IE*"1P871H(#T@
M;G5L;"P@)&YA;64@/2!N=6QL*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H
M:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@
M('T*"B`@("`@("`@)'=H97)E(#T@*&ES7VYU;&PH)'!A=&@I*2`_(&YU;&P@
M.B!S<')I;G1F*"=72$5212!V9G-?<&%T:"`]("5S)RP@*"AE;7!T>2@D<&%T
M:"DI(#\@)R(B)R`Z("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES+3Y?8V]N=F5R
M=%!A=&@H)'!A=&@I*2DI.PH*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M
M/F1B<WEN=&%X*2!["B`@("`@("`@8V%S92`G;7ES<6PG.@H@("`@("`@("`@
M("`D;&5N9W1H(#T@)TQ%3D=42"<["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@)&QE;F=T:"`]("=,14Y'
M5$A")SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)VUS<W%L
M)SH*("`@("`@("!C87-E("=S>6)A<V4G.@H@("`@("`@("`@("`D;&5N9W1H
M(#T@)T1!5$%,14Y'5$@G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`G<&=S<6PG.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1L
M96YG=&@@/2`G3T-4151?3$5.1U1()SL*("`@("`@("!]"@H*("`@("`@("`D
M<W%L(#T@<W!R:6YT9B@*("`@("`@("`@("`@)U-%3$5#5"!354TH)7,H=F9S
M7V1A=&$I*2!&4D]-("5S("5S)RP*("`@("`@("`@("`@)&QE;F=T:"P*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@
M("1W:&5R90H@("`@("`@("D["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!0
M14%27TQ/1U]$14)51RD["B`@("`@("`@)'-I>F4@/2`D=&AI<RT^7V1B+3YG
M971/;F4H)'-Q;"D["@H@("`@("`@(')E='5R;B`H*"%I<U]N=6QL*"1S:7IE
M*2D@/R`D<VEZ92`Z(#`I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]61E,O<W%L7V9I;&4N<&AP````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S(U,34`,3`T,3<S-C(W-S``
M,#(P,30U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*BH*("H@1FEL92!V86QU92!F;W(@=F9S7W1Y<&4@8V]L
M=6UN+@H@*B\*9&5F:6YE*"=61E-?1DE,12<L(#$I.PH*+RHJ"B`J($9O;&1E
M<B!V86QU92!F;W(@=F9S7W1Y<&4@8V]L=6UN+@H@*B\*9&5F:6YE*"=61E-?
M1D],1$52)RP@,BD["@HO*BH*("H@5D93.CH@:6UP;&5M96YT871I;VX@=7-I
M;F<@4$A0)W,@4$5!4B!D871A8F%S92!A8G-T<F%C=&EO;@H@*B!L87EE<B!A
M;F0@;&]C86P@9FEL92!S>7-T96T@9F]R(&9I;&4@<W1O<F%G92X*("H*("H@
M4F5Q=6ER960@=F%L=65S(&9O<B`D<&%R86US.CQP<F4^"B`J("`@("`@)W!H
M<'1Y<&4G("`@("`@(%1H92!D871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@
M)VUY<W%L)RP@971C+BDN"B`J("`@("`@)W9F<W)O;W0G("`@("`@(%1H92!R
M;V]T(&1I<F5C=&]R>2!O9B!W:&5R92!T:&4@9FEL97,@<VAO=6QD(&)E"B`J
M("`@("`@("`@("`@("`@("`@("`@(&%C='5A;&QY('-T;W)E9"X\+W!R93X*
M("H*("H@3W!T:6]N86P@=F%L=65S.CQP<F4^"B`J("`@("`@)W1A8FQE)R`@
M("`@("`@(%1H92!N86UE(&]F('1H92!V9G,@=&%B;&4@:6X@)V1A=&%B87-E
M)RX@1&5F875L=',@=&\*("H@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E
M7W9F<R<N/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@9&%T86)A<V4@
M:6UP;&5M96YT871I;VYS.CQP<F4^"B`J("`@("`@)VAO<W1S<&5C)R`@("`@
M(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("`@
M("=P<F]T;V-O;"<@("`@("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H
M)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@("`@)V1A=&%B87-E)R`@("`@
M(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`@("`G=7-E<FYA;64G
M("`@("`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T
M:&4@9&%T86)A<V4N"B`J("`@("`@)W!A<W-W;W)D)R`@("`@(%1H92!P87-S
M=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`@("`G;W!T
M:6]N<R<@("`@("`@061D:71I;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE
M(&1A=&%B87-E+@H@*B`@("`@("=T='DG("`@("`@("`@("!4:&4@5%19(&]N
M('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("`@("=P
M;W)T)R`@("`@("`@("!4:&4@<&]R="!O;B!W:&EC:"!T;R!C;VYN96-T('1O
M('1H92!D871A8F%S92X\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R
M92!F;W(@=&AE(%9&4R!C86X@8F4@9F]U;F0@:6X*("H@9&%T82]V9G,N<W%L
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<"QV(#$N-#0N-"XQ.2`R,#`V+S`S+S(T(#$V.C0Q.C0Y('-L=7-A<GH@17AP
M("0*("H*("H@0&%U=&AO<B`@36EC:&%E;"!687)G:&5S92`\;6EK92YV87)G
M:&5S94!A<V-E;&QA=&5C:"YC;VT^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@
M*B!`<&%C:V%G92!61E,*("HO"F-L87-S(%9&4U]S<6Q?9FEL92!E>'1E;F1S
M(%9&4R!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT
M(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@
M("`@("HO"B`@("!V87(@)%]D8B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M4F5T<FEE=F4@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@
M<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F
M:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)'!A=&@L("1N
M86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D[
M"B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9I
M;&4@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*"B`@
M("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G
M*2D@>PH@("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1F
M:6QE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G`@/2!`9F]P
M96XH)&9I;&4L("=R8B<I.PH@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1D871A(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D9FEL92DI.PH@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E(&$@9FEL92!I
M;B!T:&4@5D93+"!W:71H('1H92!D871A(&-O<&EE9"!F<F]M(&$@=&5M<&]R
M87)Y"B`@("`@*B!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL96YA
M;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&UP1FEL92`@("`@
M(%1H92!T96UP;W)A<GD@9FEL92!C;VYT86EN:6YG('1H92!D871A('1O(&)E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1O<F5D+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L
M;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1P871H
M+"`D;F%M92P@)'1M<$9I;&4L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@+RH@3F\@;F5E9"!T;R!C:&5C:R!Q=6]T82!H97)E(&%S('=E
M('=I;&P@8VAE8VL@:70@=VAE;B!W92!C86QL"B`@("`@("`@("H@=W)I=&5$
M871A*"DN("HO"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?
M9V5T7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E
M=%]C;VYT96YT<R@D=&UP1FEL92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&1A=&%&4"`]($!F;W!E;B@D=&UP1FEL92P@)W)B)RD["B`@("`@
M("`@("`@("1D871A(#T@0&9R96%D*"1D871A1E`L(&9I;&5S:7IE*"1T;7!&
M:6QE*2D["B`@("`@("`@("`@(&9C;&]S92@D9&%T8490*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YW<FET941A=&$H)'!A=&@L("1N86UE
M+"`D9&%T82P@)&%U=&]C<F5A=&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4W1O<F4@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@
M=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E
M871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@
M)&YA;64L("1D871A+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%7<FET92@G<W1R:6YG)RP@
M)&1A=&$I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@
M("`D9G`@/2!`9F]P96XH)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D
M;F%M92DL("=W)RD["B`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@
M:68@*"1A=71O8W)E871E*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D=&AI<RT^7V=E=$YA=&EV
M95!A=&@H)'!A=&@L("1N86UE*2P@)W<G*3L*("`@("`@("`@("`@("`@(&EF
M("@A)&9P*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(BDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!F=W)I=&4H)&9P
M+"`D9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]W<FET95-13$1A=&$H
M)'!A=&@L("1N86UE+"`D875T;V-R96%T92DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A
M=&@L("1N86UE*2D["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&9I;&4@:6X@
M=&AE(&1A=&%B87-E(&%N9"!T:&4@9FEL92!S>7-T96TN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE
M(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;VQD
M(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S="`@5&AE(&YE
M=R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E*"1P871H+"`D;F%M92P@)&1E
M<W0I"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^7V=E=$YA=&EV95!A
M=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G?%XG
M("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G6R0O77PG+"`D9&5S="DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N(&YO="!M
M;W9E(&9I;&4H<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+B(I
M*3L*("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T
M*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@
M)&9I;&5#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1D97-T+"!N=6QL+"!F
M86QS92D["B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C:R!A<R`D9FEL92D@
M>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N(BDI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H<W1R<&]S*"1D97-T+"`D=&AI<RT^7V=E=%-1
M3$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2D@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^<F5N86UE*"1P871H+"`D;F%M92P@)&1E<W0L("1N86UE*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-O<&EE<R!A(&9I;&4@=&AR;W5G:"!T:&4@
M8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D97-T("!4:&4@9&5S=&EN871I;VX@;V8@=&AE(&9I;&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]P>2@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@>PH@
M("`@("`@("1O<FEG(#T@)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D
M;F%M92D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>)R`N('!R96=?<75O
M=&4H)&]R:6<I("X@)ULD+UU\)RP@)&1E<W0I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;B!N;W0@8V]P>2!F:6QE*',I
M("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*
M("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9FEL
M94-H96-K(#T@)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L(&YU;&PL(&9A;'-E
M*3L*("`@("`@("!F;W)E86-H("@D9FEL94-H96-K(&%S("1F:6QE*2!["B`@
M("`@("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB*2D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("AS=')P;W,H)&1E<W0L("1T:&ES+3Y?9V5T4U%,3F%T
M:79E4&%T:"@D<&%T:"P@)&YA;64I*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V1I<B@D
M;W)I9RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5C=7)S:79E
M0V]P>2@D<&%T:"P@)&YA;64L("1D97-T*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A0&-O<'DH)&]R:6<L("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D9&5S
M="P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB*2D["B`@("`@("`@
M?0H*("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=)
M3E-%4E0@24Y43R`E<R`H=F9S7VED+"!V9G-?='EP92P@=F9S7W!A=&@L('9F
M<U]N86UE+"!V9G-?;6]D:69I960L('9F<U]O=VYE<BD@5D%,5453("@_+"`_
M+"`_+"`_+"`_+"`_*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M*"1I9"P@5D937T9)3$4L("1D97-T+"`D;F%M92P@=&EM92@I+"`D=&AI<RT^
M7W!A<F%M<ULG=7-E<B==*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@=6YL:6YK
M*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D9&5S="P@)&YA;64I*3L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!F;VQD
M97(@;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("!(;VQD<R!T:&4@<&%T:"!O9B!D:7)E8W1O<GD@=&\@8W)E871E(&9O
M;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@($AO;&1S('1H92!N
M86UE(&]F('1H92!N97<@9F]L9&5R+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E
M<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*
M("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTI.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2AS<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H=F9S7VED+"!V9G-?='EP
M92P@=F9S7W!A=&@L('9F<U]N86UE+"!V9G-?;6]D:69I960L('9F<U]O=VYE
M<BD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!604Q515,@*#\L(#\L(#\L(#\L(#\L(#\I)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"1I9"P@5D937T9/3$1%4BP@)'!A=&@L("1N86UE+"!T:6UE*"DL
M("1T:&ES+3Y?<&%R86US6R=U<V5R)UTI*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`;6MD:7(H)'1H:7,M
M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DI*2!["B`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=$14Q%5$4@
M1E)/32`E<R!72$5212!V9G-?:60@/2`_)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)&ED*2D["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E;F%M92!A(&9I;&4@;W(@9F]L9&5R(&EN('1H92!6
M1E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE
M(&]L9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@9FEL96YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5N86UE*"1O;&1P871H+"`D;VQD;F%M92P@)&YE=W!A=&@L
M("1N97=N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN
M96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@
M("`@:68@*'-T<G!O<R@D;F5W<&%T:"P@)R\G*2`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@)'!A<F5N="`]("<G.PH@("`@("`@("`@("`D<&%T:"`]("1N
M97=P871H.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&QI<W0H)'!A
M<F5N="P@)'!A=&@I(#T@97AP;&]D92@G+R<L("1N97=P871H+"`R*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"$D=&AI<RT^:7-&;VQD97(H)'!A<F5N="P@
M)'!A=&@I*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI
M<RT^875T;V-R96%T95!A=&@H)&YE=W!A=&@I+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*'-P<FEN=&8H)U501$%412`E<R!3150@=F9S7W!A=&@@/2`_+"!V9G-?
M;F%M92`](#\L('9F<U]M;V1I9FEE9"`](#\*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@
M04Y$('9F<U]N86UE(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D;F5W
M<&%T:"P@)&YE=VYA;64L('1I;64H*2P@)&]L9'!A=&@L("1O;&1N86UE*2D[
M"@H@("`@("`@(&EF("@D=&AI<RT^7V1B+3YA9F9E8W1E9%)O=W,H*2`]/2`P
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES7V$H)'1H:7,M/E]R96-U<G-I=F5344Q296YA;64H)&]L9'!A
M=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R
M>2AS<')I;G1F*"=54$1!5$4@)7,@4T54('9F<U]P871H(#T@/RP@=F9S7VYA
M;64@/2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64@/2`_
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&]L9'!A=&@L("1O
M;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I*3L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A0&ES7V1I
M<B@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&YE=W!A=&@I*2D@>PH@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1N
M97=P871H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@A0')E;F%M92@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&]L9'!A=&@L("1O
M;&1N86UE*2P@)'1H:7,M/E]G971.871I=F50871H*"1N97=P871H+"`D;F5W
M;F%M92DI*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2AS<')I;G1F*"=54$1!5$4@)7,@4T54('9F<U]P871H(#T@/RP@=F9S
M7VYA;64@/2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&]L9'!A=&@L
M("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I*3L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9O;&1E<B!F<F]M('1H
M92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@
M("`@5&AE('!A=&@@=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H92!F;VQD97)N86UE('1O
M('5S92X*("`@("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@($9O<F-E
M(&$@<F5C=7)S:79E(&1E;&5T93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD97(H
M)'!A=&@L("1N86UE+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?
M82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&-O;FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)')E8W5R<VEV92D@>PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F5M<'1Y1F]L9&5R*"1P871H
M("X@)R\G("X@)&YA;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'!A=&@@+B`G+R<@+B`D
M;F%M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1L:7-T+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&QI<W0["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&-O=6YT*"1L:7-T*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%T:"`N("<O)R`N("1N86UE*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R
M>2AS<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212!V9G-?='EP92`](#\@
M04Y$('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64@/2`_)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*%9&4U]&3TQ$15(L("1P871H+"`D;F%M92DI.PH*("`@
M("`@("!I9B`H)'1H:7,M/E]D8BT^869F96-T9612;W=S*"D@/3T@,"!\?"!I
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1T
M:&ES+3Y?<F5C=7)S:79E4U%,1&5L971E*"1P871H+"`D;F%M92DL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M<F5C=7)S:79E3$931&5L971E*"1P871H+"`D;F%M92DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(I
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5L971E(&$@9FEL92!F<F]M('1H92!61E,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949I;&4H
M)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^7V-H
M96-K475O=&%$96QE=&4H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S.PH@("`@("`@('T*"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE
M8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G1$5,151%
M($923TT@)7,@5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?<&%T:"`](#\@
M04Y$('9F<U]N86UE(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2A61E-?
M1DE,12P@)'!A=&@L("1N86UE*2D["@H@("`@("`@(&EF("@D=&AI<RT^7V1B
M+3YA9F9E8W1E9%)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A0'5N;&EN:R@D=&AI<RT^7V=E=$YA=&EV
M95!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@=&AE(&-O;G1E;G1S(&]F
M(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M("`@("`@5&AE(&1I<F5C=&]R>2!P871H+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1F:6QT97(@("`@("!3=')I;F<O:&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@
M8F%S960@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9FEL
M96YA;64N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%-H;W<@
M9&]T9FEL97,_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER;VYL>2`@(%-H
M;W<@9&ER96-T;W)I97,@;VYL>3\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!&:6QE(&QI<W0@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&ES=$9O;&1E<B@D<&%T:"P@)&9I
M;'1E<B`](&YU;&PL("1D;W1F:6QE<R`]('1R=64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("1D:7)O;FQY(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O
M;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX[
M"B`@("`@("`@?0H*("`@("`@("`D9FEL97,@/2!A<G)A>2@I.PH@("`@("`@
M("1F:6QE3&ES="`](&%R<F%Y*"D["@H@("`@("`@("1F:6QE3&ES="`]("1T
M:&ES+3Y?9&(M/F=E=$%L;"AS<')I;G1F*"=314Q%0U0@=F9S7VYA;64L('9F
M<U]T>7!E+"!V9G-?;6]D:69I960L('9F<U]O=VYE<B!&4D]-("5S"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%
M4D4@=F9S7W!A=&@@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"1P871H*2D["B`@("`@("`@:68@*&ES7V$H)&9I;&5,:7-T+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL94QI<W0["B`@("`@
M("`@?0H*("`@("`@("!F;W)E86-H("@D9FEL94QI<W0@87,@)&QI;F4I('L*
M("`@("`@("`@("`@+R\@1FEL=&5R(&]U="!D;W1F:6QE<R!I9B!T:&5Y(&%R
M96XG="!W86YT960N"B`@("`@("`@("`@(&EF("@A)&1O=&9I;&5S("8F('-U
M8G-T<B@D;&EN95LP72P@,"P@,2D@/3T@)RXG*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5;
M)VYA;64G72`]("1L:6YE6S!=.PH*("`@("`@("`@("`@:68@*"1L:6YE6S%=
M(#T](%9&4U]&24Q%*2!["B`@("`@("`@("`@("`@("`D;F%M92`](&5X<&QO
M9&4H)RXG+"`D;&EN95LP72D["@H@("`@("`@("`@("`@("`@:68@*&-O=6YT
M*"1N86UE*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y
M<&4G72`]("<J*FYO;F4G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@5D93.CIS=')T;VQO
M=V5R*"1N86UE6V-O=6YT*"1N86UE*2`M(#%=*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@9FEL97-I>F4H
M)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;&EN95LP72DI.PH@("`@
M("`@("`@("!](&5L<V5I9B`H)&QI;F5;,5T@/3T@5D937T9/3$1%4BD@>PH@
M("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@
M("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@+3$["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1F:6QE6R=D871E)UT@/2`D;&EN95LR73L*("`@("`@
M("`@("`@)&9I;&5;)V]W;F5R)UT@/2`D;&EN95LS73L*("`@("`@("`@("`@
M)&9I;&5;)W!E<FUS)UT@/2`G)SL*("`@("`@("`@("`@)&9I;&5;)V=R;W5P
M)UT@/2`G)SL*"B`@("`@("`@("`@("\O($9I;'1E<FEN9RX*("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?9FEL=&5R36%T8V@H)&9I;'1E<BP@)&9I;&5;)VYA
M;64G72DI('L*("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D9&ER;VYL>2`F)B`D9FEL95LG='EP92==("$]/2`G*BID:7(G*2![
M"B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5S
M6R1F:6QE6R=N86UE)UU=(#T@)&9I;&4["B`@("`@("`@("`@('5N<V5T*"1F
M:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L
M9&5R<R!I;B!S<&5C:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER
M96-T;W)Y('1O(&=E="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!D:7)E8W1O<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R86T@;6EX
M960@)&9I;'1E<B`@("`@("`@4W1R:6YG+VAA<V@@;V8@:71E;7,@=&\@9FEL
M=&5R(&)A<V5D(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]L9&5R;&ES="X*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F;VQD
M97)S("!);F-L=61E(&1O=&9O;&1E<G,_"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@1F]L9&5R(&QI<W0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M<W1&;VQD97)S*"1P871H(#T@)R<L("1F:6QT97(@/2!A<G)A>2@I+"`D9&]T
M9F]L9&5R<R`]('1R=64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*
M("`@("`@("`D<W%L(#T@<W!R:6YT9B@G4T5,14-4('9F<U]N86UE+"!V9G-?
M<&%T:"!&4D]-("5S(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7W1Y<&4@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72D["@H@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M/E]D8BT^
M9V5T06QL*"1S<6PL(&%R<F%Y*"1P871H+"`D5D937T9/3$1%4BDI.PH@("`@
M("`@(&EF("AI<U]A*"1F;VQD97),:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D9F]L9&5R3&ES=#L*("`@("`@("!]"@H@("`@
M("`@("1F;VQD97)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9F]L
M9&5R3&ES="!A<R`D;&EN92D@>PH@("`@("`@("`@("`D9F]L9&5R6R=V86PG
M72`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;&EN95LQ72P@)&QI;F5;,%TI
M.PH@("`@("`@("`@("`D9F]L9&5R6R=A8F)R978G72`]("<G.PH@("`@("`@
M("`@("`D9F]L9&5R6R=L86)E;"==(#T@)R<["@H@("`@("`@("`@("`D8V]U
M;G0@/2!S=6)S=')?8V]U;G0H)&9O;&1E<ELG=F%L)UTL("<O)RD["@H@("`@
M("`@("`@("`D>"`](#`["B`@("`@("`@("`@('=H:6QE("@D>"`\("1C;W5N
M="D@>PH@("`@("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@+CT@)R`@
M("`G.PH@("`@("`@("`@("`@("`@)&9O;&1E<ELG;&%B96PG72`N/2`G("`@
M("<["B`@("`@("`@("`@("`@("`D>"LK.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D9F]L9&5R6R=A8F)R978G72`N/2`D;&EN95LP73L*("`@("`@
M("`@("`@)&9O;&1E<ELG;&%B96PG72`N/2`D;&EN95LP73L*"B`@("`@("`@
M("`@("1S=')L96X@/2!61E,Z.G-T<FQE;B@D9F]L9&5R6R=L86)E;"==*3L*
M("`@("`@("`@("`@:68@*"1S=')L96X@/B`R-BD@>PH@("`@("`@("`@("`@
M("`@)&9O;&1E<ELG86)B<F5V)UT@/2!S=6)S='(H)&9O;&1E<ELG;&%B96PG
M72P@,"P@*"1C;W5N="`J(#0I*3L*("`@("`@("`@("`@("`@("1L96YG=&@@
M/2`H,CD@+2`H)&-O=6YT("H@-"DI("\@,CL*("`@("`@("`@("`@("`@("1F
M;VQD97);)V%B8G)E=B==("X]('-U8G-T<B@D9F]L9&5R6R=L86)E;"==+"`H
M)&-O=6YT("H@-"DL("1L96YG=&@I.PH@("`@("`@("`@("`@("`@)&9O;&1E
M<ELG86)B<F5V)UT@+CT@)RXN+B<["B`@("`@("`@("`@("`@("`D9F]L9&5R
M6R=A8F)R978G72`N/2!S=6)S='(H)&9O;&1E<ELG;&%B96PG72P@+3$@*B`D
M;&5N9W1H+"`D;&5N9W1H*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&9O=6YD(#T@9F%L<V4["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QT97(@
M87,@)&9L='(I('L*("`@("`@("`@("`@("`@(&EF("@D9F]L9&5R6R=V86PG
M72`]/2`D9FQT<BD@>PH@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("`D9F]L9&5R<ULD
M9F]L9&5R6R=V86PG75T@/2`D9F]L9&5R.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!K<V]R="@D9F]L9&5R<RD["B`@("`@("`@<F5T=7)N
M("1F;VQD97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5C=7)S:79E;'D@
M8V]P:65S('1H92!C;VYT96YT<R!O9B!A(&9O;&1E<B!T;R!A(&1E<W1I;F%T
M:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H
M92!D:7)E8W1O<GD@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4
M:&4@;F%M92!O9B!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&5S="`@5&AE(&1E<W1I;F%T:6]N(&]F('1H92!D:7)E8W1O<GDN"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W)E8W5R<VEV94-O<'DH)'!A=&@L("1N86UE+"`D9&5S="D*
M("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T949O;&1E<B@D
M9&5S="P@)&YA;64I.PH*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@)&9I;&5?;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R
M*"1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*3L*"B`@
M("`@("`@9F]R96%C:"`H)&9I;&5?;&ES="!A<R`D9FEL92D@>PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/F-O<'DH)'1H:7,M/E]G971344Q.871I
M=F50871H*"1P871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTL("1T:&ES+3Y?
M9V5T4U%,3F%T:79E4&%T:"@D9&5S="P@)&YA;64I*3L*"B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@('T*"B`@("`O*BH*("`@("`J
M(%-T;W)E(&$@9FEL97,@:6YF;W)M871I;VX@=VET:&EN('1H92!D871A8F%S
M92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O
M<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!B;V]L
M96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O
M<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?=W)I=&5344Q$871A*"1P871H+"`D;F%M92P@
M)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]("1T
M:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@
M("!]"@H@("`@("`@("\O($9I;&4@86QR96%D>2!E>&ES=',@:6X@9&%T86)A
M<V4*("`@("`@("!I9B`H)'1H:7,M/F5X:7-T<R@D<&%T:"P@)&YA;64I*2![
M"B`@("`@("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R
M86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`@("`@)R!3150@=F9S
M7VUO9&EF:65D(#T@/R<@+@H@("`@("`@("`@("`@("`@("`@("`G(%=(15)%
M('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64@/2`_)SL*("`@("`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*'1I;64H*2P@)'!A=&@L("1N86UE*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT
M260H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH*("`@("`@("`@("`@)'%U
M97)Y(#T@)TE.4T525"!)3E1/("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72`N"B`@("`@("`@("`@("`@("`@("`@("<@*'9F<U]I9"P@=F9S7W1Y<&4L
M('9F<U]P871H+"!V9G-?;F%M92P@=F9S7VUO9&EF:65D+"<@+@H@("`@("`@
M("`@("`@("`@("`@("`G('9F<U]O=VYE<BD@5D%,5453("@_+"`_+"`_+"`_
M+"`_+"`_*2<["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D:60L(%9&
M4U]&24Q%+"`D<&%T:"P@)&YA;64L('1I;64H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R)UTI.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D
M=F%L=65S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M97,@86QL(&-H
M:6QD('!A=&AS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@<&%T
M:"!O9B!T:&4@9F]L9&5R('1O(')E;F%M92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&]L9&YA;64@(%1H92!O;&0@;F%M92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9F]L9&5R('1O(')E
M;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<F5C=7)S:79E4U%,4F5N86UE*"1O;&1P871H
M+"`D;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@
M("1F;VQD97),:7-T(#T@)'1H:7,M/E]D8BT^9V5T0V]L*'-P<FEN=&8H)U-%
M3$5#5"!V9G-?;F%M92!&4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@
M=F9S7W!A=&@@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*%9&4U]&3TQ$15(L("1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D;VQD<&%T
M:"P@)&]L9&YA;64I*2D["@H@("`@("`@(&9O<F5A8V@@*"1F;VQD97),:7-T
M(&%S("1F;VQD97(I('L*("`@("`@("`@("`@)'1H:7,M/E]R96-U<G-I=F53
M44Q296YA;64H)'1H:7,M/E]G971344Q.871I=F50871H*"1O;&1P871H+"`D
M;VQD;F%M92DL("1F;VQD97(L("1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D
M;F5W<&%T:"P@)&YE=VYA;64I+"`D9F]L9&5R*3L*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=54$1!
M5$4@)7,@4T54('9F<U]P871H(#T@/R!72$5212!V9G-?<&%T:"`](#\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)'1H:7,M/E]G971344Q.871I=F50871H
M*"1N97=P871H+"`D;F5W;F%M92DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D
M;VQD<&%T:"P@)&]L9&YA;64I*2D["@H@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@
M9F]L9&5R<R!C;VYT96YT<R!F<F]M('1H92!61E,@:6X@=&AE(%-13"!D871A
M8F%S92P*("`@("`J(')E8W5R<VEV96QY+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M(%1H92!P871H(&]F('1H92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@9F]L9&5R;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E
M8W5R<VEV95-13$1E;&5T92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%3$5412!&
M4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A=&@@/2`_)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*%9&4U]&24Q%+"`D=&AI<RT^7V=E=%-1
M3$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D9F]L9&5R3&ES="`]("1T
M:&ES+3Y?9&(M/F=E=$-O;"AS<')I;G1F*"=314Q%0U0@=F9S7VYA;64@1E)/
M32`E<R!72$5212!V9G-?='EP92`](#\@04Y$('9F<U]P871H(#T@/R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@,"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2A61E-?1D],1$52+"`D=&AI
M<RT^7V=E=%-13$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2DI.PH*("`@("`@
M("!F;W)E86-H("@D9F]L9&5R3&ES="!A<R`D9F]L9&5R*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<F5C=7)S:79E4U%,1&5L971E*"1T:&ES+3Y?9V5T4U%,
M3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I+"`D9F]L9&5R*3L*("`@("`@("!]
M"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F
M*"=$14Q%5$4@1E)/32`E<R!72$5212!V9G-?='EP92`](#\@04Y$('9F<U]N
M86UE(#T@/R!!3D0@=F9S7W!A=&@@/2`_)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*%9&4U]&3TQ$15(L("1N86UE+"`D<&%T:"DI.PH*("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9O
M;&1E<G,@8V]N=&5N=',@9G)O;2!T:&4@5D93+"!R96-U<G-I=F5L>2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@9F]L9&5R+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9O;&1E<FYA;64@=&\@=7-E
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]R96-U<G-I=F5,1E-$96QE=&4H)'!A=&@L("1N86UE
M*0H@("`@>PH@("`@("`@("1D:7(@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H
M)'!A=&@L("1N86UE*3L*("`@("`@("`D9&@@/2!`;W!E;F1I<B@D9&ER*3L*
M"B`@("`@("`@=VAI;&4@*&9A;'-E("$]/2`H)&9I;&4@/2!R96%D9&ER*"1D
M:"DI*2!["B`@("`@("`@("`@(&EF("@D9FEL92`A/2`G+B<@)B8@)&9I;&4@
M(3T@)RXN)RD@>PH@("`@("`@("`@("`@("`@:68@*&ES7V1I<B@D9&ER("X@
M)R\G("X@)&9I;&4I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R
M96-U<G-I=F5,1E-$96QE=&4H96UP='DH)'!A=&@I(#\@)&YA;64@.B`D<&%T
M:"`N("<O)R`N("1N86UE+"`D9FEL92D["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH)&1I<B`N("<O)R`N
M("1F:6QE*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!`8VQO<V5D:7(H)&1H*3L*"B`@("`@("`@<F5T=7)N
M(')M9&ER*"1D:7(I.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@;W!E;B!A('!E<G-I<W1E;G0@8V]N;F5C=&EO;B!T;R!T:&4@4U%,('-E
M<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?9&(@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]P
M87)A;7,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)')E<75I<F5D(#T@87)R87DH)W!H<'1Y<&4G+"`G=F9S<F]O="<I
M.PH@("`@("`@("`@("!F;W)E86-H("@D<F5Q=6ER960@87,@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULD=F%L
M72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(I+"`D=F%L*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72`]("<G.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=U
M<V5R;F%M92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W5S97)N86UE)UT@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@)R<[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72`]("=H;W)D95]V9G,G.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S
M:6YG('1H92!S=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?9&(@
M/2`F1$(Z.F-O;FYE8W0H)'1H:7,M/E]P87)A;7,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!E<G-I<W1E;G0G(#T^
M("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==*2DI.PH@("`@
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V1B.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D8B`](&9A;'-E.PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@
M4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N"B`@("`@("`@("`@('-W:71C
M:"`H)'1H:7,M/E]D8BT^<&AP='EP92D@>PH@("`@("`@("`@("!C87-E("=M
M<W-Q;"<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH
M)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?
M4$]25$%"24Q)5%E?15)23U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL
M:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)
M5%E?15)23U)3*3L*("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C
M="!F<F]M('1H92!344P@<V5R=F5R(&%N9"!C;&5A;B!U<"!T:&4@8V]N;F5C
M=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7V1B*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(M/F1I<V-O;FYE
M8W0H*3L*("`@("`@("`@("`@)'1H:7,M/E]D8B`](&9A;'-E.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&9U;&P@9FEL96YA
M;64@;VX@=&AE(&YA=&EV92!F:6QE<WES=&5M+"!F<F]M(&$@5D93"B`@("`@
M*B!P871H(&%N9"!N86UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!61E,@
M9FEL92!P871H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(%9&
M4R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&9U;&P@;F%T:79E(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@
M*"%E;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@)&YA;64@/2`G+R<@+B`D
M;F%M93L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1P871H*2D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)VAO;64G72D@
M)B8*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)WQ>?B\_*"XJ*21\)RP@
M)'!A=&@L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'!A=&@@/2`D
M=&AI<RT^7W!A<F%M<ULG:&]M92==("`N("<O)R`N("1M871C:&5S6S%=.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A
M;7-;)W9F<W)O;W0G72`N("<O)R`N("1P871H("X@)&YA;64["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US6R=V
M9G-R;V]T)UT@+B`D;F%M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@82!F=6QL(%-13"!F:6QE;F%M92!O;B!T:&4@;F%T:79E
M(&9I;&5S>7-T96TL(&9R;VT@82!61E,*("`@("`J('!A=&@@86YD(&YA;64N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(%9&4R!F:6QE('!A=&@N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@5D93(&9I;&5N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"!N871I=F4@9FEL
M96YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971344Q.871I=F50871H
M*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'!A=&@I
M*2!["B`@("`@("`@("`@(')E='5R;B`D;F%M93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<&%T:"`N("<O)R`N("1N86UE.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ92!O9B!A(&9I;&4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@(%1H92!S:7IE(&]F('1H92!F:6QE(&EN(&)Y=&5S
M(&]R(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1FEL95-I>F4H)'!A=&@L
M("1N86UE*0H@("`@>PH@("`@("`@(&EF("@H)'-I>F4@/2!`9FEL97-I>F4H
M)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DI*2`]/3T@9F%L
M<V4I>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(L("1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<VEZ93L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]61E,O25-/5W)I=&5R+G!H<```````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#8U,S<`,3`T,3<S-C(W-S``,#(P,3<W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@H@*B!61E,@05!)(&9O<B!A8G-T
M<F%C=&5D(&-R96%T:6]N(&]F($E33R`H0T0M4D]-*2!F:6QE<WES=&5M<RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(N<&AP+'8@,2XQ+C@N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C0S(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT
M='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^
M"B`J($!P86-K86=E(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M+PIC;&%S<R!61E-?25-/5W)I=&5R('L*"B`@("`O*BH*("`@("`J($$@5D93
M(&]B:F5C="!U<V5D(&9O<B!R96%D:6YG('1H92!S;W5R8V4@9FEL97,*("`@
M("`J"B`@("`@*B!`=F%R(%9&4PH@("`@("HO"B`@("!V87(@)%]S;W5R8V56
M9G,@/2!N=6QL.PH*("`@("\J*@H@("`@("H@02!61E,@;V)J96-T('5S960@
M9F]R('=R:71I;F<@=&AE($E33R!I;6%G90H@("`@("H*("`@("`J($!V87(@
M5D93"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=%9F<R`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=',@82!N97<@5D937TE33U=R:71E<B!O8FIE8W0*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@<&%R86UE
M=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@5D937TE33U=R:71E<B@F)'-O
M=7)C959F<RP@)B1T87)G97169G,L("1P87)A;7,I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S;W5R8V569G,@/2`F)'-O=7)C959F<SL*("`@("`@("`D=&AI
M<RT^7W1A<F=E=%9F<R`]("8D=&%R9V5T5F9S.PH@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T
M92!T:&4@25-/(&EM86=E"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@3G5L;"!O<B!014%27T5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R;V-E<W,H*0H@("`@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!I;7!L
M96UE;G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O
M(&-R96%T92!A(&-O;F-R971E(%9&4U])4T]7<FET97(@<W5B8VQA<W,N"B`@
M("`@*@H@("`@("H@5&AI<R!M971H;V0@=7-E<R!I=',@<&%R86UE=&5R<R!A
M;F0@8VAE8VMS('1H92!S>7-T96T@=&\@9&5T97)M:6YE"B`@("`@*B!T:&4@
M;6]S="!A<'!R;W!R:6%T92!S=6)C;&%S<R!T;R!U<V4@9F]R(&)U:6QD:6YG
M($E33R!I;6%G97,N("!)9@H@("`@("H@;F]N92!I<R!F;W5N9"P@86X@97)R
M;W(@:7,@<F%I<V5D+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1S
M;W5R8V569G,@("`@("!2969E<F5N8V4@=&\@=&AE(%9&4R!O8FIE8W0@9G)O
M;2!W:&EC:`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!F:6QE<R!W:6QL(&)E(')E860@=&\@8W)E871E('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($E33R!I;6%G92X*("`@
M("`J($!P87)A;2!O8FIE8W0@)B1T87)G97169G,@("`@("!2969E<F5N8V4@
M=&\@=&AE(%9&4R!O8FIE8W0@=&\@=VAI8V@@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@25-/(&EM86=E('=I;&P@8F4@=W)I
M='1E;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@("!(
M87-H(&]F('!A<F%M971E<G,@9F]R(&-R96%T:6YG('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM86=E.@H@("`@("H@("`@
M("`@("`@("`@("=S;W5R8V52;V]T)R`]/B`@("`@02!D:7)E8W1O<GD@:6X@
M=&AE('-O=7)C92!61E,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F:6QE<R!T;R!B92!R96%D(&9R;VT@9F]R('1H92!I
M;6%G92X*("`@("`J("`@("`@("`@("`@("`G=&%R9V5T1FEL92<@/3X@("`@
M(%!A=&@@86YD(&9I;&5N86UE(&]F('1H92!)4T\@9FEL92!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=W)I=&4@:6YT;R!T
M:&4@=&%R9V5T(%9&4RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@
M("`@("`@("`@("`@("`@02!N97=L>2!C<F5A=&5D(&-O;F-R971E(%9&4U])
M4T]7<FET97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=6)C;&%S<RP@;W(@82!014%27T5R<F]R(&]N(&%N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@F)'-O=7)C959F<RP@)B1T87)G
M97169G,L("1P87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A
M;7-;)W1A<F=E=$9I;&4G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+B(I*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M
M<'1Y*"1P87)A;7-;)W-O=7)C95)O;W0G72DI('L*("`@("`@("`@("`@)'!A
M<F%M<ULG<V]U<F-E4F]O="==(#T@)R\G.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4FEG:'0@;F]W+"!M:VES;V9S(&ES('1H92!O;FQY(&1R:79E<BP@8G5T
M(&UA:V4@<W5R92!W92!C86X*("`@("`@("`@*B!S=7!P;W)T(&ET+B`J+PH@
M("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP)SL*("`@("`@("!I9B`H5D937TE33U=R:71E
M<E]M:VES;V9S.CIS=')A=&5G>4%V86EL86)L92@I*2!["B`@("`@("`@("`@
M("1I<V]W<FET97(@/2`F;F5W(%9&4U])4T]7<FET97)?;6MI<V]F<R@D<V]U
M<F-E5F9S+"`D=&%R9V5T5F9S+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@
M("`@(')E='5R;B`D:7-O=W)I=&5R.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RXB*2D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O5D93+VUU<W%L+G!H<```````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#0S-30W`#$P-#$W,S8R-S<P`#`Q-S4Q,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]S<6PN<&AP)SL*"B\J
M*@H@*B!097)M:7-S:6]N(&9O<B!R96%D(&%C8V5S<RX*("HO"F1E9FEN92@G
M5D937T9,04=?4D5!1"<L(#$I.PH*+RHJ"B`J(%!E<FUI<W-I;VX@9F]R(')E
M860@86-C97-S+@H@*B\*9&5F:6YE*"=61E-?1DQ!1U]74DE412<L(#(I.PH*
M+RHJ"B`J($UU;'1I(%5S97(@5D93(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G
M<R!014%2(&1A=&%B87-E"B`J(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!2
M97%U:7)E9"!V86QU97,@9F]R("1P87)A;7,Z/'!R93X*("H@("`@("`G<&AP
M='EP92<@("`@("`@5&AE(&1A=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG+"`G
M;7ES<6PG+"!E=&,N*2X\+W!R93X*("H*("H@3W!T:6]N86P@=F%L=65S.CQP
M<F4^"B`J("`@("`@)W1A8FQE)R`@("`@("`@(%1H92!N86UE(&]F('1H92!V
M9G,@=&%B;&4@:6X@)V1A=&%B87-E)RX@1&5F875L=',@=&\*("H@("`@("`@
M("`@("`@("`@("`@("`@)VAO<F1E7VUU=F9S)RX\+W!R93X*("H*("H@4F5Q
M=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*
M("H@("`@("`G:&]S='-P96,G("`@("`@5&AE(&AO<W1N86UE(&]F('1H92!D
M871A8F%S92!S97)V97(N"B`J("`@("`@)W!R;W1O8V]L)R`@("`@(%1H92!C
M;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*
M("H@("`@("`G9&%T86)A<V4G("`@("`@5&AE(&YA;64@;V8@=&AE(&1A=&%B
M87-E+@H@*B`@("`@("=U<V5R;F%M92<@("`@("!4:&4@=7-E<FYA;64@=VET
M:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`@("`G
M<&%S<W=O<F0G("`@("`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G
M=7-E<FYA;64G+@H@*B`@("`@("=O<'1I;VYS)R`@("`@("!!9&1I=&EO;F%L
M(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W1T
M>2<@("`@("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T
M:&4@9&%T86)A<V4N"B`J("`@("`@)W!O<G0G("`@("`@("`@(%1H92!P;W)T
M(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@
M*@H@*B!+;F]W;B!)<W-U97,Z"B`J($1E;&5T92!I<R!N;W0@<F5C=7-I=F4L
M('-O(&9I;&5S(&%N9"!F;VQD97)S('1H870@=7-E9"!T;R!B92!I;B!A(&9O
M;&1E<@H@*B!T:&%T(&=E=',@9&5L971E9"!L:79E(&9O<F5V97(@:6X@=&AE
M(&1A=&%B87-E+"!O<B!R92UA<'!E87(@=VAE;B!T:&4@9F]L9&5R"B`J(&ES
M(')E8W)E871E9"X*("H@4F5N86UE(&AA<R!T:&4@<V%M92!I<W-U92P@<V\@
M9FEL97,@87)E(&QO<W0@:68@82!F;VQD97(@:7,@<F5N86UE9"X*("H*("H@
M5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE(%9&4R!C86X@8F4@9F]U;F0@
M:6X*("H@9&%T82]M=79F<RYS<6PN"B`J"B`J($1A=&%B87-E('-P96-I9FEC
M(&YO=&5S.@H@*@H@*B!-4U-13#H*("H@+2!4:&4@=F9S7V1A=&$@9FEE;&0@
M;75S="!B92!O9B!T>7!E($E-04=%+@H@*B`M(%EO=2!N965D('1H92!F;VQL
M;W=I;F<@<&AP+FEN:2!S971T:6YG<SH*("H@/&-O9&4^"B`J("`@(#L@5F%L
M:60@<F%N9V4@,"`M(#(Q-#<T.#,V-#<N($1E9F%U;'0@/2`T,#DV+@H@*B`@
M("!M<W-Q;"YT97AT;&EM:70@/2`P(#L@>F5R;R!T;R!P87-S('1H<F]U9V@*
M("H*("H@("`@.R!686QI9"!R86YG92`P("T@,C$T-S0X,S8T-RX@1&5F875L
M="`](#0P.38N"B`J("`@(&US<W%L+G1E>'1S:7IE(#T@,"`[('IE<F\@=&\@
M<&%S<R!T:')O=6=H"B`J(#PO8V]D93X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`L=B`Q+C,P+C0N,30@,C`P-B\P,R\Q,B`Q
M.#HT.#HP,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@
M5D93"B`J+PIC;&%S<R!61E-?;75S<6P@97AT96YD<R!61E-?<W%L('L*"B`@
M("`O*BH*("`@("`J($QI<W0@;V8@<&5R;6ES<VEO;G,@86YD(&EF('1H97D@
M8V%N(&)E(&-H86YG960@:6X@=&AI<R!61E,*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E<FUI<W-I;VYS(#T@87)R87DH
M"B`@("`@("`@)V]W;F5R)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W
M<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DL"B`@("`@("`@
M)V=R;W5P)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@
M9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DL"B`@("`@("`@)V%L;"<@("`]
M/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@("=W<FET92<@/3X@=')U92P@("=E
M>&5C=71E)R`]/B!F86QS92D*("`@("D["@H@("`@+RHJ"B`@("`@*B!3=&]R
M92!A(&9I;&4@:6X@=&AE(%9&4R!F<F]M(')A=R!D871A+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S
M=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M("`@("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T82`@("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@
M9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D;F%M
M92P@)&1A=&$L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@=W)I=&4@
M86-C97-S('1O('1H:7,@86YD(&%L;"!P87)E;G0*("`@("`@("`@*B!P871H
M<RX@*B\*("`@("`@("!I9B`H)'!A=&@@(3T@)R<I('L*("`@("`@("`@("`@
M)'!A=&AS(#T@97AP;&]D92@G+R<L("1P871H*3L*("`@("`@("`@("`@)'!A
M=&A?;F%M92`](&%R<F%Y7W!O<"@D<&%T:',I.PH@("`@("`@("`@("!I9B`H
M(21T:&ES+3YI<T9O;&1E<BAI;7!L;V1E*"<O)RP@)'!A=&AS*2P@)'!A=&A?
M;F%M92DI('L*("`@("`@("`@("`@("`@(&EF("@A)&%U=&]C<F5A=&4I('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(I+"`D<&%T:"DL
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50
M871H*"1P871H*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&%T:'-;
M72`]("1P871H7VYA;64["B`@("`@("`@("`@("1P<F5V:6]U<R`]("<G.PH*
M("`@("`@("`@("`@9F]R96%C:"`H)'!A=&AS(&%S("1T:&ES<&%T:"D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L=',@/2`D=&AI<RT^7V1B+3YG971!;&PH
M<W!R:6YT9B@G4T5,14-4('9F<U]O=VYE<BP@=F9S7W!E<FUS($923TT@)7,*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64](#\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D
M<')E=FEO=7,L("1T:&ES<&%T:"DI.PH@("`@("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D<F5S=6QT<RD@?'P@8V]U;G0H)')E<W5L=',I(#P@,2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(BDI.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("1A;&QO=V5D(#T@9F%L<V4["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT<R!A<R`D<F5S=6QT*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,%T@/3T@)'1H:7,M/E]P
M87)A;7-;)W5S97(G72!\?"`D<F5S=6QT6S%=("8@5D937T9,04=?5U))5$4I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%L;&]W960@/2!T<G5E.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@
M*"$D86QL;W=E9"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I
M;&4N(BDI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1P
M<F5V:6]U<R`]("1T:&ES<&%T:#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ=W)I=&5$871A*"1P871H+"`D;F%M
M92P@)&1A=&$L("1A=71O8W)E871E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1E;&5T92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE
M(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE
M('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE*"1P871H+"`D;F%M92D*
M("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1C;VYN*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9FEL94QI<W0@/2`D
M=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4('9F<U]I9"P@=F9S
M7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`]
M(#\@04Y$('9F<U]N86UE/2`_($%.1"!V9G-?='EP92`](#\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)'!A=&@L("1N86UE+"!61E-?1DE,12DI
M.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QE3&ES="D@?'P@8V]U;G0H
M)&9I;&5,:7-T*2`\(#$I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB*2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!4:&5R92!M87D@8F4@;VYE(&]R(&UO<F4@
M9FEL97,@=VET:"!T:&4@<V%M92!N86UE(&)U="!T:&4*("`@("`@("`@("!U
M<V5R(&UA>2!N;W0@:&%V92!R96%D(&%C8V5S<R!T;R!T:&5M+"!S;R!D;V5S
M;B=T('-E90H@("`@("`@("`@('1H96TN(%-O('=E(&AA=F4@=&\@9&5L971E
M('1H92!O;F4@=&AE>2!H879E(&%C8V5S<R!T;RX@*B\*("`@("`@("!F;W)E
M86-H("@D9FEL94QI<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F
M:6QE6S%=(#T]("1T:&ES+3Y?<&%R86US6R=U<V5R)UT@?'P@)&9I;&5;,ET@
M)B!61E-?1DQ!1U]74DE412D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(
M15)%('9F<U]I9"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"1F:6QE6S!=*2D["@H@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?9&(M/F%F9F5C=&5D4F]W<R@I(#T](#`I('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!&25A-13H@)T%C8V5S<R!$96YI960@9&5L971I
M;F<@9FEL92`E<R\E<R<*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E;F%M92!A(&9I;&4@;W(@9F]L9&5R(&EN('1H92!6
M1E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE
M(&]L9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@9FEL96YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5N86UE*"1O;&1P871H+"`D;VQD;F%M92P@)&YE=W!A=&@L
M("1N97=N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN
M96-T*"D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-O;FXI*2!["B`@
M("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1F
M:6QE3&ES="`]("1T:&ES+3Y?9&(M/F=E=$%L;"AS<')I;G1F*"=314Q%0U0@
M=F9S7VED+"!V9G-?;W=N97(L('9F<U]P97)M<R!&4D]-("5S"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE/2`_)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&]L9'!A=&@L("1O;&1N
M86UE*2D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&9I;&5,:7-T*2!\?"!C
M;W5N="@D9FEL94QI<W0I(#P@,2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(I
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')P;W,H)&YE=W!A=&@L("<O
M)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)E;G0@/2`G)SL*("`@
M("`@("`@("`@)'!A=&@@/2`D;F5W<&%T:#L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!L:7-T*"1P87)E;G0L("1P871H*2`](&5X<&QO9&4H)R\G
M+"`D;F5W<&%T:"P@,BD["B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M
M/FES1F]L9&5R*"1P87)E;G0L("1P871H*2D@>PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1N97=P871H
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%1H
M97)E(&UA>2!B92!O;F4@;W(@;6]R92!F:6QE<R!W:71H('1H92!S86UE(&YA
M;64@8G5T('1H92!U<V5R(&UA>0H@("`@("`@("`J(&YO="!H879E(')E860@
M86-C97-S('1O('1H96TL('-O(&1O97-N)W0@<V5E('1H96TN(%-O('=E(&AA
M=F4@=&\*("`@("`@("`@*B!R96YA;64@=&AE(&]N92!T:&5Y(&AA=F4@86-C
M97-S('1O+B`J+PH@("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D9FEL
M92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;,5T@/3T@)'1H:7,M/E]P87)A
M;7-;)W5S97(G72!\?"`D9FEL95LR72`F(%9&4U]&3$%'7U=2251%*2!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R
M:6YT9B@G55!$051%("5S(%-%5"!V9G-?<&%T:"`](#\L('9F<U]N86UE(#T@
M/RP@=F9S7VUO9&EF:65D(#T@/PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@=F9S7VED(#T@/R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&YE=W!A
M=&@L("1N97=N86UE+"!T:6UE*"DL("1F:6QE6S!=*2D["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(I+"`D;VQD<&%T:"P@
M)&]L9&YA;64I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!F
M;VQD97(@;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("!(;VQD<R!T:&4@<&%T:"!O9B!D:7)E8W1O<GD@=&\@8W)E871E
M(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@($AO;&1S('1H
M92!N86UE(&]F('1H92!N97<@9F]L9&5R+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O
M;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI
M<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N
M;BDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@
M("`@("`@+RH@;6%K92!S=7)E('=E(&AA=F4@=W)I=&4@86-C97-S('1O('1H
M:7,@86YD(&%L;"!P87)E;G0@<&%T:',@*B\*("`@("`@("!I9B`H)'!A=&@@
M(3T@(B(I('L*("`@("`@("`@("`@)'!A=&AS(#T@97AP;&]D92@G+R<L("1P
M871H*3L*("`@("`@("`@("`@)'!R979I;W5S(#T@)R<["@H@("`@("`@("`@
M("!F;W)E86-H("@D<&%T:',@87,@)'1H:7-P871H*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT<R`]("1T:&ES+3Y?9&(M/F=E=$%L;"AS<')I;G1F*"=3
M14Q%0U0@=F9S7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE/2`_)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)'!R979I;W5S+"`D=&AI<W!A=&@I*3L*("`@("`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)')E<W5L=',I('Q\(&-O=6YT*"1R97-U;'1S*2`\
M(#$I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(BDI.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1A;&QO=V5D(#T@
M9F%L<V4["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT<R!A<R`D
M<F5S=6QT*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,%T@
M/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D<F5S=6QT6S%=("8@5D93
M7T9,04=?5U))5$4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%L;&]W
M960@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@:68@*"$D86QL;W=E9"D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)'!R979I;W5S(#T@)'1H:7-P871H.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN
M97AT260H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H
M=F9S7VED+"!V9G-?='EP92P@=F9S7W!A=&@L('9F<U]N86UE+"!V9G-?;6]D
M:69I960L('9F<U]O=VYE<BP@=F9S7W!E<FUS*0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%9!3%5%4R`H/RP@/RP@/RP@/RP@
M/RP@/RP@/RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)&ED+"!61E-?1D],1$52+"`D
M<&%T:"P@)&YA;64L('1I;64H*2P@)'1H:7,M/E]P87)A;7-;)W5S97(G72P@
M,"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9FEL92!F<F]M
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M("`@("`@5&AE('!A=&@@=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H92!F;VQD97)N86UE
M('1O('5S92X*("`@("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@($9O
M<F-E(&$@<F5C=7)S:79E(&1E;&5T93\*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD
M97(H)'!A=&@L("1N86UE+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@("`@<F5T=7)N("1C
M;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R96-U<G-I=F4I('L*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3YE;7!T>49O;&1E<B@D<&%T:"`N
M("<O)R`N("1N86UE*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H("X@)R\G("X@)&YA
M;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("AC;W5N="@D;&ES="DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA
M8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A=&@@+B`G+R<@+B`D;F%M92DI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D9FEL94QI<W0@/2`D=&AI<RT^7V1B+3YG971!
M;&PH<W!R:6YT9B@G4T5,14-4('9F<U]I9"P@=F9S7V]W;F5R+"!V9G-?<&5R
M;7,@1E)/32`E<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V
M9G-?;F%M93T@/R!!3D0@=F9S7W1Y<&4@/2`_)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)'!A=&@L("1N86UE+"!61E-?1D],1$52
M*2D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&9I;&5,:7-T*2!\?"!C;W5N
M="@D9FEL94QI<W0I(#P@,2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@5&AE<F4@;6%Y(&)E(&]N92!O
M<B!M;W)E(&9O;&1E<G,@=VET:"!T:&4@<V%M92!N86UE(&)U="!A<R!T:&4@
M=7-E<@H@("`@("`@("`J(&UA>2!N;W0@:&%V92!R96%D(&%C8V5S<R!T;R!T
M:&5M+"!T:&5Y(&1O;B=T('-E92!T:&5M+B!3;R!W92!H879E('1O"B`@("`@
M("`@("H@9&5L971E('1H92!O;F4@=&AE>2!H879E(&%C8V5S<R!T;R`J+PH@
M("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D9FEL92D@>PH@("`@("`@
M("`@("!I9B`H)&9I;&5;,5T@/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\
M?"`D9FEL95LR72`F(%9&4U]&3$%'7U=2251%*2!["B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G1$5,151%
M($923TT@)7,@5TA%4D4@=F9S7VED(#T@/R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)&9I;&5;,%TI*3L*"B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]D8BT^869F96-T9612;W=S*"D@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($9)6$U%.B`G06-C
M97-S($1E;FEE9"!D96QE=&EN9R!F;VQD97(@)7,O)7,G"B`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A
M(&QI<W0@;V8@=&AE(&-O;G1E;G1S(&]F(&$@9F]L9&5R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@5&AE('!A=&@@;V8@=&AE
M(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@
M4W1R:6YG+VAA<V@@=&\@9FEL=&5R(&9I;&4O9&ER;F%M92!O;BX*("`@("`J
M($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@4VAO=R!D;W1F:6QE<S\*("`@
M("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@4VAO=R!O;FQY(&1I<F5C
M=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@($9I;&4@;&ES
M="!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]L:7-T1F]L9&5R*"1P871H+"`D9FEL=&5R(#T@;G5L;"P@
M)&1O=&9I;&5S(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@)&1I
M<F]N;'D@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?
M8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@
M("`@("`@("1F:6QE<R`](&%R<F%Y*"D["B`@("`@("`@)&9I;&5,:7-T(#T@
M87)R87DH*3L*"B`@("`@("`@)&9I;&5,:7-T(#T@)'1H:7,M/E]D8BT^9V5T
M06QL*'-P<FEN=&8H)U-%3$5#5"!V9G-?;F%M92P@=F9S7W1Y<&4L('9F<U]M
M;V1I9FEE9"P@=F9S7V]W;F5R+"!V9G-?<&5R;7,L('9F<U]D871A($923TT@
M)7,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$("AV9G-?;W=N97(@/2`_(&]R
M('9F<U]P97)M<R`F)B`_*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@D<&%T:"P@)'1H:7,M/E]P87)A;7-;)W5S97(G72P@5D937T9,04=?4D5!
M1"DI.PH@("`@("`@(&EF("AI<U]A*"1F:6QE3&ES="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;&5,:7-T.PH@("`@("`@('T*
M"B`@("`@("`@9F]R96%C:"`H)&9I;&5,:7-T(&%S("1L:6YE*2!["B`@("`@
M("`@("`@("\O($9I;'1E<B!O=70@9&]T9FEL97,@:68@=&AE>2!A<F5N)W0@
M=V%N=&5D+@H@("`@("`@("`@("!I9B`H(21D;W1F:6QE<R`F)B!S=6)S='(H
M)&QI;F5;,%TL(#`L(#$I(#T]("<N)RD@>PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE6R=N86UE
M)UT@/2!S=')I<'-L87-H97,H)&QI;F5;,%TI.PH*("`@("`@("`@("`@:68@
M*"1L:6YE6S%=(#T](%9&4U]&24Q%*2!["B`@("`@("`@("`@("`@("`D;F%M
M92`](&5X<&QO9&4H)RXG+"`D;&EN95LP72D["@H@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1N86UE*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)W1Y<&4G72`]("<J*FYO;F4G.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@5D93
M.CIS=')T;VQO=V5R*"1N86UE6V-O=6YT*"1N86UE*2`M(#%=*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@
M5D93.CIS=')L96XH)&QI;F5;-5TI.PH@("`@("`@("`@("!](&5L<V5I9B`H
M)&QI;F5;,5T@/3T@5D937T9/3$1%4BD@>PH@("`@("`@("`@("`@("`@)&9I
M;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@("`D9FEL95LG
M<VEZ92==(#T@+3$["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE
M6R=D871E)UT@/2`D;&EN95LR73L*("`@("`@("`@("`@)&9I;&5;)V]W;F5R
M)UT@/2`D;&EN95LS73L*"B`@("`@("`@("`@("1L:6YE6S1=(#T@:6YT=F%L
M*"1L:6YE6S1=*3L*("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@(#T@*"1L
M:6YE6S%=(#T](%9&4U]&3TQ$15(I(#\@)V0G(#H@)RTG.PH@("`@("`@("`@
M("`D9FEL95LG<&5R;7,G72`N/2`G<G<M)SL*("`@("`@("`@("`@)&9I;&5;
M)W!E<FUS)UT@+CT@*"1L:6YE6S1=("8@5D937T9,04=?4D5!1"D@/R`G<B<@
M.B`G+2<["B`@("`@("`@("`@("1F:6QE6R=P97)M<R==("X]("@D;&EN95LT
M72`F(%9&4U]&3$%'7U=2251%*2`_("=W)R`Z("<M)SL*("`@("`@("`@("`@
M)&9I;&5;)W!E<FUS)UT@+CT@)RTG.PH@("`@("`@("`@("`D9FEL95LG9W)O
M=7`G72`]("<G.PH*("`@("`@("`@("`@+R\@9FEL=&5R:6YG"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F:6QE6R=N
M86UE)UTI*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)&1I<F]N;'D@)B8@)&9I;&5;)W1Y<&4G72`A/3T@)RHJ9&ER)RD@
M>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE
M<ULD9FEL95LG;F%M92==72`]("1F:6QE.PH@("`@("`@("`@("!U;G-E="@D
M9FEL92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VAA;F=E<R!P97)M:7-S:6]N<R!F;W(@86X@
M271E;2!O;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@($AO;&1S('1H92!P871H(&]F(&1I<F5C=&]R>2!O9B!T:&4@271E
M;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@($AO;&1S('1H92!N86UE
M(&]F('1H92!)=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H86YG95!E<FUI<W-I;VYS*"1P
M871H+"`D;F%M92P@)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@)&-O;FX@
M/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D8V]N;BDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@
M('T*"B`@("`@("`@)'9A;"`](&EN='9A;"AS=6)S='(H)'!E<FUI<W-I;VXL
M("TQ*2D["B`@("`@("`@)'!E<FT@/2`P.PH@("`@("`@("1P97)M('P]("@D
M=F%L("8@-"D@/R!61E-?1DQ!1U]214%$(#H@,#L*("`@("`@("`D<&5R;2!\
M/2`H)'9A;"`F(#(I(#\@5D937T9,04=?5U))5$4@.B`P.PH*("`@("`@("`D
M9FEL94QI<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4
M('9F<U]I9"P@=F9S7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M93T@/R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1P871H+"`D;F%M92DI
M.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QE3&ES="D@?'P@8V]U;G0H
M)&9I;&5,:7-T*2`\(#$I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB*2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!4:&5R92!M87D@8F4@;VYE(&]R(&UO<F4@
M9FEL97,@=VET:"!T:&4@<V%M92!N86UE(&)U="!T:&4@=7-E<B!M87D*("`@
M("`@("`@*B!N;W0@:&%V92!R96%D(&%C8V5S<R!T;R!T:&5M+"!S;R!D;V5S
M;B=T('-E92!T:&5M+B!3;R!W92!H879E('1O"B`@("`@("`@("H@8VAM;V0@
M=&AE(&]N92!T:&5Y(&AA=F4@86-C97-S('1O+B`J+PH@("`@("`@(&9O<F5A
M8V@@*"1F:6QE3&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I
M;&5;,5T@/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D9FEL95LR72`F
M(%9&4U]&3$%'7U=2251%*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G55!$051%("5S(%-%5"!V9G-?
M<&5R;7,@/2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!72$5212!V9G-?:60@/2`_)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D<&5R;2P@)&9I;&5;,%TI
M*3L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N(BDL("1P871H+"`D;F%M92DI.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]61E,O1T,N<&AP````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(V-C8`,3`T,3<S-C(W-S``,#$V-C0P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!#;&%S<R!F;W(@<')O=FED:6YG(&=A<F)A9V4@8V]L;&5C=&EO;B!F;W(@
M86YY(%9&4R!I;G-T86YC92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93
M+U9&4R]'0RYP:'`L=B`Q+C0N,3(N."`R,#`V+S`Q+S`Q(#(Q.C(X.C0R(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E(%9&4PH@*B\*8VQA<W,@5D937T=#('L*"B`@("`O*BH*("`@
M("`J($=A<F)A9V4@8V]L;&5C="!F:6QE<R!I;B!T:&4@5D93('-T;W)A9V4@
M<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!61E,@)B1V9G,@("`@("!4
M:&4@5D93(&]B:F5C="!T;R!P97)F;W)M(&=A<F)A9V4@8V]L;&5C=&EO;B!O
M;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("!4:&4@5D93('!A=&@@
M=&\@8VQE86XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<V5C<R`@5&AE(&UI
M;FEM=6T@86UO=6YT(&]F('1I;64@*&EN('-E8V]N9',I(')E<75I<F5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@8F5F;W)E(&$@9FEL92!I<R!R
M96UO=F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@F)'9F<RP@)'!A=&@L
M("1S96-S(#T@,S0U-C`P*0H@("`@>PH@("`@("`@("\J($$@,24@8VAA;F-E
M('=E('=I;&P@<G5N(&=A<F)A9V4@8V]L;&5C=&EO;B!D=7)I;F<@82!C86QL
M+B`J+PH@("`@("`@(&EF("AR86YD*#`L(#DY*2`]/2`P*2!["B`@("`@("`@
M("`@("\J($UA:V4@<W5R92!C;&5A;FEN9R!I<R!D;VYE(')E8W5R<VEV96QY
M+B`J+PH@("`@("`@("`@("`D9FEL97,@/2`D=F9S+3YL:7-T1F]L9&5R*"1P
M871H+"!N=6QL+"!T<G5E+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF
M("@A:7-?82@D9FEL97,L("=014%27T5R<F]R)RD@)B8@:7-?87)R87DH)&9I
M;&5S*2D@>PH@("`@("`@("`@("`@("`@)&UO9'1I;64@/2!T:6UE*"D@+2`D
M<V5C<SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D=F%L
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1V86Q;)V1A=&4G72`\("1M
M;V1T:6UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V9G,M/F1E;&5T
M949I;&4H)'!A=&@L("1V86Q;)VYA;64G72D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]/8FIE8W0N<&AP````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C`V,P`Q,#0Q
M-S,V,C<W,``P,3<U-#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXO5D93+G!H<"<["@HO*BH*("H@02!W<F%P<&5R(&9O<B!T
M:&4@5D93(&-L87-S('1O(')E='5R;B!O8FIE8W1S+"!I;G-T96%D(&]F(&%R
M<F%Y<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N
M<&AP+'8@,2XQ,BXQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z-#(@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@2F]N(%=O;V0@/&IO;D!J96QL
M>6)O8BYC;RYU:SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!7
M;V]D(#QJ;VY`:F5L;'EB;V(N8V\N=6L^"B`J($!P86-K86=E(%9&4PH@*B!`
M<VEN8V4@("!(;W)D92`R+C(*("HO"F-L87-S(%9&4U]/8FIE8W0@>PH*("`@
M("\J*@H@("`@("H@5&AE(&%C='5A;"!V9G,@=&AA="!D;V5S('1H92!W;W)K
M"B`@("`@*@H@("`@("H@0'9A<B!61E,*("`@("`J+PH@("`@=F%R("1?=F9S
M.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@<&%T:"!T:&%T(&AA<R!B
M965N('!A<W-E9"!T;R!L:7-T1F]L9&5R+"!I9B!T:&ES"B`@("`@*B!C:&%N
M9V5S+"!T:&4@;&ES="!W:6QL(&)E(')E8G5I;'0N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W5R<F5N=%!A=&@["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<F5T=7)N('9A;'5E(&9R;VT@82!S=&%N9&%R
M9"!61E,@;&ES=$9O;&1E<B!C86QL+"!T;PH@("`@("H@8F4@<F5A9"!W:71H
M('1H92!/8FIE8W0@;&ES=$9O;&1E<BX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7V9O;&1E<DQI<W0["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!)9B!Y;W4@<&%S<R!I
M;B!A;B!E>&ES=&EN9R!61E,@;V)J96-T+"!I="!W:6QL(&)E('5S960@87,@
M=&AE(%9&4PH@("`@("H@;V)J96-T(&9O<B!T:&ES(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@5D93("8D=F9S("!4:&4@5D93(&]B:F5C="!T;R!W
M<F%P+@H@("`@("HO"B`@("!F=6YC=&EO;B!61E-?3V)J96-T*"8D=F9S*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D=F9S*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W9F<R`]("1V9G,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@5D937T]B:F5C
M="!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!61E,@
M<W5B8VQA<W,@=&\@<F5T=7)N+B!)9@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("1D<FEV97(@:7,@86X@87)R87D@=&AE;B!W92!W:6QL(&QO;VL@
M:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S!=+VQI
M8B]61E,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B
M8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(%9&4U]/
M8FIE8W0@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%9&4U]/8FIE8W0@
M:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&9A;'-E
M(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D
M9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=F9S
M(#T@)E9&4SHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D[
M"B`@("`@("`@)'9F<V]B:F5C="`]("9N97<@5D937T]B:F5C="@D=F9S*3L*
M("`@("`@("!R971U<FX@)'9F<V]B:F5C=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R
M971E(%9&4R!I;G-T86YC90H@("`@("H@8F%S960@;VX@)&1R:79E<BX@270@
M=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;PH@("`@("H@
M5D93(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT
M;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@
M:68@;75L=&EP;&4@='EP97,@;V8@9FEL92!B86-K96YD<R`H86YD+`H@("`@
M("H@=&AU<RP@;75L=&EP;&4@5D93(&EN<W1A;F-E<RD@87)E(')E<75I<F5D
M+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A
M<SH@)'9A<B`]("961E,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%9&4R!S
M=6)C;&%S<R!T;R!R971U<FXN($EF"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@)&1R:79E<B!I<R!A;B!A<G)A>2!T:&5N('=E('=I;&P@;&]O:R!I
M;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("1D<FEV97);,%TO;&EB
M+U9&4R\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG
M(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C
M;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@5D937T]B
M:F5C="`@5&AE(&-O;F-R971E(%9&4U]/8FIE8W0@<F5F97)E;F-E+"!O<B!F
M86QS92!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=F9S(#T@)E9&4SHZ<VEN9VQE
M=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*3L*("`@("`@("`D=F9S
M;V)J96-T(#T@)FYE=R!61E-?3V)J96-T*"1V9G,I.PH@("`@("`@(')E='5R
M;B`D=F9S;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@=&AE
M(&-R961E;G1I86QS('1H870@=V4@:&%V92!T;R!S964@:68@=&AE<F4@:7,@
M82!V86QI9"!L;V=I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@9&5S8W)I8FEN9R!T:&4@<')O
M8FQE;0H@("`@("H@("`@("`@("`@("`@("`@:68@=&AE(&-R961E;G1I86QS
M(&%R92!I;G9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&5C:T-R961E
M;G1I86QS*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V9G,M/F-H
M96-K0W)E9&5N=&EA;',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!C
M;VYF:6=U<F%T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M
M971E<B!N86UE+W9A;'5E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M<&%I<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%!A<F%M<R@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W9F<RT^<V5T4&%R
M86US*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@
M82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')E860H)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=F9S+3YR96%D*&1I<FYA;64H)'!A=&@I+"!B87-E;F%M92@D
M<&%T:"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@82!F:6QE(&EN
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M("`@("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&UP1FEL92`@("`@(%1H92!T96UP;W)A<GD@9FEL
M92!C;VYT86EN:6YG('1H92!D871A('1O(&)E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W1O<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R
M:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=R:71E*"1P871H+"`D=&UP1FEL92P@)&%U=&]C
M<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V
M9G,M/G=R:71E*&1I<FYA;64H)'!A=&@I+"!B87-E;F%M92@D<&%T:"DL("1T
M;7!&:6QE+"`D875T;V-R96%T92`](&9A;'-E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-T;W)E(&$@9FEL92!I;B!T:&4@5D93(&9R;VT@<F%W(&1A=&$N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H
M92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T82`@("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@
M9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D9&%T
M82P@)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]V9G,M/G=R:71E1&%T82AD:7)N86UE*"1P871H*2P@8F%S96YA
M;64H)'!A=&@I+"`D9&%T82P@)&%U=&]C<F5A=&4@/2!F86QS92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F:6QE(&9R;VT@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T
M;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1FEL
M92@D<&%T:"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V9G,M/F1E
M;&5T949I;&4H9&ER;F%M92@D<&%T:"DL(&)A<V5N86UE*"1P871H*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296YA;64@82!F:6QE(&EN('1H92!61E,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE(&]L
M9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD
M;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@9FEL96YA;64N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5N86UE*"1O;&1P871H+"`D;F5W<&%T:"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]V9G,M/G)E;F%M92AD:7)N86UE*"1O;&1P871H
M*2P@8F%S96YA;64H)&]L9'!A=&@I+"!D:7)N86UE*"1N97=P871H*2P@8F%S
M96YA;64H)&YE=W!A=&@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T
M92!A(&9O;&1E<B!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@(%1H92!P871H('1O('1H92!F;VQD97(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8W)E871E1F]L9&5R*"1P871H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W9F<RT^8W)E871E1F]L9&5R*&1I<FYA;64H)'!A=&@I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!F;VQD97(@9G)O;2!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@5&AE('!A
M=&@@;V8@=&AE(&9O;&1E<B!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E
M1F]L9&5R*"1P871H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F
M<RT^9&5L971E1F]L9&5R*&1I<FYA;64H)'!A=&@I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!61E-?3&ES=$ET96T@;V)J96-T(&EF('1H
M92!F;VQD97(@8V%N"B`@("`@*B!B92!R96%D+"!O<B!A(%!%05)?17)R;W(@
M:68@:70@8V%N)W0@8F4N(%)E='5R;G,@9F%L<V4@;VYC90H@("`@("H@=&AE
M(&9O;&1E<B!H87,@8F5E;B!C;VUP;&5T96QY(')E860N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@=&AE(&1I<F5T
M;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($9I;&4@;&ES="`H
M87)R87DI(&]N('-U8V-E<W,L(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@
M("`@("`@("`@;V)J96-T(&]N(&9A:6QU<F4L(&]R(&9A;'-E(&EF('1H92!F
M;VQD97(@:7,*("`@("`J("`@("`@("`@("`@("`@(&-O;7!L971E;'D@<F5A
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<B@D<&%T:"D*("`@
M('L*("`@("`@("!I9B`H(2@D<&%T:"`]/3T@)'1H:7,M/E]C=7)R96YT4&%T
M:"DI('L*("`@("`@("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^7W9F<RT^
M;&ES=$9O;&1E<B@D<&%T:"D["B`@("`@("`@("`@(&EF("@D9F]L9&5R3&ES
M="D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]F;VQD97),:7-T(#T@)&9O
M;&1E<DQI<W0["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G10871H
M(#T@)'!A=&@["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO
M="!R96%D("5S+B(I+"`D<&%T:"DI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+TQI<W1)=&5M+G!H<"<["B`@("`@("`@:68@*"1F:6QE(#T@87)R87E?<VAI
M9G0H)'1H:7,M/E]F;VQD97),:7-T*2D@>PH@("`@("`@("`@("`D9FEL92`]
M("9N97<@5D937TQI<W1)=&5M*"1P871H+"`D9FEL92D["B`@("`@("`@("`@
M(')E='5R;B`D9FEL93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M0VAA;F=E<R!P97)M:7-S:6]N<R!F;W(@86X@271E;2!O;B!T:&4@5D93+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@($AO;&1S
M('1H92!P871H(&]F(&1I<F5C=&]R>2!O9B!T:&4@271E;2X*("`@("`J($!P
M87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@(%1/1$\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&%N
M9V5097)M:7-S:6]N<R@D<&%T:"P@)'!E<FUI<W-I;VXI"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YC:&%N9V5097)M:7-S:6]N<RAD:7)N
M86UE*"1P871H*2P@8F%S96YA;64H)'!A=&@I+"`D<&5R;6ES<VEO;BD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QI<W0@;V8@861D:71I
M;VYA;"!C<F5D96YT:6%L<R!R97%U:7)E9"P@:68@86YY+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($-R961E;G1I86P@;&ES="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4F5Q=6ER961#<F5D96YT:6%L<R@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YG971297%U:7)E9$-R961E;G1I
M86QS*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&%R<F%Y
M('-P96-I9FEC>6EN9R!W:&%T('!E<FUI<W-I;VYS(&%R92!C:&%N9V5A8FQE
M(&9O<B!T:&ES"B`@("`@*B!I;7!L96UE;G1A=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!#:&%N9V5A8FQE('!E<FUI<VEO;G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$UO9&EF:6%B;&5097)M:7-S:6]N<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YG971-;V1I9FEA8FQE
M4&5R;6ES<VEO;G,H*3L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E(&%N
M>2!R97-O=7)C97,@=&AA="!N965D('1O(&)E(&-L;W-E9"X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I
M<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F9S+3Y?9&ES8V]N
M;F5C="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ
M92!O9B!A(&9I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@9FEL96YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!53E53140*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!S:7IE(&]F('1H92!F:6QE(&EN
M(&)Y=&5S(&]R(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@
M("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1FEL95-I>F4H
M)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F
M<RT^9V5T4VEZ92AD:7)N86UE*"1P871H*2P@8F%S96YA;64H)'!A=&@I*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]&:6QE+P``````````````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S``,#$V,#4P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O=&5S=',O````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W,``P,3<R,3(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]0
M1$8O````````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S<P`#`Q-C0V,0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R\`````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S``,#$W-C$R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+V-O
M=7)I97(N<&AP````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q-@`Q
M,#0Q-S,V,C<W,``P,C$W-S$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&
M"B`J+PIF;W(@*"1I(#T@,#L@)&D@/#T@,C4U.R`D:2LK*2!["B`@("`D9F]N
M=%]W:61T:'-;)V-O=7)I97(G75MC:'(H)&DI72`](#8P,#L*?0HD9F]N=%]W
M:61T:'-;)V-O=7)I97)")UT@/2`D9F]N=%]W:61T:'-;)V-O=7)I97(G73L*
M)&9O;G1?=VED=&AS6R=C;W5R:65R22==(#T@)&9O;G1?=VED=&AS6R=C;W5R
M:65R)UT["B1F;VYT7W=I9'1H<ULG8V]U<FEE<D)))UT@/2`D9G!D9E]W:61T
M:'-;)V-O=7)I97(G73L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]H96QV971I8V$N<&AP
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,#<`,3`T,3<S-C(W-S``
M,#(R,C<Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*)&9O;G1?
M=VED=&AS6R=H96QV971I8V$G72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR-S@L
M8VAR*#$I/3XR-S@L8VAR*#(I/3XR-S@L8VAR*#,I/3XR-S@L8VAR*#0I/3XR
M-S@L8VAR*#4I/3XR-S@L8VAR*#8I/3XR-S@L8VAR*#<I/3XR-S@L8VAR*#@I
M/3XR-S@L8VAR*#DI/3XR-S@L8VAR*#$P*3T^,C<X+&-H<B@Q,2D]/C(W."QC
M:'(H,3(I/3XR-S@L8VAR*#$S*3T^,C<X+&-H<B@Q-"D]/C(W."QC:'(H,34I
M/3XR-S@L8VAR*#$V*3T^,C<X+&-H<B@Q-RD]/C(W."QC:'(H,3@I/3XR-S@L
M8VAR*#$Y*3T^,C<X+&-H<B@R,"D]/C(W."QC:'(H,C$I/3XR-S@L"B`@("!C
M:'(H,C(I/3XR-S@L8VAR*#(S*3T^,C<X+&-H<B@R-"D]/C(W."QC:'(H,C4I
M/3XR-S@L8VAR*#(V*3T^,C<X+&-H<B@R-RD]/C(W."QC:'(H,C@I/3XR-S@L
M8VAR*#(Y*3T^,C<X+&-H<B@S,"D]/C(W."QC:'(H,S$I/3XR-S@L)R`G/3XR
M-S@L)R$G/3XR-S@L)R(G/3XS-34L)R,G/3XU-38L)R0G/3XU-38L)R4G/3XX
M.#DL)R8G/3XV-C<L)UPG)ST^,3DQ+"<H)ST^,S,S+"<I)ST^,S,S+"<J)ST^
M,S@Y+"<K)ST^-3@T+`H@("`@)RPG/3XR-S@L)RTG/3XS,S,L)RXG/3XR-S@L
M)R\G/3XR-S@L)S`G/3XU-38L)S$G/3XU-38L)S(G/3XU-38L)S,G/3XU-38L
M)S0G/3XU-38L)S4G/3XU-38L)S8G/3XU-38L)S<G/3XU-38L)S@G/3XU-38L
M)SDG/3XU-38L)SHG/3XR-S@L)SLG/3XR-S@L)SPG/3XU.#0L)STG/3XU.#0L
M)SXG/3XU.#0L)S\G/3XU-38L)T`G/3XQ,#$U+"=!)ST^-C8W+`H@("`@)T(G
M/3XV-C<L)T,G/3XW,C(L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV,3$L)T<G
M/3XW-S@L)T@G/3XW,C(L)TDG/3XR-S@L)THG/3XU,#`L)TLG/3XV-C<L)TPG
M/3XU-38L)TTG/3XX,S,L)TXG/3XW,C(L)T\G/3XW-S@L)U`G/3XV-C<L)U$G
M/3XW-S@L)U(G/3XW,C(L)U,G/3XV-C<L)U0G/3XV,3$L)U4G/3XW,C(L)U8G
M/3XV-C<L)U<G/3XY-#0L"B`@("`G6"<]/C8V-RPG62<]/C8V-RPG6B<]/C8Q
M,2PG6R<]/C(W."PG7%PG/3XR-S@L)UTG/3XR-S@L)UXG/3XT-CDL)U\G/3XU
M-38L)V`G/3XS,S,L)V$G/3XU-38L)V(G/3XU-38L)V,G/3XU,#`L)V0G/3XU
M-38L)V4G/3XU-38L)V8G/3XR-S@L)V<G/3XU-38L)V@G/3XU-38L)VDG/3XR
M,C(L)VHG/3XR,C(L)VLG/3XU,#`L)VPG/3XR,C(L)VTG/3XX,S,L"B`@("`G
M;B<]/C4U-BPG;R<]/C4U-BPG<"<]/C4U-BPG<2<]/C4U-BPG<B<]/C,S,RPG
M<R<]/C4P,"PG="<]/C(W."PG=2<]/C4U-BPG=B<]/C4P,"PG=R<]/C<R,BPG
M>"<]/C4P,"PG>2<]/C4P,"PG>B<]/C4P,"PG>R<]/C,S-"PG?"<]/C(V,"PG
M?2<]/C,S-"PG?B<]/C4X-"QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU-38L
M8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,C(R+&-H<B@Q,S$I/3XU-38L"B`@
M("!C:'(H,3,R*3T^,S,S+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU-38L
M8VAR*#$S-2D]/C4U-BQC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P+&-H
M<B@Q,S@I/3XV-C<L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^,3`P,"QC:'(H
M,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]/C,U,"QC:'(H,30T
M*3T^,S4P+&-H<B@Q-#4I/3XR,C(L8VAR*#$T-BD]/C(R,BQC:'(H,30W*3T^
M,S,S+&-H<B@Q-#@I/3XS,S,L8VAR*#$T.2D]/C,U,"QC:'(H,34P*3T^-34V
M+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/C$P,#`L
M"B`@("!C:'(H,34T*3T^-3`P+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]/CDT
M-"QC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XU,#`L8VAR*#$U.2D]/C8V-RQC
M:'(H,38P*3T^,C<X+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4U-BQC:'(H
M,38S*3T^-34V+&-H<B@Q-C0I/3XU-38L8VAR*#$V-2D]/C4U-BQC:'(H,38V
M*3T^,C8P+&-H<B@Q-C<I/3XU-38L8VAR*#$V."D]/C,S,RQC:'(H,38Y*3T^
M-S,W+&-H<B@Q-S`I/3XS-S`L8VAR*#$W,2D]/C4U-BQC:'(H,3<R*3T^-3@T
M+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<S-RQC:'(H,3<U*3T^,S,S+`H@
M("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3@T+&-H<B@Q-S@I/3XS,S,L
M8VAR*#$W.2D]/C,S,RQC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU-38L8VAR
M*#$X,BD]/C4S-RQC:'(H,3@S*3T^,C<X+&-H<B@Q.#0I/3XS,S,L8VAR*#$X
M-2D]/C,S,RQC:'(H,3@V*3T^,S8U+&-H<B@Q.#<I/3XU-38L8VAR*#$X."D]
M/C@S-"QC:'(H,3@Y*3T^.#,T+&-H<B@Q.3`I/3XX,S0L8VAR*#$Y,2D]/C8Q
M,2QC:'(H,3DR*3T^-C8W+&-H<B@Q.3,I/3XV-C<L8VAR*#$Y-"D]/C8V-RQC
M:'(H,3DU*3T^-C8W+&-H<B@Q.38I/3XV-C<L8VAR*#$Y-RD]/C8V-RP*("`@
M(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW,C(L8VAR*#(P,"D]/C8V-RQC
M:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L8VAR*#(P,RD]/C8V-RQC:'(H
M,C`T*3T^,C<X+&-H<B@R,#4I/3XR-S@L8VAR*#(P-BD]/C(W."QC:'(H,C`W
M*3T^,C<X+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P*3T^
M-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]/C<W."QC:'(H,C$S*3T^-S<X
M+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4X-"QC:'(H,C$V*3T^-S<X+&-H
M<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@("`@
M8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-C8W+&-H<B@R,C(I/3XV-C<L8VAR
M*#(R,RD]/C8Q,2QC:'(H,C(T*3T^-34V+&-H<B@R,C4I/3XU-38L8VAR*#(R
M-BD]/C4U-BQC:'(H,C(W*3T^-34V+&-H<B@R,C@I/3XU-38L8VAR*#(R.2D]
M/C4U-BQC:'(H,C,P*3T^.#@Y+&-H<B@R,S$I/3XU,#`L8VAR*#(S,BD]/C4U
M-BQC:'(H,C,S*3T^-34V+&-H<B@R,S0I/3XU-38L8VAR*#(S-2D]/C4U-BQC
M:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC:'(H
M,C,Y*3T^,C<X+&-H<B@R-#`I/3XU-38L8VAR*#(T,2D]/C4U-BP*("`@(&-H
M<B@R-#(I/3XU-38L8VAR*#(T,RD]/C4U-BQC:'(H,C0T*3T^-34V+&-H<B@R
M-#4I/3XU-38L8VAR*#(T-BD]/C4U-BQC:'(H,C0W*3T^-3@T+&-H<B@R-#@I
M/3XV,3$L8VAR*#(T.2D]/C4U-BQC:'(H,C4P*3T^-34V+&-H<B@R-3$I/3XU
M-38L8VAR*#(U,BD]/C4U-BQC:'(H,C4S*3T^-3`P+&-H<B@R-30I/3XU-38L
M8VAR*#(U-2D]/C4P,"D["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O:&5L=F5T:6-A8BYP
M:'```````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,C`W`#$P-#$W,S8R-S<P
M`#`R,C0S,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"B1F;VYT
M7W=I9'1H<ULG:&5L=F5T:6-A0B==(#T@87)R87DH"B`@("!C:'(H,"D]/C(W
M."QC:'(H,2D]/C(W."QC:'(H,BD]/C(W."QC:'(H,RD]/C(W."QC:'(H-"D]
M/C(W."QC:'(H-2D]/C(W."QC:'(H-BD]/C(W."QC:'(H-RD]/C(W."QC:'(H
M."D]/C(W."QC:'(H.2D]/C(W."QC:'(H,3`I/3XR-S@L8VAR*#$Q*3T^,C<X
M+&-H<B@Q,BD]/C(W."QC:'(H,3,I/3XR-S@L8VAR*#$T*3T^,C<X+&-H<B@Q
M-2D]/C(W."QC:'(H,38I/3XR-S@L8VAR*#$W*3T^,C<X+&-H<B@Q."D]/C(W
M."QC:'(H,3DI/3XR-S@L8VAR*#(P*3T^,C<X+&-H<B@R,2D]/C(W."P*("`@
M(&-H<B@R,BD]/C(W."QC:'(H,C,I/3XR-S@L8VAR*#(T*3T^,C<X+&-H<B@R
M-2D]/C(W."QC:'(H,C8I/3XR-S@L8VAR*#(W*3T^,C<X+&-H<B@R."D]/C(W
M."QC:'(H,CDI/3XR-S@L8VAR*#,P*3T^,C<X+&-H<B@S,2D]/C(W."PG("<]
M/C(W."PG(2<]/C,S,RPG(B<]/C0W-"PG(R<]/C4U-BPG)"<]/C4U-BPG)2<]
M/C@X.2PG)B<]/C<R,BPG7"<G/3XR,S@L)R@G/3XS,S,L)RDG/3XS,S,L)RHG
M/3XS.#DL)RLG/3XU.#0L"B`@("`G+"<]/C(W."PG+2<]/C,S,RPG+B<]/C(W
M."PG+R<]/C(W."PG,"<]/C4U-BPG,2<]/C4U-BPG,B<]/C4U-BPG,R<]/C4U
M-BPG-"<]/C4U-BPG-2<]/C4U-BPG-B<]/C4U-BPG-R<]/C4U-BPG."<]/C4U
M-BPG.2<]/C4U-BPG.B<]/C,S,RPG.R<]/C,S,RPG/"<]/C4X-"PG/2<]/C4X
M-"PG/B<]/C4X-"PG/R<]/C8Q,2PG0"<]/CDW-2PG02<]/C<R,BP*("`@("="
M)ST^-S(R+"=#)ST^-S(R+"=$)ST^-S(R+"=%)ST^-C8W+"=&)ST^-C$Q+"='
M)ST^-S<X+"=()ST^-S(R+"=))ST^,C<X+"=*)ST^-34V+"=+)ST^-S(R+"=,
M)ST^-C$Q+"=-)ST^.#,S+"=.)ST^-S(R+"=/)ST^-S<X+"=0)ST^-C8W+"=1
M)ST^-S<X+"=2)ST^-S(R+"=3)ST^-C8W+"=4)ST^-C$Q+"=5)ST^-S(R+"=6
M)ST^-C8W+"=7)ST^.30T+`H@("`@)U@G/3XV-C<L)UDG/3XV-C<L)UHG/3XV
M,3$L)ULG/3XS,S,L)UQ<)ST^,C<X+"==)ST^,S,S+"=>)ST^-3@T+"=?)ST^
M-34V+"=@)ST^,S,S+"=A)ST^-34V+"=B)ST^-C$Q+"=C)ST^-34V+"=D)ST^
M-C$Q+"=E)ST^-34V+"=F)ST^,S,S+"=G)ST^-C$Q+"=H)ST^-C$Q+"=I)ST^
M,C<X+"=J)ST^,C<X+"=K)ST^-34V+"=L)ST^,C<X+"=M)ST^.#@Y+`H@("`@
M)VXG/3XV,3$L)V\G/3XV,3$L)W`G/3XV,3$L)W$G/3XV,3$L)W(G/3XS.#DL
M)W,G/3XU-38L)W0G/3XS,S,L)W4G/3XV,3$L)W8G/3XU-38L)W<G/3XW-S@L
M)W@G/3XU-38L)WDG/3XU-38L)WHG/3XU,#`L)WLG/3XS.#DL)WPG/3XR.#`L
M)WTG/3XS.#DL)WXG/3XU.#0L8VAR*#$R-RD]/C,U,"QC:'(H,3(X*3T^-34V
M+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C(W."QC:'(H,3,Q*3T^-34V+`H@
M("`@8VAR*#$S,BD]/C4P,"QC:'(H,3,S*3T^,3`P,"QC:'(H,3,T*3T^-34V
M+&-H<B@Q,S4I/3XU-38L8VAR*#$S-BD]/C,S,RQC:'(H,3,W*3T^,3`P,"QC
M:'(H,3,X*3T^-C8W+&-H<B@Q,SDI/3XS,S,L8VAR*#$T,"D]/C$P,#`L8VAR
M*#$T,2D]/C,U,"QC:'(H,30R*3T^-C$Q+&-H<B@Q-#,I/3XS-3`L8VAR*#$T
M-"D]/C,U,"QC:'(H,30U*3T^,C<X+&-H<B@Q-#8I/3XR-S@L8VAR*#$T-RD]
M/C4P,"QC:'(H,30X*3T^-3`P+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]/C4U
M-BQC:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XQ,#`P
M+`H@("`@8VAR*#$U-"D]/C4U-BQC:'(H,34U*3T^,S,S+&-H<B@Q-38I/3XY
M-#0L8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^-3`P+&-H<B@Q-3DI/3XV-C<L
M8VAR*#$V,"D]/C(W."QC:'(H,38Q*3T^,S,S+&-H<B@Q-C(I/3XU-38L8VAR
M*#$V,RD]/C4U-BQC:'(H,38T*3T^-34V+&-H<B@Q-C4I/3XU-38L8VAR*#$V
M-BD]/C(X,"QC:'(H,38W*3T^-34V+&-H<B@Q-C@I/3XS,S,L8VAR*#$V.2D]
M/C<S-RQC:'(H,3<P*3T^,S<P+&-H<B@Q-S$I/3XU-38L8VAR*#$W,BD]/C4X
M-"QC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW,S<L8VAR*#$W-2D]/C,S,RP*
M("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C4X-"QC:'(H,3<X*3T^,S,S
M+&-H<B@Q-SDI/3XS,S,L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q*3T^-C$Q+&-H
M<B@Q.#(I/3XU-38L8VAR*#$X,RD]/C(W."QC:'(H,3@T*3T^,S,S+&-H<B@Q
M.#4I/3XS,S,L8VAR*#$X-BD]/C,V-2QC:'(H,3@W*3T^-34V+&-H<B@Q.#@I
M/3XX,S0L8VAR*#$X.2D]/C@S-"QC:'(H,3DP*3T^.#,T+&-H<B@Q.3$I/3XV
M,3$L8VAR*#$Y,BD]/C<R,BQC:'(H,3DS*3T^-S(R+&-H<B@Q.30I/3XW,C(L
M8VAR*#$Y-2D]/C<R,BQC:'(H,3DV*3T^-S(R+&-H<B@Q.3<I/3XW,C(L"B`@
M("!C:'(H,3DX*3T^,3`P,"QC:'(H,3DY*3T^-S(R+&-H<B@R,#`I/3XV-C<L
M8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^-C8W+&-H<B@R,#,I/3XV-C<L8VAR
M*#(P-"D]/C(W."QC:'(H,C`U*3T^,C<X+&-H<B@R,#8I/3XR-S@L8VAR*#(P
M-RD]/C(W."QC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XW,C(L8VAR*#(Q,"D]
M/C<W."QC:'(H,C$Q*3T^-S<X+&-H<B@R,3(I/3XW-S@L8VAR*#(Q,RD]/C<W
M."QC:'(H,C$T*3T^-S<X+&-H<B@R,34I/3XU.#0L8VAR*#(Q-BD]/C<W."QC
M:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]/C<R,BP*("`@
M(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C8V-RQC:'(H,C(R*3T^-C8W+&-H
M<B@R,C,I/3XV,3$L8VAR*#(R-"D]/C4U-BQC:'(H,C(U*3T^-34V+&-H<B@R
M,C8I/3XU-38L8VAR*#(R-RD]/C4U-BQC:'(H,C(X*3T^-34V+&-H<B@R,CDI
M/3XU-38L8VAR*#(S,"D]/C@X.2QC:'(H,C,Q*3T^-34V+&-H<B@R,S(I/3XU
M-38L8VAR*#(S,RD]/C4U-BQC:'(H,C,T*3T^-34V+&-H<B@R,S4I/3XU-38L
M8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I/3XR-S@L8VAR
M*#(S.2D]/C(W."QC:'(H,C0P*3T^-C$Q+&-H<B@R-#$I/3XV,3$L"B`@("!C
M:'(H,C0R*3T^-C$Q+&-H<B@R-#,I/3XV,3$L8VAR*#(T-"D]/C8Q,2QC:'(H
M,C0U*3T^-C$Q+&-H<B@R-#8I/3XV,3$L8VAR*#(T-RD]/C4X-"QC:'(H,C0X
M*3T^-C$Q+&-H<B@R-#DI/3XV,3$L8VAR*#(U,"D]/C8Q,2QC:'(H,C4Q*3T^
M-C$Q+&-H<B@R-3(I/3XV,3$L8VAR*#(U,RD]/C4U-BQC:'(H,C4T*3T^-C$Q
M+&-H<B@R-34I/3XU-38I.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE;'9E=&EC86)I
M+G!H<``````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(Q,``Q,#0Q-S,V,C<W
M,``P,C(U-S8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD9F]N
M=%]W:61T:'-;)VAE;'9E=&EC84)))UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^
M,C<X+&-H<B@Q*3T^,C<X+&-H<B@R*3T^,C<X+&-H<B@S*3T^,C<X+&-H<B@T
M*3T^,C<X+&-H<B@U*3T^,C<X+&-H<B@V*3T^,C<X+&-H<B@W*3T^,C<X+&-H
M<B@X*3T^,C<X+&-H<B@Y*3T^,C<X+&-H<B@Q,"D]/C(W."QC:'(H,3$I/3XR
M-S@L8VAR*#$R*3T^,C<X+&-H<B@Q,RD]/C(W."QC:'(H,30I/3XR-S@L8VAR
M*#$U*3T^,C<X+&-H<B@Q-BD]/C(W."QC:'(H,3<I/3XR-S@L8VAR*#$X*3T^
M,C<X+&-H<B@Q.2D]/C(W."QC:'(H,C`I/3XR-S@L8VAR*#(Q*3T^,C<X+`H@
M("`@8VAR*#(R*3T^,C<X+&-H<B@R,RD]/C(W."QC:'(H,C0I/3XR-S@L8VAR
M*#(U*3T^,C<X+&-H<B@R-BD]/C(W."QC:'(H,C<I/3XR-S@L8VAR*#(X*3T^
M,C<X+&-H<B@R.2D]/C(W."QC:'(H,S`I/3XR-S@L8VAR*#,Q*3T^,C<X+"<@
M)ST^,C<X+"<A)ST^,S,S+"<B)ST^-#<T+"<C)ST^-34V+"<D)ST^-34V+"<E
M)ST^.#@Y+"<F)ST^-S(R+"=<)R<]/C(S."PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C,X.2PG*R<]/C4X-"P*("`@("<L)ST^,C<X+"<M)ST^,S,S+"<N)ST^
M,C<X+"<O)ST^,C<X+"<P)ST^-34V+"<Q)ST^-34V+"<R)ST^-34V+"<S)ST^
M-34V+"<T)ST^-34V+"<U)ST^-34V+"<V)ST^-34V+"<W)ST^-34V+"<X)ST^
M-34V+"<Y)ST^-34V+"<Z)ST^,S,S+"<[)ST^,S,S+"<\)ST^-3@T+"<])ST^
M-3@T+"<^)ST^-3@T+"<_)ST^-C$Q+"=`)ST^.3<U+"=!)ST^-S(R+`H@("`@
M)T(G/3XW,C(L)T,G/3XW,C(L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV,3$L
M)T<G/3XW-S@L)T@G/3XW,C(L)TDG/3XR-S@L)THG/3XU-38L)TLG/3XW,C(L
M)TPG/3XV,3$L)TTG/3XX,S,L)TXG/3XW,C(L)T\G/3XW-S@L)U`G/3XV-C<L
M)U$G/3XW-S@L)U(G/3XW,C(L)U,G/3XV-C<L)U0G/3XV,3$L)U4G/3XW,C(L
M)U8G/3XV-C<L)U<G/3XY-#0L"B`@("`G6"<]/C8V-RPG62<]/C8V-RPG6B<]
M/C8Q,2PG6R<]/C,S,RPG7%PG/3XR-S@L)UTG/3XS,S,L)UXG/3XU.#0L)U\G
M/3XU-38L)V`G/3XS,S,L)V$G/3XU-38L)V(G/3XV,3$L)V,G/3XU-38L)V0G
M/3XV,3$L)V4G/3XU-38L)V8G/3XS,S,L)V<G/3XV,3$L)V@G/3XV,3$L)VDG
M/3XR-S@L)VHG/3XR-S@L)VLG/3XU-38L)VPG/3XR-S@L)VTG/3XX.#DL"B`@
M("`G;B<]/C8Q,2PG;R<]/C8Q,2PG<"<]/C8Q,2PG<2<]/C8Q,2PG<B<]/C,X
M.2PG<R<]/C4U-BPG="<]/C,S,RPG=2<]/C8Q,2PG=B<]/C4U-BPG=R<]/C<W
M."PG>"<]/C4U-BPG>2<]/C4U-BPG>B<]/C4P,"PG>R<]/C,X.2PG?"<]/C(X
M,"PG?2<]/C,X.2PG?B<]/C4X-"QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU
M-38L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,C<X+&-H<B@Q,S$I/3XU-38L
M"B`@("!C:'(H,3,R*3T^-3`P+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU
M-38L8VAR*#$S-2D]/C4U-BQC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P
M+&-H<B@Q,S@I/3XV-C<L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^,3`P,"QC
M:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]/C,U,"QC:'(H
M,30T*3T^,S4P+&-H<B@Q-#4I/3XR-S@L8VAR*#$T-BD]/C(W."QC:'(H,30W
M*3T^-3`P+&-H<B@Q-#@I/3XU,#`L8VAR*#$T.2D]/C,U,"QC:'(H,34P*3T^
M-34V+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/C$P
M,#`L"B`@("!C:'(H,34T*3T^-34V+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]
M/CDT-"QC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XU,#`L8VAR*#$U.2D]/C8V
M-RQC:'(H,38P*3T^,C<X+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4U-BQC
M:'(H,38S*3T^-34V+&-H<B@Q-C0I/3XU-38L8VAR*#$V-2D]/C4U-BQC:'(H
M,38V*3T^,C@P+&-H<B@Q-C<I/3XU-38L8VAR*#$V."D]/C,S,RQC:'(H,38Y
M*3T^-S,W+&-H<B@Q-S`I/3XS-S`L8VAR*#$W,2D]/C4U-BQC:'(H,3<R*3T^
M-3@T+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<S-RQC:'(H,3<U*3T^,S,S
M+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3@T+&-H<B@Q-S@I/3XS
M,S,L8VAR*#$W.2D]/C,S,RQC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XV,3$L
M8VAR*#$X,BD]/C4U-BQC:'(H,3@S*3T^,C<X+&-H<B@Q.#0I/3XS,S,L8VAR
M*#$X-2D]/C,S,RQC:'(H,3@V*3T^,S8U+&-H<B@Q.#<I/3XU-38L8VAR*#$X
M."D]/C@S-"QC:'(H,3@Y*3T^.#,T+&-H<B@Q.3`I/3XX,S0L8VAR*#$Y,2D]
M/C8Q,2QC:'(H,3DR*3T^-S(R+&-H<B@Q.3,I/3XW,C(L8VAR*#$Y-"D]/C<R
M,BQC:'(H,3DU*3T^-S(R+&-H<B@Q.38I/3XW,C(L8VAR*#$Y-RD]/C<R,BP*
M("`@(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW,C(L8VAR*#(P,"D]/C8V
M-RQC:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L8VAR*#(P,RD]/C8V-RQC
M:'(H,C`T*3T^,C<X+&-H<B@R,#4I/3XR-S@L8VAR*#(P-BD]/C(W."QC:'(H
M,C`W*3T^,C<X+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P
M*3T^-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]/C<W."QC:'(H,C$S*3T^
M-S<X+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4X-"QC:'(H,C$V*3T^-S<X
M+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@
M("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-C8W+&-H<B@R,C(I/3XV-C<L
M8VAR*#(R,RD]/C8Q,2QC:'(H,C(T*3T^-34V+&-H<B@R,C4I/3XU-38L8VAR
M*#(R-BD]/C4U-BQC:'(H,C(W*3T^-34V+&-H<B@R,C@I/3XU-38L8VAR*#(R
M.2D]/C4U-BQC:'(H,C,P*3T^.#@Y+&-H<B@R,S$I/3XU-38L8VAR*#(S,BD]
M/C4U-BQC:'(H,C,S*3T^-34V+&-H<B@R,S0I/3XU-38L8VAR*#(S-2D]/C4U
M-BQC:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC
M:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XV,3$L8VAR*#(T,2D]/C8Q,2P*("`@
M(&-H<B@R-#(I/3XV,3$L8VAR*#(T,RD]/C8Q,2QC:'(H,C0T*3T^-C$Q+&-H
M<B@R-#4I/3XV,3$L8VAR*#(T-BD]/C8Q,2QC:'(H,C0W*3T^-3@T+&-H<B@R
M-#@I/3XV,3$L8VAR*#(T.2D]/C8Q,2QC:'(H,C4P*3T^-C$Q+&-H<B@R-3$I
M/3XV,3$L8VAR*#(U,BD]/C8Q,2QC:'(H,C4S*3T^-34V+&-H<B@R-30I/3XV
M,3$L8VAR*#(U-2D]/C4U-BD["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]H96QV971I8V%I
M+G!H<```````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,3``,3`T,3<S-C(W
M-S``,#(R-#,T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*)&9O
M;G1?=VED=&AS6R=H96QV971I8V%))UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^
M,C<X+&-H<B@Q*3T^,C<X+&-H<B@R*3T^,C<X+&-H<B@S*3T^,C<X+&-H<B@T
M*3T^,C<X+&-H<B@U*3T^,C<X+&-H<B@V*3T^,C<X+&-H<B@W*3T^,C<X+&-H
M<B@X*3T^,C<X+&-H<B@Y*3T^,C<X+&-H<B@Q,"D]/C(W."QC:'(H,3$I/3XR
M-S@L8VAR*#$R*3T^,C<X+&-H<B@Q,RD]/C(W."QC:'(H,30I/3XR-S@L8VAR
M*#$U*3T^,C<X+&-H<B@Q-BD]/C(W."QC:'(H,3<I/3XR-S@L8VAR*#$X*3T^
M,C<X+&-H<B@Q.2D]/C(W."QC:'(H,C`I/3XR-S@L8VAR*#(Q*3T^,C<X+`H@
M("`@8VAR*#(R*3T^,C<X+&-H<B@R,RD]/C(W."QC:'(H,C0I/3XR-S@L8VAR
M*#(U*3T^,C<X+&-H<B@R-BD]/C(W."QC:'(H,C<I/3XR-S@L8VAR*#(X*3T^
M,C<X+&-H<B@R.2D]/C(W."QC:'(H,S`I/3XR-S@L8VAR*#,Q*3T^,C<X+"<@
M)ST^,C<X+"<A)ST^,C<X+"<B)ST^,S4U+"<C)ST^-34V+"<D)ST^-34V+"<E
M)ST^.#@Y+"<F)ST^-C8W+"=<)R<]/C$Y,2PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C,X.2PG*R<]/C4X-"P*("`@("<L)ST^,C<X+"<M)ST^,S,S+"<N)ST^
M,C<X+"<O)ST^,C<X+"<P)ST^-34V+"<Q)ST^-34V+"<R)ST^-34V+"<S)ST^
M-34V+"<T)ST^-34V+"<U)ST^-34V+"<V)ST^-34V+"<W)ST^-34V+"<X)ST^
M-34V+"<Y)ST^-34V+"<Z)ST^,C<X+"<[)ST^,C<X+"<\)ST^-3@T+"<])ST^
M-3@T+"<^)ST^-3@T+"<_)ST^-34V+"=`)ST^,3`Q-2PG02<]/C8V-RP*("`@
M("=")ST^-C8W+"=#)ST^-S(R+"=$)ST^-S(R+"=%)ST^-C8W+"=&)ST^-C$Q
M+"=')ST^-S<X+"=()ST^-S(R+"=))ST^,C<X+"=*)ST^-3`P+"=+)ST^-C8W
M+"=,)ST^-34V+"=-)ST^.#,S+"=.)ST^-S(R+"=/)ST^-S<X+"=0)ST^-C8W
M+"=1)ST^-S<X+"=2)ST^-S(R+"=3)ST^-C8W+"=4)ST^-C$Q+"=5)ST^-S(R
M+"=6)ST^-C8W+"=7)ST^.30T+`H@("`@)U@G/3XV-C<L)UDG/3XV-C<L)UHG
M/3XV,3$L)ULG/3XR-S@L)UQ<)ST^,C<X+"==)ST^,C<X+"=>)ST^-#8Y+"=?
M)ST^-34V+"=@)ST^,S,S+"=A)ST^-34V+"=B)ST^-34V+"=C)ST^-3`P+"=D
M)ST^-34V+"=E)ST^-34V+"=F)ST^,C<X+"=G)ST^-34V+"=H)ST^-34V+"=I
M)ST^,C(R+"=J)ST^,C(R+"=K)ST^-3`P+"=L)ST^,C(R+"=M)ST^.#,S+`H@
M("`@)VXG/3XU-38L)V\G/3XU-38L)W`G/3XU-38L)W$G/3XU-38L)W(G/3XS
M,S,L)W,G/3XU,#`L)W0G/3XR-S@L)W4G/3XU-38L)W8G/3XU,#`L)W<G/3XW
M,C(L)W@G/3XU,#`L)WDG/3XU,#`L)WHG/3XU,#`L)WLG/3XS,S0L)WPG/3XR
M-C`L)WTG/3XS,S0L)WXG/3XU.#0L8VAR*#$R-RD]/C,U,"QC:'(H,3(X*3T^
M-34V+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C(R,BQC:'(H,3,Q*3T^-34V
M+`H@("`@8VAR*#$S,BD]/C,S,RQC:'(H,3,S*3T^,3`P,"QC:'(H,3,T*3T^
M-34V+&-H<B@Q,S4I/3XU-38L8VAR*#$S-BD]/C,S,RQC:'(H,3,W*3T^,3`P
M,"QC:'(H,3,X*3T^-C8W+&-H<B@Q,SDI/3XS,S,L8VAR*#$T,"D]/C$P,#`L
M8VAR*#$T,2D]/C,U,"QC:'(H,30R*3T^-C$Q+&-H<B@Q-#,I/3XS-3`L8VAR
M*#$T-"D]/C,U,"QC:'(H,30U*3T^,C(R+&-H<B@Q-#8I/3XR,C(L8VAR*#$T
M-RD]/C,S,RQC:'(H,30X*3T^,S,S+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]
M/C4U-BQC:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XQ
M,#`P+`H@("`@8VAR*#$U-"D]/C4P,"QC:'(H,34U*3T^,S,S+&-H<B@Q-38I
M/3XY-#0L8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^-3`P+&-H<B@Q-3DI/3XV
M-C<L8VAR*#$V,"D]/C(W."QC:'(H,38Q*3T^,S,S+&-H<B@Q-C(I/3XU-38L
M8VAR*#$V,RD]/C4U-BQC:'(H,38T*3T^-34V+&-H<B@Q-C4I/3XU-38L8VAR
M*#$V-BD]/C(V,"QC:'(H,38W*3T^-34V+&-H<B@Q-C@I/3XS,S,L8VAR*#$V
M.2D]/C<S-RQC:'(H,3<P*3T^,S<P+&-H<B@Q-S$I/3XU-38L8VAR*#$W,BD]
M/C4X-"QC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW,S<L8VAR*#$W-2D]/C,S
M,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C4X-"QC:'(H,3<X*3T^
M,S,S+&-H<B@Q-SDI/3XS,S,L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q*3T^-34V
M+&-H<B@Q.#(I/3XU,S<L8VAR*#$X,RD]/C(W."QC:'(H,3@T*3T^,S,S+&-H
M<B@Q.#4I/3XS,S,L8VAR*#$X-BD]/C,V-2QC:'(H,3@W*3T^-34V+&-H<B@Q
M.#@I/3XX,S0L8VAR*#$X.2D]/C@S-"QC:'(H,3DP*3T^.#,T+&-H<B@Q.3$I
M/3XV,3$L8VAR*#$Y,BD]/C8V-RQC:'(H,3DS*3T^-C8W+&-H<B@Q.30I/3XV
M-C<L8VAR*#$Y-2D]/C8V-RQC:'(H,3DV*3T^-C8W+&-H<B@Q.3<I/3XV-C<L
M"B`@("!C:'(H,3DX*3T^,3`P,"QC:'(H,3DY*3T^-S(R+&-H<B@R,#`I/3XV
M-C<L8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^-C8W+&-H<B@R,#,I/3XV-C<L
M8VAR*#(P-"D]/C(W."QC:'(H,C`U*3T^,C<X+&-H<B@R,#8I/3XR-S@L8VAR
M*#(P-RD]/C(W."QC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XW,C(L8VAR*#(Q
M,"D]/C<W."QC:'(H,C$Q*3T^-S<X+&-H<B@R,3(I/3XW-S@L8VAR*#(Q,RD]
M/C<W."QC:'(H,C$T*3T^-S<X+&-H<B@R,34I/3XU.#0L8VAR*#(Q-BD]/C<W
M."QC:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]/C<R,BP*
M("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C8V-RQC:'(H,C(R*3T^-C8W
M+&-H<B@R,C,I/3XV,3$L8VAR*#(R-"D]/C4U-BQC:'(H,C(U*3T^-34V+&-H
M<B@R,C8I/3XU-38L8VAR*#(R-RD]/C4U-BQC:'(H,C(X*3T^-34V+&-H<B@R
M,CDI/3XU-38L8VAR*#(S,"D]/C@X.2QC:'(H,C,Q*3T^-3`P+&-H<B@R,S(I
M/3XU-38L8VAR*#(S,RD]/C4U-BQC:'(H,C,T*3T^-34V+&-H<B@R,S4I/3XU
M-38L8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I/3XR-S@L
M8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^-34V+&-H<B@R-#$I/3XU-38L"B`@
M("!C:'(H,C0R*3T^-34V+&-H<B@R-#,I/3XU-38L8VAR*#(T-"D]/C4U-BQC
M:'(H,C0U*3T^-34V+&-H<B@R-#8I/3XU-38L8VAR*#(T-RD]/C4X-"QC:'(H
M,C0X*3T^-C$Q+&-H<B@R-#DI/3XU-38L8VAR*#(U,"D]/C4U-BQC:'(H,C4Q
M*3T^-34V+&-H<B@R-3(I/3XU-38L8VAR*#(U,RD]/C4P,"QC:'(H,C4T*3T^
M-34V+&-H<B@R-34I/3XU,#`I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O<WEM8F]L+G!H
M<```````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,#<S`#$P-#$W,S8R
M-S<P`#`R,38S,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"B1F
M;VYT7W=I9'1H<ULG<WEM8F]L)UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^,C4P
M+&-H<B@Q*3T^,C4P+&-H<B@R*3T^,C4P+&-H<B@S*3T^,C4P+&-H<B@T*3T^
M,C4P+&-H<B@U*3T^,C4P+&-H<B@V*3T^,C4P+&-H<B@W*3T^,C4P+&-H<B@X
M*3T^,C4P+&-H<B@Y*3T^,C4P+&-H<B@Q,"D]/C(U,"QC:'(H,3$I/3XR-3`L
M8VAR*#$R*3T^,C4P+&-H<B@Q,RD]/C(U,"QC:'(H,30I/3XR-3`L8VAR*#$U
M*3T^,C4P+&-H<B@Q-BD]/C(U,"QC:'(H,3<I/3XR-3`L8VAR*#$X*3T^,C4P
M+&-H<B@Q.2D]/C(U,"QC:'(H,C`I/3XR-3`L8VAR*#(Q*3T^,C4P+`H@("`@
M8VAR*#(R*3T^,C4P+&-H<B@R,RD]/C(U,"QC:'(H,C0I/3XR-3`L8VAR*#(U
M*3T^,C4P+&-H<B@R-BD]/C(U,"QC:'(H,C<I/3XR-3`L8VAR*#(X*3T^,C4P
M+&-H<B@R.2D]/C(U,"QC:'(H,S`I/3XR-3`L8VAR*#,Q*3T^,C4P+"<@)ST^
M,C4P+"<A)ST^,S,S+"<B)ST^-S$S+"<C)ST^-3`P+"<D)ST^-30Y+"<E)ST^
M.#,S+"<F)ST^-S<X+"=<)R<]/C0S.2PG*"<]/C,S,RPG*2<]/C,S,RPG*B<]
M/C4P,"PG*R<]/C4T.2P*("`@("<L)ST^,C4P+"<M)ST^-30Y+"<N)ST^,C4P
M+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^-3`P
M+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^-3`P
M+"<Y)ST^-3`P+"<Z)ST^,C<X+"<[)ST^,C<X+"<\)ST^-30Y+"<])ST^-30Y
M+"<^)ST^-30Y+"<_)ST^-#0T+"=`)ST^-30Y+"=!)ST^-S(R+`H@("`@)T(G
M/3XV-C<L)T,G/3XW,C(L)T0G/3XV,3(L)T4G/3XV,3$L)T8G/3XW-C,L)T<G
M/3XV,#,L)T@G/3XW,C(L)TDG/3XS,S,L)THG/3XV,S$L)TLG/3XW,C(L)TPG
M/3XV.#8L)TTG/3XX.#DL)TXG/3XW,C(L)T\G/3XW,C(L)U`G/3XW-C@L)U$G
M/3XW-#$L)U(G/3XU-38L)U,G/3XU.3(L)U0G/3XV,3$L)U4G/3XV.3`L)U8G
M/3XT,SDL)U<G/3XW-C@L"B`@("`G6"<]/C8T-2PG62<]/C<Y-2PG6B<]/C8Q
M,2PG6R<]/C,S,RPG7%PG/3XX-C,L)UTG/3XS,S,L)UXG/3XV-3@L)U\G/3XU
M,#`L)V`G/3XU,#`L)V$G/3XV,S$L)V(G/3XU-#DL)V,G/3XU-#DL)V0G/3XT
M.30L)V4G/3XT,SDL)V8G/3XU,C$L)V<G/3XT,3$L)V@G/3XV,#,L)VDG/3XS
M,CDL)VHG/3XV,#,L)VLG/3XU-#DL)VPG/3XU-#DL)VTG/3XU-S8L"B`@("`G
M;B<]/C4R,2PG;R<]/C4T.2PG<"<]/C4T.2PG<2<]/C4R,2PG<B<]/C4T.2PG
M<R<]/C8P,RPG="<]/C0S.2PG=2<]/C4W-BPG=B<]/C<Q,RPG=R<]/C8X-BPG
M>"<]/C0Y,RPG>2<]/C8X-BPG>B<]/C0Y-"PG>R<]/C0X,"PG?"<]/C(P,"PG
M?2<]/C0X,"PG?B<]/C4T.2QC:'(H,3(W*3T^,"QC:'(H,3(X*3T^,"QC:'(H
M,3(Y*3T^,"QC:'(H,3,P*3T^,"QC:'(H,3,Q*3T^,"P*("`@(&-H<B@Q,S(I
M/3XP+&-H<B@Q,S,I/3XP+&-H<B@Q,S0I/3XP+&-H<B@Q,S4I/3XP+&-H<B@Q
M,S8I/3XP+&-H<B@Q,S<I/3XP+&-H<B@Q,S@I/3XP+&-H<B@Q,SDI/3XP+&-H
M<B@Q-#`I/3XP+&-H<B@Q-#$I/3XP+&-H<B@Q-#(I/3XP+&-H<B@Q-#,I/3XP
M+&-H<B@Q-#0I/3XP+&-H<B@Q-#4I/3XP+&-H<B@Q-#8I/3XP+&-H<B@Q-#<I
M/3XP+&-H<B@Q-#@I/3XP+&-H<B@Q-#DI/3XP+&-H<B@Q-3`I/3XP+&-H<B@Q
M-3$I/3XP+&-H<B@Q-3(I/3XP+&-H<B@Q-3,I/3XP+`H@("`@8VAR*#$U-"D]
M/C`L8VAR*#$U-2D]/C`L8VAR*#$U-BD]/C`L8VAR*#$U-RD]/C`L8VAR*#$U
M."D]/C`L8VAR*#$U.2D]/C`L8VAR*#$V,"D]/C<U,"QC:'(H,38Q*3T^-C(P
M+&-H<B@Q-C(I/3XR-#<L8VAR*#$V,RD]/C4T.2QC:'(H,38T*3T^,38W+&-H
M<B@Q-C4I/3XW,3,L8VAR*#$V-BD]/C4P,"QC:'(H,38W*3T^-S4S+&-H<B@Q
M-C@I/3XW-3,L8VAR*#$V.2D]/C<U,RQC:'(H,3<P*3T^-S4S+&-H<B@Q-S$I
M/3XQ,#0R+&-H<B@Q-S(I/3XY.#<L8VAR*#$W,RD]/C8P,RQC:'(H,3<T*3T^
M.3@W+&-H<B@Q-S4I/3XV,#,L"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I
M/3XU-#DL8VAR*#$W."D]/C0Q,2QC:'(H,3<Y*3T^-30Y+&-H<B@Q.#`I/3XU
M-#DL8VAR*#$X,2D]/C<Q,RQC:'(H,3@R*3T^-#DT+&-H<B@Q.#,I/3XT-C`L
M8VAR*#$X-"D]/C4T.2QC:'(H,3@U*3T^-30Y+&-H<B@Q.#8I/3XU-#DL8VAR
M*#$X-RD]/C4T.2QC:'(H,3@X*3T^,3`P,"QC:'(H,3@Y*3T^-C`S+&-H<B@Q
M.3`I/3XQ,#`P+&-H<B@Q.3$I/3XV-3@L8VAR*#$Y,BD]/C@R,RQC:'(H,3DS
M*3T^-C@V+&-H<B@Q.30I/3XW.34L8VAR*#$Y-2D]/CDX-RQC:'(H,3DV*3T^
M-S8X+&-H<B@Q.3<I/3XW-C@L"B`@("!C:'(H,3DX*3T^.#(S+&-H<B@Q.3DI
M/3XW-C@L8VAR*#(P,"D]/C<V."QC:'(H,C`Q*3T^-S$S+&-H<B@R,#(I/3XW
M,3,L8VAR*#(P,RD]/C<Q,RQC:'(H,C`T*3T^-S$S+&-H<B@R,#4I/3XW,3,L
M8VAR*#(P-BD]/C<Q,RQC:'(H,C`W*3T^-S$S+&-H<B@R,#@I/3XW-C@L8VAR
M*#(P.2D]/C<Q,RQC:'(H,C$P*3T^-SDP+&-H<B@R,3$I/3XW.3`L8VAR*#(Q
M,BD]/C@Y,"QC:'(H,C$S*3T^.#(S+&-H<B@R,30I/3XU-#DL8VAR*#(Q-2D]
M/C(U,"QC:'(H,C$V*3T^-S$S+&-H<B@R,3<I/3XV,#,L8VAR*#(Q."D]/C8P
M,RQC:'(H,C$Y*3T^,3`T,BP*("`@(&-H<B@R,C`I/3XY.#<L8VAR*#(R,2D]
M/C8P,RQC:'(H,C(R*3T^.3@W+&-H<B@R,C,I/3XV,#,L8VAR*#(R-"D]/C0Y
M-"QC:'(H,C(U*3T^,S(Y+&-H<B@R,C8I/3XW.3`L8VAR*#(R-RD]/C<Y,"QC
M:'(H,C(X*3T^-S@V+&-H<B@R,CDI/3XW,3,L8VAR*#(S,"D]/C,X-"QC:'(H
M,C,Q*3T^,S@T+&-H<B@R,S(I/3XS.#0L8VAR*#(S,RD]/C,X-"QC:'(H,C,T
M*3T^,S@T+&-H<B@R,S4I/3XS.#0L8VAR*#(S-BD]/C0Y-"QC:'(H,C,W*3T^
M-#DT+&-H<B@R,S@I/3XT.30L8VAR*#(S.2D]/C0Y-"QC:'(H,C0P*3T^,"QC
M:'(H,C0Q*3T^,S(Y+`H@("`@8VAR*#(T,BD]/C(W-"QC:'(H,C0S*3T^-C@V
M+&-H<B@R-#0I/3XV.#8L8VAR*#(T-2D]/C8X-BQC:'(H,C0V*3T^,S@T+&-H
M<B@R-#<I/3XS.#0L8VAR*#(T."D]/C,X-"QC:'(H,C0Y*3T^,S@T+&-H<B@R
M-3`I/3XS.#0L8VAR*#(U,2D]/C,X-"QC:'(H,C4R*3T^-#DT+&-H<B@R-3,I
M/3XT.30L8VAR*#(U-"D]/C0Y-"QC:'(H,C4U*3T^,"D["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W1I;65S+G!H
M<```````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C$W-P`Q,#0Q-S,V
M,C<W,``P,C$T-30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD
M9F]N=%]W:61T:'-;)W1I;65S)UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^,C4P
M+&-H<B@Q*3T^,C4P+&-H<B@R*3T^,C4P+&-H<B@S*3T^,C4P+&-H<B@T*3T^
M,C4P+&-H<B@U*3T^,C4P+&-H<B@V*3T^,C4P+&-H<B@W*3T^,C4P+&-H<B@X
M*3T^,C4P+&-H<B@Y*3T^,C4P+&-H<B@Q,"D]/C(U,"QC:'(H,3$I/3XR-3`L
M8VAR*#$R*3T^,C4P+&-H<B@Q,RD]/C(U,"QC:'(H,30I/3XR-3`L8VAR*#$U
M*3T^,C4P+&-H<B@Q-BD]/C(U,"QC:'(H,3<I/3XR-3`L8VAR*#$X*3T^,C4P
M+&-H<B@Q.2D]/C(U,"QC:'(H,C`I/3XR-3`L8VAR*#(Q*3T^,C4P+`H@("`@
M8VAR*#(R*3T^,C4P+&-H<B@R,RD]/C(U,"QC:'(H,C0I/3XR-3`L8VAR*#(U
M*3T^,C4P+&-H<B@R-BD]/C(U,"QC:'(H,C<I/3XR-3`L8VAR*#(X*3T^,C4P
M+&-H<B@R.2D]/C(U,"QC:'(H,S`I/3XR-3`L8VAR*#,Q*3T^,C4P+"<@)ST^
M,C4P+"<A)ST^,S,S+"<B)ST^-#`X+"<C)ST^-3`P+"<D)ST^-3`P+"<E)ST^
M.#,S+"<F)ST^-S<X+"=<)R<]/C$X,"PG*"<]/C,S,RPG*2<]/C,S,RPG*B<]
M/C4P,"PG*R<]/C4V-"P*("`@("<L)ST^,C4P+"<M)ST^,S,S+"<N)ST^,C4P
M+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^-3`P
M+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^-3`P
M+"<Y)ST^-3`P+"<Z)ST^,C<X+"<[)ST^,C<X+"<\)ST^-38T+"<])ST^-38T
M+"<^)ST^-38T+"<_)ST^-#0T+"=`)ST^.3(Q+"=!)ST^-S(R+`H@("`@)T(G
M/3XV-C<L)T,G/3XV-C<L)T0G/3XW,C(L)T4G/3XV,3$L)T8G/3XU-38L)T<G
M/3XW,C(L)T@G/3XW,C(L)TDG/3XS,S,L)THG/3XS.#DL)TLG/3XW,C(L)TPG
M/3XV,3$L)TTG/3XX.#DL)TXG/3XW,C(L)T\G/3XW,C(L)U`G/3XU-38L)U$G
M/3XW,C(L)U(G/3XV-C<L)U,G/3XU-38L)U0G/3XV,3$L)U4G/3XW,C(L)U8G
M/3XW,C(L)U<G/3XY-#0L"B`@("`G6"<]/C<R,BPG62<]/C<R,BPG6B<]/C8Q
M,2PG6R<]/C,S,RPG7%PG/3XR-S@L)UTG/3XS,S,L)UXG/3XT-CDL)U\G/3XU
M,#`L)V`G/3XS,S,L)V$G/3XT-#0L)V(G/3XU,#`L)V,G/3XT-#0L)V0G/3XU
M,#`L)V4G/3XT-#0L)V8G/3XS,S,L)V<G/3XU,#`L)V@G/3XU,#`L)VDG/3XR
M-S@L)VHG/3XR-S@L)VLG/3XU,#`L)VPG/3XR-S@L)VTG/3XW-S@L"B`@("`G
M;B<]/C4P,"PG;R<]/C4P,"PG<"<]/C4P,"PG<2<]/C4P,"PG<B<]/C,S,RPG
M<R<]/C,X.2PG="<]/C(W."PG=2<]/C4P,"PG=B<]/C4P,"PG=R<]/C<R,BPG
M>"<]/C4P,"PG>2<]/C4P,"PG>B<]/C0T-"PG>R<]/C0X,"PG?"<]/C(P,"PG
M?2<]/C0X,"PG?B<]/C4T,2QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU,#`L
M8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,S,S+&-H<B@Q,S$I/3XU,#`L"B`@
M("!C:'(H,3,R*3T^-#0T+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU,#`L
M8VAR*#$S-2D]/C4P,"QC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P+&-H
M<B@Q,S@I/3XU-38L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^.#@Y+&-H<B@Q
M-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^,S4P+&-H<B@Q-#0I
M/3XS-3`L8VAR*#$T-2D]/C,S,RQC:'(H,30V*3T^,S,S+&-H<B@Q-#<I/3XT
M-#0L8VAR*#$T."D]/C0T-"QC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU,#`L
M8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S*3T^.3@P+`H@
M("`@8VAR*#$U-"D]/C,X.2QC:'(H,34U*3T^,S,S+&-H<B@Q-38I/3XW,C(L
M8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^-#0T+&-H<B@Q-3DI/3XW,C(L8VAR
M*#$V,"D]/C(U,"QC:'(H,38Q*3T^,S,S+&-H<B@Q-C(I/3XU,#`L8VAR*#$V
M,RD]/C4P,"QC:'(H,38T*3T^-3`P+&-H<B@Q-C4I/3XU,#`L8VAR*#$V-BD]
M/C(P,"QC:'(H,38W*3T^-3`P+&-H<B@Q-C@I/3XS,S,L8VAR*#$V.2D]/C<V
M,"QC:'(H,3<P*3T^,C<V+&-H<B@Q-S$I/3XU,#`L8VAR*#$W,BD]/C4V-"QC
M:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW-C`L8VAR*#$W-2D]/C,S,RP*("`@
M(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C4V-"QC:'(H,3<X*3T^,S`P+&-H
M<B@Q-SDI/3XS,#`L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q*3T^-3`P+&-H<B@Q
M.#(I/3XT-3,L8VAR*#$X,RD]/C(U,"QC:'(H,3@T*3T^,S,S+&-H<B@Q.#4I
M/3XS,#`L8VAR*#$X-BD]/C,Q,"QC:'(H,3@W*3T^-3`P+&-H<B@Q.#@I/3XW
M-3`L8VAR*#$X.2D]/C<U,"QC:'(H,3DP*3T^-S4P+&-H<B@Q.3$I/3XT-#0L
M8VAR*#$Y,BD]/C<R,BQC:'(H,3DS*3T^-S(R+&-H<B@Q.30I/3XW,C(L8VAR
M*#$Y-2D]/C<R,BQC:'(H,3DV*3T^-S(R+&-H<B@Q.3<I/3XW,C(L"B`@("!C
M:'(H,3DX*3T^.#@Y+&-H<B@Q.3DI/3XV-C<L8VAR*#(P,"D]/C8Q,2QC:'(H
M,C`Q*3T^-C$Q+&-H<B@R,#(I/3XV,3$L8VAR*#(P,RD]/C8Q,2QC:'(H,C`T
M*3T^,S,S+&-H<B@R,#4I/3XS,S,L8VAR*#(P-BD]/C,S,RQC:'(H,C`W*3T^
M,S,S+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P*3T^-S(R
M+&-H<B@R,3$I/3XW,C(L8VAR*#(Q,BD]/C<R,BQC:'(H,C$S*3T^-S(R+&-H
M<B@R,30I/3XW,C(L8VAR*#(Q-2D]/C4V-"QC:'(H,C$V*3T^-S(R+&-H<B@R
M,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@("`@8VAR
M*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-S(R+&-H<B@R,C(I/3XU-38L8VAR*#(R
M,RD]/C4P,"QC:'(H,C(T*3T^-#0T+&-H<B@R,C4I/3XT-#0L8VAR*#(R-BD]
M/C0T-"QC:'(H,C(W*3T^-#0T+&-H<B@R,C@I/3XT-#0L8VAR*#(R.2D]/C0T
M-"QC:'(H,C,P*3T^-C8W+&-H<B@R,S$I/3XT-#0L8VAR*#(S,BD]/C0T-"QC
M:'(H,C,S*3T^-#0T+&-H<B@R,S0I/3XT-#0L8VAR*#(S-2D]/C0T-"QC:'(H
M,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC:'(H,C,Y
M*3T^,C<X+&-H<B@R-#`I/3XU,#`L8VAR*#(T,2D]/C4P,"P*("`@(&-H<B@R
M-#(I/3XU,#`L8VAR*#(T,RD]/C4P,"QC:'(H,C0T*3T^-3`P+&-H<B@R-#4I
M/3XU,#`L8VAR*#(T-BD]/C4P,"QC:'(H,C0W*3T^-38T+&-H<B@R-#@I/3XU
M,#`L8VAR*#(T.2D]/C4P,"QC:'(H,C4P*3T^-3`P+&-H<B@R-3$I/3XU,#`L
M8VAR*#(U,BD]/C4P,"QC:'(H,C4S*3T^-3`P+&-H<B@R-30I/3XU,#`L8VAR
M*#(U-2D]/C4P,"D["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<V(N
M<&AP````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,#4`,3`T,3<S
M-C(W-S``,#(Q-C`V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*
M)&9O;G1?=VED=&AS6R=T:6UE<T(G72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR
M-3`L8VAR*#$I/3XR-3`L8VAR*#(I/3XR-3`L8VAR*#,I/3XR-3`L8VAR*#0I
M/3XR-3`L8VAR*#4I/3XR-3`L8VAR*#8I/3XR-3`L8VAR*#<I/3XR-3`L8VAR
M*#@I/3XR-3`L8VAR*#DI/3XR-3`L8VAR*#$P*3T^,C4P+&-H<B@Q,2D]/C(U
M,"QC:'(H,3(I/3XR-3`L8VAR*#$S*3T^,C4P+&-H<B@Q-"D]/C(U,"QC:'(H
M,34I/3XR-3`L8VAR*#$V*3T^,C4P+&-H<B@Q-RD]/C(U,"QC:'(H,3@I/3XR
M-3`L8VAR*#$Y*3T^,C4P+&-H<B@R,"D]/C(U,"QC:'(H,C$I/3XR-3`L"B`@
M("!C:'(H,C(I/3XR-3`L8VAR*#(S*3T^,C4P+&-H<B@R-"D]/C(U,"QC:'(H
M,C4I/3XR-3`L8VAR*#(V*3T^,C4P+&-H<B@R-RD]/C(U,"QC:'(H,C@I/3XR
M-3`L8VAR*#(Y*3T^,C4P+&-H<B@S,"D]/C(U,"QC:'(H,S$I/3XR-3`L)R`G
M/3XR-3`L)R$G/3XS,S,L)R(G/3XU-34L)R,G/3XU,#`L)R0G/3XU,#`L)R4G
M/3XQ,#`P+"<F)ST^.#,S+"=<)R<]/C(W."PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C4P,"PG*R<]/C4W,"P*("`@("<L)ST^,C4P+"<M)ST^,S,S+"<N)ST^
M,C4P+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^
M-3`P+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^
M-3`P+"<Y)ST^-3`P+"<Z)ST^,S,S+"<[)ST^,S,S+"<\)ST^-3<P+"<])ST^
M-3<P+"<^)ST^-3<P+"<_)ST^-3`P+"=`)ST^.3,P+"=!)ST^-S(R+`H@("`@
M)T(G/3XV-C<L)T,G/3XW,C(L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV,3$L
M)T<G/3XW-S@L)T@G/3XW-S@L)TDG/3XS.#DL)THG/3XU,#`L)TLG/3XW-S@L
M)TPG/3XV-C<L)TTG/3XY-#0L)TXG/3XW,C(L)T\G/3XW-S@L)U`G/3XV,3$L
M)U$G/3XW-S@L)U(G/3XW,C(L)U,G/3XU-38L)U0G/3XV-C<L)U4G/3XW,C(L
M)U8G/3XW,C(L)U<G/3XQ,#`P+`H@("`@)U@G/3XW,C(L)UDG/3XW,C(L)UHG
M/3XV-C<L)ULG/3XS,S,L)UQ<)ST^,C<X+"==)ST^,S,S+"=>)ST^-3@Q+"=?
M)ST^-3`P+"=@)ST^,S,S+"=A)ST^-3`P+"=B)ST^-34V+"=C)ST^-#0T+"=D
M)ST^-34V+"=E)ST^-#0T+"=F)ST^,S,S+"=G)ST^-3`P+"=H)ST^-34V+"=I
M)ST^,C<X+"=J)ST^,S,S+"=K)ST^-34V+"=L)ST^,C<X+"=M)ST^.#,S+`H@
M("`@)VXG/3XU-38L)V\G/3XU,#`L)W`G/3XU-38L)W$G/3XU-38L)W(G/3XT
M-#0L)W,G/3XS.#DL)W0G/3XS,S,L)W4G/3XU-38L)W8G/3XU,#`L)W<G/3XW
M,C(L)W@G/3XU,#`L)WDG/3XU,#`L)WHG/3XT-#0L)WLG/3XS.30L)WPG/3XR
M,C`L)WTG/3XS.30L)WXG/3XU,C`L8VAR*#$R-RD]/C,U,"QC:'(H,3(X*3T^
M-3`P+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C,S,RQC:'(H,3,Q*3T^-3`P
M+`H@("`@8VAR*#$S,BD]/C4P,"QC:'(H,3,S*3T^,3`P,"QC:'(H,3,T*3T^
M-3`P+&-H<B@Q,S4I/3XU,#`L8VAR*#$S-BD]/C,S,RQC:'(H,3,W*3T^,3`P
M,"QC:'(H,3,X*3T^-34V+&-H<B@Q,SDI/3XS,S,L8VAR*#$T,"D]/C$P,#`L
M8VAR*#$T,2D]/C,U,"QC:'(H,30R*3T^-C8W+&-H<B@Q-#,I/3XS-3`L8VAR
M*#$T-"D]/C,U,"QC:'(H,30U*3T^,S,S+&-H<B@Q-#8I/3XS,S,L8VAR*#$T
M-RD]/C4P,"QC:'(H,30X*3T^-3`P+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]
M/C4P,"QC:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XQ
M,#`P+`H@("`@8VAR*#$U-"D]/C,X.2QC:'(H,34U*3T^,S,S+&-H<B@Q-38I
M/3XW,C(L8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^-#0T+&-H<B@Q-3DI/3XW
M,C(L8VAR*#$V,"D]/C(U,"QC:'(H,38Q*3T^,S,S+&-H<B@Q-C(I/3XU,#`L
M8VAR*#$V,RD]/C4P,"QC:'(H,38T*3T^-3`P+&-H<B@Q-C4I/3XU,#`L8VAR
M*#$V-BD]/C(R,"QC:'(H,38W*3T^-3`P+&-H<B@Q-C@I/3XS,S,L8VAR*#$V
M.2D]/C<T-RQC:'(H,3<P*3T^,S`P+&-H<B@Q-S$I/3XU,#`L8VAR*#$W,BD]
M/C4W,"QC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW-#<L8VAR*#$W-2D]/C,S
M,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C4W,"QC:'(H,3<X*3T^
M,S`P+&-H<B@Q-SDI/3XS,#`L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q*3T^-34V
M+&-H<B@Q.#(I/3XU-#`L8VAR*#$X,RD]/C(U,"QC:'(H,3@T*3T^,S,S+&-H
M<B@Q.#4I/3XS,#`L8VAR*#$X-BD]/C,S,"QC:'(H,3@W*3T^-3`P+&-H<B@Q
M.#@I/3XW-3`L8VAR*#$X.2D]/C<U,"QC:'(H,3DP*3T^-S4P+&-H<B@Q.3$I
M/3XU,#`L8VAR*#$Y,BD]/C<R,BQC:'(H,3DS*3T^-S(R+&-H<B@Q.30I/3XW
M,C(L8VAR*#$Y-2D]/C<R,BQC:'(H,3DV*3T^-S(R+&-H<B@Q.3<I/3XW,C(L
M"B`@("!C:'(H,3DX*3T^,3`P,"QC:'(H,3DY*3T^-S(R+&-H<B@R,#`I/3XV
M-C<L8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^-C8W+&-H<B@R,#,I/3XV-C<L
M8VAR*#(P-"D]/C,X.2QC:'(H,C`U*3T^,S@Y+&-H<B@R,#8I/3XS.#DL8VAR
M*#(P-RD]/C,X.2QC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XW,C(L8VAR*#(Q
M,"D]/C<W."QC:'(H,C$Q*3T^-S<X+&-H<B@R,3(I/3XW-S@L8VAR*#(Q,RD]
M/C<W."QC:'(H,C$T*3T^-S<X+&-H<B@R,34I/3XU-S`L8VAR*#(Q-BD]/C<W
M."QC:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]/C<R,BP*
M("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C<R,BQC:'(H,C(R*3T^-C$Q
M+&-H<B@R,C,I/3XU-38L8VAR*#(R-"D]/C4P,"QC:'(H,C(U*3T^-3`P+&-H
M<B@R,C8I/3XU,#`L8VAR*#(R-RD]/C4P,"QC:'(H,C(X*3T^-3`P+&-H<B@R
M,CDI/3XU,#`L8VAR*#(S,"D]/C<R,BQC:'(H,C,Q*3T^-#0T+&-H<B@R,S(I
M/3XT-#0L8VAR*#(S,RD]/C0T-"QC:'(H,C,T*3T^-#0T+&-H<B@R,S4I/3XT
M-#0L8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I/3XR-S@L
M8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^-3`P+&-H<B@R-#$I/3XU-38L"B`@
M("!C:'(H,C0R*3T^-3`P+&-H<B@R-#,I/3XU,#`L8VAR*#(T-"D]/C4P,"QC
M:'(H,C0U*3T^-3`P+&-H<B@R-#8I/3XU,#`L8VAR*#(T-RD]/C4W,"QC:'(H
M,C0X*3T^-3`P+&-H<B@R-#DI/3XU-38L8VAR*#(U,"D]/C4U-BQC:'(H,C4Q
M*3T^-34V+&-H<B@R-3(I/3XU-38L8VAR*#(U,RD]/C4P,"QC:'(H,C4T*3T^
M-34V+&-H<B@R-34I/3XU,#`I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O=&EM97-B
M:2YP:'``````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,C`R`#$P-#$W
M,S8R-S<P`#`R,3<U-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO
M"B1F;VYT7W=I9'1H<ULG=&EM97-"22==(#T@87)R87DH"B`@("!C:'(H,"D]
M/C(U,"QC:'(H,2D]/C(U,"QC:'(H,BD]/C(U,"QC:'(H,RD]/C(U,"QC:'(H
M-"D]/C(U,"QC:'(H-2D]/C(U,"QC:'(H-BD]/C(U,"QC:'(H-RD]/C(U,"QC
M:'(H."D]/C(U,"QC:'(H.2D]/C(U,"QC:'(H,3`I/3XR-3`L8VAR*#$Q*3T^
M,C4P+&-H<B@Q,BD]/C(U,"QC:'(H,3,I/3XR-3`L8VAR*#$T*3T^,C4P+&-H
M<B@Q-2D]/C(U,"QC:'(H,38I/3XR-3`L8VAR*#$W*3T^,C4P+&-H<B@Q."D]
M/C(U,"QC:'(H,3DI/3XR-3`L8VAR*#(P*3T^,C4P+&-H<B@R,2D]/C(U,"P*
M("`@(&-H<B@R,BD]/C(U,"QC:'(H,C,I/3XR-3`L8VAR*#(T*3T^,C4P+&-H
M<B@R-2D]/C(U,"QC:'(H,C8I/3XR-3`L8VAR*#(W*3T^,C4P+&-H<B@R."D]
M/C(U,"QC:'(H,CDI/3XR-3`L8VAR*#,P*3T^,C4P+&-H<B@S,2D]/C(U,"PG
M("<]/C(U,"PG(2<]/C,X.2PG(B<]/C4U-2PG(R<]/C4P,"PG)"<]/C4P,"PG
M)2<]/C@S,RPG)B<]/C<W."PG7"<G/3XR-S@L)R@G/3XS,S,L)RDG/3XS,S,L
M)RHG/3XU,#`L)RLG/3XU-S`L"B`@("`G+"<]/C(U,"PG+2<]/C,S,RPG+B<]
M/C(U,"PG+R<]/C(W."PG,"<]/C4P,"PG,2<]/C4P,"PG,B<]/C4P,"PG,R<]
M/C4P,"PG-"<]/C4P,"PG-2<]/C4P,"PG-B<]/C4P,"PG-R<]/C4P,"PG."<]
M/C4P,"PG.2<]/C4P,"PG.B<]/C,S,RPG.R<]/C,S,RPG/"<]/C4W,"PG/2<]
M/C4W,"PG/B<]/C4W,"PG/R<]/C4P,"PG0"<]/C@S,BPG02<]/C8V-RP*("`@
M("=")ST^-C8W+"=#)ST^-C8W+"=$)ST^-S(R+"=%)ST^-C8W+"=&)ST^-C8W
M+"=')ST^-S(R+"=()ST^-S<X+"=))ST^,S@Y+"=*)ST^-3`P+"=+)ST^-C8W
M+"=,)ST^-C$Q+"=-)ST^.#@Y+"=.)ST^-S(R+"=/)ST^-S(R+"=0)ST^-C$Q
M+"=1)ST^-S(R+"=2)ST^-C8W+"=3)ST^-34V+"=4)ST^-C$Q+"=5)ST^-S(R
M+"=6)ST^-C8W+"=7)ST^.#@Y+`H@("`@)U@G/3XV-C<L)UDG/3XV,3$L)UHG
M/3XV,3$L)ULG/3XS,S,L)UQ<)ST^,C<X+"==)ST^,S,S+"=>)ST^-3<P+"=?
M)ST^-3`P+"=@)ST^,S,S+"=A)ST^-3`P+"=B)ST^-3`P+"=C)ST^-#0T+"=D
M)ST^-3`P+"=E)ST^-#0T+"=F)ST^,S,S+"=G)ST^-3`P+"=H)ST^-34V+"=I
M)ST^,C<X+"=J)ST^,C<X+"=K)ST^-3`P+"=L)ST^,C<X+"=M)ST^-S<X+`H@
M("`@)VXG/3XU-38L)V\G/3XU,#`L)W`G/3XU,#`L)W$G/3XU,#`L)W(G/3XS
M.#DL)W,G/3XS.#DL)W0G/3XR-S@L)W4G/3XU-38L)W8G/3XT-#0L)W<G/3XV
M-C<L)W@G/3XU,#`L)WDG/3XT-#0L)WHG/3XS.#DL)WLG/3XS-#@L)WPG/3XR
M,C`L)WTG/3XS-#@L)WXG/3XU-S`L8VAR*#$R-RD]/C,U,"QC:'(H,3(X*3T^
M-3`P+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C,S,RQC:'(H,3,Q*3T^-3`P
M+`H@("`@8VAR*#$S,BD]/C4P,"QC:'(H,3,S*3T^,3`P,"QC:'(H,3,T*3T^
M-3`P+&-H<B@Q,S4I/3XU,#`L8VAR*#$S-BD]/C,S,RQC:'(H,3,W*3T^,3`P
M,"QC:'(H,3,X*3T^-34V+&-H<B@Q,SDI/3XS,S,L8VAR*#$T,"D]/CDT-"QC
M:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]/C,U,"QC:'(H
M,30T*3T^,S4P+&-H<B@Q-#4I/3XS,S,L8VAR*#$T-BD]/C,S,RQC:'(H,30W
M*3T^-3`P+&-H<B@Q-#@I/3XU,#`L8VAR*#$T.2D]/C,U,"QC:'(H,34P*3T^
M-3`P+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/C$P
M,#`L"B`@("!C:'(H,34T*3T^,S@Y+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]
M/C<R,BQC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XS.#DL8VAR*#$U.2D]/C8Q
M,2QC:'(H,38P*3T^,C4P+&-H<B@Q-C$I/3XS.#DL8VAR*#$V,BD]/C4P,"QC
M:'(H,38S*3T^-3`P+&-H<B@Q-C0I/3XU,#`L8VAR*#$V-2D]/C4P,"QC:'(H
M,38V*3T^,C(P+&-H<B@Q-C<I/3XU,#`L8VAR*#$V."D]/C,S,RQC:'(H,38Y
M*3T^-S0W+&-H<B@Q-S`I/3XR-C8L8VAR*#$W,2D]/C4P,"QC:'(H,3<R*3T^
M-C`V+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<T-RQC:'(H,3<U*3T^,S,S
M+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3<P+&-H<B@Q-S@I/3XS
M,#`L8VAR*#$W.2D]/C,P,"QC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU-S8L
M8VAR*#$X,BD]/C4P,"QC:'(H,3@S*3T^,C4P+&-H<B@Q.#0I/3XS,S,L8VAR
M*#$X-2D]/C,P,"QC:'(H,3@V*3T^,S`P+&-H<B@Q.#<I/3XU,#`L8VAR*#$X
M."D]/C<U,"QC:'(H,3@Y*3T^-S4P+&-H<B@Q.3`I/3XW-3`L8VAR*#$Y,2D]
M/C4P,"QC:'(H,3DR*3T^-C8W+&-H<B@Q.3,I/3XV-C<L8VAR*#$Y-"D]/C8V
M-RQC:'(H,3DU*3T^-C8W+&-H<B@Q.38I/3XV-C<L8VAR*#$Y-RD]/C8V-RP*
M("`@(&-H<B@Q.3@I/3XY-#0L8VAR*#$Y.2D]/C8V-RQC:'(H,C`P*3T^-C8W
M+&-H<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S*3T^-C8W+&-H
M<B@R,#0I/3XS.#DL8VAR*#(P-2D]/C,X.2QC:'(H,C`V*3T^,S@Y+&-H<B@R
M,#<I/3XS.#DL8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R,3`I
M/3XW,C(L8VAR*#(Q,2D]/C<R,BQC:'(H,C$R*3T^-S(R+&-H<B@R,3,I/3XW
M,C(L8VAR*#(Q-"D]/C<R,BQC:'(H,C$U*3T^-3<P+&-H<B@R,38I/3XW,C(L
M8VAR*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@
M("!C:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XV,3$L8VAR*#(R,BD]/C8Q,2QC
M:'(H,C(S*3T^-3`P+&-H<B@R,C0I/3XU,#`L8VAR*#(R-2D]/C4P,"QC:'(H
M,C(V*3T^-3`P+&-H<B@R,C<I/3XU,#`L8VAR*#(R."D]/C4P,"QC:'(H,C(Y
M*3T^-3`P+&-H<B@R,S`I/3XW,C(L8VAR*#(S,2D]/C0T-"QC:'(H,C,R*3T^
M-#0T+&-H<B@R,S,I/3XT-#0L8VAR*#(S-"D]/C0T-"QC:'(H,C,U*3T^-#0T
M+&-H<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H
M<B@R,SDI/3XR-S@L8VAR*#(T,"D]/C4P,"QC:'(H,C0Q*3T^-34V+`H@("`@
M8VAR*#(T,BD]/C4P,"QC:'(H,C0S*3T^-3`P+&-H<B@R-#0I/3XU,#`L8VAR
M*#(T-2D]/C4P,"QC:'(H,C0V*3T^-3`P+&-H<B@R-#<I/3XU-S`L8VAR*#(T
M."D]/C4P,"QC:'(H,C0Y*3T^-34V+&-H<B@R-3`I/3XU-38L8VAR*#(U,2D]
M/C4U-BQC:'(H,C4R*3T^-34V+&-H<B@R-3,I/3XT-#0L8VAR*#(U-"D]/C4P
M,"QC:'(H,C4U*3T^-#0T*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W1I;65S
M:2YP:'``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C$W-@`Q,#0Q
M-S,V,C<W,``P,C$V,C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J
M+PHD9F]N=%]W:61T:'-;)W1I;65S22==(#T@87)R87DH"B`@("!C:'(H,"D]
M/C(U,"QC:'(H,2D]/C(U,"QC:'(H,BD]/C(U,"QC:'(H,RD]/C(U,"QC:'(H
M-"D]/C(U,"QC:'(H-2D]/C(U,"QC:'(H-BD]/C(U,"QC:'(H-RD]/C(U,"QC
M:'(H."D]/C(U,"QC:'(H.2D]/C(U,"QC:'(H,3`I/3XR-3`L8VAR*#$Q*3T^
M,C4P+&-H<B@Q,BD]/C(U,"QC:'(H,3,I/3XR-3`L8VAR*#$T*3T^,C4P+&-H
M<B@Q-2D]/C(U,"QC:'(H,38I/3XR-3`L8VAR*#$W*3T^,C4P+&-H<B@Q."D]
M/C(U,"QC:'(H,3DI/3XR-3`L8VAR*#(P*3T^,C4P+&-H<B@R,2D]/C(U,"P*
M("`@(&-H<B@R,BD]/C(U,"QC:'(H,C,I/3XR-3`L8VAR*#(T*3T^,C4P+&-H
M<B@R-2D]/C(U,"QC:'(H,C8I/3XR-3`L8VAR*#(W*3T^,C4P+&-H<B@R."D]
M/C(U,"QC:'(H,CDI/3XR-3`L8VAR*#,P*3T^,C4P+&-H<B@S,2D]/C(U,"PG
M("<]/C(U,"PG(2<]/C,S,RPG(B<]/C0R,"PG(R<]/C4P,"PG)"<]/C4P,"PG
M)2<]/C@S,RPG)B<]/C<W."PG7"<G/3XR,30L)R@G/3XS,S,L)RDG/3XS,S,L
M)RHG/3XU,#`L)RLG/3XV-S4L"B`@("`G+"<]/C(U,"PG+2<]/C,S,RPG+B<]
M/C(U,"PG+R<]/C(W."PG,"<]/C4P,"PG,2<]/C4P,"PG,B<]/C4P,"PG,R<]
M/C4P,"PG-"<]/C4P,"PG-2<]/C4P,"PG-B<]/C4P,"PG-R<]/C4P,"PG."<]
M/C4P,"PG.2<]/C4P,"PG.B<]/C,S,RPG.R<]/C,S,RPG/"<]/C8W-2PG/2<]
M/C8W-2PG/B<]/C8W-2PG/R<]/C4P,"PG0"<]/CDR,"PG02<]/C8Q,2P*("`@
M("=")ST^-C$Q+"=#)ST^-C8W+"=$)ST^-S(R+"=%)ST^-C$Q+"=&)ST^-C$Q
M+"=')ST^-S(R+"=()ST^-S(R+"=))ST^,S,S+"=*)ST^-#0T+"=+)ST^-C8W
M+"=,)ST^-34V+"=-)ST^.#,S+"=.)ST^-C8W+"=/)ST^-S(R+"=0)ST^-C$Q
M+"=1)ST^-S(R+"=2)ST^-C$Q+"=3)ST^-3`P+"=4)ST^-34V+"=5)ST^-S(R
M+"=6)ST^-C$Q+"=7)ST^.#,S+`H@("`@)U@G/3XV,3$L)UDG/3XU-38L)UHG
M/3XU-38L)ULG/3XS.#DL)UQ<)ST^,C<X+"==)ST^,S@Y+"=>)ST^-#(R+"=?
M)ST^-3`P+"=@)ST^,S,S+"=A)ST^-3`P+"=B)ST^-3`P+"=C)ST^-#0T+"=D
M)ST^-3`P+"=E)ST^-#0T+"=F)ST^,C<X+"=G)ST^-3`P+"=H)ST^-3`P+"=I
M)ST^,C<X+"=J)ST^,C<X+"=K)ST^-#0T+"=L)ST^,C<X+"=M)ST^-S(R+`H@
M("`@)VXG/3XU,#`L)V\G/3XU,#`L)W`G/3XU,#`L)W$G/3XU,#`L)W(G/3XS
M.#DL)W,G/3XS.#DL)W0G/3XR-S@L)W4G/3XU,#`L)W8G/3XT-#0L)W<G/3XV
M-C<L)W@G/3XT-#0L)WDG/3XT-#0L)WHG/3XS.#DL)WLG/3XT,#`L)WPG/3XR
M-S4L)WTG/3XT,#`L)WXG/3XU-#$L8VAR*#$R-RD]/C,U,"QC:'(H,3(X*3T^
M-3`P+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C,S,RQC:'(H,3,Q*3T^-3`P
M+`H@("`@8VAR*#$S,BD]/C4U-BQC:'(H,3,S*3T^.#@Y+&-H<B@Q,S0I/3XU
M,#`L8VAR*#$S-2D]/C4P,"QC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P
M+&-H<B@Q,S@I/3XU,#`L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^.30T+&-H
M<B@Q-#$I/3XS-3`L8VAR*#$T,BD]/C4U-BQC:'(H,30S*3T^,S4P+&-H<B@Q
M-#0I/3XS-3`L8VAR*#$T-2D]/C,S,RQC:'(H,30V*3T^,S,S+&-H<B@Q-#<I
M/3XU-38L8VAR*#$T."D]/C4U-BQC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU
M,#`L8VAR*#$U,2D]/C@X.2QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XY.#`L
M"B`@("!C:'(H,34T*3T^,S@Y+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]/C8V
M-RQC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XS.#DL8VAR*#$U.2D]/C4U-BQC
M:'(H,38P*3T^,C4P+&-H<B@Q-C$I/3XS.#DL8VAR*#$V,BD]/C4P,"QC:'(H
M,38S*3T^-3`P+&-H<B@Q-C0I/3XU,#`L8VAR*#$V-2D]/C4P,"QC:'(H,38V
M*3T^,C<U+&-H<B@Q-C<I/3XU,#`L8VAR*#$V."D]/C,S,RQC:'(H,38Y*3T^
M-S8P+&-H<B@Q-S`I/3XR-S8L8VAR*#$W,2D]/C4P,"QC:'(H,3<R*3T^-C<U
M+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<V,"QC:'(H,3<U*3T^,S,S+`H@
M("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-C<U+&-H<B@Q-S@I/3XS,#`L
M8VAR*#$W.2D]/C,P,"QC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU,#`L8VAR
M*#$X,BD]/C4R,RQC:'(H,3@S*3T^,C4P+&-H<B@Q.#0I/3XS,S,L8VAR*#$X
M-2D]/C,P,"QC:'(H,3@V*3T^,S$P+&-H<B@Q.#<I/3XU,#`L8VAR*#$X."D]
M/C<U,"QC:'(H,3@Y*3T^-S4P+&-H<B@Q.3`I/3XW-3`L8VAR*#$Y,2D]/C4P
M,"QC:'(H,3DR*3T^-C$Q+&-H<B@Q.3,I/3XV,3$L8VAR*#$Y-"D]/C8Q,2QC
M:'(H,3DU*3T^-C$Q+&-H<B@Q.38I/3XV,3$L8VAR*#$Y-RD]/C8Q,2P*("`@
M(&-H<B@Q.3@I/3XX.#DL8VAR*#$Y.2D]/C8V-RQC:'(H,C`P*3T^-C$Q+&-H
M<B@R,#$I/3XV,3$L8VAR*#(P,BD]/C8Q,2QC:'(H,C`S*3T^-C$Q+&-H<B@R
M,#0I/3XS,S,L8VAR*#(P-2D]/C,S,RQC:'(H,C`V*3T^,S,S+&-H<B@R,#<I
M/3XS,S,L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-C8W+&-H<B@R,3`I/3XW
M,C(L8VAR*#(Q,2D]/C<R,BQC:'(H,C$R*3T^-S(R+&-H<B@R,3,I/3XW,C(L
M8VAR*#(Q-"D]/C<R,BQC:'(H,C$U*3T^-C<U+&-H<B@R,38I/3XW,C(L8VAR
M*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@("!C
M:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XU-38L8VAR*#(R,BD]/C8Q,2QC:'(H
M,C(S*3T^-3`P+&-H<B@R,C0I/3XU,#`L8VAR*#(R-2D]/C4P,"QC:'(H,C(V
M*3T^-3`P+&-H<B@R,C<I/3XU,#`L8VAR*#(R."D]/C4P,"QC:'(H,C(Y*3T^
M-3`P+&-H<B@R,S`I/3XV-C<L8VAR*#(S,2D]/C0T-"QC:'(H,C,R*3T^-#0T
M+&-H<B@R,S,I/3XT-#0L8VAR*#(S-"D]/C0T-"QC:'(H,C,U*3T^-#0T+&-H
M<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H<B@R
M,SDI/3XR-S@L8VAR*#(T,"D]/C4P,"QC:'(H,C0Q*3T^-3`P+`H@("`@8VAR
M*#(T,BD]/C4P,"QC:'(H,C0S*3T^-3`P+&-H<B@R-#0I/3XU,#`L8VAR*#(T
M-2D]/C4P,"QC:'(H,C0V*3T^-3`P+&-H<B@R-#<I/3XV-S4L8VAR*#(T."D]
M/C4P,"QC:'(H,C0Y*3T^-3`P+&-H<B@R-3`I/3XU,#`L8VAR*#(U,2D]/C4P
M,"QC:'(H,C4R*3T^-3`P+&-H<B@R-3,I/3XT-#0L8VAR*#(U-"D]/C4P,"QC
M:'(H,C4U*3T^-#0T*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]Z87!F
M9&EN9V)A=',N<&AP````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8P,S``,3`T
M,3<S-C(W-S``,#(R-S<S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@
M*B\*)&9O;G1?=VED=&AS6R=Z87!F9&EN9V)A=',G72`](&%R<F%Y*`H@("`@
M8VAR*#`I/3XP+&-H<B@Q*3T^,"QC:'(H,BD]/C`L8VAR*#,I/3XP+&-H<B@T
M*3T^,"QC:'(H-2D]/C`L8VAR*#8I/3XP+&-H<B@W*3T^,"QC:'(H."D]/C`L
M8VAR*#DI/3XP+&-H<B@Q,"D]/C`L8VAR*#$Q*3T^,"QC:'(H,3(I/3XP+&-H
M<B@Q,RD]/C`L8VAR*#$T*3T^,"QC:'(H,34I/3XP+&-H<B@Q-BD]/C`L8VAR
M*#$W*3T^,"QC:'(H,3@I/3XP+&-H<B@Q.2D]/C`L8VAR*#(P*3T^,"QC:'(H
M,C$I/3XP+`H@("`@8VAR*#(R*3T^,"QC:'(H,C,I/3XP+&-H<B@R-"D]/C`L
M8VAR*#(U*3T^,"QC:'(H,C8I/3XP+&-H<B@R-RD]/C`L8VAR*#(X*3T^,"QC
M:'(H,CDI/3XP+&-H<B@S,"D]/C`L8VAR*#,Q*3T^,"PG("<]/C(W."PG(2<]
M/CDW-"PG(B<]/CDV,2PG(R<]/CDW-"PG)"<]/CDX,"PG)2<]/C<Q.2PG)B<]
M/C<X.2PG7"<G/3XW.3`L)R@G/3XW.3$L)RDG/3XV.3`L)RHG/3XY-C`L)RLG
M/3XY,SDL"B`@("`G+"<]/C4T.2PG+2<]/C@U-2PG+B<]/CDQ,2PG+R<]/CDS
M,RPG,"<]/CDQ,2PG,2<]/CDT-2PG,B<]/CDW-"PG,R<]/C<U-2PG-"<]/C@T
M-BPG-2<]/C<V,BPG-B<]/C<V,2PG-R<]/C4W,2PG."<]/C8W-RPG.2<]/C<V
M,RPG.B<]/C<V,"PG.R<]/C<U.2PG/"<]/C<U-"PG/2<]/C0Y-"PG/B<]/C4U
M,BPG/R<]/C4S-RPG0"<]/C4W-RPG02<]/C8Y,BP*("`@("=")ST^-S@V+"=#
M)ST^-S@X+"=$)ST^-S@X+"=%)ST^-SDP+"=&)ST^-SDS+"=')ST^-SDT+"=(
M)ST^.#$V+"=))ST^.#(S+"=*)ST^-S@Y+"=+)ST^.#0Q+"=,)ST^.#(S+"=-
M)ST^.#,S+"=.)ST^.#$V+"=/)ST^.#,Q+"=0)ST^.3(S+"=1)ST^-S0T+"=2
M)ST^-S(S+"=3)ST^-S0Y+"=4)ST^-SDP+"=5)ST^-SDR+"=6)ST^-CDU+"=7
M)ST^-S<V+`H@("`@)U@G/3XW-C@L)UDG/3XW.3(L)UHG/3XW-3DL)ULG/3XW
M,#<L)UQ<)ST^-S`X+"==)ST^-C@R+"=>)ST^-S`Q+"=?)ST^.#(V+"=@)ST^
M.#$U+"=A)ST^-S@Y+"=B)ST^-S@Y+"=C)ST^-S`W+"=D)ST^-C@W+"=E)ST^
M-CDV+"=F)ST^-C@Y+"=G)ST^-S@V+"=H)ST^-S@W+"=I)ST^-S$S+"=J)ST^
M-SDQ+"=K)ST^-S@U+"=L)ST^-SDQ+"=M)ST^.#<S+`H@("`@)VXG/3XW-C$L
M)V\G/3XW-C(L)W`G/3XW-C(L)W$G/3XW-3DL)W(G/3XW-3DL)W,G/3XX.3(L
M)W0G/3XX.3(L)W4G/3XW.#@L)W8G/3XW.#0L)W<G/3XT,S@L)W@G/3XQ,S@L
M)WDG/3XR-S<L)WHG/3XT,34L)WLG/3XS.3(L)WPG/3XS.3(L)WTG/3XV-C@L
M)WXG/3XV-C@L8VAR*#$R-RD]/C`L8VAR*#$R."D]/C,Y,"QC:'(H,3(Y*3T^
M,SDP+&-H<B@Q,S`I/3XS,3<L8VAR*#$S,2D]/C,Q-RP*("`@(&-H<B@Q,S(I
M/3XR-S8L8VAR*#$S,RD]/C(W-BQC:'(H,3,T*3T^-3`Y+&-H<B@Q,S4I/3XU
M,#DL8VAR*#$S-BD]/C0Q,"QC:'(H,3,W*3T^-#$P+&-H<B@Q,S@I/3XR,S0L
M8VAR*#$S.2D]/C(S-"QC:'(H,30P*3T^,S,T+&-H<B@Q-#$I/3XS,S0L8VAR
M*#$T,BD]/C`L8VAR*#$T,RD]/C`L8VAR*#$T-"D]/C`L8VAR*#$T-2D]/C`L
M8VAR*#$T-BD]/C`L8VAR*#$T-RD]/C`L8VAR*#$T."D]/C`L8VAR*#$T.2D]
M/C`L8VAR*#$U,"D]/C`L8VAR*#$U,2D]/C`L8VAR*#$U,BD]/C`L8VAR*#$U
M,RD]/C`L"B`@("!C:'(H,34T*3T^,"QC:'(H,34U*3T^,"QC:'(H,34V*3T^
M,"QC:'(H,34W*3T^,"QC:'(H,34X*3T^,"QC:'(H,34Y*3T^,"QC:'(H,38P
M*3T^,"QC:'(H,38Q*3T^-S,R+&-H<B@Q-C(I/3XU-#0L8VAR*#$V,RD]/C4T
M-"QC:'(H,38T*3T^.3$P+&-H<B@Q-C4I/3XV-C<L8VAR*#$V-BD]/C<V,"QC
M:'(H,38W*3T^-S8P+&-H<B@Q-C@I/3XW-S8L8VAR*#$V.2D]/C4Y-2QC:'(H
M,3<P*3T^-CDT+&-H<B@Q-S$I/3XV,C8L8VAR*#$W,BD]/C<X."QC:'(H,3<S
M*3T^-S@X+&-H<B@Q-S0I/3XW.#@L8VAR*#$W-2D]/C<X."P*("`@(&-H<B@Q
M-S8I/3XW.#@L8VAR*#$W-RD]/C<X."QC:'(H,3<X*3T^-S@X+&-H<B@Q-SDI
M/3XW.#@L8VAR*#$X,"D]/C<X."QC:'(H,3@Q*3T^-S@X+&-H<B@Q.#(I/3XW
M.#@L8VAR*#$X,RD]/C<X."QC:'(H,3@T*3T^-S@X+&-H<B@Q.#4I/3XW.#@L
M8VAR*#$X-BD]/C<X."QC:'(H,3@W*3T^-S@X+&-H<B@Q.#@I/3XW.#@L8VAR
M*#$X.2D]/C<X."QC:'(H,3DP*3T^-S@X+&-H<B@Q.3$I/3XW.#@L8VAR*#$Y
M,BD]/C<X."QC:'(H,3DS*3T^-S@X+&-H<B@Q.30I/3XW.#@L8VAR*#$Y-2D]
M/C<X."QC:'(H,3DV*3T^-S@X+&-H<B@Q.3<I/3XW.#@L"B`@("!C:'(H,3DX
M*3T^-S@X+&-H<B@Q.3DI/3XW.#@L8VAR*#(P,"D]/C<X."QC:'(H,C`Q*3T^
M-S@X+&-H<B@R,#(I/3XW.#@L8VAR*#(P,RD]/C<X."QC:'(H,C`T*3T^-S@X
M+&-H<B@R,#4I/3XW.#@L8VAR*#(P-BD]/C<X."QC:'(H,C`W*3T^-S@X+&-H
M<B@R,#@I/3XW.#@L8VAR*#(P.2D]/C<X."QC:'(H,C$P*3T^-S@X+&-H<B@R
M,3$I/3XW.#@L8VAR*#(Q,BD]/C@Y-"QC:'(H,C$S*3T^.#,X+&-H<B@R,30I
M/3XQ,#$V+&-H<B@R,34I/3XT-3@L8VAR*#(Q-BD]/C<T."QC:'(H,C$W*3T^
M.3(T+&-H<B@R,3@I/3XW-#@L8VAR*#(Q.2D]/CDQ."P*("`@(&-H<B@R,C`I
M/3XY,C<L8VAR*#(R,2D]/CDR."QC:'(H,C(R*3T^.3(X+&-H<B@R,C,I/3XX
M,S0L8VAR*#(R-"D]/C@W,RQC:'(H,C(U*3T^.#(X+&-H<B@R,C8I/3XY,C0L
M8VAR*#(R-RD]/CDR-"QC:'(H,C(X*3T^.3$W+&-H<B@R,CDI/3XY,S`L8VAR
M*#(S,"D]/CDS,2QC:'(H,C,Q*3T^-#8S+&-H<B@R,S(I/3XX.#,L8VAR*#(S
M,RD]/C@S-BQC:'(H,C,T*3T^.#,V+&-H<B@R,S4I/3XX-C<L8VAR*#(S-BD]
M/C@V-RQC:'(H,C,W*3T^-CDV+&-H<B@R,S@I/3XV.38L8VAR*#(S.2D]/C@W
M-"QC:'(H,C0P*3T^,"QC:'(H,C0Q*3T^.#<T+`H@("`@8VAR*#(T,BD]/C<V
M,"QC:'(H,C0S*3T^.30V+&-H<B@R-#0I/3XW-S$L8VAR*#(T-2D]/C@V-2QC
M:'(H,C0V*3T^-S<Q+&-H<B@R-#<I/3XX.#@L8VAR*#(T."D]/CDV-RQC:'(H
M,C0Y*3T^.#@X+&-H<B@R-3`I/3XX,S$L8VAR*#(U,2D]/C@W,RQC:'(H,C4R
M*3T^.3(W+&-H<B@R-3,I/3XY-S`L8VAR*#(U-"D]/CDQ."QC:'(H,C4U*3T^
M,"D["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]#4U8N<&AP````````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0P,S0T`#$P
M-#$W,S8R-S<P`#`Q-S(Q-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[
M"G)E<75I<F5?;VYC92`G1FEL92YP:'`G.PH*+RHJ"B`J(%1H92!&:6QE7T-3
M5B!P86-K86=E(&%L;&]W<R!R96%D:6YG(&%N9"!C<F5A=&EN9R!O9B!#4U8@
M9&%T82!A;F0@9FEL97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`L=B`Q+C0N,BXV(#(P,#8O,#$O,#$@,C$Z,C@Z,34@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#,@5&]M87,@5F]N(%9E
M<V-H;&5R($-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P
M-2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4L('1H870@:7,*("H@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE
M(&%T('1H<F]U9V@*("H@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U(&1I9"!N;W0*
M("H@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H90H@*B!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@80H@*B!C;W!Y(&EM;65D:6%T96QY+@H@*@H@
M*B!`875T:&]R("!4;VUA<R!6;VX@5F5S8VAL97(@0V]X(#QC;WA`:61E8VYE
M="YC;VT^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!&:6QE7T-3
M5@H@*B\*8VQA<W,@1FEL95]#4U8@>PH*("`@("\J*@H@("`@("H@1&ES8V]V
M97)S('1H92!F;W)M870@;V8@82!#4U8@9FEL92`H=&AE(&YU;6)E<B!O9B!F
M:65L9',L('1H92!S97!A<F%T;W(L"B`@("`@*B!T:&4@<75O=&4@<W1R:6YG
M+"!A;F0@=&AE(&QI;F4@8G)E86LI+@H@("`@("H*("`@("`J(%=E(&-A;B=T
M('5S92!T:&4@875T;U]D971E8W1?;&EN95]E;F1I;F=S(%!(4"!S971T:6YG
M+"!B96-A=7-E(&ET)W,@;F]T"B`@("`@*B!S=7!P;W)T960@8GD@9F=E=',H
M*2!C;VYT<F%R>2!T;R!W:&%T('1H92!M86YU86P@<V%Y<RX*("`@("`J"B`@
M("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@5&AE
M($-35B!F:6QE(&YA;64*("`@("`J($!P87)A;2!A<G)A>2`@($5X=')A('-E
M<&%R871O<G,@=&AA="!S:&]U;&0@8F4@8VAE8VME9"!F;W(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&9O<FUA="!H87-H+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D:7-C;W9E<D9O<FUA="@D9FEL92P@)&5X=')A4V5P
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"$D9G`@/2!`9F]P96XH
M)&9I;&4L("=R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T-O=6QD(&YO="!O<&5N(&9I;&4Z("<@+B`D9FEL92D["B`@("`@
M("`@?0H*("`@("`@("`D<V5P<R`](&%R<F%Y*")<="(L("<[)RP@)SHG+"`G
M+"<I.PH@("`@("`@("1S97!S(#T@87)R87E?;65R9V4H)'-E<',L("1E>'1R
M85-E<',I.PH@("`@("`@("1M871C:&5S(#T@87)R87DH*3L*("`@("`@("`D
M8W)L9B`](&YU;&P["B`@("`@("`@)&-O;F8@/2!A<G)A>2@I.PH*("`@("`@
M("`O*B!486ME('1H92!F:7)S="`Q,"!L:6YE<R!A;F0@<W1O<F4@=&AE(&YU
M;6)E<B!O9B!O8W5R<F5N8V5S(&9O<B!E86-H"B`@("`@("`@("H@<V5P87)A
M=&]R(&EN(&5A8V@@;&EN92X@*B\*("`@("`@("!F;W(@*"1I(#T@,#L@*"1I
M(#P@,3`I("8F("@D;&EN92`](&9G971S*"1F<"DI.RD@>PH@("`@("`@("`@
M("`O*B!$;R!W92!H879E($UA8R!L:6YE(&5N9&EN9W,_("HO"B`@("`@("`@
M("`@("1L:6YE<R`]('!R96=?<W!L:70H)R]<<B@_(5QN*2\G+"`D;&EN92P@
M,3`I.PH@("`@("`@("`@("`D:B`](#`["B`@("`@("`@("`@("1C(#T@8V]U
M;G0H)&QI;F5S*3L*("`@("`@("`@("`@:68@*"1C(#X@,2D@>PH@("`@("`@
M("`@("`@("`@)&-R;&8@/2`B7'(B.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@('=H:6QE("@D:2`\(#$P("8F("1J(#P@)&,I('L*("`@("`@("`@("`@
M("`@("1L:6YE(#T@)&QI;F5S6R1J73L*("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&-R;&8I*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M87)R87DH(EQR7&XB+"`B7&XB*2!A<R`D8RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H<W5B<W1R*"1L:6YE+"`M<W1R;&5N*"1C*2D@/3T@)&,I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C<FQF(#T@)&,["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@
M("`D:BLK.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'-E<',@87,@)'-E
M<"D@>PH@("`@("`@("`@("`@("`@("`@("1M871C:&5S6R1S97!=6R1I72`]
M('-U8G-T<E]C;W5N="@D;&EN92P@)'-E<"D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1C
M<FQF*2D@>PH@("`@("`@("`@("`D8V]N9ELG8W)L9B==(#T@)&-R;&8["B`@
M("`@("`@?0H*("`@("`@("`O*B!'<F]U<"!T:&4@<F5S=6QT<R!B>2!A;6]U
M;G0@;V8@97%U86P@;V-U<G)E;F-E<RX@*B\*("`@("`@("`D9FEE;&1S(#T@
M87)R87DH*3L*("`@("`@("`D86UO=6YT(#T@87)R87DH*3L*("`@("`@("!F
M;W)E86-H("@D;6%T8VAE<R!A<R`D<V5P(#T^("1L:6YE<RD@>PH@("`@("`@
M("`@("`D=&EM97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=&EM97-;,%T@
M/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D;&EN97,@87,@)&YU;2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1N=6T@/B`P*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1I;65S6R1N=6U=(#T@*&ES<V5T*"1T:6UE<ULD;G5M72DI(#\@
M)'1I;65S6R1N=6U=("L@,2`Z(#$["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@87)S;W)T*"1T:6UE<RD["B`@("`@("`@
M("`@("1F:65L9'-;)'-E<%T@/2!K97DH)'1I;65S*3L*("`@("`@("`@("`@
M)&%M;W5N=%LD<V5P72`]("1T:6UE<UMK97DH)'1I;65S*5T["B`@("`@("`@
M?0H@("`@("`@(&%R<V]R="@D86UO=6YT*3L*("`@("`@("`D<V5P(#T@:V5Y
M*"1A;6]U;G0I.PH*("`@("`@("`D8V]N9ELG9FEE;&1S)UT@/2`D9FEE;&1S
M6R1S97!=("L@,3L*("`@("`@("`D8V]N9ELG<V5P)UT@("`@/2`D<V5P.PH*
M("`@("`@("`O*B!497-T(&EF('1H97)E(&%R92!F:65L9',@=VET:"!Q=6]T
M97,@87)R;W5N9"!I;B!T:&4@9FER<W0@-0H@("`@("`@("`J(&QI;F5S+B`J
M+PH@("`@("`@("1Q=6]T97,@/2`G(EPG)SL*("`@("`@("`D<75O=&4@(#T@
M)R<["B`@("`@("`@<F5W:6YD*"1F<"D["B`@("`@("`@9F]R("@D:2`](#`[
M("@D:2`\(#4I("8F("@D;&EN92`](&9G971S*"1F<"DI.R`D:2LK*2!["B`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H*")\)'-E<"A;)'%U;W1E<UTI+BHH
M6R1Q=6]T97-=*21S97!\52(L("1L:6YE+"`D;6%T8V@I*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&UA=&-H6S%=(#T]("1M871C:%LR72D@>PH@("`@("`@
M("`@("`@("`@("`@("1Q=6]T92`]("1M871C:%LQ73L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B?%XH6R1Q=6]T97-=*2XJ
M*%LD<75O=&5S72DD<V5P?"(L("1L:6YE+"`D;6%T8V@I('Q\"B`@("`@("`@
M("`@("`@("!P<F5G7VUA=&-H*")\*%LD<75O=&5S72DN*BA;)'%U;W1E<UTI
M)'-E<%QS)'Q5<R(L("1L:6YE+"`D;6%T8V@I*0H@("`@("`@("`@("!["B`@
M("`@("`@("`@("`@("!I9B`H)&UA=&-H6S%=(#T]("1M871C:%LR72D@>PH@
M("`@("`@("`@("`@("`@("`@("1Q=6]T92`]("1M871C:%LQ73L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("`D8V]N9ELG<75O=&4G72`]("1Q
M=6]T93L*"B`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("\O(%A86"!7
M:&%T(&%B;W5T('1R>6EN9R!T;R!D:7-C;W9E<B!T:&4@(FAE861E<B(_"B`@
M("`@("`@<F5T=7)N("1C;VYF.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A
M9',@82!R;W<@9G)O;2!A($-35B!F:6QE(&%N9"!R971U<FYS(&ET(&%S(&%N
M(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@(%1H
M92!N86UE(&]F('1H92!#4U8@9FEL92X*("`@("`J($!P87)A;2!A<G)A>2`D
M8V]N9B`@(%1H92!C;VYF:6=U<F%T:6]N(&9O<B!T:&4@0U-6(&9I;&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>7QB;V]L96%N("!4:&4@0U-6(&1A
M=&$@;W(@9F%L<V4@:68@;F\@;6]R92!D871A(&%V86EL86)L92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5A9"@D9FEL92P@)B1C;VYF*0H@("`@>PH@("`@
M("`@("1F<"`]($9I;&5?0U-6.CIG9710;VEN=&5R*"1F:6QE+"`D8V]N9BP@
M1DE,15]-3T1%7U)%040I.PH@("`@("`@(&EF("AI<U]A*"1F<"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@('T*
M"B`@("`@("`@)&QI;F4@/2!F9V5T<R@D9G`I.PH@("`@("`@(&EF("@A)&QI
M;F4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@57-E(')E8611=6]T960H*2!I9B!W92!H879E($UA8R!L:6YE
M(&5N9&EN9W,N("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]<<B@_(5QN
M*2\G+"`D;&EN92DI('L*("`@("`@("`@("`@9G-E96LH)&9P+"`M<W1R;&5N
M*"1L:6YE*2P@4T5%2U]#55(I.PH@("`@("`@("`@("!R971U<FX@1FEL95]#
M4U8Z.G)E8611=6]T960H)&9I;&4L("1C;VYF*3L*("`@("`@("!]"@H@("`@
M("`@($9I;&5?0U-6.CI?;&EN92A&:6QE7T-35CHZ7VQI;F4H*2`K(#$I.PH*
M("`@("`@("!I9B`H)&-O;F9;)V9I96QD<R==(#T](#$I('L*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"1L:6YE*3L*("`@("`@("!]"@H@("`@("`@("1F
M:65L9',@/2!E>'!L;V1E*"1C;VYF6R=S97`G72P@)&QI;F4I.PH@("`@("`@
M(&EF("@D8V]N9ELG<75O=&4G72D@>PH@("`@("`@("`@("`D;&%S="`]("8D
M9FEE;&1S6V-O=6YT*"1F:65L9',I("T@,5T["B`@("`@("`@("`@("\J($9A
M;&QB86-K('1O(')E860@=&AE(&QI;F4@=VET:"!R96%D475O=&5D*"D@=VAE
M;B!G=65S<R!T:&%T('1H90H@("`@("`@("`@("`@*B!S:6UP;&4@97AP;&]D
M92!W;VXG="!W;W)K(')I9VAT+B`J+PH@("`@("`@("`@("!I9B`H*'-U8G-T
M<B@D;&%S="P@+7-T<FQE;B@D8V]N9ELG8W)L9B==*2D@/3T@)&-O;F9;)V-R
M;&8G72`F)@H@("`@("`@("`@("`@("`@("1L87-T>S!](#T]("1C;VYF6R=Q
M=6]T92==("8F"B`@("`@("`@("`@("`@("`@)&QA<W1[<W1R;&5N*')T<FEM
M*"1L87-T*2D@+2`Q?2`A/2`D8V]N9ELG<75O=&4G72D@?'P*("`@("`@("`@
M("`@("`@("AC;W5N="@D9FEE;&1S*2`A/2`D8V]N9ELG9FEE;&1S)UTI"B`@
M("`@("`@("`@("`@("`@("`@+R\@6%A8('!E<FAA<',@=&AE<F4@:7,@82!S
M97!A<F%T;W(@:6YS:61E(&$@<75O=&5D(&9I96QD"B`@("`@("`@("`@("`@
M("`@("`@+R]P<F5G7VUA=&-H*")\>R1C;VYF6R=Q=6]T92==?2XJ>R1C;VYF
M6R=S97`G77TN*GLD8V]N9ELG<75O=&4G77U\52(L("1L:6YE*0H@("`@("`@
M("`@("`@("`@*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!F<V5E
M:R@D9G`L("US=')L96XH)&QI;F4I+"!3145+7T-54BD["B`@("`@("`@("`@
M("`@("!R971U<FX@1FEL95]#4U8Z.G)E8611=6]T960H)&9I;&4L("1C;VYF
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L87-T
M(#T@<G1R:6TH)&QA<W0I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9I
M96QD<R!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@("`@("1F:65L
M9'-;)&M=(#T@1FEL95]#4U8Z.G5N<75O=&4H)'8L("1C;VYF6R=Q=6]T92==
M+"`D8V]N9ELG8W)L9B==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F:65L9'-;8V]U
M;G0H)&9I96QD<RD@+3%=(#T@<G1R:6TH)&9I96QD<UMC;W5N="@D9FEE;&1S
M*2`M,5TI.PH@("`@("`@('T*"B`@("`@("`@:68@*&-O=6YT*"1F:65L9',I
M(#P@)&-O;F9;)V9I96QD<R==*2!["B`@("`@("`@("`@($9I;&5?0U-6.CIW
M87)N:6YG*'-P<FEN=&8H7R@B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L
M:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(BDL($9I;&5?0U-6.CI?
M;&EN92@I+"`D8V]N9ELG9FEE;&1S)UTL(&-O=6YT*"1F:65L9',I*2D["B`@
M("`@("`@("`@("1F:65L9',@/2!A<G)A>5]M97)G92@D9FEE;&1S+"!A<G)A
M>5]F:6QL*#`L("1C;VYF6R=F:65L9',G72`M(&-O=6YT*"1F:65L9',I+"`G
M)RDI.PH@("`@("`@('T@96QS96EF("AC;W5N="@D9FEE;&1S*2`^("1C;VYF
M6R=F:65L9',G72D@>PH@("`@("`@("`@("!&:6QE7T-35CHZ=V%R;FEN9RAS
M<')I;G1F*%\H(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N(BDL($9I;&5?0U-6.CI?;&EN92@I+"`D8V]N9ELG
M9FEE;&1S)UTI*3L*("`@("`@("`@("`@87)R87E?<W!L:6-E*"1F:65L9',L
M("1C;VYF6R=F:65L9',G72D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&9I96QD<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E861S(&$@<F]W(&9R
M;VT@82!#4U8@9FEL92!A;F0@<F5T=7)N<R!I="!A<R!A;B!A<G)A>2X*("`@
M("`J(%1H:7,@;65T:&]D(&ES(&%B;&4@=&\@<F5A9"!F:65L9',@=VET:"!M
M=6QT:6QI;F4@9&%T82!A;F0@;F]R;6%L:7IE<PH@("`@("H@;&EN96)R96%K
M<R!T;R!S:6YG;&4@;F5W;&EN92!C:&%R86-T97)S("@P>#!A*2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("!4:&4@;F%M92!O9B!T:&4@
M0U-6(&9I;&4N"B`@("`@*B!`<&%R86T@87)R87D@)&-O;F8@("!4:&4@8V]N
M9FEG=7)A=&EO;B!F;W(@=&AE($-35B!F:6QE+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87E\8F]O;&5A;B`@5&AE($-35B!D871A(&]R(&9A;'-E(&EF
M(&YO(&UO<F4@9&%T82!A=F%I;&%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E8611=6]T960H)&9I;&4L("8D8V]N9BD*("`@('L*("`@("`@("`D9G`@
M/2!&:6QE7T-35CHZ9V5T4&]I;G1E<B@D9FEL92P@)&-O;F8L($9)3$5?34]$
M15]214%$*3L*("`@("`@("!I9B`H:7-?82@D9G`L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@("`@("!]"@H@("`@("`@
M("\J($$@8G5F9F5R('=I=&@@86QL(&-H87)A8W1E<G,@;V8@=&AE(&-U<G)E
M;G0@9FEE;&0@<F5A9"!S;R!F87(N("HO"B`@("`@("`@)&)U9F8@/2`G)SL*
M("`@("`@("`O*B!4:&4@8W5R<F5N="!C:&%R86-T97(N("HO"B`@("`@("`@
M)&,@/2!N=6QL.PH@("`@("`@("\J(%1H92!R96%D(&9I96QD<RX@*B\*("`@
M("`@("`D<F5T(#T@87)R87DH*3L*("`@("`@("`O*B!4:&4@;G5M8F5R(&]F
M('1H92!C=7)R96YT(&9I96QD+B`J+PH@("`@("`@("1I(#T@,3L*("`@("`@
M("`O*B!!<F4@=V4@:6YS:61E(&$@<75O=&5D(&9I96QD/R`J+PH@("`@("`@
M("1I;E]Q=6]T92`](&9A;'-E.PH*("`@("`@("!W:&EL92`H*"1C:"`](&9G
M971C*"1F<"DI("$]/2!F86QS92D@>PH@("`@("`@("`@("`O*B!0<F5V:6]U
M<R!C:&%R86-T97(N("HO"B`@("`@("`@("`@("1P<F5V(#T@)&,["B`@("`@
M("`@("`@("\J($-U<G)E;G0@8VAA<F%C=&5R+B`J+PH@("`@("`@("`@("`D
M8R`]("1C:#L*"B`@("`@("`@("`@("\J(%-I;7!L92!C:&%R86-T97(N("HO
M"B`@("`@("`@("`@(&EF("@D8R`A/2`D8V]N9ELG<75O=&4G72`F)@H@("`@
M("`@("`@("`@("`@)&,@(3T@)&-O;F9;)W-E<"==("8F"B`@("`@("`@("`@
M("`@("!S=')P;W,H)&-O;F9;)V-R;&8G72P@)&,I(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)&)U9F8@+CT@)&,["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1C;VYF
M6R=Q=6]T92==("8F("1C(#T]("1C;VYF6R=Q=6]T92==("8F"B`@("`@("`@
M("`@("`@("`H)'!R978@/3T@)&-O;F9;)W-E<"==('Q\"B`@("`@("`@("`@
M("`@("`@)'!R978@/3T@<W5B<W1R*"1C;VYF6R=C<FQF)UTL("TQ*2!\?`H@
M("`@("`@("`@("`@("`@("1P<F5V(#T]/2!N=6QL*2D*("`@("`@("`@("`@
M>PH@("`@("`@("`@("`@("`@+RH@475O=&4@8F5G:6XN("HO"B`@("`@("`@
M("`@("`@("`D:6Y?<75O=&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&EN7W%U;W1E*2!["B`@("`@("`@("`@("`@("`O*B!1=6]T92!E;F0_
M("HO"B`@("`@("`@("`@("`@("!I9B`H)&,@/3T@)&-O;F9;)W-E<"==("8F
M("1P<F5V(#T]("1C;VYF6R=Q=6]T92==*2!["B`@("`@("`@("`@("`@("`@
M("`@)&EN7W%U;W1E(#T@9F%L<V4["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)&,@/3T@<W5B<W1R*"1C;VYF6R=C<FQF)UTL("TQ*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1S=6(@/2`H<W1R;&5N*"1C;VYF6R=C<FQF)UTI(#X@
M,2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R978@/3T@<W5B
M<W1R*"1C;VYF6R=C<FQF)UTL("TR+"`Q*2D*("`@("`@("`@("`@("`@("`@
M("`@("`@/R`R"B`@("`@("`@("`@("`@("`@("`@("`@(#H@,3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H*'-T<FQE;B@D8G5F9BD@/CT@)'-U8BD@)B8*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1B=69F>W-T<FQE;B@D8G5F9BD@
M+2`D<W5B?2`]/2`D8V]N9ELG<75O=&4G72DI"B`@("`@("`@("`@("`@("`@
M("`@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:6Y?<75O=&4@/2!F86QS
M93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!&:6QE7T-35CHZ7VQI;F4H1FEL95]#4U8Z.E]L:6YE*"D@
M*R`Q*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($5N9"!O9B!L:6YE(&]R
M(&5N9"!O9B!F:65L9"X@*B\*("`@("`@("`@("`@:68@*"$D:6Y?<75O=&4@
M)B8*("`@("`@("`@("`@("`@("@D8R`]/2`D8V]N9ELG<V5P)UT@?'P@)&,@
M/3T@<W5B<W1R*"1C;VYF6R=C<FQF)UTL("TQ*2DI('L*("`@("`@("`@("`@
M("`@("\J($UO<F4@9FEE;&1S('1H86X@97AP96-T960N("HO"B`@("`@("`@
M("`@("`@("!I9B`H)&,@/3T@)&-O;F9;)W-E<"==("8F"B`@("`@("`@("`@
M("`@("`@("`@*&-O=6YT*"1R970I("L@,2D@/3T@)&-O;F9;)V9I96QD<R==
M*2!["B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1C("$]/2!F86QS92`F
M)B`D8R`A/2!S=6)S='(H)&-O;F9;)V-R;&8G72P@+3$I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1C(#T@9F=E=&,H)&9P*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@1FEL95]#4U8Z.G=A<FYI
M;F<H<W!R:6YT9BA?*")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+B(I+"!&:6QE7T-35CHZ7VQI;F4H*2P@)&-O
M;F9;)V9I96QD<R==*2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@:68@*"1P<F5V(#T]('-U8G-T<B@D8V]N9ELG8W)L9B==+"`M,BP@
M,2DI('L*("`@("`@("`@("`@("`@("`@("`D8G5F9B`]('-U8G-T<B@D8G5F
M9BP@,"P@+3$I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("\J($QE<W,@9FEE;&1S('1H86X@97AP96-T960N("HO"B`@("`@("`@("`@
M("`@("!I9B`H*"1C(#T]('-U8G-T<B@D8V]N9ELG8W)L9B==+"`M,2DI("8F
M"B`@("`@("`@("`@("`@("`@("`@*"1I("$]("1C;VYF6R=F:65L9',G72DI
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&D@/3T@,2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`O*B!3:VEP(&5M<'1Y(&QI;F5S+B`J+PH@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@1FEL95]#4U8Z.G=A<FYI
M;F<H<W!R:6YT9BA?*")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB*2P@1FEL95]#4U8Z.E]L:6YE
M*"DL("1C;VYF6R=F:65L9',G72P@)&DI*3L*"B`@("`@("`@("`@("`@("`@
M("`@)')E=%M=(#T@1FEL95]#4U8Z.G5N<75O=&4H)&)U9F8L("1C;VYF6R=Q
M=6]T92==+"`D8V]N9ELG8W)L9B==*3L*("`@("`@("`@("`@("`@("`@("`D
M<F5T(#T@87)R87E?;65R9V4H)')E="P@87)R87E?9FEL;"@P+"`D8V]N9ELG
M9FEE;&1S)UT@+2`D:2P@)R<I*3L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)')E=#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M<F5T6UT@/2!&:6QE7T-35CHZ=6YQ=6]T92@D8G5F9BP@)&-O;F9;)W%U;W1E
M)UTL("1C;VYF6R=C<FQF)UTI.PH@("`@("`@("`@("`@("`@:68@*&-O=6YT
M*"1R970I(#T]("1C;VYF6R=F:65L9',G72D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1B=69F(#T@)R<["B`@("`@("`@("`@("`@("`D:2LK.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&)U9F8@+CT@)&,["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F5O
M9B@D9G`I(#\@9F%L<V4@.B`D<F5T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5W)I=&5S(&$@:&%S:"!I;G1O(&$@0U-6(&9I;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9FEL92`@(%1H92!N86UE(&]F('1H92!#4U8@9FEL
M92X*("`@("`J($!P87)A;2!A<G)A>2`D9FEE;&1S("!4:&4@0U-6(&1A=&$N
M"B`@("`@*B!`<&%R86T@87)R87D@)&-O;F8@("`@5&AE(&-O;F9I9W5R871I
M;VX@9F]R('1H92!#4U8@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D9FEL92P@)&9I96QD<RP@
M)B1C;VYF*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1F<"`]($9I;&5?0U-6
M.CIG9710;VEN=&5R*"1F:6QE+"`D8V]N9BP@1DE,15]-3T1%7U=2251%*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&-O=6YT*"1F:65L9',I("$]("1C;VYF6R=F
M:65L9',G72D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D
M("5D+"!F;W5N9"`E9"XB*2P@)&-O;F9;)V9I96QD<R==+"!C;W5N="@D9FEE
M;&1S*2DI.PH@("`@("`@('T*"B`@("`@("`@)'=R:71E(#T@)R<["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&9I96QD<RD[("1I*RLI('L*
M("`@("`@("`@("`@:68@*"%I<U]N=6UE<FEC*"1F:65L9'-;)&E=*2`F)B`D
M8V]N9ELG<75O=&4G72D@>PH@("`@("`@("`@("`@("`@)'=R:71E("X]("1C
M;VYF6R=Q=6]T92==("X@)&9I96QD<ULD:5T@+B`D8V]N9ELG<75O=&4G73L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1W<FET92`N
M/2`D9FEE;&1S6R1I73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)&D@/"`H8V]U;G0H)&9I96QD<RD@+2`Q*2D@>PH@("`@("`@("`@("`@("`@
M)'=R:71E("X]("1C;VYF6R=S97`G73L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1W<FET92`N/2`D8V]N9ELG8W)L9B==.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(69W<FET92@D9G`L
M("1W<FET92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(BDL
M("1F:6QE*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@<W5R<F]U;F1I;F<@<75O=&5S
M(&9R;VT@82!S=')I;F<@86YD(&YO<FUA;&EZ97,@;&EN96)R96%K<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"`@5&AE('-T<FEN9R!T
M;R!U;G%U;W1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75O=&4@(%1H92!Q
M=6]T92!C:&%R86-T97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<FQF("`@
M5&AE(&QI;F5B<F5A:R!C:&%R86-T97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!U;G%U;W1E9"!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!U;G%U;W1E*"1F:65L9"P@)'%U;W1E+"`D8W)L9BD*("`@('L*("`@
M("`@("`O*B!3:VEP(&5M<'1Y(&9I96QD<R`H9F]R;3H@.SLI("HO"B`@("`@
M("`@:68@*"%S=')L96XH)&9I96QD*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&9I96QD.PH@("`@("`@('T*("`@("`@("!I9B`H)'%U;W1E("8F("1F:65L
M9'LP?2`]/2`D<75O=&4@)B8@)&9I96QD>W-T<FQE;B@D9FEE;&0I+3%](#T]
M("1Q=6]T92D@>PH@("`@("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)&-R
M;&8L(")<;B(L('-U8G-T<B@D9FEE;&0L(#$L("TQ*2D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D9FEE;&0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S(&]R(&=E=',@=&AE(&-U<G)E;G0@;&EN92!B96EN9R!P87)S960N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;F4@($EF('-P96-I9FEE
M9"P@=&AE(&-U<G)E;G0@;&EN92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(%1H92!C=7)R96YT(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]L:6YE*"1L:6YE(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&-U
M<G)E;G1?;&EN92`](#`["@H@("`@("`@(&EF("@A:7-?;G5L;"@D;&EN92DI
M('L*("`@("`@("`@("`@)&-U<G)E;G1?;&EN92`]("1L:6YE.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1C=7)R96YT7VQI;F4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&$@=V%R;FEN9R!T;R!O<B!R971R:65V97,@86YD
M(')E<V5T<R!T:&4@=V%R;FEN9R!S=&%C:RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("!!('=A<FYI;F<@<W1R:6YG+B`@268@;F]T('-P96-I9FEE
M9"P@=&AE(&5X:7-T:6YG"B`@("`@*B`@("`@("`@("`@("`@("!W87)N:6YG
M<R!W:6QL(&)E(')E='5R;F5D(&EN<W1E860@86YD('1H92!W87)N:6YG('-T
M86-K"B`@("`@*B`@("`@("`@("`@("`@("!G971S(&5M<'1I960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@268@;F\@<&%R86UE=&5R(&AA<R!B
M965N('-P96-I9FEE9"P@=&AE(&QI<W0@;V8@97AI<W1I;F<*("`@("`J("`@
M("`@("`@("`@("`@('=A<FYI;F=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M87)N:6YG*"1W87)N:6YG(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@
M)'=A<FYI;F=S(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)'=A
M<FYI;F<I*2!["B`@("`@("`@("`@("1R971U<FX@/2`D=V%R;FEN9W,["B`@
M("`@("`@("`@("1W87)N:6YG<R`](&%R<F%Y*"D["B`@("`@("`@("`@(')E
M='5R;B`D<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'=A<FYI;F=S6UT@
M/2`D=V%R;FEN9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@;W(@
M8W)E871E<R!T:&4@9FEL92!D97-C<FEP=&]R(&%S<V]C:6%T960@=VET:"!A
M(&9I;&4N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&9I;&4@(%1H92!N86UE(&]F('1H92!F:6QE"B`@("`@
M*B!`<&%R86T@87)R87D@)&-O;F8@("!4:&4@8V]N9FEG=7)A=&EO;@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6]D92`@5&AE(&]P96X@;6]D92X@1DE,15]-
M3T1%7U)%040@;W(@1DE,15]-3T1%7U=2251%+@H@("`@("H*("`@("`J($!R
M971U<FX@<F5S;W5R8V4@(%1H92!F:6QE(')E<V]U<F-E(&]R(%!%05)?17)R
M;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!O:6YT97(H
M)&9I;&4L("8D8V]N9BP@)&UO9&4@/2!&24Q%7TU/1$5?4D5!1"D*("`@('L*
M("`@("`@("!S=&%T:6,@)')E<V]U<F-E<R`](&%R<F%Y*"D["B`@("`@("`@
M<W1A=&EC("1C;VYF:6<@/2!A<G)A>2@I.PH*("`@("`@("`D<VEG;F%T=7)E
M(#T@)&9I;&4@+B!S97)I86QI>F4H)&-O;F8I.PH@("`@("`@(&EF("AI<W-E
M="@D<F5S;W5R8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D8V]N
M9B`]("1C;VYF:6=;)'-I9VYA='5R95T["B`@("`@("`@("`@(')E='5R;B`D
M<F5S;W5R8V5S6R1S:6=N871U<F5=.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-?82@D97)R;W(@/2!&:6QE7T-35CHZ7V-H96-K0V]N9FEG*"1C;VYF*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*("`@("`@("`D8V]N9FEG6R1S:6=N871U<F5=(#T@)&-O;F8[
M"@H@("`@("`@("1F<"`]($!F;W!E;B@D9FEL92P@)&UO9&4I.PH@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)&9P*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-A;B=T(&]P96X@9FEL92!<
M(B5S7"(N(BDL("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@("1R97-O=7)C
M97-;)'-I9VYA='5R95T@/2`D9G`["B`@("`@("`@1FEL95]#4U8Z.E]L:6YE
M*#`I.PH*("`@("`@("!I9B`H)&UO9&4@/3T@1DE,15]-3T1%7U)%040@)B8@
M(65M<'1Y*"1C;VYF6R=H96%D97(G72DI('L*("`@("`@("`@("`@:68@*&ES
M7V$H)&AE861E<B`]($9I;&5?0U-6.CIR96%D*"1F:6QE+"`D8V]N9BDL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D:&5A9&5R
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9P
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!C;VYF:6=U<F%T
M:6]N(&=I=F5N(&)Y('1H92!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D8V]N9B`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<W-O8R!A<G)A>0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D97)R;W(@(%1H92!E<G)O<B!W:6QL(&)E
M('=R:71T96X@:&5R92!I9B!A;GD*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H
M96-K0V]N9FEG*"8D8V]N9BD*("`@('L*("`@("`@("`O+R!C:&5C:R!C;VYF
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V]N9BDI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@8V]N9FEG=7)A=&EO
M;BXG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&-O;F9;)V9I
M96QD<R==*2!\?"`A:7-?;G5M97)I8R@D8V]N9ELG9FEE;&1S)UTI*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB*2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-S970H)&-O;F9;)W-E<"==*2D@>PH@("`@("`@("`@
M("!I9B`H<W1R;&5N*"1C;VYF6R=S97`G72D@(3T@,2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS96EF("@D8V]N9ELG9FEE;&1S)UT@/B`Q*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO('-E
M<&%R871O<B!S<&5C:69I960N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%E;7!T>2@D8V]N9ELG<75O=&4G72DI('L*("`@("`@("`@("`@:68@*'-T
M<FQE;B@D8V]N9ELG<75O=&4G72D@(3T@,2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C;VYF6R=Q=6]T
M92==(#T@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1C;VYF
M6R=C<FQF)UTI*2!["B`@("`@("`@("`@("1C;VYF6R=C<FQF)UT@/2`B7&XB
M.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1BYP:'``````````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R-S(P,C<`,3`T,3<S-C(W
M-S``,#$W,C`Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!&:6QE7U!$1CHZ"B`J"B`J(%1H92!&:6QE
M7U!$1CHZ(&-L87-S('!R;W9I9&5S(&$@4$A0+6]N;'D@:6UP;&5M96YT871I
M;VX@;V8@82!01$8@;&EB<F%R>2X*("H@3F\@97AT97)N86P@;&EB<R!O<B!0
M2%`@97AT96YS:6]N<R!A<F4@<F5Q=6ER960N"B`J"B`J($)A<V5D(&]N('1H
M92!&4$1&(&-L87-S(&)Y($]L:79I97(@4&QA=&AE>2`H:'1T<#HO+W=W=RYF
M<&1F+F]R9RDN"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@3VQI=FEE<B!0
M;&%T:&5Y(#QO;&EV:65R0&9P9&8N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&:6QE7U!$1B]01$8N<&AP+'8@
M,2XQ."XQ,"XQ,B`R,#`V+S`Q+S`Q(#(Q.C(X.C$U(&IA;B!%>'`@)`H@*@H@
M*B!`875T:&]R("!/;&EV:65R(%!L871H97D@/&]L:79I97)`9G!D9BYO<F<^
M"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M($!P86-K86=E($9I;&5?4$1&"B`J+PIC;&%S<R!&:6QE7U!$1B!["@H@("`@
M+RHJ"B`@("`@*B!#=7)R96YT('!A9V4@;G5M8F5R+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]P86=E(#T@,#L*"B`@
M("`O*BH*("`@("`J($-U<G)E;G0@;V)J96-T(&YU;6)E<BX*("`@("`J"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?;B`](#(["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!O9B!O8FIE8W0@;V9F<V5T<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]F9G-E=',@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0G5F9F5R(&AO;&1I;F<@:6XM
M;65M;W)Y(%!$1BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]B=69F97(@/2`G)SL*"B`@("`O*BH*("`@("`J($%R<F%Y
M(&-O;G1A:6YI;F<@=&AE('!A9V5S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<&%G97,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@0W5R<F5N="!D;V-U;65N="!S=&%T92X*("`@("`J("`@,"`M
M(&EN:71I86P@<W1A=&4*("`@("`J("`@,2`M(&1O8W5M96YT(&]P96YE9`H@
M("`@("H@("`R("T@<&%G92!O<&5N960*("`@("`J("`@,R`M(&1O8W5M96YT
M(&-L;W-E9`H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]S=&%T92`](#`["@H@("`@+RHJ"B`@("`@*B!&;&%G(&EN9&EC
M871I;F<@:68@4$1&(&9I;&4@:7,@=&\@8F4@8V]M<')E<W-E9"!O<B!N;W0N
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7V-O;7!R97-S.PH*("`@("\J*@H@("`@("H@5&AE(&1E9F%U;'0@<&%G92!O
M<FEE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]D969A=6QT7V]R:65N=&%T:6]N.PH*("`@("\J*@H@("`@
M("H@5&AE(&-U<G)E;G0@<&%G92!O<FEE;G1A=&EO;BX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C=7)R96YT7V]R:65N
M=&%T:6]N.PH*("`@("\J*@H@("`@("H@07)R87D@:6YD:6-A=&EN9R!O<FEE
M;G1A=&EO;B!C:&%N9V5S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?;W)I96YT871I;VY?8VAA;F=E<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!#=7)R96YT('=I9'1H(&]F('!A9V4@9F]R;6%T
M(&EN('!O:6YT<RX*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*
M("`@('9A<B`D9G=0=#L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@:&5I9VAT
M(&]F('!A9V4@9F]R;6%T(&EN('!O:6YT<RX*("`@("`J"B`@("`@*B!`=F%R
M(&9L;V%T"B`@("`@*B\*("`@('9A<B`D9FA0=#L*"B`@("`O*BH*("`@("`J
M($-U<G)E;G0@=VED=&@@;V8@<&%G92!F;W)M870@:6X@=7-E<B!U;FET<RX*
M("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D9G<[
M"@H@("`@+RHJ"B`@("`@*B!#=7)R96YT(&AE:6=H="!O9B!P86=E(&9O<FUA
M="!I;B!U<V5R('5N:71S+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@
M("`J+PH@("`@=F%R("1F:#L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@=VED
M=&@@;V8@<&%G92!I;B!P;VEN=',N"B`@("`@*@H@("`@("H@0'9A<B!F;&]A
M=`H@("`@("HO"B`@("!V87(@)'=0=#L*"B`@("`O*BH*("`@("`J($-U<G)E
M;G0@:&5I9VAT(&]F('!A9V4@:6X@<&]I;G1S+@H@("`@("H*("`@("`J($!V
M87(@9FQO870*("`@("`J+PH@("`@=F%R("1H4'0["@H@("`@+RHJ"B`@("`@
M*B!#=7)R96YT('=I9'1H(&]F('!A9V4@:6X@=7-E<B!U;FET<PH@("`@("H*
M("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1W.PH*("`@("\J
M*@H@("`@("H@0W5R<F5N="!H96EG:'0@;V8@<&%G92!I;B!U<V5R('5N:71S
M"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)&@[
M"@H@("`@+RHJ"B`@("`@*B!38V%L92!F86-T;W(@*&YU;6)E<B!O9B!P;VEN
M=',@:6X@=7-E<B!U;FET<RDN"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@
M("`@("HO"B`@("!V87(@)%]S8V%L93L*"B`@("`O*BH*("`@("`J($QE9G0@
M<&%G92!M87)G:6X@<VEZ92X*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@
M("`@*B\*("`@('9A<B`D7VQE9G1?;6%R9VEN.PH*("`@("\J*@H@("`@("H@
M5&]P('!A9V4@;6%R9VEN('-I>F4N"B`@("`@*@H@("`@("H@0'9A<B!F;&]A
M=`H@("`@("HO"B`@("!V87(@)%]T;W!?;6%R9VEN.PH*("`@("\J*@H@("`@
M("H@4FEG:'0@<&%G92!M87)G:6X@<VEZ92X*("`@("`J"B`@("`@*B!`=F%R
M(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7W)I9VAT7VUA<F=I;CL*"B`@("`O
M*BH*("`@("`J($)R96%K('!A9V4@;6%R9VEN('-I>F4L('1H92!B;W1T;VT@
M;6%R9VEN('=H:6-H('1R:6=G97)S(&$@<&%G92!B<F5A:RX*("`@("`J"B`@
M("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7V)R96%K7VUA<F=I
M;CL*"B`@("`O*BH*("`@("`J($-E;&P@;6%R9VEN('-I>F4N"B`@("`@*@H@
M("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]C96QL7VUA<F=I
M;CL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&AO<FEZ;VYT86P@<&]S
M:71I;VX@9F]R(&-E;&P@<&]S:71I;VYI;F<N"B`@("`@*B!686QU92!I<R!S
M970@:6X@=7-E<B!U;FET<R!A;F0@:7,@8V%L8W5L871E9"!F<F]M('1H92!T
M;W`@;&5F="!C;W)N97(*("`@("`J(&%S(&]R:6=I;BX*("`@("`J"B`@("`@
M*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D>#L*"B`@("`O*BH*("`@
M("`J(%1H92!C=7)R96YT('9E<G1I8V%L('!O<VET:6]N(&9O<B!C96QL('!O
M<VET:6]N:6YG+@H@("`@("H@5F%L=64@:7,@<V5T(&EN('5S97(@=6YI=',@
M86YD(&ES(&-A;&-U;&%T960@9G)O;2!T:&4@=&]P(&QE9G0@8V]R;F5R"B`@
M("`@*B!A<R!O<FEG:6XN"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@
M("HO"B`@("!V87(@)'D["@H@("`@+RHJ"B`@("`@*B!4:&4@:&5I9VAT(&]F
M('1H92!L87-T(&-E;&P@<')I;G1E9"X*("`@("`J"B`@("`@*B!`=F%R(&9L
M;V%T"B`@("`@*B\*("`@('9A<B`D7VQA<W1?:&5I9VAT.PH*("`@("\J*@H@
M("`@("H@3&EN92!W:61T:"!I;B!U<V5R('5N:71S+@H@("`@("H*("`@("`J
M($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?;&EN95]W:61T:#L*"B`@
M("`O*BH*("`@("`J($%N(&%R<F%Y(&]F('-T86YD87)D(&9O;G0@;F%M97,N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C
M;W)E7V9O;G1S(#T@87)R87DH)V-O=7)I97(G("`@("`@/3X@)T-O=7)I97(G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;W5R:65R0B<@("`@
M(#T^("=#;W5R:65R+4)O;&0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=C;W5R:65R22<@("`@(#T^("=#;W5R:65R+4]B;&EQ=64G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C;W5R:65R0DDG("`@(#T^("=#
M;W5R:65R+4)O;&1/8FQI<75E)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&5L=F5T:6-A)R`@("`]/B`G2&5L=F5T:6-A)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:&5L=F5T:6-A0B<@("`]/B`G2&5L=F5T
M:6-A+4)O;&0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H96QV
M971I8V%))R`@(#T^("=(96QV971I8V$M3V)L:7%U92<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VAE;'9E=&EC84)))R`@/3X@)TAE;'9E=&EC
M82U";VQD3V)L:7%U92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1I;65S)R`@("`@("`@/3X@)U1I;65S+5)O;6%N)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=&EM97-")R`@("`@("`]/B`G5&EM97,M0F]L
M9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1I;65S22<@("`@
M("`@/3X@)U1I;65S+4ET86QI8R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1I;65S0DDG("`@("`@/3X@)U1I;65S+4)O;&1)=&%L:6,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S>6UB;VPG("`@("`@(#T^
M("=3>6UB;VPG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Z87!F
M9&EN9V)A=',G(#T^("=:87!F1&EN9V)A=',G*3L*"B`@("`O*BH*("`@("`J
M($%N(&%R<F%Y(&]F('5S960@9F]N=',N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]F;VYT<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!F;VYT(&9I;&5S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9F]N=%]F:6QE<R`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!E;F-O9&EN
M9R!D:69F97)E;F-E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V1I9F9S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($%N(&%R<F%Y(&]F('5S960@:6UA9V5S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?:6UA9V5S(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&QI;FMS(&EN('!A9V5S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%G95]L
M:6YK<SL*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&EN=&5R;F%L(&QI
M;FMS+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?;&EN:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!F
M;VYT(&9A;6EL>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]F;VYT7V9A;6EL>2`]("<G.PH*("`@("\J*@H@("`@("H@
M0W5R<F5N="!F;VYT('-T>6QE+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7V9O;G1?<W1Y;&4@/2`G)SL*"B`@("`O*BH*
M("`@("`J(%5N9&5R;&EN:6YG(&9L86<N"B`@("`@*@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W5N9&5R;&EN92`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@06X@87)R87D@8V]N=&%I;FEN9R!C=7)R96YT(&9O
M;G0@:6YF;RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7V-U<G)E;G1?9F]N=#L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@
M9F]N="!S:7IE(&EN('!O:6YT<RX*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T
M"B`@("`@*B\*("`@('9A<B`D7V9O;G1?<VEZ95]P="`](#$R.PH*("`@("\J
M*@H@("`@("H@0W5R<F5N="!F;VYT('-I>F4@:6X@=7-E<B!U;FET<RX*("`@
M("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7V9O;G1?
M<VEZ93L*"B`@("`O*BH*("`@("`J($-O;6UA;F1S(&9O<B!F:6QL:6YG(&-O
M;&]R+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7V9I;&Q?8V]L;W(@/2`G,"!G)SL*"B`@("`O*BH*("`@("`J($-O;6UA
M;F1S(&9O<B!D<F%W:6YG(&-O;&]R+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7V1R87=?8V]L;W(@/2`G,"!')SL*"B`@
M("`O*BH*("`@("`J(%=O<F0@<W!A8VEN9RX*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?=V]R9%]S<&%C:6YG(#T@,#L*
M"B`@("`O*BH*("`@("`J($%U=&]M871I8R!P86=E(&)R96%K:6YG+@H@("`@
M("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]A=71O
M7W!A9V5?8G)E86L["@H@("`@+RHJ"B`@("`@*B!4:')E<VAO;&0@=7-E9"!T
M;R!T<FEG9V5R('!A9V4@8G)E86MS+@H@("`@("H*("`@("`J($!V87(@9FQO
M870*("`@("`J+PH@("`@=F%R("1?<&%G95]B<F5A:U]T<FEG9V5R.PH*("`@
M("\J*@H@("`@("H@1FQA9R!S970@=VAE;B!P<F]C97-S:6YG(&9O;W1E<BX*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?
M:6Y?9F]O=&5R(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!:;V]M(&1I<W!L
M87D@;6]D92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]Z;V]M7VUO9&4["@H@("`@+RHJ"B`@("`@*B!,87EO=70@9&ES
M<&QA>2!M;V1E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7VQA>6]U=%]M;V1E.PH*("`@("\J*@H@("`@("H@06X@87)R
M87D@8V]N=&%I;FEN9R!T:&4@9&]C=6UE;G0@:6YF;RP@8V]N<VES=&EN9R!O
M9CH*("`@("`J("`@+2!T:71L90H@("`@("H@("`M('-U8FIE8W0*("`@("`J
M("`@+2!A=71H;W(*("`@("`J("`@+2!K97EW;W)D<PH@("`@("H@("`M(&-R
M96%T;W(*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7VEN9F\@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06QI87,@9F]R
M('1O=&%L(&YU;6)E<B!O9B!P86=E<RX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]A;&EA<U]N8E]P86=E<R`]("=[;F)]
M)SL*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;G)E
M=&4@4$1&(&EN<W1A;F-E+B!)="!A;&QO=W,@=&\@<V5T('5P('1H92!P86=E
M"B`@("`@*B!F;W)M870L('1H92!O<FEE;G1A=&EO;B!A;F0@=&AE('5N:71S
M(&]F(&UE87-U<F5M96YT('5S960@:6X@86QL('1H90H@("`@("H@;65T:&]D
M<R`H97AC97!T(&9O<B!T:&4@9F]N="!S:7IE<RDN"B`@("`@*@H@("`@("H@
M17AA;7!L93H\<')E/@H@("`@("H@)'!D9B`]("9&:6QE7U!$1CHZ9F%C=&]R
M>2AA<G)A>2@G;W)I96YT871I;VXG(#T^("=0)RP*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W5N:70G(#T^("=M;2<L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F;W)M870G(#T^
M("=!-"<I*3L\+W!R93X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@02!H87-H('=I=&@@<&%R86UE=&5R<R!F;W(@=&AE(&-R96%T960@
M4$1&(&]B:F5C="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!0;W-S
M:6)L92!P87)A;65T97)S(&%R93H*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!O<FEE;G1A=&EO;B`M($1E9F%U;'0@<&%G92!O<FEE;G1A=&EO;BX@
M4&]S<VEB;&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!V86QU97,@
M87)E("AC87-E(&EN<V5N<VET:79E*3H*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`\<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!0(&]R(%!O<G1R86ET("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!,(&]R($QA;F1S8V%P90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(#PO<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@('5N:70@+2!5<V5R(&UE87-U<F4@=6YI=',N(%!O<W-I8FQE('9A;'5E
M<R!V86QU97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!A<F4Z"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@/'!R93X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("T@<'0Z('!O:6YT"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M(&UM.B!M:6QL:6UE=&5R("AD969A=6QT*0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!C;3H@8V5N=&EM971E
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!I;CH@:6YC:`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(#PO<')E/@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@($$@<&]I;G0@97%U86QS(#$O-S(@;V8@:6YC
M:"P@=&AA="!I<R!T;R!S87D@86)O=70*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`P+C,U(&UM("AA;B!I;F-H(&)E:6YG(#(N-30@8VTI+B!4:&ES
M(&ES(&$@=F5R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;6UO
M;B!U;FET(&EN('1Y<&]G<F%P:'D[(&9O;G0@<VEZ97,@87)E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@97AP<F5S<V5D(&EN('1H870@=6YI="X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F;W)M870@+2!4:&4@9F]R
M;6%T('5S960@9F]R('!A9V5S+B!)="!C86X@8F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!E:71H97(@;VYE(&]F('1H92!F;VQL;W=I;F<@=F%L
M=65S("AC87-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6YS96YS
M:71I=F4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(#QP<F4^"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($$S"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`M($$T("AD969A=6QT*0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!!-0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!,971T97(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("T@3&5G86P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`\
M+W!R93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O<B!A(&-U<W1O
M;2!F;W)M870@:6X@=&AE(&9O<FT@;V8@82!T=V\M96QE;65N=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y(&-O;G1A:6YI;F<@=&AE('=I
M9'1H(&%N9"!T:&4@:&5I9VAT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@*&5X<')E<W-E9"!I;B!T:&4@=6YI="!G:79E;B!B>2!T:&4@=6YI=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<BDN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@5&AE(&-O;F-R971E(&-L87-S(&YA
M;64@=&\@<F5T=7)N(&%N(&EN<W1A;F-E(&]F+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@($1E9F%U;'1S('1O($9I;&5?4$1&+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F9F%C=&]R>2@D<&%R86US(#T@87)R87DH*2P@)&-L87-S
M(#T@)T9I;&5?4$1&)RD*("`@('L*("`@("`@("`O*B!#:&5C:R!F;W(@4$A0
M(&QO8V%L92UR96QA=&5D(&)U9RX@*B\*("`@("`@("!I9B`H,2XQ(#T](#$I
M('L*("`@("`@("`@("`@<F5T=7)N($9I;&5?4$1&.CIR86ES945R<F]R*"=$
M;R!N;W0@86QT97(@=&AE(&QO8V%L92!B969O<F4@:6YC;'5D:6YG('1H92!C
M;&%S<R!F:6QE+B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@1&5F875L="!P
M87)A;65T97)S+B`J+PH@("`@("`@("1D969A=6QT<R`](&%R<F%Y*"=O<FEE
M;G1A=&EO;B<@/3X@)U`G+"`G=6YI="<@/3X@)VUM)RP@)V9O<FUA="<@/3X@
M)T$T)RD["@H@("`@("`@("\J($)A8VMW87)D(&-O;7!A=&EB:6QI='D@=VET
M:"!O;&0@;65T:&]D('-I9VYA='5R92X@*B\*("`@("`@("`O*B!3:&]U;&0@
M8F4@<F5M;W9E9"!A(&9E=R!V97)S:6]N<R!L871E<BX@*B\*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1C;&%S<R`]
M("=&:6QE7U!$1B<["B`@("`@("`@("`@("1P87)A;7,@/2`D9&5F875L=',[
M"B`@("`@("`@("`@("1N86UE<R`](&%R<F%Y7VME>7,H)&1E9F%U;'1S*3L*
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@9G5N8U]N=6U?87)G<R@I
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R1N86UE<ULD:5U=
M(#T@9G5N8U]G971?87)G*"1I*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>5]M97)G92@D9&5F
M875L=',L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E
M('1H92!01$8@;V)J96-T+B`J+PH@("`@("`@("1P9&8@/2`F;F5W("1C;&%S
M<R@I.PH*("`@("`@("`O*B!38V%L92!F86-T;W(N("HO"B`@("`@("`@:68@
M*"1P87)A;7-;)W5N:70G72`]/2`G<'0G*2!["B`@("`@("`@("`@("1P9&8M
M/E]S8V%L92`](#$["B`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)W5N:70G
M72`]/2`G;6TG*2!["B`@("`@("`@("`@("1P9&8M/E]S8V%L92`](#<R("\@
M,C4N-#L*("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG=6YI="==(#T]("=C
M;2<I('L*("`@("`@("`@("`@)'!D9BT^7W-C86QE(#T@-S(@+R`R+C4T.PH@
M("`@("`@('T@96QS96EF("@D<&%R86US6R=U;FET)UT@/3T@)VEN)RD@>PH@
M("`@("`@("`@("`D<&1F+3Y?<V-A;&4@/2`W,CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@1FEL95]01$8Z.G)A:7-E17)R;W(H<W!R
M:6YT9B@G26YC;W)R96-T('5N:71S.B`E<R<L("1P87)A;7-;)W5N:70G72DI
M.PH@("`@("`@('T*("`@("`@("`O*B!086=E(&9O<FUA="X@*B\*("`@("`@
M("!I9B`H:7-?<W1R:6YG*"1P87)A;7-;)V9O<FUA="==*2D@>PH@("`@("`@
M("`@("`D<&%R86US6R=F;W)M870G72`]('-T<G1O;&]W97(H)'!A<F%M<ULG
M9F]R;6%T)UTI.PH@("`@("`@("`@("!I9B`H)'!A<F%M<ULG9F]R;6%T)UT@
M/3T@)V$S)RD@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULG9F]R;6%T)UT@
M/2!A<G)A>2@X-#$N.#DL(#$Q.3`N-34I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)'!A<F%M<ULG9F]R;6%T)UT@/3T@)V$T)RD@>PH@("`@("`@("`@("`@
M("`@)'!A<F%M<ULG9F]R;6%T)UT@/2!A<G)A>2@U.34N,C@L(#@T,2XX.2D[
M"B`@("`@("`@("`@('T@96QS96EF("@D<&%R86US6R=F;W)M870G72`]/2`G
M834G*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R=F;W)M870G72`](&%R
M<F%Y*#0R,"XY-"P@-3DU+C(X*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1P
M87)A;7-;)V9O<FUA="==(#T]("=L971T97(G*2!["B`@("`@("`@("`@("`@
M("`D<&%R86US6R=F;W)M870G72`](&%R<F%Y*#8Q,BP@-SDR*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1P87)A;7-;)V9O<FUA="==(#T]("=L96=A;"<I
M('L*("`@("`@("`@("`@("`@("1P87)A;7-;)V9O<FUA="==(#T@87)R87DH
M-C$R+"`Q,#`X*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B!&:6QE7U!$1CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=5;FMN
M;W=N('!A9V4@9F]R;6%T.B`E<R<L("1P87)A;7-;)V9O<FUA="==*2D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'!D9BT^9G=0="`]("1P87)A;7-;
M)V9O<FUA="==6S!=.PH@("`@("`@("`@("`D<&1F+3YF:%!T(#T@)'!A<F%M
M<ULG9F]R;6%T)UU;,5T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'!D9BT^9G=0="`]("1P87)A;7-;)V9O<FUA="==6S!=("H@)'!D9BT^7W-C
M86QE.PH@("`@("`@("`@("`D<&1F+3YF:%!T(#T@)'!A<F%M<ULG9F]R;6%T
M)UU;,5T@*B`D<&1F+3Y?<V-A;&4["B`@("`@("`@?0H@("`@("`@("1P9&8M
M/F9W(#T@)'!D9BT^9G=0="`O("1P9&8M/E]S8V%L93L*("`@("`@("`D<&1F
M+3YF:"`]("1P9&8M/F9H4'0@+R`D<&1F+3Y?<V-A;&4["@H@("`@("`@("\J
M(%!A9V4@;W)I96YT871I;VXN("HO"B`@("`@("`@)'!A<F%M<ULG;W)I96YT
M871I;VXG72`]('-T<G1O;&]W97(H)'!A<F%M<ULG;W)I96YT871I;VXG72D[
M"B`@("`@("`@:68@*"1P87)A;7-;)V]R:65N=&%T:6]N)UT@/3T@)W`G('Q\
M("1P87)A;7-;)V]R:65N=&%T:6]N)UT@/3T@)W!O<G1R86ET)RD@>PH@("`@
M("`@("`@("`D<&1F+3Y?9&5F875L=%]O<FEE;G1A=&EO;B`]("=0)SL*("`@
M("`@("`@("`@)'!D9BT^=U!T(#T@)'!D9BT^9G=0=#L*("`@("`@("`@("`@
M)'!D9BT^:%!T(#T@)'!D9BT^9FA0=#L*("`@("`@("!](&5L<V5I9B`H)'!A
M<F%M<ULG;W)I96YT871I;VXG72`]/2`G;"<@?'P@)'!A<F%M<ULG;W)I96YT
M871I;VXG72`]/2`G;&%N9'-C87!E)RD@>PH@("`@("`@("`@("`D<&1F+3Y?
M9&5F875L=%]O<FEE;G1A=&EO;B`]("=,)SL*("`@("`@("`@("`@)'!D9BT^
M=U!T(#T@)'!D9BT^9FA0=#L*("`@("`@("`@("`@)'!D9BT^:%!T(#T@)'!D
M9BT^9G=0=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M1FEL95]01$8Z.G)A:7-E17)R;W(H<W!R:6YT9B@G26YC;W)R96-T(&]R:65N
M=&%T:6]N.B`E<R<L("1P87)A;7-;)V]R:65N=&%T:6]N)UTI*3L*("`@("`@
M("!]"B`@("`@("`@)'!D9BT^7V-U<G)E;G1?;W)I96YT871I;VX@/2`D<&1F
M+3Y?9&5F875L=%]O<FEE;G1A=&EO;CL*("`@("`@("`D<&1F+3YW(#T@)'!D
M9BT^=U!T("\@)'!D9BT^7W-C86QE.PH@("`@("`@("1P9&8M/F@@/2`D<&1F
M+3YH4'0@+R`D<&1F+3Y?<V-A;&4["@H@("`@("`@("\J(%!A9V4@;6%R9VEN
M<R`H,2!C;2D@*B\*("`@("`@("`D;6%R9VEN(#T@,C@N,S4@+R`D<&1F+3Y?
M<V-A;&4["B`@("`@("`@)'!D9BT^<V5T36%R9VEN<R@D;6%R9VEN+"`D;6%R
M9VEN*3L*"B`@("`@("`@+RH@26YT97)I;W(@8V5L;"!M87)G:6X@*#$@;6TI
M("HO"B`@("`@("`@)'!D9BT^7V-E;&Q?;6%R9VEN(#T@)&UA<F=I;B`O(#$P
M.PH*("`@("`@("`O*B!,:6YE('=I9'1H("@P+C(@;6TI("HO"B`@("`@("`@
M)'!D9BT^7VQI;F5?=VED=&@@/2`N-38W("\@)'!D9BT^7W-C86QE.PH*("`@
M("`@("`O*B!!=71O;6%T:6,@<&%G92!B<F5A:R`J+PH@("`@("`@("1P9&8M
M/G-E=$%U=&]086=E0G)E86LH=')U92P@,B`J("1M87)G:6XI.PH*("`@("`@
M("`O*B!&=6QL('=I9'1H(&1I<W!L87D@;6]D92`J+PH@("`@("`@("1P9&8M
M/G-E=$1I<W!L87E-;V1E*"=F=6QL=VED=&@G*3L*"B`@("`@("`@+RH@0V]M
M<')E<W-I;VX@*B\*("`@("`@("`D<&1F+3YS971#;VUP<F5S<VEO;BAT<G5E
M*3L*"B`@("`@("`@<F5T=7)N("1P9&8["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@4$5!4E]%<G)O<B!O8FIE8W0N(%=R87!S(&%R;W5N9"!0
M14%2.CIR86ES945R<F]R*"D@=&\*("`@("`J(&%V;VED(&AA=FEN9R!T;R!I
M;F-L=61E(%!%05(N<&AP('5N;&5S<R!A;B!E<G)O<B!O8V-U<G,N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1E<G)O<B`@5&AE(&5R<F]R(&UE<W-A
M9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@4$5!4E]%<G)O<@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"1E<G)O<BD*("`@('L*
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R;W(I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5F:6YE<R!T:&4@;&5F="P@=&]P(&%N9"!R:6=H="!M87)G:6YS
M+B!">2!D969A=6QT+"!T:&5Y(&5Q=6%L"B`@("`@*B`Q(&-M+B`@0V%L;"!T
M:&ES(&UE=&AO9"!T;R!C:&%N9V4@=&AE;2X*("`@("`J"B`@("`@*B!`<&%R
M86T@9FQO870@)&QE9G0@("!,969T(&UA<F=I;BX*("`@("`J($!P87)A;2!F
M;&]A="`D=&]P("`@(%1O<"!M87)G:6XN"B`@("`@*B!`<&%R86T@9FQO870@
M)')I9VAT("!2:6=H="!M87)G:6XN($EF(&YO="!S<&5C:69I960@9&5F875L
M="!T;R!T:&4@=F%L=64*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&]F
M('1H92!L969T(&]N92X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS
M971!=71O4&%G94)R96%K"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971,969T
M36%R9VEN"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9712:6=H=$UA<F=I;@H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T5&]P36%R9VEN"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=$UA<F=I;G,H)&QE9G0L("1T;W`L("1R:6=H="`](&YU
M;&PI"B`@("!["B`@("`@("`@+RH@4V5T(&QE9G0@86YD('1O<"!M87)G:6YS
M+B`J+PH@("`@("`@("1T:&ES+3Y?;&5F=%]M87)G:6X@(#T@)&QE9G0["B`@
M("`@("`@)'1H:7,M/E]T;W!?;6%R9VEN("`@/2`D=&]P.PH@("`@("`@("\J
M($EF(&YO(')I9VAT(&UA<F=I;B!S970@9&5F875L="!T;R!S86UE(&%S(&QE
M9G0N("HO"B`@("`@("`@)'1H:7,M/E]R:6=H=%]M87)G:6X@/2`H:7-?;G5L
M;"@D<FEG:'0I(#\@)&QE9G0@.B`D<FEG:'0I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5F:6YE<R!T:&4@;&5F="!M87)G:6XN(%1H92!M971H;V0@8V%N
M(&)E(&-A;&QE9"!B969O<F4@8W)E871I;F<@=&AE"B`@("`@*B!F:7)S="!P
M86=E+@H@("`@("H@268@=&AE(&-U<G)E;G0@86)S8VES<V$@9V5T<R!O=70@
M;V8@<&%G92P@:70@:7,@8G)O=6=H="!B86-K('1O('1H90H@("`@("H@;6%R
M9VEN+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D;6%R9VEN("`@5&AE
M(&UA<F=I;BX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971!=71O
M4&%G94)R96%K"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971-87)G:6YS"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIS9712:6=H=$UA<F=I;@H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ<V5T5&]P36%R9VEN"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$QE9G1-87)G:6XH)&UA<F=I;BD*("`@('L*("`@("`@("`D=&AI<RT^
M7VQE9G1?;6%R9VEN(#T@)&UA<F=I;CL*("`@("`@("`O*B!)9B!T:&5R92!I
M<R!A(&-U<G)E;G0@<&%G92!A;F0@=&AE(&-U<G)E;G0@6"!P;W-I=&EO;B!I
M<R!L97-S('1H86X*("`@("`@("`@*B!M87)G:6X@<V5T('1H92!8('!O<VET
M:6]N('1O('1H92!M87)G:6X@=F%L=64N("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?<&%G92`^(#`@)B8@)'1H:7,M/G@@/"`D;6%R9VEN*2!["B`@("`@("`@
M("`@("1T:&ES+3YX(#T@)&UA<F=I;CL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$969I;F5S('1H92!T;W`@;6%R9VEN+B!4:&4@;65T:&]D
M(&-A;B!B92!C86QL960@8F5F;W)E(&-R96%T:6YG('1H90H@("`@("H@9FER
M<W0@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)&UA<F=I;B`@
M5&AE(&UA<F=I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&]P36%R9VEN
M*"1M87)G:6XI"B`@("!["B`@("`@("`@)'1H:7,M/E]T;W!?;6%R9VEN(#T@
M)&UA<F=I;CL*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE(')I
M9VAT(&UA<F=I;BX@5&AE(&UE=&AO9"!C86X@8F4@8V%L;&5D(&)E9F]R92!C
M<F5A=&EN9R!T:&4*("`@("`J(&9I<G-T('!A9V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&9L;V%T("1M87)G:6X@(%1H92!M87)G:6XN"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=%)I9VAT36%R9VEN*"1M87)G:6XI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]R:6=H=%]M87)G:6X@/2`D;6%R9VEN.PH@("`@?0H*("`@
M("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!T:&4@875T;VUA=&EC
M('!A9V4@8G)E86MI;F<@;6]D92X@5VAE;B!E;F%B;&EN9RP*("`@("`J('1H
M92!S96-O;F0@<&%R86UE=&5R(&ES('1H92!D:7-T86YC92!F<F]M('1H92!B
M;W1T;VT@;V8@=&AE('!A9V4@=&AA=`H@("`@("H@9&5F:6YE<R!T:&4@=')I
M9V=E<FEN9R!L:6UI="X@0GD@9&5F875L="P@=&AE(&UO9&4@:7,@;VX@86YD
M('1H92!M87)G:6X*("`@("`J(&ES(#(@8VTN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@875T;R`@($)O;VQE86X@:6YD:6-A=&EN9R!I9B!M;V1E
M('-H;W5L9"!B92!O;B!O<B!O9F8N"B`@("`@*B!`<&%R86T@9FQO870@)&UA
M<F=I;B`@1&ES=&%N8V4@9G)O;2!T:&4@8F]T=&]M(&]F('1H92!P86=E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971!=71O4&%G94)R96%K*"1A=71O+"`D
M;6%R9VEN(#T@,"D*("`@('L*("`@("`@("`D=&AI<RT^7V%U=&]?<&%G95]B
M<F5A:R`@("`]("1A=71O.PH@("`@("`@("1T:&ES+3Y?8G)E86M?;6%R9VEN
M("`@("`@(#T@)&UA<F=I;CL*("`@("`@("`D=&AI<RT^7W!A9V5?8G)E86M?
M=')I9V=E<B`]("1T:&ES+3YH("T@)&UA<F=I;CL*("`@('T*"B`@("`O*BH*
M("`@("`J($1E9FEN97,@=&AE('=A>2!T:&4@9&]C=6UE;G0@:7,@=&\@8F4@
M9&ES<&QA>65D(&)Y('1H92!V:65W97(N(%1H92!Z;V]M"B`@("`@*B!L979E
M;"!C86X@8F4@<V5T.B!P86=E<R!C86X@8F4@9&ES<&QA>65D(&5N=&ER96QY
M(&]N('-C<F5E;BP@;V-C=7!Y('1H90H@("`@("H@9G5L;"!W:61T:"!O9B!T
M:&4@=VEN9&]W+"!U<V4@<F5A;"!S:7IE+"!B92!S8V%L960@8GD@82!S<&5C
M:69I8PH@("`@("H@>F]O;6EN9R!F86-T;W(@;W(@=7-E('9I97=E<B!D969A
M=6QT("AC;VYF:6=U<F5D(&EN('1H92!0<F5F97)E;F-E<PH@("`@("H@;65N
M=2!O9B!!8W)O8F%T*2X@5&AE('!A9V4@;&%Y;W5T(&-A;B!B92!S<&5C:69I
M960@=&]O.B!S:6YG;&4@870@;VYC92P*("`@("`J(&-O;G1I;G5O=7,@9&ES
M<&QA>2P@='=O(&-O;'5M;G,@;W(@=FEE=V5R(&1E9F%U;'0N"B`@("`@*B!"
M>2!D969A=6QT+"!D;V-U;65N=',@=7-E('1H92!F=6QL('=I9'1H(&UO9&4@
M=VET:"!C;VYT:6YU;W5S(&1I<W!L87DN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1Z;V]M("`@("`@("`@("`@(%1H92!Z;V]M('1O('5S92X@270@
M8V%N(&)E(&]N92!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;VQL;W=I;F<@<W1R:6YG('9A;'5E<SH*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("T@9G5L;'!A9V4Z(&5N
M=&ER92!P86=E(&]N('-C<F5E;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+2!F=6QL=VED=&@Z(&UA>&EM=6T@=VED=&@@;V8@
M=VEN9&]W"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`M(')E86PZ('5S97,@<F5A;"!S:7IE("@Q,#`E('IO;VTI"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`M(&1E9F%U;'0Z('5S
M97,@=FEE=V5R(&1E9F%U;'0@;6]D90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&]R(&$@;G5M8F5R(&EN9&EC871I;F<@=&AE('IO
M;VUI;F<@9F%C=&]R+@H@("`@("H@0'!A<F%M('-T<FEN9R!L87EO=70@(%1H
M92!P86=E(&QA>6]U="X@4&]S<VEB;&4@=F%L=65S(&%R93H*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@<VEN9VQE.B!O;F4@<&%G92!A="!O
M;F-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(&-O;G1I;G5O
M=7,Z('!A9V5S(&EN(&-O;G1I;G5O=7-L>0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!T=V\Z('1W;R!P86=E<R!O;B!T=V\@8V]L=6UN<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!D969A=6QT.B!U<V5S
M('9I97=E<B!D969A=6QT(&UO9&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@($1E9F%U;'0@=F%L=64@:7,@8V]N=&EN=6]U<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T1&ES<&QA>4UO9&4H)'IO;VTL("1L87EO=70@/2`G
M8V]N=&EN=6]U<R<I"B`@("!["B`@("`@("`@)'IO;VT@/2!S=')T;VQO=V5R
M*"1Z;V]M*3L*("`@("`@("!I9B`H)'IO;VT@/3T@)V9U;&QP86=E)R!\?"`D
M>F]O;2`]/2`G9G5L;'=I9'1H)R!\?"`D>F]O;2`]/2`G<F5A;"<*("`@("`@
M("`@("`@?'P@)'IO;VT@/3T@)V1E9F%U;'0G('Q\("%I<U]S=')I;F<H)'IO
M;VTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?>F]O;5]M;V1E(#T@)'IO;VT[
M"B`@("`@("`@?2!E;'-E:68@*"1Z;V]M(#T]("=Z;V]M)RD@>PH@("`@("`@
M("`@("`D=&AI<RT^7WIO;VU?;6]D92`]("1L87EO=70["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P
M<FEN=&8H)TEN8V]R<F5C="!Z;V]M(&1I<W!L87D@;6]D93H@)7,G+"`D>F]O
M;2DI.PH@("`@("`@('T*"B`@("`@("`@)&QA>6]U="`]('-T<G1O;&]W97(H
M)&QA>6]U="D["B`@("`@("`@:68@*"1L87EO=70@/3T@)W-I;F=L92<@?'P@
M)&QA>6]U="`]/2`G8V]N=&EN=6]U<R<@?'P@)&QA>6]U="`]/2`G='=O)PH@
M("`@("`@("`@("!\?"`D;&%Y;W5T(#T]("=D969A=6QT)RD@>PH@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%]M;V1E(#T@)&QA>6]U=#L*("`@("`@("!]
M(&5L<V5I9B`H)'IO;VT@(3T@)WIO;VTG*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=);F-O<G)E8W0@;&%Y;W5T
M(&1I<W!L87D@;6]D93H@)7,G+"`D;&%Y;W5T*2D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@06-T:79A=&5S(&]R(&1E86-T:79A=&5S('!A
M9V4@8V]M<')E<W-I;VXN(%=H96X@86-T:79A=&5D+"!T:&4@:6YT97)N86P*
M("`@("`J(')E<')E<V5N=&%T:6]N(&]F(&5A8V@@<&%G92!I<R!C;VUP<F5S
M<V5D+"!W:&EC:"!L96%D<R!T;R!A(&-O;7!R97-S:6]N"B`@("`@*B!R871I
M;R!O9B!A8F]U="`R(&9O<B!T:&4@<F5S=6QT:6YG(&1O8W5M96YT+@H@("`@
M("H@0V]M<')E<W-I;VX@:7,@;VX@8GD@9&5F875L="X*("`@("`J($YO=&4Z
M('1H92!:;&EB(&5X=&5N<VEO;B!I<R!R97%U:7)E9"!F;W(@=&AI<R!F96%T
M=7)E+B!)9B!N;W0@<')E<V5N="P*("`@("`J(&-O;7!R97-S:6]N('=I;&P@
M8F4@='5R;F5D(&]F9BX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M8V]M<')E<W,@($)O;VQE86X@:6YD:6-A=&EN9R!I9B!C;VUP<F5S<VEO;B!M
M=7-T(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&5N86)L
M960@;W(@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971#;VUP<F5S<VEO
M;B@D8V]M<')E<W,I"B`@("!["B`@("`@("`@+RH@268@;F\@9WIC;VUP<F5S
M<R!F=6YC=&EO;B!I<R!A=F%I;&%B;&4@=&AE;B!D969A=6QT('1O(&9A;'-E
M+B`J+PH@("`@("`@("1T:&ES+3Y?8V]M<')E<W,@/2`H9G5N8W1I;VY?97AI
M<W1S*"=G>F-O;7!R97-S)RD@/R`D8V]M<')E<W,@.B!F86QS92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&EN9F\@=&\@82!D;V-U;65N="X@
M4&]S<VEB;&4@:6YF;R!S971T:6YG<R!A<F4Z"B`@("`@*B`@("T@=&ET;&4*
M("`@("`J("`@+2!S=6)J96-T"B`@("`@*B`@("T@875T:&]R"B`@("`@*B`@
M("T@:V5Y=V]R9',*("`@("`J("`@+2!C<F5A=&]R"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1I;F9O("`@($EF('!A<W-E9"!A<R!A;B!A<G)A>2!T
M:&5N('1H92!C;VUP;&5T92!H87-H"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&%I;FEN9R!T:&4@:6YF;R!T;R!B92!I;G-E<G1E9"!I;G1O
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1O8W5M96YT+B!/
M=&AE<G=I<V4@=&AE(&YA;64@;V8@<V5T=&EN9R!T;R!B92!S970N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('9A;'5E(&]F('1H92!S971T
M:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971);F9O*"1I;F9O+"`D=F%L
M=64@/2`G)RD*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&EN9F\I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?:6YF;R`]("1I;F9O.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:6YF;ULD:6YF;UT@/2`D=F%L
M=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5F:6YE<R!A
M;B!A;&EA<R!F;W(@=&AE('1O=&%L(&YU;6)E<B!O9B!P86=E<RX@270@=VEL
M;"!B92!S=6)S=&ET=71E9`H@("`@("H@87,@=&AE(&1O8W5M96YT(&ES(&-L
M;W-E9"X*("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H@8VQA<W,@37E?
M1FEL95]01$8@97AT96YD<R!&:6QE7U!$1B!["B`@("`@*B`@("`@9G5N8W1I
M;VX@9F]O=&5R*"D*("`@("`J("`@("!["B`@("`@*B`@("`@("`@("\O($=O
M('1O(#$N-2!C;2!F<F]M(&)O='1O;0H@("`@("H@("`@("`@("`D=&AI<RT^
M<V5T62@M,34I.PH@("`@("H@("`@("`@("`O+R!396QE8W0@07)I86P@:71A
M;&EC(#@*("`@("`J("`@("`@("`@)'1H:7,M/G-E=$9O;G0H)T%R:6%L)RP@
M)TDG+"`X*3L*("`@("`J("`@("`@("`@+R\@4')I;G0@8W5R<F5N="!A;F0@
M=&]T86P@<&%G92!N=6UB97)S"B`@("`@*B`@("`@("`@("1T:&ES+3YC96QL
M*#`L(#$P+"`G4&%G92`G("X@)'1H:7,M/F=E=%!A9V5.;R@I("X@)R][;F)]
M)RP@,"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@,"P@)T,G*3L*("`@
M("`J("`@("!]"B`@("`@*B!]"B`@("`@*B`D<&1F(#T@)DUY7T9I;&5?4$1&
M.CIF86-T;W)Y*"D["B`@("`@*B`D<&1F+3YA;&EA<TYB4&%G97,H*3L*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A;&EA<R`@5&AE(&%L:6%S+B!$
M969A=6QT('9A;'5E.B![;F)]+@H@("`@("H*("`@("`J($!S964@1FEL95]0
M1$8Z.F=E=%!A9V5.;PH@("`@("H@0'-E92!&:6QE7U!$1CHZ9F]O=&5R"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%L:6%S3F)086=E<R@D86QI87,@/2`G>VYB
M?2<I"B`@("!["B`@("`@("`@)'1H:7,M/E]A;&EA<U]N8E]P86=E<R`]("1A
M;&EA<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D(&)E9VEN
M<R!T:&4@9V5N97)A=&EO;B!O9B!T:&4@4$1&(&1O8W5M96YT.R!I="!M=7-T
M(&)E"B`@("`@*B!C86QL960@8F5F;W)E(&%N>2!O=71P=70@8V]M;6%N9',N
M($YO('!A9V4@:7,@8W)E871E9"!B>2!T:&ES(&UE=&AO9"P*("`@("`J('1H
M97)E9F]R92!I="!I<R!N96-E<W-A<GD@=&\@8V%L;"!&:6QE7U!$1CHZ861D
M4&%G92X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA9&1086=E"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIC;&]S90H@("`@("HO"B`@("!F=6YC=&EO
M;B!O<&5N*"D*("`@('L*("`@("`@("`D=&AI<RT^7V)E9VEN1&]C*"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!497)M:6YA=&5S('1H92!01$8@9&]C=6UE
M;G0N($ET(&ES(&YO="!N96-E<W-A<GD@=&\@8V%L;"!T:&ES(&UE=&AO9`H@
M("`@("H@97AP;&EC:71L>2!B96-A=7-E($9I;&5?4$1&.CIO=71P=70@9&]E
M<R!I="!A=71O;6%T:6-A;&QY+@H@("`@("H@268@=&AE(&1O8W5M96YT(&-O
M;G1A:6YS(&YO('!A9V4L($9I;&5?4$1&.CIA9&1086=E(&ES(&-A;&QE9"!T
M;R!P<F5V96YT"B`@("`@*B!F<F]M(&=E='1I;F<@86X@:6YV86QI9"!D;V-U
M;65N="X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIO<&5N"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIO=71P=70*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VQO<V4H*0H@("`@>PH@("`@("`@("\J(%1E<FUI;F%T92!D;V-U;65N="`J
M+PH@("`@("`@(&EF("@D=&AI<RT^7W!A9V4@/3T@,"D@>PH@("`@("`@("`@
M("`D=&AI<RT^861D4&%G92@I.PH@("`@("`@('T*("`@("`@("`O*B!086=E
M(&9O;W1E<B`J+PH@("`@("`@("1T:&ES+3Y?:6Y?9F]O=&5R(#T@=')U93L*
M("`@("`@("`D=&AI<RT^9F]O=&5R*"D["B`@("`@("`@)'1H:7,M/E]I;E]F
M;V]T97(@/2!F86QS93L*("`@("`@("`O*B!#;&]S92!P86=E("HO"B`@("`@
M("`@)'1H:7,M/E]E;F1086=E*"D["B`@("`@("`@+RH@0VQO<V4@9&]C=6UE
M;G0@*B\*("`@("`@("`D=&AI<RT^7V5N9$1O8R@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@061D<R!A(&YE=R!P86=E('1O('1H92!D;V-U;65N="X@268@
M82!P86=E(&ES(&%L<F5A9'D@<')E<V5N="P@=&AE"B`@("`@*B!&:6QE7U!$
M1CHZ9F]O=&5R(&UE=&AO9"!I<R!C86QL960@9FER<W0@=&\@;W5T<'5T('1H
M92!F;V]T97(N(%1H96X@=&AE"B`@("`@*B!P86=E(&ES(&%D9&5D+"!T:&4@
M8W5R<F5N="!P;W-I=&EO;B!S970@=&\@=&AE('1O<"UL969T(&-O<FYE<B!A
M8V-O<F1I;F<*("`@("`J('1O('1H92!L969T(&%N9"!T;W`@;6%R9VEN<RP@
M86YD($9I;&5?4$1&.CIH96%D97(@:7,@8V%L;&5D('1O(&1I<W!L87D*("`@
M("`J('1H92!H96%D97(N"B`@("`@*B!4:&4@9F]N="!W:&EC:"!W87,@<V5T
M(&)E9F]R92!C86QL:6YG(&ES(&%U=&]M871I8V%L;'D@<F5S=&]R960N(%1H
M97)E"B`@("`@*B!I<R!N;R!N965D('1O(&-A;&P@1FEL95]01$8Z.G-E=$9O
M;G0@86=A:6X@:68@>6]U('=A;G0@=&\@8V]N=&EN=64@=VET:`H@("`@("H@
M=&AE('-A;64@9F]N="X@5&AE('-A;64@:7,@=')U92!F;W(@8V]L;W)S(&%N
M9"!L:6YE('=I9'1H+@H@("`@("H@5&AE(&]R:6=I;B!O9B!T:&4@8V]O<F1I
M;F%T92!S>7-T96T@:7,@870@=&AE('1O<"UL969T(&-O<FYE<B!A;F0*("`@
M("`J(&EN8W)E87-I;F<@;W)D:6YA=&5S(&=O(&1O=VYW87)D<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<FEE;G1A=&EO;B`@4&%G92!O<FEE
M;G1A=&EO;BX@4&]S<VEB;&4@=F%L=65S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)E("AC87-E(&EN<V5N<VET:79E*3H*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("T@4"!O<B!0;W)T<F%I
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!,(&]R
M($QA;F1S8V%P90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%1H92!D969A=6QT('9A;'5E(&ES('1H92!O;F4@<&%S<V5D('1O('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G-T<G5C=&]R
M+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.E!$1@H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ:&5A9&5R"B`@("`@*B!`<V5E($9I;&5?4$1&.CIF;V]T
M97(*("`@("`J($!S964@1FEL95]01$8Z.G-E=$UA<F=I;G,*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D4&%G92@D;W)I96YT871I;VX@/2`G)RD*("`@('L*
M("`@("`@("`O*B!&;W(@9V]O9"!M96%S=7)E(&UA:V4@<W5R92!T:&ES(&ES
M(&-A;&QE9"X@*B\*("`@("`@("`D=&AI<RT^7V)E9VEN1&]C*"D["@H@("`@
M("`@("\J(%-A=F4@<W1Y;&4@<V5T=&EN9W,@<V\@=&AA="!T:&5Y(&%R92!N
M;W0@;W9E<G)I9&1E;B!B>0H@("`@("`@("`J(&AE861E<B@I+B`J+PH@("`@
M("`@("1L=R`]("1T:&ES+3Y?;&EN95]W:61T:#L*("`@("`@("`D9&,@/2`D
M=&AI<RT^7V1R87=?8V]L;W(["B`@("`@("`@)&9C(#T@)'1H:7,M/E]F:6QL
M7V-O;&]R.PH@("`@("`@(&EF("@D=&AI<RT^7W!A9V4@/B`P*2!["B`@("`@
M("`@("`@("\J(%!A9V4@9F]O=&5R+B`J+PH@("`@("`@("`@("`D=&AI<RT^
M7VEN7V9O;W1E<B`]('1R=64["B`@("`@("`@("`@("1T:&ES+3YF;V]T97(H
M*3L*("`@("`@("`@("`@)'1H:7,M/E]I;E]F;V]T97(@/2!F86QS93L*("`@
M("`@("`@("`@+RH@0VQO<V4@<&%G92X@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]E;F1086=E*"D["B`@("`@("`@?0H@("`@("`@("\J(%-T87)T(&YE=R!P
M86=E+B`J+PH@("`@("`@("1T:&ES+3Y?8F5G:6Y086=E*"1O<FEE;G1A=&EO
M;BD["B`@("`@("`@+RH@4V5T(&QI;F4@8V%P('-T>6QE('1O('-Q=6%R92X@
M*B\*("`@("`@("`D=&AI<RT^7V]U="@G,B!*)RD["B`@("`@("`@+RH@4V5T
M(&QI;F4@=VED=&@N("HO"B`@("`@("`@)'1H:7,M/E]L:6YE7W=I9'1H(#T@
M)&QW.PH@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)R4N,F8@=R<L("1L
M=R`J("1T:&ES+3Y?<V-A;&4I*3L*("`@("`@("`O*B!3970@9F]N="!F;W(@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@<&%G92X@*B\*("`@("`@("!I9B`H)'1H
M:7,M/E]F;VYT7V9A;6EL>2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T1F]N
M="@D=&AI<RT^7V9O;G1?9F%M:6QY+"`D<W1Y;&4L("1T:&ES+3Y?9F]N=%]S
M:7IE7W!T*3L*("`@("`@("`@("`@)&9O;G1?9F%M:6QY(#T@)'1H:7,M/E]F
M;VYT7V9A;6EL>3L*("`@("`@("`@("`@)&9O;G1?<W1Y;&4@/2`D=&AI<RT^
M7V9O;G1?<W1Y;&4@+B`H)'1H:7,M/E]U;F1E<FQI;F4@/R`G52<@.B`G)RD[
M"B`@("`@("`@("`@("1F;VYT7W-I>F4@(#T@)'1H:7,M/E]F;VYT7W-I>F5?
M<'0["B`@("`@("`@?0H@("`@("`@("\J(%-E="!C;VQO<G,N("HO"B`@("`@
M("`@)'1H:7,M/E]F:6QL7V-O;&]R(#T@)&9C.PH@("`@("`@("\J($-H96-K
M(&EF(&9I;&P@8V]L;W(@:&%S(&)E96X@<V5T(&)E9F]R92!T:&ES('!A9V4N
M("HO"B`@("`@("`@:68@*"1T:&ES+3Y?9FEL;%]C;VQO<B`A/2`G,"!G)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@D=&AI<RT^7V9I;&Q?8V]L;W(I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V1R87=?8V]L;W(@/2`D9&,[
M"B`@("`@("`@+RH@0VAE8VL@:68@9')A=R!C;VQO<B!H87,@8F5E;B!S970@
M8F5F;W)E('1H:7,@<&%G92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]D<F%W
M7V-O;&]R("$]("<P($<G*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1T
M:&ES+3Y?9')A=U]C;VQO<BD["B`@("`@("`@?0H@("`@("`@("\J(%!A9V4@
M:&5A9&5R+B`J+PH@("`@("`@("1T:&ES+3YH96%D97(H*3L*("`@("`@("`O
M*B!297-T;W)E(&QI;F4@=VED=&@N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?
M;&EN95]W:61T:"`A/2`D;'<I('L*("`@("`@("`@("`@)'1H:7,M/E]L:6YE
M7W=I9'1H(#T@)&QW.PH@("`@("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F
M*"<E+C)F('<G+"`D;'<@*B`D=&AI<RT^7W-C86QE*2D["B`@("`@("`@?0H@
M("`@("`@("\J($UA:V4@<W5R92!T:&4@9F]N="!I<R!S970@9F]R('1H:7,@
M<&%G92!A<R!I="!W87,@8F5F;W)E('1H90H@("`@("`@("`J(&AE861E<BX@
M*B\*("`@("`@("!I9B`H)&9O;G1?9F%M:6QY*2!["B`@("`@("`@("`@("1T
M:&ES+3YS971&;VYT*"1F;VYT7V9A;6EL>2P@)&9O;G1?<W1Y;&4L("1F;VYT
M7W-I>F4L('1R=64I.PH@("`@("`@('T*("`@("`@("`O*B!297-T;W)E(&-O
M;&]R<RX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]D<F%W7V-O;&]R("$]("1D
M8RD@>PH@("`@("`@("`@("`D=&AI<RT^7V1R87=?8V]L;W(@/2`D9&,["B`@
M("`@("`@("`@("1T:&ES+3Y?;W5T*"1D8RD["B`@("`@("`@?0H@("`@("`@
M(&EF("@D=&AI<RT^7V9I;&Q?8V]L;W(@(3T@)&9C*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?9FEL;%]C;VQO<B`]("1F8SL*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)&9C*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:&ES(&UE=&AO9"!I<R!U<V5D('1O(')E;F1E<B!T:&4@<&%G92!H96%D97(N
M($ET(&ES(&%U=&]M871I8V%L;'D*("`@("`J(&-A;&QE9"!B>2!&:6QE7U!$
M1CHZ861D4&%G92!A;F0@<VAO=6QD(&YO="!B92!C86QL960@9&ER96-T;'D@
M8GD@=&AE"B`@("`@*B!A<'!L:6-A=&EO;BX@5&AE(&EM<&QE;65N=&%T:6]N
M(&EN($9I;&5?4$1&.CH@:7,@96UP='DL('-O('EO=2!H879E('1O"B`@("`@
M*B!S=6)C;&%S<R!I="!A;F0@;W9E<G)I9&4@=&AE(&UE=&AO9"!I9B!Y;W4@
M=V%N="!A('-P96-I9FEC('!R;V-E<W-I;F<N"B`@("`@*@H@("`@("H@17AA
M;7!L93H*("`@("`J"B`@("`@*B!C;&%S<R!->5]&:6QE7U!$1B!E>'1E;F1S
M($9I;&5?4$1&('L*("`@("`J("`@("!F=6YC=&EO;B!H96%D97(H*0H@("`@
M("H@("`@('L*("`@("`J("`@("`@("`@+R\@4V5L96-T($%R:6%L(&)O;&0@
M,34*("`@("`J("`@("`@("`@)'1H:7,M/G-E=$9O;G0H)T%R:6%L)RP@)T(G
M+"`Q-2D["B`@("`@*B`@("`@("`@("\O($UO=F4@=&\@=&AE(')I9VAT"B`@
M("`@*B`@("`@("`@("1T:&ES+3YC96QL*#@P*3L*("`@("`J("`@("`@("`@
M+R\@1G)A;65D('1I=&QE"B`@("`@*B`@("`@("`@("1T:&ES+3YC96QL*#,P
M+"`Q,"P@)U1I=&QE)RP@,2P@,"P@)T,G*3L*("`@("`J("`@("`@("`@+R\@
M3&EN92!B<F5A:PH@("`@("H@("`@("`@("`D=&AI<RT^;F5W3&EN92@R,"D[
M"B`@("`@*B`@("`@?0H@("`@("H@?0H@("`@("H*("`@("`J($!S964@1FEL
M95]01$8Z.F9O;W1E<@H@("`@("HO"B`@("!F=6YC=&EO;B!H96%D97(H*0H@
M("`@>PH@("`@("`@("\J(%1O(&)E(&EM<&QE;65N=&5D(&EN('EO=7(@;W=N
M(&EN:&5R:71E9"!C;&%S<RX@*B\*("`@('T*"B`@("`O*BH*("`@("`J(%1H
M:7,@;65T:&]D(&ES('5S960@=&\@<F5N9&5R('1H92!P86=E(&9O;W1E<BX@
M270@:7,@875T;VUA=&EC86QL>0H@("`@("H@8V%L;&5D(&)Y($9I;&5?4$1&
M.CIA9&1086=E(&%N9"!&:6QE7U!$1CHZ8VQO<V4@86YD('-H;W5L9"!N;W0@
M8F4@8V%L;&5D"B`@("`@*B!D:7)E8W1L>2!B>2!T:&4@87!P;&EC871I;VXN
M(%1H92!I;7!L96UE;G1A=&EO;B!I;B!&:6QE7U!$1CHZ(&ES(&5M<'1Y+`H@
M("`@("H@<V\@>6]U(&AA=F4@=&\@<W5B8VQA<W,@:70@86YD(&]V97)R:61E
M('1H92!M971H;V0@:68@>6]U('=A;G0@82!S<&5C:69I8PH@("`@("H@<')O
M8V5S<VEN9RX*("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H*("`@("`J
M(&-L87-S($UY7T9I;&5?4$1&(&5X=&5N9',@1FEL95]01$8@>PH@("`@("H@
M("`@9G5N8W1I;VX@9F]O=&5R*"D*("`@("`J("`@('L*("`@("`J("`@("`@
M("`O+R!';R!T;R`Q+C4@8VT@9G)O;2!B;W1T;VT*("`@("`J("`@("`@("`D
M=&AI<RT^<V5T62@M,34I.PH@("`@("H@("`@("`@("\O(%-E;&5C="!!<FEA
M;"!I=&%L:6,@.`H@("`@("H@("`@("`@("1T:&ES+3YS971&;VYT*"=!<FEA
M;"<L("=))RP@."D["B`@("`@*B`@("`@("`@+R\@4')I;G0@8V5N=&5R960@
M<&%G92!N=6UB97(*("`@("`J("`@("`@("`D=&AI<RT^8V5L;"@P+"`Q,"P@
M)U!A9V4@)R`N("1T:&ES+3YG971086=E3F\H*2P@,"P@,"P@)T,G*3L*("`@
M("`J("`@('T*("`@("`J('T*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIH96%D97(*("`@("`J+PH@("`@9G5N8W1I;VX@9F]O=&5R*"D*("`@('L*
M("`@("`@("`O*B!4;R!B92!I;7!L96UE;G1E9"!I;B!Y;W5R(&]W;B!I;FAE
M<FET960@8VQA<W,N("HO"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!C=7)R96YT('!A9V4@;G5M8F5R+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F%L:6%S
M3F)086=E<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971086=E3F\H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!A9V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!F:6QL(&-O;&]R+B!3<&5C:69I97,@=&AE(&-O
M;&]R(&9O<B!B;W1H(&9I;&QE9"!A<F5A<R!A;F0*("`@("`J('1E>'0N($1E
M<&5N9&EN9R!O;B!T:&4@8V]L;W)S<&%C92!C86QL960L('1H92!N=6UB97(@
M;V8@8V]L;W(@8V]M<&]N96YT"B`@("`@*B!P87)A;65T97)S(')E<75I<F5D
M(&-A;B!B92!E:71H97(@,2P@,R!O<B`T+B!4:&4@;65T:&]D(&-A;B!B92!C
M86QL960*("`@("`J(&)E9F]R92!T:&4@9FER<W0@<&%G92!I<R!C<F5A=&5D
M(&%N9"!T:&4@8V]L;W(@:7,@<F5T86EN960@9G)O;2!P86=E('1O"B`@("`@
M*B!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-S("!);F1I
M8V%T97,@=&AE(&-O;&]R<W!A8V4@=VAI8V@@8V%N(&)E(&5I=&AE<B`G<F=B
M)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`G8VUY:R<@;W(@)V=R87DG
M+B!$969A=6QT<R!T;R`G<F=B)RX*("`@("`J($!P87)A;2!F;&]A="`D8S$@
M("!&:7)S="!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG('!O:6YT('9A;'5E
M(&)E='=E96X@,`H@("`@("H@("`@("`@("`@("`@("`@("`@(&%N9"`Q+B!2
M97%U:7)E9"!F;W(@9W)A>2P@<F=B(&%N9"!C;7EK+@H@("`@("H@0'!A<F%M
M(&9L;V%T("1C,B`@(%-E8V]N9"!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG
M('!O:6YT('9A;'5E(&)E='=E96X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`P(&%N9"`Q+B!297%U:7)E9"!F;W(@<F=B(&%N9"!C;7EK+@H@("`@("H@
M0'!A<F%M(&9L;V%T("1C,R`@(%1H:7)D(&-O;&]R(&-O;7!O;F5N="P@9FQO
M871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@(#`@86YD(#$N(%)E<75I<F5D(&9O<B!R9V(@86YD(&-M>6LN"B`@
M("`@*B!`<&%R86T@9FQO870@)&,T("`@1F]U<G1H(&-O;&]R(&-O;7!O;F5N
M="P@9FQO871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@(#`@86YD(#$N(%)E<75I<F5D(&9O<B!C;7EK+@H@("`@
M("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$1R87=#;VQO<@H@("`@("H@
M0'-E92!&:6QE7U!$1CHZ<F5C=`H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L
M;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=$9I;&Q#;VQO<B@D8W,@/2`G<F=B)RP@)&,Q+"`D8S(@
M/2`P+"`D8S,@/2`P+"`D8S0@/2`P*0H@("`@>PH@("`@("`@("1C<R`]('-T
M<G1O;&]W97(H)&-S*3L*("`@("`@("!I9B`H)&-S(#T]("=R9V(G*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?9FEL;%]C;VQO<B`]('-P<FEN=&8H)R4N,V8@
M)2XS9B`E+C-F(')G)RP@)&,Q+"`D8S(L("1C,RD["B`@("`@("`@?2!E;'-E
M:68@*"1C<R`]/2`G8VUY:R<I('L*("`@("`@("`@("`@)'1H:7,M/E]F:6QL
M7V-O;&]R(#T@<W!R:6YT9B@G)2XS9B`E+C-F("4N,V8@)2XS9B!K)RP@)&,Q
M+"`D8S(L("1C,RP@)&,T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^7V9I;&Q?8V]L;W(@/2!S<')I;G1F*"<E+C-F(&<G+"`D8S$I
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]P86=E(#X@,"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]U="@D=&AI<RT^7V9I;&Q?8V]L;W(I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&1R87<@
M8V]L;W(L('5S960@=VAE;B!D<F%W:6YG(&QI;F5S+B!$97!E;F1I;F<@;VX@
M=&AE"B`@("`@*B!C;VQO<G-P86-E(&-A;&QE9"P@=&AE(&YU;6)E<B!O9B!C
M;VQO<B!C;VUP;VYE;G0@<&%R86UE=&5R<R!R97%U:7)E9`H@("`@("H@8V%N
M(&)E(&5I=&AE<B`Q+"`S(&]R(#0N(%1H92!M971H;V0@8V%N(&)E(&-A;&QE
M9"!B969O<F4@=&AE(&9I<G-T('!A9V4*("`@("`J(&ES(&-R96%T960@86YD
M('1H92!C;VQO<B!I<R!R971A:6YE9"!F<F]M('!A9V4@=&\@<&%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<R`@26YD:6-A=&5S('1H92!C
M;VQO<G-P86-E('=H:6-H(&-A;B!B92!E:71H97(@)W)G8B<L"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@)V-M>6LG(&]R("=G<F%Y)RX@1&5F875L=',@
M=&\@)W)G8B<N"B`@("`@*B!`<&%R86T@9FQO870@)&,Q("`@1FER<W0@8V]L
M;W(@8V]M<&]N96YT+"!F;&]A=&EN9R!P;VEN="!V86QU92!B971W965N(#`*
M("`@("`J("`@("`@("`@("`@("`@("`@("!A;F0@,2X@4F5Q=6ER960@9F]R
M(&=R87DL(')G8B!A;F0@8VUY:RX*("`@("`J($!P87)A;2!F;&]A="`D8S(@
M("!396-O;F0@8V]L;W(@8V]M<&]N96YT+"!F;&]A=&EN9R!P;VEN="!V86QU
M92!B971W965N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@,"!A;F0@,2X@
M4F5Q=6ER960@9F]R(')G8B!A;F0@8VUY:RX*("`@("`J($!P87)A;2!F;&]A
M="`D8S,@("!4:&ER9"!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG('!O:6YT
M('9A;'5E(&)E='=E96X@,`H@("`@("H@("`@("`@("`@("`@("`@("`@(&%N
M9"`Q+B!297%U:7)E9"!F;W(@<F=B(&%N9"!C;7EK+@H@("`@("H@0'!A<F%M
M(&9L;V%T("1C-"`@($9O=7)T:"!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG
M('!O:6YT('9A;'5E(&)E='=E96X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`P(&%N9"`Q+B!297%U:7)E9"!F;W(@8VUY:RX*("`@("`J"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIS971&:6QL0V]L;W(*("`@("`J($!S964@1FEL95]0
M1$8Z.FQI;F4*("`@("`J($!S964@1FEL95]01$8Z.G)E8W0*("`@("`J($!S
M964@1FEL95]01$8Z.F-E;&P*("`@("`J($!S964@1FEL95]01$8Z.FUU;'1I
M0V5L;`H@("`@("HO"B`@("!F=6YC=&EO;B!S971$<F%W0V]L;W(H)&-S(#T@
M)W)G8B<L("1C,2P@)&,R(#T@,"P@)&,S(#T@,"P@)&,T(#T@,"D*("`@('L*
M("`@("`@("`D8W,@/2!S=')T;VQO=V5R*"1C<RD["B`@("`@("`@:68@*"1C
M<R`]/2`G<F=B)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V1R87=?8V]L;W(@
M/2!S<')I;G1F*"<E+C-F("4N,V8@)2XS9B!21R<L("1C,2P@)&,R+"`D8S,I
M.PH@("`@("`@('T@96QS96EF("@D8W,@/3T@)V-M>6LG*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?9')A=U]C;VQO<B`]('-P<FEN=&8H)R4N,V8@)2XS9B`E
M+C-F("4N,V8@2R<L("1C,2P@)&,R+"`D8S,L("1C-"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]D<F%W7V-O;&]R(#T@<W!R:6YT
M9B@G)2XS9B!')RP@)&,Q*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3Y?<&%G92`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)'1H:7,M
M/E]D<F%W7V-O;&]R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!L96YG=&@@;V8@82!T97AT('-T<FEN9RX@02!F;VYT
M(&UU<W0@8F4@<V5L96-T960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@5&AE('1E>'0@=VAO<V4@;&5N9W1H(&ES('1O(&)E(&-O;7!U
M=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!T("`@0F]O;&5A;B!T;R!I
M;F1I8V%T92!I9B!T:&4@=VED=&@@<VAO=6QD(&)E(')E='5R;F5D"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!I;B!P;VEN=',@;W(@=7-E<B!U;FET
M<RX@1&5F875L="!I<R`G9F%L<V4G+@H@("`@("H*("`@("`J($!R971U<FX@
M9FQO870*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W1R:6YG5VED=&@H)'1E
M>'0L("1P="`](&9A;'-E*0H@("`@>PH@("`@("`@("1T97AT(#T@*'-T<FEN
M9RDD=&5X=#L*("`@("`@("`D=VED=&@@/2`P.PH@("`@("`@("1L96YG=&@@
M/2!S=')L96XH)'1E>'0I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1L
M96YG=&@[("1I*RLI('L*("`@("`@("`@("`@)'=I9'1H("L]("1T:&ES+3Y?
M8W5R<F5N=%]F;VYT6R=C=R==6R1T97AT>R1I?5T["B`@("`@("`@?0H*("`@
M("`@("`O*B!!9&IU<W0@9F]R('=O<F0@<W!A8VEN9RX@*B\*("`@("`@("`D
M=VED=&@@*ST@)'1H:7,M/E]W;W)D7W-P86-I;F<@*B!S=6)S=')?8V]U;G0H
M)'1E>'0L("<@)RD@*B`D=&AI<RT^7V-U<G)E;G1?9F]N=%LG8W<G75LG("==
M.PH*("`@("`@("!I9B`H)'!T*2!["B`@("`@("`@("`@(')E='5R;B`D=VED
M=&@@*B`D=&AI<RT^7V9O;G1?<VEZ95]P="`O(#$P,#`["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1W:61T:"`J("1T:&ES+3Y?9F]N
M=%]S:7IE("\@,3`P,#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$969I;F5S('1H92!L:6YE('=I9'1H+B!">2!D969A=6QT+"!T:&4@=F%L
M=64@97%U86QS(#`N,B!M;2X@5&AE(&UE=&AO9`H@("`@("H@8V%N(&)E(&-A
M;&QE9"!B969O<F4@=&AE(&9I<G-T('!A9V4@:7,@8W)E871E9"!A;F0@=&AE
M('9A;'5E(&ES"B`@("`@*B!R971A:6YE9"!F<F]M('!A9V4@=&\@<&%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'=I9'1H("!4:&4@=VED=&@N
M"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ;&EN90H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ<F5C=`H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L;`H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$QI;F57:61T:"@D=VED=&@I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]L:6YE7W=I9'1H(#T@)'=I9'1H.PH@("`@("`@(&EF("@D=&AI<RT^
M7W!A9V4@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H
M)R4N,F8@=R<L("1W:61T:"`J("1T:&ES+3Y?<V-A;&4I*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A(&QI;F4@8F5T=V5E;B!T
M=V\@<&]I;G1S+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D>#$@($%B
M<V-I<W-A(&]F(&9I<G-T('!O:6YT+@H@("`@("H@0'!A<F%M(&9L;V%T("1Y
M,2`@3W)D:6YA=&4@;V8@9FER<W0@<&]I;G0N"B`@("`@*B!`<&%R86T@9FQO
M870@)'@R("!!8G-C:7-S82!O9B!S96-O;F0@<&]I;G0N"B`@("`@*B!`<&%R
M86T@9FQO870@)'DR("!/<F1I;F%T92!O9B!S96-O;F0@<&]I;G0N"B`@("`@
M*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T3&EN95=I9'1H"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIS971$<F%W0V]L;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QI;F4H)'@Q+"`D>3$L("1X,BP@)'DR*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;W5T*'-P<FEN=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR9B!L(%,G
M+"`D>#$@*B`D=&AI<RT^7W-C86QE+"`H)'1H:7,M/F@@+2`D>3$I("H@)'1H
M:7,M/E]S8V%L92P@)'@R("H@)'1H:7,M/E]S8V%L92P@*"1T:&ES+3YH("T@
M)'DR*2`J("1T:&ES+3Y?<V-A;&4I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($]U='!U=',@82!R96-T86YG;&4N($ET(&-A;B!B92!D<F%W;B`H8F]R9&5R
M(&]N;'DI+"!F:6QL960@*'=I=&@@;F\*("`@("`J(&)O<F1E<BD@;W(@8F]T
M:"X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'@@("`@("`@06)S8VES
M<V$@;V8@=7!P97(M;&5F="!C;W)N97(N"B`@("`@*B!`<&%R86T@9FQO870@
M)'D@("`@("`@3W)D:6YA=&4@;V8@=7!P97(M;&5F="!C;W)N97(N"B`@("`@
M*B!`<&%R86T@9FQO870@)'=I9'1H("`@5VED=&@N"B`@("`@*B!`<&%R86T@
M9FQO870@)&AE:6=H="`@2&5I9VAT+@H@("`@("H@0'!A<F%M(&9L;V%T("1S
M='EL92`@(%-T>6QE(&]F(')E;F1E<FEN9RX@4&]S<VEB;&4@=F%L=65S(&%R
M93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@1"!O<B!E;7!T
M>2!S=')I;F<Z(&1R87<@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`M($8Z(&9I;&P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("T@1$8@;W(@1D0Z(&1R87<@86YD(&9I;&P*("`@("`J"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIS971,:6YE5VED=&@*("`@("`J($!S964@1FEL
M95]01$8Z.G-E=$1R87=#;VQO<@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T
M1FEL;$-O;&]R"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8W0H)'@L("1Y+"`D
M=VED=&@L("1H96EG:'0L("1S='EL92`]("<G*0H@("`@>PH@("`@("`@("1S
M='EL92`]('-T<G1O=7!P97(H)'-T>6QE*3L*("`@("`@("!I9B`H)'-T>6QE
M(#T]("=&)RD@>PH@("`@("`@("`@("`D;W`@/2`G9B<["B`@("`@("`@?2!E
M;'-E:68@*"1S='EL92`]/2`G1D0G('Q\("1S='EL92`]/2`G1$8G*2!["B`@
M("`@("`@("`@("1O<"`]("=")SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;W`@/2`G4R<["B`@("`@("`@?0H*("`@("`@("`D>"`@("`@(#T@
M)'1H:7,M/E]T;U!T*"1X*3L*("`@("`@("`D>2`@("`@(#T@)'1H:7,M/E]T
M;U!T*"1Y*3L*("`@("`@("`D=VED=&@@(#T@)'1H:7,M/E]T;U!T*"1W:61T
M:"D["B`@("`@("`@)&AE:6=H="`]("1T:&ES+3Y?=&]0="@D:&5I9VAT*3L*
M"B`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G)2XR9B`E+C)F("4N,F8@
M)2XR9B!R92`E<R<L("1X+"`D=&AI<RT^:%!T("T@)'DL("1W:61T:"P@+21H
M96EG:'0L("1O<"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!A
M(&-I<F-L92X@270@8V%N(&)E(&1R87=N("AB;W)D97(@;VYL>2DL(&9I;&QE
M9"`H=VET:"!N;PH@("`@("H@8F]R9&5R*2!O<B!B;W1H+@H@("`@("H*("`@
M("`J($!P87)A;2!F;&]A="`D>"`@("`@("!!8G-C:7-S82!O9B!T:&4@8V5N
M=&5R(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@9FQO870@)'D@("`@
M("`@3W)D:6YA=&4@;V8@=&AE(&-E;G1E<B!O9B!T:&4@8VER8VQE+@H@("`@
M("H@0'!A<F%M(&9L;V%T("1R("`@("`@($-I<F-L92!R861I=7,N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S='EL92`@4W1Y;&4@;V8@<F5N9&5R:6YG+B!0
M;W-S:6)L92!V86QU97,@87)E.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@+2!$(&]R(&5M<'1Y('-T<FEN9SH@9')A=R`H9&5F875L="D*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@1CH@9FEL;`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@+2!$1B!O<B!&1#H@9')A=R!A;F0@
M9FEL;`H@("`@("HO"B`@("!F=6YC=&EO;B!C:7)C;&4H)'@L("1Y+"`D<BP@
M)'-T>6QE(#T@)R<I"B`@("!["B`@("`@("`@)'-T>6QE(#T@<W1R=&]L;W=E
M<B@D<W1Y;&4I.PH@("`@("`@(&EF("@D<W1Y;&4@/3T@)V8G*2!["B`@("`@
M("`@("`@("1O<"`]("=F)SL@("`@("`O+R!3='EL92!I<R!F:6QL(&]N;'DN
M"B`@("`@("`@?2!E;'-E:68@*"1S='EL92`]/2`G9F0G('Q\("1S='EL92`]
M/2`G9&8G*2!["B`@("`@("`@("`@("1O<"`]("=")SL@("`@("`O+R!3='EL
M92!I<R!F:6QL(&%N9"!S=')O:V4N"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&]P(#T@)U,G.R`@("`@("\O(%-T>6QE(&ES('-T<F]K92!O;FQY
M+@H@("`@("`@('T*"B`@("`@("`@)'@@/2`D=&AI<RT^7W1O4'0H)'@I.PH@
M("`@("`@("1Y(#T@)'1H:7,M/E]T;U!T*"1Y*3L*("`@("`@("`D<B`]("1T
M:&ES+3Y?=&]0="@D<BD["@H@("`@("`@("\J($EN=F5R="!T:&4@>2!S8V%L
M92X@*B\*("`@("`@("`D>2`]("1T:&ES+3YH4'0@+2`D>3L*("`@("`@("`O
M*B!,96YG=&@@;V8@=&AE($)E>FEE<B!C;VYT<F]L+B`J+PH@("`@("`@("1B
M(#T@)'(@*B`P+C4U,CL*"B`@("`@("`@+RH@36]V92!F<F]M('1H92!G:79E
M;B!O<FEG:6X@86YD('-E="!T:&4@8W5R<F5N="!P;VEN=`H@("`@("`@("`J
M('1O('1H92!S=&%R="!O9B!T:&4@9FER<W0@0F5Z:65R(&-U<G9E+B`J+PH@
M("`@("`@("1C(#T@<W!R:6YT9B@G)2XR9B`E+C)F(&TG+"`D>"`M("1R+"`D
M>2D["B`@("`@("`@)'@@/2`D>"`M("1R.PH@("`@("`@("\J($9I<G-T(&-I
M<F-L92!Q=6%R=&5R+B`J+PH@("`@("`@("1C("X]('-P<FEN=&8H)R`E+C)F
M("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR9B!C)RP*("`@("`@("`@("`@("`@
M("`@("`@("1X+"`D>2`K("1B+"`@("`@("`@("`@+R\@1FER<W0@8V]N=')O
M;"!P;VEN="X*("`@("`@("`@("`@("`@("`@("`@("1X("L@)'(@+2`D8BP@
M)'D@*R`D<BP@+R\@4V5C;VYD(&-O;G1R;VP@<&]I;G0N"B`@("`@("`@("`@
M("`@("`@("`@("`D>"`K("1R+"`D>2`K("1R*3L@("`@("\O($9I;F%L('!O
M:6YT+@H@("`@("`@("\J(%-E="!X+WD@=&\@=&AE(&9I;F%L('!O:6YT+B`J
M+PH@("`@("`@("1X(#T@)'@@*R`D<CL*("`@("`@("`D>2`]("1Y("L@)'([
M"B`@("`@("`@+RH@4V5C;VYD(&-I<F-L92!Q=6%R=&5R+B`J+PH@("`@("`@
M("1C("X]('-P<FEN=&8H)R`E+C)F("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR
M9B!C)RP*("`@("`@("`@("`@("`@("`@("`@("1X("L@)&(L("1Y+`H@("`@
M("`@("`@("`@("`@("`@("`@)'@@*R`D<BP@)'D@+2`D<B`K("1B+`H@("`@
M("`@("`@("`@("`@("`@("`@)'@@*R`D<BP@)'D@+2`D<BD["B`@("`@("`@
M+RH@4V5T('@O>2!T;R!T:&4@9FEN86P@<&]I;G0N("HO"B`@("`@("`@)'@@
M/2`D>"`K("1R.PH@("`@("`@("1Y(#T@)'D@+2`D<CL*("`@("`@("`O*B!4
M:&ER9"!C:7)C;&4@<75A<G1E<BX@*B\*("`@("`@("`D8R`N/2!S<')I;G1F
M*"<@)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F("4N,F8@8R<L"B`@("`@("`@
M("`@("`@("`@("`@("`D>"P@)'D@+2`D8BP*("`@("`@("`@("`@("`@("`@
M("`@("1X("T@)'(@*R`D8BP@)'D@+2`D<BP*("`@("`@("`@("`@("`@("`@
M("`@("1X("T@)'(L("1Y("T@)'(I.PH@("`@("`@("\J(%-E="!X+WD@=&\@
M=&AE(&9I;F%L('!O:6YT+B`J+PH@("`@("`@("1X(#T@)'@@+2`D<CL*("`@
M("`@("`D>2`]("1Y("T@)'(["B`@("`@("`@+RH@1F]U<G1H(&-I<F-L92!Q
M=6%R=&5R+B`J+PH@("`@("`@("1C("X]('-P<FEN=&8H)R`E+C)F("4N,F8@
M)2XR9B`E+C)F("4N,F8@)2XR9B!C("5S)RP*("`@("`@("`@("`@("`@("`@
M("`@("1X("T@)&(L("1Y+`H@("`@("`@("`@("`@("`@("`@("`@)'@@+2`D
M<BP@)'D@*R`D<B`M("1B+`H@("`@("`@("`@("`@("`@("`@("`@)'@@+2`D
M<BP@)'D@*R`D<BP*("`@("`@("`@("`@("`@("`@("`@("1O<"D["B`@("`@
M("`@+RH@3W5T<'5T('1H92!W:&]L92!S=')I;F<N("HO"B`@("`@("`@)'1H
M:7,M/E]O=70H)&,I.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP;W)T<R!A
M(%1R=654>7!E(&]R(%1Y<&4Q(&9O;G0@86YD(&UA:V5S(&ET(&%V86EL86)L
M92X@270@:7,*("`@("`J(&YE8V5S<V%R>2!T;R!G96YE<F%T92!A(&9O;G0@
M9&5F:6YI=&EO;B!F:6QE(&9I<G-T('=I=&@@=&AE"B`@("`@*B!M86ME9F]N
M="YP:'`@=71I;&ET>2X*("`@("`J(%1H92!L;V-A=&EO;B!O9B!T:&4@9&5F
M:6YI=&EO;B!F:6QE("AA;F0@=&AE(&9O;G0@9FEL92!I='-E;&8@=VAE;@H@
M("`@("H@96UB961D:6YG*2!M=7-T(&)E(&9O=6YD(&%T('1H92!F=6QL('!A
M=&@@;F%M92!I;F-L=61E9"X*("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@
M("H@)'!D9BT^861D1F]N="@G0V]M:6,G+"`G22<I.PH@("`@("H@:7,@97%U
M:79A;&5N="!T;SH*("`@("`J("1P9&8M/F%D9$9O;G0H)T-O;6EC)RP@)TDG
M+"`G8V]M:6-I+G!H<"<I.PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&9A;6EL>2`@1F]N="!F86UI;'DN(%1H92!N86UE(&-A;B!B92!C:&]S96X@
M87)B:71R87)I;'DN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@($EF
M(&ET(&ES(&$@<W1A;F1A<F0@9F%M:6QY(&YA;64L(&ET('=I;&P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@;W9E<G)I9&4@=&AE(&-O<G)E<W!O
M;F1I;F<@9F]N="X*("`@("`J($!P87)A;2!S=')I;F<@)'-T>6QE("`@1F]N
M="!S='EL92X@4&]S<VEB;&4@=F%L=65S(&%R92`H8V%S90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!I;G-E;G-I=&EV92DZ"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!E;7!T>2!S=')I;F<Z(')E9W5L87(@
M*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!"
M.B!B;VQD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!).B!I
M=&%L:6,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M($))(&]R
M($E".B!B;VQD(&ET86QI8PH@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@
M("!4:&4@9F]N="!D969I;FET:6]N(&9I;&4N($)Y(&1E9F%U;'0L('1H92!N
M86UE(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&)U:6QT(&9R
M;VT@=&AE(&9A;6EL>2!A;F0@<W1Y;&4L(&EN(&QO=V5R(&-A<V4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@=VET:"!N;R!S<&%C92X*("`@("`J
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$9O;G0H)&9A;6EL>2P@)'-T>6QE(#T@)R<L("1F:6QE(#T@
M)R<I"B`@("!["B`@("`@("`@)&9A;6EL>2`]('-T<G1O;&]W97(H)&9A;6EL
M>2D["B`@("`@("`@:68@*"1F86UI;'D@/3T@)V%R:6%L)RD@>PH@("`@("`@
M("`@("`D9F%M:6QY(#T@)VAE;'9E=&EC82<["B`@("`@("`@?0H*("`@("`@
M("`D<W1Y;&4@/2!S=')T;W5P<&5R*"1S='EL92D["B`@("`@("`@:68@*"1S
M='EL92`]/2`G24(G*2!["B`@("`@("`@("`@("1S='EL92`]("="22<["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V9O;G1S6R1F86UI
M;'D@+B`D<W1Y;&5=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H<W!R:6YT9B@G1F]N="!A;')E861Y(&%D9&5D.B`E<R`E<R<L
M("1F86UI;'DL("1S='EL92DI.PH@("`@("`@('T*("`@("`@("!I9B`H)&9I
M;&4@/3T@)R<I('L*("`@("`@("`@("`@)&9I;&4@/2!S=')?<F5P;&%C92@G
M("<L("<G+"`D9F%M:6QY*2`N('-T<G1O;&]W97(H)'-T>6QE*2`N("<N<&AP
M)SL*("`@("`@("!]"B`@("`@("`@:6YC;'5D92@D9FEL92D["B`@("`@("`@
M:68@*"%I<W-E="@D;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=#;W5L9"!N;W0@:6YC;'5D92!F;VYT(&1E9FEN:71I
M;VX@9FEL92XG*3L*("`@("`@("!]"B`@("`@("`@)&D@/2!C;W5N="@D=&AI
M<RT^7V9O;G1S*2`K(#$["B`@("`@("`@)'1H:7,M/E]F;VYT<ULD9F%M:6QY
M("X@)'-T>6QE72`](&%R<F%Y*"=I)R`]/B`D:2P@)W1Y<&4G(#T^("1T>7!E
M+"`G;F%M92<@/3X@)&YA;64L("=D97-C)R`]/B`D9&5S8RP@)W5P)R`]/B`D
M=7`L("=U="<@/3X@)'5T+"`G8W<G(#T^("1C=RP@)V5N8R<@/3X@)&5N8RP@
M)V9I;&4G(#T^("1F:6QE*3L*("`@("`@("!I9B`H)&1I9F8I('L*("`@("`@
M("`@("`@+RH@4V5A<F-H(&5X:7-T:6YG(&5N8V]D:6YG<RX@*B\*("`@("`@
M("`@("`@)&0@/2`P.PH@("`@("`@("`@("`D;F(@/2!C;W5N="@D=&AI<RT^
M7V1I9F9S*3L*("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P]("1N8CL@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&EF9G-;)&E=
M(#T]("1D:69F*2!["B`@("`@("`@("`@("`@("`@("`@)&0@/2`D:3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&0@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@)&0@/2`D;F(@*R`Q.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D:69F<ULD9%T@/2`D9&EF9CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D=&AI<RT^7V9O;G1S6R1F86UI;'DN)'-T>6QE75LG9&EF9B==(#T@)&0[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D9FEL92D@>PH@("`@("`@("`@("!I
M9B`H)'1Y<&4@/3T@)U1R=654>7!E)RD@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]F;VYT7V9I;&5S6R1F:6QE72`](&%R<F%Y*"=L96YG=&@Q)R`]/B`D
M;W)I9VEN86QS:7IE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9F]N=%]F:6QE<ULD9FEL95T@/2!A<G)A>2@G;&5N
M9W1H,2<@/3X@)'-I>F4Q+"`G;&5N9W1H,B<@/3X@)'-I>F4R*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE(&9O;G0@=7-E9"!T;R!P<FEN="!C:&%R86-T97(@<W1R:6YG<RX@270@
M:7,@;6%N9&%T;W)Y('1O(&-A;&P*("`@("`J('1H:7,@;65T:&]D(&%T(&QE
M87-T(&]N8V4@8F5F;W)E('!R:6YT:6YG('1E>'0@;W(@=&AE(')E<W5L=&EN
M9PH@("`@("H@9&]C=6UE;G0@=V]U;&0@;F]T(&)E('9A;&ED+B!4:&4@9F]N
M="!C86X@8F4@96ET:&5R(&$@<W1A;F1A<F0@;VYE(&]R(&$*("`@("`J(&9O
M;G0@861D960@=FEA('1H92!&:6QE7U!$1CHZ861D1F]N="!M971H;V0N(%-T
M86YD87)D(&9O;G1S('5S92!7:6YD;W=S"B`@("`@*B!E;F-O9&EN9R!C<#$R
M-3(@*%=E<W1E<FX@175R;W!E*2X*("`@("`J(%1H92!M971H;V0@8V%N(&)E
M(&-A;&QE9"!B969O<F4@=&AE(&9I<G-T('!A9V4@:7,@8W)E871E9"!A;F0@
M=&AE(&9O;G0*("`@("`J(&ES(')E=&%I;F5D(&9R;VT@<&%G92!T;R!P86=E
M+@H@("`@("H@268@>6]U(&IU<W0@=VES:"!T;R!C:&%N9V4@=&AE(&-U<G)E
M;G0@9F]N="!S:7IE+"!I="!I<R!S:6UP;&5R('1O(&-A;&P*("`@("`J($9I
M;&5?4$1&.CIS971&;VYT4VEZ92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F86UI;'D@($9A;6EL>2!F;VYT+B!)="!C86X@8F4@96ET:&5R(&$@
M;F%M92!D969I;F5D(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M($9I;&5?4$1&.CIA9&1&;VYT(&]R(&]N92!O9B!T:&4@<W1A;F1A<F0@9F%M
M:6QI97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@*&-A<V4@:6YS
M96YS:71I=F4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@
M0V]U<FEE<B`H9FEX960M=VED=&@I"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@+2!(96QV971I8V$@;W(@07)I86P@*'-A;G,@<V5R:68I"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!4:6UE<R`H<V5R:68I
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!3>6UB;VP@*'-Y
M;6)O;&EC*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@6F%P
M9D1I;F=B871S("AS>6UB;VQI8RD*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@270@:7,@86QS;R!P;W-S:6)L92!T;R!P87-S(&%N(&5M<'1Y('-T
M<FEN9RX@26X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&AA="!C
M87-E+"!T:&4@8W5R<F5N="!F86UI;'D@:7,@<F5T86EN960N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S='EL92`@($9O;G0@<W1Y;&4N(%!O<W-I8FQE('9A
M;'5E<R!A<F4@*&-A<V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M:6YS96YS:71I=F4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("T@96UP='D@<W1R:6YG.B!R96=U;&%R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!".B!B;VQD"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@+2!).B!I=&%L:6,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`M(%4Z('5N9&5R;&EN90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!O<B!A;GD@8V]M8FEN871I;VXN(%1H92!D969A=6QT('9A;'5E
M(&ES(')E9W5L87(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@($)O
M;&0@86YD(&ET86QI8R!S='EL97,@9&\@;F]T(&%P<&QY('1O(%-Y;6)O;"!A
M;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@6F%P9D1I;F=B871S
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-I>F4@("!&;VYT('-I>F4@:6X@
M<&]I;G1S+B!4:&4@9&5F875L="!V86QU92!I<R!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@8W5R<F5N="!S:7IE+B!)9B!N;R!S:7IE(&AA
M<R!B965N('-P96-I9FEE9"!S:6YC90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@8F5G:6YN:6YG(&]F('1H92!D;V-U;65N="P@=&AE('9A
M;'5E('1A:V5N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&ES(#$R
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9O<F-E("!&;W)C92!T:&4@<V5T
M=&EN9R!O9B!T:&4@9F]N="X@16%C:"!N97<@<&%G92!W:6QL"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(')E<75I<F4@82!N97<@8V%L;"!T;R!&
M:6QE7U!$1CHZ<V5T1F]N="!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@<V5T=&EN9W,@=&AI<R!T;R!T<G5E('=I;&P@;6%K92!S=7)E('1H
M870@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-H96-K<R!F
M;W(@<V%M92!F;VYT(&-A;&QS('=I;&P@8F4@<VMI<'!E9"X*("`@("`J"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIA9&1&;VYT"B`@("`@*B!`<V5E($9I;&5?
M4$1&.CIS971&;VYT4VEZ90H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L;`H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CI7<FET90H@("`@("HO"B`@("!F=6YC=&EO;B!S971&;VYT*"1F
M86UI;'DL("1S='EL92`]("<G+"`D<VEZ92`](&YU;&PL("1F;W)C92`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1F86UI;'D@/2!S=')T;VQO=V5R*"1F86UI
M;'DI.PH@("`@("`@(&EF("@D9F%M:6QY(#T]("=A<FEA;"<I('L*("`@("`@
M("`@("`@+RH@57-E(&AE;'9E=&EC82!I;G-T96%D(&]F(&%R:6%L+B`J+PH@
M("`@("`@("`@("`D9F%M:6QY(#T@)VAE;'9E=&EC82<["B`@("`@("`@?2!E
M;'-E:68@*"1F86UI;'D@/3T@)W-Y;6)O;"<@?'P@)&9A;6EL>2`]/2`G>F%P
M9F1I;F=B871S)RD@>PH@("`@("`@("`@("`O*B!4:&5S92!T=V\@9F]N=',@
M9&\@;F]T(&AA=F4@<W1Y;&5S(&%V86EL86)L92X@*B\*("`@("`@("`@("`@
M)'-T>6QE(#T@)R<["B`@("`@("`@?0H*("`@("`@("`D<W1Y;&4@/2!S=')T
M;W5P<&5R*"1S='EL92D["@H@("`@("`@("\J(%5N9&5R;&EN92!I<R!H86YD
M;&5D('-E<&%R871E;'DL(&EF('-P96-I9FEE9"!I;B!T:&4@<W1Y;&4@=F%R
M"B`@("`@("`@("H@<F5M;W9E(&ET(&9R;VT@=&AE('-T>6QE(&%N9"!S970@
M=&AE('5N9&5R;&EN92!F;&%G+B`J+PH@("`@("`@(&EF("AS=')P;W,H)'-T
M>6QE+"`G52<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^7W5N
M9&5R;&EN92`]('1R=64["B`@("`@("`@("`@("1S='EL92`]('-T<E]R97!L
M86-E*"=5)RP@)R<L("1S='EL92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]U;F1E<FQI;F4@/2!F86QS93L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D<W1Y;&4@/3T@)TE")RD@>PH@("`@("`@("`@("`D<W1Y
M;&4@/2`G0DDG.PH@("`@("`@('T*"B`@("`@("`@+RH@268@;F\@<VEZ92!S
M<&5C:69I960L('5S92!C=7)R96YT('-I>F4N("HO"B`@("`@("`@:68@*&ES
M7VYU;&PH)'-I>F4I*2!["B`@("`@("`@("`@("1S:7IE(#T@)'1H:7,M/E]F
M;VYT7W-I>F5?<'0["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!F;VYT(')E
M<75E<W1E9"!I<R!A;')E861Y('1H92!C=7)R96YT(&9O;G0@86YD(&YO(&9O
M<F-E('-E='1I;F<*("`@("`@("`@*B!O9B!T:&4@9F]N="!I<R!R97%U97-T
M960@*&5G+B!W:&5N(&%D9&EN9R!A(&YE=R!P86=E*2!D;VXG="!B;W1H97(*
M("`@("`@("`@*B!W:71H('1H92!R97-T(&]F('1H92!F=6YC=&EO;B!A;F0@
M<VEM<&QY(')E='5R;BX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]F;VYT7V9A
M;6EL>2`]/2`D9F%M:6QY("8F("1T:&ES+3Y?9F]N=%]S='EL92`]/2`D<W1Y
M;&4@)B8*("`@("`@("`@("`@)'1H:7,M/E]F;VYT7W-I>F5?<'0@/3T@)'-I
M>F4@)B8@(21F;W)C92D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("`O*B!3970@=&AE(&9O;G0@:V5Y+B`J+PH@("`@("`@("1F
M;VYT:V5Y(#T@)&9A;6EL>2`N("1S='EL93L*"B`@("`@("`@+RH@5&5S="!I
M9B!A;')E861Y(&-A8VAE9"X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?9F]N='-;)&9O;G1K97E=*2D@>PH@("`@("`@("`@("`O*B!'970@=&AE
M(&-H87)A8W1E<B!W:61T:"!D969I;FET:6]N(&9I;&4N("HO"B`@("`@("`@
M("`@("1F;VYT7W=I9'1H<R`]("9&:6QE7U!$1CHZ7V=E=$9O;G1&:6QE*"1F
M;VYT:V5Y*3L*("`@("`@("`@("`@:68@*&ES7V$H)&9O;G1?=VED=&AS+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&9O;G1?
M=VED=&AS.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D:2`](&-O=6YT
M*"1T:&ES+3Y?9F]N=',I("L@,3L*("`@("`@("`@("`@)'1H:7,M/E]F;VYT
M<ULD9F]N=&ME>5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=I)R`@("`]
M/B`D:2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G8V]R92<L"B`@("`@
M("`@("`@("`@("`G;F%M92<@/3X@)'1H:7,M/E]C;W)E7V9O;G1S6R1F;VYT
M:V5Y72P*("`@("`@("`@("`@("`@("=U<"<@("`]/B`M,3`P+`H@("`@("`@
M("`@("`@("`@)W5T)R`@(#T^(#4P+`H@("`@("`@("`@("`@("`@)V-W)R`@
M(#T^("1F;VYT7W=I9'1H<ULD9F]N=&ME>5TI.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4W1O<F4@9F]N="!I;F9O<FUA=&EO;B!A<R!C=7)R96YT(&9O;G0N
M("HO"B`@("`@("`@)'1H:7,M/E]F;VYT7V9A;6EL>2`@/2`D9F%M:6QY.PH@
M("`@("`@("1T:&ES+3Y?9F]N=%]S='EL92`@(#T@)'-T>6QE.PH@("`@("`@
M("1T:&ES+3Y?9F]N=%]S:7IE7W!T(#T@)'-I>F4["B`@("`@("`@)'1H:7,M
M/E]F;VYT7W-I>F4@("`@/2`D<VEZ92`O("1T:&ES+3Y?<V-A;&4["B`@("`@
M("`@)'1H:7,M/E]C=7)R96YT7V9O;G0@/2`F)'1H:7,M/E]F;VYT<ULD9F]N
M=&ME>5T["@H@("`@("`@("\J($]U='!U="!F;VYT(&EN9F]R;6%T:6]N(&EF
M(&%T(&QE87-T(&]N92!P86=E(&AA<R!B965N(&1E9FEN960N("HO"B`@("`@
M("`@:68@*"1T:&ES+3Y?<&%G92`^(#`I('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H<W!R:6YT9B@G0E0@+T8E9"`E+C)F(%1F($54)RP@)'1H:7,M/E]C
M=7)R96YT7V9O;G1;)VDG72P@)'1H:7,M/E]F;VYT7W-I>F5?<'0I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$969I;F5S('1H92!S:7IE
M(&]F('1H92!C=7)R96YT(&9O;G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L
M;V%T("1S:7IE("!4:&4@<VEZ92`H:6X@<&]I;G1S*2X*("`@("`J"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$9O;G13:7IE*"1S:7IE*0H@("`@>PH@("`@("`@("\J($EF('1H92!F
M;VYT('-I>F4@:7,@86QR96%D>2!T:&4@8W5R<F5N="!F;VYT('-I>F4L(&IU
M<W0@<F5T=7)N+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V9O;G1?<VEZ95]P
M="`]/2`D<VEZ92D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@
M("`@("`@("\J(%-E="!T:&4@8W5R<F5N="!F;VYT('-I>F4L(&)O=&@@:6X@
M<&]I;G1S(&%N9"!S8V%L960@=&\@=7-E<@H@("`@("`@("`J('5N:71S+B`J
M+PH@("`@("`@("1T:&ES+3Y?9F]N=%]S:7IE7W!T(#T@)'-I>F4["B`@("`@
M("`@)'1H:7,M/E]F;VYT7W-I>F4@/2`D<VEZ92`O("1T:&ES+3Y?<V-A;&4[
M"@H@("`@("`@("\J($]U='!U="!F;VYT(&EN9F]R;6%T:6]N(&EF(&%T(&QE
M87-T(&]N92!P86=E(&AA<R!B965N(&1E9FEN960N("HO"B`@("`@("`@:68@
M*"1T:&ES+3Y?<&%G92`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M<W!R:6YT9B@G0E0@+T8E9"`E+C)F(%1F($54)RP@)'1H:7,M/E]C=7)R96YT
M7V9O;G1;)VDG72P@)'1H:7,M/E]F;VYT7W-I>F5?<'0I*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W(&EN=&5R;F%L
M(&QI;FL@86YD(')E='5R;G,@:71S(&ED96YT:69I97(N($%N(&EN=&5R;F%L
M"B`@("`@*B!L:6YK(&ES(&$@8VQI8VMA8FQE(&%R96$@=VAI8V@@9&ER96-T
M<R!T;R!A;F]T:&5R('!L86-E('=I=&AI;B!T:&4*("`@("`J(&1O8W5M96YT
M+@H@("`@("H@5&AE(&ED96YT:69I97(@8V%N('1H96X@8F4@<&%S<V5D('1O
M($9I;&5?4$1&.CIC96QL+"!&:6QE7U!$1CHZ=W)I=&4L"B`@("`@*B!&:6QE
M7U!$1CHZ:6UA9V4@;W(@1FEL95]01$8Z.FQI;FLN(%1H92!D97-T:6YA=&EO
M;B!I<R!D969I;F5D('=I=&@*("`@("`J($9I;&5?4$1&.CIS971,:6YK+@H@
M("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F-E;&P*("`@("`J($!S964@
M1FEL95]01$8Z.E=R:71E"B`@("`@*B!`<V5E($9I;&5?4$1&.CII;6%G90H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ3&EN:PH@("`@("H@0'-E92!&:6QE7U!$
M1CHZ4V5T3&EN:PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1,:6YK*"D*("`@
M('L*("`@("`@("`D;B`](&-O=6YT*"1T:&ES+3Y?;&EN:W,I("L@,3L*("`@
M("`@("`D=&AI<RT^7VQI;FMS6R1N72`](&%R<F%Y*#`L(#`I.PH@("`@("`@
M(')E='5R;B`D;CL*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE
M('!A9V4@86YD('!O<VET:6]N(&$@;&EN:R!P;VEN=',@=&\N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;FL@(%1H92!L:6YK(&ED96YT:69I
M97(@<F5T=7)N960@8GD@1FEL95]01$8Z.F%D9$QI;FLN"B`@("`@*B!`<&%R
M86T@9FQO870@)'D@("`@("`@3W)D:6YA=&4@;V8@=&%R9V5T('!O<VET:6]N
M.R`M,2!I;F1I8V%T97,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@8W5R<F5N="!P;W-I=&EO;BX@5&AE(&1E9F%U;'0@=F%L=64@:7,@,"`H
M=&]P(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%G92DN"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<&%G92`@3G5M8F5R(&]F('1A<F=E="!P
M86=E.R`M,2!I;F1I8V%T97,@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!P86=E+B!4:&ES(&ES('1H92!D969A=6QT('9A;'5E
M+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F%D9$QI;FL*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T3&EN:R@D;&EN:RP@)'D@/2`P+"`D<&%G92`]
M("TQ*0H@("`@>PH@("`@("`@(&EF("@D>2`]/2`M,2D@>PH@("`@("`@("`@
M("`D>2`]("1T:&ES+3YY.PH@("`@("`@('T*("`@("`@("!I9B`H)'!A9V4@
M/3T@+3$I('L*("`@("`@("`@("`@)'!A9V4@/2`D=&AI<RT^7W!A9V4["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?;&EN:W-;)&QI;FM=(#T@87)R87DH
M)'!A9V4L("1Y*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!U=',@82!L:6YK
M(&]N(&$@<F5C=&%N9W5L87(@87)E82!O9B!T:&4@<&%G92X@5&5X="!O<B!I
M;6%G92!L:6YK<R!A<F4*("`@("`J(&=E;F5R86QL>2!P=70@=FEA($9I;&5?
M4$1&.CIC96QL+"!&:6QE7U!$1CHZ5W)I=&4@;W(@1FEL95]01$8Z.FEM86=E
M+`H@("`@("H@8G5T('1H:7,@;65T:&]D(&-A;B!B92!U<V5F=6P@9F]R(&EN
M<W1A;F-E('1O(&1E9FEN92!A(&-L:6-K86)L92!A<F5A"B`@("`@*B!I;G-I
M9&4@86X@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("`@
M("`@($%B<V-I<W-A(&]F('1H92!U<'!E<BUL969T(&-O<FYE<B!O9B!T:&4@
M<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&9L;V%T("1Y("`@("`@($]R9&EN
M871E(&]F('1H92!U<'!E<BUL969T(&-O<FYE<B!O9B!T:&4@<F5C=&%N9VQE
M+@H@("`@("H@0'!A<F%M(&9L;V%T("1W:61T:"`@(%=I9'1H(&]F('1H92!R
M96-T86YG;&4N"B`@("`@*B!`<&%R86T@9FQO870@)&AE:6=H="`@2&5I9VAT
M(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@;6EX960@)&QI;FL@
M("`@55),(&]R(&ED96YT:69I97(@<F5T=7)N960@8GD@1FEL95]01$8Z.F%D
M9$QI;FLN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ861D3&EN:PH@
M("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L;`H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ5W)I=&4*("`@("`J($!S964@1FEL95]01$8Z.FEM86=E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QI;FLH)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1L
M:6YK*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@8V]O<F1I;F%T97,@
M=VET:"!C;W)R96-T('-C86QI;F<@:6X@<'0N("HO"B`@("`@("`@)'@@("`@
M("`]("1T:&ES+3Y?=&]0="@D>"D["B`@("`@("`@)'D@("`@("`]("1T:&ES
M+3YH4'0@+2`D=&AI<RT^7W1O4'0H)'DI.PH@("`@("`@("1W:61T:"`@/2`D
M=&AI<RT^7W1O4'0H)'=I9'1H*3L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M
M/E]T;U!T*"1H96EG:'0I.PH*("`@("`@("`O*B!3879E(&QI;FL@=&\@<&%G
M92!L:6YK<R!A<G)A>2X@*B\*("`@("`@("`D=&AI<RT^7VQI;FLH)'@L("1Y
M+"`D=VED=&@L("1H96EG:'0L("1L:6YK*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%!R:6YT<R!A(&-H87)A8W1E<B!S=')I;F<N(%1H92!O<FEG:6X@:7,@
M;VX@=&AE(&QE9G0@;V8@=&AE(&9I<G-T"B`@("`@*B!C:&%R86-T97(L(&]N
M('1H92!B87-E;&EN92X@5&AI<R!M971H;V0@86QL;W=S('1O('!L86-E(&$@
M<W1R:6YG"B`@("`@*B!P<F5C:7-E;'D@;VX@=&AE('!A9V4L(&)U="!I="!I
M<R!U<W5A;&QY(&5A<VEE<B!T;R!U<V4@1FEL95]01$8Z.F-E;&PL"B`@("`@
M*B!&:6QE7U!$1CHZ;75L=&E#96QL(&]R($9I;&5?4$1&.CI7<FET92!W:&EC
M:"!A<F4@=&AE('-T86YD87)D(&UE=&AO9',@=&\*("`@("`J('!R:6YT('1E
M>'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("`@("`@06)S8VES
M<V$@;V8@=&AE(&]R:6=I;BX*("`@("`J($!P87)A;2!F;&]A="`D>2`@("`@
M($]R9&EN871E(&]F('1H92!O<FEG:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("!3=')I;F<@=&\@<')I;G0N"B`@("`@*@H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ<V5T1F]N=`H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L;`H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CI7<FET90H@("`@("HO"B`@("!F=6YC=&EO;B!T97AT*"1X+"`D
M>2P@)'1E>'0I"B`@("!["B`@("`@("`@+RH@4V-A;&4@8V]O<F1I;F%T97,@
M:6YT;R!P;VEN=',@86YD('-E="!C;W)R96-T(%D@<&]S:71I;VXN("HO"B`@
M("`@("`@)'@@/2`D=&AI<RT^7W1O4'0H)'@I.PH@("`@("`@("1Y(#T@)'1H
M:7,M/FA0="`M("1T:&ES+3Y?=&]0="@D>2D["@H@("`@("`@("\J($5S8V%P
M92!A;GD@<&]T96YT:6%L;'D@:&%R;69U;"!C:&%R86-T97)S+B`J+PH@("`@
M("`@("1T97AT(#T@)'1H:7,M/E]E<V-A<&4H)'1E>'0I.PH*("`@("`@("`D
M;W5T(#T@<W!R:6YT9B@G0E0@)2XR9B`E+C)F(%1D("@E<RD@5&H@150G+"`D
M>"P@)'DL("1T97AT*3L*("`@("`@("!I9B`H)'1H:7,M/E]U;F1E<FQI;F4@
M)B8@)'1E>'0@(3T@)R<I('L*("`@("`@("`@("`@)&]U="`N/2`G("<@+B`D
M=&AI<RT^7V1O56YD97)L:6YE*"1X+"`D>2P@)'1E>'0I.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7V]U="@D;W5T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%=H96YE=F5R(&$@<&%G92!B<F5A:R!C;VYD:71I;VX@:7,@;65T+"!T
M:&4@;65T:&]D(&ES(&-A;&QE9"P@86YD('1H90H@("`@("H@8G)E86L@:7,@
M:7-S=65D(&]R(&YO="!D97!E;F1I;F<@;VX@=&AE(')E='5R;F5D('9A;'5E
M+B!4:&4@9&5F875L=`H@("`@("H@:6UP;&5M96YT871I;VX@<F5T=7)N<R!A
M('9A;'5E(&%C8V]R9&EN9R!T;R!T:&4@;6]D92!S96QE8W1E9"!B>0H@("`@
M("H@1FEL95]01$8Z<V5T075T;U!A9V5"<F5A:RX*("`@("`J(%1H:7,@;65T
M:&]D(&ES(&-A;&QE9"!A=71O;6%T:6-A;&QY(&%N9"!S:&]U;&0@;F]T(&)E
M(&-A;&QE9"!D:7)E8W1L>0H@("`@("H@8GD@=&AE(&%P<&QI8V%T:6]N+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("H*("`@("`J($!S
M964@1FEL95]01$8Z.G-E=$%U=&]086=E0G)E86LN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%C8V5P=%!A9V5"<F5A:R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?875T;U]P86=E7V)R96%K.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4')I;G1S(&$@8V5L;"`H<F5C=&%N9W5L87(@87)E82D@=VET:"!O<'1I
M;VYA;"!B;W)D97)S+"!B86-K9W)O=6YD"B`@("`@*B!C;VQO<B!A;F0@8VAA
M<F%C=&5R('-T<FEN9RX@5&AE('5P<&5R+6QE9G0@8V]R;F5R(&]F('1H92!C
M96QL"B`@("`@*B!C;W)R97-P;VYD<R!T;R!T:&4@8W5R<F5N="!P;W-I=&EO
M;BX@5&AE('1E>'0@8V%N(&)E(&%L:6=N960@;W(*("`@("`J(&-E;G1E<F5D
M+B!!9G1E<B!T:&4@8V%L;"P@=&AE(&-U<G)E;G0@<&]S:71I;VX@;6]V97,@
M=&\@=&AE(')I9VAT(&]R('1O"B`@("`@*B!T:&4@;F5X="!L:6YE+B!)="!I
M<R!P;W-S:6)L92!T;R!P=70@82!L:6YK(&]N('1H92!T97AT+@H@("`@("H@
M268@875T;VUA=&EC('!A9V4@8G)E86MI;F<@:7,@96YA8FQE9"!A;F0@=&AE
M(&-E;&P@9V]E<R!B97EO;F0@=&AE"B`@("`@*B!L:6UI="P@82!P86=E(&)R
M96%K(&ES(&1O;F4@8F5F;W)E(&]U='!U='1I;F<N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&9L;V%T("1W:61T:"`@($-E;&P@=VED=&@N($EF(#`L('1H92!C
M96QL(&5X=&5N9',@=7`@=&\@=&AE(')I9VAT"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@;6%R9VEN+@H@("`@("H@0'!A<F%M(&9L;V%T("1H96EG
M:'0@($-E;&P@:&5I9VAT+B!$969A=6QT('9A;'5E.B`P+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@(%-T<FEN9R!T;R!P<FEN="X@1&5F875L="!V
M86QU93H@96UP='DN"B`@("`@*B!`<&%R86T@;6EX960@)&)O<F1E<B`@26YD
M:6-A=&5S(&EF(&)O<F1E<G,@;75S="!B92!D<F%W;B!A<F]U;F0@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V5L;"X@5&AE('9A;'5E(&-A
M;B!B92!E:71H97(@82!N=6UB97(Z"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`M(#`Z(&YO(&)O<F1E<B`H9&5F875L="D*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("T@,3H@9G)A;64*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!O<B!A('-T<FEN9R!C;VYT86EN:6YG('-O;64@;W(@
M86QL(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&9O;&QO
M=VEN9R!C:&%R86-T97)S("AI;B!A;GD@;W)D97(I.@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!,.B!L969T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`M(%0Z('1O<`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@+2!2.B!R:6=H=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@+2!".B!B;W1T;VT*("`@("`J($!P87)A;2!I;G1E9V5R("1L;B`@
M("!);F1I8V%T97,@=VAE<F4@=&AE(&-U<G)E;G0@<&]S:71I;VX@<VAO=6QD
M(&=O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@869T97(@=&AE(&-A
M;&PN(%!O<W-I8FQE('9A;'5E<R!A<F4Z"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`M(#`Z('1O('1H92!R:6=H="`H9&5F875L="D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("T@,3H@=&\@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@;F5X="!L:6YE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`M(#(Z(&)E;&]W"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M4'5T=&EN9R`Q(&ES(&5Q=6EV86QE;G0@=&\@<'5T=&EN9R`P(&%N9"!C86QL
M:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@1FEL95]01$8Z.FYE
M=TQI;F4@:G5S="!A9G1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&%L:6=N
M("!!;&QO=W,@=&\@8V5N=&5R(&]R(&%L:6=N('1H92!T97AT+B!0;W-S:6)L
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($P@;W(@96UP='D@<W1R
M:6YG.B!L969T("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@+2!#.B!C96YT97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("T@4CH@<FEG:'0*("`@("`J($!P87)A;2!I;G1E9V5R("1F:6QL("!)
M;F1I8V%T97,@:68@=&AE(&-E;&P@9FEL;"!T>7!E+B!0;W-S:6)L92!V86QU
M97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!A<F4Z"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`M(#`Z('1R86YS<&%R96YT("AD969A
M=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`Q.B!P86EN
M=&5D"B`@("`@*B!`<&%R86T@<W1R:6YG("1L:6YK("`@55),(&]R(&ED96YT
M:69I97(@<F5T=7)N960@8GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!&:6QE7U!$1CIA9&1,:6YK+@H@("`@("H*("`@("`J($!S
M964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J($!S964@1FEL95]01$8Z.G-E
M=$1R87=#;VQO<@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1FEL;$-O;&]R
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971,:6YE5VED=&@*("`@("`J($!S
M964@1FEL95]01$8Z.F%D9$QI;FL*("`@("`J($!S964@1FEL95]01$8Z.FYE
M=TQI;F4*("`@("`J($!S964@1FEL95]01$8Z.FUU;'1I0V5L;`H@("`@("H@
M0'-E92!&:6QE7U!$1CHZ5W)I=&4*("`@("`J($!S964@1FEL95]01$8Z.G-E
M=$%U=&]086=E0G)E86L*("`@("`J+PH@("`@9G5N8W1I;VX@8V5L;"@D=VED
M=&@L("1H96EG:'0@/2`P+"`D=&5X="`]("<G+"`D8F]R9&5R(#T@,"P@)&QN
M(#T@,"P@)&%L:6=N(#T@)R<L("1F:6QL(#T@,"P@)&QI;FL@/2`G)RD*("`@
M('L*("`@("`@("`D:R`]("1T:&ES+3Y?<V-A;&4["B`@("`@("`@:68@*"1T
M:&ES+3YY("L@)&AE:6=H="`^("1T:&ES+3Y?<&%G95]B<F5A:U]T<FEG9V5R
M("8F("$D=&AI<RT^7VEN7V9O;W1E<B`F)B`D=&AI<RT^06-C97!T4&%G94)R
M96%K*"DI('L*("`@("`@("`@("`@)'@@/2`D=&AI<RT^>#L*("`@("`@("`@
M("`@)'=S(#T@)'1H:7,M/E]W;W)D7W-P86-I;F<["B`@("`@("`@("`@(&EF
M("@D=W,@/B`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W=O<F1?<W!A
M8VEN9R`](#`["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G,"!4=R<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YA9&1086=E*"1T
M:&ES+3Y?8W5R<F5N=%]O<FEE;G1A=&EO;BD["B`@("`@("`@("`@("1T:&ES
M+3YX(#T@)'@["B`@("`@("`@("`@(&EF("@D=W,@/B`P*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W=O<F1?<W!A8VEN9R`]("1W<SL*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)R4N,V8@5'<G+"`D=W,@*B`D
M:RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D=VED
M=&@@/3T@,"D@>PH@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^=R`M("1T
M:&ES+3Y?<FEG:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@("`@?0H@("`@
M("`@("1S(#T@)R<["B`@("`@("`@:68@*"1F:6QL(#T](#$@?'P@)&)O<F1E
M<B`]/2`Q*2!["B`@("`@("`@("`@(&EF("@D9FEL;"`]/2`Q*2!["B`@("`@
M("`@("`@("`@("`D;W`@/2`H)&)O<F1E<B`]/2`Q*2`_("=")R`Z("=F)SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1O<"`]("=3
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<R`]('-P<FEN=&8H)R4N
M,F8@)2XR9B`E+C)F("4N,F8@<F4@)7,@)RP@)'1H:7,M/G@@*B`D:RP@*"1T
M:&ES+3YH("T@)'1H:7,M/GDI("H@)&LL("1W:61T:"`J("1K+"`M)&AE:6=H
M="`J("1K+"`D;W`I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?<W1R:6YG
M*"1B;W)D97(I*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H)&)O<F1E<BP@
M)TPG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1S("X]('-P<FEN
M=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR9B!L(%,@)RP@)'1H:7,M/G@@*B`D
M:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI("H@)&LL("1T:&ES+3YX("H@)&LL
M("@D=&AI<RT^:"`M("@D=&AI<RT^>2`K("1H96EG:'0I*2`J("1K*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1B;W)D97(L("=4
M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<R`N/2!S<')I;G1F
M*"<E+C)F("4N,F8@;2`E+C)F("4N,F8@;"!3("<L("1T:&ES+3YX("H@)&LL
M("@D=&AI<RT^:"`M("1T:&ES+3YY*2`J("1K+"`H)'1H:7,M/G@@*R`D=VED
M=&@I("H@)&LL("@D=&AI<RT^:"`M("1T:&ES+3YY*2`J("1K*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1B;W)D97(L("=2)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<R`N/2!S<')I;G1F*"<E
M+C)F("4N,F8@;2`E+C)F("4N,F8@;"!3("<L("@D=&AI<RT^>"`K("1W:61T
M:"D@*B`D:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI("H@)&LL("@D=&AI<RT^
M>"`K("1W:61T:"D@*B`D:RP@*"1T:&ES+3YH("T@*"1T:&ES+3YY("L@)&AE
M:6=H="DI("H@)&LI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS
M=')P;W,H)&)O<F1E<BP@)T(G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("1S("X]('-P<FEN=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR9B!L(%,@
M)RP@)'1H:7,M/G@@*B`D:RP@*"1T:&ES+3YH("T@*"1T:&ES+3YY("L@)&AE
M:6=H="DI("H@)&LL("@D=&AI<RT^>"`K("1W:61T:"D@*B`D:RP@*"1T:&ES
M+3YH("T@*"1T:&ES+3YY("L@)&AE:6=H="DI("H@)&LI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D=&5X="`A/2`G)RD@>PH@("`@
M("`@("`@("!I9B`H)&%L:6=N(#T]("=2)RD@>PH@("`@("`@("`@("`@("`@
M)&1X(#T@)'=I9'1H("T@)'1H:7,M/E]C96QL7VUA<F=I;B`M("1T:&ES+3YG
M9713=')I;F=7:61T:"@D=&5X="D["B`@("`@("`@("`@('T@96QS96EF("@D
M86QI9VX@/3T@)T,G*2!["B`@("`@("`@("`@("`@("`D9'@@/2`H)'=I9'1H
M("T@)'1H:7,M/F=E=%-T<FEN9U=I9'1H*"1T97AT*2D@+R`R.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1X(#T@)'1H:7,M/E]C
M96QL7VUA<F=I;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&5X="`]
M('-T<E]R97!L86-E*"<I)RP@)UQ<*2<L('-T<E]R97!L86-E*"<H)RP@)UQ<
M*"<L('-T<E]R97!L86-E*"=<7"<L("=<7%Q<)RP@)'1E>'0I*2D["B`@("`@
M("`@("`@("1T97-T,B`]("@H+C4@*B`D:&5I9VAT*2`K("@N,R`J("1T:&ES
M+3Y?9F]N=%]S:7IE*2D["B`@("`@("`@("`@("1T97-T,2`]("1T:&ES+3YF
M:%!T("T@*"@D=&AI<RT^>2`K("1T97-T,BD@*B`D:RD["B`@("`@("`@("`@
M("1S("X]('-P<FEN=&8H)T)4("4N,F8@)2XR9B!49"`H)7,I(%1J($54)RP@
M*"1T:&ES+3YX("L@)&1X*2`J("1K+"`H)'1H:7,M/F@@+2`H)'1H:7,M/GD@
M*R`N-2`J("1H96EG:'0@*R`N,R`J("1T:&ES+3Y?9F]N=%]S:7IE*2D@*B`D
M:RP@)'1E>'0I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]U;F1E<FQI;F4I
M('L*("`@("`@("`@("`@("`@("1S("X]("<@)R`N("1T:&ES+3Y?9&]5;F1E
M<FQI;F4H)'1H:7,M/G@@*R`D9'@L("1T:&ES+3YY("L@+C4@*B`D:&5I9VAT
M("L@+C,@*B`D=&AI<RT^7V9O;G1?<VEZ92P@)'1E>'0I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D;&EN:RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FQI;FLH)'1H:7,M/G@@*R`D9'@L("1T:&ES+3YY("L@+C4@*B`D
M:&5I9VAT+2XU("H@)'1H:7,M/E]F;VYT7W-I>F4L("1T:&ES+3YG9713=')I
M;F=7:61T:"@D=&5X="DL("1T:&ES+3Y?9F]N=%]S:7IE+"`D;&EN:RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1S*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"1S*3L*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/E]L87-T7VAE:6=H="`]("1H96EG:'0["B`@("`@("`@:68@*"1L;B`^
M(#`I('L*("`@("`@("`@("`@+RH@1V\@=&\@;F5X="!L:6YE+B`J+PH@("`@
M("`@("`@("`D=&AI<RT^>2`K/2`D:&5I9VAT.PH@("`@("`@("`@("!I9B`H
M)&QN(#T](#$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YX(#T@)'1H:7,M
M/E]L969T7VUA<F=I;CL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YX("L]("1W:61T:#L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO9"!A;&QO=W,@<')I;G1I
M;F<@=&5X="!W:71H(&QI;F4@8G)E86MS+B!4:&5Y(&-A;B!B90H@("`@("H@
M875T;VUA=&EC("AA<R!S;V]N(&%S('1H92!T97AT(')E86-H97,@=&AE(')I
M9VAT(&)O<F1E<B!O9B!T:&4@8V5L;"D@;W(*("`@("`J(&5X<&QI8VET("AV
M:6$@=&AE(%QN(&-H87)A8W1E<BDN($%S(&UA;GD@8V5L;',@87,@;F5C97-S
M87)Y(&%R92!O=71P=70L"B`@("`@*B!O;F4@8F5L;W<@=&AE(&]T:&5R+@H@
M("`@("H@5&5X="!C86X@8F4@86QI9VYE9"P@8V5N=&5R960@;W(@:G5S=&EF
M:65D+B!4:&4@8V5L;"!B;&]C:R!C86X@8F4*("`@("`J(&9R86UE9"!A;F0@
M=&AE(&)A8VMG<F]U;F0@<&%I;G1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M9FQO870@)'=I9'1H("`@5VED=&@@;V8@8V5L;',N($EF(#`L('1H97D@97AT
M96YD('5P('1O('1H92!R:6=H=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&UA<F=I;B!O9B!T:&4@<&%G92X*("`@("`J($!P87)A;2!F;&]A="`D
M:&5I9VAT("!(96EG:'0@;V8@8V5L;',N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("`@4W1R:6YG('1O('!R:6YT+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1B;W)D97(@($EN9&EC871E<R!I9B!B;W)D97)S(&UU<W0@8F4@9')A=VX@
M87)O=6YD('1H92!C96QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M8FQO8VLN(%1H92!V86QU92!C86X@8F4@96ET:&5R(&$@;G5M8F5R.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`P.B!N;R!B;W)D97(@*&1E
M9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#$Z(&9R
M86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;W(@82!S=')I;F<@
M8V]N=&%I;FEN9R!S;VUE(&]R(&%L;"!O9B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!F;VQL;W=I;F<@8VAA<F%C=&5R<R`H:6X@86YY(&]R
M9&5R*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M($PZ(&QE
M9G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M(%0Z('1O<`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@4CH@<FEG:'0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M($(Z(&)O='1O;0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D86QI9VX@(%-E=',@=&AE('1E>'0@86QI9VYM
M96YT+B!0;W-S:6)L92!V86QU97,@87)E.@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!,.B!L969T(&%L:6=N;65N=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!#.B!C96YT97(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("T@4CH@<FEG:'0@86QI9VYM96YT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`M($HZ(&IU<W1I9FEC871I;VX@*&1E
M9F%U;'0@=F%L=64I"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9FEL;"`@26YD
M:6-A=&5S(&EF('1H92!C96QL(&)A8VMG<F]U;F0@;75S=#H*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@,#H@=')A;G-P87)E;G0@*&1E9F%U
M;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#$Z('!A:6YT
M960*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIS971$<F%W0V]L;W(*("`@("`J($!S964@1FEL
M95]01$8Z.G-E=$9I;&Q#;VQO<@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T
M3&EN95=I9'1H"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC96QL"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIW<FET90H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T
M075T;U!A9V5"<F5A:PH@("`@("HO"B`@("!F=6YC=&EO;B!M=6QT:4-E;&PH
M)'=I9'1H+"`D:&5I9VAT+"`D=&5X="P@)&)O<F1E<B`](#`L("1A;&EG;B`]
M("=*)RP@)&9I;&P@/2`P*0H@("`@>PH@("`@("`@("1C=R`]("8D=&AI<RT^
M7V-U<G)E;G1?9F]N=%LG8W<G73L*("`@("`@("!I9B`H)'=I9'1H(#T](#`I
M('L*("`@("`@("`@("`@)'=I9'1H(#T@)'1H:7,M/G<@+2`D=&AI<RT^7W)I
M9VAT7VUA<F=I;B`M("1T:&ES+3YX.PH@("`@("`@('T*("`@("`@("`D=VUA
M>"`]("@D=VED=&@M,B`J("1T:&ES+3Y?8V5L;%]M87)G:6XI("H@,3`P,"`O
M("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("1S(#T@<W1R7W)E<&QA8V4H
M(EQR(BP@)R<L("1T97AT*3L*("`@("`@("`D;F(@/2!S=')L96XH)',I.PH@
M("`@("`@(&EF("@D;F(@/B`P("8F("1S6R1N8BTQ72`]/2`B7&XB*2!["B`@
M("`@("`@("`@("1N8BTM.PH@("`@("`@('T*("`@("`@("`D8B`](#`["B`@
M("`@("`@:68@*"1B;W)D97(I('L*("`@("`@("`@("`@:68@*"1B;W)D97(@
M/3T@,2D@>PH@("`@("`@("`@("`@("`@)&)O<F1E<B`]("=,5%)")SL*("`@
M("`@("`@("`@("`@("1B(#T@)TQ25"<["B`@("`@("`@("`@("`@("`D8C(@
M/2`G3%(G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&(R(#T@)R<["B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1B;W)D97(L
M("=,)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&(R("X]
M("=,)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AS
M=')P;W,H)&)O<F1E<BP@)U(G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("`@("`D8C(@+CT@)U(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&(@/2`H<W1R<&]S*"1B;W)D97(L("=4)RD@(3T](&9A;'-E
M*2`_("1B,B`N("=4)R`Z("1B,CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("`D<V5P(#T@+3$["B`@("`@("`@)&D@("`](#`["B`@("`@("`@
M)&H@("`](#`["B`@("`@("`@)&P@("`](#`["B`@("`@("`@)&YS("`](#`[
M"B`@("`@("`@)&YL("`](#$["B`@("`@("`@=VAI;&4@*"1I(#P@)&YB*2![
M"B`@("`@("`@("`@("\J($=E="!N97AT(&-H87)A8W1E<BX@*B\*("`@("`@
M("`@("`@)&,@/2`D<ULD:5T["B`@("`@("`@("`@(&EF("@D8R`]/2`B7&XB
M*2!["B`@("`@("`@("`@("`@("`O*B!%>'!L:6-I="!L:6YE(&)R96%K+B`J
M+PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?=V]R9%]S<&%C:6YG(#X@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=V]R9%]S<&%C:6YG
M(#T@,#L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G,"!4=R<I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/F-E
M;&PH)'=I9'1H+"`D:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2TD:BDL("1B
M+"`R+"`D86QI9VXL("1F:6QL*3L*("`@("`@("`@("`@("`@("1I*RL["B`@
M("`@("`@("`@("`@("`D<V5P(#T@+3$["B`@("`@("`@("`@("`@("`D:B`]
M("1I.PH@("`@("`@("`@("`@("`@)&P@/2`P.PH@("`@("`@("`@("`@("`@
M)&YS(#T@,#L*("`@("`@("`@("`@("`@("1N;"LK.PH@("`@("`@("`@("`@
M("`@:68@*"1B;W)D97(@)B8@)&YL(#T](#(I('L*("`@("`@("`@("`@("`@
M("`@("`D8B`]("1B,CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M8R`]/2`G("<I('L*("`@("`@("`@("`@("`@("1S97`@/2`D:3L*("`@("`@
M("`@("`@("`@("1L<R`]("1L.PH@("`@("`@("`@("`@("`@)&YS*RL["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&P@*ST@)&-W6R1C73L*("`@("`@
M("`@("`@:68@*"1L(#X@)'=M87@I('L*("`@("`@("`@("`@("`@("\J($%U
M=&]M871I8R!L:6YE(&)R96%K+B`J+PH@("`@("`@("`@("`@("`@:68@*"1S
M97`@/3T@+3$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&D@/3T@)&HI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?=V]R
M9%]S<&%C:6YG(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W=O<F1?<W!A8VEN9R`](#`["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;W5T*"<P(%1W)RD["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H
M="P@<W5B<W1R*"1S+"`D:BP@)&D@+2`D:BDL("1B+"`R+"`D86QI9VXL("1F
M:6QL*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1A;&EG;B`]/2`G2B<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]W;W)D7W-P86-I;F<@/2`H)&YS/C$I(#\@*"1W;6%X
M("T@)&QS*2\Q,#`P("H@)'1H:7,M/E]F;VYT7W-I>F4@+R`H)&YS("T@,2D@
M.B`P.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="AS<')I
M;G1F*"<E+C-F(%1W)RP@)'1H:7,M/E]W;W)D7W-P86-I;F<@*B`D=&AI<RT^
M7W-C86QE*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H="P@<W5B<W1R*"1S
M+"`D:BP@)'-E<"`M("1J*2P@)&(L(#(L("1A;&EG;BP@)&9I;&PI.PH@("`@
M("`@("`@("`@("`@("`@("1I(#T@)'-E<"`K(#$["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D<V5P(#T@+3$["B`@("`@("`@("`@("`@
M("`D:B`]("1I.PH@("`@("`@("`@("`@("`@)&P@/2`P.PH@("`@("`@("`@
M("`@("`@)&YS(#T@,#L*("`@("`@("`@("`@("`@("1N;"LK.PH@("`@("`@
M("`@("`@("`@:68@*"1B;W)D97(@)B8@)&YL(#T](#(I('L*("`@("`@("`@
M("`@("`@("`@("`D8B`]("1B,CL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@+RH@3&%S="!C:'5N:RX@*B\*("`@
M("`@("!I9B`H)'1H:7,M/E]W;W)D7W-P86-I;F<@/B`P*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?=V]R9%]S<&%C:6YG(#T@,#L*("`@("`@("`@("`@)'1H
M:7,M/E]O=70H)S`@5'<G*3L*("`@("`@("!]"B`@("`@("`@:68@*"1B;W)D
M97(@)B8@<W1R<&]S*"1B;W)D97(L("=")RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1B("X]("=")SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F-E
M;&PH)'=I9'1H+"`D:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2DL("1B+"`R
M+"`D86QI9VXL("1F:6QL*3L*("`@("`@("`D=&AI<RT^>"`]("1T:&ES+3Y?
M;&5F=%]M87)G:6X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO
M9"!P<FEN=',@=&5X="!F<F]M('1H92!C=7)R96YT('!O<VET:6]N+B!7:&5N
M('1H92!R:6=H=`H@("`@("H@;6%R9VEN(&ES(')E86-H960@*&]R('1H92!<
M;B!C:&%R86-T97(@:7,@;65T*2!A(&QI;F4@8G)E86L@;V-C=7)S(&%N9`H@
M("`@("H@=&5X="!C;VYT:6YU97,@9G)O;2!T:&4@;&5F="!M87)G:6XN(%5P
M;VX@;65T:&]D(&5X:70L('1H92!C=7)R96YT"B`@("`@*B!P;W-I=&EO;B!I
M<R!L969T(&IU<W0@870@=&AE(&5N9"!O9B!T:&4@=&5X="X*("`@("`J($ET
M(&ES('!O<W-I8FQE('1O('!U="!A(&QI;FL@;VX@=&AE('1E>'0N"B`@("`@
M*@H@("`@("H@17AA;7!L93H*("`@("`J("\O0F5G:6X@=VET:"!R96=U;&%R
M(&9O;G0*("`@("`J("1P9&8M/G-E=$9O;G0H)T%R:6%L)RPG)RPQ-"D["B`@
M("`@*B`D<&1F+3YW<FET92@U+"=6:7-I="`G*3L*("`@("`J("\O5&AE;B!P
M=70@82!B;'5E('5N9&5R;&EN960@;&EN:PH@("`@("H@)'!D9BT^<V5T5&5X
M=$-O;&]R*#`L,"PR-34I.PH@("`@("H@)'!D9BT^<V5T1F]N="@G)RPG52<I
M.PH@("`@("H@)'!D9BT^=W)I=&4H-2PG=W=W+F9P9&8N;W)G)RPG:'1T<#HO
M+W=W=RYF<&1F+F]R9R<I.PH@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D
M:&5I9VAT("!,:6YE(&AE:6=H="X*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@("!3=')I;F<@=&\@<')I;G0N"B`@("`@*B!`<&%R86T@;6EX960@)&QI
M;FL@("`@55),(&]R(&ED96YT:69I97(@<F5T=7)N960@8GD@061D3&EN:R@I
M+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J
M($!S964@1FEL95]01$8Z.F%D9$QI;FL*("`@("`J($!S964@1FEL95]01$8Z
M.FUU;'1I0V5L;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T075T;U!A9V5"
M<F5A:PH@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D:&5I9VAT+"`D=&5X
M="P@)&QI;FL@/2`G)RD*("`@('L*("`@("`@("`D8W<@/2`F)'1H:7,M/E]C
M=7)R96YT7V9O;G1;)V-W)UT["B`@("`@("`@)'=I9'1H(#T@)'1H:7,M/G<@
M+2`D=&AI<RT^7W)I9VAT7VUA<F=I;B`M("1T:&ES+3YX.PH@("`@("`@("1W
M;6%X(#T@*"1W:61T:"`M(#(@*B`D=&AI<RT^7V-E;&Q?;6%R9VEN*2`J(#$P
M,#`@+R`D=&AI<RT^7V9O;G1?<VEZ93L*("`@("`@("`D<R`]('-T<E]R97!L
M86-E*")<<B(L("<G+"`D=&5X="D["B`@("`@("`@)&YB(#T@<W1R;&5N*"1S
M*3L*("`@("`@("`D<V5P(#T@+3$["B`@("`@("`@)&D@/2`P.PH@("`@("`@
M("1J(#T@,#L*("`@("`@("`D;"`](#`["B`@("`@("`@)&YL(#T@,3L*("`@
M("`@("!W:&EL92`H)&D@/"`D;F(I('L*("`@("`@("`@("`@+RH@1V5T(&YE
M>'0@8VAA<F%C=&5R+B`J+PH@("`@("`@("`@("`D8R`]("1S>R1I?3L*("`@
M("`@("`@("`@:68@*"1C(#T](")<;B(I('L*("`@("`@("`@("`@("`@("\J
M($5X<&QI8VET(&QI;F4@8G)E86LN("HO"B`@("`@("`@("`@("`@("`D=&AI
M<RT^8V5L;"@D=VED=&@L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL("1I("T@
M)&HI+"`P+"`R+"`G)RP@,"P@)&QI;FLI.PH@("`@("`@("`@("`@("`@)&DK
M*SL*("`@("`@("`@("`@("`@("1S97`@/2`M,3L*("`@("`@("`@("`@("`@
M("1J(#T@)&D["B`@("`@("`@("`@("`@("`D;"`](#`["B`@("`@("`@("`@
M("`@("!I9B`H)&YL(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X["B`@("`@("`@("`@("`@("`@
M("`@)'=I9'1H(#T@)'1H:7,M/G<@+2`D=&AI<RT^7W)I9VAT7VUA<F=I;B`M
M("1T:&ES+3YX.PH@("`@("`@("`@("`@("`@("`@("1W;6%X(#T@*"1W:61T
M:"`M(#(@*B`D=&AI<RT^7V-E;&Q?;6%R9VEN*2`J(#$P,#`@+R`D=&AI<RT^
M7V9O;G1?<VEZ93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1N;"LK.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1C(#T]("<@)RD@>PH@("`@("`@("`@("`@
M("`@)'-E<"`]("1I.PH@("`@("`@("`@("`@("`@)&QS(#T@)&P["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&P@*ST@)&-W6R1C73L*("`@("`@("`@
M("`@:68@*"1L(#X@)'=M87@I('L*("`@("`@("`@("`@("`@("\J($%U=&]M
M871I8R!L:6YE(&)R96%K+B`J+PH@("`@("`@("`@("`@("`@:68@*"1S97`@
M/3T@+3$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/G@@/B`D
M=&AI<RT^7VQE9G1?;6%R9VEN*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("\J($UO=F4@=&\@;F5X="!L:6YE+B`J+PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YY("L]("1H96EG:'0["B`@("`@("`@
M("`@("`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YW("T@)'1H:7,M/E]R
M:6=H=%]M87)G:6X@+2`D=&AI<RT^>#L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'=M87@@/2`H)'=I9'1H("T@,B`J("1T:&ES+3Y?8V5L;%]M87)G:6XI
M("H@,3`P,"`O("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@("`D;FPK*SL*
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@D:2`]/2`D:BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V5L;"@D=VED
M=&@L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL("1I("T@)&HI+"`P+"`R+"`G
M)RP@,"P@)&QI;FLI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^8V5L;"@D=VED=&@L("1H96EG:'0L('-U
M8G-T<B@D<RP@)&HL("1S97`@+2`D:BDL(#`L(#(L("<G+"`P+"`D;&EN:RD[
M"B`@("`@("`@("`@("`@("`@("`@)&D@/2`D<V5P("L@,3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1S97`@/2`M,3L*("`@("`@("`@
M("`@("`@("1J(#T@)&D["B`@("`@("`@("`@("`@("`D;"`](#`["B`@("`@
M("`@("`@("`@("!I9B`H)&YL(#T](#$I('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X["B`@("`@("`@("`@
M("`@("`@("`@)'=I9'1H(#T@)'1H:7,M/G<@+2`D=&AI<RT^7W)I9VAT7VUA
M<F=I;B`M("1T:&ES+3YX.PH@("`@("`@("`@("`@("`@("`@("1W;6%X(#T@
M*"1W:61T:"`M(#(@*B`D=&AI<RT^7V-E;&Q?;6%R9VEN*2`J(#$P,#`@+R`D
M=&AI<RT^7V9O;G1?<VEZ93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1N;"LK.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4*
M("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@?0H@("`@("`@("\J($QA
M<W0@8VAU;FLN("HO"B`@("`@("`@:68@*"1I("$]("1J*2!["B`@("`@("`@
M("`@("1T:&ES+3YC96QL*"1L("\@,3`P,"`J("1T:&ES+3Y?9F]N=%]S:7IE
M+"`D:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2DL(#`L(#`L("<G+"`P+"`D
M;&EN:RD["B`@("`@("`@?0H@("`@?0H*("`@("`O*BH*("`@("`J('=R:71E
M(%)O=&%T960@5&5X="X*("`@("`J"B`@("`@*B!7<FET92!T97AT(&%T(&%N
M(&%N9VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@
M("`@6"!C;V]R9&EN871E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@
M("`@("!9(&-O;W)D:6YA=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT
M("`@("`@(%1E>'0@=&\@=W)I=&4N"B`@("`@*B!`<&%R86T@9FQO870@)'1E
M>'1?86YG;&4@($%N9VQE('1O(')O=&%T92`H16<N(#DP(#T@8F]T=&]M('1O
M('1O<"DN"B`@("`@*B!`<&%R86T@9FQO870@)&9O;G1?86YG;&4@(%)O=&%T
M92!C:&%R86-T97)S(&%S('=E;&P@87,@=&5X="X*("`@("`J"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B\*("`@("!F=6YC=&EO;B!W
M<FET95)O=&%T960H)'@L("1Y+"`D=&5X="P@)'1E>'1?86YG;&4L("1F;VYT
M7V%N9VQE(#T@,"D*("`@("!["B`@("`@("`@("\J($5S8V%P92!T97AT+B`J
M+PH@("`@("`@("`D=&5X="`]("1T:&ES+3Y?97-C87!E*"1T97AT*3L*"B`@
M("`@("`@("1F;VYT7V%N9VQE("L](#DP("L@)'1E>'1?86YG;&4["B`@("`@
M("`@("1T97AT7V%N9VQE("H]($U?4$D@+R`Q.#`["B`@("`@("`@("1F;VYT
M7V%N9VQE("H]($U?4$D@+R`Q.#`["@H@("`@("`@("`D=&5X=%]D>"`](&-O
M<R@D=&5X=%]A;F=L92D["B`@("`@("`@("1T97AT7V1Y(#T@<VEN*"1T97AT
M7V%N9VQE*3L*("`@("`@("`@)&9O;G1?9'@@/2!C;W,H)&9O;G1?86YG;&4I
M.PH@("`@("`@("`D9F]N=%]D>2`]('-I;B@D9F]N=%]A;F=L92D["@H@("`@
M("`@("`D<ST@<W!R:6YT9B@G0E0@)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F
M("4N,F8@5&T@*"5S*2!4:B!%5"<L"B`@("`@("`@("`@("`@("`@("`@("1T
M97AT7V1X+"`D=&5X=%]D>2P@)&9O;G1?9'@L("1F;VYT7V1Y+`H@("`@("`@
M("`@("`@("`@("`@("`D>"`J("1T:&ES+3Y?<V-A;&4L("@D=&AI<RT^:"TD
M>2D@*B`D=&AI<RT^7W-C86QE+"`D=&5X="D["@H@("`@("`@("!I9B`H("1T
M:&ES+3Y?9')A=U]C;VQO<BD@>PH@("`@("`@("`@("`@)',])W$@)R`N("1T
M:&ES+3Y?9')A=U]C;VQO<B`N("<@)R`N("1S("X@)R!1)SL*("`@("`@("`@
M?0H@("`@("`@("`D=&AI<RT^7V]U="@D<RD["B`@("`@?0H*("`@("\J*@H@
M("`@("H@4')I;G1S(&%N(&EM86=E(&EN('1H92!P86=E+B!4:&4@=7!P97(M
M;&5F="!C;W)N97(@86YD(&%T(&QE87-T(&]N92!O9@H@("`@("H@=&AE(&1I
M;65N<VEO;G,@;75S="!B92!S<&5C:69I960[('1H92!H96EG:'0@;W(@=&AE
M('=I9'1H(&-A;B!B90H@("`@("H@8V%L8W5L871E9"!A=71O;6%T:6-A;&QY
M(&EN(&]R9&5R('1O(&ME97`@=&AE(&EM86=E('!R;W!O<G1I;VYS+@H@("`@
M("H@4W5P<&]R=&5D(&9O<FUA=',@87)E($I014<@86YD(%!.1RX*("`@("`J
M"B`@("`@*B!&;W(@2E!%1RP@86QL(&9L879O<G,@87)E(&%L;&]W960Z"B`@
M("`@*B`@("T@9W)A>2!S8V%L97,*("`@("`J("`@+2!T<G5E(&-O;&]R<R`H
M,C0@8FET<RD*("`@("`J("`@+2!#35E+("@S,B!B:71S*0H@("`@("H*("`@
M("`J($9O<B!03D<L(&%R92!A;&QO=V5D.@H@("`@("H@("`M(&=R87D@<V-A
M;&5S(&]N(&%T(&UO<W0@."!B:71S("@R-38@;&5V96QS*0H@("`@("H@("`M
M(&EN9&5X960@8V]L;W)S"B`@("`@*B`@("T@=')U92!C;VQO<G,@*#(T(&)I
M=',I"B`@("`@*B!B=70@87)E(&YO="!S=7!P;W)T960Z"B`@("`@*B`@("T@
M26YT97)L86-I;F<*("`@("`J("`@+2!!;'!H82!C:&%N;F5L"B`@("`@*@H@
M("`@("H@268@82!T<F%N<W!A<F5N="!C;VQO<B!I<R!D969I;F5D+"!I="!W
M:6QL(&)E('1A:V5N(&EN=&\@86-C;W5N="`H8G5T"B`@("`@*B!W:6QL(&)E
M(&]N;'D@:6YT97)P<F5T960@8GD@06-R;V)A="`T(&%N9"!A8F]V92DN"B`@
M("`@*B!4:&4@9F]R;6%T(&-A;B!B92!S<&5C:69I960@97AP;&EC:71L>2!O
M<B!I;F9E<G)E9"!F<F]M('1H92!F:6QE"B`@("`@*B!E>'1E;G-I;VXN"B`@
M("`@*B!)="!I<R!P;W-S:6)L92!T;R!P=70@82!L:6YK(&]N('1H92!I;6%G
M92X*("`@("`J"B`@("`@*B!296UA<FLZ(&EF(&%N(&EM86=E(&ES('5S960@
M<V5V97)A;"!T:6UE<RP@;VYL>2!O;F4@8V]P>2!W:6QL(&)E"B`@("`@*B!E
M;6)E9&1E9"!I;B!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F:6QE("`@3F%M92!O9B!T:&4@9FEL92!C;VYT86EN:6YG('1H92!I
M;6%G92X*("`@("`J($!P87)A;2!F;&]A="`D>"`@("`@("!!8G-C:7-S82!O
M9B!T:&4@=7!P97(M;&5F="!C;W)N97(N"B`@("`@*B!`<&%R86T@9FQO870@
M)'D@("`@("`@3W)D:6YA=&4@;V8@=&AE('5P<&5R+6QE9G0@8V]R;F5R+@H@
M("`@("H@0'!A<F%M(&9L;V%T("1W:61T:"`@(%=I9'1H(&]F('1H92!I;6%G
M92!I;B!T:&4@<&%G92X@268@97%U86P@=&\@>F5R;RP*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!I="!I<R!A=71O;6%T:6-A;&QY(&-A;&-U;&%T
M960@=&\@:V5E<"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O
M<FEG:6YA;"!P<F]P;W)T:6]N<RX*("`@("`J($!P87)A;2!F;&]A="`D:&5I
M9VAT("!(96EG:'0@;V8@=&AE(&EM86=E(&EN('1H92!P86=E+B!)9B!N;W0@
M<W!E8VEF:65D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;W(@97%U
M86P@=&\@>F5R;RP@:70@:7,@875T;VUA=&EC86QL>2!C86QC=6QA=&5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&\@:V5E<"!T:&4@;W)I9VEN
M86P@<')O<&]R=&EO;G,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@
M26UA9V4@9F]R;6%T+B!0;W-S:6)L92!V86QU97,@87)E("AC87-E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@:6YS96YS:71I=F4I(#H@2E!'+"!*
M4$5'+"!03D<N($EF(&YO="!S<&5C:69I960L"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@=&AE('1Y<&4@:7,@:6YF97)R960@9G)O;2!T:&4@9FEL
M92!E>'1E;G-I;VXN"B`@("`@*B!`<&%R86T@;6EX960@)&QI;FL@("`@55),
M(&]R(&ED96YT:69I97(@<F5T=7)N960@8GD@1FEL95]01$8Z.F%D9$QI;FLN
M"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ861D3&EN:PH@("`@("HO
M"B`@("!F=6YC=&EO;B!I;6%G92@D9FEL92P@)'@L("1Y+"`D=VED=&@@/2`P
M+"`D:&5I9VAT(#T@,"P@)'1Y<&4@/2`G)RP@)&QI;FL@/2`G)RD*("`@('L*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?:6UA9V5S6R1F:6QE72DI('L*
M("`@("`@("`@("`@+RH@1FER<W0@=7-E(&]F(&EM86=E+"!G970@<V]M92!F
M:6QE(&EN9F\N("HO"B`@("`@("`@("`@(&EF("@D='EP92`]/2`G)RD@>PH@
M("`@("`@("`@("`@("`@)'!O<R`]('-T<G)P;W,H)&9I;&4L("<N)RD["B`@
M("`@("`@("`@("`@("!I9B`H)'!O<R`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G
M26UA9V4@9FEL92!H87,@;F\@97AT96YS:6]N(&%N9"!N;R!T>7!E('=A<R!S
M<&5C:69I960Z("5S)RP@)&9I;&4I*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1T>7!E(#T@<W5B<W1R*"1F:6QE+"`D<&]S("L@,2D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1Y<&4@/2!S=')T;VQO=V5R
M*"1T>7!E*3L*("`@("`@("`@("`@)&UQ<B`](&=E=%]M86=I8U]Q=6]T97-?
M<G5N=&EM92@I.PH@("`@("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I
M;64H,"D["B`@("`@("`@("`@(&EF("@D='EP92`]/2`G:G!G)R!\?"`D='EP
M92`]/2`G:G!E9R<I('L*("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M
M/E]P87)S94I01R@D9FEL92D["B`@("`@("`@("`@('T@96QS96EF("@D='EP
M92`]/2`G<&YG)RD@>PH@("`@("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^
M7W!A<G-E4$Y'*"1F:6QE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=5
M;G-U<'!O<G1E9"!I;6%G92!F:6QE('1Y<&4Z("5S)RP@)'1Y<&4I*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I
M;64H)&UQ<BD["B`@("`@("`@("`@("1I;F9O6R=I)UT@/2!C;W5N="@D=&AI
M<RT^7VEM86=E<RD@*R`Q.PH@("`@("`@("`@("`D=&AI<RT^7VEM86=E<ULD
M9FEL95T@/2`D:6YF;SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M:6YF;R`]("1T:&ES+3Y?:6UA9V5S6R1F:6QE73L*("`@("`@("!]"@H@("`@
M("`@("\J($UA:V4@<W5R92!A;&P@=F%R<R!A<F4@8V]N=F5R=&5D('1O('!T
M('-C86QE+B`J+PH@("`@("`@("1X("`@("`@/2`D=&AI<RT^7W1O4'0H)'@I
M.PH@("`@("`@("1Y("`@("`@/2`D=&AI<RT^7W1O4'0H)'DI.PH@("`@("`@
M("1W:61T:"`@/2`D=&AI<RT^7W1O4'0H)'=I9'1H*3L*("`@("`@("`D:&5I
M9VAT(#T@)'1H:7,M/E]T;U!T*"1H96EG:'0I.PH*("`@("`@("`O*B!)9B!N
M;W0@<W!E8VEF:65D(&1O(&%U=&]M871I8R!W:61T:"!A;F0@:&5I9VAT(&-A
M;&-U;&%T:6]N<RX@*B\*("`@("`@("!I9B`H96UP='DH)'=I9'1H*2`F)B!E
M;7!T>2@D:&5I9VAT*2D@>PH@("`@("`@("`@("`D=VED=&@@/2`D:6YF;ULG
M=R==.PH@("`@("`@("`@("`D:&5I9VAT(#T@)&EN9F];)V@G73L*("`@("`@
M("!](&5L<V5I9B`H96UP='DH)'=I9'1H*2D@>PH@("`@("`@("`@("`D=VED
M=&@@/2`D:&5I9VAT("H@)&EN9F];)W<G72`O("1I;F9O6R=H)UT["B`@("`@
M("`@?2!E;'-E:68@*&5M<'1Y*"1H96EG:'0I*2!["B`@("`@("`@("`@("1H
M96EG:'0@/2`D=VED=&@@*B`D:6YF;ULG:"==("\@)&EN9F];)W<G73L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)W$@)2XR9B`P
M(#`@)2XR9B`E+C)F("4N,F8@8VT@+TDE9"!$;R!1)RP@)'=I9'1H+"`D:&5I
M9VAT+"`D>"P@)'1H:7,M/FA0="`M("@D>2`K("1H96EG:'0I+"`D:6YF;ULG
M:2==*2D["@H@("`@("`@("\J(%-E="!A;GD@;&EN:R!I9B!R97%U97-T960N
M("HO"B`@("`@("`@:68@*"1L:6YK*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;&EN:R@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&QI;FLI.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O<FUS(&$@;&EN92!B<F5A
M:RX@5&AE(&-U<G)E;G0@86)S8VES<V$@9V]E<R!B86-K('1O('1H92!L969T
M"B`@("`@*B!M87)G:6X@86YD('1H92!O<F1I;F%T92!I;F-R96%S97,@8GD@
M=&AE(&%M;W5N="!P87-S960@:6X@<&%R86UE=&5R+@H@("`@("H*("`@("`J
M($!P87)A;2!F;&]A="`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!B<F5A
M:RX@0GD@9&5F875L="P@=&AE('9A;'5E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@97%U86QS('1H92!H96EG:'0@;V8@=&AE(&QA<W0@<')I;G1E
M9"!C96QL+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F-E;&P*("`@
M("`J+PH@("`@9G5N8W1I;VX@;F5W3&EN92@D:&5I9VAT(#T@)R<I"B`@("![
M"B`@("`@("`@)'1H:7,M/G@@/2`D=&AI<RT^7VQE9G1?;6%R9VEN.PH@("`@
M("`@(&EF("AI<U]S=')I;F<H)&AE:6=H="DI('L*("`@("`@("`@("`@)'1H
M:7,M/GD@*ST@)'1H:7,M/E]L87-T7VAE:6=H=#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^>2`K/2`D:&5I9VAT.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%B<V-I<W-A(&]F
M('1H92!C=7)R96YT('!O<VET:6]N(&EN('5S97(@=6YI=',N"B`@("`@*@H@
M("`@("H@0')E='5R;B!F;&]A=`H@("`@("H*("`@("`J($!S964@1FEL95]0
M1$8Z.G-E=%@*("`@("`J($!S964@1FEL95]01$8Z.F=E=%D*("`@("`J($!S
M964@1FEL95]01$8Z.G-E=%D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T6"@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YX.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5F:6YE<R!T:&4@86)S8VES<V$@;V8@=&AE(&-U<G)E;G0@
M<&]S:71I;VXN($EF('1H92!P87-S960@=F%L=64@:7,*("`@("`J(&YE9V%T
M:79E+"!I="!I<R!R96QA=&EV92!T;R!T:&4@<FEG:'0@;V8@=&AE('!A9V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("!4:&4@=F%L=64@;V8@
M=&AE(&%B<V-I<W-A+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F=E
M=%@*("`@("`J($!S964@1FEL95]01$8Z.F=E=%D*("`@("`J($!S964@1FEL
M95]01$8Z.G-E=%D*("`@("`J($!S964@1FEL95]01$8Z.G-E=%A9"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=%@H)'@I"B`@("!["B`@("`@("`@:68@*"1X
M(#X](#`I('L*("`@("`@("`@("`@+RH@06)S;VQU=&4@=F%L=64N("HO"B`@
M("`@("`@("`@("1T:&ES+3YX(#T@)'@["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+RH@3F5G871I=F4L('-O(')E;&%T:79E('1O(')I9VAT(&5D
M9V4@;V8@=&AE('!A9V4N("HO"B`@("`@("`@("`@("1T:&ES+3YX(#T@)'1H
M:7,M/G<@*R`D>#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!O<F1I;F%T92!O9B!T:&4@8W5R<F5N="!P;W-I=&EO;B!I
M;B!U<V5R('5N:71S+@H@("`@("H*("`@("`J($!R971U<FX@9FQO870*("`@
M("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9719"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIG9718"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9718"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%DH*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^>3L*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE(&]R
M9&EN871E(&]F('1H92!C=7)R96YT('!O<VET:6]N+B!)9B!T:&4@<&%S<V5D
M('9A;'5E(&ES"B`@("`@*B!N96=A=&EV92P@:70@:7,@<F5L871I=F4@=&\@
M=&AE(&)O='1O;2!O9B!T:&4@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@
M9FQO870@)'D@(%1H92!V86QU92!O9B!T:&4@;W)D:6YA=&4N"B`@("`@*@H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ9V5T6`H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ9V5T60H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T60H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ<V5T6%D*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T62@D
M>2D*("`@('L*("`@("`@("!I9B`H)'D@/CT@,"D@>PH@("`@("`@("`@("`D
M=&AI<RT^>2`]("1Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3YY(#T@)'1H:7,M/F@@*R`D>3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$969I;F5S('1H92!A8G-C:7-S82!A;F0@;W)D:6YA=&4@
M;V8@=&AE(&-U<G)E;G0@<&]S:71I;VXN($EF('1H90H@("`@("H@<&%S<V5D
M('9A;'5E<R!A<F4@;F5G871I=F4L('1H97D@87)E(')E;&%T:79E(')E<W!E
M8W1I=F5L>2!T;R!T:&4@<FEG:'0*("`@("`J(&%N9"!B;W1T;VT@;V8@=&AE
M('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("!4:&4@=F%L
M=64@;V8@=&AE(&%B<V-I<W-A+@H@("`@("H@0'!A<F%M(&9L;V%T("1Y("!4
M:&4@=F%L=64@;V8@=&AE(&]R9&EN871E+@H@("`@("H*("`@("`J($!S964@
M1FEL95]01$8Z.G-E=%@*("`@("`J($!S964@1FEL95]01$8Z.G-E=%D*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T6%DH)'@L("1Y*0H@("`@>PH@("`@("`@
M("1T:&ES+3YS9719*"1Y*3L*("`@("`@("`D=&AI<RT^<V5T6"@D>"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!R87<@4$1&(&9I;&4N
M"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ;W5T<'5T"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$]U='!U="@I"B`@("!["B`@("`@("`@+RH@0VAE
M8VL@=VAE=&AE<B!F:6QE(&AA<R!B965N(&-L;W-E9"X@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]S=&%T92`\(#,I('L*("`@("`@("`@("`@)'1H:7,M/F-L
M;W-E*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]B=69F
M97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!O=71P=70@
M=&AE(&)U9F9E<F5D(&1A=&$@=&\@=&AE(&)R;W=S97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE;F%M92!F;W(@
M=&AE(&]U='!U="!F:6QE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN;&EN
M92`@(%1R=64@:68@:6YL:6YE+"!F86QS92!I9B!A='1A8VAM96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!O=71P=70H)&9I;&5N86UE(#T@)W5N:VYO=VXN
M<&1F)RP@)&EN;&EN92`](&9A;'-E*0H@("`@>PH@("`@("`@("\J($-H96-K
M('=H971H97(@9FEL92!H87,@8F5E;B!C;&]S960N("HO"B`@("`@("`@:68@
M*"1T:&ES+3Y?<W1A=&4@/"`S*2!["B`@("`@("`@("`@("1T:&ES+3YC;&]S
M92@I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@2%144%]$;W=N;&]A9"!I
M<R!N;W0@879A:6QA8FQE(')E='5R;B!014%27T5R<F]R+B`J+PH@("`@("`@
M(&EF("@A0&EN8VQU9&5?;VYC92`G2%144"]$;W=N;&]A9"YP:'`G*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]$;W=N;&]A9"XG*3L*("`@("`@("!]"@H@("`@
M("`@("\J($-H96-K(&EF(&AE861E<G,@:&%V92!B965N('-E;G0N("HO"B`@
M("`@("`@:68@*&AE861E<G-?<V5N="@I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YA8FQE('1O('-E;F0@4$1&(&9I;&4L
M('-O;64@9&%T82!H87,@86QR96%D>2!B965N(&]U='!U="!T;R!B<F]W<V5R
M+B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R86US(&9O<B!T:&4@;W5T
M<'5T+B`J+PH@("`@("`@("1D:7-P;W-I=&EO;B`]("@A)&EN;&EN92D@/R!(
M5%107T1/5TY,3T%$7T%45$%#2$U%3E0@.B!(5%107T1/5TY,3T%$7TE.3$E.
M13L*("`@("`@("`D<&%R86US(#T@87)R87DH)V1A=&$G("`@("`@("`@("`@
M("`@/3X@)'1H:7,M/E]B=69F97(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=C;VYT96YT='EP92<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]P9&8G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G8V]N=&5N=&1I<W!O<VET:6]N)R`]
M/B!A<G)A>2@D9&ES<&]S:71I;VXL("1F:6QE;F%M92DI.PH@("`@("`@("\J
M($]U='!U="!T:&4@9FEL92X@*B\*("`@("`@("!R971U<FX@2%144%]$;W=N
M;&]A9#HZ<W1A=&EC4V5N9"@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($9U;F-T:6]N('1O('-A=F4@=&AE(%!$1B!F:6QE('-O;65W:&5R92!L
M;V-A;"!T;R!T:&4@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&9I;&5N86UE("!4:&4@9FEL96YA;64@9F]R('1H92!O=71P=70@9FEL
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V%V92@D9FEL96YA;64@/2`G=6YK
M;F]W;BYP9&8G*0H@("`@>PH@("`@("`@("\J($-H96-K('=H971H97(@9FEL
M92!H87,@8F5E;B!C;&]S960N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A
M=&4@/"`S*2!["B`@("`@("`@("`@("1T:&ES+3YC;&]S92@I.PH@("`@("`@
M('T*"B`@("`@("`@)&8@/2!F;W!E;B@D9FEL96YA;64L("=W8B<I.PH@("`@
M("`@(&EF("@A)&8I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*'-P<FEN=&8H)U5N86)L92!T;R!S879E(%!$1B!F:6QE.B`E<R<L
M("1F:6QE;F%M92DI.PH@("`@("`@('T*("`@("`@("!F=W)I=&4H)&8L("1T
M:&ES+3Y?8G5F9F5R+"!S=')L96XH)'1H:7,M/E]B=69F97(I*3L*("`@("`@
M("!F8VQO<V4H)&8I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]T;U!T*"1V86PI
M"B`@("!["B`@("`@("`@<F5T=7)N("1V86P@*B`D=&AI<RT^7W-C86QE.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9?9V5T1F]N=$9I;&4H)&9O;G1K97DL("1P
M871H(#T@)R<I"B`@("!["B`@("`@("`@<W1A=&EC("1F;VYT7W=I9'1H<SL*
M"B`@("`@("`@:68@*"%I<W-E="@D9F]N=%]W:61T:'-;)&9O;G1K97E=*2D@
M>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1P871H*2D@>PH@("`@("`@("`@
M("`@("`@)&9I;&4@/2`D<&%T:"`N('-T<G1O;&]W97(H)&9O;G1K97DI("X@
M)RYP:'`G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&9I;&4@/2`G1FEL92]01$8O9F]N=',O)R`N('-T<G1O;&]W97(H)&9O;G1K
M97DI("X@)RYP:'`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@($!R97%U
M:7)E("1F:6QE.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1F;VYT7W=I9'1H
M<ULD9F]N=&ME>5TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H<W!R:6YT9B@G0V]U;&0@;F]T(&EN8VQU9&4@9F]N="!M
M971R:6,@9FEL93H@)7,G+"`D9FEL92DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&9O;G1?=VED=&AS.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]L:6YK*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D;&EN
M:RD*("`@('L*("`@("`@("`O*B!3879E(&QI;FL@=&\@<&%G92!L:6YK<R!A
M<G)A>2X@*B\*("`@("`@("`D=&AI<RT^7W!A9V5?;&EN:W-;)'1H:7,M/E]P
M86=E75M=(#T@87)R87DH)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1L:6YK
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8F5G:6Y$;V,H*0H@("`@>PH@("`@
M("`@("\J(%-T87)T(&1O8W5M96YT+"!B=70@;VYL>2!I9B!N;W0@>65T('-T
M87)T960N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/"`Q*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<W1A=&4@/2`Q.PH@("`@("`@("`@("`D=&AI
M<RT^7V]U="@G)5!$1BTQ+C,G*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@7W!U=%!A9V5S*"D*("`@('L*("`@("`@("`D;F(@/2`D=&AI<RT^
M7W!A9V4["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V%L:6%S7VYB7W!A
M9V5S*2D@>PH@("`@("`@("`@("`O*B!297!L86-E(&YU;6)E<B!O9B!P86=E
M<RX@*B\*("`@("`@("`@("`@9F]R("@D;B`](#$[("1N(#P]("1N8CL@)&XK
M*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P86=E<ULD;ET@/2!S=')?
M<F5P;&%C92@D=&AI<RT^7V%L:6%S7VYB7W!A9V5S+"`D;F(L("1T:&ES+3Y?
M<&%G97-;)&Y=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/E]D969A=6QT7V]R:65N=&%T:6]N(#T]("=0)RD@>PH@("`@
M("`@("`@("`D=U!T(#T@)'1H:7,M/F9W4'0["B`@("`@("`@("`@("1H4'0@
M/2`D=&AI<RT^9FA0=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=U!T(#T@)'1H:7,M/F9H4'0["B`@("`@("`@("`@("1H4'0@/2`D=&AI<RT^
M9G=0=#L*("`@("`@("!]"B`@("`@("`@)&9I;'1E<B`]("@D=&AI<RT^7V-O
M;7!R97-S*2`_("<O1FEL=&5R("]&;&%T941E8V]D92`G(#H@)R<["B`@("`@
M("`@9F]R("@D;B`](#$[("1N(#P]("1N8CL@)&XK*RD@>PH@("`@("`@("`@
M("`O*B!086=E("HO"B`@("`@("`@("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@
M("`@("`@("`@("1T:&ES+3Y?;W5T*"<\/"]4>7!E("]086=E)RD["B`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"<O4&%R96YT(#$@,"!2)RD["B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V]R:65N=&%T:6]N7V-H86YG97-;)&Y=
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G+TUE
M9&EA0F]X(%LP(#`@)2XR9B`E+C)F72<L("1H4'0L("1W4'0I*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U)E<V]U<F-E<R`R
M(#`@4B<I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86=E7VQI
M;FMS6R1N72DI('L*("`@("`@("`@("`@("`@("\J($QI;FMS("HO"B`@("`@
M("`@("`@("`@("`D86YN;W1S(#T@)R]!;FYO=',@6R<["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7W!A9V5?;&EN:W-;)&Y=(&%S("1P;"D@
M>PH@("`@("`@("`@("`@("`@("`@("1R96-T(#T@<W!R:6YT9B@G)2XR9B`E
M+C)F("4N,F8@)2XR9B<L("1P;%LP72P@)'!L6S%=+"`D<&Q;,%T@*R`D<&Q;
M,ETL("1P;%LQ72`M("1P;%LS72D["B`@("`@("`@("`@("`@("`@("`@)&%N
M;F]T<R`N/2`G/#PO5'EP92`O06YN;W0@+U-U8G1Y<&4@+TQI;FL@+U)E8W0@
M6R<@+B`D<F5C="`N("==("]";W)D97(@6S`@,"`P72`G.PH@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]S=')I;F<H)'!L6S1=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D86YN;W1S("X]("<O02`\/"]3("]54DD@+U5222`G
M("X@)'1H:7,M/E]T97AT4W1R:6YG*"1P;%LT72D@+B`G/CX^/B<["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&P@/2`D=&AI<RT^7VQI;FMS6R1P;%LT75T["B`@("`@("`@("`@("`@
M("`@("`@("`@("1H96EG:'0@/2!I<W-E="@D=&AI<RT^7V]R:65N=&%T:6]N
M7V-H86YG97-;)&Q;,%U=*2`_("1W4'0@.B`D:%!T.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D86YN;W1S("X]('-P<FEN=&8H)R]$97-T(%LE9"`P(%(@
M+UA96B`P("4N,F8@;G5L;%T^/B<L(#$@*R`R("H@)&Q;,%TL("1H96EG:'0@
M+2`D;%LQ72`J("1T:&ES+3Y?<V-A;&4I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"1A;FYO=',N)UTG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^7V]U="@G+T-O;G1E;G1S("<@+B`H)'1H:7,M/E]N("L@,2D@+B`G
M(#`@4CX^)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O8FHG*3L*
M("`@("`@("`@("`@+RH@4&%G92!C;VYT96YT("HO"B`@("`@("`@("`@("1P
M(#T@*"1T:&ES+3Y?8V]M<')E<W,I(#\@9WIC;VUP<F5S<R@D=&AI<RT^7W!A
M9V5S6R1N72D@.B`D=&AI<RT^7W!A9V5S6R1N73L*("`@("`@("`@("`@)'1H
M:7,M/E]N97=O8FHH*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SP\)R`N
M("1F:6QT97(@+B`G+TQE;F=T:"`G("X@<W1R;&5N*"1P*2`N("<^/B<I.PH@
M("`@("`@("`@("`D=&AI<RT^7W!U=%-T<F5A;2@D<"D["B`@("`@("`@("`@
M("1T:&ES+3Y?;W5T*"=E;F1O8FHG*3L*("`@("`@("!]"B`@("`@("`@+RH@
M4&%G97,@<F]O="`J+PH@("`@("`@("1T:&ES+3Y?;V9F<V5T<ULQ72`]('-T
M<FQE;B@D=&AI<RT^7V)U9F9E<BD["B`@("`@("`@)'1H:7,M/E]O=70H)S$@
M,"!O8FHG*3L*("`@("`@("`D=&AI<RT^7V]U="@G/#PO5'EP92`O4&%G97,G
M*3L*("`@("`@("`D:VED<R`]("<O2VED<R!;)SL*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D;F([("1I*RLI('L*("`@("`@("`@("`@)&MI9',@+CT@
M*#,@*R`R("H@)&DI("X@)R`P(%(@)SL*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/E]O=70H)&MI9',@+B`G72<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<O
M0V]U;G0@)R`N("1N8BD["B`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G
M+TUE9&EA0F]X(%LP(#`@)2XR9B`E+C)F72<L("1W4'0L("1H4'0I*3L*("`@
M("`@("`D=&AI<RT^7V]U="@G/CXG*3L*("`@("`@("`D=&AI<RT^7V]U="@G
M96YD;V)J)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!U=$9O;G1S*"D*("`@
M('L*("`@("`@("`D;F8@/2`D=&AI<RT^7VX["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]D:69F<R!A<R`D9&EF9BD@>PH@("`@("`@("`@("`O*B!%;F-O
M9&EN9W,@*B\*("`@("`@("`@("`@)'1H:7,M/E]N97=O8FHH*3L*("`@("`@
M("`@("`@)'1H:7,M/E]O=70H)SP\+U1Y<&4@+T5N8V]D:6YG("]"87-E16YC
M;V1I;F<@+U=I;D%N<VE%;F-O9&EN9R`O1&EF9F5R96YC97,@6R<@+B`D9&EF
M9B`N("==/CXG*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)V5N9&]B:B<I
M.PH@("`@("`@('T*("`@("`@("`D;7%R(#T@9V5T7VUA9VEC7W%U;W1E<U]R
M=6YT:6UE*"D["B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*#`I
M.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9F]N=%]F:6QE<R!A<R`D9FEL
M92`]/B`D:6YF;RD@>PH@("`@("`@("`@("`O*B!&;VYT(&9I;&4@96UB961D
M:6YG+B`J+PH@("`@("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@
M("`@("`D=&AI<RT^7V9O;G1?9FEL97-;)&9I;&5=6R=N)UT@/2`D=&AI<RT^
M7VX["B`@("`@("`@("`@("1S:7IE(#T@9FEL97-I>F4H)&9I;&4I.PH@("`@
M("`@("`@("!I9B`H(21S:7IE*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)T9O;G0@9FEL92!N;W0@9F]U;F0N)RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SP\+TQE;F=T
M:"`G("X@)'-I>F4I.PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1F:6QE+"`M
M,BD@/3T@)RYZ)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]&
M:6QT97(@+T9L871E1&5C;V1E)RD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]O=70H)R],96YG=&@Q("<@+B`D:6YF;ULG;&5N9W1H,2==
M*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=L96YG=&@R)UTI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+TQE;F=T:#(@)R`N("1I
M;F9O6R=L96YG=&@R)UT@+B`G("],96YG=&@S(#`G*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7V]U="@G/CXG*3L*("`@("`@("`@("`@
M)&8@/2!F;W!E;B@D9FEL92P@)W)B)RD["B`@("`@("`@("`@("1T:&ES+3Y?
M<'5T4W1R96%M*&9R96%D*"1F+"`D<VEZ92DI.PH@("`@("`@("`@("!F8VQO
M<V4H)&8I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD["B`@
M("`@("`@?0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@D;7%R
M*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V9O;G1S(&%S("1K(#T^("1F
M;VYT*2!["B`@("`@("`@("`@("\J($9O;G0@;V)J96-T<R`J+PH@("`@("`@
M("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`D=&AI<RT^7V9O
M;G1S6R1K75LG;B==(#T@)'1H:7,M/E]N.PH@("`@("`@("`@("`D;F%M92`]
M("1F;VYT6R=N86UE)UT["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<\/"]4
M>7!E("]&;VYT)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O0F%S949O
M;G0@+R<@+B`D;F%M92D["B`@("`@("`@("`@(&EF("@D9F]N=%LG='EP92==
M(#T]("=C;W)E)RD@>PH@("`@("`@("`@("`@("`@+RH@4W1A;F1A<F0@9F]N
M="X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4W5B='EP92`O
M5'EP93$G*3L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`A/2`G4WEM8F]L
M)R`F)B`D;F%M92`A/2`G6F%P9D1I;F=B871S)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"<O16YC;V1I;F<@+U=I;D%N<VE%;F-O9&EN
M9R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@+RH@061D:71I;VYA;"!F;VYT+B`J+PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O=70H)R]3=6)T>7!E("\G("X@)&9O;G1;)W1Y
M<&4G72D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T9I<G-T0VAA
M<B`S,B<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R],87-T0VAA
M<B`R-34G*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O5VED=&AS
M("<@+B`H)'1H:7,M/E]N("L@,2D@+B`G(#`@4B<I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]O=70H)R]&;VYT1&5S8W)I<'1O<B`G("X@*"1T:&ES+3Y?
M;B`K(#(I("X@)R`P(%(G*3L*("`@("`@("`@("`@("`@(&EF("@D9F]N=%LG
M96YC)UTI('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9O;G1;
M)V1I9F8G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)R]%;F-O9&EN9R`G("X@*"1N9B`K("1F;VYT6R=D:69F)UTI+B<@,"!2
M)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]%;F-O9&EN9R`O5VEN06YS:45N
M8V]D:6YG)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<^
M/B<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD["B`@("`@
M("`@("`@(&EF("@D9F]N=%LG='EP92==("$]("=C;W)E)RD@>PH@("`@("`@
M("`@("`@("`@+RH@5VED=&AS+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]N97=O8FHH*3L*("`@("`@("`@("`@("`@("1C=R`]("8D9F]N=%LG8W<G
M73L*("`@("`@("`@("`@("`@("1S(#T@)ULG.PH@("`@("`@("`@("`@("`@
M9F]R("@D:2`](#,R.R`D:2`\/2`R-34[("1I*RLI('L*("`@("`@("`@("`@
M("`@("`@("`D<R`N/2`D8W=;8VAR*"1I*5T@+B`G("<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@D<R`N("==)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD["B`@("`@
M("`@("`@("`@("`O*B!$97-C<FEP=&]R+B`J+PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]N97=O8FHH*3L*("`@("`@("`@("`@("`@("1S(#T@)SP\+U1Y
M<&4@+T9O;G1$97-C<FEP=&]R("]&;VYT3F%M92`O)R`N("1N86UE.PH@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&9O;G1;)V1E<V,G72!A<R`D:R`]/B`D
M=BD@>PH@("`@("`@("`@("`@("`@("`@("1S("X]("<@+R<@+B`D:R`N("<@
M)R`N("1V.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9I
M;&4@/2`D9F]N=%LG9FEL92==.PH@("`@("`@("`@("`@("`@:68@*"1F:6QE
M*2!["B`@("`@("`@("`@("`@("`@("`@)',@+CT@)R`O1F]N=$9I;&4G("X@
M*"1F;VYT6R=T>7!E)UT@/3T@)U1Y<&4Q)R`_("<G(#H@)S(G*2`N("<@)R`N
M("1T:&ES+3Y?9F]N=%]F:6QE<ULD9FEL95U;)VXG72`N("<@,"!2)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1S
M("X@)SX^)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J
M)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@7W!U=$EM86=E<R@I"B`@("!["B`@("`@("`@)&9I;'1E<B`]("@D=&AI
M<RT^7V-O;7!R97-S*2`_("<O1FEL=&5R("]&;&%T941E8V]D92`G(#H@)R<[
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I;6%G97,@87,@)&9I;&4@/3X@
M)&EN9F\I('L*("`@("`@("`@("`@)'1H:7,M/E]N97=O8FHH*3L*("`@("`@
M("`@("`@)'1H:7,M/E]I;6%G97-;)&9I;&5=6R=N)UT@/2`D=&AI<RT^7VX[
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<\/"]4>7!E("]83V)J96-T)RD[
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4W5B='EP92`O26UA9V4G*3L*
M("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]7:61T:"`G("X@)&EN9F];)W<G
M72D["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O2&5I9VAT("<@+B`D:6YF
M;ULG:"==*3L*("`@("`@("`@("`@:68@*"1I;F9O6R=C<R==(#T]("=);F1E
M>&5D)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]#;VQO<E-P
M86-E(%LO26YD97AE9"`O1&5V:6-E4D="("<@+B`H<W1R;&5N*"1I;F9O6R=P
M86PG72DO,R`M(#$I("X@)R`G("X@*"1T:&ES+3Y?;B`K(#$I+B<@,"!272<I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)R]#;VQO<E-P86-E("\G("X@)&EN9F];)V-S)UTI.PH@("`@("`@
M("`@("`@("`@:68@*"1I;F9O6R=C<R==(#T]("=$979I8V5#35E+)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O1&5C;V1E(%LQ(#`@
M,2`P(#$@,"`Q(#!=)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]":71S4&5R0V]M<&]N96YT
M("<@+B`D:6YF;ULG8G!C)UTI.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G
M+T9I;'1E<B`O)R`N("1I;F9O6R=F)UTI.PH@("`@("`@("`@("!I9B`H:7-S
M970H)&EN9F];)W!A<FUS)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V]U="@D:6YF;ULG<&%R;7,G72D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1I;F9O6R=T<FYS)UTI("8F(&ES7V%R<F%Y*"1I;F9O
M6R=T<FYS)UTI*2!["B`@("`@("`@("`@("`@("`D=')N<R`]("<G.PH@("`@
M("`@("`@("`@("`@)&E?;6%X(#T@8V]U;G0H)&EN9F];)W1R;G,G72D["B`@
M("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:5]M87@[("1I*RLI
M('L*("`@("`@("`@("`@("`@("`@("`D=')N<R`N/2`D:6YF;ULG=')N<R==
M6R1I72`N("<@)R`N("1I;F9O6R=T<FYS)UU;)&E=+B<@)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O36%S:R!;
M)R`N("1T<FYS("X@)UTG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^7V]U="@G+TQE;F=T:"`G("X@<W1R;&5N*"1I;F9O6R=D871A)UTI
M("X@)SX^)RD["B`@("`@("`@("`@("1T:&ES+3Y?<'5T4W1R96%M*"1I;F9O
M6R=D871A)UTI.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD[
M"@H@("`@("`@("`@("`O*B!086QE='1E+B`J+PH@("`@("`@("`@("!I9B`H
M)&EN9F];)V-S)UT@/3T@)TEN9&5X960G*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`@("`@)'!A;"`]("@D=&AI
M<RT^7V-O;7!R97-S*2`_(&=Z8V]M<')E<W,H)&EN9F];)W!A;"==*2`Z("1I
M;F9O6R=P86PG73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<\/"<@
M+B`D9FEL=&5R("X@)R],96YG=&@@)R`N('-T<FQE;B@D<&%L*2`N("<^/B<I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P=713=')E86TH)'!A;"D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W!U=%)E<V]U
M<F-E<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]P=71&;VYT<R@I.PH@("`@
M("`@("1T:&ES+3Y?<'5T26UA9V5S*"D["B`@("`@("`@+RH@4F5S;W5R8V4@
M9&EC=&EO;F%R>2`J+PH@("`@("`@("1T:&ES+3Y?;V9F<V5T<ULR72`]('-T
M<FQE;B@D=&AI<RT^7V)U9F9E<BD["B`@("`@("`@)'1H:7,M/E]O=70H)S(@
M,"!O8FHG*3L*("`@("`@("`D=&AI<RT^7V]U="@G/#PO4')O8U-E="!;+U!$
M1B`O5&5X="`O26UA9V5"("]);6%G94,@+TEM86=E25TG*3L*("`@("`@("`D
M=&AI<RT^7V]U="@G+T9O;G0@/#PG*3L*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7V9O;G1S(&%S("1F;VYT*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<O1B<@+B`D9F]N=%LG:2==("X@)R`G("X@)&9O;G1;)VXG72`N("<@,"!2
M)RD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@
M("`@(&EF("AC;W5N="@D=&AI<RT^7VEM86=E<RDI('L*("`@("`@("`@("`@
M)'1H:7,M/E]O=70H)R]83V)J96-T(#P\)RD["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?:6UA9V5S(&%S("1I;6%G92D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]O=70H)R]))R`N("1I;6%G95LG:2==("X@)R`G("X@)&EM
M86=E6R=N)UT@+B`G(#`@4B<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M7V]U="@G/CXG*3L*("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W!U=$EN9F\H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;W5T*"<O4')O9'5C97(@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@G
M2&]R9&4@4$1&)RDI.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I;F9O
M6R=T:71L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U1I=&QE
M("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H:7,M/E]I;F9O6R=T:71L92==
M*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I;F9O
M6R=S=6)J96-T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4W5B
M:F5C="`G("X@)'1H:7,M/E]T97AT4W1R:6YG*"1T:&ES+3Y?:6YF;ULG<W5B
M:F5C="==*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]I;F9O6R=A=71H;W(G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)R]!=71H;W(@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D=&AI<RT^7VEN9F];
M)V%U=&AO<B==*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/FME>7=O<F1S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+TME
M>7=O<F1S("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H:7,M/FME>7=O<F1S
M*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/F-R96%T
M;W(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O0W)E871O<B`G("X@
M)'1H:7,M/E]T97AT4W1R:6YG*"1T:&ES+3YC<F5A=&]R*2D["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?;W5T*"<O0W)E871I;VY$871E("<@+B`D=&AI
M<RT^7W1E>'13=')I;F<H)T0Z)R`N(&1A=&4H)UEM9$AI<R<I*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W!U=$-A=&%L;V<H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;W5T*"<O5'EP92`O0V%T86QO9R<I.PH@("`@("`@("1T:&ES+3Y?
M;W5T*"<O4&%G97,@,2`P(%(G*3L*("`@("`@("!I9B`H)'1H:7,M/E]Z;V]M
M7VUO9&4@/3T@)V9U;&QP86=E)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U
M="@G+T]P96Y!8W1I;VX@6S,@,"!2("]&:71=)RD["B`@("`@("`@?2!E;'-E
M:68@*"1T:&ES+3Y?>F]O;5]M;V1E(#T]("=F=6QL=VED=&@G*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"<O3W!E;D%C=&EO;B!;,R`P(%(@+T9I=$@@
M;G5L;%TG*3L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]Z;V]M7VUO9&4@
M/3T@)W)E86PG*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O3W!E;D%C
M=&EO;B!;,R`P(%(@+UA96B!N=6QL(&YU;&P@,5TG*3L*("`@("`@("!](&5L
M<V5I9B`H(6ES7W-T<FEN9R@D=&AI<RT^7WIO;VU?;6]D92DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]O=70H)R]/<&5N06-T:6]N(%LS(#`@4B`O6%E:(&YU
M;&P@;G5L;"`G("X@*"1T:&ES+3Y?>F]O;5]M;V1E("\@,3`P*2XG72<I.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]L87EO=71?;6]D92`]/2`G
M<VEN9VQE)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U!A9V5,87EO
M=70@+U-I;F=L95!A9V4G*3L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]L
M87EO=71?;6]D92`]/2`G8V]N=&EN=6]U<R<I('L*("`@("`@("`@("`@)'1H
M:7,M/E]O=70H)R]086=E3&%Y;W5T("]/;F5#;VQU;6XG*3L*("`@("`@("!]
M(&5L<V5I9B`H)'1H:7,M/E]L87EO=71?;6]D92`]/2`G='=O)RD@>PH@("`@
M("`@("`@("`D=&AI<RT^7V]U="@G+U!A9V5,87EO=70@+U1W;T-O;'5M;DQE
M9G0G*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W!U=%1R86EL
M97(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W5T*"<O4VEZ92`G("X@*"1T
M:&ES+3Y?;B`K(#$I*3L*("`@("`@("`D=&AI<RT^7V]U="@G+U)O;W0@)R`N
M("1T:&ES+3Y?;B`N("<@,"!2)RD["B`@("`@("`@)'1H:7,M/E]O=70H)R])
M;F9O("<@+B`H)'1H:7,M/E]N("T@,2D@+B`G(#`@4B<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]E;F1$;V,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<'5T
M4&%G97,H*3L*("`@("`@("`D=&AI<RT^7W!U=%)E<V]U<F-E<R@I.PH@("`@
M("`@("\J($EN9F\@*B\*("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@
M("`@("1T:&ES+3Y?;W5T*"<\/"<I.PH@("`@("`@("1T:&ES+3Y?<'5T26YF
M;R@I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@("1T:&ES
M+3Y?;W5T*"=E;F1O8FHG*3L*("`@("`@("`O*B!#871A;&]G("HO"B`@("`@
M("`@)'1H:7,M/E]N97=O8FHH*3L*("`@("`@("`D=&AI<RT^7V]U="@G/#PG
M*3L*("`@("`@("`D=&AI<RT^7W!U=$-A=&%L;V<H*3L*("`@("`@("`D=&AI
M<RT^7V]U="@G/CXG*3L*("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD[
M"B`@("`@("`@+RH@0W)O<W,M<F5F("HO"B`@("`@("`@)&\@/2!S=')L96XH
M)'1H:7,M/E]B=69F97(I.PH@("`@("`@("1T:&ES+3Y?;W5T*"=X<F5F)RD[
M"B`@("`@("`@)'1H:7,M/E]O=70H)S`@)R`N("@D=&AI<RT^7VX@*R`Q*2D[
M"B`@("`@("`@)'1H:7,M/E]O=70H)S`P,#`P,#`P,#`@-C4U,S4@9B`G*3L*
M("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/#T@)'1H:7,M/E]N.R`D:2LK*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)R4P,3!D(#`P,#`P
M(&X@)RP@)'1H:7,M/E]O9F9S971S6R1I72DI.PH@("`@("`@('T*("`@("`@
M("`O*B!4<F%I;&5R("HO"B`@("`@("`@)'1H:7,M/E]O=70H)W1R86EL97(G
M*3L*("`@("`@("`D=&AI<RT^7V]U="@G/#PG*3L*("`@("`@("`D=&AI<RT^
M7W!U=%1R86EL97(H*3L*("`@("`@("`D=&AI<RT^7V]U="@G/CXG*3L*("`@
M("`@("`D=&AI<RT^7V]U="@G<W1A<G1X<F5F)RD["B`@("`@("`@)'1H:7,M
M/E]O=70H)&\I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<E)45/1B<I.PH@("`@
M("`@("1T:&ES+3Y?<W1A=&4@/2`S.PH@("`@?0H*("`@(&9U;F-T:6]N(%]B
M96=I;E!A9V4H)&]R:65N=&%T:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%G92LK.PH@("`@("`@("1T:&ES+3Y?<&%G97-;)'1H:7,M/E]P86=E72`]
M("<G.PH@("`@("`@("1T:&ES+3Y?<W1A=&4@/2`R.PH@("`@("`@("1T:&ES
M+3YX(#T@)'1H:7,M/E]L969T7VUA<F=I;CL*("`@("`@("`D=&AI<RT^>2`]
M("1T:&ES+3Y?=&]P7VUA<F=I;CL*("`@("`@("`D=&AI<RT^7VQA<W1?:&5I
M9VAT(#T@,#L*("`@("`@("`O*B!086=E(&]R:65N=&%T:6]N("HO"B`@("`@
M("`@:68@*"$D;W)I96YT871I;VXI('L*("`@("`@("`@("`@)&]R:65N=&%T
M:6]N(#T@)'1H:7,M/E]D969A=6QT7V]R:65N=&%T:6]N.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1O<FEE;G1A=&EO;B`]('-T<G1O=7!P97(H
M)&]R:65N=&%T:6]N>S!]*3L*("`@("`@("`@("`@:68@*"1O<FEE;G1A=&EO
M;B`A/2`D=&AI<RT^7V1E9F%U;'1?;W)I96YT871I;VXI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;W)I96YT871I;VY?8VAA;F=E<ULD=&AI<RT^7W!A
M9V5=(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H)&]R:65N=&%T:6]N("$]("1T:&ES+3Y?8W5R<F5N=%]O<FEE;G1A=&EO
M;BD@>PH@("`@("`@("`@("`O*B!#:&%N9V4@;W)I96YT871I;VX@*B\*("`@
M("`@("`@("`@:68@*"1O<FEE;G1A=&EO;B`]/2`G4"<I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YW4'0@/2`D=&AI<RT^9G=0=#L*("`@("`@("`@("`@
M("`@("1T:&ES+3YH4'0@/2`D=&AI<RT^9FA0=#L*("`@("`@("`@("`@("`@
M("1T:&ES+3YW("`@/2`D=&AI<RT^9G<["B`@("`@("`@("`@("`@("`D=&AI
M<RT^:"`@(#T@)'1H:7,M/F9H.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G=0="`]("1T:&ES+3YF:%!T.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FA0="`]("1T:&ES+3YF=U!T.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G<@("`]("1T:&ES+3YF:#L*("`@("`@("`@("`@("`@
M("1T:&ES+3YH("`@/2`D=&AI<RT^9G<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]P86=E7V)R96%K7W1R:6=G97(@/2`D=&AI<RT^:"`M
M("1T:&ES+3Y?8G)E86M?;6%R9VEN.PH@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)E;G1?;W)I96YT871I;VX@/2`D;W)I96YT871I;VX["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]E;F1086=E*"D*("`@('L*("`@("`@("`O
M*B!%;F0@;V8@<&%G92!C;VYT96YT<R`J+PH@("`@("`@("1T:&ES+3Y?<W1A
M=&4@/2`Q.PH@("`@?0H*("`@(&9U;F-T:6]N(%]N97=O8FHH*0H@("`@>PH@
M("`@("`@("\J($)E9VEN(&$@;F5W(&]B:F5C="`J+PH@("`@("`@("1T:&ES
M+3Y?;BLK.PH@("`@("`@("1T:&ES+3Y?;V9F<V5T<ULD=&AI<RT^7VY=(#T@
M<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*3L*("`@("`@("`D=&AI<RT^7V]U="@D
M=&AI<RT^7VX@+B`G(#`@;V)J)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V1O
M56YD97)L:6YE*"1X+"`D>2P@)'1E>'0I"B`@("!["B`@("`@("`@+RH@4V5T
M('1H92!R96-T86YG;&4@=VED=&@@86-C;W)D:6YG('1O('1E>'0@=VED=&@N
M("HO"B`@("`@("`@)'=I9'1H("`]("1T:&ES+3YG9713=')I;F=7:61T:"@D
M=&5X="P@=')U92D["@H@("`@("`@("\J(%-E="!R96-T86YG;&4@<&]S:71I
M;VX@86YD(&AE:6=H="P@=7-I;F<@=6YD97)L:6YE('!O<VET:6]N(&%N9`H@
M("`@("`@("`J('1H:6-K;F5S<R!S971T:6YG<R!S8V%L960@8GD@=&AE(&9O
M;G0@<VEZ92X@*B\*("`@("`@("`D>2`]("1Y("L@*"1T:&ES+3Y?8W5R<F5N
M=%]F;VYT6R=U<"==("H@)'1H:7,M/E]F;VYT7W-I>F5?<'0@+R`Q,#`P*3L*
M("`@("`@("`D:&5I9VAT(#T@+21T:&ES+3Y?8W5R<F5N=%]F;VYT6R=U="==
M("H@)'1H:7,M/E]F;VYT7W-I>F5?<'0@+R`Q,#`P.PH*("`@("`@("!R971U
M<FX@<W!R:6YT9B@G)2XR9B`E+C)F("4N,F8@)2XR9B!R92!F)RP@)'@L("1Y
M+"`D=VED=&@L("1H96EG:'0I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P87)S
M94I01R@D9FEL92D*("`@('L*("`@("`@("`O*B!%>'1R86-T(&EN9F\@9G)O
M;2!A($I014<@9FEL92X@*B\*("`@("`@("`D:6UG(#T@0&=E=&EM86=E<VEZ
M92@D9FEL92D["B`@("`@("`@:68@*"$D:6UG*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=-:7-S:6YG(&]R(&EN
M8V]R<F5C="!I;6%G92!F:6QE.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@
M("`@("`@(&EF("@D:6UG6S)=("$](#(I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)TYO="!A($I014<@9FEL93H@
M)7,G+"`D9FEL92DI.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1I
M;6=;)V-H86YN96QS)UTI('Q\("1I;6=;)V-H86YN96QS)UT@/3T@,RD@>PH@
M("`@("`@("`@("`D8V]L<W!A8V4@/2`G1&5V:6-E4D=")SL*("`@("`@("!]
M(&5L<V5I9B`H)&EM9ULG8VAA;FYE;',G72`]/2`T*2!["B`@("`@("`@("`@
M("1C;VQS<&%C92`]("=$979I8V5#35E+)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8V]L<W!A8V4@/2`G1&5V:6-E1W)A>2<["B`@("`@("`@
M?0H@("`@("`@("1B<&,@/2!I<W-E="@D:6UG6R=B:71S)UTI(#\@)&EM9ULG
M8FET<R==(#H@.#L*"B`@("`@("`@+RH@4F5A9"!W:&]L92!F:6QE+B`J+PH@
M("`@("`@("1F(#T@9F]P96XH)&9I;&4L("=R8B<I.PH@("`@("`@("1D871A
M(#T@9G)E860H)&8L(&9I;&5S:7IE*"1F:6QE*2D["B`@("`@("`@9F-L;W-E
M*"1F*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=W)R`]/B`D:6UG6S!=+"`G
M:"<@/3X@)&EM9ULQ72P@)V-S)R`]/B`D8V]L<W!A8V4L("=B<&,G(#T^("1B
M<&,L("=F)R`]/B`G1$-41&5C;V1E)RP@)V1A=&$G(#T^("1D871A*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<&%R<V503D<H)&9I;&4I"B`@("!["B`@("`@
M("`@+RH@17AT<F%C="!I;F9O(&9R;VT@82!03D<@9FEL92X@*B\*("`@("`@
M("`D9B`](&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@("!I9B`H(21F*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F
M*"=5;F%B;&4@=&\@;W!E;B!I;6%G92!F:6QE.B`E<R<L("1F:6QE*2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!S:6=N871U<F4N("HO"B`@("`@
M("`@:68@*&9R96%D*"1F+"`X*2`A/2!C:'(H,3,W*2`N("=03D<G("X@8VAR
M*#$S*2`N(&-H<B@Q,"D@+B!C:'(H,C8I("X@8VAR*#$P*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G3F]T(&$@
M4$Y'(&9I;&4Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"@H@("`@("`@("\J
M(%)E860@:&5A9&5R(&-H=6YK+B`J+PH@("`@("`@(&9R96%D*"1F+"`T*3L*
M("`@("`@("!I9B`H9G)E860H)&8L(#0I("$]("=)2$12)RD@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G26YC;W)R
M96-T(%!.1R!F:6QE.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@
M("1W:61T:"`]("1T:&ES+3Y?9G)E861);G0H)&8I.PH@("`@("`@("1H96EG
M:'0@/2`D=&AI<RT^7V9R96%D26YT*"1F*3L*("`@("`@("`D8G!C(#T@;W)D
M*&9R96%D*"1F+"`Q*2D["B`@("`@("`@:68@*"1B<&,@/B`X*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"<Q-BUB
M:70@9&5P=&@@;F]T('-U<'!O<G1E9#H@)7,G+"`D9FEL92DI.PH@("`@("`@
M('T*("`@("`@("`D8W0@/2!O<F0H9G)E860H)&8L(#$I*3L*("`@("`@("!I
M9B`H)&-T(#T](#`I('L*("`@("`@("`@("`@)&-O;'-P86-E(#T@)T1E=FEC
M94=R87DG.PH@("`@("`@('T@96QS96EF("@D8W0@/3T@,BD@>PH@("`@("`@
M("`@("`D8V]L<W!A8V4@/2`G1&5V:6-E4D=")SL*("`@("`@("!](&5L<V5I
M9B`H)&-T(#T](#,I('L*("`@("`@("`@("`@)&-O;'-P86-E(#T@)TEN9&5X
M960G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=!;'!H82!C:&%N;F5L(&YO="!S=7!P
M;W)T960Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@("`@("`@:68@*&]R
M9"AF<F5A9"@D9BP@,2DI("$](#`I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)U5N:VYO=VX@8V]M<')E<W-I;VX@
M;65T:&]D.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@(&EF("AO
M<F0H9G)E860H)&8L(#$I*2`A/2`P*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=5;FMN;W=N(&9I;'1E<B!M971H
M;V0Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@("`@("`@:68@*&]R9"AF
M<F5A9"@D9BP@,2DI("$](#`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*'-P<FEN=&8H)TEN=&5R;&%C:6YG(&YO="!S=7!P;W)T
M960Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@("`@("`@9G)E860H)&8L
M(#0I.PH@("`@("`@("1P87)M<R`]("<O1&5C;V1E4&%R;7,@/#PO4')E9&EC
M=&]R(#$U("]#;VQO<G,@)R`N("@D8W0@/3T@,B`_(#,@.B`Q*2XG("]":71S
M4&5R0V]M<&]N96YT("<@+B`D8G!C("X@)R`O0V]L=6UN<R`G("X@)'=I9'1H
M+B<^/B<["B`@("`@("`@+RH@4V-A;B!C:'5N:W,@;&]O:VEN9R!F;W(@<&%L
M971T92P@=')A;G-P87)E;F-Y(&%N9"!I;6%G92!D871A+B`J+PH@("`@("`@
M("1P86P@/2`G)SL*("`@("`@("`D=')N<R`]("<G.PH@("`@("`@("1D871A
M(#T@)R<["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D;B`]("1T:&ES+3Y?
M9G)E861);G0H)&8I.PH@("`@("`@("`@("`D='EP92`](&9R96%D*"1F+"`T
M*3L*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=03%1%)RD@>PH@("`@("`@
M("`@("`@("`@+RH@4F5A9"!P86QE='1E("HO"B`@("`@("`@("`@("`@("`D
M<&%L(#T@9G)E860H)&8L("1N*3L*("`@("`@("`@("`@("`@(&9R96%D*"1F
M+"`T*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=T4DY3)RD@
M>PH@("`@("`@("`@("`@("`@+RH@4F5A9"!T<F%N<W!A<F5N8WD@:6YF;R`J
M+PH@("`@("`@("`@("`@("`@)'0@/2!F<F5A9"@D9BP@)&XI.PH@("`@("`@
M("`@("`@("`@:68@*"1C="`]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1R;G,@/2!A<G)A>2AO<F0H<W5B<W1R*"1T+"`Q+"`Q*2DI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1C="`]/2`R*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1R;G,@/2!A<G)A>2AO<F0H<W5B<W1R*"1T+"`Q+"`Q*2DL(&]R
M9"AS=6)S='(H)'0L(#,L(#$I*2P@;W)D*'-U8G-T<B@D="P@-2P@,2DI*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'!O<R`]('-T<G!O<R@D="P@8VAR*#`I*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?:6YT*"1P;W,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T<FYS(#T@87)R87DH)'!O<RD["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@9G)E860H)&8L(#0I
M.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)TE$050G*2!["B`@
M("`@("`@("`@("`@("`O*B!296%D(&EM86=E(&1A=&$@8FQO8VL@*B\*("`@
M("`@("`@("`@("`@("1D871A("X](&9R96%D*"1F+"`D;BD["B`@("`@("`@
M("`@("`@("!F<F5A9"@D9BP@-"D["B`@("`@("`@("`@('T@96QS96EF("@D
M='EP92`]/2`G245.1"<I('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9G)E860H)&8L("1N
M("L@-"D["B`@("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D;BD["@H@
M("`@("`@(&EF("@D8V]L<W!A8V4@/3T@)TEN9&5X960G("8F(&5M<'1Y*"1P
M86PI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS
M<')I;G1F*"=-:7-S:6YG('!A;&5T=&4@:6XZ("5S)RP@)&9I;&4I*3L*("`@
M("`@("!]"B`@("`@("`@9F-L;W-E*"1F*3L*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=W)R`]/B`D=VED=&@L("=H)R`]/B`D:&5I9VAT+"`G8W,G(#T^("1C
M;VQS<&%C92P@)V)P8R<@/3X@)&)P8RP@)V8G(#T^("=&;&%T941E8V]D92<L
M("=P87)M<R<@/3X@)'!A<FUS+"`G<&%L)R`]/B`D<&%L+"`G=')N<R<@/3X@
M)'1R;G,L("=D871A)R`]/B`D9&%T82D["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V9R96%D26YT*"1F*0H@("`@>PH@("`@("`@("\J(%)E860@82`T+6)Y=&4@
M:6YT96=E<B!F<F]M(&9I;&4N("HO"B`@("`@("`@)&D@(#T@;W)D*&9R96%D
M*"1F+"`Q*2D@/#P@,C0["B`@("`@("`@)&D@*ST@;W)D*&9R96%D*"1F+"`Q
M*2D@/#P@,38["B`@("`@("`@)&D@*ST@;W)D*&9R96%D*"1F+"`Q*2D@/#P@
M.#L*("`@("`@("`D:2`K/2!O<F0H9G)E860H)&8L(#$I*3L*("`@("`@("!R
M971U<FX@)&D["B`@("!]"@H@("`@9G5N8W1I;VX@7W1E>'13=')I;F<H)',I
M"B`@("!["B`@("`@("`@+RH@1F]R;6%T(&$@=&5X="!S=')I;F<@*B\*("`@
M("`@("!R971U<FX@)R@G("X@)'1H:7,M/E]E<V-A<&4H)',I("X@)RDG.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]E<V-A<&4H)',I"B`@("!["B`@("`@("`@
M+RH@061D(%P@8F5F;W)E(%PL("@@86YD("D@*B\*("`@("`@("!R971U<FX@
M<W1R7W)E<&QA8V4H87)R87DH)RDG+"<H)RPG7%PG*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)UQ<*2<L)UQ<*"<L)UQ<7%PG*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)',I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]P=713=')E86TH)',I"B`@("!["B`@("`@("`@)'1H:7,M/E]O=70H
M)W-T<F5A;2<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"1S*3L*("`@("`@("`D
M=&AI<RT^7V]U="@G96YD<W1R96%M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V]U="@D<RD*("`@('L*("`@("`@("`O*B!!9&0@82!L:6YE('1O('1H92!D
M;V-U;65N="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`]/2`R*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%G97-;)'1H:7,M/E]P86=E72`N/2`D
M<R`N(")<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]B=69F97(@+CT@)',@+B`B7&XB.PH@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O9&]C<R\`````````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S<P`#`Q-C$R,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92\`
M````````````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-S,`,#$V,C,U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U)$3R\`````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,0`P,38V-3<`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4D1/+U-T;W)A9V4O
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S<Q`#`R,#(V,P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]21$\O4W1O<F%G92]M>7-Q;"YP:'``````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,34V,#8`,3`T,3<S-C(W-S$`,#(R,30V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!-
M>5-13"!21$]?4W1O<F%G92!I;7!L96UE;G1A=&EO;BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4D1/+U)$3R]3=&]R86=E+VUY<W%L+G!H<"QV(#$N."XR
M+C$@,C`P-2\Q,"\Q."`Q,3HP,3HR,R!J86X@17AP("0*("H*("H@0'!A8VMA
M9V4@4D1/"B`J+PIC;&%S<R!21$]?4W1O<F%G95]M>7-Q;"!E>'1E;F1S(%)$
M3U]3=&]R86=E7W-Q;"!["@H@("`@+RHJ"B`@("`@*B!(=6UA;BUR96%D86)L
M92!N86UE(&9O<B!T:&ES(%-T;W)A9V4@9')I=F5R+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG("1N86UE"B`@("`@*B\*("`@('!U8FQI8R`D;F%M92`]
M("=->5-13"<["@H@("`@+RHJ"B`@("`@*B!0;W-T9W)E4U%,(&1A=&%B87-E
M(')E<V]U<F-E+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4@)&1B"B`@
M("`@*B\*("`@('!R:79A=&4@)&1B(#T@;G5L;#L*"B`@("`O*BH*("`@("`J
M($UY4U%,(%)$3U]3=&]R86=E(&-O;G-T<G5C=&]R+B!3971S('!A<F%M971E
M<G,@86YD(&-O;FYE8W1S('1O"B`@("`@*B!T:&4@9&%T86)A<V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@0V]N;F5C=&EO;B!A;F0@
M;W1H97(@<&%R86UE=&5R<RX*("`@("`J+PH@("`@<')O=&5C=&5D(&9U;F-T
M:6]N(%]?8V]N<W1R=6-T*"1P87)A;7,I"B`@("!["B`@("`@("`@<&%R96YT
M.CI?7V-O;G-T<G5C="@D<&%R86US*3L*"B`@("`@("`@)'1H:7,M/F-O;FYE
M8W0H*3L*("`@('T*"B`@("`O*BH*("`@("`J($9R964@86YY(')E<V]U<F-E
M<R!T:&%T(&%R92!O<&5N+@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@
M7U]D97-T<G5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YD8BD@>PH@
M("`@("`@("`@("!M>7-Q;%]C;&]S92@D=&AI<RT^9&(I.PH@("`@("`@('T*
M("`@('T*"B`@("!P=6)L:6,@9G5N8W1I;VX@8W)E871E*%)$3U]-87!P97(@
M)&UA<'!E<BP@)&9I96QD<RD*("`@('L*("`@("`@("`D;65T82`]("1M87!P
M97(M/F1E<V-R:6)E*"D["@H@("`@("`@("1S<6P@/2`G24Y315)4($E.5$\@
M)R`N("1M971A+3YC;VYT86EN97(["B`@("`@("`@)&ME>7,@/2!A<G)A>2@I
M.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@
M*"1F:65L9',@87,@)&9I96QD(#T^("1V86QU92D@>PH@("`@("`@("`@("`D
M:V5Y<UM=(#T@)&9I96QD.PH@("`@("`@("`@("`D=F%L=65S6UT@/2`B)R(@
M+B`D=&AI<RT^<75O=&4H)&UE=&$M/F=E=$9I96QD*"1F:65L9"DL("1V86QU
M92D@+B`B)R(["B`@("`@("`@?0H@("`@("`@("1S<6P@+CT@)R`H)R`N(&EM
M<&QO9&4H)RP@)RP@)&ME>7,I("X@)RD@5D%,5453("@G("X@:6UP;&]D92@G
M+"`G+"`D=F%L=65S*2`N("<I)SL*"B`@("`@("`@)'1H:7,M/F5X96-U=&4H
M)'-Q;"D["B`@("`@("`@<F5T=7)N(&UY<W%L7VEN<V5R=%]I9"@D=&AI<RT^
M9&(I.PH@("`@?0H*("`@('!U8FQI8R!F=6YC=&EO;B!U<&1A=&4H4D1/7TUA
M<'!E<B`D;6%P<&5R+"`D:60L("1F:65L9',I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YE>&5C=71E*"1T:&ES+3YQ8G5I;&1E<BT^=7!D871E*"1M
M87!P97(L("1I9"P@)&9I96QD<RDI.PH@("`@?0H*("`@('!U8FQI8R!F=6YC
M=&EO;B!D96QE=&4H4D1/7TUA<'!E<B`D;6%P<&5R+"`D8W)I=&5R:6$I"B`@
M("!["B`@("!]"@H@("`@<'5B;&EC(&9U;F-T:6]N(&9I;F0H4D1/7TUA<'!E
M<B`D;6%P<&5R+"`D;6]D92P@)&-R:71E<FEA*0H@("`@>PH@("`@("`@(')E
M='5R;B!N97<@4D1/7U)E<W5L='-?;7ES<6PH)'1H:7,L("1M87!P97(L("1M
M;V1E+"`D8W)I=&5R:6$I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&%K92!A
M('-T<FEN9RP@=W)A<"!I="!I;B!S:6YG;&4@<75O=&5S+"!A;F0@97-C87!E
M(&%N>2!Q=6]T97,*("`@("`J(&]R(&]T:&5R('-P96-I86P@8VAA<F%C=&5R
M<R!I;B!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A(%1H
M92!S=')I;F<@=&\@<75O=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@475O=&5D('-T<FEN9R!W<F%P<&5D(&EN('-I;F=L92!Q=6]T97,N"B`@
M("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!Q=6]T95-T<FEN9R@D9&%T82D*
M("`@('L*("`@("`@("!R971U<FX@(B<B("X@;7ES<6Q?<F5A;%]E<V-A<&5?
M<W1R:6YG*"1D871A+"`D=&AI<RT^9&(I("X@(B<B.PH@("`@?0H*("`@("\J
M*@H@("`@("H@57-E(&9O<B!314Q%0U0@86YD(&%N>71H:6YG('1H870@<F5T
M=7)N<R!R;W=S+@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@<75E<GDH
M)'-Q;"D*("`@('L*("`@("`@("`D<F5S=6QT(#T@;7ES<6Q?<75E<GDH)'-Q
M;"P@)'1H:7,M/F1B*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@
M("`@("`@=&AR;W<@;F5W(%)$3U]%>&-E<'1I;VXH;7ES<6Q?97)R;W(H*2`N
M("<@)R`N("1S<6PI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@('T*"B`@("`O*BH*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N
M('%U97)Y3VYE*"1S<6PI"B`@("!["B`@("`@("`@)')E<W5L="`](&UY<W%L
M7W%U97)Y*"1S<6PL("1T:&ES+3YD8BD["B`@("`@("`@:68@*"$D<F5S=6QT
M*2!["B`@("`@("`@("`@('1H<F]W(&YE=R!21$]?17AC97!T:6]N*&UY<W%L
M7V5R<F]R*"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@0&UY<W%L7W)E
M<W5L="@D<F5S=6QT+"`P+"`P*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5S
M92!F;W(@24Y315)4+"!54$1!5$4L($1%3$5412X@4F5T=7)N<R!N=6UB97(@
M;V8@869F96-T960*("`@("`J(')O=W,N"B`@("`@*B\*("`@('!U8FQI8R!F
M=6YC=&EO;B!E>&5C=71E*"1S<6PI"B`@("!["B`@("`@("`@)')E<W5L="`]
M(&UY<W%L7W%U97)Y*"1S<6PL("1T:&ES+3YD8BD["B`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@('1H<F]W(&YE=R!21$]?17AC97!T:6]N
M*&UY<W%L7V5R<F]R*"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@;7ES
M<6Q?869F96-T961?<F]W<R@D=&AI<RT^9&(I.PH@("`@?0H*("`@("\J*@H@
M("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@8F5G:6XH*0H@("`@>PH@("`@
M?0H*("`@("\J*@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@8V]M;6ET
M*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U
M;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-H86YG961?9&(I
M('L*("`@("`@("`@("`@("`@(&EF("@A0&UY<W%L7W-E;&5C=%]D8B@D=&AI
M<RT^7V-H86YG961?9&(L("1T:&ES+3YD8BDI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].
M3T1"4T5,14-4140I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)T-/34U)5"<L
M("1T:&ES+3YD8BD["B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E
M<GDH)U-%5"!!551/0T]-34E4/3$G+"`D=&AI<RT^9&(I.PH@("`@("`@("`@
M("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YM>7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+RHJ"B`@("`@*B\*
M("`@('!U8FQI8R!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]C:&%N9V5D7V1B*2!["B`@("`@("`@("`@("`@
M("!I9B`H(4!M>7-Q;%]S96QE8W1?9&(H)'1H:7,M/E]C:&%N9V5D7V1B+"`D
M=&AI<RT^9&(I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YM>7-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S
M=6QT(#T@0&UY<W%L7W%U97)Y*"=23TQ,0D%#2R<L("1T:&ES+3YD8BD["B`@
M("`@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)U-%5"!!551/0T]-
M34E4/3$G+"`D=&AI<RT^9&(I.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A
M8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R
M;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M1$)?3TL["B`@("!]"@H@("`@+RHJ"B`@("`@*B\*("`@('!U8FQI8R!F=6YC
M=&EO;B!D97-C<FEB92A21$]?36%P<&5R("1M87!P97(L(%)$3U]-971A1&%T
M82`D;65T861A=&$I"B`@("!["B`@("`@("`@)'(@/2`D=&AI<RT^<75E<GDH
M)U-(3U<@0T],54U.4R!&4D]-("<@+B`D;65T861A=&$M/F-O;G1A:6YE<BD[
M"B`@("`@("`@:68@*"$D<BD@>PH@("`@("`@("`@("!T:')O=R!N97<@4D1/
M7T5X8V5P=&EO;BAM>7-Q;%]E<G)O<B@I*3L*("`@("`@("!]"@H@("`@("`@
M('=H:6QE("@D9B`](&UY<W%L7V9E=&-H7V%S<V]C*"1R*2D@>PH@("`@("`@
M("`@("`D;65T861A=&$M/F%D9$9I96QD*"1F6R=&:65L9"==+"`D9BD["B`@
M("`@("`@("`@(&EF("@D9ELG2V5Y)UT@/3T@)U!222<I('L*("`@("`@("`@
M("`@("`@("1M971A9&%T82T^:V5Y(#T@)&9;)T9I96QD)UT["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B\*("`@('!U
M8FQI8R!F=6YC=&EO;B!F<F5E*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T
M=7)N($!M>7-Q;%]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O
M*BH*("`@("`J+PH@("`@<')I=F%T92!F=6YC=&EO;B!S971$8B@D9&%T86)A
M<V4I"B`@("!["B`@("`@("`@;7ES<6Q?<V5L96-T7V1B*"1D871A8F%S92P@
M)'1H:7,M/F1B*3L*("`@('T*"B`@("`O*BH*("`@("`J+PH@("`@<')I=F%T
M92!F=6YC=&EO;B!C;VYN96-T*"D*("`@('L*("`@("`@("`D=&AI<RT^9&(@
M/2!M>7-Q;%]C;VYN96-T*"=L;V-A;&AO<W0G+"`D=&AI<RT^<&%R86US6R=U
M<V5R;F%M92==+"`D=&AI<RT^<&%R86US6R=P87-S=V]R9"==*3L*"B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^<&%R86US6R=D871A8F%S92==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<V5T1&(H)'1H:7,M/G!A<F%M<ULG9&%T86)A
M<V4G72D["B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%)$
M3PH@*B\*8VQA<W,@4D1/7U)E<W5L='-?;7ES<6P@97AT96YD<R!21$]?4F5S
M=6QT<R!["@H@("`@+RHJ"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!C
M;W5N="@I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/G)E<W5L
M="DI('L*("`@("`@("`@("`@)'1H:7,M/G)E=VEN9"@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@;7ES<6Q?;G5M7W)O=W,H)'1H:7,M/G)E<W5L="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);7!L96UE;G1A=&EO;B!O9B!T:&4@
M<F5W:6YD*"D@;65T:&]D(&9O<B!->5-13"!R97-U;'0@<V5T<RX*("`@("`J
M+PH@("`@<'5B;&EC(&9U;F-T:6]N(')E=VEN9"@I"B`@("!["B`@("`@("`@
M+R\@4F5W:6YD(&]N;'D@:68@;F5V97(@<75E<FEE9"!B969O<F4@;W(@<75E
M<GD@=V%S"B`@("`@("`@+R\@<W5C8V5S<V9U;"X*("`@("`@("!I9B`H:7-?
M;G5L;"@D=&AI<RT^<F5S=6QT*2!\?"!I<U]R97-O=7)C92@D=&AI<RT^<F5S
M=6QT*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G)E<W5L="D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-T;W)A9V4M/F9R964H)'1H:7,M/G)E<W5L
M="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G0@
M/2!N=6QL.PH@("`@("`@("`@("`D=&AI<RT^:6YD97@@/2!N=6QL.PH@("`@
M("`@("`@("`D=&AI<RT^96]F(#T@=')U93L*"B`@("`@("`@("`@("1T:&ES
M+3YR97-U;'0@/2`D=&AI<RT^<W1O<F%G92T^9FEN9$YO=R@D=&AI<RT^;6%P
M<&5R+"`D=&AI<RT^;6]D92P@)'1H:7,M/F-R:71E<FEA*3L*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^<F5S=6QT*2!["B`@("`@("`@("`@("`@("!T:')O
M=R!N97<@4D1/7T5X8V5P=&EO;BAM>7-Q;%]E<G)O<B@I*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^;F5X="@I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($EM<&QE;65N=&%T:6]N(&]F('1H92!N97AT
M*"D@;65T:&]D(&9O<B!->5-13"!R97-U;'0@<V5T<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%1H92!N97AT(')O=RP@;W(@;G5L;"!I9B!N;R!M
M;W)E(')O=W,N"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!N97AT*"D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^<F5S=6QT*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<F5W:6YD*"D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)'1H:7,M/G)E<W5L="D@>PH@("`@("`@("`@("`D=&AI<RT^8W5R
M<F5N="`](&UY<W%L7V9E=&-H7V%S<V]C*"1T:&ES+3YR97-U;'0I.PH@("`@
M("`@("`@("!I9B`H(21T:&ES+3YC=7)R96YT*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^96]F(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YE;V8@/2!F86QS93L*"B`@("`@("`@("`@
M("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^:6YD97@I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FEN9&5X(#T@,#L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@*RLD=&AI<RT^:6YD97@["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M:&ES+3YC=7)R96YT(#T@)'1H:7,M/FUA<'!E<BT^;6%P*"1T:&ES+3YC=7)R
M96YT*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^8W5R<F5N
M=#L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]21$\O4W1O<F%G
M92]P96%R9&(N<&AP````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8W-S$`
M,3`T,3<S-C(W-S$`,#(R,C0Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)T1"+G!H<"<[
M"@HO*BH*("H@4$5!4CHZ1$(@4D1/7U-T;W)A9V4@:6UP;&5M96YT871I;VXN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U)$3R]21$\O4W1O<F%G92]P96%R
M9&(N<&AP+'8@,2XV+C(N-"`R,#`V+S`Q+S$X(#(S.C(V.C4X(&IA;B!%>'`@
M)`H@*@H@*B!`<&%C:V%G92!21$\*("HO"F-L87-S(%)$3U]3=&]R86=E7W!E
M87)D8B!E>'1E;F1S(%)$3U]3=&]R86=E('L*"B`@("`O*BH*("`@("`J($AU
M;6%N+7)E861A8FQE(&YA;64@9F]R('1H:7,@4W1O<F%G92!D<FEV97(N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<@)&YA;64*("`@("`J+PH@("`@<'5B
M;&EC("1N86UE(#T@)U!%05(Z.D1")SL*"B`@("`O*BH*("`@("`J(%!%05(Z
M.D1"(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R($1"("1D8@H@("`@("HO
M"B`@("!P<FEV871E("1D8B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B\*("`@
M('!U8FQI8R!F=6YC=&EO;B!?7V-O;G-T<G5C="@D<&%R86US*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ7U]C;VYS=')U8W0H)'!A<F%M<RD["B`@("`@("`@
M)'1H:7,M/F-O;FYE8W0H*3L*("`@('T*"B`@("`O*BH*("`@("`J($9R964@
M86YY(')E<V]U<F-E<R!T:&%T(&%R92!O<&5N+@H@("`@("HO"B`@("!P=6)L
M:6,@9G5N8W1I;VX@7U]D97-T<G5C="@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YD8BD@>PH@("`@("`@("`@("`D=&AI<RT^9&(M/F1I<V-O;FYE8W0H
M*3L*("`@("`@("`@("`@=6YS970H)'1H:7,M/F1B*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!5<V4@9F]R(%-%3$5#5"!A;F0@86YY=&AI
M;F<@=&AA="!R971U<FYS(')O=W,N"B`@("`@*B\*("`@('!U8FQI8R!F=6YC
M=&EO;B!Q=65R>2@D<W%L*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M9&(M/G%U97)Y*"1S<6PI.PH@("`@?0H*("`@("\J*@H@("`@("H@57-E(&9O
M<B!)3E-%4E0L(%501$%412P@1$5,151%+B!2971U<FYS(&YU;6)E<B!O9B!A
M9F9E8W1E9`H@("`@("H@<F]W<RX*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T
M:6]N(&5X96-U=&4H)'-Q;"D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/F1B+3YQ=65R>2@D<W%L*3L*("`@("`@("!I9B`H)')E<W5L="!I;G-T
M86YC96]F($1"7T5R<F]R*2!["B`@("`@("`@("`@('1H<F]W(&YE=R!21$]?
M17AC97!T:6]N*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/F1B+3YN=6U2;W=S*"D["B`@("!]"@H@("`@<'5B;&EC(&9U;F-T
M:6]N(&)E9VEN*"D*("`@('L*("`@('T*"B`@("!P=6)L:6,@9G5N8W1I;VX@
M8V]M;6ET*"D*("`@('L*("`@('T*"B`@("!P=6)L:6,@9G5N8W1I;VX@<F]L
M;&)A8VLH*0H@("`@>PH@("`@?0H*("`@('!R:79A=&4@9G5N8W1I;VX@8V]N
M;F5C="@I"B`@("!["B`@("`@("`@)'1H:7,M/F1B(#T@)D1".CIC;VYN96-T
M*"1T:&ES+3YP87)A;7,I.PH@("`@("`@(&EF("@D=&AI<RT^9&(@/3T@1$)?
M3D]47T-/3DY%0U1%1"D@>PH@("`@("`@("`@("!T:')O=R!N97<@4D1/7T5X
M8V5P=&EO;B@D=&AI<RT^9&(I.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^
M9&(@:6YS=&%N8V5O9B!$0E]%<G)O<BD@>PH@("`@("`@("`@("!T:')O=R!N
M97<@4D1/7T5X8V5P=&EO;B@D=&AI<RT^9&(I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N"B`@("`@("`@<W=I
M=&-H("@D=&AI<RT^9&(M/G!H<'1Y<&4I('L*("`@("`@("!C87-E("=M<W-Q
M;"<Z"B`@("`@("`@("`@("1T:&ES+3YD8BT^<V5T3W!T:6]N*"=P;W)T86)I
M;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,
M25197T524D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M
M/F1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@("`@("!]
M"@H@("`@?0H*?0H*8VQA<W,@4D1/7U)E<W5L='-?<&5A<F1B(&5X=&5N9',@
M4D1/7U)E<W5L=',@>PH*("`@("\J*@H@("`@("H@26UP;&5M96YT871I;VX@
M;V8@=&AE(')E=VEN9"@I(&UE=&AO9"!F;W(@:71E<F%T;W(N"B`@("`@*B\*
M("`@('!U8FQI8R!F=6YC=&EO;B!R97=I;F0H*0H@("`@>PH@("`@("`@("\O
M(%)E=VEN9"!O;FQY(&EF(&YE=F5R('%U97)I960@8F5F;W)E(&]R('%U97)Y
M('=A<PH@("`@("`@("\O('-U8V-E<W-F=6PN"B`@("`@("`@:68@*&ES7VYU
M;&PH)'1H:7,M/G)E<W5L="D@?'P*("`@("`@("`@("`@)'1H:7,M/G)E<W5L
M="!I;G-T86YC96]F($1"7U)E<W5L="D@>PH*("`@("`@("`@("`@:68@*"1T
M:&ES+3YR97-U;'0I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=&]R86=E
M+3YF<F5E*"1T:&ES+3YR97-U;'0I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=&AI<RT^<F5S=6QT(#T@;G5L;#L*("`@("`@("`@("`@)'1H:7,M
M/F-U<G)E;G0@/2!N=6QL.PH@("`@("`@("`@("`D=&AI<RT^:6YD97@@/2!N
M=6QL.PH@("`@("`@("`@("`D=&AI<RT^96]F(#T@=')U93L*"B`@("`@("`@
M("`@("1T:&ES+3YR97-U;'0@/2`D=&AI<RT^9&(M/G%U97)Y*"1T:&ES+3YQ
M=65R>2P@)'1H:7,M/G!A<F%M<RD["B`@("`@("`@("`@(&EF("@A*"1T:&ES
M+3YR97-U;'0@:6YS=&%N8V5O9B!$0E]297-U;'0I*2!["B`@("`@("`@("`@
M("`@("!T:')O=R!N97<@4D1/7T5X8V5P=&EO;B@D=&AI<RT^<F5S=6QT*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^;F5X="@I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($EM<&QE;65N=&%T:6]N(&]F
M('1H92!N97AT*"D@;65T:&]D(&9O<B!I=&5R871O<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%1H92!N97AT(')O=RP@;W(@;G5L;"!I9B!N;R!M
M;W)E(')O=W,N"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!N97AT*"D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^<F5S=6QT*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<F5W:6YD*"D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)'1H:7,M/G)E<W5L="D@>PH@("`@("`@("`@("`D=&AI<RT^8W5R
M<F5N="`]("1T:&ES+3YR97-U;'0M/F9E=&-H4F]W*"D["@H@("`@("`@("`@
M("!I9B`H:7-?;G5L;"@D=&AI<RT^8W5R<F5N="DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YE;V8@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F5O9B`](&9A;'-E.PH*("`@("`@("`@
M("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3YI;F1E>"DI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^:6YD97@@/2`P.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`K*R1T:&ES+3YI;F1E>#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YC=7)R96YT.PH@("`@?0H*?0H`````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4D1/+U-T;W)A
M9V4O<&=S<6PN<&AP````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U,S(S
M`#$P-#$W,S8R-S<Q`#`R,C$R-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@4&]S=&=R95-13"!21$]?
M4W1O<F%G92!I;7!L96UE;G1A=&EO;BX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO4D1/+U)$3R]3=&]R86=E+W!G<W%L+G!H<"QV(#$N.2XR+C$@,C`P-2\Q
M,"\Q."`Q,3HP,3HR,R!J86X@17AP("0*("H*("H@0'!A8VMA9V4@4D1/"B`J
M+PIC;&%S<R!21$]?4W1O<F%G95]P9W-Q;"!E>'1E;F1S(%)$3U]3=&]R86=E
M7W-Q;"!["@H@("`@+RHJ"B`@("`@*B!(=6UA;BUR96%D86)L92!N86UE(&9O
M<B!T:&ES(%-T;W)A9V4@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG("1N86UE"B`@("`@*B\*("`@('!U8FQI8R`D;F%M92`]("=0;W-T9W)E
M4U%,)SL*"B`@("`O*BH*("`@("`J(%!O<W1G<F5344P@9&%T86)A<V4@<F5S
M;W5R8V4N"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C92`D9&(*("`@("`J
M+PH@("`@<')I=F%T92`D9&(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@4&]S
M=&=R95-13"!21$]?4W1O<F%G92!C;VYS=')U8W1O<BX@4V5T<R!P87)A;65T
M97)S(&%N9`H@("`@("H@8V]N;F5C=',@=&\@=&AE(&1A=&%B87-E+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US($-O;FYE8W1I;VX@86YD
M(&]T:&5R('!A<F%M971E<G,N"B`@("`@*B\*("`@('!R;W1E8W1E9"!F=6YC
M=&EO;B!?7V-O;G-T<G5C="@D<&%R86US*0H@("`@>PH@("`@("`@('!A<F5N
M=#HZ7U]C;VYS=')U8W0H)'!A<F%M<RD["@H@("`@("`@("1T:&ES+3YC;VYN
M96-T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&<F5E(&%N>2!R97-O=7)C
M97,@=&AA="!A<F4@;W!E;BX*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N
M(%]?9&5S=')U8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9&(I('L*
M("`@("`@("`@("`@<&=?8VQO<V4H)'1H:7,M/F1B*3L*("`@("`@("!]"B`@
M("!]"@H@("`@<'5B;&EC(&9U;F-T:6]N(&-R96%T92A21$]?36%P<&5R("1M
M87!P97(L("1F:65L9',I"B`@("!["B`@("`@("`@)&UE=&%D871A(#T@)&UA
M<'!E<BT^9&5S8W)I8F4H*3L*("`@("`@("`D<F5S=6QT(#T@0'!G7VEN<V5R
M="@D=&AI<RT^9&(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UE
M=&%D871A+3YC;VYT86EN97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9I96QD<RD["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@
M("`@('1H<F]W(&YE=R!21$]?17AC97!T:6]N*'!G7VQA<W1?97)R;W(H*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y3VYE*"=3
M14Q%0U0@0U524E9!3"A<)R<@+B`D;65T861A=&$M/F-O;G1A:6YE<B`N("=?
M)R`N("1M971A9&%T82T^:V5Y("X@)U]S97%<)RDG*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%5P9&%T97,@82!B86-K96YD(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@4D1/7TUA<'!E<B`D;6%P<&5R(%1H92!21$]?36%P<&5R
M(')E<75E<W1I;F<@=&AE('5P9&%T92X*("`@("`J($!P87)A;2!S8V%L87(@
M)&ED(%1H92!U;FEQ=64@:V5Y(&]F('1H92!O8FIE8W0@8F5I;F<@=7!D871E
M9"X*("`@("`J($!P87)A;2!A<G)A>2`D9FEE;&1S($AA<V@@;V8@9FEE;&0@
M;F%M97,O;F5W('9A;'5E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@5')U92!I9B!O;F4@;V)J96-T(&ES('5P9&%T960L(&9A;'-E(&EF(&YO
M"B`@("`@*B!O8FIE8W0@:7,@=7!D871E9"P@;W(@=&AR;W<@86X@97AC97!T
M:6]N(&EF(&%N>2!E<G)O<G,@;V-C=7(N"B`@("`@*B\*("`@('!U8FQI8R!F
M=6YC=&EO;B!U<&1A=&4H4D1/7TUA<'!E<B`D;6%P<&5R+"`D:60L("1F:65L
M9',I"B`@("!["B`@("`@("`@)&UE=&%D871A(#T@)&UA<'!E<BT^9&5S8W)I
M8F4H*3L*("`@("`@("`D<75E<GD@/2!`<&=?=7!D871E*"1T:&ES+3YD8BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M971A9&%T82T^8V]N=&%I
M;F5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD<RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1M971A9&%T82T^:V5Y
M(#T^("1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!01U-13%]$
M34Q?4U1224Y'*3L*("`@("`@("!I9B`H(21Q=65R>2D@>PH@("`@("`@("`@
M("!T:')O=R!N97<@4D1/7T5X8V5P=&EO;BAP9U]L87-T7V5R<F]R*"DI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YE>&5C=71E*"1Q=65R
M>2D@/3T@,3L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!O;F4@;W(@
M;6]R92!O8FIE8W1S(&9R;VT@=&AE(&)A8VME;F0@<W1O<F%G92X*("`@("`J
M"B`@("`@*B!`<&%R86T@4D1/7TUA<'!E<B`D;6%P<&5R(%1H92!21$]?36%P
M<&5R(')E<75E<W1I;F<@=&AE(&1E;&5T:6]N+@H@("`@("H@0'!A<F%M(&%R
M<F%Y?%)$3U]#<FET97)I82`D8W)I=&5R:6$@1&5S8W)I<'1I;VX@;V8@=VAA
M="!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R($YU
M;6)E<B!O9B!O8FIE8W1S(&1E;&5T960N"B`@("`@*B\*("`@('!U8FQI8R!F
M=6YC=&EO;B!D96QE=&4H4D1/7TUA<'!E<B`D;6%P<&5R+"`D8W)I=&5R:6$I
M"B`@("!["B`@("`@("`@:68@*"1C<FET97)I82!I;G-T86YC96]F(%)$3U]#
M<FET97)I82D@>PH@("`@("`@("`@("!T:')O=R!N97<@4D1/7T5X8V5P=&EO
M;B@G0W)I=&5R:6$@;V)J96-T<R!N;W0@>65T(&EM<&QE;65N=&5D+B<I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M971A9&%T82`]("1M87!P
M97(M/F1E<V-R:6)E*"D["B`@("`@("`@("`@("1Q=65R>2`]($!P9U]D96QE
M=&4H)'1H:7,M/F1B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1M971A9&%T82T^8V]N=&%I;F5R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C<FET97)I82P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!01U-13%]$34Q?4U1224Y'*3L*("`@("`@("`@("`@:68@*"$D
M<75E<GDI('L*("`@("`@("`@("`@("`@('1H<F]W(&YE=R!21$]?17AC97!T
M:6]N*'!G7VQA<W1?97)R;W(H*2D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^97AE8W5T92@D<75E<GDI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N(&9I
M;F0H4D1/7TUA<'!E<B`D;6%P<&5R+"`D;6]D92P@)&-R:71E<FEA*0H@("`@
M>PH@("`@("`@(')E='5R;B!N97<@4D1/7U)E<W5L='-?<&=S<6PH)'1H:7,L
M("1M87!P97(L("1M;V1E+"`D8W)I=&5R:6$I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5&%K92!A('-T<FEN9RP@=W)A<"!I="!I;B!S:6YG;&4@<75O=&5S
M+"!A;F0@97-C87!E(&%N>2!Q=6]T97,*("`@("`J(&]R(&]T:&5R('-P96-I
M86P@8VAA<F%C=&5R<R!I;B!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D871A(%1H92!S=')I;F<@=&\@<75O=&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@475O=&5D('-T<FEN9R!W<F%P<&5D(&EN('-I;F=L
M92!Q=6]T97,N"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!Q=6]T95-T
M<FEN9R@D9&%T82D*("`@('L*("`@("`@("!R971U<FX@(B<B("X@<&=?97-C
M87!E7W-T<FEN9R@D9&%T82D@+B`B)R(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!5<V4@9F]R(%-%3$5#5"!A;F0@86YY=&AI;F<@=&AA="!R971U<FYS(')O
M=W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W%L($$@9G5L;"!3
M44P@<75E<GD@=&\@<G5N+@H@("`@("H*("`@("`J($!R971U<FX@<F5S;W5R
M8V4@5&AE(%!O<W1G<F5344P@<F5S=6QT(&]B:F5C="X*("`@("`J+PH@("`@
M<'5B;&EC(&9U;F-T:6]N('%U97)Y*"1S<6PI"B`@("!["B`@("`@("`@)')E
M<W5L="`]($!P9U]Q=65R>2@D=&AI<RT^9&(L("1S<6PI.PH@("`@("`@(&EF
M("@A)')E<W5L="D@>PH@("`@("`@("`@("!T:')O=R!N97<@4D1/7T5X8V5P
M=&EO;BAP9U]L87-T7V5R<F]R*"D@+B`G("<@+B`D<W%L*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@82!S:6YG;&4@=F%L=64@9G)O;2!A('%U97)Y+B!5<V5F=6P@
M9F]R('%U:6-K;'D@9V5T=&EN9PH@("`@("H@82!V86QU92!S=6-H(&%S('=I
M=&@@82!#3U5.5"@J*2!Q=65R>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S<6P@5&AE(%-13"!T;R!G970@;VYE(')E<W5L="!F<F]M+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@5&AE(&9I<G-T('9A;'5E(&]F('1H
M92!F:7)S="!R;W<@;6%T8VAE9"!B>2`D<W%L+@H@("`@("HO"B`@("!P=6)L
M:6,@9G5N8W1I;VX@<75E<GE/;F4H)'-Q;"D*("`@('L*("`@("`@("`D<F5S
M=6QT(#T@0'!G7W%U97)Y*"1T:&ES+3YD8BP@)'-Q;"D["B`@("`@("`@:68@
M*"$D<F5S=6QT*2!["B`@("`@("`@("`@('1H<F]W(&YE=R!21$]?17AC97!T
M:6]N*'!G7VQA<W1?97)R;W(H*2D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!`<&=?9F5T8VA?<F5S=6QT*"1R97-U;'0L(#`L(#`I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@57-E(&9O<B!)3E-%4E0L(%501$%412P@1$5,151%+"!A
M;F0@;W1H97(@<75E<FEE<R!T:&%T(&1O;B=T"B`@("`@*B!R971U<FX@<F]W
M<RX@4F5T=7)N<R!N=6UB97(@;V8@869F96-T960@<F]W<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S<6P@5&AE('%U97)Y('1O(')U;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@5&AE(&YU;6)E<B!O9B!R;W=S
M(&%F9F5C=&5D(&)Y("1S<6PN"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO
M;B!E>&5C=71E*"1S<6PI"B`@("!["B`@("`@("`@)')E<W5L="`]($!P9U]Q
M=65R>2@D=&AI<RT^9&(L("1S<6PI.PH@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("!T:')O=R!N97<@4D1/7T5X8V5P=&EO;BAP9U]L87-T
M7V5R<F]R*"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@<&=?869F96-T
M961?<F]W<R@D<F5S=6QT*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!M
M971A9&%T82!O;B!T:&4@9&%T86)A<V4@=&%B;&4@=&AA="`D;6%P<&5R)W,@
M;V)J96-T<R!A<F4*("`@("`J('-T;W)E9"!I;BP@86YD('-E="!I="!I;B!T
M:&4@<&%S<V5D("1M971A9&%T82!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(%)$3U]-87!P97(@)&UA<'!E<B!4:&4@36%P<&5R(&]B:F5C="!T;R!D
M97-C<FEB92X*("`@("`J($!P87)A;2!21$]?365T841A=&$@)&UE=&%D871A
M(%1H92!-971A1&%T82!I;G-T86YC92!T;R!S970@9FEE;&0@:6YF;W)M871I
M;VX@;VXN"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!D97-C<FEB92A2
M1$]?36%P<&5R("1M87!P97(L(%)$3U]-971A1&%T82`D;65T861A=&$I"B`@
M("!["B`@("`@("`@)&9I96QD<R`]($!P9U]M971A7V1A=&$H)'1H:7,M/F1B
M+"`D;65T861A=&$M/F-O;G1A:6YE<BD["B`@("`@("`@:68@*"$D9FEE;&1S
M*2!["B`@("`@("`@("`@('1H<F]W(&YE=R!21$]?17AC97!T:6]N*'!G7VQA
M<W1?97)R;W(H*2D["B`@("`@("`@?0H*("`@("`@("`D:6YD:6-E<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A<R`D9FEE;&0@/3X@
M)'9A;',I('L*("`@("`@("`@("`@)&UE=&%D871A+3YA9&1&:65L9"@D9FEE
M;&0L("1V86QS*3L*("`@("`@("`@("`@)&UE=&%D871A+3YS971&:65L9%1Y
M<&4H)&9I96QD+"`D=F%L<ULG='EP92==*3L*("`@("`@("`@("`@)&EN9&EC
M97-;)'9A;'-;)VYU;2==72`]("1F:65L9#L*("`@("`@("!]"@H@("`@("`@
M("1I9'AR97-U;'0@/2!`<&=?<75E<GDH)'1H:7,M/F1B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)U-%3$5#5"!I+FEN9&ES=6YI<75E+"!I
M+FEN9&ES<')I;6%R>2P@:2YI;F1K97D@1E)/32!P9U]C;&%S<R!C+"!P9U]I
M;F1E>"!I(%=(15)%(&,N;VED(#T@:2YI;F1R96QI9"!!3D0@8RYR96QN86UE
M(#T@7"<G("X@)&UE=&%D871A+3YC;VYT86EN97(@+B`G7"<G*3L*("`@("`@
M("!I9B`H(21I9'AR97-U;'0I('L*("`@("`@("`@("`@=&AR;W<@;F5W(%)$
M3U]%>&-E<'1I;VXH)T9A:6QE9"!T;R!G970@:6YD97@@:6YF;W)M871I;VXZ
M("<@+B!P9U]L87-T7V5R<F]R*"DI.PH@("`@("`@('T*"B`@("`@("`@)&ED
M>&EN9F\@/2!P9U]F971C:%]A;&PH)&ED>')E<W5L="D["B`@("`@("`@:68@
M*"$D:61X:6YF;RD@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*
M("`@("`@("!F;W)E86-H("@D:61X:6YF;R!A<R`D:61X*2!["B`@("`@("`@
M("`@(&EF("@D:61X6R=I;F1I<W!R:6UA<GDG72`]/2`G="<I('L*("`@("`@
M("`@("`@("`@("1M971A9&%T82T^:V5Y(#T@)&EN9&EC97-;)&ED>%LG:6YD
M:V5Y)UU=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@8F5G:6XH*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T)%1TE.)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!C;VUM:70H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T-/34U)5"<I.PH@
M("`@?0H*("`@("\J*@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@<F]L
M;&)A8VLH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)U)/
M3$Q"04-+)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&<F5E(&$@4&]S=&=R
M95-13"!R97-U;'0@<F5S;W5R8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("1R97-U;'0@5&AE(')E<W5L="!T;R!F<F5E+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B!3=6-C97-S+V9A:6QU<F4N"B`@("`@*B\*
M("`@('!U8FQI8R!F=6YC=&EO;B!F<F5E*"1R97-U;'0I"B`@("!["B`@("`@
M("`@<F5T=7)N($!P9U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($)U:6QD(&$@8V]N;F5C=&EO;B!S=')I;F<@86YD(&-O
M;FYE8W0@=&\@=&AE(%!O<W1G<F5344P@<V5R=F5R+@H@("`@("HO"B`@("!P
M<FEV871E(&9U;F-T:6]N(&-O;FYE8W0H*0H@("`@>PH@("`@("`@("1C;VYN
M<W1R(#T@)R<["@H@("`@("`@("1P<F]T;V-O;"`]("1T:&ES+3YP<F]T;V-O
M;"`_("1T:&ES+3YP<F]T;V-O;"`Z("=T8W`G.PH@("`@("`@(&EF("@D<')O
M=&]C;VP@/3T@)W1C<"<I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YH;W-T
M<W!E8RD@>PH@("`@("`@("`@("`@("`@)&-O;FYS='(@+CT@)VAO<W0])R`N
M("1T:&ES+3YH;W-T<W!E8SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/G!O<G0I('L*("`@("`@("`@("`@("`@("1C;VYN<W1R("X]
M("<@<&]R=#TG("X@)'1H:7,M/G!O<G0["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V5I9B`H)'!R;W1O8V]L(#T]("=U;FEX)RD@>PH@("`@("`@("`@
M("`O+R!!;&QO=R!F;W(@<&<@<V]C:V5T(&EN(&YO;BUS=&%N9&%R9"!L;V-A
M=&EO;G,N"B`@("`@("`@("`@(&EF("@D=&AI<RT^<V]C:V5T*2!["B`@("`@
M("`@("`@("`@("`D8V]N;G-T<B`N/2`G:&]S=#TG("X@)'1H:7,M/G-O8VME
M=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/G!O<G0I
M('L*("`@("`@("`@("`@("`@("1C;VYN<W1R("X]("<@<&]R=#TG("X@)'1H
M:7,M/G!O<G0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@D=&AI<RT^9&%T86)A<V4I('L*("`@("`@("`@("`@)&-O;FYS='(@+CT@
M)R!D8FYA;64]7"<G("X@861D<VQA<VAE<R@D=&AI<RT^9&%T86)A<V4I("X@
M)UPG)SL*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YU<V5R;F%M92D@
M>PH@("`@("`@("`@("`D8V]N;G-T<B`N/2`G('5S97(]7"<G("X@861D<VQA
M<VAE<R@D=&AI<RT^=7-E<FYA;64I("X@)UPG)SL*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3YP87-S=V]R9"D@>PH@("`@("`@("`@("`D8V]N;G-T
M<B`N/2`G('!A<W-W;W)D/5PG)R`N(&%D9'-L87-H97,H)'1H:7,M/G!A<W-W
M;W)D*2`N("=<)R<["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<RD@>PH@("`@("`@("`@("`D8V]N;G-T<B`N/2`G(&]P=&EO;G,])R`N
M("1T:&ES+3YO<'1I;VYS.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M
M/G1T>2D@>PH@("`@("`@("`@("`D8V]N;G-T<B`N/2`G('1T>3TG("X@)'1H
M:7,M/G1T>3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YC;VYN96-T
M7W1I;65O=70I('L*("`@("`@("`@("`@)&-O;FYS='(@+CT@)R!C;VYN96-T
M7W1I;65O=70])R`N("1T:&ES+3YC;VYN96-T7W1I;65O=70["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^<W-L;6]D92D@>PH@("`@("`@("`@("`D
M8V]N;G-T<B`N/2`G('-S;&UO9&4])R`N("1T:&ES+3YS<VQM;V1E.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'1H:7,M/G-E<G9I8V4I('L*("`@("`@("`@
M("`@)&-O;FYS='(@+CT@)R!S97)V:6-E/2<@+B`D=&AI<RT^<V5R=FEC93L*
M("`@("`@("!]"@H@("`@("`@("1F=6YC=&EO;B`]("1T:&ES+3YP97)S:7-T
M96YT(#\@)W!G7W!C;VYN96-T)R`Z("=P9U]C;VYN96-T)SL*("`@("`@("`D
M:6YI(#T@:6YI7V=E="@G=')A8VM?97)R;W)S)RD["B`@("`@("`@)'!H<%]E
M<G)O<FUS9R`]("<G.PH@("`@("`@(&EF("@D:6YI*2!["B`@("`@("`@("`@
M("1T:&ES+3YD8B`]($!C86QL7W5S97)?9G5N8R@D9G5N8W1I;VXL("1C;VYN
M<W1R*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I;FE?<V5T*"=T
M<F%C:U]E<G)O<G,G+"`Q*3L*("`@("`@("`@("`@)'1H:7,M/F1B(#T@0&-A
M;&Q?=7-E<E]F=6YC*"1F=6YC=&EO;BP@)&-O;FYS='(I.PH@("`@("`@("`@
M("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`D:6YI*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A)'1H:7,M/F1B*2!["B`@("`@("`@("`@('1H<F]W(&YE
M=R!21$]?17AC97!T:6]N*"1P:'!?97)R;W)M<V<I.PH@("`@("`@('T*("`@
M('T*"GT*"B\J*@H@*B!`<&%C:V%G92!21$\*("HO"F-L87-S(%)$3U]297-U
M;'1S7W!G<W%L(&5X=&5N9',@4D1/7U)E<W5L=',@>PH*("`@("\J*@H@("`@
M("H@1FEN9"!T:&4@;G5M8F5R(&]F(&]B:F5C=',@:6X@=&AI<R!R97-U;'0@
M<V5T+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B!.=6UB97(@;V8@
M;V)J96-T<R!I;B!T:&ES('-E="X*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T
M:6]N(&-O=6YT*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^
M<F5S=6QT*2D@>PH@("`@("`@("`@("`D=&AI<RT^<F5W:6YD*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!P9U]N=6U?<F]W<R@D=&AI<RT^<F5S=6QT
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($EM<&QE;65N=&%T:6]N(&]F('1H
M92!R97=I;F0H*2!M971H;V0@9F]R(%!G<W%L(')E<W5L="!S971S+@H@("`@
M("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@<F5W:6YD*"D*("`@('L*("`@("`@
M("`O+R!297=I;F0@;VYL>2!I9B!N979E<B!Q=65R:65D(&)E9F]R92!O<B!Q
M=65R>2!W87,*("`@("`@("`O+R!S=6-C97-S9G5L+@H@("`@("`@(&EF("AI
M<U]N=6QL*"1T:&ES+3YR97-U;'0I('Q\(&ES7W)E<V]U<F-E*"1T:&ES+3YR
M97-U;'0I*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^<F5S=6QT*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<W1O<F%G92T^9G)E92@D=&AI<RT^<F5S
M=6QT*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^8W5R<F5N
M="`](&YU;&P["B`@("`@("`@("`@("1T:&ES+3YI;F1E>"`](&YU;&P["B`@
M("`@("`@("`@("1T:&ES+3YE;V8@/2!T<G5E.PH*("`@("`@("`@("`@)'1H
M:7,M/G)E<W5L="`]("1T:&ES+3YS=&]R86=E+3YF:6YD3F]W*"1T:&ES+3YM
M87!P97(L("1T:&ES+3YM;V1E+"`D=&AI<RT^8W)I=&5R:6$I.PH@("`@("`@
M("`@("!I9B`H(21T:&ES+3YR97-U;'0I('L*("`@("`@("`@("`@("`@('1H
M<F]W(&YE=R!21$]?17AC97!T:6]N*'!G7VQA<W1?97)R;W(H*2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/FYE>'0H*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);7!L96UE;G1A=&EO;B!O9B!T:&4@
M;F5X="@I(&UE=&AO9"!F;W(@4&=S<6P@<F5S=6QT('-E=',N"B`@("`@*@H@
M("`@("H@0')E='5R;B!21$]\;G5L;"!4:&4@;F5X="!21$\@:6YS=&%N8V4@
M:6X@=&AE('-E="!O<B!N=6QL(&EF(&YO"B`@("`@*B!M;W)E(')E<W5L=',N
M"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!N97AT*"D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^<F5S=6QT*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^<F5W:6YD*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H
M:7,M/G)E<W5L="D@>PH@("`@("`@("`@("`D=&AI<RT^8W5R<F5N="`]('!G
M7V9E=&-H7V%S<V]C*"1T:&ES+3YR97-U;'0I.PH@("`@("`@("`@("!I9B`H
M(21T:&ES+3YC=7)R96YT*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^96]F
M(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YE;V8@/2!F86QS93L*"B`@("`@("`@("`@("`@("!I9B`H:7-?
M;G5L;"@D=&AI<RT^:6YD97@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FEN9&5X(#T@,#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@*RLD=&AI<RT^:6YD97@["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3YC=7)R96YT
M(#T@)'1H:7,M/FUA<'!E<BT^;6%P*"1T:&ES+3YC=7)R96YT*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^8W5R<F5N=#L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)$3R]3=&]R86=E+W-Q;"YP:'``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3$W,0`Q,#0Q-S,V,C<W,0`P
M,C$U-S0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($)A<V4@4U%,(%-T;W)A9V4@:6UP;&5M96YT871I
M;VX@9F]R(&-O;6UO;B!F=6YC=&EO;F%L:71Y+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]21$\O4D1/+U-T;W)A9V4O<W%L+G!H<"QV(#$N,RXR+C$@,C`P
M-2\Q,"\Q."`Q,3HP,3HR,R!J86X@17AP("0*("H*("H@0'!A8VMA9V4@4D1/
M"B`J+PIA8G-T<F%C="!C;&%S<R!21$]?4W1O<F%G95]S<6P@97AT96YD<R!2
M1$]?4W1O<F%G92!["@H@("`@+RHJ"B`@("`@*B\*("`@('!U8FQI8R!F=6YC
M=&EO;B!E>&ES=',H4D1/7TUA<'!E<B`D;6%P<&5R+"`D8W)I=&5R:6$I"B`@
M("!["B`@("`@("`@)&-R:71E<FEA(#T@)'1H:7,M/G1O0W)I=&5R:6$H)&-R
M:71E<FEA+"`D;6%P<&5R*3L*("`@("`@("`D8W)I=&5R:6$M/G-E=$9I96QD
M<RAA<G)A>2@Q*2D["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>4]N92@D
M=&AI<RT^<')O8V5S<R@D8W)I=&5R:6$I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N(&-O=6YT*%)$3U]-87!P97(@)&UA
M<'!E<BP@)&-R:71E<FEA*0H@("`@>PH@("`@("`@("1C<FET97)I82`]("1T
M:&ES+3YT;T-R:71E<FEA*"1C<FET97)I82P@)&UA<'!E<BD["B`@("`@("`@
M)&-R:71E<FEA+3YS971&:65L9',H87)R87DH)T-/54Y4*"HI)RDI.PH@("`@
M("`@(')E='5R;B`D=&AI<RT^<75E<GE/;F4H)'1H:7,M/G!R;V-E<W,H)&-R
M:71E<FEA*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B\*("`@('!U8FQI8R!F
M=6YC=&EO;B!F:6YD3F]W*%)$3U]-87!P97(@)&UA<'!E<BP@)&UO9&4L("1C
M<FET97)I82D*("`@('L*("`@("`@("`D8W)I=&5R:6$@/2`D=&AI<RT^=&]#
M<FET97)I82@D8W)I=&5R:6$L("1M87!P97(I.PH@("`@("`@("1C<FET97)I
M82T^<V5T1FEE;&1S*&%R<F%Y*"<J)RDI.PH*("`@("`@("!I9B`H)&UO9&4@
M/3T@4D1/.CI&24Y$7T9)4E-4*2!["B`@("`@("`@("`@("1C<FET97)I82T^
M;&EM:70H,2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/G%U
M97)Y*"1T:&ES+3YP<F]C97-S*"1C<FET97)I82DI.PH@("`@?0H*("`@("\J
M*@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@<75O=&4H)&9I96QD+"`D
M9&%T82`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&1A=&$I
M*2!["B`@("`@("`@("`@(')E='5R;B`G3E5,3"<["B`@("`@("`@?0H*("`@
M("`@("!S=VET8V@@*"1F:65L9%LG='EP92==*2!["B`@("`@("`@8V%S92!2
M1$]?365T841A=&$Z.DE.5$5'15(Z"B`@("`@("`@("`@(')E='5R;B`H:6YT
M*21D871A.PH*("`@("`@("!C87-E(%)$3U]-971A1&%T83HZ4U1224Y'.@H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G%U;W1E4W1R:6YG*"1D871A*3L*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@=&AR;W<@;F5W(%)$3U]%
M>&-E<'1I;VXH)U5N:VYO=VX@9&%T82!T>7!E.B`G("X@)&9I96QD6R=T>7!E
M)UTI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J+PH@("`@<'5B
M;&EC(&9U;F-T:6]N('!R;V-E<W,H4D1/7T-R:71E<FEA("1C<FET97)I82D*
M("`@('L*("`@("`@("`D;65T82`]("1C<FET97)I82T^;6%P<&5R+3YD97-C
M<FEB92@I.PH*("`@("`@("`D<W%L(#T@)U-%3$5#5"`G("X@:6UP;&]D92@G
M+"`G+"`D8W)I=&5R:6$M/F9I96QD<RD@+@H@("`@("`@("`@("`G($923TT@
M)R`N("1M971A+3YC;VYT86EN97(["@H@("`@("`@(&9O<F5A8V@@*"1C<FET
M97)I82T^<F5L871I;VYS:&EP<R!A<R`D<F5L871I;VYS:&EP*2!["B`@("`@
M("`@("`@("1R;65T82`]("1R96QA=&EO;G-H:7!;)VUA<'!E<B==+3YD97-C
M<FEB92@I.PH@("`@("`@("`@("`D<W%L("X]("<@24Y.15(@2D])3B`G("X@
M)')E;&%T:6]N<VAI<%LG8V]N=&%I;F5R)UT@+B`G($].("<@+@H@("`@("`@
M("`@("`@("`@)&UE=&$M/F-O;G1A:6YE<B`N("<N)R`N("1M971A+3YK97D@
M+B`G(#T@)R`N("1R96QA=&EO;G-H:7!;)V-O;G1A:6YE<B==("X@)RXG("X@
M)&UE=&$M/FME>3L*("`@("`@("`@("`@9F]R96%C:"`H)')E;&%T:6]N<VAI
M<%LG8W)I=&5R:6$G72!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@
M("`@("`@)'-Q;"`N/2`G($%.1"`G("X@)')E;&%T:6]N<VAI<%LG8V]N=&%I
M;F5R)UT@+B`G+B<@+B`D:V5Y("X@)R`]("<@+B`D=F%L=64["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1C;&%U<V5S(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$M/G1E<W1S(&%S("1T97-T*2![
M"B`@("`@("`@("`@("1C;&%U<V5S6UT@/2`D=&5S=%LG9FEE;&0G72`N("<@
M)R`N("1T97-T6R=T97-T)UT@+B`G("<@+B`D=&AI<RT^<75O=&4H)&UE=&$M
M/F=E=$9I96QD*"1T97-T6R=F:65L9"==*2P@)'1E<W1;)W9A;'5E)UTI.PH@
M("`@("`@('T*("`@("`@("!I9B`H)&-L875S97,I('L*("`@("`@("`@("`@
M)'-Q;"`N/2`G(%=(15)%("<@+B!I;7!L;V1E*"<@)R`N("1C<FET97)I82T^
M8V]N:G5N8W1I;VX@+B`G("<L("1C;&%U<V5S*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D8W)I=&5R:6$M/FQI;6ET*2!["B`@("`@("`@("`@("1S<6P@
M+CT@)R!,24U)5"`G("X@)&-R:71E<FEA+3YL:6UI=#L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<W%L.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O4D1/+U-T;W)A9V4O<W%L:71E+G!H<```````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q-C(W`#$P-#$W,S8R-S<Q`#`R,C,P,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M4U%,:71E($1"3U]3=&]R86=E(&EM<&QE;65N=&%T:6]N+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]21$\O4D1/+U-T;W)A9V4O<W%L:71E+G!H<"QV(#$N
M-2XR+C$@,C`P-2\Q,"\Q."`Q,3HP,3HR,R!J86X@17AP("0*("H*("H@0'!A
M8VMA9V4@4D1/"B`J+PIC;&%S<R!21$]?4W1O<F%G95]S<6QI=&4@97AT96YD
M<R!21$]?4W1O<F%G95]S<6P@>PH*("`@("\J*@H@("`@("H@2'5M86XM<F5A
M9&%B;&4@;F%M92!F;W(@=&AI<R!3=&]R86=E(&1R:79E<BX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9R`D;F%M90H@("`@("HO"B`@("!P=6)L:6,@)&YA
M;64@/2`G4U%,:71E)SL*"B`@("`O*BH*("`@("`J($9R964@86YY(')E<V]U
M<F-E<R!T:&%T(&%R92!O<&5N+@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I
M;VX@7U]D97-T<G5C="@I"B`@("!["B`@("!]"@H@("`@<'5B;&EC(&9U;F-T
M:6]N(&1E<V-R:6)E*%)$3U]-87!P97(@)&UA<'!E<BP@4D1/7TUE=&%$871A
M("1M971A9&%T82D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%5S92!F
M;W(@4T5,14-4(&%N9"!A;GET:&EN9R!T:&%T(')E='5R;G,@<F]W<RX*("`@
M("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N('%U97)Y*"1S<6PI"B`@("!["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!5<V4@9F]R($E.4T525"P@55!$051%+"!$
M14Q%5$4N(%)E='5R;G,@;G5M8F5R(&]F(&%F9F5C=&5D"B`@("`@*B!R;W=S
M+@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@97AE8W5T92@D<W%L*0H@
M("`@>PH@("`@?0H*("`@('!U8FQI8R!F=6YC=&EO;B!B96=I;B@I"B`@("![
M"B`@("!]"@H@("`@<'5B;&EC(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@
M("!]"@H@("`@<'5B;&EC(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O4D1/+T5X8V5P=&EO;BYP:'``````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-S(U`#$P-#$W,S8R-S<Q`#`R,3,R-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@4D1/($5X8V5P=&EO;B!C;&%S<RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO4D1/+U)$3R]%>&-E<'1I;VXN<&AP+'8@,2XQ+C(N,2`R,#`U+S$P
M+S$X(#$Q.C`Q.C(S(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!21$\*("HO
M"F-L87-S(%)$3U]%>&-E<'1I;VX@97AT96YD<R!%>&-E<'1I;VX@>PH*("`@
M('!R;W1E8W1E9"`D;65S<V%G93L*("`@('!R;W1E8W1E9"`D8V]D93L*"B`@
M("!P=6)L:6,@9G5N8W1I;VX@7U]C;VYS=')U8W0H)&UE<W-A9V4@/2!N=6QL
M+"`D8V]D92`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/FUE<W-A9V4@
M/2`D;65S<V%G93L*("`@("`@("`D=&AI<RT^8V]D92`]("1C;V1E.PH@("`@
M?0H*("`@('!U8FQI8R!F=6YC=&EO;B!?7W1O4W1R:6YG*"D*("`@('L*("`@
M("`@("!R971U<FX@(BA[)'1H:7,M/F-O9&5]*2![)'1H:7,M/FUE<W-A9V5]
M(CL*("`@('T*"GT*````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U)$3R]-87!P97(N<&AP````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R-#,Q-``Q,#0Q-S,V,C<W,0`P,C`V,34`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%)$3R!-
M87!P97(@8F%S92!C;&%S<RX*("H*("H@0'!A8VMA9V4@4D1/"B`J+PH*+RHJ
M"B`J(%)$3R!-87!P97(@8VQA<W,N($-O;G1R;VQS(&UA<'!I;F<@;V8@96YT
M:71Y(&]B96-T<R`H:6YS=&%N8V5S(&]F"B`J(%)$3RD@9G)O;2!A;F0@=&\@
M4D1/7U-T;W)A9V4@8F%C:V5N9',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U)$3R]21$\O36%P<&5R+G!H<"QV(#$N-RXR+C$@,C`P-2\Q,"\Q."`Q,3HP
M,3HR,R!J86X@17AP("0*("H*("H@0'!A8VMA9V4@4D1/"B`J+PIA8G-T<F%C
M="!C;&%S<R!21$]?36%P<&5R('L*"B`@("`O*BH*("`@("`J($EF('1H:7,@
M:7,@=')U92!A;F0@9FEE;&1S(&YA;65D(&-R96%T960@86YD('5P9&%T960@
M87)E"B`@("`@*B!P<F5S96YT+"!21$\@=VEL;"!A=71O;6%T:6-A;&QY('-E
M="!C<F5A=&EO;B!A;F0@;&%S="!U<&1A=&5D"B`@("`@*B!T:6UE<W1A;7!S
M+B!4:6UE<W1A;7!S(&%R92!A;'=A>7,@1TU4(&9O<B!P;W)T86)I;&ET>2X*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@<')O=&5C
M=&5D("1S9714:6UE<W1A;7!S(#T@=')U93L*"B`@("`O*BH*("`@("`J(%=H
M870@8VQA<W,@<VAO=6QD('1H:7,@36%P<&5R(&-R96%T92!F;W(@;V)J96-T
M<S\@1&5F875L=',@=&\*("`@("`J('1H92!-87!P97(@<W5B8VQA<W,G(&YA
M;64@;6EN=7,@(DUA<'!E<B(N(%-O(&EF('1H92!21$]?36%P<&5R"B`@("`@
M*B!S=6)C;&%S<R!I<R!5<V5R36%P<&5R+"!I="!W:6QL(&1E9F%U;'0@=&\@
M=')Y:6YG('1O(&-R96%T90H@("`@("H@57-E<B!O8FIE8W1S+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG("1C;&%S<VYA;64*("`@("`J+PH@("`@<')O
M=&5C=&5D("1C;&%S<VYA;64["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O
M9B!T:&4@8V]N=&%I;F5R("A344P@=&%B;&4L($Q$05`@1$XO;V)J96-T0VQA
M<W,L"B`@("`@*B!E=&,N*2!T:&%T(&AO;&1S('1H:7,@36%P<&5R)W,@;V)J
M96-T<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9R`D8V]N=&%I;F5R"B`@
M("`@*B\*("`@('!R;W1E8W1E9"`D8V]N=&%I;F5R.PH*("`@("\J*@H@("`@
M("H@4D1/7U-T;W)A9V4@;V)J96-T('1H870@<W1O<F5S('1H:7,@36%P<&5R
M)W,@;V)J96-T<RX*("`@("`J"B`@("`@*B!`=F%R(%)$3U]3=&]R86=E("1S
M=&]R86=E"B`@("`@*B\*("`@('!R;W1E8W1E9"`D<W1O<F%G93L*"B`@("`O
M*BH*("`@("`J(%)$3U]-971A1&%T82!O8FIE8W0@9&5S8W)I8FEN9R!T:&4@
M9FEE;&1S(&]F('1H:7,@:VEN9"!O9@H@("`@("H@;V)J96-T+@H@("`@("H*
M("`@("`J($!V87(@4D1/7TUE=&%$871A("1M971A9&%T80H@("`@("HO"B`@
M("!P<F]T96-T960@)&UE=&%D871A.PH*("`@("\J*@H@("`@("H@07-S;V-I
M871E(&$@<W1O<F%G92!O8FIE8W0@=VET:"!T:&ES(&UA<'!E<BX@3F]T(&YE
M961E9"!I;B!T:&4*("`@("`J(&=E;F5R86P@8V%S92!I9B!G9713=&]R86=E
M*"D@:7,@;W9E<G)I9&1E;B!I;B!T:&4@8V]N8W)E=&4*("`@("`J($UA<'!E
M<B!I;7!L96UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@4D1/7U-T
M;W)A9V4@)'-T;W)A9V4@4D1/7U-T;W)A9V4@:6YS=&%N8V4@=&\@<W1O<F4@
M;V)J96-T<RX*("`@("`J"B`@("`@*B!`<V5E(&=E=%-T;W)A9V4H*0H@("`@
M("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@<V5T4W1O<F%G92A21$]?4W1O<F%G
M92`D<W1O<F%G92D*("`@('L*("`@("`@("`D=&AI<RT^<W1O<F%G92`]("1S
M=&]R86=E.PH@("`@?0H*("`@("\J*@H@("`@("H@9V5T4W1O<F%G92@I(&UU
M<W0@8F4@;W9E<G)I9&1E;B!B>2!21$]?36%P<&5R('-U8F-L87-S97,@:68*
M("`@("`J('1H97D@9&]N)W0@<')O=FED92`D<W1O<F%G92!I;B!S;VUE(&]T
M:&5R('=A>2`H8GD@8V%L;&EN9PH@("`@("H@<V5T4W1O<F%G92@I(&]R(&]N
M(&-O;G-T<G5C=&EO;BP@9F]R(&5X86UP;&4I+@H@("`@("H*("`@("`J($!S
M964@<V5T4W1O<F%G92@I"B`@("`@*@H@("`@("H@0')E='5R;B!21$]?4W1O
M<F%G92!4:&4@<W1O<F%G92!O8FIE8W0@=&AI<R!-87!P97(G<R!O8FIE8W1S
M"B`@("`@*B!A<F4@<W1O<F5D('1O+@H@("`@("HO"B`@("!P=6)L:6,@9G5N
M8W1I;VX@9V5T4W1O<F%G92@I"B`@("!["B`@("`@("`@=&AR;W<@;F5W(%)$
M3U]%>&-E<'1I;VXH)UEO=2!M=7-T(&5I=&AE<B!O=F5R<FED92!G9713=&]R
M86=E*"D@;W(@87-S:6=N(&$@4D1/7U-T;W)A9V4@8V]N=&%I;F5R(&)Y(&-A
M;&QI;F<@<V5T4W1O<F%G92@I+B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3&%Z>2!L;V%D:6YG(&]F("1T:&ES+3YS=&]R86=E+B!!8V-E<W-I;F<@)'-T
M;W)A9V4@=&AR;W5G:"!T:&ES"B`@("`@*B!F=6YC=&EO;B!M96%N<R!Y;W4@
M;F5V97(@:&%V92!T;R!C86QL(&=E=%-T;W)A9V4H*2!Y;W5R<V5L9BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(%)$3U]3=&]R86=E(%1H92!S=&]R86=E(&]B
M:F5C="!T:&ES($UA<'!E<B=S(&]B:F5C=',*("`@("`J(&%R92!S=&]R960@
M=&\N"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!S=&]R86=E*"D*("`@
M('L*("`@("`@("!I9B`H(21T:&ES+3YS=&]R86=E*2!["B`@("`@("`@("`@
M("1T:&ES+3YS=&]R86=E(#T@)'1H:7,M/F=E=%-T;W)A9V4H*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YS=&]R86=E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3&%Z>2!L86]D:6YG(&]F('1H92!M971A9&%T82!O8FIE
M8W0@;V8@=&AI<R!-87!P97(G<R!F:65L9',@86YD"B`@("`@*B!P<F]P97)T
M:65S+@H@("`@("H*("`@("`J($!R971U<FX@4D1/7TUE=&%$871A($1E<V-R
M:7!T:6]N(&]F('1H:7,@36%P<&5R)W,@9FEE;&1S+@H@("`@("HO"B`@("!P
M=6)L:6,@9G5N8W1I;VX@9&5S8W)I8F4H*0H@("`@>PH@("`@("`@(&EF("@A
M)'1H:7,M/FUE=&%D871A*2!["B`@("`@("`@("`@("1T:&ES+3YM971A9&%T
M82`](&YE=R!21$]?365T841A=&$H)'1H:7,I.PH@("`@("`@("`@("`D=&AI
M<RT^;65T861A=&$M/F-O;G1A:6YE<B`]("1T:&ES+3YC;VYT86EN97(["B`@
M("`@("`@("`@("1T:&ES+3YS=&]R86=E*"DM/F1E<V-R:6)E*"1T:&ES+"`D
M=&AI<RT^;65T861A=&$I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/FUE=&%D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&%N
M(&EN<W1A;F-E(&]F("1T:&ES+3YC;&%S<VYA;64@9G)O;2!A('-E="!O9B!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9FEE;&1S($9I96QD
M(&YA;65S+V1E9F%U;'0@=F%L=65S(&9O<B!T:&4@;F5W(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<V5E("1C;&%S<VYA;64*("`@("`J"B`@("`@*B!`<F5T
M=7)N(%)$3R!!;B!I;G-T86YC92!O9B`D=&AI<RT^8VQA<W-N86UE('=I=&@@
M)&9I96QD<R!A<R!I;FET:6%L(&1A=&$N"B`@("`@*B\*("`@('!U8FQI8R!F
M=6YC=&EO;B!M87`H)&9I96QD<RD*("`@('L*("`@("`@("`O+R!'=65S<R!A
M(&-L87-S;F%M92!I9B!O;F4@:7-N)W0@97AP;&EC:71L>2!S970N"B`@("`@
M("`@:68@*"$D=&AI<RT^8VQA<W-N86UE*2!["B`@("`@("`@("`@("1T:&ES
M+3YC;&%S<VYA;64@/2!S=')?<F5P;&%C92@G36%P<&5R)RP@)R<L(&=E=%]C
M;&%S<R@D=&AI<RDI.PH@("`@("`@('T*"B`@("`@("`@)&\@/2!N97<@)'1H
M:7,M/F-L87-S;F%M92@D9FEE;&1S*3L*("`@("`@("`D;RT^<V5T36%P<&5R
M*"1T:&ES*3L*("`@("`@("!R971U<FX@)&\["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;W5N="!O8FIE8W1S('1H870@;6%T8V@@)&-R:71E<FEA+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D8W)I=&5R:6$@5&AE(&-R:71E<FEA
M('1O(&-O=6YT(&UA=&-H97,@;V8N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R($%L;"!O8FIE8W1S(&UA=&-H:6YG("1C<FET97)I82X*("`@("`J
M+PH@("`@<'5B;&EC(&9U;F-T:6]N(&-O=6YT*"1C<FET97)I82`](&YU;&PI
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YS=&]R86=E*"DM/F-O=6YT
M*"1T:&ES+"`D8W)I=&5R:6$I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VL@:68@870@;&5A<W0@;VYE(&]B:F5C="!M871C:&5S("1C<FET97)I82X*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&-R:71E<FEA($5I=&AE<B!A
M('!R:6UA<GD@:V5Y+"!A;B!A<G)A>2!O9B!K97ES"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(#T^('9A;'5E<RP@;W(@86X@4D1/7T-R:71E<FEA
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5')U92!O
M<B!F86QS92X*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N(&5X:7-T<R@D
M8W)I=&5R:6$I"B`@("!["B`@("`@("`@<F5T=7)N("AB;V]L*21T:&ES+3YS
M=&]R86=E*"DM/F5X:7-T<R@D=&AI<RP@)&-R:71E<FEA*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T92!A(&YE=R!O8FIE8W0@:6X@=&AE(&)A8VME
M;F0@=VET:"`D9FEE;&1S(&%S(&EN:71I86P@=F%L=65S+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D9FEE;&1S($%R<F%Y(&]F(&9I96QD(&YA;65S
M(#T^(&EN:71I86P@=F%L=65S+@H@("`@("H*("`@("`J($!R971U<FX@4D1/
M(%1H92!N97=L>2!C<F5A=&5D(&]B:F5C="X*("`@("`J+PH@("`@<'5B;&EC
M(&9U;F-T:6]N(&-R96%T92@D9FEE;&1S*0H@("`@>PH@("`@("`@("\O($EF
M(&-O;F9I9W5R960@=&\@<F5C;W)D(&-R96%T:6]N(&%N9"!U<&1A=&4@=&EM
M97,L('-E="!T:&5M"B`@("`@("`@+R\@:&5R92X@5V4@<V5T('5P9&%T960@
M=&\@=&AE(&EN:71I86P@8W)E871I;VX@=&EM92!S;R!I="=S"B`@("`@("`@
M+R\@86QW87ES('-E="X*("`@("`@("!I9B`H)'1H:7,M/G-E=%1I;65S=&%M
M<',I('L*("`@("`@("`@("`@)'1I;64@/2!G;6UK=&EM92@I.PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/F1E<V-R:6)E*"DM/FAA<T9I96QD*"=C<F5A=&5D
M)RDI('L*("`@("`@("`@("`@("`@("1F:65L9'-;)V-R96%T960G72`]("1T
M:6UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^9&5S
M8W)I8F4H*2T^:&%S1FEE;&0H)W5P9&%T960G*2D@>PH@("`@("`@("`@("`@
M("`@)&9I96QD<ULG=7!D871E9"==(#T@)'1I;64["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1I9"`]("1T:&ES+3YS=&]R86=E*"DM/F-R
M96%T92@D=&AI<RP@)&9I96QD<RD["B`@("`@("`@<F5T=7)N("1T:&ES+3YM
M87`H87)R87E?;65R9V4H)&9I96QD<RP@87)R87DH)'1H:7,M/F1E<V-R:6)E
M*"DM/FME>2`]/B`D:60I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A
M=&5S(&$@<F5C;W)D(&EN('1H92!B86-K96YD+B`D;V)J96-T(&-A;B!B92!E
M:71H97(@80H@("`@("H@<')I;6%R>2!K97D@;W(@86X@4D1/(&]B:F5C="X@
M268@)&]B:F5C="!I<R!A;B!21$\@:6YS=&%N8V4*("`@("`J('1H96X@)&9I
M96QD<R!S:&]U;&0@8F4@;G5L;"!A<R!T:&5Y('=I;&P@8F4@<'5L;&5D(&9R
M;VT@=&AE"B`@("`@*B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9WQ21$\@)&]B:F5C="!4:&4@4D1/(&EN<W1A;F-E(&]R('5N:7%U92!I
M9"!T;R!U<&1A=&4N"B`@("`@*B!`<&%R86T@87)R87D@)&9I96QD<R!)9B!P
M87-S:6YG(&$@=6YI<75E(&ED+"!T:&4@87)R87D@;V8@9FEE;&0@<')O<&5R
M=&EE<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@=&\@<V5T(&9O<B`D
M;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B!4<G5E+"!O
M<B!T:')O=R!A;B!E>&-E<'1I;VX@:68@86X@97)R;W(@;V-C=7)S+@H@("`@
M("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@=7!D871E*"1O8FIE8W0L("1F:65L
M9',@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D;V)J96-T(&EN<W1A;F-E
M;V8@4D1/*2!["B`@("`@("`@("`@("1K97D@/2`D=&AI<RT^9&5S8W)I8F4H
M*2T^:V5Y.PH@("`@("`@("`@("`D:60@/2`D;V)J96-T+3XD:V5Y.PH@("`@
M("`@("`@("`D9FEE;&1S(#T@)&]B:F5C="T^9V5T1FEE;&1S*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&ED(#T@)&]B:F5C=#L*("`@("`@
M("!]"@H@("`@("`@("\O($EF(&-O;F9I9W5R960@=&\@<F5C;W)D('5P9&%T
M92!T:6UE+"!S970@:70@:&5R92X*("`@("`@("!I9B`H)'1H:7,M/G-E=%1I
M;65S=&%M<',@)B8@)'1H:7,M/F1E<V-R:6)E*"DM/FAA<T9I96QD*"=U<&1A
M=&5D)RDI('L*("`@("`@("`@("`@)&9I96QD<ULG=7!D871E9"==(#T@9VUM
M:W1I;64H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^<W1O
M<F%G92@I+3YU<&1A=&4H)'1H:7,L("1I9"P@)&9I96QD<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!5<&1A=&5S(&$@<F5C;W)D(&EN('1H92!B86-K96YD
M+B`D;V)J96-T(&-A;B!B92!E:71H97(@80H@("`@("H@<')I;6%R>2!K97DL
M(&%N(%)$3U]#<FET97)I82!O8FIE8W0L(&]R(&%N(%)$3R!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9WQ21$]\4D1/7T-R:71E<FEA("1O
M8FIE8W0@5&AE(%)$3R!I;G-T86YC92P@8W)I=&5R:6$@;V)J96-T+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@
M=6YI<75E(&ED('1O('5P9&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@3G5M8F5R(&]F(&]B:F5C=',@9&5L971E9"X*("`@("`J+PH@("`@
M<'5B;&EC(&9U;F-T:6]N(&1E;&5T92@D;V)J96-T*0H@("`@>PH@("`@("`@
M(&EF("@D;V)J96-T(&EN<W1A;F-E;V8@4D1/*2!["B`@("`@("`@("`@("1K
M97D@/2`D=&AI<RT^9&5S8W)I8F4H*2T^:V5Y.PH@("`@("`@("`@("`D:60@
M/2`D;V)J96-T+3XD:V5Y.PH@("`@("`@("`@("`D8W)I=&5R:6$@/2!A<G)A
M>2@D:V5Y(#T^("1I9"D["B`@("`@("`@?2!E;'-E:68@*"1O8FIE8W0@:6YS
M=&%N8V5O9B!21$]?0W)I=&5R:6$I('L*("`@("`@("`@("`@)&-R:71E<FEA
M(#T@)&]B:F5C=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:V5Y
M(#T@)'1H:7,M/F1E<V-R:6)E*"DM/FME>3L*("`@("`@("`@("`@)&-R:71E
M<FEA(#T@87)R87DH)&ME>2`]/B`D;V)J96-T*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^<W1O<F%G92@I+3YD96QE=&4H)'1H:7,L("1C
M<FET97)I82D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&-A;B!B92!C
M86QL960@:6X@;G5M97)O=7,@=V%Y<RX*("`@("`J"B`@("`@*B!0<FEM87)Y
M(&ME>3H@<&%S<R!F:6YD*"D@82!S:6YG;&4@<')I;6%R>2!K97D@;W(@86X@
M87)R87D@;V8*("`@("`J('!R:6UA<GD@:V5Y<RP@86YD(&ET('=I;&P@<F5T
M=7)N(&5I=&AE<B!A('-I;F=L92!O8FIE8W0@;W(@86X*("`@("`J(%)$3U]2
M97-U;'1S(&-O;&QE8W1O;B!O9B!O8FIE8W1S(&UA=&-H:6YG('1H;W-E('!R
M:6UA<GD@:V5Y<RX*("`@("`J"B`@("`@*B!&:6YD(&UO9&4Z(&]T:&5R=VES
M92!T:&4@9FER<W0@87)G=6UE;G0@=&\@9FEN9"!S:&]U;&0@8F4@80H@("`@
M("H@9FEN9"!M;V1E+B!4:&4@9&5F875L=',@;6]D97,@87)E(%)$3SHZ1DE.
M1%]&25)35"`H<F5T=7)N<R!T:&4*("`@("`J(&9I<G-T(&]B:F5C="!M871C
M:&EN9R!T:&4@<F5S="!O9B!T:&4@8W)I=&5R:6$I+"!A;F0*("`@("`J(%)$
M3SHZ1DE.1%]!3$P@*')E='5R;B!A;B!21$]?4F5S=6QT<R!C;VQL96-T:6]N
M(&]F(&%L;`H@("`@("H@;6%T8VAE<RDN"B`@("`@*@H@("`@("H@5VAE;B!U
M<VEN9R!A(&9I;F0@;6]D92P@=&AE('-E8V]N9"!A<F=U;65N="!C86X@8F4@
M8FQA;FL@*&9I;F0*("`@("`J(&%L;"!O8FIE8W1S+"!O<B!T:&4@9FER<W0@
M;V)J96-T(&1E<&5N9&EN9R!O;B!F:6YD(&UO9&4I+"!A;@H@("`@("H@87-S
M;V-I871I=F4@87)R87D@*&ME>7,@87)E(&9I96QD<RP@=F%L=65S(&%R92!T
M:&4@=F%L=65S('1H;W-E"B`@("`@*B!F:65L9',@;75S="!M871C:"!E>&%C
M=&QY*2P@;W(@86X@4D1/7T-R:71E<FEA(&]B:F5C="P@=VAI8V@*("`@("`J
M(&1E9FEN97,@8V]M<&QE>"!M871C:&EN9R!C<FET97)I82X*("`@("`J+PH@
M("`@<'5B;&EC(&9U;F-T:6]N(&9I;F0H*0H@("`@>PH@("`@("`@("1A<F=C
M(#T@9G5N8U]N=6U?87)G<R@I.PH@("`@("`@("1A<F=V(#T@9G5N8U]G971?
M87)G<R@I.PH*("`@("`@("`O+R!-86ME('-U<F4@=V4@:&%V92!S;VUE('-O
M<G0@;V8@9FEN9"!C<FET97)I82X*("`@("`@("!I9B`H(21A<F=C*2!["B`@
M("`@("`@("`@('1H<F]W(&YE=R!21$]?17AC97!T:6]N*"=F:6YD*"D@8V%L
M;&5D('=I=&@@;F\@87)G=6UE;G1S)RD["B`@("`@("`@?0H*("`@("`@("`O
M+R!&:6=U<F4@;W5T('=H870@:VEN9"!O9B!C<FET97)I82!W92!H879E+@H@
M("`@("`@(&EF("@D87)G8R`]/2`Q*2!["B`@("`@("`@("`@(&EF("@D87)G
M=ELP72`]/2!21$\Z.D9)3D1?1DE24U0@?'P*("`@("`@("`@("`@("`@("1A
M<F=V6S!=(#T](%)$3SHZ1DE.1%]!3$PI('L*("`@("`@("`@("`@("`@("\O
M(%5S:6YG(&$@9FEN9"!M;V1E('=I=&@@;F\@8W)I=&5R:6$N"B`@("`@("`@
M("`@("`@("`D;6]D92`](&%R<F%Y7W-H:69T*"1A<F=V*3L*("`@("`@("`@
M("`@("`@("1C<FET97)I82`](&YU;&P["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`O+R!&:6YD('1H92!N86UE(&]F(&]U<B!P<FEM
M87)Y(&ME>2X*("`@("`@("`@("`@("`@("1K97D@/2`D=&AI<RT^9&5S8W)I
M8F4H*2T^:V5Y.PH@("`@("`@("`@("`@("`@:68@*&ES7W-C86QA<B@D87)G
M=ELP72DI('L*("`@("`@("`@("`@("`@("`@("`O+R!,;V]K:6YG(&9O<B!O
M;F4@<')I;6%R>2!K97DN(%=E)VQL(&IU<W0@<F5T=7)N"B`@("`@("`@("`@
M("`@("`@("`@+R\@=&AE(&-O<G)E<W!O;F1I;F<@;V)J96-T+"!O<B!T:')O
M=VX@86X*("`@("`@("`@("`@("`@("`@("`O+R!E>&-E<'1I;VXN"B`@("`@
M("`@("`@("`@("`@("`@)&UO9&4@/2!21$\Z.D9)3D1?1DE24U0["B`@("`@
M("`@("`@("`@("`@("`@)&-R:71E<FEA(#T@87)R87DH)&ME>2`]/B`D87)G
M=ELP72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("\O($QO;VMI;F<@9F]R('-E=F5R86P@<')I;6%R>2!K97ES+B!"
M=6EL9"!A;B!/4@H@("`@("`@("`@("`@("`@("`@("\O('-E87)C:"!F;W(@
M=&AE;2X@5V4G;&P@<F5T=7)N(&%N(%)$3U]297-U;'1S"B`@("`@("`@("`@
M("`@("`@("`@+R\@8V]L;&5C=&EO;B!T:&%T(&ET97)A=&5S(&]V97(@=&AE
M;2X*("`@("`@("`@("`@("`@("`@("`D;6]D92`](%)$3SHZ1DE.1%]!3$P[
M"B`@("`@("`@("`@("`@("`@("`@)&-R:71E<FEA(#T@;F5W(%)$3U]#<FET
M97)I82@I.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A<F=V6S!=
M(&%S("1I9"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W)I=&5R:6$M
M/F]R*"1K97DL(%)$3SHZ15%504Q3+"`D:60I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O(%5S:6YG(&$@9FEN9"!M;V1E('=I
M=&@@87)B:71R87)Y(&-R:71E<FEA+@H@("`@("`@("`@("`D;6]D92`](&%R
M<F%Y7W-H:69T*"1A<F=V*3L*("`@("`@("`@("`@)&-R:71E<FEA(#T@87)R
M87E?<VAI9G0H)&%R9W8I.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YS=&]R86=E*"DM/F9I;F0H)'1H:7,L("1M;V1E+"`D8W)I=&5R
M:6$I.PH*("`@("`@("`O+R!4:&4@<W1O<F%G92!D<FEV97(@9FEN9"@I(&-A
M;B!L:6UI="!R97-U;'1S("AI9B!W92=R92!U<VEN9PH@("`@("`@("\O(%)$
M3SHZ1DE.1%]&25)35"D@8G5T('=I;&P@86QW87ES(')E='5R;B!A(&-O;&QE
M8W1I;VX@=&\*("`@("`@("`O+R!R96UA:6X@<VEM<&QE<BX@5V4@=&%K92!C
M87)E(&9O(')E='5R;FEN9R!E:71H97(@=&AE"B`@("`@("`@+R\@8V]L;&5C
M=&EO;B!O<B!A('-I;F=L92!O8FIE8W0@:&5R92X*("`@("`@("!S=VET8V@@
M*"1M;V1E*2!["B`@("`@("`@8V%S92!21$\Z.D9)3D1?1DE24U0Z"B`@("`@
M("`@("`@("\O($EF('=E(&]N;'D@=V%N="!O;F4@<F5S=6QT+"!R971U<FX@
M;G5L;"!I9B!T:&5R92!A<F4@;F\*("`@("`@("`@("`@+R\@<F5S=6QT<RX*
M("`@("`@("`@("`@:68@*"1R97-U;'0M/F-O=6YT*"DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT+3YC=7)R96YT*"D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N(&YU;&P["@H@("`@("`@(&-A<V4@4D1/
M.CI&24Y$7T%,3#H*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O4D1/+U)E<W5L=',N<&AP````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S4P`#$P-#$W,S8R-S<Q`#`R,3`S-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@4F5S=6QT<R!)=&5R871O<B!F;W(@4D1/+@H@*@H@*B!43T1/
M.B!I;7!L96UE;G0@07)R87E!8V-E<W,@87,@=V5L;#\*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4D1/+U)$3R]297-U;'1S+G!H<"QV(#$N-2XR+C$@,C`P
M-2\Q,"\Q."`Q,3HP,3HR,R!J86X@17AP("0*("H*("H@0'!A8VMA9V4@4D1/
M"B`J+PIA8G-T<F%C="!C;&%S<R!21$]?4F5S=6QT<R!I;7!L96UE;G1S($ET
M97)A=&]R('L*"B`@("!P<F]T96-T960@)'-T;W)A9V4["B`@("!P<F]T96-T
M960@)&UA<'!E<CL*("`@('!R;W1E8W1E9"`D;6]D93L*("`@('!R;W1E8W1E
M9"`D8W)I=&5R:6$["B`@("!P<F]T96-T960@)')E<W5L=#L*("`@('!R;W1E
M8W1E9"`D8W5R<F5N=#L*("`@('!R;W1E8W1E9"`D:6YD97@["B`@("!P<F]T
M96-T960@)&5O9CL*"B`@("`O*BH*("`@("`J(%)E<W5L=',@8V]N<W1R=6-T
M;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(%)$3U]3=&]R86=E("1S=&]R86=E
M"B`@("`@*B!`<&%R86T@4D1/7TUA<'!E<B`@)&UA<'!E<B`@("!-87!P:6YG
M(&]B:F5C="!T:&ES(')E<W5L="!S970@8V%M92!F<F]M+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@("`@("1M;V1E"B`@("`@*B!`<&%R86T@;6EX960@("`@
M("`@)&-R:71E<FEA("!$97-C<FEP=&EO;B!O9B!Q=65R>2!T;R!R=6X@=VAE
M;B!R97-U;'1S(&%R92!R97%U97-T960N"B`@("`@*B\*("`@('!U8FQI8R!F
M=6YC=&EO;B!?7V-O;G-T<G5C="A21$]?4W1O<F%G92`D<W1O<F%G92P@4D1/
M7TUA<'!E<B`D;6%P<&5R+"`D;6]D92`](%)$3SHZ1DE.1%]!3$PL("1C<FET
M97)I82`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/G-T;W)A9V4@/2`D
M<W1O<F%G93L*("`@("`@("`D=&AI<RT^;6%P<&5R(#T@)&UA<'!E<CL*("`@
M("`@("`D=&AI<RT^;6]D92`]("1M;V1E.PH@("`@("`@("1T:&ES+3YC<FET
M97)I82`]("1C<FET97)I83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<W5L
M=',@9&5S=')U8W1O<B`M(')E;&5A<V4@86YY(')E<V]U<F-E<RX*("`@("`J
M+PH@("`@<'5B;&EC(&9U;F-T:6]N(%]?9&5S=')U8W0H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^<F5S=6QT*2!["B`@("`@("`@("`@("1T:&ES+3YS
M=&]R86=E+3YF<F5E*"1T:&ES+3YR97-U;'0I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($UU<W0@8F4@9&5F:6YE9"!B>2!T:&4@8V]N8W)E
M=&4@<W5B8VQA<W,N"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO;B!R97=I
M;F0H*0H@("`@>PH@("`@("`@('1H<F]W(&YE=R!21$]?17AC97!T:6]N*"=2
M1$]?4F5S=6QT<SHZ<F5W:6YD*"D@;75S="!B92!I;7!L96UE;G1E9"!B>2!T
M:&4@8V]N8W)E=&4@<W5B8VQA<W,N)RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!);7!L96UE;G1A=&EO;B!O9B!T:&4@8W5R<F5N="@I(&UE=&AO9"!F;W(@
M:71E<F%T;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!4:&4@8W5R
M<F5N="!R;W<L(&]R(&YU;&P@:68@;F\@<F]W<RX*("`@("`J+PH@("`@<'5B
M;&EC(&9U;F-T:6]N(&-U<G)E;G0H*0H@("`@>PH@("`@("`@(&EF("AI<U]N
M=6QL*"1T:&ES+3YR97-U;'0I*2!["B`@("`@("`@("`@("1T:&ES+3YR97=I
M;F0H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YC=7)R96YT
M.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP;&5M96YT871I;VX@;V8@=&AE
M(&ME>2@I(&UE=&AO9"!F;W(@:71E<F%T;W(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!4:&4@8W5R<F5N="!R;W<@;G5M8F5R("AS=&%R=',@870@
M,"DL(&]R($Y53$P@:68@;F\@<F]W<PH@("`@("HO"B`@("!P=6)L:6,@9G5N
M8W1I;VX@:V5Y*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^
M<F5S=6QT*2D@>PH@("`@("`@("`@("`D=&AI<RT^<F5W:6YD*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^:6YD97@["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!-=7-T(&)E(&1E9FEN960@8GD@=&AE(&-O;F-R971E('-U
M8F-L87-S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@5&AE(&YE>'0@
M<F]W+"!O<B!N=6QL(&EF(&YO(&UO<F4@<F]W<RX*("`@("`J+PH@("`@<'5B
M;&EC(&9U;F-T:6]N(&YE>'0H*0H@("`@>PH@("`@("`@('1H<F]W(&YE=R!2
M1$]?17AC97!T:6]N*"=21$]?4F5S=6QT<SHZ;F5X="@I(&UU<W0@8F4@:6UP
M;&5M96YT960@8GD@=&AE(&-O;F-R971E('-U8F-L87-S+B<I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@26UP;&5M96YT871I;VX@;V8@=&AE('9A;&ED*"D@
M;65T:&]D(&9O<B!I=&5R871O<@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B!7:&5T:&5R('1H92!I=&5R871I;VX@:7,@=F%L:60*("`@("`J+PH@
M("`@<'5B;&EC(&9U;F-T:6]N('9A;&ED*"D*("`@('L*("`@("`@("!I9B`H
M:7-?;G5L;"@D=&AI<RT^<F5S=6QT*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<F5W:6YD*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`A)'1H:7,M/F5O
M9CL*("`@('T*"GT*````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4D1/+U-T;W)A9V4N<&AP````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-C0T`#$P-#$W,S8R
M-S<Q`#`R,3`P,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@4W1O<F%G92!C;&%S<R!F;W(@4D1/+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]21$\O4D1/+U-T;W)A9V4N<&AP+'8@
M,2XT+C(N,2`R,#`U+S$P+S$X(#$Q.C`Q.C(S(&IA;B!%>'`@)`H@*@H@*B!`
M<&%C:V%G92!21$\*("HO"F%B<W1R86-T(&-L87-S(%)$3U]3=&]R86=E('L*
M"B`@("`O*BH*("`@("`J($AU;6%N+7)E861A8FQE(&YA;64@9F]R('1H:7,@
M4W1O<F%G92!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<@)&YA
M;64*("`@("`J+PH@("`@<'5B;&EC("1N86UE.PH*("`@("\J*@H@("`@("H@
M4&%R86UE=&5R<R!F;W(@=&AI<R!3=&]R86=E(&1R:79E<BX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y("1P87)A;7,*("`@("`J+PH@("`@<')O=&5C=&5D
M("1P87)A;7,["@H@("`@<'5B;&EC('-T871I8R!F=6YC=&EO;B!S:6YG;&5T
M;VXH)&)A8VME;F0L("1P87)A;7,I"B`@("!["B`@("`@("`@<W1A=&EC("1I
M;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D8F%C:V5N9"`]('-T<G1O
M;&]W97(H)&)A8VME;F0I.PH@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI
M>F4H87)R87DH)&)A8VME;F0L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES
M<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1C
M;&%S<R`]("=21$]?4W1O<F%G95\G("X@)&)A8VME;F0["B`@("`@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@("`@
M('1H<F]W(&YE=R!21$]?17AC97!T:6]N*"=3=&]R86=E(&-L87-S("(G("X@
M)&)A8VME;F0@+B`G(B!N;W0@9F]U;F0G*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`](&YE=R`D8VQA<W,H
M)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E73L*("`@('T*"B`@("!P<F]T96-T960@9G5N8W1I;VX@
M7U]C;VYS=')U8W0H)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^<&%R
M86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9R964@86YY
M(')E<V]U<F-E<R!T:&%T(&%R92!O<&5N+@H@("`@("HO"B`@("!P=6)L:6,@
M9G5N8W1I;VX@7U]D97-T<G5C="@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!;&QO=R`D<W1O<F%G92T^<&%R86T@86-C97-S('1O('-T;W)A9V4@
M<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A
M;2!4:&4@<&%R86UE=&5R('1O(&9E=&-H+@H@("`@("HO"B`@("!P=6)L:6,@
M9G5N8W1I;VX@7U]G970H)'!A<F%M*0H@("`@>PH@("`@("`@(')E='5R;B!I
M<W-E="@D=&AI<RT^<&%R86US6R1P87)A;5TI(#\@)'1H:7,M/G!A<F%M<ULD
M<&%R86U=(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%1U<FX@86YY
M(&]F('1H92!A8V-E<'1A8FQE(&-R:71E<FEA('-H;W)T:&%N9',@:6YT;R!A
M(&9U;&P*("`@("`J(%)$3U]#<FET97)I82!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1C<FET97)I82!4:&4@8W)I=&5R:6$@=&\@8V]N
M=F5R="!T;R!A;B!O8FIE8W0N"B`@("`@*B!`<&%R86T@4D1/7TUA<'!E<B`D
M;6%P<&5R(%1H92!M87!P97(@;V)J96-T(&=O=F5R;FEN9R!T:&ES(&-L875S
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%)$3U]#<FET97)I82!4:&4@9G5L
M;"!21$]?0W)I=&5R:6$@;V)J96-T+@H@("`@("HO"B`@("!P=6)L:6,@9G5N
M8W1I;VX@=&]#<FET97)I82@D8W)I=&5R:6$L(%)$3U]-87!P97(@)&UA<'!E
M<BD*("`@('L*("`@("`@("!I9B`H)&-R:71E<FEA(&EN<W1A;F-E;V8@4D1/
M7T-R:71E<FEA*2!["B`@("`@("`@("`@("1C<FET97)I82T^<V5T36%P<&5R
M*"1M87!P97(I.PH@("`@("`@("`@("!R971U<FX@)&-R:71E<FEA.PH@("`@
M("`@('T*"B`@("`@("`@)&,@/2!N97<@4D1/7T-R:71E<FEO;B@D;6%P<&5R
M*3L*"B`@("`@("`@:68@*&ES7W-C86QA<B@D8W)I=&5R:6$I*2!["B`@("`@
M("`@("`@("1C+3YA9&1497-T*"1M87!P97(M/F1E<V-R:6)E*"DM/FME>2P@
M)STG+"`D8W)I=&5R:6$I.PH@("`@("`@('T@96QS96EF("@D8W)I=&5R:6$I
M('L*("`@("`@("`@("`@)&,M/F-O;6)I;F57:71H*"=!3D0G*3L*("`@("`@
M("`@("`@9F]R96%C:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;'5E*2![
M"B`@("`@("`@("`@("`@("`D8RT^861D5&5S="@D:V5Y+"`G/2<L("1V86QU
M92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8SL*("`@('T*"B`@("`O*BH*("`@("`J+PH@("`@<'5B;&EC(&%B<W1R86-T
M(&9U;F-T:6]N(&)E9VEN*"D["@H@("`@+RHJ"B`@("`@*B\*("`@('!U8FQI
M8R!A8G-T<F%C="!F=6YC=&EO;B!C;VUM:70H*3L*"B`@("`O*BH*("`@("`J
M+PH@("`@<'5B;&EC(&%B<W1R86-T(&9U;F-T:6]N(')O;&QB86-K*"D["@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4D1/+TUE
M=&%$871A+G!H<```````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M-3`T`#$P-#$W,S8R-S<Q`#`R,3`T-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@365T841A=&$@8VQA
M<W,@9F]R(%)$3RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4D1/+U)$3R]-
M971A1&%T82YP:'`L=B`Q+C,N,BXQ(#(P,#4O,3`O,3@@,3$Z,#$Z,C,@:F%N
M($5X<"`D"B`J"B`J($!P86-K86=E(%)$3PH@*B\*8VQA<W,@4D1/7TUE=&%$
M871A('L*"B`@("!P<FEV871E("1M87!P97(["B`@("!P<FEV871E("1P<F]P
M97)T:65S(#T@87)R87DH*3L*("`@('!R:79A=&4@)&9I96QD<R`](&%R<F%Y
M*"D["@H@("`@8V]N<W0@3D]47TY53$P@/2`Q.PH@("`@8V]N<W0@4%))34%2
M62`](#(["B`@("!C;VYS="!215%525)%1"`](#0["@H@("`@8V]N<W0@24Y4
M14=%4B`]("=I;G0G.PH@("`@8V]N<W0@4U1224Y'(#T@)W-T<FEN9R<["@H@
M("`@<'5B;&EC(&9U;F-T:6]N(%]?8V]N<W1R=6-T*%)$3U]-87!P97(@)&UA
M<'!E<BD*("`@('L*("`@("`@("`D=&AI<RT^;6%P<&5R(#T@)&UA<'!E<CL*
M("`@('T*"B`@("!P=6)L:6,@9G5N8W1I;VX@7U]G970H)'!R;W!E<G1Y*0H@
M("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^<')O<&5R=&EE<ULD
M<')O<&5R='E=*2`_("1T:&ES+3YP<F]P97)T:65S6R1P<F]P97)T>5T@.B!N
M=6QL.PH@("`@?0H*("`@('!U8FQI8R!F=6YC=&EO;B!?7W-E="@D<')O<&5R
M='DL("1V86QU92D*("`@('L*("`@("`@("`D=&AI<RT^<')O<&5R=&EE<ULD
M<')O<&5R='E=(#T@)'9A;'5E.PH@("`@?0H*("`@('!U8FQI8R!F=6YC=&EO
M;B!H87-&:65L9"@D9FEE;&0I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3YF:65L9'-;)&9I96QD72D["B`@("!]"@H@("`@<'5B;&EC(&9U
M;F-T:6]N(&%D9$9I96QD*"1F:65L9"P@)'!A<F%M<RD*("`@('L*("`@("`@
M("`D=&AI<RT^9FEE;&1S6R1F:65L9%T@/2`D<&%R86US.PH@("`@?0H*("`@
M('!U8FQI8R!F=6YC=&EO;B!G971&:65L9"@D9FEE;&0I"B`@("!["B`@("`@
M("`@<F5T=7)N(&ES<V5T*"1T:&ES+3YF:65L9'-;)&9I96QD72D@/R`D=&AI
M<RT^9FEE;&1S6R1F:65L9%T@.B!N=6QL.PH@("`@?0H*("`@('!U8FQI8R!F
M=6YC=&EO;B!S971&:65L9%1Y<&4H)&9I96QD+"`D<F%W='EP92D*("`@('L*
M("`@("`@("!I9B`H<W1R:7!O<R@D<F%W='EP92P@)VEN="<I("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`D=&AI<RT^9FEE;&1S6R1F:65L9%U;)W1Y<&4G
M72`]('-E;&8Z.DE.5$5'15(["B`@("`@("`@?2!E;'-E:68@*'-T<FEP;W,H
M)')A=W1Y<&4L("=C:&%R)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1T
M:&ES+3YF:65L9'-;)&9I96QD75LG='EP92==(#T@<V5L9CHZ4U1224Y'.PH@
M("`@("`@('T*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]21$\O0W)I=&5R:6$N<&AP````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0Q-#(`,3`T,3<S-C(W-S$`,#(Q,3,P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]21$\O4D1/+T-R:71E<FEA
M+G!H<"QV(#$N-2XR+C$@,C`P-2\Q,"\Q."`Q,3HP,3HR,B!J86X@17AP("0*
M("H*("H@57-E<R!A($-O;7!O<VET92!T;R!R97!R97-E;G0@82!S:6YG;&4@
M8W)I=&5R:6]N(&]R(&$@=')E92!O9B!M86YY"B`J(&-R:71E<FEA('5N:69O
M<FUL>2!T;R!C;&EE;G1S+B!21$]?0W)I=&5R:6$@:7,@=&AE($-O;7!O;F5N
M="!P87)T"B`J(&]F('1H92!#;VUP;W-I=&4@<&%T=&5R;BX*("H*("H@0'!A
M8VMA9V4@4D1/"B`J+PIA8G-T<F%C="!C;&%S<R!21$]?0W)I=&5R:6$@>PH*
M("`@('!U8FQI8R`D<F5L871I;VYS:&EP<R`](&%R<F%Y*"D["@H@("`@<'5B
M;&EC("1M87!P97(["@H@("`@<'5B;&EC("1C;VYJ=6YC=&EO;B`]("=!3D0G
M.PH*("`@('!U8FQI8R`D9FEE;&1S(#T@87)R87DH*3L*"B`@("!P=6)L:6,@
M)'1E<W1S(#T@87)R87DH*3L*"B`@("!P=6)L:6,@)&QI;6ET.PH*("`@('!U
M8FQI8R!F=6YC=&EO;B!?7V-O;G-T<G5C="@D;6%P<&5R(#T@;G5L;"D*("`@
M('L*("`@("`@("`D=&AI<RT^;6%P<&5R(#T@)&UA<'!E<CL*("`@('T*"B`@
M("!P=6)L:6,@9G5N8W1I;VX@<V5T36%P<&5R*%)$3U]-87!P97(@)&UA<'!E
M<BD*("`@('L*("`@("`@("`D=&AI<RT^;6%P<&5R(#T@)&UA<'!E<CL*("`@
M('T*"B`@("!P=6)L:6,@9G5N8W1I;VX@<V5T1FEE;&1S*"1F:65L9',I"B`@
M("!["B`@("`@("`@)'1H:7,M/F9I96QD<R`]("1F:65L9',["B`@("!]"@H@
M("`@<'5B;&EC(&9U;F-T:6]N(&-O;6)I;F57:71H*"1C;VYJ=6YC=&EO;BD*
M("`@('L*("`@("`@("`D=&AI<RT^8V]N:G5N8W1I;VX@/2`D8V]N:G5N8W1I
M;VX["B`@("!]"@H@("`@<'5B;&EC(&9U;F-T:6]N(&%D9%1E<W0H)&9I96QD
M+"`D=&5S="P@)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3YT97-T<UM=
M(#T@87)R87DH)V9I96QD)R`]/B`D9FEE;&0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=&5S="<@/3X@)'1E<W0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1V86QU92D["B`@("!]"@H@
M("`@<'5B;&EC(&9U;F-T:6]N(&QI;6ET*"1L:6UI="D*("`@('L*("`@("`@
M("`D=&AI<RT^;&EM:70@/2`D;&EM:70["B`@("!]"@H@("`@<'5B;&EC(&9U
M;F-T:6]N(&%D9%)E;&%T:6]N<VAI<"A21$]?36%P<&5R("1M87!P97(L("1C
M;VYT86EN97(L("1C<FET97)I82D*("`@('L*("`@("`@("`D=&AI<RT^<F5L
M871I;VYS:&EP<UM=(#T@87)R87DH)VUA<'!E<B<@/3X@)&UA<'!E<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;G1A:6YE
M<B<@/3X@)&-O;G1A:6YE<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-R:71E<FEA)R`]/B`D8W)I=&5R:6$I.PH@("`@?0H*
M?0H*+RHJ"B`J(%)$3U]#<FET97)I;VX@;6]D96QS(&$@<VEN9VQE(&-R:71E
M<FEO;B!I;B!A('-E87)C:"!O<B!Q=65R>2X@270@:7,*("H@=&AE($QE868@
M<&%R="!O9B!T:&4@0V]M<&]S:71E('!A='1E<FXN"B`J"B`J($!P86-K86=E
M(%)$3PH@*B\*8VQA<W,@4D1/7T-R:71E<FEO;B!E>'1E;F1S(%)$3U]#<FET
M97)I82!["@I]"@HO*BH*("H@4D1/7T-R:71E<FEA1W)O=7`@;6]D96QS(&$@
M9W)O=7!E9"!S970@;V8@8W)I=&5R:6$N($ET(&ES('1H90H@*B!#;VUP;W-I
M=&4@<&%R="!O9B!T:&4@0V]M<&]S:71E('!A='1E<FXN"B`J"B`J($-R:71E
M<FEA1W)O=7`@;V)J96-T<R!C;VYT86EN(&EN9F]R;6%T:6]N(&%B;W5T(&AO
M=R!T:&5I<B!C;VUP;VYE;G0*("H@4D1/7T-R:71E<FEA(&]B:F5C=',@87)E
M('1O(&)E(&%S<V5M8FQE9"`H04Y$+"!/4BP@971C*2X*("H*("H@0'!A8VMA
M9V4@4D1/"B`J+PIC;&%S<R!21$]?0W)I=&5R:6%'<F]U<"!E>'1E;F1S(%)$
M3U]#<FET97)I82!["@H@("`@<'5B;&EC(&9U;F-T:6]N(&%D9$%N9"A21$]?
M0W)I=&5R:6$@)&-R:71E<FEA*0H@("`@>PH@("`@?0H*("`@('!U8FQI8R!F
M=6YC=&EO;B!A9&1/<BA21$]?0W)I=&5R:6$@)&-R:71E<FEA*0H@("`@>PH@
M("`@?0H*("`@('!U8FQI8R!F=6YC=&EO;B!A9&15;FEO;BA21$]?0W)I=&5R
M:6$@)&-R:71E<FEA*0H@("`@>PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+P``````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-S$`,#$W,3,T`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<```````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R,C`Q,``Q,#0Q-S,V,C<W,0`P,C$Q,#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O1&%T851R964N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&
M;W)M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP
M:'`G.PH*+RHJ"B`J($%U=&A?4VEG;G5P.CH@5&AI<R!C;&%S<R!P<F]V:61E
M<R!A;B!I;G1E<F9A8V4@=&\@<VEG;B!U<"!O<B!H879E"B`J(&YE=R!U<V5R
M<R!S:6=N('1H96US96QV97,@=7`@:6YT;R!T:&4@:&]R9&4@:6YS=&%L;&%T
M:6]N+"!D97!E;F1I;F<*("H@;VX@:&]W('1H92!A9&UI;B!H87,@8V]N9FEG
M=7)E9"!(;W)D92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`L=B`Q+C,X+C(N,3`@,C`P-B\P,2\P,2`R,3HR.#HP-R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-87)K;R!$:G5K
M:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U
M=&A?4VEG;G5P('L*"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@82!$871A
M5')E92!I;G-T86YC92!T;R!M86YA9V4O<W1O<F4@<VEG;G5P<PH@("`@("H*
M("`@("`J($!V87(@1&%T851R964*("`@("`J+PH@("`@=F%R("1?9&%T871R
M964["@H@("`@9G5N8W1I;VX@075T:%]3:6=N=7`H*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*&5M<'1Y*"1C;VYF6R=D871A
M=')E92==6R=D<FEV97(G72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*%\H(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H@("`@("`@("1D<FEV97(@/2`D8V]N9ELG9&%T871R964G75LG9')I=F5R
M)UT["B`@("`@("`@)'1H:7,M/E]D871A=')E92`]("9$871A5')E93HZ<VEN
M9VQE=&]N*"1D<FEV97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*$AO<F1E.CIG971$<FEV
M97)#;VYF:6<H)V1A=&%T<F5E)RP@)&1R:79E<BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=G<F]U<"<@/3X@)VAO<F1E+G-I9VYU<"<I*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@
M=&\@82!C;VYC<F5T92!!=71H7U-I9VYU<`H@("`@("H@:6YS=&%N8V4N($ET
M('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@075T:%]3
M:6=N=7`*("`@("`J(&EN<W1A;F-E(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R
M(#T@)D%U=&A?4VEG;G5P.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!R
M971U<FX@4VEG;G5P("!4:&4@8V]N8W)E=&4@4VEG;G5P(')E9F5R96YC92P@
M;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG
M;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D<VEG;G5P.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1S:6=N=7`I*2!["B`@("`@("`@("`@("1S:6=N=7`@
M/2!N97<@075T:%]3:6=N=7`H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<VEG;G5P.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&YE=R!U
M<V5R('1O('1H92!S>7-T96T@86YD(&AA;F1L97,@86YY(&5X=')A(&9I96QD
M<R!T:&%T(&UA>2!H879E"B`@("`@*B!B965N(&-O;7!I;&5D+"!R96QY:6YG
M(&]N('1H92!H;V]K<RYP:'`@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!014%27T5R<F]R(&EF(&%N>2!E<G)O<G,L(&]T:&5R=VES92!T
M<G5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&13:6=N=7`H)B1I;F9O*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D875T:"P@)&-O;F8["@H@("`@("`@("\O
M(%!E<F9O<FT@86YY('!R97!R;V-E<W-I;F<@:68@<F5Q=65S=&5D+@H@("`@
M("`@(&EF("@D8V]N9ELG<VEG;G5P)UU;)W!R97!R;V-E<W,G72D@>PH@("`@
M("`@("`@("`D:6YF;R`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?
M<VEG;G5P7W!R97!R;V-E<W,G+"!A<G)A>2@D:6YF;RDI.PH@("`@("`@("`@
M("!I9B`H:7-?82@D:6YF;RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1I;F9O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!!='1E;7!T('1O(&%D9"!T:&4@=7-E<B!T;R!T:&4@<WES
M=&5M+@H@("`@("`@("1S=6-C97-S(#T@)&%U=&@M/F%D9%5S97(H)&EN9F];
M)W5S97)?;F%M92==+"!A<G)A>2@G<&%S<W=O<F0G(#T^("1I;F9O6R=P87-S
M=V]R9"==*2D["B`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=6-C97-S.PH@("`@("`@
M('T*"B`@("`@("`@+R\@071T96UP="!T;R!A9&0O=7!D871E(&%N>2!E>'1R
M82!D871A(&AA;F1E9"!I;BX*("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R=E
M>'1R82==*2D@>PH@("`@("`@("`@("`D861D960@/2!F86QS93L*("`@("`@
M("`@("`@)&%D9&5D(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S
M:6=N=7!?861D97AT<F$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)&EN9F];)W5S97)?;F%M92==+"`D:6YF;ULG97AT
M<F$G72DI.PH@("`@("`@("`@("!I9B`H(21A9&1E9"!\?"!I<U]A*"1A9&1E
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)&%D9&5D+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T5-15)'*3L*("`@("`@("`@("`@("`@($AO<F1E.CIF871A;"A?*")5;F%B
M;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG
M('5P+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%%U975E<R!T:&4@=7-E<B=S('-U8FUI='1E9"!R96=I<W1R871I
M;VX@:6YF;R!F;W(@;&%T97(@861M:6X@87!P<F]V86PN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@4$5!4E]%<G)O<B!I9B!A;GD@97)R;W)S+"!O
M=&AE<G=I<V4@=')U92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G%U975E4VEG
M;G5P*"8D:6YF;RD*("`@('L*("`@("`@("!G;&]B86P@)&%U=&@L)&-O;F8[
M"@H@("`@("`@("\O(%!E<F9O<FT@86YY('!R97!R;V-E<W-I;F<@:68@<F5Q
M=65S=&5D+@H@("`@("`@(&EF("@D8V]N9ELG<VEG;G5P)UU;)W!R97!R;V-E
M<W,G72D@>PH@("`@("`@("`@("`D:6YF;R`]($AO<F1E.CIC86QL2&]O:R@G
M7VAO<F1E7VAO;VM?<VEG;G5P7W!R97!R;V-E<W,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D:6YF;RDI.PH@("`@("`@
M("`@("!I9B`H:7-?82@D:6YF;RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1I;F9O.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@=&AE('5S97)N86UE(&%L
M<F5A9'D@97AI<W1S+@H@("`@("`@(&EF("@D875T:"T^97AI<W1S*"1I;F9O
M6R=U<V5R7VYA;64G72D@?'P*("`@("`@("`@("`@)'1H:7,M/E]D871A=')E
M92T^97AI<W1S*"1I;F9O6R=U<V5R7VYA;64G72DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5<V5R;F%M92!<
M(B5S7"(@86QR96%D>2!E>&ES=',N(BDL("1I;F9O6R=U<V5R7VYA;64G72DI
M.PH@("`@("`@('T*"B`@("`@("`@+R\@268@:70G<R!A('5N:7%U92!U<V5R
M;F%M92P@9V\@86AE860@86YD('%U975E('1H92!R97%U97-T+@H@("`@("`@
M("1S:6=N=7`@/2`D=&AI<RT^;F5W4VEG;G5P*"1I;F9O6R=U<V5R7VYA;64G
M72D["B`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG97AT<F$G72DI('L*("`@
M("`@("`@("`@)'-I9VYU<"T^9&%T82`](&%R<F%Y7VUE<F=E*"1I;F9O6R=E
M>'1R82==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W!A<W-W;W)D)R`]/B`D:6YF;ULG<&%S<W=O<F0G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M871E4F5C96EV960G(#T^('1I;64H*2DI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S:6=N=7`M/F1A=&$@/2!A<G)A>2@G<&%S<W=O<F0G(#T^
M("1I;F9O6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1A=&5296-E:79E9"<@/3X@=&EM92@I*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D8V]N9ELG<VEG;G5P)UU;)W%U975E)UTI('L*("`@
M("`@("`@("`@)')E<W5L="`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO
M;VM?<VEG;G5P7W%U975E9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)&EN9F];)W5S97)?;F%M92==+"`D:6YF;RDI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R
M964M/F%D9"@D<VEG;G5P*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M('5S97(G<R!Q=65U960@<VEG;G5P(&EN9F]R;6%T:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("!4:&4@=7-E<FYA;64@=&\@
M<F5T<FEE=F4@=&AE('%U975E9"!I;F9O(&9O<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N($1A=&%4<F5E3V)J96-T7U-I9VYU<"`@5&AE($1A=&%4<F5E3V)J
M96-T(&9O<B!T:&4@<F5Q=65S=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<VEG;G5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9711=65U9613:6=N=7`H)'5S97)N86UE*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W0H)'5S97)N86UE+"`G1&%T
M851R965/8FIE8W1?4VEG;G5P)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE('%U975E9"!I;F9O<FUA=&EO;B!F;W(@86QL('!E;F1I;F<@<VEG
M;G5P<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O
M9B!$871A5')E94]B:F5C=%]3:6=N=7`@;V)J96-T<RP@;VYE(&9O<@H@("`@
M("H@("`@("`@("`@("`@("`@96%C:"!S:6=N=7`@:6X@=&AE('%U975E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9711=65U9613:6=N=7!S*"D*("`@('L*
M("`@("`@("`D<VEG;G5P<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]D871A=')E92T^9V5T*$1!5$%44D5%7T9/4DU!5%]&3$%4+"!$
M051!5%)%15]23T]4+"!T<G5E*2!A<R`D=7-E<FYA;64I('L*("`@("`@("`@
M("`@:68@*"1U<V5R;F%M92`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@
M("`@("`@("`D<VEG;G5P<UM=(#T@)'1H:7,M/E]D871A=')E92T^9V5T3V)J
M96-T*"1U<V5R;F%M92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1S:6=N=7!S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M
M;W9E(&$@<75E=65D('-I9VYU<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R;F%M92`@5&AE('5S97(@=&\@<F5M;W9E(&9R;VT@=&AE('-I
M9VYU<"!Q=65U92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E475E=65D
M4VEG;G5P*"1U<V5R;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^7V1A=&%T
M<F5E+3YR96UO=F4H)'5S97)N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!A(&YE=R!S:6=N=7`@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!S:6=N=7!S)W,@;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7U-I9VYU<"`@02!N97<@
M<VEG;G5P(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)FYE=U-I9VYU
M<"@D;F%M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&YA;64I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=3:6=N=7`@;F%M
M97,@;75S="!B92!N;VXM96UP='DG*3L*("`@("`@("!]"B`@("`@("`@)'-I
M9VYU<"`]("9N97<@1&%T851R965/8FIE8W1?4VEG;G5P*"1N86UE*3L*("`@
M("`@("!R971U<FX@)'-I9VYU<#L*("`@('T*"GT*"B\J*@H@*B!%>'1E;G-I
M;VX@;V8@=&AE($1A=&%4<F5E3V)J96-T(&-L87-S(&9O<B!S=&]R:6YG(%-I
M9VYU<`H@*B!I;F9O<FUA=&EO;B!I;B!T:&4@1&%T851R964@9')I=F5R+B!)
M9B!Y;W4@=V%N="!T;R!S=&]R90H@*B!S<&5C:6%L:7IE9"!3:6=N=7`@:6YF
M;W)M871I;VXL('EO=2!S:&]U;&0@97AT96YD('1H:7,@8VQA<W,*("H@:6YS
M=&5A9"!O9B!E>'1E;F1I;F<@1&%T851R965/8FIE8W0@9&ER96-T;'DN"B`J
M"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J
M+PIC;&%S<R!$871A5')E94]B:F5C=%]3:6=N=7`@97AT96YD<R!$871A5')E
M94]B:F5C="!["@H@("`@+RHJ"B`@("`@*B!792!W86YT('1O('-E92!Q=65U
M960@<VEG;G5P<R!I;B!D97-C96YD:6YG(&]R9&5R(&]F(')E8V5I<'0N"B`@
M("`@*B!);G-E<G0@;F5W('-I9VYU<',@870@<&]S:71I;VX@,"!A;F0@<'5S
M:"!T:&4@<F5S="!D;W=N+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@
M("`@("HO"B`@("!V87(@)&]R9&5R(#T@,#L*"B`@("`O*BH*("`@("`J(%1H
M92!$871A5')E94]B:F5C=%]3:6=N=7`@8V]N<W1R=6-T;W(N($IU<W0@;6%K
M97,@<W5R92!T;R!C86QL"B`@("`@*B!T:&4@<&%R96YT(&-O;G-T<G5C=&]R
M('-O('1H870@=&AE('-I9VYU<"=S(&ES(&ES('-E=`H@("`@("H@<')O<&5R
M;'DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!I9"!O
M9B!T:&4@<VEG;G5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!$871A5')E94]B
M:F5C=%]3:6=N=7`H)&ED*0H@("`@>PH@("`@("`@('!A<F5N=#HZ1&%T851R
M965/8FIE8W0H)&ED*3L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^9&%T
M82DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&$@/2!A<G)A>2@I.PH@("`@
M("`@('T*("`@('T*"GT*"B\J*@H@*B!(;W)D92!3:6=N=7`@1F]R;2P@97AT
M96YD:6YG(&]F($AO<F1E7T9O<FTZ.@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H
M"B`J+PIC;&%S<R!(;W)D95-I9VYU<$9O<FT@97AT96YD<R!(;W)D95]&;W)M
M('L*"B`@("!V87(@)%]U<V5&;W)M5&]K96X@/2!T<G5E.PH*("`@(&9U;F-T
M:6]N($AO<F1E4VEG;G5P1F]R;2@F)'9A<G,I"B`@("!["B`@("`@("`@9VQO
M8F%L("1R96=I<W1R>3L*"B`@("`@("`@<&%R96YT.CI(;W)D95]&;W)M*"1V
M87)S+"!S<')I;G1F*%\H(B5S(%-I9VX@57`B*2P@)')E9VES=')Y+3YG970H
M)VYA;64G*2DI.PH*("`@("`@("`D=&AI<RT^<V5T0G5T=&]N<RA?*")3:6=N
M('5P(BDL('1R=64I.PH*("`@("`@("`D=&AI<RT^861D2&ED9&5N*"<G+"`G
M=7)L)RP@)W1E>'0G+"!F86QS92D["B`@("`@("`@)'1H:7,M/F%D9%9A<FEA
M8FQE*%\H(D-H;V]S92!A('5S97)N86UE(BDL("=U<V5R7VYA;64G+"`G=&5X
M="<L('1R=64I.PH@("`@("`@("1T:&ES+3YA9&1687)I86)L92A?*")#:&]O
M<V4@82!P87-S=V]R9"(I+"`G<&%S<W=O<F0G+"`G<&%S<W=O<F1C;VYF:7)M
M)RP@=')U92P@9F%L<V4L(%\H(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FTB*2D["@H@("`@("`@("\J(%5S92!H;V]K<R!G970@86YY(&5X
M=')A(&9I96QD<R!R97%U:7)E9"!I;B!S:6=N:6YG('5P+B`J+PH@("`@("`@
M("1E>'1R82`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?<VEG;G5P
M7V=E=&5X=')A)RD["B`@("`@("`@:68@*"%I<U]A*"1E>'1R82P@)U!%05)?
M17)R;W(G*2`F)B`A96UP='DH)&5X=')A*2D@>PH@("`@("`@("`@("!F;W)E
M86-H("@D97AT<F$@87,@)&9I96QD7VYA;64@/3X@)&9I96QD*2!["B`@("`@
M("`@("`@("`@("`D<F5A9&]N;'D@/2!I<W-E="@D9FEE;&1;)W)E861O;FQY
M)UTI(#\@)&9I96QD6R=R96%D;VYL>2==(#H@;G5L;#L*("`@("`@("`@("`@
M("`@("1D97-C(#T@:7-S970H)&9I96QD6R=D97-C)UTI(#\@)&9I96QD6R=D
M97-C)UT@.B!N=6QL.PH@("`@("`@("`@("`@("`@)')E<75I<F5D(#T@:7-S
M970H)&9I96QD6R=R97%U:7)E9"==*2`_("1F:65L9%LG<F5Q=6ER960G72`Z
M(&9A;'-E.PH@("`@("`@("`@("`@("`@)&9I96QD7W!A<F%M<R`](&ES<V5T
M*"1F:65L9%LG<&%R86US)UTI(#\@)&9I96QD6R=P87)A;7,G72`Z(&%R<F%Y
M*"D["@H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9%9A<FEA8FQE*"1F:65L
M9%LG;&%B96PG72P@)V5X=')A6R<@+B`D9FEE;&1?;F%M92`N("==)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&1;)W1Y<&4G
M72P@)')E<75I<F5D+"`D<F5A9&]N;'DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<V,L("1F:65L9%]P87)A;7,I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V%P<&QI8V%T:6]N+G!H
M<```````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30T,3``,3`T,3<S-C(W
M-S$`,#(R,30U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]A<'!L:6-A=&EO;B!C;&%S
M<R!P<F]V:61E<R!A('=R87!P97(@87)O=6YD"B`J(&%P<&QI8V%T:6]N+7!R
M;W9I9&5D($AO<F1E(&%U=&AE;G1I8V%T:6]N('=H:6-H(&9I=',@:6YS:61E
M('1H90H@*B!(;W)D92!!=71H.CH@05!)+@H@*@H@*B!297%U:7)E9"!P87)A
M;65T97)S.CQP<F4^"B`J("`@)V%P<"<@(%1H92!A<'!L:6-A=&EO;B!W:&EC
M:"!I<R!P<F]V:61I;F<@875T:&5N=&EC871I;VXN/"]P<F4^"B`J"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]A<'!L:6-A=&EO;BYP:'`L
M=B`Q+C(W+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?
M87!P;&EC871I;VX@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N
M(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A
M;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@
M86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G
M("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G
M("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T<R!A(&YE=R!!<'!L:6-A=&EO;B!A=71H96YT:6-A=&EO
M;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@075T:%]A<'!L:6-A=&EO;B@D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=%!A<F%M<R@D<&%R
M86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%%U97)I97,@=&AE(&-U<G)E
M;G0@075T:"!O8FIE8W0@=&\@9FEN9"!O=70@:68@:70@<W5P<&]R=',@=&AE
M(&=I=F5N"B`@("`@*B!C87!A8FEL:71Y+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&-A<&%B:6QI='D@(%1H92!C87!A8FEL:71Y('1O('1E<W0@
M9F]R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O
M<B!N;W0@=&AE(&-A<&%B:6QI='D@:7,@<W5P<&]R=&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!H87-#87!A8FEL:71Y*"1C87!A8FEL:71Y*0H@("`@>PH@
M("`@("`@('-T871I8R`D;&]A9&5D(#T@87)R87DH*3L*"B`@("`@("`@)&UE
M=&AO9',@/2!A<G)A>2@G;&ES="<@/3X@)W5S97),:7-T)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("=A9&0G(#T^("=A9&15<V5R)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("=U<&1A=&4G(#T^("=U<&1A=&55<V5R)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G(#T^("=R96UO=F55<V5R
M)RD["@H@("`@("`@(&EF("AE;7!T>2@D;&]A9&5D6R1C87!A8FEL:71Y72D@
M)B8@:7-S970H)&UE=&AO9'-;)&-A<&%B:6QI='E=*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^8V%P86)I;&ET:65S6R1C87!A8FEL:71Y72`]("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YH87--971H;V0H)&UE=&AO9'-;)&-A<&%B:6QI='E=
M+"`D=&AI<RT^7W!A<F%M<ULG87!P)UTI.PH@("`@("`@("`@("`D;&]A9&5D
M6R1C87!A8FEL:71Y72`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@(65M<'1Y*"1T:&ES+3YC87!A8FEL:71I97-;)&-A<&%B:6QI='E=*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!C;VYN96-T:6]N('!A<F%M971E
M<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M=%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@($AO<F1E.CIA<W-E<G1$
M<FEV97)#;VYF:6<H)'!A<F%M<RP@)V%U=&@G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)V%P<"<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V%U=&AE;G1I8V%T:6]N(&%P<&QI8V%T
M:6]N)RD["@H@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^87!P;&EC871I;VYS6R1P87)A;7-;)V%P<"==72DI('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*"1P87)A;7-;)V%P<"==("X@)R!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN)RP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@
M<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O
M('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@
M;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS
M*0H@("`@>PH@("`@("`@(&EF("@A)$=,3T)!3%-;)W)E9VES=')Y)UTM/FAA
M<TUE=&AO9"@G875T:&5N=&EC871E)RP@)'1H:7,M/E]P87)A;7-;)V%P<"==
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)'1H:7,M/E]P87)A;7-;
M)V%P<"==("X@)R!D;V5S(&YO="!P<F]V:61E(&%N(&%U=&AE;G1I8V%T92@I
M(&UE=&AO9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&Q">5!A8VMA
M9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G875T:&5N=&EC871E)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W5S97))9"<@/3X@)'5S97))9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-R
M961E;G1I86QS)R`]/B`D8W)E9&5N=&EA;',L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A
M;7,G(#T^("1T:&ES+3Y?<&%R86US*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@<V-R965N(&9O<B!T:&ES
M(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T
M97(@;&]G:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L
M;V=I;B!S8W)E96X@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G
M:6Y38W)E96XH)&%P<"`]("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@
M("`@("!R971U<FX@<&%R96YT.CI?9V5T3&]G:6Y38W)E96XH)'1H:7,M/E]P
M87)A;7-;)V%P<"==+"`D=7)L*3L*("`@('T*"B`@("`O*BH*("`@("`J($QI
M<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&ES=%5S97)S*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B
M:6QI='DH)VQI<W0G*2D@>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F-A;&Q">5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P
M<"==+"`G=7-E<DQI<W0G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T
M:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@
M*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@
M=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@
M<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I
M86QS*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&%S0V%P86)I;&ET>2@G
M861D)RDI('L*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R
M>2==+3YC86QL0GE086-K86=E*"1T:&ES+3Y?<&%R86US6R=A<'`G72P@)V%D
M9%5S97(G+"!A<G)A>2@D=7-E<DED+"`D8W)E9&5N=&EA;',I*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G=6YS=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!5<&1A=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA
M;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@
M5&AE(&]L9"!U<V5R260N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=)1"`@
M("`@("!4:&4@;F5W('5S97))9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E
M9&5N=&EA;',@(%1H92!N97<@8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A
M=&55<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3YH87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&Q"
M>5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G=7!D871E57-E<B<L
M(&%R<F%Y*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G=6YS=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA
M;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@
M=7-E<DED('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R
M260I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH87-#87!A8FEL:71Y*"=R
M96UO=F4G*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F-A;&Q">5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==
M+"`G<F5M;W9E57-E<B<L(&%R<F%Y*"1U<V5R260I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS
M=7!P;W)T960G*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^<F5M;W9E57-E
M<D1A=&$H)'5S97))9"D["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]A
M=71O+G!H<```````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U
M,S,W`#$P-#$W,S8R-S<Q`#`R,#8R,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?875T
M;R!C;&%S<R!T<F%N<W!A<F5N=&QY(&QO9W,@=7-E<G,@:6X@=&\@2&]R9&4@
M=7-I;F<@3TY%"B`J('5S97)N86UE+"!E:71H97(@9&5F:6YE9"!I;B!T:&4@
M8V]N9FEG(&]R(&1E9F%U;'1I;F<@=&\*("H@)VAO<F1E7W5S97(G+B!4:&ES
M(&ES(&]N;'D@9F]R('5S92!I;B!T97-T:6YG(&]R(&)E:&EN9"!A(&9I<F5W
M86QL.PH@*B!I="!S:&]U;&0@3D]4(&)E('5S960@;VX@82!P=6)L:6,L('!R
M;V1U8W1I;VX@;6%C:&EN92X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\
M<')E/@H@*B`@("=U<V5R;F%M92<@("`@(%1H92!U<V5R;F%M92!T;R!A=71H
M96YT:6-A=&4@979E<GEO;F4@87,N"B`J("`@("`@("`@("`@("`@("`@1$5&
M055,5#H@)VAO<F1E7W5S97(G"B`J("`@)W!A<W-W;W)D)R`@("`@5&AE('!A
M<W-W;W)D('1O(')E8V]R9"!I;B!T:&4@=7-E<B=S(&-R961E;G1I86QS+@H@
M*B`@("`@("`@("`@("`@("`@($1%1D%53%0Z(&YO;F4*("H@("`G<F5Q=65S
M='5S97(G("!)9B!T<G5E+"!A;&QO=R!U<V5R;F%M92!T;R!B92!P87-S960@
M8GD@1T54+"!03U-4(&]R"B`J("`@("`@("`@("`@("`@("`@8V]O:VEE+CPO
M<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O875T
M;RYP:'`L=B`Q+C$R+C0N."`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!
M=71H7V%U=&\@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R
M<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R
M97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD
M('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@
M("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=')A;G-P87)E;G0G("`@/3X@=')U92D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W($%U=&]M871I8R!A=71H96YT:6-A=&EO;B!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S
M:"!C;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($%U=&A?875T;R@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M=&AI<RT^7W-E=%!A<F%M<R@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!P87)A;65T97)S(&9O<B!T:&4@075T:%]A=71O(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@4&%R86UE=&5R<RX@3F]N92!C=7)R96YT
M;'D@<F5Q=6ER960["B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W5S
M97)N86UE)RP@)W!A<W-W;W)D)RP@86YD("=R97%U97-T=7-E<B<@87)E(&]P
M=&EO;F%L+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4&%R86US*"1P87)A
M;7,I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=U<V5R;F%M
M92==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=U<V5R;F%M92==(#T@)VAO
M<F1E7W5S97(G.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]
M("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6,@875T
M:&5N=&EC871I;VXZ(%-E="!T:&4@=7-E<B!A;&QO=V5D($E0(&)L;V-K+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@
M=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!T
M<F%N<W!A<F5N="@I"B`@("!["B`@("`@("`@)'5S97)N86UE(#T@*"%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG<F5Q=65S='5S97(G72D@)B8@:7-S970H)%]2
M15%515-46R=U<V5R;F%M92==*2D@/PH@("`@("`@("`@("`D7U)%455%4U1;
M)W5S97)N86UE)UT@.@H@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E
M<FYA;64G73L*("`@("`@("`D=&AI<RT^<V5T075T:"@D=7-E<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W1R86YS<&%R96YT)R`]/B`Q
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@
M:7-S970H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI(#\@)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UT@.B!N=6QL*2D["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V-O;7!O<VET92YP:'``````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$S,#4`,3`T,3<S-C(W-S$`
M,#(Q-C0U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@075T:%]C;VUP;W-I=&4@8VQA<W,@<')O
M=FED97,@82!W<F%P<&5R(&%R;W5N9`H@*B!A<'!L:6-A=&EO;BUP<F]V:61E
M9"!(;W)D92!A=71H96YT:6-A=&EO;B!W:&EC:"!F:71S(&EN<VED92!T:&4*
M("H@2&]R9&4@075T:#HZ($%022X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@($YO;F4N/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T%U=&@O075T:"]C;VUP;W-I=&4N<&AP+'8@,2XR-BXQ,"XY(#(P
M,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?8V]M<&]S:71E(&5X=&5N
M9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@86YY
M(&EN<W1A;G1I871E9"!D<FEV97)S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?9')I=F5R<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($-O;7!O<VET92!A=71H96YT
M:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]C;VUP;W-I=&4H)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971087)A;7,H
M)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@8V]N;F5C=&EO
M;B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]S971087)A;7,H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A
M;"@G3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($-O;7!O<VET92!A=71H96YT:6-A=&EO;BXG+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!N86UE9"!P
M87)A;65T97(@9F]R('1H92!C=7)R96YT(&%U=&@@9')I=F5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A<F%M("!4:&4@<&%R86UE=&5R('1O
M(&9E=&-H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R
M86UE=&5R)W,@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M
M*"1P87)A;2D*("`@('L*("`@("`@("!I9B`H*"1L;V=I;E]D<FEV97(@/2!!
M=71H.CI?9V5T1')I=F5R0GE087)A;2@G;&]G:6YS8W)E96Y?<W=I=&-H)RP@
M)'1H:7,M/E]P87)A;7,I*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VQO861$
M<FEV97(H)&QO9VEN7V1R:79E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9')I=F5R<ULD;&]G:6Y?9')I=F5R72T^9V5T4&%R86TH)'!A<F%M
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N
M=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H
M92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E
M;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@=7-E+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I
M86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I
M8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@
M*"@D875T:%]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G;&]G
M:6YS8W)E96Y?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I*2`F)@H@("`@("`@
M("`@("`D=&AI<RT^7VQO861$<FEV97(H)&%U=&A?9')I=F5R*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]D<FEV97)S6R1A=71H7V1R:79E<ETM
M/F%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"@D875T:%]D<FEV97(@/2!!=71H.CI?9V5T1')I
M=F5R0GE087)A;2@G=7-E<FYA;65?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,L
M(&%R<F%Y*"1U<V5R260I*2D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D
M1')I=F5R*"1A=71H7V1R:79E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9')I=F5R<ULD875T:%]D<FEV97)=+3YH87-#87!A8FEL:71Y*"=T
M<F%N<W!A<F5N="<I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S971!
M=71H17)R;W(H05542%]214%33TY?1D%)3$5$*3L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=65R>2!T:&4@8W5R<F5N
M="!!=71H(&]B:F5C="!T;R!F:6YD(&]U="!I9B!I="!S=7!P;W)T<R!T:&4@
M9VEV96X*("`@("`J(&-A<&%B:6QI='DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V%P86)I;&ET>2`@5&AE(&-A<&%B:6QI='D@=&\@=&5S="!F
M;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R
M(&YO="!T:&4@8V%P86)I;&ET>2!I<R!S=7!P;W)T960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&AA<T-A<&%B:6QI='DH)&-A<&%B:6QI='DI"B`@("!["B`@
M("`@("`@<W=I=&-H("@D8V%P86)I;&ET>2D@>PH@("`@("`@(&-A<V4@)V%D
M9"<Z"B`@("`@("`@8V%S92`G=7!D871E)SH*("`@("`@("!C87-E("=R96UO
M=F4G.@H@("`@("`@(&-A<V4@)VQI<W0G.@H@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;&]A9$1R:79E<B@D=&AI<RT^7W!A<F%M<ULG
M861M:6Y?9')I=F5R)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]D<FEV97)S6R1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G75TM
M/FAA<T-A<&%B:6QI='DH)&-A<&%B:6QI='DI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=T<F%N<W!A
M<F5N="<Z"B`@("`@("`@("`@(&EF("@H)&QO9VEN7V1R:79E<B`]($%U=&@Z
M.E]G971$<FEV97)">5!A<F%M*"=L;V=I;G-C<F5E;E]S=VET8V@G+"`D=&AI
M<RT^7W!A<F%M<RDI("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQO861$
M<FEV97(H)&QO9VEN7V1R:79E<BDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1R:79E<G-;)&QO9VEN7V1R:79E<ETM/FAA<T-A<&%B:6QI
M='DH)W1R86YS<&%R96YT)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%U=&]M871I8R!A=71H96YT:6-A=&EO;CH@
M1FEN9"!O=70@:68@=&AE(&-L:65N="!M871C:&5S(&%N(&%L;&]W960@25`*
M("`@("`J(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@("!["B`@("`@("`@:68@
M*"@D;&]G:6Y?9')I=F5R(#T@075T:#HZ7V=E=$1R:79E<D)Y4&%R86TH)VQO
M9VEN<V-R965N7W-W:71C:"<L("1T:&ES+3Y?<&%R86US*2D@)B8*("`@("`@
M("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1L;V=I;E]D<FEV97(I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1R:79E<G-;)&QO9VEN7V1R:79E
M<ETM/G1R86YS<&%R96YT*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(%5222!O
M9B!T:&4@;&]G:6X@<V-R965N(&9O<B!T:&ES(&%U=&AE;G1I8V%T:6]N(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A
M<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@
M(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E96X@55))+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G:6Y38W)E96XH)&%P<"`]("=H
M;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@("!I9B`H*"1L;V=I;E]D
M<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G;&]G:6YS8W)E96Y?
M<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I*2`F)@H@("`@("`@("`@("`D=&AI
M<RT^7VQO861$<FEV97(H)&QO9VEN7V1R:79E<BDI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD;&]G:6Y?9')I=F5R72T^7V=E=$QO
M9VEN4V-R965N*"1A<'`L("1U<FPI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!P87)E;G0Z.E]G971,;V=I;E-C<F5E;B@D87!P+"`D
M=7)L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!S
M970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@=&\@
M861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E9&5N=&EA;',@(%1H92!C
M<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@("`@("`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D
M=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UTI("8F"B`@("`@("`@
M("`@("1T:&ES+3Y?;&]A9$1R:79E<B@D=&AI<RT^7W!A<F%M<ULG861M:6Y?
M9')I=F5R)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1R:79E
M<G-;)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==72T^861D57-E<B@D
M=7-E<DED+"`D8W)E9&5N=&EA;',I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U<'!O<G1E9"<I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!A('-E
M="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@("`@("!4:&4@;VQD('5S97))9"X*
M("`@("`J($!P87)A;2!S=')I;F<@)&YE=TE$("`@("`@(%1H92!N97<@=7-E
M<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE(&YE
M=R!C<F5D96YT:6%L<PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T955S97(H)&]L9$E$+"`D
M;F5W240L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@
M("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D
M<FEV97(G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R
M<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=+3YU<&1A=&55<V5R
M*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U
M<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M;&5T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@(%1H92!U<V5R260@
M=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S97))9"D*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D
M<FEV97(G72D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T
M:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?
M9')I=F5R)UU=+3YR96UO=F55<V5R*"1U<V5R260I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U
M<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QI
M<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&ES=%5S97)S*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@)'1H:7,M
M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI<RT^
M7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=+3YL:7-T57-E<G,H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G56YS=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@:68@82!U<V5R260@97AI<W1S(&EN('1H92!S>7-T96TN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO
M="!T:&4@=7-E<DED(&%L<F5A9'D@97AI<W1S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E>&ES=',H)'5S97))9"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@
M("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D
M<FEV97(G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R
M<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=+3YE>&ES=',H)'5S
M97))9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D)RD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@3&]A9',@;VYE(&]F('1H92!D<FEV97)S(&EN
M(&]U<B!C;VYF:6=U<F%T:6]N(&%R<F%Y+"!I9B!I="!I<VXG="!A;')E861Y
M"B`@("`@*B!L;V%D960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@;F%M
M92!O9B!T:&4@9')I=F5R('1O(&QO860N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]L;V%D1')I=F5R*"1D<FEV97(I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?9')I=F5R<ULD9')I=F5R72DI('L*("`@("`@("`@("`@+R\@
M5&AI<R!I<R!A(&)I="!S<&5C:6%L:7IE9"!F;W(@2&]R9&4Z.F=E=$1R:79E
M<D-O;F9I9R@I+`H@("`@("`@("`@("`O+R!S;R!L;V-A;&EZ92!I="!H97)E
M.@H@("`@("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]P87)A;7-;)V1R:79E<G,G75LD9')I=F5R75LG<&%R
M86US)UTI*2!["B`@("`@("`@("`@("`@("`D<&%R86US(#T@)'1H:7,M/E]P
M87)A;7-;)V1R:79E<G,G75LD9')I=F5R75LG<&%R86US)UT["B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&-O;F9;)'1H:7,M/E]P87)A;7-;)V1R:79E
M<G,G75LD9')I=F5R75LG9')I=F5R)UU=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1P87)A;7,@/2!A<G)A>5]M97)G92@D8V]N9ELD=&AI<RT^7W!A<F%M
M<ULG9')I=F5R<R==6R1D<FEV97)=6R=D<FEV97(G75TL("1P87)A;7,I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y
M*"1C;VYF6R1D<FEV97)=*2D@>PH@("`@("`@("`@("`@("`@)'!A<F%M<R`]
M("1C;VYF6R1D<FEV97)=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'!A<F%M<R`](&YU;&P["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1T:&ES+3Y?9')I=F5R<ULD9')I=F5R72`]("9!=71H.CIS:6YG
M;&5T;VXH)'1H:7,M/E]P87)A;7-;)V1R:79E<G,G75LD9')I=F5R75LG9')I
M=F5R)UTL("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1T:&ES+3Y?9')I=F5R<ULD9')I=F5R72D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O8W5S=&]M<W%L
M+G!H<```````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,S<V,``Q,#0Q
M-S,V,C<W,0`P,C$W,#0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O<W%L+G!H<"<["@HO*BH*("H@5&AE($%U=&A?8W5S=&]M<W%L
M(&-L87-S('!R;W9I9&5S(&$@<W%L(&EM<&QE;65N=&%T:6]N(&]F('1H92!(
M;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96T@=VET:"!T:&4@<&]S<VEB
M:6QI='D@=&\@<V5T(&-U<W1O;2UM861E('%U97)I97,N"B`J"B`J(%)E<75I
M<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G<&AP='EP92<@(%1H92!D871A
M8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P<F4^
M"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z("A#=7-T;VT@<75E<GDI/'!R
M93X*("H@4V]M92!S<&5C:6%L('1O:V5N<R!C86X@8F4@=7-E9"!I;B!T:&4@
M<W%L('%U97)Y+B!4:&5Y(&%R92!R97!L86-E9`H@*B!A="!T:&4@<75E<GD@
M<W1A9V4Z"B`J"B`J("`@+2`G7$PG('=I;&P@8F4@<F5P;&%C960@8GD@=&AE
M('5S97(G<R!L;V=I;@H@*B`@("T@)UQ0)R!W:6QL(&)E(')E<&QA8V5D(&)Y
M('1H92!U<V5R)W,@<&%S<W=O<F0N"B`J("`@+2`G7$\G('=I;&P@8F4@<F5P
M;&%C960@8GD@=&AE(&]L9"!U<V5R)W,@;&]G:6X@*')E<75I<F5D(&9O<B!U
M<&1A=&4I"B`J"B`J("`@16<Z(")314Q%0U0@*B!&4D]-('5S97)S(%=(15)%
M('5I9"`](%Q,"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.1"!P
M87-S=V0@/2!<4`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!!3D0@
M8FEL;&EN9R`]("=P86ED)PH@*@H@*B`@("=Q=65R>5]A=71H)R`@("!!=71H
M96YT:6-A=&4@=&AE('5S97(N("`@("`@("=<3"<@)B`G7$XG"B`J("`@)W%U
M97)Y7V%D9"<@("`@($%D9"!U<V5R+B`@("`@("`@("`@("`@("`@("`@)UQ,
M)R`F("=<3B<*("H@("`G<75E<GE?=7!D871E)R`@57!D871E('5S97(N("`@
M("`@("`@("`@("`@("`G7$\G+"`G7$PG("8@)UQ.)PH@*B`@("=Q=65R>5]R
M97-E='!A<W-W;W)D)R`@4F5S970@<&%S<W=O<F0N("`@("`@("=<3"<L("8@
M)UQ0)PH@*B`@("=Q=65R>5]R96UO=F4G("!296UO=F4@=7-E<BX@("`@("`@
M("`@("`@("`@("=<3"<*("H@("`G<75E<GE?;&ES="<@("`@3&ES="!U<V5R
M+B`@("`@("`@("`@("`@("`@("`G7$PG/"]P<F4^"B`J"B`J($]P=&EO;F%L
M('!A<F%M971E<G,Z/'!R93X*("H@("`G96YC<GEP=&EO;B<@("`@("`@5&AE
M(&5N8W)Y<'1I;VX@=&\@=7-E('1O('-T;W)E('1H92!P87-S=V]R9"!I;B!T
M:&4*("H@("`@("`@("`@("`@("`@("`@("`@=&%B;&4@*&4N9RX@<&QA:6XL
M(&-R>7!T+"!M9#4M:&5X+"!M9#4M8F%S938T+"!S;60U+`H@*B`@("`@("`@
M("`@("`@("`@("`@("!S:&$L('-S:&$I+@H@*B`@("`@("`@("`@("`@("`@
M("`@("!$149!54Q4.B`G;60U+6AE>"<*("H@("`G<VAO=U]E;F-R>7!T:6]N
M)R`@5VAE=&AE<B!O<B!N;W0@=&\@<')E<&5N9"!T:&4@96YC<GEP=&EO;B!I
M;B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@<&%S<W=O<F0@9FEE;&0N
M"B`J("`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=F86QS92<\+W!R
M93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A
M=&EO;G,Z/'!R93X*("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@;V8@
M=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G<')O=&]C;VPG("!4:&4@8V]M
M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J
M("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@
M("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE
M8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S=V]R9"<@(%1H92!P87-S
M=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`G;W!T:6]N
M<R<@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T86)A
M<V4N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N
M;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W1T>2<@("`@("`@5&AE(%14
M62!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X\+W!R93X*
M("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+V-U<W1O;7-Q
M;"YP:'`L=B`Q+C$V+C$P+C@@,C`P-2\Q,2\S,"`P,#HP,SHS.2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(@4F]N;FEE($=A<F-I82`\<F]N;FEE
M0&UK,BYN970^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!2;VYN:64@
M1V%R8VEA(#QR;VYN:65`;6LR+FYE=#X*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO96P@5F%N
M9&%L(#QJ=F%N9&%L0&EN9F]T96-K+G%C+F-A/@H@*B!`<VEN8V4@("!(;W)D
M92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]C
M=7-T;VUS<6P@97AT96YD<R!!=71H7W-Q;"!["@H@("`@+RHJ"B`@("`@*B!!
M;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C
M86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S
M(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D
M)R`@("`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W5P9&%T92<@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!T<G5E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@
M=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@
M("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W(%-13"!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@075T:%]C=7-T;VUS<6PH)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH*("`@("`@("!(
M;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1P87)A;7,L("=A=71H)RP*("`@
M("`@("`@("`@87)R87DH)W%U97)Y7V%U=&@G*2P*("`@("`@("`@("`@)V%U
M=&AE;G1I8V%T:6]N(&-U<W1O;2!344PG*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R
M92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED
M('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@
M5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@
M=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S
M97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T
M*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N
M("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U
M:6QD(&$@8W5S=&]M('%U97)Y+"!B87-E9"!O;B!T:&4@8V]N9FEG(&9I;&4N
M("HO"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y7V%U
M=&@G73L*("`@("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7$PG+"`D=&AI
M<RT^7V1B+3YQ=6]T92@D=7-E<DED*2P@)'%U97)Y*3L*("`@("`@("`D<75E
M<GD@/2!S=')?<F5P;&%C92@G7%`G+"`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI
M<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)V5N8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DI+"`D<75E
M<GDI.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U
M97)Y*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`D<F]W(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?
M1T5434]$15]!4U-/0RD["B`@("`@("`@("`@("\J($EF('=E(&AA=F4@870@
M;&5A<W0@;VYE(')E='5R;F5D(')O=RP@=&AE;B!T:&4@=7-E<B!I<PH@("`@
M("`@("`@("`@*B!V86QI9"X@*B\*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1R;W<I*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT+3YF<F5E*"D["B`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1R97-U;'0M/F9R964H*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T)!1$Q/
M1TE.*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T
M075T:$5R<F]R*$%55$A?4D5!4T].7T9!24Q%1"D["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))
M9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4
M:&4@8W)E9&5N=&EA;',@=&\@861D+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S
M97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!A(&-U<W1O;2!Q=65R>2P@8F%S
M960@;VX@=&AE(&-O;F9I9R!F:6QE+B`J+PH@("`@("`@("1Q=65R>2`]("1T
M:&ES+3Y?<&%R86US6R=Q=65R>5]A9&0G73L*("`@("`@("`D<75E<GD@/2!S
M=')?<F5P;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T92@D=7-E<DED*2P@
M)'%U97)Y*3L*("`@("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7%`G+"`D
M=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C
M<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W
M7V5N8W)Y<'1I;VXG72DI+"`D<75E<GDI.PH*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@82!S970@;V8@875T:&5N=&EC871I
M;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD240@("`@("`@5&AE(&]L9"!U<V5R260N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N97=)1"`@("`@("!4:&4@;F5W('5S97))9"X*("`@("`J($!P87)A
M;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!N97<@8W)E9&5N=&EA;',*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!U<&1A=&55<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA
M;',I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W:71H
M($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@("`D=&AI
M<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@82!C=7-T;VT@<75E
M<GDL(&)A<V5D(&]N('1H92!C;VYF:6<@9FEL92X@*B\*("`@("`@("`D<75E
M<GD@/2`D=&AI<RT^7W!A<F%M<ULG<75E<GE?=7!D871E)UT["B`@("`@("`@
M)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ/)RP@)'1H:7,M/E]D8BT^<75O=&4H
M)&]L9$E$*2P@)'%U97)Y*3L*("`@("`@("`D<75E<GD@/2!S=')?<F5P;&%C
M92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T92@D;F5W240I+"`D<75E<GDI.PH@
M("`@("`@("1Q=65R>2`]('-T<E]R97!L86-E*"=<4"<L("1T:&ES+3Y?9&(M
M/G%U;W1E*"1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)&-R961E;G1I86QS
M6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO
M;B==*2DL("1Q=65R>2D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B
M+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E<V5T<R!A('5S97(G<R!P87-S=V]R9"X@57-E9"!F;W(@97AA
M;7!L92!W:&5N('1H92!U<V5R(&1O97,@;F]T"B`@("`@*B!R96UE;6)E<B!T
M:&4@97AI<W1I;F<@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<E]I9"`@5&AE('5S97(@:60@9F]R('=H:6-H('1O(')E<V5T
M('1H92!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M:&4@;F5W('!A<W-W;W)D(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;@H@("`@("H@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5S971087-S=V]R9"@D=7-E<E]I9"D*("`@('L*
M("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A
M=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`O*B!'970@82!N97<@<F%N9&]M('!A<W-W;W)D+B`J
M+PH@("`@("`@("1P87-S=V]R9"`]($%U=&@Z.F=E;E)A;F1O;5!A<W-W;W)D
M*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@
M("`@)'%U97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y7W)E<V5T<&%S<W=O
M<F0G73L*("`@("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7$PG+"`D=&AI
M<RT^7V1B+3YQ=6]T92@D=7-E<E]I9"DL("1Q=65R>2D["B`@("`@("`@)'%U
M97)Y(#T@<W1R7W)E<&QA8V4H)UQ0)RP@)'1H:7,M/E]D8BT^<75O=&4H)'1H
M:7,M/F=E=$-R>7!T961087-S=V]R9"@D<&%S<W=O<F0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*2P@)'%U97)Y*3L*"B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<&%S<W=O<F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!S970@
M;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E<DED('1O(&1E;&5T92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("`@("`@(%-U8V-E<W,@
M;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E57-E<B@D
M=7-E<DED*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@
M=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD(&$@8W5S=&]M
M('%U97)Y+"!B87-E9"!O;B!T:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@("`@
M)'%U97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y7W)E;6]V92==.PH@("`@
M("`@("1Q=65R>2`]('-T<E]R97!L86-E*"=<3"<L("1T:&ES+3Y?9&(M/G%U
M;W1E*"1U<V5R260I+"`D<75E<GDI.PH*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO=F55
M<V5R1&%T82@D=7-E<DED*3L*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@
M86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&9A;'-E(&]N(&9A
M:6QU<F4O=6YS=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15
M<V5R<R@I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W
M:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@82!C=7-T;VT@
M<75E<GDL(&)A<V5D(&]N('1H92!C;VYF:6<@9FEL92X@*B\*("`@("`@("`D
M<75E<GD@/2`D=&AI<RT^7W!A<F%M<ULG<75E<GE?;&ES="==.PH*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@;G5L;"P@
M1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@86YD(&)U
M:6QD(')E='5R;B!A<G)A>2X@*B\*("`@("`@("`D=7-E<G,@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1R97-U;'0@87,@)&%R*2!["B`@("`@("`@
M("`@("1U<V5R<UM=(#T@)&%R6S!=.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1U<V5R<SL*("`@('T*"GT*`````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<```
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,3`W-0`Q,#0Q-S,V
M,C<W,0`P,C$Q-C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O075T:"]S<6PN
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])34%0+T%D;6EN+G!H<"<["@HO
M*BH*("H@5&AE($%U=&A?8WER<W%L(&-L87-S('!R;W9I9&5S(&$@4U%,(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S
M>7-T96T@9F]R('1H92!#>7)U<R!)34%0('-E<G9E<BX@36]S="!O9B!T:&4@
M9G5N8W1I;VYA;&ET>0H@*B!I<R!T:&4@<V%M92!A<R!F;W(@=&AE(%-13"!C
M;&%S<SL@;VYL>2!W:&%T(&ES(&1I9F9E<F5N="!O=F5R<FED97,@=&AE"B`J
M('!A<F5N="!C;&%S<R!I;7!L96UE;G1A=&EO;G,N"B`J"B`J(%)E<75I<F5D
M('!A<F%M971E<G,Z/'!R93X*("H@("`G8WER861M:6XG("!4:&4@=7-E<FYA
M;64@;V8@=&AE(&-Y<G5S(&%D;6EN:7-T<F%T;W(N"B`J("`@)V-Y<G!A<W,G
M("`@5&AE('!A<W-W;W)D(&9O<B!T:&4@8WER=7,@861M:6YI<W1R871O<BX*
M("H@("`G:6UA<%]D<VXG("!4:&4@9G5L;"!)34%0($133@H@*B`@("`@("`@
M("`@("`@("AI+F4N('ML;V-A;&AO<W0Z.3DS+VEM87`O<W-L+VYO=F%L:61A
M=&4M8V5R='TI+@H@*B`@("=P:'!T>7!E)R`@(%1H92!D871A8F%S92!T>7!E
M("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P<F4^"B`J"B`J($]P
M=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G9&]M86EN7V9I96QD)R`@
M("!)9B!S970@=&\@86YY=&AI;F<@;W1H97(@=&AA;B`G;F]N92<@=&AI<R!I
M<R!U<V5D(&%S"B`J("`@("`@("`@("`@("`@("`@("`@9FEE;&0@;F%M92!W
M:&5R92!D;VUA:6X@:7,@<W1O<F5D+@H@*B`@("`@("`@("`@("`@("`@("`@
M($1%1D%53%0Z("=D;VUA:6Y?;F%M92<*("H@("`G96YC<GEP=&EO;B<@("`@
M("!4:&4@96YC<GEP=&EO;B!T;R!U<V4@=&\@<W1O<F4@=&AE('!A<W-W;W)D
M(&EN('1H90H@*B`@("`@("`@("`@("`@("`@("`@('1A8FQE("AE+F<N('!L
M86EN+"!C<GEP="P@;60U+6AE>"P@;60U+6)A<V4V-"P@<VUD-2P*("H@("`@
M("`@("`@("`@("`@("`@("!S:&$L('-S:&$I+@H@*B`@("`@("`@("`@("`@
M("`@("`@($1%1D%53%0Z("=M9#4M:&5X)PH@*B`@("=F;VQD97)S)R`@("`@
M("`@($%N(&%R<F%Y(&]F(&9O;&1E<G,@=&\@8W)E871E('5N9&5R('5S97)N
M86UE+@H@*B`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z($Y/3D4*("H@
M("`G<&%S<W=O<F1?9FEE;&0G("!4:&4@;F%M92!O9B!T:&4@<&%S<W=O<F0@
M9FEE;&0@:6X@=&AE(&%U=&@@=&%B;&4N"B`J("`@("`@("`@("`@("`@("`@
M("`@1$5&055,5#H@)W!A<W-W;W)D)PH@*B`@("=Q=6]T82<@("`@("`@("`@
M(%1H92!Q=6]T82`H:6X@:VEL;V)Y=&5S*2!T;R!G<F%N="!O;B!T:&4@;6%I
M;&)O>"X*("H@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B!.3TY%"B`J
M("`@)W1A8FQE)R`@("`@("`@("`@5&AE(&YA;64@;V8@=&AE(&%U=&@@=&%B
M;&4@:6X@)V1A=&%B87-E)RX*("H@("`@("`@("`@("`@("`@("`@("!$149!
M54Q4.B`G86-C;W5N='5S97(G"B`J("`@)W5N:7AH:65R)R`@("`@("`@5&AE
M('9A;'5E(&]F(&EM87!D+F-O;F8G<R!U;FEX:&EE<F%R8VAY<V5P('-E='1I
M;F<N"B`J("`@("`@("`@("`@("`@("`@("`@4V5T('1H:7,@=&\@=')U92!I
M9B!T:&4@=F%L=64@:7,@=')U92!I;B!I;6%P9"YC;VYF+@H@*B`@("=U<V5R
M;F%M95]F:65L9"<@(%1H92!N86UE(&]F('1H92!U<V5R;F%M92!F:65L9"!I
M;B!T:&4@875T:"!T86)L92X*("H@("`@("`@("`@("`@("`@("`@("!$149!
M54Q4.B`G=7-E<FYA;64G/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@
M9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J("`@)V1A=&%B87-E
M)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=H;W-T<W!E8R<@
M(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P
M<F]T;V-O;"<@(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@
M)W5N:7@G+"!E=&,N*2X*("H@("`G=7-E<FYA;64G("!4:&4@=7-E<FYA;64@
M=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G
M<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R
M;F%M92<N"B`J("`@)V]P=&EO;G,G("`@061D:71I;VYA;"!O<'1I;VYS('1O
M('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T)R`@("`@(%1H92!P
M;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@
M("=T='DG("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T
M:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J"B`J(%1H92!T86)L92!S=')U8W1U
M<F4@9F]R('1H92!A=71H('-Y<W1E;2!I<R!A<R!F;VQL;W=S.@H@*@H@*B`\
M<')E/@H@*B!#4D5!5$4@5$%"3$4@86-C;W5N='5S97(@*`H@*B`@("`@=7-E
M<FYA;64@("`@5D%20TA!4B@R-34I($))3D%262!.3U0@3E5,3"!$149!54Q4
M("<G+`H@*B`@("`@<&%S<W=O<F0@("`@5D%20TA!4B@S,BD@0DE.05)9($Y/
M5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!P<F5F:7@@("`@("!605)#2$%2
M*#4P*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@9&]M86EN7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!53DE1
M544@2T59('5S97)N86UE("AU<V5R;F%M92D*("H@*3L*("H*("H@0U)%051%
M(%1!0DQ%(&%D;6EN=7-E<B`H"B`J("`@("!U<V5R;F%M92`@("!605)#2$%2
M*#4P*2!"24Y!4ED@3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@('!A<W-W
M;W)D("`@(%9!4D-(05(H-3`I($))3D%262!.3U0@3E5,3"!$149!54Q4("<G
M+`H@*B`@("`@='EP92`@("`@("`@24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4
M("<P)RP*("H@("`@(%-)1"`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,
M3"!$149!54Q4("<G+`H@*B`@("`@:&]M92`@("`@("`@5D%20TA!4B@R-34I
M($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!04DE-05)9($M%62`H=7-E
M<FYA;64I"B`J("D["B`J"B`J($-214%412!404),12!A;&EA<R`H"B`J("`@
M("!A;&EA<R`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$P@1$5&055,5"`G
M)RP*("H@("`@(&1E<W0@("`@("`@($Q/3D=415A4+`H@*B`@("`@=7-E<FYA
M;64@("`@5D%20TA!4B@U,"D@3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@
M('-T871U<R`@("`@($E.5"@Q,2D@3D]4($Y53$P@1$5&055,5"`G,2<L"B`J
M("`@("!04DE-05)9($M%62`H86QI87,I"B`J("D["B`J"B`J($-214%412!4
M04),12!D;VUA:6X@*`H@*B`@("`@9&]M86EN7VYA;64@5D%20TA!4B@R-34I
M($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!P<F5F:7@@("`@("!605)#
M2$%2*#4P*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@;6%X86-C;W5N
M=',@24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4("<R,"<L"B`J("`@("!Q=6]T
M82`@("`@("!)3E0H,3`I($Y/5"!.54Q,($1%1D%53%0@)S(P,#`P)RP*("H@
M("`@('1R86YS<&]R="`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4
M("=C>7)U<R<L"B`J("`@("!F<F5E;F%M97,@("!%3E5-*"=915,G+"=.3R<I
M($Y/5"!.54Q,($1%1D%53%0@)TY/)RP*("H@("`@(&9R965A9&1R97-S($5.
M54TH)UE%4R<L)TY/)RD@3D]4($Y53$P@1$5&055,5"`G3D\G+`H@*B`@("`@
M4%))34%262!+15D@*&1O;6%I;E]N86UE*2P*("H@("`@(%5.25%512!+15D@
M<')E9FEX("AP<F5F:7@I"B`J("D["B`J"B`J($-214%412!404),12!D;VUA
M:6YA9&UI;B`H"B`J("`@("!D;VUA:6Y?;F%M92!605)#2$%2*#(U-2D@3D]4
M($Y53$P@1$5&055,5"`G)RP*("H@("`@(&%D;6EN=7-E<B`@(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"!$149!54Q4("<G"B`J("D["B`J"B`J($-214%412!4
M04),12!S96%R8V@@*`H@*B`@("`@<V5A<F-H7VED("`@5D%20TA!4B@R-34I
M($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!S96%R8VA?<W%L("!415A4
M($Y/5"!.54Q,+`H@*B`@("`@<&5R<&%G92`@("`@24Y4*#$Q*2!.3U0@3E5,
M3"!$149!54Q4("<P)RP*("H@("`@('1I;65S=&%M<"`@(%1)34535$%-4"@Q
M-"D@3D]4($Y53$PL"B`J("`@("!04DE-05)9($M%62`H<V5A<F-H7VED*2P*
M("H@("`@($M%62!S96%R8VA?:60@*'-E87)C:%]I9"D*("H@*3L*("H*("H@
M0U)%051%(%1!0DQ%('9I<G1U86P@*`H@*B`@("`@86QI87,@("`@("`@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!D97-T("`@
M("`@("!,3TY'5$585"P*("H@("`@('5S97)N86UE("`@(%9!4D-(05(H-3`I
M($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!S=&%T=7,@("`@("!)3E0H
M,3$I($Y/5"!.54Q,($1%1D%53%0@)S$G+`H@*B`@("`@2T59(&%L:6%S("AA
M;&EA<RD*("H@*3L*("H*("H@0U)%051%(%1!0DQ%(&QO9R`H"B`J("`@("!I
M9"`@("`@("`@("!)3E0H,3$I($Y/5"!.54Q,($%55$]?24Y#4D5-14Y4+`H@
M*B`@("`@;7-G("`@("`@("`@5$585"!.3U0@3E5,3"P*("H@("`@('5S97(@
M("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@
M("`@:&]S="`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@
M)R<L"B`J("`@("!T:6UE("`@("`@("!$051%5$E-12!.3U0@3E5,3"!$149!
M54Q4("<R,#`P+3`P+3`P(#`P.C`P.C`P)RP*("H@("`@('!I9"`@("`@("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@4%))
M34%262!+15D@*&ED*0H@*B`I.PH@*B`\+W!R93X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`L=B`Q+C,S+C$P+C$S(#(P
M,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@26QY82`\;6%I;$!K<F5L+F]R9SX*("H@0V]P>7)I9VAT(#(P
M,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@26QY82`\;6%I;$!K<F5L+F]R9SX*("H@
M0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L
M87-S($%U=&A?8WER<W%L(&5X=&5N9',@075T:%]S<6P@>PH*("`@("\J*@H@
M("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!)34%0(&-O;FYE8W1I;VXN
M"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@
M)%]I;6%P4W1R96%M.PH*("`@("\J*@H@("`@("H@2&%N9&QE(&9O<B!A;B!)
M34%07T%D;6EN(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R($E-05!?061M
M:6X*("`@("`J+PH@("`@=F%R("1?861M:6X["@H@("`@+RHJ"B`@("`@*B!(
M:65R87)C:'D@<V5P87)A=&]R('1O('5S92`H92YG+BP@:7,@:70@=7-E<B]M
M86EL8F]X(&]R('5S97(N;6%I;&)O>"D*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]S97!A<F%T;W(@/2`G+B<["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P
M87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7V-Y<G-Q;"@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X
M=&5N<VEO;D5X:7-T<R@G:6UA<"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF
M871A;"A?*")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M("`@("`@("!P87)E;G0Z.D%U=&A?<W%L*"1P87)A;7,I.PH*("`@("`@("`D
M861M:6Y?<&%R86US(#T@87)R87DH)V%D;6EN7W5S97(G(#T^("1P87)A;7-;
M)V-Y<F%D;6EN)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A
M9&UI;E]P87-S=V]R9"<@/3X@)'!A<F%M<ULG8WER<&%S<R==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9'-N)R`]/B`D<&%R86US6R=I;6%P
M7V1S;B==*3L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=U
M;FEX:&EE<B==*2D@>PH@("`@("`@("`@("`D861M:6Y?<&%R86US6R=U<V5R
M:&EE<F%R8VAY)UT@/2`G=7-E<B\G.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^7V%D;6EN(#T@)FYE=R!)34%07T%D;6EN*"1A9&UI;E]P87)A;7,I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D(&$@<V5T(&]F(&%U=&AE;G1I8V%T
M:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97))9"`@("`@("!4:&4@=7-E<DED('1O(&%D9"X*("`@("`J($!P87)A
M;2!A<G)A>2`@)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@861D
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72D@)B8*("`@
M("`@("`@("`@*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72`A/2`G
M;F]N92<I*2!["B`@("`@("`@("`@(&QI<W0H)&YA;64L("1D;VUA:6XI(#T@
M97AP;&]D92@G0"<L("1U<V5R260I.PH@("`@("`@("`@("`O*B!"=6EL9"!T
M:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F
M*"=)3E-%4E0@24Y43R`E<R`H)7,L("5S+"`E<RD@5D%,5453("@_+"`_+"`_
M*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9%]F:65L9"==*3L*("`@("`@("`@("`@)'9A;'5E<R`](&%R
M<F%Y*"1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1O;6%I
M;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971#<GEP
M=&5D4&%S<W=O<F0H)&-R961E;G1I86QS6R=P87-S=V]R9"==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*2D[
M"@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y
M($%U=&A?8WER<W%L.CIA9&15<V5R*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@)&1B
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("`@("`@)'%U97)Y(#T@)TE.4T525"!)3E1/('9I<G1U86P@*&%L
M:6%S+"!D97-T+"!U<V5R;F%M92P@<W1A='5S*2!604Q515,@*#\L(#\L(#\L
M(#$I)SL*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1U<V5R260L("1N
M86UE+"`D;F%M92D["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M4U%,(%%U97)Y(&)Y($%U=&A?8WER<W%L.CIA9&15<V5R*"DZ("<@+B`D<75E
M<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("`@("`@)&1B<F5S=6QT,B`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1D8G)E<W5L=#(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&)R
M97-U;'0R.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&1B<F5S=6QT(#T@<&%R96YT.CIA9&15<V5R*"1U<V5R260L("1C
M<F5D96YT:6%L<RD["B`@("`@("`@("`@("1N86UE(#T@)'5S97))9#L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES7V$H)&1B<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9&)R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES7V$H)')E<W5L="`]("1T:&ES+3Y?861M:6XM
M/F%D9$UA:6QB;W@H)&YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@($!A<G)A>5]W86QK*"1T:&ES+3Y?<&%R86US6R=F;VQD97)S)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+"`G7V-R96%T95-U
M8D9O;&1E<G,G*2P@)&YA;64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=)34%0(&UA:6QB;W@@8W)E871I;VX@
M9F]R("<@+B`D;F%M92`N("<@9F%I;&5D.B`G("X@)')E<W5L="T^9V5T365S
M<V%G92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,B*2P@)')E<W5L="T^9V5T365S<V%G92@I*2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;
M)W%U;W1A)UTI("8F("1T:&ES+3Y?<&%R86US6R=Q=6]T82==(#X](#`I('L*
M("`@("`@("`@("`@:68@*"%`:6UA<%]S971?<75O=&$H)'1H:7,M/E]I;6%P
M4W1R96%M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E
M<B<@+B`D=&AI<RT^7W-E<&%R871O<B`N("1N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<75O=&$G72DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,B*2P@:6UA<%]L87-T7V5R<F]R*"DI*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA
M;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@
M=7-E<DED('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@("`@("`@(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?8V]N;F5C="@I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=D;VUA:6Y?9FEE;&0G72D@)B8*("`@("`@("`@("`@*"1T:&ES+3Y?
M<&%R86US6R=D;VUA:6Y?9FEE;&0G72`A/2`G;F]N92<I*2!["B`@("`@("`@
M("`@(&QI<W0H)&YA;64L("1D;VUA:6XI(#T@97AP;&]D92@G0"<L("1U<V5R
M260I.PH@("`@("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@
M("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!7
M2$5212`E<R`](#\@86YD("5S(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I
M96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V1O;6%I;E]F:65L9"==*3L*("`@("`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*"1N86UE+"`D9&]M86EN*3L*"B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=344P@475E<GD@8GD@075T:%]C>7)S<6PZ.G)E;6]V955S
M97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["@H@("`@("`@("`@("`D9&)R97-U;'0@/2`D=&AI<RT^7V1B
M+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("`D<75E<GD@
M/2`G1$5,151%($923TT@=FER='5A;"!72$5212!D97-T(#T@/R<["B`@("`@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D;F%M92D["@H@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($%U=&A?8WER<W%L.CIR
M96UO=F55<V5R*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@)&1B<F5S=6QT,B`]("1T
M:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@("`@
M(&EF("AI<U]A*"1D8G)E<W5L=#(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D9&)R97-U;'0R.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1B<F5S=6QT(#T@<&%R96YT
M.CIR96UO=F55<V5R*"1U<V5R260I.PH@("`@("`@("`@("`D;F%M92`]("1U
M<V5R260["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D9&)R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1D8G)E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@("\J($1E;&5T92!)34%0(&UA:6QB;W@N
M("HO"B`@("`@("`@)&EM87!R97-U;'0@/2`D=&AI<RT^7V%D;6EN+3YR96UO
M=F5-86EL8F]X*"1N86UE*3L*"B`@("`@("`@:68@*&ES7V$H)&EM87!R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*"))34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<R(I+"`D:6UA<')E<W5L="T^9V5T365S<V%G92@I*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/G)E;6]V955S97)$871A
M*"1U<V5R260I.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M;W!E;B!C;VYN96-T:6]N<R!T;R!T:&4@4U%,(&%N9"!)34%0('-E<G9E<G,N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O
M;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]C;VYN96-T960I
M('L*("`@("`@("`@("`@<&%R96YT.CI?8V]N;F5C="@I.PH*("`@("`@("`@
M("`@+R\@4F5S970@=&AE("1?8V]N;F5C=&5D(&9L86<[('=E(&AA=F5N)W0@
M>65T('-U8V-E<W-F=6QL>2!O<&5N960*("`@("`@("`@("`@+R\@979E<GET
M:&EN9RX*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!F86QS93L*
M"B`@("`@("`@("`@("1T:&ES+3Y?:6UA<%-T<F5A;2`]($!I;6%P7V]P96XH
M)'1H:7,M/E]P87)A;7-;)VEM87!?9'-N)UTL("1T:&ES+3Y?<&%R86US6R=C
M>7)A9&UI;B==+"`D=&AI<RT^7W!A<F%M<ULG8WER<&%S<R==+"!/4%](04Q&
M3U!%3BD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]I;6%P4W1R96%M*2![
M"B`@("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH<W!R:6YT9BA?*")#86XG
M="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(I+"!I;6%P7VQA<W1?97)R
M;W(H*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W5N:7AH:65R
M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E<&%R871O<B`]("<O
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E
M9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@4U%,(&%N
M9"!)34%0('-E<G9E<G,@86YD(&-L96%N('5P('1H92!C;VYN96-T:6]N<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("!P87)E;G0Z.E]D:7-C;VYN96-T*"D["B`@("`@("`@("`@($!I;6%P7V-L
M;W-E*"1T:&ES+3Y?:6UA<%-T<F5A;2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@86QL
M(&UA:6QB;WAE<R!S=7!P;&EE9"!I;B!C;VYF:6=U<F%T:6]N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M<F5A=&53=6)&;VQD97)S*"1V86QU92P@)&ME>2P@)'5S97).86UE*0H@("`@
M>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F
M:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@;&ES="@D=7-E
M<DYA;64I(#T@97AP;&]D92@G0"<L("1U<V5R3F%M92D["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?861M:6XM/F%D9$UA:6QB;W@H)'5S97).86UE("X@
M)'1H:7,M/E]S97!A<F%T;W(@+B`D=F%L=64I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@3&ES="!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@=7-E<DED<RP@;W(@
M9F%L<V4@;VX@9F%I;'5R92]U;G-U<'!O<G1E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I
M('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J
M+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72D@)B8*("`@("`@
M("`@("`@*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72`A/2`G;F]N
M92<I*2!["B`@("`@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GD@=VET
M:"!D;VUA:6XN("HO"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%
M3$5#5"`E<RP@)7,@1E)/32`E<R!/4D1%4B!"62`E<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I
M96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V1O;6%I;E]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L
M9"==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!"=6EL9"!T
M:&4@4U%,('%U97)Y('=I=&AO=70@9&]M86EN+B`J+PH@("`@("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!/4D1%4B!"62`E
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD
M)UTI.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-1
M3"!1=65R>2!B>2!!=71H7V-Y<G-Q;#HZ;&ES=%5S97)S*"DZ("<@+B`D<75E
M<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@;G5L
M;"P@1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@86YD
M(&)U:6QD(')E='5R;B!A<G)A>2X@*B\*("`@("`@("`D=7-E<G,@/2!A<G)A
M>2@I.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O
M;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)')E<W5L="!A<R`D87(I('L*("`@("`@("`@("`@("`@("1U<V5R<UM=
M(#T@)&%R6S!=("X@)T`G("X@)&%R6S%=.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R96%C:"`H)')E<W5L="!A<R`D
M87(I('L*("`@("`@("`@("`@("`@("1U<V5R<UM=(#T@)&%R6S!=.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97)S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I
M8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&]L9$E$("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F5W240@("`@("`@5&AE(&YE=R!U<V5R260N"B`@("`@*B!`
M<&%R86T@87)R87D@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E
M;G1I86QS*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@
M=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H
M:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@
M("`@("`@("`@;&ES="@D;F%M92P@)&1O;6%I;BD@/2!E>'!L;V1E*"=`)RP@
M)&]L9$E$*3L*("`@("`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2!W
M:71H(&1O;6%I;BX@*B\*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M55!$051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@/2`_(&%N9"`E<R`](#\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=D;VUA:6Y?9FEE;&0G72D["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A
M>2@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S
M<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W
M7V5N8W)Y<'1I;VXG72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92P@)&1O;6%I;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@/2`_
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G
M72D["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^9V5T0W)Y
M<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;VQD240I.PH@("`@("`@
M('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!
M=71H7V-Y<G-Q;#HZ=7!D871E57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<```````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C<V
M,C,`,3`T,3<S-C(W-S$`,#(Q,#(Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]C>7)U
M<R!C;&%S<R!P<F]V:61E<R!H;W)D92!W:71H('1H92!A8FEL:71Y(&]F(&%D
M;6EN:7-T<F%T:6YG"B`J(&$@0WER=7,@;6%I;"!S97)V97(@875T:&5N=&EC
M871I;VYS(&%G86EN<W0@86YO=&AE<B!B86-K96YD('1H870@2&]R9&4*("H@
M8V%N('5P9&%T92`H96<@4U%,(&]R($Q$05`I+@H@*@H@*B!297%U:7)E9"!P
M87)A;65T97)S.CQP<F4^"B`J("`@)V-Y<F%D;6EN)R`@(%1H92!U<V5R;F%M
M92!O9B!T:&4@8WER=7,@861M:6YI<W1R871O<@H@*B`@("=C>7)P87-S)R`@
M("!4:&4@<&%S<W=O<F0@9F]R('1H92!C>7)U<R!A9&UI;FES=')A=&]R"B`J
M("`@)VEM87!?9'-N)R`@(%1H92!F=6QL($E-05`@1%-.("AI+F4N"B`@("`@
M("`@("`@("`@("`@('ML;V-A;&AO<W0Z.3DS+VEM87`O<W-L+VYO=F%L:61A
M=&4M8V5R='TI"B`J("`@)V)A8VME;F0G("`@(%1H92!C;VUP;&5T92!H87-H
M(&9O<B!T:&4@075T:%\J(&1R:79E<B!T:&%T(&-Y<G5S"B`J("`@("`@("`@
M("`@("`@(&%U=&AE;G1I8V%T97,@86=A:6YS="`H96<@4U%,+"!,1$%0*2X*
M("H@("`G<V5P87)A=&]R)R`@2&EE<F%R8VAY('-E<&%R871O<B!T;R!U<V4@
M*&4N9RXL(&ES(&ET('5S97(O;6%I;&)O>"!O<@H@*B`@("`@("`@("`@("`@
M("!U<V5R+FUA:6QB;W@I/"]P<F4^"B`J"B`J($]P=&EO;F%L('9A;'5E<SH\
M<')E/@H@*B`@("=U;FEX:&EE<B<@("!4:&4@=F%L=64@;V8@:6UA<&0N8V]N
M9B=S('5N:7AH:65R87)C:'ES97`@<V5T=&EN9RX*("H@("`@("`@("`@("`@
M("`@4V5T('1H:7,@=&\@)W1R=64G(&EF('1H92!V86QU92!I<R!T<G5E(&EN
M(&EM87!D+F-O;F8*("H@("`G9F]L9&5R<R<@("`@06X@87)R87D@;V8@9F]L
M9&5R<R!T;R!C<F5A=&4@=6YD97(@=7-E<FYA;64N"B`J("`@("`@("`@("`@
M("`@($1O97-N)W0@8W)E871E('-U8F9O;&1E<G,@8GD@9&5F875L="X*("H@
M("`G<75O=&$G("`@("`@5&AE('%U;W1A("AI;B!K:6QO8GET97,I('1O(&=R
M86YT(&]N('1H92!M86EL8F]X+@H@*B`@("`@("`@("`@("`@("!$;V5S(&YO
M="!E<W1A8FQI<V@@<75O=&$@8GD@9&5F875L="X\+W!R93X*("H*("H@17AA
M;7!L92!5<V%G93H\<')E/@H@*B`@("1C;VYF6R=A=71H)UU;)V1R:79E<B==
M(#T@)V-O;7!O<VET92<["B`J("`@)&-O;F9;)V%U=&@G75LG<&%R86US)UU;
M)VQO9VEN<V-R965N7W-W:71C:"==(#T@)U]H;W)D95]S96QE8W1?;&]G:6YS
M8W)E96XG.PH@*B`@("1C;VYF6R=A=71H)UU;)W!A<F%M<R==6R=A9&UI;E]D
M<FEV97(G72`]("=C>7)U<R<["B`J("`@)&-O;F9;)V%U=&@G75LG<&%R86US
M)UU;)V1R:79E<G,G75LG:6UP)UT@/2!A<G)A>2@G9')I=F5R)R`]/B`G87!P
M;&EC871I;VXG+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH)V%P<"<@
M/3X@)VEM<"<I*3L*("H@("`D8V]N9ELG875T:"==6R=P87)A;7,G75LG9')I
M=F5R<R==6R=C>7)U<R==(#T@87)R87DH)V1R:79E<B<@/3X@)V-Y<G5S)RP*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH)V-Y<F%D;6EN)R`]/B`G
M8WER=7,G+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8WER<&%S
M<R<@/3X@)W!A<W-W;W)D)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W-E<&%R871O<B<@/3X@)RXG+`H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:6UA<%]D<VXG(#T^("=[;6%I:RYE>&%M<&QE+F-O;2]I;6%P
M?2<I*3L*("H@("`D8V]N9ELG875T:"==6R=P87)A;7,G75LG9')I=F5R<R==
M6R=C>7)U<R==6R=P87)A;7,G75LG8F%C:V5N9"==(#T@87)R87DH)V1R:79E
M<B<@/3X@)W-Q;"<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=P87)A;7,G(#T^(&%R<F%Y*"=P:'!T>7!E)R`]/B`G;7ES<6PG+`H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G:&]S='-P96,G(#T^("=D871A8F%S92YE>&%M<&QE+F-O;2<L"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=P<F]T;V-O;"<@/3X@)W1C<"<L"B`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R;F%M92<@/3X@)W5S
M97)N86UE)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`G<&%S<W=O<F0G+`H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&%T86)A<V4G(#T^("=M86EL)RP*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`G86-C
M;W5N='5S97(G+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G96YC<GEP=&EO;B<@/3X@)VUD-2UH97@G+`H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=7-E<FYA;65?9FEE;&0G(#T^("=U<V5R;F%M92<L"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P
M87-S=V]R9%]F:65L9"<@/3X@)W!A<W-W;W)D)RDI.PH@*@H@*B`@(&EF("@A
M9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?<V5L96-T7VQO9VEN<V-R965N)RDI
M('L*("H@("`@("`@9G5N8W1I;VX@7VAO<F1E7W-E;&5C=%]L;V=I;G-C<F5E
M;B@I('L*("H@("`@("`@("`@(')E='5R;B`G:6UP)SL*("H@("`@("`@?0H@
M*B`@('T\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<"QV(#$N,34N,3`N,3,@,C`P-B\P,2\P,2`R,3HR.#HP-R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!);'EA(#QM86EL
M0&MR96PN;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!);'EA(#QM86EL0&MR96PN;W)G/@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA
M<W,@075T:%]C>7)U<R!E>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@
M2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!)34%0(&-O;FYE8W1I;VXN"B`@("`@
M*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]I;6%P
M4W1R96%M.PH*("`@("\J*@H@("`@("H@1FQA9R!I;F1I8V%T:6YG(&EF('1H
M92!)34%0(&-O;FYE8W1I;VX@:7,@8V]N;F5C=&5D+@H@("`@("H*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYN96-T960["@H@
M("`@+RHJ"B`@("`@*B!0;VEN=&5R('1O(&%N;W1H97(@075T:%\@8F%C:V5N
M9"!T:&%T($-Y<G5S(&%U=&AE;G1I8V%T97,@86=A:6YS="X*("`@("`J"B`@
M("`@*B!`=F%R($%U=&@*("`@("`J+PH@("`@('9A<B`D7V)A8VME;F0["@H@
M("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H
M870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I
M;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I
M97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@=')U92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^('1R=64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D
M)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M;6]V92<@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V=R;W5P<R<@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@
M/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@075T:%]C>7)U<R@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["@H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG<V5P87)A=&]R)UT@/2`G+B<["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)W5N:7AH:65R
M)UTI("8F("1T:&ES+3Y?<&%R86US6R=U;FEX:&EE<B==(#T]('1R=64I('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==(#T@)R\G
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES
M=',H)VEM87`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M0W)E871E(&)A8VME;F0@:6YS=&%N8V4N"B`@("`@("`@)'1H:7,M/E]B86-K
M96YD(#T@)D%U=&@Z.G-I;F=L971O;B@D=&AI<RT^7W!A<F%M<ULG8F%C:V5N
M9"==6R=D<FEV97(G72P@)'1H:7,M/E]P87)A;7-;)V)A8VME;F0G75LG<&%R
M86US)UTI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?8F%C:V5N9"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]B86-K
M96YD.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@=&AE(&-A<&%B:6QI
M=&EE<R!O9B!T:&4@8F%C:V5N9"X*("`@("`@("!I9B`H(21T:&ES+3Y?8F%C
M:V5N9"T^:&%S0V%P86)I;&ET>2@G861D)RD@?'P*("`@("`@("`@("`@(21T
M:&ES+3Y?8F%C:V5N9"T^:&%S0V%P86)I;&ET>2@G=7!D871E)RD@?'P*("`@
M("`@("`@("`@(21T:&ES+3Y?8F%C:V5N9"T^:&%S0V%P86)I;&ET>2@G<F5M
M;W9E)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3YC87!A8FEL:71I97-;)VQI<W0G72`]("1T:&ES+3Y?8F%C:V5N
M9"T^:&%S0V%P86)I;&ET>2@G;&ES="<I.PH@("`@("`@("1T:&ES+3YC87!A
M8FEL:71I97-;)V=R;W5P<R==(#T@)'1H:7,M/E]B86-K96YD+3YH87-#87!A
M8FEL:71Y*"=G<F]U<',G*3L*("`@("`@("`D=&AI<RT^8V%P86)I;&ET:65S
M6R=T<F%N<W!A<F5N="==(#T@)'1H:7,M/E]B86-K96YD+3YH87-#87!A8FEL
M:71Y*"=T<F%N<W!A<F5N="<I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D
M(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@("!4:&4@=7-E<DED
M('1O(&%D9"X*("`@("`J($!P87)A;2!A<G)A>2`@)&-R961E;G1I86QS("!4
M:&4@8W)E9&5N=&EA;',@=&\@861D+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S
M97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/E]B86-K96YD+3YA9&15
M<V5R*"1U<V5R260L("1C<F5D96YT:6%L<RD["B`@("`@("`@:68@*&ES7V$H
M)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("!]"@H@("`@("`@("1N86UE(#T@:6UA<%]U=&8W7V5N8V]D
M92@D=7-E<DED*3L*("`@("`@("!I9B`H0&EM87!?8W)E871E;6%I;&)O>"@D
M=&AI<RT^7VEM87!3=')E86TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:6UA<%]U=&8W7V5N8V]D92@D=&AI<RT^7W!A<F%M<ULG:6UA<%]D
M<VXG72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97(G
M("X@)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==("X@)&YA;64I*2D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)V9O;&1E<G,G
M72D@)B8@:7-?87)R87DH)'1H:7,M/E]P87)A;7-;)V9O;&1E<G,G72DI('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US6R=F;VQD
M97)S)UT@87,@)&9O;&1E<BD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8W)E871E4W5B1F]L9&5R*"1N86UE+"`D9F]L9&5R*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=)34%0(&UA:6QB;W@@8W)E871I
M;VX@9F]R("<@+B`D;F%M92`N("<@9F%I;&5D("<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*"))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(I+"!I
M;6%P7VQA<W1?97)R;W(H*2DI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=Q=6]T82==*2`F)B`D=&AI<RT^7W!A<F%M
M<ULG<75O=&$G72`^/2`P*2!["B`@("`@("`@("`@(&EF("@A0&EM87!?<V5T
M7W%U;W1A*"1T:&ES+3Y?:6UA<%-T<F5A;2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W5S97(G("X@)'1H:7,M/E]S97!A<F%T;W(@+B`D
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W%U;W1A)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(BDL(&EM87!?;&%S=%]E<G)O<B@I*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@<V5T(&]F(&%U=&AE
M;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T;R!D96QE=&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("`@("`@("!3=6-C97-S(&]R(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S97))9"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@)')E
M<R`]("1T:&ES+3Y?8F%C:V5N9"T^<F5M;W9E57-E<B@D=7-E<DED*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T($%#
M3"!F;W(@;6%I;&)O>"!D96QE=&EO;BX@*B\*("`@("`@("!L:7-T*"1A9&UI
M;BD@/2!E>'!L;V1E*"=`)RP@)'1H:7,M/E]P87)A;7-;)V-Y<F%D;6EN)UTI
M.PH@("`@("`@($!I;6%P7W-E=&%C;"@D=&AI<RT^7VEM87!3=')E86TL"B`@
M("`@("`@("`@("`@("`@("`@("=U<V5R)R`N("1T:&ES+3Y?<&%R86US6R=S
M97!A<F%T;W(G72`N("1U<V5R260L"B`@("`@("`@("`@("`@("`@("`@("1A
M9&UI;BP@)VQR<W=I<&-D82<I.PH*("`@("`@("`O*B!$96QE=&4@24U!4"!M
M86EL8F]X+B`J+PH@("`@("`@("1I;6%P<F5S=6QT(#T@0&EM87!?9&5L971E
M;6%I;&)O>"@D=&AI<RT^7VEM87!3=')E86TL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=I;6%P
M7V1S;B==("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W5S97(G("X@)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==("X@
M)'5S97))9"D["@H@("`@("`@(&EF("@A)&EM87!R97-U;'0I('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*"))34%0
M(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(I+"!I;6%P7VQA<W1?97)R
M;W(H*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO
M=F55<V5R1&%T82@D=7-E<DED*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(&]P96X@8V]N;F5C=&EO;G,@=&\@=&AE(%-13"!A;F0@24U!
M4"!S97)V97)S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?
M8V]N;F5C=&5D*2!["@H@("`@("`@("`@("`D=&AI<RT^7VEM87!3=')E86T@
M/2!`:6UA<%]O<&5N*"1T:&ES+3Y?<&%R86US6R=I;6%P7V1S;B==+"`D=&AI
M<RT^7W!A<F%M<ULG8WER861M:6XG72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG8WER<&%S
M<R==+"!/4%](04Q&3U!%3BD["@H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?
M:6UA<%-T<F5A;2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*'-P
M<FEN=&8H7R@B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM87!?;&%S
M=%]E<G)O<B@I*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$:7-C;VYN96-T(&9R;VT@=&AE($E-05`@<V5R=F5R+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@($!I;6%P
M7V-L;W-E*"1T:&ES+3Y?:6UA<%-T<F5A;2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@
M82!M86EL8F]X97,@<W5P<&QI960@:6X@8V]N9FEG=7)A=&EO;@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8W)E871E4W5B1F]L9&5R*"1U<V5R3F%M92P@)&9O;&1E<DYA;64I"B`@("![
M"B`@("`@("`@($!I;6%P7V-R96%T96UA:6QB;W@H)'1H:7,M/E]I;6%P4W1R
M96%M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UA<%]U=&8W7V5N
M8V]D92@D=&AI<RT^7W!A<F%M<ULG:6UA<%]D<VXG72`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=7-E<B<@+B`D=&AI<RT^7W!A<F%M<ULG<V5P
M87)A=&]R)UT@+B`D=7-E<DYA;64@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==("X@
M)&9O;&1E<DYA;64I*3L*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@86QL
M('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&9A;'-E(&]N(&9A:6QU
M<F4O=6YS=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F%C:V5N9"T^;&ES
M=%5S97)S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@82!S970@
M;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@5&AE(&]L9"!U<V5R260N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N97=)1"`@("`@("!4:&4@;F5W('5S97))
M9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!N97<@
M8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&55<V5R*"1O;&1)1"P@)&YE
M=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8F%C:V5N9"T^=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E
M;G1I86QS*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@55))
M(&]F('1H92!L;V=I;B!S8W)E96X@9F]R('1H:7,@875T:&5N=&EC871I;VX@
M;65T:&]D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE
M(&%P<&QI8V%T:6]N('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)'5R
M;"`@5&AE(%523"!T;R!R961I<F5C="!T;R!A9G1E<B!L;V=I;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&QO9VEN('-C<F5E;B!54DDN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971,;V=I;E-C<F5E;B@D87!P(#T@
M)VAO<F1E)RP@)'5R;"`]("<G*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V)A8VME;F0M/E]G971,;V=I;E-C<F5E;B@D87!P+"`D=7)L*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A('5S97))9"!E>&ES=',@
M:6X@=&AE('-I<W1E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T('1H92!U<V5R260@86QR96%D>2!E>&ES=',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D=7-E<DED*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V)A8VME;F0M/F5X:7-T<R@D=7-E<DED*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($%U=&]M871I8R!A=71H96YT:6-A=&EO
M;CH@1FEN9"!O=70@:68@=&AE(&-L:65N="!M871C:&5S(&%N(&%L;&]W960@
M25`*("`@("`J(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?8F%C:V5N9"T^=')A;G-P87)E;G0H*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T%U=&@O9G1P+G!H<```````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-#(Q-P`Q,#0Q-S,V,C<W,0`P,C`T,S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!!=71H7V9T<"!C;&%S<R!P<F]V:61E<R!A;B!&5%`@:6UP
M;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y
M<W1E;2X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=H
M;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S(&]F('1H92!&
M5%`@<V5R=F5R+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("=L;V-A;&AO
M<W0G"B`J("`@)W!O<G0G("`@("`@5&AE('-E<G9E<B!P;W)T('1O(&-O;FYE
M8W0@=&\N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@,C$\+W!R93X*("H*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`L=B`Q
M+C(S+C$R+C@@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!-87@@2V%L:6MA(#QM
M87A`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($UA
M>"!+86QI:V$@/&UA>$!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N
M,PH@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7V9T<"!E
M>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!&5%`@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T
M:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?9G1P
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ
M97AT96YS:6]N17AI<W1S*"=F='`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH7R@B075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I
M=&-H+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@)&1E9F%U;'1?<&%R86US(#T@87)R87DH"B`@("`@("`@("`@("=H;W-T
M<W!E8R<@/3X@)VQO8V%L:&]S="<L"B`@("`@("`@("`@("=P;W)T)R`]/B`R
M,0H@("`@("`@("D["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M
M97)G92@D9&5F875L=%]P87)A;7,L("1P87)A;7,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA
M;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U
M<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I
M86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@1F]R($944"P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@;75S="!C
M;VYT86EN(&$@<&%S<W=O<F0@96YT<GDN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E
M('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U
M<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("`D9G1P(#T@0&9T
M<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+"`D=&AI<RT^
M7W!A<F%M<ULG<&]R="==*3L*"B`@("`@("`@:68@*"1F='`@)B8@0&9T<%]L
M;V=I;B@D9G1P+"`D=7-E<DED+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI
M*2!["B`@("`@("`@("`@($!F='!?<75I="@D9G1P*3L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&9T
M<%]Q=6ET*"1F='`I.PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O
M<BA!551(7U)%05-/3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'``````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C$P-P`Q,#0Q-S,V,C<W
M,0`P,C`V,C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7VAT='`@8VQA<W,@=')A;G-P
M87)E;G1L>2!L;V=S('5S97)S(&EN('1O($AO<F1E('5S:6YG"B`J(&%L<F5A
M9'D@<')E<V5N="!(5%10(&%U=&AE;G1I8V%T:6]N(&AE861E<G,N"B`J"B`J
M(%1H92`G96YC<GEP=&EO;B<@<&%R86UE=&5R('-P96-I9FEE<R!W:&%T(&MI
M;F0@;V8@<&%S<W=O<F1S(&%R92!I;@H@*B!T:&4@+FAT<&%S<W=D(&9I;&4N
M(%1H92!S=7!P;W)T960@;W!T:6]N<R!A<F4@)V-R>7!T+61E<R<@*'-T86YD
M87)D"B`J(&-R>7!T960@:'1P87-S=V0@96YT<FEE<RD@86YD("=A<')M9#4G
M+B!4:&ES(&EN9F]R;6%T:6]N(&ES('5S960@:68*("H@>6]U('=A;G0@=&\@
M9&ER96-T;'D@875T:&5N=&EC871E('5S97)S('=I=&@@=&AI<R!D<FEV97(L
M(&EN<W1E860*("H@;V8@<F5L>6EN9R!O;B!T<F%N<W!A<F5N="!A=71H+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`L=B`Q
M+C(Q+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]H='1P
M(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C
M87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H
M:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I
M="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A
M=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS
M<&%R96YT)R`@(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@
M=7-E<FYA;65S(&%N9"!H87-H960@<&%S<W=O<F1S+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=7-E<G,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!(5%10(&%U=&AE
M;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@075T:%]H='1P*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*"B`@("`@
M("`@+R\@1&5F875L="!T;R!$15,@<&%S<W=O<F1S+@H@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==(#T@)V-R>7!T+61E
M<R<["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=H='!A<W-W9%]F:6QE)UTI*2!["B`@("`@("`@("`@("1U<V5R<R`]
M($!F:6QE*"1T:&ES+3Y?<&%R86US6R=H='!A<W-W9%]F:6QE)UTI.PH@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)'5S97)S*2D@>PH@("`@("`@("`@("`@
M("`@+R\@16YA8FQE('1H92!L:7-T('5S97)S(&-A<&%B:6QI='DN"B`@("`@
M("`@("`@("`@("`D=&AI<RT^8V%P86)I;&ET:65S6R=L:7-T)UT@/2!T<G5E
M.PH*("`@("`@("`@("`@("`@("\O(%!U="!U<V5R<R!I;G1O(&%L<&AA8F5T
M:6-A;"!O<F1E<BX*("`@("`@("`@("`@("`@('-O<G0H)'5S97)S*3L*"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=7-E<G,@87,@)&QI;F4I('L*("`@
M("`@("`@("`@("`@("`@("!L:7-T*"1U<V5R+"`D<&%S<RD@/2!E>'!L;V1E
M*"<Z)RP@)&QI;F4L(#(I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=7-E<G-;=')I;2@D=7-E<BE=(#T@=')I;2@D<&%S<RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L
M<R!A<F4@=F%L:60N($]N;'D@<W5P<&]R=',*("`@("`J(&AT<&%S<W=D(&9I
M;&5S('=I=&@@1$53('!A<W-W;W)D<R!R:6=H="!N;W<N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`
M<&%R86T@87)R87D@("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@
M8W)E9&5N=&EA;',N($9O<B!)34%0+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1H:7,@;75S="!C;VYT86EN(&$@<&%S<W=O<F0@96YT
M<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R
M(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*
M("`@('L*("`@("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R
M9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(BDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]U<V5R<ULD=7-E<DED72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]S971!=71H17)R;W(H05542%]214%33TY?0D%$3$]'24XI.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D:&%S:"`]
M("1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)&-R961E;G1I86QS6R=P87-S
M=V]R9"==+"`D=&AI<RT^7W5S97)S6R1U<V5R261=+"`D=&AI<RT^7W!A<F%M
M<ULG96YC<GEP=&EO;B==+"`A96UP='DH)'1H:7,M/E]P87)A;7-;)W-H;W=?
M96YC<GEP=&EO;B==*2D["B`@("`@("`@:68@*"1H87-H(#T]("1T:&ES+3Y?
M=7-E<G-;)'5S97))9%TI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R
M;W(H05542%]214%33TY?0D%$3$]'24XI.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!54DD@;V8@=&AE(&QO9VEN('-C<F5E;B!F;W(@=&AI<R!A=71H96YT
M:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC
M871I;VX@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("!4:&4@
M55),('1O(')E9&ER96-T('1O(&%F=&5R(&QO9VEN+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@;&]G:6X@<V-R965N(%5222X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=$QO9VEN4V-R965N*"1A<'`@/2`G:&]R9&4G
M+"`D=7)L(#T@)R<I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7W!A<F%M<ULG;&]G:6Y38W)E96XG72DI('L*("`@("`@("`@("`@:68@*"1U
M<FPI('L*("`@("`@("`@("`@("`@(')E='5R;B!5=&EL.CIA9&1087)A;65T
M97(H)'1H:7,M/E]P87)A;7-;)VQO9VEN4V-R965N)UTL("=U<FPG+"`D=7)L
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!A<F%M<ULG;&]G:6Y38W)E96XG73L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!P87)E;G0Z
M.E]G971,;V=I;E-C<F5E;B@D87!P+"`D=7)L*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T:&4@<WES=&5M
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!U
M<V5R261S+"!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&%R<F%Y7VME>7,H)'1H:7,M/E]U<V5R<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!=71O;6%T:6,@875T:&5N=&EC871I;VXZ($9I;F0@;W5T
M(&EF('1H92!C;&EE;G0@:&%S($A45%`*("`@("`J(&%U=&AE;G1I8V%T:6]N
M(&EN9F\@<')E<V5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T('1H92!C;&EE;G0@:7,@86QL;W=E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=')A;G-P87)E;G0H*0H@("`@>PH@("`@("`@(&EF
M("@A96UP='DH)%]315)615);)U!(4%]!551(7U5315(G72D@)B8*("`@("`@
M("`@("`@(65M<'1Y*"1?4T525D526R=02%!?05542%]05R==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T075T:"A5=&EL.CID:7-P96Q-86=I8U%U;W1E
M<R@D7U-%4E9%4ELG4$A07T%55$A?55-%4B==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W!A<W-W;W)D)R`]/B!5=&EL.CID:7-P96Q-
M86=I8U%U;W1E<R@D7U-%4E9%4ELG4$A07T%55$A?4%<G72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@/3X@,2DI
M.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(I*3L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T%U=&@O:6UA<"YP:'``````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,S8W-P`Q,#0Q-S,V,C<W,0`P,C`V,#8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!!=71H7VEM87`Z.B!C;&%S<R!P<F]V:61E<R!A;B!)34%0(&EM<&QE;65N
M=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96TN
M"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("=F;VQD97(G
M("`@("`@("`@(%1H92!I;FET:6%L(&9O;&1E<B`O(&UA:6QB;W@@=&\@;W!E
M;BX*("H@("`@("`@("`@("`@("`@("`@(%-H;W5L9"!B92!N=6QL(&9O<B`G
M:6UA<"<@86YD("=N;G1P)R!P<F]T;V-O;',N"B`J("`@("`@("`@("`@("`@
M("`@("!$149!54Q4.B!N=6QL"B`J("`G:&]S='-P96,G("`@("`@("!4:&4@
M:&]S=&YA;64@;W(@25`@861D<F5S<R!O9B!T:&4@<V5R=F5R+@H@*B`@("`@
M("`@("`@("`@("`@("`@1$5&055,5#H@)VQO8V%L:&]S="<*("H@("=P;W)T
M)R`@("`@("`@("`@(%1H92!S97)V97(@<&]R="!T;R!W:&EC:"!W92!W:6QL
M(&-O;FYE8W0N"B`J("`@("`@("`@("`@("`@("`@("!)34%0(&ES(&=E;F5R
M86QL>2`Q-#,L('=H:6QE($E-05`M4U-,(&ES(&=E;F5R86QL>2`Y.3,N"B`J
M("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`Q-#,*("H@("=P<F]T;V-O
M;"<@("`@("`@(%1H92!C;VYN96-T:6]N('!R;W1O8V]L("AE+F<N("=I;6%P
M)RP@)W!O<#,G+"`G;FYT<"<I+@H@*B`@("`@("`@("`@("`@("`@("`@4')O
M=&]C;VP@:7,@;VYE(&]F("=I;6%P+VYO=&QS)R`H;W(@;VYL>2`G:6UA<"<@
M:68@>6]U"B`J("`@("`@("`@("`@("`@("`@("!H879E(&$@8RUC;&EE;G0@
M=F5R<VEO;B`R,#`P8R!O<B!O;&1E<BDL("=I;6%P+W-S;"<L"B`J("`@("`@
M("`@("`@("`@("`@("!O<B`G:6UA<"]S<VPO;F]V86QI9&%T92UC97)T)R`H
M9F]R(&$@<V5L9BUS:6=N960*("H@("`@("`@("`@("`@("`@("`@(&-E<G1I
M9FEC871E*2X*("H@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=I;6%P
M)PH@*B`@)V%D;6EN7W5S97(G("`@("`@5&AE(&YA;64@;V8@82!U<V5R('=I
M=&@@861M:6X@<')I=FEL96=E<RX*("H@("`@("`@("`@("`@("`@("`@($1%
M1D%53%0Z(&YU;&P*("H@("=A9&UI;E]P87-S=V]R9"<@(%1H92!P87-S=V]R
M9"!O9B!T:&4@861M:6YS=')A=&]R+@H@*B`@("`@("`@("`@("`@("`@("`@
M1$5&055,5#H@;G5L;`H@*B`@)W5S97)H:65R87)C:'DG("`@5&AE(&AI97)A
M<F-H>2!W:&5R92!U<V5R(&UA:6QB;WAE<R!A<F4@<W1O<F5D+@H@*B`@("`@
M("`@("`@("`@("`@("`@1$5&055,5#H@)W5S97(N)PH@*B`@)V1S;B<@("`@
M("`@("`@("`@5&AE(&9U;&P@24U!4"!C;VYN96-T:6]N('-T<FEN9RX*("H@
M("`@("`@("`@("`@("`@("`@($EF(&YO="!P<F5S96YT+"!T:&ES(&ES(&)U
M:6QT(&9R;VT@)VAO<W1S<&5C)RP@)W!O<G0G"B`J("`@("`@("`@("`@("`@
M("`@("!A;F0@)W!R;W1O8V]L)R!P87)A;65T97)S+CPO<')E/@H@*@H@*@H@
M*B!)9B!S971T:6YG('5P(&%S($AO<F1E(&%U=&@@:&%N9&QE<B!I;B!C;VYF
M+G!H<"P@=&AI<R!I<R!A('-A;7!L92!E;G1R>3H\<')E/@H@*B`@("1C;VYF
M6R=A=71H)UU;)W!A<F%M<R==6R=F;VQD97(G72`]("=)3D)/6"<["B`J("`@
M)&-O;F9;)V%U=&@G75LG<&%R86US)UU;)VAO<W1S<&5C)UT@/2`G:6UA<"YE
M>&%M<&QE+F-O;2<["B`J("`@)&-O;F9;)V%U=&@G75LG<&%R86US)UU;)W!O
M<G0G72`](#$T,SL*("H@("`D8V]N9ELG875T:"==6R=P87)A;7,G75LG<')O
M=&]C;VPG72`]("=I;6%P+VYO=&QS+VYO=F%L:61A=&4M8V5R="<[/"]P<F4^
M"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H
M<"QV(#$N,C@N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($=A=61E;GH@
M4W1E:6YL:6X@/&=A=61E;GHN<W1E:6YL:6Y`:60N=6YI8F4N8V@^"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!'875D96YZ(%-T96EN
M;&EN(#QG875D96YZ+G-T96EN;&EN0&ED+G5N:6)E+F-H/@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T
M:%]I;6%P(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1S(&$@;F5W($E-05`@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($%U=&A?:6UA<"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I
M9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G:6UA<"<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"A?*")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@("1D969A=6QT7W!A<F%M<R`](&%R<F%Y*`H@
M("`@("`@("`@("`G9F]L9&5R)R`]/B!N=6QL+`H@("`@("`@("`@("`G:&]S
M='-P96,G(#T^("=L;V-A;&AO<W0G+`H@("`@("`@("`@("`G<&]R="<@/3X@
M)S$T,R<L"B`@("`@("`@("`@("=P<F]T;V-O;"<@/3X@)VEM87`G+`H@("`@
M("`@("`@("`G=7-E<FAI97)A<F-H>2<@/3X@)W5S97(N)PH@("`@("`@("D[
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M97)G92@D9&5F875L
M=%]P87)A;7,L("1P87)A;7,I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?<&%R86US6R=A9&UI;E]U<V5R)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3YC87!A8FEL:71I97-;)V%D9"==(#T@=')U93L*("`@("`@("`@("`@)'1H
M:7,M/F-A<&%B:6QI=&EE<ULG<F5M;W9E)UT@/2!T<G5E.PH@("`@("`@("`@
M("`D=&AI<RT^8V%P86)I;&ET:65S6R=L:7-T)UT@/2!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0W)E871E($133B!S=')I;F<N("HO"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG9'-N)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=D<VXG72`]('-P<FEN=&8H)WLE<SHE9"\E
M<WTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=P;W)T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UTI.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=F;VQD97(G72DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D<VXG72`N/2`D=&AI
M<RT^7W!A<F%M<ULG9F]L9&5R)UT["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L
M;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E
M<DED("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A
M<G)A>2`D8W)E9&5N=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I
M86QS+B!&;W(@24U!4"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H:7,@;75S="!C;VYT86EN(&$@<&%S<W=O<F0@96YT<GDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@
M8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN(BDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D:6UA<"`]($!I;6%P7V]P96XH
M)'1H:7,M/E]P87)A;7-;)V1S;B==+"`D=7-E<DED+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL($]07TA!
M3$9/4$5.*3L*"B`@("`@("`@:68@*"1I;6%P*2!["B`@("`@("`@("`@($!I
M;6%P7V-L;W-E*"1I;6%P*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R
M;W(H05542%]214%33TY?0D%$3$]'24XI.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@
M<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@("!4:&4@=7-E<DED('1O
M(&%D9"X*("`@("`J($!P87)A;2!A<G)A>2`@)&-R961E;G1I86QS("!4:&4@
M8W)E9&5N=&EA;',@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S97))
M9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O24U!4"]!9&UI;BYP:'`G.PH@("`@("`@("1I;6%P(#T@)FYE=R!)
M34%07T%D;6EN*"1T:&ES+3Y?<&%R86US*3L*("`@("`@("!R971U<FX@)&EM
M87`M/F%D9$UA:6QB;W@H4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=7-E<DED
M+"!.3%,Z.F=E=$-H87)S970H*2P@)W5T9C<M:6UA<"<I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E;&5T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C
M<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M260@(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S
M97(H)'5S97))9"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+TE-05`O061M:6XN<&AP)SL*("`@("`@("`D:6UA<"`]("9N97<@24U!4%]!
M9&UI;B@D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@)')E<W5L="`]("1I;6%P
M+3YR96UO=F5-86EL8F]X*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'5S97))
M9"P@3DQ3.CIG971#:&%R<V5T*"DL("=U=&8W+6EM87`G*2D["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TE-05`O061M:6XN<&AP)SL*("`@("`@("`D:6UA<"`]("9N
M97<@24U!4%]!9&UI;B@D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@<F5T=7)N
M("1I;6%P+3YL:7-T36%I;&)O>&5S*"D["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M075T:"]I;7-P+G!H<```````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`U-#4V`#$P-#$W,S8R-S<Q`#`R,#8R-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($%U
M=&A?:6US<"!C;&%S<R!P<F]V:61E<R!B87-I8R!A=71H96YT:6-A=&EO;B!A
M9V%I;G-T(&%N($E-4U`@<V5R=F5R+@H@*B!4:&ES('=I;&P@8F4@;6]S="!B
M96YI9FEC:6%L(&EF(&%L<F5A9'D@=7-I;F<@86X@24U34"!B87-E9"!P<F5F
M97)E;F-E"B`J('-Y<W1E;2!O<B!)35-0(&)A<V5D(&%D9')E<W-B;V]K('-Y
M<W1E;0H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6US<"YP
M:'`L=B`Q+C(N,3`N,3`@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM
M<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P
M86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?:6US<"!E>'1E;F1S
M($%U=&A["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I
M97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@
M*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C
M87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@
M("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@
M(#T^(&9A;'-E*3L*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(@9G5N8W1I
M;VXN($-R96%T97,@;F5W($%U=&A?:6US<"!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@02!H87-H(&-O;G1A:6YI;F<@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]I;7-P*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T4&%R86US
M*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4')I=F%T92!A=71H
M96YT:6-A=&EO;B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R240@57-E
M<FYA;64@9F]R($E-4U`@<V5R=F5R+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C
M<F5D96YT:6%L<R!(87-H(&-O;G1A:6YI;F<@)W!A<W-W;W)D)R!E;&5M96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B!4<G5E(&]N('-U8V-E
M<W,@+R!&86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M875T:&5N=&EC871E*"1U<V5R240L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("!R97%U:7)E7V]N8V4@)TYE="])35-0+T%U=&@N<&AP)SL*"B`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@/2`D=7-E<DE$.PH@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==(#T@)&-R961E;G1I86QS
M6R=P87-S=V]R9"==.PH@("`@("`@("1I;7-P(#T@)DYE=%])35-07T%U=&@Z
M.G-I;F=L971O;B@D=&AI<RT^7W!A<F%M<ULG875T:%]M971H;V0G72D["@H@
M("`@("`@(&EF("AI<U]A*"1I;7-P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D:6US<#L*("`@("`@("!]"@H@("`@("`@("1R97-U
M;'0@/2`D:6US<"T^875T:&5N=&EC871E*"1T:&ES+3Y?<&%R86US+"!F86QS
M92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/
M3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&AE('!A<F%M<R!A<G)A
M>2!A;F0@<V5T<R!D969A=6QT('9A;'5E<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US($AA<V@@
M8V]N=&%I;FEN9R!)35-0('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S971087)A;7,H)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG<V5R=F5R)UT@/2`D<&%R86US6R=S97)V97(G73L*("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG<&]R="==(#T@)'!A<F%M<ULG<&]R="==.PH@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=A=71H7VUE=&AO9"==(#T@)'!A<F%M
M<ULG875T:%]M971H;V0G73L*"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;
M)V%U=&A?;65C:&%N:7-M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=A=71H7VUE8VAA;FES;2==(#T@)'!A<F%M<ULG875T:%]M96-H86YI
M<VTG73L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-O8VME="==(#T@
M)'!A<F%M<ULG<V]C:V5T)UT["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=C;VUM86YD)UT@/2`D<&%R86US6R=C;VUM86YD)UT["B`@("`@("`@?0H@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8W,C8`,3`T,3<S
M-C(W-S$`,#(Q,C8W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]I<&)A<VEC(&-L87-S
M('!R;W9I9&5S(&%C8V5S<R!C;VYT<F]L(&)A<V5D(&]N($-)1%(@;6%S:W,*
M("H@*&-L:65N="!)4"!A9&1R97-S97,I+B!)="!I<R!N;W0@;65A;G0@9F]R
M('5S97(M8F%S960@<WES=&5M<RP@8G5T"B`J(&9O<B!T:6UE<R!W:&5N('EO
M=2!W86YT(&$@8FQO8VL@;V8@25!S('1O(&)E(&%B;&4@=&\@86-C97-S(&$@
M<VET92P*("H@86YD('1H870@86-C97-S(&ES('-I;7!L>2!O;B]O9F8@+2!N
M;R!P<F5F97)E;F-E<RP@971C+B!)9B!Y;W4@;F5E9`H@*B!M;W)E('-O<&AI
M<W1I8V%T960@25`M8F%S960@875T:&5N=&EC871I;VXL('EO=2!S:&]U;&0@
M;&]O:R!A="!T:&4*("H@075T:%]I<&UA<"!C;&%S<R!W:&EC:"!L971S('EO
M=2!M87`@25`@8FQO8VMS('1O('-P96-I9FEC"B`J('5S97)N86UE<RX*("H*
M("H@4&%R86UE=&5R<SH*("H@("`G8FQO8VMS)R`@("`@06X@87)R87D@;V8@
M0TE$4B!M87-K<R!W:&EC:"!A<F4@86QL;W=E9"!A8V-E<W,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<"QV(#$N,C`N
M,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VEP8F%S:6,@
M97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A
M<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI
M8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET
M(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T
M92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P
M87)E;G0G("`@/3X@=')U92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@;F5W($)A<VEC($E0(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI
M;F<@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]I<&)A
M<VEC*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<V5T4&%R86US*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('!A<F%M971E<G,@9F]R('1H92!!=71H7VEP8F%S:6,@;V)J96-T+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!3:&]U;&0@8V]N=&%I;B`G8FQO8VMS)RP@86X@
M87)R87D@;V8@0TE$4B!M87-K<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M=%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<&%R
M86US6R=B;&]C:W,G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG8FQO8VMS
M)UT@/2!A<G)A>2@I.PH@("`@("`@('T@96QS96EF("@A:7-?87)R87DH)'!A
M<F%M<ULG8FQO8VMS)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)V)L;V-K
M<R==(#T@87)R87DH)'!A<F%M<ULG8FQO8VMS)UTI.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J
M*@H@("`@("H@075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N.B!&:6YD(&]U="!I
M9B!T:&4@8VQI96YT(&UA=&-H97,@86X@86QL;W=E9"!)4`H@("`@("H@8FQO
M8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R
M(&YO="!T:&4@8VQI96YT(&ES(&%L;&]W960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1R86YS<&%R96YT*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1?
M4T525D526R=214U/5$5?041$4B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?*"))4"!!9&1R
M97-S(&YO="!A=F%I;&%B;&4N(BDI.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D8VQI96YT(#T@)%]315)615);)U)%
M34]415]!1$12)UT["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;
M)V)L;V-K<R==(&%S("1C:61R*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V%D9')E<W-7:71H:6Y#2412*"1C;&EE;G0L("1C:61R*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$%U=&@H)&-I9'(L(&%R<F%Y*"=T<F%N<W!A
M<F5N="<@/3X@,2DI.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<V5T075T
M:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H(DE0($%D9')E<W,@;F]T
M('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(BDI.PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!I9B!A
M;B!)4"!A9&1R97-S(&ES('=I=&AI;B!A($-)1%(@8FQO8VLN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D861D<F5S<R`@5&AE($E0(&%D9')E<W,@=&\@8VAE8VLN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C:61R("`@("!4:&4@8FQO8VL@*&4N9RX@,3DR
M+C$V."XP+C`O,38I('1O('1E<W0@86=A:6YS="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!A9&1R97-S(&UA
M=&-H97,@=&AE(&UA<VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1R97-S
M5VET:&EN0TE$4B@D861D<F5S<RP@)&-I9'(I"B`@("!["B`@("`@("`@)&%D
M9')E<W,@/2!I<#)L;VYG*"1A9&1R97-S*3L*("`@("`@("!L:7-T*"1Q=6%D
M+"`D8FET<RD@/2!E>'!L;V1E*"<O)RP@)&-I9'(I.PH@("`@("`@("1B:71S
M(#T@:6YT=F%L*"1B:71S*3L*("`@("`@("`D<75A9"`](&EP,FQO;F<H)'%U
M860I.PH*("`@("`@("!R971U<FX@*"@D861D<F5S<R`^/B`H,S(@+2`D8FET
M<RDI(#T]("@D<75A9"`^/B`H,S(@+2`D8FET<RDI*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]I<&UA<"YP:'``
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#4T`#$P-#$W
M,S8R-S<Q`#`R,#<U-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]I<&)A<VEC+G!H<"<["@HO*BH*("H@5&AE($%U=&A?:7!M87`@
M8VQA<W,@<')O=FED97,@86-C97-S(&-O;G1R;VP@8F%S960@;VX@0TE$4B!M
M87-K<RX*("H*("H@4&%R86UE=&5R<SH*("H@("!.3TY%"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T%U=&@O075T:"]I<&UA<"YP:'`L=B`Q+C$T+C$P+C8@
M,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]I<&UA<"!E>'1E;F1S
M($%U=&A?:7!B87-I8R!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C
M87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H
M:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I
M="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A
M=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS
M<&%R96YT)R`@(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M<R!A(&YE=R!)4"UM87!P:6YG(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A
M:6YI;F<@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]I
M<&UA<"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^
M7W-E=%!A<F%M<R@D<&%R86US*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]!=71H+VMO;&%B+G!H<```````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#<Q,#,`,3`T,3<S-C(W-S$`,#(P-S,S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)TAO<F1E+T%U=&@O:6UA<"YP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+TAI<W1O<GDN<&AP)SL*"B\J*@H@*B!+;VQA8B!I;7!L96UE;G1A
M=&EO;B!O9B!T:&4@2&]R9&4@875T:&5N=&EC871I;VX@<WES=&5M+B!$97)I
M=F5S(&9R;VT@=&AE"B`J($%U=&A?:6UA<"!)34%0(&%U=&AE;G1I8V%T:6]N
M(&]B:F5C="P@86YD('-I;7!L>2!P<F]V:61E<R!P87)A;65T97)S('1O(&ET
M"B`J(&)A<V5D(&]N('1H92!G;&]B86P@2V]L86(@8V]N9FEG=7)A=&EO;BX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<"QV
M(#$N,2XQ,"XX(#(P,#8O,#,O,#,@,C,Z,#`Z,C@@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!3='5A<G0@0FEN9V4@/',N8FEN9V5`
M8V]D969U<VEO;BYC;RYZ83X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M(%-T=6%R="!":6YG92`\<RYB:6YG94!C;V1E9G5S:6]N+F-O+GIA/@H@*B!`
M<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*
M8VQA<W,@075T:%]K;VQA8B!E>'1E;F1S($%U=&A?:6UA<"!["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($MO;&%B(&%U=&AE;G1I8V%T:6]N
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!!=71H7VMO;&%B*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1P87)A;7-;)VAO<W1S<&5C)UT@/2`D1TQ/0D%,
M4ULG8V]N9B==6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==.PH@("`@("`@
M("1P87)A;7-;)W!O<G0G72`]("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;
M)VEM87`G75LG<&]R="==.PH@("`@("`@("1P87)A;7-;)W!R;W1O8V]L)UT@
M/2`G:6UA<"]N;W1L<R]N;W9A;&ED871E+6-E<G0G.PH*("`@("`@("!P87)E
M;G0Z.D%U=&A?:6UA<"@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V
M86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O
M(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@
M87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N($9O<B!+;VQA8BP*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@;75S="!C;VYT86EN
M(&$@<&%S<W=O<F0@96YT<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L
M("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@
M("`@("`@("1L;V=I;E]O:R`]('!A<F5N=#HZ7V%U=&AE;G1I8V%T92@D=7-E
M<DED+"`D8W)E9&5N=&EA;',I.PH*("`@("`@("!I9B`H)&-O;F9;)V%U=&@G
M75LG<&%R86US)UU;)VQO9VEN7V)L;V-K)UT@(3T@,2D@>PH@("`@("`@("`@
M("`O+R!2971U<FX@:68@9F5A='5R92!I<R!D:7-A8FQE9"X*("`@("`@("`@
M("`@<F5T=7)N("1L;V=I;E]O:SL*("`@("`@("!]"@H@("`@("`@("1H:7-T
M;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH*("`@("`@("`D
M:&ES=&]R>5]I9&5N=&EF:65R(#T@(B1U<V5R261`;&]G:6YS+FMO;&%B(CL*
M("`@("`@("`D:&ES=&]R>5]L;V<@/2`D:&ES=&]R>2T^9V5T2&ES=&]R>2@D
M:&ES=&]R>5]I9&5N=&EF:65R*3L*("`@("`@("`D:&ES=&]R>5]L:7-T(#T@
M87)R87DH*3L*"B`@("`@("`@+R\@17AT<F%C="!H:7-T;W)Y(&QI<W0@9G)O
M;2!L;V<N"B`@("`@("`@:68@*"1H:7-T;W)Y7VQO9R`F)B`A:7-?82@D:&ES
M=&]R>5]L;V<L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&1A=&$@
M/2`D:&ES=&]R>5]L;V<M/F=E=$1A=&$H*3L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D9&%T82DI('L*("`@("`@("`@("`@("`@("1E;G1R>2`](&%R<F%Y
M7W-H:69T*"1D871A*3L*("`@("`@("`@("`@("`@("1H:7-T;W)Y7VQI<W0@
M/2`D96YT<GE;)VAI<W1O<GE?;&ES="==.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!#86QC=6QA=&4@=&AE('1I;64@<F%N9V4N"B`@
M("`@("`@)'-T87)T7W1I;64@/2`H=&EM92@I("T@)&-O;F9;)V%U=&@G75LG
M<&%R86US)UU;)VQO9VEN7V)L;V-K7W1I;64G72`J(#8P*3L*"B`@("`@("`@
M)&YE=U]H:7-T;W)Y7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("1C;W5N="`]
M(#`["@H@("`@("`@("\O($-O<'D@86YD(&-O=6YT(&%L;"!R96QE=F%N="!T
M:6UE<W1A;7!S+@H@("`@("`@(&9O<F5A8V@@*"1H:7-T;W)Y7VQI<W0@87,@
M)&5N=')Y*2!["B`@("`@("`@("`@("1T:6UE<W1A;7`@/2`D96YT<GE;("=T
M:6UE<W1A;7`G(%T["@H@("`@("`@("`@("!I9B`H)'1I;65S=&%M<"`^("1S
M=&%R=%]T:6UE*2!["B`@("`@("`@("`@("`@("`D;F5W7VAI<W1O<GE?;&ES
M=%M=(#T@)&5N=')Y.PH@("`@("`@("`@("`@("`@)&-O=6YT*RL["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1M87A?8V]U;G0@/2`D8V]N
M9ELG875T:"==6R=P87)A;7,G75LG;&]G:6Y?8FQO8VM?8V]U;G0G73L*"B`@
M("`@("`@:68@*"1C;W5N="`^("1M87A?8V]U;G0@?'P@(21L;V=I;E]O:RD@
M>PH@("`@("`@("`@("`O+R!!9&0@96YT<GD@9F]R(&-U<G)E;G0@9F%I;&5D
M(&QO9VEN+@H@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D96YT<GE;("=T:6UE<W1A;7`G(%T@/2!T:6UE*"D["B`@("`@("`@
M("`@("1N97=?:&ES=&]R>5]L:7-T6UT@/2`D96YT<GD["@H@("`@("`@("`@
M("`O+R!7<FET92!B86-K(&AI<W1O<GDN"B`@("`@("`@("`@("1H:7-T;W)Y
M+3YL;V<H)&AI<W1O<GE?:61E;G1I9FEE<BP@87)R87DH)V%C=&EO;B<@/3X@
M)V%D9"<L("=W:&\G(#T^("1U<V5R260L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAI<W1O<GE?;&ES
M="<@/3X@)&YE=U]H:7-T;W)Y7VQI<W0I+"!T<G5E*3L*"B`@("`@("`@("`@
M(&EF("@D8V]U;G0@/B`D;6%X7V-O=6YT*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?*")4
M;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E
M<RXB*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)3BD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;&]G:6Y?;VL["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VMR8C4N<&AP````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4W,C<`,3`T,3<S-C(W
M-S$`,#(P-3(P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]K<F(U(&-L87-S('!R;W9I
M9&5S(&%N(&ME<F)E<F]S(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@
M*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J(%1H:7,@9')I=F5R(')E
M<75I<F5S('1H92`G:W)B-2<@4$A0(&5X=&5N<VEO;B!T;R!B92!L;V%D960N
M"B`J(%1H92!M;V1U;&4@8V%N(&)E(&1O=VYL;V%D960@:&5R93H*("H@("!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]D;W=N;&]A9"]P:'`O<&AP:W)B-2YT87(N
M9WH*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@($YO;F4N
M/"]P<F4^"B`J"B`J($EN<W1E860L($ME<F)E<F]S(&UU<W0@8F4@8V]R<F5C
M=&QY(&-O;F9I9W5R960@;VX@>6]U<B!S>7-T96T@*&4N9RX*("H@("`O971C
M+VMR8C4N8V]N9BD@9F]R('1H:7,@8VQA<W,@=&\@=V]R:R!C;W)R96-T;'DN
M"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<"QV(#$N,C$N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E
M($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?:W)B-2!E>'1E;F1S($%U=&@@
M>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S
M;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E
M<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I
M;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A
M<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F
M86QS92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO
M;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VMR8C4H
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE
M>'1E;G-I;VY%>&ES=',H)VMR8C4G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH7R@B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT
M:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE
M('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N
M=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I86QS+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1F]R(&ME<F)E<F]S+"!T:&ES
M(&UU<W0@8V]N=&%I;B!A('!A<W-W;W)D"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L
M:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))
M9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D8W)E
M9&5N=&EA;'-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF
M871A;"A?*").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("`D<F5S=6QT(#T@:W)B-5]L;V=I;B@D=7-E<DED+"`D8W)E
M9&5N=&EA;'-;)W!A<W-W;W)D)UTI.PH*("`@("`@("!I9B`H)')E<W5L="`]
M/3T@2U)"-5]/2RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)')E<W5L="`]/3T@2U)"-5]"
M041?4$%34U=/4D0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T
M:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H(D)A9"!K97)B97)O<R!P
M87-S=V]R9"XB*2D["B`@("`@("`@("`@('T@96QS96EF("@D<F5S=6QT(#T]
M/2!+4D(U7T)!1%]54T52*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E
M=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?*")"860@:V5R8F5R
M;W,@=7-E<FYA;64N(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?3453
M4T%'12P@7R@B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'``````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`T-C8P,``Q,#0Q-S,V,C<W,0`P,C`U-S``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!!=71H7VQD87`@8VQA<W,@<')O=FED97,@86X@3$1!4"!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES
M=&5M+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V)A
M<V5D;B<@("`@("`@5&AE(&)A<V4@1$X@9F]R('1H92!,1$%0('-E<G9E<BX*
M("H@("`G:&]S='-P96,G("`@("!4:&4@:&]S=&YA;64@;V8@=&AE($Q$05`@
M<V5R=F5R+@H@*B`@("=U:60G("`@("`@("`@(%1H92!U<V5R;F%M92!S96%R
M8V@@:V5Y+@H@*B`@("=F:6QT97(G("`@("`@(%1H92!,1$%0(&9O<FUA='1E
M9"!S96%R8V@@9FEL=&5R('1O('-E87)C:"!F;W(@=7-E<G,N(%1H:7,*("H@
M("`@("`@("`@("`@("`@("!S971T:6YG(&]V97)R:61E<R!T:&4@)V]B:F5C
M=&-L87-S)R!M971H;V0@8F5L;W<N"B`J("`@)V]B:F5C=&-L87-S)R`@5&AE
M(&]B:F5C=&-L87-S(&9I;'1E<B!U<V5D('1O('-E87)C:"!F;W(@=7-E<G,N
M($-A;B!B92!A"B`J("`@("`@("`@("`@("`@("`@<VEN9VQE(&]B:F5C=&-L
M87-S(&]R(&%N(&%R<F%Y+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)V)I;F1D;B<@("`@("`@5&AE($1.('5S960@=&\@
M8FEN9"!T;R!T:&4@3$1!4"!S97)V97(*("H@("`G<&%S<W=O<F0G("`@("!4
M:&4@<&%S<W=O<F0@=7-E9"!T;R!B:6YD('1O('1H92!,1$%0('-E<G9E<@H@
M*B`@("=V97)S:6]N)R`@("`@(%1H92!V97)S:6]N(&]F('1H92!,1$%0('!R
M;W1O8V]L('1O('5S92X*("H@("`@("`@("`@("`@("`@("!$149!54Q4.B!.
M3TY%("AS>7-T96T@9&5F875L="!W:6QL(&)E('5S960I/"]P<F4^"B`J"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<"QV(#$N
M-#<N,3`N,38@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?;&1A<"!E>'1E;F1S($%U=&@@
M>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S
M;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E
M<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I
M;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^('1R=64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!T
M<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S
M=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R96UO=F4G("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@=')U92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E
M*3L*"B`@("`O*BH*("`@("`J($Q$05`@8V]N;F5C=&EO;B!H86YD;&4*("`@
M("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V1S
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,1$%0(&%U=&AE
M;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VQD87`H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%
M>&ES=',H)VQD87`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W-E=%!A<F%M<R@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!C;VYF:6=U<F%T:6]N('!A<F%M971E<G,*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4&%R86US*"1P87)A;7,I
M"B`@("!["B`@("`@("`@+RH@16YS=7)E('=E)W9E(&)E96X@<')O=FED960@
M=VET:"!A;&P@;V8@=&AE(&YE8V5S<V%R>2!P87)A;65T97)S+B`J+PH@("`@
M("`@($AO<F1E.CIA<W-E<G1$<FEV97)#;VYF:6<H)'!A<F%M<RP@)V%U=&@G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VAO
M<W1S<&5C)RP@)V)A<V5D;B<L("=U:60G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=A=71H96YT:6-A=&EO;B!,1$%0)RD["@H@("`@
M("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*
M("`@("`J($1O97,@86X@;&1A<"!C;VYN96-T(&%N9"!B:6YD<R!A<R!T:&4@
M9W5E<W0@=7-E<B!O<B!A<R!T:&4@;W!T:6]N86P@9&XN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&]R($9A;'-E(&)A<V5D(&]N('-U8V-E<W,@;V8@8V]N;F5C
M="!A;F0@8FEN9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J
M+PH@("`@("`@("1T:&ES+3Y?9',@/2!`;&1A<%]C;VYN96-T*"1T:&ES+3Y?
M<&%R86US6R=H;W-T<W!E8R==*3L*("`@("`@("!I9B`H(21T:&ES+3Y?9',I
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(BDI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI
M*2!["B`@("`@("`@("`@(&EF("@A;&1A<%]S971?;W!T:6]N*"1T:&ES+3Y?
M9',L($Q$05!?3U!47U!23U1/0T],7U9%4E-)3TXL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI
M*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@
M("`@("`@("`@("`@("!S<')I;G1F*"=3970@3$1!4"!P<F]T;V-O;"!V97)S
M:6]N('1O("5D(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D8V]N;BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1C;VYN*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RDI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P87)A;7-;)V)I;F1D;B==*2D@>PH@("`@("`@("`@("`D8FEN
M9"`]($!L9&%P7V)I;F0H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)I
M;F1D;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W!A<W-W;W)D)UTI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A)&)I;F0I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD('1H92!U<V5R(&1N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@=&\@9FEN9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5S97)S(&9U;&P@1$X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V9I;F1$3B@D=7-E<DED*0H@("`@>PH@("`@
M("`@("\J(%-E87)C:"!F;W(@=&AE('5S97(G<R!F=6QL($1.+B`J+PH@("`@
M("`@("1S96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)'1H:7,M
M/E]P87)A;7-;)V)A<V5D;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W5I9"==("X@)STG("X@)'5S97))9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?
M<&%R86US6R=U:60G72DI.PH@("`@("`@(&EF("@A)'-E87)C:"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L
M("1S96%R8V@I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D<F5S=6QT*2`F)B`H
M8V]U;G0H)')E<W5L="D@/B`Q*2D@>PH@("`@("`@("`@("`D9&X@/2`D<F5S
M=6QT6S!=6R=D;B==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(D5M<'1Y(')E<W5L="XB*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&1N.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0VAE8VMS(&9O<B!S:&%D;W=,87-T0VAA;F=E(&%N9"!S:&%D;W=-
M:6XO36%X('-U<'!O<G0@86YD(')E='5R;G,@=&AE:7(*("`@("`J('9A;'5E
M<RX*("`@("`J"B`@("`@*B!792!W:6QL(&%L<V\@8VAE8VL@9F]R('!W9$QA
M<W13970@=VAI8V@@:7,@=7-E9"!I;B!!8W1I=F4@1&ER96-T;W)Y"B`@("`@
M*@H@("`@("H@5V4@;F5E9"!T;R!B92!S=6-C97-S9G5L;'D@8F]U;F0@=&\@
M=&AE(&1I<F5C=&]R>0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1N
M("`@("!4:&4@9&X@;V8@=&AE('5S97(*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!A<G)A>2!W:71H(&ME>7,@8F5I;F<@(G-H861O=VQA<W1C:&%N
M9V4B+"`B<VAA9&]W;6EN(@H@("`@("H@("`@("`@("`@("`@("`@(G-H861O
M=VUA>"(L(")S:&%D;W=W87)N:6YG(B!A;F0@8V]N=&%I;FEN9R!T:&5I<@H@
M("`@("H@("`@("`@("`@("`@("`@<F5S<&5C=&EV92!V86QU97,@;W(@9F%L
M<V4@9F]R(&YO('-U<'!O<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L;V]K
M=7!3:&%D;W<H)&1N*0H@("`@>PH@("`@("`@("\J($EN:70@=&AE(')E='5R
M;B!A<G)A>2X@*B\*("`@("`@("`D;&]O:W5P<VAA9&]W(#T@87)R87DH)W-H
M861O=VQA<W1C:&%N9V4G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<VAA9&]W;6EN)R`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-H861O=VUA>"<@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S:&%D;W=W87)N:6YG)R`]/B!F
M86QS92D["@H*("`@("`@("`D<F5S=6QT(#T@0&QD87!?<F5A9"@D=&AI<RT^
M7V1S+"`D9&XL("=O8FIE8W1#;&%S<STJ)RD["@H@("`@("`@(&EF("@D<F5S
M=6QT*2!["B`@("`@("`@("`@("1I;F9O<FUA=&EO;B`]($!L9&%P7V=E=%]E
M;G1R:65S*"1T:&ES+3Y?9',L("1R97-U;'0I.PH*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?<&%R86US6R=A9"==*2!["B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&EN9F]R;6%T:6]N6S!=6R=P=V1L87-T<V5T)UU;,%TI*2!["B`@
M("`@("`@("`@("`@("`@("`@+RH@06-T:79E($1I<F5C=&]R>2!H86YD;&5S
M('1I;65S=&%M<',@82!B:70*("`@("`@("`@("`@("`@("`@("`@*B!D:69F
M97)E;G1L>2X@($-O;G9E<G0@=&AE('1I;65S=&%M<"!T;R!A(%5.25@*("`@
M("`@("`@("`@("`@("`@("`@*B!T:6UE<W1A;7`N("HO"B`@("`@("`@("`@
M("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W;&%S=&-H86YG92==(#T@
M9FQO;W(H*"@D:6YF;W)M871I;VY;,%U;)W!W9&QA<W1S970G75LP72`O(#$P
M,#`P,#`P*2`M(#$Q-C0T-#`V-S@S*2`O(#@V-#`P*2`M(#$["@H@("`@("`@
M("`@("`@("`@("`@("\J(%!A<W-W;W)D(&5X<&ER>2!A='1R:6)U=&5S(&%R
M92!I;B!A('!O;&EC>2X@5V4*("`@("`@("`@("`@("`@("`@("`@*B!C86YN
M;W0@<F5A9"!T:&5M('-O('5S92!T:&4@2&]R9&4@8V]N9FEG+B`J+PH@("`@
M("`@("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O=W=A<FYI;F<G
M72`]("1T:&ES+3Y?<&%R86US6R=W87)N86=E)UT["B`@("`@("`@("`@("`@
M("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W;6EN)UT@("`@(#T@)'1H:7,M
M/E]P87)A;7-;)VUI;F%G92==.PH@("`@("`@("`@("`@("`@("`@("1L;V]K
M=7!S:&%D;W=;)W-H861O=VUA>"==("`@("`]("1T:&ES+3Y?<&%R86US6R=M
M87AA9V4G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;W)M871I;VY;,%U;
M)W-H861O=VUA>"==6S!=*2D@>PH@("`@("`@("`@("`@("`@("`@("1L;V]K
M=7!S:&%D;W=;)W-H861O=VUA>"==(#T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F]R;6%T:6]N6S!=6R=S:&%D
M;W=M87@G75LP73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=M:6XG75LP72DI
M('L*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P<VAA9&]W6R=S:&%D;W=M
M:6XG72`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;6EN)UU;,%T["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O
M<FUA=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG92==6S!=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O=VQA<W1C:&%N9V4G
M72`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%T["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O<FUA
M=&EO;ELP75LG<VAA9&]W=V%R;FEN9R==6S!=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O=W=A<FYI;F<G72`]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F]R;6%T
M:6]N6S!=6R=S:&%D;W=W87)N:6YG)UU;,%T["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&]O
M:W5P<VAA9&]W.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@
M=&AE(&=I=F5N('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@=&\@8VAE
M8VLN"B`@("`@*B!`<&%R86T@87)R87D@("1C<F5D96YT:6%L<R`@06X@87)R
M87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N
M=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("`O
M*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C
M8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S
M=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L("1S=6-C97-S+3YG
M971-97-S86=E*"DI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`O*B!396%R8V@@9F]R('1H92!U<V5R)W,@9G5L;"!$
M3BX@*B\*("`@("`@("`D9&X@/2`D=&AI<RT^7V9I;F1$3B@D=7-E<DED*3L*
M("`@("`@("!I9B`H:7-?82@D9&XL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'
M12P@)&1N+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!!='1E;7!T('1O(&)I;F0@=&\@
M=&AE($Q$05`@<V5R=F5R(&%S('1H92!U<V5R+B`J+PH@("`@("`@("1B:6YD
M(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S+"`D9&XL("1C<F5D96YT:6%L<ULG
M<&%S<W=O<F0G72D["B`@("`@("`@:68@*"1B:6YD("$](&9A;'-E*2!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?97AP:7)A
M=&EO;B==(#T]("=Y97,G*2!["@H@("`@("`@("`@("`@("`@)'-H861O=R`]
M("1T:&ES+3Y?;&]O:W5P4VAA9&]W*"1D;BD["@H@("`@("`@("`@("`@("`@
M:68@*"1S:&%D;W=;)W-H861O=VUA>"==("8F("1S:&%D;W=;)W-H861O=VQA
M<W1C:&%N9V4G72`F)@H@("`@("`@("`@("`@("`@("`@("1S:&%D;W=;)W-H
M861O=W=A<FYI;F<G72D@>PH*("`@("`@("`@("`@("`@("`@("`D=&]D87D@
M/2!F;&]O<BAT:6UE*"D@+R`X-C0P,"D["B`@("`@("`@("`@("`@("`@("`@
M)'=A<FYD87D@/2`D<VAA9&]W6R=S:&%D;W=L87-T8VAA;F=E)UT@*PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-H861O=ULG<VAA9&]W;6%X
M)UT@+2`D<VAA9&]W6R=S:&%D;W=W87)N:6YG)UT["@H@("`@("`@("`@("`@
M("`@("`@("1T;V5X<&ER92`]("1S:&%D;W=;)W-H861O=VQA<W1C:&%N9V4G
M72`K"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-H861O=ULG
M<VAA9&]W;6%X)UT@+2`D=&]D87D["@H*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'1O9&%Y(#X]("1W87)N9&%Y*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"AS<')I;G1F*%\H
M(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(I+"`D=&]E
M>'!I<F4I+"=H;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("`@("!I9B`H)'1O97AP:7)E(#T@,"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%U=&A#<F5D96YT:6%L
M<ULG8VAA;F=E4F5Q=65S=&5D)UT@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`@("`@:68@*"1T;V5X<&ER92`\(#`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R
M;W(H05542%]214%33TY?15A025)%1"D["B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@($!L9&%P
M7V-L;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`;&1A<%]C;&]S92@D=&AI
M<RT^7V1S*3L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H0554
M2%]214%33TY?1D%)3$5$*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('-E="!O9B!A
M=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&%D9"X*("`@
M("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L
M<R!T;R!B92!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E
M9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=A
M9"==*2!["B`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N
M("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@
M("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;
M)VAO;VMS)UU;)V%U=&AL9&%P)UTI*2!["B`@("`@("`@("`@($!I;F-L=61E
M($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@("`@("`@
M("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]A=71H;&1A<"<I
M*2!["B`@("`@("`@("`@("`@("`D96YT<GD@/2!C86QL7W5S97)?9G5N8R@G
M7VAO<F1E7VAO;VM?875T:&QD87`G+"`D=7-E<DED+"`D8W)E9&5N=&EA;',I
M.PH@("`@("`@("`@("`@("`@)&1N(#T@)&5N=')Y6R=D;B==.PH@("`@("`@
M("`@("`@("`@+RH@<F5M;W9E('1H92!D;B!E;G1R>2!F<F]M('1H92!A<G)A
M>2X@*B\*("`@("`@("`@("`@("`@('5N<V5T*"1E;G1R>5LG9&XG72D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!4
M<GD@=&AI<R!S:6UP;&4@9&5F875L="!A;F0@:&]P92!I="!W;W)K<RX@*B\*
M("`@("`@("`@("`@)&1N(#T@)'1H:7,M/E]P87)A;7-;)W5I9"==("X@)STG
M("X@)'5S97))9"`N("<L)R`N("1T:&ES+3Y?<&%R86US6R=B87-E9&XG73L*
M("`@("`@("`@("`@)&5N=')Y6R=C;B==(#T@)'5S97))9#L*("`@("`@("`@
M("`@)&5N=')Y6R=S;B==(#T@)'5S97))9#L*("`@("`@("`@("`@)&5N=')Y
M6R1T:&ES+3Y?<&%R86US6R=U:60G75T@/2`D=7-E<DED.PH@("`@("`@("`@
M("`D96YT<GE;)V]B:F5C=&-L87-S)UT@/2!A<G)A>5]M97)G92AA<G)A>2@G
M=&]P)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=N97=U<V5R7V]B:F5C=&-L87-S)UTI.PH@("`@("`@
M("`@("`D96YT<GE;)W5S97)087-S=V]R9"==(#T@)'1H:7,M/F=E=$-R>7!T
M961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL)R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=T<G5E)RD["@H@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]P87)A;7-;)W!A<W-W;W)D7V5X<&ER871I;VXG72`]/2`G>65S)RD@
M>PH@("`@("`@("`@("`@("`@)&5N=')Y6R=S:&%D;W=-:6XG72`]("1T:&ES
M+3Y?<&%R86US6R=M:6YA9V4G73L*("`@("`@("`@("`@("`@("1E;G1R>5LG
M<VAA9&]W36%X)UT@/2`D=&AI<RT^7W!A<F%M<ULG;6%X86=E)UT["B`@("`@
M("`@("`@("`@("`D96YT<GE;)W-H861O=U=A<FYI;F<G72`]("1T:&ES+3Y?
M<&%R86US6R=W87)N86=E)UT["B`@("`@("`@("`@("`@("`D96YT<GE;)W-H
M861O=TQA<W1#:&%N9V4G72`](&9L;V]R*'1I;64H*2`O(#@V-#`P*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<W5C8V5S<R`]($!L9&%P
M7V%D9"@D=&AI<RT^7V1S+"`D9&XL("1E;G1R>2D["@H@("`@("`@(&EF("@A
M)'-U8V-E<W,I('L*("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B*2P@)'5S97))9"D@
M+B!`;&1A<%]E<G)O<B@D=&AI<RT^7V1S*2D["B`@("`@("`@?0H*("`@("`@
M("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@82!S970@;V8@875T
M:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7W!A<F%M<ULG860G72D@>PH@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T
M;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI
M<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O
M<BA!551(7U)%05-/3E]-15-304=%+"`D<W5C8V5S<RT^9V5T365S<V%G92@I
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@9VQO8F%L("1C;VYF.PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO
M;VMS)UU;)V%U=&AL9&%P)UTI*2!["B`@("`@("`@("`@($!I;F-L=61E($A/
M4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]A=71H;&1A<"<I*2![
M"B`@("`@("`@("`@("`@("`D96YT<GD@/2!C86QL7W5S97)?9G5N8R@G7VAO
M<F1E7VAO;VM?875T:&QD87`G+"`D=7-E<DED*3L*("`@("`@("`@("`@("`@
M("1D;B`]("1E;G1R>5LG9&XG73L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\J(%-E87)C:"!F;W(@=&AE('5S97(G<R!F
M=6QL($1.+B`J+PH@("`@("`@("`@("`D9&X@/2`D=&AI<RT^7V9I;F1$3B@D
M=7-E<DED*3L*("`@("`@("`@("`@:68@*&ES7V$H)&1N+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!
M551(7U)%05-/3E]-15-304=%+"`D9&XM/F=E=$UE<W-A9V4H*2D["B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1S=6-C97-S(#T@0&QD87!?9&5L971E*"1T:&ES+3Y?
M9',L)&1N*3L*("`@("`@("!I9B`H(21S=6-C97-S*2!["B`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(I+"`D=7-E<DED*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@($!L9&%P7V-L;W-E
M*"1T:&ES+3Y?9',I.PH*("`@("`@("!R971U<FX@)'1H:7,M/G)E;6]V955S
M97)$871A*"1U<V5R260I.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D871E
M(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&]L9$E$("`@("`@(%1H92!O;&0@=7-E
M<DED+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@("`@5&AE(&YE
M=R!U<V5R260N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4
M:&4@;F5W(&-R961E;G1I86QS"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E57-E<B@D;VQD
M240L("1N97=)1"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7W!A<F%M<ULG860G72D@>PH@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J($-O;FYE8W0@
M=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C97-S(#T@)'1H
M:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@
M("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=A=71H;&1A<"==*2D@>PH@
M("`@("`@("`@("!`:6YC;'5D92!(3U)$15]"05-%("X@)R]C;VYF:6<O:&]O
M:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G7VAO
M<F1E7VAO;VM?875T:&QD87`G*2D@>PH@("`@("`@("`@("`@("`@)&5N=')Y
M(#T@8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RP@)&]L
M9$E$+"`D8W)E9&5N=&EA;',I.PH@("`@("`@("`@("`@("`@)&]L9&1N(#T@
M)&5N=')Y6R=D;B==.PH@("`@("`@("`@("`@("`@)&5N=')Y(#T@8V%L;%]U
M<V5R7V9U;F,H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RP@)&YE=TE$+"`D8W)E
M9&5N=&EA;',I.PH@("`@("`@("`@("`@("`@)&YE=V1N(#T@)&5N=')Y6R=D
M;B==.PH@("`@("`@("`@("`@("`@=6YS970H)&5N=')Y6R=D;B==*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%-E
M87)C:"!F;W(@=&AE('5S97(G<R!F=6QL($1.+B`J+PH@("`@("`@("`@("`D
M9&X@/2`D=&AI<RT^7V9I;F1$3B@D;VQD240I.PH*("`@("`@("`@("`@:68@
M*&ES7V$H)&1N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&]L9&1N(#T@)&1N.PH@("`@("`@("`@("`@("`@
M)&YE=V1N(#T@<')E9U]R97!L86-E*"<O=6ED/2XJ/RPO)RPG=6ED/2<N)&YE
M=TE$+B<L)RPD9&XL,2D["B`@("`@("`@("`@("`@("`D<VAA9&]W(#T@)'1H
M:7,M/E]L;V]K=7!3:&%D;W<H)&1N*3L*"B`@("`@("`@("`@("`@("`O*B!I
M9B!S:&%D;W=M:6X@:&%S;B=T('EE="!E>'!I<F5D(&]N;'D@8VAA;F=E('=H
M96X@=V4@87)E"B`@("`@("`@("`@("`@("`@("!A9&UI;FES=')A=&]R("HO
M"B`@("`@("`@("`@("`@("!I9B`H)'-H861O=ULG<VAA9&]W;&%S=&-H86YG
M92==("8F("1S:&%D;W=;)W-H861O=VUI;B==*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1S:&%D;W=;)W-H861O=VQA<W1C:&%N9V4G72`K("1S:&%D
M;W=;)W-H861O=VUI;B==(#X@*'1I;64H*2`O(#@V-#`P*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(BDI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O*B!3970@=&AE(&QA<W1C:&%N9V4@9FEE;&0@*B\*("`@
M("`@("`@("`@("`@(&EF("@D<VAA9&]W6R=S:&%D;W=L87-T8VAA;F=E)UTI
M('L*("`@("`@("`@("`@("`@("`@("`D96YT<GE;)W-H861O=VQA<W1C:&%N
M9V4G72`]("!F;&]O<BAT:6UE*"D@+R`X-C0P,"D["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@+RH@16YC<GEP="!T:&4@;F5W('!A<W-W
M;W)D("HO"B`@("`@("`@("`@("`@("`D96YT<GE;)W5S97)P87-S=V]R9"==
M(#T@)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A
M<W-W;W)D)UTL)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R
M=64G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1O
M;&1)1"`A/2`D;F5W240I('L*("`@("`@("`@("`@:68@*$Q$05!?3U!47U!2
M3U1/0T],7U9%4E-)3TX@/3T@,RD@>PH@("`@("`@("`@("`@("`@;&1A<%]R
M96YA;64H)'1H:7,M/E]D<RP@)&]L9&1N+"`D;F5W9&XL("1T:&ES+3Y?<&%R
M86US6R=B87-E9&XG72P@=')U92D["@H@("`@("`@("`@("`@("`@)'-U8V-E
M<W,@/2!L9&%P7VUO9&EF>2@D=&AI<RT^7V1S+"`D;F5W9&XL("1E;G1R>2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!'970@
M=&AE(&-O;7!L971E(&]L9"!R96-O<F0@9FER<W0@*B\*("`@("`@("`@("`@
M("`@("1S=6-C97-S(#T@0&QD87!?<F5A9"@D=&AI<RT^7V1S+"`D;VQD9&XL
M("=O8FIE8W1#;&%S<STJ)RD["@H@("`@("`@("`@("`@("`@:68@*"1S=6-C
M97-S*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9F]R;6%T:6]N(#T@0&QD
M87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-U8V-E<W,I.PH*("`@("`@
M("`@("`@("`@("`@("`O*B!296UO=F4@=&AE(&-O=6YT(&5L96UE;G1S(&9R
M;VT@=&AE(&%R<F%Y("HO"B`@("`@("`@("`@("`@("`@("`@)&-O=6YT97(@
M/2`P.PH@("`@("`@("`@("`@("`@("`@("1N97=R96-O<F0@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("AI<W-E="@D:6YF;W)M871I
M;VY;,%U;)&-O=6YT97)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)&EN9F]R;6%T:6]N6S!=6R1I;F9O<FUA=&EO;ELP75LD8V]U;G1E<EU=
M6R=C;W5N="==(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N97=R96-O<F1;)&EN9F]R;6%T:6]N6S!=6R1C;W5N=&5R75T@/2`D:6YF
M;W)M871I;VY;,%U;)&EN9F]R;6%T:6]N6S!=6R1C;W5N=&5R75U;,%T["B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;F5W<F5C;W)D6R1I;F9O<FUA=&EO;ELP75LD8V]U
M;G1E<EU=(#T@)&EN9F]R;6%T:6]N6S!=6R1I;F9O<FUA=&EO;ELP75LD8V]U
M;G1E<EU=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&YE
M=W)E8V]R9%LD:6YF;W)M871I;VY;,%U;)&-O=6YT97)=75LG8V]U;G0G72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O=6YT97(K*SL*("`@("`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@("`@("\J($%D:G5S="!T:&4@8VAA;F=E9"!P87)A;65T
M97)S("HO"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&YE=W)E8V]R9%LG
M9&XG72D["B`@("`@("`@("`@("`@("`@("`@)&YE=W)E8V]R9%LD=&AI<RT^
M7W!A<F%M<ULG=6ED)UU=(#T@)&YE=TE$.PH@("`@("`@("`@("`@("`@("`@
M("1N97=R96-O<F1;)W5S97)P87-S=V]R9"==(#T@)&5N=')Y6R=U<V5R<&%S
M<W=O<F0G73L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y
M6R=S:&%D;W=L87-T8VAA;F=E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1N97=R96-O<F1;)W-H861O=VQA<W1C:&%N9V4G72`]("1E;G1R>5LG
M<VAA9&]W;&%S=&-H86YG92==.PH@("`@("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`@("`@)'-U8V-E<W,@/2!L9&%P7V%D9"@D=&AI<RT^
M7V1S+"1N97=D;BPD;F5W<F5C;W)D*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'-U8V-E<W,I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-U8V-E
M<W,@/2!`;&1A<%]D96QE=&4H)'1H:7,M/E]D<RPD;VQD9&XI.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=6-C97-S(#T@0&QD
M87!?;6]D:69Y*"1T:&ES+3Y?9',L("1O;&1D;BP@)&5N=')Y*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<R(I+"`D;F5W240I+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@0&QD87!?8VQO<V4H)'1H
M:7,M/E]D<RD["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3&ES="!5<V5R<PH@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($QI<W0@;V8@57-E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S
M97)S*"D*("`@('L*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E
M<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I
M.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S
M+3YG971-97-S86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=F:6QT97(G
M72DI('L*("`@("`@("`@("`@)&9I;'1E<B`]("1T:&ES+3Y?<&%R86US6R=F
M:6QT97(G73L*("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?
M<&%R86US6R=O8FIE8W1C;&%S<R==*2D@>PH@("`@("`@("`@("`D9FEL=&5R
M(#T@)V]B:F5C=&-L87-S/2<@+B`D=&AI<RT^7W!A<F%M<ULG;V)J96-T8VQA
M<W,G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL=&5R(#T@
M)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US6R=O8FIE
M8W1C;&%S<R==(&%S("1O8FIE8W1C;&%S<RD@>PH@("`@("`@("`@("`@("`@
M)&9I;'1E<B`]("<H)B<@+B`D9FEL=&5R.PH@("`@("`@("`@("`@("`@)&9I
M;'1E<B`N/2`G*&]B:F5C=&-L87-S/2<@+B`D;V)J96-T8VQA<W,@+B`G*2DG
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<V5A<F-H(#T@
M0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T:&ES+3Y?<&%R86US6R=B87-E
M9&XG72P@)&9I;'1E<BP@87)R87DH)'1H:7,M/E]P87)A;7-;)W5I9"==*2D[
M"B`@("`@("`@)&5N=')I97,@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^
M7V1S+"`D<V5A<F-H*3L*("`@("`@("`D=7-E<FQI<W0@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1E;G1R:65S6R=C;W5N="==.R`D
M:2LK*2!["B`@("`@("`@("`@("1U<V5R;&ES=%LD:5T@/2`D96YT<FEE<ULD
M:5U;)'1H:7,M/E]P87)A;7-;)W5I9"==75LP73L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=7-E<FQI<W0["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O075T:"]L;V=I;BYP:'``````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-C(W`#$P-#$W,S8R-S<Q`#`R,#<V-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE($%U=&A?;&]G:6XZ.B!C;&%S<R!P<F]V:61E<R!A('-Y
M<W1E;2!L;V=I;B!I;7!L96UE;G1A=&EO;B!O9@H@*B!T:&4@2&]R9&4@875T
M:&5N=&EC871I;VX@<WES=&5M+@H@*B!4:&ES($%U=&@@9')I=F5R(&ES('5S
M969U;"!I9B!Y;W4@:&%V92!A('-H861O=R!P87-S=V]R9"!S>7-T96T*("H@
M=VAE<F4@=&AE($%U=&A?<&%S<W=D(&1R:79E<B!D;V5S;B=T('=O<FLN"B`J
M"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G;&]C871I;VXG
M("!,;V-A=&EO;B!O9B!T:&4@<W4@8FEN87)Y+@H@*B`@("`@("`@("`@("`@
M($1%1D%53%0Z("]B:6XO<W4\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<"QV(#$N,RXQ,"XY(#(P,#8O,#$O
M,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H
M"B`J+PIC;&%S<R!!=71H7VQO9VEN(&5X=&5N9',@075T:"!["@H@("`@+RHJ
M"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE
M(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET
M('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A
M<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E
M)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@
M("`O*BH*("`@("`J('-U(&)I;F%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]L;V-A=&EO;B`]("<O8FEN+W-U)SL*
M"B`@("`O*BH*("`@("`J($QI<W0@;V8@=7-E<G,@=&AA="!S:&]U;&0@8F4@
M97AC;'5D960@9G)O;2!B96EN9R!L:7-T960O:&%N9&QE9`H@("`@("H@:6X@
M86YY('=A>2!B>2!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7V5X8VQU9&4@/2!A<G)A>2@G<F]O="<L
M("=D865M;VXG+"`G8FEN)RP@)W-Y<R<L("=S>6YC)RP@)V=A;65S)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;6%N)RP@)VQP)RP@)VUA:6PG+"`G
M;F5W<R<L("=U=6-P)RP@)W!R;WAY)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<&]S=&=R97,G+"`G=W=W+61A=&$G+"`G8F%C:W5P)RP@)V]P97)A
M=&]R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<L("=I<F,G
M+"`G9VYA=',G+"`G;F]B;V1Y)RP@)VED96YT9"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W-S:&0G+"`G9V1M)RP@)W!O<W1F:7@G+"`G;7ES<6PG
M+"`G8WER=7,G+"`G9G1P)RD["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@;F5W($QO9VEN(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@
M8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!
M=71H7VQO9VEN*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@("`@("!I9B`H(65M<'1Y*"1P
M87)A;7-;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&]C
M871I;VX@/2`D<&%R86US6R=L;V-A=&EO;B==.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R
M961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@
M("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C
M<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T
M:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*
M("`@("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'!R;V,@/2!P;W!E;B@D
M=&AI<RT^7VQO8V%T:6]N("X@)R`M8R`O8FEN+W1R=64@)R`N("1U<V5R260L
M("=W)RD["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D<')O8RDI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!F=W)I
M=&4H)'!R;V,L("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72D["@H@("`@("`@
M(')E='5R;B!P8VQO<V4H)'!R;V,I(#T]/2`P.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!
M=71H+VUC86PN<&AP````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#4V,#,`,3`T,3<S-C(W-S$`,#(P-38R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T
M:%]M8V%L(&-L87-S('!R;W9I9&5S(&%N($U#04P@:6UP;&5M96YT871I;VX@
M;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@
M34-!3"!(;VUE(%!A9V4Z(&AT='`Z+R]M8V%L+F-H96LN8V]M+PH@*@H@*B!2
M97%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V-A;&5N9&%R)R`@5&AE
M($U#04P@8V%L96YD87(@;F%M92X\+W!R93X*("H*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP+'8@,2XR-RXQ,"XY(#(P,#8O
M,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?;6-A;"!E>'1E;F1S($%U=&@@
M>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S
M;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E
M<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I
M;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A
M<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A
M;'-E*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@34-!3"!A
M=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]M8V%L*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS
M:6]N17AI<W1S*"=M8V%L)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*%\H(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&5M<'1Y*"1P87)A;7-;)V-A;&5N9&%R)UTI*2!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"A?*").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D
M(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@
M;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R
M86T@87)R87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D
M96YT:6%L<RX@1F]R($U#04PL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T:&ES(&UU<W0@8V]N=&%I;B!A('!A<W-W;W)D(&5N=')Y+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@
M=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("![
M"B`@("`@("`@)&UC86P@/2!`;6-A;%]O<&5N*"1T:&ES+3Y?<&%R86US6R=C
M86QE;F1A<B==+"`D=7-E<DED+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI
M.PH*("`@("`@("!I9B`H)&UC86PI('L*("`@("`@("`@("`@0&UC86Q?8VQO
M<V4H)&UC86PI.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!`;6-A;%]C;&]S92@D;6-A;"D["B`@("`@
M("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T)!1$Q/
M1TE.*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T
M96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F
M('5S97))9',L(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@
M("`D;&EN97,@/2!`9FEL92@G+V5T8R]M<&%S<W=D)RD["B`@("`@("`@:68@
M*"$D;&EN97,@?'P@(6ES7V%R<F%Y*"1L:6YE<RDI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N86)L92!T;R!L:7-T('5S97)S
M+B<I.PH@("`@("`@('T*"B`@("`@("`@)'5S97)S(#T@87)R87DH*3L*("`@
M("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@
M)'5S97)S6UT@/2!S=6)S='(H)&QI;F4L(#`L('-T<G!O<R@D;&EN92P@)SHG
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97)S.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<&%M+G!H<```````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3,R,P`Q,#0Q-S,V
M,C<W,0`P,C`T,C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7W!A;3HZ(&-L87-S('!R
M;W9I9&5S(&$@4$%-+6)A<V5D(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D
M90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J(%!!32`H4&QU9V=A
M8FQE($%U=&AE;G1I8V%T:6]N($UO9'5L97,I(&ES(&$@9FQE>&EB;&4@;65C
M:&%N:7-M(&9O<@H@*B!A=71H96YT:6-A=&EN9R!U<V5R<RX@($ET(&AA<R!B
M96-O;64@=&AE('-T86YD87)D(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2!F;W(*
M("H@3&EN=7@L(%-O;&%R:7,@86YD($9R965"4T0N"B`J"B`J(%1H:7,@:6UP
M;&5M96YT871I;VX@<F5Q=6ER97,@0VAA9"!#=6YN:6YG:&%M)W,@<&%M7V%U
M=&@@97AT96YS:6]N.@H@*@H@*B`@("`@(&AT='`Z+R]W=W<N;6%T:"YO:&EO
M+7-T871E+F5D=2]^8V-U;FYI;F<O<&%M7V%U=&@O"B`J"B`J($]P=&EO;F%L
M('!A<F%M971E<G,Z/'!R93X*("H@("`G<V5R=FEC92<@(%1H92!N86UE(&]F
M('1H92!004T@<V5R=FEC92!T;R!U<V4@=VAE;B!A=71H96YT:6-A=&EN9RX*
M("H@("`@("`@("`@("`@($1%1D%53%0Z('!H<#PO<')E/@H@*@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<"QV(#$N,RXQ,"XQ
M,2`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4&%R:7-E(#QJ;VY`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M075T:`H@*B\*8VQA<W,@075T:%]P86T@97AT96YD<R!!=71H('L*"B`@("`O
M*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T
M:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@
M:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`]
M(&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO
M=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!004T@875T:&5N=&EC
M871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?<&%M*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*
M("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)W-E<G9I8V4G72DI('L*("`@
M("`@("`@("`@:6YI7W-E="@G<&%M7V%U=&@N<V5R=FEC96YA;64G+"`D<&%R
M86US6R=S97)V:6-E)UTI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E>'1E
M;G-I;VY?;&]A9&5D*"=P86U?875T:"<I*2!["B`@("`@("`@("`@(&1L*"=P
M86U?875T:"YS;R<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V
M86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O
M(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@
M87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@
M87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E
M*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H96UP
M='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=P86U?875T
M:"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?*")004T@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A<&%M7V%U=&@H)'5S97))
M9"P@)&-R961E;G1I86QS6R=P87-S=V]R9"==+"`F)&5R<F]R*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-3
M04=%+"`D97)R;W(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$U-S<P`#$P-#$W,S8R-S<Q`#`R,3$U-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($%U=&A?<&%S<W=D.CH@8VQA<W,@<')O=FED97,@82!P87-S
M=V0M9FEL92!I;7!L96UE;G1A=&EO;B!O9@H@*B!T:&4@2&]R9&4@875T:&5N
M=&EC871I;VX@<WES=&5M+@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP
M<F4^"B`J("`@)V9I;&5N86UE)R`@5&AE('!A<W-W9"!F:6QE('1O('5S92X*
M("H@("`@("`@("`@("`@("!$149!54Q4.B`O971C+W!A<W-W9`H@*B`@("=L
M;V-K)R`@("`@(%-H;W5L9"!W92!L;V-K('1H92!P87-S=V0@9FEL93\@*&)O
M;VQE86XI"B`J("`@("`@("`@("`@("`@1$5&055,5#H@9F%L<V4\+W!R93X*
M("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP
M:'`L=B`Q+C$V+C$P+C$P(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DW+3(P,#8@4F%S;75S($QE<F1O<F8@/')A
M<VUU<T!P:'`N;F5T/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@4F%S;75S($QE<F1O<F8@/')A<VUU<T!P:'`N;F5T/@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO
M"F-L87-S($%U=&A?<&%S<W=D(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@
M("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R
M:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U
M<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A
M>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=L:7-T)R`@("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J
M*@H@("`@("H@4&%S<W=D(&9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?9FEL96YA;64@/2`G+V5T8R]P87-S=V0G
M.PH*("`@("\J*@H@("`@("H@2&%S:"!L:7-T(&]F('5S97)S+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=7-E<G,["@H@
M("`@+RHJ"B`@("`@*B!&:6QE:&%N9&QE(&9O<B!L;V-K9FEL92X*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?9G!L;V-K
M.PH*("`@("\J*@H@("`@("H@3&]C:VEN9R!S=&%T92X*("`@("`J"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?;&]C:V5D.PH*("`@
M("\J*@H@("`@("H@3&ES="!O9B!U<V5R<R!T:&%T('-H;W5L9"!B92!E>&-L
M=61E9"!F<F]M(&)E:6YG(&QI<W1E9"]H86YD;&5D"B`@("`@*B!I;B!A;GD@
M=V%Y(&)Y('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?97AC;'5D92`](&%R<F%Y*"=R;V]T)RP@)V1A
M96UO;B<L("=B:6XG+"`G<WES)RP@)W-Y;F,G+"`G9V%M97,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("=M86XG+"`G;'`G+"`G;6%I;"<L("=N97=S
M)RP@)W5U8W`G+"`G<')O>'DG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("=P;W-T9W)E<R<L("=W=W<M9&%T82<L("=B86-K=7`G+"`G;W!E<F%T;W(G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)RP@)VER8R<L("=G
M;F%T<R<L("=N;V)O9'DG+"`G:61E;G1D)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<W-H9"<L("=G9&TG+"`G<&]S=&9I>"<L("=M>7-Q;"<L("=C
M>7)U<R<L("=F='`G*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N
M97<@4&%S<W=D(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N
M;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H
M7W!A<W-W9"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI
M<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@:68@*"%E;7!T>2@D<&%R
M86US6R=F:6QE;F%M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V9I;&5N
M86UE(#T@)'!A<F%M<ULG9FEL96YA;64G73L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?9G!L;V-K(#T@9F]P96XH2&]R9&4Z.F=E=%1E;7!$:7(H*2`N
M("<O<&%S<W=D+FQO8VLG+"`G=R<I.PH@("`@("`@(&EF("@A96UP='DH)'!A
M<F%M<ULG;&]C:R==*2D@>PH@("`@("`@("`@("!F;&]C:R@D=&AI<RT^7V9P
M;&]C:RP@3$]#2U]%6"D["B`@("`@("`@("`@("1T:&ES+3Y?;&]C:V5D(#T@
M=')U93L*("`@("`@("!]"@H@("`@("`@("1F<"`](&9O<&5N*"1T:&ES+3Y?
M9FEL96YA;64L("=R)RD["B`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD;B=T(&]P96X@)R(@
M+B`D=&AI<RT^7V9I;&5N86UE("X@(B<N(BD["B`@("`@("`@?0H@("`@("`@
M('=H:6QE("@A9F5O9B@D9G`I*2!["B`@("`@("`@("`@("1L:6YE(#T@9F=E
M=',H)&9P+"`Q,C@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1L:6YE*2D@
M>PH@("`@("`@("`@("`@("`@;&ES="@D=7-E<BP@)'!A<W,L("1U:60L("1G
M:60L("1I;F9O+"`D:&]M92P@)'-H96QL*2`](&5X<&QO9&4H)SHG+"`D;&EN
M92D["B`@("`@("`@("`@("`@("!I9B`H<W1R;&5N*"1U<V5R*2`F)@H@("`@
M("`@("`@("`@("`@("`@("%I;E]A<G)A>2@D=7-E<BP@)'1H:7,M/E]E>&-L
M=61E*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S
M97)=6R=P87-S=V]R9"==(#T@)'!A<W,["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]U<V5R<ULD=7-E<EU;)W5I9"==(#T@)'5I9#L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W5S97)S6R1U<V5R75LG9VED)UT@/2`D9VED
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S97)=6R=I
M;F9O)UT@/2`D:6YF;SL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S
M97)S6R1U<V5R75LG:&]M92==(#T@)&AO;64["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]U<V5R<ULD=7-E<EU;)W-H96QL)UT@/2`D<VAE;&P["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@9F-L;W-E*"1F<"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U
M="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*
M("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@($%N(&%R<F%Y(&]F
M(&QO9VEN(&-R961E;G1I86QS+B!&;W(@34-!3"P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H:7,@;75S="!C;VYT86EN(&$@<&%S<W=O
M<F0@96YT<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T
M:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT
M:6%L<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P
M87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB
M*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?=7-E<G-;)'5S97))9%TI*2!["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7W5S97)S6R1U<V5R261=6R=P87-S=V]R9"==(#T](&-R
M>7!T*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P@<W5B<W1R*"1T:&ES+3Y?
M=7-E<G-;)'5S97))9%U;)W!A<W-W;W)D)UTL(#`L(#(I*2D@<F5T=7)N('1R
M=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))
M9',L(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!R971U
M<FX@87)R87E?:V5Y<R@D=&AI<RT^7W5S97)S*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9',@82!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97(@($YE=R!U<V5R($E$+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%S<R`@4&%S<W=O<F0@9F]R(&YE=R!U<V5R+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8W9S("`@0U93('5S97(@:60@*&YE961E9"!F;W(@<'-E<G9E<B!P
M87-S=V0@9FEL97,I+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M4F5T=7)N<R!T<G5E(&]R(%!%05)?17)R;W(@:68@=&AE('5S97(@86QR96%D
M>0H@("`@("H@("`@("`@("`@("`@("`@("!E>&ES=',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9%5S97(H)'5S97(L("1P87-S+"`D8W9S=7-E<B`]("<G
M*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]U<V5R<ULD=7-E
M<ETI("8F("1T:&ES+3Y?;&]C:V5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M=7-E<G-;)'5S97)=(#T@8W)Y<'0H)'!A<W,I.PH@("`@("`@("`@("`D=&AI
M<RT^7V-V<ULD=7-E<ET@/2`D8W9S=7-E<CL*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H(D-O=6QD;B=T(&%D9"!U<V5R("<D=7-E<B<L(&)E
M8V%U<V4@=&AE('5S97(@86QR96%D>2!E>&ES=',N(BD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@36]D:69I97,@82!U<V5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@(%5S97(@240N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P87-S("!087-S=V]R9"!F;W(@;F5W('5S97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C=G,@("!#5E,@=7-E<B!I9"`H;F5E9&5D
M(&9O<B!P<V5R=F5R('!A<W-W9"!F:6QE<RDN"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;W(@4$5!4E]%<G)O<B!I9B!T
M:&4@=7-E<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@(&5X:7-T
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;6]D57-E<B@D=7-E<BP@)'!A<W,L
M("1C=G-U<V5R(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?=7-E<G-;)'5S97)=*2`F)B`D=&AI<RT^7VQO8VME9"D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W5S97)S6R1U<V5R72`](&-R>7!T*"1P87-S*3L*("`@
M("`@("`@("`@)'1H:7,M/E]C=G-;)'5S97)=(#T@)&-V<W5S97(["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;W5L9&XG="!M;V1I9GD@
M=7-E<B`G)'5S97(G+"!B96-A=7-E('1H92!U<V5R(&1O97-N)W0@97AI<W0N
M(BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A
M('5S97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@57-E
M<B!)1"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@
M=')U92!O<B!014%27T5R<F]R(&EF('1H92!U<V5R(&1O97-N)W0@97AI<W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;%5S97(H)'5S97(I"B`@("!["B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=7-E<G-;)'5S97)=*2`F)B`D=&AI
M<RT^7VQO8VME9"D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W5S97)S
M6R1U<V5R72D["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8W9S6R1U<V5R
M72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H(D-O=6QD;B=T(&1E;&5T92!U<V5R("<D=7-E<B<L(&)E
M8V%U<V4@=&AE('5S97(@9&]E<VXG="!E>&ES="XB*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!7<FET97,@8VAA;F=E<R!T;R!P87-S=V0@
M9FEL92!A;F0@=6YL;V-K<R!I="X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO
M<V4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VQO8VME9"D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7W5S97)S(&%S("1U<V5R(#T^("1P
M87-S*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]U<V5R<ULD=7-E
M<ETI('L*("`@("`@("`@("`@("`@("`@("!F<'5T<R@D=&AI<RT^7V9P;&]C
M:RP@(B1U<V5R.B1P87-S.B(@+B`D=&AI<RT^7W5S97)S6R1U<V5R72`N(")<
M;B(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!F<'5T<R@D=&AI<RT^7V9P;&]C:RP@(B1U<V5R.B1P87-S7&XB*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M96YA;64H)'1H:7,M/E]L;V-K9FEL92P@)'1H:7,M/E]F:6QE;F%M92D["B`@
M("`@("`@("`@(&9L;V-K*"1T:&ES+3Y?9G!L;V-K+"!,3T-+7U5.*3L*("`@
M("`@("`@("`@)'1H:7,M/E]L;V-K960@/2!F86QS93L*("`@("`@("`@("`@
M9F-L;W-E*"1T:&ES+3Y?9G!L;V-K*3L*("`@("`@("!]"B`@("!]"@I]"@``
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T
M:"]R861I=7,N<&AP````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$T-S$T`#$P-#$W,S8R-S<Q`#`R,3$T,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?
M<F%D:75S(&-L87-S('!R;W9I9&5S(&$@4D%$2553(&EM<&QE;65N=&%T:6]N
M(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J
M(%1H:7,@8VQA<W,@<F5Q=6ER97,@=&AE("=R861I=7,G(%!%0TP@97AT96YS
M:6]N+@H@*B!2041)55,@4$5#3"!E>'1E;G-I;VXZ(&AT='`Z+R]P96-L+G!H
M<"YN970O<&%C:V%G92]R861I=7,*("H*("H@3VX@*FYI>"UY(&UA8VAI;F5S
M+"!T:&ES(&5X=&5N<VEO;B!C86X@8F4@:6YS=&%L;&5D(&%S(&9O;&QO=W,Z
M/'!R93X*("H@("`B<&5A<B!I;G-T86QL(')A9&EU<R(\+W!R93X*("H*("H@
M5&AE;BP@961I="!Y;W5R('!H<"YI;FD@9FEL92!A;F0@;6%K92!S=7)E('1H
M92!F;VQL;W=I;F<@;&EN92!I<R!P<F5S96YT.CQP<F4^"B`J("`@1F]R(%=I
M;F1O=W,@;6%C:&EN97,Z("!E>'1E;G-I;VX]<&AP7W)A9&EU<RYD;&P*("H@
M("!&;W(@86QL(&]T:&5R<SH@("`@("`@(&5X=&5N<VEO;CUR861I=7,N<V\\
M+W!R93X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=H
M;W-T)R`@("!4:&4@4D%$2553(&AO<W0@=&\@=7-E("A)4"!A9&1R97-S(&]R
M(&9U;&QY('%U86QI9FEE9`H@*B`@("`@("`@("`@("!H;W-T;F%M92DN"B`J
M("`@)VUE=&AO9"<@(%1H92!2041)55,@;65T:&]D('1O('5S92!F;W(@=F%L
M:61A=&EN9R!T:&4@<F5Q=65S="X*("H@("`@("`@("`@("`@16ET:&5R.B`G
M4$%0)RP@)T-(05!?340U)RP@)TU30TA!4'8Q)RP@;W(@)TU30TA!4'8R)RX*
M("H@("`@("`@("`@("`@*BH@0U524D5.5$Q9+"!O;FQY("=005`G(&ES('-U
M<'!O<G1E9"X@*BH*("H@("`G<V5C<F5T)R`@5&AE(%)!1$E54R!S:&%R960@
M<V5C<F5T('-T<FEN9R!F;W(@=&AE(&AO<W0N(%1H90H@*B`@("`@("`@("`@
M("!2041)55,@<')O=&]C;VP@:6=N;W)E<R!A;&P@8G5T('1H92!L96%D:6YG
M(#$R."!B>71E<PH@*B`@("`@("`@("`@("!O9B!T:&4@<VAA<F5D('-E8W)E
M="X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@
M("=N87,G("`@("`@5&AE(%)!1$E54R!.05,@:61E;G1I9FEE<B!T;R!U<V4N
M"B`J("`@("`@("`@("`@("!$149!54Q4.B!4:&4@=F%L=64@;V8@)%]315)6
M15);)TA45%!?2$]35"==(&]R+"!I9B!N;W0*("H@("`@("`@("`@("`@("`@
M("`@("`@(&1E9FEN960L('1H96X@)VQO8V%L:&]S="<N"B`J("`@)W!O<G0G
M("`@("!4:&4@<&]R="!T;R!U<V4@;VX@=&AE(%)!1$E54R!S97)V97(N"B`J
M("`@("`@("`@("`@("!$149!54Q4.B!7:&%T979E<B!T:&4@;&]C86P@<WES
M=&5M(&ED96YT:69I97,@87,@=&AE"B`J("`@("`@("`@("`@("`@("`@("`@
M("`G<F%D:75S)R!51%`@<&]R=`H@*B`@("=R971R:65S)R`@5&AE(&UA>&EM
M=6T@;G5M8F5R(&]F(')E<&5A=&5D(')E<75E<W1S('1O(&UA:V4@8F5F;W)E
M"B`J("`@("`@("`@("`@("!G:79I;F<@=7`N"B`J("`@("`@("`@("`@("!$
M149!54Q4.B`S"B`J("`@)W-U9F9I>"<@("!4:&4@9&]M86EN(&YA;64@=&\@
M861D('1O('5N<75A;&EF:65D('5S97(@;F%M97,N"B`J("`@("`@("`@("`@
M("!$149!54Q4.B!.3TY%"B`J("`@)W1I;65O=70G("!4:&4@=&EM96]U="!F
M;W(@<F5C96EV:6YG(')E<&QI97,@9G)O;2!T:&4@<V5R=F5R("AI;@H@*B`@
M("`@("`@("`@("`@<V5C;VYD<RDN"B`J("`@("`@("`@("`@("!$149!54Q4
M.B`S('-E8V]N9',\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M075T:"]!=71H+W)A9&EU<RYP:'`L=B`Q+C(T+C@N."`R,#`V+S`Q+S`Q(#(Q
M.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?
M<F%D:75S(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A
M>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P
M;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W
M:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=',@82!N97<@4D%$2553(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O
M;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!!=71H7W)A9&EU<R@D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G<F%D:75S)RDI
M('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"=!=71H7W)A9&EU<R!R97%U
M:7)E<R!T:&4@<F%D:75S(%!%0TP@97AT96YS:6]N('1O(&)E(&QO861E9"XG
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]S971087)A;7,H)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3970@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A
M<F%M971E<B!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4&%R86US
M*"1P87)A;7,I"B`@("!["B`@("`@("`@+RH@02!2041)55,@:&]S="!I<R!R
M97%U:7)E9"X@*B\*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG:&]S="==
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)T%U=&A?<F%D:75S(')E
M<75I<F5S(&$@4D%$2553(&AO<W0@=&\@8V]N;F5C="!T;RXG+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@02!2041)55,@
M<V5C<F5T('-T<FEN9R!I<R!R97%U:7)E9"X@*B\*("`@("`@("!I9B`H96UP
M='DH)'!A<F%M<ULG<V5C<F5T)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF
M871A;"@G075T:%]R861I=7,@<F5Q=6ER97,@82!2041)55,@<V5C<F5T('-T
M<FEN9RXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@02!2041)55,@875T:&5N=&EC871I;VX@;65T:&]D(&ES(')E<75I
M<F5D+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=M971H;V0G72DI
M('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"=!=71H7W)A9&EU<R!R97%U
M:7)E<R!A(%)!1$E54R!A=71H96YT:6-A=&EO;B!M971H;V0N)RP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J(%)!1$E54R!.
M05,@261E;G1I9FEE<BX@*B\*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG
M;F%S)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)VYA<R==(#T@:7-S970H
M)%]315)615);)TA45%!?2$]35"==*2`_("1?4T525D526R=(5%107TA/4U0G
M"ET@.B`G;&]C86QH;W-T)SL*("`@("`@("!]"@H@("`@("`@("\J(%-U9F9I
M>"!T;R!A9&0@=&\@=6YQ=6%L:69I960@=7-E<B!N86UE<RX@*B\*("`@("`@
M("!I9B`H96UP='DH)'!A<F%M<ULG<W5F9FEX)UTI*2!["B`@("`@("`@("`@
M("1P87)A;7-;)W-U9F9I>"==(#T@)R<["B`@("`@("`@?0H*("`@("`@("`O
M*B!4:&4@4D%$2553('!O<G0@=&\@=7-E+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D<&%R86US6R=P;W)T)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)W!O
M<G0G72`](#`["B`@("`@("`@?0H*("`@("`@("`O*B!-87AI;75M(&YU;6)E
M<B!O9B!R971R:65S+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=R
M971R:65S)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)W)E=')I97,G72`]
M(#,["B`@("`@("`@?0H*("`@("`@("`O*B!2041)55,@=&EM96]U="X@*B\*
M("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG=&EM96]U="==*2D@>PH@("`@
M("`@("`@("`D<&%R86US6R=T:6UE;W5T)UT@/2`S.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA
M;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("`@(%1H92!U
M<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I
M86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($9O<B!R861I=7,L('1H:7,@;75S
M="!C;VYT86EN(&$@<&%S<W=O<F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&5N=')Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<FYA;64L
M("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("`O*B!087-S=V]R9"!I<R!R
M97%U:7)E9"X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1C<F5D96YT:6%L<ULG
M<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(E!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(BDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D<F5S
M(#T@<F%D:75S7V%U=&A?;W!E;B@I.PH@("`@("`@(')A9&EU<U]A9&1?<V5R
M=F5R*"1R97,L("1T:&ES+3Y?<&%R86US6R=H;W-T)UTL("1T:&ES+3Y?<&%R
M86US6R=P;W)T)UTL("1T:&ES+3Y?<&%R86US6R=S96-R970G72P@)'1H:7,M
M/E]P87)A;7-;)W1I;65O=70G72P@)'1H:7,M/E]P87)A;7-;)W)E=')I97,G
M72D["B`@("`@("`@<F%D:75S7V-R96%T95]R97%U97-T*"1R97,L(%)!1$E5
M4U]!0T-%4U-?4D5154535"D["B`@("`@("`@<F%D:75S7W!U=%]A='1R*"1R
M97,L(%)!1$E54U].05-?241%3E1)1DE%4BP@)'1H:7,M/E]P87)A;7-;)VYA
M<R==*3L*("`@("`@("!R861I=7-?<'5T7V%T='(H)')E<RP@4D%$25537TY!
M4U]03U)47U194$4L(%)!1$E54U]625)454%,*3L*("`@("`@("!R861I=7-?
M<'5T7V%T='(H)')E<RP@4D%$25537U-%4E9)0T5?5%E012P@4D%$25537T92
M04U%1"D["B`@("`@("`@<F%D:75S7W!U=%]A='1R*"1R97,L(%)!1$E54U]&
M4D%-141?4%)/5$]#3TPL(%)!1$E54U]04%`I.PH@("`@("`@(')A9&EU<U]P
M=71?871T<B@D<F5S+"!2041)55-?0T%,3$E.1U]35$%424].7TE$+"!I<W-E
M="@D7U-%4E9%4ELG4D5-3U1%7TA/4U0G72D@/R`D7U-%4E9%4ELG4D5-3U1%
M7TA/4U0G72`Z("<Q,C<N,"XP+C$G*3L*"B`@("`@("`@+RH@26YS97)T('5S
M97)N86UE+W!A<W-W;W)D(&EN=&\@<F5Q=65S="X@*B\*("`@("`@("!R861I
M=7-?<'5T7V%T='(H)')E<RP@4D%$25537U5315)?3D%-12P@)'5S97)N86UE
M*3L*("`@("`@("!R861I=7-?<'5T7V%T='(H)')E<RP@4D%$25537U5315)?
M4$%34U=/4D0L("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72D["@H@("`@("`@
M("\J(%-E;F0@<F5Q=65S="X@*B\*("`@("`@("`D<W5C8V5S<R`](')A9&EU
M<U]S96YD7W)E<75E<W0H)')E<RD["@H@("`@("`@('-W:71C:"`H)'-U8V-E
M<W,I('L*("`@("`@("!C87-E(%)!1$E54U]!0T-%4U-?04-#15!4.@H@("`@
M("`@("`@("!R971U<FX@=')U93L*"B`@("`@("`@8V%S92!2041)55-?04-#
M15-37U)%2D5#5#H*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H
M05542%]214%33TY?34534T%'12P@7R@B075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BXB*2D["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M/E]S
M971!=71H17)R;W(H05542%]214%33TY?34534T%'12P@<F%D:75S7W-T<F5R
M<F]R*"1R97,I*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'``````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-C`Q,0`Q,#0Q-S,V,C<W,0`P,C`V,#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!!=71H7W-A<VPZ.B!C;&%S<R!P<F]V:61E<R!A(%-!4TPM8F%S
M960@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T
M:6]N('-Y<W1E;2X*("H*("H@4T%33"!I<R!T:&4@4VEM<&QE($%U=&AE;G1I
M8V%T:6]N(&%N9"!396-U<FET>2!,87EE<B`H87,@9&5F:6YE9"!B>2!21D,*
M("H@,C(R,BDN($ET('!R;W9I9&5S(&$@<WES=&5M(&9O<B!A9&1I;F<@<&QU
M9V%B;&4@875T:&5N=&EC871I;F<@<W5P<&]R="!T;PH@*B!C;VYN96-T:6]N
M+6)A<V5D('!R;W1O8V]L<RX*("H*("H@5&AI<R!D<FEV97(@<F5L:65S(&]N
M('1H92!014-,('-A<VP@<&%C:V%G93H*("H*("H@("`@("!H='1P.B\O<&5C
M;"YP:'`N;F5T+W!A8VMA9V4O<V%S;`H@*@H@*B!/<'1I;VYA;"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)V%P<"<@("`@("!4:&4@;F%M92!O9B!T:&4@875T
M:&5N=&EC871I;F<@87!P;&EC871I;VXN"B`J("`@("`@("`@("`@("!$149!
M54Q4.B!H;W)D90H@*B`@("=S97)V:6-E)R`@5&AE(&YA;64@;V8@=&AE(%-!
M4TP@<V5R=FEC92!T;R!U<V4@=VAE;B!A=71H96YT:6-A=&EN9RX*("H@("`@
M("`@("`@("`@($1%1D%53%0Z('!H<#PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`L=B`Q+C0N,3`N.2`R,#`V
M+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!*86X@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@
M*B\*8VQA<W,@075T:%]S87-L(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@
M("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R
M:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U
M<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A
M>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@4T%33"!A=71H96YT:6-A=&EO
M;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@075T:%]S87-L*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*"B`@
M("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=S87-L)RDI('L*("`@("`@
M("`@("`@9&PH)W-A<VPN<V\G*3L*("`@("`@("!]"@H@("`@("`@("1A<'`@
M/2`H(65M<'1Y*"1P87)A;7-;)V%P<"==*2D@/R`D<&%R86US6R=A<'`G72`Z
M("=H;W)D92<["B`@("`@("`@<V%S;%]S97)V97)?:6YI="@D87!P*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN
M(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO
M="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@
M('L*("`@("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E>'1E;G-I
M;VY?;&]A9&5D*"=S87-L)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*%\H(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1S97)V
M:6-E(#T@*"%E;7!T>2@D<&%R86US6R=S97)V:6-E)UTI*2`_("1P87)A;7-;
M)W-E<G9I8V4G72`Z("=P:'`G.PH@("`@("`@("1C;VYN(#T@<V%S;%]S97)V
M97)?;F5W*"1S97)V:6-E*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1C
M;VYN*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%S87-L7V-H96-K<&%S
M<R@D8V]N;BP@)'5S97))9"P@)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/
M3E]-15-304=%+"!S87-L7V5R<F1E=&%I;"@D8V]N;BDI.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]!=71H+W-M8BYP:'``````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#<Q,C8`,3`T,3<S-C(W-S$`,#(P-#,Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@075T:%]S;6(@8VQA<W,@<')O=FED97,@86X@4TU"(&EM<&QE
M;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T
M96TN"B`J"B`J(%1H:7,@;6]D=6QE(')E<75I<F5S('1H92!S;6)A=71H(&5X
M=&5N<VEO;B!F;W(@4$A0.@H@*B`@(&AT='`Z+R]W=W<N=&5K<F%T+F-O;2]S
M;6)A=71H+PH@*@H@*B!!="!T:&4@=&EM92!O9B!T:&ES('=R:71I;F<L('1H
M92!E>'1E;G-I;VXL(&%N9"!T:'5S('1H:7,@;6]D=6QE+"!O;FQY"B`J('-U
M<'!O<G1E9"!A=71H96YT:6-A=&EO;B!A9V%I;G-T(&$@9&]M86EN+"!A;F0@
M<&1C(&%N9"!B9&,@;75S="!B92!N;VXM;G5L;`H@*B!A;F0@;F]T(&5Q=6%L
M('1O(&5A8V@@;W1H97(N($EN(&]T:&5R('=O<F1S+"!T;R!U<V4@=&AI<R!M
M;V1U;&4@>6]U(&UU<W0*("H@:&%V92!A(&1O;6%I;B!W:71H(&%T(&QE87-T
M(&]N92!01$,@86YD(&]N92!"1$,N"B`J"B`J(%)E<75I<F5D('!A<F%M971E
M<G,Z/'!R93X*("H@("`G:&]S='-P96,G("!)4"P@1$Y3($YA;64L(&]R($YE
M=$)I;W,@3F%M92!O9B!T:&4@4TU"('-E<G9E<B!T;PH@*B`@("`@("`@("`@
M("`@(&%U=&AE;G1I8V%T92!W:71H+@H@*B`@("=D;VUA:6XG("`@(%1H92!D
M;VUA:6X@;F%M92!T;R!A=71H96YT:6-A=&4@=VET:"X\+W!R93X*("H*("H@
M3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=G<F]U<"<@("`@($=R
M;W5P(&YA;64@=&AA="!T:&4@=7-E<B!M=7-T(&)E(&$@;65M8F5R(&]F+B!7
M:6QL(&)E"B`J("`@("`@("`@("`@("`@:6=N;W)E9"!I9B!T:&4@=F%L=64@
M<&%S<V5D(&ES(&$@>F5R;R!L96YG=&@@<W1R:6YG+CPO<')E/@H@*@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<"QV(#$N,C`N
M,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36%R8W5S($DN(%)Y86X@/&UA<F-U<T!R
M:6)O9FQA=FEN+FYE=#X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO
M;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($UA<F-U<R!)
M+B!2>6%N(#QM87)C=7-`<FEB;V9L879I;BYN970^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H
M7W-M8B!E>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@
M;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R
M="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI
M8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=7!D871E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<@("`@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1S(&$@;F5W(%--0B!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@075T:%]S;6(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)W-M8F%U=&@G*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ9F%T86PH7R@B075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O*B!%;G-U<F4@=V4G=F4@
M8F5E;B!P<F]V:61E9"!W:71H(&%L;"!O9B!T:&4@;F5C97-S87)Y('!A<F%M
M971E<G,N("HO"B`@("`@("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D
M<&%R86US+"`G875T:"<L"B`@("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L
M("=D;VUA:6XG*2P*("`@("`@("`@("`@)V%U=&AE;G1I8V%T:6]N(%-A;6)A
M)RD["@H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*
M"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF('1H92!G:79E;B!S970@;V8@
M;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S
M97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@
M87)R87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT
M:6%L<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R
M961E;G1I86QS*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D8W)E9&5N=&EA
M;'-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?
M*").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@075T:&5N=&EC871E+B`J+PH@("`@("`@("1R=F%L(#T@=F%L:61A=&4H
M)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&]M86EN)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG9W)O=7`G72D@
M/R`G)R`Z("1T:&ES+3Y?<&%R86US6R=G<F]U<"==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'5S97))9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72D["@H@("`@("`@(&EF("@D<G9A
M;"`]/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!I9B`H)')V86P@/3T](#$I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%
M4U-!1T4L(%\H(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(BDI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'12P@97)R,G-T<B@I
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+W-Q;"YP:'``````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#`U,#0`,3`T,3<S
M-C(W-S$`,#(P-#0T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]S<6P@8VQA<W,@<')O
M=FED97,@82!344P@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U
M=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=P:'!T>7!E)R`@("`@(%1H92!D871A8F%S92!T>7!E
M("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P<F4^"B`J"B`J($]P
M=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G96YC<GEP=&EO;B<@("`@
M("`@("`@("`@5&AE(&5N8W)Y<'1I;VX@=&\@=7-E('1O('-T;W)E('1H92!P
M87-S=V]R9"!I;@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M=&%B;&4@*&4N9RX@<&QA:6XL(&-R>7!T+"!M9#4M:&5X+`H@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!M9#4M8F%S938T+"!S;60U+"!S:&$L('-S
M:&$L(&%P<FUD-2DN"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1%
M1D%53%0Z("=M9#4M:&5X)PH@*B`@("=S:&]W7V5N8W)Y<'1I;VXG("`@("`@
M("!7:&5T:&5R(&]R(&YO="!T;R!P<F5P96YD('1H92!E;F-R>7!T:6]N(&EN
M('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!P87-S=V]R9"!F
M:65L9"X*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@
M)V9A;'-E)PH@*B`@("=P87-S=V]R9%]F:65L9"<@("`@("`@("!4:&4@;F%M
M92!O9B!T:&4@<&%S<W=O<F0@9FEE;&0@:6X@=&AE(&%U=&@@=&%B;&4N"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=U<V5R7W!A
M<W,G"B`J("`@)W1A8FQE)R`@("`@("`@("`@("`@("`@(%1H92!N86UE(&]F
M('1H92!344P@=&%B;&4@=&\@=7-E(&EN("=D871A8F%S92<N"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=H;W)D95]U<V5R<R<*
M("H@("`G=7-E<FYA;65?9FEE;&0G("`@("`@("`@5&AE(&YA;64@;V8@=&AE
M('5S97)N86UE(&9I96QD(&EN('1H92!A=71H('1A8FQE+@H@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G=7-E<E]U:60G"B`J("`@
M)W-O9G1?97AP:7)A=&EO;E]F:65L9"<@(%1H92!N86UE(&]F('1H92!F:65L
M9"!C;VYT86EN:6YG(&$@9&%T92!A9G1E<@H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!W:&EC:"!T:&4@<WES=&5M('=I;&P@<F5Q=65S="!T:&4@
M=7-E<B!C:&%N9V4@:&ES"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&]R(&AE<B!P87-S=V]R9"X*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1$5&055,5#H@;F]N90H@*B`@("=H87)D7V5X<&ER871I;VY?9FEE;&0G
M("!4:&4@;F%M92!O9B!T:&4@9FEE;&0@8V]N=&%I;FEN9R!A(&1A=&4@869T
M97(*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VAI8V@@=&AE(&%C
M8V]U;G0@:7,@;F\@;&]N9V5R('9A;&ED(&%N9"!T:&4@=7-E<@H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!W:6QL(&YO="!B92!A8FQE('1O(&QO
M9R!I;B!A="!A;&PN"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1%
M1D%53%0Z(&YO;F4\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A
M8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`G:&]S='-P96,G("`@
M("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G
M<')O=&]C;VPG("`@("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C
M<"<L("=U;FEX)RP@971C+BDN"B`J("`@)V1A=&%B87-E)R`@("`@5&AE(&YA
M;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=U<V5R;F%M92<@("`@(%1H92!U
M<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E
M+@H@*B`@("=P87-S=V]R9"<@("`@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D
M('=I=&@@)W5S97)N86UE)RX*("H@("`G;W!T:6]N<R<@("`@("!!9&1I=&EO
M;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!O
M<G0G("`@("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T
M:&4@9&%T86)A<V4N"B`J("`@)W1T>2<@("`@("`@("`@5&AE(%1462!O;B!W
M:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X\+W!R93X*("H*("H@
M5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE($%U=&@@<WES=&5M(&ES(&EN
M"B`J('-C<FEP=',O<W%L+VAO<F1E7W5S97)S+G-Q;"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`L=B`Q+C8Y+C$P+C$X(#(P
M,#8O,#$O,3@@,3DZ,S4Z-34@8F5N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K
M86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?<W%L(&5X=&5N9',@075T
M:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L
M('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O
M<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A
M8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@=')U92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^
M('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A
M<W-W;W)D)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F5M;W9E)R`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^('1R=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS
M92D["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A
M=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@
M("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J($)O;VQE86X@:6YD
M:6-A=&EN9R!W:&5T:&5R(&]R(&YO="!W92=R92!C;VYN96-T960@=&\@=&AE
M(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T<R!A(&YE=R!344P@875T:&5N=&EC871I;VX@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@
M8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($%U=&A?<W%L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O
M*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I
M86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@
M=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT
M:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L
M<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A
M=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("\J(%]C
M;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A
M:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@
M("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@
M<W!R:6YT9B@G4T5,14-4("H@1E)/32`E<R!72$5212`E<R`](#\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E
M<FYA;65?9FEE;&0G72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1U<V5R
M260I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y
M($%U=&A?<W%L.CI?875T:&5N=&EC871E*"DZ("<@+B`D<75E<GDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T9!24Q%
M1"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]'151-3T1%7T%34T]#
M*3L*("`@("`@("!I9B`H:7-?87)R87DH)')O=RDI('L*("`@("`@("`@("`@
M)')E<W5L="T^9G)E92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T)!1$Q/1TE.*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"$D=&AI<RT^7V-O;7!A<F5087-S=V]R9',H)')O=ULD=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F1?9FEE;&0G75TL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/
M3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("1N;W<@/2!T:6UE*"D["B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7V9I96QD)UTI("8F
M"B`@("`@("`@("`@("%E;7!T>2@D<F]W6R1T:&ES+3Y?<&%R86US6R=H87)D
M7V5X<&ER871I;VY?9FEE;&0G75TI("8F"B`@("`@("`@("`@("@D;F]W(#X@
M)')O=ULD=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7V9I96QD)UU=
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%
M05-/3E]%6%!)4D5$*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<V]F
M=%]E>'!I<F%T:6]N7V9I96QD)UTI("8F"B`@("`@("`@("`@("%E;7!T>2@D
M<F]W6R1T:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G75TI
M("8F"B`@("`@("`@("`@("@D;F]W(#X@)')O=ULD=&AI<RT^7W!A<F%M<ULG
M<V]F=%]E>'!I<F%T:6]N7V9I96QD)UU=*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V%U=&A#<F5D96YT:6%L<ULG8VAA;F=E4F5Q=65S=&5D)UT@/2!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N
M=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@
M("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@87)R87D@)&-R
M961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@861D+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,
M('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)TE.4T525"!)
M3E1/("5S("@E<RP@)7,I(%9!3%5%4R`H/RP@/RDG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE
M;&0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9%]F:65L9"==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH
M)'5S97))9"P*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$-R
M>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*3L*"B`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!=71H7W-Q;#HZ861D
M57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R
M961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9$E$
M("`@("`@("!4:&4@;VQD('5S97))9"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YE=TE$("`@("`@("!4:&4@;F5W('5S97))9"X*("`@("`J($!P87)A;2!A
M<G)A>2`@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I86QS
M*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(
M;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M
M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN
M("HO"B`@("`@("`@)'1U<&QE(#T@87)R87DH*3L*("`@("`@("`D='5P;&5;
M)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UU=(#T@)&YE=TE$.PH@
M("`@("`@("1T=7!L95LD=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G
M75T@/0H@("`@("`@("`@("`D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C
M<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72D["@H@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG<V]F=%]E>'!I<F%T:6]N7W=I;F1O=R==*2D@
M>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=S;V9T
M7V5X<&ER871I;VY?9FEE;&0G72DI('L*("`@("`@("`@("`@("`@("1T=7!L
M95LD=&AI<RT^7W!A<F%M<ULG<V]F=%]E>'!I<F%T:6]N7V9I96QD)UU=(#T@
M;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1D871E(#T@=&EM92@I.PH@("`@("`@("`@("`D9&%T96$@/2!L;V-A
M;'1I;64H)&1A=&4L('1R=64I.PH@("`@("`@("`@("`D9&%T92`](&UK=&EM
M92@D9&%T96%;)W1M7VAO=7(G72P@)&1A=&5A6R=T;5]M:6XG72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1A=&5A6R=T;5]S96,G72P@)&1A=&5A
M6R=T;5]M;VXG72`K(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M871E85LG=&U?;61A>2==("L@)'1H:7,M/E]P87)A;7-;)W-O9G1?97AP:7)A
M=&EO;E]W:6YD;W<G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&5A6R=T;5]Y96%R)UTI.PH*("`@("`@("`@("`@)'1U<&QE6R1T:&ES+3Y?
M<&%R86US6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G75T@/2`D9&%T93L*"B`@
M("`@("`@("`@(&=L;V)A;"`D;F]T:69I8V%T:6]N.PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1N;W1I9FEC871I;VXI*2!["B`@("`@("`@("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-T<F9T:6UE*%\H(DYE=R!P87-S=V]R9"!W
M:6QL(&5X<&ER92!O;B`E>"XB*2P@)&1A=&4I+"`G:&]R9&4N;65S<V%G92<I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]P87)A;7-;)VAA<F1?97AP:7)A=&EO;E]W:6YD;W<G72DI('L*("`@("`@
M("`@("`@("`@("1T=7!L95LD=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T
M:6]N7V9I96QD)UU=(#T@;G5L;#L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1D871E82`](&QO8V%L=&EM92@D9&%T92P@=')U92D[
M"B`@("`@("`@("`@("`@("`D9&%T92`](&UK=&EM92@D9&%T96%;)W1M7VAO
M=7(G72P@)&1A=&5A6R=T;5]M:6XG72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D871E85LG=&U?<V5C)UTL("1D871E85LG=&U?;6]N)UT@
M*R`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5A6R=T
M;5]M9&%Y)UT@*R`D=&AI<RT^7W!A<F%M<ULG<V]F=%]E>'!I<F%T:6]N7W=I
M;F1O=R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5A
M6R=T;5]Y96%R)UTI.PH*("`@("`@("`@("`@("`@("1T=7!L95LD=&AI<RT^
M7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7V9I96QD)UU=(#T@)&1A=&4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4U%,+G!H<"<["B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G55!$
M051%("5S(%-%5"`E<R!72$5212`E<R`](#\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("!(;W)D95]344PZ.G5P9&%T959A;'5E<R@D=&AI<RT^
M7V1B+"`D='5P;&4I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@("1V86QU97,@
M/2!A<G)A>2@D;VQD240I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M4U%,(%%U97)Y(&)Y($%U=&A?<W%L.G5P9&%T955S97(H*3H@)R`N("1Q=65R
M>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU
M97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5S970@82!U<V5R)W,@<&%S<W=O
M<F0N(%5S960@9F]R(&5X86UP;&4@=VAE;B!T:&4@=7-E<B!D;V5S(&YO=`H@
M("`@("H@<F5M96UB97(@=&AE(&5X:7-T:6YG('!A<W-W;W)D+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97)?:60@(%1H92!U<V5R(&ED(&9O
M<B!W:&EC:"!T;R!R97-E="!T:&4@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AE(&YE=R!P87-S=V]R9"!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX*("`@("`J("`@("`@("`@("`@("`@
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T4&%S<W=O<F0H
M)'5S97)?:60I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I
M92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@
M("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@1V5T(&$@;F5W(')A
M;F1O;2!P87-S=V]R9"X@*B\*("`@("`@("`D<&%S<W=O<F0@/2!!=71H.CIG
M96Y286YD;VU087-S=V]R9"@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,
M('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U501$%412`E
M<R!3150@)7,@/2`_(%=(15)%("5S(#T@/R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S
M97)N86UE7V9I96QD)UTI.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI
M<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1P87-S=V]R9"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("1U<V5R7VED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-13"!1=65R>2!B>2!!=71H7W-Q;#HZ<F5S971087-S=V]R9"@I.B`G("X@
M)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@
M)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<&%S<W=O<F0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA
M;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@
M=7-E<DED('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@("`@("`@(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@("\J(%]C
M;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A
M:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@
M("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@
M<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@)7,@/2`_)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N
M86UE7V9I96QD)UTI.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D=7-E<DED
M*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!
M=71H7W-Q;#HZ<F5M;W9E57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^<F5M;W9E57-E<D1A=&$H)'5S97))9"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T:&4@<WES=&5M+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O
M<B!F86QS92!O;B!F86EL=7)E+W5N<W5P<&]R=&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T
M*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N
M("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U
M:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G4T5,14-4("5S($923TT@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D["@H@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@075T:%]S
M<6PZ.FQI<W15<V5R<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&(M/F=E=$-O;"@D<75E<GDI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VMS(&EF(&$@=7-E<DED(&5X:7-T<R!I;B!T:&4@<VES=&5M+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE('5S
M97))9"!A;')E861Y(&5X:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@97AI
M<W1S*"1U<V5R260I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL
M(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@
M("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE
M(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%
M0U0@)7,@1E)/32`E<R!72$5212`E<R`](#\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U
M<V5R;F%M95]F:65L9"==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)'5S
M97))9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@
M8GD@075T:%]S<6PZ.F5X:7-T<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&(M/F=E=$]N92@D<75E<GDL("1V86QU97,I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]M<&%R92!A;B!E;F-R>7!T960@<&%S<W=O<F0@=&\@
M82!P;&%I;G1E>'0@<W1R:6YG('1O('-E92!I9@H@("`@("H@=&AE>2!M871C
M:"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;F-R>7!T960@(%1H
M92!C<GEP=&5D('!A<W-W;W)D('1O(&-O;7!A<F4@86=A:6YS="X*("`@("`J
M($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@5&AE('!L86EN=&5X="!P87-S
M=V]R9"!T;R!V97)I9GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF(&UA=&-H960L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-O;7!A<F5087-S=V]R9',H)&5N8W)Y<'1E9"P@)'!L
M86EN=&5X="D*("`@('L*("`@("`@("!R971U<FX@)&5N8W)Y<'1E9"`]/2`D
M=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1P;&%I;G1E>'0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D96YC<GEP=&5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y
M<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y
M<'1I;VXG72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O
M<&5N(&$@8V]N;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.F%S
M<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@)V%U=&@G+"!A<G)A
M>2@G<&AP='EP92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V%U=&AE;G1I8V%T:6]N(%-13"<I.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72`]("<G.PH@("`@("`@('T*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G
M.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M<&%S<W=O<F0G72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72`]("<G.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72`]
M("=M9#4M:&5X)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72`](&9A;'-E.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M(#T@)VAO<F1E7W5S97)S)SL*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72`]("=U<V5R
M7W5I9"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W5S97)N86UE7V9I96QD)UT@/2!3=')I;F<Z.FQO=V5R*"1T:&ES
M+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE
M;&0G72`]("=U<V5R7W!A<W,G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==(#T@4W1R:6YG
M.CIL;W=E<B@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72D["B`@
M("`@("`@?0H*("`@("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R
M('5S:6YG('1H92!S=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@(&EN
M8VQU9&5?;VYC92`G1$(N<&AP)SL*("`@("`@("`D=&AI<RT^7V1B(#T@)D1"
M.CIC;VYN96-T*"1T:&ES+3Y?<&%R86US+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==*2DI.PH@("`@("`@(&EF("AI
M<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M2&]R9&4Z.F9A=&%L*%\H(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("`O+R!3970@1$(@<&]R=&%B:6QI='D@;W!T:6]N<RX*("`@("`@("!S=VET
M8V@@*"1T:&ES+3Y?9&(M/G!H<'1Y<&4I('L*("`@("`@("!C87-E("=M<W-Q
M;"<Z"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B
M:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))
M3$E465]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D["B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES
M+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E4
M65],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!T<G5E.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O>6%H;V\N<&AP````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3`V,``Q,#0Q-S,V,C<W,0`P
M,C`W-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!!=71H7WEA:&]O.CH@8VQA<W,@8VAE8VMS
M(&QO9VEN(&-R961E;G1I86QS(&%G86EN<W0@66%H;V\A(&UA:6P*("H@86-C
M;W5N=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]Y86AO
M;RYP:'`L=B`Q+C$S+C$R+C<@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E('EA:&]O.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S
M($%U=&A?>6%H;V\@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($!V
M87(@2%144%]297%U97-T"B`@("`@*B\*("`@('9A<B`D7VAT='`["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%EA:&]O(&%U=&AE;G1I8V%T
M:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@075T:%]Y86AO;R@D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT
M:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@(%1H
M92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@("1C<F5D
M96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT
M:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT
M:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92`G2%144"]297%U97-T+G!H<"<["@H@("`@("`@("\O($UA
M:V4@<W5R92!T:&%T('=E(&AA=F4@82!B87)E('5S97)N86UE("T@<W1R:7`@
M;V9F(&%N>71H:6YG"B`@("`@("`@+R\@869T97(@*&%N9"!I;F-L=61I;F<I
M('1H92!F:7)S="!`+"!I9B!T:&5R92!I<R!O;F4N"B`@("`@("`@)'!O<R`]
M('-T<G!O<R@D=7-E<DED+"`G0"<I.PH@("`@("`@(&EF("@D<&]S("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`D=7-E<DED(#T@<W5B<W1R*"1U<V5R260L
M(#`L("1P;W,I.PH@("`@("`@('T*"B`@("`@("`@)&]P=&EO;G-;)VUE=&AO
M9"==(#T@2%144%]215%515-47TU%5$A/1%]03U-4.PH@("`@("`@("1O<'1I
M;VYS6R=T:6UE;W5T)UT@/2`U.PH@("`@("`@("1O<'1I;VYS6R=A;&QO=U)E
M9&ER96-T<R==(#T@=')U93L*"B`@("`@("`@)'1H:7,M/E]H='1P(#T@)FYE
M=R!(5%107U)E<75E<W0H)VAT='`Z+R]L;V=I;BYY86AO;RYC;VTO8V]N9FEG
M+VQO9VEN)RP@)&]P=&EO;G,I.PH@("`@("`@("1T:&ES+3Y?:'1T<"T^861D
M4&]S=$1A=&$H)VQO9VEN)RP@)'5S97))9"D["B`@("`@("`@)'1H:7,M/E]H
M='1P+3YA9&10;W-T1&%T82@G<&%S<W=D)RP@)&-R961E;G1I86QS6R=P87-S
M=V]R9"==*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:'1T<"T^<V5N
M9%)E<75E<W0H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D<F5S=6QT+3YG971-
M97-S86=E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"D["B`@("`@("`@
M("`@("1C;V]K:65S(#T@)'1H:7,M/E]H='1P+3YG971297-P;VYS94-O;VMI
M97,H*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1C;V]K:65S*2D@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&-O;VMI97,@87,@)&-O;VMI92D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:'1T<"T^861D0V]O:VEE
M*"1C;V]K:65;)VYA;64G72P@)&-O;VMI95LG=F%L=64G72D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M(%1H:7,@:7,@7W-U8VA?(&$@:&%C:RP@8G5T(&ET('=O<FMS+@H@("`@("`@
M(&EF("@A<')E9U]M871C:"@G?&EN=F%L:60@<&%S<W=O<F1\:2<L("1R97-U
M;'0I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@
M("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)3BD[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O5&]K96XO````````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<Q`#`Q-S,Q,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4;VME;B]F:6QE+G!H<```````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`V-#0`,3`T,3<S-C(W-S$`
M,#(P-S0U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4;VME;B!T<F%C:VEN9R!I;7!L96UE;G1A=&EO
M;B!F;W(@;&]C86P@9FEL97,N"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z
M/'!R93X*("H@("`G=&]K96Y?9&ER)R`@5&AE(&1I<F5C=&]R>2!W:&5R92!T
M;R!K965P('1O:V5N(&9I;&5S+@H@*B`@("=T:6UE;W5T)R`@("!4:&4@<&5R
M:6]D("AI;B!S96-O;F1S*2!A9G1E<B!W:&EC:"!A;B!I9"!I<R!P=7)G960N
M"B`J("`@("`@("`@("`@("`@($1E9F%U;'1S('1O(#@V-#`P("AI+F4N(#(T
M(&AO=7)S*2X\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&]K96XO
M5&]K96XO9FEL92YP:'`L=B`Q+C$Y+C8N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C,Y
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($UA>"!+86QI
M:V$@/&UA>$!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-87@@2V%L:6MA(#QM87A`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?5&]K96X*("HO"F-L87-S($AO<F1E
M7U1O:V5N7V9I;&4@97AT96YD<R!(;W)D95]4;VME;B!["@H@("`@+RHJ"B`@
M("`@*B!(86YD;&4@9F]R('1H92!O<&5N(&9I;&4@9&5S8W)I<'1O<BX*("`@
M("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V9D
M(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@
M=VAE=&AE<B!O<B!N;W0@=V4@:&%V92!A;B!O<&5N(&9I;&4@9&5S8W)I<'1O
M<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@
M82!N97<@9FEL92!B87-E9"!T;VME;BUT<F%C:VEN9R!C;VYT86EN97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG('-T;W)A9V4@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?5&]K96Y?9FEL92@D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["@H@("`@("`@("\J
M($-H;V]S92!T:&4@9&ER96-T;W)Y('1O('-A=F4@=&AE('-T=6(@9FEL97,N
M("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?
M9&ER)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T;VME;E]D
M:7(G72`](%5T:6PZ.F=E=%1E;7!$:7(H*3L*("`@("`@("!]"@H@("`@("`@
M("\J(%-E="!T:6UE;W5T('1O(#(T(&AO=7)S(&EF(&YO="!S<&5C:69I960N
M("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&EM96]U
M="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==
M(#T@.#8T,#`["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L
M971E<R!A;&P@97AP:7)E9"!C;VYN96-T:6]N(&ED)W,@9G)O;2!T:&4@4U%,
M('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5')U92!O
M;B!S=6-C97-S+"!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('!U<F=E*"D*("`@('L*("`@("`@("`O+R!-
M86ME('-U<F4@=V4@:&%V92!N;R!O<&5N(&9I;&4@9&5S8W)I<'1O<G,@8F5F
M;W)E('5N;&EN:VEN9PH@("`@("`@("\O(&9I;&5S+@H@("`@("`@(&EF("@A
M)'1H:7,M/E]D:7-C;VYN96-T*"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)U5N86)L92!T;R!C;&]S92!F:6QE(&1E<V-R:7!T
M;W)S)RD["B`@("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!S='5B(&9I;&4@
M;&ES="X@*B\*("`@("`@("!I9B`H(2@D9&ER(#T@;W!E;F1I<B@D=&AI<RT^
M7W!A<F%M<ULG=&]K96Y?9&ER)UTI*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G56YA8FQE('1O(&]P96X@=&]K96X@9&ER96-T
M;W)Y)RD["B`@("`@("`@?0H*("`@("`@("`O*B!&:6YD(&5X<&ER960@<W1U
M8B!F:6QE<R`J+PH@("`@("`@('=H:6QE("@H)&1I<D5N=')Y(#T@<F5A9&1I
M<B@D9&ER*2D@(3T@)R<I('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)WQ>8V]N;E]<=WLX?21\)RP@)&1I<D5N=')Y*2`F)B`H=&EM92@I("T@9FEL
M96UT:6UE*"1T:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G72`N("<O)R`N("1D
M:7)%;G1R>2D@/CT@)'1H:7,M/E]P87)A;7-;)W1I;65O=70G72DI('L*("`@
M("`@("`@("`@("`@(&EF("@A0'5N;&EN:R@D=&AI<RT^7W!A<F%M<ULG=&]K
M96Y?9&ER)UT@+B`G+R<@+B`D9&ER16YT<GDI*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N86)L92!T;R!P=7)G
M92!T;VME;B!F:6QE+B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!C;&]S961I<B@D9&ER*3L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!E>&ES=',H)'1O
M:V5N240I"B`@("!["B`@("`@("`@:68@*&ES7V$H*"1R97-U;'0@/2`D=&AI
M<RT^7V-O;FYE8W0H)'1O:V5N240I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J
M($9I;F0@86QR96%D>2!U<V5D($E$<RX@*B\*("`@("`@("`D9FEL94-O;G1E
M;G1S(#T@0&9I;&4H)'1H:7,M/E]P87)A;7-;)W1O:V5N7V1I<B==("X@)R]C
M;VYN7R<@+B`D=&AI<RT^96YC;V1E4F5M;W1E061D<F5S<R@I*3L*("`@("`@
M("!I9B`H)&9I;&5#;VYT96YT<RD@>PH@("`@("`@("`@("`D:4UA>"`](&-O
M=6YT*"1F:6QE0V]N=&5N=',I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D:4UA>#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*&-H;W`H
M)&9I;&5#;VYT96YT<ULD:5TI(#T]("1T;VME;DE$*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("!F=6YC=&EO;B!A9&0H)'1O:V5N240I"B`@("!["B`@("`@("`@
M:68@*&ES7V$H*"1R97-U;'0@/2`D=&AI<RT^7V-O;FYE8W0H)'1O:V5N240I
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@("\J(%=R:71E('1H92!E;G1R>2X@*B\*
M("`@("`@("!F=W)I=&4H)'1H:7,M/E]F9"P@(B1T;VME;DE$7&XB*3L*"B`@
M("`@("`@+RH@4F5T=7)N(&%N(&5R<F]R(&EF('1H92!U<&1A=&4@9F%I;',L
M('1O;RX@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?9&ES8V]N;F5C="@I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@
M=&\@8VQO<V4@=&]K96X@9FEL92!C;&5A;FQY+B<I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N
M<R!A(&9I;&4@9&5S8W)I<'1O<B!T;R!A(&YE=R!O<B!E>&ES=&EN9R!F:6QE
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;VYN96-T*"1T;VME;DE$*0H@("`@>PH@("`@("`@
M(&EF("@A)'1H:7,M/E]C;VYN96-T960I('L*"B`@("`@("`@("`@("\O($]P
M96X@82!F:6QE(&1E<V-R:7!T;W(@=&\@=&AE('1O:V5N('-T=6(@9FEL92X*
M("`@("`@("`@("`@)'1H:7,M/E]F9"`]($!F;W!E;B@D=&AI<RT^7W!A<F%M
M<ULG=&]K96Y?9&ER)UT@+B`G+V-O;FY?)R`N("1T:&ES+3YE;F-O9&5296UO
M=&5!9&1R97-S*"DL("=A)RD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]F
M9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T9A:6QE9"!T;R!O<&5N('1O:V5N(&9I;&4N)RD["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VQO<V5S('1H92!F:6QE(&1E<V-R:7!T;W(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@
M("`@)'1H:7,M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T
M=7)N(&9C;&]S92@D=&AI<RT^7V9D*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U1O:V5N+W-Q;"YP:'``````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q-#(T,``Q,#0Q-S,V,C<W,0`P,C`V,C$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1O:V5N('1R86-K:6YG(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G
M<R!014%2(&1A=&%B87-E(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U
M:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A
M=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X\+W!R
M93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A
M=&EO;G,Z/'!R93X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@
M9&%T86)A<V4N"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H
M92!D871A8F%S92!S97)V97(N"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N
M86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J
M("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G
M=7-E<FYA;64G+@H@*B`@("=O<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N
M<R!T;R!P87-S('1O('1H92!D871A8F%S92X*("H@("`G='1Y)R`@("`@("!4
M:&4@5%19(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@
M*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)W1A8FQE)R`@("`@5&AE(&YA;64@;V8@=&AE('1O
M:V5N<R!T86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@("`@($1E
M9F%U;'1S('1O("=H;W)D95]T;VME;G,G+@H@*B`@("=T:6UE;W5T)R`@(%1H
M92!P97)I;V0@*&EN('-E8V]N9',I(&%F=&5R('=H:6-H(&%N(&ED(&ES('!U
M<F=E9"X*("H@("`@("`@("`@("`@("!$969A=6QT<R!T;R`X-C0P,"`H:2YE
M+B`R-"!H;W5R<RDN/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@
M9F]R('1H92!T;VME;G,@:7,@87,@9F]L;&]W<SH*("H*("H@/'!R93X*("H@
M0U)%051%(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`J("`@("!T;VME;E]A9&1R
M97-S("`@(%9!4D-(05(H,3`P*2!.3U0@3E5,3"P*("H@("`@('1O:V5N7VED
M("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`J("`@("!T;VME;E]T
M:6UE<W1A;7`@($))1TE.5"!.3U0@3E5,3"P*("H*("H@("`@(%!224U!4ED@
M2T59("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D*("H@*3L*("H@/"]P<F4^
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1O:V5N+U1O:V5N+W-Q;"YP:'`L
M=B`Q+C(S+C8N,3(@,C`P-B\P,2\Q."`Q.3HT,#HU,2!B96X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!-87@@2V%L:6MA(#QM87A`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%X($MA;&EK82`\
M;6%X0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K
M86=E($AO<F1E7U1O:V5N"B`J+PIC;&%S<R!(;W)D95]4;VME;E]S<6P@97AT
M96YD<R!(;W)D95]4;VME;B!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R
M('1H92!C=7)R96YT(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@
M("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@)%]D8B`]("<G.PH*("`@("\J
M*@H@("`@("H@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E
M)W)E(&-O;FYE8W1E9"!T;R!T:&4@4U%,"B`@("`@*B!S97)V97(N"B`@("`@
M*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE
M8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!344P@8V]N;F5C=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@
M<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5&]K96Y?
M<W%L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@)'!A<F%M<SL*"B`@("`@("`@+RH@4V5T('1I;65O=70@=&\@
M,C0@:&]U<G,@:68@;F]T('-P96-I9FEE9"X@*B\*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T:6UE;W5T)UT@/2`X-C0P,#L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%L;"!E>'!I<F5D(&-O
M;FYE8W1I;VX@:60G<R!F<F]M('1H92!344P@<V5R=F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!U<F=E*"D*("`@('L*("`@("`@("!I9B`H:7-?82@H)')E<W5L="`]("1T
M:&ES+3Y?8V]N;F5C="@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($)U:6QD
M(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@
M)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@)R!72$5212`G.PH@("`@
M("`@("1Q=65R>2`N/2`G=&]K96Y?=&EM97-T86UP(#P@/R<["@H@("`@("`@
M("1V86QU97,@/2!A<G)A>2AT:6UE*"D@+2`D=&AI<RT^7W!A<F%M<ULG=&EM
M96]U="==*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@("\J(%)E='5R;B!A;B!E<G)O
M<B!I9B!T:&4@=7!D871E(&9A:6QS+"!T;V\N("HO"B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&5X:7-T<R@D=&]K96Y)1"D*("`@('L*("`@
M("`@("!I9B`H:7-?82@H)')E<W5L="`]("1T:&ES+3Y?8V]N;F5C="@I*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!344P@<75E<GDN("HO"B`@("`@
M("`@)'%U97)Y("`]("=314Q%0U0@=&]K96Y?:60@1E)/32`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UT["B`@("`@("`@)'%U97)Y("X]("<@5TA%4D4@
M=&]K96Y?861D<F5S<R`](#\G.PH@("`@("`@("1Q=65R>2`N/2`G($%.1"!T
M;VME;E]I9"`](#\G.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M
M/F5N8V]D95)E;6]T94%D9')E<W,H*2P@)'1O:V5N240I.PH*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("%E;7!T>2@D<F5S=6QT*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@861D*"1T;VME;DE$*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A*"@D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T*"DI+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0G5I;&0@4U%,('%U97)Y+B`J+PH@("`@("`@
M("1Q=65R>2`@/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R86US6R=T
M86)L92==("X@)R`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60L('1O:V5N7W1I
M;65S=&%M<"D@)SL*("`@("`@("`D<75E<GD@+CT@)U9!3%5%4R`H/RP@/RP@
M/RDG.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/F5N8V]D95)E
M;6]T94%D9')E<W,H*2P@)'1O:V5N240L('1I;64H*2D["@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS(&$@8V]N
M;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C
M="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)')E
M<W5L="`](%5T:6PZ.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M
M<RP@87)R87DH)W!H<'1Y<&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T;VME;B!344PG+"!A<G)A>2@G9')I=F5R
M)R`]/B`G=&]K96XG*2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1A
M=&%B87-E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D871A
M8F%S92==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@?0H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==(#T@)R<["B`@
M("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)VAO
M<W1S<&5C)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T
M<W!E8R==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==(#T@)VAO<F1E7W1O:V5N<R<["B`@("`@("`@?0H*
M("`@("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H
M92!S=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@(')E<75I<F5?;VYC
M92`G1$(N<&AP)SL*("`@("`@("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T
M*"1T:&ES+3Y?<&%R86US+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A
M<F%M<ULG<&5R<VES=&5N="==*2DI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES
M+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&(["B`@("`@("`@?0H*("`@("`@("`O+R!3970@1$(@<&]R=&%B
M:6QI='D@;W!T:6]N<RX*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/G!H
M<'1Y<&4I('L*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("1T
M:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))
M3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$0E]0
M3U)404))3$E465]25%))32D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G
M<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]0
M3U)404))3$E465]%4E)/4E,I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]C;VYN96-T960@/2!T<G5E.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@4U%,('-E
M<G9E<B!A;F0@8VQE86X@=7`@=&AE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE
M8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E
M.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I;&4O````````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-S$`,#$W-#0R`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO
M8FEL92]296YD97)E<B\`````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<W,0`P,C$R,3``(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O36]B:6QE+U)E;F1E<F5R+VAT;6PN<&AP````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#(V-#<P`#$P-#$W,S8R-S<Q`#`R,C8W,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@2&]R9&5?36]B:6QE7U)E;F1E<F5R.CH@;W5T<'5T(&UO9'5L
M92!F;W(@<VEM<&QE($A434P@86YD"B`J($EM;V1E+T%V86YT9V\O<VEM:6QA
M<B!D979I8V5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-;V)I;&4O36]B
M:6QE+U)E;F1E<F5R+VAT;6PN<&AP+'8@,2XR."XQ,"XV(#(P,#8O,#$O,#$@
M,C$Z,C@Z,C8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7U)E;F1E<F5R7VAT;6P@
M97AT96YD<R!(;W)D95]-;V)I;&5?4F5N9&5R97(@>PH*("`@("\J*@H@("`@
M("H@4')O<&5R;'D@96YC;V1E(&-H87)A8W1E<G,@9F]R(&]U='!U="!T;R!A
M;B!(5$U,(&)R;W=S97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:6YP=70@($-H87)A8W1E<G,@=&\@96YC;V1E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@96YC;V1E9"!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!E<V-A<&4H)&EN<'5T*0H@("`@>PH@("`@("`@(')E='5R;B!`
M:'1M;'-P96-I86QC:&%R<R@D:6YP=70L($5.5%]#3TU0050L($Y,4SHZ9V5T
M0VAA<G-E="@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@=&AE
M('!A9V4@:6X@=&AE(&%P<')O<')I871E(&UA<FMU<"X@1&5P96YD:6YG(&]N
M('1H90H@("`@("H@8VQI96YT<R!B<F]W<V5R('1Y<&4@<'5R92!(5$U,+"!H
M86YD:&5L9&9R:65N9&QY($%V86YT1V\@2%1-3"P*("`@("`J(&DM;6]D92!C
M2%1-3"P@;W(@34U,(&ES(&-R96%T960N"B`@("`@*@H@("`@("H@0'!A<F%M
M($AO<F1E7TUO8FEL92`D9&5C:R`@5&AE(&1E8VL@=&\@<F5N9&5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96YD97(H)B1D96-K*0H@("`@>PH@("`@("`@
M(&EF("@D9&5C:RT^7V1E8G5G*2!["B`@("`@("`@("`@(&AE861E<B@G0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H
M87)S970H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:&5A9&5R
M*"=#;VYT96YT+51Y<&4Z('1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG
M971#:&%R<V5T*"DI.PH@("`@("`@('T*("`@("`@("!H96%D97(H)U9A<GDZ
M($%C8V5P="U,86YG=6%G92<I.PH*("`@("`@("!I9B`H(21T:&ES+3YI<T)R
M;W=S97(H)VUM;"<I*2!["B`@("`@("`@("`@(&5C:&\@(CPA1$]#5%E012!H
M=&UL(%!50DQ)0R!<(BTO+U<S0R\O1%1$($A434P@-"XP(%1R86YS:71I;VYA
M;"\O14Y<(CY<;B(["B`@("`@("`@?0H*("`@("`@("!E8VAO("%E;7!T>2@D
M1TQ/0D%,4ULG;&%N9W5A9V4G72D@/R`G/&AT;6P@;&%N9STB)R`N('-T<G1R
M*"1'3$]"04Q36R=L86YG=6%G92==+"`G7R<L("<M)RD@+B`G(CXG(#H@)SQH
M=&UL/B<["B`@("`@("`@96-H;R`G/&AE860^)SL*"B`@("`@("`@:68@*"1T
M:&ES+3YI<T)R;W=S97(H)V%V86YT9V\G*2D@>PH@("`@("`@("`@("!E8VAO
M("<\;65T82!N86UE/2)(86YD:&5L9$9R:65N9&QY(B!C;VYT96YT/2)4<G5E
M(CXG.PH@("`@("`@('T*"B`@("`@("`@<')I;G1F*"(\=&ET;&4^)7,\+W1I
M=&QE/EQN(BP@)'1H:7,M/F5S8V%P92@D9&5C:RT^9V5T*"=T:71L92<I*2D[
M"@H@("`@("`@(&EF("@D9&5C:RT^7W-I;75L871O<BD@>PH@("`@("`@("`@
M("`O+R!5<V4@<VEM=6QA=&]R("AM;V)I;&4@=&AE;64I('-T>6QE<VAE970N
M"B`@("`@("`@("`@(&5C:&\@2&]R9&4Z.G-T>6QE<VAE971,:6YK*"=H;W)D
M92<L("=M;V)I;&4G*3L*("`@("`@("!]"@H@("`@("`@(&5C:&\@)SPO:&5A
M9#X\8F]D>3XG.PH*("`@("`@("!I9B`H)&1E8VLM/E]S:6UU;&%T;W(I('L*
M("`@("`@("`@("`@96-H;R`B/&-E;G1E<CX\8G(@+SY<;B(["B`@("`@("`@
M("`@("\O($-R96%T92!D969A=6QT(&1E=FEC92!S:6UU;&%T;W(@=&%B;&4@
M;&%Y;W5T('=I=&@*("`@("`@("`@("`@+R\@8V5N=')A;"!#4U,@;&%Y;W5T
M+@H@("`@("`@("`@("!E8VAO("(\=&%B;&4@8F]R9&5R/5PB,%PB(&-E;&QP
M861D:6YG/5PB,%PB(&-E;&QS<&%C:6YG/5PB,%PB/EQN(CL*("`@("`@("`@
M("`@96-H;R`B/'1R/CQT9"!C;VQS<&%N/5PB,UPB(&-L87-S/5PB=&]P7"(^
M)FYB<W`[/"]T9#X\+W1R/EQN(CL*("`@("`@("`@("`@96-H;R`B/'1R/CQT
M9"!V86QI9VX]7")T;W!<(B!C;&%S<SU<(FQE9G1<(CXF;F)S<#L\+W1D/EQN
M(CL*("`@("`@("`@("`@96-H;R`B/'1D('9A;&EG;CU<(G1O<%PB(&-L87-S
M/5PB9&ES<&QA>5PB/EQN(CL*("`@("`@("!]"@H@("`@("`@("1D:79S='EL
M92`]("<G.PH@("`@("`@(&EF("@D=&AI<RT^:&%S475I<FLH)W-C<F]L;%]T
M9',G*2`F)B`D9&5C:RT^7W-I;75L871O<BD@>PH@("`@("`@("`@("`O+R!-
M86ME(&-O;G1E;G0@;V8@=&%B;&4@96QE;65N="!S8W)O;&QA8FQE("A(;W)D
M95]-;V)I;&4*("`@("`@("`@("`@+R\@<VEM=6QA=&]R*2X*("`@("`@("`@
M("`@)&1I=G-T>6QE(#T@)R!C;&%S<STB<VEM9&5V(B<["B`@("`@("`@?0H@
M("`@("`@(&5C:&\@)SQD:78G("X@)&1I=G-T>6QE("X@)SXG.PH*("`@("`@
M("!I9B`H*"1C;G0@/2!C;W5N="@D9&5C:RT^7V-A<F1S*2D@(3T](#`I('L*
M("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D9&5C
M:RT^7V-A<F1S(&%S("1C87)D*2!["B`@("`@("`@("`@("`@("!I9B`H)&D@
M(3T@,"D@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@)SQH<B`O/B<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E;F1E
M<D-A<F0H)&-A<F0I.PH@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M96-K+3Y?96QE;65N=',@87,@)'!A9V5?96QE;65N="D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G)E;F1E<D5L96UE;G0H)'!A9V5?96QE;65N="D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&5C:&\@)SPO9&EV/B<[
M"@H@("`@("`@(&EF("@D9&5C:RT^7W-I;75L871O<BD@>PH@("`@("`@("`@
M("`O+R!$:7-P;&%Y(&QO=V5R('!A<G0@;V8@2&]R9&5?36]B:6QE(&1E9F%U
M;'0@9&5V:6-E"B`@("`@("`@("`@("\O('-I;75L871O<BX*("`@("`@("`@
M("`@96-H;R`G/"]T9#X\=&0@=F%L:6=N/2)T;W`B(&-L87-S/2)R:6=H="(^
M)FYB<W`[/"]T9#X\+W1R/CQT<CX\=&0@8V]L<W!A;CTB,R(@8VQA<W,](F)O
M='1O;2(^)FYB<W`[/"]T9#X\+W1R/CPO=&%B;&4^/"]C96YT97(^)SL*("`@
M("`@("!]"@H@("`@("`@(&5C:&\@)SPO8F]D>3X\+VAT;6P^)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R0V%R9"@F)&-A<F0I"B`@("!["B`@("`@
M("`@)&YA;64@/2`D8V%R9"T^9V5T*"=N86UE)RD@/R`G(&YA;64](B<@+B`D
M=&AI<RT^97-C87!E*"1C87)D+3YG970H)VYA;64G*2D@+B`G(B<@.B`G)SL*
M("`@("`@("!P<FEN=&8H)SQA)7,^)7,\+V$^)RP@)&YA;64L("1C87)D+3YG
M970H)W1I=&QE)RDI.PH*("`@("`@("!I9B`H8V]U;G0H)&-A<F0M/E]S;V9T
M:V5Y<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&-A<F0M/E]S;V9T:V5Y
M<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("!E8VAO("<@?"`\82!H<F5F
M/2(G("X@)&ME>5LG=7)L)UT@+B`G(CXG("X@("1T:&ES+3YE<V-A<&4H)&ME
M>5LG;&%B96PG72D@+B`G/"]A/B<["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O(%)E;F1E<B!A;&P@=&%G<RX*("`@("`@("!F;W)E86-H
M("@D8V%R9"T^7V5L96UE;G1S(&%S("1P86=E7V5L96UE;G0I('L*("`@("`@
M("`@("`@)'1H:7,M/G)E;F1E<D5L96UE;G0H)'!A9V5?96QE;65N="D["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97),:6YK*"8D;&EN
M:RD*("`@('L*("`@("`@("!I9B`H)&QI;FLM/F=E="@G=&ET;&4G*2`F)@H@
M("`@("`@("`@("`A)'1H:7,M/FES0G)O=W-E<B@G879A;G1G;R<I("8F"B`@
M("`@("`@("`@("$D=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I("8F"B`@("`@
M("`@("`@("$D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@("`@
M("`D=&ET;&5?;W!T:6]N(#T@<W!R:6YT9B@G(&]N;6]U<V5O=F5R/2)S96QF
M+G-T871U<SU<)R5S7"<[<F5T=7)N('1R=64[(B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)&QI;FLM/F=E
M="@G=&ET;&4G*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:71L95]O<'1I;VX@/2`G)SL*("`@("`@("!]"@H@("`@("`@("1A8V-E<W-K
M97E?;W!T:6]N(#T@)R<["B`@("`@("`@:68@*"1L:6YK+3YG970H)V%C8V5S
M<VME>2<I*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=I
M;6]D92<I*2!["B`@("`@("`@("`@("`@("`D86-C97-S:V5Y7V]P=&EO;B`]
M('-P<FEN=&8H)R!A8V-E<W-K97D](B5D(B<L("1L:6YK+3YG970H)V%C8V5S
M<VME>2<I*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YI<T)R;W=S
M97(H)VUM;"<I*2!["B`@("`@("`@("`@("`@("`D86-C97-S:V5Y7V]P=&EO
M;B`]('-P<FEN=&8H)R!D:7)E8W1K97D](B5D(B<L("1L:6YK+3YG970H)V%C
M8V5S<VME>2<I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<')I;G1F*"<\82!H<F5F/2(E<R(E<R5S/B5S/"]A/B<L"B`@("`@("`@("`@
M("`@('-T<E]R97!L86-E*"<F86UP.V%M<#LG+"`G)F%M<#LG+"`D=&AI<RT^
M97-C87!E*"1L:6YK+3YG970H)W5R;"<I*2DL"B`@("`@("`@("`@("`@("1T
M:71L95]O<'1I;VXL("1A8V-E<W-K97E?;W!T:6]N+`H@("`@("`@("`@("`@
M("`D=&AI<RT^97-C87!E*"1L:6YK+3YG970H)VQA8F5L)RDI*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R3&EN:W-E="@F)&QI;FMS970I"B`@("![
M"B`@("`@("`@:68@*&-O=6YT*"1L:6YK<V5T+3Y?96QE;65N=',I*2!["B`@
M("`@("`@("`@(&5C:&\@)SQO;#XG.PH@("`@("`@("`@("!F;W)E86-H("@D
M;&EN:W-E="T^7V5L96UE;G1S(&%S("1V86PI('L*("`@("`@("`@("`@("`@
M(&5C:&\@)SQL:3XG.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD97),
M:6YK*"1V86PI.PH@("`@("`@("`@("`@("`@96-H;R`G/"]L:3XG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@)SPO;VP^)SL*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E1E>'0H)B1E;&5M96YT*0H@
M("`@>PH@("`@("`@(&9O<F5A8V@@*"1E;&5M96YT+3Y?871T<FEB=71E<R!A
M<R`D871T<FEB=71E*2!["B`@("`@("`@("`@(&5C:&\@)SPG("X@)&%T=')I
M8G5T92`N("<^)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D96QE;65N="T^
M9V5T*"=L:6YE8G)E86MS)RDI('L*("`@("`@("`@("`@96-H;R!N;#)B<B@D
M=&AI<RT^97-C87!E*"1E;&5M96YT+3YG970H)W1E>'0G*2DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&5C:&\@)'1H:7,M/F5S8V%P92@D96QE
M;65N="T^9V5T*"=T97AT)RDI.PH@("`@("`@('T*"B`@("`@("`@)&%T=')I
M8G5T97,@/2!A<G)A>5]R979E<G-E*"1E;&5M96YT+3Y?871T<FEB=71E<RD[
M"B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&%T=')I8G5T92D@
M>PH@("`@("`@("`@("!E8VAO("<\+R<@+B`D871T<FEB=71E("X@)SXG.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R26UA9V4H)B1I
M;6%G92D*("`@('L*("`@("`@("`D871T<FEB=71E<R`]("<G.PH@("`@("`@
M(&9O<F5A8V@@*"1I;6%G92T^7V%T=')I8G5T97,@87,@)&%T=')I8G5T92`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@)&%T=')I8G5T97,@+CT@<W!R:6YT
M9B@G("5S/2(E<R(G+"`D871T<FEB=71E+"`D=F%L=64I.PH@("`@("`@('T*
M("`@("`@("!P<FEN=&8H)SQI;6<@<W)C/2(E<RYP;F<B)7,@+SXG+"`D:6UA
M9V4M/E]S<F,L("1A='1R:6)U=&5S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R1F]R;2@F)&9O<FTI"B`@("!["B`@("`@("`@<')I;G1F*"<\9F]R
M;2!A8W1I;VX](B5S(B!M971H;V0](B5S(CXG+"`D9F]R;2T^9V5T*"=U<FPG
M*2P@)&9O<FTM/F=E="@G;65T:&]D)RDI.PH@("`@("`@('!A<F5N=#HZ7W)E
M;F1E<D9O<FTH)&9O<FTI.PH@("`@("`@(&5C:&\@)SPO9F]R;3XG.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97));G!U="@F)&EN<'5T*0H@("`@>PH@
M("`@("`@("1T>7!E(#T@)W1Y<&4](B<@+B`D:6YP=70M/F=E="@G='EP92<I
M("X@)R(G.PH@("`@("`@("1S:7IE(#T@)&EN<'5T+3YG970H)W-I>F4G*2`_
M('-P<FEN=&8H)W-I>F4](B5D(B<L("1I;G!U="T^9V5T*"=S:7IE)RDI(#H@
M)R<["B`@("`@("`@)&UA>&QE;F=T:"`]("1I;G!U="T^9V5T*"=M87AL96YG
M=&@G*2`_('-P<FEN=&8H)VUA>&QE;F=T:#TB)60B)RP@)&EN<'5T+3YG970H
M)VUA>&QE;F=T:"<I*2`Z("<G.PH*("`@("`@("!I9B`H)'1H:7,M/FES0G)O
M=W-E<B@G:6UO9&4G*2D@>PH@("`@("`@("`@("`D;6]D92`]('-P<FEN=&8H
M)R!I<W1Y;&4](B5D(B<L("1I;G!U="T^9V5T*"=M;V1E)RDI.PH@("`@("`@
M('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@
M("`@("`D;6]D92`]("1T:&ES+3Y?9V5T36]D92@D:6YP=70M/F=E="@G;6]D
M92<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6]D92`]("<G
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E($A434P@:6YP=70N"B`@
M("`@("`@<')I;G1F*"<E<R`\:6YP=70@)7,@;F%M93TB)7,B('9A;'5E/2(E
M<R(E<R5S)7,O/B<L"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)&EN
M<'5T+3YG970H)VQA8F5L)RDI+"`D='EP92P*("`@("`@("`@("`@("`@)'1H
M:7,M/F5S8V%P92@D:6YP=70M/F=E="@G;F%M92<I*2P@)'1H:7,M/F5S8V%P
M92@D:6YP=70M/F=E="@G=F%L=64G*2DL("1S:7IE+"`D;6%X;&5N9W1H+"`D
M;6]D92D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E1E>'1A<F5A*"8D
M=&5X=&%R96$I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H
M)VEM;V1E)RDI('L*("`@("`@("`@("`@)&UO9&4@/2!S<')I;G1F*"<@:7-T
M>6QE/2(E9"(G+"`D=&AI<RT^;6]D92D["B`@("`@("`@?2!E;'-E:68@*"1T
M:&ES+3YI<T)R;W=S97(H)VUM;"<I*2!["B`@("`@("`@("`@("1M;V1E(#T@
M)'1H:7,M/E]G971-;V1E*"1T:&ES+3YM;V1E*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;6]D92`]("<G.PH@("`@("`@('T*"B`@("`@("`@
M)'=R87`@/2`G)SL*("`@("`@("!I9B`H(21T:&ES+3YI<T)R;W=S97(H)VEM
M;V1E)RD@)B8@(21T:&ES+3YI<T)R;W=S97(H)VUM;"<I*2!["B`@("`@("`@
M("`@("1W<F%P(#T@)R!W<F%P/2)V:7)T=6%L(B<["B`@("`@("`@?0H*("`@
M("`@("!P<FEN=&8H)R5S/&)R("\^/'1E>'1A<F5A(&YA;64](B5S(B!R;W=S
M/2(E<R(@8V]L<STB)7,B)7,E<SXE<SPO=&5X=&%R96$^)RP*("`@("`@("`@
M("`@("`@)'1H:7,M/F5S8V%P92@D=&5X=&%R96$M/F=E="@G;&%B96PG*2DL
M("1T97AT87)E82T^9V5T*"=N86UE)RDL("1T97AT87)E82T^9V5T*"=R;W=S
M)RDL"B`@("`@("`@("`@("`@("1T97AT87)E82T^9V5T*"=C;VQS)RDL("1M
M;V1E+"`D=W)A<"P@)'1E>'1A<F5A+3YG970H)W9A;'5E)RDI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)396QE8W0H)B1S96QE8W0I"B`@("!["B`@
M("`@("`@96-H;R`G/'-E;&5C="!N86UE/2(G("X@)'-E;&5C="T^9V5T*"=N
M86UE)RD@+B`G(B!S:7IE/2(Q(CXG.PH@("`@("`@(&9O<F5A8V@@*"1S96QE
M8W0M/E]O<'1I;VYS(&%S("1V86PI('L*("`@("`@("`@("`@:68@*"1V86Q;
M)W9A;'5E)UT@/3T@)'-E;&5C="T^7W9A;'5E*2!["B`@("`@("`@("`@("`@
M("`D<V5L(#T@)R!S96QE8W1E9#TB<V5L96-T960B)SL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1S96P@/2`G)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E8VAO("<\;W!T:6]N)R`N("1S96P@+B`G('9A
M;'5E/2(G("X@)'9A;%LG=F%L=64G72`N("<B/B<@+B`D=&AI<RT^97-C87!E
M*"1V86Q;)VQA8F5L)UTI("X@)SPO;W!T:6]N/B<["B`@("`@("`@?0H@("`@
M("`@(&5C:&\@)SPO<V5L96-T/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E)A9&EO*"8D<F%D:6\I"B`@("!["B`@("`@("`@9F]R96%C:"`H)')A
M9&EO+3Y?8G5T=&]N<R!A<R`D=F%L*2!["B`@("`@("`@("`@("1S96P@/2`H
M)'9A;%LG=F%L=64G72`]/2`D<F%D:6\M/E]V86QU92D@/R`G(&-H96-K960]
M(F-H96-K960B)R`Z("<G.PH@("`@("`@("`@("!P<FEN=&8H)SQI;G!U="!T
M>7!E/2)R861I;R(@;F%M93TB)7,B)7,@=F%L=64](B5S(B`O/B`E<SQB<B`O
M/B<L"B`@("`@("`@("`@("`@("`@("`D<F%D:6\M/F=E="@G;F%M92<I+"`D
M<V5L+"`D=F%L6R=V86QU92==+`H@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F5S8V%P92@D=F%L6R=L86)E;"==*2D["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)#:&5C:V)O>"@F)&-H96-K8F]X*0H@("`@>PH@
M("`@("`@("1S=&%T92`]("1C:&5C:V)O>"T^:7-#:&5C:V5D*"D@/R`G(&-H
M96-K960](F-H96-K960B)R`Z("<G.PH@("`@("`@('!R:6YT9B@G/&EN<'5T
M('1Y<&4](F-H96-K8F]X(B!N86UE/2(E<R(E<R!V86QU93TB)7,B("\^("5S
M/&)R("\^)RP*("`@("`@("`@("`@("`@)&-H96-K8F]X+3YG970H)VYA;64G
M*2P@)'-T871E+"`D8VAE8VMB;W@M/F=E="@G=F%L=64G*2P*("`@("`@("`@
M("`@("`@)'1H:7,M/F5S8V%P92@D8VAE8VMB;W@M/F=E="@G;&%B96PG*2DI
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)3=6)M:70H)B1S=6)M:70I
M"B`@("!["B`@("`@("`@)&YA;64@/2`A96UP='DH)'-U8FUI="T^7VYA;64I
M(#\@)R!N86UE/2(G("X@)'-U8FUI="T^7VYA;64@+B`G(B<@.B`G)SL*("`@
M("`@("!P<FEN=&8H)SQI;G!U="!T>7!E/2)S=6)M:70B)7,@=F%L=64](B5S
M(B`O/CQB<B`O/B<L"B`@("`@("`@("`@("`@("1N86UE+"`D=&AI<RT^97-C
M87!E*"1S=6)M:70M/E]L86)E;"DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97)(:61D96XH)B1H:61D96XI"B`@("!["B`@("`@("`@<')I;G1F*"<\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E<R(@=F%L=64](B5S(B`O/B<L
M"B`@("`@("`@("`@("`@("1H:61D96XM/F=E="@G;F%M92<I+"`D:&ED9&5N
M+3YG970H)W9A;'5E)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)4
M86)L92@F)'1A8FQE*0H@("`@>PH@("`@("`@("1B;W)D97(@/2`D=&%B;&4M
M/F=E="@G8F]R9&5R)RD["B`@("`@("`@)'!A9&1I;F<@/2`D=&%B;&4M/F=E
M="@G<&%D9&EN9R<I.PH@("`@("`@("1S<&%C:6YG(#T@)'1A8FQE+3YG970H
M)W-P86-I;F<G*3L*"B`@("`@("`@96-H;R`G/'1A8FQE)SL*("`@("`@("!I
M9B`H(6ES7VYU;&PH)&)O<F1E<BDI('L*("`@("`@("`@("`@96-H;R`G(&)O
M<F1E<CTB)R`N("1B;W)D97(@+B`G(B<["B`@("`@("`@?0H@("`@("`@(&EF
M("@A:7-?;G5L;"@D<&%D9&EN9RDI('L*("`@("`@("`@("`@96-H;R`G(&-E
M;&QP861D:6YG/2(G("X@)'!A9&1I;F<@+B`G(B<["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-?;G5L;"@D<W!A8VEN9RDI('L*("`@("`@("`@("`@96-H
M;R`G(&-E;&QS<&%C:6YG/2(G("X@)'-P86-I;F<@+B`G(B<["B`@("`@("`@
M?0H@("`@("`@(&5C:&\@)SXG.PH*("`@("`@("!P87)E;G0Z.E]R96YD97)4
M86)L92@D=&%B;&4I.PH*("`@("`@("`O+R!497)M:6YA=&4@=&%B;&4N"B`@
M("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)VUM;"<I*2!["B`@("`@("`@
M("`@(&5C:&\@)SPO=&%B;&4^/&)R("\^)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O+R!-34P@:&%S('!R;V)L96US('=I=&@@=&AE(&-L96%R
M(&%T=')I8G5T92X*("`@("`@("`@("`@96-H;R`G/"]T86)L93X\8G(@8VQE
M87(](F%L;"(^)SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E!H;VYE*"8D<&AO;F4I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YI
M<T)R;W=S97(H)VEM;V1E)RDI('L*("`@("`@("`@("`@+R\@0W)E871E('!H
M;VYE=&\Z(&QI;FL@9F]R(&DM36]D92X*("`@("`@("`@("`@<')I;G1F*"<\
M<#X\82!H<F5F/2)P:&]N971O.B5S(CXE<SPO83X\+W`^)RP*("`@("`@("`@
M("`@("`@("`@("1P:&]N92T^9V5T*"=N=6UB97(G*2P@)'!H;VYE+3YG970H
M)VQA8F5L)RDI.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R
M*"=M;6PG*2D@>PH@("`@("`@("`@("`O+R!#<F5A=&4@=&5L.B!L:6YK(&9O
M<B!-34PN"B`@("`@("`@("`@('!R:6YT9B@G/'`^/&$@:')E9CTB=&5L.B5S
M(CXE<SPO83X\+W`^)RP*("`@("`@("`@("`@("`@("`@("1P:&]N92T^9V5T
M*"=N=6UB97(G*2P@)'!H;VYE+3YG970H)VQA8F5L)RDI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\O($1I<W!L87D@<&AO;F4@;G5M8F5R(&%S
M('!L86EN('1E>'0N"B`@("`@("`@("`@('!R:6YT9B@G/'`^/&)I9SXE<SPO
M8FEG/CPO<#XG+"`D<&AO;F4M/F=E="@G;&%B96PG*2D["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)2=6QE*"8D<G5L92D*("`@('L*
M("`@("`@("`D=VED=&@@/2`D<G5L92T^9V5T*"=W:61T:"<I.PH@("`@("`@
M("1S:7IE(#T@)')U;&4M/F=E="@G<VEZ92<I.PH*("`@("`@("!E8VAO("<\
M:'(G("X@*"1W:61T:"`_("<@=VED=&@](B<@+B`D=VED=&@@+B`G(B<@.B`G
M)RD@+B`H)'-I>F4@/R`G('-I>F4](B<@+B`D<VEZ92`N("<B)R`Z("<G*2`N
M("(@+SY<;B(["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E=$UO9&4H)&UO9&4I
M"B`@("!["B`@("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@
M)VMA=&%K86YA)SH*("`@("`@("`@("`@<F5T=7)N("<@;6]D93TB:V%T86MA
M;F$B)SL*"B`@("`@("`@8V%S92`G:&ER86=A;F$G.@H@("`@("`@("`@("!R
M971U<FX@)R!M;V1E/2)H:7)A9V%N82(G.PH*("`@("`@("!C87-E("=N=6UE
M<FEC)SH*("`@("`@("`@("`@<F5T=7)N("<@;6]D93TB;G5M97)I8R(G.PH*
M("`@("`@("!C87-E("=A;'!H82<Z"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N("<@;6]D93TB86QP:&%B970B)SL*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O36]B:6QE+U)E;F1E<F5R+W=M;"YP:'``````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V-3(S`#$P-#$W,S8R-S<Q`#`R,C4R
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@2&]R9&5?36]B:6QE7U)E;F1E<F5R.CH@;W5T<'5T(&UO
M9'5L92!F;W(@5TU,("A7:7)E;&5S<R!-87)K=7`@3&%N9W5A9V4I+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]-;V)I;&4O36]B:6QE+U)E;F1E<F5R+W=M
M;"YP:'`L=B`Q+C,R+C$P+C<@,C`P-B\P,B\R-"`R,#HT,#HS."!C:'5C:R!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L
M87-S($AO<F1E7TUO8FEL95]296YD97)E<E]W;6P@97AT96YD<R!(;W)D95]-
M;V)I;&5?4F5N9&5R97(@>PH*("`@("\J*@H@("`@("H@4')O<&5R;'D@96YC
M;V1E(&-H87)A8W1E<G,@9F]R(&]U='!U="!T;R!A(%=-3"!D979I8V4N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@($-H87)A8W1E<G,@
M=&\@96YC;V1E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M96YC;V1E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&4H)&EN
M<'5T*0H@("`@>PH@("`@("`@("\O($5N8V]D92!E;G1I=&EE<RX*("`@("`@
M("`D;W5T<'5T(#T@0&AT;6QS<&5C:6%L8VAA<G,H)&EN<'5T+"!%3E1?0T]-
M4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["@H@("`@("`@("\O($5S8V%P92`D
M(&-H87)A8W1E<B!I;B!734PN"B`@("`@("`@)&]U='!U="`]('-T<E]R97!L
M86-E*"<D)RP@)R0D)RP@)&]U='!U="D["@H@("`@("`@("\O($=E;F5R871E
M(%541BTX+@H@("`@("`@("1O=71P=70@/2!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"1O=71P=70L($Y,4SHZ9V5T0VAA<G-E="@I+"`G=71F+3@G*3L*"B`@
M("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&5S('1H92!P86=E(&EN(%=-3"P@86QL;W=I;F<@9F]R(&1I9F9E<F5N
M="!734P@8G)O=W-E<B!Q=6ER:W,N"B`@("`@*@H@("`@("H@0'!A<F%M($AO
M<F1E7TUO8FEL92`D9&5C:R`@5&AE(&1E8VL@=&\@<F5N9&5R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96YD97(H)B1D96-K*0H@("`@>PH@("`@("`@(&EF
M("@D9&5C:RT^7V1E8G5G*2!["B`@("`@("`@("`@(&AE861E<B@G0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/75T9BTX)RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z('1E
M>'0O=FYD+G=A<"YW;6P[(&-H87)S970]=71F+3@G*3L*("`@("`@("!]"@H@
M("`@("`@(&5C:&\@(CP_>&UL('9E<G-I;VX]7"(Q+C!<(C\^7&XB.PH@("`@
M("`@(&EF("@D=&AI<RT^:&%S475I<FLH)V]W7V=U:5\Q+C,G*2D@>PH@("`@
M("`@("`@("!E8VAO("<\(41/0U194$4@=VUL(%!50DQ)0R`B+2\O4$A/3D4N
M0T]-+R]$5$0@5TU,(#$N,R\O14XB(")H='1P.B\O=W=W+F]P96YW879E+F-O
M;2]D=&0O=VUL,3,N9'1D(CXG.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&5C:&\@)SPA1$]#5%E012!W;6P@4%5"3$E#("(M+R]705!&3U)532\O
M1%1$(%=-3"`Q+C$O+T5.(B`B:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<O1%1$
M+W=M;%\Q+C$N>&UL(CXG.PH@("`@("`@('T*("`@("`@("!E8VAO("<\=VUL
M/B<["@H@("`@("`@(&EF("AC;W5N="@D9&5C:RT^7V-A<F1S*2D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D9&5C:RT^7V-A<F1S(&%S("1C87)D*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W)E;F1E<D-A<F0H)&-A<F0I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1I=&QE
M(#T@)&1E8VLM/F=E="@G=&ET;&4G*2`_("<@=&ET;&4](B<@+B`D=&AI<RT^
M97-C87!E*"1D96-K+3YG970H)W1I=&QE)RDI("X@)R(G(#H@)R<["B`@("`@
M("`@("`@('!R:6YT9B@G/&-A<F0E<SXG+"`D=&ET;&4I.PH*("`@("`@("`@
M("`@+R\@4F5N9&5R(&%L;"!T86=S+@H@("`@("`@("`@("!F;W)E86-H("@D
M9&5C:RT^7V5L96UE;G1S(&%S("1P86=E7V5L96UE;G0I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT*"1P86=E7V5L96UE;G0I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!E8VAO("<\+V-A<F0^)SL*("`@
M("`@("!]"@H@("`@("`@("\O($5N9"!T:&4@5TU,('!A9V4N"B`@("`@("`@
M96-H;R`G/"]W;6P^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R0V%R
M9"@F)&-A<F0I"B`@("!["B`@("`@("`@)&YA;64@/2`D8V%R9"T^9V5T*"=N
M86UE)RD@/R`G(&ED/2(G("X@)'1H:7,M/F5S8V%P92@D8V%R9"T^9V5T*"=N
M86UE)RDI("X@)R(G(#H@)R<["B`@("`@("`@)'1I=&QE(#T@)&-A<F0M/F=E
M="@G=&ET;&4G*2`_("<@=&ET;&4](B<@+B`D=&AI<RT^97-C87!E*"1C87)D
M+3YG970H)W1I=&QE)RDI("X@)R(G(#H@)R<["B`@("`@("`@<')I;G1F*"<\
M8V%R9"5S)7,^)RP@)&YA;64L("1T:71L92D["@H@("`@("`@("\O($EN:71I
M86QI>F4@5TU,('9A<FEA8FQE<R!W:71H('1H96ER(&1E9F%U;'0@=F%L=65S
M+@H@("`@("`@(&EF("@A:7-?;G5L;"@D8V%R9"T^7V9O<FTI*2!["B`@("`@
M("`@("`@(&5C:&\@)SQO;F5V96YT('1Y<&4](F]N96YT97)F;W)W87)D(CX\
M<F5F<F5S:#XG.PH@("`@("`@("`@("`D9&5F875L=',@/2`D8V%R9"T^7V9O
M<FTM/F=E=$1E9F%U;'1S*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1D969A
M=6QT<R!A<R`D9"D@>PH@("`@("`@("`@("`@("`@<')I;G1F*"<\<V5T=F%R
M(&YA;64](E\E<R(@=F%L=64](B5S(B\^)RP@)&1;)VYA;64G72P@)'1H:7,M
M/F5S8V%P92@D9%LG=F%L=64G72DI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5C:&\@)SPO<F5F<F5S:#X\+V]N979E;G0^)SL*("`@("`@("!]"@H@
M("`@("`@(&EF("AC;W5N="@D8V%R9"T^7W-O9G1K97ES*2D@>PH@("`@("`@
M("`@("!I9B`H8V]U;G0H)&-A<F0M/E]S;V9T:V5Y<RD@/3T@,2D@>PH@("`@
M("`@("`@("`@("`@+R\@268@=&AE<F4@:7,@;VYL>2!O;F4@<V]F=&ME>2P@
M;6%K92!I="!O9B!T>7!E"B`@("`@("`@("`@("`@("`O+R`G;W!T:6]N<R<@
M<V\@=&AA="!I="!A;'=A>7,@<VAO=W,@=7`@;VX@=&AE(')I9VAT+`H@("`@
M("`@("`@("`@("`@+R\@:6YS=&5A9"!O9B!H879I;F<@=&\@<VAA<F4@=&AE
M(&QE9G0@<V]F=&ME>2!W:71H"B`@("`@("`@("`@("`@("`O+R!A8W1I=F4@
M;&EN:W,L(&UA:VEN9R!I="!M=6-H(&AA<F1E<B!T;R!G970@=&\N"B`@("`@
M("`@("`@("`@("`D='EP92`]("=O<'1I;VYS)SL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T>7!E(#T@)V%C8V5P="<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&-A<F0M/E]S;V9T:V5Y
M<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("!E8VAO("<\9&\@='EP93TB
M)R`N("1T>7!E("X@)R(@;&%B96P](B<@+B`D=&AI<RT^97-C87!E*"1K97E;
M)VQA8F5L)UTI("X@)R(^/&=O(&AR968](B<@+B`D:V5Y6R=U<FPG72`N("<B
M+SX\+V1O/B<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M(%)E;F1E<B!A;&P@=&%G<RX*("`@("`@("!F;W)E86-H("@D8V%R9"T^7V5L
M96UE;G1S(&%S("1P86=E7V5L96UE;G0I('L*("`@("`@("`@("`@)'1H:7,M
M/G)E;F1E<D5L96UE;G0H)'!A9V5?96QE;65N="D["B`@("`@("`@?0H*("`@
M("`@("!E8VAO("<\+V-A<F0^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R3&EN:R@F)&QI;FLI"B`@("!["B`@("`@("`@)'1I=&QE7V]P=&EO;B`]
M("1L:6YK+3YG970H)W1I=&QE)RD@/R!S<')I;G1F*"<@=&ET;&4](B5S(B<L
M("1T:&ES+3YE<V-A<&4H)&QI;FLM/F=E="@G=&ET;&4G*2DI(#H@)R<["@H@
M("`@("`@('!R:6YT9B@G/&$E<R!H<F5F/2(E<R(^)7,\+V$^)RP*("`@("`@
M("`@("`@("`@)'1I=&QE7V]P=&EO;BP@<W1R7W)E<&QA8V4H)R9A;7`[86UP
M.R<L("<F86UP.R<L("1T:&ES+3YE<V-A<&4H)&QI;FLM/F=E="@G=7)L)RDI
M*2P*("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D;&EN:RT^9V5T*"=L
M86)E;"<I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<DQI;FMS970H
M)B1L:6YK<V5T*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D;&EN:W-E="T^
M7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/FES0G)O=W-E
M<B@G=7`G*2D@>PH@("`@("`@("`@("`@("`@96-H;R`G/'-E;&5C=#XG.PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&QI;FMS970M/E]E;&5M96YT<R!A
M<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)'1I=&QE(#T@)'9A;"T^
M9V5T*"=T:71L92<I(#\@)R!T:71L93TB)R`N("1T:&ES+3YE<V-A<&4H)'9A
M;"T^9V5T*"=T:71L92<I*2`N("<B)R`Z("<G.PH@("`@("`@("`@("`@("`@
M("`@('!R:6YT9B@G/&]P=&EO;B!O;G!I8VL](B5S(B5S/B5S/"]O<'1I;VX^
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H)R9A
M;7`[86UP.R<L("<F86UP.R<L("1T:&ES+3YE<V-A<&4H)'9A;"T^9V5T*"=U
M<FPG*2DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&ET;&4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)'9A;"T^
M9V5T*"=L86)E;"<I*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!E8VAO("<\+W-E;&5C=#XG.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&QI;FMS970M/E]E;&5M96YT<R!A
M<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD97),
M:6YK*"1V86PI.PH@("`@("`@("`@("`@("`@("`@(&5C:&\@)SQB<B`O/B<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E1E>'0H)B1E;&5M96YT*0H@("`@
M>PH@("`@("`@(&9O<F5A8V@@*"1E;&5M96YT+3Y?871T<FEB=71E<R!A<R`D
M871T<FEB=71E*2!["B`@("`@("`@("`@(&5C:&\@)SPG("X@)&%T=')I8G5T
M92`N("<^)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D96QE;65N="T^9V5T
M*"=L:6YE8G)E86MS)RDI('L*("`@("`@("`@("`@96-H;R!N;#)B<B@D=&AI
M<RT^97-C87!E*"1E;&5M96YT+3YG970H)W1E>'0G*2DI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&5C:&\@)'1H:7,M/F5S8V%P92@D96QE;65N
M="T^9V5T*"=T97AT)RDI.PH@("`@("`@('T*"B`@("`@("`@)&%T=')I8G5T
M97,@/2!A<G)A>5]R979E<G-E*"1E;&5M96YT+3Y?871T<FEB=71E<RD["B`@
M("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@
M("`@("`@("`@("!E8VAO("<\+R<@+B`D871T<FEB=71E("X@)SXG.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R26UA9V4H)B1I;6%G
M92D*("`@('L*("`@("`@("`D871T<FEB=71E<R`]("<G.PH@("`@("`@(&9O
M<F5A8V@@*"1I;6%G92T^7V%T=')I8G5T97,@87,@)&%T=')I8G5T92`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@)&%T=')I8G5T97,@+CT@<W!R:6YT9B@G
M("5S/2(E<R(G+"`D871T<FEB=71E+"`D=F%L=64I.PH@("`@("`@('T*("`@
M("`@("!P<FEN=&8H)SQI;6<@<W)C/2(E<RYW8FUP(B5S+SXG+"`D:6UA9V4M
M/E]S<F,L("1A='1R:6)U=&5S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R26YP=70H)B1I;G!U="D*("`@('L*("`@("`@("`D='EP92`]("<@='EP
M93TB)R`N("1I;G!U="T^9V5T*"=T>7!E)RD@+B`G(B<["B`@("`@("`@)'-I
M>F4@/2`D:6YP=70M/F=E="@G<VEZ92<I(#\@<W!R:6YT9B@G('-I>F4](B5D
M(B<L("1I;G!U="T^9V5T*"=S:7IE)RDI(#H@)R<["B`@("`@("`@)&UA>&QE
M;F=T:"`]("1I;G!U="T^9V5T*"=M87AL96YG=&@G*2`_('-P<FEN=&8H)R!M
M87AL96YG=&@](B5D(B<L("1I;G!U="T^9V5T*"=M87AL96YG=&@G*2D@.B`G
M)SL*"B`@("`@("`@<')I;G1F*"<E<SQI;G!U="!E;7!T>6]K/2)T<G5E(B!F
M;W)M870](B5S(B5S(&YA;64](E\E<R(@=F%L=64](B5S(B5S)7,O/B<L"B`@
M("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)&EN<'5T+3YG970H)VQA8F5L
M)RDI+"`D:6YP=70M/F=E="@G9F]R;6%T)RDL"B`@("`@("`@("`@("`@("1T
M>7!E+"`D=&AI<RT^97-C87!E*"1I;G!U="T^9V5T*"=N86UE)RDI+"`D=&AI
M<RT^97-C87!E*"1I;G!U="T^9V5T*"=V86QU92<I*2P@)'-I>F4L("1M87AL
M96YG=&@I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)497AT87)E82@F
M)'1E>'1A<F5A*0H@("`@>PH@("`@("`@('!R:6YT9B@G)7,\:6YP=70@96UP
M='EO:STB=')U92(@;F%M93TB7R5S(B!V86QU93TB)7,B+SXG+`H@("`@("`@
M("`@("`@("`D=&AI<RT^97-C87!E*"1T97AT87)E82T^9V5T*"=L86)E;"<I
M*2P*("`@("`@("`@("`@("`@)'1E>'1A<F5A+3YG970H)VYA;64G*2P@)'1E
M>'1A<F5A+3YG970H)W9A;'5E)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97)396QE8W0H)B1S96QE8W0I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YH87-1=6ER:R@G;W=?9W5I7S$N,R<I*2!["B`@("`@("`@("`@('-W:71C
M:"`H)'-E;&5C="T^9V5T*"=T>7!E)RDI('L*("`@("`@("`@("`@8V%S92`G
M<W!I;B<Z"B`@("`@("`@("`@("`@("`D='EP95]O<'1I;VX@/2`G='EP93TB
M<W!I;B(G.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=P;W!U<"<Z"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("`D='EP95]O<'1I;VX@/2`G='EP93TB<&]P=7`B)SL*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!E8VAO
M("<\<V5L96-T("<@+B`D='EP95]O<'1I;VX@+B`G(&YA;64](E\G("X@)'-E
M;&5C="T^9V5T*"=N86UE)RD@+B`G(CXG.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&5C:&\@)SQS96QE8W0@;F%M93TB7R<@+B`D<V5L96-T+3YG
M970H)VYA;64G*2`N("<B/B<["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H
M("@D<V5L96-T+3Y?;W!T:6]N<R!A<R`D=F%L*2!["B`@("`@("`@("`@(&5C
M:&\@)SQO<'1I;VX@=F%L=64](B<@+B`D=F%L6R=V86QU92==("X@)R(^)R`N
M("1T:&ES+3YE<V-A<&4H)'9A;%LG;&%B96PG72D@+B`G/"]O<'1I;VX^)SL*
M("`@("`@("!]"B`@("`@("`@96-H;R`G/"]S96QE8W0^)SL*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R4F%D:6\H)B1R861I;RD*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/FAA<U%U:7)K*"=O=U]G=6E?,2XS)RDI('L*("`@("`@
M("`@("`@+R\@3W!E;G=A=F4@1U5)(&5X=&5N<VEO;G,@9F]R(%=-3"`Q+C,*
M("`@("`@("`@("`@<')I;G1F*"<\<V5L96-T('1Y<&4](G)A9&EO(B!N86UE
M/2)?)7,B/B<L("1R861I;RT^9V5T*"=N86UE)RDI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\O($-O;G9E;G1I;VYA;"!734P@*'-I;6EL87(@
M=&\@2&]R9&5?36]B:6QE7W-E;&5C="DN"B`@("`@("`@("`@('!R:6YT9B@G
M/'-E;&5C="!N86UE/2)?)7,B/B<L("1R861I;RT^9V5T*"=N86UE)RDI.PH@
M("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)')A9&EO+3Y?8G5T=&]N<R!A
M<R`D=F%L*2!["B`@("`@("`@("`@('!R:6YT9B@G/&]P=&EO;B!V86QU93TB
M)7,B/B5S/"]O<'1I;VX^)RP*("`@("`@("`@("`@("`@("`@("1V86Q;)W9A
M;'5E)UTL("1T:&ES+3YE<V-A<&4H)'9A;%LG;&%B96PG72DI.PH@("`@("`@
M('T*"B`@("`@("`@96-H;R`G/"]S96QE8W0^)SL*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R0VAE8VMB;W@H)B1C:&5C:V)O>"D*("`@('L*("`@("`@
M("!P<FEN=&8H)SQS96QE8W0@;F%M93TB7R5S(B!M=6QT:7!L93TB=')U92(^
M)RP@)&-H96-K8F]X+3YG970H)VYA;64G*2D["B`@("`@("`@<')I;G1F*"<\
M;W!T:6]N('9A;'5E/2(E<R(^)7,\+V]P=&EO;CX\+W-E;&5C=#XG+`H@("`@
M("`@("`@("`@("`D8VAE8VMB;W@M/F=E="@G=F%L=64G*2P@)'1H:7,M/F5S
M8V%P92@D8VAE8VMB;W@M/F=E="@G;&%B96PG*2DI.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]R96YD97)3=6)M:70H)B1S=6)M:70I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YH87-1=6ER:R@G;W=?9W5I7S$N,R<I*2!["B`@("`@("`@
M("`@("\O($-R96%T92`\9&\@='EP93TB8G5T=&]N(CX@<V5Q=65N8V4@9F]R
M($]P96YW879E($=520H@("`@("`@("`@("`O+R!E>'1E;G-I;VYS(%=-3"`Q
M+C,N"B`@("`@("`@("`@('!R:6YT9B@G/&1O('1Y<&4](F)U='1O;B(@;&%B
M96P](B5S(CXG+`H@("`@("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D
M<W5B;6ET+3YG970H)VQA8F5L)RDI*3L*("`@("`@("`@("`@)'1A9R`]("=D
M;R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@0W)E871E(#QA
M;F-H;W(^('-E<75E;F-E(&EN(&YO<FUA;"!734PN"B`@("`@("`@("`@('!R
M:6YT9B@G/&%N8VAO<B!T:71L93TB)7,B/B5S)RP*("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YE<V-A<&4H)'-U8FUI="T^9V5T*"=L86)E;"<I*2P*("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)'-U8FUI="T^9V5T*"=L
M86)E;"<I*2D["B`@("`@("`@("`@("1T86<@/2`G86YC:&]R)SL*("`@("`@
M("!]"@H@("`@("`@(&EF("@D<W5B;6ET+3Y?9F]R;2T^9V5T*"=M971H;V0G
M*2`]/2`G<&]S="<I('L*("`@("`@("`@("`@<')I;G1F*"<\9V\@:')E9CTB
M)7,B(&UE=&AO9#TB<&]S="(^)RP@2&]R9&4Z.G5R;"@D<W5B;6ET+3Y?9F]R
M;2T^9V5T*"=U<FPG*2DI.PH*("`@("`@("`@("`@+R\@5F%L=64@9F]R('1H
M:7,@<W5B;6ET(&5L96UE;G0L(&]N;'D@:68@;F]N+65M<'1Y(&YA;64N"B`@
M("`@("`@("`@(&EF("@D<W5B;6ET+3YG970H)VYA;64G*2D@>PH@("`@("`@
M("`@("`@("`@<')I;G1F*"<\<&]S=&9I96QD(&YA;64](B5S(B!V86QU93TB
M)7,B+SXG+"`D<W5B;6ET+3YG970H)VYA;64G*2P@)'1H:7,M/F5S8V%P92@D
M<W5B;6ET+3YG970H)VQA8F5L)RDI*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&1E9F%U;'1S(#T@)'-U8FUI="T^7V9O<FTM/F=E=$1E9F%U;'1S
M*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1D969A=6QT<R!A<R`D9"D@>PH@
M("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)VAI9&1E;B<L
M("1D*2D@>PH@("`@("`@("`@("`@("`@("`@('!R:6YT9B@G/'!O<W1F:65L
M9"!N86UE/2(E<R(@=F%L=64](B5S(B\^)RP@)&1;)VYA;64G72P@)'1H:7,M
M/F5S8V%P92@D9%LG=F%L=64G72DI.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!P<FEN=&8H)SQP;W-T9FEE;&0@;F%M
M93TB)7,B('9A;'5E/2(D*%\E<RDB+SXG+"`D9%LG;F%M92==+"`D9%LG;F%M
M92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O(%-T87)T('=I=&@@=&AE('9A;'5E
M(&9O<B!T:&ES('-U8FUI="!E;&5M96YT+@H@("`@("`@("`@("`D<75E<GE?
M<W1R:6YG(#T@)'-U8FUI="T^9V5T*"=N86UE)RD@+B`G/2<@+B`D=&AI<RT^
M97-C87!E*"1S=6)M:70M/F=E="@G;&%B96PG*2D@+B`G)F%M<#LG.PH*("`@
M("`@("`@("`@)&=E='9A<G,@/2`D<W5B;6ET+3Y?9F]R;2T^9V5T1V5T5F%R
M<R@I.PH@("`@("`@("`@("!F;W)E86-H("@D9V5T=F%R<R!A<R`D=F%L*2![
M"B`@("`@("`@("`@("`@("`D<75E<GE?<W1R:6YG("X]("1V86P@+B`G/20H
M7R<@+B`D=F%L("X@)RDF86UP.R<["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("AS=6)S='(H)'%U97)Y7W-T<FEN9RP@+34I(#T]("<F86UP.R<I
M('L*("`@("`@("`@("`@("`@("1Q=65R>5]S=')I;F<@/2!S=6)S='(H)'%U
M97)Y7W-T<FEN9RP@,"P@<W1R;&5N*"1Q=65R>5]S=')I;F<I("T@-2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@('!R:6YT9B@G/&=O(&AR968](B5S
M/R5S(CXG+"`D<W5B;6ET+3Y?9F]R;2T^9V5T*"=U<FPG*2P@)'%U97)Y7W-T
M<FEN9RD["B`@("`@("`@?0H*("`@("`@("!E8VAO("(\+V=O/CPO)'1A9SXB
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)486)L92@F)'1A8FQE*0H@
M("`@>PH@("`@("`@("\O($-O=6YT(&UA>&EM=6T@;G5M8F5R(&]F(&-O;'5M
M;G,@:6X@=&%B;&4N"B`@("`@("`@)&UA>"`](#`["B`@("`@("`@9F]R96%C
M:"`H)'1A8FQE+3Y?<F]W<R!A<R`D<F]W*2!["B`@("`@("`@("`@("1M87@@
M/2!M87@H)&UA>"P@)')O=RT^9V5T0V]L=6UN0V]U;G0H*2D["B`@("`@("`@
M?0H@("`@("`@('!R:6YT9B@G/'1A8FQE(&-O;'5M;G,](B5D(CXG+"`D;6%X
M*3L*"B`@("`@("`@<&%R96YT.CI?<F5N9&5R5&%B;&4H)'1A8FQE*3L*"B`@
M("`@("`@+R\@5&5R;6EN871E('1A8FQE+@H@("`@("`@(&5C:&\@)SPO=&%B
M;&4^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4&AO;F4H)B1P:&]N
M92D*("`@('L*("`@("`@("`D=&ET;&4@/2`D<&AO;F4M/F=E="@G=&ET;&4G
M*3L*("`@("`@("`D=&ET;&5?;W!T:6]N(#T@*"1T:71L92`_('-P<FEN=&8H
M)R!T:71L93TB)7,B)RP@)'1H:7,M/F5S8V%P92@D=&ET;&4I*2`Z("<G*3L*
M"B`@("`@("`@<')I;G1F*"<\825S(&AR968](G=T86DZ+R]W<"]M8SLE<R(^
M)7,\+V$^)RP@)'1I=&QE7V]P=&EO;BP*("`@("`@("`@("`@("`@<W1R7W)E
M<&QA8V4H)RLG+"`G)3)")RP@)'!H;VYE+3YG970H)VYU;6)E<B<I*2P@)'!H
M;VYE+3YG970H)VQA8F5L)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)2=6QE*"8D<G5L92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FAA<U%U
M:7)K*"=O=U]G=6E?,2XS)RDI('L*("`@("`@("`@("`@+R\@5T%0(&1E=FEC
M92!A8V-E<'1S($]P96YW879E($=522!E>'1E;G-I;VYS(&9O<B!734P@,2XS
M"B`@("`@("`@("`@("1W:61T:"`]("1R=6QE+3YG970H)W=I9'1H)RD["B`@
M("`@("`@("`@("1S:7IE(#T@)')U;&4M/F=E="@G<VEZ92<I.PH*("`@("`@
M("`@("`@96-H;R`G/&AR)R`N("@D=VED=&@@/R`G('=I9'1H/2(G("X@)'=I
M9'1H("X@)R(G(#H@)R<I("X@*"1S:7IE(#\@)R!S:7IE/2(G("X@)'-I>F4@
M+B`G(B<@.B`G)RD@+B`G("\^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O+R!705`@9&5V:6-E(&1O97,@;F]T('5N9&5R<W1A;F0@/&AR("\^
M('1A9W,N"B`@("`@("`@("`@("\O(#T]/B!D<F%W('-O;64@;G5M8F5R(&]F
M(&AY<&AE;G,@=&\@8W)E871E(&$@<G5L90H@("`@("`@("`@("!E8VAO("<M
M+2TM+2TM+2TM/&)R("\^)SL*("`@("`@("!]"B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O36]B:6QE+U)E;F1E<F5R+G!H<```````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q,C`V`#$P-#$W,S8R-S<Q`#`R
M,3<Q-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@2&]R9&5?36]B:6QE7U)E;F1E<F5R.CH@9G)A;65W
M;W)K(&9O<B!M;V)I;&4@9&5V:6-E(&UA<FMU<`H@*B!R96YD97)E<G,N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TUO8FEL92]-;V)I;&4O4F5N9&5R97(N
M<&AP+'8@,2XQ-2XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,C8@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@
M2&]R9&5?36]B:6QE7U)E;F1E<F5R(&5X=&5N9',@2&]R9&5?36]B:6QE('L*
M"B`@("!V87(@)%]B<F]W<V5R.PH*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL
M95]296YD97)E<B@D8G)O=W-E<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7VYU;&PH)&)R;W=S97(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8G)O
M=W-E<B`]("9N97<@0G)O=W-E<B@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3Y?8G)O=W-E<B`]("1B<F]W<V5R.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!I<T)R;W=S97(H)&%G96YT*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V)R;W=S97(M/FES0G)O=W-E<B@D86=E
M;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&AA<U%U:7)K*"1Q=6ER:RD*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B<F]W<V5R+3YH87-1=6ER:R@D
M<75I<FLI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R(&%N>2!(;W)D
M95]-;V)I;&5?96QE;65N="!O8FIE8W0N($QO;VMS(&9O<B!T:&4*("`@("`J
M(&%P<')O<')I871E(')E;F1E<FEN9R!F=6YC=&EO;B!I;B!T:&4@<F5N9&5R
M97([(&EF('1H97)E(&ES;B=T"B`@("`@*B!O;F4L('=E(&EG;F]R92!T:&ES
M(&5L96UE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7TUO8FEL95]E
M;&5M96YT("1E;&5M96YT("!4:&4@96QE;65N="!T;R!R96YD97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;F1E<D5L96UE;G0H)B1E;&5M96YT*0H@("`@
M>PH@("`@("`@("1F=6YC(#T@)U]R96YD97(G("X@=6-F:7)S="AS=')?<F5P
M;&%C92@G:&]R9&5?;6]B:6QE7R<L("<G+"!S=')T;VQO=V5R*&=E=%]C;&%S
M<R@D96QE;65N="DI*2D["B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H
M:7,L("1F=6YC*2D@>PH@("`@("`@("`@("`D=&AI<RT^)&9U;F,H)&5L96UE
M;G0I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R0FQO
M8VLH)B1B;&]C:RD*("`@('L*("`@("`@("!I9B`H8V]U;G0H)&)L;V-K+3Y?
M96QE;65N=',I*2!["B`@("`@("`@("`@(&5C:&\@)SQP/B<["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1B;&]C:RT^7V5L96UE;G1S(&%S("1B;&]C:T5L96UE
M;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT*"1B
M;&]C:T5L96UE;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@
M(CPO<#Y<;B(["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)&;W)M*"8D9F]R;2D*("`@('L*("`@("`@("!F;W)E86-H("@D9F]R;2T^
M7V5L96UE;G1S(&%S("1F;W)M16QE;65N="D@>PH@("`@("`@("`@("`D=&AI
M<RT^<F5N9&5R16QE;65N="@D9F]R;45L96UE;G0I.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5&%B;&4H)B1T86)L92D*("`@('L*
M("`@("`@("!F;W)E86-H("@D=&%B;&4M/E]R;W=S(&%S("1R;W<I('L*("`@
M("`@("`@("`@)'1H:7,M/E]R96YD97)2;W<H)')O=RD["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)2;W<H)B1R;W<I"B`@("!["B`@
M("`@("`@96-H;R`G/'1R/B<["B`@("`@("`@9F]R96%C:"`H)')O=RT^7V-O
M;'5M;G,@87,@)&-O;'5M;BD@>PH@("`@("`@("`@("!E8VAO("<\=&0^)SL*
M("`@("`@("`@("`@+R\@0V%L;"!C<F5A=&4@9G5N8W1I;VX@9F]R(&5A8V@@
M8V5L;&5L96UE;G0@=&AA="!I<R!A"B`@("`@("`@("`@("\O($AO<F1E7TUO
M8FEL92!O8FIE8W0N"B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D8V]L=6UN
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E;F1E<D5L96UE;G0H)&-O
M;'5M;BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@96-H;R`G/"]T9#XG
M.PH@("`@("`@('T*("`@("`@("!E8VAO("(\+W1R/EQN(CL*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO
M<F1E7TUO8FEL95]296YD97)E<B!I;G-T86YC90H@("`@("H@8F%S960@;VX@
M)'1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@("`@
M(%1H92!K:6YD(&]F(&UA<FMU<"`H:'1M;"P@:&1M;"P@=VUL*2!W92!W86YT
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9V5N97)A=&4N
M"B`@("`@*B!`<&%R86T@0G)O=W-E<B`D8G)O=W-E<B`@5&AE($)R;W=S97(@
M;V)J96-T('1O('5S92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@
M("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@;W!T:6]N<R!F;W(@=&AE(')E;F1E
M<F5R+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?36]B:6QE7U)E;F1E
M<F5R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E7TUO8FEL95]296YD97)E
M<B!I;G-T86YC92P@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N(&%N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D='EP92P@)&)R;W=S97(@/2!N
M=6QL+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D='EP92`]
M(&)A<V5N86UE*"1T>7!E*3L*"B`@("`@("`@:68@*$!F:6QE7V5X:7-T<RAD
M:7)N86UE*%]?1DE,15]?*2`N("<O4F5N9&5R97(O)R`N("1T>7!E("X@)RYP
M:'`G*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+U)E;F1E<F5R+R<@+B`D='EP92`N("<N<&AP)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]-
M;V)I;&4O4F5N9&5R97(O)R`N("1T>7!E("X@)RYP:'`G.PH@("`@("`@('T*
M"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7TUO8FEL95]296YD97)E<E\G("X@
M)'1Y<&4["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@
M("`@("`@("`@("1R96YD97)E<B`]("9N97<@)&-L87-S*"1B<F]W<V5R+"`D
M<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5N9&5R
M97(@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@
M+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<F5N9&5R97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]-;V)I;&5?4F5N9&5R
M97(@:6YS=&%N8V4*("`@("`J(&)A<V5D(&]N("1T>7!E+B!)="!W:6QL(&]N
M;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO"B`@("`@*B!R96YD97)E
M<B!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@5&AE(&MI
M;F0@;V8@;6%R:W5P("AH=&UL+"!H9&UL+"!W;6PI('=E('=A;G0@=&\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!G96YE<F%T92X*("`@("`J
M($!P87)A;2!"<F]W<V5R("1B<F]W<V5R("!4:&4@0G)O=W-E<B!O8FIE8W0@
M=&\@=7-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S
M:"!C;VYT86EN:6YG(&%N>2!O<'1I;VYS(&9O<B!T:&4@<F5N9&5R97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!(;W)D95]-;V)I;&5?4F5N9&5R97(@(%1H
M92!N97=L>2!C<F5A=&5D(&-O;F-R971E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@2&]R9&5?36]B:6QE7U)E;F1E<F5R(&EN<W1A
M;F-E+"!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@86X@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH)'1Y<&4L("1B<F]W<V5R(#T@;G5L;"P@
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T
M86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D<VEG;F%T=7)E(#T@;60U*'-E
M<FEA;&EZ92AA<G)A>2@D='EP92P@)&)R;W=S97(L("1P87)A;7,I*2D["B`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@
M("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E7TUO
M8FEL95]296YD97)E<CHZ9F%C=&]R>2@D='EP92P@)&)R;W=S97(L("1P87)A
M;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I
M9VYA='5R95T["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1R964O````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W,0`P,3<Q,S(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M5')E92]J879A<V-R:7!T+G!H<```````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$S,30W`#$P-#$W,S8R-S<Q`#`R,C`Q-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($AO
M<F1E7U1R965?:F%V87-C<FEP=#HZ(&-L87-S(&5X=&5N9',@=&AE($AO<F1E
M7U1R964@8VQA<W,@=&\@<')O=FED90H@*B!J879A<V-R:7!T('-P96-I9FEC
M(')E;F1E<FEN9R!F=6YC=&EO;G,N"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1R964O5')E92]J879A<V-R:7!T
M+G!H<"QV(#$N,S0N,BXY(#(P,#8O,#$O,#$@,C$Z,C@Z-#`@:F%N($5X<"`D
M"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^
M"B`J($!P86-K86=E($AO<F1E7U1R964*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J+PIC;&%S<R!(;W)D95]4<F5E7VIA=F%S8W)I<'0@97AT96YD<R!(;W)D
M95]4<F5E('L*"B`@("`O*BH*("`@("`J(%1H92!N86UE(&]F('1H92!S;W5R
M8V4@9F]R('1H92!T<F5E(&1A=&$N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?<V]U<F-E7VYA;64@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('1A<F=E="!E;&5M96YT('1O
M(&]U='!U="!T:&4@:F%V87-C<FEP="!T<F5E+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G-?;F%M92`](&YU
M;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@=&%R9V5T(&5L
M96UE;G0@=&\@;W5T<'5T('1H92!J879A<V-R:7!T('1R964N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=&%R9V5T7VYA
M;64@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J
M+PH@("`@9G5N8W1I;VX@2&]R9&5?5')E95]J879A<V-R:7!T*"1T<F5E7VYA
M;64L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('!A<F5N=#HZ
M2&]R9&5?5')E92@D=')E95]N86UE+"`D<&%R86US*3L*"B`@("`@("`@:68@
M*"%I<W-E="@D1TQ/0D%,4ULG8G)O=W-E<B==*2D@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T)R;W=S97(N<&AP)SL*("`@("`@("`@("`@
M)$=,3T)!3%-;)V)R;W=S97(G72`]("9"<F]W<V5R.CIS:6YG;&5T;VXH*3L*
M("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O<B!A(&IA=F%S8W)I<'0@
M<V5S<VEO;B!S=&%T92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]U<V5S97-S
M:6]N("8F"B`@("`@("`@("`@(&ES<V5T*"1?0T]/2TE%6R1T:&ES+3Y?:6YS
M=&%N8V4@+B`G7V5X<&%N9&5D)UTI*2!["B`@("`@("`@("`@("\J(%)E;6]V
M92`B97AP(B!P<F5F:7@@9G)O;2!C;V]K:64@=F%L=64N("HO"B`@("`@("`@
M("`@("1N;V1E<R`](&5X<&QO9&4H)RPG+"!S=6)S='(H)%]#3T]+245;)'1H
M:7,M/E]I;G-T86YC92`N("=?97AP86YD960G72P@,RDI.PH*("`@("`@("`@
M("`@+RH@36%K92!S=7)E('1H97)E(&%R92!N;R!P<F5V:6]U<R!N;V1E<R!S
M=&]R960@:6X@=&AE"B`@("`@("`@("`@("`J('-E<W-I;VXN("HO"B`@("`@
M("`@("`@("1?4T534TE/3ELG:&]R9&5?=')E92==6R1T:&ES+3Y?:6YS=&%N
M8V5=6R=E>'!A;F1E9"==(#T@87)R87DH*3L*"B`@("`@("`@("`@("\J(%-A
M=F4@;F]D97,@=&\@=&AE('-E<W-I;VXN("HO"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1N;V1E<R!A<R`D:60I('L*("`@("`@("`@("`@("`@("1?4T534TE/
M3ELG:&]R9&5?=')E92==6R1T:&ES+3Y?:6YS=&%N8V5=6R=E>'!A;F1E9"==
M6R1I9%T@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=')E92X*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<W1A=&EC("!)9B!T<G5E('1H92!T<F5E(&YO
M9&5S(&-A;B=T(&)E(&5X<&%N9&5D(&%N9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@8V]L;&%P<V5D(&%N9"!T:&4@=')E92!G971S(')E;F1E
M<F5D(&5X<&%N9&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@2%1-3"!C;V1E(&]F('1H92!R96YD97)E9"!T<F5E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9714<F5E*"1S=&%T:6,@/2!F86QS92D*("`@('L*("`@
M("`@("`D=&AI<RT^7W-T871I8R`]("1S=&%T:6,["B`@("`@("`@)'1H:7,M
M/E]S;W5R8V5?;F%M92`]("=N7R<@+B`D=&AI<RT^7VEN<W1A;F-E.PH@("`@
M("`@("1T:&ES+3Y?:&5A9&5R7VYA;64@/2`G:%\G("X@)'1H:7,M/E]I;G-T
M86YC93L*("`@("`@("`D=&AI<RT^7V]P=&EO;G-?;F%M92`]("=O7R<@+B`D
M=&AI<RT^7VEN<W1A;F-E.PH@("`@("`@("1T:&ES+3Y?=&%R9V5T7VYA;64@
M/2`G=%\G("X@)'1H:7,M/E]I;G-T86YC93L*("`@("`@("`D=&AI<RT^7V)U
M:6QD26YD96YT<R@D=&AI<RT^7W)O;W1?;F]D97,I.PH*("`@("`@("`D=')E
M92`]("1T:&ES+3Y?9V5T5')E95-O=7)C92@I("X*("`@("`@("`@("`@("<\
M9&EV(&ED/2(G("X@)'1H:7,M/E]T87)G971?;F%M92`N("<B/CPO9&EV/B<@
M+@H@("`@("`@("`@("`@)'1H:7,M/E]G9714<F5E26YI="@I.PH*("`@("`@
M("!(;W)D93HZ861D4V-R:7!T1FEL92@G=')E92YJ<R<L("=H;W)D92<I.PH@
M("`@("`@(')E='5R;B`D=')E93L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K('1H92!C=7)R96YT(&5N=FER;VYM96YT('1O('-E92!I9B!W92!C86X@
M<F5N9&5R('1H92!(5$U,"B`@("`@*B!T<F5E+B!792!C:&5C:R!F;W(@1$]-
M('-U<'!O<G0@:6X@=&AE(&)R;W=S97(N"B`@("`@*@H@("`@("H@0'-T871I
M8PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@=&AI<R!4<F5E.CH@8F%C:V5N9"!W:6QL(&9U;F-T:6]N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<U-U<'!O<G1E9"@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<T9E871U<F4H)V1O;2<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!J=7-T('1H92!*4R!N;V1E
M(&1E9FEN:71I;VYS(&%S(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@2F%V87-C<FEP="!N;V1E(&%R<F%Y(&1E9FEN:71I
M;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97).;V1E1&5F:6YI=&EO
M;G,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8G5I;&1);F1E;G1S*"1T:&ES
M+3Y?<F]O=%]N;V1E<RD["@H@("`@("`@("1N;V1E2G,@/2`G)SL*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7VYO9&5S(&%S("1N;V1E7VED(#T^("1N;V1E
M*2!["B`@("`@("`@("`@("1N;V1E2G,@+CT@)'1H:7,M/E]G971*<T%R<F%Y
M16QE;65N="AS<')I;G1F*"<E<UM<)R5S7"==)RP@)VY?)R`N("1T:&ES+3Y?
M:6YS=&%N8V4L("1N;V1E7VED*2P@)&YO9&4I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1N;V1E2G,@+B`D=&AI<RT^7VEN<W1A;F-E("X@)RYR96YD
M97)4<F5E*')O;W1?;F]D97,I.R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/
M=71P=71S('1H92!D871A(&9O<B!T:&4@=')E92!A<R!A(&IA=F%S8W)I<'0@
M87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G9714<F5E4V]U<F-E*"D*("`@('L*("`@("`@("!G
M;&]B86P@)&)R;W=S97(["@H@("`@("`@("1J<R`@/2`G/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/B<@+B`B7&XB.PH@("`@("`@("1J<R`N/2`G
M=F%R(&5X=')A0V]L<TQE9G0@/2`G("X@)'1H:7,M/E]E>'1R85]C;VQS7VQE
M9G0@+B`B.UQN(CL*("`@("`@("`D:G,@+CT@)W9A<B!E>'1R84-O;'-2:6=H
M="`]("<@+B`D=&AI<RT^7V5X=')A7V-O;'-?<FEG:'0@+B`B.UQN(CL*("`@
M("`@("`D:G,@+CT@)W9A<B`G("X@)'1H:7,M/E]S;W5R8V5?;F%M92`N("<@
M/2!N97<@07)R87DH*3LG("X@(EQN(CL*"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]N;V1E<R!A<R`D;F]D95]I9"`]/B`D;F]D92D@>PH@("`@("`@("`@
M("`D:G,@+CT@)'1H:7,M/E]G971*<T%R<F%Y16QE;65N="AS<')I;G1F*"<E
M<UM<)R5S7"==)RP@)'1H:7,M/E]S;W5R8V5?;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8G)O
M=W-E<BT^97-C87!E2E-#;V1E*&%D9'-L87-H97,H)&YO9&5?:60I*2DL("1N
M;V1E*3L*("`@("`@("!]"B`@("`@("`@)&IS("X]("1T:&ES+3Y?9V5T2G-!
M<G)A>45L96UE;G0H)'1H:7,M/E]H96%D97)?;F%M92P@)'1H:7,M/E]H96%D
M97(I.PH@("`@("`@("1J<R`N/2`D=&AI<RT^7V=E=$IS07)R87E%;&5M96YT
M*"1T:&ES+3Y?;W!T:6]N<U]N86UE+"`D=&AI<RT^7V]P=&EO;G,I.PH@("`@
M("`@("1J<R`N/2`G/"]S8W)I<'0^)R`N(")<;B(["@H@("`@("`@(')E='5R
M;B`D:G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S('1H92!J879A
M<V-R:7!T('1O(&EN:71I86QI<V4@=&AE('1R964N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9714<F5E
M26YI="@I"B`@("!["B`@("`@("`@)&IS("`]("<\<V-R:7!T('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(^)R`N(")<;B(["B`@("`@("`@)&IS("X]('-P<FEN
M=&8H)R4Q)',@/2!N97<@2&]R9&5?5')E92A<)R4Q)'-<)RD[)R`N(")<;B(L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G-T86YC92D["@H@
M("`@("`@("1J<R`N/2`D=&AI<RT^7V=E=$IS07)R87E%;&5M96YT*"=R;V]T
M7VYO9&5S)RP@)'1H:7,M/E]R;V]T7VYO9&5S*3L*"B`@("`@("`@)&IS("X]
M('-P<FEN=&8H(B5S+G)E;F1E<E1R964H<F]O=%]N;V1E<RP@)7,I.UQN/"]S
M8W)I<'0^7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YS
M=&%N8V4L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T:6,@
M/R`G=')U92<@.B`G9F%L<V4G*3L*"B`@("`@("`@<F5T=7)N("1J<SL*("`@
M('T*"B`@("!F=6YC=&EO;B!?9V5T2G-!<G)A>45L96UE;G0H)'9A<BP@)'9A
M;'5E*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2!["B`@
M("`@("`@("`@("1J<R`]("1V87(@+B`G(#T@;F5W($%R<F%Y*"D[)R`N(")<
M;B(["B`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1K97DI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&YE=U9A<B`]("1V87(@+B`G6R<@+B`D
M:V5Y("X@)UTG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D;F5W5F%R(#T@)'9A<B`N("=;7"<G("X@)&ME>2`N("=<
M)UTG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&IS("X]
M("1T:&ES+3Y?9V5T2G-!<G)A>45L96UE;G0H)&YE=U9A<BP@)'9A;"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1J<SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'9A<B`N("(@/2`G(B`N(&%D
M9'-L87-H97,H)'9A;'5E*2`N("(G.UQN(CL*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4<F5E
M+VAT;6PN<&AP````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M-#(Q,C4`,3`T,3<S-C(W-S$`,#(P-C$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?
M5')E95]H=&UL.CH@8VQA<W,@97AT96YD<R!T:&4@2&]R9&5?5')E92!C;&%S
M<R!T;R!P<F]V:61E"B`J($A434P@<W!E8VEF:6,@<F5N9&5R:6YG(&9U;F-T
M:6]N<RX*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@
M/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO5')E92]4<F5E+VAT;6PN<&AP+'8@,2XU,2XR+C$R(#(P,#8O
M,#$O,34@,38Z,S,Z,CD@8VAU8VL@17AP("0*("H*("H@0&%U=&AO<B`@36%R
M:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@2&]R9&5?
M5')E90H@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F-L87-S($AO<F1E7U1R
M965?:'1M;"!E>'1E;F1S($AO<F1E7U1R964@>PH*("`@("\J*@H@("`@("H@
M26UA9V4@9&ER96-T;W)Y(&QO8V%T:6]N+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]D:7(@/2`G)SL*"B`@("`O
M*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&QI;F4N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG
M7VQI;F4@/2`G;&EN92YP;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T
M<F5E(&=R87!H:6,@9F]R(&$@8FQA;FLN"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG7V)L86YK(#T@)V)L86YK+G!N
M9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@
M82!J;VEN+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7VEM9U]J;VEN(#T@)VIO:6XN<&YG)SL*"B`@("`O*BH*("`@("`J
M($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&)O='1O;2!J;VEN+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]J
M;VEN7V)O='1O;2`]("=J;VEN8F]T=&]M+G!N9R<["@H@("`@+RHJ"B`@("`@
M*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!P;'5S+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]P;'5S(#T@
M)W!L=7,N<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P
M:&EC(&9O<B!A(&)O='1O;2!P;'5S+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]P;'5S7V)O='1O;2`]("=P;'5S
M8F]T=&]M+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A
M<&AI8R!F;W(@82!P;'5S(&]N;'DN"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?:6UG7W!L=7-?;VYL>2`]("=P;'5S;VYL
M>2YP;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@
M9F]R(&$@;6EN=7,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?:6UG7VUI;G5S(#T@)VUI;G5S+G!N9R<["@H@("`@+RHJ
M"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!B;W1T;VT@;6EN
M=7,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?:6UG7VUI;G5S7V)O='1O;2`]("=M:6YU<V)O='1O;2YP;F<G.PH*("`@
M("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@;6EN=7,@
M;VYL>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]I;6=?;6EN=7-?;VYL>2`]("=M:6YU<V]N;'DN<&YG)SL*"B`@("`O
M*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&YU;&P@;VYL
M>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]I;6=?;G5L;%]O;FQY(#T@)VYU;&QO;FQY+G!N9R<["@H@("`@+RHJ"B`@
M("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!F;VQD97(N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG7V9O
M;&1E<B`]("=F;VQD97(N<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@
M=')E92!G<F%P:&EC(&9O<B!A;B!O<&5N(&9O;&1E<BX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?9F]L9&5R7V]P
M96X@/2`G9F]L9&5R;W!E;BYP;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L
M="!T<F5E(&=R87!H:6,@9F]R(&$@;&5A9BX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?;&5A9B`]("=L96%F+G!N
M9R<["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]N;V1E<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]N;V1E7W!O<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]D<F]P;&EN92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#
M=7)R96YT('9A;'5E(&]F('1H92!A;'0@=&%G(&-O=6YT+@H@("`@("H*("`@
M("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]A;'1?8V]U;G0@
M/2`P.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?5')E95]H=&UL*"1T<F5E7VYA;64L("1P87)A;7,I
M"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D95]4<F5E*"1T<F5E7VYA;64L
M("1P87)A;7,I.PH*("`@("`@("`D=&AI<RT^7VEM9U]D:7(@/2`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RD@+B`G+W1R964G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=')E92X*("`@
M("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A=&EC("!)9B!T<G5E('1H
M92!T<F5E(&YO9&5S(&-A;B=T(&)E(&5X<&%N9&5D(&%N9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@8V]L;&%P<V5D(&%N9"!T:&4@=')E92!G
M971S(')E;F1E<F5D(&5X<&%N9&5D+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@2%1-3"!C;V1E(&]F('1H92!R96YD97)E9"!T<F5E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714<F5E*"1S=&%T:6,@/2!F86QS92D*
M("`@('L*("`@("`@("`D=&AI<RT^7W-T871I8R`]("1S=&%T:6,["B`@("`@
M("`@)'1H:7,M/E]B=6EL9$EN9&5N=',H)'1H:7,M/E]R;V]T7VYO9&5S*3L*
M"B`@("`@("`@)'1R964@/2`D=&AI<RT^7V)U:6QD2&5A9&5R*"D["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]R;V]T7VYO9&5S(&%S("1N;V1E7VED*2![
M"B`@("`@("`@("`@("1T<F5E("X]("1T:&ES+3Y?8G5I;&14<F5E*"1N;V1E
M7VED*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T<F5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VAE8VL@=&AE(&-U<G)E;G0@96YV:7)O;FUE;G0@
M=&\@<V5E(&EF('=E(&-A;B!R96YD97(@=&AE($A434P*("`@("`J('1R964N
M($A434P@:7,@86QW87ES(')E;F1E<F%B;&4L(&%T(&QE87-T('5N=&EL('=E
M(&%D9"!A"B`@("`@*B!P:'`M9W1K('1R964@8F%C:V5N9"P@:6X@=VAI8V@@
M8V%S92!T:&ES(&EM<&QE;65N=&%T:6]N('=I;&P*("`@("`J(&%C='5A;&QY
M(&YE960@82!B;V1Y+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H:7,@5')E
M93HZ(&)A8VME;F0@=VEL;"!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-3=7!P;W)T960H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!J=7-T('1H92!*4R!N;V1E
M(&1E9FEN:71I;VYS(&%S(&$@<W1R:6YG+B!4:&ES(&ES(&$*("`@("`J(&YO
M+6]P(&9O<B!T:&4@2%1-3"!R96YD97)E<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5N9&5R3F]D941E9FEN:71I;VYS*"D*("`@('L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE($A434P@8V]D92!F;W(@82!H96%D97(@
M<F]W+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&-O
M9&4@;V8@=&AE(&AE861E<B!R;W<@;W(@86X@96UP='D@<W1R:6YG+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8G5I;&1(96%D97(H*0H@("`@>PH@("`@("`@
M(&EF("@A8V]U;G0H)'1H:7,M/E]H96%D97(I*2!["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("1H=&UL(#T@)SQD:78G.PH@
M("`@("`@("\J($EF('5S:6YG(&%L=&5R;F%T:6YG(')O=R!S:&%D:6YG+"!W
M;W)K(&]U="!C;W)R96-T"B`@("`@("`@("H@<VAA9&4N("HO"B`@("`@("`@
M:68@*"1T:&ES+3YG971/<'1I;VXH)V%L=&5R;F%T92<I*2!["B`@("`@("`@
M("`@("1H=&UL("X]("<@8VQA<W,](FET96TG("X@)'1H:7,M/E]A;'1?8V]U
M;G0@+B`G(B<["B`@("`@("`@("`@("1T:&ES+3Y?86QT7V-O=6YT(#T@,2`M
M("1T:&ES+3Y?86QT7V-O=6YT.PH@("`@("`@('T*("`@("`@("`D:'1M;"`N
M/2`G/B<["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:&5A9&5R(&%S("1H
M96%D97(I('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQD:78@8VQA<W,](FQE
M9G1&;&]A="<["B`@("`@("`@("`@(&EF("@A96UP='DH)&AE861E<ELG8VQA
M<W,G72DI('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<@)R`N("1H96%D
M97);)V-L87-S)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@
M+CT@)R(G.PH*("`@("`@("`@("`@)'-T>6QE(#T@)R<["B`@("`@("`@("`@
M(&EF("@A96UP='DH)&AE861E<ELG=VED=&@G72DI('L*("`@("`@("`@("`@
M("`@("1S='EL92`N/2`G=VED=&@Z)R`N("1H96%D97);)W=I9'1H)UT@+B`G
M.R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D:&5A
M9&5R6R=A;&EG;B==*2D@>PH@("`@("`@("`@("`@("`@)'-T>6QE("X]("=T
M97AT+6%L:6=N.B<@+B`D:&5A9&5R6R=A;&EG;B==("X@)SLG.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)'-T>6QE*2D@>PH@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@)R!S='EL93TB)R`N("1S='EL92`N("<B
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/B<["B`@
M("`@("`@("`@("1H=&UL("X](&5M<'1Y*"1H96%D97);)VAT;6PG72D@/R`G
M)FYB<W`[)R`Z("1H96%D97);)VAT;6PG73L*("`@("`@("`@("`@)&AT;6P@
M+CT@)SPO9&EV/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P@
M+B`G/"]D:78^)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E8W5R<VEV92!F
M=6YC=&EO;B!T;R!W86QK('1H<F]U9V@@=&AE('1R964@87)R87D@86YD(&)U
M:6QD('1H92!O=71P=70N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F]D95]I9"`@5&AE($YO
M9&4@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T<F5E
M(')E;F1E<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD5')E92@D
M;F]D95]I9"D*("`@('L*("`@("`@("`D;W5T<'5T(#T@)'1H:7,M/E]B=6EL
M9$QI;F4H)&YO9&5?:60I.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI("8F"B`@("`@("`@("`@("1T
M:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'!A;F1E9"==*2!["B`@("`@("`@
M("`@("1N=6U?<W5B;F]D97,@/2!C;W5N="@D=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG8VAI;&1R96XG72D["B`@("`@("`@("`@(&9O<B`H)&,@/2`P.R`D
M8R`\("1N=6U?<W5B;F]D97,[("1C*RLI('L*("`@("`@("`@("`@("`@("1C
M:&EL9%]N;V1E7VED(#T@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD
M<F5N)UU;)&-=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]N;V1E7W!O<ULD
M8VAI;&1?;F]D95]I9%T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]N;V1E7W!O<ULD8VAI;&1?;F]D95]I9%U;)W!O<R==(#T@)&,@*R`Q
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]N;V1E7W!O<ULD8VAI;&1?;F]D
M95]I9%U;)V-O=6YT)UT@/2`D;G5M7W-U8FYO9&5S.PH@("`@("`@("`@("`@
M("`@)&]U='!U="`N/2`D=&AI<RT^7V)U:6QD5')E92@D8VAI;&1?;F]D95]I
M9"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@8W)E
M871E(&$@<VEN9VQE(&QI;F4@;V8@=&AE('1R964N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F]D95]I9"`@5&AE($YO9&4@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!R96YD97)E9"!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8G5I;&1,:6YE*"1N;V1E7VED*0H@("`@>PH@("`@("`@("1C;&%S<TYA
M;64@/2`G=')E95)O=R<["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VYO
M9&5S6R1N;V1E7VED75LG8VQA<W,G72DI('L*("`@("`@("`@("`@)&-L87-S
M3F%M92`N/2`G("<@+B`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG8VQA<W,G
M73L*("`@("`@("!]"B`@("`@("`@+RH@268@=7-I;F<@86QT97)N871I;F<@
M<F]W('-H861I;F<L('=O<FL@;W5T(&-O<G)E8W0*("`@("`@("`@*B!S:&%D
M92X@*B\*("`@("`@("!I9B`H)'1H:7,M/F=E=$]P=&EO;B@G86QT97)N871E
M)RDI('L*("`@("`@("`@("`@)&-L87-S3F%M92`N/2`G(&ET96TG("X@)'1H
M:7,M/E]A;'1?8V]U;G0["B`@("`@("`@("`@("1T:&ES+3Y?86QT7V-O=6YT
M(#T@,2`M("1T:&ES+3Y?86QT7V-O=6YT.PH@("`@("`@('T*"B`@("`@("`@
M)&QI;F4@/2`G/&1I=B!C;&%S<STB)R`N("1C;&%S<TYA;64@+B`G(CXG.PH*
M("`@("`@("`O*B!)9B!W92!H879E(&AE861E<G,L('1R86-K('=H:6-H(&QO
M9VEC86P@(F-O;'5M;B(@=V4G<F4@:6X*("`@("`@("`@*B!F;W(@86YY(&=I
M=F5N(&-E;&P@;V8@8V]N=&5N="X@*B\*("`@("`@("`D8V]L=6UN(#T@,#L*
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E
M>'1R82==6TA/4D1%7U12145?15A44D%?3$5&5%TI*2!["B`@("`@("`@("`@
M("1E>'1R82`]("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'1R82==6TA/
M4D1%7U12145?15A44D%?3$5&5%T["B`@("`@("`@("`@("1C36%X(#T@8V]U
M;G0H)&5X=')A*3L*("`@("`@("`@("`@9F]R("@D8R`](#`[("1C(#P@)&--
M87@[("1C*RLI('L*("`@("`@("`@("`@("`@("1S='EL92`]("<G.PH@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R6R1C;VQU;6Y=
M6R=W:61T:"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1S='EL92`N/2`G
M=VED=&@Z)R`N("1T:&ES+3Y?:&5A9&5R6R1C;VQU;6Y=6R=W:61T:"==("X@
M)SLG.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1L:6YE
M("X]("<\9&EV(&-L87-S/2)L969T1FQO870B)SL*("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)'-T>6QE*2D@>PH@("`@("`@("`@("`@("`@("`@("1L
M:6YE("X]("<@<W1Y;&4](B<@+B`D<W1Y;&4@+B`G(B<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D;&EN92`N/2`G/B<@+B`D97AT<F%;
M)&-=("X@)SPO9&EV/B<["@H@("`@("`@("`@("`@("`@)&-O;'5M;BLK.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W1Y;&4@/2`G)SL*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]H96%D97);)&-O;'5M;EU;)W=I
M9'1H)UTI*2!["B`@("`@("`@("`@("1S='EL92`N/2`G=VED=&@Z)R`N("1T
M:&ES+3Y?:&5A9&5R6R1C;VQU;6Y=6R=W:61T:"==("X@)SLG.PH@("`@("`@
M('T*("`@("`@("`D;&EN92`N/2`G/&1I=B!C;&%S<STB;&5F=$9L;V%T(B<[
M"B`@("`@("`@:68@*"%E;7!T>2@D<W1Y;&4I*2!["B`@("`@("`@("`@("1L
M:6YE("X]("<@<W1Y;&4](B<@+B`D<W1Y;&4@+B`G(B<["B`@("`@("`@?0H@
M("`@("`@("1L:6YE("X]("<^)SL*"B`@("`@("`@:68@*"1T:&ES+3YG971/
M<'1I;VXH)VUU;'1I;&EN92<I*2!["B`@("`@("`@("`@("1L:6YE("X]("<\
M=&%B;&4@8V5L;'-P86-I;F<](C`B/CQT<CX\=&0^)SL*("`@("`@("!]"@H@
M("`@("`@(&9O<B`H)&D@/2`D=&AI<RT^7W-T871I8R`_(#$@.B`P.R`D:2`\
M("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I;F1E;G0G73L@)&DK*RD@>PH@
M("`@("`@("`@("`D;&EN92`N/2`G/&EM9R!S<F,](B<@+B`D=&AI<RT^7VEM
M9U]D:7(@+B`G+R<["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V1R;W!L:6YE
M6R1I72`F)B`D=&AI<RT^9V5T3W!T:6]N*"=L:6YE<R<L(&9A;'-E+"!T<G5E
M*2D@>PH@("`@("`@("`@("`@("`@)&QI;F4@+CT@)'1H:7,M/E]I;6=?;&EN
M92`N("<B("<*("`@("`@("`@("`@("`@("`@("`N("=A;'0](GPF;F)S<#LF
M;F)S<#LF;F)S<#LB("<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D;&EN92`N/2`D=&AI<RT^7VEM9U]B;&%N:R`N("<B("<*("`@
M("`@("`@("`@("`@("`@("`N("=A;'0](B9N8G-P.R9N8G-P.R9N8G-P.R(@
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&EN92`N/2`G:&5I9VAT
M/2(R,"(@=VED=&@](C(P(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE
M(B`O/B<["B`@("`@("`@?0H@("`@("`@("1L:6YE("X]("1T:&ES+3Y?<V5T
M3F]D951O9V=L92@D;F]D95]I9"D@+B`D=&AI<RT^7W-E=$YO9&5)8V]N*"1N
M;V1E7VED*3L*("`@("`@("!I9B`H)'1H:7,M/F=E=$]P=&EO;B@G;75L=&EL
M:6YE)RDI('L*("`@("`@("`@("`@)&QI;F4@+CT@)SPO=&0^/'1D/B<["B`@
M("`@("`@?0H@("`@("`@("1L:6YE("X]("1T:&ES+3Y?<V5T3&%B96PH)&YO
M9&5?:60I.PH*("`@("`@("!I9B`H)'1H:7,M/F=E=$]P=&EO;B@G;75L=&EL
M:6YE)RDI('L*("`@("`@("`@("`@)&QI;F4@+CT@)SPO=&0^/"]T<CX\+W1A
M8FQE/B<["B`@("`@("`@?0H*("`@("`@("`D;&EN92`N/2`G/"]D:78^)SL*
M("`@("`@("`D8V]L=6UN*RL["@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7VYO9&5S6R1N;V1E7VED75LG97AT<F$G75M(3U)$15]44D5%7T585%)!7U))
M1TA472DI('L*("`@("`@("`@("`@)&5X=')A(#T@)'1H:7,M/E]N;V1E<ULD
M;F]D95]I9%U;)V5X=')A)UU;2$]21$5?5%)%15]%6%1205]224=(5%T["B`@
M("`@("`@("`@("1C36%X(#T@8V]U;G0H)&5X=')A*3L*("`@("`@("`@("`@
M9F]R("@D8R`](#`[("1C(#P@)&--87@[("1C*RLI('L*("`@("`@("`@("`@
M("`@("1S='EL92`]("<G.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?:&5A9&5R6R1C;VQU;6Y=6R=W:61T:"==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1S='EL92`N/2`G=VED=&@Z)R`N("1T:&ES+3Y?:&5A9&5R
M6R1C;VQU;6Y=6R=W:61T:"==("X@)SLG.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1L:6YE("X]("<\9&EV(&-L87-S/2)L969T1FQO
M870B)SL*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'-T>6QE*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1L:6YE("X]("<@<W1Y;&4](B<@+B`D<W1Y
M;&4@+B`G(B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M;&EN92`N/2`G/B<@+B`D97AT<F%;)&-=("X@)SPO9&EV/B<["@H@("`@("`@
M("`@("`@("`@)&-O;'5M;BLK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&QI;F4@+B`B/"]D:78^7&XB.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@;&%B96P@;VX@=&AE('1R964@;&EN92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N;V1E7VED("!4:&4@3F]D92!)1"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&QA8F5L(&9O<B!T:&4@=')E92!L
M:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T3&%B96PH)&YO9&5?:60I
M"B`@("!["B`@("`@("`@)&X@/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED73L*
M"B`@("`@("`@)&]U='!U="`]("<\<W!A;B<["B`@("`@("`@:68@*"%E;7!T
M>2@D;ELG;VYC;&EC:R==*2D@>PH@("`@("`@("`@("`D;W5T<'5T("X]("<@
M;VYC;&EC:STB)R`N("1N6R=O;F-L:6-K)UT@+B`G(B<["B`@("`@("`@?0H@
M("`@("`@("1O=71P=70@+CT@)SXG.PH*("`@("`@("`D;&%B96P@/2`D;ELG
M;&%B96PG73L*("`@("`@("!I9B`H(65M<'1Y*"1N6R=U<FPG72DI('L*("`@
M("`@("`@("`@)'1A<F=E="`]("<G.PH@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1N6R=T87)G970G72DI('L*("`@("`@("`@("`@("`@("1T87)G970@/2`G
M('1A<F=E=#TB)R`N("1N6R=T87)G970G72`N("<B)SL*("`@("`@("`@("`@
M?2!E;'-E:68@*"1T87)G970@/2`D=&AI<RT^9V5T3W!T:6]N*"=T87)G970G
M*2D@>PH@("`@("`@("`@("`@("`@)'1A<F=E="`]("<@=&%R9V5T/2(G("X@
M)'1A<F=E="`N("<B)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T
M<'5T("X]("<\82<@+B`H(65M<'1Y*"1N6R=U<FQC;&%S<R==*2`_("<@8VQA
M<W,](B<@+B`D;ELG=7)L8VQA<W,G72`N("<B)R`Z("<G*2`N("<@:')E9CTB
M)R`N("1N6R=U<FPG72`N("<B)R`N("1T87)G970@+B`G/B<@+B`D;&%B96P@
M+B`G/"]A/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]U='!U
M="`N/2`D;&%B96P["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U
M="`N("<\+W-P86X^)SL*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE
M(&YO9&4@=&]G9VQE(&]N('1H92!T<F5E(&QI;F4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F]D95]I9"`@5&AE($YO9&4@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!N;V1E('1O9V=L92!F;W(@=&AE('1R964@;&EN92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-E=$YO9&54;V=G;&4H)&YO9&5?:60I"B`@
M("!["B`@("`@("`@)&QI;FM?<W1A<G0@/2`G)SL*"B`@("`@("`@:68@*"@D
M=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6YD96YT)UT@/3T@,"D@)B8*("`@
M("`@("`@("`@:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD
M<F5N)UTI*2!["B`@("`@("`@("`@("\J(%1O<"!L979E;"!N;V1E('=I=&@@
M8VAI;&1R96XN("HO"B`@("`@("`@("`@("1T:&ES+3Y?9')O<&QI;F5;,%T@
M/2!F86QS93L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&EC*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@("`@('T@96QS96EF
M("@A)'1H:7,M/F=E=$]P=&EO;B@G;&EN97,G+"!F86QS92P@=')U92DI('L*
M("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]B;&%N:SL*("`@
M("`@("`@("`@("`@("1A;'0@/2`G)FYB<W`[)FYB<W`[)FYB<W`[)SL*("`@
M("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E
M>'!A;F1E9"==*2!["B`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I
M;6=?;6EN=7-?;VYL>3L*("`@("`@("`@("`@("`@("1A;'0@/2`G+2<["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:6UG(#T@)'1H
M:7,M/E]I;6=?<&QU<U]O;FQY.PH@("`@("`@("`@("`@("`@)&%L="`]("<K
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<W1A
M=&EC*2!["B`@("`@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE
M=&5R*$AO<F1E.CIS96QF57)L*"DL($A/4D1%7U12145?5$]'1TQ%("X@)'1H
M:7,M/E]I;G-T86YC92P@)&YO9&5?:60I.PH@("`@("`@("`@("`@("`@)&QI
M;FM?<W1A<G0@/2!(;W)D93HZ;&EN:R@D=7)L*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS96EF("@H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN
M9&5N="==("$](#`I("8F"B`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7VYO
M9&5S6R1N;V1E7VED75LG8VAI;&1R96XG72DI('L*("`@("`@("`@("`@+RH@
M3F]D92!W:71H;W5T(&-H:6QD<F5N+B`J+PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]N;V1E7W!O<ULD;F]D95]I9%U;)W!O<R==(#P@)'1H:7,M/E]N;V1E
M7W!O<ULD;F]D95]I9%U;)V-O=6YT)UTI('L*("`@("`@("`@("`@("`@("\J
M($YO="!L87-T(&YO9&4N("HO"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/F=E=$]P=&EO;B@G;&EN97,G+"!F86QS92P@=')U92DI('L*("`@("`@("`@
M("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?:F]I;CL*("`@("`@("`@
M("`@("`@("`@("`D86QT(#T@)WPM)SL*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7V)L
M86YK.PH@("`@("`@("`@("`@("`@("`@("1A;'0@/2`G)FYB<W`[)FYB<W`[
M)FYB<W`[)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9')O<&QI;F5;)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN9&5N
M="==72`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`O*B!,87-T(&YO9&4N("HO"B`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/F=E=$]P=&EO;B@G;&EN97,G+"!F86QS92P@=')U92DI('L*("`@("`@
M("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?:F]I;E]B;W1T;VT[
M"B`@("`@("`@("`@("`@("`@("`@)&%L="`]("=@+2<["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI
M<RT^7VEM9U]B;&%N:SL*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)R9N
M8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1R;W!L:6YE6R1T:&ES+3Y?;F]D97-;)&YO9&5?
M:61=6R=I;F1E;G0G75T@/2!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS96EF("AI<W-E="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG8VAI
M;&1R96XG72DI('L*("`@("`@("`@("`@+RH@3F]D92!W:71H(&-H:6QD<F5N
M+B`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]N;V1E7W!O<ULD;F]D95]I
M9%U;)W!O<R==(#P@)'1H:7,M/E]N;V1E7W!O<ULD;F]D95]I9%U;)V-O=6YT
M)UTI('L*("`@("`@("`@("`@("`@("\J($YO="!L87-T(&YO9&4N("HO"B`@
M("`@("`@("`@("`@("!I9B`H(21T:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@
M9F%L<V4L('1R=64I*2!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]("1T
M:&ES+3Y?:6UG7V)L86YK.PH@("`@("`@("`@("`@("`@("`@("1A;'0@/2`G
M)FYB<W`[)FYB<W`[)FYB<W`[)SL*("`@("`@("`@("`@("`@('T@96QS96EF
M("@D=&AI<RT^7W-T871I8RD@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@
M/2`D=&AI<RT^7VEM9U]J;VEN.PH@("`@("`@("`@("`@("`@("`@("1A;'0@
M/2`G?"TG.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?;F]D
M97-;)&YO9&5?:61=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@("`@("`@
M("`@)&EM9R`]("1T:&ES+3Y?:6UG7VUI;G5S.PH@("`@("`@("`@("`@("`@
M("`@("1A;'0@/2`G+2<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]P;'5S.PH@("`@
M("`@("`@("`@("`@("`@("1A;'0@/2`G*R<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1R;W!L:6YE6R1T:&ES+3Y?;F]D
M97-;)&YO9&5?:61=6R=I;F1E;G0G75T@/2!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@3&%S="!N;V1E+B`J+PH@("`@
M("`@("`@("`@("`@:68@*"$D=&AI<RT^9V5T3W!T:6]N*"=L:6YE<R<L(&9A
M;'-E+"!T<G5E*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI
M<RT^7VEM9U]B;&%N:SL*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)R9N
M8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)'1H:7,M/E]S=&%T:6,I('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@
M)'1H:7,M/E]I;6=?:F]I;E]B;W1T;VT["B`@("`@("`@("`@("`@("`@("`@
M)&%L="`]("=@+2<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M
M/E]N;V1E<ULD;F]D95]I9%U;)V5X<&%N9&5D)UTI('L*("`@("`@("`@("`@
M("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?;6EN=7-?8F]T=&]M.PH@("`@
M("`@("`@("`@("`@("`@("1A;'0@/2`G+2<["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM
M9U]P;'5S7V)O='1O;3L*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)RLG
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M<F]P;&EN95LD=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6YD96YT)UU=(#T@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M7W-T871I8RD@>PH@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A
M<F%M971E<BA(;W)D93HZ<V5L9E5R;"@I+"!(3U)$15]44D5%7U1/1T=,12`N
M("1T:&ES+3Y?:6YS=&%N8V4L("1N;V1E7VED*3L*("`@("`@("`@("`@("`@
M("1L:6YK7W-T87)T(#T@2&]R9&4Z.FQI;FLH)'5R;"D["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!4;W`@;&5V96P@
M;F]D92!W:71H(&YO(&-H:6QD<F5N+B`J+PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]S=&%T:6,I('L*("`@("`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/F=E=$]P=&EO;B@G
M;&EN97,G+"!F86QS92P@=')U92DI('L*("`@("`@("`@("`@("`@("1I;6<@
M/2`D=&AI<RT^7VEM9U]N=6QL7V]N;'D["B`@("`@("`@("`@("`@("`D86QT
M(#T@)R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?8FQA;FL["B`@("`@("`@
M("`@("`@("`D86QT(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]D<F]P;&EN95LP72`](&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)&QI;FM?96YD(#T@*"1L:6YK7W-T87)T
M*2`_("<\+V$^)R`Z("<G.PH*("`@("`@("`D:6UG(#T@)&QI;FM?<W1A<G0@
M+B`G/&EM9R!S<F,](B<@+B`D=&AI<RT^7VEM9U]D:7(@+B`G+R<@+B`D:6UG
M("X@)R(G"B`@("`@("`@("`@("X@*&ES<V5T*"1A;'0I(#\@)R!A;'0](B<@
M+B`D86QT("X@)R(G(#H@)R<I"B`@("`@("`@("`@("X@)R!H96EG:'0](C(P
M(B!W:61T:#TB,C`B('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B(&)O
M<F1E<CTB,"(@+SXG"B`@("`@("`@("`@("X@)&QI;FM?96YD.PH*("`@("`@
M("!R971U<FX@)&EM9SL*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE
M(&EC;VX@9F]R('1H92!N;V1E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YO9&5?:60@(%1H
M92!.;V1E($E$+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M;F]D92!I8V]N(&9O<B!T:&4@=')E92!L:6YE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<V5T3F]D94EC;VXH)&YO9&5?:60I"B`@("!["B`@("`@("`@)&EM
M9U]D:7(@/2!I<W-E="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;F1I
M<B==*2`_("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I8V]N9&ER)UT@.B`D
M=&AI<RT^7VEM9U]D:7(["B`@("`@("`@:68@*"1I;6=?9&ER*2!["B`@("`@
M("`@("`@("1I;6=?9&ER("X]("<O)SL*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;B==*2D@>PH@
M("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;
M)VEC;VXG72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`O*B!.;V1E(&AA<R!A('5S97(@9&5F:6YE
M9"!I8V]N+B`J+PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N;V1E
M<ULD;F]D95]I9%U;)VEC;VYO<&5N)UTI("8F"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AP86YD960G72D@>PH@("`@("`@
M("`@("`@("`@)&EM9R`]("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I8V]N
M;W!E;B==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&EM9R`]("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I8V]N)UT["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!5<V4@
M<W1A;F1A<F0@:6-O;B!S970N("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG8VAI;&1R96XG72DI('L*("`@("`@
M("`@("`@("`@("\J($YO9&4@=VET:"!C:&EL9')E;BX@*B\*("`@("`@("`@
M("`@("`@("1I;6<@/2`H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V5X<&%N
M9&5D)UTI(#\@)'1H:7,M/E]I;6=?9F]L9&5R7V]P96X@.B`D=&AI<RT^7VEM
M9U]F;VQD97(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`O*B!,96%F(&YO9&4@*&YO(&-H:6QD<F5N*2X@*B\*("`@("`@("`@("`@
M("`@("1I;6<@/2`D=&AI<RT^7VEM9U]L96%F.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D:6UG='AT(#T@)SQI;6<@<W)C/2(G("X@)&EM
M9U]D:7(@+B`D:6UG("X@)R(G.PH*("`@("`@("`O*B!$;V5S('1H92!N;V1E
M(&AA=F4@=7-E<B!D969I;F5D(&%L="!T97AT/R`J+PH@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;F%L="==*2D@>PH@
M("`@("`@("`@("`D:6UG='AT("X]("<@86QT/2(G("X@:'1M;'-P96-I86QC
M:&%R<R@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;F%L="==*2`N("<B
M)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6UG='AT("X@)R`O/B<[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4<F5E+W-E;&5C="YP:'``````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V,#$`,3`T,3<S-C(W-S$`
M,#(Q,3(R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?5')E95]S96QE8W0Z.B!C;&%S
M<R!E>'1E;F1S('1H92!(;W)D95]4<F5E(&-L87-S('1O('!R;W9I9&4*("H@
M/&]P=&EO;CX@=&%G(')E;F1E<FEN9RX*("H*("H@0V]P>7)I9VAT(#(P,#4M
M,C`P-B!"96X@0VAA=F5T(#QB96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5')E92]4<F5E+W-E;&5C="YP:'`L
M=B`Q+C(N,BXW(#(P,#8O,#$O,#$@,C$Z,C@Z-#`@:F%N($5X<"`D"B`J"B`J
M($!A=71H;W(@($)E;B!#:&%V970@/&)E;D!H;W)D92YO<F<^"B`J($!P86-K
M86=E($AO<F1E7U1R964*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J+PIC;&%S
M<R!(;W)D95]4<F5E7W-E;&5C="!E>'1E;F1S($AO<F1E7U1R964@>PH*("`@
M("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?;F]D97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U1R
M965?<V5L96-T*"1T<F5E7VYA;64L("1P87)A;7,I"B`@("!["B`@("`@("`@
M<&%R96YT.CI(;W)D95]4<F5E*"1T<F5E7VYA;64L("1P87)A;7,I.PH@("`@
M("`@("1T:&ES+3Y?<W1A=&EC(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('1R964N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!(5$U,(&-O9&4@;V8@=&AE(')E;F1E<F5D('1R964N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%1R964H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?8G5I;&1);F1E;G1S*"1T:&ES+3Y?<F]O=%]N;V1E<RD["@H@("`@
M("`@("1T<F5E(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]R;V]T
M7VYO9&5S(&%S("1N;V1E7VED*2!["B`@("`@("`@("`@("1T<F5E("X]("1T
M:&ES+3Y?8G5I;&14<F5E*"1N;V1E7VED*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1T<F5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H
M92!C=7)R96YT(&5N=FER;VYM96YT('1O('-E92!I9B!W92!C86X@<F5N9&5R
M('1H92!(5$U,('1R964N"B`@("`@*B!(5$U,(&ES(&%L=V%Y<R!R96YD97)A
M8FQE+"!A="!L96%S="!U;G1I;"!W92!A9&0@82!P:'`M9W1K('1R964*("`@
M("`J(&)A8VME;F0L(&EN('=H:6-H(&-A<V4@=&AI<R!I;7!L96UE;G1A=&EO
M;B!W:6QL(&%C='5A;&QY(&YE960@82!B;V1Y+@H@("`@("H*("`@("`J($!S
M=&%T:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@
M;W(@;F]T('1H:7,@5')E93HZ(&)A8VME;F0@=VEL;"!F=6YC=&EO;BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-3=7!P;W)T960H*0H@("`@>PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!J
M=7-T('1H92!*4R!N;V1E(&1E9FEN:71I;VYS(&%S(&$@<W1R:6YG+B!4:&ES
M(&ES(&$@;F\M;W`@9F]R"B`@("`@*B!T:&4@<V5L96-T(')E;F1E<F5R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96YD97).;V1E1&5F:6YI=&EO;G,H*0H@
M("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A9&1I=&EO;F%L('!A
M<F%M971E<G,@=&\@82!N;V1E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ED("`@("!4:&4@=6YI<75E(&YO9&4@:60N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@06YY(&]T:&5R('!A<F%M971E<G,@=&\@<V5T+@H@
M("`@("H@/'!R93X*("`@("`J('-E;&5C=&5D("TM("!7:&5T:&5R('1H:7,@
M;F]D92!I<R!S96QE8W1E9`H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$YO9&5087)A;7,H)&ED+"`D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@
M("`@("`@("1P87)A;7,@/2!A<G)A>2@D<&%R86US*3L*("`@("`@("!]"@H@
M("`@("`@("1A;&QO=V5D(#T@87)R87DH)W-E;&5C=&5D)RD["@H@("`@("`@
M(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M7VED(#T^("1P87)A;5]V86PI
M('L*("`@("`@("`@("`@+RH@4V5T(&]N;'D@86QL;W=E9"!A;F0@;F]N+6YU
M;&P@<&%R86US+B`J+PH@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'!A<F%M
M7VED+"`D86QL;W=E9"D@)B8@(6ES7VYU;&PH)'!A<F%M7W9A;"DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)&ED75LD<&%R86U?:61=(#T@
M)'!A<F%M7W9A;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E8W5R<VEV92!F=6YC=&EO;B!T;R!W86QK('1H<F]U
M9V@@=&AE('1R964@87)R87D@86YD(&)U:6QD('1H92!O=71P=70N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F]D95]I9"`@5&AE($YO9&4@240N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!T<F5E(')E;F1E<FEN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V)U:6QD5')E92@D;F]D95]I9"D*("`@('L*("`@("`@
M("`D<V5L96-T960@/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG<V5L96-T
M960G72`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)SL*"B`@("`@("`@
M)&]U='!U="`]("<\;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R
M<R@D;F]D95]I9"D@+B`G(B<@+B`D<V5L96-T960@+B`G/B<@+@H@("`@("`@
M("`@("!S=')?<F5P96%T*"<F;F)S<#LF;F)S<#LG+"`H:6YT*21T:&ES+3Y?
M;F]D97-;)&YO9&5?:61=6R=I;F1E;G0G72D@+B!H=&UL<W!E8VEA;&-H87)S
M*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=L86)E;"==*2`N"B`@("`@("`@
M("`@("<\+V]P=&EO;CXG.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI("8F"B`@("`@("`@("`@("1T
M:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'!A;F1E9"==*2!["B`@("`@("`@
M("`@("1N=6U?<W5B;F]D97,@/2!C;W5N="@D=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG8VAI;&1R96XG72D["B`@("`@("`@("`@(&9O<B`H)&,@/2`P.R`D
M8R`\("1N=6U?<W5B;F]D97,[("1C*RLI('L*("`@("`@("`@("`@("`@("1C
M:&EL9%]N;V1E7VED(#T@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD
M<F5N)UU;)&-=.PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^
M7V)U:6QD5')E92@D8VAI;&1?;F]D95]I9"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<Q
M`#`Q-C4U,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]522]6
M87)296YD97)E<B\`````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-S$`,#(P-S8W`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#(P,34W,@`Q,#0Q-S,V,C<W,0`P,C(T-3``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!(;W)D95]525]687)296YD97)E<E]H=&UL.CH@8VQA<W,@
M<F5N9&5R<R!V87)I86)L97,@=&\@2%1-3"X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`L=B`Q+CDX+C(N,C8@
M,C`P-B\P,R\P,B`Q-SHS.#HR,2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y
M<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!,24-%3E-%(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X*("H*("H@0'-I;F-E("`@
M2&]R9&5?54D@,"XP+C$*("H@0'!A8VMA9V4@2&]R9&5?54D*("HO"F-L87-S
M($AO<F1E7U5)7U9A<E)E;F1E<F5R7VAT;6P@97AT96YD<R!(;W)D95]525]6
M87)296YD97)E<B!["@H@("`@=F%R("1?;VY,;V%D2E,@/2!A<G)A>2@I.PH*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=$1E9F%U;'0H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`G/'-T<F]N9SY7
M87)N:6YG.CPO<W1R;VYG/B!5;FMN;W=N('9A<FEA8FQE('1Y<&4@)R`N"B`@
M("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%1Y<&5.86UE
M*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VYU;6)E<B@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A;'5E(#T@)'9A<BT^9V5T5F%L
M=64H)'9A<G,I.PH@("`@("`@(&EF("AI<W-E="@D=F%R+3YT>7!E+3Y?9G)A
M8W1I;VXI*2!["B`@("`@("`@("`@("1V86QU92`]('-P<FEN=&8H)R4P,2XG
M("X@)'9A<BT^='EP92T^7V9R86-T:6]N("X@)V8G+"`D=F%L=64I.PH@("`@
M("`@('T*("`@("`@("`D;&EN9F\@/2!.3%,Z.F=E=$QO8V%L94EN9F\H*3L*
M("`@("`@("`O*B!/;FQY(&EF('1H97)E(&ES(&$@;6]N7V1E8VEM86Q?<&]I
M;G0@9&\@=&AE"B`@("`@("`@("H@<W5B<W1I='5T:6]N+B`J+PH@("`@("`@
M(&EF("@A96UP='DH)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN="==*2D@>PH@
M("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92@G+B<L("1L:6YF;ULG
M;6]N7V1E8VEM86Q?<&]I;G0G72P@)'9A;'5E*3L*("`@("`@("!]"B`@("`@
M("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).
M86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@
M<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(U(B!N
M86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@
M("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V86QU92P*("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H
M)&9O<FTL("1V87(I"B`@("`@("`@("`@("`@("D["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VEN="@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R
M<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T
M97AT(B!S:7IE/2(U(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B)7,@
M+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I
M"B`@("`@("`@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<DEN<'5T7V]C=&%L*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*
M("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E
M=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@
M("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B('-I>F4]
M(C4B(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT
M9B@G,"5O)RP@;V-T9&5C*"1V87(M/F=E=%9A;'5E*"1V87)S*2DI+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D
M9F]R;2P@)'9A<BD*("`@("`@("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R5F%R26YP=71?:6YT;&ES="@F)&9O<FTL("8D=F%R+"`F
M)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC
M:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?
M8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E
M/2)T97AT(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B)7,@+SXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I"B`@("`@
M("`@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN
M<'5T7W1E>'0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M("1M87AL96YG=&@@/2`D=F%R+3YT>7!E+3YG971-87A,96YG=&@H*3L*("`@
M("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A
M<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@
M("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](B5S
M(B!I9#TB)7,B('-I>F4](B5S(B!V86QU93TB)7,B("5S)7,E<R`O/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<BT^='EP92T^9V5T4VEZ92@I+`H@("`@("`@("`@("`@("`@("`@("`@($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R+3YI<T1I<V%B;&5D*"D@/R`G(&1I<V%B;&5D/2)D:7-A8FQE9"(@
M)R`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@(&5M<'1Y*"1M87AL96YG
M=&@I(#\@)R<@.B`G(&UA>&QE;F=T:#TB)R`N("1M87AL96YG=&@@+B`G(B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I
M<'1S*"1F;W)M+"`D=F%R*0H@("`@("`@("`@("`@("`I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)687));G!U=%]W96%T:&5R9&]T8V]M*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]R96YD97)687));G!U=%]T97AT*"1F;W)M+"`D=F%R+"`D=F%R<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W-T<FEN9VQI<W0H
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE
M(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I
M;G1F*"<\:6YP=70@='EP93TB=&5X="(@<VEZ93TB-C`B(&YA;64](B5S(B!I
M9#TB)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A
M<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S
M970I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N
M4V-R:7!T<R@D9F]R;2P@)'9A<BD*("`@("`@("`@("`@("`@*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?8V5L;'!H;VYE*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G
M/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](B5S(B!I9#TB)7,B('-I>F4](C$R
M(B!V86QU93TB)7,B("5S)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M
M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*2P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YI<T1I<V%B;&5D*"D@
M/R`G(&1I<V%B;&5D/2)D:7-A8FQE9"(@)R`Z("<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A
M<BD*("`@("`@("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5F%R26YP=71?:7!A9&1R97-S*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V
M87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B
M(&YA;64](B5S(B!I9#TB)7,B('-I>F4](C$V(B!V86QU93TB)7,B("5S)7,@
M+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R+3YI<T1I<V%B;&5D*"D@/R`G(&1I<V%B;&5D/2)D:7-A
M8FQE9"(@)R`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BD*("`@("`@("`@("`@("`@
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?9FEL92@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@
M/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN
M=&8H)SQI;G!U="!T>7!E/2)F:6QE(B!S:7IE/2(S,"(@;F%M93TB)7,B(&ED
M/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D
M=F%R*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`=&]D;R!3:&]W(&EM86=E
M(&1I;65N<VEO;G,@:6X@=&AE('=I9'1H+VAE:6=H="!B;WAE<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VEM86=E*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`](&AT;6QS
M<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("`D:6UA
M9V4@/2`D=F%R+3YG971686QU92@D=F%R<RD["@H@("`@("`@("\J($-H96-K
M(&EF(&5X:7-T:6YG(&EM86=E(&1A=&$@:7,@8F5I;F<@;&]A9&5D+B`J+PH@
M("`@("`@("1V87(M/G1Y<&4M/E]L;V%D26UA9V5$871A*"1I;6%G92D["@H@
M("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=I;6%G92YJ<R<L("=H;W)D
M92<L('1R=64I.PH@("`@("`@("1G<F%P:&EC<U]D:7(@/2`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RD["B`@("`@("`@)&EM
M9U]D:7(@/2`D9W)A<&AI8W-?9&ER("X@)R]I;6%G92<["@H@("`@("`@("1H
M=&UL(#T@)R<["@H@("`@("`@("\J($-H96-K(&EF('1H97)E(&ES(&5X:7-T
M:6YG(&EM9R!I;F9O<FUA=&EO;B!S=&]R960N("HO"B`@("`@("`@:68@*&ES
M<V5T*"1I;6%G95LG:6UG)UTI*2!["B`@("`@("`@("`@("\J($AI9&1E;B!T
M86<@=&\@<W1O<F4@=&AE('!R979I97<@:6UA9V4@9FEL96YA;64N("HO"B`@
M("`@("`@("`@("1H=&UL(#T@<W!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B`O/B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`N("=;:6UG72<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`N("=;:6UG72<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D
M:6UA9V5;)VEM9R==+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*
M("`@("`@("`@("`@+RH@56YS97)I86QI>F4@=&AE(&EM9R!I;F9O<FUA=&EO
M;B!T;R!G970@=&AE(&9U;&P@87)R87DN("HO"B`@("`@("`@("`@("1I;6%G
M95LG:6UG)UT@/2!`=6YS97)I86QI>F4H)&EM86=E6R=I;6<G72D["B`@("`@
M("`@?0H*("`@("`@("`O*B!/=71P=70@=&AE(&EN<'5T('1A9RX@*B\*("`@
M("`@("!I9B`H96UP='DH)&EM86=E6R=I;6<G72DI('L*("`@("`@("`@("`@
M)&IS(#T@(G9A<B!P(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)R(@+B`D
M=F%R;F%M92`N(");<')E=FEE=UTG*3L@;R`]("=<7%Q<)SL@82`]("<O)SL@
M=&UP(#T@)R<@*R!D;V-U;65N="YG971%;&5M96YT0GE)9"@G(B`N("1V87)N
M86UE("X@(EMN97==)RDN=F%L=64[(&EF("AT;7`I('L@=VAI;&4@*'1M<"YI
M;F1E>$]F*&\I(#X@+3$I('L@<&]S(#T@=&UP+FEN9&5X3V8H;RD[('1M<"`]
M("<G("L@*'1M<"YS=6)S=')I;F<H,"P@<&]S*2`K(&$@*R!T;7`N<W5B<W1R
M:6YG*"AP;W,@*R!O+FQE;F=T:"DL('1M<"YL96YG=&@I*3M].R!P+G-R8R`]
M("=F:6QE.B\O+R<@*R!T;7`[('`N86QT(#T@)R(@+B!A9&1S;&%S:&5S*%\H
M(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+B(I*2`N("(G.R!].R(["B`@("`@("`@("`@("1B<F]W
M<V5R(#T@)D)R;W=S97(Z.G-I;F=L971O;B@I.PH@("`@("`@("`@("!I9B`H
M)&)R;W=S97(M/FES0G)O=W-E<B@G;7-I92<I*2!["B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2!S<')I;G1F*"<\:6YP=70@='EP93TB9FEL92(@<VEZ93TB
M,S`B(&YA;64](B5S(B!I9#TB)7,B(&]N8VAA;F=E/2(E<R(@+SXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`N("=;;F5W
M72<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE
M("X@)UMN97==)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&IS*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H
M=&UL("X]('-P<FEN=&8H)SQI;G!U="!T>7!E/2)F:6QE(B!S:7IE/2(S,"(@
M;F%M93TB)7,B(&ED/2(E<R(@;VYC;&EC:STB=VEN9&]W+G-E=%1I;65O=70H
M7"=D;V-U;65N="YG971%;&5M96YT0GE)9"A<7%PG)7-<7%PG*2YB;'5R*"D[
M7"<L(#4I.R(@;VYB;'5R/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92`N("=;;F5W72<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE("X@)UMN97==)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G6VYE
M=UTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:G,I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&AT
M;6P@+CT@<W!R:6YT9B@G/&EN<'5T('1Y<&4](F9I;&4B('-I>F4](C,P(B!N
M86UE/2(E<R(@:60](B5S(B`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<FYA;64@+B`G6VYE=UTG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE("X@)UMN97==)RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!/=71P=70@=&AE(&)U='1O;B!T;R!U<&QO860O<F5S970@=&AE
M(&EM86=E+B`J+PH@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?<VAO=U]U<&QO
M860I('L*("`@("`@("`@("`@)&AT;6P@+CT@)R9N8G-P.R<["B`@("`@("`@
M("`@("1H=&UL("X]('-P<FEN=&8H)SQI;G!U="!C;&%S<STB8G5T=&]N(B!N
M86UE/2(E<R(@:60](B5S(B!T>7!E/2)S=6)M:70B('9A;'5E/2(E<R(@+SX@
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7V1O7R<@+B`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7V1O7R<@+B`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*")5<&QO
M860B*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)&EM86=E6R=I
M;6<G72DI('L*("`@("`@("`@("`@+RH@3F\@:6UA9V4@:6YF;W)M871I;VX@
M<W1O<F5D('EE="P@<VAO=R!A(&)L86YK('!R979I97<N("HO"B`@("`@("`@
M("`@("1H=&UL("X]($AO<F1E.CII;6<H)W1R964O8FQA;FLN<&YG)RP@7R@B
M4')E=FEE=R(I+"`G=VED=&@](C4P(B!H96EG:'0](C0P(B!I9#TB)R`N("1V
M87)N86UE("X@)UMP<F5V:65W72(G+"`D9W)A<&AI8W-?9&ER*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!);6%G92!I;F9O<FUA=&EO;B!S
M=&]R960L('-H;W<@<')E=FEE=RP@861D(&)U='1O;G,@9F]R(&EM86=E"B`@
M("`@("`@("`@("`J(&UA;FEP=6QA=&EO;BX@*B\*("`@("`@("`@("`@)&AT
M;6P@+CT@)SQB<B`O/B<["B`@("`@("`@("`@("1I;6<@/2!(;W)D93HZ=7)L
M*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G
M*2`N("<O<V5R=FEC97,O:6UA9V5S+W9I97<N<&AP)RD["B`@("`@("`@("`@
M(&EF("AI<W-E="@D:6UA9V5;)VEM9R==6R=V9G-?:60G72DI('L*("`@("`@
M("`@("`@("`@("\J($-A;&QI;F<@86X@:6UA9V4@9G)O;2!61E,N("HO"B`@
M("`@("`@("`@("`@("`D:6UG(#T@571I;#HZ861D4&%R86UE=&5R*"1I;6<L
M(&%R<F%Y*"=F)R`]/B`D:6UA9V5;)VEM9R==6R=V9G-?:60G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W,G(#T^("=V9G,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<"<@/3X@)&EM86=E6R=I;6<G
M75LG=F9S7W!A=&@G72DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@+RH@0V%L;&EN9R!A;B!I;6%G92!F<F]M(&$@=&UP(&1I<F5C
M=&]R>2`H=7!L;V%D<RDN("HO"B`@("`@("`@("`@("`@("`D:6UG(#T@571I
M;#HZ861D4&%R86UE=&5R*"1I;6<L("=F)RP@)&EM86=E6R=I;6<G75LG9FEL
M92==*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4F5S970N("HO
M"B`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B4F5S
M970B*2P@)R<L("<G+"`G<VAO=TEM86=E*%PG)R`N("1I;6<@+B`G7"<L(%PG
M7W!?)R`N("1V87)N86UE("X@)UPG+"!T<G5E*3LG*2`N($AO<F1E.CII;6<H
M)W)E9G)E<V@N<&YG)RP@7R@B4F5S970B*2P@)V%L:6=N/2)M:61D;&4B)RP@
M)&EM9U]D:7(I("X@)SPO83XG.PH*("`@("`@("`@("`@+RH@4F]T871E(#(W
M,"X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH)R,G+"!?
M*")2;W1A=&4@3&5F="(I+"`G)RP@)R<L("=S:&]W26UA9V4H7"<G("X@571I
M;#HZ861D4&%R86UE=&5R*"1I;6<L(&%R<F%Y*"=A)R`]/B`G<F]T871E)RP@
M)W8G(#T^("<R-S`G*2D@+B`G7"<L(%PG7W!?)R`N("1V87)N86UE("X@)UPG
M+"!T<G5E*3LG*2`N($AO<F1E.CII;6<H)W)O=&%T92TR-S`N<&YG)RP@7R@B
M4F]T871E($QE9G0B*2P@)V%L:6=N/2)M:61D;&4B)RP@)&EM9U]D:7(I("X@
M)SPO83XG.PH*("`@("`@("`@("`@+RH@4F]T871E(#$X,"X@*B\*("`@("`@
M("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH)R,G+"!?*")2;W1A=&4@,3@P
M(BDL("<G+"`G)RP@)W-H;W=);6%G92A<)R<@+B!5=&EL.CIA9&1087)A;65T
M97(H)&EM9RP@87)R87DH)V$G(#T^("=R;W1A=&4G+"`G=B<@/3X@)S$X,"<I
M*2`N("=<)RP@7"=?<%\G("X@)'9A<FYA;64@+B`G7"<L('1R=64I.R<I("X@
M2&]R9&4Z.FEM9R@G<F]T871E+3$X,"YP;F<G+"!?*")2;W1A=&4@,3@P(BDL
M("=A;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER*2`N("<\+V$^)SL*"B`@("`@
M("`@("`@("\J(%)O=&%T92`Y,"X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@
M2&]R9&4Z.FQI;FLH)R,G+"!?*")2;W1A=&4@4FEG:'0B*2P@)R<L("<G+"`G
M<VAO=TEM86=E*%PG)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG+"!A<G)A
M>2@G82<@/3X@)W)O=&%T92<L("=V)R`]/B`G.3`G*2D@+B`G7"<L(%PG7W!?
M)R`N("1V87)N86UE("X@)UPG+"!T<G5E*3LG*2`N($AO<F1E.CII;6<H)W)O
M=&%T92TY,"YP;F<G+"!?*")2;W1A=&4@4FEG:'0B*2P@)V%L:6=N/2)M:61D
M;&4B)RP@)&EM9U]D:7(I("X@)SPO83XG.PH*("`@("`@("`@("`@+RH@1FQI
M<"!I;6%G92X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH
M)R,G+"!?*")&;&EP(BDL("<G+"`G)RP@)W-H;W=);6%G92A<)R<@+B!5=&EL
M.CIA9&1087)A;65T97(H)&EM9RP@)V$G+"`G9FQI<"<I("X@)UPG+"!<)U]P
M7R<@+B`D=F%R;F%M92`N("=<)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG*"=F
M;&EP+G!N9R<L(%\H(D9L:7`B*2P@)V%L:6=N/2)M:61D;&4B)RP@)&EM9U]D
M:7(I("X@)SPO83XG.PH*("`@("`@("`@("`@+RH@36ER<F]R(&EM86=E+B`J
M+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(DUI
M<G)O<B(I+"`G)RP@)R<L("=S:&]W26UA9V4H7"<G("X@571I;#HZ861D4&%R
M86UE=&5R*"1I;6<L("=A)RP@)VUI<G)O<B<I("X@)UPG+"!<)U]P7R<@+B`D
M=F%R;F%M92`N("=<)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG*"=M:7)R;W(N
M<&YG)RP@7R@B36ER<F]R(BDL("=A;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER
M*2`N("<\+V$^)SL*"B`@("`@("`@("`@("\J($%P<&QY(&=R87ES8V%L92X@
M*B\*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH)R,G+"!?*")'
M<F%Y<V-A;&4B*2P@)R<L("<G+"`G<VAO=TEM86=E*%PG)R`N(%5T:6PZ.F%D
M9%!A<F%M971E<B@D:6UG+"`G82<L("=G<F%Y<V-A;&4G*2`N("=<)RP@7"=?
M<%\G("X@)'9A<FYA;64@+B`G7"<L('1R=64I.R<I("X@2&]R9&4Z.FEM9R@G
M9W)A>7-C86QE+G!N9R<L(%\H(D=R87ES8V%L92(I+"`G86QI9VX](FUI9&1L
M92(G+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@("`@("`@("`O*B!297-I
M>F4@=VED=&@N("HO"B`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)R5S
M/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C0B(&]N8VAA;F=E/2)S<F,]9V5T
M4F5S:7IE4W)C*%PG)7-<)RP@7"<E<UPG*3MS:&]W26UA9V4H<W)C+"!<)U]P
M7R5S7"<L('1R=64I.R(@)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@7R@B
M=SHB*2P*("`@("`@("`@("`@("`@("`@(%5T:6PZ.F%D9%!A<F%M971E<B@D
M:6UG+"`G82<L("=R97-I>F4G*2P*("`@("`@("`@("`@("`@("`@("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=E;DE$*"=?=U\G("X@)'9A<FYA;64I*3L*"B`@
M("`@("`@("`@("\J(%)E<VEZ92!H96EG:'0N("HO"B`@("`@("`@("`@("1H
M=&UL("X]('-P<FEN=&8H)R5S/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C0B
M(&]N8VAA;F=E/2)S<F,]9V5T4F5S:7IE4W)C*%PG)7-<)RP@7"<E<UPG*3MS
M:&]W26UA9V4H<W)C+"!<)U]P7R5S7"<L('1R=64I.R(@)7,@+SXG+`H@("`@
M("`@("`@("`@("`@("`@7R@B:#HB*2P*("`@("`@("`@("`@("`@("`@(%5T
M:6PZ.F%D9%!A<F%M971E<B@D:6UG+"`G82<L("=R97-I>F4G*2P*("`@("`@
M("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64L"B`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E;DE$*"=?:%\G
M("X@)'9A<FYA;64I*3L*"B`@("`@("`@("`@("\J($%P<&QY(&9I>&5D(')A
M=&EO(')E<VEZ92X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI
M;FLH)R,G+"!?*")&:7@@<F%T:6\B*2P@)R<L("<G+"`G<W)C/6=E=%)E<VEZ
M95-R8RA<)R<@+B!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@)V$G+"`G<F5S
M:7IE)RD@+B`G7"<L(%PG)R`N("1V87)N86UE("X@)UPG+"!<)S%<)RD[<VAO
M=TEM86=E*'-R8RP@7"=?<%\G("X@)'9A<FYA;64@+B`G7"<L('1R=64I.R<I
M("X@2&]R9&4Z.FEM9R@G<F%T:6\N<&YG)RP@7R@B1FEX(')A=&EO(BDL("=A
M;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER*2`N("<\+V$^)SL*"B`@("`@("`@
M("`@("\J($ME97`@86QS;R!O<FEG:6YA;"!I9B!I="!H87,@8F5E;B!R97%U
M97-T960N("HO"B`@("`@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?<VAO=U]K
M965P;W)I9RD@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C;&%S<STB8VAE8VMB;W@B(&YA;64]
M(B5S(B!I9#TB)7,B)7,@+SXE<R<@+B`B7&XB+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92`N("=;:V5E<%]O<FEG72<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE("X@)UMK
M965P7V]R:6==)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(65M<'1Y*"1I;6%G95LG:V5E<%]O<FEG)UTI(#\@)R!C:&5C:V5D/2)C:&5C
M:V5D(B<@.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7R@B2V5E<"!O<FEG:6YA;#\B*2D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J(%1H92!P<F5V:65W(&EM86=E(&5L96UE;G0N("HO"B`@("`@("`@
M("`@("1H=&UL("X]("<\8G(@+SX\:6UG('-R8STB)R`N("1I;6<@+B`G(B`G
M("X@)'1H:7,M/E]G96Y)1"@G7W!?)R`N("1V87)N86UE*2`N("(^7&XB.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]R96YD97)687));G!U=%]L;VYG=&5X="@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@9VQO8F%L("1B<F]W<V5R.PH*("`@
M("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A
M<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@
M("`D:'1M;"`]('-P<FEN=&8H)SQT97AT87)E82!I9#TB)7,B(&YA;64](B5S
M(B!C;VQS/2(E<R(@<F]W<STB)7,B)7,E<SXE<SPO=&5X=&%R96$^)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`H
M:6YT*21V87(M/G1Y<&4M/F=E=$-O;',H*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@*&EN="DD=F%R+3YT>7!E+3YG9712;W=S*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@
M)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("1V87(M/FES1&ES86)L
M960H*2`_("<@9&ES86)L960](F1I<V%B;&5D(B<@.B`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L
M=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*"B`@
M("`@("`@:68@*"1V87(M/G1Y<&4M/FAA<TAE;'!E<B@G<G1E)RD@)B8@)&)R
M;W=S97(M/FAA<T9E871U<F4H)W)T92<I*2!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O161I=&]R+G!H<"<["B`@("`@("`@("`@("1E9&ET
M;W(@/2`F2&]R9&5?161I=&]R.CIS:6YG;&5T;VXH)VAT;6QA<F5A)RP@87)R
M87DH)VED)R`]/B`D=F%R;F%M92DI.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1V87(M/G1Y<&4M/FAA<TAE;'!E<B@I("8F("1B<F]W<V5R+3YH87-&96%T
M=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQB
M<B`O/CQT86)L92!C96QL<W!A8VEN9STB,"(^/'1R/CQT9#XG.PH@("`@("`@
M("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G;W!E;E]H=&UL7VAE;'!E<BYJ
M<R<L("=H;W)D92<I.PH@("`@("`@("`@("`D:6UG260@/2`D=&AI<RT^7V=E
M;DE$*"1V87(M/F=E=%9A<DYA;64H*2P@9F%L<V4I("X@)V5H96QP97(G.PH@
M("`@("`@("`@("!I9B`H)'9A<BT^='EP92T^:&%S2&5L<&5R*"=E;6]T:6-O
M;G,G*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH
M)R,G+"!?*")%;6]T:6-O;G,B*2P@)R<L("<G+"`G;W!E;DAT;6Q(96QP97(H
M7"=E;6]T:6-O;G-<)RP@7"<G("X@)'9A<BT^9V5T5F%R3F%M92@I("X@)UPG
M*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G<VUI;&4N<&YG)RP@
M7R@B16UO=&EC;VYS(BDL("=I9#TB)R`N("1I;6=)9"`N("<B(&%L:6=N/2)M
M:61D;&4B)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H
M;W)D92<I("X@)R]E;6]T:6-O;G,G*2`N("<\+V$^)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]T9#X\+W1R/CQT<CX\=&0^/&1I
M=B`G("X@)'1H:7,M/E]G96Y)1"@G:'1M;&AE;'!E<E\G("X@)'9A<BT^9V5T
M5F%R3F%M92@I*2`N("<@8VQA<W,](F-O;G1R;VPB/CPO9&EV/CPO=&0^/"]T
M<CX\+W1A8FQE/B<@+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1H=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]C
M;W5N=&5D=&5X="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@
M("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).
M86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@
M<F5T=7)N('-P<FEN=&8H)SQT97AT87)E82!N86UE/2(E<R(@:60](B5S(B!C
M;VQS/2(E<R(@<F]W<STB)7,B)7,E<SXE<SPO=&5X=&%R96$^)RP*("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21V
M87(M/G1Y<&4M/F=E=$-O;',H*2P*("`@("`@("`@("`@("`@("`@("`@("`H
M:6YT*21V87(M/G1Y<&4M/F=E=%)O=W,H*2P*("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("1V87(M/FES1&ES86)L960H*2`_("<@
M9&ES86)L960](F1I<V%B;&5D(B<@.B`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL
M($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]R96YD97)687));G!U=%]A9&1R97-S*"8D9F]R;2P@)B1V87(L
M("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA
M;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M
M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/'1E>'1A<F5A
M(&YA;64](B5S(B!I9#TB)7,B(&-O;',](B5S(B!R;W=S/2(E<R(E<R5S/B5S
M/"]T97AT87)E83XG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("AI;G0I)'9A<BT^='EP92T^9V5T0V]L<R@I+`H@("`@
M("`@("`@("`@("`@("`@("`@("AI;G0I)'9A<BT^='EP92T^9V5T4F]W<R@I
M+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R
M:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<BT^:7-$:7-A8FQE9"@I(#\@)R!D:7-A8FQE9#TB9&ES86)L960B)R`Z("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V
M87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R
M<V5T*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V1A
M=&4H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N
M86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S
M<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M93TB)7,B(&ED/2(E<R(@
M=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG9716
M86QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S
M*"1F;W)M+"`D=F%R*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A
M<DEN<'5T7W1I;64H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@
M("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R
M3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@
M(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@<VEZ93TB-2(@
M;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I
M86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T
M:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VAO=7)M:6YU=&5S96-O;F0H)B1F
M;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@
M0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("1T:6UE(#T@)'9A<BT^
M='EP92T^9V5T5&EM95!A<G1S*"1V87(M/F=E=%9A;'5E*"1V87)S*2D["@H@
M("`@("`@("\J($]U='!U="!H;W5R<RX@*B\*("`@("`@("`D:&]U<G,@/2!A
M<G)A>2@G)R`]/B!?*")H:"(I*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/#T@,C,[("1I*RLI('L*("`@("`@("`@("`@)&AO=7)S6R1I72`]("1I.PH@
M("`@("`@('T*("`@("`@("`D:'1M;"`]('-P<FEN=&8H)SQS96QE8W0@;F%M
M93TB)7-;:&]U<ETB(&ED/2(E<UMH;W5R72(E<SXE<SPO<V5L96-T/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1H;W5R
M<RP@*"1T:6UE6R=H;W5R)UT@/3T]("<G*2`_("<G(#H@)'1I;65;)VAO=7(G
M72DI.PH*("`@("`@("`O*B!/=71P=70@;6EN=71E<RX@*B\*("`@("`@("`D
M;6EN=71E<R`](&%R<F%Y*"<G(#T^(%\H(FUM(BDI.PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\/2`U.3L@)&DK*RD@>PH@("`@("`@("`@("`D;2`]('-P
M<FEN=&8H)R4P,F0G+"`D:2D["B`@("`@("`@("`@("1M:6YU=&5S6R1M72`]
M("1M.PH@("`@("`@('T*("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\<V5L
M96-T(&YA;64](B5S6VUI;G5T95TB(&ED/2(E<UMM:6YU=&5=(B5S/B5S/"]S
M96QE8W0^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL
M("1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96QE
M8W1/<'1I;VYS*"1M:6YU=&5S+"`H)'1I;65;)VUI;G5T92==(#T]/2`G)RD@
M/R`G)R`Z('-P<FEN=&8H)R4P,F0G+"`D=&EM95LG;6EN=71E)UTI*2D["@H@
M("`@("`@("\J(%)E='5R;B!I9B!S96-O;F1S(&%R92!N;W0@<F5Q=6ER960N
M("HO"B`@("`@("`@:68@*"$D=F%R+3YT>7!E+3Y?<VAO=U]S96-O;F1S*2![
M"B`@("`@("`@("`@(')E='5R;B`D:'1M;#L*("`@("`@("!]"@H@("`@("`@
M("\J($]U='!U="!S96-O;F1S+B`J+PH@("`@("`@("1S96-O;F1S(#T@87)R
M87DH)R<@/3X@7R@B<W,B*2D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P]
M(#4Y.R`D:2LK*2!["B`@("`@("`@("`@("1S96-O;F1S6R1I72`]('-P<FEN
M=&8H)R4P,F0G+"`D:2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:'1M
M;"`N('-P<FEN=&8H)SQS96QE8W0@;F%M93TB)7-;<V5C;VYD72(@:60](B5S
M6W-E8V]N9%TB)7,^)7,\+W-E;&5C=#XG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E;&5C=$]P
M=&EO;G,H)'-E8V]N9',L("@D=&EM95LG<V5C;VYD)UT@/3T]("<G*2`_("<G
M(#H@<W!R:6YT9B@G)3`R9"<L("1T:6UE6R=S96-O;F0G72DI*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;6]N=&AY96%R*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D9&%T97,@/2!A<G)A
M>2@I.PH@("`@("`@("1D871E<ULG;6]N=&@G72`](&%R<F%Y*"<G(#T^(%\H
M(DU-(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`]/B!?
M*")*86YU87)Y(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,B`]/B!?*")&96)R=6%R>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#,@/3X@7R@B36%R8V@B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`T(#T^(%\H(D%P<FEL(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@-2`]/B!?*")-87DB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`V(#T^(%\H(DIU;F4B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`W(#T^(%\H(DIU;'DB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`X(#T^(%\H(D%U9W5S="(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#D@/3X@7R@B4V5P=&5M8F5R
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,3`@/3X@7R@B
M3V-T;V)E<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$Q
M(#T^(%\H(DYO=F5M8F5R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,3(@/3X@7R@B1&5C96UB97(B*2D["B`@("`@("`@)&1A=&5S6R=Y
M96%R)UT@/2!A<G)A>2@G)R`]/B!?*")965E9(BDI.PH@("`@("`@(&EF("@D
M=F%R+3YT>7!E+3Y?<W1A<G1?>65A<B`^("1V87(M/G1Y<&4M/E]E;F1?>65A
M<BD@>PH@("`@("`@("`@("!F;W(@*"1I(#T@)'9A<BT^='EP92T^7W-T87)T
M7WEE87([("1I(#X]("1V87(M/G1Y<&4M/E]E;F1?>65A<CL@)&DM+2D@>PH@
M("`@("`@("`@("`@("`@)&1A=&5S6R=Y96%R)UU;)&E=(#T@)&D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F;W(@*"1I
M(#T@)'9A<BT^='EP92T^7W-T87)T7WEE87([("1I(#P]("1V87(M/G1Y<&4M
M/E]E;F1?>65A<CL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&1A=&5S6R=Y
M96%R)UU;)&E=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('-P<FEN=&8H)SQS96QE8W0@;F%M93TB)7,B(&ED/2(E<R(E
M<SXE<SPO<V5L96-T/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^
M='EP92T^9V5T36]N=&A687(H)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@)'9A<BT^='EP92T^9V5T36]N=&A687(H)'9A<BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D
M=F%R*2P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E;&5C=$]P
M=&EO;G,H)&1A=&5S6R=M;VYT:"==+"`D=F%R<RT^9V5T*"1V87(M/G1Y<&4M
M/F=E=$UO;G1H5F%R*"1V87(I*2DI("X*("`@("`@("`@("`@<W!R:6YT9B@G
M/'-E;&5C="!N86UE/2(E<R(@:60](B5S(B5S/B5S/"]S96QE8W0^)RP*("`@
M("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3YG971996%R5F%R*"1V87(I
M+`H@("`@("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/F=E=%EE87)687(H
M)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY3
M8W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-E;&5C=$]P=&EO;G,H)&1A=&5S6R=Y96%R)UTL("1V87)S+3YG970H
M)'9A<BT^='EP92T^9V5T665A<E9A<B@D=F%R*2DI*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;6]N=&AD87EY96%R*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D9&%T97,@/2!A<G)A>2@I
M.PH@("`@("`@("1D871E<ULG;6]N=&@G72`](&%R<F%Y*"<G("`@/3X@7R@B
M34TB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G,2<@(#T^
M(%\H(DIA;G5A<GDB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G,B<@(#T^(%\H(D9E8G)U87)Y(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)S,G("`]/B!?*")-87)C:"(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<T)R`@/3X@7R@B07!R:6PB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G-2<@(#T^(%\H(DUA>2(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<V)R`@/3X@7R@B2G5N
M92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<W)R`@/3X@
M7R@B2G5L>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<X
M)R`@/3X@7R@B075G=7-T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)SDG("`]/B!?*")397!T96UB97(B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G,3`G(#T^(%\H(D]C=&]B97(B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G,3$G(#T^(%\H(DYO=F5M8F5R
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S$R)R`]/B!?
M*")$96-E;6)E<B(I*3L*("`@("`@("`D9&%T97-;)V1A>2==(#T@87)R87DH
M)R<@/3X@7R@B1$0B*2D["B`@("`@("`@9F]R("@D:2`](#$[("1I(#P](#,Q
M.R`D:2LK*2!["B`@("`@("`@("`@("1D871E<ULG9&%Y)UU;)&E=(#T@)&D[
M"B`@("`@("`@?0H@("`@("`@("1D871E<ULG>65A<B==(#T@87)R87DH)R<@
M/3X@7R@B65E962(I*3L*("`@("`@("!I9B`H)'9A<BT^='EP92T^7W-T87)T
M7WEE87(@/B`D=F%R+3YT>7!E+3Y?96YD7WEE87(I('L*("`@("`@("`@("`@
M9F]R("@D:2`]("1V87(M/G1Y<&4M/E]S=&%R=%]Y96%R.R`D:2`^/2`D=F%R
M+3YT>7!E+3Y?96YD7WEE87([("1I+2TI('L*("`@("`@("`@("`@("`@("1D
M871E<ULG>65A<B==6R1I72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`]("1V87(M/G1Y<&4M/E]S
M=&%R=%]Y96%R.R`D:2`\/2`D=F%R+3YT>7!E+3Y?96YD7WEE87([("1I*RLI
M('L*("`@("`@("`@("`@("`@("1D871E<ULG>65A<B==6R1I72`]("1I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1D871E(#T@)'9A<BT^
M='EP92T^9V5T1&%T95!A<G1S*"1V87(M/F=E=%9A;'5E*"1V87)S*2D["@H@
M("`@("`@("\O(%1/1$\Z('5S92!.3%,@=&\@9V5T('1H92!O<F1E<B!R:6=H
M="!F;W(@=&AE(%)E<W0@3V8@5&AE"B`@("`@("`@+R\@5V]R;&0N"B`@("`@
M("`@)&AT;6P@/2`G)SL*("`@("`@("`D9&%T95]P87)T<R`](&%R<F%Y*"=M
M;VYT:"<L("=D87DG+"`G>65A<B<I.PH@("`@("`@(&9O<F5A8V@@*"1D871E
M7W!A<G1S(&%S("1P87)T*2!["B`@("`@("`@("`@("1V87)N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I("X@)ULG("X@)'!A
M<G0@+B`G72<L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@
M("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQS96QE8W0@;F%M93TB)7,B(&ED
M/2(E<R(E<SXE<SPO<V5L96-T/B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E;&5C=$]P=&EO;G,H)&1A=&5S
M6R1P87)T72P@)&1A=&5;)'!A<G1=*2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'9A<BT^='EP92T^7W!I8VME<B`F)B`D1TQ/0D%,4ULG8G)O=W-E<B==
M+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.F%D9%-C<FEP=$9I;&4H)V]P96Y?8V%L96YD87(N:G,G+"`G:&]R9&4G
M*3L*("`@("`@("`@("`@)&EM9TED(#T@)'1H:7,M/E]G96Y)1"@D=F%R+3YG
M971687).86UE*"DL(&9A;'-E*2`N("=G;W1O)SL*("`@("`@("`@("`@)&AT
M;6P@+CT@)SQD:78@:60](F=O=&\B(&-L87-S/2)H96%D97)B;W@B('-T>6QE
M/2)P;W-I=&EO;CIA8G-O;'5T93MV:7-I8FEL:71Y.FAI9&1E;CMP861D:6YG
M.C`B/CPO9&EV/B<@+@H@("`@("`@("`@("`@("`@2&]R9&4Z.FQI;FLH)R,G
M+"!?*")396QE8W0@82!D871E(BDL("<G+"`G)RP@)V]P96Y#86QE;F1A<BA<
M)R<@+B`D:6UG260@+B`G7"<L(%PG)R`N("1V87(M/F=E=%9A<DYA;64H*2`N
M("=<)RD[(')E='5R;B!F86QS93LG*2`N($AO<F1E.CII;6<H)V-A;&5N9&%R
M+G!N9R<L(%\H(D-A;&5N9&%R(BDL("=I9#TB)R`N("1I;6=)9"`N("<B(&%L
M:6=N/2)M:61D;&4B)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E
M1&ER*"=H;W)D92<I*2`N("(\+V$^7&XB.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1H=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687))
M;G!U=%]C;VQO<G!I8VME<B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>2P@)&)R;W=S97(["@H@("`@("`@
M("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M
M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("1H
M=&UL(#T@)SQT86)L92!C96QL<W!A8VEN9STB,"(^/'1R/CQT9#XG("X*("`@
M("`@("`@("`@)SQI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(Q,"(@;6%X;&5N
M9W1H/2(W(B!N86UE/2(G("X*("`@("`@("`@("`@)'9A<FYA;64@+B`G(B!I
M9#TB)R`N("1V87)N86UE("X*("`@("`@("`@("`@)R(@=F%L=64](B<@+B!`
M:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="D@+B`G(B`O/CPO=&0^)SL*("`@("`@
M("!I9B`H)&)R;W=S97(M/FAA<T9E871U<F4H)VIA=F%S8W)I<'0G*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G;W!E;E]C;VQO<G!I
M8VME<BYJ<R<L("=H;W)D92<L('1R=64I.PH@("`@("`@("`@("`D:'1M;"`N
M/2`G/'1D('=I9'1H/2(R,"(@:60](F-O;&]R9&5M;U\G("X@)'9A<FYA;64@
M+B`G(B!S='EL93TB8F%C:V=R;W5N9#HG("X@0&AT;6QS<&5C:6%L8VAA<G,H
M)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I("X@)R(^(#PO=&0^)R`N"B`@("`@("`@("`@("`@("`G/'1D/B<@
M+B!(;W)D93HZ;&EN:R@G(R<L(%\H(D-O;&]R(%!I8VME<B(I+"`G=VED9V5T
M)RP@)R<L("=O<&5N0V]L;W)0:6-K97(H7"<G("X@)'9A<FYA;64@+B`G7"<I
M.R!R971U<FX@9F%L<V4[)RD@+B!(;W)D93HZ:6UG*"=C;VQO<G!I8VME<BYP
M;F<G+"!?*")#;VQO<B!0:6-K97(B*2P@)VAE:6=H=#TB,38B)RP@)')E9VES
M=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/CPO=&0^)R`N"B`@
M("`@("`@("`@("`@("`G/'1D/CQD:78@:60](F-O;&]R<&EC:V5R7R<@+B`D
M=F%R;F%M92`N("<B(&-L87-S/2)C;VYT<F]L(CX\+V1I=CX\+W1D/B<["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D:'1M;"`N("<\+W1R/CPO=&%B;&4^
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?<V]R=&5R
M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!G;&]B86P@
M)')E9VES=')Y.PH*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H
M87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*3L*("`@("`@("`D:6YS=&%N8V4@/2`D=F%R+3YT>7!E+3Y?:6YS
M=&%N8V4["@H@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=S;W)T97(N
M:G,G+"`G:&]R9&4G+"!T<G5E*3L*"B`@("`@("`@<F5T=7)N("<\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2(G("X@)'9A<FYA;64@+@H@("`@("`@("`@
M("`G6V%R<F%Y72(@=F%L=64](B(@)R`N("1T:&ES+3Y?9V5N240H)'9A<FYA
M;64@+B`G6V%R<F%Y72<I("X@)R\^)R`N"B`@("`@("`@("`@("<\<V5L96-T
M(&-L87-S/2)L969T1FQO870B(&UU;'1I<&QE/2)M=6QT:7!L92(@<VEZ93TB
M)R`N"B`@("`@("`@("`@("AI;G0I)'9A<BT^='EP92T^9V5T4VEZ92@I("X@
M)R(@;F%M93TB)R`N("1V87)N86UE("X*("`@("`@("`@("`@)UML:7-T72(@
M;VYC:&%N9V4](B<@+B`D:6YS=&%N8V4@+B`G+F1E<V5L96-T2&5A9&5R*"D[
M(B`G("X*("`@("`@("`@("`@)'1H:7,M/E]G96Y)1"@D=F%R;F%M92`N("=;
M;&ES=%TG*2`N("<^)R`N"B`@("`@("`@("`@("1V87(M/G1Y<&4M/F=E=$]P
M=&EO;G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I*2`N("<\+W-E;&5C=#X\9&EV
M(&-L87-S/2)L969T1FQO870B/B<@+@H@("`@("`@("`@("!(;W)D93HZ;&EN
M:R@G(R<L(%\H(DUO=F4@=7`B*2P@)R<L("<G+"`D:6YS=&%N8V4@+B`G+FUO
M=F5#;VQU;6Y5<"@I.R!R971U<FX@9F%L<V4[)RD@+B!(;W)D93HZ:6UG*"=N
M878O=7`N<&YG)RP@7R@B36]V92!U<"(I+"`G)RP@)')E9VES=')Y+3YG971)
M;6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/CQB<B`O/B<@+@H@("`@("`@("`@
M("!(;W)D93HZ;&EN:R@G(R<L(%\H(DUO=F4@=7`B*2P@)R<L("<G+"`D:6YS
M=&%N8V4@+B`G+FUO=F5#;VQU;6Y$;W=N*"D[(')E='5R;B!F86QS93LG*2`N
M($AO<F1E.CII;6<H)VYA=B]D;W=N+G!N9R<L(%\H(DUO=F4@9&]W;B(I+"`G
M)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/CPO
M9&EV/B<@+@H@("`@("`@("`@("`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/B<@+B`B7&XB("X*("`@("`@("`@("`@<W!R:6YT9B@G)3$D<R`]
M(&YE=R!(;W)D95]&;W)M7U-O<G1E<BA<)R4Q)'-<)RP@7"<E,B1S7"<L(%PG
M)3,D<UPG*3LG("X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`D:6YS=&%N
M8V4L("1V87)N86UE+"`D=F%R+3YT>7!E+3YG971(96%D97(H*2D@+@H@("`@
M("`@("`@("!S<')I;G1F*"(E<RYS971(:61D96XH*3M<;CPO<V-R:7!T/EQN
M(BP@)&EN<W1A;F-E*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M26YP=71?87-S:6=N*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("!(;W)D93HZ861D4V-R
M:7!T1FEL92@G9F]R;5]A<W-I9VXN:G,G+"`G:&]R9&4G+"!T<G5E*3L*"B`@
M("`@("`@)&YA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).
M86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@
M)&9N86UE(#T@)&9O<FTM/F=E=$YA;64H*2`N("<N)R`N("1V87(M/F=E=%9A
M<DYA;64H*3L*("`@("`@("`D<VEZ92`]("1V87(M/G1Y<&4M/F=E=%-I>F4H
M*3L*("`@("`@("`D=VED=&@@/2`D=F%R+3YT>7!E+3YG9717:61T:"@I.PH@
M("`@("`@("1L:&1R(#T@*&)O;VPI)'9A<BT^='EP92T^9V5T2&5A9&5R*#`I
M.PH@("`@("`@("1R:&1R(#T@*&)O;VPI)'9A<BT^='EP92T^9V5T2&5A9&5R
M*#$I.PH@("`@("`@("1T:&ES+3Y?861D3VY,;V%D2F%V87-C<FEP="@G2&]R
M9&5?1F]R;5]!<W-I9VXN<V5T1FEE;&0H7"<G("X@)&9N86UE("X@)UPG*3LG
M*3L*"B`@("`@("`@<F5T=7)N("<\=&%B;&4^/'1R/CQT9#XG("X*("`@("`@
M("`@("`@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B<@+B`D;F%M92`N
M("=?7W9A;'5E<R(@+SXG("X*("`@("`@("`@("`@<W!R:6YT9B@G/'-E;&5C
M="!N86UE/2(E<U]?;&5F="(@;75L=&EP;&4](FUU;'1I<&QE(B!S:7IE/2(E
M9"(@<W1Y;&4](G=I9'1H.B5S(B5S/B<L"B`@("`@("`@("`@("`@("`@("`@
M)&YA;64L("1S:7IE+"`D=VED=&@L"B`@("`@("`@("`@("`@("`@("`@)&QH
M9'(@/R`G(&]N8VAA;F=E/2)(;W)D95]&;W)M7T%S<VEG;BYD97-E;&5C=$AE
M861E<G,H7"<G("X@)&9N86UE("X@)UPG+"`P*3LB)R`Z("<G*2`N"B`@("`@
M("`@("`@("1V87(M/G1Y<&4M/F=E=$]P=&EO;G,H,"P@)&9N86UE*2`N"B`@
M("`@("`@("`@("<\+W-E;&5C=#X\+W1D/CQT9#XG("X*("`@("`@("`@("`@
M)SQA(&AR968](B(@;VYC;&EC:STB2&]R9&5?1F]R;5]!<W-I9VXN;6]V92A<
M)R<@+B`D9FYA;64@+@H@("`@("`@("`@("`G7"<L(#`I.R!R971U<FX@9F%L
M<V4[(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G<FAA;F0N<&YG)RP@
M7R@B061D(&-O;'5M;B(I+"!N=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*2`N"B`@("`@("`@("`@("<\+V$^/&)R("\^/&$@:')E9CTB
M(B!O;F-L:6-K/2)(;W)D95]&;W)M7T%S<VEG;BYM;W9E*%PG)R`N"B`@("`@
M("`@("`@("1F;F%M92`N("=<)RP@,2D[(')E='5R;B!F86QS93LB/B<@+@H@
M("`@("`@("`@("!(;W)D93HZ:6UG*"=L:&%N9"YP;F<G+"!?*")296UO=F4@
M8V]L=6UN(BDL(&YU;&PL("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI("X*("`@("`@("`@("`@)SPO83X\+W1D/CQT9#XG("X*("`@("`@("`@
M("`@<W!R:6YT9B@G/'-E;&5C="!N86UE/2(E<U]?<FEG:'0B(&UU;'1I<&QE
M/2)M=6QT:7!L92(@<VEZ93TB)60B('-T>6QE/2)W:61T:#HE<R(E<SXG+`H@
M("`@("`@("`@("`@("`@("`@("1N86UE+"`D<VEZ92P@)'=I9'1H+`H@("`@
M("`@("`@("`@("`@("`@("1R:&1R(#\@)R!O;F-H86YG93TB2&]R9&5?1F]R
M;5]!<W-I9VXN9&5S96QE8W1(96%D97)S*%PG)R`N("1F;F%M92`N("=<)RP@
M,2D[(B<@.B`G)RD@+@H@("`@("`@("`@("`D=F%R+3YT>7!E+3YG971/<'1I
M;VYS*#$L("1F;F%M92D@+@H@("`@("`@("`@("`G/"]S96QE8W0^/"]T9#X\
M+W1R/CPO=&%B;&4^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M26YP=71?:6YV86QI9"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<F5N9&5R5F%R1&ES<&QA>5]I;G9A;&ED
M*"1F;W)M+"`D=F%R+"`D=F%R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E9A<DEN<'5T7V5N=6TH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1V86QU97,@/2`D=F%R+3YG971686QU97,H*3L*("`@("`@
M("`D<')O;7!T(#T@)'9A<BT^='EP92T^9V5T4')O;7!T*"D["B`@("`@("`@
M)&AT;6QC:&%R<R`]("1V87(M/F=E=$]P=&EO;B@G:'1M;&-H87)S)RD["B`@
M("`@("`@:68@*"%E;7!T>2@D<')O;7!T*2D@>PH@("`@("`@("`@("`D<')O
M;7!T(#T@)SQO<'1I;VX@=F%L=64](B(^)R`N("@D:'1M;&-H87)S(#\@)'!R
M;VUP="`Z($!H=&UL<W!E8VEA;&-H87)S*"1P<F]M<'0L($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="DI("X@)SPO;W!T:6]N/B<["B`@("`@("`@?0H@
M("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T
M5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@
M("`@(')E='5R;B!S<')I;G1F*"<\<V5L96-T(&YA;64](B5S(B!I9#TB)7,B
M("5S/B5S)7,\+W-E;&5C=#XG+`H@("`@("`@("`@("`@("`@("`@("`@("1V
M87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D
M9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@)'!R;VUP="P*
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E;&5C=$]P=&EO;G,H
M)'9A;'5E<RP@)'9A<BT^9V5T5F%L=64H)'9A<G,I+"`D:'1M;&-H87)S*2D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VUL96YU;2@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@
M/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@)&AV87)N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<FYA;64L($5.5%]154]415,L("1T:&ES+3Y?
M8VAA<G-E="D["B`@("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I
M.PH@("`@("`@("1P<F]M<'1S(#T@)'9A<BT^='EP92T^9V5T4')O;7!T<R@I
M.PH@("`@("`@("1S96QE8W1E9"`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*
M("`@("`@("`O*B!)9B!P87-S:6YG(&$@;F]N+6%R<F%Y('9A;'5E(&YE960@
M=&\@9V5T('1H92!K97ES+B`J+PH@("`@("`@(&EF("@A:7-?87)R87DH)'-E
M;&5C=&5D*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1K
M97E?,2`]/B`D=F%L=65S7S(I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D=F%L=65S7S);)'-E;&5C=&5D72DI('L*("`@("`@("`@("`@("`@("`@
M("`D<V5L96-T960@/2!A<G)A>2@G,2<@/3X@)&ME>5\Q+"`G,B<@/3X@)'-E
M;&5C=&5D*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M2&ED9&5N('1A9R!T;R!S=&]R92!T:&4@8W5R<F5N="!F:7)S="!L979E;"X@
M*B\*("`@("`@("`D:'1M;"`]('-P<FEN=&8H)SQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](B5S6V]L9%TB('9A;'5E/2(E<R(@)7,@+SXG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D:'9A<FYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1S96QE8W1E9%LG,2==+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V=E;DE$*"1V87)N86UE("X@)UMO;&1=)RDI.PH*("`@
M("`@("`O*B!&:7)S="!L979E;"X@*B\*("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@)'9A;'5E<U\Q(#T@2&]R9&5?
M07)R87DZ.G9A;'5E<U1O2V5Y<RAA<G)A>5]K97ES*"1V86QU97,I*3L*("`@
M("`@("`D:'1M;"`N/2!S<')I;G1F*"<\<V5L96-T("5S(&YA;64](B5S6S%=
M(B!O;F-H86YG93TB)7,B)7,^)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9V5N240H)'9A<FYA;64@+B`G6S%=)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D:'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G:68@*'1H:7,N=F%L=64I('L@9&]C=6UE;G0N)R`N("1F;W)M+3YG
M971.86UE*"D@+B`G+F9O<FUN86UE+G9A;'5E/5PG7"<[)R`N("=D;V-U;65N
M="XG("X@)&9O<FTM/F=E=$YA;64H*2`N("<N<W5B;6ET*"D@?2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`H)'9A<BT^:&%S06-T:6]N*"D@/R`G("<@
M+B`D=&AI<RT^7V=E;D%C=&EO;E-C<FEP="@D9F]R;2P@)'9A<BT^7V%C=&EO
M;BP@)'9A<FYA;64I(#H@)R<I*3L*("`@("`@("!I9B`H(65M<'1Y*"1P<F]M
M<'1S*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB
M(CXG("X@0&AT;6QS<&5C:6%L8VAA<G,H)'!R;VUP='-;,%TL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]
M"B`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1V86QU
M97-?,2P@)'-E;&5C=&5D6R<Q)UTI.PH@("`@("`@("1H=&UL("X]("<\+W-E
M;&5C=#XG.PH*("`@("`@("`O*B!396-O;F0@;&5V96PN("HO"B`@("`@("`@
M)&AT;6P@+CT@<W!R:6YT9B@G/'-E;&5C="`E<R!N86UE/2(E<ULR72(E<SXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G96Y)1"@D=F%R
M;F%M92`N("=;,ETG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1H=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("@D=F%R+3YH87-!8W1I
M;VXH*2`_("<@)R`N("1T:&ES+3Y?9V5N06-T:6]N4V-R:7!T*"1F;W)M+"`D
M=F%R+3Y?86-T:6]N+"`D=F%R;F%M92D@.B`G)RDI.PH@("`@("`@(&EF("@A
M96UP='DH)'!R;VUP=',I*2!["B`@("`@("`@("`@("1H=&UL("X]("<\;W!T
M:6]N('9A;'5E/2(B/B<@+B!`:'1M;'-P96-I86QC:&%R<R@D<')O;7!T<ULQ
M72P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N("<\+V]P=&EO;CXG
M.PH@("`@("`@('T*("`@("`@("`D=F%L=65S7S(@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("@A96UP='DH)'-E;&5C=&5D6R<Q)UTI*2!["B`@("`@("`@("`@
M("1V86QU97-?,B`]("8D=F%L=65S6R1S96QE8W1E9%LG,2==73L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1H=&UL("X@)'1H:7,M/E]S96QE8W1/<'1I
M;VYS*"1V86QU97-?,BP@)'-E;&5C=&5D6R<R)UTI("X@)SPO<V5L96-T/B<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VUU;'1I96YU
M;2@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A;'5E
M<R`]("1V87(M/F=E=%9A;'5E<R@I.PH@("`@("`@("1S96QE8W1E9"`]("1V
M87)S+3YG971%>&ES=',H)'9A<BT^9V5T5F%R3F%M92@I+"`D=V%S<V5T*3L*
M("`@("`@("!I9B`H(21W87-S970I('L*("`@("`@("`@("`@)'-E;&5C=&5D
M(#T@)'9A<BT^9V5T1&5F875L="@I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@<W!R:6YT9B@G/'-E;&5C="!M=6QT:7!L93TB;75L=&EP;&4B('-I>F4]
M(B5S(B!N86UE/2(E<UM=(B`E<SXE<SPO<V5L96-T/B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@*&EN="DD=F%R+3YT>7!E+3YS:7IE+`H@("`@("`@("`@
M("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA
M;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL
M("1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;75L=&E3
M96QE8W1/<'1I;VYS*"1V86QU97,L("1S96QE8W1E9"DI("X*("`@("`@("`@
M("`@(CQB<B`O/EQN(B`N(%\H(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@
M:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K
M97D@=VAI;&4@8VQI8VMI;F<N(BD@+B`B7&XB.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)687));G!U=%]R861I;R@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%D:6]"=71T;VYS
M*"1V87(M/F=E=%9A<DYA;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<BT^9V5T5F%L=65S*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V87(M/F=E=%9A;'5E*"1V87)S*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W-E="@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@)&AT;6P@/2`D=&AI<RT^7V-H96-K0F]X97,H
M)'9A<BT^9V5T5F%R3F%M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V87(M/F=E=%9A;'5E<R@I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V87(M/F=E=%9A;'5E*"1V87)S*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C
M=&EO;E-C<FEP=',H)&9O<FTL("1V87(I*3L*"B`@("`@("`@:68@*"1V87(M
M/G1Y<&4M/E]C:&5C:T%L;"D@>PH@("`@("`@("`@("`D9F]R;5]N86UE(#T@
M)&9O<FTM/F=E=$YA;64H*3L*("`@("`@("`@("`@)'9A<E]N86UE(#T@)'9A
M<BT^9V5T5F%R3F%M92@I("X@)UM=)SL*("`@("`@("`@("`@)&9U;F-T:6]N
M7VYA;64@/2`G<V5L96-T)R`@+B`D9F]R;5]N86UE("X@)'9A<BT^9V5T5F%R
M3F%M92@I.PH@("`@("`@("`@("`D96YA8FQE(#T@7R@B4V5L96-T(&%L;"(I
M.PH@("`@("`@("`@("`D9&ES86)L92`](%\H(E-E;&5C="!N;VYE(BD["B`@
M("`@("`@("`@("1I;G9E<G0@/2!?*"));G9E<G0@<V5L96-T:6]N(BD["B`@
M("`@("`@("`@("1H=&UL("X](#P\/$5/5`H\<V-R:7!T('1Y<&4](G1E>'0O
M:F%V87-C<FEP="(^"F9U;F-T:6]N("1F=6YC=&EO;E]N86UE*"D*>PH@("`@
M9F]R("AV87(@:2`](#`[(&D@/"!D;V-U;65N="XD9F]R;5]N86UE+F5L96UE
M;G1S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@9B`](&1O8W5M96YT+B1F;W)M
M7VYA;64N96QE;65N='-;:5T["B`@("`@("`@:68@*&8N;F%M92`A/2`G)'9A
M<E]N86UE)RD@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@
M("`@("`@:68@*&%R9W5M96YT<RYL96YG=&@I('L*("`@("`@("`@("`@9BYC
M:&5C:V5D(#T@87)G=6UE;G1S6S!=.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&8N8VAE8VME9"`]("%F+F-H96-K960["B`@("`@("`@?0H@("`@
M?0I]"CPO<V-R:7!T/@H\82!H<F5F/2(C(B!O;F-L:6-K/2(D9G5N8W1I;VY?
M;F%M92AT<G5E*3L@<F5T=7)N(&9A;'-E.R(^)&5N86)L93PO83XL"CQA(&AR
M968](B,B(&]N8VQI8VL](B1F=6YC=&EO;E]N86UE*&9A;'-E*3L@<F5T=7)N
M(&9A;'-E.R(^)&1I<V%B;&4\+V$^+`H\82!H<F5F/2(C(B!O;F-L:6-K/2(D
M9G5N8W1I;VY?;F%M92@I.R!R971U<FX@9F%L<V4[(CXD:6YV97)T/"]A/@I%
M3U0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VQI;FLH)B1F;W)M+"`F)'9A
M<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E
M<E9A<D1I<W!L87E?;&EN:R@D9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]H=&UL*"8D9F]R;2P@)B1V
M87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R96YD
M97)687)$:7-P;&%Y7VAT;6PH)&9O<FTL("1V87(L("1V87)S*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?96UA:6PH)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\
M:6YP=70@='EP93TB=&5X="(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S
M(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG971687).
M86UE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T5F%R3F%M
M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/F=E=%9A;'5E*"1V
M87)S*2P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO
M;E-C<FEP=',H)&9O<FTL("1V87(I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R26YP=71?;6%T<FEX*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D=F%R;F%M92`@(#T@)'9A<BT^9V5T5F%R3F%M92@I
M.PH@("`@("`@("1V87)?87)R87D@/2`D=F%R+3YG971686QU92@D=F%R<RD[
M"B`@("`@("`@)&-O;',@("`@("`]("1V87(M/G1Y<&4M/F=E=$-O;',H*3L*
M("`@("`@("`D<F]W<R`@("`@(#T@)'9A<BT^='EP92T^9V5T4F]W<R@I.PH@
M("`@("`@("1M871R:7@@("`@/2`D=F%R+3YT>7!E+3YG971-871R:7@H*3L*
M("`@("`@("`D;F5W7VEN<'5T(#T@)'9A<BT^='EP92T^9V5T3F5W26YP=70H
M*3L*"B`@("`@("`@)&AT;6P@/2`G/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX\
M='(^)SL*"B`@("`@("`@)&AT;6P@+CT@)SQT9"!A;&EG;CTB<FEG:'0B('=I
M9'1H/2(R,"4B/CPO=&0^)SL*("`@("`@("!F;W)E86-H("@D8V]L<R!A<R`D
M8V]L7W1I=&QE*2!["B`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQT
M9"!A;&EG;CTB8V5N=&5R(B!W:61T:#TB,24E(CXE<SPO=&0^)RP@)&-O;%]T
M:71L92D["B`@("`@("`@?0H@("`@("`@("1H=&UL("X]("<\=&0@86QI9VX]
M(G)I9VAT(B!W:61T:#TB-C`E(CX\+W1D/CPO='(^)SL*"B`@("`@("`@+RH@
M3V9F97(@82!N97<@<F]W(&]F(&1A=&$@=&\@8F4@861D960@=&\@=&AE(&UA
M=')I>#\@*B\*("`@("`@("!I9B`H)&YE=U]I;G!U="D@>PH@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1R/CQT9#XG.PH@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)&YE=U]I;G!U="DI('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P
M<FEN=&8H)SQS96QE8W0@)7,@;F%M93TB)7-;;EU;<ETB/CQO<'1I;VX@=F%L
M=64](B(^)7,\+V]P=&EO;CXE<SPO<V5L96-T/CQB<B`O/B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]G96Y)1"@D=F%R;F%M92`N("=;;EU;
M<ETG*2P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("!?*"(M+2!S96QE8W0@+2TB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-E;&5C=$]P=&EO;G,H)&YE=U]I;G!U
M="P@)'9A<E]A<G)A>5LG;B==6R=R)UTI*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1N97=?:6YP=70@/3T@=')U92D@>PH@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@<W!R:6YT9B@G/&EN<'5T("5S('1Y<&4](G1E>'0B(&YA;64](B5S
M6VY=6W)=(B!V86QU93TB)7,B("\^)RP*("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E;DE$*"1V87)N86UE("X@)UMN75MR72<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("1V87)?87)R87E;)VXG75LG<B==*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D:'1M;"`N/2`G(#PO=&0^)SL*("`@("`@("`@("`@9F]R96%C
M:"`H)&-O;',@87,@)&-O;%]I9"`]/B`D8V]L7W1I=&QE*2!["B`@("`@("`@
M("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\=&0@86QI9VX](F-E;G1E<B(^
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C;&%S<STB8VAE8VMB;W@B(&YA;64]
M(B5S6VY=6W9=6R5S72(@+SX\+W1D/B<L("1V87)N86UE+"`D8V]L7VED*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/'1D/B`\+W1D
M/CPO='(^)SL*("`@("`@("!]"@H@("`@("`@("\J($QO;W`@=&AR;W5G:"!T
M:&4@<F]W<R!A;F0@8W)E871E(&-H96-K8F]X97,@9F]R(&5A8V@@8V]L=6UN
M+B`J+PH@("`@("`@(&9O<F5A8V@@*"1R;W=S(&%S("1R;W=?:60@/3X@)')O
M=U]T:71L92D@>PH@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\='(^
M/'1D/B5S/"]T9#XG+"`D<F]W7W1I=&QE*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)&-O;',@87,@)&-O;%]I9"`]/B`D8V]L7W1I=&QE*2!["B`@("`@("`@
M("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\=&0@86QI9VX](F-E;G1E<B(^
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C;&%S<STB8VAE8VMB;W@B(&YA;64]
M(B5S6W)=6R5S75LE<UTB)7,@+SX\+W1D/B<L("1V87)N86UE+"`D<F]W7VED
M+"`D8V]L7VED+"`H(65M<'1Y*"1M871R:7A;)')O=U]I9%U;)&-O;%]I9%TI
M(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)RDI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1H=&UL("X]("<\=&0^(#PO=&0^/"]T<CXG.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO=&%B;&4^)SL*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?<&%S<W=O<F0H)B1F
M;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@
M0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F
M*"<\:6YP=70@='EP93TB<&%S<W=O<F0B(&YA;64](B5S(B!I9#TB)7,B('9A
M;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L
M=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D
M9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687))
M;G!U=%]E;6%I;&-O;F9I<FTH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1E;6%I;"`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@
M("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A
M<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@
M("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](B5S
M6V]R:6=I;F%L72(@:60](B5S6V]R:6=I;F%L72(@=F%L=64](B5S(B5S("\^
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("!`:'1M;'-P96-I86QC:&%R<R@D96UA:6Q;)V]R:6=I;F%L)UTL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D@+@H@
M("`@("`@("`@("`G("<@+B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@
M;F%M93TB)7-;8V]N9FER;5TB(&ED/2(E<UMC;VYF:7)M72(@=F%L=64](B5S
M(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D96UA:6Q;)V-O
M;F9I<FTG72P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H
M)&9O<FTL("1V87(I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M26YP=71?<&%S<W=O<F1C;VYF:7)M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D<&%S<W=O<F0@/2`D=F%R+3YG971686QU92@D=F%R
M<RD["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R
M+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D[
M"B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)P87-S=V]R
M9"(@;F%M93TB)7-;;W)I9VEN86Q=(B!I9#TB)7-;;W)I9VEN86Q=(B!V86QU
M93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1P87-S=V]R9%LG;W)I
M9VEN86PG72P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O
M<FTL("1V87(I*2`N"B`@("`@("`@("`@("<@)R`N('-P<FEN=&8H)SQI;G!U
M="!T>7!E/2)P87-S=V]R9"(@;F%M93TB)7-;8V]N9FER;5TB(&ED/2(E<UMC
M;VYF:7)M72(@=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I
M86QC:&%R<R@D<&%S<W=O<F1;)V-O;F9I<FTG72P@14Y47U%53U1%4RP@)'1H
M:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?8F]O;&5A;B@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P
M96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T
M:&ES+3Y?8VAA<G-E="D["B`@("`@("`@)&AT;6P@/2`G/&EN<'5T('1Y<&4]
M(F-H96-K8F]X(B!C;&%S<STB8VAE8VMB;W@B(&YA;64](B<@+B`@)'9A<FYA
M;64@+B`G(B<@+@H@("`@("`@("`@("`G(&ED/2(G("X@)'9A<FYA;64@+B`G
M(B<@+B`H)'9A<BT^9V5T5F%L=64H)'9A<G,I(#\@)R!C:&5C:V5D/2)C:&5C
M:V5D(B<@.B`G)RD["B`@("`@("`@:68@*"1V87(M/FAA<T%C=&EO;B@I*2![
M"B`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?9V5N06-T:6]N4V-R:7!T
M*"1F;W)M+"`D=F%R+3Y?86-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG971687).86UE*"DI.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&AT;6P@+B`G("\^)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?8W)E9&ET8V%R9"@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`
M:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@)&AT;6P@/2`G/&EN<'5T
M('1Y<&4](G1E>'0B(&YA;64](B<@+B`D=F%R;F%M92`N("<B(&ED/2(G("X@
M)'9A<FYA;64@+B`G(B!V86QU93TB)R`N"B`@("`@("`@("`@($!H=&UL<W!E
M8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@
M)'1H:7,M/E]C:&%R<V5T*2`N("<B)SL*("`@("`@("!I9B`H)'9A<BT^:&%S
M06-T:6]N*"DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]G96Y!
M8W1I;VY38W)I<'0H)&9O<FTL("1V87(M/E]A8W1I;VXL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87(M/F=E=%9A
M<DYA;64H*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:'1M;"`N("<@
M+SXG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]O8G)O
M=W-E<B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A
M<FYA;64@/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@)'9A<G9A;'5E
M(#T@)'9A<G,M/F=E="@D=F%R;F%M92D["B`@("`@("`@)&9I96QD260@/2`D
M=&AI<RT^7V=E;DE$*&UD-2AU;FEQ:60H<F%N9"@I+"!T<G5E*2DL(&9A;'-E
M*2`N("=I9"<["B`@("`@("`@)&AT;6P@/2`G"B`@("`@("`@("`@(#QS8W)I
M<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*("`@("`@("`@("`@=F%R(&]B
M<F]W<V5R5VEN9&]W3F%M93L*("`@("`@("`@("`@9G5N8W1I;VX@;V)R;W=S
M97)#86QL8F%C:RAN86UE+"!O:60I"B`@("`@("`@("`@('L*("`@("`@("`@
M("`@("`@(&EF("AN86UE(#T](&]B<F]W<V5R5VEN9&]W3F%M92D@>PH@("`@
M("`@("`@("`@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*%PG)R`N
M("1F:65L9$ED("X@)UPG*2YV86QU92`](&]I9#L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`B26YV86QI9"!W:6YD;W<@;F%M
M92!S=7!P;&EE9"(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@/"]S8W)I<'0^"B`@("`@("`@("`@("<["B`@("`@("`@
M)&AT;6P@+CT@<W!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M)7,B(&ED/2(E<R(E<R!V86QU93TB)7,B/B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R;F%M92P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("1F:65L9$ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87)V86QU92P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D["B`@("`@("`@:68@*"%E;7!T>2@D
M=F%R=F%L=64I*2!["B`@("`@("`@("`@("1H=&UL("X]("1V87)V86QU93L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH
M87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@2&]R9&4Z
M.F%D9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U92D["B`@
M("`@("`@("`@("1I;6=)9"`]("1T:&ES+3Y?9V5N240H)'9A<FYA;64L(&9A
M;'-E*2`N("=G;W1O)SL*("`@("`@("`@("`@)&AT;6P@+CT@)SQD:78@:60]
M(F=O=&\B(&-L87-S/2)H96%D97)B;W@B('-T>6QE/2)P;W-I=&EO;CIA8G-O
M;'5T93MV:7-I8FEL:71Y.FAI9&1E;CMP861D:6YG.C`B/CPO9&EV/B<@+@H@
M("`@("`@("`@("`@("`@2&]R9&4Z.FQI;FLH)R,G+"!?*")396QE8W0@86X@
M;V)J96-T(BDL("<G+"`G)RP@)V]B<F]W<V5R5VEN9&]W(#T@<&]P=7`H7"<G
M("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D
M92<I("X@)R]S97)V:6-E<R]O8G)O=W-E<B\G("X@)UPG*3L@;V)R;W=S97)7
M:6YD;W=.86UE(#T@;V)R;W=S97)7:6YD;W<N;F%M93L@<F5T=7)N(&9A;'-E
M.R<I("X@2&]R9&4Z.FEM9R@G=')E92]L96%F+G!N9R<L(%\H(D]B:F5C="(I
M+"`G:60](B<@+B`D:6UG260@+B`G(B!A;&EG;CTB;6ED9&QE(B<L("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`B/"]A
M/EQN(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?9&)L;V]K=7`H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)E;F1E<E9A<DEN<'5T7V5N=6TH)&9O<FTL("1V87(L("1V87)S*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?9FEG;&5T*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G
M/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](B5S(B!I9#TB)7,B('-I>F4](B5S
M(B!V86QU93TB)7,B("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("!S=')L96XH)'9A<BT^='EP92T^9V5T5&5X="@I
M*2P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D
M=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="DI("X*("`@("`@("`@("`@)SQB<B`O/B<@+B!?*")%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SHB*2`N("<\8G(@+SXG("X*("`@("`@("`@("`@)'1H
M:7,M/E]R96YD97)687)$:7-P;&%Y7V9I9VQE="@D9F]R;2P@)'9A<BP@)'9A
M<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y1&5F
M875L="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T
M=7)N(&YL,F)R*$!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V
M87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?:'1M;"@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@+R\@4VEN8V4@=&AI<R!I<R!A
M;B!(5$U,('1Y<&4@=V4@97AP;&EC:71L>2!D;VXG="!E<V-A<&4*("`@("`@
M("`O+R!I="X@57-E<B!B97=A<F4N"B`@("`@("`@<F5T=7)N("1V87(M/F=E
M=%9A;'5E*"1V87)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M1&ES<&QA>5]E;6%I;"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@)&1I<W!L87E?96UA:6P@/2`D96UA:6P@/2`D=F%R+3YG971686QU
M92@D=F%R<RD["@H@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?<W1R:7!?9&]M
M86EN("8F('-T<G!O<R@D96UA:6PL("=`)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1D:7-P;&%Y7V5M86EL(#T@<W1R7W)E<&QA8V4H87)R87DH)T`G
M+"`G+B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"<@*&%T*2`G+"`G("AD;W0I("<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;6%I;"D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'9A<BT^='EP92T^7VQI;FM?8V]M<&]S92D@>PH@
M("`@("`@("`@("`D96UA:6Q?=F%L(#T@=')I;2@D96UA:6PI.PH*("`@("`@
M("`@("`@+R\@1F]R;6%T('1H92!A9&1R97-S(&%C8V]R9&EN9R!T;R!21D,X
M,C(N"B`@("`@("`@("`@("1M86EL8F]X7VAO<W0@/2!E>'!L;V1E*"=`)RP@
M)&5M86EL7W9A;"D["B`@("`@("`@("`@(&EF("@A:7-S970H)&UA:6QB;WA?
M:&]S=%LQ72DI('L*("`@("`@("`@("`@("`@("1M86EL8F]X7VAO<W1;,5T@
M/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&YA;64@/2!N=6QL
M.PH@("`@("`@("`@("!I9B`H)'9A<BT^='EP92T^7VQI;FM?;F%M92D@>PH@
M("`@("`@("`@("`@("`@)&YA;64@/2`D=F%R+3YT>7!E+3Y?;&EN:U]N86UE
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+TU)344N<&AP)SL*("`@("`@("`@("`@)&%D9')E<W,@/2!-24U%.CIR
M9F,X,C)7<FET94%D9')E<W,H)&UA:6QB;WA?:&]S=%LP72P@)&UA:6QB;WA?
M:&]S=%LQ72P@)&YA;64I.PH*("`@("`@("`@("`@+R\@1V5T(')I9"!O9B!T
M:&4@=')A:6QI;F<@0"`H=VAE;B!N;R!H;W-T(&ES(&EN8VQU9&5D(&EN"B`@
M("`@("`@("`@("\O('1H92!E;6%I;"!A9&1R97-S*2X*("`@("`@("`@("`@
M)&%D9')E<W,@/2!S=')?<F5P;&%C92@G0#XG+"`G/B<L("1A9&1R97-S*3L*
M("`@("`@("`@("`@)&UA:6Q?;&EN:R`]("1'3$]"04Q36R=R96=I<W1R>2==
M+3YC86QL*"=M86EL+V-O;7!O<V4G+"!A<G)A>2AA<G)A>2@G=&\G(#T^(&%D
M9'-L87-H97,H)&%D9')E<W,I*2DI.PH@("`@("`@("`@("!I9B`H:7-?82@D
M;6%I;%]L:6YK+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D
M;6%I;%]L:6YK(#T@)VUA:6QT;SHG("X@=7)L96YC;V1E*"1A9&1R97-S*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N($AO<F1E.CIL:6YK
M*"1M86EL7VQI;FLL("1E;6%I;%]V86PI("X@0&AT;6QS<&5C:6%L8VAA<G,H
M)&1I<W!L87E?96UA:6PL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D@
M+B`G/"]A/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(&YL,F)R*$!H=&UL<W!E8VEA;&-H87)S*"1D:7-P;&%Y7V5M86EL+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?<&%S<W=O<F0H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`G*BHJ*BHJ
M*BHG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7W!A
M<W-W;W)D8V]N9FER;2@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@<F5T=7)N("<J*BHJ*BHJ*B<["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E9A<D1I<W!L87E?;V-T86PH)B1F;W)M+"`F)'9A<BP@)B1V87)S
M*0H@("`@>PH@("`@("`@(')E='5R;B!S<')I;G1F*"<P)6\G+"!O8W1D96,H
M)'9A<BT^9V5T5F%L=64H)'9A<G,I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E9A<D1I<W!L87E?8F]O;&5A;B@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@<F5T=7)N("1V87(M/F=E=%9A;'5E*"1V87)S
M*2`_(%\H(EEE<R(I(#H@7R@B3F\B*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R1&ES<&QA>5]E;G5M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@
M("`@("`@)'9A;'5E(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@
M(&EF("AC;W5N="@D=F%L=65S*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R
M;B!?*").;R!V86QU97,B*3L*("`@("`@("!](&5L<V5I9B`H:7-S970H)'9A
M;'5E<ULD=F%L=65=*2`F)B`D=F%L=64@(3T@)R<I('L*("`@("`@("`@("`@
M<F5T=7)N($!H=&UL<W!E8VEA;&-H87)S*"1V86QU97-;)'9A;'5E72P@14Y4
M7U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?<F%D:6\H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R+3YG
M971686QU97,H*3L*("`@("`@("!I9B`H8V]U;G0H)'9A;'5E<RD@/3T@,"D@
M>PH@("`@("`@("`@("!R971U<FX@7R@B3F\@=F%L=65S(BD["B`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1V86QU97-;)'9A<BT^9V5T5F%L=64H)'9A<G,I
M72DI('L*("`@("`@("`@("`@<F5T=7)N($!H=&UL<W!E8VEA;&-H87)S*"1V
M86QU97-;)'9A<BT^9V5T5F%L=64H)'9A<G,I72P@14Y47U%53U1%4RP@)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E9A<D1I<W!L87E?;75L=&EE;G5M*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S
M*"D["B`@("`@("`@)&]N(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@
M("`@(&EF("@A8V]U;G0H)'9A;'5E<RD@?'P@(6-O=6YT*"1O;BDI('L*("`@
M("`@("`@("`@<F5T=7)N(%\H(DYO('9A;'5E<R(I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1D:7-P;&%Y(#T@87)R87DH*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D=F%L=64@/3X@)&YA;64I('L*("`@
M("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D=F%L=64L("1O;BDI('L*("`@
M("`@("`@("`@("`@("`@("`D9&ES<&QA>5M=(#T@)&YA;64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N($!H
M=&UL<W!E8VEA;&-H87)S*&EM<&QO9&4H)RP@)RP@)&1I<W!L87DI+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]S970H)B1F;W)M+"`F)'9A
M<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R+3YG9716
M86QU97,H*3L*("`@("`@("`D;VX@/2`D=F%R+3YG971686QU92@D=F%R<RD[
M"B`@("`@("`@:68@*"%C;W5N="@D=F%L=65S*2!\?"`A8V]U;G0H)&]N*2D@
M>PH@("`@("`@("`@("!R971U<FX@7R@B3F\@=F%L=65S(BD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&1I<W!L87D@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1V86QU92`]/B`D;F%M92D@
M>PH@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1V86QU92P@)&]N*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1D:7-P;&%Y6UT@/2`D;F%M93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@0&AT;6QS<&5C:6%L8VAA<G,H:6UP;&]D92@G+"`G+"`D9&ES<&QA>2DL
M($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7VEM86=E*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D:6UG7W!A<F%M<R`]
M("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`D:6UG7W5R;"`]($AO
M<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L
M("=H;W)D92<I("X@)R]S97)V:6-E<R]I;6%G97,O=FEE=RYP:'`G*3L*("`@
M("`@("`D:6UG7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG7W5R;"P@
M)&EM9U]P87)A;7,I.PH*("`@("`@("!R971U<FX@2&]R9&4Z.FEM9R@D:6UG
M7W5R;"P@:7-S970H)&EM9U]P87)A;7-;)V8G72D@/R`D:6UG7W!A<F%M<ULG
M9B==(#H@)R<L("<G+"`G)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<D1I<W!L87E?8V5L;'!H;VYE*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D;G5M
M8F5R(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@("1H=&UL(#T@
M0&AT;6QS<&5C:6%L8VAA<G,H)&YU;6)E<BP@14Y47U%53U1%4RP@)'1H:7,M
M/E]C:&%R<V5T*3L*"B`@("`@("`@:68@*"1N=6UB97(@)B8@)')E9VES=')Y
M+3YH87--971H;V0H)W-M<R]C;VUP;W-E)RDI('L*("`@("`@("`@("`@)'5R
M;"`]("1R96=I<W1R>2T^;&EN:R@G<VUS+V-O;7!O<V4G+"!A<G)A>2@G=&\G
M(#T^("1N=6UB97(I*3L*("`@("`@("`@("`@)&AT;6P@+CT@)R`G("X@2&]R
M9&4Z.FQI;FLH)'5R;"P@7R@B4V5N9"!335,B*2D@+B!(;W)D93HZ:6UG*"=S
M=V]O<V@N<&YG)RP@7R@B4V5N9"!335,B*2P@)R<L("1R96=I<W1R>2T^9V5T
M26UA9V5$:7(H)W-W;V]S:"<I*2`N("<\+V$^)SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R1&ES<&QA>5]A9&1R97-S*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D861D<F5S
M<R`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`D875S7W-T871E
M7W)E9V5X(#T@)R@_.D%#5'Q.4U=\3E1\44Q$?%-!?%1!4WQ624-\5T$I)SL*
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H*#\Z05M"3%U\0EM!0D1(3$Y2
M4U1=/WQ#6T%"1DA-3U)45E==?$1;041%1TA,3E1977Q%6T-(3EA=/WQ&6TM9
M77Q'6TQ565T_?$A;041'4%)355A=?$E;1TU05EU\2D5\2UM!5%=977Q,6T%$
M14Q.4U5=/WQ-6T5+3%T_?$Y;14=.4%)773]\3UM,6%U\4%M!14A,3U)=?%);
M1TA-77Q36T%%1TM,34Y/4%)35%=973]\5%M!1$9.45)35UU\54)\5UM!0T1&
M3E)35ET_?%E/?%I%*5QD*#\Z7&1\6T$M6ETI/R!<9%M!+5I=>S)]*2\G+"`D
M861D<F5S<RP@)'!O<W1C;V1E*2D@>PH@("`@("`@("`@("`O*B!52R!P;W-T
M8V]D92!D971E8W1E9"X@*B\*("`@("`@("`@("`@+RH@375L=&EM87`N8V\N
M=6L@9V5N97)A=&5D(&UA<"`J+PH@("`@("`@("`@("`D;6%P=7)L(#T@)VAT
M='`Z+R]W=W<N;75L=&EM87`N8V]M+VUA<"]B<F]W<V4N8V=I/W!C/2<@+B!U
M<FQE;F-O9&4H)'!O<W1C;V1E6S%=*3L*("`@("`@("`@("`@)&1E<V,@/2!?
M*")-=6QT:6UA<"!52R!M87`B*3L*("`@("`@("`@("`@)&EC;VX@/2`G;6%P
M+G!N9R<["B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]<8B<@+B`D
M875S7W-T871E7W)E9V5X("X@)UQB+R<L("1A9&1R97-S*2D@>PH@("`@("`@
M("`@("`O*B!!=7-T<F%L:6%N('-T871E(&1E=&5C=&5D+B`J+PH@("`@("`@
M("`@("`O*B!7:&5R96ES+F-O;2YA=2!G96YE<F%T960@;6%P("HO"B`@("`@
M("`@("`@("1M87!U<FP@/2`G:'1T<#HO+W=W=RYW:&5R96ES+F-O;2YA=2]W
M:&5R96ES+VUA<'!I;F<O9V5O8V]D94%D9')E<W,N9&\_)SL*("`@("`@("`@
M("`@)&1E<V,@/2!?*")7:&5R96ES($%U<W1R86QI82!M87`B*3L*("`@("`@
M("`@("`@)&EC;VX@/2`G;6%P+G!N9R<["B`@("`@("`@("`@("\J(%-P;&ET
M(&]U="!T:&4@861D<F5S<RP@;&EN92UB>2UL:6YE+B`J+PH@("`@("`@("`@
M("`D861D<F5S<TQI;F5S(#T@97AP;&]D92@B7&XB+"`D861D<F5S<RD["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1A9&1R97-S3&EN
M97,I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`O*B!3964@:68@:70G<R!T
M:&4@<W1R965T(&YU;6)E<B`F(&YA;64N("HO"B`@("`@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@G+RA<9"M<<RI<+UQS*BD_*%QD*WQ<9"M;82UZ02U:
M72E<<RLH6V$M>D$M6B!=*BDO)RP@)&%D9')E<W-,:6YE<ULD:5TL("1L:6YE
M4&%R=',I*2!["B`@("`@("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)G-T
M<F5E=$YU;6)E<CTG("X@=7)L96YC;V1E*"1L:6YE4&%R='-;,ETI("X@)R9S
M=')E971.86UE/2<@+B!U<FQE;F-O9&4H)&QI;F5087)T<ULS72D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`O*B!,;V]K(&9O<B`B4W5B
M=7)B+"!3=&%T92(N("HO"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@G+RA;82UZ02U:(%TJ*2P_7',K)R`N("1A=7-?<W1A=&5?<F5G97AP("X@
M)R\G+"`D861D<F5S<TQI;F5S6R1I72P@)&QI;F5087)T<RDI('L*("`@("`@
M("`@("`@("`@("`@("`D;6%P=7)L("X]("<F<W5B=7)B/2<@+B!U<FQE;F-O
M9&4H)&QI;F5087)T<ULQ72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`O*B!,;V]K(&9O<B`B4W1A=&4@/#0@9&EG:70@<&]S=&-O9&4^
M(BX@*B\*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*"<@+B`D
M875S7W-T871E7W)E9V5X<"`N("<I7',K*%QD>S1]*2\G+"`D861D<F5S<TQI
M;F5S6R1I72P@)&QI;F5087)T<RDI('L*("`@("`@("`@("`@("`@("`@("`D
M;6%P=7)L("X]("<F<W1A=&4])R`N('5R;&5N8V]D92@D;&EN95!A<G1S6S%=
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS96EF("AP<F5G7VUA=&-H*"<O*"XJ*5QN*"XJ*5QS*BQ<<RHH7'<K*5PN
M/UQS*RA<9"M\6V$M>D$M6EU<9%MA+7I!+5I=7',_7&1;82UZ02U:75QD*2\G
M+"`D861D<F5S<RP@)&%D9')E<W-087)T<RDI('L*("`@("`@("`@("`@+RH@
M06UE<FEC86XO0V%N861I86X@861D<F5S<R!S='EL92X@*B\*("`@("`@("`@
M("`@+RH@36%P<75E<W0@9V5N97)A=&5D(&UA<"`J+PH@("`@("`@("`@("`D
M;6%P=7)L(#T@)VAT='`Z+R]W=W<N;6%P<75E<W0N8V]M+VUA<',O;6%P+F%D
M<#]S:7IE/6)I9R9Z;V]M/3<G.PH@("`@("`@("`@("`D9&5S8R`](%\H(DUA
M<%%U97-T(&UA<"(I.PH@("`@("`@("`@("`D:6-O;B`]("=M87`N<&YG)SL*
M("`@("`@("`@("`@)&-O=6YT<GD@/2!N=6QL.PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1A9&1R97-S4&%R='-;-%TI("8F('!R96=?;6%T8V@H)WQ;82UZ
M02U:75QD6V$M>D$M6EU<<S]<9%MA+7I!+5I=7&1\)RP@)&%D9')E<W-087)T
M<ULT72DI('L*("`@("`@("`@("`@("`@("1C;W5N=')Y(#T@)T-!)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R
M='-;,5TI*2!["B`@("`@("`@("`@("`@("`D;6%P=7)L("X]("<F861D<F5S
M<STG("X@=7)L96YC;V1E*"1A9&1R97-S4&%R='-;,5TI.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULR72DI
M('L*("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9C:71Y/2<@+B!U<FQE
M;F-O9&4H)&%D9')E<W-087)T<ULR72D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S-=*2D@>PH@("`@("`@
M("`@("`@("`@)&UA<'5R;"`N/2`G)G-T871E/2<@+B!U<FQE;F-O9&4H)&%D
M9')E<W-087)T<ULS72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D861D<F5S<U!A<G1S6S1=*2D@>PH@("`@("`@("`@("`@("`@
M:68@*"1C;W5N=')Y(#T]("=#02<I('L*("`@("`@("`@("`@("`@("`@("`D
M;6%P=7)L("X]("<F8V]U;G1R>3U#02<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D;6%P=7)L("X]("<F>FEP8V]D93TG("X@=7)L96YC
M;V1E*"1A9&1R97-S4&%R='-;-%TI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!986AO;R$@9V5N97)A=&5D(&UA<"X@*B\*("`@("`@("`@("`@
M)&UA<'5R;#(@/2`G:'1T<#HO+W5S+G)D+GEA:&]O+F-O;2]M87!S+VAO;64O
M<W5B;6ET7V$O*BUH='1P.B\O;6%P<RYY86AO;RYC;VTO;6%P<S]S<F-H='EP
M93UA)F=E=&UA<#U'970K36%P)B<["B`@("`@("`@("`@("1D97-C,B`](%\H
M(EEA:&]O(2!M87`B*3L*("`@("`@("`@("`@)&EC;VXR(#T@)VUA<"YP;F<G
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;,5TI*2![
M"B`@("`@("`@("`@("`@("`D;6%P=7)L,B`N/2`G)F%D9'(])R`N('5R;&5N
M8V]D92@D861D<F5S<U!A<G1S6S%=*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`O*B!':79E('!R96-E9&5N8V4@=&\@>FEP8V]D92!O=F5R(&-I='DO
M<W1A=&4@*B\*("`@("`@("`@("`@:68@*&5M<'1Y*"1A9&1R97-S4&%R='-;
M-%TI("8F("%E;7!T>2@D861D<F5S<U!A<G1S6S)=*2`F)B`A96UP='DH)&%D
M9')E<W-087)T<ULS72DI('L*("`@("`@("`@("`@("`@("1M87!U<FPR("X]
M("<F8W-Z/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULR72`N("<@)R`N
M("1A9&1R97-S4&%R='-;,UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A96UP='DH)&%D9')E<W-087)T<ULT72DI('L*("`@("`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"=\*%MA+7I!+5I=7&1;82UZ02U:72E<<S\H
M7&1;82UZ02U:75QD*7PG+"`D861D<F5S<U!A<G1S6S1=+"`D<&-087)T<RDI
M('L*("`@("`@("`@("`@("`@("`@("`D;6%P=7)L,B`N/2`G)F-O=6YT<GD]
M8V$G.PH@("`@("`@("`@("`@("`@("`@("\J(&UA:V4@<W5R92!T:&4@<&]S
M=&%L+6-O9&4@:&%S(&$@<W!A8V4@*B\*("`@("`@("`@("`@("`@("`@("`D
M861D<F5S<U!A<G1S6S1=(#T@)'!C4&%R='-;,5T@+B`G("<@+B`D<&-087)T
M<ULR73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1M87!U
M<FPR("X]("<F8W-Z/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULT72D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($=O;V=L92!G96YE<F%T
M960@;6%P+B`J+PH@("`@("`@("`@("`D;6%P=7)L,R`]("=H='1P.B\O;6%P
M<RYG;V]G;&4N8V]M+VUA<',_<3TG("X@=7)L96YC;V1E*"1A9&1R97-S4&%R
M='-;,%TI("X@)R9H;#UE;B<["B`@("`@("`@("`@("1D97-C,R`](%\H(D=O
M;V=L92!-87!S(BD["B`@("`@("`@("`@("1I8V]N,R`]("=M87`N<&YG)SL*
M"B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R\H+BH_*5QR/UQN*%M!
M+5I=>S$L,WTI+2A<9'LU?2E<<RLH+BHI+VDG+"`D861D<F5S<RP@)&%D9')E
M<W-087)T<RDI('L*("`@("`@("`@("`@+RH@175R;W!E86X@861D<F5S<R!S
M='EL92X@*B\*("`@("`@("`@("`@:6YC;'5D92`G2&]R9&4O3DQ3+V-A<G-I
M9VYS+G!H<"<["B`@("`@("`@("`@("1C;W5N=')Y(#T@87)R87E?<V5A<F-H
M*%-T<FEN9SHZ=7!P97(H)&%D9')E<W-087)T<ULR72DL("1C87)S:6=N<RD[
M"@H@("`@("`@("`@("`O*B!-87`R-"!G96YE<F%T960@;6%P+B`J+PH@("`@
M("`@("`@("!I9B`H:6Y?87)R87DH)&-O=6YT<GDL(&%R<F%Y*"=A;"<L("=A
M9"<L("=A;2<L("=A>B<L("=B92<L("=B82<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V)G)RP@)V1E)RP@)V1K)RP@)V5E
M)RP@)V9O)RP@)V9I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9G(G+"`G9V4G+"`G9W(G+"`G9V(G+"`G:64G+"`G:7,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I
M="<L("=H<B<L("=L=B<L("=L:2<L("=L="<L("=L=2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUT)RP@)VUK)RP@)VUD
M)RP@)VUC)RP@)VYL)RP@)VYO)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<&PG+"`G<'0G+"`G<F\G+"`G<G4G+"`G<V4G
M+"`G8V@G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=C<R<L("=S:R<L("=S:2<L("=E<R<L("=C>B<L("=T<B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5A)RP@)VAU
M)RP@)V)Y)RP@)V-Y)RP@)V%T)RDI*2!["B`@("`@("`@("`@("`@("!I9B`H
M:6Y?87)R87DH)&-O=6YT<GDL(&%R<F%Y*"=A="<L("=B92<L("=C:"<L("=D
M92<L("=D:R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=E<R<L("=F:2<L("=F<B<L("=I="<L("=N;"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N;R<L
M("=S92<I*2D@>PH@("`@("`@("`@("`@("`@("`@("1M:7)R;W(@/2`D8V]U
M;G1R>3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)&UI<G)O<B`]("=U:R<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D;6%P=7)L(#T@)VAT='`Z+R]W=W<N)R`N("1M:7)R;W(@
M+B`G+FUA<#(T+F-O;2]S;W5R8V4O861D<F5S<R]V,BXP+C`O8VYT7VYA=E]M
M87!L970N<&AP/V-I9#UV86QI9&%T96%D9'(F8V]U;G1R>3TG("X@)&-O=6YT
M<GD["B`@("`@("`@("`@("`@("`D9&5S8R`](%\H(DUA<#(T(&UA<"(I.PH@
M("`@("`@("`@("`@("`@)&EC;VX@/2`G;6%P7V5U+G!N9R<["B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;,5TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)G-T<F5E=#TG("X@=7)L96YC
M;V1E*"1A9&1R97-S4&%R='-;,5TI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S-=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9Z:7`])R`N('5R;&5N
M8V]D92@D861D<F5S<U!A<G1S6S-=*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULT72DI('L*
M("`@("`@("`@("`@("`@("`@("`D;6%P=7)L("X]("<F8VET>3TG("X@=7)L
M96YC;V1E*"1A9&1R97-S4&%R='-;-%TI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!-87!Q=65S="!G96YE<F%T
M960@;6%P+B`J+PH@("`@("`@("`@("`D;6%P=7)L,B`]("=H='1P.B\O=W=W
M+FUA<'%U97-T+F-O;2]M87!S+VUA<"YA9'`_8V]U;G1R>3TG("X@4W1R:6YG
M.CIU<'!E<B@D8V]U;G1R>2D["B`@("`@("`@("`@("1D97-C,B`](%\H(DUA
M<%%U97-T(&UA<"(I.PH@("`@("`@("`@("`D:6-O;C(@/2`G;6%P7V5U+G!N
M9R<["B`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULQ72DI
M('L*("`@("`@("`@("`@("`@("1M87!U<FPR("X]("<F861D<F5S<STG("X@
M=7)L96YC;V1E*"1A9&1R97-S4&%R='-;,5TI.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULS72DI('L*("`@
M("`@("`@("`@("`@("1M87!U<FPR("X]("<F>FEP8V]D93TG("X@=7)L96YC
M;V1E*"1A9&1R97-S4&%R='-;,UTI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULT72DI('L*("`@("`@("`@
M("`@("`@("1M87!U<FPR("X]("<F8VET>3TG("X@=7)L96YC;V1E*"1A9&1R
M97-S4&%R='-;-%TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D:'1M;"`](&YL,F)R*$!H=&UL<W!E8VEA;&-H87)S*"1A9&1R97-S+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*("`@("`@("!I9B`H(65M
M<'1Y*"1M87!U<FPI*2!["B`@("`@("`@("`@("1H=&UL("X]("<F;F)S<#LF
M;F)S<#LG("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F5X=&5R;F%L57)L*"1M87!U
M<FPI+"`D9&5S8RP@;G5L;"P@)U]B;&%N:R<I("X@2&]R9&4Z.FEM9R@D:6-O
M;BP@)&1E<V,L("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA
M9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PH@("`@("`@('T*("`@("`@("!I
M9B`H(65M<'1Y*"1M87!U<FPR*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G
M)FYB<W`[)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIE>'1E<FYA;%5R;"@D;6%P
M=7)L,BDL("1D97-C,BP@;G5L;"P@)U]B;&%N:R<I("X@2&]R9&4Z.FEM9R@D
M:6-O;C(L("1D97-C,BP@)V%L:6=N/2)M:61D;&4B)RP@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<["B`@("`@("`@?0H@("`@
M("`@(&EF("@A96UP='DH)&UA<'5R;#,I*2!["B`@("`@("`@("`@("1H=&UL
M("X]("<F;F)S<#LG("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F5X=&5R;F%L57)L
M*"1M87!U<FPS*2P@)&1E<V,S+"!N=6QL+"`G7V)L86YK)RD@+B!(;W)D93HZ
M:6UG*"1I8V]N,RP@)&1E<V,S+"`G86QI9VX](FUI9&1L92(G+"`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R1&ES<&QA>5]D871E*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("!R971U<FX@:'1M;'-P96-I86QC:&%R<R@D=F%R+3YT
M>7!E+3YG971&;W)M871T9614:6UE*"1V87(M/F=E=%9A;'5E*"1V87)S*2DI
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7VAO=7)M
M:6YU=&5S96-O;F0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@
M("`@("1T:6UE(#T@)'9A<BT^='EP92T^9V5T5&EM95!A<G1S*"1V87(M/F=E
M=%9A;'5E*"1V87)S*2D["B`@("`@("`@:68@*"$D=F%R+3YT>7!E+3Y?<VAO
M=U]S96-O;F1S*2!["B`@("`@("`@("`@(')E='5R;B`H:6YT*21T:6UE6R=H
M;W5R)UT@+B`G.B<@+B!S<')I;G1F*"<E,#)D)RP@*&EN="DD=&EM95LG;6EN
M=71E)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`H
M:6YT*21T:6UE6R=H;W5R)UT@+B`G.B<@+B!S<')I;G1F*"<E,#)D)RP@*&EN
M="DD=&EM95LG;6EN=71E)UTI("X@)SHG("X@<W!R:6YT9B@G)3`R9"<L("AI
M;G0I)'1I;65;)W-E8V]N9"==*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?;6]N=&AY96%R*"8D9F]R;2P@)B1V
M87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@*&EN="DD=F%R<RT^
M9V5T*"1V87(M/F=E=%9A<DYA;64H*2`N("=;;6]N=&A=)RD@+B`G+"`G("X@
M*&EN="DD=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2`N("=;>65A<ETG
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]M;VYT
M:&1A>7EE87(H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M("1D871E(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@(&EF("@H
M:7-?87)R87DH)&1A=&4I("8F("%E;7!T>2@D9&%T95LG>65A<B==*2`F)@H@
M("`@("`@("`@("`@(65M<'1Y*"1D871E6R=M;VYT:"==*2`F)B`A96UP='DH
M)&1A=&5;)V1A>2==*2D*("`@("`@("`@("`@?'P@*"%I<U]A<G)A>2@D9&%T
M92D@)B8@(65M<'1Y*"1D871E*2DI('L*("`@("`@("`@("`@<F5T=7)N("1V
M87(M/G1Y<&4M/F9O<FUA=$1A=&4H)&1A=&4I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)R<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I
M<W!L87E?:6YV86QI9"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@<F5T=7)N("<\<W!A;B!C;&%S<STB9F]R;2UE<G)O<B(^)R`N($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/G1Y<&4M/FUE<W-A9V4L($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D@+B`G/"]S<&%N/B<["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?;&EN:R@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A;'5E<R`]("1V87(M/G1Y<&4M
M/G9A;'5E<SL*("`@("`@("!I9B`H(6ES<V5T*"1V86QU97-;,%TI*2!["B`@
M("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=F%L=65S*3L*("`@("`@("!]
M"@H@("`@("`@("1C;W5N="`](&-O=6YT*"1V86QU97,I.PH@("`@("`@("1H
M=&UL(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D
M:2LK*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=F%L=65S6R1I75LG=7)L
M)UTI('Q\(&5M<'1Y*"1V86QU97-;)&E=6R=T97AT)UTI*2!["B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1V86QU97-;)&E=6R=T87)G970G72DI('L*("`@("`@("`@
M("`@("`@("1V86QU97-;)&E=6R=T87)G970G72`]("<G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)'9A;'5E<ULD:5U;)V]N8VQI
M8VLG72DI('L*("`@("`@("`@("`@("`@("1V86QU97-;)&E=6R=O;F-L:6-K
M)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1V86QU97-;)&E=6R=T:71L92==*2D@>PH@("`@("`@("`@("`@("`@)'9A
M;'5E<ULD:5U;)W1I=&QE)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1V86QU97-;)&E=6R=A8V-E<W-K97DG72DI('L*
M("`@("`@("`@("`@("`@("1V86QU97-;)&E=6R=A8V-E<W-K97DG72`]("<G
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D:2`^(#`I('L*("`@
M("`@("`@("`@("`@("1H=&UL("X]("<@?"`G.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"1V86QU97-;)&E=6R=U
M<FPG72P@)'9A;'5E<ULD:5U;)W1E>'0G72P@)W=I9&=E="<L("1V86QU97-;
M)&E=6R=T87)G970G72P@)'9A;'5E<ULD:5U;)V]N8VQI8VLG72P@)'9A;'5E
M<ULD:5U;)W1I=&QE)UTL("1V86QU97-;)&E=6R=A8V-E<W-K97DG72D@+B!`
M:'1M;'-P96-I86QC:&%R<R@D=F%L=65S6R1I75LG=&5X="==+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I("X@)SPO83XG.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687)$:7-P;&%Y7V1B;&]O:W5P*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R96YD97)687)$:7-P;&%Y
M7V5N=6TH)&9O<FTL("1V87(L("1V87)S*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!?<F5N9&5R5F%R1&ES<&QA>5]F:6=L970H)B1F;W)M+"`F)'9A<BP@)B1V
M87)S*0H@("`@>PH@("`@("`@('-T871I8R`D9FEG;&5T.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1F:6=L970I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G5&5X="]&:6=L970N<&AP)SL*("`@("`@("`@("`@)&9I9VQE="`]("9N
M97<@5&5X=%]&:6=L970H*3L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@
M/2`D9FEG;&5T+3YL;V%D1F]N="@D=F%R+3YT>7!E+3YG971&;VYT*"DI.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0M/F=E=$UE<W-A9V4H*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`G/'!R93XG("X@)&9I9VQE="T^;&EN945C
M:&\H)'9A<BT^='EP92T^9V5T5&5X="@I*2`N("<\+W!R93XG.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]S96QE8W1&:6QE<R@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@+RH@3F5E9&5D(&9O
M<B!G;VQL96T@:G,@8V%L;',@*B\*("`@("`@("`D=F%R;F%M92`]($!H=&UL
M<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@
M)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`D:'1M;"`]('-P<FEN=&8H)SQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E
M<R(@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`G<V5L96-T;&ES=%]S
M96QE8W1I9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("=S96QE8W1L:7-T
M7W-E;&5C=&ED)RP*("`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^='EP
M92T^7W-E;&5C=&ED*2`N"B`@("`@("`@("`@('-P<FEN=&8H)SQI;G!U="!T
M>7!E/2)H:61D96XB(&YA;64](B5S(B!I9#TB)7,B("\^)RP@)V%C=&EO;DE$
M)RP@)V%C=&EO;DE$)RD@+@H*("`@("`@("`@("`@+RH@1F]R;2!F:65L9"X@
M*B\*("`@("`@("`@("`@<W!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B`O/B<L"B`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`@)'9A<BT^='EP92T^7W-E;&5C=&ED
M*3L*"B`@("`@("`@+RH@3W!E;B!W:6YD;W<@;&EN:RX@*B\*("`@("`@("`D
M<&%R86T@/2!A<G)A>2@D=F%R+3YT>7!E+3Y?;&EN:U]T97AT+`H@("`@("`@
M("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/E]L:6YK7W-T>6QE+`H@("`@
M("`@("`@("`@("`@("`@("`@("1F;W)M+3YG971.86UE*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<BT^='EP92T^7VEC;VXL"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<BT^='EP92T^7W-E;&5C=&ED*3L*("`@("`@("`D
M:'1M;"`N/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G9FEL97,O<V5L
M96-T;&ES=$QI;FLG+"`D<&%R86TI("X@(CQB<B`O/EQN(CL*"B`@("`@("`@
M:68@*"1V87(M/G1Y<&4M/E]S96QE8W1I9"D@>PH@("`@("`@("`@("`D<&%R
M86T@/2!A<G)A>2@D=F%R+3YT>7!E+3Y?<V5L96-T:60I.PH@("`@("`@("`@
M("`D9FEL97,@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G9FEL97,O
M<V5L96-T;&ES=%)E<W5L=',G+"`D<&%R86TI.PH@("`@("`@("`@("!I9B`H
M)&9I;&5S*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL97,@87,@
M)&ED(#T^("1F:6QE*2!["B`@("`@("`@("`@("`@("`@("`@)&1I<B`](&ME
M>2@D9FEL92D["B`@("`@("`@("`@("`@("`@("`@)&9I;&5N86UE(#T@8W5R
M<F5N="@D9FEL92D["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@*"1I
M9"`K(#$I("X@)RX@)SL*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1D:7(I("8F("@D9&ER("$]("<N)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&9I;&5N86UE(#T@)&1I<B`N("<O)R`N("1F:6QE;F%M93L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&AT;6P@
M+CT@0&AT;6QS<&5C:6%L8VAA<G,H)&9I;&5N86UE+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I("X@(CQB<B`O/EQN(CL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H
M=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S96QE8W1/<'1I;VYS*"8D=F%L
M=65S+"`D<V5L96-T961686QU92`](&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&AT;6QC:&%R<R`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1R97-U;'0@/2`G)SL*("`@("`@("`D<V5L(#T@9F%L<V4["B`@("`@("`@
M9F]R96%C:"`H)'9A;'5E<R!A<R`D=F%L=64@/3X@)&1I<W!L87DI('L*("`@
M("`@("`@("`@:68@*"%I<U]N=6QL*"1S96QE8W1E9%9A;'5E*2`F)B`A)'-E
M;"`F)@H@("`@("`@("`@("`@("`@)'9A;'5E(#T]("1S96QE8W1E9%9A;'5E
M("8F"B`@("`@("`@("`@("`@("!S=')L96XH)'9A;'5E*2`]/2!S=')L96XH
M)'-E;&5C=&5D5F%L=64I*2!["B`@("`@("`@("`@("`@("`D<V5L96-T960@
M/2`G('-E;&5C=&5D/2)S96QE8W1E9"(G.PH@("`@("`@("`@("`@("`@)'-E
M;"`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<V5L96-T960@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<F5S=6QT("X]("<@/&]P=&EO;B!V86QU93TB)SL*("`@("`@("`@("`@)')E
M<W5L="`N/2`D:'1M;&-H87)S"B`@("`@("`@("`@("`@("`_("1V86QU90H@
M("`@("`@("`@("`@("`@.B!`:'1M;'-P96-I86QC:&%R<R@D=F%L=64L($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@("`@("1R97-U
M;'0@+CT@)R(G("X@)'-E;&5C=&5D("X@)SXG.PH@("`@("`@("`@("`D<F5S
M=6QT("X]("1H=&UL8VAA<G,*("`@("`@("`@("`@("`@(#\@)&1I<W!L87D*
M("`@("`@("`@("`@("`@(#H@0&AT;6QS<&5C:6%L8VAA<G,H)&1I<W!L87DL
M($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@("`@("1R
M97-U;'0@+CT@(CPO;W!T:6]N/EQN(CL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*("`@(&9U;F-T:6]N(%]M=6QT:5-E;&5C
M=$]P=&EO;G,H)B1V86QU97,L("1S96QE8W1E9%9A;'5E<RD*("`@('L*("`@
M("`@("`D<F5S=6QT(#T@)R<["B`@("`@("`@)'-E;"`](&9A;'-E.PH@("`@
M("`@(&9O<F5A8V@@*"1V86QU97,@87,@)'9A;'5E(#T^("1D:7-P;&%Y*2![
M"B`@("`@("`@("`@(&EF("A`:6Y?87)R87DH)'9A;'5E+"`D<V5L96-T9616
M86QU97,I*2!["B`@("`@("`@("`@("`@("`D<V5L96-T960@/2`G('-E;&5C
M=&5D/2)S96QE8W1E9"(G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'-E;&5C=&5D(#T@)R<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)')E<W5L="`N/2`B(#QO<'1I;VX@=F%L=64]7"(B("X@0&AT;6QS
M<&5C:6%L8VAA<G,H)'9A;'5E+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S
M970I("X@(EPB)'-E;&5C=&5D/B(@+B!`:'1M;'-P96-I86QC:&%R<R@D9&ES
M<&QA>2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N("(\+V]P=&EO
M;CY<;B(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M('T*"B`@("!F=6YC=&EO;B!?8VAE8VM";WAE<R@D;F%M92P@)'9A;'5E<RP@
M)&-H96-K961686QU97,L("1A8W1I;VYS(#T@)R<I"B`@("!["B`@("`@("`@
M)')E<W5L="`]("<G.PH@("`@("`@(&EF("@A:7-?87)R87DH)&-H96-K9616
M86QU97,I*2!["B`@("`@("`@("`@("1C:&5C:V5D5F%L=65S(#T@87)R87DH
M*3L*("`@("`@("!]"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A8V@@
M*"1V86QU97,@87,@)'9A;'5E(#T^("1D:7-P;&%Y*2!["B`@("`@("`@("`@
M("1C:&5C:V5D(#T@*&EN7V%R<F%Y*"1V86QU92P@)&-H96-K961686QU97,I
M*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<["B`@("`@("`@("`@("1R
M97-U;'0@+CT@<W!R:6YT9B@G/&EN<'5T(&ED/2(E<R5S(B!T>7!E/2)C:&5C
M:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N86UE/2(E<UM=(B!V86QU93TB)7,B
M)7,E<R`O/CQL86)E;"!F;W(](B5S)7,B/B9N8G-P.R5S/"]L86)E;#X\8G(@
M+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C
M:6%L8VAA<G,H)&YA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1N86UE
M+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-H96-K960L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D86-T:6]N<RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1N86UE+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P
M96-I86QC:&%R<R@D9&ES<&QA>2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R
M<V5T*2D["B`@("`@("`@("`@("1I*RL["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F%D:6]"=71T
M;VYS*"1N86UE+"`D=F%L=65S+"`D8VAE8VME9%9A;'5E(#T@;G5L;"P@)&%C
M=&EO;G,@/2`G)RD*("`@('L*("`@("`@("`D<F5S=6QT(#T@)R<["B`@("`@
M("`@)&D@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)'9A;'5E
M(#T^("1D:7-P;&%Y*2!["B`@("`@("`@("`@("1C:&5C:V5D(#T@*"%I<U]N
M=6QL*"1C:&5C:V5D5F%L=64I("8F("1V86QU92`]/2`D8VAE8VME9%9A;'5E
M*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<["B`@("`@("`@("`@("1R
M97-U;'0@+CT@<W!R:6YT9B@G/&EN<'5T(&ED/2(E<R5S(B!T>7!E/2)R861I
M;R(@8VQA<W,](F-H96-K8F]X(B!N86UE/2(E<R(@=F%L=64](B5S(B5S)7,@
M+SX\;&%B96P@9F]R/2(E<R5S(CXF;F)S<#LE<SPO;&%B96P^/&)R("\^)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H
M87)S*"1N86UE+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D;F%M92P@14Y4
M7U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V86QU92P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C:&5C:V5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&%C=&EO;G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!`:'1M;'-P96-I86QC:&%R<R@D;F%M92P@14Y47U%53U1%4RP@)'1H:7,M
M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L
M8VAA<G,H)&1I<W!L87DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DI
M.PH@("`@("`@("`@("`D:2LK.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E;DE$*"1N86UE+"`D
M9G5L;'1A9R`]('1R=64I"B`@("!["B`@("`@("`@)&YA;64@/2!`:'1M;'-P
M96-I86QC:&%R<R@D;F%M92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*3L*("`@("`@("!R971U<FX@)&9U;&QT86<@/R`G:60](B<@+B`D;F%M92`N
M("<B)R`Z("1N86UE.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G96Y!8W1I;VY3
M8W)I<'0H)B1F;W)M+"`D86-T:6]N+"`D=F%R;F%M92D*("`@('L*("`@("`@
M("`D:'1M;"`]("<G.PH@("`@("`@("1T<FEG9V5R<R`]("1A8W1I;VXM/F=E
M=%1R:6=G97(H*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T<FEG9V5R<RDI
M('L*("`@("`@("`@("`@)'1R:6=G97)S(#T@87)R87DH)'1R:6=G97)S*3L*
M("`@("`@("!]"B`@("`@("`@)&IS(#T@)&%C=&EO;BT^9V5T06-T:6]N4V-R
M:7!T*"1F;W)M+"`D=&AI<RP@)'9A<FYA;64I.PH@("`@("`@(&9O<F5A8V@@
M*"1T<FEG9V5R<R!A<R`D=')I9V=E<BD@>PH@("`@("`@("`@("!I9B`H)'1R
M:6=G97(@/3T@)V]N;&]A9"<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M861D3VY,;V%D2F%V87-C<FEP="@D:G,I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)R`G("X@)'1R:6=G97(@+B`G
M/2(G("X@)&IS("X@)R(G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T06-T
M:6]N4V-R:7!T<R@F)&9O<FTL("8D=F%R*0H@("`@>PH@("`@("`@("1A8W1I
M;VYS(#T@)R<["B`@("`@("`@:68@*"1V87(M/FAA<T%C=&EO;B@I*2!["B`@
M("`@("`@("`@("1V87)N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@
M("`@("`@("`D86-T:6]N(#TF("1V87(M/E]A8W1I;VX["B`@("`@("`@("`@
M("1T<FEG9V5R<R`]("1A8W1I;VXM/F=E=%1R:6=G97(H*3L*("`@("`@("`@
M("`@:68@*"%I<U]A<G)A>2@D=')I9V=E<G,I*2!["B`@("`@("`@("`@("`@
M("`D=')I9V=E<G,@/2!A<G)A>2@D=')I9V=E<G,I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1J<R`]("1A8W1I;VXM/F=E=$%C=&EO;E-C<FEP="@D
M9F]R;2P@)'1H:7,L("1V87)N86UE*3L*("`@("`@("`@("`@9F]R96%C:"`H
M)'1R:6=G97)S(&%S("1T<FEG9V5R*2!["B`@("`@("`@("`@("`@("!I9B`H
M)'1R:6=G97(@/3T@)V]N;&]A9"<I('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%D9$]N3&]A9$IA=F%S8W)I<'0H)&IS*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&%C=&EO;G,@+CT@
M)R`G("X@)'1R:6=G97(@+B`G/2(G("X@)&IS("X@)R(G.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D86-T:6]N<SL*("`@('T*"B`@("!F=6YC=&EO;B!?861D3VY,;V%D2F%V
M87-C<FEP="@D<V-R:7!T*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;VY,;V%D
M2E-;72`]("1S8W)I<'0["B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R16YD
M*"D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]O;DQO861*4RDI
M('L*("`@("`@("`@("`@<F5T=7)N("(\<V-R:7!T('1Y<&4]7")T97AT+VIA
M=F%S8W)I<'1<(CXB("X*("`@("`@("`@("`@("`@("(\(2TM7&XB("X@(&EM
M<&QO9&4H(EQN(BP@)'1H:7,M/E]O;DQO861*4RD@+B`B7&XO+R`M+3Y<;B(@
M+@H@("`@("`@("`@("`@("`@(CPO<V-R:7!T/B(["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]522]687)296YD
M97)E<B]T86)L97-E=%]H=&UL+G!H<```````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8P-#0`
M,3`T,3<S-C(W-S$`,#(T,S,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]T86)L97-E=%]H=&UL+G!H<"QV(#$N
M,RXR+C$@,C`P-2\Q,"\Q."`Q,3HP,3HS-B!J86X@17AP("0*("H*("H@0'!A
M8VMA9V4@2&]R9&5?54D*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J+PIC;&%S
M<R!(;W)D95]525]687)296YD97)E<E]T86)L97-E=%]H=&UL(&5X=&5N9',@
M2&]R9&5?54E?5F%R4F5N9&5R97)?:'1M;"!["@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E9A<DEN<'5T7W1A8FQE<V5T*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D:&5A9&5R(#T@)'9A<BT^='EP92T^9V5T2&5A9&5R
M*"D["B`@("`@("`@)&YA;64@("`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@
M("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@("`@("`@)&-H
M96-K961686QU97,@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@
M)&%C=&EO;G,@/2`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V
M87(I.PH*("`@("`@("`D:'1M;"`]("<\=&%B;&4@=VED=&@](C$P,"4B(&-L
M87-S/2)I=&5M(B!C96QL<W!A8VEN9STB,2(^/'1R(&-L87-S/2)S96QE8W1E
M9"(^)R`N"B`@("`@("`@("`@("<\=&@@8VQA<W,](G=I9&=E="(@86QI9VX]
M(G)I9VAT(B!W:61T:#TB,24B/B9N8G-P.SPO=&@^)SL*("`@("`@("!F;W)E
M86-H("@D:&5A9&5R(&%S("1C;VQ?=&ET;&4I('L*("`@("`@("`@("`@)&AT
M;6P@+CT@<W!R:6YT9B@G/'1H(&%L:6=N/2)L969T(B!C;&%S<STB=VED9V5T
M(CXE<SPO=&@^)RP@)&-O;%]T:71L92D["B`@("`@("`@?0H@("`@("`@("1H
M=&UL("X]("<\+W1R/B<["@H@("`@("`@(&EF("@A:7-?87)R87DH)&-H96-K
M961686QU97,I*2!["B`@("`@("`@("`@("1C:&5C:V5D5F%L=65S(#T@87)R
M87DH*3L*("`@("`@("!]"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A
M8V@@*"1V86QU97,@87,@)'9A;'5E(#T^("1D:7-P;&%Y<RD@>PH@("`@("`@
M("`@("`D8VQA<W,@/2`G:71E;2<@+B`H)&D@*R`Q*2`E(#(["B`@("`@("`@
M("`@("1C:&5C:V5D(#T@*&EN7V%R<F%Y*"1V86QU92P@)&-H96-K961686QU
M97,I*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<["B`@("`@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H)SQT<B!C;&%S<STB)7,B/B<L("1C;&%S<RD@
M+@H@("`@("`@("`@("`@("`@<W!R:6YT9B@G/'1D(&%L:6=N/2)C96YT97(B
M/CQI;G!U="!I9#TB)7,E<R(@='EP93TB8VAE8VMB;W@B(&YA;64](B5S6UTB
M('9A;'5E/2(E<R(E<R5S("\^/"]T9#XG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)&DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("1N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=64L"B`@("`@("`@("`@("`@("`@("`@("`@("1C:&5C:V5D
M+`H@("`@("`@("`@("`@("`@("`@("`@("`D86-T:6]N<RD["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1D:7-P;&%Y<R!A<R`D8V]L*2!["B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2!S<')I;G1F*"<\=&0@86QI9VX](FQE9G0B/B9N8G-P
M.R5S/"]T9#XG+"`D8V]L*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M:'1M;"`N/2`G/"]T<CXG.PH@("`@("`@("`@("`D:2LK.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO=&%B;&4^)SL*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]T86)L97-E="@F)&9O<FTL
M("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&AE861E<B`]("1V87(M
M/G1Y<&4M/F=E=$AE861E<B@I.PH@("`@("`@("1N86UE("`@/2`D=F%R+3YG
M971687).86UE*"D["B`@("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E
M<R@I.PH@("`@("`@("1C:&5C:V5D5F%L=65S(#T@)'9A<BT^9V5T5F%L=64H
M)'9A<G,I.PH@("`@("`@("1A8W1I;VYS(#T@)'1H:7,M/E]G971!8W1I;VY3
M8W)I<'1S*"1F;W)M+"`D=F%R*3L*"B`@("`@("`@)&AT;6P@/2`G/'1A8FQE
M('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,2(^/'1R(&-L87-S/2)S96QE
M8W1E9"(^)R`N"B`@("`@("`@("`@("<\=&@@8VQA<W,](G=I9&=E="(@86QI
M9VX](G)I9VAT(B!W:61T:#TB,24B/B9N8G-P.SPO=&@^)SL*("`@("`@("!F
M;W)E86-H("@D:&5A9&5R(&%S("1C;VQ?=&ET;&4I('L*("`@("`@("`@("`@
M)&AT;6P@+CT@<W!R:6YT9B@G/'1H(&%L:6=N/2)L969T(B!C;&%S<STB=VED
M9V5T(CXE<SPO=&@^)RP@)&-O;%]T:71L92D["B`@("`@("`@?0H@("`@("`@
M("1H=&UL("X]("<\+W1R/B<["@H@("`@("`@(&EF("@A:7-?87)R87DH)&-H
M96-K961686QU97,I*2!["B`@("`@("`@("`@("1C:&5C:V5D5F%L=65S(#T@
M87)R87DH*3L*("`@("`@("!]"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O
M<F5A8V@@*"1V86QU97,@87,@)'9A;'5E(#T^("1D:7-P;&%Y<RD@>PH@("`@
M("`@("`@("`D8VQA<W,@("`]("=I=&5M)R`N("@D:2`K(#$I("4@,CL*("`@
M("`@("`@("`@)&-H96-K960@/2`H:6Y?87)R87DH)'9A;'5E+"`D8VAE8VME
M9%9A;'5E<RDI(#\@)UL@/'-T<F]N9SX\9F]N="!C;VQO<CUG<F5E;CY6/"]F
M;VYT/CPO<W1R;VYG/B!=)R`Z("=;(#QS=')O;F<^/&9O;G0@8V]L;W(]<F5D
M/E@\+V9O;G0^/"]S=')O;F<^(%TG.PH@("`@("`@("`@("`D:'1M;"`N/2!S
M<')I;G1F*"<\='(@8VQA<W,](B5S(CXG+"`D8VQA<W,I("X*("`@("`@("`@
M("`@("`@('-P<FEN=&8H)SQT9"!A;&EG;CTB8V5N=&5R(CXE<SPO=&0^)RP@
M)&-H96-K960I.PH@("`@("`@("`@("!F;W)E86-H("@D9&ES<&QA>7,@87,@
M)&-O;"D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1D
M(&%L:6=N/2)L969T(CXF;F)S<#LE<SPO=&0^)RP@)&-O;"D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SPO='(^)SL*("`@("`@("`@
M("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;"`N("<\
M+W1A8FQE/B<["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO3&%N9W5A
M9V4N<&AP````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,3(P
M`#$P-#$W,S8R-S<Q`#`R,#<W-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7U5)7TQA
M;F=U86=E.CH@8VQA<W,@<')O=FED97,@82!W:61G970@9F]R(&-H86YG:6YG
M('1H90H@*B!C=7)R96YT;'D@<V5L96-T960@;&%N9W5A9V4N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U5)+U5)+TQA;F=U86=E+G!H<"QV(#$N-2XQ,"XV
M(#(P,#8O,#$O,#$@,C$Z,C@Z-#`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+@H@*@H@*B!`<VEN8V4@("!(
M;W)D95]522`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*8VQA<W,@
M2&]R9&5?54E?3&%N9W5A9V4@>PH*("`@("\J*@H@("`@("H@4F5N9&5R('1H
M92!L86YG=6%G92!S96QE8W1I;VXN"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9O<FT@(%)E='5R;B!T
M:&4@<V5L96-T:6]N(&)O>"!A<R!A;B!C;VUP;&5T92!S=&%N9&%L;VYE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@9F]R;2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@<V5L96-T:6]N(&)O>"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"D*("`@('L*("`@("`@("`D:'1M
M;"`]("<G.PH@("`@("`@(&EF("@A)$=,3T)!3%-;)W!R969S)UTM/FES3&]C
M:V5D*"=L86YG=6%G92<I*2!["B`@("`@("`@("`@($AO<F1E.CIA9&138W)I
M<'1&:6QE*"=L86YG=6%G92YJ<R<L("=H;W)D92<I.PH@("`@("`@("`@("`D
M7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UT@/2!.3%,Z.G-E;&5C="@I.PH@
M("`@("`@("`@("`D:'1M;"`]('-P<FEN=&8H)SQF;W)M(&YA;64](FQA;F=U
M86=E(B!A8W1I;VX](B5S(CXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R
M;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VQA;F=U86=E+G!H<"<L(&9A
M;'-E+"`M,2DI.PH@("`@("`@("`@("`D:'1M;"`N/2`G/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB=7)L(B!V86QU93TB)R`N($!H=&UL<W!E8VEA;&-H
M87)S*$AO<F1E.CIS96QF57)L*&9A;'-E+"!F86QS92P@=')U92DI("X@)R(@
M+SXG.PH@("`@("`@("`@("`D:'1M;"`N/2`G/'-E;&5C="!N86UE/2)N97=?
M;&%N9R(@;VYC:&%N9V4](F1O8W5M96YT+FQA;F=U86=E+G-U8FUI="@I(CXG
M.PH@("`@("`@("`@("!F;W)E86-H("@D1TQ/0D%,4ULG;FQS)UU;)VQA;F=U
M86=E<R==(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'-E
M;"`]("@D:V5Y(#T]("1?4T534TE/3ELG:&]R9&5?;&%N9W5A9V4G72D@/R`G
M('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<["B`@("`@("`@("`@("`@("`D
M:'1M;"`N/2`B/&]P=&EO;B!V86QU93U<(B1K97E<(B1S96P^)'9A;#PO;W!T
M:6]N/B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SPO
M<V5L96-T/CPO9F]R;3XG.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&AT
M;6P["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U!A9V5R+G!H<```
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S4Q,0`Q,#0Q
M-S,V,C<W,0`P,C`S,C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O5VED9V5T+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7U5)7U!A
M9V5R.CH@<')O=FED97,@;&EN:W,@=&\@:6YD:79I9'5A;"!P86=E<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP+'8@,2XW+C$P
M+C4@,C`P-B\P,2\P,2`R,3HR.#HT,"!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C:RYQ
M8RYC83X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$)31"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M;&EC96YS97,O8G-D;"YP:'`N"B`J"B`J($!A=71H;W(@($)E;B!#:&%V970@
M/&)E;D!C:&%V970N;F5T/@H@*B!`875T:&]R("!*;V5L(%9A;F1A;"`\:G9A
M;F1A;$!I;F9O=&5C:RYQ8RYC83X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E7U5)(#`N
M,"XQ"B`J($!P86-K86=E($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]525]0
M86=E<B!E>'1E;F1S($AO<F1E7U5)7U=I9&=E="!["@H@("`@9G5N8W1I;VX@
M2&]R9&5?54E?4&%G97(H)&YA;64L("8D=F%R<RP@)&-O;F9I9RD*("`@('L*
M("`@("`@("!I9B`H(6ES<V5T*"1C;VYF:6=;)W!A9V5?;&EM:70G72DI('L*
M("`@("`@("`@("`@)&-O;F9I9ULG<&%G95]L:6UI="==(#T@,3`["B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-S970H)&-O;F9I9ULG<&5R<&%G92==*2D@
M>PH@("`@("`@("`@("`D8V]N9FEG6R=P97)P86=E)UT@/2`Q,#`["B`@("`@
M("`@?0H@("`@("`@('!A<F5N=#HZ2&]R9&5?54E?5VED9V5T*"1N86UE+"`D
M=F%R<RP@)&-O;F9I9RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@
M=&AE('!A9V5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!(5$U,
M(&-O9&4@8V]N=&%I;FEN9R!A(&-E;G1E<F5D('1A8FQE('=I=&@@=&AE('!A
M9V5R"B`@("`@*B`@("`@(&QI;FMS+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96YD97(H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,L("1R96=I<W1R
M>2P@)&-O;F8["@H@("`@("`@("1N=6T@/2`D=&AI<RT^7V-O;F9I9ULG;G5M
M)UT["B`@("`@("`@)'5R;"`]("1T:&ES+3Y?8V]N9FEG6R=U<FPG73L*("`@
M("`@("`D<&%G95]L:6UI="`]("1T:&ES+3Y?8V]N9FEG6R=P86=E7VQI;6ET
M)UT["B`@("`@("`@)'!E<G!A9V4@/2`D=&AI<RT^7V-O;F9I9ULG<&5R<&%G
M92==.PH*("`@("`@("`D8W5R<F5N=%]P86=E(#T@)'1H:7,M/E]V87)S+3YG
M970H)'1H:7,M/E]N86UE*3L*"B`@("`@("`@+R\@1FEG=7)E(&]U="!H;W<@
M;6%N>2!P86=E<R!T:&5R92!W:6QL(&)E+@H@("`@("`@("1P86=E<R`]("@D
M;G5M("\@)'!E<G!A9V4I.PH@("`@("`@(&EF("AI<U]I;G1E9V5R*"1P86=E
M<RDI('L*("`@("`@("`@("`@)'!A9V5S+2T["B`@("`@("`@?0H@("`@("`@
M("1P86=E<R`]("AI;G0I)'!A9V5S.PH*("`@("`@("`O+R!2971U<FX@;F]T
M:&EN9R!I9B!T:&5R92!I<R!O;FQY(&]N92!P86=E+@H@("`@("`@(&EF("@D
M<&%G97,@/3T@,"!\?"`D;G5M(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@('T*"B`@("`@("`@)&AT;6P@/2`G/&1I=B!C;&%S<STB
M<&%G97(B('-T>6QE/2)T97AT+6%L:6=N.F-E;G1E<B(^)SL*"B`@("`@("`@
M+R\@0W)E871E('1H92`G/#P@4')E=B<@;&EN:R!I9B!W92!A<F4@;F]T(&]N
M('1H92!F:7)S="!P86=E+@H@("`@("`@("1L:6YK(#T@571I;#HZ861D4&%R
M86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)&-U<G)E;G1?<&%G92`M(#$I
M.PH@("`@("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V960H)&QI;FLI
M.PH@("`@("`@(&EF("@D8W5R<F5N=%]P86=E(#X@,"D@>PH@("`@("`@("`@
M("`D:'1M;"`N/2!(;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC871I;VY5<FPH
M)&QI;FLI+"`G)RP@)W!R978G*2`N(&AT;6QS<&5C:6%L8VAA<G,H7R@B/%!R
M979I;W5S(BDI("X@)SPO83XG.PH@("`@("`@('T*"B`@("`@("`@+R\@1FEG
M=7)E(&]U="!T:&4@=&]P("8@8F]T=&]M(&1I<W!L87D@;&EM:71S+@H@("`@
M("`@("1B;W1T;VT@/2`D8W5R<F5N=%]P86=E("T@*"1C=7)R96YT7W!A9V4@
M)2`D<&%G95]L:6UI="D["B`@("`@("`@)'1O<"`]("1B;W1T;VT@*R`D<&%G
M95]L:6UI="`M(#$["@H@("`@("`@("\O($-R96%T92!B;W1T;VT@)UMX+7E=
M)R!L:6YK(&EF(&YE8V5S<V%R>2X*("`@("`@("`D;&EN:R`]("1T:&ES+3Y?
M861D4')E<V5R=F5D*%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`D=&AI<RT^
M7VYA;64L("1B;W1T;VT@+2`Q*2D["B`@("`@("`@:68@*"1B;W1T;VT@/B`Q
M*2!["B`@("`@("`@("`@("1H=&UL("X]("<@)R`N($AO<F1E.CIL:6YK*$AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@D;&EN:RDL("<G+"`G<')E=E)A;F=E)RD@
M+B`G6R<@+B`H)&)O='1O;2`M("1P86=E7VQI;6ET("L@,2D@+B`G+2<@+B`D
M8F]T=&]M("X@)UT\+V$^)SL*("`@("`@("!]"@H@("`@("`@("\O($-R96%T
M92!L:6YK<R!T;R!I;F1I=FED=6%L('!A9V5S(&)E='=E96X@;&EM:71S+@H@
M("`@("`@(&9O<B`H)&D@/2`D8F]T=&]M.R`D:2`\/2`D=&]P("8F("1I(#P]
M("1P86=E<SL@)&DK*RD@>PH@("`@("`@("`@("!I9B`H)&D@/3T@)&-U<G)E
M;G1?<&%G92D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG
M/B@G("X@*"1I("L@,2D@+B`G*3PO<W1R;VYG/B<["B`@("`@("`@("`@('T@
M96QS96EF("@D:2`^/2`P("8F("1I(#P]("1P86=E<RD@>PH@("`@("`@("`@
M("`@("`@)&QI;FL@/2`D=&AI<RT^7V%D9%!R97-E<G9E9"A5=&EL.CIA9&10
M87)A;65T97(H)'5R;"P@)'1H:7,M/E]N86UE+"`D:2DI.PH@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"1L:6YK*2D@+B`H)&D@*R`Q*2`N("<\+V$^)SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E('1O<"`G6W@M
M>5TG(&QI;FL@:68@;F5C97-S87)Y+@H@("`@("`@(&EF("@D=&]P(#P@)'!A
M9V5S*2!["B`@("`@("`@("`@("1L87-T(#T@)'1O<"`K("1P86=E7VQI;6ET
M(#P@)'!A9V5S(#\@)'1O<"`K("1P86=E7VQI;6ET("L@,2`Z("1P86=E<R`K
M(#$["B`@("`@("`@("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V960H
M571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)'1O<"`K
M(#$I*3L*("`@("`@("`@("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z.FQI;FLH
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1L:6YK*2P@)R<L("=N97AT4F%N9V4G
M*2`N("=;)R`N"B`@("`@("`@("`@("`@("`H)'1O<"`K(#(I("X@)RTG("X@
M)&QA<W0@+B`G73PO83X\+W1D/B<["B`@("`@("`@?0H*("`@("`@("`O+R!#
M<F5A=&4@=&AE("=.97AT/CXG(&QI;FL@:68@=V4@87)E(&YO="!O;B!T:&4@
M;&%S="!P86=E+@H@("`@("`@(&EF("@D8W5R<F5N=%]P86=E(#P@)'!A9V5S
M*2!["B`@("`@("`@("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V960H
M571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)&-U<G)E
M;G1?<&%G92`K(#$I*3L*("`@("`@("`@("`@)&AT;6P@+CT@)R`G("X@2&]R
M9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1L:6YK*2P@)R<L("=N
M97AT)RD@+B!H=&UL<W!E8VEA;&-H87)S*%\H(DYE>'0^(BDI("X@)SPO83XG
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO9&EV/B<[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U5)+U1A8G,N<&AP````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C0W-P`Q,#0Q-S,V,C<W,0`P,C`Q-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O5VED9V5T+G!H<"<["@HO*BH*
M("H@5&AE($AO<F1E7U5)7U1A8G,Z.B!C;&%S<R!M86YA9V5S(&%N9"!R96YD
M97)S(&$@=&%B+6QI:V4@:6YT97)F86-E+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]522]522]486)S+G!H<"QV(#$N,C<N-BXY(#(P,#8O,#$O,#$@,C$Z
M,C@Z-#`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#,@4F]B
M97)T($4N($-O>6QE(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R
M;VYO<WES+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.
M4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+@H@*@H@*B!`<VEN
M8V4@("!(;W)D95]522`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*
M8VQA<W,@2&]R9&5?54E?5&%B<R!E>'1E;F1S($AO<F1E7U5)7U=I9&=E="![
M"@H@("`@+RHJ"B`@("`@*B!4:&4@87)R87D@;V8@=&%B<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1A8G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@061D(&$@=&%B('1O('1H92!I;G1E<F9A
M8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&ET;&4@("`@5&AE
M('1E>'0@=VAI8V@@87!P96%R<R!O;B!T:&4@=&%B+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;&EN:R`@("`@5&AE('1A<F=E="!P86=E+@H@("`@("H@0'!A
M<F%M(&UI>&5D("`D<&%R86US("`@16ET:&5R(&$@<W1R:6YG('9A;'5E('1O
M('-E="!T:&4@=&%B('9A<FEA8FQE('1O+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@;W(@82!H87-H(&]F('!A<F%M971E<G,N($EF(&%N(&%R
M<F%Y+"!T:&4@=&%B('9A<FEA8FQE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!C86X@8F4@<V5T(&)Y('1H92`G=&%B;F%M92<@:V5Y+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1486(H)'1I=&QE+"`D;&EN:RP@)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R
M86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@87)R87DH)W1A8FYA;64G
M(#T^("1P87)A;7,I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W1A8G-;
M72`](&%R<F%Y7VUE<F=E*&%R<F%Y*"=T:71L92<@/3X@)'1I=&QE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG
M(#T^("1L:6YK+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1A8FYA;64G(#T^(&YU;&PI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971R:65V92!T:&4@=&ET;&4@;V8@=&AE('1A8B!W:71H('1H
M92!S<&5C:69I960@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T86)N86UE("!4:&4@;F%M92!O9B!T:&4@=&%B+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@=&%B)W,@=&ET;&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%1I=&QE1G)O;4%C=&EO;B@D=&%B;F%M92D*("`@('L*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1A8G,@87,@)'1A8BD@>PH@("`@
M("`@("`@("!I9B`H)'1A8ELG=&%B;F%M92==(#T]("1T86)N86UE*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1A8ELG=&ET;&4G73L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296YD97)S('1H92!T86)S+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%C=&EV95]T86(@($EF('-P96-I9FEE9"P@=&AE
M(&YA;64@;V8@=&AE(&%C=&EV92!T86(N($EF"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!N;W0L('1H92!A8W1I=F4@=&%B(&ES(&1E=&5R
M;6EN960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%U=&]M
M871I8V%L;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D86-T:79E
M7W1A8B`](&YU;&PI"B`@("!["B`@("`@("`@)&AT;6P@/2`B/&1I=B!C;&%S
M<SU<(G1A8G-E=%PB/CQU;#Y<;B(["@H@("`@("`@("1F:7)S="`]('1R=64[
M"B`@("`@("`@)&%C=&EV92`]("1?4T525D526R=02%!?4T5,1B==("X@)'1H
M:7,M/E]V87)S+3YG970H)'1H:7,M/E]N86UE*3L*"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]T86)S(&%S("1T86(I('L*("`@("`@("`@("`@)&QI;FL@
M/2`D=&AI<RT^7V%D9%!R97-E<G9E9"@D=&%B6R=L:6YK)UTI.PH@("`@("`@
M("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]N86UE*2`F)B`A:7-?;G5L;"@D
M=&%B6R=T86)N86UE)UTI*2!["B`@("`@("`@("`@("`@("`D;&EN:R`](%5T
M:6PZ.F%D9%!A<F%M971E<B@D;&EN:RP@)'1H:7,M/E]N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8ELG=&%B
M;F%M92==*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-L87-S(#T@
M)R<["B`@("`@("`@("`@(&EF("@H(6ES7VYU;&PH)&%C=&EV95]T86(I("8F
M("1A8W1I=F5?=&%B(#T]("1T86);)W1A8FYA;64G72D@?'P*("`@("`@("`@
M("`@("`@("@D86-T:79E(#T]("1T86);)VQI;FLG72`N("1T86);)W1A8FYA
M;64G72DI('L*("`@("`@("`@("`@("`@("1C;&%S<R`]("<@8VQA<W,](F%C
M=&EV951A8B(G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T86);)W1A<F=E="==*2D@>PH@("`@("`@("`@("`@("`@)'1A8ELG
M=&%R9V5T)UT@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&%B6R=O;F-L:6-K)UTI*2!["B`@("`@("`@("`@("`@("`D
M=&%B6R=O;F-L:6-K)UT@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&%C8V5S<VME>2`]($AO<F1E.CIG971!8V-E<W-+97DH)'1A8ELG=&ET
M;&4G72D["@H@("`@("`@("`@("`D:'1M;"`N/2`G/&QI)R`N("1C;&%S<R`N
M("<^)R`N"B`@("`@("`@("`@("`@("!(;W)D93HZ;&EN:R@D;&EN:RP@)R<L
M("<G+"`D=&%B6R=T87)G970G72P@)'1A8ELG;VYC;&EC:R==+"!N=6QL+"`D
M86-C97-S:V5Y*2`N"B`@("`@("`@("`@("`@("!(;W)D93HZ:&EG:&QI9VAT
M06-C97-S2V5Y*'-T<E]R97!L86-E*"<@)RP@)R9N8G-P.R<L("1T86);)W1I
M=&QE)UTI+"`D86-C97-S:V5Y*2`N"B`@("`@("`@("`@("`@("`B/"]A/B`\
M+VQI/EQN(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;"`N("(\
M+W5L/CPO9&EV/CQB<B!C;&%S<SU<(F-L96%R7"(@+SY<;B(["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]522]687)296YD97)E<BYP:'``````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3`Q,#``,3`T,3<S-C(W-S$`,#(Q-#8U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@2&]R9&5?54E?5F%R4F5N9&5R97(Z.B!C;&%S<R!P<F]V:61E<R!B87-E
M(&9U;F-T:6]N86QI='D@9F]R"B`J(&]T:&5R($AO<F1E(%5)(&5L96UE;G1S
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]522]522]687)296YD97)E<BYP
M:'`L=B`Q+C$R+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HT,"!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF
M96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN"B`J
M"B`J($!S:6YC92`@($AO<F1E7U5)(#`N,"XQ"B`J($!P86-K86=E($AO<F1E
M7U5)"B`J+PIC;&%S<R!(;W)D95]525]687)296YD97)E<B!["@H@("`@+RHJ
M"B`@("`@*B!087)A;65T97)S('=H:6-H(&-H86YG92!T:&ES(')E;F1E<F5R
M)W,@8F5H879I;W(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P87)A;7,["@H@("`@+RHJ"B`@("`@*B!#:&%R<V5T('1O
M('5S92!F;W(@;W5T<'5T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V-H87)S970["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1S(&$@;F5W(')E;F1E<F5R+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!4:&4@;F%M92!O9B!T:&4@=F%R:6%B;&4@=VAI8V@@
M=VEL;"!T<F%C:R!T:&ES(%5)"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@=VED9V5T)W,@<W1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7U5)7U9A<E)E;F1E<F5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@("`@("`D=&AI<RT^
M7V-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=',@82!N97<@2&]R9&5?54E?5F%R4F5N9&5R97(Z
M.B!I;G-T86YC92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E
M<B`@5&AI<R!I<R!T:&4@<F5N9&5R97(@<W5B8VQA<W,@=V4@=VEL;"!I;G-T
M86YT:6%T92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!)9B!A;B!A
M<G)A>2!I<R!P87-S960L('1H92!F:7)S="!E;&5M96YT(&ES('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&QI8G)A<GD@<&%T:"!A;F0@=&AE
M('-E8V]N9"!E;&5M96YT(&ES('1H92!D<FEV97(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!N86UE+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@(%!A<F%M971E<G,@<W!E8VEF:6,@=&\@=&AE('-U8F-L87-S+@H@("`@
M("H*("`@("`J($!R971U<FX@2&]R9&5?54E?5F%R4F5N9&5R97(@($$@2&]R
M9&5?54E?5F%R4F5N9&5R97(Z.B!S=6)C;&%S<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@
M("`@("`D87!P(#T@)&1R:79E<ELP73L*("`@("`@("`@("`@)&1R:79E<B`]
M("1D<FEV97);,5T["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S
M96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]522]687)296YD97)E
M<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I
M;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]687)296YD97)E<B\G
M("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]687)296YD97)E<B\G("X@)&1R
M:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`
M:6YC;'5D95]O;F-E("=(;W)D92]522]687)296YD97)E<B\G("X@)&1R:79E
M<B`N("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D
M95]525]687)296YD97)E<E\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA
M<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)'9R(#T@)FYE=R`D
M8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'9R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G
M("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'9R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@:6YS=&%N8V4L(&-O;G-T<G5C=&EN
M9R!O;F4@=VET:"!T:&4*("`@("`J('-P96-I9FEE9"!P87)A;65T97)S(&EF
M(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV
M97(@(%1H:7,@:7,@=&AE(')E;F1E<F5R('-U8F-L87-S('=E('=I;&P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N=&EA=&4N"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@(%!A<F%M971E<G,@<W!E8VEF:6,@
M=&\@=&AE('-U8F-L87-S+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?
M54E?5F%R4F5N9&5R97(@($$@2&]R9&5?54E?5F%R4F5N9&5R97(Z.B!S=6)C
M;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YS
M=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E
M<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1C
M86-H93L*"B`@("`@("`@:68@*&ES7VYU;&PH)&1R:79E<BDI('L*("`@("`@
M("`@("`@)&-L87-S(#T@)TAO<F1E7U5)7U9A<E)E;F1E<F5R)SL*("`@("`@
M("!]"B`@("`@("`@)&ME>2`]('-E<FEA;&EZ92AA<G)A>2`H)&1R:79E<BP@
M)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H)&-A8VAE6R1K97E=*2D@
M>PH@("`@("`@("`@("`D8V%C:&5;)&ME>5T@/2`F2&]R9&5?54E?5F%R4F5N
M9&5R97(Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D8V%C:&5;)&ME>5T["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296YD97)S(&$@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M($AO<F1E7T9O<FT@)B1F;W)M("`@("`@("`@("!2969E<F5N8V4@=&\@82!(
M;W)D95]&;W)M(&EN<W1A;F-E+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!O<B!N=6QL(&EF(&YO;F4@:7,@879A:6QA8FQE
M+@H@("`@("H@0'!A<F%M($AO<F1E7T9O<FU?5F%R:6%B;&4@)B1V87(@("!2
M969E<F5N8V4@=&\@82!(;W)D95]&;W)M7U9A<FEA8FQE+@H@("`@("H@0'!A
M<F%M(%9A<FEA8FQE<R`F)'9A<G,@("`@("`@("`@("!!(%9A<FEA8FQE<R!I
M;G-T86YC92X*("`@("`J($!P87)A;2!B;V]L96%N("1I<TEN<'5T("`@("`@
M("`@("`@5VAE=&AE<B!T:&ES(&ES(&%N(&EN<'5T(&9I96QD+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96YD97(H)B1F;W)M+"`F)'9A<BP@)B1V87)S+"`D
M:7-);G!U="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D:7-);G!U="D@
M>PH@("`@("`@("`@("`D<W1A=&4@/2`G26YP=70G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1S=&%T92`]("=$:7-P;&%Y)SL*("`@("`@("!]
M"B`@("`@("`@)&UE=&AO9"`](")?<F5N9&5R5F%R)'MS=&%T97U?(B`N("1V
M87(M/G1Y<&4M/F=E=%1Y<&5.86UE*"D["B`@("`@("`@:68@*"%`;65T:&]D
M7V5X:7-T<R@D=&AI<RP@)&UE=&AO9"DI('L*("`@("`@("`@("`@)&UE=&AO
M9"`](")?<F5N9&5R5F%R)'MS=&%T97U$969A=6QT(CL*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1T:&ES+3XD;65T:&]D*"1F;W)M+"`D=F%R+"`D=F%R
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YI<VAE<R!R96YD97)I;F<@
M869T97(@86QL(&9I96QD<R!A<F4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97)%;F0H*0H@("`@>PH@("`@("`@(')E='5R;B`G)SL*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U=I
M9&=E="YP:'``````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#(S,@`Q,#0Q-S,V,C<W,0`P,C`U,#(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]5
M25]7:61G970Z.B!C;&%S<R!P<F]V:61E<R!B87-E(&9U;F-T:6]N86QI='D@
M9F]R(&]T:&5R($AO<F1E"B`J(%5)(&5L96UE;G1S+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]522]522]7:61G970N<&AP+'8@,2XW+C$P+C<@,C`P-B\P
M,2\P,2`R,3HR.#HT,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN"B`J"B`J($!S:6YC92`@($AO<F1E7U5)
M(#`N,"XQ"B`J($!P86-K86=E($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]5
M25]7:61G970@>PH*("`@("\J*@H@("`@("H@06YY('9A<FEA8FQE<R!T:&%T
M('-H;W5L9"!B92!P<F5S97)V960@:6X@86QL(&]F('1H92!W:61G970G<PH@
M("`@("H@;&EN:W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P<F5S97)V92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;F%M92!O9B!T:&ES('=I9&=E="X@(%1H:7,@:7,@=7-E9"!A<R!T
M:&4@8F%S96YA;64@9F]R('9A<FEA8FQE<PH@("`@("H@=V4@86-C97-S(&%N
M9"!M86YI<'5L871E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VYA;64["@H@("`@+RHJ"B`@("`@*B!!(')E9F5R96YC
M92!T;R!A(%9A<FEA8FQE<SHZ(&]B:F5C="!T:&ES('=I9&=E="!W:6QL('5S
M92!A;F0*("`@("`J(&UA;FEP=6QA=&4N"B`@("`@*@H@("`@("H@0'9A<B!6
M87)I86)L97,*("`@("`J+PH@("`@=F%R("1?=F%R<SL*"B`@("`O*BH*("`@
M("`J($%N(&%R<F%Y(&]F(&YA;64@/3X@=F%L=64@<&%I<G,@=VAI8V@@8V]N
M9FEG=7)E(&AO=R!T:&ES('=I9&=E=`H@("`@("H@8F5H879E<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-O;F9I9SL*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C="!A(&YE=R!522!7:61G970@:6YT
M97)F86-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@
M("!4:&4@;F%M92!O9B!T:&4@=F%R:6%B;&4@=VAI8V@@=VEL;"!T<F%C:R!T
M:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@54D@=VED9V5T
M)W,@<W1A=&4N"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("8D=F%R<R`@02!6
M87)I86)L97,Z.B!O8FIE8W0N"B`@("`@*B!`<&%R86T@87)R87D@)&-O;F9I
M9R`@("`@5&AE('=I9&=E="=S(&-O;F9I9W5R871I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7U5)7U=I9&=E="@D;F%M92P@)B1V87)S+"`D8V]N
M9FEG(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D
M;F%M93L*("`@("`@("`D=&AI<RT^7W9A<G,@/2`F)'9A<G,["B`@("`@("`@
M)'1H:7,M/E]C;VYF:6<@/2`D8V]N9FEG.PH@("`@?0H*("`@("\J*@H@("`@
M("H@26YS=')U8W0@2&]R9&5?54E?5VED9V5T.CH@=&\@<')E<V5R=F4@82!V
M87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V87(@("!4
M:&4@;F%M92!O9B!T:&4@=F%R:6%B;&4@=&\@<')E<V5R=F4N"B`@("`@*B!`
M<&%R86T@;6EX960@)'9A;'5E("!4:&4@=F%L=64@;V8@=&AE('9A<FEA8FQE
M('1O('!R97-E<G9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F5S97)V92@D
M=F%R+"`D=F%L=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]P<F5S97)V95LD
M=F%R72`]("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?861D4')E<V5R=F5D*"1L
M:6YK*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<')E<V5R=F4@
M87,@)'9A<DYA;64@/3X@)'9A<E9A;'5E*2!["B`@("`@("`@("`@("1L:6YK
M(#T@571I;#HZ861D4&%R86UE=&5R*"1L:6YK+"`D=F%R3F%M92P@)'9A<E9A
M;'5E*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YK.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5N9&5R('1H92!W:61G970N"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A
M("!4:&4@=VED9V5T)W,@<W1A=&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5N9&5R*"D@>WT*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T=R;W5P+P``````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,0`P,3<S,C<`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)O=7`O:&]O:W,N<&AP````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-30T`#$P-#$W,S8R-S<Q
M`#`R,3$W,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($=R;W5P7VAO;VMS.CH@8VQA<W,@<')O
M=FED97,@=&AE($AO<F1E(&=R;W5P<R!S>7-T96T@=VET:"!T:&4*("H@861D
M:71I;VX@;V8@861D:6YG('-U<'!O<G0@9F]R(&AO;VL@9G5N8W1I;VYS('1O
M(&1E9FEN92!I9B!A('5S97(*("H@:7,@:6X@82!G<F]U<"X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O:&]O:W,N<&AP+'8@,2XW+C(N
M,3`@,C`P-B\P,2\P,2`R,3HR.#HQ.2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!*87-O;B!2=7-T(#QJ<G5S=$!R=7-T>7!A<G1S+F-O
M;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N(%)U<W0@/&IR
M=7-T0')U<W1Y<&%R=',N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?1W)O=7`*("HO"F-L87-S($=R;W5P7VAO;VMS(&5X
M=&5N9',@1W)O=7`@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($=R;W5P7VAO;VMS*"D*("`@('L*("`@("`@
M("!P87)E;G0Z.D=R;W5P*"D["B`@("`@("`@<F5Q=6ER92`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]C;VYF
M:6<O:&]O:W,N<&AP)SL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI
M<W0@;V8@979E<GD@9W)O=7`@=&AA="`D=7-E<B!I<R!I;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T
M;R!G970@9W)O=7!S(&9O<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P87)E
M;G1'<F]U<',@($%L<V\@<F5T=7)N('1H92!P87)E;G1S(&]F(&%N>2!G<F]U
M<',_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@
M86QL(&=R;W5P<R!T:&4@=7-E<B!I<R!I;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1W)O=7!-96UB97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<R`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("1M96UB97)S:&EP<R`]('!A<F5N=#HZ
M9V5T1W)O=7!-96UB97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<RD["B`@
M("`@("`@)&=R;W5P<R`]("1T:&ES+3YL:7-T1W)O=7!S*"D["B`@("`@("`@
M9F]R96%C:"`H)&=R;W5P<R!A<R`D9VED(#T^("1G<F]U<"D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/FAA<TAO;VLH)&=R;W5P*2`F)@H@("`@("`@("`@
M("`@("`@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/E]G971'<F]U<$AO;VM.86UE
M*"1G<F]U<"DL("1U<V5R*2D@>PH@("`@("`@("`@("`@("`@)&UE;6)E<G-H
M:7!S("L](&%R<F%Y*"1G:60@/3X@)&=R;W5P*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)'!A<F5N=$=R;W5P<RD@>PH@("`@("`@("`@("`@
M("`@)'!A<F5N=',@/2`D=&AI<RT^9V5T1W)O=7!087)E;G1,:7-T*"1G:60I
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F5N=',@87,@)'!I9"`]
M/B`D<&%R96YT*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YH
M87-(;V]K*"1P87)E;G0I("8F"B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M;&Q?=7-E<E]F=6YC*"1T:&ES+3Y?9V5T1W)O=7!(;V]K3F%M92@D9W)O=7`I
M+"`D=7-E<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&UE;6)E<G-H
M:7!S("L](&%R<F%Y*"1P:60@/3X@)'!A<F5N="D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&UE;6)E<G-H:7!S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V%Y(&EF(&$@=7-E<B!I<R!A(&UE;6)E<B!O9B!A(&=R
M;W5P(&]R(&YO="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7-E
M<B`@("`@("!4:&4@;F%M92!O9B!T:&4@=7-E<BX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1G:60@("`@("`@(%1H92!)1"!O9B!T:&4@9W)O=7`N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<W5B9W)O=7!S("!2971U<FX@=')U92!I9B!T
M:&4@=7-E<B!I<R!I;B!A;GD@<W5B9W)O=7!S"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!O9B`D9W)O=7`L(&%L<V\N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N"B`@("`@*B\*("`@(&9U;F-T:6]N('5S97))
M<TEN1W)O=7`H)'5S97(L("1G:60L("1S=6)G<F]U<',@/2!T<G5E*0H@("`@
M>PH@("`@("`@("1G<F]U<"`]("1T:&ES+3YG971'<F]U<$YA;64H)&=I9"D[
M"B`@("`@("`@:68@*"1T:&ES+3YH87-(;V]K*"1G<F]U<"DI('L*("`@("`@
M("`@("`@:68@*&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3Y?9V5T1W)O=7!(;V]K
M3F%M92@D9W)O=7`I+"`D=7-E<BDI('L*("`@("`@("`@("`@("`@("1I;D=R
M;W5P(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1I;D=R;W5P(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D:6Y'<F]U<"`](&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1I;D=R;W5P('Q\('!A<F5N=#HZ=7-E<DES26Y'
M<F]U<"@D=7-E<BP@)&=I9"P@)'-U8F=R;W5P<RDI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN97,@:68@82!G<F]U<"!H87,@82!H;V]K(&%S<V]C:6%T960@=VET
M:"!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M9W)O=7`@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE(&=R;W5P(&AA<R!A(&AO;VLL(&9A;'-E(&]T:&5R=VES90H@
M("`@("HO"B`@("!F=6YC=&EO;B!H87-(;V]K*"1N86UE*0H@("`@>PH@("`@
M("`@(')E='5R;B!F=6YC=&EO;E]E>&ES=',H)'1H:7,M/E]G971'<F]U<$AO
M;VM.86UE*"1N86UE*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!N86UE(&]F('1H92!H;V]K(&9U;F-T:6]N+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!G<F]U<"!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5N8W1I;VX@;F%M92!F;W(@
M=&AE(&AO;VL@9F]R('1H:7,@9W)O=7`*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$=R;W5P2&]O:TYA;64H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N
M("=?9W)O=7!?:&]O:U\G("X@<W1R7W)E<&QA8V4H)SHG+"`G7U\G+"`D;F%M
M92D["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,S$U-0`Q,#0Q-S,V,C<W
M,0`P,C`W-C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!'<F]U<%]L9&%P(&-L87-S('!R;W9I
M9&5S(&%N($Q$05`@8F%C:V5N9"!F;W(@=&AE($AO<F1E(&=R;W5P<PH@*B!S
M>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP+'8@,2XQ."XR+C(@,C`P-B\P,2\P,2`R,3HR.#HQ.2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!"96X@0VAA=F5T(#QB96Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0F5N($-H
M879E="`\8F5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J
M($!P86-K86=E($AO<F1E7T=R;W5P"B`J+PIC;&%S<R!'<F]U<%]L9&%P(&5X
M=&5N9',@1W)O=7`@>PH*("`@("\J*@H@("`@("H@3$1!4"!C;VYN96-T:6]N
M(&AA;F1L90H@("`@("HO"B`@("!V87(@)%]D<SL*"B`@("`O*BH*("`@("`J
M($QO8V%L(&-O<'D@;V8@=&AE(&=L;V)A;"`D8V]N9ELG9W)O=7`G75LG<&%R
M86US)UT@87)R87DN("!3:6UP;'D*("`@("`J(&9O<B!C;V1I;F<@8V]N=F5N
M:65N8V4N"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<SL*"B`@("`O*BH*("`@
M("`J($=E;F5R871E9"!,1$%0(&9I;'1E<B!B87-E9"!O;B!T:&4@8V]N9FEG
M('!A<F%M971E<G,*("`@("`J+PH@("`@=F%R("1?9FEL=&5R.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($=R
M;W5P7VQD87`H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@
M("`D=&AI<RT^7W!A<F%M<R`]("1C;VYF6R=G<F]U<"==6R=P87)A;7,G73L*
M"B`@("`@("`@)'1H:7,M/E]P87)A;7-;)V=I9"==(#T@<W1R=&]L;W=E<B@D
M=&AI<RT^7W!A<F%M<ULG9VED)UTI.PH@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=M96UB97)U:60G72`]('-T<G1O;&]W97(H)'1H:7,M/E]P87)A;7-;)VUE
M;6)E<G5I9"==*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG
M;F5W9W)O=7!?;V)J96-T8VQA<W,G72!A<R`D:V5Y(#T^("1V86PI('L*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VYE=V=R;W5P7V]B:F5C=&-L87-S
M)UU;)&ME>5T@/2!S=')T;VQO=V5R*"1V86PI.PH@("`@("`@('T*"B`@("`@
M("`@+RH@1V5N97)A=&4@3$1!4"!S96%R8V@@9FEL=&5R+B`J+PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V9I;'1E<B==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V9I;'1E<B`]("1T:&ES+3Y?<&%R86US6R=F:6QT
M97(G73L*("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?<&%R
M86US6R=O8FIE8W1C;&%S<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V9I
M;'1E<B`]("=O8FIE8W1C;&%S<STG("X@)'1H:7,M/E]P87)A;7-;)V]B:F5C
M=&-L87-S)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]F:6QT97(@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P
M87)A;7-;)V]B:F5C=&-L87-S)UT@87,@)&]B:F5C=&-L87-S*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V9I;'1E<B`]("<H)B<@+B`D=&AI<RT^7V9I
M;'1E<CL*("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL=&5R("X]("<H;V)J
M96-T8VQA<W,])R`N("1O8FIE8W1C;&%S<R`N("<I*2<["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9FEL=&5R(#T@<W1R=&]L
M;W=E<B@D=&AI<RT^7V9I;'1E<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYN96-T<R!T;R!T:&4@3$1!4"!S97)V97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]R($9A;'-E(&)A<V5D(&]N('-U8V-E<W,@
M;V8@8V]N;F5C="!A;F0@8FEN9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O
M;FYE8W0H*0H@("`@>PH@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@
M<V5R=F5R+B`J+PH@("`@("`@("1T:&ES+3Y?9',@/2!`;&1A<%]C;VYN96-T
M*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*3L*("`@("`@("!I9B`H(21T
M:&ES+3Y?9',I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%L9&%P7W-E=%]O<'1I;VXH)'1H:7,M
M/E]D<RP@3$1!4%]/4%1?4%)/5$]#3TQ?5D524TE/3BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@
M("`@('-P<FEN=&8H)U-E="!,1$%0('!R;W1O8V]L('9E<G-I;VX@=&\@)60@
M9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W9E<G-I;VXG72P*("`@("`@("`@("`@("`@("`@("`@
M("`@;&1A<%]E<G)N;R@D8V]N;BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M(&QD87!?97)R;W(H)&-O;FXI+`H@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A<F%M<ULG8FEN9&1N)UTI*2!["B`@("`@("`@("`@
M("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S+"`D=&AI<RT^7W!A<F%M
M<ULG8FEN9&1N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&)I;F0@/2!`;&1A<%]B:6YD*"1T:&ES+3Y?9',I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"$D8FEN9"D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BXB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E8W5R<VEV96QY(&1E;&5T97,@
M)&1N+B`D=&AI<RT^7V1S($U54U0@86QR96%D>2!B92!C;VYN96-T960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!I9B!D96QE=&4@=V%S
M('-U8V-E<W-F=6PL(%!%05)?17)R;W(@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<F5C=7)S:79E7V1E;&5T92@D9&XI"B`@("!["B`@("`@
M("`@)'-E87)C:"`]($!L9&%P7VQI<W0H)'1H:7,M/E]D<RP@)&1N+"`G;V)J
M96-T8VQA<W,]*B<L(&%R<F%Y*"<G*2D["B`@("`@("`@:68@*"$D<V5A<F-H
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@('T*
M"B`@("`@("`@)&-H:6QD<F5N(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M
M/E]D<RP@)'-E87)C:"D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-H
M:6QD<F5N6R=C;W5N="==.R`D:2LK*2!["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7W)E8W5R<VEV95]D96QE=&4H)&-H:6QD<F5N6R1I75LG9&XG
M72D["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(BDL("1T:&ES+3YG971.
M86UE*"1C:&EL9')E;ELD:5U;)V1N)UTI*2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1R97-U;'0@/2!`;&1A<%]D96QE=&4H)'1H:7,M
M/E]D<RP@)&1N*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(BDL("1D;BDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!396%R8VAE<R!E>&ES=&EN9R!G<F]U<',@9F]R('1H92!H:6=H
M97-T(&=I9&YU;6)E<BP@86YD(')E='5R;G,*("`@("`J(&]N92!H:6=H97(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]N97AT1VED*"D*("`@('L*("`@("`@
M("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D
M<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A
M*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@
M("`@("`@('T*"B`@("`@("`@)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI
M<RT^7V1S+"`D9&XL("1T:&ES+3Y?9FEL=&5R*3L*("`@("`@("!I9B`H(21S
M96%R8V@I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@("`@
M("`@?0H*("`@("`@("!`;&1A<%]S;W)T*"1T:&ES+3Y?9',L("1S96%R8V@L
M("=G:61N=6UB97(G*3L*("`@("`@("`D<F5S=6QT(#T@0&QD87!?9V5T7V5N
M=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D["B`@("`@("`@0&QD87!?8VQO
M<V4H)'1H:7,M/E]D<RD["@H@("`@("`@(&EF("@A:7-?87)R87DH)')E<W5L
M="D@?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I*2!["B`@("`@("`@("`@(')E
M='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'1;)')E
M<W5L=%LG8V]U;G0G72`M(#%=6R=G:61N=6UB97(G75LP72`K(#$["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!N97<@9W)O=7`@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&=R;W5P
M)W,@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<F5N="`@5&AE(&=R
M;W5P)W,@<&%R96YT)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N($Q$
M05!?1W)O=7`@($$@;F5W(&=R;W5P(&]B:F5C="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)FYE=T=R;W5P*"1N86UE+"`D<&%R96YT(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y(BDI.PH@("`@("`@('T*"B`@("`@("`@9VQO8F%L("1C;VYF.PH@
M("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)V=R;W5P;&1A<"==
M*2D@>PH@("`@("`@("`@("!`:6YC;'5D92!(3U)$15]"05-%("X@)R]C;VYF
M:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@G7VAO<F1E7VAO;VM?9W)O=7!L9&%P)RDI('L*("`@("`@("`@("`@("`@
M("1E;G1R>2`](&-A;&Q?=7-E<E]F=6YC*"=?:&]R9&5?:&]O:U]G<F]U<&QD
M87`G+"`D;F%M92P@)'!A<F5N="D["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!4<GD@=&AI<R!S:6UP;&4@9&5F875L
M="!A;F0@:&]P92!I="!W;W)K<RX*("`@("`@("`@("`@)&5N=')Y6R1T:&ES
M+3Y?<&%R86US6R=G:60G75T@/2`D;F%M93L*("`@("`@("`@("`@)&5N=')Y
M6R=O8FIE8W1C;&%S<R==(#T@)'1H:7,M/E]P87)A;7-;)VYE=V=R;W5P7V]B
M:F5C=&-L87-S)UT["B`@("`@("`@("`@("1E;G1R>5LG9VED;G5M8F5R)UT@
M/2`D=&AI<RT^7VYE>'1':60H*3L*("`@("`@("!]"@H@("`@("`@("1G<F]U
M<"`]("9N97<@3$1!4%]'<F]U<"@D;F%M92P@)'!A<F5N="D["B`@("`@("`@
M)&=R;W5P+3Y?9G)O;4%T=')I8G5T97,H)&5N=')Y*3L*("`@("`@("`D9W)O
M=7`M/G-E=$=R;W5P3V(H)'1H:7,I.PH@("`@("`@(')E='5R;B`D9W)O=7`[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@86X@3$1!4%]'<F]U<"!O
M8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@;F%M960@9W)O=7`L('=I=&@@
M=&AE"B`@("`@*B!U<V5R<R!A;F0@;W1H97(@9&%T82!R971R:65V960@87!P
M<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!.3U1%.B!G971'<F]U<$)Y260H
M*2!S:&]U;&0@8F4@=7-E9"!W:&5R92!P;W-S:6)L92!I;G-T96%D(&]F"B`@
M("`@*B!G971'<F]U<"@I(&)E8V%U<V4@9W)O=7`@;F%M97,@87)E('!O=&5N
M=&EA;&QY(&YO;BUU;FEQ=64@=F%L=65S+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!G<F]U<"!T;R!R971R
M:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N($Q$05!?1W)O=7`@(%1H92!R
M97%U97-T960@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971'<F]U
M<"@D;F%M92D*("`@('L*("`@("`@("`D9&X@/2`D=&AI<RT^9V5T1W)O=7!)
M9"@D;F%M92D["B`@("`@("`@:68@*&ES7V$H)&1N+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1D;BT^
M9V5T365S<V%G92@I*3L*("`@("`@("!]"B`@("`@("`@)&=R;W5P(#T@)B1T
M:&ES+3YG971'<F]U<$)Y260H)&1N*3L*("`@("`@("!R971U<FX@)&=R;W5P
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&%N($Q$05!?3V)J96-T
M(&]B:F5C="!C;W)R97-P;VYD:6YG('1O('1H92!G:79E;B!D;BP@=VET:"!T
M:&4*("`@("`J('5S97)S(&%N9"!O=&AE<B!D871A(')E=')I979E9"!A<'!R
M;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1N("!4
M:&4@9&X@;V8@=&AE(&=R;W5P('1O(')E=')I979E+@H@("`@("H*("`@("`J
M($!R971U<FX@3$1!4%]/8FIE8W0@(%1H92!R97%U97-T960@9W)O=7`N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G971'<F]U<$)Y260H)&1N*0H@("`@>PH@
M("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF("@A:7-?87)R87DH
M)&-A8VAE*2D@>PH@("`@("`@("`@("`D8V%C:&4@/2!A<G)A>2@I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D8V%C:&5;)&1N72DI('L*("`@
M("`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@
M("`@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S
M<RT^9V5T365S<V%G92@I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D9&XL("1T:&ES
M+3Y?9FEL=&5R*3L*("`@("`@("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(I*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)')E<W5L="`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES
M+3Y?9',L("1S96%R8V@I.PH@("`@("`@("`@("!`;&1A<%]C;&]S92@D=&AI
M<RT^7V1S*3L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5S=6QT*2!\
M?"`H8V]U;G0H)')E<W5L="D@/#T@,2DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(D5M<'1Y(')E<W5L="XB*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH
M*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)')E<W5L=%LP75LG
M8V]U;G0G73L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;
M,%U;)')E<W5L=%LP75LD:5U=6R=C;W5N="==(#X@,2D@>PH@("`@("`@("`@
M("`@("`@("`@("1A='1R:6)U=&5S6R1R97-U;'1;,%U;)&E=72`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)')E
M<W5L=%LP75LD<F5S=6QT6S!=6R1I75U;)V-O=6YT)UT[("1J*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)')E<W5L=%LP75LD
M:5U=6UT@/2`D<F5S=6QT6S!=6R1R97-U;'1;,%U;)&E=75LD:ET["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D871T<FEB=71E<ULD<F5S=6QT6S!=6R1I75T@
M/2`D<F5S=6QT6S!=6R1R97-U;'1;,%U;)&E=75LP73L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D871T<FEB=71E<ULG
M9&XG72`]("1R97-U;'1;,%U;)V1N)UT["@H@("`@("`@("`@("`D9W)O=7`@
M/2!N97<@3$1!4%]'<F]U<"@D=&AI<RT^9V5T1W)O=7!.86UE*"1D;BDI.PH@
M("`@("`@("`@("`D9W)O=7`M/E]F<F]M071T<FEB=71E<R@D871T<FEB=71E
M<RD["B`@("`@("`@("`@("1G<F]U<"T^<V5T1W)O=7!/8B@D=&AI<RD["B`@
M("`@("`@("`@("1C86-H95LD9&Y=(#T@)&=R;W5P.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&-A8VAE6R1D;ET["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@82!G;&]B86QL>2!U;FEQ=64@240@9F]R(&$@9W)O=7`N("!4:&ES
M(')E86QL>2!J=7-T(')E='5R;G,@=&AE(&1N"B`@("`@*B!F;W(@=&AE(&=R
M;W5P+"!B=70@:7,@:6YC;'5D960@9F]R(&-O;7!A=&EB:6QI='D@=VET:"!T
M:&4@1W)O=7`@8VQA<W,N"B`@("`@*@H@("`@("H@0'!A<F%M($Q$05!?3V)J
M96-T("1G<F]U<"`@5&AE(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!A($=5240@<F5F97)R:6YG('1O("1G<F]U<"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1U5)1"@D9W)O=7`I"B`@("!["B`@("`@("`@<F5T
M=7)N("1G<F]U<"T^9V5T*"=D;B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D(&$@9W)O=7`@=&\@=&AE(&=R;W5P<R!S>7-T96TN("!4:&4@9W)O=7`@
M;75S="!F:7)S="!B92!C<F5A=&5D('=I=&@*("`@("`J($=R;W5P7VQD87`Z
M.FYE=T=R;W5P*"DL(&%N9"!H879E(&%N>2!I;FET:6%L('5S97)S(&%D9&5D
M('1O(&ET+"!B969O<F4*("`@("`J('1H:7,@9G5N8W1I;VX@:7,@8V%L;&5D
M+@H@("`@("H*("`@("`J($!P87)A;2!,1$%07T=R;W5P("1G<F]U<"`@5&AE
M(&YE=R!G<F]U<"!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!I9B!S=6-C97-S9G5L+"!014%27T5R<F]R(&]T:&5R=VES92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D1W)O=7`H)&=R;W5P*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U
M<"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"='
M<F]U<',@;75S="!B92!$871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R
M(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@)'-U8V-E
M<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<W5C
M8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I*3L*("`@("`@
M("!]"@H@("`@("`@("1D;B`]("1G<F]U<"T^9V5T*"=D;B<I.PH*("`@("`@
M("`D96YT<GD@/2`D9W)O=7`M/E]T;T%T=')I8G5T97,H*3L*("`@("`@("`D
M<W5C8V5S<R`]($!L9&%P7V%D9"@D=&AI<RT^7V1S+"`D9&XL("1E;G1R>2D[
M"@H@("`@("`@(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B*2P@)&=R;W5P+3YG971.86UE*"DI("X@0&QD87!?97)R;W(H)'1H
M:7,M/E]D<RDI.PH@("`@("`@('T*"B`@("`@("`@0&QD87!?8VQO<V4H)'1H
M:7,M/E]D<RD["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4W1O<F4@=7!D871E9"!D871A("T@=7-E<G,L(&5T8RX@+2!O
M9B!A(&=R;W5P('1O('1H92!B86-K96YD('-Y<W1E;2X*("`@("`J"B`@("`@
M*B!`<&%R86T@3$1!4%]/8FIE8W0@)&=R;W5P("!4:&4@9W)O=7`@=&\@=7!D
M871E"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S+"!014%27T5R<F]R(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=7!D871E1W)O=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$
M871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L
M87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@)&5N=')Y(#T@)&=R;W5P+3Y?
M=&]!='1R:6)U=&5S*"D["@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$
M05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN
M96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U
M8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@("`@("`D<F5S
M=6QT(#T@0&QD87!?;6]D:69Y*"1T:&ES+3Y?9',L("1G<F]U<"T^9V5T260H
M*2P@)&5N=')Y*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(BDL("1G<F]U<"T^9V5T
M3F%M92@I*2D["B`@("`@("`@?0H*("`@("`@("!`;&1A<%]C;&]S92@D=&AI
M<RT^7V1S*3L*"B`@("`@("`@+RH@3&]G('1H92!U<&1A=&4@;V8@=&AE(&=R
M;W5P('5S97)S(&]N('1H92!H:7-T;W)Y(&QO9RX@*B\*("`@("`@("`D:&ES
M=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D
M9W5I9"`]("1T:&ES+3YG971'54E$*"1G<F]U<"D["B`@("`@("`@9F]R96%C
M:"`H)&=R;W5P+3YG971!=61I=$QO9R@I(&%S("1U<V5R260@/3X@)&%C=&EO
M;BD@>PH@("`@("`@("`@("`D:&ES=&]R>2T^;&]G*"1G=6ED+"!A<G)A>2@G
M86-T:6]N)R`]/B`D86-T:6]N+"`G=7-E<B<@/3X@)'5S97))9"DL('1R=64I
M.PH@("`@("`@('T*("`@("`@("`D9W)O=7`M/F-L96%R075D:71,;V<H*3L*
M"B`@("`@("`@+RH@3&]G('1H92!G<F]U<"!M;V1I9FEC871I;VXN("HO"B`@
M("`@("`@)&AI<W1O<GDM/FQO9R@D9W5I9"P@87)R87DH)V%C=&EO;B<@/3X@
M)VUO9&EF>2<I+"!T<G5E*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H86YG92!T:&4@;F%M92!O9B!A(&=R;W5P
M+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E94]B:F5C=%]'<F]U<"`D
M9W)O=7`@(%1H92!G<F]U<"!T;R!R96YA;64N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N97=.86UE("`@("`@("`@("`@("!4:&4@9W)O=7`G<R!N97<@;F%M
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE1W)O=7`H)&=R;W5P+"`D
M;F5W3F%M92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G1&%T
M851R965/8FIE8W1?1W)O=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G1W)O=7!S(&UU<W0@8F4@1&%T851R965/8FIE8W1?
M1W)O=7`@;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@
M("!]"@H@("`@("`@("1G<F]U<"T^<V5T*"1T:&ES+3Y?<&%R86US6R=G:60G
M72P@)&YE=TYA;64I.PH@("`@("`@("1E;G1R>2`]("1G<F]U<"T^7W1O071T
M<FEB=71E<R@I.PH*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E
M<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I
M.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S
M+3YG971-97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]
M($!L9&%P7VUO9&EF>2@D=&AI<RT^7V1S+"`D9W)O=7`M/F=E=$ED*"DL("1E
M;G1R>2D["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1W)O=7!?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(I+"`D9W)O=7`M/F=E=$YA;64H
M*2DI.PH@("`@("`@('T*"B`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D
M<RD["@H@("`@("`@("\J($AI<W1O<GD@3&]G('1H92!N86UE(&-H86YG92!O
M9B!T:&4@9W)O=7`N("HO"B`@("`@("`@)&AI<W1O<GD@/2`F2&]R9&5?2&ES
M=&]R>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@)&AI<W1O<GDM/FQO9R@D9W)O
M=7`M/F=E="@G9&XG*2P@87)R87DH)V%C=&EO;B<@/3X@)W)E;F%M92<I+"!T
M<G5E*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F4@82!G<F]U<"!F<F]M('1H92!G<F]U<',@<WES=&5M
M('!E<FUA;F5N=&QY+@H@("`@("H*("`@("`J($!P87)A;2!,1$%07T=R;W5P
M("1G<F]U<"`@5&AE(&=R;W5P('1O(')E;6]V92X*("`@("`J($!P87)A;2!B
M;V]L96%N("1F;W)C92`@("`@4F5C=7)S:79E;'D@9&5L971E(&-H:6QD<F5N
M(&=R;W5P<R!I9B!T<G5E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;6]V94=R;W5P*"1G<F]U<"P@)&9O<F-E(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A=&%4
M<F5E3V)J96-T7T=R;W5P)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T=R;W5P<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7T=R
M;W5P(&]B:F5C=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@
M?0H*("`@("`@("`D9&X@/2`D9W)O=7`M/F=E=$ED*"D["@H@("`@("`@("\J
M($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C
M97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U
M8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&9O<F-E*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)E8W5R<VEV95]D96QE=&4H)&1N*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@0&QD87!?9&5L971E*"1T:&ES
M+3Y?9',L("1D;BD["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(BDL("1D
M;BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F4@=&AE(&YA;64@;V8@82!G<F]U<"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE(&1N(&]F('1H92!G<F]U<"!T
M;R!R971R:65V92!T:&4@;F%M92!F;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!G<F]U<"=S(&YA;64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$=R;W5P3F%M92@D9&XI"B`@("!["B`@("`@("`@)')E<W5L="`]
M(&QD87!?97AP;&]D95]D;B@D9&XL(#$I.PH@("`@("`@(')E='5R;B`D<F5S
M=6QT6S!=.PH@("`@?0H*("`@("\J*@H@("`@("H@1&%T851R965/8FIE8W0@
M9G5L;"!N86UE<R!I;F-L=61E(')E9F5R96YC97,@=&\@<&%R96YT<RP@8G5T
M($Q$05`@9&]E<PH@("`@("H@;F]T(&AA=F4@=&AI<R!C;VYC97!T+B`@5&AI
M<R!F=6YC=&EO;B!S:6UP;'D@<F5T=7)N<R!T:&4@)&=R;W5P"B`@("`@*B!P
M87)A;65T97(@86YD(&ES(&EN8VQU9&5D(&9O<B!C;VUP871I8FEL:71Y('=I
M=&@@=&AE($=R;W5P(&-L87-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&=R;W5P("!'<F]U<"!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("`D9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P
M4VAO<G1.86UE*"1G<F]U<"D*("`@('L*("`@("`@("!R971U<FX@)&=R;W5P
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE($E$(&]F('1H
M92!G:79E;B!G<F]U<"X*("`@("`J"B`@("`@*B!.3U1%.B!)9B!G:79E;B!A
M(&=R;W5P(&YA;64L('1H:7,@9G5N8W1I;VX@8V%N(&)E('5N<F5L:6%B;&4@
M:68@;6]R90H@("`@("H@=&AA;B!O;F4@9W)O=7`@97AI<W1S('=I=&@@=&AE
M('-A;64@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&=R;W5P
M("`@3$1!4%]'<F]U<"!O8FIE8W0L(&]R(&$@9W)O=7`@;F%M92`H<W1R:6YG
M*0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9W)O=7`G<R!)
M1"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!)9"@D9W)O=7`I"B`@
M("!["B`@("`@("`@:68@*&ES7V$H)&=R;W5P+"`G3$1!4%]'<F]U<"<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D9W)O=7`M/F=E="@G9&XG*3L*("`@("`@
M("!]"@H@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF("@A:7-?
M87)R87DH)&-A8VAE*2D@>PH@("`@("`@("`@("`D8V%C:&4@/2!A<G)A>2@I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D8V%C:&5;)&=R;W5P
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@
M("`@("1S96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)'1H:7,M
M/E]P87)A;7-;)V)A<V5D;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=G:60G72`N("<])R`N("1G<F]U
M<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D
M=&AI<RT^7W!A<F%M<ULG9VED)UTI*3L*("`@("`@("`@("`@:68@*"$D<V5A
M<F-H*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(I*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)')E<W5L="`]($!L9&%P7V=E=%]E
M;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I.PH@("`@("`@("`@("!`;&1A
M<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D<F5S=6QT*2!\?"`H8V]U;G0H)')E<W5L="D@/#T@,2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D5M<'1Y(')E
M<W5L="XB*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-A8VAE6R1G
M<F]U<%T@/2`D<F5S=6QT6S!=6R=D;B==.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1C86-H95LD9W)O=7!=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VL@:68@82!G<F]U<"!E>&ES=',@:6X@=&AE('-Y<W1E;2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@5&AE(&=R;W5P(&YA;64@
M=&\@8VAE8VL@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!I9B!T:&4@9W)O=7`@97AI<W1S+"!&86QS92!O=&AE<G=I<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D9W)O=7`I"B`@("!["B`@("`@
M("`@<W1A=&EC("1C86-H93L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V%C
M:&4I*2!["B`@("`@("`@("`@("1C86-H92`](&%R<F%Y*"D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES<V5T*"1C86-H95LD9W)O=7!=*2D@>PH@("`@
M("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@
M("`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S
M+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<V5A<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1D;BP@)R@F)R`N
M("1T:&ES+3Y?9FEL=&5R("X@)R@G("X@)'1H:7,M/E]P87)A;7-;)V=I9"==
M("X@)STG("X@)&=R;W5P("X@)RDI)RD["B`@("`@("`@("`@(&EF("@A)'-E
M87)C:"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]G971?
M96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`@("`@0&QD
M87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@("`@("`@("`@("1C86-H95LD9W)O
M=7!=(#T@*&ES7V%R<F%Y*"1R97-U;'0I("8F("AC;W5N="@D<F5S=6QT(#X@
M,2DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V%C:&5;)&=R;W5P
M73L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@=&AE('!A
M<F5N=',@;V8@82!C:&EL9"!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D;B`@5&AE(&1N(&]F('1H92!C:&EL9"!G<F]U<"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9&X@86YD(&YA;64@;V8@=&AE
M('!A<F5N="!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!0
M87)E;G1S*"1D;BD*("`@('L*("`@("`@("`D<&%R96YT(#T@)'1H:7,M/F=E
M=$=R;W5P4&%R96YT*"1D;BD["B`@("`@("`@<F5T=7)N(&%R<F%Y*"1P87)E
M;G0@/3X@)'1H:7,M/F=E=$=R;W5P3F%M92@D<&%R96YT*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@=&AE('!A<F5N="!O9B!T:&4@9VEV96X@9W)O
M=7`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&X@(%1H92!D;B!O
M9B!T:&4@8VAI;&0@9W)O=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!D;B!O9B!T:&4@<&%R96YT(&=R;W5P+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971'<F]U<%!A<F5N="@D9&XI"B`@("!["B`@("`@("`@)')E
M<W5L="`](&QD87!?97AP;&]D95]D;B@D9&XL(#`I.PH@("`@("`@('5N<V5T
M*"1R97-U;'1;)V-O=6YT)UTI.PH@("`@("`@('5N<V5T*"1R97-U;'1;,%TI
M.PH@("`@("`@("1P87)E;G1?9&X@/2!I;7!L;V1E*"<L)RP@)')E<W5L="D[
M"@H@("`@("`@(&EF("@D<&%R96YT7V1N(#T]("1'3$]"04Q36R=C;VYF)UU;
M)V=R;W5P)UU;)W!A<F%M<R==6R=B87-E9&XG72D@>PH@("`@("`@("`@("!R
M971U<FX@1$%40512145?4D]/5#L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)'!A<F5N=%]D;CL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('!A<F5N=',@86QL('1H92!W87D@
M=7`@=&\@=&AE(')O;W0@;V)J96-T(&9O<B!T:&4@9VEV96X*("`@("`J(&=R
M;W5P+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1N("!4:&4@9&X@
M;V8@=&AE(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@
M9FQA="!L:7-T(&]F(&%L;"!O9B!T:&4@<&%R96YT<R!O9B!T:&4@9VEV96X@
M9W)O=7`L"B`@("`@*B`@("`@("`@("`@("`@("!H87-H960@:6X@)&1N(#T^
M("1N86UE(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!0
M87)E;G1,:7-T*"1D;BD*("`@('L*("`@("`@("`D<F5S=6QT(#T@;&1A<%]E
M>'!L;V1E7V1N*"1D;BP@,"D["B`@("`@("`@)&YU;2`]("1R97-U;'1;)V-O
M=6YT)UT["@H@("`@("`@('5N<V5T*"1R97-U;'1;)V-O=6YT)UTI.PH@("`@
M("`@('5N<V5T*"1R97-U;'1;,%TI.PH*("`@("`@("`D8V]U;G0@/2`P.PH@
M("`@("`@("1P87)E;G1S(#T@87)R87DH*3L*("`@("`@("`D<&%R96YT7V1N
M(#T@:6UP;&]D92@G+"<L("1R97-U;'0I.PH@("`@("`@('=H:6QE("@D<&%R
M96YT7V1N("$]("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72`F)B`D8V]U;G0K
M*R`A/2`D;G5M*2!["B`@("`@("`@("`@("1P87)E;G1S6R1P87)E;G1?9&Y=
M(#T@)'1H:7,M/F=E=$=R;W5P3F%M92@D<&%R96YT7V1N*3L*("`@("`@("`@
M("`@=6YS970H)')E<W5L=%LD8V]U;G1=*3L*("`@("`@("`@("`@)'!A<F5N
M=%]D;B`](&EM<&QO9&4H)RPG+"`D<F5S=6QT*3L*("`@("`@("!]"B`@("`@
M("`@)'!A<F5N='-;1$%40512145?4D]/5%T@/2!$051!5%)%15]23T]4.PH*
M("`@("`@("!R971U<FX@)'!A<F5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P+"!I;B!T:&4@9F]R;6%T(&1N
M(#T^(&=R;W5P;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<F5F<F5S:"`@268@=')U92P@=&AE(&-A8VAE9"!V86QU92!I<R!I9VYO<F5D
M(&%N9"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!G<F]U
M<"!L:7-T(&ES(')E9G)E<VAE9"!F<F]M('1H92!G<F]U<"!B86-K96YD+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(&1N(#T^(&=R;W5P;F%M92!H
M87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1W)O=7!S*"1R969R97-H
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC("1G<F]U<',["@H@("`@
M("`@(&EF("@D<F5F<F5S:"!\?"!I<U]N=6QL*"1G<F]U<',I*2!["B`@("`@
M("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@
M("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M
M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S
M96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A
M;7-;)V)A<V5D;B==+"`D=&AI<RT^7V9I;'1E<BP@87)R87DH)'1H:7,M/E]P
M87)A;7-;)V=I9"==*2D["B`@("`@("`@("`@(&EF("@A)'-E87)C:"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U
M;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@($!L9&%P7W-O<G0H)'1H:7,M/E]D<RP@)'-E87)C
M:"P@)'1H:7,M/E]P87)A;7-;)V=I9"==*3L*"B`@("`@("`@("`@("1R97-U
M;'0@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*
M("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@("`@("`@
M("`@(&EF("@A:7-?87)R87DH)')E<W5L="D@?'P@*&-O=6YT*"1R97-U;'0I
M(#P](#$I*2!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&=R;W5P<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1R97-U;'1;)V-O=6YT)UT[
M("1I*RLI('L*("`@("`@("`@("`@("`@("1G<F]U<'-;)')E<W5L=%LD:5U;
M)V1N)UU=(#T@)')E<W5L=%LD:5U;)'1H:7,M/E]P87)A;7-;)V=I9"==75LP
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G
M<F]U<',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V
M97)Y('5S97(@=&AA="!I<R!P87)T(&]F('1H92!S<&5C:69I960@9W)O=7`@
M86YD(&%N>0H@("`@("H@;V8@:71S('-U8F=R;W5P<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE(&1N(&]F('1H92!P87)E;G0@9W)O
M=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&-O;7!L971E
M('5S97(@;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$%L;%5S97)S
M*"1D;BD*("`@('L*("`@("`@("!S=&%T:6,@)&-A8VAE.PH*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1C86-H92DI('L*("`@("`@("`@("`@)&-A8VAE(#T@
M87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&-A8VAE
M6R1D;ETI*2!["B`@("`@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN
M96-T*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S
M+"`D=&AI<RT^9V5T1W)O=7!087)E;G0H)&1N*2P@)'1H:7,M/E]F:6QE<BD[
M"B`@("`@("`@("`@(&EF("@A)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1R97-U;'0@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A
M<F-H*3L*("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@
M("`@("`@("`@(&EF("@A:7-?87)R87DH)')E<W5L="D@?'P@*&-O=6YT*"1R
M97-U;'0I(#P](#$I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")%;7!T>2!R97-U;'0N(BDI.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=7-E<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D<F5S=6QT6R=C;W5N="==.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"`D<F5S=6QT6R1I75LD
M=&AI<RT^7W!A<F%M<ULG;65M8F5R=6ED)UU=6R=C;W5N="==.R`D:BLK*2![
M"B`@("`@("`@("`@("`@("`@("`@)'5S97)S6UT@/2`D<F5S=6QT6R1I75LD
M=&AI<RT^7W!A<F%M<ULG;65M8F5R=6ED)UU=6R1J73L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-A8VAE6R1D;ET@
M/2!A<G)A>5]U;FEQ=64H)'5S97)S*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8V%C:&5;)&1N73L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M(&QI<W0@;V8@979E<GD@9W)O=7`@=&AA="!T:&4@9VEV96X@=7-E<B!I<R!A
M(&UE;6)E<B!O9BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7-E
M<B`@("`@("`@("!4:&4@=7-E<B!T;R!G970@9W)O=7!S(&9O<BX*("`@("`J
M($!P87)A;2!B;V]L96%N("1P87)E;G1'<F]U<',@($%L<V\@<F5T=7)N('1H
M92!P87)E;G1S(&]F(&%N>2!G<F]U<',_"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@06X@87)R87D@;V8@86QL(&=R;W5P<R!T:&4@=7-E<B!I<R!I
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!-96UB97)S:&EP<R@D
M=7-E<BP@)'!A<F5N=$=R;W5P<R`](&9A;'-E*0H@("`@>PH@("`@("`@('-T
M871I8R`D8V%C:&4["@H@("`@("`@(&EF("AE;7!T>2@D8V%C:&5;)'5S97)=
M*2D@>PH@("`@("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E
M<BX@*B\*("`@("`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D<V5A<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T
M:&ES+3Y?<&%R86US6R=B87-E9&XG72P@)R@G("X@)'1H:7,M/E]P87)A;7-;
M)VUE;6)E<G5I9"==("X@)STG("X@)'5S97(@+B`G*2<I.PH@("`@("`@("`@
M("!I9B`H(21S96%R8V@I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V
M97(N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@
M0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D["B`@("`@
M("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1R97-U;'0I('Q\("AC;W5N="@D<F5S=6QT*2`\/2`Q
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B16UP='D@<F5S=6QT+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&=R;W5P<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1R97-U;'1;)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@
M("`@("1G<F]U<'-;)')E<W5L=%LD:5U;)V1N)UU=(#T@)')E<W5L=%LD:5U;
M)'1H:7,M/E]P87)A;7-;)V=I9"==75LP73L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&-A8VAE6R1U<V5R72`]("1G<F]U<',["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&-A8VAE6R1U<V5R73L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE('1R964@9&5P=&@@;V8@=&AE(&=I=F5N(&=R
M;W5P+"!R96QA=&EV92!T;R!T:&4@8F%S92!D;BX*("`@("`J(#`@:7,@<F5T
M=7)N960@9F]R(&%N>2!O8FIE8W0@9&ER96-T;'D@8F5L;W<@=&AE(&)A<V4@
M9&XN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&X@(%1H92!D;B!O
M9B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96YG97(@
M(%1H92!T<F4@9&5P=&@@;V8@=&AE(&=R;W5P+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971,979E;"@D9&XI"B`@("!["B`@("`@("`@)&)A<V4@/2!`;&1A
M<%]E>'!L;V1E7V1N*"1T:&ES+3Y?<&%R86US6R=B87-E9&XG72P@,"D["B`@
M("`@("`@)&=R;W5P(#T@0&QD87!?97AP;&]D95]D;B@D9&XL(#`I.PH@("`@
M("`@(')E='5R;B`D9W)O=7!;)V-O=6YT)UT@+2`D8F%S95LG8V]U;G0G72`M
M(#$["B`@("!]"@I]"@HO*BH*("H@17AT96YS:6]N(&]F('1H92!$871A5')E
M94]B:F5C=%]'<F]U<"!C;&%S<R!F;W(@<W1O<FEN9R!G<F]U<"!I;F9O<FUA
M=&EO;@H@*B!I;B!A;B!,1$%0(&1I<F5C=&]R>2X*("H*("H@0&%U=&AO<B`@
M0F5N($-H879E="`\8F5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXQ"B`J($!P86-K86=E($AO<F1E7T=R;W5P"B`J+PIC;&%S<R!,1$%07T=R
M;W5P(&5X=&5N9',@1&%T851R965/8FIE8W1?1W)O=7`@>PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("!4:&4@;F%M92!O9B!T:&ES(&=R;W5P+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%R96YT("!4:&4@9&X@;V8@=&AE('!A<F5N="!O9B!T
M:&ES(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!,1$%07T=R;W5P*"1N
M86UE+"`D<&%R96YT(#T@;G5L;"D*("`@('L*("`@("`@("!P87)E;G0Z.D1A
M=&%4<F5E3V)J96-T7T=R;W5P*"1N86UE*3L*("`@("`@("!I9B`H)'!A<F5N
M="D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG9&XG72`]('-T<G1O;&]W
M97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O=7`G75LG<&%R86US)UU;)V=I9"==
M*2`N("<])R`N("1N86UE("X@)RPG("X@)'!A<F5N=#L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG9&XG72`]('-T<G1O;&]W
M97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O=7`G75LG<&%R86US)UU;)V=I9"==
M*2`N("<])R`N("1N86UE("X*("`@("`@("`@("`@("`@("<L)R`N('-T<G1O
M;&]W97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O=7`G75LG<&%R86US)UU;)V)A
M<V5D;B==*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I<R!P87)T(&]F('1H:7,@9W)O
M=7`@*&%N9"!O;FQY"B`@("`@*B!T:&ES(&=R;W5P*2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@=7-E<B!L:7-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V=R;W5P3V(M/FQI<W15<V5R<R@D=&AI<RT^9&%T85LG9&XG72D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@
M=&AA="!I<R!A(&UE;6)E<B!O9B!T:&ES(&=R;W5P(&%N9"!A;GD@;V8*("`@
M("`J(&ET)W,@<W5B9W)O=7!S+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!C;VUP;&5T92!U<V5R(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QI<W1!;&Q5<V5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9W)O=7!/8BT^;&ES=$%L;%5S97)S*"1T:&ES+3YD871A6R=D;B==*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@:6X@82!L:7-T(&]F(&%T=')I
M8G5T97,@9G)O;2!T:&4@8F%C:V5N9"!A;F0@;6%P(&ET('1O(&]U<@H@("`@
M("H@:6YT97)N86P@9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&%T=')I8G5T97,@(%1H92!L:7-T(&]F(&%T=')I8G5T97,@9G)O
M;2!T:&4@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9R;VU!='1R
M:6)U=&5S*"1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M=&AI<RT^9&%T85LG=7-E<G,G72`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C
M:"`H)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@
M("`@:68@*"1K97D@/3T@<W1R=&]L;W=E<B@D1TQ/0D%,4ULG8V]N9B==6R=G
M<F]U<"==6R=P87)A;7,G75LG;65M8F5R=6ED)UTI*2!["B`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1V86QU92!A<R`D=7-E<BD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ET@/2`G,2<[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LG=7-E<G,G75LD
M=F%L=65=(#T@)S$G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V5I9B`H)&ME>2`]/2`G;6%I;"<I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YD871A6R=E;6%I;"==(#T@)'9A;'5E.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)&ME>5T@/2`D=F%L
M=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!-87`@=&AI<R!O8FIE8W0G<R!A='1R:6)U=&5S(&9R;VT@=&AE(&1A
M=&$@87)R87D@:6YT;R!A(&9O<FUA="!T:&%T"B`@("`@*B!C86X@8F4@<W1O
M<F5D(&EN(&%N($Q$05`@96YT<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE(&5N=')Y(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M=&]!='1R:6)U=&5S*"D*("`@('L*("`@("`@("`D871T<FEB=71E<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F1A=&$@87,@)&ME>2`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*"1K97D@/3T@)W5S97)S)RD@
M>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1U<V5R(#T^
M("1M96UB97)S:&EP*2!["B`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T
M97-;<W1R=&]L;W=E<B@D1TQ/0D%,4ULG8V]N9B==6R=G<F]U<"==6R=P87)A
M;7,G75LG;65M8F5R=6ED)UTI75M=(#T@)'5S97(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS96EF("@D:V5Y(#T]("=E;6%I;"<I('L*
M("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R=M86EL)UT@/2`A96UP='DH
M)'9A;'5E*2`_("1V86QU92`Z("<@)SL*("`@("`@("`@("`@?2!E;'-E:68@
M*"1K97D@(3T@)V1N)R`F)B`D:V5Y("$]('-T<G1O;&]W97(H)$=,3T)!3%-;
M)V-O;F8G75LG9W)O=7`G75LG<&%R86US)UU;)VUE;6)E<G5I9"==*2D@>PH@
M("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)&ME>5T@/2`A96UP='DH)'9A
M;'5E*2`_("1V86QU92`Z("<@)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1A='1R:6)U=&5S.PH@("`@?0H*?0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].3%,O````````````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-S$`,#$V-C8W`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'``````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`S,34R-0`Q,#0Q-S,V,C<W,0`P,C`S-#8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E(&]P
M=&EM:7IE9"!I;G1E<F9A8V4@=&\@=&AE($UA>$UI;F0@25`@061D<F5S<RT^
M0V]U;G1R>0H@*B!L:7-T:6YG+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<"QV(#$N,3`N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X
M.C(W(&IA;B!%>'`@)`H@*@H@*B!"87-E9"!O;B!02%`@9V5O:7`N:6YC(&QI
M8G)A<GD@8GD@36%X36EN9"!,3$,Z"B`J("`@:'1T<#HO+W=W=RYM87AM:6YD
M+F-O;2]D;W=N;&]A9"]G96]I<"]A<&DO<&AP+PH@*@H@*B!/<FEG:6YA;&QY
M(&)A<V5D(&]N('!H<"!V97)S:6]N(&]F('1H92!G96]I<"!L:6)R87)Y('=R
M:71T96X@:6X@36%Y"B`J(#(P,#(@8GD@:FEM('=I;G-T96%D(#QJ:6UW0&%P
M86-H92YO<F<^"B`J"B`J($-O<'ER:6=H="`H0RD@,C`P,R!-87A-:6YD($Q,
M0PH@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@5&AI<R!L:6)R87)Y
M(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N
M9"]O<@H@*B!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@
M3&5S<V5R($=E;F5R86P@4'5B;&EC"B`J($QI8V5N<V4@87,@<'5B;&ES:&5D
M(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VX[(&5I=&AE<@H@*B!V
M97)S:6]N(#(N,2!O9B!T:&4@3&EC96YS92P@;W(@*&%T('EO=7(@;W!T:6]N
M*2!A;GD@;&%T97(@=F5R<VEO;BX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7TY,4PH@*B\*"B\J($-O=6YT<GD@;&ES="X@*B\*)$=,3T)!3%-;)T=%3TE0
M7T-/54Y44EE?0T]$15,G72`](&%R<F%Y*`HG)RP@)T%0)RP@)T55)RP@)T%$
M)RP@)T%%)RP@)T%&)RP@)T%')RP@)T%))RP@)T%,)RP@)T%-)RP@)T%.)RP@
M)T%/)RP@)T%1)RP*)T%2)RP@)T%3)RP@)T%4)RP@)T%5)RP@)T%7)RP@)T%:
M)RP@)T)!)RP@)T)")RP@)T)$)RP@)T)%)RP@)T)&)RP@)T)')RP@)T)()RP*
M)T)))RP@)T)*)RP@)T)-)RP@)T).)RP@)T)/)RP@)T)2)RP@)T)3)RP@)T)4
M)RP@)T)6)RP@)T)7)RP@)T)9)RP@)T):)RP@)T-!)RP*)T-#)RP@)T-$)RP@
M)T-&)RP@)T-')RP@)T-()RP@)T-))RP@)T-+)RP@)T-,)RP@)T--)RP@)T-.
M)RP@)T-/)RP@)T-2)RP@)T-5)RP*)T-6)RP@)T-8)RP@)T-9)RP@)T-:)RP@
M)T1%)RP@)T1*)RP@)T1+)RP@)T1-)RP@)T1/)RP@)T1:)RP@)T5#)RP@)T5%
M)RP@)T5')RP*)T5()RP@)T52)RP@)T53)RP@)T54)RP@)T9))RP@)T9*)RP@
M)T9+)RP@)T9-)RP@)T9/)RP@)T92)RP@)T98)RP@)T=!)RP@)U5+)RP*)T=$
M)RP@)T=%)RP@)T=&)RP@)T=()RP@)T=))RP@)T=,)RP@)T=-)RP@)T=.)RP@
M)T=0)RP@)T=1)RP@)T=2)RP@)T=3)RP@)T=4)RP*)T=5)RP@)T=7)RP@)T=9
M)RP@)TA+)RP@)TA-)RP@)TA.)RP@)TA2)RP@)TA4)RP@)TA5)RP@)TE$)RP@
M)TE%)RP@)TE,)RP@)TE.)RP*)TE/)RP@)TE1)RP@)TE2)RP@)TE3)RP@)TE4
M)RP@)TI-)RP@)TI/)RP@)TI0)RP@)TM%)RP@)TM')RP@)TM()RP@)TM))RP@
M)TM-)RP*)TM.)RP@)TM0)RP@)TM2)RP@)TM7)RP@)TM9)RP@)TM:)RP@)TQ!
M)RP@)TQ")RP@)TQ#)RP@)TQ))RP@)TQ+)RP@)TQ2)RP@)TQ3)RP*)TQ4)RP@
M)TQ5)RP@)TQ6)RP@)TQ9)RP@)TU!)RP@)TU#)RP@)TU$)RP@)TU')RP@)TU(
M)RP@)TU+)RP@)TU,)RP@)TU-)RP@)TU.)RP*)TU/)RP@)TU0)RP@)TU1)RP@
M)TU2)RP@)TU3)RP@)TU4)RP@)TU5)RP@)TU6)RP@)TU7)RP@)TU8)RP@)TU9
M)RP@)TU:)RP@)TY!)RP*)TY#)RP@)TY%)RP@)TY&)RP@)TY')RP@)TY))RP@
M)TY,)RP@)TY/)RP@)TY0)RP@)TY2)RP@)TY5)RP@)TY:)RP@)T]-)RP@)U!!
M)RP*)U!%)RP@)U!&)RP@)U!')RP@)U!()RP@)U!+)RP@)U!,)RP@)U!-)RP@
M)U!.)RP@)U!2)RP@)U!3)RP@)U!4)RP@)U!7)RP@)U!9)RP*)U%!)RP@)U)%
M)RP@)U)/)RP@)U)5)RP@)U)7)RP@)U-!)RP@)U-")RP@)U-#)RP@)U-$)RP@
M)U-%)RP@)U-')RP@)U-()RP@)U-))RP*)U-*)RP@)U-+)RP@)U-,)RP@)U--
M)RP@)U-.)RP@)U-/)RP@)U-2)RP@)U-4)RP@)U-6)RP@)U-9)RP@)U-:)RP@
M)U1#)RP@)U1$)RP*)U1&)RP@)U1')RP@)U1()RP@)U1*)RP@)U1+)RP@)U1-
M)RP@)U1.)RP@)U1/)RP@)U10)RP@)U12)RP@)U14)RP@)U16)RP@)U17)RP*
M)U1:)RP@)U5!)RP@)U5')RP@)U5-)RP@)U53)RP@)U59)RP@)U5:)RP@)U9!
M)RP@)U9#)RP@)U9%)RP@)U9')RP@)U9))RP@)U9.)RP*)U95)RP@)U=&)RP@
M)U=3)RP@)UE%)RP@)UE4)RP@)UE5)RP@)UI!)RP@)UI-)RP@)UI2)RP@)UI7
M)RP@)T$Q)RP@)T$R)RP@)T\Q)PHI.PH*+RH@0V]U;G1R>2!.86UE<RX@*B\*
M)$=,3T)!3%-;)T=%3TE07T-/54Y44EE?3D%-15,G72`](&%R<F%Y*`HB(BP@
M7R@B07-I82]086-I9FEC(%)E9VEO;B(I+"!?*")%=7)O<&4B*2P@7R@B06YD
M;W)R82(I+`I?*")5;FET960@07)A8B!%;6ER871E<R(I+"!?*")!9F=H86YI
M<W1A;B(I+"!?*")!;G1I9W5A(&%N9"!"87)B=61A(BDL"E\H(D%N9W5I;&QA
M(BDL(%\H(D%L8F%N:6$B*2P@7R@B07)M96YI82(I+"!?*").971H97)L86YD
M<R!!;G1I;&QE<R(I+`I?*")!;F=O;&$B*2P@7R@B06YT87)C=&EC82(I+"!?
M*")!<F=E;G1I;F$B*2P@7R@B06UE<FEC86X@4V%M;V$B*2P*7R@B075S=')I
M82(I+"!?*")!=7-T<F%L:6$B*2P@7R@B07)U8F$B*2P@7R@B07IE<F)A:6IA
M;B(I+`I?*")";W-N:6$@86YD($AE<GIE9V]V:6YA(BDL(%\H(D)A<F)A9&]S
M(BDL(%\H(D)A;F=L861E<V@B*2P@7R@B0F5L9VEU;2(I+`I?*")"=7)K:6YA
M($9A<V\B*2P@7R@B0G5L9V%R:6$B*2P@7R@B0F%H<F%I;B(I+"!?*")"=7)U
M;F1I(BDL(%\H(D)E;FEN(BDL"E\H(D)E<FUU9&$B*2P@7R@B0G)U;F5I($1A
M<G5S<V%L86TB*2P@7R@B0F]L:79I82(I+"!?*")"<F%Z:6PB*2P@7R@B0F%H
M86UA<R(I+`I?*")":'5T86XB*2P@7R@B0F]U=F5T($ES;&%N9"(I+"!?*")"
M;W1S=V%N82(I+"!?*")"96QA<G5S(BDL(%\H(D)E;&EZ92(I+`I?*")#86YA
M9&$B*2P@7R@B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B*2P*7R@B0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(I+"!?*")#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,B*2P*7R@B0V]N9V\B*2P@7R@B4W=I='IE<FQA
M;F0B*2P@7R@B0V]T92!D)TEV;VER92(I+"!?*")#;V]K($ES;&%N9',B*2P*
M7R@B0VAI;&4B*2P@7R@B0V%M97)O;VXB*2P@7R@B0VAI;F$B*2P@7R@B0V]L
M;VUB:6$B*2P@7R@B0V]S=&$@4FEC82(I+`I?*")#=6)A(BDL(%\H(D-A<&4@
M5F5R9&4B*2P@7R@B0VAR:7-T;6%S($ES;&%N9"(I+"!?*")#>7!R=7,B*2P*
M7R@B0WIE8V@@4F5P=6)L:6,B*2P@7R@B1V5R;6%N>2(I+"!?*")$:FEB;W5T
M:2(I+"!?*")$96YM87)K(BDL(%\H(D1O;6EN:6-A(BDL"E\H(D1O;6EN:6-A
M;B!297!U8FQI8R(I+"!?*")!;&=E<FEA(BDL(%\H(D5C=6%D;W(B*2P@7R@B
M17-T;VYI82(I+"!?*")%9WEP="(I+`I?*")797-T97)N(%-A:&%R82(I+"!?
M*")%<FET<F5A(BDL(%\H(E-P86EN(BDL(%\H(D5T:&EO<&EA(BDL(%\H(D9I
M;FQA;F0B*2P*7R@B1FEJ:2(I+"!?*")&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RDB*2P@7R@B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(I
M+`I?*")&87)O92!)<VQA;F1S(BDL(%\H(D9R86YC92(I+"!?*")&<F%N8V4L
M($UE=')O<&]L:71A;B(I+"!?*")'86)O;B(I+`I?*")5;FET960@2VEN9V1O
M;2(I+"!?*")'<F5N861A(BDL(%\H(D=E;W)G:6$B*2P@7R@B1G)E;F-H($=U
M:6%N82(I+`I?*")':&%N82(I+"!?*")':6)R86QT87(B*2P@7R@B1W)E96YL
M86YD(BDL(%\H(D=A;6)I82(I+"!?*")'=6EN96$B*2P*7R@B1W5A9&5L;W5P
M92(I+"!?*")%<75A=&]R:6%L($=U:6YE82(I+"!?*")'<F5E8V4B*2P*7R@B
M4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B
M*2P@7R@B1W5A=&5M86QA(BDL(%\H(D=U86TB*2P*7R@B1W5I;F5A+4)I<W-A
M=2(I+"!?*")'=7EA;F$B*2P@7R@B2&]N9R!+;VYG(BDL"E\H(DAE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(I+"!?*")(;VYD=7)A<R(I+"!?
M*")#<F]A=&EA(BDL"E\H(DAA:71I(BDL(%\H(DAU;F=A<GDB*2P@7R@B26YD
M;VYE<VEA(BDL(%\H(DER96QA;F0B*2P@7R@B27-R865L(BDL"E\H(DEN9&EA
M(BDL(%\H(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(I+"!?*"))
M<F%Q(BDL"E\H(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B*2P@7R@B26-E
M;&%N9"(I+"!?*"))=&%L>2(I+"!?*")*86UA:6-A(BDL"E\H(DIO<F1A;B(I
M+"!?*")*87!A;B(I+"!?*")+96YY82(I+"!?*")+>7)G>7IS=&%N(BDL(%\H
M(D-A;6)O9&EA(BDL"E\H(DMI<FEB871I(BDL(%\H(D-O;6]R;W,B*2P@7R@B
M4V%I;G0@2VET=',@86YD($YE=FES(BDL"E\H(DMO<F5A+"!$96UO8W)A=&EC
M(%!E;W!L92=S(%)E<'5B;&EC(&]F(BDL(%\H(DMO<F5A+"!297!U8FQI8R!O
M9B(I+`I?*")+=7=A:70B*2P@7R@B0V%Y;6%N($ES;&%N9',B*2P@7R@B2V%Z
M86MH<W1A;B(I+`I?*"),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8R(I+"!?*"),96)A;F]N(BDL(%\H(E-A:6YT($QU8VEA(BDL"E\H(DQI96-H
M=&5N<W1E:6XB*2P@7R@B4W)I($QA;FMA(BDL(%\H(DQI8F5R:6$B*2P@7R@B
M3&5S;W1H;R(I+`I?*"),:71H=6%N:6$B*2P@7R@B3'5X96UB;W5R9R(I+"!?
M*"),871V:6$B*2P@7R@B3&EB>6%N($%R86(@2F%M86AI<FEY82(I+`I?*")-
M;W)O8V-O(BDL(%\H(DUO;F%C;R(I+"!?*")-;VQD;W9A+"!297!U8FQI8R!O
M9B(I+"!?*")-861A9V%S8V%R(BDL"E\H(DUA<G-H86QL($ES;&%N9',B*2P@
M7R@B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M(BDL"E\H(DUA;&DB*2P@7R@B37EA;FUA<B(I+"!?*")-;VYG;VQI82(I+"!?
M*")-86-A;R(I+`I?*").;W)T:&5R;B!-87)I86YA($ES;&%N9',B*2P@7R@B
M36%R=&EN:7%U92(I+"!?*")-875R:71A;FEA(BDL"E\H(DUO;G1S97)R870B
M*2P@7R@B36%L=&$B*2P@7R@B36%U<FET:75S(BDL(%\H(DUA;&1I=F5S(BDL
M(%\H(DUA;&%W:2(I+`I?*")-97AI8V\B*2P@7R@B36%L87ES:6$B*2P@7R@B
M36]Z86UB:7%U92(I+"!?*").86UI8FEA(BDL(%\H(DYE=R!#86QE9&]N:6$B
M*2P*7R@B3FEG97(B*2P@7R@B3F]R9F]L:R!)<VQA;F0B*2P@7R@B3FEG97)I
M82(I+"!?*").:6-A<F%G=6$B*2P*7R@B3F5T:&5R;&%N9',B*2P@7R@B3F]R
M=V%Y(BDL(%\H(DYE<&%L(BDL(%\H(DYA=7)U(BDL(%\H(DYI=64B*2P*7R@B
M3F5W(%IE86QA;F0B*2P@7R@B3VUA;B(I+"!?*")086YA;6$B*2P@7R@B4&5R
M=2(I+"!?*")&<F5N8V@@4&]L>6YE<VEA(BDL"E\H(E!A<'5A($YE=R!'=6EN
M96$B*2P@7R@B4&AI;&EP<&EN97,B*2P@7R@B4&%K:7-T86XB*2P@7R@B4&]L
M86YD(BDL"E\H(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB*2P@7R@B4&ET
M8V%I<FXB*2P@7R@B4'5E<G1O(%)I8V\B*2P*7R@B4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9"(I+"!?*")0;W)T=6=A;"(I+"!?*")086QA=2(I
M+`I?*")087)A9W5A>2(I+"!?*")1871A<B(I+"!?*")2975N:6]N(BDL(%\H
M(E)O;6%N:6$B*2P*7R@B4G5S<VEA;B!&961E<F%T:6]N(BDL(%\H(E)W86YD
M82(I+"!?*")3875D:2!!<F%B:6$B*2P@7R@B4V]L;VUO;B!)<VQA;F1S(BDL
M"E\H(E-E>6-H96QL97,B*2P@7R@B4W5D86XB*2P@7R@B4W=E9&5N(BDL(%\H
M(E-I;F=A<&]R92(I+"!?*")386EN="!(96QE;F$B*2P*7R@B4VQO=F5N:6$B
M*2P@7R@B4W9A;&)A<F0@86YD($IA;B!-87EE;B(I+"!?*")3;&]V86MI82(I
M+"!?*")3:65R<F$@3&5O;F4B*2P*7R@B4V%N($UA<FEN;R(I+"!?*")396YE
M9V%L(BDL(%\H(E-O;6%L:6$B*2P@7R@B4W5R:6YA;64B*2P*7R@B4V%O(%1O
M;64@86YD(%!R:6YC:7!E(BDL(%\H(D5L(%-A;'9A9&]R(BDL(%\H(E-Y<FEA
M;B!!<F%B(%)E<'5B;&EC(BDL"E\H(E-W87II;&%N9"(I+"!?*")4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',B*2P@7R@B0VAA9"(I+`I?*")&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,B*2P@7R@B5&]G;R(I+"!?*")4:&%I;&%N9"(I
M+"!?*")486II:VES=&%N(BDL"E\H(E1O:V5L874B*2P@7R@B5'5R:VUE;FES
M=&%N(BDL(%\H(E1U;FES:6$B*2P@7R@B5&]N9V$B*2P@7R@B5&EM;W(M3&5S
M=&4B*2P*7R@B5'5R:V5Y(BDL(%\H(E1R:6YI9&%D(&%N9"!4;V)A9V\B*2P@
M7R@B5'5V86QU(BDL(%\H(E1A:7=A;B(I+`I?*")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(BDL(%\H(E5K<F%I;F4B*2P@7R@B56=A;F1A(BDL"E\H
M(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(I+"!?*")5
M;FET960@4W1A=&5S(BDL(%\H(E5R=6=U87DB*2P*7R@B57IB96MI<W1A;B(I
M+"!?*")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(I+`I?*")386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(I+"!?*")696YE>G5E;&$B
M*2P*7R@B5FER9VEN($ES;&%N9',L($)R:71I<V@B*2P@7R@B5FER9VEN($ES
M;&%N9',L(%4N4RXB*2P@7R@B5FEE="!.86TB*2P*7R@B5F%N=6%T=2(I+"!?
M*")786QL:7,@86YD($9U='5N82(I+"!?*")386UO82(I+"!?*")996UE;B(I
M+"!?*")-87EO='1E(BDL"E\H(EEU9V]S;&%V:6$B*2P@7R@B4V]U=&@@069R
M:6-A(BDL(%\H(EIA;6)I82(I+"!?*"):86ER92(I+"!?*")::6UB86)W92(I
M+`I?*")!;F]N>6UO=7,@4')O>'DB*2P@7R@B4V%T96QL:71E(%!R;W9I9&5R
M(BDL(%\H(D]T:&5R(BD**3L*"F1E9FEN92@G1T5/25!?0T]53E1265]"14=)
M3B<L(#$V-S<V.38P*3L*9&5F:6YE*"=35%)50U154D5?24Y&3U]-05A?4TE:
M12<L(#(P*3L*9&5F:6YE*"=35$%.1$%21%]214-/4D1?3$5.1U1()RP@,RD[
M"@IC;&%S<R!.3%-?1V5O25`@>PH*("`@("\J*@H@("`@("H@5&AE(&QO8V%T
M:6]N(&]F('1H92!'96])4"!D871A8F%S92X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D871A9FEL93L*"B`@("`O*BH*
M("`@("`J(%1H92!O<&5N(&9I;&5H86YD;&4@=&\@=&AE($=E;TE0(&1A=&%B
M87-E+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@
M=F%R("1?9FEL96AA;F1L93L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R
M969E<F5N8V4@=&\@=&AE(&=L;V)A;"!.3%-?1V5O25`@;V)J96-T+"!O;FQY
M(&-R96%T:6YG(&ET"B`@("`@*B!I9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI
M<W0N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D
M(&%S.@H@("`@("H@("`D9V5O:7`@/2`F1V5O25`Z.G-I;F=L971O;B@D9&%T
M869I;&4I.PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&%F:6QE
M("!4:&4@;&]C871I;VX@;V8@=&AE($=E;TE0(&1A=&%B87-E+@H@("`@("H*
M("`@("`J($!R971U<FX@;V)J96-T($Y,4U]'96])4"`@5&AE($Y,4U]'96])
M4"!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D
M9&%T869I;&4I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC93L*"B`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V4I*2!["B`@("`@("`@("`@("1I
M;G-T86YC92`](&YE=R!.3%-?1V5O25`H)&1A=&%F:6QE*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&4@82!.3%-?1V5O25`@:6YS=&%N8V4@*$-O;G-T<G5C=&]R
M*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A9FEL92`@5&AE
M(&QO8V%T:6]N(&]F('1H92!'96])4"!D871A8F%S92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@3DQ37T=E;TE0*"1D871A9FEL92D*("`@('L*("`@("`@("`D
M=&AI<RT^7V1A=&%F:6QE(#T@)&1A=&%F:6QE.PH@("`@?0H*("`@("\J*@H@
M("`@("H@3W!E;B!T:&4@1V5O25`@9&%T86)A<V4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!&86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V]P96XH
M*0H@("`@>PH@("`@("`@("\J(%)E='5R;B!I9B!W92!A;')E861Y(&AA=F4@
M86X@;V)J96-T+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]G:2DI
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("`O*B!2971U<FX@:68@;F\@9&%T869I;&4@<W!E8VEF:65D+B`J+PH@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7V1A=&%F:6QE*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9I
M;&5H86YD;&4@/2!F;W!E;B@D=&AI<RT^7V1A=&%F:6QE+"`G<F(G*3L*"B`@
M("`@("`@)&9I;&5P;W,@/2!F=&5L;"@D=&AI<RT^7V9I;&5H86YD;&4I.PH@
M("`@("`@(&9S965K*"1T:&ES+3Y?9FEL96AA;F1L92P@+3,L(%-%14M?14Y$
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!35%)50U154D5?24Y&3U]-
M05A?4TE:13L@)&DK*RD@>PH@("`@("`@("`@("`D9&5L:6T@/2!F<F5A9"@D
M=&AI<RT^7V9I;&5H86YD;&4L(#,I.PH@("`@("`@("`@("!I9B`H)&1E;&EM
M(#T]("AC:'(H,C4U*2`N(&-H<B@R-34I("X@8VAR*#(U-2DI*2!["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&9S965K*"1T:&ES+3Y?9FEL96AA;F1L92P@+30L(%-%14M?
M0U52*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!F<V5E:R@D
M=&AI<RT^7V9I;&5H86YD;&4L("1F:6QE<&]S+"!3145+7U-%5"D["@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@8V]U;G1R>2!)1"!F;W(@82!H;W-T;F%M92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@:&]S=&YA;64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@1V5O25`@8V]U;G1R>2!)1"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1R>4ED0GE.86UE*"1N86UE*0H@
M("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N*"DI('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D861D<B`](&=E
M=&AO<W1B>6YA;64H)&YA;64I.PH@("`@("`@(&EF("@A)&%D9'(@?'P@)&%D
M9'(@/3T@)&YA;64I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/F-O=6YT<GE)9$)Y061D<B@D
M861D<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N
M=')Y(&%B8G)E=FEA=&EO;B`H,BUL971T97(I(&9O<B!A(&AO<W1N86UE+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!H;W-T;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C;W5N=')Y
M(&%B8G)E=FEA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1R>4-O
M9&5">4YA;64H)&YA;64I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E
M;B@I*2!["B`@("`@("`@("`@("1C;W5N=')Y7VED(#T@)'1H:7,M/F-O=6YT
M<GE)9$)Y3F%M92@D;F%M92D["B`@("`@("`@("`@(&EF("@D8V]U;G1R>5]I
M9"`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,
M4ULG1T5/25!?0T]53E1265]#3T1%4R==6R1C;W5N=')Y7VED73L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N=')Y(&YA;64@9F]R
M(&$@:&]S=&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&AO<W1N86UE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&-O=6YT<GD@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U
M;G1R>4YA;65">4YA;64H)&YA;64I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3Y?;W!E;B@I*2!["B`@("`@("`@("`@("1C;W5N=')Y7VED(#T@)'1H:7,M
M/F-O=6YT<GE)9$)Y3F%M92@D;F%M92D["B`@("`@("`@("`@(&EF("@D8V]U
M;G1R>5]I9"`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M1TQ/0D%,4ULG1T5/25!?0T]53E1265].04U%4R==6R1C;W5N=')Y7VED73L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N=')Y($E$
M(&9O<B!A;B!)4"!!9&1R97-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&%D9'(@(%1H92!)4"!!9&1R97-S+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@5&AE($=E;TE0(&-O=6YT<GD@240N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O=6YT<GE)9$)Y061D<B@D861D<BD*("`@('L*("`@("`@
M("!I9B`H(21T:&ES+3Y?;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@)&EP;G5M(#T@:7`R;&]N9R@D861D
M<BD["B`@("`@("`@<F5T=7)N("@D=&AI<RT^7W-E96M#;W5N=')Y*"1I<&YU
M;2D@+2!'14])4%]#3U5.5%)97T)%1TE.*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&-O=6YT<GD@86)B<F5V:6%T:6]N("@R+6QE='1E
M<BD@9F]R(&%N($E0($%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D861D<B`@5&AE($E0($%D9')E<W,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!4:&4@8V]U;G1R>2!A8F)R979I871I;VXN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE#;V1E0GE!9&1R*"1A9&1R*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96XH*2D@>PH@("`@("`@("`@("`D
M8V]U;G1R>5]I9"`]("1T:&ES+3YC;W5N=')Y261">4%D9'(H)&%D9'(I.PH@
M("`@("`@("`@("!I9B`H)&-O=6YT<GE?:60@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)T=%3TE07T-/54Y44EE?0T]$
M15,G75LD8V]U;G1R>5]I9%T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@8V]U;G1R>2!N86UE(&9O<B!A;B!)4"!A9&1R97-S+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D9'(@(%1H92!)4"!A9&1R97-S
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!C;W5N=')Y(&YA
M;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE.86UE0GE!9&1R*"1A
M9&1R*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96XH*2D@>PH@("`@
M("`@("`@("`D8V]U;G1R>5]I9"`]("1T:&ES+3YC;W5N=')Y261">4%D9'(H
M)&%D9'(I.PH@("`@("`@("`@("!I9B`H)&-O=6YT<GE?:60@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)T=%3TE07T-/
M54Y44EE?3D%-15,G75LD8V]U;G1R>5]I9%T["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1FEN9',@82!C;W5N=')Y(&)Y($E0($%D9')E<W,@:6X@=&AE($=E
M;TE0(&1A=&%B87-E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EP;G5M("!4:&4@25`@061D
M<F5S<R!T;R!S96%R8V@@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1H92!C;W5N=')Y($E$(&]R(&9A;'-E(&EF(&YO="!F;W5N9"X*("`@
M("`J("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E96M#;W5N=')Y*"1I<&YU;2D*
M("`@('L*("`@("`@("`D;V9F<V5T(#T@,#L*("`@("`@("!F;W(@*"1D97!T
M:"`](#,Q.R`D9&5P=&@@/CT@,#L@+2TD9&5P=&@I('L*("`@("`@("`@("`@
M:68@*&9S965K*"1T:&ES+3Y?9FEL96AA;F1L92P@,B`J(%-404Y$05)$7U)%
M0T]21%],14Y'5$@@*B`D;V9F<V5T+"!3145+7U-%5"D@(3T@,"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)V9S965K(&9A
M:6QE9"<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1B=68@/2!F<F5A
M9"@D=&AI<RT^7V9I;&5H86YD;&4L(#(@*B!35$%.1$%21%]214-/4D1?3$5.
M1U1(*3L*("`@("`@("`@("`@)'@@/2!A<G)A>2@P+"`P*3L*("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@,CL@*RLD:2D@>PH@("`@("`@("`@("`@
M("`@9F]R("@D:B`](#`[("1J(#P@4U1!3D1!4D1?4D5#3U)$7TQ%3D=42#L@
M*RLD:BD@>PH@("`@("`@("`@("`@("`@("`@("1X6R1I72`K/2!O<F0H)&)U
M9EM35$%.1$%21%]214-/4D1?3$5.1U1(("H@)&D@*R`D:ETI(#P\("@D:B`J
M(#@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@D:7!N=6T@)B`H,2`\/"`D9&5P=&@I*2!["B`@("`@("`@("`@
M("`@("!I9B`H)'A;,5T@/CT@1T5/25!?0T]53E1265]"14=)3BD@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D>%LQ73L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1O9F9S970@/2`D>%LQ73L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@D>%LP72`^/2!'14])
M4%]#3U5.5%)97T)%1TE.*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1X6S!=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&]F
M9G-E="`]("1X6S!=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TY,4R]C87)S:6=N<RYP:'``````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-S,R,@`Q,#0Q-S,V,C<W,0`P,C$R,3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!L:7-T(&]F(&EN=&5R;F%T:6]N86P@;&EC96YS92!P;&%T92!C;V1E
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3DQ3+TY,4R]C87)S:6=N<RYP
M:'`L=B`Q+C$@,C`P-"\P.2\P."`Q-3HQ.#HU-R!J86X@17AP("0*("H*("H@
M0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PH*)&-A<G-I9VYS(#T@87)R87DH"B`@
M("`G870G(#T^("=!)RP*("`@("=A9B<@/3X@)T%&1R<L"B`@("`G86<G(#T^
M("=!1R<L"B`@("`G86PG(#T^("=!3"<L"B`@("`G860G(#T^("=!3D0G+`H@
M("`@)V%O)R`]/B`G04Y')RP*("`@("=A;2<@/3X@)T%232<L"B`@("`G874G
M(#T^("=!55,G+`H@("`@)V%Z)R`]/B`G05HG+`H@("`@)V)E)R`]/B`G0B<L
M"B`@("`G8F0G(#T^("="1"<L"B`@("`G8F(G(#T^("="1%,G+`H@("`@)V)F
M)R`]/B`G0D8G+`H@("`@)V)G)R`]/B`G0D<G+`H@("`@)V)Z)R`]/B`G0D@G
M+`H@("`@)V)T)R`]/B`G0DA4)RP*("`@("=B82<@/3X@)T))2"<L"B`@("`G
M8F\G(#T^("="3TPG+`H@("`@)V)R)R`]/B`G0E(G+`H@("`@)V)H)R`]/B`G
M0E).)RP*("`@("=B;B<@/3X@)T)252<L"B`@("`G8G,G(#T^("="4R<L"B`@
M("`G8FDG(#T^("="52<L"B`@("`G=F<G(#T^("="5DDG+`H@("`@)V)Y)R`]
M/B`G0EDG+`H@("`@)V)Z)R`]/B`G0EHG+`H@("`@)V-U)R`]/B`G0R<L"B`@
M("`G8VTG(#T^("=#04TG+`H@("`@)V-D)R`]/B`G0T0G+`H@("`@)V-A)R`]
M/B`G0T1.)RP*("`@("=C:"<@/3X@)T-()RP*("`@("=C:2<@/3X@)T-))RP*
M("`@("=L:R<@/3X@)T-,)RP*("`@("=C;R<@/3X@)T-/)RP*("`@("=K;2<@
M/3X@)T-/32<L"B`@("`G8W(G(#T^("=#4B<L"B`@("`G8W8G(#T^("=#5B<L
M"B`@("`G8WDG(#T^("=#62<L"B`@("`G8WHG(#T^("=#6B<L"B`@("`G9&4G
M(#T^("=$)RP*("`@("=D:B<@/3X@)T1*22<L"B`@("`G9&LG(#T^("=$2R<L
M"B`@("`G9&\G(#T^("=$3TTG+`H@("`@)VMP)R`]/B`G1%922R<L"B`@("`G
M8FHG(#T^("=$62<L"B`@("`G9'HG(#T^("=$6B<L"B`@("`G97,G(#T^("=%
M)RP*("`@("=K92<@/3X@)T5!2R<L"B`@("`G='HG(#T^("=%050G+`H@("`@
M)W5G)R`]/B`G14%5)RP*("`@("=E8R<@/3X@)T5#)RP*("`@("=E<B<@/3X@
M)T52)RP*("`@("=S=B<@/3X@)T53)RP*("`@("=E92<@/3X@)T535"<L"B`@
M("`G96<G(#T^("=%5"<L"B`@("`G970G(#T^("=%5$@G+`H@("`@)V9R)R`]
M/B`G1B<L"B`@("`G9FDG(#T^("=&24XG+`H@("`@)V9J)R`]/B`G1DI))RP*
M("`@("=L:2<@/3X@)T9,)RP*("`@("=F;R<@/3X@)T9/)RP*("`@("=F;2<@
M/3X@)T9332<L"B`@("`G9V$G(#T^("=')RP*("`@("=G8B<@/3X@)T=")RP*
M("`@("=G:2<@/3X@)T="6B<L"B`@("`G9W0G(#T^("='0T$G+`H@("`@)V=E
M)R`]/B`G1T4G+`H@("`@)V=H)R`]/B`G1T@G+`H@("`@)V=Q)R`]/B`G1U$G
M+`H@("`@)V=R)R`]/B`G1U(G+`H@("`@)V=Y)R`]/B`G1U59)RP*("`@("=H
M=2<@/3X@)T@G+`H@("`@)VAK)R`]/B`G2$LG+`H@("`@)VAN)R`]/B`G2$XG
M+`H@("`@)VAR)R`]/B`G2%(G+`H@("`@)VET)R`]/B`G22<L"B`@("`G:6PG
M(#T^("=)3"<L"B`@("`G:6XG(#T^("=)3D0G+`H@("`@)VER)R`]/B`G25(G
M+`H@("`@)VEE)R`]/B`G25),)RP*("`@("=I<2<@/3X@)TE242<L"B`@("`G
M:7,G(#T^("=)4R<L"B`@("`G:G`G(#T^("=*)RP*("`@("=J;2<@/3X@)TI!
M)RP*("`@("=J;R<@/3X@)TI/4B<L"B`@("`G:V@G(#T^("=+)RP*("`@("=K
M:2<@/3X@)TM)4B<L"B`@("`G9VPG(#T^("=+3B<L"B`@("`G:V<G(#T^("=+
M4R<L"B`@("`G<V$G(#T^("=+4T$G+`H@("`@)VMW)R`]/B`G2U=4)RP*("`@
M("=K>B<@/3X@)TM:)RP*("`@("=L=2<@/3X@)TPG+`H@("`@)VQA)R`]/B`G
M3$%/)RP*("`@("=L>2<@/3X@)TQ!4B<L"B`@("`G;'(G(#T^("=,0B<L"B`@
M("`G;',G(#T^("=,4R<L"B`@("`G;'0G(#T^("=,5"<L"B`@("`G;'8G(#T^
M("=,5B<L"B`@("`G;70G(#T^("=-)RP*("`@("=M82<@/3X@)TU!)RP*("`@
M("=M>2<@/3X@)TU!3"<L"B`@("`G;6,G(#T^("=-0R<L"B`@("`G;60G(#T^
M("=-1"<L"B`@("`G;7@G(#T^("=-15@G+`H@("`@)VUN)R`]/B`G34=,)RP*
M("`@("=M:"<@/3X@)TU()RP*("`@("=M:R<@/3X@)TU+)RP*("`@("=M>B<@
M/3X@)TU/0R<L"B`@("`G;74G(#T^("=-4R<L"B`@("`G;78G(#T^("=-5B<L
M"B`@("`G;7<G(#T^("=-5R<L"B`@("`G;6TG(#T^("=-64$G+`H@("`@)VYO
M)R`]/B`G3B<L"B`@("`G86XG(#T^("=.02<L"B`@("`G;FPG(#T^("=.3"<L
M"B`@("`G;GHG(#T^("=.6B<L"B`@("`G;VTG(#T^("=/32<L"B`@("`G<'0G
M(#T^("=0)RP*("`@("=P82<@/3X@)U!!)RP*("`@("=P=R<@/3X@)U!!3"<L
M"B`@("`G<&4G(#T^("=012<L"B`@("`G<&LG(#T^("=02R<L"B`@("`G<&PG
M(#T^("=03"<L"B`@("`G<&<G(#T^("=03D<G+`H@("`@)V-N)R`]/B`G4%)#
M)RP*("`@("=P<R<@/3X@)U!3)RP*("`@("=P>2<@/3X@)U!9)RP*("`@("=Q
M82<@/3X@)U$G+`H@("`@)V%R)R`]/B`G4D$G+`H@("`@)V)W)R`]/B`G4D(G
M+`H@("`@)W1W)R`]/B`G4D,G+`H@("`@)V-F)R`]/B`G4D-!)RP*("`@("=C
M9"<@/3X@)U)#0B<L"B`@("`G8VPG(#T^("=20T@G+`H@("`@)W)E)R`]/B`G
M4D4G+`H@("`@)V=N)R`]/B`G4D<G+`H@("`@)VAT)R`]/B`G4D@G+`H@("`@
M)VED)R`]/B`G4DDG+`H@("`@)VUR)R`]/B`G4DE-)RP*("`@("=L8B<@/3X@
M)U),)RP*("`@("=M9R<@/3X@)U)-)RP*("`@("=M;"<@/3X@)U)-32<L"B`@
M("`G;F4G(#T^("=23B<L"B`@("`G<F\G(#T^("=23R<L"B`@("`G:W(G(#T^
M("=23TLG+`H@("`@)W5Y)R`]/B`G4D]5)RP*("`@("=P:"<@/3X@)U)0)RP*
M("`@("=S;2<@/3X@)U)332<L"B`@("`G=&<G(#T^("=25"<L"B`@("`G<G4G
M(#T^("=255,G+`H@("`@)W)W)R`]/B`G4E=!)RP*("`@("=S92<@/3X@)U,G
M+`H@("`@)V-S)R`]/B`G4T-')RP*("`@("=K;B<@/3X@)U-#3B<L"B`@("`G
M<WHG(#T^("=31"<L"B`@("`G<V<G(#T^("=31U`G+`H@("`@)W-K)R`]/B`G
M4TLG+`H@("`@)W-I)R`]/B`G4TQ/)RP*("`@("=S<B<@/3X@)U--12<L"B`@
M("`G<VXG(#T^("=33B<L"B`@("`G<V(G(#T^("=33TPG+`H@("`@)W-O)R`]
M/B`G4U`G+`H@("`@)W-T)R`]/B`G4U10)RP*("`@("=S9"<@/3X@)U-51"<L
M"B`@("`G<V,G(#T^("=362<L"B`@("`G<WDG(#T^("=365(G+`H@("`@)W1D
M)R`]/B`G5$-()RP*("`@("=T:"<@/3X@)U1(02<L"B`@("`G=&HG(#T^("=4
M2B<L"B`@("`G=&PG(#T^("=43"<L"B`@("`G=&TG(#T^("=432<L"B`@("`G
M=&XG(#T^("=43B<L"B`@("`G=&\G(#T^("=43R<L"B`@("`G='(G(#T^("=4
M4B<L"B`@("`G='0G(#T^("=45"<L"B`@("`G='8G(#T^("=4558G+`H@("`@
M)W5A)R`]/B`G54$G+`H@("`@)V%E)R`]/B`G54%%)RP*("`@("=U<R<@/3X@
M)U5302<L"B`@("`G=7HG(#T^("=56B<L"B`@("`G=F$G(#T^("=6)RP*("`@
M("=V;B<@/3X@)U9.)RP*("`@("=V=2<@/3X@)U95)RP*("`@("='32<@/3X@
M)U=!1R<L"B`@("`G<VPG(#T^("=704PG+`H@("`@)VYG)R`]/B`G5T%.)RP*
M("`@("=D;2<@/3X@)U=$)RP*("`@("=G9"<@/3X@)U=')RP*("`@("=L8R<@
M/3X@)U=,)RP*("`@("=W<R<@/3X@)U=3)RP*("`@("=V8R<@/3X@)U=6)RP*
M("`@("=Y92<@/3X@)UE!4B<L"B`@("`G=F4G(#T^("=95B<L"B`@("`G>FTG
M(#T^("=:)RP*("`@("=Z82<@/3X@)UI!)RP*("`@("=Z=R<@/3X@)UI7)PHI
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R]C;V]R9&EN871E<RYP:'``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<V-3,S-``Q,#0Q-S,V,C<W
M,0`P,C$W,S$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!L:7-T<R!T:&4@;&]C871I
M;VYS(&]F(&-I=&EE<R!A<F]U;F0@=&AE('=O<FQD+B!4:&4*("H@9F]R;6%T
M(&ES.@H@*@H@*B`@("1C;V]R9&EN871E<ULG8V]U;G1R>6YA;64G75LG;&%T
M.FQO;F<G72`]("=C:71Y;F%M92<["B`J"B`J($QA=&ET=61E(&%N9"!L;VYG
M:71U9&4@87)E(&1E8VEM86QS("AS;W5T:"!A;F0@=V5S="!A<F4@;F5G871I
M=F4I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].3%,O3DQ3+V-O;W)D:6YA
M=&5S+G!H<"QV(#$N,BXQ,BXS(#(P,#4O,3`O,3@@,3$Z,#$Z,3@@:F%N($5X
M<"`D"B`J"B`J($!P86-K86=E($AO<F1E7TY,4PH@*B\*"B1C;V]R9&EN871E
M<ULG069G:&%N:7-T86XG75LG,S$N,#`P.C8Q+C@U,"==(#T@)UIA<F%N:B<[
M"B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG,S(N,S8W.C8R+C$X,R==
M(#T@)T9A<F%H)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S,RXT
M,#`Z-C(N,C@S)UT@/2`G4VAI;F1A;F0G.PHD8V]O<F1I;F%T97-;)T%F9VAA
M;FES=&%N)UU;)S,T+C(Q-SHV,BXR,3<G72`]("=(97)A="<["B1C;V]R9&EN
M871E<ULG069G:&%N:7-T86XG75LG,S0N-#,S.C<P+C0V-R==(#T@)TIA;&%L
M86)A9"<["B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG,S0N-C,S.C8Y
M+C(P,"==(#T@)TMA8G5L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%F9VAA
M;FES=&%N)UU;)S,U+C$S,SHV.2XR-3`G72`]("=*86)U;"U387)A:B<["B1C
M;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG,S8N-3`P.C<Q+C(U,"==(#T@
M)UIE8F%K)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S-BXV-C<Z
M-C4N-S$W)UT@/2`G4VAE8FER9VAA;B<["B1C;V]R9&EN871E<ULG069G:&%N
M:7-T86XG75LG,S8N-S`P.C8W+C(P,"==(#T@)TUA>F%R+4DM4VAA<FEF)SL*
M)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S-RXQ,3<Z-S`N-3$W)UT@
M/2`G1F%I>F%B860G.PHD8V]O<F1I;F%T97-;)T%L8F%N:6$G75LG-#$N,S,S
M.C$Y+C<X,R==(#T@)U1I<F%N82<["B1C;V]R9&EN871E<ULG06QG97)I82==
M6R<R-"XU-3`Z.2XT-C<G72`]("=$:F%N970G.PHD8V]O<F1I;F%T97-;)T%L
M9V5R:6$G75LG,C8N-3`P.C@N-#$W)UT@/2`G26QL:7II)SL*)&-O;W)D:6YA
M=&5S6R=!;&=E<FEA)UU;)S(W+C8V-SHM."XQ,S,G72`]("=4:6YD;W5F)SL*
M)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S(W+C@X,SHM,"XR.#,G72`]("=!
M9')A<B<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<R."XP-3`Z.2XV,S,G
M72`]("=);B!!;65N87,G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,CDN
M,C4P.C`N,C@S)UT@/2`G5&EM:6UO=6XG.PHD8V]O<F1I;F%T97-;)T%L9V5R
M:6$G75LG,S`N-38W.C(N.#8W)UT@/2`G16P@1V]L96$G.PHD8V]O<F1I;F%T
M97-;)T%L9V5R:6$G75LG,S$N-C$W.BTR+C(S,R==(#T@)T)E8VAA<B<["B1C
M;V]R9&EN871E<ULG06QG97)I82==6R<S,2XV-C<Z-BXQ-3`G72`]("=(87-S
M:2U-97-S86]U9"<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S,2XY,3<Z
M-2XT,#`G72`]("=/=6%R9VQA)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;
M)S,R+C,X,SHS+C@Q-R==(#T@)T=H87)D86EA)SL*)&-O;W)D:6YA=&5S6R=!
M;&=E<FEA)UU;)S,S+C$Q-SHV+C$S,R==(#T@)U1O=6=G;W5R="<["B1C;V]R
M9&EN871E<ULG06QG97)I82==6R<S,RXU,#`Z-BXQ,3<G72`]("=%;"!/=65D
M)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,S+C<V-SHR+CDS,R==(#T@
M)TQA9VAO=6%T)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,T+C8X,SHS
M+C(U,"==(#T@)T1J96QF82<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S
M-"XX,#`Z-2XW,S,G72`]("=":7-K<F$G.PHD8V]O<F1I;F%T97-;)T%L9V5R
M:6$G75LG,S0N.3,S.BTP+C0S,R==(#T@)TUE8VAE<FEA)SL*)&-O;W)D:6YA
M=&5S6R=!;&=E<FEA)UU;)S,U+C`Q-SHM,2XT-C<G72`]("=4;&5M8V5N(%IE
M;F%T82<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-2XR,#`Z+3`N,3,S
M)UT@/2`G36%S8V%R82U':')I<W,G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G
M75LG,S4N,C4P.C$N-#,S)UT@/2`G5&EA<F5T)SL*)&-O;W)D:6YA=&5S6R=!
M;&=E<FEA)UU;)S,U+C,S,SHT+C(P,"==(#T@)T)O=2U386%D82<["B1C;V]R
M9&EN871E<ULG06QG97)I82==6R<S-2XT.#,Z."XQ,S,G72`]("=496)E<W-A
M)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,U+C4U,#HV+C$X,R==(#T@
M)T)A=&YA)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,U+C8S,SHM,"XV
M,#`G72`]("=/<F%N("\@17,@4V5N:6$G.PHD8V]O<F1I;F%T97-;)T%L9V5R
M:6$G75LG,S8N,3@S.C4N-#$W)UT@/2`G4V5T:68G.PHD8V]O<F1I;F%T97-;
M)T%L9V5R:6$G75LG,S8N,C$W.C$N,S,S)UT@/2`G0VAL968G.PHD8V]O<F1I
M;F%T97-;)T%L9V5R:6$G75LG,S8N,C@S.C8N-C$W)UT@/2`G0V]N<W1A;G1I
M;F4G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S8N-S$W.C,N,C4P)UT@
M/2`G1&%R+45L+4)E:61A)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,V
M+C<Q-SHU+C`V-R==(#T@)T)E:F%I82<["B1C;V]R9&EN871E<ULG06QG97)I
M82==6R<S-BXX,S,Z-RXX,3<G72`]("=!;FYA8F$G.PHD8V]O<F1I;F%T97-;
M)T%L9V5R:6$G75LG,S8N.#@S.C4N.#$W)UT@/2`G2FEJ96P@06-H;W5A="<[
M"B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-BXY,S,Z-BXY-3`G72`]("=3
M:VEK9&$G.PHD8V]O<F1I;F%T97-;)T%N9V]L82==6R<M,3(N,S@S.C$V+CDU
M,"==(#T@)T)I92!3:6QV82!0;W)T;R<["B1C;V]R9&EN871E<ULG06YG;VQA
M)UU;)RTQ,BXU.#,Z,3,N-#$W)UT@/2`G36]N8F%C82!"96YG=65L82<["B1C
M;V]R9&EN871E<ULG06YG;VQA)UU;)RTQ,BXX,#`Z,34N-S4P)UT@/2`G2'5A
M;6)O($YO=F$@3&ES8F]A)SL*)&-O;W)D:6YA=&5S6R=!;F=O;&$G75LG+34N
M-34P.C$R+C$X,R==(#T@)T-A8FEN9&$G.PHD8V]O<F1I;F%T97-;)T%N9V]L
M82==6R<M."XX-3`Z,3,N,C,S)UT@/2`G3'5A;F1A)SL*)&-O;W)D:6YA=&5S
M6R=!;G1A<F-T:6-A)UU;)RTW-RXX-C<Z,38V+CDV-R==(#T@)U=I;&QI86US
M($9I96QD)SL*)&-O;W)D:6YA=&5S6R=!;G1A<F-T:6-A)UU;)RTY,"XP,#`Z
M,"XP,#`G72`]("=!;75N9'-E;BU38V]T="!3;W5T:"!0;VQE(%-T871I;VXG
M.PHD8V]O<F1I;F%T97-;)T%N=&EG=6$@86YD($)A<F)U9&$G75LG,3<N,3$W
M.BTV,2XW.#,G72`]("=68R!":7)D($EN=&5R;F%T:6]N86P@06ER<&]R="!!
M;G1I9W5A)SL*)&-O;W)D:6YA=&5S6R=!;G1I9W5A(&%N9"!"87)B=61A)UU;
M)S$W+C(P,#HM-C(N-3@S)UT@/2`G0VAA<FQE<W1O=VX@+R!.97=C87-T)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(R+C$P,#HM-C4N-C`P)UT@
M/2`G3&$@475I86-A($]B<V5R=F%T;W)I;R<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTR,BXV-3`Z+38S+C@Q-R==(#T@)U1A<G1A9V%L($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR,RXQ-3`Z+38T
M+C,Q-R==(#T@)T]R86X@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3(T+C$V-SHM-C(N.3`P)UT@/2`G4FEV861A=FEA)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(T+C,X,SHM-C4N,#@S)UT@/2`G
M2G5J=7D@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+3(T+C<P,#HM-C`N-3@S)UT@/2`G3&%S($QO;6ET87,G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,C0N.#4P.BTV-2XT.#,G72`]("=386QT82!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C4N-S,S
M.BTU-"XT-C<G72`]("=)9W5A>G4@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+3(V+C(P,#HM-3@N,C,S)UT@/2`G1F]R;6]S82!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C8N.#$W
M.BTV,"XT-3`G72`]("=0<F5S:61E;F-I82!2;W%U92!3865N>B!096YA($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-BXX-3`Z
M+38U+C$P,"==(#T@)U1U8W5M86X@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+3(W+C,V-SHM-34N.38W)UT@/2`G4&]S861A<R!!
M97)O+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-RXT-3`Z+34X
M+C<V-R==(#T@)T-O<G)I96YT97,@065R;RXG.PHD8V]O<F1I;F%T97-;)T%R
M9V5N=&EN82==6R<M,C<N-#4P.BTU.2XP-3`G72`]("=297-I<W1E;F-I82!!
M97)O+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-RXW-C<Z+38T
M+C,P,"==(#T@)U-A;G1I86=O($1E;"!%<W1E<F\@065R;RXG.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M,C@N,#8W.BTV-RXU-C<G72`]("=4:6YO
M9V%S=&$G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C@N-C`P.BTV
M-2XW-C<G72`]("=#871A;6%R8V$@065R;RXG.PHD8V]O<F1I;F%T97-;)T%R
M9V5N=&EN82==6R<M,CDN,C$W.BTV-RXT,S,G72`]("=#:&EL96-I=&\G.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,CDN,S@S.BTV-BXX,3<G72`]
M("=,82!2:6]J82!!97)O+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;
M)RTR.2XV.#,Z+34W+C$U,"==(#T@)U!A<V\@1&4@3&]S($QI8G)E<R!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,CDN-S@S.BTU
M-RXY.#,G72`]("=#=7)U>G4@0W5A=&EA($%E<F]D<F]M92<["B1C;V]R9&EN
M871E<ULG07)G96YT:6YA)UU;)RTR.2XX.#,Z+38Q+CDU,"==(#T@)T-E<F5S
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR.2XY
M,#`Z+38S+C8X,R==(#T@)U9I;&QA($1E($UA<FEA($1E;"!2:6\@4V5C;R<[
M"B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,"XR-3`Z+38X+C<U,"==
M(#T@)TIA8VAA;"<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,"XR
M-C<Z+34W+C8U,"==(#T@)TUO;G1E($-A<V5R;W,@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C,P,#HM-3@N,#$W)UT@/2`G
M0V]N8V]R9&EA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTS,2XS,3<Z+38T+C(Q-R==(#T@)T-O<F1O8F$@065R;V1R;VUE)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C,S,SHM-C8N-C`P)UT@
M/2`G0VAE<&5S)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C4V
M-SHM-C@N.#8W)UT@/2`G4V%N($IU86X@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C8V-SHM-C,N.#@S)UT@/2`G4&EL87(@
M3V)S97)V871O<FEO)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q
M+C<P,#HM-C`N.#$W)UT@/2`G4V%U8V4@5FEE:F\@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C<X,SHM-C`N-#@S)UT@/2`G
M4&%R86YA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;
M)RTS,2XX-3`Z+34Y+C`X,R==(#T@)U9I;&QA9W5A>2!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N.34P.BTV-2XQ,S,G72`]
M("=6:6QL82!$;VQO<F5S($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTS,BXV,#`Z+38Y+C,S,R==(#T@)U5S<&%L;&%T82<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,BXW,#`Z+38R+C$U,"==(#T@
M)TUA<F-O<R!*=6%R97H@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3,R+C@S,SHM-C@N-S@S)UT@/2`G365N9&]Z82!!97)O9')O
M;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S(N.3$W.BTV,"XW
M.#,G72`]("=2;W-A<FEO($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTS,RXP,#`Z+34X+C8Q-R==(#T@)T=U86QE9W5A>6-H=2!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S,N,#@S
M.BTV."XT,3<G72`]("=386X@36%R=&EN)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3,S+C$Q-SHM-C0N,C,S)UT@/2`G4FEO($-U87)T;R!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S,N,C8W.BTV
M-BXS-3`G72`]("=386X@3'5I<R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;
M)T%R9V5N=&EN82==6R<M,S,N-S,S.BTV-2XS.#,G72`]("=6:6QL82!297EN
M;VQD<R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,S,N-S8W.BTV.2XP,S,G72`]("=386X@0V%R;&]S)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+3,T+C$S,SHM-C,N,S8W)UT@/2`G3&%B;W5L87EE
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,T+C0X,SHM-3@N-C$W
M)UT@/2`G1&]N(%1O<F-U871O($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTS-"XU-3`Z+38P+CDQ-R==(#T@)TIU;FEN($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-"XU-C<Z+34X
M+C0Q-R==(#T@)T%E<F]P87)Q=64@0G,N($%S+B!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S0N-3@S.BTU."XT.#,G72`]("="
M=65N;W,@06ER97,@3V)S97)V871O<FEO)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3,T+C4X,SHM-C@N-#`P)UT@/2`G4V%N(%)A9F%E;"!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S0N-C`P.BTU
M."XV,#`G72`]("=%;"!086QO;6%R($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTS-"XX,3<Z+34X+C4S,R==(#T@)T5Z96EZ82!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S0N.38W
M.BTU-RXY,#`G72`]("=,82!0;&%T82!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S4N-3`P.BTV.2XU.#,G72`]("=-86QA<F=U
M92!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S4N
M-S`P.BTV,RXW-3`G72`]("='96YE<F%L(%!I8V\@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,U+C@V-SHM-C$N.3`P)UT@/2`G
M4&5H=6%J;R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,S8N,S4P.BTU-RXW,S,G72`]("=$;VQO<F5S($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-BXU-C<Z+38T+C(V-R==(#T@
M)U-A;G1A(%)O<V$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I
M;F$G75LG+3,V+C<U,#HM-3DN.#,S)UT@/2`G07IU;"!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,W+C(S,SHM-3<N,#,S)UT@/2`G
M5FEL;&$@1V5S96QL)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,W
M+C(S,SHM-3DN,C4P)UT@/2`G5&%N9&EL($%E<F]D<F]M92<["B1C;V]R9&EN
M871E<ULG07)G96YT:6YA)UU;)RTS-RXV,#`Z+38R+C,X,R==(#T@)U!I9W5E
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-RXY
M,S,Z+34W+C4X,R==(#T@)TUA<B!$96P@4&QA=&$@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,X+C,S,SHM-C`N,C4P)UT@/2`G
M5')E<R!!<G)O>6]S)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,X
M+C<S,SHM-C(N,38W)UT@/2`G0F%H:6$@0FQA;F-A($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS."XY-3`Z+38X+C$S,R==(#T@
M)TYE=7%U96X@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G
M75LG+3,Y+C`Q-SHM-C0N,#@S)UT@/2`G4FEO($-O;&]R861O)SL*)&-O;W)D
M:6YA=&5S6R=!<F=E;G1I;F$G75LG+30P+C`X,SHM-S$N,3,S)UT@/2`G0VAA
M<&5L8V\G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#`N-S@S.BTV
M-2XQ,#`G72`]("=386X@06YT;VYI;R!/97-T92!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#`N.#4P.BTV,RXP,3<G72`]("=6
M:65D;6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+30Q+C$U,#HM-S$N,38W)UT@/2`G0F%R:6QO8VAE($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT,2XY-C<Z+3<Q+C4Q-R==(#T@
M)T5L($)O;'-O;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN
M82==6R<M-#(N.3,S.BTW,2XQ-3`G72`]("=%<W%U96P@065R;V1R;VUE)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30S+C(P,#HM-C4N,C8W)UT@
M/2`G5')E;&5W($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTT,RXX,3<Z+38X+C@X,R==(#T@)U!A<V\@1&4@26YD:6]S)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30U+C<X,SHM-C<N-3`P)UT@/2`G
M0V]M;V1O<F\@4FEV861A=FEA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTT-BXU,3<Z+3<Q+C`Q-R==(#T@)U!E<FET;R!-;W)E
M;F\@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30W
M+C<S,SHM-C4N.3$W)UT@/2`G4'5E<G1O($1E<V5A9&\@065R;V1R;VUE)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30X+C<X,SHM-S`N,38W)UT@
M/2`G1V]B97)N861O<B!'<F5G;W)E<R!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M-#DN,S$W.BTV-RXW-3`G72`]("=386X@2G5L
M:6%N($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTU
M,"XP,3<Z+38X+C4V-R==(#T@)U-A;G1A($-R=7H@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+34P+C,S,SHM-S(N,S`P)UT@/2`G
M3&%G;R!!<F=E;G1I;F\@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+34Q+C8Q-SHM-CDN,C@S)UT@/2`G4FEO($=A;&QE9V]S($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTU,RXX,#`Z
M+38W+C<U,"==(#T@)U)I;R!'<F%N9&4@0BX@02XG.PHD8V]O<F1I;F%T97-;
M)T%R9V5N=&EN82==6R<M-30N.#`P.BTV."XS,3<G72`]("=5<VAU86EA($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)M96YI82==6R<T,"XQ,S,Z-#0N
M-#8W)UT@/2`G665R979A;B<["B1C;V]R9&EN871E<ULG07)U8F$G75LG,3(N
M-3`P.BTW,"XP,3<G72`]("=1=65E;B!"96%T<FEX($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,3(N,C8W.C$S-BXX,3<G72`]("='
M;W9E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,3(N
M-#`P.C$S,"XX-C<G72`]("=$87)W:6X@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTQ,BXV,S,Z,30Q+C@X,R==(#T@)U=E:7!A($-I
M='DG.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,34N-S8W.C$R."XW
M,#`G72`]("=+=6YU;G5R<F$@2W5N=6YU<G)A($%W<R<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTQ-BXX.#,Z,30U+C<U,"==(#T@)T-A:7)N<R!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3$W+C,P,#HQ
M,C,N-C$W)UT@/2`G1&5R8GDG.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,3<N.34P.C$R,BXR,3<G72`]("="<F]O;64@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTQ.2XR-3`Z,30V+C<U,"==(#T@)U1O
M=VYS=FEL;&4@06UO)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3$Y
M+C8S,SHQ,S0N,38W)UT@/2`G5&5N;F%N="!#<F5E:R!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(P+C$P,#HQ,3DN-38W)UT@/2`G
M4&]R="!(961L86YD(%!A<F1O;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA
M)UU;)RTR,"XT.#,Z,30X+C4S,R==(#T@)U!R;W-E<G!I;F4@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR,"XV-C<Z,3,Y+C0V-R==
M(#T@)TUO=6YT($ES82!!;6\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,C$N,3$W.C$T.2XR,#`G72`]("=-86-K87D@36\G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,C(N,C,S.C$Q-"XP.#,G72`]("=,96%R;6]N
M=&@@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR,RXS
M.#,Z,34P+C0V-R==(#T@)U)O8VMH86UP=&]N($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,C,N-#,S.C$T-"XR-C<G72`]("=,;VYG
M<F5A8V@@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR
M,RXX,#`Z,3,S+C@X,R==(#T@)T%L:6-E(%-P<FEN9W,@065R;V1R;VUE)SL*
M)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(S+C@U,#HQ-3$N,C4P)UT@
M/2`G1VQA9'-T;VYE)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(U
M+C$X,SHQ,S`N.38W)UT@/2`G675L87)A($%W<R<["B1C;V]R9&EN871E<ULG
M075S=')A;&EA)UU;)RTR-BXT,#`Z,30V+C(V-R==(#T@)T-H87)L979I;&QE
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C8N-C`P
M.C$Q."XU,S,G72`]("=-965K871H87)R82!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<F%L:6$G75LG+3(W+C,X,SHQ-3,N,3`P)UT@/2`G0G)I<V)A
M;F4@06ER<&]R="!-+B!/)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG
M+3(W+C0Q-SHQ-3$N-S,S)UT@/2`G3V%K97D@065R;V1R;VUE)SL*)&-O;W)D
M:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(W+C4V-SHQ-3,N,#`P)UT@/2`G07)C
M:&5R9FEE;&0@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+3(W+C8S,SHQ-3(N-S$W)UT@/2`G06UB97)L97D@065R;V1R;VUE)SL*
M)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(X+C$V-SHQ-3,N-3`P)UT@
M/2`G0V]O;&%N9V%T=&$@06ER<&]R="!!=W,G.PHD8V]O<F1I;F%T97-;)T%U
M<W1R86QI82==6R<M,C@N-S@S.C$Q-"XW,#`G72`]("='97)A;&1T;VX@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR.2XP,S,Z,38W
M+CDS,R==(#T@)TYO<F9O;&L@27-L86YD($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,S`N,S$W.C$U,RXQ,3<G72`]("=#;V9F<R!(
M87)B;W5R($UO)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,P+C4X
M,SHQ,S@N-#$W)UT@/2`G3&5I9V@@0W)E96L@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG075S=')A;&EA)UU;)RTS,"XW.#,Z,3(Q+C0U,"==(#T@)TMA;&=O
M;W)L:64@0F]U;&1E<B!!;6\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,S`N.#,S.C$R."XQ,#`G72`]("=&;W)R97-T($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S$N,#@S.C$U,"XX,S,G72`]("=4
M86UW;W)T:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG
M+3,Q+C$S,SHQ,S8N.#$W)UT@/2`G5V]O;65R82!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S$N-C8W.C$Q-BXP,3<G72`]("="
M=6QL<V)R;V]K(%!E87)C92!!;6\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI
M82==6R<M,S$N.3,S.C$Q-2XY-3`G72`]("="96QM;VYT(%!E<G1H($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S$N.38W.C$T,2XT
M-C<G72`]("="<F]K96X@2&EL;"!0871T;VX@4W1R965T)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<F%L:6$G75LG+3,R+C$Q-SHQ,S,N-S`P)UT@/2`G0V5D=6YA
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S(N,C`P
M.C$T."XU-C<G72`]("=$=6)B;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA
M)UU;)RTS,BXW.#,Z,34Q+C@Q-R==(#T@)U=I;&QI86UT;W=N($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,RXV,#`Z,34P+C<X
M,R==(#T@)U)I8VAM;VYD($%U<RU!9F(G.PHD8V]O<F1I;F%T97-;)T%U<W1R
M86QI82==6R<M,S,N.3$W.C$U,"XY.#,G72`]("="86YK<W1O=VX@06ER<&]R
M="!!=W,G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S,N.34P.C$U
M,2XQ.#,G72`]("=3>61N97D@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S
M=')A;&EA)UU;)RTS-"XP,S,Z,34P+C8X,R==(#T@)T-A;61E;B!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,T+C(Q-SHQ-#(N,#@S
M)UT@/2`G36EL9'5R82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L
M:6$G75LG+3,T+C<P,#HQ,S@N-C$W)UT@/2`G161I;F)U<F=H($TN($\N)SL*
M)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,T+C<X,SHQ,S@N-C,S)UT@
M/2`G4&%R869I96QD($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI
M82==6R<M,S0N.3,S.C$Q-RXX,#`G72`]("=!;&)A;GD@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-"XY,S,Z,3,X+C4Q-R==(#T@
M)T%D96QA:61E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,S0N.34P.C$U,"XU,S,G72`]("=.;W=R82!286X@06ER(%-T871I;VXG
M.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S4N,34P.C$T-RXT-3`G
M72`]("=786=G82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+3,U+C,P,#HQ-#DN,3@S)UT@/2`G0V%N8F5R<F$G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,S8N,#8W.C$T-BXY-3`G72`]("=!;&)U<GD@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-BXR,S,Z
M,30Y+C`X,R==(#T@)T-O;VUA)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+3,W+C8V-SHQ-#0N.#,S)UT@/2`G365L8F]U<FYE($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S<N-S,S.C$T,"XW.#,G72`]
M("=-;W5N="!'86UB:65R($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG075S
M=')A;&EA)UU;)RTS-RXW,S,Z,30U+C0P,"==(#T@)T=O;&1S=')E86T@07=S
M)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,W+C@U,#HQ-#0N-S,S
M)UT@/2`G3&%V97)T;VX@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+3,W+CDV-SHQ-#4N,3`P)UT@/2`G36]O<F%B8FEN($%I<G!O
M<G0@07=S)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,X+C$P,#HQ
M-#<N,3,S)UT@/2`G16%S="!386QE($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTT,"XY.#,Z,30U+C<Q-R==(#T@)U=Y;GEA<F0@
M5V5S="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTT,2XQ-C<Z,30V
M+C,V-R==(#T@)T1E=F]N<&]R="!%87-T)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+30Q+C4S,SHQ-#<N,C`P)UT@/2`G3&%U;F-E<W1O;B!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+30R+C@S,SHQ-#<N
M-#@S)UT@/2`G2&]B87)T($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R
M86QI82==6R<M-30N-#@S.C$U."XY-3`G72`]("=-86-Q=6%R:64@27-L86YD
M)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0V+C8U,#HQ-"XS,S,G72`]
M("=+;&%G96YF=7)T+49L=6=H869E;B<["B1C;V]R9&EN871E<ULG075S=')I
M82==6R<T-RXP,#`Z,34N-#,S)UT@/2`G1W)A>BU4:&%L97)H;V8M1FQU9VAA
M9F5N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0W+C(P,#HQ-"XW-3`G
M72`]("=:96QT=V5G)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0W+C(V
M-SHQ,2XS-3`G72`]("=);FYS8G)U8VLM1FQU9VAA9F5N)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<FEA)UU;)S0W+C,S,SHQ,2XW,#`G72`]("=38VAW87H@2&5L
M:7!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#<N-3,S.C$T+C$S
M,R==(#T@)T%I9V5N($EM($5N;G-T86PG.PHD8V]O<F1I;F%T97-;)T%U<W1R
M:6$G75LG-#<N.#`P.C$S+C`P,"==(#T@)U-A;'IB=7)G+49L=6=H869E;B<[
M"B1C;V]R9&EN871E<ULG075S=')I82==6R<T-RXY-C0Z,38N,C4Y)UT@/2`G
M3FEE9&5R;W-T97)R96EC:"`O($QU9W!L871Z("!6;W-L874G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R:6$G75LG-#@N,3$W.C$V+C4V-R==(#T@)U=I96X@+R!3
M8VAW96-H870M1FQU9VAA9F5N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;
M)S0X+C(S,SHQ-"XQ.#,G72`]("=(;W)S8VAI;F<@075S+4%F8B<["B1C;V]R
M9&EN871E<ULG075S=')I82==6R<T."XR,S,Z,30N,3@S)UT@/2`G3&EN>B`O
M($AO97)S8VAI;F<M1FQU9VAA9F5N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA
M)UU;)S0X+C,Q-SHQ-BXQ,3<G72`]("=4=6QL;B<["B1C;V]R9&EN871E<ULG
M07IE<F)A:6IA;B==6R<T,"XT-3`Z-3`N,#8W)UT@/2`G0F%K=2`O($)I;F4@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG0F%H86UA<R==6R<R,"XY-3`Z+3<S
M+C8X,R==(#T@)TUA='1H97<@5&]W;BP@26YA9W5A)SL*)&-O;W)D:6YA=&5S
M6R="86AA;6%S)UU;)S(S+C0W-3HM-S4N-S8W)UT@/2`G1V5O<F=E=&]W;BP@
M17AU;6$G.PHD8V]O<F1I;F%T97-;)T)A:&%M87,G75LG,C0N,#4P.BTW-"XU
M,S,G72`]("=#;V-K8G5R;B!4;W=N+"!386X@4V%L=F%D;W(G.PHD8V]O<F1I
M;F%T97-;)T)A:&%M87,G75LG,C4N,#4P.BTW-RXT-C<G72`]("=.87-S874@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG0F%H86UA<R==6R<R-2XW,S,Z+3<Y
M+C,P,"==(#T@)T%L:6-E(%1O=VXL($)I;6EN:2<["B1C;V]R9&EN871E<ULG
M0F%H86UA<R==6R<R-BXU-3`Z+3<X+C<P,"==(#T@)T9R965P;W)T+"!'<F%N
M9"!"86AA;6$G.PHD8V]O<F1I;F%T97-;)T)A:&%M87,G75LG,C8N-S`P.BTW
M."XY-C<G72`]("=797-T($5N9"P@1W)A;F0@0F%H86UA)SL*)&-O;W)D:6YA
M=&5S6R="86AR86EN)UU;)S(V+C(V-SHU,"XV-3`G72`]("="86AR86EN($EN
M=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG0F%N9VQA9&5S
M:"==6R<R,2XT,S,Z.3$N.38W)UT@/2`G0V]X7"=S($)A>F%R)SL*)&-O;W)D
M:6YA=&5S6R="86YG;&%D97-H)UU;)S(R+C(V-SHY,2XX,3<G72`]("=#:&ET
M=&%G;VYG(%!A=&5N9V$G.PHD8V]O<F1I;F%T97-;)T)A;F=L861E<V@G75LG
M,C,N,3@S.C@Y+C$V-R==(#T@)TIE<W-O<F4G.PHD8V]O<F1I;F%T97-;)T)A
M;F=L861E<V@G75LG,C,N-S8W.CDP+C,X,R==(#T@)T1H86MA)SL*)&-O;W)D
M:6YA=&5S6R="86YG;&%D97-H)UU;)S(S+C@U,#HY,"XT,#`G72`]("=+=7)M
M:71O;&$L($1I82<["B1C;V]R9&EN871E<ULG0F%N9VQA9&5S:"==6R<R-"XQ
M,S,Z.#DN,#4P)UT@/2`G27-H=7)D:2<["B1C;V]R9&EN871E<ULG0F%N9VQA
M9&5S:"==6R<R-"XS-C<Z.#@N-S`P)UT@/2`G4F%J<VAA:&DG.PHD8V]O<F1I
M;F%T97-;)T)A;F=L861E<V@G75LG,C0N.3`P.CDQ+C@X,R==(#T@)U-Y;&AE
M="<["B1C;V]R9&EN871E<ULG0F%R8F%D;W,G75LG,3,N,#8W.BTU.2XT.#,G
M72`]("='<F%N=&QE>2!!9&%M<R<["B1C;V]R9&EN871E<ULG0F5L87)U<R==
M6R<U,RXY,S,Z,C<N-C,S)UT@/2`G36EN<VLG.PHD8V]O<F1I;F%T97-;)T)E
M;&%R=7,G75LG-34N,38W.C,P+C(Q-R==(#T@)U9I=&5B<VLG.PHD8V]O<F1I
M;F%T97-;)T)E;&=I=6TG75LG-#DN.3`P.C4N,C$W)UT@/2`G0F5R=')I>"!"
M96PM069B)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C`S,SHU+C0P
M,"==(#T@)U-T+4AU8F5R="<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U
M,"XR,S,Z-"XV-3`G72`]("=&;&]R96YN97,G.PHD8V]O<F1I;F%T97-;)T)E
M;&=I=6TG75LG-3`N-#8W.C0N-#4P)UT@/2`G0VAA<FQE<F]I("\@1V]S<V5L
M:65S)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C0V-SHV+C$X,R==
M(#T@)T5L<V5N8F]R;B<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XT
M.#,Z-2XY,3<G72`]("=3<&$@+R!,82!3875V96YI97)E)SL*)&-O;W)D:6YA
M=&5S6R="96QG:75M)UU;)S4P+C4V-SHS+C@S,R==(#T@)T-H:65V<F5S)SL*
M)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C8U,#HU+C0U,"==(#T@)T)I
M97)S970G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N-S4P.C0N-S8W
M)UT@/2`G0F5A=79E8VAA:6XG.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG
M-3`N-S@S.C0N.34P)UT@/2`G1V]E='-E;FAO=F5N)SL*)&-O;W)D:6YA=&5S
M6R="96QG:75M)UU;)S4P+C@P,#HU+C(P,"==(#T@)U-I;G0M5')U:61E;B<[
M"B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XY,#`Z-"XU,#`G72`]("=-
M96QS8G)O96L@0F5L+4%F8B<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U
M,"XY,#`Z-"XU,S,G72`]("="<G5X96QL97,@3F%T:6]N86PG.PHD8V]O<F1I
M;F%T97-;)T)E;&=I=6TG75LG-3`N.3,S.C,N-S,S)UT@/2`G375N=&4G.PHD
M8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N.3,S.C4N-3`P)UT@/2`G1V5N
M:R<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,2XP,#`Z-2XP-C<G72`]
M("=38VAA9F9E;B<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,2XP.#,Z
M,BXV-3`G72`]("=+;VMS:6ID92<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==
M6R<U,2XQ-C<Z-2XT-C<G72`]("=+;&5I;F4@0G)O9V5L)SL*)&-O;W)D:6YA
M=&5S6R="96QG:75M)UU;)S4Q+C$X,SHS+C@Q-R==(#T@)T=E;G0@+R!);F1U
M<W1R:64M6F]N92<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,2XR,#`Z
M,BXX-C<G72`]("=/;W-T96YD92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="
M96QG:75M)UU;)S4Q+C(P,#HT+C0V-R==(#T@)T%N='=E<G!E;B`O($1E=7)N
M92<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,2XS,S,Z-"XU,#`G72`]
M("="<F%S<V-H86%T)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C0Q
M-SHU+C`P,"==(#T@)U=E96QD92!-:6QI=&%R>2<["B1C;V]R9&EN871E<ULG
M0F5L:7IE)UU;)S$W+C4S,SHM.#@N,S`P)UT@/2`G0F5L:7IE("\@4&AI;&QI
M<"!';VQD<W1O;B!);G1L+B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="96YI
M;B==6R<Q,"XS,3<Z,2XS.#,G72`]("=.871I=&EN9V]U)SL*)&-O;W)D:6YA
M=&5S6R="96YI;B==6R<Q,2XQ,S,Z,BXY,S,G72`]("=+86YD:2<["B1C;V]R
M9&EN871E<ULG0F5N:6XG75LG-BXS-3`Z,BXS.#,G72`]("=#;W1O;F]U)SL*
M)&-O;W)D:6YA=&5S6R="96YI;B==6R<W+C$V-SHR+C`V-R==(#T@)T)O:&EC
M;VXG.PHD8V]O<F1I;F%T97-;)T)E;FEN)UU;)S@N,#,S.C(N-#8W)UT@/2`G
M4V%V92<["B1C;V]R9&EN871E<ULG0F5N:6XG75LG.2XS-3`Z,BXV,3<G72`]
M("=087)A:V]U)SL*)&-O;W)D:6YA=&5S6R="97)M=61A)UU;)S,R+C,V-SHM
M-C0N-C@S)UT@/2`G0F5R;75D82<["B1C;V]R9&EN871E<ULG0F]L:79I82==
M6R<M,3`N.#$W.BTV-2XS-3`G72`]("='=6%Y87)A;65R:6XG.PHD8V]O<F1I
M;F%T97-;)T)O;&EV:6$G75LG+3$Q+C`P,#HM-C8N,3$W)UT@/2`G4FEB97)A
M;'1A)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ,2XP,S,Z+38X+C<X
M,R==(#T@)T-O8FEJ82<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3,N
M,#8W.BTV-"XX,3<G72`]("=386X@2F]A<75I;B<["B1C;V]R9&EN871E<ULG
M0F]L:79I82==6R<M,3,N,S,S.BTV-"XQ,3<G72`]("=-86=D86QE;F$G.PHD
M8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$S+C<V-SHM-C4N-#,S)UT@/2`G
M4V%N=&$@06YA)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-"XS,3<Z
M+38W+C,X,R==(#T@)U)E>65S)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;
M)RTQ-"XT-C<Z+38W+C4V-R==(#T@)U)U<G)E;F%B87%U92<["B1C;V]R9&EN
M871E<ULG0F]L:79I82==6R<M,30N-S,S.BTV."XU,#`G72`]("=!<&]L;R<[
M"B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,30N.#$W.BTV-"XY,3<G72`]
M("=4<FEN:61A9"<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,30N.#8W
M.BTV-BXX-C<G72`]("=386X@0F]R:F$G.PHD8V]O<F1I;F%T97-;)T)O;&EV
M:6$G75LG+3$T+CDQ-SHM-C4N-C`P)UT@/2`G4V%N($EG;F%C:6\@1&4@36]X
M;W,G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$U+C<Q-SHM-C,N,3`P
M)UT@/2`G07-C96YC:6]N($1E($=U87)A>6]S)SL*)&-O;W)D:6YA=&5S6R="
M;VQI=FEA)UU;)RTQ-BXQ-3`Z+38R+C`Q-R==(#T@)T-O;F-E<&-I;VXG.PHD
M8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$V+C(V-SHM-C(N-#8W)UT@/2`G
M4V%N($IA=FEE<B<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,38N,S@S
M.BTV,"XY-C<G72`]("=386X@26=N86-I;R!$92!696QA<V-O)SL*)&-O;W)D
M:6YA=&5S6R=";VQI=FEA)UU;)RTQ-BXU,3<Z+38X+C$X,R==(#T@)TQA(%!A
M>B`O($%L=&\G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$W+C0Q-SHM
M-C8N,3@S)UT@/2`G0V]C:&%B86UB82<["B1C;V]R9&EN871E<ULG0F]L:79I
M82==6R<M,3<N-3@S.BTV.2XV,#`G72`]("=#:&%R86YA)SL*)&-O;W)D:6YA
M=&5S6R=";VQI=FEA)UU;)RTQ-RXV,S,Z+38S+C$S,R==(#T@)U9I<G4M5FER
M=2<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3<N.#`P.BTV,"XW,S,G
M72`]("=386X@2F]S92!$92!#:&EQ=6ET;W,G.PHD8V]O<F1I;F%T97-;)T)O
M;&EV:6$G75LG+3$W+C@P,#HM-C,N,3@S)UT@/2`G4V%N=&$@0W)U>B`O($5L
M(%1R;VUP:6QL;R<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3<N.38W
M.BTV-RXP-C<G72`]("=/<G5R;R<["B1C;V]R9&EN871E<ULG0F]L:79I82==
M6R<M,3@N,S$W.BTU.2XW-C<G72`]("=2;V)O<F4G.PHD8V]O<F1I;F%T97-;
M)T)O;&EV:6$G75LG+3$X+CDX,SHM-3<N.#$W)UT@/2`G4'5E<G1O(%-U87)E
M>B<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3DN,#$W.BTV-2XS,#`G
M72`]("=3=6-R92<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3DN-34P
M.BTV-2XW,S,G72`]("=0;W1O<VDG.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G
M75LG+3(P+C`P,#HM-C,N-3,S)UT@/2`G0V%M:7)I)SL*)&-O;W)D:6YA=&5S
M6R=";VQI=FEA)UU;)RTR,2XR-3`Z+38S+C0U,"==(#T@)U9I;&QA;6]N=&5S
M)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTR,2XU-3`Z+38T+C<P,"==
M(#T@)U1A<FEJ82<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,C$N.34P
M.BTV,RXV-3`G72`]("=986-U:6)A)SL*)&-O;W)D:6YA=&5S6R=";W-N:6$@
M86YD($AE<GIE9V]V:6YA)UU;)S0S+C@S,SHQ-RXP,3<G72`]("=,:79N;R<[
M"B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3$W+C@Q-SHR-2XQ-3`G72`]
M("=+87-A;F4G.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;)RTQ."XS-C<Z
M,C$N.#4P)UT@/2`G4VAA:V%W92<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G
M75LG+3$Y+CDX,SHR,RXT,3<G72`]("=-875N)SL*)&-O;W)D:6YA=&5S6R="
M;W1S=V%N82==6R<M,C`N-#8W.C(U+CDX,R==(#T@)U-U82U086XG.PHD8V]O
M<F1I;F%T97-;)T)O='-W86YA)UU;)RTR,2XR,3<Z,C<N-3`P)UT@/2`G1G)A
M;F-I<W1O=VXG.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;)RTR,2XT,3<Z
M,C4N-C`P)UT@/2`G3&5T;&AA:V%N92<["B1C;V]R9&EN871E<ULG0F]T<W=A
M;F$G75LG+3(Q+C<P,#HR,2XV-3`G72`]("=':&%N>FDG.PHD8V]O<F1I;F%T
M97-;)T)O='-W86YA)UU;)RTR-"XP,3<Z,C$N.#@S)UT@/2`G5'-H86YE)SL*
M)&-O;W)D:6YA=&5S6R=";W1S=V%N82==6R<M,C0N,C$W.C(U+CDQ-R==(#T@
M)U-E<F5T<V4@2VAA;6$@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=";W1S=V%N82==6R<M,C0N-C`P.C(T+C8V-R==(#T@)TIW86YE
M;F<G.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;)RTR-BXP-3`Z,C(N-#4P
M)UT@/2`G5'-A8F]N9R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)S`N,#,S
M.BTU,"XP-3`G72`]("=-86-A<&$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,"XQ,S,Z+38W+C`X,R==(#T@)U-A;R!'86)R:65L($1A($-A8VAO96ER
M82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)S`N-C$W.BTV.2XR,#`G72`]
M("=)875A<F5T92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTP+CDX,SHM
M-C(N-3@S)UT@/2`G0F%R8V5L;W,G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,2XS.#,Z+30X+C0X,R==(#T@)T)E;&5M($%E<F]P;W)T;R<["B1C;V]R
M9&EN871E<ULG0G)A>FEL)UU;)RTQ,"XP,#`Z+38W+C@P,"==(#T@)U)I;R!"
M<F%N8V\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3`N-S`P.BTT."XT
M,#`G72`]("=0;W)T;R!.86-I;VYA;"!!97)O<&]R=&\G.PHD8V]O<F1I;F%T
M97-;)T)R87II;"==6R<M,3`N.3@S.BTS-RXP-C<G72`]("=!<F%C86IU($%E
M<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ,BXW,#`Z+38P
M+C$P,"==(#T@)U9I;&AE;F$@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3$R+CDP,#HM,S@N,S,S)UT@/2`G4V%L=F%D;W(@065R;W!O
M<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$S+C(V-SHM-#,N-#$W
M)UT@/2`G0F]M($IE<W5S($1A($QA<&$G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,30N-S`P.BTU,BXS-3`G72`]("=8879A;G1I;F$G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,30N.#$W.BTS.2XP,S,G72`]("=);&AE=7,@
M065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$T+CDU,#HM
M-#`N.#@S)UT@/2`G5FET;W)I82!$82!#;VYQ=6ES=&$G.PHD8V]O<F1I;F%T
M97-;)T)R87II;"==6R<M,34N-C4P.BTU-BXQ,#`G72`]("=#=6EA8F$@065R
M;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$U+C@V-SHM-#<N
M.3,S)UT@/2`G0G)A<VEL:6$@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3$U+C@V-SHM-3(N,S@S)UT@/2`G0F%R<F$@1&\@1V%R8V%S
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$V+C`U,#HM-#@N,#4P)UT@
M/2`G1V%M82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ-BXR,S,Z+30X
M+CDV-R==(#T@)T%N87!O;&ES($)R87HM069B)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3$V+C8S,SHM-#DN,C$W)UT@/2`G1V]I86YI82!!97)O<&]R
M=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,38N-S$W.BTT,RXX-C<G
M72`]("=-;VYT97,@0VQA<F]S)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3$W+C8S,SHM,SDN,C4P)UT@/2`G0V%R879E;&%S($%E<F]P;W(M5&\G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3DN,#@S.BTU-RXU,#`G72`]("=#
M;W)U;6)A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$Y+C<X,SHM-#<N
M.38W)UT@/2`G56)E<F%B82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ
M.2XX-3`Z+30S+CDU,"==(#T@)T)E;&\@2&]R:7IO;G1E($%E<F]P;W)T;R<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ.2XY,S,Z+30S+CDS,R==(#T@
M)T)E;&\@2&]R:7IO;G1E)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(N
M-#,S.BTU-"XW,3<G72`]("=386YT87)E;2U!97)O<&]R=&\G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,BXV,#`Z+30T+C(S,R==(#T@)U-A;R!,=6EZ
M($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)S(N.#,S.BTV
M,"XW,#`G72`]("=";V$@5FES=&$@065R;W!O<BU4;R<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTR+CDQ-SHM-#$N-S4P)UT@/2`G4&%R;F%I8F$@065R
M;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(P+C(V-SHM-#`N
M,C@S)UT@/2`G5FET;W)I82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,C`N-#8W.BTU-"XV-C<G72`]("=#86UP;R!'<F%N9&4@065R
M;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(Q+C(U,#HM-#,N
M-S8W)UT@/2`G0F%R8F%C96YA)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3(Q+C<U,#HM-#$N,S,S)UT@/2`G0V%M<&]S)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3(Q+C<V-SHM-#,N,S4P)UT@/2`G2G5I>B!$92!&;W)A)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(Q+C@U,#HM-#8N-38W)UT@/2`G
M4&]C;W,@1&4@0V%L9&%S)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(Q
M+CDX,SHM-#<N,S,S)UT@/2`G4&ER87-S=6YU;F=A)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+3(R+C`Q-SHM-#<N.#@S)UT@/2`G4V%O($-A<FQO<R<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,BXQ,3<Z+34Q+C,X,R==(#T@
M)U!R97-I9&5N=&4@4')U9&5N=&4G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,C(N,S$W.BTT.2XP-C<G72`]("="875R=2<["B1C;V]R9&EN871E<ULG
M0G)A>FEL)UU;)RTR,BXT.#,Z+30T+C0V-R==(#T@)U)E<V5N9&4G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,C(N-34P.BTU-2XW,#`G72`]("=0;VYT
M82!0;W)A($%E<F]P;W(M5&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M
M,C(N-S@S.BTT-2XR,#`G72`]("='=6%R871I;F=U971A)SL*)&-O;W)D:6YA
M=&5S6R="<F%Z:6PG75LG+3(R+C@Q-SHM-#(N,3`P)UT@/2`G4RX@4"X@06QD
M96EA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,BXX
M,3<Z+30S+C(U,"==(#T@)T=A;&5A;R<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTR,BXX-C<Z+30S+C,V-R==(#T@)T%F;VYS;W,@065R;W!O<G1O)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+CDP,#HM-#,N,38W)UT@/2`G
M4FEO($1E($IA;F5I<F\@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3(R+CDS,SHM-#,N-S$W)UT@/2`G4V%N=&$@0W)U>B!!97)O<&]R
M+51O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+CDX,SHM-#,N,S8W
M)UT@/2`G4FEO("\@2F%C87)E<&%G=6$G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,C,N,#`P.BTT-RXQ,S,G72`]("=#86UP:6YA<R!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C,N,S,S.BTU,2XQ,S,G72`]
M("=,;VYD<FEN82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,C,N-#$W.BTU,2XY-3`G72`]("=-87)I;F=A)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+3(S+C4Q-SHM-#8N-C,S)UT@/2`G36%R=&4@0VEV("\@
M36EL)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(S+C8Q-SHM-#8N-C4P
M)UT@/2`G4V%O(%!A=6QO($%E<F]P;W(M5&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,C,N.3,S.BTT-BXS,#`G72`]("=386YT;W,@065R;W!O<G1O
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(U+C0S,SHM-#DN,C8W)UT@
M/2`G0W5R:71I8F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C4N-3$W
M.BTT."XU,3<G72`]("=087)A;F%G=6$G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,C4N-3$W.BTT.2XQ-C<G72`]("=#=7)I=&EB82!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C4N-3$W.BTU-"XU.#,G72`]
M("=&;WH@1&\@26=U86-U($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTR-RXV-C<Z+30X+C4U,"==(#T@)T9L;W)I86YO<&]L:7,@065R
M;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(X+C(U,#HM-3(N
M-#`P)UT@/2`G4&%S<V\@1G5N9&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,CDN-S$W.BTU,RXW,#`G72`]("=386YT82!-87)I82!!97)O+5!O<G1O
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(Y+C<X,SHM-3<N,#,S)UT@
M/2`G57)U9W5A:6%N82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,RXP,S,Z+38P+C`U,"==(#T@)T5D=6%R9&\@1V]M97,@26YT97)N
M871I;VYA;"<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS+C$U,#HM-3DN
M.3@S)UT@/2`G36%N875S($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTS+C(P,#HM-3(N,C`P)UT@/2`G06QT86UI<F$G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,RXS-C<Z+38T+C8X,R==(#T@)U1E9F4G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,RXV-C<Z+38Y+C8V-R==(#T@)U1A
M8F%T:6YG82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS+C<Q-SHM-#DN
M-S$W)UT@/2`G5'5C=7)U:2<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS
M+C<X,SHM,S@N-3,S)UT@/2`G1F]R=&%L97IA($%E<F]P;W(M5&\G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<S+C@S,SHM-3$N.#,S)UT@/2`G3VEA<&]Q
M=64G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,RXX-3`Z+3,R+C0Q-R==
M(#T@)T9E<FYA;F1O($1E($YO<F]N:&$G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,S`N,#`P.BTU,2XQ.#,G72`]("=0;W)T;R!!;&5G<F4@065R;RU0
M;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS,"XP,3<Z+34Q+C(Q
M-R==(#T@)U!O<G1O($%L96=R92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTS,2XS-3`Z+34T+C$Q-R==(#T@)T)A9V4@065R;W!O<G1O)SL*)&-O;W)D
M:6YA=&5S6R="<F%Z:6PG75LG+3,Q+C@V-SHM-3(N,S4P)UT@/2`G4&5L;W1A
M<R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTT+C(U,#HM-38N,#`P)UT@
M/2`G271A:71U8F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-"XS.#,Z
M+3<P+C`S,R==(#T@)T)E;FIA;6EN($-O;G-T86YT)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+34N,#4P.BTT,BXX,3<G72`]("=497)E<VEN82!!97)O
M<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-2XR,#`Z+3,W+C,V
M-R==(#T@)TUO8V]R;R`O(#$W(%)O<V%D;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTU+C,U,#HM-#DN,34P)UT@/2`G36%R86)A)SL*)&-O;W)D:6YA
M=&5S6R="<F%Z:6PG75LG+34N-3,S.BTT-RXU,#`G72`]("=);7!E<F%T<FEZ
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+34N.#$W.BTV,2XS,#`G72`]
M("=-86YI8V]R92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTU+CDQ-SHM
M,S4N,C4P)UT@/2`G3F%T86P@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+38N,C8W.BTU-RXW,S,G72`]("=*86-A<F5A8V%N9V$G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M-RXQ,#`Z+3,T+C@V-R==(#T@)TIO
M86\@4&5S<V]A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3<N,C$W.BTS
M-2XX.#,G72`]("=#86UP:6YA($=R86YD92<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTW+C,Q-SHM-#<N-#8W)UT@/2`G36%R86YH86\@+R!#87)O;&EN
M82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3<N-C,S.BTW
M,BXV-C<G72`]("=#<G5Z96ER;R!$;R!3=6PG.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M."XP-C<Z+3,T+C@U,"==(#T@)U)E8VEF92!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M."XQ-C<Z+3<P+C<V-R==(#T@
M)U1A<F%U86-A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3@N,C4P.BTT
M.2XR.#,G72`]("=#;VYC96EC86\@1&\@07)A9W5A:6$G.PHD8V]O<F1I;F%T
M97-;)T)R87II;"==6R<M."XW-C<Z+38S+CDQ-R==(#T@)U!O<G1O(%9E;&AO
M($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTY+C,U,#HM
M-#`N-34P)UT@/2`G4&5T<F]L:6YA($%E<F]P;W(M5&\G.PHD8V]O<F1I;F%T
M97-;)T)R87II;"==6R<M.2XT,#`Z+3,X+C(Q-R==(#T@)U!A=6QO($%F;VYS
M;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTY+C4Q-SHM,S4N-S@S)UT@
M/2`G36%C96EO($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTY+C@V-SHM-38N,3`P)UT@/2`G06QT82!&;&]R97-T82!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R
M>2==6R<M-RXS,#`Z-S(N-#`P)UT@/2`G1&EE9V\@1V%R8VEA)SL*)&-O;W)D
M:6YA=&5S6R="<G5N96D@1&%R=7-S86QA;2==6R<T+CDS,SHQ,30N.3,S)UT@
M/2`G0G)U;F5I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T)U;&=A<FEA)UU;
M)S0R+C$S,SHR-"XW-3`G72`]("=0;&]V9&EV)SL*)&-O;W)D:6YA=&5S6R="
M=6QG87)I82==6R<T,BXT.#,Z,C<N-#@S)UT@/2`G0G5R9V%S)SL*)&-O;W)D
M:6YA=&5S6R="=6QG87)I82==6R<T,BXV-3`Z,C,N,S@S)UT@/2`G4V]F:6$@
M3V)S97)V+B<["B1C;V]R9&EN871E<ULG0G5L9V%R:6$G75LG-#,N,C`P.C(W
M+CDQ-R==(#T@)U9A<FYA)SL*)&-O;W)D:6YA=&5S6R="=6QG87)I82==6R<T
M,RXX-3`Z,C4N.34P)UT@/2`G4F]U<W-E)SL*)&-O;W)D:6YA=&5S6R="=7)K
M:6YA($9A<V\G75LG,3`N,S,S.BTS+C$X,R==(#T@)T=A;W5A)SL*)&-O;W)D
M:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3$N,34P.BTQ+C$U,"==(#T@)U!O
M)SL*)&-O;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3$N,38W.BTT+C,Q
M-R==(#T@)T)O8F\M1&EO=6QA<W-O)SL*)&-O;W)D:6YA=&5S6R="=7)K:6YA
M($9A<V\G75LG,3$N-S4P.BTR+CDS,R==(#T@)T)O<F]M;R<["B1C;V]R9&EN
M871E<ULG0G5R:VEN82!&87-O)UU;)S$R+C`S,SHP+C,V-R==(#T@)T9A9&$@
M3EPG1V]U<FUA)SL*)&-O;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3(N
M,S4P.BTQ+C4Q-R==(#T@)T]U86=A9&]U9V]U)SL*)&-O;W)D:6YA=&5S6R="
M=7)K:6YA($9A<V\G75LG,3(N-#8W.BTS+C0X,R==(#T@)T1E9&]U9V]U)SL*
M)&-O;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3,N-38W.BTR+C0Q-R==
M(#T@)T]U86AI9V]U>6$G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==
M6R<Q-"XP,S,Z+3`N,#,S)UT@/2`G1&]R:2<["B1C;V]R9&EN871E<ULG0G5R
M=6YD:2==6R<M,RXS,3<Z,CDN,S$W)UT@/2`G0G5J=6UB=7)A)SL*)&-O;W)D
M:6YA=&5S6R=#86UB;V1I82==6R<Q,2XU-3`Z,3`T+C@U,"==(#T@)U!H;F]M
M+5!E;F@@+R!0;V-H96YT;VYG)SL*)&-O;W)D:6YA=&5S6R=#86UB;V1I82==
M6R<Q,BXP,#`Z,3`U+C0U,"==(#T@)TMO;7!O;F<M0VAA;2<["B1C;V]R9&EN
M871E<ULG0V%M8F]D:6$G75LG,3,N,S8W.C$P,RXX-3`G72`]("=3:65M<F5A
M<"<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG,3`N-#4P.C$T+C(U,"==
M(#T@)TUA<F]U82U386QA:R<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG
M,BXY-3`Z.2XY,#`G72`]("=+<FEB:2<["B1C;V]R9&EN871E<ULG0V%M97)O
M;VXG75LG,RXQ-3`Z,3,N-C$W)UT@/2`G3&]M:64G.PHD8V]O<F1I;F%T97-;
M)T-A;65R;V]N)UU;)S,N.#,S.C$Q+C4Q-R==(#T@)UEA;W5N9&4G.PHD8V]O
M<F1I;F%T97-;)T-A;65R;V]N)UU;)S,N.38W.C$S+C(P,"==(#T@)T%B;VYG
M+4UB86YG)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<T+C`P,#HY+C<S
M,R==(#T@)T1O=6%L82!/8G,N)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==
M6R<T+C`X,SHY+C,V-R==(#T@)U1I:V\G.PHD8V]O<F1I;F%T97-;)T-A;65R
M;V]N)UU;)S0N-#8W.C$T+C,V-R==(#T@)T)A=&]U<FDG.PHD8V]O<F1I;F%T
M97-;)T-A;65R;V]N)UU;)S0N-S,S.C$Q+C(U,"==(#T@)T)A9FEA)SL*)&-O
M;W)D:6YA=&5S6R=#86UE<F]O;B==6R<T+CDU,#HY+CDS,R==(#T@)TYK;VYG
M<V%M8F$G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S4N-34P.C$R+C,V
M-R==(#T@)UEO:V\G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S4N-C`P
M.C$T+C`V-R==(#T@)T)E=&%R92U/>6$G.PHD8V]O<F1I;F%T97-;)T-A;65R
M;V]N)UU;)S4N-C4P.C$P+C<U,"==(#T@)TMO=6YD:F$G.PHD8V]O<F1I;F%T
M97-;)T-A;65R;V]N)UU;)S4N-S$W.CDN,C@S)UT@/2`G36%M9F4G.PHD8V]O
M<F1I;F%T97-;)T-A;65R;V]N)UU;)S8N,#4P.C$P+C$Q-R==(#T@)T)A;65N
M9&$G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S8N-3,S.C$T+C,V-R==
M(#T@)TUE:6=A;F=A)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<V+C<X
M,SHQ,2XX,3<G72`]("="86YY;R<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG
M75LG-RXS-3`Z,3,N-38W)UT@/2`G3F=A;W5N9&5R92<["B1C;V]R9&EN871E
M<ULG0V%M97)O;VXG75LG.2XS,S,Z,3,N,S@S)UT@/2`G1V%R;W5A)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#$N.#,S.BTX,BXT-C<G72`]("=3+B!%
M+B!3:&]A;"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T
M:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0R+C(U,#HM
M.#$N.3`P)UT@/2`G17)I96%U($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A
M;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#(N,C8W.BTX,BXY-C<G72`]("=7:6YD<V]R+"!/;G0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#(N,S`P.BTX,BXW,#`G72`]("="96QL92!2
M:79E<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0R+C4V-SHM.#`N,#4P
M)UT@/2`G3&]N9R!0;VEN="!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@
M4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0R+C@U,#HM.#`N,C8W)UT@/2`G4VEM8V]E+"!/;G0N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#(N.#8W.BTW.2XR-3`G72`]("=0;W)T($-O;&)O
M<FYE($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0R+C@V-SHM.#`N-34P)UT@/2`G1&5L:&D@0U,L($]N
M="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXP,#`Z+3@R+C,Q-R==
M(#T@)U-A<FYI82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#,N,#,S.BTX,2XQ-3`G72`]("=,;VYD;VXL($]N="XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T,RXQ-C<Z+3<Y+CDS,R==(#T@)TAA;6EL=&]N($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXR-3`Z+3<Y+C(Q
M-R==(#T@)U!O<G0@5V5L;&5R+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#,N,S`P.BTW.2XX,#`G72`]("="=7)L:6YG=&]N(%!I97)S)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N-#8W.BTX,"XS.#,G72`]("=7
M871E<FQO;R!796QL)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N-C$W
M.BTW.2XS-3`G72`]("=4;W)O;G1O($AE861L86YD)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#,N-C,S.BTW.2XT,#`G72`]("=4;W)O;G1O($ES;&%N
M9"!!:7)P;W)T($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0S+C8V-SHM-SDN-C,S)UT@/2`G5&]R;VYT
M;R!096%R<V]N($EN=%PG3"X@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0S+C<V-SHM.#$N-S$W)UT@/2`G1V]D97)I8V@@075T;VUA=&EC(%=E
M871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0S+C<X,SHM-SDN-#8W)UT@/2`G5&]R;VYT;R!!97,@2'$G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T,RXX,S,Z+38V+C`X,R==(#T@)UEA<FUO
M=71H+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+C@S,SHM
M-S<N,34P)UT@/2`G4&]I;G0@4&5T<F4L($]N="XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T,RXY,S,Z+38P+C`Q-R==(#T@)U-A8FQE($ES;&%N9"P@
M3BX@4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXY-3`Z+3<X+C$V
M-R==(#T@)T-O8F]U<F<L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T,RXY.#,Z+38T+C8V-R==(#T@)U=E<W1E<FX@2&5A9"P@3BX@4RXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXY.#,Z+3@P+C<U,"==(#T@)TUO
M=6YT($9O<F5S="P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T
M+C$Q-SHM-S<N-3,S)UT@/2`G5')E;G1O;BP@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0T+C(Q-SHM-S8N-C`P)UT@/2`G2VEN9W-T;VXL($]N
M="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XR,S,Z+3<X+C,V-R==
M(#T@)U!E=&5R8F]R;W5G:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#0N,C@V.BTV-BXS-#<G72`]("="<FEE<B!)<VQA;F0L($XN(%,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N,S@S.BTW.2XW.#,G72`]
M("="87)R:64L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XT
M,3<Z+3<U+C@U,"==(#T@)T=R96YA9&EE<B!)<VQA;F0G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-"XT,S,Z+38U+C(P,"==(#T@)TME:FEM:W5J:6L@
M,2P@3BX@4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XU,#`Z+3@P
M+C(Q-R==(#T@)T-O;&QI;F=W;V]D($%U=&]M871I8R!796%T:&5R(%)E<&]R
M=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XU,S,Z
M+3<Y+C(Q-R==(#T@)TQA9V]O;B!#:71Y)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#0N-C,S.BTV,RXU,#`G72`]("=3:&5A<G=A=&5R+"!.+B!3+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C<P,#HM-S8N,S`P)UT@/2`G
M57!P97(@4FED96%U($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-"XW,S,Z+3@Q+C(X,R==(#T@)T]L:7!H86YT(%P@3VYT)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#0N-S4P.BTX,2XQ,#`G72`]("=7:6%R=&]N+"!/
M;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N.#$W.BTV,BXS,S,G
M72`]("="96%V96X@27-L86YD+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0T+C@U,#HM-SDN.#8W)UT@/2`G0F5A=7-O;&5I;"!)<VQA;F0@
M075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#0N.#@S.BTV,RXU,#`G72`]("=(86QI9F%X($EN=&5R;F%T
M:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+CDV
M-SHM-SDN,S`P)UT@/2`G375S:V]K82P@3VYT+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0T+CDX,SHM-C0N.3$W)UT@/2`G1W)E96YW;V]D+"!.+B!3
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C`S,SHM.#`N,S8W)UT@
M/2`G5V5S=&5R;B!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L
M(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T-2XP-3`Z+3<R+C@S,R==(#T@)T9R96QI9VAS8G5R9R<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0U+C`V-SHM-C0N-#@S)UT@/2`G2V5N='9I;&QE
M+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C$Q-SHM-S0N
M,C@S)UT@/2`G4W0@06YI8V5T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#4N,38W.BTW,RXV.#,G72`]("=386EN="!#;&]T:&EL9&4@075T;VUA=&5D
M(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#4N,C$W.BTV-RXR-3`G72`]("=3="X@4W1E<&AE;BP@3BX@0BXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-2XS,#`Z+3<S+C,U,"==(#T@)TQ<)T%C
M861I92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C,Q-SHM-S(N,C4P
M)UT@/2`G36]N="U/<F9O<F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-2XS,3<Z+3<U+C8V-R==(#T@)T]T=&%W82!);G1<)TPN($]N="XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-2XS,S,Z+38U+C@X,R==(#T@)U-A:6YT
M($IO:&XL($XN($(N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,S,S
M.BTX,2XW,S,G72`]("=#;W9E($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O
M;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0U+C,U,#HM-C`N.3@S)UT@/2`G2&%R="!)<VQA;F0@365T
M96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XS-C<Z+38S+C(V-R==(#T@
M)U1R=7)O+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C,V
M-SHM-S$N.#$W)UT@/2`G3&5N;F]X=FEL;&4G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T-2XT,#`Z+3<Q+C@X,R==(#T@)U-H97)B<F]O:V4L(%%U92XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XT,3<Z+3<S+CDS,R==(#T@
M)TUC9VEL;"!2861A<B!3:71E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#4N-#,S.BTW,RXY,S,G72`]("=3=&4@06YN92!$92!"96QL(#$G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-2XT-C<Z+3<S+C<U,"==(#T@)TUO;G1R
M96%L("\@1&]R=F%L($EN=&5R;F%T:6]N86PL(%%U92<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0U+C4P,#HM-S,N-3@S)UT@/2`G36,@5&%V:7-H($%U
M=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0U+C4Q-SHM-S,N-#$W)UT@/2`G4V%I;G0@2'5B97)T($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XV,S,Z+3<P+C4U,"==
M(#T@)TUO;G1R96%L+45S="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U
M+C8S,SHM.#(N.38W)UT@/2`G1W)E870@1'5C:R!)<VQA;F0G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-2XW,3<Z+38P+C(S,R==(#T@)T9O=7)C:'4@
M2&5A9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C<Q-SHM-S,N
M,S@S)UT@/2`G5F%R96YN97,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-2XW-C<Z+38R+C8X,R==(#T@)T-A<FEB;W4@4&]I;G0@365T96]R;VQO9VEC
M86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-2XX,#`Z+3@P+C4S,R==(#T@)T)R:71T+"!/
M;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N.#$W.BTW,RXT,S,G
M72`]("=,7"=!<W-O;7!T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#4N.#,S.BTV-BXT,S,G72`]("='86=E=&]W;B!#86XM36EL)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#4N.#,S.BTW-2XV-3`G72`]("=(:6=H($9A
M;&QS+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N.#4P.BTV
M-"XR-C<G72`]("=!;6AE<G-T+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0U+C@V-SHM-C8N-3,S)UT@/2`G1G)E9&5R:6-T;VXL($XN($(N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N.#@S.BTX,BXU-C<G72`]
M("=';W)E($)A>2P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U
M+CDU,#HM-S<N,S$W)UT@/2`G4&5T87=A=V$L($]N="XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-2XY-C<Z+3@Q+C0X,R==(#T@)TMI;&QA<FYE>2!-
M971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C`U,#HM-S0N,C@S)UT@
M/2`G4W1E($%G871H92!$97,@36]N="<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0V+C`V-SHM-S0N-3,S)UT@/2`G4W0@2F]V:71E($%U=&]M871I8R!7
M96%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T-BXQ,3<Z+38T+C8X,R==(#T@)TUO;F-T;VXL($XN($(N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,38W.BTV,"XP-3`G72`]("=3>61N
M97DL($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,C`P.BTW
M,"XW.#,G72`]("="96%U8V5V:6QL92<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0V+C(Q-SHM-S(N-C4P)UT@/2`G3FEC;VQE="!!=71O;6%T:6,@5V5A
M=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N,C@S.BTV,RXQ,S,G72`]("=#:&%R;&]T=&5T;W=N+"!0+B!%+B!)
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C(X,SHM-S8N,#`P)UT@
M/2`G36%N:7=A:VDG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXS,3<Z
M+3<Y+C0V-R==(#T@)TYI<&ES<VEN9R<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0V+C,U,#HM-S(N-3$W)UT@/2`G5')O:7,@4FEV:65R97,G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-BXS-3`Z+3<Y+C0S,R==(#T@)TYO<G1H
M($)A>2P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C,X,SHM
M-S4N.38W)UT@/2`G36%N:7=A:VDL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T-BXT,S,Z+38S+C@S,R==(#T@)U-U;6UE<G-I9&4@0V%N+4UI
M;"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C0S,SHM-S$N.3,S)UT@
M/2`G5FEL;&5R;WD@4F%D87(@4VET92<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0V+C0U,#HM-C$N.38W)UT@/2`G16%S="!0;VEN="P@4"X@12X@22<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C0X,SHM.#0N-3`P)UT@/2`G
M4V%U;'0@4W1E($UA<FEE+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N-34P.BTV,2XP-3`G72`]("='<F%N9"!%=&%N9RP@3BX@4RXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXU.#,Z+3<R+C4X,R==(#T@)U-H
M87=I;FEG86X@0U,L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-BXV,3<Z+3@P+C@P,"==(#T@)U-U9&)U<GDL($]N="XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-BXV-3`Z+34S+C`V-R==(#T@)T-A<&4@4F%C92P@
M3F9L9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C8X,SHM-S$N.34P
M)UT@/2`G1&5S8VAA;6)A=6QT<RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0V+C@P,#HM-S$N,S@S)UT@/2`G475E8F5C+"!1=64G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-BXX,3<Z+38P+C8V-R==(#T@)TYO<G1H
M($UO=6YT86EN+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V
M+C@S,SHM-S$N,C`P)UT@/2`G0F5A=7!O<G0@0U,L(%%U92XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-BXY,#`Z+3<Q+C4P,"==(#T@)U9A;&-A<G1I
M97(@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+CDP,#HM
M-S$N-3`P)UT@/2`G5F%L8V%R=&EE<B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0V+CDQ-SHM-34N,S@S)UT@/2`G4W0N($QA=W)E;F-E+"!.9FQD+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C`P,#HM-C4N-#4P)UT@/2`G
M0VAA=&AA;2!#86XM36EL)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N
M,#`P.BTW,"XX,3<G72`]("=);&4@1%PG3W)L96%N<R!!=71O;6%T960@4F5P
M;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXP
M-C<Z+38T+C@P,"==(#T@)U!O:6YT($5S8W5M:6YA8R!-971E;W)O;&]G:6-A
M;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0W+C`V-SHM-S`N.#`P)UT@/2`G0V%P(%1O=7)M
M96YT92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C$U,#HM-C<N.#,S
M)UT@/2`G4V%I;G0@3&5O;F%R9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#<N,C,S.BTV,"XQ,S,G72`]("=386EN="!0875L($ES;&%N
M9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C(X,SHM-S`N-C,S
M)UT@/2`G0VAA<FQE=F]I>"!#4RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0W+C,P,#HM-30N,#`P)UT@/2`G07)G96YT:6$L($YF;&0G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXS,#`Z+3<Q+C(V-R==(#T@)U-T
M92!&;WD@0U,L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXS
M,S,Z+3@U+C@S,R==(#T@)T-A<FEB;W4@27-L86YD+"!/;G0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#<N,S4P.BTW,"XP,S,G72`]("=,82!0;V-A
M=&EE<F4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXS-C<Z+34U+C@P
M,"==(#T@)U-A9V]N82!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I
M8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T-RXT,3<Z+38Q+C<X,R==(#T@)TEL97,@1&4@3&$@36%D96QE:6YE
M<75E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C0Q-SHM-C$N.#`P
M)UT@/2`G26QE<RU$92U,82U-861E;&5I;B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0W+C0Q-SHM-S(N.#`P)UT@/2`G3&$@5'5Q=64G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-RXU,38Z+34R+C<X-2==(#T@)U-T+B!*;VAN
M7"=S(%=E<W0@0T1!($-3+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0W+C4V-SHM-3DN,38W)UT@/2`G4&]R="U!=7@M0F%S<75E<RP@3F9L
M9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXU-C<Z+3<Q+C(S,R==
M(#T@)U!A<F,@1&5S($QA=7)E;G1I9"<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0W+C8Q-SHM-3(N-S,S)UT@/2`G4W0N($IO:&Y<)W,L($YF;&0G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXW,#`Z+3<Y+C@U,"==(#T@)T5A
M<FQT;VXL($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXX,#`Z
M+38Y+C4U,"==(#T@)U)I=FEE<F4@1'4@3&]U<"P@475E+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0W+CDQ-SHM-S0N-C$W)UT@/2`G4&%R96YT+"!1
M=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N.38W.BTX-"XW.#,G
M72`]("=787=A+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N
M.3@S.BTV-BXS,S,G72`]("=#:&%R;&\L($XN($(N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#@N,#$W.BTV-"XU,#`G72`]("=-:7-C;W4@27-L86YD
M+"!.+B!"+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C`Q-SHM-C4N
M,S,S)UT@/2`G3F5W($-A<FQI<VQE,2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0X+C`V-SHM-S<N-S@S)UT@/2`G5F%L($1<)T]R+"!1=64N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,#@S.BTV.2XU-3`G72`]("=);&4@
M4F]U9V4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO
M;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XR-3`Z+3<Y
M+C`S,R==(#T@)U)O=7EN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N
M,C8W.BTW,"XQ,3<G72`]("=0=6EN=&4@0VQA=F5A=2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0X+C,P,#HM,3(S+C4S,R==(#T@)U)A8V4@4F]C:W,@
M075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0X+C,P,#HM-S`N.3,S)UT@/2`G3&$@0F%I92P@
M475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C,S,SHM-S$N,#`P
M)UT@/2`G0F%G;W1V:6QL92P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0X+C,V-SHM.#DN,3$W)UT@/2`G5V5L8V]M92!)<VQA;F0G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T."XS-C<Z+3@Y+C,Q-R==(#T@)U1H=6YD
M97(@0F%Y+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,S@S
M.BTQ,C,N.3$W)UT@/2`G4VAE<FEN9VAA;2!!=71O;6%T:6,@5V5A=&AE<B!2
M97!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N
M,S@S.BTW,"XU,S,G72`]("=#87`@4F]U9V4G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T."XT,38Z+38X+C@Y,R==(#T@)TEL92!":6-Q=65T=&4L(%%U
M92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XT,3<Z+3$R,RXS,3<G
M72`]("=6:6-T;W)I82!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES
M=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-#$W.BTV-"XS,3<G
M72`]("=#87`@1%PG17-P;VER+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#@N-#$W.BTW,2XR,3<G72`]("=*;VYQ=6EE<F4@075T;VUA=&5D
M(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#@N-#,S.BTQ,C,N-#,S)UT@/2`G17-Q=6EM86QT($AA<F)O=7(L($(N($,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-#4P.BTQ,C,N,S`P)UT@
M/2`G5FEC=&]R:6$@56YI=F5R<VET>2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0X+C0V-SHM-C<N-#,S)UT@/2`G06UQ=6DL(%%U92XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T."XU,3<Z+3<R+C(V-R==(#T@)U)O8F5R=F%L
M+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-3,S.BTU."XU
M-3`G72`]("=3=&5P:&5N=FEL;&4L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#@N-34W.BTU,RXY-S0G72`]("=497)R82!.;W9A($YA=&EO
M;F%L(%!A<FL@0U,L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#@N-38W.BTX,2XS-C<G72`]("=4:6UM:6YS+"!/;G0N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#@N-3@S.BTQ,C,N-3@S)UT@/2`G36%L86AA="!!
M=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#@N-C`P.BTV."XR,3<G72`]("=-;VYT($IO;&DL
M(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XV,#`Z+3@V+C,P
M,"==(#T@)U!U:V%S:W=A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N
M-C,S.BTW.2XT-3`G72`]("=2;W%U96UA=7)E)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#@N-C4P.BTQ,C,N-#,S)UT@/2`G5FEC=&]R:6$@26YT+B!!
M:7)P;W)T+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C8V
M-SHM,3(T+C@S,R==(#T@)TYI=&EN870@3&%K92!-971E;W)O;&]G:6-A;"!!
M97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0X+C8V-SHM-3,N,3$W)UT@/2`G0F]N879I<W1A+"!.
M9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C<U,#HM.3$N-C$W
M)UT@/2`G071I:V]K86X@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-S8W.BTV-"XT.#,G72`]("='
M87-P92P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C<V-SHM
M-S$N-S$W)UT@/2`G36ES=&]O:R!!=71O;6%T960@4F5P;W)T:6YG(%-T871I
M;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XW.#,Z+3$R,RXP-3`G
M72`]("=3871U<FYA($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC
M86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0X+C@S,SHM-S(N-34P)UT@/2`G3F]R;6%N9&EN)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#@N.#@S.BTW,2XP,S,G72`]("=/;F%T8VAI=V%Y
M+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N.3$W.BTQ,C4N
M-34P)UT@/2`G06UP:&ET<FET92!0;VEN="<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0X+CDU,#HM-30N-38W)UT@/2`G1V%N9&5R($EN="X@06ER<&]R
M="P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XY-C<Z+34V
M+C`V-R==(#T@)T)A9&=E<BP@3F9L9"<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C`Q-SHM,3(R+C<X,R==(#T@)U=H:71E(%)O8VL@075T;VUA=&EC
M(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C`S,SHM,3$Y+C0S,R==(#T@)T]S;WEO;W,@075T;VUA=&EC
M(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C`S,SHM,3(R+C,V-R==(#T@)T%B8F]T<V9O<F0L($(N($,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,#,S.BTY,"XT-C<G72`]
M("=5<'-A;&$L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XP
M,S,Z+3DW+C4V-R==(#T@)T=R971N82P@36%N+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C`U,#HM,3`U+C0X,R==(#T@)T-O<F]N86-H(%-P8R<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`U,#HM,3(S+C@V-R==(#T@
M)TYA;F%I;6\@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C`V-SHM,3`W+C4X,R==(#T@)U9A;"!-87)I92!3;W5T:&5A<W0L(%-A<VLG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XP.#,Z+3$Q-BXU,#`G72`]
M("=#<F5S=&]N($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XP.#,Z+3$R-2XW-C<G72`]
M("=4;V9I;F\@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C`X,SHM-C$N-S`P)UT@/2`G2&5A=&@@4&]I;G0@365T96]R;VQO9VEC86P@
M065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T.2XQ,3<Z+3$Q,"XT-C<G72`]("=/;F5F;W5R($%U
M=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T.2XQ,3<Z+38V+C8U,"==(#T@)T-A<"!#:&%T($-3
M+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,3,S.BTQ,3(N
M,#4P)UT@/2`G36EL:R!2:79E<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0Y+C$S,SHM-C@N,C`P)UT@/2`G0F%I92!#;VUE874L(%%U92XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XQ-C<Z+3$P-2XY.#,G72`]("=2;V-K
M9VQE;BP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XQ.#,Z
M+3$R,RXQ-C<G72`]("=686YC;W5V97(@26YT97)N871I;VYA;"!!:7(M4&]R
M="P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XQ.#,Z+3DX
M+C`X,R==(#T@)TUO<F1E;B!#1$$@0U,L($UA;BXG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T.2XR,#`Z+3$Q,RXR.#,G72`]("=#87)D<W1O;B!!=71O
M;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XR,#`Z+3$R,BXV.#,G72`]("=0+B!-96%D;W=S($-O87-T86P@
M4W1A=&EO;B!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,C`P.BTY."XY,#`G72`]("=0
M:6QO="!-;W5N9"P@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C(Q-SHM,3`R+CDV-R==(#T@)T5S=&5V86XL(%-A<VLN)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#DN,C$W.BTQ,C,N.#`P)UT@/2`G16YT<F%N8V4@
M27-L86YD($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR,3<Z+34W+C0P,"==(#T@)T1E
M97(@3&%K92P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR
M-3`Z+3$R,2XW-C<G72`]("=!9V%S<VEZ($%U=&]M871E9"!297!O<G1I;F<@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(U,#HM,3(T
M+C@S,R==(#T@)U!O<G0@06QB97)N:2P@0BX@0RXG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T.2XR-3`Z+38U+C,S,R==(#T@)T-A<"!-861E;&5I;F4@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR-C<Z+34T+C@X,R==
M(#T@)T-O;69O<G0@0V]V92P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XR-C<Z+38X+C$U,"==(#T@)T)A:64@0V]M96%U)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN,C@S.BTQ,#`N.3@S)UT@/2`G365L:71A
M+"!-86XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR.#,Z+3<S+C,U
M,"==(#T@)T-H86UO=6-H;W5A;F4@075T;VUA=&EC(%=E871H97(@4F5P;W)T
M:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C,P,#HM
M,3$W+C8S,R==(#T@)T-A<W1L96=A<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN,S`P.BTQ,C,N,3$W)UT@/2`G5F%N8V]U=F5R($%U
M=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T.2XS,3<Z+38W+C,X,R==(#T@)U!O:6YT92U$97,M
M36]N=',L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XS-3`Z
M+3$R,RXQ.#,G72`]("=7(%9A;F-O=79E<B!!=71O;6%T:6,@5V5A=&AE<B!2
M97!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M,S4P.BTQ,C0N,38W)UT@/2`G0F%L;&5N87,@27-L86YD($%U=&]M871I8R!7
M96%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XS-C<Z+3$R,2XT.#,G72`]("=(;W!E+"!"+B!#+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0Y+C,X,SHM,3(V+C4U,"==(#T@)T5S=&5V
M86X@4&]I;G0L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M-#`P.BTY."XS,3<G72`]("=$965R=V]O9"!20U,L($UA;BXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XT,3<Z+3@R+C0V-R==(#T@)TMA<'5S:V%S
M:6YG+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-#,S.BTQ
M,#@N.3@S)UT@/2`G16%S=&5N9"!#>7!R97-S+"!387-K)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#DN-#8W.BTQ,3DN-C`P)UT@/2`G4&5N=&EC=&]N
M+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C0V-SHM,3(P
M+C4Q-R==(#T@)U!R:6YC971O;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN-#@S.BTQ,C,N,S`P)UT@/2`G4&%M(%)O8VMS)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-#@S.BTQ,C0N-#,S)UT@/2`G4VES
M=&5R<R!)<VQA;F0@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C4P,#HM,3$W+C,P,"==
M(#T@)TYE;'-O;B!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-3`P.BTY."XP,S,G72`]
M("=#87)M86X@52!/9B!-)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M-38W.BTQ,3DN-C4P)UT@/2`G4W5M;65R;&%N9"!!=71O;6%T:6,@5V5A=&AE
M<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN-38W.BTU-RXX.#,G72`]("=2;V-K>2!(87)B;W5R($-3+"!.9FQD+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C4X,SHM,3$T+C0Q-R==(#T@
M)U1U<G1L92!-;W5N=&%I;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C8Q-SHM,3$U+C<X,R==(#T@)T-R86YB<F]O:RP@0BX@0RXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XV,S,Z+3$Q,2XT-3`G72`]("=";W<@27-L
M86YD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-C,S.BTQ,3(N.#`P
M)UT@/2`G3&5T:&)R:61G92P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XV,S,Z+3$Q-"XT.#,G72`]("=#<F]W<VYE<W0G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XV-3`Z+3$P.2XU,3<G72`]("=#>7!R97-S
M($AI;&QS(%!A<FLG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XV.#,Z
M+34T+C@P,"==(#T@)U1W:6QL:6YG871E($UE=&5O<F]L;V=I8V%L($%E<F]N
M875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN-S`P.BTQ,#,N.#`P)UT@/2`G5V5Y8G5R;B!!=71O;6%T
M:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN-S`P.BTQ,3(N-S@S)UT@/2`G3&5T:&)R:61G92!!=71O
M;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XW,3<Z+3$R-"XY,#`G72`]("=#;VUO>"P@0BX@0RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XW,3<Z+3@X+C,S,R==(#T@)TMA=&%T
M;W1A($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<S,SHM
M,3`U+CDS,R==(#T@)T%S<VEN:6)O:6$@06ER<&]R="!!=71O;6%T960@4F5P
M;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW
M-3`Z+3$Q-"XY,#`G72`]("=3<&%R=V]O9"!!=71O;6%T:6,@5V5A=&AE<B!2
M97!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M-S4P.BTX-"XQ-C<G72`]("=.86=A9V%M:2P@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C<V-SHM-S0N-3,S)UT@/2`G0VAI8F]U9V%M874M
M0VAA<&%I<RP@475E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S8W
M.BTW-RXX,3<G72`]("=-871A9V%M:2P@475E+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C<X,SHM,3(S+C$V-R==(#T@)U-Q=6%M:7-H($%I<G!O
M<G0L($(N($,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW.#,Z+3@V
M+CDS,R==(#T@)T=E<F%L9'1O;BP@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C<X,SHM.30N,S8W)UT@/2`G2V5N;W)A+"!/;G0N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S@S.BTY.2XV,S,G72`]("=3:&EL
M;R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C@S,SHM,3(T+C4P,"==
M(#T@)U!O=V5L;"!2:79E<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#DN.#,S.BTV-"XS,#`G72`]("=0;W)T($UE;FEE<BP@475E+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C@X,SHM.3<N,3,S)UT@/2`G
M5VEN;FEP96<@5&AE($9O<FMS+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#DN.3`P.BTQ,#DN-#8W)UT@/2`G36%P;&5C<F5E:R!!=71O;6%T
M:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN.3`P.BTW,2XR-3`G72`]("=#:'5T92!$97,@4&%S<V5S
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.3`P.BTY-RXR,S,G72`]
M("=7:6YN:7!E9R!);G0N($%I<G!O<G1M86XN)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN.3`P.BTY."XR-C<G72`]("=0;W)T86=E(%-O=71H<&]R
M="!!)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.3`P.BTY.2XS-3`G
M72`]("=#87)B97)R>2!-8V1C)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN.3$W.BTU-2XV-C<G72`]("=,82!38VEE+"!.9FQD+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+CDQ-SHM.3DN.34P)UT@/2`G0G)A;F1O;BP@
M36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+CDV-SHM,3$Y+C,X
M,R==(#T@)TME;&]W;F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4P+C`Q-SHM,3$P+C<Q-R==(#T@)TUE9&EC:6YE($AA="P@06QT82XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XP,3<Z+3$Q,RXV,S,G72`]
M("=#;&%R97-H;VQM($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XP-3`Z+3$Q,BXQ,S,G
M72`]("=6875X:&%L;"!#9&$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,"XQ,3<Z+3$R-RXY,S,G72`]("=3;VQA;F1E<B!)<VQA;F0@365T96]R;VQO
M9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,"XQ,3<Z+3DQ+CDP,"==(#T@)U-I;W5X
M($QO;VMO=70L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XQ
M-C<Z+38P+C`V-R==(#T@)T-A<&4@5VAI='1L92<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4P+C$V-SHM-C8N-#,S)UT@/2`G4&]I;G1E($YO:7)E+"!1
M=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,3@S.BTV,2XX,3<G
M72`]("=.871A<VAQ=6%N+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3`N,3@S.BTY-BXP-C<G72`]("=0:6YA=V$@075T;VUA=&EC(%=E871H
M97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4P+C(P,#HM,3`T+C<P,"==(#T@)T)R871T<R!,86ME+"!387-K+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(Q-SHM-C8N,C8W)UT@/2`G4V5P
M="U);&5S+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,C(T
M.BTV-"XR,#@G72`]("=);&4@075X(%!E<G)O<75E=',L(%%U92XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,"XR,S,Z+3$Q.2XR.#,G72`]("=697)N
M;VXL($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,C,S.BTQ
M,C$N-3@S)UT@/2`G3'ET=&]N+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4P+C(S,SHM-3<N-3@S)UT@/2`G1&%N:65L7"=S($AA<F)O=7(L
M($YF;&0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR-C<Z+3$P-RXW
M,S,G72`]("=3=VEF="!#=7)R96YT($%U=&]M871I8R!796%T:&5R(%)E<&]R
M=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR-C<Z
M+3$Q,2XQ.#,G72`]("=3=69F:65L9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3`N,C8W.BTQ,3<N.#$W)UT@/2`G3F%K=7-P($%U=&]M
M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,"XR-C<Z+38T+C(S,R==(#T@)TQO;F=U92!0;VEN="!$
M92!-:6YG86XL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR
M.#,Z+3$P-RXV.#,G72`]("=3=VEF="!#=7)R96YT+"!387-K+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C(X,SHM-C,N-C$W)UT@/2`G2&%V<F4@
M4W0@4&EE<G)E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,S`P.BTQ
M,C(N-S,S)UT@/2`G4&5M8F5R=&]N($%U=&]M871I8R!796%T:&5R(%)E<&]R
M=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XS,#`Z
M+3@Y+C`S,R==(#T@)T%R;7-T<F]N9RP@3VYT+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4P+C,S,SHM,3`U+C4U,"==(#T@)TUO;W-E($IA=RP@4V%S
M:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XS.#,Z+3$P,BXV.#,G
M72`]("="<F]A9'9I97<L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3`N-#`P.BTQ,#0N-3@S)UT@/2`G4F5G:6YA(%5N:79E<G-I='DG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XT,#`Z+3$R-2XX-C<G72`]("=(
M96QM8VME;B!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R
M97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,"XT,S,Z+3$P-"XV-C<G72`]("=296=I;F$L(%-A<VLN)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3`N-#4P.BTQ,#`N-C`P)UT@/2`G4VAO86P@3&%K
M92!!:7)P;W)T($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C0V-SHM-3DN-C,S)UT@/2`G0VAE=F5R
M>2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C4U,#HM,3$Q
M+C@U,"==(#T@)T)R;V]K<R!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@
M4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-C`P.BTQ,C`N
M-3$W)UT@/2`G4')I;F-E=&]N($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN
M9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XV,3<Z+3DW
M+C`S,R==(#T@)T=I;6QI($EN9'5S=')I86PL($UA;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+C8S,3HM.38N.3@R)UT@/2`G1VEM;&D@2&%R8F]U
M<B!#4RP@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C8S,SHM
M,3(X+C$Q-R==(#T@)TAO;&)E<F<L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3`N-C4P.BTY.2XY,S,G72`]("=787-A9V%M:6YG+"!-86XN
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-C8W.BTW,"XU,S,G72`]
M("=-86YO=6%N92U%<W0@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-C@S.BTQ,C<N,S8W)UT@/2`G
M4&]R="!(87)D>2P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,"XW,#`Z+3$Q.2XR.#,G72`]("=386QM;VX@07)M($%U=&]M871I8R!796%T
M:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,"XW,#`Z+3$R,"XT-3`G72`]("=+86UL;V]P<RP@0BX@0RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,"XW,#`Z+3DV+C4V-R==(#T@)U9I8W1O
M<FEA($)E86-H)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-S$W.BTU
M-BXQ,3<G72`]("=%;F=L964@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L
M(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,"XW,S,Z+3<Q+C`Q-R==(#T@)T)O;FYA<F0@,2P@475E+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C<X,SHM,3(X+C0S,R==(#T@)T-A<&4@
M4V-O='0@3&EG:'0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XX,3<Z
M+3$R."XY,#`G72`]("=387)T:6YE($ES;&%N9"!-971E;W)O;&]G:6-A;"!!
M97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+CDP,#HM,3`Y+C4P,"==(#T@)TQE861E<B!!:7)P
M;W)T($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,"XY,S,Z+3$R-RXV,S,G72`]("=(97)B
M97)T($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N
M=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+CDU
M,#HM,3`W+C$U,"==(#T@)TQU8VMY($QA:V4@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P
M+CDU,#HM,3$U+C$X,R==(#T@)TYA:VES:V$@4FED9V5T;W`G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,"XY-C<Z+3$Q."XQ.#,G72`]("=2979E;'-T
M;VME+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+CDX,SHM
M,3(W+C<S,R==(#T@)U!I;F4@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N
M875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3$N,#8W.BTY,RXX,#`G72`]("=2960@3&%K92P@3VYT+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C`X,SHM,3$T+C(Q-R==(#T@
M)T-O<"!5<'!E<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C`X,SHM
M,3$U+C`V-R==(#T@)T)O=R!686QL97DG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,2XP.#,Z+3DW+C4U,"==(#T@)T9I<VAE<B!"<F%N8V@@36%R:6YE
M($%V:6%T:6]N(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3$N,3`P.BTQ,#`N,#4P)UT@/2`G1&%U<&AI;B!#;V%S=&%L
M(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XQ,#`Z+3$P
M,"XP-3`G72`]("=$875P:&EN+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3$N,3$W.BTQ,30N,#$W)UT@/2`G0V%L9V%R>2!);G1E<FYA=&EO
M;F%L+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C$S,SHM
M,3`V+C4X,R==(#T@)T5L8F]W($UA<FEN92!!=FEA=&EO;B!297!O<G1I;F<@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C$U,#HM,3(Q
M+C4P,"==(#T@)T-L:6YT;VXL($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3$N,3@S.BTQ,34N-38W)UT@/2`G0F%N9F8L($%L=&$N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,C4P.BTQ,C,N,#@S)UT@/2`G0FEG
M($-R965K)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,C8W.BTQ,#(N
M-#8W)UT@/2`G66]R:W1O;BP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,2XR-C<Z+3@P+C8U,"==(#T@)TUO;W-O;F5E+"!/;G0N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,S8W.BTU-2XV,S,G72`]("=3="X@
M06YT:&]N>2P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XT
M-3`Z+3$Q-BXS,S,G72`]("=9;VAO(%!A<FL@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q
M+C0U,#HM-3<N,3@S)UT@/2`G0FQA;F,@4V%B;&]N+"!1=64N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3$N-#4P.BTY,"XR,#`G72`]("=0:6-K;&4@
M3&%K92P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C0X,SHM
M,3`W+C`U,"==(#T@)T]U=&QO;VL@4&9R82<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4Q+C4Q-SHM,3`Y+C$V-R==(#T@)TMI;F1E<G-L97DL(%-A<VLN
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-34P.BTW,2XQ,3<G72`]
M("=,86,@0F5N;VET)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-38W
M.BTQ,#<N.3$W)UT@/2`G4F]S971O=VX@16%S="P@4V%S:R<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4Q+C8V-SHM,3`U+C0P,"==(#T@)U=A=')O=7,@
M16%S="!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,2XV-C<Z+3$Q,"XR,#`G72`]("=%<W1H97(@,2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C8V-SHM.3@N-S4P)UT@/2`G
M1WEP<W5M=FEL;&4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XW,#`Z
M+3$Q,RXR,3<G72`]("=4:')E92!(:6QL<R<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4Q+C<U,#HM.3DN.3`P)UT@/2`G0F%C:&5L;W)S($ES;&%N9"!!
M=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,2XW-C<Z+3$P-"XR,#`G72`]("=7>6YY87)D+"!387-K+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C<V-SHM,3$T+C8X,R==(#T@
M)U-U;F1R92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C@V-SHM-C,N
M,C@S)UT@/2`G3&%C($5O;BP@475E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3(N,#8W.BTQ,3$N-#4P)UT@/2`G0V]R;VYA=&EO;B!-87)I;F4@079I
M871I;VX@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,BXQ,3<Z+3$P,2XR,S,G72`]("=3=V%N(%)I=F5R+"!-86XN)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,3$W.BTQ,C0N,3,S)UT@/2`G
M4'5N='II($UO=6YT86EN+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4R+C$S,SHM,3$Y+C,P,"==(#T@)T)L=64@4FEV97(L($(N($,N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,34P.BTQ,#8N-34P)UT@/2`G
M4V%S:V%T;V]N($ME<FYE;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R
M+C$V-SHM,3`V+C8X,R==(#T@)U-A<VMA=&]O;BP@4V%S:RXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,BXQ.#,Z+3$Q,RXY,#`G72`]("=2960@1&5E
M<BP@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXQ.#,Z+3$R
M,BXP-3`G72`]("=7:6QL:6%M<R!,86ME+"!"+B!#+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4R+C$X,SHM,3(W+C0V-R==(#T@)T-A=&AE9')A;"!0
M;VEN="!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C(S,SHM.#<N
M.#@S)UT@/2`G3&%N<V1O=VYE($AO=7-E)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3(N,C8W.BTQ,C@N-S$W)UT@/2`G36-I;FYE<R!)<VQA;F0L($(N
M($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,S`P.BTU-2XX,S,G
M72`]("=-87)Y7"=S($AA<F)O=7(L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3(N,S4P.BTY-RXP,S,G72`]("="97)E;G,@4FEV97(@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C,U,#HM.3<N,#,S
M)UT@/2`G0F5R96YS(%)I=F5R($-3+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3(N,S@S.BTQ,C8N-3@S)UT@/2`G0F5L;&$@0V]O;&$@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C0S,SHM,3$T+CDQ
M-R==(#T@)U)O8VMY($UO=6YT86EN($AO=7-E+"!!;'1A)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3(N-#4P.BTQ,3,N-S4P)UT@/2`G3&%C;VUB92!#
M9&$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXV-3`Z+34V+C@V-R==
M(#T@)T%L97AI<R!2:79E<B!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@
M4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4R+C<V-SHM,3`X+C(U,"==(#T@)TYO<G1H($)A='1L969O<F0L(%-A<VLN
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N.#`P.BTY-RXV,3<G72`]
M("='96]R9V4@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0
M<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3(N.#$W.BTQ,#(N,S$W)UT@/2`G2'5D<V]N($)A>2P@4V%S:RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,BXX,3<Z+3$P-"XV,#`G72`]("=-96QF
M;W)T($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,BXX.#,Z+3$Q."XP-C<G72`]("=*87-P
M97(L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N.3,S.BTQ
M,3@N,S$W)UT@/2`G2F%S<&5R(%=A<F1E;B!!=71O;6%T960@4F5P;W)T:6YG
M(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXY,S,Z+38V
M+C@V-R==(#T@)U=A8G5S:"!,86ME+"!.9FQD+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4S+C`S,SHM,3`P+CDS,R==(#T@)TAU;G1E<G,@4&]I;G0@
M36%R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,#,S.BTQ,3(N.#$W
M)UT@/2`G0V%M<F]S92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C`S
M,SHM,3(R+C4Q-R==(#T@)U%U97-N96P@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4S+C`U,#HM,3(Y+C8X,R==(#T@)T5T:&5L9&$@0F%Y
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,3@S.BTY.2XR-C<G72`]
M("='<F%N9"!287!I9',L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,RXR,3<Z+3$P-2XV.#,G72`]("=0<FEN8V4@06QB97)T+"!387-K+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C(U,#HM,3,Q+C@Q-R==(#T@
M)U-A;F1S<&ET+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S
M+C,P,#HM,3$S+C4X,R==(#T@)T5D;6]N=&]N($EN=&5R;F%T:6]N86PL($%L
M=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,S`P.BTQ,3,N-C`P
M)UT@/2`G161M;VYT;VX@26YT97)N871I;VYA;"!#4RP@06QT82XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,RXS,3<Z+3$Q,"XP-C<G72`]("=,;&]Y
M9&UI;FES=&5R+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S
M+C,Q-SHM,3,R+C<U,"==(#T@)TMI;F1A:W5N(%)O8VMS+"!"+B!#+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C,Q-SHM-C`N-#$W)UT@/2`G1V]O
M<V4L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,S,S.BTQ
M,#0N,#`P)UT@/2`G3FEP87=I;BP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,RXS-C<Z+3$P-RXU-3`G72`]("=3<&ER:71W;V]D(%=E<W0L
M(%-A<VLG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXS.#,Z+3$Q."XS
M,S,G72`]("=7:6QL;W<@0W)E96LG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,RXT,3<Z+3$Q,RXR,#`G72`]("=%;&QE<G-L:64G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,RXT-3`Z+3$Q-"XT-C<G72`]("=(:6=H=F%L92<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4P,#HM,3,P+C8S,R==(#T@
M)T)O;FEL;&$@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0
M<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3,N-3,S.BTQ,30N,3`P)UT@/2`G161M;VYT;VX@4W1O;GD@4&QA:6X@06QT
M82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXU-3`Z+38T+C$P,"==
M(#T@)T-H=7)C:&EL;"!&86QL<RP@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,RXU-C<Z+3$Q,RXU,3<G72`]("=%9&UO;G1O;B!-=6YI8VEP
M86P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXU-C<Z+3$Q
M,RXU,3<G72`]("=%9&UO;G1O;B!-=6YI8VEP86P@0U(Q,"P@06QT82XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXU-C<Z+38T+C$P,"==(#T@)T-H
M=7)C:&EL;"!&86QL<R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4X
M,SHM,3$V+C0V-R==(#T@)T5D<V]N+"!!;'1A+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4S+C8Q-SHM,3$R+C`S,R==(#T@)U9E9W)E=FEL;&4@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4S+C8S,SHM-S<N-S`P)UT@/2`G3&$@1W)A;F1E(%)I
M=FEE<F4L(%%U92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C8V-SHM
M,3$S+C0V-R==(#T@)T5D;6]N=&]N($YA;6%O($%L=&$N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3,N-C@S.BTQ,3(N.#8W)UT@/2`G16QK($ES;&%N
M9"!.871I;VYA;"!087)K)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N
M-C@S.BTQ,C0N.#,S)UT@/2`G3F5C:&%K;R!2:79E<B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4S+C<P,#HM-3<N,#,S)UT@/2`G0V%R='=R:6=H="P@
M3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXW,S,Z+3$P-2XR
M-C<G72`]("=#86YD;&4@3&%K92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4S+C<U,#HM-S,N-C8W)UT@/2`G3&$@1W)A;F1E($EV+"!1=64N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-S@S.BTQ,3@N-#,S)UT@/2`G2&5N
M9&5R:6-K<V]N($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXX,S,Z+3@Y+C@V-R==(#T@
M)T)I9R!4<F]U="!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N
M.#4P.BTY-"XV-3`G72`]("=)<VQA;F0@3&%K92P@36%N+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4S+C@X,SHM,3(R+C8X,R==(#T@)U!R:6YC92!'
M96]R9V4L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N.3$W
M.BTQ,#8N,#8W)UT@/2`G5V%S:V5S:74@3&%K92!!=71O;6%T960@4F5P;W)T
M:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXY-C<Z
M+3$P,2XQ,#`G72`]("=4:&4@4&%S+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3,N.38W.BTY-RXX,S,G72`]("=.;W)W87D@2&]U<V4L($UA
M;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-"XQ,S,Z+3$P."XU,3<G
M72`]("=-96%D;W<@3&%K92P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U-"XQ-3`Z+3$Q-2XW.#,G72`]("=7:&ET96-O=7)T+"!!;'1A+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C$U,#HM,3$U+C<X,R==(#T@
M)U=H:71E8V]U<G0L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-30N,38W.BTQ,S`N,S8W)UT@/2`G2&]L;&%N9"!2;V-K($%U=&]M871I8R!7
M96%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U-"XQ-C<Z+3$S,2XV-C<G72`]("=2;W-E(%-P:70@365T96]R;VQO
M9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-"XR-3`Z+3$S,RXQ,S,G72`]("=,86YG
M87)A+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C,P,#HM
M,3,P+C0S,R==(#T@)U!R:6YC92!2=7!E<G0L($(N($,N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-30N,S@S.BTQ,C4N.34P)UT@/2`G0G5R;G,@3&%K
M92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C0Q-SHM,3$P+C(X,R==
M(#T@)T-O;&0@3&%K92P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U-"XT-C<Z+3$R."XU.#,G72`]("=497)R86-E+"!"+B!#+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4T+C4X,SHM,3,P+C<P,"==(#T@)T=R97D@
M27-L970@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO
M;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-"XW-3`Z+3$Q
M,"XP-3`G72`]("=0<FEM<F]S92!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-30N-S8W.BTQ,3(N,#$W)UT@/2`G3&%C($QA($)I8VAE+"!!;'1A
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C<X,SHM,3$P+C`V-R==
M(#T@)U!R:6UR;W-E($QA:V4@,B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4T+C@P,#HM-C8N.#`P)UT@/2`G4V-H969F97)V:6QL92P@475E+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C@Q-SHM,3(W+C$X,R==(#T@)U-M
M:71H97)S+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+CDX
M,SHM.#4N-#,S)UT@/2`G4&5A=V%N=6-K($UE=&5O<F]L;V=I8V%L($%E<F]N
M875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-34N,34P.BTQ,#4N,C8W)UT@/2`G3&$@4F]N9V4L(%-A<VLN
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N,34P.BTQ,#4N,C8W)UT@
M/2`G3&$@4F]N9V4L(%-A<VLG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M-2XQ.#,Z+3$Q."XX.#,G72`]("='<F%N9&4@4')A:7)I92P@06QT82XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-2XR,#`Z+3$Q.2XT,#`G72`]("="
M96%V97)L;V1G92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U+C(X,SHM
M-S<N-S8W)UT@/2`G2W5U:FIU87)A<&EK+"!1=64N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-34N,S`P.BTQ,30N-S@S)UT@/2`G4VQA=F4@3&%K92P@
M06QT82<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U+C,P,#HM,3(S+C$S
M,R==(#T@)TUA8VME;GII92P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U-2XS,S,Z+38S+C(Q-R==(#T@)T)O<F1E<BP@475E+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4U+C0U,#HM-C`N,C,S)UT@/2`G2&]P961A
M;&4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3
M>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-2XV.34Z+3$Q.2XR
M,S0G72`]("=3<&ER:70@4FEV97(@075T;R!3=&%T:6]N+"!!;'1A)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-34N.#`P.BTY-RXX-3`G72`]("=4:&]M
M<'-O;B!796%T:&5R($]F9FEC92P@36%N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-34N.#,S.BTQ,#@N-#,S)UT@/2`G0G5F9F%L;R!.87)R;W=S+"!3
M87-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U+CDS,SHM,3(Y+CDX
M,R==(#T@)U-T97=A<G0@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4V+C(S,SHM,3$W+C0S,R==(#T@)U!E86-E(%)I=F5R+"!!;'1A+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C(S,SHM,3(P+C<S,R==(#T@
M)T9O<G0@4W0@2F]H;BP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U-BXS,S,Z+3$P,RXR.#,G72`]("=3;W5T:&5N9"!!=71O;6%T:6,@5V5A
M=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-38N,S4P.BTY-"XW,#`G72`]("=':6QL86TL($UA;BXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U-BXU,S,Z+3$Q-2XR-C<G72`]("=2960@16%R
M=&@G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-BXU-3`Z+38Q+C8X,R==
M(#T@)TYA:6XL($YF;&0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-BXV
M-3`Z+3$Q,2XR,3<G72`]("=&;W)T($UC375R<F%Y($-3+"!!;'1A+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C8U,#HM,3$Q+C(Q-R==(#T@)T9O
M<G0@36-M=7)R87DL($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-38N-S,S.BTQ,S$N-C8W)UT@/2`G27-K=70@4FEV97(G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U-BXX-C<Z+3$P,2XP.#,G72`]("=,>6YN($QA:V4L
M($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-RXQ,S,Z+38Q+C0X
M,R==(#T@)T-A<&4@2VEG;&%P86ET+"!.9FQD+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4W+C(U,#HM,3`U+C8Q-R==(#T@)TME>2!,86ME)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3<N,S4P.BTQ,#<N,3,S)UT@/2`G0W)E
M92!,86ME($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I
M;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3<N-3,S.BTQ
M,3$N-38W)UT@/2`G36EL9')E9"!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3@N,3`P.BTV."XT,3<G72`]("=+=75J:G5A<2P@475E+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C$X,SHM,3`S+C<P,"==(#T@)T-O
M;&QI;G,@0F%Y($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XS,S,Z+38R+C4X,R==(#T@
M)U-A9VQE:R!"87DG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XS.#,Z
M+3$P.2XU,#`G72`]("=#;'5F9B!,86ME+"!387-K+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4X+C0Q-SHM,3,P+C`P,"==(#T@)T1E87-E($QA:V4@
M0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XT,3<Z+3$S,"XP
M,#`G72`]("=$96%S92!,86ME($-O87-T86P@4W1A=&EO;B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4X+C0U,#HM-S@N,3$W)UT@/2`G26YU:VIU86LL
M(%%U92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C4X,SHM,3$X+C4P
M,"==(#T@)U-O=7-A($-R:R!!=G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U."XV,3<Z+3$Q-RXQ-C<G72`]("=(:6=H($QE=F5L+"!!;'1A)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N-C(R.BTQ,3$N-C<R)UT@/2`G4')A
M:7)I92!2:79E<BP@06QT82<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X
M+C8X,SHM,3$S+C@X,R==(#T@)T=A<F1E;B!2:79E<B!!=71O;6%T:6,@5V5A
M=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3@N-S,S.BTY-"XP-C<G72`]("=#:'5R8VAI;&PL($UA;BXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U."XW-C<Z+3$Q,2XQ,3<G72`]("=&;W)T
M($-H:7!E=WEA;BP@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M."XX,S,Z+3$R,BXU.#,G72`]("=&;W)T($YE;'-O;BP@0BX@0RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U.2XQ,S,Z+3$Q,RXX,#`G72`]("=7871E
M<G1O;B!087)K($=A=&4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U.2XR
M,3<Z+3$P.2XW,#`G72`]("="96%R=&]O=&@@27-L86YD)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3DN,C4P.BTQ,#4N.#,S)UT@/2`G4W1O;GD@4F%P
M:61S($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U.2XU-C<Z
M+3$P."XT.#,G72`]("=5<F%N:75M($-I='DL(%-A<VLN)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3DN.3@S.BTV-"XQ-C<G72`]("=#87!E($MA:VMI
M=FEA:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8P+C`Q-SHM,3$Q+CDU
M,"==(#T@)T9O<G0@4VUI=&@L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-C`N,3$W.BTQ,C@N.#$W)UT@/2`G5V%T<V]N($QA:V4L(%DN
M(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C`N,38W.BTQ,S(N-S,S
M)UT@/2`G5&5S;&EN+"!9+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8P+C0Q-SHM-C0N.#4P)UT@/2`G2VEL;&EN96L@365T96]R;VQO9VEC86P@
M065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V,"XT,S,Z+3$R,2XR,S,G72`]("=4<F]U="!,86ME
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C`N-S$W.BTQ,S4N,#8W)UT@
M/2`G5VAI=&5H;W)S92P@62X@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V,"XW-C<Z+3$S-RXU.#,G72`]("=(86EN97,@2G5N8W1I;VXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<V,"XX,S,Z+3$Q-2XW.#,G72`]("=(87D@
M4FEV97(L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N
M,#4P.BTQ,#DN,S,S)UT@/2`G4&]W9&5R($QA:V4G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<V,2XP-3`Z+38Y+C8S,R==(#T@)U%U87%T87$@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Q+C$Q-SHM,3(R+C@U,"==
M(#T@)TQI;F1B97)G($QA;F1I;F<L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C$N,3,S.BTQ,#`N.3`P)UT@/2`G16YN861A:2!,86ME
M($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES
M=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N,S$W.BTQ,3<N-C`P
M)UT@/2`G1F]R="!0<F]V:61E;F-E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-C$N,S8W.BTQ,SDN,#4P)UT@/2`G0G5R=V%S:"!!=71O;6%T:6,@5V5A
M=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-C$N-3@S.BTV-"XV-3`G72`]("=297-O;'5T:6]N($ES;&%N9"P@3BX@
M5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XV,S,Z+3$R-2XX
M,#`G72`]("=6:7)G:6YI82!&86QL<R<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S8Q+C8V-SHM,3`X+C0Q-R==(#T@)U!O<G1E<B!,86ME)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C$N-S4P.BTQ,C$N,C,S)UT@/2`G1F]R="!3
M:6UP<V]N+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Q
M+CDQ-SHM,3$S+C<S,R==(#T@)TEN;F5R(%=H86QE8F%C:W,G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V,2XY-C<Z+3$R-RXR,3<G72`]("=286)B:70@
M2V5T=&QE($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8R+C$Q-SHM,3,V+C$X,R==(#T@)T-A<FUA8VMS
M($-3+"!9+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8R+C(S,SHM
M,3,S+C,U,"==(#T@)T9A<F\L(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C(N-#8W.BTQ,30N-#4P)UT@/2`G665L;&]W:VYI9F4L($XN(%<N
M(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C(N-S`P.BTY."XS,#`G
M72`]("=9871H:WEE9"!,86ME($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A
M;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-C(N-S$W.BTQ,#DN,3@S)UT@/2`G1F]R="!296QI86YC92P@3BX@5RX@
M5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,BXX,3<Z+3DR+C$Q-R==
M(#T@)U)A;FMI;B!);FQE="P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V,RXQ-3`Z+3$Q-RXR-C<G72`]("=,86,@3&$@36%R=')E)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C,N,C,S.BTQ,#$N-S8W)UT@/2`G
M1'5B87=N="!,86ME($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S
M96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C,N
M,S,S.BTV-"XQ-3`G72`]("="<F5V;V]R="!)<VQA;F0G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V,RXU.#,Z+3$P-2XQ-3`G72`]("=(86YB=7)Y(%)I
M=F5R($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8S+C8P,#HM,3$S+C@V-R==(#T@)TQO=V5R($-A<G`@
M3&%K92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,RXV
M,3<Z+3$S-2XX-C<G72`]("=-87EO($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<V,RXW-3`Z+38X+C4U,"==(#T@)TEQ86QU:70L($XN(%<N
M(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C0N,#4P.BTQ,SDN,3,S
M)UT@/2`G1&%W<V]N+"!9+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8T+C$Q-SHM,3$W+C,V-R==(#T@)U)A92!,86ME<R<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8T+C(P,#HM.#,N,S8W)UT@/2`G0V]R86P@2&%R8F]U
M<BP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-"XR,3<Z
M+3<V+C4S,R==(#T@)T-A<&4@1&]R<V5T+"!.+B!7+B!4+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8T+C,P,#HM.38N,#@S)UT@/2`G0F%K97(@3&%K
M92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-"XS.#,Z
M+3$Q-2XP,3<G72`]("=);F1I86X@4FEV97(G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V-"XW-3`Z+3$R-"XR,3<G72`]("=3="!#:&%R;&5S($-R965K
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C0N.34P.BTV,RXU.#,G72`]
M("=#87!E($UE<F-Y)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C4N,3`P
M.BTQ,#(N-#,S)UT@/2`G4F]B97)T<V]N($QA:V4@075T;VUA=&5D(%)E<&]R
M=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C4N,C$W
M.BTQ,C,N-#,S)UT@/2`G1&5L:6YE+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8U+C(X,SHM,3(V+C@P,"==(#T@)TYO<FUA;B!796QL
M<RP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-2XV,3<Z
M+3$Q."XQ,3<G72`]("=#86US96QL(%)I=F5R+"!.+B!7+B!4+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8U+C<V-SHM,3$Q+C(S,R==(#T@)TQU<&EN
M+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8U+CDU,#HM
M,3,P+C0V-R==(#T@)U)A;7!A<G0@4FEV97(@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8V
M+C`P,#HM,3$W+C<V-R==(#T@)T-L=70@3&%K92!!=71O;6%T960@4F5P;W)T
M:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-BXP,S,Z
M+3DQ+C@S,R==(#T@)T(L(%(G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V
M-BXP.#,Z+3DV+C4P,"==(#T@)T)A8VL@4FEV97(@365T96]R;VQO9VEC86P@
M065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V-BXQ-3`Z+38U+C<S,R==(#T@)U!A;F=N:7)T=6YG
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C8N-3@S.BTV,2XV,3<G72`]
M("=#87!E($1Y97(L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-C8N.#8W.BTQ,S0N,C`P)UT@/2`G4V%T86@@4FEV97(@075T;VUA=&EC
M(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8W+C`S,SHM,3(V+C`X,R==(#T@)T-O;'9I;&QE($QA:V4G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-RXP-C<Z+3$R,2XQ,#`G72`]("=(
M86QD86YE(%)I=F5R($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-RXR,#`Z+3$S,"XR,3<G
M72`]("=,:71T;&4@0VAI8V%G;R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8W+C4S,SHM-C,N-S@S)UT@/2`G0G)O=6=H=&]N($ES;&%N9"<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8W+C4V-SHM,3,Y+C@S,R==(#T@)T]L9"!#
M<F]W($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<V-RXW,#`Z+3$P-"XT-C<G72`]("=%;&QI
M8V4@4FEV97(@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C<N.#$W.BTQ,34N,3,S)UT@/2`G0V]P<&5R
M;6EN92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XR
M-3@Z+3$R,BXQ,#0G72`]("=1879V:6L@3&%K92P@3BX@5RX@5"XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<V."XS,#`Z+3$S,RXT.#,G72`]("=);G5V
M:6LL($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N,S`P
M.BTX-2XV-C<G72`]("=-86-K87(@26YL970G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V."XS,3<Z+3$P,"XP.#,G72`]("=(870@27-L86YD+"!.+B!7
M+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C0S,SHM.#DN-S$W
M)UT@/2`G4&5L;'D@0F%Y)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N
M-#8W.BTV-BXX,#`G72`]("=#87!E($AO;W!E<BP@3BX@5RX@5"XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<V."XU,#`Z+3$Q,RXR,3<G72`]("=,861Y
M($9R86YK;&EN(%!O:6YT+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8X+C8U,#HM,3`Q+C<S,R==(#T@)TIE;FYY($QI;F0@27-L86YD
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XV-3`Z+3<Q
M+C$V-R==(#T@)T1E=V%R($QA:V5S+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8X+C<U,#HM,3`Y+C`V-R==(#T@)T)Y<F]N($)A>2!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N-S4P.BTQ,S,N
M-3`P)UT@/2`G5')A:6P@5F%L;&5Y+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8X+C<X,SHM,3$T+C@S,R==(#T@)T)E<FYA<F0@2&%R
M8F]U<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C<X,SHM.#$N,C4P
M)UT@/2`G2&%L;"!"96%C:"P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V."XX,3<Z+3DS+C0S,R==(#T@)U-H97!H97)D($)A>2P@3BX@
M5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XX.#,Z+3<U+C$S
M,R==(#T@)TQO;F=S=&%F9B!";'5F9BP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V."XY,#`Z+3$S,RXY,S,G72`]("=3=&]R;2!(:6QL
M<RP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XY,S,Z
M+3$Q-BXY,3<G72`]("=#87!E(%EO=6YG($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V."XY-3`Z+3$S-RXR,3<G72`]("=3:&EN9VQE(%!O
M:6YT+"!9+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+C$P,#HM
M,3`U+C$Q-R==(#T@)T-A;6)R:61G92!"87DL($XN(%<N(%0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-CDN,34P.BTQ-#`N,34P)UT@/2`G279V879I
M:R!087)K($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XQ.#,Z+3$R,BXS-3`G72`]("=4
M=6MT=70@3F]G86ET+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S8Y+C,U,#HM,3(T+C`U,"==(#T@)U!A=6QA='5K($%U=&]M871E9"!2
M97!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y
M+C0S,SHM,3,S+C`S,R==(#T@)U1U:W1O>6%K='5K($%U=&]M871E9"!297!O
M<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+C0S
M,SHM.#DN-S,S)UT@/2`G4&5L;'D@0F%Y(#$G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V.2XT-3`Z+3$S,RXP,3<G72`]("=4=6MT;WEA:W1U:R<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+C4V-SHM,3,X+CDQ-R==(#T@)TAE
M<G-C:&5L($ES;&%N9"!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES
M=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN-3@S.BTQ-#`N,3@S
M)UT@/2`G2V]M86MU:R!"96%C:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-CDN-C`P.BTQ,S`N.3`P)UT@/2`G3&EV97)P;V]L($)A>2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+C8Q-SHM,30P+C(P,"==(#T@
M)TMO;6%K=6L@0F5A8V@L(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-CDN-C,S.BTQ,S4N-#,S)UT@/2`G4&5L;'D@27-L86YD($%U=&]M871I
M8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V.2XY,S,Z+3$R."XY-C<G72`]("=.:6-H;VQS;VX@4&5N:6YS
M=6PG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<W,"XQ-C<Z+3$R-"XW,#`G
M72`]("=#87!E(%!A<G)Y+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S<P+C0X,SHM-C@N-3$W)UT@/2`G0VQY9&4L($XN(%<N(%0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-S(N,#`P.BTQ,C4N,C8W)UT@/2`G
M4V%C:',@2&%R8F]U<BP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<W,BXW,#`Z+3<W+CDV-R==(#T@)U!O;F0@26YL970L($XN(%<N(%0N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-S0N,3,S.BTQ,3DN.3@S)UT@
M/2`G075L=FEK($YA=&EO;F%L(%!A<FLG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<W-"XW,3<Z+3DT+CDX,R==(#T@)U)E<V]L=71E+"!.+B!7+B!4+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<V+C(S,SHM,3$Y+C,S,R==(#T@
M)TUO=6QD($)A>2P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<W."XW.#,Z+3$P,RXU-3`G72`]("=)<V%C:'-E;B!-971E;W)O;&]G:6-A
M;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S<Y+CDX,SHM.#4N.3,S)UT@/2`G175R96MA+"!.
M+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S@R+C4P,#HM-C(N
M,S,S)UT@/2`G06QE<G0L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#87!E
M(%9E<F1E)UU;)S$V+C<S,SHM,C(N.34P)UT@/2`G4V%L)SL*)&-O;W)D:6YA
M=&5S6R=#87EM86X@27-L86YD<R==6R<Q.2XR.#,Z+3@Q+C,U,"==(#T@)T]W
M96X@4F]B97)T<R!!:7)P;W)T9W)A;F0@0V%Y;6%N)SL*)&-O;W)D:6YA=&5S
M6R=#96YT<F%L($%F<FEC86X@4F5P=6)L:6,G75LG,3`N,C@S.C(R+C<X,R==
M(#T@)T)I<F%O)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,G75LG-"XR-3`Z,34N.#`P)UT@/2`G0F5R8F5R871I)SL*)&-O;W)D
M:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L:6,G75LG-"XT,#`Z,3@N
M-3$W)UT@/2`G0F%N9W5I)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,G75LG-"XW,S,Z,C(N.#,S)UT@/2`G0F%N9V%S<V]U)SL*
M)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L:6,G75LG-2XP
M-3`Z,C$N,C`P)UT@/2`G06QI;F1A;R<["B1C;V]R9&EN871E<ULG0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S4N,C8W.C$W+C8S,R==(#T@)T)O<W-E
M;6)E;&4G.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI
M8R==6R<U+C0P,#HR-BXU,#`G72`]("=/8F\G.PHD8V]O<F1I;F%T97-;)T-E
M;G1R86P@069R:6-A;B!297!U8FQI8R==6R<U+C@U,#HR,"XV-3`G72`]("="
M86UB87)I)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,G75LG-2XY-C<Z,34N-C,S)UT@/2`G0F]U87(G.PHD8V]O<F1I;F%T97-;
M)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<V+C0X,SHQ-RXT,S,G72`]
M("=";W-S86YG;V$G.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R==6R<V+C4P,#HR,RXR-C<G72`]("=986QI;F=A)SL*)&-O;W)D
M:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L:6,G75LG-BXU,S,Z,C$N
M.3@S)UT@/2`G0G)I82<["B1C;V]R9&EN871E<ULG0V5N=')A;"!!9G)I8V%N
M(%)E<'5B;&EC)UU;)S@N-#`P.C(P+C8U,"==(#T@)TY<)T1E;&4G.PHD8V]O
M<F1I;F%T97-;)T-H860G75LG,3$N,#,S.C(P+C(X,R==(#T@)T%M+51I;6%N
M)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)S$R+C$S,SHQ-2XP,S,G72`]("=.
M9&IA;65N82<["B1C;V]R9&EN871E<ULG0VAA9"==6R<Q,BXS.#,Z,3<N,#4P
M)UT@/2`G0F]K;W)O)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)S$S+C0S,SHQ
M-"XW,S,G72`]("=";VPM0F5R:6TG.PHD8V]O<F1I;F%T97-;)T-H860G75LG
M,3,N.#4P.C(P+C@U,"==(#T@)T%B96-H92<["B1C;V]R9&EN871E<ULG0VAA
M9"==6R<Q."XP,#`Z,3DN,38W)UT@/2`G1F%Y82<["B1C;V]R9&EN871E<ULG
M0VAA9"==6R<X+C8Q-SHQ-BXP-C<G72`]("=-;W5N9&]U)SL*)&-O;W)D:6YA
M=&5S6R=#:&%D)UU;)SDN,34P.C$X+C,X,R==(#T@)U-A<F@G.PHD8V]O<F1I
M;F%T97-;)T-H860G75LG.2XS-C<Z,30N.3$W)UT@/2`G4&%L82<["B1C;V]R
M9&EN871E<ULG0VAI;&4G75LG+3$X+C,S,SHM-S`N,S,S)UT@/2`G07)I8V$G
M.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTR,"XU,S,Z+3<P+C$X,R==(#T@
M)TEQ=6EQ=64@+R!$:65G;R!!<F%C)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==
M6R<M,C,N-#,S.BTW,"XT,S,G72`]("=!;G1O9F%G87-T82<["B1C;V]R9&EN
M871E<ULG0VAI;&4G75LG+3(V+C,Q-SHM-S`N-C$W)UT@/2`G0VAA;F%R86PG
M.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTR-RXQ-3`Z+3$P.2XT,3<G72`]
M("=)<VQA($1E(%!A<V-U82<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3(W
M+C,P,#HM-S`N-#$W)UT@/2`G0V]P:6%P;R<["B1C;V]R9&EN871E<ULG0VAI
M;&4G75LG+3(X+C8P,#HM-S`N-S8W)UT@/2`G5F%L;&5N87(G.PHD8V]O<F1I
M;F%T97-;)T-H:6QE)UU;)RTR.2XY,#`Z+3<Q+C(P,"==(#T@)TQA(%-E<F5N
M82<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3,R+C<X,SHM-S$N-3$W)UT@
M/2`G475I;G1E<F\@4V%N=&EA9V\G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;
M)RTS,RXS.#,Z+3<P+C<X,R==(#T@)U!U9&%H=65L)SL*)&-O;W)D:6YA=&5S
M6R=#:&EL92==6R<M,S0N.38W.BTW,2XR,S,G72`]("=#=7)I8V\G.PHD8V]O
M<F1I;F%T97-;)T-H:6QE)UU;)RTS-BXU-C<Z+3<R+C`S,R==(#T@)T-H:6QL
M86XG.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTS-BXW-C<Z+3<S+C`U,"==
M(#T@)T-O;F-E<&-I;VXG.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTS."XW
M-3`Z+3<R+C8S,R==(#T@)U1E;75C;R<["B1C;V]R9&EN871E<ULG0VAI;&4G
M75LG+3,Y+C8Q-SHM-S,N,#@S)UT@/2`G5F%L9&EV:6$G.PHD8V]O<F1I;F%T
M97-;)T-H:6QE)UU;)RTT,2XT,3<Z+3<S+C`X,R==(#T@)U!U97)T;R!-;VYT
M="<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+30U+C4X,SHM-S(N,3$W)UT@
M/2`G0V]Y:&%I<75E)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M-#4N.3$W
M.BTW,2XV.#,G72`]("="86QM86-E9&$G.PHD8V]O<F1I;F%T97-;)T-H:6QE
M)UU;)RTT-BXU-3`Z+3<Q+C<P,"==(#T@)T-H:6QE($-H:6-O)SL*)&-O;W)D
M:6YA=&5S6R=#:&EL92==6R<M-#<N,C,S.BTW,BXU-3`G72`]("=#;V-H<F%N
M92<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+34S+C`P,#HM-S`N.#4P)UT@
M/2`G4'5N=&$@07)E;F%S)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R,"XP
M,S,Z,3$P+C,U,"==(#T@)TAA:6MO=2<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,C$N,C$W.C$Q,"XT,#`G72`]("=::&%N:FEA;F<G.PHD8V]O<F1I;F%T
M97-;)T-H:6YA)UU;)S(R+C4U,#HQ,30N,3`P)UT@/2`G4VAE;GIH96XG.PHD
M8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(R+C@Q-SHQ,#@N,S4P)UT@/2`G3F%N
M;FEN9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C,N,38W.C$Q,RXS,S,G
M72`]("='=6%N9WIH;W4G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(S+C0P
M,#HQ,38N-C@S)UT@/2`G4VAA;G1O=2<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,C0N-#@S.C$Q."XP.#,G72`]("=8:6%M96XG.PHD8V]O<F1I;F%T97-;
M)T-H:6YA)UU;)S(U+C`Q-SHQ,#(N-C@S)UT@/2`G2W5N;6EN9R<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG,C4N,S,S.C$Q,"XS,#`G72`]("='=6EL:6XG
M.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(U+C@U,#HQ,30N.34P)UT@/2`G
M1V%N>FAO=2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C8N,#@S.C$Q.2XR
M.#,G72`]("=&=7IH;W4G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(V+C4X
M,SHQ,#8N-S$W)UT@/2`G1W5I>6%N9R<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,C@N,C`P.C$Q,RXP.#,G72`]("=#:&%N9W-H82<["B1C;V]R9&EN871E
M<ULG0VAI;F$G75LG,C@N-C`P.C$Q-2XY,3<G72`]("=.86YC:&%N9R<["B1C
M;V]R9&EN871E<ULG0VAI;F$G75LG,CDN-3$W.C$P-BXT.#,G72`]("=#:&]N
M9W%I;F<G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(Y+C8V-SHY,2XQ,S,G
M72`]("=,:&%S82<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S`N,C,S.C$R
M,"XQ-C<G72`]("=(86YG>FAO=2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG
M,S`N-C$W.C$Q-"XQ,S,G72`]("=7=6AA;B<["B1C;V]R9&EN871E<ULG0VAI
M;F$G75LG,S`N-C8W.C$P-"XP,3<G72`]("=#:&5N9V1U)SL*)&-O;W)D:6YA
M=&5S6R=#:&EN82==6R<S,2XQ-C<Z,3(Q+C0S,R==(#T@)U-H86YG:&%I("\@
M2&]N9W%I86\G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,Q+C@V-SHQ,3<N
M,C,S)UT@/2`G2&5F96DG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,R+C`P
M,#HQ,3@N.#`P)UT@/2`G3F%N:FEN9R<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,S0N,S`P.C$P."XY,S,G72`]("=8:5PG06XG.PHD8V]O<F1I;F%T97-;
M)T-H:6YA)UU;)S,T+C<Q-SHQ,3,N-C4P)UT@/2`G6FAE;F=Z:&]U)SL*)&-O
M;W)D:6YA=&5S6R=#:&EN82==6R<S-BXP-C<Z,3(P+C,S,R==(#T@)U%I;F=D
M86\G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,V+C8P,#HQ,#DN-3`P)UT@
M/2`G66%N($%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-BXV,3<Z,3`Q
M+C<V-R==(#T@)UAI;FEN9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S8N
M-C@S.C$Q-BXY.#,G72`]("=*:6YA;B<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,S<N,3,S.C<Y+CDS,R==(#T@)TAO=&%N)SL*)&-O;W)D:6YA=&5S6R=#
M:&EN82==6R<S-RXW.#,Z,3$R+C4U,"==(#T@)U1A:7EU86XG.PHD8V]O<F1I
M;F%T97-;)T-H:6YA)UU;)S,X+C0X,SHQ,#8N,C$W)UT@/2`G66EN8VAU86XG
M.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,X+CDP,#HQ,C$N-C,S)UT@/2`G
M1&%L:6%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S.2XT-C<Z-S4N.3@S
M)UT@/2`G2V%S:&DG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,Y+C<V-SHY
M."XT.#,G72`]("=*:75Q=6%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S
M.2XY,S,Z,3$V+C(X,R==(#T@)T)E:6II;F<G.PHD8V]O<F1I;F%T97-;)T-H
M:6YA)UU;)S0P+C@Q-SHQ,3$N-C@S)UT@/2`G2&]H:&]T)SL*)&-O;W)D:6YA
M=&5S6R=#:&EN82==6R<T,BXX,3<Z.3,N-3$W)UT@/2`G2&%M:2<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG-#,N.3`P.C$R-2XR,3<G72`]("=#:&%N9V-H
M=6XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S0S+CDU,#HX,2XS,S,G72`]
M("=9:6YI;F<G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S0W+C,X,SHQ,C,N
M.3$W)UT@/2`G46EQ:6AA<B<["B1C;V]R9&EN871E<ULG0VAR:7-T;6%S($ES
M;&%N9"==6R<M,3`N-#,S.C$P-2XV.#,G72`]("=#:')I<W1M87,@27-L86YD
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG0VAR:7-T;6%S($ES;&%N9"==
M6R<M,3(N,3@S.CDV+C@Q-R==(#T@)T-O8V]S($ES;&%N9"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<P+C4P,#HM-S8N-3`P)UT@/2`G
M4'5E<G1O($%S:7,G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S`N.#$W
M.BTW-RXV,S,G72`]("=)<&EA;&5S("\@4V%N($QU:7,G.PHD8V]O<F1I;F%T
M97-;)T-O;&]M8FEA)UU;)S$N,3,S.BTW,"XP-3`G72`]("=-:71U)SL*)&-O
M;W)D:6YA=&5S6R=#;VQO;6)I82==6R<Q+C0Q-SHM-S<N,C8W)UT@/2`G4&%S
M=&\@+R!!;G1O;FEO($YA<FEN)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==
M6R<Q,"XT,S,Z+3<S+C(U,"==(#T@)U9A;&QE9'5P87(@+R!!;&9O;G-O($QO
M<&5Z)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<Q,"XT-3`Z+3<U+C4Q
M-R==(#T@)T-A<G1A9V5N82`O(%)A9F%E;"!.=6YE>B<["B1C;V]R9&EN871E
M<ULG0V]L;VUB:6$G75LG,3`N.#@S.BTW-"XW.#,G72`]("="87)R86YQ=6EL
M;&$@+R!%<FYE<W1O8V]R=&ES<V]Z)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I
M82==6R<Q,2XQ,S,Z+3<T+C(S,R==(#T@)U-A;G1A($UA<G1A("\@4VEM;VX@
M0F]L:79A<B<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,3$N-3,S.BTW
M,BXY,S,G72`]("=2:6]H86-H82`O($%L;6ER86YT92!0861I;&QA)SL*)&-O
M;W)D:6YA=&5S6R=#;VQO;6)I82==6R<Q,BXU.#,Z+3@Q+C<Q-R==(#T@)U-A
M;B!!;F1R97,@27-L82`O(%-E<W%U:6-E;G1E;F%R:6\G.PHD8V]O<F1I;F%T
M97-;)T-O;&]M8FEA)UU;)S$S+C,V-SHM.#$N,S4P)UT@/2`G4')O=FED96YC
M:6$@27-L82`O($5L($5M8G)U:F\G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA
M)UU;)S(N-#8W.BTW-BXV,#`G72`]("=0;W!A>6%N("\@1W5I;&QE<FUO)SL*
M)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<R+C4V-SHM-S(N-C,S)UT@/2`G
M4V%N($IO<V4@1&5L($=U879I87)E)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I
M82==6R<R+CDV-SHM-S4N,S`P)UT@/2`G3F5I=F$@+R!"96YI=&\@4V%L87,G
M.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S,N-34P.BTW-BXS.#,G72`]
M("=#86QI("\@06QF;VYS;R!";VYI;&QA87)A9V]N)SL*)&-O;W)D:6YA=&5S
M6R=#;VQO;6)I82==6R<S+C@U,#HM-S8N.38W)UT@/2`G0G5E;F%V96YT=7)A
M)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<M-"XQ-C<Z+38Y+CDU,"==
M(#T@)TQE=&EC:6$@+R!687-Q=65Z($-O8F\G.PHD8V]O<F1I;F%T97-;)T-O
M;&]M8FEA)UU;)S0N,38W.BTW,RXV,3<G72`]("=6:6QL879I8V5N8VEO("\@
M5F%N9W5A<F1I82<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-"XT,S,Z
M+3<U+C$U,"==(#T@)TEB86=U92`O(%!E<F%L97,G.PHD8V]O<F1I;F%T97-;
M)T-O;&]M8FEA)UU;)S0N-3`P.BTW-2XW,3<G72`]("=!<FUE;FEA("\@16P@
M161E;B<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-"XW,3<Z+3<T+C$U
M,"==(#T@)T)O9V]T82`O($5L9&]R861O)SL*)&-O;W)D:6YA=&5S6R=#;VQO
M;6)I82==6R<T+C@Q-SHM-S4N-S,S)UT@/2`G4&5R96ER82`O($UA=&5C86YA
M)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<U+C<Q-SHM-S8N-C$W)UT@
M/2`G475I8F1O("\@16P@0V%R86YO)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I
M82==6R<V+C$S,SHM-S4N-#,S)UT@/2`G4FEO;F5G<F\@+R!*+B!-+B!#;W)D
M;W9A)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<V+C$V-SHM-C<N-3`P
M)UT@/2`G4'5E<G1O($-A<G)E;F\@+R!!+B!'=6%U<75E82<["B1C;V]R9&EN
M871E<ULG0V]L;VUB:6$G75LG-BXR,3<Z+3<U+C8P,"==(#T@)TUE9&5L;&EN
M("\@3VQA>6$@2&5R<F5R82<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG
M-RXP,3<Z+3<S+C@P,"==(#T@)T)A<G)A;F-A8F5R;65J82`O(%EA<FEG=6EE
M<R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-RXP-C<Z+3<P+C<S,R==
M(#T@)T%R875C82`O(%-A;G1I86=O(%!E<F5Z)SL*)&-O;W)D:6YA=&5S6R=#
M;VQO;6)I82==6R<W+C$P,#HM-S,N,C`P)UT@/2`G0G5C87)A;6%N9V$@+R!0
M86QO;F5G<F\G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S<N.#$W.BTW
M-BXW,#`G72`]("=!<&%R=&%D;R`O($QO<R!#961R;W,G.PHD8V]O<F1I;F%T
M97-;)T-O;&]M8FEA)UU;)S<N.3,S.BTW,BXU,3<G72`]("=#=6-U=&$@+R!#
M86UI;&\@1&%Z82<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG."XX,3<Z
M+3<U+C@U,"==(#T@)TUO;G1E<FEA("\@3&]S($=A<GIO;F5S)SL*)&-O;W)D
M:6YA=&5S6R=#;VUO<F]S)UU;)RTQ,2XU,S,Z-#,N,C8W)UT@/2`G2&%H87EA
M($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V]M;W)O
M<R==6R<M,3(N,3$W.C0T+C0S,R==(#T@)T]U86YI($%N:F]U86XG.PHD8V]O
M<F1I;F%T97-;)T-O;6]R;W,G75LG+3$R+C@P,#HT-2XR.#,G72`]("=$>F%O
M=61Z:2`O(%!A;6%N>FD@36%Y;W1T92<["B1C;V]R9&EN871E<ULG0V]N9V\G
M75LG+3`N,#$W.C$U+C4X,R==(#T@)TUA:V]U82<["B1C;V]R9&EN871E<ULG
M0V]N9V\G75LG,2XV,3<Z,38N,#4P)UT@/2`G3W5E<W-O)SL*)&-O;W)D:6YA
M=&5S6R=#;VYG;R==6R<Q+C8Q-SHQ."XP-C<G72`]("=);7!F;VYD;R<["B1C
M;V]R9&EN871E<ULG0V]N9V\G75LG+3$N.#8W.C$U+C@V-R==(#T@)T=A;6)O
M;6$G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)S(N,#8W.C$T+C$S,R==(#T@
M)U-O=6%N:V4G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTR+C4S,SHQ-"XW
M-C<G72`]("=$:F%M8F%L82<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG+3(N
M-C$W.C$V+C(Q-R==(#T@)TU<)U!O=7EA)SL*)&-O;W)D:6YA=&5S6R=#;VYG
M;R==6R<M,RXT.#,Z,3(N-C$W)UT@/2`G36%K86)A;F$G.PHD8V]O<F1I;F%T
M97-;)T-O;F=O)UU;)RTS+C8X,SHQ,RXS-3`G72`]("=3:6)I=&DG.PHD8V]O
M<F1I;F%T97-;)T-O;F=O)UU;)RTS+CDX,SHQ,RXY,3<G72`]("=-;W5Y;VYD
M>FDG.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTT+C(P,#HQ,BXW,#`G72`]
M("=,;W5B;VUO)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==6R<M-"XR-3`Z,34N
M,C4P)UT@/2`G0G)A>GIA=FEL;&4@+R!-87EA+4UA>6$G.PHD8V]O<F1I;F%T
M97-;)T-O;F=O)UU;)RTT+C@Q-SHQ,2XY,#`G72`]("=0;VEN=&4M3F]I<F4G
M.PHD8V]O<F1I;F%T97-;)T-O;VL@27-L86YD<R==6R<M,3DN,#8W.BTQ-CDN
M.3$W)UT@/2`G06QO9FD@+R!.:75E)SL*)&-O;W)D:6YA=&5S6R=#;V]K($ES
M;&%N9',G75LG+3(Q+C(P,#HM,34Y+C@Q-R==(#T@)U)A<F]T;VYG82<["B1C
M;V]R9&EN871E<ULG0V]S=&$@4FEC82==6R<Q,"XP,#`Z+3@S+C`U,"==(#T@
M)U!U97)T;R!,:6UO;B<["B1C;V]R9&EN871E<ULG0V]S=&$@4FEC82==6R<Q
M,"XP,#`Z+3@T+C(Q-R==(#T@)TIU86X@4V%N=&%M87)I82<["B1C;V]R9&EN
M871E<ULG0V]S=&$@4FEC82==6R<Q,"XQ-3`Z+3@U+C0U,"==(#T@)TYI8V]Y
M82<["B1C;V]R9&EN871E<ULG0V]S=&$@4FEC82==6R<Q,"XV,3<Z+3@U+C0S
M,R==(#T@)TQI8F5R:6$G.PHD8V]O<F1I;F%T97-;)T-O<W1A(%)I8V$G75LG
M."XY-3`Z+3@S+C0V-R==(#T@)U!A;&UA<B!3=7(G.PHD8V]O<F1I;F%T97-;
M)T-O=&4@1%PG279O:7)E)UU;)S0N-#$W.BTW+C,V-R==(#T@)U1A8F]U)SL*
M)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<T+C<U,#HM-BXV-3`G
M72`]("=386X@4&5D<F\G.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E
M)UU;)S0N.34P.BTV+C`X,R==(#T@)U-A<W-A;F1R82<["B1C;V]R9&EN871E
M<ULG0V]T92!$7"=)=F]I<F4G75LG-2XR-3`Z+3,N.3,S)UT@/2`G06)I9&IA
M;B<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G75LG-2XS,#`Z+3,N
M,S`P)UT@/2`G061I86ME)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER
M92==6R<V+C$S,SHM-2XY-3`G72`]("='86=N;V$G.PHD8V]O<F1I;F%T97-;
M)T-O=&4@1%PG279O:7)E)UU;)S8N-C4P.BTT+C<P,"==(#T@)T1I;6)O:W)O
M)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<V+C@V-SHM-BXT
M-C<G72`]("=$86QO82<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G
M75LG-BXY,#`Z+34N,S4P)UT@/2`G66%M;W5S<V]U:W)O)SL*)&-O;W)D:6YA
M=&5S6R=#;W1E($1<)TEV;VER92==6R<W+C,X,SHM-RXU,3<G72`]("=-86XG
M.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S<N-S,S.BTU+C`V
M-R==(#T@)T)O=6%K92<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G
M75LG."XP-3`Z+3(N-S@S)UT@/2`G0F]N9&]U:V]U)SL*)&-O;W)D:6YA=&5S
M6R=#;W1E($1<)TEV;VER92==6R<Y+C0Q-SHM-2XV,3<G72`]("=+;W)H;V=O
M)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<Y+C4P,#HM-RXU
M-C<G72`]("=/9&EE;FYE)SL*)&-O;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0R
M+C4V-SHQ."XR-C<G72`]("=$=6)R;W9N:6L@+R!#:6QI<&DG.PHD8V]O<F1I
M;F%T97-;)T-R;V%T:6$G75LG-#,N,38W.C$V+C0U,"==(#T@)TAV87(G.PHD
M8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#,N-3,S.C$V+C,P,"==(#T@)U-P
M;&ET("\@4F5S;FEK)SL*)&-O;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0T+C$P
M,#HQ-2XS-3`G72`]("=:861A<B`O(%IE;75N:6LG.PHD8V]O<F1I;F%T97-;
M)T-R;V%T:6$G75LG-#4N,#,S.C$X+C@P,"==(#T@)T]S:6IE:R`O($-E<&EN
M)SL*)&-O;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0U+C$V-SHQ."XP,#`G72`]
M("=3;&%V;VYS:VD@0G)O9"<["B1C;V]R9&EN871E<ULG0W)O871I82==6R<T
M-2XR,3<Z,30N-3@S)UT@/2`G4FEJ96MA("\@3VUI<V%L:B<["B1C;V]R9&EN
M871E<ULG0W)O871I82==6R<T-2XW,S,Z,38N,#8W)UT@/2`G6F%G<F5B("\@
M4&QE<V\G.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#4N.#$W.C$V+C`S
M,R==(#T@)UIA9W)E8B`O($UA:W-I;6ER)SL*)&-O;W)D:6YA=&5S6R=#<F]A
M=&EA)UU;)S0U+CDP,#HQ,RXY,3<G72`]("=0=6QA($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG0W)O871I82==6R<T-BXS,#`Z,38N,S@S)UT@/2`G5F%R
M87ID:6XG.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG,3DN.3`P.BTW-2XQ,S,G
M72`]("='=6%N=&%N86UO+"!/<FEE;G1E)SL*)&-O;W)D:6YA=&5S6R=#=6)A
M)UU;)S$Y+CDV-SHM-S4N.#4P)UT@/2`G4V%N=&EA9V\@1&4@0W5B82P@3W)I
M96YT92<["B1C;V]R9&EN871E<ULG0W5B82==6R<R,"XP.#,Z+3<U+C$U,"==
M(#T@)T=U86YT86YA;6\L($]R:65N=&4G.PHD8V]O<F1I;F%T97-;)T-U8F$G
M75LG,C`N,S,S.BTW-RXQ,3<G72`]("=-86YZ86YI;&QO+"!/<FEE;G1E)SL*
M)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(P+C,U,#HM-S0N-3`P)UT@/2`G0F%R
M86-O82P@3W)I96YT92<["B1C;V]R9&EN871E<ULG0W5B82==6R<R,"XY-3`Z
M+3<V+CDU,"==(#T@)TQA<R!4=6YA<RP@3&%S(%1U;F%S)SL*)&-O;W)D:6YA
M=&5S6R=#=6)A)UU;)S(Q+C0Q-SHM-S<N.#4P)UT@/2`G0V%M86=U97D@065R
M;W!U97)T;R<["B1C;V]R9&EN871E<ULG0W5B82==6R<R,2XW.#,Z+3<X+C<X
M,R==(#T@)U9E;F5Z=65L82P@0VEE9V\@1&4@079I;&$G.PHD8V]O<F1I;F%T
M97-;)T-U8F$G75LG,C$N.#,S.BTX,BXW.#,G72`]("=.=65V82!'97)O;F$L
M($ES;&$@1&4@4&EN;W,G.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG,C(N,34P
M.BTX,"XT,#`G72`]("=#:65N9G5E9V]S+"!,87,@5FEL;&%S)SL*)&-O;W)D
M:6YA=&5S6R=#=6)A)UU;)S(R+C0Q-SHM.#,N-C@S)UT@/2`G4&EN87(@1&5L
M(%)I;RP@4&EN87(@1&5L(%)I;R<["B1C;V]R9&EN871E<ULG0W5B82==6R<R
M,BXY.#,Z+3@R+C0P,"==(#T@)T%E<F]P=65R=&\@2F]S92!-87)T:2P@4F%N
M8VAO+4)O>65R;W,L($AA8F%N82<["B1C;V]R9&EN871E<ULG0W5B82==6R<R
M,RXQ,S,Z+3@Q+C(X,R==(#T@)U9A<F%D97)O+"!-871A;GIA<R<["B1C;V]R
M9&EN871E<ULG0WEP<G5S)UU;)S,T+C4X,SHS,BXY.#,G72`]("=!:W)O=&ER
M:2<["B1C;V]R9&EN871E<ULG0WEP<G5S)UU;)S,T+C<Q-SHS,BXT.#,G72`]
M("=087!H;W,@06ER<&]R="<["B1C;V]R9&EN871E<ULG0WEP<G5S)UU;)S,T
M+C@X,SHS,RXV,S,G72`]("=,87)N86-A($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T-Y<')U<R==6R<S-2XQ-3`Z,S,N-#`P)UT@/2`G071H86QA<W-A)SL*
M)&-O;W)D:6YA=&5S6R=#>F5C:"!297!U8FQI8R==6R<T.2XQ-3`Z,38N-S`P
M)UT@/2`G0G)N;R`O(%1U<F%N>2<["B1C;V]R9&EN871E<ULG0WIE8V@@4F5P
M=6)L:6,G75LG-#DN,S$W.C$W+C4V-R==(#T@)TAO;&5S;W8G.PHD8V]O<F1I
M;F%T97-;)T-Z96-H(%)E<'5B;&EC)UU;)S0Y+C8X,SHQ."XQ,3<G72`]("=/
M<W1R879A("\@36]S;F]V)SL*)&-O;W)D:6YA=&5S6R=#>F5C:"!297!U8FQI
M8R==6R<U,"XQ,#`Z,30N,C4P)UT@/2`G4')A:&$@+R!2=7IY;F4G.PHD8V]O
M<F1I;F%T97-;)T-Z96-H(%)E<'5B;&EC)UU;)S4P+C(P,#HQ,BXY,3<G72`]
M("=+87)L;W9Y(%9A<GDG.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-30N
M-S`P.C$Q+C0U,"==(#T@)TUA<FEB;R!,=69T:&%V;B<["B1C;V]R9&EN871E
M<ULG1&5N;6%R:R==6R<U-"XY-C<Z.2XW.#,G72`]("=3;V5N9&5R8F]R9R!,
M=69T:&%V;B<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XP,3<Z,3`N
M-38W)UT@/2`G4WED9GEN<R!&;'EV97!L861S)SL*)&-O;W)D:6YA=&5S6R=$
M96YM87)K)UU;)S4U+C`V-SHQ-"XW-3`G72`]("=2;V5N;F4G.PHD8V]O<F1I
M;F%T97-;)T1E;FUA<FLG75LG-34N,#@S.C$Q+C<X,R==(#T@)T%V;F\@1&%N
M:7-H($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;
M)S4U+C(S,SHY+C(V-R==(#T@)U-K<GED<W1R=7`G.PHD8V]O<F1I;F%T97-;
M)T1E;FUA<FLG75LG-34N-#,S.CDN,S,S)UT@/2`G5F%M9')U<"<["B1C;V]R
M9&EN871E<ULG1&5N;6%R:R==6R<U-2XT.#,Z,3`N,S,S)UT@/2`G3V1E;G-E
M("\@0F5L9')I;F=E)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4U+C4S
M,SHX+C4V-R==(#T@)T5S8FIE<F<G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG
M75LG-34N-3@S.C$R+C$S,R==(#T@)TMO96)E;FAA=FX@+R!2;W-K:6QD92<[
M"B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XV,3<Z,3(N-C4P)UT@/2`G
M2V]E8F5N:&%V;B`O($MA<W1R=7`G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG
M75LG-34N-S`P.CDN,C`P)UT@/2`G5F%N9&5L)SL*)&-O;W)D:6YA=&5S6R=$
M96YM87)K)UU;)S4U+C<S,SHY+C$V-R==(#T@)T)I;&QU;F0@3'5F=&AA=FXG
M.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N-S8W.C$R+C,S,R==(#T@
M)U9A97)L;V5S92<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-BXP,#`Z
M."XS-3`G72`]("=3=&%U;FEN9R!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG
M1&5N;6%R:R==6R<U-BXS,#`Z,3`N-C$W)UT@/2`G5&ER<W1R=7`G.PHD8V]O
M<F1I;F%T97-;)T1E;FUA<FLG75LG-38N,S`P.CDN,3$W)UT@/2`G2V%R=7`G
M.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-38N-#`P.C@N-#4P)UT@/2`G
M3&EN9'1O<G`@06ER<&]R="<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U
M-BXU-3`Z.2XQ-C<G72`]("=3:VEV92!,=69T:&%V;B<["B1C;V]R9&EN871E
M<ULG1&5N;6%R:R==6R<U-BXW,#`Z,3$N-34P)UT@/2`G06YH;VQT($ES;&%N
M9"!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;
M)T1E;FUA<FLG75LG-38N-S$W.C$P+C$Q-R==(#T@)TAA9'-U;F0G.PHD8V]O
M<F1I;F%T97-;)T1E;FUA<FLG75LG-3<N,#8W.C@N-S$W)UT@/2`G5&AI<W1E
M9"!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-RXQ,#`Z
M.2XX-3`G72`]("=!86QB;W)G)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;
M)S4W+C4P,#HQ,"XR,3<G72`]("=3:6YD86P@1FQY=F5P;&%D<R<["B1C;V]R
M9&EN871E<ULG1&5N;6%R:R==6R<V,BXP-C<Z+3<N,C@S)UT@/2`G4V]E<G9A
M86<@+R!686=A<B<["B1C;V]R9&EN871E<ULG1&II8F]U=&DG75LG,3$N-34P
M.C0S+C$U,"==(#T@)T1J:6)O=71I)SL*)&-O;W)D:6YA=&5S6R=$;VUI;FEC
M82==6R<Q-2XS,#`Z+38Q+C0P,"==(#T@)U)O<V5A=2<["B1C;V]R9&EN871E
M<ULG1&]M:6YI8V$G75LG,34N-3,S.BTV,2XS,#`G72`]("=-96QV:6QL92!(
M86QL($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A)UU;)S$U+C4S
M,SHM-C$N-#`P)UT@/2`G0V%N969I96QD($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q."XR,#`Z+3<Q+C$P,"==(#T@
M)T)A<F%H;VYA)SL*)&-O;W)D:6YA=&5S6R=$;VUI;FEC86X@4F5P=6)L:6,G
M75LG,3@N-#,S.BTV.2XV-C<G72`]("=,87,@06UE<FEC87,G.PHD8V]O<F1I
M;F%T97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q."XT-C<Z+38Y+CDV-R==
M(#T@)TAE<G)E<F$G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A;B!297!U8FQI
M8R==6R<Q."XU-C<Z+38X+C,V-R==(#T@)U!U;G1A($-A;F$G.PHD8V]O<F1I
M;F%T97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q.2XT-3`Z+3<P+C<P,"==
M(#T@)U-A;G1I86=O)SL*)&-O;W)D:6YA=&5S6R=$;VUI;FEC86X@4F5P=6)L
M:6,G75LG,3DN-S4P.BTW,"XU-3`G72`]("=0=65R=&\@4&QA=&$@26YT97)N
M871I;VYA;"<["B1C;V]R9&EN871E<ULG16%S="!4:6UO<B==6R<M."XU,#`Z
M,3(V+C0P,"==(#T@)T)A=6-A=2<["B1C;V]R9&EN871E<ULG16%S="!4:6UO
M<B==6R<M."XU-C<Z,3(U+C4V-R==(#T@)T1I;&QI("\@1&EL;&D@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG16%S="!4:6UO<B==6R<M.2XR,#`Z,3(T+C,V
M-R==(#T@)T]E+4-U<W-E("\@3V4@0W5S<V4G.PHD8V]O<F1I;F%T97-;)T5C
M=6%D;W(G75LG+3`N,34P.BTW."XT.#,G72`]("=1=6ET;R`O($UA<FES8V%L
M(%-U8W)E)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)S`N,S4P.BTW."XQ
M,S,G72`]("=)8F%R<F$@+R!!=&%H=6%L<&$G.PHD8V]O<F1I;F%T97-;)T5C
M=6%D;W(G75LG+3`N-3@S.BTX,"XT,#`G72`]("="86AI82!$92!#87)A<75E
M>B<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,"XW.#,Z+3<U+C4Q-R==
M(#T@)U1I<'5T:6YI)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)S`N.#$W
M.BTW-RXW,#`G72`]("=4=6QC86X@+R!%;"!2;W-A;"<["B1C;V]R9&EN871E
M<ULG16-U861O<B==6R<M,"XY,#`Z+3@Y+C8P,"==(#T@)U-A;B!#<FES=&]B
M86P@1V%L87!A9V]S)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTP+CDQ
M-SHM-S@N-C$W)UT@/2`G3&%T86-U;F=A)SL*)&-O;W)D:6YA=&5S6R=%8W5A
M9&]R)UU;)RTP+CDU,#HM.#`N-C@S)UT@/2`G36%N=&$G.PHD8V]O<F1I;F%T
M97-;)T5C=6%D;W(G75LG,"XY-C<Z+3<Y+C8S,R==(#T@)T5S;65R86QD87,M
M5&%C:&EN82<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,2XR,#`Z+3<X
M+C4V-R==(#T@)T%M8F%T;R`O($-H86-H;V%N)SL*)&-O;W)D:6YA=&5S6R=%
M8W5A9&]R)UU;)RTQ+C4P,#HM-S@N,#4P)UT@/2`G4&%S=&%Z82`O(%)I;R!!
M;6%Z;VYA<R<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,BXQ-3`Z+3<Y
M+C@X,R==(#T@)T=U87EA<75I;"`O(%-I;6]N($)O;&EV87(G.PHD8V]O<F1I
M;F%T97-;)T5C=6%D;W(G75LG+3(N,C`P.BTX,"XY.#,G72`]("=386QI;F%S
M("\@1V5N97)A;"!5;'!I86YO(%!A97HG.PHD8V]O<F1I;F%T97-;)T5C=6%D
M;W(G75LG+3(N.#@S.BTW."XY.#,G72`]("=#=65N8V$@+R!-87)I<V-A;"!,
M86UA<B<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,RXR-3`Z+3<Y+CDV
M-R==(#T@)TUA8VAA;&$@+R!'96YE<F%L($TN(%-E<G)A;F\G.PHD8V]O<F1I
M;F%T97-;)T5C=6%D;W(G75LG+30N,#`P.BTW.2XS-C<G72`]("=#871A;6%Y
M;R`O($-A;6EL;R!0;VYC92!%;G)I<75E>B<["B1C;V]R9&EN871E<ULG16-U
M861O<B==6R<M-"XS-C<Z+3<Y+CDS,R==(#T@)TUA8V%R82`O($HN($TN(%9E
M;&%S8V\@22XG.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S(S+CDV-SHS,BXW
M.#,G72`]("=!<W-W86XG.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S(U+C8V
M-SHS,BXW,#`G72`]("=,=7AO<B<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG
M,C<N,#4P.C,Q+C`Q-R==(#T@)T%S>75T)SL*)&-O;W)D:6YA=&5S6R=%9WEP
M="==6R<R-RXQ-3`Z,S,N-S$W)UT@/2`G2'5R9W5A9&$G.PHD8V]O<F1I;F%T
M97-;)T5G>7!T)UU;)S(X+C(S,SHS,BXV,3<G72`]("=%;"!4;W(G.PHD8V]O
M<F1I;F%T97-;)T5G>7!T)UU;)S,P+C$S,SHS,2XT,#`G72`]("=#86ER;R!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=%9WEP="==6R<S,2XP.#,Z,S,N.#$W
M)UT@/2`G16P@07)I<V@G.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S,Q+C(P
M,#HR.2XY-3`G72`]("=!;&5X86YD<FEA("\@3F]U>FAA)SL*)&-O;W)D:6YA
M=&5S6R=%9WEP="==6R<S,2XR-C<Z,S(N,S`P)UT@/2`G4&]R="!386ED)SL*
M)&-O;W)D:6YA=&5S6R=%9WEP="==6R<S,2XS,S,Z,C<N,C$W)UT@/2`G365R
M<V$@36%T<G5H)SL*)&-O;W)D:6YA=&5S6R=%;"!386QV861O<B==6R<Q,RXT
M,S,Z+3@Y+C`U,"==(#T@)T5L(%-A;'9A9&]R($EN=&PN($%I<G!O<G0@+R!#
M;VUA;&%P82<["B1C;V]R9&EN871E<ULG16P@4V%L=F%D;W(G75LG,3,N-#4P
M.BTX."XQ,3<G72`]("=386X@36EG=65L("\@16P@4&%P86QO;B<["B1C;V]R
M9&EN871E<ULG16P@4V%L=F%D;W(G75LG,3,N-38W.BTX.2XX,S,G72`]("=!
M8V%J=71L82<["B1C;V]R9&EN871E<ULG16P@4V%L=F%D;W(G75LG,3,N-S`P
M.BTX.2XQ,3<G72`]("=386X@4V%L=F%D;W(@+R!);&]P86YG;R<["B1C;V]R
M9&EN871E<ULG16P@4V%L=F%D;W(G75LG,3,N.3@S.BTX.2XU-C<G72`]("=3
M86YT82!!;F$@+R!%;"!086QM87(G.PHD8V]O<F1I;F%T97-;)T5Q=6%T;W)I
M86P@1W5I;F5A)UU;)S,N-S4P.C@N-S8W)UT@/2`G36%L86)O+T9E<FYA;F1O
M(%!O;R<["B1C;V]R9&EN871E<ULG17-T;VYI82==6R<U."XY.#,Z,C(N.#$W
M)UT@/2`G2V%R9&QA)SL*)&-O;W)D:6YA=&5S6R=%<W1O;FEA)UU;)S4Y+C,X
M,SHR-"XU.#,G72`]("=486QL:6YN)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I
M82==6R<Q,"XS-3`Z,S<N-S$W)UT@/2`G1&5B<F5M87)C;W,G.PHD8V]O<F1I
M;F%T97-;)T5T:&EO<&EA)UU;)S$Q+C`X,SHS.2XW,3<G72`]("=#;VUB;VQC
M:&$G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S$Q+C8P,#HS-RXT,#`G
M72`]("="86AA<B!$87(G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S$R
M+C4S,SHS-RXT,S,G72`]("=';VYD87(G.PHD8V]O<F1I;F%T97-;)T5T:&EO
M<&EA)UU;)S$S+C`V-SHT,BXW,3<G72`]("=!<W-A8B<["B1C;V]R9&EN871E
M<ULG171H:6]P:6$G75LG,3,N-3`P.C,Y+C0X,R==(#T@)TUA:V%L92<["B1C
M;V]R9&EN871E<ULG171H:6]P:6$G75LG,34N,C@S.C,X+CDQ-R==(#T@)T%S
M;6%R82<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG,34N-C$W.C,Y+C0U
M,"==(#T@)TUA<W-A=V$G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S4N
M,3`P.C0T+C4X,R==(#T@)T=O9&4G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA
M)UU;)S4N,C@S.C,Y+C<U,"==(#T@)TYE9VAE;&QI)SL*)&-O;W)D:6YA=&5S
M6R=%=&AI;W!I82==6R<V+C`V-SHS-RXV-C<G72`]("=!<F)A($UI;F-H)SL*
M)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<W+C`V-SHS."XU,#`G72`]("=!
M=V%S<V$G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S<N-C8W.C,V+C@S
M,R==(#T@)TII;6UA)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<X+C$V
M-SHS-2XU-3`G72`]("=';W)E)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==
M6R<X+C<S,SHS.2XP,#`G72`]("=(87)A<B!-961A)SL*)&-O;W)D:6YA=&5S
M6R=%=&AI;W!I82==6R<X+CDX,SHS."XX,#`G72`]("=!9&1I<R!!8F%B82<[
M"B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG.2XS,S,Z-#(N-S$W)UT@/2`G
M2FEG9VEG82<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG.2XV,#`Z-#$N
M.#8W)UT@/2`G1&ER92!$87=A)SL*)&-O;W)D:6YA=&5S6R=&86QK;&%N9"!)
M<VQA;F1S("A-86QV:6YA<RDG75LG+34Q+C8X,SHM-3<N-S8W)UT@/2`G4W1A
M;FQE>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=&:6II)UU;)RTQ,BXU,#`Z
M,3<W+C`U,"==(#T@)U)O='5M82<["B1C;V]R9&EN871E<ULG1FEJ:2==6R<M
M,3<N-S4P.C$W-RXT-3`G72`]("=.86YD:2<["B1C;V]R9&EN871E<ULG1FEJ
M:2==6R<M,3@N,#4P.C$W."XU-C<G72`]("=.875S;W)I)SL*)&-O;W)D:6YA
M=&5S6R=&:6II)UU;)RTQ."XR,S,Z+3$W."XX,#`G72`]("=,86ME;6)A)SL*
M)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8P+C$Q-SHQ.2XY,#`G72`]("=-
M87)I96AA;6X@+R!!;&%N9"!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)T9I;FQA
M;F0G75LG-C`N,C4P.C(U+C`U,"==(#T@)TAE;'-I;FMI+4UA;&UI)SL*)&-O
M;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8P+C,Q-SHR-"XY-C<G72`]("=(96QS
M:6YK:2U686YT86$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C`N-3$W
M.C(R+C(V-R==(#T@)U1U<FMU)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;
M)S8P+CDP,#HR-BXY,S,G72`]("=5='1I)SL*)&-O;W)D:6YA=&5S6R=&:6YL
M86YD)UU;)S8Q+C`T-CHR."XQ-#DG72`]("=,87!P965N<F%N=&$G.PHD8V]O
M<F1I;F%T97-;)T9I;FQA;F0G75LG-C$N-#$W.C(S+C4X,R==(#T@)U1A;7!E
M<F4@+R!0:7)K:V%L82<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,2XT
M-C<Z,C$N.#`P)UT@/2`G4&]R:2<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==
M6R<V,2XW,S,Z,C<N,S`P)UT@/2`G36EK:V5L:2<["B1C;V]R9&EN871E<ULG
M1FEN;&%N9"==6R<V,2XX-3`Z,C0N.#`P)UT@/2`G2&%L;&DG.PHD8V]O<F1I
M;F%T97-;)T9I;FQA;F0G75LG-C$N.34P.C(X+CDU,"==(#T@)U-A=F]N;&EN
M;F$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C(N-#`P.C(U+C8X,R==
M(#T@)TIY=F%S:WEL82<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,BXU
M,S,Z,C0N,C$W)UT@/2`G06AT87)I)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD
M)UU;)S8R+C8V-SHR.2XV,S,G72`]("=*;V5N<W5U)SL*)&-O;W)D:6YA=&5S
M6R=&:6YL86YD)UU;)S8S+C`Q-SHR-RXX,#`G72`]("=+=6]P:6\G.PHD8V]O
M<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N,#4P.C(Q+C<V-R==(#T@)U9A87-A
M)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8S+C`X,SHR-2XX-C<G72`]
M("=6:6ET87-A87)I)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8S+C$P
M,#HR,RXP,S,G72`]("=+875H879A)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD
M)UU;)S8S+C<Q-SHR,RXQ-3`G72`]("=+<G5U;G5P>7DG.PHD8V]O<F1I;F%T
M97-;)T9I;FQA;F0G75LG-C0N,C@S.C(W+C8X,R==(#T@)TMA:F%A;FDG.PHD
M8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C0N.3`P.C(Y+C`Q-R==(#T@)U-U
M;VUU<W-A;&UI)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8T+CDS,SHR
M-2XS-C<G72`]("=/=6QU)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8U
M+C`S,SHR-"XX,#`G72`]("=(86EL=6]T;R<["B1C;V]R9&EN871E<ULG1FEN
M;&%N9"==6R<V-2XS-C<Z,C<N,#$W)UT@/2`G4'5D87-J87)V:2<["B1C;V]R
M9&EN871E<ULG1FEN;&%N9"==6R<V-2XW.#,Z,C0N-3@S)UT@/2`G2V5M:2<[
M"B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V-2XY-C<Z,CDN,3@S)UT@/2`G
M2W5U<V%M;R<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V-BXU-C<Z,C4N
M.#,S)UT@/2`G4F]V86YI96UI)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;
M)S8V+C@P,#HR-"XP,#`G72`]("=096QL;R<["B1C;V]R9&EN871E<ULG1FEN
M;&%N9"==6R<V-RXS-C<Z,C8N-C4P)UT@/2`G4V]D86YK>6QA)SL*)&-O;W)D
M:6YA=&5S6R=&:6YL86YD)UU;)S8X+C8Q-SHR-RXT,3<G72`]("=)=F%L;R<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)RTQ,RXR,S,Z+3$W-BXQ-C<G72`]
M("=(:6AI9F\@26QE(%=A;&QI<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)RTQ-"XS,3<Z+3$W."XQ,3<G72`]("=-86]P;V]P;R!);&4@1G5T=6YA)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#$N-3`P.CDN,3`P)UT@/2`G1FEG
M87)I)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#$N.3$W.C@N.#`P)UT@
M/2`G06IA8V-I;R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Q+CDQ-SHY
M+C0P,"==(#T@)U-O;&5N>F%R82<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0R+C4S,SHX+C@P,"==(#T@)T-A;'9I)SL*)&-O;W)D:6YA=&5S6R=&<F%N
M8V4G75LG-#(N-34P.CDN-#@S)UT@/2`G0F%S=&EA)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#(N-S,S.C(N.#8W)UT@/2`G4&5R<&EG;F%N)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N,#`P.C$N,3`P)UT@/2`G4W0M1VER
M;VYS)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N,3`P.C8N,34P)UT@
M/2`G2'EE<F5S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N,3@S.C`N
M,#`P)UT@/2`G5&%R8F5S("\@3W-S=6XG.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T,RXR,3<Z,BXS,3<G72`]("=#87)C87-S;VYN92<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0S+C,X,SHM,"XT,3<G72`]("=0874G.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T,RXS.#,Z-BXS.#,G72`]("=,92!,=6,G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXT,3<Z-BXW-3`G72`]("=3
M="U287!H865L)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-#4P.C4N
M,C,S)UT@/2`G36%R<V5I;&QE("\@36%R:6=N86YE)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#,N-#8W.BTQ+C4S,R==(#T@)T)I87)R:71Z)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-3`P.C4N,S8W)UT@/2`G06EX($QE
M<R!-:6QL97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXU,3<Z-"XY
M,S,G72`]("=)<W1R97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXU
M,S,Z,2XS-C<G72`]("=4;W5L;W5S92`O($9R86YC87IA;"<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0S+C4U,#HV+CDU,"==(#T@)T-A;FYE<R<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C4X,SHS+CDV-R==(#T@)TUO;G1P
M96QL:65R)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-C`P.C4N,3`P
M)UT@/2`G4V%L;VXG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXV,S,Z
M,2XS-C<G72`]("=4;W5L;W5S92`O($)L86=N86,G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T,RXV-3`Z-RXR,#`G72`]("=.:6-E)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#,N-C@S.C`N-C`P)UT@/2`G075C:"<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0S+C8X,SHM,2XP-C<G72`]("=$87@G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXW-3`Z-"XT,3<G72`]("=.:6UE
M<R`O($=A<F]N<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C@V-SHT
M+C0P,"==(#T@)TYI;65S("\@0V]U<F)E<W-A8R<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0S+CDQ-SHM,"XU,#`G72`]("=-;VYT+41E+4UA<G-A;B<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+CDQ-SHR+C$Q-R==(#T@)T%L
M8FDG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-"XP-C<Z-BXP,#`G72`]
M("=3="U!=6)A;BU3=7(M1'5R86YC92<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0T+C$S,SHT+C@S,R==(#T@)T]R86YG92<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0T+C$X,SHP+C8P,"==(#T@)T%G96XG.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T-"XQ.#,Z,BXU,3<G72`]("=#87-S86=N97,M0F5G
M;VYH97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-"XT,#`Z,BXT.#,G
M72`]("=2;V1E>B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C0S,SHM
M,2XR-3`G72`]("=":7-C87)O<W-E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#0N-3,S.BTQ+C$S,R==(#T@)T-A>F%U>"<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0T+C4X,SHT+C<S,R==(#T@)TUO;G1E;&EM87(G.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T-"XX,3<Z,"XU,3<G72`]("="97)G97)A
M8R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C@S,SHM,"XW,#`G72`]
M("=";W)D96%U>"`O($UE<FEG;F%C)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#0N.3`P.C(N-#$W)UT@/2`G075R:6QL86,G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T-2XP.#,Z,RXW-C<G72`]("=,92!0=7DG.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T-2XQ-3`Z,2XT-C<G72`]("="<FEV92<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C(P,#HP+C@Q-R==(#T@)U!E<FEG
M=65U>"<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C,V-SHU+C,S,R==
M(#T@)T=R96YO8FQE("\@4W0N($=E;VER<R<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0U+C4S,SHT+C,P,"==(#T@)U-T+45T:65N;F4@0F]U=&AE;VXG
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XV-3`Z-2XX.#,G72`]("=#
M:&%M8F5R>2`O($%I>"U,97,M0F%I;G,G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T-2XV-C<Z+3`N,S$W)UT@/2`G0V]G;F%C)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#4N-S$W.C0N.34P)UT@/2`G3'EO;B`O($)R;VXG.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XW,S,Z-2XP.#,G72`]("=,>6]N
M("\@4V%T;VQA<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C<X,SHS
M+C$V-R==(#T@)T-L97)M;VYT+49E<G)A;F0G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T-2XX-C<Z,2XQ.#,G72`]("=,:6UO9V5S)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#4N.3@S.C4N,S,S)UT@/2`G06UB97)I974G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T-BXQ-3`Z+3$N,34P)UT@/2`G3&$@
M4F]C:&5L;&4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-BXQ-C<Z,RXT
M,#`G72`]("=6:6-H>2<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0V+C,P
M,#HT+C@P,"==(#T@)TUA8V]N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#8N,S$W.BTP+C0P,"==(#T@)TYI;W)T)SL*)&-O;W)D:6YA=&5S6R=&<F%N
M8V4G75LG-#8N-#$W.C0N,#$W)UT@/2`G4V%I;G0M66%N)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#8N-3@S.C`N,S$W)UT@/2`G4&]I=&EE<G,G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T-BXW,#`Z+3$N,S@S)UT@/2`G3&$@
M4F]C:&4M4W5R+5EO;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0V+C@U
M,#HQ+C<Q-R==(#T@)T-H871E875R;W5X)SL*)&-O;W)D:6YA=&5S6R=&<F%N
M8V4G75LG-#<N,#`P.C,N,3`P)UT@/2`G3F5V97)S)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#<N,#8W.C(N,S8W)UT@/2`G0F]U<F=E<R<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0W+C$V-SHM,2XV,#`G72`]("=.86YT97,G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXR-3`Z-2XY.#,G72`]("="
M97-A;F-O;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C(V-SHU+C`X
M,R==(#T@)T1I:F]N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N,S$W
M.C$N-C@S)UT@/2`G4F]M;W)A;G1I;B<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0W+C,Q-SHM,BXQ-C<G72`]("=3="U.87IA:7)E)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#<N-#4P.C`N-S$W)UT@/2`G5&]U<G,G.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T-RXU,#`Z+3`N-38W)UT@/2`G06YG97)S
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N-C`P.C<N-3$W)UT@/2`G
M0F%L92U-=6QH;W5S92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C8S
M,SHV+C@V-R==(#T@)T)E;&9O<G0G.PHD8V]O<F1I;F%T97-;)T9R86YC92==
M6R<T-RXW-C<Z+3,N-#4P)UT@/2`G3&%N;B!":6AO=64G.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T-RXW.#,Z-BXS-3`G72`]("=,=7AE=6EL)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N.#`P.C,N-34P)UT@/2`G075X97)R
M92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C@U,#HT+C4U,"==(#T@
M)T-H871I;&QO;BU3=7(M4V5I;F4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==
M6R<T-RXY,3<Z-RXT,#`G72`]("=#;VQM87(G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T-RXY,S,Z,"XR,#`G72`]("=,92!-86YS)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#<N.38W.BTT+C$V-R==(#T@)U%U:6UP97(G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXY.#,Z,2XW-3`G72`]("=/<FQE
M86YS)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N,#4P.C$N,S@S)UT@
M/2`G0VAA=&5A=61U;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C`V
M-SHM,2XW,S,G72`]("=296YN97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==
M6R<T."XR.#,Z+30N-#,S)UT@/2`G3&%N=F5O8R!0;W5L;6EC)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#@N,S,S.C0N,#$W)UT@/2`G5')O>65S)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-#4P.C`N,3$W)UT@/2`G06QE
M;F-O;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C0U,#HM-"XT,3<G
M72`]("="<F5S="<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C0V-SHQ
M+C4Q-R==(#T@)T-H87)T<F5S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#@N-3$W.BTT+C$U,"==(#T@)TQA;F1I=FES:6%U)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#@N-3,S.BTR+C@U,"==(#T@)U-A:6YT+4)R:65U8R<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C4U,#HW+C8S,R==(#T@)U-T
M<F%S8F]U<F<G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XU.#,Z+3(N
M,#8W)UT@/2`G1&EN87)D)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N
M-3@S.C4N.38W)UT@/2`G3F%N8WD@+R!/8VAE>2<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0X+C8Q-SHR+C8X,R==(#T@)TUE;'5N)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#@N-C,S.C0N.3`P)UT@/2`G4W0M1&EZ:65R)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-C@S.C8N,C$W)UT@/2`G3F%N
M8WD@+R!%<W-E>2<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C<S,SHR
M+C0P,"==(#T@)U!A<FES+4]R;'DG.PHD8V]O<F1I;F%T97-;)T9R86YC92==
M6R<T."XW-C<Z,2XQ,#`G72`]("=4;W5S<W5S($QE($YO8FQE)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#@N-S8W.C(N,C`P)UT@/2`G5FEL;&%C;W5B
M;&%Y)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-S@S.C4N-#@S)UT@
M/2`G5&]U;"`O(%)O<VEE<F5S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#@N.38W.C(N-#4P)UT@/2`G4&%R:7,@+R!,92!";W5R9V5T)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#@N.3@S.C8N,C4P)UT@/2`G365T>BU.86YC
M>2U,;W)R86EN92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C`Q-SHQ
M+C(Q-R==(#T@)T5V<F5U>"<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y
M+C`Q-SHR+C4S,R==(#T@)U!A<FES+4%E<F]P;W)T($-H87)L97,@1&4@1V%U
M;&QE)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN,#@S.C8N,3,S)UT@
M/2`G365T>B`O($9R97-C871Y)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#DN,3@S.BTP+C0U,"==(#T@)T-A96XG.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T.2XR-3`Z,BXU,3<G72`]("=#<F5I;"!&869B)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#DN,S`P.C0N,#,S)UT@/2`G4F5I;7,G.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T.2XS.#,Z,2XQ.#,G72`]("=2;W5E;B<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C0V-SHR+C$Q-R==(#T@)T)E
M875V86ES)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN-3$W.C`N,#8W
M)UT@/2`G3&$@2&5V92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C8U
M,#HM,2XT-C<G72`]("=#:&5R8F]U<F<@+R!-875P97)T=7,G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T.2XW.#,Z-"XV,S,G72`]("=#:&%R;&5V:6QL
M92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C@Q-SHS+C(P,"==(#T@
M)U-A:6YT+5%U96YT:6XG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XX
M,S,Z,"XV-3`G72`]("=6:71T969L975R("\@4W0N(%9A;&4G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<U,"XQ,S,Z,2XX,S,G72`]("=!8F)E=FEL;&4G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<U,"XR,3<Z,RXQ-3`G72`]("=#
M86UB<F%I)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-3`N-3$W.C$N-C$W
M)UT@/2`G3&4@5&]U<75E="<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S4P
M+C4V-SHS+C$P,"==(#T@)TQI;&QE)SL*)&-O;W)D:6YA=&5S6R=&<F5N8V@@
M1W5I86YA)UU;)S0N.#,S.BTU,BXS-C<G72`]("=#87EE;FYE("\@4F]C:&%M
M8F5A=2<["B1C;V]R9&EN871E<ULG1G)E;F-H($=U:6%N82==6R<U+C4P,#HM
M-30N,#,S)UT@/2`G4V%I;G0M3&%U<F5N="U$=2U-87)O;FDG.PHD8V]O<F1I
M;F%T97-;)T9R96YC:"!0;VQY;F5S:6$G75LG+3$T+CDV-SHM,30W+C8V-R==
M(#T@)U)A;F=I<F]A("\@5'5A;6]T;R!)<VQA;F0G.PHD8V]O<F1I;F%T97-;
M)T9R96YC:"!0;VQY;F5S:6$G75LG+3$V+C0U,#HM,34Q+C<U,"==(#T@)T)O
M<F$M0F]R82<["B1C;V]R9&EN871E<ULG1G)E;F-H(%!O;'EN97-I82==6R<M
M,3<N-34P.BTQ-#DN-C$W)UT@/2`G5&%H:71I+49A86$G.PHD8V]O<F1I;F%T
M97-;)T9R96YC:"!0;VQY;F5S:6$G75LG+3$X+C`V-SHM,30P+CDU,"==(#T@
M)TAA;R<["B1C;V]R9&EN871E<ULG1G)E;F-H(%!O;'EN97-I82==6R<M,C$N
M.#$W.BTQ,S@N.#`P)UT@/2`G375R=7)O82<["B1C;V]R9&EN871E<ULG1G)E
M;F-H(%!O;'EN97-I82==6R<M,C,N,S4P.BTQ-#DN-#@S)UT@/2`G5'5B=6%I
M)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<P+C0U,#HY+C0Q-R==(#T@)TQI
M8G)E=FEL;&4G.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)S`N-38W.C$R+C@V
M-R==(#T@)TUA:V]K;W4G.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)RTP+C<P
M,#HX+C<U,"==(#T@)U!O<G0M1V5N=&EL)SL*)&-O;W)D:6YA=&5S6R='86)O
M;B==6R<M,"XW,3<Z,3`N,C,S)UT@/2`G3&%M8F%R96YE)SL*)&-O;W)D:6YA
M=&5S6R='86)O;B==6R<P+C<X,SHQ,2XU,S,G72`]("=-:71Z:6,G.PHD8V]O
M<F1I;F%T97-;)T=A8F]N)UU;)RTP+C@S,SHQ,BXW,3<G72`]("=,87-T;W5R
M<W9I;&QE)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<Q+C`P,#HY+C8P,"==
M(#T@)T-O8V]B96%C:"<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG,2XP,3<Z
M,3,N.3,S)UT@/2`G365K86UB;R<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG
M+3$N-3,S.C$S+C(V-R==(#T@)TUO86YD82<["B1C;V]R9&EN871E<ULG1V%B
M;VXG75LG+3$N.#8W.C$Q+C`Q-R==(#T@)TUO=6EL82<["B1C;V]R9&EN871E
M<ULG1V%B;VXG75LG,BXP.#,Z,3$N-#@S)UT@/2`G0FET86TG.PHD8V]O<F1I
M;F%T97-;)T=A8F]N)UU;)RTR+C@U,#HQ,2XP,3<G72`]("=48VAI8F%N9V$G
M.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)RTS+C0Q-SHQ,"XV-3`G72`]("=-
M87EU;6)A)SL*)&-O;W)D:6YA=&5S6R='86UB:6$G75LG,3,N,S4P.BTQ-BXX
M,#`G72`]("="86YJ=6P@+R!9=6YD=6TG.PHD8V]O<F1I;F%T97-;)T=E;W)G
M:6$G75LG-#$N-C@S.C0T+CDU,"==(#T@)U1B:6QI<VDG.PHD8V]O<F1I;F%T
M97-;)T=E;W)G:6$G75LG-#$N.3,S.C0T+C4X,R==(#T@)TUU:')A;FDG.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N-C8W.CDN-3$W)UT@/2`G1G)I
M961R:6-H<VAA9F5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0W+C8X
M,SHY+C$X,R==(#T@)TMO;G-T86YZ)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S0W+C@S,SHQ,"XX-C<G72`]("=!;'1E;G-T861T)SL*)&-O;W)D:6YA
M=&5S6R='97)M86YY)UU;)S0W+CDV-SHX+C4Q-R==(#T@)T1O;F%U97-C:&EN
M9V5N("\@5FEL;&EN9V5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0W
M+CDX,SHQ,"XR,S,G72`]("=-96UM:6YG96XG.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-#@N,#8W.C$P+CDP,"==(#T@)TQA;F1S8F5R9R<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<T."XQ,S,Z,3$N-S`P)UT@/2`G375N:6-H
M("\@4FEE;2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XQ.#,Z,3`N
M.#8W)UT@/2`G3&5C:&9E;&0G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG
M-#@N,3@S.CDN,#`P)UT@/2`G365S<W-T971T96XG.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-#@N,C`P.C$Q+C(V-R==(#T@)T9U97)S=&5N9F5L9&)R
M=6-K)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0X+C(Q-SHY+CDQ-R==
M(#T@)TQA=7!H96EM)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0X+C,Q
M-SHQ,2XY-3`G72`]("=%<F1I;F<G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-#@N-#,S.C$P+CDS,R==(#T@)T%U9W-B=7)G)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S0X+C8X,SHY+C(Q-R==(#T@)U-T=71T9V%R="U%8VAT
M97)D:6YG96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#@N-S$W.C$Q
M+C(Q-R==(#T@)TYE=6)U<F<@+R!$;VYA=2<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<T."XW,3<Z,3$N-3,S)UT@/2`G26YG;VQS=&%D="<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<T.2XR,3<Z,3$N,3`P)UT@/2`G4F]T:"<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XR,3<Z,3$N.#,S)UT@/2`G
M2&]H96YF96QS)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C(Q-SHW
M+C$Q-R==(#T@)U-A87)B<G5E8VME;B`O($5N<VAE:6TG.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-#DN,S$W.C$P+C8S,R==(#T@)T%N<V)A8V@@+R!+
M871T97)B86-H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C0P,#HX
M+C8U,"==(#T@)TAE:61E;&)E<F<G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-#DN-#`P.CDN.38W)UT@/2`G3FEE9&5R<W1E='1E;B<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<T.2XT,S,Z,3$N.3`P)UT@/2`G2W5E;6UE<G-R
M=6-K)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C0S,SHW+C8P,"==
M(#T@)U)A;7-T96EN)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C0V
M-SHQ,"XS.#,G72`]("=);&QE<VAE:6TG.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-#DN-#<S.C@N-3$V)UT@/2`G0F%D96X@5W5R='1E;6)E<F<L($YE
M=6]S=&AE:6TG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-3`P.C$Q
M+C`U,"==(#T@)TYU97)N8F5R9R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<T.2XU,#`Z-RXX-C<G72`]("=396UB86-H(%5N:71E9"!3=&%T97,@06ER
M($9O<F-E($]P97)A=&5D($)A<V4@26X@1F]R96EG;B!#;W5N=')Y)SL*)&-O
M;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C4V-SHX+C0V-R==(#T@)T-O;&5M
M86X@36%N;FAE:6TG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-C4P
M.CDN.38W)UT@/2`G1VEE8F5L<W1A9'0G.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-#DN-S`P.C$Q+CDU,"==(#T@)T=R869E;G=O96AR)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S0Y+C<P,#HW+C,S,R==(#T@)TED87(M3V)E
M<G-T96EN)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C<U,#HQ,"XR
M,#`G72`]("=+:71Z:6YG96X@57-A(%P@068G.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-#DN.#4P.C<N-C`P)UT@/2`G4&9E<F1S9F5L9"<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<T.2XX-3`Z-RXX.#,G72`]("="860@2W)E
M=7IN86-H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+CDU,#HW+C(V
M-R==(#T@)TAA:&XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN.3@S
M.C$Q+C8S,R==(#T@)T)A>7)E=71H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S0Y+CDX,SHV+C<P,"==(#T@)U-P86YG9&%H;&5M)SL*)&-O;W)D:6YA
M=&5S6R='97)M86YY)UU;)S4P+C`U,#HX+C,S,R==(#T@)U=I97-B861E;B<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,"XP-3`Z."XV,#`G72`]("=&
M<F%N:V9U<G0@+R!-+49L=6=H869E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<U,"XQ-C<Z-RXP-C<G72`]("="=65C:&5L)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4P+C$V-SHX+CDV-R==(#T@)TAA;F%U)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S4P+C,Q-SHQ,2XX.#,G72`]("=(;V8G.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N,S8W.C<N,S$W)UT@/2`G365N
M9&EG)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+C@Q-SHV+C$X,R==
M(#T@)T%A8VAE;B`O($UE<GIB<G5C:R<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<U,"XX,S,Z-BXV-C<G72`]("=.;V5R=F5N:6-H)SL*)&-O;W)D:6YA
M=&5S6R='97)M86YY)UU;)S4P+C@V-SHW+C$V-R==(#T@)TMO96QN("\@0F]N
M;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,"XY-C<Z-BXP-3`G72`]
M("='96EL96YK:7)C:&5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P
M+CDX,SHQ,"XY-C<G72`]("=%<F9U<G0M0FEN9&5R<VQE8F5N)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S4Q+C$Q-SHY+C(X,R==(#T@)T9R:71Z;&%R
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C$S,SHQ,RXW-3`G72`]
M("=$<F5S9&5N+4ML;W1Z<V-H92<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<U,2XR,#`Z-BXQ,S,G72`]("="<G5E9V=E;B<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<U,2XS,#`Z-BXW-C<G72`]("=$=65S<V5L9&]R9B<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XT,#`Z-BXY-C<G72`]("=%<W-E
M;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XT,#`Z.2XS.#,G72`]
M("=+87-S96P@+R!#86QD96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG
M-3$N-#$W.C$R+C(S,R==(#T@)TQE:7!Z:6<M4V-H:V5U9&ET>B<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<U,2XU,3<Z-RXV,3<G72`]("=$;W)T;75N
M9"`O(%=I8VME9&4G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N-C`P
M.C8N,34P)UT@/2`G3&%A<F)R=6-H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4Q+C8Q-SHX+C8Q-R==(#T@)U!A9&5R8F]R;B`O($QI<'!S=&%D="<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XV-C<Z,30N-C,S)UT@/2`G
M4')E<V-H96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N-S,S.C8N
M,C8W)UT@/2`G2V%L:V%R)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q
M+C<V-SHQ,RXQ.#,G72`]("=(;VQZ9&]R9B<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<U,2XW-C<Z,30N,S`P)UT@/2`G0V]T=&)U<R!&;'5G<&QA='HG
M.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N.3$W.C@N,S`P)UT@/2`G
M1W5E=&5R<VQO:"<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXQ,S,Z
M-RXW,#`G72`]("=-=65N<W1E<B`O($]S;F%B<G5E8VLG.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-3(N,C@S.CDN,#@S)UT@/2`G0G5E8VME8G5R9R<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXS,#`Z,3`N-#4P)UT@/2`G
M0G)A=6YS8VAW96EG)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+C,P
M,#HW+C,X,R==(#T@)U)H96EN92U"96YT;&%G92<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<U,BXS,S,Z-RXU,S,G72`]("=(;W!S=&5N)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S4R+C,X,SHQ,RXU,3<G72`]("="97)L:6XM
M4V-H;V5N969E;&0G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N-#4P
M.C<N,38W)UT@/2`G3F]R9&AO<FXG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-3(N-#4P.CDN-#,S)UT@/2`G5W5N<W1O<F8G.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-3(N-#8W.C$S+C0P,"==(#T@)T)E<FQI;BU496UP96QH
M;V8G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N-#8W.CDN-C@S)UT@
M/2`G2&%N;F]V97(G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N-38W
M.C$S+C,Q-R==(#T@)T)E<FQI;BU496=E;"<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<U,BXU.#,Z."XS-3`G72`]("=$:65P:&]L>B<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<U,BXV,#`Z,3`N,#$W)UT@/2`G0V5L;&4G.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N.#$W.CDN.3,S)UT@/2`G0F5R
M9V5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+CDQ-SHQ,"XQ.#,G
M72`]("=&87-S8F5R9R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,RXP
M-3`Z."XX,#`G72`]("="<F5M96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-3,N,C`P.C$R+C4Q-R==(#T@)U=I='1S=&]C:R<["B1C;V]R9&EN871E
M<ULG1V5R;6%N>2==6R<U,RXT,C<Z,3$N-S@T)UT@/2`G365C:VQE;F)U<F<M
M5F]R<&]M;65R;BP@4&%R8VAI;2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<U,RXU,S,Z-RXX.#,G72`]("=*979E<B<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<U,RXU,S,Z.2XX,S,G72`]("=(86UB=7)G+49I;FME;G=E<F1E
M<B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,RXU-3`Z-RXV-C<G72`]
M("=7:71T;75N9&AA=F5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S
M+C8P,#HQ,RXS,3<G72`]("=4<F]L;&5N:&%G96XG.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-3,N-C,S.C$P+C`P,"==(#T@)TAA;6)U<F<M1G5H;'-B
M=65T=&5L)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C<V-SHX+C8V
M-R==(#T@)TYO<F1H;VQZ)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S
M+C@Q-SHQ,"XW,#`G72`]("=,=65B96-K+4)L86YK96YS964G.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3,N.3$W.C$R+C(X,R==(#T@)TQA86=E)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4T+C`P,#HY+C4X,R==(#T@)TET
M>F5H;V4G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-30N,S$W.CDN-3,S
M)UT@/2`G2&]H;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U-"XS.#,Z
M,3`N,34P)UT@/2`G2VEE;"U(;VQT96YA=2<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<U-"XT-C<Z.2XU,3<G72`]("=38VAL97-W:6<M2F%G96PG.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-30N-C,S.CDN,S4P)UT@/2`G16=G
M96)E:R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U-"XX,S,Z.2XU,#`G
M72`]("=';'5E8VMS8G5R9R`O($UE:65R=VEK)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S4T+CDQ-SHX+C,U,"==(#T@)U=E<W1E<FQA;F0@+R!3>6QT
M)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<Q,"XP-3`Z+3(N-3`P)UT@/2`G
M5V$G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S$P+CDP,#HM,2XQ,#`G72`]
M("=.879R;VYG;R<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-"XX-C<Z+3(N
M,C,S)UT@/2`G07AI;2<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-"XX.#,Z
M+3$N-S8W)UT@/2`G5&%K;W)A9&DG.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;
M)S4N,C`P.BTQ+C`V-R==(#T@)U-A;'1P;VYD)SL*)&-O;W)D:6YA=&5S6R='
M:&%N82==6R<U+C8P,#HM,"XQ-C<G72`]("=!8V-R82<["B1C;V]R9&EN871E
M<ULG1VAA;F$G75LG-2XV,3<Z,"XP,#`G72`]("=496UA)SL*)&-O;W)D:6YA
M=&5S6R=':&%N82==6R<U+C<X,SHP+C8S,R==(#T@)T%D82<["B1C;V]R9&EN
M871E<ULG1VAA;F$G75LG-2XY,S,Z+3`N.3@S)UT@/2`G06MI;2!/9&$G.PHD
M8V]O<F1I;F%T97-;)T=H86YA)UU;)S8N,#@S.BTP+C(U,"==(#T@)TMO9F]R
M:61U82<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-BXQ,#`Z,"XQ,3<G72`]
M("=!:W5S92<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-BXR,#`Z+3(N,S,S
M)UT@/2`G4V5F=VD@0F5K=V%I)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<V
M+C8P,#HP+C0V-R==(#T@)TAO)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<V
M+C<Q-SHM,2XV,#`G72`]("=+=6UA<VDG.PHD8V]O<F1I;F%T97-;)T=H86YA
M)UU;)S<N,S,S.BTR+C,S,R==(#T@)U-U;GEA;FDG.PHD8V]O<F1I;F%T97-;
M)T=H86YA)UU;)S<N-S4P.BTR+C$P,"==(#T@)U=E;F-H:2<["B1C;V]R9&EN
M871E<ULG1VAA;F$G75LG.2XP,S,Z+3(N-#@S)UT@/2`G0F]L92<["B1C;V]R
M9&EN871E<ULG1VAA;F$G75LG.2XT-3`Z+3`N,#$W)UT@/2`G665N9&DG.PHD
M8V]O<F1I;F%T97-;)T=H86YA)UU;)SDN-3`P.BTP+C@U,"==(#T@)U1A;6%L
M92<["B1C;V]R9&EN871E<ULG1VEB<F%L=&%R)UU;)S,V+C$U,#HM-2XS-3`G
M72`]("=':6)R86QT87(G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S-2XS
M,S,Z,C4N,3@S)UT@/2`G2&5R86ML:6]N($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T=R965C92==6R<S-2XT,30Z,C<N,30X)UT@/2`G2V%R<&%T:&]S($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S-2XT.#,Z,C0N,3$W
M)UT@/2`G4V]U9&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;
M)S,V+C0P,#HR."XP.#,G72`]("=2:&]D97,@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG1W)E96-E)UU;)S,V+C<X,SHR-RXP-C<G72`]("=+;W,@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,W+C`V-SHR,BXP,3<G72`]
M("=+86QA;6%T82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG
M,S<N-3,S.C(R+C0P,"==(#T@)U1R:7!O;&ES($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)T=R965C92==6R<S-RXW,#`Z,C8N.3$W)UT@/2`G4V%M;W,@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,W+CDP,#HR,RXW,S,G
M72`]("=!=&AI;F%I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==
M6R<S-RXY,3<Z,C$N,C@S)UT@/2`G06YD<F%V:61A($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T=R965C92==6R<S."XP-C<Z,C,N-34P)UT@/2`G16QE9G-I
M<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S@N,3`P.C(S
M+C<X,R==(#T@)U1A=&]I)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S@N
M,3$W.C(P+C4P,"==(#T@)TME9F%L:&YI82!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R='<F5E8V4G75LG,S@N,34P.C(Q+C0Q-R==(#T@)T%R87AO<R!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S@N,S$W.C(S+C4S,R==
M(#T@)U1A;F%G<F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;
M)S,X+C,S,SHR-BXQ,S,G72`]("=#:&EO<R!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R='<F5E8V4G75LG,S@N-C$W.C(P+C<V-R==(#T@)T%K=&EO;B!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,SDN,#8W.C(V+C8P,"==
M(#T@)TUY=&EL:6YI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==
M6R<S.2XR,3<Z,C(N.#`P)UT@/2`G06YC:&EA;&]S($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T=R965C92==6R<S.2XV,3<Z,3DN.3$W)UT@/2`G2V5R:WER
M82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,SDN-C,S.C(R
M+C0Q-R==(#T@)TQA<FES<V$@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E
M96-E)UU;)S,Y+CDQ-SHR-2XR,S,G72`]("=,:6UN;W,@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG1W)E96-E)UU;)S0P+C,P,#HR,2XW.#,G72`]("=+;WIA
M;FD@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S0P+C0U,#HR
M,2XR.#,G72`]("=+87-T;W)I82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='
M<F5E8V4G75LG-#`N-3$W.C(R+CDV-R==(#T@)U1H97-S86QO;FEK:2!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG-#`N.#4P.C(U+CDQ-R==
M(#T@)T%L97AA;F1R;W5P;VQI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R
M965C92==6R<T,"XY.#,Z,C0N-C`P)UT@/2`G0VAR>7-O=7!O;&D@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S4Y+CDX,SHM-#4N,C`P
M)UT@/2`G06YG:7-O<2<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8P
M+C`U,#HM-#,N,38W)UT@/2`G4')I;G,@0VAR:7-T:6%N(%-U;F0G.PHD8V]O
M<F1I;F%T97-;)T=R965N;&%N9"==6R<V,"XW,3<Z+30V+C`U,"==(#T@)TIU
M;&EA;F5H86%B)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C$N,38W
M.BTT-2XT,3<G72`]("=.87)S87)S=6%Q)SL*)&-O;W)D:6YA=&5S6R='<F5E
M;FQA;F0G75LG-C$N,C,S.BTT."XQ,#`G72`]("='<F]E;FYE9&%L)SL*)&-O
M;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C(N,#`P.BTT.2XV-C<G72`]("=&
M<F5D97)I:W-H86%B)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C0N
M,38W.BTU,2XW-3`G72`]("=';V1T:&%A8B`O($YU=6LG.PHD8V]O<F1I;F%T
M97-;)T=R965N;&%N9"==6R<V-2XU.#,Z+3,W+C$U,"==(#T@)TMU;'5S=6L@
M3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V-2XV,#`Z
M+3,W+C8S,R==(#T@)U1A<VEI;&%Q)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA
M;F0G75LG-C8N.3$W.BTU,RXV-C<G72`]("=(;VQS=&5I;G-B;W)G)SL*)&-O
M;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C<N,#$W.BTU,"XW,#`G72`]("=3
M9'(@4W1R;V5M9FIO<F0G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V
M-RXW.#,Z+3,R+C,P,"==(#T@)T%P=71I=&5E<2<["B1C;V]R9&EN871E<ULG
M1W)E96YL86YD)UU;)S8X+C<P,#HM-3(N-S4P)UT@/2`G16=E9&5S;6EN9&4G
M.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V.2XR,S,Z+34Q+C`V-R==
M(#T@)TIA8V]B<VAA=FX@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)T=R965N
M;&%N9"==6R<W,"XT,3<Z+3(Q+CDV-R==(#T@)T-A<&4@5&]B:6X@075T;VUA
M=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA
M;F0G75LG-S`N-#@S.BTR,2XY-3`G72`]("=38V]R97-B>7-U;F0G.PHD8V]O
M<F1I;F%T97-;)T=R965N;&%N9"==6R<W,"XW-3`Z+3(R+C8U,"==(#T@)T-O
M;G-T86)L92!0>6YT)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-S0N
M,S`P.BTR,"XR,3<G72`]("=$86YE8F]R9R<["B1C;V]R9&EN871E<ULG1W)E
M96YL86YD)UU;)S<V+C4S,SHM-C@N-S4P)UT@/2`G5&AU;&4@02X@0BXG.PHD
M8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<W-BXW-C<Z+3$X+C8V-R==(#T@
M)T1A;FUA<FMS:&%V;B<["B1C;V]R9&EN871E<ULG1W)E;F%D82==6R<Q,BXP
M,#`Z+38Q+C<X,R==(#T@)U!O:6YT(%-A;&EN97,@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG1W5A9&5L;W5P92==6R<Q-BXR-C<Z+38Q+C4Q-R==(#T@)TQE
M(%)A:7IE="P@1W5A9&5L;W5P92<["B1C;V]R9&EN871E<ULG1W5A9&5L;W5P
M92==6R<Q-RXY,#`Z+38R+C@U,"==(#T@)T=U<W1A=FEA+"!386EN="!"87)T
M:&5L96UY)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA;&$G75LG,3,N.3$W.BTY
M,"XX,3<G72`]("=386X@2F]S92<["B1C;V]R9&EN871E<ULG1W5A=&5M86QA
M)UU;)S$T+C4S,SHM.3$N-C8W)UT@/2`G4F5T86QH=6QE=2<["B1C;V]R9&EN
M871E<ULG1W5A=&5M86QA)UU;)S$T+C4X,SHM.3`N-3$W)UT@/2`G1W5A=&5M
M86QA($%E<F]P=65R=&]L82!!=7)O<F$G.PHD8V]O<F1I;F%T97-;)T=U871E
M;6%L82==6R<Q-2XS,3<Z+3DQ+C0V-R==(#T@)TAU96AU971E;F%N9V\G.PHD
M8V]O<F1I;F%T97-;)T=U871E;6%L82==6R<Q-2XT-C<Z+3DP+C,Q-R==(#T@
M)T-O8F%N)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA;&$G75LG,34N-S$W.BTX
M."XV,#`G72`]("=0=65R=&\@0F%R<FEO<R<["B1C;V]R9&EN871E<ULG1W5A
M=&5M86QA)UU;)S$V+CDQ-SHM.#DN.#@S)UT@/2`G1FQO<F5S)SL*)&-O;W)D
M:6YA=&5S6R='=6EN96$G75LG,3`N,#,S.BTQ,"XW-3`G72`]("=&87)A;F%H
M("\@0F%D86QA)SL*)&-O;W)D:6YA=&5S6R='=6EN96$G75LG,3`N,#4P.BTQ
M,BXX-C<G72`]("=+:6YD:6$G.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Q
M,"XS.#,Z+3DN,S`P)UT@/2`G2V%N:V%N)SL*)&-O;W)D:6YA=&5S6R='=6EN
M96$G75LG,3`N.3,S.BTQ-"XS,3<G72`]("=";VME)SL*)&-O;W)D:6YA=&5S
M6R='=6EN96$G75LG,3$N,S$W.BTQ,BXS,#`G72`]("=,86)E)SL*)&-O;W)D
M:6YA=&5S6R='=6EN96$G75LG,3$N-#,S.BTY+C$V-R==(#T@)U-I9W5I<FDG
M.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<W+C<S,SHM."XX,S,G72`]("=.
M7"=:97)E:V]R92<["B1C;V]R9&EN871E<ULG1W5I;F5A)UU;)S@N-3,S.BTY
M+C0V-R==(#T@)TUA8V5N=&$G.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Y
M+C$X,SHM,3`N,3`P)UT@/2`G2VES<VED;W5G;W4G.PHD8V]O<F1I;F%T97-;
M)T=U:6YE82==6R<Y+C4V-SHM,3,N-C$W)UT@/2`G0V]N86MR>2`O($=B97-S
M:6$G.PHD8V]O<F1I;F%T97-;)T=U:6YE82U":7-S874G75LG,3$N.#@S.BTQ
M-2XV-3`G72`]("=":7-S874@065R;W!O<G0G.PHD8V]O<F1I;F%T97-;)T=U
M:6YE82U":7-S874G75LG,3(N,38W.BTQ-"XV-C<G72`]("="869A=&$G.PHD
M8V]O<F1I;F%T97-;)T=U>6%N82==6R<V+C4P,#HM-3@N,C4P)UT@/2`G5&EM
M96AR:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='=7EA;F$G75LG-BXX,#`Z
M+34X+C$U,"==(#T@)T=E;W)G971O=VXG.PHD8V]O<F1I;F%T97-;)TAA:71I
M)UU;)S$X+C4V-SHM-S(N,S`P)UT@/2`G4&]R="U!=2U0<FEN8V4@+R!!97)O
M<&]R="!);G1E<FYA=&EO;F%L)SL*)&-O;W)D:6YA=&5S6R=(86ET:2==6R<Q
M.2XW-3`Z+3<R+C$X,R==(#T@)T-A<"U(86ET:65N)SL*)&-O;W)D:6YA=&5S
M6R=(;VYD=7)A<R==6R<Q,RXR-C<Z+3@W+C8U,"==(#T@)T%M87!A;&$G.PHD
M8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$S+C,P,#HM.#<N,3@S)UT@/2`G
M0VAO;'5T96-A)SL*)&-O;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-"XP-3`Z
M+3@W+C(Q-R==(#T@)U1E9W5C:6=A;'!A)SL*)&-O;W)D:6YA=&5S6R=(;VYD
M=7)A<R==6R<Q-"XS,3<Z+3@X+C$U,"==(#T@)TQA($5S<&5R86YZ82<["B1C
M;V]R9&EN871E<ULG2&]N9'5R87,G75LG,30N,S@S.BTX-RXV,3<G72`]("=#
M;W)O;F5L($5N<FEQ=64@4V]T;R!#86YO($%I<B!"87-E)SL*)&-O;W)D:6YA
M=&5S6R=(;VYD=7)A<R==6R<Q-"XW.#,Z+3@X+C<X,R==(#T@)U-A;G1A(%)O
M<V$@1&4@0V]P86XG.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$T+CDP
M,#HM.#4N.3,S)UT@/2`G0V%T86-A;6%S)SL*)&-O;W)D:6YA=&5S6R=(;VYD
M=7)A<R==6R<Q-2XQ-C<Z+3@W+C$Q-R==(#T@)UEO<F\G.PHD8V]O<F1I;F%T
M97-;)TAO;F1U<F%S)UU;)S$U+C(Q-SHM.#,N.#`P)UT@/2`G4'5E<G1O($QE
M;7!I<F$G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$U+C0U,#HM.#<N
M.3,S)UT@/2`G3&$@365S82!386X@4&5D<F\@4W5L82<["B1C;V]R9&EN871E
M<ULG2&]N9'5R87,G75LG,34N-S$W.BTX-RXT.#,G72`]("=496QA)SL*)&-O
M;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-2XW,S,Z+3@V+C@V-R==(#T@)TQA
M($-E:6)A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$V
M+C,Q-SHM.#8N-3$W)UT@/2`G4F]A=&%N)SL*)&-O;W)D:6YA=&5S6R=(;VYD
M=7)A<R==6R<Q-BXT-C<Z+3@V+C`V-R==(#T@)T=U86YA:F$G.PHD8V]O<F1I
M;F%T97-;)TAO;F1U<F%S)UU;)S$W+C0P,#HM.#,N.3,S)UT@/2`G27-L87,@
M1&5L($-I<VYE)SL*)&-O;W)D:6YA=&5S6R=(;VYG($MO;F<G75LG,C(N,C`P
M.C$Q-"XP,3<G72`]("=#:&5U;F<@0VAA=2<["B1C;V]R9&EN871E<ULG2&]N
M9R!+;VYG)UU;)S(R+C,S,SHQ,30N,3@S)UT@/2`G2&]N9R!+;VYG($EN=&5R
M+4YA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG
M-#8N,3`P.C$X+C(S,R==(#T@)U!E8W,@+R!0;V=A;GDG.PHD8V]O<F1I;F%T
M97-;)TAU;F=A<GDG75LG-#8N,C4P.C(P+C$P,"==(#T@)U-Z96=E9"<["B1C
M;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-BXS.#,Z,3<N.#,S)UT@/2`G2V%P
M;W-V87(G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#8N-C@S.C(Q+C$V
M-R==(#T@)T)E:V5S8W-A8F$G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG
M-#8N.3$W.C$X+C`U,"==(#T@)U-I;V9O:R<["B1C;V]R9&EN871E<ULG2'5N
M9V%R>2==6R<T-BXY,3<Z,3DN-S4P)UT@/2`G2V5C<VME;65T)SL*)&-O;W)D
M:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C$Q-SHR,"XR,S,G72`]("=3>F]L;F]K
M)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C(P,#HQ-RXU,#`G72`]
M("=087!A)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C(V-SHQ-BXV
M,S,G72`]("=3>F]M8F%T:&5L>2<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==
M6R<T-RXT,S,Z,3DN,C8W)UT@/2`G0G5D87!E<W0@+R!&97)I:&5G>2<["B1C
M;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-RXT-3`Z,3@N.38W)UT@/2`G0G5D
M86]R<R<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-RXT.#,Z,C$N-C`P
M)UT@/2`G1&5B<F5C96XG.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#<N
M-3$W.C$Y+C`S,R==(#T@)T)U9&%P97-T($UE="!#96YT97(G.PHD8V]O<F1I
M;F%T97-;)TAU;F=A<GDG75LG-#<N.38W.C(Q+CDX,R==(#T@)TYY:7)E9WEH
M87IA("\@3F%P:V]R)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0X+C`X
M,SHR,"XW-C<G72`]("=-:7-K;VQC)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD
M)UU;)S8S+C0P,#HM,C`N,C@S)UT@/2`G5F5S=&UA;FYA97EJ87(G.PHD8V]O
M<F1I;F%T97-;)TEC96QA;F0G75LG-C,N.38W.BTR,BXV,#`G72`]("=+969L
M879I:W5R9FQU9W9O;&QU<B<["B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V
M-"XQ,S,Z+3(Q+CDP,"==(#T@)U)E>6MJ879I:R<["B1C;V]R9&EN871E<ULG
M26-E;&%N9"==6R<V-"XS,#`Z+3$U+C(Q-R==(#T@)T%K=7)N97,G.PHD8V]O
M<F1I;F%T97-;)TEC96QA;F0G75LG-C4N,#@S.BTR,BXW,S,G72`]("=3='EK
M:VES:&]L;75R)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD)UU;)S8U+C(X,SHM
M,30N-#`P)UT@/2`G16=I;'-S=&%D:7(G.PHD8V]O<F1I;F%T97-;)TEC96QA
M;F0G75LG-C4N-C@S.BTQ."XP.#,G72`]("=!:W5R97ER:2<["B1C;V]R9&EN
M871E<ULG26-E;&%N9"==6R<V-2XW,#`Z+3$T+C@Q-R==(#T@)U-K:F%L9'1H
M:6YG<W-T861I<B<["B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V-BXT-3`Z
M+3$U+CDU,"==(#T@)U)A=69A<FAO9FXG.PHD8V]O<F1I;F%T97-;)TEC96QA
M;F0G75LG-C8N-3,S.BTQ."XP,3<G72`]("='<FEM<V5Y)SL*)&-O;W)D:6YA
M=&5S6R=);F1I82==6R<Q,"XW-C<Z-S@N-S$W)UT@/2`G5&ER=6-H8VAI<F%P
M86QL:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,3$N,#,S.C<W+C`U,"==
M(#T@)T-O:6UB871O<F4@+R!0965L86UE9'4G.PHD8V]O<F1I;F%T97-;)TEN
M9&EA)UU;)S$Q+C8V-SHY,BXW,3<G72`]("=0;W)T($)L86ER)SL*)&-O;W)D
M:6YA=&5S6R=);F1I82==6R<Q,BXY,3<Z-S0N.#@S)UT@/2`G36%N9V%L;W)E
M("\@0F%J<&4G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$R+CDQ-SHW.2XQ
M-3`G72`]("=696QL;W)E)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q,RXP
M,#`Z.#`N,3@S)UT@/2`G36%D<F%S("\@36EN86UB86MK86TG.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)S$T+C0X,SHW."XX,S,G72`]("=#=61D87!A:"<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,34N,34P.C<V+C@U,"==(#T@)T)E
M;&QA<GDG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$U+C,X,SHW,RXX,3<G
M72`]("=';V$@+R!$86)O;&EM($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TEN
M9&EA)UU;)S$U+C@U,#HW-"XV,3<G72`]("="96QG875M("\@4V%M8G)A)SL*
M)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q-BXU,S,Z.#`N.#`P)UT@/2`G5FEJ
M87EA=V%D82`O($=A;FYA=F%R86TG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;
M)S$V+C<P,#HW-"XR,S,G72`]("=+;VQH87!U<B<["B1C;V]R9&EN871E<ULG
M26YD:6$G75LG,3<N-#4P.C<X+C0V-R==(#T@)TAY9&5R86)A9"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q-RXV-C<Z-S4N.3`P)UT@/2`G
M4VAO;&%P=7(G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$Y+C$Q-SHW,BXX
M-3`G72`]("=";VUB87D@+R!386YT86-R=7HG.PHD8V]O<F1I;F%T97-;)TEN
M9&EA)UU;)S$Y+C@U,#HW-2XT,#`G72`]("=!=7)A;F=A8F%D($-H:6MA;'1H
M86X@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,"XR-3`Z
M.#4N.#,S)UT@/2`G0FAU8F%N97-W87(G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(P+C<P,#HW-RXP-C<G72`]("=!:V]L82<["B1C;V]R9&EN871E<ULG
M26YD:6$G75LG,C$N,3`P.C<Y+C`U,"==(#T@)TYA9W!U<B!3;VYE9V%O;B<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,C$N-S4P.C<R+C(P,"==(#T@)T)H
M875N86=A<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C$N.#,S.C<V+C,V
M-R==(#T@)TMH86YD=V$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(Q+CDQ
M-SHX-"XP.#,G72`]("=*:&%R<W5G=61A)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R,BXS,#`Z-S`N-S@S)UT@/2`G4F%J:V]T)SL*)&-O;W)D:6YA=&5S
M6R=);F1I82==6R<R,BXV-3`Z.#@N-#4P)UT@/2`G0V%L8W5T=&$@+R!$=6T@
M1'5M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,BXW,3<Z-S4N.#`P)UT@
M/2`G26YD;W)E)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,BXX,3<Z.#8N
M,3@S)UT@/2`G2F%M<VAE9'!U<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,C,N,#8W.C<R+C8S,R==(#T@)T%H;6%D86)A9"<["B1C;V]R9&EN871E<ULG
M26YD:6$G75LG,C,N,C`P.C<Y+CDU,"==(#T@)TIA8F%L<'5R)SL*)&-O;W)D
M:6YA=&5S6R=);F1I82==6R<R,RXR-3`Z-CDN-C8W)UT@/2`G0FAU:BU2=61R
M86UA=&$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(S+C(X,SHW-RXS-3`G
M72`]("=":&]P86P@+R!"86ER86=A<F@G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(S+C,Q-SHX-2XS,3<G72`]("=-+B!/+B!286YC:&DG.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)S(S+C@X,SHY,2XR-3`G72`]("=!9V%R=&%L82<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,C0N-38W.C@P+C@S,R==(#T@)U-A
M=&YA)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-"XV,3<Z-S,N.#@S)UT@
M/2`G561A:7!U<B!$86)O:R<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C0N
M-S4P.C@T+CDU,"==(#T@)T=A>6$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;
M)S(T+C<V-SHY,RXY,#`G72`]("=);7!H86P@5'5L:6AA;"<["B1C;V]R9&EN
M871E<ULG26YD:6$G75LG,C4N,34P.C<U+C@U,"==(#T@)TMO=&$@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-2XT-3`Z-S@N-3@S)UT@
M/2`G2FAA;G-I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-2XT-3`Z.#$N
M-S,S)UT@/2`G06QL86AA8F%D("\@0F%M:')A=6QI)SL*)&-O;W)D:6YA=&5S
M6R=);F1I82==6R<R-2XT-3`Z.#(N.#8W)UT@/2`G5F%R86YA<VD@+R!"86)A
M='!U<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C4N-C`P.C@U+C$P,"==
M(#T@)U!A=&YA)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-BXQ,#`Z.3$N
M-3@S)UT@/2`G1V%U:&%T:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C8N
M,C,S.C<X+C(U,"==(#T@)T=W86QI;W(G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(V+C,P,#HW,RXP,3<G72`]("=*;V1H<'5R)SL*)&-O;W)D:6YA=&5S
M6R=);F1I82==6R<R-BXT,#`Z.#`N-#`P)UT@/2`G2V%N<'5R("\@0VAA:V5R
M:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C8N-C,S.C@X+C,Q-R==(#T@
M)U-I;&EG=7)I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-BXW-3`Z.#`N
M.#@S)UT@/2`G3'5C:VYO=R`O($%M875S:2<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,C8N-S4P.C@S+C,V-R==(#T@)T=O<F%K:'!U<B<["B1C;V]R9&EN
M871E<ULG26YD:6$G75LG,C8N.#$W.C<U+C@P,"==(#T@)TIA:7!U<B`O(%-A
M;F=A;F5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-RXQ-3`Z-S<N.38W
M)UT@/2`G06=R82<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C<N,C,S.CDT
M+C$Q-R==(#T@)TYO<G1H($QA:VAI;7!U<B<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,C<N-#@S.CDU+C`Q-R==(#T@)T1I8G)U9V%R:"`O($UO:&%N8F%R
M:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C@N,S8W.C<Y+C0P,"==(#T@
M)T)A<F5I;&QY)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R."XU-C<Z-S<N
M,3$W)UT@/2`G3F5W($1E;&AI("\@4&%L86TG.PHD8V]O<F1I;F%T97-;)TEN
M9&EA)UU;)S(X+C4X,SHW-RXR,#`G72`]("=.97<@1&5L:&D@+R!3869D87)J
M=6YG)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R.2XQ-C<Z-S4N-S,S)UT@
M/2`G2&ES<V%R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<S,2XR-3`Z-S8N
M-C8W)UT@/2`G0FEL87-P=7(G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S,Q
M+C8S,SHW-"XX-C<G72`]("=!;7)I='-A<B<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG."XT-C<Z-S8N.34P)UT@/2`G5&AI<G5V86YA;G1H87!U<F%M)SL*
M)&-O;W)D:6YA=&5S6R=);F1I82==6R<Y+C$U,#HY,BXX,3<G72`]("=#87(@
M3FEC;V)A<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG.2XX,S,Z-S@N,#@S
M)UT@/2`G36%D=7)A:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG.2XY-3`Z
M-S8N,C8W)UT@/2`G0V]C:&EN("\@5VEL;&EN9V1O;B<["B1C;V]R9&EN871E
M<ULG26YD;VYE<VEA)UU;)S`N,3$W.C$Q,2XU,S,G72`]("=3:6YT86YG)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N,34P.C$P.2XT,#`G72`]
M("=0;VYT:6%N86L@+R!3=7!A9&EO)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG,"XT-C<Z,3`Q+C0U,"==(#T@)U!A:V%N8F%R=2`O(%-I;7!A;F=T
M:6=A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,"XT-C<Z,3`R+C,Q
M-R==(#T@)U)E;F=A="`O($IA<'5R82<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTP+C0X,SHQ,#0N-3@S)UT@/2`G4VEN9VME<"`O($1A8F\G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<P+C4Q-SHQ,C,N,#8W)UT@/2`G
M1V]R;VYT86QO("\@2F%L86QU9&1I;B<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTP+C8Q-SHQ,3<N,34P)UT@/2`G4V%M87)I;F1A("\@5&5M:6YD
M=6YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N-C@S.C$Q.2XW
M,S,G72`]("=086QU("\@375T:6%R82<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)S`N-S@S.C$R-RXS.#,G72`]("=497)N871E("\@0F%B=6QL86@G
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,"XX.#,Z,3`P+C,U,"==
M(#T@)U!A9&%N9R`O(%1A8FEN9R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTP+C@X,SHQ,S0N,#4P)UT@/2`G36%N;VMW87)I("\@4F5N9&%N:2<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTP+CDP,#HQ,C(N-S@S)UT@
M/2`G3'5W=6L@+R!"=6)U;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<P+CDQ-SHQ,#0N-3,S)UT@/2`G5&%N:G5N9W!I;F%N9R`O($MI:F%N9R<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTP+CDS,SHQ,S$N,3$W)UT@
M/2`G4V]R;VYG("\@2F5F;6%N)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3`N.34P.C$Q-"XY,#`G72`]("=-=6%R871E=V4@+R!"97)I;F=I;B<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C`P,#HQ,30N,#`P)UT@
M/2`G4&%L86YG:V%R87EA("\@4&%N87)U;F<G.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<Q+C`Q-SHQ,C`N.#`P)UT@/2`G5&]L:2U4;VQI("\@3&%L
M;W,G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<Q+C`X,SHQ,#DN-C8W
M)UT@/2`G4VEN9VMA=V%N9R!):2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)S$N,3$W.C$P-"XQ,3<G72`]("="871A;B`H4W5M871R82DG.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XQ.#,Z,3,V+C$Q-R==(#T@)T)I
M86L@+R!-;VMM97(G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XR
M-C<Z,3$V+CDP,"==(#T@)T)A;&EK<&%P86X@+R!397!I;F=G86XG.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XS.#,Z,3(P+C<S,R==(#T@)U!O
M<V\@+R!+87-I9W5N8W4G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<Q
M+C4P,#HY-RXV,S,G72`]("='=6YU;F<@4VET;VQI("\@0FEN86MA)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,2XU,S,Z,3(T+CDQ-R==(#T@)TUE
M;F%D;R`O($1R+B!386T@4F%T=6QA;F=I)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG,2XU-3`Z.3@N.#@S)UT@/2`G4VEB;VQG82`O(%!I;F%N9W-O
M<FDG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XV,3<Z,3(T+C4U
M,"==(#T@)TQA8G5H82`O(%1A;&EA8G4G.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<M,2XV,S,Z,3`S+C8U,"==(#T@)TIA;6)I("\@4W5L=&%N(%1A
M:&$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<Q+C@Q-SHQ,C<N.#,S
M)UT@/2`G1V%L96QA("\@1V%M87)M86QA;74G.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M,2XX,S,Z,3,X+C<Q-R==(#T@)U-A<FUI)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG+3$N.#4P.C$P.2XY-C<G72`]("=+971A
M<&%N9R`O(%)A:&%D:2!5<VUA;6%N)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3$N.#8W.C$S-BXR,S,G72`]("=397)U:2`O(%EE;F1O<V$G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,3`N,38W.C$R,RXV-C<G72`]
M("=+=7!A;F<@+R!%;"!487)I)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3$P+C4P,#HQ,C$N.#,S)UT@/2`G4V%B=2`O(%1A<F1A;74G.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M,3`N-S,S.C$R,RXP-C<G72`]("=2
M;W1E("\@0F%A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3(N,#@S
M.C$R-BXP,#`G72`]("=386YA;F$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I
M82==6R<R+C$Q-SHQ,3<N-#4P)UT@/2`G5&%N:G5N9R!2961E<"`O($)E<F%U
M)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3(N,38W.C$P-BXQ,S,G
M72`]("=086YG:V%L<&EN86YG("\@4&%N9VMA;'!I;F%N9R<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTR+C4V-SHQ-#`N-#@S)UT@/2`G2F%Y87!U
M<F$@+R!396YT86YI)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3(N
M-S`P.C$Q,"XW,#`G72`]("=086YG:V%L86X@0G5N("\@27-K86YD87(G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXW-3`Z,3`W+C<U,"==(#T@
M)U1A;FIU;F=P86YD86X@+R!"=6QU:"!4=6UB86YG)SL*)&-O;W)D:6YA=&5S
M6R=);F1O;F5S:6$G75LG+3(N-S8W.C$P,2XS-C<G72`]("=+97)I;F-I("\@
M1&5P871I(%!A<F)O)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,BXX
M-3`Z,3$W+C,S,R==(#T@)U1A;FIU;F<@4V5L;W(G.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M,BXX.#,Z,3,R+C(U,"==(#T@)T9A:RU&86L@+R!4
M;W)E82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTR+CDP,#HQ,#0N
M-S`P)UT@/2`G4&%L96UB86YG("\@5&%L86YG8F5T=71U)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+3,N,C4P.C$R-RXP.#,G72`]("=.86UL96$G
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<S+C,S,SHQ,3<N-38W)UT@
M/2`G5&%R86MA;B`O($IU=V%T82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTS+C,S,SHQ,S4N-3`P)UT@/2`G3F%B:7)E)SL*)&-O;W)D:6YA=&5S
M6R=);F1O;F5S:6$G75LG+3,N,S4P.C$R."XX.#,G72`]("=!;6%H86DG.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXT,#`Z,3$V+C(Q-R==(#T@
M)TMO=&%B87)U)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3,N-#,S
M.C$Q-"XW-3`G72`]("="86YJ87)M87-I;B`O(%-Y86US=61D:6X@3F]O<B<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S,N-38W.CDX+C8X,R==(#T@
M)TUE9&%N("\@4&]L;VYI82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)S,N-3@S.C$R-2XT-C<G72`]("=486AU;F$G.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M,RXV-C<Z,3,S+C<U,"==(#T@)TMA:6UA;F$@+R!5=&%R
M;VTG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXW,#`Z,3(X+C`X
M,R==(#T@)T%M8F]N("\@4&%T=&EM=7)A)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG,RXW,S,Z,3$U+C8X,R==(#T@)TQO;F=B87=A;B`O($IU=F%I
M(%-E;6%R:6YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3,N.#@S
M.C$P,BXS,S,G72`]("="96YG:W5L=2`O(%!A9&%N9VME;6EL:6YG)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3,N.3$W.C$S-BXS-C<G72`]("=%
M;F%R;W1A;&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<S+CDU,#HQ
M,#@N,S@S)UT@/2`G4F%N86D@+R!286YA:2<["B1C;V]R9&EN871E<ULG26YD
M;VYE<VEA)UU;)RTT+C`V-SHQ,S@N.34P)UT@/2`G5V%M96YA("\@5V%M96YA
M)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+30N,3`P.C$R,BXT,S,G
M72`]("=+96YD87)I("\@5V]L=&5R;6]N+4=I;G-I9&DG.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<T+C(U,#HY-BXQ,3<G72`]("=-975L86)O:"`O
M($-U="!.>6%K($1H:65N)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M+30N-#4P.C$P-2XQ.#,G72`]("=-96YG9V%L82`O($%S=')A($MS971R82<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTT+C<Q-SHQ,S8N-#,S)UT@
M/2`G2V]K;VYA;R`O(%1I;75K82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTU+C`V-SHQ,3DN-34P)UT@/2`G56IU;F<@4&%N9&%N9R`O($AA<V%N
M=61D:6XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<U+C(S,SHY-RXR
M,#`G72`]("=,:&]K<V5U;6%W92`O($UA;&EK=7-S86QE:"<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTU+C(V-SHQ,#4N,3@S)UT@/2`G5&5L=6MB
M971U;F<@+R!"97)A;G1I)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M+34N-#8W.C$R,BXV,3<G72`]("="874M0F%U("\@0F5T;R!!;6)I<FDG.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<U+C4Q-SHY-2XT,3<G72`]("="
M86YD82!!8V5H("\@0FQA;F=B:6YT86YG)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG-2XX-C<Z.34N,S$W)UT@/2`G4V%B86YG("\@0W5T($)A=2<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTV+C$P,#HQ-#`N,S`P)UT@
M/2`G5&%N86@@365R86@@+R!486YA:"!-97)A:"<["B1C;V]R9&EN871E<ULG
M26YD;VYE<VEA)UU;)RTV+C$Q-SHQ,#8N-C4P)UT@/2`G2F%K87)T82`O(%-O
M96MA<FYO+4AA='1A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+38N
M,C,S.C$P-BXV-3`G72`]("=#=7)U9R`O($)U9&EA<G1O)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+38N,C4P.C$P-BXY,#`G72`]("=*86MA<G1A
M($AA;&EM(%!E<F1A;F%K=7-U;6$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I
M82==6R<M-BXU-3`Z,3`W+C8V-R==(#T@)TMA;&EJ871I)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+38N.3`P.C$P-RXU.#,G72`]("="86YD=6YG
M("\@2'5S96EN)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+38N.3@S
M.C$Q,"XS.#,G72`]("=396UA<F%N9R`O($%H;6%D>6%N:2<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTW+C(Q-SHQ,3(N-S$W)UT@/2`G4W5R86)A
M>6$@+R!097)A:R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTW+C(Q
M-SHQ,3,N-S$W)UT@/2`G4W5R86)A>6$G.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<M-RXS,S,Z,3`X+C(U,"==(#T@)U1A<VEK;6%L87EA("\@0VEB
M975R975M)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N,S8W.C$Q
M,BXW-C<G72`]("=3=7)A8F%Y82`O($IU86YD82<["B1C;V]R9&EN871E<ULG
M26YD;VYE<VEA)UU;)RTW+C8Q-SHQ,3$N-3$W)UT@/2`G36%D:75N("\@27-W
M86AY=61I)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N-S,S.C$P
M.2XP,3<G72`]("=#:6QA8V%P)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3<N-S@S.C$Q,"XT,S,G72`]("=*;V=Y86MA<G1A("\@061I<W5C:7!T
M;R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTW+C@V-SHQ,3`N.3$W
M)UT@/2`G4W5R86MA<G1A("\@061I<W5M87)M;R<["B1C;V]R9&EN871E<ULG
M26YD;VYE<VEA)UU;)RTW+CDV-SHQ,3(N-S`P)UT@/2`G36%L86YG("\@06)D
M=6P@4F%H:VUA;G-A;&5H)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M+3<N.3@S.C$S,2XS,#`G72`]("=3875M;&%K:2<["B1C;V]R9&EN871E<ULG
M26YD;VYE<VEA)UU;)RTX+C(Q-SHQ,C0N-38W)UT@/2`G06QO<B`O($UA;&DG
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M."XR-C<Z,3(R+CDV-R==
M(#T@)TQA<F%N='5K82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX
M+C0S,SHQ,3<N-#$W)UT@/2`G4W5M8F%W82!"97-A<B`O(%-U;6)A=V$@0F5S
M87(G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M."XT-C<Z,30P+C,X
M,R==(#T@)TUE<F%U:V4@+R!-;W!A:"<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTX+C4S,SHQ,38N,#8W)UT@/2`G06UP96YA;B`O(%-E;&%P87)A
M;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M."XU-3`Z,3$X+C<P
M,"==(#T@)T)I;6$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M."XV
M,S,Z,3(R+C(U,"==(#T@)TUA=6UE<F4@+R!786D@3W1I)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+3@N-S4P.C$Q-2XQ-C<G72`]("=$96YP87-A
M<B`O($YG=7)A:"U286DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M
M.2XV-C<Z,3(P+C,S,R==(#T@)U=A:6YG87!U("\@36%U($AA=2<["B1C;V]R
M9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<R-2XT,3<Z
M-C`N-S4P)UT@/2`G0VAA:&)A:&%R)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(V+C4X,SHU-"XX,S,G72`]("="86YD
M87(@3&5N9V5H)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F)UU;)S(V+C8S,SHU-RXW-C<G72`]("=*87-K)SL*)&-O;W)D:6YA
M=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(W+C(P,#HV,"XW
M,#`G72`]("=)<F%N<VAA:'(G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8G75LG,C<N,C$W.C4V+C,V-R==(#T@)T)A;F1A<F%B
M8F%S<R<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B==6R<R."XY-C<Z-3,N-C@S)UT@/2`G1F%S82<["B1C;V]R9&EN871E<ULG
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<R."XY.#,Z-3`N.#,S)UT@
M/2`G0G5S:&5H<B!#:78@+R!!9F(G.PHD8V]O<F1I;F%T97-;)TER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8G75LG,CDN,3`P.C4X+C0P,"==(#T@)T)A;2<[
M"B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<R
M.2XT-C<Z-C`N.#@S)UT@/2`G6F%H961A;B<["B1C;V]R9&EN871E<ULG27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<R.2XU,S,Z-3(N-3@S)UT@/2`G
M4VAI<F%Z)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F)UU;)S,P+C(U,#HU-BXY-C<G72`]("=+97)M86XG.PHD8V]O<F1I;F%T
M97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S`N,S8W.C0X+C(U
M,"==(#T@)T%B861A;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B==6R<S,"XT,S,Z-3`N-S8W)UT@/2`G1V%C:"!387)A;B!$
M=2!'=6YB861A;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B==6R<S,"XW-C<Z-#DN-C8W)UT@/2`G3VUI9&EE:"<["B1C;V]R
M9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,2XQ.#,Z
M-3(N-C8W)UT@/2`G06)A9&5H)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F)UU;)S,Q+C,S,SHT."XV-C<G72`]("=!:'=A>B<[
M"B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S
M,2XS,S,Z-C$N-#@S)UT@/2`G6F%B;VPG.PHD8V]O<F1I;F%T97-;)TER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S$N.3`P.C4T+C0P,"==(#T@)UEA
M>F0G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G
M75LG,S$N.3@S.C0Y+C(V-R==(#T@)TUA<VIE9"U3;VQE>6UA;B<["B1C;V]R
M9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,BXS,S,Z
M-3`N.#4P)UT@/2`G4VAA:')E+4MO<F0G.PHD8V]O<F1I;F%T97-;)TER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S(N-#8W.C4Q+C<Q-R==(#T@)T5S
M9F%H86XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8G75LG,S(N.#8W.C4Y+C(P,"==(#T@)T)I<FIA;F0G.PHD8V]O<F1I;F%T
M97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S,N-C`P.C4V+CDQ
M-R==(#T@)U1A8F%S)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F)UU;)S,S+CDX,SHU,2XT-3`G72`]("=+87-H86XG.PHD8V]O
M<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S0N,3`P
M.C0Y+C0P,"==(#T@)T%R86LG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8G75LG,S0N,C8W.C0W+C$Q-R==(#T@)TME<FUA;G-H
M86@G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G
M75LG,S0N-3$W.C0U+C4X,R==(#T@)T=H87-R92U3:&ER:6XG.PHD8V]O<F1I
M;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S4N,C8W.C4Y
M+C(Q-R==(#T@)U1O<F)A="U(97ED87)I96@G.PHD8V]O<F1I;F%T97-;)TER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S4N,S,S.C0W+C`P,"==(#T@
M)U-A;F%N9&%J)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F)UU;)S,U+C4U,#HU,RXS.#,G72`]("=396UN86XG.PHD8V]O<F1I
M;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S4N-C@S.C4Q
M+C,U,"==(#T@)U1E:')A;BU-96AR86)A9"<["B1C;V]R9&EN871E<ULG27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-BXR,3<Z-3<N-C8W)UT@/2`G
M4V%B>F5V87(G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8G75LG,S8N,C4P.C0V+C(V-R==(#T@)U-A9VAE>B<["B1C;V]R9&EN
M871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-BXR-3`Z-3`N
M,#`P)UT@/2`G1VAA>G9I;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B==6R<S-BXR-C<Z-3DN-C,S)UT@/2`G36%S:&AA9"<[
M"B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S
M-BXV.#,Z-#@N-#@S)UT@/2`G6F%N:F%N)SL*)&-O;W)D:6YA=&5S6R=)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C@Q-SHU-"XT-C<G72`]("='
M;W)G86XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8G75LG,S8N.3`P.C4P+C8V-R==(#T@)U)A;7-A<B<["B1C;V]R9&EN871E
M<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-RXR,#`Z-#DN-C,S
M)UT@/2`G4F%S:'0G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8G75LG,S<N-#8W.C4W+C,S,R==(#T@)T)O:FYO=7)D)SL*)&-O
M;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,W+C4S
M,SHT-2XP.#,G72`]("=/<G5M:65H)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,X+C`X,SHT-BXR.#,G72`]("=486)R
M:7HG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G
M75LG,S@N-34P.C0T+CDV-R==(#T@)TMH;WDG.PHD8V]O<F1I;F%T97-;)TER
M87$G75LG,S`N-#$W.C0W+C8U,"==(#T@)U-H86EB86@@+R!"87-R86@G.PHD
M8V]O<F1I;F%T97-;)TER87$G75LG,S,N,C,S.C0T+C(S,R==(#T@)T)A9VAD
M860G.PHD8V]O<F1I;F%T97-;)TER87$G75LG,S8N,S$W.C0S+C$U,"==(#T@
M)TUO<W5L)SL*)&-O;W)D:6YA=&5S6R=)<F5L86YD)UU;)S4Q+C@U,#HM."XT
M.#,G72`]("=#;W)K($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TER96QA;F0G
M75LG-3(N-S`P.BTX+CDQ-R==(#T@)U-H86YN;VX@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG27)E;&%N9"==6R<U,RXS,#`Z+38N-#,S)UT@/2`G0V%S96UE
M;G0@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=)<F5L86YD)UU;)S4S+C0S
M,SHM-BXR-3`G72`]("=$=6)L:6X@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M27-R865L)UU;)S(Y+C4U,#HS-"XY-3`G72`]("=%:6QA="<["B1C;V]R9&EN
M871E<ULG27-R865L)UU;)S,P+C`P,#HS-"XX,S,G72`]("=/=F1A)SL*)&-O
M;W)D:6YA=&5S6R=)<W)A96PG75LG,S$N,C,S.C,T+C<X,R==(#T@)T)E97(M
M4VAE=F$G.PHD8V]O<F1I;F%T97-;)TES<F%E;"==6R<S,2XX-C<Z,S4N,C$W
M)UT@/2`G2F5R=7-A;&5M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TES<F%E
M;"==6R<S,BXP,#`Z,S0N.3`P)UT@/2`G0F5N+4=U<FEO;B!);G1E<FYA=&EO
M;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TES<F%E;"==6R<S,BXX,#`Z
M,S4N,#,S)UT@/2`G4V1E+4AA:69A($AA:69A)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<S-2XU,#`Z,3(N-C`P)UT@/2`G3&%M<&5D=7-A)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<S-BXV.#,Z,34N,3,S)UT@/2`G0V]Z>F\@4W!A
M9&%R;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG,S8N.#$W.C$Q+CDV-R==
M(#T@)U!A;G1E;&QE<FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S-RXP
M.#,Z,30N,C$W)UT@/2`G1V5L82<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M,S<N-#`P.C$T+CDQ-R==(#T@)T-A=&%N:6$@+R!3:6=O;F5L;&$G.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S,W+C0V-SHQ-2XP-3`G72`]("=#871A;FEA
M("\@1F]N=&%N87)O<W-A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S-RXU
M-C<Z,30N,C@S)UT@/2`G16YN82<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M,S<N.3$W.C$R+C4P,"==(#T@)U1R87!A;FD@+R!":7)G:2<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG,S@N,#8W.C$U+C8U,"==(#T@)U)E9V=I;R!#86QA
M8G)I82<["B1C;V]R9&EN871E<ULG271A;'DG75LG,S@N,3`P.C$S+C,P,"==
M(#T@)U!A;&5R;6\@0F]C8V%D:69A;&-O)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<S."XQ.#,Z,3,N,3`P)UT@/2`G4&%L97)M;R`O(%!U;G1A(%)A:7-I
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XR,#`Z,34N-34P)UT@/2`G
M365S<VEN82<["B1C;V]R9&EN871E<ULG271A;'DG75LG,S@N-S`P.C$S+C$X
M,R==(#T@)U5S=&EC82<["B1C;V]R9&EN871E<ULG271A;'DG75LG,S@N.3`P
M.C$V+C(U,"==(#T@)TQA;65Z:6$@5&5R;64G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S,Y+C`P,#HQ-RXP-C<G72`]("=#<F]T;VYE)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<S.2XQ,#`Z.2XU,3<G72`]("=#87!O($-A<F)O;F%R
M82<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN,C4P.CDN,#8W)UT@/2`G
M0V%G;&EA<FD@+R!%;&UA<R<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN
M,S,S.C$V+C0P,"==(#T@)TUO;G1E(%-C=7)O)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<S.2XS-3`Z."XY-C<G72`]("=$96-I;6]M86YN=2<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG,SDN-3`P.CDN-C,S)UT@/2`G0V%P;R!3+B!,
M;W)E;GIO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XU.#,Z,34N.#@S
M)UT@/2`G0F]N:69A=&DG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,Y+C8V
M-SHY+C0S,R==(#T@)U!E<F1A<V1E9F]G=2<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG,SDN-S4P.C@N-#8W)UT@/2`G0V%P;R!&<F%S8V$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S,Y+C@Q-SHQ."XS-3`G72`]("=3+B!-87)I82!$
M:2!,975C82<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN.3,S.CDN-S$W
M)UT@/2`G0V%P;R!"96QL879I<W1A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T,"XP,3<Z,34N,C@S)UT@/2`G0V%P;R!086QI;G5R;R<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#`N,#@S.C$V+C`Q-R==(#T@)TQA=')O;FEC;R<[
M"B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N,3$W.CDN,C4P)UT@/2`G1F]N
M;FDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C(S,SHQ."XQ-3`G72`]
M("=,96-C92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N-#,S.C$V+C@X
M,R==(#T@)TUA<FEN82!$:2!':6YO<V$G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0P+C4Q-SHQ-RXT,#`G72`]("='<F]T=&%G;&EE)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T,"XU-3`Z,30N,C`P)UT@/2`G0V%P<FDG.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S0P+C4V-SHX+C$V-R==(#T@)T-A<&\@0V%C
M8VEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XV,S,Z,34N.#`P)UT@
M/2`G4&]T96YZ82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N-C,S.C@N
M,C@S)UT@/2`G06QG:&5R;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N
M-C4P.C$W+CDU,"==(#T@)T)R:6YD:7-I)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T,"XW-C<Z,38N.3,S)UT@/2`G1VEO:6$@1&5L($-O;&QE)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XX-3`Z,30N,S`P)UT@/2`G3F%P;VQI
M("\@0V%P;V1I8VAI;F\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+CDP
M,#HY+C4Q-R==(#T@)T]L8FEA("\@0V]S=&$@4VUE<F%L9&$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0P+CDQ-SHQ,BXY-3`G72`]("=0;VYZ82<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#$N,#4P.C$T+C`V-R==(#T@)T=R87IZ
M86YI<V4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+C`U,#HQ-2XR,S,G
M72`]("=4<F5V:6-O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XQ,S,Z
M,38N-S@S)UT@/2`G0F%R:2`O(%!A;&5S92!-86-C:&EE)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T,2XR,3<Z.2XT,#`G72`]("='=6%R9&EA=F5C8VAI
M82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#$N-3,S.C$U+C<Q-R==(#T@
M)T%M96YD;VQA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XU-3`Z,3(N
M.3`P)UT@/2`G3&%T:6YA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XU
M-C<Z,30N-C4P)UT@/2`G0V%M<&]B87-S;R<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#$N-C,S.C$S+C,P,"==(#T@)T9R;W-I;F]N92<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#$N-C4P.C$R+C0U,"==(#T@)U!R871I8V$@1&D@
M36%R92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#$N-S`P.C$U+CDU,"==
M(#T@)TUO;G1E(%,N($%N9V5L;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#$N-S@S.C$R+C4X,R==(#T@)U)O;6$@+R!#:6%M<&EN;R<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#$N.#`P.C$R+C(S,R==(#T@)U)O;6$@1FEU;6EC
M:6YO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XY-3`Z,3(N-3`P)UT@
M/2`G4F]M82`O(%5R8F4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R+C`P
M,#HQ,BXW,S,G72`]("='=6ED;VYI82<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG-#(N,#`P.C$U+C`P,"==(#T@)U1E<FUO;&DG.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0R+C`S,SHQ,2XX,S,G72`]("=#:79I=&%V96-C:&EA)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXP.#,Z,3(N,C$W)UT@/2`G5FEG
M;F$@1&D@5F%L;&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R+C,X,SHQ
M,2XQ-C<G72`]("=-;VYT92!!<F=E;G1A<FEO)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T,BXT,3<Z,3(N.#4P)UT@/2`G4FEE=&DG.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0R+C0S,SHQ,BXP-3`G72`]("=6:71E<F)O)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXT,S,Z,30N,C`P)UT@/2`G4&5S8V%R
M82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N-#8W.C$R+CDX,R==(#T@
M)TUO;G1E(%1E<FUI;FEL;&\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R
M+C<S,SHQ,"XT,#`G72`]("=-+B!#86QA;6ET82<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#(N-S4P.C$Q+C`V-R==(#T@)T=R;W-S971O)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T,BXY,#`Z,3$N-S8W)UT@/2`G4F%D:6-O9F%N
M:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#,N,#@S.C$R+C4P,"==(#T@
M)U!E<G5G:6$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0S+C0P,#HQ,"XX
M-C<G72`]("=6;VQT97)R82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#,N
M-#8W.C$Q+C@U,"==(#T@)T%R97IZ;R<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG-#,N-3$W.C$R+C<S,R==(#T@)T9R;VYT;VYE)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<T,RXV,3<Z,3,N,S8W)UT@/2`G1F%L8V]N87)A)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXV.#,Z,3`N,S@S)UT@/2`G4&ES82`O
M(%,N($=I=7-T;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#,N.#`P.C$Q
M+C(P,"==(#T@)T9I<F5N>F4@+R!097)E=&]L82<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#,N.34P.C@N,38W)UT@/2`G0V%P;R!-96QE)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T-"XP,S,Z,3(N-C$W)UT@/2`G4FEM:6YI)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XP,S,Z.2XX,S,G72`]("=)<V]L
M82!$:2!086QM87)I82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N,#4P
M.C@N,3$W)UT@/2`G06QB96YG82<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#0N,#@S.CDN.3@S)UT@/2`G4V%R>F%N82`O($QU;FDG.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0T+C(P,#HQ,"XW,#`G72`]("=-;VYT92!#:6UO;F4G
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C(P,#HQ,BXP-C<G72`]("=&
M;W)L:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N,C$W.C$R+C,P,"==
M(#T@)T-E<G9I82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N,C4P.C<N
M.#`P)UT@/2`G36]N=&4@36%L86YO='1E)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T-"XT,3<Z."XX-3`G72`]("='96YO=F$@+R!397-T<FDG.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S0T+C0S,SHY+CDS,R==(#T@)U!A<W-O($1E
M;&QA($-I<V$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C0U,#HQ,BXS
M,#`G72`]("=0=6YT82!-87)I;F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S0T+C4S,SHQ,2XS,#`G72`]("=";VQO9VYA("\@0F]R9V\@4&%N:6=A;&4G
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C8S,SHX+CDS,R==(#T@)U!A
M<W-O($1E:2!':6]V:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N.#,S
M.C$Q+C8Q-R==(#T@)T9E<G)A<F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S0T+CDQ-SHY+C<S,R==(#T@)U!I86-E;GIA)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T-2XP,S,Z-RXW,S,G72`]("=4;W)I;F\@+R!"<FEC($1E;&QA
M($-R;V-E)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XR,3<Z-RXV-3`G
M72`]("=4;W)I;F\@+R!#87-E;&QE)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T-2XS.#,Z,3`N.#8W)UT@/2`G5F5R;VYA("\@5FEL;&%F<F%N8V$G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C0Q-SHQ,"XR.#,G72`]("="<F5S
M8VEA("\@1VAE9&DG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C0S,SHY
M+C(X,R==(#T@)TUI;&%N;R`O($QI;F%T92<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#4N-3`P.C$R+C,S,R==(#T@)U9E;F5Z:6$@+R!497-S97)A)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XU,3<Z."XV-C<G72`]("=.;W9A
M<F$@+R!#86UE<FDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C4V-SHQ
M,2XU,3<G72`]("=6:6-E;GIA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M-2XV,3<Z."XW,S,G72`]("=-:6QA;F\@+R!-86QP96YS82<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#4N-C4P.C$R+C$X,R==(#T@)U1R979I<V\@+R!3
M+B!!;F=E;&\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C8U,#HQ,RXW
M-3`G72`]("=4<FEE<W1E)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XV
M-C<Z.2XW,#`G72`]("="97)G86UO("\@3W)I;R!!;"!397)I;R<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#4N-C@S.C$R+C$P,"==(#T@)U1R979I<V\@
M+R!)<W1R86YA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XX,3<Z,3,N
M-#@S)UT@/2`G4F]N8VAI($1E:2!,96=I;VYA<FDG.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0U+C@V-SHY+C`V-R==(#T@)TUO;G1E($)I<V)I;F\G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+CDS,SHW+C<P,"==(#T@)U!I86X@
M4F]S82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N.3@S.C$S+C`S,R==
M(#T@)U5D:6YE("\@4FEV;VQT;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#8N,#,S.C$R+C8P,"==(#T@)T%V:6%N;R<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#8N,#,S.C$R+C8Q-R==(#T@)T%V:6%N;R!5<V%F)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T-BXP,S,Z,3,N,3@S)UT@/2`G561I;F4@+R!#
M86UP;V9O<FUI9&\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0V+C$U,#HQ
M,2XP,S,G72`]("=086=A;F5L;&$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S0V+C,P,#HQ,2XW.#,G72`]("=087-S;R!2;VQL92<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#8N-#8W.C$Q+C,S,R==(#T@)T)O;'IA;F\G.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S0V+C4P,#HQ,RXU.#,G72`]("=487)V:7-I
M;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#8N-S,S.C$R+C(Q-R==(#T@
M)T1O8F)I86-O)SL*)&-O;W)D:6YA=&5S6R=*86UA:6-A)UU;)S$W+CDS,SHM
M-S8N-S@S)UT@/2`G2VEN9W-T;VX@+R!.;W)M86X@36%N;&5Y)SL*)&-O;W)D
M:6YA=&5S6R=*86UA:6-A)UU;)S$X+C4P,#HM-S<N.3$W)UT@/2`G36]N=&5G
M;R!"87D@+R!386YG<W1E<B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C0N
M,S`P.C$U,RXY-C<G72`]("=-:6YA;6ET;W)I<VAI;6$G.PHD8V]O<F1I;F%T
M97-;)TIA<&%N)UU;)S(T+C,S,SHQ,C0N,38W)UT@/2`G27-H:6=A:VEJ:6UA
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-"XT-C<Z,3(R+CDX,R==(#T@
M)UEO;F%G=6YI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(T
M+C<X,SHQ,C4N,C@S)UT@/2`G36EY86MO:FEM82<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,C0N-S@S.C$T,2XS,3<G72`]("=)=V]J:6UA)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<R-2XX,S,Z,3,Q+C(S,R==(#T@)TUI;F%M:61A
M:71O:FEM82<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C8N,3@S.C$R-RXV
M-3`G72`]("=.86AA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S(V+C(V-SHQ,C<N-S4P)UT@/2`G1G5T96YM82!-87)I;F4@0V]R<',@06ER
M($9A8VEL:71Y)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-BXS,#`Z,3(W
M+C<V-R==(#T@)TAA;6)Y(%4N(%,N($%R;7D@06ER9FEE;&0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S(V+C,S,SHQ,C8N.#`P)UT@/2`G2W5M96II;6$G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(V+C,U,#HQ,C<N-S8W)UT@/2`G
M2V%D96YA($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-BXW,3<Z,3(W
M+C<X,R==(#T@)TEE:FEM82!!=7AI;&EA<GD@06(G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S(W+C`X,SHQ-#(N,3@S)UT@/2`G0VAI8VAI:FEM82<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,C<N-#,S.C$R."XW,#`G72`]("=/:VEN
M;V5R86)U)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-RXX,S,Z,3(X+C@X
M,R==(#T@)U1O:W5N;W-H:6UA($ES;&%N9"<["B1C;V]R9&EN871E<ULG2F%P
M86XG75LG,C@N-#,S.C$R.2XW,3<G72`]("=!;6%M:2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<S,"XS.#,Z,3,P+C8V-R==(#T@)UEA:W5S
M:&EM82<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S`N-34P.C$S,"XY-3`G
M72`]("=486YE9V%S:&EM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S,2XS-C<Z,3,P+C@S,R==(#T@)TMA;F]Y82!!8B<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S$N.#`P.C$S,"XW,3<G72`]("=+86=O<VAI;6$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S$N.#8W.C$S,2XT
M-3`G72`]("=-:7EA>F%K:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S,BXP.#,Z,3,Q+C0U,"==(#T@)TYY=71A8F%R=2!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S(N-C8W.C$R."XX,S,G72`]("=&=6MU92!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,BXX,S,Z,3,P+C@U
M,"==(#T@)TMU;6%M;W1O($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S,R+CDQ-SHQ,CDN.3$W)UT@/2`G3F%G87-A:VD@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S,N,3$W.C$S.2XW.#,G72`]("=(86-H
M:6IO:FEM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,RXQ
M-3`Z,3(Y+C<Q-R==(#T@)U-A<V5B;R!5<VXG.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S,S+C,Q-SHQ,S`N-#$W)UT@/2`G365T86)A<G4@06(G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,S+C0X,SHQ,S$N-S,S)UT@/2`G3VET82!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,RXU,S,Z,3,S+C8V
M-R==(#T@)TMO8VAI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S,S+C4X,SHQ,S`N-#4P)UT@/2`G1G5K=6]K82!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S,RXV-C<Z,3,U+C,U,"==(#T@)TYA;FMI<VAI
M<F%H86UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C8X
M,SHQ,S$N,#4P)UT@/2`G5'-U:6MI($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S,RXW-3`Z,3(Y+C<X,R==(#T@)TEK:2!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S,RXX,3<Z,3,R+C<P,"==(#T@)TUA='-U>6%M
M82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,RXX,S,Z,3,P
M+CDU,"==(#T@)TMI=&%K>75S:'4@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,S,N.#@S.C$S,"XV-3`G72`]("=!<VAI>6$@06(G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,S+CDS,SHQ,S$N,C@S)UT@/2`G66%M86=U
M8VAI(%5B92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XP
M,#`Z,3,T+C8S,R==(#T@)TMO;6%T<W5J:6UA($%B)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<S-"XP,S,Z,3,Q+C4U,"==(#T@)TAO9G4@06(G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,T+C`U,#HQ,S$N,#4P)UT@/2`G3WIU:VD@
M06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C`V-SHQ,SDN-38W)UT@
M/2`G36EY86ME:FEM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S-"XQ,S,Z,3,R+C(S,R==(#T@)TEW86MU;FD@36%R:6YE($-O<G!S($%I
M<B!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XQ,S,Z,3,T
M+C8Q-R==(#T@)U1O:W5S:&EM82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S0N,C$W.C$S-"XP,3<G72`]("=486MA;6%T<W4@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S0N,C@S.C$R.2XS,S,G72`]("=4<W5S
M:&EM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XT,3<Z
M,3,U+C(U,"==(#T@)TMA;G-A:2!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C0S,SHQ,S(N.3$W)UT@/2`G2&ER
M;W-H:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C4S
M,SHQ,S8N-C@S)UT@/2`G06ME;F\@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S,T+C8P,#HQ,S4N-C`P)UT@/2`G66%O($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,T+C8V-SHQ,S$N.#`P)UT@/2`G27=A;6D@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N-S4P.C$S,RXX-3`G
M72`]("=/:V%Y86UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S,T+C<U,#HQ,S<N-S`P)UT@/2`G2&%M86UA='-U($%B)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<S-"XW.#,Z,3,U+C0U,"==(#T@)T]S86MA($EN=&5R
M;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N
M-S@S.C$S.2XS-C<G72`]("=/<VAI;6$@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S0N.#$W.C$S."XS,#`G72`]("=3:&EZ=6AA;6$@06(G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+CDX,SHQ,SDN.#,S)UT@/2`G
M5&%T97EA;6$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C(U,#HQ
M,S8N.3,S)UT@/2`G3F%G;WEA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S,U+C(X,SHQ,SDN-C8W)UT@/2`G66]K;W-U:V$@1G=F)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<S-2XS,3<Z,3,X+C@V-R==(#T@)T9U:FD@
M06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C,X,SHQ,S8N.#8W)UT@
M/2`G1VEF=2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N-#`P.C$S
M.2XY,3<G72`]("=+:7-A<F%Z=2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S4N-#$W.C$S,BXY,#`G72`]("=)>G5M;R!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S-2XT-3`Z,3,Y+C0U,"==(#T@)T%T<W5G:2!5
M;FET960@4W1A=&5S($YA=F%L($%I<B!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<S-2XT.#,Z,3,S+C(U,"==(#T@)TUI:&\@06(G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,U+C4Q-SHQ,SDN-#`P)UT@/2`G6F%M82!!
M:7)F:65L9"<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N-3,S.C$S-"XQ
M-C<G72`]("=4;W1T;W)I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S,U+C4U,#HQ,SDN-S@S)UT@/2`G5&]K>6\@26YT97)N871I;VYA;"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XV,S,Z,3,Y+C@U
M,"==(#T@)U1O:WEO($AE;&EP;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S-2XV-C<Z,3,Y+C4S,R==(#T@)T-H;V9U($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,U+C8X,SHQ,SDN-S8W)UT@/2`G5&]K>6\G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C<P,#HQ,SDN-#`P)UT@/2`G5&%C
M:&EK87=A($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XW-3`Z,3,Y
M+C,U,"==(#T@)UEO:V]T82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S4N-S8W.C$T,"XS.#,G72`]("=.97<@5&]K>6\@26YT97(M3F%T:6]N86P@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N.#`P.C$T,"XP
M,3<G72`]("=3:&EM;V9U<V$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S,U+C@S,SHQ,SDN-#$W)UT@/2`G27)U;6$@06(G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,V+C`S,SHQ-#`N,C`P)UT@/2`G2V%S=6UI9V%U<F$@06(G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,V+C$S,SHQ,S8N,C,S)UT@/2`G
M1G5K=6D@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S8N,38W
M.C$S-RXY,S,G72`]("=-871S=6UO=&\@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S8N,3@S.C$S,RXS,S,G72`]("=/:VD@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,S8N,3@S.C$T,"XT,3<G72`]("=(
M>6%K=7)I($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-BXS.#,Z,3,V
M+C0Q-R==(#T@)TMO;6%T<W4@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S,V+C4Q-SHQ,SDN.#8W)UT@/2`G571S=6YO;6EY82!!8B<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S8N-C4P.C$S-RXQ.#,G72`]("=4;WEA;6$@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S<N,C,S.C$T,"XT,S,G
M72`]("=&=6MU<VAI;6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S<N.34P.C$S.2XQ,3<G72`]("=.:6EG871A($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,X+C`U,#HQ,S@N-#$W)UT@/2`G4V%D;R!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S."XQ,S,Z,30P+CDQ
M-R==(#T@)U-E;F1A:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S."XR,S,Z,30P+CDQ-R==(#T@)TMA<W5M:6YO;64@06(G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,X+C0P,#HQ-#$N,C$W)UT@/2`G36%T<W5S:&EM
M82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S@N-#$W.C$T,"XS-C<G
M72`]("=986UA9V%T82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S.2XT,S,Z,30Q+C$S,R==(#T@)TAA;F%M86MI($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,Y+C8Q-SHQ-#`N,C$W)UT@/2`G06MI=&$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#`N-34P.C$T,2XT
M-C<G72`]("=(86-H:6YO:&4@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S0P+C<P,#HQ-#$N,S@S)UT@/2`G36ES87=A($%B)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<T,"XW,S,Z,30P+C<P,"==(#T@)T%O;6]R:2!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,2XR,S,Z,30Q+C$S,R==(#T@
M)T]M:6YA=&\@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0Q+C<V-SHQ
M-#`N.#$W)UT@/2`G2&%K;V1A=&4@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG-#(N,S$W.C$T,"XY.#,G72`]("=-=7)O<F%N)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<T,BXW,S,Z,30S+C(Q-R==(#T@)T]B:6AI<F\@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#(N.#`P.C$T,2XV
M-C<G72`]("=#:&ET;W-E($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T
M,BXX,3<Z,30Q+C8X,R==(#T@)T-H:71O<V4@2F%P86YE<V4@06ER(%-E;&8@
M1&5F96YS92!&;W)C92<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#(N.3@S
M.C$T-"XT,#`G72`]("=+=7-H:7)O)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<T,RXP,S,Z,30T+C(P,"==(#T@)TMU<VAI<F\@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG-#,N,3$W.C$T,2XS.#,G72`]("=387!P;W)O
M($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,RXU-C<Z,30T+CDV-R==
M(#T@)TYA:V%S:&EB971S=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<T,RXV-C<Z,30R+C0U,"==(#T@)T%S86AI:V%W82!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,RXX,#`Z,30R+C,V-R==(#T@)T%S
M86AI:V%W82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#,N.#@S.C$T
M-"XQ-C<G72`]("=-96UA;6)E='-U($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S0T+C(U,#HQ-#,N-3,S)UT@/2`G36]M8F5T<W4@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#4N-#`P.C$T,2XX,#`G72`]
M("=786MK86YA:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG
M,CDN-C,S.C,U+C`Q-R==(#T@)T%Q86)A($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)TIO<F1A;B==6R<S,"XQ-C<Z,S4N-S@S)UT@/2`G36%<)T%N)SL*)&-O
M;W)D:6YA=&5S6R=*;W)D86XG75LG,S$N-C8W.C,U+CDV-R==(#T@)U%U965N
M($%L:6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F]R9&%N)UU;)S,Q+CDX
M,SHS-2XY.#,G72`]("=!;6UA;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*
M;W)D86XG75LG,S(N,C`P.C,W+C$S,R==(#T@)T@M-5PG4V%F87=I)SL*)&-O
M;W)D:6YA=&5S6R=*;W)D86XG75LG,S(N,S8W.C,V+C(U,"==(#T@)TUA9G)A
M<2<["B1C;V]R9&EN871E<ULG2F]R9&%N)UU;)S,R+C4P,#HS."XR,#`G72`]
M("=(+31<)TER=V%I<VAE9"<["B1C;V]R9&EN871E<ULG2F]R9&%N)UU;)S,R
M+C4U,#HS-2XX-3`G72`]("=)<F)I9"<["B1C;V]R9&EN871E<ULG2V%Z86MH
M<W1A;B==6R<T,BXS,3<Z-CDN-S`P)UT@/2`G4VAY;6ME;G0G.PHD8V]O<F1I
M;F%T97-;)TMA>F%K:'-T86XG75LG-#,N,C,S.C<V+CDS,R==(#T@)T%L;6%T
M>2<["B1C;V]R9&EN871E<ULG2V%Z86MH<W1A;B==6R<T-"XX-3`Z-C4N-3`P
M)UT@/2`G2WIY;"U/<F1A)SL*)&-O;W)D:6YA=&5S6R=+87IA:VAS=&%N)UU;
M)S0V+C<X,SHV,2XV-3`G72`]("=!<F%L<VMO92!-;W)E)SL*)&-O;W)D:6YA
M=&5S6R=+87IA:VAS=&%N)UU;)S4P+C(X,SHU-RXQ-3`G72`]("=!:W1J=6)I
M;G-K)SL*)&-O;W)D:6YA=&5S6R=+87IA:VAS=&%N)UU;)S4Q+C(U,#HU,2XR
M.#,G72`]("=5<F%L<VLG.PHD8V]O<F1I;F%T97-;)TMA>F%K<W1A;B==6R<T
M.2XX,#`Z-S,N,34P)UT@/2`G2V%R86=A;F1A)SL*)&-O;W)D:6YA=&5S6R=+
M96YY82==6R<P+C`X,SHS-RXV-3`G72`]("=-97)U)SL*)&-O;W)D:6YA=&5S
M6R=+96YY82==6R<M,"XQ,#`Z,S0N-S4P)UT@/2`G2VES=6UU)SL*)&-O;W)D
M:6YA=&5S6R=+96YY82==6R<M,"XR-C<Z,S8N,3`P)UT@/2`G3F%K=7)U)SL*
M)&-O;W)D:6YA=&5S6R=+96YY82==6R<P+C(X,SHS-"XW.#,G72`]("=+86MA
M;65G82<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3`N,S8W.C,U+C,U,"==
M(#T@)TME<FEC:&\G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTP+C0V-SHS
M.2XV,S,G72`]("='87)I<W-A)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M
M,"XU,#`Z,S8N.38W)UT@/2`G3GEE<FDG.PHD8V]O<F1I;F%T97-;)TME;GEA
M)UU;)RTP+C4P,#HS-RXT-3`G72`]("=%;6)U)SL*)&-O;W)D:6YA=&5S6R=+
M96YY82==6R<P+C4S,SHS-2XR.#,G72`]("=%;&1O<F5T)SL*)&-O;W)D:6YA
M=&5S6R=+96YY82==6R<M,"XV-C<Z,S0N-S@S)UT@/2`G2VES:6DG.PHD8V]O
M<F1I;F%T97-;)TME;GEA)UU;)S$N,#$W.C,U+C`P,"==(#T@)TMI=&%L92<[
M"B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3$N,3,S.C,U+C@S,R==(#T@)TYA
M<F]K)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,2XS,#`Z,S8N-S4P)UT@
M/2`G3F%I<F]B:2`O($1A9V]R971T:2<["B1C;V]R9&EN871E<ULG2V5N>6$G
M75LG+3$N,S$W.C,V+C@Q-R==(#T@)TYA:7)O8FD@+R!7:6QS;VXG.PHD8V]O
M<F1I;F%T97-;)TME;GEA)UU;)RTQ+C,Q-SHS-BXY,S,G72`]("=.86ER;V)I
M($%#0R]&24,O4D-#+TU%5"]#3TTO)SL*)&-O;W)D:6YA=&5S6R=+96YY82==
M6R<Q+C<U,#HT,"XP-C<G72`]("=786II<B<["B1C;V]R9&EN871E<ULG2V5N
M>6$G75LG+3(N,C8W.C0P+C@S,R==(#T@)TQA;74G.PHD8V]O<F1I;F%T97-;
M)TME;GEA)UU;)RTR+C(X,SHS-RXX,S,G72`]("=-86MI;F1U)SL*)&-O;W)D
M:6YA=&5S6R=+96YY82==6R<R+C,P,#HS-RXY,#`G72`]("=-87)S86)I="<[
M"B1C;V]R9&EN871E<ULG2V5N>6$G75LG,RXQ,3<Z,S4N-C$W)UT@/2`G3&]D
M=V%R)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,RXR,S,Z-#`N,3`P)UT@
M/2`G36%L:6YD:2<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3,N-#`P.C,X
M+C4V-R==(#T@)U9O:2<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG,RXU,S,Z
M,SDN,#4P)UT@/2`G36]Y86QE)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<S
M+CDS,SHT,2XX-C<G72`]("=-86YD97)A)SL*)&-O;W)D:6YA=&5S6R=+96YY
M82==6R<M-"XP,S,Z,SDN-C$W)UT@/2`G36]M8F%S82<["B1C;V]R9&EN871E
M<ULG2VER:6)A=&DG75LG,2XS-3`Z,3<R+CDQ-R==(#T@)U1A<F%W82<["B1C
M;V]R9&EN871E<ULG2VER:6)A=&DG75LG+3$N,S4P.C$W-BXP,#`G72`]("="
M97)U)SL*)&-O;W)D:6YA=&5S6R=+:7)I8F%T:2==6R<M,BXV-C<Z,3<V+C@S
M,R==(#T@)T%R;W)A92<["B1C;V]R9&EN871E<ULG2VER:6)A=&DG75LG,RXP
M,S,Z,3<R+C<X,R==(#T@)T)U=&%R:71A<FDG.PHD8V]O<F1I;F%T97-;)TMO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L95PG<R!297!U8FQI8R!O9B==6R<S.2XP
M,S,Z,3(U+C<X,R==(#T@)U!Y;VYG>6%N9R<["B1C;V]R9&EN871E<ULG2V]R
M96$L($1E;6]C<F%T:6,@4&5O<&QE7"=S(%)E<'5B;&EC(&]F)UU;)S0P+C8V
M-SHQ,CDN,C`P)UT@/2`G2VEM8VAA96LG.PHD8V]O<F1I;F%T97-;)TMO<F5A
M+"!297!U8FQI8R!O9B==6R<S,RXR,#`Z,3(V+C(V-R==(#T@)TUO<W5L<&\@
M06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S,RXU
M,#`Z,3(V+C4P,"==(#T@)T-H96IU($EN=&5R;F%T:6]N86P@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,T+C@S,SHQ
M,C<N-C$W)UT@/2`G66]S=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=+;W)E
M82P@4F5P=6)L:6,@;V8G75LG,S4N,#@S.C$R."XP.#,G72`]("=386-H7"=/
M;B!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,U
M+C$Q-SHQ,C8N.#$W)UT@/2`G2W=A;F=J=2!!8B<["B1C;V]R9&EN871E<ULG
M2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,U+C$X,SHQ,C@N.3,S)UT@/2`G4'5S
M86X@+R!+:6UH864@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N-34P.C$R.2XS,3<G72`]
M("=5;'-A;B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;
M)S,U+C@X,SHQ,C@N-C$W)UT@/2`G5&%E9W4G.PHD8V]O<F1I;F%T97-;)TMO
M<F5A+"!297!U8FQI8R!O9B==6R<S-2XY,#`Z,3(X+C8U,"==(#T@)U1A96=U
M($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N
M.3$W.C$R-BXV,3<G72`]("=+=6YS86X@06(G.PHD8V]O<F1I;F%T97-;)TMO
M<F5A+"!297!U8FQI8R!O9B==6R<S-2XY.#,Z,3(Y+C0Q-R==(#T@)U!O:&%N
M9R!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,V
M+C,P,#HQ,C<N-#`P)UT@/2`G5&%E:F]N)SL*)&-O;W)D:6YA=&5S6R=+;W)E
M82P@4F5P=6)L:6,@;V8G75LG,S8N,S,S.C$R-RXS.#,G72`]("=4865J;VX@
M2V]R+4%F8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;
M)S,V+C0P,#HQ,C<N-3`P)UT@/2`G4V]N9VUU($%B)SL*)&-O;W)D:6YA=&5S
M6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N-34P.C$R."XW,3<G72`]("=!
M;F1O;F<G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S
M-BXV,S,Z,3(X+C,U,"==(#T@)UEE8VAO;B!!8B<["B1C;V]R9&EN871E<ULG
M2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,V+C<P,#HQ,C<N-3`P)UT@/2`G0VAO
M;F=J=2!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;
M)S,V+CDS,SHQ,C8N-#4P)UT@/2`G36%N9VEL<V%N($%B)SL*)&-O;W)D:6YA
M=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N.3,S.C$R-RXP,#`G72`]
M("=0>6]N9W1A96L@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI
M8R!O9B==6R<S-RXP,S,Z,3(V+C<U,"==(#T@)TMO;VXM3FD@4F%N9V4G.PHD
M8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXP,S,Z,3(W
M+C@X,R==(#T@)TIU;F<@5V]N(%)O:RU!8B<["B1C;V]R9&EN871E<ULG2V]R
M96$L(%)E<'5B;&EC(&]F)UU;)S,W+C$P,#HQ,C<N,#,S)UT@/2`G3W-A;B!!
M8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C(U
M,#HQ,C<N,#`P)UT@/2`G4W5W;VX@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A
M+"!297!U8FQI8R!O9B==6R<S-RXS,S,Z,3(W+CDU,"==(#T@)U=O;FIU)SL*
M)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-#,S.C$R
M-RXQ,3<G72`]("=396]U;"!%($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@
M4F5P=6)L:6,@;V8G75LG,S<N-#,S.C$R-RXY-3`G72`]("=(;V5N9W-O;F<@
M06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXT
M-C<Z,3(V+C0U,"==(#T@)TEN8VAE;VX@26YT97)N871I;VYA;"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-3`P
M.C$R-BXY,S,G72`]("=396]U;"`O(%EO;F=D=6YG<%PG3R!2;VMA9B!78R<[
M"B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C4P,#HQ
M,CDN,3,S)UT@/2`G5&]N9VAA92!2861A<B!3:71E)SL*)&-O;W)D:6YA=&5S
M6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-34P.C$R-BXX,#`G72`]("=3
M96]U;"`O($MI;7!<)T\@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-38W.C$R-BXY-C<G
M72`]("=396]U;"<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F
M)UU;)S,W+C<U,#HQ,C@N.34P)UT@/2`G2V%N9VYU;F<@06(G.PHD8V]O<F1I
M;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXX-C<Z,3(W+C<Q-R==
M(#T@)T-H=6YC:&]N($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L
M:6,@;V8G75LG,S<N.38W.C$R-"XV-C<G72`]("=0865N9VYY;VYG9&\@06(G
M.PHD8V]O<F1I;F%T97-;)TMU=V%I="==6R<R.2XR,3<Z-#<N.3@S)UT@/2`G
M2W5W86ET($EN=&5R;F%T:6]N86QA:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=,
M86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P=6)L:6,G75LG,30N.#`P.C$P
M-BXX,S,G72`]("=!='1O<&5U)SL*)&-O;W)D:6YA=&5S6R=,86\@4&5O<&QE
M7"=S($1E;6]C<F%T:6,@4F5P=6)L:6,G75LG,34N,3$W.C$P-2XQ-C<G72`]
M("=086MS92<["B1C;V]R9&EN871E<ULG3&%O(%!E;W!L95PG<R!$96UO8W)A
M=&EC(%)E<'5B;&EC)UU;)S$U+C8X,SHQ,#8N-#,S)UT@/2`G4V%R879A;F4G
M.PHD8V]O<F1I;F%T97-;)TQA;R!096]P;&5<)W,@1&5M;V-R871I8R!297!U
M8FQI8R==6R<Q-BXU-3`Z,3`T+C8U,"==(#T@)U-A=F%N;F%K:&5T)SL*)&-O
M;W)D:6YA=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P=6)L:6,G
M75LG,3<N,S@S.C$P-"XV-3`G72`]("=4:&%K:&5K)SL*)&-O;W)D:6YA=&5S
M6R=,86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P=6)L:6,G75LG,3<N.34P
M.C$P,BXU-C<G72`]("=6:65N=&EA;F4G.PHD8V]O<F1I;F%T97-;)TQA;R!0
M96]P;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==6R<Q.2XR,S,Z,3`Q+C<S
M,R==(#T@)U-A>6%B;W5R>2<["B1C;V]R9&EN871E<ULG3&%O(%!E;W!L95PG
M<R!$96UO8W)A=&EC(%)E<'5B;&EC)UU;)S$Y+C@X,SHQ,#(N,3,S)UT@/2`G
M3'5A;F<M4')A8F%N9R<["B1C;V]R9&EN871E<ULG3&%T=FEA)UU;)S4V+CDV
M-SHR-"XP-3`G72`]("=2:6=A)SL*)&-O;W)D:6YA=&5S6R=,871V:6$G75LG
M-3<N-#`P.C(Q+C4S,R==(#T@)U9E;G1S<&EL<R<["B1C;V]R9&EN871E<ULG
M3&5B86YO;B==6R<S,RXX,3<Z,S4N-#@S)UT@/2`G0F5Y<F]U=&@@065R;W!O
M<G0G.PHD8V]O<F1I;F%T97-;)TQE<V]T:&\G75LG+3(Y+C0U,#HR-RXU-3`G
M72`]("=-87-E<G4M36EA)SL*)&-O;W)D:6YA=&5S6R=,:6)E<FEA)UU;)S8N
M,C4P.BTQ,"XS-3`G72`]("='<F%N9"!"87-S82P@4F]B97)T<R!&:65L9"<[
M"B1C;V]R9&EN871E<ULG3&EB>6%N($%R86(@2F%M86AI<FEY82==6R<R-"XR
M,3<Z,C,N,S`P)UT@/2`G2W5F<F$G.PHD8V]O<F1I;F%T97-;)TQI8GEA;B!!
M<F%B($IA;6%H:7)I>6$G75LG,C4N,3,S.C$P+C$U,"==(#T@)T=H870G.PHD
M8V]O<F1I;F%T97-;)TQI8GEA;B!!<F%B($IA;6%H:7)I>6$G75LG,C<N,#$W
M.C$T+C0U,"==(#T@)U-E8FAA)SL*)&-O;W)D:6YA=&5S6R=,:6)Y86X@07)A
M8B!*86UA:&ER:7EA)UU;)S,P+C$S,SHY+C4P,"==(#T@)T=H861A;65S)SL*
M)&-O;W)D:6YA=&5S6R=,:6)Y86X@07)A8B!*86UA:&ER:7EA)UU;)S,R+C$P
M,#HR,"XR-C<G72`]("="96YI;F$G.PHD8V]O<F1I;F%T97-;)TQI8GEA;B!!
M<F%B($IA;6%H:7)I>6$G75LG,S(N-C8W.C$S+C$U,"==(#T@)U1R:7!O;&D@
M26YT97(M3F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG3&ET:'5A
M;FEA)UU;)S4T+C8S,SHR-2XQ,#`G72`]("=6:6QN:75S)SL*)&-O;W)D:6YA
M=&5S6R=,=7AE;6)O=7)G)UU;)S0Y+C8Q-SHV+C(Q-R==(#T@)TQU>&5M8F]U
M<F<@+R!,=7AE;6)O=7)G)SL*)&-O;W)D:6YA=&5S6R=-86-A=2==6R<R,BXQ
M-C<Z,3$S+C4V-R==(#T@)U1A:7!A)SL*)&-O;W)D:6YA=&5S6R=-86-E9&]N
M:6$L('1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8G75LG-#$N,3$W
M.C(P+C@P,"==(#T@)T]H<FED)SL*)&-O;W)D:6YA=&5S6R=-86-E9&]N:6$L
M('1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8G75LG-#$N.38W.C(Q
M+C8U,"==(#T@)U-K;W!J92U0971R;W9E8R<["B1C;V]R9&EN871E<ULG36%D
M86=A<V-A<B==6R<M,3(N,S4P.C0Y+C,P,"==(#T@)T1I96=O+5-U87)E>B<[
M"B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,3,N,S$W.C0X+C,Q-R==
M(#T@)T9A<V-E;F4@3F]S<VDM0F4G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C
M87(G75LG+3$S+C,V-SHU,"XP,#`G72`]("=6;VAE;6%R)SL*)&-O;W)D:6YA
M=&5S6R=-861A9V%S8V%R)UU;)RTQ-"XR.#,Z-3`N,38W)UT@/2`G4V%M8F%V
M82<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,30N-C,S.C0W+C<V
M-R==(#T@)T%N86QA;&%V82<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==
M6R<M,30N-C4P.C0Y+C8Q-R==(#T@)T%N9&%P82<["B1C;V]R9&EN871E<ULG
M36%D86=A<V-A<B==6R<M,30N.#@S.C4P+C(U,"==(#T@)T%N=&%L86AA)SL*
M)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-2XV-C<Z-#8N,S4P)UT@
M/2`G36%J=6YG82<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,38N
M-S4P.C0T+C0X,R==(#T@)T)E<V%L86UP>2<["B1C;V]R9&EN871E<ULG36%D
M86=A<V-A<B==6R<M,3<N,#@S.C0Y+C@Q-R==(#T@)U-A:6YT92U-87)I92!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3$X+C`U
M,#HT-"XP,S,G72`]("=-86EN=&ER86YO)SL*)&-O;W)D:6YA=&5S6R=-861A
M9V%S8V%R)UU;)RTQ."XQ,3<Z-#DN-#`P)UT@/2`G5&%M871A=F4G.PHD8V]O
M<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3$X+C@P,#HT-RXT.#,G72`]("=!
M;G1A;F%N87)I=F\@+R!)=F%T;R<["B1C;V]R9&EN871E<ULG36%D86=A<V-A
M<B==6R<M,3DN.#$W.C0W+C`V-R==(#T@)T%N='-I<F%B92<["B1C;V]R9&EN
M871E<ULG36%D86=A<V-A<B==6R<M,3DN.#,S.C0X+C@P,"==(#T@)TUA:&%N
M;W)O)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTR,"XR.#,Z-#0N
M,S$W)UT@/2`G36]R;VYD879A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R
M)UU;)RTR,2XR,#`Z-#@N,S8W)UT@/2`G36%N86YJ87)Y)SL*)&-O;W)D:6YA
M=&5S6R=-861A9V%S8V%R)UU;)RTR,2XT-3`Z-#<N,3`P)UT@/2`G1FEA;F%R
M86YT<V]A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTR,2XW-3`Z
M-#,N,S8W)UT@/2`G36]R;VUB92<["B1C;V]R9&EN871E<ULG36%D86=A<V-A
M<B==6R<M,C(N-34P.C0U+C0P,"==(#T@)U)A;F]H:7)A)SL*)&-O;W)D:6YA
M=&5S6R=-861A9V%S8V%R)UU;)RTR,BXX,#`Z-#<N.#,S)UT@/2`G1F%R869A
M;F=A;F$G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(S+C,X,SHT
M,RXW,S,G72`]("=4=6QE87(G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G
M75LG+3(U+C`S,SHT-BXY-3`G72`]("=&;W)T+41A=7!H:6XG.PHD8V]O<F1I
M;F%T97-;)TUA;&%W:2==6R<M,3$N-#4P.C,T+C`Q-R==(#T@)TUZ=7IU)SL*
M)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG+3$Q+C@X,SHS,RXV,3<G72`]("=-
M>FEM8F$G.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M,3(N.3$W.C,T+C(V
M-R==(#T@)TYK:&]T82!+;W1A)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG
M+3$S+C<U,#HS-"XU.#,G72`]("=386QI;6$G.PHD8V]O<F1I;F%T97-;)TUA
M;&%W:2==6R<M,3,N-S@S.C,S+C<V-R==(#T@)TQI;&]N9W=E($EN=&5R;F%T
M:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG36%L87=I)UU;)RTQ-"XP
M.#,Z,S0N.3$W)UT@/2`G36]N:V5Y($)A>2<["B1C;V]R9&EN871E<ULG36%L
M87=I)UU;)RTQ-"XS,3<Z,S0N,C8W)UT@/2`G1&5D>F$G.PHD8V]O<F1I;F%T
M97-;)TUA;&%W:2==6R<M,30N-#,S.C,U+C(U,"==(#T@)TUA;F=O8VAI)SL*
M)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG+3$U+C8X,SHS-"XY-C<G72`]("=#
M:&EL96MA)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG+3DN-S`P.C,S+C(V
M-R==(#T@)T-H:71I<&$G.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M.2XY
M-3`Z,S,N.#@S)UT@/2`G2V%R;VYG82<["B1C;V]R9&EN871E<ULG36%L87ES
M:6$G75LG,2XT.#,Z,3$P+C,S,R==(#T@)TMU8VAI;F<G.PHD8V]O<F1I;F%T
M97-;)TUA;&%Y<VEA)UU;)S$N-C,S.C$P,RXV-C<G72`]("=*;VAO<F4@0FAA
M<G4@+R!396YA:2<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG,BXR-C<Z
M,3`R+C(U,"==(#T@)TUA;&%C8V$G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA
M)UU;)S(N,S,S.C$Q,2XX,S,G72`]("=3:6)U)SL*)&-O;W)D:6YA=&5S6R=-
M86QA>7-I82==6R<S+C$Q-SHQ,#$N-34P)UT@/2`G2W5A;&$@3'5M<'5R("\@
M4W5B86YG)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<S+C(P,#HQ,3,N
M,#,S)UT@/2`G0FEN='5L=2<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG
M,RXV,3<Z,3`S+C(Q-R==(#T@)TMU86YT86XG.PHD8V]O<F1I;F%T97-;)TUA
M;&%Y<VEA)UU;)S0N,C$W.C$P,"XW,#`G72`]("=3:71I87=A;B<["B1C;V]R
M9&EN871E<ULG36%L87ES:6$G75LG-"XR-C<Z,3$W+C@X,R==(#T@)U1A=V%U
M)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<T+C,S,SHQ,3,N.3@S)UT@
M/2`G36ER:2<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG-2XS,#`Z,3`P
M+C(V-R==(#T@)U!E;F%N9R`O($)A>6%N($QE<&%S)SL*)&-O;W)D:6YA=&5S
M6R=-86QA>7-I82==6R<U+C,P,#HQ,34N,C4P)UT@/2`G3&%B=6%N)SL*)&-O
M;W)D:6YA=&5S6R=-86QA>7-I82==6R<U+CDP,#HQ,3@N,#8W)UT@/2`G4V%N
M9&%K86XG.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S4N.3,S.C$Q-BXP
M-3`G72`]("=+;W1A($MI;F%B86QU)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I
M82==6R<V+C$V-SHQ,#(N,C@S)UT@/2`G2V]T82!":&%R=2<["B1C;V]R9&EN
M871E<ULG36%L87ES:6$G75LG-BXS,S,Z.3DN-S,S)UT@/2`G3&%N9VMA=VDG
M.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S8N.3$W.C$Q-BXX,S,G72`]
M("=+=61A="<["B1C;V]R9&EN871E<ULG36%L9&EV97,G75LG+3`N-C@S.C<S
M+C$U,"==(#T@)T=A;B<["B1C;V]R9&EN871E<ULG36%L9&EV97,G75LG-"XR
M,#`Z-S,N-3,S)UT@/2`G36%L92<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q
M,2XS-3`Z+34N-C@S)UT@/2`G4VEK87-S;R<["B1C;V]R9&EN871E<ULG36%L
M:2==6R<Q,2XT,3<Z+3<N-3`P)UT@/2`G0F]U9V]U;FDG.PHD8V]O<F1I;F%T
M97-;)TUA;&DG75LG,3(N,S@S.BTU+C0V-R==(#T@)TMO=71I86QA)SL*)&-O
M;W)D:6YA=&5S6R=-86QI)UU;)S$R+C4S,SHM-RXY-3`G72`]("="86UA:V\@
M+R!396YO=2<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q,BXX-3`Z+3$Q+C(S
M,R==(#T@)TME;FEE8F$G.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,3,N,#8W
M.BTY+C0V-R==(#T@)TMI=&$G.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,3,N
M,S,S.BTT+C@S,R==(#T@)U-A;B<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q
M,RXT,#`Z+38N,34P)UT@/2`G4V5G;W4G.PHD8V]O<F1I;F%T97-;)TUA;&DG
M75LG,30N-#,S.BTQ,2XT,S,G72`]("=+87EE<R<["B1C;V]R9&EN871E<ULG
M36%L:2==6R<Q-"XU,3<Z+30N,3`P)UT@/2`G36]P=&DG.PHD8V]O<F1I;F%T
M97-;)TUA;&DG75LG,34N,38W.BTW+C(X,R==(#T@)TYA<F$G.PHD8V]O<F1I
M;F%T97-;)TUA;&DG75LG,34N,C,S.BTY+C,U,"==(#T@)TYI;W)O($1U(%-A
M:&5L)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$U+C,S,SHM,2XV.#,G72`]
M("=(;VUB;W)I)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$U+C@V-SHR+C(Q
M-R==(#T@)TUE;F%K82<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q-BXR-C<Z
M+3`N,#4P)UT@/2`G1V%O)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$V+C<Q
M-SHM,RXP,#`G72`]("=4;VUB;W5C=&]U)SL*)&-O;W)D:6YA=&5S6R=-86QI
M)UU;)S$X+C0S,SHQ+C,U,"==(#T@)TMI9&%L)SL*)&-O;W)D:6YA=&5S6R=-
M86QI)UU;)S(P+C(P,#HP+CDX,R==(#T@)U1E<W-A;&ET)SL*)&-O;W)D:6YA
M=&5S6R=-86QT82==6R<S-2XX-3`Z,30N-#@S)UT@/2`G3'5Q82<["B1C;V]R
M9&EN871E<ULG36%R<VAA;&P@27-L86YD<R==6R<W+C`V-SHQ-S$N,C@S)UT@
M/2`G36%J=7)O($%T;VQL+"!-87)S:&%L;"!)<VQA;F1S($EN="X@06ER<"XG
M.PHD8V]O<F1I;F%T97-;)TUA<G-H86QL($ES;&%N9',G75LG."XW,3<Z,38W
M+C<S,R==(#T@)TMW86IA;&5I;BP@0G5C:&]L>B!!048H2W=A:F%L96EN($M-
M4BDH051/3"D@06ER<"XG.PHD8V]O<F1I;F%T97-;)TUA<G1I;FEQ=64G75LG
M,30N-C`P.BTV,2XP,#`G72`]("=,92!,86UE;G1I;B<["B1C;V]R9&EN871E
M<ULG36%U<FET86YI82==6R<Q-BXQ-3`Z+3$S+C4Q-R==(#T@)TMA961I)SL*
M)&-O;W)D:6YA=&5S6R=-875R:71A;FEA)UU;)S$V+C4P,#HM,34N.#$W)UT@
M/2`G4F]S<V\G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G75LG,38N-C`P
M.BTW+C(V-R==(#T@)TYE;6$G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G
M75LG,38N-C,S.BTQ,2XT,#`G72`]("=+:69F82<["B1C;V]R9&EN871E<ULG
M36%U<FET86YI82==6R<Q-BXW,#`Z+3DN-C`P)UT@/2`G06EO=6X@16P@071R
M;W5S<R<["B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q-RXU,S,Z+3$T
M+C8X,R==(#T@)T)O=71I;&EM:70G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N
M:6$G75LG,3@N,3`P.BTQ-2XY-3`G72`]("=.;W5A:V-H;W1T)SL*)&-O;W)D
M:6YA=&5S6R=-875R:71A;FEA)UU;)S$X+C4V-SHM,3$N-#,S)UT@/2`G5&ED
M:FEK:F$G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G75LG,3DN-S4P.BTQ
M-"XS-C<G72`]("=!:VIO=6IT)SL*)&-O;W)D:6YA=&5S6R=-875R:71A;FEA
M)UU;)S(P+C4Q-SHM,3,N,#8W)UT@/2`G071A<B<["B1C;V]R9&EN871E<ULG
M36%U<FET86YI82==6R<R,"XY,S,Z+3$W+C`S,R==(#T@)TYO=6%D:&EB;W4G
M.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G75LG,C4N,C,S.BTQ,2XV,3<G
M72`]("=":7(@36]G:')E:6XG.PHD8V]O<F1I;F%T97-;)TUA=7)I=&EU<R==
M6R<M,3DN-C@S.C8S+C0Q-R==(#T@)U)O9')I9W5E<R<["B1C;V]R9&EN871E
M<ULG36%U<FET:75S)UU;)RTR,"XT,S,Z-3<N-C8W)UT@/2`G4&QA:7-A;F-E
M($UA=7)I=&EU<R<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S$V+C<U,#HM
M.3,N,3$W)UT@/2`G5'5X=&QA($=U=&EE<G)E>BP@0VAI<RXG.PHD8V]O<F1I
M;F%T97-;)TUE>&EC;R==6R<Q."XT.#,Z+3@X+C,P,"==(#T@)T-H971U;6%L
M+"!1+B!2;V\G.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<Q."XX.#,Z+3DY
M+C(S,R==(#T@)T-U97)N879A8V$L($UO<BXG.PHD8V]O<F1I;F%T97-;)TUE
M>&EC;R==6R<Q.2XP-3`Z+3DX+C$V-R==(#T@)U!U96)L82P@4'5E+B<["B1C
M;V]R9&EN871E<ULG365X:6-O)UU;)S$Y+C(V-SHM,3`S+C4X,R==(#T@)T-O
M;&EM82<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S$Y+C@U,#HM.3`N-34P
M)UT@/2`G0V%M<&5C:&4L($-A;7`N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G
M75LG,C`N,#@S.BTY."XS-C<G72`]("=4=6QA;F-I;F=O)SL*)&-O;W)D:6YA
M=&5S6R=-97AI8V\G75LG,C`N-C`P.BTQ,#`N,S@S)UT@/2`G475E<F5T87)O
M+"!1<F\N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,C`N.3,S.BTX.2XV
M-3`G72`]("=-97)I9&$@+R!L:6,@36%N=65L($-R96-E;F-I;R<["B1C;V]R
M9&EN871E<ULG365X:6-O)UU;)S(Q+C4Q-SHM,3`T+CDP,"==(#T@)U1E<&EC
M+"!.87DN)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,C$N.#@S.BTQ,#(N
M,S`P)UT@/2`G06=U87-C86QI96YT97,L($%G<RXG.PHD8V]O<F1I;F%T97-;
M)TUE>&EC;R==6R<R,BXQ-3`Z+3$P,"XY.#,G72`]("=386X@3'5I<R!0;W1O
M<VDL(%,N($PN(%`N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,C0N.#$W
M.BTQ,#<N-#`P)UT@/2`G0W5L:6%C86XL(%-I;BXG.PHD8V]O<F1I;F%T97-;
M)TUE>&EC;R==6R<R-2XT-3`Z+3$P,"XY.#,G72`]("=386QT:6QL;RP@0V]A
M:"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R-2XU,S,Z+3$P,RXT-3`G
M72`]("=4;W)R96]N+"!#;V%H+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;
M)S(U+C@V-SHM,3`P+C(S,R==(#T@)T%E<F]P+B!);G1E<FYA8VEO;F%L($UO
M;G1E<G)E>2P@3BX@3"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R-BXP
M,3<Z+3$Q,2XS-3`G72`]("=,;W)E=&\L($(N($,N(%,N)SL*)&-O;W)D:6YA
M=&5S6R=-97AI8V\G75LG,C8N.#@S.BTQ,#$N-#$W)UT@/2`G36]N8VQO=F$L
M($-O86@N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,C<N,S$W.BTQ,3(N
M,S`P)UT@/2`G4V%N=&$@4F]S86QI82P@0BX@0RX@4RXG.PHD8V]O<F1I;F%T
M97-;)TUE>&EC;R==6R<R."XW,#`Z+3$P,"XU,3<G72`]("=0:65D<F%S($YE
M9W)A<RP@0V]A:"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R.2XP-C<Z
M+3$Q,"XY-3`G72`]("=(97)M;W-I;&QO+"!3;VXN)SL*)&-O;W)D:6YA=&5S
M6R=-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F)UU;)S4N,S4P.C$V
M,BXY-3`G72`]("=+;W-R864@0V%R;VQI;F5S("\@5B<["B1C;V]R9&EN871E
M<ULG36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B==6R<U+C,U,#HQ
M-C(N.34P)UT@/2`G2V]S<F%E($ES;&%N9"P@2V]S<F%E($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)TUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8G
M75LG-BXY.#,Z,34X+C(P,"==(#T@)U!O:&YP96D@27-L86YD+"!0;VAN<&5I
M($EN="X@06ER<"XG.PHD8V]O<F1I;F%T97-;)TUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8G75LG-RXT-C<Z,34Q+C@U,"==(#T@)U=E;F\@27-L
M86YD+"!#:'5U:R!);G0N($%I<G`N)SL*)&-O;W)D:6YA=&5S6R=-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F)UU;)SDN-#@S.C$S."XP.#,G72`]
M("=987`@27-L86YD+"!987`@26YT+B!!:7)P+B<["B1C;V]R9&EN871E<ULG
M36]L9&]V82P@4F5P=6)L:6,@;V8G75LG-#<N,#$W.C(X+CDX,R==(#T@)TMI
M<VEN978G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,C@N-#4P.BTQ,2XQ
M-3`G72`]("=486XM5&%N)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S(Y
M+C,V-SHM,3`N,3@S)UT@/2`G4VED:2!)9FYI)SL*)&-O;W)D:6YA=&5S6R=-
M;W)O8V-O)UU;)S,P+C,S,SHM.2XT,#`G72`]("=!9V%D:7(@06P@36%S<VER
M82<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S,"XS.#,Z+3DN-38W)UT@
M/2`G06=A9&ER)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,P+CDS,SHM
M-BXY,#`G72`]("=/=6%R>F%Z871E)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O
M)UU;)S,Q+C4Q-SHM.2XW.#,G72`]("=%<W-A;W5I<F$G.PHD8V]O<F1I;F%T
M97-;)TUO<F]C8V\G75LG,S$N-C$W.BTX+C`S,R==(#T@)TUA<G)A:V5C:"<[
M"B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S,2XY,S,Z+30N-#`P)UT@/2`G
M17)R86-H:61I82<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S,BXR.#,Z
M+3DN,C,S)UT@/2`G4V%F:2<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S
M,RXS-C<Z+3<N-3@S)UT@/2`G3F]U87-S975R)SL*)&-O;W)D:6YA=&5S6R=-
M;W)O8V-O)UU;)S,S+C4P,#HM-2XQ-C<G72`]("=)9G)A;F4G.PHD8V]O<F1I
M;F%T97-;)TUO<F]C8V\G75LG,S,N-38W.BTW+C8V-R==(#T@)T-A<V%B;&%N
M8V$G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S,N.#@S.BTU+C4S,R==
M(#T@)TUE:VYE<R<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S,RXY,S,Z
M+30N.3@S)UT@/2`G1F5S+5-A:7,G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G
M75LG,S0N,#4P.BTV+C<V-R==(#T@)U)A8F%T+5-A;&4G.PHD8V]O<F1I;F%T
M97-;)TUO<F]C8V\G75LG,S0N,C$W.BTT+C`P,"==(#T@)U1A>F$G.PHD8V]O
M<F1I;F%T97-;)TUO<F]C8V\G75LG,S0N,S`P.BTV+C8P,"==(#T@)TME;FET
M<F$G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S0N-S@S.BTQ+CDS,R==
M(#T@)T]U:F1A)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,U+C$U,#HM
M,BXY,3<G72`]("=.861O<B<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S
M-2XQ.#,Z+3,N.#4P)UT@/2`G06P@2&]C96EM82<["B1C;V]R9&EN871E<ULG
M36]R;V-C;R==6R<S-2XU.#,Z+34N,S,S)UT@/2`G5&5T=6%N("\@4V%N:6$@
M4F%M96PG.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S4N-S,S.BTU+CDP
M,"==(#T@)U1A;F=E<B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TUO>F%M
M8FEQ=64G75LG+3$Q+C,U,#HT,"XS-C<G72`]("=-;V-I;6)O82!$82!0<F%I
M82<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,3(N.3@S.C0P+C4S
M,R==(#T@)U!E;6)A)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ
M,RXS,#`Z,S4N,C,S)UT@/2`G3&EC:&EN9V$G.PHD8V]O<F1I;F%T97-;)TUO
M>F%M8FEQ=64G75LG+3$T+C@Q-SHS-BXU,S,G72`]("=#=6%M8F$G.PHD8V]O
M<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3$U+C`S,SHT,"XV-C<G72`]("=,
M=6UB;R<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,34N,3`P.C,Y
M+C(X,R==(#T@)TYA;7!U;&$G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G
M75LG+3$V+C$X,SHS,RXU.#,G72`]("=4971E)SL*)&-O;W)D:6YA=&5S6R=-
M;WIA;6)I<75E)UU;)RTQ-RXX.#,Z,S8N.#@S)UT@/2`G475E;&EM86YE)SL*
M)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ.2XQ,3<Z,S,N-#8W)UT@
M/2`G0VAI;6]I;R<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,3DN
M.#`P.C,T+CDP,"==(#T@)T)E:7)A)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I
M<75E)UU;)RTR,BXP,#`Z,S4N,S$W)UT@/2`G5FEL86YC=6QO<R<["B1C;V]R
M9&EN871E<ULG36]Z86UB:7%U92==6R<M,C,N.#8W.C,U+C,X,R==(#T@)TEN
M:&%M8F%N92<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,C4N,#4P
M.C,S+C8S,R==(#T@)UAA:2!886DG.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ
M=64G75LG+3(U+CDQ-SHS,BXU-C<G72`]("=-87!U=&\@+R!-879A;&%N92<[
M"B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q,BXT,S,Z.3@N-C`P)UT@/2`G
M365R9W5I)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$T+C$P,#HY."XR
M,3<G72`]("=$87=E:2<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q-"XQ
M,3<Z.3,N,S8W)UT@/2`G0V]C;R!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)TUY
M86YM87(G75LG,38N-3`P.CDW+C8Q-R==(#T@)TUO=6QM96EN)SL*)&-O;W)D
M:6YA=&5S6R=->6%N;6%R)UU;)S$V+C<U,#HY-RXV-C<G72`]("=(<&$M06XG
M.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,38N-S8W.CDT+C<V-R==(#T@
M)U!A=&AE:6XG.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,38N-S8W.CDV
M+C$V-R==(#T@)UEA;F=O;B<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q
M-BXY,#`Z.38N,3@S)UT@/2`G36EN9V%L861O;B<["B1C;V]R9&EN871E<ULG
M37EA;FUA<B==6R<Q."XT-C<Z.30N,S4P)UT@/2`G4V%N9&]W87DG.PHD8V]O
M<F1I;F%T97-;)TUY86YM87(G75LG,3@N.#`P.CDU+C(Q-R==(#T@)U!R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$Y+C0Q-SHY,RXU-3`G72`]
M("=+>6%U:W!Y=2<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<R,"XQ,S,Z
M.3(N.#@S)UT@/2`G4VET='=E)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;
M)S(P+C@S,SHY-2XX,S,G72`]("=-96EK=&EL82<["B1C;V]R9&EN871E<ULG
M37EA;FUA<B==6R<R,2XS,#`Z.3DN-C$W)UT@/2`G2V5N9W1U;F<G.PHD8V]O
M<F1I;F%T97-;)TUY86YM87(G75LG,C$N.3@S.CDV+C$P,"==(#T@)TUA;F1A
M;&%Y)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S(R+CDS,SHY-RXW-3`G
M72`]("=,87-H:6\G.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,C0N,C8W
M.CDW+C(P,"==(#T@)T)H86UO)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;
M)S(T+C@V-SHY-"XY,3<G72`]("=(;VUA;&EN)SL*)&-O;W)D:6YA=&5S6R=-
M>6%N;6%R)UU;)S(U+C,V-SHY-RXT,#`G72`]("=->6ET:WEI;F$G.PHD8V]O
M<F1I;F%T97-;)TUY86YM87(G75LG,C<N,S,S.CDW+C0Q-R==(#T@)U!U=&%O
M)SL*)&-O;W)D:6YA=&5S6R=.86UI8FEA)UU;)RTQ-RXY,3<Z,3DN-S8W)UT@
M/2`G4G5N9'4G.PHD8V]O<F1I;F%T97-;)TYA;6EB:6$G75LG+3$Y+C8P,#HQ
M."XQ,3<G72`]("='<F]O=&9O;G1E:6XG.PHD8V]O<F1I;F%T97-;)TYA;6EB
M:6$G75LG+3(R+C0V-SHQ."XY-C<G72`]("=';V)A8FES)SL*)&-O;W)D:6YA
M=&5S6R=.86UI8FEA)UU;)RTR,BXT.#,Z,3<N-#8W)UT@/2`G2BX@1RX@4W1R
M:6ID;VTG.PHD8V]O<F1I;F%T97-;)TYA;6EB:6$G75LG+3(V+C4S,SHQ."XQ
M,3<G72`]("=+965T;6%N<VAO;W`G.PHD8V]O<F1I;F%T97-;)TYA=7)U)UU;
M)RTP+C4S,SHQ-C8N.3$W)UT@/2`G3F%U<G4@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG3F5P86PG75LG,C8N-#@S.C@W+C(V-R==(#T@)T)I<F%T;F%G87(@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG3F5P86PG75LG,C<N,38W.C@T+CDX
M,R==(#T@)U-I;7)A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TYE<&%L)UU;
M)S(W+C,U,#HX-RXV-C<G72`]("=487!L96IU;F<G.PHD8V]O<F1I;F%T97-;
M)TYE<&%L)UU;)S(W+C4Q-SHX,RXT-3`G72`]("=":&%I<F%W82!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=.97!A;"==6R<R-RXW,#`Z.#4N,S8W)UT@/2`G
M2V%T:&UA;F1U($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TYE<&%L)UU;)S(X
M+C(Q-SHX-"XP,#`G72`]("=0;VMH87)A($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)TYE<&%L)UU;)S(X+C8P,#HX,2XV,3<G72`]("=3=7)K:&5T)SL*)&-O
M;W)D:6YA=&5S6R=.97!A;"==6R<R.2XR.#,Z.#(N,38W)UT@/2`G2G5M;&$G
M.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S($%N=&EL;&5S)UU;)S$R+C$U
M,#HM-C@N,C@S)UT@/2`G1FQA;6EN9V\@06ER<&]R="P@0F]N86ER92<["B1C
M;V]R9&EN871E<ULG3F5T:&5R;&%N9',@06YT:6QL97,G75LG,3(N,C`P.BTV
M."XY-C<G72`]("=(871O($%I<G!O<G0L($-U<F%C86\G.PHD8V]O<F1I;F%T
M97-;)TYE=&AE<FQA;F1S($%N=&EL;&5S)UU;)S$W+C0X,SHM-C(N.3@S)UT@
M/2`G4F]O<V5V96QT($%I<G!O<G0@4V%I;G0@175S=&%T:75S)SL*)&-O;W)D
M:6YA=&5S6R=.971H97)L86YD<R!!;G1I;&QE<R==6R<Q."XP-3`Z+38S+C$Q
M-R==(#T@)TIU;&EA;F$@06ER<&]R="P@4V%I;G0@36%A<G1E;B<["B1C;V]R
M9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3`N.3$W.C4N-S@S)UT@/2`G36%A
M<W1R:6-H="!!:7)P;W)T(%IU:60@3&EM8G5R9R<["B1C;V]R9&EN871E<ULG
M3F5T:&5R;&%N9',G75LG-3$N-#4P.C0N,S,S)UT@/2`G5V]E;G-D<F5C:'0G
M.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4Q+C0U,#HU+C0Q-R==
M(#T@)T5I;F1H;W9E;B<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG
M-3$N-38W.C0N.3,S)UT@/2`G1VEL>F4M4FEJ96XG.PHD8V]O<F1I;F%T97-;
M)TYE=&AE<FQA;F1S)UU;)S4Q+C8U,#HU+C<P,"==(#T@)U9O;&ME;"<["B1C
M;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3$N.34P.C0N-#4P)UT@/2`G
M4F]T=&5R9&%M($%I<G!O<G0@6F5S=&EE;FAO=F5N)SL*)&-O;W)D:6YA=&5S
M6R=.971H97)L86YD<R==6R<U,BXP-C<Z-2XX.#,G72`]("=$965L96XG.PHD
M8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R+C$P,#HU+C$X,R==(#T@
M)T1E($)I;'0G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R+C$S
M,SHU+C(X,R==(#T@)U-O97-T97)B97)G)SL*)&-O;W)D:6YA=&5S6R=.971H
M97)L86YD<R==6R<U,BXQ.#,Z-"XT,3<G72`]("=686QK96YB=7)G)SL*)&-O
M;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,BXR-C<Z-BXY,#`G72`]("=4
M=V5N=&AE)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,BXS,#`Z
M-"XW-C<G72`]("=!;7-T97)D86T@06ER<&]R="!38VAI<&AO;"<["B1C;V]R
M9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3(N-#4P.C4N-3$W)UT@/2`G3&5L
M>7-T860G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R+CDQ-SHT
M+C<X,R==(#T@)T1E($MO;WDG.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S
M)UU;)S4S+C$S,SHV+C4X,R==(#T@)T=R;VYI;F=E;B!!:7)P;W)T($5E;&1E
M)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,RXR,3<Z-2XW-C<G
M72`]("=,965U=V%R9&5N)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==
M6R<U,RXR-3`Z-"XY,3<G72`]("=6;&EE;&%N9"<["B1C;V]R9&EN871E<ULG
M3F5W($-A;&5D;VYI82==6R<M,C`N-38W.C$V-"XR.#,G72`]("=+;W5M86,@
M3FQL92U#86QE9&]N:64G.PHD8V]O<F1I;F%T97-;)TYE=R!#86QE9&]N:6$G
M75LG+3(P+C8U,#HQ-C8N-3@S)UT@/2`G3W5L;W5P($EL92!/=79E82<["B1C
M;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==6R<M,C`N-S8W.C$V-RXR,S,G
M72`]("=/=6%N86AA;2!);&4@3&EF;W4G.PHD8V]O<F1I;F%T97-;)TYE=R!#
M86QE9&]N:6$G75LG+3(Q+C0X,SHQ-C@N,#,S)UT@/2`G3&$@4F]C:&4@26QE
M($UA<F4G.PHD8V]O<F1I;F%T97-;)TYE=R!#86QE9&]N:6$G75LG+3(R+C`Q
M-SHQ-C8N,C$W)UT@/2`G3&$@5&]N=&]U=&$@3FQL92U#86QE9&]N:64G.PHD
M8V]O<F1I;F%T97-;)TYE=R!#86QE9&]N:6$G75LG+3(R+C(V-SHQ-C8N-#4P
M)UT@/2`G3F]U;65A($YL;&4M0V%L961O;FEE)SL*)&-O;W)D:6YA=&5S6R=.
M97<@0V%L961O;FEA)UU;)RTR,BXV,#`Z,38W+C0U,"==(#T@)TUO=64@26QE
M($1E<R!0:6YS)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<Q+CDX
M,SHM,34W+C0X,R==(#T@)T-H<FES=&UA<R`O($-A<W-I9'DG.PHD8V]O<F1I
M;F%T97-;)TYE=R!:96%L86YD)UU;)RTR.2XR-3`Z+3$W-RXY,3<G72`]("=2
M86]U;"!)<VQA;F0L($ME<FUA9&5C($ES;&%N9"<["B1C;V]R9&EN871E<ULG
M3F5W(%IE86QA;F0G75LG,RXX-3`Z+3$U.2XS-C<G72`]("=&86YN:6YG($ES
M;&%N9"<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG+3,V+C<X,SHQ
M-S0N-C,S)UT@/2`G5VAE;G5A<&%I)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A
M;&%N9"==6R<M,S<N,#$W.C$W-"XX,#`G72`]("=!=6-K;&%N9"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,S<N-C8W.C$W-BXR
M,#`G72`]("=4875R86YG82!!97)O9')O;64@07=S)SL*)&-O;W)D:6YA=&5S
M6R=.97<@6F5A;&%N9"==6R<M,S@N,3$W.C$W-BXS,3<G72`]("=2;W1O<G5A
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG+3,X
M+C8V-SHQ-S<N.3@S)UT@/2`G1VES8F]R;F4@065R;V1R;VUE)SL*)&-O;W)D
M:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,SDN,#$W.C$W-"XQ.#,G72`]("=.
M97<@4&QY;6]U=&@@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A
M;&%N9"==6R<M-#`N,C`P.C$W-2XS-C<G72`]("=/:&%K96$G.PHD8V]O<F1I
M;F%T97-;)TYE=R!:96%L86YD)UU;)RTT,"XY,#`Z,3<T+CDX,R==(#T@)U!A
M<F%P87)A=6UU($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA
M;F0G75LG+30Q+C,S,SHQ-S0N.#`P)UT@/2`G5V5L;&EN9W1O;B!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M-#(N-#$W.C$W,RXW
M,#`G72`]("=+86EK;W5R82<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G
M75LG+30R+C<Q-SHQ-S`N.3@S)UT@/2`G2&]K:71I:V$@065R;V1R;VUE)SL*
M)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M-#,N-#@S.C$W,BXU-3`G
M72`]("=#:')I<W1C:'5R8V@G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD
M)UU;)RTT,RXY-3`Z+3$W-BXU-C<G72`]("=#:&%T:&%M($ES;&%N9"<["B1C
M;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG+30U+CDS,SHQ-S`N,C`P)UT@
M/2`G1'5N961I;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L
M86YD)UU;)RTT-BXW,#`Z,38X+C4U,"==(#T@)TEN=F5R8V%R9VEL;"!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)TYI8V%R86=U82==6R<Q,2XT,3<Z+3@U
M+C@S,R==(#T@)U)I=F%S)SL*)&-O;W)D:6YA=&5S6R=.:6-A<F%G=6$G75LG
M,3(N,#`P.BTX-BXW-C<G72`]("=";'5E9FEE;&1S)SL*)&-O;W)D:6YA=&5S
M6R=.:6-A<F%G=6$G75LG,3(N,3`P.BTX-2XS-C<G72`]("=*=6EG86QP82<[
M"B1C;V]R9&EN871E<ULG3FEC87)A9W5A)UU;)S$R+C$U,#HM.#8N,38W)UT@
M/2`G36%N86=U82!!+B!#+B!386YD:6YO)SL*)&-O;W)D:6YA=&5S6R=.:6-A
M<F%G=6$G75LG,3(N-C,S.BTX-RXQ,S,G72`]("=#:&EN86YD96=A)SL*)&-O
M;W)D:6YA=&5S6R=.:6-A<F%G=6$G75LG,3,N,#@S.BTX-2XY.#,G72`]("=*
M:6YO=&5G82<["B1C;V]R9&EN871E<ULG3FEC87)A9W5A)UU;)S$T+C`U,#HM
M.#,N,S8W)UT@/2`G4'5E<G1O($-A8F5Z87,G.PHD8V]O<F1I;F%T97-;)TYI
M9V5R)UU;)S$Q+C@X,SHS+C0U,"==(#T@)T=A>6$G.PHD8V]O<F1I;F%T97-;
M)TYI9V5R)UU;)S$S+C(S,SHQ,2XY.#,G72`]("=-86EN92U3;W)O82<["B1C
M;V]R9&EN871E<ULG3FEG97(G75LG,3,N-#$W.C$R+C<X,R==(#T@)T1I9F9A
M)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==6R<Q,RXT-C<Z-RXP.#,G72`]("=-
M87)A9&DG.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$S+C0X,SHR+C$V-R==
M(#T@)TYI86UE>2U!97)O)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==6R<Q,RXW
M.#,Z."XY.#,G72`]("=::6YD97(G.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;
M)S$S+C@P,#HU+C(U,"==(#T@)T)I<FYI+4Y<)TMO;FYI)SL*)&-O;W)D:6YA
M=&5S6R=.:6=E<B==6R<Q,RXY.#,Z,3`N,S`P)UT@/2`G1V]U<F4G.PHD8V]O
M<F1I;F%T97-;)TYI9V5R)UU;)S$T+C(P,#HQ+C0U,"==(#T@)U1I;&QA8F5R
M>2<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,30N.3`P.C4N,C4P)UT@/2`G
M5&%H;W5A)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==6R<Q-BXY-C<Z-RXY.#,G
M72`]("=!9V%D97HG.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$X+C8X,SHQ
M,BXY,3<G72`]("=":6QM82<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<Q
M,"XV,#`Z-RXT-3`G72`]("=+861U;F$G.PHD8V]O<F1I;F%T97-;)TYI9V5R
M:6$G75LG,3$N,3,S.C<N-C@S)UT@/2`G6F%R:6$G.PHD8V]O<F1I;F%T97-;
M)TYI9V5R:6$G75LG,3$N.#4P.C$S+C`X,R==(#T@)TUA:61U9W5R:2<["B1C
M;V]R9&EN871E<ULG3FEG97)I82==6R<Q,BXP-3`Z."XU,S,G72`]("=+86YO
M)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S$R+C$V-SHV+C<P,"==(#T@
M)T=U<V%U)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S$S+C`Q-SHU+C(U
M,"==(#T@)U-O:V]T;R<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<T+C@U
M,#HW+C`Q-R==(#T@)U!O<G0@2&%R8V]U<G0G.PHD8V]O<F1I;F%T97-;)TYI
M9V5R:6$G75LG-"XY-C<Z."XS-3`G72`]("=#86QA8F%R)SL*)&-O;W)D:6YA
M=&5S6R=.:6=E<FEA)UU;)S8N-#8W.C<N-34P)UT@/2`G16YU9W4G.PHD8V]O
M<F1I;F%T97-;)TYI9V5R:6$G75LG-BXU.#,Z,RXS,S,G72`]("=,86=O<R`O
M($EK96IA)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S<N-#,S.C,N.3`P
M)UT@/2`G26)A9&%N)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S<N-C@S
M.C@N-C$W)UT@/2`G36%K=7)D:2<["B1C;V]R9&EN871E<ULG3FEG97)I82==
M6R<W+C<X,SHT+C0X,R==(#T@)T]S:&]G8F\G.PHD8V]O<F1I;F%T97-;)TYI
M9V5R:6$G75LG."XT.#,Z-"XU.#,G72`]("=);&]R:6XG.PHD8V]O<F1I;F%T
M97-;)TYI9V5R:6$G75LG.2XQ,#`Z-BXP,3<G72`]("=":61A)SL*)&-O;W)D
M:6YA=&5S6R=.:6=E<FEA)UU;)SDN,C,S.C$R+C0V-R==(#T@)UEO;&$G.PHD
M8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG.2XX-C<Z."XY,#`G72`]("=*;W,G
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<U."XQ,#`Z-BXV,S,G72`]("=,
M:7-T82!&;'EP;&%S<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S4X+C(P
M,#HX+C`X,R==(#T@)TMR:7-T:6%N<V%N9"`O($MJ979I:R<["B1C;V]R9&EN
M871E<ULG3F]R=V%Y)UU;)S4X+C@X,SHU+C8S,R==(#T@)U-T879A;F=E<B`O
M(%-O;&$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<U.2XQ.#,Z.2XU-C<G
M72`]("=3:VEE;BU'96ET97)Y9V=E;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S4Y+C(P,#HQ,"XR-C<G72`]("=4;W)P)SL*)&-O;W)D:6YA=&5S6R=.
M;W)W87DG75LG-3DN,S4P.C4N,C$W)UT@/2`G2&%U9V5S=6YD("\@2V%R;6]Y
M)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3DN,S@S.C$P+C<X,R==(#T@
M)U)Y9V=E)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3DN.3`P.C$P+C8S
M,R==(#T@)T]S;&\@+R!&;W)N96)U)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG
M75LG-C`N,C`P.C$Q+C`X,R==(#T@)T]S;&\@+R!'87)D97)M;V5N)SL*)&-O
M;W)D:6YA=&5S6R=.;W)W87DG75LG-C`N,C@S.C4N,C,S)UT@/2`G0F5R9V5N
M("\@1FQE<VQA;F0G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,"XV-3`Z
M-BXU,#`G72`]("=6;W-S+4)O)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG
M-C$N,#`P.CDN,S`P)UT@/2`G1F%G97)N97,@3&5I<FEN)SL*)&-O;W)D:6YA
M=&5S6R=.;W)W87DG75LG-C$N,34P.C<N,3,S)UT@/2`G4V]G;F1A;"`O($AA
M=6MA<V5N)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C$N-3@S.C4N,#,S
M)UT@/2`G1FQO<F\G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,2XX,S,Z
M-BXQ,3<G72`]("=386YD86YE("\@06YD82<["B1C;V]R9&EN871E<ULG3F]R
M=V%Y)UU;)S8R+C$X,SHV+C`V-R==(#T@)T]R<W1A+59O;&1A("\@2&]V9&5N
M)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C(N-38W.C8N,3$W)UT@/2`G
M06QE<W5N9"`O(%9I9W)A)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C(N
M-3@S.C$Q+C,U,"==(#T@)U)O<F]S($QU9G1H879N)SL*)&-O;W)D:6YA=&5S
M6R=.;W)W87DG75LG-C(N-S4P.C<N,C8W)UT@/2`G36]L9&4@+R!!<F\G.PHD
M8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,RXQ,3<Z-RXX,S,G72`]("=+<FES
M=&EA;G-U;F0@+R!+=F5R;F)E<F=E="<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S8S+C0V-SHQ,"XY,S,G72`]("=4<F]N9&AE:6T@+R!6865R;F5S)SL*
M)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C,N-S`P.CDN-C`P)UT@/2`G3W)L
M86YD($EI:2<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8T+C0V-SHQ,2XU
M.#,G72`]("=.86US;W,@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)TYO<G=A
M>2==6R<V-"XX,S,Z,3$N,34P)UT@/2`G4F]R=FEK("\@4GEU;2<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S8U+C0V-SHQ,BXR,3<G72`]("="<F]N;F]Y
M<W5N9"`O($)R;VYN;WDG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V-2XX
M,#`Z,3,N,3,S)UT@/2`G36]S:F]E;B!+:F%E<G-T860G.PHD8V]O<F1I;F%T
M97-;)TYO<G=A>2==6R<V-2XY-C<Z,3(N-#8W)UT@/2`G4V%N9&YE<W-J;V5N
M("\@4W1O:VMA)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C8N,S8W.C$T
M+C,P,"==(#T@)TUO($D@4F%N82`O(%)O<W-V;VQL)SL*)&-O;W)D:6YA=&5S
M6R=.;W)W87DG75LG-C<N,C8W.C$T+C,V-R==(#T@)T)O9&\@5FDG.PHD8V]O
M<F1I;F%T97-;)TYO<G=A>2==6R<V-RXU,3<Z,3(N,3`P)UT@/2`G4F]S="!&
M;'EP;&%S<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8X+C$U,#HQ,RXV
M,3<G72`]("=,96MN97,G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V."XR
M-3`Z,30N-C8W)UT@/2`G4W9O;'9A97(@+R!(96QL92<["B1C;V]R9&EN871E
M<ULG3F]R=V%Y)UU;)S8X+C0V-SHQ-RXU,#`G72`]("=.87)V:6L@26EI)SL*
M)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C@N-3$W.C$V+C8X,R==(#T@)T5V
M96YE<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8X+C4X,SHQ-2XP,3<G
M72`]("=3=&]R:VUA<FMN97,@+R!3:V%G96XG.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<V.2XP,#`Z,C,N,#,S)UT@/2`G2V%U=&]K96EN;R<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S8Y+C`V-SHQ."XU,S,G72`]("="87)D=69O
M<W,G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XS,#`Z,38N,34P)UT@
M/2`G06YD;WEA)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-CDN-C@S.C$X
M+CDQ-R==(#T@)U1R;VUS;R`O($QA;F=N97,G.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<V.2XW,S,Z,CDN.3`P)UT@/2`G2VER:V5N97,@3'5F=&AA=FXG
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XW.#,Z,C`N.38W)UT@/2`G
M4V]R:VIO<V5N)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-CDN.3@S.C(S
M+C,V-R==(#T@)T%L=&$@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)TYO<G=A
M>2==6R<W,"XP-C<Z,C0N.3@S)UT@/2`G0F%N86LG.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<W,"XP-C<Z,CDN.#4P)UT@/2`G5F%D<V\G.PHD8V]O<F1I
M;F%T97-;)TYO<G=A>2==6R<W,"XS-3`Z,S$N,#4P)UT@/2`G4W9A<G1N97,G
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W,"XV-C<Z,C,N-C8W)UT@/2`G
M2&%M;65R9F5S="<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<P+C@V-SHR
M.2XP,S,G72`]("="97)L979A9R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S<P+CDS,SHM."XV-C<G72`]("=*86X@36%Y96XG.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<W,2XP,3<Z,C4N.3@S)UT@/2`G2&]N;FEN9W-V86<@+R!6
M86QA;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<Q+C`S,SHR-RXX,S,G
M72`]("=-96AA;6XG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W-"XU,3<Z
M,3DN,#$W)UT@/2`G0FIO<FYO>6$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==
M6R<W-BXU,#`Z,C4N,#8W)UT@/2`G2&]P96XG.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<W."XR-3`Z,34N-#8W)UT@/2`G4W9A;&)A<F0@3'5F=&AA=FXG
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W."XY,3<Z,3$N.3,S)UT@/2`G
M3GDM06QE<W5N9"!):2<["B1C;V]R9&EN871E<ULG3VUA;B==6R<Q-RXP,S,Z
M-30N,#@S)UT@/2`G4V%L86QA:"<["B1C;V]R9&EN871E<ULG3VUA;B==6R<Q
M-RXV-C<Z-30N,#,S)UT@/2`G5&AU;7)A:70G.PHD8V]O<F1I;F%T97-;)T]M
M86XG75LG,C`N-C8W.C4X+CDP,"==(#T@)TUA<VER86@G.PHD8V]O<F1I;F%T
M97-;)T]M86XG75LG,C(N,S4P.C4V+C0X,R==(#T@)T9A:'5D)SL*)&-O;W)D
M:6YA=&5S6R=/;6%N)UU;)S(R+C4S,SHU.2XT.#,G72`]("=3=7(G.PHD8V]O
M<F1I;F%T97-;)T]M86XG75LG,C,N,#8W.C4W+C8U,"==(#T@)U-A:7$G.PHD
M8V]O<F1I;F%T97-;)T]M86XG75LG,C,N-3@S.C4X+C(X,R==(#T@)U-E96(L
M($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG3VUA;B==
M6R<R-"XR,S,Z-34N-S@S)UT@/2`G0G5R86EM:2<["B1C;V]R9&EN871E<ULG
M3VUA;B==6R<R-"XT-C<Z-38N-C,S)UT@/2`G4V]H87(@36%J:7,G.PHD8V]O
M<F1I;F%T97-;)T]M86XG75LG,C8N,C$W.C4V+C(S,R==(#T@)TMH87-S86(G
M.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S(T+CDP,#HV-RXQ,S,G72`]
M("=+87)A8VAI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;
M)S(U+C`V-SHV,2XX,#`G72`]("=*:7=A;FDG.PHD8V]O<F1I;F%T97-;)U!A
M:VES=&%N)UU;)S(U+C,X,SHV."XT,3<G72`]("=(>61E<F%B860@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,C8N,C4P.C8X+C,V-R==
M(#T@)TYA=V%B<VAA:"<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,C8N
M.38W.C8T+C$P,"==(#T@)U!A;FIG=7(G.PHD8V]O<F1I;F%T97-;)U!A:VES
M=&%N)UU;)S(X+C,P,#HV."XT-C<G72`]("=*86-O8F%B860G.PHD8V]O<F1I
M;F%T97-;)U!A:VES=&%N)UU;)S(Y+C4U,#HV-RXX.#,G72`]("=3:6)I)SL*
M)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S,"XR,#`Z-S$N-#,S)UT@/2`G
M375L=&%N)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S,"XR-3`Z-C8N
M.#@S)UT@/2`G475E='1A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U!A:VES
M=&%N)UU;)S,Q+C4Q-SHW-"XT,#`G72`]("=,86AO<F4@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG4&%K:7-T86XG75LG,S$N-34P.C<T+C,S,R==(#T@)TQA
M:&]R92!#:71Y)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S,2XX,3<Z
M-S`N.3$W)UT@/2`G1&5R82!)<VUA:6P@2VAA;B<["B1C;V]R9&EN871E<ULG
M4&%K:7-T86XG75LG,S(N,#4P.C<R+C8V-R==(#T@)U-A<F=O9&AA)SL*)&-O
M;W)D:6YA=&5S6R=086MI<W1A;B==6R<S,BXU-3`Z-S$N-3$W)UT@/2`G36EA
M;G=A;&DG.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S,S+C8Q-SHW,RXQ
M,#`G72`]("=)<VQA;6%B860@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&%K
M:7-T86XG75LG,S0N,#$W.C<Q+C4X,R==(#T@)U!E<VAA=V%R)SL*)&-O;W)D
M:6YA=&5S6R=086MI<W1A;B==6R<S-"XP-C<Z-S$N.3@S)UT@/2`G4FES86QP
M=7(G.PHD8V]O<F1I;F%T97-;)U!A;&%U)UU;)S<N,S8W.C$S-"XU,S,G72`]
M("="86)E;'1H=6%P($ES;&%N9"P@0F%B96QT:'5A<"]+;W)O<B!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=086YA;6$G75LG."XP.#,Z+3@P+CDU,"==(#T@
M)U-A;G1I86=O)SL*)&-O;W)D:6YA=&5S6R=086YA;6$G75LG."XT,#`Z+3@R
M+C0Q-R==(#T@)T1A=FED)SL*)&-O;W)D:6YA=&5S6R=086YA;6$G75LG."XY
M,3<Z+3<Y+C8P,"==(#T@)TAO=V%R9"!!:7(@1F]R8V4@0F%S92<["B1C;V]R
M9&EN871E<ULG4&%N86UA)UU;)SDN,#4P.BTW.2XS-C<G72`]("=4;V-U;65N
M)SL*)&-O;W)D:6YA=&5S6R=086YA;6$G75LG.2XS,S,Z+3<Y+CDX,R==(#T@
M)T9T(%-H97)M86X@4F]C;V(G.PHD8V]O<F1I;F%T97-;)U!A<'5A($YE=R!'
M=6EN96$G75LG+3,N-38W.C$T,RXV,S,G72`]("=797=A:R<["B1C;V]R9&EN
M871E<ULG4&%P=6$@3F5W($=U:6YE82==6R<M-2XR,3<Z,30U+C<X,R==(#T@
M)TUA9&%N9R<["B1C;V]R9&EN871E<ULG4&%P=6$@3F5W($=U:6YE82==6R<M
M.2XT,S,Z,30W+C(Q-R==(#T@)TUO<F5S8GDG.PHD8V]O<F1I;F%T97-;)U!A
M<F%G=6%Y)UU;)RTR,"XW,3<Z+38Q+CDQ-R==(#T@)TYU979A($%S=6YC:6]N
M)SL*)&-O;W)D:6YA=&5S6R=087)A9W5A>2==6R<M,C(N,#$W.BTV,"XV,#`G
M72`]("=-87)I<V-A;"!%<W1I9V%R<FEB:6$G.PHD8V]O<F1I;F%T97-;)U!A
M<F%G=6%Y)UU;)RTR,RXT,3<Z+34W+C,P,"==(#T@)T-O;F-E<&-I;VXG.PHD
M8V]O<F1I;F%T97-;)U!A<F%G=6%Y)UU;)RTR-2XR-C<Z+34W+C8S,R==(#T@
M)T%S=6YC:6]N("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4&%R86=U
M87DG75LG+3(W+C,Q-SHM-34N.#,S)UT@/2`G16YC87)N86-I;VXG.PHD8V]O
M<F1I;F%T97-;)U!E<G4G75LG+3$P+C<S,SHM-S,N-S@S)UT@/2`G071A;&%Y
M82<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,3(N,#`P.BTW-RXQ,3<G72`]
M("=,:6UA+4-A;&QA;R`O($%E<F]P+B!);G1E<FYA8VEO;F%L($IO<F=E8VAA
M=F5Z)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ,BXV,S,Z+38Y+C(P,"==
M(#T@)U!U97)T;R!-86QD;VYA9&\G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG
M+3$S+C$S,SHM-S0N,C$W)UT@/2`G07EA8W5C:&\G.PHD8V]O<F1I;F%T97-;
M)U!E<G4G75LG+3$S+C4U,#HM-S$N.3@S)UT@/2`G0W5Z8V\G.PHD8V]O<F1I
M;F%T97-;)U!E<G4G75LG+3$S+C<Q-SHM-S,N,S4P)UT@/2`G06YD86AU87EL
M82<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,3,N-S4P.BTW-BXR.#,G72`]
M("=0:7-C;R<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,34N,S@S.BTW-2XQ
M-C<G72`]("=386X@2G5A;B<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,34N
M-#@S.BTW,"XQ-3`G72`]("=*=6QI86-A)SL*)&-O;W)D:6YA=&5S6R=097)U
M)UU;)RTQ-BXS,3<Z+3<Q+C4U,"==(#T@)T%R97%U:7!A)SL*)&-O;W)D:6YA
M=&5S6R=097)U)UU;)RTQ."XP-C<Z+3<P+C,P,"==(#T@)U1A8VYA)SL*)&-O
M;W)D:6YA=&5S6R=097)U)UU;)RTS+C4U,#HM.#`N-#`P)UT@/2`G5'5M8F5S
M)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTS+C<U,#HM-S,N,C4P)UT@/2`G
M27%U:71O<R<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M-"XU-C<Z+3@Q+C(U
M,"==(#T@)U1A;&%R82<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M-2XQ.#,Z
M+3@P+C8P,"==(#T@)U!I=7)A)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTU
M+CDP,#HM-S8N,#@S)UT@/2`G675R:6UA9W5A<R<["B1C;V]R9&EN871E<ULG
M4&5R=2==6R<M-BXP-3`Z+3<W+C$U,"==(#T@)U)I;VIA)SL*)&-O;W)D:6YA
M=&5S6R=097)U)UU;)RTV+C(Q-SHM-S<N.#,S)UT@/2`G0VAA8VAA<&]Y87,G
M.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+38N-#4P.BTW-BXS.#,G72`]("=4
M87)A<&]T;R<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M-BXW.#,Z+3<Y+C@S
M,R==(#T@)T-H:6-L87EO)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTW+C$S
M,SHM-S@N-#8W)UT@/2`G0V%J86UA<F-A)SL*)&-O;W)D:6YA=&5S6R=097)U
M)UU;)RTW+C(Q-SHM-S8N-S$W)UT@/2`G2G5A;FIU:2<["B1C;V]R9&EN871E
M<ULG4&5R=2==6R<M."XQ,#`Z+3<Y+C`S,R==(#T@)U1R=6II;&QO)SL*)&-O
M;W)D:6YA=&5S6R=097)U)UU;)RTX+C0Q-SHM-S0N-C`P)UT@/2`G4'5C86QL
M<&$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3DN,3,S.BTW-2XY-3`G72`]
M("=4:6YG;R!-87)I82<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M.2XQ-C<Z
M+3<X+C4Q-R==(#T@)T-H:6UB;W1E)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;
M)RTY+C,U,#HM-S<N-C`P)UT@/2`G06YT82!(=6%R87HG.PHD8V]O<F1I;F%T
M97-;)U!E<G4G75LG+3DN.3`P.BTW-2XW-3`G72`]("=(=6%N=6-O)SL*)&-O
M;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,"XS,#`Z,3(S+CDV-R==(#T@
M)TUA8W1A;B<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3`N-S`P
M.C$R,BXU-C<G72`]("=);&]I;&\G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I
M;F5S)UU;)S$Q+C`S,SHQ,C8N-S,S)UT@/2`G1W5I=6%N)SL*)&-O;W)D:6YA
M=&5S6R=0:&EL:7!P:6YE<R==6R<Q,2XR-3`Z,3(U+C`P,"==(#T@)U1A8VQO
M8F%N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,2XU.#,Z,3(R
M+C<U,"==(#T@)U)O>&%S)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==
M6R<Q,BXS-3`Z,3(Q+C`S,R==(#T@)U-A;B!*;W-E)SL*)&-O;W)D:6YA=&5S
M6R=0:&EL:7!P:6YE<R==6R<Q,BXS-C<Z,3(S+C8Q-R==(#T@)TUA<V)A=&4G
M.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$R+C0X,SHQ,C0N-C,S
M)UT@/2`G0V%T87)M86XG.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;
M)S$R+C4X,SHQ,C(N,C8W)UT@/2`G4F]M8FQO;B<["B1C;V]R9&EN871E<ULG
M4&AI;&EP<&EN97,G75LG,3,N,3,S.C$R,RXW,S,G72`]("=,96=A<W!I)SL*
M)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,RXT,3<Z,3(Q+C$X,R==
M(#T@)T-A;&%P86XG.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$S
M+C4X,SHQ,C0N,C,S)UT@/2`G5FER86,G.PHD8V]O<F1I;F%T97-;)U!H:6QI
M<'!I;F5S)UU;)S$T+C`X,SHQ,C(N,#$W)UT@/2`G06QA8F%T)SL*)&-O;W)D
M:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-"XQ,S,Z,3(R+CDX,R==(#T@)T1A
M970G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$T+C4P,#HQ,C`N
M.3$W)UT@/2`G4V%N9VQE>2!0;VEN="<["B1C;V]R9&EN871E<ULG4&AI;&EP
M<&EN97,G75LG,30N-3$W.C$R,2XP,#`G72`]("=.:6YO>2!!<75I;F\@26YT
M97(M3F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN
M97,G75LG,30N.#`P.C$R,"XR-C<G72`]("=3=6)I8R!"87D@5V5A=&AE<B!3
M=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-2XQ-C<Z
M,3(P+C4V-R==(#T@)T-L87)K($%B)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P
M:6YE<R==6R<Q-2XS,S,Z,3$Y+CDV-R==(#T@)TEB82<["B1C;V]R9&EN871E
M<ULG4&AI;&EP<&EN97,G75LG,34N-S8W.C$R,2XU-C<G72`]("="86QE<B<[
M"B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,38N-#$W.C$R,"XV,#`G
M72`]("="86=U:6\G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$W
M+C4V-SHQ,C`N,S@S)UT@/2`G5FEG86XG.PHD8V]O<F1I;F%T97-;)U!H:6QI
M<'!I;F5S)UU;)S$W+C8Q-SHQ,C$N-S,S)UT@/2`G5'5G=65G87)A;R<["B1C
M;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3@N,3@S.C$R,"XU,S,G72`]
M("=,86]A9R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3@N,S8W
M.C$R,2XV,S,G72`]("=!<&%R<FDG.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I
M;F5S)UU;)S(P+C0U,#HQ,C$N.38W)UT@/2`G0F%S8V\G.PHD8V]O<F1I;F%T
M97-;)U!H:6QI<'!I;F5S)UU;)S8N,3$W.C$R-2XQ.#,G72`]("='96XN(%-A
M;G1O<R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG-BXY,#`Z,3(R
M+C`V-R==(#T@)UIA;6)O86YG82<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN
M97,G75LG-RXQ,3<Z,3(U+C8U,"==(#T@)T1A=F%O($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S<N,38W.C$R-"XR,3<G72`]("=#
M;W1O8F%T;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG."XQ-3`Z
M,3(U+C`X,R==(#T@)TUA;&%Y8F%L87DG.PHD8V]O<F1I;F%T97-;)U!H:6QI
M<'!I;F5S)UU;)S@N-#@S.C$R-"XV,S,G72`]("=#86=A>6%N($1E($]R;R<[
M"B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG."XV,#`Z,3(S+C,U,"==
M(#T@)T1I<&]L;V<G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)SDN
M,S`P.C$R,RXS,#`G72`]("=$=6UA9W5E=&4G.PHD8V]O<F1I;F%T97-;)U!H
M:6QI<'!I;F5S)UU;)SDN-C`P.C$R,RXX-3`G72`]("=486=B:6QA<F%N)SL*
M)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Y+C<U,#HQ,3@N-S,S)UT@
M/2`G4'5E<G1O(%!R:6YC97-A)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE
M<R==6R<Y+C@P,#HQ,C4N-3`P)UT@/2`G4W5R:6=A;R<["B1C;V]R9&EN871E
M<ULG4&AI;&EP<&EN97,G75LG.2XY,S,Z,3(U+C4Q-R==(#T@)T)U='5A;B<[
M"B1C;V]R9&EN871E<ULG4&]L86YD)UU;)S4P+C`X,SHQ.2XX,#`G72`]("=+
M<F%K;W<G.PHD8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U,"XQ,#`Z,C(N,#4P
M)UT@/2`G4GIE<WIO=RU*87-I;VYK82<["B1C;V]R9&EN871E<ULG4&]L86YD
M)UU;)S4P+C(S,SHQ.2XP,S,G72`]("=+871O=VEC92<["B1C;V]R9&EN871E
M<ULG4&]L86YD)UU;)S4Q+C$P,#HQ-BXX.#,G72`]("=7<F]C;&%W($EI)SL*
M)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3$N.3,S.C$U+C4S,R==(#T@)UII
M96QO;F$@1V]R82<["B1C;V]R9&EN871E<ULG4&]L86YD)UU;)S4R+C$V-SHR
M,"XY-C<G72`]("=787)S>F%W82U/:V5C:64G.PHD8V]O<F1I;F%T97-;)U!O
M;&%N9"==6R<U,BXT,3<Z,38N.#,S)UT@/2`G4&]Z;F%N)SL*)&-O;W)D:6YA
M=&5S6R=0;VQA;F0G75LG-3,N-#`P.C$T+C8Q-R==(#T@)U-Z8WIE8VEN)SL*
M)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-30N,C`P.C$V+C$U,"==(#T@)TMO
M<WIA;&EN)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-30N,S@S.C$X+C0V
M-R==(#T@)T=D86YS:RU296)I96-H;W=O)SL*)&-O;W)D:6YA=&5S6R=0;W)T
M=6=A;"==6R<S,BXV.#,Z+3$V+C<V-R==(#T@)T9U;F-H86P@+R!3+B!#871A
M<FEN82<["B1C;V]R9&EN871E<ULG4&]R='5G86PG75LG,S,N,#8W.BTQ-BXS
M-3`G72`]("=0;W)T;R!386YT;R<["B1C;V]R9&EN871E<ULG4&]R='5G86PG
M75LG,S8N.38W.BTR-2XQ-C<G72`]("=386YT82!-87)I82!!8V]R97,G.PHD
M8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,W+C`Q-SHM-RXY-C<G72`]("=&
M87)O("\@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S
M-RXW,S,Z+3(U+C<P,"==(#T@)U!O;G1A($1E;&=A9&$@+R!.;W)D96QA($%C
M;W)E<R<["B1C;V]R9&EN871E<ULG4&]R='5G86PG75LG,S@N,#$W.BTW+C@V
M-R==(#T@)T)E:F$G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,X+C4Q
M-SHM,C@N-S$W)UT@/2`G2&]R=&$@+R!#87-T96QO($)R86YC;R!!8V]R97,G
M.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,X+C<V-SHM,C<N,3`P)UT@
M/2`G3&%J97,@06-O<F5S)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S
M."XW-C<Z+3DN,3,S)UT@/2`G3&ES8F]A("\@4&]R=&5L82<["B1C;V]R9&EN
M871E<ULG4&]R='5G86PG75LG,SDN-#4P.BTS,2XQ,S,G72`]("=&;&]R97,@
M06-O<F5S)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<T,2XR,S,Z+3@N
M-C@S)UT@/2`G4&]R=&\@+R!0961R87,@4G5B<F%S)SL*)&-O;W)D:6YA=&5S
M6R=0;W)T=6=A;"==6R<T,2XR-C<Z+3<N-S$W)UT@/2`G5FEL82!296%L)SL*
M)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<T,2XX,#`Z+38N-S,S)UT@/2`G
M0G)A9V%N8V$G.PHD8V]O<F1I;F%T97-;)U%A=&%R)UU;)S(U+C(U,#HU,2XU
M-C<G72`]("=$;VAA($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG4F5U;FEO;B==6R<M,C`N.#@S.C4U+C4Q-R==(#T@)U-A:6YT+41E
M;FES("\@1VEL;&]T)SL*)&-O;W)D:6YA=&5S6R=2975N:6]N)UU;)RTR,2XS
M,S,Z-34N-#@S)UT@/2`G4V%I;G0M4&EE<G)E)SL*)&-O;W)D:6YA=&5S6R=2
M;VUA;FEA)UU;)S0T+C(S,SHR,RXX-C<G72`]("=#<F%I;W9A)SL*)&-O;W)D
M:6YA=&5S6R=2;VUA;FEA)UU;)S0T+C,S,SHR."XT,S,G72`]("=+;V=A;&YI
M8V5A;G4G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#0N-3`P.C(V+C$S
M,R==(#T@)T)U8W5R97-T:2`O($EM:"<["B1C;V]R9&EN871E<ULG4F]M86YI
M82==6R<T-"XU-3`Z,C8N,3`P)UT@/2`G0G5C=7)E<W1I($]T;W!E;FDG.PHD
M8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#4N,3@S.C(X+C@Q-R==(#T@)U1U
M;&-E82<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-2XT,3<Z,C(N,C4P
M)UT@/2`G0V%R86YS96)E<R<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T
M-2XW-C<Z,C$N,C4P)UT@/2`G5&EM:7-O87)A)SL*)&-O;W)D:6YA=&5S6R=2
M;VUA;FEA)UU;)S0U+C@P,#HR-"XQ-3`G72`]("=3:6)I=2<["B1C;V]R9&EN
M871E<ULG4F]M86YI82==6R<T-BXR,#`Z,C$N-#`P)UT@/2`G07)A9"<["B1C
M;V]R9&EN871E<ULG4F]M86YI82==6R<T-BXU,S,Z,C0N-3,S)UT@/2`G5&ER
M9W4@375R97,G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#8N-3@S.C(V
M+CDV-R==(#T@)T)A8V%U)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0V
M+C<X,SHR,RXU-C<G72`]("=#;'5J+4YA<&]C82<["B1C;V]R9&EN871E<ULG
M4F]M86YI82==6R<T-RXP-3`Z,C$N.3,S)UT@/2`G3W)A9&5A)SL*)&-O;W)D
M:6YA=&5S6R=2;VUA;FEA)UU;)S0W+C$V-SHR-RXV,S,G72`]("=)87-I)SL*
M)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0W+C8U,#HR-BXR-3`G72`]("=3
M=6-E879A("\@4V%L8V5A)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0W
M+C8V-SHR,RXU.#,G72`]("="86EA($UA<F4G.PHD8V]O<F1I;F%T97-;)U)O
M;6%N:6$G75LG-#<N.#`P.C(R+C@X,R==(#T@)U-A='4@36%R92<["B1C;V]R
M9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0S+C$Q-SHQ,S$N.3,S
M)UT@/2`G5FQA9&EV;W-T;VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D
M97)A=&EO;B==6R<T,RXT,S,Z,SDN.3`P)UT@/2`G061L97(G.PHD8V]O<F1I
M;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T-"XR,S,Z-#,N,#8W)UT@
M/2`G36EN97)A;%PG3GEE(%9O9'DG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@
M1F5D97)A=&EO;B==6R<T-2XP,S,Z,SDN,34P)UT@/2`G2W)A<VYO9&%R)SL*
M)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-#8N,S8W.C0T
M+C,S,R==(#T@)T5L:7-T82<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E
M<F%T:6]N)UU;)S0V+CDU,#HQ-#(N-S$W)UT@/2`G675Z:&YO+5-A:VAA;&EN
M<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T-RXR
M-C<Z,SDN.#$W)UT@/2`G4F]S=&]V+4YA+41O;G4G.PHD8V]O<F1I;F%T97-;
M)U)U<W-I86X@1F5D97)A=&EO;B==6R<T."XU,3<Z,3,U+C$V-R==(#T@)TAA
M8F%R;W9S:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;
M)S0X+C<X,SHT-"XS-C<G72`]("=6;VQG;V=R860G.PHD8V]O<F1I;F%T97-;
M)U)U<W-I86X@1F5D97)A=&EO;B==6R<T.2XT-3`Z,3,V+C4V-R==(#T@)U1R
M;VEC:V]E)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG
M-3$N-C4P.C,Y+C(U,"==(#T@)U9O<F]N97HG.PHD8V]O<F1I;F%T97-;)U)U
M<W-I86X@1F5D97)A=&EO;B==6R<U,2XX,S,Z,3`W+C8P,"==(#T@)U5L86XM
M561E)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3(N
M,#@S.C$Q,RXT.#,G72`]("=#:&ET82<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S4R+C$V-SHQ,#DN-S@S)UT@/2`G2&]R:6YS:R<[
M"B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4R+C(V-SHQ
M,#0N,S$W)UT@/2`G27)K=71S:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&
M961E<F%T:6]N)UU;)S4R+C@Q-SHQ,#0N-S8W)UT@/2`G57-T7"=/<F1Y;G-K
M:6HG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,RXP
M-C<Z,3,R+CDX,R==(#T@)T5K:6UC:&%N)SL*)&-O;W)D:6YA=&5S6R=2=7-S
M:6%N($9E9&5R871I;VXG75LG-3,N,#@S.C$U."XU.#,G72`]("=0971R;W!A
M=FQO=G-K+4MA;6-H871S:VEJ)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E
M9&5R871I;VXG75LG-3,N,3$W.C0U+C`Q-R==(#T@)U!E;GIA)SL*)&-O;W)D
M:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3,N,C`P.C4P+C$U,"==
M(#T@)U-A;6%R82<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N
M)UU;)S4S+C(U,#HS-"XS,3<G72`]("="<FIA;G-K)SL*)&-O;W)D:6YA=&5S
M6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3,N-#,S.C@S+C4Q-R==(#T@)T)A
M<FYA=6PG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U
M-"XX.#,Z.3DN,#,S)UT@/2`G3FEZ:&YE=61I;G-K)SL*)&-O;W)D:6YA=&5S
M6R=2=7-S:6%N($9E9&5R871I;VXG75LG-34N,#@S.C@R+CDP,"==(#T@)TYO
M=F]S:6)I<G-K)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG
M75LG-38N,S4P.C,P+C8Q-R==(#T@)U9E;&EK:64@3'5K:2<["B1C;V]R9&EN
M871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4V+C@S,SHQ,C0N.#8W)UT@
M/2`G0W5L7"=-86XG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO
M;B==6R<U-BXX,S,Z-C`N-C,S)UT@/2`G16MA=&5R:6YB=7)G)SL*)&-O;W)D
M:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-38N.3`P.C,U+C@X,R==
M(#T@)U1V97(G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==
M6R<U-RXW-C<Z,3`X+C`V-R==(#T@)TMI<F5N<VLG.PHD8V]O<F1I;F%T97-;
M)U)U<W-I86X@1F5D97)A=&EO;B==6R<U-RXX-3`Z,3$T+C(S,R==(#T@)T)O
M9&%J8F\G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U
M."XT-3`Z.3(N,34P)UT@/2`G16YI<V5J<VLG.PHD8V]O<F1I;F%T97-;)U)U
M<W-I86X@1F5D97)A=&EO;B==6R<U.2XS,3<Z,SDN.3$W)UT@/2`G5F]L;V=D
M82<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4Y+C4U
M,#HQ-3`N-S@S)UT@/2`G36%G861A;B<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S4Y+C@X,SHT,BXW-3`G72`]("=4;W1<)TUA)SL*
M)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3DN.38W.C,P
M+C,P,"==(#T@)U-T+B!0971E<F)U<F<G.PHD8V]O<F1I;F%T97-;)U)U<W-I
M86X@1F5D97)A=&EO;B==6R<V,2XP,3<Z-CDN,#,S)UT@/2`G2&%N='DM36%N
M<VEJ<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V
M,2XR,S,Z-#8N-S$W)UT@/2`G2V]T;&%S)SL*)&-O;W)D:6YA=&5S6R=2=7-S
M:6%N($9E9&5R871I;VXG75LG-C$N,C4P.C<S+C4P,"==(#T@)U-U<F=U="<[
M"B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S8Q+C8X,SHU
M,RXV.#,G72`]("=5<W1<)RT@2W5L;VTG.PHD8V]O<F1I;F%T97-;)U)U<W-I
M86X@1F5D97)A=&EO;B==6R<V,2XW,3<Z-3`N.#,S)UT@/2`G4WEK='EV:V%R
M)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-C(N,#$W
M.C$R.2XW,3<G72`]("=*86MU='-K)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N
M($9E9&5R871I;VXG75LG-C0N-#$W.BTQ-S,N,C,S)UT@/2`G0G5H=&$@4')O
M=FED96YJ82<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;
M)S8T+C4P,#HT,"XW,S,G72`]("=!<FAA;F=E;%PG4VLG.PHD8V]O<F1I;F%T
M97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V-"XW.#,Z,3<W+C4V-R==(#T@
M)T%N861Y<B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;
M)S8X+CDV-SHS,RXP-3`G72`]("=-=7)M86YS:R<["B1C;V]R9&EN871E<ULG
M4G=A;F1A)UU;)RTQ+C8V-SHR.2XR-3`G72`]("=':7-E;GEI)SL*)&-O;W)D
M:6YA=&5S6R=2=V%N9&$G75LG+3$N.38W.C,P+C$Q-R==(#T@)TMI9V%L:2<[
M"B1C;V]R9&EN871E<ULG4V%I;G0@2&5L96YA)UU;)RTW+CDV-SHM,30N-#`P
M)UT@/2`G5VED92!!=V%K92!&:65L9"!!<V-E;G-I;VX@27-L86YD)SL*)&-O
M;W)D:6YA=&5S6R=386EN="!+:71T<R!A;F0@3F5V:7,G75LG,3<N,S`P.BTV
M,BXV.#,G72`]("=';VQD96X@4F]C:R<["B1C;V]R9&EN871E<ULG4V%I;G0@
M3'5C:6$G75LG,3,N-S4P.BTV,"XY-3`G72`]("=(97=A;F]R<F$@26YT97)N
M871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=386EN="!,=6-I82==
M6R<Q-"XP,3<Z+38Q+C`P,"==(#T@)U9I9VEE)SL*)&-O;W)D:6YA=&5S6R=3
M86EN="!0:65R<F4@86YD($UI<75E;&]N)UU;)S0V+C<V-SHM-38N,38W)UT@
M/2`G4V%I;G0M4&EE<G)E)SL*)&-O;W)D:6YA=&5S6R=386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<R==6R<Q,RXQ,S,Z+38Q+C(P,"==(#T@)T%R
M;F]S(%9A;&4G.PHD8V]O<F1I;F%T97-;)U-A;6]A)UU;)RTQ,RXX,#`Z+3$W
M,2XW.#,G72`]("=!<&EA("\@57!O;'4@27-L86YD)SL*)&-O;W)D:6YA=&5S
M6R=386UO82==6R<M,3,N.#$W.BTQ-S(N,#`P)UT@/2`G1F%L96]L;R!);G1L
M("\@07!I82<["B1C;V]R9&EN871E<ULG4V%O(%1O;64@86YD(%!R:6YC:7!E
M)UU;)S`N,S@S.C8N-S$W)UT@/2`G4RX@5&]M92<["B1C;V]R9&EN871E<ULG
M4V%O(%1O;64@86YD(%!R:6YC:7!E)UU;)S$N-C4P.C<N-#$W)UT@/2`G4')I
M;F-I<&4G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<Q-BXY,#`Z
M-#(N-3@S)UT@/2`G1VEZ86XG.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I
M82==6R<Q-RXT-C<Z-#<N,3$W)UT@/2`G4VAA<G5R86@G.PHD8V]O<F1I;F%T
M97-;)U-A=61I($%R86)I82==6R<Q-RXV,3<Z-#0N-#$W)UT@/2`G3F%J<F%N
M)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,3@N,C,S.C0R+C8U
M,"==(#T@)T%B:&$G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<Q
M."XS,#`Z-#(N.#`P)UT@/2`G2VAA;6ES($UU<VAA:70G.PHD8V]O<F1I;F%T
M97-;)U-A=61I($%R86)I82==6R<Q.2XY.#,Z-#(N-C$W)UT@/2`G0FES:&$G
M.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R,"XS,#`Z-#$N-C,S
M)UT@/2`G06P@0F%H82<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;
M)S(P+C4P,#HT-2XR,#`G72`]("=7861I($%L($1A=V%S<V5R($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R,2XT,S,Z,SDN-S8W
M)UT@/2`G36%K:V%H)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG
M,C$N-#@S.C0P+C4U,"==(#T@)U1A:68G.PHD8V]O<F1I;F%T97-;)U-A=61I
M($%R86)I82==6R<R,2XU,#`Z,SDN,C`P)UT@/2`G2F5D9&%H)SL*)&-O;W)D
M:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C$N-S`P.C,Y+C$X,R==(#T@)TIE
M9&1A:"!+:6YG($%B9'5L($%Z:7H@26YT97)N871I;VYA;"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C0N,34P.C,X+C`V-R==
M(#T@)UEE;F)O)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C0N
M-3`P.C0T+C,U,"==(#T@)T1A=V%D;6DG.PHD8V]O<F1I;F%T97-;)U-A=61I
M($%R86)I82==6R<R-"XU-3`Z,SDN-S`P)UT@/2`G36%D:6YA:"<["B1C;V]R
M9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(T+C<Q-SHT-BXW,S,G72`]("=2
M:7EA9&@G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-"XY,S,Z
M-#8N-S$W)UT@/2`G2VEN9R!+:&%L960@26YT97)N871I;VYA;"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C4N,S`P.C0Y+C0X
M,R==(#T@)T%L($%H<V$G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==
M6R<R-BXR,#`Z,S8N-#8W)UT@/2`G5V5J:"<["B1C;V]R9&EN871E<ULG4V%U
M9&D@07)A8FEA)UU;)S(V+C(V-SHU,"XQ-3`G72`]("=$:&%H<F%N)SL*)&-O
M;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C8N,S`P.C0S+C<V-R==(#T@
M)T=A<W-I;2<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(V+C0V
M-SHT.2XW.#,G72`]("=$86UM86TM2VEN9R!&86AD($EN=&5R;F%T:6]N86P@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(W+C0S
M,SHT,2XV.#,G72`]("=(86EL)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B
M:6$G75LG,C<N.3`P.C0U+C4S,R==(#T@)TAA9G(@06PM0F%T:6XG.PHD8V]O
M<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R."XS,3<Z-#8N,3$W)UT@/2`G
M06P@46%Y<W5M86@G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R
M."XS-C<Z,S8N-C`P)UT@/2`G5&%B=6LG.PHD8V]O<F1I;F%T97-;)U-A=61I
M($%R86)I82==6R<R.2XV,3<Z-#,N-#@S)UT@/2`G4F%F:&$G.PHD8V]O<F1I
M;F%T97-;)U-A=61I($%R86)I82==6R<R.2XW.#,Z-#`N,3`P)UT@/2`G06PM
M2F]U9B<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S,P+CDP,#HT
M,2XQ,S,G72`]("=!<F%R)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G
M75LG,S$N-#`P.C,W+C(V-R==(#T@)T=U<FEA="<["B1C;V]R9&EN871E<ULG
M4V%U9&D@07)A8FEA)UU;)S,Q+C8X,SHS."XW,S,G72`]("=4=7)A:68G.PHD
M8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,3(N-#`P.BTQ-BXW-3`G72`]("=#
M87`M4VMI<G)I;F<G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,3(N-34P
M.BTQ-BXR-C<G72`]("=::6=U:6YC:&]R)SL*)&-O;W)D:6YA=&5S6R=396YE
M9V%L)UU;)S$R+C4V-SHM,3(N,C$W)UT@/2`G2V5D;W5G;W4G.PHD8V]O<F1I
M;F%T97-;)U-E;F5G86PG75LG,3(N.#@S.BTQ-"XY-C<G72`]("=+;VQD82<[
M"B1C;V]R9&EN871E<ULG4V5N96=A;"==6R<Q,RXW-C<Z+3$S+C8X,R==(#T@
M)U1A;6)A8V]U;F1A)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$T+C$S
M,SHM,38N,#8W)UT@/2`G2V%O;&%C:R<["B1C;V]R9&EN871E<ULG4V5N96=A
M;"==6R<Q-"XV-3`Z+3$V+C(S,R==(#T@)T1I;W5R8F5L)SL*)&-O;W)D:6YA
M=&5S6R=396YE9V%L)UU;)S$T+C<S,SHM,3<N-3`P)UT@/2`G1&%K87(@+R!9
M;V9F)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$U+C,X,SHM,34N,3$W
M)UT@/2`G3&EN9W5E<F4G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,34N
M-C4P.BTQ,RXR-3`G72`]("=-871A;2<["B1C;V]R9&EN871E<ULG4V5N96=A
M;"==6R<Q-BXP-3`Z+3$V+C0U,"==(#T@)U-A:6YT+4QO=6ES)SL*)&-O;W)D
M:6YA=&5S6R=396YE9V%L)UU;)S$V+C8U,#HM,30N.38W)UT@/2`G4&]D;W(G
M.PHD8V]O<F1I;F%T97-;)U-E>6-H96QL97,G75LG+30N-C8W.C4U+C4Q-R==
M(#T@)U-E>6-H96QL97,@26YT97(M3F%T:6]N86P@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG4V5Y8VAE;&QE<R==6R<M-"XV.#,Z-34N-3,S)UT@/2`G4V5Y
M8VAE;&QE<R!);G1E<FYA=&EO;F%L($%I<G!O<G0@4F%W:6YS;VYD92!3=&%T
M:6]N)SL*)&-O;W)D:6YA=&5S6R=3:65R<F$@3&5O;F4G75LG."XV,3<Z+3$S
M+C(P,"==(#T@)TQU;F=I)SL*)&-O;W)D:6YA=&5S6R=3:6YG87!O<F4G75LG
M,2XS-C<Z,3`S+CDQ-R==(#T@)U-I;F=A<&]R92`O(%!A>6$@3&5B87(G.PHD
M8V]O<F1I;F%T97-;)U-I;F=A<&]R92==6R<Q+C,V-SHQ,#,N.3@S)UT@/2`G
M4VEN9V%P;W)E("\@0VAA;F=I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-L
M;W9A:VEA)UU;)S0X+C(P,#HQ-RXR,#`G72`]("="<F%T:7-L879A($EV86YK
M82<["B1C;V]R9&EN871E<ULG4VQO=F%K:6$G75LG-#@N,S,S.C$Y+C<S,R==
M(#T@)TQU8V5N96,G.PHD8V]O<F1I;F%T97-;)U-L;W9A:VEA)UU;)S0X+C8Q
M-SHQ-RXX,S,G72`]("=0:65S=&%N>2<["B1C;V]R9&EN871E<ULG4VQO=F%K
M:6$G75LG-#@N-C4P.C$Y+C$U,"==(#T@)U-L:6%C)SL*)&-O;W)D:6YA=&5S
M6R=3;&]V86MI82==6R<T."XV-C<Z,C$N,C$W)UT@/2`G2V]S:6-E)SL*)&-O
M;W)D:6YA=&5S6R=3;&]V86MI82==6R<T."XY,S,Z,C(N,#`P)UT@/2`G2V%M
M96YI8V$@3F%D($-I<F]C:&]U)SL*)&-O;W)D:6YA=&5S6R=3;&]V86MI82==
M6R<T.2XP-C<Z,C`N,C4P)UT@/2`G4&]P<F%D("\@5&%T<GDG.PHD8V]O<F1I
M;F%T97-;)U-L;W9E;FEA)UU;)S0U+C0X,SHQ,RXV,3<G72`]("=0;W)T;W)O
M>B`O(%-E8V]V;&IE)SL*)&-O;W)D:6YA=&5S6R=3;&]V96YI82==6R<T-2XU
M,3<Z,3,N-38W)UT@/2`G4&]R=&]R;WHG.PHD8V]O<F1I;F%T97-;)U-L;W9E
M;FEA)UU;)S0V+C(Q-SHQ-"XT.#,G72`]("=,:G5B;&IA;F$@+R!"<FYI:R<[
M"B1C;V]R9&EN871E<ULG4VQO=F5N:6$G75LG-#8N,C$W.C$T+C0X,R==(#T@
M)TQJ=6)L:F%N82`O($)R;FEK)SL*)&-O;W)D:6YA=&5S6R=3;&]V96YI82==
M6R<T-BXT.#,Z,34N-C@S)UT@/2`G36%R:6)O<B`O(%-L:79N:6-A)SL*)&-O
M;W)D:6YA=&5S6R=3;&]V96YI82==6R<T-BXV-3`Z,38N,3@S)UT@/2`G375R
M<VMA(%-O8F]T82<["B1C;V]R9&EN871E<ULG4V]L;VUO;B!)<VQA;F1S)UU;
M)RTQ,"XW,#`Z,38U+C@P,"==(#T@)U-A;G1A($-R=7HG.PHD8V]O<F1I;F%T
M97-;)U-O;&]M;VX@27-L86YD<R==6R<M."XS,S,Z,34W+C(V-R==(#T@)TUU
M;F1A)SL*)&-O;W)D:6YA=&5S6R=3;VQO;6]N($ES;&%N9',G75LG+3DN-#$W
M.C$V,"XP-3`G72`]("=(;VYI87)A("\@2&5N9&5R<V]N)SL*)&-O;W)D:6YA
M=&5S6R=3;VUA;&EA)UU;)S$P+C0Q-SHT-2XP,3<G72`]("="97)B97)A)SL*
M)&-O;W)D:6YA=&5S6R=3;VUA;&EA)UU;)S(N,#,S.C0U+C,U,"==(#T@)TUO
M9V%D:7-C:6\G.PHD8V]O<F1I;F%T97-;)U-O;6%L:6$G75LG-"XW,#`Z-#4N
M,C$W)UT@/2`G0F5L970@565N)SL*)&-O;W)D:6YA=&5S6R=3;VUA;&EA)UU;
M)SDN-3`P.C0T+C`X,R==(#T@)TAA<F=E:7-A)SL*)&-O;W)D:6YA=&5S6R=3
M;VUA;&EA)UU;)SDN-3`P.C0U+C4V-R==(#T@)T)U<F%O)SL*)&-O;W)D:6YA
M=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(S+C<R-CHR-RXV.#@G72`]("=%;&QI
M<W)A<R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR,RXX-C<Z
M,CDN-#4P)UT@/2`G4&EE=&5R<V)U<F<G.PHD8V]O<F1I;F%T97-;)U-O=71H
M($%F<FEC82==6R<M,C,N.3,S.C,Q+C$U,"==(#T@)U!H86QA8F]R=V$G.PHD
M8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C0N,S8W.C,Q+C`S,R==
M(#T@)TAO961S<')U:70G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==
M6R<M,C4N-#,S.C,P+CDX,R==(#T@)TYE;'-P<G5I="<["B1C;V]R9&EN871E
M<ULG4V]U=&@@069R:6-A)UU;)RTR-2XW,S,Z,C@N,3@S)UT@/2`G4')E=&]R
M:6$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C4N-S@S.C(U
M+C4S,R==(#T@)TUM86)A=&AO($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-O
M=71H($%F<FEC82==6R<M,C4N.#,S.C(X+C(Q-R==(#T@)U=A=&5R:VQO;V8@
M3&UB)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(U+CDQ-SHR
M."XR,3<G72`]("=0<F5T;W)I82!)<F5N92<["B1C;V]R9&EN871E<ULG4V]U
M=&@@069R:6-A)UU;)RTR-BXP-C<Z,S`N,3$W)UT@/2`G0V%R;VQI;F$G.PHD
M8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C8N,3,S.C(X+C(S,R==
M(#T@)TIA;B!3;75T<R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;
M)RTR-BXX-C<Z,C8N-S$W)UT@/2`G2VQE<FMS9&]R<"<["B1C;V]R9&EN871E
M<ULG4V]U=&@@069R:6-A)UU;)RTR-BXY-3`Z,C0N-C,S)UT@/2`G5G)Y8G5R
M9R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-RXR-C<Z,C@N
M-3`P)UT@/2`G1G)A;FMF;W)T)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I
M8V$G75LG+3(X+C`P,#HR-BXV-C<G72`]("=796QK;VTG.PHD8V]O<F1I;F%T
M97-;)U-O=71H($%F<FEC82==6R<M,C@N,C4P.C(X+C,S,R==(#T@)T)E=&AL
M96AE;2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG
M+3(X+C0P,#HR,2XR-C<G72`]("=5<&EN9W1O;B<["B1C;V]R9&EN871E<ULG
M4V]U=&@@069R:6-A)UU;)RTR."XU-C<Z,38N-3,S)UT@/2`G06QE>&%N9&5R
M($)A>2<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR."XU-C<Z
M,CDN-S8W)UT@/2`G3&%D>7-M:71H)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!
M9G)I8V$G75LG+3(X+C@P,#HR-"XW-C<G72`]("=+:6UB97)L97DG.PHD8V]O
M<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C@N.#`P.C,R+C$P,"==(#T@
M)U)I8VAA<F0@0F%Y)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG
M+3(Y+C$P,#HR-BXS,#`G72`]("=";&]E;69O;G1E:6X@2BX@0BX@32X@2&5R
M='IO9R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR.2XV-C<Z
M,3<N.#8W)UT@/2`G4W!R:6YG8F]K)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!
M9G)I8V$G75LG+3(Y+CDV-SHS,"XY-3`G72`]("=$=7)B86X@3&]U:7,@0F]T
M:&$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S`N-C,S.C(S
M+CDQ-R==(#T@)T1E($%A<B<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A
M)UU;)RTS,"XV-3`Z,C0N,#$W)UT@/2`G1&4@06%R)SL*)&-O;W)D:6YA=&5S
M6R=3;W5T:"!!9G)I8V$G75LG+3,P+C<Q-SHR-BXW,3<G72`]("=!;&EW86P@
M3F]R=&@G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S$N-#8W
M.C$Y+C<V-R==(#T@)T-A;'9I;FEA)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!
M9G)I8V$G75LG+3,Q+C0X,SHR-2XP,S,G72`]("=-:61D96QB=7)G)SL*)&-O
M;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,Q+C4S,SHR."XV-C<G72`]
M("=5;71A=&$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S$N
M-C,S.C(Y+C4U,"==(#T@)U!O<G0@4W0@2F]H;G,G.PHD8V]O<F1I;F%T97-;
M)U-O=71H($%F<FEC82==6R<M,S$N-C8W.C$X+C4P,"==(#T@)U9R961E;F1A
M;"<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,2XY,#`Z,C8N
M.#8W)UT@/2`G475E96YS=&]W;B<["B1C;V]R9&EN871E<ULG4V]U=&@@069R
M:6-A)UU;)RTS,2XY,3<Z,C$N-3$W)UT@/2`G1G)A<V5R8G5R9R<["B1C;V]R
M9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,BXR-3`Z,C0N-3,S)UT@/2`G
M1W)A869F(%)E:6YE="<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;
M)RTS,BXS-3`Z,C(N-3@S)UT@/2`G0F5A=69O<G0@5V5S="<["B1C;V]R9&EN
M871E<ULG4V]U=&@@069R:6-A)UU;)RTS,BXY-C<Z,3@N,38W)UT@/2`G3&%N
M9V5B86%N=V5G)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,S
M+C`S,SHR-RXX,S,G72`]("=%87-T($QO;F1O;B<["B1C;V]R9&EN871E<ULG
M4V]U=&@@069R:6-A)UU;)RTS,RXU-C<Z,C(N,C$W)UT@/2`G3W5D='-H;V]R
M;B<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,RXY.#,Z,3@N
M-C`P)UT@/2`G0V%P92!4;W=N($0N($8N($UA;&%N)SL*)&-O;W)D:6YA=&5S
M6R=3;W5T:"!!9G)I8V$G75LG+3,S+CDX,SHR-2XV,#`G72`]("=0;W)T($5L
M:7IA8F5T:"<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS-"XP
M,#`Z,C(N,S@S)UT@/2`G1V5O<F=E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)U-O=71H($%F<FEC82==6R<M,S0N,3@S.C(R+C$U,"==(#T@)TUO<W-E;"!"
M87D@0V%P92!386EN="!";&%I>F4G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F
M<FEC82==6R<M,S<N,#4P.BTQ,BXS,3<G72`]("=4<FES=&%N($1A($-U;FAA
M)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+30P+C,U,#HM.2XX
M.#,G72`]("=';W5G:"!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F
M<FEC82==6R<M-#8N.#@S.C,W+C@V-R==(#T@)TUA<FEO;B!)<VQA;F0G.PHD
M8V]O<F1I;F%T97-;)U-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S)UU;)RTU,2XX,3<Z+34X+C0U,"==(#T@)TUO=6YT(%!L
M96%S86YT($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S(W+C@Q
M-SHM,3<N.#@S)UT@/2`G2&EE<G)O("\@065R;W!U97)T;R<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG,C<N.3,S.BTQ-2XS.#,G72`]("=,87,@4&%L;6%S
M($1E($=R86X@0V%N87)I82`O($=A;F1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I
M;B==6R<R."XP-3`Z+3$V+C4V-R==(#T@)U1E;F5R:69E(%-U<B<["B1C;V]R
M9&EN871E<ULG4W!A:6XG75LG,C@N-#4P.BTQ,RXX-C<G72`]("=&=65R=&5V
M96YT=7)A("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG
M,C@N-#8W.BTQ-BXS,3<G72`]("=496YE<FEF92`O($QO<R!2;V1E;W,G.PHD
M8V]O<F1I;F%T97-;)U-P86EN)UU;)S(X+C8Q-SHM,3<N-S4P)UT@/2`G3&$@
M4&%L;6$@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<R
M."XY-3`Z+3$S+C8P,"==(#T@)TQA;GIA<F]T92`O($%E<F]P=65R=&\G.PHD
M8V]O<F1I;F%T97-;)U-P86EN)UU;)S,U+C(X,SHM,BXY-3`G72`]("=-96QI
M;&QA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-BXV-3`Z+38N,S4P)UT@
M/2`G4F]T82<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S8N-C8W.BTT+C0X
M,R==(#T@)TUA;&%G82`O($%E<F]P=65R=&\G.PHD8V]O<F1I;F%T97-;)U-P
M86EN)UU;)S,V+C<U,#HM-BXP-C<G72`]("=*97)E>B!$92!,82!&<F]N=&5R
M86%E<F]P=65R=&\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,V+C@U,#HM
M,BXS.#,G72`]("=!;&UE<FEA("\@065R;W!U97)T;R<["B1C;V]R9&EN871E
M<ULG4W!A:6XG75LG,S<N,34P.BTU+C8Q-R==(#T@)TUO<F]N($1E($QA($9R
M;VYT97)A)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-RXQ.#,Z+3,N-S@S
M)UT@/2`G1W)A;F%D82`O($%E<F]P=65R=&\G.PHD8V]O<F1I;F%T97-;)U-P
M86EN)UU;)S,W+C0Q-SHM-2XY,#`G72`]("=3979I;&QA("\@4V%N(%!A8FQO
M)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-RXW.#,Z+3`N.#`P)UT@/2`G
M375R8VEA("\@4V%N($IA=FEE<B<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG
M,S<N.#4P.BTT+C@U,"==(#T@)T-O<F1O8F$@+R!!97)O<'5E<G1O)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<S-RXY-3`Z+3$N,C,S)UT@/2`G375R8VEA
M("\@06QC86YT87)I;&QA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S."XR
M.#,Z+3`N-34P)UT@/2`G06QI8V%N=&4@+R!%;"!!;'1E="<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG,S@N-3$W.BTU+C$Q-R==(#T@)TAI;F]J;W-A($1E
M;"!$=7%U92<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S@N.#8W.C$N,S@S
M)UT@/2`G26)I>F$@+R!%<R!#;V1O;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN
M)UU;)S,X+C@X,SHM-BXX,3<G72`]("="861A:F]Z("\@5&%L879E<F$@3&$@
M4F5A;"<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S@N.34P.BTQ+C@U,"==
M(#T@)T%L8F%C971E("\@3&]S($QL86YO<R<["B1C;V]R9&EN871E<ULG4W!A
M:6XG75LG,SDN-3`P.BTP+C0V-R==(#T@)U9A;&5N8VEA("\@065R;W!U97)T
M;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,SDN-34P.C(N-S,S)UT@/2`G
M4&%L;6$@1&4@36%L;&]R8V$@+R!3;VX@4V%N($IU86XG.PHD8V]O<F1I;F%T
M97-;)U-P86EN)UU;)S,Y+C@V-SHT+C(S,R==(#T@)TUE;F]R8V$@+R!-86AO
M;B<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#`N,S`P.BTS+C<Q-R==(#T@
M)TUA9')I9"`O($=E=&%F92<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#`N
M,S@S.BTS+C<X,R==(#T@)TUA9')I9"`O($-U871R;R!6:65N=&]S)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XT-3`Z+3,N-34P)UT@/2`G36%D<FED
M("\@0F%R86IA<R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#`N-#@S.BTS
M+C0U,"==(#T@)TUA9')I9"`O(%1O<G)E:F]N)SL*)&-O;W)D:6YA=&5S6R=3
M<&%I;B==6R<T,"XV-3`Z+3,N-S,S)UT@/2`G36%D<FDM0V]L;65N87(G.PHD
M8V]O<F1I;F%T97-;)U-P86EN)UU;)S0P+CDS,SHM,2XS,#`G72`]("=#86QA
M;6]C:&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0P+CDU,#HM-2XU,#`G
M72`]("=386QA;6%N8V$@+R!-871A8V%N)SL*)&-O;W)D:6YA=&5S6R=3<&%I
M;B==6R<T,2XQ-3`Z,2XQ-C<G72`]("=2975S("\@065R;W!U97)T;R<["B1C
M;V]R9&EN871E<ULG4W!A:6XG75LG-#$N,C@S.C(N,#8W)UT@/2`G0F%R8V5L
M;VYA("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#$N
M-C8W.BTQ+C`Q-R==(#T@)UIA<F%G;WIA("\@065R;W!U97)T;R<["B1C;V]R
M9&EN871E<ULG4W!A:6XG75LG-#$N-S$W.BTT+C@U,"==(#T@)U9A;&QA9&]L
M:60@+R!6:6QL86YU8FQA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,2XY
M,#`Z,BXW-C<G72`]("='97)O;F$@+R!#;W-T82!"<F%V82<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG-#(N,C$W.BTX+C8S,R==(#T@)U9I9V\@+R!096EN
M861O<B<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#(N,S8W.BTS+C8S,R==
M(#T@)T)U<F=O<R`O(%9I;&QA9G)I82<["B1C;V]R9&EN871E<ULG4W!A:6XG
M75LG-#(N-#4P.BTR+C,S,R==(#T@)TQO9W)O;F\@+R!!9V]N8VEL;&\G.PHD
M8V]O<F1I;F%T97-;)U-P86EN)UU;)S0R+C4X,SHM-2XV-3`G72`]("=,96]N
M("\@5FER9V5N($1E;"!#86UI;F\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;
M)S0R+C<V-SHM,2XV,S,G72`]("=086UP;&]N82`O($YO86EN)SL*)&-O;W)D
M:6YA=&5S6R=3<&%I;B==6R<T,BXX.#,Z+3(N-S$W)UT@/2`G5FET;W)I82<[
M"B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#(N.3`P.BTX+C0S,R==(#T@)U-A
M;G1I86=O("\@3&%B86-O;&QA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T
M,RXS,#`Z+3(N.3,S)UT@/2`G0FEL8F%O("\@4V]N9&EC82<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG-#,N,S`P.BTX+C,X,R==(#T@)TQA($-O<G5N82`O
M($%L=F5D<F\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0S+C,U,#HM,2XX
M,#`G72`]("=386X@4V5B87-T:6%N("\@1G5E;G1E<G)A8FEA)SL*)&-O;W)D
M:6YA=&5S6R=3<&%I;B==6R<T,RXT,S,Z+3,N.#$W)UT@/2`G4V%N=&%N9&5R
M("\@4&%R87EA<R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#,N-34P.BTV
M+C`S,R==(#T@)T%S='5R:6%S("\@079I;&5S)SL*)&-O;W)D:6YA=&5S6R=3
M<FD@3&%N:V$G75LG-BXX,3<Z-SDN.#@S)UT@/2`G4F%T;6%L86YA)SL*)&-O
M;W)D:6YA=&5S6R=3<FD@3&%N:V$G75LG-RXQ-C<Z-SDN.#@S)UT@/2`G2V%T
M=6YA>6%K92<["B1C;V]R9&EN871E<ULG4W)I($QA;FMA)UU;)S<N-S$W.C@Q
M+C<P,"==(#T@)T)A='1I8V%L;V$G.PHD8V]O<F1I;F%T97-;)U-R:2!,86YK
M82==6R<X+C,S,SHX,"XT,3<G72`]("=!;G5R861H87!U<F$G.PHD8V]O<F1I
M;F%T97-;)U-R:2!,86YK82==6R<X+C4X,SHX,2XR-3`G72`]("=4<FEN8V]M
M86QE92<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3$N,#`P.C(Y+C<Q-R==
M(#T@)TMA9'5G;&DG.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$Q+C<U,#HS
M,BXW.#,G72`]("=296YK)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q,2XW
M.#,Z,S0N,S@S)UT@/2`G1&%M87II;F4G.PHD8V]O<F1I;F%T97-;)U-U9&%N
M)UU;)S$R+C`U,#HR-"XX.#,G72`]("=.>6%L82<["B1C;V]R9&EN871E<ULG
M4W5D86XG75LG,3,N,38W.C,P+C(S,R==(#T@)T5L($]B96ED)SL*)&-O;W)D
M:6YA=&5S6R=3=61A;B==6R<Q,RXQ-C<Z,S(N-C8W)UT@/2`G2V]S=&DG.PHD
M8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$S+C0X,SHR,BXT-3`G72`]("='96YE
M:6YA)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q,RXU-3`Z,S,N-C$W)UT@
M/2`G4V5N;F%R)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q,RXV,3<Z,C4N
M,S,S)UT@/2`G16P@1F%S:&5R)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q
M-"XP,S,Z,S4N-#`P)UT@/2`G1V5D87)E9B<["B1C;V]R9&EN871E<ULG4W5D
M86XG75LG,34N-#8W.C,V+C0P,"==(#T@)TMA<W-A;&$G.PHD8V]O<F1I;F%T
M97-;)U-U9&%N)UU;)S$U+C8P,#HS,BXU-3`G72`]("=+:&%R=&]U;2<["B1C
M;V]R9&EN871E<ULG4W5D86XG75LG,3<N-S`P.C,S+CDV-R==(#T@)T%T8F%R
M82<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3DN,38W.C,P+C0X,R==(#T@
M)T1O;F=O;&$G.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$Y+C4X,SHS-RXR
M,3<G72`]("=0;W)T(%-U9&%N)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<R
M,2XX,3<Z,S$N-#@S)UT@/2`G5V%D:2!(86QF82<["B1C;V]R9&EN871E<ULG
M4W5D86XG75LG-"XX-C<Z,S$N-C`P)UT@/2`G2G5B82<["B1C;V]R9&EN871E
M<ULG4W5D86XG75LG.2XU-3`Z,S$N-C4P)UT@/2`G36%L86MA;"<["B1C;V]R
M9&EN871E<ULG4W5R:6YA;64G75LG-2XT-3`Z+34U+C(P,"==(#T@)UIA;F1E
M<FEJ)SL*)&-O;W)D:6YA=&5S6R=3=V%Z:6QA;F0G75LG+3(V+C4S,SHS,2XS
M,#`G72`]("=-86YZ:6YI("\@36%T<V%P82!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=3=V5D96XG75LG-34N-34P.C$S+C,V-R==(#T@)TUA;&UO("\@4W1U
M<G5P)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-34N.3$W.C$T+C`X,R==
M(#T@)TMR:7-T:6%N<W1A9"`O($5V97)O9"<["B1C;V]R9&EN871E<ULG4W=E
M9&5N)UU;)S4V+C`X-3HQ,RXR,#<G72`]("=,:G5N9V)Y:&5D+"!,:G5N9V)Y
M:&5D("A35T4M049"*2<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4V+C(V
M-SHQ-2XR.#,G72`]("=2;VYN96)Y)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG
M75LG-38N,S`P.C$R+C@U,"==(#T@)T%N9V5L:&]L;2<["B1C;V]R9&EN871E
M<ULG4W=E9&5N)UU;)S4V+C8X,SHQ,BXX,S,G72`]("=(86QM<W1A9"!3=V5D
M:7-H($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG
M-38N-S,S.C$V+C,P,"==(#T@)TMA;&UA<B<["B1C;V]R9&EN871E<ULG4W=E
M9&5N)UU;)S4V+C@U,#HQ-"XX,S,G72`]("=687AJ;R<["B1C;V]R9&EN871E
M<ULG4W=E9&5N)UU;)S4W+C,P,#HQ-"XQ,S,G72`]("=(86=S:'5L="<["B1C
M;V]R9&EN871E<ULG4W=E9&5N)UU;)S4W+C4Q-SHQ-2XX,S,G72`]("=(=6QT
M<V9R960@4W=E9&ES:"!!:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG
M4W=E9&5N)UU;)S4W+C8V-SHQ,BXS,#`G72`]("=';W1E8F]R9R`O($QA;F1V
M971T97(G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U-RXV-C<Z,3@N,S4P
M)UT@/2`G5FES8GD@1FQY9W!L871S)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG
M75LG-3<N-S8W.C$T+C`X,R==(#T@)TIO;FMO<&EN9R!&;'EG<&QA=',G.PHD
M8V]O<F1I;F%T97-;)U-W961E;B==6R<U-RXW.#,Z,3$N.#@S)UT@/2`G1V]T
M96)O<F<@+R!3879E)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3@N-#`P
M.C$U+C4Q-R==(#T@)TQI;FMO<&EN9R`O($UA;&UE;B<["B1C;V]R9&EN871E
M<ULG4W=E9&5N)UU;)S4X+C0S,SHQ,BXW,#`G72`]("=3871E;F%S)SL*)&-O
M;W)D:6YA=&5S6R=3=V5D96XG75LG-3@N-#4P.C$S+CDV-R==(#T@)U-K;W9D
M92!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U."XU.#,Z
M,38N,34P)UT@/2`G3F]R<FMO<&EN9R<["B1C;V]R9&EN871E<ULG4W=E9&5N
M)UU;)S4Y+C,U,#HQ-RXY-3`G72`]("=3=&]C:VAO;&T@+R!"<F]M;6$G.PHD
M8V]O<F1I;F%T97-;)U-W961E;B==6R<U.2XS-C<Z,3,N-#8W)UT@/2`G2V%R
M;'-T860@1FQY9W!L871S)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3DN
M-3@S.C$V+C8S,R==(#T@)U9A<W1E<F%S("\@2&%S<VQO)SL*)&-O;W)D:6YA
M=&5S6R=3=V5D96XG75LG-3DN-C4P.C$W+CDU,"==(#T@)U-T;V-K:&]L;2`O
M($%R;&%N9&$G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U.2XX.#,Z,3<N
M-C`P)UT@/2`G57!P<V%L82<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8P
M+C0S,SHQ-2XU,3<G72`]("=";W)L86YG92<["B1C;V]R9&EN871E<ULG4W=E
M9&5N)UU;)S8P+C8P,#HQ-BXY-3`G72`]("='879L92`O(%-A;F1V:6ME;B!!
M:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8Q+C(V
M-SHQ-RXQ,#`G72`]("=3;V1E<FAA;6XG.PHD8V]O<F1I;F%T97-;)U-W961E
M;B==6R<V,BXU,S,Z,3<N-#4P)UT@/2`G4W5N9'-V86QL+4AA<FYO<V%N9"!&
M;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<V,RXP-3`Z,3<N
M-S8W)UT@/2`G2W)A;69O<G,@1FQY9W!L871S)SL*)&-O;W)D:6YA=&5S6R=3
M=V5D96XG75LG-C,N,3@S.C$T+C4P,"==(#T@)T]S=&5R<W5N9"`O($9R;W-O
M;B<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8S+C0P,#HQ."XY-C<G72`]
M("=/<FYS:V]L9'-V:6L@06ER<&]R="<["B1C;V]R9&EN871E<ULG4W=E9&5N
M)UU;)S8S+C@P,#HR,"XR.#,G72`]("=5;65A($9L>6=P;&%T<R<["B1C;V]R
M9&EN871E<ULG4W=E9&5N)UU;)S8T+C8S,SHR,2XP.#,G72`]("=3:V5L;&5F
M=&5A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<V-"XY-C<Z
M,3<N-S`P)UT@/2`G1W5N;F%R;B<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;
M)S8U+C4U,#HR,BXQ,S,G72`]("=,=6QE82`O($MA;&QA>"<["B1C;V]R9&EN
M871E<ULG4W=E9&5N)UU;)S8U+C@V-SHR,"XQ,S,G72`]("=6:61S96PG.PHD
M8V]O<F1I;F%T97-;)U-W961E;B==6R<V-BXV,S,Z,3DN-C4P)UT@/2`G2F]K
M:VUO:VLG.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<V-RXQ-3`Z,C`N-C4P
M)UT@/2`G1V%L;&EV87)E)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C<N
M.#$W.C(P+C,S,R==(#T@)TMI<G5N82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=3=VET>F5R;&%N9"==6R<T-BXP,#`Z."XY-C<G72`]("=,=6=A;F\G.PHD
M8V]O<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0V+C(Q-SHW+C,S,R==(#T@
M)U-I;VXG.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0V+C(U,#HV
M+C$S,R==(#T@)T=E;F5V92U#;VEN=')I;B<["B1C;V]R9&EN871E<ULG4W=I
M='IE<FQA;F0G75LG-#8N-34P.C8N-C$W)UT@/2`G3&%U<V%N;F4G.PHD8V]O
M<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0V+C@Q-SHV+CDU,"==(#T@)U!A
M>65R;F4G.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0W+C`P,#HV
M+CDU,"==(#T@)TYE=6-H871E;"<["B1C;V]R9&EN871E<ULG4W=I='IE<FQA
M;F0G75LG-#<N,3@Q.C<N-#$V)UT@/2`G1W)E;F-H96XG.PHD8V]O<F1I;F%T
M97-;)U-W:71Z97)L86YD)UU;)S0W+C0X,SHX+C4S,R==(#T@)UIU<FEC:"U+
M;&]T96XG.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0W+C0X-3HY
M+C4V,B==(#T@)U-A:6YT($=A;&QE;BU!;'1E;G)H96EN)SL*)&-O;W)D:6YA
M=&5S6R=3>7)I86X@07)A8B!297!U8FQI8R==6R<S,RXT,3<Z,S8N-3$W)UT@
M/2`G1&%M87-C=7,@26YT+B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3>7)I
M86X@07)A8B!297!U8FQI8R==6R<S-"XU-3`Z,S@N,S`P)UT@/2`G4&%L;7ER
M82<["B1C;V]R9&EN871E<ULG4WER:6%N($%R86(@4F5P=6)L:6,G75LG,S4N
M,S$W.C0P+C$U,"==(#T@)T1E:7(@17IZ;W(G.PHD8V]O<F1I;F%T97-;)U-Y
M<FEA;B!!<F%B(%)E<'5B;&EC)UU;)S,U+C4S,SHS-2XW-C<G72`]("=,871T
M86MI82<["B1C;V]R9&EN871E<ULG4WER:6%N($%R86(@4F5P=6)L:6,G75LG
M,S8N,3@S.C,W+C(P,"==(#T@)T%L97!P;R!);G1E<FYA=&EO;F%L($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)U-Y<FEA;B!!<F%B(%)E<'5B;&EC)UU;)S,W
M+C`U,#HT,2XR,3<G72`]("=+86UI<VAL:2<["B1C;V]R9&EN871E<ULG5&%I
M=V%N)UU;)S(P+C8V-SHQ,38N-S$W)UT@/2`G1&]N9W-H82<["B1C;V]R9&EN
M871E<ULG5&%I=V%N)UU;)S(Q+CDS,SHQ,C`N.#,S)UT@/2`G2&5N9V-H=6XG
M.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R,BXP,S,Z,3(Q+C4U,"==(#T@
M)TQA;B!9=2<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(R+C0Q-SHQ,C`N
M-34P)UT@/2`G0VAI82!4=6YG)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG
M,C(N-#8W.C$R,"XT,S,G72`]("=$;VYG9V%N9R<["B1C;V]R9&EN871E<ULG
M5&%I=V%N)UU;)S(R+C4X,SHQ,C`N,S4P)UT@/2`G2V%O:'-I=6YG($EN=&5R
M;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(R
M+C8X,SHQ,C`N-#8W)UT@/2`G4&EN9W1U;F<@4V]U=&@@06ER($9O<F-E($)A
M<V4G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R,BXW,#`Z,3(P+C0X,R==
M(#T@)U!I;F=T=6YG($YO<G1H($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA
M=&5S6R=486EW86XG75LG,C(N-S@S.C$R,"XR-C<G72`]("=+86YG<VAA;B!4
M=RU!9F(G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R,BXX,#`Z,3(Q+C$X
M,R==(#T@)T-H:6AH86YG(%1W+4%F8B<["B1C;V]R9&EN871E<ULG5&%I=V%N
M)UU;)S(R+CDU,#HQ,C`N,C`P)UT@/2`G5&%I;F%N(%1W+4%F8B<["B1C;V]R
M9&EN871E<ULG5&%I=V%N)UU;)S(S+C(V-SHQ,3DN-C8W)UT@/2`G1&]N9W-H
M:2<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(S+C0V-SHQ,C`N,S@S)UT@
M/2`G0VAI87EI(%1W+4%F8B<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(S
M+C4X,SHQ,3DN-C$W)UT@/2`G36%K=6YG($%B)SL*)&-O;W)D:6YA=&5S6R=4
M86EW86XG75LG,C0N,#,S.C$R,2XV,3<G72`]("=(=6QI96X@06(G.PHD8V]O
M<F1I;F%T97-;)U1A:7=A;B==6R<R-"XQ.#,Z,3(P+C8U,"==(#T@)U1A:6-H
M=6YG(%1W+4%F8B<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(T+C(V-SHQ
M,C`N-C$W)UT@/2`G5W5C:&EA($]B<V5R=F%T;W)Y)SL*)&-O;W)D:6YA=&5S
M6R=486EW86XG75LG,C0N-#,S.C$Q."XS-C<G72`]("=#:&EN;65M("\@4VAA
M=&]U($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG
M,C0N-S4P.C$R,2XW-C<G72`]("=);&%N)SL*)&-O;W)D:6YA=&5S6R=486EW
M86XG75LG,C0N.#$W.C$R,"XY,S,G72`]("=(<VEN8VAU(%1W+4%F8B<["B1C
M;V]R9&EN871E<ULG5&%I=V%N)UU;)S(T+CDS,SHQ,C$N,S`P)UT@/2`G4&$@
M2W5E:2`O($)A:W5A:2<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(U+C`V
M-SHQ,C$N,C,S)UT@/2`G5&%O>75A;B!!8B`](#4X.38U,"<["B1C;V]R9&EN
M871E<ULG5&%I=V%N)UU;)S(U+C`V-SHQ,C$N-34P)UT@/2`G4W5N9W-H86X@
M+R!486EP96DG.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R-2XP.#,Z,3(Q
M+C(Q-R==(#T@)T-H:6%N9R!+86D@4VAE:R<["B1C;V]R9&EN871E<ULG5&%I
M=V%N)UU;)S(V+C$V-SHQ,3DN.3,S)UT@/2`G36%Z=2<["B1C;V]R9&EN871E
M<ULG5&%J:6MI<W1A;B==6R<S."XU-3`Z-C@N-S@S)UT@/2`G1'5S:&%N8F4G
M.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G
M75LG+3$N,S,S.C,Q+C@Q-R==(#T@)T)U:V]B82<["B1C;V]R9&EN871E<ULG
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M,2XU,#`Z,S,N.#`P
M)UT@/2`G375S;VUA)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F)UU;)RTQ,"XR-C<Z-#`N,3@S)UT@/2`G371W87)A)SL*
M)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;
M)RTQ,"XS-3`Z,S@N-S4P)UT@/2`G3F%C:&EN9W=E82<["B1C;V]R9&EN871E
M<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M,3`N-C@S.C,U
M+C4X,R==(#T@)U-O;F=E82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B==6R<M,BXT-C<Z,S(N.3$W)UT@/2`G37=A;GIA
M)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F
M)UU;)RTS+C,S,SHS-BXV,3<G72`]("=!<G5S:&$G.PHD8V]O<F1I;F%T97-;
M)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3,N,S4P.C,W+C,S
M,R==(#T@)TUO<VAI)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F)UU;)RTS+C0Q-SHS-RXP-C<G72`]("=+:6QI;6%N:F%R
M;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F)UU;)RTT+C`X,SHS-RXW,3<G72`]("=386UE)SL*)&-O;W)D
M:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTT+C@X
M,SHR.2XV,S,G72`]("=+:6=O;6$G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8G75LG+30N.#@S.C,X+C(X,R==(#T@)TUO
M;6)O)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F)UU;)RTU+C`X,SHS,BXX,S,G72`]("=486)O<F$@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M
M-2XP.#,Z,SDN,#8W)UT@/2`G5&%N9V$G.PHD8V]O<F1I;F%T97-;)U1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+34N,C4P.C,Y+C@Q-R==(#T@
M)U!E;6)A("\@2V%R=6UE($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+38N,38W.C,U+C<V-R==(#T@
M)T1O9&]M82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9B==6R<M-BXR,3<Z,SDN,C$W)UT@/2`G6F%N>FEB87(@+R!+:7-A
M=6YI)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F)UU;)RTV+C@S,SHS-RXV-3`G72`]("=-;W)O9V]R;R<["B1C;V]R9&EN
M871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M-BXX-C<Z
M,SDN,C`P)UT@/2`G1&%R($5S(%-A;&%A;2!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTW+C8V-SHS
M-2XW-3`G72`]("=)<FEN9V$G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8G75LG+3@N.3,S.C,S+C0V-R==(#T@)TUB97EA
M)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q,"XT.#,Z.3DN,3@S)UT@
M/2`G0VAU;7!H;VXG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$Q+C@S
M,SHY.2XX,S,G72`]("=0<F%C:'5A<"!+:&ER:6MH86XG.PHD8V]O<F1I;F%T
M97-;)U1H86EL86YD)UU;)S$R+C4X,SHY.2XY-3`G72`]("=(=6$@2&EN)SL*
M)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q,BXV,#`Z,3`R+C$Q-R==(#T@
M)T-H86YT:&%B=7)I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q,BXV
M,S,Z,3`Q+C,U,"==(#T@)U)A>6]N9R<["B1C;V]R9&EN871E<ULG5&AA:6QA
M;F0G75LG,3,N,34P.C$P,"XP-C<G72`]("=0:&5T8VAA8G5R:2<["B1C;V]R
M9&EN871E<ULG5&AA:6QA;F0G75LG,3,N,S8W.C$P,"XY.#,G72`]("=#:&]N
M($)U<FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$S+CDQ-SHQ,#`N
M-C`P)UT@/2`G1&]N($UU86YG)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==
M6R<Q-"XP,3<Z.3DN-3,S)UT@/2`G2V%N8VAA;F%B=7)I)SL*)&-O;W)D:6YA
M=&5S6R=4:&%I;&%N9"==6R<Q-"XP-3`Z,3`Q+C,V-R==(#T@)U!R86-H:6X@
M0G5R:2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,30N.38W.C$P,BXP
M.#,G72`]("=.86MH;VX@4F%T8VAA<VEM82<["B1C;V]R9&EN871E<ULG5&AA
M:6QA;F0G75LG,34N,C4P.C$P-"XX-C<G72`]("=58F]N(%)A=&-H871H86YI
M)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-2XX,#`Z,3`P+C$V-R==
M(#T@)TYA:VAO;B!387=A;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG
M,34N.#`P.C$P,BXP,S,G72`]("=#:&%I>6%P:'5M)SL*)&-O;W)D:6YA=&5S
M6R=4:&%I;&%N9"==6R<Q-BXP-3`Z,3`S+C8X,R==(#T@)U)O:2!%="<["B1C
M;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,38N-#,S.C$P,BXX,S,G72`]("=+
M:&]N($MA96XG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$V+C4S,SHQ
M,#0N-S$W)UT@/2`G375K9&%H86XG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S$V+C8V-SHY."XU-3`G72`]("=-864@4V]T)SL*)&-O;W)D:6YA=&5S
M6R=4:&%I;&%N9"==6R<Q-BXW.#,Z,3`P+C(V-R==(#T@)U!H:71S86YU;&]K
M)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-BXX.#,Z.3DN,34P)UT@
M/2`G5&%K)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-RXQ-3`Z,3`T
M+C$S,R==(#T@)U-A:V]N($YA:VAO;B<["B1C;V]R9&EN871E<ULG5&AA:6QA
M;F0G75LG,3<N,S@S.C$P,BXX,#`G72`]("=59&]N(%1H86YI)SL*)&-O;W)D
M:6YA=&5S6R=4:&%I;&%N9"==6R<Q-RXT,3<Z,3`T+C<X,R==(#T@)TYA:VAO
M;B!0:&%N;VTG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$W+C0U,#HQ
M,#$N-S,S)UT@/2`G3&]E:2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG
M,3<N-C$W.C$P,"XQ,#`G72`]("=5='1A<F%D:70G.PHD8V]O<F1I;F%T97-;
M)U1H86EL86YD)UU;)S$W+C@V-SHQ,#(N-S$W)UT@/2`G3F]N9R!+:&%I)SL*
M)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q."XQ-C<Z,3`P+C$V-R==(#T@
M)U!H<F%E)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q."XQ-C<Z.3<N
M.3,S)UT@/2`G36%E(%-A<FEA;F<G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S$X+C(X,SHY.2XU,3<G72`]("=,86UP86YG)SL*)&-O;W)D:6YA=&5S
M6R=4:&%I;&%N9"==6R<Q."XW-C<Z,3`P+C<V-R==(#T@)TYA;B<["B1C;V]R
M9&EN871E<ULG5&AA:6QA;F0G75LG,3@N-S@S.CDX+CDX,R==(#T@)T-H:6%N
M9R!-86DG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$Y+C,P,#HY-RXX
M,S,G72`]("=-864@2&]N9R!3;VXG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S$Y+CDQ-SHY.2XX,S,G72`]("=#:&EA;F<@4F%I)SL*)&-O;W)D:6YA
M=&5S6R=4:&%I;&%N9"==6R<V+C8U,#HQ,#`N,#@S)UT@/2`G4V%T=6XG.PHD
M8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S8N-S@S.C$P,2XQ-3`G72`]("=0
M871T86YI)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<V+CDQ-SHQ,#`N
M-#,S)UT@/2`G2&%T(%EA:2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG
M-RXR,#`Z,3`P+C8P,"==(#T@)U-O;F=K:&QA)SL*)&-O;W)D:6YA=&5S6R=4
M:&%I;&%N9"==6R<W+C4Q-SHY.2XV,3<G72`]("=4<F%N9R<["B1C;V]R9&EN
M871E<ULG5&AA:6QA;F0G75LG."XQ,3<Z.3@N,S$W)UT@/2`G4&AU:V5T($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S@N-#8W.CDY+CDV
M-R==(#T@)TYA:VAO;B!3:2!4:&%M;6%R870G.PHD8V]O<F1I;F%T97-;)U1H
M86EL86YD)UU;)SDN,3$W.CDY+C,U,"==(#T@)U-U<F%T(%1H86YI)SL*)&-O
M;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Y+CDX,SHY."XV,3<G72`]("=286YO
M;F<G.PHD8V]O<F1I;F%T97-;)U1O9V\G75LG,3`N,S8W.C`N-#8W)UT@/2`G
M36%N9V\G.PHD8V]O<F1I;F%T97-;)U1O9V\G75LG-BXQ-C<Z,2XR-3`G72`]
M("=,;VUE)SL*)&-O;W)D:6YA=&5S6R=4;V=O)UU;)S8N-3@S.C$N-3`P)UT@
M/2`G5&%B;&EG8F\G.PHD8V]O<F1I;F%T97-;)U1O9V\G75LG-RXU.#,Z,2XQ
M,3<G72`]("=!=&%K<&%M92<["B1C;V]R9&EN871E<ULG5&]G;R==6R<X+CDX
M,SHQ+C$U,"==(#T@)U-O:V]D92<["B1C;V]R9&EN871E<ULG5&]G;R==6R<Y
M+C<V-SHQ+C$P,"==(#T@)TYI86UT;W5G;W4G.PHD8V]O<F1I;F%T97-;)U1O
M;F=A)UU;)RTQ.2XX,#`Z+3$W-"XS-3`G72`]("=(86%P86DG.PHD8V]O<F1I
M;F%T97-;)U1O;F=A)UU;)RTR,2XR,S,Z+3$W-2XQ-3`G72`]("=&=6%<)T%M
M;W1U)SL*)&-O;W)D:6YA=&5S6R=4<FEN:61A9"!A;F0@5&]B86=O)UU;)S$P
M+C8Q-SHM-C$N,S4P)UT@/2`G4&EA<F-O($EN=&5R;F%T:6]N86P@06ER<&]R
M="P@5')I;FED860G.PHD8V]O<F1I;F%T97-;)U1R:6YI9&%D(&%N9"!4;V)A
M9V\G75LG,3$N,34P.BTV,"XX,S,G72`]("=#<F]W;B!0;VEN="!!:7)P;W)T
M+"!4;V)A9V\G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S$N-C@S.CDN
M,38W)UT@/2`G16P@0F]R;6$G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG
M,S(N,S$W.C$P+C0P,"==(#T@)U)E;6%D82<["B1C;V]R9&EN871E<ULG5'5N
M:7-I82==6R<S,RXX-C<Z,3`N-S8W)UT@/2`G1&IE<F)A($UE;&QI=&$G.PHD
M8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S,N.#@S.C$P+C$P,"==(#T@)T=A
M8F5S)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,S+CDQ-SHX+C$P,"==
M(#T@)U1O>F5U<B<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S-"XT,3<Z
M."XX,3<G72`]("='869S82<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S
M-"XW,3<Z,3`N-C@S)UT@/2`G4V9A>"!%;"U-86]U)SL*)&-O;W)D:6YA=&5S
M6R=4=6YI<VEA)UU;)S,U+C8V-SHQ,"XQ,#`G72`]("=+86ER;W5A;B<["B1C
M;V]R9&EN871E<ULG5'5N:7-I82==6R<S-2XV-C<Z,3`N-S4P)UT@/2`G36]N
M87-T:7(M4VMA;F5S)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,V+C0X
M,SHX+C@P,"==(#T@)TIE;F1O=6)A)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA
M)UU;)S,V+C@S,SHQ,"XR,S,G72`]("=4=6YI<RU#87)T:&%G92<["B1C;V]R
M9&EN871E<ULG5'5N:7-I82==6R<S-BXX-3`Z,3$N,#@S)UT@/2`G2V5L:6)I
M82<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S-BXY-3`Z."XW-3`G72`]
M("=486)A<FMA)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,W+C(U,#HY
M+C@P,"==(#T@)T)I>F5R=&4G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S
M-BXU.#,Z,S8N,38W)UT@/2`G27-K96YD97)U;B<["B1C;V]R9&EN871E<ULG
M5'5R:V5Y)UU;)S,V+C<P,#HR."XW.#,G72`]("=$86QA;6%N)SL*)&-O;W)D
M:6YA=&5S6R=4=7)K97DG75LG,S8N-S`P.C,P+C<S,R==(#T@)T%N=&%L>6$G
M.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-BXY.#,Z,S4N,S`P)UT@/2`G
M061A;F$@+R!386MI<G!A<V$G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S
M-RXP,#`Z,S4N-#$W)UT@/2`G061A;F$@+R!);F-I<FQI:R<["B1C;V]R9&EN
M871E<ULG5'5R:V5Y)UU;)S,W+C`S,SHR-RXT,3<G72`]("=";V1R=6TG.PHD
M8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-RXP.#,Z,S<N,S8W)UT@/2`G1V%Z
M:6%N=&5P)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S<N,3,S.C,X+C<V
M-R==(#T@)U5R9F$G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-RXW-3`Z
M,S`N-34P)UT@/2`G27-P87)T82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;
M)S,W+C@U,#HR-RXX-3`G72`]("=!>61I;B<["B1C;V]R9&EN871E<ULG5'5R
M:V5Y)UU;)S,W+C@V-SHT,2XQ-C<G72`]("="871M86XG.PHD8V]O<F1I;F%T
M97-;)U1U<FME>2==6R<S-RXX.#,Z-#`N,3@S)UT@/2`G1&EY87)B86MI<B<[
M"B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+CDV-SHS,BXU-3`G72`]("=+
M;VYY82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+C(V-SHR-RXQ-3`G
M72`]("=)>FUI<B`O($%D;F%N($UE;F1E<F5S)SL*)&-O;W)D:6YA=&5S6R=4
M=7)K97DG75LG,S@N-#,S.C,X+C`X,R==(#T@)TUA;&%T>6$@+R!%<FAA8R<[
M"B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+C0U,#HT,RXS,3<G72`]("=6
M86XG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S."XU,#`Z,C<N,#$W)UT@
M/2`G27IM:7(@+R!#:6=L:2<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X
M+C8P,#HS.2XR.#,G72`]("=%;&%Z:6<G.PHD8V]O<F1I;F%T97-;)U1U<FME
M>2==6R<S."XV-C<Z,CDN-#$W)UT@/2`G57-A:R<["B1C;V]R9&EN871E<ULG
M5'5R:V5Y)UU;)S,X+C<U,#HS,"XU,S,G72`]("=!9GEO;B<["B1C;V]R9&EN
M871E<ULG5'5R:V5Y)UU;)S,X+C<X,SHS-2XT.#,G72`]("=+87ES97)I("\@
M17)K:6QE="<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+CDQ-SHR-RXX
M-3`G72`]("=!:VAI<V%R)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,SDN
M-C$W.C(W+CDQ-R==(#T@)T)A;&EK97-I<B<["B1C;V]R9&EN871E<ULG5'5R
M:V5Y)UU;)S,Y+C<S,SHS.2XU,#`G72`]("=%<GII;F-A;B<["B1C;V]R9&EN
M871E<ULG5'5R:V5Y)UU;)S,Y+C<U,#HS-RXP,3<G72`]("=3:79A<R<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,Y+C<X,SHS,"XU-C<G72`]("=%<VMI
M<V5H:7(G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S.2XY,3<Z-#$N,C8W
M)UT@/2`G17)Z=7)U;2<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,Y+CDU
M,#HS,BXV.#,G72`]("=!;FMA<F$@+R!%=&EM97-G=70G.PHD8V]O<F1I;F%T
M97-;)U1U<FME>2==6R<T,"XP.#,Z,S(N-38W)UT@/2`G375R=&5D(%1U<BU!
M9F(G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,"XQ,3<Z,S(N.3@S)UT@
M/2`G06YK87)A("\@17-E;F)O9V$G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==
M6R<T,"XQ,S,Z,C8N-#`P)UT@/2`G0V%N86MK86QE)SL*)&-O;W)D:6YA=&5S
M6R=4=7)K97DG75LG-#`N,3@S.C(Y+C`V-R==(#T@)T)U<G-A)SL*)&-O;W)D
M:6YA=&5S6R=4=7)K97DG75LG-#`N,S`P.C,V+C4V-R==(#T@)U1O:V%T)SL*
M)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG-#`N,S$W.C(W+CDV-R==(#T@)T)A
M;F1I<FUA)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG-#`N-C`P.C0S+C`X
M,R==(#T@)TMA<G,G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,"XX-3`Z
M,S4N-3@S)UT@/2`G365R>FEF;VXG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==
M6R<T,"XY-C<Z,C@N.#$W)UT@/2`G27-T86YB=6P@+R!!=&%T=7)K)SL*)&-O
M;W)D:6YA=&5S6R=4=7)K97DG75LG-#$N,#`P.C,Y+C<Q-R==(#T@)U1R86)Z
M;VXG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,2XR-C<Z,S8N,S`P)UT@
M/2`G4V%M<W5N)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG-#$N-#4P.C,Q
M+C@P,"==(#T@)UIO;F=U;&1A:R<["B1C;V]R9&EN871E<ULG5'5V86QU)UU;
M)RTU+C8V-SHQ-S8N,3,S)UT@/2`G3F%N=6UE82<["B1C;V]R9&EN871E<ULG
M5'5V86QU)UU;)RTX+C4Q-SHQ-SDN,C$W)UT@/2`G1G5N869U=&DG.PHD8V]O
M<F1I;F%T97-;)U5G86YD82==6R<P+C`U,#HS,BXT-3`G72`]("=%;G1E8F)E
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<P+C$X,SHS,"XQ
M,#`G72`]("=+87-E<V4G.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<P+C0U
M,#HS,RXQ.#,G72`]("=*:6YJ82<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;
M)RTP+C8Q-SHS,"XV-3`G72`]("=-8F%R87)A)SL*)&-O;W)D:6YA=&5S6R=5
M9V%N9&$G75LG,"XV.#,Z,S0N,38W)UT@/2`G5&]R;W)O)SL*)&-O;W)D:6YA
M=&5S6R=59V%N9&$G75LG+3$N,C4P.C(Y+CDX,R==(#T@)TMA8F%L92<["B1C
M;V]R9&EN871E<ULG56=A;F1A)UU;)S$N-C@S.C,Q+C<Q-R==(#T@)TUA<VEN
M9&DG.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<Q+C<Q-SHS,RXV,3<G72`]
M("=3;W)O=&DG.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<R+C<U,#HS,BXS
M,S,G72`]("='=6QU)SL*)&-O;W)D:6YA=&5S6R=59V%N9&$G75LG,RXP-3`Z
M,S`N.3$W)UT@/2`G07)U82<["B1C;V]R9&EN871E<ULG56MR86EN92==6R<T
M-"XV.#,Z,S0N,3,S)UT@/2`G4VEM9F5R;W!O;"<["B1C;V]R9&EN871E<ULG
M56MR86EN92==6R<T-BXT,S,Z,S`N-S8W)UT@/2`G3V1E<V$G.PHD8V]O<F1I
M;F%T97-;)U5K<F%I;F4G75LG-#DN.#$W.C(S+CDU,"==(#T@)TQ<)U9I=B<[
M"B1C;V]R9&EN871E<ULG56MR86EN92==6R<T.2XY-C<Z,S8N,3,S)UT@/2`G
M2VAA<FMI=B<["B1C;V]R9&EN871E<ULG56MR86EN92==6R<U,"XS,S,Z,S`N
M.38W)UT@/2`G0F]R>7-P:6PG.PHD8V]O<F1I;F%T97-;)U5K<F%I;F4G75LG
M-3`N-#`P.C,P+C4V-R==(#T@)TMY:78G.PHD8V]O<F1I;F%T97-;)U5K<F%I
M;F4G75LG-3`N-3@S.C(V+C$S,R==(#T@)U)I=FYE)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@07)A8B!%;6ER871E<R==6R<R-"XR-C<Z-34N-C`P)UT@/2`G
M06P@06EN($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M56YI=&5D($%R86(@16UI<F%T97,G75LG,C0N-#,S.C4T+C0V-R==(#T@)T%B
M=2!$:&%B:2!"871E96X@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D
M($%R86(@16UI<F%T97,G75LG,C0N-#,S.C4T+C8U,"==(#T@)T%B=2!$:&%B
M:2!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!!<F%B($5M:7)A=&5S)UU;)S(U+C$P,#HU-BXS,S,G72`]("=&=6IA:7)A
M:"<["B1C;V]R9&EN871E<ULG56YI=&5D($%R86(@16UI<F%T97,G75LG,C4N
M,C4P.C4U+C,S,R==(#T@)T1U8F%I($EN=&5R;F%T:6]N86P@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($%R86(@16UI<F%T97,G75LG,C4N,S,S
M.C4U+C4Q-R==(#T@)U-H87)J86@@26YT97)N871I;VYA;"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@07)A8B!%;6ER871E<R==6R<R-2XV,3<Z
M-34N.3,S)UT@/2`G4F%S($%L($MH86EM86@@26YT97)N871I;VYA;"!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<T.2XR,3<Z
M+3(N,C`P)UT@/2`G2F5R<V5Y($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S0Y+C0S,SHM,BXV,#`G72`]("='=65R;G-E>2!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<T.2XY
M,3<Z+38N,S`P)UT@/2`G4V-I;&QY+"!386EN="!-87)Y7"=3)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,"XP.#,Z+34N,C4P)UT@/2`G
M0W5L9')O<V4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4P
M+C,U,#HM-"XQ,3<G72`]("=0;'EM;W5T:"<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3`N-#,S.BTU+C`P,"==(#T@)U-A:6YT($UA=V=A
M;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3`N-38W.BTR
M+C0U,"==(#T@)U!O<G1L86YD("\@4FYA<R<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3`N-S,S.BTS+C0Q-R==(#T@)T5X971E<B!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,"XW.#,Z
M+3$N.#,S)UT@/2`G0F]U<FYE;6]U=&@@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG56YI=&5D($MI;F=D;VTG75LG-3`N.#,S.BTP+C(X,R==(#T@)U-H;W)E
M:&%M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;
M)S4P+CDP,#HM,2XT,#`G72`]("=3;W5T:&%M<'1O;B`O(%=E871H97(@0V5N
M=')E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XP,#`Z
M+3(N-C,S)UT@/2`G665O=FEL=&]N)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U,2XP.#,Z+30N,34P)UT@/2`G0VAI=F5N;W(G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C$U,#HM,"XQ.#,G72`]
M("=,;VYD;VX@+R!'871W:6-K($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4Q+C$U,#HM,2XU-C<G72`]("=-:61D;&4@5V%L
M;&]P)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XQ-C<Z
M+3$N-S4P)UT@/2`G0F]S8V]M8F4@1&]W;B<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3$N,C,S.BTP+CDU,"==(#T@)T]D:6AA;2<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N,C@S.BTP+C<V-R==
M(#T@)T9A<FYB;W)O=6=H($UI;&ET87)Y)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,2XR.#,Z+3`N-S8W)UT@/2`G1F%R;F)O<F]U9V@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C,U,#HQ+C,U
M,"==(#T@)TUA;G-T;VXG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M
M)UU;)S4Q+C,X,SHM,"XW.#,G72`]("="<F%C:VYE;&P@+R!"96%U9F]R="!0
M87)K)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XT,#`Z
M+3,N,S4P)UT@/2`G0V%R9&EF9BU786QE<R!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XT.#,Z+3`N-#4P)UT@/2`G3&]N
M9&]N("\@2&5A=&AR;W<@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D
M($MI;F=D;VTG75LG-3$N-3`P.BTQ+CDX,R==(#T@)TQY;F5H86TG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C4Q-SHM,"XQ,3<G72`]
M("=,;VYD;VX@5V5A=&AE<B!#96YT<F4G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4Q+C4U,#HM,"XT,3<G72`]("=.;W)T:&]L="<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N-C$W.BTQ+C`X,R==
M(#T@)T)E;G-O;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3$N-C@S.BTQ+C<X,R==(#T@)T9A:7)F;W)D(%)O>6%L($%I<B!&;W)C92!"
M87-E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XW,3<Z
M+30N,S8W)UT@/2`G4&5M8G)E>2!386YD<R<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3$N-S4P.BTQ+C4X,R==(#T@)T)R:7IE($YO<G1O
M;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N.#@S.C`N
M,C,S)UT@/2`G4W1A;G-T960@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3(N,3$W.C`N.38W)UT@/2`G5V%T=&ES:&%M)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXQ,S,Z+30N-38W
M)UT@/2`G06)E<G!O<G1H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U,BXS,S,Z,"XW-C<G72`]("=(;VYI;F=T;VX@4F]Y86P@06ER($9O
M<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R
M+C,U,#HM,"XQ,3<G72`]("=7>71O;B!2;WEA;"!!:7(@1F]R8V4@0F%S92<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N,S8W.BTP+C(Q
M-R==(#T@)T%L8V]N8G5R>2!2;WEA;"!!:7(@1F]R8V4@0F%S92<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N,S8W.C`N-#@S)UT@/2`G
M36EL9&5N:&%L;"!2;WEA;"!!:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E
M<ULG56YI=&5D($MI;F=D;VTG75LG-3(N-#$W.C`N-38W)UT@/2`G3&%K96YH
M96%T:"!2;WEA;"!!:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3(N-#,S.C$N,S4P)UT@/2`G0V]L=&ES:&%L;"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N-#4P.BTQ+C<S
M,R==(#T@)T)I<FUI;F=H86T@+R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@2VEN9V1O;2==6R<U,BXV,3<Z+3`N-#8W)UT@/2`G5VET=&5R:6YG
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXV,S,Z,2XS
M,#`G72`]("=.;W)W:6-H(%=E871H97(@0V5N=')E)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@2VEN9V1O;2==6R<U,BXV-3`Z,"XU-C<G72`]("=-87)H86TG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C<S,SHM,"XV
M-3`G72`]("=#;W1T97-M;W)E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,BXX,#`Z+3(N-C8W)UT@/2`G4VAA=V)U<GDG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C@V-SHP+C$U,"==(#T@)TAO
M;&)E86-H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,RXP
M,S,Z+3`N-3`P)UT@/2`G0W)A;G=E;&PG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4S+C`X,SHM,"XQ-C<G72`]("=#;VYI;F=S8GD@4F]Y
M86P@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG
M9&]M)UU;)S4S+C`X,SHP+C(V-R==(#T@)U=A:6YF;&5E="<["B1C;V]R9&EN
M871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N,38W.BTP+C4Q-R==(#T@)U=A
M9&1I;F=T;VXG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4S
M+C$V-SHM,BXY.#,G72`]("=(87=A<F1E;B<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3,N,C4P.BTT+C4S,R==(#T@)U9A;&QE>2<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N,S4P.BTR+C(X,R==
M(#T@)TUA;F-H97-T97(@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D
M($MI;F=D;VTG75LG-3,N-S8W.BTS+C`S,R==(#T@)T)L86-K<&]O;"!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,RXX,S,Z
M+3$N,C`P)UT@/2`G0VAU<F-H($9E;G1O;B<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3,N.#8W.BTP+C0S,R==(#T@)TQE8V]N9FEE;&0G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4T+C`U,#HM,2XR
M-3`G72`]("=,:6YT;VXM3VXM3W5S92<["B1C;V]R9&EN871E<ULG56YI=&5D
M($MI;F=D;VTG75LG-30N,#@S.BTT+C8S,R==(#T@)TES;&4@3V8@36%N("\@
M4F]N86QD<W=A>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U-"XQ,3<Z+3,N,C4P)UT@/2`G5V%L;F5Y($ES;&%N9"<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-30N,3,S.BTQ+C0Q-R==
M(#T@)T1I<V9O<G1H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==
M6R<U-"XS,#`Z+3$N-3,S)UT@/2`G3&5E;6EN9R<["B1C;V]R9&EN871E<ULG
M56YI=&5D($MI;F=D;VTG75LG-30N-C`P.BTU+C@X,R==(#T@)T)E;&9A<W0@
M+R!(87)B;W5R)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U
M-"XV-3`Z+38N,C$W)UT@/2`G0F5L9F%S="`O($%L9&5R9W)O=F4@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-30N.#4P.BTT
M+CDU,"==(#T@)U=E<W0@1G)E=6=H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U-"XY,S,Z+3(N.34P)UT@/2`G0V%R;&ES;&4G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4U+C`U,#HM,BXU-3`G72`]
M("=3<&%D96%D86TG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;
M)S4U+C0Q-SHM,2XV,#`G72`]("=";W5L;65R)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@2VEN9V1O;2==6R<U-2XT,S,Z+34N-S`P)UT@/2`G36%C:')I:&%N
M:7-H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-2XU,#`Z
M+30N-3@S)UT@/2`G4')E<W1W:6-K($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!+:6YG9&]M)UU;)S4U+C@V-SHM-"XT,S,G72`]("=';&%S9V]W
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4U
M+CDU,#HM,RXS-3`G72`]("=%9&EN8G5R9V@@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG56YI=&5D($MI;F=D;VTG75LG-38N,S@S.BTR+C@V-R==(#T@)TQE
M=6-H87)S)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-BXU
M,#`Z+38N.#@S)UT@/2`G5&ER964G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+
M:6YG9&]M)UU;)S4W+C(P,#HM,BXR,3<G72`]("=!8F5R9&5E;B`O($1Y8V4G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4W+C0V-SHM-RXS
M-C<G72`]("="96YB96-U;&$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG
M9&]M)UU;)S4W+C4S,SHM-"XP-3`G72`]("=);G9E<FYE<W,@+R!$86QC<F]S
M<R<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3<N-C4P.BTS
M+C4V-R==(#T@)TMI;FQO<W,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG
M9&]M)UU;)S4W+C<Q-SHM,RXS,3<G72`]("=,;W-S:65M;W5T:"<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3<N.#$W.BTS+CDV-R==(#T@
M)U1A:6X@4F%N9V4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;
M)S4X+C(Q-SHM-BXS,3<G72`]("=3=&]R;F]W87DG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!+:6YG9&]M)UU;)S4X+C0U,#HM,RXP.#,G72`]("=7:6-K)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U."XY-3`Z+3(N.3`P
M)UT@/2`G2VER:W=A;&P@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D
M($MI;F=D;VTG75LG-3DN.#@S.BTQ+C,P,"==(#T@)U-U;6)U<F=H($-A<&4G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<R==6R<M,30N,S,S.BTQ-S`N-S$W)UT@/2`G4&%G;R!086=O("\@
M26YT+B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',G75LG,38N-S,S.BTQ-CDN-3,S)UT@/2`G
M2F]H;G-T;VX@27-L86YD+"!*;VAN<W1O;B!!=&]L;"!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$S+C0X,SHQ-#0N.#`P)UT@
M/2`G06=A;F$L($=U86T@26YT97)N871I;VYA;"!!:7)P;W)T+"!'52<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<Q,RXU.#,Z,30T+CDS,R==
M(#T@)T%N9&5R<V5N("A-87)I86YA($ES*2P@06YD97)S96X@06ER($9O<F-E
M($)A<V4L($=5)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$S
M+CDQ-SHQ-#0N.#,S)UT@/2`G1W5A;2P@36%R:6%N82!)<VQA;F0L($=5)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$T+C$X,SHQ-#4N,C4P
M)UT@/2`G4F]T82!)<VQA;F0@*$XN($UA<FEA;F$@27,I+"!2;W1A($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@1U4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,30N.3@S.C$T-2XV,3<G72`]("=4:6YI86X@27-L86YD("A.
M+B!-87)I86YA($ES*2P@5V5S="!4:6YI86X@06ER<&]R="P@1U4G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,34N,3$W.C$T-2XW,S,G72`]
M("=386EP86X@27-L86YD+"!386EP86X@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!.;W)T:&5R;B!-87)I86YA($ES;&%N9',G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,3@N,C4U.BTV-2XV-#,G72`]("=2;V]S979E;'0@
M4F]A9',L(%)O;W-E=F5L="!2;V%D<R!.879A;"!3=&%T:6]N("A/9G-T:64@
M1FEE;&0I+"!04B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<Q
M."XU,#`Z+38W+C$S,R==(#T@)T%Q=6%D:6QL82P@4F%F865L($AE<FYA;F1E
M>B!!:7)P;W)T+"!04B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<Q.2XQ,#`Z+3$U-2XW-3`G72`]("=3;W5T:"!+;VYA("\@2&%W86EI+"!(
M22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<Q.2XR.#,Z,38V
M+C8U,"==(#T@)U=A:V4@27-L86YD+"!786ME($ES;&%N9"!!<FUY($%I<F9I
M96QD($%I<G!O<G0L($=5)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S$Y+C<R,CHM,34U+C`U-B==(#T@)TAI;&\L($AI;&\@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!(22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<R,"XX.3(Z+3$U-BXT,S<G72`]("=+86AU;'5I+"!+86AU;'5I($%I
M<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(Q
M+C$U,#HM,34W+C$P,"==(#T@)TUO;&]K86D@075T;VUA=&EC($UE=&5O<F]L
M;V=I8V%L($]B<V5R=FEN9R!3>7-T96TL($A))SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S(Q+C,P.#HM,34X+C`V."==(#T@)T]A:'4L($MA
M;&%E;&]A($%I<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S(Q+C,R.#HM,34W+CDT,R==(#T@)TAO;F]L=6QU+"!(;VYO;'5L
M=2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S(Q+C0U-#HM,34W+C<V-B==(#T@)TMA;F5O:&4L
M($UA<FEN92!#;W)P<R!!:7(@4W1A=&EO;BP@2$DG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,C$N-#@S.BTQ-3@N,#,S)UT@/2`G5VAE96QE
M<B!!:7(@1F]R8V4@0F%S92`O($]A:'4L($A))SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S(Q+CDX-#HM,34Y+C,T,2==(#T@)TQI:'5E+"!,
M:6AU92!!:7)P;W)T+"!(22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<R,BXP,S8Z+3$U.2XW.#8G72`]("=+96MA:&$L(%!A8VEF:6,@36ES
M<VEL92!497-T($9A8VEL:71Y($)A<FMI;F<@4V%N9',L($A))SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(T+C4U-#HM.#$N-S4T)UT@/2`G
M2V5Y(%=E<W0L($ME>2!797-T($EN=&5R;F%T:6]N86P@06ER<&]R="P@1DPG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C4N-SDQ.BTX,"XS
M,38G72`]("=-:6%M:2P@36EA;6D@26YT97)N871I;VYA;"!!:7)P;W)T+"!&
M3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-2XY,30Z+3DW
M+C0R,R==(#T@)T)R;W=N<W9I;&QE+"!"<F]W;G-V:6QL92`O(%-O=71H(%!A
M9')E($ES;&%N9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(V+C8X-3HM.#`N,#DY)UT@/2`G
M5V5S="!086QM($)E86-H+"!086QM($)E86-H($EN=&5R;F%T:6]N86P@06ER
M<&]R="P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C<N
M-34P.BTY.2XT-C<G72`]("=,87)E9&\@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-RXV-3`Z
M+3@Q+C,S,R==(#T@)T%V;VX@4&%R:R!'=6YN97)Y(%)A;F=E+"!&3"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-RXW,#`Z+3@R+C0P,"==
M(#T@)U1A;7!A($)A>2!!<F5A+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<R-RXW-S,Z+3DW+C4Q,R==(#T@)T-O<G!U<R!#:')I<W1I
M+"!#;W)P=7,@0VAR:7-T:2!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%18)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(W+C@U,#HM.#(N-3`P
M)UT@/2`G36%C9&EL;"!!:7(@1F]R8V4@0F%S92P@1FPN+"!&3"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-RXY-C$Z+3@R+C4T,"==(#T@
M)U1A;7!A+"!486UP82!);G1E<FYA=&EO;F%L($%I<G!O<G0L($9,)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(X+C$P,SHM.#`N-C0V)UT@
M/2`G365L8F]U<FYE+"!-96QB;W5R;F4@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R."XR,3<Z
M+3$W-RXS-C<G72`]("=386YD($ES;&%N9"P@2&5N9&5R<V]N($9I96QD($%I
M<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(X
M+C(S,SHM.#`N-C`P)UT@/2`G0V]C;V$@+R!0871R:6-K($%I<B!&;W)C92!"
M87-E+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R."XT
M,3<Z+3@Q+C,R-2==(#T@)T]R;&%N9&\L($]R;&%N9&\@26YT97)N871I;VYA
M;"!!:7)P;W)T+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<R."XT-C<Z+3@P+C4U,"==(#T@)T-A<&4@2V5N;F5D>2P@1DPG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C@N.#8S.BTY-BXY,S`G72`]
M("=6:6-T;W)I82P@5FEC=&]R:6$@4F5G:6]N86P@06ER<&]R="P@5%@G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN,C<P.BTY-"XX-C0G
M72`]("='86QV97-T;VXL(%-C:&]L97,@1FEE;&0L(%18)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S(Y+C,S,SHM.#DN-#`P)UT@/2`G0F]O
M=&AV:6QL92P@3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,CDN,S<U.BTQ,#`N.3(T)UT@/2`G1&5L(%)I;RP@1&5L(%)I;R!);G1E<FYA
M=&EO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S(Y+C4S,SHM.3@N-#8T)UT@/2`G4V%N($%N=&]N:6\L(%-A;B!!
M;G1O;FEO($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,CDN-34P.BTX,RXQ,#4G72`]("=#<F]S
M<R!#:71Y+"!#<F]S<R!#:71Y($%I<G!O<G0L($9,)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S(Y+C<R-SHM.#4N,#(U)UT@/2`G07!A;&%C
M:&EC;VQA+"!!<&%L86-H:6-O;&$L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S(Y+CDU,3HM.30N,#(Q)UT@/2`G0F5A=6UO;G0@+R!0
M;W)T($%R=&AU<BP@4V]U=&AE87-T(%1E>&%S(%)E9VEO;F%L($%I<G!O<G0L
M(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(Y+CDY,CHM
M.34N,S8T)UT@/2`G2&]U<W1O;BP@2&]U<W1O;B!);G1E<F-O;G1I;F5N=&%L
M($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S(Y+CDY,SHM.3`N,C4Q)UT@/2`G3F5W($]R;&5A;G,L($YE=R!/<FQE86YS
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@3$$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S`N,#8W.BTX-2XU.#,G72`]("=4>6YD86QL($%I
M<B!&;W)C92!"87-E+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,"XQ,C8Z+3DS+C(R,R==(#T@)TQA:V4@0VAA<FQE<RP@3&%K92!#
M:&%R;&5S(%)E9VEO;F%L($%I<G!O<G0L($Q!)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,P+C$V-SHM,3`R+C0Q-R==(#T@)U-A;F1E<G-O
M;BP@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N,S,S
M.BTX.2XX,3<G72`]("=3;&ED96QL+"!,02<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S,"XS-C<Z+3$P-"XP,3<G72`]("=-87)F82P@5%@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N,SDS.BTX-"XS
M-3,G72`]("=486QL86AA<W-E92P@5&%L;&%H87-S964@4F5G:6]N86P@06ER
M<&]R="P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N
M-#$W.BTX-BXV.#,G72`]("=(=7)L8G5R="!&:65L9"P@1DPG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N-#@S.BTX-BXU,3<G72`]("=6
M86QP87)A:7-O("\@16=L:6X@06ER($9O<F-E($)A<V4L($9,)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P+C0Y-#HM.#$N-CDS)UT@/2`G
M2F%C:W-O;G9I;&QE+"!*86-K<V]N=FEL;&4@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XU
M,3$Z+3DY+C<V-B==(#T@)TIU;F-T:6]N+"!+:6UB;&4@0V]U;G1Y($%I<G!O
M<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P+C8X
M.#HM.#@N,C0V)UT@/2`G36]B:6QE+"!-;V)I;&4@4F5G:6]N86P@06ER<&]R
M="P@04PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N.38W
M.BTX,RXR,#`G72`]("=-;V]D>2!!:7(@1F]R8V4@0F%S92P@1T$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N,#,S.BTY,RXP,S,G72`]
M("=&;W)T(%!O;&LL($Q!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,Q+C$P,#HM.3<N,S,S)UT@/2`G1F]R="!(;V]D+"!46"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XQ,S,Z+3DR+C4V-R==(#T@
M)T-L86EB;W)N92!286YG92P@06ER=V%Y<R!&86-I;&ET:65S(%-E8W1O<BP@
M3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N,C4P.BTX
M,BXT,#`G72`]("=787EC<F]S<R`O(%=A<F4@0V]U;G1Y+"!'82P@1T$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N,S,U.BTY,BXU-3DG
M72`]("=!;&5X86YD<FEA+"!!;&5X86YD<FEA($EN=&5R;F%T:6]N86P@06ER
M<&]R="P@3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N
M,S4Q.BTQ,#`N-#DT)UT@/2`G4V%N($%N9V5L;RP@36%T:&ES($9I96QD+"!4
M6"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XU,S8Z+3@T
M+C$Y-"==(#T@)T%L8F%N>2P@4V]U=&AW97-T($=E;W)G:6$@4F5G:6]N86P@
M06ER<&]R="P@1T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S$N-3@S.BTQ,3`N,S,S)UT@/2`G1F]R="!(=6%C:'5C82P@05HG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N-C$W.BTY-RXR,C@G72`]
M("=786-O+"!786-O(%)E9VEO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+C@Q,3HM,3`V+C,W-B==(#T@)T5L
M(%!A<V\L($5L(%!A<V\@26YT97)N871I;VYA;"!!:7)P;W)T+"!46"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XX,S$Z+3$P-"XX,#DG
M72`]("=0:6YE(%-P<FEN9W,L($=U861A;'5P92!-;W5N=&%I;G,@3F%T:6]N
M86P@4&%R:RP@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S$N.#8W.BTQ,#8N-S`P)UT@/2`G4V%N=&$@5&5R97-A+"!.32<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XX.#,Z+3@Q+C4V-R==(#T@
M)T9T+B!3=&5W87)T+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,2XY-#@Z+3$P,BXR,#DG72`]("=-:61L86YD+"!-:61L86YD($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S(N,3$Y.BTX,2XR,#(G72`]("=3879A;FYA:"P@4V%V
M86YN86@@26YT97)N871I;VYA;"!!:7)P;W)T+"!'02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,BXQ,S$Z+3$Q,"XY-34G72`]("=4=6-S
M;VXL(%1U8W-O;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($%:)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C(Q-SHM.3@N,3@S)UT@/2`G
M4W1E<&AE;G9I;&QE("\@0VQA<FL@1FEE;&0@375N:6-I<&%L+"!4>"XL(%18
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C,P,#HM.#8N
M-#`V)UT@/2`G36]N=&=O;65R>2P@1&%N;F5L;'D@1FEE;&0L($%,)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C,R,#HM.3`N,#<X)UT@
M/2`G2F%C:W-O;BP@2F%C:W-O;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U3
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C,S,SHM.#0N
M.#,S)UT@/2`G1F]R="!"96YN:6YG+"!'02<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S,BXS,S@Z+3@X+C<T."==(#T@)TUE<FED:6%N+"!+
M97D@1FEE;&0L($U3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,R+C,X,SHM,3`V+C0X,R==(#T@)U=H:71E(%-A;F1S+"!.32<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXS.3$Z+3DT+C<Q-"==(#T@
M)TQO;F=V:65W+"!'<F5G9R!#;W5N='D@06ER<&]R="P@5%@G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N-#$P.BTY.2XV.#(G72`]("=!
M8FEL96YE+"!!8FEL96YE(%)E9VEO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C0S,SHM,3$R+C8X,R==(#T@
M)T=I;&$@0F5N9"!5+B!3+B!!<FUY($%I<F9I96QD+"!!6B<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S,BXT-#<Z+3DS+C@R-"==(#T@)U-H
M<F5V97!O<G0L(%-H<F5V97!O<G0@4F5G:6]N86P@06ER<&]R="P@3$$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N-C,S.BTQ,#@N,34P
M)UT@/2`G4VEL=F5R($-I='D@+R!'<F%N="P@3DTG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S(N-C4P.BTQ,30N-C`P)UT@/2`G675M82`O
M(%EU;6$@26YT97)N871I;VYA;"P@05HG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S(N-C@X.BTX,RXV-30G72`]("=-86-O;BP@36ED9&QE
M($=E;W)G:6$@4F5G:6]N86P@06ER<&]R="P@1T$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S(N-S,T.BTQ,3<N,3@S)UT@/2`G4V%N($1I
M96=O+"!386X@1&EE9V\@26YT97)N871I;VYA;"U,:6YD8F5R9V@@1FEE;&0L
M($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C@R-3HM
M,3$U+C8V,2==(#T@)T5L($-E;G1R;RP@3F%V86P@06ER($9A8VEL:71Y+"!#
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXX,S,Z+3DW
M+C,P,"==(#T@)T9O<G0@5V]R=&@L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,R+C@U,#HM,3`V+C$P,"==(#T@)TAO;&QO;6%N($%I
M<B!&;W)C92!"87-E+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,BXX-C@Z+3$Q-RXQ-#,G72`]("=386X@1&EE9V\L($UI<F%M87(@
M34-!4R]-:71S8VAE<B!&:65L9"!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,BXX.3<Z+3DW+C`R,B==(#T@)T1A;&QA
M<R`O($9O<G0@5V]R=&@L($1A;&QA<R`O($9O<G0@5V]R=&@@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,BXX.3DZ+3@P+C`T,2==(#T@)T-H87)L97-T;VXL($-H87)L97-T
M;VX@06ER($9O<F-E($)A<V4L(%-#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,R+CDP,#HM.#<N,C4P)UT@/2`G0V5N=')E=FEL;&4L($%,
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+C(S-3HM,3$Y
M+C0U,R==(#T@)U-A;B!.:6-H;VQA<R!)<VQA;F0L($-!)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+C(S-SHM,3`W+C(V."==(#T@)U1R
M=71H($]R($-O;G-E<75E;F-E<RP@5')U=&@@3W(@0V]N<V5Q=65N8V5S($UU
M;FEC:7!A;"!!:7)P;W)T+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S,RXS,#@Z+3$P-"XU,#@G72`]("=2;W-W96QL+"!2;W-W96QL
M($EN9'5S=')I86P@06ER($-E;G1E<B!!:7)P;W)T+"!.32<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S,RXS-C0Z+3@Q+CDV,R==(#T@)T%U
M9W5S=&$L($)U<V@@1FEE;&0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,S+C0P-3HM,3$X+C0Q-B==(#T@)T%V86QO;BP@0V%T86QI
M;F$@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S,N-#,T.BTQ,3(N,#4Q)UT@/2`G4&AO96YI>"P@4&AO96YI>"!3:WD@
M2&%R8F]R($EN=&5R;F%T:6]N86P@06ER<&]R="P@05HG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S,N-38V.BTX-BXW-#4G72`]("=":7)M
M:6YG:&%M+"!":7)M:6YG:&%M($EN=&5R;F%T:6]N86P@06ER<&]R="P@04PG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N-C,P.BTX-"XT
M-#(G72`]("=!=&QA;G1A+"!(87)T<V9I96QD($%T;&%N=&$@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,RXV-C<Z+3$P,2XX,C$G72`]("=,=6)B;V-K+"!,=6)B;V-K($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S,N-C@S.BTW."XY,S,G72`]("=->7)T;&4@0F5A8V@@
M06ER($9O<F-E($)A<V4L(%-#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,S+C@Q,CHM,3$X+C$T-B==(#T@)TQO;F<@0F5A8V@L($QO;F<@
M0F5A8V@@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S,N.#4P.BTX,"XT.#,G72`]("=0;VEN<V5T="!286YG92P@4W5M
M<'1E<BP@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N
M.3`P.BTQ,#8N-#`P)UT@/2`G3F]R=&AR=7`@3&%N9&EN9R!3=')I<"P@3DTG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N.3`P.BTQ,3<N
M,C4P)UT@/2`G4FEV97)S:61E("\@36%R8V@@06ER($9O<F-E($)A<V4L($-!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+CDQ-SHM.#0N
M-3$W)UT@/2`G36%R:65T=&$@+R!$;V)B:6YS($%I<B!&;W)C92!"87-E+"!'
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXY,S@Z+3$Q
M."XS.#DG72`]("=,;W,@06YG96QE<RP@3&]S($%N9V5L97,@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,RXY-#(Z+3@Q+C$Q."==(#T@)T-O;'5M8FEA+"!#;VQU;6)I82!-
M971R;W!O;&ET86X@06ER<&]R="P@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S,N.34Q.BTX,RXS,C@G72`]("=!=&AE;G,L($%T:&5N
M<R!!:7)P;W)T+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S,RXY-C<Z+3@P+C0X,R==(#T@)U-H87<@06ER($9O<F-E($)A<V4L(%-#
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+CDW.3HM.3@N
M-#DS)UT@/2`G5VEC:&ET82!&86QL<RP@4VAE<'!A<F0@06ER($9O<F-E($)A
M<V4L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C`Q
M-SHM,3`V+CDP,"==(#T@)U-O8V]R<F\@375N:6-I<&%L+"!.32<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XQ,C0Z+3$Q.2XQ,C(G72`]
M("=0;VEN="!-=6=U+"!.879A;"!!:7(@5V%R9F%R92!#96YT97(L($-!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C(P,#HM,3$X+C,V
M-2==(#T@)T)U<F)A;FLL($)U<F)A;FLM1VQE;F1A;&4M4&%S861E;F$@06ER
M<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N
M,C,S.BTQ,3@N,#8W)UT@/2`G36]U;G0@5VEL<V]N+"!#02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-"XR-C@Z+3@X+C<W,"==(#T@)U1U
M<&5L;RP@5'5P96QO(%)E9VEO;F%L($%I<G!O<G0L($U3)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C,P,#HM,3`S+C@P,"==(#T@)TUE
M;')O<V4@1W5N;F5R>2!286YG92P@3DTG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S0N,S0X.BTX-2XQ-C$G72`]("=2;VUE+"!2+B!"+B!2
M=7-S96QL($%I<G!O<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,T+C4Q-SHM.38N.3@S)UT@/2`G4W5L<&AU<B!-=6YI8VEP86PL
M($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C8P,#HM
M.3@N-#`P)UT@/2`G1F]R="!3:6QL+"!/2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-"XV,S`Z+3$Q."XP.#$G72`]("=086QM9&%L92P@
M4&%L;61A;&4@4')O9'5C=&EO;B!&;&EG:'0@4&QA;G0L($-!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C8T-#HM.#8N-S@V)UT@/2`G
M2'5N='-V:6QL92P@2'5N='-V:6QL92!);G1E<FYA=&EO;F%L("\@2F]N97,@
M1FEE;&0L($%,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T
M+C8U,#HM.3DN,C8W)UT@/2`G06QT=7,@06ER($9O<F-E($)A<V4L($]+)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C<S.3HM.3(N,C<X
M)UT@/2`G3&ET=&QE(%)O8VLL($AE:6=H=',L($%2)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,T+C<T-#HM,3$X+C<R-"==(#T@)U-A;F1B
M97)G+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XW
M-3`Z+3$R,"XU-C<G72`]("=686YD96YB97)G($%I<B!&;W)C92!"87-E+"!#
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XW.#,Z+3<V
M+C@X,R==(#T@)TYE=W!O<G0L($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,T+C@S,SHM.3(N,C4P)UT@/2`G3F]R=&@@3&ET=&QE(%)O
M8VLL($YO<G1H($QI='1L92!2;V-K($%I<G!O<G0L($%2)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C@X-#HM.#(N,C(Q)UT@/2`G1W)E
M97(L($=R965N=FEL;&4M4W!A<G1A;F)U<F<@06ER<&]R="P@4T,G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N.#DX.BTW-BXX.#$G72`]
M("=#:&5R<GD@4&]I;G0L($UA<FEN92!#;W)P<R!!:7(@4W1A=&EO;BP@3D,G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N.#DY.BTQ,C`N
M-#0Y)UT@/2`G4V%N=&$@36%R:6$L(%-A;G1A($UA<FEA(%!U8FQI8R!!:7)P
M;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XY
M,3<Z+3$Q-RXY,#`G72`]("=%9'=A<F1S($%I<B!&;W)C92!"87-E+"!#02<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XP,C@Z+3$Q,"XW
M,C$G72`]("=7:6YS;&]W+"!7:6YS;&]W($UU;FEC:7!A;"!!:7)P;W)T+"!!
M6B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XP,S,Z+3@U
M+C(P,"==(#T@)T-H871T86YO;V=A+"!,;W9E;&P@1FEE;&0L(%1.)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C`T,CHM,3`V+C8Q-2==
M(#T@)T%L8G5Q=65R<75E+"!!;&)U<75E<G%U92!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U
M+C`V,3HM.#DN.3@U)UT@/2`G365M<&AI<RP@365M<&AI<R!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L(%1.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,U+C$S,SHM-S@N.3,S)UT@/2`G1F]R="!"<F%G9R`O(%-I;6UO;G,@
M07)M>2!!:7)F:65L9"P@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S4N,34P.BTW-2XS,#`G72`]("=$:6%M;VYD(%-H;V%L<R!#;V%S
M="!'=6%R9"!3=&%T:6]N+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-2XQ-C<Z+3<Y+C`S,R==(#T@)U!O<&4@06ER($9O<F-E($)A
M<V4L($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C(Q
M,SHM.#`N.30Y)UT@/2`G0VAA<FQO='1E+"!#:&%R;&]T=&4@+R!$;W5G;&%S
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@3D,G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S4N,C$W.BTY-RXT-3`G72`]("=.;W)M86X@+R!-
M87@@5V5S=&AE:6UE<BP@3TLG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S4N,C(P.BTQ,#$N-S$W)UT@/2`G06UA<FEL;&\L($%M87)I;&QO
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S4N,C4X.BTQ,3,N.3,S)UT@/2`G2VEN9VUA;BP@
M2VEN9VUA;B!!:7)P;W)T+"!!6B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-2XR-3DZ+3DS+C`Y,R==(#T@)U)U<W-E;&QV:6QL92P@4G5S
M<V5L;'9I;&QE(%)E9VEO;F%L($%I<G!O<G0L($%2)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,U+C(V-SHM,3$W+C0S,R==(#T@)T-U9&1L
M96)A8VL@1W5N;F5R>2!286YG92P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S4N,C8W.BTW-2XU-3`G72`]("=#87!E($AA='1E<F%S
M+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XR.#,Z
M+3$Q-BXV,3<G72`]("=":6-Y8VQE($QA:V4@52X@4RX@07)M>2!!:7)F:65L
M9"P@0V$L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U
M+C,S-#HM.30N,S8U)UT@/2`G1F]R="!3;6ET:"P@1F]R="!3;6ET:"!296=I
M;VYA;"!!:7)P;W)T+"!!4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-2XS.#DZ+3DW+C8P,"==(#T@)T]K;&%H;VUA($-I='DL(%=I;&P@
M4F]G97)S(%=O<FQD($%I<G!O<G0L($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,U+C0P,#HM.38N,#$W)UT@/2`G2&5N<GEE='1A($UU
M;FEC:7!A;"P@3TLG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S4N-#$W.BTY-RXS.#,G72`]("=4:6YK97(@06ER($9O<F-E($)A<V4L($]+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C0S,CHM.#(N
M-3,W)UT@/2`G07-H979I;&QE+"!!<VAE=FEL;&4@4F5G:6]N86P@06ER<&]R
M="P@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N-#,T
M.BTQ,3DN,#4W)UT@/2`G0F%K97)S9FEE;&0L($UE861O=W,@1FEE;&0@06ER
M<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N
M-C4P.BTQ,#DN,#8W)UT@/2`G5VEN9&]W(%)O8VLL(%=I;F1O=R!2;V-K($%I
M<G!O<G0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U
M+C8V-CHM,3(Q+C(X-2==(#T@)U!O:6YT(%!I961R87,@0FQA;F-A+"!#02<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XV-C<Z+3<U+CDP
M,"==(#T@)T1A<F4@0V]U;G1Y($=U;FYE<GD@4F%N9V4L($Y#)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C8X-CHM,3$W+C8Y,"==(#T@
M)T-H:6YA($QA:V4L($YA=F%L($%I<B!&86-I;&ET>2P@0T$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N.#$X.BTX,RXY.#8G72`]("=+
M;F]X=FEL;&4L($UC1VAE92!4>7-O;B!!:7)P;W)T+"!43B<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-2XX-S$Z+3<X+C<X-B==(#T@)U)A
M;&5I9V@@+R!$=7)H86TL(%)A;&5I9V@M1'5R:&%M($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S8N,#<Y.BTQ,34N,34U)UT@/2`G3&%S(%9E9V%S+"!-8T-A<G)A;B!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,V+C`Y.#HM-SDN.30T)UT@/2`G1W)E96YS8F]R;RP@4&EE
M9&UO;G0@5')I860@26YT97)N871I;VYA;"!!:7)P;W)T+"!.0R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXQ,3DZ+3@V+C8X.2==(#T@
M)TYA<VAV:6QL92P@3F%S:'9I;&QE($EN=&5R;F%T:6]N86P@06ER<&]R="P@
M5$XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S8N,3DW.BTY
M-2XX.#8G72`]("=4=6QS82P@5'5L<V$@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!/2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXS,#0Z
M+3$Q.2XY,S@G72`]("=,96UO;W)E+"!.879A;"!!:7(@4W1A=&EO;BP@0T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S8N,S,S.BTQ,3<N
M,3`P)UT@/2`G4W5P97)I;W(@5F%L;&5Y($=U;FYE<GD@4F%N9V4L($-!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C0S,SHM.38N,S@S
M)UT@/2`G2&]M:6YY($UU;FEC:7!A;"P@3TLG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S8N-#,W.BTY.2XU,C$G72`]("=7;V]D=V%R9"P@
M5V5S="!7;V]D=V%R9"!!:7)P;W)T+"!/2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-BXT-#@Z+3$P,RXQ-3,G72`]("=#;&%Y=&]N+"!#
M;&%Y=&]N($UU;FEC:7!A;"!!:7)P87)K+"!.32<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-BXU,S,Z+3$Q-2XY,#`G72`]("=);F1I86X@
M4W!R:6YG<R!'=6YN97)Y(%)A;F=E+"!.5B<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-BXV,C$Z+3$Q-BXP,C@G72`]("=-97)C=7)Y+"!$
M97-E<G0@4F]C:R!!:7)P;W)T+"!.5B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-BXV-C<Z+3@W+C4P,"==(#T@)T9O<G0@0V%M<&)E;&P@
M52X@4RX@07)M>2!!:7)F:65L9"P@2UDG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S8N-S@P.BTQ,3DN-S$Y)UT@/2`G1G)E<VYO+"!&<F5S
M;F\@06ER(%1E<FUI;F%L+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-BXY,#0Z+3<V+C$Y,B==(#T@)TYO<F9O;&LL($YO<F9O;&L@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!602<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-BXY,C$Z+3$Q,2XT-#@G72`]("=086=E+"!086=E
M($UU;FEC:7!A;"!!:7)P;W)T+"!!6B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-RXP,#`Z+3$P,2XX.#,G72`]("=%;&MH87)T("\@16QK
M:&%R="U-;W)T;VX@0V]U;G1Y($%I<G!O<G0L($M3)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,W+C`U-CHM.#@N-S<T)UT@/2`G4&%D=6-A
M:"P@0F%R:VQE>2!296=I;VYA;"!!:7)P;W)T+"!+62<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S-RXP.#,Z+3<V+C,U,"==(#T@)TQA;F=L
M97D@06ER($9O<F-E($)A<V4L(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,W+C(T,#HM.3,N,SDP)UT@/2`G4W!R:6YG9FEE;&0L(%-P
M<FEN9V9I96QD(%)E9VEO;F%L($%I<G!O<G0L($U/)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,W+C(X-#HM.3@N-34S)UT@/2`G365D:6-I
M;F4@3&]D9V4L($UE9&EC:6YE($QO9&=E+"!+4R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-RXS,3<Z+3<Y+CDW-"==(#T@)U)O86YO:V4L
M(%)O86YO:V4@4F5G:6]N86P@06ER<&]R="P@5D$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S<N,S(Q.BTW.2XR,#<G72`]("=,>6YC:&)U
M<F<L($QY;F-H8G5R9R!296=I;VYA;"!!:7)P;W)T+"!602<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-RXS-C<Z+3$R,"XU-C<G72`]("=-
M97)C960@+R!#87-T;&4@06ER($9O<F-E($)A<V4L($-!)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C,W,3HM,3$X+C,U."==(#T@)T)I
M<VAO<"P@0FES:&]P($%I<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,W+C0P-CHM,3(R+C`T."==(#T@)TUO=6YT86EN(%9I
M97<L($UO9F9E='0@1FEE;&0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,W+C0S.3HM,3`U+C@V,2==(#T@)T%L86UO<V$L(%-A;B!,
M=6ES(%9A;&QE>2!296=I;VYA;"!!:7)P;W)T+"!#3R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S-RXU,3$Z+3<W+C,R,R==(#T@)U)I8VAM
M;VYD+"!2:6-H;6]N9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%9!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C8Q,CHM,3$T+C4R-B==
M(#T@)T-A;&EE;G1E+"!.5B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-RXV,C`Z+3$R,BXS-C4G72`]("=386X@1G)A;F-I<V-O+"!386X@
M1G)A;F-I<V-O($EN=&5R;F%T:6]N86P@06ER<&]R="P@0T$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N-C0W.BTY-RXT,CDG72`]("=7
M:6-H:71A+"!7:6-H:71A($UI9"U#;VYT:6YE;G0@06ER<&]R="P@2U,G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N-S`P.BTQ,C,N,#`P
M)UT@/2`G1F%R86QL;VX@27-L86YD+"!#02<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-RXW,#`Z+3DX+C<U,"==(#T@)U!R871T($UU;FEC
M:7!A;"P@2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N
M-S$Y.BTQ,C(N,C,U)UT@/2`G3V%K;&%N9"P@365T<F\@3V%K;&%N9"!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,W+C<W,SHM.3DN.3<P)UT@/2`G1&]D9V4@0VET>2P@1&]D
M9V4@0VET>2!296=I;VYA;"!!:7)P;W)T+"!+4R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-RXW.#,Z+3$R,BXS,3<G72`]("=!;&%M961A
M($YA=F%L($%I<B!3=&%T:6]N+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-RXW.34Z+3@Q+C$R-2==(#T@)T)E8VML97DL(%)A;&5I
M9V@@0V]U;G1Y($UE;6]R:6%L($%I<G!O<G0L(%=6)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,W+C@Y,#HM,3(Q+C(R-"==(#T@)U-T;V-K
M=&]N+"!3=&]C:W1O;B!-971R;W!O;&ET86X@06ER<&]R="P@0T$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N.3`P.BTX-2XY-C<G72`]
M("=&;W)T($MN;W@L($M9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,W+CDT,3HM-S4N-#8S)UT@/2`G5V%L;&]P<R!)<VQA;F0L(%=A;&QO
M<',@1FQI9VAT($9A8VEL:71Y($%I<G!O<G0L(%9!)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,X+C`T,3HM.#0N-C`V)UT@/2`G3&5X:6YG
M=&]N+"!";'5E($=R87-S($%I<G!O<G0L($M9)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,X+C`T,SHM.#<N-3(P)UT@/2`G179A;G-V:6QL
M92P@179A;G-V:6QL92!296=I;VYA;"!!:7)P;W)T+"!)3B<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S."XQ-S<Z+3@U+C<S,"==(#T@)TQO
M=6ES=FEL;&4L(%-T86YD:69O<F0@1FEE;&0L($M9)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,X+C(V-SHM,3(Q+CDU,"==(#T@)T9A:7)F
M:65L9"`O(%1R879I<R!!:7(@1F]R8V4@0F%S92P@0T$G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S@N,C<Y.BTW-BXT,30G72`]("=0871U
M>&5N="!2:79E<BP@3F%V86P@06ER(%-T871I;VXL($U$)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C(Y,#HM,3`T+C0Y."==(#T@)U!U
M96)L;RP@4'5E8FQO($UE;6]R:6%L($%I<G!O<G0L($-/)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C,S,SHM-S4N,#@S)UT@/2`G3V-E
M86X@0VET>2P@340G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S@N,S8U.BTX,BXU-34G72`]("=(=6YT:6YG=&]N+"!4<FDM4W1A=&4@06ER
M<&]R="P@5U8G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N
M,S<Y.BTX,2XU.3$G72`]("=#:&%R;&5S=&]N+"!996%G97(@06ER<&]R="P@
M5U8G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N-3`W.BTQ
M,C$N-#DU)UT@/2`G4V%C<F%M96YT;RP@4V%C<F%M96YT;R!%>&5C=71I=F4@
M06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S@N-C0S.BTX."XY-C0G72`]("=386QE;2P@4V%L96TM3&5C:W)O;F4@06ER
M<&]R="P@24PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N
M-S`P.BTQ,#0N-S8W)UT@/2`G1F]R="!#87)S;VXL($-/)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C<U,CHM.3`N,S<T)UT@/2`G4W0N
M($QO=6ES+"!,86UB97)T+5-T+B!,;W5I<R!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($U/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C@Q
M-CHM,3`T+C<Q,2==(#T@)T-O;&]R861O(%-P<FEN9W,L($-I='D@3V8@0V]L
M;W)A9&\@4W!R:6YG<R!-=6YI8VEP86P@06ER<&]R="P@0T\G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N.#$W.BTW-BXX-3`G72`]("=#
M86UP(%-P<FEN9W,@+R!!;F1R97=S($%I<B!&;W)C92!"87-E+"!-1"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XX,3<Z+3DR+C(Q."==
M(#T@)T-O;'5M8FEA+"!#;VQU;6)I82!296=I;VYA;"!!:7)P;W)T+"!-3R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XX-#@Z+3<W+C`S
M-"==(#T@)U=A<VAI;F=T;VX@1$,L(%)E86=A;B!.871I;VYA;"!!:7)P;W)T
M+"!602<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XX.#4Z
M+3<Y+C@U,R==(#T@)T5L:VEN<RP@16QK:6YS+5)A;F1O;'!H($-O=6YT>2U*
M96YN:6YG<R!286YD;VQP:"!&:65L9"P@5U8G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S@N.3,U.BTW-RXT-#@G72`]("=787-H:6YG=&]N
M($1#+"!787-H:6YG=&]N+41U;&QE<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+CDV-SHM
M,3`T+C@Q-R==(#T@)T%I<B!&;W)C92!!8V%D96UY+"!#3R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S.2XP-#,Z+3@T+C8W,B==(#T@)T-O
M=FEN9W1O;B`O($-I;F-I;FYA=&DL($-I;F-I;FYA=&D@+R!.;W)T:&5R;B!+
M96YT=6-K>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($M9)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C`W,SHM.34N-C(V)UT@/2`G5&]P
M96MA+"!0:&EL:7`@0FEL;&%R9"!-=6YI8VEP86P@06ER<&]R="P@2U,G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN,3`P.BTY-BXW-C<G
M72`]("=&;W)T(%)I;&5Y+"!+4R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S.2XQ,S0Z+3$P."XU,SDG72`]("='<F%N9"!*=6YC=&EO;BP@
M5V%L:V5R($9I96QD+"!#3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S.2XQ-C<Z+3<V+C8X,R==(#T@)T)A;'1I;6]R92P@0F%L=&EM;W)E
M+5=A<VAI;F=T;VX@26YT97)N871I;VYA;"!!:7)P;W)T+"!-1"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XR.34Z+3$Q-"XX-#4G72`]
M("=%;'DL($5L>2!!:7)P;W)T+"!.5B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S.2XR.3<Z+3DT+C<S,2==(#T@)TMA;G-A<R!#:71Y+"!+
M86YS87,@0VET>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U/)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C,V-SHM,3`Q+C8Y,R==(#T@
M)T=O;V1L86YD+"!296YN97(@1FEE;&0L($M3)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,Y+C0P,#HM,3(S+C@Q-R==(#T@)T9O<G0@0G)A
M9V<L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C0V
M-3HM-S0N-3@W)UT@/2`G071L86YT:6,@0VET>2P@071L86YT:6,@0VET>2!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($Y*)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,Y+C0X-#HM,3$Y+C<W,2==(#T@)U)E;F\L(%)E;F\@
M5&%H;V4@26YT97)N871I;VYA;"!!:7)P;W)T+"!.5B<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S.2XU-3$Z+3DW+C8U,2==(#T@)T-O;F-O
M<F1I82P@0FQO<W-E<B!-=6YI8VEP86P@06ER<&]R="P@2U,G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-C`Y.BTQ,3`N-S4U)UT@/2`G
M4')I8V4L($-A<F)O;B!#;W5N='D@06ER<&]R="P@550G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,SDN-S(U.BTX-BXR.#(G72`]("=);F1I
M86YA<&]L:7,L($EN9&EA;F%P;VQI<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M($E.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C<V-SHM
M-S0N,3`P)UT@/2`G0F%R;F5G870@0V]A<W0@1W5A<F0@4W1A=&EO;BP@3DHG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-S8X.BTY-"XY
M,#DG72`]("=3="X@2F]S97!H+"!2;W-E8W)A;G,@365M;W)I86P@06ER<&]R
M="P@34\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-S@S
M.BTQ,#0N.#8W)UT@/2`G1&5N=F5R("\@4W1A<&QE=&]N($EN=&5R;F%T:6]N
M86PL($-O+BP@0T\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,SDN.#,S.BTQ,#0N-C4W)UT@/2`G1&5N=F5R+"!$96YV97(@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!#3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S.2XX,S,Z+3@T+C`U,"==(#T@)T1A>71O;B`O(%=R:6=H="U0871T
M97)S;VX@06ER($9O<F-E($)A<V4L($]()SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,Y+C@T-3HM.#DN-C@T)UT@/2`G4W!R:6YG9FEE;&0L
M($-A<&ET86P@06ER<&]R="P@24PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,SDN.#8X.BTW-2XR,S$G72`]("=0:&EL861E;'!H:6$L(%!H
M:6QA9&5L<&AI82!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%!!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+CDP-CHM.#0N,C$Y)UT@/2`G
M1&%Y=&]N+"!#;W@@1&%Y=&]N($EN=&5R;F%T:6]N86P@06ER<&]R="P@3T@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN.3DU.BTX,BXX
M-S8G72`]("=#;VQU;6)U<RP@4&]R="!#;VQU;6)U<R!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L($]()SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0P+C`S,SHM-S0N,S$W)UT@/2`G3&%K96AU<G-T($YA=F%L($%I<B!3=&%T
M:6]N+"!.2B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XQ
M-3$Z+3$R,BXR-3(G72`]("=2960@0FQU9F8L(%)E9"!";'5F9B!-=6YI8VEP
M86P@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#`N,38W.BTQ,3(N.3,S)UT@/2`G1'5G=V%Y(%!R;W9I;F<@1W)O=6YD
M<RP@550G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N,C4P
M.BTY,RXW,3<G72`]("=3<&EC:V%R9"P@34\G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#`N,S`P.BTQ,#DN.3@S)UT@/2`G4F]O<V5V96QT
M+"!55"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XT.3,Z
M+3$P-RXU,C0G72`]("=#<F%I9RP@0W)A:6<M36]F9F%T($%I<G!O<G0L($-/
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C4P-#HM.#`N
M,C8V)UT@/2`G4&ET='-B=7)G:"P@4&ET='-B=7)G:"!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L(%!!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0P+C4Q-3HM,3(R+C(Y-R==(#T@)U)E9&1I;F<L(%)E9&1I;F<@375N:6-I
M<&%L($%I<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0P+C8S.3HM-S,N-S8R)UT@/2`G3F5W(%EO<FLL($ME;FYE9'D@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!.62<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,"XV-3$Z+3<U+C0T.2==(#T@)T%L;&5N=&]W;BP@3&5H
M:6=H(%9A;&QE>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%!!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C8V-SHM.#DN-C@T)UT@/2`G
M4&5O<FEA+"!'<F5A=&5R(%!E;W)I82!296=I;VYA;"!!:7)P;W)T+"!)3"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XV.#(Z+3<T+C$V
M.2==(#T@)TYE=V%R:RP@3F5W87)K($EN=&5R;F%T:6]N86P@06ER<&]R="P@
M3DHG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N-S,S.BTQ
M,30N,#,S)UT@/2`G5V5N9&]V97(@+R!!:7(@1F]R8V4@075X:6QL87)Y($9I
M96QD+"!55"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XW
M-S@Z+3$Q,2XY-CDG72`]("=386QT($QA:V4@0VET>2P@4V%L="!,86ME($-I
M='D@26YT97)N871I;VYA;"!!:7)P;W)T+"!55"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T,"XW-SDZ+3<S+C@X,"==(#T@)TYE=R!9;W)K
M+"!,82!'=6%R9&EA($%I<G!O<G0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0P+C@P,#HM,3(T+C$V-R==(#T@)T5U<F5K82P@0T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N.#,Q.BTY-BXW
M-C0G72`]("=,:6YC;VQN+"!,:6YC;VQN($UU;FEC:7!A;"!!:7)P;W)T+"!.
M12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XY,#(Z+3$Q
M-RXX,#<G72`]("=7:6YN96UU8V-A+"!7:6YN96UU8V-A($UU;FEC:7!A;"!!
M:7)P;W)T+"!.5B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M,"XY,3@Z+3@Q+C0T,R==(#T@)T%K<F]N+"!!:W)O;BU#86YT;VX@4F5G:6]N
M86P@06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#`N.34X.BTY."XS,3,G72`]("='<F%N9"!)<VQA;F0L($-E;G1R86P@
M3F5B<F%S:V$@4F5G:6]N86P@06ER<&]R="P@3D4G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#`N.3<X.BTX-2XQ.34G72`]("=&;W)T(%=A
M>6YE+"!&;W)T(%=A>6YE($EN=&5R;F%T:6]N86P@06ER<&]R="P@24XG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,#DY.BTQ,#(N.3@V
M)UT@/2`G4VED;F5Y+"!3:61N97D@375N:6-I<&%L($%I<G!O<G0L($Y%)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C$Q-SHM.34N.3`P
M)UT@/2`G3VUA:&$@+R!/9F9U='0@06ER($9O<F-E($)A<V4L($Y%)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C$R,CHM,3`P+C8V."==
M(#T@)TYO<G1H(%!L871T92P@3F]R=&@@4&QA='1E(%)E9VEO;F%L($%I<G!O
M<G0L($Y%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C$U
M.#HM,3`T+C@P-R==(#T@)T-H97EE;FYE+"!#:&5Y96YN92!!:7)P;W)T+"!7
M62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XQ-3@Z+3<S
M+C$R.2==(#T@)T)R:61G97!O<G0L(%-I:V]R<VMY($UE;6]R:6%L($%I<G!O
M<G0L($-4)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C$Y
M-#HM,3$R+C`Q-B==(#T@)T]G9&5N+"!/9V1E;BU(:6YC:VQE>2!!:7)P;W)T
M+"!55"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XR-#,Z
M+3<V+CDR,B==(#T@)U=I;&QI86US<&]R="P@5VEL;&EA;7-P;W)T+4QY8V]M
M:6YG($-O=6YT>2!!:7)P;W)T+"!002<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,2XR-30Z+3@P+C8W-"==(#T@)UEO=6YG<W1O=VXL(%EO
M=6YG<W1O=VXM5V%R<F5N(%)E9VEO;F%L($%I<G!O<G0L($]()SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C,Q,#HM.34N.#DY)UT@/2`G
M3VUA:&$L($5P<&QE>2!!:7)F:65L9"P@3D4G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#$N,S$W.BTY-BXS-C<G72`]("=686QL97DL($Y%
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C,S.3HM-S4N
M-S(W)UT@/2`G5VEL:V5S+4)A<G)E("T@4V-R86YT;VXL(%=I;&ME<RU"87)R
M92`O(%-C<F%N=&]N($EN=&5R;F%T:6]N86P@06ER<&]R="P@4$$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,S8W.BTX."XV.#,G72`]
M("=-87)S96EL;&5S($ES;&%N9"P@24PG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#$N-#`U.BTX,2XX-3,G72`]("=#;&5V96QA;F0L($-L
M979E;&%N9"U(;W!K:6YS($EN=&5R;F%T:6]N86P@06ER<&]R="P@3T@G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N-#4Q.BTY,"XU,34G
M72`]("=-;VQI;F4L(%%U860M0VET>2!!:7)P;W)T+"!)3"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,2XU,S@Z+3DS+C8V-B==(#T@)T1E
M<R!-;VEN97,L($1E<R!-;VEN97,@26YT97)N871I;VYA;"!!:7)P;W)T+"!)
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XU.#DZ+3@S
M+C@P,2==(#T@)U1O;&5D;RP@5&]L961O($5X<')E<W,@06ER<&]R="P@3T@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N-3DT.BTQ,#DN
M,#8U)UT@/2`G4F]C:R!3<')I;F=S+"!2;V-K(%-P<FEN9W,M4W=E971W871E
M<B!#;W5N='D@06ER<&]R="P@5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#$N-C4P.BTW,"XU,3<G72`]("=/=&ES($%I<B!.871I;VYA
M;"!'=6%R9"!"87-E+"!-02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,2XV-C<Z+38Y+CDV-R==(#T@)T-H871H86TL($U!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C<P.3HM.#8N,S$Y)UT@/2`G
M4V]U=&@@0F5N9"P@4V]U=&@@0F5N9"!296=I;VYA;"!!:7)P;W)T+"!)3B<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XW,C0Z+3<Q+C0R
M."==(#T@)U!R;W9I9&5N8V4L(%1H96]D;W)E($9R86YC:7,@1W)E96X@4W1A
M=&4@06ER<&]R="P@4DDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#$N-S@T.BTX-RXW-34G72`]("=#:&EC86=O+"!#:&EC86=O($UI9'=A
M>2!!:7)P;W)T+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,2XX-C<Z+3$P,RXU.#8G72`]("=38V]T='-B;'5F9BP@2&5I;&EG($9I
M96QD+"!.12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XX
M.#,Z+3DQ+C<R-"==(#T@)T-E9&%R(%)A<&ED<RP@0V5D87(@4F%P:61S($UU
M;FEC:7!A;"!!:7)P;W)T+"!)02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,2XY,S@Z+3<R+C8X,R==(#T@)U=I;F1S;W(@3&]C:W,L($)R
M861L97D@26YT97)N871I;VYA;"!!:7)P;W)T+"!#5"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,2XY.#`Z+3@W+CDP-"==(#T@)T-H:6-A
M9V\L($-H:6-A9V\M3UPG2&%R92!);G1E<FYA=&EO;F%L($%I<G!O<G0L($E,
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+CDX,3HM.3<N
M-#,W)UT@/2`G3F]R9F]L:RP@4W1E9F%N($UE;6]R:6%L($%I<G!O<G0L($Y%
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C`X,#HM.#`N
M,3@S)UT@/2`G17)I92P@17)I92!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%!!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C$Y,SHM.#DN
M,#DS)UT@/2`G4F]C:V9O<F0L($=R96%T97(@4F]C:V9O<F0@06ER<&]R="P@
M24PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,C`P.BTW
M,BXU,S,G72`]("=#:&EC;W!E92!&86QL<R`O(%=E<W1O=F5R($%I<B!&;W)C
M92!"87-E+"!-02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M,BXR,#@Z+3<U+CDX,2==(#T@)T)I;F=H86UT;VXL($)I;F=H86UT;VX@4F5G
M:6]N86P@06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#(N,C,Q.BTX,RXS,S$G72`]("=$971R;VET+"!$971R;VET($UE
M=')O<&]L:71A;B!787EN92!#;W5N='D@06ER<&]R="P@34DG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,S8Q.BTW,2XP,3$G72`]("="
M;W-T;VXL($QO9V%N($EN=&5R;F%T:6]N86P@06ER<&]R="P@34$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,S@Q.BTQ,C(N.#<R)UT@
M/2`G365D9F]R9"P@4F]G=64@5F%L;&5Y($EN=&5R;F%T:6]N86P@06ER<&]R
M="P@3U(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,SDX
M.BTY,"XW,#0G72`]("=$=6)U<75E+"!$=6)U<75E(%)E9VEO;F%L($%I<G!O
M<G0L($E!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C0P
M,CHM.38N,S@T)UT@/2`G4VEO=7@@0VET>2P@4VEO=7@@1V%T97=A>2!!:7)P
M;W)T+"!)02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXT
M-C@Z+3<Q+C(Y-"==(#T@)T)E9&9O<F0L($AA;G-C;VT@1FEE;&0L($U!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C4U,#HM.30N,3@S
M)UT@/2`G1F]R="!$;V1G92P@24$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#(N-34T.BTY,BXT,#$G72`]("=7871E<FQO;RP@5V%T97)L
M;V\@375N:6-I<&%L($%I<G!O<G0L($E!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0R+C4W.3HM,3$P+C$P,R==(#T@)T)I9R!0:6YE>2P@
M0FEG(%!I;F5Y+4UA<F)L971O;B!!:7)P;W)T+"!762<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,BXW-#<Z+3<S+C<Y.2==(#T@)T%L8F%N
M>2P@06QB86YY($-O=6YT>2!!:7)P;W)T+"!.62<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T,BXW.#`Z+3@T+C4W.2==(#T@)TQA;G-I;F<L
M($-A<&ET86P@0VET>2!!:7)P;W)T+"!-22<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,BXW.30Z+3$P-2XS.#(G72`]("=$;W5G;&%S+"!#
M;VYV97)S92!#;W5N='D@06ER<&]R="P@5UDG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#(N.#$U.BTQ,#@N-S(X)UT@/2`G3&%N9&5R+"!7
M62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXX-3DZ+3$P
M,"XU-3$G72`]("=686QE;G1I;F4L($UI;&QE<B!&:65L9"P@3D4G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N.#@Q.BTX-2XU,C,G72`]
M("='<F%N9"!287!I9',L($=E<F%L9"!2+B!&;W)D($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@34DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#(N.#DX.BTQ,#8N-#<S)UT@/2`G0V%S<&5R+"!.871R;VYA($-O=6YT>2!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L(%=9)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0R+CDR,#HM,3$R+C4W,2==(#T@)U!O8V%T96QL;RP@
M4&]C871E;&QO(%)E9VEO;F%L($%I<G!O<G0L($E$)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0R+CDT,3HM-S@N-S,V)UT@/2`G0G5F9F%L
M;RP@1W)E871E<B!"=69F86QO($EN=&5R;F%T:6]N86P@06ER<&]R="P@3EDG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N.34U.BTX-RXY
M,#0G72`]("=-:6QW875K964L($=E;F5R86P@36ET8VAE;&P@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!722<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,BXY-C<Z+3@S+C<T.2==(#T@)T9L:6YT+"!":7-H;W`@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!-22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,RXP-C(Z+3$P."XT-#8G72`]("=2:79E<G1O;BP@4FEV97)T
M;VX@4F5G:6]N86P@06ER<&]R="P@5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#,N,3`Y.BTW-BXQ,#,G72`]("=3>7)A8W5S92P@4WER
M86-U<V4@2&%N8V]C:R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y9)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+C$Q-SHM-S<N-C<W)UT@
M/2`G4F]C:&5S=&5R+"!'<F5A=&5R(%)O8VAE<W1E<B!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0S+C$T,3HM.#DN,S0U)UT@/2`G36%D:7-O;BP@1&%N92!#;W5N='D@4F5G
M:6]N86PM5')U87@@1FEE;&0L(%=))SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0S+C$W,3HM.#8N,C,W)UT@/2`G375S:V5G;VXL($UU<VME
M9V]N($-O=6YT>2!!:7)P;W)T+"!-22<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,RXQ.34Z+3<Q+C4P,2==(#T@)T-O;F-O<F0L($-O;F-O
M<F0@375N:6-I<&%L($%I<G!O<G0L($Y()SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0S+C,Y,3HM.3DN.#0S)UT@/2`G5VEN;F5R+"!";V(@
M5VEL97D@1FEE;&0@06ER<&]R="P@4T0G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#,N-38W.BTQ,38N,C0Q)UT@/2`G0F]I<V4L($)O:7-E
M($%I<B!497)M:6YA;"P@240G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#,N-3<W.BTY-BXW-30G72`]("=3:6]U>"!&86QL<RP@1F]S<R!&
M:65L9"P@4T0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N
M-3DU.BTQ,3@N.34V)UT@/2`G0G5R;G,L($)U<FYS($UU;FEC:7!A;"!!:7)P
M;W)T+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXV
M-#(Z+3<P+C,P-"==(#T@)U!O<G1L86YD+"!0;W)T;&%N9"!);G1E<FYA=&EO
M;F%L($IE='!O<G0L($U%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0S+C<V-SHM.3DN,S$X)UT@/2`G0VAA;6)E<FQA:6XL($-H86UB97)L
M86EN($UU;FEC:7!A;"!!:7)P;W)T+"!31"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,RXX-SDZ+3DQ+C(U-R==(#T@)TQA($-R;W-S92P@
M3&$@0W)O<W-E($UU;FEC:7!A;"!!:7)P;W)T+"!722<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,RXY,#`Z+38Y+CDS-2==(#T@)T)R=6YS
M=VEC:RP@3F%V86P@06ER(%-T871I;VXL($U%)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0S+CDP-#HM.3(N-#DR)UT@/2`G4F]C:&5S=&5R
M+"!2;V-H97-T97(@26YT97)N871I;VYA;"!!:7)P;W)T+"!-3B<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XP-#8Z+3$P,RXP-30G72`]
M("=287!I9"!#:71Y+"!287!I9"!#:71Y(%)E9VEO;F%L($%I<G!O<G0L(%-$
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C`U,#HM-S4N
M-S,S)UT@/2`G1F]R="!$<G5M("\@5VAE96QE<BU386-K(%4N(%,N($%R;7D@
M06ER9FEE;&0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0T+C$S,SHM,3(S+C(Q-"==(#T@)T5U9V5N92P@36%H;&]N(%-W965T($9I
M96QD+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XR
M-C<Z+3<Q+C,P,"==(#T@)TUO=6YT(%=A<VAI;F=T;VXL($Y()SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C,S.3HM,3`U+C4T,B==(#T@
M)T=I;&QE='1E+"!':6QL971T92U#86UP8F5L;"!#;W5N='D@06ER<&]R="P@
M5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N,S4Q.BTX
M-"XV-S0G72`]("=(;W5G:'1O;B!,86ME+"!2;W-C;VUM;VX@0V]U;G1Y($%I
M<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T
M+C,X.#HM.3@N,C(X)UT@/2`G2'5R;VXL($AU<F]N(%)E9VEO;F%L($%I<G!O
M<G0L(%-$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C0Q
M.3HM-S(N,#$Y)UT@/2`G4V%I;G0@2F]H;G-B=7)Y+"!65"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-"XT-C@Z+3<S+C$U,"==(#T@)T)U
M<FQI;F=T;VXL($)U<FQI;F=T;VX@26YT97)N871I;VYA;"!!:7)P;W)T+"!6
M5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XT-SDZ+3@X
M+C$S-R==(#T@)T=R965N($)A>2P@075S=&EN(%-T<F%U8F5L($EN=&5R;F%T
M:6]N86P@06ER<&]R="P@5TDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#0N-3$W.BTQ,#DN,#$W)UT@/2`G0V]D>2P@5UDG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N-3,S.BTW,"XU,S,G72`]("=2
M=6UF;W)D+"!-12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M-"XU-S8Z+3<Q+C$W.2==(#T@)T)E<FQI;BP@0F5R;&EN($UU;FEC:7!A;"!!
M:7)P;W)T+"!.2"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M-"XW-CDZ+3$P-BXY-CDG72`]("=3:&5R:61A;BP@4VAE<FED86X@0V]U;G1Y
M($%I<G!O<G0L(%=9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0T+C@S,SHM.#0N-34P)UT@/2`G1W)A>6EN9R!!:7(@1F]R8V4@4F%N9V4L
M($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C@X,SHM
M.3,N,C(Y)UT@/2`G36EN;F5A<&]L:7,L($UI;FYE87!O;&ES+5-T+B!0875L
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@34XG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#0N.3`X.BTQ,C(N.3DU)UT@/2`G4V%L96TL($UC
M3F%R>2!&:65L9"P@3U(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#0N.3$W.BTV-RXP,#`G72`]("=%87-T<&]R="P@344G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N.3,S.BTW,BXR,#`G72`]("=.
M97=P;W)T+"!65"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M-2XP-S(Z+3@S+C4V-"==(#T@)T%L<&5N82P@06QP96YA($-O=6YT>2!296=I
M;VYA;"!!:7)P;W)T+"!-22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T-2XT-#,Z+3DX+C0Q,R==(#T@)T%B97)D965N+"!!8F5R9&5E;B!2
M96=I;VYA;"!!:7)P;W)T+"!31"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-2XU-#4Z+3DT+C`U,B==(#T@)U-T+B!#;&]U9"P@4W0N($-L
M;W5D($UU;FEC:7!A;"!!:7)P;W)T+"!-3B<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T-2XU.3$Z+3$R,BXV,#`G72`]("=0;W)T;&%N9"P@
M4&]R=&QA;F0@26YT97)N871I;VYA;"!!:7)P;W)T+"!/4B<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-2XV.3@Z+3$Q."XX,S0G72`]("=0
M96YD;&5T;VXL($5A<W1E<FX@3W)E9V]N(%)E9VEO;F%L($%T(%!E;F1L971O
M;B!!:7)P;W)T+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T-2XW-3`Z+3@W+C`S,R==(#T@)T5S8V%N86)A+"!-22<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-2XX,#<Z+3$P."XU-#(G72`]("="
M:6QL:6YG<RP@0FEL;&EN9W,@3&]G86X@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-2XY,S,Z
M+3DP+C0U,"==(#T@)U!A<FL@1F%L;',L(%=))SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0V+C$U-SHM,3(S+C@X,B==(#T@)T%S=&]R:6$L
M($%S=&]R:6$@4F5G:6]N86P@06ER<&]R="P@3U(G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#8N,S<U.BTQ,3<N,#$T)UT@/2`G3&5W:7-T
M;VXL($QE=VES=&]N+4YE>B!097)C92!#;W5N='D@06ER<&]R="P@240G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#8N-#(X.BTQ,#4N.#@V
M)UT@/2`G36EL97,@0VET>2P@1G)A;FL@5VEL97D@1FEE;&0@06ER<&]R="P@
M350G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#8N-#<Y.BTX
M-"XS-3<G72`]("=3875L="!3=&4N($UA<FEE+"!-22<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T-BXU,S,Z+3@W+C4U,"==(#T@)TUA<G%U
M971T92P@34DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#8N
M-38T.BTQ,C`N-3,T)UT@/2`G66%K:6UA+"!986MI;6$@06ER(%1E<FUI;F%L
M+"!702<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXU-C<Z
M+3$Q.2XV,#`G72`]("=(86YF;W)D+"!702<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T-BXV,#`Z+3DT+C,Q-R==(#T@)U!E<75O="!,86ME
M+"!-3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXV,#8Z
M+3$Q,2XY-C0G72`]("=(96QE;F$L($AE;&5N82!296=I;VYA;"!!:7)P;W)T
M+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXV.#,Z
M+38X+C`U,"==(#T@)U!R97-Q=64@27-L92P@344G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#8N-S@R.BTQ,#`N-S4W)UT@/2`G0FES;6%R
M8VLL($)I<VUA<F-K($UU;FEC:7!A;"!!:7)P;W)T+"!.1"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-BXX-#,Z+3DR+C(R-B==(#T@)T1U
M;'5T:"P@1'5L=71H($EN=&5R;F%T:6]N86P@06ER<&]R="P@34XG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#8N.#8W.BTV."XP,3,G72`]
M("=#87)I8F]U+"!#87)I8F]U($UU;FEC:7!A;"!!:7)P;W)T+"!-12<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXY,C$Z+3$Q-"XP.3,G
M72`]("=-:7-S;W5L82P@36ES<V]U;&$@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXY,C4Z
M+3DV+C@Q,2==(#T@)T9A<F=O+"!(96-T;W(@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!.1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXY
M-S,Z+3$R,BXY,#,G72`]("=/;'EM<&EA+"!/;'EM<&EA($%I<G!O<G0L(%=!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0W+C$Q-SHM,3(R
M+C4U,"==(#T@)T9O<G0@3&5W:7,@+R!'<F%Y(%4N(%,N($%R;7D@06ER9FEE
M;&0L(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0W+C$U
M,#HM,3(R+C0X,R==(#T@)U1A8V]M82`O($UC0VAO<F0@06ER($9O<F-E($)A
M<V4L(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0W+C$V
M.#HM.#@N-#@Y)UT@/2`G2&%N8V]C:RP@2&]U9VAT;VX@0V]U;G1Y($UE;6]R
M:6%L($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0W+C0T-3HM,3(R+C,Q-"==(#T@)U-E871T;&4L(%-E871T;&4M5&%C
M;VUA($EN=&5R;F%T:6]N86P@06ER<&]R="P@5T$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#<N-#<S.BTQ,3$N,S@R)UT@/2`G1W)E870@
M1F%L;',L($=R96%T($9A;&QS($EN=&5R;F%T:6]N86P@06ER<&]R="P@350G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N-3`P.BTY-"XY
M,S,G72`]("="96UI9&II+"!-3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-RXV,C$Z+3$Q-RXU,C@G72`]("=3<&]K86YE+"!3<&]K86YE
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@5T$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#<N-S4P.BTQ,#$N.#,S)UT@/2`G4F]S96=L96XL
M($Y$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0W+CDS.#HM
M,3(T+C4U-2==(#T@)U%U:6QL87EU=&4L(%%U:6QL87EU=&4@4W1A=&4@06ER
M<&]R="P@5T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#@N
M,3`P.BTY."XX-C<G72`]("=$979I;',@3&%K92P@3D0G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#@N,3,S.BTQ,C,N-#`P)UT@/2`G4&]R
M="!!;F=E;&5S($-O87-T($=U87)D($%I<B!3=&%T:6]N+"!702<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XQ-S0Z+3$P,RXV,S<G72`]
M("=7:6QL:7-T;VXL(%-L;W5L:6X@1FEE;&0@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!.1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XR
M,30Z+3$P-BXV,C$G72`]("=';&%S9V]W+"!';&%S9V]W($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@350G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#@N,S`T.BTQ,30N,C8T)UT@/2`G2V%L:7-P96QL+"!';&%C:65R(%!A
M<FL@26YT97)N871I;VYA;"!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T."XU-#,Z+3$P.2XW-C,G72`]("=(879R92P@
M2&%V<F4@0VET>2U#;W5N='D@06ER<&]R="P@350G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#@N-38R.BTY,RXS.3@G72`]("=);G1E<FYA
M=&EO;F%L($9A;&QS+"!&86QL<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U.
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0X+CDS,SHM.34N
M,S4P)UT@/2`G5V%R<F]A9"P@34XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-3$N.#DP.BTQ-S8N-C(U)UT@/2`G061A:RP@3F%V86P@06ER
M(%-T871I;VXL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S4R+C<Q-SHQ-S0N,3$W)UT@/2`G4VAE;7EA+"!%87)E8VMS;VX@07,L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4R+CDU,#HM,38X
M+C@U,"==(#T@)TYI:V]L<VMI+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<U,RXY,#`Z+3$V-BXU-3`G72`]("=$=71C:"!(87)B;W(L
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4U+C`S,SHM
M,3,Q+C4V-R==(#T@)T%N;F5T=&4@27-L86YD+"!!2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<U-2XR,C$Z+3$V,BXW,C@G72`]("=#;VQD
M($)A>2P@0V]L9"!"87D@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-34N,S4S.BTQ,S$N-S(R)UT@/2`G2V5T8VAI:V%N
M+"!+971C:&EK86X@26YT97)N871I;VYA;"!!:7)P;W)T+"!!2R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-2XU.#,Z+3$S,RXP.#,G72`]
M("=+;&%W;V-K+"!+;&%W;V-K($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S4V+C0X,SHM,3,R+C,V-R==(#T@)U=R86YG
M96QL+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-BXX
M,3<Z+3$S,BXY-C<G72`]("=0971E<G-B=7)G+"!!2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<U-BXY-3`Z+3$U."XV,3<G72`]("=0;W)T
M($AE:61E;BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-3<N,#0X.BTQ,S4N,S8U)UT@/2`G4VET:V$L(%-I=&MA($%I<G!O<G0L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4W+C$U,#HM,3<P
M+C(Q-R==(#T@)U-A:6YT(%!A=6PL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S4W+C4P,#HM,3,T+C4X,R==(#T@)T%N9V]O;BP@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3<N-S4P.BTQ-3(N
M-3`P)UT@/2`G2V]D:6%K+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<U."XS-38Z+3$S-"XU-C,G72`]("=*=6YE874L($IU;F5A=2!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S4X+C0Q-SHM,3,U+C<S,R==(#T@)T=U<W1A=G5S+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U."XV-3`Z+3$V
M,BXP-C<G72`]("=#87!E($YE=V5N:&%M($%I<G=A>7,@1F%C:6QI=&EE<R!3
M96-T;W(L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4X
M+C8X-#HM,34V+C8U-"==(#T@)TMI;F<@4V%L;6]N+"!+:6YG(%-A;&UO;B!!
M:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U
M.2XP-3`Z+3$U."XU,3<G72`]("=$:6QL:6YG:&%M($UU;FEC:7!A;"P@06LL
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4Y+C0S,SHM
M,30V+C,S,R==(#T@)TUI9&1L971O;B!)<VQA;F0L($%K+"!!2R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U.2XT-C<Z+3$S-2XS,#`G72`]
M("=3:V%G=V%Y+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<U.2XU,3<Z+3$S.2XV-C<G72`]("=986MU=&%T+"!!2R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<U.2XV,S,Z+3$U,2XU,#`G72`]("=(
M;VUE<B`O($UU;FEC:7!A;"P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-3DN-S4P.BTQ-30N.3$W)UT@/2`G26QI86UN82`O($EL:6%M
M;F$@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-3DN.#`P.BTQ-#0N-C`P)UT@/2`G0V%P92!386EN="!%;&EA<RP@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C`N,#@S.BTQ-#(N
M-3`P)UT@/2`G66%K871A9V$L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S8P+C$Q-SHM,30Y+C0U,"==(#T@)U-E=V%R9"P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C`N-#DR.BTQ-#4N-#<X
M)UT@/2`G0V]R9&]V82P@365R;&4@2RX@*$UU9&AO;&4I(%-M:71H($%I<G!O
M<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8P+C4X
M,#HM,34Q+C(S.2==(#T@)TME;F%I+"!+96YA:2!-=6YI8VEP86P@06ER<&]R
M="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C`N-S@S
M.BTQ-C$N.#,S)UT@/2`G0F5T:&5L("\@0F5T:&5L($%I<G!O<G0L($%+)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+C$P,#HM,34U+C4V
M-R==(#T@)U-P87)R979O:&X@06ER=V%Y<R!&86-I;&ET:65S(%-E8W1O<BP@
M04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C$N,3<T.BTQ
M-#DN.3DV)UT@/2`G06YC:&]R86=E+"!4960@4W1E=F5N<R!!;F-H;W)A9V4@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<V,2XR-3`Z+3$T.2XX,#`G72`]("=!;F-H;W)A9V4@
M+R!%;&UE;F1O<F8@06ER($9O<F-E($)A<V4L($%+)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S8Q+C(V-SHM,30Y+C8U,"==(#T@)T9T+B!2
M:6-H87)D<V]N("\@0G)Y86YT(%4N(%,N($%R;7D@2&5L:7!O<G0L($%K+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,2XU.#,Z+3$U
M.2XU,S,G72`]("=!;FEA:RP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-C$N-C`P.BTQ-#DN,#@S)UT@/2`G4&%L;65R+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,2XW.#,Z+3$V-BXP,S,G
M72`]("=#87!E(%)O;6%N>F]F9B!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,2XY-C<Z
M+3$U,2XQ.#,G72`]("=3:W=E;G1N82P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C(N,3`P.BTQ-3(N-S4P)UT@/2`G4'5N=&EL;&$L
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8R+C$U,#HM
M,30U+C0U,"==(#T@)T=U;&MA;F$L($=U;&MA;F$@06ER<&]R="P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C(N,S(Q.BTQ-3`N,#DT
M)UT@/2`G5&%L:V5E=&YA+"!486QK965T;F$@06ER<&]R="P@04LG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C(N.38S.BTQ-#$N.3,V)UT@
M/2`G3F]R=&AW87DL($YO<G1H=V%Y($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S8R+CDV-SHM,34U+C8Q-R==(#T@)TUC
M1W)A=&@L($UC1W)A=&@@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C,N-S8W.BTQ-S$N-S,S)UT@/2`G1V%M8F5L;"!!
M=71O;6%T:6,@5V5A=&AE<B!/8G-E<G9I;F<@+R!297!O<G1I;F<@4WES=&5M
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,RXX.#,Z
M+3$V,"XX,#`G72`]("=5;F%L86ML965T+"!!2R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<V,RXY,#`Z+3$U,BXR-C<G72`]("=-:6YC:'5M
M:6YA+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-"XP
M,#`Z+3$T-2XW,S,G72`]("=&;W)T($=R965L>2`O($%L;&5N(%4N(%,N($%R
M;7D@06ER9FEE;&0L($%K+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<V-"XU,3(Z+3$V-2XT,S8G72`]("=.;VUE+"!.;VUE($%I<G!O
M<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8T+C4U
M,#HM,30Y+C`X,R==(#T@)TYE;F%N82`O($UU;BXL($%+)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S8T+C8U,#HM,30W+C`V-R==(#T@)T9A
M:7)B86YK<R`O($5I96QS;VX@06ER($9O<F-E($)A<V4L($%+)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8T+C<S,SHM,34V+CDS,R==(#T@
M)T=A;&5N82!!+BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-C0N.#`T.BTQ-#<N.#<V)UT@/2`G1F%I<F)A;FMS+"!&86ER8F%N:W,@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<V-2XQ-C<Z+3$U,BXQ,#`G72`]("=486YA;F$L($-A
M;&AO=6X@365M;W)I86P@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C4N,C4P.BTQ-C8N.#8W)UT@/2`G4&]R="!#;&%R
M96YC92P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C4N
M-38W.BTQ-C<N.3$W)UT@/2`G5&EN($-I='D@06ER=V%Y<R!&86-I;&ET:65S
M(%-E8W1O<BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-C4N.3@R.BTQ-C$N,34R)UT@/2`G0G5C:VQA;F0L($)U8VML86YD($%I<G!O
M<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8V+C`P
M,#HM,34S+C<P,"==(#T@)TEN9&EA;B!-;W5N=&%I;B!!:7)W87ES($9A8VEL
M:71I97,@4V5C=&]R+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<V-BXU-C<Z+3$T-2XR-C<G72`]("=&;W)T(%EU:V]N+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-BXX.#8Z+3$V,BXV,#0G
M72`]("=+;W1Z96)U92P@5VEE;B!-96UO<FEA;"!!:7)P;W)T+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-BXY,3<Z+3$U,2XU,3<G
M72`]("="971T;&5S+"!"971T;&5S($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S8W+C$P,#HM,34W+C@U,"==(#T@)T%M
M8FQE<BP@06UB;&5R($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S8X+C@X,SHM,38V+C$S,R==(#T@)T-A<&4@3&ES8G5R
M;F4@06ER=V%Y<R!&86-I;&ET:65S(%-E8W1O<BP@04LG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-CDN,S8W.BTQ-3(N,3,S)UT@/2`G56UI
M870L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Y+C@Q
M-SHM,38R+CDQ-R==(#T@)U!O:6YT($QA>2P@04LG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-S`N,3,S.BTQ-#,N-C,S)UT@/2`G0F%R=&5R
M($ES;&%N9"P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-S`N,C$P.BTQ-3$N,#`V)UT@/2`G3G5I<7-U="P@3G5I<7-U="!!:7)P;W)T
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<W,"XU,#`Z
M+3$T.2XX.#,G72`]("=/;&EK=&]K($1I<W1A;G0@16%R;'D@5V%R;FEN9RP@
M04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-S`N-C,S.BTQ
M-3DN.#4P)UT@/2`G5V%I;G=R:6=H="P@5V%I;G=R:6=H="!!:7)P;W)T+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<W,2XR.#0Z+3$U
M-BXW-S@G72`]("="87)R;W<L(%!O<W0@4F]G97)S($UE;6]R:6%L($%I<G!O
M<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,"XS.#,Z+34V
M+C4P,"==(#T@)T%R=&EG87,G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG
M+3,P+C@X,SHM-34N-3,S)UT@/2`G4FEV97)A)SL*)&-O;W)D:6YA=&5S6R=5
M<G5G=6%Y)UU;)RTS,2XS.#,Z+34W+CDU,"==(#T@)U-A;'1O)SL*)&-O;W)D
M:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,2XW,#`Z+34U+CDX,R==(#T@)U1A8W5A
M<F5M8F\G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG+3,R+C,S,SHM-3@N
M,#,S)UT@/2`G4&%Y<V%N9'4G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG
M+3,R+C,V-SHM-30N,C$W)UT@/2`G365L;R<["B1C;V]R9&EN871E<ULG57)U
M9W5A>2==6R<M,S,N,C$W.BTU-"XS.#,G72`]("=4<F5I;G1A(%D@5')E<R<[
M"B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S,N,C4P.BTU."XP-C<G72`]
M("=-97)C961E<R<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S,N,S4P
M.BTU-BXU,#`G72`]("=$=7)A>FYO)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y
M)UU;)RTS-"XT-3`Z+34W+C@S,R==(#T@)T-O;&]N:6$G.PHD8V]O<F1I;F%T
M97-;)U5R=6=U87DG75LG+3,T+C<X,SHM-38N,C4P)UT@/2`G365L:6QL82<[
M"B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S0N.#,S.BTU-BXP,#`G72`]
M("=#87)R87-C;R<["B1C;V]R9&EN871E<ULG57IB96MI<W1A;B==6R<S-RXR
M,S,Z-C<N,C8W)UT@/2`G5&5R;65Z)SL*)&-O;W)D:6YA=&5S6R=5>F)E:VES
M=&%N)UU;)S,Y+C4V-SHV-BXY-3`G72`]("=386UA<FMA;F0G.PHD8V]O<F1I
M;F%T97-;)U5Z8F5K:7-T86XG75LG-#`N,3$W.C8W+C@S,R==(#T@)T1Z:7IA
M:R<["B1C;V]R9&EN871E<ULG57IB96MI<W1A;B==6R<T,2XR-C<Z-CDN,C8W
M)UT@/2`G5&%S:&ME;G0G.PHD8V]O<F1I;F%T97-;)U5Z8F5K:7-T86XG75LG
M-#$N-S,S.C8T+C8Q-R==(#T@)U1A;61Y)SL*)&-O;W)D:6YA=&5S6R=686YU
M871U)UU;)RTQ,RXX-3`Z,38W+C4U,"==(#T@)U-O;&$@5F%N=6$@3&%V82<[
M"B1C;V]R9&EN871E<ULG5F%N=6%T=2==6R<M,34N-3$W.C$V-RXR,3<G72`]
M("=096MO82!!:7)P;W)T(%-A;G1O)SL*)&-O;W)D:6YA=&5S6R=686YU871U
M)UU;)RTQ-BXT,3<Z,38W+C@P,"==(#T@)TQA;6%P($UA;&5K=6QA)SL*)&-O
M;W)D:6YA=&5S6R=686YU871U)UU;)RTQ-RXW,#`Z,38X+C,P,"==(#T@)T)A
M=65R9FEE;&0@169A=&4G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q
M,"XP-C<Z+38Y+C,Q-R==(#T@)T)A<G%U:7-I;65T;R<["B1C;V]R9&EN871E
M<ULG5F5N97IU96QA)UU;)S$P+C$Q-SHM-C0N-C@S)UT@/2`G0F%R8V5L;VYA
M)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N,38W.BTV-RXY,S,G
M72`]("=686QE;F-I82<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S$P
M+C(U,#HM-C<N-C4P)UT@/2`G36%R86-A>2U"+B!!+B!3=6-R92<["B1C;V]R
M9&EN871E<ULG5F5N97IU96QA)UU;)S$P+C0U,#HM-C0N,3@S)UT@/2`G0W5M
M86YA)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N-3`P.BTV-BXX
M.#,G72`]("=#87)A8V%S("\@3&$@0V%R;&]T82<["B1C;V]R9&EN871E<ULG
M5F5N97IU96QA)UU;)S$P+C4P,#HM-C@N,#`P)UT@/2`G4'1O+B!#86)E;&QO
M)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N-38W.BTW,2XW,S,G
M72`]("=-87)A8V%I8F\M3&$@0VAI;FET82<["B1C;V]R9&EN871E<ULG5F5N
M97IU96QA)UU;)S$P+C4X,SHM-C(N,S$W)UT@/2`G1W5I<FEA)SL*)&-O;W)D
M:6YA=&5S6R=696YE>G5E;&$G75LG,3`N-C`P.BTV-BXY.#,G72`]("=#87)A
M8V%S("\@36%I<75E=&EA($%E<F]P+B!);G1L+B!3:6UO;B!";VQI=F%R)SL*
M)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3$N-#$W.BTV.2XV.#,G72`]
M("=#;W)O)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3$N.#`P.BTV
M-BXQ.#,G72`]("=,82!/<F-H:6QA)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E
M;&$G75LG-"XV,#`Z+38Q+C$Q-R==(#T@)U-A;G1A($5L96YA($1E(%5A:7)E
M;B<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S4N-C`P.BTV-RXU,#`G
M72`]("=0=65R=&\@07EA8W5C:&\G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L
M82==6R<W+C(S,SHM-S`N.#`P)UT@/2`G1W5A<V1U86QI=&\G.PHD8V]O<F1I
M;F%T97-;)U9E;F5Z=65L82==6R<W+C,P,#HM-C$N-#4P)UT@/2`G5'5M97)E
M;6\G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<W+C4X,SHM-S(N,#8W
M)UT@/2`G4W1O+B!$;VUI;F=O)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G
M75LG-RXX-3`Z+3<R+C0U,"==(#T@)U-A;B!!;G1O;FEO($1E;"!486-H:7)A
M)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG-RXY,#`Z+38W+C0Q-R==
M(#T@)U-A;B!&97)N86YD;R!$92!!<'5R92<["B1C;V]R9&EN871E<ULG5F5N
M97IU96QA)UU;)S@N,34P.BTV,RXU-3`G72`]("=#:75D860@0F]L:79A<B<[
M"B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S@N-C`P.BTW,2XQ.#,G72`]
M("=-97)I9&$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<X+C8Q-SHM
M-S`N,C$W)UT@/2`G0F%R:6YA<R<["B1C;V]R9&EN871E<ULG5F5N97IU96QA
M)UU;)S@N.3,S.BTV-RXT,3<G72`]("=#86QA8F]Z;R<["B1C;V]R9&EN871E
M<ULG5F5N97IU96QA)UU;)SDN,#$W.BTV,BXV,3<G72`]("=496UB;&%D;W(G
M.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Y+C`Q-SHM-CDN-S,S)UT@
M/2`G1W5A;F%R92<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)SDN,C$W
M.BTV-BXP,3<G72`]("=686QL92!$92!,82!087-C=6$G.PHD8V]O<F1I;F%T
M97-;)U9E;F5Z=65L82==6R<Y+C,U,#HM-S`N-C$W)UT@/2`G5F%L97)A)SL*
M)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG.2XU-3`Z+38Y+C(S,R==(#T@
M)T%C87)I9W5A)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG.2XW-3`Z
M+38S+C$X,R==(#T@)TUA='5R:6XG.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L
M82==6R<Y+C@Q-SHM-S`N.3,S)UT@/2`G365N92!'<F%N9&4G.PHD8V]O<F1I
M;F%T97-;)U9E;F5Z=65L82==6R<Y+CDQ-SHM-C<N,S,S)UT@/2`G4V%N($IU
M86X@1&4@3&]S($UO<G)O<R<["B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG
M,3`N.#$W.C$P-BXV-C<G72`]("=(;R!#:&D@36EN:"<["B1C;V]R9&EN871E
M<ULG5FEE="!.86TG75LG,3(N,C4P.C$P.2XR,#`G72`]("=.:&$@5')A;F<G
M.PHD8V]O<F1I;F%T97-;)U9I970@3F%M)UU;)S$S+C<V-SHQ,#DN,C$W)UT@
M/2`G475Y($YH;VXG.PHD8V]O<F1I;F%T97-;)U9I970@3F%M)UU;)S$S+CDX
M,SHQ,#@N,#`P)UT@/2`G4&QE:6MU($-I='DG.PHD8V]O<F1I;F%T97-;)U9I
M970@3F%M)UU;)S$V+C`S,SHQ,#@N,3@S)UT@/2`G1&$@3F%N9R<["B1C;V]R
M9&EN871E<ULG5FEE="!.86TG75LG,38N-#`P.C$P-RXV.#,G72`]("=(=64G
M.PHD8V]O<F1I;F%T97-;)U9I970@3F%M)UU;)S$X+C<P,#HQ,#4N-C8W)UT@
M/2`G5FEN:"<["B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG,C$N,#$W.C$P
M-2XX,#`G72`]("=(82!.;VDG.PHD8V]O<F1I;F%T97-;)U9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H)UU;)S$X+C0U,#HM-C0N-3,S)UT@/2`G0F5E9B!)<VQA
M;F0L(%1O<G1O;&$G.PHD8V]O<F1I;F%T97-;)U9I<F=I;B!)<VQA;F1S+"!5
M;FET960@4W1A=&5S)UU;)S$W+C<P,#HM-C0N.#`P)UT@/2`G0VAR:7-T:6%N
M<W1E9"P@2&5N<GD@12X@4F]H;'-E;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=6:7)G:6X@27-L86YD<RP@56YI=&5D(%-T871E<R==6R<Q."XS,S,Z+38T
M+CDX,R==(#T@)T-H87)L;W1T92!!;6%L:64@4W0N(%1H;VUA<RP@0WER:6P@
M12X@2VEN9R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=797-T97)N(%-A:&%R
M82==6R<R,RXW,#`Z+3$U+C@V-R==(#T@)U9I;&QA($-I<VYE<F]S)SL*)&-O
M;W)D:6YA=&5S6R=996UE;B==6R<Q,BXV,S,Z-3,N.3`P)UT@/2`G4V]C;W1R
M82<["B1C;V]R9&EN871E<ULG665M96XG75LG,3(N-C8W.C0U+C`S,R==(#T@
M)T%D96XG.PHD8V]O<F1I;F%T97-;)UEE;65N)UU;)S$S+C(U,#HT,RXR.#,G
M72`]("=-;VMH82<["B1C;V]R9&EN871E<ULG665M96XG75LG,3,N,C4P.C0T
M+C$S,R==(#T@)TUO:VAA)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q,RXV
M.#,Z-#0N,3,S)UT@/2`G5&%I>B<["B1C;V]R9&EN871E<ULG665M96XG75LG
M,30N-3$W.C0V+C@U,"==(#T@)T%T87$G.PHD8V]O<F1I;F%T97-;)UEE;65N
M)UU;)S$T+C8U,#HT.2XS.#,G72`]("=2:7EA;B<["B1C;V]R9&EN871E<ULG
M665M96XG75LG,30N-S4P.C0R+CDX,R==(#T@)TAO9&5I9&%H)SL*)&-O;W)D
M:6YA=&5S6R=996UE;B==6R<Q-2XT,S,Z-#4N,S,S)UT@/2`G36%R:6(G.PHD
M8V]O<F1I;F%T97-;)UEE;65N)UU;)S$U+C4Q-SHT-"XQ.#,G72`]("=386YA
M7"=!)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q-BXR,#`Z-#0N-S@S)UT@
M/2`G06PM2&%Z;2<["B1C;V]R9&EN871E<ULG675G;W-L879I82==6R<T,BXS
M-C<Z,3DN,C4P)UT@/2`G4&]D9V]R:6-A("\@1V]L=6)O=F-I)SL*)&-O;W)D
M:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0R+C0P,#HQ."XW,S,G72`]("=4:79A
M="<["B1C;V]R9&EN871E<ULG675G;W-L879I82==6R<T,BXV-3`Z,C$N,34P
M)UT@/2`G4')I<W1I;F$G.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V:6$G75LG
M-#,N,S,S.C(Q+CDP,"==(#T@)TYI<R<["B1C;V]R9&EN871E<ULG675G;W-L
M879I82==6R<T,RXS-3`Z,3<N.#`P)UT@/2`G36]S=&%R)SL*)&-O;W)D:6YA
M=&5S6R=9=6=O<VQA=FEA)UU;)S0S+C@Q-SHQ."XS,S,G72`]("=387)A:F5V
M;R`O($)U=&UI<B<["B1C;V]R9&EN871E<ULG675G;W-L879I82==6R<T-"XU
M-3`Z,3@N-S`P)UT@/2`G5'5Z;&$G.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V
M:6$G75LG-#0N-S@S.C$W+C(Q-R==(#T@)T)A;FIA($QU:V$G.PHD8V]O<F1I
M;F%T97-;)UEU9V]S;&%V:6$G75LG-#0N.#$W.C$U+C@X,R==(#T@)T)I:&%C
M)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0T+C@Q-SHR,"XR.#,G
M72`]("="96]G<F%D("\@4W5R8VEN)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA
M=FEA)UU;)S0U+C$U,#HR,2XS,3<G72`]("=6<G-A8R<["B1C;V]R9&EN871E
M<ULG6F%I<F4G75LG,"XP-3`Z,3@N,C8W)UT@/2`G36)A;F1A:V$G.PHD8V]O
M<F1I;F%T97-;)UIA:7)E)UU;)S`N,3,S.C(Y+C(V-R==(#T@)T)U=&5M8F\G
M.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTP+C(Q-SHR,"XX-3`G72`]("="
M;V5N9&4G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)S`N-3$W.C(U+C$X,R==
M(#T@)TMI<V%N9V%N:2<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+3$N,3@S
M.C(Y+C0U,"==(#T@)U)U='-H=7)U)SL*)&-O;W)D:6YA=&5S6R=:86ER92==
M6R<M,2XV.#,Z,CDN,C,S)UT@/2`G1V]M82<["B1C;V]R9&EN871E<ULG6F%I
M<F4G75LG+3$N.38W.C$X+C(V-R==(#T@)TEN;VYG;R<["B1C;V]R9&EN871E
M<ULG6F%I<F4G75LG+3$P+C<Q-SHR-2XT-3`G72`]("=+;VQW97II)SL*)&-O
M;W)D:6YA=&5S6R=:86ER92==6R<M,3$N-C8W.C(W+C0X,R==(#T@)TQU8G5M
M8F%S:&DM3'5A;F\G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTR+CDU,#HR
M-2XY,3<G72`]("=+:6YD=2<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG,RXR
M.#,Z,3DN-S@S)UT@/2`G1V5M96YA)SL*)&-O;W)D:6YA=&5S6R=:86ER92==
M6R<M,RXS,#`Z,3<N,S4P)UT@/2`G0F%N9'5N9'4G.PHD8V]O<F1I;F%T97-;
M)UIA:7)E)UU;)RTS+C0X,SHR,RXT-C<G72`]("=,;V1J82<["B1C;V]R9&EN
M871E<ULG6F%I<F4G75LG+30N,S,S.C(P+C4X,R==(#T@)TEL96)O)SL*)&-O
M;W)D:6YA=&5S6R=:86ER92==6R<M-"XS.#,Z,34N-#,S)UT@/2`G2VEN<VAA
M<V$@+R!.7"=$:FEL:2<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+30N.3$W
M.C$W+C`V-R==(#T@)TME;F=E)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M
M-"XY-C<Z,C,N-#,S)UT@/2`G3'5S86UB;R<["B1C;V]R9&EN871E<ULG6F%I
M<F4G75LG+34N,#,S.C$X+C@P,"==(#T@)TMI:W=I="<["B1C;V]R9&EN871E
M<ULG6F%I<F4G75LG+34N,S4P.C(W+C`P,"==(#T@)TMO;F=O;&\G.PHD8V]O
M<F1I;F%T97-;)UIA:7)E)UU;)RTU+C4Q-SHQ,RXU.#,G72`]("=);F=A)SL*
M)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-2XX,#`Z,3,N-#,S)UT@/2`G36%T
M861I)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-2XX.#,Z,C(N-#$W)UT@
M/2`G2V%N86YG82<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+34N.#@S.C(Y
M+C$X,R==(#T@)TMA;&5M:64G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTV
M+C`P,#HQ,BXT,3<G72`]("=-;V%N9&$G.PHD8V]O<F1I;F%T97-;)UIA:7)E
M)UU;)RTV+C$V-SHR,RXV,3<G72`]("=-8G5J:2U-87EI)SL*)&-O;W)D:6YA
M=&5S6R=:86ER92==6R<M-BXT,3<Z,C`N.#4P)UT@/2`G5'-H:6MA<&$G.PHD
M8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTW+C(X,SHR-RXT,S,G72`]("=-86YO
M;F\G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTX+C8S,SHR-2XR-3`G72`]
M("=+86UI;F$@+R!"87-E)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$P
M+C$Q-SHS,BXV,S,G72`]("=)<V]K82<["B1C;V]R9&EN871E<ULG6F%M8FEA
M)UU;)RTQ,"XR,3<Z,S$N,3,S)UT@/2`G2V%S86UA)SL*)&-O;W)D:6YA=&5S
M6R=:86UB:6$G75LG+3$Q+C$P,#HR."XX-3`G72`]("=-86YS82<["B1C;V]R
M9&EN871E<ULG6F%M8FEA)UU;)RTQ,2XW-3`Z,C0N-#,S)UT@/2`G37=I;FEL
M=6YG82<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ,2XY,#`Z,S$N-#,S
M)UT@/2`G37!I:V$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3(N,3@S
M.C(V+C,X,R==(#T@)U-O;'=E>FDG.PHD8V]O<F1I;F%T97-;)UIA;6)I82==
M6R<M,3(N,C@S.C,S+C(P,"==(#T@)TQU;F1A>FDG.PHD8V]O<F1I;F%T97-;
M)UIA;6)I82==6R<M,3,N,#`P.C(X+C8U,"==(#T@)TYD;VQA)SL*)&-O;W)D
M:6YA=&5S6R=:86UB:6$G75LG+3$S+C(S,SHS,"XR,3<G72`]("=397)E;FIE
M)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$S+C4S,SHR,RXQ,3<G72`]
M("=:86UB97II)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$S+C4S,SHR
M-2XX-3`G72`]("=+87-E;7!A)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG
M+3$S+C4U,#HS,BXU.#,G72`]("=#:&EP871A)SL*)&-O;W)D:6YA=&5S6R=:
M86UB:6$G75LG+3$S+C8P,#HR-"XR,#`G72`]("=+86)O;7!O)SL*)&-O;W)D
M:6YA=&5S6R=:86UB:6$G75LG+3$T+C(U,#HS,2XR.#,G72`]("=0971A=6ME
M)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$T+C0U,#HR."XT-C<G72`]
M("=+86)W92<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ-"XT-3`Z,C@N
M-#8W)UT@/2`G3'5S86MA($-I='D@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M6F%M8FEA)UU;)RTQ-"XX,#`Z,C0N.#`P)UT@/2`G2V%O;6$G.PHD8V]O<F1I
M;F%T97-;)UIA;6)I82==6R<M,34N,C4P.C(S+C$U,"==(#T@)TUO;F=U)SL*
M)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$U+C,Q-SHR."XT-3`G72`]("=,
M=7-A:V$@26YT97)N871I;VYA;&%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)UIA
M;6)I82==6R<M,38N,3`P.C(S+C(V-R==(#T@)U-E;F%N9V$G.PHD8V]O<F1I
M;F%T97-;)UIA;6)I82==6R<M,38N.#,S.C(W+C`V-R==(#T@)T-H;VUA)SL*
M)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$W+C0V-SHR-"XS,#`G72`]("=3
M97-H96ME)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$W+C@Q-SHR-2XX
M,3<G72`]("=,:79I;F=S=&]N92<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;
M)RTX+C@U,#HS,2XS,S,G72`]("=-8F%L82<["B1C;V]R9&EN871E<ULG6F%M
M8FEA)UU;)RTY+C@P,#HR.2XP.#,G72`]("=+87=A;6)W82<["B1C;V]R9&EN
M871E<ULG6FEM8F%B=V4G75LG+3$V+C4Q-SHR."XX.#,G72`]("=+87)I8F$G
M.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ-BXX,S,Z,CDN-C$W)UT@
M/2`G2V%R;VDG.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ-RXT,3<Z
M,S(N,C$W)UT@/2`G375T;VMO)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==
M6R<M,3<N-C$W.C(W+C,S,R==(#T@)T)I;F=A)SL*)&-O;W)D:6YA=&5S6R=:
M:6UB86)W92==6R<M,3<N.3$W.C,Q+C$S,R==(#T@)TAA<F%R92!+=71S86=A
M)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,3@N,3`P.C(U+C@U,"==
M(#T@)U9I8W1O<FEA($9A;&QS)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==
M6R<M,3@N,C$W.C(X+CDS,R==(#T@)T=O:W=E)SL*)&-O;W)D:6YA=&5S6R=:
M:6UB86)W92==6R<M,3@N-3,S.C,R+C$S,R==(#T@)U)U<V%P92<["B1C;V]R
M9&EN871E<ULG6FEM8F%B=V4G75LG+3$X+C8S,SHR-RXP,#`G72`]("=(=V%N
M9V4@3F%T:6]N86P@4&%R:R<["B1C;V]R9&EN871E<ULG6FEM8F%B=V4G75LG
M+3$Y+C0U,#HR.2XX-3`G72`]("='=V5R=2<["B1C;V]R9&EN871E<ULG6FEM
M8F%B=V4G75LG+3(P+C`Q-SHR."XV,3<G72`]("="=6QA=V%Y;R!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,C`N,#8W.C,P+C@V-R==
M(#T@)TUA<W9I;F=O)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,C`N
M,C`P.C,R+C8Q-R==(#T@)T-H:7!I;F=E)SL*)&-O;W)D:6YA=&5S6R=::6UB
M86)W92==6R<M,C$N,#$W.C,Q+C4X,R==(#T@)T)U9F9A;&\@4F%N9V4G.PHD
M8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTR,BXR,3<Z,S`N,#`P)UT@/2`G
M0F5I=&)R:61G92<["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<```
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38S,#4`,3`T,3<S-C(W
M-S$`,#(Q-#$U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@25-/+3,Q-C8@8V]U;G1R>2!L:7-T
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`L=B`Q+C,N,3(N,2`R,#`U+S$P+S$X(#$Q.C`Q.C$X(&IA;B!%>'`@)`H@
M*@H@*B!`<&%C:V%G92!(;W)D95].3%,*("HO"@HD8V]U;G1R:65S(#T@87)R
M87DH"B`@("`G048G(#T^(%\H(D%F9VAA;FES=&%N(BDL"B`@("`G04PG(#T^
M(%\H(D%L8F%N:6$B*2P*("`@("=$6B<@/3X@7R@B06QG97)I82(I+`H@("`@
M)T%3)R`]/B!?*")!;65R:6-A;B!386UO82(I+`H@("`@)T%$)R`]/B!?*")!
M;F1O<G)A(BDL"B`@("`G04\G(#T^(%\H(D%N9V]L82(I+`H@("`@)T%))R`]
M/B!?*")!;F=U:6QL82(I+`H@("`@)T%1)R`]/B!?*")!;G1A<F-T:6-A(BDL
M"B`@("`G04<G(#T^(%\H(D%N=&EG=6$@86YD($)A<F)U9&$B*2P*("`@("=!
M4B<@/3X@7R@B07)G96YT:6YA(BDL"B`@("`G04TG(#T^(%\H(D%R;65N:6$B
M*2P*("`@("=!5R<@/3X@7R@B07)U8F$B*2P*("`@("=!52<@/3X@7R@B075S
M=')A;&EA(BDL"B`@("`G050G(#T^(%\H(D%U<W1R:6$B*2P*("`@("=!6B<@
M/3X@7R@B07IE<F)A:6IA;B(I+`H@("`@)T)3)R`]/B!?*")"86AA;6%S(BDL
M"B`@("`G0D@G(#T^(%\H(D)A:')A:6XB*2P*("`@("="1"<@/3X@7R@B0F%N
M9VQA9&5S:"(I+`H@("`@)T)")R`]/B!?*")"87)B861O<R(I+`H@("`@)T)9
M)R`]/B!?*")"96QA<G5S(BDL"B`@("`G0D4G(#T^(%\H(D)E;&=I=6TB*2P*
M("`@("="6B<@/3X@7R@B0F5L:7IE(BDL"B`@("`G0DHG(#T^(%\H(D)E;FEN
M(BDL"B`@("`G0DTG(#T^(%\H(D)E<FUU9&$B*2P*("`@("="5"<@/3X@7R@B
M0FAU=&%N(BDL"B`@("`G0D\G(#T^(%\H(D)O;&EV:6$B*2P*("`@("="02<@
M/3X@7R@B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(I+`H@("`@)T)7)R`]/B!?
M*")";W1S=V%N82(I+`H@("`@)T)6)R`]/B!?*")";W5V970@27-L86YD(BDL
M"B`@("`G0E(G(#T^(%\H(D)R87II;"(I+`H@("`@)TE/)R`]/B!?*")"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB*2P*("`@("="3B<@/3X@7R@B
M0G)U;F5I($1A<G5S<V%L86TB*2P*("`@("="1R<@/3X@7R@B0G5L9V%R:6$B
M*2P*("`@("="1B<@/3X@7R@B0G5R:VEN82!&87-O(BDL"B`@("`G0DDG(#T^
M(%\H(D)U<G5N9&DB*2P*("`@("=+2"<@/3X@7R@B0V%M8F]D:6$B*2P*("`@
M("=#32<@/3X@7R@B0V%M97)O;VXB*2P*("`@("=#02<@/3X@7R@B0V%N861A
M(BDL"B`@("`G0U8G(#T^(%\H(D-A<&4@5F5R9&4B*2P*("`@("=+62<@/3X@
M7R@B0V%Y;6%N($ES;&%N9',B*2P*("`@("=#1B<@/3X@7R@B0V5N=')A;"!!
M9G)I8V%N(%)E<'5B;&EC(BDL"B`@("`G5$0G(#T^(%\H(D-H860B*2P*("`@
M("=#3"<@/3X@7R@B0VAI;&4B*2P*("`@("=#3B<@/3X@7R@B0VAI;F$B*2P*
M("`@("=#6"<@/3X@7R@B0VAR:7-T;6%S($ES;&%N9"(I+`H@("`@)T-#)R`]
M/B!?*")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(I+`H@("`@)T-/)R`]/B!?
M*")#;VQO;6)I82(I+`H@("`@)TM-)R`]/B!?*")#;VUO<F]S(BDL"B`@("`G
M0T<G(#T^(%\H(D-O;F=O(BDL"B`@("`G0T0G(#T^(%\H(D-O;F=O+"!4:&4@
M1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B*2P*("`@("=#2R<@/3X@7R@B
M0V]O:R!)<VQA;F1S(BDL"B`@("`G0U(G(#T^(%\H(D-O<W1A(%)I8V$B*2P*
M("`@("=#22<@/3X@7R@B0V]T92!D)TEV;VER92(I+`H@("`@)TA2)R`]/B!?
M*")#<F]A=&EA(BDL"B`@("`G0U4G(#T^(%\H(D-U8F$B*2P*("`@("=#62<@
M/3X@7R@B0WEP<G5S(BDL"B`@("`G0UHG(#T^(%\H(D-Z96-H(%)E<'5B;&EC
M(BDL"B`@("`G1$LG(#T^(%\H(D1E;FUA<FLB*2P*("`@("=$2B<@/3X@7R@B
M1&II8F]U=&DB*2P*("`@("=$32<@/3X@7R@B1&]M:6YI8V$B*2P*("`@("=$
M3R<@/3X@7R@B1&]M:6YI8V%N(%)E<'5B;&EC(BDL"B`@("`G14,G(#T^(%\H
M(D5C=6%D;W(B*2P*("`@("=%1R<@/3X@7R@B16=Y<'0B*2P*("`@("=35B<@
M/3X@7R@B16P@4V%L=F%D;W(B*2P*("`@("='42<@/3X@7R@B17%U871O<FEA
M;"!'=6EN96$B*2P*("`@("=%4B<@/3X@7R@B17)I=')E82(I+`H@("`@)T5%
M)R`]/B!?*")%<W1O;FEA(BDL"B`@("`G150G(#T^(%\H(D5T:&EO<&EA(BDL
M"B`@("`G1DLG(#T^(%\H(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(I
M+`H@("`@)T9/)R`]/B!?*")&87)O92!)<VQA;F1S(BDL"B`@("`G1DHG(#T^
M(%\H(D9I:FDB*2P*("`@("=&22<@/3X@7R@B1FEN;&%N9"(I+`H@("`@)T92
M)R`]/B!?*")&<F%N8V4B*2P*("`@("='1B<@/3X@7R@B1G)E;F-H($=U:6%N
M82(I+`H@("`@)U!&)R`]/B!?*")&<F5N8V@@4&]L>6YE<VEA(BDL"B`@("`G
M5$8G(#T^(%\H(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(I+`H@("`@
M)T=!)R`]/B!?*")'86)O;B(I+`H@("`@)T=-)R`]/B!?*")'86UB:6$B*2P*
M("`@("='12<@/3X@7R@B1V5O<F=I82(I+`H@("`@)T1%)R`]/B!?*")'97)M
M86YY(BDL"B`@("`G1T@G(#T^(%\H(D=H86YA(BDL"B`@("`G1TDG(#T^(%\H
M(D=I8G)A;'1A<B(I+`H@("`@)T=2)R`]/B!?*")'<F5E8V4B*2P*("`@("='
M3"<@/3X@7R@B1W)E96YL86YD(BDL"B`@("`G1T0G(#T^(%\H(D=R96YA9&$B
M*2P*("`@("='4"<@/3X@7R@B1W5A9&5L;W5P92(I+`H@("`@)T=5)R`]/B!?
M*")'=6%M(BDL"B`@("`G1U0G(#T^(%\H(D=U871E;6%L82(I+`H@("`@)T=.
M)R`]/B!?*")'=6EN96$B*2P*("`@("='5R<@/3X@7R@B1W5I;F5A+4)I<W-A
M=2(I+`H@("`@)T=9)R`]/B!?*")'=7EA;F$B*2P*("`@("=(5"<@/3X@7R@B
M2&%I=&DB*2P*("`@("=(32<@/3X@7R@B2&5A<F0@27-L86YD(&%N9"!-8T1O
M;F%L9"!)<VQA;F1S(BDL"B`@("`G5D$G(#T^(%\H(DAO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I(BDL"B`@("`G2$XG(#T^(%\H(DAO;F1U<F%S(BDL
M"B`@("`G2$LG(#T^(%\H(DAO;F<@2V]N9R(I+`H@("`@)TA5)R`]/B!?*")(
M=6YG87)Y(BDL"B`@("`G25,G(#T^(%\H(DEC96QA;F0B*2P*("`@("=)3B<@
M/3X@7R@B26YD:6$B*2P*("`@("=)1"<@/3X@7R@B26YD;VYE<VEA(BDL"B`@
M("`G25(G(#T^(%\H(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B*2P*("`@
M("=)42<@/3X@7R@B27)A<2(I+`H@("`@)TE%)R`]/B!?*"))<F5L86YD(BDL
M"B`@("`G24PG(#T^(%\H(DES<F%E;"(I+`H@("`@)TE4)R`]/B!?*"))=&%L
M>2(I+`H@("`@)TI-)R`]/B!?*")*86UA:6-A(BDL"B`@("`G2E`G(#T^(%\H
M(DIA<&%N(BDL"B`@("`G2D\G(#T^(%\H(DIO<F1A;B(I+`H@("`@)TM:)R`]
M/B!?*")+87IA:VAS=&%N(BDL"B`@("`G2T4G(#T^(%\H(DME;GEA(BDL"B`@
M("`G2TDG(#T^(%\H(DMI<FEB871I(BDL"B`@("`G2U`G(#T^(%\H(DMO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(BDL"B`@("`G2U(G
M(#T^(%\H(DMO<F5A+"!297!U8FQI8R!O9B(I+`H@("`@)TM7)R`]/B!?*")+
M=7=A:70B*2P*("`@("=+1R<@/3X@7R@B2WER9WEZ<W1A;B(I+`H@("`@)TQ!
M)R`]/B!?*"),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(I+`H@
M("`@)TQ6)R`]/B!?*"),871V:6$B*2P*("`@("=,0B<@/3X@7R@B3&5B86YO
M;B(I+`H@("`@)TQ3)R`]/B!?*"),97-O=&AO(BDL"B`@("`G3%(G(#T^(%\H
M(DQI8F5R:6$B*2P*("`@("=,62<@/3X@7R@B3&EB>6%N($%R86(@2F%M86AI
M<FEY82(I+`H@("`@)TQ))R`]/B!?*"),:65C:'1E;G-T96EN(BDL"B`@("`G
M3%0G(#T^(%\H(DQI=&AU86YI82(I+`H@("`@)TQ5)R`]/B!?*"),=7AE;6)O
M=7)G(BDL"B`@("`G34\G(#T^(%\H(DUA8V%O(BDL"B`@("`G34LG(#T^(%\H
M(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(I
M+`H@("`@)TU')R`]/B!?*")-861A9V%S8V%R(BDL"B`@("`G35<G(#T^(%\H
M(DUA;&%W:2(I+`H@("`@)TU9)R`]/B!?*")-86QA>7-I82(I+`H@("`@)TU6
M)R`]/B!?*")-86QD:79E<R(I+`H@("`@)TU,)R`]/B!?*")-86QI(BDL"B`@
M("`G350G(#T^(%\H(DUA;'1A(BDL"B`@("`G34@G(#T^(%\H(DUA<G-H86QL
M($ES;&%N9',B*2P*("`@("=-42<@/3X@7R@B36%R=&EN:7%U92(I+`H@("`@
M)TU2)R`]/B!?*")-875R:71A;FEA(BDL"B`@("`G354G(#T^(%\H(DUA=7)I
M=&EU<R(I+`H@("`@)UE4)R`]/B!?*")-87EO='1E(BDL"B`@("`G35@G(#T^
M(%\H(DUE>&EC;R(I+`H@("`@)T9-)R`]/B!?*")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(BDL"B`@("`G340G(#T^(%\H(DUO;&1O=F$L(%)E
M<'5B;&EC(&]F(BDL"B`@("`G34,G(#T^(%\H(DUO;F%C;R(I+`H@("`@)TU.
M)R`]/B!?*")-;VYG;VQI82(I+`H@("`@)TU3)R`]/B!?*")-;VYT<V5R<F%T
M(BDL"B`@("`G34$G(#T^(%\H(DUO<F]C8V\B*2P*("`@("=-6B<@/3X@7R@B
M36]Z86UB:7%U92(I+`H@("`@)TU-)R`]/B!?*")->6%N;6%R(BDL"B`@("`G
M3D$G(#T^(%\H(DYA;6EB:6$B*2P*("`@("=.4B<@/3X@7R@B3F%U<G4B*2P*
M("`@("=.4"<@/3X@7R@B3F5P86PB*2P*("`@("=.3"<@/3X@7R@B3F5T:&5R
M;&%N9',B*2P*("`@("=!3B<@/3X@7R@B3F5T:&5R;&%N9',@06YT:6QL97,B
M*2P*("`@("=.0R<@/3X@7R@B3F5W($-A;&5D;VYI82(I+`H@("`@)TY:)R`]
M/B!?*").97<@6F5A;&%N9"(I+`H@("`@)TY))R`]/B!?*").:6-A<F%G=6$B
M*2P*("`@("=.12<@/3X@7R@B3FEG97(B*2P*("`@("=.1R<@/3X@7R@B3FEG
M97)I82(I+`H@("`@)TY5)R`]/B!?*").:75E(BDL"B`@("`G3D8G(#T^(%\H
M(DYO<F9O;&L@27-L86YD(BDL"B`@("`G35`G(#T^(%\H(DYO<G1H97)N($UA
M<FEA;F$@27-L86YD<R(I+`H@("`@)TY/)R`]/B!?*").;W)W87DB*2P*("`@
M("=/32<@/3X@7R@B3VUA;B(I+`H@("`@)U!+)R`]/B!?*")086MI<W1A;B(I
M+`H@("`@)U!7)R`]/B!?*")086QA=2(I+`H@("`@)U!3)R`]/B!?*")086QE
M<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(BDL"B`@("`G4$$G(#T^(%\H
M(E!A;F%M82(I+`H@("`@)U!')R`]/B!?*")087!U82!.97<@1W5I;F5A(BDL
M"B`@("`G4%DG(#T^(%\H(E!A<F%G=6%Y(BDL"B`@("`G4$4G(#T^(%\H(E!E
M<G4B*2P*("`@("=02"<@/3X@7R@B4&AI;&EP<&EN97,B*2P*("`@("=03B<@
M/3X@7R@B4&ET8V%I<FXB*2P*("`@("=03"<@/3X@7R@B4&]L86YD(BDL"B`@
M("`G4%0G(#T^(%\H(E!O<G1U9V%L(BDL"B`@("`G4%(G(#T^(%\H(E!U97)T
M;R!2:6-O(BDL"B`@("`G44$G(#T^(%\H(E%A=&%R(BDL"B`@("`G4D4G(#T^
M(%\H(E)E=6YI;VXB*2P*("`@("=23R<@/3X@7R@B4F]M86YI82(I+`H@("`@
M)U)5)R`]/B!?*")2=7-S:6%N($9E9&5R871I;VXB*2P*("`@("=25R<@/3X@
M7R@B4G=A;F1A(BDL"B`@("`G4T@G(#T^(%\H(E-A:6YT($AE;&5N82(I+`H@
M("`@)TM.)R`]/B!?*")386EN="!+:71T<R!A;F0@3F5V:7,B*2P*("`@("=,
M0R<@/3X@7R@B4V%I;G0@3'5C:6$B*2P*("`@("=032<@/3X@7R@B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(I+`H@("`@)U9#)R`]/B!?*")386EN="!6
M:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(I+`H@("`@)U=3)R`]/B!?*")3
M86UO82(I+`H@("`@)U--)R`]/B!?*")386X@36%R:6YO(BDL"B`@("`G4U0G
M(#T^(%\H(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(I+`H@("`@)U-!)R`]/B!?
M*")3875D:2!!<F%B:6$B*2P*("`@("=33B<@/3X@7R@B4V5N96=A;"(I+`H@
M("`@)T-3)R`]/B!?*")397)B:6$@86YD($UO;G1E;F5G<F\B*2P*("`@("=3
M0R<@/3X@7R@B4V5Y8VAE;&QE<R(I+`H@("`@)U-,)R`]/B!?*")3:65R<F$@
M3&5O;F4B*2P*("`@("=31R<@/3X@7R@B4VEN9V%P;W)E(BDL"B`@("`G4TLG
M(#T^(%\H(E-L;W9A:VEA(BDL"B`@("`G4TDG(#T^(%\H(E-L;W9E;FEA(BDL
M"B`@("`G4T(G(#T^(%\H(E-O;&]M;VX@27-L86YD<R(I+`H@("`@)U-/)R`]
M/B!?*")3;VUA;&EA(BDL"B`@("`G6D$G(#T^(%\H(E-O=71H($%F<FEC82(I
M+`H@("`@)T=3)R`]/B!?*")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@
M4V%N9'=I8V@@27-L86YD<R(I+`H@("`@)T53)R`]/B!?*")3<&%I;B(I+`H@
M("`@)TQ+)R`]/B!?*")3<FD@3&%N:V$B*2P*("`@("=31"<@/3X@7R@B4W5D
M86XB*2P*("`@("=34B<@/3X@7R@B4W5R:6YA;64B*2P*("`@("=32B<@/3X@
M7R@B4W9A;&)A<F0@86YD($IA;B!-87EE;B(I+`H@("`@)U-:)R`]/B!?*")3
M=V%Z:6QA;F0B*2P*("`@("=312<@/3X@7R@B4W=E9&5N(BDL"B`@("`G0T@G
M(#T^(%\H(E-W:71Z97)L86YD(BDL"B`@("`G4UDG(#T^(%\H(E-Y<FEA;B!!
M<F%B(%)E<'5B;&EC(BDL"B`@("`G5%<G(#T^(%\H(E1A:7=A;BP@4')O=FEN
M8V4@;V8@0VAI;F$B*2P*("`@("=42B<@/3X@7R@B5&%J:6MI<W1A;B(I+`H@
M("`@)U1:)R`]/B!?*")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(BDL
M"B`@("`G5$@G(#T^(%\H(E1H86EL86YD(BDL"B`@("`G5$PG(#T^(%\H(E1I
M;6]R+4QE<W1E(BDL"B`@("`G5$<G(#T^(%\H(E1O9V\B*2P*("`@("=42R<@
M/3X@7R@B5&]K96QA=2(I+`H@("`@)U1/)R`]/B!?*")4;VYG82(I+`H@("`@
M)U14)R`]/B!?*")4<FEN:61A9"!A;F0@5&]B86=O(BDL"B`@("`G5$XG(#T^
M(%\H(E1U;FES:6$B*2P*("`@("=44B<@/3X@7R@B5'5R:V5Y(BDL"B`@("`G
M5$TG(#T^(%\H(E1U<FMM96YI<W1A;B(I+`H@("`@)U1#)R`]/B!?*")4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',B*2P*("`@("=45B<@/3X@7R@B5'5V86QU
M(BDL"B`@("`G54<G(#T^(%\H(E5G86YD82(I+`H@("`@)U5!)R`]/B!?*")5
M:W)A:6YE(BDL"B`@("`G044G(#T^(%\H(E5N:71E9"!!<F%B($5M:7)A=&5S
M(BDL"B`@("`G1T(G(#T^(%\H(E5N:71E9"!+:6YG9&]M(BDL"B`@("`G55,G
M(#T^(%\H(E5N:71E9"!3=&%T97,B*2P*("`@("=532<@/3X@7R@B56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(BDL"B`@("`G55DG(#T^
M(%\H(E5R=6=U87DB*2P*("`@("=56B<@/3X@7R@B57IB96MI<W1A;B(I+`H@
M("`@)U95)R`]/B!?*")686YU871U(BDL"B`@("`G5D4G(#T^(%\H(E9E;F5Z
M=65L82(I+`H@("`@)U9.)R`]/B!?*")6:65T($YA;2(I+`H@("`@)U9')R`]
M/B!?*")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(I+`H@("`@)U9))R`]/B!?
M*")6:7)G:6X@27-L86YD<RP@52Y3+B(I+`H@("`@)U=&)R`]/B!?*")786QL
M:7,@86YD($9U='5N82(I+`H@("`@)T5()R`]/B!?*")797-T97)N(%-A:&%R
M82(I+`H@("`@)UE%)R`]/B!?*")996UE;B(I+`H@("`@)UI-)R`]/B!?*"):
M86UB:6$B*2P*("`@("=:5R<@/3X@7R@B6FEM8F%B=V4B*2D["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R]T;&0N<&AP````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C<R-0`Q,#0Q-S,V
M,C<W,0`P,C`Q-S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1O<"!L979E;"!D;VUA:6X@*%1,1"D@
M;&ES="!F;W(@8V]U;G1R>2!C;V1E<RX*("H@1V5N97)A=&5D(&9R;VT@24%.
M02`H26YT97)N970@07-S:6=N960@3G5M8F5R<R!!=71H;W)I='DI(&1A=&$@
M;&]C871E9`H@*B!A="!H='1P.B\O=W=W+FEA;F$N;W)G+V-C=&QD+V-C=&QD
M+7=H;VES+FAT;0H@*@H@*B!&;W)M870Z"B`J("`@)'1L9%LG8V]U;G1R>6-O
M9&4G72`]("=C;W5N=')Y;F%M92<["B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<"QV(#$N-2`R,#`T+S`Q+S`T(#`R.C(T.C`U(&UD
M:G5K:6,@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PHD=&QD
M(#T@87)R87DH"B`@("`G86,G(#T^(%\H(D%S8V5N<VEO;B!)<VQA;F0B*2P*
M("`@("=A9"<@/3X@7R@B06YD;W)R82(I+`H@("`@)V%E)R`]/B!?*")5;FET
M960@07)A8B!%;6ER871E<R(I+`H@("`@)V%F)R`]/B!?*")!9F=H86YI<W1A
M;B(I+`H@("`@)V%G)R`]/B!?*")!;G1I9W5A(&%N9"!"87)B=61A(BDL"B`@
M("`G86DG(#T^(%\H(D%N9W5I;&QA(BDL"B`@("`G86PG(#T^(%\H(D%L8F%N
M:6$B*2P*("`@("=A;2<@/3X@7R@B07)M96YI82(I+`H@("`@)V%N)R`]/B!?
M*").971H97)L86YD<R!!;G1I;&QE<R(I+`H@("`@)V%O)R`]/B!?*")!;F=O
M;&$B*2P*("`@("=A<2<@/3X@7R@B06YT87)C=&EC82(I+`H@("`@)V%R)R`]
M/B!?*")!<F=E;G1I;F$B*2P*("`@("=A<R<@/3X@7R@B06UE<FEC86X@4V%M
M;V$B*2P*("`@("=A="<@/3X@7R@B075S=')I82(I+`H@("`@)V%U)R`]/B!?
M*")!=7-T<F%L:6$B*2P*("`@("=A=R<@/3X@7R@B07)U8F$B*2P*("`@("=A
M>B<@/3X@7R@B07IE<F)A:6IA;B(I+`H@("`@)V)A)R`]/B!?*")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(BDL"B`@("`G8F(G(#T^(%\H(D)A<F)A9&]S(BDL
M"B`@("`G8F0G(#T^(%\H(D)A;F=L861E<V@B*2P*("`@("=B92<@/3X@7R@B
M0F5L9VEU;2(I+`H@("`@)V)F)R`]/B!?*")"=7)K:6YA($9A<V\B*2P*("`@
M("=B9R<@/3X@7R@B0G5L9V%R:6$B*2P*("`@("=B:"<@/3X@7R@B0F%H<F%I
M;B(I+`H@("`@)V)I)R`]/B!?*")"=7)U;F1I(BDL"B`@("`G8FHG(#T^(%\H
M(D)E;FEN(BDL"B`@("`G8FTG(#T^(%\H(D)E<FUU9&$B*2P*("`@("=B;B<@
M/3X@7R@B0G)U;F5I($1A<G5S<V%L86TB*2P*("`@("=B;R<@/3X@7R@B0F]L
M:79I82(I+`H@("`@)V)R)R`]/B!?*")"<F%Z:6PB*2P*("`@("=B<R<@/3X@
M7R@B0F%H86UA<R(I+`H@("`@)V)T)R`]/B!?*")":'5T86XB*2P*("`@("=B
M=B<@/3X@7R@B0F]U=F5T($ES;&%N9"(I+`H@("`@)V)W)R`]/B!?*")";W1S
M=V%N82(I+`H@("`@)V)Y)R`]/B!?*")"96QA<G5S(BDL"B`@("`G8GHG(#T^
M(%\H(D)E;&EZ92(I+`H@("`@)V-A)R`]/B!?*")#86YA9&$B*2P*("`@("=C
M8R<@/3X@7R@B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B*2P*("`@("=C9"<@
M/3X@7R@B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(I
M+`H@("`@)V-F)R`]/B!?*")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B*2P*
M("`@("=C9R<@/3X@7R@B0V]N9V\B*2P*("`@("=C:"<@/3X@7R@B4W=I='IE
M<FQA;F0B*2P*("`@("=C:2<@/3X@7R@B0V]T92!D)TEV;VER92(I+`H@("`@
M)V-K)R`]/B!?*")#;V]K($ES;&%N9',B*2P*("`@("=C;"<@/3X@7R@B0VAI
M;&4B*2P*("`@("=C;2<@/3X@7R@B0V%M97)O;VXB*2P*("`@("=C;B<@/3X@
M7R@B0VAI;F$B*2P*("`@("=C;R<@/3X@7R@B0V]L;VUB:6$B*2P*("`@("=C
M<B<@/3X@7R@B0V]S=&$@4FEC82(I+`H@("`@)V-U)R`]/B!?*")#=6)A(BDL
M"B`@("`G8W8G(#T^(%\H(D-A<&4@5F5R9&4B*2P*("`@("=C>"<@/3X@7R@B
M0VAR:7-T;6%S($ES;&%N9"(I+`H@("`@)V-Y)R`]/B!?*")#>7!R=7,B*2P*
M("`@("=C>B<@/3X@7R@B0WIE8V@@4F5P=6)L:6,B*2P*("`@("=D92<@/3X@
M7R@B1V5R;6%N>2(I+`H@("`@)V1J)R`]/B!?*")$:FEB;W5T:2(I+`H@("`@
M)V1K)R`]/B!?*")$96YM87)K(BDL"B`@("`G9&TG(#T^(%\H(D1O;6EN:6-A
M(BDL"B`@("`G9&\G(#T^(%\H(D1O;6EN:6-A;B!297!U8FQI8R(I+`H@("`@
M)V1Z)R`]/B!?*")!;&=E<FEA(BDL"B`@("`G96,G(#T^(%\H(D5C=6%D;W(B
M*2P*("`@("=E92<@/3X@7R@B17-T;VYI82(I+`H@("`@)V5G)R`]/B!?*")%
M9WEP="(I+`H@("`@)V5H)R`]/B!?*")797-T97)N(%-A:&%R82(I+`H@("`@
M)V5R)R`]/B!?*")%<FET<F5A(BDL"B`@("`G97,G(#T^(%\H(E-P86EN(BDL
M"B`@("`G970G(#T^(%\H(D5T:&EO<&EA(BDL"B`@("`G9FDG(#T^(%\H(D9I
M;FQA;F0B*2P*("`@("=F:B<@/3X@7R@B1FEJ:2(I+`H@("`@)V9K)R`]/B!?
M*")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB*2P*("`@("=F;2<@/3X@
M7R@B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(I+`H@("`@)V9O
M)R`]/B!?*")&87)O92!)<VQA;F1S(BDL"B`@("`G9G(G(#T^(%\H(D9R86YC
M92(I+`H@("`@)V=A)R`]/B!?*")'86)O;B(I+`H@("`@)V=D)R`]/B!?*")'
M<F5N861A(BDL"B`@("`G9V4G(#T^(%\H(D=E;W)G:6$B*2P*("`@("=G9B<@
M/3X@7R@B1G)E;F-H($=U:6%N82(I+`H@("`@)V=G)R`]/B!?*")'=65R;G-E
M>2(I+`H@("`@)V=H)R`]/B!?*")':&%N82(I+`H@("`@)V=I)R`]/B!?*")'
M:6)R86QT87(B*2P*("`@("=G;"<@/3X@7R@B1W)E96YL86YD(BDL"B`@("`G
M9VTG(#T^(%\H(D=A;6)I82(I+`H@("`@)V=N)R`]/B!?*")'=6EN96$B*2P*
M("`@("=G<"<@/3X@7R@B1W5A9&5L;W5P92(I+`H@("`@)V=Q)R`]/B!?*")%
M<75A=&]R:6%L($=U:6YE82(I+`H@("`@)V=R)R`]/B!?*")'<F5E8V4B*2P*
M("`@("=G<R<@/3X@7R@B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',B*2P*("`@("=G="<@/3X@7R@B1W5A=&5M86QA(BDL
M"B`@("`G9W4G(#T^(%\H(D=U86TB*2P*("`@("=G=R<@/3X@7R@B1W5I;F5A
M+4)I<W-A=2(I+`H@("`@)V=Y)R`]/B!?*")'=7EA;F$B*2P*("`@("=H:R<@
M/3X@7R@B2&]N9R!+;VYG(BDL"B`@("`G:&TG(#T^(%\H(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(I+`H@("`@)VAN)R`]/B!?*")(;VYD
M=7)A<R(I+`H@("`@)VAR)R`]/B!?*")#<F]A=&EA(BDL"B`@("`G:'0G(#T^
M(%\H(DAA:71I(BDL"B`@("`G:'4G(#T^(%\H(DAU;F=A<GDB*2P*("`@("=I
M9"<@/3X@7R@B26YD;VYE<VEA(BDL"B`@("`G:64G(#T^(%\H(DER96QA;F0B
M*2P*("`@("=I;"<@/3X@7R@B27-R865L(BDL"B`@("`G:6TG(#T^(%\H(DES
M;&4@;V8@36%N(BDL"B`@("`G:6XG(#T^(%\H(DEN9&EA(BDL"B`@("`G:6\G
M(#T^(%\H(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(I+`H@("`@
M)VEQ)R`]/B!?*"))<F%Q(BDL"B`@("`G:7(G(#T^(%\H(DER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8B*2P*("`@("=I<R<@/3X@7R@B26-E;&%N9"(I+`H@
M("`@)VET)R`]/B!?*"))=&%L>2(I+`H@("`@)VIE)R`]/B!?*")*97)S97DB
M*2P*("`@("=J;2<@/3X@7R@B2F%M86EC82(I+`H@("`@)VIO)R`]/B!?*")*
M;W)D86XB*2P*("`@("=J<"<@/3X@7R@B2F%P86XB*2P*("`@("=K92<@/3X@
M7R@B2V5N>6$B*2P*("`@("=K9R<@/3X@7R@B2WER9WEZ<W1A;B(I+`H@("`@
M)VMH)R`]/B!?*")#86UB;V1I82(I+`H@("`@)VMI)R`]/B!?*")+:7)I8F%T
M:2(I+`H@("`@)VMM)R`]/B!?*")#;VUO<F]S(BDL"B`@("`G:VXG(#T^(%\H
M(E-A:6YT($MI='1S(&%N9"!.979I<R(I+`H@("`@)VMP)R`]/B!?*")+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(I+`H@("`@)VMR
M)R`]/B!?*")+;W)E82P@4F5P=6)L:6,@;V8B*2P*("`@("=K=R<@/3X@7R@B
M2W5W86ET(BDL"B`@("`G:WDG(#T^(%\H(D-A>6UA;B!)<VQA;F1S(BDL"B`@
M("`G:WHG(#T^(%\H(DMA>F%K:'-T86XB*2P*("`@("=L82<@/3X@7R@B3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B*2P*("`@("=L8B<@/3X@
M7R@B3&5B86YO;B(I+`H@("`@)VQC)R`]/B!?*")386EN="!,=6-I82(I+`H@
M("`@)VQI)R`]/B!?*"),:65C:'1E;G-T96EN(BDL"B`@("`G;&LG(#T^(%\H
M(E-R:2!,86YK82(I+`H@("`@)VQR)R`]/B!?*"),:6)E<FEA(BDL"B`@("`G
M;',G(#T^(%\H(DQE<V]T:&\B*2P*("`@("=L="<@/3X@7R@B3&ET:'5A;FEA
M(BDL"B`@("`G;'4G(#T^(%\H(DQU>&5M8F]U<F<B*2P*("`@("=L=B<@/3X@
M7R@B3&%T=FEA(BDL"B`@("`G;'DG(#T^(%\H(DQI8GEA;B!!<F%B($IA;6%H
M:7)I>6$B*2P*("`@("=M82<@/3X@7R@B36]R;V-C;R(I+`H@("`@)VUC)R`]
M/B!?*")-;VYA8V\B*2P*("`@("=M9"<@/3X@7R@B36]L9&]V82P@4F5P=6)L
M:6,@;V8B*2P*("`@("=M9R<@/3X@7R@B36%D86=A<V-A<B(I+`H@("`@)VUH
M)R`]/B!?*")-87)S:&%L;"!)<VQA;F1S(BDL"B`@("`G;6LG(#T^(%\H(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(I+`H@
M("`@)VUL)R`]/B!?*")-86QI(BDL"B`@("`G;6TG(#T^(%\H(DUY86YM87(B
M*2P*("`@("=M;B<@/3X@7R@B36]N9V]L:6$B*2P*("`@("=M;R<@/3X@7R@B
M36%C86\B*2P*("`@("=M<"<@/3X@7R@B3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S(BDL"B`@("`G;7$G(#T^(%\H(DUA<G1I;FEQ=64B*2P*("`@("=M<B<@
M/3X@7R@B36%U<FET86YI82(I+`H@("`@)VUS)R`]/B!?*")-;VYT<V5R<F%T
M(BDL"B`@("`G;70G(#T^(%\H(DUA;'1A(BDL"B`@("`G;74G(#T^(%\H(DUA
M=7)I=&EU<R(I+`H@("`@)VUV)R`]/B!?*")-86QD:79E<R(I+`H@("`@)VUW
M)R`]/B!?*")-86QA=VDB*2P*("`@("=M>"<@/3X@7R@B365X:6-O(BDL"B`@
M("`G;7DG(#T^(%\H(DUA;&%Y<VEA(BDL"B`@("`G;7HG(#T^(%\H(DUO>F%M
M8FEQ=64B*2P*("`@("=N82<@/3X@7R@B3F%M:6)I82(I+`H@("`@)VYC)R`]
M/B!?*").97<@0V%L961O;FEA(BDL"B`@("`G;F4G(#T^(%\H(DYI9V5R(BDL
M"B`@("`G;F8G(#T^(%\H(DYO<F9O;&L@27-L86YD(BDL"B`@("`G;F<G(#T^
M(%\H(DYI9V5R:6$B*2P*("`@("=N:2<@/3X@7R@B3FEC87)A9W5A(BDL"B`@
M("`G;FPG(#T^(%\H(DYE=&AE<FQA;F1S(BDL"B`@("`G;F\G(#T^(%\H(DYO
M<G=A>2(I+`H@("`@)VYP)R`]/B!?*").97!A;"(I+`H@("`@)VYR)R`]/B!?
M*").875R=2(I+`H@("`@)VYU)R`]/B!?*").:75E(BDL"B`@("`G;GHG(#T^
M(%\H(DYE=R!:96%L86YD(BDL"B`@("`G;VTG(#T^(%\H(D]M86XB*2P*("`@
M("=P82<@/3X@7R@B4&%N86UA(BDL"B`@("`G<&4G(#T^(%\H(E!E<G4B*2P*
M("`@("=P9B<@/3X@7R@B1G)E;F-H(%!O;'EN97-I82(I+`H@("`@)W!G)R`]
M/B!?*")087!U82!.97<@1W5I;F5A(BDL"B`@("`G<&@G(#T^(%\H(E!H:6QI
M<'!I;F5S(BDL"B`@("`G<&LG(#T^(%\H(E!A:VES=&%N(BDL"B`@("`G<&PG
M(#T^(%\H(E!O;&%N9"(I+`H@("`@)W!M)R`]/B!?*")386EN="!0:65R<F4@
M86YD($UI<75E;&]N(BDL"B`@("`G<&XG(#T^(%\H(E!I=&-A:7)N(BDL"B`@
M("`G<'(G(#T^(%\H(E!U97)T;R!2:6-O(BDL"B`@("`G<',G(#T^(%\H(E!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B*2P*("`@("=P="<@/3X@
M7R@B4&]R='5G86PB*2P*("`@("=P=R<@/3X@7R@B4&%L874B*2P*("`@("=P
M>2<@/3X@7R@B4&%R86=U87DB*2P*("`@("=Q82<@/3X@7R@B46%T87(B*2P*
M("`@("=R92<@/3X@7R@B4F5U;FEO;B(I+`H@("`@)W)O)R`]/B!?*")2;VUA
M;FEA(BDL"B`@("`G<G4G(#T^(%\H(E)U<W-I86X@1F5D97)A=&EO;B(I+`H@
M("`@)W)W)R`]/B!?*")2=V%N9&$B*2P*("`@("=S82<@/3X@7R@B4V%U9&D@
M07)A8FEA(BDL"B`@("`G<V(G(#T^(%\H(E-O;&]M;VX@27-L86YD<R(I+`H@
M("`@)W-C)R`]/B!?*")397EC:&5L;&5S(BDL"B`@("`G<V0G(#T^(%\H(E-U
M9&%N(BDL"B`@("`G<V4G(#T^(%\H(E-W961E;B(I+`H@("`@)W-G)R`]/B!?
M*")3:6YG87!O<F4B*2P*("`@("=S:"<@/3X@7R@B4V%I;G0@2&5L96YA(BDL
M"B`@("`G<VDG(#T^(%\H(E-L;W9E;FEA(BDL"B`@("`G<VHG(#T^(%\H(E-V
M86QB87)D(&%N9"!*86X@36%Y96XB*2P*("`@("=S:R<@/3X@7R@B4VQO=F%K
M:6$B*2P*("`@("=S;"<@/3X@7R@B4VEE<G)A($QE;VYE(BDL"B`@("`G<VTG
M(#T^(%\H(E-A;B!-87)I;F\B*2P*("`@("=S;B<@/3X@7R@B4V5N96=A;"(I
M+`H@("`@)W-O)R`]/B!?*")3;VUA;&EA(BDL"B`@("`G<W(G(#T^(%\H(E-U
M<FEN86UE(BDL"B`@("`G<W0G(#T^(%\H(E-A;R!4;VUE(&%N9"!0<FEN8VEP
M92(I+`H@("`@)W-V)R`]/B!?*")%;"!386QV861O<B(I+`H@("`@)W-Y)R`]
M/B!?*")3>7)I86X@07)A8B!297!U8FQI8R(I+`H@("`@)W-Z)R`]/B!?*")3
M=V%Z:6QA;F0B*2P*("`@("=T8R<@/3X@7R@B5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S(BDL"B`@("`G=&0G(#T^(%\H(D-H860B*2P*("`@("=T9B<@/3X@
M7R@B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(BDL"B`@("`G=&<G(#T^
M(%\H(E1O9V\B*2P*("`@("=T:"<@/3X@7R@B5&AA:6QA;F0B*2P*("`@("=T
M:B<@/3X@7R@B5&%J:6MI<W1A;B(I+`H@("`@)W1K)R`]/B!?*")4;VME;&%U
M(BDL"B`@("`G=&TG(#T^(%\H(E1U<FMM96YI<W1A;B(I+`H@("`@)W1N)R`]
M/B!?*")4=6YI<VEA(BDL"B`@("`G=&\G(#T^(%\H(E1O;F=A(BDL"B`@("`G
M='`G(#T^(%\H(E1I;6]R+4QE<W1E(BDL"B`@("`G='(G(#T^(%\H(E1U<FME
M>2(I+`H@("`@)W1T)R`]/B!?*")4<FEN:61A9"!A;F0@5&]B86=O(BDL"B`@
M("`G='8G(#T^(%\H(E1U=F%L=2(I+`H@("`@)W1W)R`]/B!?*")486EW86XB
M*2P*("`@("=T>B<@/3X@7R@B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(I+`H@("`@)W5A)R`]/B!?*")5:W)A:6YE(BDL"B`@("`G=6<G(#T^(%\H
M(E5G86YD82(I+`H@("`@)W5K)R`]/B!?*")5;FET960@2VEN9V1O;2(I+`H@
M("`@)W5M)R`]/B!?*")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',B*2P*("`@("=U<R<@/3X@7R@B56YI=&5D(%-T871E<R(I+`H@("`@
M)W5Y)R`]/B!?*")5<G5G=6%Y(BDL"B`@("`G=7HG(#T^(%\H(E5Z8F5K:7-T
M86XB*2P*("`@("=V82<@/3X@7R@B2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92DB*2P*("`@("=V8R<@/3X@7R@B4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,B*2P*("`@("=V92<@/3X@7R@B5F5N97IU96QA(BDL"B`@
M("`G=F<G(#T^(%\H(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(BDL"B`@("`G
M=FDG(#T^(%\H(E9I<F=I;B!)<VQA;F1S+"!5+E,N(BDL"B`@("`G=FXG(#T^
M(%\H(E9I970@3F%M(BDL"B`@("`G=G4G(#T^(%\H(E9A;G5A='4B*2P*("`@
M("=W9B<@/3X@7R@B5V%L;&ES(&%N9"!&=71U;F$B*2P*("`@("=W<R<@/3X@
M7R@B4V%M;V$B*2P*("`@("=Y92<@/3X@7R@B665M96XB*2P*("`@("=Y="<@
M/3X@7R@B36%Y;W1T92(I+`H@("`@)WEU)R`]/B!?*")9=6=O<VQA=FEA(BDL
M"B`@("`G>F$G(#T^(%\H(E-O=71H($%F<FEC82(I+`H@("`@)WIM)R`]/B!?
M*"):86UB:6$B*2P*("`@("=Z=R<@/3X@7R@B6FEM8F%B=V4B*0HI.PH`````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0W)Y<'0O````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8R-S<Q`#`Q-S,S-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]#<GEP="]P9W`N<&AP````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`Q-#4U-#8`,3`T,3<S-C(W-S$`,#(P-C0W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+T-R>7!T+G!H<"<["@HO*BH*("H@07)M;W(@2&5A9&5R($QI
M;F5S("T@1G)O;2!21D,@,C0T,`H@*@H@*B`@06X@07)M;W(@2&5A9&5R($QI
M;F4@8V]N<VES=',@;V8@=&AE(&%P<')O<')I871E(&AE861E<B!L:6YE('1E
M>'0*("H@('-U<G)O=6YD960@8GD@9FEV92`H-2D@9&%S:&5S("@G+2<L(#!X
M,D0I(&]N(&5I=&AE<B!S:61E(&]F('1H92!H96%D97(*("H@(&QI;F4@=&5X
M="X@5&AE(&AE861E<B!L:6YE('1E>'0@:7,@8VAO<V5N(&)A<V5D('5P;VX@
M=&AE('1Y<&4@;V8@9&%T82!T:&%T"B`J("!I<R!B96EN9R!E;F-O9&5D(&EN
M($%R;6]R+"!A;F0@:&]W(&ET(&ES(&)E:6YG(&5N8V]D960N($AE861E<B!L
M:6YE('1E>'1S"B`J("!I;F-L=61E('1H92!F;VQL;W=I;F<@<W1R:6YG<SH*
M("H*("H@($%L;"!!<FUO<B!(96%D97(@3&EN97,@87)E('!R969I>&5D('=I
M=&@@)U!'4"<N"B`J"B`J("!4:&4@07)M;W(@5&%I;"!,:6YE(&ES(&-O;7!O
M<V5D(&EN('1H92!S86UE(&UA;FYE<B!A<R!T:&4@07)M;W(@2&5A9&5R"B`J
M("!,:6YE+"!E>&-E<'0@=&AE('-T<FEN9R`B0D5'24XB(&ES(')E<&QA8V5D
M(&)Y('1H92!S=')I;F<@(D5.1"XB"B`J+PH*+RHJ(%5S960@9F]R('-I9VYE
M9"P@96YC<GEP=&5D+"!O<B!C;VUP<F5S<V5D(&9I;&5S+B`J+PID969I;F4H
M)U!'4%]!4DU/4E]-15-304=%)RP@,2D["@HO*BH@57-E9"!F;W(@<VEG;F5D
M(&9I;&5S+B`J+PID969I;F4H)U!'4%]!4DU/4E]324=.141?34534T%'12<L
M(#(I.PH*+RHJ(%5S960@9F]R(&%R;6]R:6YG('!U8FQI8R!K97ES+B`J+PID
M969I;F4H)U!'4%]!4DU/4E]054),24-?2T59)RP@,RD["@HO*BH@57-E9"!F
M;W(@87)M;W)I;F<@<')I=F%T92!K97ES+B`J+PID969I;F4H)U!'4%]!4DU/
M4E]04DE6051%7TM%62<L(#0I.PH*+RHJ"B`J(%5S960@9F]R(&1E=&%C:&5D
M('-I9VYA='5R97,L(%!'4"]-24U%('-I9VYA='5R97,L(&%N9"!N871U<F5S
M(&9O;&QO=VEN9PH@*B!C;&5A<G-I9VYE9"!M97-S86=E<RX*("HO"F1E9FEN
M92@G4$=07T%234]27U-)1TY!5%5212<L(#4I.PH*+RHJ(%)E9W5L87(@=&5X
M="!C;VYT86EN960@:6X@86X@4$=0(&UE<W-A9V4N("HO"F1E9FEN92@G4$=0
M7T%234]27U1%6%0G+"`V*3L*"@HO*BH@5&AE(&1E9F%U;'0@<'5B;&EC(%!'
M4"!K97ES97)V97(@=&\@=7-E+B`J+PID969I;F4H)U!'4%]+15E315)615)?
M4%5"3$E#)RP@)W=W=VME>7,N<&=P+FYE="<I.PH*+RHJ"B`J(%1H92!N=6UB
M97(@;V8@=&EM97,@=&AE(&ME>7-E<G9E<B!R969U<V5S(&-O;FYE8W1I;VX@
M8F5F;W)E(&%N(&5R<F]R(&ES"B`J(')E='5R;F5D+@H@*B\*9&5F:6YE*"=0
M1U!?2T594T525D527U)%1E5312<L(#,I.PH*+RHJ"B`J(%1H92!N=6UB97(@
M;V8@<V5C;VYD<R!T:&%T(%!(4"!W:6QL(&%T=&5M<'0@=&\@8V]N;F5C="!T
M;R!T:&4@:V5Y<V5R=F5R"B`J(&)E9F]R92!I="!W:6QL('-T;W`@<')O8V5S
M<VEN9R!T:&4@<F5Q=65S="X*("HO"F1E9FEN92@G4$=07TM%65-%4E9%4E]4
M24U%3U54)RP@,3`I.PH*"B\J*@H@*B!(;W)D95]#<GEP=%]P9W`Z.B!P<F]V
M:61E<R!A(&9R86UE=V]R:R!F;W(@2&]R9&4@87!P;&EC871I;VYS('1O(&EN
M=&5R86-T"B`J('=I=&@@=&AE($=.52!0<FEV86-Y($=U87)D('!R;V=R86T@
M*")';G501R(I+B`@1VYU4$<@:6UP;&5M96YT<R!T:&4@3W!E;E!'4`H@*B!S
M=&%N9&%R9"`H4D9#(#(T-#`I+@H@*@H@*B!';G501R!796)S:71E.B!H='1P
M.B\O=W=W+F=N=7!G+F]R9R\*("H*("H@5&AI<R!C;&%S<R!H87,@8F5E;B!D
M979E;&]P960@=VET:"P@86YD(&ES(&]N;'D@9W5A<F%N=&5E9"!T;R!W;W)K
M('=I=&@L"B`J(%9E<G-I;VX@,2XR,2!O<B!A8F]V92!O9B!';G501RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<"QV(#$N
M.#4N,BXQ,2`R,#`V+S`Q+S`Q(#(Q.C(X.C$R(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7T-R>7!T"B`J+PIC;&%S<R!(;W)D95]#<GEP=%]P9W`@97AT96YD<R!(;W)D
M95]#<GEP="!["@H@("`@+RHJ"B`@("`@*B!3=')I;F=S(&EN(&%R;6]R(&AE
M861E<B!L:6YE<R!U<V5D('1O(&1I<W1I;F=U:7-H(&)E='=E96X@=&AE(&1I
M9F9E<F5N=`H@("`@("H@='EP97,@;V8@4$=0(&1E8W)Y<'1I;VXO96YC<GEP
M=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V%R;6]R(#T@87)R87DH"B`@("`@("`@)TU%4U-!1T4G("`@("`@("`@
M("`@/3X@(%!'4%]!4DU/4E]-15-304=%+`H@("`@("`@("=324=.140@3453
M4T%'12<@("`@(#T^("!01U!?05)-3U)?4TE'3D5$7TU%4U-!1T4L"B`@("`@
M("`@)U!50DQ)0R!+15D@0DQ/0TLG("`@/3X@(%!'4%]!4DU/4E]054),24-?
M2T59+`H@("`@("`@("=04DE6051%($M%62!"3$]#2R<@(#T^("!01U!?05)-
M3U)?4%))5D%415]+15DL"B`@("`@("`@)U-)1TY!5%5212<@("`@("`@("`@
M/3X@(%!'4%]!4DU/4E]324=.05154D4*("`@("D["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;&ES="!O9B!01U`@:&%S:"!A;&=O<FET:&US("AF<F]M(%)&0R`S
M,34V*2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7VAA<VA!;&<@/2!A<G)A>2@*("`@("`@("`Q("`]/B`@)W!G<"UM9#4G
M+`H@("`@("`@(#(@(#T^("`G<&=P+7-H83$G+`H@("`@("`@(#,@(#T^("`G
M<&=P+7)I<&5M9#$V,"<L"B`@("`@("`@-2`@/3X@("=P9W`M;60R)RP*("`@
M("`@("`V("`]/B`@)W!G<"UT:6=E<C$Y,B<L"B`@("`@("`@-R`@/3X@("=P
M9W`M:&%V86PM-2TQ-C`G+`H@("`@("`@(#@@(#T^("`G<&=P+7-H83(U-B<L
M"B`@("`@("`@.2`@/3X@("=P9W`M<VAA,S@T)RP*("`@("`@("`Q,"`]/B`@
M)W!G<"US:&$U,3(G+`H@("`@*3L*"B`@("`O*BH*("`@("`J($=N=5!'('!R
M;V=R86T@;&]C871I;VXO8V]M;6]N(&]P=&EO;G,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]G;G5P9SL*"B`@("`O*BH*
M("`@("`J($9I;&5N86UE(&]F('1H92!T96UP;W)A<GD@<'5B;&EC(&ME>7)I
M;F<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?<'5B;&EC2V5Y<FEN9SL*"B`@("`O*BH*("`@("`J($9I;&5N86UE(&]F
M('1H92!T96UP;W)A<GD@<')I=F%T92!K97ER:6YG+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!R:79A=&5+97ER:6YG
M.PH*("`@("\J*@H@("`@("H@5&AE(&5X:7-T96YC92!O9B!T:&ES('!R;W!E
M<G1Y(&EN9&EC871E<R!T:&%T(&UU;'1I<&QE(')E8VEP:65N=`H@("`@("H@
M96YC<GEP=&EO;B!I<R!A=F%I;&%B;&4N"B`@("`@*@H@("`@("H@0'-I;F-E
M($AO<F1E(#,N,0H@("`@("H*("`@("`J($!D97!R96-A=&5D"B`@("`@*@H@
M("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D;75L=&EP;&52
M96-I<&EE;G1%;F-R>7!T:6]N(#T@=')U93L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!087)A;65T97(@87)R87D@8V]N=&%I;FEN9R!T:&4@<&%T:"!T;R!T:&4@
M1VYU4$<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!B:6YA<GD@*&ME
M>2`]("=P<F]G<F%M)RD@86YD('1O(&$@=&5M<&]R87)Y"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@9&ER96-T;W)Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!(;W)D95]#<GEP=%]P9W`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]T96UP9&ER(#T@571I;#HZ8W)E871E5&5M<$1I
M<BAT<G5E+"`D<&%R86US6R=T96UP)UTI.PH*("`@("`@("!I9B`H96UP='DH
M)'!A<F%M<ULG<')O9W)A;2==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RXB*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!3=&]R92!T:&4@;&]C871I;VX@;V8@1VYU4$<@86YD('-E="!C
M;VUM;VX@;W!T:6]N<RX@*B\*("`@("`@("`D=&AI<RT^7V=N=7!G(#T@87)R
M87DH"B`@("`@("`@("`@("1P87)A;7-;)W!R;V=R86TG72P*("`@("`@("`@
M("`@)RTM;F\M='1Y)RP*("`@("`@("`@("`@)RTM;F\M<V5C;65M+7=A<FYI
M;F<G+`H@("`@("`@("`@("`G+2UN;RUO<'1I;VYS)RP*("`@("`@("`@("`@
M)RTM;F\M9&5F875L="UK97ER:6YG)RP*("`@("`@("`@("`@)RTM<75I970G
M+`H@("`@("`@("`@("`G+2UY97,G+`H@("`@("`@("`@("`G+2UH;VUE9&ER
M("<@+B`D=&AI<RT^7W1E;7!D:7(*("`@("`@("`I.PH*("`@("`@("!I9B`H
M<W5B<W1R*%!(4%]/4RP@,"P@,RD@(3T@)U=)3B<I('L*("`@("`@("`@("`@
M87)R87E?=6YS:&EF="@D=&AI<RT^7V=N=7!G+"`G3$%.1ST@.R<I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A('!E<G-O
M;F%L(%!U8FQI8R]0<FEV871E(&ME>7!A:7(@8V]M8FEN871I;VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5A;&YA;64@("`@5&AE(&YA;64@
M=&\@=7-E(&9O<B!T:&4@:V5Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96UA
M:6P@("`@("`@5&AE(&5M86EL('1O('5S92!F;W(@=&AE(&ME>2X*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A<W-P:')A<V4@(%1H92!P87-S<&AR87-E('1O
M('5S92!F;W(@=&AE(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UE
M;G0@("`@(%1H92!C;VUM96YT('1O('5S92!F;W(@=&AE(&ME>2X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1K97EL96YG=&@@(%1H92!K97EL96YG=&@@=&\@
M=7-E(&9O<B!T:&4@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%N(&%R<F%Y(&-O;G-I<W1I;F<@;V8@=&AE('!U8FQI8R!K97D@86YD('1H
M92!P<FEV871E"B`@("`@*B`@("`@("`@("`@("`@("!K97DL(&]R(%!%05)?
M17)R;W(@;VX@97)R;W(N"B`@("`@*B`\<')E/@H@("`@("H@4F5T=7)N(&%R
M<F%Y.@H@("`@("H@2V5Y("`@("`@("`@("`@5F%L=64*("`@("`J("TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`@("`@*B`G<'5B;&EC)R`@(#T^("!0
M=6)L:6,@2V5Y"B`@("`@*B`G<')I=F%T92<@(#T^("!0<FEV871E($ME>0H@
M("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E2V5Y
M*"1R96%L;F%M92P@)&5M86EL+"`D<&%S<W!H<F%S92P@)&-O;6UE;G0@/2`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1K97EL96YG=&@@/2`Q,#(T
M*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO
M;BX@*B\*("`@("`@("`D<V5C=7)E7V-H96-K(#T@)'1H:7,M/G)E<75I<F53
M96-U<F5#;VYN96-T:6]N*"D["B`@("`@("`@:68@*&ES7V$H)'-E8W5R95]C
M:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E
M8W5R95]C:&5C:SL*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP
M(&9I;&5S('1O(&AO;&0@=&AE(&=E;F5R871E9"!K97ES+B`J+PH@("`@("`@
M("1P=6)?9FEL92`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G
M<"<I.PH@("`@("`@("1S96-R971?9FEL92`]("1T:&ES+3Y?8W)E871E5&5M
M<$9I;&4H)VAO<F1E+7!G<"<I.PH*("`@("`@("`O*B!#<F5A=&4@=&AE(&-O
M;F9I9R!F:6QE(&YE8V5S<V%R>2!F;W(@1VYU4$<@=&\@<G5N(&EN(&)A=&-H
M(&UO9&4N("HO"B`@("`@("`@+RH@5$]$3SH@4V%N:71I>F4@:6YP=70L($UO
M<F4@=7-E<B!C=7-T;VUI>F%B;&4_("HO"B`@("`@("`@)&EN<'5T(#T@87)R
M87DH*3L*("`@("`@("`D:6YP=71;72`]("<E<'5B<FEN9R`G("X@)'!U8E]F
M:6QE.PH@("`@("`@("1I;G!U=%M=(#T@)R5S96-R:6YG("<@+B`D<V5C<F5T
M7V9I;&4["B`@("`@("`@)&EN<'5T6UT@/2`G2V5Y+51Y<&4Z($1302<["B`@
M("`@("`@)&EN<'5T6UT@/2`G2V5Y+4QE;F=T:#H@,3`R-"<["B`@("`@("`@
M)&EN<'5T6UT@/2`G4W5B:V5Y+51Y<&4Z($5,1RU%)SL*("`@("`@("`D:6YP
M=71;72`]("=3=6)K97DM3&5N9W1H.B`G("X@)&ME>6QE;F=T:#L*("`@("`@
M("`D:6YP=71;72`]("=.86UE+5)E86PZ("<@+B`D<F5A;&YA;64["B`@("`@
M("`@:68@*"%E;7!T>2@D8V]M;65N="DI('L*("`@("`@("`@("`@)&EN<'5T
M6UT@/2`G3F%M92U#;VUM96YT.B`G("X@)&-O;6UE;G0["B`@("`@("`@?0H@
M("`@("`@("1I;G!U=%M=(#T@)TYA;64M16UA:6PZ("<@+B`D96UA:6P["B`@
M("`@("`@)&EN<'5T6UT@/2`G17AP:7)E+41A=&4Z(#`G.PH@("`@("`@("1I
M;G!U=%M=(#T@)U!A<W-P:')A<V4Z("<@+B`D<&%S<W!H<F%S93L*("`@("`@
M("`D:6YP=71;72`]("<E8V]M;6ET)SL*"B`@("`@("`@+RH@4G5N('1H<F]U
M9V@@9W!G(&)I;F%R>2X@*B\*("`@("`@("`D8VUD;&EN92`](&%R<F%Y*`H@
M("`@("`@("`@("`G+2UG96XM:V5Y)RP*("`@("`@("`@("`@)RTM8F%T8V@G
M+`H@("`@("`@("`@("`G+2UA<FUO<B<*("`@("`@("`I.PH@("`@("`@("1T
M:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W<G+"`D:6YP=70I.PH*("`@("`@
M("`O*B!'970@=&AE(&ME>7,@9G)O;2!T:&4@=&5M<"!F:6QE<RX@*B\*("`@
M("`@("`D<'5B;&EC7VME>2`](&9I;&4H)'!U8E]F:6QE*3L*("`@("`@("`D
M<V5C<F5T7VME>2`](&9I;&4H)'-E8W)E=%]F:6QE*3L*"B`@("`@("`@+RH@
M268@96ET:&5R(&ME>2!I<R!E;7!T>2P@<V]M971H:6YG('=E;G0@=W)O;F<N
M("HO"B`@("`@("`@:68@*&5M<'1Y*"1P=6)L:6-?:V5Y*2!\?"!E;7!T>2@D
M<V5C<F5T7VME>2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@87)R87DH)W!U8FQI8R<@/3X@)'!U8FQI8U]K97DL
M("=P<FEV871E)R`]/B`D<V5C<F5T7VME>2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&]N(&$@4$=0(&1A=&$@8FQO8VLN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&=P9&%T82`@5&AE(%!'
M4"!D871A(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N
M(&%R<F%Y('=I=&@@:6YF;W)M871I;VX@;VX@=&AE(%!'4"!D871A(&)L;V-K
M+B!)9B!A;@H@("`@("H@("`@("`@("`@("`@("`@96QE;65N="!I<R!N;W0@
M<')E<V5N="!I;B!T:&4@9&%T82!B;&]C:RP@:70@=VEL;`H@("`@("H@("`@
M("`@("`@("`@("`@;&EK97=I<V4@;F]T(&)E('-E="!I;B!T:&4@87)R87DN
M"B`@("`@*B`\<')E/@H@("`@("H@07)R87D@1F]R;6%T.@H@("`@("H@+2TM
M+2TM+2TM+2TM+0H@("`@("H@6W!U8FQI8U]K97E=+UMS96-R971?:V5Y72`]
M/B!!<G)A>0H@("`@("H@("`H"B`@("`@*B`@("`@6V-R96%T961=(#T^($ME
M>2!C<F5A=&EO;B`M(%5.25@@=&EM97-T86UP"B`@("`@*B`@("`@6V5X<&ER
M97-=(#T^($ME>2!E>'!I<F%T:6]N("T@54Y)6"!T:6UE<W1A;7`@*#`@/2!N
M979E<B!E>'!I<F5S*0H@("`@("H@("`@(%MS:7IE72`@("`]/B!3:7IE(&]F
M('1H92!K97D@:6X@8FET<PH@("`@("H@("`I"B`@("`@*@H@("`@("H@6V9I
M;F=E<G!R:6YT72`]/B!&:6YG97)P<FEN="!O9B!T:&4@4$=0(&1A=&$@*&EF
M(&%V86EL86)L92D*("`@("`J("`@("`@("`@("`@("`@("`@,38M8FET(&AE
M>"!V86QU90H@("`@("H*("`@("`J(%MS:6=N871U<F5=(#T^($%R<F%Y("@*
M("`@("`J("`@("!;:61[;GTO)U]324=.05154D4G72`]/B!!<G)A>2`H"B`@
M("`@*B`@("`@("`@(%MN86UE72`@("`@("`@/3X@1G5L;"!.86UE"B`@("`@
M*B`@("`@("`@(%MC;VUM96YT72`@("`@/3X@0V]M;65N=`H@("`@("H@("`@
M("`@("!;96UA:6Q=("`@("`@(#T^($4M;6%I;"!!9&1R97-S"B`@("`@*B`@
M("`@("`@(%MF:6YG97)P<FEN=%T@/3X@,38M8FET(&AE>"!V86QU90H@("`@
M("H@("`@("`@("!;8W)E871E9%T@("`@(#T^(%-I9VYA='5R92!C<F5A=&EO
M;B`M(%5.25@@=&EM97-T86UP"B`@("`@*B`@("`@("`@(%MM:6-A;&==("`@
M("`@/3X@5&AE(&AA<V@@=7-E9"!T;R!C<F5A=&4@=&AE('-I9VYA='5R90H@
M("`@("H@("`@("`@("!;<VEG7WMH97A]72`@(#T^($%R<F%Y(%MD971A:6QS
M(&]F(&$@<VEG('9E<FEF>6EN9R!T:&4@241=("@*("`@("`J("`@("`@("`@
M("`@(%MC<F5A=&5D72`@("`@/3X@4VEG;F%T=7)E(&-R96%T:6]N("T@54Y)
M6"!T:6UE<W1A;7`*("`@("`J("`@("`@("`@("`@(%MF:6YG97)P<FEN=%T@
M/3X@,38M8FET(&AE>"!V86QU90H@("`@("H@("`@("`@("`@("`@6VUI8V%L
M9UT@("`@("`]/B!4:&4@:&%S:"!U<V5D('1O(&-R96%T92!T:&4@<VEG;F%T
M=7)E"B`@("`@*B`@("`@("`@("D*("`@("`J("`@("`I"B`@("`@*B`I"B`@
M("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!%86-H('5S97(@240@=VEL;"!B
M92!S=&]R960@:6X@=&AE(&%R<F%Y("=S:6=N871U<F4G(&%N9"!H879E(&1A
M=&$*("`@("`J(&%S<V]C:6%T960@=VET:"!I="P@:6YC;'5D:6YG(&%N(&%R
M<F%Y(&9O<B!I;F9O<FUA=&EO;B!O;B!E86-H"B`@("`@*B!S:6=N871U<F4@
M=&AA="!H87,@<VEG;F5D('1H870@54E$+B!3:6=N871U<F5S(&YO="!A<W-O
M8VEA=&5D('=I=&@@80H@("`@("H@54E$("AE+F<N(')E=F]C871I;VX@<VEG
M;F%T=7)E<R!A;F0@<W5B(&ME>7,I('=I;&P@8F4@<W1O<F5D('5N9&5R('1H
M90H@("`@("H@<W!E8VEA;"!K97EW;W)D("=?4TE'3D%455)%)RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<&=P4&%C:V5T26YF;W)M871I;VXH)'!G<&1A=&$I
M"B`@("!["B`@("`@("`@)&1A=&%?87)R87D@/2!A<G)A>2@I.PH@("`@("`@
M("1F:6YG97)P<FEN="`]("<G.PH@("`@("`@("1H96%D97(@/2!N=6QL.PH@
M("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E
M+7!G<"<I.PH@("`@("`@("1S:6=?:60@/2`D=6ED7VED>"`](#`["@H@("`@
M("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@=&5M<&]R87)Y(&9I;&4N("HO"B`@
M("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T
M<R@D9G`L("1P9W!D871A*3L*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@
M("`@)&-M9&QI;F4@/2!A<G)A>2@*("`@("`@("`@("`@)RTM;&ES="UP86-K
M971S)RP*("`@("`@("`@("`@)&EN<'5T"B`@("`@("`@*3L*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G<B<I.PH*("`@
M("`@("!F;W)E86-H("AE>'!L;V1E*")<;B(L("1R97-U;'0M/G-T9&]U="D@
M87,@)&QI;F4I('L*("`@("`@("`@("`@+RH@2&5A9&5R<R!A<F4@<')E9F%C
M960@=VET:"!A("<Z)R!A<R!T:&4@9FER<W0@8VAA<F%C=&5R(&]N('1H90H@
M("`@("`@("`@("`@("!L:6YE+B`J+PH@("`@("`@("`@("!I9B`H<W1R<&]S
M*"1L:6YE+"`G.B<I(#T]/2`P*2!["B`@("`@("`@("`@("`@("`D;&]W97),
M:6YE(#T@4W1R:6YG.CIL;W=E<B@D;&EN92D["@H@("`@("`@("`@("`@("`@
M+RH@268@=V4@:&%V92!A(&ME>2`H<F%T:&5R('1H86X@82!S:6=N871U<F4@
M8FQO8VLI+"!G970@=&AE"B`@("`@("`@("`@("`@("`@("!K97DG<R!F:6YG
M97)P<FEN="`J+PH@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;&]W97),
M:6YE+"`G.G!U8FQI8R!K97D@<&%C:V5T.B<I("$]/2!F86QS92!\?`H@("`@
M("`@("`@("`@("`@("`@('-T<G!O<R@D;&]W97),:6YE+"`G.G-E8W)E="!K
M97D@<&%C:V5T.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M("1C;61L:6YE(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("<M
M+7=I=&@M8V]L;VYS)RP*("`@("`@("`@("`@("`@("`@("`@("`@)&EN<'5T
M"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`D
M9&%T82`]("1T:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W(G*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B+RAS96-\<'5B*3HN*CHN
M*CHN*CHH6T$M1C`M.5U[,39]*3HO(BP@)&1A=&$M/G-T9&]U="P@)&UA=&-H
M97,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F:6YG97)P<FEN="`]
M("1M871C:&5S6S)=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1L;W=E<DQI
M;F4L("<Z<'5B;&EC(&ME>2!P86-K970Z)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`@("`@)&AE861E<B`]("=P=6)L:6-?:V5Y)SL*("`@("`@
M("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&QO=V5R3&EN92P@)SIS96-R
M970@:V5Y('!A8VME=#HG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("`@("`D:&5A9&5R(#T@)W-E8W)E=%]K97DG.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*'-T<G!O<R@D;&]W97),:6YE+"`G.G5S97(@:60@<&%C:V5T
M.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1U:61?:61X
M*RL["B`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2!P<F5G7W)E<&QA8V5?
M8V%L;&)A8VLH)R]<7%Q<>"A;,"TY82UF77LR?2DO)RP@8W)E871E7V9U;F-T
M:6]N*"<D82<L("=R971U<FX@8VAR*&AE>&1E8R@D85LQ72DI.R<I+"`D;&EN
M92D["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(B]<(BA;
M7EP\72LI7#PH6UY</ETK*5P^7"(O(BP@)&QI;F4L("1M871C:&5S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D:&5A9&5R(#T@)VED)R`N("1U:61?
M:61X.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+RA;7EPH72LI7"@H+BLI7"DD+R<L('1R:6TH)&UA=&-H97-;,5TI+"`D8V]M
M;65N=%]M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D97)=6R=N86UE)UT@/2!T
M<FEM*"1C;VUM96YT7VUA=&-H97-;,5TI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1A=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D97)=6R=C
M;VUM96YT)UT@/2`D8V]M;65N=%]M871C:&5S6S)=.PH@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D97)=6R=N86UE)UT@
M/2!T<FEM*"1M871C:&5S6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LD:&5A9&5R75LG8V]M;65N
M="==(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D
M97)=6R=E;6%I;"==(#T@)&UA=&-H97-;,ET["B`@("`@("`@("`@("`@("`@
M("`@("`@("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LD:&5A9&5R75LG9FEN
M9V5R<')I;G0G72`]("1F:6YG97)P<FEN=#L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1L;W=E<DQI
M;F4L("<Z<VEG;F%T=7)E('!A8VME=#HG*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H96UP='DH)&AE861E<BD@?'P@96UP='DH)'5I
M9%]I9'@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H96%D97(@/2`G
M7U-)1TY!5%5212<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O:V5Y:61<<RLH6S`M.4$M1ETK
M*2]I(BP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<VEG7VED(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("`@("`@
M("`@("`@("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LD:&5A9&5R75LG<VEG
M7R<@+B`D<VEG7VED75LG9FEN9V5R<')I;G0G72`]("1M871C:&5S6S%=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG9FEN9V5R<')I
M;G0G72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AE
M861E<B`](&YU;&P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!I9B`H*"1H96%D97(@/3T@)W-E8W)E
M=%]K97DG*2!\?"`H)&AE861E<B`]/2`G<'5B;&EC7VME>2<I*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(B]C<F5A=&5D7',K*%QD
M*RDL7',K97AP:7)E<UQS*RA<9"LI+VDB+"`D;&EN92P@)&UA=&-H97,I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R1H96%D97)=
M6R=C<F5A=&5D)UT@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&%?87)R87E;)&AE861E<EU;)V5X<&ER97,G72`]("1M871C
M:&5S6S)=.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA
M=&-H*"(O7',K6W-P76ME>5Q;,%Q=.EQS*UQ;*%QD*RDO:2(L("1L:6YE+"`D
M;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R
M87E;)&AE861E<EU;)W-I>F4G72`]("1M871C:&5S6S%=.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@D:&5A9&5R
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(B]V97)S
M:6]N7',K7&0K+%QS*V-R96%T961<<RLH7&0K*2]I(BP@)&QI;F4L("1M871C
M:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG
M<VEG;F%T=7)E)UU;)&AE861E<EU;)W-I9U\G("X@)'-I9U]I9%U;)V-R96%T
M960G72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M96EF("AP<F5G7VUA=&-H*"(O9&EG97-T(&%L9V]<<RLH7&1[,7TI+R(L("1L
M:6YE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&UI
M8V%L9R`]("1T:&ES+3Y?:&%S:$%L9ULD;6%T8VAE<ULQ75T["B`@("`@("`@
M("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LD:&5A
M9&5R75LG<VEG7R<@+B`D<VEG7VED75LG;6EC86QG)UT@/2`D;6EC86QG.PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&AE861E<B`]/2`G7U-)1TY!
M5%5212<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\J($QI:V5L
M>2!A('-I9VYA='5R92!B;&]C:RP@;F]T(&$@:V5Y+B`J+PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1A=&%?87)R87E;)W-I9VYA='5R92==6R=?
M4TE'3D%455)%)UU;)VUI8V%L9R==(#T@)&UI8V%L9SL*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'-I
M9U]I9"`]/2`D9FEN9V5R<')I;G0I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\J(%-E;&8@<VEG;FEN9R!S:6=N871U<F4@+2!W92!C86X@87-S
M=6UE('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;6EC86QG
M('9A;'5E(&9R;VT@=&AI<R!S:6=N871U<F4@:7,@=&AA="!F;W(*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1H92!K97D@*B\*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LG
M7U-)1TY!5%5212==6R=M:6-A;&<G72`]("1M:6-A;&<["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG<VEG;F%T=7)E)UU;)&AE
M861E<EU;)VUI8V%L9R==(#T@)&UI8V%L9SL*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&9I;F=E<G!R
M:6YT("8F("1D871A7V%R<F%Y6R=F:6YG97)P<FEN="==(#T@)&9I;F=E<G!R
M:6YT.PH*("`@("`@("!R971U<FX@)&1A=&%?87)R87D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&AU;6%N(')E861A8FQE(&EN9F]R;6%T:6]N
M(&]N(&$@4$=0(&ME>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M9W!D871A("!4:&4@4$=0(&1A=&$@8FQO8VLN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1A8G5L87(@:6YF;W)M871I;VX@;VX@=&AE(%!'4"!K
M97DN"B`@("`@*B\*("`@(&9U;F-T:6]N('!G<%!R971T>4ME>2@D<&=P9&%T
M82D*("`@('L*("`@("`@("`D;7-G(#T@)R<["B`@("`@("`@)'!A8VME=%]I
M;F9O(#T@)'1H:7,M/G!G<%!A8VME=$EN9F]R;6%T:6]N*"1P9W!D871A*3L*
M"B`@("`@("`@:68@*"%E;7!T>2@D<&%C:V5T7VEN9F];)W-I9VYA='5R92==
M*2D@>PH@("`@("`@("`@("`O*B!-86MI;F<@=&AE('!R;W!E<G1Y(&YA;65S
M('1H92!S86UE('=I9'1H(&9O<B!A;&P*("`@("`@("`@("`@("H@;&]C86QI
M>F%T:6]N<R`N*B\*("`@("`@("`@("`@)&QE9G1R;W<@/2!A<G)A>2A?*").
M86UE(BDL(%\H(DME>2!4>7!E(BDL(%\H(DME>2!#<F5A=&EO;B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%\H(D5X<&ER871I;VX@1&%T92(I
M+"!?*")+97D@3&5N9W1H(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7R@B0V]M;65N="(I+"!?*")%+4UA:6PB*2P@7R@B2&%S:"U!;&=O<FET
M:&TB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*")+97D@1FEN
M9V5R<')I;G0B*2D["B`@("`@("`@("`@("1L969T=VED=&@@/2!A<G)A>5]M
M87`H)W-T<FQE;B<L("1L969T<F]W*3L*("`@("`@("`@("`@)&UA>'=I9'1H
M("`](&UA>"@D;&5F='=I9'1H*2`K(#(["B`@("`@("`@("`@(&%R<F%Y7W=A
M;&LH)&QE9G1R;W<L(&-R96%T95]F=6YC=&EO;B@G)B1S+"`D:RP@)&TG+"`G
M)',@/2`D<R`N("(Z(B`N('-T<E]R97!E870H(B`B+"`D;2`M(%-T<FEN9SHZ
M;&5N9W1H*"1S*2D[)RDL("1M87AW:61T:"D["@H@("`@("`@("`@("!F;W)E
M86-H("AA<G)A>5]K97ES*"1P86-K971?:6YF;ULG<VEG;F%T=7)E)UTI(&%S
M("1U:61?:61X*2!["B`@("`@("`@("`@("`@("!I9B`H)'5I9%]I9'@@/3T@
M)U]324=.05154D4G*2!C;VYT:6YU93L*("`@("`@("`@("`@("`@("1K97E?
M:6YF;R`]("1T:&ES+3YP9W!086-K9713:6=N871U<F5">55I9$EN9&5X*"1P
M9W!D871A+"`D=6ED7VED>"D["B`@("`@("`@("`@("`@("`D;7-G("X]("1L
M969T<F]W6S!=("X@<W1R:7!C<VQA<VAE<R@D:V5Y7VEN9F];)VYA;64G72D@
M+B`B7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULQ72`N
M("@H)&ME>5]I;F9O6R=K97E?='EP92==(#T]("=P=6)L:6-?:V5Y)RD@/R!?
M*")0=6)L:6,@2V5Y(BD@.B!?*")0<FEV871E($ME>2(I*2`N(")<;B(["B`@
M("`@("`@("`@("`@("`D;7-G("X]("1L969T<F]W6S)=("X@<W1R9G1I;64H
M(B5$(BP@)&ME>5]I;F9O6R=K97E?8W)E871E9"==*2`N(")<;B(["B`@("`@
M("`@("`@("`@("`D;7-G("X]("1L969T<F]W6S-=("X@*&5M<'1Y*"1K97E?
M:6YF;ULG:V5Y7V5X<&ER97,G72D@/R`G6R<@+B!?*").979E<B(I("X@)UTG
M(#H@<W1R9G1I;64H(B5$(BP@)&ME>5]I;F9O6R=K97E?97AP:7)E<R==*2D@
M+B`B7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULT72`N
M("1K97E?:6YF;ULG:V5Y7W-I>F4G72`N("(@0GET97-<;B(["B`@("`@("`@
M("`@("`@("`D;7-G("X]("1L969T<F]W6S5=("X@*&5M<'1Y*"1K97E?:6YF
M;ULG8V]M;65N="==*2`_("=;)R`N(%\H(DYO;F4B*2`N("==)R`Z("1K97E?
M:6YF;ULG8V]M;65N="==*2`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G
M("X]("1L969T<F]W6S9=("X@)&ME>5]I;F9O6R=E;6%I;"==("X@(EQN(CL*
M("`@("`@("`@("`@("`@("1M<V<@+CT@)&QE9G1R;W=;-UT@+B`H96UP='DH
M)&ME>5]I;F9O6R=M:6-A;&<G72D@/R`G6R<@+B!?*")5;FMN;W=N(BD@+B`G
M72<@.B`D:V5Y7VEN9F];)VUI8V%L9R==*2`N(")<;B(["B`@("`@("`@("`@
M("`@("`D;7-G("X]("1L969T<F]W6SA=("X@*&5M<'1Y*"1K97E?:6YF;ULG
M9FEN9V5R<')I;G0G72D@/R`G6R<@+B!?*")5;FMN;W=N(BD@+B`G72<@.B`D
M:V5Y7VEN9F];)V9I;F=E<G!R:6YT)UTI("X@(EQN7&XB.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@;VYL>2!I;F9O<FUA=&EO;B!O;B!T:&4@
M9FER<W0@240@=&AA="!M871C:&5S('1H92!E;6%I;"!A9&1R97-S"B`@("`@
M*B!I;G!U="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P9W!D871A
M("!4:&4@4$=0(&1A=&$@8FQO8VLN"B`@("`@*B!`<&%R86T@<W1R:6YG("1E
M;6%I;"`@("!!;B!E+6UA:6P@861D<F5S<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H(&EN9F]R;6%T:6]N(&]N('1H92!0
M1U`@9&%T82!B;&]C:RX@268@86X*("`@("`J("`@("`@("`@("`@("`@(&5L
M96UE;G0@:7,@;F]T('!R97-E;G0@:6X@=&AE(&1A=&$@8FQO8VLL(&ET('=I
M;&P*("`@("`J("`@("`@("`@("`@("`@(&QI:V5W:7-E(&YO="!B92!S970@
M:6X@=&AE(&%R<F%Y+@H@("`@("H@/'!R93X*("`@("`J($%R<F%Y($9I96QD
M<SH*("`@("`J("TM+2TM+2TM+2TM+2T*("`@("`J(&ME>5]C<F5A=&5D("`]
M/B`@2V5Y(&-R96%T:6]N("T@54Y)6"!T:6UE<W1A;7`*("`@("`J(&ME>5]E
M>'!I<F5S("`]/B`@2V5Y(&5X<&ER871I;VX@+2!53DE8('1I;65S=&%M<"`H
M,"`](&YE=F5R(&5X<&ER97,I"B`@("`@*B!K97E?<VEZ92`@("`@/3X@(%-I
M>F4@;V8@=&AE(&ME>2!I;B!B:71S"B`@("`@*B!K97E?='EP92`@("`@/3X@
M(%1H92!K97D@='EP92`H<'5B;&EC7VME>2!O<B!S96-R971?:V5Y*0H@("`@
M("H@;F%M92`@("`@("`@(#T^("!&=6QL($YA;64*("`@("`J(&-O;6UE;G0@
M("`@("`]/B`@0V]M;65N=`H@("`@("H@96UA:6P@("`@("`@(#T^("!%+6UA
M:6P@061D<F5S<PH@("`@("H@9FEN9V5R<')I;G0@(#T^("`Q-BUB:70@:&5X
M('9A;'5E"B`@("`@*B!C<F5A=&5D("`@("`@/3X@(%-I9VYA='5R92!C<F5A
M=&EO;B`M(%5.25@@=&EM97-T86UP"B`@("`@*B!M:6-A;&<@("`@("`@/3X@
M(%1H92!H87-H('5S960@=&\@8W)E871E('1H92!S:6=N871U<F4*("`@("`J
M(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!P9W!086-K9713:6=N871U
M<F4H)'!G<&1A=&$L("1E;6%I;"D*("`@('L*("`@("`@("`D9&%T82`]("1T
M:&ES+3YP9W!086-K971);F9O<FUA=&EO;B@D<&=P9&%T82D["B`@("`@("`@
M)&ME>5]T>7!E(#T@;G5L;#L*("`@("`@("`D<F5T=7)N7V%R<F%Y(#T@87)R
M87DH*3L*"B`@("`@("`@+RH@0VAE8VL@=&AA="!;<VEG;F%T=7)E72!K97D@
M97AI<W1S+B`J+PH@("`@("`@(&EF("@A:7-S970H)&1A=&%;)W-I9VYA='5R
M92==*2D@>PH@("`@("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@
M("`@("!]"@H@("`@("`@("\J(%-T;W)E('1H92!S:6=N871U<F4@:6YF;W)M
M871I;VX@;F]W+B`J+PH@("`@("`@(&EF("@H)&5M86EL(#T]("=?4TE'3D%4
M55)%)RD@)B8*("`@("`@("`@("`@:7-S970H)&1A=&%;)W-I9VYA='5R92==
M6R=?4TE'3D%455)%)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1D871A
M6R=S:6=N871U<F4G75LD96UA:6Q=(&%S("1K97D@/3X@)'9A;'5E*2!["B`@
M("`@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6R1K97E=(#T@)'9A;'5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5I
M9%]I9'@@/2`Q.PH*("`@("`@("`@("`@=VAI;&4@*&ES<V5T*"1D871A6R=S
M:6=N871U<F4G75LG:60G("X@)'5I9%]I9'A=*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"1D871A6R=S:6=N871U<F4G75LG:60G("X@)'5I9%]I9'A=6R=E
M;6%I;"==(#T]("1E;6%I;"D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1D871A6R=S:6=N871U<F4G75LG:60G("X@)'5I9%]I9'A=(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N
M7V%R<F%Y6R1K97E=(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D=6ED7VED>"LK.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]P9W!086-K9713:6=N871U
M<F4H)&1A=&$L("1R971U<FY?87)R87DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!O;B!A(%!'4"!S:6=N871U<F4@96UB
M961D960@:6X@4$=0(&1A=&$N("!3:6UI;&%R"B`@("`@*B!T;R!P9W!086-K
M9713:6=N871U<F4H*2P@8G5T(')E='5R;G,@:6YF;W)M871I;VX@8GD@=6YI
M<75E(%5S97(@240*("`@("`J($EN9&5X("AF;W)M870@:61[;GT@=VAE<F4@
M;B!I<R!A;B!I;G1E9V5R(&]F(#$@;W(@9W)E871E<BDN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&=P9&%T82`@(%-E92!P9W!086-K9713:6=N
M871U<F4H*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1U:61?:61X("!4:&4@
M54E$(&EN9&5X+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%-E92!P
M9W!086-K9713:6=N871U<F4H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<&=P
M4&%C:V5T4VEG;F%T=7)E0GE5:61);F1E>"@D<&=P9&%T82P@)'5I9%]I9'@I
M"B`@("!["B`@("`@("`@)&1A=&$@/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M
M871I;VXH)'!G<&1A=&$I.PH@("`@("`@("1K97E?='EP92`](&YU;&P["B`@
M("`@("`@)')E='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@("\J(%-E
M87)C:"!F;W(@=&AE(%5)1"!I;F1E>"X@*B\*("`@("`@("!I9B`H(6ES<V5T
M*"1D871A6R=S:6=N871U<F4G72D@?'P*("`@("`@("`@("`@(6ES<V5T*"1D
M871A6R=S:6=N871U<F4G75LD=6ED7VED>%TI*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5T=7)N7V%R<F%Y.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O
M<F4@=&AE('-I9VYA='5R92!I;F9O<FUA=&EO;B!N;W<N("HO"B`@("`@("`@
M9F]R96%C:"`H)&1A=&%;)W-I9VYA='5R92==6R1U:61?:61X72!A<R`D:V5Y
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6R1K97E=
M(#T@)'9A;'5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<&=P4&%C:V5T4VEG;F%T=7)E*"1D871A+"`D<F5T=7)N7V%R<F%Y*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@<V]M92!D871A('1O('1H92!P9W!0
M86-K9713:6=N871U<F4J*"D@9G5N8W1I;VX@87)R87DN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1D871A("`@("`@4V5E('!G<%!A8VME=%-I9VYA='5R92@I+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1R971A<G)A>2`@5&AE(')E='5R;B!A<G)A>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5T=7)N(&%R<F%Y+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<&=P4&%C:V5T4VEG;F%T=7)E*"1D871A
M+"`D<F5T87)R87DI"B`@("!["B`@("`@("`@+RH@268@96UP='DL(')E='5R
M;B!N;W<N("HO"B`@("`@("`@:68@*&5M<'1Y*"1R971A<G)A>2DI('L*("`@
M("`@("`@("`@<F5T=7)N("1R971A<G)A>3L*("`@("`@("!]"@H@("`@("`@
M("1K97E?='EP92`](&YU;&P["@H@("`@("`@("\J(%-T;W)E(&%N>2!P=6)L
M:6,O<')I=F%T92!K97D@:6YF;W)M871I;VXN("HO"B`@("`@("`@:68@*&ES
M<V5T*"1D871A6R=P=6)L:6-?:V5Y)UTI*2!["B`@("`@("`@("`@("1K97E?
M='EP92`]("=P=6)L:6-?:V5Y)SL*("`@("`@("!](&5L<V5I9B`H:7-S970H
M)&1A=&%;)W-E8W)E=%]K97DG72DI('L*("`@("`@("`@("`@)&ME>5]T>7!E
M(#T@)W-E8W)E=%]K97DG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1K97E?
M='EP92D@>PH@("`@("`@("`@("`D<F5T87)R87E;)VME>5]T>7!E)UT@/2`D
M:V5Y7W1Y<&4["B`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LD:V5Y7W1Y
M<&5=6R=C<F5A=&5D)UTI*2!["B`@("`@("`@("`@("`@("`D<F5T87)R87E;
M)VME>5]C<F5A=&5D)UT@/2`D9&%T85LD:V5Y7W1Y<&5=6R=C<F5A=&5D)UT[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R1K
M97E?='EP95U;)V5X<&ER97,G72DI('L*("`@("`@("`@("`@("`@("1R971A
M<G)A>5LG:V5Y7V5X<&ER97,G72`]("1D871A6R1K97E?='EP95U;)V5X<&ER
M97,G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&1A
M=&%;)&ME>5]T>7!E75LG<VEZ92==*2D@>PH@("`@("`@("`@("`@("`@)')E
M=&%R<F%Y6R=K97E?<VEZ92==(#T@)&1A=&%;)&ME>5]T>7!E75LG<VEZ92==
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E
M=&%R<F%Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VAO
M<G0@9FEN9V5R<')I;G0@*$ME>2!)1"D@;V8@=&AE(&ME>2!U<V5D('1O('-I
M9VX@82!B;&]C:PH@("`@("H@;V8@4$=0(&1A=&$N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE(%!'4"!S:6=N960@=&5X="!B;&]C
M:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-H;W)T(&9I
M;F=E<G!R:6YT(&]F('1H92!K97D@=7-E9"!T;R!S:6=N("1T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9713:6=N97)S1FEN9V5R<')I;G0H)'1E>'0I
M"B`@("!["B`@("`@("`@)&9I;F=E<G!R:6YT(#T@;G5L;#L*"B`@("`@("`@
M)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<&=P)RD[
M"@H@("`@("`@("1F<"`](&9O<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@
M9G!U=',H)&9P+"`D=&5X="D["B`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@
M("`@("1C;61L:6YE(#T@87)R87DH"B`@("`@("`@("`@("<M+79E<FEF>2<L
M"B`@("`@("`@("`@("1I;G!U="P*("`@("`@("`@("`@)S(^)C$G"B`@("`@
M("`@*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L
M:6YE+"`G<B<I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O9W!G.EQS4VEG
M;F%T=7)E7'-M861E+BI)1%QS*RA;02U&,"TY77LX?2E<<RLO)RP@)')E<W5L
M="T^<W1D;W5T+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)&9I;F=E<G!R
M:6YT(#T@)&UA=&-H97-;,5T["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&9I;F=E<G!R:6YT.PH@("`@?0H*("`@("\J*@H@("`@("H@5F5R:69Y(&$@
M<&%S<W!H<F%S92!F;W(@82!G:79E;B!P=6)L:6,O<')I=F%T92!K97EP86ER
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!U8FQI8U]K97D@("!4
M:&4@=7-E<B=S(%!'4"!P=6)L:6,@:V5Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<')I=F%T95]K97D@(%1H92!U<V5R)W,@4$=0('!R:79A=&4@:V5Y+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<W!H<F%S92`@(%1H92!U<V5R)W,@
M<&%S<W!H<F%S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E
M='5R;G,@=')U92!O;B!V86QI9"!P87-S<&AR87-E+"!F86QS92!O;B!I;G9A
M;&ED"B`@("`@*B`@("`@("`@("`@("`@("`@('!A<W-P:')A<V4L(&%N9"!0
M14%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!V97)I
M9GE087-S<&AR87-E*"1P=6)L:6-?:V5Y+"`D<')I=F%T95]K97DL("1P87-S
M<&AR87-E*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O<B!S96-U<F4@8V]N
M;F5C=&EO;BX@*B\*("`@("`@("`D<V5C=7)E7V-H96-K(#T@)'1H:7,M/G)E
M<75I<F5396-U<F5#;VYN96-T:6]N*"D["B`@("`@("`@:68@*&ES7V$H)'-E
M8W5R95]C:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'-E8W5R95]C:&5C:SL*("`@("`@("!]"@H@("`@("`@("\J($5N8W)Y
M<'0@82!T97-T(&UE<W-A9V4N("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YE;F-R>7!T*"=497-T)RP@87)R87DH)W1Y<&4G(#T^("=M97-S86=E)RP@
M)W!U8FME>2<@/3X@)'!U8FQI8U]K97DI*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@("\J(%1R>2!T;R!D96-R>7!T('1H
M92!M97-S86=E+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9&5C<GEP
M="@D<F5S=6QT+"!A<G)A>2@G='EP92<@/3X@)VUE<W-A9V4G+"`G<'5B:V5Y
M)R`]/B`D<'5B;&EC7VME>2P@)W!R:79K97DG(#T^("1P<FEV871E7VME>2P@
M)W!A<W-P:')A<V4G(#T^("1P87-S<&AR87-E*2D["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A(&UE<W-A9V4@:6YT;R!T97AT
M(&%N9"!01U`@8V]M<&]N96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&4@=&5X="!T;R!P87)S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H('1H92!P87)S960@=&5X="P@
M<F5T=7)N960@:6X@8FQO8VMS(&]F"B`@("`@*B`@("`@("`@("`@("`@("!T
M97AT(&-O<G)E<W!O;F1I;F<@=&\@=&AE:7(@86-T=6%L(&]R9&5R+@H@("`@
M("H@/'!R93X*("`@("`J(%)E='5R;B!A<G)A>3H*("`@("`J($ME>2`@("`@
M("`@(%9A;'5E"B`@("`@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`@("`@*B`G='EP92<@(#T^("!4:&4@
M='EP92!O9B!D871A(&-O;G1A:6YE9"!I;B!B;&]C:RX*("`@("`J("`@("`@
M("`@("`@(%9A;&ED('1Y<&5S(&%R92!D969I;F5D(&%T('1H92!T;W`@;V8@
M=&AI<R!C;&%S<PH@("`@("H@("`@("`@("`@("`@*'1H92!01U!?05)-3U)?
M*B!C;VYS=&%N=',I+@H@("`@("H@)V1A=&$G("`]/B`@5&AE(&%C='5A;"!D
M871A(&9O<B!E86-H('-E8W1I;VXN"B`@("`@*B`\+W!R93X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<&%R<V501U!$871A*"1T97AT*0H@("`@>PH@("`@("`@
M("1D871A(#T@87)R87DH*3L*"B`@("`@("`@)&)U9F9E<B`](&5X<&QO9&4H
M(EQN(BP@)'1E>'0I.PH*("`@("`@("`O*B!3970@)'1E;7!?87)R87D@=&\@
M8F4@;V8@='EP92!01U!?05)-3U)?5$585"X@*B\*("`@("`@("`D=&5M<%]A
M<G)A>2`](&%R<F%Y*"D["B`@("`@("`@)'1E;7!?87)R87E;)W1Y<&4G72`]
M(%!'4%]!4DU/4E]415A4.PH*("`@("`@("!F;W)E86-H("@D8G5F9F5R(&%S
M("1V86QU92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXM+2TM
M+2A"14=)3GQ%3D0I(%!'4"`H6UXM72LI+2TM+2U<<RHD+R<L("1V86QU92P@
M)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1E;7!?
M87)R87E;)V1A=&$G72DI('L*("`@("`@("`@("`@("`@("`@("`D9&%T85M=
M(#T@)'1E;7!?87)R87D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!U;G-E="@D=&5M<%]A<G)A>2D["B`@("`@("`@("`@("`@("`D=&5M
M<%]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@("`@("`@("`@:68@*"1M871C
M:&5S6S%=(#T]/2`G0D5'24XG*2!["B`@("`@("`@("`@("`@("`@("`@)'1E
M;7!?87)R87E;)W1Y<&4G72`]("1T:&ES+3Y?87)M;W);)&UA=&-H97-;,EU=
M.PH@("`@("`@("`@("`@("`@("`@("1T96UP7V%R<F%Y6R=D871A)UU;72`]
M("1V86QU93L*("`@("`@("`@("`@("`@('T@96QS96EF("@D;6%T8VAE<ULQ
M72`]/3T@)T5.1"<I('L*("`@("`@("`@("`@("`@("`@("`D=&5M<%]A<G)A
M>5LG='EP92==(#T@4$=07T%234]27U1%6%0["B`@("`@("`@("`@("`@("`@
M("`@)&1A=&%;8V]U;G0H)&1A=&$I("T@,5U;)V1A=&$G75M=(#T@)'9A;'5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1E;7!?87)R87E;)V1A=&$G75M=(#T@)'9A;'5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1E
M;7!?87)R87E;)V1A=&$G72DI('L*("`@("`@("`@("`@)&1A=&%;72`]("1T
M96UP7V%R<F%Y.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D871A.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(%!'4"!P=6)L:6,@:V5Y
M(&9R;VT@82!P=6)L:6,@:V5Y<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9P<FEN="`@5&AE(&9I;F=E<G!R:6YT(&]F('1H92!01U`@
M:V5Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5R=F5R("!4:&4@:V5Y<V5R
M=F5R('1O('5S92X*("`@("`J($!P87)A;2!F;&]A="`D=&EM96]U="`@5&AE
M(&ME>7-E<G9E<B!T:6UE;W5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@4$=0('!U8FQI8R!K97DL(&]R(%!%05)?17)R;W(@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!U8FQI8TME>7-E<G9E<B@D
M9G!R:6YT+"`D<V5R=F5R(#T@4$=07TM%65-%4E9%4E]054),24,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1I;65O=70@/2!01U!?2T59
M4T525D527U1)345/550I"B`@("!["B`@("`@("`@+RH@1V5T('1H92`X(&-H
M87)A8W1E<B!F:6YG97)P<FEN="!S=')I;F<N("HO"B`@("`@("`@:68@*'-T
M<G!O<R@D9G!R:6YT+"`G,'@G*2`]/3T@,"D@>PH@("`@("`@("`@("`D9G!R
M:6YT(#T@<W5B<W1R*"1F<')I;G0L(#(I.PH@("`@("`@('T*("`@("`@("!I
M9B`H<W1R;&5N*"1F<')I;G0I(#X@."D@>PH@("`@("`@("`@("`D9G!R:6YT
M(#T@<W5B<W1R*"1F<')I;G0L(#@I.PH@("`@("`@('T*("`@("`@("`D9G!R
M:6YT(#T@)S!X)R`N("1F<')I;G0["@H@("`@("`@("\J($-O;FYE8W0@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N("HO"B`@("`@("`@)&-M9"`]("='150@
M+W!K<R]L;V]K=7`_;W`]9V5T)F5X86-T/6]N)G-E87)C:#TG("X@)&9P<FEN
M="`N("<@2%144"\Q+C`G.PH@("`@("`@("1O=71P=70@/2`D=&AI<RT^7V-O
M;FYE8W1+97ES97)V97(H)&-M9"P@)'-E<G9E<BP@)'1I;65O=70I.PH@("`@
M("`@(&EF("AI<U]A*"1O=71P=70L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1O=71P=70["B`@("`@("`@?0H*("`@("`@("`O*B!3
M=')I<"!(5$U,(%1A9W,@9G)O;2!O=71P=70N("HO"B`@("`@("`@:68@*"@D
M<W1A<G0@/2!S=')S='(H)&]U='!U="P@)RTM+2TM0D5'24XG*2DI('L*("`@
M("`@("`@("`@)&QE;F=T:"`]('-T<G!O<R@D<W1A<G0L("<M+2TM+45.1"<I
M("L@,S0["B`@("`@("`@("`@(')E='5R;B!S=6)S='(H)'-T87)T+"`P+"`D
M;&5N9W1H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD<R!A(%!'4"!P=6)L
M:6,@:V5Y('1O(&$@<'5B;&EC(&ME>7-E<G9E<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P=6)K97D@(%1H92!01U`@<'5B;&EC(&ME>0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V5R=F5R("!4:&4@:V5Y<V5R=F5R('1O('5S
M92X*("`@("`J($!P87)A;2!F;&]A="`D=&EM96]U="`@5&AE(&ME>7-E<G9E
M<B!T:6UE;W5T+@H@("`@("H*("`@("`J($!R971U<FX@4$5!4E]%<G)O<B`@
M4$5!4E]%<G)O<B!O;B!E<G)O<B]F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P=710=6)L:6-+97ES97)V97(H)'!U8FME>2P@)'-E<G9E<B`](%!'
M4%]+15E315)615)?4%5"3$E#+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:6UE;W5T(#T@4$=07TM%65-%4E9%4E]424U%3U54*0H@("`@
M>PH@("`@("`@("\J($=E="!T:&4@9FEN9V5R<')I;G0@;V8@=&AE('!U8FQI
M8R!K97DN("HO"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^<&=P4&%C:V5T26YF
M;W)M871I;VXH)'!U8FME>2D["@H@("`@("`@("\J(%-E92!I9B!T:&4@<'5B
M;&EC(&ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@:V5Y<V5R=F5R+B`J+PH@
M("`@("`@(&EF("@A:7-?82@D=&AI<RT^9V5T4'5B;&EC2V5Y<V5R=F5R*"1I
M;F9O6R=F:6YG97)P<FEN="==+"`D<V5R=F5R+"`D=&EM96]U="DL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@0V]N;F5C="!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@7V-O;FYE8W1+
M97ES97)V97(H*2!R971U<FYS(&$*("`@("`@("`@("!014%27T5R<F]R(&]B
M:F5C="!O;B!E<G)O<B!A;F0@=&AE(&]U='!U="!T97AT(&]N('-U8V-E<W,N
M("HO"B`@("`@("`@)'!U8FME>2`]("=K97ET97AT/2<@+B!U<FQE;F-O9&4H
M<G1R:6TH)'!U8FME>2DI.PH@("`@("`@("1C;60@/2`G4$]35"`O<&MS+V%D
M9"!(5%10+S$N,%QN0V]N=&5N="U,96YG=&@Z("<@+B!S=')L96XH)'!U8FME
M>2D@+B`B7&Y<;B(@+B`D<'5B:V5Y("X@(EQN(CL*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]C;VYN96-T2V5Y<V5R=F5R*"1C;60L("1S97)V97(L("1T
M:6UE;W5T*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;FYE8W1S('1O(&$@<'5B;&EC(&ME
M>2!S97)V97(@=FEA($A+4"`H2&]R<F]W:71Z($ME>7-E<G9E<B!0<F]T;V-O
M;"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]M;6%N9"`@5&AE(%!'4"!C;VUM86YD('1O
M(')U;BX*("`@("`J($!P87)A;2!S=')I;F<@)'-E<G9E<B`@(%1H92!K97ES
M97)V97(@=&\@=7-E+@H@("`@("H@0'!A<F%M(&9L;V%T("1T:6UE;W5T("`@
M5&AE('1I;65O=70@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!T97AT(&9R;VT@<W1A;F1A<F0@;W5T<'5T(&]N('-U8V-E<W,L
M(&]R(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@("!O;B!E<G)O
M<B]F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C=$ME>7-E
M<G9E<B@D8V]M;6%N9"P@)'-E<G9E<BP@)'1I;65O=70I"B`@("!["B`@("`@
M("`@)&-O;FY2969U<V4@/2`P.PH@("`@("`@("1O=71P=70@/2`G)SL*"B`@
M("`@("`@+RH@071T96UP="!T;R!G970@=&AE(&ME>2!F<F]M('1H92!K97ES
M97)V97(N("HO"B`@("`@("`@9&\@>PH@("`@("`@("`@("`D8V]N;D5R<F]R
M(#T@9F%L<V4["B`@("`@("`@("`@("1E<G)N;R`]("1E<G)S='(@/2!N=6QL
M.PH*("`@("`@("`@("`@+RH@5&AE($A+4"!S97)V97(@:7,@;&]C871E9"!O
M;B!P;W)T(#$Q,S<Q+B`J+PH@("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N
M*"1S97)V97(L("<Q,3,W,2<L("1E<G)N;RP@)&5R<G-T<BP@)'1I;65O=70I
M.PH@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@("`@("`@("`@)&-O
M;FY%<G)O<B`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!F<'5T<R@D9G`L("1C;VUM86YD("X@(EQN7&XB*3L*("`@("`@
M("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2!F9V5T<R@D9G`L(#$P,C0I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D8V]N;D5R<F]R*2!["B`@("`@("`@
M("`@("`@("!I9B`H*RLD8V]N;E)E9G5S92`]/3T@4$=07TM%65-%4E9%4E]2
M14954T4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&5R<FYO(#T](#`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`](%!%05(Z.G)A
M:7-E17)R;W(H7R@B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T
M(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M(BDL(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&5R<G-T<BP@3DQ3.CIG971%
M>'1E<FYA;$-H87)S970H*2DL("1E<G)N;RDL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@
M=VAI;&4@*"1C;VYN17)R;W(I.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'1S('1E>'0@=7-I;F<@4$=0
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X
M="!T;R!B92!01U`@96YC<GEP=&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@96YC<GEP=&EO;BX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!3964@=&AE(&EN9&EV:61U
M86P@7V5N8W)Y<'0J*"D@9G5N8W1I;VYS(&9O<B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!P87)A;65T97(@<F5Q=6ER96UE;G1S+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC<GEP=&5D(&UE<W-A
M9V4L(&]R(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5N8W)Y<'0H)'1E>'0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R=T>7!E)UTI*2!["B`@("`@("`@
M("`@(&EF("@D<&%R86US6R=T>7!E)UT@/3T]("=M97-S86=E)RD@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YC<GEP=$UE<W-A9V4H)'1E
M>'0L("1P87)A;7,I.PH@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG
M='EP92==(#T]/2`G<VEG;F%T=7)E)RD@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?96YC<GEP=%-I9VYA='5R92@D=&5X="P@)'!A<F%M<RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$96-R>7!T<R!T97AT('5S:6YG(%!'4"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@4$=0(&1E8W)Y<'1E
M9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R
M<R!N965D960@9F]R(&1E8W)Y<'1I;VXN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@4V5E('1H92!I;F1I=FED=6%L(%]D96-R>7!T*B@I(&9U;F-T
M:6]N<R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%R
M86UE=&5R(')E<75I<F5M96YT<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&1E8W)Y<'1E9"!M97-S86=E+"!O<B!014%27T5R<F]R(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T*"1T97AT+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-S970H)'!A
M<F%M<ULG='EP92==*2D@>PH@("`@("`@("`@("!I9B`H)'!A<F%M<ULG='EP
M92==(#T]/2`G;65S<V%G92<I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1E8W)Y<'1-97-S86=E*"1T97AT+"`D<&%R86US*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"@D<&%R86US6R=T>7!E)UT@/3T]("=S:6=N871U
M<F4G*2!\?`H@("`@("`@("`@("`@("`@("`@("`@*"1P87)A;7-;)W1Y<&4G
M72`]/3T@)V1E=&%C:&5D+7-I9VYA='5R92<I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]D96-R>7!T4VEG;F%T=7)E*"1T97AT+"`D<&%R
M86US*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T97,@82!T96UP;W)A<GD@9W!G(&ME>7)I;F<N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D='EP92`@5&AE('1Y<&4@;V8@:V5Y('1O(&%N86QY>F4N($5I
M=&AE<B`G<'5B;&EC)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@*$1E
M9F%U;'0I(&]R("=P<FEV871E)PH@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!#;VUM86YD(&QI;F4@:V5Y<W1R:6YG(&]P=&EO;B!T;R!U<V4@=VET
M:"!G<&<@<')O9W)A;2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T94ME
M>7)I;F<H)'1Y<&4@/2`G<'5B;&EC)RD*("`@('L*("`@("`@("`D='EP92`]
M(%-T<FEN9SHZ;&]W97(H)'1Y<&4I.PH*("`@("`@("!I9B`H)'1Y<&4@/3T]
M("=P=6)L:6,G*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!U
M8FQI8TME>7)I;F<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!U8FQI
M8TME>7)I;F<@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92UP9W`G
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)RTM:V5Y<FEN
M9R`G("X@)'1H:7,M/E]P=6)L:6-+97ER:6YG.PH@("`@("`@('T@96QS96EF
M("@D='EP92`]/3T@)W!R:79A=&4G*2!["B`@("`@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7W!R:79A=&5+97ER:6YG*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P<FEV871E2V5Y<FEN9R`]("1T:&ES+3Y?8W)E871E5&5M<$9I
M;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E
M='5R;B`G+2US96-R970M:V5Y<FEN9R`G("X@)'1H:7,M/E]P<FEV871E2V5Y
M<FEN9SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(%!'
M4"!K97ES('1O('1H92!K97ER:6YG+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:V5Y<R`@($$@
M<VEN9VQE(&ME>2!O<B!A;B!A<G)A>2!O9B!K97DH<RD@=&\@861D('1O('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@:V5Y<FEN9RX*("`@("`J
M($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!T>7!E(&]F(&ME>2AS*2!T;R!A
M9&0N($5I=&AE<B`G<'5B;&EC)PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@*$1E9F%U;'0I(&]R("=P<FEV871E)PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!#;VUM86YD(&QI;F4@:V5Y<W1R:6YG(&]P=&EO;B!T;R!U
M<V4@=VET:"!G<&<@<')O9W)A;2X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!U
M=$EN2V5Y<FEN9R@D:V5Y<R`](&%R<F%Y*"DL("1T>7!E(#T@)W!U8FQI8R<I
M"B`@("!["B`@("`@("`@)'1Y<&4@/2!3=')I;F<Z.FQO=V5R*"1T>7!E*3L*
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:V5Y<RDI('L*("`@("`@("`@("`@
M)&ME>7,@/2!A<G)A>2@D:V5Y<RD["B`@("`@("`@?0H*("`@("`@("`O*B!#
M<F5A=&4@=&AE(&ME>7)I;F=S(&EF('1H97D@9&]N)W0@86QR96%D>2!E>&ES
M="X@*B\*("`@("`@("`D:V5Y<FEN9R`]("1T:&ES+3Y?8W)E871E2V5Y<FEN
M9R@D='EP92D["@H@("`@("`@("\J(%-T;W)E('1H92!K97DH<RD@:6X@=&AE
M(&ME>7)I;F<N("HO"B`@("`@("`@)&-M9&QI;F4@/2!A<G)A>2@*("`@("`@
M("`@("`@)RTM86QL;W<M<V5C<F5T+6ME>2UI;7!O<G0G+`H@("`@("`@("`@
M("`G+2UF87-T+6EM<&]R="<L"B`@("`@("`@("`@("1K97ER:6YG"B`@("`@
M("`@*3L*("`@("`@("`D=&AI<RT^7V-A;&Q'<&<H)&-M9&QI;F4L("=W)RP@
M87)R87E?=F%L=65S*"1K97ES*2D["@H@("`@("`@(')E='5R;B`D:V5Y<FEN
M9SL*("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'1S(&$@;65S<V%G92!I
M;B!01U`@9F]R;6%T('5S:6YG(&$@<'5B;&EC(&ME>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("`@5&AE('1E>'0@=&\@8F4@96YC<GEP=&5D+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@
M96YC<GEP=&EO;BX*("`@("`J(#QP<F4^"B`@("`@*B!087)A;65T97)S.@H@
M("`@("H@/3T]/3T]/3T]/3T*("`@("`J("=T>7!E)R`@("`]/B`@)VUE<W-A
M9V4G("A215%525)%1"D*("`@("`J("=P=6)K97DG("`]/B`@4$=0('!U8FQI
M8R!K97DN("A/<'1I;VYA;"D@*$1%4%)%0T%4140I"B`@("`@*B`G96UA:6PG
M("`@/3X@($4M;6%I;"!A9&1R97-S(&]F(')E8VEP:65N="X@268@;F]T('!R
M97-E;G0L(&]R(&YO="!F;W5N9`H@("`@("H@("`@("`@("`@("`@("!I;B!T
M:&4@<'5B;&EC(&ME>2P@=&AE(&9I<G-T(&4M;6%I;"!A9&1R97-S(&9O=6YD
M(&EN('1H90H@("`@("H@("`@("`@("`@("`@("!K97D@=VEL;"!B92!U<V5D
M(&EN<W1E860N("A/<'1I;VYA;"D@*$1%4%)%0T%4140I"B`@("`@*B`G<F5C
M:7!S)R`@/3X@($%N(&%R<F%Y('=I=&@@=&AE(&4M;6%I;"!A9&1R97-S(&]F
M('1H92!R96-I<&EE;G0@87,*("`@("`J("`@("`@("`@("`@("`@=&AE(&ME
M>2!A;F0@=&AA="!P97)S;VXG<R!P=6)L:6,@:V5Y(&%S('1H92!V86QU92X*
M("`@("`J("`@("`@("`@("`@("`@*%)%455)4D5$*0H@("`@("H@/"]P<F4^
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-R>7!T960@
M;65S<V%G92P@;W(@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V5N8W)Y<'1-97-S86=E*"1T97AT+"`D<&%R86US*0H@("`@
M>PH@("`@("`@("1E;6%I;"`](&YU;&P["@H@("`@("`@(&EF("@A:7-S970H
M)'!A<F%M<ULG<F5C:7!S)UTI*2!["B`@("`@("`@("`@("\J($-H96-K(&9O
M<B!R97%U:7)E9"!P87)A;65T97)S+B`J+PH@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1P87)A;7-;)W!U8FME>2==*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($=E="!I;F9O<FUA
M=&EO;B!O;B!T:&4@:V5Y+B`J+PH@("`@("`@("`@("!I9B`H:7-S970H)'!A
M<F%M<ULG96UA:6PG72DI('L*("`@("`@("`@("`@("`@("1K97E?:6YF;R`]
M("1T:&ES+3YP9W!086-K9713:6=N871U<F4H)'!A<F%M<ULG<'5B:V5Y)UTL
M("1P87)A;7-;)V5M86EL)UTI.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D:V5Y7VEN9F\I*2!["B`@("`@("`@("`@("`@("`@("`@)&5M86EL(#T@
M)&ME>5]I;F9O6R=E;6%I;"==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O*B!)9B!W92!H879E(&YO(&5M86EL(&%D
M9')E<W,@870@=&AI<R!P;VEN="P@=7-E('1H92!F:7)S="!E;6%I;`H@("`@
M("`@("`@("`@("!A9&1R97-S(&9O=6YD(&EN('1H92!P=6)L:6,@:V5Y+B`J
M+PH@("`@("`@("`@("!I9B`H96UP='DH)&5M86EL*2D@>PH@("`@("`@("`@
M("`@("`@)&ME>5]I;F9O(#T@)'1H:7,M/G!G<%!A8VME=$EN9F]R;6%T:6]N
M*"1P87)A;7-;)W!U8FME>2==*3L*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D:V5Y7VEN9F];)W-I9VYA='5R92==6R=I9#$G75LG96UA:6PG72DI('L*
M("`@("`@("`@("`@("`@("`@("`D96UA:6P@/2`D:V5Y7VEN9F];)W-I9VYA
M='5R92==6R=I9#$G75LG96UA:6PG73L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<&%R86US6R=R96-I
M<',G72`](&%R<F%Y*"1E;6%I;"`]/B`D<&%R86US6R=P=6)K97DG72D["B`@
M("`@("`@?0H*("`@("`@("`O*B!3=&]R92!P=6)L:6,@:V5Y(&EN('1E;7!O
M<F%R>2!K97ER:6YG+B`J+PH@("`@("`@("1K97ER:6YG(#T@)'1H:7,M/E]P
M=71);DME>7)I;F<H87)R87E?=F%L=65S*"1P87)A;7-;)W)E8VEP<R==*2D[
M"@H@("`@("`@("\J($5N8W)Y<'0@=&AE(&1O8W5M96YT+B`J+PH@("`@("`@
M("1C;61L:6YE(#T@87)R87DH"B`@("`@("`@("`@("<M+6%R;6]R)RP*("`@
M("`@("`@("`@)RTM8F%T8V@G+`H@("`@("`@("`@("`G+2UA;'=A>7,M=')U
M<W0G+`H@("`@("`@("`@("`D:V5Y<FEN9RP*("`@("`@("`@("`@)RTM96YC
M<GEP="<*("`@("`@("`I.PH@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H
M)'!A<F%M<ULG<F5C:7!S)UTI(&%S("1V86PI('L*("`@("`@("`@("`@)&-M
M9&QI;F5;72`]("<M+7)E8VEP:65N="`G("X@)'9A;#L*("`@("`@("!]"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W<G
M+"`D=&5X="P@=')U92P@=')U92D["B`@("`@("`@:68@*&5M<'1Y*"1R97-U
M;'0M/F]U='!U="DI('L*("`@("`@("`@("`@)&5R<F]R(#T@<')E9U]R97!L
M86-E*"<O7&XN*B\G+"`G)RP@)')E<W5L="T^<W1D97)R*3L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4Z("(I("X@)&5R<F]R+"`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT+3YO=71P=70["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3:6=N<R!A(&UE<W-A9V4@:6X@4$=0(&9O
M<FUA="!U<VEN9R!A('!R:79A=&4@:V5Y+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@
M("!4:&4@=&5X="!T;R!B92!S:6=N960N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!S:6=N:6YG+@H@
M("`@("H@/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]/3T]
M/3T]/0H@("`@("H@)W1Y<&4G("`@("`@("`]/B`@)W-I9VYA='5R92<@*%)%
M455)4D5$*0H@("`@("H@)W!U8FME>2<@("`@("`]/B`@4$=0('!U8FQI8R!K
M97DN("A215%525)%1"D*("`@("`J("=P<FEV:V5Y)R`@("`@/3X@(%!'4"!P
M<FEV871E(&ME>2X@*%)%455)4D5$*0H@("`@("H@)W!A<W-P:')A<V4G("`]
M/B`@4&%S<W!H<F%S92!F;W(@4$=0($ME>2X@*%)%455)4D5$*0H@("`@("H@
M)W-I9W1Y<&4G("`@("`]/B`@1&5T97)M:6YE('1H92!S:6=N871U<F4@='EP
M92!T;R!U<V4N("A/<'1I;VYA;"D*("`@("`J("`@("`@("`@("`@("`@("`@
M("=C;&5A<G1E>'0G("`M+2`@36%K92!A(&-L96%R('1E>'0@<VEG;F%T=7)E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`G9&5T86-H)R`@("`@+2T@($UA
M:V4@82!D971A8VAE9"!S:6=N871U<F4@*$1%1D%53%0I"B`@("`@*B`\+W!R
M93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-I9VYE9"!M
M97-S86=E+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?96YC<GEP=%-I9VYA='5R92@D=&5X="P@)'!A<F%M<RD*("`@
M('L*("`@("`@("`O*B!#:&5C:R!F;W(@<V5C=7)E(&-O;FYE8W1I;VXN("HO
M"B`@("`@("`@)'-E8W5R95]C:&5C:R`]("1T:&ES+3YR97%U:7)E4V5C=7)E
M0V]N;F5C=&EO;B@I.PH@("`@("`@(&EF("AI<U]A*"1S96-U<F5?8VAE8VLL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S96-U<F5?
M8VAE8VL["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@<F5Q=6ER
M960@<&%R86UE=&5R<RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;
M)W!U8FME>2==*2!\?`H@("`@("`@("`@("`A:7-S970H)'!A<F%M<ULG<')I
M=FME>2==*2!\?`H@("`@("`@("`@("`A:7-S970H)'!A<F%M<ULG<&%S<W!H
M<F%S92==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92XB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@
M=&5M<"!F:6QE<R!F;W(@:6YP=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H
M:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<&=P)RD["@H@("`@("`@("\J
M($5N8W)Y<'1I;VX@<F5Q=6ER97,@8F]T:"!K97ER:6YG<RX@*B\*("`@("`@
M("`D<'5B7VME>7)I;F<@/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9RAA<G)A>2@D
M<&%R86US6R=P=6)K97DG72DI.PH@("`@("`@("1S96-?:V5Y<FEN9R`]("1T
M:&ES+3Y?<'5T26Y+97ER:6YG*&%R<F%Y*"1P87)A;7-;)W!R:79K97DG72DL
M("=P<FEV871E)RD["@H@("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@=&5M
M<&]R87)Y(&9I;&4N("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G
M=RLG*3L*("`@("`@("!F<'5T<R@D9G`L("1T97AT*3L*("`@("`@("!F8VQO
M<V4H)&9P*3L*"B`@("`@("`@+RH@1&5T97)M:6YE('1H92!S:6=N871U<F4@
M='EP92!T;R!U<V4N("HO"B`@("`@("`@)&-M9&QI;F4@/2!A<G)A>2@I.PH@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R=S:6=T>7!E)UTI("8F"B`@("`@
M("`@("`@("1P87)A;7-;)W-I9W1Y<&4G72`]/2`G8VQE87)T97AT)RD@>PH@
M("`@("`@("`@("`D<VEG;E]T>7!E(#T@)RTM8VQE87)S:6=N)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<VEG;E]T>7!E(#T@)RTM9&5T86-H
M+7-I9VXG.PH@("`@("`@('T*"B`@("`@("`@+RH@061D:71I;VYA;"!'4$<@
M;W!T:6]N<RX@*B\*("`@("`@("`D8VUD;&EN92`K/2!A<G)A>2@*("`@("`@
M("`@("`@)RTM87)M;W(G+`H@("`@("`@("`@("`G+2UB871C:"<L"B`@("`@
M("`@("`@("<M+7!A<W-P:')A<V4M9F0@,"<L"B`@("`@("`@("`@("1S96-?
M:V5Y<FEN9RP*("`@("`@("`@("`@)'!U8E]K97ER:6YG+`H@("`@("`@("`@
M("`D<VEG;E]T>7!E+`H@("`@("`@("`@("`D:6YP=70*("`@("`@("`I.PH*
M("`@("`@("`O*B!3:6=N('1H92!D;V-U;65N="X@*B\*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G=R<L("1P87)A;7-;
M)W!A<W-P:')A<V4G72P@=')U92P@=')U92D["B`@("`@("`@:68@*&5M<'1Y
M*"1R97-U;'0M/F]U='!U="DI('L*("`@("`@("`@("`@)&5R<F]R(#T@<')E
M9U]R97!L86-E*"<O7&XN*B\G+"`G)RP@)')E<W5L="T^<W1D97)R*3L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4Z("(I("X@)&5R<F]R+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M="T^;W5T<'5T.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M8W)Y<'1S(&%N(%!'4"!E;F-R>7!T960@;65S<V%G92!U<VEN9R!A('!R:79A
M=&4O<'5B;&EC(&ME>7!A:7(@86YD(&$*("`@("`J('!A<W-H<')A<V4N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E(&1E8W)Y<'1E9"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R<R!N
M965D960@9F]R(&1E8W)Y<'1I;VXN"B`@("`@*B`\<')E/@H@("`@("H@4&%R
M86UE=&5R<SH*("`@("`J(#T]/3T]/3T]/3T]"B`@("`@*B`G='EP92<@("`@
M("`@(#T^("`G;65S<V%G92<@*%)%455)4D5$*0H@("`@("H@)W!U8FME>2<@
M("`@("`]/B`@4$=0('!U8FQI8R!K97DN("A215%525)%1"D*("`@("`J("=P
M<FEV:V5Y)R`@("`@/3X@(%!'4"!P<FEV871E(&ME>2X@*%)%455)4D5$*0H@
M("`@("H@)W!A<W-P:')A<V4G("`]/B`@4&%S<W!H<F%S92!F;W(@4$=0($ME
M>2X@*%)%455)4D5$*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=&1#;&%S<R`@06X@;V)J96-T('=I=&@@=&AE(&9O;&QO=VEN9R!P
M<F]P97)T:65S+"!O<B!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("!O;B!E<G)O<CH*("`@("`J(#QP<F4^"B`@("`@*B`G;65S<V%G92<@
M("`@("T@(%1H92!D96-R>7!T960@;65S<V%G92X*("`@("`J("=S:6=?<F5S
M=6QT)R`@+2`@5&AE(')E<W5L="!O9B!T:&4@<VEG;F%T=7)E('1E<W0N"B`@
M("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8W)Y<'1-97-S
M86=E*"1T97AT+"`D<&%R86US*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O
M<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D<V5C=7)E7V-H96-K
M(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN96-T:6]N*"D["B`@("`@("`@
M:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C:SL*("`@("`@("!]"@H@("`@
M("`@("1G;V]D7W-I9U]F;&%G(#T@9F%L<V4["@H@("`@("`@("\J($-H96-K
M(&9O<B!R97%U:7)E9"!P87)A;65T97)S+B`J+PH@("`@("`@(&EF("@A:7-S
M970H)'!A<F%M<ULG<'5B:V5Y)UTI('Q\"B`@("`@("`@("`@("%I<W-E="@D
M<&%R86US6R=P<FEV:V5Y)UTI('Q\"B`@("`@("`@("`@("%I<W-E="@D<&%R
M86US6R=P87-S<&AR87-E)UTI*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@
M("`@("\J($-R96%T92!T96UP(&9I;&5S+B`J+PH@("`@("`@("1I;G!U="`]
M("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH*("`@("`@
M("`O*B!$96-R>7!T:6]N(')E<75I<F5S(&)O=&@@:V5Y<FEN9W,N("HO"B`@
M("`@("`@)'!U8E]K97ER:6YG(#T@)'1H:7,M/E]P=71);DME>7)I;F<H87)R
M87DH)'!A<F%M<ULG<'5B:V5Y)UTI*3L*("`@("`@("`D<V5C7VME>7)I;F<@
M/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9RAA<G)A>2@D<&%R86US6R=P<FEV:V5Y
M)UTI+"`G<')I=F%T92<I.PH*("`@("`@("`O*B!3=&]R92!M97-S86=E(&EN
M(&9I;&4N("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*
M("`@("`@("!F<'5T<R@D9G`L("1T97AT*3L*("`@("`@("!F8VQO<V4H)&9P
M*3L*"B`@("`@("`@+RH@1&5C<GEP="!T:&4@9&]C=6UE;G0@;F]W+B`J+PH@
M("`@("`@("1C;61L:6YE(#T@87)R87DH"B`@("`@("`@("`@("<M+6%L=V%Y
M<RUT<G5S="<L"B`@("`@("`@("`@("<M+6%R;6]R)RP*("`@("`@("`@("`@
M)RTM8F%T8V@G+`H@("`@("`@("`@("`G+2UP87-S<&AR87-E+69D(#`G+`H@
M("`@("`@("`@("`D<V5C7VME>7)I;F<L"B`@("`@("`@("`@("1P=6)?:V5Y
M<FEN9RP*("`@("`@("`@("`@)RTM9&5C<GEP="<L"B`@("`@("`@("`@("1I
M;G!U=`H@("`@("`@("D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L
M;$=P9R@D8VUD;&EN92P@)W<G+"`D<&%R86US6R=P87-S<&AR87-E)UTL('1R
M=64L('1R=64I.PH@("`@("`@(&EF("AE;7!T>2@D<F5S=6QT+3YO=71P=70I
M*2!["B`@("`@("`@("`@("1E<G)O<B`]('!R96=?<F5P;&%C92@G+UQN+BHO
M)RP@)R<L("1R97-U;'0M/G-T9&5R<BD["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M.B`B*2`N("1E<G)O<BP@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!#<F5A=&4@=&AE(')E='5R;B!O8FIE8W0N("HO"B`@("`@("`@
M)&]B(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`D;V(M/FUE<W-A9V4@/2`D
M<F5S=6QT+3YO=71P=70["@H@("`@("`@("\J($-H96-K('1H92!01U`@<VEG
M;F%T=7)E+B`J+PH@("`@("`@("1S:6=?8VAE8VL@/2`D=&AI<RT^7V-H96-K
M4VEG;F%T=7)E4F5S=6QT*"1R97-U;'0M/G-T9&5R<BD["B`@("`@("`@:68@
M*&ES7V$H)'-I9U]C:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D;V(M/G-I9U]R97-U;'0@/2`D<VEG7V-H96-K.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1O8BT^<VEG7W)E<W5L="`]("@D<VEG7V-H96-K
M*2`_("1R97-U;'0M/G-T9&5R<B`Z("<G.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1O8CL*("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'1S(&%N
M(%!'4"!S:6=N960@;65S<V%G92!U<VEN9R!A('!U8FQI8R!K97DN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E('9E<FEF:65D+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E
M9"!F;W(@=F5R:69I8V%T:6]N+@H@("`@("H@/'!R93X*("`@("`J(%!A<F%M
M971E<G,Z"B`@("`@*B`]/3T]/3T]/3T]/0H@("`@("H@)W1Y<&4G("`@("`@
M(#T^("`G<VEG;F%T=7)E)R!O<B`G9&5T86-H960M<VEG;F%T=7)E)R`H4D51
M54E2140I"B`@("`@*B`G<'5B:V5Y)R`@("`@/3X@(%!'4"!P=6)L:6,@:V5Y
M+B`H4D5154E2140I"B`@("`@*B`G<VEG;F%T=7)E)R`@/3X@(%!'4"!S:6=N
M871U<F4@8FQO8VLN("A215%525)%1"!F;W(@9&5T86-H960@<VEG;F%T=7)E
M*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!V97)I9FEC871I;VX@;65S<V%G92!F<F]M(&=P9RX@268@;F\@<VEG
M;F%T=7)E+`H@("`@("H@("`@("`@("`@("`@("`@(')E='5R;G,@96UP='D@
M<W1R:6YG+"!A;F0@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V1E8W)Y<'13:6=N871U<F4H)'1E>'0L("1P87)A;7,I"B`@
M("!["B`@("`@("`@+RH@0VAE8VL@9F]R(')E<75I<F5D('!A<F%M971E<G,N
M("HO"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=P=6)K97DG72DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H@("`@("`@(&EF
M("@H)'!A<F%M<ULG='EP92==(#T]/2`G9&5T86-H960M<VEG;F%T=7)E)RD@
M)B8*("`@("`@("`@("`@(6ES<V5T*"1P87)A;7-;)W-I9VYA='5R92==*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("!]"@H@("`@("`@("1G;V]D7W-I9U]F;&%G(#T@,#L*"B`@("`@
M("`@+RH@0W)E871E('1E;7`@9FEL97,@9F]R(&EN<'5T+B`J+PH@("`@("`@
M("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I
M.PH*("`@("`@("`O*B!3=&]R92!P=6)L:6,@:V5Y(&EN('1E;7!O<F%R>2!K
M97ER:6YG+B`J+PH@("`@("`@("1K97ER:6YG(#T@)'1H:7,M/E]P=71);DME
M>7)I;F<H)'!A<F%M<ULG<'5B:V5Y)UTI.PH*("`@("`@("`O*B!3=&]R92!T
M:&4@;65S<V%G92!I;B!A('1E;7!O<F%R>2!F:6QE+B`J+PH@("`@("`@("1F
M<"`](&9O<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@9G!U=',H)&9P+"`D
M=&5X="D["B`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("\J($]P=&EO
M;G,@9F]R('1H92!'4$<@8FEN87)Y+B`J+PH@("`@("`@("1C;61L:6YE(#T@
M87)R87DH"B`@("`@("`@("`@("<M+6%R;6]R)RP*("`@("`@("`@("`@)RTM
M86QW87ES+71R=7-T)RP*("`@("`@("`@("`@)RTM8F%T8V@G+`H@("`@("`@
M("`@("`G+2UC:&%R<V5T("<@+B!.3%,Z.F=E=$-H87)S970H*2P*("`@("`@
M("`@("`@)&ME>7)I;F<L"B`@("`@("`@("`@("<M+79E<FEF>2<*("`@("`@
M("`I.PH*("`@("`@("`O*B!%>'1R82!S='5F9B!T;R!D;R!I9B!W92!A<F4@
M=7-I;F<@82!D971A8VAE9"!S:6=N871U<F4N("HO"B`@("`@("`@:68@*"1P
M87)A;7-;)W1Y<&4G72`]/3T@)V1E=&%C:&5D+7-I9VYA='5R92<I('L*("`@
M("`@("`@("`@)'-I9V9I;&4@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H
M;W)D92UP9W`G*3L*("`@("`@("`@("`@)&-M9&QI;F5;72`]("1S:6=F:6QE
M("X@)R`G("X@)&EN<'5T.PH*("`@("`@("`@("`@)&9P(#T@9F]P96XH)'-I
M9V9I;&4L("=W*R<I.PH@("`@("`@("`@("!F<'5T<R@D9G`L("1P87)A;7-;
M)W-I9VYA='5R92==*3L*("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&-M9&QI;F5;72`]("1I;G!U=#L*
M("`@("`@("!]"B`@("`@("`@)&-M9&QI;F5;72`]("<R/B8Q)SL*"B`@("`@
M("`@+RH@5F5R:69Y('1H92!S:6=N871U<F4N"B`@("`@("`@("`@5V4@;F5E
M9"!T;R!C871C:"!S=&%N9&%R9"!E<G)O<B!O=71P=70L('-I;F-E('1H:7,@
M:7,@=VAE<F4*("`@("`@("`@("!T:&4@<VEG;F%T=7)E(&EN9F]R;6%T:6]N
M(&ES('-E;G0N("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;$=P
M9R@D8VUD;&EN92P@)W(G*3L*("`@("`@("`D<VEG7W)E<W5L="`]("1T:&ES
M+3Y?8VAE8VM3:6=N871U<F5297-U;'0H)')E<W5L="T^<W1D;W5T*3L*("`@
M("`@("!I9B`H:7-?82@D<VEG7W)E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'-I9U]R97-U;'0["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("@D<VEG7W)E<W5L="D@/R`D<F5S=6QT
M+3YS=&1O=70@.B`G)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@<VEG;F%T=7)E(')E<W5L="!F<F]M('1H92!';G501R!B:6YA
M<GDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<F5S=6QT("!4:&4@<VEG;F%T=7)E(')E<W5L
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@<VEG
M;F%T=7)E(&ES(&=O;V0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:U-I
M9VYA='5R95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@("\J($=O;V0@
M<VEG;F%T=7)E.@H@("`@("`@("`J("`@9W!G.B!';V]D('-I9VYA='5R92!F
M<F]M(")B;&%H(&)L86@@8FQA:"`H0V]M;65N="DB"B`@("`@("`@("H@0F%D
M('-I9VYA='5R93H*("`@("`@("`@*B`@(&=P9SH@0D%$('-I9VYA='5R92!F
M<F]M(")B;&%H(&)L86@@8FQA:"`H0V]M;65N="DB("HO"B`@("`@("`@:68@
M*'-T<G!O<R@D<F5S=6QT+"`G9W!G.B!"040@<VEG;F%T=7)E)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1R
M97-U;'0L("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS96EF("AS=')P
M;W,H)')E<W5L="P@)V=P9SH@1V]O9"!S:6=N871U<F4G*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-I9VYS(&$@34E-15]087)T('5S:6YG(%!'4"X*("`@
M("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("1M:6UE7W!A<G0@(%1H92!-
M24U%7U!A<G0@;V)J96-T('1O('-I9VXN"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@("`@("`@(%1H92!P87)A;65T97)S(')E<75I<F5D(&9O<B!S
M:6=N:6YG+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`
M<V5E(%]E;F-R>7!T4VEG;F%T=7)E*"DN"B`@("`@*@H@("`@("H@0')E='5R
M;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B:F5C="!T:&%T(&ES('-I9VYE
M9"!A8V-O<F1I;F<@=&\@4D9#"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M,C`Q-2\S,34V+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S:6=N34E-15!A<G0H)&UI;65?<&%R="P@)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D92]-
M24U%+U!A<G0N<&AP)SL*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E
M*"1P87)A;7,L(&%R<F%Y*"=T>7!E)R`]/B`G<VEG;F%T=7)E)RP@)W-I9W1Y
M<&4G(#T^("=D971A8V@G*2D["@H@("`@("`@("\J(%)&0R`R,#$U(%)E<75I
M<F5M96YT<R!F;W(@82!01U`@<VEG;F5D(&UE<W-A9V4Z"B`@("`@("`@("H@
M*R!#;VYT96YT+51Y<&4@<&%R86US("=M:6-A;&<G("8@)W!R;W1O8V]L)R!A
M<F4@4D5154E2140N"B`@("`@("`@("H@*R!4:&4@9&EG:71A;&QY('-I9VYE
M9"!M97-S86=E($U54U0@8F4@8V]N<W1R86EN960@=&\@-R!B:71S+@H@("`@
M("`@("`J("L@5&AE($U)344@:&5A9&5R<R!-55-4(&)E(&$@<&%R="!O9B!T
M:&4@<VEG;F5D(&1A=&$N("HO"@H@("`@("`@("1M:6UE7W!A<G0M/G-T<FEC
M=#=B:70H=')U92D["B`@("`@("`@)&US9U]S:6=N(#T@)'1H:7,M/F5N8W)Y
M<'0H)&UI;65?<&%R="T^=&]#86YO;FEC86Q3=')I;F<H*2P@)'!A<F%M<RD[
M"B`@("`@("`@:68@*&ES7V$H)&US9U]S:6=N+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D;7-G7W-I9VX["B`@("`@("`@?0H*("`@
M("`@("`O*B!!9&0@=&AE(%!'4"!S:6=N871U<F4N("HO"B`@("`@("`@)'!G
M<%]S:6=N(#T@)FYE=R!-24U%7U!A<G0H)V%P<&QI8V%T:6]N+W!G<"US:6=N
M871U<F4G+"`D;7-G7W-I9VXL(&YU;&PL("=I;FQI;F4G*3L*("`@("`@("`D
M<&=P7W-I9VXM/G-E=$1E<V-R:7!T:6]N*%\H(E!'4"!$:6=I=&%L(%-I9VYA
M='5R92(I*3L*"B`@("`@("`@+RH@1V5T('1H92!A;&=O<FET:&EM(&EN9F]R
M;6%T:6]N(&9R;VT@=&AE('-I9VYA='5R92X@4VEN8V4@=V4@87)E"B`@("`@
M("`@("H@86YA;'EZ:6YG(&$@<VEG;F%T=7)E('!A8VME="P@=V4@;F5E9"!T
M;R!U<V4@=&AE('-P96-I86P@:V5Y=V]R9`H@("`@("`@("`J("=?4TE'3D%4
M55)%)R`M('-E92!(;W)D95]#<GEP=%]P9W`N("HO"B`@("`@("`@)'-I9U]I
M;F9O(#T@)'1H:7,M/G!G<%!A8VME=%-I9VYA='5R92@D;7-G7W-I9VXL("=?
M4TE'3D%455)%)RD["@H@("`@("`@("\J(%-E='5P('1H92!M=6QT:7!A<G0@
M34E-12!087)T+B`J+PH@("`@("`@("1P87)T(#T@)FYE=R!-24U%7U!A<G0H
M)VUU;'1I<&%R="]S:6=N960G*3L*("`@("`@("`D<&%R="T^<V5T0V]N=&5N
M=',H)U1H:7,@;65S<V%G92!I<R!I;B!-24U%(&9O<FUA="!A;F0@:&%S(&)E
M96X@4$=0('-I9VYE9"XG("X@(EQN(BD["B`@("`@("`@)'!A<G0M/F%D9%!A
M<G0H)&UI;65?<&%R="D["B`@("`@("`@)'!A<G0M/F%D9%!A<G0H)'!G<%]S
M:6=N*3L*("`@("`@("`D<&%R="T^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H
M)W!R;W1O8V]L)RP@)V%P<&QI8V%T:6]N+W!G<"US:6=N871U<F4G*3L*("`@
M("`@("`D<&%R="T^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)VUI8V%L9R<L
M("1S:6=?:6YF;ULG;6EC86QG)UTI.PH*("`@("`@("!R971U<FX@)'!A<G0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T<R!A($U)345?4&%R="!U
M<VEN9R!01U`N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM
M95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!E;F-R>7!T+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("!4:&4@<&%R86UE=&5R
M<R!R97%U:7)E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($!S964@7V5N8W)Y<'1-97-S86=E*"DN"B`@
M("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B
M:F5C="!T:&%T(&ES(&5N8W)Y<'1E9"!A8V-O<F1I;F<@=&\@4D9#"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@,C`Q-2\S,34V+"!O<B!014%27T5R<F]R
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-R>7!T34E-15!A
M<G0H)&UI;65?<&%R="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:6YC;'5D95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*"B`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*"1P87)A;7,L(&%R<F%Y*"=T>7!E
M)R`]/B`G;65S<V%G92<I*3L*"B`@("`@("`@)'-I9VYE;F-?8F]D>2`]("1M
M:6UE7W!A<G0M/G1O0V%N;VYI8V%L4W1R:6YG*"D["B`@("`@("`@)&UE<W-A
M9V5?96YC<GEP="`]("1T:&ES+3YE;F-R>7!T*"1S:6=N96YC7V)O9'DL("1P
M87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1M97-S86=E7V5N8W)Y<'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1M97-S86=E7V5N
M8W)Y<'0["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=7`@34E-12!3=')U
M8W1U<F4@86-C;W)D:6YG('1O(%)&0R`R,#$U+B`J+PH@("`@("`@("1P87)T
M(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I<&%R="]E;F-R>7!T960G*3L*("`@
M("`@("`D<&%R="T^<V5T0V]N=&5N=',H)U1H:7,@;65S<V%G92!I<R!I;B!-
M24U%(&9O<FUA="!A;F0@:&%S(&)E96X@4$=0(&5N8W)Y<'1E9"XG("X@(EQN
M(BD["B`@("`@("`@)'!A<G0M/F%D9%!A<G0H;F5W($U)345?4&%R="@G87!P
M;&EC871I;VXO<&=P+65N8W)Y<'1E9"<L(")697)S:6]N.B`Q7&XB+"!N=6QL
M*2D["B`@("`@("`@)'!A<G0M/F%D9%!A<G0H;F5W($U)345?4&%R="@G87!P
M;&EC871I;VXO;V-T970M<W1R96%M)RP@)&UE<W-A9V5?96YC<GEP="P@;G5L
M;"P@)VEN;&EN92<I*3L*("`@("`@("`D<&%R="T^<V5T0V]N=&5N=%1Y<&50
M87)A;65T97(H)W!R;W1O8V]L)RP@)V%P<&QI8V%T:6]N+W!G<"UE;F-R>7!T
M960G*3L*("`@("`@("`D<&%R="T^<V5T1&5S8W)I<'1I;VXH7R@B4$=0($5N
M8W)Y<'1E9"!$871A(BDI.PH*("`@("`@("!R971U<FX@)'!A<G0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3:6=N<R!A;F0@96YC<GEP=',@82!-24U%7U!A
M<G0@=7-I;F<@4$=0+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@
M)&UI;65?<&%R="`@(%1H92!-24U%7U!A<G0@;V)J96-T('1O('-I9VX@86YD
M(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'-I9VY?<&%R86US("`@
M("!4:&4@<&%R86UE=&5R<R!R97%U:7)E9"!F;W(@<VEG;FEN9RX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!S964@7V5N8W)Y<'13
M:6=N871U<F4H*2X*("`@("`J($!P87)A;2!A<G)A>2`D96YC<GEP=%]P87)A
M;7,@(%1H92!P87)A;65T97)S(')E<75I<F5D(&9O<B!E;F-R>7!T:6]N+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0'-E92!?96YC
M<GEP=$UE<W-A9V4H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R
M="`@02!-24U%7U!A<G0@;V)J96-T('1H870@:7,@<VEG;F5D(&%N9"!E;F-R
M>7!T960*("`@("`J("`@("`@("`@("`@("`@("`@("!A8V-O<F1I;F<@=&\@
M4D9#(#(P,34O,S$U-BP@;W(@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<VEG;D%N9$5N8W)Y<'1-24U%4&%R="@D;6EM95]P
M87)T+"`D<VEG;E]P87)A;7,@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D96YC<GEP=%]P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O34E-12]087)T
M+G!H<"<["@H@("`@("`@("\J(%)&0R`R,#$U(')E<75I<F5S('1H870@=&AE
M(&5N=&ER92!S:6=N960@;65S<V%G92!B92!E;F-R>7!T960N("!790H@("`@
M("`@("`J(&YE960@=&\@97AP;&EC:71L>2!C86QL('5S:6YG($AO<F1E7T-R
M>7!T7W!G<#HZ(&)E8V%U<V4@=V4@9&]N)W0*("`@("`@("`@*B!K;F]W('=H
M971H97(@82!S=6)C;&%S<R!H87,@97AT96YD960@=&AE<V4@;65T:&]D<RX@
M*B\*("`@("`@("`D<&%R="`]("1T:&ES+3YS:6=N34E-15!A<G0H)&UI;65?
M<&%R="P@)'-I9VY?<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D<&%R="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'!A<G0["B`@
M("`@("`@?0H@("`@("`@("1P87)T(#T@)'1H:7,M/F5N8W)Y<'1-24U%4&%R
M="@D<&%R="P@)&5N8W)Y<'1?<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D
M<&%R="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'!A
M<G0["B`@("`@("`@?0H@("`@("`@("1P87)T+3YS971#;VYT96YT<R@G5&AI
M<R!M97-S86=E(&ES(&EN($U)344@9F]R;6%T(&%N9"!H87,@8F5E;B!01U`@
M<VEG;F5D(&%N9"!E;F-R>7!T960N)R`N(")<;B(I.PH@("`@("`@("1P87)T
M+3YS971$97-C<FEP=&EO;BA?*")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M(BDI.PH*("`@("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'96YE<F%T97,@82!-24U%7U!A<G0@;V)J96-T+"!I;B!A8V-O<F1A
M;F-E('=I=&@@4D9#(#(P,34O,S$U-BP@=&AA=`H@("`@("H@8V]N=&%I;G,@
M82!P=6)L:6,@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME
M>2`@5&AE('!U8FQI8R!K97DN"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%
M7U!A<G0@($$@34E-15]087)T(&]B:F5C="!T:&%T(&-O;G1A:6YS('1H92!P
M=6)L:6,@:V5Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!P=6)L:6-+97E-24U%
M4&%R="@D:V5Y*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O
M34E-12]087)T+G!H<"<["@H@("`@("`@("1P87)T(#T@)FYE=R!-24U%7U!A
M<G0H)V%P<&QI8V%T:6]N+W!G<"UK97ES)RP@)&ME>2D["B`@("`@("`@)'!A
M<G0M/G-E=$1E<V-R:7!T:6]N*%\H(E!'4"!0=6)L:6,@2V5Y(BDI.PH*("`@
M("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!T:&%T(&AA;F1L97,@:6YT97)F86-I;F<@=VET:"!T:&4@1VYU4$<@
M8FEN87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@(%1/1$\*("`@("`J($!P
M87)A;2!S=')I;F<@)&UO9&4@("`@(%1/1$\*("`@("`J($!P87)A;2!A<G)A
M>2`D:6YP=70@("`@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1O=71P
M=70@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1S=&1E<G(@(%1/1$\*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L87-S("!43T1/"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C86QL1W!G*"1O<'1I;VYS+"`D;6]D92P@)&EN<'5T
M(#T@87)R87DH*2P@)&]U='!U="`](&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@)'-T9&5R<B`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;61L:6YE
M(#T@87)R87E?;65R9V4H)'1H:7,M/E]G;G5P9RP@)&]P=&EO;G,I.PH@("`@
M("`@("1D871A(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`D9&%T82T^;W5T
M<'5T(#T@;G5L;#L*("`@("`@("`D9&%T82T^<W1D97)R(#T@;G5L;#L*("`@
M("`@("`D9&%T82T^<W1D;W5T(#T@;G5L;#L*"B`@("`@("`@+RH@0W)E871E
M('1E;7`@9FEL97,@9F]R(&]U='!U="X@*B\*("`@("`@("!I9B`H)&]U='!U
M="D@>PH@("`@("`@("`@("`D;W5T<'5T7V9I;&4@/2`D=&AI<RT^7V-R96%T
M951E;7!&:6QE*"=H;W)D92UP9W`G+"!F86QS92D["B`@("`@("`@("`@(&%R
M<F%Y7W5N<VAI9G0H)&]P=&EO;G,L("<M+6]U='!U="`G("X@)&]U='!U=%]F
M:6QE*3L*"B`@("`@("`@("`@("\J($1O('=E(&YE960@<W1A;F1A<F0@97)R
M;W(@;W5T<'5T/R`J+PH@("`@("`@("`@("!I9B`H)'-T9&5R<BD@>PH@("`@
M("`@("`@("`@("`@)'-T9&5R<E]F:6QE(#T@)'1H:7,M/E]C<F5A=&5496UP
M1FEL92@G:&]R9&4M<&=P)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)&]P
M=&EO;G-;72`]("<R/B`G("X@)'-T9&5R<E]F:6QE.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!T:&4@8V]M;6%N9"!L:6YE
M('-T<FEN9R!N;W<N("HO"B`@("`@("`@)&-M9&QI;F4@/2!I;7!L;V1E*"<@
M)RP@87)R87E?;65R9V4H)'1H:7,M/E]G;G5P9RP@)&]P=&EO;G,I*3L*"B`@
M("`@("`@:68@*"1M;V1E(#T]("=W)RD@>PH@("`@("`@("`@("`D9G`@/2!P
M;W!E;B@D8VUD;&EN92P@)W<G*3L*("`@("`@("`@("`@)'=I;C,R(#T@<W5B
M<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)3B<["@H@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1I;G!U="DI('L*("`@("`@("`@("`@("`@("1I;G!U="`]
M(&%R<F%Y*"1I;G!U="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R
M96%C:"`H)&EN<'5T(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H
M)'=I;C,R("8F("AS=')P;W,H)&QI;F4L(")<>#!D7'@P82(I("$]/2!F86QS
M92DI('L*("`@("`@("`@("`@("`@("`@("`D8VAU;FMS(#T@97AP;&]D92@B
M7'@P9%QX,&$B+"`D;&EN92D["B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&-H=6YK<R!A<R`D8VAU;FLI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@9G!U=',H)&9P+"`D8VAU;FL@+B`B7&XB*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&9P=71S*"1F<"P@)&QI;F4@+B`B7&XB*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D;6]D92`]
M/2`G<B<I('L*("`@("`@("`@("`@)&9P(#T@<&]P96XH)&-M9&QI;F4L("=R
M)RD["B`@("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2!["B`@("`@("`@
M("`@("`@("`D9&%T82T^<W1D;W5T("X](&9G971S*"1F<"P@,3`R-"D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1F<"D["@H@
M("`@("`@(&EF("@D;W5T<'5T*2!["B`@("`@("`@("`@("1D871A+3YO=71P
M=70@/2!F:6QE7V=E=%]C;VYT96YT<R@D;W5T<'5T7V9I;&4I.PH@("`@("`@
M("`@("!U;FQI;FLH)&]U='!U=%]F:6QE*3L*("`@("`@("`@("`@:68@*"1S
M=&1E<G(I('L*("`@("`@("`@("`@("`@("1D871A+3YS=&1E<G(@/2!F:6QE
M7V=E=%]C;VYT96YT<R@D<W1D97)R7V9I;&4I.PH@("`@("`@("`@("`@("`@
M=6YL:6YK*"1S=&1E<G)?9FEL92D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<```````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#$T-#4R,0`Q,#0Q-S,V,C<W,0`P,C$Q-C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G
M2&]R9&4O0W)Y<'0N<&AP)SL*"B\J*@H@*B!(;W)D95]#<GEP=%]S;6EM93HZ
M('!R;W9I9&5S(&$@9G)A;65W;W)K(&9O<B!(;W)D92!A<'!L:6-A=&EO;G,@
M=&\*("H@:6YT97)A8W0@=VET:"!T:&4@3W!E;E-33"!L:6)R87)Y(&%N9"!I
M;7!L96UE;G0@4R]-24U%+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`L=B`Q+C0Y+C(N,3(@,C`P-B\P,B\P,R`Q-3HU
M,CHU-2!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!(;W)D95]#<GEP=`H@*B\*8VQA<W,@2&]R9&5?0W)Y<'1?<VUI;64@
M97AT96YD<R!(;W)D95]#<GEP="!["@H@("`@+RHJ"B`@("`@*B!/8FIE8W0@
M261E;G1I9F5R<R!T;R!N86UE(&%R<F%Y+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?;VED<R`](&%R<F%Y*`H@("`@("`@
M("<R+C4N-"XS)R`]/B`G0V]M;6]N3F%M92<L"B`@("`@("`@)S(N-2XT+C0G
M(#T^("=3=7)N86UE)RP*("`@("`@("`G,BXU+C0N-B<@/3X@)T-O=6YT<GDG
M+`H@("`@("`@("<R+C4N-"XW)R`]/B`G3&]C871I;VXG+`H@("`@("`@("<R
M+C4N-"XX)R`]/B`G4W1A=&5/<E!R;W9I;F-E)RP*("`@("`@("`G,BXU+C0N
M.2<@/3X@)U-T<F5E=$%D9')E<W,G+`H@("`@("`@("<R+C4N-"XQ,"<@/3X@
M)T]R9V%N:7-A=&EO;B<L"B`@("`@("`@)S(N-2XT+C$Q)R`]/B`G3W)G86YI
M<V%T:6]N86Q5;FET)RP*("`@("`@("`G,BXU+C0N,3(G(#T^("=4:71L92<L
M"B`@("`@("`@)S(N-2XT+C(P)R`]/B`G5&5L97!H;VYE3G5M8F5R)RP*("`@
M("`@("`G,BXU+C0N-#(G(#T^("=':79E;DYA;64G+`H*("`@("`@("`G,BXU
M+C(Y+C$T)R`]/B`G:60M8V4M<W5B:F5C=$ME>4ED96YT:69I97(G+`H*("`@
M("`@("`G,BXU+C(Y+C$T)R`]/B`G:60M8V4M<W5B:F5C=$ME>4ED96YT:69I
M97(G+`H@("`@("`@("<R+C4N,CDN,34G(#T^("=I9"UC92UK97E5<V%G92<L
M"B`@("`@("`@)S(N-2XR.2XQ-R<@/3X@)VED+6-E+7-U8FIE8W1!;'1.86UE
M)RP*("`@("`@("`G,BXU+C(Y+C$Y)R`]/B`G:60M8V4M8F%S:6-#;VYS=')A
M:6YT<R<L"B`@("`@("`@)S(N-2XR.2XS,2<@/3X@)VED+6-E+4-23$1I<W1R
M:6)U=&EO;E!O:6YT<R<L"B`@("`@("`@)S(N-2XR.2XS,B<@/3X@)VED+6-E
M+6-E<G1I9FEC871E4&]L:6-I97,G+`H@("`@("`@("<R+C4N,CDN,S4G(#T^
M("=I9"UC92UA=71H;W)I='E+97E)9&5N=&EF:65R)RP*("`@("`@("`G,BXU
M+C(Y+C,W)R`]/B`G:60M8V4M97AT2V5Y57-A9V4G+`H*("`@("`@("`G,2XR
M+C@T,"XQ,3,U-#DN,2XY+C$G(#T^("=%;6%I;"<L"B`@("`@("`@)S$N,BXX
M-#`N,3$S-30Y+C$N,2XQ)R`]/B`G4E-!16YC<GEP=&EO;B<L"B`@("`@("`@
M)S$N,BXX-#`N,3$S-30Y+C$N,2XR)R`]/B`G;60R5VET:%)3045N8W)Y<'1I
M;VXG+`H@("`@("`@("<Q+C(N.#0P+C$Q,S4T.2XQ+C$N-"<@/3X@)VUD-7=I
M=&A24T%%;F-R>7!T:6]N)RP*("`@("`@("`G,2XR+C@T,"XQ,3,U-#DN,2XQ
M+C4G(#T^("=32$$M,5=I=&A24T%%;F-R>7!T:6]N)RP*("`@("`@("`G,2XR
M+C@T,"XQ,#`T,"XT+C,G(#T^("=I9"UD<V$M=VET:"US:&$M,2<L"@H@("`@
M("`@("<Q+C,N-BXQ+C4N-2XW+C,N,B<@/3X@)VED7VMP7V-L:65N=$%U=&@G
M+`H*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N,2XQ)R`]/B`G;F5T<V-A
M<&4M8V5R="UT>7!E)RP*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N,2XR
M)R`]/B`G;F5T<V-A<&4M8F%S92UU<FPG+`H@("`@("`@("<R+C$V+C@T,"XQ
M+C$Q,S<S,"XQ+C,G(#T^("=N971S8V%P92UR979O8V%T:6]N+75R;"<L"B`@
M("`@("`@)S(N,38N.#0P+C$N,3$S-S,P+C$N-"<@/3X@)VYE='-C87!E+6-A
M+7)E=F]C871I;VXM=7)L)RP*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N
M,2XW)R`]/B`G;F5T<V-A<&4M8V5R="UR96YE=V%L+75R;"<L"B`@("`@("`@
M)S(N,38N.#0P+C$N,3$S-S,P+C$N."<@/3X@)VYE='-C87!E+6-A+7!O;&EC
M>2UU<FPG+`H@("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S,"XQ+C$R)R`]/B`G
M;F5T<V-A<&4M<W-L+7-E<G9E<BUN86UE)RP*("`@("`@("`G,BXQ-BXX-#`N
M,2XQ,3,W,S`N,2XQ,R<@/3X@)VYE='-C87!E+6-O;6UE;G0G+`H@("`@*3L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!087)A;65T97(@87)R87DN"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@)W1E;7`G(#T^($QO8V%T:6]N(&]F('1E
M;7!O<F%R>2!D:7)E8W1O<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7T-R>7!T7W-M:6UE*"1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]T
M96UP9&ER(#T@)'!A<F%M<ULG=&5M<"==.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5F5R:69Y(&$@<&%S<W!H<F%S92!F;W(@82!G:79E;B!P<FEV871E(&ME
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEV871E7VME>2`@
M5&AE('5S97(G<R!P<FEV871E(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<W-P:')A<V4@("!4:&4@=7-E<B=S('!A<W-P:')A<V4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;VX@=F%L:60@
M<&%S<W!H<F%S92P@9F%L<V4@;VX@:6YV86QI9`H@("`@("H@("`@("`@("`@
M("`@("`@("!P87-S<&AR87-E+@H@("`@("H@("`@("`@("`@("`@("`@("!2
M971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('9E<FEF>5!A<W-P:')A<V4H)'!R:79A=&5?:V5Y+"`D<&%S<W!H<F%S
M92D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D<&%S<W!H<F%S92DI('L*
M("`@("`@("`@("`@)')E<R`](&]P96YS<VQ?<&ME>5]G971?<')I=F%T92@D
M<')I=F%T95]K97DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M97,@/2!O<&5N<W-L7W!K97E?9V5T7W!R:79A=&4H)'!R:79A=&5?:V5Y+"`D
M<&%S<W!H<F%S92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-?<F5S
M;W5R8V4H)')E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T('1E
M>'0@=7-I;F<@4R]-24U%+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("!4:&4@=&5X="!T;R!B92!E;F-R>7!T960N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!E
M;F-R>7!T:6]N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%-E92!T
M:&4@:6YD:79I9'5A;"!?96YC<GEP="HH*2!F=6YC=&EO;G,@9F]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=&AE('!A<F%M971E<B!R97%U:7)E
M;65N=',N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-R
M>7!T960@;65S<V%G92X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS
M(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E;F-R>7!T*"1T97AT+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("`O*B!#:&5C:R!F;W(@879A:6QA8FEL:71Y(&]F($]P96Y34TP@
M4$A0(&5X=&5N<VEO;BX@*B\*("`@("`@("`D;W!E;G-S;"`]("1T:&ES+3YC
M:&5C:T9O<D]P96Y34TPH*3L*("`@("`@("!I9B`H:7-?82@D;W!E;G-S;"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&]P96YS<VP[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG='EP92==
M*2D@>PH@("`@("`@("`@("!I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G;65S
M<V%G92<I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V5N8W)Y
M<'1-97-S86=E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1P87)A;7-;)W1Y<&4G72`]/3T@)W-I9VYA='5R92<I('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V5N8W)Y<'13:6=N871U<F4H)'1E
M>'0L("1P87)A;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1&5C<GEP="!T97AT('9I82!3+TU)344N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E
M('-M:6UE(&1E8W)Y<'1E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R(&1E8W)Y<'1I;VXN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@4V5E('1H92!I;F1I=FED=6%L(%]D
M96-R>7!T*B@I(&9U;F-T:6]N<R!F;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@<&%R86UE=&5R(')E<75I<F5M96YT<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!M97-S86=E+@H@
M("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'0H)'1E
M>'0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J($-H96-K
M(&9O<B!A=F%I;&%B:6QI='D@;V8@3W!E;E-33"!02%`@97AT96YS:6]N+B`J
M+PH@("`@("`@("1O<&5N<W-L(#T@)'1H:7,M/F-H96-K1F]R3W!E;E-33"@I
M.PH@("`@("`@(&EF("AI<U]A*"1O<&5N<W-L+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D;W!E;G-S;#L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D<&%R86US6R=T>7!E)UTI*2!["B`@("`@("`@("`@
M(&EF("@D<&%R86US6R=T>7!E)UT@/3T]("=M97-S86=E)RD@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&5C<GEP=$UE<W-A9V4H)'1E>'0L
M("1P87)A;7,I.PH@("`@("`@("`@("!](&5L<V5I9B`H*"1P87)A;7-;)W1Y
M<&4G72`]/3T@)W-I9VYA='5R92<I('Q\"B`@("`@("`@("`@("`@("`@("`@
M("`H)'!A<F%M<ULG='EP92==(#T]/2`G9&5T86-H960M<VEG;F%T=7)E)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E8W)Y<'13:6=N
M871U<F4H)'1E>'0L("1P87)A;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@5F5R:69Y(&$@<VEG;F%T=7)E('5S
M:6YG('9I82!3+TU)344N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@5&AE(&UU;'1I<&%R="]S:6=N960@9&%T82!T;R!B92!V97)I9FEE
M9"X*("`@("`J($!P87)A;2!M:7AE9"`D8V5R=',@($5I=&AE<B!A('-I;F=L
M92!O<B!A<G)A>2!O9B!R;V]T(&-E<G1I9FEC871E<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T9$-L87-S("!/8FIE8W0@=VET:"!T:&4@9F]L;&]W:6YG
M(&5L96UE;G1S.@H@("`@("H@("`@("`@("`@("`@("`@("`@)W)E<W5L="<@
M+3X@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,["B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O
M<BX*("`@("`J("`@("`@("`@("`@("`@("`@("=C97)T)R`M/B!4:&4@8V5R
M=&EF:6-A=&4@;V8@=&AE('-I9VYE<B!S=&]R960*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I;B!T:&4@;65S<V%G92`H:6X@4$5-(&9O
M<FUA="DN"B`@("`@*B`@("`@("`@("`@("`@("`@("`G96UA:6PG("T^(%1H
M92!E;6%I;"!O9B!T:&4@<VEG;FEN9R!P97)S;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N('9E<FEF>2@D=&5X="P@)&-E<G1S*0H@("`@>PH@("`@("`@("\J
M($-H96-K(&9O<B!A=F%I;&%B:6QI='D@;V8@3W!E;E-33"!02%`@97AT96YS
M:6]N+B`J+PH@("`@("`@("1O<&5N<W-L(#T@)'1H:7,M/F-H96-K1F]R3W!E
M;E-33"@I.PH@("`@("`@(&EF("AI<U]A*"1O<&5N<W-L+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;W!E;G-S;#L*("`@("`@("!]
M"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S(&9O<B!I;G!U="]O=71P
M=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL
M92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D;W5T<'5T(#T@)'1H:7,M/E]C
M<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@("`@("`@+RH@5W)I
M=&4@=&5X="!T;R!F:6QE("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T
M+"`G=RLG*3L*("`@("`@("!F=W)I=&4H)&9P+"`D=&5X="D["B`@("`@("`@
M9F-L;W-E*"1F<"D["@H@("`@("`@("1R;V]T7V-E<G1S(#T@87)R87DH*3L*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C97)T<RDI('L*("`@("`@("`@("`@
M)&-E<G1S(#T@87)R87DH)&-E<G1S*3L*("`@("`@("!]"B`@("`@("`@9F]R
M96%C:"`H)&-E<G1S(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("AF:6QE
M7V5X:7-T<R@D9FEL92DI('L*("`@("`@("`@("`@("`@("1R;V]T7V-E<G1S
M6UT@/2`D9FEL93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)&]B(#T@)FYE=R!S=&1#;&%S<SL*"B`@("`@("`@:68@*"%E;7!T>2@D<F]O
M=%]C97)T<RDI('L*("`@("`@("`@("`@)')E<W5L="`](&]P96YS<VQ?<&MC
M<S=?=F5R:69Y*"1I;G!U="P@,"P@)&]U='!U="P@)')O;W1?8V5R=',I.PH@
M("`@("`@("`@("`O*B!-97-S86=E('9E<FEF:65D("HO"B`@("`@("`@("`@
M(&EF("@D<F5S=6QT(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`D;V(M
M/G)E<W5L="`]('1R=64["B`@("`@("`@("`@("`@("`D;V(M/F-E<G0@/2!F
M:6QE7V=E=%]C;VYT96YT<R@D;W5T<'5T*3L*("`@("`@("`@("`@("`@("1O
M8BT^96UA:6P@/2`D=&AI<RT^9V5T16UA:6Q&<F]M2V5Y*"1O8BT^8V5R="D[
M"B`@("`@("`@("`@("`@("!R971U<FX@)&]B.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!4<GD@86=A:6X@=VET:&]U="!V97)F>6EN
M9R!T:&4@<VEG;F5R)W,@8V5R="`J+PH@("`@("`@("1R97-U;'0@/2!O<&5N
M<W-L7W!K8W,W7W9E<FEF>2@D:6YP=70L(%!+0U,W7TY/5D522499+"`D;W5T
M<'5T*3L*"B`@("`@("`@:68@*"@D<F5S=6QT(#T]/2!T<G5E*2!\?"`H)')E
M<W5L="`]/3T@+3$I*2!["B`@("`@("`@("`@("1O8BT^<F5S=6QT(#T@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V
M97)I9FEE9"XB*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;V(M/G)E<W5L="`](%!%05(Z.G)A:7-E17)R;W(H
M7R@B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@('T*"B`@("`@("`@)&]B+3YC97)T(#T@9FEL95]G971?8V]N=&5N=',H
M)&]U='!U="D["B`@("`@("`@)&]B+3YE;6%I;"`]("1T:&ES+3YG971%;6%I
M;$9R;VU+97DH)&]B+3YC97)T*3L*"B`@("`@("`@<F5T=7)N("1O8CL*("`@
M('T*"B`@("`O*BH*("`@("`J($5X=')A8W0@=&AE(&-O;G1E;G1S(&9R;VT@
M<VEG;F5D(%,O34E-12!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&1A=&$@("`@(%1H92!S:6=N960@4R]-24U%(&1A=&$N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S<VQP871H("!4:&4@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M;VYT96YT<R!E;6)E9&1E9"!I;B!T:&4@<VEG;F5D(&1A=&$N"B`@("`@*B`@
M("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!E>'1R86-T4VEG;F5D0V]N=&5N=',H)&1A
M=&$L("1S<VQP871H*0H@("`@>PH@("`@("`@("1P:7!E<U]D97-C(#T@87)R
M87DH"B`@("`@("`@("`@(#`@/3X@87)R87DH)W!I<&4G+"`G<B<I+`H@("`@
M("`@("`@("`Q(#T^(&%R<F%Y*"=P:7!E)RP@)W<G*0H@("`@("`@("D["@H@
M("`@("`@("1F<"`]('!R;V-?;W!E;B@D<W-L<&%T:"`N("<@<VUI;64@+79E
M<FEF>2`M;F]V97)I9GD@+6YO8VAA:6XG+"`D<&EP97-?9&5S8RP@)'!I<&5S
M*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1F<"DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`D;W5T
M<'5T(#T@)R<["@H@("`@("`@("\J("1P:7!E<ULP72`]/B!W<FET96%B;&4@
M:&%N9&QE(&-O;FYE8W1E9"!T;R!C:&EL9"!S=&1I;@H@("`@("`@("`@("1P
M:7!E<ULQ72`]/B!R96%D86)L92!H86YD;&4@8V]N;F5C=&5D('1O(&-H:6QD
M('-T9&]U="`J+PH@("`@("`@(&9W<FET92@D<&EP97-;,%TL("1D871A*3L*
M("`@("`@("!F8VQO<V4H)'!I<&5S6S!=*3L*"B`@("`@("`@=VAI;&4@*"%F
M96]F*"1P:7!E<ULQ72DI('L*("`@("`@("`@("`@)&]U='!U="`N/2!F9V5T
M<R@D<&EP97-;,5TL(#$P,C0I.PH@("`@("`@('T*("`@("`@("!F8VQO<V4H
M)'!I<&5S6S%=*3L*("`@("`@("!P<F]C7V-L;W-E*"1F<"D["@H@("`@("`@
M(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4VEG;B!A
M($U)345?4&%R="!U<VEN9R!3+TU)344N"B`@("`@*@H@("`@("H@0'!A<F%M
M($U)345?4&%R="`D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T
M;R!S:6=N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("!4
M:&4@<&%R86UE=&5R<R!R97%U:7)E9"!F;W(@<VEG;FEN9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%7U!A<G0@;V)J96-T('1H
M870@:7,@<VEG;F5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@(%)E='5R
M;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-I9VY-24U%4&%R="@D;6EM95]P87)T+"`D<&%R86US*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]087)T+G!H<"<[
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C='5R92YP
M:'`G.PH*("`@("`@("`O*B!3:6=N('1H92!P87)T(&%S(&$@;65S<V%G92`J
M+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M/F5N8W)Y<'0H)&UI;65?<&%R
M="T^=&]#86YO;FEC86Q3=')I;F<H*2P@)'!A<F%M<RD["@H@("`@("`@("\J
M($)R96%K('1H92!R97-U;'0@:6YT;R!I=',@8V]M<&]N96YT<R`J+PH@("`@
M("`@("1M:6UE7VUE<W-A9V4@/2!-24U%7U-T<G5C='5R93HZ<&%R<V5497AT
M34E-14UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`D<VUI;65?<VEG;B`]
M("1M:6UE7VUE<W-A9V4M/F=E=%!A<G0H,BD["B`@("`@("`@)'-M:6UE7W-I
M9VXM/G-E=$1E<V-R:7!T:6]N*%\H(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R92(I*3L*("`@("`@("`D<VUI;65?<VEG;BT^=')A;G-F97)$96-O
M9&5#;VYT96YT<R@I.PH@("`@("`@("1S;6EM95]S:6=N+3YS9714<F%N<V9E
M<D5N8V]D:6YG*"=B87-E-C0G*3L*"B`@("`@("`@)'-M:6UE7W!A<G0@/2`F
M;F5W($U)345?4&%R="@G;75L=&EP87)T+W-I9VYE9"<I.PH@("`@("`@("1S
M;6EM95]P87)T+3YS971#;VYT96YT<R@G5&AI<R!I<R!A(&-R>7!T;V=R87!H
M:6-A;&QY('-I9VYE9"!M97-S86=E(&EN($U)344@9F]R;6%T+B<@+B`B7&XB
M*3L*("`@("`@("`D<VUI;65?<&%R="T^861D4&%R="@D;6EM95]P87)T*3L*
M("`@("`@("`D<VUI;65?<&%R="T^861D4&%R="@D<VUI;65?<VEG;BD["B`@
M("`@("`@)'-M:6UE7W!A<G0M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=P
M<F]T;V-O;"<L("=A<'!L:6-A=&EO;B]P:V-S-RUS:6=N871U<F4G*3L*("`@
M("`@("`D<VUI;65?<&%R="T^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)VUI
M8V%L9R<L("=S:&$Q)RD["@H@("`@("`@(')E='5R;B`D<VUI;65?<&%R=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!-24U%7U!A<G0@=7-I
M;F<@4R]-24U%+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)&UI
M;65?<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@=&\@96YC<GEP="X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@5&AE('!A<F%M971E
M<G,@<F5Q=6ER960@9F]R(&5N8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B:F5C="!T:&%T(&ES(&5N
M8W)Y<'1E9"X*("`@("`J("`@("`@("`@("`@("`@("`@("!2971U<FYS(%!%
M05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y
M<'1-24U%4&%R="@D;6EM95]P87)T+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4&%R="YP:'`G
M.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]3=')U8W1U<F4N
M<&AP)SL*"B`@("`@("`@+RH@4VEG;B!T:&4@<&%R="!A<R!A(&UE<W-A9V4@
M*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3YE;F-R>7!T*"1M:6UE7W!A
M<G0M/G1O0V%N;VYI8V%L4W1R:6YG*"DL("1P87)A;7,I.PH@("`@("`@(&EF
M("AI<U]A*"1M97-S86=E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D;65S<V%G93L*("`@("`@("!]"@H@("`@("`@("\J($)R96%K
M('1H92!R97-U;'0@:6YT;R!I=',@8V]M<&]N96YT<R`J+PH@("`@("`@("1M
M:6UE7VUE<W-A9V4@/2!-24U%7U-T<G5C='5R93HZ<&%R<V5497AT34E-14UE
M<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`D<VUI;65?<&%R="`]("1M:6UE
M7VUE<W-A9V4M/F=E=$)A<V5087)T*"D["B`@("`@("`@)'-M:6UE7W!A<G0M
M/G-E=$1E<V-R:7!T:6]N*%\H(E,O34E-12!%;F-R>7!T960@365S<V%G92(I
M*3L*("`@("`@("`D<VUI;65?<&%R="T^=')A;G-F97)$96-O9&5#;VYT96YT
M<R@I.PH@("`@("`@("1S;6EM95]P87)T+3YS9714<F%N<V9E<D5N8V]D:6YG
M*"=B87-E-C0G*3L*("`@("`@("`D<VUI;65?<&%R="T^<V5T1&ES<&]S:71I
M;VXH)VEN;&EN92<I.PH*("`@("`@("`O*B!">2!D969A=6QT+"!E;F-R>7!T
M*"D@<')O9'5C97,@82!M97-S86=E('=I=&@@='EP90H@("`@("`@("`J("=A
M<'!L:6-A=&EO;B]X+7!K8W,W+6UI;64G(&%N9"!N;R`G<VUI;64M='EP92<@
M<&%R86UE=&5R+B!097(*("`@("`@("`@*B!21D,@,C,Q,2P@=&AE(&UO<F4@
M8V]R<F5C="!-24U%('1Y<&4@:7,@)V%P<&QI8V%T:6]N+W!K8W,W+6UI;64G
M"B`@("`@("`@("H@86YD('1H92!S;6EM92UT>7!E('-H;W5L9"!B92`G96YV
M96QO<&5D+61A=&$G+B`J+PH@("`@("`@("1S;6EM95]P87)T+3YS9714>7!E
M*"=A<'!L:6-A=&EO;B]P:V-S-RUM:6UE)RD["B`@("`@("`@)'-M:6UE7W!A
M<G0M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=S;6EM92UT>7!E)RP@)V5N
M=F5L;W!E9"UD871A)RD["@H@("`@("`@(')E='5R;B`D<VUI;65?<&%R=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!M97-S86=E(&EN(%,O
M34E-12!F;W)M870@=7-I;F<@82!P=6)L:6,@:V5Y+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("!4:&4@=&5X="!T;R!B92!E;F-R>7!T960N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!E
M;F-R>7!T:6]N+@H@("`@("H@/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@
M("`@*B`]/3T]/3T]/3T]/0H@("`@("H@)W1Y<&4G("`@(#T^("`G;65S<V%G
M92<@*%)%455)4D5$*0H@("`@("H@)W!U8FME>2<@(#T^("!P=6)L:6,@:V5Y
M+B`H4D5154E2140I"B`@("`@*B`G96UA:6PG("`@/3X@($4M;6%I;"!A9&1R
M97-S(&]F(')E8VEP:65N="X@268@;F]T('!R97-E;G0L(&]R(&YO="!F;W5N
M9`H@("`@("H@("`@("`@("`@("`@("!I;B!T:&4@<'5B;&EC(&ME>2P@=&AE
M(&9I<G-T(&4M;6%I;"!A9&1R97-S(&9O=6YD(&EN('1H90H@("`@("H@("`@
M("`@("`@("`@("!K97D@=VEL;"!B92!U<V5D(&EN<W1E860N("A/<'1I;VYA
M;"D*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@96YC<GEP=&5D(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@("`@
M("`@4F5T=7)N(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?96YC<GEP=$UE<W-A9V4H)'1E>'0L("1P87)A;7,I
M"B`@("!["B`@("`@("`@)&5M86EL(#T@;G5L;#L*"B`@("`@("`@+RH@0VAE
M8VL@9F]R(')E<75I<F5D('!A<F%M971E<G,N("HO"B`@("`@("`@:68@*"%I
M<W-E="@D<&%R86US6R=P=6)K97DG72DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S(&9O
M<B!I;G!U="]O=71P=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C
M<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D;W5T<'5T
M(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@
M("`@("`@+RH@4W1O<F4@;65S<V%G92!I;B!F:6QE+B`J+PH@("`@("`@("1F
M<#$@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P=71S*"1F<#$L
M("1T97AT*3L*("`@("`@("!F8VQO<V4H)&9P,2D["@H@("`@("`@(&EF("AI
M<W-E="@D<&%R86US6R=E;6%I;"==*2D@>PH@("`@("`@("`@("`D96UA:6P@
M/2`D<&%R86US6R=E;6%I;"==.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1E;6%I;"`]("1T:&ES+3YG971%;6%I;$9R;VU+97DH)'!A<F%M<ULG
M<'5B:V5Y)UTI.PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D96UA:6PI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J($5N8W)Y<'0@=&AE(&1O8W5M96YT+B`J+PH@("`@
M("`@(&EF("AO<&5N<W-L7W!K8W,W7V5N8W)Y<'0H)&EN<'5T+"`D;W5T<'5T
M+"`D<&%R86US6R=P=6)K97DG72P@87)R87DH)U1O)R`]/B`D96UA:6PI*2D@
M>PH@("`@("`@("`@("`D<F5S=6QT(#T@9FEL95]G971?8V]N=&5N=',H)&]U
M='!U="D["B`@("`@("`@("`@(&EF("@A96UP='DH)')E<W5L="DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V9I>$-O;G1E;G14>7!E*"1R
M97-U;'0L("=E;F-R>7!T)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-I9VX@82!M97-S86=E(&EN(%,O34E-12!F
M;W)M870@=7-I;F<@82!P<FEV871E(&ME>2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT
M("`@5&AE('1E>'0@=&\@8F4@<VEG;F5D+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@<VEG;FEN9RX*
M("`@("`J(#QP<F4^"B`@("`@*B!087)A;65T97)S.@H@("`@("H@/3T]/3T]
M/3T]/3T*("`@("`J("=C97)T<R<@("`@("`@/3X@($%D9&ET:6]N86P@<VEG
M;FEN9R!C97)T<R`H3W!T:6]N86PI"B`@("`@*B`G<&%S<W!H<F%S92<@(#T^
M("!087-S<&AR87-E(&9O<B!K97D@*%)%455)4D5$*0H@("`@("H@)W!R:79K
M97DG("`@("`]/B`@4')I=F%T92!K97D@*%)%455)4D5$*0H@("`@("H@)W!U
M8FME>2<@("`@("`]/B`@4'5B;&EC(&ME>2`H4D5154E2140I"B`@("`@*B`G
M<VEG='EP92<@("`@(#T^("!$971E<FUI;F4@=&AE('-I9VYA='5R92!T>7!E
M('1O('5S92X@*$]P=&EO;F%L*0H@("`@("H@("`@("`@("`@("`@("`@("`@
M)V-L96%R=&5X="<@("TM("!-86ME(&$@8VQE87(@=&5X="!S:6=N871U<F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("=D971A8V@G("`@("`M+2`@36%K
M92!A(&1E=&%C:&5D('-I9VYA='5R92`H1$5&055,5"D*("`@("`J("=T>7!E
M)R`@("`@("`@/3X@("=S:6=N871U<F4G("A215%525)%1"D*("`@("`J(#PO
M<')E/@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<VEG;F5D
M(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N(%!%05)?
M17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M96YC<GEP=%-I9VYA='5R92@D=&5X="P@)'!A<F%M<RD*("`@('L*("`@("`@
M("`O*B!#:&5C:R!F;W(@<V5C=7)E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@
M)'-E8W5R95]C:&5C:R`]("1T:&ES+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO
M;B@I.PH@("`@("`@(&EF("AI<U]A*"1S96-U<F5?8VAE8VLL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S96-U<F5?8VAE8VL["B`@
M("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@<F5Q=6ER960@<&%R86UE
M=&5R<RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)W!U8FME>2==
M*2!\?`H@("`@("`@("`@("`A:7-S970H)'!A<F%M<ULG<')I=FME>2==*2!\
M?`H@("`@("`@("`@("`A87)R87E?:V5Y7V5X:7-T<R@G<&%S<W!H<F%S92<L
M("1P87)A;7,I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S
M86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J
M($-R96%T92!T96UP(&9I;&5S(&9O<B!I;G!U="]O=71P=70O8V5R=&EF:6-A
M=&5S+B`J+PH@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I
M;&4H)VAO<F1E+7-M:6UE)RD["B`@("`@("`@)&]U='!U="`]("1T:&ES+3Y?
M8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["B`@("`@("`@)&-E<G1S
M(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@
M("`@("`@+RH@4W1O<F4@;65S<V%G92!I;B!T96UP;W)A<GD@9FEL92X@*B\*
M("`@("`@("`D9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P
M=71S*"1F<"P@)'1E>'0I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@
M("`O*B!3=&]R92!A9&1I=&EO;F%L(&-E<G1S(&EN('1E;7!O<F%R>2!F:6QE
M+B`J+PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG8V5R=',G72DI('L*
M("`@("`@("`@("`@)&9P(#T@9F]P96XH)&-E<G1S+"`G=RLG*3L*("`@("`@
M("`@("`@9G!U=',H)&9P+"`D<&%R86US6R=C97)T<R==*3L*("`@("`@("`@
M("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H*("`@("`@("`O*B!$971E<FUI
M;F4@=&AE('-I9VYA='5R92!T>7!E('1O('5S92X@*B\*("`@("`@("!I9B`H
M:7-S970H)'!A<F%M<ULG<VEG='EP92==*2`F)B`H)'!A<F%M<ULG<VEG='EP
M92==(#T]("=C;&5A<G1E>'0G*2D@>PH@("`@("`@("`@("`D9FQA9W,@/2!0
M2T-3-U]415A4.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F;&%G
M<R`](%!+0U,W7T1%5$%#2$5$.PH@("`@("`@('T*"B`@("`@("`@)'!R:79K
M97D@/2`H:7-?;G5L;"@D<&%R86US6R=P87-S<&AR87-E)UTI*2`_("1P87)A
M;7-;)W!R:79K97DG72`Z(&%R<F%Y*"1P87)A;7-;)W!R:79K97DG72P@)'!A
M<F%M<ULG<&%S<W!H<F%S92==*3L*"B`@("`@("`@:68@*&5M<'1Y*"1P87)A
M;7-;)V-E<G1S)UTI*2!["B`@("`@("`@("`@("1R97,@/2!O<&5N<W-L7W!K
M8W,W7W-I9VXH)&EN<'5T+"`D;W5T<'5T+"`D<&%R86US6R=P=6)K97DG72P@
M)'!R:79K97DL(&%R<F%Y*"DL("1F;&%G<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)')E<R`](&]P96YS<VQ?<&MC<S=?<VEG;B@D:6YP=70L
M("1O=71P=70L("1P87)A;7-;)W!U8FME>2==+"`D<')I=FME>2P@87)R87DH
M*2P@)&9L86=S+"`D8V5R=',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D
M<F5S*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(I+"`G:&]R9&4N97)R
M;W(G*3L*("`@("`@("!]"@H@("`@("`@("1D871A(#T@9FEL95]G971?8V]N
M=&5N=',H)&]U='!U="D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9FEX0V]N
M=&5N=%1Y<&4H)&1A=&$L("=S:6=N871U<F4G*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E8W)Y<'0@86X@4R]-24U%(&5N8W)Y<'1E9"!M97-S86=E('5S
M:6YG(&$@<')I=F%T92]P=6)L:6,@:V5Y<&%I<@H@("`@("H@86YD(&$@<&%S
M<VAP<F%S92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@
M9&5C<GEP=&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P
M87)A;65T97)S(&YE961E9"!F;W(@9&5C<GEP=&EO;BX*("`@("`J(#QP<F4^
M"B`@("`@*B!087)A;65T97)S.@H@("`@("H@/3T]/3T]/3T]/3T*("`@("`J
M("=T>7!E)R`@("`@("`@/3X@("=M97-S86=E)R`H4D5154E2140I"B`@("`@
M*B`G<'5B:V5Y)R`@("`@(#T^("!P=6)L:6,@:V5Y+B`H4D5154E2140I"B`@
M("`@*B`G<')I=FME>2<@("`@(#T^("!P<FEV871E(&ME>2X@*%)%455)4D5$
M*0H@("`@("H@)W!A<W-P:')A<V4G("`]/B`@4&%S<W!H<F%S92!F;W(@2V5Y
M+B`H4D5154E2140I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!M97-S86=E+@H@("`@("H@("`@
M("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96-R>7!T365S<V%G92@D=&5X
M="P@)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!#:&5C:R!F;W(@<V5C=7)E
M(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'-E8W5R95]C:&5C:R`]("1T:&ES
M+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO;B@I.PH@("`@("`@(&EF("AI<U]A
M*"1S96-U<F5?8VAE8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1S96-U<F5?8VAE8VL["B`@("`@("`@?0H*("`@("`@("`O*B!#
M:&5C:R!F;W(@<F5Q=6ER960@<&%R86UE=&5R<RX@*B\*("`@("`@("!I9B`H
M(6ES<V5T*"1P87)A;7-;)W!U8FME>2==*2!\?`H@("`@("`@("`@("`A:7-S
M970H)'!A<F%M<ULG<')I=FME>2==*2!\?`H@("`@("`@("`@("`A87)R87E?
M:V5Y7V5X:7-T<R@G<&%S<W!H<F%S92<L("1P87)A;7,I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+B(I+"`G:&]R9&4N97)R
M;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S
M(&9O<B!I;G!U="]O=71P=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M
M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D;W5T
M<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*
M"B`@("`@("`@+RH@4W1O<F4@;65S<V%G92!I;B!F:6QE+B`J+PH@("`@("`@
M("1F<"`](&9O<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@9G!U=',H)&9P
M+"!T<FEM*"1T97AT*2D["B`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@
M("1P<FEV:V5Y(#T@*&ES7VYU;&PH)'!A<F%M<ULG<&%S<W!H<F%S92==*2D@
M/R`D<&%R86US6R=P<FEV:V5Y)UT@.B!A<G)A>2@D<&%R86US6R=P<FEV:V5Y
M)UTL("1P87)A;7-;)W!A<W-P:')A<V4G72D["B`@("`@("`@:68@*&]P96YS
M<VQ?<&MC<S=?9&5C<GEP="@D:6YP=70L("1O=71P=70L("1P87)A;7-;)W!U
M8FME>2==+"`D<')I=FME>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9I;&5?
M9V5T7V-O;G1E;G1S*"1O=71P=70I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4VEG;B!A;F0@16YC<GEP="!A($U)345?4&%R="!U<VEN9R!3+TU)
M344N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM95]P87)T
M("`@5&AE($U)345?4&%R="!O8FIE8W0@=&\@<VEG;B!A;F0@96YC<GEP="X*
M("`@("`J($!P87)A;2!A<G)A>2`D<VEG;E]P87)A;7,@("`@(%1H92!P87)A
M;65T97)S(')E<75I<F5D(&9O<B!S:6=N:6YG+B!3964*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]E;F-R>7!T4VEG;F%T=7)E*"DN
M"B`@("`@*B!`<&%R86T@87)R87D@)&5N8W)Y<'1?<&%R86US("!4:&4@<&%R
M86UE=&5R<R!R97%U:7)E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%-E92!?96YC<GEP=$UE<W-A9V4H
M*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%7U!A
M<G0@;V)J96-T('1H870@:7,@<VEG;F5D(&%N9"!E;F-R>7!T960N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:6=N06YD16YC<GEP=$U)3450
M87)T*"1M:6UE7W!A<G0L("1S:6=N7W!A<F%M<R`](&%R<F%Y*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;F-R>7!T7W!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D
M92]-24U%+U!A<G0N<&AP)SL*"B`@("`@("`@)'!A<G0@/2`D=&AI<RT^<VEG
M;DU)345087)T*"1M:6UE7W!A<G0L("1S:6=N7W!A<F%M<RD["B`@("`@("`@
M:68@*&ES7V$H)'!A<G0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1P87)T.PH@("`@("`@('T*("`@("`@("`D<&%R="`]("1T:&ES
M+3YE;F-R>7!T34E-15!A<G0H)'!A<G0L("1E;F-R>7!T7W!A<F%M<RD["B`@
M("`@("`@:68@*&ES7V$H)'!A<G0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1P87)T.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!A(%!%32!F
M;W)M870@8V5R=&EF:6-A=&4@=&\@<F5A9&%B;&4@2%1-3"!V97)S:6]N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V5R="`@(%!%32!F;W)M870@
M8V5R=&EF:6-A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@2%1-
M3"!D971A:6QI;F<@=&AE(&-E<G1I9FEC871E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C97)T5&](5$U,*"1C97)T*0H@("`@>PH@("`@("`@("\J($-O;6UO
M;B!&:65L9',@*B\*("`@("`@("`D9FEE;&1N86UE<R`](&%R<F%Y*`H@("`@
M("`@("`@("`G16UA:6PG(#T^(%\H(D5M86EL($%D9')E<W,B*2P*("`@("`@
M("`@("`@)T-O;6UO;DYA;64G(#T^(%\H(D-O;6UO;B!.86UE(BDL"B`@("`@
M("`@("`@("=/<F=A;FES871I;VXG(#T^(%\H(D]R9V%N:7-A=&EO;B(I+`H@
M("`@("`@("`@("`G3W)G86YI<V%T:6]N86Q5;FET)R`]/B!?*")/<F=A;FES
M871I;VYA;"!5;FET(BDL"B`@("`@("`@("`@("=#;W5N=')Y)R`]/B!?*")#
M;W5N=')Y(BDL"B`@("`@("`@("`@("=3=&%T94]R4')O=FEN8V4G(#T^(%\H
M(E-T871E(&]R(%!R;W9I;F-E(BDL"B`@("`@("`@("`@("=,;V-A=&EO;B<@
M/3X@7R@B3&]C871I;VXB*2P*("`@("`@("`@("`@)U-T<F5E=$%D9')E<W,G
M(#T^(%\H(E-T<F5E="!!9&1R97-S(BDL"B`@("`@("`@("`@("=496QE<&AO
M;F5.=6UB97(G(#T^(%\H(E1E;&5P:&]N92!.=6UB97(B*2P*("`@("`@("`@
M("`@)U-U<FYA;64G(#T^(%\H(E-U<FYA;64B*2P*("`@("`@("`@("`@)T=I
M=F5N3F%M92<@/3X@7R@B1VEV96X@3F%M92(I"B`@("`@("`@*3L*"B`@("`@
M("`@+RH@3F5T<V-A<&4@17AT96YS:6]N<R`J+PH@("`@("`@("1F:65L9&YA
M;65S("L](&%R<F%Y*`H@("`@("`@("`@("`G;F5T<V-A<&4M8V5R="UT>7!E
M)R`]/B!?*").971S8V%P92!C97)T:69I8V%T92!T>7!E(BDL"B`@("`@("`@
M("`@("=N971S8V%P92UB87-E+75R;"<@/3X@7R@B3F5T<V-A<&4@0F%S92!5
M4DPB*2P*("`@("`@("`@("`@)VYE='-C87!E+7)E=F]C871I;VXM=7)L)R`]
M/B!?*").971S8V%P92!2979O8V%T:6]N(%523"(I+`H@("`@("`@("`@("`G
M;F5T<V-A<&4M8V$M<F5V;V-A=&EO;BUU<FPG(#T^(%\H(DYE='-C87!E($-!
M(%)E=F]C871I;VX@55),(BDL"B`@("`@("`@("`@("=N971S8V%P92UC97)T
M+7)E;F5W86PM=7)L)R`]/B!?*").971S8V%P92!296YE=V%L(%523"(I+`H@
M("`@("`@("`@("`G;F5T<V-A<&4M8V$M<&]L:6-Y+75R;"<@/3X@7R@B3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523"(I+`H@("`@("`@("`@("`G;F5T<V-A<&4M
M<W-L+7-E<G9E<BUN86UE)R`]/B!?*").971S8V%P92!34TP@<V5R=F5R(&YA
M;64B*2P*("`@("`@("`@("`@)VYE='-C87!E+6-O;6UE;G0G(#T^(%\H(DYE
M='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B*0H@("`@("`@("D["@H@("`@
M("`@("\J(%@U.3!V,R!%>'1E;G-I;VYS("HO"B`@("`@("`@)&9I96QD;F%M
M97,@*ST@87)R87DH"B`@("`@("`@("`@("=I9"UC92UE>'1+97E5<V%G92<@
M/3X@7R@B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(I+`H@("`@("`@("`@
M("`G:60M8V4M8F%S:6-#;VYS=')A:6YT<R<@/3X@7R@B6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S(BDL"B`@("`@("`@("`@("=I9"UC92US=6)J96-T06QT
M3F%M92<@/3X@7R@B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(I
M+`H@("`@("`@("`@("`G:60M8V4M<W5B:F5C=$ME>4ED96YT:69I97(G(#T^
M(%\H(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(BDL"B`@("`@("`@
M("`@("=I9"UC92UC97)T:69I8V%T95!O;&EC:65S)R`]/B!?*")#97)T:69I
M8V%T92!0;VQI8VEE<R(I+`H@("`@("`@("`@("`G:60M8V4M0U),1&ES=')I
M8G5T:6]N4&]I;G1S)R`]/B!?*")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(I
M+`H@("`@("`@("`@("`G:60M8V4M:V5Y57-A9V4G(#T^(%\H(DME>2!5<V%G
M92(I"B`@("`@("`@*3L*"B`@("`@("`@)&-E<G1?9&5T86EL<R`]("1T:&ES
M+3YP87)S94-E<G0H)&-E<G0I.PH@("`@("`@(&EF("@A:7-?87)R87DH)&-E
M<G1?9&5T86EL<RDI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E(&-L87-S
M/2)F:7AE9"(^)R`N(%\H(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',B*2`N("<\+W!R93XG.PH@("`@("`@('T*("`@("`@("`D8V5R
M=&EF:6-A=&4@/2`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==.PH*("`@
M("`@("`D=&5X="`]("<\<')E(&-L87-S/2)F:7AE9"(^)SL*"B`@("`@("`@
M+RH@4W5B:F5C="`H82]K+V$@0V5R=&EF:6-A=&4@3W=N97(I("HO"B`@("`@
M("`@:68@*&ES<V5T*"1C97)T:69I8V%T95LG<W5B:F5C="==*2D@>PH@("`@
M("`@("`@("`D=&5X="`N/2`B/'-T<F]N9SXB("X@7R@B0V5R=&EF:6-A=&4@
M3W=N97(B*2`N("(Z/"]S=')O;F<^7&XB.PH*("`@("`@("`@("`@9F]R96%C
M:"`H)&-E<G1I9FEC871E6R=S=6)J96-T)UT@87,@)&ME>2`]/B`D=F%L=64I
M('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEE;&1N86UE<ULD:V5Y
M72DI('L*("`@("`@("`@("`@("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F
M;F)S<#LF;F)S<#LE<SH@)7-<;B(L("1F:65L9&YA;65S6R1K97E=+"`D=F%L
M=64I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LJ)7,Z("5S7&XB
M+"`D:V5Y+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T97AT("X](")<;B(["B`@("`@("`@?0H*("`@
M("`@("`O*B!)<W-U97(@*B\*("`@("`@("!I9B`H:7-S970H)&-E<G1I9FEC
M871E6R=I<W-U97(G72DI('L*("`@("`@("`@("`@)'1E>'0@+CT@(CQS=')O
M;F<^(B`N(%\H(DES<W5E<B(I("X@(CH\+W-T<F]N9SY<;B(["@H@("`@("`@
M("`@("!F;W)E86-H("@D8V5R=&EF:6-A=&5;)VES<W5E<B==(&%S("1K97D@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9I96QD
M;F%M97-;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@
M<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"`D9FEE;&1N86UE<ULD
M:V5Y72P@)'9A;'5E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[
M*B5S.B`E<UQN(BP@)&ME>2P@)'9A;'5E*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&5X="`N/2`B7&XB.PH@("`@
M("`@('T*"B`@("`@("`@+RH@1&%T97,@("HO"B`@("`@("`@)'1E>'0@+CT@
M(CQS=')O;F<^(B`N(%\H(E9A;&ED:71Y(BD@+B`B.CPO<W1R;VYG/EQN(CL*
M("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SH@)7-<
M;B(L(%\H(DYO="!"969O<F4B*2P@<W1R9G1I;64H(B5X("58(BP@)&-E<G1I
M9FEC871E6R=V86QI9&ET>2==6R=N;W1B969O<F4G72DI.PH@("`@("`@("1T
M97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@7R@B3F]T
M($%F=&5R(BDL('-T<F9T:6UE*"(E>"`E6"(L("1C97)T:69I8V%T95LG=F%L
M:61I='DG75LG;F]T869T97(G72DI.PH@("`@("`@("1T97AT("X](")<;B([
M"@H@("`@("`@("\J($-E<G1I9FEC871E($]W;F5R("T@4'5B;&EC($ME>2!)
M;F9O("HO"B`@("`@("`@)'1E>'0@+CT@(CQS=')O;F<^(B`N(%\H(E!U8FQI
M8R!+97D@26YF;R(I("X@(CH\+W-T<F]N9SY<;B(["B`@("`@("`@)'1E>'0@
M+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"!?*")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(I+"`D8V5R=&EF:6-A=&5;)W-U8FIE8W10=6)L:6-+
M97E);F9O)UU;)V%L9V]R:71H;2==*3L*("`@("`@("!I9B`H)&-E<G1I9FEC
M871E6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==6R=A;&=O<FET:&TG72`]/2`G
M<G-A16YC<GEP=&EO;B<I('L*("`@("`@("`@("`@:68@*%5T:6PZ.F5X=&5N
M<VEO;D5X:7-T<R@G8F-M871H)RDI('L*("`@("`@("`@("`@("`@("1M;V1U
M;'5S(#T@)&-E<G1I9FEC871E6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==6R=S
M=6)J96-T4'5B;&EC2V5Y)UU;)VUO9'5L=7,G73L*("`@("`@("`@("`@("`@
M("1M;V1U;'5S7VAE>"`]("<G.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1M
M;V1U;'5S("$]("<P)RD@>PH@("`@("`@("`@("`@("`@("`@("1M;V1U;'5S
M7VAE>"`](&1E8VAE>"AB8VUO9"@D;6]D=6QU<RP@)S$V)RDI("X@)&UO9'5L
M=7-?:&5X.PH@("`@("`@("`@("`@("`@("`@("1M;V1U;'5S(#T@8F-D:78H
M)&UO9'5L=7,L("<Q-B<L(#`I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@(&EF("@H<W1R;&5N*"1M;V1U;'5S7VAE>"D@/B`V-"D@)B8*
M("`@("`@("`@("`@("`@("`@("`H<W1R;&5N*"1M;V1U;'5S7VAE>"D@/"`Q
M,C@I*2!["B`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"@D;6]D=6QU<U]H
M97@L(#$R."P@)S`G+"!35%)?4$%$7U))1TA4*3L*("`@("`@("`@("`@("`@
M('T@96QS96EF("@H<W1R;&5N*"1M;V1U;'5S7VAE>"D@/B`Q,C@I("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@*'-T<FQE;B@D;6]D=6QU<U]H97@I
M(#P@,C4V*2D@>PH@("`@("`@("`@("`@("`@("`@('-T<E]P860H)&UO9'5L
M=7-?:&5X+"`R-38L("<P)RP@4U127U!!1%]224=(5"D["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@)'1E>'0@+CT@(B9N8G-P.R9N8G-P
M.R(@+B!S<')I;G1F*%\H(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(BDL('-T
M<FQE;B@D;6]D=6QU<U]H97@I("H@-"D@+B`B.EQN(CL*"B`@("`@("`@("`@
M("`@("`D;6]D=6QU<U]S='(@/2`G)SL*("`@("`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\('-T<FQE;B@D;6]D=6QU<U]H97@I.R`D:2`K/2`R*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"@D:2`E(#,R*2`]/2`P*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1M;V1U;'5S7W-T<B`N/2`B7&XF;F)S
M<#LF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LB.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;6]D=6QU<U]S='(@
M+CT@<W5B<W1R*"1M;V1U;'5S7VAE>"P@)&DL(#(I("X@)SHG.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1T97AT("X]('-P<FEN=&8H
M(B9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@7R@B36]D=6QU
M<R(I+"`D;6]D=6QU<U]S='(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LE
M<SH@)7-<;B(L(%\H(D5X<&]N96YT(BDL("1C97)T:69I8V%T95LG<W5B:F5C
M=%!U8FQI8TME>4EN9F\G75LG<W5B:F5C=%!U8FQI8TME>2==6R=P=6)L:6-%
M>'!O;F5N="==*3L*("`@("`@("!]"B`@("`@("`@)'1E>'0@+CT@(EQN(CL*
M"B`@("`@("`@+RH@6#4P.78S(&5X=&5N<VEO;G,@*B\*("`@("`@("!I9B`H
M:7-S970H)&-E<G1I9FEC871E6R=E>'1E;G-I;VYS)UTI*2!["B`@("`@("`@
M("`@("1T97AT("X]("(\<W1R;VYG/B(@+B!?*")8-3`Y=C,@97AT96YS:6]N
M<R(I("X@(CH\+W-T<F]N9SY<;B(["@H@("`@("`@("`@("!F;W)E86-H("@D
M8V5R=&EF:6-A=&5;)V5X=&5N<VEO;G,G72!A<R`D:V5Y(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@/2!?*")5;G-U<'!O<G1E9"!%>'1E
M;G-I;VXB*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9FEE;&1N86UE<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@
M("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SI<;B9N8G-P
M.R9N8G-P.R9N8G-P.R9N8G-P.R5S7&XB+"`D9FEE;&1N86UE<ULD:V5Y72P@
M=V]R9'=R87`H)'9A;'5E+"`T,"P@(EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB
M<W`[(BDI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SI<;B9N
M8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R5S7&XB+"`D:V5Y+"!W;W)D=W)A<"@D
M=F%L=64L(#8P+"`B7&XF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LB*2D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M97AT("X](")<;B(["B`@("`@("`@?0H*("`@("`@("`O*B!#97)T:69I8V%T
M92!$971A:6QS("HO"B`@("`@("`@)'1E>'0@+CT@(CQS=')O;F<^(B`N(%\H
M(D-E<G1I9FEC871E($1E=&%I;',B*2`N("(Z/"]S=')O;F<^7&XB.PH@("`@
M("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E9%QN(BP@
M7R@B5F5R<VEO;B(I+"`D8V5R=&EF:6-A=&5;)W9E<G-I;VXG72D["B`@("`@
M("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z("5D7&XB+"!?
M*")397)I86P@3G5M8F5R(BDL("1C97)T:69I8V%T95LG<V5R:6%L3G5M8F5R
M)UTI.PH*("`@("`@("!F;W)E86-H("@D8V5R=%]D971A:6QS6R=F:6YG97)P
M<FEN=',G72!A<R`D:&%S:"`]/B`D9FEN9V5R<')I;G0I('L*("`@("`@("`@
M("`@)&QA8F5L(#T@<W!R:6YT9BA?*"(E<R!&:6YG97)P<FEN="(I+"!3=')I
M;F<Z.G5P<&5R*"1H87-H*2D["B`@("`@("`@("`@("1F:6YG97)P<FEN=%]S
M='(@/2`G)SL*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N
M*"1F:6YG97)P<FEN="D[("1I("L](#(I('L*("`@("`@("`@("`@("`@("1F
M:6YG97)P<FEN=%]S='(@+CT@<W5B<W1R*"1F:6YG97)P<FEN="P@)&DL(#(I
M("X@)SHG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T97AT("X]('-P
M<FEN=&8H(B9N8G-P.R9N8G-P.R5S.EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB
M<W`[)FYB<W`[)FYB<W`[)7-<;B(L("1L86)E;"P@)&9I;F=E<G!R:6YT7W-T
M<BD["B`@("`@("`@?0H@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P
M.R9N8G-P.R5S.B`E<UQN(BP@7R@B4VEG;F%T=7)E($%L9V]R:71H;2(I+"`D
M8V5R=%]D971A:6QS6R=S:6=N871U<F5!;&=O<FET:&TG72D["B`@("`@("`@
M)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z(BP@7R@B4VEG;F%T
M=7)E(BDI.PH*("`@("`@("`D<VEG7W-T<B`]("<G.PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\('-T<FQE;B@D8V5R=%]D971A:6QS6R=S:6=N871U<F4G
M72D[("1I*RLI('L*("`@("`@("`@("`@:68@*"@D:2`E(#$V*2`]/2`P*2![
M"B`@("`@("`@("`@("`@("`D<VEG7W-T<B`N/2`B7&XF;F)S<#LF;F)S<#LF
M;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LB.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1S:6=?<W1R("X]('-P<FEN=&8H(B4P,G@Z(BP@;W)D*"1C97)T
M7V1E=&%I;'-;)W-I9VYA='5R92==6R1I72DI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T97AT("X@)'-I9U]S='(@+B`B7&X\+W!R93XB.PH@("`@
M?0H*("`@("\J*@H@("`@("H@17AT<F%C="!T:&4@8V]N=&5N=',@;V8@82!0
M14T@9F]R;6%T(&-E<G1I9FEC871E('1O(&%N(&%R<F%Y+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&-E<G0@(%!%32!F;W)M870@8V5R=&EF:6-A
M=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!C;VYT86EN
M:6YG(&%L;"!E>'1R86-T86)L92!I;F9O<FUA=&EO;B!A8F]U=`H@("`@("H@
M("`@("`@("`@("`@("`@=&AE(&-E<G1I9FEC871E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P87)S94-E<G0H)&-E<G0I"B`@("!["B`@("`@("`@)&-E<G1?
M<W!L:70@/2!P<F5G7W-P;&ET*"<O*"TM+2TM*"A"14=)3BE\*$5.1"DI($-%
M4E1)1DE#051%+2TM+2TI+R<L("1C97)T*3L*("`@("`@("!I9B`H(6ES<V5T
M*"1C97)T7W-P;&ET6S%=*2D@>PH@("`@("`@("`@("`D<F%W7V-E<G0@/2!B
M87-E-C1?9&5C;V1E*"1C97)T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<F%W7V-E<G0@/2!B87-E-C1?9&5C;V1E*"1C97)T7W-P;&ET6S%=
M*3L*("`@("`@("!]"@H@("`@("`@("1C97)T7V1A=&$@/2`D=&AI<RT^7W!A
M<G-E05-.*"1R87=?8V5R="D["B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V5R
M=%]D871A*2!\?"`H)&-E<G1?9&%T85LP72`]/2`G54Y+3D]73B<I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1C
M97)T7V1E=&%I;',@/2!A<G)A>2@I.PH@("`@("`@("1C97)T7V1E=&%I;'-;
M)V9I;F=E<G!R:6YT<R==6R=M9#4G72`](&UD-2@D<F%W7V-E<G0I.PH@("`@
M("`@(&EF("A5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VUH87-H)RDI('L*("`@
M("`@("`@("`@)&-E<G1?9&5T86EL<ULG9FEN9V5R<')I;G1S)UU;)W-H83$G
M72`](&)I;C)H97@H;6AA<V@H34A!4TA?4TA!,2P@)')A=U]C97)T*2D["B`@
M("`@("`@?0H*("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==
M6R=E>'1E;G-I;VYS)UT@/2!A<G)A>2@I.PH@("`@("`@("1C97)T7V1E=&%I
M;'-;)V-E<G1I9FEC871E)UU;)W9E<G-I;VXG72`]("1C97)T7V1A=&%;,5U;
M,%U;,5U;,%U;,5T@*R`Q.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I
M9FEC871E)UU;)W-E<FEA;$YU;6)E<B==(#T@)&-E<G1?9&%T85LQ75LP75LQ
M75LQ75LQ73L*("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==
M6R=S:6=N871U<F4G72`]("1C97)T7V1A=&%;,5U;,%U;,5U;,EU;,5U;,%U;
M,5T["B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG:7-S
M=65R)UT@/2`D8V5R=%]D871A6S%=6S!=6S%=6S-=6S%=.PH@("`@("`@("1C
M97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W9A;&ED:71Y)UT@/2`D8V5R
M=%]D871A6S%=6S!=6S%=6S1=6S%=.PH@("`@("`@("1C97)T7V1E=&%I;'-;
M)V-E<G1I9FEC871E)UU;)W-U8FIE8W0G72`]($`D8V5R=%]D871A6S%=6S!=
M6S%=6S5=6S%=.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E
M)UU;)W-U8FIE8W10=6)L:6-+97E);F9O)UT@/2`D8V5R=%]D871A6S%=6S!=
M6S%=6S9=6S%=.PH*("`@("`@("`D8V5R=%]D971A:6QS6R=S:6=N871U<F5!
M;&=O<FET:&TG72`]("1C97)T7V1A=&%;,5U;,5U;,5U;,%U;,5T["B`@("`@
M("`@)&-E<G1?9&5T86EL<ULG<VEG;F%T=7)E)UT@/2`D8V5R=%]D871A6S%=
M6S)=6S%=.PH*("`@("`@("`O+R!I<W-U97(*("`@("`@("`D:7-S=65R(#T@
M87)R87DH*3L*("`@("`@("!F;W)E86-H("@D8V5R=%]D971A:6QS6R=C97)T
M:69I8V%T92==6R=I<W-U97(G72!A<R`D=F%L=64I('L*("`@("`@("`@("`@
M)&ES<W5E<ELD=F%L=65;,5U;,5U;,%U;,5U=(#T@)'9A;'5E6S%=6S%=6S%=
M6S%=.PH@("`@("`@('T*("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I
M8V%T92==6R=I<W-U97(G72`]("1I<W-U97(["@H@("`@("`@("\O('-U8FIE
M8W0*("`@("`@("`D<W5B:F5C="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C
M:"`H)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG<W5B:F5C="==(&%S
M("1V86QU92D@>PH@("`@("`@("`@("`D<W5B:F5C=%LD=F%L=65;,5U;,5U;
M,%U;,5U=(#T@)'9A;'5E6S%=6S%=6S%=6S%=.PH@("`@("`@('T*("`@("`@
M("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=S=6)J96-T)UT@/2`D
M<W5B:F5C=#L*"B`@("`@("`@+R\@=F%L:61I='D*("`@("`@("`D=F%L<R`]
M("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W9A;&ED:71Y)UT["B`@
M("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F%L:61I='DG
M72`](&%R<F%Y*"D["B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A
M=&4G75LG=F%L:61I='DG75LG;F]T8F5F;W)E)UT@/2`D=F%L<ULP75LQ73L*
M("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI9&ET
M>2==6R=N;W1A9G1E<B==(#T@)'9A;'-;,5U;,5T["B`@("`@("`@9F]R96%C
M:"`H)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F%L:61I='DG72!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)'EE87(@/2!S=6)S='(H
M)'9A;"P@,"P@,BD["B`@("`@("`@("`@("1M;VYT:"`]('-U8G-T<B@D=F%L
M+"`R+"`R*3L*("`@("`@("`@("`@)&1A>2`]('-U8G-T<B@D=F%L+"`T+"`R
M*3L*("`@("`@("`@("`@)&AO=7(@/2!S=6)S='(H)'9A;"P@-BP@,BD["B`@
M("`@("`@("`@("1M:6YU=&4@/2!S=6)S='(H)'9A;"P@."P@,BD["B`@("`@
M("`@("`@(&EF("@H)'9A;%LQ,5T@/3T@)RTG*2!\?"`H)'9A;%LY72`]/2`G
M*R<I*2!["B`@("`@("`@("`@("`@("`O+R!H86YD;&4@=&EM92!Z;VYE(&]F
M9G-E="!H97)E"B`@("`@("`@("`@("`@("`D<V5C;VYD<R`](#`["B`@("`@
M("`@("`@('T@96QS96EF("A3=')I;F<Z.G5P<&5R*"1V86Q;,3%=*2`]/2`G
M6B<I('L*("`@("`@("`@("`@("`@("1S96-O;F1S(#T@,#L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S96-O;F1S(#T@<W5B<W1R
M*"1V86PL(#$P+"`R*3L*("`@("`@("`@("`@("`@(&EF("@H)'9A;%LQ,5T@
M/3T@)RTG*2!\?"`H)'9A;%LY72`]/2`G*R<I*2!["B`@("`@("`@("`@("`@
M("`@("`@+R\@:&%N9&QE('1I;64@>F]N92!O9F9S970@:&5R90H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1C97)T7V1E
M=&%I;'-;)V-E<G1I9FEC871E)UU;)W9A;&ED:71Y)UU;)&ME>5T@/2!M:W1I
M;64@*"1H;W5R+"`D;6EN=71E+"`D<V5C;VYD<RP@)&UO;G1H+"`D9&%Y+"`D
M>65A<BD["B`@("`@("`@?0H*("`@("`@("`O+R!3<&QI="!T:&4@4'5B;&EC
M($ME>2!I;G1O(&-O;7!O;F5N=',N"B`@("`@("`@)'-U8FIE8W10=6)L:6-+
M97E);F9O(#T@87)R87DH*3L*("`@("`@("`D<W5B:F5C=%!U8FQI8TME>4EN
M9F];)V%L9V]R:71H;2==(#T@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G
M75LG<W5B:F5C=%!U8FQI8TME>4EN9F\G75LP75LQ75LP75LQ73L*("`@("`@
M("!I9B`H)'-U8FIE8W10=6)L:6-+97E);F9O6R=A;&=O<FET:&TG72`]/2`G
M<G-A16YC<GEP=&EO;B<I('L*("`@("`@("`@("`@)'-U8FIE8W10=6)L:6-+
M97D@/2`D=&AI<RT^7W!A<G-E05-.*"1C97)T7V1E=&%I;'-;)V-E<G1I9FEC
M871E)UU;)W-U8FIE8W10=6)L:6-+97E);F9O)UU;,5U;,5TI.PH@("`@("`@
M("`@("`D<W5B:F5C=%!U8FQI8TME>4EN9F];)W-U8FIE8W10=6)L:6-+97DG
M75LG;6]D=6QU<R==(#T@)'-U8FIE8W10=6)L:6-+97E;,5U;,%U;,5T["B`@
M("`@("`@("`@("1S=6)J96-T4'5B;&EC2V5Y26YF;ULG<W5B:F5C=%!U8FQI
M8TME>2==6R=P=6)L:6-%>'!O;F5N="==(#T@)'-U8FIE8W10=6)L:6-+97E;
M,5U;,5U;,5T["B`@("`@("`@?0H@("`@("`@("1C97)T7V1E=&%I;'-;)V-E
M<G1I9FEC871E)UU;)W-U8FIE8W10=6)L:6-+97E);F9O)UT@/2`D<W5B:F5C
M=%!U8FQI8TME>4EN9F\["@H@("`@("`@(&EF("AI<W-E="@D8V5R=%]D871A
M6S%=6S!=6S%=6S==*2`F)@H@("`@("`@("`@("!I<U]A<G)A>2@D8V5R=%]D
M871A6S%=6S!=6S%=6S==6S%=*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M8V5R=%]D871A6S%=6S!=6S%=6S==6S%=(&%S("1E>'0I('L*("`@("`@("`@
M("`@("`@("1O:60@/2`D97AT6S%=6S!=6S%=.PH@("`@("`@("`@("`@("`@
M)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O
M:61=(#T@)&5X=%LQ75LQ73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&D@/2`Y.PH@("`@("`@('=H:6QE("AI<W-E="@D8V5R=%]D871A
M6S%=6S!=6S%=6R1I72DI('L*("`@("`@("`@("`@)&]I9"`]("1C97)T7V1A
M=&%;,5U;,%U;,5U;)&E=6S%=6S!=6S%=.PH@("`@("`@("`@("`D8V5R=%]D
M971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2`D
M8V5R=%]D871A6S%=6S!=6S%=6R1I75LQ75LQ73L*("`@("`@("`@("`@)&DK
M*SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1C97)T7V1E=&%I;'-;
M)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G72!A<R`D;VED(#T^("1V86PI
M('L*("`@("`@("`@("`@<W=I=&-H("@D;VED*2!["B`@("`@("`@("`@(&-A
M<V4@)VYE='-C87!E+6)A<V4M=7)L)SH*("`@("`@("`@("`@8V%S92`G;F5T
M<V-A<&4M<F5V;V-A=&EO;BUU<FPG.@H@("`@("`@("`@("!C87-E("=N971S
M8V%P92UC82UR979O8V%T:6]N+75R;"<Z"B`@("`@("`@("`@(&-A<V4@)VYE
M='-C87!E+6-E<G0M<F5N97=A;"UU<FPG.@H@("`@("`@("`@("!C87-E("=N
M971S8V%P92UC82UP;VQI8WDM=7)L)SH*("`@("`@("`@("`@8V%S92`G;F5T
M<V-A<&4M<W-L+7-E<G9E<BUN86UE)SH*("`@("`@("`@("`@8V%S92`G;F5T
M<V-A<&4M8V]M;65N="<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M
M/E]P87)S94%33B@D=F%L6S%=*3L*("`@("`@("`@("`@("`@("1C97)T7V1E
M=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`]("1V
M86Q;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)VED+6-E+7-U8FIE8W1!;'1.86UE)SH*("`@("`@("`@("`@("`@("1V
M86P@/2`D=&AI<RT^7W!A<G-E05-.*"1V86Q;,5TI.PH@("`@("`@("`@("`@
M("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==
M6R1O:61=(#T@)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L6S%=
M(&%S("1N86UE*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I
M9%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;
M)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`N/2`G+"`G.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8V5R
M=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@
M+CT@)&YA;65;,5T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VYE='-C87!E+6-E<G0M='EP
M92<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]P87)S94%33B@D
M=F%L6S%=*3L*("`@("`@("`@("`@("`@("1V86P@/2!O<F0H)'9A;%LQ72D[
M"B`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)R<["@H@("`@("`@("`@("`@
M("`@:68@*"1V86P@)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@("`@)&YE
M=U9A;"`N/2!E;7!T>2@D;F5W5F%L*2`_("=34TP@8VQI96YT)R`Z("<L(%-3
M3"!C;&EE;G0G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*"1V86P@)B`P>#0P*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A
M;"`N/2!E;7!T>2@D;F5W5F%L*2`_("=34TP@<V5R=F5R)R`Z("<L(%-33"!S
M97)V97(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*"1V86P@)B`P>#(P*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N
M/2!E;7!T>2@D;F5W5F%L*2`_("=3+TU)344G(#H@)RP@4R]-24U%)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D=F%L("8@,'@Q
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1N97=686P@+CT@96UP='DH)&YE
M=U9A;"D@/R`G3V)J96-T(%-I9VYI;F<G(#H@)RP@3V)J96-T(%-I9VYI;F<G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1V86P@
M)B`P>#`T*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T
M>2@D;F5W5F%L*2`_("=34TP@0T$G(#H@)RP@4U-,($-!)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D=F%L("8@,'@P,BD@>PH@
M("`@("`@("`@("`@("`@("`@("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@
M/R`G4R]-24U%($-!)R`Z("<L(%,O34E-12!#02<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!I9B`H)'9A;"`F(#!X,#$I('L*("`@("`@
M("`@("`@("`@("`@("`D;F5W5F%L("X](&5M<'1Y*"1N97=686PI(#\@)T]B
M:F5C="!3:6=N:6YG($-!)R`Z("<L($]B:F5C="!3:6=N:6YG($-!)SL*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D8V5R=%]D971A:6QS
M6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2`D;F5W5F%L
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=I
M9"UC92UE>'1+97E5<V%G92<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H
M:7,M/E]P87)S94%33B@D=F%L6S%=*3L*("`@("`@("`@("`@("`@("1V86P@
M/2`D=F%L6S%=.PH*("`@("`@("`@("`@("`@("1N97=686P@/2`G)SL*("`@
M("`@("`@("`@("`@(&EF("@D=F%L6S!=6S%=("$]("=S97%U96YC92<I('L*
M("`@("`@("`@("`@("`@("`@("`D=F%L(#T@87)R87DH)'9A;"D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V86P@
M/2`D=F%L6S%=6S%=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'9A;"!A<R`D=7-A9V4I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'5S86=E6S%=(#T]("=I9%]K<%]C;&EE;G1!=71H)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X](&5M<'1Y*"1N97=6
M86PI(#\@)U1,4R!796(@0VQI96YT($%U=&AE;G1I8V%T:6]N)R`Z("<L(%1,
M4R!796(@0VQI96YT($%U=&AE;G1I8V%T:6]N)SL*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L
M("X](&5M<'1Y*"1N97=686PI(#\@)'5S86=E6S%=(#H@)RP@)R`N("1U<V%G
M95LQ73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==
M6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2`D;F5W5F%L.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=I9"UC92US=6)J96-T2V5Y
M261E;G1I9FEE<B<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]P
M87)S94%33B@D=F%L6S%=*3L*("`@("`@("`@("`@("`@("1V86P@/2`D=F%L
M6S%=.PH*("`@("`@("`@("`@("`@("1N97=686P@/2`G)SL*"B`@("`@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)'9A;"D[("1I*RLI
M('L*("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X]('-P<FEN=&8H(B4P
M,G@Z(BP@;W)D*"1V86Q;)&E=*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E
M;G-I;VYS)UU;)&]I9%T@/2`D;F5W5F%L.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=I9"UC92UA=71H;W)I='E+97E)9&5N
M=&EF:65R)SH*("`@("`@("`@("`@("`@("1V86P@/2`D=&AI<RT^7W!A<G-E
M05-.*"1V86Q;,5TI.PH@("`@("`@("`@("`@("`@:68@*"1V86Q;,%T@/3T@
M)W-T<FEN9R<I('L*("`@("`@("`@("`@("`@("`@("`D=F%L(#T@)'9A;%LQ
M73L*"B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("<G.PH@("`@("`@
M("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE;B@D=F%L*3L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X]('-P
M<FEN=&8H(B4P,G@Z(BP@;W)D*"1V86Q;)&E=*2D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E
M<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`]("1N97=686P["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1C
M97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED
M72`](%\H(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=I9"UC92UB87-I8T-O;G-T<F%I;G1S)SH*("`@("`@("`@("`@8V%S92`G
M9&5F875L="<Z"B`@("`@("`@("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T
M:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2!?*")5;G-U<'!O<G1E
M9"!%>'1E;G-I;VXB*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-E<G1?9&5T86EL
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'0@=&\@<&%R<V4@05-.
M+C$@9F]R;6%T960@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("!!4TXN,2!F
M;W)M871E9"!D871A"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R
M87D@8V]N=&%I;F5D('1H92!E>'1R86-T960@=F%L=65S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<&%R<V5!4TXH)&1A=&$I"B`@("!["B`@("`@("`@)')E
M<W5L="`](&%R<F%Y*"D["@H@("`@("`@('=H:6QE("AS=')L96XH)&1A=&$I
M(#X@,2D@>PH@("`@("`@("`@("`D8VQA<W,@/2!O<F0H)&1A=&%;,%TI.PH@
M("`@("`@("`@("!S=VET8V@@*"1C;&%S<RD@>PH@("`@("`@("`@("!C87-E
M(#!X,S`Z"B`@("`@("`@("`@("`@("`O+R!397%U96YC90H@("`@("`@("`@
M("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D
M8GET97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2![
M"B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@
M("`@("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T
M85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D<V5Q=65N8V5?9&%T82`]('-U8G-T
M<B@D9&%T82P@,B`K("1B>71E<RP@)&QE;BD["B`@("`@("`@("`@("`@("`D
M9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<R`K("1L96XI.PH*("`@
M("`@("`@("`@("`@("1V86QU97,@/2`D=&AI<RT^7W!A<G-E05-.*"1S97%U
M96YC95]D871A*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'9A
M;'5E<RD@?'P@:7-?<W1R:6YG*"1V86QU97-;,%TI*2!["B`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1V86QU97,I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)'-E<75E;F-E7W9A;'5E<R`](&%R
M<F%Y*"D["B`@("`@("`@("`@("`@("`D:2`](#`["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=F%L=65S(&%S("1V86PI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'9A;%LP72`]/2`G97AT96YS:6]N)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<V5Q=65N8V5?=F%L=65S6R=E>'1E;G-I;VYS)UU;
M72`]("1V86P["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-E<75E;F-E7W9A;'5E<ULD:2LK72`]("1V
M86P["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)W-E<75E;F-E)RP@
M)'-E<75E;F-E7W9A;'5E<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@,'@S,3H*("`@("`@("`@("`@("`@("\O(%-E="!O
M9@H@("`@("`@("`@("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@
M("`@("`@("`@("`D8GET97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L
M96X@)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE
M;B`F(#!X,&8["B`@("`@("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@
M("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X
M*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<V5Q=65N8V5?
M9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<RP@)&QE;BD["B`@("`@
M("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<R`K
M("1L96XI.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)W-E
M="<L("1T:&ES+3Y?<&%R<V5!4TXH)'-E<75E;F-E7V1A=&$I*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#`Q.@H@("`@
M("`@("`@("`@("`@+R\@0F]O;&5A;B!T>7!E"B`@("`@("`@("`@("`@("`D
M8F]O;&5A;E]V86QU92`]("AO<F0H)&1A=&%;,ETI(#T](#!X9F8I.PH@("`@
M("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#,I.PH@("`@("`@
M("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)V)O;VQE86XG+"`D8F]O;&5A
M;E]V86QU92D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@,'@P,CH*("`@("`@("`@("`@("`@("\O($EN=&5G97(@='EP90H@
M("`@("`@("`@("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@
M("`@("`@("`D8GET97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L96X@
M)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F
M(#!X,&8["B`@("`@("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\
M(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&EN=&5G97)?9&%T
M82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<RP@)&QE;BD["B`@("`@("`@
M("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<R`K("1L
M96XI.PH*("`@("`@("`@("`@("`@("1V86QU92`](#`["B`@("`@("`@("`@
M("`@("!I9B`H)&QE;B`\/2`T*2!["B`@("`@("`@("`@("`@("`@("`@+RH@
M365T:&]D('=O<FMS(&9I;F4@9F]R('-M86QL(&EN=&5G97)S("HO"B`@("`@
M("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1I;G1E
M9V5R7V1A=&$I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V
M86QU92`]("@D=F%L=64@/#P@."D@?"!O<F0H)&EN=&5G97)?9&%T85LD:5TI
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@+RH@365T:&]D('=O<FMS(&9O<B!A
M<F)I=')A<GD@;&5N9W1H(&EN=&5G97)S("HO"B`@("`@("`@("`@("`@("`@
M("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G8F-M871H)RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N
M*"1I;G1E9V5R7V1A=&$I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2!B8V%D9"AB8VUU;"@D=F%L=64L(#(U-BDL(&]R
M9"@D:6YT96=E<E]D871A6R1I72DI.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@+3$["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W5L=%M=
M(#T@87)R87DH)VEN=&5G97(H)R`N("1L96X@+B`G*2<L("1V86QU92D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@P,SH*
M("`@("`@("`@("`@("`@("\O($)I='-T<FEN9R!T>7!E"B`@("`@("`@("`@
M("`@("`D;&5N(#T@;W)D*"1D871A6S%=*3L*("`@("`@("`@("`@("`@("1B
M>71E<R`](#`["B`@("`@("`@("`@("`@("!I9B`H)&QE;B`F(#!X.#`I('L*
M("`@("`@("`@("`@("`@("`@("`D8GET97,@/2`D;&5N("8@,'@P9CL*("`@
M("`@("`@("`@("`@("`@("`D;&5N(#T@,#L*("`@("`@("`@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D8GET97,[("1I*RLI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&QE;B`]("@D;&5N(#P\(#@I('P@;W)D*"1D871A
M6R1I("L@,ETI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1B:71S=')I;F=?9&%T82`]('-U8G-T
M<B@D9&%T82P@,R`K("1B>71E<RP@)&QE;BD["B`@("`@("`@("`@("`@("`D
M9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<R`K("1L96XI.PH@("`@
M("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)V)I="!S=')I;F<G+"`D
M8FET<W1R:6YG7V1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E(#!X,#0Z"B`@("`@("`@("`@("`@("`O+R!/8W1E='-T
M<FEN9R!T>7!E"B`@("`@("`@("`@("`@("`D;&5N(#T@;W)D*"1D871A6S%=
M*3L*("`@("`@("`@("`@("`@("1B>71E<R`](#`["B`@("`@("`@("`@("`@
M("!I9B`H)&QE;B`F(#!X.#`I('L*("`@("`@("`@("`@("`@("`@("`D8GET
M97,@/2`D;&5N("8@,'@P9CL*("`@("`@("`@("`@("`@("`@("`D;&5N(#T@
M,#L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8GET
M97,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QE;B`]("@D
M;&5N(#P\(#@I('P@;W)D*"1D871A6R1I("L@,ETI.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1O
M8W1E8W1S=')I;F=?9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<RP@
M)&QE;BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@
M,B`K("1B>71E<R`K("1L96XI.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=
M(#T@87)R87DH)V]C=&5T('-T<FEN9R<L("1O8W1E8W1S=')I;F=?9&%T82D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@P
M-3H*("`@("`@("`@("`@("`@("\O($YU;&P@='EP90H@("`@("`@("`@("`@
M("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(I.PH@("`@("`@("`@("`@("`@
M)')E<W5L=%M=(#T@87)R87DH)VYU;&PG+"!N=6QL*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#`V.@H@("`@("`@("`@
M("`@("`@+R\@3V)J96-T(&ED96YT:69I97(@='EP90H@("`@("`@("`@("`@
M("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D8GET
M97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@
M("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@
M("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD
M:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D;VED7V1A=&$@/2!S=6)S='(H)&1A=&$L
M(#(@*R`D8GET97,L("1L96XI.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S
M=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D;&5N*3L*"B`@("`@("`@("`@
M("`@("`O+R!5;G!A8VL@=&AE($])1`H@("`@("`@("`@("`@("`@)'!L86EN
M("`](&9L;V]R*&]R9"@D;VED7V1A=&%;,%TI("\@-#`I.PH@("`@("`@("`@
M("`@("`@)'!L86EN("X]("<N)R`N(&]R9"@D;VED7V1A=&%;,%TI("4@-#`[
M"@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@,#L*("`@("`@("`@("`@("`@
M("1I(#T@,3L*("`@("`@("`@("`@("`@('=H:6QE("@D:2`\('-T<FQE;B@D
M;VED7V1A=&$I*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'9A
M;'5E(#P\(#<["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'9A;'5E
M('P@*&]R9"@D;VED7V1A=&%;)&E=*2`F(#!X-V8I.PH*("`@("`@("`@("`@
M("`@("`@("!I9B`H(2AO<F0H)&]I9%]D871A6R1I72D@)B`P>#@P*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<&QA:6X@+CT@)RXG("X@)'9A;'5E
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`P.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7V]I9'-;)'!L86EN72DI('L*("`@("`@("`@("`@("`@("`@("`D<F5S
M=6QT6UT@/2!A<G)A>2@G;VED)RP@)'1H:7,M/E]O:61S6R1P;&%I;ETI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M<F5S=6QT6UT@/2!A<G)A>2@G;VED)RP@)'!L86EN*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@,'@Q,CH*("`@("`@("`@("`@8V%S92`P>#$S.@H@("`@("`@("`@("!C
M87-E(#!X,30Z"B`@("`@("`@("`@(&-A<V4@,'@Q-3H*("`@("`@("`@("`@
M8V%S92`P>#$V.@H@("`@("`@("`@("!C87-E(#!X.#$Z"B`@("`@("`@("`@
M(&-A<V4@,'@X,#H*("`@("`@("`@("`@("`@("\O($-H87)A8W1E<B!S=')I
M;F<@='EP90H@("`@("`@("`@("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D[
M"B`@("`@("`@("`@("`@("`D8GET97,@/2`P.PH@("`@("`@("`@("`@("`@
M:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S
M(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@("`@("`@("`@)&QE;B`](#`[
M"B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L96X@/2`H)&QE
M;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<W1R
M:6YG7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI.PH@
M("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET
M97,@*R`D;&5N*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y
M*"=S=')I;F<G+"`D<W1R:6YG7V1A=&$I.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E(#!X,3<Z"B`@("`@("`@("`@("`@("`O
M+R!4:6UE('1Y<&5S"B`@("`@("`@("`@("`@("`D;&5N(#T@;W)D*"1D871A
M6S%=*3L*("`@("`@("`@("`@("`@("1B>71E<R`](#`["B`@("`@("`@("`@
M("`@("!I9B`H)&QE;B`F(#!X.#`I('L*("`@("`@("`@("`@("`@("`@("`D
M8GET97,@/2`D;&5N("8@,'@P9CL*("`@("`@("`@("`@("`@("`@("`D;&5N
M(#T@,#L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8GET97,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QE;B`]
M("@D;&5N(#P\(#@I('P@;W)D*"1D871A6R1I("L@,ETI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1T:6UE7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI
M.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D
M8GET97,@*R`D;&5N*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R
M<F%Y*"=U=&-T:6UE)RP@)'1I;65?9&%T82D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@X,CH*("`@("`@("`@("`@("`@
M("\O(%@U,#EV,R!E>'1E;G-I;VYS/PH@("`@("`@("`@("`@("`@)&QE;B`]
M(&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D8GET97,@/2`P.PH@
M("`@("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@("`@
M("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@("`@
M("`@("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<V5Q=65N8V5?9&%T82`]('-U8G-T<B@D9&%T82P@,B`K
M("1B>71E<RP@)&QE;BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U8G-T
M<B@D9&%T82P@,B`K("1B>71E<R`K("1L96XI.PH@("`@("`@("`@("`@("`@
M)')E<W5L=%M=(#T@87)R87DH)V5X=&5N<VEO;B<L("=8-3`Y=C,@97AT96YS
M:6]N<R<I.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@)'1H:7,M/E]P
M87)S94%33B@D<V5Q=65N8V5?9&%T82D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@,'AA,#H*("`@("`@("`@("`@8V%S92`P
M>&$S.@H@("`@("`@("`@("`@("`@+R\@17AT96YS:6]N<PH@("`@("`@("`@
M("`@("`@)&5X=&5N<VEO;E]D871A(#T@<W5B<W1R*"1D871A+"`P+"`R*3L*
M("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R*3L*("`@
M("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=E>'1E;G-I;VXG+"!D
M96-H97@H)&5X=&5N<VEO;E]D871A*2D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@,'AE-CH*("`@("`@("`@("`@("`@("1E
M>'1E;G-I;VY?9&%T82`]('-U8G-T<B@D9&%T82P@,"P@,2D["B`@("`@("`@
M("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@,2D["B`@("`@("`@("`@
M("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G97AT96YS:6]N)RP@9&5C:&5X*"1E
M>'1E;G-I;VY?9&%T82DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E(#!X83$Z"B`@("`@("`@("`@("`@("`D97AT96YS:6]N
M7V1A=&$@/2!S=6)S='(H)&1A=&$L(#`L(#$I.PH@("`@("`@("`@("`@("`@
M)&1A=&$@/2!S=6)S='(H)&1A=&$L(#8I.PH@("`@("`@("`@("`@("`@)')E
M<W5L=%M=(#T@87)R87DH)V5X=&5N<VEO;B<L(&1E8VAE>"@D97AT96YS:6]N
M7V1A=&$I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("\O(%5N:VYO=VX*("`@("`@("`@
M("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=53DM.3U=.)RP@9&5C:&5X*"1D
M871A*2D["B`@("`@("`@("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`H8V]U;G0H)')E<W5L="D@/B`Q*2`_("1R97-U;'0@.B!A<G)A
M>5]P;W`H)')E<W5L="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T
M(&%N(%,_34E-12!S:6=N960@;65S<V%G92!U<VEN9R!A('!U8FQI8R!K97DN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E('9E<FEF:65D
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S
M(&YE961E9"!F;W(@=F5R:69I8V%T:6]N+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@=F5R:69I8V%T:6]N(&UE<W-A9V4N"B`@("`@*B`@
M("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]B:F5C="!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8W)Y<'13:6=N871U<F4H
M)'1E>'0L("1P87)A;7,I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U]D96-R>7!T4VEG;F%T=7)E*"D@)R`N(%\H(FYO="!Y970@
M:6UP;&5M96YT960B*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!F
M;W(@=&AE('!R97-E;F-E(&]F('1H92!/<&5N4U-,(&5X=&5N<VEO;B!T;R!0
M2%`N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R
M=64@:68@=&AE(&]P96YS<VP@97AT96YS:6]N(&ES(&%V86EL86)L92X*("`@
M("`J("`@("`@("`@("`@("`@("`@4F5T=7)N<R!A(%!%05)?17)R;W(@:68@
M;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&5C:T9O<D]P96Y34TPH*0H@
M("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=O<&5N
M<W-L)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB*2D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@17AT<F%C="!T:&4@96UA:6P@861D<F5S<R!F<F]M
M(&$@<'5B;&EC(&ME>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K
M97D@(%1H92!P=6)L:6,@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!2971U<FYS('1H92!E;6%I;"!A9&1R97-S+"!O<B!N=6QL(&EF(&YO
M;F4@:7,@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5M86EL1G)O
M;4ME>2@D:V5Y*0H@("`@>PH@("`@("`@("1K97E?:6YF;R`](&]P96YS<VQ?
M>#4P.5]P87)S92@D:V5Y*3L*("`@("`@("!I9B`H:7-?87)R87DH)&ME>5]I
M;F9O*2`F)B!I<W-E="@D:V5Y7VEN9F];)W-U8FIE8W0G72DI('L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1K97E?:6YF;ULG<W5B:F5C="==6R=%;6%I;"==
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1K97E?:6YF;ULG<W5B:F5C
M="==6R=%;6%I;"==.PH@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&ME
M>5]I;F9O6R=S=6)J96-T)UU;)V5M86EL061D<F5S<R==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1K97E?:6YF;ULG<W5B:F5C="==6R=E;6%I;$%D
M9')E<W,G73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T(&$@4$M#
M4R`Q,B!E;F-R>7!T960@8V5R=&EF:6-A=&4@<&%C:V%G92!I;G1O(&$@<')I
M=F%T92!K97DL"B`@("`@*B!P=6)L:6,@:V5Y+"!A;F0@86YY(&%D9&ET:6]N
M86P@:V5Y<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@
M5&AE(%!+0U,@,3(@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R('!A<G-I;F<N"B`@("`@*B`\
M<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@("`J(#T]/3T]/3T]/3T]"B`@
M("`@*B`G<W-L<&%T:"<@/3X@5&AE('!A=&@@=&\@=&AE($]P96Y34TP@8FEN
M87)Y+B`H4D5154E2140I"B`@("`@*B`G<&%S<W=O<F0G(#T^(%1H92!P87-S
M=V]R9"!T;R!U<V4@=&\@9&5C<GEP="!T:&4@9&%T82X@*$]P=&EO;F%L*0H@
M("`@("H@)VYE=W!A<W-W;W)D)R`]/B!4:&4@<&%S<W=O<F0@=&\@=7-E('1O
M(&5N8W)Y<'0@=&AE('!R:79A=&4@:V5Y+@H@("`@("H@("`@("`@("`@("`@
M("`@("`H3W!T:6]N86PI"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T9$-L87-S("!!;B!O8FIE8W0N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`G<')I=F%T92<@+2`@5&AE('!R:79A=&4@:V5Y(&EN(%!%32!F
M;W)M870N"B`@("`@*B`@("`@("`@("`@("`@("`@("`G<'5B;&EC)R`@+2`@
M5&AE('!U8FQI8R!K97D@:6X@4$5-(&9O<FUA="X*("`@("`J("`@("`@("`@
M("`@("`@("`@("=C97)T<R<@("`M("!!;B!A<G)A>2!O9B!A9&1I=&EO;F%L
M(&-E<G1S+@H@("`@("H@("`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%2
M7T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S95!+
M0U,Q,D1A=&$H)'!K8W,Q,BP@)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!#
M:&5C:R!F;W(@879A:6QA8FEL:71Y(&]F($]P96Y34TP@4$A0(&5X=&5N<VEO
M;BX@*B\*("`@("`@("`D;W!E;G-S;"`]("1T:&ES+3YC:&5C:T9O<D]P96Y3
M4TPH*3L*("`@("`@("!I9B`H:7-?82@D;W!E;G-S;"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&]P96YS<VP["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)W-S;'!A=&@G72DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@<&%T:"!T
M;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I
M;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H@("`@("`@("1S<VQP871H
M(#T@97-C87!E<VAE;&QC;60H)'!A<F%M<ULG<W-L<&%T:"==*3L*"B`@("`@
M("`@+RH@0W)E871E('1E;7`@9FEL97,@9F]R(&EN<'5T+V]U='!U="X@*B\*
M("`@("`@("`D:6YP=70@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D
M92US;6EM92<I.PH@("`@("`@("1O=71P=70@/2`D=&AI<RT^7V-R96%T951E
M;7!&:6QE*"=H;W)D92US;6EM92<I.PH*("`@("`@("`D;V(@/2`F;F5W('-T
M9$-L87-S.PH*("`@("`@("`O*B!7<FET92!T97AT('1O(&9I;&4@*B\*("`@
M("`@("`D9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9W<FET
M92@D9G`L("1P:V-S,3(I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@
M("`O*B!%>'1R86-T('1H92!P<FEV871E(&ME>2!F<F]M('1H92!F:6QE(&9I
M<G-T+B`J+PH@("`@("`@("1C;61L:6YE(#T@)'-S;'!A=&@@+B`G('!K8W,Q
M,B`M:6X@)R`N("1I;G!U="`N("<@+6]U="`G("X@)&]U='!U="`N("<@+6YO
M8V5R=',G.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=P87-S=V]R9"==
M*2D@>PH@("`@("`@("`@("`D8VUD;&EN92`N/2`G("UP87-S:6X@<W1D:6XG
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)VYE=W!A<W-W;W)D
M)UTI*2!["B`@("`@("`@("`@("`@("`D8VUD;&EN92`N/2`G("UP87-S;W5T
M('-T9&EN)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1C;61L:6YE("X]("<@+6YO9&5S)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D9F0@/2!P;W!E;B@D8VUD;&EN92P@)W<G*3L*("`@("`@("`@("`@
M9G=R:71E*"1F9"P@)'!A<F%M<ULG<&%S<W=O<F0G72`N(")<;B(I.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)VYE=W!A<W-W;W)D)UTI*2![
M"B`@("`@("`@("`@("`@("!F=W)I=&4H)&9D+"`D<&%R86US6R=N97=P87-S
M=V]R9"==("X@(EQN(BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<&-L
M;W-E*"1F9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-M9&QI
M;F4@+CT@)R`M;F]D97,G.PH@("`@("`@("`@("!E>&5C*"1C;61L:6YE*3L*
M("`@("`@("!]"B`@("`@("`@)&]B+3YP<FEV871E(#T@=')I;2AF:6QE7V=E
M=%]C;VYT96YT<R@D;W5T<'5T*2D["B`@("`@("`@:68@*&5M<'1Y*"1O8BT^
M<')I=F%T92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B4&%S<W=O<F0@:6YC;W)R96-T(BDL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@17AT<F%C="!T:&4@<'5B;&EC(&ME>2!N
M97AT+B`J+PH@("`@("`@("1C;61L:6YE(#T@)'-S;'!A=&@@+B`G('!K8W,Q
M,B`M:6X@)R`N("1I;G!U="`N("<@+6]U="`G("X@)&]U='!U="`N("<@+6YO
M:V5Y<R`M8VQC97)T<R<["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W!A
M<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1C;61L:6YE("X]("<@+7!A<W-I
M;B!S=&1I;B<["B`@("`@("`@("`@("1F9"`]('!O<&5N*"1C;61L:6YE+"`G
M=R<I.PH@("`@("`@("`@("!F=W)I=&4H)&9D+"`D<&%R86US6R=P87-S=V]R
M9"==("X@(EQN(BD["B`@("`@("`@("`@('!C;&]S92@D9F0I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&5X96,H)&-M9&QI;F4I.PH@("`@("`@
M('T*("`@("`@("`D;V(M/G!U8FQI8R`]('1R:6TH9FEL95]G971?8V]N=&5N
M=',H)&]U='!U="DI.PH*("`@("`@("`O*B!%>'1R86-T('1H92!P=6)L:6,@
M:V5Y(&YE>'0N("HO"B`@("`@("`@)&-M9&QI;F4@/2`D<W-L<&%T:"`N("<@
M<&MC<S$R("UI;B`G("X@)&EN<'5T("X@)R`M;W5T("<@+B`D;W5T<'5T("X@
M)R`M;F]K97ES("UC86-E<G1S)SL*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@)&-M9&QI;F4@+CT@)R`M
M<&%S<VEN('-T9&EN)SL*("`@("`@("`@("`@)&9D(#T@<&]P96XH)&-M9&QI
M;F4L("=W)RD["B`@("`@("`@("`@(&9W<FET92@D9F0L("1P87)A;7-;)W!A
M<W-W;W)D)UT@+B`B7&XB*3L*("`@("`@("`@("`@<&-L;W-E*"1F9"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@97AE8R@D8VUD;&EN92D["B`@
M("`@("`@?0H@("`@("`@("1O8BT^8V5R=',@/2!T<FEM*&9I;&5?9V5T7V-O
M;G1E;G1S*"1O=71P=70I*3L*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H92!#;VYT96YT+51Y<&4@<&%R86UE=&5R<R!0
M2%`G<R!O<&5N<W-L7W!K8W,W7RH@9G5N8W1I;VYS(')E='5R;B!A<F4*("`@
M("`J(&1E<')E8V%T960N("!&:7@@=&AE<V4@:&5A9&5R<R!T;R!T:&4@8V]R
M<F5C="!O;F5S("AS964@4D9#(#(S,3$I+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@
M(%1H92!02T-3-R!D871A+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M27,@=&AI<R`G;65S<V%G92<@;W(@)W-I9VYA='5R92<@9&%T83\*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%!+0U,W(&1A=&$@=VET:"!T
M:&4@8V]R<F5C="!#;VYT96YT+51Y<&4@<&%R86UE=&5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9FEX0V]N=&5N=%1Y<&4H)'1E>'0L("1T>7!E*0H@("`@
M>PH@("`@("`@(&EF("@D='EP92`]/2`G;65S<V%G92<I('L*("`@("`@("`@
M("`@)&9R;VT@/2`G87!P;&EC871I;VXO>"UP:V-S-RUM:6UE)SL*("`@("`@
M("`@("`@)'1O(#T@)V%P<&QI8V%T:6]N+W!K8W,W+6UI;64G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1F<F]M(#T@)V%P<&QI8V%T:6]N+W@M
M<&MC<S<M<VEG;F%T=7)E)SL*("`@("`@("`@("`@)'1O(#T@)V%P<&QI8V%T
M:6]N+W!K8W,W+7-I9VYA='5R92<["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!S=')?<F5P;&%C92@G0V]N=&5N="U4>7!E.B`G("X@)&9R;VTL("=#;VYT
M96YT+51Y<&4Z("<@+B`D=&\L("1T97AT*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B\`````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,0`P
M,C`V-C$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+P``````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S<Q`#`R,C0T-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O875D:6\N<&AP````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,T,S0`,3`T,3<S-C(W-S$`,#(T,C8Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@)TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<BYP:'`G
M.PH*+RHJ"B`J(%1H92!.;W1I9FEC871I;VY?3&ES=&5N97)?875D:6\Z.B!C
M;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y(&9O<@H@*B!I;G-E<G1I;F<@
M96UB961D960@875D:6\@;F]T:69I8V%T:6]N<R!F<F]M('1H92!S=&%C:R!I
M;G1O('1H92!P86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+V%U9&EO+G!H<"QV(#$N,RXR
M+C(@,C`P-B\P,2\P,2`R,3HR.#HS,"!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#4M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO
M<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-
M+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?3F]T:69I8V%T:6]N"B`J+PIC
M;&%S<R!.;W1I9FEC871I;VY?3&ES=&5N97)?875D:6\@97AT96YD<R!.;W1I
M9FEC871I;VY?3&ES=&5N97(@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(*("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T:6]N7TQI<W1E;F5R
M7V%U9&EO*"D*("`@('L*("`@("`@("`D=&AI<RT^7VAA;F1L97,@/2!A<G)A
M>2@G875D:6\G(#T^("<G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!A('5N:7%U92!I9&5N=&EF:65R(&9O<B!T:&ES(&QI<W1E;F5R+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!5;FEQ=64@:60N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`G
M875D:6\G.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!T:&4@96UB
M961D960@875D:6\@8V]D92!I9B!T:&5R92!A<F4@86YY(&UE<W-A9V5S(&]N
M('1H90H@("`@("H@)V%U9&EO)R!M97-S86=E('-T86-K+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`F)&UE<W-A9V53=&%C:R`@("`@5&AE('-T86-K
M(&]F(&UE<W-A9V5S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS("!!
M;B!A<G)A>2!O9B!O<'1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!N;W1I
M9GDH)B1M97-S86=E4W1A8VLL("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I9B`H8V]U;G0H)&UE<W-A9V53=&%C:RDI('L*("`@("`@("`@
M("`@=VAI;&4@*"1M97-S86=E(#T@87)R87E?<VAI9G0H)&UE<W-A9V53=&%C
M:RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YG971-97-S86=E*"1M97-S
M86=E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($]U='!U=',@;VYE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1M97-S86=E("!/;F4@;65S<V%G92!H87-H(&9R;VT@=&AE
M('-T86-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-97-S86=E*"1M97-S
M86=E*0H@("`@>PH@("`@("`@("1E=F5N="`]("1T:&ES+3YG971%=F5N="@D
M;65S<V%G92D["B`@("`@("`@96-H;R`G/&5M8F5D('-R8STB)RP@:'1M;'-P
M96-I86QC:&%R<R@D979E;G0M/F=E=$UE<W-A9V4H*2DL"B`@("`@("`@("`@
M("`G(B!W:61T:#TB,"(@:&5I9VAT/2(P(B!A=71O<W1A<G0](G1R=64B("\^
M)SL*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VIA=F%S8W)I<'0N<&AP````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`T,#$T`#$P-#$W,S8R-S<Q`#`R-3,R,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E("=(;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(N<&AP)SL*"B\J
M*@H@*B!4:&4@3F]T:69I8V%T:6]N7TQI<W1E;F5R7VIA=F%S8W)I<'0Z.B!C
M;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y(&9O<@H@*B!I;G-E<G1I;F<@
M:F%V87-C<FEP="!C;V1E(&9R;VT@=&AE(&UE<W-A9V4@<W1A8VL@:6YT;R!T
M:&4@<&%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]J879A<V-R:7!T+G!H<"QV(#$N-RXQ
M,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,S`@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;E],
M:7-T96YE<E]J879A<V-R:7!T(&5X=&5N9',@3F]T:69I8V%T:6]N7TQI<W1E
M;F5R('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@
M(&9U;F-T:6]N($YO=&EF:6-A=&EO;E],:7-T96YE<E]J879A<V-R:7!T*"D*
M("`@('L*("`@("`@("`D=&AI<RT^7VAA;F1L97,@/2!A<G)A>2@G:F%V87-C
M<FEP="<@/3X@)R<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@
M=6YI<75E(&ED96YT:69I97(@9F]R('1H:7,@;&ES=&5N97(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%5N:7%U92!I9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("=J879A
M<V-R:7!T)SL*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U=',@=&AE(&IA
M=F%S8W)I<'0@8V]D92!I9B!T:&5R92!A<F4@86YY(&UE<W-A9V5S(&]N('1H
M90H@("`@("H@)VIA=F%S8W)I<'0G(&UE<W-A9V4@<W1A8VL@86YD(&EF('1H
M92`G;F]T:69Y7VIA=F%S8W)I<'0G(&]P=&EO;B!I<R!S970N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("8D;65S<V%G95-T86-K("`@("!4:&4@<W1A
M8VL@;V8@;65S<V%G97,N"B`@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@
M($%N(&%R<F%Y(&]F(&]P=&EO;G,N($]P=&EO;G,Z("=N;W-C<FEP="<*("`@
M("`J+PH@("`@9G5N8W1I;VX@;F]T:69Y*"8D;65S<V%G95-T86-K+"`D;W!T
M:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1M97-S
M86=E4W1A8VLI*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG
M;F]S8W)I<'0G72DI('L*("`@("`@("`@("`@("`@(&5C:&\@)SQS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(CXG.PH@("`@("`@("`@("`@("`@96-H
M;R`B7&X\(2TM7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('=H:6QE
M("@D;65S<V%G92`](&%R<F%Y7W-H:69T*"1M97-S86=E4W1A8VLI*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^9V5T365S<V%G92@D;65S<V%G92D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=N
M;W-C<FEP="==*2D@>PH@("`@("`@("`@("`@("`@96-H;R`B+R\M+3Y<;CPO
M<V-R:7!T/EQN(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($]U='!U=',@;VYE(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1M97-S86=E("!/;F4@;65S<V%G92!H87-H(&9R
M;VT@=&AE('-T86-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-97-S86=E
M*"1M97-S86=E*0H@("`@>PH@("`@("`@("1E=F5N="`]("1T:&ES+3YG971%
M=F5N="@D;65S<V%G92D["B`@("`@("`@96-H;R`D979E;G0M/F=E=$UE<W-A
M9V4H*2`N(")<;B(["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'```````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-#0U`#$P-#$W,S8R-S<Q`#`R-#0S
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<"<["@HO*BH*("H@5&AE($YO=&EF:6-A=&EO;E],:7-T
M96YE<E]M;V)I;&4Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y(&9O
M<@H@*B!D:7-P;&%Y:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&UE<W-A9V4@<W1A
M8VL@;VX@;6]B:6QE(&1E=FEC97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<"QV(#$N."XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,S`@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TYO=&EF:6-A=&EO;@H@*B\*8VQA
M<W,@3F]T:69I8V%T:6]N7TQI<W1E;F5R7VUO8FEL92!E>'1E;F1S($YO=&EF
M:6-A=&EO;E],:7-T96YE<E]S=&%T=7,@>PH*("`@("\J*@H@("`@("H@5&AE
M($AO<F1E7TUO8FEL93HZ(&]B:F5C="!T:&%T('-T871U<R!L:6YE<R!S:&]U
M;&0@8F4@861D960@=&\N"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]-;V)I
M;&4*("`@("`J+PH@("`@=F%R("1?;6]B:6QE(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($YO=&EF
M:6-A=&EO;E],:7-T96YE<E]M;V)I;&4H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?:&%N9&QE<R`](&%R<F%Y*"=H;W)D92YE<G)O<B<@("`]/B!?*")%4E(B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N<W5C
M8V5S<R<@/3X@7R@B4U5#0T534R(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H;W)D92YW87)N:6YG)R`]/B!?*")705).(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+FUE<W-A9V4G(#T^
M(%\H(DU31R(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($%S<V]C:6%T92!A
M($AO<F1E7TUO8FEL93HZ(&]B:F5C="!W:71H('1H92!L:7-T96YE<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@2&]R9&5?36]B:6QE("!4:&4@2&]R9&5?36]B
M:6QE.CH@;V)J96-T('1O('-E;F0@<W1A='5S(&QI;F5S('1O+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971-;V)I;&5/8FIE8W0H)B1M;V)I;&4I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2`F)&UO8FEL93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!A('5N:7%U92!I9&5N=&EF:65R(&9O<B!T
M:&ES(&QI<W1E;F5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!5
M;FEQ=64@:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H*0H@("`@
M>PH@("`@("`@(')E='5R;B`G;6]B:6QE)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($]U='!U=',@=&AE('-T871U<R!L:6YE(&EF('1H97)E(&%R92!A;GD@
M;65S<V%G97,@;VX@=&AE("=M;V)I;&4G"B`@("`@*B!M97-S86=E('-T86-K
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&UE<W-A9V53=&%C:R`@
M5&AE('-T86-K(&]F(&UE<W-A9V5S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1O
M<'1I;VYS("`@("`@("!!;B!A<G)A>2!O9B!O<'1I;VYS+B!/<'1I;VYS.B`G
M;F]S<&%C92<*("`@("`J+PH@("`@9G5N8W1I;VX@;F]T:69Y*"8D;65S<V%G
M95-T86-K+"`D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@
M*"$D=&AI<RT^7VUO8FEL92D@>PH@("`@("`@("`@("!P87)E;G0Z.DYO=&EF
M:6-A=&EO;E],:7-T96YE<E]S=&%T=7,H*3L*("`@("`@("`@("`@<F5T=7)N
M('!A<F5N=#HZ;F]T:69Y*"1M97-S86=E4W1A8VLL("1O<'1I;VYS*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D;65S<V%G95-T86-K*2D@>PH@
M("`@("`@("`@("!W:&EL92`H)&UE<W-A9V4@/2!A<G)A>5]S:&EF="@D;65S
M<V%G95-T86-K*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$UE<W-A
M9V4H)&UE<W-A9V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T(#T@
M)B1T:&ES+3Y?;6]B:6QE+3YA9&0H;F5W($AO<F1E7TUO8FEL95]T97AT*")<
M;B(I*3L*("`@("`@("`@("`@)'0M/G-E="@G;&EN96)R96%K<R<L('1R=64I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U=',@;VYE
M(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S86=E
M("!/;F4@;65S<V%G92!H87-H(&9R;VT@=&AE('-T86-K+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971-97-S86=E*"1M97-S86=E*0H@("`@>PH@("`@("`@
M(&EF("@A)'1H:7,M/E]M;V)I;&4I('L*("`@("`@("`@("`@<&%R96YT.CI.
M;W1I9FEC871I;VY?3&ES=&5N97)?<W1A='5S*"D["B`@("`@("`@("`@(')E
M='5R;B!P87)E;G0Z.F=E=$UE<W-A9V4H)&UE<W-A9V4I.PH@("`@("`@('T*
M"B`@("`@("`@)&5V96YT(#T@)'1H:7,M/F=E=$5V96YT*"1M97-S86=E*3L*
M("`@("`@("`D=&AI<RT^7VUO8FEL92T^861D*&YE=R!(;W)D95]-;V)I;&5?
M=&5X="AS<')I;G1F*%\H(B5S.B`E<R(I+"`D=&AI<RT^7VAA;F1L97-;)&UE
M<W-A9V5;)W1Y<&4G75TL('-T<FEP7W1A9W,H)&5V96YT+3YG971-97-S86=E
M*"DI*2DI.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<```````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#0U-S``,3`T,3<S-C(W-S$`,#(T-3`U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<BYP:'`G.PH*+RHJ"B`J
M(%1H92!.;W1I9FEC871I;VY?3&ES=&5N97)?<W1A='5S.CH@8VQA<W,@<')O
M=FED97,@9G5N8W1I;VYA;&ET>2!F;W(*("H@9&ES<&QA>6EN9R!M97-S86=E
M<R!F<F]M('1H92!M97-S86=E('-T86-K(&%S(&$@<W1A='5S(&QI;F4N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<"QV(#$N,CDN,BXU(#(P,#8O,#$O,#$@
M,C$Z,C@Z,S`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95].;W1I9FEC
M871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;E],:7-T96YE<E]S=&%T=7,@
M97AT96YD<R!.;W1I9FEC871I;VY?3&ES=&5N97(@>PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T
M:6]N7TQI<W1E;F5R7W-T871U<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]H
M86YD;&5S(#T@87)R87DH)VAO<F1E+F5R<F]R)R`@(#T^(&%R<F%Y*"=A;&5R
M=',O97)R;W(N<&YG)RP@7R@B17)R;W(B*2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G(#T^(&%R<F%Y*"=A;&5R
M=',O<W5C8V5S<RYP;F<G+"!?*")3=6-C97-S(BDI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=H;W)D92YW87)N:6YG)R`]/B!A<G)A>2@G
M86QE<G1S+W=A<FYI;F<N<&YG)RP@7R@B5V%R;FEN9R(I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N;65S<V%G92<@/3X@87)R
M87DH)V%L97)T<R]M97-S86=E+G!N9R<L(%\H(DUE<W-A9V4B*2DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@=6YI<75E(&ED96YT:69I97(@
M9F]R('1H:7,@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%5N:7%U92!I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F%M92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("=S=&%T=7,G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3W5T<'5T<R!T:&4@<W1A='5S(&QI;F4@:68@=&AE<F4@87)E
M(&%N>2!M97-S86=E<R!O;B!T:&4@)W-T871U<R<*("`@("`J(&UE<W-A9V4@
M<W1A8VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D;65S<V%G95-T
M86-K("!4:&4@<W1A8VL@;V8@;65S<V%G97,N"B`@("`@*B!`<&%R86T@87)R
M87D@)&]P=&EO;G,@("`@("`@($%N(&%R<F%Y(&]F(&]P=&EO;G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YO=&EF>2@F)&UE<W-A9V53=&%C:RP@)&]P=&EO
M;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D;65S<V%G
M95-T86-K*2D@>PH@("`@("`@("`@("!W:&EL92`H)&UE<W-A9V4@/2!A<G)A
M>5]S:&EF="@D;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("`@("`@96-H
M;R`D=&AI<RT^9V5T365S<V%G92@D;65S<V%G92D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96-H;R`G/&)R(&-L87-S/2)S<&%C97(B("\^)SL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S(&]N92!M97-S
M86=E+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@3VYE
M(&UE<W-A9V4@:&%S:"!F<F]M('1H92!S=&%C:RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T365S<V%G92@D;65S<V%G92D*("`@('L*("`@("`@("!G;&]B
M86P@)')E9VES=')Y.PH*("`@("`@("`D979E;G0@/2`D=&AI<RT^9V5T179E
M;G0H)&UE<W-A9V4I.PH@("`@("`@("1T97AT(#T@)&5V96YT+3YG971-97-S
M86=E*"D["@H@("`@("`@(&EF("@A:6Y?87)R87DH)V-O;G1E;G0N<F%W)RP@
M)'1H:7,M/F=E=$9L86=S*"1M97-S86=E*2DI('L*("`@("`@("`@("`@)'1E
M>'0@/2!H=&UL<W!E8VEA;&-H87)S*"1T97AT*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`G/'`@8VQA<W,](FYO=&EC92(^)R`N($AO<F1E.CII;6<H
M)'1H:7,M/E]H86YD;&5S6R1M97-S86=E6R=T>7!E)UU=6S!=+"`D=&AI<RT^
M7VAA;F1L97-;)&UE<W-A9V5;)W1Y<&4G75U;,5TL("<G+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<F;F)S<#LF;F)S<#LG("X@)'1E
M>'0@+B`G/"]P/B<["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO179E;G0N<&AP````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(U,C0`,3`T,3<S-C(W-S$`,#(R-#4S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@3F]T:69I8V%T:6]N7T5V96YT.CH@8VQA<W,@<')O=FED
M97,@82!C;VYT86EN97(@9F]R('!A<W-I;F<*("H@;65S<V%G97,@=&\@3F]T
M:69I8V%T:6]N7TQI<W1E;F5R(&-L87-S97,N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO179E;G0N<&AP+'8@
M,2XU+C(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($AA;G,@3&5L;&5L:60@/&AA;G-`=F5L=6TN
M;F5T/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2&%N<R!,96QL96QI
M9"`\:&%N<T!V96QU;2YN970^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A
M=&EO;E]%=F5N="!["@H@("`@+RHJ"B`@("`@*B!4:&4@;65S<V%G92!B96EN
M9R!P87-S960N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7VUE<W-A9V4@/2`G)SL*"B`@("`O
M*BH*("`@("`J($EF('!A<W-E9"P@<V5T<R!T:&4@;65S<V%G92!F;W(@=&AI
M<R!E=F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E
M("!4:&4@=&5X="!M97-S86=E(&9O<B!T:&ES(&5V96YT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!.;W1I9FEC871I;VY?179E;G0H)&UE<W-A9V4@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D;65S<V%G92DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$UE<W-A9V4H)&UE<W-A9V4I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE('1E>'0@;65S<V%G
M92!F;W(@=&AI<R!E=F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1M97-S86=E("!4:&4@=&5X="!M97-S86=E('1O(&1I<W!L87DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$UE<W-A9V4H)&UE<W-A9V4I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]M97-S86=E(#T@)&UE<W-A9V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'971S('1H92!T97AT(&UE<W-A9V4@9F]R('1H:7,@979E
M;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&UE
M<W-A9V4@=&\@9&ES<&QA>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T365S
M<V%G92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;65S<V%G93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<BYP:'``````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S8R
M,P`Q,#0Q-S,V,C<W,0`P,C,Q-C0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!.;W1I9FEC871I
M;VY?3&ES=&5N97(Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y(&9O
M<B!D:7-P;&%Y:6YG"B`J(&UE<W-A9V5S(&9R;VT@=&AE(&UE<W-A9V4@<W1A
M8VL@87,@82!S=&%T=7,@;&EN92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<BYP:'`L=B`Q+C$V
M+C(N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@
M*B!`<&%C:V%G92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF
M:6-A=&EO;E],:7-T96YE<B!["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!O9B!M
M97-S86=E('1Y<&5S('1H870@=&AI<R!L:7-T96YE<B!H86YD;&5S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:&%N9&QE
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@
M("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VY?3&ES=&5N97(H*0H@("`@
M>PH@("`@?0H*("`@("\J*@H@("`@("H@1&]E<R!T:&ES(&QI<W1E;F5R(&AA
M;F1L92!A(&-E<G1A:6X@='EP92!O9B!M97-S86=E/PH@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!M97-S86=E('1Y<&4@:6X@<75E
M<W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R
M('1H:7,@;&ES=&5N97(@:&%N9&QE<R!T:&4@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:&%N9&QE<R@D='EP92D*("`@('L*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/E]H86YD;&5S6R1T>7!E72D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@82!U;FEQ=64@:61E;G1I9FEE<B!F;W(@=&AI<R!L
M:7-T96YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@56YI<75E
M(&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@
M("`@("!R971U<FX@9V5T7V-L87-S*"1T:&ES*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($]U='!U=',@=&AE('-T871U<R!L:6YE+"!S96YD<R!E;6%I;',L
M('!A9V5S+"!E=&,N+"!I9B!T:&5R90H@("`@("H@87)E(&%N>2!M97-S86=E
M<R!O;B!T:&ES(&QI<W1E;F5R)W,@;65S<V%G92!S=&%C:RX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)B1M97-S86=E4W1A8VL@(%1H92!S=&%C:R!O
M9B!M97-S86=E<RX*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@("`@
M("`@06X@87)R87D@;V8@;W!T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M;F]T:69Y*"8D;65S<V%G95-T86-K<RP@)&]P=&EO;G,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S<V5S(&]N92!M97-S
M86=E(&9R;VT@=&AE(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1M97-S86=E("!/;F4@;65S<V%G92!H87-H(&9R;VT@=&AE
M('-T86-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-97-S86=E*"1M97-S
M86=E*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@56YS97)I86QI>F4@
M86X@979E;G0@9G)O;2!T:&4@;65S<V%G92!S=&%C:RP@8VAE8VMI;F<@=&\@
M<V5E(&EF('1H90H@("`@("H@87!P<F]P<FEA=&4@8VQA<W,@97AI<W1S(&%N
M9"!K;'5D9VEN9R!I="!I;G1O(&$@8F%S92!.;W1I9FEC871I;VY?179E;G0*
M("`@("`J(&]B:F5C="!I9B!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$5V96YT*"1M97-S86=E*0H@("`@>PH@("`@("`@("1O8B`](&9A;'-E.PH@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&UE<W-A9V5;)V-L87-S)UTI*2![
M"B`@("`@("`@("`@("1O8B`]($!U;G-E<FEA;&EZ92@D;65S<V%G95LG979E
M;G0G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]%=F5N="YP:'`G.PH@("`@("`@
M("`@("`D;V(@/2!`=6YS97)I86QI>F4H)&UE<W-A9V5;)V5V96YT)UTI.PH@
M("`@("`@("`@("!I9B`H(6UE=&AO9%]E>&ES=',H)&]B+"`G9V5T365S<V%G
M92<I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]B+3Y?;65S<V%G
M92DI('L*("`@("`@("`@("`@("`@("`@("`D;V(@/2`F;F5W($YO=&EF:6-A
M=&EO;E]%=F5N="@D;V(M/E]M97-S86=E*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@=V4G=F4@
M9F%I;&5D('1O(&-R96%T92!A('9A;&ED($YO=&EF:6-A=&EO;E]%=F5N="!O
M8FIE8W0*("`@("`@("`@*B`H;W(@<W5B8VQA<W,@;V)J96-T*2!S;R!F87(L
M(')E='5R;B!A(%!%05)?17)R;W(N("HO"B`@("`@("`@:68@*"%M971H;V1?
M97AI<W1S*"1O8BP@)V=E=$UE<W-A9V4G*2D@>PH@("`@("`@("`@("`D;V(@
M/2!014%2.CIR86ES945R<F]R*"=5;F%B;&4@=&\@9&5C;V1E(&UE<W-A9V4@
M979E;G0Z("<@+B`D;65S<V%G95LG979E;G0G72D["B`@("`@("`@?0H*("`@
M("`@("`O*B!3<&5C:6%L;'D@:&%N9&QE(%!%05)?17)R;W(@;V)J96-T<R!A
M;F0@861D('5S97)I;F9O(&EF"B`@("`@("`@("H@:70G<R!T:&5R92X@*B\*
M("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;V(L("=G9715<V5R26YF;R<I
M*2!["B`@("`@("`@("`@("1U<V5R:6YF;R`]("1O8BT^9V5T57-E<DEN9F\H
M*3L*("`@("`@("`@("`@:68@*"1U<V5R:6YF;RD@>PH@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1U<V5R:6YF;RDI('L*("`@("`@("`@("`@("`@
M("`@("`D=7-E<FEN9F\@/2!`:6UP;&]D92@G+"`G+"`D=7-E<FEN9F\I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&]B+3Y?;65S<V%G
M92`]("1O8BT^9V5T365S<V%G92@I("X@)R`Z("<@+B`D=7-E<FEN9F\["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!5;G-E<FEA;&EZ92!A;B!A<G)A>2!O9B!E
M=F5N="!F;&%G<R!F<F]M('1H92!M97-S86=E('-T86-K+B`@268@=&AI<PH@
M("`@("H@979E;G0@:&%S(&YO(&9L86=S+"!O<B!T:&4@9FQA9W,@87)R87D@
M8V]U;&0@;F]T(&)E('5N<V5R:6%L:7IE9"P@86X*("`@("`J(&5M<'1Y(&%R
M<F%Y(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%N(&%R<F%Y(&]F(&9L86=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&
M;&%G<R@D;65S<V%G92D*("`@('L*("`@("`@("`O*B!)9B!T:&ES(&UE<W-A
M9V4@9&]E<VXG="!H879E(&%N>2!F;&%G<RP@<F5T=7)N(&%N(&5M<'1Y"B`@
M("`@("`@("H@87)R87DN("HO"B`@("`@("`@:68@*&5M<'1Y*"1M97-S86=E
M6R=F;&%G<R==*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@
M("`@("!]"@H@("`@("`@("\J(%5N<V5R:6%L:7IE('1H92!F;&%G<R!A<G)A
M>2!F<F]M('1H92!M97-S86=E+B`J+PH@("`@("`@("1F;&%G<R`]($!U;G-E
M<FEA;&EZ92@D;65S<V%G95LG9FQA9W,G72D["@H@("`@("`@("\J($EF('=E
M(&-O=6QD;B=T('5N<V5R:6%L:7IE('1H92!F;&%G<R!A<G)A>2P@<F5T=7)N
M(&%N(&5M<'1Y"B`@("`@("`@("H@87)R87DN("HO"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D9FQA9W,I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F;&%G<SL*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T-A8VAE+P``````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,0`P,3<R,S8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V%C:&4O9FEL92YP:'``````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T,34W`#$P-#$W,S8R
M-S<Q`#`R,#8W,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T-A8VAE7V9I;&4Z.B!C
M;&%S<R!P<F]V:61E<R!A(&9I;&5S>7-T96T@:6UP;&5M96YT871I;VX@;V8@
M=&AE"B`J($AO<F1E(&-A8VAI;F<@<WES=&5M+@H@*@H@*B!/<'1I;VYA;"!P
M87)A;65T97)S.CQP<F4^"B`J("`@)V1I<B<@("`@(%1H92!D:7)E8W1O<GD@
M=&\@<W1O<F4@=&AE(&-A8VAE(&9I;&5S(&EN+@H@*B`@("=P<F5F:7@G("!4
M:&4@9FEL96YA;64@<')E9FEX('1O('5S92!F;W(@=&AE(&-A8VAE(&9I;&5S
M+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#86-H92]#86-H92]F
M:6QE+G!H<"QV(#$N,C@N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E
M9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O
M:6PN;W)G/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO
M<F1E7T-A8VAE"B`J+PIC;&%S<R!(;W)D95]#86-H95]F:6QE(&5X=&5N9',@
M2&]R9&5?0V%C:&4@>PH*("`@("\J*@H@("`@("H@5&AE(&QO8V%T:6]N(&]F
M('1H92!T96UP(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]D:7(["@H@("`@+RHJ"B`@("`@*B!4:&4@
M9FEL96YA;64@<')E9FEX(&9O<B!C86-H92!F:6QE<RX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P<F5F:7@@/2`G8V%C
M:&5?)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C="!A(&YE=R!(;W)D95]#
M86-H95]F:6QE(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@4&%R86UE=&5R(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!(;W)D95]#86-H95]F:6QE*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG9&ER)UTI("8F($!I<U]D:7(H
M)'!A<F%M<ULG9&ER)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&ER(#T@
M)'!A<F%M<ULG9&ER)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]5=&EL+G!H<"<["B`@("`@("`@("`@("1T
M:&ES+3Y?9&ER(#T@571I;#HZ9V5T5&5M<$1I<B@I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W!R969I>"==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!R969I>"`]("1P87)A;7-;)W!R969I>"==.PH@("`@
M("`@('T*"B`@("`@("`@<&%R96YT.CI(;W)D95]#86-H92@D<&%R86US*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E=')I979E(&-A
M8VAE9"!D871A(&9R;VT@=&AE(&9I;&5S>7-T96T@86YD(')E='5R;B!I="!T
M;PH@("`@("H@=&AE(&-A;&QE<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D:V5Y("`@("`@($-A8VAE(&ME>2!T;R!F971C:"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1L:69E=&EM92`@3&EF971I;64@;V8@=&AE(&1A=&$@
M:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!#86-H
M960@9&%T82P@;W(@9F%L<V4@:68@;F]N92!W87,@9F]U;F0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E="@D:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^97AI<W1S*"1K97DL("1L:69E=&EM92DI('L*
M("`@("`@("`@("`@)&9I;&5N86UE(#T@)'1H:7,M/E]K97E4;T9I;&4H)&ME
M>2D["B`@("`@("`@("`@("1S:7IE(#T@9FEL97-I>F4H)&9I;&5N86UE*3L*
M("`@("`@("`@("`@:68@*"$D<VEZ92D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D871A(#T@9FEL
M95]G971?8V]N=&5N=',H)&9I;&5N86UE*3L*("`@("`@("`@("`@:68@*"1D
M871A("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871A
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!.;W1H:6YG
M(&-A8VAE9"P@<F5T=7)N(&9A:6QU<F4N("HO"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<W1O<F4@
M9&%T82!T;R!T:&4@9FEL97-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1K97D@("!#86-H92!K97DN"B`@("`@*B!`<&%R86T@;6EX960@
M("1D871A("!$871A('1O('-T;W)E(&EN('1H92!C86-H92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T*"1K97DL("1D
M871A*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O571I;"YP
M:'`G.PH@("`@("`@("1F:6QE;F%M92`]("1T:&ES+3Y?:V5Y5&]&:6QE*"1K
M97DI.PH@("`@("`@("1T;7!?9FEL92`](%5T:6PZ.F=E=%1E;7!&:6QE*"=(
M;W)D94-A8VAE)RP@=')U92P@)'1H:7,M/E]D:7(I.PH*("`@("`@("!I9B`H
M)&9D(#T@9F]P96XH)'1M<%]F:6QE+"`G=R<I*2!["B`@("`@("`@("`@(&EF
M("AF=W)I=&4H)&9D+"`D9&%T82D@/"!S=')L96XH)&1A=&$I*2!["B`@("`@
M("`@("`@("`@("!F8VQO<V4H)&9D*3L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&9C;&]S92@D9F0I.PH@("`@("`@("`@("`@("`@0')E;F%M92@D=&UP7V9I
M;&4L("1F:6QE;F%M92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!D:7)E8W1L>2!O=71P=70@
M8V%C:&5D(&1A=&$@9G)O;2!T:&4@9FEL97-Y<W1E;2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D:V5Y("`@("`@($-A8VAE(&ME>2!T;R!O=71P
M=70N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE
M(&]F('1H92!D871A(&EN('-E8V]N9',N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@0V%C:&5D(&1A=&$L(&]R(&9A;'-E(&EF(&YO;F4@=V%S(&9O
M=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!O=71P=70H)&ME>2P@)&QI9F5T
M:6UE(#T@,2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F5X:7-T<R@D:V5Y
M+"`D;&EF971I;64I*2!["B`@("`@("`@("`@("1F:6QE;F%M92`]("1T:&ES
M+3Y?:V5Y5&]&:6QE*"1K97DI.PH@("`@("`@("`@("`D9F0@/2!`9F]P96XH
M)&9I;&5N86UE+"`G<B<I.PH@("`@("`@("`@("!I9B`H)&9D*2!["B`@("`@
M("`@("`@("`@("!F<&%S<W1H<G4H)&9D*3L*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!.;W1H:6YG(&-A8VAE9"P@<F5T=7)N(&9A:6QU<F4N("HO"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF
M(&$@9VEV96X@:V5Y(&5X:7-T<R!I;B!T:&4@8V%C:&4L('9A;&ED(&9O<B!T
M:&4@9VEV96X*("`@("`J(&QI9F5T:6UE+B!)9B!I="!E>&ES=',@8G5T(&ES
M(&5X<&ER960L(&1E;&5T92!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D:V5Y("`@("`@($-A8VAE(&ME>2!T;R!C:&5C:RX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1L:69E=&EM92`@3&EF971I;64@;V8@=&AE
M(&ME>2!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@17AI<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)&ME
M>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("`D9FEL96YA;64@/2`D
M=&AI<RT^7VME>51O1FEL92@D:V5Y*3L*"B`@("`@("`@+RH@2V5Y(&5X:7-T
M<R!I;B!T:&4@8V%C:&4@*B\*("`@("`@("!I9B`H9FEL95]E>&ES=',H)&9I
M;&5N86UE*2D@>PH@("`@("`@("`@("`O*B`P(&UE86YS(&YO(&5X<&ER92X@
M*B\*("`@("`@("`@("`@:68@*"1L:69E=&EM92`]/2`P*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@268@=&AE(&9I;&4@=V%S(&)E96X@8W)E871E9"!A9G1E<B!T:&4@
M<W5P<&QI960@=F%L=64L"B`@("`@("`@("`@("`J('1H92!D871A(&ES('9A
M;&ED("AF<F5S:"DN("HO"B`@("`@("`@("`@(&EF("AT:6UE*"D@+2`D;&EF
M971I;64@/#T@9FEL96UT:6UE*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@0'5N;&EN:R@D9FEL96YA;64I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!%>'!I<F4@86YY(&5X:7-T:6YG(&1A=&$@9F]R('1H92!G:79E
M;B!K97DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!#86-H
M92!K97D@=&\@97AP:7)E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E
M>'!I<F4H)&ME>2D*("`@('L*("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^
M7VME>51O1FEL92@D:V5Y*3L*("`@("`@("!R971U<FX@0'5N;&EN:R@D9FEL
M96YA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P(&$@8V%C:&4@:V5Y
M('1O(&$@=6YI<75E(&9I;&5N86UE+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@0V%C
M:&4@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!&=6QL>2!Q
M=6%L:69I960@9FEL96YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]K97E4
M;T9I;&4H)&ME>2D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D:7(@
M+B`G+R<@+B`D=&AI<RT^7W!R969I>"`N(&UD-2@D:V5Y*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1O(&%N>2!G87)B86=E(&-O;&QE8W1I;VX@;F5E9&5D
M(&9O<B!T:&4@9')I=F5R+@H@("`@("H*("`@("`J($!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-E8W,@(%1H92!M:6YI;75M(&%M
M;W5N="!O9B!T:6UE("AI;B!S96-O;F1S*2!R97%U:7)E9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&)E9F]R92!A(&-A8VAE(&ET96T@:7,@<F5M
M;W9E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1O1T,H)'-E8W,I"B`@("![
M"B`@("`@("`@)&9I;&5N86UE(#T@)'1H:7,M/E]D:7(@+B`G+VAO<F1E7V-A
M8VAE7V=C)SL*("`@("`@("`D9V-?=&EM92`]('1I;64H*2`M("1S96-S.PH@
M("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL96YA;64I*2!["B`@("`@("`@
M("`@("1O;&1?=&EM92`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE;F%M92D[
M"B`@("`@("`@("`@(&EF("@H)&]L9%]T:6UE("$]/2!F86QS92D@)B8*("`@
M("`@("`@("`@("`@("@D9V-?=&EM92`^("1O;&1?=&EM92DI('L*("`@("`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&0@/2!D:7(H)'1H:7,M/E]D:7(I.PH@("`@("`@('=H:6QE("@H
M)&5N=')Y(#T@)&0M/G)E860H*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M(&EF("AS=')P;W,H)&5N=')Y+"`D=&AI<RT^7W!R969I>"D@/3T](#`I('L*
M("`@("`@("`@("`@("`@("1M=&EM92`](&9I;&5M=&EM92@D=&AI<RT^7V1I
M<B`N("<O)R`N("1E;G1R>2D["B`@("`@("`@("`@("`@("!I9B`H)&=C7W1I
M;64@/B`D;71I;64I('L*("`@("`@("`@("`@("`@("`@("!`=6YL:6YK*"1T
M:&ES+3Y?9&ER("X@)R\G("X@)&5N=')Y*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D9"T^8VQO<V4H*3L*
M(`H@("`@("`@("1F<"`](&9O<&5N*"1F:6QE;F%M92P@)W<G*3L*("`@("`@
M("!F=W)I=&4H)&9P+"!T:6UE*"DI.PH@("`@("`@(&9C;&]S92@D9G`I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-A8VAE
M+WIP<S0N<&AP````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#0W,@`Q,#0Q-S,V,C<W,0`P,C`V-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#
M86-H95]Z<',T.CH@8VQA<W,@<')O=FED97,@82!:96YD(%!E<F9O<FUA;F-E
M(%-U:71E"B`J("AV97)S:6]N(#0N,"LI(&EM<&QE;65N=&%T:6]N(&]F('1H
M92!(;W)D92!C86-H:6YG('-Y<W1E;2X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO0V%C:&4O0V%C:&4O>G!S-"YP:'`L=B`Q+C$N,3`N-"`R,#`V+S`Q+S`Q
M(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]#86-H90H@*B\*8VQA<W,@2&]R9&5?0V%C:&5?>G!S-"!E>'1E;F1S($AO
M<F1E7T-A8VAE('L*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E=')I
M979E(&$@<&EE8V4@;V8@8V%C:&5D(&1A=&$@86YD(')E='5R;B!I="!T;R!T
M:&4@8V%L;&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1K97D@
M("`@("`@0V%C:&4@:V5Y('1O(&9E=&-H+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&QI9F5T:6UE("!,:69E=&EM92!O9B!T:&4@:V5Y(&EN('-E8V]N9',N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@0V%C:&5D(&1A=&$L(&]R
M(&9A;'-E(&EF(&YO;F4@=V%S(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G970H)&ME>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("!R971U
M<FX@;W5T<'5T7V-A8VAE7V=E="@D:V5Y+"`D;&EF971I;64I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<W1O<F4@86X@;V)J96-T('1O
M('1H92!C86-H92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@
M("!#86-H92!K97D@*&ED96YT:69I97(I+@H@("`@("H@0'!A<F%M(&UI>&5D
M("`D9&%T82`@1&%T82!T;R!S=&]R92!I;B!T:&4@8V%C:&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D:V5Y+"`D
M9&%T82D*("`@('L*("`@("`@("!O=71P=71?8V%C:&5?<'5T*"1K97DL("1D
M871A*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O(&1I<F5C=&QY(&]U='!U="!C86-H960@9&%T82X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D:V5Y("`@("`@($-A8VAE
M(&ME>2!T;R!O=71P=70N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I
M;64@($QI9F5T:6UE(&]F('1H92!K97D@:6X@<V5C;VYD<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@:68@
M;F]N92!W87,@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D
M:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@(&5C:&\@)'1H:7,M
M/F9E=&-H*"1K97DL("1L:69E=&EM92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@:68@82!G:79E;B!K97D@97AI<W1S(&EN('1H92!C86-H92P@
M=F%L:60@9F]R('1H92!G:79E;B!L:69E=&EM92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D:V5Y("`@("`@($-A8VAE(&ME>2!T;R!C:&5C:RX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1L:69E=&EM92`@3&EF971I;64@;V8@
M=&AE(&ME>2!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@17AI<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H
M)&ME>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("`D97AI<W1S(#T@
M;W5T<'5T7V-A8VAE7V5X:7-T<R@D:V5Y+"`D;&EF971I;64I.PH@("`@("`@
M(&]U='!U=%]C86-H95]S=&]P*"D["B`@("`@("`@<F5T=7)N("1E>&ES=',[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!I<F4@86YY(&5X:7-T:6YG(&1A
M=&$@9F]R('1H92!G:79E;B!K97DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:V5Y("!#86-H92!K97D@=&\@97AP:7)E+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>'!I<F4H)&ME>2D*("`@('L*("`@("`@("!R971U
M<FX@;W5T<'5T7V-A8VAE7W)E;6]V95]K97DH)&ME>2D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U9#+P``````````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,0`P,38U-#,`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5D,O8W9S+G!H<```````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3`Q-S`W`#$P-#$W,S8R-S<Q
M`#`R,#`U,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]R8W,N<&AP)SL*"B\J*@H@*B!60U]C=G,@:6UP;&5M96YT871I;VXN"B`J
M"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@06YI;"!-861H879A<&5D9'DL(#QA
M;FEL0')E8V]I;"YO<F<^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9#+U9#
M+V-V<RYP:'`L=B`Q+C,R+C(N,3@@,C`P-B\P,2\P,2`R,3HR.#HT,B!J86X@
M17AP("0*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7V-V<R!E
M>'1E;F1S(%9#7W)C<R!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M
M971E<B!T:&4@8VQA<W,@97AP96-T<RX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`\<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($-U
M<G)E;G0@<&%R86UE=&5R<SH*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`G<V]U<F-E<F]O="<Z(%1H92!S;W5R8V4@<F]O="!F;W(@=&AI<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5P;W-I
M=&]R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=P871H<R<Z($AA
M<V@@=VET:"!T:&4@;&]C871I;VYS(&]F(&%L;`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YE8V5S<V%R>2!B:6YA<FEE<SH@)W)C
M<V1I9F8G+"`G<FQO9R<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V-V<W!S)RP@)V-V<W!S7VAO;64G(&%N9"!T:&4@=&5M<`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!A=&@Z("=T
M96UP)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(#PO<')E/@H@("`@
M("HO"B`@("!F=6YC=&EO;B!60U]C=G,H)'!A<F%M<RD*("`@('L*("`@("`@
M("`D=&AI<RT^7W-O=7)C97)O;W0@/2`D<&%R86US6R=S;W5R8V5R;V]T)UT[
M"B`@("`@("`@)'1H:7,M/E]P871H<R`]("1P87)A;7-;)W!A=&AS)UT["B`@
M("!]"@H@("`@9G5N8W1I;VX@:7-&:6QE*"1W:&5R92D*("`@('L*("`@("`@
M("!R971U<FX@0&ES7V9I;&4H)'=H97)E("X@)RQV)RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@)G%U97)Y1&ER*"1W:&5R92D*("`@('L*("`@("`@("`D9&ER
M(#T@)FYE=R!60U]$:7)E8W1O<GE?8W9S*"1T:&ES+"`D=VAE<F4I.PH@("`@
M("`@(')E='5R;B`D9&ER.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-H96-K
M;W5T*"1F:6QE+"`D<F5V*0H@("`@>PH@("`@("`@(')E='5R;B!60U]#:&5C
M:V]U=%]C=G,Z.F=E="@D=&AI<RP@)&9I;&4M/G%U97)Y1G5L;%!A=&@H*2P@
M)')E=BD["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&EF9B@F)&9I;&4L("1R
M978Q+"`D<F5V,BP@)'1Y<&4@/2`G8V]N=&5X="<L("1N=6T@/2`S+"`D=W,@
M/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R;B!60U]$:69F7V-V<SHZ9V5T
M*"1T:&ES+"`D9FEL92P@)')E=C$L("1R978R+"`D='EP92P@)&YU;2P@)'=S
M*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T1FEL94]B:F5C="@D9FEL96YA
M;64L("1C86-H92`](&YU;&PL("1Q=6EC:VQO9R`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("AS=6)S='(H)&9I;&5N86UE+"`P+"`Q*2`A/2`G+R<I('L*
M("`@("`@("`@("`@)&9I;&5N86UE(#T@)R\G("X@)&9I;&5N86UE.PH@("`@
M("`@('T*("`@("`@("`D9F\@/2`F5D-?1FEL95]C=G,Z.F=E=$9I;&5/8FIE
M8W0H)'1H:7,L("1T:&ES+3YS;W5R8V5R;V]T*"D@+B`D9FEL96YA;64L("1C
M86-H92P@)'%U:6-K;&]G*3L*("`@("`@("!R971U<FX@)&9O.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9G971!;FYO=&%T94]B:F5C="@D9FEL96YA;64I"B`@
M("!["B`@("`@("`@)&)L86UE(#T@)FYE=R!60U]!;FYO=&%T95]C=G,H)'1H
M:7,L("1F:6QE;F%M92P@571I;#HZ9V5T5&5M<$9I;&4H)W9C)RP@=')U92P@
M)'1H:7,M/E]P871H<ULG=&5M<"==*2D["B`@("`@("`@<F5T=7)N("1B;&%M
M93L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4&%T8VAS971/8FIE8W0H)&9I
M;&5N86UE+"`D8V%C:&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1P;R`]("96
M0U]0871C:'-E=%]C=G,Z.F=E=%!A=&-H<V5T3V)J96-T*"1T:&ES+"`D=&AI
M<RT^<V]U<F-E<F]O="@I("X@)R\G("X@)&9I;&5N86UE+"`D8V%C:&4I.PH@
M("`@("`@(')E='5R;B`D<&\["B`@("!]"@I]"@HO*BH*("H@5D-?8W9S(&%N
M;F]T871E(&-L87-S+@H@*@H@*B!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@
M/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#
M7T%N;F]T871E7V-V<R!["@H@("`@=F%R("1F:6QE.PH@("`@=F%R("1R97`[
M"B`@("!V87(@)'1M<&9I;&4["@H@("`@9G5N8W1I;VX@5D-?06YN;W1A=&5?
M8W9S*"8D<F5P+"`D9FEL92P@)'1M<&9I;&4I"B`@("!["B`@("`@("`@)'1H
M:7,M/G)E<"`]("8D<F5P.PH@("`@("`@("1T:&ES+3YF:6QE(#T@)B1F:6QE
M.PH@("`@("`@("1T:&ES+3YT;7!F:6QE(#T@)'1M<&9I;&4["B`@("!]"@H@
M("`@9G5N8W1I;VX@9&]!;FYO=&%T92@D<F5V*0H@("`@>PH@("`@("`@("\J
M($UA:V4@<W5R92!T:&%T('1H92!F:6QE('9A;'5E<R!F;W(@=&AI<R!O8FIE
M8W0@:7,@=F%L:60N("HO"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/F9I;&4L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('1H870@=&AE(&-V<W)E
M<"!P87)A;65T97(@:7,@=F%L:60N("HO"B`@("`@("`@:68@*&ES7V$H)'1H
M:7,M/G)E<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(59#7U)E=FES:6]N.CIV
M86QI9"@D<F5V*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D=VAE<F4@/2`D=&AI<RT^9FEL92T^<75E<GE-;V1U
M;&50871H*"D["B`@("`@("`@)'-O=7)C97)O;W0@/2`D=&AI<RT^<F5P+3YS
M;W5R8V5R;V]T*"D["@H@("`@("`@("1P:7!E(#T@<&]P96XH)'1H:7,M/G)E
M<"T^9V5T4&%T:"@G8W9S)RD@+B`G("UN('-E<G9E<B`^("<@+B`D=&AI<RT^
M=&UP9FEL92P@5D-?5TE.1$]74R`_("=W8B<@.B`G=R<I.PH*("`@("`@("`D
M;W5T(#T@87)R87DH*3L*("`@("`@("`D;W5T6UT@/2`B4F]O="`D<V]U<F-E
M<F]O="(["B`@("`@("`@)&]U=%M=(#T@)U9A;&ED+7)E<W!O;G-E<R!O:R!E
M<G)O<B!686QI9"UR97%U97-T<R!#:&5C:V5D+6EN(%5P9&%T960@365R9V5D
M(%)E;6]V960@32!%)SL*("`@("`@("`D;W5T6UT@/2`G57-E56YC:&%N9V5D
M)SL*("`@("`@("`D;W5T6UT@/2`G07)G=6UE;G0@+7(G.PH@("`@("`@("1O
M=71;72`](")!<F=U;65N="`D<F5V(CL*("`@("`@("`D;W5T6UT@/2`B07)G
M=6UE;G0@)'=H97)E(CL*("`@("`@("`D9&ER<R`](&5X<&QO9&4H)R\G+"!D
M:7)N86UE*"1W:&5R92DI.PH@("`@("`@('=H:6QE("AC;W5N="@D9&ER<RDI
M('L*("`@("`@("`@("`@)&]U=%M=(#T@)T1I<F5C=&]R>2`G("X@:6UP;&]D
M92@G+R<L("1D:7)S*3L*("`@("`@("`@("`@)&]U=%M=(#T@(B1S;W5R8V5R
M;V]T+R(@+B!I;7!L;V1E*"<O)RP@)&1I<G,I.PH@("`@("`@("`@("!A<G)A
M>5]P;W`H)&1I<G,I.PH@("`@("`@('T*("`@("`@("`D;W5T6UT@/2`G1&ER
M96-T;W)Y("XG.PH@("`@("`@("1O=71;72`]("1S;W5R8V5R;V]T.PH@("`@
M("`@("1O=71;72`]("=A;FYO=&%T92<["@H@("`@("`@(&9O<F5A8V@@*"1O
M=70@87,@)&QI;F4I('L*("`@("`@("`@("`@9G=R:71E*"1P:7!E+"`B)&QI
M;F5<;B(I.PH@("`@("`@('T*("`@("`@("!P8VQO<V4H)'!I<&4I.PH*("`@
M("`@("!I9B`H(2@D9FP@/2!F;W!E;B@D=&AI<RT^=&UP9FEL92P@5D-?5TE.
M1$]74R`_("=R8B<@.B`G<B<I*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@
M("`@("1L:6YE(#T@9F=E=',H)&9L+"`T,#DV*3L*"B`@("`@("`@+R\@5VEN
M9&]W<R!V97)S:6]N<R!O9B!C=G,@86QW87ES(')E='5R;B`D=VAE<F4@=VET
M:"!F;W)W87)D<R!S;&%S:&5S+@H@("`@("`@(&EF("A60U]724Y$3U=3*2![
M"B`@("`@("`@("`@("1W:&5R92`]('-T<E]R97!L86-E*$1)4D5#5$]265]3
M15!!4D%43U(L("<O)RP@)'=H97)E*3L*("`@("`@("!]"@H@("`@("`@('=H
M:6QE("@D;&EN92`F)B`A<')E9U]M871C:"@B?%Y%7',K06YN;W1A=&EO;G,@
M9F]R("1W:&5R97PB+"`D;&EN92DI('L*("`@("`@("`@("`@)&QI;F4@/2!F
M9V5T<R@D9FPL(#0P.38I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D;&EN
M92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YA
M8FQE('1O(&%N;F]T871E.R!S97)V97(@<V%I9#H@)R`N("1L:6YE*3L*("`@
M("`@("!]"@H@("`@("`@("1L:6YE;F\@/2`Q.PH@("`@("`@('=H:6QE("@D
M;&EN92`](&9G971S*"1F;"P@-#`Y-BDI('L*("`@("`@("`@("`@:68@*'!R
M96=?;6%T8V@H)R]>35QS*RA;7&1<+ETK*5QS*UPH*"XK*5QS*RA<9"LM7'<K
M+5QD*RE<*3HN*"XJ*20O)RP@)&QI;F4L("1R96=S*2D@>PH@("`@("`@("`@
M("`@("`@)&5N=')Y(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1E;G1R
M>5LG<F5V)UT@("`@/2`D<F5G<ULQ73L*("`@("`@("`@("`@("`@("1E;G1R
M>5LG875T:&]R)UT@/2`D<F5G<ULR73L*("`@("`@("`@("`@("`@("1E;G1R
M>5LG9&%T92==("`@/2`D<F5G<ULS73L*("`@("`@("`@("`@("`@("1E;G1R
M>5LG;&EN92==("`@/2`D<F5G<ULT73L*("`@("`@("`@("`@("`@("1E;G1R
M>5LG;&EN96YO)UT@/2`D;&EN96YO*RL["B`@("`@("`@("`@("`@("`D;&EN
M97-;72`]("1E;G1R>3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@9F-L;W-E*"1F;"D["B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@('T*
M"GT*"B\J*@H@*B!60U]C=G,@8VAE8VMO=70@8VQA<W,N"B`J"B`J(%-E92!T
M:&4@4D5!1$U%(&9I;&4@=&AA="!C86UE('=I=&@@=&AI<R!L:6)R87)Y(&9O
M<B!M;W)E"B`J(&EN9F]R;6%T:6]N+"!A;F0@<F5A9"!T:&4@:6YL:6YE(&1O
M8W5M96YT871I;VXN"B`J"B`J($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R
M96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\
M86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?
M0VAE8VMO=71?8W9S('L*"B`@("`O*BH*("`@("`J(%-T871I8R!F=6YC=&EO
M;B!W:&EC:"!R971U<FYS(&$@9FEL92!P;VEN=&EN9R!T;R!T:&4@:&5A9"!O
M9B!T:&4*("`@("`J(')E<75E<W1E9"!R979I<VEO;B!O9B!A;B!20U,@9FEL
M92X*("`@("`J"B`@("`@*B!`<&%R86T@5D-?8W9S("1R97`@("`@("`@02!R
M97!O<VET;W)Y(&]B:F5C=`H@("`@("H@0'!A<F%M('-T<FEN9R`D9G5L;&YA
M;64@($9U;&QY('%U86QI9FEE9"!P871H;F%M92!O9B!T:&4@9&5S:7)E9"!2
M0U,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE('1O(&-H
M96-K;W5T"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978@("`@("`@4D-3(')E
M=FES:6]N(&YU;6)E<B!T;R!C:&5C:R!O=70*("`@("`J"B`@("`@*B!`<F5T
M=7)N(')E<V]U<F-E?&]B:F5C="`@16ET:&5R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0L(&]R(&$@<W1R96%M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@<&]I;G1E<B!T;R!T:&4@:&5A9"!O9B!T:&4@8VAE8VMO=70*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T*"8D<F5P+"`D9G5L;&YA;64L("1R978I"B`@
M("!["B`@("`@("`@:68@*"%60U]2979I<VEO;CHZ=F%L:60H)')E=BDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@
M<F5V:7-I;VX@;G5M8F5R)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H5D-?
M5TE.1$]74RD@>PH@("`@("`@("`@("`D42`]("<B)SL*("`@("`@("`@("`@
M)&UO9&4@/2`G<F(G.PH@("`@("`@("`@("`D9G5L;&YA;64@/2!S=')?<F5P
M;&%C92@G7%PG+"`G+R<L("1F=6QL;F%M92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)%$@/2`B)R(["B`@("`@("`@("`@("1M;V1E(#T@)W(G
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"$H)%)#4R`]('!O<&5N*"1R97`M
M/F=E=%!A=&@H)V-O)RD@+B`B("UP)')E=B`D421F=6QL;F%M9211(#(^)C$B
M+"`D;6]D92DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=#;W5L9&Y<)W0@<&5R9F]R;2!C:&5C:V]U="!O9B!T:&4@<F5Q=65S
M=&5D(&9I;&4G*3L*("`@("`@("!]"@H@("`@("`@("\J($9I<G-T(&QI;F4@
M9G)O;2!C;R!S:&]U;&0@8F4@;V8@=&AE(&9O<FT@.@H@("`@("`@("`J("]P
M871H+W1O+V9I;&5N86UE+'8@("TM/B`@<W1A;F1A<F0@;W5T"B`@("`@("`@
M("H@86YD('=E(&-H96-K('1H870@=&AI<R!I<R!T:&4@8V%S92!A;F0@97)R
M;W(@;W1H97)W:7-E"B`@("`@("`@("HO"@H@("`@("`@("1C;R`](&9G971S
M*"120U,L(#$P,C0I.PH@("`@("`@(&EF("@A<')E9U]M871C:"@G+UXH6UQ3
M(%TK*2QV7',K+2T^7',K<W0H86YD87(I/V0@/V]U="AP=70I/UQS*B0O)RP@
M)&-O+"`D<F5G<RD@?'P@)')E9W-;,5TN)RQV)R`A/2`D9G5L;&YA;64I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N97AP96-T
M960@;W5T<'5T(&9R;VT@8VAE8VMO=70Z("<@+B`D8V\I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3F5X="!L:6YE(&9R;VT@8V\@:7,@;V8@=&AE(&9O<FTZ
M"B`@("`@("`@("H@<F5V:7-I;VX@,2XR+C,*("`@("`@("`@*B!43T1/.B!C
M;VUP87)E('1H:7,@=&\@)')E=B!F;W(@8V]N<VES=&5N8WDL(&%T;2!W92!J
M=7-T"B`@("`@("`@("H@("`@("`@9&ES8V%R9"!T:&4@=F%L=64@=&\@;6]V
M92!I;G!U="!P;VEN=&5R(&%L;VYG("T@879S;0H@("`@("`@("`J+PH@("`@
M("`@("1C;R`](&9G971S*"120U,L(#$P,C0I.PH*("`@("`@("!R971U<FX@
M)%)#4SL*("`@('T*"GT*"B\J*@H@*B!60U]C=G,@9&EF9B!C;&%S<RX*("H*
M("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN
M;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R
M96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?1&EF9E]C
M=G,@>PH*("`@("\J*@H@("`@("H@3V)T86EN('1H92!D:69F97)E;F-E<R!B
M971W965N('1W;R!R979I<VEO;G,@;V8@82!F:6QE+@H@("`@("H*("`@("`J
M($!P87)A;2!60U]C=G,@)')E<"`@("`@("`@02!R97!O<VET;W)Y(&]B:F5C
M="X*("`@("`J($!P87)A;2!60U]&:6QE7V-V<R`D9FEL92`@5&AE(&1E<VER
M960@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)')E=C$@("`@("`@3W)I
M9VEN86P@<F5V:7-I;VX@;G5M8F5R('1O(&-O;7!A<F4@9G)O;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)')E=C(@("`@("`@3F5W(')E=FES:6]N(&YU;6)E
M<B!T;R!C;VUP87)E(&%G86EN<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("`@("`@(%1H92!T>7!E(&]F(&1I9F8@*&4N9RX@)W5N:69I960G*2X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1N=6T@("`@("`@3G5M8F5R(&]F(&QI
M;F5S('1O(&)E('5S960@:6X@8V]N=&5X="!A;F0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=6YI9FEE9"!D:69F<RX*("`@("`J($!P87)A
M;2!B;V]L96%N("1W<R`@("`@("`@4VAO=R!W:&ET97-P86-E(&EN('1H92!D
M:69F/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG?&)O;VQE86X@($9A
M;'-E(&]N(&9A:6QU<F4L(&]R(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!D:69F(&]N('-U8V-E<W,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@F)')E<"P@)B1F:6QE+"`D<F5V
M,2P@)')E=C(L("1T>7!E(#T@)V-O;G1E>'0G+"`D;G5M(#T@,RP*("`@("`@
M("`@("`@("`@("`D=W,@/2!T<G5E*0H@("`@>PH@("`@("`@("\J($UA:V4@
M<W5R92!T:&%T('1H92!F:6QE('!A<F%M971E<B!I<R!V86QI9"X@*B\*("`@
M("`@("!I9B`H:7-?82@D9FEL92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C
M:R!T:&%T('1H92!R979I<VEO;B!N=6UB97)S(&%R92!V86QI9"X@*B\*("`@
M("`@("`D<F5V,2`](%9#7U)E=FES:6]N.CIV86QI9"@D<F5V,2D@/R`D<F5V
M,2`Z("<Q+C$G.PH@("`@("`@("1R978R(#T@5D-?4F5V:7-I;VXZ.G9A;&ED
M*"1R978Q*2`_("1R978R(#H@)S$N,2<["@H@("`@("`@("1F=6QL3F%M92`]
M("1F:6QE+3YQ=65R>49U;&Q0871H*"D["B`@("`@("`@)&1I9F8@/2!A<G)A
M>2@I.PH@("`@("`@("1O<'1I;VYS(#T@)RUK:R`G.PH@("`@("`@(&EF("@A
M)'=S*2!["B`@("`@("`@("`@("1O<'1S(#T@)R`M8D(@)SL*("`@("`@("`@
M("`@)&]P=&EO;G,@+CT@)&]P=',["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&]P=',@/2`G)SL*("`@("`@("!]"B`@("`@("`@<W=I=&-H("@D
M='EP92D@>PH@("`@("`@(&-A<V4@)V-O;G1E>'0G.@H@("`@("`@("`@("`D
M;W!T:6]N<R`]("1O<'1S("X@)RUP("TM8V]N=&5X=#TG("X@*&EN="DD;G5M
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G=6YI9FEE9"<Z
M"B`@("`@("`@("`@("1O<'1I;VYS(#T@)&]P=',@+B`G+7`@+2UU;FEF:65D
M/2<@+B`H:6YT*21N=6T["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=C;VQU;6XG.@H@("`@("`@("`@("`D;W!T:6]N<R`]("1O<'1S("X@
M)RTM<VED92UB>2US:61E("TM=VED=&@],3(P)SL*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@)V5D)SH*("`@("`@("`@("`@)&]P=&EO;G,@
M/2`D;W!T<R`N("<M92<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M"B`@("`@("`@+R\@5VEN9&]W<R!V97)S:6]N<R!O9B!C=G,@86QW87ES(')E
M='5R;B`D=VAE<F4@=VET:"!F;W)W87)D<R!S;&%S:&5S+@H@("`@("`@(&EF
M("A60U]724Y$3U=3*2!["B`@("`@("`@("`@("1F=6QL3F%M92`]('-T<E]R
M97!L86-E*$1)4D5#5$]265]315!!4D%43U(L("<O)RP@)&9U;&Q.86UE*3L*
M("`@("`@("!]"@H@("`@("`@("\O(%1/1$\Z(&%D9"!O<'1I;VYS(&9O<B`D
M:'(@;W!T:6]N<R`M(&AO=V5V97(@=&AE<V4@;6%Y(&YO="!B90H@("`@("`@
M("\O(&-O;7!A=&EB;&4@=VET:"!S;VUE(&1I9F9S+@H@("`@("`@("1C;VUM
M86YD(#T@)')E<"T^9V5T4&%T:"@G<F-S9&EF9B<I("X@(B`D;W!T:6]N<R`M
M<B1R978Q("UR)')E=C(@7"(B("X@97-C87!E<VAE;&QC;60H)&9U;&Q.86UE
M*2`N("<B(#(^)C$G.PH@("`@("`@(&EF("A60U]724Y$3U=3*2!["B`@("`@
M("`@("`@("1C;VUM86YD("X]("<@/"`B)R`N(%]?1DE,15]?("X@)R(G.PH@
M("`@("`@('T*"B`@("`@("`@97AE8R@D8V]M;6%N9"P@)&1I9F8L("1R971V
M86PI.PH@("`@("`@(')E='5R;B`H)')E='9A;"`^(#`I(#\@)&1I9F8@.B!A
M<G)A>2@I.PH@("`@?0H*?0H*+RHJ"B`J(%9#7V-V<R!D:7)E8W1O<GD@8VQA
M<W,N"B`J"B`J($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@
M/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#
M7T1I<F5C=&]R>5]C=G,@>PH*("`@('9A<B`D<F5P.PH@("`@=F%R("1D:7).
M86UE.PH@("`@=F%R("1F:6QE<SL*("`@('9A<B`D871T:6-&:6QE<SL*("`@
M('9A<B`D;65R9V5D1FEL97,["B`@("!V87(@)&1I<G,["B`@("!V87(@)'!A
M<F5N=#L*("`@('9A<B`D;6]D=6QE3F%M93L*("`@('9A<B`D<V]R=$1I<CL*
M"B`@("`O*BH*("`@("`J($-R96%T97,@82!#5E,@1&ER96-T;W)Y(&]B:F5C
M="!T;R!S=&]R92!I;F9O<FUA=&EO;@H@("`@("H@86)O=70@=&AE(&9I;&5S
M(&EN(&$@<VEN9VQE(&1I<F5C=&]R>2!I;B!T:&4@<F5P;W-I=&]R>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@5D-?8W9S("1R97`@("`@("`@("`@($$@<F5P
M;W-I=&]R>2!O8FIE8W0*("`@("`J($!P87)A;2!S=')I;F<@)&1N("`@("`@
M("`@("`@4&%T:"!T;R!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M(%9#
M7T1I<F5C=&]R>5]C=G,@)'!N("!4:&4@<&%R96YT(%9#7T1I<F5C=&]R>2!T
M;R!T:&ES(&]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?1&ER96-T;W)Y
M7V-V<R@D<F5P+"`D9&XL("1P;B`]("<G*0H@("`@>PH@("`@("`@("1T:&ES
M+3YR97`@/2`F)')E<#L*("`@("`@("`D=&AI<RT^<&%R96YT(#T@)B1P;CL*
M("`@("`@("`D=&AI<RT^;6]D=6QE3F%M92`]("1D;CL*("`@("`@("`D=&AI
M<RT^9&ER3F%M92`]("1R97`M/G-O=7)C97)O;W0H*2`N("(O)&1N(CL*("`@
M("`@("`D=&AI<RT^9FEL97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YD
M:7)S(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!F
M=6QL>2!Q=6%L:69I960@<&%T:&YA;64@=&\@=&AI<R!D:7)E8W1O<GD@=VET
M:"!N;PH@("`@("H@=')A:6QI;F<@+RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@4&%T:&YA;64@;V8@=&AI<R!D:7)E8W1O<GD*("`@("`J+PH@
M("`@9G5N8W1I;VX@<75E<GE$:7(H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9&ER3F%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F<75E<GE$:7),
M:7-T*"D*("`@('L*("`@("`@("!R97-E="@D=&AI<RT^9&ER<RD["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YD:7)S.PH@("`@?0H*("`@(&9U;F-T:6]N("9Q
M=65R>49I;&5,:7-T*"1S:&]W871T:6,@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H)'-H;W=A='1I8R`F)B!I<W-E="@D=&AI<RT^;65R9V5D1FEL97,I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;65R9V5D1FEL97,["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF:6QE
M<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!496QL('1H92!O
M8FIE8W0@=&\@;W!E;B!A;F0@8G)O=W-E(&ET<R!C=7)R96YT(&1I<F5C=&]R
M>2P@86YD"B`@("`@*B!R971R:65V92!A(&QI<W0@;V8@86QL('1H92!O8FIE
M8W1S(&EN('1H97)E+B`@270@=&AE;B!P;W!U;&%T97,*("`@("`J('1H92!F
M:6QE+V1I<F5C=&]R>2!S=&%C:R!A;F0@;6%K97,@:70@879A:6QA8FQE(&9O
M<B!R971R:65V86PN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B
M:F5C="`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@86X@97)R;W(L('1R=64@;VX@
M<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8G)O=W-E1&ER*"1C86-H
M92`](&YU;&PL("1Q=6EC:VQO9R`]('1R=64L("1S:&]W871T:6,@/2!F86QS
M92D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@87)E('1R>6EN9R!T
M;R!L:7-T(&$@9&ER96-T;W)Y("HO"B`@("`@("`@:68@*"%`:7-?9&ER*"1T
M:&ES+3YD:7).86UE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G56YA8FQE('1O(&9I;F0@9&ER96-T;W)Y("<@+B`D=&AI<RT^
M9&ER3F%M92D["B`@("`@("`@?0H*("`@("`@("`O*B!/<&5N('1H92!D:7)E
M8W1O<GD@9F]R(')E861I;F<@:71S(&-O;G1E;G1S("HO"B`@("`@("`@:68@
M*"$H)$1)4B`]($!O<&5N9&ER*"1T:&ES+3YD:7).86UE*2DI('L*("`@("`@
M("`@("`@)&5R<FUS9R`]("@A96UP='DH)'!H<%]E<G)O<FUS9RDI(#\@)'!H
M<%]E<G)O<FUS9R`Z("=097)M:7-S:6]N(&1E;FEE9"<["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)M<V<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0W)E871E('1W;R!A<G)A>7,@+2!O;F4@;V8@86QL('1H
M92!F:6QE<RP@86YD('1H92!O=&AE<B!O9@H@("`@("`@("`J(&%L;"!T:&4@
M9&ER96-T;W)I97,N("HO"B`@("`@("`@=VAI;&4@*"@D;F%M92`](')E861D
M:7(H)$1)4BDI("$]/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H)&YA;64@
M/3T@)RXG('Q\("1N86UE(#T]("<N+B<I('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<&%T:"`]("1T
M:&ES+3YD:7).86UE("X@)R\G("X@)&YA;64["B`@("`@("`@("`@(&EF("A`
M:7-?9&ER*"1P871H*2D@>PH@("`@("`@("`@("`@("`@+RH@4VMI<"!!='1I
M8R!D:7)E8W1O<GDN("HO"B`@("`@("`@("`@("`@("!I9B`H)&YA;64@(3T@
M)T%T=&EC)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD:7)S6UT@
M/2`D;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M:68@*$!I<U]F:6QE*"1P871H*2`F)B!S=6)S='(H)&YA;64L("TR*2`]/2`G
M+'8G*2!["B`@("`@("`@("`@("`@("`O*B!3<&%W;B!A(&YE=R!F:6QE(&]B
M:F5C="!T;R!R97!R97-E;G0@=&AI<R!F:6QE+B`J+PH@("`@("`@("`@("`@
M("`@)&9L(#T@)B1T:&ES+3YR97`M/F=E=$9I;&5/8FIE8W0H<W5B<W1R*"1P
M871H+"!S=')L96XH)'1H:7,M/G)E<"T^<V]U<F-E<F]O="@I*2P@+3(I+"`D
M8V%C:&4L("1Q=6EC:VQO9RD["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D
M9FPL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&9L.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^9FEL97-;72`]("8D9FP["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-L;W-E
M('1H92!F:6QE:&%N9&QE.R!W92=V92!N;W<@9V]T(&$@;&ES="!O9B!D:7)S
M(&%N9`H@("`@("`@("`J(&9I;&5S+B`J+PH@("`@("`@(&-L;W-E9&ER*"1$
M25(I.PH*("`@("`@("`O*B!)9B!W92!W86YT('1O(&UE<F=E('1H92!A='1I
M8RP@861D(&ET(&EN(&AE<F4N("HO"B`@("`@("`@:68@*"1S:&]W871T:6,I
M('L*("`@("`@("`@("`@)&%T=&EC1&ER(#T@)FYE=R!60U]$:7)E8W1O<GE?
M8W9S*"1T:&ES+3YR97`L("1T:&ES+3YM;V1U;&5.86UE("X@)R]!='1I8R<L
M("1T:&ES*3L*("`@("`@("`@("`@:68@*"1A='1I8T1I<BT^8G)O=W-E1&ER
M*"1C86-H92P@)'%U:6-K;&]G*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^871T:6-&:6QE<R`]("8D871T:6-$:7(M/G%U97)Y1FEL94QI<W0H
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YM97)G961&:6QE<R`](&%R<F%Y
M7VUE<F=E*"1T:&ES+3YF:6QE<RP@)'1H:7,M/F%T=&EC1FEL97,I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-O<G0@=&AE(&-O;G1E;G1S(&]F('1H92!D
M:7)E8W1O<GD@:6X@82!G:79E;B!F87-H:6]N(&%N9`H@("`@("H@;W)D97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AO=R`@3V8@=&AE(&9O
M<FT@5D-?4T]25%\J('=H97)E("H@8V%N(&)E.@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@3D].12P@3D%-12P@04=%+"!2158@9F]R('-O<G1I;F<@
M8GD@;F%M92P@86=E(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!R
M979I<VEO;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7(@($]F('1H92!F
M;W)M(%9#7U-/4E1?*B!W:&5R92`J(&-A;B!B93H*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@($%30T5.1$E.1RP@1$530T5.1$E.1R!F;W(@=&AE(&]R
M9&5R(&]F('1H92!S;W)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L>5-O
M<G0H)&AO=R`](%9#7U-/4E1?3D].12P@)&1I<B`](%9#7U-/4E1?05-#14Y$
M24Y'*0H@("`@>PH@("`@("`@("\O($%L=V%Y<R!S;W)T(&1I<F5C=&]R:65S
M(&)Y(&YA;64N"B`@("`@("`@;F%T8V%S97-O<G0H)'1H:7,M/F1I<G,I.PH*
M("`@("`@("`D=&AI<RT^9&]&:6QE4V]R="@D=&AI<RT^9FEL97,L("1H;W<L
M("1D:7(I.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^871T:6-&:6QE<RDI
M('L*("`@("`@("`@("`@)'1H:7,M/F1O1FEL95-O<G0H)'1H:7,M/F%T=&EC
M1FEL97,L("1H;W<L("1D:7(I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/FUE<F=E9$9I;&5S*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M9&]&:6QE4V]R="@D=&AI<RT^;65R9V5D1FEL97,L("1H;W<L("1D:7(I.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!D;T9I;&53;W)T*"8D9FEL
M94QI<W0L("1H;W<@/2!60U]33U)47TY/3D4L("1D:7(@/2!60U]33U)47T%3
M0T5.1$E.1RD*("`@('L*("`@("`@("`D=&AI<RT^<V]R=$1I<B`]("1D:7([
M"@H@("`@("`@('-W:71C:"`H)&AO=RD@>PH@("`@("`@(&-A<V4@5D-?4T]2
M5%]!1T4Z"B`@("`@("`@("`@('5S;W)T*"1F:6QE3&ES="P@87)R87DH)'1H
M:7,L("=F:6QE06=E4V]R="<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@5D-?4T]25%].04U%.@H@("`@("`@("`@("!U<V]R="@D9FEL
M94QI<W0L(&%R<F%Y*"1T:&ES+"`G9FEL94YA;653;W)T)RDI.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)47T%55$A/4CH*("`@
M("`@("`@("`@=7-O<G0H)&9I;&5,:7-T+"!A<G)A>2@D=&AI<RP@)V9I;&5!
M=71H;W)3;W)T)RDI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92!60U]33U)47U)%5CH*("`@("`@("`@("`@=7-O<G0H)&9I;&5,:7-T+"!A
M<G)A>2@D=&AI<RP@)V9I;&529793;W)T)RDI.PH@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!]"@H@("`@("`@('5N<V5T*"1T:&ES+3YS;W)T1&ER*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@9G5N8W1I;VX@9F]R(&9I;&4@
M86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE06=E4V]R="@D82P@)&(I
M"B`@("!["B`@("`@("`@)&%A(#T@)&$M/G%U97)Y3&%S=$QO9R@I.PH@("`@
M("`@("1B8B`]("1B+3YQ=65R>4QA<W1,;V<H*3L*("`@("`@("!I9B`H)&%A
M+3YQ=65R>41A=&4H*2`]/2`D8F(M/G%U97)Y1&%T92@I*2!["B`@("`@("`@
M("`@(')E='5R;B`P.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^<V]R=$1I
M<B`]/2!60U]33U)47T%30T5.1$E.1RD@>PH@("`@("`@("`@("!R971U<FX@
M*"1A82T^<75E<GE$871E*"D@/"`D8F(M/G%U97)Y1&%T92@I*2`_(#$@.B`M
M,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@*"1B8BT^
M<75E<GE$871E*"D@/"`D86$M/G%U97)Y1&%T92@I*2`_(#$@.B`M,3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&9U;F-T:6]N(&)Y
M(&%U=&AO<B!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE075T:&]R
M4V]R="@D82P@)&(I"B`@("!["B`@("`@("`@)&%A(#T@)&$M/G%U97)Y3&%S
M=$QO9R@I.PH@("`@("`@("1B8B`]("1B+3YQ=65R>4QA<W1,;V<H*3L*("`@
M("`@("!I9B`H)&%A+3YQ=65R>4%U=&AO<B@I(#T]("1B8BT^<75E<GE!=71H
M;W(H*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/G-O<G1$:7(@/3T@5D-?4T]25%]!4T-%3D1)3D<I('L*("`@
M("`@("`@("`@<F5T=7)N("@D86$M/G%U97)Y075T:&]R*"D@/B`D8F(M/G%U
M97)Y075T:&]R*"DI(#\@,2`Z("TQ.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`H)&)B+3YQ=65R>4%U=&AO<B@I(#X@)&%A+3YQ=65R
M>4%U=&AO<B@I*2`_(#$@.B`M,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3;W)T(&9U;F-T:6]N(&9O<B!F:6QE;F%M92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9FEL94YA;653;W)T*"1A+"`D8BD*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/G-O<G1$:7(@/3T@5D-?4T]25%]!4T-%3D1)3D<I('L*
M("`@("`@("`@("`@<F5T=7)N('-T<F-A<V5C;7`H)&$M/FYA;64L("1B+3YN
M86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@<W1R
M8V%S96-M<"@D8BT^;F%M92P@)&$M/FYA;64I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%-O<G0@9G5N8W1I;VX@9F]R(')E=FES:6]N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!F:6QE4F5V4V]R="@D82P@)&(I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3YS;W)T1&ER(#T](%9#7U-/4E1?05-#14Y$
M24Y'*2!["B`@("`@("`@("`@(')E='5R;B!60U]2979I<VEO;CHZ8VUP*"1A
M+3YQ=65R>4AE860H*2P@)&(M/G%U97)Y2&5A9"@I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@5D-?4F5V:7-I;VXZ.F-M<"@D8BT^
M<75E<GE(96%D*"DL("1A+3YQ=65R>4AE860H*2D["B`@("`@("`@?0H@("`@
M?0H*?0H*+RHJ"B`J(%9#7V-V<R!F:6QE(&-L87-S+@H@*@H@*B!#;W!Y<FEG
M:'0@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J
M($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]&:6QE7V-V<R!E>'1E;F1S
M(%9#7T9I;&4@>PH*("`@("\J*@H@("`@("H@0W)E871E(&$@<F5P;W-I=&]R
M>2!F:6QE(&]B:F5C="P@86YD(&=I=F4@:70@:6YF;W)M871I;VX@86)O=70*
M("`@("`J('=H870@:71S('!A<F5N="!D:7)E8W1O<GD@86YD(')E<&]S:71O
M<GD@;V)J96-T<R!A<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FP@($9U;&P@<&%T:"!T;R!T:&ES(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%9#7T9I;&5?8W9S*"1F;"P@)'%U:6-K;&]G(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&9L("X]("<L=B<["B`@("`@("`@)'1H:7,M/FYA;64@/2!B
M87-E;F%M92@D9FPI.PH@("`@("`@("1T:&ES+3YD:7(@/2!D:7)N86UE*"1F
M;"D["B`@("`@("`@)'1H:7,M/FQO9W,@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3YQ=6EC:VQO9R`]("1Q=6EC:VQO9SL*("`@("`@("`D=&AI<RT^<F5V
M<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/F)R86YC:&5S(#T@87)R87DH
M*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T1FEL94]B:F5C="@F)')E<"P@
M)&9I;&5N86UE+"`D8V%C:&4@/2!N=6QL+"`D<75I8VML;V<@/2!F86QS92D*
M("`@('L*("`@("`@("`O*BH*("`@("`@("`@*B!4:&4@=F5R<VEO;B!O9B!T
M:&4@8V%C:&5D(&1A=&$N($EN8W)E;65N="!T:&ES('=H96YE=F5R('1H90H@
M("`@("`@("`J(&EN=&5R;F%L('-T;W)A9V4@9F]R;6%T(&-H86YG97,L('-U
M8V@@=&AA="!W92!M=7-T"B`@("`@("`@("H@:6YV86QI9&%T92!P<FEO<B!C
M86-H960@9&%T82X*("`@("`@("`@*B\*("`@("`@("`D8V%C:&5697)S:6]N
M(#T@,CL*("`@("`@("`D8V%C:&5)9"`]("1R97`M/G-O=7)C97)O;W0H*2`N
M("=?;B<@+B`D9FEL96YA;64@+B`G7V8G("X@*&EN="DD<75I8VML;V<@+B`G
M7W8G("X@)&-A8VAE5F5R<VEO;CL*"B`@("`@("`@:68@*"1C86-H92`F)@H@
M("`@("`@("`@("`D8V%C:&4M/F5X:7-T<R@D8V%C:&5)9"P@=&EM92@I("T@
M0&9I;&5M=&EM92@D9FEL96YA;64@+B`G+'8G*2DI('L*("`@("`@("`@("`@
M)&9I;&5/8B`]('5N<V5R:6%L:7IE*"1C86-H92T^9V5T*"1C86-H94ED+"!T
M:6UE*"D@+2!`9FEL96UT:6UE*"1F:6QE;F%M92`N("<L=B<I*2D["B`@("`@
M("`@("`@("1F:6QE3V(M/G-E=%)E<&]S:71O<GDH)')E<"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&9I;&5/8B`]("9N97<@5D-?1FEL95]C
M=G,H)&9I;&5N86UE+"`D<75I8VML;V<I.PH@("`@("`@("`@("`D9FEL94]B
M+3YS971297!O<VET;W)Y*"1R97`I.PH@("`@("`@("`@("!I9B`H:7-?82@H
M)')E<W5L="`]("1F:6QE3V(M/F=E=$)R;W=S94EN9F\H*2DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1F:6QE3V(M/F%P<&QY4V]R="A60U]3
M3U)47T%'12D["@H@("`@("`@("`@("!I9B`H)&-A8VAE*2!["B`@("`@("`@
M("`@("`@("`D8V%C:&4M/G-E="@D8V%C:&5)9"P@<V5R:6%L:7IE*"1F:6QE
M3V(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1F:6QE3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)9B!T:&ES(&9I;&4@
M:7,@<')E<V5N="!I;B!A;B!!='1I8R!D:7)E8W1O<GDL('1H:7,@:6YD:6-A
M=&5S"B`@("`@*B!I="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@9FEL92!I<R!I;B!T:&4@071T:6,L(&%N9"!F86QS92!O=&AE
M<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@:7-!='1I8T9I;&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B!S=6)S='(H)'1H:7,M/F1I<BP@+34I(#T]("=!
M='1I8R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N86UE
M(&]F('1H92!C=7)R96YT(&9I;&4@87,@:6X@=&AE(')E<&]S:71O<GD*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1FEL96YA;64@*'=I=&AO=70@
M=&AE('!A=&@I"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y4F5P;W-I=&]R
M>4YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F%M93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@;F%M92!O9B!T:&4@8W5R<F5N
M="!F:6QE('=I=&AO=70@=&AE(')E<&]S:71O<GD*("`@("`J(&5X=&5N<VEO
M;G,@*'5S=6%L;'D@+'8I"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M($9I;&5N86UE('=I=&AO=70@<F5P;W-I=&]R>2!E>'1E;G-I;VX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<75E<GE.86UE*"D*("`@('L*("`@("`@("!R971U
M<FX@<')E9U]R97!L86-E*"<O+'8D+R<L("<G+"`D=&AI<RT^;F%M92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QA<W0@<F5V:7-I;VX@
M;V8@=&AE(&-U<G)E;G0@9FEL92!O;B!T:&4@2$5!1"!B<F%N8V@*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9WQO8FIE8W0@($QA<W0@<F5V:7-I;VX@
M;V8@=&AE(&-U<G)E;G0@9FEL92!O<B!014%27T5R<F]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('%U97)Y4F5V:7-I;VXH*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/G)E=G-;,%TI*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=.;R!R979I<VEO;G,G*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR979S6S!=.PH@("`@?0H*("`@(&9U;F-T:6]N
M('%U97)Y4')E=FEO=7-2979I<VEO;B@D<F5V*0H@("`@>PH@("`@("`@(')E
M='5R;B!60U]2979I<VEO;CHZ<')E=B@D<F5V*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@2$5!1"`H;6]S="!R96-E;G0I(')E=FES:6]N
M(&YU;6)E<B!F;W(@=&AI<R!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!(14%$(')E=FES:6]N(&YU;6)E<@H@("`@("HO"B`@("!F=6YC
M=&EO;B!Q=65R>4AE860H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M:&5A9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;&%S="!6
M0U]L;V<@;V)J96-T(&EN('1H92!F:6QE+@H@("`@("H*("`@("`J($!R971U
M<FX@5D-?;&]G(&]F('1H92!L87-T(&5N=')Y(&EN('1H92!F:6QE"B`@("`@
M*B\*("`@(&9U;F-T:6]N('%U97)Y3&%S=$QO9R@I"B`@("!["B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^<F5V<ULP72D@?'P@(6ES<V5T*"1T:&ES+3YL
M;V=S6R1T:&ES+3YR979S6S!=72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)TYO(')E=FES:6]N<R<I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)'1H:7,M/FQO9W-;)'1H:7,M/G)E=G-;,%U=.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V]R="!T:&4@;&ES="!O9B!60U]L;V<@;V)J
M96-T<R!T:&%T('1H:7,@9FEL92!C;VYT86EN<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D:&]W("!60U]33U)47U)%5B`H<V]R="!B>2!R979I
M<VEO;BDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!60U]33U)47TY!
M344@*'-O<G0@8GD@875T:&]R(&YA;64I+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@5D-?4T]25%]!1T4@*'-O<G0@8GD@8V]M;6ET(&1A=&4I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%P<&QY4V]R="@D:&]W(#T@5D-?4T]25%]2
M158I"B`@("!["B`@("`@("`@<W=I=&-H("@D:&]W*2!["B`@("`@("`@8V%S
M92!60U]33U)47TY!344Z"B`@("`@("`@("`@("1F=6YC(#T@)TYA;64G.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)47T%'13H*
M("`@("`@("`@("`@)&9U;F,@/2`G06=E)SL*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@5D-?4T]25%]2158Z"B`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@)&9U;F,@/2`G4F5V:7-I;VXG.PH@("`@("`@('T*"B`@
M("`@("`@=6%S;W)T*"1T:&ES+3YL;V=S+"!A<G)A>2@D=&AI<RP@(G-O<G1"
M>21F=6YC(BDI.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5&AE('-O<G1">2HH*2!F=6YC=&EO;G,@87)E(&EN=&5R;F%L
M;'D@=7-E9"!B>2!A<'!L>5-O<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-O
M<G1">5)E=FES:6]N*"1A+"`D8BD*("`@('L*("`@("`@("!R971U<FX@5D-?
M4F5V:7-I;VXZ.F-M<"@D8BT^<F5V+"`D82T^<F5V*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!S;W)T0GE!9V4H)&$L("1B*0H@("`@>PH@("`@("`@(')E='5R
M;B`D8BT^9&%T92`M("1A+3YD871E.PH@("`@?0H*("`@(&9U;F-T:6]N('-O
M<G1">4YA;64H)&$L("1B*0H@("`@>PH@("`@("`@(')E='5R;B!S=')C;7`H
M)&$M/F%U=&AO<BP@)&(M/F%U=&AO<BD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!0;W!U;&%T92!T:&4@;V)J96-T('=I=&@@:6YF;W)M871I;VX@86)O=70@
M=&AE(')E=FES:6]N<R!L;V=S(&%N9"!D871E<PH@("`@("H@;V8@=&AE(&9I
M;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C="`@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(L(&]R('1R=64@;VX@<W5C8V5S<PH@
M("`@("HO"B`@("!F=6YC=&EO;B!G971"<F]W<V5);F9O*"D*("`@('L*("`@
M("`@("`O*B!#:&5C:R!T:&%T('=E(&%R92!A8W1U86QL>2!I;B!T:&4@9FEL
M97-Y<W1E;2X@*B\*("`@("`@("`D9FEL92`]("1T:&ES+3YQ=65R>49U;&Q0
M871H*"D["B`@("`@("`@:68@*"%I<U]F:6QE*"1F:6QE*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1FEL92!.;W0@1F]U;F0Z
M("<@+B`D9FEL92D["B`@("`@("`@?0H*("`@("`@("`O*B!#86QL('1H92!2
M0U,@<FQO9R!C;VUM86YD('1O(')E=')I979E('1H92!F:6QE"B`@("`@("`@
M("H@:6YF;W)M871I;VXN("HO"B`@("`@("`@)&9L86<@/2`D=&AI<RT^<75I
M8VML;V<@/R`G("UR("<@.B`G("<["B`@("`@("`@)%$@/2!60U]724Y$3U=3
M(#\@)R(G(#H@(B<B(#L*"B`@("`@("`@)&-M9"`]("1T:&ES+3YR97`M/F=E
M=%!A=&@H)W)L;V<G*2`N("1F;&%G("X@)%$@+B`D9FEL92`N("11.PH@("`@
M("`@(&5X96,H)&-M9"P@)')E='5R;E]A<G)A>2P@)')E='9A;"D["@H@("`@
M("`@(&EF("@D<F5T=F%L*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=&86EL960@=&\@<W!A=VX@<FQO9R!T;R!R971R:65V92!F
M:6QE(&QO9R!I;F9O<FUA=&EO;B!F;W(@)R`N("1F:6QE*3L*("`@("`@("!]
M"@H@("`@("`@("1A8V-U;2`](&%R<F%Y*"D["B`@("`@("`@)'-Y;7)E=B`]
M(&%R<F%Y*"D["B`@("`@("`@)')E=G-Y;2`](&%R<F%Y*"D["B`@("`@("`@
M)'-T871E(#T@)VEN:70G.PH@("`@("`@(&9O<F5A8V@@*"1R971U<FY?87)R
M87D@87,@)&QI;F4I('L*("`@("`@("`@("`@<W=I=&-H("@D<W1A=&4I('L*
M("`@("`@("`@("`@8V%S92`G:6YI="<Z"B`@("`@("`@("`@("`@("!I9B`H
M(7-T<FYC;7`H)VAE860Z("<L("1L:6YE+"`V*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YH96%D(#T@<W5B<W1R*"1L:6YE+"`V*3L*("`@("`@
M("`@("`@("`@('T@96QS96EF("@A<W1R;F-M<"@G8G)A;F-H.B<L("1L:6YE
M+"`W*2D@>PH@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=R978G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=R978G.@H@("`@("`@("`@("`@("`@:68@*"%S=')N
M8VUP*"<M+2TM+2TM+2TM)RP@)&QI;F4L(#$P*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1S=&%T92`]("=I;F9O)SL*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<WEM<F5V(#T@)'-Y;7)E=CL*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<F5V<WEM(#T@)')E=G-Y;3L*("`@("`@("`@("`@("`@('T@96QS
M96EF("AP<F5G7VUA=&-H*"(O7EQS*RA;7CI=*RDZ7',K*%M<9%PN72LI+R(L
M("1L:6YE+"`D<F5G<RDI('L*("`@("`@("`@("`@("`@("`@("`O+R!#:&5C
M:R!T;R!S964@:68@=&AI<R!I<R!A(&)R86YC:`H@("`@("`@("`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O7BA<9"LH7"Y<9"LI*RE<+C!<+BA<9"LI
M)"\G+"1R96=S6S)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8G)A
M;F-H4F5V(#T@5D-?4F5V:7-I;VXZ.G1O0G)A;F-H*"1R96=S6S)=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^8G)A;F-H
M97-;)&)R86YC:%)E=ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^8G)A;F-H97-;)&)R86YC:%)E=ET@/2`D<F5G<ULQ73L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1S>6UR979;)')E9W-;
M,5U=(#T@)')E9W-;,ET["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AE
M;7!T>2@D<F5V<WEM6R1R96=S6S)=72DI("1R979S>6U;)')E9W-;,EU=/6%R
M<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("1R979S>6U;)')E9W-;
M,EU=6UT@/2`D<F5G<ULQ73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)VEN9F\G.@H@("`@("`@("`@("`@("`@:68@*'-T<FYC;7`H
M)ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2<L("1L:6YE+"`S,"D@
M)B8*("`@("`@("`@("`@("`@("`@("!S=')C;7`H)RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TG+"`D;&EN92DI('L*("`@("`@("`@("`@("`@("`@
M("`D86-C=6U;72`]("1L:6YE.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*&-O=6YT*"1A8V-U;2DI('L*("`@("`@("`@("`@("`@("`@("`O+R!S<&%W
M;B!A(&YE=R!60U]L;V<@;V)J96-T(&%N9"!A9&0@:70@=&\@=&AE(&QO9W,@
M:&%S:`H@("`@("`@("`@("`@("`@("`@("1L;V<@/2`F;F5W(%9#7TQO9U]C
M=G,H)'1H:7,I.PH@("`@("`@("`@("`@("`@("`@("1E<G(@/2`D;&]G+3YP
M<F]C97-S3&]G*"1A8V-U;2D["B`@("`@("`@("`@("`@("`@("`@+R\@5$]$
M3SH@97)R;W(@8VAE8VMS("T@879S;0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V=S6R1L;V<M/G%U97)Y4F5V:7-I;VXH*5T@/2`F)&QO9SL*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<F5V<UM=(#T@)&QO9RT^<75E<GE2
M979I<VEO;B@I.PH@("`@("`@("`@("`@("`@("`@("1A8V-U;2`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9U;&QY('%U86QI
M9FEE9"!F:6QE;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($9U;&QY('%U86QI9FEE9"!F:6QE;F%M92!O9B!T:&ES(&]B:F5C
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>49U;&Q0871H*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/F1I<B`N("<O)R`N("1T:&ES+3YN86UE
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!N86UE(&]F('1H
M:7,@9FEL92!R96QA=&EV92!T;R!I=',@<V]U<F-E<F]O="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@4&%T:&YA;64@<F5L871I=F4@=&\@=&AE
M('-O=7)C97)O;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y36]D=6QE
M4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G?%XG
M+B`D=&AI<RT^<F5P+3YS;W5R8V5R;V]T*"D@+B`G+S\H+BHI+'8D?"<L("=<
M,2<L("1T:&ES+3YQ=65R>49U;&Q0871H*"DI.PH@("`@?0H*?0H*+RHJ"B`J
M(%9#7V-V<R!L;V<@8VQA<W,N"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V
M87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC
M;&%S<R!60U],;V=?8W9S('L*"B`@("!V87(@)')E<#L*("`@('9A<B`D9FEL
M93L*("`@('9A<B`D=&%G<SL*("`@('9A<B`D<F5V.PH@("`@=F%R("1D871E
M.PH@("`@=F%R("1L;V<["B`@("!V87(@)&%U=&AO<CL*("`@('9A<B`D<W1A
M=&4["B`@("!V87(@)&QI;F5S.PH@("`@=F%R("1B<F%N8VAE<SL*"B`@("`O
M*BH*("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7TQO9U]C=G,H)B1F
M;"D*("`@('L*("`@("`@("`D=&AI<RT^9FEL92`]("8D9FP["B`@("`@("`@
M)'1H:7,M/F)R86YC:&5S(#T@87)R87DH*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!P<F]C97-S3&]G*"1R87<I"B`@("!["B`@("`@("`@+RH@26YI=&EA;&ES
M92!A('-I;7!L92!S=&%T92!M86-H:6YE('1O('!A<G-E('1H92!O=71P=70@
M;V8@<FQO9R`J+PH@("`@("`@("1S=&%T92`]("=I;FET)SL*("`@("`@("!W
M:&EL92`H(65M<'1Y*"1R87<I("8F("1S=&%T92`A/2`G9&]N92<I('L*("`@
M("`@("`@("`@<W=I=&-H("@D<W1A=&4I('L*("`@("`@("`@("`@+RH@1F]U
M;F0@9FEL96YA;64L(&YO=R!L;V]K:6YG(&9O<B!T:&4@<F5V:7-I;VX@;G5M
M8F5R("HO"B`@("`@("`@("`@(&-A<V4@)VEN:70G.@H@("`@("`@("`@("`@
M("`@)&QI;F4@/2!A<G)A>5]S:&EF="@D<F%W*3L*("`@("`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"(O<F5V:7-I;VX@*"XK*20O(BP@)&QI;F4L("1P
M87)T<RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<F5V(#T@)'!A
M<G1S6S%=.PH@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=D871E)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@+RH@1F]U;F0@<F5V:7-I;VX@86YD(&9I;&5N86UE+"!N;W<@
M;&]O:VEN9R!F;W(@9&%T92`J+PH@("`@("`@("`@("!C87-E("=D871E)SH*
M("`@("`@("`@("`@("`@("1L:6YE(#T@87)R87E?<VAI9G0H)')A=RD["B`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B?%YD871E.EQS*RA<9"LI
M6RTO72A<9"LI6RTO72A<9"LI7',K*%QD*RDZ*%QD*RDZ*%QD*RDN*C\[7',K
M875T:&]R.EQS*R@N*RD[7',K<W1A=&4Z7',K*%Q3*RD[*%QS*VQI;F5S.EQS
M*RA;,"TY7',K+5TK*2D_?"(L("1L:6YE+"`D<&%R=',I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F1A=&4@/2!G;6UK=&EM92@D<&%R='-;-%TL
M("1P87)T<ULU72P@)'!A<G1S6S9=+"`D<&%R='-;,ETL("1P87)T<ULS72P@
M)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^875T:&]R
M(#T@)'!A<G1S6S==.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS=&%T
M92`]("1P87)T<ULX73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&EN
M97,@/2!I<W-E="@D<&%R='-;,3!=*2`_("1P87)T<ULQ,%T@.B`G)SL*("`@
M("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G8G)A;F-H97,G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`O*B!,;V]K(&9O<B!A(&)R86YC:"!P;VEN="!H97)E("T@9F]R;6%T(&ES
M("=B<F%N8VAE<SH@('@N>2YZ.R`@82YB+F,[)R`J+PH@("`@("`@("`@("!C
M87-E("=B<F%N8VAE<R<Z"B`@("`@("`@("`@("`@("`O*B!)9B!W92!F:6YD
M(&$@8G)A;F-H('1A9RP@<')O8V5S<R!A;F0@<&]P(&ET+`H@("`@("`@("`@
M("`@("`@("`@;W1H97)W:7-E(&QE879E(&EN<'5T('-T<F5A;2!U;G1O=6-H
M960@*B\*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)')A=RD@)B8@<')E
M9U]M871C:"@B+UYB<F%N8VAE<SI<<RLH+BHI+R(L("1R87=;,%TL("1B<BDI
M('L*("`@("`@("`@("`@("`@("`@("`O*B!'970@=&AE(&QI<W0@;V8@8G)A
M;F-H97,@9G)O;2!T:&4@<W1R:6YG+"!A;F0*("`@("`@("`@("`@("`@("`@
M("`@*B!P=7-H('9A;&ED(')E=FES:6]N<R!I;G1O('1H92!B<F%N8VAE<R!A
M<G)A>2`J+PH@("`@("`@("`@("`@("`@("`@("1B<G,@/2!P<F5G7W-P;&ET
M*"<O.UQS*B\G+"`D8G);,5TI.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1B<G,@87,@)&)R<&]I;G0I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*%9#7U)E=FES:6]N.CIV86QI9"@D8G)P;VEN="DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YB<F%N8VAE<UM=(#T@)&)R
M<&]I;G0["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)')A
M=RD["@H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&%T
M92`]("=D;VYE)SL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!!<W-U;64@=&AE(')E<W0@;V8@
M=&AE(&QI;F5S(&%R92!T:&4@;&]G(&UE<W-A9V4@*B\*("`@("`@("`D=&AI
M<RT^;&]G(#T@:6UP;&]D92@B7&XB+"`D<F%W*3L*("`@("`@("`D=&AI<RT^
M=&%G<R`]($`D=&AI<RT^9FEL92T^<F5V<WEM6R1T:&ES+3YR979=.PH@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^=&%G<RDI('L*("`@("`@("`@("`@)'1H
M:7,M/G1A9W,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!Q=65R>41A=&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M9&%T93L*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>5)E=FES:6]N*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/G)E=CL*("`@('T*"B`@("!F=6YC
M=&EO;B!Q=65R>4%U=&AO<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YA=71H;W(["B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE,;V<H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]G.PH@("`@?0H*("`@(&9U;F-T
M:6]N('%U97)Y0VAA;F=E9$QI;F5S*"D*("`@('L*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/FQI;F5S*2`_("@D=&AI<RT^;&EN97,I(#H@)R<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A(&)R86YC:"!R979I<VEO;B!N
M=6UB97(L('1H:7,@9G5N8W1I;VX@<F5M87!S(&ET"B`@("`@*B!A8V-O<F1I
M;F=L>2P@86YD('!E<F9O<FUS(&$@;&]O:W5P(&]N('1H92!F:6QE(&]B:F5C
M="!T;PH@("`@("H@<F5T=7)N('1H92!S>6UB;VQI8R!N86UE*',I(&]F('1H
M870@8G)A;F-H(&EN('1H92!T<F5E+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($AA<V@@;V8@<WEM8F]L:6,@;F%M97,@/3X@8G)A;F-H(&YU;6)E
M<G,*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE3>6UB;VQI8T)R86YC:&5S
M*"D*("`@('L*("`@("`@("`D<WEM0G)A;F-H97,@/2!A<G)A>2@I.PH@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3YB<F%N8VAE<R!A<R`D8G)A;F-H*2!["B`@
M("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)RXG+"`D8G)A;F-H*3L*("`@
M("`@("`@("`@)&QA<W0@/2!A<G)A>5]P;W`H)'!A<G1S*3L*("`@("`@("`@
M("`@)'!A<G1S6UT@/2`G,"<["B`@("`@("`@("`@("1P87)T<UM=(#T@)&QA
M<W0["B`@("`@("`@("`@("1R978@/2!I;7!L;V1E*"<N)RP@)'!A<G1S*3L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YF:6QE+3YB<F%N8VAE<ULD
M8G)A;F-H72DI('L*("`@("`@("`@("`@("`@("1S>6U"<F%N8VAE<ULD=&AI
M<RT^9FEL92T^8G)A;F-H97-;)&)R86YC:%U=(#T@)&)R86YC:#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'-Y;4)R86YC:&5S
M.PH@("`@?0H*?0H*+RHJ"B`J(%9#7V-V<R!0871C:'-E="!C;&%S<RX*("H*
M("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN
M;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R
M96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?4&%T8VAS
M971?8W9S('L*"B`@("!V87(@)%]R97`["B`@("!V87(@)%]D:7(["B`@("!V
M87(@)%]N86UE.PH@("`@=F%R("1?<&%T8VAS971S(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($-R96%T92!A('!A=&-H<V5T(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("!4:&4@9FEL96YA;64@=&\@
M9V5T('!A=&-H<V5T<R!F;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7U!A
M=&-H<V5T7V-V<R@D9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@
M/2!B87-E;F%M92@D9FEL92D["B`@("`@("`@)'1H:7,M/E]D:7(@/2!D:7)N
M86UE*"1F:6QE*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4&%T8VAS971/
M8FIE8W0H)B1R97`L("1F:6QE;F%M92P@)&-A8VAE(#T@;G5L;"D*("`@('L*
M("`@("`@("`O*B!4:&4@=F5R<VEO;B!O9B!T:&4@8V%C:&5D(&1A=&$N($EN
M8W)E;65N="!T:&ES('=H96YE=F5R('1H90H@("`@("`@("`J(&EN=&5R;F%L
M('-T;W)A9V4@9F]R;6%T(&-H86YG97,L('-U8V@@=&AA="!W92!M=7-T"B`@
M("`@("`@("H@:6YV86QI9&%T92!P<FEO<B!C86-H960@9&%T82X@*B\*("`@
M("`@("`D8V%C:&5697)S:6]N(#T@,3L*("`@("`@("`D8V%C:&5)9"`]("1R
M97`M/G-O=7)C97)O;W0H*2`N("=?;B<@+B`D9FEL96YA;64@+B`G7V9?=B<@
M+B`D8V%C:&5697)S:6]N.PH*("`@("`@("!I9B`H)&-A8VAE("8F"B`@("`@
M("`@("`@("1C86-H92T^97AI<W1S*"1C86-H94ED+"!T:6UE*"D@+2!`9FEL
M96UT:6UE*"1F:6QE;F%M92`N("<L=B<I*2D@>PH@("`@("`@("`@("`D<'-/
M8B`]('5N<V5R:6%L:7IE*"1C86-H92T^9V5T*"1C86-H94ED+"!T:6UE*"D@
M+2!`9FEL96UT:6UE*"1F:6QE;F%M92`N("<L=B<I*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'!S3V(@/2`F;F5W(%9#7U!A=&-H<V5T7V-V
M<R@D9FEL96YA;64I.PH*("`@("`@("`@("`@:68@*"1C86-H92D@>PH@("`@
M("`@("`@("`@("`@)&-A8VAE+3YS970H)&-A8VAE260L('-E<FEA;&EZ92@D
M<'-/8BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<'-/
M8BT^7W)E<"`]("8D<F5P.PH*("`@("`@("!I9B`H:7-?82@H)')E<W5L="`]
M("1P<T]B+3YG9710871C:'-E=',H)')E<"DI+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1P<T]B.PH@("`@?0H*("`@("\J*@H@("`@("H@4&]P=6QA
M=&4@=&AE(&]B:F5C="!W:71H(&EN9F]R;6%T:6]N(&%B;W5T('1H92!P871C
M:'-E=',@=&AA=`H@("`@("H@=&AI<R!F:6QE(&ES(&EN=F]L=F5D(&EN+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E<&]S:71O<GD@(%1H92!F
M=6QL(')E<&]S:71O<GD@;&]C871I;VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N?&]B:F5C="`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(L
M(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&%T8VAS971S*"1R97!O<VET;W)Y*0H@("`@>PH@("`@("`@("\J($-H96-K
M('1H870@=V4@87)E(&%C='5A;&QY(&EN('1H92!F:6QE<WES=&5M+B`J+PH@
M("`@("`@(&EF("@A:7-?9FEL92@D=&AI<RT^9V5T1G5L;%!A=&@H*2`N("<L
M=B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&
M:6QE($YO="!&;W5N9"<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0V%L;"!C
M=G-P<R!T;R!R971R:65V92!A;&P@<&%T8VAS971S(&9O<B!T:&ES(&9I;&4N
M("HO"B`@("`@("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B.PH*("`@
M("`@("`D8W9S<'-?:&]M92`]("1R97!O<VET;W)Y+3YG9710871H*"=C=G-P
M<U]H;VUE)RD["B`@("`@("`@)$A/344@/2`A96UP='DH)&-V<W!S7VAO;64I
M(#\*("`@("`@("`@("`@)TA/344])R`N("1C=G-P<U]H;VUE("X@)R`G(#H*
M("`@("`@("`@("`@)R<["@H@("`@("`@("1C;60@/2`D2$]-12`N("1R97!O
M<VET;W)Y+3YG9710871H*"=C=G-P<R<I("X@)R`M=2`M+6-V<RUD:7)E8W0@
M+2UR;V]T("<@+B`D42`N("1R97!O<VET;W)Y+3YS;W5R8V5R;V]T*"D@+B`D
M42`N("<@+68@)R`N("11("X@)'1H:7,M/E]N86UE("X@)%$@+B`G("<@+B`D
M42`N("1T:&ES+3Y?9&ER("X@)%$["B`@("`@("`@97AE8R@D8VUD+"`D<F5T
M=7)N7V%R<F%Y+"`D<F5T=F%L*3L*("`@("`@("!I9B`H)')E='9A;"D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O
M('-P87=N(&-V<W!S('1O(')E=')I979E('!A=&-H<V5T(&EN9F]R;6%T:6]N
M)RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<R`](&%R
M<F%Y*"D["B`@("`@("`@)'-T871E(#T@)V)E9VEN)SL*("`@("`@("!F;W)E
M86-H("@D<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2!["B`@("`@("`@("`@("1L
M:6YE(#T@=')I;2@D;&EN92D["B`@("`@("`@("`@(&EF("@D;&EN92`]/2`G
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM)RD@>PH@("`@("`@("`@("`@("`@)'-T
M871E(#T@)V)E9VEN)SL*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!S=VET8V@@*"1S=&%T92D@>PH@("`@
M("`@("`@("!C87-E("=B96=I;B<Z"B`@("`@("`@("`@("`@("`D:60@/2!S
M=')?<F5P;&%C92@G4&%T8VA3970@)RP@)R<L("1L:6YE*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I9%T@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`@("`@)'-T871E(#T@)VEN9F\G.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=I;F9O)SH*("`@("`@("`@("`@
M("`@("1I;F9O(#T@97AP;&]D92@G.B<L("1L:6YE+"`R*3L*("`@("`@("`@
M("`@("`@('-W:71C:"`H)&EN9F];,%TI('L*("`@("`@("`@("`@("`@(&-A
M<V4@)T1A=&4G.@H@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"=\*%QD>S1]*2\H7&1[,GTI+RA<9'LR?2D@*%QD>S)]*3HH7&1[,GTI.BA<
M9'LR?2E\)RP@)&EN9F];,5TL("1D871E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=D871E)UT@/2!G;6UK
M=&EM92@D9&%T95LT72P@)&1A=&5;-5TL("1D871E6S9=+"`D9&%T95LR72P@
M)&1A=&5;,UTL("1D871E6S%=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`G075T:&]R)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A=&-H
M<V5T<ULD:61=6R=A=71H;W(G72`]('1R:6TH)&EN9F];,5TI.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)T)R
M86YC:"<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;
M)&ED75LG8G)A;F-H)UT@/2!T<FEM*"1I;F9O6S%=*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=486<G.@H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I9%U;)W1A
M9R==(#T@=')I;2@D:6YF;ULQ72D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G3&]G)SH*("`@("`@("`@("`@
M("`@("`@("`D<W1A=&4@/2`G;&]G)SL*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=L;V<G72`]("<G.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=L;V<G.@H@("`@("`@
M("`@("`@("`@:68@*"1L:6YE(#T]("=-96UB97)S.B<I('L*("`@("`@("`@
M("`@("`@("`@("`D<W1A=&4@/2`G;65M8F5R<R<["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P871C:'-E='-;)&ED75LG;&]G)UT@/2!T<FEM*"1T
M:&ES+3Y?<&%T8VAS971S6R1I9%U;)VQO9R==*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=M96UB97)S)UT@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=L;V<G72`N/2`D;&EN92`N
M(")<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)VUE;6)E<G,G.@H@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D;&EN92DI('L*("`@("`@("`@("`@("`@("`@("`D
M<&%R=',@/2!E>'!L;V1E*"<Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@
M("`@("1R979S(#T@97AP;&]D92@G+3XG+"`D<&%R='-;,5TI.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I9%U;)VUE;6)E<G,G
M75M=(#T@87)R87DH)V9I;&4G(#T^("1P87)T<ULP72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=F<F]M)R`]/B`D<F5V<ULP72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T;R<@/3X@)')E=G-;,5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!F=6QL>2!Q=6%L:69I960@9FEL96YA;64@;V8@=&AI<R!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($9U;&QY('%U86QI9FEE
M9"!F:6QE;F%M92!O9B!T:&ES(&]B:F5C=`H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971&=6QL4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&ER("X@)R\G("X@)'1H:7,M/E]N86UE.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]60R]R8W,N
M<&AP````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38R
M,S8`,3`T,3<S-C(W-S$`,#(P,#4P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!60U]R8W,@:6UP;&5M
M96YT871I;VXN"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F5F9B!38VAW
M96YT;F5R(#QJ969F<F5Y+G-C:'=E;G1N97)`;&UC;RYC;VT^"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U9#+U9#+W)C<RYP:'`L=B`Q+C,N."XU(#(P,#8O
M,#$O,#$@,C$Z,C@Z-#(@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($IE9F8@
M4V-H=V5N=&YE<B`\:F5F9G)E>2YS8VAW96YT;F5R0&QM8V\N8V]M/@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7W)C<R!E>'1E;F1S(%9#('L*"B`@
M("`O*BH*("`@("`J($-H96-K<R!A;B!20U,@9FEL92!I;B!W:71H(&$@<W!E
M8VEF:65D(&-H86YG92!L;V<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9FEL97!A=&@@("`@3&]C871I;VX@;V8@9FEL92!T;R!C:&5C:R!I;BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A9V4@("`@($QO9R!O9B!C:&%N
M9V5S('-I;F-E(&QA<W0@=F5R<VEO;BX*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97(@("`@("`@(%1H92!U<V5R(&YA;64@=&\@=7-E(&9O<B!T:&4@8VAE
M8VL@:6XN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;F5W0FEN87)Y("!$;V5S
M('1H92!C:&%N9V4@:6YV;VQV92!B:6YA<GD@9&%T83\*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9WQO8FIE8W0@(%1H92!N97<@<F5V:7-I;VX@;G5M
M8F5R(&]N('-U8V-E<W,L(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8VDH)&9I;&5P871H+"`D;65S<V%G92P@)'5S97(@/2!N
M=6QL+"`D;F5W0FEN87)Y(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1U
M<V5R*2!["B`@("`@("`@("`@('!U=&5N=B@G3$]'3D%-13TG("X@)'5S97(I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!U=&5N=B@G3$]'3D%-
M13UG=65S="<I.PH@("`@("`@('T*"B`@("`@("`@)%$@/2!60U]724Y$3U=3
M(#\@)R(G(#H@(B<B(#L*"B`@("`@("`@)&-I7V-M9"`]("1T:&ES+3YG9710
M871H*"=C:2<I("X@)R`G("X@)%$@+B`D9FEL97!A=&@@+B`D42XG(#(^)C$G
M.PH@("`@("`@("1R8W-?8VUD(#T@)'1H:7,M/F=E=%!A=&@H)W)C<R<I("X@
M)R`M:2`M:V(@)R`N("11("X@)&9I;&5P871H("X@)%$N)R`R/B8Q)SL*("`@
M("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@("1M97-S86=E7VQI;F5S(#T@
M97AP;&]D92@B7&XB+"`D;65S<V%G92D["@H@("`@("`@("1P:7!E7V1E9B`]
M(&%R<F%Y*#`@/3X@87)R87DH(G!I<&4B+"`G<B<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@(#$@/3X@87)R87DH(G!I<&4B+"`G=R<I*3L*"B`@("`@
M("`@:68@*"1N97=":6YA<GDI('L*("`@("`@("`@("`@)'!R;V-E<W,@/2!P
M<F]C7V]P96XH)')C<U]C;60L("1P:7!E7V1E9BP@)'!I<&5S*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<')O8V5S<R`]('!R;V-?;W!E;B@D
M8VE?8VUD+"`D<&EP95]D968L("1P:7!E<RD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-?<F5S;W5R8V4H)'!R;V-E<W,I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1M97-S86=E7VQI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&QI;F4@/3T@)RY<;B<I('L*("`@("`@("`@("`@("`@("`@
M("`D;&EN92`]("<N(%QN)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&9W<FET92@D<&EP97-;,%TL("1L:6YE*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@9G=R:71E*"1P:7!E<ULP72P@(EQN+EQN(BD["B`@
M("`@("`@("`@(&9C;&]S92@D<&EP97-;,%TI.PH*("`@("`@("`@("`@=VAI
M;&4@*"%F96]F*"1P:7!E<ULQ72DI('L*("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@9G)E860H)'!I<&5S6S%=+"`X,3DR*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!F8VQO<V4H)'!I<&5S6S%=*3L*("`@("`@("`@("`@<')O
M8U]C;&]S92@D<')O8V5S<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!O<&5N('!I
M<&4@:6X@8VDH*2<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1N97=":6YA
M<GDI('L*("`@("`@("`@("`@97AE8R@D8VE?8VUD("X@)R`R/B8Q)RP@)')E
M='5R;E]A<G)A>2P@)')E='9A;"D["@H@("`@("`@("`@("!I9B`H)')E='9A
M;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M(E5N86)L92!T;R!S<&%W;B!C:2!O;B`D9FEL97!A=&@@9G)O;2!C:2@I(BD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("`@
M("`@)&]U='!U="`N/2`D;&EN93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)')E=E]S=&%R="`]('-T<G!O
M<R@D;W5T<'5T+"`G;F5W(')E=FES:6]N.B`G*3L*"B`@("`@("`@+R\@268@
M;F\@;F5W(')E=FES:6]N+"!S964@:68@=&AI<R!I<R!A;B!I;FET:6%L(&-H
M96-K:6XN"B`@("`@("`@:68@*"1R979?<W1A<G0@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@("1R979?<W1A<G0@/2!S=')P;W,H)&]U='!U="P@)VEN:71I
M86P@<F5V:7-I;VXZ("<I.PH@("`@("`@("`@("`D<F5V7V5N9"`]('-T<G!O
M<R@D;W5T<'5T+"`G("<L("1R979?<W1A<G0I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1R979?96YD(#T@<W1R<&]S*"1O=71P=70L("<[)RP@
M)')E=E]S=&%R="D["B`@("`@("`@?0H*("`@("`@("!I9B`H)')E=E]S=&%R
M="`A/3T@9F%L<V4@)B8@)')E=E]E;F0@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("1R979?<W1A<G0@*ST@,30["B`@("`@("`@("`@(')E='5R;B!S=6)S
M='(H)&]U='!U="P@)')E=E]S=&%R="P@)')E=E]E;F0@+2`D<F5V7W-T87)T
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U;FQO8VLH)&9I;&5P
M871H*3L*("`@("`@("`@("`@)'1E;7!?<&]S(#T@<W1R<&]S*"1O=71P=70L
M("=F:6QE(&ES('5N8VAA;F=E9"<I.PH@("`@("`@("`@("!I9B`H)'1E;7!?
M<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T-H96-K+6EN($9A:6QU<F4Z("<@+B!B87-E;F%M92@D
M9FEL97!A=&@I("X@)R!H87,@;F]T(&)E96X@;6]D:69I960G*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*")&86EL960@=&\@8VAE8VMI;B`D9FEL97!A=&@L("1C:5]C
M;60L("1O=71P=70B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@;&]C:W,@;VX@82!#5E,O4D-3
M(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL97!A=&@@
M("`@3&]C871I;VX@;V8@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)B1L
M;V-K961?8GD@(%)E='5R;G,@=&AE('5S97)N86UE(&AO;&1I;F<@=&AE(&QO
M8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C="`@5')U
M92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-,;V-K960H)&9I;&5P871H+"`F)&QO8VME
M9%]B>2D*("`@('L*("`@("`@("`D<FQO9U]C;60@(#T@)'1H:7,M/F=E=%!A
M=&@H)W)L;V<G*3L*("`@("`@("`D<FQO9U]F;&%G(#T@)R`M3"`G.PH*("`@
M("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@.B`B)R(["@H@("`@("`@("1C
M;60@/2`D<FQO9U]C;60@+B`D<FQO9U]F;&%G("X@)%$@+B`D9FEL97!A=&@@
M+B`D43L*"B`@("`@("`@97AE8R@D8VUD+B<@,CXF,2<L("1R971U<FY?87)R
M87DL("1R971V86PI.PH*("`@("`@("!I9B`H)')E='9A;"D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B56YA8FQE('1O('-P87=N
M(')L;V<@;VX@)&9I;&5P871H(&9R;VT@:7-,;V-K960H*2(I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1O=71P=70@/2`G)SL*"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1R971U<FY?87)R87D@87,@)&QI;F4I('L*("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@)&QI;F4["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1S=&%R=%]N86UE(#T@<W1R<&]S*"1O=71P=70L("=L;V-K
M960@8GDZ("<I.PH@("`@("`@("`@("`D96YD7VYA;64@/2!S=')P;W,H)&]U
M='!U="P@)SLG+"`D<W1A<G1?;F%M92D["@H@("`@("`@("`@("!I9B`H)'-T
M87)T7VYA;64@(3T](&9A;'-E("8F("1E;F1?;F%M92`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1S=&%R=%]N86UE("L](#$Q.PH@("`@("`@("`@
M("`@("`@)&QO8VME9%]B>2`]('-U8G-T<B@D;W5T<'5T+"`D<W1A<G1?;F%M
M92P@)&5N9%]N86UE("T@)'-T87)T7VYA;64I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@('T@(&5L<V5I9B`H<W1R;&5N*"1O
M=71P=70I(#T](#`I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=&86EL=7)E(')U;FYI;F<@<FQO9R!I;B!I<TQO
M8VME9"@I)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!,;V-K<R!A($-64R]20U,@9FEL92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F:6QE<&%T:"`@3&]C871I;VX@;V8@9FEL92X*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("!5<V5R(&YA;64@=&\@
M;&]C:R!T:&4@9FEL92!W:71H"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N?&]B:F5C="`@5')U92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&]C:R@D9FEL97!A
M=&@L("1U<V5R(#T@;G5L;"D*("`@('L*("`@("`@("`O+R!'970@=7-E<FYA
M;64@9F]R(%)#4R!T86<N"B`@("`@("`@:68@*"1U<V5R*2!["B`@("`@("`@
M("`@('!U=&5N=B@G3$]'3D%-13TG("X@)'5S97(I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@('!U=&5N=B@G3$]'3D%-13UG=65S="<I.PH@("`@
M("`@('T*"B`@("`@("`@)')C<U]C;60@/2`D=&AI<RT^9V5T4&%T:"@G<F-S
M)RD["B`@("`@("`@)')C<U]F;&%G(#T@)R`M;"`G.PH*("`@("`@("`D42`]
M(%9#7U=)3D1/5U,@/R`G(B<@.B`B)R(@.PH@("`@("`@("1C;60@/2`D<F-S
M7V-M9"`N("1R8W-?9FQA9R`N("11("X@)&9I;&5P871H("X@)%$["B`@("`@
M("`@97AE8R@D8VUD+B<@,CXF,2<L("1R971U<FY?87)R87DL("1R971V86PI
M.PH*("`@("`@("!I9B`H)')E='9A;"D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O('-P87=N(')C<R`H(B<@+B`D
M8VUD("X@)R(I(&]N("(G("X@)&9I;&5P871H("X@)R(@*')E='5R;F5D("<@
M+B`D<F5T=F%L("X@)RDG*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;W5T<'5T(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1R971U<FY?
M87)R87D@87,@)&QI;F4I('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M)&QI;F4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1L;V-K961?<&]S
M(#T@<W1R<&]S*"1O=71P=70L("=L;V-K960G*3L*("`@("`@("`@("`@:68@
M*"1L;V-K961?<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&QO8VL@(B<@
M+B`D9FEL97!A=&@@+B`G(B`H4F%N("(G("X@)&-M9"`N("<B+"!G;W0@<F5T
M=7)N(&-O9&4@)R`N("1R971V86P@+B`G+"!O=71P=70Z("<@+B`D;W5T<'5T
M("X@)RDG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%5N;&]C:W,@82!#5E,O4D-3(&9I;&4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9FEL97!A=&@@($QO8V%T:6]N(&]F(&9I;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@57-E<B!N86UE('1O
M('5N;&]C:R!T:&4@9FEL92!W:71H"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N?&]B:F5C="`@5')U92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=6YL;V-K*"1F
M:6QE<&%T:"P@)'5S97(@/2!N=6QL*0H@("`@>PH@("`@("`@("\O($=E="!U
M<V5R;F%M92!F;W(@4D-3('1A9RX*("`@("`@("!I9B`H)'5S97(I('L*("`@
M("`@("`@("`@<'5T96YV*"=,3T=.04U%/2<@+B`D=7-E<BD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<'5T96YV*"=,3T=.04U%/6=U97-T)RD[
M"B`@("`@("`@?0H*("`@("`@("`D<F-S7V-M9"`]("1T:&ES+3YG9710871H
M*"=R8W,G*3L*("`@("`@("`D<F-S7V9L86<@/2`G("UU("<["@H@("`@("`@
M("11(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G(B`["B`@("`@("`@)&-M9"`]
M("1R8W-?8VUD("X@)')C<U]F;&%G("X@)%$@+B`D9FEL97!A=&@@+B`D43L*
M("`@("`@("!E>&5C*"1C;60@+B`G(#(^)C$G+"`D<F5T=7)N7V%R<F%Y+"`D
M<F5T=F%L*3L*"B`@("`@("`@:68@*"1R971V86PI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!S<&%W;B!R8W,@
M*"(G("X@)&-M9"`N("<B*2!O;B`B)R`N("1F:6QE<&%T:"`N("<B("AR971U
M<FYE9"`G("X@)')E='9A;"`N("<I)RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("`@("`@9F]R96%C:"`H
M)')E='5R;E]A<G)A>2!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2`D;&EN93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'5N
M;&]C:V5D7W!O<R`]('-T<G!O<R@D;W5T<'5T+"`G=6YL;V-K960G*3L*"B`@
M("`@("`@("`@(&EF("@D=6YL;V-K961?<&]S("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`O+R!!;')E861Y('5N;&]C:V5D+@H@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U9#+W-V
M;BYP:'``````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V
M,#<R,@`Q,#0Q-S,V,C<W,0`P,C`P-C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%9#7W-V;B!I;7!L
M96UE;G1A=&EO;BX*("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P-B!!;FEL($UA
M9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO5D,O5D,O<W9N+G!H<"QV(#$N,C@N-"XQ-"`R,#`V+S`Q+S`Q
M(#(Q.C(X.C0R(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA
M=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7W-V;B!E>'1E;F1S(%9#
M('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R('1H92!C;&%S
M<R!E>'!E8W1S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($-U<G)E
M;G0@<&%R86UE=&5R<SH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`G
M<V]U<F-E<F]O="<Z(%1H92!S;W5R8V4@<F]O="!F;W(@=&AI<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5P;W-I=&]R
M>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=P871H<R<Z($AA<V@@
M=VET:"!T:&4@;&]C871I;VYS(&]F(&%L;`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&YE8V5S<V%R>2!B:6YA<FEE<SH@)W-V;B<L
M("=D:69F)PH@("`@("HO"B`@("!F=6YC=&EO;B!60U]S=FXH)'!A<F%M<RD*
M("`@('L*("`@("`@("`D=&AI<RT^7W-O=7)C97)O;W0@/2`D<&%R86US6R=S
M;W5R8V5R;V]T)UT["B`@("`@("`@)'1H:7,M/E]P871H<R`]("1P87)A;7-;
M)W!A=&AS)UT["B`@("!]"@H@("`@9G5N8W1I;VX@:7-&:6QE*"1W:&5R92D*
M("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO
M;B`F<75E<GE$:7(H)'=H97)E*0H@("`@>PH@("`@("`@("1D:7(@/2`F;F5W
M(%9#7T1I<F5C=&]R>5]S=FXH)'1H:7,L("1W:&5R92D["B`@("`@("`@<F5T
M=7)N("1D:7(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0VAE8VMO=70H)&9I
M;&4L("1R978I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7T-H96-K;W5T7W-V
M;CHZ9V5T*"1T:&ES+"`D9FEL92T^<75E<GE&=6QL4&%T:"@I+"`D<F5V*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971$:69F*"8D9FEL92P@)')E=C$L("1R
M978R+"`D='EP92`]("=C;VYT97AT)RP@)&YU;2`](#,L("1W<R`]('1R=64I
M"B`@("!["B`@("`@("`@<F5T=7)N(%9#7T1I9F9?<W9N.CIG970H)'1H:7,L
M("1F:6QE+"`D<F5V,2P@)')E=C(L("1T>7!E+"`D;G5M+"`D=W,I.PH@("`@
M?0H*("`@(&9U;F-T:6]N("9G971&:6QE3V)J96-T*"1F:6QE;F%M92P@)&-A
M8VAE(#T@;G5L;"P@)'%U:6-K;&]G(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)&9O(#T@)E9#7T9I;&5?<W9N.CIG971&:6QE3V)J96-T*"1T:&ES+"`D9FEL
M96YA;64L("1C86-H92P@)'%U:6-K;&]G*3L*("`@("`@("!R971U<FX@)&9O
M.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971!;FYO=&%T94]B:F5C="@D9FEL
M96YA;64I"B`@("!["B`@("`@("`@)&)L86UE(#T@)FYE=R!60U]!;FYO=&%T
M95]S=FXH)'1H:7,L("1F:6QE;F%M92D["B`@("`@("`@<F5T=7)N("1B;&%M
M93L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4&%T8VAS971/8FIE8W0H)&9I
M;&5N86UE+"`D8V%C:&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1P;R`]("96
M0U]0871C:'-E=%]S=FXZ.F=E=%!A=&-H<V5T3V)J96-T*"1T:&ES+"`D9FEL
M96YA;64L("1C86-H92D["B`@("`@("`@<F5T=7)N("1P;SL*("`@('T*"GT*
M"B\J*@H@*B!60U]S=FX@86YN;W1A=&4@8VQA<W,N"B`J"B`J($%N:6P@36%D
M:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!
M;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G
M92!60PH@*B\*8VQA<W,@5D-?06YN;W1A=&5?<W9N('L*"B`@("!V87(@)&9I
M;&4["B`@("!V87(@)%-63CL*("`@('9A<B`D=&UP9FEL93L*"B`@("!F=6YC
M=&EO;B!60U]!;FYO=&%T95]S=FXH)B1R97`L("1F:6QE*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y35DX@/2`F)')E<#L*("`@("`@("`D=&AI<RT^9FEL92`]
M("8D9FEL93L*("`@('T*"B`@("!F=6YC=&EO;B!D;T%N;F]T871E*"1R978I
M"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('1H870@=&AE(&9I;&4@=F%L
M=65S(&9O<B!T:&ES(&]B:F5C="!I<R!V86QI9"X@*B\*("`@("`@("!I9B`H
M:7-?82@D=&AI<RT^9FEL92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(59#7U)E
M=FES:6]N.CIV86QI9"@D<F5V*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@
M.B`B)R(["B`@("`@("`@)&-O;6UA;F0@/2`D=&AI<RT^4U9.+3YG9710871H
M*"=S=FXG*2`N("<@86YN;W1A=&4@+7(@,3HG("X@)')E=B`N("<@)R`N("11
M("X@<W1R7W)E<&QA8V4H)%$L("=<7"<@+B`D42P@)'1H:7,M/F9I;&4M/G%U
M97)Y1G5L;%!A=&@H*2D@+B`D42`N("<@,CXF,2<["B`@("`@("`@)'!I<&4@
M/2!P;W!E;B@D8V]M;6%N9"P@)W(G*3L*("`@("`@("!I9B`H(21P:7!E*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@
M=&\@97AE8W5T92!S=FX@86YN;W1A=&4Z("<@+B`D8V]M;6%N9"D["B`@("`@
M("`@?0H*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@("1L:6YE
M;F\@/2`Q.PH@("`@("`@('=H:6QE("@A9F5O9B@D<&EP92DI('L*("`@("`@
M("`@("`@)&QI;F4@/2!F9V5T<R@D<&EP92P@-#`Y-BD["B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7EQS*RA<9"LI7',K*%M<=UPN72LI7',H+BHI
M)"\G+"`D;&EN92P@)')E9W,I*2!["B`@("`@("`@("`@("`@("`D96YT<GD@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=R978G72`@("`]
M("1R96=S6S%=.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=A=71H;W(G72`]
M("1R96=S6S)=.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=D871E)UT@("`]
M("<G.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=L:6YE)UT@("`]("1R96=S
M6S-=.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=L:6YE;F\G72`]("1L:6YE
M;F\K*SL*("`@("`@("`@("`@("`@("1L:6YE<UM=(#T@)&5N=')Y.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!P8VQO<V4H)'!I<&4I.PH@
M("`@("`@(')E='5R;B`D;&EN97,["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N
M(&-H96-K;W5T(&-L87-S+@H@*@H@*B!!;FEL($UA9&AA=F%P961D>2P@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D
M9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S
M(%9#7T-H96-K;W5T7W-V;B!["@H@("`@+RHJ"B`@("`@("H@4W1A=&EC(&9U
M;F-T:6]N('=H:6-H(')E='5R;G,@82!F:6QE('!O:6YT:6YG('1O('1H92!H
M96%D(&]F('1H92!R97%U97-T960*("`@("`@*B!R979I<VEO;B!O9B!A;B!2
M0U,@9FEL92X*("`@("`@*B!`<&%R86T@9G5L;&YA;64@1G5L;'D@<75A;&EF
M:65D('!A=&AN86UE(&]F('1H92!D97-I<F5D(%)#4R!F:6QE('1O(&-H96-K
M;W5T"B`@("`@("H@0'!A<F%M(')E=B!20U,@<F5V:7-I;VX@;G5M8F5R('1O
M(&-H96-K(&]U=`H@("`@("`J($!R971U<FX@16ET:&5R(&$@4$5!4E]%<G)O
M<B!O8FIE8W0L(&]R(&$@<W1R96%M('!O:6YT97(@=&\@=&AE(&AE860@;V8@
M=&AE(&-H96-K;W5T"B`@("`@("HO"B`@("!F=6YC=&EO;B!G970H)B1R97`L
M("1F=6QL;F%M92P@)')E=BD*("`@('L*("`@("`@("!I9B`H(59#7U)E=FES
M:6]N.CIV86QI9"@D<F5V*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G26YV86QI9"!R979I<VEO;B!N=6UB97(G*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("A60U]724Y$3U=3*2!["B`@("`@("`@("`@("11
M(#T@)R(G.PH@("`@("`@("`@("`D;6]D92`]("=R8B<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)%$@/2`B)R(["B`@("`@("`@("`@("1M;V1E
M(#T@)W(G.PH@("`@("`@('T*"B`@("`@("`@:68@*"$H)%)#4R`]('!O<&5N
M*"1R97`M/F=E=%!A=&@H)W-V;B<I("X@)R!C870@+7(@)R`N("1R978@+B`G
M("<@+B`D42`N('-T<E]R97!L86-E*"11+"`G7%PG("X@)%$L("1F=6QL;F%M
M92D@+B`D42`N("<@,CXF,2<L("1M;V1E*2DI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD;EPG="!P97)F;W)M(&-H96-K
M;W5T(&]F('1H92!R97%U97-T960@9FEL92<I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("120U,["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N(&1I9F8@
M8VQA<W,N"B`J"B`J($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D
M9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S
M(%9#7T1I9F9?<W9N('L*"B`@("`O*BH*("`@("`J($]B=&%I;B!T:&4@9&EF
M9F5R96YC97,@8F5T=V5E;B!T=V\@<F5V:7-I;VYS(&]F(&$@9FEL92X*("`@
M("`J"B`@("`@*B!`<&%R86T@5D-?<W9N("1R97`@("`@("`@($$@<F5P;W-I
M=&]R>2!O8FIE8W0N"B`@("`@*B!`<&%R86T@5D-?1FEL95]S=FX@)&9I;&4@
M(%1H92!D97-I<F5D(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978Q
M("`@("`@($]R:6=I;F%L(')E=FES:6]N(&YU;6)E<B!T;R!C;VUP87)E(&9R
M;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978R("`@("`@($YE=R!R979I
M<VEO;B!N=6UB97(@=&\@8V]M<&%R92!A9V%I;G-T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D='EP92`@("`@("!4:&4@='EP92!O9B!D:69F("AE+F<N("=U
M;FEF:65D)RDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;G5M("`@("`@($YU
M;6)E<B!O9B!L:6YE<R!T;R!B92!U<V5D(&EN(&-O;G1E>'0@86YD"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@('5N:69I960@9&EF9G,N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D=W,@("`@("`@(%-H;W<@=VAI=&5S<&%C
M92!I;B!T:&4@9&EF9C\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQB
M;V]L96%N("!&86QS92!O;B!F86EL=7)E+"!O<B!A('-T<FEN9R!C;VYT86EN
M:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9&EF9B!O
M;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)B1R97`L("8D
M9FEL92P@)')E=C$L("1R978R+"`D='EP92`]("=C;VYT97AT)RP@)&YU;2`]
M(#,L"B`@("`@("`@("`@("`@("`@)'=S(#T@=')U92D*("`@('L*("`@("`@
M("`O*B!-86ME('-U<F4@=&AA="!T:&4@9FEL92!P87)A;65T97(@:7,@=F%L
M:60@*B\*("`@("`@("!I9B`H:7-?82@D9FEL92P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`O*B!#:&5C:R!T:&%T('1H92!R979I<VEO;B!N=6UB97)S(&%R92!V86QI
M9"`J+PH@("`@("`@("1R978Q(#T@5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978Q
M*2`_("1R978Q(#H@,#L*("`@("`@("`D<F5V,B`](%9#7U)E=FES:6]N.CIV
M86QI9"@D<F5V,2D@/R`D<F5V,B`Z(#`["@H@("`@("`@("1F=6QL3F%M92`]
M("1F:6QE+3YQ=65R>49U;&Q0871H*"D["B`@("`@("`@)&1I9F8@/2!A<G)A
M>2@I.PH@("`@("`@("1O<'1I;VYS(#T@)R<["B`@("`@("`@:68@*"$D=W,I
M('L*("`@("`@("`@("`@)&]P=&EO;G,@+CT@)R`M8D(@)SL*("`@("`@("!]
M"@H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("!C87-E("=C;VYT
M97AT)SH*("`@("`@("`@("`@)&]P=&EO;G,@+CT@)RTM8V]N=&5X=#TG("X@
M*&EN="DD;G5M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M=6YI9FEE9"<Z"B`@("`@("`@("`@("1O<'1I;VYS("X]("<M+75N:69I960]
M)R`N("AI;G0I)&YU;3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)V-O;'5M;B<Z"B`@("`@("`@("`@("1O<'1I;VYS("X]("<M+7-I9&4M
M8GDM<VED92`M+7=I9'1H/3$R,"<["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E("=E9"<Z"B`@("`@("`@("`@("1O<'1I;VYS("X]("<M92<[
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@5$]$
M3SH@861D(&]P=&EO;G,@9F]R("1H<B!O<'1I;VYS("T@:&]W979E<B!T:&5S
M92!M87D@;F]T"B`@("`@("`@+R\@8F4@8V]M<&%T:6)L92!W:71H('-O;64@
M9&EF9G,N"B`@("`@("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B.PH@
M("`@("`@("1C;VUM86YD(#T@)')E<"T^9V5T4&%T:"@G<W9N)RD@+B`B(&1I
M9F8@+2UD:69F+6-M9"`B("X@)')E<"T^9V5T4&%T:"@G9&EF9B<I("X@(B`M
M<B`D<F5V,3HD<F5V,B`M>"`B("X@)%$@+B`D;W!T:6]N<R`N("11("X@)R`G
M("X@)&9I;&4M/G%U97)Y1G5L;%!A=&@H*2`N("<@,CXF,2<["@H@("`@("`@
M(&5X96,H)&-O;6UA;F0L("1D:69F+"`D<F5T=F%L*3L*("`@("`@("!R971U
M<FX@)&1I9F8["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N(&1I<F5C=&]R>2!C
M;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI
M;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D
M>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@
M5D-?1&ER96-T;W)Y7W-V;B!["@H@("`@=F%R("1R97`["B`@("!V87(@)&1I
M<DYA;64["B`@("!V87(@)&9I;&5S.PH@("`@=F%R("1A='1I8T9I;&5S.PH@
M("`@=F%R("1M97)G961&:6QE<SL*("`@('9A<B`D9&ER<SL*("`@('9A<B`D
M<&%R96YT.PH@("`@=F%R("1M;V1U;&5.86UE.PH*("`@("\J*@H@("`@("H@
M0W)E871E(&$@4U9.($1I<F5C=&]R>2!O8FIE8W0@=&\@<W1O<F4@:6YF;W)M
M871I;VX@86)O=70@=&AE"B`@("`@*B!F:6QE<R!I;B!A('-I;F=L92!D:7)E
M8W1O<GD@:6X@=&AE(')E<&]S:71O<GD*("`@("`J"B`@("`@*B!`<&%R86T@
M5D-?4F5P;W-I=&]R>5]S=FX@)')P("!4:&4@5D-?4F5P;W-I=&]R>2!O8FIE
M8W0@=&AI<R!D:7)E8W1O<GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&ES('!A<G0@;V8N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M;B`@("`@("`@("`@("!0871H('1O('1H92!D:7)E8W1O<GDN"B`@("`@*B!`
M<&%R86T@5D-?1&ER96-T;W)Y7W-V;B`D<&X@("!4:&4@<&%R96YT(%9#7T1I
M<F5C=&]R>2!T;R!T:&ES(&]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?
M1&ER96-T;W)Y7W-V;B@F)')E<"P@)&1N+"`D<&X@/2`G)RD*("`@('L*("`@
M("`@("`D=&AI<RT^<F5P(#T@)B1R97`["B`@("`@("`@)'1H:7,M/G!A<F5N
M="`]("8D<&X["B`@("`@("`@)'1H:7,M/FUO9'5L94YA;64@/2`D9&X["B`@
M("`@("`@)'1H:7,M/F1I<DYA;64@/2`B+R1D;B(["B`@("`@("`@)'1H:7,M
M/F9I;&5S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^9&ER<R`](&%R<F%Y
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@9G5L;'D@<75A;&EF
M:65D('!A=&AN86UE('1O('1H:7,@9&ER96-T;W)Y('=I=&@@;F\*("`@("`J
M('1R86EL:6YG("\N"B`@("`@*@H@("`@("H@0')E='5R;B!0871H;F%M92!O
M9B!T:&ES(&1I<F5C=&]R>0H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>41I
M<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD:7).86UE.PH@("`@
M?0H*("`@(&9U;F-T:6]N("9Q=65R>41I<DQI<W0H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^9&ER<SL*("`@('T*"B`@("!F=6YC=&EO;B`F<75E
M<GE&:6QE3&ES="@D<VAO=V%T=&EC(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M:68@*"1S:&]W871T:6,@)B8@:7-S970H)'1H:7,M/FUE<F=E9$9I;&5S*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUE<F=E9$9I;&5S.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9FEL97,[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&5L;"!T:&4@;V)J
M96-T('1O(&]P96X@86YD(&)R;W=S92!I=',@8W5R<F5N="!D:7)E8W1O<GDL
M(&%N9`H@("`@("H@<F5T<FEE=F4@82!L:7-T(&]F(&%L;"!T:&4@;V)J96-T
M<R!I;B!T:&5R92X@($ET('1H96X@<&]P=6QA=&5S"B`@("`@*B!T:&4@9FEL
M92]D:7)E8W1O<GD@<W1A8VL@86YD(&UA:V5S(&ET(&%V86EL86)L92!F;W(@
M<F5T<FEE=F%L+@H@("`@("H*("`@("`J($!R971U<FX@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@86X@97)R;W(L(#$@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8G)O=W-E1&ER*"1C86-H92`](&YU;&PL("1Q=6EC:VQO9R`]
M('1R=64L("1S:&]W871T:6,@/2!F86QS92D*("`@('L*("`@("`@("`D42`]
M(%9#7U=)3D1/5U,@/R`G(B<@.B`B)R(@.PH@("`@("`@("1C;60@/2`D=&AI
M<RT^<F5P+3YG9710871H*"=S=FXG*2`N("<@;',@)R`N("11("X@<W1R7W)E
M<&QA8V4H)%$L("=<7"<@+B`D42P@)'1H:7,M/G)E<"T^<V]U<F-E<F]O="@I
M("X@)'1H:7,M/G%U97)Y1&ER*"DI("X@)%$@+B`G(#(^)C$G.PH@("`@("`@
M("1D:7(@/2!P;W!E;B@D8VUD+"`G<B<I.PH@("`@("`@(&EF("@A)&1I<BD@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D
M('1O(&5X96-U=&4@<W9N(&QS.B`G("X@)&-M9"D["B`@("`@("`@?0H*("`@
M("`@("`O*B!#<F5A=&4@='=O(&%R<F%Y<R`M(&]N92!O9B!A;&P@=&AE(&9I
M;&5S+"!A;F0@=&AE(&]T:&5R(&]F"B`@("`@("`@("H@86QL('1H92!D:7)S
M+B`J+PH@("`@("`@("1E<G)O<G,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE
M("@A9F5O9B@D9&ER*2D@>PH@("`@("`@("`@("`D;&EN92`](&-H;W`H9F=E
M=',H)&1I<BP@,3`R-"DI.PH@("`@("`@("`@("!I9B`H(7-T<FQE;B@D;&EN
M92DI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H<W5B<W1R*"1L:6YE+"`P+"`T*2`]/2`G<W9N
M.B<I('L*("`@("`@("`@("`@("`@("1E<G)O<G-;72`]("1L:6YE.PH@("`@
M("`@("`@("!](&5L<V5I9B`H<W5B<W1R*"1L:6YE+"`M,2D@/3T@)R\G*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^9&ER<UM=(#T@<W5B<W1R*"1L:6YE
M+"`P+"`M,2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D9FP@/2`F)'1H:7,M/G)E<"T^9V5T1FEL94]B:F5C="@D=&AI<RT^<75E
M<GE$:7(H*2`N("(O)&QI;F4B+"`D8V%C:&4L("1Q=6EC:VQO9RD["B`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D9FPL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)&9L.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9FEL97-;72`]
M("8D9FP["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@('!C;&]S92@D9&ER*3L*"B`@("`@("`@:68@*"1E<G)O
M<G,I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H:6UP
M;&]D92@B7&XB+"`D97)R;W)S*2D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@=&AE(&-O;G1E
M;G1S(&]F('1H92!D:7)E8W1O<GD@:6X@82!G:79E;B!F87-H:6]N(&%N9`H@
M("`@("H@;W)D97(N"B`@("`@*@H@("`@("H@0'!A<F%M("1H;W<@3V8@=&AE
M(&9O<FT@5D-?4T]25%\J('=H97)E("H@8V%N(&)E.@H@("`@("H@("`@("`@
M("`@("`@3D].12P@3D%-12P@04=%+"!2158@9F]R('-O<G1I;F<@8GD@;F%M
M92P@86=E(&]R(')E=FES:6]N+@H@("`@("H@0'!A<F%M("1D:7(@3V8@=&AE
M(&9O<FT@5D-?4T]25%\J('=H97)E("H@8V%N(&)E.@H@("`@("H@("`@("`@
M("`@("`@05-#14Y$24Y'+"!$15-#14Y$24Y'(&9O<B!T:&4@;W)D97(@;V8@
M=&AE('-O<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<&QY4V]R="@D:&]W
M(#T@5D-?4T]25%].3TY%+"`D9&ER(#T@5D-?4T]25%]!4T-%3D1)3D<I"B`@
M("!["B`@("`@("`@+RH@5$]$3SH@=&AI<R!C;V1E(&QO;VMS('9E<GD@:6YE
M9F9I8VEE;G0A(&]P=&EM:7-E+BXN("T*("`@("`@("`@*B!A=G-M+B`J+PH*
M("`@("`@("`O+R!!<W-U;64@8GD@;F%M92!F;W(@=&AE(&UO;65N="X*("`@
M("`@("!N871C87-E<V]R="@D=&AI<RT^9&ER<RD["B`@("`@("`@)'1H:7,M
M/F1O1FEL95-O<G0H)'1H:7,M/F9I;&5S+"`D:&]W+"`D9&ER*3L*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/F%T=&EC1FEL97,I*2!["B`@("`@("`@("`@
M("1T:&ES+3YD;T9I;&53;W)T*"1T:&ES+3YA='1I8T9I;&5S+"`D:&]W+"`D
M9&ER*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YM97)G
M961&:6QE<RDI('L*("`@("`@("`@("`@)'1H:7,M/F1O1FEL95-O<G0H)'1H
M:7,M/FUE<F=E9$9I;&5S+"`D:&]W+"`D9&ER*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1D:7(@/3T@5D-?4T]25%]$15-#14Y$24Y'*2!["B`@("`@("`@
M("`@("1T:&ES+3YD:7)S(#T@87)R87E?<F5V97)S92@D=&AI<RT^9&ER<RD[
M"B`@("`@("`@("`@("1T:&ES+3YF:6QE<R`](&%R<F%Y7W)E=F5R<V4H)'1H
M:7,M/F9I;&5S*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YM97)G
M961&:6QE<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YM97)G961&:6QE
M<R`](&%R<F%Y7W)E=F5R<V4H)'1H:7,M/FUE<F=E9$9I;&5S*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!D;T9I;&53
M;W)T*"8D9FEL94QI<W0L("1H;W<@/2!60U]33U)47TY/3D4L("1D:7(@/2!6
M0U]33U)47T%30T5.1$E.1RD*("`@('L*("`@("`@("!S=VET8V@@*"1H;W<I
M('L*("`@("`@("!C87-E(%9#7U-/4E1?04=%.@H@("`@("`@("`@("!U<V]R
M="@D9FEL94QI<W0L(&%R<F%Y*"1T:&ES+"`G9FEL94%G95-O<G0G*2D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9#7U-/4E1?3D%-13H*
M("`@("`@("`@("`@=7-O<G0H)&9I;&5,:7-T+"!A<G)A>2@D=&AI<RP@)V9I
M;&5.86UE4V]R="<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@5D-?4T]25%]!551(3U(Z"B`@("`@("`@("`@('5S;W)T*"1F:6QE3&ES
M="P@87)R87DH)'1H:7,L("=F:6QE075T:&]R4V]R="<I*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@5D-?4T]25%]2158Z"B`@("`@("`@
M("`@('5S;W)T*"1F:6QE3&ES="P@87)R87DH)'1H:7,L("=F:6QE4F5V4V]R
M="<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@5D-?4T]2
M5%].3TY%.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@9G5N8W1I;VX@
M9F]R(&%S8V5N9&EN9R!A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I;&5!
M9V53;W)T*"1A+"`D8BD*("`@('L*("`@("`@("`D86$@/2`D82T^<75E<GE,
M87-T3&]G*"D["B`@("`@("`@)&)B(#T@)&(M/G%U97)Y3&%S=$QO9R@I.PH@
M("`@("`@(&EF("@D86$M/G%U97)Y1&%T92@I(#T]("1B8BT^<75E<GE$871E
M*"DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("@D86$M/G%U97)Y1&%T92@I(#P@)&)B+3YQ
M=65R>41A=&4H*2D@/R`Q(#H@+3$["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4V]R="!F=6YC=&EO;B!B>2!A=71H;W(@;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9FEL94%U=&AO<E-O<G0H)&$L("1B*0H@("`@>PH@
M("`@("`@("1A82`]("1A+3YQ=65R>4QA<W1,;V<H*3L*("`@("`@("`D8F(@
M/2`D8BT^<75E<GE,87-T3&]G*"D["B`@("`@("`@:68@*"1A82T^<75E<GE!
M=71H;W(H*2`]/2`D8F(M/G%U97)Y075T:&]R*"DI('L*("`@("`@("`@("`@
M<F5T=7)N(#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("@D86$M/G%U97)Y075T:&]R*"D@/B`D8F(M/G%U97)Y075T:&]R*"DI(#\@
M,2`Z("TQ.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@
M9G5N8W1I;VX@9F]R(&%S8V5N9&EN9R!F:6QE;F%M92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9FEL94YA;653;W)T*"1A+"`D8BD*("`@('L*("`@("`@("!R
M971U<FX@<W1R8V%S96-M<"@D82T^;F%M92P@)&(M/FYA;64I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V]R="!F=6YC=&EO;B!F;W(@87-C96YD:6YG(')E
M=FES:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE4F5V4V]R="@D82P@
M)&(I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N.CIC;7`H)&$M
M/G%U97)Y2&5A9"@I+"`D8BT^<75E<GE(96%D*"DI.PH@("`@?0H*?0H*+RHJ
M"B`J(%9#7W-V;B!F:6QE(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@06YI;"!-
M861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@
M($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K
M86=E(%9#"B`J+PIC;&%S<R!60U]&:6QE7W-V;B!E>'1E;F1S(%9#7T9I;&4@
M>PH*("`@("\J*@H@("`@("H@0W)E871E(&$@<F5P;W-I=&]R>2!F:6QE(&]B
M:F5C="P@86YD(&=I=F4@:70@:6YF;W)M871I;VX@86)O=70*("`@("`J('=H
M870@:71S('!A<F5N="!D:7)E8W1O<GD@86YD(')E<&]S:71O<GD@;V)J96-T
M<R!A<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FP@($9U;&P@
M<&%T:"!T;R!T:&ES(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7T9I
M;&5?<W9N*"8D<F5P+"`D9FPL("1Q=6EC:VQO9R`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1T:&ES+3YR97`@/2`F)')E<#L*("`@("`@("`D=&AI<RT^;F%M
M92`](&)A<V5N86UE*"1F;"D["B`@("`@("`@)'1H:7,M/F1I<B`](&1I<FYA
M;64H)&9L*3L*("`@("`@("`D=&AI<RT^;&]G<R`](&%R<F%Y*"D["B`@("`@
M("`@)'1H:7,M/G%U:6-K;&]G(#T@)'%U:6-K;&]G.PH@("`@("`@("1T:&ES
M+3YR979S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^<F5V<WEM(#T@87)R
M87DH*3L*("`@("`@("`D=&AI<RT^<WEM<F5V(#T@87)R87DH*3L*("`@("`@
M("`D=&AI<RT^8G)A;F-H97,@/2!A<G)A>2@I.PH@("`@?0H*("`@(&9U;F-T
M:6]N("9G971&:6QE3V)J96-T*"8D<F5P+"`D9FEL96YA;64L("1C86-H92`]
M(&YU;&PL("1Q=6EC:VQO9R`](&9A;'-E*0H@("`@>PH@("`@("`@("\J*@H@
M("`@("`@("`J(%1H92!V97)S:6]N(&]F('1H92!C86-H960@9&%T82X@26YC
M<F5M96YT('1H:7,@=VAE;F5V97(@=&AE"B`@("`@("`@("H@:6YT97)N86P@
M<W1O<F%G92!F;W)M870@8VAA;F=E<RP@<W5C:"!T:&%T('=E(&UU<W0*("`@
M("`@("`@*B!I;G9A;&ED871E('!R:6]R(&-A8VAE9"!D871A+@H@("`@("`@
M("`J+PH@("`@("`@("1C86-H959E<G-I;VX@/2`R.PH@("`@("`@("1C86-H
M94ED(#T@)')E<"T^<V]U<F-E<F]O="@I("X@)U]N)R`N("1F:6QE;F%M92`N
M("=?9B<@+B`H:6YT*21Q=6EC:VQO9R`N("=?=B<@+B`D8V%C:&5697)S:6]N
M.PH*("`@("`@("!I9B`H)&-A8VAE("8F"B`@("`@("`@("`@("\O(%1H92!F
M:6QE(&ES(&-A8VAE9"!F;W(@;VYE(&AO=7(@;F\@;6%T=&5R('=H870L(&)E
M8V%U<V4*("`@("`@("`@("`@+R\@=&AE<F4@:7,@;F\@=V%Y('1O(&1E=&5R
M;6EN92!W:71H(%-U8G9E<G-I;VX@=&AE('1I;64*("`@("`@("`@("`@+R\@
M=&AE(&9I;&4@;&%S="!C:&%N9V5D+@H@("`@("`@("`@("`D8V%C:&4M/F5X
M:7-T<R@D8V%C:&5)9"P@,S8P,"DI('L*("`@("`@("`@("`@)&9I;&5/8B`]
M('5N<V5R:6%L:7IE*"1C86-H92T^9V5T*"1C86-H94ED+"`S-C`P*2D["B`@
M("`@("`@("`@("1F:6QE3V(M/G-E=%)E<&]S:71O<GDH)')E<"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&9I;&5/8B`]("9N97<@5D-?1FEL
M95]S=FXH)')E<"P@)&9I;&5N86UE+"`D<75I8VML;V<I.PH@("`@("`@("`@
M("`D9FEL94]B+3YS971297!O<VET;W)Y*"1R97`I.PH@("`@("`@("`@("!I
M9B`H:7-?82@H)')E<W5L="`]("1F:6QE3V(M/F=E=$)R;W=S94EN9F\H*2DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F:6QE3V(M/F%P<&QY
M4V]R="A60U]33U)47T%'12D["@H@("`@("`@("`@("!I9B`H)&-A8VAE*2![
M"B`@("`@("`@("`@("`@("`D8V%C:&4M/G-E="@D8V%C:&5)9"P@<V5R:6%L
M:7IE*"1F:6QE3V(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1F:6QE3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)9B!T
M:&ES(&9I;&4@:7,@<')E<V5N="!I;B!A;B!!='1I8R!D:7)E8W1O<GDL('1H
M:7,@:6YD:6-A=&5S"B`@("`@*B!I="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('1R=64@:68@9FEL92!I<R!I;B!T:&4@071T:6,L(&%N9"!F86QS92!O=&AE
M<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@:7-!='1I8T9I;&4H*0H@("`@
M>PH@("`@("`@("\O($YO="!I;7!L96UE;G1E9"!Y970*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N
M86UE(&]F('1H92!C=7)R96YT(&9I;&4@87,@:6X@=&AE(')E<&]S:71O<GD*
M("`@("`J"B`@("`@*B!`<F5T=7)N($9I;&5N86UE("AW:71H;W5T('1H92!P
M871H*0H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>5)E<&]S:71O<GE.86UE
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FYA;64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&YA;64@;V8@=&AE(&-U<G)E;G0@9FEL
M92!W:71H;W5T('1H92!R97!O<VET;W)Y"B`@("`@*B!E>'1E;G-I;VYS("AU
M<W5A;&QY("QV*0H@("`@("H*("`@("`J($!R971U<FX@1FEL96YA;64@=VET
M:&]U="!R97!O<VET;W)Y(&5X=&5N<VEO;@H@("`@("HO"B`@("!F=6YC=&EO
M;B!Q=65R>4YA;64H*0H@("`@>PH@("`@("`@<F5T=7)N('!R96=?<F5P;&%C
M92@G+RQV)"\G+"`G)RP@)'1H:7,M/FYA;64I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!L87-T(')E=FES:6]N(&]F('1H92!C=7)R96YT
M(&9I;&4@;VX@=&AE($A%040@8G)A;F-H"B`@("`@*@H@("`@("H@0')E='5R
M;B!,87-T(')E=FES:6]N(&]F('1H92!C=7)R96YT(&9I;&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@<75E<GE2979I<VEO;B@I"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^<F5V<ULP72DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)TYO(')E=FES:6]N<R<I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/G)E=G-;,%T["B`@("!]"@H@("`@9G5N
M8W1I;VX@<75E<GE0<F5V:6]U<U)E=FES:6]N*"1R978I"B`@("!["B`@("`@
M("`@)&QA<W0@/2!F86QS93L*("`@("`@("!F;W)E86-H("@D=&AI<RT^<F5V
M<R!A<R`D96YT<GDI('L*("`@("`@("`@("`@:68@*"1L87-T*0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1E;G1R>3L*("`@("`@("`@("`@:68@*"1E;G1R
M>2`]/2`D<F5V*0H@("`@("`@("`@("`@("`@)&QA<W0@/2!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!(14%$("AM;W-T(')E8V5N="D@<F5V:7-I;VX@
M;G5M8F5R(&9O<B!T:&ES(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!(
M14%$(')E=FES:6]N(&YU;6)E<@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R
M>4AE860H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GE2979I
M<VEO;B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!L87-T
M(%9#7TQO9R!O8FIE8W0@:6X@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!60U],;V<@;V8@=&AE(&QA<W0@96YT<GD@:6X@=&AE(&9I;&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@<75E<GE,87-T3&]G*"D*("`@('L*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3YR979S6S!=*2!\?"`A:7-S970H)'1H:7,M
M/FQO9W-;)'1H:7,M/G)E=G-;,%U=*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G3F\@<F5V:7-I;VYS)RD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^;&]G<ULD=&AI<RT^<F5V<ULP75T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T('1H92!L:7-T(&]F(%9#7TQO9R!O
M8FIE8W1S('1H870@=&AI<R!F:6QE(&-O;G1A:6YS+@H@("`@("H*("`@("`J
M($!P87)A;2!H;W<@5D-?4T]25%]2158@*'-O<G0@8GD@<F5V:7-I;VXI+`H@
M("`@("H@("`@("`@("`@("!60U]33U)47TY!344@*'-O<G0@8GD@875T:&]R
M(&YA;64I+`H@("`@("H@("`@("`@("`@("!60U]33U)47T%'12`H<V]R="!B
M>2!C;VUM:70@9&%T92D*("`@("`J+PH@("`@9G5N8W1I;VX@87!P;'E3;W)T
M*"1H;W<@/2!60U]33U)47U)%5BD*("`@('L*("`@("`@("!S=VET8V@@*"1H
M;W<I('L*("`@("`@("!C87-E(%9#7U-/4E1?4D56.@H@("`@("`@("`@("`D
M9G5N8R`]("=2979I<VEO;B<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(&-A<V4@5D-?4T]25%].04U%.@H@("`@("`@("`@("`D9G5N8R`]("=.86UE
M)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92!60U]33U)47T%'
M13H*("`@("`@("`@("`@)&9U;F,@/2`G06=E)SL*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)&9U;F,@/2`G4F5V
M:7-I;VXG.PH@("`@("`@('T*("`@("`@("!U87-O<G0H)'1H:7,M/FQO9W,L
M(&%R<F%Y*"1T:&ES+"`B<V]R=$)Y)&9U;F,B*2D["B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@<V]R=$)Y*B@I(&9U
M;F-T:6]N<R!A<F4@:6YT97)N86QL>2!U<V5D(&)Y(&%P<&QY4V]R="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V]R=$)Y4F5V:7-I;VXH)&$L("1B*0H@("`@
M>PH@("`@("`@(')E='5R;B!60U]2979I<VEO;CHZ8VUP*"1B+3YR978L("1A
M+3YR978I.PH@("`@?0H*("`@(&9U;F-T:6]N('-O<G1">4%G92@D82P@)&(I
M"B`@("!["B`@("`@("`@<F5T=7)N("1B+3YD871E("T@)&$M/F1A=&4["B`@
M("!]"@H@("`@9G5N8W1I;VX@<V]R=$)Y3F%M92@D82P@)&(I"B`@("!["B`@
M("`@("`@<F5T=7)N('-T<F-M<"@D82T^875T:&]R+"`D8BT^875T:&]R*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%!O<'5L871E('1H92!O8FIE8W0@=VET
M:"!I;F9O<FUA=&EO;B!A8F]U="!T:&4@<F5V:7-I;VYS(&QO9W,*("`@("`J
M(&%N9"!D871E<R!O9B!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(&)O;VQE86X@("`@("`@("`@("!4<G5E(&]N('-U8V-E<W,L"B`@
M("`@*B`@("`@("`@("`@("`@(%!%05)?17)R;W(@("`@("`@("!/;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0G)O=W-E26YF;R@I"B`@("![
M"B`@("`@("`@+RH@5&AI<R!D;V5S;B=T('=O<FL[(&YE960@=&\@9FEN9"!A
M;F]T:&5R('=A>2!T;R!S:6UP;'D*("`@("`@("`@*B!R97%U97-T('1H92!M
M;W-T(')E8V5N="!R979I<VEO;CH*("`@("`@("`@*@H@("`@("`@("`J("1F
M;&%G(#T@)'1H:7,M/G%U:6-K;&]G(#\@)RUR($A%040@)R`Z("<G.R`J+PH@
M("`@("`@("1F;&%G(#T@)R<["B`@("`@("`@)%$@/2!60U]724Y$3U=3(#\@
M)R(G(#H@(B<B.PH@("`@("`@("1C;60@/2`D=&AI<RT^<F5P+3YG9710871H
M*"=S=FXG*2`N("<@;&]G("UV("<@+B`D9FQA9R`N("11("X@<W1R7W)E<&QA
M8V4H)%$L("=<7"<@+B`D42P@)'1H:7,M/G%U97)Y1G5L;%!A=&@H*2D@+B`D
M42`N("<@,CXF,2<["B`@("`@("`@)'!I<&4@/2!P;W!E;B@D8VUD+"`G<B<I
M.PH@("`@("`@(&EF("@A)'!I<&4I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!E>&5C=71E('-V;B!L;V<Z("<@
M+B`D8VUD*3L*("`@("`@("!]"@H@("`@("`@(&9G971S*"1P:7!E*3L*("`@
M("`@("!W:&EL92`H(69E;V8H)'!I<&4I*2!["B`@("`@("`@("`@("1L;V<@
M/2`F;F5W(%9#7TQO9U]S=FXH)'1H:7,M/G)E<"P@)'1H:7,I.PH@("`@("`@
M("`@("`D97)R(#T@)&QO9RT^<')O8V5S<TQO9R@D<&EP92D["B`@("`@("`@
M("`@(&EF("@D97)R*2!["B`@("`@("`@("`@("`@("`D<F5V(#T@)&QO9RT^
M<75E<GE2979I<VEO;B@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO9W-;
M)')E=ET@/2`D;&]G.PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E=G-;72`]
M("1R978["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M<75I8VML;V<I('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!P8VQO<V4H)'!I<&4I.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!F=6QL>2!Q=6%L:69I960@9FEL96YA;64@;V8@=&AI<R!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!&=6QL>2!Q=6%L:69I960@9FEL96YA;64@
M;V8@=&AI<R!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE&=6QL
M4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR97`M/G-O=7)C
M97)O;W0H*2`N("<O)R`N("1T:&ES+3YQ=65R>4UO9'5L95!A=&@H*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;F%M92!O9B!T:&ES(&9I
M;&4@<F5L871I=F4@=&\@:71S('-O=7)C97)O;W0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%!A=&AN86UE(')E;&%T:79E('1O('1H92!S;W5R
M8V5R;V]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>4UO9'5L95!A=&@H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&ER("X@)R\G("X@)'1H
M:7,M/FYA;64["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N(&QO9R!C;&%S<RX*
M("H*("H@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J
M"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO
M<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U],;V=?<W9N('L*"B`@
M("!V87(@)')E<#L*("`@('9A<B`D97)R.PH@("`@=F%R("1F:6QE.PH@("`@
M=F%R("1F:6QE<SL*("`@('9A<B`D=&%G<SL*("`@('9A<B`D<F5V.PH@("`@
M=F%R("1D871E.PH@("`@=F%R("1L;V<["B`@("!V87(@)&%U=&AO<CL*("`@
M('9A<B`D<W1A=&4["B`@("!V87(@)&QI;F5S.PH@("`@=F%R("1B<F%N8VAE
M<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!60U],;V=?<W9N*"1R97`L("8D9FPI"B`@("!["B`@("`@("`@
M)'1H:7,M/G)E<"`]("1R97`["B`@("`@("`@)'1H:7,M/F9I;&4@/2`F)&9L
M.PH@("`@("`@("1T:&ES+3YB<F%N8VAE<R`](&%R<F%Y*"D["B`@("!]"@H@
M("`@9G5N8W1I;VX@<')O8V5S<TQO9R@D<&EP92D*("`@('L*("`@("`@("`D
M;&EN92`](&9G971S*"1P:7!E*3L*"B`@("`@("`@:68@*&9E;V8H)'!I<&4I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O7G(H6S`M.5TJ*2!<?"`H+BH_*2!<?"`H
M+BHI(%PH+BI<*2!<?"`H6S`M.5TJ*2!L:6YE<S\D+R<L("1L:6YE+"`D;6%T
M8VAE<RDI('L*("`@("`@("`@("`@)'1H:7,M/G)E=B`]("1M871C:&5S6S%=
M.PH@("`@("`@("`@("`D=&AI<RT^875T:&]R(#T@)&UA=&-H97-;,ET["B`@
M("`@("`@("`@("1T:&ES+3YD871E(#T@<W1R=&]T:6UE*"1M871C:&5S6S-=
M*3L*("`@("`@("`@("`@)'-I>F4@/2`D;6%T8VAE<ULT73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^97)R(#T@)&QI;F4["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&9G971S
M*"1P:7!E*3L*"B`@("`@("`@)'1H:7,M/F9I;&5S(#T@87)R87DH*3L*("`@
M("`@("!W:&EL92`H*"1L:6YE(#T@=')I;2AF9V5T<R@D<&EP92DI*2`A/2`G
M)RD@>PH@("`@("`@("`@("`D=&AI<RT^9FEL97-;72`]("1L:6YE.PH@("`@
M("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I("$]("1S:7IE.R`K*R1I
M*2!["B`@("`@("`@("`@("1T:&ES+3YL;V<@/2`D=&AI<RT^;&]G("X@8VAO
M<"AF9V5T<R@D<&EP92DI("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3YL;V<@/2!C:&]P*"1T:&ES+3YL;V<I.PH@("`@("`@(&9G971S*"1P
M:7!E*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I
M;VX@<75E<GE$871E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1A
M=&4["B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE2979I<VEO;B@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YR978["B`@("!]"@H@("`@9G5N8W1I
M;VX@<75E<GE!=71H;W(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M875T:&]R.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y3&]G*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/FQO9SL*("`@('T*"B`@("!F=6YC=&EO
M;B!Q=65R>4-H86YG961,:6YE<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1T:&ES+3YL:6YE<RD@/R`H)'1H:7,M/FQI;F5S*2`Z("<G.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1VEV96X@82!B<F%N8V@@<F5V:7-I;VX@;G5M
M8F5R+"!T:&ES(&9U;F-T:6]N(')E;6%P<R!I=`H@("`@("H@86-C;W)D:6YG
M;'DL(&%N9"!P97)F;W)M<R!A(&QO;VMU<"!O;B!T:&4@9FEL92!O8FIE8W0@
M=&\*("`@("`J(')E='5R;B!T:&4@<WEM8F]L:6,@;F%M92AS*2!O9B!T:&%T
M(&)R86YC:"!I;B!T:&4@=')E92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&AA
M<V@@;V8@<WEM8F]L:6,@;F%M97,@/3X@8G)A;F-H(&YU;6)E<G,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<75E<GE3>6UB;VQI8T)R86YC:&5S*"D*("`@('L*
M("`@("`@("`D<WEM0G)A;F-H97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YB<F%N8VAE<R!A<R`D8G)A;F-H*2!["B`@("`@("`@("`@
M("1P87)T<R`](&5X<&QO9&4H)RXG+"`D8G)A;F-H*3L*("`@("`@("`@("`@
M)&QA<W0@/2!A<G)A>5]P;W`H)'!A<G1S*3L*("`@("`@("`@("`@)'!A<G1S
M6UT@/2`G,"<["B`@("`@("`@("`@("1P87)T<UM=(#T@)&QA<W0["B`@("`@
M("`@("`@("1R978@/2!I;7!L;V1E*"<N)RP@)'!A<G1S*3L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YF:6QE+3YB<F%N8VAE<ULD8G)A;F-H72DI
M('L*("`@("`@("`@("`@("`@("1S>6U"<F%N8VAE<ULD=&AI<RT^9FEL92T^
M8G)A;F-H97-;)&)R86YC:%U=(#T@)&)R86YC:#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)'-Y;4)R86YC:&5S.PH@("`@?0H*
M?0H*+RHJ"B`J(%9#7W-V;B!0871C:'-E="!C;&%S<RX*("H*("H@0V]P>7)I
M9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@
M*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G
M/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?4&%T8VAS971?<W9N('L*
M"B`@("!V87(@)%]R97`["B`@("!V87(@)%]F:6QE.PH@("`@=F%R("1?<&%T
M8VAS971S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-R96%T92!A('!A
M=&-H<V5T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE("!4:&4@9FEL96YA;64@=&\@9V5T('!A=&-H<V5T<R!F;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%9#7U!A=&-H<V5T7W-V;B@D9FEL92D*("`@('L*
M("`@("`@("`D=&AI<RT^7V9I;&4@/2`D9FEL93L*("`@('T*"B`@("!F=6YC
M=&EO;B`F9V5T4&%T8VAS971/8FIE8W0H)B1R97`L("1F:6QE;F%M92P@)&-A
M8VAE(#T@;G5L;"D*("`@('L*("`@("`@("`O*BH*("`@("`@("`@*B!4:&4@
M=F5R<VEO;B!O9B!T:&4@8V%C:&5D(&1A=&$N($EN8W)E;65N="!T:&ES('=H
M96YE=F5R('1H90H@("`@("`@("`J(&EN=&5R;F%L('-T;W)A9V4@9F]R;6%T
M(&-H86YG97,L('-U8V@@=&AA="!W92!M=7-T"B`@("`@("`@("H@:6YV86QI
M9&%T92!P<FEO<B!C86-H960@9&%T82X*("`@("`@("`@*B\*("`@("`@("`D
M8V%C:&5697)S:6]N(#T@,3L*("`@("`@("`D8V%C:&5)9"`]("1R97`M/G-O
M=7)C97)O;W0H*2`N("=?;B<@+B`D9FEL96YA;64@+B`G7V9?=B<@+B`D8V%C
M:&5697)S:6]N.PH*("`@("`@("!I9B`H)&-A8VAE("8F"B`@("`@("`@("`@
M("\O(%1H92!F:6QE(&ES(&-A8VAE9"!F;W(@;VYE(&AO=7(@;F\@;6%T=&5R
M('=H870L(&)E8V%U<V4*("`@("`@("`@("`@+R\@=&AE<F4@:7,@;F\@=V%Y
M('1O(&1E=&5R;6EN92!W:71H('-V;B!T:&4@=&EM92!T:&4@9FEL90H@("`@
M("`@("`@("`O+R!L87-T(&-H86YG960N"B`@("`@("`@("`@("1C86-H92T^
M97AI<W1S*"1C86-H94ED+"`S-C`P*2D@>PH@("`@("`@("`@("`D<'-/8B`]
M('5N<V5R:6%L:7IE*"1C86-H92T^9V5T*"1C86-H94ED+"`S-C`P*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!S3V(@/2`F;F5W(%9#7U!A
M=&-H<V5T7W-V;B@D9FEL96YA;64I.PH*("`@("`@("`@("`@:68@*"1C86-H
M92D@>PH@("`@("`@("`@("`@("`@)&-A8VAE+3YS970H)&-A8VAE260L('-E
M<FEA;&EZ92@D<'-/8BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D<'-/8BT^7W)E<"`]("8D<F5P.PH*("`@("`@("!I9B`H:7-?82@H
M)')E<W5L="`]("1P<T]B+3YG9710871C:'-E=',H)')E<"DI+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1P<T]B.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4&]P=6QA=&4@=&AE(&]B:F5C="!W:71H(&EN9F]R;6%T:6]N(&%B;W5T
M('1H92!P871C:'-E=',@=&AA=`H@("`@("H@=&AI<R!F:6QE(&ES(&EN=F]L
M=F5D(&EN+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E<&]S:71O
M<GD@(%1H92!F=6QL(')E<&]S:71O<GD@;&]C871I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(L
M(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&%T8VAS971S*"1R97!O<VET;W)Y*0H@("`@>PH@("`@("`@("1F:6QE3V(@
M/2`F;F5W(%9#7T9I;&5?<W9N*"1T:&ES+3Y?<F5P+"`D=&AI<RT^7V9I;&4I
M.PH@("`@("`@(&EF("AI<U]A*"@D<F5S=6QT(#T@)&9I;&5/8BT^9V5T0G)O
M=W-E26YF;R@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%T8VAS
M971S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9FEL94]B+3YL;V=S
M(&%S("1R978@/3X@)&QO9RD@>PH@("`@("`@("`@("`D=&AI<RT^7W!A=&-H
M<V5T<ULD<F5V72`](&%R<F%Y*"D["B`@("`@("`@("`@("1T:&ES+3Y?<&%T
M8VAS971S6R1R979=6R=D871E)UT@/2`D;&]G+3YQ=65R>41A=&4H*3L*("`@
M("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)')E=EU;)V%U=&AO<B==(#T@
M)&QO9RT^<75E<GE!=71H;W(H*3L*("`@("`@("`@("`@)'1H:7,M/E]P871C
M:'-E='-;)')E=EU;)V)R86YC:"==(#T@)R<["B`@("`@("`@("`@("1T:&ES
M+3Y?<&%T8VAS971S6R1R979=6R=T86<G72`]("<G.PH@("`@("`@("`@("`D
M=&AI<RT^7W!A=&-H<V5T<ULD<F5V75LG;&]G)UT@/2`D;&]G+3YQ=65R>4QO
M9R@I.PH@("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD<F5V75LG;65M
M8F5R<R==(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&QO9RT^
M9FEL97,@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@("1A8W1I;VX@/2!S
M=6)S='(H)&9I;&4L(#`L(#$I.PH@("`@("`@("`@("`@("`@)&9I;&4@/2!P
M<F5G7W)E<&QA8V4H)R\N*C]<<R@N*C\I*%QS?"0I+BHO)RP@)UQ<,2<L("1F
M:6QE*3L*("`@("`@("`@("`@("`@("1T;R`]("1R978["B`@("`@("`@("`@
M("`@("!I9B`H)&%C=&EO;B`]/2`G02<I('L*("`@("`@("`@("`@("`@("`@
M("`D9G)O;2`]("=)3DE424%,)SL*("`@("`@("`@("`@("`@('T@96QS96EF
M("@D86-T:6]N(#T]("=$)RD@>PH@("`@("`@("`@("`@("`@("`@("1F<F]M
M(#T@)'1O.PH@("`@("`@("`@("`@("`@("`@("1T;R`]("<H1$5!1"DG.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O
M+R!4:&ES('1E8VAN:6-A;&QY(&ES;B=T('1H92!P<F5V:6]U<R!R979I<VEO
M;BP*("`@("`@("`@("`@("`@("`@("`O+R!B=70@:70@=V]R:W,@9F]R(&1I
M9F9I;F<@<'5R<&]S97,N"B`@("`@("`@("`@("`@("`@("`@)&9R;VT@/2`D
M=&\@+2`Q.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%T8VAS971S6R1R979=6R=M96UB97)S)UU;72`](&%R<F%Y*"=F
M:6QE)R`]/B`D9FEL92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F<F]M)R`]/B`D9G)O
M;2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T;R<@/3X@)'1O*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]097)M<R\`````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-S$`,#$W,S(Q`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<```````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`V-C0V,@`Q,#0Q-S,V,C<W,0`P,C$V,S8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G2&]R9&4O1&%T851R964N<&AP)SL*"B\J*@H@*B!4:&4@4&5R
M;7-?9&%T871R964Z.B!C;&%S<R!P<F]V:61E<R!A($1A=&%4<F5E(&1R:79E
M<B!F;W(@=&AE($AO<F1E"B`J('!E<FUI<W-I;VYS('-Y<W1E;2X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP+'8@
M,2XV+C(N,3`@,C`P-B\P,2\P."`Q-SHU,#HT-B!C:'5C:R!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO
M<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U!E<FUS"B`J+PIC;&%S<R!0
M97)M<U]D871A=')E92!E>'1E;F1S(%!E<FUS('L*"B`@("`O*BH*("`@("`J
M(%!O:6YT97(@=&\@82!$871A5')E92!I;G-T86YC92!T;R!M86YA9V4@=&AE
M(&1I9F9E<F5N=`H@("`@("H@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@
M0'9A<B!$871A5')E90H@("`@("HO"B`@("!V87(@)%]D871A=')E93L*"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!097)M<U]D871A=')E92@I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF
M.PH*("`@("`@("!I9B`H96UP='DH)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E
M<B==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)UEO=2!M=7-T(&-O
M;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E('1H92!097)M<R!$
M871A5')E92!D<FEV97(N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@("1D<FEV97(@/2`D8V]N9ELG9&%T871R964G75LG9')I
M=F5R)UT["B`@("`@("`@)'1H:7,M/E]D871A=')E92`]("9$871A5')E93HZ
M<VEN9VQE=&]N*"1D<FEV97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*$AO<F1E.CIG971$
M<FEV97)#;VYF:6<H)V1A=&%T<F5E)RP@)&1R:79E<BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=G<F]U<"<@/3X@)VAO<F1E+G!E<FUS)RDI*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%V86EL86)L92!P97)M:7-S
M:6]N<R!F;W(@82!G:79E;B!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@<&5R;6ES<VEO;B=S(&YA;64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@879A:6QA8FQE('!E
M<FUI<W-I;VYS(&%N9"!T:&5I<B!T:71L97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%V86EL86)L92@D;F%M92D*("`@('L*("`@("`@("!I9B`H)&YA
M;64@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`D;F%M92`]("<G
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@<&%R96YT.CIG971!=F%I;&%B
M;&4H)&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@82!P97)M
M:7-S:6]N(&YA;64L(')E='5R;G,@=&AE('1I=&QE(&9O<B!T:&%T('!E<FUI
M<W-I;VX@8GD*("`@("`J(&QO;VMI;F<@:70@=7`@:6X@=&AE(&%P<&QI8V%T
M:6]N<R=S('!E<FUI<W-I;VX@87!I+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!P97)M:7-S:6]N<R=S(&YA;64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T:71L92!F;W(@=&AE('!E<FUI
M<W-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1I=&QE*"1N86UE*0H@
M("`@>PH@("`@("`@(&EF("@D;F%M92`]/2!$051!5%)%15]23T]4*2!["B`@
M("`@("`@("`@(')E='5R;B!?*")!;&P@4&5R;6ES<VEO;G,B*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ9V5T5&ET;&4H)&YA;64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&YE=R!P97)M:7-S:6]N
M<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE('!E<FUI<W-I;VXG<R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@
M1&%T851R965/8FIE8W1?4&5R;6ES<VEO;G,@($$@;F5W('!E<FUI<W-I;VYS
M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)FYE=U!E<FUI<W-I;VXH
M)&YA;64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1N86UE*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4&5R;6ES<VEO;B!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>2<I.PH@("`@("`@('T*"B`@("`@("`@
M)'1Y<&4@/2`G;6%T<FEX)SL*("`@("`@("`D<&%R86US(#T@;G5L;#L*("`@
M("`@("!I9B`H)'!O<R`]('-T<G!O<R@D;F%M92P@)SHG*2D@>PH@("`@("`@
M("`@("`D:6YF;R`]("1T:&ES+3YG971!<'!L:6-A=&EO;E!E<FUI<W-I;VYS
M*'-U8G-T<B@D;F%M92P@,"P@)'!O<RDI.PH@("`@("`@("`@("!I9B`H(6ES
M7V$H)&EN9F\L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D:6YF;ULG='EP92==*2`F)B!I<W-E="@D:6YF;ULG='EP92==
M6R1N86UE72DI('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]("1I;F9O
M6R=T>7!E)UU;)&YA;65=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1I;F9O6R=P87)A;7,G72D@)B8@:7-S970H)&EN
M9F];)W!A<F%M<R==6R1N86UE72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<&%R86US(#T@)&EN9F];)W!A<F%M<R==6R1N86UE73L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<&5R;2`]
M("9N97<@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B@D;F%M92P@)'1Y<&4L
M("1P87)A;7,I.PH@("`@("`@("1P97)M+3YS971$871A5')E92@D=&AI<RT^
M7V1A=&%T<F5E*3L*"B`@("`@("`@<F5T=7)N("1P97)M.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I
M;VX@;V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE"B`@("`@*B!N86UE9"!P
M97)M:7-S:6]N+"!W:71H('1H92!U<V5R<R!A;F0@;W1H97(@9&%T82!R971R
M:65V960*("`@("`J(&%P<')O<')I871E;'DN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE('!E<FUI<W-I;VX@
M=&\@<F5T<FEE=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971097)M:7-S
M:6]N*"1N86UE*0H@("`@>PH@("`@("`@("\J($-A8VAE(&]F('!R979I;W5S
M;'D@<F5T<FEE=F5D('!E<FUI<W-I;VYS+B`J+PH@("`@("`@('-T871I8R`D
M<&5R;7-#86-H92`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI<W-E="@D<&5R
M;7-#86-H95LD;F%M95TI*2!["B`@("`@("`@("`@(')E='5R;B`D<&5R;7-#
M86-H95LD;F%M95T["B`@("`@("`@?0H*("`@("`@("`D<&5R;7-#86-H95LD
M;F%M95T@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W0H)&YA;64L("=$
M871A5')E94]B:F5C=%]097)M:7-S:6]N)RD["B`@("`@("`@<F5T=7)N("1P
M97)M<T-A8VAE6R1N86UE73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!$871A5')E94]B:F5C=%]097)M:7-S:6]N(&]B:F5C="!C;W)R97-P
M;VYD:6YG('1O('1H92!G:79E;@H@("`@("H@=6YI<75E($E$+"!W:71H('1H
M92!U<V5R<R!A;F0@;W1H97(@9&%T82!R971R:65V960@87!P<F]P<FEA=&5L
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VED("!4:&4@=6YI
M<75E($E$(&]F('1H92!P97)M:7-S:6]N('1O(')E=')I979E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F9V5T4&5R;6ES<VEO;D)Y260H)&-I9"D*("`@('L*
M("`@("`@("`D;V)J96-T(#T@)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T
M0GE)9"@D8VED+"`G1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B<I.PH@("`@
M("`@(')E='5R;B`D;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@061D
M<R!A('!E<FUI<W-I;VX@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X@5&AE
M('!E<FUI<W-I;VX@;75S="!F:7)S=`H@("`@("H@8F4@8W)E871E9"!W:71H
M(%!E<FTZ.FYE=U!E<FUI<W-I;VXH*2P@86YD(&AA=F4@86YY(&EN:71I86P@
M=7-E<G,*("`@("`J(&%D9&5D('1O(&ET+"!B969O<F4@=&AI<R!F=6YC=&EO
M;B!I<R!C86QL960N"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J
M96-T7U!E<FUI<W-I;VX@)'!E<FT@(%1H92!N97<@<&5R;2!O8FIE8W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9%!E<FUI<W-I;VXH)B1P97)M*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?82@D<&5R;2P@)T1A=&%4<F5E3V)J96-T7U!E
M<FUI<W-I;VXG*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G4&5R;6ES<VEO;G,@;75S="!B92!$871A5')E94]B:F5C=%]097)M
M:7-S:6]N(&]B:F5C=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^861D*"1P
M97)M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!P97)M:7-S
M:6]N(&9R;VT@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2!P97)M86YE;G1L>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?4&5R;6ES<VEO
M;B`D<&5R;2`@5&AE('!E<FUI<W-I;VX@=&\@<F5M;W9E+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&9O<F-E("`@("`@("`@("`@("`@("`@($9O<F-E('1O
M(')E;6]V92!E=F5R>2!C:&EL9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M
M;W9E4&5R;6ES<VEO;B@F)'!E<FTL("1F;W)C92`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?82@D<&5R;2P@)T1A=&%4<F5E3V)J96-T7U!E<FUI
M<W-I;VXG*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G4&5R;6ES<VEO;G,@;75S="!B92!$871A5')E94]B:F5C=%]097)M:7-S
M:6]N(&]B:F5C=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^<F5M;W9E*"1P
M97)M+3YG971.86UE*"DL("1F;W)C92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6YD<R!O=70@=VAA="!R:6=H=',@=&AE(&=I=F5N('5S97(@:&%S('1O
M('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D<&5R
M;6ES<VEO;B`@5&AE(&9U;&P@<&5R;6ES<VEO;B!N86UE(&]F('1H92!O8FIE
M8W0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8VAE8VL@
M=&AE('!E<FUI<W-I;VYS(&]F+"!O<B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B!O8FIE
M8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@(%1H92!U<V5R
M('1O(&-H96-K(&9O<BX@1&5F875L=',@=&\@=&AE(&-U<G)E;G0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E<BX*("`@("`J($!P87)A
M;2!S=')I;F<@)&-R96%T;W(@("`@5&AE('5S97(@=VAO(&-R96%T960@=&AE
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!(&)I=&UA
M<VL@;V8@<&5R;6ES<VEO;G,L(&$@<&5R;6ES<VEO;B!V86QU92P@;W(@86X@
M87)R87D*("`@("`J("`@("`@("`@("`@("`@(&]F('!E<FUI<W-I;VX@=F%L
M=65S('1H92!U<V5R(&AA<RP@9&5P96YD:6YG(&]N('1H90H@("`@("H@("`@
M("`@("`@("`@("`@<&5R;6ES<VEO;B!T>7!E(&%N9"!W:&5T:&5R('1H92!P
M97)M:7-S:6]N('9A;'5E(&ES"B`@("`@*B`@("`@("`@("`@("`@("!A;6)I
M9W5O=7,N($9A;'-E(&EF('1H97)E(&ES(&YO('-U8V@@<&5R;7-I<W-I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!E<FUI<W-I;VYS*"1P97)M:7-S
M:6]N+"`D=7-E<B`](&YU;&PL("1C<F5A=&]R(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H(6ES7V$H)'!E<FUI<W-I;VXL("=$871A5')E94]B:F5C=%]0
M97)M:7-S:6]N)RDI('L*("`@("`@("`@("`@)'!E<FUI<W-I;VX@/2`F)'1H
M:7,M/F=E=%!E<FUI<W-I;VXH)'!E<FUI<W-I;VXI.PH@("`@("`@("`@("!I
M9B`H:7-?82@D<&5R;6ES<VEO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)'!E<FUI<W-I;VXL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'5S97(@/3T](&YU;&PI('L*("`@("`@("`@("`@)'5S97(@
M/2!!=71H.CIG971!=71H*"D["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!T
M:&ES(&ES(&$@9W5E<W0@=7-E<BP@;VYL>2!C:&5C:R!G=65S="!P97)M:7-S
M:6]N<RX*("`@("`@("!I9B`H96UP='DH)'5S97(I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<&5R;6ES<VEO;BT^9V5T1W5E<W1097)M:7-S:6]N<R@I.PH@
M("`@("`@('T*"B`@("`@("`@+R\@268@)&-R96%T;W(@=V%S('-P96-I9FEE
M9"P@8VAE8VL@8W)E871O<B!P97)M:7-S:6]N<RX*("`@("`@("!I9B`H)&-R
M96%T;W(@(3T](&YU;&PI('L*("`@("`@("`@("`@+R\@268@=&AE('5S97(@
M:7,@=&AE(&-R96%T;W(@;V8@=&AE(&5V96YT('-E92!I9B!T:&5R90H@("`@
M("`@("`@("`O+R!A<F4@8W)E871O<B!P97)M:7-S:6]N<RX*("`@("`@("`@
M("`@:68@*'-T<FQE;B@D=7-E<BD@)B8@)'5S97(@/3T]("1C<F5A=&]R("8F
M"B`@("`@("`@("`@("`@("`H)'!E<FUS(#T@)'!E<FUI<W-I;VXM/F=E=$-R
M96%T;W)097)M:7-S:6]N<R@I*2`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1P97)M<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@0VAE8VL@=7-E<BUL979E;"!P97)M:7-S:6]N<RX*("`@("`@
M("`D=7-E<G!E<FUS(#T@)'!E<FUI<W-I;VXM/F=E=%5S97)097)M:7-S:6]N
M<R@I.PH@("`@("`@(&EF("AI<W-E="@D=7-E<G!E<FUS6R1U<V5R72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1U<V5R<&5R;7-;)'5S97)=.PH@("`@("`@
M('T*"B`@("`@("`@+R\@268@;F\@=7-E<B!P97)M:7-S:6]N<R!A<F4@9F]U
M;F0L('1R>2!G<F]U<"!P97)M:7-S:6]N<RX*("`@("`@("!I9B`H:7-S970H
M)'!E<FUI<W-I;VXM/F1A=&%;)V=R;W5P<R==*2`F)@H@("`@("`@("`@("!I
M<U]A<G)A>2@D<&5R;6ES<VEO;BT^9&%T85LG9W)O=7!S)UTI("8F"B`@("`@
M("`@("`@(&-O=6YT*"1P97)M:7-S:6]N+3YD871A6R=G<F]U<',G72DI('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@
M("`@("`@("`@("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@
M("`@("`@("`@("1C;VUP;W-I=&5?<&5R;2`](&YU;&P["B`@("`@("`@("`@
M("1T>7!E(#T@)'!E<FUI<W-I;VXM/F=E="@G='EP92<I.PH@("`@("`@("`@
M("!F;W)E86-H("@D<&5R;6ES<VEO;BT^9&%T85LG9W)O=7!S)UT@87,@)&=R
M;W5P(#T^("1P97)M*2!["B`@("`@("`@("`@("`@("!I9B`H)&=R;W5P<RT^
M=7-E<DES26Y'<F]U<"@D=7-E<BP@)&=R;W5P*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D8V]M<&]S:71E7W!E<FT@/3T](&YU;&PI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;7!O<VET95]P97)M(#T@)'1Y<&4@/3T@
M)VUA=')I>"<@/R`P(#H@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=M871R:7@G*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VUP;W-I=&5?<&5R;2!\/2`D
M<&5R;3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D8V]M<&]S:71E7W!E<FU;72`]("1P97)M.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*"1C;VUP;W-I=&5?<&5R;2`A/3T@;G5L
M;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C;VUP;W-I=&5?<&5R;3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@268@=&AE<F4@
M87)E(&1E9F%U;'0@<&5R;6ES<VEO;G,L(')E='5R;B!T:&5M+@H@("`@("`@
M(&EF("@H)'!E<FUS(#T@)'!E<FUI<W-I;VXM/F=E=$1E9F%U;'1097)M:7-S
M:6]N<R@I*2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@)'!E<FUS
M.PH@("`@("`@('T*"B`@("`@("`@+R\@3W1H97)W:7-E+"!D96YY(&%L;"!P
M97)M:7-S:6]N<R!T;R!T:&4@;V)J96-T+@H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5N:7%U92!I
M9&5N=&EF:65R(&]F('1H:7,@<&5R;6ES<VEO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B`D<&5R;6ES<VEO;B`@
M5&AE('!E<FUI<W-I;VX@;V)J96-T('1O"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9V5T('1H92!)1"!O
M9BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!U;FEQ=64@
M:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!E<FUI<W-I;VY)9"@D<&5R
M;6ES<VEO;BD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E
M92T^9V5T260H)'!E<FUI<W-I;VXM/F=E=$YA;64H*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&:6YD<R!O=70@:68@=&AE('5S97(@:&%S('1H92!S<&5C
M:69I960@<FEG:'1S('1O('1H92!G:79E;B!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@
M=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@("!4
M:&4@=7-E<B!T;R!C:&5C:R!F;W(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<&5R;2`@("`@("!4:&4@<&5R;6ES<VEO;B!L979E;"!T:&%T(&YE961S('1O
M(&)E(&-H96-K960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<BX*("`@("`J($!P87)A;2!S=')I;F<@)&-R96%T;W(@("`@(%1H92!C
M<F5A=&]R(&]F('1H92!E=F5N=`H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!T:&4@=7-E<B!H87,@=&AE('-P96-I9FEE9"!P97)M
M:7-S:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S4&5R;6ES<VEO;B@D
M<&5R;6ES<VEO;BP@)'5S97(L("1P97)M+"`D8W)E871O<B`](&YU;&PI"B`@
M("!["B`@("`@("`@<F5T=7)N("@D=&AI<RT^9V5T4&5R;6ES<VEO;G,H)'!E
M<FUI<W-I;VXL("1U<V5R+"`D8W)E871O<BD@)B`D<&5R;2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!P97)M:7-S:6]N(&5X:7-T<R!I
M;B!T:&4@<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!E
M<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N('1O(&-H96-K+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@<&5R;6ES<VEO;B!E
M>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D<&5R;6ES<VEO
M;BD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^97AI
M<W1S*"1P97)M:7-S:6]N*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!L:7-T(&]F('!A<F5N="!P97)M:7-S:6]N<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C:&EL9"`@5&AE(&YA;64@;V8@=&AE(&-H:6QD
M('1O(')E=')I979E('!A<F5N=',@9F]R+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($$@:&%S:"!W:71H(&%L;"!P87)E;G1S(&EN(&$@=')E92!F
M;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=',H)&-H:6QD
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG9710
M87)E;G1S*"1C:&EL9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&%L;"!P97)M:7-S:6]N<R!O9B!T:&4@<WES=&5M(&EN(&$@=')E92!F;W)M
M870N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I=&@@
M86QL('!E<FUI<W-I;VYS(&EN(&$@=')E92!F;W)M870N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9G9714<F5E*"D*("`@('L*("`@("`@("`D=')E92`]("1T
M:&ES+3Y?9&%T871R964M/F=E="A$051!5%)%15]&3U)-051?1DQ!5"P@1$%4
M0512145?4D]/5"P@=')U92D["B`@("`@("`@<F5T=7)N("1T<F5E.PH@("`@
M?0H*?0H*+RHJ"B`J($5X=&5N<VEO;B!O9B!T:&4@1&%T851R965/8FIE8W0@
M8VQA<W,@9F]R('-T;W)I;F<@4&5R;6ES<VEO;B!I;F9O<FUA=&EO;B!I;@H@
M*B!T:&4@1&%T851R964@9')I=F5R+B!)9B!Y;W4@=V%N="!T;R!S=&]R92!S
M<&5C:6%L:7IE9"!097)M:7-S:6]N"B`J(&EN9F]R;6%T:6]N+"!Y;W4@<VAO
M=6QD(&5X=&5N9"!T:&ES(&-L87-S(&EN<W1E860@;V8@97AT96YD:6YG"B`J
M($1A=&%4<F5E3V)J96-T(&1I<F5C=&QY+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,BXQ"B`J($!P86-K86=E($AO<F1E7U!E<FUS"B`J+PIC;&%S<R!$871A5')E
M94]B:F5C=%]097)M:7-S:6]N(&5X=&5N9',@1&%T851R965/8FIE8W0@>PH*
M("`@("\J*@H@("`@("H@5&AE($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@
M8V]N<W1R=6-T;W(N($IU<W0@;6%K97,@<W5R92!T;R!C86QL('1H90H@("`@
M("H@<&%R96YT(&-O;G-T<G5C=&]R('-O('1H870@=&AE('!E<FTG<R!N86UE
M(&ES('-E="!P<F]P97)L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@5&AE(&YA;64@;V8@=&AE('!E<FTN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T>7!E("`@5&AE('!E<FUI<W-I;VX@='EP92X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@=VET:"!A;GD@<&%R86UE=&5R
M<R!T:&%T('1H92!P97)M:7-S:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@='EP92!N965D<RX*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T851R
M965/8FIE8W1?4&5R;6ES<VEO;B@D;F%M92P@)'1Y<&4@/2`G;6%T<FEX)RP@
M)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<&%R96YT.CI$871A5')E
M94]B:F5C="@D;F%M92D["B`@("`@("`@)'1H:7,M/F1A=&%;)W1Y<&4G72`]
M("1T>7!E.PH@("`@("`@(&EF("AI<U]A<G)A>2@D<&%R86US*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^9&%T85LG<&%R86US)UT@/2`D<&%R86US.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@;VYE(&]F('1H92!A
M='1R:6)U=&5S(&]F('1H92!O8FIE8W0L(&]R(&YU;&P@:68@:70@:7-N)W0@
M9&5F:6YE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U
M=&4@(%1H92!A='1R:6)U=&4@=&\@9V5T+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!V86QU92!O9B!T:&4@871T<FEB=71E+"!O<B!N=6QL
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)&%T=')I8G5T92D*("`@('L*
M("`@("`@("`D=F%L=64@/2!P87)E;G0Z.F=E="@D871T<FEB=71E*3L*("`@
M("`@("!I9B`H)'9A;'5E(#T]/2!N=6QL("8F("1A='1R:6)U=&4@/3T@)W1Y
M<&4G*2!["B`@("`@("`@("`@("1V86QU92`]("=M871R:7@G.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@57!D871E<R!T:&4@<&5R;6ES<VEO;G,@8F%S960@;VX@9&%T82!P87-S
M960@:6X@=&AE(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M<&5R;7,@($%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE('!E<FUI<W-I;VYS('=H
M:6-H(&%R92!T;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@=7!D
M871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E4&5R;6ES<VEO;G,H
M)'!E<FUS*0H@("`@>PH@("`@("`@("1T>7!E(#T@)'1H:7,M/F=E="@G='EP
M92<I.PH*("`@("`@("!I9B`H)'1Y<&4@/3T@)VUA=')I>"<I('L*("`@("`@
M("`@("`@+RH@07)R87D@;V8@<&5R;6ES<VEO;B!T>7!E<R!T;R!I=&5R871E
M('1H<F]U9V@N("HO"B`@("`@("`@("`@("1P97)M7W1Y<&5S(#T@4&5R;7,Z
M.F=E=%!E<FUS07)R87DH*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1P97)M<R!A<R`D<&5R;5]C;&%S<R`]/B`D<&5R;5]V86QU97,I('L*("`@
M("`@("`@("`@<W=I=&-H("@D<&5R;5]C;&%S<RD@>PH@("`@("`@("`@("!C
M87-E("=D969A=6QT)SH*("`@("`@("`@("`@8V%S92`G9W5E<W0G.@H@("`@
M("`@("`@("!C87-E("=C<F5A=&]R)SH*("`@("`@("`@("`@("`@(&EF("@D
M='EP92`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P97)M7W1Y<&5S(&%S("1V86P@/3X@)&QA8F5L*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'!E<FU?=F%L=65S6R1V86Q=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%!E
M<FTH)'!E<FU?8VQA<W,L("1V86PL(&9A;'-E*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YU;G-E=%!E<FTH)'!E<FU?8VQA<W,L("1V86PL(&9A;'-E*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)'!E<FU?=F%L
M=65S*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971097)M*"1P
M97)M7V-L87-S+"`D<&5R;5]V86QU97,L(&9A;'-E*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5N<V5T
M4&5R;2@D<&5R;5]C;&%S<RP@;G5L;"P@9F%L<V4I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=U)SH*("`@("`@("`@("`@8V%S92`G9R<Z"B`@("`@("`@("`@("`@("`D
M<&5R;4ED(#T@87)R87DH)V-L87-S)R`]/B`D<&5R;5]C;&%S<R`]/2`G=2<@
M/R`G=7-E<G,G(#H@)V=R;W5P<R<I.PH@("`@("`@("`@("`@("`@+RH@1FEG
M=7)E(&]U="!W:&%T(&YA;65S('1H870@87)E('-T;W)E9"!I;B!T:&ES('!E
M<FUI<W-I;VX*("`@("`@("`@("`@("`@("`J(&-L87-S(&AA=F4@;F]T(&)E
M96X@<W5B;6ET=&5D(&9O<B!A;B!U<&1A=&4L(&EE+B!H879E(&)E96X*("`@
M("`@("`@("`@("`@("`J(')E;6]V960@96YT:7)E;'DN("HO"B`@("`@("`@
M("`@("`@("`D8W5R<F5N=%]N86UE<R`](&ES<V5T*"1T:&ES+3YD871A6R1P
M97)M261;)V-L87-S)UU=*0H@("`@("`@("`@("`@("`@("`@(#\@87)R87E?
M:V5Y<R@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==72D*("`@("`@("`@
M("`@("`@("`@("`Z(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D=7!D871E
M9%]N86UE<R`](&%R<F%Y7VME>7,H)'!E<FU?=F%L=65S*3L*("`@("`@("`@
M("`@("`@("1R96UO=F5D7VYA;65S(#T@87)R87E?9&EF9B@D8W5R<F5N=%]N
M86UE<RP@)'5P9&%T961?;F%M97,I.PH*("`@("`@("`@("`@("`@("\J(%)E
M;6]V92!A;GD@;F%M97,@=&AA="!H879E(&)E96X@8V]M<&QE=&5L>2!U;G-E
M="X@*B\*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R96UO=F5D7VYA;65S
M(&%S("1N86UE*2!["B`@("`@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M
M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75U;)&YA;65=*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`O*B!)9B!N;W1H:6YG('1O(&%C='5A
M;&QY('5P9&%T92!F:6YI<V@@=VET:"!T:&ES(&-A<V4N("HO"B`@("`@("`@
M("`@("`@("!I9B`H)'!E<FU?=F%L=65S(#T]/2!N=6QL*2!["B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@+RH@3&]O<"!T:')O=6=H('1H92!N86UE<R!A;F0@=7!D
M871E('!E<FUI<W-I;VYS(&9O<B!E86-H+B`J+PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'!E<FU?=F%L=65S(&%S("1N86UE(#T^("1N86UE7W9A;'5E
M<RD@>PH@("`@("`@("`@("`@("`@("`@("1P97)M261;)VYA;64G72`]("1N
M86UE.PH*("`@("`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)VUA=')I
M>"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!E<FU?
M='EP97,@87,@)'9A;"`]/B`D;&%B96PI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&YA;65?=F%L=65S6R1V86Q=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971097)M
M*"1P97)M260L("1V86PL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G5N<V5T4&5R;2@D<&5R;4ED+"`D=F%L+"!F86QS92D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y
M*"1N86UE7W9A;'5E<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=%!E<FTH)'!E<FU)9"P@)&YA;65?=F%L=65S+"!F86QS92D["B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G5N<V5T4&5R;2@D<&5R;4ED+"!N=6QL+"!F86QS92D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1DE8344Z(&YE961S(&1O8W,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T4&5R;2@D<&5R;4ED+"`D<&5R;6ES<VEO;BP@
M)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1P
M97)M260I*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D<&5R;4ED6R=N86UE
M)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX
M)R`F)@H@("`@("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)'!E<FU)
M9%LG8VQA<W,G75U;)'!E<FU)9%LG;F%M92==72DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M261;)VYA
M;64G75T@?#T@)'!E<FUI<W-I;VX["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==75LD
M<&5R;4ED6R=N86UE)UU=(#T@)'!E<FUI<W-I;VX["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/F=E="@G
M='EP92<I(#T]("=M871R:7@G("8F"B`@("`@("`@("`@("`@("!I<W-E="@D
M=&AI<RT^9&%T85LD<&5R;4ED72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YD871A6R1P97)M261=('P]("1P97)M:7-S:6]N.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'!E<FU)9%T@
M/2`D<&5R;6ES<VEO;CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&25A-13H@;F5E9',@
M9&]C<PH@("`@("HO"B`@("!F=6YC=&EO;B!U;G-E=%!E<FTH)'!E<FU)9"P@
M)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D<&5R;4ED*2D@>PH@("`@("`@("`@("!I9B`H96UP='DH
M)'!E<FU)9%LG;F%M92==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E
M)RD@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==75LD<&5R;4ED6R=N86UE)UU=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1P97)M261;
M)V-L87-S)UU=6R1P97)M261;)VYA;64G75T@)CT@?B1P97)M:7-S:6]N.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^9&%T85LD<&5R
M;4ED6R=C;&%S<R==75LD<&5R;4ED6R=N86UE)UU=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S
M<R==75LD<&5R;4ED6R=N86UE)UU=*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C
M;&%S<R==75LD<&5R;4ED6R=N86UE)UU=*3L*("`@("`@("`@("`@("`@(&EF
M("@D=7!D871E*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@
M)VUA=')I>"<I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M9&%T85LD<&5R;4ED72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9&%T85LD<&5R;4ED72`F/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!U;G-E="@D=&AI<RT^9&%T85LD<&5R;4ED72D["B`@("`@("`@("`@("`@
M("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M879E*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'<F%N=',@82!U<V5R(&%D9&ET
M:6]N86P@<&5R;6ES<VEO;G,@=&\@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T;R!G
M<F%N="!A9&1I=&EO;F%L('!E<FUI<W-I;VYS"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1O+@H@("`@("H@0'!A<F%M(&-O;G-T86YT
M("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E
M=&,N*2!T;R!A9&0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@
M("`@(%=H971H97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9%5S97)097)M:7-S:6]N*"1U<V5R+"`D<&5R
M;6ES<VEO;BP@)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1U<V5R*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<@)B8*
M("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S97)=
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ET@
M?#T@)'!E<FUI<W-I;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S97)=(#T@)'!E<FUI<W-I;VX["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($=R86YT<R!G=65S=',@861D:71I;VYA;"!P97)M:7-S:6]N<R!T;R!T:&ES
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI
M<W-I;VX@(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O
M(&%D9"X*("`@("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE
M=&AE<B!T;R!A=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D1W5E<W1097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7!D
M871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP
M92<I(#T]("=M871R:7@G("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD
M871A6R=G=65S="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG9W5E
M<W0G72!\/2`D<&5R;6ES<VEO;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^9&%T85LG9W5E<W0G72`]("1P97)M:7-S:6]N.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@)'1H
M:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M<F%N=',@8W)E871O<G,@861D:71I;VYA;"!P97)M:7-S:6]N<R!T;R!T:&ES
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI
M<W-I;VX@(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O
M(&%D9"X*("`@("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE
M=&AE<B!T;R!A=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D0W)E871O<E!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U
M<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T
M>7!E)RD@/3T@)VUA=')I>"<@)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M
M/F1A=&%;)V-R96%T;W(G72DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;
M)V-R96%T;W(G72!\/2`D<&5R;6ES<VEO;CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^9&%T85LG8W)E871O<B==(#T@)'!E<FUI<W-I
M;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@
M("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($=R86YT<R!A9&1I=&EO;F%L(&1E9F%U;'0@<&5R;6ES<VEO;G,@
M=&\@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&-O;G-T86YT
M("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E
M=&,N*2!T;R!A9&0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@
M("`@(%=H971H97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9$1E9F%U;'1097)M:7-S:6]N*"1P97)M:7-S
M:6]N+"`D=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/F=E="@G='EP92<I(#T]("=M871R:7@G("8F"B`@("`@("`@("`@(&ES<V5T
M*"1T:&ES+3YD871A6R=D969A=6QT)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3YD871A6R=D969A=6QT)UT@?#T@)'!E<FUI<W-I;VX["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V1E9F%U;'0G72`]("1P
M97)M:7-S:6]N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1U<&1A=&4I('L*
M("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'<F%N=',@82!G<F]U<"!A9&1I=&EO;F%L('!E<FUI
M<W-I;VYS('1O('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1G<F]U<$ED("`@("`@5&AE(&ED(&]F('1H92!G<F]U<"!T;R!G
M<F%N="!A9&1I=&EO;F%L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('!E<FUI<W-I;VYS('1O+@H@("`@("H@0'!A<F%M(&-O;G-T86YT
M("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E
M=&,N*2!T;R!A9&0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@
M("`@(%=H971H97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9$=R;W5P4&5R;6ES<VEO;B@D9W)O=7!)9"P@
M)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF
M("AE;7!T>2@D9W)O=7!)9"DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T
M<FEX)R`F)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^9&%T85LG9W)O=7!S
M)UU;)&=R;W5P261=*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG9W)O
M=7!S)UU;)&=R;W5P261=('P]("1P97)M:7-S:6]N.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=G<F]U<',G75LD9W)O=7!)
M9%T@/2`D<&5R;6ES<VEO;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=7!D
M871E*2!["B`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A('!E<FUI<W-I;VX@=&AA
M="!A('5S97(@8W5R<F5N=&QY(&AA<R!O;B!T:&ES(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@("`@(%1H92!U<V5R
M('1O(')E;6]V92!T:&4@<&5R;6ES<VEO;B!F<F]M+@H@("`@("H@0'!A<F%M
M(&-O;G-T86YT("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?
M1$5,151%+"!E=&,N*2!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E
M("`@("`@(%=H971H97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97)097)M:7-S:6]N*"1U<V5R
M+"`D<&5R;6ES<VEO;BP@)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1U<V5R*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R
M:7@G("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD871A6R=U<V5R<R==
M6R1U<V5R72DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)W5S97)S)UU;
M)'5S97)=("8]('XD<&5R;6ES<VEO;CL*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72DI('L*("`@("`@("`@("`@
M("`@('5N<V5T*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ETI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@<&5R
M;6ES<VEO;B!T:&%T(&=U97-T<R!C=7)R96YT;'D@:&%V92!O;B!T:&ES(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I
M;VX@(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E;6]V92X*("`@
M("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5M;W9E1W5E<W1097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7!D871E(#T@
M=')U92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]
M("=M871R:7@G("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD871A6R=G
M=65S="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG9W5E<W0G72`F
M/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@(&EF("@D=7!D871E*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A=&%;
M)V=U97-T)UTI.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!P97)M:7-S:6]N
M('1H870@8W)E871O<G,@8W5R<F5N=&QY(&AA=F4@;VX@=&AI<R!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S:6]N("!4
M:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E=&,N*2!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO=F4N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H971H97(@=&\@875T;VUA
M=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V
M94-R96%T;W)097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7!D871E(#T@=')U
M92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M
M871R:7@G("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD871A6R=C<F5A
M=&]R)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=C<F5A=&]R)UT@
M)CT@?B1P97)M:7-S:6]N.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A
M6R=C<F5A=&]R)UTI.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!D969A=6QT
M('!E<FUI<W-I;VX@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&-O;G-T86YT("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H4$52
M35-?1$5,151%+"!E=&,N*2!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D
M871E("`@("`@(%=H971H97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V941E9F%U;'1097)M:7-S:6]N
M*"1P97)M:7-S:6]N+"`D=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G("8F"B`@("`@("`@
M("`@(&ES<V5T*"1T:&ES+3YD871A6R=D969A=6QT)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3YD871A6R=D969A=6QT)UT@)CT@?B1P97)M:7-S:6]N.PH@
M("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=D969A=6QT)UTI.PH@("`@
M("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;6]V97,@82!P97)M:7-S:6]N('1H870@82!G<F]U<"!C
M=7)R96YT;'D@:&%S(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1G<F]U<$ED("`@("`@5&AE(&ED(&]F('1H92!G<F]U
M<"!T;R!R96UO=F4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('!E<FUI<W-I;VX@9G)O;2X*("`@("`J($!P87)A;2!C;VYS=&%N
M="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@*%!%4DU37T1%3$5412P@
M971C+BD@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7
M:&5T:&5R('1O(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B86-K96YD+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P260L("1P
M97)M:7-S:6]N+"`D=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)&=R;W5P260I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"@H@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I
M>"<@)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)V=R;W5P<R==
M6R1G<F]U<$ED72DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V=R;W5P
M<R==6R1G<F]U<$ED72`F/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@(&EF
M("AE;7!T>2@D=&AI<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P261=*2D@>PH@
M("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G
M<F]U<$ED72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1U<&1A
M=&4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P261=*3L*("`@("`@("`@("`@:68@
M*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&%N(&%R<F%Y(&]F(&%L;"!U<V5R('!E<FUI<W-I;VYS(&]N('1H
M:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M
M("!,:7-T(&]N;'D@=7-E<G,@=VET:"!T:&ES('!E<FUI<W-I;VX@;&5V96PN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@86QL
M('5S97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%L;"!U<V5R
M('!E<FUI<W-I;VYS(&9O<B!T:&ES(&]B:F5C="P@:6YD97AE9"!B>2!U<V5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9715<V5R4&5R;6ES<VEO;G,H)'!E
M<FT@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1A
M=&%;)W5S97)S)UTI('Q\("%I<U]A<G)A>2@D=&AI<RT^9&%T85LG=7-E<G,G
M72DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?2!E
M;'-E:68@*"$D<&5R;2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F1A
M=&%;)W5S97)S)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5S
M97)S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F1A
M=&%;)W5S97)S)UT@87,@)'5S97(@/3X@)'5P97)M*2!["B`@("`@("`@("`@
M("`@("!I9B`H)'5P97)M("8@)'!E<FTI('L*("`@("`@("`@("`@("`@("`@
M("`D=7-E<G-;)'5S97)=(#T@)'5P97)M.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D=7-E<G,["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9W5E<W0@
M<&5R;6ES<VEO;G,@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!4:&4@9W5E<W0@<&5R;6ES<VEO;G,@;VX@=&AI<R!O
M8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=U97-T4&5R;6ES<VEO
M;G,H*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M/F1A=&%;
M)V=U97-T)UTI(#\*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V=U97-T)UT@
M.@H@("`@("`@("`@("!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@8W)E871O<B!P97)M:7-S:6]N<R!O;B!T:&ES(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C<F5A=&]R('!E
M<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971#<F5A=&]R4&5R;6ES<VEO;G,H*0H@("`@>PH@("`@("`@(')E='5R
M;B`A96UP='DH)'1H:7,M/F1A=&%;)V-R96%T;W(G72D@/PH@("`@("`@("`@
M("`D=&AI<RT^9&%T85LG8W)E871O<B==(#H*("`@("`@("`@("`@;G5L;#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1E9F%U;'0@<&5R
M;6ES<VEO;G,@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@9&5F875L="!P97)M:7-S:6]N<R!O;B!T:&ES(&]B
M:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%!E<FUI<W-I
M;VYS*"D*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3YD871A
M6R=D969A=6QT)UTI(#\*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V1E9F%U
M;'0G72`Z"B`@("`@("`@("`@(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&%N(&%R<F%Y(&]F(&%L;"!G<F]U<"!P97)M:7-S:6]N<R!O
M;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<&5R;2`@3&ES="!O;FQY('5S97)S('=I=&@@=&AI<R!P97)M:7-S:6]N(&QE
M=F5L+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O
M(&%L;"!U<V5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;&P@
M9W)O=7`@<&5R;6ES<VEO;G,@9F]R('1H:7,@;V)J96-T+"!I;F1E>&5D(&)Y
M(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<%!E<FUI<W-I
M;VYS*"1P97)M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3YD871A6R=G<F]U<',G72D@?'P*("`@("`@("`@("`@(6ES7V%R<F%Y
M*"1T:&ES+3YD871A6R=G<F]U<',G72DI('L*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D["B`@("`@("`@?2!E;'-E:68@*"$D<&5R;2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F1A=&%;)V=R;W5P<R==.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1G<F]U<',@/2!A<G)A>2@I.PH@("`@("`@
M("`@("!F;W)E86-H("@D=&AI<RT^9&%T85LG9W)O=7!S)UT@87,@)&=R;W5P
M(#T^("1G<&5R;2D@>PH@("`@("`@("`@("`@("`@:68@*"1G<&5R;2`F("1P
M97)M*2!["B`@("`@("`@("`@("`@("`@("`@)&=R;W5P<ULD9W)O=7!=(#T@
M)&=P97)M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B`D9W)O=7!S.PH@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]097)M<R]522YP:'``````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-#4R-#,`,3`T,3<S-C(W-S$`,#(P,S4T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@4&5R;7-?54DZ.B!C;&%S<R!P<F]V:61E<R!522!M971H
M;V1S(&9O<B!T:&4@2&]R9&4@<&5R;6ES<VEO;G,*("H@<WES=&5M+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`L=B`Q+C(W
M+C(N."`R,#`V+S`Q+S`Q(#(Q.C(X.C,Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@
M*B!`<&%C:V%G92!(;W)D95]097)M<PH@*B\*8VQA<W,@4&5R;7-?54D@>PH*
M("`@("\J*@H@("`@("H@5&AE(%!E<FUS(&]B:F5C="!W92=R92!D:7-P;&%Y
M:6YG(%5)('-T=69F(&9O<BX*("`@("`J"B`@("`@*B!`=F%R(%!E<FUS"B`@
M("`@*B\*("`@('9A<B`D7W!E<FUS.PH*("`@("\J*@H@("`@("H@5&AE($AO
M<F1E7T9O<FT@;V)J96-T('1H870@=VEL;"!B92!U<V5D(&9O<B!D:7-P;&%Y
M:6YG('1H92!E9&ET(&9O<FTN"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]&
M;W)M"B`@("`@*B\*("`@('9A<B`D7V9O<FT@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@5&AE(%9A<FEA8FQE<R!O8FIE8W0@=7-E9"!I;B!(;W)D95]&;W)M
M+@H@("`@("H*("`@("`J($!V87(@5F%R:6%B;&5S"B`@("`@*B\*("`@('9A
M<B`D7W9A<G,@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE('!E<FUI<W-I
M;VX@='EP92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]T>7!E(#T@)VUA=')I>"<["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@4&5R;7,@)'!E<FUS("!4
M:&4@4&5R;7,@;V)J96-T('1O(&1I<W!L87D@54D@<W1U9F8@9F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!097)M<U]522@F)'!E<FUS*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<&5R;7,@/2`F)'!E<FUS.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&$@2&]R9&5?5')E92!R97!R97-E;G1A=&EO;B!O9B!T
M:&4@<&5R;6ES<VEO;G,@=')E92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&AT;6P@<VAO=VEN9R!T:&4@<&5R;6ES<VEO;G,@87,@82!(
M;W)D95]4<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)4<F5E*"1C
M=7)R96YT(#T@1$%40512145?4D]/5"D*("`@('L*("`@("`@("!G;&]B86P@
M)')E9VES=')Y.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1R964N
M<&AP)SL*"B`@("`@("`@+RH@1V5T('1H92!P97)M<R!T<F5E+B`J+PH@("`@
M("`@("1N;V1E<R`]("8D=&AI<RT^7W!E<FUS+3YG9714<F5E*"D["@H@("`@
M("`@("1I8V]N9&ER(#T@87)R87DH)VEC;VYD:7(G(#T^("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG971);6%G941I<B@I*3L*("`@("`@("`D<&5R;7-?;F]D
M92`]("1I8V]N9&ER("L@87)R87DH)VEC;VXG(#T^("=P97)M<RYP;F<G*3L*
M("`@("`@("`D861D(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`G*3L*("`@("`@("`D961I="`]($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O961I="YP:'`G*3L*("`@("`@
M("`D9&5L971E(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M
M<R]D96QE=&4N<&AP)RD["B`@("`@("`@)&5D:71?:6UG(#T@2&]R9&4Z.FEM
M9R@G961I="YP;F<G+"!?*")%9&ET(%!E<FUI<W-I;VXB*2D["B`@("`@("`@
M)&1E;&5T95]I;6<@/2!(;W)D93HZ:6UG*"=D96QE=&4N<&YG)RP@7R@B1&5L
M971E(%!E<FUI<W-I;VXB*2D["@H@("`@("`@("\J(%-E="!U<"!T:&4@=')E
M92X@*B\*("`@("`@("`D=')E92`]("9(;W)D95]4<F5E.CIS:6YG;&5T;VXH
M)W!E<FUS7W5I)RP@)VIA=F%S8W)I<'0G*3L*("`@("`@("`D=')E92T^<V5T
M3W!T:6]N*&%R<F%Y*"=A;'1E<FYA=&4G(#T^('1R=64L("=H:61E2&5A9&5R
M<R<@/3X@=')U92DI.PH@("`@("`@("1T<F5E+3YS971(96%D97(H87)R87DH
M87)R87DH)W=I9'1H)R`]/B`G-3`E)RDI*3L*"B`@("`@("`@9F]R96%C:"`H
M)&YO9&5S(&%S("1P97)M7VED(#T^("1N;V1E*2!["B`@("`@("`@("`@("1N
M;V1E7V-L87-S(#T@*"1C=7)R96YT(#T]("1P97)M7VED*2`_(&%R<F%Y*"=C
M;&%S<R<@/3X@)W-E;&5C=&5D)RD@.B!A<G)A>2@I.PH@("`@("`@("`@("!I
M9B`H)'!E<FU?:60@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`@
M("`@)&%D9%]I;6<@/2!(;W)D93HZ:6UG*"=P97)M<RYP;F<G+"!?*")!9&0@
M3F5W(%!E<FUI<W-I;VXB*2D["B`@("`@("`@("`@("`@("`D861D7VQI;FL@
M/2!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H)&%D9"P@)W!E<FU?
M:60G+"`D<&5R;5]I9"DL(%\H(D%D9"!.97<@4&5R;6ES<VEO;B(I*2`N("1A
M9&1?:6UG("X@)SPO83XG.PH@("`@("`@("`@("`@("`@)&)A<V5?;F]D95]P
M87)A;7,@/2`D:6-O;F1I<B`K(&%R<F%Y*"=I8V]N)R`]/B`G861M:6YI<W1R
M871I;VXN<&YG)RD["@H@("`@("`@("`@("`@("`@)'1R964M/F%D9$YO9&4H
M)'!E<FU?:60L(&YU;&PL(%\H(D%L;"!097)M:7-S:6]N<R(I+"`P+"!T<G5E
M+"`D8F%S95]N;V1E7W!A<F%M<R`K("1N;V1E7V-L87-S+"!A<G)A>2@D861D
M7VQI;FLI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1P87)E;G1?:60@/2`D=&AI<RT^7W!E<FUS+3Y?9&%T871R964M/F=E=%!A
M<F5N="@D;F]D92D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<&%R96YT
M7VED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@2&]R
M9&4Z.F9A=&%L*"1P87)E;G1?:60L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&%D9%]I;6<@/2!(
M;W)D93HZ:6UG*"=P97)M<RYP;F<G+"!?*")!9&0@0VAI;&0@4&5R;6ES<VEO
M;B(I*3L*("`@("`@("`@("`@("`@("1A9&1?;&EN:R`]($AO<F1E.CIL:6YK
M*%5T:6PZ.F%D9%!A<F%M971E<B@D861D+"`G<&5R;5]I9"<L("1P97)M7VED
M*2P@7R@B061D($-H:6QD(%!E<FUI<W-I;VXB*2D@+B`D861D7VEM9R`N("<\
M+V$^)SL*("`@("`@("`@("`@("`@("1E9&ET7VQI;FL@/2!(;W)D93HZ;&EN
M:RA5=&EL.CIA9&1087)A;65T97(H)&5D:70L("=P97)M7VED)RP@)'!E<FU?
M:60I+"!?*")%9&ET(%!E<FUI<W-I;VXB*2D@+B`D961I=%]I;6<@+B`G/"]A
M/B<["B`@("`@("`@("`@("`@("`D9&5L971E7VQI;FL@/2!(;W)D93HZ;&EN
M:RA5=&EL.CIA9&1087)A;65T97(H)&1E;&5T92P@)W!E<FU?:60G+"`D<&5R
M;5]I9"DL(%\H(D1E;&5T92!097)M:7-S:6]N(BDI("X@)&1E;&5T95]I;6<@
M+B`G/"]A/B<["B`@("`@("`@("`@("`@("`D<&5R;7-?97AT<F$@/2!A<G)A
M>2@D861D7VQI;FLL("1E9&ET7VQI;FLL("1D96QE=&5?;&EN:RD["B`@("`@
M("`@("`@("`@("`D;F%M92`]("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1N
M;V1E*3L*"B`@("`@("`@("`@("`@("`D=')E92T^861D3F]D92@D<&5R;5]I
M9"P@)'!A<F5N=%]I9"P@)&YA;64L('-U8G-T<E]C;W5N="@D;F]D92P@)SHG
M*2`K(#$L(&9A;'-E+"`D<&5R;7-?;F]D92`K("1N;V1E7V-L87-S+"`D<&5R
M;7-?97AT<F$I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M=')E92T^<V]R="@G;&%B96PG*3L*"B`@("`@("`@<F5T=7)N("1T<F5E+3YR
M96YD97)4<F5E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@86X@97AI
M<W1I;F<@9F]R;2!O8FIE8W0@=&\@=7-E(&9O<B!T:&4@961I="!F;W)M+@H@
M("`@("H*("`@("`J($!P87)A;2!(;W)D95]&;W)M("1F;W)M("!!;B!E>&ES
M=&EN9R!(;W)D95]&;W)M(&]B:F5C="!T;R!U<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$9O<FTH)B1F;W)M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M9F]R;2`]("8D9F]R;3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!A;B!E
M>&ES=&EN9R!V87)S(&]B:F5C="!T;R!U<V4@9F]R('1H92!E9&ET(&9O<FTN
M"B`@("`@*@H@("`@("H@0'!A<F%M(%9A<FEA8FQE<R`D=F%R<R`@06X@97AI
M<W1I;F<@5F%R:6%B;&5S(&]B:F5C="!T;R!U<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%9A<G,H)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M=F%R<R`]("8D=F%R<SL*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A
M(&9O<FT@=&\@861D(&$@<&5R;6ES<VEO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@4&5R;7,@)'!E<FUI<W-I;VX*("`@("`J($!P87)A;2!S=')I;F<@)&9O
M<F-E7V-H;VEC92`@268@=&AE('!E<FUI<W-I;VX@=&\@8F4@861D960@8V%N
M(&)E(&]N92!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!M86YY+"!S971T:6YG('1H:7,@=VEL;"!F;W)C92!T:&4@8VAO:6-E('1O
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]N92!P87)T
M:6-U;&%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971U<$%D9$9O<FTH)'!E
M<FUI<W-I;VXL("1F;W)C95]C:&]I8V4@/2!N=6QL*0H@("`@>PH@("`@("`@
M("\J($EN:71I86QI<V4@9F]R;2!I9B!R97%U:7)E9"X@*B\*("`@("`@("`D
M=&AI<RT^7V9O<FU);FET*"D["@H@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T
M5&ET;&4H<W!R:6YT9BA?*")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB
M)7-<(B(I+"`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^
M9V5T3F%M92@I*2DI.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T0G5T=&]N
M<RA?*")!9&0B*2P@=')U92D["B`@("`@("`@)'1H:7,M/E]V87)S+3YS970H
M)W!E<FU?:60G+"`D=&AI<RT^7W!E<FUS+3YG971097)M:7-S:6]N260H)'!E
M<FUI<W-I;VXI*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9$AI9&1E;B@G
M)RP@)W!E<FU?:60G+"`G=&5X="<L(&9A;'-E*3L*"B`@("`@("`@+RH@4V5T
M('5P('1H92!A8W1U86P@8VAI;&0@861D:6YG(&9I96QD+B`J+PH@("`@("`@
M("1C:&EL9%]P97)M<R`]("1T:&ES+3Y?<&5R;7,M/F=E=$%V86EL86)L92@D
M<&5R;6ES<VEO;BT^9V5T3F%M92@I*3L*("`@("`@("!I9B`H)&-H:6QD7W!E
M<FUS(#T]/2!F86QS92D@>PH@("`@("`@("`@("`O*B!&86QS92P@<V\@;F\@
M8VAI;&1S(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+B`J+PH@
M("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*%\H(E!E<FUI
M<W-I;VXB*2P@)V-H:6QD)RP@)VEN=F%L:60G+"!T<G5E+"!F86QS92P@;G5L
M;"P@87)R87DH7R@B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BXB*2DI.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D
M8VAI;&1?<&5R;7,I*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)&9O<F-E
M7V-H;VEC92DI('L*("`@("`@("`@("`@("`@("\J($-H;VEC92!A<G)A>2!A
M=F%I;&%B;&4L(&)U="!C:&]I8V4@8F5I;F<@9F]R8V5D+B`J+PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]V87)S+3YS970H)V-H:6QD)RP@)&9O<F-E7V-H
M;VEC92D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA
M8FQE*%\H(E!E<FUI<W-I;VYS(BDL("=C:&EL9"<L("=E;G5M)RP@=')U92P@
M=')U92P@;G5L;"P@87)R87DH)&-H:6QD7W!E<FUS*2D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!#:&]I8V4@87)R87D@879A
M:6QA8FQE+"!S;R!S970@=7`@96YU;2!F:65L9"X@*B\*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H7R@B4&5R;6ES<VEO;G,B
M*2P@)V-H:6QD)RP@)V5N=6TG+"!T<G5E+"!F86QS92P@;G5L;"P@87)R87DH
M)&-H:6QD7W!E<FUS*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A;GD@861D
M(&9O<FT@:6YP=70N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET
M:&5R(&9A;'-E(&EF('1H92!F;W)M(&1O97,@;F]T('9A;&ED871E(&-O<G)E
M8W1L>2!O<@H@("`@("H@("`@("`@("`@("`@("`@86X@87)R87D@=VET:"!A
M;&P@=&AE(&9O<FT@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!V86QI
M9&%T94%D9$9O<FTH)B1I;F9O*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M
M/E]F;W)M+3YV86QI9&%T92@D=&AI<RT^7W9A<G,I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9F]R
M;2T^9V5T26YF;R@D=&AI<RT^7W9A<G,L("1I;F9O*3L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A('!E<FUI
M<W-I;VX@961I=&EN9R!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!$871A
M5')E94]B:F5C=%]097)M:7-S:6]N("1P97)M:7-S:6]N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E='5P161I=$9O<FTH)'!E<FUI<W-I;VXI"B`@("!["B`@
M("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@26YI=&EA;&ES
M92!F;W)M(&EF(')E<75I<F5D+B`J+PH@("`@("`@("1T:&ES+3Y?9F]R;4EN
M:70H*3L*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971"=71T;VYS*%\H(E5P
M9&%T92(I+"!T<G5E*3L*("`@("`@("`D<&5R;5]I9"`]("1T:&ES+3Y?<&5R
M;7,M/F=E=%!E<FUI<W-I;VY)9"@D<&5R;6ES<VEO;BD["B`@("`@("`@)'1H
M:7,M/E]F;W)M+3YA9&1(:61D96XH)R<L("=P97)M7VED)RP@)W1E>'0G+"!F
M86QS92D["@H@("`@("`@("\J($=E="!P97)M:7-S:6]N(&-O;F9I9W5R871I
M;VXN("HO"B`@("`@("`@)'1H:7,M/E]T>7!E(#T@)'!E<FUI<W-I;VXM/F=E
M="@G='EP92<I.PH@("`@("`@("1P87)A;7,@/2`D<&5R;6ES<VEO;BT^9V5T
M*"=P87)A;7,G*3L*"B`@("`@("`@+RH@1&5F875L="!P97)M:7-S:6]N<RX@
M*B\*("`@("`@("`D<&5R;5]V86P@/2`D<&5R;6ES<VEO;BT^9V5T1&5F875L
M=%!E<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971396-T
M:6]N*"=D969A=6QT)RP@7R@B06QL($%U=&AE;G1I8V%T960@57-E<G,B*2P@
M2&]R9&4Z.FEM9R@G<&5R;7,N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E
M=$EM86=E1&ER*"=H;W)D92<I*2P@9F%L<V4I.PH*("`@("`@("`O*B!792!-
M55-4('5S92`G9&5F;'0G(&9O<B!T:&4@=F%R:6%B;&4@;F%M92!B96-A=7-E
M("=D969A=6QT)R!I<R!A"B`@("`@("`@("H@<F5S97)V960@=V]R9"!I;B!*
M879A4V-R:7!T+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA
M=')I>"<I('L*("`@("`@("`@("`@+RH@4V5T('5P('1H92!C;VQU;6YS(&9O
M<B!T:&4@<&5R;6ES<VEO;G,@;6%T<FEX+B`J+PH@("`@("`@("`@("`D8V]L
M<R`](%!E<FUS.CIG971097)M<T%R<F%Y*"D["@H@("`@("`@("`@("`O*B!$
M969I;F4@82!S:6YG;&4@;6%T<FEX(')O=R!F;W(@9&5F875L="!P97)M<RX@
M*B\*("`@("`@("`@("`@)&UA=')I>"`](&%R<F%Y*"D["B`@("`@("`@("`@
M("1M871R:7A;,%T@/2!097)M<SHZ:6YT96=E<E1O07)R87DH)'!E<FU?=F%L
M*3L*("`@("`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@G)RP@
M)V1E9FQT)RP@)VUA=')I>"<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH
M)&-O;',L(&%R<F%Y*#`@/3X@)R<I+"`D;6%T<FEX*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A
M<FEA8FQE*"<G+"`G9&5F;'0G+"`D=&AI<RT^7W1Y<&4L(&9A;'-E+"!F86QS
M92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@("1V87(M/G-E=$1E9F%U
M;'0H)'!E<FU?=F%L*3L*("`@("`@("!]"@H@("`@("`@("\J($=U97-T('!E
M<FUI<W-I;VYS+B`J+PH@("`@("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N
M+3YG971'=65S=%!E<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M
M+3YS971396-T:6]N*"=G=65S="<L(%\H(D=U97-T(%!E<FUI<W-I;VYS(BDL
M("<G+"!F86QS92D["@H@("`@("`@(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA
M=')I>"<I('L*("`@("`@("`@("`@+RH@1&5F:6YE(&$@<VEN9VQE(&UA=')I
M>"!R;W<@9F]R(&=U97-T('!E<FUS+B`J+PH@("`@("`@("`@("`D;6%T<FEX
M(#T@87)R87DH*3L*("`@("`@("`@("`@)&UA=')I>%LP72`](%!E<FUS.CII
M;G1E9V5R5&]!<G)A>2@D<&5R;5]V86PI.PH@("`@("`@("`@("`D=&AI<RT^
M7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G9W5E<W0G+"`G;6%T<FEX)RP@9F%L
M<V4L(&9A;'-E+"!N=6QL+"!A<G)A>2@D8V]L<RP@87)R87DH,"`]/B`G)RDL
M("1M871R:7@I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%R
M(#T@)B1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=G=65S="<L("1T
M:&ES+3Y?='EP92P@9F%L<V4L(&9A;'-E+"!N=6QL+"`D<&%R86US*3L*("`@
M("`@("`@("`@)'9A<BT^<V5T1&5F875L="@D<&5R;5]V86PI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,N("HO
M"B`@("`@("`@)'!E<FU?=F%L(#T@)'!E<FUI<W-I;VXM/F=E=$-R96%T;W)0
M97)M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO
M;B@G8W)E871O<B<L(%\H(D-R96%T;W(@4&5R;6ES<VEO;G,B*2P@2&]R9&4Z
M.FEM9R@G=7-E<BYP;F<G+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI+"!F86QS92D["@H@("`@("`@(&EF("@D=&AI<RT^7W1Y
M<&4@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@+RH@1&5F:6YE(&$@<VEN
M9VQE(&UA=')I>"!R;W<@9F]R(&-R96%T;W(@<&5R;7,N("HO"B`@("`@("`@
M("`@("1M871R:7@@/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6%T<FEX6S!=
M(#T@4&5R;7,Z.FEN=&5G97)4;T%R<F%Y*"1P97)M7W9A;"D["B`@("`@("`@
M("`@("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=C<F5A=&]R)RP@
M)VUA=')I>"<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)&-O;',L(&%R
M<F%Y*#`@/3X@)R<I+"`D;6%T<FEX*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G
M+"`G8W)E871O<B<L("1T:&ES+3Y?='EP92P@9F%L<V4L(&9A;'-E+"!N=6QL
M+"`D<&%R86US*3L*("`@("`@("`@("`@)'9A<BT^<V5T1&5F875L="@D<&5R
M;5]V86PI.PH@("`@("`@('T*"B`@("`@("`@+RH@57-E<G,@<&5R;6ES<VEO
M;G,N("HO"B`@("`@("`@)'!E<FU?=F%L(#T@)'!E<FUI<W-I;VXM/F=E=%5S
M97)097)M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C
M=&EO;B@G=7-E<G,G+"!?*"));F1I=FED=6%L(%5S97)S(BDL($AO<F1E.CII
M;6<H)W5S97(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*2P@9F%L<V4I.PH@("`@("`@("1A=71H(#T@)D%U=&@Z.G-I
M;F=L971O;B@D1TQ/0D%,4ULG8V]N9B==6R=A=71H)UU;)V1R:79E<B==*3L*
M("`@("`@("!I9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2D@>PH@
M("`@("`@("`@("`O*B!4:&4@875T:"!D<FEV97(@:&%S(&QI<W0@8V%P86)I
M;&ET:65S('-O('-E="!U<"!A;B!A<G)A>2!W:&EC:`H@("`@("`@("`@("`@
M*B!T:&4@;6%T<FEX(&9I96QD('1Y<&4@=VEL;"!R96-O9VYI<V4@=&\@<V5T
M('5P(&%N(&5N=6T@8F]X(&9O<@H@("`@("`@("`@("`@*B!A9&1I;F<@;F5W
M('5S97)S('1O('1H92!P97)M:7-S:6]N<R!M871R:7@N("HO"B`@("`@("`@
M("`@("1N97=?=7-E<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=7-E<E]L
M:7-T(#T@)&%U=&@M/FQI<W15<V5R<R@I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D=7-E<E]L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`D;F5W7W5S97)S(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@('-O<G0H)'5S97)?;&ES="D["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=7-E<E]L:7-T(&%S("1U<V5R*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<&5R;5]V86Q;)'5S97)=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;F5W7W5S97)S6R1U<V5R72`]("1U<V5R
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO
M(&QI<W0@8V%P86)I;&ET:65S+"!S971T:6YG('1O('1R=64@<V\@=&AA="!T
M:&4@;6%T<FEX(&9I96QD"B`@("`@("`@("`@("`J('1Y<&4@=VEL;"!O9F9E
M<B!A('1E>'0@:6YP=70@8F]X(&9O<B!A9&1I;F<@;F5W('5S97)S+B`J+PH@
M("`@("`@("`@("`D;F5W7W5S97)S(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA=')I>"<I('L*("`@("`@("`@
M("`@+RH@4V5T('5P('1H92!M871R:7@@87)R87DL(&)R96%K:6YG('5P(&5A
M8V@@<&5R;6ES<VEO;B!I;G1E9V5R"B`@("`@("`@("`@("`J(&EN=&\@86X@
M87)R87DN("!4:&4@:V5Y<R!O9B!T:&ES(&%R<F%Y('=I;&P@8F4@=&AE(')O
M=PH@("`@("`@("`@("`@*B!H96%D97)S+B`J+PH@("`@("`@("`@("`D<F]W
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1M871R:7@@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!F;W)E86-H("@D<&5R;5]V86P@87,@)'5?:60@/3X@)'5?
M<&5R;7,I('L*("`@("`@("`@("`@("`@("1R;W=S6R1U7VED72`]("1U7VED
M.PH@("`@("`@("`@("`@("`@)&UA=')I>%LD=5]I9%T@/2!097)M<SHZ:6YT
M96=E<E1O07)R87DH)'5?<&5R;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=U)RP@)VUA=')I
M>"<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)&-O;',L("1R;W=S+"`D
M;6%T<FEX+"`D;F5W7W5S97)S*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@:68@*"1N97=?=7-E<G,I('L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D;F5W7W5S97)S*2D@>PH@("`@("`@("`@("`@("`@("`@("1U
M7VX@/2!5=&EL.CIG971&;W)M1&%T82@G=5]N)RD["B`@("`@("`@("`@("`@
M("`@("`@)'5?;B`](&5M<'1Y*"1U7VY;)W4G72D@/R!N=6QL(#H@)'5?;ELG
M=2==.PH@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@/2`G/'-E;&5C
M="!N86UE/2)U7VY;=5TB/CQO<'1I;VX^)R`N(%\H(BTM('-E;&5C="`M+2(I
M("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&YE=U]U<V5R<R!A<R`D;F5W7W5S97(I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'5S97)?:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB)R`N("1N97=?
M=7-E<B`N("<B)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M
M;"`N/2`D=5]N(#T]("1N97=?=7-E<B`_("<@<V5L96-T960](G-E;&5C=&5D
M(B<@.B`G)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M;"`N
M/2`G/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1N97=?=7-E<BD@+B`G/"]O<'1I
M;VX^)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)'5S97)?:'1M;"`N/2`G/"]S96QE8W0^)SL*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M;"`]("<\
M:6YP=70@='EP93TB=&5X="(@;F%M93TB=5]N6W5=(B`O/B<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A
M<FEA8FQE*"1U<V5R7VAT;6PL("=U7VY;=ETG+"`D=&AI<RT^7W1Y<&4L(&9A
M;'-E+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@9F]R96%C:"`H)'!E<FU?=F%L(&%S("1U7VED(#T^("1U7W!E
M<FUS*2!["B`@("`@("`@("`@("`@("`D=F%R(#T@)B1T:&ES+3Y?9F]R;2T^
M861D5F%R:6%B;&4H)'5?:60L("=U7W9;)R`N("1U7VED("X@)UTG+"`D=&AI
M<RT^7W1Y<&4L(&9A;'-E+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@
M("`@("`@("`@("`D=F%R+3YS971$969A=6QT*"1U7W!E<FUS*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@1W)O=7!S('!E<FUI<W-I
M;VYS+B`J+PH@("`@("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG971'
M<F]U<%!E<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS9713
M96-T:6]N*"=G<F]U<',G+"!?*")'<F]U<',B*2P@2&]R9&4Z.FEM9R@G9W)O
M=7`N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D
M92<I*2P@9F%L<V4I.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O
M=7`N<&AP)SL*("`@("`@("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH
M*3L*("`@("`@("`D9W)O=7!?;&ES="`]("1G<F]U<',M/FQI<W1'<F]U<',H
M*3L*("`@("`@("!I9B`H(65M<'1Y*"1G<F]U<%]L:7-T*2D@>PH@("`@("`@
M("`@("`O*B!4:&5R92!I<R!A;B!A=F%I;&%B;&4@;&ES="!O9B!G<F]U<',@
M<V\@<V5T('5P(&%N(&%R<F%Y('=H:6-H"B`@("`@("`@("`@("`J('1H92!M
M871R:7@@9FEE;&0@='EP92!W:6QL(')E8V]G;FES92!T;R!S970@=7`@86X@
M96YU;2!B;W@@9F]R"B`@("`@("`@("`@("`J(&%D9&EN9R!N97<@9W)O=7!S
M('1O('1H92!P97)M:7-S:6]N<R!M871R:7@N("HO"B`@("`@("`@("`@("1N
M97=?9W)O=7!S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&=R
M;W5P7VQI<W0@87,@)&=R;W5P260@/3X@)&=R;W5P*2!["B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1P97)M7W9A;%LD9W)O=7!)9%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&YE=U]G<F]U<'-;)&=R;W5P261=(#T@)&=R;W5P
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+RH@1&\@;F]T(&]F9F5R(&$@=&5X="!B;W@@
M=&\@861D(&YE=R!G<F]U<',N("HO"B`@("`@("`@("`@("1N97=?9W)O=7!S
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E
M(#T]("=M871R:7@G*2!["B`@("`@("`@("`@("\J(%-E="!U<"!T:&4@;6%T
M<FEX(&%R<F%Y+"!B<F5A:R!U<"!E86-H('!E<FUI<W-I;VX@:6YT96=E<B!I
M;G1O"B`@("`@("`@("`@("`J(&%N(&%R<F%Y+B!4:&4@:V5Y<R!O9B!T:&ES
M(&%R<F%Y('=I;&P@8F4@=&AE(')O=R!H96%D97)S+B`J+PH@("`@("`@("`@
M("`D<F]W<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1M871R:7@@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]V86P@87,@)&=?:60@
M/3X@)&=?<&5R;7,I('L*("`@("`@("`@("`@("`@("1R;W=S6R1G7VED72`]
M(&ES<V5T*"1G<F]U<%]L:7-T6R1G7VED72D@/R`D9W)O=7!?;&ES=%LD9U]I
M9%T@.B`D9U]I9#L*("`@("`@("`@("`@("`@("1M871R:7A;)&=?:61=(#T@
M4&5R;7,Z.FEN=&5G97)4;T%R<F%Y*"1G7W!E<FUS*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G
M9R<L("=M871R:7@G+"!F86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS
M+"`D<F]W<RP@)&UA=')I>"P@)&YE=U]G<F]U<',I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)&YE=U]G<F]U<',I('L*("`@("`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D;F5W7V=R;W5P<RDI('L*("`@("`@("`@
M("`@("`@("`@("`D9U]N(#T@571I;#HZ9V5T1F]R;41A=&$H)V=?;B<I.PH@
M("`@("`@("`@("`@("`@("`@("1G7VX@/2!E;7!T>2@D9U]N6R=G)UTI(#\@
M;G5L;"`Z("1G7VY;)V<G73L*("`@("`@("`@("`@("`@("`@("`D9W)O=7!?
M:'1M;"`]("<\<V5L96-T(&YA;64](F=?;EMG72(^/&]P=&EO;CXG("X@7R@B
M+2T@<V5L96-T("TM(BD@+B`G/"]O<'1I;VX^)SL*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;F5W7V=R;W5P<R!A<R`D9W)O=7!)9"`]/B`D9W)O
M=7`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P7VAT;6P@+CT@
M)SQO<'1I;VX@=F%L=64](B<@+B`D9W)O=7!)9"`N("<B)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@)&=R;W5P7VAT;6P@+CT@)&=?;B`]/2`D9W)O=7!)
M9"`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@)&=R;W5P7VAT;6P@+CT@)SXG("X@:'1M;'-P96-I86QC
M:&%R<R@D9W)O=7`I("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1G<F]U<%]H=&UL("X]("<\+W-E
M;&5C=#XG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D9W)O=7!?:'1M;"`]("<\:6YP=70@='EP93TB=&5X="(@;F%M
M93TB9U]N6V==(B`O/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"1G<F]U<%]H=&UL+"`G
M9U]N6W9=)RP@)'1H:7,M/E]T>7!E+"!F86QS92P@9F%L<V4L(&YU;&PL("1P
M87)A;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1P
M97)M7W9A;"!A<R`D9U]I9"`]/B`D9U]P97)M<RD@>PH@("`@("`@("`@("`@
M("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*&ES<V5T*"1G
M<F]U<%]L:7-T6R1G7VED72D@/R`D9W)O=7!?;&ES=%LD9U]I9%T@.B`D9U]I
M9"P@)V=?=ELG("X@)&=?:60@+B`G72<L("1T:&ES+3Y?='EP92P@9F%L<V4L
M(&9A;'-E+"!N=6QL+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("1V87(M
M/G-E=$1E9F%U;'0H)&=?<&5R;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O*B!3970@9F]R;2!T:71L92X@*B\*("`@("`@("`D=&AI
M<RT^7V9O<FTM/G-E=%1I=&QE*'-P<FEN=&8H7R@B161I="!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(BDL("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1P97)M
M:7-S:6]N+3YG971.86UE*"DI*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&
M=6YC=&EO;B!T;R!V86QI9&%T92!A;GD@961I="!F;W)M(&EN<'5T+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!F86QS92!I9B!T:&4@
M9F]R;2!D;V5S(&YO="!V86QI9&%T92!C;W)R96-T;'D@;W(*("`@("`J("`@
M("`@("`@("`@("`@(&%N(&%R<F%Y('=I=&@@86QL('1H92!F;W)M('9A;'5E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5%9&ET1F]R;2@F)&EN
M9F\I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V9O<FTM/G9A;&ED871E
M*"1T:&ES+3Y?=F%R<RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YG971);F9O*"1T:&ES
M+3Y?=F%R<RP@)&EN9F\I.PH*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]
M("=M871R:7@G*2!["B`@("`@("`@("`@("\J($-O;&QA<'-E('1H92!A<G)A
M>2!F;W(@9&5F875L="]G=65S="]C<F5A=&]R+B`J+PH@("`@("`@("`@("`D
M:6YF;ULG9&5F;'0G72`](&ES<V5T*"1I;F9O6R=D969L="==6S!=*2`_("1I
M;F9O6R=D969L="==6S!=(#H@;G5L;#L*("`@("`@("`@("`@)&EN9F];)V=U
M97-T)UT@("`](&ES<V5T*"1I;F9O6R=G=65S="==6S!=*2`_("1I;F9O6R=G
M=65S="==6S!=(#H@;G5L;#L*("`@("`@("`@("`@)&EN9F];)V-R96%T;W(G
M72`](&ES<V5T*"1I;F9O6R=C<F5A=&]R)UU;,%TI(#\@)&EN9F];)V-R96%T
M;W(G75LP72`Z(&YU;&P["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'5?;B`]("1T:&ES+3Y?=F%R<RT^9V5T*"=U7VXG*3L*("`@("`@("`@("`@
M)&EN9F];)W4G72`](&%R<F%Y*"1U7VY;)W4G72`]/B`D:6YF;ULG=5]N)UU;
M)W8G72D["B`@("`@("`@("`@('5N<V5T*"1I;F9O6R=U7VXG72D["B`@("`@
M("`@("`@(&EF("AI<W-E="@D:6YF;ULG=5]V)UTI*2!["B`@("`@("`@("`@
M("`@("`D:6YF;ULG=2==(#T@87)R87E?;65R9V4H)&EN9F];)W4G72P@)&EN
M9F];)W5?=B==*3L*("`@("`@("`@("`@("`@('5N<V5T*"1I;F9O6R=U7W8G
M72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&=?;B`]("1T:&ES+3Y?
M=F%R<RT^9V5T*"=G7VXG*3L*("`@("`@("`@("`@)&EN9F];)V<G72`](&%R
M<F%Y*"1G7VY;)V<G72`]/B`D:6YF;ULG9U]N)UU;)W8G72D["B`@("`@("`@
M("`@('5N<V5T*"1I;F9O6R=G7VXG72D["B`@("`@("`@("`@(&EF("AI<W-E
M="@D:6YF;ULG9U]V)UTI*2!["B`@("`@("`@("`@("`@("`D:6YF;ULG9R==
M(#T@87)R87E?;65R9V4H)&EN9F];)V<G72P@)&EN9F];)V=?=B==*3L*("`@
M("`@("`@("`@("`@('5N<V5T*"1I;F9O6R=G7W8G72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@)&EN9F];)V1E9F%U;'0G72`]("1I;F9O
M6R=D969L="==.PH@("`@("`@('5N<V5T*"1I;F9O6R=D969L="==*3L*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&4@82!P97)M:7-S:6]N(&1E;&5T:6YG(&9O<FTN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&]B:F5C="`D<&5R;6ES<VEO;@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971U<$1E;&5T949O<FTH)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@
M+RH@26YI=&EA;&ES92!F;W)M(&EF(')E<75I<F5D+B`J+PH@("`@("`@("1T
M:&ES+3Y?9F]R;4EN:70H*3L*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YS9714
M:71L92AS<')I;G1F*%\H(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB
M(BDL("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1P97)M:7-S:6]N+3YG971.
M86UE*"DI*2D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971"=71T;VYS*&%R
M<F%Y*%\H(D1E;&5T92(I+"!?*")$;R!N;W0@9&5L971E(BDI*3L*("`@("`@
M("`D=&AI<RT^7V9O<FTM/F%D9$AI9&1E;B@G)RP@)W!E<FU?:60G+"`G=&5X
M="<L(&9A;'-E*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE
M*'-P<FEN=&8H7R@B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_(BDL("1T:&ES+3Y?<&5R;7,M/F=E=%1I
M=&QE*"1P97)M:7-S:6]N+3YG971.86UE*"DI*2P@)W!R;VUP="<L("=D97-C
M<FEP=&EO;B<L(&9A;'-E*3L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!T;R!V86QI9&%T92!A;GD@9&5L971E(&9O<FT@:6YP=70N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@268@=&AE(&1E;&5T92!B=71T;VX@
M8V]N9FER;6%T:6]N(&AA<R!B965N('!R97-S960@<F5T=7)N"B`@("`@*B`@
M("`@("`@("`@("`@("!T<G5E+"!I9B!A;GD@;W1H97(@<W5B;6ET(&)U='1O
M;B!H87,@8F5E;B!P<F5S<V5D(')E='5R;@H@("`@("H@("`@("`@("`@("`@
M("`@9F%L<V4N($EF(&9O<FT@9&ED(&YO="!V86QI9&%T92!R971U<FX@;G5L
M;"X*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5$96QE=&5&;W)M*"8D
M:6YF;RD*("`@('L*("`@("`@("`D9F]R;5]S=6)M:70@/2`D=&AI<RT^7W9A
M<G,M/F=E="@G<W5B;6ET8G5T=&]N)RD["@H@("`@("`@(&EF("@D9F]R;5]S
M=6)M:70@/3T@7R@B1&5L971E(BDI('L*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?9F]R;2T^=F%L:61A=&4H)'1H:7,M/E]V87)S*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]F;W)M+3YG971);F9O*"1T:&ES+3Y?=F%R<RP@)&EN
M9F\I.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1F;W)M7W-U8FUI="DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97)S('1H
M92!E9&ET(&9O<FTN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<D9O<FTH
M)&9O<FU?<V-R:7!T(#T@)V5D:70N<&AP)RD*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*("`@("`@("`D
M<F5N9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H*3L*("`@("`@
M("`D=&AI<RT^7V9O<FTM/G)E;F1E<D%C=&EV92@D<F5N9&5R97(L("1T:&ES
M+3Y?=F%R<RP@)&9O<FU?<V-R:7!T+"`G<&]S="<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A;GD@9F]R;2!O8FIE8W1S(&EF('1H97D@:&%V
M92!N;W0@8F5E;B!I;FET:6%L:7-E9"!Y970N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F;W)M26YI="@I
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]V87)S*2D@>PH@
M("`@("`@("`@("`O*B!.;R!E>&ES=&EN9R!V87)S('-E="P@9V5T('1H96T@
M;F]W+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA
M8FQE<RYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7W9A<G,@/2`F5F%R:6%B
M;&5S.CIG971$969A=6QT5F%R:6%B;&5S*"D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(6ES7V$H)'1H:7,M/E]F;W)M+"`G2&]R9&5?1F]R;2<I*2!["B`@
M("`@("`@("`@("\J($YO(&5X:7-T:6YG('9A;&ED(&9O<FT@;V)J96-T('-E
M="!S;R!S970@=7`@82!N97<@;VYE+B`J+PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]F
M;W)M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G)RP@)'1H:7,M/E]V87)S
M*3L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]I0V%L96YD87(O````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-S$`,#(P,3$U`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V86QA<FTN<&AP````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,W-0`Q,#0Q-S,V,C<W,0`P,C(Q
M,3,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN9R!V06QA<FUS+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]I0V%L96YD87(O:4-A;&5N9&%R+W9A;&%R
M;2YP:'`L=B`Q+C@N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C0W(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N
M9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87)?=F%L87)M(&5X=&5N9',@
M2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@
M('L*("`@("`@("!R971U<FX@)W9!;&%R;2<["B`@("!]"@H@("`@9G5N8W1I
M;VX@<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R96YT
M.CIP87)S979#86QE;F1A<B@D9&%T82P@)U9!3$%232<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@("`@<F5T
M=7)N('!A<F5N=#HZ7V5X<&]R='9$871A*"=604Q!4DTG*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V8V%R9"YP:'``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S(T,0`Q,#0Q-S,V,C<W
M,0`P,C$W,C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H
M<"<["@HO+R!4:&4@9F]L;&]W:6YG('=E<F4@<VAA;65L97-S;'D@>6]I;FME
M9"!F<F]M($-O;G1A8W1?5F-A<F1?0G5I;&0*+R\@4&%R="!N=6UB97)S(&9O
M<B!.(&-O;7!O;F5N=',N"F1E9FEN92@G5D-!4D1?3E]&04U)3%DG+"`@("`@
M,"D["F1E9FEN92@G5D-!4D1?3E]'259%3B<L("`@("`@,2D["F1E9FEN92@G
M5D-!4D1?3E]!1$1,)RP@("`@("`@,BD["F1E9FEN92@G5D-!4D1?3E]04D5&
M25@G+"`@("`@,RD["F1E9FEN92@G5D-!4D1?3E]3549&25@G+"`@("`@-"D[
M"@HO+R!087)T(&YU;6)E<G,@9F]R($%$4B!C;VUP;VYE;G1S+@ID969I;F4H
M)U9#05)$7T%$4E]03T(G+"`@("`@(#`I.PID969I;F4H)U9#05)$7T%$4E]%
M6%1%3D0G+"`@(#$I.PID969I;F4H)U9#05)$7T%$4E]35%)%150G+"`@(#(I
M.PID969I;F4H)U9#05)$7T%$4E],3T-!3$E462<L(#,I.PID969I;F4H)U9#
M05)$7T%$4E]214=)3TXG+"`@(#0I.PID969I;F4H)U9#05)$7T%$4E]03U-4
M0T]$12<L(#4I.PID969I;F4H)U9#05)$7T%$4E]#3U5.5%)9)RP@(#8I.PH*
M+R\@4&%R="!N=6UB97)S(&9O<B!'14\@8V]M<&]N96YT<RX*9&5F:6YE*"=6
M0T%21%]'14]?3$%4)RP@("`@("`P*3L*9&5F:6YE*"=60T%21%]'14]?3$].
M)RP@("`@("`Q*3L*"B\J*@H@*B!#;&%S<R!R97!R97-E;G1I;F<@=D-A<F0@
M96YT<FEE<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#
M86QE;F1A<B]V8V%R9"YP:'`L=B`Q+C,N,3`N-R`R,#`V+S`S+S`S(#`Y.C`W
M.C(Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($MA<G-T
M96X@1F]U<FUO;G0@*&MA<G-T96Y`:&]R9&4N;W)G*0H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D
M92YO<F<^"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@
M2&]R9&5?:4-A;&5N9&%R7W9C87)D(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R
M('L*"B`@("!F=6YC=&EO;B!(;W)D95]I0V%L96YD87)?=F-A<F0H)'9E<G-I
M;VX@/2`G,BXQ)RD*("`@('L*("`@("`@("!R971U<FX@<&%R96YT.CI(;W)D
M95]I0V%L96YD87(H)'9E<G-I;VXI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=F-A<F0G.PH@("`@?0H*
M("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@
M("`@(')E='5R;B!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G=F-A
M<F0G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&EK92!V979E;G0@86YD
M('9T;V1O+"!A('9C87)D(&ES(&YO<FUA;&QY(&YO="!E;F-L;W-E9"!I;B!A
M;@H@("`@("H@:4-A;&5N9&%R(&-O;G1A:6YE<BX@*$)%1TE.+BY%3D0I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@
M("`@("`@)')E<75I<F5D071T<FEB=71E<ULG0D]$62==(#T@)R<["B`@("`@
M("`@)')E<75I<F5D071T<FEB=71E<ULG5D524TE/3B==(#T@)S(N,2<["@H@
M("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9$%T=')I8G5T97,@87,@)&YA;64@
M/3X@)&1E9F%U;'1?=F%L=64I('L*("`@("`@("`@("`@:68@*&ES7V$H)'1H
M:7,M/F=E=$%T=')I8G5T92@D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)&YA;64L("1D969A
M=6QT7W9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?97AP;W)T=D1A=&$H)U9#05)$)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;VYT96YT<R!O9B!T:&4@(DXB
M('1A9R!A<R!A('!R:6YT86)L92!.86UE.@H@("`@("H@:2YE+B!C;VYV97)T
M<SH*("`@("`J"B`@("`@*B`@($XZ1'5C:SM$86=O8F5R=#M4.U!R;V9E<W-O
M<CM396XN"B`@("`@*B!T;PH@("`@("H@("`B4')O9F5S<V]R($1A9V]B97)T
M(%0@1'5C:R!396XB"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($9U
M;&P@;F%M92!O9B!V8V%R9"`B3B(@=&%G"B`@("`@*B`@("`@("`@("`@("`@
M("`@;W(@;G5L;"!I9B!N;R!.('1A9RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<')I;G1A8FQE3F%M92@I"B`@("!["B`@("`@("`@)&YA;65?<&%R=',@/2`D
M=&AI<RT^9V5T071T<FEB=71E5F%L=65S*"=.)RD["B`@("`@("`@:68@*&ES
M7V$H)&YA;65?<&%R=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1N
M86UE7W!A<G1S6U9#05)$7TY?4%)%1DE872DI('L*("`@("`@("`@("`@)&YA
M;65?87)R6UT@/2`D;F%M95]P87)T<UM60T%21%].7U!2149)6%T["B`@("`@
M("`@?0H@("`@("`@(&EF("@A96UP='DH)&YA;65?<&%R='-;5D-!4D1?3E]'
M259%3ETI*2!["B`@("`@("`@("`@("1N86UE7V%R<EM=(#T@)&YA;65?<&%R
M='-;5D-!4D1?3E]'259%3ET["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP
M='DH)&YA;65?<&%R='-;5D-!4D1?3E]!1$1,72DI('L*("`@("`@("`@("`@
M)&YA;65?87)R6UT@/2`D;F%M95]P87)T<UM60T%21%].7T%$1$Q=.PH@("`@
M("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1N86UE7W!A<G1S6U9#05)$7TY?
M1D%-24Q972DI('L*("`@("`@("`@("`@)&YA;65?87)R6UT@/2`D;F%M95]P
M87)T<UM60T%21%].7T9!34E,65T["B`@("`@("`@?0H@("`@("`@(&EF("@A
M96UP='DH)&YA;65?<&%R='-;5D-!4D1?3E]3549&25A=*2D@>PH@("`@("`@
M("`@("`D;F%M95]A<G);72`]("1N86UE7W!A<G1S6U9#05)$7TY?4U5&1DE8
M73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!I;7!L;V1E*"<@)RP@)&YA
M;65?87)R*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T871I8R!F=6YC=&EO
M;B!T;R!M86ME(&$@9VEV96X@96UA:6P@861D<F5S<R!R9F,X,C(@8V]M<&QI
M86YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')E<W,@($%N
M(&5M86EL(&%D9')E<W,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!21D,X,C(M9F]R;6%T=&5D(&5M86EL(&%D9')E<W,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$)A<F5%;6%I;"@D861D<F5S<RD*("`@('L*("`@
M("`@("`O+R!%;7!T>2!V86QU97,@87)E('-T:6QL(&5M<'1Y+@H@("`@("`@
M(&EF("@A)&%D9')E<W,I('L*("`@("`@("`@("`@<F5T=7)N("1A9&1R97-S
M.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+U)&0S@R
M,BYP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G
M.PH*("`@("`@("!S=&%T:6,@)')F8S@R,CL*("`@("`@("!I9B`H:7-?;G5L
M;"@D<F9C.#(R*2D@>PH@("`@("`@("`@("`D<F9C.#(R(#T@)FYE=R!-86EL
M7U)&0S@R,B@I.PH@("`@("`@('T*"B`@("`@("`@)')F8S@R,BT^=F%L:61A
M=&5-86EL8F]X*"1A9&1R97-S*3L*("`@("`@("!R971U<FX@34E-13HZ<F9C
M.#(R5W)I=&5!9&1R97-S*"1A9&1R97-S+3YM86EL8F]X+"`D861D<F5S<RT^
M:&]S="D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#
M86QE;F1A<B]V979E;G0N<&AP````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R,#(U-``Q,#0Q-S,V,C<W,0`P,C(Q,S4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($-L87-S(')E
M<')E<V5N=&EN9R!V179E;G1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]I
M0V%L96YD87(O:4-A;&5N9&%R+W9E=F5N="YP:'`L=B`Q+C,Q+C$P+C@@,C`P
M-B\P,2\P,2`R,3HR.#HT-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R9&5?
M:4-A;&5N9&%R7W9E=F5N="!E>'1E;F1S($AO<F1E7VE#86QE;F1A<B!["@H@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=V
M179E;G0G.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D
M871A*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A
M=&$L("=6159%3E0G*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L
M96YD87(H*0H@("`@>PH@("`@("`@("\O($1E9F%U;'0@=F%L=65S+@H@("`@
M("`@("1R97%U:7)E9$%T=')I8G5T97,@/2!A<G)A>2@I.PH@("`@("`@("1R
M97%U:7)E9$%T=')I8G5T97-;)T144U1!35`G72`]('1I;64H*3L*("`@("`@
M("`D<F5Q=6ER961!='1R:6)U=&5S6R=/4D=!3DE:15(G72`]("=5;FMN;W=N
M($]R9V%N:7IE<B<["B`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG54E$
M)UT@/2`D=&AI<RT^7V5X<&]R=$1A=&54:6UE*'1I;64H*2D@+B`G0"<@+B`H
M:7-S970H)%]315)615);)U-%4E9%4E].04U%)UTI(#\@)%]315)615);)U-%
M4E9%4E].04U%)UT@.B`G;&]C86QH;W-T)RD["@H@("`@("`@("1M971H;V0@
M/2`A96UP='DH)'1H:7,M/E]C;VYT86EN97(I(#\*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYT86EN97(M/F=E=$%T=')I8G5T92@G34542$]$)RD@.B`G4%5"
M3$E32"<["@H@("`@("`@('-W:71C:"`H)&UE=&AO9"D@>PH@("`@("`@(&-A
M<V4@)U!50DQ)4T@G.@H@("`@("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S
M6R=$5%-405)4)UT@/2!T:6UE*"D["B`@("`@("`@("`@("1R97%U:7)E9$%T
M=')I8G5T97-;)U-534U!4EDG72`]("<G.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G4D5154535"<Z"B`@("`@("`@("`@("1R97%U:7)E
M9$%T=')I8G5T97-;)T%45$5.1$5%)UT@/2`G)SL*("`@("`@("`@("`@)')E
M<75I<F5D071T<FEB=71E<ULG1%135$%25"==(#T@=&EM92@I.PH@("`@("`@
M("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=354U-05)9)UT@/2`G)SL*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)U)%4$Q9)SH*("`@("`@
M("`@("`@)')E<75I<F5D071T<FEB=71E<ULG051414Y$144G72`]("<G.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G041$)SH*("`@("`@
M("`@("`@)')E<75I<F5D071T<FEB=71E<ULG1%135$%25"==(#T@=&EM92@I
M.PH@("`@("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=315%514Y#12==
M(#T@,3L*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG4U5-34%2
M62==(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=#
M04Y#14PG.@H@("`@("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=!5%1%
M3D1%12==(#T@)R<["B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;
M)U-%455%3D-%)UT@/2`Q.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`G4D5&4D532"<Z"B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T
M97-;)T%45$5.1$5%)UT@/2`G)SL*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!F;W)E86-H("@D<F5Q=6ER961!='1R:6)U=&5S(&%S
M("1N86UE(#T^("1D969A=6QT7W9A;'5E*2!["B`@("`@("`@("`@(&EF("AI
M<U]A*"1T:&ES+3YG971!='1R:6)U=&4H)&YA;64I+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1N86UE
M+"`D9&5F875L=%]V86QU92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!P87)E;G0Z.E]E>'!O<G1V1&%T82@G5D5614Y4)RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE('-T871U<R!O9B!A
M;B!A='1E;F1E92!O9B!A;B!E=F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@
M)&5M86EL("`@(%1H92!E;6%I;"!A9&1R97-S(&]F('1H92!A='1E;F1E92X*
M("`@("`J($!P87)A;2`D<W1A='5S("`@5&AE('!A<G1I8VEP86YT('-T871U
M<R!T;R!S970N"B`@("`@*B!`<&%R86T@)&9U;&QN86UE(%1H92!F=6QL(&YA
M;64@;V8@=&AE('!A<G1I8VEP86YT('1O('-E="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=7!D871E071T96YD964H)&5M86EL+"`D<W1A='5S+"`D9G5L;&YA
M;64@/2`G)RD*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I
M8G5T97,@87,@)&ME>2`]/B`D871T<FEB=71E*2!["B`@("`@("`@("`@(&EF
M("@D871T<FEB=71E6R=N86UE)UT@/3T@)T%45$5.1$5%)R`F)B`D871T<FEB
M=71E6R=V86QU92==(#T]("=-04E,5$\Z)R`N("1E;6%I;"D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P87)A;7,G75LG
M4$%25%-4050G72`]("1S=&%T=7,["B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1F=6QL;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V%T=')I8G5T97-;)&ME>5U;)W!A<F%M<R==6R=#3B==(#T@)&9U;&QN86UE
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P87)A;7,G75LG4E-64"==*3L*("`@
M("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("`D<&%R86US(#T@87)R87DH)U!!4E135$%4)R`]/B`D<W1A='5S
M*3L*("`@("`@("!I9B`H(65M<'1Y*"1F=6QL;F%M92DI('L*("`@("`@("`@
M("`@)'!A<F%M<ULG0TXG72`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/G-E=$%T=')I8G5T92@G051414Y$144G+"`G34%)3%1/.B<@
M+B`D96UA:6PL("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!O<F=A;FEZ97(@9&ES<&QA>2!N86UE(&]R(&5M86EL+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;W)G86YI>F5R(&YA;64@
M=&\@9&ES<&QA>2!F;W(@=&AI<R!E=F5N="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;W)G86YI>F5R3F%M92@I"B`@("!["B`@("`@("`@)&]R9V%N:7IE<B`]
M("1T:&ES+3YG971!='1R:6)U=&4H)T]21T%.25I%4B<L('1R=64I.PH@("`@
M("`@(&EF("AI<U]A*"1O<F=A;FEZ97(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-S970H)&]R9V%N:7IE<ELP75LG0TXG72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1O<F=A;FEZ97);,%U;)T-.)UT["B`@("`@("`@?0H*("`@("`@("`D
M;W)G86YI>F5R(#T@<&%R<V5?=7)L*"1T:&ES+3YG971!='1R:6)U=&4H)T]2
M1T%.25I%4B<I*3L*"B`@("`@("`@<F5T=7)N("1O<F=A;FEZ97);)W!A=&@G
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!T:&ES(&5V96YT('=I
M=&@@9&5T86EL<R!F<F]M(&%N;W1H97(@979E;G0N"B`@("`@*@H@("`@("H@
M0'!A<F%M($AO<F1E7VE#86QE;F1A<E]V179E;G0@)'9E=F5N="`@5&AE('9%
M=F5N="!W:71H(&QA=&5S="!D971A:6QS+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!U<&1A=&5&<F]M=D5V96YT*"1V979E;G0I"B`@("!["B`@("`@("`@)&YE
M=T%T=')I8G5T97,@/2`D=F5V96YT+3YG971!;&Q!='1R:6)U=&5S*"D["B`@
M("`@("`@9F]R96%C:"`H)&YE=T%T=')I8G5T97,@87,@)&YE=T%T=')I8G5T
M92D@>PH@("`@("`@("`@("`D8W5R<F5N=%9A;'5E(#T@)'1H:7,M/F=E=$%T
M=')I8G5T92@D;F5W071T<FEB=71E6R=N86UE)UTI.PH@("`@("`@("`@("!I
M9B`H:7-?82@D8W5R<F5N=%9A;'5E+"`G4$5!4E]E<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`O+R!!;')E861Y(&5X:7-T<R!S;R!J=7-T(&%D9"!I="X*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)&YE=T%T=')I
M8G5T95LG;F%M92==+"`D;F5W071T<FEB=71E6R=V86QU92==+"`D;F5W071T
M<FEB=71E6R=P87)A;7,G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`O+R!!;')E861Y(&5X:7-T<R!S;R!L;V-A=&4@86YD(&UO
M9&EF>2X*("`@("`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH*("`@("`@
M("`@("`@("`@("\O(%1R>2!M871C:&EN9R!T:&4@871T<FEB=&4@;F%M92!A
M;F0@=F%L=64@:6YC87-E"B`@("`@("`@("`@("`@("`O+R!O;FQY('1H92!P
M87)A;7,@8VAA;F=E9"`H96<@871T96YD964@=7!D871I;F<*("`@("`@("`@
M("`@("`@("\O('-T871U<RDN"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7V%T=')I8G5T97,@87,@)&ED(#T^("1A='1R*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1A='1R6R=N86UE)UT@/3T@)&YE=T%T=')I8G5T
M95LG;F%M92==("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R6R=V
M86QU92==(#T]("1N97=!='1R:6)U=&5;)W9A;'5E)UTI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@;65R9V4@=&AE('!A<F%M<PH@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D;F5W071T<FEB=71E6R=P87)A;7,G
M72!A<R`D<&%R86U?:60@/3X@)'!A<F%M7VYA;64I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:61=6R=P87)A
M;7,G75LD<&%R86U?:61=(#T@)'!A<F%M7VYA;64["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@
M=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*"$D9F]U;F0I('L*("`@("`@("`@("`@("`@("`@("`O+R!%;'-E
M(&UA=&-H('1H92!F:7)S="!A='1R:6)U=&4@=VET:"!T:&4@<V%M90H@("`@
M("`@("`@("`@("`@("`@("\O(&YA;64@*&5G(&-H86YG:6YG('-T87)T('1I
M;64I+@H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T
M<FEB=71E<R!A<R`D:60@/3X@)&%T='(I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1A='1R6R=N86UE)UT@/3T@)&YE=T%T=')I8G5T95LG;F%M
M92==*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%T
M=')I8G5T97-;)&ED75LG=F%L=64G72`]("1N97=!='1R:6)U=&5;)W9A;'5E
M)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!-97)G92!T:&4@
M<&%R86US+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&YE=T%T=')I8G5T95LG<&%R86US)UT@87,@)'!A<F%M7VED(#T^("1P87)A
M;5]N86UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A='1R:6)U=&5S6R1I9%U;)W!A<F%M<R==6R1P87)A;5]I9%T@/2`D
M<&%R86U?;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@57!D871E(&IU<W0@=&AE(&%T=&5N9&5S<R!O9B!E=F5N="!W
M:71H(&1E=&%I;',@9G)O;2!A;F]T:&5R"B`@("`@*B!E=F5N="X*("`@("`J
M"B`@("`@*B!`<&%R86T@2&]R9&5?:4-A;&5N9&%R7W9%=F5N="`D=F5V96YT
M("!4:&4@=D5V96YT('=I=&@@;&%T97-T(&1E=&%I;',*("`@("`J+PH@("`@
M9G5N8W1I;VX@=7!D871E071T96YD965S1G)O;79%=F5N="@D=F5V96YT*0H@
M("`@>PH@("`@("`@("1N97=!='1R:6)U=&5S(#T@)'9E=F5N="T^9V5T06QL
M071T<FEB=71E<R@I.PH@("`@("`@(&9O<F5A8V@@*"1N97=!='1R:6)U=&5S
M(&%S("1N97=!='1R:6)U=&4I('L*("`@("`@("`@("`@:68@*"1N97=!='1R
M:6)U=&5;)VYA;64G72`A/2`G051414Y$144G*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8W5R<F5N
M=%9A;'5E(#T@)'1H:7,M/F=E=$%T=')I8G5T92@D;F5W071T<FEB=71E6R=N
M86UE)UTI.PH@("`@("`@("`@("!I9B`H:7-?82@D8W5R<F5N=%9A;'5E+"`G
M4$5!4E]E<G)O<B<I*2!["B`@("`@("`@("`@("`@("`O+R!!;')E861Y(&5X
M:7-T<R!S;R!J=7-T(&%D9"!I="X*("`@("`@("`@("`@("`@("1T:&ES+3YS
M971!='1R:6)U=&4H)&YE=T%T=')I8G5T95LG;F%M92==+"`D;F5W071T<FEB
M=71E6R=V86QU92==+"`D;F5W071T<FEB=71E6R=P87)A;7,G72D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!!;')E861Y(&5X
M:7-T<R!S;R!L;V-A=&4@86YD(&UO9&EF>2X*("`@("`@("`@("`@("`@("1F
M;W5N9"`](&9A;'-E.PH@("`@("`@("`@("`@("`@+R\@5')Y(&UA=&-H:6YG
M('1H92!A='1R:6)T92!N86UE(&%N9"!V86QU92!I;F-A<V4*("`@("`@("`@
M("`@("`@("\O(&]N;'D@=&AE('!A<F%M<R!C:&%N9V5D("AE9R!A='1E;F1E
M92!U<&1A=&EN9PH@("`@("`@("`@("`@("`@+R\@<W1A='5S*2X*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D:60@
M/3X@)&%T='(I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&%T=');)VYA
M;64G72`]/2`D;F5W071T<FEB=71E6R=N86UE)UT@)B8*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%T=');)W9A;'5E)UT@/3T@)&YE=T%T=')I8G5T95LG
M=F%L=64G72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!-97)G92!T
M:&4@<&%R86US+@H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M;F5W071T<FEB=71E6R=P87)A;7,G72!A<R`D<&%R86U?:60@/3X@)'!A<F%M
M7VYA;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M871T<FEB=71E<ULD:61=6R=P87)A;7,G75LD<&%R86U?:61=(#T@)'!A<F%M
M7VYA;64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@=')U93L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@A)&9O=6YD*2!["B`@("`@
M("`@("`@("`@("`@("`@+R\@16QS92!M871C:"!T:&4@9FER<W0@871T<FEB
M=71E('=I=&@@=&AE('-A;64*("`@("`@("`@("`@("`@("`@("`O+R!N86UE
M("AE9R!C:&%N9VEN9R!S=&%R="!T:6UE*2X*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&ED(#T^("1A='1R
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D871T<ELG;F%M92==
M(#T]("1N97=!='1R:6)U=&5;)VYA;64G72D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1I9%U;)W9A;'5E)UT@
M/2`D;F5W071T<FEB=71E6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@365R9V4@=&AE('!A<F%M<RX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1N97=!='1R:6)U=&5;)W!A<F%M<R==
M(&%S("1P87)A;5]I9"`]/B`D<&%R86U?;F%M92D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:61=6R=P
M87)A;7,G75LD<&%R86U?:61=(#T@)'!A<F%M7VYA;64["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V
M9G)E96)U<WDN<&AP````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,S8T,0`Q
M,#0Q-S,V,C<W,0`P,C(V-#,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN
M9R!V1G)E96)U<WD@8V]M<&]N96YT<RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO:4-A;&5N9&%R+VE#86QE;F1A<B]V9G)E96)U<WDN<&AP+'8@,2XQ-BXQ
M,"XY(#(P,#8O,#(O,#8@,3<Z-3,Z,SD@;7)U8FEN<VL@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D
M:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK
M92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*
M8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W9F<F5E8G5S>2!E>'1E;F1S($AO<F1E
M7VE#86QE;F1A<B!["@H@("`@=F%R("1?8G5S>5!E<FEO9',@/2!A<G)A>2@I
M.PH*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`G=D9R965B=7-Y)SL*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A
M('-T<FEN9R!C;VYT86EN:6YG('9&<F5E8G5S>2!D871A+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@(%1H92!D871A('1O('!A<G-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*
M("`@('L*("`@("`@("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G
M5D92145"55-9)RD["@H@("`@("`@("\O($1O('-O;65T:&EN9R!W:71H(&%L
M;"!T:&4@8G5S>2!P97)I;V1S+@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M871T<FEB=71E<R!A<R`D:V5Y(#T^("1A='1R:6)U=&4I('L*("`@("`@("`@
M("`@:68@*"1A='1R:6)U=&5;)VYA;64G72`]/2`G1E)%14)54UDG*2!["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D871T<FEB=71E6R=V86QU97,G72!A
M<R`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A
M;'5E6R=D=7)A=&EO;B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YA9&1"=7-Y4&5R:6]D*"="55-9)RP@)'9A;'5E6R=S=&%R="==+"!N
M=6QL+"`D=F%L=65;)V1U<F%T:6]N)UTI.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$)U
M<WE097)I;V0H)T)54UDG+"`D=F%L=65;)W-T87)T)UTL("1V86QU95LG96YD
M)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y
M72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7V)U<WE097)I;V1S(&%S("1S=&%R="`]/B`D96YD*2!["B`@("`@
M("`@("`@("1P97)I;V1S(#T@87)R87DH87)R87DH)W-T87)T)R`]/B`D<W1A
M<G0L("=E;F0G(#T^("1E;F0I*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T
M=')I8G5T92@G1E)%14)54UDG+"`D<&5R:6]D<RD["B`@("`@("`@?0H*("`@
M("`@("`D<F5S(#T@<&%R96YT.CI?97AP;W)T=D1A=&$H)U9&4D5%0E5362<I
M.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&ME
M>2`]/B`D871T<FEB=71E*2!["B`@("`@("`@("`@(&EF("@D871T<FEB=71E
M6R=N86UE)UT@/3T@)T92145"55-9)RD@>PH@("`@("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@9&ES<&QA>2!N86UE(&9O<B!T:&ES(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!C;&5A<B!T97AT
M(&YA;64@9F]R(&1I<W!L87EI;F<@=&AI<R!O8FIE8W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$YA;64H*0H@("`@>PH@("`@("`@("1N86UE(#T@)R<[
M"B`@("`@("`@)&UE=&AO9"`]("%E;7!T>2@D=&AI<RT^7V-O;G1A:6YE<BD@
M/PH@("`@("`@("`@("`D=&AI<RT^7V-O;G1A:6YE<BT^9V5T071T<FEB=71E
M*"=-151(3T0G*2`Z("=054),25-()SL*"B`@("`@("`@:68@*&ES7V$H)&UE
M=&AO9"P@)U!%05)?17)R;W(G*2!\?"`D;65T:&]D(#T]("=054),25-()RD@
M>PH@("`@("`@("`@("`D871T<B`]("=/4D=!3DE:15(G.PH@("`@("`@('T@
M96QS96EF("@D;65T:&]D(#T]("=215!,62<I('L*("`@("`@("`@("`@)&%T
M='(@/2`G051414Y$144G.PH@("`@("`@('T*"B`@("`@("`@)&YA;64@/2`D
M=&AI<RT^9V5T071T<FEB=71E*"1A='1R+"!T<G5E*3L*("`@("`@("!I9B`H
M:7-S970H)&YA;65;,%U;)T-.)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D
M;F%M95LP75LG0TXG73L*("`@("`@("!]"@H@("`@("`@("1N86UE(#T@)'1H
M:7,M/F=E=$%T=')I8G5T92@D871T<BD["B`@("`@("`@:68@*&ES7V$H)&YA
M;64L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N86UE(#T@<&%R<V5?=7)L
M*"1N86UE*3L*("`@("`@("`@("`@<F5T=7)N("1N86UE6R=P871H)UT["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@96UA
M:6P@861D<F5S<R!F;W(@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!E;6%I;"!A9&1R97-S(&]F('1H:7,@;V)J96-T
M)W,@;W=N97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5M86EL*"D*("`@
M('L*("`@("`@("`D;F%M92`]("<G.PH@("`@("`@("1M971H;V0@/2`A96UP
M='DH)'1H:7,M/E]C;VYT86EN97(I"B`@("`@("`@("`@("`@("`@(#\@)'1H
M:7,M/E]C;VYT86EN97(M/F=E=$%T=')I8G5T92@G34542$]$)RD@.B`G4%5"
M3$E32"<["@H@("`@("`@(&EF("AI<U]A*"1M971H;V0L("=014%27T5R<F]R
M)RD@?'P@)&UE=&AO9"`]/2`G4%5"3$E32"<I('L*("`@("`@("`@("`@)&%T
M='(@/2`G3U)'04Y)6D52)SL*("`@("`@("!](&5L<V5I9B`H)&UE=&AO9"`]
M/2`G4D503%DG*2!["B`@("`@("`@("`@("1A='1R(#T@)T%45$5.1$5%)SL*
M("`@("`@("!]"@H@("`@("`@("1N86UE(#T@)'1H:7,M/F=E=$%T=')I8G5T
M92@D871T<BD["B`@("`@("`@:68@*&ES7V$H)&YA;64L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1N86UE(#T@<&%R<V5?=7)L*"1N86UE*3L*("`@("`@
M("`@("`@<F5T=7)N("1N86UE6R=P871H)UT["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$)U<WE097)I;V1S*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]B=7-Y4&5R:6]D<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@86QL('1H92!F<F5E('!E<FEO9',@;V8@=&EM92!I;B!A
M(&=I=F5N('!E<FEO9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<W1A<G13=&%M<"`@5&AE('-T87)T('1I;65S=&%M<"X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1E;F13=&%M<"`@("!4:&4@96YD('1I;65S=&%M<"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@=VET:"!F<F5E('1I
M;64@<&5R:6]D<RP@=&AE('-T87)T('1I;65S(&%S('1H90H@("`@("H@("`@
M("`@("`@("`@("`@:V5Y<R!A;F0@=&AE(&5N9"!T:6UE<R!A<R!T:&4@=F%L
M=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&<F5E4&5R:6]D<R@D<W1A
M<G13=&%M<"P@)&5N9%-T86UP*0H@("`@>PH@("`@("`@("1T:&ES+3YS:6UP
M;&EF>2@I.PH@("`@("`@("1P97)I;V1S(#T@87)R87DH*3L*"B`@("`@("`@
M+R\@0VAE8VL@=&AA="!W92!H879E(&1A=&$@9F]R('-O;64@<&%R="!O9B!T
M:&ES('!E<FEO9"X*("`@("`@("!I9B`H)'1H:7,M/F=E=$5N9"@I(#P@)'-T
M87)T4W1A;7`@?'P@)'1H:7,M/F=E=%-T87)T*"D@/B`D96YD4W1A;7`I('L*
M("`@("`@("`@("`@<F5T=7)N("1P97)I;V1S.PH@("`@("`@('T*"B`@("`@
M("`@+R\@3&]C871E('1H92!F:7)S="!T:6UE(&EN('1H92!R97%U97-T960@
M<&5R:6]D('=E(&AA=F4@9&%T82!F;W(N"B`@("`@("`@)&YE>'1S=&%R="`]
M(&UA>"@D<W1A<G13=&%M<"P@)'1H:7,M/F=E=%-T87)T*"DI.PH*("`@("`@
M("`O+R!#:&5C:R!E86-H(&)U<WD@<&5R:6]D(&%N9"!A9&0@9G)E92!P97)I
M;V1S(&EN(&)E='=E96XN"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]B=7-Y
M4&5R:6]D<R!A<R`D<W1A<G0@/3X@)&5N9"D@>PH@("`@("`@("`@("!I9B`H
M)'-T87)T(#P]("1E;F13=&%M<"`F)B`D96YD(#X]("1N97AT<W1A<G0I('L*
M("`@("`@("`@("`@("`@(&EF("@D;F5X='-T87)T(#P]("1S=&%R="D@>PH@
M("`@("`@("`@("`@("`@("`@("1P97)I;V1S6R1N97AT<W1A<G1=(#T@;6EN
M*"1S=&%R="P@)&5N9%-T86UP*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1N97AT<W1A<G0@/2!M:6XH)&5N9"P@)&5N9%-T86UP*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@268@=V4@9&ED
M;B=T(')E860@=&AE(&5N9"!O9B!T:&4@<F5Q=65S=&5D('!E<FEO9"!B=70@
M<W1I;&P@:&%V90H@("`@("`@("\O(&1A=&$@=&AE;B!M87)K(&%S(&9R964@
M=&\@=&AE(&5N9"!O9B!T:&4@<&5R:6]D(&]R(&%V86EL86)L92!D871A+@H@
M("`@("`@(&EF("@D;F5X='-T87)T(#P@)&5N9%-T86UP("8F("1N97AT<W1A
M<G0@/"`D=&AI<RT^9V5T16YD*"DI('L*("`@("`@("`@("`@)'!E<FEO9'-;
M)&YE>'1S=&%R=%T@/2!M:6XH)'1H:7,M/F=E=$5N9"@I+"`D96YD4W1A;7`I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P97)I;V1S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A(&)U<WD@<&5R:6]D('1O('1H92!I;F9O
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@("`@5&AE
M('1Y<&4@;V8@=&AE('!E<FEO9"X@16ET:&5R("=&4D5%)R!O<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G0E5362<[(&]N;'D@)T)54UDG
M('-U<'!O<G1E9"!A="!T:&4@;6]M96YT+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'-T87)T("`@("!4:&4@<W1A<G0@=&EM97-T86UP(&]F('1H92!P97)I
M;V0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96YD("`@("`@(%1H92!E;F0@
M=&EM97-T86UP(&]F('1H92!P97)I;V0N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9'5R871I;VX@(%1H92!D=7)A=&EO;B!O9B!T:&4@<&5R:6]D+B!)9B!S
M<&5C:69I960L('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D96YD('!A<F%M971E<B!W:6QL(&)E(&EG;F]R960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9$)U<WE097)I;V0H)'1Y<&4L("1S=&%R="P@)&5N9"`]
M(&YU;&PL("1D=7)A=&EO;B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1T
M>7!E(#T]("=&4D5%)RD@>PH@("`@("`@("`@("`O+R!-86ME('-U<F4@=&AI
M<R!P97)I;V0@:7,@;F]T(&UA<FME9"!A<R!B=7-Y+@H@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!#86QC=6QA=&4@
M=&AE(&5N9"!T:6UE(&EF(&1U<F%T:6]N('=A<R!S<&5C:69I960N"B`@("`@
M("`@)'1E;7!%;F0@/2!I<U]N=6QL*"1D=7)A=&EO;BD@/R`D96YD(#H@)'-T
M87)T("L@)&1U<F%T:6]N.PH*("`@("`@("`O+R!-86ME('-U<F4@=&AE('!E
M<FEO9"!L96YG=&@@:7,@86QW87ES('!O<VET:79E+@H@("`@("`@("1E;F0@
M/2!M87@H)'-T87)T+"`D=&5M<$5N9"D["B`@("`@("`@)'-T87)T(#T@;6EN
M*"1S=&%R="P@)'1E;7!%;F0I.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]B=7-Y4&5R:6]D<ULD<W1A<G1=*2D@>PH@("`@("`@("`@("`O+R!!;')E
M861Y(&$@<&5R:6]D('-T87)T:6YG(&%T('1H:7,@=&EM92X@17AT96YD('1O
M('1H92!L96YG=&@@;V8*("`@("`@("`@("`@+R\@=&AE(&QO;F=E<W0@;V8@
M=&AE('1W;RX*("`@("`@("`@("`@)'1H:7,M/E]B=7-Y4&5R:6]D<ULD<W1A
M<G1=(#T@;6%X*"1E;F0L("1T:&ES+3Y?8G5S>5!E<FEO9'-;)'-T87)T72D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@061D(&$@;F5W(&)U
M<WD@<&5R:6]D+@H@("`@("`@("`@("`D=&AI<RT^7V)U<WE097)I;V1S6R1S
M=&%R=%T@/2`D96YD.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T:6UE<W1A;7`@
M;V8@=&AE('-T87)T(&]F('1H92!T:6UE('!E<FEO9"!T:&ES(&9R964@8G5S
M>0H@("`@("H@:6YF;W)M871I;VX@8V]V97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@02!T:6UE<W1A;7`N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%-T87)T*"D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'1H:7,M
M/F=E=$%T=')I8G5T92@G1%135$%25"<I+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T071T<FEB=71E*"=$5%-405)4
M)RD["B`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1T:&ES+3Y?8G5S>5!E<FEO
M9',I*2!["B`@("`@("`@("`@(')E='5R;B!M:6XH87)R87E?:V5Y<R@D=&AI
M<RT^7V)U<WE097)I;V1S*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('1I;65S=&%M<"!O9B!T:&4@96YD(&]F('1H92!T
M:6UE('!E<FEO9"!T:&ES(&9R964@8G5S>0H@("`@("H@:6YF;W)M871I;VX@
M8V]V97)S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@02!T:6UE
M<W1A;7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5N9"@I"B`@("!["B`@
M("`@("`@:68@*"%I<U]A*"1T:&ES+3YG971!='1R:6)U=&4H)T1414Y$)RDL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG
M971!='1R:6)U=&4H)T1414Y$)RD["B`@("`@("`@?2!E;'-E:68@*&-O=6YT
M*"1T:&ES+3Y?8G5S>5!E<FEO9',I*2!["B`@("`@("`@("`@(')E='5R;B!M
M87@H87)R87E?=F%L=65S*"1T:&ES+3Y?8G5S>5!E<FEO9',I*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@365R9V5S('1H92!B=7-Y('!E<FEO
M9',@;V8@86YO=&AE<B!(;W)D95]I0V%L96YD87)?=F9R965B=7-Y(&]B:F5C
M="!I;G1O"B`@("`@*B!T:&ES(&]N92X*("`@("`J"B`@("`@*B!`<&%R86T@
M2&]R9&5?:4-A;&5N9&%R7W9F<F5E8G5S>2`D9G)E96)U<WD@($$@9G)E96)U
M<WD@;V)J96-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-I;7!L:69Y("`@
M("`@("`@("`@("`@("`@("!)9B!T<G5E+"!S:6UP;&EF>2@I('=I;&P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8V%L;&5D(&%F=&5R('1H92!M97)G92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;65R9V4H)&9R965B=7-Y+"`D<VEM<&QI9GD@/2!T<G5E*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?82@D9G)E96)U<WDL("=(;W)D95]I0V%L96YD87)?
M=F9R965B=7-Y)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H)&9R965B=7-Y+3YG971"=7-Y4&5R
M:6]D<R@I(&%S("1S=&%R="`]/B`D96YD*2!["B`@("`@("`@("`@("1T:&ES
M+3YA9&1"=7-Y4&5R:6]D*"="55-9)RP@)'-T87)T+"`D96YD*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES871T<B`]("1T:&ES+3YG971!='1R:6)U=&4H
M)T144U1!4E0G*3L*("`@("`@("`D=&AA=&%T='(@/2`D9G)E96)U<WDM/F=E
M=$%T=')I8G5T92@G1%135$%25"<I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES
M871T<BP@)U!%05)?17)R;W(G*2`F)B`A:7-?82@D=&AA=&%T='(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@G
M1%135$%25"<L("1T:&%T871T<BD["B`@("`@("`@?2!E;'-E:68@*"%I<U]A
M*"1T:&%T871T<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!I9B`H
M)'1H871A='1R(#X@)'1H:7-A='1R*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T071T<FEB=71E*"=$5%-405)4)RP@)'1H871A='1R*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7-A='1R(#T@)'1H:7,M
M/F=E=$%T=')I8G5T92@G1%1%3D0G*3L*("`@("`@("`D=&AA=&%T='(@/2`D
M9G)E96)U<WDM/F=E=$%T=')I8G5T92@G1%1%3D0G*3L*("`@("`@("!I9B`H
M:7-?82@D=&AI<V%T='(L("=014%27T5R<F]R)RD@)B8@(6ES7V$H)'1H871A
M='1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YS971!
M='1R:6)U=&4H)T1414Y$)RP@)'1H871A='1R*3L*("`@("`@("!](&5L<V5I
M9B`H(6ES7V$H)'1H871A='1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(&EF("@D=&AA=&%T='(@/"`D=&AI<V%T='(I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971!='1R:6)U=&4H)T1414Y$)RP@)'1H871A='1R*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1S:6UP;&EF
M>2D@>PH@("`@("`@("`@("`D=&AI<RT^<VEM<&QI9GDH*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5M;W9E<R!A;&P@;W9E<FQA<',@86YD('-I;7!L:69I97,@=&AE(&)U<WD@
M<&5R:6]D<R!A<G)A>2!A<R!M=6-H(&%S"B`@("`@*B!P;W-S:6)L92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<VEM<&QI9GDH*0H@("`@>PH@("`@("`@("1C
M:&5C:V5D(#T@87)R87DH*3L*("`@("`@("`D8VAE8VME9$5M<'1Y(#T@=')U
M93L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]B=7-Y4&5R:6]D<R!A<R`D
M<W1A<G0@/3X@)&5N9"D@>PH@("`@("`@("`@("!I9B`H)&-H96-K961%;7!T
M>2D@>PH@("`@("`@("`@("`@("`@)&-H96-K961;)'-T87)T72`]("1E;F0[
M"B`@("`@("`@("`@("`@("`D8VAE8VME9$5M<'1Y(#T@9F%L<V4["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D861D960@/2!F86QS
M93L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C:&5C:V5D(&%S("1T97-T
M4W1A<G0@/3X@)'1E<W1%;F0I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'-T87)T(#T]("1T97-T4W1A<G0I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-H96-K961;)'1E<W13=&%R=%T@/2!M87@H)'1E<W1%;F0L("1E;F0I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D861D960@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D96YD(#P]("1T97-T16YD("8F
M("1E;F0@/CT@)'1E<W13=&%R="D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!U;G-E="@D8VAE8VME9%LD=&5S=%-T87)T72D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C:&5C:V5D6VUI;B@D=&5S=%-T87)T+"`D<W1A<G0I72`]
M(&UA>"@D=&5S=$5N9"P@)&5N9"D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1A9&1E9"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D861D960I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"$D861D960I('L*("`@("`@
M("`@("`@("`@("`@("`D8VAE8VME9%LD<W1A<G1=(#T@)&5N9#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:W-O<G0H)&-H96-K960L(%-/4E1?3E5-15))0RD["B`@("`@("`@)'1H:7,M
M/E]B=7-Y4&5R:6]D<R`]("1C:&5C:V5D.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V:F]U
M<FYA;"YP:'``````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,30Q,0`Q,#0Q
M-S,V,C<W,0`P,C(T-C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN9R!V
M2F]U<FYA;',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+VE#86QE;F1A<B]I
M0V%L96YD87(O=FIO=7)N86PN<&AP+'8@,2XX+C$P+C0@,C`P-B\P,2\P,2`R
M,3HR.#HT-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R9&5?:4-A;&5N9&%R
M7W9J;W5R;F%L(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC
M=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W9*;W5R;F%L
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*
M("`@('L*("`@("`@("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G
M5DI/55).04PG*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD
M87(H*0H@("`@>PH@("`@("`@(')E='5R;B!P87)E;G0Z.E]E>'!O<G1V1&%T
M82@G5DI/55).04PG*3L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A
M<B]V;F]T92YP:'``````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0V
M,@`Q,#0Q-S,V,C<W,0`P,C$W-C(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O
M:4-A;&5N9&%R+G!H<"<["@HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG('9.
M;W1E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE
M;F1A<B]V;F]T92YP:'`L=B`Q+C,N,3`N-2`R,#`V+S`S+S`S(#`Y.C`W.C,Q
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QF;W5R;6]N=$!G;7@N
M9&4^"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R
M9&5?:4-A;&5N9&%R7W9N;W1E(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*
M"B`@("!F=6YC=&EO;B!(;W)D95]I0V%L96YD87)?=FYO=&4H)'9E<G-I;VX@
M/2`G,2XQ)RD*("`@('L*("`@("`@("!R971U<FX@<&%R96YT.CI(;W)D95]I
M0V%L96YD87(H)'9E<G-I;VXI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1Y
M<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=DYO=&4G.PH@("`@?0H*("`@
M(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@
M(')E='5R;B!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G5DY/5$4G
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&EK92!V979E;G0@86YD('9T
M;V1O+"!A('9N;W1E(&ES(&YO<FUA;&QY(&YO="!E;F-L;W-E9"!I;B!A;@H@
M("`@("H@:4-A;&5N9&%R(&-O;G1A:6YE<BX@*$)%1TE.+BY%3D0I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@
M("`@)')E<75I<F5D071T<FEB=71E<ULG0D]$62==(#T@)R<["B`@("`@("`@
M)')E<75I<F5D071T<FEB=71E<ULG5D524TE/3B==(#T@)S$N,2<["@H@("`@
M("`@(&9O<F5A8V@@*"1R97%U:7)E9$%T=')I8G5T97,@87,@)&YA;64@/3X@
M)&1E9F%U;'1?=F%L=64I('L*("`@("`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/F=E=&%T=')I8G5T92@D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)&YA;64L("1D969A=6QT
M7W9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?97AP;W)T=D1A=&$H)U9.3U1%)RD["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9T:6UE>F]N92YP:'``````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S$W`#$P-#$W,S8R-S<Q`#`R,C8U,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG('94:6UE>F]N97,N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L96YD87(O=G1I;65Z
M;VYE+G!H<"QV(#$N."XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z-#<@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L
M96YD87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]V=&EM97IO;F4@97AT
M96YD<R!(;W)D95]I0V%L96YD87(@>PH*("`@(&9U;F-T:6]N(&=E=%1Y<&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`G=E1I;65:;VYE)SL*("`@('T*"B`@
M("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*("`@('L*("`@("`@
M("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G5E1)345:3TY%)RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@('L*
M("`@("`@("!R971U<FX@<&%R96YT.CI?97AP;W)T=D1A=&$H)U9424U%6D].
M12<I.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A
M<@H@*B\*8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W-T86YD87)D(&5X=&5N9',@
M2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@
M('L*("`@("`@("!R971U<FX@)W-T86YD87)D)SL*("`@('T*"B`@("!F=6YC
M=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*("`@('L*("`@("`@("!P87)E
M;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G4U1!3D1!4D0G*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@
M(')E='5R;B!P87)E;G0Z.E]E>'!O<G1V1&%T82@G4U1!3D1!4D0G*3L*("`@
M('T*"GT*"B\J*@H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO"F-L
M87-S($AO<F1E7VE#86QE;F1A<E]D87EL:6=H="!E>'1E;F1S($AO<F1E7VE#
M86QE;F1A<B!["@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("=D87EL:6=H="<["B`@("!]"@H@("`@9G5N8W1I;VX@<&%R
M<V5V0V%L96YD87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R96YT.CIP87)S
M979#86QE;F1A<B@D9&%T82P@)T1!64Q)1TA4)RD["B`@("!]"@H@("`@9G5N
M8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("!R971U<FX@
M<&%R96YT.CI?97AP;W)T=D1A=&$H)T1!64Q)1TA4)RD["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD
M87(O=G1O9&\N<&AP````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0U
M,C$`,3`T,3<S-C(W-S$`,#(Q-S8P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!#;&%S<R!R97!R97-E
M;G1I;F<@=E1O9&]S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]I0V%L96YD
M87(O:4-A;&5N9&%R+W9T;V1O+G!H<"QV(#$N,3,N,3`N-"`R,#`V+S`Q+S`Q
M(#(Q.C(X.C0W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?:4-A;&5N9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD
M87)?=G1O9&\@97AT96YD<R!(;W)D95]I0V%L96YD87(@>PH*("`@(&9U;F-T
M:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=E1O9&\G.PH@
M("`@?0H*("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@
M>PH@("`@("`@('!A<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A=&$L("=65$]$
M3R<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@
M("!["B`@("`@("`@<F5T=7)N('!A<F5N=#HZ7V5X<&]R='9$871A*"=65$]$
M3R<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T:&ES('1O9&\@
M=&\@86X@87)R87D@;V8@871T<FEB=71E<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!<G)A>2!C;VYT86EN:6YG('1H92!D971A:6QS(&]F('1H
M92!T;V1O(&EN(&$@:&%S:`H@("`@("H@("`@("`@("`@("`@("`@87,@=7-E
M9"!B>2!(;W)D92!A<'!L:6-A=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1O07)R87DH*0H@("`@>PH@("`@("`@("1T;V1O(#T@87)R87DH*3L*"B`@
M("`@("`@)&YA;64@/2`D=&AI<RT^9V5T071T<FEB=71E*"=354U-05)9)RD[
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;F%M92D@)B8@(6ES7V$H)&YA;64L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1O9&];)VYA;64G72`]
M("1N86UE.PH@("`@("`@('T*("`@("`@("`D9&5S8R`]("1T:&ES+3YG971!
M='1R:6)U=&4H)T1%4T-225!424].)RD["B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D9&5S8RD@)B8@(6ES7V$H)&1E<V,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@)'1O9&];)V1E<V,G72`]("1D97-C.PH@("`@("`@('T*"B`@
M("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/F=E=$%T=')I8G5T92@G4%))3U))
M5%DG*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P<FEO<FET>2D@)B8@(6ES
M7V$H)'!R:6]R:71Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T
M;V1O6R=P<FEO<FET>2==(#T@)'!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@
M("`@)&1U92`]("1T:&ES+3YG971!='1R:6)U=&4H)T144U1!35`G*3L*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1D=64I("8F("%I<U]A*"1D=64L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@)'1O9&];)V1U92==(#T@)&1U93L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&]D;SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@871T<FEB=71E<R!F;W(@=&AI<R!T;V1O(&ET
M96T@9G)O;2!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'1O9&\@($%R<F%Y(&-O;G1A:6YI;F<@=&AE(&1E=&%I;',@;V8@=&AE('1O
M9&\@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&AE('-A;64@9F]R
M;6%T('1H870@=&]!<G)A>2@I(&5X<&]R=',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9R;VU!<G)A>2@D=&]D;RD*("`@('L*("`@("`@("!I9B`H:7-S970H
M)'1O9&];)VYA;64G72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I
M8G5T92@G4U5-34%262<L("1T;V1O6R=N86UE)UTI.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-S970H)'1O9&];)V1E<V,G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/G-E=$%T=')I8G5T92@G1$530U))4%1)3TXG+"`D=&]D;ULG9&5S
M8R==*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&]D;ULG<')I
M;W)I='DG72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@G
M4%))3U))5%DG+"`D=&]D;ULG<')I;W)I='DG72D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H:7-S970H)'1O9&];)V1U92==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V5T071T<FEB=71E*"=$5%-404U0)RP@)'1O9&];)V1U92==*3L*
M("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]D;V-S+P``````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S$`,#$W,38S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+V1O8W,O97AA;7!L97,O````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,0`P
M,C$P,#$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S<Q`#`Q-S,Q,@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,30P-S0`,3`T,3<S-C(W-S$`,#(S,#<V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!#;&%S<R!F;W(@:&%N9&QI;F<@82!L:7-T(&]F(&-A=&5G;W)I97,@
M<W1O<F5D(&EN(&$@=7-E<B=S"B`J('!R969E<F5N8V5S+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M+'8@,2XQ,2XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S(@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0<F5F
M<U]#871E9V]R>4UA;F%G97(@>PH*("`@("\J*@H@("`@("H@1V5T(&%L;"!C
M871E9V]R:65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@("1S=')I;F<@/2`D<')E
M9G,M/F=E=%9A;'5E*"=C871E9V]R:65S)RD["B`@("`@("`@:68@*&5M<'1Y
M*"1S=')I;F<I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@
M("`@('T*"B`@("`@("`@)&-A=&5G;W)I97,@/2!E>'!L;V1E*"=\)RP@)'-T
M<FEN9RD["B`@("`@("`@87-O<G0H)&-A=&5G;W)I97,I.PH*("`@("`@("!R
M971U<FX@)&-A=&5G;W)I97,["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4V5L
M96-T*"1I9"P@)&-U<G)E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<')E9G,["@H@("`@("`@("1H=&UL(#T@)SQS96QE8W0@:60](B<@+B!H
M=&UL<W!E8VEA;&-H87)S*"1I9"D@+B`G(B!N86UE/2(G("X@:'1M;'-P96-I
M86QC:&%R<R@D:60I("X@)R(^)SL*"B`@("`@("`@)&-A=&5G;W)I97,@/2!0
M<F5F<U]#871E9V]R>4UA;F%G97(Z.F=E="@I.PH@("`@("`@(&EF("@A:6Y?
M87)R87DH)&-U<G)E;G0L("1C871E9V]R:65S*2`F)B`A96UP='DH)&-U<G)E
M;G0I*2!["B`@("`@("`@("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2(J
M;F5W*B<@+B!H=&UL<W!E8VEA;&-H87)S*"1C=7)R96YT*2`N("<B/B<@+B!S
M<')I;G1F*%\H(E5S92!#=7)R96YT.B`E<R(I+"!H=&UL<W!E8VEA;&-H87)S
M*"1C=7)R96YT*2D@+B`G/"]O<'1I;VX^)R`N"B`@("`@("`@("`@("`@("`G
M/&]P=&EO;B!V86QU93TB(CXM+2TM/"]O<'1I;VX^)SL*("`@("`@("!]"@H@
M("`@("`@(&EF("@A)'!R969S+3YI<TQO8VME9"@G8V%T96=O<FEE<R<I*2![
M"B`@("`@("`@("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2(J;F5W*B(^
M)R`N(%\H(DYE=R!#871E9V]R>2(I("X@(CPO;W!T:6]N/EQN(B`N"B`@("`@
M("`@("`@("`@("`G/&]P=&EO;B!V86QU93TB(CXM+2TM/"]O<'1I;VX^)SL*
M("`@("`@("!]"@H@("`@("`@("\O($%L=V%Y<R!A9&0@86X@56YF:6QE9"!O
M<'1I;VXN"B`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64](B(G("X*
M("`@("`@("`@("`@*&5M<'1Y*"1C=7)R96YT*2`_("<@<V5L96-T960](G-E
M;&5C=&5D(CXG(#H@)SXG*2`N"B`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA
M<G,H7R@B56YF:6QE9"(I*2`N("<\+V]P=&EO;CXG.PH*("`@("`@("!F;W)E
M86-H("@D8V%T96=O<FEE<R!A<R`D;F%M92D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`G/&]P=&EO;B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&YA
M;64I("X@)R(G("X*("`@("`@("`@("`@("`@("@D;F%M92`]/3T@)&-U<G)E
M;G0@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(^)R`Z("<^)RD@+@H@("`@("`@
M("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D;F%M92D@+B`G/"]O<'1I;VX^
M)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;"`N("<\+W-E;&5C
M=#XG.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$IA=F%38W)I<'0H)&9O<FUN
M86UE+"`D96QE;65N=&YA;64I"B`@("!["B`@("`@("`@)'!R;VUP="`](&%D
M9'-L87-H97,H7R@B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.B(I*3L*("`@("`@("`D97)R;W(@/2!A9&1S;&%S:&5S*%\H(EEO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB*2D["@H@("`@("`@(')E='5R
M;B`\/#Q*059!4T-225!4"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP
M="(^"CPA+2T*9G5N8W1I;VX@8VAE8VM#871E9V]R>2@I"GL*("`@(&EF("AD
M;V-U;65N="XD9F]R;6YA;64N)&5L96UE;G1N86UE+G9A;'5E(#T]("<J;F5W
M*B<I('L*("`@("`@("!V87(@8V%T96=O<GD@/2!W:6YD;W<N<')O;7!T*"<D
M<')O;7!T)RP@)R<I.PH@("`@("`@(&EF("AC871E9V]R>2`A/2!N=6QL("8F
M(&-A=&5G;W)Y("$]("<G*2!["B`@("`@("`@("`@(&1O8W5M96YT+B1F;W)M
M;F%M92YN97=?8V%T96=O<GDN=F%L=64@/2!C871E9V]R>3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!W:6YD;W<N86QE<G0H)R1E<G)O<B<I.PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?2!E;'-E
M(&EF("AD;V-U;65N="XD9F]R;6YA;64N)&5L96UE;G1N86UE+G9A;'5E+FEN
M9&5X3V8H)RIN97<J)RD@(3T@+3$I('L*("`@("`@("!D;V-U;65N="XD9F]R
M;6YA;64N;F5W7V-A=&5G;W)Y+G9A;'5E(#T@9&]C=6UE;G0N)&9O<FUN86UE
M+B1E;&5M96YT;F%M92YV86QU92YS=6)S='(H-2P@9&]C=6UE;G0N)&9O<FUN
M86UE+B1E;&5M96YT;F%M92YV86QU92YL96YG=&@I.PH@("`@?0H*("`@(')E
M='5R;B!T<G5E.PI]"B\O+2T^"CPO<V-R:7!T/@I*059!4T-225!4.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D(&$@;F5W(&-A=&5G;W)Y+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&-A=&5G;W)Y("!4:&4@;F%M92!O9B!T
M:&4@8V%T96=O<GD@=&\@861D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($9A;'-E(&]N(&9A:6QU<F4L(&]R('1H92!N97<@8V%T96=O<GDG<R!N
M86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H)&-A=&5G;W)Y*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@(&EF("@D<')E9G,M
M/FES3&]C:V5D*"=C871E9V]R:65S)RD@?'P@96UP='DH)&-A=&5G;W)Y*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`D8V%T96=O<FEE<R`](%!R969S7T-A=&5G;W)Y36%N86=E<CHZ9V5T*"D[
M"B`@("`@("`@:68@*&EN7V%R<F%Y*"1C871E9V]R>2P@)&-A=&5G;W)I97,I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1C871E9V]R:65S6UT@/2`D8V%T96=O<GD["B`@("`@("`@)'!R969S
M+3YS971686QU92@G8V%T96=O<FEE<R<L(&EM<&QO9&4H)WPG+"`D8V%T96=O
M<FEE<RDI.PH*("`@("`@("!R971U<FX@)&-A=&5G;W)Y.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E(&$@8V%T96=O<GDN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V%T96=O<GD@(%1H92!C871E9V]R>2!T;R!R96UO
M=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U
M8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V92@D8V%T96=O<GDI"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F
M<SL*"B`@("`@("`@:68@*"1P<F5F<RT^:7-,;V-K960H)V-A=&5G;W)I97,G
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`D8V%T96=O<FEE<R`](%!R969S7T-A=&5G;W)Y36%N86=E<CHZ9V5T
M*"D["@H@("`@("`@("1K97D@/2!A<G)A>5]S96%R8V@H)&-A=&5G;W)Y+"`D
M8V%T96=O<FEE<RD["B`@("`@("`@:68@*"1K97D@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B`D:V5Y.PH@("`@("`@('T*"B`@("`@("`@=6YS
M970H)&-A=&5G;W)I97-;)&ME>5TI.PH@("`@("`@("1P<F5F<RT^<V5T5F%L
M=64H)V-A=&5G;W)I97,G+"!I;7!L;V1E*"=\)RP@)&-A=&5G;W)I97,I*3L*
M"B`@("`@("`@+R\@4F5M;W9E(&%N>2!C;VQO<B!S971T:6YG<R!F;W(@)&-A
M=&5G;W)Y+@H@("`@("`@("1C;VQO<G,@/2!0<F5F<U]#871E9V]R>4UA;F%G
M97(Z.F-O;&]R<R@I.PH@("`@("`@('5N<V5T*"1C;VQO<G-;)&-A=&5G;W)Y
M72D["B`@("`@("`@4')E9G-?0V%T96=O<GE-86YA9V5R.CIS971#;VQO<G,H
M)&-O;&]R<RD["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@8V]L;W(@9F]R(&5A8V@@;V8@=&AE('5S
M97(G<R!C871E9V]R:65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($$@;&ES="!O9B!C;VQO<G,L(&ME>2!I<R!T:&4@8V%T96=O<GD@;F%M92P@
M=F%L=64@:7,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!(5$U,(&-O;&]R
M(&-O9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;&]R<R@I"B`@("!["B`@
M("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@+RH@1&5F875L="!V86QU
M97,@=&AA="!C86X@8F4@;W9E<G)I9&1E;B!B=70@;75S="!A;'=A>7,@8F4*
M("`@("`@("`@*B!P<F5S96YT+B`J+PH@("`@("`@("1C;VQO<G-;)U]D969A
M=6QT7R==(#T@)R-&1D9&1D8G.PH@("`@("`@("1C;VQO<G-;)U]U;F9I;&5D
M7R==(#T@)R-$1$1$1$0G.PH*("`@("`@("`D<&%I<G,@/2!E>'!L;V1E*"=\
M)RP@)'!R969S+3YG971686QU92@G8V%T96=O<GE?8V]L;W)S)RDI.PH@("`@
M("`@(&9O<F5A8V@@*"1P86ER<R!A<R`D<&%I<BD@>PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1P86ER*2D@>PH@("`@("`@("`@("`@("`@;&ES="@D8V%T
M96=O<GDL("1C;VQO<BD@/2!E>'!L;V1E*"<Z)RP@)'!A:7(I.PH@("`@("`@
M("`@("`@("`@)&-O;&]R<ULD8V%T96=O<GE=(#T@)&-O;&]R.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V]L;W)S6R<G72`]("1C;VQO
M<G-;)U]U;F9I;&5D7R==.PH*("`@("`@("!R971U<FX@)&-O;&]R<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&9O<F5G<F]U;F0@8V]L
M;W(@9F]R(&5A8V@@;V8@=&AE('5S97(G<R!C871E9V]R:65S+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($$@;&ES="!O9B!C;VQO<G,L(&ME>2!I
M<R!T:&4@8V%T96=O<GD@;F%M92P@=F%L=64@:7,@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("!(5$U,(&-O;&]R(&-O9&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9G0V]L;W)S*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+TEM86=E+G!H<"<["@H@("`@("`@("1C;VQO<G,@/2!0<F5F<U]#871E
M9V]R>4UA;F%G97(Z.F-O;&]R<R@I.PH@("`@("`@("1F9V-O;&]R<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&-O;&]R<R!A<R`D;F%M92`]/B`D
M8V]L;W(I('L*("`@("`@("`@("`@)&9G8V]L;W)S6R1N86UE72`]($AO<F1E
M7TEM86=E.CIB<FEG:'1N97-S*"1C;VQO<BD@/"`Q,C@@/R`G(V8V9C9F-B<@
M.B`G(S`P,"<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9G8V]L;W)S
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$-O;&]R*"1C871E9V]R>2P@)&-O
M;&]R*0H@("`@>PH@("`@("`@("1C;VQO<G,@/2!0<F5F<U]#871E9V]R>4UA
M;F%G97(Z.F-O;&]R<R@I.PH@("`@("`@("1C;VQO<G-;)&-A=&5G;W)Y72`]
M("1C;VQO<CL*("`@("`@("!0<F5F<U]#871E9V]R>4UA;F%G97(Z.G-E=$-O
M;&]R<R@D8V]L;W)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!S971#;VQO<G,H
M)&-O;&]R<RD*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@
M("`D<&%I<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C;VQO<G,@
M87,@)&-A=&5G;W)Y(#T^("1C;VQO<BD@>PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1C871E9V]R>2DI('L*("`@("`@("`@("`@("`@("1P86ER<UM=(#T@
M(B1C871E9V]R>3HD8V]L;W(B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=C871E9V]R>5]C;VQO<G,G+"!I
M;7!L;V1E*"=\)RP@)'!A:7)S*2D["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O54DN<&AP````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,T-34V`#$P-#$W,S8R-S<Q
M`#`R,#,U,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@0VQA<W,@9F]R(&%U=&\M9V5N97)A=&EN9R!T
M:&4@<')E9F5R96YC97,@=7-E<B!I;G1E<F9A8V4@86YD"B`J('!R;V-E<W-I
M;F<@=&AE(&9O<FUS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`L=B`Q+C8S+C(N,34@,C`P-B\P,2\Q,B`R,CHR-3HQ-"!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*("HO
M"F-L87-S(%!R969S7U5)('L*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!W
M:&5T:&5R(&]R(&YO="!A('!R969E<F5N8V5S(&=R;W5P(&ES(&5D:71A8FQE
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!4:&4@<')E
M9F5R96YC97,@9W)O=7`@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@9W)O=7`@:7,@961I=&%B
M;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=R;W5P27-%9&ET86)L92@D9W)O
M=7`I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<RP@)'!R969'<F]U<',[
M"@H@("`@("`@('-T871I8R`D<F5S=6QT<R`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("@A:7-S970H)')E<W5L='-;)&=R;W5P72DI('L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D<')E9D=R;W5P<ULD9W)O=7!=6R=U<FPG72DI('L*("`@
M("`@("`@("`@("`@("1R97-U;'1S6R1G<F]U<%T@/2!T<G5E.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L='-;)&=R;W5P
M72`](&9A;'-E.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P<F5F1W)O
M=7!S6R1G<F]U<%U;)VUE;6)E<G,G72DI('L*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<')E9D=R;W5P<ULD9W)O=7!=6R=M96UB97)S)UT@87,@
M)'!R968I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D<')E9G,M
M/FES3&]C:V5D*"1P<F5F*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<W5L='-;)&=R;W5P72`]('1R=64["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U
M;'1S6R1G<F]U<%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!(86YD;&4@82!P
M<F5F97)E;F-E<R!F;W)M('-U8FUI<W-I;VX@:68@=&AE<F4@:7,@;VYE+"!U
M<&1A=&EN9PH@("`@("H@86YY('!R969E<F5N8V5S('=H:6-H(&AA=F4@8F5E
M;B!C:&%N9V5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P
M("!4:&4@<')E9F5R96YC97,@9W)O=7`@=&AA="!W87,@961I=&5D+@H@("`@
M("H@0'!A<F%M(&]B:F5C="`D<V%V92`@(%1H92!O8FIE8W0@=VAE<F4@=&AE
M(&-H86YG960@=F%L=65S(&%R90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@('-A=F5D+B!-=7-T(&EM<&QE;65N="!S971686QU92AS=')I;F<L('-T
M<FEN9RDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R
M('!R969E<F5N8V5S(&AA=F4@8F5E;B!U<&1A=&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!H86YD;&5&;W)M*"8D9W)O=7`L("8D<V%V92D*("`@('L*("`@
M("`@("!G;&]B86P@)'!R969S+"`D<')E9D=R;W5P<RP@)%]P<F5F<RP@)&YO
M=&EF:6-A=&EO;BP@)')E9VES=')Y.PH*("`@("`@("`D=7!D871E9"`](&9A
M;'-E.PH*("`@("`@("`O*B!2=6X@=&AR;W5G:"!T:&4@86-T:6]N(&AA;F1L
M97)S("HO"B`@("`@("`@:68@*%5T:6PZ.F=E=%!O<W0H)V%C=&EO;DE$)RD@
M/3T@)W5P9&%T95]P<F5F<R<I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1G
M<F]U<"D@)B8@4')E9G-?54DZ.F=R;W5P27-%9&ET86)L92@D9W)O=7`I*2![
M"B`@("`@("`@("`@("`@("`D=7!D871E9"`](&9A;'-E.PH*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1P<F5F1W)O=7!S6R1G<F]U<%U;)VUE;6)E<G,G
M72!A<R`D<')E9BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A)'!R969S
M+3YI<TQO8VME9"@D<')E9BD@?'P*("`@("`@("`@("`@("`@("`@("`@("`@
M*"1?<')E9G-;)'!R969=6R=T>7!E)UT@/3T@)W-P96-I86PG*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!S=VET8V@@*"1?<')E9G-;)'!R969=6R=T
M>7!E)UTI('L*"B`@("`@("`@("`@("`@("`@("`@("`@("\J(%1H97-E(&5I
M=&AE<B!A<F5N)W0@<V5T(&]R(&%R92!S970@:6X@;W1H97(*("`@("`@("`@
M("`@("`@("`@("`@("`@("H@<&%R=',@;V8@=&AE(%5)+B`J+PH@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E("=I;7!L:6-I="<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)VQI;FLG.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("=S96QE8W0G.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=T97AT
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G=&5X=&%R96$G.@H@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E("=P87-S=V]R9"<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=7!D871E9"`]("1U<&1A=&5D('P@
M)'-A=F4M/G-E=%9A;'5E*"1P<F5F+"!5=&EL.CIG9710;W-T*"1P<F5F*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V5N=6TG.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;"`](%5T:6PZ.F=E=%!O<W0H)'!R968I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?<')E9G-;)'!R
M969=6R=E;G5M)UU;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'5P9&%T960@/2`D=7!D871E9"!\("1S879E+3YS971686QU
M92@D<')E9BP@)'9A;"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G;75L=&EE;G5M)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1V86QS(#T@571I;#HZ9V5T4&]S
M="@D<')E9BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5T(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;G9A;&ED
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)'9A;',I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'9A;',@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)%]P<F5F<ULD<')E9EU;
M)V5N=6TG75LD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S971;72`]("1V86P["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YV86QI9"`]('1R=64["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)&EN=F%L:60I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*%\H(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1U<&1A=&5D(#T@)'5P9&%T960@?"`D<V%V92T^<V5T5F%L=64H
M)'!R968L($!S97)I86QI>F4H)'-E="DI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=N=6UB97(G.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&YU;2`](%5T:6PZ.F=E=%!O<W0H
M)'!R968I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&EN='9A
M;"@D;G5M*2`A/2`D;G5M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1N=6T@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=7!D871E9"`]
M("1U<&1A=&5D('P@)'-A=F4M/G-E=%9A;'5E*"1P<F5F+"`D;G5M*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`G8VAE8VMB;W@G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M;"`](%5T:6PZ.F=E=%!O<W0H)'!R968I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'5P9&%T960@/2`D=7!D871E9"!\("1S879E+3YS971686QU
M92@D<')E9BP@:7-S970H)'9A;"D@/R`Q(#H@,"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)W-P96-I86PG.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+RH@0V]D92!F;W(@<W!E8VEA;"!E;&5M96YT<R!M=7-T(&)E"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*B!W<FET=&5N('-P96-I9FEC86QL>2!F
M;W(@96%C:`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("H@87!P;&EC
M871I;VXN("HO"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H9G5N
M8W1I;VY?97AI<W1S*"=H86YD;&5?)R`N("1P<F5F*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1U<&1A=&5D(#T@)'5P9&%T960@?"!C
M86QL7W5S97)?9G5N8R@G:&%N9&QE7R<@+B`D<')E9BP@)'5P9&%T960I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@:68@*"1U<&1A=&5D*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G<')E9G-?8V%L;&)A8VLG*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!P<F5F<U]C86QL8F%C:R@I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M82@D<')E9G,L("=0<F5F<U]S97-S:6]N)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN(BDL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"A?*")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M(BDL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1G<F]U<"`](&YU;&P["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=7!D871E9#L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E('1H
M92!522!F;W(@=&AE('!R969E<F5N8V5S(&EN=&5R9F%C92P@96ET:&5R(&9O
M<B!A"B`@("`@*B!S<&5C:69I8R!G<F]U<"P@;W(@=&AE(&=R;W5P('-E;&5C
M=&EO;B!I;G1E<F9A8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9W)O=7`@(%1H92!G<F]U<"!T;R!G96YE<F%T92!T:&4@54D@9F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G96YE<F%T955)*"1G<F]U<"`](&YU;&PI"B`@
M("!["B`@("`@("`@9VQO8F%L("1B<F]W<V5R+"`D8V]N9BP@)'!R969S+"`D
M<')E9D=R;W5P<RP@)%]P<F5F<RP@)')E9VES=')Y+"`D87!P.PH*("`@("`@
M("`O*B!#:&5C:R!I9B!A;GD@;W!T:6]N<R!A<F4@86-T=6%L;'D@879A:6QA
M8FQE+B`J+PH@("`@("`@(&EF("AI<U]N=6QL*"1P<F5F1W)O=7!S*2D@>PH@
M("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/G!U<V@H7R@B
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(I+"`G:&]R9&4N;65S
M<V%G92<I.PH@("`@("`@('T*"B`@("`@("`@+RH@4VAO=R!T:&4@:&5A9&5R
M+B`J+PH@("`@("`@(%!R969S7U5).CIG96YE<F%T94AE861E<B@D9W)O=7`I
M.PH*("`@("`@("`O*B!!<W-I9VX@=F%R:6%B;&5S('1O(&AO;&0@<V5L96-T
M(&QI<W1S+B`J+PH@("`@("`@(&EF("@A)'!R969S+3YI<TQO8VME9"@G;&%N
M9W5A9V4G*2D@>PH@("`@("`@("`@("`D1TQ/0D%,4ULG;&%N9W5A9V5?;W!T
M:6]N<R==(#T@)$=,3T)!3%-;)VYL<R==6R=L86YG=6%G97,G73L*("`@("`@
M("`@("`@87)R87E?=6YS:&EF="@D1TQ/0D%,4ULG;&%N9W5A9V5?;W!T:6]N
M<R==+"!?*")$969A=6QT(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E
M;7!T>2@D9W)O=7`I("8F(%!R969S7U5).CIG<F]U<$ES161I=&%B;&4H)&=R
M;W5P*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D<')E9D=R;W5P<ULD9W)O
M=7!=6R=M96UB97)S)UT@87,@)'!R968I('L*("`@("`@("`@("`@("`@(&EF
M("@A)'!R969S+3YI<TQO8VME9"@D<')E9BDI('L*("`@("`@("`@("`@("`@
M("`@("`O*B!'970@=&AE(&AE;'`@;&EN:RX@*B\*("`@("`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1?<')E9G-;)'!R969=6R=H96QP)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1H96QP;&EN:R`]($AE;'`Z.FQI;FLH
M(65M<'1Y*"1?<')E9G-;)'!R969=6R=S:&%R960G72D@/R`G:&]R9&4G(#H@
M)')E9VES=')Y+3YG971!<'`H*2P@)%]P<F5F<ULD<')E9EU;)VAE;'`G72D[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&AE;'!L:6YK(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)%]P<F5F<ULD<')E
M9EU;)W1Y<&4G72D@>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VEM<&QI
M8VET)SH*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)W-P96-I86PG.@H@("`@("`@("`@("`@("`@
M("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`A
M96UP='DH)%]P<F5F<ULD<')E9EU;)W-H87)E9"==*2`_("=H;W)D92<@.B`D
M<F5G:7-T<GDM/F=E=$%P<"@I*2`N("(O<')E9G,O)'!R968N:6YC(CL*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F4@
M)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]P<F5F
M<R\G("X@)%]P<F5F<ULD<')E9EU;)W1Y<&4G72`N("<N:6YC)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I
M("X@)R]P<F5F<R]E;F0N:6YC)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<W!A;B`](#$P,#L*("`@("`@("`@("`@)&-O;'5M;G,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!R969'<F]U<',I*2![
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<')E9D=R;W5P<R!A<R`D9W)O
M=7`@/3X@)&=V86QS*2!["B`@("`@("`@("`@("`@("`@("`@:68@*%!R969S
M7U5).CIG<F]U<$ES161I=&%B;&4H)&=R;W5P*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]L(#T@)&=V86QS6R=C;VQU;6XG73L*("`@("`@("`@
M("`@("`@("`@("`@("`@=6YS970H)&=V86QS6R=C;VQU;6XG72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1C;VQU;6YS6R1C;VQ=6R1G<F]U<%T@/2`D
M9W9A;',["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1C;VQU;6YS*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1S<&%N(#T@<F]U;F0H,3`P("\@8V]U;G0H)&-O
M;'5M;G,I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@
M)VAO<F1E)RD@+B`G+W!R969S+V]V97)V:65W+FEN8R<["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!T:&4@9G5L;"!H
M96%D97(@;V8@82!P<F5F97)E;F-E('-C<F5E;B!I;F-L=61I;F<*("`@("`J
M(&UE;G4@86YD(&YA=FEG871I;VX@8F%R<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1G<F]U<"`@5&AE(&=R;W5P('1O(&=E;F5R871E('1H92!H
M96%D97(@9F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T94AE861E
M<B@D9W)O=7`@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GDL("1P<F5F1W)O=7!S+"`D87!P+"`D<&5R;7,L("1P<F5F<RP@)&YO=&EF
M:6-A=&EO;CL*"B`@("`@("`@)'1I=&QE(#T@7R@B57-E<B!/<'1I;VYS(BD[
M"B`@("`@("`@:68@*"1G<F]U<"`]/2`G:61E;G1I=&EE<R<@)B8@(21P<F5F
M<RT^:7-,;V-K960H)V1E9F%U;'1?:61E;G1I='DG*2D@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*"=N97=#:&]I8V4H*2<L("=J879A<V-R
M:7!T)RD["B`@("`@("`@?0H@("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG
M970H)W1E;7!L871E<R<L("1A<'`I("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<[
M"B`@("`@("`@:68@*&ES7V-A;&QA8FQE*&%R<F%Y*"1A<'`L("=G971-96YU
M)RDI*2!["B`@("`@("`@("`@("1M96YU(#T@8V%L;%]U<V5R7V9U;F,H87)R
M87DH)&%P<"P@)V=E=$UE;G4G*2D["B`@("`@("`@("`@(')E<75I<F4@)')E
M9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]M96YU+VUE
M;G4N:6YC)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!5<V4@
M82!D969A=6QT(&UE;G4N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O365N=2YP:'`G.PH@("`@("`@("`@("`D;65N=2`]("9N97<@365N
M=2@I.PH@("`@("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP
M;&%T97,G+"`G:&]R9&4G*2`N("<O;65N=2]M96YU+FEN8R<["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-?8V%L;&%B;&4H87)R87DH)&%P<"P@)W-T871U
M<R<I*2D@>PH@("`@("`@("`@("!C86QL7W5S97)?9G5N8RAA<G)A>2@D87!P
M+"`G<W1A='5S)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1'
M3$]"04Q36R=N;W1I9FEC871I;VXG72T^;F]T:69Y*&%R<F%Y*"=L:7-T96YE
M<G,G(#T^("=S=&%T=7,G*2D["B`@("`@("`@?0H*("`@("`@("`O*B!'970@
M;&ES="!O9B!A8V-E<W-I8FQE(&%P<&QI8V%T:6]N<RX@*B\*("`@("`@("`D
M87!P<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)')E9VES=')Y+3YA
M<'!L:6-A=&EO;G,@87,@)&%P<&QI8V%T:6]N(#T^("1P87)A;7,I('L*("`@
M("`@("`@("`@+R\@36%K92!S=7)E('1H92!A<'`@:7,@:6YS=&%L;&5D(&%N
M9"!H87,@82!P<F5F<R!F:6QE+@H@("`@("`@("`@("!I9B`H(69I;&5?97AI
M<W1S*"1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'!L:6-A=&EO;BD@
M+B`G+V-O;F9I9R]P<F5F<RYP:'`G*2D@>PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D<&%R86US
M6R=S=&%T=7,G72`]/2`G:&5A9&EN9R<@?'P*("`@("`@("`@("`@("`@("1P
M87)A;7-;)W-T871U<R==(#T]("=B;&]C:R<I('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#:&5C
M:R!I9B!T:&4@8W5R<F5N="!U<V5R(&AA<R!P97)M:7-S;VX@=&\@<V5E('1H
M:7,*("`@("`@("`@("`@("H@87!P;&EC871I;VXL(&%N9"!I9B!T:&4@87!P
M;&EC871I;VX@:7,@86-T:79E+@H@("`@("`@("`@("`@*B!!9&UI;FES=')A
M=&]R<R!A;'=A>7,@<V5E(&%L;"!A<'!L:6-A=&EO;G,N("HO"B`@("`@("`@
M("`@(&EF("@H075T:#HZ:7-!9&UI;B@I("8F("1P87)A;7-;)W-T871U<R==
M("$]("=I;F%C=&EV92<I('Q\"B`@("`@("`@("`@("`@("`H)')E9VES=')Y
M+3YH87-097)M:7-S:6]N*"1A<'!L:6-A=&EO;BD@)B8*("`@("`@("`@("`@
M("`@("`H)'!A<F%M<ULG<W1A='5S)UT@/3T@)V%C=&EV92<@?'P@)'!A<F%M
M<ULG<W1A='5S)UT@/3T@)VYO=&]O;&)A<B<I*2D@>PH@("`@("`@("`@("`@
M("`@)&%P<'-;)&%P<&QI8V%T:6]N72`](%\H)'!A<F%M<ULG;F%M92==*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!A<V]R="@D87!P<RD[
M"@H@("`@("`@("\J(%-H;W<@=&AE(&-U<G)E;G0@87!P;&EC871I;VX@86YD
M(&$@9F]R;2!F;W(@<W=I=&-H:6YG"B`@("`@("`@("H@87!P;&EC871I;VYS
M+B`J+PH@("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E
M<R<L("=H;W)D92<I("X@)R]P<F5F<R]A<'`N:6YC)SL*"B`@("`@("`@+RH@
M268@=&AE<F4G<R!O;FQY(&]N92!P<F5F1W)O=7`L(&IU<W0@<VAO=R!I="X@
M*B\*("`@("`@("!I9B`H96UP='DH)&=R;W5P*2`F)B!C;W5N="@D<')E9D=R
M;W5P<RD@/3T@,2D@>PH@("`@("`@("`@("`D9W)O=7`@/2!A<G)A>5]K97ES
M*"1P<F5F1W)O=7!S*3L*("`@("`@("`@("`@)&=R;W5P(#T@87)R87E?<&]P
M*"1G<F]U<"D["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1G<F]U
M<"D@)B8@4')E9G-?54DZ.F=R;W5P27-%9&ET86)L92@D9W)O=7`I*2!["B`@
M("`@("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L
M("=H;W)D92<I("X@)R]P<F5F<R]B96=I;BYI;F,G.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($=E;F5R871E('1H92!C;VYT96YT(&]F('1H
M92!T:71L92!B87(@;F%V:6=A=&EO;B!C96QL("AP<F5V:6]U<R!\(&YE>'0*
M("`@("`J(&]P=&EO;B!G<F]U<"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9W)O=7`@($-U<G)E;G0@;W!T:6]N(&=R;W5P+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G96YE<F%T94YA=FEG871I;VY#96QL*"1G<F]U<"D*("`@
M('L*("`@("`@("!G;&]B86P@)'!R969'<F]U<',L("1R96=I<W1R>2P@)&%P
M<#L*"B`@("`@("`@+R\@4V5A<F-H(&9O<B!P<F5V:6]U<R!A;F0@;F5X="!G
M<F]U<',N"B`@("`@("`@)'!R979I;W5S(#T@;G5L;#L*("`@("`@("`D;F5X
M="`](&YU;&P["B`@("`@("`@)&QA<W0@/2!N=6QL.PH@("`@("`@("1F:7)S
M="`](&YU;&P["B`@("`@("`@)&9O=6YD(#T@9F%L<V4["B`@("`@("`@)&9I
M;FES:"`](&9A;'-E.PH@("`@("`@(&9O<F5A8V@@*"1P<F5F1W)O=7!S(&%S
M("1P9W)O=7`@/3X@)&=V86PI('L*("`@("`@("`@("`@:68@*%!R969S7U5)
M.CIG<F]U<$ES161I=&%B;&4H)'!G<F]U<"DI('L*("`@("`@("`@("`@("`@
M(&EF("@A)&9I<G-T*2!["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T(#T@
M)'!G<F]U<#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1P9W)O=7`@
M/3T@)&=R;W5P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P<F5V:6]U
M<R`]("1L87-T.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T
M<G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"$D9FEN:7-H*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1F:6YI<V@@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;F5X="`]("1P9W)O=7`["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&QA<W0@/2`D<&=R;W5P.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@A)'!R979I;W5S*2!["B`@("`@("`@("`@("1P<F5V:6]U<R`]
M("1L87-T.PH@("`@("`@('T*("`@("`@("!I9B`H(21N97AT*2!["B`@("`@
M("`@("`@("1N97AT(#T@)&9I<G-T.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1&]N)W0@;&]O<"!I9B!T:&5R92=S(&]N;'D@;VYE(&=R;W5P+B`J+PH@("`@
M("`@(&EF("@D;F5X="`]/2`D<')E=FEO=7,I('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@96-H;R`G/'5L/CQL:3XG.PH@("`@
M("`@(&EF("@A96UP='DH)'!R969'<F]U<'-;)'!R979I;W5S75LG=7)L)UTI
M*2!["B`@("`@("`@("`@(&5C:&\@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"1P<F5F1W)O=7!S6R1P<F5V:6]U<UU;)W5R;"==*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?*")0<F5V:6]U<R!O<'1I;VYS
M(BDI.PH@("`@("`@("`@("!E8VAO("<F;'0[)FQT.R`G("X@)'!R969'<F]U
M<'-;)'!R979I;W5S75LG;&%B96PG73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<BA(
M;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@
M+B`G+W-E<G9I8V5S+W!R969S+G!H<"<I+"!A<G)A>2@G9W)O=7`G(#T^("1P
M<F5V:6]U<RP@)V%P<"<@/3X@)&%P<"DI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%\H(E!R979I;W5S(&]P=&EO;G,B*2D["B`@("`@("`@("`@
M(&5C:&\@)R9L=#LF;'0[("<@+B`D<')E9D=R;W5P<ULD<')E=FEO=7-=6R=L
M86)E;"==.PH@("`@("`@('T*("`@("`@("!E8VAO("<\+V$^)FYB<W`[?"9N
M8G-P.R<["B`@("`@("`@:68@*"%E;7!T>2@D<')E9D=R;W5P<ULD;F5X=%U;
M)W5R;"==*2D@>PH@("`@("`@("`@("!E8VAO($AO<F1E.CIL:6YK*$AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@D<')E9D=R;W5P<ULD;F5X=%U;)W5R;"==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*").97AT(&]P=&EO;G,B
M*2D["B`@("`@("`@("`@(&5C:&\@)'!R969'<F]U<'-;)&YE>'1=6R=L86)E
M;"==("X@)R`F9W0[)F=T.R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z
M.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S
M97)V:6-E<R]P<F5F<RYP:'`G*2P@87)R87DH)V=R;W5P)R`]/B`D;F5X="P@
M)V%P<"<@/3X@)&%P<"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%\H(DYE>'0@;W!T:6]N<R(I*3L*("`@("`@("`@("`@96-H;R`D<')E9D=R
M;W5P<ULD;F5X=%U;)VQA8F5L)UT@+B`G("9G=#LF9W0[)SL*("`@("`@("!]
M"B`@("`@("`@96-H;R`G/"]A/CPO;&D^/"]U;#XG.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H92!D969A=6QT(&%P<&QI8V%T:6]N('1O('-H;W<@
M<')E9F5R96YC97,@9F]R+B!$969A=6QT<PH@("`@("H@=&\@)VAO<F1E)RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=$%P<"@I"B`@("!["B`@
M("`@("`@)&%P<&QI8V%T:6]N<R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YL
M:7-T07!P<RAN=6QL+"!T<G5E+"!015)-4U]214%$*3L*("`@("`@("!R971U
M<FX@:7-S970H)&%P<&QI8V%T:6]N<ULG:&]R9&4G72D@/R`G:&]R9&4G(#H@
M87)R87E?<VAI9G0H)&%P<&QI8V%T:6]N<RD["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O
M:6US<"YP:'``````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P
M-S<P`#$P-#$W,S8R-S<Q`#`R,#<W-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@4')E9F5R96YC92!S
M=&]R86=E(&EM<&QE;65N=&%T:6]N(&9O<B!A;B!)35-0('-E<G9E<BX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O4')E9G,O:6US<"YP:'`L=B`Q
M+C$N,3`N,3$@,C`P-B\P,B\R."`P-3HU.3HQ.2!S;'5S87)Z($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!2=6)I;G-K>2`\;7)U
M8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*B!`<&%C
M:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?:6US<"!E>'1E;F1S
M(%!R969S('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R(&9U;F-T:6]N
M+@H@("`@("H@)'!A<F%M<R!M=7-T(&-O;G1A:6XZ"B`@("`@*B`G875T:%]M
M971H;V0G+"`G<V5R=F5R)RP@)W!O<G0G"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'5S97(@("`@(%5S97)N86UE(&]F(&-U<G)E;G0@=7-E<BX*
M("`@("`J($!P87)A;2!S=')I;F<@("1P87-S=V]R9"!087-S=V]R9"!F;W(@
M8W5R<F5N="!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-C;W!E("`@
M(%1H92!S8V]P92!F;W(@=&AE<V4@<')E9F5R96YC97,N"B`@("`@*B!`<&%R
M86T@87)R87D@("`D<&%R86US("`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O
M<B!T:&ES(&]B:F5C="X*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H:6YG
M("!!<F4@=V4@=7-I;F<@<V5S<VEO;B!C86-H93\*("`@("`J+PH@("`@9G5N
M8W1I;VX@4')E9G-?:6US<"@D=7-E<BP@)'!A<W-W;W)D(#T@)R<L("1S8V]P
M92`]("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@;G5L
M;"P@)&-A8VAI;F<@/2!T<G5E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@<&%R96YT.CI0<F5F<R@I.PH@("`@("`@(')E<75I<F5?
M;VYC92`G3F5T+TE-4U`N<&AP)SL*"B`@("`@("`@)'1H:7,M/E]S8V]P92`]
M("1S8V]P93L*("`@("`@("`D=&AI<RT^7V-A8VAI;F<@/2`D8V%C:&EN9SL*
M("`@("`@("`D=&AI<RT^7W5S97(@/2`D=7-E<CL*("`@("`@("`D=&AI<RT^
M<&%R86US(#T@)'!A<F%M<SL*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H
M7BXJ*4`O)RP@)'5S97(L("1M871C:&5S*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^<&%R86US6R=U<V5R;F%M92==(#T@)&UA=&-H97-;,5T["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G!A<F%M<ULG=7-E<FYA;64G
M72`]("1U<V5R.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^<&%R86US6R=P
M87-S=V]R9"==(#T@)'!A<W-W;W)D.PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^<&%R86US6R=S;V-K970G72DI('L*("`@("`@("`@("`@)'1H:7,M/G!A
M<F%M<ULG<V]C:V5T)UT@/2`D<&%R86US6R=S;V-K970G72`N("=I;7-P7R<@
M+B`D=&AI<RT^<&%R86US6R=U<V5R;F%M92==("X@)RYS8VLG.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7VEM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O
M;B@G3W!T:6]N<R<L("1T:&ES+3YP87)A;7,I.PH@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7VEM<W`M/FEN:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A
M;"@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^7VEM<W`M/G-E=$QO9V=E<B@D8V]N9ELG;&]G)UTI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!R97%U97-T960@
M<V5T(&]F('!R969E<F5N8V5S(&9R;VT@=&AE($E-4U`@<V5R=F5R+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E=')I979E*"D*("`@('L*("`@("`@("`O*B!'970@=&AE(&1E
M9F%U;'1S+B`J+PH@("`@("`@('!A<F5N=#HZ<F5T<FEE=F4H*3L*"B`@("`@
M("`@+RH@1V5T('1H92!S:&%R960@<')E9G,@86YD(')E;6]V92!T:&4@<V-O
M<&4@=F%L=64@9G)O;2!T:&4*("`@("`@("`@*B!S=')I;F<N("HO"B`@("`@
M("`@)&=L;V)A;%]P<F5F<R`]("1T:&ES+3Y?:6US<"T^9V5T*"=H;W)D92XJ
M)RD["B`@("`@("`@:68@*&ES7V$H)&=L;V)A;%]P<F5F<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&=L;V)A;%]P<F5F<SL*("`@
M("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1G;&]B86Q?<')E9G,@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1N97=+97D@/2!S=')?<F5P;&%C
M92@G:&]R9&4N)RP@)R<L("1K97DI.PH@("`@("`@("`@("!I9B`H)'9A;"`]
M/2`G+2<I('L*("`@("`@("`@("`@("`@("1V86P@/2`D=&AI<RT^9V5T1&5F
M875L="@D;F5W2V5Y*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<')E9G-;)&YE=TME>5TI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T5F%L=64H)&YE=TME>2P@)'9A;"D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1N97=+
M97DL("1V86PL(%]04D5&7U-(05)%1"D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J($1O;B=T(&9O<F=E="!T;R!C;&5A;B!I="X@*B\*("`@("`@
M("`@("`@)'1H:7,M/G-E=$1I<G1Y*"1N97=+97DL(&9A;'-E*3L*("`@("`@
M("!]"@H@("`@("`@("\J($YO=R!T:&4@87!P('-P96-I9FEC('!R969S+B`J
M+PH@("`@("`@("1L;V-A;%]P<F5F<R`]("1T:&ES+3Y?:6US<"T^9V5T*"1T
M:&ES+3Y?<V-O<&4@+B`G+BHG*3L*("`@("`@("!I9B`H:7-?82@D;&]C86Q?
M<')E9G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L
M;V-A;%]P<F5F<SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1L;V-A
M;%]P<F5F<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&YE=TME
M>2`]('-T<E]R97!L86-E*"1T:&ES+3Y?<V-O<&4@+B`G+B<L("<G+"`D:V5Y
M*3L*("`@("`@("`@("`@:68@*"1V86P@/3T@)RTG*2!["B`@("`@("`@("`@
M("`@("`D=F%L(#T@)'1H:7,M/F=E=$1E9F%U;'0H)&YE=TME>2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<')E9G-;
M)&YE=TME>5TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T5F%L=64H
M)&YE=TME>2P@)'9A;"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^861D*"1N97=+97DL("1V86PL(#`I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O*B!#;&5A;B!T:&4@<')E9BX@*B\*("`@
M("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y*"1N97=+97DL(&9A;'-E*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V%L;$AO;VMS*"D["B`@("`@("`@
M)'1H:7,M/F-A8VAE57!D871E*"D["B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@86QL(&1I<G1Y('!R969S('1O
M($E-4U`@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W)E*"D*("`@('L*("`@("`@
M("`D9&ER='E?<')E9G,@/2`D=&AI<RT^7V1I<G1Y4')E9G,H*3L*("`@("`@
M("!I9B`H(6-O=6YT*"1D:7)T>5]P<F5F<RDI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9&ER='E?
M<')E9G,@87,@)&YA;64I('L*("`@("`@("`@("`@)'-C;W!E(#T@)'1H:7,M
M/F=E=%-C;W!E*"1N86UE*3L*("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M
M/F=E=%9A;'5E*"1N86UE*3L*("`@("`@("`@("`@:68@*&5M<'1Y*"1V86QU
M92DI('L*("`@("`@("`@("`@("`@("1V86QU92`]("<M)SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^<V5T
M*"1S8V]P92`N("<N)R`N("1N86UE+"`D=F%L=64I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/G!U<V@H(E1H97)E('=A
M<R!A('!R;V)L96T@<V%V:6YG('1H92!P<F5F<F5N8V5S(BD["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@0VQE86X@=&AE('!R968@<VEN8V4@:70@=V%S(&IU<W0@<V%V
M960N("HO"B`@("`@("`@("`@("1T:&ES+3YS971$:7)T>2@D;F%M92P@9F%L
M<V4I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^8V%C:&55<&1A=&4H*3L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*```````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]K;VQA8BYP:'``
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S-S$`,3`T,3<S
M-C(W-S$`,#(Q,3$T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+VQD
M87`N<&AP)SL*"B\J*@H@*B!+;VQA8B!I;7!L96UE;G1A=&EO;B!O9B!T:&4@
M2&]R9&4@<')E9F5R96YC92!S>7-T96TN($1E<FEV97,@9G)O;2!T:&4*("H@
M4')E9G-?;&1A<"!,1$%0(&%U=&AE;G1I8V%T:6]N(&]B:F5C="P@86YD('-I
M;7!L>2!P<F]V:61E<R!P87)A;65T97)S('1O(&ET"B`J(&)A<V5D(&]N('1H
M92!G;&]B86P@2V]L86(@8V]N9FEG=7)A=&EO;BX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O:V]L86(N<&AP+'8@,2XQ+C$P+C<@,C`P
M-B\P,2\P,2`R,3HR.#HS,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#0M,C`P-B!3='5A<G0@0FEN9V4@/',N8FEN9V5`8V]D969U<VEO;BYC;RYZ
M83X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%-T=6%R="!":6YG92`\
M<RYB:6YG94!C;V1E9G5S:6]N+F-O+GIA/@H@*B!`<VEN8V4@("!(;W)D92`Q
M+C,*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*("HO"F-L87-S(%!R969S7VMO
M;&%B(&5X=&5N9',@4')E9G-?;&1A<"!["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1S(&$@;F5W($MO;&%B('!R969E<F5N8V5S(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@5&AE('5S97(@=VAO
M(&]W;G,@=&AE<V4@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P87-S=V]R9"`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`D=7-E
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-C;W!E("`@("!4:&4@8W5R<F5N
M="!A<'!L:6-A=&EO;B!S8V]P92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E
M<G,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V%C:&EN9R`@4VAO=6QD(&-A
M8VAI;F<@8F4@=7-E9#\*("`@("`J+PH@("`@9G5N8W1I;VX@4')E9G-?:V]L
M86(H)'5S97(L("1P87-S=V]R9"P@)'-C;W!E(#T@)R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH*2P@)&-A8VAI;F<@/2!F
M86QS92D*("`@('L*("`@("`@("`D<&%R86US6R=H;W-T<W!E8R==(#T@)$=,
M3T)!3%-;)V-O;F8G75LG:V]L86(G75LG;&1A<"==6R=S97)V97(G73L*("`@
M("`@("`D<&%R86US6R=P;W)T)UT@/2`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA
M8B==6R=L9&%P)UU;)W!O<G0G73L*("`@("`@("`D<&%R86US6R=V97)S:6]N
M)UT@/2`G,R<["B`@("`@("`@)'!A<F%M<ULG8F%S961N)UT@/2`D1TQ/0D%,
M4ULG8V]N9B==6R=K;VQA8B==6R=L9&%P)UU;)V)A<V5D;B==.PH@("`@("`@
M("1P87)A;7-;)V9E=&-H9&XG72`]('1R=64["B`@("`@("`@+R\D<&%R86US
M6R=R;V]T9&XG72`]("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G
M75LG8FEN9&1N)UT["B`@("`@("`@+R\D<&%R86US6R=P87-S=V]R9"==(#T@
M)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG;&1A<"==6R=B:6YD<'<G73L*
M("`@("`@("`D<&%R86US6R=U:60G72`](&%R<F%Y*"=M86EL)RP@)W5I9"<I
M.PH*("`@("`@("!P87)E;G0Z.E!R969S7VQD87`H)'5S97(L("1P87-S=V]R
M9"P@)'-C;W!E+"`D<&%R86US+"`D8V%C:&EN9RD["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'``````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0V,S,V`#$P-#$W,S8R-S<Q
M`#`R,#<U-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@4')E9F5R96YC97,@<W1O<F%G92!I;7!L96UE
M;G1A=&EO;B!F;W(@4$A0)W,@3$1!4"!E>'1E;G1I;VXN"B`J"B`J(%)E<75I
M<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G8F%S961N)R`@("!4:&4@8F%S
M92!$3B!F;W(@=&AE($Q$05`@<V5R=F5R+@H@*B`@("=H;W-T<W!E8R<@(%1H
M92!H;W-T;F%M92!O9B!T:&4@3$1!4"!S97)V97(N"B`J("`@)W5I9"<@("`@
M("`@5&AE('5S97)N86UE('-E87)C:"!K97DN/"]P<F4^"B`J"B`J($]P=&EO
M;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G<&%S<W=O<F0G("`G<F]O=&1N
M)W,@<&%S<W=O<F0@9F]R(&)I;F0@875T:&5N=&EC871I;VXN"B`J("`@)W!O
M<G0G("`@("`@5&AE('!O<G0@;V8@=&AE($Q$05`@<V5R=F5R+@H@*B`@("`@
M("`@("`@("`@($1%1D%53%0Z(#,X.0H@*B`@("=R;V]T9&XG("`@(%1H92!$
M3B!O9B!T:&4@<F]O="`H861M:6YI<W1R871I=F4I(&%C8V]U;G0@=&\@8FEN
M9"!F;W(*("H@("`@("`@("`@("`@("!W<FET92!O<&5R871I;VYS+@H@*B`@
M("=U<V5R;F%M92<@(%1/1$\*("H@("`G=F5R<VEO;B<@("!4:&4@=F5R<VEO
M;B!O9B!T:&4@3$1!4"!P<F]T;V-O;"!T;R!U<V4N"B`J("`@("`@("`@("`@
M("`@1$5&055,5#H@3D].12`H<WES=&5M(&1E9F%U;'0@=VEL;"!B92!U<V5D
M*3PO<')E/@H@*@H@*B!.3U1%.B!P87)A;65T97(@)W5S97)N86UE)R!H87,@
M8F5E;B!D97!R96-A=&5D+B!5<V4@)W)O;W1D;B<N"B`J"B`J"B`J($EF('-E
M='1I;F<@=7`@87,@=&AE($AO<F1E('!R969E<F5N8V4@:&%N9&QE<B!I;B!C
M;VYF+G!H<"P@=&AE(&9O;&QO=VEN9PH@*B!I<R!A;B!E>&%M<&QE(&-O;F9I
M9W5R871I;VXN"B`J(%1H92!S8VAE;6%S(&YE961E9"!F;W(@;&1A<"!A<F4@
M:6X@:&]R9&4O<V-R:7!T<R]L9&%P+@H@*@H@*B`\<')E/@H@*B`@("1C;VYF
M6R=P<F5F<R==6R=D<FEV97(G72`]("=L9&%P)SL*("H@("`D8V]N9ELG<')E
M9G,G75LG<&%R86US)UU;)VAO<W1S<&5C)UT@/2`G;&]C86QH;W-T)SL*("H@
M("`D8V]N9ELG<')E9G,G75LG<&%R86US)UU;)W!O<G0G72`]("<S.#DG.PH@
M*B`@("1C;VYF6R=P<F5F<R==6R=P87)A;7,G75LG8F%S961N)UT@/2`G9&,]
M97AA;7!L92QD8SUO<F<G.PH@*B`@("1C;VYF6R=P<F5F<R==6R=P87)A;7,G
M75LG=6ED)UT@/2`G;6%I;"<["B`J(#PO<')E/@H@*@H@*B!4:&4@9F]L;&]W
M:6YG(&ES('9A;&ED(&)U="!W;W5L9"!O;FQY(&)E(&YE8V5S<V%R>2!I9B!U
M<V5R<PH@*B!D;R!.3U0@:&%V92!P97)M:7-S:6]N('1O(&UO9&EF>2!T:&5I
M<B!O=VX@3$1!4"!A8V-O=6YT<RX*("H*("H@/'!R93X*("H@("`D8V]N9ELG
M<')E9G,G75LG<&%R86US)UU;)W)O;W1D;B==(#T@)V-N/4UA;F%G97(L9&,]
M97AA;7!L92QD8SUO<F<G.PH@*B`@("1C;VYF6R=P<F5F<R==6R=P87)A;7,G
M75LG<&%S<W=O<F0G72`]("=P87-S=V]R9"<["B`J(#PO<')E/@H@*@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<"QV(#$N
M.#4N,3`N,3@@,C`P-B\P,B\R."`P-3HU.3HQ.2!S;'5S87)Z($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@
M/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C
M:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?;&1A<"!E>'1E;F1S
M(%!R969S('L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!C;VYN
M96-T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!,1$%0(&-O;FYE8W1I;VXN
M"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@
M)%]C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@0F]O;&5A;B!I;F1I8V%T
M:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE8W1E9"!T;R!T:&4@3$1!
M4"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M4W1R:6YG(&AO;&1I;F<@=&AE('5S97(G<R!$3BX*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D;B`]("<G.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,1$%0('!R969E<F5N8V5S(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@
M5&AE('5S97(@=VAO(&]W;G,@=&AE<V4@<')E9F5R96YC97,N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5&AE('!A<W-W;W)D(&%S<V]C:6%T
M960@=VET:"`D=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-C;W!E("`@
M("!4:&4@8W5R<F5N="!A<'!L:6-A=&EO;B!S8V]P92X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T
M:6]N('!A<F%M971E<G,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V%C:&EN
M9R`@4VAO=6QD(&-A8VAI;F<@8F4@=7-E9#\*("`@("`J+PH@("`@9G5N8W1I
M;VX@4')E9G-?;&1A<"@D=7-E<BP@)'!A<W-W;W)D+"`D<V-O<&4@/2`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"DL("1C
M86-H:6YG(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE>'1E
M;G-I;VY%>&ES=',H)VQD87`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH4$5!4CHZ<F%I<V5%<G)O<BA?*")0<F5F<U]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDI+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]U<V5R(#T@)'5S97([
M"B`@("`@("`@)'1H:7,M/E]S8V]P92`]("1S8V]P93L*("`@("`@("`D=&AI
M<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@)'1H:7,M/E]C86-H:6YG
M(#T@)&-A8VAI;F<["@H@("`@("`@("\J($EF(&$@=F%L:60@<V5R=F5R('!O
M<G0@:&%S(&YO="!B965N('-P96-I9FEE9"P@<V5T('1H92!D969A=6QT+B`J
M+PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W!O<G0G72D@
M?'P@(6ES7VEN="@D=&AI<RT^7W!A<F%M<ULG<&]R="==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R="==(#T@,S@Y.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@)'!A<F%M<ULG<F]O=&1N)UT@:7,@96UP='DL(&%U
M=&AE;G1I8V%T92!A<R!T:&4@8W5R<F5N="!U<V5R+@H@("`@("`@("`@($YO
M=&4Z(%1H:7,@87-S=6UE<R!T:&4@=7-E<B!I<R!A;&QO=V5D('1O(&UO9&EF
M>2!T:&5I<B!O=VX@3$1!4`H@("`@("`@("`@("`@("`@(&5N=')Y+B`J+PH@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72D@
M)B8*("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P87)A;7-;)W)O;W1D;B==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]
M("1U<V5R.PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G
M72`]("1P87-S=V]R9#L*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ4')E
M9G,H*3L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS(&$@8V]N;F5C=&EO
M;B!T;R!T:&4@3$1!4"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@("\J
M(%)E='5R;B!I9B!A;')E861Y(&-O;FYE8W1E9"X@*B\*("`@("`@("!I9B`H
M)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG
M*"1T:&ES+3Y?<&%R86US+"`G<')E9G,G+`H@("`@("`@("`@("!A<G)A>2@G
M:&]S='-P96,G+"`G8F%S961N)RP@)W5I9"<L("=P87-S=V]R9"<I+`H@("`@
M("`@("`@("`G<')E9F5R96YC97,@3$1!4"<I.PH*("`@("`@("`O*B!!;&QO
M=R!F;W(@;75L=&EP;&4@=6ED('-E87)C:"!F:65L9',@*B\*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?<&%R86US6R=U:60G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W5I9"==(#T@87)R87DH)'1H:7,M/E]P
M87)A;7-;)W5I9"==*3L*("`@("`@("!]"@H@("`@("`@("\J($-O;FYE8W0@
M=&\@=&AE($Q$05`@<V5R=F5R(&%N;VYY;6]U<VQY+B`J+PH@("`@("`@("1C
M;VYN(#T@;&1A<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==
M+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==*3L*("`@("`@("!I9B`H(21C;VYN
M*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@
M("`@("`@<W!R:6YT9B@G1F%I;&5D('1O(&]P96X@86X@3$1!4"!C;VYN96-T
M:6]N('1O("5S+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=H;W-T<W!E8R==*2P*("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\J(%-E="!T:&4@3$1!4"!P<F]T;V-O;"!V97)S:6]N
M+B`J+PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG=F5R<VEO
M;B==*2D@>PH@("`@("`@("`@("!I9B`H(6QD87!?<V5T7V]P=&EO;B@D8V]N
M;BP@3$1!4%]/4%1?4%)/5$]#3TQ?5D524TE/3BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72DI
M('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@
M("`@("`@("`@("`@('-P<FEN=&8H)U-E="!,1$%0('!R;W1O8V]L('9E<G-I
M;VX@=&\@)60@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T:&ES+3Y?8V]N;F5C
M=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R
M*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@4F5G:7-T97(@;W5R(&-A;&QB86-K(&9U;F-T
M:6]N('1O(&AA;F1L92!R969E<G)A;',N("HO"B`@("`@("`@:68@*&9U;F-T
M:6]N7V5X:7-T<R@G;&1A<%]S971?<F5B:6YD7W!R;V,G*2`F)@H@("`@("`@
M("`@("`A;&1A<%]S971?<F5B:6YD7W!R;V,H)&-O;FXL(&%R<F%Y*"1T:&ES
M+"`G7W)E8FEN9%!R;V,G*2DI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H"B`@("`@("`@("`@("`@("!S<')I;G1F*"=3970@<F5B:6YD('!R
M;V,@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M;&1A<%]E<G)N;R@D=&AI<RT^7V-O;FYE8W1I;VXI+`H@("`@("`@("`@("`@
M("`@("`@("`@("!L9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O<F4@
M=&AE(&-O;FYE8W1I;VX@:&%N9&QE(&%T('1H92!I;G-T86YC92!L979E;"X@
M*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W1I;VX@/2`D8V]N;CL*("`@("`@
M("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["@H@("`@("`@(&EF("@A)'1H
M:7,M/E]P87)A;7-;)V9E=&-H9&XG72D@>PH@("`@("`@("`@("`O*B!$969I
M;F4@=&AE($1.(&]F('1H92!C=7)R96YT('5S97(N("HO"B`@("`@("`@("`@
M("1T:&ES+3Y?9&X@/2!S<')I;G1F*"<E<STE<RPE<R<L("1T:&ES+3Y?<&%R
M86US6R=U:60G75LP72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]U<V5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTI.PH*("`@("`@("`@("`@
M+RH@06YD('1H92!$3B!O9B!T:&4@875T:&5N=&EC871I;F<@=7-E<B`H;6%Y
M(&)E('1H92!S86UE(&%S(&%B;W9E*2X@*B\*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG<F]O=&1N)UTI*2!["B`@("`@("`@("`@
M("`@("`D8FEN9%]D;B`]("1T:&ES+3Y?<&%R86US6R=R;V]T9&XG73L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1B:6YD7V1N(#T@
M<W!R:6YT9B@G)7,])7,L)7,G+"`D=&AI<RT^7W!A<F%M<ULG=6ED)UU;,%TL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@0FEN9"!T;R!T:&4@3$1!4"!S97)V97(@
M87,@=&AE(&%U=&AE;G1I8V%T:6YG('5S97(N("HO"B`@("`@("`@("`@("1B
M:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V-O;FYE8W1I;VXL("1B:6YD7V1N
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W!A<W-W;W)D)UTI.PH@("`@("`@("`@("!I9B`H(21B:6YD*2!["B`@
M("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@
M("`@("`@("!S<')I;G1F*"=":6YD('1O('-E<G9E<B`E<SHE9"!W:71H($1.
M("5S(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8FEN9%]D;BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M/E]C;VYN96-T:6]N
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)'1H
M:7,M/E]C;VYN96-T:6]N*2DL"B`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4V5A<F-H(&9O
M<B!T:&4@=7-E<B=S(&9U;&P@1$XN("HO"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]P87)A;7-;)W5I9"==(&%S("1U:61?9FEE;&0I('L*("`@("`@("`@
M("`@)'-E87)C:"`](&QD87!?<V5A<F-H*"1T:&ES+3Y?8V]N;F5C=&EO;BP@
M)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'5I9%]F:65L9"`N("<])R`N("1T:&ES+3Y?=7-E
M<BP@87)R87DH)V1N)RDI.PH@("`@("`@("`@("!I9B`H)'-E87)C:"D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L="`](&QD87!?9V5T7V5N=')I97,H)'1H
M:7,M/E]C;VYN96-T:6]N+"`D<V5A<F-H*3L*("`@("`@("`@("`@("`@(&EF
M("@D<F5S=6QT("8F("1R97-U;'1;)V-O=6YT)UT@/B`P*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D;B`]("1R97-U;'1;,%U;)V1N)UT["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=F971C:&1N
M)UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@4F4M8FEN9"!A<R!T
M:&4@=7-E<BX*("`@("`@("`@("`@("`@("`@("`@("`@)&)I;F0@/2!`;&1A
M<%]B:6YD*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'1H:7,M/E]D;BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=P87-S=V]R9"==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*`H@("`@("`@("`@("!S<')I;G1F*"=&86EL960@=&\@<F5T
M<FEE=F4@=7-E<EPG<R!$3CH@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@
M("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O;FYE8W1I;VXI+`H@("`@("`@("`@
M("`@("`@("`@(&QD87!?97)R;W(H)'1H:7,M/E]C;VYN96-T:6]N*2DL"B`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W0@9G)O
M;2!T:&4@3$1!4"!S97)V97(@86YD(&-L96%N('5P('1H92!C;VYN96-T:6]N
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?9&X@/2`G)SL*("`@("`@("`@("`@)'1H:7,M/E]C;VYN
M96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N(&QD87!?8VQO<V4H
M)'1H:7,M/E]C;VYN96-T:6]N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#86QL8F%C:R!F=6YC=&EO;B!F;W(@3$1!4"!R969E<G)A;',N("!4
M:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"!W:&5N(&%N"B`@("`@*B!,1$%0(&]P
M97)A=&EO;B!R971U<FYS(&$@<F5F97)R86P@=&\@86X@86QT97)N871E('-E
M<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(#$@;VX@97)R;W(L(#`@;VX@<W5C8V5S
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E8FEN9%!R;V,H)&-O;FXL("1W
M:&\I"B`@("!["B`@("`@("`@+RH@4W1R:7`@;W5T('1H92!H;W-T;F%M92!W
M92=R92!B96EN9R!R961I<F5C=&5D('1O+B`J+PH@("`@("`@("1W:&\@/2!P
M<F5G7W)E<&QA8V4H87)R87DH)WQ>+BHZ+R]\)RP@)WPZ7&0J)'PG*2P@)R<L
M("1W:&\I.PH*("`@("`@("`O*B!&:6=U<F4@;W5T('1H92!$3B!O9B!T:&4@
M875T:&5N=&EC871I;F<@=7-E<BX@*B\*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=R;V]T9&XG72DI('L*("`@("`@("`@("`@)&)I;F1?
M9&X@/2`D=&AI<RT^7W!A<F%M<ULG<F]O=&1N)UT["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&)I;F1?9&X@/2!S<')I;G1F*"<E<STE<RPE<R<L
M("1T:&ES+3Y?<&%R86US6R=U:60G75LP72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V)A
M<V5D;B==*3L*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!T:&4@
M<V5R=F5R('=E)W)E(&)E:6YG(')E9&ER96-T960@=&\@:7,@:6X@;W5R(&QI
M<W0@;V8*("`@("`@("`@("!V86QI9"!S97)V97)S+B`J+PH@("`@("`@(&EF
M("AS=')P;W,H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL("1W:&\I(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@
M("`@("`@("`@("`@('-P<FEN=&8H)U)E9F5R<F%L('1A<F=E="`E<R!F;W(@
M1$X@)7,@:7,@;F]T(&EN('1H92!A=71H;W)I>F5D('-E<G9E<B!L:7-T(2<L
M("1W:&\L("1B:6YD7V1N*2P*("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0FEN9"!T;R!T:&4@;F5W('-E<G9E<BX@*B\*("`@("`@("`D
M8FEN9"`]($!L9&%P7V)I;F0H)&-O;FXL("1B:6YD7V1N+"`D=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@:68@*"$D8FEN9"D@>PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@("`@('-P
M<FEN=&8H)U)E8FEN9"!T;R!S97)V97(@)7,Z)60@=VET:"!$3B`E<R!F86EL
M960Z(%LE9%T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@)&)I;F1?9&XL"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R
M;F\H)'1H:7,M/E]C;VYN96-T:6]N*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@,#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T
M:&4@<F5Q=65S=&5D('-E="!O9B!P<F5F97)E;F-E<R!F<F]M('1H92!U<V5R
M)W,@3$1!4"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R971R:65V92@I"B`@("!["B`@
M("`@("`@+RH@071T96UP="!T;R!P=6QL('1H92!V86QU97,@9G)O;2!T:&4@
M<V5S<VEO;B!C86-H92!F:7)S="X@*B\*("`@("`@("!I9B`H)'1H:7,M/F-A
M8VAE3&]O:W5P*"DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H*("`@("`@("`O*B!,;V%D(&1E9F%U;'1S('1O(&UA:V4@<W5R92!W
M92!H879E(&%L;"!P<F5F97)E;F-E<RX@*B\*("`@("`@("!P87)E;G0Z.G)E
M=')I979E*"D["@H@("`@("`@("\J($UA:V4@<W5R92!W92!A<F4@8V]N;F5C
M=&5D+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O
M*B!/;FQY(&9E=&-H('1H92!F:65L9',@9F]R('1H92!A='1R:6)U=&5S('=E
M(&YE960N("HO"B`@("`@("`@)&%T=')S(#T@87)R87DH)VAO<F1E4')E9G,G
M*3L*("`@("`@("!I9B`H<W1R8VUP*"1T:&ES+3Y?<V-O<&4L("=H;W)D92<I
M("$](#`I('L*("`@("`@("`@("`@)&%T=')S6UT@/2`D=&AI<RT^7W-C;W!E
M("X@)U!R969S)SL*("`@("`@("!]"@H@("`@("`@("\J(%-E87)C:"!F;W(@
M=&AE(&UU;'1I+79A;'5E9"!F:65L9"!C;VYT86EN:6YG('1H92!A<G)A>2!O
M9@H@("`@("`@("`@('!R969E<F5N8V5S+B`J+PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?<&%R86US6R=U:60G72!A<R`D=6ED7V9I96QD*2!["B`@("`@
M("`@("`@("1S96%R8V@@/2!L9&%P7W-E87)C:"@D=&AI<RT^7V-O;FYE8W1I
M;VXL("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1U:61?9FEE;&0@+B`G/2<@+B`D=&AI<RT^
M7W5S97(L("1A='1R<RD["B`@("`@("`@("`@(&EF("@D<V5A<F-H*2!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@;&1A<%]G971?96YT<FEE<R@D=&AI
M<RT^7V-O;FYE8W1I;VXL("1S96%R8V@I.PH@("`@("`@("`@("`@("`@:68@
M*"1R97-U;'0@)B8@)')E<W5L=%LG8V]U;G0G72`^(#`I('L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1R97-U;'0I*2![
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('!R969E<F5N8V5S('-E<G9E<BXG+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@;&1A<%]G971?96YT
M<FEE<R@I(&-O;G9E<G1S(&%T=')I8G5T92!I;F1E>&5S('1O(&QO=V5R8V%S
M92X@*B\*("`@("`@("`D9FEE;&0@/2!3=')I;F<Z.FQO=V5R*"1T:&ES+3Y?
M<V-O<&4@+B`G<')E9G,G*3L*"B`@("`@("`@:68@*&ES<V5T*"1R97-U;'0I
M*2!["B`@("`@("`@("`@("\J(%-E="!T:&4@<F5Q=65S=&5D('9A;'5E<R!I
M;B!T:&4@)'1H:7,M/E]P<F5F<R!H87-H(&)A<V5D(&]N"B`@("`@("`@("`@
M("`@('1H92!C;VYT96YT<R!O9B!T:&4@3$1!4"!R97-U;'0N"@H@("`@("`@
M("`@("`@("!0<F5F97)E;F-E<R!A<F4@<W1O<F5D(&%S(&-O;&]N+7-E<&%R
M871E9"!N86UE.G9A;'5E('!A:7)S+@H@("`@("`@("`@("`@("!%86-H('!A
M:7(@:7,@<W1O<F5D(&%S(&ET<R!O=VX@871T<FEB=71E(&]F9B!O9B!T:&4@
M;75L=&DM"B`@("`@("`@("`@("`@('9A;'5E(&%T=')I8G5T92!N86UE9"!I
M;CH@)'1H:7,M/E]S8V]P92`N("=0<F5F<R<*"B`@("`@("`@("`@("`@($YO
M=&4@=&AA="!0<F5F<SHZ<V5T5F%L=64H*2!C86XG="!B92!U<V5D(&AE<F4@
M8F5C875S92!O9B!T:&4*("`@("`@("`@("`@("`@8VAE8VL@9F]R('1H92`B
M8VAA;F=E86)L92(@8FET+B`@5V4@=V%N="!T;R!O=F5R<FED92!T:&%T"B`@
M("`@("`@("`@("`@(&-H96-K('=H96X@<&]P=6QA=&EN9R!T:&4@)'1H:7,M
M/E]P<F5F<R!H87-H(&9R;VT@=&AE($Q$05`*("`@("`@("`@("`@("`@<V5R
M=F5R+@H@("`@("`@("`@("`@*B\*"B`@("`@("`@("`@("1P<F5F<R`](&%R
M<F%Y*"D["@H@("`@("`@("`@("`O*B!)9B!H;W)D95!R969S(&5X:7-T<RP@
M;65R9V4@=&AE;2!A<R!T:&4@8F%S92!O9B!T:&4@<')E9G,N("HO"B`@("`@
M("`@("`@(&EF("AI<W-E="@D<F5S=6QT6S!=6R=H;W)D97!R969S)UTI*2![
M"B`@("`@("`@("`@("`@("`D<')E9G,@/2!A<G)A>5]M97)G92@D<')E9G,L
M("1R97-U;'1;,%U;)VAO<F1E<')E9G,G72D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($EF('1H:7,@<V-O<&4G<R!P<F5F<R!A<F4@879A:6QA
M8FQE+"!M97)G92!T:&5M(&%S('=I;&PN("!':79E"B`@("`@("`@("`@("`J
M('1H96T@82!H:6=H97(@<')E8V5D96YC92!T:&%N(&AO<F1E4')E9G,N("HO
M"B`@("`@("`@("`@(&EF("AS=')C;7`H)'1H:7,M/E]S8V]P92P@)VAO<F1E
M)RD@(3T@,"D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R97-U;'1;
M,%U;)&9I96QD72DI('L*("`@("`@("`@("`@("`@("`@("`D<')E9G,@/2!A
M<G)A>5]M97)G92@D<')E9G,L("1R97-U;'1;,%U;)&9I96QD72D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1P<F5F<R!A<R`D<')E9G-T<BD@>PH@("`@("`@("`@("`@("`@+RH@
M268@=&AE('-T<FEN9R!D;V5S;B=T(&-O;G1A:6X@82!C;VQO;B!D96QI;6ET
M97(L('-K:7`@:70N("HO"B`@("`@("`@("`@("`@("!I9B`H<W5B<W1R7V-O
M=6YT*"1P<F5F<W1R+"`G.B<I(#T](#`I('L*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`O*B!3<&QI="!T:&4@<W1R:6YG(&EN=&\@:71S(&YA;64Z=F%L=64@8V]M
M<&]N96YT<RX@*B\*("`@("`@("`@("`@("`@(&QI<W0H)'!R968L("1V86PI
M(#T@<W!L:70H)SHG+"`D<')E9G-T<BP@,BD["@H@("`@("`@("`@("`@("`@
M+RH@4F5T<FEE=F4@=&AI<R!P<F5F97)E;F-E+B`J+PH@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<')E9G-;)'!R969=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<V5T5F%L=64H)'!R968L(&)A<V4V-%]D
M96-O9&4H)'9A;"DL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1&5F875L="@D<')E9BP@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1P<F5F
M+"!B87-E-C1?9&5C;V1E*"1V86PI+"!?4%)%1E]32$%2140I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#86QL
M(&AO;VMS+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V-A;&Q(;V]K<R@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=.;R!P<F5F97)E;F-E<R!W97)E(')E=')I979E9"XG+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@
M("`@("`O*B!5<&1A=&4@=&AE('-E<W-I;VX@8V%C:&4N("HO"B`@("`@("`@
M)'1H:7,M/F-A8VAE57!D871E*"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S('!R969E<F5N8V5S('1O('1H
M92!,1$%0('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@I"B`@("!["B`@("`@
M("`@)'5P9&%T960@/2!T<G5E.PH*("`@("`@("`O*B!#:&5C:R!F;W(@86YY
M(")D:7)T>2(@<')E9F5R96YC97,N($EF(&YO(")D:7)T>2(*("`@("`@("`@
M*B!P<F5F97)E;F-E<R!A<F4@9F]U;F0L('1H97)E)W,@;F\@;F5E9"!T;R!U
M<&1A=&4@=&AE($Q$05`*("`@("`@("`@*B!S97)V97(N($5X:70@<W5C8V5S
M<V9U;&QY+B`J+PH@("`@("`@("1D:7)T>5]P<F5F<R`]("1T:&ES+3Y?9&ER
M='E0<F5F<R@I.PH@("`@("`@(&EF("@A8V]U;G0H)&1I<G1Y7W!R969S*2D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M("\J($UA:V4@<W5R92!W92!A<F4@8V]N;F5C=&5D+B`J+PH@("`@("`@("1T
M:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!A(&AA<V@@;V8@
M=&AE('!R969E<F5N8V5S(&%N9"!T:&5I<B!V86QU97,@=&AA="!N965D"B`@
M("`@("`@("H@=&\@8F4@<W1O<F5D(&EN('1H92!,1$%0('-E<G9E<BX@0F5C
M875S92!W92!H879E('1O('5P9&%T90H@("`@("`@("`J(&%L;"!O9B!T:&4@
M=F%L=65S(&]F(&$@;75L=&DM=F%L=64@96YT<GD@=VAO;&5S86QE+"!W90H@
M("`@("`@("`J(&-A;B=T(&IU<W0@<&EC:R!O=70@=&AE(&1I<G1Y('!R969E
M<F5N8V5S.R!W92!M=7-T('5P9&%T90H@("`@("`@("`J(&5V97)Y=&AI;F<N
M("HO"B`@("`@("`@)&YE=U]V86QU97,@/2!A<G)A>2@I.PH@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]P<F5F<RD@87,@)'!R968I('L*
M("`@("`@("`@("`@+R\@1&]N)W0@<W1O<F4@;&]C:V5D('!R969E<F5N8V5S
M+@H@("`@("`@("`@("!I9B`H(21T:&ES+3YI<TQO8VME9"@D<')E9BDI('L*
M("`@("`@("`@("`@("`@("1E;G1R>2`]("1P<F5F("X@)SHG("X@8F%S938T
M7V5N8V]D92@D=&AI<RT^9V5T5F%L=64H)'!R968I*3L*("`@("`@("`@("`@
M("`@("1F:65L9"`]("1T:&ES+3YG97138V]P92@D<')E9BD@+B`G4')E9G,G
M.PH@("`@("`@("`@("`@("`@)&YE=U]V86QU97-;)&9I96QD75M=(#T@)&5N
M=')Y.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!%;G1R
M:65S(&UU<W0@:&%V92!T:&4@;V)J96-T8VQA<W-E<R`G=&]P)R!A;F0@)VAO
M<F1E<&5R<V]N)PH@("`@("`@("`J('1O('-U8V-E<W-F=6QL>2!S=&]R92!,
M1$%0('!R969S+B!#:&5C:R!F;W(@8F]T:"!O9B!T:&5M+`H@("`@("`@("`J
M(&%N9"!A9&0@=&AE;2!I9B!N96-E<W-A<GDN("HO"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]P87)A;7-;)W5I9"==(&%S("1U:61?9FEE;&0I('L*("`@
M("`@("`@("`@)'-E87)C:"`](&QD87!?<V5A<F-H*"1T:&ES+3Y?8V]N;F5C
M=&EO;BP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'5I9%]F:65L9"`N("<])R`N("1T:&ES
M+3Y?=7-E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=O8FIE8W1C;&%S<R<I*3L*("`@("`@("`@("`@:68@*"1S96%R8V@I
M('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!L9&%P7V=E=%]E;G1R:65S
M*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'-E87)C:"D["B`@("`@("`@("`@("`@
M("!I9B`H)')E<W5L="`F)B`D<F5S=6QT6R=C;W5N="==(#X@,"D@>PH@("`@
M("`@("`@("`@("`@("`@("1T;W`@/2!F86QS93L*("`@("`@("`@("`@("`@
M("`@("`D:&]R9&5P97)S;VX@/2!F86QS93L*"B`@("`@("`@("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)')E<W5L=%LP75LG;V)J96-T8VQA<W,G
M75LG8V]U;G0G73L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)')E<W5L=%LP75LG;V)J96-T8VQA<W,G75LD:5T@/3T@)W1O<"<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T;W`@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)')E<W5L=%LP75LG;V)J
M96-T8VQA<W,G75LD:5T@/3T@)VAO<F1E4&5R<V]N)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&AO<F1E<&5R<V]N(#T@=')U93L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`@("`@+RH@061D(&%N>2!M:7-S:6YG(&]B:F5C=&-L
M87-S97,N("HO"B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&]P*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&QD87!?;6]D7V%D9"@D=&AI<RT^7V-O
M;FYE8W1I;VXL("1T:&ES+3Y?9&XL(&%R<F%Y*"=O8FIE8W1C;&%S<R<@/3X@
M)W1O<"<I*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@(&EF("@A)&AO<F1E<&5R<V]N*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QD87!?;6]D7V%D9"@D=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES
M+3Y?9&XL(&%R<F%Y*"=O8FIE8W1C;&%S<R<@/3X@)VAO<F1E4&5R<V]N)RDI
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@4V5N9"!T:&4@:&%S:"!T;R!T:&4@3$1!4"!S
M97)V97(N("HO"B`@("`@("`@:68@*&QD87!?;6]D7W)E<&QA8V4H)'1H:7,M
M/E]C;VYN96-T:6]N+"`D=&AI<RT^7V1N+"`D;F5W7W9A;'5E<RDI('L*("`@
M("`@("`@("`@9F]R96%C:"`H)&1I<G1Y7W!R969S(&%S("1P<F5F*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1&ER='DH)'!R968L(&9A;'-E*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("`@("!S<')I;G1F*"=5;F%B
M;&4@=&\@;6]D:69Y('!R969E<F5N8V5S.B!;)61=("5S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O;FYE8W1I;VXI
M+`H@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1T:&ES+3Y?
M8V]N;F5C=&EO;BDI+`H@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("`@("`@)'5P9&%T960@/2!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\J($%T=&5M<'0@=&\@8V%C:&4@=&AE('!R969E<F5N8V5S
M(&EN('1H92!S97-S:6]N+B`J+PH@("`@("`@("1T:&ES+3YC86-H955P9&%T
M92@I.PH*("`@("`@("!R971U<FX@)'5P9&%T960["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;&5A<G,@86QL('!R969E<F5N8V5S(&9R;VT@=&AE($Q$05`@
M8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE87(H*0H@("`@>PH@
M("`@("`@("\J($UA:V4@<W5R92!W92!A<F4@8V]N;F5C=&5D+B`J+PH@("`@
M("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D871T<G,@/2`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^;&ES=$%P<',H87)R87DH)VEN86-T:79E)RP@
M)V%C=&EV92<L("=H:61D96XG+"`G;F]T;V]L8F%R)RP@)V%D;6EN)RDI.PH@
M("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D:V5Y(#T^("1V86PI('L*("`@
M("`@("`@("`@)&%T=')S6R1K97E=(#T@)'9A;"`N("=0<F5F<R<["B`@("`@
M("`@?0H*("`@("`@("`D<V5A<F-H(#T@;&1A<%]R96%D*"1T:&ES+3Y?8V]N
M;F5C=&EO;BP@)'1H:7,M/E]D;BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=O8FIE8W1#;&%S<SUH;W)D95!E<G-O;B<L("1A='1R<RP@,2D["@H@
M("`@("`@(&EF("@D<V5A<F-H*2!["B`@("`@("`@("`@("1R97-U;'0@/2!L
M9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'-E87)C:"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)T9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<')E9F5R96YC97,@<V5R
M=F5R+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("`D871T<G,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D<F5S=6QT*2!["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1R97-U;'1;,%U;)V-O=6YT
M)UT[("1I*RLI('L*("`@("`@("`@("`@("`@("1A='1R<ULD<F5S=6QT6S!=
M6R1I75T@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A;&1A<%]M;V1?9&5L*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'1H:7,M/E]D
M;BP@)&%T=')S*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G56YA8FQE('1O(&-L
M96%R('!R969E<F5N8V5S.B!;)61=("5S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M/E]C;VYN96-T:6]N*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)'1H:7,M/E]C
M;VYN96-T:6]N*2DL"B`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("`@("`@<W!R
M:6YT9B@G56YA8FQE('1O(&-L96%R('!R969E<F5N8V5S.B!;)61=("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O
M;FYE8W1I;VXI+`H@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R
M*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YC;&5A
M;G5P*'1R=64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4&5R9F]R;2!C;&5A
M;G5P(&]P97)A=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&%L;"`@0VQE86YU<"!A;&P@2&]R9&4@<')E9F5R96YC97,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-L96%N=7`H)&%L;"`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\J($-L;W-E('1H92!,1$%0(&-O;FYE8W1I;VXN("HO"B`@("`@("`@
M)'1H:7,M/E]D:7-C;VYN96-T*"D["@H@("`@("`@('!A<F5N=#HZ8VQE86YU
M<"@D86QL*3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H
M<```````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<P,C$`,3`T,3<S
M-C(W-S$`,#(Q-3`S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!0<F5F97)E;F-E<R!S=&]R86=E(&EM
M<&QE;65N=&%T:6]N(&9O<B!02%`G<R!S97-S:6]N(&EM<&QE;65N=&%T:6]N
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N
M+G!H<"QV(#$N,S(N,3(N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C,R(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*;VX@4&%R
M:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,N-`H@
M*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?<V5S<VEO
M;B!E>'1E;F1S(%!R969S('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@
M82!N97<@<V5S<VEO;B!P<F5F97)E;F-E<R!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!U<V5R('=H;R!O=VYS
M('1H97-E('!R969E<F5N8V5S+B`H56YU<V5D*0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%S<W=O<F0@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@
M)'5S97(N("A5;G5S960I"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8V]P92`@
M("`@5&AE(&-U<G)E;G0@<')E9F5R96YC97,@<V-O<&4N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@("`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C
M=&EO;B!P87)A;65T97)S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`H56YU<V5D*0H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@
M(%-H;W5L9"!C86-H:6YG(&)E('5S960_("A5;G5S960I"B`@("`@*@H@("`@
M("HO"B`@("!F=6YC=&EO;B!0<F5F<U]S97-S:6]N*"1U<V5R+"`D<&%S<W=O
M<F0@/2`G)RP@)'-C;W!E(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)A;7,@/2!N=6QL+"`D8V%C:&EN9R`]('1R=64I"B`@("!["B`@
M("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)W-E<W-I;VXG*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BA?
M*")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RDI.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]S8V]P92`]("1S8V]P93L*"B`@("`@("`@<&%R
M96YT.CI0<F5F<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S
M('1H92!R97%U97-T960@<V5T(&]F('!R969E<F5N8V5S(&9R;VT@=&AE(&-U
M<G)E;G0@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R971R:65V92@I"B`@("!["B`@
M("`@("`@+RH@3&]A9"!D969A=6QT<R!T;R!M86ME('-U<F4@=V4@:&%V92!A
M;&P@<')E9F5R96YC97,N("HO"B`@("`@("`@<&%R96YT.CIR971R:65V92@I
M.PH*("`@("`@("`D9VQO8F%L7W!R969S(#T@87)R87DH*3L*("`@("`@("`D
M;&]C86Q?<')E9G,@/2!A<G)A>2@I.PH*("`@("`@("`O*B!2971R:65V92!G
M;&]B86P@86YD(&QO8V%L('!R969E<F5N8V5S(&9R;VT@=&AE('-E<W-I;VX@
M=F%R:6%B;&4N("HO"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R
M9&5?<')E9G,G75LG:&]R9&4G72DI('L*("`@("`@("`@("`@)&=L;V)A;%]P
M<F5F<R`]("1?4T534TE/3ELG:&]R9&5?<')E9G,G75LG:&]R9&4G73L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&5?<')E
M9G,G75LD=&AI<RT^7W-C;W!E72DI('L*("`@("`@("`@("`@)&QO8V%L7W!R
M969S(#T@)%]315-324].6R=H;W)D95]P<F5F<R==6R1T:&ES+3Y?<V-O<&5=
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T<FEE=F4@86YD('-T;W)E('1H
M92!L;V-A;"!A;F0@9VQO8F%L('!R969E<F5N8V5S+B`J+PH@("`@("`@("1T
M:&ES+3Y?<')E9G,@/2!A<G)A>5]M97)G92@D=&AI<RT^7W!R969S+"`D9VQO
M8F%L7W!R969S+"`D;&]C86Q?<')E9G,I.PH*("`@("`@("`O*B!#86QL(&AO
M;VMS+B`J+PH@("`@("`@("1T:&ES+3Y?8V%L;$AO;VMS*"D["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S('!R
M969E<F5N8V5S(&EN('1H92!C=7)R96YT('-E<W-I;VXN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P<F5F<R`@06X@87)R87D@;&ES=&EN9R!T:&4@
M<')E9F5R96YC97,@=&\@8F4@<W1O<F5D+B!)9@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@;F]T('-P96-I9FEE9"P@<W1O<F4@86QL('1H92!P<F5F
M97)E;F-E<R!L:7-T960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M('1H92`D<')E9G,@:&%S:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@D<')E9G,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("\J($-R96%T92!A;F0@<F5G:7-T97(@
M=&AE('!R969E<F5N8V5S(&%R<F%Y+"!I9B!N96-E<W-A<GDN("HO"B`@("`@
M("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)VAO<F1E7W!R969S)UTI*2!["B`@
M("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?<')E9G,G72`](&%R<F%Y*"D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#;W!Y('1H92!C=7)R96YT('!R969E
M<F5N8V5S(&EN=&\@=&AE('-E<W-I;VX@=F%R:6%B;&4N("HO"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]P<F5F<R!A<R`D;F%M92`]/B`D<')E9BD@>PH@
M("`@("`@("`@("`D<V-O<&4@/2`D=&AI<RT^9V5T4V-O<&4H)&YA;64I.PH@
M("`@("`@("`@("`D7U-%4U-)3TY;)VAO<F1E7W!R969S)UU;)'-C;W!E75LD
M;F%M95T@/2`D<')E9CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4&5R9F]R;2!C;&5A;G5P(&]P97)A
M=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;"`@0VQE
M86YU<"!A;&P@2&]R9&4@<')E9F5R96YC97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-L96%N=7`H)&%L;"`](&9A;'-E*0H@("`@>PH@("`@("`@("\J(%!E
M<F9O<FT@82!(;W)D92UW:61E(&-L96%N=7`_("HO"B`@("`@("`@:68@*"1A
M;&PI('L*("`@("`@("`@("`@=6YS970H)%]315-324].6R=H;W)D95]P<F5F
M<R==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U;G-E="@D7U-%
M4U-)3TY;)VAO<F1E7W!R969S)UU;)'1H:7,M/E]S8V]P95TI.PH@("`@("`@
M("`@("`D7U-%4U-)3TY;)VAO<F1E7W!R969S)UU;)U]F:6QL960G72`](&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT.CIC;&5A;G5P*"1A;&PI
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]0<F5F<R]S<6PN<&AP````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,S(Q,#8`,3`T,3<S-C(W-S$`,#(P-C(Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!`<&%C
M:V%G92!(;W)D95]0<F5F<PH@*B\*"B\J*@H@*B!297%U:7)E9"!D871A8F%S
M92!L87EE<BX*("HO"G)E<75I<F5?;VYC92`G1$(N<&AP)SL*"B\J*@H@*B!0
M<F5F97)E;F-E<R!S=&]R86=E(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!0
M14%2(&1A=&%B87-E"B`J(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U
M:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A
M=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X*("H@
M("`G8VAA<G-E="<@("!4:&4@9&%T86)A<V4G<R!I;G1E<FYA;"!C:&%R<V5T
M+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@
M)W1A8FQE)R`@("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V5S('1A8FQE
M(&EN("=D871A8F%S92<N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@)VAO
M<F1E7W!R969S)SPO<')E/@H@*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A=&%B
M87-E(&EM<&QE;65N=&%T:6]N<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H
M92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T
M;V-O;"<@(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N
M:7@G+"!E=&,N*2X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@
M9&%T86)A<V4N"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I=&@@
M=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W
M;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G
M+@H@*B`@("=O<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S
M('1O('1H92!D871A8F%S92X*("H@("`G<&]R="<@("`@("!4:&4@<&]R="!O
M;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G='1Y
M)R`@("`@("!4:&4@5%19(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A
M=&%B87-E+CPO<')E/@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&9O<B!T
M:&4@4')E9G,@<WES=&5M(&ES(&EN"B`J('-C<FEP=',O<W%L+VAO<F1E7W!R
M969S+G-Q;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<W%L+G!H<"QV(#$N.3$N,3`N,3D@,C`P-B\P,B\R."`P-3HU.3HQ.2!S;'5S
M87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES
M92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?
M<W%L(&5X=&5N9',@4')E9G,@>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B
M87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO
M"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A
M=&EN9R!W:&5T:&5R(&]R(&YO="!W92=R92!C;VYN96-T960@=&\@=&AE(%-1
M3"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!344P@<')E9F5R96YC97,@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("!4:&4@=7-E<B!W
M:&\@;W=N<R!T:&5S92!P<F5F97)E;F-E<RX*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A<W-W;W)D("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("1U
M<V5R+B`H56YU<V5D*0H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@("`@
M(%1H92!C=7)R96YT('!R969E<F5N8V5S('-C;W!E+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H:6YG
M("!3:&]U;&0@8V%C:&EN9R!B92!U<V5D/PH@("`@("HO"B`@("!F=6YC=&EO
M;B!0<F5F<U]S<6PH)'5S97(L("1P87-S=V]R9"`]("<G+"`D<V-O<&4@/2`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH*2P@
M)&-A8VAI;F<@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7W5S97(@
M/2`D=7-E<CL*("`@("`@("`D=&AI<RT^7W-C;W!E(#T@)'-C;W!E.PH@("`@
M("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@("`@("`D=&AI<RT^
M7V-A8VAI;F<@/2`D8V%C:&EN9SL*"B`@("`@("`@<&%R96YT.CI0<F5F<R@I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<G-E="!U
M<V5D(&)Y('1H92!C;VYC<F5T92!P<F5F97)E;F-E(&)A8VME;F0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P<F5F97)E;F-E(&)A8VME
M;F0G<R!C:&%R<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#:&%R<V5T
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A;7-;)V-H87)S
M970G73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@<F5Q
M=65S=&5D('-E="!O9B!P<F5F97)E;F-E<R!F<F]M('1H92!U<V5R)W,@9&%T
M86)A<V4*("`@("`J(&5N=')Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<')E9G,@($%N(&%R<F%Y(&QI<W1I;F<@=&AE('!R969E<F5N8V5S('1O
M(')E=')I979E+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@;F]T
M('-P96-I9FEE9"P@<F5T<FEE=F4@86QL(&]F('1H92!P<F5F97)E;F-E<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@;&ES=&5D(&EN('1H92`D<')E
M9G,@:&%S:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R971R:65V92@D<')E9G,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("\J($%T=&5M<'0@=&\@<'5L;"!T:&4@=F%L=65S
M(&9R;VT@=&AE('-E<W-I;VX@8V%C:&4@9FER<W0N("HO"B`@("`@("`@:68@
M*"1T:&ES+3YC86-H94QO;VMU<"@I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]A9"!D969A=6QT<R!T;R!M
M86ME('-U<F4@=V4@:&%V92!A;&P@<')E9F5R96YC97,N("HO"B`@("`@("`@
M<&%R96YT.CIR971R:65V92@I.PH*("`@("`@("`O*B!-86ME('-U<F4@=V4G
M<F4@8V]N;F5C=&5D+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*
M("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q
M=65R>2`]("=314Q%0U0@<')E9E]S8V]P92P@<')E9E]N86UE+"!P<F5F7W9A
M;'5E($923TT@)SL*("`@("`@("`D<75E<GD@+CT@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT@+B`G("<["B`@("`@("`@)'%U97)Y("X]("=72$5212!P<F5F
M7W5I9"`](#\G.PH@("`@("`@("1Q=65R>2`N/2`G($%.1"`H<')E9E]S8V]P
M92`](#\G.PH@("`@("`@("1Q=65R>2`N/2`B($]2('!R969?<V-O<&4@/2`G
M:&]R9&4G*2!/4D1%4B!"62!P<F5F7W-C;W!E(CL*"B`@("`@("`@)'9A;'5E
M<R`](&%R<F%Y*"1T:&ES+3Y?=7-E<BP@)'1H:7,M/E]S8V]P92D["@H@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!0
M<F5F<U]S<6PZ.G)E=')I979E*"DZ("5S)RP@)'%U97)Y*2P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U
M=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B
M+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("!I9B`H:7-S970H
M)')E<W5L="D@)B8@(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`D<F]W(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-
M3T1%7T%34T]#*3L*("`@("`@("`@("`@:68@*&ES7V$H)')O=RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)')O=RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!3970@=&AE(')E<75E<W1E9"!V86QU97,@:6X@=&AE("1T:&ES+3Y?
M<')E9G,@:&%S:`H@("`@("`@("`@("`@*B!B87-E9"!O;B!T:&4@8V]N=&5N
M=',@;V8@=&AE(%-13"!R97-U;'0N"B`@("`@("`@("`@("`J"B`@("`@("`@
M("`@("`J($YO=&4@=&AA="!0<F5F<SHZ<V5T5F%L=64H*2!C86XG="!B92!U
M<V5D(&AE<F4@8F5C875S90H@("`@("`@("`@("`@*B!O9B!T:&4@8VAE8VL@
M9F]R('1H92`B8VAA;F=E86)L92(@8FET+B!792!W86YT('1O"B`@("`@("`@
M("`@("`J(&]V97)R:61E('1H870@8VAE8VL@=VAE;B!P;W!U;&%T:6YG('1H
M92`D=&AI<RT^7W!R969S"B`@("`@("`@("`@("`J(&AA<V@@9G)O;2!T:&4@
M4U%,('-E<G9E<BX@*B\*("`@("`@("`@("`@=VAI;&4@*"1R;W<@)B8@(6ES
M7V$H)')O=RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YA
M;64@/2!T<FEM*"1R;W=;)W!R969?;F%M92==*3L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!R969S6R1N86UE72DI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E=%9A;'5E*"1N86UE+"`D<F]W6R=P<F5F
M7W9A;'5E)UTL(&9A;'-E+"!F86QS92D["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$1I<G1Y*"1N86UE+"!F86QS92D["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&0H)&YA
M;64L("1R;W=;)W!R969?=F%L=64G72P@)')O=ULG<')E9E]S8V]P92==(#T]
M("=H;W)D92<@/R!?4%)%1E]32$%2140@.B`P*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$
M0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!#86QL(&AO;VMS+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V-A;&Q(
M;V]K<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=.;R!P<F5F97)E;F-E<R!W97)E(')E=')I979E9"XG+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@57!D871E('1H92!S
M97-S:6]N(&-A8VAE+B`J+PH@("`@("`@("1T:&ES+3YC86-H955P9&%T92@I
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-T;W)E<R!P<F5F97)E;F-E<R!T;R!344P@<V5R=F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-T;W)E*"D*("`@('L*("`@("`@("`O*B!#:&5C:R!F;W(@86YY(")D:7)T
M>2(@<')E9F5R96YC97,N($EF(&YO(")D:7)T>2(*("`@("`@("`@*B!P<F5F
M97)E;F-E<R!A<F4@9F]U;F0L('1H97)E)W,@;F\@;F5E9"!T;R!U<&1A=&4@
M=&AE(%-13`H@("`@("`@("`J('-E<G9E<BX@17AI="!S=6-C97-S9G5L;'DN
M("HO"B`@("`@("`@)&1I<G1Y7W!R969S(#T@)'1H:7,M/E]D:7)T>5!R969S
M*"D["B`@("`@("`@:68@*"%C;W5N="@D9&ER='E?<')E9G,I*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K
M92!S=7)E('=E)W)E(&-O;FYE8W1E9"X@*B\*("`@("`@("`D=&AI<RT^7V-O
M;FYE8W0H*3L*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H('1H92`B9&ER='DB
M('!R969E<F5N8V5S+B`@268@82!R;W<@86QR96%D>0H@("`@("`@("`J(&5X
M:7-T<R!F;W(@=&AI<R!P<F5F97)E;F-E+"!A='1E;7!T('1O('5P9&%T92!I
M="X*("`@("`@("`@*B!/=&AE<G=I<V4L(&EN<V5R="!A(&YE=R!R;W<N("HO
M"B`@("`@("`@9F]R96%C:"`H)&1I<G1Y7W!R969S(&%S("1N86UE*2!["B`@
M("`@("`@("`@("\O($1O;B=T('-T;W)E(&QO8VME9"!P<F5F97)E;F-E<RX*
M("`@("`@("`@("`@:68@*"1T:&ES+3YI<TQO8VME9"@D;F%M92DI('L*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D<V-O<&4@/2`D=&AI<RT^9V5T4V-O<&4H)&YA;64I.PH*("`@("`@
M("`@("`@+RH@1&]E<R!A;B!E;G1R>2!A;')E861Y(&5X:7-T(&9O<B!T:&ES
M('!R969E<F5N8V4_("HO"B`@("`@("`@("`@("1Q=65R>2`]("=314Q%0U0@
M,2!&4D]-("<["B`@("`@("`@("`@("1Q=65R>2`N/2`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72`N("<@)SL*("`@("`@("`@("`@)'%U97)Y("X]("=72$52
M12!P<F5F7W5I9"`](#\G.PH@("`@("`@("`@("`D<75E<GD@+CT@)R!!3D0@
M<')E9E]N86UE(#T@/R<["B`@("`@("`@("`@("1Q=65R>2`N/2`G($%.1"`H
M<')E9E]S8V]P92`](#\G.PH@("`@("`@("`@("`D<75E<GD@+CT@(B!/4B!P
M<F5F7W-C;W!E(#T@)VAO<F1E)RDB.PH*("`@("`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*"1T:&ES+3Y?=7-E<BP@)&YA;64L("1S8V]P92D["@H@("`@("`@
M("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`@("`@)&-H
M96-K(#T@)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD["@H@
M("`@("`@("`@("`O*B!2971U<FX@86X@97)R;W(@:68@=&AE('%U97)Y(&9A
M:6QS+B`J+PH@("`@("`@("`@("!I9B`H:7-?82@D8VAE8VLL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=&
M86EL960@<F5T<FEE=FEN9R!P<F5F<R!F;W(@)R`N("1T:&ES+3Y?=7-E<BP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!)<R!T:&5R92!A;B!E>&ES=&EN9R!R;W<@9F]R('1H:7,@<')E
M9F5R96YC93\@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D8VAE8VLI*2![
M"B`@("`@("`@("`@("`@("`O*B!5<&1A=&4@=&AE(&5X:7-T:6YG(')O=RX@
M*B\*("`@("`@("`@("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==("X@)R`G.PH@("`@("`@("`@("`@("`@)'%U
M97)Y("X]("=3150@<')E9E]V86QU92`](#\G.PH@("`@("`@("`@("`@("`@
M)'%U97)Y("X]("<@5TA%4D4@<')E9E]U:60@/2`_)SL*("`@("`@("`@("`@
M("`@("1Q=65R>2`N/2`G($%.1"!P<F5F7VYA;64@/2`_)SL*("`@("`@("`@
M("`@("`@("1Q=65R>2`N/2`G($%.1"!P<F5F7W-C;W!E(#T@/R<["@H@("`@
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"AS=')I;F<I)'1H:7,M/F=E
M=%9A;'5E*"1N86UE+"!F86QS92DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]U<V5R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S8V]P92D["@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@("`@("`@
M("`@+RH@4F5T=7)N(&%N(&5R<F]R(&EF('1H92!U<&1A=&4@9F%I;',N("HO
M"B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1R97-U
M;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!);G-E<G0@
M82!N97<@<F]W+B`J+PH@("`@("`@("`@("`@("`@)'%U97)Y("`]("=)3E-%
M4E0@24Y43R`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+B`G("<["B`@
M("`@("`@("`@("`@("`D<75E<GD@+CT@)RAP<F5F7W5I9"P@<')E9E]S8V]P
M92P@<')E9E]N86UE+"!P<F5F7W9A;'5E*2!604Q515,G.PH@("`@("`@("`@
M("`@("`@)'%U97)Y("X]("<H/RP@/RP@/RP@/RDG.PH*("`@("`@("`@("`@
M("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^7W5S97(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-C;W!E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("AS=')I;F<I)'1H:7,M/F=E=%9A;'5E*"1N86UE+"!F86QS
M92DI.PH*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("`@("`@("`@("\J(%)E
M='5R;B!A;B!E<G)O<B!I9B!T:&4@:6YS97)T(&9A:6QS+B`J+PH@("`@("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@("`@($AO<F1E.CIF871A;"@D<F5S=6QT+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!-87)K('1H:7,@<')E9F5R96YC92!A<R`B
M8VQE86XB(&YO=RX@*B\*("`@("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y*"1N
M86UE+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("`O*B!5<&1A=&4@=&AE
M('-E<W-I;VX@8V%C:&4N("HO"B`@("`@("`@)'1H:7,M/F-A8VAE57!D871E
M*"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4&5R9F]R;2!C;&5A;G5P(&]P97)A=&EO;G,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&%L;"`@0VQE86YU<"!A;&P@2&]R9&4@<')E9F5R
M96YC97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%N=7`H)&%L;"`](&9A
M;'-E*0H@("`@>PH@("`@("`@("\J($-L;W-E('1H92!D871A8F%S92!C;VYN
M96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?9&ES8V]N;F5C="@I.PH*("`@
M("`@("!P87)E;G0Z.F-L96%N=7`H)&%L;"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;&5A<G,@86QL('!R969E<F5N8V5S(&9R;VT@=&AE(&)A8VME;F0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R*"D*("`@('L*("`@("`@("`O
M*B!-86ME('-U<F4@=V4G<F4@8V]N;F5C=&5D+B`J+PH@("`@("`@("1T:&ES
M+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y
M+B`J+PH@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UT["B`@("`@("`@)'%U97)Y("X]("<@5TA%4D4@
M<')E9E]U:60@/2`_)SL*"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES
M+3Y?=7-E<BD["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H
M)U-13"!1=65R>2!B>2!0<F5F<U]S<6PZ.F-L96%R*"DZ("5S)RP@)'%U97)Y
M*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@
M("`O*B!#;&5A;G5P+B`J+PH@("`@("`@('!A<F5N=#HZ8VQE87(H*3L*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYV97)T<R!A('9A;'5E(&9R;VT@=&AE(&1R:79E<B=S(&-H87)S970@=&\@
M=&AE('-P96-I9FEE9"!C:&%R<V5T+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D=F%L=64@("`@($$@=F%L=64@=&\@8V]N=F5R="X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T('1O(&-O;G9E<G0@
M=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-O;G9E<G1E
M9"!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=$9R;VU$<FEV
M97(H)'9A;'5E+"`D8VAA<G-E="D*("`@('L*("`@("`@("!S=&%T:6,@)&-O
M;G9E<G1E9"`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L
M=64I*2!["B`@("`@("`@("`@(')E='5R;B!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"1V86QU92P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72P@)&-H87)S
M970I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V)O;VPH)'9A;'5E*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'9A;'5E.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%I<W-E="@D8V]N=F5R=&5D6R1C:&%R<V5T75LD=F%L=65=*2D@
M>PH@("`@("`@("`@("`D8V]N=F5R=&5D6R1C:&%R<V5T75LD=F%L=65=(#T@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1T:&ES+3Y?<&%R86US
M6R=C:&%R<V5T)UTL("1C:&%R<V5T*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8V]N=F5R=&5D6R1C:&%R<V5T75LD=F%L=65=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]N=F5R=',@82!V86QU92!F<F]M('1H92!S<&5C:69I
M960@8VAA<G-E="!T;R!T:&4@9')I=F5R)W,@8VAA<G-E="X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)'9A;'5E("!!('9A;'5E('1O(&-O;G9E<G0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T
M;R!C;VYV97)T(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5&AE(&-O;G9E<G1E9"!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N
M=F5R=%1O1')I=F5R*"1V86QU92P@)&-H87)S970I"B`@("!["B`@("`@("`@
M<F5T=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"`D8VAA<G-E
M="P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@<&5R<VES=&5N="!C;VYN96-T
M:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@
M<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@("`O
M*B!#:&5C:R!T;R!S964@:68@=V4@87)E(&%L<F5A9'D@8V]N;F5C=&5D+B`J
M+PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@($AO<F1E.CIA<W-E
M<G1$<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=P<F5F<R<L"B`@("`@
M("`@("`@(&%R<F%Y*"=P:'!T>7!E)RP@)V-H87)S970G*2P*("`@("`@("`@
M("`@)W!R969E<F5N8V5S(%-13"<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG9&%T86)A<V4G72`]("<G.PH@("`@("`@('T*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=P
M87-S=V]R9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S
M<W=O<F0G72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG:&]S='-P96,G72`]("<G.PH@("`@("`@('T*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T86)L92==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`]("=H;W)D95]P<F5F
M<R<["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYN96-T('1O('1H92!344P@
M<V5R=F5R('5S:6YG('1H92!S=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@
M("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H)'1H:7,M/E]P87)A;7,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R
M<VES=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT
M)UTI*2D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)'1H:7,M/E]D8BP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E
M="!$0B!P;W)T86)I;&ET>2!O<'1I;VYS+@H@("`@("`@('-W:71C:"`H)'1H
M:7,M/E]D8BT^<&AP='EP92D@>PH@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@
M("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L
M($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T52
M4D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M/E]D8BT^
M<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T52
M0T%312!\($1"7U!/4E1!0DE,25197T524D]24RD["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C="!F<F]M
M('1H92!344P@<V5R=F5R(&%N9"!C;&5A;B!U<"!T:&4@8V]N;F5C=&EO;BX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)R;W=S97(O````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W,0`P,3<V-38`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M0G)O=W-E<B]I;6]D92YP:'``````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#,Q,#<R`#$P-#$W,S8R-S<Q`#`R,30V-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($)R
M;W=S97)?:6UO9&4Z.B!C;&%S<R!E>'1E;F1S('1H92!"<F]W<V5R($%022!B
M>2!P<F]V:61I;F<*("H@<W!E8VEF:6,@:6YF;W)M871I;VX@86)O=70@26UO
M9&4@:&%N9'-E=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<B]I;6]D92YP:'`L=B`Q+C<N,3(N-2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C`Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($UI:V$@
M5'5U<&]L80H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]"<F]W<V5R"B`J+PIC
M;&%S<R!"<F]W<V5R7VEM;V1E('L*"B`@("`O*BH*("`@("`J($1E=FEC92!D
M871A+B!&<F]M(&AT='`Z+R]W=W<N;G1T9&]C;VUO+F-O+FIP+VDO=&%G+W,U
M+FAT;6PC-5\Q"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]D871A(#T@87)R87DH"B`@("`@("`@)T0R,#EI)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG
M:'0G(#T^(#DP+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X
M=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@
M("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@
M("`@("DL"B`@("`@("`@)T8R,#EI)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DQ+`H@("`@
M("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-RP*
M("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G
M969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@
M)TXR,#EI)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^
M(#$P."P@)VEM86=E:&5I9VAT)R`]/B`X,BP*("`@("`@("`@("`@)W1E>'1W
M:61T:"<@/3X@.2P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@("`@("=C
M;VQO<B<@/3X@)V=R97DG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]
M/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=0,C`Y:2<@/3X@
M87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E
M:&5I9VAT)R`]/B`X-RP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@
M)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V=R
M97DG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF
M)RD*("`@("`@("`I+`H@("`@("`@("=0,C`Y:7,G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@
M.#<L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT
M)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@
M("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*
M("`@("`@("`G4C(P.6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W
M:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@-S(L"B`@("`@("`@("`@
M("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R
M;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G15(R
M,#EI)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$R
M,"P@)VEM86=E:&5I9VAT)R`]/B`W,BP*("`@("`@("`@("`@)W1E>'1W:61T
M:"<@/3X@,3`L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L
M;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@
M87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G2T\R,#EI)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H
M96EG:'0G(#T^(#DV+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G
M=&5X=&AE:6=H="<@/3X@."P*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L
M"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@
M("`@("`@("DL"B`@("`@("`@)T0R,3!I)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DQ+`H@
M("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@
M-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)T8R,3!I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G
M(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#$Q,RP*("`@("`@("`@("`@)W1E
M>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#@L"B`@("`@("`@("`@
M("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]
M/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=.,C$P:2<@/3X@
M87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,3@L("=I;6%G
M96AE:6=H="<@/3X@,3$S+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q
M,"P@)W1E>'1H96EG:'0G(#T^(#@L"B`@("`@("`@("`@("=C;VQO<B<@/3X@
M,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF
M)RD*("`@("`@("`I+`H@("`@("`@("=0,C$P:2<@/3X@87)R87DH"B`@("`@
M("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Y
M,2P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G
M(#T^(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@
M("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@
M("`@("`@("=+3S(Q,&DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W
M:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@.38L"B`@("`@("`@("`@
M("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`X+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T
M<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4T\R,3!I
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$R,"P@
M)VEM86=E:&5I9VAT)R`]/B`Q,3,L"B`@("`@("`@("`@("=T97AT=VED=&@G
M(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L;W(G
M(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH
M)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G1#4P,6DG(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@
M/3X@-S(L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I
M9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=B;&%C:R<L"B`@
M("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@
M("`@("DL"B`@("`@("`@)T8U,#%I)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)VEM86=E=VED=&@G(#T^(#$Q,BP@)VEM86=E:&5I9VAT)R`]/B`X-"P*("`@
M("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L
M"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V)L86-K)RP*("`@("`@("`@("`@
M)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@
M("`@("`G3C4P,6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T
M:"<@/3X@,3$X+"`G:6UA9V5H96EG:'0G(#T^(#$R."P*("`@("`@("`@("`@
M)W1E>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT)R`]/C$P+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^("=B;&%C:R<L"B`@("`@("`@("`@("=I;6%G969O
M<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)U`U
M,#%I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV
M+"`G:6UA9V5H96EG:'0G(#T^(#$R,"P*("`@("`@("`@("`@)W1E>'1W:61T
M:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#@L"B`@("`@("`@("`@("=C;VQO
M<B<@/3X@)V)L86-K)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@
M87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G1#4P,FDG(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE
M:6=H="<@/3X@.3`L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T
M97AT:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*
M("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@
M("`@("`@*2P*("`@("`@("`G1C4P,FDG(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@.3$L"B`@
M("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W
M+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM
M86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@
M("`G1C4P,FET)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G
M(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DQ+`H@("`@("`@("`@("`G=&5X
M='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@
M)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^
M(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)TXU,#)I)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM86=E
M:&5I9VAT)R`]/B`Q,C@L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$P
M+"`G=&5X=&AE:6=H="<@/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@
M)V=R97DG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G
M9VEF)RD*("`@("`@("`I+`H@("`@("`@("=.-3`R:70G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3$X+"`G:6UA9V5H96EG:'0G
M(#T^(#$R."P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L("=T97AT
M:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@
M("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@
M("`@("DL"B`@("`@("`@)U`U,#)I)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'1H)R`]/B`Q,3<L"B`@
M("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`X
M+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@
M)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@
M("`@("`G3DTU,#)I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED
M=&@G(#T^(#$Q,2P@)VEM86=E:&5I9VAT)R`]/B`W-RP*("`@("`@("`@("`@
M)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@
M("`@("=C;VQO<B<@/3X@)V)L86-K)RP*("`@("`@("`@("`@)VEM86=E9F]R
M;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4T\U
M,#)I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$R
M,"P@)VEM86=E:&5I9VAT)R`]/B`Q,C`L"B`@("`@("`@("`@("=T97AT=VED
M=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`X+`H@("`@("`@("`@("`G8V]L
M;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@
M87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4T\U,#)I=VTG(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G:6UA
M9V5H96EG:'0G(#T^(#$Q,RP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@
M."P@)W1E>'1H96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C;VQO<B<@/3X@
M,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF
M)RD*("`@("`@("`I+`H@("`@("`@("=&-3`S:2<@/3X@87)R87DH"B`@("`@
M("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H="<@/3X@
M,3,P+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG
M:'0G(#T^(#$P+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@
M("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@
M*2P*("`@("`@("`G1C4P,VE3)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM
M86=E=VED=&@G(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,S`L"B`@("`@
M("`@("`@("=T97AT=VED=&@G(#T^(#$R+"`G=&5X=&AE:6=H="<@/3X@,3(L
M"B`@("`@("`@("`@("=C;VQO<B<@/3X@-#`Y-BP*("`@("`@("`@("`@)VEM
M86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@
M("`G4#4P,VDG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@
M/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^(#$S,"P*("`@("`@("`@("`@)W1E
M>'1W:61T:"<@/3X@,3(L("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@
M("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G
M(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)U`U,#-I4R<@
M/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,C`L("=I
M;6%G96AE:6=H="<@/3X@,3,P+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]
M/B`Q,BP@)W1E>'1H96EG:'0G(#T^(#$P+`H@("`@("`@("`@("`G8V]L;W(G
M(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH
M)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4T\U,#-I)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$R,"P@)VEM86=E:&5I9VAT
M)R`]/B`Q,3,L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@N-2P@)W1E
M>'1H96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C;VQO<B<@/3X@-C4U,S8L
M"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@
M("`@("`@("DL"B`@("`@("`@)T0U,#-I)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)VEM86=E=VED=&@G(#T^(#$S,BP@)VEM86=E:&5I9VAT)R`]/B`Q,C8L
M"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]
M/B`W+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#0P.38L"B`@("`@("`@("`@
M("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@
M("`@("`@)TXU,#-I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED
M=&@G(#T^(#$Q."P@)VEM86=E:&5I9VAT)R`]/B`Q,C@L"B`@("`@("`@("`@
M("=T97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@/3X@,3`L"B`@("`@
M("`@("`@("=C;VQO<B<@/3X@-#`Y-BP*("`@("`@("`@("`@)VEM86=E9F]R
M;6%T<R<@/3X@87)R87DH)V=I9B<L("=J<&<G*0H@("`@("`@("DL"B`@("`@
M("`@)TXU,#-I4R<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H
M)R`]/B`Q,3@L("=I;6%G96AE:6=H="<@/3X@,3(X+`H@("`@("`@("`@("`G
M=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG:'0G(#T^(#$P+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^(#0P.38L"B`@("`@("`@("`@("=I;6%G969O<FUA
M=',G(#T^(&%R<F%Y*"=G:68G+"`G:G!G)RD*("`@("`@("`I+`H@("`@("`@
M("=.-CDQ:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]
M/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`W,BP*("`@("`@("`@("`@)W1E>'1W
M:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@("`@("=C
M;VQO<B<@/3X@)V=R97DG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]
M/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=32#@R,6DG(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G
M96AE:6=H="<@/3X@-S@L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L
M("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U
M-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I
M"B`@("`@("`@*2P*("`@("`@("`G3C@R,6DG(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G:6UA9V5W:61T:"<@/3X@,3$X+"`G:6UA9V5H96EG:'0G(#T^(#$R
M."P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT
M)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@("`@
M("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@
M("DL"B`@("`@("`@)U`X,C%I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM
M86=E=VED=&@G(#T^(#$Q."P@)VEM86=E:&5I9VAT)R`]/B`Q,C@L"B`@("`@
M("`@("`@("=T97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@/3X@,3`L
M"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V=R97DG+`H@("`@("`@("`@("`G
M:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@
M("`@("=S869E)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G
M(#T^(#DT+"`G:6UA9V5H96EG:'0G(#T^(#<R+`H@("`@("`@("`@("`G=&5X
M='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@("`@
M)V-O;&]R)R`]/B`G8FQA8VLG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S
M)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I"B`@("`I.PH*("`@('9A<B`D
M7VUA;G5F86-T=7)E<FQI<W0@/2!A<G)A>2@*("`@("`@("`G1"<@/3X@)TUI
M='-U8FES:&DG+`H@("`@("`@("=0)R`]/B`G4&%N87-O;FEC("A-871S=7-H
M:71A*2<L"B`@("`@("`@)TY-)R`]/B`G3F]K:6$G+`H@("`@("`@("=33R<@
M/3X@)U-O;GDG+`H@("`@("`@("=&)R`]/B`G1G5J:71S=2<L"B`@("`@("`@
M)TXG(#T^("=.96,G+`H@("`@("`@("=32"<@/3X@)U-H87)P)RP*("`@("`@
M("`G15(G(#T^("=%<FEC<W-O;B<L"B`@("`@("`@)U(G(#T^("=*87!A;B!2
M861I;R<L"B`@("`@("`@)TM/)R`]/B`G2V]K=7-A:2`H2&ET86-H:2DG"B`@
M("`I.PH*("`@('9A<B`D7V5X=')A(#T@87)R87DH"B`@("`@("`@)W0G(#T^
M("=4<F%N<W!O<G0@;&%Y97(G+`H@("`@("`@("=E)R`]/B`G16YG;&ES:"!L
M86YG=6%G92<L"B`@("`@("`@)W,G(#T^("=396-O;F0@=F5R<VEO;B<*("`@
M("D["@H@("`@=F%R("1?=7-E<E]A9V5N=#L*("`@('9A<B`D7VUO9&5L.PH@
M("`@=F%R("1?;6%N=69A8W1U<F5R.PH@("`@=F%R("1?:'1T<'9E<G-I;VX[
M"B`@("!V87(@)%]C86-H92`](#4["@H@("`@+RHJ"B`@("`@*B!$;V5S(&YO
M="!H86YD;&4@8F]G=7,@=7-E<E]A9V5N=',@;W(@;6]S="!O9B!T:&4@;W1H
M97(@97)R;W(*("`@("`J('-I='5A=&EO;B!P<F]P97)L>2!Y970N"B`@("`@
M*@H@("`@("H@17AA;7!L92!U<V%G93H*("`@("`J("`@)'5A(#T@)FYE=R!"
M<F]W<V5R7VEM;V1E*"1?4T525D5R6R=(5%107U5315)?04=%3E0G72D["B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@(%1H92!U<V5R(&%G
M96YT('1O(&UA=&-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!"<F]W<V5R7VEM
M;V1E*"1I;G!U="D*("`@('L*("`@("`@("`D7V5R<F]R(#T@,#L*("`@("`@
M("`D=&5M<"`](&5X<&QO9&4H)R\G+"`D:6YP=70I.PH*("`@("`@("`D=&AI
M<RT^7W5S97)?86=E;G0@/2`D:6YP=70["B`@("`@("`@)'1H:7,M/E]H='1P
M=F5R<VEO;B`]("1T96UP6S%=.PH@("`@("`@("1T:&ES+3Y?;6]D96P@/2`D
M=&5M<%LR73L*("`@("`@("!I9B`H)'1E;7!;,UTI('L*("`@("`@("`@("`@
M)'1H:7,M/E]C86-H92`]('-U8G-T<B@D=&5M<%LS72P@,2D["B`@("`@("`@
M?0H*("`@("`@("!P<F5G7VUA=&-H*"<O*%Y;82UZ02U:72LI*%LP+3E=*VDI
M*"XJ*5PO/R@N*BDO)RP@)'1H:7,M/E]M;V1E;"P@)&UA=&-H97,I.PH*("`@
M("`@("`O+R!`5$]$3SH@1FEX('-I='5A=&EO;B!O9B!U;FMN;W=N(&UA;G5F
M86-T=7)E<BX@26UP;&5M96YT"B`@("`@("`@+R\@97AT<F%I;F9O('!R;W!E
M<FQY+@H@("`@("`@("1T:&ES+3Y?;6%N=69A8W1U<F5R(#T@)'1H:7,M/E]M
M86YU9F%C='5R97)L:7-T6R1M871C:&5S6S%=73L*("`@("`@("`D=&AI<RT^
M7V5X=')A(#T@)&UA=&-H97-;,UT["@H@("`@("`@(&EF("@A*"1T:&ES+3Y?
M9&%T85LD=&AI<RT^7VUO9&5L72DI('L*("`@("`@("`@("`@)%]E<G)O<B`]
M(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@57-E<B!!9V5N="<I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X86UP;&4@=7-A9V4Z"B`@
M("`@*B`@)&EM86=E9&EM("`@(#T@)'5A+3YG971);6%G941I;65N<VEO;G,H
M*3L*("`@("`J("`D:6UA9V5W:61T:"`@/2`D:6UA9V5D:6U;,%T["B`@("`@
M*B`@)&EM86=E:&5I9VAT(#T@)&EM86=E9&EM6S%=.PH@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@(%1H92!M87AI;75M(&EM86=E=VED=&@@86YD(&EM
M86=E:&5I9VAT('1H870*("`@("`J("`@("`@("`@("`@("`@(&9I="!O;B!T
M:&4@:&%N9'-E="!S8W)E96X@=VET:&]U="!S8W)O;&QI;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$EM86=E1&EM96YS:6]N<R@I"B`@("!["B`@("`@
M("`@)&1A=&$@/2`D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%T["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"1D871A6R=I;6%G97=I9'1H)UTL("1D871A6R=I
M;6%G96AE:6=H="==*3L*("`@('T*"B`@("`O*BH*("`@("`J($5X86UP;&4@
M=7-A9V4Z"B`@("`@*B`@)'1E>'1D:6T@("`@/2`D=6$M/F=E=%1E>'1$:6UE
M;G-I;VYS*"D["B`@("`@*B`@)'1E>'1W:61T:"`@/2`D=&5X=&1I;5LP73L*
M("`@("`J("`D=&5X=&AE:6=H="`]("1T97AT9&EM6S%=.PH@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!-87AI;75M('1E>'1W:61T:"!A;F0@
M=&5X=&AE:6=H="!T:&%T"B`@("`@*B`@("`@("`@("`@("`@("!F:70@;VX@
M=&AE(&AA;F1S970@<V-R965N('=I=&AO=70@<V-R;VQL:6YG+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971497AT1&EM96YS:6]N<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO9&5L75LG
M=&5X='=I9'1H)UTL"B`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&%T
M85LD=&AI<RT^7VUO9&5L75LG=&5X=&AE:6=H="==*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&%M;W5N="!O9B!H86YD
M<V5T(&-A8VAE(&EN(&MI;&]B>71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T0V%C:&4H*0H@("`@>PH@("`@("`@(')E='5R;B`H:6YT*21T:&ES+3Y?
M8V%C:&4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T36%N=69A8W1U<F5R*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M86YU9F%C='5R97(["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T17AT<F$H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V5X=')A.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$EM
M86=E1F]R;6%T<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T
M85LD=&AI<RT^7VUO9&5L75LG:6UA9V5F;W)M871S)UT["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%=H:6-H(&-O;&]R(&UO9&5L
M('1H92!H86YD<V5T('-U<'!O<G1S+@H@("`@("H@("!686QU97,@:&%V92!T
M:&4@9F]L;&]W:6YG(&UE86YI;F<Z"B`@("`@*B`@("`@,"`M/B!B;&%C:R!A
M;F0@=VAI=&4*("`@("`J("`@("`Q("T^(#0@=&]N92!G<F5Y<V-A;&4*("`@
M("`J("`@("`R("T^(#(U-B!C;VQO<@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971#;VQO<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T85LD
M=&AI<RT^7VUO9&5L75LG8V]L;W(G73L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971(5%105F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:'1T<'9E<G-I;VX["B`@("!]"@H@("`@9G5N8W1I;VX@:7-#;VQO<B@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO9&5L
M75LG8V]L;W(G72`]/2`R-38["B`@("!]"@H@("`@9G5N8W1I;VX@:7-'<F5Y
M4V-A;&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;)'1H
M:7,M/E]M;V1E;%U;)V-O;&]R)UT@/3T@)V=R97DG.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&ES0FQA8VM!;F17:&ET92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO9&5L75LG8V]L;W(G72`]/2`G8FQA
M8VLG.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O1W)A<&@O````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<Q`#`Q-S(W-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]#:&%R="\`````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-S$`,#(P,S,U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R
M87!H+T-H87)T+W!I92YP:'``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,#<Q-P`Q,#0Q-S,V,C<W,0`P,C$V,C8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%!I92!G<F%P
M:"!I;7!L96UE;G1A=&EO;B!F;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T=R87!H+T=R87!H+T-H87)T+W!I
M92YP:'`L=B`Q+C$P+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L87-S
M($AO<F1E7T=R87!H7T-H87)T7W!I92!["@H@("`@=F%R("1G<F%P:#L*"B`@
M("!V87(@)%]D871A<V5T.PH@("`@=F%R("1?<&%D9&EN9R`](#(P.PH@("`@
M=F%R("1?;W5T;&EN92`]('1R=64["B`@("!V87(@)%]C;VQO<G,@/2!A<G)A
M>2@G=&%N)RP@)W!A;&5G;VQD96YR;V0G+"`G;VQI=F5D<F%B)RP@)V)L=64G
M+"`G<F5D)RP@)V=R965N)RP@)WEE;&QO=R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G;W)A;F=E)RP@)V=R87DG+"`G<'5R<&QE)RD["B`@("`O*BH*
M("`@("`@(C(U-2PQ-3,L,"(L"B`@("`@("(P+#(P-"PQ-3,B+`H@("`@("`B
M,C`T+#(U-2PQ,#(B+`H@("`@("`B,C4U+#$P,BPQ,#(B+`H@("`@("`B,3`R
M+#(P-"PR-34B+`H@("`@("`B,C`T+#$U,RPR-34B+`H@("`@("`B,C4U+#`L
M,"(L"B`@("`@("(U,2PP+#(U-2(L"B`@("`@("(R-34L-3$L,34S(BP*("`@
M("`@(C(P-"PP+#(U-2(L"B`@("`@("(R-34L,C4U+#4Q(BP*("`@("`@(C4Q
M+#(U-2PU,2(L"B`@("`@("(R-34L,3`R+#`B*3L*("`@("HO"@H@("`@9G5N
M8W1I;VX@2&]R9&5?1W)A<&A?0VAA<G1?<&EE*"8D9W)A<&@L("1P87)A;7,I
M"B`@("!["B`@("`@("`@)'1H:7,M/F=R87!H(#T@)B1G<F%P:#L*"B`@("`@
M("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86T@/3X@)'9A;'5E*2!["B`@
M("`@("`@("`@("1K97D@/2`G7R<@+B`D<&%R86T["B`@("`@("`@("`@("1T
M:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!D<F%W*"D*("`@('L*("`@("`@("`D9&%T82`]("1T:&ES+3YG<F%P
M:"T^7V1A=&%;)WDG75LD=&AI<RT^7V1A=&%S971=.PH*("`@("`@("`O+R!)
M;FET:6%L:7IE('-O;64@=F%R:6%B;&5S+@H@("`@("`@("1D:6%M971E<B`]
M(&UI;B@D=&AI<RT^9W)A<&@M/E]G<F%P:%=I9'1H+"`D=&AI<RT^9W)A<&@M
M/E]G<F%P:$AE:6=H="D@+2`H)'1H:7,M/E]P861D:6YG("H@,BD["B`@("`@
M("`@)')A9&EU<R`]("1D:6%M971E<B`O(#(["B`@("`@("`@)&-O=6YT(#T@
M8V]U;G0H)&1A=&$I.PH@("`@("`@("1X8V5N=&5R(#T@)'1H:7,M/F=R87!H
M+3Y?9W)A<&A,969T("L@)'1H:7,M/E]P861D:6YG("L@*"1T:&ES+3YG<F%P
M:"T^7V=R87!H5VED=&@@+R`R*3L*("`@("`@("`D>6-E;G1E<B`]("1T:&ES
M+3YG<F%P:"T^7V=R87!H5&]P("L@)'1H:7,M/E]P861D:6YG("L@*"1T:&ES
M+3YG<F%P:"T^7V=R87!H2&5I9VAT("\@,BD["@H@("`@("`@("\O($-A;&-U
M;&%T92!T:&4@<W5M(&]F(&%L;"!S;&EC97,N"B`@("`@("`@)'-U;2`](#`[
M"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)'@I('L*("`@("`@("`@("`@
M)'-U;2`K/2`D>#L*("`@("`@("!]"@H@("`@("`@("\O($-O;G9E<G0@96%C
M:"!S;&EC92!I;G1O('1H92!C;W)R97-P;VYD:6YG('!E<F-E;G1A9V4@;V8@
M80H@("`@("`@("\O(#,V,"UD96=R964@8VER8VQE+@H@("`@("`@("1D96=#
M;W5N="`](#`["B`@("`@("`@)'-L:6-E<R`](&%R<F%Y*"D["B`@("`@("`@
M)&1E9W)E97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1D871A(&%S
M("1I(#T^("1Y*2!["B`@("`@("`@("`@(&EF("@H*"1Y("\@)'-U;2D@*B`S
M-C`I(#X@,"D@>PH@("`@("`@("`@("`@("`@)&1E9W)E97-;)&1E9T-O=6YT
M72`]("@D>2`O("1S=6TI("H@,S8P.PH@("`@("`@("`@("`@("`@)'-L:6-E
M<ULD9&5G0V]U;G1=(#T@)'D["B`@("`@("`@("`@("`@("`D;F%M97-;)&1E
M9T-O=6YT72`](&ES<V5T*"1T:&ES+3YG<F%P:"T^7V1A=&%;)W@G75LD:5TI
M(#\@)'1H:7,M/F=R87!H+3Y?9&%T85LG>"==6R1I72`Z("<G.PH@("`@("`@
M("`@("`@("`@)&1E9T-O=6YT*RL["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O($1R87<@=&AE(&)A<V5L:6YE+@H@("`@("`@(&EF("@D
M8V]U;G0@/B`Q*2!["B`@("`@("`@("`@("1L87-T7V%N9VQE(#T@,#L*("`@
M("`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&1E9W)E97,I.PH@("`@("`@("`@
M("!F;W(@*"1Z(#T@,#L@)'H@/"`D8V]U;G0[("1Z*RLI('L*("`@("`@("`@
M("`@("`@("\O($-A;&-U;&%T92!A;F0@9')A=R!A<F-S(&-O<G)E<W!O;F1I
M;F<@=&\@96%C:`H@("`@("`@("`@("`@("`@+R\@<VQI8V4N"B`@("`@("`@
M("`@("`@("`D8WH@/2`D>B`E(&-O=6YT*"1T:&ES+3Y?8V]L;W)S*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^:6UG+3YA<F,H)'AC96YT97(L
M("1Y8V5N=&5R+"`D<F%D:75S+"`D;&%S=%]A;F=L92P@*"1L87-T7V%N9VQE
M("L@)&1E9W)E97-;)'I=*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]O=71L:6YE(#\@)V)L86-K)R`Z("1T:&ES
M+3Y?8V]L;W)S6R1C>ETL("1T:&ES+3Y?8V]L;W)S6R1C>ETI.PH@("`@("`@
M("`@("`@("`@)&QA<W1?86YG;&4@/2`D;&%S=%]A;F=L92`K("1D96=R965S
M6R1Z73L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YG<F%P:"T^:6UG+3YC:7)C;&4H)'AC96YT97(L("1Y8V5N
M=&5R+"`D<F%D:75S+"`G8FQA8VLG+"`D=&AI<RT^7V-O;&]R<ULP72D["B`@
M("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@=&AE(&-O;&]R(&ME>2!A;F0@
M<VQI8V4@;&%B96QS+@H@("`@("`@("1Y0F%S92`]("1T:&ES+3YG<F%P:"T^
M7V=R87!H5&]P.PH@("`@("`@("1X0F%S92`](#4["B`@("`@("`@)&UA>"`]
M('-T<FQE;B@H<W1R:6YG*6UA>"@D9&%T82DI.PH@("`@("`@(&9O<B`H)'H@
M/2`P.R`D>B`\("1D96=#;W5N=#L@)'HK*RD@>PH@("`@("`@("`@("`D8WH@
M/2`D>B`E(&-O=6YT*"1T:&ES+3Y?8V]L;W)S*3L*("`@("`@("`@("`@)'!E
M<F-E;G0@/2`H)&1E9W)E97-;)'I=("\@,S8P*2`J(#$P,#L*("`@("`@("`@
M("`@)'!E<F-E;G0@/2!R;W5N9"@D<&5R8V5N="P@,BD["B`@("`@("`@("`@
M("1Y0F%S92`K/2`Q-3L*"B`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^:6UG
M+3YR96-T86YG;&4H)'A"87-E+"`D>4)A<V4L(#$R+"`Q,BP@)V)L86-K)RP@
M)'1H:7,M/E]C;VQO<G-;)&-Z72D["B`@("`@("`@("`@(&EF("@D<VQI8V5S
M6R1Z72`^/2`Q,#`P("8F("1S;&EC97-;)'I=(#P@,3`P,#`P,"D@>PH@("`@
M("`@("`@("`@("`@)'-L:6-E<ULD>ET@/2`D<VQI8V5S6R1Z72`O(#$P,#`[
M"B`@("`@("`@("`@("`@("`D<VQI8V5S6R1Z72`]("1S;&EC97-;)'I=("X@
M)VLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97!E870@/2`D;6%X
M("T@<W1R;&5N*"1S;&EC97-;)'I=*3L*("`@("`@("`@("`@:68@*"1R97!E
M870@/"`P*2!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D<VQI8V5S6R1Z72`]('-T<E]R97!E870H
M)R`G+"`D<F5P96%T*2`N("1S;&EC97-;)'I=.PH*("`@("`@("`@("`@)'1H
M:7,M/F=R87!H+3YI;6<M/G1E>'0H)'-L:6-E<ULD>ETL("1X0F%S92`K(#(P
M+"`H)'E"87-E("L@,2DI.PH*("`@("`@("`@("`@)&QA8F5L(#T@)&YA;65S
M6R1Z72`N("<@*"<@+B`D<&5R8V5N="`N("<E*2<["B`@("`@("`@("`@(&EF
M("AS=')L96XH)&QA8F5L*2`^(#(P*2!["B`@("`@("`@("`@("`@("`D;&%B
M96QS(#T@97AP;&]D92@B7&XB+"!W;W)D=W)A<"@D;&%B96PL(#(P*2D["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D;&%B96QS(&%S("1I(#T^("1L86)E
M;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D:2`^(#`I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'E"87-E("L](#$U.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9W)A<&@M/FEM
M9RT^=&5X="@D;&%B96PL("1X0F%S92`K(#,U("L@*"1M87@@*B`T*2P@*"1Y
M0F%S92`K(#$I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^:6UG+3YT97AT
M*"1L86)E;"P@)'A"87-E("L@,S4@*R`H)&UA>"`J(#0I+"`H)'E"87-E("L@
M,2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O0VAA<G0O
M<&EE,V0N<&AP````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S8W`#$P
M-#$W,S8R-S<Q`#`R,C`U-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@,T0@4&EE(&=R87!H(&EM<&QE
M;65N=&%T:6]N(&9O<B!T:&4@2&]R9&5?1W)A<&@@<&%C:V%G92X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO1W)A<&@O1W)A<&@O0VAA<G0O<&EE,V0N<&AP
M+'8@,2XQ+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L87-S($AO<F1E
M7T=R87!H7T-H87)T7W!I93-D('L*"B`@("!V87(@)&=R87!H.PH*("`@('9A
M<B`D7V1A=&%S970["B`@("!V87(@)%]P861D:6YG(#T@,C`["B`@("!V87(@
M)%]O=71L:6YE(#T@=')U93L*("`@('9A<B`D7V-O;&]R<R`](&%R<F%Y*"=T
M86XG+"`G<&%L96=O;&1E;G)O9"<L("=O;&EV961R86(G+"`G8FQU92<L("=R
M960G+"`G9W)E96XG+"`G>65L;&]W)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("=O<F%N9V4G+"`G9W)A>2<L("=P=7)P;&4G*3L*("`@("\J*@H@("`@
M("`B,C4U+#$U,RPP(BP*("`@("`@(C`L,C`T+#$U,R(L"B`@("`@("(R,#0L
M,C4U+#$P,B(L"B`@("`@("(R-34L,3`R+#$P,B(L"B`@("`@("(Q,#(L,C`T
M+#(U-2(L"B`@("`@("(R,#0L,34S+#(U-2(L"B`@("`@("(R-34L,"PP(BP*
M("`@("`@(C4Q+#`L,C4U(BP*("`@("`@(C(U-2PU,2PQ-3,B+`H@("`@("`B
M,C`T+#`L,C4U(BP*("`@("`@(C(U-2PR-34L-3$B+`H@("`@("`B-3$L,C4U
M+#4Q(BP*("`@("`@(C(U-2PQ,#(L,"(I.PH@("`@*B\*"B`@("!F=6YC=&EO
M;B!(;W)D95]'<F%P:%]#:&%R=%]P:64S9"@F)&=R87!H+"`D<&%R86US*0H@
M("`@>PH@("`@("`@("1T:&ES+3YG<F%P:"`]("8D9W)A<&@["@H@("`@("`@
M(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@("`D=&AI
M<RT^)&ME>2`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@9')A=R@I"B`@("!["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]'<F%P:"]0;&]T+P``````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S$`,#(P,C$R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+U!L;W0O8F%R+G!H
M<```````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`R,P`Q,#0Q-S,V
M,C<W,0`P,C$T-C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($)A<B!G<F%P:"!I;7!L96UE;G1A=&EO
M;B!F;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T=R87!H+T=R87!H+U!L;W0O8F%R+G!H<"QV(#$N-2XQ,BXT
M(#(P,#8O,#$O,#$@,C$Z,C@Z,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T=R87!H"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]0;&]T
M7V)A<B!["@H@("`@=F%R("1G<F%P:#L*"B`@("!V87(@)%]C;VQO<B`]("=B
M;'5E)SL*("`@('9A<B`D7V]U=&QI;F4@/2`G8FQA8VLG.PH@("`@=F%R("1?
M=VED=&@@/2`Q,#L*("`@('9A<B`D7V]F9G-E="`](#`["B`@("!V87(@)%]D
M871A<V5T.PH*("`@(&9U;F-T:6]N($AO<F1E7T=R87!H7U!L;W1?8F%R*"8D
M9W)A<&@L("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/F=R87!H(#T@
M)B1G<F%P:#L*"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86T@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1K97D@/2`G7R<@+B`D<&%R86T[
M"B`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!D<F%W*"1M:6Y9(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^9W)A<&@M/E]D871A6R=Y)UU;)'1H
M:7,M/E]D871A<V5T73L*"B`@("`@("`@)&)A<E=I9'1H(#T@)'1H:7,M/E]W
M:61T:#L*("`@("`@("`D8F%R3V9F<V5T(#T@)'1H:7,M/E]O9F9S970@*B`D
M8F%R5VED=&@["B`@("`@("`@)'4@/2`P.PH@("`@("`@("1V(#T@,#L*("`@
M("`@("`D8V]U;G0@/2!C;W5N="@D9&%T82D["B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1X(#T@)&D[
M"B`@("`@("`@("`@(&EF("@D;6EN62`]/3T@9F%L<V4@?'P@)&1A=&%;)&E=
M(#X]("1M:6Y9*2!["B`@("`@("`@("`@("`@("`D>2`]("1D871A6R1I73L*
M("`@("`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^=')A;G-L871E*"1X+"`D
M>2D["B`@("`@("`@("`@("`@("`D>"`]("1X("T@*"1B87)7:61T:"`O(#(I
M("L@)&)A<D]F9G-E=#L*("`@("`@("`@("`@("`@("1H96EG:'0@/2`D=&AI
M<RT^9W)A<&@M/E]G<F%P:$)O='1O;2`M("1Y.PH*("`@("`@("`@("`@("`@
M("1T:&ES+3YG<F%P:"T^:6UG+3YR96-T86YG;&4H)'@L("1Y+"`D8F%R5VED
M=&@L("1H96EG:'0L("1T:&ES+3Y?;W5T;&EN92P@)'1H:7,M/E]C;VQO<BD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0;&]T+V)A<F=R;W5P960N
M<&AP````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-S(`,3`T,3<S-C(W-S$`
M,#(S,#8P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T=R87!H+U!L;W0O8F%R
M+G!H<"<["@HO*BH*("H@1W)O=7!E9"!B87(@9W)A<&@@:6UP;&5M96YT871I
M;VX@9F]R('1H92!(;W)D95]'<F%P:"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]'<F%P:"]'<F%P:"]0;&]T+V)A<F=R;W5P960N<&AP+'8@
M,2XQ+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L87-S($AO<F1E7T=R
M87!H7U!L;W1?8F%R9W)O=7!E9"!E>'1E;F1S($AO<F1E7T=R87!H7U!L;W1?
M8F%R('L*"B`@("!V87(@)%]S=&5P(#T@+C4["B`@("!V87(@)%]C;VQO<G,@
M/2!A<G)A>2@I.PH@("`@=F%R("1?9&%T87-E=',@/2!A<G)A>2@I.PH*("`@
M(&9U;F-T:6]N(&1R87<H*0H@("`@>PH@("`@("`@("\O($-A;&-U;&%T92!T
M:&4@<W1A<G1I;F<@;V9F<V5T(&9O<B!E86-H(&)A<BP@9G)O;2!W:&EC:"!W
M90H@("`@("`@("\O(&UO=F4@:70@;W9E<B!B>2`D=&AI<RT^7W-T97`N"B`@
M("`@("`@)&1A=&%S971S(#T@8V]U;G0H)'1H:7,M/E]D871A<V5T<RD["B`@
M("`@("`@)&=L;V)A;$]F9G-E="`]("1T:&ES+3Y?;V9F<V5T("T@*"@D=&AI
M<RT^7W-T97`@*B`H)&1A=&%S971S("T@,2DI("\@,BD["@H@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1D871A<V5T<SL@)&DK*RD@>PH@("`@("`@("`@
M("`O+R!#86QC=6QA=&4@=&AE(&]F9G-E="!O9B!T:&ES('-E="!O9B!B87)S
M+@H@("`@("`@("`@("`D=&AI<RT^7V]F9G-E="`]("1G;&]B86Q/9F9S970@
M*R`H)'1H:7,M/E]S=&5P("H@)&DI.PH*("`@("`@("`@("`@+R\@4V5T(&)A
M<B!P87)A;65T97)S('1H870@8VAA;F=E('!E<BUG<F]U<"X*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?8V]L;W)S6R1I72DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V]L;W(@/2`D=&AI<RT^7V-O;&]R<ULD:5T["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]D871A<V5T(#T@)'1H
M:7,M/E]D871A<V5T<ULD:5T["@H@("`@("`@("`@("`O+R!$<F%W('1H:7,@
M9&%T87-E="X*("`@("`@("`@("`@<&%R96YT.CID<F%W*"D["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T=R87!H+U!L;W0O8F%R<W1A8VME9"YP:'``````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,38R-0`Q,#0Q-S,V,C<W,0`P,C,P,C<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%-T86-K
M960@8F%R(&=R87!H(&EM<&QE;65N=&%T:6]N(&9O<B!T:&4@2&]R9&5?1W)A
M<&@@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1W)A<&@O1W)A
M<&@O4&QO="]B87)S=&%C:V5D+G!H<"QV(#$N,2XQ,"XT(#(P,#8O,#$O,#$@
M,C$Z,C@Z,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7T=R87!H"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]0;&]T7V)A<G-T86-K960@
M>PH*("`@('9A<B`D9W)A<&@["@H@("`@=F%R("1?8V]L;W(@/2`G8FQU92<[
M"B`@("!V87(@)%]O=71L:6YE(#T@)V)L86-K)SL*("`@('9A<B`D7W=I9'1H
M(#T@,3`["B`@("!V87(@)%]O9F9S970@/2`P.PH@("`@=F%R("1?9&%T87-E
M=#L*"B`@("!F=6YC=&EO;B!(;W)D95]'<F%P:%]0;&]T7V)A<G-T86-K960H
M)B1G<F%P:"P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^9W)A<&@@
M/2`F)&=R87!H.PH*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A
M;2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&ME>2`]("=?)R`N("1P87)A
M;3L*("`@("`@("`@("`@)'1H:7,M/B1K97D@/2`D=F%L=64["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N(&1R87<H*0H@("`@>PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T=R87!H+U!L;W0O<V-A='1E<BYP:'``````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C0R,0`Q,#0Q-S,V,C<W,0`P,C(S-C0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%-C871T97(@<&QO="!I;7!L96UE;G1A=&EO;B!F;W(@=&AE($AO<F1E7T=R
M87!H('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T=R87!H+T=R
M87!H+U!L;W0O<V-A='1E<BYP:'`L=B`Q+C,N,3(N-"`R,#`V+S`Q+S`Q(#(Q
M.C(X.C$X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'
M<F%P:`H@*B\*8VQA<W,@2&]R9&5?1W)A<&A?4&QO=%]S8V%T=&5R('L*"B`@
M("!V87(@)%]G<F%P:#L*("`@('9A<B`D7V-O;&]R(#T@)V)L=64G.PH@("`@
M=F%R("1?<VAA<&4@/2`G<W%U87)E)SL*("`@('9A<B`D7V1A=&%S970["@H@
M("`@9G5N8W1I;VX@2&]R9&5?1W)A<&A?4&QO=%]S8V%T=&5R*"8D9W)A<&@L
M("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]G<F%P:"`]("8D9W)A
M<&@["@H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@
M("`@("`@("`D=&AI<RT^)&ME>2`]("1V86QU93L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@9')A=R@D;6EN62`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1D871A(#T@)'1H:7,M/E]G<F%P:"T^7V1A=&%;)WDG75LD=&AI<RT^
M7V1A=&%S971=.PH*("`@("`@("`D8V]U;G0@/2!C;W5N="@D9&%T82D["B`@
M("`@("`@)'9E<G1S(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)'@@/2`D:3L*("`@
M("`@("`@("`@:68@*"1M:6Y9(#T]/2!F86QS92!\?"`D9&%T85LD:5T@/CT@
M)&UI;EDI('L*("`@("`@("`@("`@("`@("1Y(#T@)&1A=&%;)&E=.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G<F%P:"T^=')A;G-L871E*"1X+"`D>2D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V=R87!H+3YI;6<M/F)R=7-H*"1X
M+"`D>2P@)'1H:7,M/E]C;VQO<BP@)'1H:7,M/E]S:&%P92D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O4&QO="]L:6YE
M+G!H<```````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,C4W`#$P-#$W
M,S8R-S<Q`#`R,38U-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@3&EN92!G<F%P:"!I;7!L96UE;G1A
M=&EO;B!F;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T=R87!H+T=R87!H+U!L;W0O;&EN92YP:'`L=B`Q+C0N
M,3(N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95]'<F%P:`H@*B\*8VQA<W,@2&]R9&5?1W)A<&A?
M4&QO=%]L:6YE('L*"B`@("!V87(@)%]G<F%P:#L*("`@('9A<B`D7V-O;&]R
M(#T@)V)L=64G.PH@("`@=F%R("1?=VED=&@@/2`Q.PH@("`@=F%R("1?9&%T
M87-E=#L*"B`@("!F=6YC=&EO;B!(;W)D95]'<F%P:%]0;&]T7VQI;F4H)B1G
M<F%P:"P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7V=R87!H(#T@
M)B1G<F%P:#L*"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86T@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1K97D@/2`G7R<@+B`D<&%R86T[
M"B`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!D<F%W*"1M:6Y9(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=R87!H+3Y?9&%T85LG>2==6R1T
M:&ES+3Y?9&%T87-E=%T["@H@("`@("`@("1C;W5N="`](&-O=6YT*"1D871A
M*3L*("`@("`@("`D=F5R=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D>"`]("1I
M.PH@("`@("`@("`@("!I9B`H)&UI;ED@(3T](&9A;'-E("8F("1D871A6R1I
M72`\("1M:6Y9*2!["B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'9E<G1S
M*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G<F%P:"T^
M:6UG+3YC:7)C;&4H)'9E<G1S6S!=6R=X)UTL("1V97)T<ULP75LG>2==+"`D
M=&AI<RT^7W=I9'1H+"`D=&AI<RT^7V-O;&]R+"`D=&AI<RT^7V-O;&]R*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9W)A<&@M/FEM9RT^<&]L>6QI;F4H
M)'9E<G1S+"`D=&AI<RT^7V-O;&]R+"`D=&AI<RT^7W=I9'1H*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V97)T<R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("`D>2`]("1D871A6R1I73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9W)A<&@M/G1R86YS;&%T92@D>"P@)'DI.PH@("`@("`@("`@("`@("`@)'9E
M<G1S6UT@/2!A<G)A>2@G>"<@/3X@)'@L("=Y)R`]/B`D>2D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9W)A<&@M/FEM9RT^
M<&]L>6QI;F4H)'9E<G1S+"`D=&AI<RT^7V-O;&]R+"`D=&AI<RT^7W=I9'1H
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&%4<F5E+P``````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W
M,0`P,3<W,C0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T
M851R964O;G5L;"YP:'``````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#(W,S<W`#$P-#$W,S8R-S<Q`#`R,30R-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($1A=&%4
M<F5E7VYU;&PZ.B!C;&%S<R!P<F]V:61E<R!A(&1U;6UY(&EM<&QE;65N=&%T
M:6]N(&]F('1H90H@*B!$871A5')E93HZ($%023L@;F\@9&%T82!W:6QL(&QA
M<W0@8F5Y;VYD(&$@<VEN9VQE('!A9V4@<F5Q=65S="X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O;G5L;"YP:'`L=B`Q+C$U
M+C(N-"`R,#`U+S$P+S$X(#$Q.C`Q.C`U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2P@,C`P,"P@,C`P,2P@,C`P,B!3=&5P:&%N92!(=71H97(@
M/'-H=71H97)`8FEG9F]O="YC;VT^"B`J($-O<'ER:6=H="`R,#`Q+"`R,#`R
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?1&%T851R964*("HO"F-L87-S($1A=&%4<F5E7VYU;&P@97AT96YD<R!$
M871A5')E92!["@H@("`@+RHJ"B`@("`@*B!#86-H92!O9B!A='1R:6)U=&5S
M(&9O<B!A;GD@;V)J96-T<R!C<F5A=&5D(&1U<FEN9R!T:&ES('!A9V4@<F5Q
M=65S="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V%T=')I8G5T94-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-A8VAE(&]F(&1A=&$@9F]R(&%N>2!O8FIE8W1S(&-R96%T960@9'5R:6YG
M('1H:7,@<&%G92!R97%U97-T+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?9&%T84-A8VAE(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($QO860@*&$@<W5B<V5T(&]F*2!T:&4@9&%T871R964@:6YT
M;R!T:&4@)%]D871A(&%R<F%Y+B!087)T(&]F('1H90H@("`@("H@1&%T851R
M964@05!)('1H870@;75S="!B92!O=F5R<FED9&5N(&)Y('-U8F-L87-S97,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)')O;W0@("`@5VAI8V@@
M<&]R=&EO;B!O9B!T:&4@=')E92!T;R!L;V%D+B!$969A=6QT<R!T;PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@86QL(&]F(&ET+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)')E;&]A9"`@4F4M;&]A9"!A;')E861Y(&QO861E
M9"!V86QU97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M;&]A9"@D<F]O="`](&YU;&PL("1R96QO860@/2!F86QS92D*("`@('L*("`@
M('T*"B`@("`O*BH*("`@("`J($QO860@82!S<&5C:69I8R!O8FIE8W0@:61E
M;G1I9FEE9"!B>2!I=',@=6YI<75E($E$("@D:60I+"!A;F0*("`@("`J(&ET
M<R!P87)E;G1S+"!I;G1O('1H92`D7V1A=&$@87)R87DN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@5&AE('5N:7%U92!)1"!O9B!T:&4@
M;V)J96-T('1O(&QO860N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?;&]A9$)Y260H)&-I9"D*("`@('L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!A('1R964@<V]R=&5D(&)Y('1H92!S<&5C:69I960@871T<FEB
M=71E(&YA;64@86YD+V]R(&ME>2X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R
M9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)')O;W0@("`@
M("`@5VAI8V@@<&]R=&EO;B!O9B!T:&4@=')E92!T;R!S;W)T+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@86QL(&]F
M(&ET+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8614<F5E("`@4V]R="!T
M:&4@=')E92!S=&%R=&EN9R!A="`D<F]O="P@;W(@:G5S="!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<75E<W1E9"!L979E;"!A
M;F0@9&ER96-T('!A<F5N=',_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V96PN"B`@("`@*B!`<&%R
M86T@87)R87D@)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M92!T;R!U<V4@
M9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)'-O<G1B>5]K97D@
M("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P
M87)A;2!A<G)A>2`D9&ER96-T:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C
M96YD:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-O<G1E9%1R964H)')O
M;W0L("1L;V%D5')E92`](&9A;'-E+"`D<V]R=&)Y7VYA;64@/2!N=6QL+"`D
M<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@
M("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D
M(&%N(&]B:F5C="X@4&%R="!O9B!T:&4@1&%T851R964@05!)('1H870@;75S
M="!B90H@("`@("H@;W9E<G)I9&1E;B!B>2!S=6)C;&%S<V5S+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D9G5L;&YA;64@(%1H92!O8FIE8W0@=&\@
M861D("AS=')I;F<@;W(@1&%T851R965/8FIE8W0I+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&0H)&]B:F5C="D*("`@('L*("`@("`@("!I9B`H:7-?82@D
M;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@("`@("`D9G5L
M;&YA;64@/2`D;V)J96-T+3YG971.86UE*"D["B`@("`@("`@("`@("1O<F1E
M<B`]("1O8FIE8W0M/F]R9&5R.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1F=6QL;F%M92`]("1O8FIE8W0["B`@("`@("`@("`@("1O<F1E<B`]
M(&YU;&P["B`@("`@("`@?0H*("`@("`@("`D:60@/2!M9#4H;71?<F%N9"@I
M*3L*("`@("`@("!I9B`H<W1R<&]S*"1F=6QL;F%M92P@)SHG*2`A/3T@9F%L
M<V4I('L*("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G.B<L("1F=6QL
M;F%M92D["B`@("`@("`@("`@("1N86UE(#T@87)R87E?<&]P*"1P87)T<RD[
M"B`@("`@("`@("`@("1P87)E;G0@/2!I;7!L;V1E*"<Z)RP@)'!A<G1S*3L*
M("`@("`@("`@("`@)'!I9"`]("1T:&ES+3YG971)9"@D<&%R96YT*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)'!I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9"@D<&%R96YT*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P:60@/2!$051!5%)%
M15]23T]4.PH@("`@("`@('T*"B`@("`@("`@:68@*'!A<F5N=#HZ97AI<W1S
M*"1F=6QL;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T%L<F5A9'D@97AI<W1S)RD["B`@("`@("`@?0H*("`@("`@("`D
M861D960@/2!P87)E;G0Z.E]A9&0H)&9U;&QN86UE+"`D:60L("1P:60L("1O
M<F1E<BD["B`@("`@("`@:68@*&ES7V$H)&%D9&5D+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D861D960["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^=7!D871E1&%T82@D;V)J96-T*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H86YG92!O<F1E<B!O9B!T:&4@8VAI;&1R96X@
M;V8@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M<F5N=',@(%1H92!P87)E;G0@:60@<W1R:6YG('!A=&@N"B`@("`@*B!`<&%R
M86T@;6EX960@)&]R9&5R("`@("!!('-P96-I9FEC(&YE=R!O<F1E<B!P;W-I
M=&EO;B!O<B!A;B!A<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N=&%I;FEN9R!T:&4@;F5W('!O<VET:6]N<R!F;W(@=&AE(&=I=F5N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R96YT<R!O8FIE
M8W0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VED("`@("!)9B!P<F]V:61E
M9"!I;F1I8V%T97,@:6YS97)T:6]N(&]F(&$@;F5W(&-H:6QD"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!T;R!T:&4@;V)J96-T+"!A;F0@=VEL
M;"!B92!U<V5D('1O(&%V;VED"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!I;F-R96UE;G1I;F<@:70@=VAE;B!S:&EF=&EN9R!U<"!A;&P@;W1H
M97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N)W,@
M;W)D97(N($EF(&YO="!P<F]V:61E9"!I;F1I8V%T97,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&1E;&5T:6]N+"!H96YC92!S:&EF="!A;&P@
M;W1H97(@<&]S:71I;VYS(&1O=VX*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5O<F1E<B@D<&%R
M96YT<RP@)&]R9&5R(#T@;G5L;"P@)&-I9"`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1O<F1E<BD@)B8@(65M<'1Y*"1O<F1E<BDI('L*
M("`@("`@("`@("`@+R\@375L=&D@=7!D871E+@H@("`@("`@("`@("`D=&AI
M<RT^7W)E;W)D97(H)'!I9"P@)&]R9&5R*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!%>'!L:6-I=&QY('-E="!T:&4@;W)D97(@9F]R(&$@
M9&%T871R964@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1I9"`@("`@5&AE(&1A=&%T<F5E(&]B:F5C="!I9"!T;R!C:&%N9V4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D;W)D97(@(%1H92!N97<@;W)D97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$]R9&5R*"1I9"P@)&]R9&5R*0H@("`@
M>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A;B!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&]B:F5C="`@5&AE(&]B:F5C
M="!T;R!R96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R8V4@("!&
M;W)C92!R96UO=F%L(&]F(&5V97)Y(&-H:6QD(&]B:F5C=#\*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5M;W9E*"1O8FIE8W0L("1F;W)C92`](&9A;'-E*0H@
M("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E(&]N92!O<B!M;W)E
M(&]B:F5C=',@8GD@:60N(%1H:7,@9G5N8W1I;VX@9&]E<R`J;F]T*B!D;PH@
M("`@("H@=&AE('9A;&ED871I;VXL(')E;W)D97)I;F<L(&5T8RX@=&AA="!R
M96UO=F4H*2!D;V5S+B!)9B!Y;W4*("`@("`J(&YE960@=&\@8VAE8VL@9F]R
M(&-H:6QD<F5N+"!R92UD;R!O<F1E<FEN9RP@971C+BP@=&AE;B!Y;W4@;75S
M=`H@("`@("H@<F5M;W9E*"D@;V)J96-T<R!O;F4M8GDM;VYE+B!4:&ES(&ES
M(&9O<B!C;V1E('1H870@:VYO=W,@:70G<PH@("`@("H@9&5A;&EN9R!W:71H
M('-I;F=L92`H;F]N+7!A<F5N=&5D*2!O8FIE8W1S(&%N9"!N965D<R!T;R!D
M96QE=&4*("`@("`J(&$@8F%T8V@@;V8@=&AE;2!Q=6EC:VQY+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D:61S("!4:&4@;V)J96-T<R!T;R!R96UO
M=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94)Y261S*"1I9',I"B`@
M("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@;VYE(&]R(&UO<F4@
M;V)J96-T<R!B>2!N86UE+B!4:&ES(&9U;F-T:6]N(&1O97,@*FYO="H@9&\*
M("`@("`J('1H92!V86QI9&%T:6]N+"!R96]R9&5R:6YG+"!E=&,N('1H870@
M<F5M;W9E*"D@9&]E<RX@268@>6]U"B`@("`@*B!N965D('1O(&-H96-K(&9O
M<B!C:&EL9')E;BP@<F4M9&\@;W)D97)I;F<L(&5T8RXL('1H96X@>6]U(&UU
M<W0*("`@("`J(')E;6]V92@I(&]B:F5C=',@;VYE+6)Y+6]N92X@5&AI<R!I
M<R!F;W(@8V]D92!T:&%T(&MN;W=S(&ET)W,*("`@("`J(&1E86QI;F<@=VET
M:"!S:6YG;&4@*&YO;BUP87)E;G1E9"D@;V)J96-T<R!A;F0@;F5E9',@=&\@
M9&5L971E"B`@("`@*B!A(&)A=&-H(&]F('1H96T@<75I8VML>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)&YA;65S("!4:&4@;V)J96-T<R!T;R!R
M96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94)Y3F%M97,H)&YA
M;65S*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@36]V92!A;B!O8FIE
M8W0@=&\@82!N97<@<&%R96YT+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`@)&]B:F5C="`@("`@5&AE(&]B:F5C="!T;R!M;W9E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F5W<&%R96YT("!4:&4@;F5W('!A<F5N="!O8FIE8W0N
M($1E9F%U;'1S('1O('1H92!R;V]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!M
M;W9E*"1O8FIE8W0L("1N97=P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VAA;F=E(&%N(&]B:F5C="=S(&YA;64N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;VQD7V]B:F5C="`@("`@("!4:&4@
M;VQD(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=U]O8FIE8W1?
M;F%M92`@5&AE(&YE=R!O8FIE8W0@;F%M92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5N86UE*"1O;&1?;V)J96-T+"`D;F5W7V]B:F5C=%]N86UE*0H@("`@
M>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@9&%T82!F;W(@86X@
M;V)J96-T(&9R;VT@=&AE(&1A=&%T<F5E7V1A=&$@9FEE;&0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@5&AE(&]B:F5C="!I9"!T;R!F
M971C:"P@;W(@86X@87)R87D@;V8@;V)J96-T(&ED<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1&%T82@D8VED*0H@("`@>PH@("`@("`@(')E='5R;B!I
M<W-E="@D=&AI<RT^7V1A=&%#86-H95LD8VED72D@/PH@("`@("`@("`@("`D
M=&AI<RT^7V1A=&%#86-H95LD8VED72`Z"B`@("`@("`@("`@(&%R<F%Y*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!D871A(&9O<B!A;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@5&AE
M(&]B:F5C="!I9"!T;R!F971C:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M071T<FEB=71E<R@D8VED*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M8VED*2D@>PH@("`@("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1C:60@87,@)&ED*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]A='1R:6)U=&5#86-H95LD:61=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1D871A6R1I9%T@/2`D=&AI<RT^7V%T=')I8G5T
M94-A8VAE6R1I9%T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]A='1R:6)U=&5#86-H
M95LD8VED72D@/PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5#
M86-H95LD8VED72`Z"B`@("`@("`@("`@("`@("!A<G)A>2@I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O
M9B!O8FIE8W1S(&UA=&-H:6YG(&$@<V5T(&]F(&%T=')I8G5T90H@("`@("H@
M8W)I=&5R:6$N"B`@("`@*@H@("`@("H@0'-E92!B=6EL9$%T=')I8G5T95%U
M97)Y*"D*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D8W)I=&5R:6$@
M("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D<&%R96YT("`@("!4:&4@<&%R96YT(&YO9&4@=&\@<W1A<G0@<V5A<F-H
M:6YG(&9R;VTN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("!2
M971U<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C:&EL9')E;B!O9B`D<&%R96YT
M/R!$969A=6QT<R!T;R!A;&P@;&5V96QS+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)')E<W1R:6-T("`@3VYL>2!R971U<FX@871T<FEB=71E<R!W:71H('1H
M92!S86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A='1R
M:6)U=&5?;F%M92!O<B!A='1R:6)U=&5?:60N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O=6YT0GE!='1R:6)U=&5S*"1C<FET97)I82P@)'!A<F5N="`]($1!
M5$%44D5%7U)/3U0L("1A;&Q,979E;',@/2!T<G5E+"`D<F5S=')I8W0@/2`G
M;F%M92<I"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D8W)I=&5R:6$I*2![
M"B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&-O=6YT*"1T:&ES+3Y?871T<FEB=71E0V%C:&4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A('-E="!O9B!O8FIE8W0@:61S(&)A<V5D
M(&]N(&$@<V5T(&]F(&%T=')I8G5T92!C<FET97)I82X*("`@("`J"B`@("`@
M*B!`<V5E(&)U:6QD071T<FEB=71E475E<GDH*0H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`@("1C<FET97)I82`@("`@5&AE(&%R<F%Y(&]F(&-R:71E
M<FEA+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("`@("!4:&4@
M<&%R96YT(&YO9&4@=&\@<W1A<G0@<V5A<F-H:6YG(&9R;VTN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("`@(%)E='5R;B!A;&P@;&5V96QS
M+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@
M86QL(&QE=F5L<RX*("`@("`J($!P87)A;2!S=')I;F<@("1R97-T<FEC="`@
M("`@3VYL>2!R971U<FX@871T<FEB=71E<R!W:71H('1H92!S86UE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%T=')I8G5T95]N86UE
M(&]R(&%T=')I8G5T95]I9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1F<F]M
M("`@("`@("`@5&AE(&]B:F5C="!T;R!S=&%R="!T;R!F971C:&EN9PH@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&-O=6YT("`@("`@("!4:&4@;G5M8F5R(&]F
M(&]B:F5C=',@=&\@9F5T8V@*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T
M8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@("!!='1R:6)U=&4@
M:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)Y071T<FEB=71E<R@D8W)I=&5R
M:6$L("1P87)E;G0@/2!$051!5%)%15]23T]4+"`D86QL3&5V96QS(#T@=')U
M92P@)')E<W1R:6-T(#T@)VYA;64G+"`D9G)O;2`](#`L("1C;W5N="`](#`L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]N86UE(#T@
M;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@
M('L*("`@("`@("!I9B`H(6-O=6YT*"1C<FET97)I82DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO(&-R:71E<FEA)RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D=&AI<RT^7V%T
M=')I8G5T94-A8VAE*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G1S($E$
M<R!B>2!A='1R:6)U=&4@=F%L=65S+B!)1',@=VET:&]U="!A='1R:6)U=&5S
M('=I;&P@8F4*("`@("`J(&%D9&5D('1O('1H92!E;F0@;V8@=&AE('-O<G1E
M9"!L:7-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D=6YO<F1E<F5D
M7VED<R`@07)R87D@;V8@:61S('1O('-O<G0N"B`@("`@*B!`<&%R86T@87)R
M87D@)'-O<G1B>5]N86UE("`@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@
M<V]R=&EN9RX*("`@("`J($!P87)A;2!A<G)A>2`D<V]R=&)Y7VME>2`@("`@
M071T<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R
M86T@87)R87D@)&1I<F5C=&EO;B`@("`@(%-O<G0@9&ER96-T:6]N.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I
M;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@
M9&5S8V5N9&EN9PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%-O<G1E
M9"!I9',N"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G1">4%T=')I8G5T97,H
M)'5N;W)D97)E9%]I9',L("1S;W)T8GE?;F%M92`](&YU;&PL("1S;W)T8GE?
M:V5Y(#T@;G5L;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@<F5T
M=7)N("1U;F]R9&5R961?:61S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A(&QI<W0@;V8@86QL(&]F('1H92!A=F%I;&%B;&4@=F%L=65S(&]F
M('1H92!G:79E;@H@("`@("H@871T<FEB=71E(&YA;64O:V5Y(&-O;6)I;F%T
M:6]N+B!%:71H97(@871T<FEB=71E7VYA;64@;W(*("`@("`J(&%T=')I8G5T
M95]K97D@35535"!B92!S=7!P;&EE9"P@86YD(&)O=&@@34%9(&)E('-U<'!L
M:65D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%T=')I8G5T95]N
M86UE("!4:&4@;F%M92!O9B!T:&4@871T<FEB=71E+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D871T<FEB=71E7VME>2`@(%1H92!K97D@=F%L=64@;V8@=&AE
M(&%T=')I8G5T92X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<F5N="`@("`@
M("`@("!4:&4@<&%R96YT(&YO9&4@=&\@<W1A<G0@<V5A<F-H:6YG(&9R;VTN
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("`@("`@4F5T=7)N
M(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL
M(&]F('1H92!A=F%I;&%B;&4@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971!='1R:6)U=&5686QU97,H)&%T=')I8G5T95]N86UE(#T@;G5L;"P@
M)&%T=')I8G5T95]K97D@/2!N=6QL+"`D<&%R96YT(#T@1$%40512145?4D]/
M5"P@)&%L;$QE=F5L<R`]('1R=64I"B`@("!["B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE(&1A=&$@
M:6X@86X@;V)J96-T+B!$;V5S(&YO="!C:&%N9V4@=&AE(&]B:F5C="=S"B`@
M("`@*B!P87)E;G0@;W(@;F%M92P@:G5S="!S97)I86QI>F5D(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;V)J96-T("!4:&4@;V)J96-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5$871A*"1O8FIE8W0I"B`@
M("!["B`@("`@("`@:68@*"%I<U]A*"1O8FIE8W0L("=$871A5')E94]B:F5C
M="<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@)&-I9"`]("1T:&ES+3YG971)9"@D;V)J96-T+3YG971.86UE*"DI
M.PH@("`@("`@(&EF("AI<U]A*"1C:60L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C:60["B`@("`@("`@?0H*("`@("`@("`O+R!7
M92!H86YD;&4@9&%T82!D:69F97)E;G1L>2!I9B!W92!C86X@;6%P(&ET('1O
M"B`@("`@("`@+R\@871T<FEB=71E<RX*("`@("`@("!I9B`H;65T:&]D7V5X
M:7-T<R@D;V)J96-T+"`G7W1O071T<FEB=71E<R<I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?871T<FEB=71E0V%C:&5;)&-I9%T@/2`D;V)J96-T+3Y?=&]!
M='1R:6)U=&5S*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/E]D871A0V%C:&5;)&-I9%T@/2`D;V)J96-T+3YG971$871A*"D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]$871A5')E92]S<6PN<&AP````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-S0Q,S4`,3`T,3<S-C(W-S$`,#(Q,C0T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@1&%T851R965?<W%L.CH@8VQA<W,@<')O=FED97,@
M86X@4U%,(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!$871A5')E
M92!S>7-T96TN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@
M("`G<&AP='EP92<@("!4:&4@9&%T86)A<V4@='EP92`H:64N("=P9W-Q;"<L
M("=M>7-Q;"<L(&5T8RXI+@H@*B`@("=C:&%R<V5T)R`@(%1H92!C:&%R<V5T
M('5S960@8GD@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P
M87)A;65T97)S.CQP<F4^"B`J("`@)W1A8FQE)R`@("`@5&AE(&YA;64@;V8@
M=&AE(&1A=&$@=&%B;&4@:6X@)V1A=&%B87-E)RX*("H@("`@("`@("`@("`@
M("!$149!54Q4.B`G:&]R9&5?9&%T871R964G/"]P<F4^"B`J"B`J(%)E<75I
M<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J
M("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@
M("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE
M8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S=V]R9"<@(%1H92!P87-S
M=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`G:&]S='-P
M96,G("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@
M("`G<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C
M<"<L("=U;FEX)RP@971C+BDN"B`J("`@)V]P=&EO;G,G("`@061D:71I;VYA
M;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T
M)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A
M=&%B87-E+@H@*B`@("=T='DG("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J(%1H92!T86)L
M92!S=')U8W1U<F4@9F]R('1H92!$871A5')E92!S>7-T96T@:7,@:6X*("H@
M<V-R:7!T<R]S<6PO:&]R9&5?9&%T871R964N<W%L+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP+'8@,2XQ-38N
M,BXR-R`R,#`V+S`Q+S$X(#$Y.C,W.C$U(&)E;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F
M;V]T+F-O;3X*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!*
M86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF"B`J('EO=2!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964*("H@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!A=71H;W(@(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T
M+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E
M7T1A=&%4<F5E"B`J+PIC;&%S<R!$871A5')E95]S<6P@97AT96YD<R!$871A
M5')E92!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT
M(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@
M("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J(%1H92!N=6UB
M97(@;V8@8V]P:65S(&]F('1H92!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M('1A8FQE"B`@("`@*B!T:&%T('=E(&YE960@=&\@:F]I;B!O;B!I;B!T:&4@
M8W5R<F5N="!Q=65R>2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?=&%B;&5#;W5N="`](#$["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1S(&$@;F5W(%-13"!$871A5')E92!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@1&%T851R965?<W%L*"1P87)A;7,I"B`@("!["B`@("`@("`@<&%R96YT
M.CI$871A5')E92@D<&%R86US*3L*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T(&]F(&%L
M;"!G<F]U<',@*')O;W0@;F]D97,I(&]F('1H92!D871A('1R964N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('1H92!G<F]U<"!)1',*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!S*"D*("`@('L*("`@("`@("`D
M<75E<GD@/2`G4T5,14-4($1)4U1)3D-4(&=R;W5P7W5I9"!&4D]-("<@+B`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT["@H@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIG971'<F]U<',H
M*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YG971#;VPH)'%U
M97)Y*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO861S("AA('-U8G-E="!O
M9BD@=&AE(&1A=&%T<F5E(&EN=&\@=&AE("1?9&%T82!A<G)A>2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<F]O="`@("`@("`@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R
M964@=&\@;&]A9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1&5F875L=',@=&\@86QL(&]F(&ET+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&QO8614<F5E("`@("!,;V%D(&$@=')E92!S=&%R=&EN9R!A="`D<F]O
M="P@;W(@:G5S="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5Q=65S=&5D(&QE=F5L(&%N9"!D:7)E8W0@<&%R96YT<S\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@
M<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E;&]A9"`@
M("`@("!292UL;V%D(&%L<F5A9'D@;&]A9&5D('9A;'5E<S\*("`@("`J($!P
M87)A;2!S=')I;F<@("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@
M=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B
M>5]K97D@("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I
M;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A
M<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]L;V%D*"1R;V]T(#T@1$%40512145?4D]/
M5"P@)&QO8614<F5E(#T@9F%L<V4L("1R96QO860@/2!F86QS92P*("`@("`@
M("`@("`@("`@("`@("1S;W)T8GE?;F%M92`](&YU;&PL("1S;W)T8GE?:V5Y
M(#T@;G5L;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@+RH@1&\@
M3D]4('5S92!$871A5')E93HZ97AI<W1S*"D@:&5R93L@=&AA="!W;W5L9"!C
M875S92!A;B!I;F9I;FET90H@("`@("`@("`J(&QO;W`N("HO"B`@("`@("`@
M:68@*"$D<F5L;V%D("8F"B`@("`@("`@("`@("AI;E]A<G)A>2@D<F]O="P@
M)'1H:7,M/E]N86UE36%P*2!\?`H@("`@("`@("`@("`@*&-O=6YT*"1T:&ES
M+3Y?9&%T82D@)B8@)')O;W0@/3T@1$%40512145?4D]/5"DI('Q\"B`@("`@
M("`@("`@("@A:7-?;G5L;"@D=&AI<RT^7W-O<G1(87-H*2`F)@H@("`@("`@
M("`@("`@:7-S970H)'1H:7,M/E]D871A6R1R;V]T75LG<V]R=&5R)UU;)'1H
M:7,M/E]S;W)T2&%S:%TI*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"@H@("`@("`@("1Q=65R>2`]("1T:&ES+3Y?8G5I;&1,;V%D
M475E<GDH)')O;W0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;&]A9%1R964L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!$051!5%)%15]"54E,1%]314Q%0U0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R
M=&)Y7VME>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D:7)E8W1I;VXI.PH@("`@("`@(&EF("AI<U]A*"1Q=65R>2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)'%U97)Y*2D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CI?;&]A9"@I.B`G
M("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("`D9&%T82`]("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDI
M.PH@("`@("`@(&EF("AI<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YS970H)&1A=&$L("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T
M)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]U;G1S("AA('-U8G-E="!O
M9BD@=&AE(&1A=&%T<F5E('=H:6-H('=O=6QD(&)E(&QO861E9"!I;G1O('1H
M92`D7V1A=&$*("`@("`J(&%R<F%Y(&EF(%]L;V%D*"D@:7,@8V%L;&5D('=I
M=&@@=&AE('-A;64@=F%L=64@;V8@)')O;W0N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F]O
M="`@5VAI8V@@<&]R=&EO;B!O9B!T:&4@=')E92!T;R!L;V%D+B!$969A=6QT
M<R!T;R!A;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&]F(&ET+@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@3G5M8F5R(&]F(&]B:F5C
M=',*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O=6YT*"1R;V]T(#T@1$%40512
M145?4D]/5"D*("`@('L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^7V)U:6QD
M3&]A9%%U97)Y*"1R;V]T+"!T<G5E+"!$051!5%)%15]"54E,1%]#3U5.5"D[
M"B`@("`@("`@:68@*&ES7V$H)'%U97)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<75E<GD["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@
M("`@('T*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y
M($1A=&%4<F5E7W-Q;#HZ7V-O=6YT*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R;B`H
M:6YT*21T:&ES+3Y?9&(M/F=E=$]N92@D<75E<GDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3&]A9',@*&$@<W5B<V5T(&]F*2!T:&4@9&%T871R964@:6YT
M;R!T:&4@)%]D871A(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1R;V]T("`@("`@
M("`@5VAI8V@@<&]R=&EO;B!O9B!T:&4@=')E92!T;R!L;V%D+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!A;&P@
M;V8@:70N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;&]A9%1R964@("`@($QO
M860@82!T<F5E('-T87)T:6YG(&%T("1R;V]T+"!O<B!J=7-T('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U97-T960@;&5V
M96P@86YD(&1I<F5C="!P87)E;G1S/PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V96PN"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;W!E<F%T:6]N("`@(%1Y<&4@;V8@<75E<GD@
M=&\@8G5I;&0*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?;F%M92`@
M071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@("!!='1R:6)U=&4@:V5Y('1O('5S
M92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I
M;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9$QO
M8611=65R>2@D<F]O="`]($1!5$%44D5%7U)/3U0L("1L;V%D5')E92`](&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<&5R871I;VX@
M/2!$051!5%)%15]"54E,1%]314Q%0U0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)E8W1I;VX@
M/2`P*0H@("`@>PH@("`@("`@("1S;W)T960@/2!F86QS93L*("`@("`@("`D
M=VAE<F4@/2!S<')I;G1F*"=C+F=R;W5P7W5I9"`]("5S("<L("1T:&ES+3Y?
M9&(M/G%U;W1E*"1T:&ES+3Y?<&%R86US6R=G<F]U<"==*2D["@H@("`@("`@
M(&EF("@A96UP='DH)')O;W0I("8F("1R;V]T("$]($1!5$%44D5%7U)/3U0I
M('L*("`@("`@("`@("`@)'!A<F5N=%]W:&5R92`]("1T:&ES+3Y?8G5I;&10
M87)E;G1)9',H)')O;W0L("1L;V%D5')E92P@)V,N)RD["B`@("`@("`@("`@
M(&EF("@A96UP='DH)'!A<F5N=%]W:&5R92D@)B8@(6ES7V$H)'!A<F5N=%]W
M:&5R92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'=H97)E
M(#T@<W!R:6YT9B@G)7,@04Y$("@E<RDG+"`D=VAE<F4L("1P87)E;G1?=VAE
M<F4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?
M;G5L;"@D<V]R=&)Y7VYA;64I*2!["B`@("`@("`@("`@("1W:&5R92`]('-P
M<FEN=&8H)R5S($%.1"!A+F%T=')I8G5T95]N86UE(#T@)7,@)RP@)'=H97)E
M+"`D=&AI<RT^7V1B+3YQ=6]T92@D<V]R=&)Y7VYA;64I*3L*("`@("`@("`@
M("`@)'-O<G1E9"`]('1R=64["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?
M;G5L;"@D<V]R=&)Y7VME>2DI('L*("`@("`@("`@("`@)'=H97)E(#T@<W!R
M:6YT9B@G)7,@04Y$(&$N871T<FEB=71E7VME>2`]("5S("<L("1W:&5R92P@
M)'1H:7,M/E]D8BT^<75O=&4H)'-O<G1B>5]K97DI*3L*("`@("`@("`@("`@
M)'-O<G1E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1O
M<&5R871I;VXI('L*("`@("`@("!C87-E($1!5$%44D5%7T)524Q$7T-/54Y4
M.@H@("`@("`@("`@("`D=VAA="`]("=#3U5.5"@J*2<["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=VAA="`]
M("=C+F1A=&%T<F5E7VED+"!C+F1A=&%T<F5E7VYA;64L(&,N9&%T871R965?
M<&%R96YT<RP@8RYD871A=')E95]O<F1E<B<["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S;W)T960I('L*("`@("`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@8R!,1494
M($I/24X@)7,@82!/3B`H8RYD871A=')E95]I9"`](&$N9&%T871R965?:60@
M3U(@8RYD871A=')E95]N86UE/25S*2`G+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=72$5212`E<R!'4D]54"!"62!C+F1A=&%T<F5E7VED+"!C
M+F1A=&%T<F5E7VYA;64L(&,N9&%T871R965?<&%R96YT<RP@8RYD871A=')E
M95]O<F1E<B!/4D1%4B!"62!A+F%T=')I8G5T95]V86QU92`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'=H870L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M7V%T=')I8G5T97,G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1B+3YQ=6]T92@D<F]O="DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'=H97)E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("@D9&ER96-T:6]N(#T](#$I(#\@)T1%4T,G(#H@)T%30R<I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#
M5"`E<R!&4D]-("5S(&,@5TA%4D4@)7,G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1W:&%T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1W:&5R92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'%U97)Y.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S('!A<F5N="!)
M1"!S=')I;F<@9F]R('-E;&5C=&EN9R!T<F5E<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M<F]O="`@("`@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R964@=&\@;&]A9"X*
M("`@("`J($!P87)A;2!B;V]L96%N("1L;V%D5')E92`@3&]A9"!A('1R964@
M<W1A<G1I;F<@870@)')O;W0L(&]R(&IU<W0@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E<75E<W1E9"!L979E;"!A;F0@9&ER96-T
M('!A<F5N=',_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@($1E
M9F%U;'1S('1O('-I;F=L92!L979E;"X*("`@("`J($!P87)A;2!S=')I;F<@
M("1J;VEN7VYA;64@5&%B;&4@:F]I;B!N86UE"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@($ED(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B
M=6EL9%!A<F5N=$ED<R@D<F]O="P@)&QO8614<F5E(#T@9F%L<V4L("1J;VEN
M7VYA;64@/2`G)RD*("`@('L*("`@("`@("!I9B`H<W1R<&]S*"1R;V]T+"`G
M.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E
M*"<Z)RP@)')O;W0I.PH@("`@("`@("`@("`D<F]O="`](&%R<F%Y7W!O<"@D
M<&%R=',I.PH@("`@("`@('T*("`@("`@("`D<F]O="`]("AS=')I;F<I)')O
M;W0["@H@("`@("`@("1Q=65R>2`]("=314Q%0U0@9&%T871R965?:60L(&1A
M=&%T<F5E7W!A<F5N=',G("X*("`@("`@("`@("`@)R!&4D]-("<@+B`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("<@5TA%4D4@9&%T
M871R965?;F%M92`](#\@04Y$(&=R;W5P7W5I9"`](#\G("X*("`@("`@("`@
M("`@)R!/4D1%4B!"62!D871A=')E95]I9"<["B`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*"1R;V]T+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG9W)O=7`G72D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CI?8G5I;&1087)E;G1)9',H
M*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@)')O;W0@/2`D=&AI<RT^7V1B+3YG971!<W-O8R@D
M<75E<GDL(&9A;'-E+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F]O
M="P@)U!%05)?17)R;W(G*2!\?"`A8V]U;G0H)')O;W0I*2!["B`@("`@("`@
M("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("1W:&5R92`]("<G
M.PH@("`@("`@("1F:7)S=%]T:6UE(#T@=')U93L*("`@("`@("!F;W)E86-H
M("@D<F]O="!A<R`D;V)J96-T7VED(#T^("1O8FIE8W1?<&%R96YT<RD@>PH@
M("`@("`@("`@("`D<'-T<FEN9R`]("1O8FIE8W1?<&%R96YT<R`N("<Z)R`N
M("1O8FIE8W1?:60@+B`G)2<["B`@("`@("`@("`@("1P<75E<GD@/2`G)SL*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D;V)J96-T7W!A<F5N=',I*2!["B`@
M("`@("`@("`@("`@("`D:61S(#T@<W5B<W1R*"1O8FIE8W1?<&%R96YT<RP@
M,2D["B`@("`@("`@("`@("`@("`D<'%U97)Y(#T@)R!/4B`G("X@)&IO:6Y?
M;F%M92`N("=D871A=')E95]I9"!)3B`H)R`N('-T<E]R97!L86-E*"<Z)RP@
M)RP@)RP@)&ED<RD@+B`G*2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1L;V%D5')E92D@>PH@("`@("`@("`@("`@("`@)'!Q=65R>2`N/2`G
M($]2("<@+B`D:F]I;E]N86UE("X@)V1A=&%T<F5E7W!A<F5N=',@/2`G("X@
M)'1H:7,M/E]D8BT^<75O=&4H<W5B<W1R*"1P<W1R:6YG+"`P+"`M,BDI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(21F:7)S=%]T:6UE*2![
M"B`@("`@("`@("`@("`@("`D=VAE<F4@+CT@)R!/4B`G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1W:&5R92`N/2!S<')I;G1F*"1J;VEN7VYA;64@
M+B`G9&%T871R965?<&%R96YT<R!,24M%("5S($]2("<@+B`D:F]I;E]N86UE
M("X@)V1A=&%T<F5E7VED(#T@)7,E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1P<W1R:6YG*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&]B:F5C=%]I9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!Q=65R>2D["@H@("`@("`@("`@("`D
M9FER<W1?=&EM92`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1W:&5R93L*("`@('T*"B`@("`O*BH*("`@("`J($QO861S(&$@<V5T(&]F
M(&]B:F5C=',@:61E;G1I9FEE9"!B>2!T:&5I<B!U;FEQ=64@241S+"!A;F0@
M=&AE:7(*("`@("`J('!A<F5N=',L(&EN=&\@=&AE("1?9&%T82!A<G)A>2X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)&-I9',@(%1H92!U;FEQ=64@240@;V8@=&AE(&]B:F5C
M="!T;R!L;V%D+"!O<B!A;B!A<G)A>2!O9@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("!O8FIE8W0@:61S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861">4ED*"1C:61S*0H@("`@
M>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&%N(&%R<F%Y+B`J+PH@
M("`@("`@(&EF("@A:7-?87)R87DH)&-I9',I*2!["B`@("`@("`@("`@("1C
M:61S(#T@87)R87DH*&EN="DD8VED<RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@87)R87E?=V%L:R@D8VED<RP@)VEN='9A;"<I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0F%I;"!O=70@;F]W(&EF('1H97)E)W,@;F]T:&EN
M9R!T;R!L;V%D+B`J+PH@("`@("`@(&EF("@A8V]U;G0H)&-I9',I*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1&]N)W0@;&]A9"!A;GD@=&AA="!A<F4@86QR96%D>2!L;V%D960N($%L<V\L
M(&UA:V4@<W5R92!T:&%T"B`@("`@("`@("H@979E<GET:&EN9R!I;B!T:&4@
M)&ED<R!A<G)A>2!T:&%T('=E(&%R92!B=6EL9&EN9R!I<R!A;B!I;G1E9V5R
M+B`J+PH@("`@("`@("1I9',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@
M*"1C:61S(&%S("1C:60I('L*("`@("`@("`@("`@+RH@1&\@3D]4('5S92!$
M871A5')E93HZ97AI<W1S*"D@:&5R93L@=&AA="!W;W5L9"!C875S92!A;@H@
M("`@("`@("`@("`@*B!I;F9I;FET92!L;V]P+B`J+PH@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?9&%T85LD8VED72DI('L*("`@("`@("`@("`@
M("`@("1I9'-;72`]("AI;G0I)&-I9#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@268@=&AE<F4@87)E(&YO;F4@;&5F="!T;R!L;V%D
M+"!R971U<FXN("HO"B`@("`@("`@:68@*"%C;W5N="@D:61S*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1I;B`]
M(&%R<F%Y7W-E87)C:"A$051!5%)%15]23T]4+"`D:61S*2`]/3T@9F%L<V4@
M/R!S<')I;G1F*"=D871A=')E95]I9"!)3B`H)7,I($%.1"`G+"!I;7!L;V1E
M*"<L("<L("1I9',I*2`Z("<G.PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)U-%3$5#5"!D871A=')E95]I9"P@9&%T871R965?<&%R96YT<R!&4D]-("5S
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`G(%=(15)%("5S9W)O=7!?
M=6ED(#T@)7,G("X*("`@("`@("`@("`@("`@("`@("`@("`@("<@3U)$15(@
M0ED@9&%T871R965?:60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D:6XL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ
M=6]T92@D=&AI<RT^7W!A<F%M<ULG9W)O=7`G72DI.PH@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CI?;&]A
M9$)Y260H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["B`@("`@("`@)'!A<F5N=',@/2`D=&AI<RT^7V1B+3YG
M971!<W-O8R@D<75E<GDI.PH@("`@("`@(&EF("AI<U]A*"1P87)E;G1S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<&%R96YT<SL*
M("`@("`@("!]"@H@("`@("`@("1I9',@/2!A<G)A>2@I.PH@("`@("`@(&9O
M<F5A8V@@*"1P87)E;G1S(&%S("1C:60@/3X@)'!A<F5N="D@>PH@("`@("`@
M("`@("`D:61S6RAI;G0I)&-I9%T@/2`H:6YT*21C:60["@H@("`@("`@("`@
M("`D<&ED<R`](&5X<&QO9&4H)SHG+"!S=6)S='(H)'!A<F5N="P@,2DI.PH@
M("`@("`@("`@("!F;W)E86-H("@D<&ED<R!A<R`D<&ED*2!["B`@("`@("`@
M("`@("`@("`D<&ED(#T@*&EN="DD<&ED.PH@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V1A=&%;)'!I9%TI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&ED<ULD<&ED72`]("1P:60["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF("1I9',@:7,@
M96UP='DL('=E(&AA=F4@;F]T:&EN9R!T;R!L;V%D+B`J+PH@("`@("`@(&EF
M("@A8V]U;G0H)&ED<RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("`D<75E<GD@/2`G4T5,14-4(&1A=&%T<F5E7VED
M+"!D871A=')E95]N86UE+"!D871A=')E95]P87)E;G1S+"!D871A=')E95]O
M<F1E<B<@+@H@("`@("`@("`@("`@("`@("<@1E)/32`G("X@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T
M871R965?:60@24X@*#\G("X@<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H)&ED
M<RD@+2`Q*2`N("<I)R`N"B`@("`@("`@("`@("`@("`@)R!!3D0@9W)O=7!?
M=6ED(#T@/R!/4D1%4B!"62!D871A=')E95]I9"<["B`@("`@("`@)'9A;'5E
M<R`](&%R<F%Y7VUE<F=E*"1I9',L(&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=G
M<F]U<"==*2D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E
M<GD@8GD@1&%T851R965?<W%L.CI?;&]A9$)Y260H*3H@)R`N("1Q=65R>2P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@
M)&1A=&$@/2`D=&AI<RT^7V1B+3YG971!;&PH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("!I9B`H:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/G-E="@D9&%T82P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G
M72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@=')E92!S;W)T
M960@8GD@=&AE('-P96-I9FEE9"!A='1R:6)U=&4@;F%M92!A;F0O;W(@:V5Y
M+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1R;V]T("`@("`@("`@5VAI8V@@<&]R=&EO;B!O
M9B!T:&4@=')E92!T;R!S;W)T+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($1E9F%U;'1S('1O(&%L;"!O9B!I="X*("`@("`J($!P87)A
M;2!B;V]L96%N("1L;V%D5')E92`@("!3;W)T('1H92!T<F5E('-T87)T:6YG
M(&%T("1R;V]T+"!O<B!J=7-T('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E<75E<W1E9"!L979E;"!A;F0@9&ER96-T('!A<F5N
M=',_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L
M=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V]R
M=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'-O<G1B>5]K97D@("!!='1R:6)U=&4@
M:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1D:7)E8W1I;VX@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4V]R=&5D5')E92@D<F]O="P@)&QO8614<F5E
M(#T@9F%L<V4L("1S;W)T8GE?;F%M92`](&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C=&EO;B`]
M(#`I"B`@("!["B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/E]B=6EL9$QO8611
M=65R>2@D<F]O="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1L;V%D5')E92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1!5$%44D5%7T)524Q$7U-%3$5#5"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?;F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T
M8GE?:V5Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1I<F5C=&EO;BD["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YG
M971!;&PH)'%U97)Y*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@86X@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;V)J96-T("`@
M("`@("!4:&4@;V)J96-T('1O(&%D9"`H<W1R:6YG(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@1&%T851R965/8FIE8W0I+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&ED7V%S7VYA;64@(%=H971H97(@=&AE(&]B
M:F5C="!)1"!I<R!T;R!B92!U<V5D(&%S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;V)J96-T(&YA;64N("!5<V5D(&EN('-I='5A=&EO
M;G,@=VAE<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&5R92!I<R!N;R!A=F%I;&%B;&4@=6YI<75E(&EN<'5T(&9O<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="!N86UE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&0H)&]B:F5C="P@)&ED7V%S7VYA;64@/2!F
M86QS92D*("`@('L*("`@("`@("`D871T<FEB=71E<R`](&9A;'-E.PH@("`@
M("`@(&EF("AI<U]A*"1O8FIE8W0L("=$871A5')E94]B:F5C="<I*2!["B`@
M("`@("`@("`@("1F=6QL;F%M92`]("1O8FIE8W0M/F=E=$YA;64H*3L*("`@
M("`@("`@("`@)&]R9&5R(#T@)&]B:F5C="T^;W)D97(["@H@("`@("`@("`@
M("`O*B!792!H86YD;&4@9&%T82!D:69F97)E;G1L>2!I9B!W92!C86X@;6%P
M(&ET('1O('1H90H@("`@("`@("`@("`@*B!H;W)D95]D871A=')E95]A='1R
M:6)U=&5S('1A8FQE+B`J+PH@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T
M<R@D;V)J96-T+"`G7W1O071T<FEB=71E<R<I*2!["B`@("`@("`@("`@("`@
M("`D9&%T82`]("<G.PH@("`@("`@("`@("`@("`@)'-E<B`](&YU;&P["@H@
M("`@("`@("`@("`@("`@+RH@4V5T(&$@9FQA9R!F;W(@;&%T97(@<V\@=&AA
M="!W92!K;F]W('1O(&EN<V5R="!T:&4*("`@("`@("`@("`@("`@("`J(&%T
M=')I8G5T92!R;W=S+B`J+PH@("`@("`@("`@("`@("`@)&%T=')I8G5T97,@
M/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]397)I86QI>F4N<&AP)SL*("`@("`@("`@
M("`@("`@("1S97(@/2!315))04Q)6D5?551&-U]"05-)0SL*("`@("`@("`@
M("`@("`@("1D871A(#T@2&]R9&5?4V5R:6%L:7IE.CIS97)I86QI>F4H)&]B
M:F5C="T^9V5T1&%T82@I+"`D<V5R+"!.3%,Z.F=E=$-H87)S970H*2D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G5L
M;&YA;64@/2`D;V)J96-T.PH@("`@("`@("`@("`D;W)D97(@/2!N=6QL.PH@
M("`@("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("`@("`D<V5R(#T@;G5L
M;#L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@;F5X="!U;FEQ=64@
M240N("HO"B`@("`@("`@)&ED(#T@)'1H:7,M/E]D8BT^;F5X=$ED*"1T:&ES
M+3Y?<&%R86US6R=T86)L92==*3L*("`@("`@("!I9B`H:7-?82@D:60L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)&ED+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@
M("`@("`@(')E='5R;B`D:60["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R
M<&]S*"1F=6QL;F%M92P@)SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M)'!A<G1S(#T@97AP;&]D92@G.B<L("1F=6QL;F%M92D["B`@("`@("`@("`@
M("1P87)E;G1S(#T@)R<["B`@("`@("`@("`@("1P<W1R:6YG(#T@)R<["B`@
M("`@("`@("`@(&EF("@D:61?87-?;F%M92D@>PH@("`@("`@("`@("`@("`@
M+RH@4F5Q=65S=&5D('5S92!O9B!)1"!A<R!N86UE+"!S;R!D:7-C87)D(&-U
M<G)E;G0@;F%M92X@*B\*("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<&%R
M=',I.PH@("`@("`@("`@("`@("`@+RH@4V5T(&YA;64@=&\@240N("HO"B`@
M("`@("`@("`@("`@("`D;F%M92`]("1I9#L*("`@("`@("`@("`@("`@("\J
M($UO9&EF>2!F=6QL;F%M92!T;R!R969L96-T(&YE=R!N86UE+B`J+PH@("`@
M("`@("`@("`@("`@)&9U;&QN86UE(#T@:6UP;&]D92@G.B<L("1P87)T<RD@
M+B`G.B<@+B`D:60["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D;V)J96-T
M+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@("`@("`@("`@("`@("1O
M8FIE8W0M/G-E=$YA;64H)&9U;&QN86UE*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&]B:F5C="`]("1F=6QL;F%M
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1N86UE(#T@87)R87E?<&]P*"1P87)T<RD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)'!A<G1S(&%S("1P87(I
M('L*("`@("`@("`@("`@("`@("1P<W1R:6YG("X]("AE;7!T>2@D<'-T<FEN
M9RD@/R`G)R`Z("<Z)RD@+B`D<&%R.PH@("`@("`@("`@("`@("`@)'!I9"`]
M("1T:&ES+3YG971)9"@D<'-T<FEN9RD["B`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@+RH@075T;RUC<F5A=&4@<&%R96YT<RX@*B\*("`@("`@("`@("`@("`@
M("`@("`D<&ED(#T@)'1H:7,M/F%D9"@D<'-T<FEN9RD["B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7V$H)'!I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!I9#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M<&%R96YT<R`N/2`G.B<@+B`D<&ED.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:68@*"1I9%]A<U]N86UE*2!["B`@("`@
M("`@("`@("`@("`O*B!297%U97-T960@=7-E(&]F($E$(&%S(&YA;64L('-E
M="!F=6QL;F%M92!A;F0@;F%M92!T;R!)1"X@*B\*("`@("`@("`@("`@("`@
M("1F=6QL;F%M92`]("1I9#L*("`@("`@("`@("`@("`@("1N86UE(#T@)&ED
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&]B:F5C="P@)T1A=&%4<F5E
M3V)J96-T)RDI('L*("`@("`@("`@("`@("`@("`@("`D;V)J96-T+3YS971.
M86UE*"1F=6QL;F%M92D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1O8FIE8W0@/2`D9G5L;&YA;64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;F%M92`]("1F=6QL;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<&%R96YT<R`]("<G.PH@("`@("`@("`@("`D<&ED(#T@1$%40512145?
M4D]/5#L*("`@("`@("!]"@H@("`@("`@(&EF("AP87)E;G0Z.F5X:7-T<R@D
M9G5L;&YA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D%L<F5A9'D@97AI<W1S(BDI.PH@("`@("`@('T*"B`@("`@("`@
M)'%U97)Y(#T@)TE.4T525"!)3E1/("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N"B`@("`@("`@("`@("`@("`@)R`H9&%T871R965?:60L(&=R;W5P
M7W5I9"P@9&%T871R965?;F%M92P@9&%T871R965?;W)D97(L)R`N"B`@("`@
M("`@("`@("`@("`@)R!D871A=')E95]D871A+"!U<V5R7W5I9"P@9&%T871R
M965?<V5R:6%L:7IE9"PG("X*("`@("`@("`@("`@("`@("`G(&1A=&%T<F5E
M7W!A<F5N=',I)R`N"B`@("`@("`@("`@("`@("`@)R!604Q515,@*#\L(#\L
M(#\L(#\L(#\L(#\L(#\L(#\I)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH
M*&EN="DD:60L"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=G<F]U<"==+`H@("`@("`@("`@("`@("`@("`@("`@("!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1N86UE+"!.3%,Z.F=E=$-H87)S970H*2P@)'1H
M:7,M/E]P87)A;7-;)V-H87)S970G72DL"B`@("`@("`@("`@("`@("`@("`@
M("`@(&ES7VYU;&PH)&]R9&5R*2`_($Y53$P@.B`H:6YT*21O<F1E<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1A=&$L"B`@("`@("`@("`@("`@("`@
M("`@("`@("AS=')I;F<I075T:#HZ9V5T075T:"@I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`H:6YT*21S97(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)E;G1S*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!$871A5')E95]S<6PZ.F%D9"@I.B`G("X@)'%U97)Y+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<F5O<F1E<B`]("1T:&ES+3YR
M96]R9&5R*"1P87)E;G1S+"`D;W)D97(L("1I9"D["B`@("`@("`@:68@*&ES
M7V$H)')E;W)D97(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)')E;W)D97(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1R96]R9&5R.PH@
M("`@("`@('T*"B`@("`@("`@)')E<W5L="`]('!A<F5N=#HZ7V%D9"@D9G5L
M;&YA;64L("1I9"P@)'!I9"P@)&]R9&5R*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@<W5C8V5S9G5L
M;'D@:6YS97)T960@=&AE(&]B:F5C="!A;F0@:70@<W5P<&]R=',*("`@("`@
M("`@*B!B96EN9R!M87!P960@=&\@=&AE(&%T=')I8G5T97,@=&%B;&4L(&1O
M('1H870@;F]W.B`J+PH@("`@("`@(&EF("@A96UP='DH)&%T=')I8G5T97,I
M*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^=7!D871E1&%T82@D
M;V)J96-T*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:60["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H92!O<F1E<B!O9B!T:&4@
M8VAI;&1R96X@;V8@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A<F5N="`@5&AE(&9U;&P@:60@<&%T:"!O9B!T:&4@<&%R96YT
M(&]B:F5C="X*("`@("`J($!P87)A;2!M:7AE9"`D;W)D97(@("`@268@86X@
M87)R87D@:70@<W!E8VEF:65S('1H92!N97<@<&]S:71I;VYS(&9O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!A;&P@8VAI;&0@;V)J96-T<RX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@268@86X@:6YT96=E<B!A
M;F0@)&-I9"!I<R!S<&5C:69I960L('1H92!P;W-I=&EO;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!W:&5R92!T:&4@8VAI;&0@<W!E8VEF:65D
M(&)Y("1C:60@:7,@:6YS97)T960N($EF"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("1C:60@:7,@;F]T('-P96-I9FEE9"P@=&AE('!O<VET:6]N
M(&=E=',@9&5L971E9"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M8V%U<VEN9R!T:&4@9F]L;&]W:6YG('!O<VET:6]N<R!T;R!S:&EF="!U<"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@("`@4V5E("1O<F1E<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5O<F1E<B@D<&%R96YT+"`D;W)D97(@/2!N
M=6QL+"`D8VED(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(21P87)E;G0@
M?'P@:7-?82@D<&%R96YT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("\O($%B;W)T(&EM;65D:6%T96QY(&EF('1H92!P87)E;G0@<W1R:6YG(&ES
M(&5M<'1Y.R!W90H@("`@("`@("`@("`O+R!C86YN;W0@<V%F96QY(')E;W)D
M97(@86QL('1O<"UL979E;"!E;&5M96YT<RX*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*"B`@("`@("`@)'!Q=65R>2`]("<G.PH@("`@("`@(&EF
M("@A:7-?87)R87DH)&]R9&5R*2`F)B`A:7-?;G5L;"@D;W)D97(I*2!["B`@
M("`@("`@("`@("\J(%-I;F=L92!U<&1A=&4@*&%D9"]D96PI+B`J+PH@("`@
M("`@("`@("!I9B`H:7-?;G5L;"@D8VED*2D@>PH@("`@("`@("`@("`@("`@
M+RH@3F\@;V)J96-T(&ED(&=I=F5N('-O('-H=69F;&4@9&]W;BX@*B\*("`@
M("`@("`@("`@("`@("1D:7)E8W1I;VX@/2`G+2<["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O*B!792!H879E(&%N(&]B:F5C="!I
M9"!S;R!S:'5F9FQE('5P+B`J+PH@("`@("`@("`@("`@("`@)&1I<F5C=&EO
M;B`]("<K)SL*"B`@("`@("`@("`@("`@("`O*B!,96%V:6YG('1H92!N97=L
M>2!I;G-E<G1E9"!O8FIE8W0@86QO;F4N("HO"B`@("`@("`@("`@("`@("`D
M<'%U97)Y(#T@<W!R:6YT9B@G($%.1"!D871A=')E95]I9"`A/2`E<R<L("AI
M;G0I)&-I9"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'%U97)Y(#T@
M<W!R:6YT9B@G55!$051%("5S(%-%5"!D871A=')E95]O<F1E<B`](&1A=&%T
M<F5E7V]R9&5R("5S(#$@5TA%4D4@9W)O=7!?=6ED(#T@)7,@04Y$(&1A=&%T
M<F5E7W!A<F5N=',@/2`E<R!!3D0@9&%T871R965?;W)D97(@/CT@)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)E8W1I
M;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^
M<75O=&4H)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1P87)E;G0I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES7VYU;&PH)&]R9&5R*2`_
M("=.54Q,)R`Z("AI;G0I)&]R9&5R*2`N("1P<75E<GD["@H@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q
M;#HZ<F5O<F1E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@?2!E;'-E:68@*&ES7V%R
M<F%Y*"1O<F1E<BDI('L*("`@("`@("`@("`@+RH@375L=&D@=7!D871E+B`J
M+PH@("`@("`@("`@("`D<75E<GD@/2`G4T5,14-4($-/54Y4*&1A=&%T<F5E
M7VED*2<@+@H@("`@("`@("`@("`@("`@("`@("`G($923TT@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`@("`@)R!7
M2$5212!G<F]U<%]U:60@/2`_($%.1"!D871A=')E95]P87)E;G1S(#T@/R<@
M+@H@("`@("`@("`@("`@("`@("`@("`G($=23U50($)9(&1A=&%T<F5E7W!A
M<F5N=',G.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/E]P
M87)A;7-;)V=R;W5P)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%R96YT*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@
M475E<GD@8GD@1&%T851R965?<W%L.CIR96]R9&5R*"DZ("<@+B`D<75E<GDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F=E=$]N92@D<75E<GDL("1V
M86QU97,I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1O<F1E<BD@(3T@)')E<W5L="D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N(BDI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;U]K97D@/2`P.PH@("`@("`@
M("`@("!F;W)E86-H("@D;W)D97(@87,@)&]?8VED*2!["B`@("`@("`@("`@
M("`@("`D<75E<GD@/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`G(%-%5"!D871A=')E
M95]O<F1E<B`](#\@5TA%4D4@9&%T871R965?:60@/2`_)SL*("`@("`@("`@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D;U]K97DL(&ES7VYU;&PH)&]?8VED
M*2`_($Y53$P@.B`H:6YT*21O7V-I9"D["@H@("`@("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G)E
M;W)D97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`D;U]K97DK*SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'!I9"`]("1T:&ES+3YG971)9"@D<&%R96YT*3L*"B`@("`@
M("`@("`@("\J(%)E+6]R9&5R(&]U<B!C86-H92X@*B\*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F5O<F1E<B@D<&ED+"`D;W)D97(I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&QI8VET;'D@<V5T('1H92!O
M<F1E<B!F;W(@82!D871A=')E92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&ED("`@("!4:&4@9&%T871R964@;V)J96-T(&ED('1O
M(&-H86YG92X*("`@("`J($!P87)A;2!I;G1E9V5R("1O<F1E<B`@5&AE(&YE
M=R!O<F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W)D97(H)&ED+"`D
M;W)D97(I"B`@("!["B`@("`@("`@)'%U97)Y(#T@)U501$%412`G("X@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@4T54
M(&1A=&%T<F5E7V]R9&5R(#T@/R!72$5212!D871A=')E95]I9"`](#\G.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2AI<U]N=6QL*"1O<F1E<BD@/R!.54Q,
M(#H@*&EN="DD;W)D97(L"B`@("`@("`@("`@("`@("`@("`@("`@("AI;G0I
M)&ED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B
M>2!$871A5')E95]S<6PZ.G-E=$]R9&5R*"DZ("<@+B`D<75E<GDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5M;W9E<R!A;B!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("`@)&]B:F5C="`@5&AE(&]B:F5C="!T;R!R96UO
M=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R8V4@("!&;W)C92!R96UO
M=F%L(&]F(&5V97)Y(&-H:6QD(&]B:F5C=#\*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E*"1O8FIE8W0L("1F;W)C92`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1I9"`]("1T:&ES+3YG971)9"@D;V)J96-T*3L*("`@("`@("`D;W)D
M97(@/2`D=&AI<RT^9V5T3W)D97(H)&]B:F5C="D["@H@("`@("`@("1Q=65R
M>2`]("=314Q%0U0@9&%T871R965?:60@1E)/32`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@9W)O=7!?
M=6ED(#T@/R!!3D0@9&%T871R965?<&%R96YT<R!,24M%(#\G("X*("`@("`@
M("`@("`@("`@("`G($]21$52($)9(&1A=&%T<F5E7VED)SL*("`@("`@("`D
M=F%L=65S(#T@87)R87DH)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("<E.B<@+B`H:6YT*21I9"`N("<G*3L*"B`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E
M95]S<6PZ.G)E;6]V92@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D8VAI;&1R96X@/2`D=&AI
M<RT^7V1B+3YG971!;&PH)'%U97)Y+"`D=F%L=65S+"!$0E]&151#2$U/1$5?
M05-33T,I.PH*("`@("`@("!I9B`H8V]U;G0H)&-H:6QD<F5N*2D@>PH@("`@
M("`@("`@("!I9B`H)&9O<F-E*2!["B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D8VAI;&1R96X@87,@)&-H:6QD*2!["B`@("`@("`@("`@("`@("`@("`@
M)&-A="`]("1T:&ES+3YG971.86UE*"1C:&EL9%LG9&%T871R965?:60G72D[
M"B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YR96UO=F4H
M)&-A="P@=')U92D["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(I+"!C;W5N="@D8VAI;&1R
M96XI*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%)E
M;6]V92!A='1R:6)U=&5S(&9O<B!T:&ES(&]B:F5C="X@*B\*("`@("`@("`D
M<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L
M95]A='1R:6)U=&5S)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T
M871R965?:60@/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH*&EN="DD
M:60I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y
M($1A=&%4<F5E7W-Q;#HZ<F5M;W9E*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<75E<GD@
M/2`G1$5,151%($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*
M("`@("`@("`@("`@("`@("`G(%=(15)%(&1A=&%T<F5E7VED(#T@/R<["B`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"AI;G0I)&ED*3L*"B`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G)E
M;6]V92@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E
M<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@)'!A<F5N=',@/2`D=&AI<RT^9V5T4&%R
M96YT2613=')I;F<H)&]B:F5C="D["B`@("`@("`@:68@*&ES7V$H)'!A<F5N
M=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1P87)E
M;G1S.PH@("`@("`@('T*"B`@("`@("`@)')E;W)D97(@/2`D=&AI<RT^<F5O
M<F1E<B@D<&%R96YT<RP@)&]R9&5R*3L*("`@("`@("!I9B`H:7-?82@D<F5O
M<F1E<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M;W)D97(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-?82AP87)E;G0Z
M.G)E;6]V92@D;V)J96-T*2P@)U!%05)?17)R;W(G*2`_("1I9"`Z('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&]N92!O<B!M;W)E(&]B
M:F5C=',@8GD@:60N"B`@("`@*@H@("`@("H@5&AI<R!F=6YC=&EO;B!D;V5S
M("IN;W0J(&1O('1H92!V86QI9&%T:6]N+"!R96]R9&5R:6YG+"!E=&,N('1H
M870*("`@("`J(')E;6]V92@I(&1O97,N($EF('EO=2!N965D('1O(&-H96-K
M(&9O<B!C:&EL9')E;BP@<F4M9&\@;W)D97)I;F<L(&5T8RXL"B`@("`@*B!T
M:&5N('EO=2!M=7-T(')E;6]V92@I(&]B:F5C=',@;VYE+6)Y+6]N92X@5&AI
M<R!I<R!F;W(@8V]D92!T:&%T(&MN;W=S"B`@("`@*B!I="=S(&1E86QI;F<@
M=VET:"!S:6YG;&4@*&YO;BUP87)E;G1E9"D@;V)J96-T<R!A;F0@;F5E9',@
M=&\@9&5L971E(&$*("`@("`J(&)A=&-H(&]F('1H96T@<75I8VML>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ED<R`@5&AE(&]B:F5C=',@=&\@
M<F5M;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5">4ED<R@D:61S
M*0H@("`@>PH@("`@("`@("\J(%-A;FET:7IE(&EN<'5T+B`J+PH@("`@("`@
M(&EF("@A:7-?87)R87DH)&ED<RDI('L*("`@("`@("`@("`@)&ED<R`](&%R
M<F%Y*"AI;G0I)&ED<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M87)R87E?=V%L:R@D:61S+"`G:6YT=F%L)RD["B`@("`@("`@?0H*("`@("`@
M("`O*B!296UO=FEN9R!Z97)O(&]B:F5C=',@86QW87ES('-U8V-E961S+B`J
M+PH@("`@("`@(&EF("@A)&ED<RD@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"@H@("`@("`@("\J(%)E;6]V92!A='1R:6)U=&5S(&9O
M<B`D:61S+B`J+PH@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72`N"B`@("`@("`@
M("`@("`@("`@)R!72$5212!D871A=')E95]I9"!)3B`H/R<@+B!S=')?<F5P
M96%T*"<L(#\G+"!C;W5N="@D:61S*2`M(#$I("X@)RDG.PH@("`@("`@("1V
M86QU97,@/2`D:61S.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,
M(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E0GE)9',H*3H@)R`N("1Q
M=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A
M;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T871R
M965?:60@24X@*#\G("X@<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H)&ED<RD@
M+2`Q*2`N("<I)SL*("`@("`@("`D=F%L=65S(#T@)&ED<SL*"B`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ
M.G)E;6]V94)Y261S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1B
M+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5M;W9E<R!O;F4@;W(@;6]R92!O8FIE8W1S(&)Y(&YA;64N"B`@("`@
M*@H@("`@("H@5&AI<R!F=6YC=&EO;B!D;V5S("IN;W0J(&1O('1H92!V86QI
M9&%T:6]N+"!R96]R9&5R:6YG+"!E=&,N('1H870*("`@("`J(')E;6]V92@I
M(&1O97,N($EF('EO=2!N965D('1O(&-H96-K(&9O<B!C:&EL9')E;BP@<F4M
M9&\@;W)D97)I;F<L(&5T8RXL"B`@("`@*B!T:&5N('EO=2!M=7-T(')E;6]V
M92@I(&]B:F5C=',@;VYE+6)Y+6]N92X@5&AI<R!I<R!F;W(@8V]D92!T:&%T
M(&MN;W=S"B`@("`@*B!I="=S(&1E86QI;F<@=VET:"!S:6YG;&4@*&YO;BUP
M87)E;G1E9"D@;V)J96-T<R!A;F0@;F5E9',@=&\@9&5L971E(&$*("`@("`J
M(&)A=&-H(&]F('1H96T@<75I8VML>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&YA;65S("!4:&4@;V)J96-T<R!T;R!R96UO=F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')E;6]V94)Y3F%M97,H)&YA;65S*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?87)R87DH)&YA;65S*2D@>PH@("`@("`@("`@("`D;F%M
M97,@/2!A<G)A>2@D;F%M97,I.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5M
M;W9I;F<@>F5R;R!O8FIE8W1S(&%L=V%Y<R!S=6-C965D<RX@*B\*("`@("`@
M("!I9B`H(21N86UE<RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("1Q=65R>2`]("=314Q%0U0@9&%T871R965?:60@
M1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@
M("`@("`@("<@5TA%4D4@9&%T871R965?;F%M92!)3B`H/R<@+B!S=')?<F5P
M96%T*"<L(#\G+"!C;W5N="@D;F%M97,I("T@,2D@+B`G*2<["B`@("`@("`@
M)'9A;'5E<R`]("1N86UE<SL*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G)E;6]V94)Y3F%M97,H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@)&ED<R`]("1T:&ES+3Y?9&(M/F=E=$-O;"@D<75E<GDL
M(#`L("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1I9',L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I9',["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/G)E;6]V94)Y261S*"1I9',I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@36]V92!A;B!O8FIE8W0@=&\@82!N97<@<&%R
M96YT+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@)&]B:F5C="`@("`@
M5&AE(&]B:F5C="!T;R!M;W9E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W
M<&%R96YT("!4:&4@;F5W('!A<F5N="!O8FIE8W0N($1E9F%U;'1S('1O('1H
M92!R;V]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E*"1O8FIE8W0L("1N
M97=P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@("1O;&1?<&%R96YT7W!A
M=&@@/2`D=&AI<RT^9V5T4&%R96YT2613=')I;F<H)&]B:F5C="D["B`@("`@
M("`@)')E<W5L="`]('!A<F5N=#HZ;6]V92@D;V)J96-T+"`D;F5W<&%R96YT
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@
M("`D:60@/2`D=&AI<RT^9V5T260H)&]B:F5C="D["B`@("`@("`@)&YE=U]P
M87)E;G1?<&%T:"`]("1T:&ES+3YG971087)E;G1)9%-T<FEN9R@D;V)J96-T
M*3L*"B`@("`@("`@+RH@1F5T8V@@=&AE(&]B:F5C="!B96EN9R!M;W9E9"!A
M;F0@86QL(&]F(&ET<R!C:&EL9')E;BP@<VEN8V4*("`@("`@("`@*B!W92!A
M;'-O(&YE960@=&\@=7!D871E('1H96ER('!A<F5N="!P871H<R!T;R!A=F]I
M9"!C<F5A=&EN9PH@("`@("`@("`J(&]R<&AA;G,N("HO"B`@("`@("`@)'%U
M97)Y(#T@)U-%3$5#5"!D871A=')E95]I9"P@9&%T871R965?<&%R96YT<R<@
M+@H@("`@("`@("`@("`@("`@("<@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T871R965?
M<&%R96YT<R`](#\@3U(@9&%T871R965?<&%R96YT<R!,24M%(#\G("X*("`@
M("`@("`@("`@("`@("`G($]2(&1A=&%T<F5E7VED(#T@/R<["B`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*"1O;&1?<&%R96YT7W!A=&@@+B`G.B<@+B`D:60L
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O;&1?<&%R96YT7W!A=&@@+B`G
M.B<@+B`D:60@+B`G.B4G+`H@("`@("`@("`@("`@("`@("`@("`@("`H:6YT
M*21I9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@
M8GD@1&%T851R965?<W%L.CIM;W9E*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1R;W=S970@
M/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@
M(&EF("AI<U]A*"1R;W=S970L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R;W=S970["B`@("`@("`@?0H*("`@("`@("`O*B!5<&1A
M=&4@96%C:"!O8FIE8W0L(')E<&QA8VEN9R!T:&4@;VQD('!A<F5N="!P871H
M('=I=&@@=&AE"B`@("`@("`@("H@;F5W(&]N92X@*B\*("`@("`@("!W:&EL
M92`H)')O=R`]("1R;W=S970M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/
M0RDI('L*("`@("`@("`@("`@:68@*&ES7V$H)')O=RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R;W<["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1O<75E<GD@/2`G)SL*("`@("`@("`@("`@:68@
M*"1R;W=;)V1A=&%T<F5E7VED)UT@/3T@)&ED*2!["B`@("`@("`@("`@("`@
M("`D;W%U97)Y(#T@)RP@9&%T871R965?;W)D97(@/2`P("<["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($1O('-T<E]R97!L86-E*"D@;VYL>2!I
M9B!T:&ES(&ES(&YO="!A(&9I<G-T(&QE=F5L"B`@("`@("`@("`@("`J(&]B
M:F5C="X@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D<F]W6R=D871A=')E
M95]P87)E;G1S)UTI*2!["B`@("`@("`@("`@("`@("`D<'!A=&@@/2!S=')?
M<F5P;&%C92@D;VQD7W!A<F5N=%]P871H+"`D;F5W7W!A<F5N=%]P871H+"`D
M<F]W6R=D871A=')E95]P87)E;G1S)UTI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'!P871H(#T@)&YE=U]P87)E;G1?<&%T:#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=5
M4$1!5$4@)7,@4T54(&1A=&%T<F5E7W!A<F5N=',@/2`E<R<@+B`D;W%U97)Y
M("X@)R!72$5212!D871A=')E95]I9"`]("5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D<'!A
M=&@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AI;G0I)')O=ULG
M9&%T871R965?:60G72D["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ;6]V92@I.B`G("X@)'%U
M97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D;W)D97(@/2`D=&AI<RT^9V5T3W)D
M97(H)&]B:F5C="D["@H@("`@("`@("\J(%-H=69F;&4@9&]W;B!T:&4@;VQD
M(&]R9&5R('!O<VET:6]N<RX@*B\*("`@("`@("`D<F5O<F1E<B`]("1T:&ES
M+3YR96]R9&5R*"1O;&1?<&%R96YT7W!A=&@L("1O<F1E<BD["@H@("`@("`@
M("\J(%-H=69F;&4@=7`@=&AE(&YE=R!O<F1E<B!P;W-I=&EO;G,N("HO"B`@
M("`@("`@)')E;W)D97(@/2`D=&AI<RT^<F5O<F1E<B@D;F5W7W!A<F5N=%]P
M871H+"`P+"`D:60I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($-H86YG92!A;B!O8FIE8W0G<R!N86UE+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`@)&]L9%]O8FIE8W0@("`@("`@5&AE(&]L
M9"!O8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=?;V)J96-T7VYA
M;64@(%1H92!N97<@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F%M92@D;VQD7V]B:F5C="P@)&YE=U]O8FIE8W1?;F%M92D*("`@('L*
M("`@("`@("`O*B!$;R!T:&4@8V%C:&4@<F5N86UI;F<@9FER<W0@*B\*("`@
M("`@("`D<F5S=6QT(#T@<&%R96YT.CIR96YA;64H)&]L9%]O8FIE8W0L("1N
M97=?;V)J96-T7VYA;64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(&]B:F5C="!I9"!A;F0@<V5T
M('5P('1H92!S<6P@<75E<GDN("HO"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E
M=$ED*"1O;&1?;V)J96-T*3L*("`@("`@("`D<75E<GD@/2`G55!$051%("<@
M+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@
M)R!3150@9&%T871R965?;F%M92`](#\@5TA%4D4@9&%T871R965?:60@/2`_
M)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH4W1R:6YG.CIC;VYV97)T0VAA
M<G-E="@D;F5W7V]B:F5C=%]N86UE+"!.3%,Z.F=E=$-H87)S970H*2P@)'1H
M:7,M/E]P87)A;7-;)V-H87)S970G72DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("AI;G0I)&ED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-1
M3"!1=65R>2!B>2!$871A5')E95]S<6PZ.G)E;F%M92@I.B`G("X@)'%U97)Y
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S
M*3L*"B`@("`@("`@<F5T=7)N(&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2`_("1R97-U;'0@.B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F5S(&1A=&$@9F]R(&%N(&]B:F5C="!F<F]M('1H92!D871A=')E95]D
M871A(&9I96QD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@
M(%1H92!O8FIE8W0@:60@=&\@9F5T8V@L(&]R(&%N(&%R<F%Y(&]F(&]B:F5C
M="!I9',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A=&$H)&-I9"D*("`@
M('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<FEA;&EZ92YP:'`G
M.PH*("`@("`@("!I9B`H:7-?87)R87DH)&-I9"DI('L*("`@("`@("`@("`@
M:68@*"%C;W5N="@D8VED*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1Q=65R>2`]('-P
M<FEN=&8H)U-%3$5#5"!D871A=')E95]I9"P@9&%T871R965?9&%T82P@9&%T
M871R965?<V5R:6%L:7IE9"!&4D]-("5S(%=(15)%(&1A=&%T<F5E7VED($E.
M("@E<RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EM<&QO9&4H)RP@)RP@)&-I9"DI.PH*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$1A=&$H
M*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YG971!
M<W-O8R@D<75E<GDI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@I.PH@("`@("`@("`@
M("!F;W)E86-H("@D<F5S=6QT(&%S("1I9"`]/B`D<F]W*2!["B`@("`@("`@
M("`@("`@("`D9&%T85LD:61=(#T@2&]R9&5?4V5R:6%L:7IE.CIU;G-E<FEA
M;&EZ92@D<F]W6S!=+"`D<F]W6S%=+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3DQ3.CIG971#
M:&%R<V5T*"DI.PH@("`@("`@("`@("`@("`@+RH@0V]N=F5R="!O;&0@9&%T
M82!T;R!T:&4@;F5W(&9O<FUA="X@*B\*("`@("`@("`@("`@("`@(&EF("@D
M<F]W6S%=(#T](%-%4DE!3$E:15]"05-)0RD@>PH@("`@("`@("`@("`@("`@
M("`@("1D871A6R1I9%T@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D871A
M6R1I9%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@3DQ3.CIG971#:&%R<V5T*'1R=64I*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D9&%T85LD:61=(#T@
M*&ES7VYU;&PH)&1A=&%;)&ED72D@?'P@(6ES7V%R<F%Y*"1D871A6R1I9%TI
M*0H@("`@("`@("`@("`@("`@("`@(#\@87)R87DH*0H@("`@("`@("`@("`@
M("`@("`@(#H@)&1A=&%;)&ED73L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@<F5T=7)N("1D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1Q=65R>2`]("=314Q%0U0@9&%T871R965?9&%T82P@9&%T871R965?<V5R
M:6%L:7IE9"<@+@H@("`@("`@("`@("`@("`@("`@("`G($923TT@)R`N("1T
M:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`@("`@
M)R!72$5212!D871A=')E95]I9"`](#\G.PH@("`@("`@("`@("`D=F%L=65S
M(#T@87)R87DH*&EN="DD8VED*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIG971$871A*"DZ
M("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH@("`@("`@("`@("`D<F]W(#T@)'1H:7,M/E]D8BT^9V5T4F]W*"1Q
M=65R>2P@)'9A;'5E<RP@1$)?1D540TA-3T1%7T%34T]#*3L*"B`@("`@("`@
M("`@("1D871A(#T@2&]R9&5?4V5R:6%L:7IE.CIU;G-E<FEA;&EZ92@D<F]W
M6R=D871A=')E95]D871A)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<F]W6R=D871A=')E95]S97)I86QI
M>F5D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@("\J
M($-O;G9E<G0@;VQD(&1A=&$@=&\@=&AE(&YE=R!F;W)M870N("HO"B`@("`@
M("`@("`@(&EF("@D<F]W6R=D871A=')E95]S97)I86QI>F5D)UT@/3T@4T52
M24%,25I%7T)!4TE#*2!["B`@("`@("`@("`@("`@("`D9&%T82`](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)&1A=&$L($Y,4SHZ9V5T0VAA<G-E="AT<G5E
M*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("AI<U]N=6QL
M*"1D871A*2!\?"`A:7-?87)R87DH)&1A=&$I*2`_(&%R<F%Y*"D@.B`D9&%T
M83L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@
M9&%T82!F;W(@86X@;V)J96-T(&9R;VT@=&AE(&AO<F1E7V1A=&%T<F5E7V%T
M=')I8G5T97,@=&%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97)\
M87)R87D@)&-I9"`@5&AE(&]B:F5C="!I9"!T;R!F971C:"P@;W(@86X@87)R
M87D@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C
M="!I9',N"B`@("`@*B!`<&%R86T@87)R87D@)&ME>7,@("`@("`@("!4:&4@
M871T<FEB=71E<R!K97ES('1O(&9E=&-H+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($$@:&%S:"!O9B!A='1R:6)U=&5S+"!O<B!A(&UU;'1I+6QE
M=F5L(&AA<V@@;V8@;V)J96-T"B`@("`@*B`@("`@("`@("`@("`@("!I9',@
M/3X@=&AE:7(@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M071T<FEB=71E<R@D8VED+"`D:V5Y<R`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D8VED*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D:V5Y<RD@>PH@("`@("`@("`@
M("`D9FEL=&5R(#T@<W!R:6YT9B@G($%.1"!A='1R:6)U=&5?:V5Y($E.("A<
M)R5S7"<I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D
M92@B)RP@)R(L("1K97ES*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&9I;'1E<B`]("<G.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1C:60I*2!["B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%
M3$5#5"!D871A=')E95]I9"P@871T<FEB=71E7VYA;64@05,@;F%M92P@871T
M<FEB=71E7VME>2!!4R`B:V5Y(BP@871T<FEB=71E7W9A;'5E($%3('9A;'5E
M($923TT@)7,@5TA%4D4@9&%T871R965?:60@24X@*"5S*25S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&5?
M871T<FEB=71E<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM
M<&QO9&4H)RP@)RP@)&-I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9I;'1E<BD["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ9V5T071T<FEB=71E<R@I.B`G
M("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("`@("`@)')O=W,@/2`D=&AI<RT^7V1B+3YG971!;&PH)'%U
M97)Y+"!$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F]W<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R;W=S.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9&%T82`]
M(&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1R;W=S(&%S("1R;W<I
M('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D9&%T85LD<F]W6R=D871A
M=')E95]I9"==72DI('L*("`@("`@("`@("`@("`@("`@("`D9&%T85LD<F]W
M6R=D871A=')E95]I9"==72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D9&%T85LD<F]W6R=D871A=')E95]I9"==75M=
M(#T@87)R87DH)VYA;64G(#T^("1R;W=;)VYA;64G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:V5Y
M)R`]/B`D<F]W6R=K97DG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G(#T^(%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)')O=ULG=F%L=64G72P@)'1H:7,M/E]P87)A;7-;
M)V-H87)S970G72P@3DQ3.CIG971#:&%R<V5T*"DI*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4(&%T=')I8G5T
M95]N86UE($%3(&YA;64L(&%T=')I8G5T95]K97D@05,@(FME>2(L(&%T=')I
M8G5T95]V86QU92!!4R!V86QU92!&4D]-("5S(%=(15)%(&1A=&%T<F5E7VED
M(#T@)7,E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`H:6YT*21C:60L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I;'1E<BD["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ9V5T071T<FEB=71E
M<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*("`@("`@("`@("`@)')O=W,@/2`D=&AI<RT^7V1B+3YG971!
M;&PH)'%U97)Y+"!$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<F]W<RD[("1I*RLI('L*("`@("`@
M("`@("`@("`@("1R;W=S6R1I75LG=F%L=64G72`](%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H)')O=W-;)&E=6R=V86QU92==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!.3%,Z
M.F=E=$-H87)S970H*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("1R;W=S.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&YU;6)E<B!O9B!O8FIE8W1S(&UA=&-H:6YG(&$@<V5T(&]F
M(&%T=')I8G5T92!C<FET97)I82X*("`@("`J"B`@("`@*B!`<V5E(&)U:6QD
M071T<FEB=71E475E<GDH*0H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@
M("1C<FET97)I82`@(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@("`J($!P
M87)A;2!S=')I;F<@("1P87)E;G0@("`@(%1H92!P87)E;G0@;F]D92!T;R!S
M=&%R="!S96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L96%N("1A
M;&Q,979E;',@(%)E='5R;B!A;&P@;&5V96QS+"!O<B!J=7-T('1H92!D:7)E
M8W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N
M(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L;"!L979E;',N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<F5S=')I8W0@("!/;FQY(')E='5R;B!A='1R:6)U
M=&5S('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%T=')I8G5T95]N86UE(&]R(&%T=')I8G5T95]I9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]U;G1">4%T=')I8G5T97,H)&-R:71E<FEA+"`D
M<&%R96YT(#T@1$%40512145?4D]/5"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A;&Q,979E;',@/2!T<G5E+"`D<F5S=')I8W0@/2`G;F%M
M92<I"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D8W)I=&5R:6$I*2!["B`@
M("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@;&ES="@D
M<75E<GDL("1V86QU97,I(#T@)'1H:7,M/F)U:6QD071T<FEB=71E475E<GDH
M)&-R:71E<FEA+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%L;$QE=F5L<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=')I8W0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@1$%40512145?0E5)3$1?0T]53E0I.PH*("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ8V]U
M;G1">4%T=')I8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"B`@("`@("`@)')O=R`]("8D<F5S=6QT+3YF971C:%)O=R@I.PH@
M("`@("`@(&EF("AI<U]A*"1R;W<L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')O=RP@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)')O=SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F]W6S!=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A('-E="!O9B!O8FIE8W0@:61S(&)A<V5D
M(&]N(&$@<V5T(&]F(&%T=')I8G5T92!C<FET97)I82X*("`@("`J"B`@("`@
M*B!`<V5E(&)U:6QD071T<FEB=71E475E<GDH*0H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`@("1C<FET97)I82`@("`@5&AE(&%R<F%Y(&]F(&-R:71E
M<FEA+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("`@("!4:&4@
M<&%R96YT(&YO9&4@=&\@<W1A<G0@<V5A<F-H:6YG(&9R;VTN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("`@(%)E='5R;B!A;&P@;&5V96QS
M+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@
M86QL(&QE=F5L<RX*("`@("`J($!P87)A;2!S=')I;F<@("1R97-T<FEC="`@
M("`@3VYL>2!R971U<FX@871T<FEB=71E<R!W:71H('1H92!S86UE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%T=')I8G5T95]N86UE
M(&]R(&%T=')I8G5T95]I9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1F<F]M
M("`@("`@("`@5&AE(&]B:F5C="!T;R!S=&%R="!T;R!F971C:&EN9PH@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&-O=6YT("`@("`@("!4:&4@;G5M8F5R(&]F
M(&]B:F5C=',@=&\@9F5T8V@*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T
M8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@("!!='1R:6)U=&4@
M:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)Y071T<FEB=71E<R@D8W)I=&5R
M:6$L("1P87)E;G0@/2!$051!5%)%15]23T]4+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1A;&Q,979E;',@/2!T<G5E+"`D<F5S=')I8W0@/2`G
M;F%M92<L("1F<F]M(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]U;G0@/2`P+"`D<V]R=&)Y7VYA;64@/2!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C
M=&EO;B`](#`I"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D8W)I=&5R:6$I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;R!C
M<FET97)I82<I.PH@("`@("`@('T*"B`@("`@("`@;&ES="@D<75E<GDL("1V
M86QU97,I(#T@)'1H:7,M/F)U:6QD071T<FEB=71E475E<GDH)&-R:71E<FEA
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)E;G0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L;$QE
M=F5L<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5S=')I8W0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1$%40512145?0E5)3$1?4T5,14-4+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VME>2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&ER96-T:6]N*3L*"B`@("`@("`@:68@*"1C;W5N="D@>PH@("`@("`@
M("`@("`D<75E<GD@/2`D=&AI<RT^7V1B+3YM;V1I9GE,:6UI=%%U97)Y*"1Q
M=65R>2P@)&9R;VTL("1C;W5N="D["B`@("`@("`@("`@(&EF("AI<U]A*"1Q
M=65R>2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1Q=65R>3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E
M=$)Y071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*("`@("`@("`D<F]W<R`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@
M*"1R;W<@/2`F)')E<W5L="T^9F5T8VA2;W<H*2D@>PH@("`@("`@("`@("`D
M<F]W<ULD<F]W6S!=72`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)')O=ULQ
M72P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)')O=W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T
M<R!)1',@8GD@871T<FEB=71E('9A;'5E<RX@241S('=I=&AO=70@871T<FEB
M=71E<R!W:6QL(&)E(&%D9&5D('1O"B`@("`@*B!T:&4@96YD(&]F('1H92!S
M;W)T960@;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'5N;W)D
M97)E9%]I9',@($%R<F%Y(&]F(&ED<R!T;R!S;W)T+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1S;W)T8GE?;F%M92`@("!!='1R:6)U=&4@;F%M92!T;R!U<V4@
M9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)'-O<G1B>5]K97D@
M("`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1D:7)E8W1I;VX@("`@("!3;W)T(&1I<F5C=&EO;CH*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C
M96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!3
M;W)T960@:61S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T0GE!='1R:6)U
M=&5S*"1U;F]R9&5R961?:61S+"`D<V]R=&)Y7VYA;64@/2!N=6QL+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VME>2`](&YU;&PL
M("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("\J(%-E;&5C="!I9',@
M;W)D97)E9"!B>2!A='1R:6)U=&4@=F%L=64N("HO"B`@("`@("`@)'=H97)E
M(#T@)R<["B`@("`@("`@:68@*"%I<U]N=6QL*"1S;W)T8GE?;F%M92DI('L*
M("`@("`@("`@("`@)'=H97)E(#T@<W!R:6YT9B@G($%.1"!A='1R:6)U=&5?
M;F%M92`]("5S("<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D8BT^<75O=&4H)'-O<G1B>5]N86UE*2D["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VME>2DI('L*("`@("`@("`@("`@
M)'=H97)E(#T@<W!R:6YT9B@G)7,@04Y$(&%T=')I8G5T95]K97D@/2`E<R`G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W:&5R92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D<V]R
M=&)Y7VME>2DI.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G4T5,14-4(&1A=&%T<F5E7VED($923TT@)7,@5TA%4D4@9&%T871R965?
M:60@24X@*"5S*2`E<R!/4D1%4B!"62!A='1R:6)U=&5?=F%L=64@)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M7V%T=')I8G5T97,G72P*("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO
M9&4H)RPG+"`D=6YO<F1E<F5D7VED<RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=VAE<F4L"B`@("`@("`@("`@("`@("`@("`@("`@("`H)&1I<F5C
M=&EO;B`]/2`Q*2`_("=$15-#)R`Z("=!4T,G*3L*"B`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G-O<G1"
M>4%T=')I8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)&]R9&5R961?:61S(#T@)'1H
M:7,M/E]D8BT^9V5T0V]L*"1Q=65R>2D["@H@("`@("`@("\J($UA:V4@<W5R
M92!T:&%T('-O;64@:61S(&1I9&XG="!G970@;&]S="!B96-A=7-E(&AA<R!N
M;R!S=6-H"B`@("`@("`@("H@871T<FEB=71E(&YA;64O:V5Y+B!!<'!E;F0@
M=&AE;2!T;R!T:&4@96YD+B`J+PH@("`@("`@(&EF("AC;W5N="@D;W)D97)E
M9%]I9',I("$](&-O=6YT*"1U;F]R9&5R961?:61S*2D@>PH@("`@("`@("`@
M("`D;W)D97)E9%]I9',@/2!A<G)A>5]U;FEQ=64H87)R87E?;65R9V4H)&]R
M9&5R961?:61S+"`D=6YO<F1E<F5D7VED<RDI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1O<F1E<F5D7VED<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!L:7-T(&]F(&%L;"!O9B!T:&4@879A:6QA8FQE('9A;'5E
M<R!O9B!T:&4@9VEV96X@871T<FEB=71E"B`@("`@*B!N86UE+VME>2!C;VUB
M:6YA=&EO;BX@16ET:&5R(&%T=')I8G5T95]N86UE(&]R(&%T=')I8G5T95]K
M97D@35535"!B90H@("`@("H@<W5P<&QI960L(&%N9"!B;W1H($U!62!B92!S
M=7!P;&EE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D871T<FEB
M=71E7VYA;64@(%1H92!N86UE(&]F('1H92!A='1R:6)U=&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D871T<FEB=71E7VME>2`@(%1H92!K97D@=F%L=64@
M;V8@=&AE(&%T=')I8G5T92X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E
M;G0@("`@("`@("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN
M9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@("`@
M("!2971U<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F
M("1P87)E;G0_($1E9F%U;'1S('1O(&%L;`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!L979E;',N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL(&]F('1H92!A=F%I;&%B;&4@
M=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&5686QU
M97,H)&%T=')I8G5T95]N86UE(#T@;G5L;"P@)&%T=')I8G5T95]K97D@/2!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0@
M/2!$051!5%)%15]23T]4+"`D86QL3&5V96QS(#T@=')U92D*("`@('L*("`@
M("`@("`O+R!"=6EL9"!T:&4@;F%M92]K97D@9FEL=&5R+@H@("`@("`@("1W
M:&5R92`]("<G.PH@("`@("`@(&EF("@A:7-?;G5L;"@D871T<FEB=71E7VYA
M;64I*2!["B`@("`@("`@("`@("1W:&5R92`N/2`G82YA='1R:6)U=&5?;F%M
M92`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D871T<FEB=71E7VYA;64I.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)&%T=')I8G5T95]K97DI
M*2!["B`@("`@("`@("`@(&EF("@D=VAE<F4I('L*("`@("`@("`@("`@("`@
M("1W:&5R92`N/2`G($%.1"`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1W:&5R92`N/2`G82YA='1R:6)U=&5?:V5Y(#T@)R`N("1T:&ES+3Y?9&(M
M/G%U;W1E*"1A='1R:6)U=&5?:V5Y*3L*("`@("`@("!]"@H@("`@("`@("\O
M(%)E='5R;B!I9B!W92!H879E(&YO(&-R:71E<FEA+@H@("`@("`@(&EF("@A
M)'=H97)E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=N;R!C<FET97)I82<I.PH@("`@("`@('T*"B`@("`@("`@+R\@061D(&9I
M;'1E<FEN9R!B>2!P87)E;G0L(&%N9"!F;W(@;VYE(&]R(&%L;"!L979E;',N
M"B`@("`@("`@)&QE=F5L475E<GD@/2`G)SL*("`@("`@("!I9B`H)'!A<F5N
M="`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@("1P87)T<R`](&5X
M<&QO9&4H)SHG+"`D<&%R96YT*3L*("`@("`@("`@("`@)'!A<F5N=',@/2`G
M)SL*("`@("`@("`@("`@)'!S=')I;F<@/2`G)SL*("`@("`@("`@("`@9F]R
M96%C:"`H)'!A<G1S(&%S("1P87)T*2!["B`@("`@("`@("`@("`@("`D<'-T
M<FEN9R`N/2`H96UP='DH)'!S=')I;F<I(#\@)R<@.B`G.B<I("X@)'!A<G0[
M"B`@("`@("`@("`@("`@("`D<&ED(#T@)'1H:7,M/F=E=$ED*"1P<W1R:6YG
M*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!I9#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P87)E;G1S("X]("<Z)R`N
M("1P:60["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D86QL3&5V
M96QS*2!["B`@("`@("`@("`@("`@("`D;&5V96Q1=65R>2`]('-P<FEN=&8H
M)T%.1"`H9&%T871R965?<&%R96YT<R`]("5S($]2(&1A=&%T<F5E7W!A<F5N
M=',@3$E+12`E<RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1P87)E;G1S*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T
M92@D<&%R96YT<R`N("<Z)2<I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1L979E;%%U97)Y(#T@<W!R:6YT9B@G04Y$(&1A=&%T
M<F5E7W!A<F5N=',@/2`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)'!A<F5N=',I*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@A)&%L;$QE=F5L<RD@>PH@
M("`@("`@("`@("`D;&5V96Q1=65R>2`](")!3D0@9&%T871R965?<&%R96YT
M<R`]("<G(CL*("`@("`@("!]"@H@("`@("`@("\O($)U:6QD('1H92!&4D]-
M+TI/24X@8VQA=7-E<RX*("`@("`@("`D:F]I;G,@/2`G3$5&5"!*3TE.("<@
M+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("<@8R!/
M3B!A+F1A=&%T<F5E7VED(#T@8RYD871A=')E95]I9"<["@H@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)U-%3$5#5"!$25-424Y#5"!A+F%T=')I8G5T95]V
M86QU92!&4D]-("5S(&$@)7,@5TA%4D4@8RYG<F]U<%]U:60@/2`E<R!!3D0@
M)7,@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE7V%T=')I8G5T97,G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1J;VEN<RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&(M/G%U;W1E*"1T:&ES+3Y?<&%R86US6R=G<F]U<"==*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1W:&5R92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1L979E;%%U97)Y*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$%T=')I8G5T959A;'5E
M<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@)')O=W,@/2`D=&AI<RT^7V1B+3YG971#;VPH
M)'%U97)Y*3L*("`@("`@("!I9B`H:7-?82@D<F]W<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F]W<RP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R;W=S.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I
M;&1S(&%N(&%T=')I8G5T92!Q=65R>2X@2&5R92!I<R!A;B!E>&%M<&QE("1C
M<FET97)I82!A<G)A>3H*("`@("`J"B`@("`@*B`\8V]D93X*("`@("`J("1C
M<FET97)I85LG3U(G72`](&%R<F%Y*`H@("`@("H@("`@(&%R<F%Y*"=!3D0G
M(#T^(&%R<F%Y*`H@("`@("H@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N
M86UE)RP*("`@("`J("`@("`@("`@("`@("`@)V]P)R`@("`]/B`G/2<L"B`@
M("`@*B`@("`@("`@("`@("`@("=T97-T)R`@/3X@)V9O;R<I+`H@("`@("H@
M("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=K97DG+`H@("`@("H@("`@("`@
M("`@("`@("`G;W`G("`@(#T^("<])RP*("`@("`J("`@("`@("`@("`@("`@
M)W1E<W0G("`]/B`G86)C)RDI*2P*("`@("`J("`@("`@("`@87)R87DH)T%.
M1"<@/3X@87)R87DH"B`@("`@*B`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G
M(#T^("=N86UE)RP*("`@("`J("`@("`@("`@("`@("`@("`@("=O<"<@("`@
M/3X@)STG+`H@("`@("H@("`@("`@("`@("`@("`@("`@)W1E<W0G("`]/B`G
M8F%R)RDL"B`@("`@*B`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=K
M97DG+`H@("`@("H@("`@("`@("`@("`@("`@("`@)V]P)R`@("`]/B`G/2<L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`G=&5S="<@(#T^("=X>7HG*2DI
M*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!4:&ES('=O=6QD(&9E
M=&-H(&%L;"!O8FIE8W0@:61S('=H97)E(&%T=')I8G5T92!N86UE(&ES(")F
M;V\B($%.1"!K97D*("`@("`J(&ES(")A8F,B+"!/4B`B8F%R(B!!3D0@(GAY
M>B(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&-R:71E<FEA("`@
M("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D<&%R96YT("`@("`@(%1H92!P87)E;G0@;F]D92!T;R!S=&%R="!S96%R
M8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&Q,979E;',@
M("`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&EL9')E;B!O9B`D
M<&%R96YT/R!$969A=6QT<R!T;R!A;&P@;&5V96QS+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)')E<W1R:6-T("`@("!/;FQY(')E='5R;B!A='1R:6)U=&5S
M('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@871T<FEB=71E7VYA;64@;W(@871T<FEB=71E7VED+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&]P97)A=&EO;B`@("!4>7!E(&]F('%U97)Y('1O
M(&)U:6QD"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA;64@($%T
M=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A
M;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U<V4@
M9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N
M("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(%-13"!Q=65R>2!A;F0@82!L:7-T(&]F
M('9A;'5E<R!S=6ET86)L92!F;W(@8FEN9&EN9PH@("`@("H@("`@("`@("`@
M("`@("`@87,@86X@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD
M071T<FEB=71E475E<GDH)&-R:71E<FEA+"`D<&%R96YT(#T@1$%40512145?
M4D]/5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L;$QE
M=F5L<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&]P97)A=&EO;B`]($1!5$%44D5%7T)5
M24Q$7U-%3$5#5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER96-T:6]N(#T@,"D*
M("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1C<FET97)I82DI('L*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"<G+"!A<G)A>2@I*3L*("`@("`@("!]"@H@
M("`@("`@("\J($)U:6QD('1H92!Q=65R>2X@*B\*("`@("`@("`D=&AI<RT^
M7W1A8FQE0V]U;G0@/2`Q.PH@("`@("`@("1Q=65R>2`]("<G.PH@("`@("`@
M("1V86QU97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C<FET97)I
M82!A<R`D:V5Y(#T^("1V86QS*2!["B`@("`@("`@("`@(&EF("@D:V5Y(#T]
M("=/4B<@?'P@)&ME>2`]/2`G04Y$)RD@>PH@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D<75E<GDI*2!["B`@("`@("`@("`@("`@("`@("`@)'%U97)Y
M("X]("<@)R`N("1K97D@+B`G("<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D8FEN9',@/2`D=&AI<RT^7V)U:6QD071T<FEB=71E475E
M<GDH)&ME>2P@)'9A;',I.PH@("`@("`@("`@("`@("`@)'%U97)Y("X]("<H
M)R`N("1B:6YD<ULP72`N("<I)SL*("`@("`@("`@("`@("`@("1V86QU97,@
M*ST@)&)I;F1S6S%=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!!9&0@9FEL=&5R:6YG(&)Y('!A<F5N="P@86YD(&9O<B!O;F4@;W(@
M86QL(&QE=F5L<RX*("`@("`@("`D;&5V96Q1=65R>2`]("<G.PH@("`@("`@
M("1L979E;%9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1P87)E;G0@
M(3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`D<&%R=',@/2!E>'!L
M;V1E*"<Z)RP@)'!A<F5N="D["B`@("`@("`@("`@("1P87)E;G1S(#T@)R<[
M"B`@("`@("`@("`@("1P<W1R:6YG(#T@)R<["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1P87)T<R!A<R`D<&%R="D@>PH@("`@("`@("`@("`@("`@)'!S=')I
M;F<@+CT@*&5M<'1Y*"1P<W1R:6YG*2`_("<G(#H@)SHG*2`N("1P87)T.PH@
M("`@("`@("`@("`@("`@)'!I9"`]("1T:&ES+3YG971)9"@D<'-T<FEN9RD[
M"B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1P:60["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<&%R96YT<R`N/2`G.B<@+B`D
M<&ED.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&%L;$QE=F5L
M<RD@>PH@("`@("`@("`@("`@("`@)&QE=F5L475E<GD@/2`G04Y$("AD871A
M=')E95]P87)E;G1S(#T@/R!/4B!D871A=')E95]P87)E;G1S($Q)2T4@/RDG
M.PH@("`@("`@("`@("`@("`@)&QE=F5L5F%L=65S(#T@87)R87DH)'!A<F5N
M=',L("1P87)E;G1S("X@)SHE)RD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;&5V96Q1=65R>2`]("=!3D0@9&%T871R965?<&%R
M96YT<R`](#\G.PH@("`@("`@("`@("`@("`@)&QE=F5L5F%L=65S(#T@87)R
M87DH)'!A<F5N=',I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@
M*"$D86QL3&5V96QS*2!["B`@("`@("`@("`@("1L979E;%%U97)Y(#T@(D%.
M1"!D871A=')E95]P87)E;G1S(#T@)R<B.PH@("`@("`@('T*"B`@("`@("`@
M+R\@0G5I;&0@=&AE($923TTO2D])3B!C;&%U<V5S+@H@("`@("`@("1J;VEN
M<R`](&%R<F%Y*"D["B`@("`@("`@)'!A:7)S(#T@87)R87DH*3L*("`@("`@
M("!F;W(@*"1I(#T@,3L@)&D@/#T@)'1H:7,M/E]T86)L94-O=6YT.R`D:2LK
M*2!["B`@("`@("`@("`@("1J;VEN<UM=(#T@)TQ%1E0@2D])3B`G("X@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72`N"B`@("`@("`@("`@
M("`@("`G(&$G("X@)&D@+B`G($].(&$G("X@)&D@+B`G+F1A=&%T<F5E7VED
M(#T@8RYD871A=')E95]I9"<["@H@("`@("`@("`@("!I9B`H)&D@(3T@,2D@
M>PH@("`@("`@("`@("`@("`@:68@*"1R97-T<FEC="`]/2`G;F%M92<I('L*
M("`@("`@("`@("`@("`@("`@("`D<&%I<G-;72`]("=!3D0@83$N871T<FEB
M=71E7VYA;64@/2!A)R`N("1I("X@)RYA='1R:6)U=&5?;F%M92<["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)')E<W1R:6-T(#T]("=I9"<I('L*("`@
M("`@("`@("`@("`@("`@("`D<&%I<G-;72`]("=!3D0@83$N9&%T871R965?
M:60@/2!A)R`N("1I("X@)RYD871A=')E95]I9"<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($]V97)R
M:61E('-O<G1I;F<N"B`@("`@("`@)'-O<G0@/2!A<G)A>2@I.PH@("`@("`@
M(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VYA;64I('Q\("%I<U]N=6QL*"1S;W)T
M8GE?:V5Y*2D@>PH@("`@("`@("`@("`D;W)D97)?=&%B;&4@/2`G82<@+B`D
M:3L*("`@("`@("`@("`@)&IO:6YS6UT@/2`G3$5&5"!*3TE.("<@+B`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&5?871T<FEB=71E<R==("X*("`@("`@("`@("`@
M("`@("<@)R`N("1O<F1E<E]T86)L92`N("<@3TX@)R`N("1O<F1E<E]T86)L
M92`N"B`@("`@("`@("`@("`@("`G+F1A=&%T<F5E7VED(#T@8RYD871A=')E
M95]I9"<["@H@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)'-O<G1B>5]N86UE
M*2D@>PH@("`@("`@("`@("`@("`@)'!A:7)S6UT@/2!S<')I;G1F*"=!3D0@
M)7,N871T<FEB=71E7VYA;64@/2`_("<L("1O<F1E<E]T86)L92D["B`@("`@
M("`@("`@("`@("`D<V]R=%M=(#T@)'-O<G1B>5]N86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VME>2DI('L*
M("`@("`@("`@("`@("`@("1P86ER<UM=(#T@<W!R:6YT9B@G04Y$("5S+F%T
M=')I8G5T95]K97D@/2`_("<L("1O<F1E<E]T86)L92D["B`@("`@("`@("`@
M("`@("`D<V]R=%M=(#T@)'-O<G1B>5]K97D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1O<F1E<B`]('-P<FEN=&8H)R5S+F%T=')I8G5T95]V86QU
M92`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]R9&5R7W1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D9&ER96-T:6]N
M(#T](#$I(#\@)T1%4T,G(#H@)T%30R<I.PH@("`@("`@("`@("`D9W)O=7!?
M8GD@/2`G8RYD871A=')E95]I9"P@8RYD871A=')E95]N86UE+"!C+F1A=&%T
M<F5E7V]R9&5R+"`G("X*("`@("`@("`@("`@("`@("1O<F1E<E]T86)L92`N
M("<N871T<FEB=71E7W9A;'5E)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;W)D97(@/2`G8RYD871A=')E95]O<F1E<BP@8RYD871A=')E95]N
M86UE+"!C+F1A=&%T<F5E7VED)SL*("`@("`@("`@("`@)&=R;W5P7V)Y(#T@
M)V,N9&%T871R965?:60L(&,N9&%T871R965?;F%M92P@8RYD871A=')E95]O
M<F1E<B<["B`@("`@("`@?0H*("`@("`@("`D:F]I;G,@/2!I;7!L;V1E*"<@
M)RP@)&IO:6YS*3L*("`@("`@("`D<&%I<G,@/2!I;7!L;V1E*"<@)RP@)'!A
M:7)S*3L*("`@("`@("`D=&%I;"`]('-P<FEN=&8H)T=23U50($)9("5S($]2
M1$52($)9("5S)RP@)&=R;W5P7V)Y+"`D;W)D97(I.PH*("`@("`@("!S=VET
M8V@@*"1O<&5R871I;VXI('L*("`@("`@("!C87-E($1!5$%44D5%7T)524Q$
M7T-/54Y4.@H@("`@("`@("`@("`D=VAA="`]("=#3U5.5"A$25-424Y#5"!C
M+F1A=&%T<F5E7VED*2<["B`@("`@("`@("`@("1T86EL(#T@)R<["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D
M=VAA="`]("=C+F1A=&%T<F5E7VED+"!C+F1A=&%T<F5E7VYA;64G.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A
M>2AS<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!C("5S(%=(15)%(&,N9W)O
M=7!?=6ED(#T@/R!!3D0@)7,@)7,@)7,@)7,G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1W:&%T+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1J;VEN<RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<75E<GDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QE
M=F5L475E<GDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A:7)S
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T86EL*2P*("`@("`@
M("`@("`@("`@("`@("`@87)R87E?;65R9V4H87)R87DH)'1H:7,M/E]P87)A
M;7-;)V=R;W5P)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%L=65S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;&5V96Q686QU97,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S;W)T*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!P:65C
M92!O9B!A;B!A='1R:6)U=&4@<75E<GDN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9VQU92`@("`@5&AE(&=L=64@=&\@:F]I;B!T:&4@8W)I=&5R
M:6$@*$]2+T%.1"DN"B`@("`@*B!`<&%R86T@87)R87D@)&-R:71E<FEA("!4
M:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M:F]I;B`@("!3:&]U;&0@=V4@:F]I;B!O;B!A(&-L96%N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M('1A8FQE/R!$969A=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@9F%L<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M4U%,(&9R86=M96YT(&%N9"!A(&QI<W0@;V8@=F%L=65S('-U:71A8FQE(&9O
M<B!B:6YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("!A<R!A;B!A<G)A>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD071T<FEB=71E475E<GDH)&=L
M=64L("1C<FET97)I82P@)&IO:6X@/2!F86QS92D*("`@('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+U-13"YP:'`G.PH*("`@("`@("`O+R!);FET
M:6%L:7IE('1H92!C;&%U<V4@=&AA="!W92=R92!B=6EL9&EN9RX*("`@("`@
M("`D8VQA=7-E(#T@)R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["@H@
M("`@("`@("\O($=E="!T:&4@=&%B;&4@86QI87,@=&\@=7-E(&9O<B!T:&ES
M('-E="!O9B!C<FET97)I82X*("`@("`@("`D86QI87,@/2`D=&AI<RT^7V=E
M=$%L:6%S*"1J;VEN*3L*"B`@("`@("`@9F]R96%C:"`H)&-R:71E<FEA(&%S
M("1K97D@/3X@)'9A;',I('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D8VQA
M=7-E*2D@>PH@("`@("`@("`@("`@("`@)&-L875S92`N/2`G("<@+B`D9VQU
M92`N("<@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1V86QS6R=/4B==*2!\?"`A96UP='DH)'9A;'-;)T%.1"==*2D@>PH@("`@
M("`@("`@("`@("`@)&)I;F1S(#T@)'1H:7,M/E]B=6EL9$%T=')I8G5T95%U
M97)Y*"1G;'5E+"`D=F%L<RD["B`@("`@("`@("`@("`@("`D8VQA=7-E("X]
M("<H)R`N("1B:6YD<ULP72`N("<I)SL*("`@("`@("`@("`@("`@("1V86QU
M97,@/2!A<G)A>5]M97)G92@D=F%L=65S+"`D8FEN9'-;,5TI.PH@("`@("`@
M("`@("!](&5L<V5I9B`H(65M<'1Y*"1V86QS6R=*3TE.)UTI*2!["B`@("`@
M("`@("`@("`@("`D8FEN9',@/2`D=&AI<RT^7V)U:6QD071T<FEB=71E475E
M<GDH)&=L=64L("1V86QS6R=*3TE.)UTL('1R=64I.PH@("`@("`@("`@("`@
M("`@)&-L875S92`N/2`D8FEN9'-;,%T["B`@("`@("`@("`@("`@("`D=F%L
M=65S(#T@87)R87E?;65R9V4H)'9A;'5E<RP@)&)I;F1S6S%=*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L
M<ULG9FEE;&0G72DI('L*("`@("`@("`@("`@("`@("`@("`D8FEN9',@/2!(
M;W)D95]344PZ.F)U:6QD0VQA=7-E*"1T:&ES+3Y?9&(L("1A;&EA<R`N("<N
M871T<FEB=71E7R<@+B`D=F%L<ULG9FEE;&0G72P@)'9A;'-;)V]P)UTL("1V
M86QS6R=T97-T)UTL('1R=64I.PH@("`@("`@("`@("`@("`@("`@("1C;&%U
M<V4@+CT@)&)I;F1S6S!=.PH@("`@("`@("`@("`@("`@("`@("1V86QU97,@
M/2!A<G)A>5]M97)G92@D=F%L=65S+"`D8FEN9'-;,5TI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D8FEN9',@/2`D
M=&AI<RT^7V)U:6QD071T<FEB=71E475E<GDH)&ME>2P@)'9A;',I.PH@("`@
M("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)&)I;F1S6S!=.PH@("`@("`@
M("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>5]M97)G92@D=F%L=65S+"`D
M8FEN9'-;,5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)&-L875S92P@)'9A;'5E
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@86X@86QI87,@=&\@:&]R
M9&5?9&%T871R965?871T<FEB=71E<RP@:6YC<F5M96YT:6YG(&ET(&EF"B`@
M("`@*B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&EN8W)E;65N="`@26YC<F5M96YT('1H92!A;&EA<R!C;W5N=#\@1&5F875L
M=',@=&\@;F\N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971!;&EA<R@D:6YC
M<F5M96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC("1S965N(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*"1I;F-R96UE;G0@)B8@(65M<'1Y*"1S
M965N6R1T:&ES+3Y?=&%B;&5#;W5N=%TI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?=&%B;&5#;W5N="LK.PH@("`@("`@('T*"B`@("`@("`@)'-E96Y;)'1H
M:7,M/E]T86)L94-O=6YT72`]('1R=64["B`@("`@("`@<F5T=7)N("=A)R`N
M("1T:&ES+3Y?=&%B;&5#;W5N=#L*("`@('T*"B`@("`O*BH*("`@("`J(%5P
M9&%T92!T:&4@9&%T82!I;B!A;B!O8FIE8W0N($1O97,@;F]T(&-H86YG92!T
M:&4@;V)J96-T)W,*("`@("`J('!A<F5N="!O<B!N86UE+"!J=7-T('-E<FEA
M;&EZ960@9&%T82!O<B!A='1R:6)U=&5S+@H@("`@("H*("`@("`J($!P87)A
M;2!$871A5')E92`D;V)J96-T("!!($1A=&%4<F5E(&]B:F5C="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=7!D871E1&%T82@D;V)J96-T*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@>PH@
M("`@("`@("`@("`O*B!.;W1H:6YG('1O(&1O(&9O<B!N;VX@;V)J96-T<RX@
M*B\*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("`O*B!'970@=&AE(&]B:F5C="!I9"X@*B\*("`@("`@("`D:60@/2`D=&AI
M<RT^9V5T260H)&]B:F5C="T^9V5T3F%M92@I*3L*("`@("`@("!I9B`H:7-?
M82@D:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M9#L*("`@("`@("!]"@H@("`@("`@("\J(%-E92!I9B!W92!C86X@8G)E86L@
M=&AE(&]B:F5C="!O=70@=&\@9&%T871R965?871T<FEB=71E<R!T86)L92X@
M*B\*("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;V)J96-T+"`G7W1O071T
M<FEB=71E<R<I*2!["B`@("`@("`@("`@("\J($EF('=E(&-A;BP@8VQE87(@
M;W5T('1H92!D871A=')E95]D871A(&9I96QD('1O(&UA:V4@<W5R92!I=`H@
M("`@("`@("`@("`@*B!D;V5S;B=T(&=E="!P:6-K960@=7`@8GD@9V5T1&%T
M82@I+B!);G1E;G1I;VYA;&QY(&1O;B=T(&-H96-K"B`@("`@("`@("`@("`J
M(&9O<B!E<G)O<G,@:&5R92!I;B!C87-E(&1A=&%T<F5E7V1A=&$@9V]E<R!A
M=V%Y(&EN('1H90H@("`@("`@("`@("`@*B!F=71U<F4N("HO"B`@("`@("`@
M("`@("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L
M92==("X*("`@("`@("`@("`@("`@("`@("`@)R!3150@9&%T871R965?9&%T
M82`](#\@5TA%4D4@9&%T871R965?:60@/2`_)SL*("`@("`@("`@("`@)'9A
M;'5E<R`](&%R<F%Y*$Y53$PL("AI;G0I)&ED*3L*"B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIU
M<&1A=&5$871A*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=65R
M>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("`@("`@+RH@4W1A<G0@82!T
M<F%N<V%C=&EO;BX@*B\*("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O
M;6UI="AF86QS92D["@H@("`@("`@("`@("`O*B!$96QE=&4@;VQD(&%T=')I
M8G5T97,N("HO"B`@("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G
M("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72`N"B`@("`@
M("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T871R965?:60@/2`_)SL*("`@
M("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"AI;G0I)&ED*3L*"B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?
M<W%L.CIU<&1A=&5$871A*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D8BT^<F]L;&)A8VLH*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@1V5T('1H92!N97<@871T<FEB=71E('-E="P@86YD(&EN<V5R="!E
M86-H(&EN=&\@=&AE($1"+B!)9@H@("`@("`@("`@("`@*B!A;GET:&EN9R!F
M86EL<R!I;B!H97)E+"!R;VQL8F%C:R!T:&4@=')A;G-A8W1I;VXL(')E='5R
M;B!T:&4*("`@("`@("`@("`@("H@<F5L979A;G0@97)R;W(L(&%N9"!B86EL
M(&]U="X@*B\*("`@("`@("`@("`@)&%T=')I8G5T97,@/2`D;V)J96-T+3Y?
M=&]!='1R:6)U=&5S*"D["B`@("`@("`@("`@("1Q=65R>2`]("=)3E-%4E0@
M24Y43R`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72`N
M"B`@("`@("`@("`@("`@("`@("`@("<@*&1A=&%T<F5E7VED+"!A='1R:6)U
M=&5?;F%M92P@871T<FEB=71E7VME>2P@871T<FEB=71E7W9A;'5E*2<@+@H@
M("`@("`@("`@("`@("`@("`@("`G(%9!3%5%4R`H/RP@/RP@/RP@/RDG.PH@
M("`@("`@("`@("`D<W1A=&5M96YT(#T@)'1H:7,M/E]D8BT^<')E<&%R92@D
M<75E<GDI.PH@("`@("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D
M871T<BD@>PH@("`@("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"AI;G0I
M)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A='1R6R=N
M86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=');
M)VME>2==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)&%T=');)W9A;'5E)UTL($Y,4SHZ9V5T0VAA
M<G-E="@I+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*2D["@H@("`@("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A
M5')E95]S<6PZ.G5P9&%T941A=&$H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/F5X96-U=&4H)'-T871E;65N="P@)'9A
M;'5E<RD["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^
M<F]L;&)A8VLH*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YA
M=71O0V]M;6ET*'1R=64I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!#;VUM:70@=&AE('1R86YS86-T:6]N+"!A;F0@='5R;B!A
M=71O8V]M;6ET(&)A8VL@;VXN("HO"B`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V1B+3YC;VUM:70H*3L*("`@("`@("`@("`@)'1H:7,M/E]D8BT^
M875T;T-O;6UI="AT<G5E*3L*"B`@("`@("`@("`@(')E='5R;B!I<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RD@/R`D<F5S=6QT(#H@=')U93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!7<FET92!T;R!T:&4@9&%T871R
M965?9&%T82!F:65L9"X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]397)I86QI>F4N<&AP)SL*("`@("`@("`@("`@)'-E<B`](%-%4DE!
M3$E:15]55$8W7T)!4TE#.PH@("`@("`@("`@("`D9&%T82`]($AO<F1E7U-E
M<FEA;&EZ93HZ<V5R:6%L:7IE*"1O8FIE8W0M/F=E=$1A=&$H*2P@)'-E<BP@
M3DQ3.CIG971#:&%R<V5T*"DI.PH*("`@("`@("`@("`@)'%U97)Y(#T@)U50
M1$%412`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@
M("`@("`@("`@("`G(%-%5"!D871A=')E95]D871A(#T@/RP@9&%T871R965?
M<V5R:6%L:7IE9"`](#\G("X*("`@("`@("`@("`@("`@("`@("`@)R!72$52
M12!D871A=')E95]I9"`](#\G.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R
M87DH)&1A=&$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21S
M97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21I9"D["@H@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A
M=&%4<F5E7W-Q;#HZ=7!D871E1&%T82@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@
M("`@("`@("`@("!R971U<FX@:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M(#\@)')E<W5L="`Z('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP=',@=&\@;W!E;B!A(&-O;FYE8W1I;VX@=&\@=&AE(%-1
M3"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@
M("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@
M)W-T;W)A9V4G+`H@("`@("`@("`@("!A<G)A>2@G<&AP='EP92<L("=C:&%R
M<V5T)RDL"B`@("`@("`@("`@("=$871A5')E92!344PG*3L*"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@/2`G)SL*("`@
M("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=7-E
M<FYA;64G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N
M86UE)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W!A<W-W;W)D)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*("`@
M("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@
M/2`G:&]R9&5?9&%T871R964G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UT@
M/2`G:&]R9&5?9&%T871R965?871T<FEB=71E<R<["B`@("`@("`@?0H*("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S
M=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@(')E<75I<F5?;VYC92`G
M1$(N<&AP)SL*("`@("`@("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T
M:&ES+3Y?<&%R86US+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A<F%M
M<ULG<&5R<VES=&5N="==*2DI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*"1T:&ES+3Y?9&(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*
M("`@("`@("`O+R!3970@1$(@<&]R=&%B:6QI='D@;W!T:6]N<PH@("`@("`@
M('-W:71C:"`H)'1H:7,M/E]D8BT^<&AP='EP92D@>PH@("`@("`@(&-A<V4@
M)VUS<W%L)SH*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P
M;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/
M4E1!0DE,25197T524D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!
M0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]2
M4$,O````````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-S$`,#$V-C4W`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U)00R]R97-T+G!H<```````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S`Q-P`Q,#0Q-S,V,C<W,0`P,C`S-#<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!(;W)D95]24$-?<F5S="!C;&%S<R!P<F]V:61E<R!A
M(%)%4U0@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E(%)00PH@*B!S>7-T
M96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`L
M=B`Q+C8N,BXQ(#(P,#4O,3`O,3@@,3$Z,#$Z,C0@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="!2869A96P@5F%R96QA(%!E="`\<F%F865L+G9A<F5L82YP
M971`=7-C+F5S/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F%F865L
M(%9A<F5L82`\<F%F865L+G9A<F5L82YP971`=7-C+F5S/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C$*("H@0'!A8VMA9V4@2&]R9&5?4E!#"B`J+PIC;&%S<R!(
M;W)D95]24$-?<F5S="!E>'1E;F1S($AO<F1E7U)00R!["@H@("`@+RHJ"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VYT96YT5'EP
M92`]("=T97AT+VAT;6PG.PH*("`@("\J*@H@("`@("H@0VAE8VL@875T:&5N
M=&EC871I;VXN($1I9F9E<F5N="!B86-K96YD<R!M87D@:&%N9&QE"B`@("`@
M*B!A=71H96YT:6-A=&EO;B!I;B!D:69F97)E;G0@=V%Y<RX@5&AE(&)A<V4@
M8VQA<W,@:6UP;&5M96YT871I;VX*("`@("`J(&-H96-K<R!F;W(@2%144"!!
M=71H96YT:6-A=&EO;B!A9V%I;G-T('1H92!(;W)D92!A=71H('-E='5P+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&EF
M(&%U=&AE;G1I8V%T:6]N(&ES('-U8V-E<W-F=6PN"B`@("`@*B`@("`@("`@
M("`@("`@("`@(%-H;W5L9"!S96YD(&%P<')O<')I871E(")N;W0@875T:&]R
M:7IE9"(@:&5A9&5R<PH@("`@("H@("`@("`@("`@("`@("`@("!O<B!O=&AE
M<B!R97-P;VYS92!C;V1E<R]B;V1Y(&EF(&%U=&@@9F%I;',L"B`@("`@*B`@
M("`@("`@("`@("`@("`@(&%N9"!T86ME(&-A<F4@;V8@97AI=&EN9RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@875T:&]R:7IE*"D*("`@('L*("`@("`@("!I
M9B`H(21T:&ES+3Y?875T:&]R:7IE*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@:68@*$%U=&@Z.F=E=$%U=&@H*2D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!P87)E;G0Z.F%U=&AO<FEZ92@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T+B!A;&P@=&AE($=%5"!I;G!U="!D871A+B!4:&4@)V-A;&PG
M('!A<F%M(&ES(&5X=')A8W1E9"!F<F]M('1H90H@("`@("H@87)R87D@86YD
M('1R96%T960@<V5P87)A=&5L>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("`H;65T:&]D(&YA;64L(&%R<F%Y(&]F('!A<F%M971E<G,I"B`@("`@
M*@H@("`@("H@5$]$3SH@9&5S97)I86QI>FEN9R!O9B!C;VUP;&5X(&1A=&$@
M='EP97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN<'5T*"D*("`@('L*
M("`@("`@("`D=&AI<RT^7V-O;G1E;G14>7!E(#T@571I;#HZ9V5T1V5T*"=R
M97-T0V]N=&5N=%1Y<&4G+"`G=&5X="]H=&UL)RD["@H@("`@"21G971$871A
M(#T@571I;#HZ9&ES<&5L36%G:6-1=6]T97,H)%]'150I.PH@("`@"75N<V5T
M*"1G971$871A6R=R97-T0V%L;"==*3L*("`@(`EU;G-E="@D9V5T1&%T85LG
M<F5S=$-O;G1E;G14>7!E)UTI.PH*("`@(`ER971U<FX@87)R87DH)VUE=&AO
M9"<@/3X@571I;#HZ9V5T1V5T*"=R97-T0V%L;"<I+`H@("`@"2`@("`@("`@
M("`@("`G<&%R86US)R`]/B`D9V5T1&%T82D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!396YD<R!A;B!24$,@<F5Q=65S="!T;R!T:&4@<V5R=F5R(&%N9"!R
M971U<FYS('1H92!R97-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@5&AE(')A=R!R97%U97-T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R(&]R(&%N
M(%!%05(@97)R;W(@;V)J96-T(&]N"B`@("`@*B`@("`@("`@("`@("`@("!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D<F5Q
M=65S="D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@
M("`D;65T:&]D(#T@<W1R7W)E<&QA8V4H)RXG+"`G+R<L("1R97%U97-T6R=M
M971H;V0G72D["@H@("`@("`@(&EF("@A)')E9VES=')Y+3YH87--971H;V0H
M)&UE=&AO9"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H
M;V0Z("5S(BDL("1M971H;V0I*3L*("`@("`@("!]"@H@("`@("`@("\J($QO
M;VL@870@=&AE(&UE=&AO9"!S:6=N871U<F4@<V\@=&AA="!P87)A;65T97)S
M(&%R92!A<W-I9VYE9"!B>0H@("`@("`@("`J(&YA;64L(&EN<W1E860@;V8@
M<F5L>6EN9R!O;B!T:&4@;W)D97(@;V8@1T54('!A<F%M971E<G,@=&\@;6%T
M8V@*("`@("`@("`@*B!T:&4@;W)D97(@9&5F:6YE9"!I;B!T:&4@05!)(&UE
M=&AO9"X@*B\*("`@("`@("`D<VEG;F%T=7)E(#T@)')E9VES=')Y+3YG9713
M:6=N871U<F4H)&UE=&AO9"D["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D[
M"B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<VEG;F%T=7)E6S!=*2!A
M<R`D<&%R86TI('L*("`@("`@("`@("`@)'!A<F%M<ULD<&%R86U=(#T@:7-S
M970H)')E<75E<W1;)W!A<F%M<R==6R1P87)A;5TI(#\@)')E<75E<W1;)W!A
M<F%M<R==6R1P87)A;5T@.B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@)')E
M<W5L="`]("1R96=I<W1R>2T^8V%L;"@D;65T:&]D+"`D<&%R86US*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@
M5&AE(')E<W5L="!I<R!R971U<FYE9"!D97!E;F1I;F<@;VX@=&AE(')E<75E
M<W1E9"!C;VYT96YT('1Y<&4N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8V]N
M=&5N=%1Y<&4@/3T@)W1E>'0O:'1M;"<I('L*("`@("`@("`@("`@<F5T=7)N
M("<\:'1M;#X\8F]D>3XG("X@<')I;G1?<B@D<F5S=6QT+"!T<G5E*2`N("<\
M+V)O9'D^/"]H=&UL/B<["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?8V]N
M=&5N=%1Y<&4@/3T@)W1E>'0O<&QA:6XG*2!["B`@("`@("`@("`@(')E='5R
M;B!P<FEN=%]R*"1R97-U;'0L('1R=64I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="!T:&4@0V]N=&5N="U4>7!E(&]F('1H92!R97-P
M;VYS92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@
M0V]N=&5N="U4>7!E(&]F('1H92!24$,@<F5S<&]N<V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%)E<W!O;G-E0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-O;G1E;G14>7!E.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]S;V%P+G!H
M<```````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-3$U-P`Q
M,#0Q-S,V,C<W,0`P,C`S-#``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]24$-?<V]A
M<"!C;&%S<R!P<F]V:61E<R!A;B!33T%0(&EM<&QE;65N=&%T:6]N(&]F('1H
M90H@*B!(;W)D92!24$,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]24$,O4E!#+W-O87`N<&AP+'8@,2XQ,RXQ,"XW(#(P,#8O,#$O,#$@,C$Z
M,C@Z,S,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]24$,*("HO"F-L
M87-S($AO<F1E7U)00U]S;V%P(&5X=&5N9',@2&]R9&5?4E!#('L*"B`@("`O
M*BH*("`@("`J(%)E<V]U<F-E(&AA;F1L97(@9F]R('1H92!24$,@<V5R=F5R
M+@H@("`@("H*("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D
M7W-E<G9E<CL*"B`@("`O*BH*("`@("`J($AA<V@@:&]L9&EN9R!A;&P@;65T
M:&]D<R<@<VEG;F%T=7)E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7U]D:7-P871C:%]M87`@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@4T]!4"!S97)V97(@8V]N<W1R=6-T;W(*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R
M9&5?4E!#7W-O87`H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"1P87)A;7,@/3T@)W=S9&PG('Q\("1P87)A;7,@/3T@)V1I<V-O)RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7V%U=&AO<FEZ92`](&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@<&%R96YT.CI(;W)D95]24$,H*3L*"B`@("`@("`@9VQO
M8F%L("1R96=I<W1R>3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=33T%0+U-E
M<G9E<BYP:'`G.PH@("`@("`@("1T:&ES+3Y?<V5R=F5R(#T@)FYE=R!33T%0
M7U-E<G9E<B@I.PH@("`@("`@("1T:&ES+3Y?<V5R=F5R+3Y?875T;U]T<F%N
M<VQA=&EO;B`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6QL<R!A
M(&AA<V@@=&AA="!I<R!U<V5D(&)Y('1H92!33T%0('-E<G9E<B!W:71H('1H
M92!S:6=N871U<F5S(&]F"B`@("`@*B!A;&P@879A:6QA8FQE(&UE=&AO9',N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971U<$1I<W!A=&-H36%P*"D*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D;65T:&]D
M<R`]("1R96=I<W1R>2T^;&ES=$UE=&AO9',H*3L*("`@("`@("!F;W)E86-H
M("@D;65T:&]D<R!A<R`D;65T:&]D*2!["B`@("`@("`@("`@("1S:6=N871U
M<F4@/2`D<F5G:7-T<GDM/F=E=%-I9VYA='5R92@D;65T:&]D*3L*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<VEG;F%T=7)E*2D@>PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&UE
M=&AO9"`]('-T<E]R97!L86-E*"<O)RP@)RXG+"`D;65T:&]D*3L*("`@("`@
M("`@("`@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R1M971H;V1=(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`G:6XG(#T^("1S:6=N871U<F5;,%TL"B`@("`@
M("`@("`@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T<'5T)R`]/B`D<VEG;F%T
M=7)E6S%=*0H@("`@("`@("`@("`I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]?='EP961E9B`]("1R96=I<W1R>2T^;&ES=%1Y<&5S*"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S:6=N871U<F4@;V8@82!M
M971H;V0N"B`@("`@*B!);G1E<FYA;&QY('5S960@8GD@=&AE(%-/05`@<V5R
M=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@02!M
M971H;V0@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A
M<G)A>2!D97-C<FEB:6YG('1H92!M971H;V0G<R!S:6=N871U<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]?9&ES<&%T8V@H)&UE=&AO9"D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@("1M971H;V0@/2!S=')?
M<F5P;&%C92@G+B<L("<O)RP@)&UE=&AO9"D["@H@("`@("`@("1S:6=N871U
M<F4@/2`D<F5G:7-T<GDM/F=E=%-I9VYA='5R92@D;65T:&]D*3L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1S:6=N871U<F4I*2!["B`@("`@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=I
M;B<@/3X@)'-I9VYA='5R95LP72P*("`@("`@("`@("`@("`@("`@("`@)V]U
M="<@/3X@87)R87DH)V]U='!U="<@/3X@)'-I9VYA='5R95LQ72DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5VEL;"!B92!R96=I<W1E<F5D(&%S('1H92!H
M86YD;&5R(&9O<B!A;&P@;65T:&]D<R!C86QL960@:6X@=&AE"B`@("`@*B!3
M3T%0('-E<G9E<B!A;F0@=VEL;"!C86QL('1H92!A<'!R;W!R:6%T92!F=6YC
M=&EO;B!T:')O=6=H('1H92!R96=I<W1R>2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H
M;V0@("`@5&AE(&YA;64@;V8@=&AE(&UE=&AO9"!C86QL960@8GD@=&AE(%)0
M0R!R97%U97-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@(%1H
M92!P87-S960@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!M:7AE9"`D9&%T
M82`@("`@("!5;FMN;W=N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M("`@("`@("`@("!4:&4@<F5S=6QT(&]F('1H92!C86QL960@<F5G:7-T<GD@
M;65T:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES<&%T8VAE<B@D;65T
M:&]D+"`D<&%R86US*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD[
M"B`@("`@("`@)&UE=&AO9"`]('-T<E]R97!L86-E*"<N)RP@)R\G+"`D;65T
M:&]D*3L*"B`@("`@("`@:68@*"$D<F5G:7-T<GDM/FAA<TUE=&AO9"@D;65T
M:&]D*2D@>PH@("`@("`@("`@("!R971U<FX@<W!R:6YT9BA?*")-971H;V0@
M7"(E<UPB(&ES(&YO="!D969I;F5D(BDL("1M971H;V0I.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]S97)V97(M/F)I;F174T1,*$AO<F1E.CIU<FPH
M)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<G!C+G!H
M<#]W<V1L)RP@=')U92P@9F%L<V4I*3L*("`@("`@("!R971U<FX@)')E9VES
M=')Y+3YC86QL*"1M971H;V0L("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5&%K97,@86X@4E!#(')E<75E<W0@86YD(')E='5R;G,@=&AE(')E
M<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!4:&4@<F%W(')E
M<75E<W0@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@4W1R:6YG('-P
M96-I9GEI;F<@=VAA="!K:6YD(&]F(&1A=&$@=&\@<F5T=7)N+B!$969A=6QT
M<PH@("`@("H@("`@("`@("`@("`@("`@=&\@4T]!4"!R97%U97-T+B!0;W-S
M:6)L92!O=&AE<B!V86QU97,Z(")W9'-L(B!A;F0*("`@("`J("`@("`@("`@
M("`@("`@(")D:7-C;R(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!834P@96YC;V1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1R97%U97-T+"`D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E<G9E<BT^861D
M3V)J96-T36%P*"1T:&ES+"`G=7)N.FAO<F1E)RD["@H@("`@("`@(&EF("@A
M)'!A<F%M<RD@>PH@("`@("`@("`@("`D=&AI<RT^7W-E<G9E<BT^<V5T0V%L
M;$AA;F1L97(H87)R87DH)'1H:7,L("=?9&ES<&%T8VAE<B<I*3L*("`@("`@
M("`@("`@+RH@5V4@8V%N)W0@=7-E(%5T:6PZ.F)U9F9E<D]U='!U="@I(&AE
M<F4@9F]R('-O;64@<F5A<V]N+B`J+PH@("`@("`@("`@("!O8E]S=&%R="@I
M.PH@("`@("`@("`@("`D=&AI<RT^7W-E<G9E<BT^<V5R=FEC92@D<F5Q=65S
M="D["B`@("`@("`@("`@("1O=71P=70@/2!O8E]G971?8V]N=&5N=',H*3L*
M("`@("`@("`@("`@;V)?96YD7V-L96%N*"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=33T%0+T1I<V-O+G!H<"<["B`@
M("`@("`@("`@("1D:7-C;R`](&YE=R!33T%07T1)4T-/7U-E<G9E<B@D=&AI
M<RT^7W-E<G9E<BP@)VAO<F1E)RD["B`@("`@("`@("`@(&EF("@D<&%R86US
M(#T]("=W<V1L)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S971U<$1I
M<W!A=&-H36%P*"D["B`@("`@("`@("`@("`@("`D;W5T<'5T(#T@)&1I<V-O
M+3YG97174T1,*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D;W5T<'5T(#T@)&1I<V-O+3YG971$25-#3R@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!33T%0(')E<75E<W0@86YD('-E
M;F1S(&ET('1O('1H92!33T%0('-E<G9E<BX*("`@("`J"B`@("`@*B!4:&ES
M('-T871I8V%L;'D@8V%L;&5D(&UE=&AO9"!I<R!A8W1U86QL>2!T:&4@4T]!
M4"!C;&EE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@
M("!4:&4@<&%T:"!T;R!T:&4@4T]!4"!S97)V97(@;VX@=&AE(&-A;&QE9"!H
M;W-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@;65T:&]D
M('1O(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S
M:"!C;VYT86EN:6YG(&%N>2!N96-E<W-A<GD@<&%R86UE=&5R<R!F;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&UE=&AO9"!C86QL+@H@
M("`@("H@0'!A<F%M("1O<'1I;VYS("!/<'1I;VYA;"!A<W-O8VEA=&EV92!A
M<G)A>2!O9B!P87)A;65T97)S('=H:6-H(&-A;B!B93H*("`@("`J("`@("`@
M("`@("`@("`@("`@=7-E<B`@("`@("`@("`@("`@("`M($)A<VEC($%U=&@@
M=7-E<FYA;64*("`@("`J("`@("`@("`@("`@("`@("`@<&%S<R`@("`@("`@
M("`@("`@("`M($)A<VEC($%U=&@@<&%S<W=O<F0*("`@("`J("`@("`@("`@
M("`@("`@("`@<')O>'E?:&]S="`@("`@("`@("`M(%!R;WAY('-E<G9E<B!H
M;W-T"B`@("`@*B`@("`@("`@("`@("`@("`@('!R;WAY7W!O<G0@("`@("`@
M("`@+2!0<F]X>2!S97)V97(@<&]R=`H@("`@("H@("`@("`@("`@("`@("`@
M("!P<F]X>5]U<V5R("`@("`@("`@("T@4')O>'D@875T:"!U<V5R;F%M90H@
M("`@("H@("`@("`@("`@("`@("`@("!P<F]X>5]P87-S("`@("`@("`@("T@
M4')O>'D@875T:"!P87-S=V]R9`H@("`@("H@("`@("`@("`@("`@("`@("!T
M:6UE;W5T("`@("`@("`@("`@("T@0V]N;F5C=&EO;B!T:6UE;W5T(&EN('-E
M8V]N9',N"B`@("`@*B`@("`@("`@("`@("`@("`@(&%L;&]W4F5D:7)E8W1S
M("`@("`@+2!7:&5T:&5R('1O(&9O;&QO=R!R961I<F5C=',@;W(@;F]T"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&UA>%)E9&ER96-T<R`@("`@("`@+2!-
M87@@;G5M8F5R(&]F(')E9&ER96-T<R!T;R!F;VQL;W<*("`@("`J("`@("`@
M("`@("`@("`@("`@;F%M97-P86-E"B`@("`@*B`@("`@("`@("`@("`@("`@
M('-O87!A8W1I;VX*("`@("`J("`@("`@("`@("`@("`@("`@9G)O;2`@("`@
M("`@("`@("`@("`M(%--5%`L(&9R;VT@861D<F5S<PH@("`@("H@("`@("`@
M("`@("`@("`@("!T<F%N<V9E<BUE;F-O9&EN9R`@("T@4TU44"P@<V5T<R!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<@:&5A9&5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@('-U8FIE8W0@("`@("`@("`@("`@+2!33510+"!S
M=6)J96-T(&AE861E<@H@("`@("H@("`@("`@("`@("`@("`@("!H96%D97)S
M("`@("`@("`@("`@("T@4TU44"P@87)R87DM:&%S:"!O9B!E>'1R82!S;71P
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!H96%D97)S"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@("`@("`@
M("`@(%1H92!R971U<FYE9"!R97-U;'0@9G)O;2!T:&4@;65T:&]D(&]R(&$@
M4$5!4@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97%U97-T
M*"1U<FPL("1M971H;V0L("1P87)A;7,@/2!N=6QL+"`D;W!T:6]N<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG=&EM
M96]U="==*2D@>PH@("`@("`@("`@("`D;W!T:6]N<ULG=&EM96]U="==(#T@
M-3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG86QL
M;W=2961I<F5C=',G72DI('L*("`@("`@("`@("`@)&]P=&EO;G-;)V%L;&]W
M4F5D:7)E8W1S)UT@/2!T<G5E.PH@("`@("`@("`@("`D;W!T:6]N<ULG;6%X
M4F5D:7)E8W1S)UT@("`](#,["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E
M7V]N8V4@)U-/05`O0VQI96YT+G!H<"<["B`@("`@("`@)'-O87`@/2`F;F5W
M(%-/05!?0VQI96YT*"1U<FPL(&9A;'-E+"!F86QS92P@)&]P=&EO;G,I.PH@
M("`@("`@(')E='5R;B`D<V]A<"T^8V%L;"@D;65T:&]D+"`D<&%R86US+"`D
M;W!T:6]N<ULG;F%M97-P86-E)UTI.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]S>6YC;6PN<&AP````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S8Q-@`Q,#0Q-S,V,C<W,0`P,C`W
M,#4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G4WEN8TU,+G!H<"<["G)E<75I<F5?;VYC
M92`G4WEN8TU,+U-T871E+G!H<"<["G)E<75I<F5?;VYC92`G4WEN8TU,+T-O
M;6UA;F0O4W1A='5S+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7U)00U]S>6YC
M;6P@8VQA<W,@<')O=FED97,@82!3>6YC34P@:6UP;&5M96YT871I;VX@;V8@
M=&AE($AO<F1E"B`J(%)00R!S>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U)00R]24$,O<WEN8VUL+G!H<"QV(#$N,3@N,3`N-B`R,#`V+S`Q+S`Q
M(#(Q.C(X.C,S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC
M;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@06YT:&]N>2!-:6QL
M<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7U)00PH@*B\*8VQA<W,@2&]R9&5?4E!#7W-Y
M;F-M;"!E>'1E;F1S($AO<F1E7U)00R!["@H@("`@+RHJ"B`@("`@*B!/=71P
M=70@0V]N=&5N=$AA;F1L97(@=7-E9"!T;R!O=71P=70@6$U,(&5V96YT<RX*
M("`@("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)%]O
M=71P=70["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?>&UL4W1A8VL@/2`P.PH*("`@("\J*@H@("`@("H@1&5B=6<@
M9&ER96-T;W)Y+"!I9B!S970@=VEL;"!S=&]R92!C;W!I97,@;V8@86QL('!A
M8VME=',N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?9&5B=6=$:7(@/2`G+W1M<"]S>6YC)SL*"B`@("`O*BH*("`@("`J
M($1E9F%U;'0@8VAA<F%C=&5R('-E="X@($]N;'D@<W5P<&]R=',@551&+3@H
M05-#24D_*2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]C:&%R<V5T(#T@)U541BTX)SL*"B`@("`O*BH*("`@("`J(%-Y
M;F--3"!H86YD;&5S(&%U=&AE;G1I8V%T:6]N(&EN=&5R;F%L;'DL('-O(&)Y
M<&%S<R!T:&4@4E!#(&9R86UE=V]R:PH@("`@("H@875T:"!C:&5C:R!B>2!J
M=7-T(')E='5R;FEN9R!T<G5E(&AE<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%U=&AO<FEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!396YD<R!A;B!24$,@<F5Q=65S="!T;R!T:&4@
M<V5R=F5R(&%N9"!R971U<FYS('1H92!R97-U;'0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<F5Q=65S="`@5&AE(')A=R!R97%U97-T('-T<FEN
M9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%A-3"!E;F-O
M9&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4F5S<&]N<V4H)')E<75E<W0I"B`@("!["B`@("`@("`@+RH@
M0V%T8V@@86YY(&5R<F]R<R]W87)N:6YG<R]N;W1I8V5S('1H870@;6%Y(&=E
M="!T:')O=VX@=VAI;&4*("`@("`@("`@*B!P<F]C97-S:6YG+B!$;VXG="!W
M86YT('1O(&QE="!A;GET:&EN9R!G;R!T;R!T:&4@8VQI96YT('1H870G<R!N
M;W0*("`@("`@("`@*B!P87)T(&]F('1H92!V86QI9"!R97-P;VYS92X@*B\*
M("`@("`@("!O8E]S=&%R="@I.PH*("`@("`@("`O*B!697)Y('5S969U;"!F
M;W(@9&5B=6=G:6YG+B!,;V=S(%="6$U,('!A8VME=',@=&\*("`@("`@("`@
M*B`D=&AI<RT^7V1E8G5G1&ER+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]D96)U9T1I<BD@)B8@:7-?9&ER*"1T:&ES+3Y?9&5B=6=$:7(I*2![
M"B`@("`@("`@("`@("1P86-K971.=6T@/2!`:6YT=F%L*&9I;&5?9V5T7V-O
M;G1E;G1S*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;"YP86-K971N=6TG
M*2D["B`@("`@("`@("`@(&EF("@A:7-S970H)'!A8VME=$YU;2DI('L*("`@
M("`@("`@("`@("`@("1P86-K971.=6T@/2`P.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D9B`]($!F;W!E;B@D=&AI<RT^7V1E8G5G1&ER("X@)R]S
M>6YC;6Q?8VQI96YT7R<@+B`D<&%C:V5T3G5M("X@)RYX;6PG+"`G=V(G*3L*
M("`@("`@("`@("`@:68@*"1F*2!["B`@("`@("`@("`@("`@("!F=W)I=&4H
M)&8L("1R97%U97-T*3L*("`@("`@("`@("`@("`@(&9C;&]S92@D9BD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G
M6$U,+U="6$U,+T-O;G1E;G1(86YD;&5R+G!H<"<["B`@("`@("`@)'1H:7,M
M/E]O=71P=70@/2`F;F5W(%A-3%]70EA-3%]#;VYT96YT2&%N9&QE<B@I.PH*
M("`@("`@("`D=&AI<RT^7W!A<G-E*"1R97%U97-T*3L*("`@("`@("`D<F5S
M<&]N<V4@/2`D=&AI<RT^7V]U='!U="T^9V5T3W5T<'5T*"D["@H@("`@("`@
M("\J(%9E<GD@=7-E9G5L(&9O<B!D96)U9V=I;F<N("HO"B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7V1E8G5G1&ER*2`F)B!I<U]D:7(H)'1H:7,M/E]D
M96)U9T1I<BDI('L*("`@("`@("`@("`@)&8@/2!`9F]P96XH)'1H:7,M/E]D
M96)U9T1I<B`N("<O<WEN8VUL7W-E<G9E<E\G("X@)'!A8VME=$YU;2`N("<N
M>&UL)RP@)W=B)RD["B`@("`@("`@("`@(&EF("@D9BD@>PH@("`@("`@("`@
M("`@("`@9G=R:71E*"1F+"`D<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@
M9F-L;W-E*"1F*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9P(#T@
M0&9O<&5N*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;"YP86-K971N=6TG
M+"`G=R<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@
M("!F=W)I=&4H)&9P+"`K*R1P86-K971.=6TI.PH@("`@("`@("`@("`@("`@
M9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($-L96%R('1H92!O=71P=70@8G5F9F5R('1H870@=V4@<W1A<G1E9"!A
M8F]V92P@86YD(&QO9R!A;GET:&EN9PH@("`@("`@("`J('1H870@8V%M92!U
M<"!F;W(@;&%T97(@9&5B=6=G:6YG+B`J+PH@("`@("`@("1E<G)O<DQO9V=I
M;F<@/2!O8E]G971?8VQE86XH*3L*("`@("`@("!I9B`H(65M<'1Y*"1E<G)O
M<DQO9V=I;F<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=3
M>6YC34PZ(&-A=6=H="!O=71P=70])R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E<G)O<DQO9V=I;F<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M97-P;VYS93L*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R<V4H)'AM;"D*("`@
M('L*("`@("`@("`O*B!T<GD@=&\@97AT<F%C="!C:&%R<V5T(&9R;VT@6$U,
M('1E>'0@*B\*("`@("`@("!I9BAP<F5G7VUA=&-H*"<O7EQS*CQ</WAM;%M>
M/ETJ96YC;V1I;F=<<RH]7',J(BA;7B)=*BDB+VDG+`H@("`@("`@("`@("`@
M("`@)'AM;"P@)&TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8VAA<G-E="`]
M("1M6S%=.PH@("`@("`@('T*("`@("`@("!.3%,Z.G-E=$-H87)S970H)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("!3=')I;F<Z.G-E=$1E9F%U;'1#:&%R
M<V5T*"1T:&ES+3Y?8VAA<G-E="D["@H@("`@("`@("\J($-R96%T92!T:&4@
M6$U,('!A<G-E<B!A;F0@<V5T(&UE=&AO9"!R969E<F5N8V5S+B`J+PH@("`@
M("`@("1T:&ES+3Y?<&%R<V5R(#T@>&UL7W!A<G-E<E]C<F5A=&5?;G,H)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("!X;6Q?<V5T7V]B:F5C="@D=&AI<RT^
M7W!A<G-E<BP@)'1H:7,I.PH@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO
M;B@D=&AI<RT^7W!A<G-E<BP@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L(&9A
M;'-E*3L*("`@("`@("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D=&AI<RT^
M7W!A<G-E<BP@)U]S=&%R=$5L96UE;G0G+"`G7V5N9$5L96UE;G0G*3L*("`@
M("`@("!X;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'1H:7,M/E]P
M87)S97(L("=?8VAA<F%C=&5R<R<I.PH@("`@("`@('AM;%]S971?<')O8V5S
M<VEN9U]I;G-T<G5C=&EO;E]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G)RD[
M"B`@("`@("`@>&UL7W-E=%]E>'1E<FYA;%]E;G1I='E?<F5F7VAA;F1L97(H
M)'1H:7,M/E]P87)S97(L("<G*3L*"B`@("`@("`@:68@*"%X;6Q?<&%R<V4H
M)'1H:7,M/E]P87)S97(L("1X;6PI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=834P@97)R;W(Z("5S(&%T(&QI
M;F4@)60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!X;6Q?97)R;W)?<W1R:6YG*'AM;%]G971?97)R;W)?8V]D92@D
M=&AI<RT^7W!A<G-E<BDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?;&EN95]N=6UB97(H
M)'1H:7,M/E]P87)S97(I*2D["B`@("`@("`@?0H*("`@("`@("!X;6Q?<&%R
M<V5R7V9R964H)'1H:7,M/E]P87)S97(I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]S=&%R=$5L96UE;G0H)'!A<G-E<BP@)'1A9RP@)&%T=')I8G5T97,I"B`@
M("!["B`@("`@("`@;&ES="@D=7)I+"`D;F%M92D@/2`D=&AI<RT^7W-P;&ET
M55))*"1T86<I.PH*("`@("`@("`D=&AI<RT^<W1A<G1%;&5M96YT*"1U<FDL
M("1N86UE+"`D871T<FEB=71E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H
M87)A8W1E<G,H)'!A<G-E<BP@)&-H87)S*0H@("`@>PH@("`@("`@("1T:&ES
M+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V5N
M9$5L96UE;G0H)'!A<G-E<BP@)'1A9RD*("`@('L*("`@("`@("!L:7-T*"1U
M<FDL("1N86UE*2`]("1T:&ES+3Y?<W!L:7154DDH)'1A9RD["@H@("`@("`@
M("1T:&ES+3YE;F1%;&5M96YT*"1U<FDL("1N86UE*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!?<W!L:7154DDH)'1A9RD*("`@('L*("`@("`@("`D<&%R=',@
M/2!E>'!L;V1E*"<Z)RP@)'1A9RD["B`@("`@("`@)&YA;64@/2!A<G)A>5]P
M;W`H)'!A<G1S*3L*("`@("`@("`D=7)I(#T@:6UP;&]D92@G.B<L("1P87)T
M<RD["B`@("`@("`@<F5T=7)N(&%R<F%Y*"1U<FDL("1N86UE*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($-O;G1E;G0M5'EP92!O9B!T
M:&4@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!-24U%($-O;G1E;G0M5'EP92!O9B!T:&4@4E!#(')E<W!O;G-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS94-O;G1E;G14>7!E*"D*("`@
M('L*("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PK>&UL
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L
M96UE;G0L("1A='1R<RD*("`@('L*("`@("`@("`D=&AI<RT^7WAM;%-T86-K
M*RL["@H@("`@("`@('-W:71C:"`H)'1H:7,M/E]X;6Q3=&%C:RD@>PH@("`@
M("`@(&-A<V4@,3H*("`@("`@("`@("`@+R\@/%-Y;F--3#X*("`@("`@("`@
M("`@+R\@1&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C
M;VPL('9E<G-I;VX@,2XQ(#4N,BXQ"B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@
M("\O($5I=&AE<B`\4WEN8TU,/CQ3>6YC2&1R/B!O<B`\4WEN8TU,/CQ3>6YC
M0F]D>3X*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-O;G1E;G1(
M86YD;&5R*2D@>PH@("`@("`@("`@("`@("`@+R\@268@;F]T(&1E9FEN960@
M=&AE;B!C<F5A=&4@4WEN8TAD<BX*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8V]N=&5N=$AA;F1L97(@/2`F;F5W(%-Y;F--3%]3>6YC;6Q(9'(H*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/G-E=$]U='!U
M="@D=&AI<RT^7V]U='!U="D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/G-T87)T16QE;65N="@D=7)I+"`D
M96QE;65N="P@)&%T=')S*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-O;G1E
M;G1(86YD;&5R*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT
M2&%N9&QE<BT^<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1H:7,M/E]X;6Q3=&%C:RD@>PH@
M("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@+R\@/"]3>6YC34P^"B`@("`@
M("`@("`@("\O($1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R
M;W1O8V]L+"!V97)S:6]N(#$N,2`U+C(N,0H@("`@("`@("`@("`D=&AI<RT^
M7V]U='!U="T^96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("\O($5I
M=&AE<B`\+U-Y;F-(9'(^/"]3>6YC34P^(&]R(#PO4WEN8T)O9'D^/"]3>6YC
M34P^"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G4WEN8TAD<B<I('L*
M("`@("`@("`@("`@("`@("\O(%1H96X@=V4@9V5T('1H92!S=&%T92!F<F]M
M(%-Y;F--3$AD<BP@86YD(&-R96%T92!A(&YE=PH@("`@("`@("`@("`@("`@
M+R\@4WEN8TU,0F]D>2X*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N
M=$AA;F1L97(M/F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH*("`@("`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L97(I.PH*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(@/2`F;F5W(%-Y
M;F--3%]3>6YC;6Q";V1Y*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O
M;G1E;G1(86YD;&5R+3YS971/=71P=70H)'1H:7,M/E]O=71P=70I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@3F\@;&]N9V5R
M('5S960N"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R
M+3YE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@("`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L97(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`O+R`\+RH^/"]3>6YC2&1R/CPO4WEN8TU,/B!O<B`\+RH^/"]3>6YC
M0F]D>3X\+U-Y;F--3#X*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M8V]N=&5N=$AA;F1L97(I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O
M;G1E;G1(86YD;&5R+3YE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V-H87)S*2D@>PH@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^7V-H87)S*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?>&UL4W1A8VLM+3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%R86-T97)S
M*"1S='(I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V]N=&5N
M=$AA;F1L97(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L
M97(M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(')A:7-E17)R;W(H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@
M2&]R9&4Z.FQO9TUE<W-A9V4H)'-T<BP@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]24$,O<WEN
M8VUL7W=B>&UL+G!H<```````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8W
M,#<`,3`T,3<S-C(W-S$`,#(R,3$U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+W-Y;F-M;"YP:'`G.PIR97%U:7)E7V]N8V4@)UA-
M3"]70EA-3"]$96-O9&5R+G!H<"<["G)E<75I<F5?;VYC92`G6$U,+U="6$U,
M+T5N8V]D97(N<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?4E!#7W-Y;F-M;%]W
M8GAM;"!C;&%S<R!P<F]V:61E<R!A(%-Y;F--3"!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4*("H@2&]R9&4@4E!#('-Y<W1E;2!U<VEN9R!70EA-3"!E;F-O9&EN
M9RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4E!#+U)00R]S>6YC;6Q?=V)X
M;6PN<&AP+'8@,2XQ,2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,S,@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT
M:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI
M9#8N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?4E!#"B`J+PIC;&%S<R!(;W)D95]24$-?<WEN8VUL7W=B>&UL(&5X=&5N
M9',@2&]R9&5?4E!#7W-Y;F-M;"!["@H@("`@+RHJ"B`@("`@*B!396YD<R!A
M;B!24$,@<F5Q=65S="!T;R!T:&4@<V5R=F5R(&%N9"!R971U<FYS('1H92!R
M97-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q=65S="`@
M5&AE(')A=R!R97%U97-T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(%="6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T:&4@
M<V5R=F5R("AB:6YA<GDI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P
M;VYS92@D<F5Q=65S="D*("`@('L*("`@("`@("`O*B!#871C:"!A;GD@97)R
M;W)S+W=A<FYI;F=S+VYO=&EC97,@=&AA="!M87D@9V5T('1H<F]W;B!W:&EL
M90H@("`@("`@("`J('!R;V-E<W-I;F<N($1O;B=T('=A;G0@=&\@;&5T(&%N
M>71H:6YG(&=O('1O('1H92!C;&EE;G0@=&AA="=S(&YO=`H@("`@("`@("`J
M('!A<G0@;V8@=&AE('9A;&ED(')E<W!O;G-E+B`J+PH@("`@("`@(&]B7W-T
M87)T*"D["@H@("`@("`@("\J(%9E<GD@=7-E9G5L(&9O<B!D96)U9V=I;F<N
M($QO9W,@5T)834P@<&%C:V5T<R!T;PH@("`@("`@("`J("1T:&ES+3Y?9&5B
M=6=$:7(N("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V1E8G5G1&ER
M*2`F)B!I<U]D:7(H)'1H:7,M/E]D96)U9T1I<BDI('L*("`@("`@("`@("`@
M)'!A8VME=$YU;2`]($!I;G1V86PH9FEL95]G971?8V]N=&5N=',H)'1H:7,M
M/E]D96)U9T1I<B`N("<O<WEN8VUL+G!A8VME=&YU;2<I*3L*("`@("`@("`@
M("`@:68@*"%I<W-E="@D<&%C:V5T3G5M*2D@>PH@("`@("`@("`@("`@("`@
M)'!A8VME=$YU;2`](#`["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F
M<"`](&9O<&5N*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;%]C;&EE;G1?
M)R`N("1P86-K971.=6T@+B`G+G=B>&UL)RP@)W=B)RD["B`@("`@("`@("`@
M(&9W<FET92@D9G`L("1R97%U97-T*3L*("`@("`@("`@("`@9F-L;W-E*"1F
M<"D["B`@("`@("`@?0H*"B`@("`@("`@)&1E8V]D97(@/2`F;F5W(%A-3%]7
M0EA-3%]$96-O9&5R*"D["B`@("`@("`@)'1H:7,M/E]O=71P=70@/2`F;F5W
M(%A-3%]70EA-3%]%;F-O9&5R*"D["@H@("`@("`@("1D96-O9&5R+3YS971#
M;VYT96YT2&%N9&QE<B@D=&AI<RD["@H@("`@("`@("1R(#T@)&1E8V]D97(M
M/F1E8V]D92@D<F5Q=65S="D["B`@("`@("`@:68@*&ES7V$H)'(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-Y
M;F--3#H@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R+3YG
M971-97-S86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YS971697)S
M:6]N*"1D96-O9&5R+3YG971697)S:6]N*"DI.PH@("`@("`@("1T:&ES+3Y?
M;W5T<'5T+3YS971#:&%R<V5T*"1D96-O9&5R+3YG971#:&%R<V5T4W1R*"DI
M.PH@("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?;W5T<'5T+3YG971/=71P
M=70H*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-P;VYS
M92P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("`D<F5S<&]N<V4@/2`D<F5S<&]N<V4M/F=E=$UE<W-A9V4H*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]D96)U9T1I<BD@
M)B8@:7-?9&ER*"1T:&ES+3Y?9&5B=6=$:7(I*2!["B`@("`@("`@("`@("1F
M<"`](&9O<&5N*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;%]S97)V97)?
M)R`N("1P86-K971.=6T@+B`G+G=B>&UL)RP@)W=B)RD["B`@("`@("`@("`@
M(&9W<FET92@D9G`L("1R97-P;VYS92D["B`@("`@("`@("`@(&9C;&]S92@D
M9G`I.PH*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES+3Y?9&5B=6=$
M:7(@+B`G+W-Y;F-M;"YP86-K971N=6TG+"`G=R<I.PH@("`@("`@("`@("!I
M9B`H)&9P*2!["B`@("`@("`@("`@("`@("!F=W)I=&4H)&9P+"`K*R1P86-K
M971.=6TI.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@
M("`@('T*"B`@("`@("`@?0H*("`@("`@("`O*B!#;&5A<B!T:&4@;W5T<'5T
M(&)U9F9E<B!T:&%T('=E('-T87)T960@86)O=F4L(&%N9"!L;V<@86YY=&AI
M;F<*("`@("`@("`@*B!T:&%T(&-A;64@=7`@9F]R(&QA=&5R(&1E8G5G9VEN
M9RX@*B\*("`@("`@("`D97)R;W),;V=G:6YG(#T@;V)?9V5T7V-L96%N*"D[
M"B`@("`@("`@:68@*"%E;7!T>2@D97)R;W),;V=G:6YG*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@G4WEN8TU,.B!C875G:'0@;W5T<'5T
M/2<@+B`D97)R;W),;V=G:6YG+`H@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!#;VYT96YT+51Y<&4@;V8@=&AE(')E<W!O;G-E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!#;VYT96YT+51Y<&4@;V8@
M=&AE(%)00R!R97-P;VYS92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S
M<&]N<V5#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=A<'!L
M:6-A=&EO;B]V;F0N<WEN8VUL*W=B>&UL)SL*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+W=E
M8F1A=BYP:'``````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U
M-C0U`#$P-#$W,S8R-S<Q`#`R,#8U,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=(5%10
M+U=E8D1!5B]397)V97(N<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?4E!#7W=E
M8F1A=B!C;&%S<R!P<F]V:61E<R!A(%=E8D1!5B!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4*("H@2&]R9&4@4E!#('-Y<W1E;2X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO4E!#+U)00R]W96)D878N<&AP+'8@,2XQ+C$R+C8@,C`P-B\P,2\P
M,2`R,3HR.#HS,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?4E!#"B`J+PIC;&%S<R!(;W)D95]24$-?=V5B9&%V(&5X=&5N9',@2&]R
M9&5?4E!#('L*"B`@("`O*BH*("`@("`J(%)E<V]U<F-E(&AA;F1L97(@9F]R
M('1H92!796)$058@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@2%144%]7
M96)$059?4V5R=F5R7TAO<F1E"B`@("`@*B\*("`@('9A<B`D7W-E<G9E<CL*
M"B`@("`O*BH*("`@("`J(%=E8D1A=B!S97)V97(@8V]N<W1R=6-T;W(N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N($AO<F1E7U)00U]W96)D878H*0H@("`@>PH@("`@("`@('!A<F5N=#HZ
M2&]R9&5?4E!#*"D["@H@("`@("`@("1T:&ES+3Y?<V5R=F5R(#T@)FYE=R!(
M5%107U=E8D1!5E]397)V97)?2&]R9&4H*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E;F1S(&%N(%)00R!R97%U97-T('1O('1H92!S97)V97(@86YD(')E
M='5R;G,@=&AE(')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("!4:&4@<F%W(')E<75E<W0@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T:&4@
M<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D<F5Q
M=65S="D*("`@('L*("`@("`@("`D=&AI<RT^7W-E<G9E<BT^4V5R=F5297%U
M97-T*"D["B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*BH*("`@("`J(%=E
M8D1!5B!H86YD;&5S(&%U=&AE;G1I8V%T:6]N(&EN=&5R;F%L;'DL('-O(&)Y
M<&%S<R!T:&4*("`@("`J('-Y<W1E;2UL979E;"!A=71H(&-H96-K(&)Y(&IU
M<W0@<F5T=7)N:6YG('1R=64@:&5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M875T:&]R:7IE*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"GT*"B\J*@H@*B!(;W)D92!E>'1E;G-I;VX@;V8@=&AE(&)A<V4@2%144%]7
M96)$059?4V5R=F5R(&-L87-S+@H@*@H@*B!`<&%C:V%G92!(;W)D95]24$,*
M("HO"F-L87-S($A45%!?5V5B1$%67U-E<G9E<E](;W)D92!E>'1E;F1S($A4
M5%!?5V5B1$%67U-E<G9E<B!["@H@("`@+RHJ"B`@("`@*B!296%L;2!S=')I
M;F<@=&\@8F4@=7-E9"!I;B!A=71H96YT:69I8V%T:6]N('!O<'5P<PH@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:'1T<%]A
M=71H7W)E86QM(#T@)TAO<F1E(%=E8D1!5B<["@H@("`@+RHJ"B`@("`@*B!3
M=')I;F<@=&\@8F4@=7-E9"!I;B`B6"U$878M4&]W97)E9"U">2(@:&5A9&5R
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D
M879?<&]W97)E9%]B>2`]("=(;W)D92!796)$058@4V5R=F5R)SL*"B`@("`O
M*BH*("`@("`J($=%5"!I;7!L96UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&]P=&EO;G,@($%R<F%Y(&]F(&EN<'5T(&%N9"!O=71P
M=70@<&%R86UE=&5R<RX*("`@("`J(#QB<CX\<W1R;VYG/FEN<'5T/"]S=')O
M;F<^/'5L/@H@("`@("H@/&QI/B!P871H("T*("`@("`J(#PO=6P^"B`@("`@
M*B`\8G(^/'-T<F]N9SYO=71P=70\+W-T<F]N9SX\=6P^"B`@("`@*B`\;&D^
M('-I>F4@+0H@("`@("H@/"]U;#X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@($A45%`M4W1A='5S8V]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M1T54*"8D;W!T:6]N<RD*("`@('L*("`@("`@("!I9B`H)&]P=&EO;G-;)W!A
M=&@G72`]/2`G+R<I('L*("`@("`@("`@("`@)&]P=&EO;G-;)VUI;65T>7!E
M)UT@/2`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]L:7-T*"1O<'1I;VYS
M6R=P871H)UTL(#`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0550@;65T:&]D(&AA;F1L97(*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1O<'1I;VYS("!087)A;65T97(@
M<&%S<VEN9R!A<G)A>2X*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!0550H)B1O<'1I;VYS
M*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4%)/4$9)3D0@;65T:&]D(&AA;F1L97(*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&]P=&EO;G,@($=E;F5R86P@<&%R86UE=&5R('!A<W-I
M;F<@87)R87DN"B`@("`@*B!`<&%R86T@87)R87D@)B1F:6QE<R`@4F5T=7)N
M(&%R<F%Y(&9O<B!F:6QE('!R;W!E<G1I97,N"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M4%)/4$9)3D0H)&]P=&EO;G,L("8D9FEL97,I"B`@("!["B`@("`@("`@)&QI
M<W0@/2`D=&AI<RT^7VQI<W0H)&]P=&EO;G-;)W!A=&@G72P@)&]P=&EO;G-;
M)V1E<'1H)UTI.PH@("`@("`@(&EF("@D;&ES="`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D9FEL
M97-;)V9I;&5S)UT@/2`D;&ES=#L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("!F=6YC=&EO;B!?;&ES="@D<&%T:"P@)&1E<'1H*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1L:7-T(#T@87)R
M87DH"B`@("`@("`@("`@(&%R<F%Y*"=P871H)R`]/B`D=&AI<RT^<&%T:"P*
M("`@("`@("`@("`@("`@("=P<F]P<R<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FUK<')O<"@G9&ES<&QA>6YA;64G+"`D=&AI<RT^
M<&%T:"DL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G8W)E
M871I;VYD871E)RP@=&EM92@I*2P*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;6MP<F]P*"=G971L87-T;6]D:69I960G+"!T:6UE*"DI+`H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)W)E<V]U<F-E='EP92<L("=C
M;VQL96-T:6]N)RDL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O
M<"@G9V5T8V]N=&5N='1Y<&4G+"`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG*2P*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT
M;&5N9W1H)RP@,"DI*2D["B`@("`@("`@:68@*"1P871H(#T]("<O)RD@>PH@
M("`@("`@("`@("`D87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H;G5L;"P@
M9F%L<V4L(%!%4DU37U)%040I.PH@("`@("`@("`@("!I9B`H:7-?82@D87!P
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1A<'!S
M(&%S("1A<'`I('L*("`@("`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA
M<TUE=&AO9"@G8G)O=W-E)RP@)&%P<"DI('L*("`@("`@("`@("`@("`@("`@
M("`D<')O<',@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FUK<')O<"@G9&ES<&QA>6YA;64G+"!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"DL($Y,4SHZ9V5T0VAA
M<G-E="@I+"`G551&+3@G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YM:W!R;W`H)V-R96%T:6]N9&%T92<L('1I;64H*2DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&QA<W1M;V1I9FEE
M9"<L('1I;64H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM
M:W!R;W`H)W)E<V]U<F-E='EP92<L("=C;VQL96-T:6]N)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O;G1E;G1T>7!E
M)RP@)VAT='!D+W5N:7@M9&ER96-T;W)Y)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O;G1E;G1L96YG=&@G+"`P*2D[
M"B`@("`@("`@("`@("`@("`@("`@)&ET96T@/2!A<G)A>2@G<&%T:"<@/3X@
M)'1H:7,M/G!A=&@@+B`G+R<@+B`D87!P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!R;W!S)R`]/B`D<')O<',I.PH@("`@("`@("`@
M("`@("`@("`@("1L:7-T6UT@/2`D:71E;3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF
M("AS=6)S='(H)'!A=&@L(#`L(#$I(#T]("<O)RD@>PH@("`@("`@("`@("`@
M("`@)'!A=&@@/2!S=6)S='(H)'!A=&@L(#$I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1P:65C97,@/2!E>'!L;V1E*"<O)RP@)'!A=&@I.PH@("`@
M("`@("`@("`D:71E;7,@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)'!I
M96-E<ULP72P@)V)R;W=S92<L(&%R<F%Y*"=P871H)R`]/B`D<&%T:"P@)W!R
M;W!E<G1I97,G(#T^(&%R<F%Y*"=N86UE)RP@)V)R;W=S96%B;&4G+"`G8V]N
M=&5N='1Y<&4G+"`G8V]N=&5N=&QE;F=T:"<L("=C<F5A=&5D)RP@)VUO9&EF
M:65D)RDI*3L*("`@("`@("`@("`@:68@*&ES7V$H)&ET96US+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2AR97-E="@D:71E
M;7,I*2D@>PH@("`@("`@("`@("`@("`@+RH@5V4@<F5T=7)N(&%N(&]B:F5C
M="=S(&-O;G1E;G0N("HO"B`@("`@("`@("`@("`@("!R971U<FX@)&ET96US
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1I=&5M<R!A
M<R`D<W5B7W!A=&@@/3X@)&DI('L*("`@("`@("`@("`@("`@("1P<F]P<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V1I
M<W!L87EN86UE)RP@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D:5LG;F%M92==
M+"!.3%,Z.F=E=$-H87)S970H*2P@)U541BTX)RDI+`H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YM:W!R;W`H)V-R96%T:6]N9&%T92<L(&5M<'1Y*"1I
M6R=C<F5A=&5D)UTI(#\@,"`Z("1I6R=C<F5A=&5D)UTI+`H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&QA<W1M;V1I9FEE9"<L(&5M
M<'1Y*"1I6R=M;V1I9FEE9"==*2`_(#`@.B`D:5LG;6]D:69I960G72DL"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G<F5S;W5R8V5T>7!E
M)RP@)&E;)V)R;W=S96%B;&4G72`_("=C;VQL96-T:6]N)R`Z("<G*2P*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT='EP
M92<L("1I6R=B<F]W<V5A8FQE)UT@/R`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG
M(#H@*&5M<'1Y*"1I6R=C;VYT96YT='EP92==*2`_("=A<'!L:6-A=&EO;B]O
M8W1E="US=')E86TG(#H@)&E;)V-O;G1E;G1T>7!E)UTI*2P*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT;&5N9W1H)RP@
M96UP='DH)&E;)V-O;G1E;G1L96YG=&@G72D@/R`P(#H@)&E;)V-O;G1E;G1L
M96YG=&@G72DI.PH@("`@("`@("`@("`@("`@)&ET96T@/2!A<G)A>2@G<&%T
M:"<@/3X@)R\G("X@)'-U8E]P871H+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<')O<',G(#T^("1P<F]P<RD["B`@("`@("`@("`@("`@("`D
M;&ES=%M=(#T@)&ET96T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@D9&5P=&@I('L*("`@("`@("`@("`@:68@*"1D97!T:"`]/2`Q
M*2!["B`@("`@("`@("`@("`@("`D9&5P=&@@/2`P.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1A<'`@/3X@)&ET96TI
M('L*("`@("`@("`@("`@("`@("\O7VQI<W0H)'!A=&@@+B`G+R<@+B`D:71E
M;2P@)&1E<'1H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1L:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@875T
M:&5N=&EC871I;VXN(%=E(&%L=V%Y<R!R971U<FX@=')U92!H97)E('-I;F-E
M('=E"B`@("`@*B!H86YD;&4@<&5R;6ES<VEO;G,@8F%S960@;VX@=&AE(')E
M<V]U<F-E('1H870G<R!R97%U97-T960L(&)U=`H@("`@("H@=V4@9&\@<F5C
M;W)D('1H92!A=71H96YT:6-A=&5D('5S97(@9F]R(&QA=&5R('5S92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@075T:&5N=&EC
M871I;VX@='EP92P@92YG+B`B8F%S:6,B(&]R(")D:6=E<W0B"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R;F%M92`@5')A;G-M:71T960@=7-E<FYA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5')A;G-M:71T960@
M<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!!=71H
M96YT:6-A=&EO;B!S=&%T=7,N($%L=V%Y<R!T<G5E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C:&5C:U]A=71H*"1T>7!E+"`D=7-E<FYA;64L("1P87-S=V]R
M9"D*("`@('L*("`@("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH)$=,
M3T)!3%-;)V-O;F8G75LG875T:"==6R=D<FEV97(G72D["B`@("`@("`@<F5T
M=7)N("1A=71H+3YA=71H96YT:6-A=&4H)'5S97)N86UE+"!A<G)A>2@G<&%S
M<W=O<F0G(#T^("1P87-S=V]R9"DI.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'``````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R-38R`#$P-#$W,S8R-S<Q
M`#`R,#<P,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($AO<F1E7U)00U]X;6QR<&,@8VQA<W,@
M<')O=FED97,@86X@6$U,4E!#(&EM<&QE;65N=&%T:6]N(&]F('1H90H@*B!(
M;W)D92!24$,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`L=B`Q+CDN,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C,S
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4E!#"B`J+PIC;&%S<R!(
M;W)D95]24$-?>&UL<G!C(&5X=&5N9',@2&]R9&5?4E!#('L*"B`@("`O*BH*
M("`@("`J(%)E<V]U<F-E(&AA;F1L97(@9F]R('1H92!834Q24$,@<V5R=F5R
M+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R
M("1?<V5R=F5R.PH*("`@("\J*@H@("`@("H@6$U,4E!#('-E<G9E<B!C;VYS
M=')U8W1O<@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!(;W)D95]24$-?>&UL<G!C*"D*("`@('L*("`@("`@
M("!P87)E;G0Z.DAO<F1E7U)00R@I.PH*("`@("`@("`D=&AI<RT^7W-E<G9E
M<B`]('AM;')P8U]S97)V97)?8W)E871E*"D["@H@("`@("`@(&9O<F5A8V@@
M*"1'3$]"04Q36R=R96=I<W1R>2==+3YL:7-T365T:&]D<R@I(&%S("1M971H
M;V0I('L*("`@("`@("`@("`@>&UL<G!C7W-E<G9E<E]R96=I<W1E<E]M971H
M;V0H)'1H:7,M/E]S97)V97(L('-T<E]R97!L86-E*"<O)RP@)RXG+"`D;65T
M:&]D*2P@87)R87DH)TAO<F1E7U)00U]X;6QR<&,G+"`G7V1I<W!A=&-H97(G
M*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VQE86YS('5P
M('1H92!24$,@<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:'5T9&]W
M;B@I"B`@("!["B`@("`@("`@>&UL<G!C7W-E<G9E<E]D97-T<F]Y*"1T:&ES
M+3Y?<V5R=F5R*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F1S(&%N(%)0
M0R!R97%U97-T('1O('1H92!S97)V97(@86YD(')E='5R;G,@=&AE(')E<W5L
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!4:&4@<F%W(')E<75E
M<W0@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D<F5Q=65S="D*("`@('L*("`@
M("`@("`D<F5S<&]N<V4@/2!N=6QL.PH@("`@("`@(')E='5R;B!X;6QR<&-?
M<V5R=F5R7V-A;&Q?;65T:&]D*"1T:&ES+3Y?<V5R=F5R+"`D<F5Q=65S="P@
M)')E<W!O;G-E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=I;&P@8F4@<F5G
M:7-T97)E9"!A<R!T:&4@:&%N9&QE<B!F;W(@86QL(&%V86EL86)L92!M971H
M;V1S"B`@("`@*B!A;F0@=VEL;"!C86QL('1H92!A<'!R;W!R:6%T92!F=6YC
M=&EO;B!T:')O=6=H('1H92!R96=I<W1R>2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H
M;V0@(%1H92!N86UE(&]F('1H92!M971H;V0@8V%L;&5D(&)Y('1H92!24$,@
M<F5Q=65S="X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@5&AE('!A
M<W-E9"!P87)A;65T97)S+@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A("`@
M("!5;FMN;W=N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!R
M97-U;'0@;V8@=&AE(&-A;&QE9"!R96=I<W1R>2!M971H;V0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]D:7-P871C:&5R*"1M971H;V0L("1P87)A;7,L("1D
M871A*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@
M)&UE=&AO9"`]('-T<E]R97!L86-E*"<N)RP@)R\G+"`D;65T:&]D*3L*"B`@
M("`@("`@:68@*"$D<F5G:7-T<GDM/FAA<TUE=&AO9"@D;65T:&]D*2D@>PH@
M("`@("`@("`@("!R971U<FX@<W!R:6YT9BA?*")-971H;V0@7"(E<UPB(&ES
M(&YO="!D969I;F5D(BDL("1M971H;V0I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R96=I<W1R>2T^8V%L;"@D;65T:&]D+"`D<&%R86US*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!834Q24$,@<F5Q=65S="!A
M;F0@<V5N9',@:70@=&\@=&AE(%A-3%)00R!S97)V97(N"B`@("`@*@H@("`@
M("H@5&AI<R!S=&%T:6-A;&QY(&-A;&QE9"!M971H;V0@:7,@86-T=6%L;'D@
M=&AE(%A-3%)00R!C;&EE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7)L("`@("!4:&4@<&%T:"!T;R!T:&4@6$U,4E!#('-E<G9E<B!O;B!T
M:&4@8V%L;&5D(&AO<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@
M(%1H92!M971H;V0@=&\@8V%L;"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("`@02!H87-H(&-O;G1A:6YI;F<@86YY(&YE8V5S<V%R>2!P87)A;65T
M97)S(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;65T
M:&]D(&-A;&PN"B`@("`@*B!`<&%R86T@)&]P=&EO;G,@($]P=&EO;F%L(&%S
M<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M971E<G,@=VAI8V@@8V%N(&)E.@H@
M("`@("H@("`@("`@("`@("`@("`@("!U<V5R("`@("`@("`@("`M($)A<VEC
M($%U=&@@=7-E<FYA;64*("`@("`J("`@("`@("`@("`@("`@("`@<&%S<R`@
M("`@("`@("`@+2!"87-I8R!!=71H('!A<W-W;W)D"B`@("`@*B`@("`@("`@
M("`@("`@("`@('!R;WAY7VAO<W0@("`@("T@4')O>'D@<V5R=F5R(&AO<W0*
M("`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?<&]R="`@("`@+2!0<F]X
M>2!S97)V97(@<&]R=`H@("`@("H@("`@("`@("`@("`@("`@("!P<F]X>5]U
M<V5R("`@("`M(%!R;WAY(&%U=&@@=7-E<FYA;64*("`@("`J("`@("`@("`@
M("`@("`@("`@<')O>'E?<&%S<R`@("`@+2!0<F]X>2!A=71H('!A<W-W;W)D
M"B`@("`@*B`@("`@("`@("`@("`@("`@('1I;65O=70@("`@("`@("T@0V]N
M;F5C=&EO;B!T:6UE;W5T(&EN('-E8V]N9',N"B`@("`@*B`@("`@("`@("`@
M("`@("`@(&%L;&]W4F5D:7)E8W1S("T@5VAE=&AE<B!T;R!F;VQL;W<@<F5D
M:7)E8W1S(&]R(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("!M87A2961I
M<F5C=',@("`M($UA>"!N=6UB97(@;V8@<F5D:7)E8W1S('1O(&9O;&QO=PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@("`@("`@("!4:&4@<F5T
M=7)N960@<F5S=6QT(&9R;VT@=&AE(&UE=&AO9"!O<B!A(%!%05(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!E<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5Q=65S="@D=7)L+"`D;65T
M:&]D+"`D<&%R86US(#T@;G5L;"P@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1O<'1I;VYS6R=M971H;V0G72`]("=03U-4)SL*("`@("`@
M("`D;&%N9W5A9V4@/2!I<W-E="@D1TQ/0D%,4ULG;&%N9W5A9V4G72D@/R`D
M1TQ/0D%,4ULG;&%N9W5A9V4G72`Z"B`@("`@("`@("`@("`@("`@("`@*&ES
M<V5T*"1?4T525D526R=,04Y')UTI(#\@)%]315)615);)TQ!3D<G72`Z("<G
M*3L*"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG=&EM96]U="==*2D@
M>PH@("`@("`@("`@("`D;W!T:6]N<ULG=&EM96]U="==(#T@-3L*("`@("`@
M("!]"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG86QL;W=2961I<F5C
M=',G72DI('L*("`@("`@("`@("`@)&]P=&EO;G-;)V%L;&]W4F5D:7)E8W1S
M)UT@/2!T<G5E.PH@("`@("`@("`@("`D;W!T:6]N<ULG;6%X4F5D:7)E8W1S
M)UT@/2`S.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(5%10
M+U)E<75E<W0N<&AP)SL*"B`@("`@("`@)&AT='`@/2`F;F5W($A45%!?4F5Q
M=65S="@D=7)L+"`D;W!T:6]N<RD["B`@("`@("`@:68@*"%E;7!T>2@D;&%N
M9W5A9V4I*2!["B`@("`@("`@("`@("1H='1P+3YA9&1(96%D97(H)T%C8V5P
M="U,86YG=6%G92<L("1L86YG=6%G92D["B`@("`@("`@?0H@("`@("`@("1H
M='1P+3YA9&1(96%D97(H)U5S97(M06=E;G0G+"`G2&]R9&4@4E!#(&-L:65N
M="<I.PH@("`@("`@("1H='1P+3YA9&1(96%D97(H)T-O;G1E;G0M5'EP92<L
M("=T97AT+WAM;"<I.PH@("`@("`@("1H='1P+3YA9&1287=0;W-T1&%T82AX
M;6QR<&-?96YC;V1E7W)E<75E<W0H)&UE=&AO9"P@)'!A<F%M<RDI.PH*("`@
M("`@("`D<F5S=6QT(#T@)&AT='`M/G-E;F1297%U97-T*"D["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V5I9B`H)&AT='`M/F=E
M=%)E<W!O;G-E0V]D92@I("$](#(P,"D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(I("X@)&AT='`M/F=E=%)E<W!O
M;G-E0V]D92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V5I9B`H
M<W1R<&]S*"1H='1P+3YG971297-P;VYS94)O9'DH*2P@)SP_>&UL)RD@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(BDL("=H;W)D92YE<G)O
M<B<L(&YU;&PL(&YU;&PL("1H='1P+3YG971297-P;VYS94)O9'DH*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W!O;G-E(#T@0'AM;')P
M8U]D96-O9&4H<W5B<W1R*"1H='1P+3YG971297-P;VYS94)O9'DH*2P@<W1R
M<&]S*"1H='1P+3YG971297-P;VYS94)O9'DH*2P@)SP_>&UL)RDI*3L*("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1R97-P;VYS92D@)B8@:7-S970H)')E
M<W!O;G-E6R=F875L=%-T<FEN9R==*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)')E<W!O;G-E6R=F875L=%-T<FEN9R==
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R
M<F%Y*"1R97-P;VYS92D@)B8@:7-S970H)')E<W!O;G-E6S!=*2`F)@H@("`@
M("`@("`@("`@("`@("`@("`@:7-?87)R87DH)')E<W!O;G-E6S!=*2`F)B!I
M<W-E="@D<F5S<&]N<V5;,%U;)V9A=6QT4W1R:6YG)UTI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<F5S<&]N<V5;,%U;
M)V9A=6QT4W1R:6YG)UTL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O0VEP:&5R+P``````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<Q`#`Q-S0T-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O0FQO8VM-;V1E+P``````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S$`,#(Q
M,S`T`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]"
M;&]C:TUO9&4O8V)C+G!H<```````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#<P
M,P`Q,#0Q-S,V,C<W,0`P,C(U-#4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H
M97)?0FQO8VM-;V1E7V-B8SHZ(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4*
M("H@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!U<VEN9R!T:&4@0VEP:&5R($)L
M;V-K($-H86EN:6YG(&UE=&AO9"!O9@H@*B!E;F-R>7!T:6YG(&)L;V-K<R!O
M9B!D871A+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R
M+T)L;V-K36]D92]C8F,N<&AP+'8@,2XW+C$R+C4@,C`P-B\P,2\P,2`R,3HR
M.#HQ,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E
M($AO<F1E7T-I<&AE<@H@*B\*8VQA<W,@2&]R9&5?0VEP:&5R7T)L;V-K36]D
M95]C8F,@97AT96YD<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E('L*"B`@("`O
M*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A
M<F%M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I=&AM('1O
M('5S92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M96YC<GEP=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@
M("`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M("!4:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N
M8W)Y<'0H)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@("!["B`@("`@("`@)&5N
M8W)Y<'1E9"`]("<G.PH*("`@("`@("`D8FQO8VMS:7IE(#T@)&-I<&AE<BT^
M9V5T0FQO8VM3:7IE*"D["B`@("`@("`@)'!R979I;W5S0VEP:&5R(#T@)'1H
M:7,M/E]I=CL*"B`@("`@("`@)&I-87@@/2!S=')L96XH)'!L86EN=&5X="D[
M"B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J("L]("1B;&]C
M:W-I>F4I('L*("`@("`@("`@("`@)'!L86EN(#T@<W5B<W1R*"1P;&%I;G1E
M>'0L("1J+"`D8FQO8VMS:7IE*3L*"B`@("`@("`@("`@(&EF("AS=')L96XH
M)'!L86EN*2`\("1B;&]C:W-I>F4I('L*("`@("`@("`@("`@("`@("\O('!A
M9"!T:&4@8FQO8VL@=VET:"!<,"=S(&EF(&ET)W,@;F]T(&QO;F<@96YO=6=H
M"B`@("`@("`@("`@("`@("`D<&QA:6X@/2!S=')?<&%D*"1P;&%I;BP@."P@
M(EPP(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1P;&%I;B`]("1P
M;&%I;B!>("1P<F5V:6]U<T-I<&AE<CL*("`@("`@("`@("`@)'!R979I;W5S
M0VEP:&5R(#T@)&-I<&AE<BT^96YC<GEP=$)L;V-K*"1P;&%I;BD["B`@("`@
M("`@("`@("1E;F-R>7!T960@+CT@)'!R979I;W5S0VEP:&5R.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1E;F-R>7!T960["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96-R>7!T(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2!(;W)D95]#:7!H97(@)&-I<&AE<B`@0VEP:&5R(&%L9V]R:71H;2!T;R!U
M<V4@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E
M8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:7!H97)T97AT("`@
M(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R;B`@
M5&AE(&1E8W)Y<'1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R
M>7!T*"8D8VEP:&5R+"`D8VEP:&5R=&5X="D*("`@('L*("`@("`@("`D9&5C
M<GEP=&5D(#T@)R<["@H@("`@("`@("1B;&]C:W-I>F4@/2`D8VEP:&5R+3YG
M971";&]C:U-I>F4H*3L*("`@("`@("`D<')E=FEO=7-#:7!H97(@/2`D=&AI
M<RT^7VEV.PH*("`@("`@("`D:DUA>"`]('-T<FQE;B@D8VEP:&5R=&5X="D[
M"B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J("L]("1B;&]C
M:W-I>F4I('L*("`@("`@("`@("`@)'!L86EN(#T@<W5B<W1R*"1C:7!H97)T
M97AT+"`D:BP@)&)L;V-K<VEZ92D["B`@("`@("`@("`@("1D96-R>7!T960@
M+CT@)&-I<&AE<BT^9&5C<GEP=$)L;V-K*"1P;&%I;BD@7B`D<')E=FEO=7-#
M:7!H97(["B`@("`@("`@("`@("1P<F5V:6]U<T-I<&AE<B`]("1P;&%I;CL*
M("`@("`@("!]"@H@("`@("`@("\O(%)E;6]V92!T<F%I;&EN9R!<,"=S('5S
M960@=&\@<&%D('1H92!L87-T(&)L;V-K+@H@("`@("`@('=H:6QE("AS=6)S
M='(H)&1E8W)Y<'1E9"P@+3$L(#$I(#T](")<,"(I('L*("`@("`@("`@("`@
M)&1E8W)Y<'1E9"`]('-U8G-T<B@D9&5C<GEP=&5D+"`P+"`M,2D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T-I<&AE<B]";&]C:TUO9&4O8V9B-C0N<&AP````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#8V-``Q,#0Q-S,V,C<W,0`P,C(W,S``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V-F8C8T.CH@5&AI<R!C;&%S<R!I
M;7!L96UE;G1S('1H90H@*B!(;W)D95]#:7!H97)?0FQO8VM-;V1E('5S:6YG
M(&$@-C0@8FET(&-I<&AE<B!F965D8F%C:RX*("H*("H@5&AI<R!C86X@8F4@
M=7-E9"!T;R!E;F-R>7!T(&%N>2!L96YG=&@@<W1R:6YG(&%N9"!T:&4@96YC
M<GEP=&5D"B`J('9E<G-I;VX@=VEL;"!B92!T:&4@<V%M92!L96YG=&@N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O0FQO8VM-;V1E
M+V-F8C8T+G!H<"QV(#$N-RXQ,BXU(#(P,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#
M:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]";&]C:TUO9&5?8V9B-C0@
M97AT96YD<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E('L*"B`@("`O*BH*("`@
M("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M($AO
M<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I=&AM('1O('5S92!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96YC<GEP
M=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@5&AE
M(&1A=&$@=&\@96YC<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N("!4:&4@
M96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H
M)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@("!["B`@("`@("`@)&5N8W)Y<'1E
M9"`]("<G.PH*("`@("`@("`D;B`](#`["B`@("`@("`@)&I-87@@/2!S=')L
M96XH)'!L86EN=&5X="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-
M87@[("1J*RLI('L*("`@("`@("`@("`@:68@*"1N(#T](#`I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:78@/2`D8VEP:&5R+3YE;F-R>7!T0FQO8VLH
M)'1H:7,M/E]I=BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C(#T@
M)'!L86EN=&5X=%LD:ET@7B`D=&AI<RT^7VEV6R1N73L*("`@("`@("`@("`@
M)'1H:7,M/E]I=B`]('-U8G-T<B@D=&AI<RT^7VEV+"`P+"`D;BD@+B`D8R`N
M('-U8G-T<B@D=&AI<RT^7VEV+"`D;B`K(#$I.PH@("`@("`@("`@("`D96YC
M<GEP=&5D("X]("1C.PH*("`@("`@("`@("`@)&X@/2`H*RLD;BD@)B`P>#`W
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E;F-R>7!T960["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@<W1R:6YG+@H@("`@("H*("`@
M("`J($!P87)A;2!(;W)D95]#:7!H97(@)&-I<&AE<B`@0VEP:&5R(&%L9V]R
M:71H;2!T;R!U<V4@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&1E8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:7!H
M97)T97AT("`@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*@H@("`@("H@
M0')E='5R;B`@5&AE(&1E8W)Y<'1E9"!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D96-R>7!T*"8D8VEP:&5R+"`D8VEP:&5R=&5X="D*("`@('L*("`@
M("`@("`D9&5C<GEP=&5D(#T@)R<["@H@("`@("`@("1N(#T@,#L*("`@("`@
M("`D:DUA>"`]('-T<FQE;B@D8VEP:&5R=&5X="D["B`@("`@("`@9F]R("@D
M:B`](#`[("1J(#P@)&I-87@[("1J*RLI('L*("`@("`@("`@("`@:68@*"1N
M(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:78@/2`D8VEP:&5R
M+3YE;F-R>7!T0FQO8VLH)'1H:7,M/E]I=BD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1C(#T@)&-I<&AE<G1E>'1;)&I=(%X@)'1H:7,M/E]I=ELD
M;ET["B`@("`@("`@("`@("1T:&ES+3Y?:78@/2!S=6)S='(H)'1H:7,M/E]I
M=BP@,"P@)&XI("X@<W5B<W1R*"1C:7!H97)T97AT+"`D:BP@,2D@+B!S=6)S
M='(H)'1H:7,M/E]I=BP@)&X@*R`Q*3L*("`@("`@("`@("`@)&1E8W)Y<'1E
M9"`N/2`D8SL*"B`@("`@("`@("`@("1N(#T@*"LK)&XI("8@,'@P-SL*("`@
M("`@("!]"@H@("`@("`@("\O(%)E;6]V92!T<F%I;&EN9R!<,"=S('5S960@
M=&\@<&%D('1H92!L87-T(&)L;V-K+@H@("`@("`@('=H:6QE("AS=6)S='(H
M)&1E8W)Y<'1E9"P@+3$L(#$I(#T](")<,"(I('L*("`@("`@("`@("`@)&1E
M8W)Y<'1E9"`]('-U8G-T<B@D9&5C<GEP=&5D+"`P+"`M,2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O96-B+G!H<```````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#,S-@`Q,#0Q-S,V,C<W,0`P,C(U-3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V5C8CHZ(%1H
M:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4*("H@2&]R9&5?0VEP:&5R7T)L;V-K
M36]D92!U<VEN9R!T:&4@16QE8W1R;VYI8R!#;V1E($)O;VL@;65T:&]D(&]F
M"B`J(&5N8W)Y<'1I;F<@8FQO8VMS(&]F(&1A=&$N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O0FQO8VM-;V1E+V5C8BYP:'`L=B`Q
M+C<N,3(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C$Q(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@
M("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S
M<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V5C8B!E>'1E;F1S($AO<F1E7T-I
M<&AE<E]";&]C:TUO9&4@>PH*("`@("\J*@H@("`@("H@16YC<GEP="!A('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?0VEP:&5R("1C:7!H
M97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!E;F-R>7!T:6]N+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&QA:6YT97AT("`@("!4:&4@9&%T82!T;R!E;F-R>7!T
M+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!E;F-R>7!T960@9&%T82X*
M("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP="@F)&-I<&AE<BP@)'!L86EN
M=&5X="D*("`@('L*("`@("`@("`D96YC<GEP=&5D(#T@)R<["B`@("`@("`@
M)&)L;V-K<VEZ92`]("1C:7!H97(M/F=E=$)L;V-K4VEZ92@I.PH*("`@("`@
M("`D:DUA>"`]('-T<FQE;B@D<&QA:6YT97AT*3L*("`@("`@("!F;W(@*"1J
M(#T@,#L@)&H@/"`D:DUA>#L@)&H@*ST@)&)L;V-K<VEZ92D@>PH@("`@("`@
M("`@("`D<&QA:6X@/2!S=6)S='(H)'!L86EN=&5X="P@)&HL("1B;&]C:W-I
M>F4I.PH*("`@("`@("`@("`@:68@*'-T<FQE;B@D<&QA:6XI(#P@)&)L;V-K
M<VEZ92D@>PH@("`@("`@("`@("`@("`@+R\@<&%D('1H92!B;&]C:R!W:71H
M(%PP)W,@:68@:70G<R!N;W0@;&]N9R!E;F]U9V@*("`@("`@("`@("`@("`@
M("1P;&%I;B`]('-T<E]P860H)'!L86EN+"`X+"`B7#`B*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&5N8W)Y<'1E9"`N/2`D8VEP:&5R+3YE;F-R
M>7!T0FQO8VLH)'!L86EN*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M96YC<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?0VEP:&5R("1C:7!H
M97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!D96-R>7!T:6]N+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8VEP:&5R=&5X="`@("!4:&4@9&%T82!T;R!D96-R>7!T
M+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!D96-R>7!T960@9&%T82X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP="@F)&-I<&AE<BP@)&-I<&AE
M<G1E>'0I"B`@("!["B`@("`@("`@)&1E8W)Y<'1E9"`]("<G.PH@("`@("`@
M("1B;&]C:W-I>F4@/2`D8VEP:&5R+3YG971";&]C:U-I>F4H*3L*"B`@("`@
M("`@)&I-87@@/2!S=')L96XH)&-I<&AE<G1E>'0I.PH@("`@("`@(&9O<B`H
M)&H@/2`P.R`D:B`\("1J36%X.R`D:B`K/2`D8FQO8VMS:7IE*2!["B`@("`@
M("`@("`@("1P;&%I;B`]('-U8G-T<B@D8VEP:&5R=&5X="P@)&HL("1B;&]C
M:W-I>F4I.PH@("`@("`@("`@("`D9&5C<GEP=&5D("X]("1C:7!H97(M/F1E
M8W)Y<'1";&]C:R@D<&QA:6XI.PH@("`@("`@('T*"B`@("`@("`@+R\@4F5M
M;W9E('1R86EL:6YG(%PP)W,@=7-E9"!T;R!P860@=&AE(&QA<W0@8FQO8VLN
M"B`@("`@("`@=VAI;&4@*'-U8G-T<B@D9&5C<GEP=&5D+"`M,2P@,2D@/3T@
M(EPP(BD@>PH@("`@("`@("`@("`D9&5C<GEP=&5D(#T@<W5B<W1R*"1D96-R
M>7!T960L(#`L("TQ*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&5C
M<GEP=&5D.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O
M;V9B-C0N<&AP````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#`W-@`Q,#0Q-S,V
M,C<W,0`P,C(W-#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-
M;V1E7V]F8C8T.CH@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H90H@*B!(;W)D
M95]#:7!H97)?0FQO8VM-;V1E('5S:6YG(&$@-C0@8FET(&]U='!U="!F965D
M8F%C:RX*("H*("H@5&AI<R!C86X@=7-E9"!T;R!E;F-R>7!T(&%N>2!L96YG
M=&@@<W1R:6YG(&%N9"!T:&4@96YC<GEP=&5D('9E<G-I;VX*("H@=VEL;"!B
M92!T:&4@<V%M92!L96YG=&@N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I
M<&AE<B]#:7!H97(O0FQO8VM-;V1E+V]F8C8T+G!H<"QV(#$N-RXQ,BXU(#(P
M,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN
M>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#(N
M,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I
M<&AE<E]";&]C:TUO9&5?;V9B-C0@97AT96YD<R!(;W)D95]#:7!H97)?0FQO
M8VM-;V1E('L*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N"B`@
M("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H
M97(@86QG;W)I=&AM('1O('5S92!F;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@96YC<GEP=&EO;BX*("`@("`J($!P87)A;2!S=')I
M;F<@)'!L86EN=&5X="`@("`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N("!4:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5N8W)Y<'0H)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@
M("!["B`@("`@("`@)&5N8W)Y<'1E9"`]("<G.PH*("`@("`@("`D;B`](#`[
M"B`@("`@("`@)&I-87@@/2!S=')L96XH)'!L86EN=&5X="D["B`@("`@("`@
M9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J*RLI('L*("`@("`@("`@("`@
M:68@*"1N(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:78@/2`D
M8VEP:&5R+3YE;F-R>7!T0FQO8VLH)'1H:7,M/E]I=BD["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1C(#T@)'!L86EN=&5X=%LD:ET@7B`D=&AI<RT^
M7VEV6R1N73L*("`@("`@("`@("`@)&5N8W)Y<'1E9"`N/2`D8SL*"B`@("`@
M("`@("`@("1N(#T@*"LK)&XI("8@,'@P-SL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D96YC<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C
M<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?0VEP
M:&5R("1C:7!H97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D96-R>7!T:6]N+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VEP:&5R=&5X="`@("!4:&4@9&%T82!T
M;R!D96-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!D96-R>7!T
M960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP="@F)&-I<&AE
M<BP@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@)&1E8W)Y<'1E9"`]("<G
M.PH*("`@("`@("`D;B`](#`["B`@("`@("`@)&I-87@@/2!S=')L96XH)&-I
M<&AE<G1E>'0I.PH@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D
M:BLK*2!["B`@("`@("`@("`@(&EF("@D;B`]/2`P*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VEV(#T@)&-I<&AE<BT^96YC<GEP=$)L;V-K*"1T:&ES
M+3Y?:78I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8R`]("1C:7!H
M97)T97AT6R1J72!>("1T:&ES+3Y?:79;)&Y=.PH@("`@("`@("`@("`D9&5C
M<GEP=&5D("X]("1C.PH*("`@("`@("`@("`@)&X@/2`H*RLD;BD@)B`P>#`W
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D96-R>7!T960["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE
M<B]B;&]W9FES:"YP:'``````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U
M-S4P-``Q,#0Q-S,V,C<W,0`P,C(P,#,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!#:7!H97)?
M8FQO=V9I<V@Z.B!C;&%S<R!I;7!L96UE;G1S('1H92!#:7!H97(@:6YT97)F
M86-E(&5N8W)Y<'1I;VX@9&%T80H@*B!U<VEN9R!T:&4@0FQO=V9I<V@@86QG
M;W)I=&AM+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R
M+V)L;W=F:7-H+G!H<"QV(#$N,30N,3(N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C$P
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R
M9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?8FQO=V9I<V@@97AT
M96YD<R!(;W)D95]#:7!H97(@>PH*("`@("\J*@H@("`@("H@4&D@07)R87D*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<"`]
M(&%R<F%Y*`H@("`@("`@(#!X,C0S1C9!.#@L(#!X.#5!,S`X1#,L(#!X,3,Q
M.3A!,D4L(#!X,#,W,#<S-#0L"B`@("`@("`@,'A!-#`Y,S@R,BP@,'@R.3E&
M,S%$,"P@,'@P.#)%1D$Y."P@,'A%0S1%-D,X.2P*("`@("`@("`P>#0U,C@R
M,44V+"`P>#,X1#`Q,S<W+"`P>$)%-30V-D-&+"`P>#,T13DP0S9#+`H@("`@
M("`@(#!X0S!!0S(Y0C<L(#!X0SDW0S4P1$0L(#!X,T8X-$0U0C4L(#!X0C4T
M-S`Y,3<L"B`@("`@("`@,'@Y,C$V1#5$.2P@,'@X.3<Y1D(Q0BD["@H@("`@
M+RHJ"B`@("`@*B!3($)O>"`H<S$I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)',Q(#T@87)R87DH"B`@("`@("`@,'A$,3,Q
M,$)!-BP@,'@Y.$1&0C5!0RP@,'@R1D9$-S)$0BP@,'A$,#%!1$9"-RP*("`@
M("`@("`P>$(X13%!1D5$+"`P>#9!,C8W13DV+"`P>$)!-T,Y,#0U+"`P>$8Q
M,D,W1CDY+`H@("`@("`@(#!X,C1!,3DY-#<L(#!X0C,Y,39#1C<L(#!X,#@P
M,48R13(L(#!X.#4X149#,38L"B`@("`@("`@,'@V,S8Y,C!$."P@,'@W,34W
M-$4V.2P@,'A!-#4X1D5!,RP@,'A&-#DS,T0W12P*("`@("`@("`P>#!$.34W
M-#A&+"`P>#<R.$5"-C4X+"`P>#<Q.$)#1#4X+"`P>#@R,34T045%+`H@("`@
M("`@(#!X-T(U-$$T,40L(#!X0S(U034Y0C4L(#!X.4,S,$0U,SDL(#!X,D%&
M,C8P,3,L"B`@("`@("`@,'A#-40Q0C`R,RP@,'@R.#8P.#5&,"P@,'A#030Q
M-SDQ."P@,'A".$1",SA%1BP*("`@("`@("`P>#A%-SE$0T(P+"`P>#8P,T$Q
M.#!%+"`P>#9#.44P13A"+"`P>$(P,44X03-%+`H@("`@("`@(#!X1#<Q-3<W
M0S$L(#!X0D0S,31",C<L(#!X-SA!1C)&1$$L(#!X-34V,#5#-C`L"B`@("`@
M("`@,'A%-C4U,C5&,RP@,'A!034U04(Y-"P@,'@U-S0X.3@V,BP@,'@V,T4X
M,30T,"P*("`@("`@("`P>#4U0T$S.39!+"`P>#)!04(Q,$(V+"`P>$(T0T,U
M0S,T+"`P>#$Q-#%%.$-%+`H@("`@("`@(#!X03$U-#@V048L(#!X-T,W,D4Y
M.3,L(#!X0C-%13$T,3$L(#!X-C,V1D)#,D$L"B`@("`@("`@,'@R0D$Y0S4U
M1"P@,'@W-#$X,S%&-BP@,'A#135#,T4Q-BP@,'@Y0C@W.3,Q12P*("`@("`@
M("`P>$%&1#9"03,S+"`P>#9#,C1#1C5#+"`P>#=!,S(U,S@Q+"`P>#(X.34X
M-C<W+`H@("`@("`@(#!X,T(X1C0X.3@L(#!X-D(T0D(Y048L(#!X0S1"1D4X
M,4(L(#!X-C8R.#(Q.3,L"B`@("`@("`@,'@V,40X,#E#0RP@,'A&0C(Q03DY
M,2P@,'@T.#=#04,V,"P@,'@U1$5#.#`S,BP*("`@("`@("`P>$5&.#0U1#5$
M+"`P>$4Y.#4W-4(Q+"`P>$1#,C8R,S`R+"`P>$5"-C4Q0C@X+`H@("`@("`@
M(#!X,C,X.3-%.#$L(#!X1#,Y-D%#0S4L(#!X,$8V1#9&1C,L(#!X.#-&-#0R
M,SDL"B`@("`@("`@,'@R13!"-#0X,BP@,'A!-#@T,C`P-"P@,'@V.4,X1C`T
M02P@,'@Y13%&.4(U12P*("`@("`@("`P>#(Q0S8V.#0R+"`P>$8V13DV0SE!
M+"`P>#8W,$,Y0S8Q+"`P>$%"1#,X.$8P+`H@("`@("`@(#!X-D$U,4$P1#(L
M(#!X1#@U-#)&-C@L(#!X.38P1D$W,C@L(#!X04(U,3,S03,L"B`@("`@("`@
M,'@V145&,$(V0RP@,'@Q,S=!,T)%-"P@,'A"03-"1C`U,"P@,'@W149",D$Y
M."P*("`@("`@("`P>$$Q1C$V-3%$+"`P>#,Y048P,3<V+"`P>#8V0T$U.3-%
M+"`P>#@R-#,P13@X+`H@("`@("`@(#!X.$-%13@V,3DL(#!X-#4V1CE&0C0L
M(#!X-T0X-$$U0S,L(#!X,T(X0C5%0D4L"B`@("`@("`@,'A%,#9&-S5$."P@
M,'@X-4,Q,C`W,RP@,'@T,#%!-#0Y1BP@,'@U-D,Q-D%!-BP*("`@("`@("`P
M>#1%1#-!038R+"`P>#,V,T8W-S`V+"`P>#%"1D5$1C<R+"`P>#0R.4(P,C-$
M+`H@("`@("`@(#!X,S=$,$0W,C0L(#!X1#`P03$R-#@L(#!X1$(P1D5!1#,L
M(#!X-#E&,4,P.4(L"B`@("`@("`@,'@P-S4S-S)#.2P@,'@X,#DY,4(W0BP@
M,'@R-40T-SE$."P@,'A&-D4X1$5&-RP*("`@("`@("`P>$4S1D4U,#%!+"`P
M>$(V-SDT0S-"+"`P>#DW-D-%,$)$+"`P>#`T0S`P-D)!+`H@("`@("`@(#!X
M0S%!.31&0C8L(#!X-#`Y1C8P0S0L(#!X-44U0SE%0S(L(#!X,3DV03(T-C,L
M"B`@("`@("`@,'@V.$9"-D9!1BP@,'@S139#-3-"-2P@,'@Q,S,Y0C)%0BP@
M,'@S0C4R14,V1BP*("`@("`@("`P>#9$1D,U,3%&+"`P>#E",S`Y-3)#+"`P
M>$-#.#$T-30T+"`P>$%&-45"1#`Y+`H@("`@("`@(#!X0D5%,T0P,#0L(#!X
M1$4S,S1!1D0L(#!X-C8P1C(X,#<L(#!X,3DR131"0C,L"B`@("`@("`@,'A#
M,$-"03@U-RP@,'@T-4,X-S0P1BP@,'A$,C!"-48S.2P@,'A".40S1D)$0BP*
M("`@("`@("`P>#4U-SE#,$)$+"`P>#%!-C`S,C!!+"`P>$0V03$P,$,V+"`P
M>#0P,D,W,C<Y+`H@("`@("`@(#!X-C<Y1C(U1D4L(#!X1D(Q1D$S0T,L(#!X
M.$5!-44Y1C@L(#!X1$(S,C(R1C@L"B`@("`@("`@,'@S0S<U,39$1BP@,'A&
M1#8Q-D(Q-2P@,'@R1C4P,45#."P@,'A!1#`U-3)!0BP*("`@("`@("`P>#,R
M,T1"-49!+"`P>$9$,C,X-S8P+"`P>#4S,S$W0C0X+"`P>#-%,#!$1C@R+`H@
M("`@("`@(#!X.44U0S4W0D(L(#!X0T$V1CA#03`L(#!X,4$X-S4V,D4L(#!X
M1$8Q-S8Y1$(L"B`@("`@("`@,'A$-30R03A&-BP@,'@R.#=%1D9#,RP@,'A!
M0S8W,S)#-BP@,'@X0S1&-34W,RP*("`@("`@("`P>#8Y-4(R-T(P+"`P>$)"
M0T$U.$,X+"`P>$4Q1D9!,S5$+"`P>$(X1C`Q,4$P+`H@("`@("`@(#!X,3!&
M03-$.3@L(#!X1D0R,3@S0C@L(#!X-$%&0T(U-D,L(#!X,D1$,40S-4(L"B`@
M("`@("`@,'@Y034S130W.2P@,'A"-D8X-#4V-2P@,'A$,CA%-#E"0RP@,'@T
M0D9".3<Y,"P*("`@("`@("`P>$4Q1$1&,D1!+"`P>$$T0T(W13,S+"`P>#8R
M1D(Q,S0Q+"`P>$-%131#-D4X+`H@("`@("`@(#!X148R,$-!1$$L(#!X,S8W
M-S1#,#$L(#!X1#`W13E%1D4L(#!X,D)&,3%&0C0L"B`@("`@("`@,'@Y-41"
M1$$T1"P@,'A!13DP.3$Y."P@,'A%04%$.$4W,2P@,'@V0CDS1#5!,"P*("`@
M("`@("`P>$0P.$5$,40P+"`P>$%&0S<R-44P+"`P>#A%,T,U0C)&+"`P>#A%
M-S4Y-$(W+`H@("`@("`@(#!X.$9&-D4R1D(L(#!X1C(Q,C)"-C0L(#!X.#@X
M.$(X,3(L(#!X.3`P1$8P,4,L"B`@("`@("`@,'@T1D%$-45!,"P@,'@V.#A&
M0S,Q0RP@,'A$,4-&1C$Y,2P@,'A",T$X0S%!1"P*("`@("`@("`P>#)&,D8R
M,C$X+"`P>$)%,$4Q-S<W+"`P>$5!-S4R1$9%+"`P>#A",#(Q1D$Q+`H@("`@
M("`@(#!X135!,$-#,$8L(#!X0C4V1C<T13@L(#!X,3A!0T8S1#8L(#!X0T4X
M.44R.3DL"B`@("`@("`@,'A"-$$X-$9%,"P@,'A&1#$S13!"-RP@,'@W0T,T
M,T(X,2P@,'A$,D%$03A$.2P*("`@("`@("`P>#$V-49!,C8V+"`P>#@P.34W
M-S`U+"`P>#DS0T,W,S$T+"`P>#(Q,4$Q-#<W+`H@("`@("`@(#!X139!1#(P
M-C4L(#!X-S="-49!.#8L(#!X0S<U-#0R1C4L(#!X1D(Y1#,U0T8L"B`@("`@
M("`@,'A%0D-$048P0RP@,'@W0C-%.#E!,"P@,'A$-C0Q,4)$,RP@,'A!13%%
M-T4T.2P*("`@("`@("`P>#`P,C4P13)$+"`P>#(P-S%",S5%+"`P>#(R-C@P
M,$)"+"`P>#4W0CA%,$%&+`H@("`@("`@(#!X,C0V-#,V.4(L(#!X1C`P.4(Y
M,44L(#!X-34V,SDQ,40L(#!X-3E$1D$V04$L"B`@("`@("`@,'@W.$,Q-#,X
M.2P@,'A$.35!-3,W1BP@,'@R,#=$-4)!,BP@,'@P,D4U0CE#-2P*("`@("`@
M("`P>#@S,C8P,S<V+"`P>#8R.35#1D$Y+"`P>#$Q0S@Q.38X+"`P>#1%-S,T
M030Q+`H@("`@("`@(#!X0C,T-S)$0T$L(#!X-T(Q-$$Y-$$L(#!X,4(U,3`P
M-3(L(#!X.4$U,S(Y,34L"B`@("`@("`@,'A$-C!&-3<S1BP@,'A"0SE"0S9%
M-"P@,'@R0C8P030W-BP@,'@X,44V-S0P,"P*("`@("`@("`P>#`X0D$V1D(U
M+"`P>#4W,4)%.3%&+"`P>$8R.39%0S9"+"`P>#)!,$1$.3$U+`H@("`@("`@
M(#!X0C8V,S8U,C$L(#!X13=".48Y0C8L(#!X1D8S-#`U,D4L(#!X0S4X-34V
M-C0L"B`@("`@("`@,'@U,T(P,D0U1"P@,'A!.3E&.$9!,2P@,'@P.$)!-#<Y
M.2P@,'@V13@U,#<V02D["@H@("`@+RHJ"B`@("`@*B!3($)O>"`H<S(I"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',R(#T@
M87)R87DH"B`@("`@("`@,'@T0C=!-S!%.2P@,'A"-4(S,CDT-"P@,'A$0C<U
M,#DR12P@,'A#-#$Y,C8R,RP*("`@("`@("`P>$%$-D5!-D(P+"`P>#0Y03=$
M1C=$+"`P>#E#144V,$(X+"`P>#A&141",C8V+`H@("`@("`@(#!X14-!03A#
M-S$L(#!X-CDY03$W1D8L(#!X-38V-#4R-D,L(#!X0S)",3E%13$L"B`@("`@
M("`@,'@Q.3,V,#)!-2P@,'@W-3`Y-$,R.2P@,'A!,#4Y,3,T,"P@,'A%-#$X
M,T$S12P*("`@("`@("`P>#-&-30Y.#E!+"`P>#5"-#(Y1#8U+"`P>#9".$9%
M-$0V+"`P>#DY1C<S1D0V+`H@("`@("`@(#!X03%$,CE#,#<L(#!X149%.#,P
M1C4L(#!X-$0R1#,X138L(#!X1C`R-35$0S$L"B`@("`@("`@,'@T0T1$,C`X
M-BP@,'@X-#<P14(R-BP@,'@V,S@R13E#-BP@,'@P,C%%0T,U12P*("`@("`@
M("`P>#`Y-C@V0C-&+"`P>#-%0D%%1D,Y+"`P>#-#.3<Q.#$T+"`P>#9"-D$W
M,$$Q+`H@("`@("`@(#!X-C@W1C,U.#0L(#!X-3)!,$4R.#8L(#!X0C<Y0S4S
M,#4L(#!X04$U,#`W,S<L"B`@("`@("`@,'@S13`W.#0Q0RP@,'@W1D1%044U
M0RP@,'@X13=$-#1%0RP@,'@U-S$V1C)"."P*("`@("`@("`P>$(P,T%$03,W
M+"`P>$8P-3`P0S!$+"`P>$8P,4,Q1C`T+"`P>#`R,#!",T9&+`H@("`@("`@
M(#!X044P0T8U,4$L(#!X,T-"-3<T0C(L(#!X,C4X,S=!-3@L(#!X1$,P.3(Q
M0D0L"B`@("`@("`@,'A$,3DQ,3-&.2P@,'@W0T$Y,D9&-BP@,'@Y-#,R-#<W
M,RP@,'@R,D8U-#<P,2P*("`@("`@("`P>#-!135%-3@Q+"`P>#,W0S)$041#
M+"`P>$,X0C4W-C,T+"`P>#E!1C-$1$$W+`H@("`@("`@(#!X03DT-#8Q-#8L
M(#!X,$9$,#`S,$4L(#!X14-#.$,W,T4L(#!X030W-3%%-#$L"B`@("`@("`@
M,'A%,C,X0T0Y.2P@,'@S0D5!,$4R1BP@,'@S,C@P0D)!,2P@,'@Q.#-%0C,S
M,2P*("`@("`@("`P>#1%-30X0C,X+"`P>#1&-D1".3`X+"`P>#9&-#(P1#`S
M+"`P>$8V,$$P-$)&+`H@("`@("`@(#!X,D-".#$R.3`L(#!X,C0Y-S=#-SDL
M(#!X-38W.4(P-S(L(#!X0D-!1C@Y048L"B`@("`@("`@,'A$13E!-S<Q1BP@
M,'A$.3DS,#@Q,"P@,'A",SA"044Q,BP@,'A$0T-&,T8R12P*("`@("`@("`P
M>#4U,3(W,C%&+"`P>#)%-D(W,3(T+"`P>#4P,4%$1$4V+"`P>#E&.#1#1#@W
M+`H@("`@("`@(#!X-T$U.#0W,3@L(#!X-S0P.$1!,3<L(#!X0D,Y1CE!0D,L
M(#!X13DT0C=$.$,L"B`@("`@("`@,'A%0S=!14,S02P@,'A$0C@U,41&02P@
M,'@V,S`Y-#,V-BP@,'A#-#8T0S-$,BP*("`@("`@("`P>$5&,4,Q.#0W+"`P
M>#,R,35$.3`X+"`P>$1$-#,S0C,W+"`P>#(T0S)"03$V+`H@("`@("`@(#!X
M,3)!,31$-#,L(#!X,D$V-4,T-3$L(#!X-3`Y-#`P,#(L(#!X,3,S044T1$0L
M"B`@("`@("`@,'@W,41&1C@Y12P@,'@Q,#,Q-$4U-2P@,'@X,4%#-S=$-BP@
M,'@U1C$Q,3DY0BP*("`@("`@("`P>#`T,S4U-D8Q+"`P>$0W03-#-S9"+"`P
M>#-#,3$Q.#-"+"`P>#4Y,C1!-3`Y+`H@("`@("`@(#!X1C(X1D4V140L(#!X
M.3=&,49"1D$L(#!X.45"04)&,D,L(#!X,44Q-3-#-D4L"B`@("`@("`@,'@X
M-D4S-#4W,"P@,'A%044Y-D9",2P@,'@X-C!%-44P02P@,'@U03-%,D%",RP*
M("`@("`@("`P>#<W,49%-S%#+"`P>#1%,T0P-D9!+"`P>#(Y-C5$0T(Y+"`P
M>#DY13<Q1#!&+`H@("`@("`@(#!X.#`S13@Y1#8L(#!X-3(V-D,X,C4L(#!X
M,D4T0T,Y-S@L(#!X.4,Q,$(S-D$L"B`@("`@("`@,'A#-C$U,$5"02P@,'@Y
M-$4R14$W."P@,'A!-49#,T,U,RP@,'@Q13!!,D1&-"P*("`@("`@("`P>$8R
M1C<T14$W+"`P>#,V,40R0C-$+"`P>#$Y,SDR-C!&+"`P>#$Y0S(W.38P+`H@
M("`@("`@(#!X-3(R,T$W,#@L(#!X1C<Q,S$R0C8L(#!X14)!1$9%-D4L(#!X
M14%#,S%&-C8L"B`@("`@("`@,'A%,T)#-#4Y-2P@,'A!-C="0S@X,RP@,'A"
M,3=&,S=$,2P@,'@P,3A#1D8R."P*("`@("`@("`P>$,S,S)$1$5&+"`P>$)%
M-D,U04$U+"`P>#8U-3@R,3@U+"`P>#8X04(Y.#`R+`H@("`@("`@(#!X145#
M14$U,$8L(#!X1$(R1CDU,T(L(#!X,D%%1C=$040L(#!X-4(V13)&.#0L"B`@
M("`@("`@,'@Q-3(Q0C8R."P@,'@R.3`W-C$W,"P@,'A%0T1$-#<W-2P@,'@V
M,3E&,34Q,"P*("`@("`@("`P>#$S0T-!.#,P+"`P>$5"-C%"1#DV+"`P>#`S
M,S1&13%%+"`P>$%!,#,V,T-&+`H@("`@("`@(#!X0C4W,S5#.3`L(#!X-$,W
M,$$R,SDL(#!X1#4Y13E%,$(L(#!X0T)!041%,30L"B`@("`@("`@,'A%14-#
M.#9"0RP@,'@V,#8R,D-!-RP@,'@Y0T%"-4-!0BP@,'A",D8S.#0V12P*("`@
M("`@("`P>#8T.$(Q14%&+"`P>#$Y0D1&,$-!+"`P>$$P,C,V.4(Y+"`P>#8U
M-4%"0C4P+`H@("`@("`@(#!X-#`V.#5!,S(L(#!X,T,R04(T0C,L(#!X,S$Y
M144Y1#4L(#!X0S`R,4(X1C<L"B`@("`@("`@,'@Y0C4T,$(Q.2P@,'@X-S5&
M03`Y.2P@,'@Y-48W.3DW12P@,'@V,C-$-T1!."P*("`@("`@("`P>$8X,S<X
M.#E!+"`P>#DW13,R1#<W+"`P>#$Q140Y,S5&+"`P>#$V-C@Q,C@Q+`H@("`@
M("`@(#!X,$4S-3@X,CDL(#!X0S=%-C%&1#8L(#!X.39$141&03$L(#!X-S@U
M.$)!.3DL"B`@("`@("`@,'@U-T8U.#1!-2P@,'@Q0C(R-S(V,RP@,'@Y0C@S
M0S-&1BP@,'@Q04,R-#8Y-BP*("`@("`@("`P>$-$0C,P045"+"`P>#4S,D4S
M,#4T+"`P>#A&1#DT.$4T+"`P>#9$0D,S,3(X+`H@("`@("`@(#!X-3A%0D8R
M148L(#!X,S1#-D9&14$L(#!X1D4R.$5$-C$L(#!X144W0S-#-S,L"B`@("`@
M("`@,'@U1#1!,31$.2P@,'A%.#8T0C=%,RP@,'@T,C$P-40Q-"P@,'@R,#-%
M,3-%,"P*("`@("`@("`P>#0U145%,D(V+"`P>$$S04%!0D5!+"`P>$1"-D,T
M1C$U+"`P>$9!0T(T1D0P+`H@("`@("`@(#!X0S<T,D8T-#(L(#!X148V04)"
M0C4L(#!X-C4T1C-",40L(#!X-#%#1#(Q,#4L"B`@("`@("`@,'A$.#%%-SDY
M12P@,'@X-C@U-$1#-RP@,'A%-#1"-#<V02P@,'@S1#@Q-C(U,"P*("`@("`@
M("`P>$-&-C)!,48R+"`P>#5".$0R-C0V+"`P>$9#.#@X,T$P+"`P>$,Q0S="
M-D$S+`H@("`@("`@(#!X-T8Q-3(T0S,L(#!X-CE#0C<T.3(L(#!X-#<X-#A!
M,$(L(#!X-38Y,D(R.#4L"B`@("`@("`@,'@P.35"0D8P,"P@,'A!1#$Y-#@Y
M1"P@,'@Q-#8R0C$W-"P@,'@R,S@R,$4P,"P*("`@("`@("`P>#4X-#(X1#)!
M+"`P>#!#-35&-45!+"`P>#%$041&-#-%+"`P>#(S,T8W,#8Q+`H@("`@("`@
M(#!X,S,W,D8P.3(L(#!X.$0Y,S=%-#$L(#!X1#8U1D5#1C$L(#!X-D,R,C-"
M1$(L"B`@("`@("`@,'@W0T1%,S<U.2P@,'A#0D5%-S0V,"P@,'@T,#@U1C)!
M-RP@,'A#13<W,S(V12P*("`@("`@("`P>$$V,#<X,#@T+"`P>#$Y1C@U,#E%
M+"`P>$4X149$.#4U+"`P>#8Q1#DY-S,U+`H@("`@("`@(#!X03DV.4$W04$L
M(#!X0S4P0S`V0S(L(#!X-4$P-$%"1D,L(#!X.#`P0D-!1$,L"B`@("`@("`@
M,'@Y130T-T$R12P@,'A#,S0U,S0X-"P@,'A&1$0U-C<P-2P@,'@P13%%.45#
M.2P*("`@("`@("`P>$1"-S-$0D0S+"`P>#$P-34X.$-$+"`P>#8W-49$03<Y
M+"`P>$4S-C<T,S0P+`H@("`@("`@(#!X0S5#-#,T-C4L(#!X-S$S13,X1#@L
M(#!X,T0R.$8X.44L(#!X1C$V1$9&,C`L"B`@("`@("`@,'@Q-3-%,C%%-RP@
M,'@X1D(P,T0T02P@,'A%-D4S.48R0BP@,'A$0C@S041&-RD["@H@("`@+RHJ
M"B`@("`@*B!3($)O>"`H<S,I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)',S(#T@87)R87DH"B`@("`@("`@,'A%.3-$-4$V
M."P@,'@Y-#@Q-#!&-RP@,'A&-C1#,C8Q0RP@,'@Y-#8Y,CDS-"P*("`@("`@
M("`P>#0Q,34R,$8W+"`P>#<V,#)$-$8W+"`P>$)#1C0V0C)%+"`P>$0T03(P
M,#8X+`H@("`@("`@(#!X1#0P.#(T-S$L(#!X,S,R,$8T-D$L(#!X-#-"-T0T
M0C<L(#!X-3`P,#8Q048L"B`@("`@("`@,'@Q13,Y1C8R12P@,'@Y-S(T-#4T
M-BP@,'@Q-#(Q-$8W-"P@,'A"1CA".#@T,"P*("`@("`@("`P>#1$.35&0S%$
M+"`P>#DV0C4Y,4%&+"`P>#<P1C1$1$0S+"`P>#8V03`R1C0U+`H@("`@("`@
M(#!X0D9"0S`Y14,L(#!X,#-"1#DW.#4L(#!X-T9!0S9$1#`L(#!X,S%#0C@U
M,#0L"B`@("`@("`@,'@Y-D5",C=",RP@,'@U-49$,SDT,2P@,'A$03(U-#=%
M-BP@,'A!0D-!,$$Y02P*("`@("`@("`P>#(X-3`W.#(U+"`P>#4S,#0R.48T
M+"`P>#!!,D,X-D1!+"`P>$4Y0C8V1$9"+`H@("`@("`@(#!X-CA$0S$T-C(L
M(#!X1#<T.#8Y,#`L(#!X-C@P14,P030L(#!X,C=!,3A$144L"B`@("`@("`@
M,'@T1C-&1D5!,BP@,'A%.#@W040X0RP@,'A"-3A#13`P-BP@,'@W048T1#9"
M-BP*("`@("`@("`P>$%!0T4Q13=#+"`P>$0S,S<U1D5#+"`P>$-%-SA!,SDY
M+"`P>#0P-D(R030R+`H@("`@("`@(#!X,C!&13E%,S4L(#!X1#E&,S@U0CDL
M(#!X144S.40W04(L(#!X,T(Q,C1%.$(L"B`@("`@("`@,'@Q1$,Y1D%&-RP@
M,'@T0C9$,3@U-BP@,'@R-D$S-C8S,2P@,'A%044S.3=",BP*("`@("`@("`P
M>#-!-D5&03<T+"`P>$1$-4(T,S,R+"`P>#8X-#%%-T8W+"`P>$-!-S@R,$9"
M+`H@("`@("`@(#!X1D(P048U-$4L(#!X1#A&14(S.3<L(#!X-#4T,#4V04,L
M(#!X0D$T.#DU,C<L"B`@("`@("`@,'@U-34S,T$S02P@,'@R,#@S.$0X-RP@
M,'A&139"03E"-RP@,'A$,#DV.34T0BP*("`@("`@("`P>#4U03@V-T)#+"`P
M>$$Q,34Y034X+"`P>$-#03DR.38S+"`P>#DY13%$0C,S+`H@("`@("`@(#!X
M038R031!-38L(#!X,T8S,3(U1CDL(#!X-45&-#=%,4,L(#!X.3`R.3,Q-T,L
M"B`@("`@("`@,'A&1$8X13@P,BP@,'@P-#(W,D8W,"P@,'@X,$)",34U0RP@
M,'@P-3(X,D-%,RP*("`@("`@("`P>#DU0S$Q-30X+"`P>$4T0S8V1#(R+"`P
M>#0X0S$Q,S-&+"`P>$,W,$8X-D1#+`H@("`@("`@(#!X,#=&.4,Y144L(#!X
M-#$P-#%&,$8L(#!X-#`T-S<Y030L(#!X-40X.#9%,3<L"B`@("`@("`@,'@S
M,C5&-3%%0BP@,'A$-3E"0S!$,2P@,'A&,D)#0S$X1BP@,'@T,3$Q,S4V-"P*
M("`@("`@("`P>#(U-T(W.#,T+"`P>#8P,D$Y0S8P+"`P>$1&1CA%.$$S+"`P
M>#%&-C,V0S%"+`H@("`@("`@(#!X,$4Q,D(T0S(L(#!X,#)%,3,R.44L(#!X
M048V-C1&1#$L(#!X0T%$,3@Q,34L"B`@("`@("`@,'@V0C(S.35%,"P@,'@S
M,S-%.3)%,2P@,'@S0C(T,$(V,BP@,'A%14)%0CDR,BP*("`@("`@("`P>#@U
M0C)!,C!%+"`P>$4V0D$P1#DY+"`P>$1%-S(P0SA#+"`P>#)$03)&-S(X+`H@
M("`@("`@(#!X1#`Q,C<X-#4L(#!X.35"-SDT1D0L(#!X-C0W1#`X-C(L(#!X
M13=#0T8U1C`L"B`@("`@("`@,'@U-#0Y03,V1BP@,'@X-S=$-#A&02P@,'A#
M,SE$1D0R-RP@,'A&,S-%.$0Q12P*("`@("`@("`P>#!!-#<V,S0Q+"`P>#DY
M,D5&1C<T+"`P>#-!-D8V14%"+"`P>$8T1CA&1#,W+`H@("`@("`@(#!X03@Q
M,D1#-C`L(#!X03%%0D1$1C@L(#!X.3DQ0D4Q-$,L(#!X1$(V139",$0L"B`@
M("`@("`@,'A#-C="-34Q,"P@,'@V1#8W,D,S-RP@,'@R-S8U1#0S0BP@,'A$
M0T0P13@P-"P*("`@("`@("`P>$8Q,CDP1$,W+"`P>$-#,#!&1D$S+"`P>$(U
M,SDP1CDR+"`P>#8Y,$9%1#!"+`H@("`@("`@(#!X-C8W0CE&1D(L(#!X0T5$
M0C=$.4,L(#!X03`Y,4-&,$(L(#!X1#DQ-35%03,L"B`@("`@("`@,'A"0C$S
M,D8X."P@,'@U,35"040R-"P@,'@W0CDT-SE"1BP@,'@W-C-"1#9%0BP*("`@
M("`@("`P>#,W,SDR14(S+"`P>$-#,3$U.3<Y+"`P>#@P,C9%,CDW+"`P>$8T
M,D4S,3)$+`H@("`@("`@(#!X-C@T,D%$03<L(#!X0S8V03)",T(L(#!X,3(W
M-31#0T,L(#!X-S@R148Q,4,L"B`@("`@("`@,'@V03$R-#(S-RP@,'A"-SDR
M-3%%-RP@,'@P-D$Q0D)%-BP@,'@T0D9"-C,U,"P*("`@("`@("`P>#%!-D(Q
M,#$X+"`P>#$Q0T%%1$9!+"`P>#-$,C5"1$0X+"`P>$4R13%#,T,Y+`H@("`@
M("`@(#!X-#0T,C$V-3DL(#!X,$$Q,C$S.#8L(#!X1#DP0T5#-D4L(#!X1#5!
M0D5!,D$L"B`@("`@("`@,'@V-$%&-C<T12P@,'A$03@V03@U1BP@,'A"14)&
M13DX."P@,'@V-$4T0S-&12P*("`@("`@("`P>#E$0D,X,#4W+"`P>$8P1C=#
M,#@V+"`P>#8P-S@W0D8X+"`P>#8P,#,V,#1$+`H@("`@("`@(#!X1#%&1#@S
M-#8L(#!X1C8S.#%&0C`L(#!X-S<T-4%%,#0L(#!X1#<S-D9#0T,L"B`@("`@
M("`@,'@X,S0R-D(S,RP@,'A&,#%%04(W,2P@,'A",#@P-#$X-RP@,'@S0S`P
M-44U1BP*("`@("`@("`P>#<W03`U-T)%+"`P>$)$13A!13(T+"`P>#4U-#8T
M,CDY+"`P>$)&-3@R138Q+`H@("`@("`@(#!X-$4U.$8T.$8L(#!X1C)$1$9$
M03(L(#!X1C0W-$5&,S@L(#!X.#<X.4)$0S(L"B`@("`@("`@,'@U,S8V1CE#
M,RP@,'A#.$(S.$4W-"P@,'A"-#<U1C(U-2P@,'@T-D9#1#E".2P*("`@("`@
M("`P>#=!14(R-C8Q+"`P>#A",41$1C@T+"`P>#@T-D$P13<Y+"`P>#DQ-48Y
M-44R+`H@("`@("`@(#!X-#8V134Y.$4L(#!X,C!"-#4W-S`L(#!X.$-$-34U
M.3$L(#!X0SDP,D1%-$,L"B`@("`@("`@,'A".3!"04-%,2P@,'A"0C@R,#5$
M,"P@,'@Q,4$X-C(T."P@,'@W-3<T03DY12P*("`@("`@("`P>$(W-T8Q.4(V
M+"`P>$4P03E$0S`Y+"`P>#8V,D0P.4$Q+"`P>$,T,S(T-C,S+`H@("`@("`@
M(#!X13@U03%&,#(L(#!X,#E&,$)%.$,L(#!X-$$Y.4$P,C4L(#!X,40V149%
M,3`L"B`@("`@("`@,'@Q04(Y,T0Q1"P@,'@P0D$U031$1BP@,'A!,3@V1C(P
M1BP@,'@R.#8X1C$V.2P*("`@("`@("`P>$1#0C=$03@S+"`P>#4W,SDP-D9%
M+"`P>$$Q13)#13E"+"`P>#1&0T0W1C4R+`H@("`@("`@(#!X-3`Q,35%,#$L
M(#!X03<P-C@S1D$L(#!X03`P,D(U0S0L(#!X,$1%-D0P,C<L"B`@("`@("`@
M,'@Y048X.$,R-RP@,'@W-S-&.#8T,2P@,'A#,S8P-$,P-BP@,'@V,4$X,#9"
M-2P*("`@("`@("`P>$8P,3<W03(X+"`P>$,P1C4X-D4P+"`P>#`P-C`U.$%!
M+"`P>#,P1$,W1#8R+`H@("`@("`@(#!X,3%%-CE%1#<L(#!X,C,S.$5!-C,L
M(#!X-3-#,D1$.30L(#!X0S)#,C$V,S0L"B`@("`@("`@,'A"0D-"144U-BP@
M,'@Y,$)#0C9$12P@,'A%0D9#-T1!,2P@,'A#134Y,40W-BP*("`@("`@("`P
M>#9&,#5%-#`Y+"`P>#1"-T,P,3@X+"`P>#,Y-S(P03-$+"`P>#=#.3(W0S(T
M+`H@("`@("`@(#!X.#9%,S<R-48L(#!X-S(T1#E$0CDL(#!X,4%#,35"0C0L
M(#!X1#,Y14(X1D,L"B`@("`@("`@,'A%1#4T-34W."P@,'@P.$9#035"-2P@
M,'A$.#-$-T-$,RP@,'@T1$%$,$9#-"P*("`@("`@("`P>#%%-3!%1C5%+"`P
M>$(Q-C%%-D8X+"`P>$$R.#4Q-$0Y+"`P>#9#-3$Q,S-#+`H@("`@("`@(#!X
M-D9$-4,W13<L(#!X-39%,31%0S0L(#!X,S8R04)&0T4L(#!X1$1#-D,X,S<L
M"B`@("`@("`@,'A$-SE!,S(S-"P@,'@Y,C8S.#(Q,BP@,'@V-S!%1D$X12P@
M,'@T,#8P,#!%,"D["@H@("`@+RHJ"B`@("`@*B!3($)O>"`H<S0I"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',T(#T@87)R
M87DH"B`@("`@("`@,'@S03,Y0T4S-RP@,'A$,T9!1C5#1BP@,'A!0D,R-S<S
M-RP@,'@U04,U,D0Q0BP*("`@("`@("`P>#5#0C`V-SE%+"`P>#1&03,S-S0R
M+"`P>$0S.#(R-S0P+"`P>#DY0D,Y0D)%+`H@("`@("`@(#!X1#4Q,3A%.40L
M(#!X0D8P1C<S,34L(#!X1#8R1#%#-T4L(#!X0S<P,$,T-T(L"B`@("`@("`@
M,'A"-SA#,4(V0BP@,'@R,4$Q.3`T-2P@,'A",C9%0C%"12P@,'@V03,V-D5"
M-"P*("`@("`@("`P>#4W-#A!0C)&+"`P>$)#.30V13<Y+"`P>$,V03,W-D0R
M+"`P>#8U-#E#,D,X+`H@("`@("`@(#!X-3,P1D8X144L(#!X-#8X1$1%-T0L
M(#!X1#4W,S!!,40L(#!X-$-$,#1$0S8L"B`@("`@("`@,'@R.3,Y0D)$0BP@
M,'A!.4)!-#8U,"P@,'A!0SDU,C9%."P@,'A"135%13,P-"P*("`@("`@("`P
M>$$Q1D%$-48P+"`P>#9!,D0U,3E!+"`P>#8S148X0T4R+"`P>#E!.#9%13(R
M+`H@("`@("`@(#!X0S`X.4,R0C@L(#!X-#,R-#)%1C8L(#!X034Q13`S04$L
M(#!X.4-&,D0P030L"B`@("`@("`@,'@X,T,P-C%"02P@,'@Y0D4Y-D$T1"P@
M,'@X1D4U,34U,"P@,'A"038T-4)$-BP*("`@("`@("`P>#(X,C9!,D8Y+"`P
M>$$W,T$S044Q+"`P>#1"03DY-3@V+"`P>$5&-34V,D4Y+`H@("`@("`@(#!X
M0S<R1D5&1#,L(#!X1C<U,D8W1$$L(#!X,T8P-#9&-CDL(#!X-S=&03!!-3DL
M"B`@("`@("`@,'@X,$4T03DQ-2P@,'@X-T(P.#8P,2P@,'@Y0C`Y139!1"P@
M,'@S0C-%134Y,RP*("`@("`@("`P>$4Y.3!&1#5!+"`P>#E%,S1$-SDW+"`P
M>#)#1C!"-T0Y+"`P>#`R,D(X0C4Q+`H@("`@("`@(#!X.39$-4%#,T$L(#!X
M,#$W1$$V-T0L(#!X1#%#1C-%1#8L(#!X-T,W1#)$,C@L"B`@("`@("`@,'@Q
M1CE&,C5#1BP@,'A!1$8R0C@Y0BP@,'@U040V0C0W,BP@,'@U03@X1C4T0RP*
M("`@("`@("`P>$4P,CE!0S<Q+"`P>$4P,3E!-44V+"`P>#0W0C!!0T9$+"`P
M>$5$.3-&03E"+`H@("`@("`@(#!X13A$,T,T.$0L(#!X,C@S0C4W0T,L(#!X
M1CA$-38V,CDL(#!X-SDQ,S)%,C@L"B`@("`@("`@,'@W.#5&,#$Y,2P@,'A%
M1#<U-C`U-2P@,'A&-SDV,$4T-"P@,'A%,T0S-44X0RP*("`@("`@("`P>#$U
M,#4V1$0T+"`P>#@X1C0V1$)!+"`P>#`S03$V,3(U+"`P>#`U-C1&,$)$+`H@
M("`@("`@(#!X0S-%0CE%,34L(#!X,T,Y,#4W03(L(#!X.3<R-S%!14,L(#!X
M03DS03`W,D$L"B`@("`@("`@,'@Q0C-&-D0Y0BP@,'@Q138S,C%&-2P@,'A&
M-3E#-C9&0BP@,'@R-D1#1C,Q.2P*("`@("`@("`P>#<U,S-$.3(X+"`P>$(Q
M-35&1$8U+"`P>#`S-38S-#@R+"`P>#A!0D$S0T)"+`H@("`@("`@(#!X,C@U
M,3<W,3$L(#!X0S(P040Y1C@L(#!X04)#0S4Q-C<L(#!X0T-!1#DR-48L"B`@
M("`@("`@,'@T1$4X,3<U,2P@,'@S.#,P1$,X12P@,'@S-SE$-3@V,BP@,'@Y
M,S(P1CDY,2P*("`@("`@("`P>$5!-T$Y,$,R+"`P>$9",T4W0D-%+"`P>#4Q
M,C%#138T+"`P>#<W-$9"13,R+`H@("`@("`@(#!X03A"-D4S-T4L(#!X0S,R
M.3-$-#8L(#!X-#A$134S-CDL(#!X-C0Q,T4V.#`L"B`@("`@("`@,'A!,D%%
M,#@Q,"P@,'A$1#9$0C(R-"P@,'@V.3@U,D1&1"P@,'@P.3`W,C$V-BP*("`@
M("`@("`P>$(S.4$T-C!!+"`P>#8T-#5#,$1$+"`P>#4X-D-$14-&+"`P>#%#
M,C!#.$%%+`H@("`@("`@(#!X-4)"148W1$0L(#!X,4(U.#A$-#`L(#!X0T-$
M,C`Q-T8L(#!X-D)"-$4S0D(L"B`@("`@("`@,'A$1$$R-D$W12P@,'@S034Y
M1D8T-2P@,'@S13,U,$$T-"P@,'A"0T(T0T1$-2P*("`@("`@("`P>#<R14%#
M14$X+"`P>$9!-C0X-$)"+"`P>#A$-C8Q,D%%+"`P>$)&,T,V1C0W+`H@("`@
M("`@(#!X1#(Y0D4T-C,L(#!X-30R1C5$.44L(#!X045#,C<W,4(L(#!X1C8T
M138S-S`L"B`@("`@("`@,'@W-#!%,$0X1"P@,'A%-S5",3,U-RP@,'A&.#<R
M,38W,2P@,'A!1C4S-T0U1"P*("`@("`@("`P>#0P-#!#0C`X+"`P>#1%0C1%
M,D-#+"`P>#,T1#(T-C9!+"`P>#`Q,35!1C@T+`H@("`@("`@(#!X13%",#`T
M,C@L(#!X.34Y.#-!,40L(#!X,#9".#E&0C0L(#!X0T4V14$P-#@L"B`@("`@
M("`@,'@V1C-&,T(X,BP@,'@S-3(P04(X,BP@,'@P,3%!,40T0BP@,'@R-S<R
M,C=&."P*("`@("`@("`P>#8Q,34V,$(Q+"`P>$4W.3,S1D1#+"`P>$)",T$W
M.3)"+"`P>#,T-#4R-4)$+`H@("`@("`@(#!X03`X.#,Y13$L(#!X-3%#13<Y
M-$(L(#!X,D8S,D,Y0C<L(#!X03`Q1D)!0SDL"B`@("`@("`@,'A%,#%#0S@W
M12P@,'A"0T,W1#%&-BP@,'A#1C`Q,3%#,RP@,'A!,44X04%#-RP*("`@("`@
M("`P>#%!.3`X-S0Y+"`P>$0T-$9"1#E!+"`P>$0P1$%$14-"+"`P>$0U,$%$
M03,X+`H@("`@("`@(#!X,#,S.4,S,D$L(#!X0S8Y,3,V-C<L(#!X.$1&.3,Q
M-T,L(#!X13!",3)"-$8L"B`@("`@("`@,'A&-SE%-3E"-RP@,'@T,T8U0D(S
M02P@,'A&,D0U,3E&1BP@,'@R-T0Y-#4Y0RP*("`@("`@("`P>$)&.3<R,C)#
M+"`P>#$U139&0S)!+"`P>#!&.3%&0S<Q+"`P>#E".30Q-3(U+`H@("`@("`@
M(#!X1D%%-3DS-C$L(#!X0T5"-CE#14(L(#!X0S)!.#8T-3DL(#!X,3)"04$X
M1#$L"B`@("`@("`@,'A"-D,Q,#<U12P@,'A%,S`U-D$P0RP@,'@Q,$0R-3`V
M-2P@,'A#0C`S030T,BP*("`@("`@("`P>$4P14,V13!%+"`P>#$V.3A$0C-"
M+"`P>#1#.3A!,$)%+"`P>#,R-SA%.38T+`H@("`@("`@(#!X.48Q1CDU,S(L
M(#!X13!$,SDR1$8L(#!X1#-!,#,T,D(L(#!X.#DW,48R,44L"B`@("`@("`@
M,'@Q0C!!-S0T,2P@,'@T0D$S,S0X0RP@,'A#-4)%-S$R,"P@,'A#,S<V,S)$
M."P*("`@("`@("`P>$1&,S4Y1CA$+"`P>#E".3DR1C)%+"`P>$4V,$(V1C0W
M+"`P>#!&13-&,3%$+`H@("`@("`@(#!X134T0T1!-30L(#!X,45$040X.3$L
M(#!X0T4V,C<Y0T8L(#!X0T0S13=%-D8L"B`@("`@("`@,'@Q-C$X0C$V-BP@
M,'A&1#)#,40P-2P@,'@X-#A&1#)#-2P@,'A&-D9",C(Y.2P*("`@("`@("`P
M>$8U,C-&,S4W+"`P>$$V,S(W-C(S+"`P>#DS03@S-3,Q+"`P>#4V0T-#1#`R
M+`H@("`@("`@(#!X04-&,#@Q-C(L(#!X-4$W-45"0C4L(#!X-D4Q-C,V.3<L
M(#!X.#A$,C<S0T,L"B`@("`@("`@,'A$13DV-C(Y,BP@,'@X,4(Y-#E$,"P@
M,'@T0S4P.3`Q0BP@,'@W,4,V-38Q-"P*("`@("`@("`P>$4V0S9#-T)$+"`P
M>#,R-T$Q-#!!+"`P>#0U13%$,#`V+"`P>$,S1C(W0CE!+`H@("`@("`@(#!X
M0SE!034S1D0L(#!X-C)!.#!&,#`L(#!X0D(R-4)&13(L(#!X,S5"1$0R1C8L
M"B`@("`@("`@,'@W,3$R-CDP-2P@,'A",C`T,#(R,BP@,'A"-D-"0T8W0RP@
M,'A#1#<V.4,R0BP*("`@("`@("`P>#4S,3$S14,P+"`P>#$V-#!%,T0S+"`P
M>#,X04)"1#8P+"`P>#(U-#=!1$8P+`H@("`@("`@(#!X0D$S.#(P.4,L(#!X
M1C<T-D-%-S8L(#!X-S=!1D$Q0S4L(#!X,C`W-38P-C`L"B`@("`@("`@,'@X
M-4-"1D4T12P@,'@X044X.$1$."P@,'@W04%!1CE","P@,'@T0T8Y04$W12P*
M("`@("`@("`P>#$Y-#A#,C5#+"`P>#`R1D(X03A#+"`P>#`Q0S,V044T+"`P
M>$0V14)%,48Y+`H@("`@("`@(#!X.3!$-$8X-CDL(#!X038U0T1%03`L(#!X
M,T8P.3(U,D0L(#!X0S(P.$4V.48L"B`@("`@("`@,'A"-S1%-C$S,BP@,'A#
M13<W13(U0BP@,'@U-SA&1$9%,RP@,'@S04,S-S)%-BD["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;G5M8F5R(&]F(')O=6YD<R!T;R!D;PH@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]R;W5N9',@/2`Q-CL*
M"B`@("`O*BH*("`@("`J(%-E="!T:&4@:V5Y('1O(&)E('5S960@9F]R(&5N
M+V1E8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y
M("!4:&4@:V5Y('1O('5S92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2V5Y
M*"1K97DI"B`@("!["B`@("`@("`@)&ME>2`]("1T:&ES+3Y?9F]R;6%T2V5Y
M*"1K97DI.PH@("`@("`@("1K97E0;W,@/2`P.PH@("`@("`@("1K97E8;W(@
M/2`P.PH*("`@("`@("`D:4UA>"`](&-O=6YT*"1T:&ES+3YP*3L*("`@("`@
M("`D:V5Y3&5N(#T@8V]U;G0H)&ME>2D["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&E-87@[("1I*RLI('L*("`@("`@("`@("`@9F]R("@D="`](#`[
M("1T(#P@-#L@)'0K*RD@>PH@("`@("`@("`@("`@("`@)&ME>5AO<B`]("@D
M:V5Y6&]R(#P\(#@I('P@*"@D:V5Y6R1K97E0;W-=*2`F(#!X,&9F*3L*("`@
M("`@("`@("`@("`@(&EF("@K*R1K97E0;W,@/3T@)&ME>4QE;BD@>PH@("`@
M("`@("`@("`@("`@("`@("1K97E0;W,@/2`P.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YP6R1I72`]("1T
M:&ES+3YP6R1I72!>("1K97E8;W(["B`@("`@("`@?0H*("`@("`@("`D96YC
M6F5R;R`](&%R<F%Y*"=,)R`]/B`P+"`G4B<@/3X@,"D["B`@("`@("`@9F]R
M("@D:2`](#`[("1I("L@,2`\("1I36%X.R`D:2`K/2`R*2!["B`@("`@("`@
M("`@("1E;F-:97)O(#T@)'1H:7,M/E]E;F-R>7!T0FQO8VLH)&5N8UIE<F];
M)TPG72P@)&5N8UIE<F];)U(G72D["B`@("`@("`@("`@("1T:&ES+3YP6R1I
M72`]("1E;F-:97)O6R=,)UT["B`@("`@("`@("`@("1T:&ES+3YP6R1I("L@
M,5T@/2`D96YC6F5R;ULG4B==.PH@("`@("`@('T*"B`@("`@("`@)&E-87@@
M/2!C;W5N="@D=&AI<RT^<S$I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1I36%X.R`D:2`K/2`R*2!["B`@("`@("`@("`@("1E;F-:97)O(#T@)'1H
M:7,M/E]E;F-R>7!T0FQO8VLH)&5N8UIE<F];)TPG72P@)&5N8UIE<F];)U(G
M72D["B`@("`@("`@("`@("1T:&ES+3YS,5LD:5T@/2`D96YC6F5R;ULG3"==
M.PH@("`@("`@("`@("`D=&AI<RT^<S%;)&D@*R`Q72`]("1E;F-:97)O6R=2
M)UT["B`@("`@("`@?0H*("`@("`@("`D:4UA>"`](&-O=6YT*"1T:&ES+3YS
M,BD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&E-87@[("1I("L](#(I
M('L*("`@("`@("`@("`@)&5N8UIE<F\@/2`D=&AI<RT^7V5N8W)Y<'1";&]C
M:R@D96YC6F5R;ULG3"==+"`D96YC6F5R;ULG4B==*3L*("`@("`@("`@("`@
M)'1H:7,M/G,R6R1I72`]("1E;F-:97)O6R=,)UT["B`@("`@("`@("`@("1T
M:&ES+3YS,ELD:2`K(#%=(#T@)&5N8UIE<F];)U(G73L*("`@("`@("!]"@H@
M("`@("`@("1I36%X(#T@8V]U;G0H)'1H:7,M/G,S*3L*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D:4UA>#L@)&D@*ST@,BD@>PH@("`@("`@("`@("`D
M96YC6F5R;R`]("1T:&ES+3Y?96YC<GEP=$)L;V-K*"1E;F-:97)O6R=,)UTL
M("1E;F-:97)O6R=2)UTI.PH@("`@("`@("`@("`D=&AI<RT^<S-;)&E=(#T@
M)&5N8UIE<F];)TPG73L*("`@("`@("`@("`@)'1H:7,M/G,S6R1I("L@,5T@
M/2`D96YC6F5R;ULG4B==.PH@("`@("`@('T*"B`@("`@("`@)&E-87@@/2!C
M;W5N="@D=&AI<RT^<S0I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I
M36%X.R`D:2`K/2`R*2!["B`@("`@("`@("`@("1E;F-:97)O(#T@)'1H:7,M
M/E]E;F-R>7!T0FQO8VLH)&5N8UIE<F];)TPG72P@)&5N8UIE<F];)U(G72D[
M"B`@("`@("`@("`@("1T:&ES+3YS-%LD:5T@/2`D96YC6F5R;ULG3"==.PH@
M("`@("`@("`@("`D=&AI<RT^<S1;)&D@*R`Q72`]("1E;F-:97)O6R=2)UT[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!S
M:7IE(&]F('1H92!B;&]C:W,@=&AA="!T:&ES(&-I<&AE<B!N965D<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@8VAA
M<F%C=&5R<R!P97(@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L
M;V-K4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N(#@["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%;F-R>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@("`@(%1H92!D871A('1O(&5N
M8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@("`@(%1H92!K
M97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M96YC<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP
M=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3YS971+97DH
M)&ME>2D["B`@("`@("`@?0H*("`@("`@("!L:7-T*"1,+"`D4BD@/2!A<G)A
M>5]V86QU97,H=6YP86-K*"=.*B<L("1B;&]C:RDI.PH@("`@("`@("1P87)T
M<R`]("1T:&ES+3Y?96YC<GEP=$)L;V-K*"1,+"`D4BD["B`@("`@("`@<F5T
M=7)N('!A8VLH)TY.)RP@)'!A<G1S6R=,)UTL("1P87)T<ULG4B==*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@;&5F="!A;F0@<FEG:'0@:&%L
M=F5S(&]F(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D3"`@3&5F
M="!H86QF(&]F('1H92!D871A+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)%(@
M(%)I9VAT(&AA;&8@;V8@=&AE(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@02!H87-H+"!W:71H(&ME>7,@)TPG(&%N9"`G4B<L(&%N9"!T
M:&4@96YC<GEP=&5D(&1A=&$@87,*("`@("`J("`@("`@("`@("`@("`@('1H
M92!V86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E;F-R>7!T0FQO8VLH
M)$PL("12*0H@("`@>PH@("`@("`@("1,(%X]("1T:&ES+3YP6S!=.PH@("`@
M("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D
M=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,
M(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D
M=&AI<RT^<%LQ73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^
M(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI
M(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;
M)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,ET["B`@("`@("`@)%(@7CT@*"@H
M)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@
M/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F
M9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S-=.PH@
M("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@
M*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;
M*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@
M7B`D=&AI<RT^<%LT73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,
M(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F
M9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^
M<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;-5T["B`@("`@("`@)$P@7CT@
M*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH
M)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P
M>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S9=
M.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&
M1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^
M<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F
M72D@7B`D=&AI<RT^<%LW73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;
M*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P
M>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI
M<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;.%T["B`@("`@("`@)%(@
M7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS
M,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@
M)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP
M6SE=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@
M,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI
M<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X
M,&9F72D@7B`D=&AI<RT^<%LQ,%T["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M
M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I
M("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@
M)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S$Q73L*("`@("`@
M("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H
M:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^
M/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H
M:7,M/G!;,3)=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@
M,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@
M7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD
M3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ,UT["B`@("`@("`@)$P@7CT@*"@H
M)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@
M/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F
M9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S$T73L*
M("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=
M("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S
M6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI
M(%X@)'1H:7,M/G!;,35=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH
M)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X
M,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES
M+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ-ET["B`@("`@("`@)%(@
M7CT@)'1H:7,M/G!;,3==.PH*("`@("`@("!R971U<FX@87)R87DH)TPG(#T^
M("12+"`G4B<@/3X@)$PI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP
M="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8FQO8VL@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1K97D@("`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@;W5T<'5T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D96-R>7!T0FQO8VLH)&)L;V-K+"`D:V5Y(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@
M("`@("`@)'1H:7,M/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@
M(&QI<W0H)$PL("12*2`](&%R<F%Y7W9A;'5E<RAU;G!A8VLH)TXJ)RP@)&)L
M;V-K*2D["@H@("`@("`@("1,(%X]("1T:&ES+3YP6S$W73L*("`@("`@("`D
M4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M
M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X
M*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M
M/G!;,39=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I
M("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D
M=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F
M(#!X,&9F72D@7B`D=&AI<RT^<%LQ-5T["B`@("`@("`@)%(@7CT@*"@H)'1H
M:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@
M,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI
M("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S$T73L*("`@
M("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@
M)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D
M4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@
M)'1H:7,M/G!;,3-=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@
M/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F
M72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS
M-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ,ET["B`@("`@("`@)$P@7CT@
M*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH
M)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P
M>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S$Q
M73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X
M1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M
M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F
M9ETI(%X@)'1H:7,M/G!;,3!=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS
M,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F
M(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T
M:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LY73L*("`@("`@("`D
M4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M
M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X
M*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M
M/G!;.%T["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@
M)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T
M:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@
M,'@P9F9=*2!>("1T:&ES+3YP6S==.PH@("`@("`@("12(%X]("@H*"1T:&ES
M+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V
M*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K
M("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LV73L*("`@("`@
M("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H
M:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^
M/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H
M:7,M/G!;-5T["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R
M-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>
M("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,
M("8@,'@P9F9=*2!>("1T:&ES+3YP6S1=.PH@("`@("`@("1,(%X]("@H*"1T
M:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^
M(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=
M*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LS73L*("`@
M("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@
M)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D
M3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@
M)'1H:7,M/G!;,ET["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^
M/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=
M*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T
M6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S%=.PH*("`@("`@("`D9&5C<GEP
M=&5D(#T@<&%C:R@B3DXB+"`D4B!>("1T:&ES+3YP6S!=+"`D3"D["B`@("`@
M("`@<F5T=7)N("1D96-R>7!T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYV97)T<R!A('1E>'0@:V5Y(&EN=&\@86X@87)R87DN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:V5Y("!+97D@:6X@=&5X="!F;W)M870N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&ME>2!I;B!A<G)A>2!F
M;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F;W)M871+97DH)&ME>2D*
M("`@('L*("`@("`@("!R971U<FX@87)R87E?=F%L=65S*'5N<&%C:R@G0RHG
M+"`D:V5Y*2D["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+V-A<W0Q,C@N<&AP````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3,R-3,V`#$P-#$W,S8R-S<Q`#`R,3,U
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&AE($-I<&AE<E]C87-T,3(X.CH@8VQA<W,@:6UP;&5M
M96YT<R!T:&4@0VEP:&5R(&EN=&5R9F%C92!E;F-R>7!T:6]N(&1A=&$*("H@
M=7-I;F<@=&AE($-!4U0Q,C@@*&%K82!#87-T-2D@86QG;W)I=&AM(&%S(&1E
M9FEN960@:6X@4D9#,C$T-"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0VEP
M:&5R+T-I<&AE<B]C87-T,3(X+G!H<"QV(#$N-RXQ,BXX(#(P,#8O,#$O,#$@
M,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C
M:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]C87-T
M,3(X(&5X=&5N9',@2&]R9&5?0VEP:&5R('L*"B`@("`O*BH*("`@("`J(%,@
M8F]X("AS,2D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D<S$@/2!A<G)A>2@*("`@("`@("`P>#,P9F(T,&0T+"`P>#EF83!F
M9C!B+"`P>#9B96-C9#)F+"`P>#-F,C4X8S=A+"`P>#%E,C$S9C)F+"`P>#EC
M,#`T9&0S+"`P>#8P,#-E-30P+"`P>&-F.69C.30Y+`H@("`@("`@(#!X8F9D
M-&%F,C<L(#!X.#AB8F)D8C4L(#!X93(P,S0P.3`L(#!X.3AD,#DV-S4L(#!X
M-F4V,V$P93`L(#!X,35C,S8Q9#(L(#!X8S)E-S8V,60L(#!X,C)D-&9F.&4L
M"B`@("`@("`@,'@R.#8X,V(V9BP@,'AC,#=F9#`U.2P@,'AF9C(S-SEC."P@
M,'@W-S5F-3!E,BP@,'@T,V,S-#!D,RP@,'AD9C)F.#8U-BP@,'@X.#=C830Q
M82P@,'AA,F0R8F0R9"P*("`@("`@("`P>&$Q8SEE,&0V+"`P>#,T-F,T.#$Y
M+"`P>#8Q8C<V9#@W+"`P>#(R-30P9C)F+"`P>#)A8F4S,F4Q+"`P>&%A-30Q
M-C9B+"`P>#(R-38X93-A+"`P>&$R9#,T,60P+`H@("`@("`@(#!X-C9D8C0P
M8S@L(#!X83<X-#,Y,F8L(#!X,#`T9&9F,F8L(#!X,F1B.60R9&4L(#!X.3<Y
M-#-F86,L(#!X-&$Y-V,Q9#@L(#!X-3(W-C0T8C<L(#!X8C5F-#,W83<L"B`@
M("`@("`@,'AB.#)C8F%E9BP@,'AD-S4Q9#$U.2P@,'@V9F8W9C!E9"P@,'@U
M83`Y-V$Q9BP@,'@X,C=B-CAD,"P@,'@Y,&5C9C4R92P@,'@R,F(P8S`U-"P@
M,'AB8SAE-3DS-2P*("`@("`@("`P>#1B-F0R9C=F+"`P>#4P8F(V-&$R+"`P
M>&0R-C8T.3$P+"`P>&)E934X,3)D+"`P>&(W,S,R,CDP+"`P>&4Y,V(Q-3EF
M+"`P>&(T.&5E-#$Q+"`P>#1B9F8S-#5D+`H@("`@("`@(#!X9F0T-6,R-#`L
M(#!X860S,3DW,V8L(#!X8S1F-F0P,F4L(#!X-35F8S@Q-C4L(#!X9#5B,6-A
M860L(#!X83%A8S)D864L(#!X83)D-&(W-F0L(#!X8S$Y8C!C-3`L"B`@("`@
M("`@,'@X.#(R-#!F,BP@,'@P8S9E-&8S."P@,'AA-&4T8F9D-RP@,'@T9C5B
M83(W,BP@,'@U-C1C,60R9BP@,'AC-3EC-3,Q.2P@,'AB.30Y93,U-"P@,'AB
M,#0V-CEF92P*("`@("`@("`P>&(Q8C9A8CAA+"`P>&,W,3,U.&1D+"`P>#8S
M.#5C-30U+"`P>#$Q,&8Y,S5D+"`P>#4W-3,X860U+"`P>#9A,SDP-#DS+"`P
M>&4V,V0S-V4P+"`P>#)A-31F-F(S+`H@("`@("`@(#!X,V$W.#=D-68L(#!X
M-C(W-F$P8C4L(#!X,3EA-F9C9&8L(#!X-V$T,C(P-F$L(#!X,CEF.60T9#4L
M(#!X9C8Q8C$X.3$L(#!X8F(W,C(W-64L(#!X86$U,#@Q-C<L"B`@("`@("`@
M,'@S.#DP,3`Y,2P@,'AC-F(U,#5E8BP@,'@X-&,W8V(X8RP@,'@R860W-6$P
M9BP@,'@X-S1A,30R-RP@,'AA,F0Q.3,V8BP@,'@R860R.#9A9BP@,'AA834V
M9#(Y,2P*("`@("`@("`P>&0W.#DT,S8P+"`P>#0R-6,W-3!D+"`P>#DS8C,Y
M93(V+"`P>#$X-S$X-&,Y+"`P>#9C,#!B,S)D+"`P>#<S93)B8C$T+"`P>&$P
M8F5B8S-C+"`P>#4T-C(S-S<Y+`H@("`@("`@(#!X-C0T-3EE86(L(#!X,V8S
M,CAB.#(L(#!X-S<Q.&-F.#(L(#!X-3EA,F-E838L(#!X,#1E93`P,F4L(#!X
M.#EF93<X938L(#!X,V9A8C`Y-3`L(#!X,S(U9F8V8S(L"B`@("`@("`@,'@X
M,3,X,V8P-2P@,'@V.38S8S5C."P@,'@W-F-B-6%D-BP@,'AD-#DY-S1C.2P@
M,'AC83$X,&1C9BP@,'@S.#`W.#)D-2P@,'AC-V9A-6-F-BP@,'@X86,S,34Q
M,2P*("`@("`@("`P>#,U93<Y93$S+"`P>#0W9&$Y,60P+"`P>&8T,&8Y,#@V
M+"`P>&$W93(T,3EE+"`P>#,Q,S8V,C0Q+"`P>#`U,65F-#DU+"`P>&%A-3<S
M8C`T+"`P>#1A.#`U9#AD+`H@("`@("`@(#!X-30X,S`P9#`L(#!X,#`S,C)A
M,V,L(#!X8F8V-&-D9&8L(#!X8F$U-V$V.&4L(#!X-S5C-C,W,F(L(#!X-3!A
M9F0S-#$L(#!X83=C,3,R-S4L(#!X.3$U83!B9C4L"B`@("`@("`@,'@V8C4T
M8F9A8BP@,'@R8C!B,30R-BP@,'AA8C1C8SED-RP@,'@T-#EC8V0X,BP@,'AF
M-V9B9C(V-2P@,'AA8C@U8S5F,RP@,'@Q8C4U9&(Y-"P@,'AA860T93,R-"P*
M("`@("`@("`P>&-F831B9#-F+"`P>#)D96%A,V4R+"`P>#EE,C`T9#`R+"`P
M>&,X8F0R-6%C+"`P>&5A9&8U-6(S+"`P>&0U8F0Y93DX+"`P>&4S,3(S,6(R
M+"`P>#)A9#5A9#9C+`H@("`@("`@(#!X.34T,S(Y9&4L(#!X861B930U,C@L
M(#!X9#@W,3!F-CDL(#!X86$U,6,Y,&8L(#!X86$W.#9B9C8L(#!X,C(U,3-F
M,64L(#!X86$U,6$W.6(L(#!X,F%D,S0T8V,L"B`@("`@("`@,'@W8C5A-#%F
M,"P@,'AD,S=C9F)A9"P@,'@Q8C`V.34P-2P@,'@T,65C930Y,2P@,'AB-&,S
M,S)E-BP@,'@P,S(R-CAD-"P@,'AC.38P,&%C8RP@,'AC93,X-V4V9"P*("`@
M("`@("`P>&)F-F)B,39C+"`P>#9A-S!F8C<X+"`P>#!D,#-D.6,Y+"`P>&0T
M9&8S.61E+"`P>&4P,3`V,V1A+"`P>#0W,S9F-#8T+"`P>#5A9#,R.&0X+"`P
M>&(S-#=C8SDV+`H@("`@("`@(#!X-S5B8C!F8S,L(#!X.3@U,3%B9F(L(#!X
M-&9F8F-C,S4L(#!X8C4X8F-F-F$L(#!X93$Q9C!A8F,L(#!X8F9C-69E-&$L
M(#!X83<P865C,3`L(#!X86,S.34W,&$L"B`@("`@("`@,'@S9C`T-#0R9BP@
M,'@V,3@X8C$U,RP@,'AE,#,Y-V$R92P@,'@U-S(W8V(W.2P@,'@Y8V5B-#$X
M9BP@,'@Q8V%C9#8X9"P@,'@R860S-V,Y-BP@,'@P,3<U8V(Y9"P*("`@("`@
M("`P>&,V.61F9C`Y+"`P>&,W-6(V-68P+"`P>&0Y9&(T,&0X+"`P>&5C,&4W
M-S<Y+"`P>#0W-#1E860T+"`P>&(Q,6,S,C<T+"`P>&1D,C1C8CEE+"`P>#=E
M,6,U-&)D+`H@("`@("`@(#!X9C`Q,30T9CDL(#!X9#(R-#!E8C$L(#!X.38W
M-6(S9F0L(#!X83-A8S,W-34L(#!X9#0W8S(W868L(#!X-3%C.#5F-&0L(#!X
M-38Y,#<U.38L(#!X835B8C$U938L"B`@("`@("`@,'@U.#`S,#1F,"P@,'AC
M83`T,F-F,2P@,'@P,3%A,S=E82P@,'@X9&)F86%D8BP@,'@S-6)A,V4T82P@
M,'@S-3(V9F9A,"P@,'AC,S=B-&0P.2P@,'AB8S,P-F5D.2P*("`@("`@("`P
M>#DX834R-C8V+"`P>#4V-#AF-S(U+"`P>&9F-64U-CED+"`P>#!C960V,V0P
M+"`P>#=C-C-B,F-F+"`P>#<P,&(T-64Q+"`P>&0U96$U,&8Q+"`P>#@U83DR
M.#<R+`H@("`@("`@(#!X868Q9F)D83<L(#!X9#0R,S0X-S`L(#!X83<X-S!B
M9C,L(#!X,F0S8C1D-SDL(#!X-#)E,#0Q.3@L(#!X,&-D,&5D93<L(#!X,C8T
M-S!D8C@L(#!X9C@X,3@Q-&,L"B`@("`@("`@,'@T-S1D-F%D-RP@,'@W8S!C
M-64U8RP@,'AD,3(S,3DU.2P@,'@S.#%B-S(Y."P@,'AF-60R9C1D8BP@,'AA
M8C@S.#8U,RP@,'@V93)F,64R,RP@,'@X,S<Q.6,Y92P*("`@("`@("`P>&)D
M.3%E,#0V+"`P>#EA-38T-39E+"`P>&1C,SDR,#!C+"`P>#(P8SAC-3<Q+"`P
M>#DV,F)D83%C+"`P>&4Q938Y-F9F+"`P>&(Q-#%A8C`X+"`P>#=C8V$X.6(Y
M+`H@("`@("`@(#!X,6$V.64W.#,L(#!X,#)C8S0X-#,L(#!X83)F-V,U-SDL
M(#!X-#(Y968T-V0L(#!X-#(W8C$V.6,L(#!X-6%C.68P-#DL(#!X9&0X9C!F
M,#`L(#!X-6,X,38U8F8I.PH*("`@("\J*@H@("`@("H@4R!B;W@@*',R*0H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S,B`]
M(&%R<F%Y*`H@("`@("`@(#!X,68R,#$P.30L(#!X968P8F$W-6(L(#!X-CEE
M,V-F-V4L(#!X,SDS9C0S.#`L(#!X9F4V,6-F-V$L(#!X965C-3(P-V$L(#!X
M-34X.#EC.30L(#!X-S)F8S`V-3$L"B`@("`@("`@,'AA9&$W968W.2P@,'@T
M93%D-S(S-2P@,'AD-35A-C-C92P@,'AD93`T,S9B82P@,'@Y.6,T,S!E9BP@
M,'@U9C!C,#<Y-"P@,'@Q.&1C9&(W9"P@,'AA,60V969F,RP*("`@("`@("`P
M>&$P8C4R9C=B+"`P>#4Y93@S-C`U+"`P>&5E,35B,#DT+"`P>&4Y9F9D.3`Y
M+"`P>&1C-#0P,#@V+"`P>&5F.30T-#4Y+"`P>&)A.#-C8V(S+"`P>&4P8S-C
M9&9B+`H@("`@("`@(#!X9#%D830Q.#$L(#!X,V(P.3)A8C$L(#!X9CDY-V8Q
M8S$L(#!X835E-F-F-V(L(#!X,#$T,C!D9&(L(#!X931E-V5F-6(L(#!X,C5A
M,69F-#$L(#!X93$X,&8X,#8L"B`@("`@("`@,'@Q9F,T,3`X,"P@,'@Q-SEB
M964W82P@,'AD,S=A8S9A.2P@,'AF934X,S!A-"P@,'@Y.&1E.&(W9BP@,'@W
M-V4X,V8T92P@,'@W.3DR.3(V.2P@,'@R-&9A.68W8BP*("`@("`@("`P>&4Q
M,3-C.#5B+"`P>&%C8S0P,#@S+"`P>&0W-3`S-3(U+"`P>&8W96$V,35F+"`P
M>#8R,30S,34T+"`P>#!D-34T8C8S+"`P>#5D-C@Q,3(Q+"`P>&,X-C9C,S4Y
M+`H@("`@("`@(#!X,V0V,V-F-S,L(#!X8V5E,C,T8S`L(#!X9#1D.#=E.#<L
M(#!X-6,V-S)B,C$L(#!X,#<Q9C8Q.#$L(#!X,SEF-S8R-V8L(#!X,S8Q93,P
M.#0L(#!X931E8C4W,V(L"B`@("`@("`@,'@V,#)F-C1A-"P@,'AD-C-A8V0Y
M8RP@,'@Q8F)C-#8S-2P@,'@Y93@Q,#,R9"P@,'@R-S`Q9C4P8RP@,'@Y.3@T
M-V%B-"P@,'AA,&4S9&8W.2P@,'AB839C9C,X8RP*("`@("`@("`P>#$P.#0S
M,#DT+"`P>#(U,S=A.35E+"`P>&8T-F8V9F9E+"`P>&$Q9F8S8C%F+"`P>#(P
M.&-F8C9A+"`P>#AF-#4X8S<T+"`P>&0Y93!A,C(W+"`P>#1E8S<S83,T+`H@
M("`@("`@(#!X9F,X.#1F-CDL(#!X,V4T9&4X9&8L(#!X968P93`P.#@L(#!X
M,S4U.38T.&0L(#!X.&$T-3,X.&,L(#!X,60X,#0S-C8L(#!X-S(Q9#EB9F0L
M(#!X834X-C@T8F(L"B`@("`@("`@,'AE.#(U-C,S,RP@,'@X-#1E.#(Q,BP@
M,'@Q,CAD.#`Y."P@,'AF960S,V9B-"P@,'AC93(X,&%E,2P@,'@R-V4Q.6)A
M-2P@,'AD-6$V8S(U,BP@,'AE-#DW-31B9"P*("`@("`@("`P>&,U9#8U-61D
M+"`P>&5B-C8W,#8T+"`P>#<W.#0P8C1D+"`P>&$Q8C9A.#`Q+"`P>#@T9&(R
M-F$Y+"`P>&4P8C4V-S$T+"`P>#(Q9C`T,V(W+"`P>&4U9#`U.#8P+`H@("`@
M("`@(#!X-31F,#,P.#0L(#!X,#8V9F8T-S(L(#!X83,Q86$Q-3,L(#!X9&%D
M8S0W-34L(#!X8C4V,C5D8F8L(#!X-C@U-C%B938L(#!X.#-C839B.30L(#!X
M,F0V960R,V(L"B`@("`@("`@,'AE8V-F,#%D8BP@,'AA-F0S9#!B82P@,'AB
M-C@P,V0U8RP@,'AA9C<W83<P.2P@,'@S,V(T83,T8RP@,'@S.3=B8SAD-BP@
M,'@U964R,F(Y-2P@,'@U9C!E-3,P-"P*("`@("`@("`P>#@Q960V9C8Q+"`P
M>#(P93<T,S8T+"`P>&(T-64Q,S<X+"`P>&1E,3@V,SEB+"`P>#@X,6-A,3(R
M+"`P>&(Y-C<R-F0Q+"`P>#@P-#EA-V4X+"`P>#(R8C=D83=B+`H@("`@("`@
M(#!X-64U-3)D,C4L(#!X-3(W,F0R,S<L(#!X-SED,CDU,6,L(#!X8S8P9#@Y
M-&,L(#!X-#@X8V(T,#(L(#!X,6)A-&9E-6(L(#!X831B,#EF-F(L(#!X,6-A
M.#$U8V8L"B`@("`@("`@,'AA,C!C,S`P-2P@,'@X.#<Q9&8V,RP@,'AB.61E
M,F9C8BP@,'@P8V,V8SEE.2P@,'@P8F5E9F8U,RP@,'AE,S(Q-#4Q-RP@,'AB
M-#4T,C@S-2P@,'@Y9C8S,CDS8RP*("`@("`@("`P>&5E-#%E-S(Y+"`P>#9E
M,60R9#=C+"`P>#4P,#0U,C@V+"`P>#%E-C8X-68S+"`P>&8S,S0P,6,V+"`P
M>#,P83(R8SDU+"`P>#,Q83<P.#4P+"`P>#8P.3,P9C$S+`H@("`@("`@(#!X
M-S-F.3@T,3<L(#!X83$R-CDX-3DL(#!X96,V-#5C-#0L(#!X-3)C.#<W83DL
M(#!X8V1F9C,S838L(#!X83`R8C$W-#$L(#!X-V-B860Y83(L(#!X,C$X,#`S
M-F8L"B`@("`@("`@,'@U,&0Y.6,P."P@,'AC8C-F-#@V,2P@,'AC,C9B9#<V
M-2P@,'@V-&$S9C9A8BP@,'@X,#,T,C8W-BP@,'@R-6$W-64W8BP@,'AE-&4V
M9#%F8RP@,'@R,&,W,3!E-BP*("`@("`@("`P>&-D9C!B-C@P+"`P>#$W.#0T
M9#-B+"`P>#,Q965F.#1D+"`P>#=E,#@R-&4T+"`P>#)C8V(T.65B+"`P>#@T
M-F$S8F%E+"`P>#AF9C<W.#@X+"`P>&5E-60V,&8V+`H@("`@("`@(#!X-V%F
M-S4V-S,L(#!X,F9D9#5C9&(L(#!X83$Q-C,Q8S$L(#!X,S!F-C9F-#,L(#!X
M8C-F865C-30L(#!X,34W9F0W9F$L(#!X968X-3<Y8V,L(#!X9#$U,F1E-3@L
M"B`@("`@("`@,'AD8C)F9F0U92P@,'@X9C,R8V4Q.2P@,'@S,#9A9CDW82P@
M,'@P,F8P,V5F."P@,'@Y.3,Q.6%D-2P@,'AC,C0R9F$P9BP@,'AA-V4S96)B
M,"P@,'AC-CAE-#DP-BP*("`@("`@("`P>&(X9&$R,S!C+"`P>#@P.#(S,#(X
M+"`P>&1C9&5F,V,X+"`P>&0S-69B,3<Q+"`P>#`X.&$Q8F,X+"`P>&)E8S!C
M-38P+"`P>#8Q83-C.64X+"`P>&)C83AF-31D+`H@("`@("`@(#!X8S<R9F5F
M9F$L(#!X,C(X,C)E.3DL(#!X.#)C-3<P8C0L(#!X9#AD.31E.#DL(#!X.&(Q
M8S,T8F,L(#!X,S`Q93$V938L(#!X,C<S8F4Y-SDL(#!X8C!F9F5A838L"B`@
M("`@("`@,'@V,60Y8CAC-BP@,'@P,&(R-#@V.2P@,'AB-V9F8V4S9BP@,'@P
M.&1C,C@S8BP@,'@T,V1A9C8U82P@,'AF-V4Q.3<Y."P@,'@W-C$Y8C<R9BP@
M,'@X9C%C.6)A-"P*("`@("`@("`P>&1C.#8S-V$P+"`P>#$V83=D,V(Q+"`P
M>#EF8S,Y,V(W+"`P>&$W,3,V965B+"`P>&,V8F-C-C-E+"`P>#%A-3$S-S0R
M+"`P>&5F-C@R.&)C+"`P>#4R,#,V-60V+`H@("`@("`@(#!X,F0V83<W86(L
M(#!X,S4R-V5D-&(L(#!X.#(Q9F0R,38L(#!X,#DU8S9E,F4L(#!X9&(Y,F8R
M9F(L(#!X-65E83(Y8V(L(#!X,30U.#DR9C4L(#!X.3$U.#1F-V8L"B`@("`@
M("`@,'@U-#@S-CDW8BP@,'@R-C8W83AC8RP@,'@X-3$Y-C`T."P@,'@X8S1B
M86-E82P@,'@X,S,X-C!D-"P@,'@P9#(S93!F.2P@,'@V8S,X-V4X82P@,'@P
M864V9#(T.2P*("`@("`@("`P>&(R.#0V,#!C+"`P>&0X,S4W,S%D+"`P>&1C
M8C%C-C0W+"`P>&%C-&,U-F5A+"`P>#-E8F0X,6(S+"`P>#(S,&5A8F(P+"`P
M>#8T,SAB8S@W+"`P>&8P8C5B,69A+`H@("`@("`@(#!X.&8U96$R8C,L(#!X
M9F,Q.#0V-#(L(#!X,&$P,S9B-V$L(#!X-&9B,#@Y8F0L(#!X-C0Y9&$U.#DL
M(#!X83,T-30Q-64L(#!X-6,P,S@S,C,L(#!X,V4U9#-B8CDL"B`@("`@("`@
M,'@T,V0W.34W,BP@,'@W939D9#`W8RP@,'@P-F1F9&8Q92P@,'@V8S9C8S1E
M9BP@,'@W,38P834S.2P@,'@W,V)F8F4W,"P@,'@X,S@W-S8P-2P@,'@T-3(S
M96-F,2D["@H@("`@+RHJ"B`@("`@*B!3(&)O>"`H<S,I"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',S(#T@87)R87DH"B`@
M("`@("`@,'@X9&5F8S(T,"P@,'@R-69A-60Y9BP@,'AE8CDP,V1B9BP@,'AE
M.#$P8SDP-RP@,'@T-S8P-V9F9BP@,'@S-CEF930T8BP@,'@X8S%F8S8T-"P@
M,'AA96-E8V$Y,"P*("`@("`@("`P>&)E8C%F.6)F+"`P>&5E9F)C865A+"`P
M>&4X8V8Q.34P+"`P>#4Q9&8P-V%E+"`P>#DR,&4X.#`V+"`P>&8P860P-30X
M+"`P>&4Q,V,X9#@S+"`P>#DR-S`Q,&0U+`H@("`@("`@(#!X,3$Q,#=D.68L
M(#!X,#<V-#=D8CDL(#!X8C)E,V4T9#0L(#!X,V0T9C(X-64L(#!X8CEA9F$X
M,C`L(#!X9F%D93@R93`L(#!X83`V-S(V.&(L(#!X.#(W,C<Y,F4L"B`@("`@
M("`@,'@U-3-F8C)C,"P@,'@T.#EA93(R8BP@,'AD-&5F.3<Y-"P@,'@Q,C5E
M,V9B8RP@,'@R,69F9F-E92P@,'@X,C5B,6)F9"P@,'@Y,C4U8S5E9"P@,'@Q
M,C4W83(T,"P*("`@("`@("`P>#1E,6$X,S`R+"`P>&)A93`W9F9F+"`P>#4R
M.#(T-F4W+"`P>#AE-3<Q-#!E+"`P>#,S-S-F-V)F+"`P>#AC.68X,3@X+"`P
M>&$V9F,T964X+"`P>&,Y.#)B-6$U+`H@("`@("`@(#!X83AC,#%D8C<L(#!X
M-3<Y9F,R-C0L(#!X-C<P.31F,S$L(#!X9C)B9#-F-68L(#!X-#!F9F8W8S$L
M(#!X,69B-SAD9F,L(#!X.&4V8F0R8S$L(#!X-#,W8F4U.6(L"B`@("`@("`@
M,'@Y.6(P,V1B9BP@,'AB-61B8S8T8BP@,'@V,SAD8S!E-BP@,'@U-3@Q.60Y
M.2P@,'AA,3DW8S@Q8RP@,'@T83`Q,F0V92P@,'AC-3@X-&$R."P@,'AC8V,S
M-F8W,2P*("`@("`@("`P>&(X-#-C,C$S+"`P>#9C,#<T,V8Q+"`P>#@S,#DX
M.3-C+"`P>#!F961D9#5F+"`P>#)F-V9E.#4P+"`P>&0W8S`W9C=E+"`P>#`R
M-3`W9F)F+"`P>#5A9F(Y83`T+`H@("`@("`@(#!X83<T-V0R9#`L(#!X,38U
M,3$Y,F4L(#!X868W,&)F,V4L(#!X-3AC,S$S.#`L(#!X-68Y.#,P,F4L(#!X
M-S(W8V,S8S0L(#!X,&$P9F(T,#(L(#!X,&8W9F5F.#(L"B`@("`@("`@,'@X
M8SDV9F1A9"P@,'@U9#)C,F%A92P@,'@X964Y.6$T.2P@,'@U,&1A.#AB."P@
M,'@X-#(W9C1A,"P@,'@Q96%C-3<Y,"P@,'@W.39F8C0T.2P@,'@X,C4R9&,Q
M-2P*("`@("`@("`P>&5F8F0W9#EB+"`P>&$V-S(U.3=D+"`P>&%D83@T,&0X
M+"`P>#0U9C4T-3`T+"`P>&9A-60W-#`S+"`P>&4X,V5C,S`U+"`P>#1F.3$W
M-3%A+"`P>#DR-38V.6,R+`H@("`@("`@(#!X,C-E9F4Y-#$L(#!X83DP,V8Q
M,F4L(#!X-C`R-S!D9C(L(#!X,#(W-F4T8C8L(#!X.31F9#8U-S0L(#!X.3(W
M.3@U8C(L(#!X.#(W-F1B8V(L(#!X,#(W-S@Q-S8L"B`@("`@("`@,'AF.&%F
M.3$X9"P@,'@T930X9C<Y92P@,'@X9C8Q-F1D9BP@,'AE,CED.#0P92P@,'@X
M-#)F-V0X,RP@,'@S-#!C935C."P@,'@Y-F)B8C8X,BP@,'@Y,V(T8C$T."P*
M("`@("`@("`P>&5F,S`S8V%B+"`P>#DX-&9A9C(X+"`P>#<W.69A9CEB+"`P
M>#DR9&,U-C!D+"`P>#(R-&0Q93(P+"`P>#@T,S=A83@X+"`P>#=D,CED8SDV
M+"`P>#(W-39D,V1C+`H@("`@("`@(#!X.&(Y,#=C964L(#!X8C4Q9F0R-#`L
M(#!X93=C,#=C93,L(#!X934V-F(T83$L(#!X8S-E.38Q-64L(#!X,V-F.#(P
M.60L(#!X-C`Y-&0Q93,L(#!X8V0Y8V$S-#$L"B`@("`@("`@,'@U8S<V-#8P
M92P@,'@P,&5A.3@S8BP@,'AD-&0V-S@X,2P@,'AF9#0W-3<R8RP@,'AF-S9C
M961D.2P@,'AB9&$X,C(Y8RP@,'@Q,C=D861A82P@,'@T,SAA,#<T92P*("`@
M("`@("`P>#%F.3=C,#DP+"`P>#`X,6)D8CAA+"`P>#DS83`W96)E+"`P>&(Y
M,SAC83$U+"`P>#DW8C`S8V9F+"`P>#-D8S)C,&8X+"`P>#AD,6%B,F5C+"`P
M>#8T,S@P934Q+`H@("`@("`@(#!X-CAC8S=B9F(L(#!X9#DP9C(W.#@L(#!X
M,3(T.3`Q.#$L(#!X-61E-69F9#0L(#!X9&0W968X-F$L(#!X-S9A,F4R,30L
M(#!X8CEA-#`S-C@L(#!X.3(U9#DU.&8L"B`@("`@("`@,'@T8C,Y9F9F82P@
M,'AB83,Y865E.2P@,'AA-&9F9#,P8BP@,'AF868W.3,S8BP@,'@V9#0Y.#8R
M,RP@,'@Q.3-C8F-F82P@,'@R-S8R-S4T-2P@,'@X,C5C9C0W82P*("`@("`@
M("`P>#8Q8F0X8F$P+"`P>&0Q,64T,F0Q+"`P>&-E860P-&8T+"`P>#$R-V5A
M,SDR+"`P>#$P-#(X9&(W+"`P>#@R-S)A.3<R+"`P>#DR-S!C-&$X+"`P>#$R
M-V1E-3!B+`H@("`@("`@(#!X,C@U8F$Q8S@L(#!X,V,V,F8T-&8L(#!X,S5C
M,&5A834L(#!X93@P-60R,S$L(#!X-#(X.3(Y9F(L(#!X8C1F8V1F.#(L(#!X
M-&9B-C9A-3,L(#!X,&4W9&,Q-6(L"B`@("`@("`@,'@Q9C`X,69A8BP@,'@Q
M,#@V,3AA92P@,'AF8V9D,#@V9"P@,'AF.69F,C@X.2P@,'@V.31B8V,Q,2P@
M,'@R,S9A-6-A92P@,'@Q,F1E8V$T9"P@,'@R8S-F.&-C-2P*("`@("`@("`P
M>&0R9#`R9&9E+"`P>&8X968U.#DV+"`P>&4T8V8U,F1A+"`P>#DU,34U8C8W
M+"`P>#0Y-&$T.#AC+"`P>&(Y8C9A.#!C+"`P>#5C.&8X,F)C+"`P>#@Y9#,V
M8C0U+`H@("`@("`@(#!X,V$V,#DT,S<L(#!X96,P,&,Y83DL(#!X-#0W,34R
M-3,L(#!X,&$X-S1B-#DL(#!X9#<W,V)C-#`L(#!X-V,S-#8W,6,L(#!X,#(W
M,3=E9C8L(#!X-&9E8C4U,S8L"B`@("`@("`@,'AA,F0P,F9F9BP@,'AD,F)F
M-C!C-"P@,'AD-#-F,#-C,"P@,'@U,&(T968V9"P@,'@P-S0W.&-D,2P@,'@P
M,#9E,3@X."P@,'AA,F4U,V8U-2P@,'AB.64V9#1B8RP*("`@("`@("`P>&$R
M,#0X,#$V+"`P>#DW-3<S.#,S+"`P>&0W,C`W9#8W+"`P>&1E,&8X9C-D+"`P
M>#<R9C@W8C,S+"`P>&%B8V,T9C,S+"`P>#<V.#AC-35D+"`P>#=B,#!A-F(P
M+`H@("`@("`@(#!X.30W8C`P,#$L(#!X-3<P,#<U9#(L(#!X9CEB8C@X9C@L
M(#!X.#DT,C`Q.64L(#!X-#(V-&$U9F8L(#!X.#4V,S`R93`L(#!X-S)D8F0Y
M,F(L(#!X964Y-S%B-CDL"B`@("`@("`@,'@V96$R,F9D92P@,'@U9C`X864R
M8BP@,'AA9C=A-C$V9"P@,'AE-6,Y.#<V-RP@,'AC9C%F96)D,BP@,'@V,65F
M8SAC,BP@,'AF,6%C,C4W,2P@,'AC8S@R,SEC,BP*("`@("`@("`P>#8W,C$T
M8V(X+"`P>&(Q934X,V0Q+"`P>&(W9&,S938R+"`P>#=F,3!B9&-E+"`P>&8Y
M,&$U8S,X+"`P>#!F9C`T-#-D+"`P>#8P-F4V9&,V+"`P>#8P-30S830Y+`H@
M("`@("`@(#!X-3<R-V,Q-#@L(#!X,F)E.3AA,60L(#!X.&%B-#$W,S@L(#!X
M,C!E,6)E,C0L(#!X868Y-F1A,&8L(#!X-C@T-3@T,C4L(#!X.3DX,S-B934L
M(#!X-C`P9#0U-V0L"B`@("`@("`@,'@R.#)F.3,U,"P@,'@X,S,T8C,V,BP@
M,'AD.3%D,3$R,"P@,'@R8C9D.&1A,"P@,'@V-#)B,64S,2P@,'@Y8S,P-6$P
M,"P@,'@U,F)C938X."P@,'@Q8C`S-3@X82P*("`@("`@("`P>&8W8F%E9F0U
M+"`P>#0Q-#)E9#EC+"`P>&$T,S$U8S$Q+"`P>#@S,S(S96,U+"`P>&1F968T
M-C,V+"`P>&$Q,S-C-3`Q+"`P>&4Y9#,U,S%C+"`P>&5E,S4S-S@S*3L*"B`@
M("`O*BH*("`@("`J(%,@8F]X("AS-"D*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D<S0@/2!A<G)A>2@*("`@("`@("`P>#ED
M8C,P-#(P+"`P>#%F8C9E.61E+"`P>&$W8F4W8F5F+"`P>&0R-S-A,CDX+"`P
M>#1A-&8W8F1B+"`P>#8T860X8S4W+"`P>#@U-3$P-#0S+"`P>&9A,#(P960Q
M+`H@("`@("`@(#!X-V4R.#=A9F8L(#!X938P9F(V-C,L(#!X,#DU9C,U83$L
M(#!X-SEE8F8Q,C`L(#!X9F0P-3ED-#,L(#!X-C0Y-V(W8C$L(#!X9C,V-#%F
M-C,L(#!X,C0Q931A9&8L"B`@("`@("`@,'@R.#$T-V8U9BP@,'@T9F$R8CAC
M9"P@,'AC.30S,#`T,"P@,'@P8V,S,C(R,"P@,'AF9&0S,&(S,"P@,'AC,&$U
M,S<T9BP@,'@Q9#)D,#!D.2P@,'@R-#$T-V(Q-2P*("`@("`@("`P>&5E-&0Q
M,3%A+"`P>#!F8V$U,38W+"`P>#<Q9F8Y,#1C+"`P>#)D,3DU9F9E+"`P>#%A
M,#4V-#5F+"`P>#!C,3-F969E+"`P>#`X,6(P.&-A+"`P>#`U,3<P,3(Q+`H@
M("`@("`@(#!X.#`U,S`Q,#`L(#!X93@S935E9F4L(#!X86,Y868T9C@L(#!X
M-V9E-S(W,#$L(#!X9#)B.&5E-68L(#!X,#9D9C0R-C$L(#!X8F(Y93EB.&$L
M(#!X-S(Y,V5A,C4L"B`@("`@("`@,'AC93@T9F9D9BP@,'AF-3<Q.#@P,2P@
M,'@S9&0V-&(P-"P@,'AA,C9F,C8S8BP@,'@W960T.#0P,"P@,'@U-#=E96)E
M-BP@,'@T-#9D-&-A,"P@,'@V8V8S9#9F-2P*("`@("`@("`P>#(V-#EA8F1F
M+"`P>&%E83!C-V8U+"`P>#,V,S,X8V,Q+"`P>#4P,V8W93DS+"`P>&0S-S<R
M,#8Q+"`P>#$Q8C8S.&4Q+"`P>#<R-3`P93`S+"`P>&8X,&5B,F)B+`H@("`@
M("`@(#!X86)E,#4P,F4L(#!X96,X9#<W9&4L(#!X-3<Y-S%E.#$L(#!X93$T
M9C8W-#8L(#!X8SDS,S4T,#`L(#!X-CDR,#,Q.&8L(#!X,#@Q9&)B.3DL(#!X
M9F9C,S`T834L"B`@("`@("`@,'@T9#,U,3@P-2P@,'@W9C-D-6-E,RP@,'AA
M-F,X-C9C-BP@,'@U9#5B8V-A.2P@,'AD865C-F9E82P@,'@Y9CDR-F8Y,2P@
M,'@Y9C0V,C(R9BP@,'@S.3DQ-#8W9"P*("`@("`@("`P>&$U8F8V9#AE+"`P
M>#$Q-#-C-#1F+"`P>#0S.34X,S`R+"`P>&0P,C$T965B+"`P>#`R,C`X,V(X
M+"`P>#-F8C8Q.#!C+"`P>#$X9C@Y,S%E+"`P>#(X,38U.&4V+`H@("`@("`@
M(#!X,C8T.#9E,V4L(#!X.&)D-SAA-S`L(#!X-S0W-V4T8S$L(#!X8C4P-F4P
M-V,L(#!X9C,R9#!A,C4L(#!X-SDP.3AB,#(L(#!X931E86)B.#$L(#!X,C@Q
M,C-B,C,L"B`@("`@("`@,'@V.61E860S."P@,'@Q-3<T8V$Q-BP@,'AD9C@W
M,6(V,BP@,'@R,3%C-#!B-RP@,'AA-3%A.65F.2P@,'@P,#$T,S<W8BP@,'@P
M-#%E.&%C."P@,'@P.3$Q-#`P,RP*("`@("`@("`P>&)D-3EE-&0R+"`P>&4S
M9#$U-F0U+"`P>#1F93@W-F0U+"`P>#)F.3%A,S0P+"`P>#4U-V)E.&1E+"`P
M>#`P96%E-&$W+"`P>#!C935C,F5C+"`P>#1D8C1B8F$V+`H@("`@("`@(#!X
M93<U-F)D9F8L(#!X9&0S,S8Y86,L(#!X96,Q-V(P,S4L(#!X,#8U-S(S,C<L
M(#!X.3EA9F,X8C`L(#!X-39C.&,S.3$L(#!X-F(V-3@Q,6,L(#!X-64Q-#8Q
M,3DL"B`@("`@("`@,'@V93@U8V(W-2P@,'AB93`W8S`P,BP@,'AC,C,R-34W
M-RP@,'@X.3-F9C1E8RP@,'@U8F)F8SDR9"P@,'AD,&5C,V(R-2P@,'AB-S@P
M,6%B-RP@,'@X9#9D,V(R-"P*("`@("`@("`P>#(P8S<V,V5F+"`P>&,S-C9A
M-69C+"`P>#EC,S@R.#@P+"`P>#!A8V4S,C`U+"`P>&%A8SDU-#AA+"`P>&5C
M83%D-V,W+"`P>#`T,6%F83,R+"`P>#%D,38V,C5A+`H@("`@("`@(#!X-C<P
M,3DP,F,L(#!X.6(W-3=A-30L(#!X,S%D-#<W9C<L(#!X.3$R-F(P,S$L(#!X
M,S9C8S9F9&(L(#!X8S<P8CAB-#8L(#!X9#EE-C9A-#@L(#!X-39E-35A-SDL
M"B`@("`@("`@,'@P,C9A-&-E8BP@,'@U,C0S-V5F9BP@,'@R9CAF-S9B-"P@
M,'@P9&8Y.#!A-2P@,'@X-C<T8V1E,RP@,'AE9&1A,#1E8BP@,'@Q-V$Y8F4P
M-"P@,'@R8S$X9C1D9BP*("`@("`@("`P>&(W-S0W9CED+"`P>&%B,F%F-V(T
M+"`P>&5F8S,T9#(P+"`P>#)E,#DV8C=C+"`P>#$W-#%A,C4T+"`P>&4U8C9A
M,#,U+"`P>#(Q,V0T,F8V+"`P>#)C,6,W8S(V+`H@("`@("`@(#!X-C%C,F8U
M,&8L(#!X-C4U,F1A9CDL(#!X9#)C,C,Q9C@L(#!X,C4Q,S!F-CDL(#!X9#@Q
M-C=F83(L(#!X,#0Q.&8R8S@L(#!X,#`Q83DV838L(#!X,&0Q-3(V86(L"B`@
M("`@("`@,'@V,S,Q-6,R,2P@,'@U93!A-S)E8RP@,'@T.6)A9F5F9"P@,'@Q
M.#<Y,#AD.2P@,'@X9#!D8F0X-BP@,'@S,3$Q-S!A-RP@,'@S93EB-C0P8RP@
M,'AC8S-E,3!D-RP*("`@("`@("`P>&0U8V%D,V(V+"`P>#!C865C,S@X+"`P
M>&8W,S`P,64Q+"`P>#9C-S(X869F+"`P>#<Q96%E,F$Q+"`P>#%F.6%F,S9E
M+"`P>&-F8V)D,3)F+"`P>&,Q9&4X-#$W+`H@("`@("`@(#!X86,P-V)E-F(L
M(#!X8V(T-&$Q9#@L(#!X.&(Y8C!F-38L(#!X,#$S.3@X8S,L(#!X8C%C-3)F
M8V$L(#!X8C1B93,Q8V0L(#!X9#@W.#(X,#8L(#!X,3)A,V$T93(L"B`@("`@
M("`@,'@V9C=D934S,BP@,'@U.&9D-V5B-BP@,'AD,#%E93DP,"P@,'@R-&%D
M9F9C,BP@,'AF-#DY,&9C-2P@,'@Y-S$Q86%C-2P@,'@P,#%D-V(Y-2P@,'@X
M,F4U93=D,BP*("`@("`@("`P>#$P.3@W,V8V+"`P>#`P-C$S,#DV+"`P>&,S
M,F0Y-3(Q+"`P>&%D83$R,69F+"`P>#(Y.3`X-#$U+"`P>#=F8F(Y-S=F+"`P
M>&%F.65B,V1B+"`P>#(Y8SEE9#)A+`H@("`@("`@(#!X-6-E,F$T-C4L(#!X
M83<S,&8S,F,L(#!X9#!A83-F93@L(#!X.&$U8V,P.3$L(#!X9#0Y93)C93<L
M(#!X,&-E-#4T83DL(#!X9#8P86-D.#8L(#!X,#$U9C$Y,3DL"B`@("`@("`@
M,'@W-S`W.3$P,RP@,'AD96$P,V%F-BP@,'@W.&$X-38U92P@,'AD964S-39D
M9BP@,'@R,68P-6-B92P@,'@X8C<U93,X-RP@,'AB,V,U,#8U,2P@,'AB.&$U
M8S-E9BP*("`@("`@("`P>&0X965B-F0R+"`P>&4U,C-B93<W+"`P>&,R,34T
M-3(Y+"`P>#)F-CEE9F1F+"`P>&%F938W869B+"`P>&8T-S!C-&(R+"`P>&8S
M93!E8C5B+"`P>&0V8V,Y.#<V+`H@("`@("`@(#!X,SEE-#0V,&,L(#!X,69D
M83@U,S@L(#!X,3DX-S@S,F8L(#!X8V$P,#<S-C<L(#!X83DY,30T9C@L(#!X
M,CDV8C(Y.64L(#!X-#DR9F,R.34L(#!X.3(V-F)E86(L"B`@("`@("`@,'AB
M-38W-F4V.2P@,'@Y8F0S9&1D82P@,'AD9C=E,#4R9BP@,'AD8C(U-S`Q8RP@
M,'@Q8C5E-3%E92P@,'AF-C4S,C1E-BP@,'@V869C93,V8RP@,'@P,S$V8V,P
M-"P*("`@("`@("`P>#@V-#0R,3-E+"`P>&(W9&,U.60P+"`P>#<Y-C4R.3%F
M+"`P>&-C9#9F9#0S+"`P>#0Q.#(S.3<Y+"`P>#DS,F)C9&8V+"`P>&(V-3=C
M,S1D+"`P>#1E9&9D,C@R+`H@("`@("`@(#!X-V%E-3(Y,&,L(#!X,V-B.34S
M-F(L(#!X.#4Q93(P9F4L(#!X.3@S,S4U-V4L(#!X,3-E8V8P8C`L(#!X9#-F
M9F(S-S(L(#!X,V8X-6,U8S$L(#!X,&%E9C=E9#(I.PH*("`@("\J*@H@("`@
M("H@4R!B;W@@*',U*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1S-2`](&%R<F%Y*`H@("`@("`@(#!X-V5C.3!C,#0L(#!X
M,F,V93<T8CDL(#!X.6(P938V9&8L(#!X838S,S<Y,3$L(#!X8C@V83=F9F8L
M(#!X,61D,S4X9C4L(#!X-#1D9#ED-#0L(#!X,3<S,3$V-V8L"B`@("`@("`@
M,'@P.&9B9C%F82P@,'AE-V8U,3%C8RP@,'AD,C`U,6(P,"P@,'@W,S5A8F$P
M,"P@,'@R86(W,C)D."P@,'@S.#8S.#%C8BP@,'AA8V8V,C0S82P@,'@V.6)E
M9F0W82P*("`@("`@("`P>&4V83)E-S=F+"`P>&8P8S<R,&-D+"`P>&,T-#DT
M.#$V+"`P>&-C9C5C,3@P+"`P>#,X.#4Q-C0P+"`P>#$U8C!A.#0X+"`P>&4V
M.&(Q.&-B+"`P>#1C86%D969F+`H@("`@("`@(#!X-68T.#!A,#$L(#!X,#0Q
M,F(R86$L(#!X,C4Y.#$T9F,L(#!X-#%D,&5F93(L(#!X-&4T,&(T.&0L(#!X
M,C0X96(V9F(L(#!X.&1B83%C9F4L(#!X-#%A.3EB,#(L"B`@("`@("`@,'@Q
M834U,&$P-"P@,'AB83AF-C5C8BP@,'@W,C4Q9C1E-RP@,'@Y-6$U,3<R-2P@
M,'AC,3`V96-D-RP@,'@Y-V$U.3@P82P@,'AC-3,Y8CEA82P@,'@T9#<Y9F4V
M82P*("`@("`@("`P>&8R9C-F-S8S+"`P>#8X868X,#0P+"`P>&5D,&,Y934V
M+"`P>#$Q8C0Y-3AB+"`P>&4Q96(U83@X+"`P>#@W,#EE-F(P+"`P>&0W93`W
M,34V+"`P>#1E,CEF96$W+`H@("`@("`@(#!X-C,V-F4U,F0L(#!X,#)D,6,P
M,#`L(#!X8S1A8SAE,#4L(#!X.3,W-V8U-S$L(#!X,&,P-3,W,F$L(#!X-3<X
M-3,U9C(L(#!X,C(V,6)E,#(L(#!X9#8T,F$P8SDL"B`@("`@("`@,'AD9C$S
M83(X,"P@,'@W-&(U-6)D,BP@,'@V.#(Q.3EC,"P@,'AD-#(Q935E8RP@,'@U
M,V9B,V-E."P@,'AC.&%D961B,RP@,'@R.&$X-V9C.2P@,'@S9#DU.3DX,2P*
M("`@("`@("`P>#5C,69F.3`P+"`P>&9E,SAD,SDY+"`P>#!C-&5F9C!B+"`P
M>#`V,C0P-V5A+"`P>&%A,F8T9F(Q+"`P>#1F8CDV.3<V+"`P>#DP8S<Y-3`U
M+"`P>&(P83AA-S<T+`H@("`@("`@(#!X968U-6$Q9F8L(#!X934Y8V$R8S(L
M(#!X839B-C)D,C<L(#!X938V830R-C,L(#!X9&8V-3`P,68L(#!X,&5C-3`Y
M-C8L(#!X9&9D9#4U8F,L(#!X,CED93`V-34L"B`@("`@("`@,'@Y,3%E-S,Y
M82P@,'@Q-V%F.#DW-2P@,'@S,F,W.3$Q8RP@,'@X.68X.30V."P@,'@P9#`Q
M93DX,"P@,'@U,C0W-35F-"P@,'@P,V(V,V-C.2P@,'@P8V,X-#1B,BP*("`@
M("`@("`P>&)C9C-F,&%A+"`P>#@W86,S-F4Y+"`P>&4U,V$W-#(V+"`P>#`Q
M8C-D.#)B+"`P>#%A.64W-#0Y+"`P>#8T964R9#=E+"`P>&-D9&)B,61A+"`P
M>#`Q8SDT.3$P+`H@("`@("`@(#!X8C@V.&)F.#`L(#!X,&0R-F8S9F0L(#!X
M.3,T,F5D93<L(#!X,#1A-6,R.#0L(#!X-C,V-S,W8C8L(#!X-3!F-6(V,38L
M(#!X9C(T-S8V93,L(#!X.&5C83,V8S$L"B`@("`@("`@,'@Q,S9E,#5D8BP@
M,'AF968Q.#,Y,2P@,'AF8C@X-V$S-RP@,'AD-F4W9C=D-"P@,'AC-V9B-V1C
M.2P@,'@S,#8S9F-D9BP@,'AB-F8U.#ED92P@,'AE8S(Y-#%D82P*("`@("`@
M("`P>#(V930V-CDU+"`P>&(W-38V-#$Y+"`P>&8V-31E9F,U+"`P>&0P.&0U
M.&(W+"`P>#0X.3(U-#`Q+"`P>&,Q8F%C8C=F+"`P>&4U9F8U-3!F+"`P>&(V
M,#@S,#0Y+`H@("`@("`@(#!X-6)B-60P93@L(#!X.#=D-S)E-6$L(#!X86(V
M839E93$L(#!X,C(S838V8V4L(#!X8S8R8F8S8V0L(#!X.64P.#@U9CDL(#!X
M-CAC8C-E-#<L(#!X,#@V8S`Q,&8L"B`@("`@("`@,'AA,C%D93@R,"P@,'AD
M,3AB-CED92P@,'AF,V8V-3<W-RP@,'AF83`R8S-F-BP@,'@T,#=E9&%C,RP@
M,'AC8F(S9#4U,"P@,'@Q-SDS,#@T9"P@,'AB,&0W,&5B82P*("`@("`@("`P
M>#!A8C,W.&0U+"`P>&0Y-3%F8C!C+"`P>&1E9#=D834V+"`P>#0Q,C1B8F4T
M+"`P>#DT8V$P8C4V+"`P>#!F-3<U-60Q+"`P>&4P93%E-39E+"`P>#8Q.#1B
M-6)E+`H@("`@("`@(#!X-3@P83(T.68L(#!X.31F-S1B8S`L(#!X93,R-S@X
M.&4L(#!X.68W8C4U-C$L(#!X8S-D8S`R.#`L(#!X,#4V.#<W,34L(#!X-C0V
M8S9B9#<L(#!X-#0Y,#1D8C,L"B`@("`@("`@,'@V-F(T9C!A,RP@,'AC,&8Q
M-C0X82P@,'@V.3=E9#5A9BP@,'@T.64Y,F9F-BP@,'@S,#EE,S<T9BP@,'@R
M8V(V,S4V82P@,'@X-3@P.#4W,RP@,'@T.3DQ9C@T,"P*("`@("`@("`P>#<V
M9C!A93`R+"`P>#`X,V)E.#1D+"`P>#(X-#(Q8SEA+"`P>#0T-#@Y-#`V+"`P
M>#<S-F4T8V(X+"`P>&,Q,#DR.3$P+"`P>#AB8SDU9F,V+"`P>#=D.#8Y8V8T
M+`H@("`@("`@(#!X,3,T9C8Q-F8L(#!X,F4W-S$Q.&0L(#!X8C,Q8C)B93$L
M(#!X86$Y,&(T-S(L(#!X,V-A-60W,3<L(#!X-V0Q-C%B8F$L(#!X.6-A9#DP
M,3`L(#!X868T-C)B83(L"B`@("`@("`@,'@Y9F4T-3ED,BP@,'@T-60S-#4U
M.2P@,'AD.68R9&$Q,RP@,'AD8F,V-30X-RP@,'AF,V4T9CDT92P@,'@Q-S9D
M-#@V9BP@,'@P.3=C,3-E82P@,'@V,S%D835C-RP*("`@("`@("`P>#0T-68W
M,S@R+"`P>#$W-38X,V8T+"`P>&-D8S8V83DW+"`P>#<P8F4P,C@X+"`P>&(S
M8V1C9C<R+"`P>#9E-61D,F8S+"`P>#(P.3,V,#<Y+"`P>#0U.6(X,&$U+`H@
M("`@("`@(#!X8F4V,&4R9&(L(#!X83EC,C,Q,#$L(#!X96)A-3,Q-6,L(#!X
M,C(T930R9C(L(#!X,6,U8S$U-S(L(#!X9C8W,C%B,F,L(#!X,6%D,F9F9C,L
M(#!X.&,R-30P-&4L"B`@("`@("`@,'@S,C1E9#<R9BP@,'@T,#8W8C=F9"P@
M,'@P-3(S,3,X92P@,'@U8V$S8F,W."P@,'AD8S!F9#8V92P@,'@W-3DR,C(X
M,RP@,'@W.#1D-F(Q-RP@,'@U.&5B8C$V92P*("`@("`@("`P>#0T,#DT9C@U
M+"`P>#-F-#@Q9#@W+"`P>&9C9F5A93=B+"`P>#<W8C5F9C<V+"`P>#AC,C,P
M,F)F+"`P>&%A9C0W-34V+"`P>#5F-#9B,#)A+"`P>#)B,#DR.#`Q+`H@("`@
M("`@(#!X,V0S.&8U9C<L(#!X,&-A.#%F,S8L(#!X-3)A9C1A.&$L(#!X-C9D
M-64W8S`L(#!X9&8S8C`X-S0L(#!X.34P-34Q,3`L(#!X,6(U860W83@L(#!X
M9C8Q960U860L"B`@("`@("`@,'@V8V8V930W.2P@,'@R,#<U.#$X-"P@,'AD
M,&-E9F$V-2P@,'@X.&8W8F4U."P@,'@T83`T-C@R-BP@,'@P9F8V9CAF,RP@
M,'AA,#EC-V8W,"P@,'@U,S0V86)A,"P*("`@("`@("`P>#5C93DV8S(X+"`P
M>&4Q-S9E9&$S+"`P>#9B86,S,#=F+"`P>#,W-C@R.60R+"`P>#@U,S8P9F$Y
M+"`P>#$W93-F93)A+"`P>#(T8C<Y-S8W+"`P>&8U83DV8C(P+`H@("`@("`@
M(#!X9#9C9#(U.34L(#!X-CAF9C%E8F8L(#!X-S4U-30T,F,L(#!X9C$Y9C`V
M8F4L(#!X9CEE,#8U.6$L(#!X965B.30Y,60L(#!X,S0P,3`W,3@L(#!X8F(S
M,&-A8C@L"B`@("`@("`@,'AE.#(R9F4Q-2P@,'@X.#4W,#DX,RP@,'@W-3!E
M-C(T.2P@,'AD838R-V4U-2P@,'@U93<V9F9A."P@,'AB,34S-#4T-BP@,'@V
M9#0W9&4P."P@,'AE9F4Y93=D-"D["@H@("`@+RHJ"B`@("`@*B!3(&)O>"`H
M<S8I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)',V(#T@87)R87DH"B`@("`@("`@,'AF-F9A.&8Y9"P@,'@R8V%C-F-E,2P@
M,'@T8V$S-#@V-RP@,'AE,C,S-V8W8RP@,'@Y-61B,#AE-RP@,'@P,38X-#-B
M-"P@,'AE8V5D-6-B8RP@,'@S,C4U-3-A8RP*("`@("`@("`P>&)F.68P.38P
M+"`P>&1F83%E,F5D+"`P>#@S9C`U-SED+"`P>#8S960X-F(Y+"`P>#%A8C9A
M-F(X+"`P>&1E-65B93,Y+"`P>&8S.&9F-S,R+"`P>#@Y.#EB,3,X+`H@("`@
M("`@(#!X,S-F,30Y-C$L(#!X8S`Q.3,W8F0L(#!X9C4P-F,V9&$L(#!X930V
M,C5E-V4L(#!X83,P.&5A.3DL(#!X-&4R,V4S,V,L(#!X-SEC8F0W8V,L(#!X
M-#AA,30S-C<L"B`@("`@("`@,'AA,S$T.38Q.2P@,'AF96,Y-&)D-2P@,'AA
M,3$T,3<T82P@,'AE86$P,3@V-BP@,'AA,#@T9&(R9"P@,'@P.6$X-#@V9BP@
M,'AA.#@X-C$T82P@,'@R.3`P868Y."P*("`@("`@("`P>#`Q-C8U.3DQ+"`P
M>&4Q.3DR.#8S+"`P>&,X9C,P8S8P+"`P>#)E-SAE9C-C+"`P>&0P9#4Q.3,R
M+"`P>&-F,&9E8S$T+"`P>&8W8V$P-V0R+"`P>&0P83@R,#<R+`H@("`@("`@
M(#!X9F0T,3$Y-V4L(#!X.3,P-6$V8C`L(#!X93@V8F4S9&$L(#!X-S1B960S
M8V0L(#!X,S<R9&$U,V,L(#!X-&,W9C0T-#@L(#!X9&%B-60T-#`L(#!X-F1B
M83!E8S,L"B`@("`@("`@,'@P.#,Y,3EA-RP@,'@Y9F)A965D.2P@,'@T.61B
M8V9B,"P@,'@T938W,&,U,RP@,'@U8S-D.6,P,2P@,'@V-&)D8CDT,2P@,'@R
M8S!E-C,V82P@,'AB83=D9#EC9"P*("`@("`@("`P>&5A-F8W,S@X+"`P>&4W
M,&)C-S8R+"`P>#,U9C(Y861B+"`P>#5C-&-D9#AD+"`P>&8P9#0X9#AC+"`P
M>&(X.#$U,V4R+"`P>#`X83$Y.#8V+"`P>#%A93)E86,X+`H@("`@("`@(#!X
M,C@T8V%F.#DL(#!X86$Y,C@R,C,L(#!X.3,S-&)E-3,L(#!X,V(S83(Q8F8L
M(#!X,38T,S1B93,L(#!X.6%E83,Y,#8L(#!X969E.&,S-F4L(#!X9C@Y,&-D
M9#DL"B`@("`@("`@,'@X,#(R-F1A92P@,'AC,S0P831A,RP@,'AD9C=E.6,P
M.2P@,'AA-CDT83@P-RP@,'@U8C=C-65C8RP@,'@R,C%D8C-A-BP@,'@Y838Y
M83`R9BP@,'@V.#@Q.&$U-"P*("`@("`@("`P>&-E8C(R.39F+"`P>#4S8S`X
M-#-A+"`P>&9E.#DS-C4U+"`P>#(U8F9E-CAA+"`P>&(T-C(X86)C+"`P>&-F
M,C(R96)F+"`P>#(U86,V9C0X+"`P>&$Y83DY,S@W+`H@("`@("`@(#!X-3-B
M9&1B-C4L(#!X93<V9F9B93<L(#!X93DV-V9D-S@L(#!X,&)A.3,U-C,L(#!X
M.&4S-#)B8S$L(#!X93AA,3%B93DL(#!X-#DX,#<T,&0L(#!X8S@P.#=D9F,L
M"B`@("`@("`@,'@X9&4T8F8Y.2P@,'AA,3$Q,#%A,"P@,'@W9F0S-SDW-2P@
M,'AD835A,C9C,"P@,'AE.#%F.3DT9BP@,'@Y-3(X8V0X.2P@,'AF9#,S.69E
M9"P@,'AB.#<X,S1B9BP*("`@("`@("`P>#5F,#0T-39D+"`P>#(R,C4X-CDX
M+"`P>&,Y8S1C.#-B+"`P>#)D8S$U-F)E+"`P>#1F-C(X9&%A+"`P>#4W9C4U
M96,U+"`P>&4R,C(P86)E+"`P>&0R.3$V96)F+`H@("`@("`@(#!X-&5C-S5B
M.34L(#!X,C1F,F,S8S`L(#!X-#)D,35D.3DL(#!X8V0P9#=F83`L(#!X-V(V
M93(W9F8L(#!X83AD8SAA9C`L(#!X-S,T-6,Q,#8L(#!X9C0Q93(S,F8L"B`@
M("`@("`@,'@S-3$V,C,X-BP@,'AE-F5A.#DR-BP@,'@S,S,S8C`Y-"P@,'@Q
M-3=E8S9F,BP@,'@S-S)B-S1A9BP@,'@V.3(U-S-E-"P@,'AE.6$Y9#@T."P@
M,'AF,S$V,#(X.2P*("`@("`@("`P>#-A-C)E9C%D+"`P>&$W.#=E,C,X+"`P
M>&8S835F-C<V+"`P>#<T,S8T.#4S+"`P>#(P.34Q,#8S+"`P>#0U-S8V.3AD
M+"`P>&(V9F%D-#`W+"`P>#4Y,F%F.34P+`H@("`@("`@(#!X,S9F-S,U,C,L
M(#!X-&-F8C9E.#<L(#!X-V1A-&-E8S`L(#!X-F,Q-3)D86$L(#!X8V(P,SDV
M83@L(#!X8S4P9&9E-60L(#!X9F-D-S`W86(L(#!X,#DR,6,T,F8L"B`@("`@
M("`@,'@X.61F9C!B8BP@,'@U9F4R8F4W."P@,'@T-#AF-&8S,RP@,'@W-30V
M,3-C.2P@,'@R8C`U9#`X9"P@,'@T.&(Y9#4X-2P@,'AD8S`T.30T,2P@,'AC
M.#`Y.&8Y8BP*("`@("`@("`P>#=D961E-S@V+"`P>&,S.6$S,S<S+"`P>#0R
M-#$P,#`U+"`P>#9A,#DQ-S4Q+"`P>#!E9C-C.&$V+"`P>#@Y,#`W,F0V+"`P
M>#(X,C`W-C@R+"`P>&$Y83EF-V)E+`H@("`@("`@(#!X8F8S,C8W.60L(#!X
M9#0U8C5B-S4L(#!X8C,U,V9D,#`L(#!X8V)B,&4S-3@L(#!X.#,P9C(R,&$L
M(#!X,68X9F(R,30L(#!X9#,W,F-F,#@L(#!X8V,S8S1A,3,L"B`@("`@("`@
M,'@X8V8V,S$V-BP@,'@P-C%C.#=B92P@,'@X.&,Y.&8X."P@,'@V,#8R93,Y
M-RP@,'@T-V-F.&4W82P@,'AB-F,X-3(X,RP@,'@S8V,R86-F8BP@,'@S9F,P
M-CDW-BP*("`@("`@("`P>#1E.&8P,C4R+"`P>#8T9#@S,31D+"`P>&1A,S@W
M,&4S+"`P>#%E-C8U-#4Y+"`P>&,Q,#DP.&8P+"`P>#4Q,S`R,6$U+"`P>#9C
M-6(V.&(W+"`P>#@R,F8X86$P+`H@("`@("`@(#!X,S`P-V-D,V4L(#!X-S0W
M,3EE968L(#!X9&,X-S(V.#$L(#!X,#<S,S0P9#0L(#!X-V4T,S)F9#DL(#!X
M,&,U96,R-#$L(#!X.#@P.3(X-F,L(#!X9C4Y,F0X.3$L"B`@("`@("`@,'@P
M.&$Y,S!F-BP@,'@Y-3=E9C,P-2P@,'AB-V9B9F9B9"P@,'AC,C8V93DV9BP@
M,'@V9F4T86,Y."P@,'AB,3<S96-C,"P@,'AB8S8P8C0R82P@,'@Y-3,T.3AD
M82P*("`@("`@("`P>&9B83%A93$R+"`P>#)D-&)D-S,V+"`P>#!F,C5F86%B
M+"`P>&$T9C-F8V5B+"`P>&4R.38Y,3(S+"`P>#(U-V8P8S-D+"`P>#DS-#AA
M9C0Y+"`P>#,V,30P,&)C+`H@("`@("`@(#!X93@X,39F-&$L(#!X,S@Q-&8R
M,#`L(#!X83-F.30P-#,L(#!X.6,W834T8S(L(#!X8F,W,#1F-3<L(#!X9&$T
M,64W9CDL(#!X8S(U860S,V$L(#!X-31F-&$P.#0L"B`@("`@("`@,'AB,3=F
M-34P-2P@,'@U.3,U-V-B92P@,'AE9&)D,35C."P@,'@W9CDW8S5A8BP@,'AB
M835A8S=B-2P@,'AB-F8V9&5A9BP@,'@S830W.6,S82P@,'@U,S`R9&$R-2P*
M("`@("`@("`P>#8U,V0W939A+"`P>#4T,C8X9#0Y+"`P>#4Q830W-V5A+"`P
M>#4P,3=D-35B+"`P>&0W9#(U9#@X+"`P>#0T,3,V8S<V+"`P>#`T,#1A.&,X
M+"`P>&(X935A,3(Q+`H@("`@("`@(#!X8C@Q83DR.&$L(#!X-C!E9#4X-CDL
M(#!X.3=C-35B.38L(#!X96%E8SDY,6(L(#!X,CDY,S4Y,3,L(#!X,#%F9&(W
M9C$L(#!X,#@X93AD9F$L(#!X.6%B-F8V9C4L"B`@("`@("`@,'@S8C1C8F8Y
M9BP@,'@T835D93-A8BP@,'AE-C`U,60S-2P@,'AA,&4Q9#@U-2P@,'AD,S9B
M-&-F,2P@,'AF-30T961E8BP@,'AB,&4Y,S4R-"P@,'AB96)B.&9B9"P*("`@
M("`@("`P>&$R9#<V,F-F+"`P>#0Y8SDR9C4T+"`P>#,X8C5F,S,Q+"`P>#<Q
M,CAA-#4T+"`P>#0X,SDR.3`U+"`P>&$V-6(Q9&(X+"`P>#@U,6,Y-V)D+"`P
M>&0V-S5C9C)F*3L*"B`@("`O*BH*("`@("`J(%,@8F]X("AS-RD*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S<@/2!A<G)A
M>2@*("`@("`@("`P>#@U93`T,#$Y+"`P>#,S,F)F-38W+"`P>#8V,F1B9F9F
M+"`P>&-F8S8U-CDS+"`P>#)A.&0W9C9F+"`P>&%B.6)C.3$R+"`P>&1E-C`P
M.&$Q+"`P>#(P,CAD83%F+`H@("`@("`@(#!X,#(R-V)C93<L(#!X-&0V-#(Y
M,38L(#!X,3AF86,S,#`L(#!X-3!F,3AB.#(L(#!X,F-B,F-B,3$L(#!X8C(S
M,F4W-6,L(#!X-&(S-CDU9C(L(#!X8C(X-S`W9&4L"B`@("`@("`@,'AA,#5F
M8F-F-BP@,'AC9#0Q.#%E.2P@,'AE,34P,C$P8RP@,'AE,C1E9C%B9"P@,'AB
M,38X8S,X,2P@,'AF9&4T93<X.2P@,'@U8S<Y8C!D."P@,'@Q93AB9F0T,RP*
M("`@("`@("`P>#1D-#DU,#`Q+"`P>#,X8F4T,S0Q+"`P>#DQ,V-E93%D+"`P
M>#DR83<Y8S-F+"`P>#`X.3<V-F)E+"`P>&)A965A9&8T+"`P>#$R.#9B96-F
M+"`P>&(V96%C8C$Y+`H@("`@("`@(#!X,C8V,&,R,#`L(#!X-S4V-6)D930L
M(#!X-C0R-#%F-V$L(#!X.#(T.&1C83DL(#!X8S-B,V%D-C8L(#!X,C@Q,S8P
M.#8L(#!X,&)D.&1F83@L(#!X,S4V9#%C9C(L"B`@("`@("`@,'@Q,#<W.#EB
M92P@,'AB,V(R93EC92P@,'@P-3`R86$X9BP@,'@P8F,P,S4Q92P@,'@Q-C9B
M9C4R82P@,'AE8C$R9F8X,BP@,'AE,S0X-CDQ,2P@,'AD,S1D-S4Q-BP*("`@
M("`@("`P>#1E-V(S869F+"`P>#5F-#,V-S%B+"`P>#EC9C9E,#,W+"`P>#0Y
M.#%A8S@S+"`P>#,S-#(V-F-E+"`P>#AC.3,T,6(W+"`P>&0P9#@U-&,P+"`P
M>&-B,V$V8S@X+`H@("`@("`@(#!X-#=B8S(X,CDL(#!X-#<R-6)A,S<L(#!X
M838V860R,F(L(#!X-V%D-C%F,64L(#!X,&,U8V)A9F$L(#!X-#0S-V8Q,#<L
M(#!X8C9E-SDY-C(L(#!X-#)D,F0X,38L"B`@("`@("`@,'@P83DV,3(X."P@
M,'AE,6$U8S`V92P@,'@Q,S<T.64V-RP@,'@W,F9C,#@Q82P@,'AB,60Q,SEF
M-RP@,'AF.34X,S<T-2P@,'AC9C$Y9&8U."P@,'AB96,S9C<U-BP*("`@("`@
M("`P>&,P-F5B83,P+"`P>#`W,C$Q8C(T+"`P>#0U8S(X.#(Y+"`P>&,Y-64S
M,3=F+"`P>&)C.&5C-3$Q+"`P>#,X8F,T-F4Y+"`P>&,V939F83$T+"`P>&)A
M93@U.#1A+`H@("`@("`@(#!X860T96)C-#8L(#!X-#8X9C4P.&(L(#!X-S@R
M.30S-68L(#!X9C$R-#$X,V(L(#!X.#(Q9&)A.68L(#!X869F-C!F9C0L(#!X
M96$R8S1E-F0L(#!X,39E,SDR-C0L"B`@("`@("`@,'@Y,C4T-&$X8BP@,'@P
M,#EB-&9C,RP@,'AA8F$V.&-E9"P@,'@Y86,Y-F8W."P@,'@P-F$U8C<Y82P@
M,'AB,C@U-F4V92P@,'@Q865C,V-A.2P@,'AB93@S.#8X."P*("`@("`@("`P
M>#!E,#@P-&4Y+"`P>#4U9C%B934V+"`P>&4W934S-C-B+"`P>&(S83%F,C5D
M+"`P>&8W9&5B8C@U+"`P>#8Q9F4P,S-C+"`P>#$V-S0V,C,S+"`P>#-C,#,T
M8S(X+`H@("`@("`@(#!X9&$V9#!C-S0L(#!X-SEA86,U-F,L(#!X,V-E-&4Q
M860L(#!X-3%F,&,X,#(L(#!X.3AF.&8S-6$L(#!X,38R-F$T.68L(#!X965D
M.#)B,CDL(#!X,60S.#)F93,L"B`@("`@("`@,'@P8S1F8CDY82P@,'AB8C,R
M-3<W."P@,'@S96,V9#DW8BP@,'@V93<W839A.2P@,'AC8C8U.&(U8RP@,'AD
M-#4R,S!C-RP@,'@R8F0Q-#`X8BP@,'@V,&,P,V5B-RP*("`@("`@("`P>&(Y
M,#8X9#<X+"`P>&$S,S<U-&8T+"`P>&8T,S!C.#=D+"`P>&,X83<Q,S`R+"`P
M>&(Y-F0X8S,R+"`P>&5B9#1E-V)E+"`P>&)E.&(Y9#)D+"`P>#<Y-SEF8C`V
M+`H@("`@("`@(#!X93<R,C4S,#@L(#!X.&(W-6-F-S<L(#!X,3%E9CAD830L
M(#!X93`X,V,X-3@L(#!X.&0V8C<X-F8L(#!X-6$V,S$W838L(#!X9F$U8V8W
M83`L(#!X-61D83`P,S,L"B`@("`@("`@,'AF,CAE8F9B,"P@,'AF-6(Y8S,Q
M,"P@,'AA,&5A8S(X,"P@,'@P.&(Y-S8W82P@,'AA,V0Y9#)B,"P@,'@W.60S
M-#(Q-RP@,'@P,C%A-S$X9"P@,'@Y86,V,S,V82P*("`@("`@("`P>#(W,3%F
M9#8P+"`P>#0S.#`U,&4S+"`P>#`V.3DP.&$X+"`P>#-D-V9E9&,T+"`P>#@R
M-F0R8F5F+"`P>#1E96(X-#<V+"`P>#0X.&1C9C(U+"`P>#,V8SED-38V+`H@
M("`@("`@(#!X,CAE-S1E-#$L(#!X8S(V,3!A8V$L(#!X,V0T.6$Y8V8L(#!X
M8F%E,V(Y9&8L(#!X8C8U9CAD938L(#!X.3)A96%F-C0L(#!X,V%C-V0U938L
M(#!X.65A.#`U,#DL"B`@("`@("`@,'AF,C)B,#$W9"P@,'AA-#$W,V8W,"P@
M,'AD9#%E,39C,RP@,'@Q-64P9#=F.2P@,'@U,&(Q8C@X-RP@,'@R8CEF-&9D
M-2P@,'@V,C5A8F$X,BP@,'@V83`Q-SDV,BP*("`@("`@("`P>#)E8S`Q8CEC
M+"`P>#$U-#@X86$Y+"`P>&0W,39E-S0P+"`P>#0P,#4U83)C+"`P>#DS9#(Y
M83(R+"`P>&4S,F1B9CEA+"`P>#`U.#<T-6(Y+"`P>#,T-3-D8S%E+`H@("`@
M("`@(#!X9#8Y.3(Y-F4L(#!X-#DV8V9F-F8L(#!X,6,Y9C0Y.#8L(#!X9&9E
M,F5D,#<L(#!X8C@W,C0R9#$L(#!X,3ED93=E864L(#!X,#4S934V,6$L(#!X
M,35A9#9F.&,L"B`@("`@("`@,'@V-C8R-F,Q8RP@,'@W,34T8S(T8RP@,'AE
M83`X,F(R82P@,'@Y,V5B,CDS.2P@,'@Q-V1C8C!F,"P@,'@U.&0T9C)A92P@
M,'@Y96$R.31F8BP@,'@U,F-F-38T8RP*("`@("`@("`P>#DX.#-F938V+"`P
M>#)E8S0P-3@Q+"`P>#<V,SDU,V,S+"`P>#`Q9#8V.3)E+"`P>&0S83!C,3`X
M+"`P>&$Q93<Q-C!E+"`P>&4T9C)D9F$V+"`P>#8Y,V5D,C@U+`H@("`@("`@
M(#!X-S0Y,#0V.3@L(#!X-&,R8C!E9&0L(#!X-&8W-3<V-38L(#!X-60S.3,S
M-S@L(#!X83$S,C(S-&8L(#!X,V0S,C%C-60L(#!X8S-F-64Q.30L(#!X-&(R
M-CDS,#$L"B`@("`@("`@,'AC-SEF,#(R9BP@,'@S8SDY-V4W92P@,'@U931F
M.34P-"P@,'@S9F9A9F)B9"P@,'@W-F8W860P92P@,'@R.38V.3-F-"P@,'@S
M9#%F8V4V9BP@,'AC-C%E-#5B92P*("`@("`@("`P>&0S8C5A8C,T+"`P>&8W
M,F)F.6(W+"`P>#%B,#0S-&,P+"`P>#1E-S)B-38W+"`P>#4U.3)A,S-D+"`P
M>&(U,C(Y,S`Q+"`P>&-F9#)A.#=F+"`P>#8P865B-S8W+`H@("`@("`@(#!X
M,3@Q-#,X-F(L(#!X,S!B8V,S,V0L(#!X,SAA,&,P-V0L(#!X9F0Q-C`V9C(L
M(#!X8S,V,S4Q.6(L(#!X-3@Y9&0S.3`L(#!X-30W.68X938L(#!X,6-B.&0V
M-#<L"B`@("`@("`@,'@Y-V9D-C%A.2P@,'AE83<W-3EF-"P@,'@R9#4W-3,Y
M9"P@,'@U-CEA-3AC9BP@,'AE.#1E-C-A9"P@,'@T-C)E,6(W."P@,'@V-3@P
M9C@W92P@,'AF,S@Q-SDQ-"P*("`@("`@("`P>#DQ9&$U-68T+"`P>#0P83(S
M,&8S+"`P>&0Q.3@X9C,U+"`P>&(V93,Q.&0R+"`P>#-F9F$U,&)C+"`P>#-D
M-#!F,#(Q+"`P>&,S8S!B9&%E+"`P>#0Y-3AC,C1C+`H@("`@("`@(#!X-3$X
M9C,V8C(L(#!X.#1B,60S-S`L(#!X,&9E9&-E.#,L(#!X.#<X9&1A9&$L(#!X
M9C)A,C<Y8S<L(#!X.31E,#%B93@L(#!X.3`W,39F-&(L(#!X.34T8CAA83,I
M.PH*("`@("\J*@H@("`@("H@4R!B;W@@*',X*0H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1S."`](&%R<F%Y*`H@("`@("`@
M(#!X93(Q-C,P,&0L(#!X8F)D9&9F9F,L(#!X83=E8F1A8F0L(#!X,S4V-#@P
M.34L(#!X-S<X.68X8C<L(#!X939C,3$R,6(L(#!X,&4R-#$V,#`L(#!X,#4R
M8V4X8C4L"B`@("`@("`@,'@Q,6$Y8V9B,"P@,'AE-3DU,F8Q,2P@,'AE8V4W
M.3DP82P@,'@Y,S@V9#$W-"P@,'@R830R.3,Q8RP@,'@W-F4S.#$Q,2P@,'AB
M,3)D968S82P@,'@S-V1D9&1F8RP*("`@("`@("`P>&1E.6%D96(Q+"`P>#!A
M,&-C,S)C+"`P>&)E,3DW,#(Y+"`P>#@T83`P.30P+"`P>&)B,C0S83!F+"`P
M>&(T9#$S-V-F+"`P>&(T-&4W.68P+"`P>#`T.65E9&9D+`H@("`@("`@(#!X
M,&(Q-6$Q-60L(#!X-#@P9#,Q-C@L(#!X.&)B8F1E-6$L(#!X-C8Y9&5D-#(L
M(#!X8S=E8V4X,S$L(#!X,V8X9CDU93<L(#!X-S)D9C$Y,6(L(#!X-S4X,#,S
M,&0L"B`@("`@("`@,'@Y-#`W-#(U,2P@,'@U8S=D8V1F82P@,'AA8F)E-F0V
M,RP@,'AA830P,C$V-"P@,'AB,S`Q9#0P82P@,'@P,F4W9#%C82P@,'@U,S4W
M,61A92P@,'@W83,Q.#)A,BP*("`@("`@("`P>#$R83AD9&5C+"`P>&9D86$S
M,S5D+"`P>#$W-F8T,V4X+"`P>#<Q9F(T-F0T+"`P>#,X,3(Y,#(R+"`P>&-E
M.30Y860T+"`P>&(X-#<V.6%D+"`P>#DV-6)D.#8R+`H@("`@("`@(#!X.#)F
M,V0P-34L(#!X-C9F8CDW-C<L(#!X,35B.#!B-&4L(#!X,60U8C0W83`L(#!X
M-&-F9&4P-F8L(#!X8S(X96,T8C@L(#!X-3=E.#<R-F4L(#!X-C0W83<X9F,L
M"B`@("`@("`@,'@Y.3@V-60T-"P@,'@V,#AB9#4Y,RP@,'@V8S(P,&4P,RP@
M,'@S.61C-69F-BP@,'@U9#!B,#!A,RP@,'AA938S869F,BP@,'@W93AB9#8S
M,BP@,'@W,#$P.&,P8RP*("`@("`@("`P>&)B9#,U,#0Y+"`P>#(Y.3AD9C`T
M+"`P>#DX,&-F-#)A+"`P>#EB-F1F-#DQ+"`P>#EE-V5D9#4S+"`P>#`V.3$X
M-30X+"`P>#4X8V(W93`W+"`P>#-B-S1E9C)E+`H@("`@("`@(#!X-3(R9F9F
M8C$L(#!X9#(T-S`X8V,L(#!X,6,W93(W8V0L(#!X831E8C(Q-6(L(#!X,V-F
M,60R93(L(#!X,3EB-#=A,S@L(#!X-#(T9C<V,3@L(#!X,S4X-38P,SDL"B`@
M("`@("`@,'@Y9#$W9&5E-RP@,'@R-V5B,S5E-BP@,'AC.6%F9C8W8BP@,'@S
M-F)A9C5B."P@,'@P.6,T-C=C9"P@,'AC,3@Y,3!B,2P@,'AE,3%D8F8W8BP@
M,'@P-F-D,6%F."P*("`@("`@("`P>#<Q-S!C-C`X+"`P>#)D-64S,S4T+"`P
M>&0T9&4T.35A+"`P>#8T8S9D,#`V+"`P>&)C8S!C-C)C+"`P>#-D9#`P9&(S
M+"`P>#<P.&8X9C,T+"`P>#<W9#4Q8C0R+`H@("`@("`@(#!X,C8T9C8R,&8L
M(#!X,C1B.&0R8F8L(#!X,35C,6(W.64L(#!X-#9A-3(U-C0L(#!X9CAD-V4U
M-&4L(#!X,V4S-S@Q-C`L(#!X-S@Y-6-D834L(#!X.#4Y8S$U834L"B`@("`@
M("`@,'AE-C0U.3<X."P@,'AC,S=B8S<U9BP@,'AD8C`W8F$P8RP@,'@P-C<V
M83-A8BP@,'@W9C(R.6(Q92P@,'@S,3@T,F4W8BP@,'@R-#(U.69D-RP@,'AF
M.&)E9C0W,BP*("`@("`@("`P>#@S-69F8V(X+"`P>#9D9C1C,68R+"`P>#DV
M9C5B,3DU+"`P>&9D,&%F,&9C+"`P>&(P9F4Q,S1C+"`P>&4R-3`V9#-D+"`P
M>#1F.6(Q,F5A+"`P>&8R,35F,C(U+`H@("`@("`@(#!X83(R,S<S-F8L(#!X
M.69B-&,T,C@L(#!X,C5D,#0Y-SDL(#!X,S1C-S$S9C@L(#!X8S0V,3@Q.#<L
M(#!X96$W839E.3@L(#!X-V-D,39E9F,L(#!X,30S-C@W-F,L"B`@("`@("`@
M,'AF,34T-#$P-RP@,'AB961E964Q-"P@,'@U-F4Y868R-RP@,'AA,#1A830T
M,2P@,'@S8V8W8S@Y.2P@,'@Y,F5C8F%E-BP@,'AD9#8W,#$V9"P@,'@Q-3$V
M.#)E8BP*("`@("`@("`P>&$X-#)E961F+"`P>&9D8F$V,&(T+"`P>&8Q.3`W
M8C<U+"`P>#(P93,P,S!F+"`P>#(T9#AC,CEE+"`P>&4Q,SDV-S-B+"`P>&5F
M838S9F(X+"`P>#<Q.#<S,#4T+`H@("`@("`@(#!X8C9F,F-F,V(L(#!X.68S
M,C8T-#(L(#!X8V(Q-6$T8V,L(#!X8C`Q830U,#0L(#!X9C%E-#=D.&0L(#!X
M.#0T83%B934L(#!X8F%E-V1F9&,L(#!X-#)C8F1A-S`L"B`@("`@("`@,'AC
M9#=D864P82P@,'@U-V4X-6(W82P@,'AD-3-F-6%F-BP@,'@R,&-F-&0X8RP@
M,'AC96$T9#0R."P@,'@W.60Q,S!A-"P@,'@S-#@V96)F8BP@,'@S,V0S8V1D
M8RP*("`@("`@("`P>#<W.#4S8C4S+"`P>#,W969F8V(U+"`P>&,U,#8X-S<X
M+"`P>&4U.#!B,V4V+"`P>#1E-CAB.&8T+"`P>&,U8SAB,S=E+"`P>#!D.#`Y
M96$R+"`P>#,Y.&9E8C=C+`H@("`@("`@(#!X,3,R831F.30L(#!X-#-B-SDU
M,&4L(#!X,F9E93=D,6,L(#!X,C(S-C$S8F0L(#!X9&0P-F-A83(L(#!X,S=D
M9CDS,F(L(#!X8S0R-#@R.#DL(#!X86-F,V5B8S,L"B`@("`@("`@,'@U-S$U
M9C9B-RP@,'AE9C,T-SAD9"P@,'AF,C8W-C$V9BP@,'AC,30X8V)E-"P@,'@Y
M,#4R.#$U92P@,'@U930Q,&9A8BP@,'AB-#AA,C0V-2P@,'@R961A-V9A-"P*
M("`@("`@("`P>&4X-V(T,&4T+"`P>&4Y.&5A,#@T+"`P>#4X.#EE.64Q+"`P
M>&5F9#,Y,&9C+"`P>&1D,#=D,S5B+"`P>&1B-#@U-CDT+"`P>#,X9#=E-6(R
M+"`P>#4W-S(P,3`Q+`H@("`@("`@(#!X-S,P961E8F,L(#!X-6(V-#,Q,3,L
M(#!X.30Y,3=E-&8L(#!X-3`S8S)F8F$L(#!X-C0V9C$R.#(L(#!X-S4R,V0R
M-&$L(#!X93`W-SDV.34L(#!X9CEC,3=A.&8L"B`@("`@("`@,'@W835B,C$R
M,2P@,'AD,3@W8C@Y-BP@,'@R.3(V,V$T9"P@,'AB834Q,&-D9BP@,'@X,68T
M-V,Y9BP@,'AA9#$Q-C-E9"P@,'AE83=B-3DV-2P@,'@Q83`P-S(V92P*("`@
M("`@("`P>#$Q-#`S,#DR+"`P>#`P9&$V9#<W+"`P>#1A,&-D9#8Q+"`P>&%D
M,68T-C`S+"`P>#8P-6)D9F(P+"`P>#EE961C,S8T+"`P>#(R96)E-F$X+"`P
M>&-E93=D,CAA+`H@("`@("`@(#!X83!E-S,V83`L(#!X-34V-&$V8CDL(#!X
M,3`X-3,R,#DL(#!X8S=E8CAF,S<L(#!X,F1E-S`U8V$L(#!X.#DU,34W,&8L
M(#!X9&8P.3@R,F(L(#!X8F0V.3%A-F,L"B`@("`@("`@,'AA83$R931F,BP@
M,'@X-S0U,6,P9BP@,'AE,&8V83(W82P@,'@S861A-#@Q.2P@,'@T8V8Q-S8T
M9BP@,'@P9#<W,6,R8BP@,'@V-V-D8C$U-BP@,'@S-3!D.#,X-"P*("`@("`@
M("`P>#4Y,SAF83!F+"`P>#0R,SDY968S+"`P>#,V.3DW8C`W+"`P>#!E.#0P
M.3-D+"`P>#1A83DS938Q+"`P>#@S-C!D.#=B+"`P>#%F83DX8C!C+"`P>#$Q
M-#DS.#)C+`H@("`@("`@(#!X93DW-C(U834L(#!X,#8Q-&0Q8C<L(#!X,&4R
M-3(T-&(L(#!X,&,W-C@S-#<L(#!X-3@Y93AD.#(L(#!X,&0R,#4Y9#$L(#!X
M830V-F)B,64L(#!X9CAD83!A.#(L"B`@("`@("`@,'@P-&8Q.3$S,"P@,'AB
M839E-&5C,"P@,'@Y.3(V-3$V-"P@,'@Q964W,C,P9"P@,'@U,&(R860X,"P@
M,'AE865E-C@P,2P@,'@X9&(R83(X,RP@,'AE83AB9C4Y92D["@H@("`@+RHJ
M"B`@("`@*B!-87-K:6YG($ME>7,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7TMM(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J(%)O=&%T92!+97ES"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]+<B`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4
M:&4@;G5M8F5R(&]F(')O=6YD<R!T;R!D;PH@("`@("H*("`@("`J($!V87(@
M:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]R;W5N9',@/2`Q-CL*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@:V5Y('1O(&)E('5S960@9F]R(&5N+V1E8W)Y
M<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!4:&4@
M:V5Y('1O('5S92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2V5Y*"1K97DI
M"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<F]U;F1S(#T@*'-T<FQE;B@D:V5Y*2`\(#$Q*2`_(#$R
M(#H@,38["B`@("`@("`@("`@("1K97D@/2`D=&AI<RT^7V9O<FUA=$ME>2@D
M:V5Y*3L*("`@("`@("`@("`@)&ME>5-C:&5D=6QE(#T@)'1H:7,M/E]K97E3
M8VAE9'5L92@D:V5Y*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE('-I>F4@;V8@=&AE(&)L;V-K<R!T:&%T('1H:7,@8VEP
M:&5R(&YE961S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE
M(&YU;6)E<B!O9B!C:&%R86-T97)S('!E<B!B;&]C:RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T0FQO8VM3:7IE*"D*("`@('L*("`@("`@("!R971U<FX@
M.#L*("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!B;&]C:R!O9B!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@
M9&%T82!T;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@
M(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@96YC<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M96YC<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<F]U;F1S(#T@*'-T<FQE;B@D:V5Y*2`\(#$Q*2`_(#$R(#H@,38["B`@("`@
M("`@("`@("1K97D@/2`D=&AI<RT^7V9O<FUA=$ME>2@D:V5Y*3L*("`@("`@
M("`@("`@)&ME>5-C:&5D=6QE(#T@)'1H:7,M/E]K97E38VAE9'5L92@D:V5Y
M*3L*("`@("`@("!]"@H@("`@("`@("1,(#T@)'1H:7,M/E]F;W)M871$871A
M*'-U8G-T<B@D8FQO8VLL(#`L(#0I*3L*("`@("`@("`D4B`]("1T:&ES+3Y?
M9F]R;6%T1&%T82AS=6)S='(H)&)L;V-K+"`T+"`T*2D["@H@("`@("`@("1,
M(%X]("1T:&ES+3YF,2@D4BP@)'1H:7,M/E]+;5LQ72P@("1T:&ES+3Y?2W);
M,5TI.PH@("`@("`@("12(%X]("1T:&ES+3YF,B@D3"P@)'1H:7,M/E]+;5LR
M72P@("1T:&ES+3Y?2W);,ETI.PH@("`@("`@("1,(%X]("1T:&ES+3YF,R@D
M4BP@)'1H:7,M/E]+;5LS72P@("1T:&ES+3Y?2W);,UTI.PH@("`@("`@("12
M(%X]("1T:&ES+3YF,2@D3"P@)'1H:7,M/E]+;5LT72P@("1T:&ES+3Y?2W);
M-%TI.PH@("`@("`@("1,(%X]("1T:&ES+3YF,B@D4BP@)'1H:7,M/E]+;5LU
M72P@("1T:&ES+3Y?2W);-5TI.PH@("`@("`@("12(%X]("1T:&ES+3YF,R@D
M3"P@)'1H:7,M/E]+;5LV72P@("1T:&ES+3Y?2W);-ETI.PH@("`@("`@("1,
M(%X]("1T:&ES+3YF,2@D4BP@)'1H:7,M/E]+;5LW72P@("1T:&ES+3Y?2W);
M-UTI.PH@("`@("`@("12(%X]("1T:&ES+3YF,B@D3"P@)'1H:7,M/E]+;5LX
M72P@("1T:&ES+3Y?2W);.%TI.PH@("`@("`@("1,(%X]("1T:&ES+3YF,R@D
M4BP@)'1H:7,M/E]+;5LY72P@("1T:&ES+3Y?2W);.5TI.PH@("`@("`@("12
M(%X]("1T:&ES+3YF,2@D3"P@)'1H:7,M/E]+;5LQ,%TL("1T:&ES+3Y?2W);
M,3!=*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C(H)%(L("1T:&ES+3Y?2VU;
M,3%=+"`D=&AI<RT^7TMR6S$Q72D["B`@("`@("`@)%(@7CT@)'1H:7,M/F8S
M*"1,+"`D=&AI<RT^7TMM6S$R72P@)'1H:7,M/E]+<ELQ,ETI.PH@("`@("`@
M(&EF("@D=&AI<RT^7W)O=6YD<R`^(#$R*2!["B`@("`@("`@("`@("1,(%X]
M("1T:&ES+3YF,2@D4BP@)'1H:7,M/E]+;5LQ,UTL("1T:&ES+3Y?2W);,3-=
M*3L*("`@("`@("`@("`@)%(@7CT@)'1H:7,M/F8R*"1,+"`D=&AI<RT^7TMM
M6S$T72P@)'1H:7,M/E]+<ELQ-%TI.PH@("`@("`@("`@("`D3"!>/2`D=&AI
M<RT^9C,H)%(L("1T:&ES+3Y?2VU;,35=+"`D=&AI<RT^7TMR6S$U72D["B`@
M("`@("`@("`@("12(%X]("1T:&ES+3YF,2@D3"P@)'1H:7,M/E]+;5LQ-ETL
M("1T:&ES+3Y?2W);,39=*3L*("`@("`@("!]"@H@("`@("`@("1E;F-R>7!T
M960@/2!P86-K*").(BP@)%(I("X@<&%C:R@B3B(L("1,*3L*"B`@("`@("`@
M<F5T=7)N("1E;F-R>7!T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R
M>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1B;&]C:R`@5&AE(&1A=&$@=&\@9&5C<GEP="X*("`@("`J($!P87)A
M;2!S=')I;F<@)&ME>2`@("!4:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!O=71P=70N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'1";&]C:R@D8FQO8VLL("1K97D@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W)O=6YD<R`]("AS=')L96XH)&ME>2D@/"`Q,2D@
M/R`Q,B`Z(#$V.PH@("`@("`@("`@("`D:V5Y(#T@)'1H:7,M/E]F;W)M871+
M97DH)&ME>2D["B`@("`@("`@("`@("1K97E38VAE9'5L92`]("1T:&ES+3Y?
M:V5Y4V-H961U;&4H)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D4B`]("1T
M:&ES+3Y?9F]R;6%T1&%T82AS=6)S='(H)&)L;V-K+"`P+"`T*2D["B`@("`@
M("`@)$P@/2`D=&AI<RT^7V9O<FUA=$1A=&$H<W5B<W1R*"1B;&]C:RP@-"P@
M-"DI.PH*("`@("`@("!I9B`H)'1H:7,M/E]R;W5N9',@/B`Q,BD@>PH@("`@
M("`@("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;,39=+"`D
M=&AI<RT^7TMR6S$V72D["B`@("`@("`@("`@("1,(%X]("1T:&ES+3YF,R@D
M4BP@)'1H:7,M/E]+;5LQ-5TL("1T:&ES+3Y?2W);,35=*3L*("`@("`@("`@
M("`@)%(@7CT@)'1H:7,M/F8R*"1,+"`D=&AI<RT^7TMM6S$T72P@)'1H:7,M
M/E]+<ELQ-%TI.PH@("`@("`@("`@("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T
M:&ES+3Y?2VU;,3-=+"`D=&AI<RT^7TMR6S$S72D["B`@("`@("`@?0H*("`@
M("`@("`D4B!>/2`D=&AI<RT^9C,H)$PL("1T:&ES+3Y?2VU;,3)=+"`D=&AI
M<RT^7TMR6S$R72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8R*"12+"`D=&AI
M<RT^7TMM6S$Q72P@)'1H:7,M/E]+<ELQ,5TI.PH@("`@("`@("12(%X]("1T
M:&ES+3YF,2@D3"P@)'1H:7,M/E]+;5LQ,%TL("1T:&ES+3Y?2W);,3!=*3L*
M("`@("`@("`D3"!>/2`D=&AI<RT^9C,H)%(L("1T:&ES+3Y?2VU;.5TL("`D
M=&AI<RT^7TMR6SE=*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C(H)$PL("1T
M:&ES+3Y?2VU;.%TL("`D=&AI<RT^7TMR6SA=*3L*("`@("`@("`D3"!>/2`D
M=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;-UTL("`D=&AI<RT^7TMR6S==*3L*
M("`@("`@("`D4B!>/2`D=&AI<RT^9C,H)$PL("1T:&ES+3Y?2VU;-ETL("`D
M=&AI<RT^7TMR6S9=*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C(H)%(L("1T
M:&ES+3Y?2VU;-5TL("`D=&AI<RT^7TMR6S5=*3L*("`@("`@("`D4B!>/2`D
M=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;-%TL("`D=&AI<RT^7TMR6S1=*3L*
M("`@("`@("`D3"!>/2`D=&AI<RT^9C,H)%(L("1T:&ES+3Y?2VU;,UTL("`D
M=&AI<RT^7TMR6S-=*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C(H)$PL("1T
M:&ES+3Y?2VU;,ETL("`D=&AI<RT^7TMR6S)=*3L*("`@("`@("`D3"!>/2`D
M=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;,5TL("`D=&AI<RT^7TMR6S%=*3L*
M"B`@("`@("`@)&1E8W)Y<'1E9"`]('!A8VLH(DXB+"`D3"D@+B!P86-K*").
M(BP@)%(I.PH*("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*("`@('T*"B`@
M("`O*BH*("`@("`J(&8Q*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9C$H)&0L
M("1+;2P@)$MR*0H@("`@>PH@("`@("`@("1)(#T@)$MM("L@)&0["@H@("`@
M("`@("\J($YA<W1Y($9I>"!A<PH@("`@("`@("`J("1)(#P\("1+<B!\("1)
M(#X^("@S,B`M("1+<BD*("`@("`@("`@*B!$;V5S;B=T(&%L=V%Y<R!G:79E
M('1H92!C;W)R96-T(&%N<W=E<@H@("`@("`@("`J+PH@("`@("`@("1B:6X@
M/2!S=')?<&%D*&1E8V)I;B@D22DL(#,R+"`G,"<L(%-44E]0041?3$5&5"D[
M"B`@("`@("`@)$D@/2!B:6YD96,H<W5B<W1R*"1B:6XL("1+<BD@+B!S=6)S
M='(H)&)I;BP@,"P@)$MR*2D["@H@("`@("`@("1F(#T@)'1H:7,M/G,Q6R@D
M22`^/B`R-"D@)B`P>$9&72!>("1T:&ES+3YS,ELH)$D@/CX@,38I("8@,'A&
M1ET["B`@("`@("`@)&8@/2`D9B`M("1T:&ES+3YS,ULH)$D@/CX@."D@)B`P
M>$9&73L*("`@("`@("`D9B`]("1F("L@)'1H:7,M/G,T6R1)("8@,'A&1ET[
M"B`@("`@("`@<F5T=7)N("1F.PH@("`@?0H*("`@("\J*@H@("`@("H@9C(H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!F,B@D9"P@)$MM+"`D2W(I"B`@("![
M"B`@("`@("`@)$D@/2`D2VT@7B`D9#L*"B`@("`@("`@+RH@3F%S='D@1FEX
M(&%S"B`@("`@("`@("H@)$D@/#P@)$MR('P@)$D@/CX@*#,R("T@)$MR*0H@
M("`@("`@("`J($1O97-N)W0@86QW87ES(&=I=F4@=&AE(&-O<G)E8W0@86YS
M=V5R"B`@("`@("`@("HO"B`@("`@("`@)&)I;B`]('-T<E]P860H9&5C8FEN
M*"1)*2P@,S(L("<P)RP@4U127U!!1%],1494*3L*("`@("`@("`D22`](&)I
M;F1E8RAS=6)S='(H)&)I;BP@)$MR*2`N('-U8G-T<B@D8FEN+"`P+"`D2W(I
M*3L*"B`@("`@("`@)&8@/2`D=&AI<RT^<S%;*"1)(#X^(#(T*2`F(#!X1D9=
M("T@)'1H:7,M/G,R6R@D22`^/B`Q-BD@)B`P>$9&73L*("`@("`@("`D9B`]
M("1F("L@)'1H:7,M/G,S6R@D22`^/B`X*2`F(#!X1D9=.PH@("`@("`@("1F
M(#T@)&8@7B`D=&AI<RT^<S1;)$D@)B`P>$9&73L*("`@("`@("!R971U<FX@
M)&8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!F,R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&8S*"1D+"`D2VTL("1+<BD*("`@('L*("`@("`@("`D22`](#!X
M1D9&1D9&1D8@)B`H)$MM("T@)&0I.PH*("`@("`@("`O*B!.87-T>2!&:7@@
M87,*("`@("`@("`@*B`D22`\/"`D2W(@?"`D22`^/B`H,S(@+2`D2W(I"B`@
M("`@("`@("H@1&]E<VXG="!A;'=A>7,@9VEV92!T:&4@8V]R<F5C="!A;G-W
M97(*("`@("`@("`@*B\*("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH
M)$DI+"`S,BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@("1)(#T@8FEN
M9&5C*'-U8G-T<B@D8FEN+"`D2W(I("X@<W5B<W1R*"1B:6XL(#`L("1+<BDI
M.PH*("`@("`@("`D9B`]("@D=&AI<RT^<S%;*"1)(#X^(#(T*2`F(#!X1D9=
M("L@)'1H:7,M/G,R6R@D22`^/B`Q-BD@)B`P>$9&72D["B`@("`@("`@)&8@
M/2`D9B!>("1T:&ES+3YS,ULH)$D@/CX@."D@)B`P>$9&73L*("`@("`@("`D
M9B`](#!X1D9&1D9&1D8@)B`H)&8@+2`D=&AI<RT^<S1;)$D@)B`P>$9&72D[
M"B`@("`@("`@<F5T=7)N("1F.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N
M=F5R="!A('-T<FEN9R!I;G1O(&$@87)R87D@;V8@=&AE(&]R9&EN871E<R!O
M9B!I=',@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D871A("!$871A('1O(&-O;G9E<G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@5&AE(&-O;G9E<G1E9"!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9F]R;6%T1&%T82@D9&%T82D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]C;VUB:6YE-"AU;G!A8VLH)T,J)RP@)&1A=&$I+"`P>#$I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!T97AT(&ME>2!I;G1O
M(&%N(&%R<F%Y('!A9&1E9"!W:71H(%PP)W,@=&\@82!L96YG=&@@;V8@,3(X
M"B`@("`@*B!B:71S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME
M>2`@5&AE(&ME>2!T;R!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE('!A9&1E9"!K97DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F
M;W)M871+97DH)&ME>2D*("`@('L*("`@("`@("`D<F5S(#T@87)R87E?=F%L
M=65S*'5N<&%C:R@G0RHG+"`D:V5Y*2D["B`@("`@("`@9F]R("@D:2`](&-O
M=6YT*"1R97,I.R`D:2`\(#$V.R`D:2LK*2!["B`@("`@("`@("`@("1R97-;
M)&E=(#T@,#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE(&-O;7!L971E(&ME>2!S:&5D
M=6QE+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D:V5Y("!4:&4@:V5Y
M('1O('5S92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VME>5-C:&5D=6QE*"1K
M97DI"B`@("!["B`@("`@("`@)'@P>#%X,G@S(#T@)'1H:7,M/E]C;VUB:6YE
M-"@D:V5Y+"`P>#`I.PH@("`@("`@("1X-'@U>#9X-R`]("1T:&ES+3Y?8V]M
M8FEN930H)&ME>2P@,'@T*3L*("`@("`@("`D>#AX.7A!>$(@/2`D=&AI<RT^
M7V-O;6)I;F4T*"1K97DL(#!X."D["B`@("`@("`@)'A#>$1X17A&(#T@)'1H
M:7,M/E]C;VUB:6YE-"@D:V5Y+"`P>$,I.PH*("`@("`@("`D8B`]("1T:&ES
M+3Y?<W!L:70H)'@P>#%X,G@S*3L@)'@P(#T@)&);,%T[("1X,2`]("1B6S%=
M.R`D>#(@/2`D8ELR73L@)'@S(#T@)&);,UT["B`@("`@("`@)&(@/2`D=&AI
M<RT^7W-P;&ET*"1X-'@U>#9X-RD[("1X-"`]("1B6S!=.R`D>#4@/2`D8ELQ
M73L@)'@V(#T@)&);,ET[("1X-R`]("1B6S-=.PH@("`@("`@("1B(#T@)'1H
M:7,M/E]S<&QI="@D>#AX.7A!>$(I.R`D>#@@/2`D8ELP73L@)'@Y(#T@)&);
M,5T[("1X02`]("1B6S)=.R`D>$(@/2`D8ELS73L*("`@("`@("`D8B`]("1T
M:&ES+3Y?<W!L:70H)'A#>$1X17A&*3L@)'A#(#T@)&);,%T[("1X1"`]("1B
M6S%=.R`D>$4@/2`D8ELR73L@)'A&(#T@)&);,UT["@H@("`@("`@("1Z,'HQ
M>C)Z,R`]("1X,'@Q>#)X,R!>("1T:&ES+3YS-5LD>$1=(%X@)'1H:7,M/G,V
M6R1X1ET@7B`D=&AI<RT^<S=;)'A#72!>("1T:&ES+3YS.%LD>$5=(%X@)'1H
M:7,M/G,W6R1X.%T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z,'HQ
M>C)Z,RD[("1Z,"`]("1B6S!=.R`D>C$@/2`D8ELQ73L@)'HR(#T@)&);,ET[
M("1Z,R`]("1B6S-=.PH@("`@("`@("1Z-'HU>C9Z-R`]("1X.'@Y>$%X0B!>
M("1T:&ES+3YS-5LD>C!=(%X@)'1H:7,M/G,V6R1Z,ET@7B`D=&AI<RT^<S=;
M)'HQ72!>("1T:&ES+3YS.%LD>C-=(%X@)'1H:7,M/G,X6R1X05T["B`@("`@
M("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z-'HU>C9Z-RD[("1Z-"`]("1B6S!=
M.R`D>C4@/2`D8ELQ73L@)'HV(#T@)&);,ET[("1Z-R`]("1B6S-=.PH@("`@
M("`@("1Z.'HY>D%Z0B`]("1X0WA$>$5X1B!>("1T:&ES+3YS-5LD>C==(%X@
M)'1H:7,M/G,V6R1Z-ET@7B`D=&AI<RT^<S=;)'HU72!>("1T:&ES+3YS.%LD
M>C1=(%X@)'1H:7,M/G,U6R1X.5T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P
M;&ET*"1Z.'HY>D%Z0BD[("1Z."`]("1B6S!=.R`D>CD@/2`D8ELQ73L@)'I!
M(#T@)&);,ET[("1Z0B`]("1B6S-=.PH@("`@("`@("1Z0WI$>D5Z1B`]("1X
M-'@U>#9X-R!>("1T:&ES+3YS-5LD>D%=(%X@)'1H:7,M/G,V6R1Z.5T@7B`D
M=&AI<RT^<S=;)'I"72!>("1T:&ES+3YS.%LD>CA=(%X@)'1H:7,M/G,V6R1X
M0ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z0WI$>D5Z1BD[("1Z
M0R`]("1B6S!=.R`D>D0@/2`D8ELQ73L@)'I%(#T@)&);,ET[("1Z1B`]("1B
M6S-=.PH*("`@("`@("`D=&AI<RT^7TMM6S%=(#T@)'1H:7,M/G,U6R1Z.%T@
M7B`D=&AI<RT^<S9;)'HY72!>("1T:&ES+3YS-ULD>C==(%X@)'1H:7,M/G,X
M6R1Z-ET@7B`D=&AI<RT^<S5;)'HR73L*("`@("`@("`D=&AI<RT^7TMM6S)=
M(#T@)'1H:7,M/G,U6R1Z05T@7B`D=&AI<RT^<S9;)'I"72!>("1T:&ES+3YS
M-ULD>C5=(%X@)'1H:7,M/G,X6R1Z-%T@7B`D=&AI<RT^<S9;)'HV73L*("`@
M("`@("`D=&AI<RT^7TMM6S-=(#T@)'1H:7,M/G,U6R1Z0UT@7B`D=&AI<RT^
M<S9;)'I$72!>("1T:&ES+3YS-ULD>C-=(%X@)'1H:7,M/G,X6R1Z,ET@7B`D
M=&AI<RT^<S=;)'HY73L*("`@("`@("`D=&AI<RT^7TMM6S1=(#T@)'1H:7,M
M/G,U6R1Z15T@7B`D=&AI<RT^<S9;)'I&72!>("1T:&ES+3YS-ULD>C%=(%X@
M)'1H:7,M/G,X6R1Z,%T@7B`D=&AI<RT^<SA;)'I#73L*"B`@("`@("`@)'@P
M>#%X,G@S(#T@)'HX>CEZ07I"(%X@)'1H:7,M/G,U6R1Z-5T@7B`D=&AI<RT^
M<S9;)'HW72!>("1T:&ES+3YS-ULD>C1=(%X@)'1H:7,M/G,X6R1Z-ET@7B`D
M=&AI<RT^<S=;)'HP73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@P
M>#%X,G@S*3L@)'@P(#T@)&);,%T[("1X,2`]("1B6S%=.R`D>#(@/2`D8ELR
M73L@)'@S(#T@)&);,UT["B`@("`@("`@)'@T>#5X-G@W(#T@)'HP>C%Z,GHS
M(%X@)'1H:7,M/G,U6R1X,%T@7B`D=&AI<RT^<S9;)'@R72!>("1T:&ES+3YS
M-ULD>#%=(%X@)'1H:7,M/G,X6R1X,UT@7B`D=&AI<RT^<SA;)'HR73L*("`@
M("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@T>#5X-G@W*3L@)'@T(#T@)&);
M,%T[("1X-2`]("1B6S%=.R`D>#8@/2`D8ELR73L@)'@W(#T@)&);,UT["B`@
M("`@("`@)'@X>#EX07A"(#T@)'HT>C5Z-GHW(%X@)'1H:7,M/G,U6R1X-UT@
M7B`D=&AI<RT^<S9;)'@V72!>("1T:&ES+3YS-ULD>#5=(%X@)'1H:7,M/G,X
M6R1X-%T@7B`D=&AI<RT^<S5;)'HQ73L*("`@("`@("`D8B`]("1T:&ES+3Y?
M<W!L:70H)'@X>#EX07A"*3L@)'@X(#T@)&);,%T[("1X.2`]("1B6S%=.R`D
M>$$@/2`D8ELR73L@)'A"(#T@)&);,UT["B`@("`@("`@)'A#>$1X17A&(#T@
M)'I#>D1Z17I&(%X@)'1H:7,M/G,U6R1X05T@7B`D=&AI<RT^<S9;)'@Y72!>
M("1T:&ES+3YS-ULD>$)=(%X@)'1H:7,M/G,X6R1X.%T@7B`D=&AI<RT^<S9;
M)'HS73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'A#>$1X17A&*3L@
M)'A#(#T@)&);,%T[("1X1"`]("1B6S%=.R`D>$4@/2`D8ELR73L@)'A&(#T@
M)&);,UT["@H@("`@("`@("1T:&ES+3Y?2VU;-5T@(#T@)'1H:7,M/G,U6R1X
M,UT@7B`D=&AI<RT^<S9;)'@R72!>("1T:&ES+3YS-ULD>$-=(%X@)'1H:7,M
M/G,X6R1X1%T@7B`D=&AI<RT^<S5;)'@X73L*("`@("`@("`D=&AI<RT^7TMM
M6S9=("`]("1T:&ES+3YS-5LD>#%=(%X@)'1H:7,M/G,V6R1X,%T@7B`D=&AI
M<RT^<S=;)'A%72!>("1T:&ES+3YS.%LD>$9=(%X@)'1H:7,M/G,V6R1X1%T[
M"B`@("`@("`@)'1H:7,M/E]+;5LW72`@/2`D=&AI<RT^<S5;)'@W72!>("1T
M:&ES+3YS-ELD>#9=(%X@)'1H:7,M/G,W6R1X.%T@7B`D=&AI<RT^<SA;)'@Y
M72!>("1T:&ES+3YS-ULD>#-=.PH@("`@("`@("1T:&ES+3Y?2VU;.%T@(#T@
M)'1H:7,M/G,U6R1X-5T@7B`D=&AI<RT^<S9;)'@T72!>("1T:&ES+3YS-ULD
M>$%=(%X@)'1H:7,M/G,X6R1X0ET@7B`D=&AI<RT^<SA;)'@W73L*"B`@("`@
M("`@)'HP>C%Z,GHS(#T@)'@P>#%X,G@S(%X@)'1H:7,M/G,U6R1X1%T@7B`D
M=&AI<RT^<S9;)'A&72!>("1T:&ES+3YS-ULD>$-=(%X@)'1H:7,M/G,X6R1X
M15T@7B`D=&AI<RT^<S=;)'@X73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L
M:70H)'HP>C%Z,GHS*3L@)'HP(#T@)&);,%T[("1Z,2`]("1B6S%=.R`D>C(@
M/2`D8ELR73L@)'HS(#T@)&);,UT["B`@("`@("`@)'HT>C5Z-GHW(#T@)'@X
M>#EX07A"(%X@)'1H:7,M/G,U6R1Z,%T@7B`D=&AI<RT^<S9;)'HR72!>("1T
M:&ES+3YS-ULD>C%=(%X@)'1H:7,M/G,X6R1Z,UT@7B`D=&AI<RT^<SA;)'A!
M73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HT>C5Z-GHW*3L@)'HT
M(#T@)&);,%T[("1Z-2`]("1B6S%=.R`D>C8@/2`D8ELR73L@)'HW(#T@)&);
M,UT["B`@("`@("`@)'HX>CEZ07I"(#T@)'A#>$1X17A&(%X@)'1H:7,M/G,U
M6R1Z-UT@7B`D=&AI<RT^<S9;)'HV72!>("1T:&ES+3YS-ULD>C5=(%X@)'1H
M:7,M/G,X6R1Z-%T@7B`D=&AI<RT^<S5;)'@Y73L*("`@("`@("`D8B`]("1T
M:&ES+3Y?<W!L:70H)'HX>CEZ07I"*3L@)'HX(#T@)&);,%T[("1Z.2`]("1B
M6S%=.R`D>D$@/2`D8ELR73L@)'I"(#T@)&);,UT["B`@("`@("`@)'I#>D1Z
M17I&(#T@)'@T>#5X-G@W(%X@)'1H:7,M/G,U6R1Z05T@7B`D=&AI<RT^<S9;
M)'HY72!>("1T:&ES+3YS-ULD>D)=(%X@)'1H:7,M/G,X6R1Z.%T@7B`D=&AI
M<RT^<S9;)'A"73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'I#>D1Z
M17I&*3L@)'I#(#T@)&);,%T[("1Z1"`]("1B6S%=.R`D>D4@/2`D8ELR73L@
M)'I&(#T@)&);,UT["@H@("`@("`@("1T:&ES+3Y?2VU;.5T@(#T@)'1H:7,M
M/G,U6R1Z,UT@7B`D=&AI<RT^<S9;)'HR72!>("1T:&ES+3YS-ULD>D-=(%X@
M)'1H:7,M/G,X6R1Z1%T@7B`D=&AI<RT^<S5;)'HY73L*("`@("`@("`D=&AI
M<RT^7TMM6S$P72`]("1T:&ES+3YS-5LD>C%=(%X@)'1H:7,M/G,V6R1Z,%T@
M7B`D=&AI<RT^<S=;)'I%72!>("1T:&ES+3YS.%LD>D9=(%X@)'1H:7,M/G,V
M6R1Z0UT["B`@("`@("`@)'1H:7,M/E]+;5LQ,5T@/2`D=&AI<RT^<S5;)'HW
M72!>("1T:&ES+3YS-ELD>C9=(%X@)'1H:7,M/G,W6R1Z.%T@7B`D=&AI<RT^
M<SA;)'HY72!>("1T:&ES+3YS-ULD>C)=.PH@("`@("`@("1T:&ES+3Y?2VU;
M,3)=(#T@)'1H:7,M/G,U6R1Z-5T@7B`D=&AI<RT^<S9;)'HT72!>("1T:&ES
M+3YS-ULD>D%=(%X@)'1H:7,M/G,X6R1Z0ET@7B`D=&AI<RT^<SA;)'HV73L*
M"B`@("`@("`@)'@P>#%X,G@S(#T@)'HX>CEZ07I"(%X@)'1H:7,M/G,U6R1Z
M-5T@7B`D=&AI<RT^<S9;)'HW72!>("1T:&ES+3YS-ULD>C1=(%X@)'1H:7,M
M/G,X6R1Z-ET@7B`D=&AI<RT^<S=;)'HP73L*("`@("`@("`D8B`]("1T:&ES
M+3Y?<W!L:70H)'@P>#%X,G@S*3L@)'@P(#T@)&);,%T[("1X,2`]("1B6S%=
M.R`D>#(@/2`D8ELR73L@)'@S(#T@)&);,UT["B`@("`@("`@)'@T>#5X-G@W
M(#T@)'HP>C%Z,GHS(%X@)'1H:7,M/G,U6R1X,%T@7B`D=&AI<RT^<S9;)'@R
M72!>("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M/G,X6R1X,UT@7B`D=&AI<RT^
M<SA;)'HR73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@T>#5X-G@W
M*3L@)'@T(#T@)&);,%T[("1X-2`]("1B6S%=.R`D>#8@/2`D8ELR73L@)'@W
M(#T@)&);,UT["B`@("`@("`@)'@X>#EX07A"(#T@)'HT>C5Z-GHW(%X@)'1H
M:7,M/G,U6R1X-UT@7B`D=&AI<RT^<S9;)'@V72!>("1T:&ES+3YS-ULD>#5=
M(%X@)'1H:7,M/G,X6R1X-%T@7B`D=&AI<RT^<S5;)'HQ73L*("`@("`@("`D
M8B`]("1T:&ES+3Y?<W!L:70H)'@X>#EX07A"*3L@)'@X(#T@)&);,%T[("1X
M.2`]("1B6S%=.R`D>$$@/2`D8ELR73L@)'A"(#T@)&);,UT["B`@("`@("`@
M)'A#>$1X17A&(#T@)'I#>D1Z17I&(%X@)'1H:7,M/G,U6R1X05T@7B`D=&AI
M<RT^<S9;)'@Y72!>("1T:&ES+3YS-ULD>$)=(%X@)'1H:7,M/G,X6R1X.%T@
M7B`D=&AI<RT^<S9;)'HS73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H
M)'A#>$1X17A&*3L@)'A#(#T@)&);,%T[("1X1"`]("1B6S%=.R`D>$4@/2`D
M8ELR73L@)'A&(#T@)&);,UT["@H@("`@("`@("1T:&ES+3Y?2VU;,3-=(#T@
M)'1H:7,M/G,U6R1X.%T@7B`D=&AI<RT^<S9;)'@Y72!>("1T:&ES+3YS-ULD
M>#==(%X@)'1H:7,M/G,X6R1X-ET@7B`D=&AI<RT^<S5;)'@S73L*("`@("`@
M("`D=&AI<RT^7TMM6S$T72`]("1T:&ES+3YS-5LD>$%=(%X@)'1H:7,M/G,V
M6R1X0ET@7B`D=&AI<RT^<S=;)'@U72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H
M:7,M/G,V6R1X-UT["B`@("`@("`@)'1H:7,M/E]+;5LQ-5T@/2`D=&AI<RT^
M<S5;)'A#72!>("1T:&ES+3YS-ELD>$1=(%X@)'1H:7,M/G,W6R1X,UT@7B`D
M=&AI<RT^<SA;)'@R72!>("1T:&ES+3YS-ULD>#A=.PH@("`@("`@("1T:&ES
M+3Y?2VU;,39=(#T@)'1H:7,M/G,U6R1X15T@7B`D=&AI<RT^<S9;)'A&72!>
M("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M/G,X6R1X,%T@7B`D=&AI<RT^<SA;
M)'A$73L*"B`@("`@("`@)'HP>C%Z,GHS(#T@)'@P>#%X,G@S(%X@)'1H:7,M
M/G,U6R1X1%T@7B`D=&AI<RT^<S9;)'A&72!>("1T:&ES+3YS-ULD>$-=(%X@
M)'1H:7,M/G,X6R1X15T@7B`D=&AI<RT^<S=;)'@X73L*("`@("`@("`D8B`]
M("1T:&ES+3Y?<W!L:70H)'HP>C%Z,GHS*3L@)'HP(#T@)&);,%T[("1Z,2`]
M("1B6S%=.R`D>C(@/2`D8ELR73L@)'HS(#T@)&);,UT["B`@("`@("`@)'HT
M>C5Z-GHW(#T@)'@X>#EX07A"(%X@)'1H:7,M/G,U6R1Z,%T@7B`D=&AI<RT^
M<S9;)'HR72!>("1T:&ES+3YS-ULD>C%=(%X@)'1H:7,M/G,X6R1Z,UT@7B`D
M=&AI<RT^<SA;)'A!73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HT
M>C5Z-GHW*3L@)'HT(#T@)&);,%T[("1Z-2`]("1B6S%=.R`D>C8@/2`D8ELR
M73L@)'HW(#T@)&);,UT["B`@("`@("`@)'HX>CEZ07I"(#T@)'A#>$1X17A&
M(%X@)'1H:7,M/G,U6R1Z-UT@7B`D=&AI<RT^<S9;)'HV72!>("1T:&ES+3YS
M-ULD>C5=(%X@)'1H:7,M/G,X6R1Z-%T@7B`D=&AI<RT^<S5;)'@Y73L*("`@
M("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HX>CEZ07I"*3L@)'HX(#T@)&);
M,%T[("1Z.2`]("1B6S%=.R`D>D$@/2`D8ELR73L@)'I"(#T@)&);,UT["B`@
M("`@("`@)'I#>D1Z17I&(#T@)'@T>#5X-G@W(%X@)'1H:7,M/G,U6R1Z05T@
M7B`D=&AI<RT^<S9;)'HY72!>("1T:&ES+3YS-ULD>D)=(%X@)'1H:7,M/G,X
M6R1Z.%T@7B`D=&AI<RT^<S9;)'A"73L*("`@("`@("`D8B`]("1T:&ES+3Y?
M<W!L:70H)'I#>D1Z17I&*3L@)'I#(#T@)&);,%T[("1Z1"`]("1B6S%=.R`D
M>D4@/2`D8ELR73L@)'I&(#T@)&);,UT["@H@("`@("`@("1T:&ES+3Y?2W);
M,5T@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'HX72!>("1T:&ES+3YS-ELD>CE=
M(%X@)'1H:7,M/G,W6R1Z-UT@7B`D=&AI<RT^<SA;)'HV72!>("1T:&ES+3YS
M-5LD>C)=*3L*("`@("`@("`D=&AI<RT^7TMR6S)=("`](#!X,48@)B`H)'1H
M:7,M/G,U6R1Z05T@7B`D=&AI<RT^<S9;)'I"72!>("1T:&ES+3YS-ULD>C5=
M(%X@)'1H:7,M/G,X6R1Z-%T@7B`D=&AI<RT^<S9;)'HV72D["B`@("`@("`@
M)'1H:7,M/E]+<ELS72`@/2`P>#%&("8@*"1T:&ES+3YS-5LD>D-=(%X@)'1H
M:7,M/G,V6R1Z1%T@7B`D=&AI<RT^<S=;)'HS72!>("1T:&ES+3YS.%LD>C)=
M(%X@)'1H:7,M/G,W6R1Z.5TI.PH@("`@("`@("1T:&ES+3Y?2W);-%T@(#T@
M,'@Q1B`F("@D=&AI<RT^<S5;)'I%72!>("1T:&ES+3YS-ELD>D9=(%X@)'1H
M:7,M/G,W6R1Z,5T@7B`D=&AI<RT^<SA;)'HP72!>("1T:&ES+3YS.%LD>D-=
M*3L*"B`@("`@("`@)'@P>#%X,G@S(#T@)'HX>CEZ07I"(%X@)'1H:7,M/G,U
M6R1Z-5T@7B`D=&AI<RT^<S9;)'HW72!>("1T:&ES+3YS-ULD>C1=(%X@)'1H
M:7,M/G,X6R1Z-ET@7B`D=&AI<RT^<S=;)'HP73L*("`@("`@("`D8B`]("1T
M:&ES+3Y?<W!L:70H)'@P>#%X,G@S*3L@)'@P(#T@)&);,%T[("1X,2`]("1B
M6S%=.R`D>#(@/2`D8ELR73L@)'@S(#T@)&);,UT["B`@("`@("`@)'@T>#5X
M-G@W(#T@)'HP>C%Z,GHS(%X@)'1H:7,M/G,U6R1X,%T@7B`D=&AI<RT^<S9;
M)'@R72!>("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M/G,X6R1X,UT@7B`D=&AI
M<RT^<SA;)'HR73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@T>#5X
M-G@W*3L@)'@T(#T@)&);,%T[("1X-2`]("1B6S%=.R`D>#8@/2`D8ELR73L@
M)'@W(#T@)&);,UT["B`@("`@("`@)'@X>#EX07A"(#T@)'HT>C5Z-GHW(%X@
M)'1H:7,M/G,U6R1X-UT@7B`D=&AI<RT^<S9;)'@V72!>("1T:&ES+3YS-ULD
M>#5=(%X@)'1H:7,M/G,X6R1X-%T@7B`D=&AI<RT^<S5;)'HQ73L*("`@("`@
M("`D8B`]("1T:&ES+3Y?<W!L:70H)'@X>#EX07A"*3L@)'@X(#T@)&);,%T[
M("1X.2`]("1B6S%=.R`D>$$@/2`D8ELR73L@)'A"(#T@)&);,UT["B`@("`@
M("`@)'A#>$1X17A&(#T@)'I#>D1Z17I&(%X@)'1H:7,M/G,U6R1X05T@7B`D
M=&AI<RT^<S9;)'@Y72!>("1T:&ES+3YS-ULD>$)=(%X@)'1H:7,M/G,X6R1X
M.%T@7B`D=&AI<RT^<S9;)'HS73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L
M:70H)'A#>$1X17A&*3L@)'A#(#T@)&);,%T[("1X1"`]("1B6S%=.R`D>$4@
M/2`D8ELR73L@)'A&(#T@)&);,UT["@H@("`@("`@("1T:&ES+3Y?2W);-5T@
M(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'@S72!>("1T:&ES+3YS-ELD>#)=(%X@
M)'1H:7,M/G,W6R1X0UT@7B`D=&AI<RT^<SA;)'A$72!>("1T:&ES+3YS-5LD
M>#A=*3L*("`@("`@("`D=&AI<RT^7TMR6S9=("`](#!X,48@)B`H)'1H:7,M
M/G,U6R1X,5T@7B`D=&AI<RT^<S9;)'@P72!>("1T:&ES+3YS-ULD>$5=(%X@
M)'1H:7,M/G,X6R1X1ET@7B`D=&AI<RT^<S9;)'A$72D["B`@("`@("`@)'1H
M:7,M/E]+<ELW72`@/2`P>#%&("8@*"1T:&ES+3YS-5LD>#==(%X@)'1H:7,M
M/G,V6R1X-ET@7B`D=&AI<RT^<S=;)'@X72!>("1T:&ES+3YS.%LD>#E=(%X@
M)'1H:7,M/G,W6R1X,UTI.PH@("`@("`@("1T:&ES+3Y?2W);.%T@(#T@,'@Q
M1B`F("@D=&AI<RT^<S5;)'@U72!>("1T:&ES+3YS-ELD>#1=(%X@)'1H:7,M
M/G,W6R1X05T@7B`D=&AI<RT^<SA;)'A"72!>("1T:&ES+3YS.%LD>#==*3L*
M"B`@("`@("`@)'HP>C%Z,GHS(#T@)'@P>#%X,G@S(%X@)'1H:7,M/G,U6R1X
M1%T@7B`D=&AI<RT^<S9;)'A&72!>("1T:&ES+3YS-ULD>$-=(%X@)'1H:7,M
M/G,X6R1X15T@7B`D=&AI<RT^<S=;)'@X73L*("`@("`@("`D8B`]("1T:&ES
M+3Y?<W!L:70H)'HP>C%Z,GHS*3L@)'HP(#T@)&);,%T[("1Z,2`]("1B6S%=
M.R`D>C(@/2`D8ELR73L@)'HS(#T@)&);,UT["B`@("`@("`@)'HT>C5Z-GHW
M(#T@)'@X>#EX07A"(%X@)'1H:7,M/G,U6R1Z,%T@7B`D=&AI<RT^<S9;)'HR
M72!>("1T:&ES+3YS-ULD>C%=(%X@)'1H:7,M/G,X6R1Z,UT@7B`D=&AI<RT^
M<SA;)'A!73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HT>C5Z-GHW
M*3L@)'HT(#T@)&);,%T[("1Z-2`]("1B6S%=.R`D>C8@/2`D8ELR73L@)'HW
M(#T@)&);,UT["B`@("`@("`@)'HX>CEZ07I"(#T@)'A#>$1X17A&(%X@)'1H
M:7,M/G,U6R1Z-UT@7B`D=&AI<RT^<S9;)'HV72!>("1T:&ES+3YS-ULD>C5=
M(%X@)'1H:7,M/G,X6R1Z-%T@7B`D=&AI<RT^<S5;)'@Y73L*("`@("`@("`D
M8B`]("1T:&ES+3Y?<W!L:70H)'HX>CEZ07I"*3L@)'HX(#T@)&);,%T[("1Z
M.2`]("1B6S%=.R`D>D$@/2`D8ELR73L@)'I"(#T@)&);,UT["B`@("`@("`@
M)'I#>D1Z17I&(#T@)'@T>#5X-G@W(%X@)'1H:7,M/G,U6R1Z05T@7B`D=&AI
M<RT^<S9;)'HY72!>("1T:&ES+3YS-ULD>D)=(%X@)'1H:7,M/G,X6R1Z.%T@
M7B`D=&AI<RT^<S9;)'A"73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H
M)'I#>D1Z17I&*3L@)'I#(#T@)&);,%T[("1Z1"`]("1B6S%=.R`D>D4@/2`D
M8ELR73L@)'I&(#T@)&);,UT["@H@("`@("`@("1T:&ES+3Y?2W);.5T@(#T@
M,'@Q1B`F("@D=&AI<RT^<S5;)'HS72!>("1T:&ES+3YS-ELD>C)=(%X@)'1H
M:7,M/G,W6R1Z0UT@7B`D=&AI<RT^<SA;)'I$72!>("1T:&ES+3YS-5LD>CE=
M*3L*("`@("`@("`D=&AI<RT^7TMR6S$P72`](#!X,48@)B`H)'1H:7,M/G,U
M6R1Z,5T@7B`D=&AI<RT^<S9;)'HP72!>("1T:&ES+3YS-ULD>D5=(%X@)'1H
M:7,M/G,X6R1Z1ET@7B`D=&AI<RT^<S9;)'I#72D["B`@("`@("`@)'1H:7,M
M/E]+<ELQ,5T@/2`P>#%&("8@*"1T:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V
M6R1Z-ET@7B`D=&AI<RT^<S=;)'HX72!>("1T:&ES+3YS.%LD>CE=(%X@)'1H
M:7,M/G,W6R1Z,ETI.PH@("`@("`@("1T:&ES+3Y?2W);,3)=(#T@,'@Q1B`F
M("@D=&AI<RT^<S5;)'HU72!>("1T:&ES+3YS-ELD>C1=(%X@)'1H:7,M/G,W
M6R1Z05T@7B`D=&AI<RT^<SA;)'I"72!>("1T:&ES+3YS.%LD>C9=*3L*"B`@
M("`@("`@)'@P>#%X,G@S(#T@)'HX>CEZ07I"(%X@)'1H:7,M/G,U6R1Z-5T@
M7B`D=&AI<RT^<S9;)'HW72!>("1T:&ES+3YS-ULD>C1=(%X@)'1H:7,M/G,X
M6R1Z-ET@7B`D=&AI<RT^<S=;)'HP73L*("`@("`@("`D8B`]("1T:&ES+3Y?
M<W!L:70H)'@P>#%X,G@S*3L@)'@P(#T@)&);,%T[("1X,2`]("1B6S%=.R`D
M>#(@/2`D8ELR73L@)'@S(#T@)&);,UT["B`@("`@("`@)'@T>#5X-G@W(#T@
M)'HP>C%Z,GHS(%X@)'1H:7,M/G,U6R1X,%T@7B`D=&AI<RT^<S9;)'@R72!>
M("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M/G,X6R1X,UT@7B`D=&AI<RT^<SA;
M)'HR73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@T>#5X-G@W*3L@
M)'@T(#T@)&);,%T[("1X-2`]("1B6S%=.R`D>#8@/2`D8ELR73L@)'@W(#T@
M)&);,UT["B`@("`@("`@)'@X>#EX07A"(#T@)'HT>C5Z-GHW(%X@)'1H:7,M
M/G,U6R1X-UT@7B`D=&AI<RT^<S9;)'@V72!>("1T:&ES+3YS-ULD>#5=(%X@
M)'1H:7,M/G,X6R1X-%T@7B`D=&AI<RT^<S5;)'HQ73L*("`@("`@("`D8B`]
M("1T:&ES+3Y?<W!L:70H)'@X>#EX07A"*3L@)'@X(#T@)&);,%T[("1X.2`]
M("1B6S%=.R`D>$$@/2`D8ELR73L@)'A"(#T@)&);,UT["B`@("`@("`@)'A#
M>$1X17A&(#T@)'I#>D1Z17I&(%X@)'1H:7,M/G,U6R1X05T@7B`D=&AI<RT^
M<S9;)'@Y72!>("1T:&ES+3YS-ULD>$)=(%X@)'1H:7,M/G,X6R1X.%T@7B`D
M=&AI<RT^<S9;)'HS73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'A#
M>$1X17A&*3L@)'A#(#T@)&);,%T[("1X1"`]("1B6S%=.R`D>$4@/2`D8ELR
M73L@)'A&(#T@)&);,UT["@H@("`@("`@("1T:&ES+3Y?2W);,3-=(#T@,'@Q
M1B`F("@D=&AI<RT^<S5;)'@X72!>("1T:&ES+3YS-ELD>#E=(%X@)'1H:7,M
M/G,W6R1X-UT@7B`D=&AI<RT^<SA;)'@V72!>("1T:&ES+3YS-5LD>#-=*3L*
M("`@("`@("`D=&AI<RT^7TMR6S$T72`](#!X,48@)B`H)'1H:7,M/G,U6R1X
M05T@7B`D=&AI<RT^<S9;)'A"72!>("1T:&ES+3YS-ULD>#5=(%X@)'1H:7,M
M/G,X6R1X-%T@7B`D=&AI<RT^<S9;)'@W72D["B`@("`@("`@)'1H:7,M/E]+
M<ELQ-5T@/2`P>#%&("8@*"1T:&ES+3YS-5LD>$-=(%X@)'1H:7,M/G,V6R1X
M1%T@7B`D=&AI<RT^<S=;)'@S72!>("1T:&ES+3YS.%LD>#)=(%X@)'1H:7,M
M/G,W6R1X.%TI.PH@("`@("`@("1T:&ES+3Y?2W);,39=(#T@,'@Q1B`F("@D
M=&AI<RT^<S5;)'A%72!>("1T:&ES+3YS-ELD>$9=(%X@)'1H:7,M/G,W6R1X
M,5T@7B`D=&AI<RT^<SA;)'@P72!>("1T:&ES+3YS.%LD>$1=*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%5N<&%C:R!T:&4@,S(@8FET('9A;'5E(&EN=&\@
M86X@87)R87D@;V8@9F]U<B`X(&)I="!V86QU97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'@@(#,R(&)I="!V86QU92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!&;W5R(#@@8FET('9A;'5E<R!-4R!T;R!,4RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W-P;&ET*"1X*0H@("`@>PH@("`@("`@
M(')E='5R;B!A<G)A>2@H)'@@/CX@,C0I("8@,'A&1BP@*"1X(#X^(#$V*2`F
M(#!X1D8L("@D>"`^/B`X*2`F(#!X1D8L("1X("8@,'A&1BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!086-K(&9O=7(@."!B:70@=F%L=65S(&EN=&\@;VYE
M(#,R(&)I="!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ME
M>2`@("`@($%R<F%Y(&]F(#@@8FET('9A;'5E<RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1S=&%R="`@4W1A<G0@<&]S:71I;VX@:6X@87)R87D@=&\@9V5T
M(#0@=F%L=65S(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R
M("`S,B!B:70@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VUB:6YE
M-"@D:V5Y+"`D<W1A<G0@/2`P*0H@("`@>PH@("`@("`@("1R97,@(#T@,#L*
M("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D<W1A<G0L("1K97DI*2![
M"B`@("`@("`@("`@("1R97,@?#T@*"1K97E;)'-T87)T72D@/#P@,C0["B`@
M("`@("`@?0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"1S=&%R="`K
M(#$L("1K97DI*2!["B`@("`@("`@("`@("1R97,@?#T@*"1K97E;)'-T87)T
M("L@,5TI(#P\(#$V.PH@("`@("`@('T*("`@("`@("!I9B`H87)R87E?:V5Y
M7V5X:7-T<R@D<W1A<G0@*R`R+"`D:V5Y*2D@>PH@("`@("`@("`@("`D<F5S
M('P]("@D:V5Y6R1S=&%R="`K(#)=*2`\/"`X.PH@("`@("`@('T*("`@("`@
M("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D<W1A<G0@*R`S+"`D:V5Y*2D@>PH@
M("`@("`@("`@("`D<F5S('P]("@D:V5Y6R1S=&%R="`K(#-=*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T-I<&AE<B]R8S(N<&AP````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q-S`W-P`Q,#0Q-S,V,C<W,0`P,C`V-34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!#:7!H97)?<F,R.CH@8VQA<W,@:6UP;&5M96YT<R!T:&4@0VEP:&5R
M(&EN=&5R9F%C92!E;F-R>7!T:6]N(&1A=&$*("H@=7-I;F<@=&AE(%)#,B!A
M;&=O<FET:&T@87,@9&5S8W)I8F5D(&EN(%)&0S(R-C@N"B`J"B`J($)A<V5D
M(&]N('1H92!N;W1E<R!B>2!0971E<B!'=71M86YN(#QP9W5T,#%`8W,N875C
M:VQA;F0N86,N;GH^"B`J(&AT='`Z+R]W=W<N;6ER<F]R<RYW:7)E=&%P<&5D
M+FYE="]S96-U<FET>2]C<GEP=&]G<F%P:'DO"B`J("`@86QG;W)I=&AM<R]R
M8S(O8V]M;65N=',O9W5T;6%N+3DV,#(Q,0H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]#:7!H97(O0VEP:&5R+W)C,BYP:'`L=B`Q+CDN,3(N-R`R,#`V+S`Q
M+S`Q(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@
M0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?
M<F,R(&5X=&5N9',@2&]R9&5?0VEP:&5R('L*"B`@("`O*BH*("`@("`J(%!E
M<FUU=&%T:6]N<R!A<G)A>0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?<&5R;2`](&%R<F%Y*`H@("`@("`@(#!X1#DL(#!X
M-S@L(#!X1CDL(#!X0S0L(#!X,3DL(#!X1$0L(#!X0C4L(#!X140L"B`@("`@
M("`@,'@R."P@,'A%.2P@,'A&1"P@,'@W.2P@,'@T02P@,'A!,"P@,'A$."P@
M,'@Y1"P*("`@("`@("`P>$,V+"`P>#=%+"`P>#,W+"`P>#@S+"`P>#)"+"`P
M>#<V+"`P>#4S+"`P>#A%+`H@("`@("`@(#!X-C(L(#!X-$,L(#!X-C0L(#!X
M.#@L(#!X-#0L(#!X.$(L(#!X1D(L(#!X03(L"B`@("`@("`@,'@Q-RP@,'@Y
M02P@,'@U.2P@,'A&-2P@,'@X-RP@,'A",RP@,'@T1BP@,'@Q,RP*("`@("`@
M("`P>#8Q+"`P>#0U+"`P>#9$+"`P>#A$+"`P>#`Y+"`P>#@Q+"`P>#=$+"`P
M>#,R+`H@("`@("`@(#!X0D0L(#!X.$8L(#!X-#`L(#!X14(L(#!X.#8L(#!X
M0C<L(#!X-T(L(#!X,$(L"B`@("`@("`@,'A&,"P@,'@Y-2P@,'@R,2P@,'@R
M,BP@,'@U0RP@,'@V0BP@,'@T12P@,'@X,BP*("`@("`@("`P>#4T+"`P>$0V
M+"`P>#8U+"`P>#DS+"`P>$-%+"`P>#8P+"`P>$(R+"`P>#%#+`H@("`@("`@
M(#!X-S,L(#!X-38L(#!X0S`L(#!X,30L(#!X03<L(#!X.$,L(#!X1C$L(#!X
M1$,L"B`@("`@("`@,'@Q,BP@,'@W-2P@,'A#02P@,'@Q1BP@,'@S0BP@,'A"
M12P@,'A%-"P@,'A$,2P*("`@("`@("`P>#0R+"`P>#-$+"`P>$0T+"`P>#,P
M+"`P>$$S+"`P>#-#+"`P>$(V+"`P>#(V+`H@("`@("`@(#!X-D8L(#!X0D8L
M(#!X,$4L(#!X1$$L(#!X-#8L(#!X-CDL(#!X,#<L(#!X-3<L"B`@("`@("`@
M,'@R-RP@,'A&,BP@,'@Q1"P@,'@Y0BP@,'A"0RP@,'@Y-"P@,'@T,RP@,'@P
M,RP*("`@("`@("`P>$8X+"`P>#$Q+"`P>$,W+"`P>$8V+"`P>#DP+"`P>$5&
M+"`P>#-%+"`P>$4W+`H@("`@("`@(#!X,#8L(#!X0S,L(#!X1#4L(#!X,D8L
M(#!X0S@L(#!X-C8L(#!X,44L(#!X1#<L"B`@("`@("`@,'@P."P@,'A%."P@
M,'A%02P@,'A$12P@,'@X,"P@,'@U,BP@,'A%12P@,'A&-RP*("`@("`@("`P
M>#@T+"`P>$%!+"`P>#<R+"`P>$%#+"`P>#,U+"`P>#1$+"`P>#9!+"`P>#)!
M+`H@("`@("`@(#!X.38L(#!X,4$L(#!X1#(L(#!X-S$L(#!X-4$L(#!X,34L
M(#!X-#DL(#!X-S0L"B`@("`@("`@,'@T0BP@,'@Y1BP@,'A$,"P@,'@U12P@
M,'@P-"P@,'@Q."P@,'A!-"P@,'A%0RP*("`@("`@("`P>$,R+"`P>$4P+"`P
M>#0Q+"`P>#9%+"`P>#!&+"`P>#4Q+"`P>$-"+"`P>$-#+`H@("`@("`@(#!X
M,C0L(#!X.3$L(#!X048L(#!X-3`L(#!X03$L(#!X1C0L(#!X-S`L(#!X,SDL
M"B`@("`@("`@,'@Y.2P@,'@W0RP@,'@S02P@,'@X-2P@,'@R,RP@,'A"."P@
M,'A"-"P@,'@W02P*("`@("`@("`P>$9#+"`P>#`R+"`P>#,V+"`P>#5"+"`P
M>#(U+"`P>#4U+"`P>#DW+"`P>#,Q+`H@("`@("`@(#!X,D0L(#!X-40L(#!X
M1D$L(#!X.3@L(#!X13,L(#!X.$$L(#!X.3(L(#!X044L"B`@("`@("`@,'@P
M-2P@,'A$1BP@,'@R.2P@,'@Q,"P@,'@V-RP@,'@V0RP@,'A"02P@,'A#.2P*
M("`@("`@("`P>$0S+"`P>#`P+"`P>$4V+"`P>$-&+"`P>$4Q+"`P>#E%+"`P
M>$$X+"`P>#)#+`H@("`@("`@(#!X-C,L(#!X,38L(#!X,#$L(#!X,T8L(#!X
M-3@L(#!X13(L(#!X.#DL(#!X03DL"B`@("`@("`@,'@P1"P@,'@S."P@,'@S
M-"P@,'@Q0BP@,'A!0BP@,'@S,RP@,'A&1BP@,'A","P*("`@("`@("`P>$)"
M+"`P>#0X+"`P>#!#+"`P>#5&+"`P>$(Y+"`P>$(Q+"`P>$-$+"`P>#)%+`H@
M("`@("`@(#!X0S4L(#!X1C,L(#!X1$(L(#!X-#<L(#!X134L(#!X034L(#!X
M.4,L(#!X-S<L"B`@("`@("`@,'@P02P@,'A!-BP@,'@R,"P@,'@V."P@,'A&
M12P@,'@W1BP@,'A#,2P@,'A!1`H@("`@*3L*"B`@("`O*BH*("`@("`J($%R
M<F%Y('1O(&AO;&0@=&AE(&ME>2!S8VAE9'5L90H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:V5Y4V-H961U;&4@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@4V5T('1H92!K97D@=&\@8F4@=7-E9"!F
M;W(@96XO9&5C<GEP=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1K97D@(%1H92!K97D@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971+97DH)&ME>2D*("`@('L*("`@("`@("`D:V5Y(#T@87)R87E?=F%L=65S
M*'5N<&%C:R@G0RHG+"`D:V5Y*2D["B`@("`@("`@)&)I=',@/2`Q,#(T.PH*
M("`@("`@("`O*B!%>'!A;F0@:6YP=70@:V5Y('1O(#$R."!B>71E<R`J+PH@
M("`@("`@("1L96X@/2!C;W5N="@D:V5Y*3L*("`@("`@("`D;&%S="`]("1K
M97E;)&QE;B`M(#%=.PH@("`@("`@(&9O<B`H)&D@/2`D;&5N.R`D:2`\(#$R
M.#L@)&DK*RD@>PH@("`@("`@("`@("`D;&%S="`]("1T:&ES+3Y?<&5R;5LH
M)&ME>5LD:2`M("1L96Y=("L@)&QA<W0I("8@,'A&1ET["B`@("`@("`@("`@
M("1K97E;)&E=(#T@)&QA<W0["B`@("`@("`@?0H*("`@("`@("`O*B!0:&%S
M92`R("T@<F5D=6-E(&5F9F5C=&EV92!K97D@<VEZ92!T;R`B8FET<R(@*B\*
M("`@("`@("!I9B`H)&QE;B`A/2`X*2!["B`@("`@("`@("`@("1L96X@/2`D
M;&5N("H@.#L*("`@("`@("!]"B`@("`@("`@)&ME>5LQ,C@@+2`D;&5N72`]
M("1T:&ES+3Y?<&5R;5LD:V5Y6S$R."`M("1L96Y=("8@,'A&1ET["B`@("`@
M("`@9F]R("@D:2`](#$R-R`M("1L96X[("1I(#X](#`[("1I+2TI('L*("`@
M("`@("`@("`@)&ME>5LD:5T@/2`D=&AI<RT^7W!E<FU;)&ME>5LD:2`K("1L
M96Y=(%X@)&ME>5LD:2`K(#%=73L*("`@("`@("!]"@H@("`@("`@("\J(%!H
M87-E(#,@+2!C;VYV97)T('1O(#$V(&)I="!V86QU97,@*B\*("`@("`@("!F
M;W(@*"1I(#T@-C,[("1I(#X](#`[("1I+2TI('L*("`@("`@("`@("`@)'1H
M:7,M/E]K97E38VAE9'5L95LD:5T@/2`H)&ME>5LD:2`J(#(@*R`Q72`\/"`X
M('P@)&ME>5LD:2`J(#)=*2`F(#!X1D9&1CL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-I>F4@;V8@=&AE(&)L;V-K<R!T
M:&%T('1H:7,@8VEP:&5R(&YE961S+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!C:&%R86-T97)S('!E<B!B;&]C:RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO8VM3:7IE*"D*("`@('L*("`@
M("`@("!R971U<FX@.#L*("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@
M82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&)L;V-K("!4:&4@9&%T82!T;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@96YC<GEP=&5D(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@96YC<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@
M("`@("1T:&ES+3YS971+97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D
M<&QA:6X@/2!U;G!A8VLH)W8J)RP@)&)L;V-K*3L*"B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@,38[("1I*RLI('L*("`@("`@("`@("`@)'!L86EN6S%=
M("L]("@D<&QA:6Y;,ET@)B!^)'!L86EN6S1=*2`K("@D<&QA:6Y;,UT@)B`D
M<&QA:6Y;-%TI("L@)'1H:7,M/E]K97E38VAE9'5L95LT("H@)&D@*R`P73L*
M("`@("`@("`@("`@)&)I;B`]('-T<E]P860H9&5C8FEN*#!X1D9&1B`F("1P
M;&%I;ELQ72DL(#,R+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@
M("1P;&%I;ELQ72`](&)I;F1E8R@D8FEN("X@<W5B<W1R*"1B:6XL(#$V+"`Q
M*2D["@H@("`@("`@("`@("`D<&QA:6Y;,ET@*ST@*"1P;&%I;ELS72`F('XD
M<&QA:6Y;,5TI("L@*"1P;&%I;ELT72`F("1P;&%I;ELQ72D@*R`D=&AI<RT^
M7VME>5-C:&5D=6QE6S0@*B`D:2`K(#%=.PH@("`@("`@("`@("`D8FEN(#T@
M<W1R7W!A9"AD96-B:6XH,'A&1D9&("8@)'!L86EN6S)=*2P@,S(L("<P)RP@
M4U127U!!1%],1494*3L*("`@("`@("`@("`@)'!L86EN6S)=(#T@8FEN9&5C
M*"1B:6X@+B!S=6)S='(H)&)I;BP@,38L(#(I*3L*"B`@("`@("`@("`@("1P
M;&%I;ELS72`K/2`H)'!L86EN6S1=("8@?B1P;&%I;ELR72D@*R`H)'!L86EN
M6S%=("8@)'!L86EN6S)=*2`K("1T:&ES+3Y?:V5Y4V-H961U;&5;-"`J("1I
M("L@,ET["B`@("`@("`@("`@("1B:6X@/2!S=')?<&%D*&1E8V)I;B@P>$9&
M1D8@)B`D<&QA:6Y;,UTI+"`Q-BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@
M("`@("`@("`D<&QA:6Y;,UT@/2!B:6YD96,H)&)I;B`N('-U8G-T<B@D8FEN
M+"`P+"`S*2D["@H@("`@("`@("`@("`D<&QA:6Y;-%T@*ST@*"1P;&%I;ELQ
M72`F('XD<&QA:6Y;,UTI("L@*"1P;&%I;ELR72`F("1P;&%I;ELS72D@*R`D
M=&AI<RT^7VME>5-C:&5D=6QE6S0@*B`D:2`K(#-=.PH@("`@("`@("`@("`D
M8FEN(#T@<W1R7W!A9"AD96-B:6XH,'A&1D9&("8@)'!L86EN6S1=*2P@,38L
M("<P)RP@4U127U!!1%],1494*3L*("`@("`@("`@("`@)'!L86EN6S1=(#T@
M8FEN9&5C*"1B:6X@+B!S=6)S='(H)&)I;BP@,"P@-2DI.PH*("`@("`@("`@
M("`@:68@*"1I(#T](#0@?'P@)&D@/3T@,3`I('L*("`@("`@("`@("`@("`@
M("1P;&%I;ELQ72`K/2`D=&AI<RT^7VME>5-C:&5D=6QE6R1P;&%I;ELT72`F
M(#!X,T9=.PH@("`@("`@("`@("`@("`@)'!L86EN6S)=("L]("1T:&ES+3Y?
M:V5Y4V-H961U;&5;)'!L86EN6S%=("8@,'@S1ET["B`@("`@("`@("`@("`@
M("`D<&QA:6Y;,UT@*ST@)'1H:7,M/E]K97E38VAE9'5L95LD<&QA:6Y;,ET@
M)B`P>#-&73L*("`@("`@("`@("`@("`@("1P;&%I;ELT72`K/2`D=&AI<RT^
M7VME>5-C:&5D=6QE6R1P;&%I;ELS72`F(#!X,T9=.PH@("`@("`@("`@("!]
M"@H@("`@("`@('T*"B`@("`@("`@)&5N8W)Y<'1E9"`]('!A8VLH(G8J(BP@
M)'!L86EN6S%=+"`D<&QA:6Y;,ETL("1P;&%I;ELS72P@)'!L86EN6S1=*3L*
M("`@("`@("!R971U<FX@)&5N8W)Y<'1E9#L*("`@('T*"B`@("`O*BH*("`@
M("`J($1E8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP=&5D(&]U='!U
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP=$)L;V-K*"1B;&]C:RP@
M)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI
M*2!["B`@("`@("`@("`@("1T:&ES+3YS971+97DH)&ME>2D["B`@("`@("`@
M?0H*("`@("`@("`D8VEP:&5R(#T@=6YP86-K*"=V*B<L("1B;&]C:RD["@H@
M("`@("`@(&9O<B`H)&D@/2`Q-3L@)&D@/CT@,#L@)&DM+2D@>PH@("`@("`@
M("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH,'A&1D9&("8@)&-I<&AE<ELT
M72DL(#$V+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1C:7!H
M97);-%T@/2!B:6YD96,H<W5B<W1R*"1B:6XL("TR,2P@,C$I("X@<W5B<W1R
M*"1B:6XL(#`L(#$Q*2D["B`@("`@("`@("`@("1C:7!H97);-%T@+3T@*"1C
M:7!H97);,5T@)B!^)&-I<&AE<ELS72D@*R`H)&-I<&AE<ELR72`F("1C:7!H
M97);,UTI("L@)'1H:7,M/E]K97E38VAE9'5L95LT("H@)&D@*R`S73L*"B`@
M("`@("`@("`@("1B:6X@/2!S=')?<&%D*&1E8V)I;B@P>$9&1D8@)B`D8VEP
M:&5R6S-=*2P@,38L("<P)RP@4U127U!!1%],1494*3L*("`@("`@("`@("`@
M)&-I<&AE<ELS72`](&)I;F1E8RAS=6)S='(H)&)I;BP@+3$Y+"`Q.2D@+B!S
M=6)S='(H)&)I;BP@,"P@,3,I*3L*("`@("`@("`@("`@)&-I<&AE<ELS72`M
M/2`H)&-I<&AE<ELT72`F('XD8VEP:&5R6S)=*2`K("@D8VEP:&5R6S%=("8@
M)&-I<&AE<ELR72D@*R`D=&AI<RT^7VME>5-C:&5D=6QE6S0@*B`D:2`K(#)=
M.PH*("`@("`@("`@("`@)&)I;B`]('-T<E]P860H9&5C8FEN*#!X1D9&1B`F
M("1C:7!H97);,ETI+"`Q-BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@
M("`@("`D8VEP:&5R6S)=(#T@8FEN9&5C*'-U8G-T<B@D8FEN+"`M,3@L(#$X
M*2`N('-U8G-T<B@D8FEN+"`P+"`Q-"DI.PH@("`@("`@("`@("`D8VEP:&5R
M6S)=("T]("@D8VEP:&5R6S-=("8@?B1C:7!H97);,5TI("L@*"1C:7!H97);
M-%T@)B`D8VEP:&5R6S%=*2`K("1T:&ES+3Y?:V5Y4V-H961U;&5;-"`J("1I
M("L@,5T["@H@("`@("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH,'A&
M1D9&("8@)&-I<&AE<ELQ72DL(#$V+"`G,"<L(%-44E]0041?3$5&5"D["B`@
M("`@("`@("`@("1C:7!H97);,5T@/2!B:6YD96,H<W5B<W1R*"1B:6XL("TQ
M-RP@,3<I("X@<W5B<W1R*"1B:6XL(#`L(#$U*2D["B`@("`@("`@("`@("1C
M:7!H97);,5T@+3T@*"1C:7!H97);,ET@)B!^)&-I<&AE<ELT72D@*R`H)&-I
M<&AE<ELS72`F("1C:7!H97);-%TI("L@)'1H:7,M/E]K97E38VAE9'5L95LT
M("H@)&D@*R`P73L*"B`@("`@("`@("`@(&EF("@D:2`]/2`U('Q\("1I(#T]
M(#$Q*2!["B`@("`@("`@("`@("`@("`D8VEP:&5R6S1=("T]("1T:&ES+3Y?
M:V5Y4V-H961U;&5;)&-I<&AE<ELS72`F(#!X,T9=.PH@("`@("`@("`@("`@
M("`@)&-I<&AE<ELS72`M/2`D=&AI<RT^7VME>5-C:&5D=6QE6R1C:7!H97);
M,ET@)B`P>#-&73L*("`@("`@("`@("`@("`@("1C:7!H97);,ET@+3T@)'1H
M:7,M/E]K97E38VAE9'5L95LD8VEP:&5R6S%=("8@,'@S1ET["B`@("`@("`@
M("`@("`@("`D8VEP:&5R6S%=("T]("1T:&ES+3Y?:V5Y4V-H961U;&5;)&-I
M<&AE<ELT72`F(#!X,T9=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@<&%C:R@B=BHB+"`D8VEP:&5R6S%=+"`D8VEP:&5R6S)=
M+"`D8VEP:&5R6S-=+"`D8VEP:&5R6S1=*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O<F,T+G!H<```````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T-#``,3`T,3<S-C(W
M-S$`,#(P-C0U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@0VEP:&5R7W)C-#HZ(&-L87-S(&EM
M<&QE;65N=',@=&AE($-I<&AE<B!I;G1E<F9A8V4@96YC<GEP=&EO;B!D871A
M"B`J('5S:6YG('1H92!20S0@96YC<GEP=&EO;B!A;&=O<G1H:6TN(%1H:7,@
M8VQA<W,@=7-E<R!T:&4@4$5!4B!#<GEP=%]20S0*("H@8VQA<W,@=&\@9&\@
M=&AE(&5N8W)Y<'1I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE
M<B]#:7!H97(O<F,T+G!H<"QV(#$N-"XQ,BXW(#(P,#8O,#$O,#$@,C$Z,C@Z
M,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(
M;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]R8S0@97AT96YD
M<R!(;W)D95]#:7!H97(@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!A
M(%!%05(@0W)Y<'1?<F,T(&]B:F5C=`H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?8VEP:&5R(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7T-I<&AE<E]R8S0H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@
M<F5Q=6ER95]O;F-E("=#<GEP="]28S0N<&AP)SL*("`@("`@("`D=&AI<RT^
M7V-I<&AE<B`]("9N97<@0W)Y<'1?4F,T*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE(&ME>2!T;R!B92!U<V5D(&9O<B!E;B]D96-R>7!T:6]N
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@5&AE(&ME>2!T
M;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ME>2@D:V5Y*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?8VEP:&5R+3YK97DH)&ME>2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-I>F4@;V8@=&AE(&)L;V-K<R!T
M:&%T('1H:7,@8VEP:&5R(&YE961S+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!C:&%R86-T97)S('!E<B!B;&]C:RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO8VM3:7IE*"D*("`@('L*("`@
M("`@("!R971U<FX@.#L*("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@
M82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&)L;V-K("!4:&4@9&%T82!T;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@96YC<GEP=&5D(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@96YC<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@
M("`@("1T:&ES+3YS971+97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("`O
M+R!-86ME(&$@8V]P>2!O9B!T:&4@8VEP:&5R(&%S(&ET(&1E<W1R;WES(&ET
M<V5L9B!D=7)I;F<@82!C<GEP=`H@("`@("`@("1C:7!H97(@/2`D=&AI<RT^
M7V-I<&AE<CL*("`@("`@("`D8VEP:&5R+3YC<GEP="@D8FQO8VLI.PH*("`@
M("`@("!R971U<FX@)&)L;V-K.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C
M<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8FQO8VL@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1K97D@("`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@;W5T<'5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96-R>7!T0FQO8VLH)&)L;V-K+"`D:V5Y(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@
M("`@("\O($UA:V4@82!C;W!Y(&]F('1H92!C:7!H97(@87,@:70@9&5S=')O
M>7,@:71S96QF(&1U<FEN9R!A"B`@("`@("`@+R\@8W)Y<'0N"B`@("`@("`@
M)&-I<&AE<B`]("1T:&ES+3Y?8VEP:&5R.PH@("`@("`@("1C:7!H97(M/F1E
M8W)Y<'0H)&)L;V-K*3L*"B`@("`@("`@<F5T=7)N("1B;&]C:SL*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O
M9&5S+G!H<```````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C<R
M,#(`,3`T,3<S-C(W-S$`,#(P-S,Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@0VEP:&5R7V1E
M<SHZ(&-L87-S(&EM<&QE;65N=',@=&AE($-I<&AE<B!I;G1E<F9A8V4@96YC
M<GEP=&EO;B!D871A"B`J('5S:6YG('1H92!$871A($5N8W)Y<'1I;VX@4W1A
M;F1A<F0@*$1%4RD@86QG;W)I=&AM(&%S(&1E9FEN92!I;B!&25!3-#8M,RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0VEP:&5R+T-I<&AE<B]D97,N<&AP
M+'8@,2XT+C$R+C<@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@*B\*
M8VQA<W,@2&]R9&5?0VEP:&5R7V1E<R!E>'1E;F1S($AO<F1E7T-I<&AE<B![
M"@H@("`@+RHJ"B`@("`@*B!);FET:6%L(%!E<FUU=&%T:6]N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&EP(#T@87)R87DH
M"B`@("`@("`@-3@L(#4P+"`T,BP@,S0L(#(V+"`Q."P@,3`L("`R+`H@("`@
M("`@(#8P+"`U,BP@-#0L(#,V+"`R."P@,C`L(#$R+"`@-"P*("`@("`@("`V
M,BP@-30L(#0V+"`S."P@,S`L(#(R+"`Q-"P@(#8L"B`@("`@("`@-C0L(#4V
M+"`T."P@-#`L(#,R+"`R-"P@,38L("`X+`H@("`@("`@(#4W+"`T.2P@-#$L
M(#,S+"`R-2P@,3<L("`Y+"`@,2P*("`@("`@("`U.2P@-3$L(#0S+"`S-2P@
M,C<L(#$Y+"`Q,2P@(#,L"B`@("`@("`@-C$L(#4S+"`T-2P@,S<L(#(Y+"`R
M,2P@,3,L("`U+`H@("`@("`@(#8S+"`U-2P@-#<L(#,Y+"`S,2P@,C,L(#$U
M+"`@-PH@("`@*3L*"B`@("`O*BH*("`@("`J($9I;F%L(%!E<FUU=&%T:6]N
M($E07BTQ"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)&9P(#T@87)R87DH"B`@("`@("`@-#`L("`X+"`T."P@,38L(#4V+"`R
M-"P@-C0L(#,R+`H@("`@("`@(#,Y+"`@-RP@-#<L(#$U+"`U-2P@,C,L(#8S
M+"`S,2P*("`@("`@("`S."P@(#8L(#0V+"`Q-"P@-30L(#(R+"`V,BP@,S`L
M"B`@("`@("`@,S<L("`U+"`T-2P@,3,L(#4S+"`R,2P@-C$L(#(Y+`H@("`@
M("`@(#,V+"`@-"P@-#0L(#$R+"`U,BP@,C`L(#8P+"`R."P*("`@("`@("`S
M-2P@(#,L(#0S+"`Q,2P@-3$L(#$Y+"`U.2P@,C<L"B`@("`@("`@,S0L("`R
M+"`T,BP@,3`L(#4P+"`Q."P@-3@L(#(V+`H@("`@("`@(#,S+"`@,2P@-#$L
M("`Y+"`T.2P@,3<L(#4W+"`R-0H@("`@*3L*"B`@("`O*BH*("`@("`J($4@
M0FET(%-E;&5C=&EO;B!486)L90H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1E(#T@87)R87DH"B`@("`@("`@,S(L("`Q+"`@
M,BP@(#,L("`T+"`@-2P*("`@("`@("`@-"P@(#4L("`V+"`@-RP@(#@L("`Y
M+`H@("`@("`@("`X+"`@.2P@,3`L(#$Q+"`Q,BP@,3,L"B`@("`@("`@,3(L
M(#$S+"`Q-"P@,34L(#$V+"`Q-RP*("`@("`@("`Q-BP@,3<L(#$X+"`Q.2P@
M,C`L(#(Q+`H@("`@("`@(#(P+"`R,2P@,C(L(#(S+"`R-"P@,C4L"B`@("`@
M("`@,C0L(#(U+"`R-BP@,C<L(#(X+"`R.2P*("`@("`@("`R."P@,CDL(#,P
M+"`S,2P@,S(L("`Q"B`@("`I.PH*("`@("\J*@H@("`@("H@4R!B;WAE<PH@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<R`]
M(&%R<F%Y*`H@("`@("`@("\J(%,Q("HO"B`@("`@("`@,2`]/B!A<G)A>2@*
M("`@("`@("`@("`Q-"P@(#0L(#$S+"`@,2P@(#(L(#$U+"`Q,2P@(#@L("`S
M+"`Q,"P@(#8L(#$R+"`@-2P@(#DL("`P+"`@-RP*("`@("`@("`@("`@,"P@
M,34L("`W+"`@-"P@,30L("`R+"`Q,RP@(#$L(#$P+"`@-BP@,3(L(#$Q+"`@
M.2P@(#4L("`S+"`@."P*("`@("`@("`@("`@-"P@(#$L(#$T+"`@."P@,3,L
M("`V+"`@,BP@,3$L(#$U+"`Q,BP@(#DL("`W+"`@,RP@,3`L("`U+"`@,"P*
M("`@("`@("`@("`Q-2P@,3(L("`X+"`@,BP@(#0L("`Y+"`@,2P@(#<L("`U
M+"`Q,2P@(#,L(#$T+"`Q,"P@(#`L("`V+"`Q,PH@("`@("`@("DL"@H@("`@
M("`@("\J(%,R("HO"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`Q
M-2P@(#$L("`X+"`Q-"P@(#8L(#$Q+"`@,RP@(#0L("`Y+"`@-RP@(#(L(#$S
M+"`Q,BP@(#`L("`U+"`Q,"P*("`@("`@("`@("`@,RP@,3,L("`T+"`@-RP@
M,34L("`R+"`@."P@,30L(#$R+"`@,"P@(#$L(#$P+"`@-BP@(#DL(#$Q+"`@
M-2P*("`@("`@("`@("`@,"P@,30L("`W+"`Q,2P@,3`L("`T+"`Q,RP@(#$L
M("`U+"`@."P@,3(L("`V+"`@.2P@(#,L("`R+"`Q-2P*("`@("`@("`@("`Q
M,RP@(#@L(#$P+"`@,2P@(#,L(#$U+"`@-"P@(#(L(#$Q+"`@-BP@(#<L(#$R
M+"`@,"P@(#4L(#$T+"`@.2P*("`@("`@("`I+`H*("`@("`@("`O*B!3,R`J
M+PH@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@,3`L("`P+"`@.2P@
M,30L("`V+"`@,RP@,34L("`U+"`@,2P@,3,L(#$R+"`@-RP@,3$L("`T+"`@
M,BP@(#@L"B`@("`@("`@("`@,3,L("`W+"`@,"P@(#DL("`S+"`@-"P@(#8L
M(#$P+"`@,BP@(#@L("`U+"`Q-"P@,3(L(#$Q+"`Q-2P@(#$L"B`@("`@("`@
M("`@,3,L("`V+"`@-"P@(#DL("`X+"`Q-2P@(#,L("`P+"`Q,2P@(#$L("`R
M+"`Q,BP@(#4L(#$P+"`Q-"P@(#<L"B`@("`@("`@("`@(#$L(#$P+"`Q,RP@
M(#`L("`V+"`@.2P@(#@L("`W+"`@-"P@,34L(#$T+"`@,RP@,3$L("`U+"`@
M,BP@,3(L"B`@("`@("`@*2P*"B`@("`@("`@+RH@4S0@*B\*("`@("`@("`T
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`W+"`Q,RP@,30L("`S+"`@,"P@(#8L
M("`Y+"`Q,"P@(#$L("`R+"`@."P@(#4L(#$Q+"`Q,BP@(#0L(#$U+`H@("`@
M("`@("`@(#$S+"`@."P@,3$L("`U+"`@-BP@,34L("`P+"`@,RP@(#0L("`W
M+"`@,BP@,3(L("`Q+"`Q,"P@,30L("`Y+`H@("`@("`@("`@(#$P+"`@-BP@
M(#DL("`P+"`Q,BP@,3$L("`W+"`Q,RP@,34L("`Q+"`@,RP@,30L("`U+"`@
M,BP@(#@L("`T+`H@("`@("`@("`@("`S+"`Q-2P@(#`L("`V+"`Q,"P@(#$L
M(#$S+"`@."P@(#DL("`T+"`@-2P@,3$L(#$R+"`@-RP@(#(L(#$T+`H@("`@
M("`@("DL"@H@("`@("`@("\J(%,U("HO"B`@("`@("`@-2`]/B!A<G)A>2@*
M("`@("`@("`@("`@,BP@,3(L("`T+"`@,2P@(#<L(#$P+"`Q,2P@(#8L("`X
M+"`@-2P@(#,L(#$U+"`Q,RP@(#`L(#$T+"`@.2P*("`@("`@("`@("`Q-"P@
M,3$L("`R+"`Q,BP@(#0L("`W+"`Q,RP@(#$L("`U+"`@,"P@,34L(#$P+"`@
M,RP@(#DL("`X+"`@-BP*("`@("`@("`@("`@-"P@(#(L("`Q+"`Q,2P@,3`L
M(#$S+"`@-RP@(#@L(#$U+"`@.2P@,3(L("`U+"`@-BP@(#,L("`P+"`Q-"P*
M("`@("`@("`@("`Q,2P@(#@L(#$R+"`@-RP@(#$L(#$T+"`@,BP@,3,L("`V
M+"`Q-2P@(#`L("`Y+"`Q,"P@(#0L("`U+"`@,RP*("`@("`@("`I+`H*("`@
M("`@("`O*B!3-B`J+PH@("`@("`@(#8@/3X@87)R87DH"B`@("`@("`@("`@
M,3(L("`Q+"`Q,"P@,34L("`Y+"`@,BP@(#8L("`X+"`@,"P@,3,L("`S+"`@
M-"P@,30L("`W+"`@-2P@,3$L"B`@("`@("`@("`@,3`L(#$U+"`@-"P@(#(L
M("`W+"`Q,BP@(#DL("`U+"`@-BP@(#$L(#$S+"`Q-"P@(#`L(#$Q+"`@,RP@
M(#@L"B`@("`@("`@("`@(#DL(#$T+"`Q-2P@(#4L("`R+"`@."P@,3(L("`S
M+"`@-RP@(#`L("`T+"`Q,"P@(#$L(#$S+"`Q,2P@(#8L"B`@("`@("`@("`@
M(#0L("`S+"`@,BP@,3(L("`Y+"`@-2P@,34L(#$P+"`Q,2P@,30L("`Q+"`@
M-RP@(#8L("`P+"`@."P@,3,L"B`@("`@("`@*2P*"B`@("`@("`@+RH@4S<@
M*B\*("`@("`@("`W(#T^(&%R<F%Y*`H@("`@("`@("`@("`T+"`Q,2P@(#(L
M(#$T+"`Q-2P@(#`L("`X+"`Q,RP@(#,L(#$R+"`@.2P@(#<L("`U+"`Q,"P@
M(#8L("`Q+`H@("`@("`@("`@(#$S+"`@,"P@,3$L("`W+"`@-"P@(#DL("`Q
M+"`Q,"P@,30L("`S+"`@-2P@,3(L("`R+"`Q-2P@(#@L("`V+`H@("`@("`@
M("`@("`Q+"`@-"P@,3$L(#$S+"`Q,BP@(#,L("`W+"`Q-"P@,3`L(#$U+"`@
M-BP@(#@L("`P+"`@-2P@(#DL("`R+`H@("`@("`@("`@("`V+"`Q,2P@,3,L
M("`X+"`@,2P@(#0L(#$P+"`@-RP@(#DL("`U+"`@,"P@,34L(#$T+"`@,BP@
M(#,L(#$R+`H@("`@("`@("DL"@H@("`@("`@("\J(%,X("HO"B`@("`@("`@
M."`]/B!A<G)A>2@*("`@("`@("`@("`@,3,L("`R+"`@."P@(#0L("`V+"`Q
M-2P@,3$L("`Q+"`Q,"P@(#DL("`S+"`Q-"P@(#4L("`P+"`Q,BP@(#<L"B`@
M("`@("`@("`@("`Q+"`Q-2P@,3,L("`X+"`Q,"P@(#,L("`W+"`@-"P@,3(L
M("`U+"`@-BP@,3$L("`P+"`Q-"P@(#DL("`R+`H@("`@("`@("`@("`@-RP@
M,3$L("`T+"`@,2P@(#DL(#$R+"`Q-"P@(#(L("`P+"`@-BP@,3`L(#$S+"`Q
M-2P@(#,L("`U+"`@."P*("`@("`@("`@("`@(#(L("`Q+"`Q-"P@(#<L("`T
M+"`Q,"P@(#@L(#$S+"`Q-2P@,3(L("`Y+"`@,"P@(#,L("`U+"`@-BP@,3$*
M("`@("`@("`I"B`@("`I.PH*("`@("\J*@H@("`@("H@4')I;6ET:79E(&9U
M;F-T:6]N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)'`@/2!A<G)A>2@*("`@("`@("`Q-BP@(#<L(#(P+"`R,2P*("`@("`@
M("`R.2P@,3(L(#(X+"`Q-RP*("`@("`@("`@,2P@,34L(#(S+"`R-BP*("`@
M("`@("`@-2P@,3@L(#,Q+"`Q,"P*("`@("`@("`@,BP@(#@L(#(T+"`Q-"P*
M("`@("`@("`S,BP@,C<L("`S+"`@.2P*("`@("`@("`Q.2P@,3,L(#,P+"`@
M-BP*("`@("`@("`R,BP@,3$L("`T+"`R-0H@("`@*3L*"B`@("`O*BH*("`@
M("`J(%!E<FUU=&5D($-H;VEC92!486)L90H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1P8S$@/2!A<G)A>2@*("`@("`@("`U
M-RP@-#DL(#0Q+"`S,RP@,C4L(#$W+"`@.2P*("`@("`@("`@,2P@-3@L(#4P
M+"`T,BP@,S0L(#(V+"`Q."P*("`@("`@("`Q,"P@(#(L(#4Y+"`U,2P@-#,L
M(#,U+"`R-RP*("`@("`@("`Q.2P@,3$L("`S+"`V,"P@-3(L(#0T+"`S-BP*
M"B`@("`@("`@-C,L(#4U+"`T-RP@,SDL(#,Q+"`R,RP@,34L"B`@("`@("`@
M(#<L(#8R+"`U-"P@-#8L(#,X+"`S,"P@,C(L"B`@("`@("`@,30L("`V+"`V
M,2P@-3,L(#0U+"`S-RP@,CDL"B`@("`@("`@,C$L(#$S+"`@-2P@,C@L(#(P
M+"`Q,BP@(#0*("`@("D["@H@("`@+RHJ"B`@("`@*B!.=6UB97(@;&5F="!R
M;W1A=&EO;G,@;V8@<&,Q"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)'-H:69T<R`](&%R<F%Y*`H@("`@("`@(#$L(#$L(#(L
M(#(L(#(L(#(L(#(L(#(L"B`@("`@("`@,2P@,BP@,BP@,BP@,BP@,BP@,BP@
M,0H@("`@*3L*"B`@("`O*BH*("`@("`J(%!E<FUU=&5D($-H;VEC92!486)L
M92`R"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)'!C,B`](&%R<F%Y*`H@("`@("`@(#$T+"`Q-RP@,3$L(#(T+"`@,2P@(#4L
M"B`@("`@("`@(#,L(#(X+"`Q-2P@(#8L(#(Q+"`Q,"P*("`@("`@("`R,RP@
M,3DL(#$R+"`@-"P@,C8L("`X+`H@("`@("`@(#$V+"`@-RP@,C<L(#(P+"`Q
M,RP@(#(L"B`@("`@("`@-#$L(#4R+"`S,2P@,S<L(#0W+"`U-2P*("`@("`@
M("`S,"P@-#`L(#4Q+"`T-2P@,S,L(#0X+`H@("`@("`@(#0T+"`T.2P@,SDL
M(#4V+"`S-"P@-3,L"B`@("`@("`@-#8L(#0R+"`U,"P@,S8L(#(Y+"`S,@H@
M("`@*3L*"B`@("`O*BH*("`@("`J($ME>2!38VAE9'5L90H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?2W,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@4V5T('1H92!K97D@=&\@8F4@=7-E9"!F;W(@
M96XO9&5C<GEP=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K
M97D@(%1H92!K97D@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971+
M97DH)&ME>2D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]+<R`]("1T:&ES+3Y?:V5Y4V-H961U;&4H
M)&ME>2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!S:7IE(&]F('1H92!B;&]C:W,@=&AA="!T:&ES(&-I<&AE<B!N965D
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@
M;V8@8VAA<F%C=&5R<R!P97(@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$)L;V-K4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N(#@["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@5&AE(&1A=&$@=&\@
M96YC<GEP="X*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("!4:&4@:V5Y
M('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N
M8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'1"
M;&]C:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^7TMS(#T@)'1H
M:7,M/E]K97E38VAE9'5L92@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@("1B
M;&]C:R`]("1T:&ES+3Y?:6YI=&EA;%!E<FTH)&)L;V-K*3L*"B`@("`@("`@
M)$P@/2!S=6)S='(H)&)L;V-K+"`P+"`T*3L*("`@("`@("`D4B`]('-U8G-T
M<B@D8FQO8VLL(#0L(#0I.PH*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/#T@
M,38[("1I*RL@*2!["B`@("`@("`@("`@("127W!R978@/2`D4CL*("`@("`@
M("`@("`@)$Q?<')E=B`]("1,.PH*("`@("`@("`@("`@)$P@/2`D4CL*("`@
M("`@("`@("`@)%(@/2`D3%]P<F5V(%X@)'1H:7,M/E]F*"127W!R978L("1I
M*3L*("`@("`@("!]"@H@("`@("`@("1B;&]C:R`]("12("X@)$P["B`@("`@
M("`@)&)L;V-K(#T@)'1H:7,M/E]F:6YA;%!E<FTH)&)L;V-K*3L*"B`@("`@
M("`@<F5T=7)N("1B;&]C:SL*("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y
M<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&)L;V-K("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP=&5D(&]U='!U="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9&5C<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU
M;&PI"B`@("!["B`@("`@("`@)&)L;V-K(#T@)'1H:7,M/E]I;FET:6%L4&5R
M;2@D8FQO8VLI.PH*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]+<R`]("1T:&ES+3Y?:V5Y4V-H961U;&4H)&ME
M>2D["B`@("`@("`@?0H*("`@("`@("`D3"`]('-U8G-T<B@D8FQO8VLL(#`L
M(#0I.PH@("`@("`@("12(#T@<W5B<W1R*"1B;&]C:RP@-"P@-"D["@H@("`@
M("`@(&9O<B`H)&D@/2`Q-CL@)&D@/CT@,3L@)&DM+2`I('L*("`@("`@("`@
M("`@)%)?<')E=B`]("12.PH@("`@("`@("`@("`D3%]P<F5V(#T@)$P["@H@
M("`@("`@("`@("`D3"`]("127W!R978["B`@("`@("`@("`@("12(#T@)$Q?
M<')E=B!>("1T:&ES+3Y?9B@D4E]P<F5V+"`D:2D["B`@("`@("`@?0H*("`@
M("`@("`D8FQO8VL@/2`D4B`N("1,.PH@("`@("`@("1B;&]C:R`]("1T:&ES
M+3Y?9FEN86Q097)M*"1B;&]C:RD["@H@("`@("`@(')E='5R;B`D8FQO8VL[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0=70@86X@:6YP=70@<W1R:6YG('1H
M<F]U9V@@86X@:6YI=&EA;"!P97)M=71A=&EO;@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&EN<'5T("!);G!U="!S=')I;F<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%!E<FUU=&%T960@<W1R:6YG+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?:6YI=&EA;%!E<FTH)&EN<'5T*0H@("`@>PH@("`@
M("`@("\O(%1/1$\Z(%-O;64@<W1Y;&EE(&)I='=I<V4@=&AI;F<@:6YS=&5A
M9"X*"B`@("`@("`@)&EN<'5T7V)I;B`]("<G.PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(#@[("1I*RLI('L*("`@("`@("`@("`@)&EN<'5T7V)I;B`N
M/2!S=')?<&%D*&1E8V)I;BAO<F0H)&EN<'5T6R1I72DI+"`X+"`G,"<L(%-4
M4E]0041?3$5&5"D["B`@("`@("`@?0H*("`@("`@("`D;W5T<'5T7V)I;B`]
M("<G.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YI<"!A<R`D;V9F<V5T*2![
M"B`@("`@("`@("`@("1O=71P=71?8FEN("X]("1I;G!U=%]B:6Y;)&]F9G-E
M="`M(#%=.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U="`]("<G.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[("1I*RLI('L*("`@("`@("`@("`@
M)&]U='!U="`N/2!C:'(H8FEN9&5C*'-U8G-T<B@D;W5T<'5T7V)I;BP@."`J
M("1I+"`X*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0=70@86X@:6YP=70@<W1R:6YG('1H
M<F]U9V@@82!F:6YA;"!P97)M=71A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I;G!U="`@26YP=70@<W1R:6YG+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!097)M=71A=&5D('-T<FEN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V9I;F%L4&5R;2@D:6YP=70I"B`@("!["B`@("`@("`@
M+R\@5$]$3SH@4V]M92!S='EL:64@8FET=VES92!T:&EN9R!I;G-T96%D+@H@
M("`@("`@("1I;G!U=%]B:6X@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@("1I;G!U=%]B:6X@+CT@<W1R
M7W!A9"AD96-B:6XH;W)D*"1I;G!U=%LD:5TI*2P@."P@)S`G+"!35%)?4$%$
M7TQ%1E0I.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U=%]B:6X@/2`G)SL*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^9G`@87,@)&]F9G-E="D@>PH@("`@
M("`@("`@("`D;W5T<'5T7V)I;B`N/2`D:6YP=71?8FEN6R1O9F9S970@+2`Q
M73L*("`@("`@("!]"@H@("`@("`@("1O=71P=70@/2`G)SL*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@("1O=71P
M=70@+CT@8VAR*&)I;F1E8RAS=6)S='(H)&]U='!U=%]B:6XL(#@@*B`D:2P@
M."DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@
M?0H*"B`@("`O*BH*("`@("`J(&8H*2!4:&4@<&5R;75T871I;VX@9G5N8W1I
M;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@($EN<'5T
M('-T<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W5N9"`@5&AE(')O
M=6YD+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;W5T<'5T
M('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V8H)&EN<'5T+"`D<F]U
M;F0I"B`@("!["B`@("`@("`@+R\@5$]$3SH@4V]M92!S='EL:64@8FET=VES
M92!T:&EN9R!I;G-T96%D+@H@("`@("`@("1K97D@/2`D=&AI<RT^7TMS6R1R
M;W5N9%T["@H@("`@("`@("1I;G!U=%]B:6X@/2`G)SL*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`T.R`D:2LK*2!["B`@("`@("`@("`@("1I;G!U=%]B
M:6X@+CT@<W1R7W!A9"AD96-B:6XH;W)D*"1I;G!U=%LD:5TI*2P@."P@)S`G
M+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T*"B`@("`@("`@)&5X<&%N9&5D
M7V)I;B`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YE(&%S("1O9F9S
M970I('L*("`@("`@("`@("`@)&5X<&%N9&5D7V)I;B`N/2`D:6YP=71?8FEN
M6R1O9F9S970@+2`Q73L*("`@("`@("!]"@H@("`@("`@("1E>'!A;F1E9"`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@.#L@)&DK*RD@
M>PH@("`@("`@("`@("`D97AP86YD961;)&E=(#T@8FEN9&5C*"<P,"<@+B!S
M=6)S='(H)&5X<&%N9&5D7V)I;BP@)&D@*B`V+"`V*2D@7B`D:V5Y6R1I73L*
M("`@("`@("!]"@H@("`@("`@("1C;VUB:6YE9%]B:6X@/2`G)SL*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@("1S
M7VEN9&5X(#T@*"@D97AP86YD961;)&E=("8@,'@R,"D@/CX@-"D@?"`H)&5X
M<&%N9&5D6R1I72`F(#!X,#$I.PH@("`@("`@("`@("`D<U]I;F1E>"`](#$V
M("H@)'-?:6YD97@@*R`H*"1E>'!A;F1E9%LD:5T@)B`P>#%%*2`^/B`Q*3L*
M("`@("`@("`@("`@)'9A;"`]("1T:&ES+3Y?<ULD:2`K(#%=6R1S7VEN9&5X
M73L*("`@("`@("`@("`@)&-O;6)I;F5D7V)I;B`N/2!S=')?<&%D*&1E8V)I
M;B@D=F%L*2P@-"P@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T*"B`@
M("`@("`@)&]U='!U=%]B:6X@/2`G)SL*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^<"!A<R`D;V9F<V5T*2!["B`@("`@("`@("`@("1O=71P=71?8FEN("X]
M("1C;VUB:6YE9%]B:6Y;)&]F9G-E="`M(#%=.PH@("`@("`@('T*"B`@("`@
M("`@)&]U='!U="`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#0[
M("1I*RLI('L*("`@("`@("`@("`@)&]U='!U="`N/2!C:'(H8FEN9&5C*'-U
M8G-T<B@D;W5T<'5T7V)I;BP@)&D@*B`X+"`X*2DI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&4@=&AE(&-O;7!L971E(&ME>2!S:&5D=6QE+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2!+97D@<V-H961U;&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]K97E38VAE9'5L92@D:V5Y*0H@("`@>PH@("`@("`@("1K
M97D@/2!S=')?<&%D*"1K97DL(#@L(")<,"(I.PH@("`@("`@("1K<R`](&%R
M<F%Y*"D["@H@("`@("`@("1K97E?8FEN(#T@)R<["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@.#L@)&DK*RD@>PH@("`@("`@("`@("`D:V5Y7V)I;B`N
M/2!S=')?<&%D*&1E8V)I;BAO<F0H)&ME>5LD:5TI*2P@."P@)S`G+"!35%)?
M4$%$7TQ%1E0I.PH@("`@("`@('T*"B`@("`@("`@)&,@/2`G)SL*("`@("`@
M("`D9"`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#(X.R`D:2LK
M*2!["B`@("`@("`@("`@("1C("X]("1K97E?8FEN6R1T:&ES+3YP8S%;)&E=
M("T@,5T["B`@("`@("`@("`@("1D("X]("1K97E?8FEN6R1T:&ES+3YP8S%;
M,C@@*R`D:5T@+2`Q73L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(#$V.R`D:2LK*2!["B`@("`@("`@("`@("1C(#T@<W5B<W1R*"1C
M+"`D=&AI<RT^<VAI9G1S6R1I72D@+B!S=6)S='(H)&,L(#`L("1T:&ES+3YS
M:&EF='-;)&E=*3L*("`@("`@("`@("`@)&0@/2!S=6)S='(H)&0L("1T:&ES
M+3YS:&EF='-;)&E=*2`N('-U8G-T<B@D9"P@,"P@)'1H:7,M/G-H:69T<ULD
M:5TI.PH*("`@("`@("`@("`@)&-D(#T@)&,@+B`D9#L*"B`@("`@("`@("`@
M("1P97)M=71A=&5D7V)I;B`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^<&,R(&%S("1O9F9S970I('L*("`@("`@("`@("`@("`@("1P97)M
M=71A=&5D7V)I;B`N/2`D8V1;)&]F9G-E="`M(#%=.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"`X.R`D:BLK*2!["B`@
M("`@("`@("`@("`@("`D:W-;)&D@*R`Q75M=(#T@8FEN9&5C*"<P,"<@+B!S
M=6)S='(H)'!E<FUU=&%T961?8FEN+"`D:B`J(#8L(#8I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1K<SL*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4N<&AP````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S8R,@`Q,#0Q-S,V,C<W,0`P,C(P,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E.CH@8VQA<W,@<')O
M=FED97,@82!C;VUM;VX@86)S=')A8W1E9`H@*B!I;G1E<F9A8V4@=&\@=F%R
M:6]U<R!B;&]C:R!M;V1E(&AA;F1L97)S(&9O<B!C:7!H97)S+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+T)L;V-K36]D92YP:'`L
M=B`Q+C$T+C$R+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I
M;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@*B\*
M8VQA<W,@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@:6YI=&EA;&EZ871I;VX@=F5C=&]R+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEV(#T@(EPP7#!<,%PP7#!<
M,%PP7#`B.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M8V]N8W)E=&4@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!I;G-T86YC92!B87-E
M9"!O;@H@("`@("H@)&UO9&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;6]D92`@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T-I<&AE<E]"
M;&]C:TUO9&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S
M<R!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@;6EG:'0@;F5E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T-I<&AE<E]";&]C:TUO
M9&4@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($-I<&AE<D)L;V-K36]D92!I;G-T
M86YC92P@;W(@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F9A8W1O<GDH)&UO9&4L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@
M("1M;V1E(#T@8F%S96YA;64H)&UO9&4I.PH@("`@("`@(&EF("A`9FEL95]E
M>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+T)L;V-K36]D92\G("X@)&UO
M9&4@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O0FQO8VM-;V1E+R<@+B`D;6]D92`N("<N<&AP
M)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]#:7!H97)?
M0FQO8VM-;V1E7R<@+B`D;6]D93L*("`@("`@("!I9B`H8VQA<W-?97AI<W1S
M*"1C;&%S<RDI('L*("`@("`@("`@("`@)&)L;V-K;6]D92`]("9N97<@)&-L
M87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1B
M;&]C:VUO9&4@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N
M(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D8FQO8VMM;V1E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T('1H92!)5@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EV
M("!4:&4@;F5W($E6+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971)5B@D:78I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]I=B`]("1I=CL*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92])34%0+P``````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S,`,#$V-S8S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O04-,+P``````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W
M,P`P,3<S-C(`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'``````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#,W-C$Q`#$P-#$W,S8R-S<S`#`R,3$W,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@0V]N=&%I;G,@
M9G5N8W1I;VYS(')E;&%T960@=&\@;6%N86=I;F<@06-C97-S($-O;G1R;VP@
M3&ES=',@;VX@86X@24U!4`H@*B!S97)V97(@=7-I;F<@4D9#(#(P.#8N"B`J
M"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G=7-E<FYA;64G
M("!4:&4@=7-E<FYA;64@9F]R('1H92!S97)V97(@8V]N;F5C=&EO;@H@*B`@
M("=P87-S=V]R9"<@(%1H92!P87-S=V]R9"!F;W(@=&AE('-E<G9E<B!C;VYN
M96-T:6]N"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]R($E0(&%D
M9')E<W,@;V8@=&AE('-E<G9E<BX*("H@("`@("`@("`@("`@("!$149!54Q4
M.B`G;&]C86QH;W-T)PH@*B`@("=P;W)T)R`@("`@(%1H92!S97)V97(@<&]R
M="!T;R!W:&EC:"!W92!W:6QL(&-O;FYE8W0N"B`J("`@("`@("`@("`@("`@
M24U!4"!I<R!G96YE<F%L;'D@,30S+"!W:&EL92!)34%0+5-33"!I<R!G96YE
M<F%L;'D@.3DS+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z(#$T,PH@*B`@
M("=P<F]T;V-O;"<@(%1H92!C;VYN96-T:6]N('!R;W1O8V]L("AE+F<N("=I
M;6%P)RP@)W!O<#,G+"`G;FYT<"<I+@H@*B`@("`@("`@("`@("`@(%!R;W1O
M8V]L(&ES(&]N92!O9B`G:6UA<"]N;W1L<R<@*&]R(&]N;'D@)VEM87`G(&EF
M('EO=0H@*B`@("`@("`@("`@("`@(&AA=F4@82!C+6-L:65N="!V97)S:6]N
M(#(P,#!C(&]R(&]L9&5R*2P@)VEM87`O<W-L)RP@;W(*("H@("`@("`@("`@
M("`@("`G:6UA<"]S<VPO;F]V86QI9&%T92UC97)T)R`H9F]R(&$@<V5L9BUS
M:6=N960@8V5R=&EF:6-A=&4I+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z
M("=I;6%P)SPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP+'8@,2XV+C@N.2`R,#`V+S`R+S`S(#`S.C`W
M.C4X('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-H
M<FES($AA<W1I92`\:6UP0&]A:RUW;V]D+F-O+G5K/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAR:7,@2&%S=&EE(#QI;7!`;V%K+7=O;V0N8V\N
M=6L^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95])
M34%0"B`J+PIC;&%S<R!)34%07T%#3%]R9F,R,#@V(&5X=&5N9',@24U!4%]!
M0TP@>PH*("`@("\J*@H@("`@("H@24U!4"!R97-O=7)C92X*("`@("`J"B`@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7VEM87`["@H@
M("`@+RHJ"B`@("`@*B!,:7-T(&]F('-E<G9E<B=S(&-A<&%B:6QI=&EE<RP@
M;W5T<'5T(&]F($-!4$%"24Q)5%D@8V]M;6%N9"X@1F]R;6%T960*("`@("`J
M(&%S(&$@:&%S:`H@("`@("H@/&-O9&4^"B`@("`@*B!A<G)A>2@*("`@("`J
M("`@("`J8V%P86)I;&ET>2H@/3X@,0H@("`@("H@*0H@("`@("H@/"]C;V1E
M/@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M8V%P<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY(&%D9&ET
M:6]N86P@<&%R86UE=&5R<R!T:&ES(&1R:79E<B!M87D@;F5E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@24U!4%]!0TQ?<F9C,C`X-B@D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`](&%R<F%Y7VUE
M<F=E*&%R<F%Y*"=H;W-T<W!E8R<@/3X@)VQO8V%L:&]S="<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&]R="<@/3X@
M,30S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W!R;W1O8V]L)R`]/B`G:6UA<"<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["@H@("`@("`@("1T:&ES+3Y?
M8V%P<R`]("1T:&ES+3Y?9V5T0V%P86)I;&ET>2@I.PH@("`@("`@(&EF("AI
M<U]A*"1T:&ES+3Y?8V%P<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V5R<F]R(#T@)'1H:7,M/E]C87!S.PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H<W5B<W1R*"1T:&ES+3Y?
M<&%R86US6R=P<F]T;V-O;"==+"`P+"`T*2`A/2`G:6UA<"<I('L*("`@("`@
M("`@("`@+RH@3F\@<&]I;G0@:6X@9V]I;F<@86YY(&9U<G1H97(@:68@:70G
M<R!N;W0@86X@24U!4"!S97)V97(N("HO"B`@("`@("`@("`@("1T:&ES+3Y?
M97)R;W(@/2!014%2.CIR86ES945R<F]R*%\H(D]N;'D@24U!4"!S97)V97)S
M('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(BDI.PH@("`@("`@("`@("`D=&AI
M<RT^7W-U<'!O<G1E9"`](&9A;'-E.PH@("`@("`@('T@96QS96EF("@A:7-S
M970H)'1H:7,M/E]C87!S6R=A8VPG72DI('L*("`@("`@("`@("`@+RH@268@
M=V4@8V]U;&1N)W0@9V5T('1H92!S97)V97(G<R!C87!A8FEL:71Y+"!W92=L
M;"!A<W-U;64@04-,(&ES"B`@("`@("`@("`@("`@(&YO="!S=7!P;W)T960@
M9F]R(&YO=RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]S=7!P;W)T960@/2!F
M86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-U
M<'!O<G1E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!R
M;W1E8W1E9"`](&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*3L*
M"B`@("`@("`@)'1H:7,M/E]R:6=H='-,:7-T(#T@87)R87DH"B`@("`@("`@
M("`@("`G;"<@/3X@7R@B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M(BDL"B`@("`@("`@("`@("`G<B<@/3X@7R@B4F5A9"!M97-S86=E<R(I+`H@
M("`@("`@("`@("`@)W,G(#T^(%\H(DUA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<R(I+`H@("`@("`@("`@("`@)W<G(#T^(%\H(DUA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(BDL"B`@("`@("`@
M("`@("`G:2<@/3X@7R@B26YS97)T(&UE<W-A9V5S(BDL"B`@("`@("`@("`@
M("`G<"<@/3X@7R@B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I(BDL"B`@("`@("`@("`@("`G8R<@/3X@7R@B0W)E871E('-U
M8B!F;VQD97)S(BDL"B`@("`@("`@("`@("`G9"<@/3X@7R@B1&5L971E(&%N
M9"!P=7)G92!M97-S86=E<R(I+`H@("`@("`@("`@("`@)V$G(#T^(%\H(D%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(BD*
M("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@
M('L*("`@("`@("`D=&AI<RT^7VEM87`@/2!`:6UA<%]O<&5N*'-P<FEN=&8H
M)WLE<SHE9"\E<WTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UTI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($]07TA!3$9/4$5.*3L*("`@("`@("!I9B`H
M(21T:&ES+3Y?:6UA<"D@>PH@("`@("`@("`@("`D=&AI<RT^7VEM87`@/2!0
M14%2.CIR86ES945R<F]R*&EM87!?;&%S=%]E<G)O<B@I*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE($%#3"!O;B!A;B!)
M34%0('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;VQD
M97(@("`@("!4:&4@9F]L9&5R(&]N('=H:6-H('1O(&5D:70@=&AE($%#3"X*
M("`@("`J($!P87)A;2!S=')I;F<@)'-H87)E7W5S97(@(%1H92!U<V5R('1O
M(&=R86YT(')I9VAT<R!T;RX*("`@("`J($!P87)A;2!A<G)A>2`D86-L("`@
M("`@("`@($%N(&%R<F%Y+"!T:&4@:V5Y<R!O9B!W:&EC:"!A<F4@=&AE(')I
M9VAT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F4@
M9W)A;G1E9"`H<V5E(%)&0R`R,#@V*2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@9F%I;'5R
M92!O<B!I9B!S97)V97(*("`@("`J("`@("`@("`@("`@("`@(&1O97-N)W0@
M<W5P<&]R="!!0TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5!0TPH
M)&9O;&1E<BP@)'-H87)E7W5S97(L("1A8VPI"B`@("!["B`@("`@("`@:68@
M*"$D=&AI<RT^7V-O;FYE8W0H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]I;6%P.PH@("`@("`@('T*"B`@("`@("`@)&%C;%]S='(@/2`G)SL*
M("`@("`@("!I9B`H(65M<'1Y*"1A8VPI*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1A8VP@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D
M86-L7W-T<B`N/2`D:V5Y.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!#86XG="!C86QL('1H:7,@87,@0&EM87!?<V5T86-L*"D@87,@
M<W5P<')E<W-I;F<@97)R;W)S(&QE861S('1O"B`@("`@("`@("`@:6UA<%]E
M<G)O<G,H*2!R971U<FYI;F<@;F]T:&EN9RX@*B\*("`@("`@("`D<F5S=6QT
M(#T@:6UA<%]S971A8VPH)'1H:7,M/E]I;6%P+"`D9F]L9&5R+"`D<VAA<F5?
M=7-E<BP@)&%C;%]S='(I.PH*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@
M("`@("`@("`@)&5R<F]R<R`](&EM87!?97)R;W)S*"D["B`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D97)R;W)S*2D@>PH@("`@("`@("`@("`@("`@)&5R
M<F]R7W-T<FEN9R`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5R
M<F]R<R!A<R`D97)R*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1E<G(@
M/3T@)T%#3"!N;W0@879A:6QA8FQE(&]N('1H:7,@24U!4"!S97)V97(G*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1E<G(@+CT@7R@B5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&5R
M<F]R7W-T<FEN9R`N/2`D97)R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R7W-T<FEN
M9RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L9&XG="!G:79E('5S97(@7"(E<UPB
M('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@
M)7,B*2P@)'-H87)E7W5S97(L("1F;VQD97(L("1A8VQ?<W1R*2D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($5D:71S(&%N($%#3"!O;B!A;B!)34%0('-E<G9E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;VQD97(@("`@("!4:&4@9F]L9&5R
M(&]N('=H:6-H('1O(&5D:70@=&AE($%#3"X*("`@("`J($!P87)A;2!S=')I
M;F<@)'-H87)E7W5S97(@(%1H92!U<V5R('1O(&=R86YT(')I9VAT<R!T;RX*
M("`@("`J($!P87)A;2!A<G)A>2`D86-L("`@("`@("`@($%N(&%R<F%Y+"!T
M:&4@:V5Y<R!O9B!W:&EC:"!A<F4@=&AE(')I9VAT<R!T;PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8F4@9W)A;G1E9"`H<V5E(%)&0R`R
M,#@V*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4@=6YL97-S('-E<G9E<B!D;V5S;B=T
M"B`@("`@*B`@("`@("`@("`@("`@("!S=7!P;W)T($%#3',L(')E='5R;G,@
M)VYO7W-U<'!O<G0G"B`@("`@*B\*("`@(&9U;F-T:6]N(&5D:71!0TPH)&9O
M;&1E<BP@)'-H87)E7W5S97(L("1A8VPI"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YC<F5A=&5!0TPH)&9O;&1E<BP@)'-H87)E7W5S97(L("1A8VPI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@9V5T('1H92!R
M97-U;'0@;V8@82!#05!!0DE,2519(&-O;6UA;F0@=&\@=&AE(&-U<G)E;G0@
M24U!4`H@("`@("H@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&-O
M;G1A:6YI;F<@=&AE('-E<G9E<B=S(&-A<&%B:6QI=&EE<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V=E=$-A<&%B:6QI='DH*0H@("`@>PH@("`@("`@("1C
M87!A8FEL:71I97,@/2!N=6QL.PH@("`@("`@("1S97)V97(@/2`D=&AI<RT^
M7W!A<F%M<ULG:&]S='-P96,G73L*("`@("`@("`D<W5B7W!R;W1O(#T@;G5L
M;#L*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>6UXO72LO<W-L?"<L("1T
M:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*2D@>PH@("`@("`@("`@("`D<V5R
M=F5R(#T@)W-S;#HO+R<@+B`D<V5R=F5R.PH@("`@("`@('T*"B`@("`@("`@
M)&EM87`@/2!F<V]C:V]P96XH)'-E<G9E<BP@)'1H:7,M/E]P87)A;7-;)W!O
M<G0G72P@)&5R<FYO+"`D97)R<W1R+"`S,"D["@H@("`@("`@(&EF("@A)&EM
M87`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(I("X@
M)R`M("<@+B`H)&5R<FYO(#\@7R@B0V]N;F5C=&EO;B!F86EL960Z("(I("X@
M)&5R<FYO("X@)R`Z("<@+B`D97)R<W1R(#H@7R@B0V]N;F5C=&EO;B!F86EL
M960N(BDI*3L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E<W!O;G-E(#T@9F=E=',H)&EM87`L(#0P
M.38I.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<*EQS*T]++R<L
M("1R97-P;VYS92DI('L*("`@("`@("`@("`@("`@(&9P=71S*"1I;6%P+"`B
M>"!#05!!0DE,25197')<;B(I.PH@("`@("`@("`@("`@("`@)')E<W!O;G-E
M(#T@=')I;2AF9V5T<R@D:6UA<"P@,3`R-"DI.PH@("`@("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R]>7"I<<RM#05!!0DE,2519+R<L("1R97-P;VYS
M92DI('L*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V5?87)R87D@/2!E
M>'!L;V1E*"<@)RP@)')E<W!O;G-E*3L*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<F5S<&]N<V5?87)R87D@87,@)'9A<BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1V87(L("<])RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R,B`](&5X<&QO
M9&4H)STG+"`D=F%R+"`R*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C87!A8FEL:71I97-;4W1R:6YG.CIL;W=E<B@D=F%R,ELP72E=6U-T<FEN
M9SHZ;&]W97(H)'9A<C);,5TI72`](#$["B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V%P
M86)I;&ET:65S6U-T<FEN9SHZ;&]W97(H)'9A<BE=(#T@,3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&9C;&]S
M92`H)&EM87`I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,B*2`N("<@+2`G("X@7R@B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@(BD@+B`G7"=X($-!4$%"24Q)5%E<)R`Z("<@+B`D
M<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@9F-L;W-E("@D:6UA<"D["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@
M<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(BD@+B`G("T@)R`N(%\H
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@(BD@+B`D<F5S<&]N<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&9C;&]S92`H)&EM87`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C
M87!A8FEL:71I97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971R:65V92!T:&4@97AI<W1I;F<@04-,(&9O<B!A(&9O;&1E<B!F<F]M
M('1H92!C=7)R96YT"B`@("`@*B!)34%0('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&9O;&1E<B`@5&AE(&9O;&1E<B!T;R!G970@=&AE
M($%#3"!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H
M(&-O;G1A:6YI;F<@:6YF;W)M871I;VX@;VX@=&AE($%#3"X*("`@("`J(#QP
M<F4^"B`@("`@*B!!<G)A>2`H"B`@("`@*B`@('5S97(@/3X@07)R87D@*`H@
M("`@("H@("`@(')I9VAT(#T^(#$*("`@("`J("`@*0H@("`@("H@*0H@("`@
M("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%#3"@D9F]L9&5R
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-A<'-;)V%U=&@G
M75LG9&EG97-T+6UD-2==*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]G971!0TPH)&9O;&1E<BP@)V1I9V5S="UM9#4G*3L*("`@("`@("!](&5L
M<V5I9B`H:7-S970H)'1H:7,M/E]C87!S6R=A=71H)UU;)V-R86TM;60U)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$%#3"@D9F]L9&5R
M+"`G8W)A;2UM9#4G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]G971!0TPH)&9O;&1E<BP@)VQO9VEN)RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T<FEE
M=F4@=&AE(&5X:7-T:6YG($%#3"!F;W(@82!F;VQD97(@9G)O;2!T:&4@8W5R
M<F5N=`H@("`@("H@24U!4"!S97)V97(N"B`@("`@*@H@("`@("H@3D(Z(&EF
M($%U=&A?4T%33"!I<R!N;W0@:6YS=&%L;&5D('1H:7,@9G5N8W1I;VX@=VEL
M;"!S96YD('1H92!U<V5R<PH@("`@("H@<&%S<W=O<F0@=&\@=&AE($E-05`@
M<V5R=F5R(&%S('!L86EN('1E>'0A(0H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@9F]L9&5R("`@
M(%1H92!F;VQD97(@=&\@9V5T('1H92!!0TP@9F]R+@H@("`@("H@0'!A<F%M
M('-T<FEN9R!A=71H365C:"`@5&AE(&%U=&AO<FES871I;VX@;65C:&%N:7-M
M('1O('5S92X@3VYE(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!C<F%M+6UD-2P@9&EG97-T+6UD-2!O<B!L;V=I;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@8V]N=&%I;FEN9R!I;F9O<FUA=&EO
M;B!O;B!T:&4@04-,"B`@("`@*B`\<')E/@H@("`@("H@07)R87D@*`H@("`@
M("H@("!U<V5R(#T^($%R<F%Y("@*("`@("`J("`@("!R:6=H="`]/B`Q"B`@
M("`@*B`@("D*("`@("`J("D*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T04-,*"1F;VQD97(L("1A=71H365C:"D*("`@('L*("`@
M("`@("!G;&]B86P@)&YO=&EF:6-A=&EO;CL*"B`@("`@("`@)&AA=F5?<V%S
M;"`](&9A;'-E.PH@("`@("`@("1R971U<FY!0TP@/2!A<G)A>2@I.PH@("`@
M("`@("1S97)V97(@/2`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G73L*("`@
M("`@("`D<W5B7W!R;W1O(#T@;G5L;#L*("`@("`@("`D='AI9"`](#`["@H@
M("`@("`@("\J(%-I;&5N8V4@=V%R;FEN9W,@9'5R:6YG(&-H96-K(&EF($%U
M=&A?4T%33"!M;V1U;&4@:7,@:6YS=&%L;&5D+B`J+PH@("`@("`@(&EF("A`
M:6YC;'5D95]O;F-E("=!=71H+U-!4TPN<&AP)RD@>PH@("`@("`@("`@("`D
M:&%V95]S87-L(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("1P87-S(#T@
M)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT["@H@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"=\7EM>+UTK+W-S;'PG+"`D=&AI<RT^7W!A<F%M<ULG<')O=&]C
M;VPG72DI('L*("`@("`@("`@("`@)'-E<G9E<B`]("=S<VPZ+R\G("X@)'-E
M<G9E<CL*("`@("`@("!]"@H@("`@("`@("\J(%%U;W1E('1H92!F;VQD97(@
M<W1R:6YG(&EF(&ET(&-O;G1A:6YS(&YO;B!A;'!H82UN=6UE<FEC"B`@("`@
M("`@("`@8VAA<F%C=&5R<RX@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UQ7+R<L)&9O;&1E<BDI('L*("`@("`@("`@("`@)&9O;&1E<B`]("<B)R`N
M("1F;VQD97(@+B`G(B<["B`@("`@("`@?0H*("`@("`@("`D:6UA<"`](&9S
M;V-K;W!E;B@D<V5R=F5R+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==+"`D97)R
M;F\L("1E<G)S='(L(#,P*3L*"B`@("`@("`@:68@*"$D:6UA<"D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@
M<F5T<FEE=F4@04-,(BD*("`@("`@("`@("`@("`@("X@)R`M("<@+B`H)&5R
M<FYO(#\@7R@B0V]N;F5C=&EO;B!F86EL960Z("(I("X@)&5R<FYO+B<@.B`G
M("X@)&5R<G-T<B`Z(%\H(D-O;FYE8W1I;VX@9F%I;&5D+B(I*2D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W!O;G-E(#T@9F=E=',H)&EM
M87`L(#0P.38I.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<*EQS
M*T]++R<L("1R97-P;VYS92DI('L*"B`@("`@("`@("`@("`@("`O*B!L;V=I
M;B!U<VEN9R!T:&4@<')E9F5R<F5D(&UE8VAA;FES;2!D969A=6QT('1O(&QO
M9VEN(&EF"B`@("`@("`@("`@("`@("`@("!!=71H7U-!4TP@:7,@;F]T(&EN
M<W1A;&QE9"X@*B\*("`@("`@("`@("`@("`@(&EF("@D:&%V95]S87-L("8F
M("@D875T:$UE8V@@/3T@)V-R86TM;60U)RDI('L*("`@("`@("`@("`@("`@
M("`@("`D;&]G:6X@/2!!=71H7U-!4TPZ.F9A8W1O<GDH)V-R86UM9#4G*3L*
M"B`@("`@("`@("`@("`@("`@("`@9G!U=',H)&EM87`L("(D='AI9"!!551(
M14Y424-!5$4@0U)!32U-1#5<<EQN(BD["B`@("`@("`@("`@("`@("`@("`@
M)&-H86QL96YG92`](&5X<&QO9&4H)R`G+"!T<FEM*&9G971S*"1I;6%P+"`Q
M,#(T*2DI.PH*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D;&]G
M:6XM/F=E=%)E<W!O;G-E*"1?4T534TE/3ELG:6UP)UU;)W5S97(G72P@)'!A
M<W,L(&)A<V4V-%]D96-O9&4H)&-H86QL96YG95LQ72DI.PH@("`@("`@("`@
M("`@("`@("`@(&9P=71S*"1I;6%P+"!B87-E-C1?96YC;V1E*"1R97-P;VYS
M92D@+B`B7')<;B(I.PH*("`@("`@("`@("`@("`@('T@96QS96EF*"1H879E
M7W-A<VP@)B8@*"1A=71H365C:"`]/2`G9&EG97-T+6UD-2<I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&QO9VEN(#T@075T:%]305-,.CIF86-T;W)Y*"=D
M:6=E<W1M9#4G*3L*"B`@("`@("`@("`@("`@("`@("`@9G!U=',H)&EM87`L
M("(D='AI9"!!551(14Y424-!5$4@1$E'15-4+4U$-5QR7&XB*3L*("`@("`@
M("`@("`@("`@("`@("`D8VAA;&QE;F=E(#T@97AP;&]D92@G("<L('1R:6TH
M9F=E=',H)&EM87`L(#$P,C0I*2D["@H@("`@("`@("`@("`@("`@("`@("1R
M97-P;VYS92`]("1L;V=I;BT^9V5T4F5S<&]N<V4H)%]315-324].6R=I;7`G
M75LG=7-E<B==+"`D<&%S<RP@8F%S938T7V1E8V]D92@D8VAA;&QE;F=E6S%=
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG
M<V5R=F5R)UTL("1?4T534TE/3ELG:6UP)UU;)V)A<V5?<')O=&]C;VPG72D[
M"@H@("`@("`@("`@("`@("`@("`@(&9P=71S*"1I;6%P+"!B87-E-C1?96YC
M;V1E*"1R97-P;VYS92D@+B`B7')<;B(I.PH@("`@("`@("`@("`@("`@("`@
M("1R97-P;VYS92`](&5X<&QO9&4H)R`G+"!T<FEM*&9G971S*"1I;6%P+"`Q
M,#(T*2DI.PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS92`](&)A<V4V
M-%]D96-O9&4H)')E<W!O;G-E6S%=*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H<W1R<&]S*"1R97-P;VYS92P@)W)S<&%U=&@])RD@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D:6UA<"D["B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D-O=6QD(&YO="!R971R:65V92!!0TPB*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G("T@)R`N(%\H(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z("(I("X@)T1I9V5S="U-1#4@<F5S<&]N<V4G+"`G:&]R
M9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!F<'5T<R@D:6UA<"P@(EQR7&XB*3L*"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O7%<O)RP@)'!A<W,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87-S(#T@861D<VQA<VAE<R@D<&%S<RD["B`@("`@("`@("`@("`@("`@
M("`@("`@("1P87-S(#T@)R(G("X@)'!A<W,@+B`G(B<["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&9P=71S*"1I;6%P+"`B
M)'1X:60@3$]'24X@(B`N("1?4T534TE/3ELG:6UP)UU;)W5S97(G72`N("<@
M)R`N("1P87-S("X@(EQR7&XB*3L*"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<F5S<&]N<V4@/2!T<FEM*&9G971S*"1I;6%P+"`Q,#(T
M*2D["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B+UXD='AI9%QS
M3TLO(BP@)')E<W!O;G-E*2D@>PH@("`@("`@("`@("`@("`@("`@("1T>&ED
M*RL["B`@("`@("`@("`@("`@("`@("`@9G!U=',H)&EM87`L("(D='AI9"!'
M151!0TP@(B`N("1F;VQD97(@+B`B7')<;B(I.PH@("`@("`@("`@("`@("`@
M("`@("1R97-P;VYS92`]('1R:6TH9F=E=',H)&EM87`L(#0P.38I*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<*EQS*T%#3%QS
M*R@N*BDO:2<L("1R97-P;VYS92P@)&UA=&-H97,I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1R97-?87)R(#T@)'1H:7,M/E]A=&]M:7-E*"1M871C
M:&5S6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E<U]F;VQD97(@
M/2!A<G)A>5]S:&EF="@D<F5S7V%R<BD["B`@("`@("`@("`@("`@("`@("`@
M("`@("1I<U]K97D@/2`Q.PH@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y
M(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E
M<U]A<G(@87,@)'9A<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1I<U]K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:V5Y(#T@)'9A<CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:7-?:V5Y(#T@,#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FUS
M(#T@<')E9U]S<&QI="@G+R\G+"`D=F%R+"`M,2P@4%)%1U]34$Q)5%].3U]%
M35!462D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'!E<FUS(&%S("1P7VME>2`]/B`D<%]V87(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;D%#3%LD:V5Y75LD<%]V
M87)=(#T@,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ES7VME>2`](#$["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!F8VQO<V4H)&EM87`I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(BD*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)R`M("<@+B!?*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B`B*2`N("(G)'1X:60@1T5404-,)R`Z("(@+B1R97-P;VYS92D["@H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1I;6%P*3L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(BD*("`@("`@("`@("`@("`@("`@("`@("`@+B`G
M("T@)R`N(%\H(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M("(I("X@)VQO9VEN(#H@)R`N("1R97-P;VYS92D["@H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9F-L
M;W-E*"1I;6%P*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D-O=6QD(&YO="!R971R:65V92!!0TPB*0H@("`@("`@("`@
M("`@("`@("`@("X@)R`M("<@+B!?*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(I("X@)')E<W!O;G-E*3L*"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@9F-L;W-E*"1I;6%P*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<F5T=7)N04-,.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0V%N(&$@=7-E<B!E9&ET('1H92!!0TP@9F]R('1H:7,@9F]L
M9&5R/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE
M(&9O;&1E<B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("!!
M('5S97(@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@)'5S97(@:&%S('!E<FUI<W-I;VX@=&\@961I="!T:&4@04-,(&]N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("1F;VQD97(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-A;D5D:70H)&9O;&1E<BP@)'5S97(I"B`@("!["B`@("`@
M("`@+RH@5V4@8V%N)W0@97-T86)L:7-H(&EF('1H92!U<V5R(&ES(&EN(&$@
M9W)O=7`@=VET:"!T:&4@)V$G"B`@("`@("`@("`@<')I=FEL96=E+"!S;R!J
M=7-T(')E='5R;B!T<G5E(&%N9"!L96%V92!T:&4@9&5C:7-I;VX@=&\@=&AE
M"B`@("`@("`@("`@<V5R=F5R("HO"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<G5D96QY('-P;&ET(&$@<W1R:6YG(&EN
M=&\@)V%T;VUS)RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;B`@5&AE('-T<FEN9R!T;R!S
M<&QI="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O
M9B`G871O;7,G+@H@("`@("HO"B`@("!F=6YC=&EO;B!?871O;6ES92@D:6XI
M"B`@("!["B`@("`@("`@)&QE;F=T:"`]('-T<FQE;B@D:6XI.PH@("`@("`@
M("1Q="`](&9A;'-E.PH@("`@("`@("1I9'@@/2`P.PH@("`@("`@("1O=70@
M/2!A<G)A>2@I.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;&5N9W1H
M.R`D:2LK*2!["B`@("`@("`@("`@("1C:&%R(#T@<W5B<W1R*"1I;BP@)&DL
M(#$I.PH@("`@("`@("`@("!I9B`H*"1C:&%R(#T]("<B)RD@)B8@(21Q="D@
M>PH@("`@("`@("`@("`@("`@)'%T(#T@=')U93L*("`@("`@("`@("`@("`@
M("1I9'@K*SL*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!](&5L<V5I9B`H*"1C:&%R(#T]("<@)RD@)B8@(21Q="D@>PH@("`@("`@
M("`@("`@("`@)&ED>"LK.PH@("`@("`@("`@("!](&5L<V5I9B`H*"1C:&%R
M(#T]("<B)RD@)B8@)'%T*2!["B`@("`@("`@("`@("`@("`D<70@/2!F86QS
M93L*("`@("`@("`@("`@("`@("1I9'@K*SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;W5T6R1I9'A=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1O=71;)&ED>%T@/2`D8VAA<CL*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&]U=%LD
M:61X72`N/2`D8VAA<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'``````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,C$V`#$P-#$W,S8R-S<S`#`R,3$V
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<"<["@HO*BH*("H@0V]N=&%I;G,@9G5N8W1I;VYS(')E;&%T960@=&\@;6%N
M86=I;F<@06-C97-S($-O;G1R;VP@3&ES=',@;VX@86X@24U!4`H@*B!S97)V
M97(@=7-I;F<@4D9#(#0S,30N"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z
M/'!R93X*("H@("`G=7-E<FYA;64G("!4:&4@=7-E<FYA;64@9F]R('1H92!S
M97)V97(@8V]N;F5C=&EO;@H@*B`@("=P87-S=V]R9"<@(%1H92!P87-S=V]R
M9"!F;W(@=&AE('-E<G9E<B!C;VYN96-T:6]N"B`J("`@)VAO<W1S<&5C)R`@
M5&AE(&AO<W1N86UE(&]R($E0(&%D9')E<W,@;V8@=&AE('-E<G9E<BX*("H@
M("`@("`@("`@("`@("!$149!54Q4.B`G;&]C86QH;W-T)PH@*B`@("=P;W)T
M)R`@("`@(%1H92!S97)V97(@<&]R="!T;R!W:&EC:"!W92!W:6QL(&-O;FYE
M8W0N"B`J("`@("`@("`@("`@("`@24U!4"!I<R!G96YE<F%L;'D@,30S+"!W
M:&EL92!)34%0+5-33"!I<R!G96YE<F%L;'D@.3DS+@H@*B`@("`@("`@("`@
M("`@($1%1D%53%0Z(#$T,PH@*B`@("=P<F]T;V-O;"<@(%1H92!C;VYN96-T
M:6]N('!R;W1O8V]L("AE+F<N("=I;6%P)RP@)W!O<#,G+"`G;FYT<"<I+@H@
M*B`@("`@("`@("`@("`@(%!R;W1O8V]L(&ES(&]N92!O9B`G:6UA<"]N;W1L
M<R<@*&]R(&]N;'D@)VEM87`G(&EF('EO=0H@*B`@("`@("`@("`@("`@(&AA
M=F4@82!C+6-L:65N="!V97)S:6]N(#(P,#!C(&]R(&]L9&5R*2P@)VEM87`O
M<W-L)RP@;W(*("H@("`@("`@("`@("`@("`G:6UA<"]S<VPO;F]V86QI9&%T
M92UC97)T)R`H9F]R(&$@<V5L9BUS:6=N960@8V5R=&EF:6-A=&4I+@H@*B`@
M("`@("`@("`@("`@($1%1D%53%0Z("=I;6%P)SPO<')E/@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP+'8@,2XR
M+C(N,2`R,#`V+S`R+S`V(#(S.C(Q.C$Y('-E;'-K>2!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P-B!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D
M=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA='0@4V5L<VMY(#QS
M96QS:WE`8V]L=6UB:6$N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@
M0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@24U!4%]!0TQ?<F9C-#,Q
M-"!E>'1E;F1S($E-05!?04-,7W)F8S(P.#8@>PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AI<R!D<FEV97(@;6%Y
M(&YE960N"B`@("`@*B\*("`@(&9U;F-T:6]N($E-05!?04-,7W)F8S0S,30H
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<&%R96YT.CI)34%0
M7T%#3%]R9F,R,#@V*"1P87)A;7,I.PH*("`@("`@("`D=&AI<RT^7W)I9VAT
M<TQI<W0@/2!A<G)A>2@*("`@("`@("`@("`@("=L)R`]/B!?*"),:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(B*2P*("`@("`@("`@("`@("=R)R`]
M/B!?*")296%D(&UE<W-A9V5S(BDL"B`@("`@("`@("`@("`G<R<@/3X@7R@B
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(BDL"B`@("`@("`@("`@("`G
M=R<@/3X@7R@B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"DB*2P*("`@("`@("`@("`@("=I)R`]/B!?*"));G-E<G0@
M;65S<V%G97,B*2P*("`@("`@("`@("`@("=P)R`]/B!?*")0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB*2P*("`@("`@("`@
M("`@("=K)R`]/B!?*")#<F5A=&4@<W5B(&9O;&1E<G,B*2P*("`@("`@("`@
M("`@("=X)R`]/B!?*")$96QE=&4@<W5B(&9O;&1E<G,B*2P*("`@("`@("`@
M("`@("=T)R`]/B!?*")$96QE=&4@;65S<V%G97,B*2P*("`@("`@("`@("`@
M("=E)R`]/B!?*")0=7)G92!M97-S86=E<R(I+`H@("`@("`@("`@("`@)V$G
M(#T^(%\H(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S(BD*("`@("`@("`I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!9&UI;BYP:'``
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W,C4R`#$P-#$W
M,S8R-S<S`#`R,#4S,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AE($E-05!?061M:6XZ.B!C;&%S
M<R!A;&QO=R!M86YA9VEN9R!O9B!M86EL8F]X97,@;VX@24U!4"!S97)V97)S
M+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V%D;6EN
M7W5S97(G("`@("`@5&AE(&YA;64@;V8@82!U<V5R('=I=&@@861M:6X@<')I
M=FEL96=E<RX*("H@("`G861M:6Y?<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@
M;V8@=&AE(&%D;6EN<W1R871O<BX\+W!R93X*("H*("H@3W!T:6]N86P@<&%R
M86UE=&5R<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@("`@("`@5&AE(&AO<W1N
M86UE(&]R($E0(&%D9')E<W,@;V8@=&AE('-E<G9E<BX*("H@("`@("`@("`@
M("`@("`@("`@($1%1D%53%0Z("=L;V-A;&AO<W0G"B`J("`@)W!O<G0G("`@
M("`@("`@("!4:&4@<V5R=F5R('!O<G0@=&\@=VAI8V@@=V4@=VEL;"!C;VYN
M96-T+@H@*B`@("`@("`@("`@("`@("`@("`@24U!4"!I<R!G96YE<F%L;'D@
M,30S+"!W:&EL92!)34%0+5-33"!I<R!G96YE<F%L;'D@.3DS+@H@*B`@("`@
M("`@("`@("`@("`@("`@1$5&055,5#H@,30S"B`J("`@)W!R;W1O8V]L)R`@
M("`@("!4:&4@8V]N;F5C=&EO;B!P<F]T;V-O;"`H92YG+B`G:6UA<"<L("=P
M;W`S)RP@)VYN='`G*2X*("H@("`@("`@("`@("`@("`@("`@(%!R;W1O8V]L
M(&ES(&]N92!O9B`G:6UA<"]N;W1L<R<@*&]R(&]N;'D@)VEM87`G(&EF('EO
M=0H@*B`@("`@("`@("`@("`@("`@("`@:&%V92!A(&,M8VQI96YT('9E<G-I
M;VX@,C`P,&,@;W(@;VQD97(I+"`G:6UA<"]S<VPG+`H@*B`@("`@("`@("`@
M("`@("`@("`@;W(@)VEM87`O<W-L+VYO=F%L:61A=&4M8V5R="<@*&9O<B!A
M('-E;&8M<VEG;F5D"B`J("`@("`@("`@("`@("`@("`@("!C97)T:69I8V%T
M92DN"B`J("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G:6UA<"<*("H@
M("`G=7-E<FAI97)A<F-H>2<@(%1H92!H:65R87)C:'D@=VAE<F4@=7-E<B!M
M86EL8F]X97,@87)E('-T;W)E9"X*("H@("`@("`@("`@("`@("`@("`@($1%
M1D%53%0Z("=U<V5R+B<*("H@("`G9'-N)R`@("`@("`@("`@(%1H92!F=6QL
M($E-05`@8V]N;F5C=&EO;B!S=')I;F<N"B`J("`@("`@("`@("`@("`@("`@
M("!)9B!N;W0@<')E<V5N="P@=&AI<R!I<R!B=6EL="!F<F]M("=H;W-T<W!E
M8R<L("=P;W)T)PH@*B`@("`@("`@("`@("`@("`@("`@86YD("=P<F]T;V-O
M;"<@<&%R86UE=&5R<RX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M24U!4"])34%0+T%D;6EN+G!H<"QV(#$N-2XV+C@@,C`P-B\P,2\P,2`R,3HR
M.#HR,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-05`*("HO"F-L
M87-S($E-05!?061M:6X@>PH*("`@("\J*@H@("`@("H@4&%R86UE=&5R(&AA
M<V@N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]P87)A;7,["@H@("`@+RHJ"B`@("`@*B!)34%0(')E<V]U<F-E+@H@("`@
M("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?:6UA
M<#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@=VET:"!A;&P@;F5C97-S
M87)Y('!A<F%M971E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]!9&UI
M;B@D<&%R86US*0H@("`@>PH@("`@("`@("1D969A=6QT7W!A<F%M<R`](&%R
M<F%Y*`H@("`@("`@("`@("`G:&]S='-P96,G(#T^("=L;V-A;&AO<W0G+`H@
M("`@("`@("`@("`G<&]R="<@/3X@)S$T,R<L"B`@("`@("`@("`@("=P<F]T
M;V-O;"<@/3X@)VEM87`G+`H@("`@("`@("`@("`G=7-E<FAI97)A<F-H>2<@
M/3X@)W5S97(N)PH@("`@("`@("D["B`@("`@("`@)'1H:7,M/E]P87)A;7,@
M/2!A<G)A>5]M97)G92@D9&5F875L=%]P87)A;7,L("1P87)A;7,I.PH*("`@
M("`@("`O*B!#<F5A=&4@1%-.('-T<FEN9RX@*B\*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=D<VXG72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)V1S;B==(#T@<W!R:6YT9B@G>R5S.B5D+R5S?2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@("`@("1T
M:&ES+3Y?<F5F(#T@)'1H:7,M/E]P87)A;7-;)V1S;B==.PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=F;VQD97(G72DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D<VXG72`N/2`D=&AI<RT^
M7W!A<F%M<ULG9F]L9&5R)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY[*%M>.ETK*3HH
M7&0K*5PO*%M>?5TK*7TO)RP@)'1H:7,M/E]P87)A;7-;)V1S;B==+"`D;6%T
M8VAE<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T
M<W!E8R==(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG<&]R="==(#T@)&UA=&-H97-;,ET["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72`]("1M871C:&5S6S-=.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R968@/2!S<')I;G1F*"=[)7,Z)60O
M)7-])RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R="==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=P<F]T;V-O;"==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;FYE8W1S('1O('1H92!)34%0('-E
M<G9E<B!W:71H('1H92!P87)A;65T97)S('!A<W-E9"!T;R!T:&4*("`@("`J
M(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!R971U<FX@<F5S;W5R8V5\
M;V)J96-T("!!;B!)34%0(')E<V]U<F-E(&]R(&$@4$5!4E]%<G)O<B!O;B!F
M86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]I;6%P(#T@0&EM87!?;W!E;B@D=&AI<RT^7W)E9BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG861M:6Y?=7-E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=A9&UI;E]P87-S=V]R9"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($]07TA!
M3$9/4$5.*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7VEM87`I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6UA<"`](%!%05(Z.G)A:7-E17)R;W(H
M7R@B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(I+"`G
M:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;6%P.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D<R!A(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;6%I;&)O>"`@("`@(%1H92!M86EL8F]X(&YA;64@=&\@861D+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9$UA:6QB;W@H)&UA:6QB;W@I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)&EM87`@/2`D=&AI<RT^7V-O;FYE8W0H*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&EM87`["B`@("`@("`@?0H@("`@("`@
M(&EF("@A0&EM87!?8W)E871E;6%I;&)O>"@D:6UA<"P@)'1H:7,M/E]R968@
M+B`D=&AI<RT^7W!A<F%M<ULG=7-E<FAI97)A<F-H>2==("X@)&UA:6QB;W@I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*&EM87!?
M;&%S=%]E<G)O<B@I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9W)A;G1!9&UI;E!E<FUS*"1M86EL8F]X
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($=R86YT('1H92!A9&UI;B!U<V5R
M(&%L;"!R:6=H=',@;VX@=&AE(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I
M;&)O>"`@("`@("!T:&4@;F%M92!O9B!T:&4@;6%I;&)O>"!O;B!W:&EC:"!W
M92!W:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&=R
M86YT('1H92!P97)M:7-S:6]N"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R=64@
M:68@<W5C8V5S<V9U;"P@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G<F%N=$%D;6EN4&5R;7,H)&UA:6QB;W@I"B`@
M("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]!0TPN<&AP)SL*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=U<V5R;F%M
M92<@/3X@)'1H:7,M/E]P87)A;7-;)V%D;6EN7W5S97(G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`D=&AI<RT^7W!A<F%M<ULG
M861M:6Y?<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@)VAO
M<W1S<&5C)R`]/B`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@)W!O<G0G(#T^("1T:&ES+3Y?<&%R86US6R=P
M;W)T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("=P<F]T;V-O;"<@/3X@
M)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UTI.PH@("`@("`@("1A8VP@/2`F
M24U!4%]!0TPZ.F9A8W1O<GDH)W)F8S(P.#8G+"`D<&%R86US*3L*("`@("`@
M("`D<F5S=6QT(#T@)&%C;"T^8W)E871E04-,*"1T:&ES+3Y?<&%R86US6R=U
M<V5R:&EE<F%R8VAY)UT@+B`D;6%I;&)O>"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=A9&UI;E]U<V5R)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;"<@
M/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W,G(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=R<@/3X@=')U92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I)R`]/B!T<G5E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W`G(#T^('1R
M=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8R<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V$G(#T^('1R=64I*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!M86EL8F]X+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&UA:6QB;W@@(%1H92!M86EL8F]X('1O
M(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5-86EL8F]X*"1M86EL8F]X*0H@
M("`@>PH@("`@("`@(&EF("AI<U]A*"1I;6%P(#T@)'1H:7,M/E]C;VYN96-T
M*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;6%P
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]G<F%N=$%D;6EN4&5R;7,H
M)&UA:6QB;W@I.PH@("`@("`@(&EF("@A0&EM87!?9&5L971E;6%I;&)O>"@D
M:6UA<"P@)'1H:7,M/E]R968@+B`D=&AI<RT^7W!A<F%M<ULG=7-E<FAI97)A
M<F-H>2==("X@)&UA:6QB;W@I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*&EM87!?;&%S=%]E<G)O<B@I+"`G:&]R9&4N=V%R;FEN
M9R<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($QI<W0@86QL(&UA:6QB;WAE<RX*("`@("`J"B`@("`@
M*B!.;W1E('1H870@=&AI<R!D;V5S(&YO="!W;W)K(&]N(&$@=FER='5A;"UD
M;VUA:6X@96YA8FQE9"!#>7)U<R`H:70@=VEL;`H@("`@("H@;VYL>2!R971U
M<FX@;6%I;&)O>&5S(&EN('1H92!D969A=6QT(&1O;6%I;BDN"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F(&UA:6QB;WAE<RP@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L:7-T36%I;&)O>&5S*"D*("`@('L*("`@("`@("!I9B`H
M:7-?82@D:6UA<"`]("1T:&ES+3Y?8V]N;F5C="@I+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D:6UA<#L*("`@("`@("!]"@H@("`@
M("`@("1L:7-T(#T@0&EM87!?;&ES="@D:6UA<"P@)'1H:7,M/E]R968L("1T
M:&ES+3Y?<&%R86US6R=U<V5R:&EE<F%R8VAY)UT@+B`G)2<I.PH@("`@("`@
M(&EF("@A)&QI<W0I('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H)R\N*B<@+B!P
M<F5G7W%U;W1E*"1T:&ES+3Y?<&%R86US6R=U<V5R:&EE<F%R8VAY)UTL("<O
M)RD@+B`G*"XJ*2\G+"`G7%PQ)RP@)&QI<W0I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0VAE8VL@=VAE=&AE<B!A(&UA:6QB;W@@97AI<W1S+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&UA:6QB;W@@("!4:&4@;6%I;&)O>"!T
M;R!C:&5C:RX*("`@("`J($!R971U<FX@;6EX960@(%1R=64@:68@;6%I;&)O
M>"!E>&ES=',L(&9A;'-E(&EF(&YO="P@;W(@82!014%27T5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!M86EL8F]X17AI<W1S*"1M86EL8F]X*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A*"1I;6%P(#T@)'1H:7,M/E]C;VYN96-T*"DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;6%P.PH@
M("`@("`@('T*"B`@("`@("`@)&QI<W0@/2!`:6UA<%]L:7-T*"1I;6%P+"`D
M=&AI<RT^7W)E9BP@)'1H:7,M/E]P87)A;7-;)W5S97)H:65R87)C:'DG72`N
M("1M86EL8F]X*3L*("`@("`@("!I9B`H)&QI<W0@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N(&-O=6YT*"1L:7-T*2`^(#`["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TE-05`O0V%C:&4N<&AP````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,#4S-P`Q,#0Q-S,V,C<W,P`P,C`U,#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!)34%07T-A8VAE.CH@8VQA<W,@9F%C:6QI=&%T97,@:6X@8V%C:&EN9R!O
M=71P=70@9G)O;2!T:&4@4$A0(&EM87`*("H@97AT96YS:6]N(&EN('1H92!C
M=7)R96YT('-E<W-I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TE-05`O
M24U!4"]#86-H92YP:'`L=B`Q+C0N,3(N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(Q
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95])34%0"B`J+PIC;&%S<R!)34%07T-A8VAE('L*
M"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@=&AE('-E<W-I;VX@8V%C:&4N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C
M86-H93L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R969E<F5N8V4@=&\@
M=&AE(&=L;V)A;"!)34%07T-A8VAE(&]B:F5C="P@;VYL>2!C<F5A=&EN9PH@
M("`@("H@:70@:68@:70@9&]E<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*
M("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*("`@("`J
M("`@)&EM87!?8V%C:&4@/2`F24U!4%]#86-H93HZ<VEN9VQE=&]N*"D["B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T
M97)S('1H92!C;VYS=')U8W1O<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($E-05!?0V%C:&4@(%1H92!)34%07T-A8VAE(&EN<W1A;F-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D;V)J96-T.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1O8FIE8W0I*2!["B`@("`@("`@("`@("1O8FIE8W0@/2`F
M;F5W($E-05!?0V%C:&4H)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&]B:F5C=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($YO="!U
M<V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07T-A8VAE*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)%]315-324].
M6R=I;6%P7V-A8VAE)UTI*2!["B`@("`@("`@("`@("1?4T534TE/3ELG:6UA
M<%]C86-H92==(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/E]C86-H92`]("8D7U-%4U-)3TY;)VEM87!?8V%C:&4G73L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="!D871A(&9R;VT@=&AE(&-A8VAE+@H@("`@("H*
M("`@("`J($!P87)A;2!R97-O=7)C92`F)&EM87`@(%1H92!)34%0(')E<V]U
M<F-E('-T<F5A;2X*("`@("`J($!P87)A;2!S=')I;F<@)&UA:6QB;W@@(%1H
M92!F=6QL("A[:&]S=&YA;65];6%I;&)O>"D@;6%I;&)O>"!N86UE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@5&AE(&YA;64@;V8@82!S<&5C
M:69I8R!E;G1R>2!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M8VAE8VL@("!#:&5C:R!F;W(@=7!D871E9"!M86EL8F]X/PH@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!D871A(')E<75E<W1E9"P@;W(@9F%L
M<V4@:68@;F]T(&%V86EL86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M0V%C:&4H)B1I;6%P+"`D;6%I;&)O>"P@)&ME>2`](&YU;&PL("1C:&5C:R`]
M('1R=64I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V%C:&5;
M)&UA:6QB;WA=*2D@>PH@("`@("`@("`@("!I9B`H(21C:&5C:R!\?"`D=&AI
M<RT^8VAE8VM#86-H92@D:6UA<"P@)&UA:6QB;W@I*2!["B`@("`@("`@("`@
M("`@("`D<'1R(#T@)B1T:&ES+3Y?8V%C:&5;)&UA:6QB;WA=.PH@("`@("`@
M("`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P=');)V0G75LD:V5Y72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1P=');)V0G75LD:V5Y73L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D<'1R6R=D)UT["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&-A8VAE(&EN
M9F]R;6%T:6]N('5P+71O+61A=&4_"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("8D:6UA<"`@5&AE($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9U;&P@*'MH;W-T;F%M
M97UM86EL8F]X*2!M86EL8F]X(&YA;64N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D=7!D871E("!3:&]U;&0@=&AE(&-A8VAE($E$('-T<FEN9R!B92!U<&1A
M=&5D/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!C
M86-H92!I;F9O<FUA=&EO;B!U<"UT;RUD871E+"!F86QS92!I9B!N;W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-H96-K0V%C:&4H)B1I;6%P+"`D;6%I;&)O
M>"P@)'5P9&%T92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V-A8VAE6R1M86EL8F]X72DI('L*("`@("`@("`@("`@)&ED(#T@
M)'1H:7,M/E]G971#86-H94E$*"1I;6%P+"`D;6%I;&)O>"D["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V-A8VAE6R1M86EL8F]X75LG:R==(#T]("1I9"D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@
M96QS96EF("@D=7!D871E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W1O
M<F5#86-H92@D:6UA<"P@)&UA:6QB;W@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@)'1H:7,M/G-T
M;W)E0V%C:&4H)&EM87`L("1M86EL8F]X*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@9&%T
M82!I;B!T:&4@8V%C:&4N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E
M("8D:6UA<"`@5&AE($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9U;&P@*'MH;W-T;F%M97UM86EL
M8F]X*2!M86EL8F]X(&YA;64N"B`@("`@*B!`<&%R86T@87)R87D@)'9A;'5E
M<R`@("!4:&4@9&%T82!T;R!A9&0@=&\@=&AE(&-A8VAE+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S=&]R94-A8VAE*"8D:6UA<"P@)&UA:6QB;W@L("1V86QU
M97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1I9"`]("1T:&ES+3Y?9V5T
M0V%C:&5)1"@D:6UA<"P@)&UA:6QB;W@I.PH@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]C86-H95LD;6%I;&)O>%TI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?8V%C:&5;)&UA:6QB;WA=(#T@87)R87DH)VLG(#T^("1I9"P@)V0G(#T^
M("1V86QU97,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P='(@
M/2`F)'1H:7,M/E]C86-H95LD;6%I;&)O>%T["B`@("`@("`@("`@("1P=');
M)VLG72`]("1I9#L*("`@("`@("`@("`@)'!T<ELG9"==(#T@87)R87E?;65R
M9V4H)'9A;'5E<RP@)'!T<ELG9"==*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@=6YI<75E($E$('-T<FEN9R!F;W(@
M=&AE(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("8D:6UA<"`@5&AE($E-05`@
M<F5S;W5R8V4@<W1R96%M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O
M>"`@5&AE(&9U;&P@*'MH;W-T;F%M97UM86EL8F]X*2!M86EL8F]X(&YA;64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@=6YI<75E('-T<FEN
M9R!F;W(@=&AE(&-U<G)E;G0@<W1A=&4@;V8@=&AE(&UA:6QB;W@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971#86-H94E$*"8D:6UA<"P@)&UA:6QB;W@I
M"B`@("!["B`@("`@("`@)&]B(#T@0&EM87!?<W1A='5S*"1I;6%P+"`D;6%I
M;&)O>"P@4T%?34534T%'15,@?"!305]214-%3E0@?"!305]53E-%14X@?"!3
M05]5241.15A4*3L*("`@("`@("!R971U<FX@:6UP;&]D92@G?"<L(&%R<F%Y
M*"1O8BT^;65S<V%G97,L("1O8BT^<F5C96YT+"`D;V(M/G5N<V5E;BP@)&]B
M+3YU:61N97AT*2D["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]3
M96%R8V@N<&AP````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0Q
M,C$S`#$P-#$W,S8R-S<S`#`R,#8W-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE($E-05!?4V5A
M<F-H.CH@8VQA<W,@<&5R9F]R;7,@8V]M<&QE>"!S96%R8VAI;F<@;V8@86X@
M24U!4"!M86EL8F]X+@H@*@H@*B!#;&%S<V5S('1O(&AE;'`@=VET:"!C;VUP
M;&5X('-E87)C:&EN9R!O9B!A;B!)34%0(&UA:6QB;W@N("!4:&4@8G5I;'0M
M:6X*("H@4$A0('-E87)C:"@I(&9U;F-T:6]N(&]N;'D@86QL;W=S($E-05!V
M,B!S96%R8V@@<75E<FEE<R`H<V5E(%)&0R`Q,3<V*2X*("H@5&AI<R!L:6)R
M87)Y(&%L;&]W<R!M;W)E(&-O;7!L97@@<V5A<F-H97,@=&\@8F4@8W)E871E
M9"`H92YG+B!/4B!S96%R8VAE<RP*("H@<V5A<F-H:6YG('-P96-I9FEC(&AE
M861E<G,I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-05`O4V5A
M<F-H+G!H<"QV(#$N,CDN,3`N,C,@,C`P-B\P,B\P,2`P.3HQ,SHS,R!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O
M<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@24U!4%]396%R8V@@>PH*("`@
M("\J*@H@("`@("H@5&AE(&AE861E<G,@8V%C:&4N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]H96%D97)S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J(%1H92!R97-U;'1S(&-A8VAE+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<F5S=6QT(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!P87)A;6%T97(@;&ES="X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A
M<F%M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8VAA<G-E="!O
M9B!T:&4@<V5A<F-H('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]C:&%R<V5T.PH*("`@("\J*@H@("`@("H@
M26YT97)N86P@9FQA9R!U<V5D(&)Y('-E87)C:$UA:6QB;W@H*2X*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<V5A<F-H
M9FQA9R`](#`["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E;F-E
M('1O('1H92!G;&]B86P@24U!4%]396%R8V@@;V)J96-T+"!O;FQY(&-R96%T
M:6YG(&ET"B`@("`@*B!I9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N"B`@
M("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.CQC
M;V1E/@H@("`@("H@("`D:6UA<%]S96%R8V@@/2`F24U!4%]396%R8V@Z.G-I
M;F=L971O;B@I.SPO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(&-O;G-T<G5C=&]R(&UA>2!N
M965D+@H@("`@("H*("`@("`J($!R971U<FX@24U!4%]396%R8V@@(%1H92!)
M34%07U-E87)C:"!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T
M:6,@)&]B:F5C=#L*"B`@("`@("`@:68@*"%I<W-E="@D;V)J96-T*2D@>PH@
M("`@("`@("`@("`D;V)J96-T(#T@;F5W($E-05!?4V5A<F-H*"1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8FIE8W0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@=&AE(&9O;&QO
M=VEN9R!E;G1R:65S.CQP<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@)W!O<#,G(#T^(&)O;VQE86X@*'5S:6YG(%!/4#,@8V]N;F5C=&EO;C\I
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^('-T
M<FEN9R`H8VAA<G-E="!O9B!S96%R8V@@=F%L=65S*0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("=N;U]I;6%P7W-E87)C:"<@/3X@=')U92!I9B!T
M:&4@24U!4"!S97)V97(@9&]E<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;F]T('-U<'!O<G0@=&AE(&-H87)S
M970@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H92!S96%R8V@@8V]M;6%N9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%0
M7U-E87)C:"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI
M<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M96%R8VAE<R!M97-S86=E<R!B>2!!3$P@:&5A9&5R<R`H<F%T:&5R('1H86X@
M=&AE(&QI;6ET960@<V5T('!R;W9I9&5D"B`@("`@*B!B>2!I;6%P7W-E87)C
M:"@I*2X*("`@("`J"B`@("`@*B!`<&%R86T@24U!4%]396%R8VA?475E<GD@
M)'%U97)Y("!4:&4@<V5A<F-H('%U97)Y+@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("8D:6UA<"`@("`@("`@("`@06X@24U!4"!R97-O=7)C92!S=')E86TN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M8F]X("`@("`@("`@("`@("!4:&4@
M;F%M92!O9B!T:&4@;6%I;&)O>"!T;R!S96%R8V@N($9O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$]0,RP@=&AI<R!S:&]U
M;&0@8F4@96UP='DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&QI<W0@;V8@:6YD:6-E<R!T:&%T(&UA=&-H('1H92!S96%R8V@@<G5L97,@
M:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!C=7)R96YT(&UA:6QB;W@N
M"B`@("`@*B`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E87)C:$UA:6QB;W@H)'%U
M97)Y+"`F)&EM87`L("1M8F]X*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O
M<B!)34%0(&5X=&5N<VEO;BX@*B\*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N
M<VEO;D5X:7-T<R@G:6UA<"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A
M;"A014%2.CIR86ES945R<F]R*")4:&ES(&9U;F-T:6]N(')E<75I<F5S("=I
M;6%P)R!T;R!B92!B=6EL="!I;G1O(%!(4"XB*2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("`O*B!/<&5N('1O('1H
M92!C;W)R96-T(&UA:6QB;W@N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7W!A
M<F%M<ULG<&]P,R==*2!["B`@("`@("`@("`@($!I;6%P7W)E;W!E;B@D:6UA
M<"P@)&UB;W@L($]07U)%041/3DQ9*3L*("`@("`@("!]"@H@("`@("`@("\J
M($-L96%R('1H92!S96%R8V@@9FQA9RX@*B\*("`@("`@("`D=&AI<RT^7W-E
M87)C:&9L86<@/2`P.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]S96%R8VA-
M86EL8F]X*"1Q=65R>2P@)&EM87`L("1M8F]X*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E87)C:&5S('1H92!M86EL8F]X(&%N9"!S;W)T<R!T:&4@<F5S
M=6QT<RX*("`@("`J"B`@("`@*B!`<&%R86T@24U!4%]396%R8VA?475E<GD@
M)'%U97)Y("!4:&4@<V5A<F-H('%U97)Y+@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("8D:6UA<"`@("`@("`@("`@06X@24U!4"!R97-O=7)C92!S=')E86TN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M8F]X("`@("`@("`@("`@("!4:&4@
M;F%M92!O9B!T:&4@;6%I;&)O>"!T;R!S96%R8V@N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<V]R=&)Y("`@("`@("`@("!4:&4@8W)I=&5R:6$@=&\@<V]R
M="!B>2`H<V5E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;6%P7W-O<G0H*2DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<V]R
M=&1I<B`@("`@("`@("`Q(&9O<B!R979E<G-E('-O<G1I;F<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@:6YD:6-E<R!T:&%T
M(&UA=&-H('1H92!S96%R8V@@<G5L97,@:6X@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("!C=7)R96YT(&UA:6QB;W@@86YD('-O<G1E9"X*("`@("`J("`@
M("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H4V]R=$UA:6QB;W@H)'%U97)Y+"`F
M)&EM87`L("1M8F]X+"`D<V]R=&)Y+"`D<V]R=&1I<B`](#`I"B`@("!["B`@
M("`@("`@)&EN9&EC97,@/2`D=&AI<RT^<V5A<F-H36%I;&)O>"@D<75E<GDL
M("1I;6%P+"`D;6)O>"D["B`@("`@("`@:68@*&ES7V$H)&EN9&EC97,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;F1I8V5S.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I;F1I8V5S7W-O<G0@/2!`
M:6UA<%]S;W)T*"1I;6%P+"`D<V]R=&)Y+"`D<V]R=&1I<BP@4T5?54E$*3L*
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7W9A;'5E<RAA<G)A>5]I;G1E<G-E
M8W0H)&EN9&EC97-?<V]R="P@)&EN9&EC97,I*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!);G1E<FYA;"!W<F%P<&5R(&UE=&AO9"!T;R!I
M;6%P7W-E87)C:"!T:&%T(&%L;&]W<R!C:&%R<V5T(&%W87)E"B`@("`@*B!S
M96%R8VAE<R!I9B!A=F%I;&%B;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;6%P4V5A<F-H*"8D:6UA
M<"P@)&-R:71E<FEA*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]P87)A;7-;)V-H87)S970G72DI('L*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=N;U]I;6%P7V-H87)S970G72D@)B8*("`@("`@
M("`@("`@("`@('9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C,N
M,R<L("<^/2<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@0&EM87!?<V5A
M<F-H*"1I;6%P+"`D8W)I=&5R:6$L(%-%7U5)1"P@)'1H:7,M/E]P87)A;7-;
M)V-H87)S970G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D8W)I=&5R:6$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1C<FET
M97)I82P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72P@)U53+4%30TE))RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!`:6UA
M<%]S96%R8V@H)&EM87`L("1C<FET97)I82P@4T5?54E$*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($EN=&5R;F%L(&9U;F-T:6]N('1O('-E87)C:"!T:&4@
M;6%I;&)O>"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W-E87)C:$UA:6QB;W@H)'%U97)Y+"`F)&EM87`L
M("1M8F]X*0H@("`@>PH@("`@("`@("1I;F1I8V5S(#T@87)R87DH*3L*"B`@
M("`@("`@)'1H:7,M/E]S96%R8VAF;&%G(#T@,#L*"B`@("`@("`@+RH@1&\@
M=&AE('-I;7!L92!S96%R8VAE<R!T:&%T(&EM87!?<V5A<F-H*"D@8V%N(&AA
M;F1L92X@*B\*("`@("`@("!I9B`H*"1O8B`]("1Q=65R>2T^8G5I;&0H*2DI
M('L*("`@("`@("`@("`@:68@*"1O8BT^;F]T*2!["B`@("`@("`@("`@("`@
M("!I9B`H(2@D:6YD:6-E<S$@/2`D=&AI<RT^7VEM87!396%R8V@H)&EM87`L
M("1O8BT^9FQA9W,I*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;F1I8V5S
M,2`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H(2@D:6YD:6-E<S(@/2`D=&AI<RT^7VEM87!396%R8V@H)&EM87`L
M("1O8BT^<75E<GDI*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;F1I8V5S
M,B`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D:6YD:6-E<R`](&%R<F%Y7V1I9F8H)&EN9&EC97,Q+"`D:6YD:6-E<S(I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"$H
M)&EN9&EC97,@/2`D=&AI<RT^7VEM87!396%R8V@H)&EM87`L("1O8BT^9G5L
M;'%U97)Y*2DI('L*("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<R`](&%R
M<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J(%-E="!T:&4@<V5A<F-H(&9L86<N("HO"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7W-E87)C:&9L86<@/3T@,"D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]S96%R8VAF;&%G(#T@,3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@4')O8V5S<R!E>'1E;F1E9"!S96%R8VAE<RX@
M*B\*("`@("`@("!I9B`H*"1E>'1E;F1E9"`]("1Q=65R>2T^97AT96YD9613
M96%R8V@H*2DI('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<V5A
M<F-H4$A0*"1E>'1E;F1E9"P@)'%U97)Y+3YF;&%G<R@I+"`D:6UA<"P@)&UB
M;W@I.PH@("`@("`@("`@("`O*B!3970@=&AE('-E87)C:"!F;&%G+B`J+PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]S96%R8VAF;&%G(#T](#`I('L*("`@
M("`@("`@("`@("`@("1I;F1I8V5S(#T@)')E<W5L=#L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<V5A<F-H9FQA9R`](#$["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D:6YD:6-E<R`](&%R<F%Y7W9A;'5E<RAA
M<G)A>5]I;G1E<G-E8W0H)&EN9&EC97,L("1R97-U;'0I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4')O8V5S<R!S:7IE('-E87)C
M:&5S+B`J+PH@("`@("`@(&EF("@H)'-I>F5/8B`]("1Q=65R>2T^<VEZ95-E
M87)C:"@I*2D@>PH@("`@("`@("`@("`D;W9E<G9I97<@/2!`:6UA<%]F971C
M:%]O=F5R=FEE=R@D:6UA<"P@:6UP;&]D92@G+"<L("1I;F1I8V5S*2P@1E1?
M54E$*3L*("`@("`@("`@("`@)&9U;F,@/2!C<F5A=&5?9G5N8W1I;VXH)R1A
M)RP@)W)E='5R;B`H)&$@)R`N("1S:7IE3V(M/G-I>F5O<"`N("<@)R`N("1S
M:7IE3V(M/G-I>F4@+B`G*3LG*3L*("`@("`@("`@("`@)')E<W5L="`](&%R
M<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1O=F5R=FEE=R!A<R`D=F%L
M*2!["B`@("`@("`@("`@("`@("!I9B`H)&9U;F,H)'9A;"T^<VEZ92DI('L*
M("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2`D=F%L+3YU:60["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?<V5A<F-H9FQA9R`]/2`P*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E87)C:&9L86<@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1I;F1I8V5S(#T@87)R87E?=F%L=65S*&%R<F%Y7VEN=&5R<V5C="@D
M:6YD:6-E<RP@)')E<W5L="DI.PH@("`@("`@('T*"B`@("`@("`@+RH@4')O
M8V5S<R!!3D0@<V5A<F-H97,@;F]W+B`J+PH@("`@("`@("1I;F1I8V5S(#T@
M)'1H:7,M/E]D;T%N9$]R4V5A<F-H*"1Q=65R>2T^86YD4V5A<F-H*"DL("1I
M;6%P+"`D;6)O>"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G86YD)RP@)&EN9&EC97,I.PH*("`@("`@("`O*B!0<F]C97-S
M($]2('-E87)C:&5S(&YO=RX@*B\*("`@("`@("`D:6YD:6-E<R`]("1T:&ES
M+3Y?9&]!;F1/<E-E87)C:"@D<75E<GDM/F]R4V5A<F-H*"DL("1I;6%P+"`D
M;6)O>"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;W(G+"`D:6YD:6-E<RD["@H@("`@("`@(')E='5R;B`D:6YD:6-E<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($EN=&5R;F%L(&9U;F-T:6]N('1O('-E
M87)C:"!T:&4@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1O06YD3W)396%R8V@H)'%U97)Y
M+"`F)&EM87`L("1M8F]X+"`D;6]D92P@)&EN9&EC97,L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8F%S92`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`D:6YD
M:6-E<SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1Q=65R>2!A<R`D
M=F%L*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1V86PL("=)34%07U-E87)C
M:%]1=65R>2<I*2!["B`@("`@("`@("`@("`@("`D<')E=G-E87)C:"`]("AE
M;7!T>2@D:6YD:6-E<RD@)B8@*"1T:&ES+3Y?<V5A<F-H9FQA9R`]/2`P*2D[
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]S96%R8VA-86EL
M8F]X*"1V86PL("1I;6%P+"`D;6)O>"D["B`@("`@("`@("`@("`@("!I9B`H
M)&UO9&4@/3T@)V%N9"<I('L*("`@("`@("`@("`@("`@("`@("`O*B!)9B!T
M:&4@<F5S=6QT(&ES(&5M<'1Y(&EN(&%N($%.1"!S96%R8V@L('=E(&MN;W<@
M=&AA=`H@("`@("`@("`@("`@("`@("`@("`@('1H92!E;G1I<F4@04Y$('-E
M87)C:"!W:6QL(&)E(&5M<'1Y('-O(')E='5R;@H@("`@("`@("`@("`@("`@
M("`@("`@(&EM;65D:6%T96QY+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF
M("AE;7!T>2@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("\J($EF('=E(&AA=F4@<F5A8VAE9"!T:&ES('!O:6YT
M+"!A;F0@:&%V92!N;W0@<&5R9F]R;65D(&$*("`@("`@("`@("`@("`@("`@
M("`@("!S96%R8V@@>65T+"!W92!M=7-T('5S92!T:&4@<F5S=6QT<R!A<R!T
M:&4@:6YD:6-E<PH@("`@("`@("`@("`@("`@("`@("`@(&QI<W0N(%=I=&AO
M=70@=&AI<R!C:&5C:RP@=&AE(&EN9&EC97,@;&ES="!W:6QL(&%L=V%Y<PH@
M("`@("`@("`@("`@("`@("`@("`@(&)E(&5M<'1Y(&EF(&%N($%.1"!S96%R
M8V@@:7,@=&AE(&9I<G-T('-E87)C:"X@*B\*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'!R979S96%R8V@I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN9&EC97,@/2`D<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E87)C:&9L86<@/2`Q.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@87)R
M87E?=F%L=65S*&%R<F%Y7VEN=&5R<V5C="@D:6YD:6-E<RP@)')E<W5L="DI
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS
M96EF("@A96UP='DH)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("`D
M:6YD:6-E<R`](&%R<F%Y7W5N:7%U92AA<G)A>5]M97)G92@D:6YD:6-E<RP@
M)')E<W5L="DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&EN9&EC97,@/2`D=&AI<RT^7V1O06YD
M3W)396%R8V@H)'9A;"P@)&EM87`L("1M8F]X+"`D;6]D92P@)&EN9&EC97,I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN
M9&EC97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<V5S(%!(4"!B87-E9"!F
M=6YC=&EO;G,@=&\@<&5R9F]R;2!T:&4@<V5A<F-H+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=&1#;&%S
M<R`D:6UA<%]Q=65R>2`@<F-H('%U97)Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9FQA9W,@("`@("`@("!!;GD@861D:71I;VYA;"!F;&%G<RX*("`@("`J
M($!P87)A;2!R97-O=7)C92`F)&EM87`@("`@("`@06X@24U!4"!R97-O=7)C
M92!S=')E86TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M8F]X("`@("`@("`@
M(%1H92!N86UE(&]F('1H92!S96%R8V@@;6%I;&)O>"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!I;F1I8V5S('1H870@;6%T
M8V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96%R8VA02%`H)&EM87!?<75E
M<GDL("1F;&%G<RP@)B1I;6%P+"`D;6)O>"D*("`@('L*("`@("`@("`D:6YD
M:6-E<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("AE;7!T>2@D9FQA9W,I*2![
M"B`@("`@("`@("`@("1F;&%G<R`]("=!3$PG.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&]P,R==*2D@>PH@("`@
M("`@("`@("`D;6)O>"`]("=03U`S)SL*("`@("`@("!]"@H@("`@("`@("1C
M86-H95]K97D@/2`D;6)O>"`N("=\)R`N("1F;&%G<SL*"B`@("`@("`@+RH@
M5V4@:&%V92!T;R!U<V4@<&%R<V5-24U%2&5A9&5R<R@I('1O(&=E="!E86-H
M(&AE861E<B!A;F0@<V5E(&EF(&%N>0H@("`@("`@("`J(&9I96QD(&UA=&-H
M97,N(%5S92!I;6%P7W-E87)C:"@I('1O(&=E="!T:&4@;&ES="!O9B!M97-S
M86=E(&EN9&EC97,*("`@("`@("`@*B!O<B!R971U<FX@96UP='D@;&ES="!I
M9B!N;R!S96%R8V@@<F5S=6QT<RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<F5S=6QT6R1C86-H95]K97E=*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W)E<W5L=%LD8V%C:&5?:V5Y72`]($!I;6%P7W-E87)C:"@D:6UA<"P@
M)&9L86=S+"!315]5240I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@96UP
M='D@;65S<V%G92!L:7-T+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W)E<W5L=%LD8V%C:&5?:V5Y72DI('L*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I;F-L=61E
M7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<"<["@H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]H96%D97)S6R1M8F]X72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]H96%D97)S6R1M8F]X72`](&%R<F%Y*"D["B`@("`@("`@
M?0H*("`@("`@("`O*B!'970@=&AE(&AE861E<B]Q=65R>2!T;R!S96%R8V@@
M9F]R+B`J+PH@("`@("`@("1Q=65R>2`](')E<V5T*"1I;6%P7W%U97)Y+3YQ
M=65R>2D["B`@("`@("`@)&ME>2`]('-T<G1O;&]W97(H:V5Y*"1I;6%P7W%U
M97)Y+3YQ=65R>2DI.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)E<W5L
M=%LD8V%C:&5?:V5Y72!A<R`D:6YD97@I('L*("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7VAE861E<G-;)&UB;WA=6R1I;F1E>%TI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;)&UB;WA=6R1I;F1E>%T@/2!-
M24U%7U-T<G5C='5R93HZ<&%R<V5-24U%2&5A9&5R<RA`:6UA<%]F971C:&AE
M861E<B@D:6UA<"P@)&EN9&5X+"!&5%]5240I+"!N=6QL+"!T<G5E*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:"`]("8D=&AI<RT^7VAE861E<G-;
M)&UB;WA=6R1I;F1E>%T["@H@("`@("`@("`@("`O*B!792!N965D('1O(&1O
M(&$@8V%S92!I;G-E;G-I=&EV92!S96%R8V@@;VX@=&5X="!B96-A=7-E+"!F
M;W(*("`@("`@("`@("`@("H@97AA;7!L92P@92UM86EL(&%D9')E<W-E<R!M
M87D@;F]T(&)E(&-A=6=H="!C;W)R96-T;'D*("`@("`@("`@("`@("H@*&9I
M;'1E<FEN9R!F;W(@97AA;7!L94!E>&%M<&QE+F-O;2!W:6QL(&YO="!C871C
M:`H@("`@("`@("`@("`@*B!E>$%M<&QE0&5X86UP;&4N8V]M*2X@*B\*("`@
M("`@("`@("`@)&UA=&-H7W-U8V-E<W,@/2!F86QS93L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1H6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)&AD<E]A
M<G)A>2`]("AI<U]A<G)A>2@D:%LD:V5Y72DI(#\@)&A;)&ME>5T@.B!A<G)A
M>2@D:%LD:V5Y72D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:&1R7V%R
M<F%Y(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T
M<B@D=F%L+"!S=')V86PH)'%U97)Y*2D@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1M871C:%]S=6-C97-S(#T@=')U93L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@H)&EM87!?<75E<GDM/FYO="`F)B`A)&UA=&-H7W-U8V-E<W,I('Q\
M"B`@("`@("`@("`@("`@("`H(21I;6%P7W%U97)Y+3YN;W0@)B8@)&UA=&-H
M7W-U8V-E<W,I*2!["B`@("`@("`@("`@("`@("`D:6YD:6-E<UM=(#T@)&EN
M9&5X.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&EN9&EC97,["B`@("!]"@I]"@HO*BH*("H@5&AE($E-05!?4V5A<F-H7T]B
M:F5C=#HZ(&-L87-S(&ES('5S960@=&\@9F]R;75L871E('%U97)I97,@=&\@
M8F4@=7-E9"!W:71H"B`J('1H92!)34%07U-E87)C:#HZ(&-L87-S+@H@*@H@
M*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC
M;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95])34%0"B`J+PIC;&%S<R!)34%07U-E87)C:%]1=65R>2!["@H@
M("`@=F%R("1?86YD(#T@87)R87DH*3L*("`@('9A<B`D7V5X=&5N9&5D4V5A
M<F-H(#T@87)R87DH*3L*("`@('9A<B`D7V9L86=S(#T@87)R87DH*3L*("`@
M('9A<B`D7VYO="`](&9A;'-E.PH@("`@=F%R("1?;W(@/2!A<G)A>2@I.PH@
M("`@=F%R("1?<75E<GD@/2!N=6QL.PH@("`@=F%R("1?<VEZ92`](&YU;&P[
M"B`@("!V87(@)%]S:7IE;W`@/2!N=6QL.PH*("`@(&9U;F-T:6]N($E-05!?
M4V5A<F-H7U%U97)Y*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@86YY(&5X=&5N9&5D('-E87)C:&5S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E>'1E;F1E9%-E87)C:"@I"B`@("!["B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7V5X=&5N9&5D4V5A<F-H*2D@>PH@("`@("`@("`@("`D<V5A
M<F-H(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`@("`@)'-E87)C:"T^;F]T
M(#T@)'1H:7,M/E]N;W0["B`@("`@("`@("`@("1S96%R8V@M/G%U97)Y(#T@
M)'1H:7,M/E]E>'1E;F1E9%-E87)C:#L*("`@("`@("`@("`@<F5T=7)N("1S
M96%R8V@["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU
M;&P["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@<&%R86UE=&5R<R!F;W(@82!S:7IE('-E87)C:"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<VEZ95-E87)C:"@I"B`@("!["B`@("`@("`@:68@*&ES7VYU
M;&PH)'1H:7,M/E]S:7IE*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("`@("`@)&]B(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@
M("`D;V(M/G-I>F4@/2`H9FQO870I)'1H:7,M/E]S:7IE.PH@("`@("`@("1O
M8BT^<VEZ96]P(#T@)'1H:7,M/E]S:7IE;W`["@H@("`@("`@(')E='5R;B`D
M;V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N>2!!3D0@<V5A
M<F-H97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%N9%-E87)C:"@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?86YD.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;GD@3U(@<V5A<F-H97,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&]R4V5A<F-H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]O<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&9L86=S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!F;&%G<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("@H96UP='DH)'1H:7,M/E]F;&%G<RDI(#\@)R<@.B!I;7!L;V1E
M*"<@)RP@)'1H:7,M/E]F;&%G<RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0G5I;&1S('1H92!)34%0('-E87)C:"!Q=65R>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8G5I;&0H*0H@("`@>PH@("`@("`@("1S96%R8V@@/2`F;F5W('-T
M9$-L87-S.PH*("`@("`@("`D<V5A<F-H+3YN;W0@/2`D=&AI<RT^7VYO=#L*
M("`@("`@("`D<V5A<F-H+3YF;&%G<R`]("1T:&ES+3YF;&%G<R@I.PH*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]Q=65R>2DI('L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7V]R*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S96%R8V@M/G%U
M97)Y(#T@)T%,3"<["B`@("`@("`@("`@("1S96%R8V@M/FYO="`](&9A;'-E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D<V5A<F-H+3YN
M;W0@)B8@96UP='DH)'-E87)C:"T^9FQA9W,I*2!["B`@("`@("`@("`@("`@
M("`D<V5A<F-H+3YF;&%G<R`]("=!3$PG.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1S96%R8V@M/G%U97)Y(#T@)'1H:7,M/E]Q=65R>3L*("`@("`@
M("!]"B`@("`@("`@)'-E87)C:"T^9G5L;'%U97)Y(#T@*"%E;7!T>2@D<V5A
M<F-H+3YF;&%G<RD@/R`D<V5A<F-H+3YF;&%G<R`N("<@)R`Z("<G*2`N("1S
M96%R8V@M/G%U97)Y.PH*("`@("`@("!R971U<FX@)'-E87)C:#L*("`@('T*
M"B`@("`O*B!)34%0('-E87)C:"!M;V1I9FEE<G,N("HO"B`@("!F=6YC=&EO
M;B!?;6]D:69I97)S*"1O8BP@)&-M9"D*("`@('L*("`@("`@("!I9B`H:7-?
M82@D;V(L("=)34%07U-E87)C:%]1=65R>2<I*2!["B`@("`@("`@("`@("1O
M8B`](&%R<F%Y*"1O8BD["B`@("`@("`@?0H@("`@("`@(&%R<F%Y7W!U<V@H
M)'1H:7,M/B1C;60L("1O8BD["B`@("!]"@H@("`@9G5N8W1I;VX@:6UA<$%N
M9"@D;V(I"B`@("!["B`@("`@("`@)'1H:7,M/E]M;V1I9FEE<G,H)&]B+"`G
M7V%N9"<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&EM87!/<B@D;V(I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]M;V1I9FEE<G,H)&]B+"`G7V]R)RD["B`@("!]
M"@H@("`@+RH@24U!4"!396%R8V@@1FQA9W,N("HO"B`@("`O*B!4:&5R92!I
M<R!N;R!N965D('1O('-U<'!O<G0@=&AE($M%65=/4D0O54Y+15E73U)$('%U
M97)Y('-I;F-E('1H90H@("`@("`@:6YD:79I9'5A;"!K97EW;W)D<R!H879E
M(&ED96YT:6-A;"!F=6YC=&EO;F%L:71Y+B`J+PH@("`@9G5N8W1I;VX@7VEM
M87!&;&%G<R@D9FQA9RP@)&-M9"D*("`@('L*("`@("`@("`D8VUD(#T@*"1F
M;&%G*2`_("1C;60@.B`G54XG("X@)&-M9#L*("`@("`@("`D=&AI<RT^7V9L
M86=S6UT@/2`D8VUD.PH@("`@?0H*("`@(&9U;F-T:6]N(&%N<W=E<F5D*"1F
M;&%G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6UA<$9L86=S*"1F;&%G+"`G
M04Y35T52140G*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96QE=&5D*"1F;&%G
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6UA<$9L86=S*"1F;&%G+"`G1$5,
M151%1"<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&9L86=G960H)&9L86<I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I;6%P1FQA9W,H)&9L86<L("=&3$%'1T5$
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@<V5E;B@D9FQA9RD*("`@('L*("`@
M("`@("`D=&AI<RT^7VEM87!&;&%G<R@D9FQA9RP@)U-%14XG*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!R96-E;G0H)&9L86<I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]I;6%P1FQA9W,H=')U92P@*"@D9FQA9RD@/R`G4D5#14Y4)R`Z("=/
M3$0G*2D["B`@("!]"@H@("`@9G5N8W1I;VX@:6UA<$YE=R@I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I;6%P1FQA9W,H=')U92P@)TY%5R<I.PH@("`@?0H*
M("`@("\J($E-05`@2&5A9&5R(%-E87)C:"X@*B\*("`@(&9U;F-T:6]N(&AE
M861E<B@D:&5A9&5R+"`D<75E<GDL("1N;W0@/2!F86QS92D*("`@('L*("`@
M("`@("`D:&5A9&5R(#T@=6-F:7)S="AR=')I;2@D:&5A9&5R+"`G.B<I*3L*
M("`@("`@("`D<W1D2&1R<R`](&%R<F%Y*"=4;R<L("=#8R<L("=&<F]M)RP@
M)U-U8FIE8W0G*3L*("`@("`@("!I9B`H)'%U97)Y("$]("<G*2!["B`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2@D:&5A9&5R+"`D<W1D2&1R<RDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<75E<GD@/2!3=')I;F<Z.G5P<&5R*"1H
M96%D97(I("X@)R`B)R`N(&%D9'-L87-H97,H)'%U97)Y*2`N("<B)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?97AT
M96YD961396%R8VA;)&AE861E<ET@/2`D<75E<GD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/E]N;W0@/2`D;F]T.PH@("`@("`@('T*("`@
M('T*"B`@("`O*B!)34%0($1A=&4@4V5A<F-H+B`J+PH@("`@9G5N8W1I;VX@
M7VEM87!$871E*"1D87DL("1M;VYT:"P@)'EE87(L("1C;60I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]Q=65R>2`]("1C;60@+B`G("<@+B!D871E*")D+4TM
M>2(L(&UK=&EM92@P+"`P+"`P+"`D;6]N=&@L("1D87DL("1Y96%R*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@8F5F;W)E*"1D87DL("1M;VYT:"P@)'EE87(I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]I;6%P1&%T92@D9&%Y+"`D;6]N=&@L
M("1Y96%R+"`G0D5&3U)%)RD["B`@("!]"@H@("`@9G5N8W1I;VX@<VEN8V4H
M)&1A>2P@)&UO;G1H+"`D>65A<BD*("`@('L*("`@("`@("`D=&AI<RT^7VEM
M87!$871E*"1D87DL("1M;VYT:"P@)'EE87(L("=324Y#12<I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&]N*"1D87DL("1M;VYT:"P@)'EE87(I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I;6%P1&%T92@D9&%Y+"`D;6]N=&@L("1Y96%R+"`G
M3TXG*3L*("`@('T*"B`@("`O*B!)34%0(%1E>'0@<V5A<F-H97,N("HO"B`@
M("!F=6YC=&EO;B!B;V1Y*"1Q=65R>2P@)&YO="`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<75E<GD@/2`G0D]$62`B)R`N("1Q=65R>2`N("<B
M)SL*("`@("`@("`D=&AI<RT^7VYO="`]("1N;W0["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&5X="@D<75E<GDL("1N;W0@/2!F86QS92D*("`@('L*("`@("`@
M("`D=&AI<RT^7W%U97)Y(#T@)U1%6%0@(B<@+B`D<75E<GD@+B`G(B<["B`@
M("`@("`@)'1H:7,M/E]N;W0@/2`D;F]T.PH@("`@?0H*("`@("\J($E-05`@
M4VEZ92!S96%R8VAE<RX@*B\*("`@(&9U;F-T:6]N('-I>F4H)'-I>F4L("1O
M<&5R871O<BD*("`@('L*("`@("`@("`D=&AI<RT^7W-I>F4@/2`D<VEZ93L*
M("`@("`@("`D=&AI<RT^7W-I>F5O<"`]("1O<&5R871O<CL*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TE-05`O04-,+G!H<```````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,C<Q-0`Q,#0Q-S,V,C<W,P`P,C`P-S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J($-O
M;G1A:6YS(&9U;F-T:6]N<R!R96QA=&5D('1O(&UA;F%G:6YG"B`J($%C8V5S
M<R!#;VYT<F]L($QI<W1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+G!H<"QV(#$N,BXQ,BXQ,"`R,#`V+S`R+S`S(#`S.C`W.C4W
M('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-H<FES
M($AA<W1I92`\:6UP0&]A:RUW;V]D+F-O+G5K/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAR:7,@2&%S=&EE(#QI;7!`;V%K+7=O;V0N8V\N=6L^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95])34%0
M"B`J+PIC;&%S<R!)34%07T%#3"!["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O
M;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!I9B!T:&4@
M9')I=F5R(&ES('-U<'!O<G1E9"!B>2!T:&4@<V5R=F5R"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W-U<'!O<G1E9"`]
M(&9A;'-E.PH*("`@("\J*@H@("`@("H@06YY(%!%05)?17)R;W(@=&AA="!O
M8V-U<F5D(&)U="!C;W5L9&XG="!B92!R971U<FYE9"!D:7)E8W1L>2X*("`@
M("`J"B`@("`@*B!`=F%R(%!%05)?17)R;W(*("`@("`J+PH@("`@=F%R("1?
M97)R;W(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG
M('1H92!L:7-T(&]F('!O<W-I8FQE(')I9VAT<R!A;F0@82!H=6UA;@H@("`@
M("H@<F5A9&%B;&4@9&5S8W)I<'1I;VX@;V8@96%C:`H@("`@("H*("`@("`J
M($%R<F%Y("@*("`@("`J("`@("!R:6=H="UI9"`]/B!R:6=H="UD97-C<FEP
M=&EO;@H@("`@("H@*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<FEG:'1S3&ES="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!!<G)A>2!C;VYT86EN:6YG('5S97(@;F%M97,@=&AA="!C86YN;W0@
M:&%V92!T:&5I<B!A8V-E<W,*("`@("`J(')I9VAT<R!C:&%N9V5D+@H@("`@
M("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]P<F]T
M96-T960["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@2&%S:"!C;VYT86EN:6YG(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@24U!
M4%]!0TPH)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP=',@=&\@<F5T<FEE=F4@=&AE(&5X:7-T:6YG($%#3"!F;W(@82!F;VQD
M97(@9G)O;0H@("`@("H@=&AE(&-U<G)E;G0@24U!4"!S97)V97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R!F;VQD97(@(%1H92!F;VQD97(@=&\@
M9V5T('1H92!!0TP@9F]R"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M02!H87-H(&-O;G1A:6YI;F<@:6YF;W)M871I;VX@;VX@=&AE($%#3`H@("`@
M("H@("`@("`@("`@("`@("`@07)R87D@*`H@("`@("H@("`@("`@("`@("`@
M("`@("`@('5S97(@/3X@07)R87D@*`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')I9VAT(#T^(#$*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("D*("`@("`J("`@("`@("`@("`@("`@("D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T04-,*"1F;VQD97(I"B`@("!["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T
M:&4@04-,(&]N(&%N($E-05`@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9F]L9&5R("!4:&4@9F]L9&5R(&]N('=H:6-H('1O(&5D:70@
M=&AE($%#3`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-H87)E7W5S
M97(@(%1H92!U<V5R('1O(&=R86YT(')I9VAT<R!T;PH@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D86-L("!!;B!A<G)A>2P@=&AE(&ME>7,@;V8@=VAI
M8V@@87)E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@(')I9VAT<R!T
M;R!B92!G<F%N=&5D("AS964@4D9#(#(P.#8I"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E
M('5N;&5S<PH@("`@("H@("`@("`@("`@("`@("`@<V5R=F5R(&1O97-N)W0@
M<W5P<&]R="!!0TQS+"!R971U<FYS("=N;U]S=7!P;W)T)PH@("`@("HO"B`@
M("!F=6YC=&EO;B!C<F5A=&5!0TPH)&9O;&1E<BP@)'-H87)E7W5S97(L("1A
M8VPI"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@161I=',@86X@04-,(&]N(&%N($E-05`@<V5R=F5R"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]L9&5R("!4:&4@9F]L9&5R(&]N
M('=H:6-H('1O(&5D:70@=&AE($%#3`H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'-H87)E7W5S97(@(%1H92!U<V5R('1O(&=R86YT(')I9VAT<R!T
M;PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D86-L("!!;B!A<G)A>2P@
M=&AE(&ME>7,@;V8@=VAI8V@@87)E('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@(')I9VAT<R!T;R!B92!G<F%N=&5D("AS964@4D9#(#(P.#8I"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!F86EL=7)E('5N;&5S<PH@("`@("H@("`@("`@("`@("`@("`@
M<V5R=F5R(&1O97-N)W0@<W5P<&]R="!!0TQS+"!R971U<FYS("=N;U]S=7!P
M;W)T)PH@("`@("HO"B`@("!F=6YC=&EO;B!E9&ET04-,*"1F;VQD97(L("1S
M:&%R95]U<V5R+"`D86-L*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J($-A;B!A('5S97(@961I="!T:&4@04-,
M(&9O<B!T:&ES(&9O;&1E<C\@4F5T=7)N<R!T<G5E(&EF("1U<V5R"B`@("`@
M*B!P97)M:7-S:6]N('1O(&5D:70@=&AE($%#3"!O;B`D9F]L9&5R"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]L9&5R("!4:&4@9F]L9&5R(&YA
M;64*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("!!('5S97(@
M;F%M90H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B`D
M=7-E<B!H87,@)V$G(')I9VAT"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A;D5D
M:70H)&9O;&1E<BP@)'5S97(I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4FEG:'1S*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]R:6=H='-,:7-T.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=%!R;W1E8W1E9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<')O=&5C=&5D.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES4W5P<&]R=&5D
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S=7!P;W)T960["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T17)R;W(H*0H@("`@>PH@("`@("`@("1E
M<G)O<B`]("1T:&ES+3Y?97)R;W(["B`@("`@("`@)'1H:7,M/E]E<G)O<B`]
M(&YU;&P["B`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@('T*"B`@("`O*BH*
M("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A;B!!0TP@:6YS=&%N8V4@8F%S
M960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E($%#3"!S=6)C;&%S<R!T;R!R
M971U<FXN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T
M97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!!0TP@:6YS
M=&%N8V4L(&]R(&9A;'-E"B`@("`@*B`@("`@("`@("`@("`@("!O;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&1R:79E<B`](&)A<V5N
M86UE*"1D<FEV97(I.PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?
M1DE,15]?*2`N("<O04-,+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@
M("1C;&%S<R`]("=)34%07T%#3%\G("X@)&1R:79E<CL*("`@("`@("!I9B`H
M8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&%C;"`]("9N
M97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1A8VP@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M86-L.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@04-,(&EN<W1A;F-E"B`@("`@
M*B!B87-E9"!O;B`D9')I=F5R+B`@270@=VEL;"!O;FQY(&-R96%T92!A(&YE
M=R!I;G-T86YC92!I9B!N;PH@("`@("H@04-,(&EN<W1A;F-E('=I=&@@=&AE
M('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9)
M34%07T%#3#HZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E($%#3"!S=6)C;&%S
M<R!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@
M:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P
M87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@8W)E871E9"!C;VYC<F5T92!!0TP@:6YS
M=&%N8V4L(&]R(&9A;'-E(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A
M<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA
M;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I
M<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DE-05!?04-,.CIF86-T;W)Y*"1D
M<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I
M;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O5&AR96%D+G!H<```
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-30W-@`Q,#0Q-S,V
M,C<W,P`P,C`W,34`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($E-05!?5&AR96%D('!R;W9I9&5S(&9U
M;F-T:6]N<R!F;W(@=V]R:VEN9R!W:71H(&EM87!?=&AR96%D*"D@;W5T<'5T
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-05`O5&AR96%D+G!H
M<"QV(#$N-"XQ,"XQ,R`R,#`V+S`Q+S`Q(#(Q.C(X.C(Q(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!C=7)E8V%N=&DN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!C=7)E8V%N=&DN;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*
M8VQA<W,@24U!4%]4:')E860@>PH*("`@("\J*@H@("`@("H@:6UA<%]T:')E
M860H*2!O=71P=70N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]T:')E861A<G)A>3L*"B`@("`O*BH*("`@("`J($EN=&5R
M;F%L('1H<F5A9"!D871A('-T<G5C='5R92X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1H<F5A9"`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!I;F1E>"!T;R!-97-S86=E(&EN9&5X(&QO
M;VMU<"!A<G)A>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7VQO;VMU<"`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&]B("!/
M=71P=70@9G)O;2!I;6%P7W1H<F5A9"@I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!)34%07U1H<F5A9"@D;V(I"B`@("!["B`@("`@("`@)'1H:7,M/E]T:')E
M861A<G)A>2`]("1O8CL*("`@("`@("`D=&AI<RT^7W!R;V-E<W-3=')U8W1U
M<F4H*3L*("`@('T*"B`@("\J*@H@("`@("H@1V5T<R!T:&4@:6YD96YT:6]N
M(&QE=F5L(&9O<B!A;B!)34%0(&UE<W-A9V4@:6YD97@N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("!4:&4@24U!4"!M97-S86=E(&EN
M9&5X+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%)E='5R;G,@=&AE
M('1H<F5A9"!I;F1E;G0@;&5V96P@:68@)&EN9&5X(&9O=6YD+@H@("`@("H@
M("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9714:')E861);F1E;G0H)&EN9&5X*0H@("`@
M>PH@("`@("`@("1K97D@/2`D=&AI<RT^7V=E=$ME>2@D:6YD97@I.PH@("`@
M("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]T:')E861;)&ME>5U;)VQE=F5L)UTI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]T:')E861;)&ME>5U;)VQE=F5L)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!B87-E('1H<F5A
M9"!I;F1E>"!F;W(@86X@24U!4"!M97-S86=E(&EN9&5X+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE($E-05`@;65S<V%G92!I
M;F1E>"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2971U<FYS('1H
M92!B87-E($E-05`@:6YD97@@:68@)&EN9&5X(&ES('!A<G0@;V8@80H@("`@
M("H@("`@("`@("`@("`@("`@=&AR96%D+@H@("`@("H@("`@("`@("`@("`@
M("`@4F5T=7)N<R!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9714:')E861"87-E*"1I;F1E>"D*("`@('L*("`@("`@("`D:V5Y
M(#T@)'1H:7,M/E]G971+97DH)&EN9&5X*3L*("`@("`@("!I9B`H(6ES7VYU
M;&PH)&ME>2DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W1H
M<F5A9%LD:V5Y75LG8F%S92==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=&AR96%D6R1K97E=6R=B87-E)UT["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M*BH*("`@("`J($ES('1H:7,@:6YD97@@=&AE(&QA<W0@:6X@=&AE(&-U<G)E
M;G0@;&5V96P_"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X
M("!4:&4@24U!4"!M97-S86=E(&EN9&5X+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&EF("1I;F1E>"!I<R!T:&4@;&%S
M="!E;&5M96YT(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("!C=7)R
M96YT('1H<F5A9"!L979E;"X*("`@("`J("`@("`@("`@("`@("`@("`@4F5T
M=7)N<R!F86QS92!I9B!N;W0L(&]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QA<W1);DQE=F5L*"1I;F1E>"D*("`@('L*("`@("`@("`D
M:V5Y(#T@)'1H:7,M/E]G971+97DH)&EN9&5X*3L*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7W1H<F5A9%LD:V5Y75LG;&%S="==*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=&AR96%D6R1K97E=6R=L87-T)UT["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J($1O('1H92!M97-S86=E(&EN9&5X("T^(&%R<F%Y(&EN
M9&5X(&QO;VMU<"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YD97@@(%1H92!)34%0(&UE
M<W-A9V4@:6YD97@N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M(&%R<F%Y(&EN9&5X('9A;'5E(&]R(&YU;&P@:68@;F\@:6YD97@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971+97DH)&EN9&5X*0H@("`@>PH@("`@("`@
M(')E='5R;B`H:7-S970H)'1H:7,M/E]L;V]K=7!;)&EN9&5X72DI(#\@)'1H
M:7,M/E]L;V]K=7!;)&EN9&5X72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE('-O<G1E9"!L:7-T(&]F(&UE<W-A9V5S(&EN9&EC
M97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YE=R`@5')U92!F
M;W(@;F5W97-T(&9I<G-T+"!F86QS92!F;W(@;VQD97-T(&9I<G-T+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!S;W)T960@;&ES="!O9B!M
M97-S86=E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;65S<V%G94QI<W0H)&YE
M=RD*("`@('L*("`@("`@("!R971U<FX@*"1N97<I(#\@87)R87E?<F5V97)S
M92AA<G)A>5]K97ES*"1T:&ES+3Y?;&]O:W5P*2D@.B!A<G)A>5]K97ES*"1T
M:&ES+3Y?;&]O:W5P*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&QI<W0@;V8@;65S<V%G97,@:6X@=&AE(&-U<G)E;G0@=&AR96%D+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE($E-05`@
M:6YD97@@;V8@=&AE(&-U<G)E;G0@;65S<V%G92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@24U!4"!M97-S86=E(&EN9&EC97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1H<F5A9"@D:6YD97@I"B`@("![
M"B`@("`@("`@+RH@1FEN9"!T:&4@8F5G:6YN:6YG(&]F('1H92!T:')E860N
M("HO"B`@("`@("`@)&)E9VEN(#T@)'1H:7,M/F=E=%1H<F5A9$)A<V4H)&EN
M9&5X*3L*("`@("`@("`D:V5Y(#T@)'1H:7,M/E]G971+97DH)&)E9VEN*3L*
M("`@("`@("!I9B`H:7-?;G5L;"@D:V5Y*2!\?"!E;7!T>2@D8F5G:6XI*2![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@D:6YD97@I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@5V]R:R!F;W)W87)D(&9R;VT@=&AE(&9I<G-T('1H<F5A
M9"!E;&5M96YT('1O(&9I;F0@=&AE(&5N9"!O9B!T:&4*("`@("`@("`@*B!T
M:')E860N("HO"B`@("`@("`@)'1H<F5A9%]L:7-T(#T@87)R87DH)'1H:7,M
M/E]T:')E861;)&ME>5U;)VEN9&5X)UTI.PH@("`@("`@('=H:6QE("@K*R1K
M97DI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W1H<F5A9%LD
M:V5Y72DI('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1C=7)R(#T@)'1H:7,M/E]T:')E861;)&ME>5T["B`@
M("`@("`@("`@(&EF("@D8W5R<ELG8F%S92==(#T]("1B96=I;BD@>PH@("`@
M("`@("`@("`@("`@)'1H<F5A9%]L:7-T6UT@/2`D=&AI<RT^7W1H<F5A9%LD
M:V5Y75LG:6YD97@G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H<F5A9%]L:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4')O8V5S<R!T:&4@;W5T<'5T(&9R;VT@:6UA<%]T:')E860H*2!I;G1O(&%N
M(&EN=&5R;F%L(&1A=&$@<W1R=6-T=7)E+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<')O8V5S<U-T<G5C
M='5R92@I"B`@("!["B`@("`@("`@)&-O;G1A:6YE<B`]("1C;VYT86EN97)?
M8F%S92`]("1L87-T7VEN9&5X(#T@)'1H<F5A9%]B87-E(#T@)'1H<F5A9%]B
M87-E7VED>"`]("!N=6QL.PH@("`@("`@("1I;F1I8V5S(#T@87)R87DH*3L*
M("`@("`@("`D:2`]("1L87-T7VD@/2`D;&5V96P@/2`P.PH*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7W1H<F5A9&%R<F%Y(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1K97DL("<N)RD["B`@("`@
M("`@("`@("1I;F1E>"`]('-U8G-T<B@D:V5Y+"`P+"`D<&]S*3L*("`@("`@
M("`@("`@)'1Y<&4@/2!S=6)S='(H)&ME>2P@)'!O<R`K(#$I.PH*("`@("`@
M("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C87-E("=N=6TG
M.@H@("`@("`@("`@("`@("`@:68@*"1V86P@/3T](#`I('L*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&%I;F5R(#T@)&EN9&5X.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C;VYT86EN97(I("8F(&5M<'1Y
M*"1L979E;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H<F5A9%]B
M87-E(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H<F5A9%]B
M87-E7VED>"`]("1I;F1E>#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L;V]K=7!;)'9A;%T@/2`D:6YD97@[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T:')E861;)&EN9&5X72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T:')E861;
M)&EN9&5X75LG:6YD97@G72`]("1V86P["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VYE>'0G
M.@H@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1C;VYT86EN97(I("8F
M("@D8V]N=&%I;F5R(#T]/2`D:6YD97@I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&-O;G1A:6YE<E]B87-E(#T@)'1H:7,M/E]T:')E861A<G)A>5LD=F%L
M("X@)RYN=6TG73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M7VYU;&PH)&-O;G1A:6YE<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]T:')E861;)&EN9&5X75LG8F%S92==(#T@)&-O;G1A:6YE<E]B
M87-E.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=&AR96%D6R1I;F1E>%U;)V)A<V4G72`]
M("@A96UP='DH)&QE=F5L*2!\?"`H)'9A;"`A/2`P*2D@/R`D=&AR96%D7V)A
M<V4@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D;&5V96PK*SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8G)A;F-H)SH*("`@
M("`@("`@("`@("`@(&EF("@D8V]N=&%I;F5R(#T]/2`D:6YD97@I('L*("`@
M("`@("`@("`@("`@("`@("`D8V]N=&%I;F5R(#T@)&-O;G1A:6YE<E]B87-E
M(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1H<F5A9%LD
M;&%S=%]I;F1E>%U;)VQA<W0G72`]('1R=64["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&AR96%D6R1I
M;F1E>%U;)VQE=F5L)UT@/2`D;&5V96PM+3L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W1H<F5A9%LD:6YD97A=6R=L87-T)UT@/2`A*"%I<U]N=6QL
M*"1C;VYT86EN97(I("8F(&5M<'1Y*"1L979E;"DI.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D:6YD97@@/3T]("1T:')E861?8F%S95]I9'@I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9&5X(#T@;G5L;#L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1L979E;"D@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(6ES7VYU;&PH)&QA<W1?:6YD97@I
M("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES
M+3Y?=&AR96%D6R1L87-T7VEN9&5X72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]T:')E861;)&QA<W1?:6YD97A=6R=L87-T)UT@/2`H
M)&QA<W1?:2`]/2`H)&D@+2`Q*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QA<W1?:6YD97@@
M/2`D:6YD97@["B`@("`@("`@("`@("`@("`D;&%S=%]I(#T@)&DK*SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TE-05`O5')E92YP:'``````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#$V-S`S,``Q,#0Q-S,V,C<W,P`P,C`S-S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RH@0V]N<W1A;G1S(&9O<B!M86EL8F]X16QT(&%T=')I8G5T97,N"B`J($%L
M;"!V97)S:6]N<R!O9B!C+6-L:65N="`H8RUC;&EE;G0O;6%I;"YH*2!D969I
M;F4@=&AE<V4@8V]N<W1A;G1S.@H@*B`@($Q!5%1?3D])3D9%4DE/4E,@*&QO
M;F<I(#!X,2`](#$*("H@("!,05147TY/4T5,14-4("AL;VYG*2`P>#(@/2`R
M"B`J("`@3$%45%]-05)+140@*&QO;F<I(#!X-"`](#0*("H@("!,05147U5.
M34%22T5$("AL;VYG*2`P>#@@/2`X"B`J"B`J($YE=V5R('9E<G-I;VYS(&]F
M(&,M8VQI96YT("AI;6%P+3(P,#(@86YD(&=R96%T97(I(&1E9FEN92!T:&5S
M92!C;VYS=&%N=',Z"B`J("`@3$%45%]2149%4E)!3"`H;&]N9RD@,'@Q,"`]
M(#$V"B`J("`@3$%45%](05-#2$E,1%)%3B`H;&]N9RD@,'@R,"`](#,R"B`J
M("`@3$%45%](05-.3T-(24Q$4D5.("AL;VYG*2`P>#0P(#T@-C0*("H@+BXN
M8G5T('1H97-E(&-O;G-T86YT(&YA;65S(&1O(&YO="!A<'!E87(@:6X@4$A0
M('5N=&EL(%!(4"`T+C,N-2!A;F0@-2XP+@H@*B\*:68@*"%D969I;F5D*"=,
M05147TA!4T-(24Q$4D5.)RDI('L*("`@($!D969I;F4H)TQ!5%1?4D5&15)2
M04PG+"`Q-BD["B`@("!`9&5F:6YE*"=,05147TA!4T-(24Q$4D5.)RP@,S(I
M.PH@("`@0&1E9FEN92@G3$%45%](05-.3T-(24Q$4D5.)RP@-C0I.PI]"@HO
M*B!3=&%R="!A="`Q,C@@9F]R(&]U<B!L;V-A;"!B:71M87-K<R!T;R!A;&QO
M=R!F;W(@=&AE(&,M8VQI96YT($Q!5%1?*@H@("!C;VYS=&%N=',N("HO"F1E
M9FEN92@G24U!4%12145?14Q47TA!4U]#2$E,1%)%3B<L(#$R."D[("\O($1%
M4%)%0T%4140*9&5F:6YE*"=)34%05%)%15]%3%1?25-?3U!%3B<L(#(U-BD[
M"F1E9FEN92@G24U!4%12145?14Q47TE37U-50E-#4DE"140G+"`U,3(I.PID
M969I;F4H)TE-05!44D5%7T5,5%])4U]$25-#3U9%4D5$)RP@,3`R-"D["F1E
M9FEN92@G24U!4%12145?14Q47TE37U!/3$Q%1"<L(#(P-#@I.PID969I;F4H
M)TE-05!44D5%7T5,5%].145$7U-/4E0G+"`T,#DV*3L*+R\@)S@Q.3(G(&ES
M('5S960@8GD@24U0(#0N>"!S;R!D;R!N;W0@=7-E(&ET(&AE<F4*9&5F:6YE
M*"=)34%05%)%15]%3%1?3D%-15-004-%)RP@,38S.#0I.PH*+RH@5&AE(&ES
M3W!E;B@I(&5X<&%N9&5D(&UO9&4@8V]N<W1A;G1S+B`J+PID969I;F4H)TE-
M05!44D5%7T]014Y?3D].12<L(#`I.PID969I;F4H)TE-05!44D5%7T]014Y?
M04Q,)RP@,2D["F1E9FEN92@G24U!4%12145?3U!%3E]54T52)RP@,BD["@HO
M*B!7:&EC:"!M;V1E(&]F($E-05`@86-C97-S(&%R92!W92!U<VEN9RX@*B\*
M9&5F:6YE*"=)34%05%)%15]-3T1%7TU!24PG+"`P*3L*9&5F:6YE*"=)34%0
M5%)%15]-3T1%7TY%5U,G+"`Q*3L*"B\J(%1H92!I;FET86QI>F%T:6]N(&UO
M9&4@=&\@=7-E('=H96X@8W)E871I;F<@=&AE('1R964N("HO"F1E9FEN92@G
M24U!4%12145?24Y)5%]354(G+"`Q*3L*9&5F:6YE*"=)34%05%)%15])3DE4
M7U5.4U5")RP@,BD["F1E9FEN92@G24U!4%12145?24Y)5%]&151#2$%,3"<L
M(#0I.PH*+RH@5&AE(&UA;FYE<B!T;R!W:&EC:"!T;R!T<F%V97)S92!T:&4@
M=')E92!W:&5N(&-A;&QI;F<@;F5X="@I+B`J+PID969I;F4H)TE-05!44D5%
M7TY%6%1?4TA/5T-,3U-%1"<L(#$I.PID969I;F4H)TE-05!44D5%7TY%6%1?
M4TA/5U-50B<L(#(I.PH*+RH@5&AE('-T<FEN9R!U<V5D('1O(&EN9&EC871E
M('1H92!B87-E(&]F('1H92!T<F5E+B`J+PID969I;F4H)TE-05!44D5%7T)!
M4T5?14Q4)RP@;G5L;"D["@HO*BH*("H@5&AE($E-05!?5')E92!C;&%S<R!P
M<F]V:61E<R!A('1R964@=FEE=R!O9B!T:&4@9F]L9&5R<R!S=7!P;W)T960@
M=VET:`H@*B!T:&4@4$A0(&EM87`@97AT96YS:6]N("A)34%0+U!/4#,O3DY4
M4"!R97!O<VET;W)I97,I+B`@270@<')O=FED97,@86-C97-S"B`J(&9U;F-T
M:6]N<R!T;R!I=&5R871E('1H<F]U9V@@=&AI<R!T<F5E(&%N9"!Q=65R>2!I
M;F9O<FUA=&EO;B!A8F]U=`H@*B!I;F1I=FED=6%L(&UA:6QB;WAE<R]F;VQD
M97)S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-05`O5')E92YP
M:'`L=B`Q+C0X+C(N-#$@,C`P-B\P,B\R-R`P,#HP-#HP,2!S;'5S87)Z($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@2F]N
M(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#`M,C`P
M-B!!;FEL($UA9&AA=F%P961D>2`\879S;4!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\
M:F]N0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@
M/&%V<VU`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@24U!4%]4<F5E('L*"B`@
M("`O*BH*("`@("`J($%S<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@=&AE
M(&UA:6QB;W@@=')E92X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W1R964["@H@("`@+RHJ"B`@("`@*B!,;V-A=&EO;B!O
M9B!C=7)R96YT(&5L96UE;G0@:6X@=&AE('1R964N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W5R<G!A<F5N="`](&YU
M;&P["@H@("`@+RHJ"B`@("`@*B!,;V-A=&EO;B!O9B!C=7)R96YT(&5L96UE
M;G0@:6X@=&AE('1R964N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`@*B\*("`@('9A<B`D7V-U<G)K97D@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@3&]C871I;VX@;V8@8W5R<F5N="!E;&5M96YT(&EN('1H92!T<F5E+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8W5R
M<G-T86-K(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-H;W<@=6YS=6)S
M8W)I8F5D(&UA:6QB;WAE<S\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?<VAO=W5N<W5B(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!087)E;G0@;&ES="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7W!A<F5N="`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8V%C:&5D(&QI<W0@;V8@;6%I;&)O>&5S('1O('!O;&PN
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P
M;VQL(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!C86-H960@;&ES="!O
M9B!E>'!A;F1E9"!F;VQD97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?97AP86YD960@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@0V%C:&5D(&QI<W0@;V8@<W5B<V-R:6)E9"!M86EL8F]X97,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S=6)S
M8W)I8F5D(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-A8VAE9"!L:7-T(&]F
M('5N<W5B<V-R:6)E9"!M86EL8F]X97,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]U;G-U8G-C<FEB960@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@26YI="!M;V1E(&9L86<N"B`@("`@*@H@("`@("H@
M0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VEN:71M;V1E(#T@,#L*
M"B`@("`O*BH*("`@("`J(%1R964@8VAA;F=E9"!F;&%G+B`@4V5T('=H96X@
M<V]M971H:6YG(&EN('1H92!T<F5E(&AA<R!B965N(&%L=&5R960N"B`@("`@
M*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-H86YG
M960@/2!F86QS93L*"B`@("`O*BH*("`@("`J($AA=F4@=V4@<VAO=VX@=6YS
M=6)S8W)I8F5D(&9O;&1E<G,@<')E=FEO=7-L>3\*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?=6YS=6)V:65W(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@24U!4%]3;W)T(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`=F%R($E-05!?4V]R=`H@("`@("HO"B`@("!V87(@)%]I
M;6%P7W-O<G0@/2!N=6QL.PH*("`@("\J*@H@("`@("H@26YS97)T(&%N(&5L
M96UE;G0@:6X@=&AE('1R964@=&AA="!D;V5S;B=T(&%P<&5A<B!O;B!T:&4@
M24U!4"!S97)V97(N"B`@("`@*B!)9B!S970L($E-05!?5')E93HZ('=I;&P@
M8V%L;"!?9V5T3F]N24U!4$5L="@I('1O(&]B=&%I;B!T:&4@96QE;65N=`H@
M("`@("H@=&\@861D('1O('1H92!T<F5E+@H@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]N;VYI;6%P96QT(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!T;R!U<V4@=VAE;B!S=&]R:6YG
M('1H92!O8FIE8W0@:6X@=&AE('-E<W-I;VXN"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8V%C:&5N86UE.PH*("`@("\J
M*@H@("`@("H@5&AE(&%P<&QI8V%T:6]N('1H870@9V5N97)A=&5D('1H:7,@
M=')E92X*("`@("`J(%1(25,@4TA/54Q$($)%(%-%5"!)3B!%5D5262!354)#
M3$%34R!#3TY35%)50U1/4BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]A<'`@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE('-E<G9E<B!S=')I;F<@9F]R('1H92!C=7)R96YT('-E<G9E<BX*("`@
M("`J(%1(25,@4TA/54Q$($)%(%-%5"!)3B!%5D5262!354)#3$%34R!#3TY3
M5%)50U1/4BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]S97)V97(@/2`G)SL*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W
M92!U<V4@)VUA:6PG(&UO9&4@;W(@)VYE=W,G(&UO9&4_"B`@("`@*B!42$E3
M(%-(3U5,1"!"12!3150@24X@159%4ED@4U5"0TQ!4U,@0T].4U1254-43U(N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7VUO9&4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@;F%M
M97-P86-E<R!T;R!A9&0@=&\@=&AE('1R964N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]N86UE<W!A8V5S.PH@("`@+RHJ
M"B`@("`@*B!$;V5S('1H92!)34%0('-E<G9E<B!S=7!P;W)T('1H92!C:&EL
M9')E;B!E>'1E;G-I;VX_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7V-H:6QD<F5N<W5P<&]R="`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!5<V5D('1O(&1E=&5R;6EN92!T:&4@;&ES="!O9B!E;&5M
M96YT(&-H86YG97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]E;'1D:69F(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($E-
M05!?5')E92!I;G-T86YC92X*("`@("`J"B`@("`@*B!)9B!A;B!)34%07U1R
M964@;V)J96-T(&ES(&-U<G)E;G1L>2!S=&]R960@:6X@=&AE(&QO8V%L('-E
M<W-I;VXL"B`@("`@*B!R96-R96%T92!T:&%T(&]B:F5C="X@($5L<V4L(&EF
M("1C<F5A=&4@:7,@=')U92P@=VEL;"!C<F5A=&4@82!N97<*("`@("`J(&EN
M<W1A;F-E+B`@16YS=7)E<R!T:&%T(&]N;'D@;VYE($E-05!?5')E92!I;G-T
M86YC92!I<R!A=F%I;&%B;&4*("`@("`J(&%T(&%N>2!T:6UE+@H@("`@("H*
M("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH\<')E/@H@
M("`@("H@("`D:6UA<%]T<F5E(#T@)DE-05!?5')E93HZ<VEN9VQE=&]N*"1A
M<'`L("1C;&%S<VYA;64L(%LD8W)E871E6RP@)'5N<W5B75TI.SPO<')E/@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@("`@("`@5&AE(&-U
M<G)E;G0@87!P;&EC871I;VX@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&-L87-S;F%M92`@5&AE(&-L87-S(&YA;64@=&\@=7-E('=H96X@:6YS=&%N
M=&EA=&EN9R!A(&YE=PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!O8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8W)E871E("`@($-R
M96%T92!A(&YE=R!)34%07U1R964@:68@:70@9&]E<VXG="!E>&ES="!I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@<V5S<VEO;C\*
M("`@("`J($!P87)A;2!I;G1E9V5R("1I;FET("`@("`@5&AE(&EN:71I86QI
M>F%T:6]N(&UO9&4@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%C
M:&5N86UE("!4:&4@;F%M92!T;R!U<V4@=VAE;B!S=&]R:6YG(&EN('1H92!S
M97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@24U!4%]4<F5E("!4:&4@
M24U!4%]4<F5E(&]B:F5C="!O<B!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F<VEN9VQE=&]N*"1A<'`L("1C;&%S<VYA;64L("1C<F5A=&4@/2!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@)&EN:70@/2!)34%05%)%15])
M3DE47U-50BP@)&-A8VAE;F%M92`]("=I;6%P=')E92<I"B`@("!["B`@("`@
M("`@<W1A=&EC("1I;G-T86YC92`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI
M<W-E="@D:6YS=&%N8V5;)&%P<%TI*2!["B`@("`@("`@("`@(')E='5R;B`D
M:6YS=&%N8V5;)&%P<%T["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1?4T534TE/3ELD87!P75LD8V%C:&5N86UE72DI('L*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]397-S:6]N3V)J96-T<RYP:'`G.PH@("`@
M("`@("`@("`D8V%C:&5397-S(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS
M:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&EN<W1A;F-E6R1A<'!=(#T@)B1C
M86-H95-E<W,M/G%U97)Y*"1?4T534TE/3ELD87!P75LD8V%C:&5N86UE72D[
M"B`@("`@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y
M*"8D:6YS=&%N8V5;)&%P<%TL("=?<W1O<F4G*2D["B`@("`@("`@?2!E;'-E
M:68@*"1C<F5A=&4I('L*("`@("`@("`@("`@)&EN<W1A;F-E6R1A<'!=(#T@
M)FYE=R`D8VQA<W-N86UE*"1I;FET+"`D8V%C:&5N86UE*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5;)&%P<%T["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:6YI="`@("`@(%1H92!I;FET:6%L:7IA=&EO;B!M;V1E('1O
M('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)&-A8VAE;F%M92`@5&AE(&YA
M;64@=&\@=7-E('=H96X@<W1O<FEN9R!I;B!T:&4@<V5S<VEO;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@24U!4%]4<F5E*"1I;FET(#T@24U!4%12145?24Y)
M5%]354(L("1C86-H96YA;64@/2`G:6UA<'1R964G*0H@("`@>PH@("`@("`@
M(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U]S
M=&]R92<I*3L*("`@("`@("`D=&AI<RT^7V-A8VAE;F%M92`]("1C86-H96YA
M;64["B`@("`@("`@)'1H:7,M/FEN:70H)&EN:70I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4W1O<F4@82!S97)I86QI>F5D('9E<G-I;VX@;V8@;W5R<V5L
M9B!I;B!T:&4@8W5R<F5N="!S97-S:6]N+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<W1O<F4H*0H@("`@
M>PH@("`@("`@("\J(%=E(&]N;'D@;F5E9"!T;R!R97-T;W)E('1H92!O8FIE
M8W0@:68@=&AE('1R964@:&%S(&-H86YG960N("HO"B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7V-H86YG960I*2!["B`@("`@("`@("`@("\J($1O;B=T
M('-T;W)E("1?97AP86YD960@86YD("1?<&]L;"`M('1H97-E('9A;'5E<R!A
M<F4@:&%N9&QE9`H@("`@("`@("`@("`@*B!B>2!T:&4@<W5B8VQA<W-E<RX*
M("`@("`@("`@("`@("H@1&]N)W0@<W1O<F4@)%]I;6%P7W-O<G0@;W(@)%]E
M;'1D:69F("T@=&AI<R!N965D<R!T;R!B90H@("`@("`@("`@("`@*B!R96=E
M;F5R871E9"!F;W(@96%C:"!R97%U97-T+@H@("`@("`@("`@("`@*B!$;VXG
M="!S=&]R92`D7V-U<G)K97DL("1?8W5R<G!A<F5N="P@86YD("1?8W5R<E-T
M86-K('-I;F-E('1H90H@("`@("`@("`@("`@*B!U<V5R($U54U0@8V%L;"!R
M97-E="@I(&)E9F]R92!C>6-L:6YG('1H<F]U9V@@=&AE('1R964N"B`@("`@
M("`@("`@("`J(%)E<V5T('1H92`D7V-H86YG960@9FQA9RX@*B\*("`@("`@
M("`@("`@)'1H:7,M/E]C=7)R:V5Y(#T@)'1H:7,M/E]C=7)R<&%R96YT(#T@
M)'1H:7,M/E]E;'1D:69F(#T@)'1H:7,M/E]E>'!A;F1E9"`]("1T:&ES+3Y?
M:6UA<%]S;W)T(#T@)'1H:7,M/E]P;VQL(#T@;G5L;#L*("`@("`@("`@("`@
M)'1H:7,M/E]C=7)R4W1A8VL@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=&AI
M<RT^7V-H86YG960@/2!F86QS93L*"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O4V5S<VEO;D]B:F5C=',N<&AP)SL*("`@("`@("`@("`@)&-A
M8VAE4V5S<R`]("9(;W)D95]397-S:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D[
M"@H@("`@("`@("`@("`O*B!2975S92!O;&0@<V5S<VEO;B!)1"!I9B!P;W-S
M:6)L92X@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELD=&AI
M<RT^7V%P<%U;)'1H:7,M/E]C86-H96YA;65=*2D@>PH@("`@("`@("`@("`@
M("`@)&-A8VAE4V5S<RT^;W9E<G=R:71E*"1?4T534TE/3ELD=&AI<RT^7V%P
M<%U;)'1H:7,M/E]C86-H96YA;65=+"`D=&AI<RP@9F%L<V4I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D7U-%
M4U-)3TY;)'1H:7,M/E]A<'!=*2D@>PH@("`@("`@("`@("`@("`@("`@("1?
M4T534TE/3ELD=&AI<RT^7V%P<%T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?87!P75LD
M=&AI<RT^7V-A8VAE;F%M95T@/2`D8V%C:&5397-S+3YS=&]R94]I9"@D=&AI
M<RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@;V8@9F]L9&5R<R]M86EL8F]X
M97,@;6%T8VAI;F<@82!C97)T86EN('!A=&@N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE(&UA:6QB;W@@<&%T:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!(&QI<W0@;V8@;6%I;&)O>%]O8FIE8W1S('=H;W-E(&YA;64@;6%T
M8VAE9"`D<&%T:"X*("`@("`J("`@("`@("`@("`@("`@(%1H92!S97)V97(@
M<W1R:6YG(&AA<R!B965N(')E;6]V960@9G)O;2!T:&4@;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=$QI<W0H)'!A=&@I"B`@("!["B`@("`@("`@
M)'5N:7%U92`](&%R<F%Y*"D["@H@("`@("`@(&EF("@A)'1H:7,M/E]S:&]W
M=6YS=6(I('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET4W5B<V-R:6)E9"@I
M.PH@("`@("`@('T*("`@("`@("`D;F5W8F]X97,@/2!`:6UA<%]G971M86EL
M8F]X97,H)'1H:7,M/E]G9713=')E86TH*2P@)'1H:7,M/E]S97)V97(L("1P
M871H*3L*("`@("`@("!I9B`H:7-?87)R87DH)&YE=V)O>&5S*2D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D;F5W8F]X97,@87,@)&)O>"D@>PH@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?<VAO=W5N<W5B('Q\"B`@("`@("`@("`@
M("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?<W5B<V-R:6)E9%LD8F]X+3YN86UE
M72DI('L*("`@("`@("`@("`@("`@("`@("`O*B!3=')I<"!O9F8@<V5R=F5R
M('-T<FEN9RX@*B\*("`@("`@("`@("`@("`@("`@("`D8F]X(#T@)'1H:7,M
M/E]R96UO=F5397)V97)3=')I;F<H)&)O>"D["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1B;W@M/FYA;64@)B8@(6ES<V5T*"1U;FEQ=65;)&)O>"T^;F%M
M95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1U;FEQ=65;)&)O>"T^
M;F%M95T@/2`D8F]X.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1U;FEQ=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME(&$@<VEN
M9VQE(&UA:6QB;W@@=')E92!E;&5M96YT+@H@("`@("H@06X@96QE;65N="!C
M;VYS:7-T<R!O9B!T:&4@9F]L;&]W:6YG(&ET96US("AW92!U<V4@<VEN9VQE
M(&QE='1E<G,@:&5R90H@("`@("H@=&\@<V%V92!I;B!S97-S:6]N('-T;W)A
M9V4@<W!A8V4I.@H@("`@("H@("`G82<@("TM("!!='1R:6)U=&5S"B`@("`@
M*B`@("=C)R`@+2T@($QE=F5L(&-O=6YT"B`@("`@*B`@("=L)R`@+2T@($QA
M8F5L"B`@("`@*B`@("=P)R`@+2T@(%!A<F5N="!N;V1E"B`@("`@*B`@("=V
M)R`@+2T@(%9A;'5E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="!S=&1#;&%S<R`D;V(@(%1H92!O
M8FIE8W0@<F5T=7)N960@8GD@:6UA<%]G971M86EL8F]X97,H*2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!3964@9F]R;6%T(&%B;W9E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?;6%K94UA:6QB;WA4<F5E16QT*"1O8BD*("`@
M('L*("`@("`@("`D96QT6R=A)UT@/2`D;V(M/F%T=')I8G5T97,["B`@("`@
M("`@)&5L=%LG8R==(#T@,#L*("`@("`@("`D96QT6R=P)UT@/2!)34%05%)%
M15]"05-%7T5,5#L*("`@("`@("`D96QT6R=V)UT@/2`D;V(M/FYA;64["@H@
M("`@("`@("\J(%-E="!S=6)S8W)I8F5D('9A;'5E<RX@36%K92!S=7)E($E.
M0D]8(&ES(&%L=V%Y<R!S=6)S8W)I8F5D"B`@("`@("`@("H@=&\@*&EF('=O
M<FMI;F<@=VET:"!M86EL*2!S;R!T:&5R92!I<R!A;'=A>7,@870@;&5A<W0@
M,0H@("`@("`@("`J('9I97=A8FQE(&5L96UE;G0N("HO"B`@("`@("`@:68@
M*"1E;'1;)W8G72`]/2`G24Y"3U@G*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<V5T4W5B<V-R:6)E9"@D96QT+"!T<G5E*3L*("`@("`@("!](&5L<V5I9B`H
M(21T:&ES+3YI<U-U8G-C<FEB960H)&5L="DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]I;FET4W5B<V-R:6)E9"@I.PH@("`@("`@("`@("`D=&AI<RT^7W-E
M=%-U8G-C<FEB960H)&5L="P@:7-S970H)'1H:7,M/E]S=6)S8W)I8F5D6R1E
M;'1;)W8G75TI*3L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O<B!P
M;VQL960@<W1A='5S+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/FES4&]L;&5D
M*"1E;'0I*2!["B`@("`@("`@("`@("1T:&ES+3YG9710;VQL3&ES="@I.PH@
M("`@("`@("`@("`D=&AI<RT^7W-E=%!O;&QE9"@D96QT+"!I<W-E="@D=&AI
M<RT^7W!O;&Q;)&5L=%LG=B==72DI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0VAE8VL@9F]R(&]P96X@<W1A='5S+B`J+PH@("`@("`@("1T:&ES+3Y?<V5T
M3W!E;B@D96QT+"`D=&AI<RT^:7-/<&5N*"1E;'0I*3L*"B`@("`@("`@+RH@
M0V]M<'5T960@=F%L=65S+B`J+PH@("`@("`@("1N<U]I;F9O(#T@)'1H:7,M
M/E]G971.86UE<W!A8V4H)&5L=%LG=B==*3L*("`@("`@("`D=&UP(#T@97AP
M;&]D92@H:7-?;G5L;"@D;G-?:6YF;RDI(#\@)'1H:7,M/E]D96QI;6ET97(@
M.B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTL("1E;'1;)W8G72D["B`@("`@("`@
M)&5L=%LG8R==(#T@8V]U;G0H)'1M<"D@+2`Q.PH@("`@("`@("1L86)E;"`]
M("1E;'1;)V,G73L*("`@("`@("!I9B`H(65M<'1Y*"1E;'1;)V,G72D@)B8*
M("`@("`@("`@("`@(7!R96=?;6%T8V@H(B]<>RXJ<&]P,RXJ7'TO(BP@)&]B
M+3YF=6QL4V5R=F5R4&%T:"DI('L*("`@("`@("`@("`@)&5L=%LG<"==(#T@
M:6UP;&]D92@H:7-?;G5L;"@D;G-?:6YF;RDI(#\@)'1H:7,M/E]D96QI;6ET
M97(@.B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTL(&%R<F%Y7W-L:6-E*"1T;7`L
M(#`L("1E;'1;)V,G72DI.PH@("`@("`@("`@("`O*B!3=')I<"!P97)S;VYA
M;"!N86UE<W!A8V4N("HO"B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D;G-?
M:6YF;RD@)B8*("`@("`@("`@("`@("`@("%E;7!T>2@D;G-?:6YF;ULG;F%M
M92==*2`F)@H@("`@("`@("`@("`@("`@*"1N<U]I;F9O6R=T>7!E)UT@/3T@
M)W!E<G-O;F%L)RDI('L*("`@("`@("`@("`@("`@("1E;'1;)V,G72TM.PH@
M("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D96QT6R=P)UTL("1N<U]I;F9O
M6R=D96QI;6ET97(G72D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@
M("`@)&5L=%LG<"==(#T@24U!4%12145?0D%315]%3%0["B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H<W1R<&]S*"1E;'1;)W8G72P@)&YS7VEN9F];)VYA
M;64G72`N("=)3D)/6"<@+B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTI(#T]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)&5L=%LG<"==(#T@)TE.0D]8)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("`D96QT6R=L)UT@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1T;7!;
M)&QA8F5L72P@)U541C<M24U!4"<I.PH*("`@("`@("!R971U<FX@)&5L=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($EN:71A;&EZ92!T:&4@;&ES="!A="!T
M:&4@=&]P(&QE=F5L(&]F('1H92!H:65R87)C:'DN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&EN:70@(%1H92!I;FET:6%L:7IA=&EO;B!M;V1E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;FET*"1I;FET*0H@("`@>PH@("`@
M("`@("\J(%)E<V5T(&%L;"!C;&%S<R!V87)I86)L97,@=&\@=&AE(&1E9F%U
M;'1S+B`J+PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@
M("`@)'1H:7,M/E]C=7)R:V5Y(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7V-U
M<G)P87)E;G0@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?8W5R<G-T86-K(#T@
M87)R87DH*3L*("`@("`@("`D=&AI<RT^7W1R964@/2!A<G)A>2@I.PH@("`@
M("`@("1T:&ES+3Y?<&%R96YT(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M7W-H;W=U;G-U8B`]("1T:&ES+3Y?=6YS=6)V:65W(#T@*"1I;FET("8@24U!
M4%12145?24Y)5%]53E-50BD["B`@("`@("`@)'1H:7,M/E]S=6)S8W)I8F5D
M(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7W5N<W5B<V-R:6)E9"`](&YU;&P[
M"@H@("`@("`@("\J(%-E="!I;FET:6%L:7IA=&EO;B!M;V1E+B`J+PH@("`@
M("`@("1T:&ES+3Y?:6YI=&UO9&4@/2`D:6YI=#L*"B`@("`@("`@+RH@1V5T
M('1H92!I;FET:6%L(&QI<W0@;V8@;6%I;&)O>&5S(&9R;VT@=&AE('-U8F-L
M87-S+B`J+PH@("`@("`@("1B;WAE<R`]("1T:&ES+3Y?:6YI="@I.PH*("`@
M("`@("`O*B!#<F5A=&4@82!P;&%C96AO;&1E<B!E;&5M96YT('1O('1H92!B
M87-E(&]F('1H92!T<F5E(&QI<W0@<V\@=V4@8V%N"B`@("`@("`@("H@:V5E
M<"!T<F%C:R!O9B!W:&5T:&5R('1H92!B87-E(&QE=F5L(&YE961S('1O(&)E
M('-O<G1E9"X@*B\*("`@("`@("`D=&AI<RT^7W1R965;24U!4%12145?0D%3
M15]%3%1=(#T@87)R87DH)V$G(#T^($E-05!44D5%7T5,5%])4U]$25-#3U9%
M4D5$*3L*"B`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E(&%L;"!N86UE
M<W!A8V4@96QE;65N=',@87)E(&EN('1H92!T<F5E+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^7VYA;65S<&%C97,I('L*("`@("`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]N86UE<W!A8V5S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@:68@*"1V86Q;)W1Y<&4G72`A/2`G<&5R<V]N86PG*2!["B`@
M("`@("`@("`@("`@("`@("`@)&YA;64@/2!S=6)S='(H)&ME>2P@,"P@+3$@
M*B!S=')L96XH)'9A;%LG9&5L:6UI=&5R)UTI*3L*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=')E95LD=F%L6R=N86UE)UU=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D;V(@/2`F;F5W('-T9$-L87-S
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D;V(M/F1E;&EM:71E<B`]("1V
M86Q;)V1E;&EM:71E<B==.PH@("`@("`@("`@("`@("`@("`@("`@("`D;V(M
M/F%T=')I8G5T97,@/2!,05147TY/4T5,14-4('P@24U!4%12145?14Q47TY!
M34534$%#13L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@)&]B+3YF=6QL
M4V5R=F5R4&%T:"!I<R!N;W0@8V]M<&QE=&5L>2!S970@:&5R92X@*B\*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]B+3YF=6QL4V5R=F5R4&%T:"`]("1O
M8BT^;F%M92`]("1N86UE.PH@("`@("`@("`@("`@("`@("`@("`@("`D96QT
M(#T@)'1H:7,M/E]M86ME36%I;&)O>%1R965%;'0H)&]B*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I;G-E<G1%;'0H)&5L="D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AE(&QI<W0@*$E.
M0D]8(&%N9"!A;GD@;W1H97(@:&EE<F%R8VAI97,I+B`J+PH@("`@("`@("1T
M:&ES+3Y?861D3&5V96PH)&)O>&5S*3L*"B`@("`@("`@+RH@16YD(&EN:71I
M86QI>F%T:6]N(&UO9&4N("HO"B`@("`@("`@)'1H:7,M/E]I;FET;6]D92`]
M(#`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=6)C;&%S<R!S<&5C:69I8R!I
M;FET:6%L:7IA=&EO;B!T87-K<RX*("`@("`J(%1(25,@34542$]$($U54U0@
M0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@:6YI=&EA;"!L:7-T(&]F(&5L
M96UE;G1S('1O(&%D9"!T;R!T:&4@=')E92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7VEN:70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@17AP86YD(&$@;6%I;"!F;VQD97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]L9&5R("`@("`@5&AE(&9O;&1E
M<B!N86UE('1O(&5X<&%N9"X*("`@("`J($!P87)A;2!B;V]L96%N("1E>'!A
M;F1A;&P@($5X<&%N9"!A;&P@9F]L9&5R<R!U;F1E<B!T:&ES(&]N93\*("`@
M("`J+PH@("`@9G5N8W1I;VX@97AP86YD*"1F;VQD97(L("1E>'!A;F1A;&P@
M/2!F86QS92D*("`@('L*("`@("`@("`D9F]L9&5R(#T@)'1H:7,M/E]C;VYV
M97)T3F%M92@D9F]L9&5R*3L*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W1R965;)&9O;&1E<ETI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["@H@("`@("`@
M("\J($UE<F=E(&EN(&YE>'0@;&5V96P@;V8@:6YF;W)M871I;VXN("HO"B`@
M("`@("`@:68@*"1T:&ES+3YH87-#:&EL9')E;B@D=&AI<RT^7W1R965;)&9O
M;&1E<ETI*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/FES1&ES8V]V97)E
M9"@D=&AI<RT^7W1R965;)&9O;&1E<ETI*2!["B`@("`@("`@("`@("`@("`D
M:6YF;R`]("1T:&ES+3Y?8VAI;&1R96Y);F9O*"1F;VQD97(I.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D:6YF;RDI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]I;FET;6]D92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H*"1T:&ES+3Y?:6YI=&UO9&4@)B!)34%05%)%15])3DE4
M7T9%5$-(04Q,*2!\?`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FES3W!E;B@D=&AI<RT^7W1R965;)&9O;&1E<ETI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$QE=F5L*"1I;F9O*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D
M3&5V96PH)&EN9F\I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-E=$]P96XH)'1H:7,M/E]T<F5E6R1F;VQD97)=+"!T<G5E*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H(2@D=&AI<RT^7VEN:71M
M;V1E("8@24U!4%12145?24Y)5%]&151#2$%,3"DI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M/E]T<F5E6R1F;VQD97)=
M+"!T<G5E*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M*B!%>'!A;F0@86QL(&-H:6QD<F5N(&)E;F5A=&@@=&AI<R!O;F4N("HO"B`@
M("`@("`@("`@("`@("!I9B`H)&5X<&%N9&%L;"`F)B`A96UP='DH)'1H:7,M
M/E]P87)E;G1;)&9O;&1E<ETI*2!["B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]P87)E;G1;)&9O;&1E<ET@87,@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97AP86YD*"1T:&ES+3Y?=')E
M95LD=F%L75LG=B==+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VQL87!S92!A(&UA:6P@9F]L9&5R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!N
M86UE('1O(&-O;&QA<'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VQL87!S
M92@D9F]L9&5R*0H@("`@>PH@("`@("`@("1F;VQD97(@/2`D=&AI<RT^7V-O
M;G9E<G1.86UE*"1F;VQD97(I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?=')E95LD9F]L9&5R72DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D(#T@=')U93L*"B`@("`@
M("`@+RH@4V5T('1H92!F;VQD97(@871T<FEB=71E<R!T;R!N;W0@97AP86YD
M960N("HO"B`@("`@("`@)'1H:7,M/E]S971/<&5N*"1T:&ES+3Y?=')E95LD
M9F]L9&5R72P@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T
M:&4@:6YT97)N86P@87)R87D@<&]I;G1E<B!T;R!T:&4@;F5X="!E;&5M96YT
M+"!A;F0@<F5T=7)N<R!T:&4*("`@("`J(&YE>'0@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1M87-K("!!(&UA<VL@=VET:"!T:&4@
M9F]L;&]W:6YG(&5L96UE;G1S.@H@("`@("H@/'!R93X*("`@("`J($E-05!4
M4D5%7TY%6%1?4TA/5T-,3U-%1"`M($1O;B=T(&EG;F]R92!C;&]S960@96QE
M;65N=',N"B`@("`@*B!)34%05%)%15].15A47U-(3U=354(@+2!/;FQY('-H
M;W<@<W5B<V-R:6)E9"!E;&5M96YT<RX*("`@("`J(#PO<')E/@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%)E='5R;G,@=&AE(&YE>'0@96QE;65N
M="!O<B!F86QS92!I9B!T:&4@96QE;65N="!D;V5S;B=T"B`@("`@*B`@("`@
M("`@("`@("`@("!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X="@D
M;6%S:R`](#`I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]C
M=7)R:V5Y*2`F)B!I<U]N=6QL*"1T:&ES+3Y?8W5R<G!A<F5N="DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&-U
M<G(@/2`D=&AI<RT^8W5R<F5N="@I.PH*("`@("`@("`D;VQD7W-H;W=U;G-U
M8B`]("1T:&ES+3Y?<VAO=W5N<W5B.PH@("`@("`@(&EF("@D;6%S:R`F($E-
M05!44D5%7TY%6%1?4TA/5U-50BD@>PH@("`@("`@("`@("`D=&AI<RT^7W-H
M;W=U;G-U8B`](&9A;'-E.PH@("`@("`@('T*("`@("`@(`H@("`@("`@(&EF
M("@D=&AI<RT^7V%C=&EV945L="@D8W5R<BD@)B8*("`@("`@("`@("`@*"@D
M;6%S:R`F($E-05!44D5%7TY%6%1?4TA/5T-,3U-%1"D@?'P@)'1H:7,M/FES
M3W!E;B@D8W5R<BDI("8F"B`@("`@("`@("`@("@D=&AI<RT^7V-U<G)P87)E
M;G0@(3T@)&-U<G);)W8G72DI('L*("`@("`@("`@("`@+RH@268@=&AE(&-U
M<G)E;G0@96QE;65N="!I<R!O<&5N+"!A;F0@8VAI;&1R96X@97AI<W0L(&UO
M=F4@:6YT;PH@("`@("`@("`@("`@*B!I="X@*B\*("`@("`@("`@("`@)'1H
M:7,M/E]C=7)R<W1A8VM;72`](&%R<F%Y*"=K)R`]/B`D=&AI<RT^7V-U<G)K
M97DL("=P)R`]/B`D=&AI<RT^7V-U<G)P87)E;G0I.PH@("`@("`@("`@("`D
M=&AI<RT^7V-U<G)K97D@/2`P.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)P
M87)E;G0@/2`D8W5R<ELG=B==.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]N
M965D4V]R="@D=&AI<RT^7W1R965;)&-U<G);)W8G75TI*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-O<G1,:7-T*"1T:&ES+3Y?<&%R96YT6R1C=7)R
M6R=V)UU=+"!I<U]N=6QL*"1C=7)R6R=V)UTI*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V5T3F5E9%-O<G0H)'1H:7,M/E]T<F5E6R1C=7)R6R=V)UU=
M+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T
M<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH@16QS92P@:6YC<F5M96YT('=I=&AI;B!T:&4@8W5R<F5N="!S=6)F
M;VQD97(N("HO"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<FME>2LK.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@=&AE('!O:6YT97(@9&]E<VXG="!P;VEN
M="!T;R!A;B!E;&5M96YT+"!T<GD@=&\@;6]V92!B86-K('1O"B`@("`@("`@
M("`@=&AE('!R979I;W5S('-U8F9O;&1E<BX@($EF('1H97)E(&ES(&YO('!R
M979I;W5S('-U8F9O;&1E<BP*("`@("`@("`@("!R971U<FX@9F%L<V4N("HO
M"B`@("`@("`@)&-U<G(@/2`D=&AI<RT^8W5R<F5N="@I.PH@("`@("`@(&EF
M("@A)&-U<G(@)B8*("`@("`@("`@("`@*"1M87-K("8@24U!4%12145?3D58
M5%]32$]70TQ/4T5$*2`F)@H@("`@("`@("`@("`A)'1H:7,M/FES1&ES8V]V
M97)E9"@D=&AI<RT^7W1R965;)'1H:7,M/E]C=7)R<&%R96YT72D@)B8*("`@
M("`@("`@("`@)'1H:7,M/FAA<T-H:6QD<F5N*"1T:&ES+3Y?=')E95LD=&AI
M<RT^7V-U<G)P87)E;G1=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%D9$QE
M=F5L*"1T:&ES+3Y?8VAI;&1R96Y);F9O*"1T:&ES+3Y?=')E95LD=&AI<RT^
M7V-U<G)P87)E;G1=6R=V)UTI*3L*("`@("`@("`@("`@)&-U<G(@/2`D=&AI
M<RT^8W5R<F5N="@I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S:&]W
M=6YS=6(@/2`D;VQD7W-H;W=U;G-U8CL*"B`@("`@("`@:68@*"$D8W5R<BD@
M>PH@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]C=7)R<W1A8VLI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)K97D@/2!N=6QL.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C=7)R<&%R96YT(#T@;G5L;#L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&1O('L*("`@("`@("`@("`@("`@("`@("`D;VQD
M(#T@87)R87E?<&]P*"1T:&ES+3Y?8W5R<G-T86-K*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-U<G)K97D@/2`D;VQD6R=K)UT@*R`Q.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<G!A<F5N="`]("1O;&1;)W`G
M73L*("`@("`@("`@("`@("`@('T@=VAI;&4@*"@H)&-U<G(@/2`D=&AI<RT^
M8W5R<F5N="@I*2`]/2!F86QS92D@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`@(&-O=6YT*"1T:&ES+3Y?8W5R<G-T86-K*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/E]A8W1I=F5%;'0H)&-U
M<G(I*2!["B`@("`@("`@("`@("\J(%-K:7`@=&AI<R!E;G1R>2!I9CH*("`@
M("`@("`@("`@("H@,2X@5V4@87)E(&YO="!S:&]W:6YG(&%L;"!E;&5M96YT
M<PH@("`@("`@("`@("`@*B`R+B!792!A<F4@;F]T('-U8G-C<FEB960@=&\@
M=&AI<R!E;&5M96YT"B`@("`@("`@("`@("`J(#,N($ET(&ES(&YO="!A(&-O
M;G1A:6YE<B`M3U(M+"!I9B!I="!I<R!A(&-O;G1A:6YE<BP@:68@=&AE<F4*
M("`@("`@("`@("`@("H@("`@87)E(&YO('9I97=A8FQE(&5L96UE;G1S('5N
M9&5R;F5A=&@@:70N"B`@("`@("`@("`@("`J(#0N(%1H:7,@:7,@86X@96UP
M='D@;F%M97-P86-E(&5L96UE;G0N("HO"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;F5X="@D;6%S:RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&-U<G(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@:6YT97)N86P@<&]I
M;G1E<B!T;R!T:&4@:&5A9"!O9B!T:&4@=')E92X*("`@("`J(%1H:7,@3553
M5"!B92!C86QL960@8F5F;W)E('EO=2!C86X@=')A=F5R<V4@=&AE('1R964@
M=VET:"!N97AT*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4F5T
M=7)N<R!T:&4@96QE;65N="!A="!T:&4@:&5A9"!O9B!T:&4@=')E92!O<B!F
M86QS90H@("`@("H@("`@("`@("`@("`@("`@:68@=&AE(&5L96UE;G0@9&]E
M<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S970H*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?8W5R<FME>2`](#`["B`@("`@("`@)'1H:7,M
M/E]C=7)R<&%R96YT(#T@24U!4%12145?0D%315]%3%0["B`@("`@("`@)'1H
M:7,M/E]C=7)R<W1A8VL@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M
M/E]N965D4V]R="@D=&AI<RT^7W1R965;)'1H:7,M/E]C=7)R<&%R96YT72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]S;W)T3&ES="@D=&AI<RT^7W!A<F5N
M=%LD=&AI<RT^7V-U<G)P87)E;G1=+"!I<U]N=6QL*"1T:&ES+3Y?8W5R<G!A
M<F5N="DI.PH@("`@("`@("`@("`D=&AI<RT^7W-E=$YE9613;W)T*"1T:&ES
M+3Y?=')E95LD=&AI<RT^7V-U<G)P87)E;G1=+"!F86QS92D["B`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@
M("`O*B!7:&5N(')E<V5T=&EN9R!I;B!N97=S(&UO9&4L('1H92!F:7)S="!E
M;&5M96YT(&UA>2!N;W0@8F4*("`@("`@("`@*B!V:65W86)L92`H=6YL:6ME
M(&UA:6P@;6]D92P@=VAE<F4@=&AE(&9I<G-T(&5L96UE;G0@:7,@24Y"3U@@
M86YD"B`@("`@("`@("H@:7,@86QW87ES('9I97=A8FQE*2X@(%1H97)E9F]R
M92P@=V4@;F5E9"!T;R!S96%R8V@@9F]R('1H92!F:7)S=`H@("`@("`@("`J
M('9I97=A8FQE(&ET96T@86YD('1H870@=VEL;"!B92!T:&4@8F%S92!O9B!T
M:&4@=FEE=V%B;&4@=')E92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]M;V1E
M(#T]($E-05!44D5%7TU/1$5?3D574RD@>PH@("`@("`@("`@("`D8W5R<B`]
M("1T:&ES+3YC=7)R96YT*"D["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]A
M8W1I=F5%;'0H)&-U<G(I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;F5X
M="@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/F-U<G)E;G0H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@8W5R<F5N="!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@5&AE(&-U<G)E;G0@=')E92!E;&5M96YT(&]R(&9A;'-E
M(&EF('1H97)E(&ES(&YO"B`@("`@*B`@("`@("`@("`@("`@("!E;&5M96YT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C=7)R96YT*"D*("`@('L*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R96YT6R1T:&ES+3Y?8W5R<G!A<F5N
M=%U;)'1H:7,M/E]C=7)R:V5Y72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?861D06QI
M87-E<R@D=&AI<RT^7W1R965;)'1H:7,M/E]P87)E;G1;)'1H:7,M/E]C=7)R
M<&%R96YT75LD=&AI<RT^7V-U<G)K97E=72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$971E<FUI;F5S(&EF('1H97)E(&%R92!M;W)E(&5L96UE;G1S(&EN
M('1H92!C=7)R96YT('1R964@;&5V96PN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H97)E(&%R92!M;W)E(&5L96UE;G1S+"!F
M86QS92!I9B!T:&ES(&ES('1H90H@("`@("H@("`@("`@("`@("`@("`@("!L
M87-T(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!E96LH*0H@("`@
M>PH@("`@("`@(&9O<B`H)&D@/2`H)'1H:7,M/E]C=7)R:V5Y("L@,2D[(#L@
M)&DK*RD@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R96YT
M6R1T:&ES+3Y?8W5R<G!A<F5N=%U;)&E=*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V%C=&EV945L="@D=&AI<RT^7V%D9$%L:6%S97,H)'1H:7,M/E]T
M<F5E6R1T:&ES+3Y?<&%R96YT6R1T:&ES+3Y?8W5R<G!A<F5N=%U;)&E=72DI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@86QI87-E
M<R!T;R!A('1R964@96QE;65N="!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT:6YG
M(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@=')E92!E;&5M96YT('=I
M=&@@=&AE(&%L:6%S97,@861D960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A
M9&1!;&EA<V5S*"1E;'0I"B`@("!["B`@("`@("`@)&5L=%LG;&%B96PG72`]
M("1E;'1;)VPG73L*("`@("`@("`D96QT6R=L979E;"==(#T@)&5L=%LG8R==
M.PH@("`@("`@("1E;'1;)W!A<F5N="==(#T@)&5L=%LG<"==.PH@("`@("`@
M("1E;'1;)W9A;'5E)UT@/2`D96QT6R=V)UT["@H@("`@("`@(')E='5R;B`D
M96QT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<F5Q=65S
M=&5D(&5L96UE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&YA;64@;V8@=&AE('1R964@96QE;65N="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!2971U<FYS('1H92!R97%U97-T960@96QE;65N
M="!O<B!F86QS92!I9B!N;W0@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E="@D;F%M92D*("`@('L*("`@("`@("`D;F%M92`]("1T:&ES+3Y?8V]N
M=F5R=$YA;64H)&YA;64I.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T
M<F5E6R1N86UE72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?861D
M06QI87-E<R@D=&AI<RT^7W1R965;)&YA;65=*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@26YS97)T(&$@9F]L9&5R+VUA:6QB;W@@:6YT;R!T
M:&4@=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&ED("!4:&4@
M;F%M92!O9B!T:&4@9F]L9&5R("AO<B!A(&QI<W0@;V8@9F]L9&5R(&YA;65S
M*0H@("`@("H@("`@("`@("`@("`@("`@("`@=&\@861D("AM=7-T(&)E('!R
M97-E;G0@;VX@=&AE(&UA:6P@<V5R=F5R*2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN<V5R="@D:60I"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^7VYO;FEM87!E;'0I('L*("`@("`@("`@("`@("`@("\J(%=E('=A;G0@
M=&\@861D(&9R;VT@=&AE($)!4T4@;V8@=&AE('1R964@=7`@9F]R(&5F9FEC
M:65N8WD*("`@("`@("`@("`@("`@("`J('-A:V4N("HO"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-O<G1,:7-T*"1I9"D["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:60@/2!A<G)A>2@D:60I.PH@
M("`@("`@('T*"B`@("`@("`@)'-U8V-E<W,@/2!T<G5E.PH@("`@("`@(&9O
M<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@("`@("`@("`@("1C=7)R<W5C8V5S
M<R`]("1T:&ES+3Y?:6YS97)T*"1V86PL(#$I.PH@("`@("`@("`@("!I9B`H
M(21C=7)R<W5C8V5S<RD@>PH@("`@("`@("`@("`@("`@)'-U8V-E<W,@/2!F
M86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1S=6-C97-S.PH@("`@?0H*("`@("\J*@H@("`@("H@26YS97)T(&$@9F]L
M9&5R+VUA:6QB;W@@:6YT;R!T:&4@=')E92X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@
M("!4:&4@;F%M92!O9B!T:&4@9F]L9&5R('1O(&%D9"`H;75S="!B92!P<F5S
M96YT(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T:&4@;6%I;"!S
M97)V97(I+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<R`@0W5R<F5N="!D
M96QI;6ET97(@<&]S:71I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?:6YS97)T*"1I9"P@)'!O<RD*("`@('L*("`@("`@
M("`D=&AI<RT^7V-H86YG960@/2!T<G5E.PH*("`@("`@("`D;G-?:6YF;R`]
M("1T:&ES+3Y?9V5T3F%M97-P86-E*"1I9"D["@H@("`@("`@("\J($)R96%K
M(&%P87)T('1H92!N86UE('9I82!T:&4@9&5L:6UI=&5R(&%N9"!G;R!S=&5P
M(&)Y('-T97`@=&AR;W5G:`H@("`@("`@("`J('1H92!N86UE('1O(&UA:V4@
M<W5R92!A;&P@<W5B9F]L9&5R<R!E>&ES="!I;B!T:&4@=')E92X@*B\*("`@
M("`@("!I9B`H:7-?;G5L;"@D;G-?:6YF;RDI('L*("`@("`@("`@("`@)&)E
M9VEN(#T@)&ED.PH@("`@("`@("`@("`D;6]R92`](&9A;'-E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)&YS7VEN
M9F];)V1E;&EM:71E<B==+"`D:60I.PH@("`@("`@("`@("`D<&%R='-;,%T@
M/2`D=&AI<RT^7V-O;G9E<G1.86UE*"1P87)T<ULP72D["B`@("`@("`@("`@
M("1B96=I;B`](&EM<&QO9&4H)&YS7VEN9F];)V1E;&EM:71E<B==+"!A<G)A
M>5]S;&EC92@D<&%R=',L(#`L("1P;W,I*3L*("`@("`@("`@("`@)&UO<F4@
M/2`H8V]U;G0H)'!A<G1S*2`^("1P;W,I.PH@("`@("`@('T*"B`@("`@("`@
M)&ES8V]N=&%I;F5R(#T@*&ES<V5T*"1T:&ES+3Y?=')E95LD8F5G:6Y=*2`F
M)B`D=&AI<RT^:7-#;VYT86EN97(H)'1H:7,M/E]T<F5E6R1B96=I;ETI*2`_
M("1T:&ES+3Y?=')E95LD8F5G:6Y=(#H@9F%L<V4["@H@("`@("`@(&EF("@H
M)'1H:7,M/E]M;V1E("$]($E-05!44D5%7TU/1$5?3D574RD@)B8*("`@("`@
M("`@("`@*"%I<W-E="@D=&AI<RT^7W1R965;)&)E9VEN72D@?'P@)&ES8V]N
M=&%I;F5R*2`F)@H@("`@("`@("`@("`H:7-?;G5L;"@D;G-?:6YF;RD@?'P@
M*"@D8F5G:6X@+B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTI("$]("1N<U]I;F9O
M6R=N86UE)UTI*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]N;VYI;6%P
M96QT*2!["B`@("`@("`@("`@("`@("`D96QT(#T@)'1H:7,M/E]G971.;VY)
M34%016QT*"1B96=I;BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D;V(@/2`D=&AI<RT^7V=E=$QI<W0H)&)E9VEN*3L*("`@("`@
M("`@("`@("`@("1E;'0@/2`D=&AI<RT^7VUA:V5-86EL8F]X5')E945L="AR
M97-E="@D;V(I*3L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES4W5B
M<V-R:6)E9"@D96QT*2D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!`
M:6UA<%]L<W5B*"1T:&ES+3Y?9V5T4W1R96%M*"DL("1T:&ES+3Y?<V5R=F5R
M+"`D96QT6R=V)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)'1M<"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S9713
M=6)S8W)I8F5D*"1E;'0L('1R=64I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?:6YS97)T16QT*"1E;'0I*2!["B`@("`@("`@("`@("`@
M("`O*B!792!K;F]W('1H870@=&AE('!A<F5N="!F;VQD97(@:&%S(&-H:6QD
M<F5N+B`J+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=')E
M95LD96QT6R=P)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V5T0VAI;&1R96XH)'1H:7,M/E]T<F5E6R1E;'1;)W`G75TL('1R=64I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J($UA:V4@<W5R
M92!W92!A<F4@<V]R=&5D(&-O<G)E8W1L>2X@*B\*("`@("`@("`@("`@("`@
M(&EF("AC;W5N="@D=&AI<RT^7W!A<F5N=%LD96QT6R=P)UU=*2`^(#$I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$YE9613;W)T*"1T:&ES
M+3Y?=')E95LD96QT6R=P)UU=+"!T<G5E*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`O*B!!9&0@=&\@<W5B<V-R:6)E9"]U;G-U8G-C
M<FEB960@;&ES="X@*B\*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-3
M=6)S8W)I8F5D*"1E;'0I("8F("%I<U]N=6QL*"1T:&ES+3Y?<W5B<V-R:6)E
M9"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-U8G-C<FEB961;
M)&5L=%LG=B==72`](#$["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(21T
M:&ES+3YI<U-U8G-C<FEB960H)&5L="D@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@("`A:7-?;G5L;"@D=&AI<RT^7W5N<W5B<V-R:6)E9"DI('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W5N<W5B<V-R:6)E9%LD96QT6R=V
M)UU=(#T@,3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M*B!)9B!T:&ES(&5L96UE;G0@=V%S(&$@8V]N=&%I;F5R+"!M86EN=&%I;B!T
M:&4@;VQD(&5X<&%N9&5D"B`@("`@("`@("`@("`@("`@*B!V86QU92X@*B\*
M("`@("`@("`@("`@("`@(&EF("@D:7-C;VYT86EN97(I('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M/E]T<F5E6R1E;'1;
M)W8G75TL("1T:&ES+3YI<T]P96XH)&ES8V]N=&%I;F5R*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@D;6]R92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;G-E<G0H
M)&ED+"`K*R1P;W,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G-E<G0@86X@96QE;65N="!I;G1O
M('1H92!T<F5E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!4:&4@96QE;65N="!T;R!I
M;G-E<G0N(%1H92!K97D@:6X@=&AE('1R964@:7,@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@)W8G("AV86QU92D@96QE;65N="!O9B!T:&4@96QE
M;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M861D960@=&\@=&AE('1R964N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;G-E
M<G1%;'0H)&5L="D*("`@('L*("`@("`@("`O*B!$;VXG="!I;F-L=61E('1H
M92!P87)E;G0@9&ER96-T;W)I97,@=&AA="!55R!P87-S97,@8F%C:R!I;@H@
M("`@("`@("`@("4O)2!L:7-T<RX*("`@("`@("`@("!43T1/.B!296UO=F4@
M9&]T9FEL97,@9FEL=&5R(&EN(&YE>'0@;6%J;W(@<F5L96%S92X@*B\*("`@
M("`@("!I9B`H<W1R;&5N*"1E;'1;)VPG72D@)B8*("`@("`@("`@("`@*"%I
M<W-E="@D=&AI<RT^7W1R965;)&5L=%LG=B==72D@?'P*("`@("`@("`@("`@
M("1T:&ES+3YI<T-O;G1A:6YE<B@D=&AI<RT^7W1R965;)&5L=%LG=B==72DI
M("8F"B`@("`@("`@("`@("@D=&AI<RT^7V1O=&9I;&5S('Q\("@D96QT6R=L
M)UU;,%T@(3T@)RXG*2DI('L*("`@("`@("`@("`@+RH@4V5T('1H92!P87)E
M;G0@87)R87D@=&\@=&AE('9A;'5E(&EN("1E;'1;)W`G72X@*B\*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R96YT6R1E;'1;)W`G75TI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F5N=%LD96QT6R=P)UU=(#T@
M87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W!A
M<F5N=%LD96QT6R=P)UU=6UT@/2`D96QT6R=V)UT["B`@("`@("`@("`@("1T
M:&ES+3Y?=')E95LD96QT6R=V)UU=(#T@)&5L=#L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T
M92!A;B!E;&5M96YT(&9R;VT@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1I9"`@5&AE(&5L96UE;G0@;F%M92!O<B!A;B!A<G)A>2!O
M9B!E;&5M96YT(&YA;65S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@4F5T=7)N('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T92@D:60I"B`@("!["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@+RH@5V4@=V%N="!T
M;R!D96QE=&4@9G)O;2!T:&4@5$]0(&]F('1H92!T<F5E(&1O=VX@=&\@96YS
M=7)E('1H870*("`@("`@("`@("`@("H@<&%R96YT<R!H879E(&%N(&%C8W5R
M871E('9I97<@;V8@=VAA="!C:&EL9')E;B!A<F4@;&5F="X@*B\*("`@("`@
M("`@("`@)'1H:7,M/E]S;W)T3&ES="@D:60I.PH@("`@("`@("`@("`D:60@
M/2!A<G)A>5]R979E<G-E*"1I9"D["@H@("`@("`@("`@("`D<W5C8V5S<R`]
M('1R=64["B`@("`@("`@("`@(&9O<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@
M("`@("`@("`@("`@("`D8W5R<G-U8V-E<W,@/2`D=&AI<RT^9&5L971E*"1V
M86PI.PH@("`@("`@("`@("`@("`@:68@*"$D8W5R<G-U8V-E<W,I('L*("`@
M("`@("`@("`@("`@("`@("`D<W5C8V5S<R`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<W5C
M8V5S<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:60@/2`D=&AI
M<RT^7V-O;G9E<G1.86UE*"1I9"P@=')U92D["B`@("`@("`@?0H*("`@("`@
M("`D;G-?:6YF;R`]("1T:&ES+3Y?9V5T3F%M97-P86-E*"1I9"D["@H@("`@
M("`@(&EF("@H)&ED(#T]("=)3D)/6"<I('Q\"B`@("`@("`@("`@("%I<W-E
M="@D=&AI<RT^7W1R965;)&ED72D@?'P*("`@("`@("`@("`@*"1I9"`]/2`D
M;G-?:6YF;ULG;F%M92==*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T<G5E.PH*
M("`@("`@("`D96QT(#T@)B1T:&ES+3Y?=')E95LD:61=.PH*("`@("`@("`O
M*B!$;R!N;W0@9&5L971E(&9R;VT@=')E92!I9B!T:&5R92!A<F4@8VAI;&0@
M96QE;65N=',@+2!I;G-T96%D+`H@("`@("`@("`J(&-O;G9E<G0@=&\@82!C
M;VYT86EN97(@96QE;65N="X@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA<T-H
M:6QD<F5N*"1E;'0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T0V]N=&%I
M;F5R*"1E;'0L('1R=64I.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("1P87)E;G0@/2`D96QT6R=P)UT["@H@("`@("`@
M("\J($1E;&5T92!T:&4@=')E92!E;G1R:65S+B`J+PH@("`@("`@('5N<V5T
M*"1T:&ES+3Y?=')E95LD:61=*3L*("`@("`@("!U;G-E="@D=&AI<RT^7W-U
M8G-C<FEB961;)&ED72D["B`@("`@("`@=6YS970H)'1H:7,M/E]U;G-U8G-C
M<FEB961;)&ED72D["@H@("`@("`@("\J($1E;&5T92!T:&4@96YT<GD@9G)O
M;2!T:&4@<&%R96YT('1R964N("HO"B`@("`@("`@)&ME>2`](&%R<F%Y7W-E
M87)C:"@D:60L("1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*3L*("`@("`@("!U
M;G-E="@D=&AI<RT^7W!A<F5N=%LD<&%R96YT75LD:V5Y72D["@H@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W!A<F5N=%LD<&%R96YT72DI('L*("`@("`@
M("`@("`@+RH@5&AI<R!F;VQD97(@:7,@;F]W(&-O;7!L971E;'D@96UP='D@
M*&YO(&-H:6QD<F5N*2X@($EF('1H90H@("`@("`@("`@("`@*B!F;VQD97(@
M:7,@82!C;VYT86EN97(@;VYL>2P@=V4@<VAO=6QD(&1E;&5T92!T:&4@9F]L
M9&5R(&9R;VT*("`@("`@("`@("`@("H@=&AE('1R964N("HO"B`@("`@("`@
M("`@('5N<V5T*"1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*3L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?=')E95LD<&%R96YT72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5T0VAI;&1R96XH)'1H:7,M/E]T<F5E6R1P
M87)E;G1=+"!N=6QL*3L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-#
M;VYT86EN97(H)'1H:7,M/E]T<F5E6R1P87)E;G1=*2`F)@H@("`@("`@("`@
M("`@("`@("`@("$D=&AI<RT^:7-.86UE<W!A8V4H)'1H:7,M/E]T<F5E6R1P
M87)E;G1=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD96QE=&4H
M)'!A<F5N="D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YH
M87-#:&EL9')E;B@D=&AI<RT^7W1R965;)'!A<F5N=%TI*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5%>'!A;F1E9$QI<W0H)'!A<F5N
M="D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971#:&EL9')E;B@D
M=&AI<RT^7W1R965;)'!A<F5N=%TL(&9A;'-E*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M/E]T<F5E6R1P87)E;G1=+"!F
M86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!296)U:6QD('1H92!P87)E;G0@
M=')E92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]P87)E;G1;)'!A<F5N=%T@
M/2!A<G)A>5]V86QU97,H)'1H:7,M/E]P87)E;G1;)'!A<F5N=%TI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4F5M;W9E('1H92!M86EL8F]X(&9R;VT@=&AE
M(&5X<&%N9&5D(&9O;&1E<G,@;&ES="X@*B\*("`@("`@("`D=&AI<RT^7W)E
M;6]V945X<&%N9&5D3&ES="@D:60I.PH*("`@("`@("`O*B!296UO=F4@=&AE
M(&UA:6QB;W@@9G)O;2!T:&4@;F%V7W!O;&P@;&ES="X@*B\*("`@("`@("`D
M=&AI<RT^<F5M;W9E4&]L;$QI<W0H)&ED*3L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=6)S8W)I8F4@86X@96QE;65N
M="!T;R!T:&4@=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&ED
M("!4:&4@96QE;65N="!N86UE(&]R(&%N(&%R<F%Y(&]F(&5L96UE;G0@;F%M
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-U8G-C<FEB92@D:60I"B`@("![
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:60I*2!["B`@("`@("`@("`@("1I
M9"`](&%R<F%Y*"1I9"D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D
M:60@87,@)'9A;"D@>PH@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]C;VYV
M97)T3F%M92@D=F%L*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M=')E95LD=F%L72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E
M9"`]('1R=64["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=%-U8G-C<FEB
M960H)'1H:7,M/E]T<F5E6R1V86Q=+"!T<G5E*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V5T0V]N=&%I;F5R*"1T:&ES+3Y?=')E95LD=F%L72P@9F%L
M<V4I.PH@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?<W5B
M<V-R:6)E9"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-U8G-C
M<FEB961;)'9A;%T@/2`Q.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@=6YS970H)'1H:7,M/E]U;G-U8G-C<FEB961;)'9A;%TI.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FEN<V5R
M="@D=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%5N<W5B<V-R:6)E(&%N(&5L96UE;G0@9G)O;2!T:&4@=')E
M92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&ED("!4:&4@96QE;65N
M="!N86UE(&]R(&%N(&%R<F%Y(&]F(&5L96UE;G0@;F%M97,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('5N<W5B<V-R:6)E*"1I9"D*("`@('L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@)&ED(#T@87)R87DH
M)&ED*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!792!W86YT
M('1O(&1E;&5T92!F<F]M('1H92!43U`@;V8@=&AE('1R964@9&]W;B!T;R!E
M;G-U<F4@=&AA=`H@("`@("`@("`@("`@*B!P87)E;G1S(&AA=F4@86X@86-C
M=7)A=&4@=FEE=R!O9B!W:&%T(&-H:6QD<F5N(&%R92!L969T+B`J+PH@("`@
M("`@("`@("`D=&AI<RT^7W-O<G1,:7-T*"1I9"D["B`@("`@("`@("`@("1I
M9"`](&%R<F%Y7W)E=F5R<V4H)&ED*3L*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@("`@("`@("`@("1V86P@/2`D=&AI
M<RT^7V-O;G9E<G1.86UE*"1V86PI.PH*("`@("`@("`@("`@+RH@24Y"3U@@
M8V%N(&YE=F5R(&)E('5N<W5B<V-R:6)E9"!T;R`H:68@:6X@;6%I;"!M;V1E
M*2X@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=')E95LD=F%L
M72D@)B8@*"1V86P@(3T@)TE.0D]8)RDI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W5N<W5B=FEE=R`]('1R=64["@H@("`@("`@("`@("`@("`@)&5L="`]("8D
M=&AI<RT^7W1R965;)'9A;%T["@H@("`@("`@("`@("`@("`@+RH@1&\@;F]T
M(&1E;&5T92!F<F]M('1R964@:68@=&AE<F4@87)E(&-H:6QD(&5L96UE;G1S
M("T*("`@("`@("`@("`@("`@("`J(&EN<W1E860L(&-O;G9E<G0@=&\@82!C
M;VYT86EN97(@96QE;65N="X@*B\*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^:&%S0VAI;&1R96XH)&5L="DI('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E=$-O;G1A:6YE<B@D96QT+"!T<G5E*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`O*B!3970@87,@=6YS=6)S8W)I8F5D
M+"!A9&0@=&\@=6YS=6)S8W)I8F5D(&QI<W0L(&%N9"!R96UO=F4*("`@("`@
M("`@("`@("`@("`J(&9R;VT@<W5B<V-R:6)E9"!L:7-T+B`J+PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S9713=6)S8W)I8F5D*"1E;'0L(&9A;'-E*3L*
M("`@("`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7W5N<W5B<V-R
M:6)E9"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5N<W5B<V-R
M:6)E9%LD=F%L72`](#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^7W-U8G-C<FEB961;)'9A;%TI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&%N
M;W1H97(@;&5V96P@;V8@:&EE<F%R8VAY('1O('1H92!T<F5E+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D;&ES="`@02!L:7-T(&]F('-T9$-L87-S(&]B:F5C=',@:6X@=&AE
M(&9O<FUA="!R971U<FYE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("!F
M<F]M(&EM87!?9V5T;6%I;&)O>&5S*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]A9&1,979E;"@D;&ES="D*("`@('L*("`@("`@("`D97AP86YD86QL(#T@
M*"1T:&ES+3Y?:6YI=&UO9&4@)B!)34%05%)%15])3DE47T9%5$-(04Q,*3L*
M"B`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)'9A;"D@>PH@("`@("`@("`@
M("`D96QT(#T@)'1H:7,M/E]M86ME36%I;&)O>%1R965%;'0H)'9A;"D["@H@
M("`@("`@("`@("`D<&%R96YT(#T@)&5L=%LG<"==.PH@("`@("`@("`@("`D
M=&AI<RT^7VEN<V5R=$5L="@D96QT*3L*("`@("`@("`@("`@)'1H:7,M/E]C
M:&%N9V5D(#T@=')U93L*"B`@("`@("`@("`@(&EF("@D97AP86YD86QL('Q\
M("1T:&ES+3YI<T]P96XH)&5L="DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YE>'!A;F0H)&5L=%LG=B==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@4V]R="!T:&4@;&ES="X@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1L:7-T*2`F)@H@("`@("`@("`@("`A96UP='DH)'1H:7,M/E]P87)E
M;G1;)'!A<F5N=%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T1&ES8V]V
M97)E9"@D=&AI<RT^7W1R965;)'!A<F5N=%TL('1R=64I.PH@("`@("`@("`@
M("!I9B`H8V]U;G0H)'1H:7,M/E]P87)E;G1;)'!A<F5N=%TI(#X@,2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S971.965D4V]R="@D=&AI<RT^7W1R
M965;)'!A<F5N=%TL('1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T(&%N(&%T=')I8G5T92!F;W(@86X@
M96QE;65N="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)B1E;'0@("`@(%1H92!T<F5E(&5L96UE
M;G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]N<W0@(%1H92!C;VYS=&%N
M="!T;R!S970O<F5M;W9E(&9R;VT@=&AE(&)I=&UA<VLN"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D8F]O;"`@(%-H;W5L9"!T:&4@871T<FEB=71E(&)E('-E
M=#\*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$%T=')I8G5T92@F)&5L="P@
M)&-O;G-T+"`D8F]O;"D*("`@('L*("`@("`@("!I9B`H)&)O;VPI('L*("`@
M("`@("`@("`@)&5L=%LG82==('P]("1C;VYS=#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D96QT6R=A)UT@)CT@?B1C;VYS=#L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;V5S('1H92!E;&5M96YT(&AA=F4@
M86YY(&%C=&EV92!C:&EL9')E;C\*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!E;&5M96YT(&AA<R!A8W1I=F4@8VAI
M;&1R96XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-H:6QD<F5N*"1E;'0I
M"B`@("!["B`@("`@("`@<W1A=&EC("1H87-#:&EL9')E;D-A8VAE(#T@87)R
M87DH*3L*"B`@("`@("`@)&ES7VYS(#T@)'1H:7,M/FES3F%M97-P86-E*"1E
M;'0I.PH*("`@("`@("`O*B!$;VXG="!D;R!T:&4@9F]L;&]W:6YG(&EF('=E
M(&%R92!D96%L:6YG('=I=&@@82!N86UE<W!A8V4*("`@("`@("`@*B!C;VYT
M86EN97(N("HO"B`@("`@("`@:68@*"$D:7-?;G,I('L*("`@("`@("`@("`@
M+RH@3F]T(&%L;"!)34%0('-E<G9E<G,@<W5P<&]R="!T:&4@2$%30TA)3$12
M14X@9FQA9R`H;&EK92!55R$I('-O"B`@("`@("`@("`@("`J('=E(&YE960@
M=&\@<VMI<"!T:&ES(&-H96-K(&EF('1H92!)34%0('-E<G9E<B!D;V5S;B=T
M('-E=`H@("`@("`@("`@("`@*B!E:71H97(@2$%30TA)3$1214X@;W(@2$%3
M3D]#2$E,1%)%3BX@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7V-H:6QD<F5N<W5P<&]R="D@?'P*("`@("`@("`@("`@("`@("AI<U]N=6QL
M*"1T:&ES+3Y?8VAI;&1R96YS=7!P;W)T*2`F)@H@("`@("`@("`@("`@("`@
M("@D96QT6R=A)UT@)B!,05147TA!4T-(24Q$4D5.*2!\?`H@("`@("`@("`@
M("`@("`@("@D96QT6R=A)UT@)B!,05147TA!4TY/0TA)3$1214XI*2D@>PH@
M("`@("`@("`@("`@("`@)')E="`]("@D96QT6R=A)UT@)B!,05147TA!4T-(
M24Q$4D5.*3L*"B`@("`@("`@("`@("`@("`O*B!#2$5#2SH@268@=V4@87)E
M('9I97=I;F<@86QL(&9O;&1E<G,L(&%N9"!T:&5R92!I<R!A(&9O;&1E<@H@
M("`@("`@("`@("`@("`@("H@;&ES=&5D(&%S(&5X<&%N9&5D(&)U="!I="!D
M;V5S(&YO="!C;VYT86EN(&%N>2!C:&EL9')E;BP*("`@("`@("`@("`@("`@
M("`J('1H96X@=V4@<VAO=6QD(')E;6]V92!I="!F<F]M('1H92!E>'!A;F1E
M9"!L:7-T('-I;F-E(&ET"B`@("`@("`@("`@("`@("`@*B!D;V5S;B=T(&5X
M:7-T(&%N>6UO<F4N("HO"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]S
M:&]W=6YS=6(@)B8@(21R970I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEN:71%>'!A;F1E9$QI<W0H*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?97AP86YD961;)&5L=%LG=B==72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5%>'!A;F1E9$QI
M<W0H)&5L=%LG=B==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S971/<&5N*"1T:&ES+3Y?=')E95LD96QT6R=V)UU=+"!F86QS92D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@(&EF("@A)')E="D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`O*B!)9B!W92!A<F4@=FEE=VEN9R!A;&P@96QE;65N=',@*'-U8G-C<FEB
M960@86YD('5N<W5B<V-R:6)E9"D*("`@("`@("`@("`@("`@("`J(&%N9"!W
M92!R96%C:"!T:&ES('!O:6YT('=E(&MN;W<@=&AA="!T:&5R92!M=7-T(&)E
M('9I97=A8FQE"B`@("`@("`@("`@("`@("`@*B!C:&EL9')E;B!S;R!R971U
M<FX@=')U92X@*B\*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W-H;W=U
M;G-U8BD@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!#86-H92!R97-U;'1S(&9R;VT@8F5L;W<@<VEN8V4L(&UO<W0@;&EK
M96QY(&EF('=E(&=E="!T:&ES(&9A<BP*("`@("`@("`@*B!T:&ES(&-O9&4@
M=VEL;"!B92!A8V-E<W-E9"!S979E<F%L('1I;65S(&EN('1H92!C=7)R96YT
M(')E<75E<W0N("HO"B`@("`@("`@:68@*&ES<V5T*"1H87-#:&EL9')E;D-A
M8VAE6R1E;'1;)W8G75TI*2!["B`@("`@("`@("`@(')E='5R;B`D:&%S0VAI
M;&1R96Y#86-H95LD96QT6R=V)UU=.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@=V4@<F5A8V@@=&AI<R!P;VEN="P@=&AE;B!W92!A<F4@96ET:&5R(&EN
M('-U8G-C<FEB92UO;FQY(&UO9&4*("`@("`@("`@*B!O<B!W92!A<F4@9&5A
M;&EN9R!W:71H(&$@;F%M97-P86-E(&-O;G1A:6YE<BX@0VAE8VL@9F]R('1H
M90H@("`@("`@("`J(&5X:7-T96YC92!O9B!A;GD@<W5B<V-R:6)E9"!M86EL
M8F]X97,@8F5L;W<@=&AE(&-U<G)E;G0@;F]D92X@*B\*("`@("`@("`D=&AI
M<RT^7VEN:713=6)S8W)I8F5D*"D["B`@("`@("`@)&9O;&1E<E]L:7-T(#T@
M)'1H:7,M/E]S=6)S8W)I8F5D.PH@("`@("`@(&EF("@D=&AI<RT^7W-H;W=U
M;G-U8BD@>PH@("`@("`@("`@("`D=&AI<RT^7VEN:715;G-U8G-C<FEB960H
M*3L*("`@("`@("`@("`@)&9O;&1E<E]L:7-T("L]("1T:&ES+3Y?=6YS=6)S
M8W)I8F5D.PH@("`@("`@('T*("`@("`@("`D;G-?:6YF;R`]("1T:&ES+3Y?
M9V5T3F%M97-P86-E*"1E;'1;)W8G72D["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1N<U]I;F9O*2D@>PH@("`@("`@("`@("`D<V5A<F-H7W-T<B`]("1E;'1;
M)W8G72`N("1N<U]I;F9O6R=D96QI;6ET97(G73L*("`@("`@("`@("`@:68@
M*"@D96QT6R=V)UT@/3T@)TE.0D]8)RD@)B8*("`@("`@("`@("`@("`@("@D
M;G-?:6YF;ULG;F%M92==(#T]("@G24Y"3U@G("X@)&YS7VEN9F];)V1E;&EM
M:71E<B==*2DI('L*("`@("`@("`@("`@("`@("1S96%R8VA?<W1R("X]("1N
M<U]I;F9O6R=N86UE)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R
M96%C:"`H87)R87E?:V5Y<R@D9F]L9&5R7VQI<W0I(&%S("1V86PI('L*("`@
M("`@("`@("`@("`@(&EF("AS=')P;W,H)'9A;"P@)'-E87)C:%]S='(I(#T]
M/2`P*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]H87-#:&EL9')E
M;D-A8VAE6R1E;'1;)W8G75T@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!$;R!O;F4@9FEN86P@8VAE8VL@:68@
M=&AI<R!I<R!A(&YA;65S<&%C92!C;VYT86EN97(@+2!I9B!W92!G970*("`@
M("`@("`@*B!T:&ES(&9A<BP@86YD(&%R92!V:65W:6YG(&%L;"!F;VQD97)S
M+"!T:&5N('=E(&MN;W<@=V4@:&%V92!N;PH@("`@("`@("`J(&-H:6QD<F5N
M('-O(&UA:V4@<W5R92!T:&4@96QE;65N="!I<R!N;W0@<V5T('1O(&5X<&%N
M9&5D+V]P96XN("HO"B`@("`@("`@:68@*"1I<U]N<R`F)B`D=&AI<RT^7W-H
M;W=U;G-U8BD@>PH@("`@("`@("`@("`D=&AI<RT^7VEN:71%>'!A;F1E9$QI
M<W0H*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V5X<&%N9&5D
M6R1E;'1;)W8G75TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E;6]V
M945X<&%N9&5D3&ES="@D96QT6R=V)UTI.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S971/<&5N*"1T:&ES+3Y?=')E95LD96QT6R=V)UU=+"!F86QS92D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1H87-#:&EL9')E
M;D-A8VAE6R1E;'1;)W8G75T@/2!F86QS93L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&-H:6QD<F5N(&%T
M=')I8G5T92!F;W(@86X@96QE;65N="X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1E;'0@($$@
M=')E92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&UI>&5D("1B;V]L("!4:&4@
M<V5T=&EN9RX@268@;G5L;"P@8VQE87)S('1H92!F;&%G+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5T0VAI;&1R96XH)B1E;'0L("1B;V]L*0H@("`@>PH@
M("`@("`@(&EF("AI<U]N=6QL*"1B;V]L*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W-E=$%T=')I8G5T92@D96QT+"!,05147TA!4T-(24Q$4D5.+"!F86QS
M92D["B`@("`@("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E;'0L($Q!
M5%1?2$%33D]#2$E,1%)%3BP@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E;'0L($Q!5%1?2$%3
M0TA)3$1214XL("1B;V]L*3L*("`@("`@("`@("`@)'1H:7,M/E]S971!='1R
M:6)U=&4H)&5L="P@3$%45%](05-.3T-(24Q$4D5.+"`A)&)O;VPI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($AA<R!T:&4@=')E92!E;&5M
M96YT(&)E96X@9&ES8V]V97)E9#\*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!.;VXM>F5R;R!I9B!T:&4@96QE;65N="!H87,@8F5E;B!D
M:7-C;W9E<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T1I<V-O=F5R960H
M)&5L="D*("`@('L*("`@("`@("!R971U<FX@)&5L=%LG82==("8@24U!4%12
M145?14Q47TE37T1)4T-/5D52140["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M970@=&AE(&1I<V-O=F5R960@871T<FEB=71E(&9O<B!A;B!E;&5M96YT+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`F)&5L="`@("!!('1R964@96QE;65N="X*("`@("`J($!P
M87)A;2!B;V]L96%N("1B;V]L("!4:&4@<V5T=&EN9RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E=$1I<V-O=F5R960H)B1E;'0L("1B;V]L*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E;'0L($E-05!44D5%7T5,
M5%])4U]$25-#3U9%4D5$+"`D8F]O;"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!)<R!T:&4@=')E92!E;&5M96YT(&]P96X_"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5')U92!I9B!T:&4@96QE;65N="!I<R!O<&5N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T]P96XH)&5L="D*("`@('L*("`@
M("`@("!I9B`H(21T:&ES+3Y?:6YI=&UO9&4I('L*("`@("`@("`@("`@<F5T
M=7)N("@H)&5L=%LG82==("8@24U!4%12145?14Q47TE37T]014XI("8F("1T
M:&ES+3YH87-#:&EL9')E;B@D96QT*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<W=I=&-H("@D=&AI<RT^7V=E=$EN:71%>'!A;F1E9$UO9&4H
M*2D@>PH@("`@("`@("`@("!C87-E($E-05!44D5%7T]014Y?3D].13H*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92!)34%05%)%15]/4$5.7T%,3#H*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E($E-05!44D5%7T]014Y?55-%4CH*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6YI=$5X<&%N9&5D3&ES="@I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^7V5X<&%N9&5D6R1E
M;'1;)W8G75TI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&]P
M96X@871T<FEB=71E(&9O<B!A;B!E;&5M96YT+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&5L
M="`@("!!('1R964@96QE;65N="X*("`@("`J($!P87)A;2!B;V]L96%N("1B
M;V]L("!4:&4@<V5T=&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$]P
M96XH)B1E;'0L("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T071T
M<FEB=71E*"1E;'0L($E-05!44D5%7T5,5%])4U]/4$5.+"`D8F]O;"D["B`@
M("`@("`@:68@*"$D=&AI<RT^7VEN:71M;V1E*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?:6YI=$5X<&%N9&5D3&ES="@I.PH@("`@("`@("`@("!I9B`H)&)O
M;VPI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D17AP86YD961,:7-T
M*"1E;'1;)W8G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)E;6]V945X<&%N9&5D3&ES="@D96QT6R=V)UTI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M27,@=&AI<R!E;&5M96YT(&$@8V]N=&%I;F5R(&]N;'DL(&YO="!A(&UA:6QB
M;W@@*&UE86YI;F<@>6]U(&-A;@H@("`@("H@;F]T(&]P96X@:70I/PH@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!('1R964@96QE;65N="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1R=64@:68@=&AE(&5L
M96UE;G0@:7,@82!C;VYT86EN97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M0V]N=&%I;F5R*"1E;'0I"B`@("!["B`@("`@("`@<F5T=7)N("@H)&5L=%LG
M82==("8@3$%45%].3U-%3$5#5"D@?'P*("`@("`@("`@("`@("`@("@A)'1H
M:7,M/E]S:&]W=6YS=6(@)B8*("`@("`@("`@("`@("`@("`A)'1H:7,M/FES
M4W5B<V-R:6)E9"@D96QT*2`F)@H@("`@("`@("`@("`@("`@("1T:&ES+3YH
M87-#:&EL9')E;B@D96QT*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('1H92!E;&5M96YT(&%S(&$@8V]N=&%I;F5R/PH@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&5L
M="`@("!!('1R964@96QE;65N="X*("`@("`J($!P87)A;2!B;V]L96%N("1B
M;V]L("!)<R!T:&4@96QE;65N="!A(&-O;G1A:6YE<C\*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E=$-O;G1A:6YE<B@F)&5L="P@)&)O;VPI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L="P@3$%45%].3U-%3$5#
M5"P@)&)O;VPI.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE('5S97(@
M<W5B<V-R:6)E9"!T;R!T:&ES(&5L96UE;G0_"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5')U92!I9B!T:&4@=7-E<B!I<R!S=6)S8W)I
M8F5D('1O('1H92!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U-U
M8G-C<FEB960H)&5L="D*("`@('L*("`@("`@("!R971U<FX@)&5L=%LG82==
M("8@24U!4%12145?14Q47TE37U-50E-#4DE"140["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3970@=&AE('-U8G-C<FEP=&EO;B!S=&%T=7,@9F]R(&%N(&5L
M96UE;G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("8D96QT("`@($$@=')E92!E;&5M96YT+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@($ES('1H92!E;&5M96YT('-U
M8G-C<FEB960@=&\_"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S9713=6)S8W)I
M8F5D*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$%T
M=')I8G5T92@D96QT+"!)34%05%)%15]%3%1?25-?4U5"4T-224)%1"P@)&)O
M;VPI.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&5L96UE;G0@82!N
M86UE<W!A8V4@8V]N=&%I;F5R/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D96QT("!!('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1R=64@:68@=&AE(&5L96UE;G0@:7,@82!N86UE<W!A8V4@
M8V]N=&%I;F5R/PH@("`@("HO"B`@("!F=6YC=&EO;B!I<TYA;65S<&%C92@D
M96QT*0H@("`@>PH@("`@("`@(')E='5R;B`D96QT6R=A)UT@)B!)34%05%)%
M15]%3%1?3D%-15-004-%.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E
M('1H92!S97)V97(@<W1R:6YG(&9R;VT@=&AE("=N86UE)R!P87)A;65T97(N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&]B:F5C="!S=&1#;&%S<R`D;V(@($%N(&]B:F5C="!R971U<FYE
M9"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UA
M<%]G971M86EL8F]X97,H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L
M87-S("!4:&4@;V)J96-T(')E='5R;F5D('=I=&@@=&AE('-E<G9E<B!S=')I
M;F<@<W1R:7!P960*("`@("`J("`@("`@("`@("`@("`@("`@(&9R;VT@=&AE
M("=N86UE)R!P87)A;65T97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96UO
M=F5397)V97)3=')I;F<H)&]B*0H@("`@>PH@("`@("`@("1O8BT^9G5L;%-E
M<G9E<E!A=&@@/2`D;V(M/FYA;64["B`@("`@("`@)&]B+3YN86UE(#T@)'1H
M:7,M/E]C;VYV97)T3F%M92AS=6)S='(H)&]B+3YN86UE+"!S=')P;W,H)&]B
M+3YN86UE+"`G?2<I("L@,2DI.PH@("`@("`@(')E='5R;B`D;V(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!);FET:6%L:7IE('1H92!E>'!A;F1E9"!F;VQD
M97(@;&ES="X*("`@("`J(%1(25,@34542$]$(%-(3U5,1"!"12!$149)3D5$
M($E.($%,3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?:6YI=$5X<&%N9&5D3&ES="@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]E>'!A;F1E9"`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&0@86X@96QE;65N="!T;R!T:&4@97AP86YD960@;&ES="X*("`@("`J(%1(
M25,@34542$]$(%-(3U5,1"!"12!$149)3D5$($E.($%,3"!354)#3$%34T53
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4
M:&4@96QE;65N="!N86UE('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V%D9$5X<&%N9&5D3&ES="@D:60I"B`@("!["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F4@86X@96QE;65N="!F<F]M('1H92!E>'!A;F1E9"!L
M:7-T+@H@("`@("H@5$A)4R!-151(3T0@4TA/54Q$($)%($1%1DE.140@24X@
M04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:60@(%1H92!E;&5M96YT(&YA;64@=&\@<F5M;W9E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<F5M;W9E17AP86YD961,:7-T*"1I9"D*("`@
M('L*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QI>F4O9V5T('1H92!L
M:7-T(&]F(&5L96UE;G1S('1O('!O;&PN"B`@("`@*B!42$E3($U%5$A/1"!3
M2$]53$0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4
M:&4@;&ES="!O9B!E;&5M96YT<R!T;R!P;VQL("AN86UE(&EN(&ME>2!F:65L
M9"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!O;&Q,:7-T*"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W!O;&P@/2!A<G)A>2@I.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!O;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@96QE
M;65N="!T;R!T:&4@<&]L;"!L:7-T+@H@("`@("H@5$A)4R!-151(3T0@4TA/
M54Q$($)%($1%1DE.140@24X@04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I9"`@
M5&AE(&5L96UE;G0@;F%M92!O<B!A(&QI<W0@;V8@96QE;65N="!N86UE<R!T
M;R!A9&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%!O;&Q,:7-T*"1I9"D*
M("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!E;&5M96YT(&9R
M;VT@=&AE('!O;&P@;&ES="X*("`@("`J(%1(25,@34542$]$(%-(3U5,1"!"
M12!$149)3D5$($E.($%,3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@
M9F]L9&5R+VUA:6QB;W@@;W(@82!L:7-T(&]F(&9O;&1E<G,O;6%I;&)O>&5S
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@=&\@<F5M;W9E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96UO=F50;VQL3&ES="@D:60I"B`@("!["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$;V5S('1H92!U<V5R('=A;G0@=&\@<&]L;"!T
M:&ES(&UA:6QB;W@@9F]R(&YE=R]U;G-E96X@;65S<V%G97,_"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5')U92!I9B!T:&4@=7-E<B!W
M86YT<R!T;R!P;VQL('1H92!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I<U!O;&QE9"@D96QT*0H@("`@>PH@("`@("`@(')E='5R;B`D96QT6R=A
M)UT@)B!)34%05%)%15]%3%1?25-?4$],3$5$.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T('1H92!P;VQL960@871T<FEB=71E(&9O<B!A;B!E;&5M96YT
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`F)&5L="`@("!!('1R964@96QE;65N="X*("`@("`J
M($!P87)A;2!B;V]L96%N("1B;V]L("!4:&4@<V5T=&EN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-E=%!O;&QE9"@F)&5L="P@)&)O;VPI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L="P@24U!4%12145?14Q4
M7TE37U!/3$Q%1"P@)&)O;VPI.PH@("`@?0H*("`@("\J*@H@("`@("H@1FQA
M9R!T:&4@96QE;65N="!A<R!N965D:6YG(&ET<R!C:&EL9')E;B!T;R!B92!S
M;W)T960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("8D96QT("`@($$@=')E92!E;&5M96YT+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@(%1H92!S971T:6YG+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<V5T3F5E9%-O<G0H)B1E;'0L("1B;V]L*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E;'0L($E-05!4
M4D5%7T5,5%].145$7U-/4E0L("1B;V]L*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($1O97,@=&AI<R!E;&5M96YT)W,@8VAI;&1R96X@;F5E9"!S;W)T:6YG
M/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!('1R964@96QE
M;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1R=64@:68@
M=&AE(&-H:6QD<F5N(&YE960@=&\@8F4@<V]R=&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?;F5E9%-O<G0H)&5L="D*("`@('L*("`@("`@("!R971U<FX@
M)&5L=%LG82==("8@24U!4%12145?14Q47TY%141?4T]25#L*("`@('T*"B`@
M("`O*BH*("`@("`J($EN:71I86QI>F4@=&AE(&QI<W0@;V8@<W5B<V-R:6)E
M9"!M86EL8F]X97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]I;FET4W5B<V-R:6)E9"@I"B`@("!["B`@
M("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]S=6)S8W)I8F5D*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T<G5E.PH@("`@("`@("`@("`D
M=&AI<RT^7W-U8G-C<FEB960@/2!A<G)A>2@I.PH@("`@("`@("`@("`D<W5B
M;&ES="`](&%R<F%Y*"D["@H@("`@("`@("`@("`O*B!)3D)/6"!I<R!A;'=A
M>7,@<W5B<V-R:6)E9"!T;R!I9B!W92!A<F4@:6X@;6%I;"!M;V1E+B`J+PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]M;V1E(#T]($E-05!44D5%7TU/1$5?
M34%)3"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S=6)S8W)I8F5D6R=)
M3D)/6"==(#T@,3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?;F%M97-P86-E<RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]N86UE<W!A8V5S(&%S("1V86PI('L*("`@("`@("`@("`@("`@
M("`@("`D=&UP(#T@0&EM87!?;'-U8B@D=&AI<RT^7V=E=%-T<F5A;2@I+"`D
M=&AI<RT^7W-E<G9E<BP@)'9A;%LG;F%M92==("X@)RHG*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1S=6)L:7-T(#T@87)R87E?;65R9V4H)'-U8FQI<W0L("1T
M;7`I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S=6)L:7-T
M(#T@0&EM87!?;'-U8B@D=&AI<RT^7V=E=%-T<F5A;2@I+"`D=&AI<RT^7W-E
M<G9E<BP@)'1H:7,M/E]P<F5F:7@@+B`G*B<I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1S=6)L:7-T*2D@>PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'-U8FQI<W0@87,@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<W5B<V-R:6)E9%MS=6)S='(H)'9A;"P@<W1R
M<&]S*"1V86PL("=])RD@*R`Q*5T@/2`Q.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M26YI=&EA;&EZ92!T:&4@;&ES="!O9B!U;G-U8G-C<FEB960@;6%I;&)O>&5S
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!?:6YI=%5N<W5B<V-R:6)E9"@I"B`@("!["B`@("`@("`@:68@
M*&ES7VYU;&PH)'1H:7,M/E]U;G-U8G-C<FEB960I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@("1T:&ES+3Y?
M:6YI=%-U8G-C<FEB960H*3L*("`@("`@("`@("`@)'1H:7,M/E]U;G-U8G-C
M<FEB960@/2!A<G)A>2@I.PH@("`@("`@("`@("`D86QL7VQI<W0@/2!A<G)A
M>2@I.PH*("`@("`@("`@("`@+RH@1V5T(&QI<W0@;V8@86QL(&UA:6QB;WAE
M<RX@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?;F%M97-P86-E<RD@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]N86UE<W!A8V5S(&%S
M("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@0&EM87!?;&ES
M="@D=&AI<RT^7V=E=%-T<F5A;2@I+"`D=&AI<RT^7W-E<G9E<BP@)'9A;%LG
M;F%M92==("X@)RHG*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1T;7`I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A;&Q?;&ES="`]
M(&%R<F%Y7VUE<F=E*"1A;&Q?;&ES="P@)'1M<"D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&%L;%]L:7-T(#T@0&EM87!?;&ES="@D=&AI
M<RT^7V=E=%-T<F5A;2@I+"`D=&AI<RT^7W-E<G9E<BP@)'1H:7,M/E]P<F5F
M:7@@+B`G*B<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1A;&Q?;&ES="DI('L*("`@("`@("`@("`@("`@("\J($9I;F0@86QL
M(&UA:6QB;WAE<R!T:&%T(&%R96XG="!I;B!T:&4@<W5B<V-R:6)E9"!L:7-T
M+B`J+PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%L;%]L:7-T(&%S("1V
M86PI('L*("`@("`@("`@("`@("`@("`@("`D=F%L(#T@<W5B<W1R*"1V86PL
M('-T<G!O<R@D=F%L+"`G?2<I("L@,2D["B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W-U8G-C<FEB961;)'9A;%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=6YS=6)S8W)I8F5D6R1V86Q=
M(#T@,3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3:&]U;&0@=V4@97AP86YD(&%L;"!E;&5M96YT<S\*("`@("`J+PH@("`@
M9G5N8W1I;VX@97AP86YD06QL*"D*("`@('L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7W!A<F5N=%MN=6QL72!A<R`D=F%L*2!["B`@("`@("`@("`@("1T
M:&ES+3YE>'!A;F0H)'9A;"P@=')U92D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4VAO=6QD('=E(&-O;&QA<'-E(&%L;"!E;&5M96YT<S\*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V]L;&%P<V5!;&PH*0H@("`@>PH@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?=')E92!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("`@("`@:68@*"1K97D@(3T@24U!4%12145?0D%315]%3%0I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YC;VQL87!S92@D=F%L6R=V)UTI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#;&5A<B!A;&P@
M96YT<FEE<R!F<F]M('1H92!E>'!A;F1E9"!L:7-T+B`J+PH@("`@("`@("1T
M:&ES+3Y?:6YI=$5X<&%N9&5D3&ES="@I.PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?97AP86YD960@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<F5M;W9E17AP86YD961,:7-T*"1K97DI.PH@("`@("`@('T*
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QI<W0@;V8@;6%I
M;&)O>&5S(&EN('1H92!N97AT(&QE=F5L+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4
M:&4@8W5R<F5N="!M86EL8F]X+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($$@;&ES="!O9B!M86EL8F]X(&]B:F5C=',@;W(@=&AE(&5M<'1Y(&QI
M<W0N"B`@("`@*B`@("`@("`@("`@("`@("!3964@7V=E=$QI<W0H*2!F;W(@
M9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAI;&1R96Y);F9O*"1I
M9"D*("`@('L*("`@("`@("`D:6YF;R`](&%R<F%Y*"D["B`@("`@("`@)&YS
M7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C92@D:60I.PH*("`@("`@("!I
M9B`H:7-?;G5L;"@D;G-?:6YF;RDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M;F9O.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D:60@/3T@)TE.0D]8)RD@
M)B8*("`@("`@("`@("`@*"1N<U]I;F9O6R=N86UE)UT@/3T@*"=)3D)/6"<@
M+B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTI*2D@>PH@("`@("`@("`@("`D<V5A
M<F-H(#T@)&ED("X@)&YS7VEN9F];)V1E;&EM:71E<B==("X@)&YS7VEN9F];
M)VYA;64G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<V5A<F-H
M(#T@)&ED("X@)&YS7VEN9F];)V1E;&EM:71E<B==.PH@("`@("`@('T*"B`@
M("`@("`@)&EN9F\@/2`D=&AI<RT^7V=E=$QI<W0H)'-E87)C:"`N("<E)RD[
M"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1R965;)&ED72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]S971#:&EL9')E;B@D=&AI<RT^7W1R965;)&ED
M72P@(65M<'1Y*"1I;F9O*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&EN9F\["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=VET8V@@<W5B<V-R:6)E
M9"]U;G-U8G-C<FEB960@=FEE=VEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D=6YS=6(@(%-H;W<@=6YS=6)S8W)I8F5D(&5L96UE;G1S/PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S:&]W56YS=6)S8W)I8F5D*"1U;G-U8BD*
M("`@('L*("`@("`@("!I9B`H)'5N<W5B(#T]/2`D=&AI<RT^7W-H;W=U;G-U
M8BD@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W-H;W=U;G-U8B`]("1U;G-U8CL*("`@("`@("`D=&AI<RT^7V-H
M86YG960@/2!T<G5E.PH*("`@("`@("`O*B!)9B!W92!A<F4@<W=I=&-H:6YG
M(&9R;VT@=6YS=6)S8W)I8F5D('1O('-U8G-C<FEB960L(&YO(&YE960*("`@
M("`@("`@*B!T;R!D;R!A;GET:&EN9R`H=V4@:G5S="!I9VYO<F4@=6YS=6)S
M8W)I8F5D('-T=69F*2X@*B\*("`@("`@("!I9B`H)'5N<W5B(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!W92!A<F4@<W=I=&-H:6YG(&9R;VT@<W5B<V-R:6)E9"!T;R!U;G-U
M8G-C<FEB960L('=E(&YE960*("`@("`@("`@*B!T;R!A9&0@86QL('5N<W5B
M<V-R:6)E9"!E;&5M96YT<R!T:&%T(&QI=F4@:6X@8W5R<F5N=&QY"B`@("`@
M("`@("H@9&ES8V]V97)E9"!I=&5M<RX@*B\*("`@("`@("`D=&AI<RT^7W5N
M<W5B=FEE=R`]('1R=64["B`@("`@("`@)'1H:7,M/E]I;FET56YS=6)S8W)I
M8F5D*"D["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=6YS=6)S8W)I8F5D
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7VEN:71M;V1E(#T@24U!4%12145?24Y)5%]53E-50CL*("`@("`@
M("`D=&AI<RT^:6YS97)T*&%R<F%Y7VME>7,H)'1H:7,M/E]U;G-U8G-C<FEB
M960I*3L*("`@("`@("`D=&AI<RT^7VEN:71M;V1E(#T@,#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!R969E<F5N8V4@=&\@82!C=7)R96YT
M;'D@;W!E;B!)34%0('-T<F5A;2X*("`@("`J(%1(25,@34542$]$($U54U0@
M0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(')E<V]U<F-E("!!;B!)34%0(')E<V]U<F-E('-T
M<F5A;2X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]G9713=')E86TH*0H@("`@
M>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&-U<G)E;G1L>2!S96QE8W1E9"!I;FET:6%L:7IA=&EO
M;B!E>'!A;F1E9"!M;V1E+@H@("`@("H@5$A)4R!-151(3T0@4TA/54Q$($)%
M($1%1DE.140@24X@04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@8W5R<F5N="!I;FET:6%L:7IA
M=&EO;B!E>'!A;F1E9"!M;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T
M26YI=$5X<&%N9&5D36]D92@I"B`@("!["B`@("`@("`@<F5T=7)N($E-05!4
M4D5%7T]014Y?3D].13L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!I;F9O
M<FUA=&EO;B!A8F]U="!N97<O=6YS965N+W1O=&%L(&UE<W-A9V5S(&9O<B!T
M:&4@9VEV96X@96QE;65N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@96QE;65N="!N86UE+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9R!F:65L9',Z"B`@
M("`@*B`\<')E/@H@("`@("H@)VUE<W-A9V5S)R`@+2T@($YU;6)E<B!O9B!T
M;W1A;"!M97-S86=E<RX*("`@("`J("=N97=M<V<G("`@("TM("!.=6UB97(@
M;V8@;F5W(&UE<W-A9V5S+@H@("`@("H@)W5N<V5E;B<@("`@+2T@($YU;6)E
M<B!O9B!U;G-E96X@;65S<V%G97,N"B`@("`@*B`\+W!R93X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T16QE;65N=$EN9F\H)&YA;64I"B`@("!["B`@("`@
M("`@)'-T871U<R`](&%R<F%Y*"D["@H@("`@("`@("1S=',@/2!`:6UA<%]S
M=&%T=7,H)'1H:7,M/E]G9713=')E86TH*2P@)'1H:7,M/E]S97)V97(@+B`D
M;F%M92P@4T%?34534T%'15,@?"!305]53E-%14X@?"!305]214-%3E0I.PH@
M("`@("`@(&EF("@A96UP='DH)'-T<RDI('L*("`@("`@("`@("`@)'-T871U
M<ULG;65S<V%G97,G72`]("1S=',M/FUE<W-A9V5S.PH@("`@("`@("`@("`D
M<W1A='5S6R=U;G-E96XG72`](&ES<V5T*"1S=',M/G5N<V5E;BD@/R`D<W1S
M+3YU;G-E96X@.B`P.PH@("`@("`@("`@("`D<W1A='5S6R=N97=M<V<G72`]
M(&ES<V5T*"1S=',M/G)E8V5N="D@/R`D<W1S+3YR96-E;G0@.B`P.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3;W)T<R!A(&QI<W0@;V8@;6%I;&)O>&5S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`F)&UB;W@@("!4:&4@;&ES="!O9B!M86EL8F]X97,@=&\@<V]R="X*("`@
M("`J($!P87)A;2!B;V]L96%N("1B87-E("!!<F4@=V4@<V]R=&EN9R!A(&QI
M<W0@;V8@;6%I;&)O>&5S(&EN('1H92!B87-E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@;V8@=&AE('1R964N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]S;W)T3&ES="@F)&UB;W@L("1B87-E(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@:68@*&ES7VYU;&PH)'1H:7,M/E]I;6%P7W-O<G0I*2!["B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O24U!4"]3;W)T+G!H<"<["B`@("`@
M("`@("`@("1T:&ES+3Y?:6UA<%]S;W)T(#T@)FYE=R!)34%07U-O<G0H)'1H
M:7,M/E]D96QI;6ET97(I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1B87-E
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M8F]X(&%S("1V86PI('L*("`@
M("`@("`@("`@("`@("1B87-E<V]R=%LD=F%L72`]("@D=F%L(#T]("=)3D)/
M6"<I(#\@)TE.0D]8)R`Z("1T:&ES+3Y?=')E95LD=F%L75LG;"==.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?:6UA<%]S;W)T+3YS;W)T
M36%I;&)O>&5S*"1B87-E<V]R="P@*"1T:&ES+3Y?;6]D92`]/2!)34%05%)%
M15]-3T1%7TU!24PI+"!T<G5E+"!T<G5E*3L*("`@("`@("`@("`@)&UB;W@@
M/2!A<G)A>5]K97ES*"1B87-E<V]R="D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/E]I;6%P7W-O<G0M/G-O<G1-86EL8F]X97,H)&UB
M;W@L("@D=&AI<RT^7VUO9&4@/3T@24U!4%12145?34]$15]-04E,*2D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@3F]N+4E-
M05`@;6%I;&)O>"!E;&5M96YT(&=I=F5N(&%N(&5L96UE;G0@:61E;G1I9FEE
M<BX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@
M5&AE(&5L96UE;G0@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!(&UA:6QB;W@@96QE;65N="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$YO;DE-05!%;'0H)&ED*0H@("`@>PH@("`@("`@(')E='5R;B!A
M<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&=I=F5N(&5L
M96UE;G0@86X@(F%C=&EV92(@96QE;65N="`H:2YE+B!A;B!E;&5M96YT('1H
M870@<VAO=6QD"B`@("`@*B!B92!W;W)K960@=VET:"!G:79E;B!T:&4@8W5R
M<F5N="!V:65W:6YG('!A<F%M971E<G,I+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!
M('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@:70@:7,@86X@86-T:79E(&5L96UE;G0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]A8W1I=F5%;'0H)&5L="D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/E]S:&]W=6YS=6(@)B8*("`@("`@("`@("`@)'1H:7,M/FES3F%M
M97-P86-E*"1E;'0I*2!["B`@("`@("`@("`@(')E='5R;B`H)'1H:7,M/FAA
M<T-H:6QD<F5N*"1E;'0I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@*"1T:&ES+3Y?<VAO=W5N<W5B('Q\"B`@("`@("`@("`@("`@
M("`@("`@*"1T:&ES+3YI<U-U8G-C<FEB960H)&5L="D@)B8@(21T:&ES+3YI
M<T-O;G1A:6YE<B@D96QT*2D@?'P*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^:&%S0VAI;&1R96XH)&5L="DI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G9E<G0@82!M86EL8F]X(&YA;64@=&\@=&AE(&-O<G)E
M8W0L(&EN=&5R;F%L(&YA;64@*&DN92X@;6%K92!S=7)E"B`@("`@*B!)3D)/
M6"!I<R!A;'=A>7,@8V%P:71A;&EZ960@9F]R($E-05`@<V5R=F5R<RDN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@5&AE(&UA:6QB;W@@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G9E<G1E9"!N86UE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=$YA;64H)&YA;64I"B`@("!["B`@
M("`@("`@<F5T=7)N("@H)'1H:7,M/E]M;V1E(#T]($E-05!44D5%7TU/1$5?
M34%)3"D@)B8@*'-T<F-A<V5C;7`H)&YA;64L("=)3D)/6"<I(#T](#`I*2`_
M("=)3D)/6"<@.B`D;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!N
M86UE<W!A8V4@:6YF;R!F;W(@82!F=6QL(&9O;&1E<B!P871H+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&UA:6QB;W@@(%1H92!F;VQD97(@<&%T:"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@;F%M97-P86-E(&EN9F\@9F]R('1H92!F
M;VQD97(@<&%T:"!O<B!N=6QL(&EF('1H90H@("`@("H@("`@("`@("`@("`@
M("`@<&%T:"!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T3F%M97-P86-E*"1M86EL8F]X*0H@("`@>PH@("`@("`@('-T871I8R`D
M;F%M97-P86-E0V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H:7-S970H
M)&YA;65S<&%C94-A8VAE6R1M86EL8F]X72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1N86UE<W!A8V5#86-H95LD;6%I;&)O>%T["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;F%M97-P86-E<RDI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]N86UE<W!A8V5S(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*"@H)&UA:6QB;W@@+B`D=F%L
M6R=D96QI;6ET97(G72D@/3T@)&ME>2D@?'P*("`@("`@("`@("`@("`@("`@
M("`H(65M<'1Y*"1K97DI("8F("AS=')P;W,H)&UA:6QB;W@L("1K97DI(#T]
M/2`P*2DI('L*("`@("`@("`@("`@("`@("`@("`D;F%M97-P86-E0V%C:&5;
M)&UA:6QB;WA=(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'9A;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F%M97-P86-E<ULG)UTI*2!["B`@
M("`@("`@("`@("`@("`D;F%M97-P86-E0V%C:&5;)&UA:6QB;WA=(#T@)'1H
M:7,M/E]N86UE<W!A8V5S6R<G73L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VYA;65S<&%C97-;)R==.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D;F%M97-P86-E0V%C:&5;)&UA:6QB;WA=(#T@;G5L;#L*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*'-U8G-T<B@D=&AI<RT^7W!R969I>"P@+3$I(#T]("1T:&ES+3Y?
M9&5L:6UI=&5R*2!["B`@("`@("`@("`@("`@("`D;F%M92`]('-U8G-T<B@D
M=&AI<RT^7W!R969I>"P@,"P@<W1R;&5N*"1T:&ES+3Y?<')E9FEX*2`M(#$I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YA;64@
M/2`D=&AI<RT^7W!R969I>#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;F%M97-P86-E0V%C:&5;)&UA:6QB;WA=(#T@87)R87DH)V1E;&EM:71E<B<@
M/3X@)'1H:7,M/E]D96QI;6ET97(L("=N86UE)R`]/B`D;F%M92P@)W1Y<&4G
M(#T^("=P97)S;VYA;"<I.PH@("`@("`@("`@("!R971U<FX@)&YA;65S<&%C
M94-A8VAE6R1M86EL8F]X73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$;V5S('1H92!)34%0('-E<G9E<B!S=7!P;W)T('1H92`G0TA)3$12
M14XG($E-05`@97AT96YS:6]N/PH@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1S=7!P;W)T("!4<G5E(&EF('1H92!)34%0('-E<G9E<B!S=7!P;W)T
M<R!T:&4@0TA)3$1214X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!E>'1E;G-I;VXL(&9A;'-E(&EF(&ET(&1O97-N)W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($E-05!C:&EL9')E;E-U<'!O<G0H)'-U<'!O<G0I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]C:&EL9')E;G-U<'!O<G0@/2`H8F]O;"D@)'-U
M<'!O<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('-T87)T('!O
M:6YT(&9O<B!D971E<FUI;FEN9R!E;&5M96YT(&1I9F9E<F5N8V5S('9I82!E
M;'1$:69F*"DN"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("HO"B`@("!F=6YC=&EO;B!E;'1$:69F4W1A<G0H*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?96QT9&EF9B`]("1T:&ES+3Y?=')E93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@;&ES="!O9B!E;&5M96YT<R!T:&%T(&AA
M=F4@8VAA;F=E9"!S:6YC92!N;V1E1&EF9E-T87)T*"D*("`@("`J('=A<R!L
M87-T(&-A;&QE9"X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@=VET:"!T:&4@
M9F]L;&]W:6YG(&ME>7,Z"B`@("`@*B`\<')E/@H@("`@("H@)V$G(#T^($$@
M;&ES="!O9B!E;&5M96YT<R!T:&%T(&AA=F4@8F5E;B!A9&1E9"X*("`@("`J
M("=C)R`]/B!!(&QI<W0@;V8@96QE;65N=',@=&AA="!H879E(&)E96X@8VAA
M;F=E9"X*("`@("`J("=D)R`]/B!!(&QI<W0@;V8@96QE;65N=',@=&AA="!H
M879E(&)E96X@9&5L971E9"X*("`@("`J(#PO<')E/@H@("`@("H@("`@("`@
M("`@("`@("`@4F5T=7)N<R!F86QS92!I9B!N;R!C:&%N9V5S(&AA=F4@;V-C
M=7)R960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5L=$1I9F8H*0H@("`@>PH@
M("`@("`@(&EF("@A)'1H:7,M/E]C:&%N9V5D('Q\("$D=&AI<RT^7V5L=&1I
M9F8I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)&%D9&5D(#T@)&-H86YG960@/2`D9&5L971E9"`](&%R<F%Y*"D[
M"@H@("`@("`@("\J($1E=&5R;6EN92!T:&4@9&5L971E9"!I=&5M<RX@*B\*
M("`@("`@("`D9&5L971E9"`](&%R<F%Y7W9A;'5E<RAA<G)A>5]D:69F*&%R
M<F%Y7VME>7,H)'1H:7,M/E]E;'1D:69F*2P@87)R87E?:V5Y<R@D=&AI<RT^
M7W1R964I*2D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?=')E92!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7V5L=&1I9F9;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D861D961;72`]
M("1K97D["B`@("`@("`@("`@('T@96QS96EF("@D=F%L("$]("1T:&ES+3Y?
M96QT9&EF9ELD:V5Y72D@>PH@("`@("`@("`@("`@("`@)&-H86YG961;72`]
M("1K97D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AE
M;7!T>2@D861D960I("8F(&5M<'1Y*"1C:&%N9V5D*2`F)B!E;7!T>2@D9&5L
M971E9"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G82<@/3X@)&%D9&5D
M+"`G8R<@/3X@)&-H86YG960L("=D)R`]/B`D9&5L971E9"D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*BHJ($1E<')E8V%T960@=F%R:6%B;&5S+V9U;F-T
M:6]N<RX@5&AE<V4@<F5M86EN(&9O<B!"0R!O;FQY+B`J*BHJ+PH*("`@("\J
M*@H@("`@("H@5&AE('!R969I>"!W:71H;W5T(&$@=')A:6QI;F<@9&5L:6UI
M=&5R+@H@("`@("H*("`@("`J($!D97!R96-A=&5D('-I;F-E($AO<F1E(#,N
M,0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<')E9FEX
M;F]D96QI;2`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('-E<G9E<B!S=')I
M;F<@=7-E9"!F;W(@=&AE(&1E;&EM:71E<BX*("`@("`J(%1(25,@4TA/54Q$
M($)%(%-%5"!)3B!%5D5262!354)#3$%34R!#3TY35%)50U1/4BX*("`@("`J
M"B`@("`@*B!`9&5P<F5C871E9"!S:6YC92!(;W)D92`S+C$*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1E;&EM:71E<B`]("<O)SL*
M"B`@("`O*BH*("`@("`J(%=H97)E('=E('-T87)T(&QI<W1I;F<@9F]L9&5R
M<RX*("`@("`J(%1(25,@4TA/54Q$($)%(%-%5"!)3B!%5D5262!354)#3$%3
M4R!#3TY35%)50U1/4BX*("`@("`J"B`@("`@*B!`9&5P<F5C871E9"!S:6YC
M92!(;W)D92`S+C$*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7W!R969I>"`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&QO8V%T:6]N
M(&]F('1H92!F:7)S="!L979E;"!O9B!F;VQD97)S(&)E;&]W('1H92!)3D)/
M6"X*("`@("`J(%1(25,@4TA/54Q$($)%(%-%5"!)3B!%5D5262!354)#3$%3
M4R!#3TY35%)50U1/4BX*("`@("`J"B`@("`@*B!`9&5P<F5C871E9"!S:6YC
M92!(;W)D92`S+C$*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7VYA;65S<&%C92`]("<G.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&1O
M=&9I;&5S(&)E('-H;W=N/PH@("`@("H@5$A)4R!32$]53$0@0D4@4T54($E.
M($5615)9(%-50D-,05-3($-/3E-44E5#5$]2+@H@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]D;W1F:6QE<R`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@5&AE(&5X:7-T96YC92!O9B!T:&ES(&9U;F-T
M:6]N(&EN($E-05!?5')E92!I;F1I8V%T97,@=&AA="!E>'1E;F1E9`H@("`@
M("H@;F%M97-P86-E('-U<'!O<G0@:7,@879A:6QA8FQE+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!E>'1E;F1E9$YA;65S<&%C95-U<'!O<G0H*0H@("`@>PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!P<F5F:7@N"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@<VEN
M8V4@2&]R9&4@,RXQ"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R969I
M>"!W:&5R92!F;VQD97)S(&)E9VEN('1O(&)E(&QI<W1E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4')E9FEX*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]P<F5F:7@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@:6YF
M;W)M871I;VX@86)O=70@82!S<&5C:69I8R!M86EL8F]X+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0&1E<')E8V%T960@<VEN8V4@
M2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE(&UA:6QB;W@@=&\@<75E<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=&1#;&%S<R`@4V5E(&EM87!?9V5T;6%I;&)O>&5S*"DN("!4:&4@<V5R=F5R
M('-T<FEN9R!H87,*("`@("`J("`@("`@("`@("`@("`@("`@(&%L<F5A9'D@
M8F5E;B!R96UO=F5D(&9R;VT@=&AE("=N86UE)R!P87)A;65T97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971-86EL8F]X*"1P871H*0H@("`@>PH@("`@
M("`@("1B;W@@/2`D=&AI<RT^7V=E=$QI<W0H)'!A=&@I.PH@("`@("`@(&EF
M("AE;7!T>2@D8F]X*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(')E<V5T*"1B;W@I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA:V4@<W5R92!T
M:&5R92!I<R!N;R!T<F%I;&EN9R!D96QI;6ET97(@;VX@=&AE(&5L96UE;G0@
M;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M96QE;65N="!N86UE+@H@("`@("H@0&1E<')E8V%T960@<VEN8V4@2&]R9&4@
M,RXQ"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;&5M96YT
M(&YA;64@=VET:"!A;GD@=')A:6QI;F<@9&5L:6UI=&5R('-T<FEP<&5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@;V9F+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!N;U1R86EL:6YG1&5L:6UI=&5R*"1N86UE*0H@("`@>PH@("`@("`@("1N
M<U]I;F9O(#T@)'1H:7,M/E]G971.86UE<W!A8V4H)&YA;64I.PH@("`@("`@
M(&EF("AS=6)S='(H)&YA;64L("TQ*2`]/2`D;G-?:6YF;ULG9&5L:6UI=&5R
M)UTI('L*("`@("`@("`@("`@)&YA;64@/2!S=6)S='(H)&YA;64L(#`L('-T
M<FQE;B@D;F%M92D@+2`Q*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;F%M93L*("`@('T*"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M24U!4"]3;W)T+G!H<```````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`W,3`U`#$P-#$W,S8R-S<S`#`R,#0R,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@24U!4%]3
M;W)T('!R;W9I9&5S(&9U;F-T:6]N<R!F;W(@<V]R=&EN9R!L:7-T<R!O9B!)
M34%0(&UA:6QB;WAE<R]F;VQD97)S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R])34%0+TE-05`O4V]R="YP:'`L=B`Q+C8N."XQ,R`R,#`V+S`R+S$U(#$X
M.C`W.C4R('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@24U!
M4%]3;W)T('L*"B`@("`O*BH*("`@("`J(%1H92!D96QI;6ET97(@8VAA<F%C
M=&5R('1O('5S92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]D96QI;6ET97(["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@
M=V4@<V]R="!W:71H("=)3D)/6"<@870@=&AE(&9R;VYT(&]F('1H92!L:7-T
M/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)%]S;W)T:6YB;W@["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D96QI;6ET97(@(%1H92!D96QI
M;6ET97(@=7-E9"!T;R!S97!A<F%T92!M86EL8F]X97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($E-05!?4V]R="@D9&5L:6UI=&5R*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?9&5L:6UI=&5R(#T@)&1E;&EM:71E<CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%-O<G0@82!L:7-T(&]F(&UA:6QB;WAE<R`H8GD@=F%L=64I
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&UB;W@@("`@5&AE(&QI
M<W0@;V8@;6%I;&)O>&5S('1O('-O<G0N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D:6YB;W@@(%=H96X@<V]R=&EN9RP@86QW87ES('!U="`G24Y"3U@G(&%T
M('1H92!H96%D(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!L:7-T/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN9&5X("!-86EN=&%I
M;B!I;F1E>"!A<W-O8VEA=&EO;C\*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R
M=$UA:6QB;WAE<R@F)&UB;W@L("1I;F)O>"`]('1R=64L("1I;F1E>"`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]R=&EN8F]X(#T@)&EN8F]X
M.PH@("`@("`@(&EF("@D:6YD97@I('L*("`@("`@("`@("`@=6%S;W)T*"1M
M8F]X+"!A<G)A>2@F)'1H:7,L("=?;6)O>%]C;7`G*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@=7-O<G0H)&UB;W@L(&%R<F%Y*"8D=&AI<RP@
M)U]M8F]X7V-M<"<I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3;W)T(&$@;&ES="!O9B!M86EL8F]X97,@*&)Y(&ME>2DN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("8D;6)O>"`@("!4:&4@;&ES="!O9B!M86EL
M8F]X97,@=&\@<V]R="P@=VET:"!T:&4@:V5Y<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!B96EN9R!T:&4@;6%I;&)O>"!N86UE<RX*("`@("`J
M($!P87)A;2!B;V]L96%N("1I;F)O>"`@5VAE;B!S;W)T:6YG+"!A;'=A>7,@
M<'5T("=)3D)/6"<@870@=&AE(&AE860@;V8*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&QI<W0_"B`@("`@*B\*("`@(&9U;F-T:6]N('-O
M<G1-86EL8F]X97-">4ME>2@F)&UB;W@L("1I;F)O>"`]('1R=64I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]S;W)T:6YB;W@@/2`D:6YB;W@["B`@("`@("`@
M=6MS;W)T*"1M8F]X+"!A<G)A>2@F)'1H:7,L("=?;6)O>%]C;7`G*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!(:65R87)C:&EC86P@9F]L9&5R('-O<G1I
M;F<@9G5N8W1I;VX@*'5S960@=VET:"!U<V]R="@I*2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A("!#;VUP87)I<V]N(&ET96T@,2X*("`@("`J($!P87)A;2!S=')I;F<@
M)&(@($-O;7!A<FES;VX@:71E;2`R+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@4V5E('5S;W)T*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]M
M8F]X7V-M<"@D82P@)&(I"B`@("!["B`@("`@("`@+RH@06QW87ES(')E='5R
M;B!)3D)/6"!A<R`B<VUA;&QE<B(N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?
M<V]R=&EN8F]X*2!["B`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1A+"`G
M24Y"3U@G*2`]/2`P*2!["B`@("`@("`@("`@("`@("!R971U<FX@+3$["B`@
M("`@("`@("`@('T@96QS96EF("AS=')C87-E8VUP*"1B+"`G24Y"3U@G*2`]
M/2`P*2!["B`@("`@("`@("`@("`@("!R971U<FX@,3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)&%?<&%R=',@/2!E>'!L;V1E*"1T:&ES
M+3Y?9&5L:6UI=&5R+"`D82D["B`@("`@("`@)&)?<&%R=',@/2!E>'!L;V1E
M*"1T:&ES+3Y?9&5L:6UI=&5R+"`D8BD["@H@("`@("`@("1A7V-O=6YT(#T@
M8V]U;G0H)&%?<&%R=',I.PH@("`@("`@("1B7V-O=6YT(#T@8V]U;G0H)&)?
M<&%R=',I.PH*("`@("`@("`D:4UA>"`](&UI;B@D85]C;W5N="P@)&)?8V]U
M;G0I.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:4UA>#L@)&DK*RD@
M>PH@("`@("`@("`@("!I9B`H)&%?<&%R='-;)&E=("$]("1B7W!A<G1S6R1I
M72D@>PH@("`@("`@("`@("`@("`@+RH@268@;VYL>2!O;F4@;V8@=&AE(&9O
M;&1E<G,@:7,@=6YD97(@24Y"3U@L(')E='5R;B!I="!A<PH@("`@("`@("`@
M("`@("`@("H@(G-M86QL97(B+B`J+PH@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?<V]R=&EN8F]X("8F("@D:2`]/2`P*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1A7V)A<V4@/2`H<W1R8V%S96-M<"@D85]P87)T<ULP72P@)TE.
M0D]8)RD@/3T@,"D["B`@("`@("`@("`@("`@("`@("`@)&)?8F%S92`]("AS
M=')C87-E8VUP*"1B7W!A<G1S6S!=+"`G24Y"3U@G*2`]/2`P*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&%?8F%S92`F)B`A)&)?8F%S92D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@+3$["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"$D85]B87-E("8F("1B7V)A<V4I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-M<"`]
M('-T<FYA=&-A<V5C;7`H)&%?<&%R='-;)&E=+"`D8E]P87)T<ULD:5TI.PH@
M("`@("`@("`@("`@("`@:68@*"1C;7`@/3T@,"D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!S=')C;7`H)&%?<&%R='-;)&E=+"`D8E]P87)T<ULD
M:5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1C;7`["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`H)&%?8V]U;G0@+2`D8E]C;W5N="D["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O4U%,+P``````````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<S`#`Q-C8W
M-``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]344PO071T<FEB
M=71E<RYP:'``````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`S,C4`
M,3`T,3<S-C(W-S,`,#(Q-3,S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I
M9&5S(&%T=')I8G5T97,@;65T:&]D<R!F;W(@86YY(&5X:7-T:6YG(%-13"!C
M;&%S<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4U%,+U-13"]!='1R:6)U
M=&5S+G!H<"QV(#$N,30N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C,S(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?4U%,"B`J+PIC;&%S
M<R!(;W)D95]344Q?071T<FEB=71E<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M4$5!4CHZ1$(@;V)J96-T('1O(')U;B!Q=65R:65S('=I=&@N"B`@("`@*@H@
M("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*
M("`@("`J(%!A<F%M971E<G,@=&\@=7-E('=H96X@9V5N97)A=&EN9R!Q=65R
M:65S.@H@("`@("H@("!I9%]C;VQU;6X@("`@("`@+2!4:&4@<')I;6%R>2!I
M9"!C;VQU;6X@=&\@=7-E(&EN(&IO:6YS+@H@("`@("H@("!P<FEM87)Y7W1A
M8FQE("`@+2!4:&4@;6%I;B!T86)L92!N86UE+@H@("`@("H@("!A='1R:6)U
M=&5?=&%B;&4@+2!4:&4@=&%B;&4@=&AA="!T:&4@871T<FEB=71E<R!A<F4@
M<W1O<F5D(&EN+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H
M92!N=6UB97(@;V8@8V]P:65S(&]F('1H92!A='1R:6)U=&5S('1A8FQE('1H
M870@=V4@;F5E9"!T;R!J;VEN(&]N(&EN"B`@("`@*B!T:&4@8W5R<F5N="!Q
M=65R>2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?=&%B;&5?8V]U;G0@/2`Q.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M($1"("1D8F@@("`@("`@($$@
M4$5!4CHZ1$(@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M(%1H92!I9"!C;VQU;6XL('1A8FQE(&YA;65S+"!E=&,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7U-13%]!='1R:6)U=&5S*"1D8F@L("1P87)A;7,I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]D8B`]("1D8F@["B`@("`@("`@)'1H
M:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A;&P@871T<FEB=71E<R!F;W(@82!G:79E;B!I9"!O<B!M=6QT
M:7!L92!I9',N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@?"!A<G)A
M>2`D:60@(%1H92!I9"!T;R!F971C:"!O<B!A;B!A<G)A>2!O9B!I9',N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H(&]F(&%T=')I8G5T
M97,L(&]R(&$@;75L=&DM;&5V96P@:&%S:`H@("`@("H@("`@("`@("`@("`@
M("`@;V8@:61S(#T^('1H96ER(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$%T=')I8G5T97,H)&ED*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D:60I*2!["B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)U-%3$5#5"`E,21S+"!A='1R:6)U=&5?;F%M92!A<R!N86UE+"!A='1R:6)U
M=&5?:V5Y(&%S(")K97DB+"!A='1R:6)U=&5?=F%L=64@87,@=F%L=64@1E)/
M32`E,B1S(%=(15)%("4Q)',@24X@*"4S)',I)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:61?8V]L=6UN)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%T
M=')I8G5T95]T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EM<&QO9&4H)RP@)RP@)&ED*2D["@H@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R:6)U=&5S.CIG
M971!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F]W<R`]("1T:&ES
M+3Y?9&(M/F=E=$%L;"@D<75E<GDL($1"7T9%5$-(34]$15]!4U-/0RD["B`@
M("`@("`@("`@(&EF("AI<U]A*"1R;W=S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')O=W,["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1I9%]C;VQU;6X@/2`D=&AI<RT^7W!A<F%M<ULG:61?8V]L
M=6UN)UT["B`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)')O=W,@87,@)')O=RD@>PH@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1D871A6R1R;W=;)&ED7V-O;'5M;EU=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1D871A6R1R;W=;)&ED7V-O;'5M;EU=(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D871A6R1R
M;W=;)&ED7V-O;'5M;EU=6UT@/2!A<G)A>2@G;F%M92<@(#T^("1R;W=;)VYA
M;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:V5Y)R`@(#T^("1R;W=;)VME>2==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@
M)')O=ULG=F%L=64G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("1D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)U-%3$5#5"`E,21S+"!A='1R:6)U=&5?;F%M92!A<R!N
M86UE+"!A='1R:6)U=&5?:V5Y(&%S(")K97DB+"!A='1R:6)U=&5?=F%L=64@
M87,@=F%L=64@1E)/32`E,B1S(%=(15)%("4Q)',@/2`E,R1S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:61?8V]L
M=6UN)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V%T=')I8G5T95]T86)L92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("AI;G0I)&ED*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)U-13"!1=65R>2!B>2!(;W)D95]344Q?071T<FEB=71E<SHZ9V5T
M071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&(M/F=E=$%L;"@D<75E<GDL($1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@<V5T(&]F(&ED
M<R!B87-E9"!O;B!A('-E="!O9B!A='1R:6)U=&4@8W)I=&5R:6$N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<FET97)I82`@5&AE(&%R<F%Y(&]F
M(&-R:71E<FEA+B!%>&%M<&QE.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-R:71E<FEA6R=/4B==(#T@87)R87DH"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]
M/B`G;F%M92<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V]P)R`@("`]/B`G/2<L"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1E<W0G("`]
M/B`G9F]O)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]P)R`@
M("`]/B`G/2<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1E<W0G("`]/B`G8F%R)RDI.PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@(%1H:7,@=V]U;&0@<F5T=7)N(&%L;"!I
M9',@9F]R('=H:6-H('1H92!F:65L9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%T=')I8G5T95]N86UE(&ES(&5I=&AE<B`G9F]O)R!O<B`G
M8F%R)RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0GE!='1R:6)U=&5S*"1C
M<FET97)I82D*("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1C<FET97)I82DI
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("`O*B!"=6EL9"!T:&4@<75E<GDN("HO"B`@("`@("`@)'1H:7,M/E]T
M86)L95]C;W5N="`](#$["B`@("`@("`@)'%U97)Y(#T@)R<["B`@("`@("`@
M9F]R96%C:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;',I('L*("`@("`@
M("`@("`@:68@*"1K97D@/3T@)T]2)R!\?"`D:V5Y(#T]("=!3D0G*2!["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1Q=65R>2DI('L*("`@("`@("`@
M("`@("`@("`@("`D<75E<GD@+CT@)R`G("X@)&ME>2`N("<@)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1Q=65R>2`N/2`G*"<@+B`D
M=&AI<RT^7V)U:6QD071T<FEB=71E475E<GDH)&ME>2P@)'9A;',I("X@)RDG
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!T
M:&4@1E)/32]*3TE.(&-L875S97,N("HO"B`@("`@("`@)&IO:6YS(#T@87)R
M87DH*3L*("`@("`@("`D<&%I<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H
M)&D@/2`Q.R`D:2`\/2`D=&AI<RT^7W1A8FQE7V-O=6YT.R`D:2LK*2!["B`@
M("`@("`@("`@("1J;VEN<UM=(#T@<W!R:6YT9B@G3$5&5"!*3TE.("4Q)',@
M824R)',@3TX@824R)',N)3,D<R`](&TN)3,D<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T<FEB=71E7W1A
M8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=I
M9%]C;VQU;6XG72D["@H@("`@("`@("`@("`D<&%I<G-;72`]("=!3D0@83$N
M871T<FEB=71E7VYA;64@/2!A)R`N("1I("X@)RYA='1R:6)U=&5?;F%M92<[
M"B`@("`@("`@?0H@("`@("`@("1J;VEN<R`](&EM<&QO9&4H)R`G+"`D:F]I
M;G,I.PH@("`@("`@("1P86ER<R`](&EM<&QO9&4H)R`G+"`D<&%I<G,I.PH*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@1$E35$E.0U0@83$N
M)7,@1E)/32`E<R!M("5S(%=(15)%("5S("5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=I9%]C;VQU;6XG72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P<FEM87)Y7W1A
M8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D:F]I;G,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D<75E<GDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%I<G,I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R:6)U=&5S.CIG971">4%T=')I
M8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YG971#
M;VPH)'%U97)Y*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@;F5W
M(&%T=')I8G5T92!S970@86YD(&%N(&ED+"!I;G-E<G0@96%C:"!I;G1O('1H
M92!$0BX@268*("`@("`J(&%N>71H:6YG(&9A:6QS(&EN(&AE<F4L(')O;&QB
M86-K('1H92!T<F%N<V%C=&EO;BP@<F5T=7)N('1H92!R96QE=F%N=`H@("`@
M("H@97)R;W(@86YD(&)A:6P@;W5T+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1I9"`@("`@("`@5&AE(&ED(&]F('1H92!R96-O<F0@9F]R('=H
M:6-H(&%T=')I8G5T97,@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)E:6YG(&EN<V5R=&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A
M='1R:6)U=&5S("!!;B!H87-H(&-O;G1A:6YI;F<@=&AE(&%T=')I8G5T97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN<V5R=$%T=')I8G5T97,H)&ED+"`D
M871T<FEB=71E<RD*("`@('L*("`@("`@("!F;W)E86-H("@D871T<FEB=71E
M<R!A<R`D871T<BD@>PH@("`@("`@("`@("`D<75E<GD@/2`G24Y315)4($E.
M5$\@)R`N("1T:&ES+3Y?<&%R86US6R=A='1R:6)U=&5?=&%B;&4G72`N"B`@
M("`@("`@("`@("`@("`@("`@("<@*"<@+B`D=&AI<RT^7W!A<F%M<ULG:61?
M8V]L=6UN)UT@+B`G+"!A='1R:6)U=&5?;F%M92PG("X*("`@("`@("`@("`@
M("`@("`@("`@)R!A='1R:6)U=&5?:V5Y+"!A='1R:6)U=&5?=F%L=64I(%9!
M3%5%4R`H/RP@/RP@/RP@/RDG.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R
M87DH*&EN="DD:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D871T
M<ELG;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=');
M)VME>2==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=');)W9A
M;'5E)UTI.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!(;W)D95]344Q?071T<FEB=71E<SHZ:6YS97)T071T<FEB=71E
M<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1B+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M8BT^875T;T-O;6UI="AT<G5E*3L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#
M;VUM:70@=&AE('1R86YS86-T:6]N+"!A;F0@='5R;B!A=71O8V]M;6ET(&)A
M8VL@;VXN("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F-O;6UI
M="@I.PH@("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A;B!I9"P@9&5L971E(&%L;"!A
M='1R:6)U=&5S(&9O<B!T:&%T(&ED(&9R;VT@=&AE"B`@("`@*B!A='1R:6)U
M=&5S('1A8FQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9"`@
M5&AE(&ED(&]F('1H92!R96-O<F0@9F]R('=H:6-H(&%T=')I8G5T97,@87)E
M(&)E:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&1E;&5T960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T94%T=')I8G5T97,H)&ED*0H@("`@
M>PH@("`@("`@("\J($1E;&5T92!A='1R:6)U=&5S+B`J+PH@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%("5S(#T@)7,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%T
M=')I8G5T95]T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)VED7V-O;'5M;B==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@*&EN="DD:60I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R:6)U=&5S.CID96QE=&5!='1R
M:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($=I=F5N(&%N(&ED+"!U<&1A=&4@86QL(&%T=')I8G5T97,@9F]R('1H
M870@:60@:6X@=&AE(&%T=')I8G5T97,@=&%B;&4*("`@("`J('=I=&@@=&AE
M(&YE=R!A='1R:6)U=&5S+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1I9"`@("`@("`@5&AE(&ED(&]F('1H92!R96-O<F0@9F]R('=H:6-H(&%T
M=')I8G5T97,@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)E:6YG(&1E;&5T960N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T
M97,@($%N(&AA<V@@8V]N=&%I;FEN9R!T:&4@871T<FEB=71E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@=7!D871E071T<FEB=71E<R@D:60L("1A='1R:6)U
M=&5S*0H@("`@>PH@("`@("`@("\J($1E;&5T92!T:&4@;VQD(&%T=')I8G5T
M97,N("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YD96QE=&5!='1R:6)U
M=&5S*"1I9"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@("\J($EN<V5R="!T:&4@;F5W(&%T=')I8G5T92!S970N("HO
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YI;G-E<G1!='1R:6)U=&5S*"1I
M9"P@)&%T=')I8G5T97,I.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0G5I;&0@82!P:65C92!O9B!A;B!A='1R:6)U
M=&4@<75E<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9VQU92`@
M("`@5&AE(&=L=64@=&\@:F]I;B!T:&4@8W)I=&5R:6$@*$]2+T%.1"DN"B`@
M("`@*B!`<&%R86T@87)R87D@)&-R:71E<FEA("!4:&4@87)R87D@;V8@8W)I
M=&5R:6$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:F]I;B`@("!3:&]U;&0@
M=V4@:F]I;B!O;B!A(&-L96%N(&%T=')I8G5T97,@=&%B;&4_"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@($%N(%-13"!F<F%G;65N="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V)U:6QD071T<FEB=71E475E<GDH)&=L=64L("1C
M<FET97)I82P@)&IO:6X@/2!F86QS92D*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U-13"YP:'`G.PH*("`@("`@("`O*B!);FET:6%L:7IE
M('1H92!C;&%U<V4@=&AA="!W92=R92!B=6EL9&EN9RX@*B\*("`@("`@("`D
M8VQA=7-E(#T@)R<["@H@("`@("`@("\J($=E="!T:&4@=&%B;&4@86QI87,@
M=&\@=7-E(&9O<B!T:&ES('-E="!O9B!C<FET97)I82X@*B\*("`@("`@("!I
M9B`H)&IO:6XI('L*("`@("`@("`@("`@)&%L:6%S(#T@)'1H:7,M/E]G971!
M;&EA<RAT<G5E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D86QI
M87,@/2`D=&AI<RT^7V=E=$%L:6%S*"D["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L<RD@>PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1V86QS6R=/4B==*2!\?"`A96UP='DH)'9A;'-;
M)T%.1"==*2D@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8VQA=7-E
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)R`G("X@)&=L
M=64@+B`G("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M8VQA=7-E("X]("<H)R`N("1T:&ES+3Y?8G5I;&1!='1R:6)U=&51=65R>2@D
M9VQU92P@)'9A;',I("X@)RDG.PH@("`@("`@("`@("!](&5L<V5I9B`H(65M
M<'1Y*"1V86QS6R=*3TE.)UTI*2!["B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1C;&%U<V4I*2!["B`@("`@("`@("`@("`@("`@("`@)&-L875S92`N
M/2`G("<@+B`D9VQU92`N("<@)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1C;&%U<V4@+CT@)'1H:7,M/E]B=6EL9$%T=')I8G5T95%U
M97)Y*"1G;'5E+"`D=F%L<ULG2D])3B==+"!T<G5E*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L<ULG9FEE
M;&0G72DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;&%U
M<V4I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)R`G
M("X@)&=L=64@+B`G("<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1C;&%U<V4@+CT@2&]R9&5?4U%,.CIB=6EL9$-L875S
M92@D=&AI<RT^7V1B+"`D86QI87,@+B`G+F%T=')I8G5T95\G("X@)'9A;'-;
M)V9I96QD)UTL("1V86QS6R=O<"==+"`D=F%L<ULG=&5S="==*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'9A;',@87,@)'1E<W0I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D8VQA=7-E*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-L875S92`N/2`G("<@+B`D:V5Y("X@)R`G.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1C;&%U
M<V4@+CT@2&]R9&5?4U%,.CIB=6EL9$-L875S92@D=&AI<RT^7V1B+"`D86QI
M87,@+B`G+F%T=')I8G5T95\G("X@)'1E<W1;)V9I96QD)UTL("1T97-T6R=O
M<"==+"`D=&5S=%LG=&5S="==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D8VQA=7-E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&%N(&%L:6%S('1O(&%N(&%T=')I8G5T97,@=&%B;&4L(&EN8W)E;65N=&EN
M9R!I="!I9@H@("`@("H@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1I;F-R96UE;G0@($EN8W)E;65N="!T:&4@86QI87,@8V]U
M;G0_($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T06QI87,H)&EN8W)E;65N="`](&9A;'-E*0H@("`@>PH@("`@("`@('-T
M871I8R`D<V5E;B`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&EN8W)E;65N
M="`F)B`A96UP='DH)'-E96Y;)'1H:7,M/E]T86)L95]C;W5N=%TI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?=&%B;&5?8V]U;G0K*SL*("`@("`@("!]"@H@
M("`@("`@("1S965N6R1T:&ES+3Y?=&%B;&5?8V]U;G1=(#T@=')U93L*("`@
M("`@("!R971U<FX@)V$G("X@)'1H:7,M/E]T86)L95]C;W5N=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC
M92!T;R!A(&-O;F-R971E(%-13"!!='1R:6)U=&5S"B`@("`@*B!I;G-T86YC
M92!B87-E9"!O;B!P87)A;65T97)S('!A<W-E9"X@270@=VEL;"!O;FQY(&-R
M96%T92!A(&YE=PH@("`@("H@:6YS=&%N8V4@:68@;F\@071T<FEB=71E<R!I
M;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,*("`@("`J(&-U<G)E
M;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E
M9"!I9B!M=6QT:7!L92!344P@871T<FEB=71E('1A8FQE<R!A<F4*("`@("`J
M(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@
M:6YV;VME9"!A<SH@)'9A<B`]"B`@("`@*B`F2&]R9&5?4U%,7T%T=')I8G5T
M97,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M($1"("1D8F@@
M("`@("`@($%N(&]B:F5C="!P;VEN=&EN9R!T;R!A(%-13"!D871A8F%S92!H
M86YD;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%!A
M<F%M971E<G,@9F]R('1H92!A='1R:6)U=&5S('1A8FQE+"!C;VYS:7-T:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;V8@=&AE(&9O;&QO=VEN
M9R!K97ES.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=P<FEM87)Y
M7W1A8FQE)R`@("T@=&AE(&UA:6X@4U%,('1A8FQE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@)V%T=')I8G5T95]T86)L92<@+2!T:&4@<V5C;VYD
M('1A8FQE(&-O;G1A:6YI;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!A='1R:6)U=&5S('1O('1H92!M
M86EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T86)L92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`G
M:61?8V]L=6UN)R`@("`@("`M('1H92!N86UE(&]F('1H92!C;VQU;6X@=VET
M:`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE($E$(&]R(&ME>2!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D9&)H+"`D<&%R86US*0H@("`@>PH@("`@("`@('-T
M871I8R`D:6YS=&%N8V5S.PH*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC
M97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@
M("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92@D<&%R86US
M*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI
M*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F;F5W
M($AO<F1E7U-13%]!='1R:6)U=&5S*"1D8F@L("1P87)A;7,I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<```
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-3,R`#$P-#$W,S8R
M-S<S`#`R,3(Q-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A('!A
M<G-E<B!W:&EC:"!C86X@8V]N<W1R=6-T(&%N(%-13"!72$5210H@*B!C;&%U
M<V4@9G)O;2!A($=O;V=L92UL:6ME('-E87)C:"!E>'!R97-S:6]N+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<"QV(#$N
M,BXQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z,S,@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#8@0W)O;F]S>7,L($Q,0R`\:'1T<#HO+W=W=RYC
M<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J(%1H92!E>'!R97-S
M:6]N(')E8V]G;FEZ97,@8F]O;&5A;B`B04Y$(BP@(D]2(BP@86YD(").3U0B
M("AP<F]V:61I;F<*("H@;F\@;W!E<F%T;W(@8F5T=V5E;B!K97EW;W)D<R!I
M;7!L:65S(")!3D0B*2P@;&EK92!S;SH*("H*("H@("!C870@86YD(&1O9PH@
M*B`@(&-A="!O<B!D;V<*("H@("!C870@86YD(&YO="!D;V<*("H*("H@268@
M;F\@;W!E<F%T;W(@87!P96%R<R!B971W965N(&ME>7=O<F1S(&]R('%U;W1E
M9"!S=')I;F=S+"`B04Y$(B!I<PH@*B!A<W-U;65D+B`@02!C;VUM82!C86X@
M8F4@=7-E9"!I;G-T96%D(&]F(")/4B(Z"B`J"B`J("`@8V%T(&1O9PH@*B`@
M(&-A="P@9&]G"B`J("`@8V%T(&YO="!D;V<*("H*("H@5&AE('!A<G-E<B!R
M96-O9VYI>F5S('!A<F5N=&AE<V5S+"!S;R!C;VUP;&5X(&5X<')E<W-I;VYS
M(&-A;B!B90H@*B!C<F5A=&5D.@H@*@H@*B`@(&-A="!A;F0@;F]T("AD;V<@
M;W(@<'5P<'DI"B`J"B`J(%%U;W1E9"!S=')I;F=S(&%R92!A;'-O(')E8V]G
M;FEZ960L(&%N9"!A<F4@=&%K96X@87,@;&ET97)A;`H@*B!K97EW;W)D<SH*
M("H*("H@("`B8V%T(&%N9"!D;V<B"B`J"B`J(%!A<G-I;F<@:7,@9&5S:6=N
M960@=&\@8F4@87,@9G5Z>GD@87,@<&]S<VEB;&4L('-O(&ET('-H;W5L9&XG
M=`H@*B!E<G)O<B!U;FQE<W,@<&5O<&QE('-E87)C:"!F;W(@(D%.1"(L(")/
M4B(L(&]R(").3U0B('=I=&AO=70*("H@<75O=&EN9R!I="!O<B!U<V4@=6YB
M86QA;F-E9"!P87)E;G1H97-E<RX*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@
M1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-13`H@*B\*8VQA<W,@2&]R9&5?
M4U%,7TME>7=O<F1S('L*"B`@("`O*BH*("`@("`J(%!A<G-E(&$@:V5Y=V]R
M9"!E>'!R97-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;'5M;B`@("`@("`@5&AI<R!I<R!T:&4@4U%,(&9I96QD(&YA;64@=&AE(')E
M<W5L=&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E
M>'!R97-S:6]N('-H;W5L9"!T97-T(&%G86EN<W0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1E>'!R("`@("`@("`@(%1H:7,@:7,@=&AE(&ME>7=O<F0@97AP
M<F5S<VEO;B!W92!W86YT('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('!A<G-E+@H@("`@("H@0')E='5R;B!M:7AE9"!T:&4@<75E
M<GD@97AP<F5S<VEO;B!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<&%R<V4H)&-O;'5M;BP@)&5X<'(I"B`@("![
M"B`@("`@("`@+RH@1FER<W0@<&%S<R`M('-C86X@=&AE('-T<FEN9R!F;W(@
M=&]K96YS+B`@0F%R92!W;W)D<R!A<F4*("`@("`@("`@*B!T;VME;G,L(&]R
M('1H92!U<V5R(&-A;B!Q=6]T92!S=')I;F=S('1O(&AA=F4@96UB961D960*
M("`@("`@("`@*B!S<&%C97,L(&ME>7=O<F1S+"!O<B!P87)E;G1H97-E<RX@
M(%!A<F5N=&AE<V5S(&-A;B!B92!U<V5D"B`@("`@("`@("H@9F]R(&=R;W5P
M:6YG(&)O;VQE86X@;W!E<F%T;W)S+"!A;F0@=&AE(&)O;VQE86X@;W!E<F%T
M;W)S"B`@("`@("`@("H@04Y$+"!/4BP@86YD($Y/5"!A<F4@86QL(')E8V]G
M;FEZ960N"B`@("`@("`@("H*("`@("`@("`@*B!4:&4@=&]K96YS(&%R92!R
M971U<FYE9"!I;B!T:&4@)'1O:V5N<R!A<G)A>2`M+2!A;B!A<G)A>2!O9@H@
M("`@("`@("`J('-T<FEN9W,N("!%86-H('-T<FEN9R!I;B!T:&4@87)R87D@
M<W1A<G1S('=I=&@@96ET:&5R(&$@8"$G"B`@("`@("`@("H@;W(@82!@/2<N
M("!@/2<@:7,@82!B87)E('=O<F0@;W(@<75O=&5D('-T<FEN9R!W92!A<F4*
M("`@("`@("`@*B!S96%R8VAI;F<@9F]R+"!A;F0@8"$G(&EN9&EC871E<R!A
M(&)O;VQE86X@;W!E<F%T;W(@;W(*("`@("`@("`@*B!P87)E;G1H97-I<RX@
M($$@=&]K96X@=&AA="!S=&%R=',@=VET:"!A("<N)R`@:6YD:6-A=&5S(&$*
M("`@("`@("`@*B!0;W-T9W)E4U%,('=O<F0@8F]U;F1A<GD@<V5A<F-H+B`J
M+PH@("`@("`@("1T;VME;G,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("@A
M96UP='DH)&5X<'(I*2!["B`@("`@("`@("`@("1E>'!R(#T@<')E9U]R97!L
M86-E*"(O7EQS*R\B+"`B(BP@)&5X<'(I.PH@("`@("`@("`@("!I9B`H96UP
M='DH)&5X<'(I*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1E>'!R+#`L,2D@/3T@)R@G
M*2!["B`@("`@("`@("`@("`@("`D97AP<B`]('-U8G-T<B@D97AP<BP@,2D[
M"B`@("`@("`@("`@("`@("`D=&]K96X@/2`G(2@G.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H<W5B<W1R*"1E>'!R+"`P+"`Q*2`]/2`G*2<I('L*("`@("`@
M("`@("`@("`@("1E>'!R(#T@<W5B<W1R*"1E>'!R+"`Q*3L*("`@("`@("`@
M("`@("`@("1T;VME;B`]("<A*2<["B`@("`@("`@("`@('T@96QS96EF("AS
M=6)S='(H)&5X<'(L(#`L(#$I(#T]("<L)RD@>PH@("`@("`@("`@("`@("`@
M)&5X<'(@/2!S=6)S='(H)&5X<'(L(#$I.PH@("`@("`@("`@("`@("`@)'1O
M:V5N(#T@)R%/4B<["B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H
M*"(O7BA!3D1\3U)\3D]4*2A;7F$M>ETN*BD_)"]I(BP@)&5X<'(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M871C:&5S*2D@>PH@("`@
M("`@("`@("`@("`@)'1O:V5N(#T@)R$G("X@<W1R=&]U<'!E<B@D;6%T8VAE
M<ULQ72D["B`@("`@("`@("`@("`@("`D97AP<B`]('-U8G-T<B@D97AP<BP@
M<W1R;&5N*"1M871C:&5S6S%=*2D["B`@("`@("`@("`@('T@96QS96EF("AP
M<F5G7VUA=&-H*"(O7EPB*"A;7EPB77Q<7%LP+3==*WQ<7%M8>%U;,"TY82UF
M02U&72M\7%Q;7EAX,"TW72DJ*5PB+R(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E>'!R+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@
M("`@("1T;VME;B`]("<])R`N('-T<FEP8W-L87-H97,H)&UA=&-H97-;,5TI
M.PH@("`@("`@("`@("`@("`@)&5X<'(@/2!S=6)S='(H)&5X<'(L('-T<FQE
M;B@D;6%T8VAE<ULP72DI.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M
M871C:"@B+UY;7EQ<<UQ<*%Q<*2Q=*R\B+"`D97AP<BP@)&UA=&-H97,I*2![
M"B`@("`@("`@("`@("`@("`D=&]K96X@/2`G/2<@+B`D;6%T8VAE<ULP73L*
M("`@("`@("`@("`@("`@("1E>'!R(#T@<W5B<W1R*"1E>'!R+'-T<FQE;B@D
M=&]K96XI+3$I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<R(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H)'1O:V5N(#T]("<A04Y$)RD@>PH@("`@("`@("`@("`@("`@+RH@(4%.
M1"!I<R!I;7!L:65D(&)Y(&-O;F-A=&5N871I;VXN("HO"B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&]K
M96YS6UT@/2`D=&]K96X["B`@("`@("`@?0H*("`@("`@("`O*B!#86QL('1H
M92!E>'!R97-S:6]N('!A<G-E<BX@*B\*("`@("`@("!R971U<FX@2&]R9&5?
M4U%,7TME>7=O<F1S.CI?<&%R<V5+97EW;W)D<S$H)&-O;'5M;BP@)'1O:V5N
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<G-E2V5Y=V]R9',Q*"1C;VQU
M;6XL("8D=&]K96YS*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&]K96YS
M*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(D5M<'1Y('-E87)C:"!T97)M<R(I*3L*("`@("`@("!]"B`@("`@("`@
M)&QH<R`]($AO<F1E7U-13%]+97EW;W)D<SHZ7W!A<G-E2V5Y=V]R9',R*"1C
M;VQU;6XL("1T;VME;G,I.PH@("`@("`@(&EF("AI<U]A*"1L:',L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L:',["B`@("`@("`@
M?0H@("`@("`@(&EF("AC;W5N="@D=&]K96YS*2`]/2`P('Q\("1T;VME;G-;
M,%T@(3T@)R%/4B<I('L*("`@("`@("`@("`@<F5T=7)N("1L:',["B`@("`@
M("`@?0H@("`@("`@(&%R<F%Y7W-H:69T*"1T;VME;G,I.PH@("`@("`@("1R
M:',@/2!(;W)D95]344Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S,2@D8V]L
M=6UN+"`D=&]K96YS*3L*("`@("`@("!I9B`H:7-?82@D<FAS+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<FAS.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@(B@@)&QH<R!/4B`D<FAS("DB.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]P87)S94ME>7=O<F1S,B@D8V]L=6UN+"`F)'1O:V5N<RD*
M("`@('L*("`@("`@("`D;&AS(#T@2&]R9&5?4U%,7TME>7=O<F1S.CI?<&%R
M<V5+97EW;W)D<S,H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@("`@:68@*&ES
M7V$H)&QH<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&QH<SL*("`@("`@("!]"B`@("`@("`@:68@*'-I>F5O9B@D=&]K96YS*2`]
M/2`P('Q\("1T;VME;G-;,%T@/3T@)R$I)R!\?"`D=&]K96YS6S!=(#T]("<A
M3U(G*2!["B`@("`@("`@("`@(')E='5R;B`D;&AS.PH@("`@("`@('T*("`@
M("`@("`D<FAS(#T@2&]R9&5?4U%,7TME>7=O<F1S.CI?<&%R<V5+97EW;W)D
M<S(H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@("`@:68@*&ES7V$H)')H<RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')H<SL*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("(H("1L:',@04Y$("1R:',@*2(["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W!A<G-E2V5Y=V]R9',S*"1C;VQU;6XL("8D
M=&]K96YS*0H@("`@>PH@("`@("`@(&EF("@D=&]K96YS6S!=(#T]("<A3D]4
M)RD@>PH@("`@("`@("`@("!A<G)A>5]S:&EF="@D=&]K96YS*3L*("`@("`@
M("`@("`@)&QH<R`]($AO<F1E7U-13%]+97EW;W)D<SHZ7W!A<G-E2V5Y=V]R
M9',T*"1C;VQU;6XL("1T;VME;G,I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M;&AS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&QH<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@(B@@3D]4
M("1L:',@*2(["B`@("`@("`@?0H@("`@("`@(')E='5R;B!(;W)D95]344Q?
M2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S-"@D8V]L=6UN+"`D=&]K96YS*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<&%R<V5+97EW;W)D<S0H)&-O;'5M;BP@
M)B1T;VME;G,I"B`@("!["B`@("`@("`@:68@*"`D=&]K96YS6S!=(#T]("<A
M*"<@*2!["B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1T;VME;G,I.PH@("`@
M("`@("`@("`D;&AS(#T@2&]R9&5?4U%,7TME>7=O<F1S.CI?<&%R<V5+97EW
M;W)D<S$H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@("`@("`@(&EF("AI<U]A
M*"1L:',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D;&AS.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS:7IE;V8H
M)'1O:V5N<RD@/3T@,"!\?"`D=&]K96YS6S!=("$]("<A*2<I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D5X<&5C=&5D
M("<I)R(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G)A>5]S:&EF
M="@D=&]K96YS*3L*("`@("`@("`@("`@<F5T=7)N("1L:',["B`@("`@("`@
M?0H@("`@("`@(&EF("AS=6)S='(H)'1O:V5N<ULP72P@,"P@,2D@(3T@)STG
M("8F"B`@("`@("`@("`@('-U8G-T<B@D=&]K96YS6S!=+"`P+"`R*2`A/2`G
M/2XG*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB*2D[
M"B`@("`@("`@?0H@("`@("`@("1V86P@/2!S=')T;VQO=V5R*'-U8G-T<BAA
M<G)A>5]S:&EF="@D=&]K96YS*2P@,2DI.PH@("`@("`@("1V86P@/2!A9&1S
M;&%S:&5S*&5R96=?<F5P;&%C92@B*%M<7"5=*2(L(")<7%Q<,2(L("1V86PI
M*3L*("`@("`@("!R971U<FX@(B@@3$]715(H)&-O;'5M;BD@3$E+12`G)21V
M86PE)R`I(CL*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+W1E<W1S
M+P``````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<W,P`P,3<S-S<`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O4V-H961U;&5R+P``````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<S`#`R,#$U,P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]38VAE9'5L97(O8W)O;BYP
M:'``````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8T,C``,3`T,3<S
M-C(W-S,`,#(Q-C(V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U-C:&5D=6QE
M<BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ
M"B`J($AO<F1E7U-C:&5D=6QE<E]C<F]N.CH@4V]R="!O9B!A(&-R;VX@<F5P
M;&%C96UE;G0@:6X@82!02%`@8VQI"B`J('-C<FEP="X*("H*("H@1&%T92!3
M>6YT87@@17AA;7!L97,N"B`J"B`J(%)E;65M8F5R.@H@*B`@("T@5VAI=&5S
M<&%C92`H<W!A8V4L('1A8BP@;F5W;&EN92D@9&5L:6UI=&5D(&9I96QD<PH@
M*B`@("T@4VEN9VQE('9A;'5E<RP@<V5T<RP@<F%N9V5S+"!W:6QD8V%R9',*
M("H*("H@4T5#3TY$("`@34E.551%("`@("`@("`@("`@("!(3U52("`@("`@
M("!$05D@("`@($U/3E1("B`J("H@("`@("`@("H@("`@("`@("`@("`@("`@
M("`@*B`@("`@("`@("`@*B`@("`@("`J("`@("`@("AE=F5R>2!S96-O;F0I
M"B`J(#`L,S`@("`@("H@("`@("`@("`@("`@("`@("`@*B`@("`@("`@("`@
M*B`@("`@("`J("`@("`@("AE=F5R>2`S,"!S96-O;F1S*0H@*B`P("`@("`@
M("`P+#$P+#(P+#,P+#0P+#4P("`@("H@("`@("`@("`@("H@("`@("`@*B`@
M("`@("`H979E<GD@,3`@;6EN=71E<RD*("H@,"`@("`@("`@,"`@("`@("`@
M("`@("`@("`@("`J("`@("`@("`@("`J("`@("`@("H@("`@("`@*&)E9VEN
M;FEN9R!O9B!E=F5R>2!H;W5R*0H@*B`P("`@("`@("`P("`@("`@("`@("`@
M("`@("`@(#`L-BPQ,BPQ."`@("H@("`@("`@*B`@("`@("`H870@;6ED;FEG
M:'0L(#9A;2P@;F]O;BP@-G!M*0H@*B`P("`@("`@("`P("`@("`@("`@("`@
M("`@("`@(#`@("`@("`@("`@(#$M-R9&<FD@*B`@("`@("`H;6ED;FEG:'0L
M(&9I<G-T($9R:2!O9B!T:&4@;6]N=&@I"B`J(#`@("`@("`@(#`@("`@("`@
M("`@("`@("`@("`@,"`@("`@("`@("`@,2TW(49R:2`J("`@("`@("AM:61N
M:6=H="P@9FER<W0@36]N+51H=2Q3870M4W5N(&]F('1H92!M;VYT:"D*("H*
M("H*("H@17AA;7!L92!U<V%G93H*("H*("H@0'-E=%]T:6UE7VQI;6ET*#`I
M.PH@*B!R97%U:7)E7V]N8V4@)TAO<F1E+U-C:&5D=6QE<BYP:'`G.PH@*B`D
M8W)O;B`]("9(;W)D95]38VAE9'5L97(Z.G-I;F=L971O;B@G8W)O;B<I.PH@
M*@H@*B`O+R!2=6X@=&AI<R!C;VUM86YD(&5V97)Y(#4@;6EN=71E<RX*("H@
M)&-R;VXM/F%D9%1A<VLH)W!E<FP@<V]M97-C<FEP="YP;"<L("<P(#`L-2PQ
M,"PQ-2PR,"PR-2PS,"PS-2PT,"PT-2PU,"PU-2`J("H@*B<I.PH@*@H@*B`O
M+R!2=6X@=&AI<R!C;VUM86YD(&UI9&YI9VAT(&]F('1H92!F:7)S="!&<FED
M87D@;V8@;V1D(&YU;6)E<F5D(&UO;G1H<RX*("H@)&-R;VXM/F%D9%1A<VLH
M)W!H<"`M<2!S;VUE<V-R:7!T+G!H<"<L("<P(#`@,"`Q+3<F1G)I(#$L,RPU
M+#<L.2PQ,2<I.PH@*@H@*B`O+R!!;'-O(')U;B!T:&ES(&-O;6UA;F0@;6ED
M;FEG:'0@;V8@=&AE('-E8V]N9"!4:'5R<V1A>2!A;F0@4V%T=7)D87D@;V8@
M=&AE(&5V96X@;G5M8F5R960@;6]N=&AS+@H@*B`D8W)O;BT^861D5&%S:R@G
M<&AP("UQ('-O;65S8W)I<'0N<&AP)RP@)S`@,"`P(#@M,34F5&AU+#@M,34F
M4V%T(#(L-"PV+#@L,3`L,3(G*3L*("H*("H@)&-R;VXM/G)U;B@I.PH@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]38VAE9'5L97(O4V-H961U;&5R+V-R;VXN
M<&AP+'8@,2XQ,RXQ,"XS(#(P,#4O,3`O,3@@,3$Z,#$Z,C8@:F%N($5X<"`D
M"B`J"B`J($!A=71H;W(@(%)Y86X@1FQY;FX@/')Y86Y`<GEA;F9L>6YN+F-O
M;3X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!P86-K86=E($AO<F1E7U-C:&5D=6QE<@H@*B\*8VQA<W,@2&]R
M9&5?4V-H961U;&5R7V-R;VX@97AT96YD<R!(;W)D95]38VAE9'5L97(@>PH*
M("`@('9A<B`D7W1A<VMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($5V
M97)Y('1I;64@82!T87-K(&ES(&%D9&5D(&ET('=I;&P@9V5T(&$@9G)E<V@@
M=6ED(&5V96X@:68*("`@("`J(&EM;65D:6%T96QY(')E;6]V960N"B`@("`@
M*B\*("`@('9A<B`D7V-O=6YT97(@/2`Q.PH*("`@(&9U;F-T:6]N(&%D9%1A
M<VLH)&-M9"P@)')U;&5S*0H@("`@>PH@("`@("`@("1D<R`]("9N97<@2&]R
M9&5?4V-H961U;&5R7V-R;VY$871E*"1R=6QE<RD["@H@("`@("`@("1T:&ES
M+3Y?8V]U;G1E<BLK.PH*("`@("`@("`D=&AI<RT^7W1A<VMS6UT@/0H@("`@
M("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("=U:60G(#T^("1T:&ES
M+3Y?8V]U;G1E<BP*("`@("`@("`@("`@("`@("=R=6QE<R<@/3X@)&1S+`H@
M("`@("`@("`@("`@("`@)V-M9"<@/3X@)&-M9`H@("`@("`@("`@("`I.PH*
M("`@("`@("!R971U<FX@)'1H:7,M/E]C;W5N=&5R.PH@("`@?0H*("`@(&9U
M;F-T:6]N(')E;6]V951A<VLH)'5I9"D*("`@('L*("`@("`@("`D8V]U;G0@
M/2!C;W5N="@D=&AI<RT^7W1A<VMS*3L*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M=&%S:W-;)W5I9"==(#T]("1U:60I('L*("`@("`@("`@("`@("`@("1F;W5N
M9"`]("1I.PH@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E*"1T:&ES+3Y?
M=&%S:W,L("1I*3L*("`@("`@("`@("`@("`@(')E='5R;B`D:3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(#`["B`@("!]"@H@
M("`@9G5N8W1I;VX@<G5N*"D*("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1T
M:&ES+3Y?=&%S:W,I*2!["B`@("`@("`@("`@(&5X:70H(F-R;VYD.B!.;W1H
M:6YG('1O('-C:&5D=6QE.R!E>&ET:6YG+EQN(BD["B`@("`@("`@?0H*("`@
M("`@("!W:&EL92`H=')U92D@>PH@("`@("`@("`@("`D="`]('1I;64H*3L*
M"B`@("`@("`@("`@("\O($-H96-K(&5A8V@@=&%S:RX*("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]T87-K<R!A<R`D=&%S:RD@>PH@("`@("`@("`@
M("`@("`@:68@*"1T87-K6R=R=6QE<R==+3YN;W=-871C:&5S*"DI('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<G5N8VUD*"1T87-K*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@5V%I
M="!U;G1I;"!T:&4@;F5X="!S96-O;F0N"B`@("`@("`@("`@('=H:6QE("AT
M:6UE*"D@/3T@)'0I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS;&5E<"@Q
M,#`P,#`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(')U;F-M9"@F)'1A<VLI"B`@("!["B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)TAO<F1E7U-C:&5D=6QE<E]#<F]N.CIR=6YC;60H*3H@)R`N
M("1T87-K6R=C;60G72`N("<@<G5N(&)Y("<@+B`D=&%S:ULG=6ED)UTL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@<F5T
M=7)N('-H96QL7V5X96,H)'1A<VM;)V-M9"==*3L*("`@('T*"GT*"B\J*@H@
M*B!`<&%C:V%G92!(;W)D95]38VAE9'5L97(*("HO"F-L87-S($AO<F1E7U-C
M:&5D=6QE<E]C<F]N1&%T92!["@H@("`@=F%R("1L96=A;$1A>7,@/2!A<G)A
M>2@G34].)RP@)U1512<L("=7140G+"`G5$A5)RP@)T9222<L("=3050G+"`G
M4U5.)RD["@H@("`@=F%R("1S96,["B`@("!V87(@)&UI;CL*("`@('9A<B`D
M:&]U<CL*("`@('9A<B`D9&%Y.PH@("`@=F%R("1M;VYT:#L*"B`@("!F=6YC
M=&EO;B!(;W)D95]38VAE9'5L97)?8W)O;D1A=&4H)')A=RD*("`@('L*("`@
M("`@("`D=&AI<RT^<&%R<V4H4W1R:6YG.CIU<'!E<B@D<F%W*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@;F]W36%T8VAE<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YS8VAE9'5L961!="AT:6UE*"DI.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-C:&5D=6QE9$%T*"1T<R`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"1T<R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D=',@/2!T:6UE*"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`H)'1H:7,M/FUO;G1H36%T8VAE
M<R@D=',I("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^;6]N=&A-871C:&5S
M*"1T<RD@)B8*("`@("`@("`@("`@("`@("1T:&ES+3YD87E-871C:&5S*"1T
M<RD@)B8*("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R36%T8VAE<R@D=',I
M("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^;6EN36%T8VAE<R@D=',I("8F
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5C36%T8VAE<R@D=',I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!M;VYT:$UA=&-H97,H)'1S*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^;6]N=&@@/3T@)RHG*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&-U<G)E;G1M;VYT:"`]
M("<M)R`N(&1A=&4H)VXG+"`D=',I("X@)RTG.PH*("`@("`@("!R971U<FX@
M*&)O;VPI<W1R<&]S*"1T:&ES+3YM;VYT:"P@)&-U<G)E;G1M;VYT:"D["B`@
M("!]"@H@("`@9G5N8W1I;VX@9&%Y36%T8VAE<R@D=',I"B`@("!["B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^9&%Y6R=V86QU92==*2`F)B`D=&AI<RT^
M9&%Y6R=V86QU92==(#T]("<J)RD@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"@H@("`@("`@("1C=7)R96YT9&%Y;G5M(#T@)RTG("X@
M9&%T92@G:B<L("1T<RD@+B`G+2<["B`@("`@("`@)&-U<G)E;G1D87ET>'0@
M/2!3=')I;F<Z.G5P<&5R*&1A=&4H)T0G*2D["@H@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YD87D@87,@)&1A>2D@>PH@("`@("`@("`@("!I9B`H0'-T<G!O
M<R@D9&%Y6R=N;W0G72P@)&-U<G)E;G1D87ET>'0I(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)'8Q(#T@*$!S=')P;W,H)&1A>5LG=F%L=64G72P@
M)&-U<G)E;G1D87EN=6TI("$]/2!F86QS92D["B`@("`@("`@("`@("`@("`D
M=C(@/2`H0'-T<G!O<R@D9&%Y6R=A;F0G72P@)&-U<G)E;G1D87ET>'0I("$]
M/2!F86QS92D["@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9&%Y6R=A
M;F0G72D@)B8@*"1V,2`F)B`D=C(I*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H96UP='DH
M)&1A>5LG86YD)UTI("8F("1V,2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N
M8W1I;VX@:&]U<DUA=&-H97,H)'1S*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^:&]U<B`]/2`G*B<I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("`D8W5R<F5N=&AO=7(@/2`G+2<@+B!D871E*"='
M)RP@)'1S*2`N("<M)SL*"B`@("`@("`@<F5T=7)N("AS=')P;W,H)'1H:7,M
M/FAO=7(L("1C=7)R96YT:&]U<BD@(3T](&9A;'-E*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!M:6Y-871C:&5S*"1T<RD*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/FUI;B`]/2`G*B<I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("`D8W5R<F5N=&UI;B`]("<M)R`N(&EN='9A;"AD
M871E*"=I)RP@)'1S*2D@+B`G+2<["@H@("`@("`@(')E='5R;B`H<W1R<&]S
M*"1T:&ES+3YM:6XL("1C=7)R96YT;6EN*2`A/3T@9F%L<V4I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-E8TUA=&-H97,H)'1S*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^<V5C(#T]("<J)RD@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"@H@("`@("`@("1C=7)R96YT<V5C(#T@)RTG("X@:6YT
M=F%L*&1A=&4H)W,G+"`D=',I*2`N("<M)SL*"B`@("`@("`@<F5T=7)N("AS
M=')P;W,H)'1H:7,M/G-E8RP@)&-U<G)E;G1S96,I("$]/2!F86QS92D["B`@
M("!]"@H@("`@9G5N8W1I;VX@<&%R<V4H)'-T<BD*("`@('L*("`@("`@("`D
M<R`](&%R<F%Y*"D["@H@("`@("`@(&QI<W0H)'-;)W-E8R==+"`D<ULG;6EN
M)UTL("1S6R=H;W5R)UTL("1S6R=D87DG72P@)'-;)VUO;G1H)UTI(#T@<')E
M9U]S<&QI="@G?%M<;EQT(%TK?"<L("1S='(I.PH*("`@("`@("!F;W)E86-H
M("@D<R!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1V
M+"`G*B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'-;)&M=(#T@
M87)R87DH)RHG*3L*("`@("`@("`@("`@?2!E;'-E:68@*"$D=&AI<RT^9V5N
M97)A;&QY1&5C96YT4WEN=&%X*"1V*2D@>PH@("`@("`@("`@("`@("`@9&EE
M*"));&QE9V%L('-Y;G1A>"!I;B`G)'8G7&XB*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1S6R1K72`](&5X<&QO9&4H)RPG+"`D
M<ULD:UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'-;)W-E8R==6S!=(#T]("<J)RD@>PH@("`@("`@("`@("`D=&AI<RT^<V5C
M(#T@)RHG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\('-I>F5O9B@D<ULG<V5C)UTI.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/FES4F%N9V4H)'-;)W-E8R==6R1I72DI('L*
M("`@("`@("`@("`@("`@("`@("`D<ULG<V5C)UU;)&E=(#T@)'1H:7,M/F5X
M<&%N9%)A;F=E*"1T:&ES+3YR86YG959A;',H)'-;)W-E8R==6R1I72DI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T
M:&ES+3YS96,@/2`G+2<@+B!J;VEN*"<M)RP@)'-;)W-E8R==*2`N("<M)SL*
M("`@("`@("!]"@H@("`@("`@(&EF("@D<ULG;6EN)UU;,%T@/3T@)RHG*2![
M"B`@("`@("`@("`@("1T:&ES+3YM:6X@/2`G*B<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1S6R=M
M:6XG72D[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-2
M86YG92@D<ULG;6EN)UU;)&E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1S
M6R=M:6XG75LD:5T@/2`D=&AI<RT^97AP86YD4F%N9V4H)'1H:7,M/G)A;F=E
M5F%L<R@D<ULG;6EN)UU;)&E=*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/FUI;B`]("<M)R`N(&IO:6XH
M)RTG+"`D<ULG;6EN)UTI("X@)RTG.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1S6R=H;W5R)UU;,%T@/3T@)RHG*2!["B`@("`@("`@("`@("1T:&ES+3YH
M;W5R(#T@)RHG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\('-I>F5O9B@D<ULG:&]U<B==*3L@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YI<U)A;F=E*"1S6R=H;W5R)UU;)&E=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1S6R=H;W5R)UU;)&E=(#T@)'1H
M:7,M/F5X<&%N9%)A;F=E*"1T:&ES+3YR86YG959A;',H)'-;)VAO=7(G75LD
M:5TI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^:&]U<B`]("<M)R`N(&IO:6XH)RTG+"`D<ULG:&]U<B==
M*2`N("<M)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D<ULG9&%Y)UU;,%T@
M/3T@)RHG*2!["B`@("`@("`@("`@("1T:&ES+3YD87D@/2`G*B<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ
M96]F*"1S6R=D87DG72D[("1I*RLI('L*("`@("`@("`@("`@("`@("1T;7`@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@:68@*"@D8VAA<B`]("1T:&ES
M+3YI<T-O;F0H)'-;)V1A>2==6R1I72DI("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D8VAA<B`]/2`G)B<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@;&ES="@D=&UP6R=V86QU92==+"`D=&UP6R=A;F0G72D@
M/2!E>'!L;V1E*"1C:&%R+"`D<ULG9&%Y)UU;)&E=*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YI<U)A;F=E*"1T;7!;)V%N9"==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1M<%LG86YD)UT@/2`D
M=&AI<RT^97AP86YD4F%N9V4H)'1H:7,M/G)A;F=E5F%L<R@D=&UP6R=A;F0G
M72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D
M=&UP6R=V86QU92==+"`D=&UP6R=N;W0G72D@/2!E>'!L;V1E*"1C:&%R+"`D
M<ULG9&%Y)UU;)&E=*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YI<U)A;F=E*"1T;7!;)VYO="==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1M<%LG;F]T)UT@/2`D=&AI<RT^97AP86YD4F%N9V4H
M)'1H:7,M/G)A;F=E5F%L<R@D=&UP6R=N;W0G72DI.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@87)R
M87DH)W9A;'5E)R`]/B`D<ULG9&%Y)UU;)&E=*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D<ULG9&%Y)UU;)&E=(#T@)'1M<#L*"B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES4F%N9V4H)'-;)V1A>2==6R1I
M75LG=F%L=64G72DI('L*("`@("`@("`@("`@("`@("`@("`D<ULG9&%Y)UU;
M)&E=6R=V86QU92==(#T@)'1H:7,M/F5X<&%N9%)A;F=E*"1T:&ES+3YR86YG
M959A;',H)'-;)V1A>2==6R1I75LG=F%L=64G72DI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^9&%Y(#T@
M)'-;)V1A>2==.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S6R=M;VYT:"==
M6S!=(#T]("<J)RD@>PH@("`@("`@("`@("`D=&AI<RT^;6]N=&@@/2`G*B<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@<VEZ96]F*"1S6R=M;VYT:"==*3L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YI<U)A;F=E*"1S6R=M;VYT:"==6R1I72DI('L*("`@
M("`@("`@("`@("`@("`@("`D<ULG;6]N=&@G75LD:5T@/2`D=&AI<RT^97AP
M86YD4F%N9V4H)'1H:7,M/G)A;F=E5F%L<R@D<ULG;6]N=&@G75LD:5TI*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^;6]N=&@@/2`G+2<@+B!J;VEN*"<M)RP@)'-;)VUO;G1H)UTI("X@
M)RTG.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I<T-O;F0H)',I
M"B`@("!["B`@("`@("`@:68@*'-T<G!O<R@D<RP@)R8G*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N("<F)SL*("`@("`@("!](&5L<V5I9B`H
M<W1R<&]S*"1S+"`G(2<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@)R$G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-286YG92@D
M<RD*("`@('L*("`@("`@("!R971U<FX@<')E9U]M871C:"@G+UY<=RM<+5QW
M*R\G+"`D<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:7-#;VYD4F%N9V4H)',I
M"B`@("!["B`@("`@("`@<F5T=7)N("AI<T-O;F0H)',I("8F(&ES4F%N9V4H
M)',I*3L*("`@('T*"B`@("!F=6YC=&EO;B!I<T-O;F1686PH)',I"B`@("![
M"B`@("`@("`@<F5T=7)N("AI<T-O;F0H)',I("8F("%I<U)A;F=E*"1S*2D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<F%N9V5686QS*"1S*0H@("`@>PH@("`@
M("`@(')E='5R;B!E>'!L;V1E*"<M)RP@)',I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&5X<&%N9%)A;F=E*"1L+"`D:"`]("<G*0H@("`@>PH@("`@("`@("\O
M($5X<&%N9"!R86YG92!F<F]M(#$M-2`M/B`G+3$M,BTS+30M-2TG+@H@("`@
M("`@(&EF("AI<U]A<G)A>2@D;"DI('L*("`@("`@("`@("`@)&@@/2`D;%LQ
M73L*("`@("`@("`@("`@)&P@/2`D;%LP73L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=&AI<RT^:7-$:6=I="@D;"DI('L*("`@("`@("`@("`@:68@*"$D
M=&AI<RT^:7-$:6=I="@D:"DI('L*("`@("`@("`@("`@("`@(&1I92@B26YV
M86QI9"!V86QU92`G)&@G(&EN(')A;F=E("<D;"TD:"<B*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R\@0W5R<F5N=&QY('1H97)E(&ES(&YO('!O
M<W-I8FQE(')E87-O;B!T;R!N965D('1O(&1O(&$*("`@("`@("`@("`@+R\@
M<F%N9V4@8F5Y;VYD(#`M-3D@9F]R(&%N>71H:6YG+@H@("`@("`@("`@("!I
M9B`H)&P@/"`P*2!["B`@("`@("`@("`@("`@("`D;"`](#`["B`@("`@("`@
M("`@('T@96QS96EF("@D;"`^(#4Y*2!["B`@("`@("`@("`@("`@("`D;"`]
M(#4Y.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&@@/"`P*2![
M"B`@("`@("`@("`@("`@("`D:"`](#`["B`@("`@("`@("`@('T@96QS96EF
M("@D:"`^(#4Y*2!["B`@("`@("`@("`@("`@("`D:"`](#4Y.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9B`H)&P@/B`D:"D@>PH@("`@("`@("`@
M("`@("`@)'1M<"`]("1L.PH@("`@("`@("`@("`@("`@)&P@/2`D:#L*("`@
M("`@("`@("`@("`@("1H(#T@)'1M<#L*("`@("`@("`@("`@("`@('5N<V5T
M*"1T;7`I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!&;W(@<V]M
M92!R96%S;VX@<F%N9V4H*2!D;V5S;B=T('=O<FL@=R]O('1H92!E>'!L:6-I
M=`H@("`@("`@("`@("`O+R!I;G1V86PH*2!C86QL<RX*("`@("`@("`@("`@
M<F5T=7)N("<M)R`N(&IO:6XH)RTG+"!R86YG92AI;G1V86PH)&PI+"!I;G1V
M86PH)&@I*2D@+B`G+2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+R\@26YV86QI9"X*("`@("`@("`@("`@9&EE*"));G9A;&ED('9A;'5E("<D
M;"<@:6X@<F%N9V4@)R1L+21H)R(I.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!D87E686QU92@D<RD*("`@('L*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!C;W5N="@D=&AI<RT^;&5G86Q$87ES*3L@)&DK*RD@>PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/FQE9V%L1&%Y<ULD:5T@/3T@)',I('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D:3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("TQ.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES
M1&EG:70H)',I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?;6%T8V@H)R]>
M7&0K)"\G+"`D<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:7-!;'!H82@D<RD*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FES3&5G86Q$87DH)',I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&ES3&5G86Q$87DH)',I"B`@("!["B`@("`@
M("`@<F5T=7)N(&EN7V%R<F%Y*"1S+"`D=&AI<RT^;&5G86Q$87ES*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!G96YE<F%L;'E$96-E;G13>6YT87@H)',I"B`@
M("!["B`@("`@("`@<F5T=7)N("@D<R`]/2`G*B<@?'P*("`@("`@("`@("`@
M("`@('!R96=?;6%T8V@H)R]>7&0K*"U<9"LI/RA;(29=6T$M6EPJ72LH+5M!
M+5I<*ETK*3\I/R@L7&0K*"U<9"LI/RA;(29=6T$M6EPJ72LH+5M!+5I<*ETK
M*3\I/RDJ)"\G+"`D<RDI.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]%9&ET;W(O````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-S,`,#$W-#8S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T5D:71O<B]H=&UL87)E82YP:'``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C8S,``Q,#0Q-S,V,C<W,P`P,C$W-S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!%9&ET;W)?:'1M;&%R96$Z.B!C;&%S<R!P<F]V:61E<R!A;B!765-)5UE'
M(&5D:71O<B!F;W(@=7-E"B`J(&EN('1H92!(;W)D92!&<F%M97=O<FLN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T5D:71O<B]%9&ET;W(O:'1M;&%R96$N
M<&AP+'8@,2XR-"XT+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-"!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!.=6YO($QO=7)E:7)O(#QN=6YO
M0&-O+G-A<&\N<'0^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($YU;F\@3&]U<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H@0&%U=&AO
M<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T5D:71O<@H@*B\*8VQA<W,@
M2&]R9&5?161I=&]R7VAT;6QA<F5A(&5X=&5N9',@2&]R9&5?161I=&]R('L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+B!);F-L=61E('1H92!N96-E
M<W-A<GD@:F%V87-C<FEP="!F:6QE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?161I=&]R7VAT;6QA<F5A*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1N;W1I9FEC871I;VXL("1P
M<F5F<SL*"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAT;6QA<F5A
M+FIS)RP@)VAO<F1E)RD["B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)R]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M;&%R96$N:G,G+"`G:&]R
M9&4G+"!T<G5E*3L*("`@("`@("`D<V-R:7!T(#T@2&]R9&4Z.G5R;"A5=&EL
M.CIA9&1087)A;65T97(H)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R
M9&4G*2`N("<O<V5R=FEC97,O:F%V87-C<FEP="YP:'`G+"`G87!P)RP@)VAO
M<F1E)RDL('1R=64I.PH@("`@("`@("1J<R`]("=(5$U,07)E82YL;V%D4V-R
M:7!T*"(G("X@571I;#HZ861D4&%R86UE=&5R*"1S8W)I<'0L("=F:6QE)RP@
M("=H=&UL87)E85]L86YG+FIS)RP@9F%L<V4I("X@)R(I.R`G.PH*("`@("`@
M("`D<&QU9VEN<R`]("<G.PH@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E
M*"=T86)L96]P97)A=&EO;G,G*2D@>PH@("`@("`@("`@("`D:G,@+CT@)TA4
M34Q!<F5A+FQO8610;'5G:6XH(E1A8FQE3W!E<F%T:6]N<R(I.R`G("X*("`@
M("`@("`@("`@("`@("`@("=(5$U,07)E82YL;V%D4V-R:7!T*"(G("X@571I
M;#HZ861D4&%R86UE=&5R*"1S8W)I<'0L("=F:6QE)RP@("=H=&UL87)E85]T
M86)L95]L86YG+FIS)RP@9F%L<V4I("X@)R(I.R`G.PH@("`@("`@("`@("`D
M<&QU9VEN<R`N/2`G961I=&]R+G)E9VES=&5R4&QU9VEN*%1A8FQE3W!E<F%T
M:6]N<RD[("<["B`@("`@("`@?0H@("`@("`@(&EF("@D<')E9G,M/F=E=%9A
M;'5E*"=C;VYT97AT;65N=2<I*2!["B`@("`@("`@("`@("1J<R`N/2`G2%1-
M3$%R96$N;&]A9%!L=6=I;B@B0V]N=&5X=$UE;G4B*3L@)R`N"B`@("`@("`@
M("`@("`@("`@("`G2%1-3$%R96$N;&]A9%-C<FEP="@B)R`N(%5T:6PZ.F%D
M9%!A<F%M971E<B@D<V-R:7!T+"`G9FEL92<L("`G:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS)RP@9F%L<V4I("X@)R(I.R`G.PH@("`@("`@("`@("`D<&QU
M9VEN<R`N/2`G961I=&]R+G)E9VES=&5R4&QU9VEN*$-O;G1E>'1-96YU*3L@
M)SL*("`@("`@("!]"B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)VQI
M<W1T>7!E)RDI('L*("`@("`@("`@("`@)&IS("X]("=(5$U,07)E82YL;V%D
M4&QU9VEN*"),:7-T5'EP92(I.R`G("X*("`@("`@("`@("`@("`@("`@("=(
M5$U,07)E82YL;V%D4V-R:7!T*"(G("X@571I;#HZ861D4&%R86UE=&5R*"1S
M8W)I<'0L("=F:6QE)RP@("=H=&UL87)E85]L:7-T='EP95]L86YG+FIS)RP@
M9F%L<V4I("X@)R(I.R`G.PH@("`@("`@("`@("`D<&QU9VEN<R`N/2`G961I
M=&]R+G)E9VES=&5R4&QU9VEN*$QI<W14>7!E*3L@)SL*("`@("`@("!]"B`@
M("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)V%N<V5L:6UA9V4G*2`F)B`D
M<F5G:7-T<GDM/FAA<TUE=&AO9"@G:6UA9V5S+VQI<W1'86QL97)I97,G*2D@
M>PH@("`@("`@("`@("`D:G,@+CT@)TA434Q!<F5A+FQO8610;'5G:6XH(D%N
M<V5L26UA9V4B*3L@)R`N"B`@("`@("`@("`@("`@("`@("`G2%1-3$%R96$N
M;&]A9%-C<FEP="@B)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D<V-R:7!T+"`G
M9FEL92<L("`G:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS)RP@9F%L<V4I
M("X@)R(I.R`G.PH@("`@("`@("`@("`D<&QU9VEN<R`N/2`G961I=&]R+G)E
M9VES=&5R4&QU9VEN*$%N<V5L26UA9V4I.R`G.PH@("`@("`@('T*"B`@("`@
M("`@)&IS("X]("=(5$U,07)E82YO;FQO860@/2!F=6YC=&EO;B@I('L@)R`N
M"B`@("`@("`@("`@("`@("=V87(@8V]N9FEG(#T@;F5W($A434Q!<F5A+D-O
M;F9I9R@I(#LG("X*("`@("`@("`@("`@("`@)V-O;F9I9RYD96)U9R`](&9A
M;'-E.R`G("X*("`@("`@("`@("`@("`@)V-O;F9I9RYH:61E4V]M94)U='1O
M;G,H(B!S:&]W:&5L<"`B*3L@)SL*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG8V]N9FEG)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7-;
M)V-O;F9I9R==(&%S("1C;VYF:6<@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("`D:G,@+CT@)V-O;F9I9RXG("X@)&-O;F9I9R`N("<@/2`B)R`N(&%D
M9'-L87-H97,H)'9A;'5E*2`N("<B.R<["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=I9"==*2D@>PH@("`@
M("`@("`@("`D:G,@+CT@)W9A<B!T97AT87)E87,@/2!;9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H(B<@+B`D<&%R86US6R=I9"==("X@)R(I73L@)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:G,@+CT@)W9A<B!T97AT87)E
M87,@/2!D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@B=&5X=&%R96$B
M*3L@)SL*("`@("`@("!]"B`@("`@("`@)&IS("X]("=F;W(@*'9A<B!I(#T@
M=&5X=&%R96%S+FQE;F=T:"`M(#$[(&D@/CT@,#L@:2TM*2![("<@+@H@("`@
M("`@("`@("`@("`G=F%R(&5D:71O<B`](&YE=R!(5$U,07)E82AT97AT87)E
M87-;:5TL(&-O;F9I9RD[("<@+@H@("`@("`@("`@("`@("`D<&QU9VEN<R`N
M"B`@("`@("`@("`@("`@("=E9&ET;W(N9V5N97)A=&4H*7U].R`G("X*("`@
M("`@("`@("`@("`@)TA434Q!<F5A+FEN:70H*3LG.PH*("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*"1J<RP@)VIA=F%S8W)I<'0G*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]);6%G92\`````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S,`,#$W,C4W`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+V=D+G!H<```````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P-S8T-@`Q,#0Q-S,V,C<W,P`P
M,C`S-S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXO26UA9V4N<&AP)SL*"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@
M=&AE($AO<F1E7TEM86=E.CH@05!)(&9O<B!T:&4@4$A0($=$"B`J(&5X=&5N
M<VEO;BX@270@;6%I;FQY('!R;W9I9&5S('-O;64@=71I;&ET>2!F=6YC=&EO
M;G,L('-U8V@@87,@=&AE"B`J(&%B:6QI='D@=&\@;6%K92!P:7AE;',L(&9O
M<B!N;W<N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TEM86=E+TEM86=E+V=D
M+G!H<"QV(#$N-#@N,3`N,30@,C`P-B\P,2\P,2`R,3HR.#HR,B!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?26UA9V4*("HO"F-L87-S
M($AO<F1E7TEM86=E7V=D(&5X=&5N9',@2&]R9&5?26UA9V4@>PH*("`@("\J
M*@H@("`@("H@0V%P86)I;&ET97,@;V8@=&AI<R!D<FEV97(N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C87!A8FEL:71I
M97,@/2!A<G)A>2@G<F5S:7IE)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C<F]P)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R;W1A=&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9L
M:7`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUI<G)O<B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9W)A>7-C86QE)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S97!I82<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G>65L;&]W:7IE)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=W871E<FUA<FLG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V-A;G9A<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`I.PH*("`@("\J*@H@("`@("H@5VAA="!K:6YD(&]F
M(&EM86=E<R!S:&]U;&0@1T0@9V5N97)A=&4_($1E9F%U;'1S('1O("=P;F<G
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W1Y<&4@/2`G<&YG)SL*"B`@("`O*BH*("`@("`J($=$($EM86=E(')E<V]U
M<F-E(&9O<B!T:&4@8W5R<F5N="!I;6%G92!D871A+@H@("`@("H*("`@("`J
M($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?:6T["@H@("`@+RHJ
M"B`@("`@*B!3=')I;F<@:61E;G1I9FEE<B!O9B!T:&4@8W5R<F5N="!I;6%G
M92X@3F5W(&EM86=E(&1A=&$@=VEL;"!N;W0@8F4*("`@("`J(&QO861E9"!I
M9B!T:&4@<V%M92!I9"!I<R!A;')E861Y(&QO861E9"X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I9"`]("<G.PH*("`@
M(&9U;F-T:6]N($AO<F1E7TEM86=E7V=D*"1P87)A;7,I"B`@("!["B`@("`@
M("`@<&%R96YT.CI(;W)D95]);6%G92@D<&%R86US*3L*("`@("`@("!I9B`H
M(65M<'1Y*"1P87)A;7-;)W1Y<&4G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]T>7!E(#T@)'!A<F%M<ULG='EP92==.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D<&%R86US6R=W:61T:"==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7VEM(#T@)B1T:&ES+3Y?8W)E871E*"1T:&ES+3Y?=VED=&@L("1T
M:&ES+3Y?:&5I9VAT*3L*("`@("`@("`@("`@)'1H:7,M/E]C86QL*"=I;6%G
M949I;&PG+"!A<G)A>2@D=&AI<RT^7VEM+"`P+"`P+"`D=&AI<RT^86QL;V-A
M=&5#;VQO<B@D=&AI<RT^7V)A8VMG<F]U;F0I*2D["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14>7!E*"D*("`@('L*("`@("`@
M("!R971U<FX@)VEM86=E+R<@+B`D=&AI<RT^7W1Y<&4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$:7-P;&%Y('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("`D=&AI<RT^
M:&5A9&5R<R@I.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-A;&PH)VEM86=E
M)R`N("1T:&ES+3Y?='EP92P@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<F%W(&1A=&$@9F]R('1H:7,@
M:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-O;G9E<G0@
M($EF('1R=64L('1H92!I;6%G92!D871A('=I;&P@8F4@<F5T=7)N960@:6X@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&%R9V5T(&9O
M<FUA="P@:6YD97!E;F1E;G1L>2!F<F]M(&%N>2!I;6%G90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]P97)A=&EO;G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!R87<@:6UA9V4@9&%T82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F%W*"1C;VYV97)T(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@<F5T=7)N(%5T:6PZ.F)U9F9E<D]U='!U="@G:6UA9V4G("X@)'1H
M:7,M/E]T>7!E+"`D=&AI<RT^7VEM*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E<V5T('1H92!I;6%G92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M97-E="@I"B`@("!["B`@("`@("`@<&%R96YT.CIR97-E="@I.PH@("`@("`@
M(&EF("AI<U]R97-O=7)C92@D=&AI<RT^7VEM*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]C86QL*"=I;6%G941E<W1R;WDG+"!A<G)A>2@D=&AI
M<RT^7VEM*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T('1H92!H96EG:'0@86YD('=I9'1H(&]F
M('1H92!C=7)R96YT(&EM86=E+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%N(&AA<V@@=VET:"`G=VED=&@G(&-O;G1A:6YI;F<@=&AE('=I9'1H
M+`H@("`@("H@("`@("`@("`@("`@("`@)VAE:6=H="<@8V]N=&%I;FEN9R!T
M:&4@:&5I9VAT(&]F('1H92!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1&EM96YS:6]N<R@I"B`@("!["B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/E]I;2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]I;3L*("`@("`@("!](&5L<V5I9B`H:7-?<F5S;W5R8V4H)'1H:7,M
M/E]I;2DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=W:61T:"<@/3X@
M)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)VAE:6=H="<@/3X@)'1H:7,M/E]C
M86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I;2DI*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)W=I9'1H)R`]/B`P
M+"`G:&5I9VAT)R`]/B`P*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&5S(&$@8V]L;W(@=&AA="!C86X@8F4@86-C97-S960@:6X@
M=&AI<R!O8FIE8W0N(%=H96X@80H@("`@("H@8V]L;W(@:7,@<V5T+"!T:&4@
M:6YT96=E<B!R97-O=7)C92!O9B!I="!I<R!R971U<FYE9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@8V]L
M;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@<F5S;W5R
M8V4@;V8@=&AE(&-O;&]R('1H870@8V%N(&)E('!A<W-E9"!T;R!'1"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@86QL;V-A=&5#;VQO<B@D;F%M92D*("`@('L*
M("`@("`@("!S=&%T:6,@)&-O;&]R<R`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("AE;7!T>2@D8V]L;W)S6R1N86UE72DI('L*("`@("`@("`@("`@;&ES="@D
M<BP@)&<L("1B*2`]("1T:&ES+3YG97121T(H)&YA;64I.PH@("`@("`@("`@
M("`D8V]L;W)S6R1N86UE72`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<D%L
M;&]C871E)RP@87)R87DH)'1H:7,M/E]I;2P@)'(L("1G+"`D8BDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1C;VQO<G-;)&YA;65=.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$9O;G0H)&9O;G0I"B`@("!["B`@("`@("`@<W=I
M=&-H("@D9F]N="D@>PH@("`@("`@(&-A<V4@)W1I;GDG.@H@("`@("`@("`@
M("!R971U<FX@,3L*"B`@("`@("`@8V%S92`G;65D:75M)SH*("`@("`@("`@
M("`@<F5T=7)N(#,["@H@("`@("`@(&-A<V4@)VQA<F=E)SH*("`@("`@("`@
M("`@<F5T=7)N(#0["@H@("`@("`@(&-A<V4@)V=I86YT)SH*("`@("`@("`@
M("`@<F5T=7)N(#4["@H@("`@("`@(&-A<V4@)W-M86QL)SH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("!R971U<FX@,CL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,;V%D('1H92!I;6%G92!D871A(&9R;VT@82!S
M=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@
M("`@06X@87)B:71R87)Y(&ED(&9O<B!T:&4@:6UA9V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I;6%G95]D871A("!4:&4@9&%T82!T;R!U<V4@9F]R('1H
M92!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9%-T<FEN9R@D:60L
M("1I;6%G95]D871A*0H@("`@>PH@("`@("`@(&EF("@D:60@(3T@)'1H:7,M
M/E]I9"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]I;2D@>PH@("`@("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YR97-E="@I+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E0W)E871E
M1G)O;5-T<FEN9R<L(&%R<F%Y*"1I;6%G95]D871A*2D["B`@("`@("`@("`@
M("1T:&ES+3Y?:60@/2`D:60["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES
M+3Y?:6TL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7VEM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@3&]A9"!T:&4@:6UA9V4@9&%T82!F<F]M(&$@9FEL
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE
M(&9U;&P@<&%T:"!A;F0@9FEL96YA;64@=&\@=&AE(&9I;&4@=&\@;&]A9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!I;6%G92!D871A
M(&9R;VTN(%1H92!F:6QE;F%M92!W:6QL(&%L<V\@8F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!U<V5D(&9O<B!T:&4@:6UA9V4@:60N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4$5!4B!%<G)O<B!I9B!F:6QE
M(&1O97,@;F]T(&5X:7-T(&]R(&-O=6QD(&YO="!B92!L;V%D960*("`@("`J
M("`@("`@("`@("`@("`@(&]T:&5R=VES92!.54Q,(&EF('-U8V-E<W-F=6P@
M;W(@86QR96%D>2!L;V%D960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO861&
M:6QE*"1F:6QE;F%M92D*("`@('L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M(#T@)'1H:7,M/G)E<V5T*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M82@D:6YF;R`]("1T:&ES+3Y?8V%L;"@G9V5T:6UA9V5S:7IE)RP@87)R87DH
M)&9I;&5N86UE*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1I;F9O.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1I
M;F9O*2D@>PH@("`@("`@("`@("!S=VET8V@@*"1I;F9O6S)=*2!["B`@("`@
M("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E
M>&ES=',H)VEM86=E8W)E871E9G)O;6=I9B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E8W)E871E
M9G)O;6=I9B<L(&%R<F%Y*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@,CH*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I
M;6%G96-R96%T969R;VUJ<&5G)RP@87)R87DH)&9I;&5N86UE*2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`S.@H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E8W)E
M871E9G)O;7!N9R<L(&%R<F%Y*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@,34Z"B`@("`@("`@("`@("`@
M("!I9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%G96-R96%T969R;VUG=V)M<"<I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^
M7V-A;&PH)VEM86=E8W)E871E9G)O;6=W8FUP)RP@87)R87DH)&9I;&5N86UE
M*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@8V%S92`Q-CH*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G96-R96%T969R;VUX8FTG+"!A<G)A
M>2@D9FEL96YA;64I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES
M+3Y?:6TI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2!P87)E;G0Z.FQO861&:6QE*"1F:6QE;F%M92D["B`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G94-R96%T949R
M;VU3=')I;F<G+"!A<G)A>2@D=&AI<RT^7V1A=&$I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E<VEZ92!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("`@("!4:&4@;F5W('=I9'1H
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H="`@("`@5&AE(&YE=R!H
M96EG:'0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F%T:6\@("`@("!-86EN
M=&%I;B!O<FEG:6YA;"!A<W!E8W0@<F%T:6\N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E<VEZ92@D=VED=&@L("1H96EG:'0L("1R871I;R`]('1R=64I"B`@
M("!["B`@("`@("`@+RH@06)O<G0@:68@=V4G<F4@87-K960@=&\@9&EV:61E
M(&)Y('IE<F\L(&]R('1R=6YC871E('1H90H@("`@("`@("`J(&EM86=E(&-O
M;7!L971E;'D@:6X@96ET:&5R(&1I<F5C=&EO;BX@*B\*("`@("`@("!I9B`H
M(21W:61T:"!\?"`A)&AE:6=H="D@>PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)')A=&EO*2!["B`@("`@("`@("`@(&EF
M("@D=VED=&@@+R`D:&5I9VAT(#X@)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@
M87)R87DH)'1H:7,M/E]I;2DI("\@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@
M87)R87DH)'1H:7,M/E]I;2DI*2!["B`@("`@("`@("`@("`@("`D=VED=&@@
M/2`D:&5I9VAT("H@)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H
M:7,M/E]I;2DI("\@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H
M:7,M/E]I;2DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&AE:6=H="`]("1W:61T:"`J("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L
M(&%R<F%Y*"1T:&ES+3Y?:6TI*2`O("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L
M(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&EM(#T@)'1H:7,M/E]I;3L*("`@("`@("`D=&AI<RT^7VEM
M(#T@)B1T:&ES+3Y?8W)E871E*"1W:61T:"P@)&AE:6=H="D["B`@("`@("`@
M:68@*&ES7V$H)'1H:7,M/E]I;2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL)RP@87)R
M87DH)'1H:7,M/E]I;2P@,"P@,"P@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R
M06QL;V-A=&4G+"!A<G)A>2@D=&AI<RT^7VEM+"`R-34L(#(U-2P@,C4U*2DI
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]C86QL*"=I
M;6%G94-O<'E297-A;7!L960G+"!A<G)A>2@D=&AI<RT^7VEM+"`D:6TL(#`L
M(#`L(#`L(#`L("1W:61T:"P@)&AE:6=H="P@)'1H:7,M/E]C86QL*"=I;6%G
M95-8)RP@87)R87DH)&EM*2DL("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R
M<F%Y*"1I;2DI*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y4F5S:7IE9"<L(&%R<F%Y*"1T
M:&ES+3Y?:6TL("1I;2P@,"P@,"P@,"P@,"P@)'=I9'1H+"`D:&5I9VAT+"`D
M=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D:6TI*2P@)'1H:7,M/E]C
M86QL*"=I;6%G95-9)RP@87)R87DH)&EM*2DI*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F]P('1H92!C=7)R96YT(&EM86=E+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X,2`@5&AE('1O<"!L969T(&-O
M<FYE<B!O9B!T:&4@8W)O<'!E9"!I;6%G92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1Y,2`@5&AE('1O<"!R:6=H="!C;W)N97(@;V8@=&AE(&-R;W!P960@
M:6UA9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#(@(%1H92!B;W1T;VT@
M;&5F="!C;W)N97(@;V8@=&AE(&-R;W!P960@:6UA9V4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>3(@(%1H92!B;W1T;VT@<FEG:'0@8V]R;F5R(&]F('1H
M92!C<F]P<&5D(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F]P*"1X
M,2P@)'DQ+"`D>#(L("1Y,BD*("`@('L*("`@("`@("`D:6T@/2`D=&AI<RT^
M7VEM.PH@("`@("`@("1T:&ES+3Y?:6T@/2`F)'1H:7,M/E]C<F5A=&4H)'@R
M("T@)'@Q+"`D>3(@+2`D>3$I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M:6TL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6T["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7V-A;&PH
M)VEM86=E0V]P>2<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1I;2P@,"P@,"P@)'@Q
M+"`D>3$L("1X,B`M("1X,2P@)'DR("T@)'DQ*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2;W1A=&4@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&%N9VQE("`@("`@(%1H92!A;F=L92!T;R!R
M;W1A=&4@=&AE(&EM86=E(&)Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EN('1H92!C;&]C:W=I<V4@9&ER96-T:6]N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D8F%C:V=R;W5N9"`@5&AE(&)A8VMG<F]U;F0@8V]L
M;W(@=&\@9FEL;"!A;GD@=')I86YG;&5S"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')O=&%T92@D86YG;&4L("1B86-K9W)O=6YD(#T@)W=H:71E)RD*("`@('L*
M("`@("`@("!I9B`H(69U;F-T:6]N7V5X:7-T<R@G:6UA9V5R;W1A=&4G*2D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D8F%C
M:V=R;W5N9"`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1B86-K9W)O=6YD*3L*
M("`@("`@("!I9B`H:7-?82@D8F%C:V=R;W5N9"P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&)A8VMG<F]U;F0["B`@("`@("`@?0H*
M("`@("`@("!S=VET8V@@*"1A;F=L92D@>PH@("`@("`@(&-A<V4@)SDP)SH*
M("`@("`@("`@("`@)'@@/2`D=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A
M>2@D=&AI<RT^7VEM*2D["B`@("`@("`@("`@("1Y(#T@)'1H:7,M/E]C86QL
M*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@("`@("`@("`D
M>'EM87@@/2!M87@H)'@L("1Y*3L*"B`@("`@("`@("`@("1I;2`]("8D=&AI
M<RT^7V-R96%T92@D>'EM87@L("1X>6UA>"D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1I;2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1I;3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O<'DG+"!A<G)A>2@D:6TL
M("1T:&ES+3Y?:6TL(#`L(#`L(#`L(#`L("1X+"`D>2DI+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G
M95)O=&%T92<L(&%R<F%Y*"1I;2P@,C<P+"`D8F%C:V=R;W5N9"DI.PH@("`@
M("`@("`@("!I9B`H:7-?82@D:6TL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D:6T["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]I;2`]("1I;3L*("`@("`@("`@("`@)&EM(#T@)B1T:&ES
M+3Y?8W)E871E*"1Y+"`D>"D["B`@("`@("`@("`@(&EF("AI<U]A*"1I;2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I;3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'@@/"`D>2D@>PH@("`@
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G
M:6UA9V5#;W!Y)RP@87)R87DH)&EM+"`D=&AI<RT^7VEM+"`P+"`P+"`P+"`P
M+"`D>'EM87@L("1X>6UA>"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS96EF("@D>"`^("1Y*2!["B`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O
M<'DG+"!A<G)A>2@D:6TL("1T:&ES+3Y?:6TL(#`L(#`L("1X>6UA>"`M("1Y
M+"`D>'EM87@@+2`D>"P@)'AY;6%X+"`D>'EM87@I*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3Y?:6T@/2`D:6T["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`D=&AI<RT^7VEM(#T@)B1T:&ES+3Y?8V%L;"@G
M:6UA9V52;W1A=&4G+"!A<G)A>2@D=&AI<RT^7VEM+"`S-C`@+2`D86YG;&4L
M("1B86-K9W)O=6YD*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M:6TL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9L:7`@=&AE(&-U<G)E
M;G0@:6UA9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9L:7`H*0H@("`@>PH@
M("`@("`@("1X(#T@)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H
M:7,M/E]I;2DI.PH@("`@("`@("1Y(#T@)'1H:7,M/E]C86QL*"=I;6%G95-9
M)RP@87)R87DH)'1H:7,M/E]I;2DI.PH*("`@("`@("`D:6T@/2`F)'1H:7,M
M/E]C<F5A=&4H)'@L("1Y*3L*("`@("`@("!I9B`H:7-?82@D:6TL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;3L*("`@("`@("!]
M"B`@("`@("`@9F]R("@D8W5R62`](#`[("1C=7)9(#P@)'D[("1C=7)9*RLI
M('L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V5#;W!Y)RP@87)R87DH)&EM+"`D=&AI<RT^7VEM+"`P+"`D>2`M
M("@D8W5R62`K(#$I+"`P+"`D8W5R62P@)'@L(#$I*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6T@/2`D:6T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-:7)R;W(@=&AE(&-U<G)E;G0@:6UA9V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&UI<G)O<B@I"B`@("!["B`@("`@("`@
M)'@@/2`D=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM
M*2D["B`@("`@("`@)'D@/2`D=&AI<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A
M>2@D=&AI<RT^7VEM*2D["@H@("`@("`@("1I;2`]("8D=&AI<RT^7V-R96%T
M92@D>"P@)'DI.PH@("`@("`@(&EF("AI<U]A*"1I;2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&EM.PH@("`@("`@('T*("`@("`@
M("!F;W(@*"1C=7)8(#T@,#L@)&-U<E@@/"`D>#L@)&-U<E@K*RD@>PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G
M94-O<'DG+"!A<G)A>2@D:6TL("1T:&ES+3Y?:6TL("1X("T@*"1C=7)8("L@
M,2DL(#`L("1C=7)8+"`P+"`Q+"`D>2DI+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;2`]("1I;3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;G9E<G0@=&AE(&-U<G)E;G0@:6UA9V4@=&\@9W)A
M>7-C86QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G<F%Y<V-A;&4H*0H@("`@
M>PH@("`@("`@("1R871E4B`]("XR,CD["B`@("`@("`@)')A=&5'(#T@+C4X
M-SL*("`@("`@("`D<F%T94(@/2`N,3$T.PH@("`@("`@("1W:&ET96YE<W,@
M/2`S.PH*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%G96ES=')U
M96-O;&]R)RD@)B8@)'1H:7,M/E]C86QL*"=I;6%G94ES5')U94-O;&]R)RP@
M87)R87DH)'1H:7,M/E]I;2DI(#T]/2!T<G5E*2!["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E5')U94-O;&]R
M5&]086QE='1E)RP@87)R87DH)'1H:7,M/E]I;2P@=')U92P@,C4V*2DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V]L;W)S(#T@
M;6EN*#(U-BP@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R<U1O=&%L)RP@87)R
M87DH)'1H:7,M/E]I;2DI*3L*("`@("`@("!F;W(@*"1X(#T@,#L@)'@@/"`D
M8V]L;W)S.R`D>"LK*2!["B`@("`@("`@("`@("1S<F,@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E0V]L;W)S1F]R26YD97@G+"!A<G)A>2@D=&AI<RT^7VEM+"`D
M>"DI.PH@("`@("`@("`@("!I9B`H:7-?82@D<W)C+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-R8SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D;F5W(#T@;6EN*#(U-2P@86)S*"1S<F-;)W)E9"==
M("H@)')A=&52("L@)'-R8ULG9W)E96XG72`J("1R871E1R`K("1S<F-;)V)L
M=64G72`J("1R871E0BD@*R`D=VAI=&5N97-S*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<E-E="<L
M(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D;F5W+"`D;F5W+"`D;F5W*2DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4V5P:6$@9FEL=&5R+@H@("`@("H*("`@("`J($)A<VEC86QL>2!T=7)N
M<R!T:&4@:6UA9V4@=&\@9W)A>7-C86QE(&%N9"!T:&5N(&%D9',@<V]M90H@
M("`@("H@9&5F:6YE9"!T:6YT(&]N(&ET("A2("L](#,P+"!'("L](#0S+"!"
M("L]("TR,RD@<V\@:70@=VEL;`H@("`@("H@87!P96%R('1O(&)E(&$@=F5R
M>2!O;&0@<&EC='5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5P:6$H*0H@
M("`@>PH@("`@("`@("1T:6YT4B`](#@P.PH@("`@("`@("1T:6YT1R`](#0S
M.PH@("`@("`@("1T:6YT0B`]("TR,SL*("`@("`@("`D<F%T95(@/2`N,C(Y
M.PH@("`@("`@("1R871E1R`]("XU.#<["B`@("`@("`@)')A=&5"(#T@+C$Q
M-#L*("`@("`@("`D=VAI=&5N97-S(#T@,SL*"B`@("`@("`@:68@*"1T:&ES
M+3Y?8V%L;"@G:6UA9V5)<U1R=65#;VQO<B<L(&%R<F%Y*"1T:&ES+3Y?:6TI
M*2`]/3T@=')U92D@>PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@
M)'1H:7,M/E]C86QL*"=I;6%G951R=65#;VQO<E1O4&%L971T92<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL('1R=64L(#(U-BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&-O;&]R<R`](&UA>"@R-38L("1T:&ES+3Y?
M8V%L;"@G:6UA9V5#;VQO<G-4;W1A;"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2D[
M"B`@("`@("`@9F]R("@D>"`](#`[("1X(#P@)&-O;&]R<SL@)'@K*RD@>PH@
M("`@("`@("`@("`D<W)C(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R<T9O
M<DEN9&5X)RP@87)R87DH)'1H:7,M/E]I;2P@)'@I*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)'-R8RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1S<F,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YE
M=R`](&UI;B@R-34L(&%B<R@D<W)C6R=R960G72`J("1R871E4B`K("1S<F-;
M)V=R965N)UT@*B`D<F%T94<@*R`D<W)C6R=B;'5E)UT@*B`D<F%T94(I("L@
M)'=H:71E;F5S<RD["B`@("`@("`@("`@("1R(#T@;6EN*#(U-2P@)&YE=R`K
M("1T:6YT4BD["B`@("`@("`@("`@("1G(#T@;6EN*#(U-2P@)&YE=R`K("1T
M:6YT1RD["B`@("`@("`@("`@("1B(#T@;6EN*#(U-2P@)&YE=R`K("1T:6YT
M0BD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E0V]L;W)3970G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)'(L
M("1G+"`D8BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%EE;&QO=VEZ92!F:6QT97(N"B`@("`@*@H@("`@
M("H@061D<R!A(&QA>65R(&]F('EE;&QO=R!T:&%T(&-A;B!B92!T<F%N<W!A
M<F5N="!O<B!S;VQI9"X@268*("`@("`J("1I;G1E;G-I='E!(&ES(#(U-2!T
M:&4@:6UA9V4@=VEL;"!B92`P)2!T<F%N<W!A<F5N="`H<V]L:60I+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;G1E;G-I='E9("!(;W<@<W1R
M;VYG('-H;W5L9"!T:&4@>65L;&]W("AR960@86YD(&=R965N*2!B93\@*#`M
M,C4U*0H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN=&5N<VET>4(@($AO=R!W
M96%K('-H;W5L9"!T:&4@8FQU92!B93\@*#X](#(L(&EN('1H92!P;W-I=&EV
M92!L:6UI="!I="!W:6QL(&)E(&UA:V4@0DQ512`P*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!Y96QL;W=I>F4H)&EN=&5N<VET>5D@/2`U,"P@)&EN=&5N<VET
M>4(@/2`S*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-A;&PH)VEM86=E
M27-4<G5E0V]L;W(G+"!A<G)A>2@D=&AI<RT^7VEM*2D@/3T]('1R=64I('L*
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G
M:6UA9V54<G5E0V]L;W)4;U!A;&5T=&4G+"!A<G)A>2@D=&AI<RT^7VEM+"!T
M<G5E+"`R-38I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("1C;VQO<G,@/2!M87@H,C4V+"`D=&AI<RT^7V-A;&PH)VEM86=E0V]L
M;W)S5&]T86PG+"!A<G)A>2@D=&AI<RT^7VEM*2DI.PH@("`@("`@(&9O<B`H
M)'@@/2`P.R`D>"`\("1C;VQO<G,[("1X*RLI('L*("`@("`@("`@("`@)'-R
M8R`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<G-&;W));F1E>"<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL("1X*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1S<F,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W)C
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R(#T@;6EN*"1S<F-;)W)E
M9"==("L@)&EN=&5N<VET>5DL(#(U-2D["B`@("`@("`@("`@("1G(#T@;6EN
M*"1S<F-;)V=R965N)UT@*R`D:6YT96YS:71Y62P@,C4U*3L*("`@("`@("`@
M("`@)&(@/2!M87@H*"1R("L@)&<I("\@;6%X*"1I;G1E;G-I='E"+"`R*2P@
M,"D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E0V]L;W)3970G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)'(L
M("1G+"`D8BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!W871E<FUA<FLH)'1E>'0L("1H86QI9VX@/2`G<FEG
M:'0G+"`D=F%L:6=N(#T@)V)O='1O;2<L("1F;VYT(#T@)W-M86QL)RD*("`@
M('L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)#
M;&]S97-T)RP@87)R87DH)'1H:7,M/E]I;2P@,C4U+"`R-34L(#(U-2DI.PH@
M("`@("`@(&EF("AI<U]A*"1C;VQO<BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&-O;&]R.PH@("`@("`@('T*("`@("`@("`D<VAA
M9&]W(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R0VQO<V5S="<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL(#`L(#`L(#`I*3L*("`@("`@("!I9B`H:7-?82@D<VAA
M9&]W+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<VAA
M9&]W.PH@("`@("`@('T*"B`@("`@("`@+R\@4VAA9&]W(&]F9G-E="!I;B!P
M:7AE;',N"B`@("`@("`@)&1R;W`@/2`Q.PH*("`@("`@("`O+R!-87AI;75M
M('1E>'0@=VED=&@N"B`@("`@("`@)&UA>'=I9'1H(#T@,C`P.PH*("`@("`@
M("`O+R!!;6]U;G0@;V8@<W!A8V4@=&\@;&5A=F4@8F5T=V5E;B!T:&4@=&5X
M="!A;F0@=&AE(&EM86=E"B`@("`@("`@+R\@8F]R9&5R+@H@("`@("`@("1P
M861D:6YG(#T@,3`["@H@("`@("`@("1F(#T@)'1H:7,M/F=E=$9O;G0H)&9O
M;G0I.PH@("`@("`@("1F;VYT=VED=&@@/2`D=&AI<RT^7V-A;&PH)VEM86=E
M1F]N=%=I9'1H)RP@87)R87DH)&8I*3L*("`@("`@("!I9B`H:7-?82@D9F]N
M='=I9'1H+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M9F]N='=I9'1H.PH@("`@("`@('T*("`@("`@("`D9F]N=&AE:6=H="`]("1T
M:&ES+3Y?8V%L;"@G:6UA9V5&;VYT2&5I9VAT)RP@87)R87DH)&8I*3L*("`@
M("`@("!I9B`H:7-?82@D9F]N=&AE:6=H="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&9O;G1H96EG:'0["B`@("`@("`@?0H*("`@
M("`@("`O+R!3;R!T:&%T('-H861O=R!I<R!N;W0@;V9F('1H92!I;6%G92!W
M:71H(')I9VAT(&%L:6=N(&%N9`H@("`@("`@("\O(&)O='1O;2!V86QI9VXN
M"B`@("`@("`@)&UA<F=I;B`](&9L;V]R*"1P861D:6YG("L@)&1R;W`I("\@
M,CL*"B`@("`@("`@:68@*"1M87AW:61T:"D@>PH@("`@("`@("`@("`D;6%X
M8VAA<G-P97)L:6YE(#T@9FQO;W(H*"1M87AW:61T:"`M("@D;6%R9VEN("H@
M,BDI("\@)&9O;G1W:61T:"D["B`@("`@("`@("`@("1T97AT(#T@=V]R9'=R
M87`H)'1E>'0L("1M87AC:&%R<W!E<FQI;F4L(")<;B(L(#$I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@4W!L:70@)'1E>'0@:6YT;R!I;F1I=FED=6%L(&QI
M;F5S+@H@("`@("`@("1L:6YE<R`](&5X<&QO9&4H(EQN(BP@)'1E>'0I.PH*
M("`@("`@("!S=VET8V@@*"1V86QI9VXI('L*("`@("`@("!C87-E("=C96YT
M97(G.@H@("`@("`@("`@("`D>2`]("@D=&AI<RT^7V-A;&PH)VEM86=E4UDG
M+"!A<G)A>2@D=&AI<RT^7VEM*2D@+2`H)&9O;G1H96EG:'0@*B!C;W5N="@D
M;&EN97,I*2D@+R`R.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`G8F]T=&]M)SH*("`@("`@("`@("`@)'D@/2`D=&AI<RT^7V-A;&PH)VEM
M86=E4UDG+"!A<G)A>2@D=&AI<RT^7VEM*2D@+2`H*"1F;VYT:&5I9VAT("H@
M8V]U;G0H)&QI;F5S*2D@*R`D;6%R9VEN*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1Y(#T@)&UA<F=I;CL*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@
M*"1H86QI9VXI('L*("`@("`@("!C87-E("=R:6=H="<Z"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V53=')I;F<G
M+"!A<G)A>2@D=&AI<RT^7VEM+"`D9BP@*"1T:&ES+3Y?8V%L;"@G:6UA9V53
M6"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`M("1F;VYT=VED=&@@*B!S=')L96XH
M)&QI;F4I*2`M("1M87)G:6X@*R`D9')O<"P@*"1Y("L@)&1R;W`I+"`D;&EN
M92P@)'-H861O=RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN
M9R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1F+"`H)'1H:7,M/E]C86QL*"=I;6%G
M95-8)RP@87)R87DH)'1H:7,M/E]I;2DI("T@)&9O;G1W:61T:"`J('-T<FQE
M;B@D;&EN92DI("T@)&UA<F=I;BP@)'DL("1L:6YE+"`D8V]L;W(I*3L*("`@
M("`@("`@("`@("`@("1Y("L]("1F;VYT:&5I9VAT.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=C96YT97(G.@H@
M("`@("`@("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM
M86=E4W1R:6YG)RP@87)R87DH)'1H:7,M/E]I;2P@)&8L(&9L;V]R*"@D=&AI
M<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D@+2`D9F]N
M='=I9'1H("H@<W1R;&5N*"1L:6YE*2D@+R`R*2`K("1D<F]P+"`H)'D@*R`D
M9')O<"DL("1L:6YE+"`D<VAA9&]W*2DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH
M)VEM86=E4W1R:6YG)RP@87)R87DH)'1H:7,M/E]I;2P@)&8L(&9L;V]R*"@D
M=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D@+2`D
M9F]N='=I9'1H("H@<W1R;&5N*"1L:6YE*2D@+R`R*2P@)'DL("1L:6YE+"`D
M8V]L;W(I*3L*("`@("`@("`@("`@("`@("1Y("L]("1F;VYT:&5I9VAT.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E4W1R:6YG)RP@87)R87DH)'1H:7,M/E]I;2P@)&8L("1M87)G
M:6X@*R`D9')O<"P@*"1Y("L@)&1R;W`I+"`D;&EN92P@)'-H861O=RDI+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1F+"`D;6%R9VEN+"`D>2P@)&QI;F4L("1C;VQO<BDI.PH@("`@
M("`@("`@("`@("`@)'D@*ST@)&9O;G1H96EG:'0["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R
M87=S(&$@=&5X="!S=')I;F<@;VX@=&AE(&EM86=E(&EN(&$@<W!E8VEF:65D
M(&QO8V%T:6]N+"!W:71H"B`@("`@*B!T:&4@<W!E8VEF:65D('-T>6QE(&EN
M9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1T97AT
M("`@("`@(%1H92!T97AT('1O(&1R87<N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>"`@("`@("`@("!4:&4@;&5F="!X(&-O;W)D:6YA=&4@;V8@=&AE('-T
M87)T(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&5X="!S=')I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("`@
M("!4:&4@=&]P('D@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0@;V8@=&AE('1E
M>'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9RX*
M("`@("`J($!P87)A;2!S=')I;F<@("1F;VYT("`@("`@(%1H92!F;VYT(&ED
M96YT:69I97(@>6]U('=A;G0@=&\@=7-E(&9O<B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1E>'0N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D8V]L;W(@("`@("!4:&4@8V]L;W(@=&AA="!Y;W4@=V%N="!T:&4@
M=&5X="!D:7-P;&%Y960@:6XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER
M96-T:6]N("!!;B!I;G1E9V5R('1H870@<W!E8VEF:65S('1H92!O<FEE;G1A
M=&EO;B!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('1E>'0H)'-T<FEN9RP@)'@L
M("1Y+"`D9F]N="`]("=M;VYO<W!A8V4G+"`D8V]L;W(@/2`G8FQA8VLG+"`D
M9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("`D8R`]("1T:&ES+3YA;&QO
M8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*
M("`@("`@("`D9B`]("1T:&ES+3YG971&;VYT*"1F;VYT*3L*("`@("`@("!S
M=VET8V@@*"1D:7)E8W1I;VXI('L*("`@("`@("!C87-E("TY,#H*("`@("`@
M("!C87-E(#(W,#H*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V53=')I;F=5<"<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1F+"`D>"P@
M)'DL("1S=')I;F<L("1C*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#`Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?8V%L;"@G:6UA9V53=')I;F<G+"!A<G)A>2@D=&AI<RT^
M7VEM+"`D9BP@)'@L("1Y+"`D<W1R:6YG+"`D8RDI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M<F%W(&$@8VER8VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'D@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H
M92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<B`@("`@5&AE(')A
M9&EU<R!O9B!T:&4@8VER8VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L
M;W(@(%1H92!L:6YE(&-O;&]R(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F:6QL("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(&-I<F-L
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VER8VQE*"1X+"`D>2P@)'(L("1C
M;VQO<BP@)&9I;&P@/2!N=6QL*0H@("`@>PH@("`@("`@("1C(#T@)'1H:7,M
M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@("`@("!I9B`H:7-?82@D8RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&,["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<U]N=6QL*"1F:6QL*2D@>PH@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G945L;&EP<V4G+"!A<G)A
M>2@D=&AI<RT^7VEM+"`D>"P@)'DL("1R("H@,BP@)'(@*B`R+"`D8RDI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D9FEL;"`A/3T@)&-O
M;&]R*2!["B`@("`@("`@("`@("`@("`D9FEL;$-O;&]R(#T@)'1H:7,M/F%L
M;&]C871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H
M)&9I;&Q#;VQO<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D9FEL;$-O;&]R.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G
M:6UA9V5&:6QL961%;&QI<'-E)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y
M+"`D<B`J(#(L("1R("H@,BP@)&9I;&Q#;VQO<BDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]C86QL*"=I;6%G945L;&EP<V4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@
M)'DL("1R("H@,BP@)'(@*B`R+"`D8RDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA
M9V5&:6QL961%;&QI<'-E)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D
M<B`J(#(L("1R("H@,BP@)&,I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($1R87<@82!P;VQY9V]N(&)A<V5D(&]N(&$@<V5T(&]F
M('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D=F5R=&EC
M97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@)'9E<G1I8V5S6S!=6R=X
M)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W86YT('1O(&1R87<@=&AE
M('!O;'EG;VX@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@
M(%1H92!C;VQO<B!T;R!F:6QL('1H92!P;VQY9V]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P;VQY9V]N*"1V97)T<RP@)&-O;&]R+"`D9FEL;"`]("=N;VYE
M)RD*("`@('L*("`@("`@("`D=F5R=&EC97,@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1V97)T<R!A<R`D=F5R="D@>PH@("`@("`@("`@("`D=F5R
M=&EC97-;72`]("1V97)T6R=X)UT["B`@("`@("`@("`@("1V97)T:6-E<UM=
M(#T@)'9E<G1;)WDG73L*("`@("`@("!]"@H@("`@("`@(&EF("@D9FEL;"`A
M/2`G;F]N92<I('L*("`@("`@("`@("`@)&8@/2`D=&AI<RT^86QL;V-A=&5#
M;VQO<B@D9FEL;"D["B`@("`@("`@("`@(&EF("AI<U]A*"1F+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&8["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?
M8V%L;"@G:6UA9V5&:6QL9610;VQY9V]N)RP@87)R87DH)'1H:7,M/E]I;2P@
M)'9E<G1I8V5S+"!C;W5N="@D=F5R=',I+"`D9BDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1F:6QL(#T]("=N;VYE)R!\
M?"`D9FEL;"`A/2`D8V]L;W(I('L*("`@("`@("`@("`@)&,@/2`D=&AI<RT^
M86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M8RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@
M/2`D=&AI<RT^7V-A;&PH)VEM86=E4&]L>6=O;B<L(&%R<F%Y*"1T:&ES+3Y?
M:6TL("1V97)T:6-E<RP@8V]U;G0H)'9E<G1S*2P@)&,I*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W
M(&$@<F5C=&%N9VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M("`@("`@(%1H92!L969T('@M8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("`@5&AE('1O<"!Y+6-O
M;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H="`@5&AE(&AE:6=H="!O9B!T:&4@
M<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE
M(&QI;F4@8V]L;W(@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!R96-T86YG
M;&4@=VET:"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5C=&%N9VQE*"1X+"`D
M>2P@)'=I9'1H+"`D:&5I9VAT+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`]
M("=N;VYE)RD*("`@('L*("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2![
M"B`@("`@("`@("`@("1F(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I;&PI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D9BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1F.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E
M1FEL;&5D4F5C=&%N9VQE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D
M>"`K("1W:61T:"P@)'D@*R`D:&5I9VAT+"`D9BDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1F:6QL(#T]("=N;VYE)R!\
M?"`D9FEL;"`A/2`D8V]L;W(I('L*("`@("`@("`@("`@)&,@/2`D=&AI<RT^
M86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M8RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@
M/2`D=&AI<RT^7V-A;&PH)VEM86=E4F5C=&%N9VQE)RP@87)R87DH)'1H:7,M
M/E]I;2P@)'@L("1Y+"`D>"`K("1W:61T:"P@)'D@*R`D:&5I9VAT+"`D8RDI
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1R87<@82!R;W5N9&5D(')E8W1A;F=L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA
M=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y
M("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@
M=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@
M(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W5N9"`@(%1H92!W:61T:"!O9B!T:&4@8V]R;F5R(')O=6YD
M:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&QI;F4@
M8V]L;W(@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!R;W5N9&5D(')E8W1A
M;F=L92!W:71H+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;W5N9&5D4F5C=&%N
M9VQE*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D<F]U;F0L("1C;VQO<B`]
M("=B;&%C:R<L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@(&EF("@D
M<F]U;F0@/#T@,"D@>PH@("`@("`@("`@("`O+R!/<'1I;6EZ92!O=70@86YY
M(&-A;&QS('=I=&@@;F\@8V]R;F5R(')O=6YD:6YG+@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H
M="P@)&-O;&]R+"`D9FEL;"D["B`@("`@("`@?0H*("`@("`@("`D8R`]("1T
M:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@:68@*&ES7V$H
M)&,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C.PH@
M("`@("`@('T*"B`@("`@("`@+R\@4V5T(&-O<FYE<B!P;VEN=',@=&\@879O
M:60@;&]T<R!O9B!R961U;F1A;G0@;6%T:"X*("`@("`@("`D>#$@/2`D>"`K
M("1R;W5N9#L*("`@("`@("`D>3$@/2`D>2`K("1R;W5N9#L*"B`@("`@("`@
M)'@R(#T@)'@@*R`D=VED=&@@+2`D<F]U;F0["B`@("`@("`@)'DR(#T@)'D@
M*R`D<F]U;F0["@H@("`@("`@("1X,R`]("1X("L@)'=I9'1H("T@)')O=6YD
M.PH@("`@("`@("1Y,R`]("1Y("L@)&AE:6=H="`M("1R;W5N9#L*"B`@("`@
M("`@)'@T(#T@)'@@*R`D<F]U;F0["B`@("`@("`@)'DT(#T@)'D@*R`D:&5I
M9VAT("T@)')O=6YD.PH*("`@("`@("`D<B`]("1R;W5N9"`J(#(["@H@("`@
M("`@("\O($-A;&-U;&%T92!T:&4@=7!P97(@;&5F="!A<F,N"B`@("`@("`@
M)'`Q(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`Q.#`L(#(R-2D["B`@
M("`@("`@)'`R(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`R,C4L(#(W
M,"D["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@=7!P97(@<FEG:'0@87)C
M+@H@("`@("`@("1P,R`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@,C<P
M+"`S,34I.PH@("`@("`@("1P-"`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N
M9"P@,S$U+"`S-C`I.PH*("`@("`@("`O+R!#86QC=6QA=&4@=&AE(&QO=V5R
M(')I9VAT(&%R8RX*("`@("`@("`D<#4@/2`D=&AI<RT^7V%R8U!O:6YT<R@D
M<F]U;F0L(#`L(#0U*3L*("`@("`@("`D<#8@/2`D=&AI<RT^7V%R8U!O:6YT
M<R@D<F]U;F0L(#0U+"`Y,"D["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@
M;&]W97(@;&5F="!A<F,N"B`@("`@("`@)'`W(#T@)'1H:7,M/E]A<F-0;VEN
M=',H)')O=6YD+"`Y,"P@,3,U*3L*("`@("`@("`D<#@@/2`D=&AI<RT^7V%R
M8U!O:6YT<R@D<F]U;F0L(#$S-2P@,3@P*3L*"B`@("`@("`@+R\@1')A=R!T
M:&4@8V]R;F5R<R`M('5P<&5R(&QE9G0L('5P<&5R(')I9VAT+"!L;W=E<B!R
M:6=H="P*("`@("`@("`O+R!L;W=E<B!L969T+@H@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E07)C)RP@87)R87DH)'1H
M:7,M/E]I;2P@)'@Q+"`D>3$L("1R+"`D<BP@,3@P+"`R-S`L("1C*2DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@R+"`D>3(L("1R
M+"`D<BP@,C<P+"`S-C`L("1C*2DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E07)C)RP@87)R87DH
M)'1H:7,M/E]I;2P@)'@S+"`D>3,L("1R+"`D<BP@,"P@.3`L("1C*2DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@T+"`D>30L("1R
M+"`D<BP@.3`L(#$X,"P@)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\O($1R
M87<@=&AE(&-O;FYE8W1I;F<@<VED97,@+2!T;W`L(')I9VAT+"!B;W1T;VTL
M(&QE9G0N"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@Q("L@)'`R6R=X
M,B==+"`D>3$@*R`D<#);)WDR)UTL("1X,B`K("1P,ULG>#$G72P@)'DR("L@
M)'`S6R=Y,2==+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94QI;F4G+"!A<G)A>2@D=&AI
M<RT^7VEM+"`D>#(@*R`D<#1;)W@R)UTL("1Y,B`K("1P-%LG>3(G72P@)'@S
M("L@)'`U6R=X,2==+"`D>3,@*R`D<#5;)WDQ)UTL("1C*2DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM
M86=E3&EN92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,R`K("1P-ELG>#(G72P@
M)'DS("L@)'`V6R=Y,B==+"`D>#0@*R`D<#=;)W@Q)UTL("1Y-"`K("1P-ULG
M>3$G72P@)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I
M;2P@)'@T("L@)'`X6R=X,B==+"`D>30@*R`D<#A;)WDR)UTL("1X,2`K("1P
M,5LG>#$G72P@)'DQ("L@)'`Q6R=Y,2==+"`D8RDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@("`D9B`]
M("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)&8L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I;&Q4;T)O<F1E<B<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1X("L@*"1W:61T:"`O(#(I+"`D>2`K("@D:&5I
M9VAT("\@,BDL("1C+"`D9BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!L:6YE+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("!4:&4@>"!C;RUO<F1I;F%T
M92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@
M5&AE('D@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@Q("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!E;F0N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@("`@5&AE('D@8V\M;W)D:6YA
M=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("!4
M:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A;2!S=')I;F<@)'=I9'1H("!4
M:&4@=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M;F4H)'@Q+"`D>3$L("1X,BP@)'DR+"`D8V]L;W(@/2`G8FQA8VLG+"`D=VED
M=&@@/2`Q*0H@("`@>PH@("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L
M;W(H)&-O;&]R*3L*("`@("`@("!I9B`H:7-?82@D8RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&,["B`@("`@("`@?0H*("`@("`@
M("`O+R!$;VXG="!N965D('1O(&1O(&%N>71H:6YG('-P96-I86P@9F]R('-I
M;F=L92UW:61T:"!L:6YE<RX*("`@("`@("!I9B`H)'=I9'1H(#T](#$I('L*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5,:6YE
M)RP@87)R87DH)'1H:7,M/E]I;2P@)'@Q+"`D>3$L("1X,BP@)'DR+"`D8RDI
M.PH@("`@("`@('T@96QS96EF("@D>#$@/3T@)'@R*2!["B`@("`@("`@("`@
M("\O($9O<B!V97)T:6-A;"!L:6YE<RP@=V4@8V%N(&IU<W0@9')A=R!A('9E
M<G1I8V%L"B`@("`@("`@("`@("\O(')E8W1A;F=L92X*("`@("`@("`@("`@
M)&QE9G0@/2`D>#$@+2!F;&]O<B@H)'=I9'1H("T@,2D@+R`R*3L*("`@("`@
M("`@("`@)')I9VAT(#T@)'@Q("L@9FQO;W(H)'=I9'1H("\@,BD["B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D4F5C
M=&%N9VQE)RP@87)R87DH)'1H:7,M/E]I;2P@)&QE9G0L("1Y,2P@)')I9VAT
M+"`D>3(L("1C*2D["B`@("`@("`@?2!E;'-E:68@*"1Y,2`]/2`D>3(I('L*
M("`@("`@("`@("`@+R\@1F]R(&AO<FEZ;VYT86P@;&EN97,L('=E(&-A;B!J
M=7-T(&1R87<@82!H;W)I>F]N=&%L"B`@("`@("`@("`@("\O(&9I;&QE9"!R
M96-T86YG;&4N"B`@("`@("`@("`@("1T;W`@/2`D>3$@+2!F;&]O<B@D=VED
M=&@@+R`R*3L*("`@("`@("`@("`@)&)O='1O;2`]("1Y,2`K(&9L;V]R*"@D
M=VED=&@@+2`Q*2`O(#(I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]C86QL*"=I;6%G949I;&QE9%)E8W1A;F=L92<L(&%R<F%Y*"1T:&ES+3Y?
M:6TL("1X,2P@)'1O<"P@)'@R+"`D8F]T=&]M+"`D8RDI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\O($%N9VQE9"!L:6YE<RX*"B`@("`@("`@
M("`@("\O($UA:V4@<W5R92!T:&%T('1H92!E;F0@<&]I;G1S(&]F('1H92!L
M:6YE(&%R90H@("`@("`@("`@("`O+R!P97)P96YD:6-U;&%R('1O('1H92!L
M:6YE(&ET<V5L9BX*("`@("`@("`@("`@)&$@/2!A=&%N,B@D>3$@+2`D>3(L
M("1X,B`M("1X,2D["B`@("`@("`@("`@("1D>"`]("AS:6XH)&$I("H@)'=I
M9'1H("\@,BD["B`@("`@("`@("`@("1D>2`]("AC;W,H)&$I("H@)'=I9'1H
M("\@,BD["@H@("`@("`@("`@("`D=F5R=',@/2!A<G)A>2@D>#(@*R`D9'@L
M("1Y,B`K("1D>2P@)'@R("T@)&1X+"`D>3(@+2`D9'DL("1X,2`M("1D>"P@
M)'DQ("T@)&1Y+"`D>#$@*R`D9'@L("1Y,2`K("1D>2D["B`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D4&]L>6=O;B<L
M(&%R<F%Y*"1T:&ES+3Y?:6TL("1V97)T<RP@8V]U;G0H)'9E<G1S*2`O(#(L
M("1C*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M('T*"B`@("`O*BH*("`@("`J($1R87<@82!D87-H960@;&EN92X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#`@("`@("`@("`@(%1H92!X(&-O
M+6]R9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1Y,"`@("`@("`@("`@5&AE('D@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q("`@("`@("`@("!4:&4@>"!C
M;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'DQ("`@("`@("`@("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@("`@("!4:&4@;&EN92!C
M;VQO<BX*("`@("`J($!P87)A;2!S=')I;F<@)'=I9'1H("`@("`@("`@5&AE
M('=I9'1H(&]F('1H92!L:6YE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1A
M<VA?;&5N9W1H("!4:&4@;&5N9W1H(&]F(&$@9&%S:"!O;B!T:&4@9&%S:&5D
M(&QI;F4*("`@("`J($!P87)A;2!I;G1E9V5R("1D87-H7W-P86-E("`@5&AE
M(&QE;F=T:"!O9B!A('-P86-E(&EN('1H92!D87-H960@;&EN90H@("`@("HO
M"B`@("!F=6YC=&EO;B!D87-H961,:6YE*"1X,"P@)'DP+"`D>#$L("1Y,2P@
M)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2P@)&1A<VA?;&5N9W1H(#T@
M,BP@)&1A<VA?<W!A8V4@/2`R*0H@("`@>PH@("`@("`@("1C(#T@)'1H:7,M
M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@("`@("!I9B`H:7-?82@D8RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&,["B`@("`@
M("`@?0H@("`@("`@("1W(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)W=H:71E
M)RD["B`@("`@("`@:68@*&ES7V$H)'<L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1W.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T
M('5P('1H92!S='EL92!A<G)A>2!A8V-O<F1I;F<@=&\@=&AE("1D87-H7RH@
M<&%R86UE=&5R<RX*("`@("`@("`D<W1Y;&4@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1D87-H7VQE;F=T:#L@)&DK*RD@>PH@("`@
M("`@("`@("`D<W1Y;&5;72`]("1C.PH@("`@("`@('T*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D9&%S:%]S<&%C93L@)&DK*RD@>PH@("`@("`@("`@
M("`D<W1Y;&5;72`]("1W.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V539713='EL92<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL("1S='EL92DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-E=%1H:6-K;F5S
M<R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1W:61T:"DI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)'1H:7,M/E]C86QL*"=I;6%G94QI;F4G+"!A<G)A>2@D
M=&AI<RT^7VEM+"`D>#`L("1Y,"P@)'@Q+"`D>3$L($E-1U]#3TQ/4E]35%E,
M140I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY;&EN92`H
M82!N;VXM8VQO<V5D+"!N;VXM9FEL;&5D('!O;'EG;VXI(&)A<V5D(&]N(&$*
M("`@("`J('-E="!O9B!V97)T:6-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'9E<G1I8V5S("!!;B!A<G)A>2!O9B!X(&%N9"!Y(&QA8F5L960@
M87)R87ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`H96<N("1V
M97)T:6-E<ULP75LG>"==+"`D=F5R=&EC97-;,%U;)WDG72P@+BXN*2X*("`@
M("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!C;VQO<B!Y;W4@=V%N
M="!T;R!D<F%W('1H92!L:6YE('=I=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1W:61T:"`@("!4:&4@=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!O;'EL:6YE*"1V97)T<RP@)&-O;&]R+"`D=VED=&@@/2`Q
M*0H@("`@>PH@("`@("`@("1F:7)S="`]('1R=64["B`@("`@("`@9F]R96%C
M:"`H)'9E<G1S(&%S("1V97)T*2!["B`@("`@("`@("`@(&EF("@A)&9I<G-T
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M
M/FQI;F4H)&QA<W18+"`D;&%S=%DL("1V97)T6R=X)UTL("1V97)T6R=Y)UTL
M("1C;VQO<BP@)'=I9'1H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9I<G-T(#T@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QA<W18(#T@)'9E
M<G1;)W@G73L*("`@("`@("`@("`@)&QA<W19(#T@)'9E<G1;)WDG73L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&%N(&%R8RX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@(%1H92!X(&-O+6]R
M9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>2`@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<B`@("`@(%1H92!R861I=7,@;V8@=&AE(&%R
M8RX*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@5&AE('-T87)T(&%N
M9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96YD("`@
M(%1H92!E;F0@86YG;&4@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!S=')I
M;F<@("1C;VQO<B`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(&%R8RX*("`@("`J
M($!P87)A;2!S=')I;F<@("1F:6QL("`@5&AE(&9I;&P@8V]L;W(@;V8@=&AE
M(&%R8R`H9&5F875L=',@=&\@;F]N92DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%R8R@D>"P@)'DL("1R+"`D<W1A<G0L("1E;F0L("1C;VQO<B`]("=B;&%C
M:R<L("1F:6QL(#T@;G5L;"D*("`@('L*("`@("`@("`D8R`]("1T:&ES+3YA
M;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-?;G5L;"@D9FEL;"DI('L*("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5!<F,G+"!A<G)A>2@D=&AI
M<RT^7VEM+"`D>"P@)'DL("1R("H@,BP@)'(@*B`R+"`D<W1A<G0L("1E;F0L
M("1C*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1F:6QL
M("$]/2`D8V]L;W(I('L*("`@("`@("`@("`@("`@("1F(#T@)'1H:7,M/F%L
M;&]C871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H
M)&8L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&8["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9$%R8R<L
M(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L("1S
M=&%R="P@)&5N9"P@)&8L($E-1U]!4D-?4$E%*2DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V-A;&PH)VEM86=E1FEL;&5D07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L
M("1Y+"`D<B`J(#(L("1R("H@,BP@)'-T87)T+"`D96YD+"`D8RP@24U'7T%2
M0U]%1$=%1"!\($E-1U]!4D-?3D]&24Q,*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I
M;6%G949I;&QE9$%R8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@
M*B`R+"`D<B`J(#(L("1S=&%R="P@)&5N9"P@)&,L($E-1U]!4D-?4$E%*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&%N(&EM86=E(&]F
M('1H92!G:79E;B!S:7IE+@H@("`@("H@268@<&]S<VEB;&4@=&AE(&9U;F-T
M:6]N(')E='5R;G,@82!T<G5E(&-O;&]R(&EM86=E+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1W:61T:"`@(%1H92!I;6%G92!W:61T:"X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!I;6%G92!H96EG:'0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!R97-O=7)C97QO8FIE8W0@4$5!4B!%
M<G)O<B`@5&AE(&EM86=E(&AA;F1L97(@;W(@82!014%27T5R<F]R(&]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)E]C<F5A=&4H)'=I9'1H+"`D:&5I
M9VAT*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`F)'1H:7,M/E]C86QL*"=I
M;6%G94-R96%T951R=65#;VQO<B<L(&%R<F%Y*"1W:61T:"P@)&AE:6=H="DI
M.PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)')E<W5L="DI('L*("`@("`@
M("`@("`@)')E<W5L="`]("8D=&AI<RT^7V-A;&PH)VEM86=E0W)E871E)RP@
M87)R87DH)'=I9'1H+"`D:&5I9VAT*2D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)A<',@82!C
M86QL('1O(&$@9G5N8W1I;VX@;V8@=&AE(&=D(&5X=&5N<VEO;BX*("`@("`J
M($EF('1H92!C86QL('!R;V1U8V5S(&%N(&5R<F]R+"!A(%!%05)?17)R;W(@
M:7,@<F5T=7)N960L('1H92!F=6YC=&EO;@H@("`@("H@<F5S=6QT(&]T:&5R
M=VES92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F=6YC=&EO;B`@
M5&AE(&YA;64@;V8@=&AE(&9U;F-T:6]N('1O('=R87`N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@("`@06X@87)R87D@=VET:"!A;&P@<&%R86UE
M=&5R<R!F;W(@=&AA="!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!%:71H97(@=&AE(&9U;F-T:6]N(')E<W5L="!O<B!A(%!%05)?
M17)R;W(@:68@86X@97)R;W(*("`@("`J("`@("`@("`@("`@("`@(&]C8W5R
M960@=VAE;B!E>&5C=71I;F<@=&AE(&9U;F-T:6]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F7V-A;&PH)&9U;F-T:6]N+"`D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("!U;G-E="@D<&AP7V5R<F]R;7-G*3L*("`@("`@("`D=')A
M8VL@/2!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`Q*3L*("`@("`@("`D<F5S
M=6QT(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1F=6YC=&EO;BP@)'!A<F%M
M<RD["B`@("`@("`@:68@*"1T<F%C:R`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@)'1R86-K*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"%E;7!T>2@D<&AP7V5R<F]R;7-G*2D@>PH@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@)')E
M<W5L="`](%!%05(Z.G)A:7-E17)R;W(H)&9U;F-T:6]N("X@)SH@)R`N("1P
M:'!?97)R;W)M<V<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O26UA9V4O:6TN<&AP````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#,W,S0V`#$P-#$W,S8R-S<S`#`R,#0P-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E("=(;W)D92]);6%G92YP:'`G.PH*+RHJ"B`J(%1H:7,@8VQA<W,@:6UP
M;&5M96YT<R!T:&4@2&]R9&5?26UA9V4Z.B!!4$D@9F]R($EM86=E36%G:6-K
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]);6%G92]);6%G92]I;2YP:'`L
M=B`Q+C,T+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z,C@Z,C(@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?26UA9V4*("HO"F-L87-S($AO<F1E7TEM86=E7VEM(&5X=&5N9',@2&]R
M9&5?26UA9V4@>PH*("`@("\J*@H@("`@("H@0V%P86)I;&ET97,@;V8@=&AI
M<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]C87!A8FEL:71I97,@/2!A<G)A>2@G<F5S:7IE)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C<F]P)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R;W1A=&4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V=R87ES8V%L92<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9FQI<"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;6ER<F]R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=S97!I82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8V%N=F%S)PH@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`O*BH*
M("`@("`J(%=H870@:VEN9"!O9B!I;6%G97,@<VAO=6QD($EM86=E36%G:6-K
M(&=E;F5R871E/R!$969A=6QT<R!T;R`G<&YG)RX*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T>7!E(#T@)W!N9R<["@H@
M("`@+RHJ"B`@("`@*B!/<&5R871I;VYS('1O(&)E('!E<F9O<FUE9"X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]P97)A
M=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!S=')O
M:V4@8V]L;W([(&-A8VAE9"!S;R!W92!D;VXG="!I<W-U92!M;W)E("US=')O
M:V4@8V]M;6%N9',*("`@("`J('1H86X@;F5C97-S87)Y+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-T<F]K94-O;&]R
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@<W1R;VME('=I9'1H
M.R!C86-H960@<V\@=V4@9&]N)W0@:7-S=64@;6]R92`M<W1R;VME=VED=&@*
M("`@("`J(&-O;6UA;F1S('1H86X@;F5C97-S87)Y+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-T<F]K95=I9'1H(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@9FEL;"!C;VQO<CL@8V%C
M:&5D('-O('=E(&1O;B=T(&ES<W5E(&UO<F4@+69I;&P@8V]M;6%N9',@=&AA
M;@H@("`@("H@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7V9I;&Q#;VQO<B`](&YU;&P["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R
M9&5?26UA9V5?:6TH)'!A<F%M<RD*("`@('L*("`@("`@("!P87)E;G0Z.DAO
M<F1E7TEM86=E*"1P87)A;7,I.PH*("`@("`@("!I9B`H(65M<'1Y*"1P87)A
M;7-;)W1Y<&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]T>7!E(#T@)'!A
M<F%M<ULG='EP92==.PH@("`@("`@('T*"B`@("`@("`@+R\@36%K92!S=7)E
M('=E('-T87)T('=I=&@@82!W:&ET92!B86-K9W)O=6YD('1O(&)E(&-O;G-I
M<W1E;G0*("`@("`@("`O+R!W:71H(&]T:&5R(&1R:79E<G,N"B`@("`@("`@
M:68@*"%E;7!T>2@D<&%R86US6R=B86-K9W)O=6YD)UTI*2!["B`@("`@("`@
M("`@("1B9R`]("1P87)A;7-;)V)A8VMG<F]U;F0G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D8F<@/2`G=VAI=&4G.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^<F5C=&%N9VQE*#`L(#`L("1T:&ES+3Y?=VED=&@L("1T
M:&ES+3Y?:&5I9VAT+"`D8F<L("1B9RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(&-O;G1E;G0@='EP92!F;W(@=&AI<R!I;6%G92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!F
M;W(@=&AI<R!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]N=&5N
M=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G:6UA9V4O)R`N("1T:&ES
M+3Y?='EP93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')A
M=R!D871A(&9O<B!T:&ES(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1C;VYV97)T("!)9B!T<G5E+"!T:&4@:6UA9V4@9&%T82!W:6QL
M(&)E(')E='5R;F5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@('1A<F=E="!F;W)M870L(&EN9&5P96YD96YT;'D@9G)O;2!A;GD@
M:6UA9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!O<&5R871I
M;VYS+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W(&EM
M86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')A=R@D8V]N=F5R="`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7V1A=&$I*2!["B`@("`@("`@("`@("\O($EF
M('1H97)E(&%R92!N;R!O<&5R871I;VYS+"!A;F0@=V4@86QR96%D>2!H879E
M(&1A=&$L"B`@("`@("`@("`@("\O(&1O;B=T(&)O=&AE<B!W<FET:6YG(&]U
M="!F:6QE<RP@:G5S="!R971U<FX@=&AE(&-U<G)E;G0*("`@("`@("`@("`@
M+R\@9&%T82X*("`@("`@("`@("`@:68@*"$D8V]N=F5R="`F)B`A8V]U;G0H
M)'1H:7,M/E]O<&5R871I;VYS*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&%T83L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1M
M<&EN(#T@)'1H:7,M/G1O1FEL92@D=&AI<RT^7V1A=&$I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\O($-R96%T92!A;B!E;7!T>2!04$T@9FEL
M92!T;R!L;V%D+@H@("`@("`@("`@("`D=&UP:6X@/2!5=&EL.CIG971496UP
M1FEL92@G:6UG)RP@9F%L<V4L("1T:&ES+3Y?=&UP9&ER*3L*("`@("`@("`@
M("`@)&9P(#T@9F]P96XH)'1M<&EN+"`G=V(G*3L*("`@("`@("`@("`@9G=R
M:71E*"1F<"P@<W!R:6YT9B@B4#-<;B5D("5D7&XR-35<;B`B+"`D=&AI<RT^
M7W=I9'1H+"`D=&AI<RT^7VAE:6=H="DI.PH@("`@("`@("`@("!F8VQO<V4H
M)&9P*3L*("`@("`@("!]"@H@("`@("`@("1T;7!O=70@/2!5=&EL.CIG9714
M96UP1FEL92@G:6UG)RP@9F%L<V4L("1T:&ES+3Y?=&UP9&ER*3L*"B`@("`@
M("`@)&-O;6UA;F0@(#T@)&-O;F9;)VEM86=E)UU;)V-O;G9E<G0G73L*("`@
M("`@("`D8V]M;6%N9"`N/2`G("<@+B!I;7!L;V1E*"<@)RP@)'1H:7,M/E]O
M<&5R871I;VYS*3L*("`@("`@("`D8V]M;6%N9"`N/2`G("(G("X@)'1M<&EN
M("X@)R(@*W!R;V9I;&4@(BHB("<@+B`D=&AI<RT^7W1Y<&4@+B`G.B(G("X@
M)'1M<&]U="`N("<B(#(^)C$G.PH*("`@("`@("!E>&5C*"1C;VUM86YD+"`D
M;W5T<'5T+"`D<F5T=F%L*3L*"B`@("`@("`@)'1H:7,M/E]D871A(#T@9FEL
M95]G971?8V]N=&5N=',H)'1M<&]U="D["@H@("`@("`@($!U;FQI;FLH)'1M
M<&EN*3L*("`@("`@("!`=6YL:6YK*"1T;7!O=70I.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/E]D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5S970@
M=&AE(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T*"D*
M("`@('L*("`@("`@("!P87)E;G0Z.G)E<V5T*"D["B`@("`@("`@)'1H:7,M
M/E]O<&5R871I;VYS(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E<VEZ92!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D=VED=&@@("!4:&4@;F5W('=I9'1H+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&AE:6=H="`@5&AE(&YE=R!H96EG:'0N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<F%T:6\@("!-86EN=&%I;B!O<FEG:6YA;"!A<W!E
M8W0@<F%T:6\N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<VEZ92@D=VED=&@L
M("1H96EG:'0L("1R871I;R`]('1R=64I"B`@("!["B`@("`@("`@:68@*"1R
M871I;RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M
M<VEZ92![)'=I9'1H?7A[)&AE:6=H='T@+7)E<VEZ92![)'=I9'1H?7A[)&AE
M:6=H='TB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?
M;W!E<F%T:6]N<UM=(#T@(BUS:7IE('LD=VED=&A]>'LD:&5I9VAT?2`M<F5S
M:7IE('LD=VED=&A]>'LD:&5I9VAT?2$B.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($-R;W`@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q("!4:&4@=&]P(&QE9G0@8V]R;F5R
M(&]F('1H92!C<F]P<&5D(&EM86=E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'DQ("!4:&4@=&]P(')I9VAT(&-O<FYE<B!O9B!T:&4@8W)O<'!E9"!I;6%G
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1X,B`@5&AE(&)O='1O;2!L969T
M(&-O<FYE<B!O9B!T:&4@8W)O<'!E9"!I;6%G92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1Y,B`@5&AE(&)O='1O;2!R:6=H="!C;W)N97(@;V8@=&AE(&-R
M;W!P960@:6UA9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R;W`H)'@Q+"`D
M>3$L("1X,BP@)'DR*0H@("`@>PH@("`@("`@("1L:6YE(#T@*"1X,B`M("1X
M,2D@+B`G>"<@+B`H)'DR("T@)'DQ*2`N("<K)R`N("1X,2`N("<K)R`N("1Y
M,CL*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("<M8W)O<"`G("X@
M)&QI;F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2;W1A=&4@=&AE(&-U<G)E
M;G0@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%N9VQE
M("`@("`@(%1H92!A;F=L92!T;R!R;W1A=&4@=&AE(&EM86=E(&)Y+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN('1H92!C;&]C:W=I
M<V4@9&ER96-T:6]N+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&)A8VMG<F]U
M;F0@(%1H92!B86-K9W)O=6YD(&-O;&]R('1O(&9I;&P@86YY('1R:6%N9VQE
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F]T871E*"1A;F=L92P@)&)A8VMG
M<F]U;F0@/2`G=VAI=&4G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E<F%T
M:6]N<UM=(#T@(BUR;W1A=&4@>R1A;F=L97T@+6)A8VMG<F]U;F0@)&)A8VMG
M<F]U;F0B.PH@("`@?0H*("`@("\J*@H@("`@("H@1FQI<"!T:&4@8W5R<F5N
M="!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9FQI<"@I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`G+69L:7`G.PH@("`@?0H*
M("`@("\J*@H@("`@("H@36ER<F]R('1H92!C=7)R96YT(&EM86=E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!M:7)R;W(H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;W!E<F%T:6]N<UM=(#T@)RUF;&]P)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G9E<G0@=&AE(&-U<G)E;G0@:6UA9V4@=&\@9W)A>7-C86QE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G<F%Y<V-A;&4H*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@)RUC;VQO<G-P86-E($=205D@+6-O
M;&]R<R`R-38G.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5P:6$@9FEL=&5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S97!I82@I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]O<&5R871I;VYS6UT@/2`G+6UO9'5L871E(#$Q,"`M8V]L;W)S
M<&%C92!'4D%9("UC;VQO<G,@,C4V("UG86UM82`Q+C(U+S$O,"XV-B<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A('1E>'0@<W1R:6YG(&]N('1H
M92!I;6%G92!I;B!A('-P96-I9FEE9"!L;V-A=&EO;BP@=VET:`H@("`@("H@
M=&AE('-P96-I9FEE9"!S='EL92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D=&5X="`@("`@("!4:&4@=&5X="!T;R!D<F%W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@("`@5&AE(&QE9G0@
M>"!C;V]R9&EN871E(&]F('1H92!S=&%R="!O9B!T:&4@=&5X="!S=')I;F<N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("`@("!4:&4@=&]P('D@
M8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0@;V8@=&AE('1E>'0@<W1R:6YG+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&9O;G0@("`@("`@5&AE(&9O;G0@:61E
M;G1I9FEE<B!Y;W4@=V%N="!T;R!U<V4@9F]R('1H92!T97AT+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)&-O;&]R("`@("`@5&AE(&-O;&]R('1H870@>6]U
M('=A;G0@=&AE('1E>'0@9&ES<&QA>65D(&EN+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&1I<F5C=&EO;B`@06X@:6YT96=E<B!T:&%T('-P96-I9FEE<R!T
M:&4@;W)I96YT871I;VX@;V8@=&AE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1E>'0H)'-T<FEN9RP@)'@L("1Y+"`D9F]N="`]("=?<V%N<R<L("1C
M;VQO<B`]("=B;&%C:R<L("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@
M("1T:&ES+3YS9713=')O:V5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1T:&ES
M+3YS9713=')O:V57:61T:"@Q*3L*"B`@("`@("`@)'-T<FEN9R`](&%D9'-L
M87-H97,H)R(G("X@)'-T<FEN9R`N("<B)RD["B`@("`@("`@)'D@/2`D>2`K
M(#$R.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB
M=&5X="`D>"PD>2`D<W1R:6YG7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1')A=R!A(&-I<F-L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>"`@("`@5&AE('@@8V]O<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'D@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE
M(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1R("`@("!4:&4@<F%D
M:75S(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO
M<B`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(&-I<F-L92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&P@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@8VER8VQE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:7)C;&4H)'@L("1Y+"`D<BP@)&-O
M;&]R+"`D9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@("`D=&AI<RT^<V5T
M4W1R;VME0V]L;W(H)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T1FEL;$-O
M;&]R*"1F:6QL*3L*"B`@("`@("`@)'A-87@@/2`D>"`K("1R.PH@("`@("`@
M("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB8VER8VQE("1X+"1Y
M("1X36%X+"1Y7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A('!O
M;'EG;VX@8F%S960@;VX@82!S970@;V8@=F5R=&EC97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@;V8@>"!A;F0@
M>2!L86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=6R=Y)UTL
M("XN+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@8V]L
M;W(@>6]U('=A;G0@=&\@9')A=R!T:&4@<&]L>6=O;B!W:71H+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE
M('!O;'EG;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EG;VXH)'9E<G1S
M+"`D8V]L;W(L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@("1T:&ES
M+3YS9713=')O:V5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1T:&ES+3YS971&
M:6QL0V]L;W(H)&9I;&PI.PH*("`@("`@("`D8V]M;6%N9"`]("<G.PH@("`@
M("`@(&9O<F5A8V@@*"1V97)T<R!A<R`D=F5R="D@>PH@("`@("`@("`@("`D
M8V]M;6%N9"`N/2!S<')I;G1F*"<@)60L)60G+"`D=F5R=%LG>"==+"`D=F5R
M=%LG>2==*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS
M6UT@/2`B+61R87<@7")P;VQY9V]N("1C;VUM86YD7"(B.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L92X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@
M;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@
M("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE
M(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H
M92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@
M9FEL;"!T:&4@<F5C=&%N9VQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96-T
M86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1C;VQO<BP@)&9I;&P@
M/2`G;F]N92<I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R
M*"1C;VQO<BD["B`@("`@("`@)'1H:7,M/G-E=$9I;&Q#;VQO<B@D9FEL;"D[
M"@H@("`@("`@("1X36%X(#T@)'@@*R`D=VED=&@["B`@("`@("`@)'E-87@@
M/2`D>2`K("1H96EG:'0["B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@
M/2`B+61R87<@7")R96-T86YG;&4@)'@L)'D@)'A-87@L)'E-87A<(B(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<F]U;F1E9"!R96-T86YG;&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE
M9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T
M:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@
M5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<F]U;F0@("!4:&4@=VED=&@@;V8@=&AE
M(&-O<FYE<B!R;W5N9&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO
M<B`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D9FEL;"`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@
M<F]U;F1E9"!R96-T86YG;&4@=VET:"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F]U;F1E9%)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)')O
M=6YD+"`D8V]L;W(L("1F:6QL*0H@("`@>PH@("`@("`@("1T:&ES+3YS9713
M=')O:V5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1T:&ES+3YS971&:6QL0V]L
M;W(H)&9I;&PI.PH*("`@("`@("`D>#$@/2`D>"`K("1W:61T:#L*("`@("`@
M("`D>3$@/2`D>2`K("1H96EG:'0["B`@("`@("`@)'1H:7,M/E]O<&5R871I
M;VYS6UT@/2`B+61R87<@7")R;W5N9%)E8W1A;F=L92`D>"PD>2`D>#$L)'DQ
M+"`D<F]U;F0L)')O=6YD7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A
M=R!A(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@P("`@
M("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1Y,"`@("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@<W1A
M<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#$@("`@(%1H92!X(&-O;W)D
M:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@
M("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]L;W(@("!4:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A
M;2!S=')I;F<@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L:6YE*"1X,"P@)'DP+"`D>#$L("1Y,2P@)&-O
M;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2D*("`@('L*("`@("`@("`D=&AI
M<RT^<V5T4W1R;VME0V]L;W(H)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T
M4W1R;VME5VED=&@H)'=I9'1H*3L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO
M;G-;72`]("(M9')A=R!<(FQI;F4@)'@P+"1Y,"`D>#$L)'DQ7"(B.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1')A=R!A(&1A<VAE9"!L:6YE+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@("`@("`@5&AE('@@8V\M
M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'DP("`@("`@("`@("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#$@("`@("`@("`@(%1H92!X(&-O
M+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>3$@("`@("`@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("`@("`@(%1H92!L:6YE(&-O
M;&]R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=VED=&@@("`@("`@("!4:&4@
M=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&%S
M:%]L96YG=&@@(%1H92!L96YG=&@@;V8@82!D87-H(&]N('1H92!D87-H960@
M;&EN90H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1A<VA?<W!A8V4@("!4:&4@
M;&5N9W1H(&]F(&$@<W!A8V4@:6X@=&AE(&1A<VAE9"!L:6YE"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1A<VAE9$QI;F4H)'@P+"`D>3`L("1X,2P@)'DQ+"`D
M8V]L;W(@/2`G8FQA8VLG+"`D=VED=&@@/2`Q+"`D9&%S:%]L96YG=&@@/2`R
M+"`D9&%S:%]S<&%C92`](#(I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T
M<F]K94-O;&]R*"1C;VQO<BD["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K95=I
M9'1H*"1W:61T:"D["B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B
M+61R87<@7")L:6YE("1X,"PD>3`@)'@Q+"1Y,5PB(CL*("`@('T*"B`@("`O
M*BH*("`@("`J($1R87<@82!P;VQY;&EN92`H82!N;VXM8VQO<V5D+"!N;VXM
M9FEL;&5D('!O;'EG;VXI(&)A<V5D(&]N(&$*("`@("`J('-E="!O9B!V97)T
M:6-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'9E<G1I8V5S("!!
M;B!A<G)A>2!O9B!X(&%N9"!Y(&QA8F5L960@87)R87ES"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`H96<N("1V97)T:6-E<ULP75LG>"==+"`D
M=F5R=&EC97-;,%U;)WDG72P@+BXN*2X*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;&]R("`@(%1H92!C;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!L:6YE
M('=I=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@("!4:&4@=VED
M=&@@;V8@=&AE(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EL:6YE
M*"1V97)T<RP@)&-O;&]R+"`D=VED=&@@/2`Q*0H@("`@>PH@("`@("`@("1T
M:&ES+3YS9713=')O:V5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1T:&ES+3YS
M9713=')O:V57:61T:"@D=VED=&@I.PH@("`@("`@("1T:&ES+3YS971&:6QL
M0V]L;W(H)VYO;F4G*3L*"B`@("`@("`@)&-O;6UA;F0@/2`G)SL*("`@("`@
M("!F;W)E86-H("@D=F5R=',@87,@)'9E<G0I('L*("`@("`@("`@("`@)&-O
M;6UA;F0@+CT@<W!R:6YT9B@G("5D+"5D)RP@)'9E<G1;)W@G72P@)'9E<G1;
M)WDG72D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=
M(#T@(BUD<F%W(%PB<&]L>6QI;F4@)&-O;6UA;F1<(B(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$<F%W(&%N(&%R8RX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>"`@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@5&AE('D@8V]O<F1I
M;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'(@
M("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<W1A<G0@(%1H92!S=&%R="!A;F=L92!O9B!T:&4@87)C+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@96YD(&%N9VQE(&]F('1H
M92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@(%1H92!L:6YE
M(&-O;&]R(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL
M;"`@(%1H92!F:6QL(&-O;&]R(&]F('1H92!A<F,@*&1E9F%U;'1S('1O(&YO
M;F4I+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<F,H)'@L("1Y+"`D<BP@)'-T
M87)T+"`D96YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`]("=N;VYE)RD*
M("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O;&]R*3L*
M("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"1F:6QL*3L*"B`@("`@("`@
M+R\@4W!L:70@=7`@87)C<R!G<F5A=&5R('1H86X@,3@P(&1E9W)E97,@:6YT
M;R!T=V\@<&EE8V5S+@H@("`@("`@("1M:60@/2!R;W5N9"@H)'-T87)T("L@
M)&5N9"D@+R`R*3L*("`@("`@("`D>"`](')O=6YD*"1X*3L*("`@("`@("`D
M>2`](')O=6YD*"1Y*3L*("`@("`@("`D<B`](')O=6YD*"1R*3L*("`@("`@
M("!I9B`H)&UI9"`^(#DP*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E<F%T
M:6]N<UM=(#T@(BUD<F%W(%PB96QL:7!S92`D>"PD>2`D<BPD<B`D<W1A<G0L
M)&UI9%PB(CL*("`@("`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B
M+61R87<@7")E;&QI<'-E("1X+"1Y("1R+"1R("1M:60L)&5N9%PB(CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;
M72`]("(M9')A=R!<(F5L;&EP<V4@)'@L)'D@)'(L)'(@)'-T87)T+"1E;F1<
M(B(["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!F:6QL960L(&1R87<@=&AE
M(&]U=&QI;F4N"B`@("`@("`@:68@*"%E;7!T>2@D9FEL;"DI('L*("`@("`@
M("`@("`@;&ES="@D>#$L("1Y,2D@/2`D=&AI<RT^7V-I<F-L95!O:6YT*"1S
M=&%R="P@)'(@*B`R*3L*("`@("`@("`@("`@;&ES="@D>#(L("1Y,BD@/2`D
M=&AI<RT^7V-I<F-L95!O:6YT*"1M:60L("1R("H@,BD["B`@("`@("`@("`@
M(&QI<W0H)'@S+"`D>3,I(#T@)'1H:7,M/E]C:7)C;&50;VEN="@D96YD+"`D
M<B`J(#(I.PH*("`@("`@("`@("`@+R\@5&AI<R!S965M<R!T;R!R97-U;'0@
M:6X@<VQI9VAT;'D@8F5T=&5R('!L86-E;65N="!O9@H@("`@("`@("`@("`O
M+R!P:64@<VQI8V5S+@H@("`@("`@("`@("`D>"LK.PH@("`@("`@("`@("`D
M>2LK.PH*("`@("`@("`@("`@)'9E<G1S(#T@87)R87DH87)R87DH)W@G(#T^
M("1X("L@)'@S+"`G>2<@/3X@)'D@*R`D>3,I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G>"<@/3X@)'@L("=Y)R`]/B`D>2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=X)R`]/B`D>"`K("1X,2P@
M)WDG(#T^("1Y("L@)'DQ*2D["@H@("`@("`@("`@("!I9B`H)&UI9"`^(#DP
M*2!["B`@("`@("`@("`@("`@("`D=F5R=',Q(#T@87)R87DH87)R87DH)W@G
M(#T^("1X("L@)'@R+"`G>2<@/3X@)'D@*R`D>3(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G>"<@
M/3X@)'@@*R`D>#$L("=Y)R`]/B`D>2`K("1Y,2DI.PH@("`@("`@("`@("`@
M("`@)'9E<G1S,B`](&%R<F%Y*&%R<F%Y*"=X)R`]/B`D>"`K("1X,RP@)WDG
M(#T^("1Y("L@)'DS*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G>"<@/3X@)'@L("=Y)R`]/B`D>2DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)W@G(#T^("1X("L@)'@R+"`G>2<@
M/3X@)'D@*R`D>3(I*3L*"B`@("`@("`@("`@("`@("`D=&AI<RT^<&]L>6=O
M;B@D=F5R=',Q+"`D9FEL;"P@)&9I;&PI.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G!O;'EG;VXH)'9E<G1S,BP@)&9I;&PL("1F:6QL*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YP;VQY9V]N*"1V
M97)T<RP@)&9I;&PL("1F:6QL*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'1H:7,M/G!O;'EL:6YE*"1V97)T<RP@)&-O;&]R*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE(&-U<G)E;G0@<W1R
M;VME(&-O;&]R+B!7:6QL(&]N;'D@869F96-T('1H92!C;VUM86YD"B`@("`@
M*B!S=')I;F<@:68@)'-T<F]K92!I<R!D:69F97)E;G0@9G)O;2!T:&4@<')E
M=FEO=7,@<W1R;VME(&-O;&]R"B`@("`@*B`H<W1O<F5D(&EN("1T:&ES+3Y?
M<W1R;VME0V]L;W(I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H@0'-E92`D7W-T<F]K94-O;&]R"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]L;W(@(%1H92!N97<@<W1R;VME(&-O;&]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S9713=')O:V5#;VQO<B@D8V]L;W(I"B`@("!["B`@
M("`@("`@:68@*"1C;VQO<B`A/2`D=&AI<RT^7W-T<F]K94-O;&]R*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUS=')O:V4@)&-O
M;&]R(CL*("`@("`@("`@("`@)'1H:7,M/E]S=')O:V5#;VQO<B`]("1C;VQO
M<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE
M(&-U<G)E;G0@<W1R;VME('=I9'1H+B!7:6QL(&]N;'D@869F96-T('1H92!C
M;VUM86YD"B`@("`@*B!S=')I;F<@:68@)'=I9'1H(&ES(&1I9F9E<F5N="!F
M<F]M('1H92!P<F5V:6]U<R!S=')O:V4@=VED=&@*("`@("`J("AS=&]R960@
M:6X@)'1H:7,M/E]S=')O:V57:61T:"DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B!`<V5E("1?<W1R;VME"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=VED=&@@(%1H92!N97<@<W1R;VME('=I9'1H+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S9713=')O:V57:61T:"@D=VED=&@I"B`@
M("!["B`@("`@("`@:68@*"1W:61T:"`A/2`D=&AI<RT^7W-T<F]K95=I9'1H
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUS=')O
M:V5W:61T:"`D=VED=&@B.PH@("`@("`@("`@("`D=&AI<RT^7W-T<F]K95=I
M9'1H(#T@)'=I9'1H.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($-H86YG92!T:&4@8W5R<F5N="!F:6QL(&-O;&]R+B!7:6QL(&]N;'D@869F
M96-T('1H92!C;VUM86YD"B`@("`@*B!S=')I;F<@:68@)&-O;&]R(&ES(&1I
M9F9E<F5N="!F<F]M('1H92!P<F5V:6]U<R!F:6QL(&-O;&]R"B`@("`@*B`H
M<W1O<F5D(&EN("1T:&ES+3Y?9FEL;$-O;&]R*2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J($!S964@)%]F:6QL"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@(%1H92!N97<@9FEL;"!C;VQO<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1FEL;$-O;&]R*"1C;VQO<BD*("`@
M('L*("`@("`@("!I9B`H)&-O;&]R("$]("1T:&ES+3Y?9FEL;$-O;&]R*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUF:6QL("1C
M;VQO<B(["B`@("`@("`@("`@("1T:&ES+3Y?9FEL;$-O;&]R(#T@)&-O;&]R
M.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O<&YG+G!H<```````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U-3,P`#$P-#$W,S8R-S<S
M`#`R,#4U-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B]);6%G92YP:'`G.PH*+RHJ"B`J(%1H:7,@8VQA<W,@:6UP;&5M96YT
M<R!T:&4@2&]R9&5?26UA9V4Z.B!!4$D@9F]R(%!.1R!I;6%G97,N($ET"B`J
M(&UA:6YL>2!P<F]V:61E<R!S;VUE('5T:6QI='D@9G5N8W1I;VYS+"!S=6-H
M(&%S('1H92!A8FEL:71Y('1O(&UA:V4*("H@<&EX96QS(&]R('-O;&ED(&EM
M86=E<R!F;W(@;F]W+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]);6%G92])
M;6%G92]P;F<N<&AP+'8@,2XQ.2XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C(@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]);6%G90H@*B\*8VQA<W,@2&]R9&5?26UA9V5?<&YG(&5X=&5N9',@2&]R
M9&5?26UA9V4@>PH*("`@("\J*@H@("`@("H@5&AE(&%R<F%Y(&]F('!I>&5L
M(&1A=&$N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]I;6<@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]L;W(@9&5P
M=&@@*&]N;'D@."!A;F0@,38@:6UP;&5M96YT960I+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]C;VQO<D1E<'1H(#T@
M.#L*"B`@("`O*BH*("`@("`J($-O;&]R('1Y<&4@*&]N;'D@,B`H=')U92!C
M;VQO<BD@:6UP;&5M96YT960I+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]C;VQO<E1Y<&4@/2`R.PH*("`@("\J*@H@
M("`@("H@0V]M<')E<W-I;VX@;65T:&]D("@P(&ES('1H92!O;FQY(&-U<G)E
M;G0@=F%L:60@=F%L=64I+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@
M("`@("HO"B`@("!V87(@)%]C;VUP<F5S<VEO;DUE=&AO9"`](#`["@H@("`@
M+RHJ"B`@("`@*B!&:6QT97(@;65T:&]D("@P(&ES('1H92!O;FQY(&-U<G)E
M;G0@=F%L:60@=F%L=64I+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@
M("`@("HO"B`@("!V87(@)%]F:6QT97)-971H;V0@/2`P.PH*("`@("\J*@H@
M("`@("H@26YT97)L86-E(&UE=&AO9"`H;VYL>2`P("AN;R!I;G1E<FQA8V4I
M(&EM<&QE;65N=&5D*2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?:6YT97)L86-E365T:&]D(#T@,#L*"B`@("`O*BH*
M("`@("`J(%!.1R!I;6%G92!C;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@2&]R9&5?26UA9V5?<&YG*"1P87)A;7,I"B`@("!["B`@("`@("`@
M<&%R96YT.CI(;W)D95]);6%G92@D<&%R86US*3L*"B`@("`@("`@:68@*"%E
M;7!T>2@D<&%R86US6R=W:61T:"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<F5C=&%N9VQE*#`L(#`L("1P87)A;7-;)W=I9'1H)UTL("1P87)A;7-;)VAE
M:6=H="==+"`D=&AI<RT^7V)A8VMG<F]U;F0L("1T:&ES+3Y?8F%C:V=R;W5N
M9"D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14
M>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)VEM86=E+W!N9R<["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(')A=R!D871A(&9O<B!T:&ES
M(&EM86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W
M(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')A=R@I"B`@("![
M"B`@("`@("`@<F5T=7)N"B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R*"D@
M+@H@("`@("`@("`@("`D=&AI<RT^7TE(1%(H*2`N"@H@("`@("`@("`@("`O
M*B!387D@=VAA="!C<F5A=&5D('1H92!I;6%G92!F:6QE+B`J+PH@("`@("`@
M("`@("`D=&AI<RT^7W1%6'0H)U-O9G1W87)E)RP@)TAO<F1E($9R86UE=V]R
M:R!);6%G95]P;F<@0VQA<W,G*2`N"@H@("`@("`@("`@("`O*B!3970@=&AE
M(&QA<W0@;6]D:69I960@9&%T92]T:6UE+B`J+PH@("`@("`@("`@("`D=&AI
M<RT^7W1)344H*2`N"@H@("`@("`@("`@("`D=&AI<RT^7TE$050H*2`N"B`@
M("`@("`@("`@("1T:&ES+3Y?245.1"@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5S970@=&AE(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E<V5T*"D*("`@('L*("`@("`@("!P87)E;G0Z.G)E<V5T*"D["B`@("`@
M("`@)'1H:7,M/E]I;6<@/2!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1')A=R!A(')E8W1A;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E
M8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T
M;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@
M;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R
M("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@
M<F5C=&%N9VQE('=I=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8W1A;F=L
M92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&-O;&]R(#T@)V)L86-K)RP@
M)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@;&ES="@D<BP@)&<L("1B
M*2`]("1T:&ES+3YG97121T(H)&-O;&]R*3L*("`@("`@("!I9B`H)&9I;&P@
M(3T@)VYO;F4G*2!["B`@("`@("`@("`@(&QI<W0H)&92+"`D9D<L("1F0BD@
M/2`D=&AI<RT^9V5T4D="*"1F:6QL*3L*("`@("`@("!]"@H@("`@("`@("1X
M,B`]("1X("L@)'=I9'1H.PH@("`@("`@("1Y,B`]("1Y("L@)&AE:6=H=#L*
M"B`@("`@("`@9F]R("@D:"`]("1Y.R`D:"`\/2`D>3([("1H*RLI('L*("`@
M("`@("`@("`@9F]R("@D=R`]("1X.R`D=R`\/2`D>#([("1W*RLI('L*("`@
M("`@("`@("`@("`@("\O(%-E92!I9B!W92=R92!O;B!A;B!E9&=E+@H@("`@
M("`@("`@("`@("`@:68@*"1W(#T]("1X('Q\("1H(#T]("1Y('Q\("1W(#T]
M("1X,B!\?"`D:"`]/2`D>3(I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEM9ULD:%U;)'==(#T@87)R87DH)W(G(#T^("1R+"`G9R<@/3X@)&<L
M("=B)R`]/B`D8BD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&9I;&P@
M(3T@)VYO;F4G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;6=;
M)&A=6R1W72`](&%R<F%Y*"=R)R`]/B`D9E(L("=G)R`]/B`D9D<L("=B)R`]
M/B`D9D(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!03D<@9FEL
M92!H96%D97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H96%D97(H*0H@("`@
M>PH@("`@("`@(')E='5R;B!P86-K*"=#0T-#0T-#0R<L(#$S-RP@.#`L(#<X
M+"`W,2P@,3,L(#$P+"`R-BP@,3`I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0W)E871E($EM86=E($AE861E<B!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7TE(1%(H*0H@("`@>PH@("`@("`@("1D871A(#T@<&%C:R@G831.3D-#
M0T-#)RP@)TE(1%(G+"`D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H="P@
M)'1H:7,M/E]C;VQO<D1E<'1H+"`D=&AI<RT^7V-O;&]R5'EP92P@)'1H:7,M
M/E]C;VUP<F5S<VEO;DUE=&AO9"P@)'1H:7,M/E]F:6QT97)-971H;V0L("1T
M:&ES+3Y?:6YT97)L86-E365T:&]D*3L*("`@("`@("!R971U<FX@<&%C:R@G
M3F$G("X@<W1R;&5N*"1D871A*2`N("=.)RP@<W1R;&5N*"1D871A*2`M(#0L
M("1D871A+"!C<F,S,B@D9&%T82DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0W)E871E($E%3D0@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%])14Y$
M*"D*("`@('L*("`@("`@("`D9&%T82`]("=)14Y$)SL*("`@("`@("!R971U
M<FX@<&%C:R@G3F$G("X@<W1R;&5N*"1D871A*2`N("=.)RP@<W1R;&5N*"1D
M871A*2`M(#0L("1D871A+"!C<F,S,B@D9&%T82DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E($EM86=E($1A=&$@8FQO8VLN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%])1$%4*"D*("`@('L*("`@("`@("`D9&%T82`]("<G.PH@
M("`@("`@("1P<F5V<V-A;FQI;F4@/2!N=6QL.PH@("`@("`@("1F:6QT97(@
M/2`P.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1T:&ES+3Y?:&5I9VAT
M.R`D:2LK*2!["B`@("`@("`@("`@("1S8V%N;&EN92`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1D871A("X](&-H<B@D9FEL=&5R*3L*("`@("`@("`@("`@
M9F]R("@D:B`](#`[("1J(#P@)'1H:7,M/E]W:61T:#L@)&HK*RD@>PH@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]L;W)$97!T:"`]/2`X*2!["B`@
M("`@("`@("`@("`@("`@("`@)'-C86YL:6YE6R1J72`]('!A8VLH)T-#0R<L
M("1T:&ES+3Y?:6UG6R1I75LD:EU;)W(G72P@)'1H:7,M/E]I;6=;)&E=6R1J
M75LG9R==+"`D=&AI<RT^7VEM9ULD:5U;)&I=6R=B)UTI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?8V]L;W)$97!T:"`]/2`Q-BD@>PH@
M("`@("`@("`@("`@("`@("`@("1S8V%N;&EN95LD:ET@/2!P86-K*"=N;FXG
M+"`D=&AI<RT^7VEM9ULD:5U;)&I=6R=R)UT@/#P@."P@)'1H:7,M/E]I;6=;
M)&E=6R1J75LG9R==(#P\(#@L("1T:&ES+3Y?:6UG6R1I75LD:EU;)V(G72`\
M/"`X("D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@
M*"1F:6QT97(@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("\J($YO($9I
M;'1E<BX@*B\*("`@("`@("`@("`@("`@("`@("`D9&%T82`N/2`D<V-A;FQI
M;F5;)&I=.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1F:6QT97(@/3T@
M,BD@>PH@("`@("`@("`@("`@("`@("`@("\J(%5P($9I;'1E<BX@*B\*("`@
M("`@("`@("`@("`@("`@("`D<&EX96P@/2`D<V-A;FQI;F5;)&I=("T@)'!R
M979S8V%N;&EN95LD:ET["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?8V]L;W)$97!T:"`]/2`X*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A("X]('!A8VLH)T-#0R<L("1P:7AE;"`^/B`Q-BP@*"1P:7AE;"`^
M/B`X*2`F(#!X1D8L("1P:7AE;"`F(#!X1D8I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("@D=&AI<RT^7V-O;&]R1&5P=&@@/3T@,38I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1A=&$@+CT@<&%C:R@G;FYN)RP@*"1P
M:7AE;"`^/B`S,BDL("@D<&EX96P@/CX@,38I("8@,'A&1D9&+"`D<&EX96P@
M)B`P>$9&1D8I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<')E=G-C86YL:6YE
M(#T@)'-C86YL:6YE.PH@("`@("`@('T*("`@("`@("`D8V]M<')E<W-E9"`]
M(&=Z9&5F;&%T92@D9&%T82P@.2D["@H@("`@("`@("1D871A(#T@)TE$050G
M("X@<&%C:R@G0T-A)R`N('-T<FQE;B@D8V]M<')E<W-E9"D@+B`G830G+"`P
M>#<X+"`P>#`Q+"`D8V]M<')E<W-E9"P@)'1H:7,M/E]!9&QE<C,R*"1D871A
M*2D["B`@("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T<FQE;B@D9&%T82D@
M+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@8W)C,S(H)&1A=&$I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!T15AT(&)L;V-K+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?=$58="@D:V5Y=V]R9"P@)'1E>'0I"B`@
M("!["B`@("`@("`@)&1A=&$@/2`G=$58="<@+B`D:V5Y=V]R9"`N(")<,"(@
M+B`D=&5X=#L*("`@("`@("!R971U<FX@<&%C:R@G3F$G("X@<W1R;&5N*"1D
M871A*2`N("=.)RP@<W1R;&5N*"1D871A*2`M(#0L("1D871A+"!C<F,S,B@D
M9&%T82DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&QA<W0@;6]D
M:69I960@=&EM92!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W1)344H
M)&1A=&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1D871E
M*2D@>PH@("`@("`@("`@("`D9&%T92`]('1I;64H*3L*("`@("`@("!]"@H@
M("`@("`@("1D871A(#T@)W1)344G("X@<&%C:R@G;D-#0T-#)RP@:6YT=F%L
M*&1A=&4H)UDG+"`D9&%T92DI+"!I;G1V86PH9&%T92@G;2<L("1D871E*2DL
M(&EN='9A;"AD871E*"=J)RP@)&1A=&4I*2P@:6YT=F%L*&1A=&4H)T<G+"`D
M9&%T92DI+"!I;G1V86PH9&%T92@G:2<L("1D871E*2DL(&EN='9A;"AD871E
M*"=S)RP@)&1A=&4I*2D["B`@("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T
M<FQE;B@D9&%T82D@+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@
M8W)C,S(H)&1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A;&-U;&%T
M92!A;B!!9&QE<C,R(&-H96-K<W5M(&9O<B!A('-T<FEN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7T%D;&5R,S(H)&EN<'5T*0H@("`@>PH@("`@("`@("1S
M,2`](#$["B`@("`@("`@)',R(#T@,#L*("`@("`@("`D:4UA>"`]('-T<FQE
M;B@D:6YP=70I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I36%X.R`D
M:2LK*2!["B`@("`@("`@("`@("1S,2`]("@D<S$@*R!O<F0H)&EN<'5T6R1I
M72DI("4@,'A&1D8Q.PH@("`@("`@("`@("`D<S(@/2`H)',R("L@)',Q*2`E
M(#!X1D9&,3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('!A8VLH)TXG+"`H
M*"1S,B`\/"`Q-BD@?"`D<S$I*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O26UA9V4O<F=B+G!H<```````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#0R-C<Q`#$P-#$W,S8R-S<S`#`R,#4U,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@4D="(&-O;&]R(&YA;65S+W9A;'5E<RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO26UA9V4O26UA9V4O<F=B+G!H<"QV(#$N,BXQ,BXQ(#(P,#4O,3`O
M,3@@,3$Z,#$Z,3,@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7TEM
M86=E"B`J+PHD1TQ/0D%,4ULG:&]R9&5?:6UA9V5?<F=B7V-O;&]R<R==(#T@
M87)R87DH"B`@("`G87%U82<@/3X@87)R87DH,"P@,C4U+"`R-34I+"`)"0H@
M("`@)VQI;64G(#T^(&%R<F%Y*#`L(#(U-2P@,"DL(`D)"B`@("`G=&5A;"<@
M/3X@87)R87DH,"P@,3(X+"`Q,C@I+`H@("`@)W=H:71E<VUO:V4G(#T^(&%R
M<F%Y*#(T-2P@,C0U+"`R-#4I+`H@("`@)V=A:6YS8F]R;R<@/3X@87)R87DH
M,C(P+"`R,C`L(#(R,"DL"B`@("`G;VQD;&%C92<@/3X@87)R87DH,C4S+"`R
M-#4L(#(S,"DL"B`@("`G;&EN96XG(#T^(&%R<F%Y*#(U,"P@,C0P+"`R,S`I
M+`H@("`@)V%N=&EQ=65W:&ET92<@/3X@87)R87DH,C4P+"`R,S4L(#(Q-2DL
M"B`@("`G<&%P87EA=VAI<"<@/3X@87)R87DH,C4U+"`R,SDL(#(Q,RDL"B`@
M("`G8FQA;F-H961A;&UO;F0G(#T^(&%R<F%Y*#(U-2P@,C,U+"`R,#4I+`H@
M("`@)V)I<W%U92<@/3X@87)R87DH,C4U+"`R,C@L(#$Y-BDL"B`@("`G<&5A
M8VAP=69F)R`]/B!A<G)A>2@R-34L(#(Q."P@,3@U*2P*("`@("=N879A:F]W
M:&ET92<@/3X@87)R87DH,C4U+"`R,C(L(#$W,RDL"B`@("`G;6]C8V%S:6XG
M(#T^(&%R<F%Y*#(U-2P@,C(X+"`Q.#$I+`H@("`@)V-O<FYS:6QK)R`]/B!A
M<G)A>2@R-34L(#(T."P@,C(P*2P*("`@("=I=F]R>2<@/3X@87)R87DH,C4U
M+"`R-34L(#(T,"DL"B`@("`G;&5M;VYC:&EF9F]N)R`]/B!A<G)A>2@R-34L
M(#(U,"P@,C`U*2P*("`@("=S96%S:&5L;"<@/3X@87)R87DH,C4U+"`R-#4L
M(#(S."DL"B`@("`G;6EN=&-R96%M)R`]/B!A<G)A>2@R-#4L(#(U-2P@,C4P
M*2P*("`@("=A>G5R92<@/3X@87)R87DH,C0P+"`R-34L(#(U-2DL"B`@("`G
M86QI8V5B;'5E)R`]/B!A<G)A>2@R-#`L(#(T."P@,C4U*2P*("`@("=L879E
M;F1E<B<@/3X@87)R87DH,C,P+"`R,S`L(#(U,"DL"B`@("`G;&%V96YD97)B
M;'5S:"<@/3X@87)R87DH,C4U+"`R-#`L(#(T-2DL"B`@("`G;6ES='ER;W-E
M)R`]/B!A<G)A>2@R-34L(#(R."P@,C(U*2P*("`@("=W:&ET92<@/3X@87)R
M87DH,C4U+"`R-34L(#(U-2DL"B`@("`G8FQA8VLG(#T^(&%R<F%Y*#`L(#`L
M(#`I+`H@("`@)V1A<FMS;&%T96=R87DG(#T^(&%R<F%Y*#0W+"`W.2P@-SDI
M+`H@("`@)V1I;6=R87DG(#T^(&%R<F%Y*#$P-2P@,3`U+"`Q,#4I+`H@("`@
M)W-L871E9W)A>2<@/3X@87)R87DH,3$R+"`Q,C@L(#$T-"DL"B`@("`G;&EG
M:'1S;&%T96=R87DG(#T^(&%R<F%Y*#$Q.2P@,3,V+"`Q-3,I+`H@("`@)V=R
M87DG(#T^(&%R<F%Y*#$Y,"P@,3DP+"`Q.3`I+`H@("`@)VQI9VAT9W)A>2<@
M/3X@87)R87DH,C$Q+"`R,3$L(#(Q,2DL"B`@("`G;6ED;FEG:'1B;'5E)R`]
M/B!A<G)A>2@R-2P@,C4L(#$Q,BDL"B`@("`G;F%V>2<@/3X@87)R87DH,"P@
M,"P@,3(X*2P*("`@("=C;W)N9FQO=V5R8FQU92<@/3X@87)R87DH,3`P+"`Q
M-#DL(#(S-RDL"B`@("`G9&%R:W-L871E8FQU92<@/3X@87)R87DH-S(L(#8Q
M+"`Q,SDI+`H@("`@)W-L871E8FQU92<@/3X@87)R87DH,3`V+"`Y,"P@,C`U
M*2P*("`@("=M961I=6US;&%T96)L=64G(#T^(&%R<F%Y*#$R,RP@,3`T+"`R
M,S@I+`H@("`@)VQI9VAT<VQA=&5B;'5E)R`]/B!A<G)A>2@Q,S(L(#$Q,BP@
M,C4U*2P*("`@("=M961I=6UB;'5E)R`]/B!A<G)A>2@P+"`P+"`R,#4I+`H@
M("`@)W)O>6%L8FQU92<@/3X@87)R87DH-C4L(#$P-2P@,C(U*2P*("`@("=B
M;'5E)R`]/B!A<G)A>2@P+"`P+"`R-34I+`H@("`@)V1O9&=E<F)L=64G(#T^
M(&%R<F%Y*#,P+"`Q-#0L(#(U-2DL"B`@("`G9&5E<'-K>6)L=64G(#T^(&%R
M<F%Y*#`L(#$Y,2P@,C4U*2P*("`@("=S:WEB;'5E)R`]/B!A<G)A>2@Q,S4L
M(#(P-BP@,C,U*2P*("`@("=L:6=H='-K>6)L=64G(#T^(&%R<F%Y*#$S-2P@
M,C`V+"`R-3`I+`H@("`@)W-T965L8FQU92<@/3X@87)R87DH-S`L(#$S,"P@
M,3@P*2P*("`@("=L:6=H=')E9"<@/3X@87)R87DH,C$Q+"`Q-C<L(#$V."DL
M"B`@("`G;&EG:'1S=&5E;&)L=64G(#T^(&%R<F%Y*#$W-BP@,3DV+"`R,C(I
M+`H@("`@)VQI9VAT8FQU92<@/3X@87)R87DH,3<S+"`R,38L(#(S,"DL"B`@
M("`G<&]W9&5R8FQU92<@/3X@87)R87DH,3<V+"`R,C0L(#(S,"DL"B`@("`G
M<&%L971U<G%U;VES92<@/3X@87)R87DH,3<U+"`R,S@L(#(S."DL"B`@("`G
M9&%R:W1U<G%U;VES92<@/3X@87)R87DH,"P@,C`V+"`R,#DI+`H@("`@)VUE
M9&EU;71U<G%U;VES92<@/3X@87)R87DH-S(L(#(P.2P@,C`T*2P*("`@("=T
M=7)Q=6]I<V4G(#T^(&%R<F%Y*#8T+"`R,C0L(#(P."DL"B`@("`G8WEA;B<@
M/3X@87)R87DH,"P@,C4U+"`R-34I+`H@("`@)VQI9VAT8WEA;B<@/3X@87)R
M87DH,C(T+"`R-34L(#(U-2DL"B`@("`G8V%D971B;'5E)R`]/B!A<G)A>2@Y
M-2P@,34X+"`Q-C`I+`H@("`@)VUE9&EU;6%Q=6%M87)I;F4G(#T^(&%R<F%Y
M*#$P,BP@,C`U+"`Q-S`I+`H@("`@)V%Q=6%M87)I;F4G(#T^(&%R<F%Y*#$R
M-RP@,C4U+"`R,3(I+`H@("`@)V1A<FMG<F5E;B<@/3X@87)R87DH,"P@,3`P
M+"`P*2P*("`@("=D87)K;VQI=F5G<F5E;B<@/3X@87)R87DH.#4L(#$P-RP@
M-#<I+`H@("`@)V1A<FMS96%G<F5E;B<@/3X@87)R87DH,30S+"`Q.#@L(#$T
M,RDL"B`@("`G<V5A9W)E96XG(#T^(&%R<F%Y*#0V+"`Q,SDL(#@W*2P*("`@
M("=M961I=6US96%G<F5E;B<@/3X@87)R87DH-C`L(#$W.2P@,3$S*2P*("`@
M("=L:6=H='-E86=R965N)R`]/B!A<G)A>2@S,BP@,3<X+"`Q-S`I+`H@("`@
M)W!A;&5G<F5E;B<@/3X@87)R87DH,34R+"`R-3$L(#$U,BDL"B`@("`G<W!R
M:6YG9W)E96XG(#T^(&%R<F%Y*#`L(#(U-2P@,3(W*2P*("`@("=L87=N9W)E
M96XG(#T^(&%R<F%Y*#$R-"P@,C4R+"`P*2P*("`@("=G<F5E;B<@/3X@87)R
M87DH,"P@,C4U+"`P*2P*("`@("=C:&%R=')E=7-E)R`]/B!A<G)A>2@Q,C<L
M(#(U-2P@,"DL"B`@("`G;65D:75M<W!R:6YG9W)E96XG(#T^(&%R<F%Y*#`L
M(#(U,"P@,34T*2P*("`@("=G<F5E;GEE;&QO=R<@/3X@87)R87DH,3<S+"`R
M-34L(#0W*2P*("`@("=L:6UE9W)E96XG(#T^(&%R<F%Y*#4P+"`R,#4L(#4P
M*2P*("`@("=Y96QL;W=G<F5E;B<@/3X@87)R87DH,34T+"`R,#4L(#4P*2P*
M("`@("=F;W)E<W1G<F5E;B<@/3X@87)R87DH,S0L(#$S.2P@,S0I+`H@("`@
M)V]L:79E9')A8B<@/3X@87)R87DH,3`W+"`Q-#(L(#,U*2P*("`@("=D87)K
M:VAA:VDG(#T^(&%R<F%Y*#$X.2P@,3@S+"`Q,#<I+`H@("`@)VMH86MI)R`]
M/B!A<G)A>2@R-#`L(#(S,"P@,30P*2P*("`@("=P86QE9V]L9&5N<F]D)R`]
M/B!A<G)A>2@R,S@L(#(S,BP@,3<P*2P*("`@("=L:6=H=&=O;&1E;G)O9'EE
M;&QO=R<@/3X@87)R87DH,C4P+"`R-3`L(#(Q,"DL"B`@("`G;&EG:'1Y96QL
M;W<G(#T^(&%R<F%Y*#(U-2P@,C4U+"`R,#`I+`H@("`@)WEE;&QO=R<@/3X@
M87)R87DH,C4U+"`R-34L(#`I+`H@("`@)V=O;&0G(#T^(&%R<F%Y*#(U-2P@
M,C$U+"`P*2P*("`@("=L:6=H=&=O;&1E;G)O9"<@/3X@87)R87DH,C,X+"`R
M,C$L(#$S,"DL"B`@("`G9V]L9&5N<F]D)R`]/B!A<G)A>2@R,3@L(#$V-2P@
M,S(I+`H@("`@)V1A<FMG;VQD96YR;V0G(#T^(&%R<F%Y*#$X-"P@,3,T+"`Q
M,2DL"B`@("`G<F]S>6)R;W=N)R`]/B!A<G)A>2@Q.#@L(#$T,RP@,30S*2P*
M("`@("=I;F1I86YR960G(#T^(&%R<F%Y*#(P-2P@.3(L(#DR*2P*("`@("=S
M861D;&5B<F]W;B<@/3X@87)R87DH,3,Y+"`V.2P@,3DI+`H@("`@)W-I96YN
M82<@/3X@87)R87DH,38P+"`X,BP@-#4I+`H@("`@)W!E<G4G(#T^(&%R<F%Y
M*#(P-2P@,3,S+"`V,RDL"B`@("`G8G5R;'EW;V]D)R`]/B!A<G)A>2@R,C(L
M(#$X-"P@,3,U*2P*("`@("=B96EG92<@/3X@87)R87DH,C0U+"`R-#4L(#(R
M,"DL"B`@("`G=VAE870G(#T^(&%R<F%Y*#(T-2P@,C(R+"`Q-SDI+`H@("`@
M)W-A;F1Y8G)O=VXG(#T^(&%R<F%Y*#(T-"P@,38T+"`Y-BDL"B`@("`G=&%N
M)R`]/B!A<G)A>2@R,3`L(#$X,"P@,30P*2P*("`@("=C:&]C;VQA=&4G(#T^
M(&%R<F%Y*#(Q,"P@,3`U+"`S,"DL"B`@("`G9FER96)R:6-K)R`]/B!A<G)A
M>2@Q-S@L(#,T+"`S-"DL"B`@("`G8G)O=VXG(#T^(&%R<F%Y*#$V-2P@-#(L
M(#0R*2P*("`@("=D87)K<V%L;6]N)R`]/B!A<G)A>2@R,S,L(#$U,"P@,3(R
M*2P*("`@("=S86QM;VXG(#T^(&%R<F%Y*#(U,"P@,3(X+"`Q,30I+`H@("`@
M)VQI9VAT<V%L;6]N)R`]/B!A<G)A>2@R-34L(#$V,"P@,3(R*2P*("`@("=O
M<F%N9V4G(#T^(&%R<F%Y*#(U-2P@,38U+"`P*2P*("`@("=D87)K;W)A;F=E
M)R`]/B!A<G)A>2@R-34L(#$T,"P@,"DL"B`@("`G8V]R86PG(#T^(&%R<F%Y
M*#(U-2P@,3(W+"`X,"DL"B`@("`G;&EG:'1C;W)A;"<@/3X@87)R87DH,C0P
M+"`Q,C@L(#$R."DL"B`@("`G=&]M871O)R`]/B!A<G)A>2@R-34L(#DY+"`W
M,2DL"B`@("`G;W)A;F=E<F5D)R`]/B!A<G)A>2@R-34L(#8Y+"`P*2P*("`@
M("=R960G(#T^(&%R<F%Y*#(U-2P@,"P@,"DL"B`@("`G:&]T<&EN:R<@/3X@
M87)R87DH,C4U+"`Q,#4L(#$X,"DL"B`@("`G9&5E<'!I;FLG(#T^(&%R<F%Y
M*#(U-2P@,C`L(#$T-RDL"B`@("`G<&EN:R<@/3X@87)R87DH,C4U+"`Q.3(L
M(#(P,RDL"B`@("`G;&EG:'1P:6YK)R`]/B!A<G)A>2@R-34L(#$X,BP@,3DS
M*2P*("`@("=P86QE=FEO;&5T<F5D)R`]/B!A<G)A>2@R,3DL(#$Q,BP@,30W
M*2P*("`@("=M87)O;VXG(#T^(&%R<F%Y*#$W-BP@-#@L(#DV*2P*("`@("=M
M961I=6UV:6]L971R960G(#T^(&%R<F%Y*#$Y.2P@,C$L(#$S,RDL"B`@("`G
M=FEO;&5T<F5D)R`]/B!A<G)A>2@R,#@L(#,R+"`Q-#0I+`H@("`@)VUA9V5N
M=&$G(#T^(&%R<F%Y*#(U-2P@,"P@,C4U*2P*("`@("=V:6]L970G(#T^(&%R
M<F%Y*#(S."P@,3,P+"`R,S@I+`H@("`@)W!L=6TG(#T^(&%R<F%Y*#(R,2P@
M,38P+"`R,C$I+`H@("`@)V]R8VAI9"<@/3X@87)R87DH,C$X+"`Q,3(L(#(Q
M-"DL"B`@("`G;65D:75M;W)C:&ED)R`]/B!A<G)A>2@Q.#8L(#@U+"`R,3$I
M+`H@("`@)V1A<FMO<F-H:60G(#T^(&%R<F%Y*#$U,RP@-3`L(#(P-"DL"B`@
M("`G9&%R:W9I;VQE="<@/3X@87)R87DH,30X+"`P+"`R,3$I+`H@("`@)V)L
M=65V:6]L970G(#T^(&%R<F%Y*#$S."P@-#,L(#(R-BDL"B`@("`G<'5R<&QE
M)R`]/B!A<G)A>2@Q-C`L(#,R+"`R-#`I+`H@("`@)VUE9&EU;7!U<G!L92<@
M/3X@87)R87DH,30W+"`Q,3(L(#(Q.2DL"B`@("`G=&AI<W1L92<@/3X@87)R
M87DH,C$V+"`Q.3$L(#(Q-BDL"B`@("`G<VYO=S$G(#T^(&%R<F%Y*#(U-2P@
M,C4P+"`R-3`I+`H@("`@)W-N;W<R)R`]/B!A<G)A>2@R,S@L(#(S,RP@,C,S
M*2P*("`@("=S;F]W,R<@/3X@87)R87DH,C`U+"`R,#$L(#(P,2DL"B`@("`G
M<VYO=S0G(#T^(&%R<F%Y*#$S.2P@,3,W+"`Q,S<I+`H@("`@)W-E87-H96QL
M,2<@/3X@87)R87DH,C4U+"`R-#4L(#(S."DL"B`@("`G<V5A<VAE;&PR)R`]
M/B!A<G)A>2@R,S@L(#(R.2P@,C(R*2P*("`@("=S96%S:&5L;#,G(#T^(&%R
M<F%Y*#(P-2P@,3DW+"`Q.3$I+`H@("`@)W-E87-H96QL-"<@/3X@87)R87DH
M,3,Y+"`Q,S0L(#$S,"DL"B`@("`G06YT:7%U95=H:71E,2<@/3X@87)R87DH
M,C4U+"`R,SDL(#(Q.2DL"B`@("`G06YT:7%U95=H:71E,B<@/3X@87)R87DH
M,C,X+"`R,C,L(#(P-"DL"B`@("`G06YT:7%U95=H:71E,R<@/3X@87)R87DH
M,C`U+"`Q.3(L(#$W-BDL"B`@("`G06YT:7%U95=H:71E-"<@/3X@87)R87DH
M,3,Y+"`Q,S$L(#$R,"DL"B`@("`G8FES<75E,2<@/3X@87)R87DH,C4U+"`R
M,C@L(#$Y-BDL"B`@("`G8FES<75E,B<@/3X@87)R87DH,C,X+"`R,3,L(#$X
M,RDL"B`@("`G8FES<75E,R<@/3X@87)R87DH,C`U+"`Q.#,L(#$U."DL"B`@
M("`G8FES<75E-"<@/3X@87)R87DH,3,Y+"`Q,C4L(#$P-RDL"B`@("`G<&5A
M8VA0=69F,2<@/3X@87)R87DH,C4U+"`R,3@L(#$X-2DL"B`@("`G<&5A8VAP
M=69F,B<@/3X@87)R87DH,C,X+"`R,#,L(#$W,RDL"B`@("`G<&5A8VAP=69F
M,R<@/3X@87)R87DH,C`U+"`Q-S4L(#$T.2DL"B`@("`G<&5A8VAP=69F-"<@
M/3X@87)R87DH,3,Y+"`Q,3DL(#$P,2DL"B`@("`G;F%V86IO=VAI=&4Q)R`]
M/B!A<G)A>2@R-34L(#(R,BP@,3<S*2P*("`@("=N879A:F]W:&ET93(G(#T^
M(&%R<F%Y*#(S."P@,C`W+"`Q-C$I+`H@("`@)VYA=F%J;W=H:71E,R<@/3X@
M87)R87DH,C`U+"`Q-SDL(#$S.2DL"B`@("`G;F%V86IO=VAI=&4T)R`]/B!A
M<G)A>2@Q,SDL(#$R,2P@.30I+`H@("`@)VQE;6]N8VAI9F9O;C$G(#T^(&%R
M<F%Y*#(U-2P@,C4P+"`R,#4I+`H@("`@)VQE;6]N8VAI9F9O;C(G(#T^(&%R
M<F%Y*#(S."P@,C,S+"`Q.3$I+`H@("`@)VQE;6]N8VAI9F9O;C,G(#T^(&%R
M<F%Y*#(P-2P@,C`Q+"`Q-C4I+`H@("`@)VQE;6]N8VAI9F9O;C0G(#T^(&%R
M<F%Y*#$S.2P@,3,W+"`Q,3(I+`H@("`@)VEV;W)Y,2<@/3X@87)R87DH,C4U
M+"`R-34L(#(T,"DL"B`@("`G:79O<GDR)R`]/B!A<G)A>2@R,S@L(#(S."P@
M,C(T*2P*("`@("=I=F]R>3,G(#T^(&%R<F%Y*#(P-2P@,C`U+"`Q.3,I+`H@
M("`@)VEV;W)Y-"<@/3X@87)R87DH,3,Y+"`Q,SDL(#$S,2DL"B`@("`G:&]N
M97ED97<G(#T^(&%R<F%Y*#$Y,RP@,C`U+"`Q.3,I+`H@("`@)VQA=F5N9&5R
M8FQU<V@Q)R`]/B!A<G)A>2@R-34L(#(T,"P@,C0U*2P*("`@("=L879E;F1E
M<F)L=7-H,B<@/3X@87)R87DH,C,X+"`R,C0L(#(R.2DL"B`@("`G;&%V96YD
M97)B;'5S:#,G(#T^(&%R<F%Y*#(P-2P@,3DS+"`Q.3<I+`H@("`@)VQA=F5N
M9&5R8FQU<V@T)R`]/B!A<G)A>2@Q,SDL(#$S,2P@,3,T*2P*("`@("=M:7-T
M>7)O<V4Q)R`]/B!A<G)A>2@R-34L(#(R."P@,C(U*2P*("`@("=M:7-T>7)O
M<V4R)R`]/B!A<G)A>2@R,S@L(#(Q,RP@,C$P*2P*("`@("=M:7-T>7)O<V4S
M)R`]/B!A<G)A>2@R,#4L(#$X,RP@,3@Q*2P*("`@("=M:7-T>7)O<V4T)R`]
M/B!A<G)A>2@Q,SDL(#$R-2P@,3(S*2P*("`@("=A>G5R93$G(#T^(&%R<F%Y
M*#(T,"P@,C4U+"`R-34I+`H@("`@)V%Z=7)E,B<@/3X@87)R87DH,C(T+"`R
M,S@L(#(S."DL"B`@("`G87IU<F4S)R`]/B!A<G)A>2@Q.3,L(#(P-2P@,C`U
M*2P*("`@("=A>G5R930G(#T^(&%R<F%Y*#$S,2P@,3,Y+"`Q,SDI+`H@("`@
M)W-L871E8FQU93$G(#T^(&%R<F%Y*#$S,2P@,3$Q+"`R-34I+`H@("`@)W-L
M871E8FQU93(G(#T^(&%R<F%Y*#$R,BP@,3`S+"`R,S@I+`H@("`@)W-L871E
M8FQU93,G(#T^(&%R<F%Y*#$P-2P@.#DL(#(P-2DL"B`@("`G<VQA=&5B;'5E
M-"<@/3X@87)R87DH-S$L(#8P+"`Q,SDI+`H@("`@)W)O>6%L8FQU93$G(#T^
M(&%R<F%Y*#<R+"`Q,3@L(#(U-2DL"B`@("`G<F]Y86QB;'5E,B<@/3X@87)R
M87DH-C<L(#$Q,"P@,C,X*2P*("`@("=R;WEA;&)L=64S)R`]/B!A<G)A>2@U
M."P@.34L(#(P-2DL"B`@("`G<F]Y86QB;'5E-"<@/3X@87)R87DH,SDL(#8T
M+"`Q,SDI+`H@("`@)V1O9&=E<F)L=64Q)R`]/B!A<G)A>2@S,"P@,30T+"`R
M-34I+`H@("`@)V1O9&=E<F)L=64R)R`]/B!A<G)A>2@R."P@,3,T+"`R,S@I
M+`H@("`@)V1O9&=E<F)L=64S)R`]/B!A<G)A>2@R-"P@,3$V+"`R,#4I+`H@
M("`@)V1O9&=E<F)L=64T)R`]/B!A<G)A>2@Q-BP@-S@L(#$S.2DL"B`@("`G
M<W1E96QB;'5E,2<@/3X@87)R87DH.3DL(#$X-"P@,C4U*2P*("`@("=S=&5E
M;&)L=64R)R`]/B!A<G)A>2@Y,BP@,3<R+"`R,S@I+`H@("`@)W-T965L8FQU
M93,G(#T^(&%R<F%Y*#<Y+"`Q-#@L(#(P-2DL"B`@("`G<W1E96QB;'5E-"<@
M/3X@87)R87DH-30L(#$P,"P@,3,Y*2P*("`@("=D965P<VMY8FQU93$G(#T^
M(&%R<F%Y*#`L(#$Y,2P@,C4U*2P*("`@("=D965P<VMY8FQU93(G(#T^(&%R
M<F%Y*#`L(#$W."P@,C,X*2P*("`@("=D965P<VMY8FQU93,G(#T^(&%R<F%Y
M*#`L(#$U-"P@,C`U*2P*("`@("=D965P<VMY8FQU930G(#T^(&%R<F%Y*#`L
M(#$P-"P@,3,Y*2P*("`@("=S:WEB;'5E,2<@/3X@87)R87DH,3,U+"`R,#8L
M(#(U-2DL"B`@("`G<VMY8FQU93(G(#T^(&%R<F%Y*#$R-BP@,3DR+"`R,S@I
M+`H@("`@)W-K>6)L=64S)R`]/B!A<G)A>2@Q,#@L(#$V-BP@,C`U*2P*("`@
M("=S:WEB;'5E-"<@/3X@87)R87DH-S0L(#$Q,BP@,3,Y*2P*("`@("=L:6=H
M='-K>6)L=64Q)R`]/B!A<G)A>2@Q-S8L(#(R-BP@,C4U*2P*("`@("=L:6=H
M='-K>6)L=64R)R`]/B!A<G)A>2@Q-C0L(#(Q,2P@,C,X*2P*("`@("=L:6=H
M='-K>6)L=64S)R`]/B!A<G)A>2@Q-#$L(#$X,BP@,C`U*2P*("`@("=L:6=H
M='-K>6)L=64T)R`]/B!A<G)A>2@Y-BP@,3(S+"`Q,SDI+`H@("`@)W-L871E
M9W)A>3$G(#T^(&%R<F%Y*#$Y."P@,C(V+"`R-34I+`H@("`@)W-L871E9W)A
M>3(G(#T^(&%R<F%Y*#$X-2P@,C$Q+"`R,S@I+`H@("`@)W-L871E9W)A>3,G
M(#T^(&%R<F%Y*#$U.2P@,3@R+"`R,#4I+`H@("`@)W-L871E9W)A>30G(#T^
M(&%R<F%Y*#$P."P@,3(S+"`Q,SDI+`H@("`@)VQI9VAT<W1E96QB;'5E,2<@
M/3X@87)R87DH,C`R+"`R,C4L(#(U-2DL"B`@("`G;&EG:'1S=&5E;&)L=64R
M)R`]/B!A<G)A>2@Q.#@L(#(Q,"P@,C,X*2P*("`@("=L:6=H='-T965L8FQU
M93,G(#T^(&%R<F%Y*#$V,BP@,3@Q+"`R,#4I+`H@("`@)VQI9VAT<W1E96QB
M;'5E-"<@/3X@87)R87DH,3$P+"`Q,C,L(#$S.2DL"B`@("`G;&EG:'1B;'5E
M,2<@/3X@87)R87DH,3DQ+"`R,SDL(#(U-2DL"B`@("`G;&EG:'1B;'5E,B<@
M/3X@87)R87DH,3<X+"`R,C,L(#(S."DL"B`@("`G;&EG:'1B;'5E,R<@/3X@
M87)R87DH,34T+"`Q.3(L(#(P-2DL"B`@("`G;&EG:'1B;'5E-"<@/3X@87)R
M87DH,3`T+"`Q,S$L(#$S.2DL"B`@("`G;&EG:'1C>6%N,2<@/3X@87)R87DH
M,C(T+"`R-34L(#(U-2DL"B`@("`G;&EG:'1C>6%N,B<@/3X@87)R87DH,C`Y
M+"`R,S@L(#(S."DL"B`@("`G;&EG:'1C>6%N,R<@/3X@87)R87DH,3@P+"`R
M,#4L(#(P-2DL"B`@("`G;&EG:'1C>6%N-"<@/3X@87)R87DH,3(R+"`Q,SDL
M(#$S.2DL"B`@("`G<&%L971U<G%U;VES93$G(#T^(&%R<F%Y*#$X-RP@,C4U
M+"`R-34I+`H@("`@)W!A;&5T=7)Q=6]I<V4R)R`]/B!A<G)A>2@Q-S0L(#(S
M."P@,C,X*2P*("`@("=P86QE='5R<75O:7-E,R<@/3X@87)R87DH,34P+"`R
M,#4L(#(P-2DL"B`@("`G<&%L971U<G%U;VES930G(#T^(&%R<F%Y*#$P,BP@
M,3,Y+"`Q,SDI+`H@("`@)V-A9&5T8FQU93$G(#T^(&%R<F%Y*#$U,BP@,C0U
M+"`R-34I+`H@("`@)V-A9&5T8FQU93(G(#T^(&%R<F%Y*#$T,BP@,C(Y+"`R
M,S@I+`H@("`@)V-A9&5T8FQU93,G(#T^(&%R<F%Y*#$R,BP@,3DW+"`R,#4I
M+`H@("`@)V-A9&5T8FQU930G(#T^(&%R<F%Y*#@S+"`Q,S0L(#$S.2DL"B`@
M("`G='5R<75O:7-E,2<@/3X@87)R87DH,"P@,C0U+"`R-34I+`H@("`@)W1U
M<G%U;VES93(G(#T^(&%R<F%Y*#`L(#(R.2P@,C,X*2P*("`@("=T=7)Q=6]I
M<V4S)R`]/B!A<G)A>2@P+"`Q.3<L(#(P-2DL"B`@("`G='5R<75O:7-E-"<@
M/3X@87)R87DH,"P@,3,T+"`Q,SDI+`H@("`@)V-Y86XQ)R`]/B!A<G)A>2@P
M+"`R-34L(#(U-2DL"B`@("`G8WEA;C(G(#T^(&%R<F%Y*#`L(#(S."P@,C,X
M*2P*("`@("=C>6%N,R<@/3X@87)R87DH,"P@,C`U+"`R,#4I+`H@("`@)V-Y
M86XT)R`]/B!A<G)A>2@P+"`Q,SDL(#$S.2DL"B`@("`G9&%R:W-L871E9W)A
M>3$G(#T^(&%R<F%Y*#$U,2P@,C4U+"`R-34I+`H@("`@)V1A<FMS;&%T96=R
M87DR)R`]/B!A<G)A>2@Q-#$L(#(S."P@,C,X*2P*("`@("=D87)K<VQA=&5G
M<F%Y,R<@/3X@87)R87DH,3(Q+"`R,#4L(#(P-2DL"B`@("`G9&%R:W-L871E
M9W)A>30G(#T^(&%R<F%Y*#@R+"`Q,SDL(#$S.2DL"B`@("`G87%U86UA<FEN
M93$G(#T^(&%R<F%Y*#$R-RP@,C4U+"`R,3(I+`H@("`@)V%Q=6%M87)I;F4R
M)R`]/B!A<G)A>2@Q,3@L(#(S."P@,3DX*2P*("`@("=A<75A;6%R:6YE,R<@
M/3X@87)R87DH,3`R+"`R,#4L(#$W,"DL"B`@("`G87%U86UA<FEN930G(#T^
M(&%R<F%Y*#8Y+"`Q,SDL(#$Q-BDL"B`@("`G9&%R:W-E86=R965N,2<@/3X@
M87)R87DH,3DS+"`R-34L(#$Y,RDL"B`@("`G9&%R:W-E86=R965N,B<@/3X@
M87)R87DH,3@P+"`R,S@L(#$X,"DL"B`@("`G9&%R:W-E86=R965N,R<@/3X@
M87)R87DH,34U+"`R,#4L(#$U-2DL"B`@("`G9&%R:W-E86=R965N-"<@/3X@
M87)R87DH,3`U+"`Q,SDL(#$P-2DL"B`@("`G<V5A9W)E96XQ)R`]/B!A<G)A
M>2@X-"P@,C4U+"`Q-3DI+`H@("`@)W-E86=R965N,B<@/3X@87)R87DH-S@L
M(#(S."P@,30X*2P*("`@("=S96%G<F5E;C,G(#T^(&%R<F%Y*#8W+"`R,#4L
M(#$R."DL"B`@("`G<V5A9W)E96XT)R`]/B!A<G)A>2@T-BP@,3,Y+"`X-RDL
M"B`@("`G<&%L96=R965N,2<@/3X@87)R87DH,34T+"`R-34L(#$U-"DL"B`@
M("`G<&%L96=R965N,B<@/3X@87)R87DH,30T+"`R,S@L(#$T-"DL"B`@("`G
M<&%L96=R965N,R<@/3X@87)R87DH,3(T+"`R,#4L(#$R-"DL"B`@("`G<&%L
M96=R965N-"<@/3X@87)R87DH.#0L(#$S.2P@.#0I+`H@("`@)W-P<FEN9V=R
M965N,2<@/3X@87)R87DH,"P@,C4U+"`Q,C<I+`H@("`@)W-P<FEN9V=R965N
M,B<@/3X@87)R87DH,"P@,C,X+"`Q,3@I+`H@("`@)W-P<FEN9V=R965N,R<@
M/3X@87)R87DH,"P@,C`U+"`Q,#(I+`H@("`@)W-P<FEN9V=R965N-"<@/3X@
M87)R87DH,"P@,3,Y+"`V.2DL"B`@("`G8VAA<G1R975S93$G(#T^(&%R<F%Y
M*#$R-RP@,C4U+"`P*2P*("`@("=C:&%R=')E=7-E,B<@/3X@87)R87DH,3$X
M+"`R,S@L(#`I+`H@("`@)V-H87)T<F5U<V4S)R`]/B!A<G)A>2@Q,#(L(#(P
M-2P@,"DL"B`@("`G8VAA<G1R975S930G(#T^(&%R<F%Y*#8Y+"`Q,SDL(#`I
M+`H@("`@)V]L:79E9')A8C$G(#T^(&%R<F%Y*#$Y,BP@,C4U+"`V,BDL"B`@
M("`G;VQI=F5D<F%B,B<@/3X@87)R87DH,3<Y+"`R,S@L(#4X*2P*("`@("=O
M;&EV961R86(S)R`]/B!A<G)A>2@Q-30L(#(P-2P@-3`I+`H@("`@)V]L:79E
M9')A8C0G(#T^(&%R<F%Y*#$P-2P@,3,Y+"`S-"DL"B`@("`G9&%R:V]L:79E
M9W)E96XQ)R`]/B!A<G)A>2@R,#(L(#(U-2P@,3$R*2P*("`@("=D87)K;VQI
M=F5G<F5E;C(G(#T^(&%R<F%Y*#$X."P@,C,X+"`Q,#0I+`H@("`@)V1A<FMO
M;&EV96=R965N,R<@/3X@87)R87DH,38R+"`R,#4L(#DP*2P*("`@("=D87)K
M;VQI=F5G<F5E;C0G(#T^(&%R<F%Y*#$Q,"P@,3,Y+"`V,2DL"B`@("`G:VAA
M:VDQ)R`]/B!A<G)A>2@R-34L(#(T-BP@,30S*2P*("`@("=K:&%K:3(G(#T^
M(&%R<F%Y*#(S."P@,C,P+"`Q,S,I+`H@("`@)VMH86MI,R<@/3X@87)R87DH
M,C`U+"`Q.3@L(#$Q-2DL"B`@("`G:VAA:VDT)R`]/B!A<G)A>2@Q,SDL(#$S
M-"P@-S@I+`H@("`@)VQI9VAT9V]L9&5N<F]D,2<@/3X@87)R87DH,C4U+"`R
M,S8L(#$S.2DL"B`@("`G;&EG:'1G;VQD96YR;V0R)R`]/B!A<G)A>2@R,S@L
M(#(R,"P@,3,P*2P*("`@("=L:6=H=&=O;&1E;G)O9#,G(#T^(&%R<F%Y*#(P
M-2P@,3DP+"`Q,3(I+`H@("`@)VQI9VAT9V]L9&5N<F]D-"<@/3X@87)R87DH
M,3,Y+"`Q,CDL(#<V*2P*("`@("=Y96QL;W<Q)R`]/B!A<G)A>2@R-34L(#(U
M-2P@,"DL"B`@("`G>65L;&]W,B<@/3X@87)R87DH,C,X+"`R,S@L(#`I+`H@
M("`@)WEE;&QO=S,G(#T^(&%R<F%Y*#(P-2P@,C`U+"`P*2P*("`@("=Y96QL
M;W<T)R`]/B!A<G)A>2@Q,SDL(#$S.2P@,"DL"B`@("`G9V]L9#$G(#T^(&%R
M<F%Y*#(U-2P@,C$U+"`P*2P*("`@("=G;VQD,B<@/3X@87)R87DH,C,X+"`R
M,#$L(#`I+`H@("`@)V=O;&0S)R`]/B!A<G)A>2@R,#4L(#$W,RP@,"DL"B`@
M("`G9V]L9#0G(#T^(&%R<F%Y*#$S.2P@,3$W+"`P*2P*("`@("=G;VQD96YR
M;V0Q)R`]/B!A<G)A>2@R-34L(#$Y,RP@,S<I+`H@("`@)V=O;&1E;G)O9#(G
M(#T^(&%R<F%Y*#(S."P@,3@P+"`S-"DL"B`@("`G9V]L9&5N<F]D,R<@/3X@
M87)R87DH,C`U+"`Q-34L(#(Y*2P*("`@("=G;VQD96YR;V0T)R`]/B!A<G)A
M>2@Q,SDL(#$P-2P@,C`I+`H@("`@)V1A<FMG;VQD96YR;V0Q)R`]/B!A<G)A
M>2@R-34L(#$X-2P@,34I+`H@("`@)V1A<FMG;VQD96YR;V0R)R`]/B!A<G)A
M>2@R,S@L(#$W,RP@,30I+`H@("`@)V1A<FMG;VQD96YR;V0S)R`]/B!A<G)A
M>2@R,#4L(#$T.2P@,3(I+`H@("`@)V1A<FMG;VQD96YR;V0T)R`]/B!A<G)A
M>2@Q,SDL(#$P,2P@."DL"B`@("`G<F]S>6)R;W=N,2<@/3X@87)R87DH,C4U
M+"`Q.3,L(#$Y,RDL"B`@("`G<F]S>6)R;W=N,B<@/3X@87)R87DH,C,X+"`Q
M.#`L(#$X,"DL"B`@("`G<F]S>6)R;W=N,R<@/3X@87)R87DH,C`U+"`Q-34L
M(#$U-2DL"B`@("`G<F]S>6)R;W=N-"<@/3X@87)R87DH,3,Y+"`Q,#4L(#$P
M-2DL"B`@("`G:6YD:6%N<F5D,2<@/3X@87)R87DH,C4U+"`Q,#8L(#$P-BDL
M"B`@("`G:6YD:6%N<F5D,B<@/3X@87)R87DH,C,X+"`Y.2P@.3DI+`H@("`@
M)VEN9&EA;G)E9#,G(#T^(&%R<F%Y*#(P-2P@.#4L(#@U*2P*("`@("=I;F1I
M86YR960T)R`]/B!A<G)A>2@Q,SDL(#4X+"`U."DL"B`@("`G<VEE;FYA,2<@
M/3X@87)R87DH,C4U+"`Q,S`L(#<Q*2P*("`@("=S:65N;F$R)R`]/B!A<G)A
M>2@R,S@L(#$R,2P@-C8I+`H@("`@)W-I96YN83,G(#T^(&%R<F%Y*#(P-2P@
M,3`T+"`U-RDL"B`@("`G<VEE;FYA-"<@/3X@87)R87DH,3,Y+"`W,2P@,S@I
M+`H@("`@)V)U<FQY=V]O9#$G(#T^(&%R<F%Y*#(U-2P@,C$Q+"`Q-34I+`H@
M("`@)V)U<FQY=V]O9#(G(#T^(&%R<F%Y*#(S."P@,3DW+"`Q-#4I+`H@("`@
M)V)U<FQY=V]O9#,G(#T^(&%R<F%Y*#(P-2P@,3<P+"`Q,C4I+`H@("`@)V)U
M<FQY=V]O9#0G(#T^(&%R<F%Y*#$S.2P@,3$U+"`X-2DL"B`@("`G=VAE870Q
M)R`]/B!A<G)A>2@R-34L(#(S,2P@,3@V*2P*("`@("=W:&5A=#(G(#T^(&%R
M<F%Y*#(S."P@,C$V+"`Q-S0I+`H@("`@)W=H96%T,R<@/3X@87)R87DH,C`U
M+"`Q.#8L(#$U,"DL"B`@("`G=VAE870T)R`]/B!A<G)A>2@Q,SDL(#$R-BP@
M,3`R*2P*("`@("=T86XQ)R`]/B!A<G)A>2@R-34L(#$V-2P@-SDI+`H@("`@
M)W1A;C(G(#T^(&%R<F%Y*#(S."P@,34T+"`W,RDL"B`@("`G=&%N,R<@/3X@
M87)R87DH,C`U+"`Q,S,L(#8S*2P*("`@("=T86XT)R`]/B!A<G)A>2@Q,SDL
M(#DP+"`T,RDL"B`@("`G8VAO8V]L871E,2<@/3X@87)R87DH,C4U+"`Q,C<L
M(#,V*2P*("`@("=C:&]C;VQA=&4R)R`]/B!A<G)A>2@R,S@L(#$Q."P@,S,I
M+`H@("`@)V-H;V-O;&%T93,G(#T^(&%R<F%Y*#(P-2P@,3`R+"`R.2DL"B`@
M("`G8VAO8V]L871E-"<@/3X@87)R87DH,3,Y+"`V.2P@,3DI+`H@("`@)V9I
M<F5B<FEC:S$G(#T^(&%R<F%Y*#(U-2P@-#@L(#0X*2P*("`@("=F:7)E8G)I
M8VLR)R`]/B!A<G)A>2@R,S@L(#0T+"`T-"DL"B`@("`G9FER96)R:6-K,R<@
M/3X@87)R87DH,C`U+"`S."P@,S@I+`H@("`@)V9I<F5B<FEC:S0G(#T^(&%R
M<F%Y*#$S.2P@,C8L(#(V*2P*("`@("=B<F]W;C$G(#T^(&%R<F%Y*#(U-2P@
M-C0L(#8T*2P*("`@("=B<F]W;C(G(#T^(&%R<F%Y*#(S."P@-3DL(#4Y*2P*
M("`@("=B<F]W;C,G(#T^(&%R<F%Y*#(P-2P@-3$L(#4Q*2P*("`@("=B<F]W
M;C0G(#T^(&%R<F%Y*#$S.2P@,S4L(#,U*2P*("`@("=S86QM;VXQ)R`]/B!A
M<G)A>2@R-34L(#$T,"P@,3`U*2P*("`@("=S86QM;VXR)R`]/B!A<G)A>2@R
M,S@L(#$S,"P@.3@I+`H@("`@)W-A;&UO;C,G(#T^(&%R<F%Y*#(P-2P@,3$R
M+"`X-"DL"B`@("`G<V%L;6]N-"<@/3X@87)R87DH,3,Y+"`W-BP@-3<I+`H@
M("`@)VQI9VAT<V%L;6]N,2<@/3X@87)R87DH,C4U+"`Q-C`L(#$R,BDL"B`@
M("`G;&EG:'1S86QM;VXR)R`]/B!A<G)A>2@R,S@L(#$T.2P@,3$T*2P*("`@
M("=L:6=H='-A;&UO;C,G(#T^(&%R<F%Y*#(P-2P@,3(Y+"`Y."DL"B`@("`G
M;&EG:'1S86QM;VXT)R`]/B!A<G)A>2@Q,SDL(#@W+"`V-BDL"B`@("`G;W)A
M;F=E,2<@/3X@87)R87DH,C4U+"`Q-C4L(#`I+`H@("`@)V]R86YG93(G(#T^
M(&%R<F%Y*#(S."P@,34T+"`P*2P*("`@("=O<F%N9V4S)R`]/B!A<G)A>2@R
M,#4L(#$S,RP@,"DL"B`@("`G;W)A;F=E-"<@/3X@87)R87DH,3,Y+"`Y,"P@
M,"DL"B`@("`G9&%R:V]R86YG93$G(#T^(&%R<F%Y*#(U-2P@,3(W+"`P*2P*
M("`@("=D87)K;W)A;F=E,B<@/3X@87)R87DH,C,X+"`Q,3@L(#`I+`H@("`@
M)V1A<FMO<F%N9V4S)R`]/B!A<G)A>2@R,#4L(#$P,BP@,"DL"B`@("`G9&%R
M:V]R86YG930G(#T^(&%R<F%Y*#$S.2P@-CDL(#`I+`H@("`@)V-O<F%L,2<@
M/3X@87)R87DH,C4U+"`Q,30L(#@V*2P*("`@("=C;W)A;#(G(#T^(&%R<F%Y
M*#(S."P@,3`V+"`X,"DL"B`@("`G8V]R86PS)R`]/B!A<G)A>2@R,#4L(#DQ
M+"`V.2DL"B`@("`G8V]R86PT)R`]/B!A<G)A>2@Q,SDL(#8R+"`T-RDL"B`@
M("`G=&]M871O,2<@/3X@87)R87DH,C4U+"`Y.2P@-S$I+`H@("`@)W1O;6%T
M;S(G(#T^(&%R<F%Y*#(S."P@.3(L(#8V*2P*("`@("=T;VUA=&\S)R`]/B!A
M<G)A>2@R,#4L(#<Y+"`U-RDL"B`@("`G=&]M871O-"<@/3X@87)R87DH,3,Y
M+"`U-"P@,S@I+`H@("`@)V]R86YG97)E9#$G(#T^(&%R<F%Y*#(U-2P@-CDL
M(#`I+`H@("`@)V]R86YG97)E9#(G(#T^(&%R<F%Y*#(S."P@-C0L(#`I+`H@
M("`@)V]R86YG97)E9#,G(#T^(&%R<F%Y*#(P-2P@-34L(#`I+`H@("`@)V]R
M86YG97)E9#0G(#T^(&%R<F%Y*#$S.2P@,S<L(#`I+`H@("`@)V1E97!P:6YK
M,2<@/3X@87)R87DH,C4U+"`R,"P@,30W*2P*("`@("=D965P<&EN:S(G(#T^
M(&%R<F%Y*#(S."P@,3@L(#$S-RDL"B`@("`G9&5E<'!I;FLS)R`]/B!A<G)A
M>2@R,#4L(#$V+"`Q,3@I+`H@("`@)V1E97!P:6YK-"<@/3X@87)R87DH,3,Y
M+"`Q,"P@.#`I+`H@("`@)VAO='!I;FLQ)R`]/B!A<G)A>2@R-34L(#$Q,"P@
M,3@P*2P*("`@("=H;W1P:6YK,B<@/3X@87)R87DH,C,X+"`Q,#8L(#$V-RDL
M"B`@("`G:&]T<&EN:S,G(#T^(&%R<F%Y*#(P-2P@.38L(#$T-"DL"B`@("`G
M:&]T<&EN:S0G(#T^(&%R<F%Y*#$S.2P@-3@L(#DX*2P*("`@("=P:6YK,2<@
M/3X@87)R87DH,C4U+"`Q.#$L(#$Y-RDL"B`@("`G<&EN:S(G(#T^(&%R<F%Y
M*#(S."P@,38Y+"`Q.#0I+`H@("`@)W!I;FLS)R`]/B!A<G)A>2@R,#4L(#$T
M-2P@,34X*2P*("`@("=P:6YK-"<@/3X@87)R87DH,3,Y+"`Y.2P@,3`X*2P*
M("`@("=L:6=H='!I;FLQ)R`]/B!A<G)A>2@R-34L(#$W-"P@,3@U*2P*("`@
M("=L:6=H='!I;FLR)R`]/B!A<G)A>2@R,S@L(#$V,BP@,3<S*2P*("`@("=L
M:6=H='!I;FLS)R`]/B!A<G)A>2@R,#4L(#$T,"P@,30Y*2P*("`@("=L:6=H
M='!I;FLT)R`]/B!A<G)A>2@Q,SDL(#DU+"`Q,#$I+`H@("`@)W!A;&5V:6]L
M971R960Q)R`]/B!A<G)A>2@R-34L(#$S,"P@,3<Q*2P*("`@("=P86QE=FEO
M;&5T<F5D,B<@/3X@87)R87DH,C,X+"`Q,C$L(#$U.2DL"B`@("`G<&%L979I
M;VQE=')E9#,G(#T^(&%R<F%Y*#(P-2P@,3`T+"`Q,S<I+`H@("`@)W!A;&5V
M:6]L971R960T)R`]/B!A<G)A>2@Q,SDL(#<Q+"`Y,RDL"B`@("`G;6%R;V]N
M,2<@/3X@87)R87DH,C4U+"`U,BP@,3<Y*2P*("`@("=M87)O;VXR)R`]/B!A
M<G)A>2@R,S@L(#0X+"`Q-C<I+`H@("`@)VUA<F]O;C,G(#T^(&%R<F%Y*#(P
M-2P@-#$L(#$T-"DL"B`@("`G;6%R;V]N-"<@/3X@87)R87DH,3,Y+"`R."P@
M.3@I+`H@("`@)W9I;VQE=')E9#$G(#T^(&%R<F%Y*#(U-2P@-C(L(#$U,"DL
M"B`@("`G=FEO;&5T<F5D,B<@/3X@87)R87DH,C,X+"`U."P@,30P*2P*("`@
M("=V:6]L971R960S)R`]/B!A<G)A>2@R,#4L(#4P+"`Q,C`I+`H@("`@)W9I
M;VQE=')E9#0G(#T^(&%R<F%Y*#$S.2P@,S0L(#@R*2P*("`@("=M86=E;G1A
M,2<@/3X@87)R87DH,C4U+"`P+"`R-34I+`H@("`@)VUA9V5N=&$R)R`]/B!A
M<G)A>2@R,S@L(#`L(#(S."DL"B`@("`G;6%G96YT83,G(#T^(&%R<F%Y*#(P
M-2P@,"P@,C`U*2P*("`@("=M86=E;G1A-"<@/3X@87)R87DH,3,Y+"`P+"`Q
M,SDI+`H@("`@)VUE9&EU;7)E9"<@/3X@87)R87DH,30P+"`S-"P@,S0I+`H@
M("`@)V]R8VAI9#$G(#T^(&%R<F%Y*#(U-2P@,3,Q+"`R-3`I+`H@("`@)V]R
M8VAI9#(G(#T^(&%R<F%Y*#(S."P@,3(R+"`R,S,I+`H@("`@)V]R8VAI9#,G
M(#T^(&%R<F%Y*#(P-2P@,3`U+"`R,#$I+`H@("`@)V]R8VAI9#0G(#T^(&%R
M<F%Y*#$S.2P@-S$L(#$S-RDL"B`@("`G<&QU;3$G(#T^(&%R<F%Y*#(U-2P@
M,3@W+"`R-34I+`H@("`@)W!L=6TR)R`]/B!A<G)A>2@R,S@L(#$W-"P@,C,X
M*2P*("`@("=P;'5M,R<@/3X@87)R87DH,C`U+"`Q-3`L(#(P-2DL"B`@("`G
M<&QU;30G(#T^(&%R<F%Y*#$S.2P@,3`R+"`Q,SDI+`H@("`@)VUE9&EU;6]R
M8VAI9#$G(#T^(&%R<F%Y*#(R-"P@,3`R+"`R-34I+`H@("`@)VUE9&EU;6]R
M8VAI9#(G(#T^(&%R<F%Y*#(P.2P@.34L(#(S."DL"B`@("`G;65D:75M;W)C
M:&ED,R<@/3X@87)R87DH,3@P+"`X,BP@,C`U*2P*("`@("=M961I=6UO<F-H
M:60T)R`]/B!A<G)A>2@Q,C(L(#4U+"`Q,SDI+`H@("`@)V1A<FMO<F-H:60Q
M)R`]/B!A<G)A>2@Q.3$L(#8R+"`R-34I+`H@("`@)V1A<FMO<F-H:60R)R`]
M/B!A<G)A>2@Q-S@L(#4X+"`R,S@I+`H@("`@)V1A<FMO<F-H:60S)R`]/B!A
M<G)A>2@Q-30L(#4P+"`R,#4I+`H@("`@)V1A<FMO<F-H:60T)R`]/B!A<G)A
M>2@Q,#0L(#,T+"`Q,SDI+`H@("`@)W!U<G!L93$G(#T^(&%R<F%Y*#$U-2P@
M-#@L(#(U-2DL"B`@("`G<'5R<&QE,B<@/3X@87)R87DH,30U+"`T-"P@,C,X
M*2P*("`@("=P=7)P;&4S)R`]/B!A<G)A>2@Q,C4L(#,X+"`R,#4I+`H@("`@
M)W!U<G!L930G(#T^(&%R<F%Y*#@U+"`R-BP@,3,Y*2P*("`@("=M961I=6UP
M=7)P;&4Q)R`]/B!A<G)A>2@Q-S$L(#$S,"P@,C4U*2P*("`@("=M961I=6UP
M=7)P;&4R)R`]/B!A<G)A>2@Q-3DL(#$R,2P@,C,X*2P*("`@("=M961I=6UP
M=7)P;&4S)R`]/B!A<G)A>2@Q,S<L(#$P-"P@,C`U*2P*("`@("=M961I=6UP
M=7)P;&4T)R`]/B!A<G)A>2@Y,RP@-S$L(#$S.2DL"B`@("`G=&AI<W1L93$G
M(#T^(&%R<F%Y*#(U-2P@,C(U+"`R-34I+`H@("`@)W1H:7-T;&4R)R`]/B!A
M<G)A>2@R,S@L(#(Q,"P@,C,X*2P*("`@("=T:&ES=&QE,R<@/3X@87)R87DH
M,C`U+"`Q.#$L(#(P-2DL"B`@("`G=&AI<W1L930G(#T^(&%R<F%Y*#$S.2P@
M,3(S+"`Q,SDI+`H@("`@)V=R87DQ)R`]/B!A<G)A>2@Q,"P@,3`L(#$P*2P*
M("`@("=G<F%Y,B<@/3X@87)R87DH-#`L(#0P+"`S,"DL"B`@("`G9W)A>3,G
M(#T^(&%R<F%Y*#<P+"`W,"P@-S`I+`H@("`@)V=R87DT)R`]/B!A<G)A>2@Q
M,#`L(#$P,"P@,3`P*2P*("`@("=G<F%Y-2<@/3X@87)R87DH,3,P+"`Q,S`L
M(#$S,"DL"B`@("`G9W)A>38G(#T^(&%R<F%Y*#$V,"P@,38P+"`Q-C`I+`H@
M("`@)V=R87DW)R`]/B!A<G)A>2@Q.3`L(#$Y,"P@,3DP*2P*("`@("=G<F%Y
M."<@/3X@87)R87DH,C$P+"`R,3`L(#(Q,"DL"B`@("`G9W)A>3DG(#T^(&%R
M<F%Y*#(T,"P@,C0P+"`R-#`I+`H@("`@)V1A<FMG<F%Y)R`]/B!A<G)A>2@Q
M,#`L(#$P,"P@,3`P*2P*("`@("=D87)K8FQU92<@/3X@87)R87DH,"P@,"P@
M,3,Y*2P*("`@("=D87)K8WEA;B<@/3X@87)R87DH,"P@,3,Y+"`Q,SDI+`H@
M("`@)V1A<FMM86=E;G1A)R`]/B!A<G)A>2@Q,SDL(#`L(#$S.2DL"B`@("`G
M9&%R:W)E9"<@/3X@87)R87DH,3,Y+"`P+"`P*2P*("`@("=S:6QV97(G(#T^
M(&%R<F%Y*#$Y,BP@(#$Y,BP@(#$Y,BDL"B`@("`G96=G<&QA;G0G(#T^(&%R
M<F%Y*#$T-"P@,3<V+"`Q-C@I+`H@("`@)VQI9VAT9W)E96XG(#T^(&%R<F%Y
M*#$T-"P@,C,X+"`Q-#0I"BD["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O<W9G
M+G!H<```````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,Q-C`Q
M`#$P-#$W,S8R-S<S`#`R,#4V-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B]);6%G92YP:'`G.PIR97%U:7)E7V]N8V4@)UA-
M3"]35D<N<&AP)SL*"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE
M($AO<F1E7TEM86=E.CH@05!)(&9O<B!35D<N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TEM86=E+TEM86=E+W-V9RYP:'`L=B`Q+C,Q+C$P+C8@,C`P-B\P
M,2\P,2`R,3HR.#HR,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?26UA9V4*("HO"F-L87-S($AO<F1E7TEM86=E7W-V9R!E>'1E;F1S
M($AO<F1E7TEM86=E('L*"B`@("!V87(@)%]S=F<["@H@("`@+RHJ"B`@("`@
M*B!#87!A8FEL:71E<R!O9B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-A<&%B:6QI=&EE<R`](&%R
M<F%Y*"=C86YV87,G*3L*"B`@("!F=6YC=&EO;B!(;W)D95]);6%G95]S=F<H
M)'!A<F%M<RD*("`@('L*("`@("`@("!P87)E;G0Z.DAO<F1E7TEM86=E*"1P
M87)A;7,I.PH@("`@("`@("1T:&ES+3Y?<W9G(#T@)FYE=R!834Q?4U9'7T1O
M8W5M96YT*&%R<F%Y*"=W:61T:"<@/3X@)'1H:7,M/E]W:61T:"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:&5I9VAT)R`]/B`D=&AI<RT^7VAE:6=H="DI.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$-O;G1E;G14>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)VEM
M86=E+W-V9RMX;6PG.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$QI;FLH)'5R
M;"P@)'1I=&QE(#T@)R<I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@9&ES
M<&QA>2@I"B`@("!["B`@("`@("`@)'1H:7,M/E]S=F<M/G!R:6YT16QE;65N
M="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!R87<@9&%T
M82!F;W(@=&AI<R!I;6%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(')A=R!I;6%G92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M87<H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-V9RT^8G5F9F5R
M3V)J96-T*"D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1F]N="@D9F]N="D*
M("`@('L*("`@("`@("!R971U<FX@)&9O;G0["B`@("!]"@H@("`@9G5N8W1I
M;VX@7V-R96%T95-Y;6)O;"@D<RP@)&ED*0H@("`@>PH@("`@("`@("1S+3YS
M971087)A;2@G:60G+"`D:60I.PH@("`@("`@("1D969S(#T@)FYE=R!834Q?
M4U9'7T1E9G,H*3L*("`@("`@("`D9&5F<RT^861D0VAI;&0H)',I.PH@("`@
M("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"@D9&5F<RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@7V-R96%T941R;W!3:&%D;W<H)&ED(#T@)V1R;W!3:&%D;W<G
M*0H@("`@>PH@("`@("`@("1D969S(#T@)FYE=R!834Q?4U9'7T1E9G,H*3L*
M("`@("`@("`D9FEL=&5R(#T@)FYE=R!834Q?4U9'7T9I;'1E<BAA<G)A>2@G
M:60G(#T^("1I9"DI.PH@("`@("`@("1F:6QT97(M/F%D9%!R:6UI=&EV92@G
M1V%U<W-I86Y";'5R)RP@87)R87DH)VEN)R`]/B`G4V]U<F-E06QP:&$G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W-T9$1E=FEA=&EO;B<@/3X@,BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-U;'0G(#T^
M("=B;'5R)RDI.PH@("`@("`@("1F:6QT97(M/F%D9%!R:6UI=&EV92@G3V9F
M<V5T)RP@87)R87DH)VEN)R`]/B`G8FQU<B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9'@G(#T^(#0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9'DG
M(#T^(#0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5S=6QT)R`]/B`G;V9F<V5T0FQU<B<I*3L*("`@("`@("`D
M;65R9V4@/2`F;F5W(%A-3%]35D=?1FEL=&5R4')I;6ET:79E*"=-97)G92<I
M.PH@("`@("`@("1M97)G92T^861D365R9V5.;V1E*"=O9F9S971";'5R)RD[
M"B`@("`@("`@)&UE<F=E+3YA9&1-97)G94YO9&4H)U-O=7)C94=R87!H:6,G
M*3L*"B`@("`@("`@)&9I;'1E<BT^861D0VAI;&0H)&UE<F=E*3L*("`@("`@
M("`D9&5F<RT^861D0VAI;&0H)&9I;'1E<BD["B`@("`@("`@)'1H:7,M/E]S
M=F<M/F%D9$-H:6QD*"1D969S*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R
M87=S(&$@=&5X="!S=')I;F<@;VX@=&AE(&EM86=E(&EN(&$@<W!E8VEF:65D
M(&QO8V%T:6]N+"!W:71H"B`@("`@*B!T:&4@<W!E8VEF:65D('-T>6QE(&EN
M9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1T97AT
M("`@("`@(%1H92!T97AT('1O(&1R87<N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>"`@("`@("`@("!4:&4@;&5F="!X(&-O;W)D:6YA=&4@;V8@=&AE('-T
M87)T(&]F('1H92!T97AT('-T<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1Y("`@("`@("`@(%1H92!T;W`@>2!C;V]R9&EN871E(&]F('1H92!S=&%R
M="!O9B!T:&4@=&5X="!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M9F]N="`@("`@("!4:&4@9F]N="!I9&5N=&EF:65R('EO=2!W86YT('1O('5S
M92!F;W(@=&AE('1E>'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@
M("`@("!4:&4@8V]L;W(@=&AA="!Y;W4@=V%N="!T:&4@=&5X="!D:7-P;&%Y
M960@:6XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("!!;B!I
M;G1E9V5R('1H870@<W!E8VEF:65S('1H92!O<FEE;G1A=&EO;B!O9B!T:&4@
M=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@=&5X="@D<W1R:6YG+"`D>"P@
M)'DL("1F;VYT(#T@)VUO;F]S<&%C92<L("1C;VQO<B`]("=B;&%C:R<L("1D
M:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("1H96EG:'0@/2`Q,CL*("`@
M("`@("`D<W1Y;&4@/2`G9F]N="UF86UI;'DZ)R`N("1F;VYT("X@)SMF;VYT
M+6AE:6=H=#HG("X@)&AE:6=H="`N("=P>#MF:6QL.B<@+B`D=&AI<RT^9V5T
M2&5X0V]L;W(H)&-O;&]R*2`N("<[=&5X="UA;F-H;W(Z<W1A<G0[)SL*("`@
M("`@("`D=')A;G-F;W)M(#T@)W)O=&%T92@G("X@)&1I<F5C=&EO;B`N("<L
M)R`N("1X("X@)RPG("X@)'D@+B`G*2<["B`@("`@("`@)'1H:7,M/E]S=F<M
M/F%D9$-H:6QD*&YE=R!834Q?4U9'7U1E>'0H87)R87DH)W1E>'0G(#T^("1S
M=')I;F<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W@G(#T^("AI;G0I)'@L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WDG(#T^
M("AI;G0I)'D@*R`D:&5I9VAT+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<V9O<FTG(#T^("1T
M<F%N<V9O<FTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`D<W1Y;&4I*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@8VER8VQE+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1X("`@("`@5&AE('@@8V]O<F1I;F%T92!O9B!T
M:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("!4:&4@
M>2!C;V]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<B`@("`@(%1H92!R861I=7,@;V8@=&AE(&-I<F-L92X*("`@("`J
M($!P87)A;2!S=')I;F<@("1C;VQO<B`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE
M(&-I<F-L92X*("`@("`J($!P87)A;2!S=')I;F<@("1F:6QL("`@5&AE(&-O
M;&]R('1O(&9I;&P@=&AE(&-I<F-L92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VER8VQE*"1X+"`D>2P@)'(L("1C;VQO<BP@)&9I;&P@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A96UP='DH)&9I;&PI*2!["B`@("`@("`@("`@("1S
M='EL92`]("=F:6QL.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&9I;&PI("X@
M)SL@)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G
M9FEL;#IN;VYE.R<["B`@("`@("`@?0H@("`@("`@("1S='EL92`N/2`G<W1R
M;VME.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&-O;&]R*2`N("<[('-T<F]K
M92UW:61T:#HQ)SL*"B`@("`@("`@)'1H:7,M/E]S=F<M/F%D9$-H:6QD*&YE
M=R!834Q?4U9'7T-I<F-L92AA<G)A>2@G8W@G(#T^("1X+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-Y)R`]/B`D>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=R)R`]/B`D<BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S
M='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A
M=R!A('!O;'EG;VX@8F%S960@;VX@82!S970@;V8@=F5R=&EC97,N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@;V8@
M>"!A;F0@>2!L86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=
M6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4
M:&4@8V]L;W(@>6]U('=A;G0@=&\@9')A=R!T:&4@<&]L>6=O;B!W:71H+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I
M;&P@=&AE('!O;'EG;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EG;VXH
M)'9E<G1S+"`D8V]L;W(L("1F:6QL(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H(65M<'1Y*"1F:6QL*2D@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL
M;#HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1F:6QL*2`N("<[("<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ;F]N93LG
M.PH@("`@("`@('T*("`@("`@("`D<W1Y;&4@+CT@)W-T<F]K93HG("X@)'1H
M:7,M/F=E=$AE>$-O;&]R*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z,2<[
M"@H@("`@("`@("1P;VEN=',@/2`G)SL*("`@("`@("!F;W)E86-H("@D=F5R
M=',@87,@)'8I('L*("`@("`@("`@("`@)'!O:6YT<R`N/2`D=ELG>"==("X@
M)RPG("X@)'9;)WDG72`N("<@)SL*("`@("`@("!]"B`@("`@("`@)'!O:6YT
M<R`]('1R:6TH)'!O:6YT<RD["@H@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#
M:&EL9"AN97<@6$U,7U-61U]0;VQY9V]N*&%R<F%Y*"=P;VEN=',G(#T^("1P
M;VEN=',L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`D<W1Y;&4I*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<F5C=&%N9VQE+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@(%1H92!L969T('@M8V]O<F1I
M;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'D@("`@("`@5&AE('1O<"!Y+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1W:61T:"`@(%1H92!W:61T:"!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H
M="`@5&AE(&AE:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]L;W(@("`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(')E8W1A
M;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@(%1H92!C;VQO
M<B!T;R!F:6QL('1H92!R96-T86YG;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&-O;&]R+"`D
M9FEL;"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D9FEL;"DI
M('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ)R`N("1T:&ES+3YG971(
M97A#;VQO<B@D9FEL;"D@+B`G.R`G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1S='EL92`]("=F:6QL.FYO;F4[)SL*("`@("`@("!]"B`@("`@
M("`@)'-T>6QE("X]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO<B@D
M8V]L;W(I("X@)SL@<W1R;VME+7=I9'1H.C$G.PH*("`@("`@("`D=&AI<RT^
M7W-V9RT^861D0VAI;&0H;F5W(%A-3%]35D=?4F5C="AA<G)A>2@G>"<@/3X@
M)'@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)WDG(#T^("1Y+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=W:61T:"<@/3X@)'=I
M9'1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=H96EG:'0G(#T^("1H96EG:'0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T
M>6QE)R`]/B`D<W1Y;&4I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W
M(&$@<F5C=&%N9VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M("`@("`@(%1H92!L969T('@M8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("`@5&AE('1O<"!Y+6-O
M;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H="`@5&AE(&AE:6=H="!O9B!T:&4@
M<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=6YD("`@5&AE
M('=I9'1H(&]F('1H92!C;W)N97(@<F]U;F1I;F<N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D8V]L;W(@("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@<F5C=&%N
M9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@("`@5&AE(&-O;&]R
M('1O(&9I;&P@=&AE(')E8W1A;F=L92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F]U;F1E9%)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)')O
M=6YD+"`D8V]L;W(L("1F:6QL*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH
M)&9I;&PI*2!["B`@("`@("`@("`@("1S='EL92`]("=F:6QL.B<@+B`D=&AI
M<RT^9V5T2&5X0V]L;W(H)&9I;&PI("X@)SL@)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#IN;VYE.R<["B`@("`@("`@
M?0H@("`@("`@("1S='EL92`N/2`G<W1R;VME.B<@+B`D=&AI<RT^9V5T2&5X
M0V]L;W(H)&-O;&]R*2`N("<[('-T<F]K92UW:61T:#HQ)SL*"B`@("`@("`@
M)'1H:7,M/E]S=F<M/F%D9$-H:6QD*&YE=R!834Q?4U9'7U)E8W0H87)R87DH
M)W@G(#T^("1X+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=Y)R`]/B`D>2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<G@G(#T^
M("1R;W5N9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<GDG(#T^("1R;W5N9"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=VED
M=&@G(#T^("1W:61T:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:&5I9VAT)R`]/B`D:&5I9VAT+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1')A=R!A(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'@P("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!S=&%R="X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y,"`@("`@5&AE('D@8V]O<F1I;F%T92!O
M9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#$@("`@(%1H
M92!X(&-O;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1Y,2`@("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@96YD+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("!4:&4@;&EN92!C;VQO<BX*("`@
M("`J($!P87)A;2!S=')I;F<@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!L
M:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YE*"1X,2P@)'DQ+"`D>#(L
M("1Y,BP@)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2D*("`@('L*("`@
M("`@("`D<W1Y;&4@/2`G<W1R;VME.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H
M)&-O;&]R*2`N("<[('-T<F]K92UW:61T:#HG("X@*&EN="DD=VED=&@["B`@
M("`@("`@)'1H:7,M/E]S=F<M/F%D9$-H:6QD*&YE=R!834Q?4U9'7TQI;F4H
M87)R87DH)W@Q)R`]/B`D>#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)WDQ)R`]/B`D>3$L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W@R)R`]/B`D>#(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)WDR)R`]/B`D>3(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W-T>6QE)R`]/B`D<W1Y;&4I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M<F%W(&$@9&%S:&5D(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'@P("`@("`@("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!S=&%R
M="X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,"`@("`@("`@("`@5&AE('D@
M8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>#$@("`@("`@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE(&5N9"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@("`@("`@("`@5&AE('D@8V]O
M<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O
M;&]R("`@("`@("!4:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A;2!S=')I
M;F<@("1W:61T:"`@("`@("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&1A<VA?;&5N9W1H("!4:&4@;&5N9W1H(&]F
M(&$@9&%S:"!O;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J($!P87)A;2!I;G1E
M9V5R("1D87-H7W-P86-E("`@5&AE(&QE;F=T:"!O9B!A('-P86-E(&EN('1H
M92!D87-H960@;&EN90H@("`@("HO"B`@("!F=6YC=&EO;B!D87-H961,:6YE
M*"1X,2P@)'DQ+"`D>#(L("1Y,BP@)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H
M(#T@,2P@)&1A<VA?;&5N9W1H(#T@,BP@)&1A<VA?<W!A8V4@/2`R*0H@("`@
M>PH@("`@("`@("1S='EL92`]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#
M;VQO<B@D8V]L;W(I("X@)SL@<W1R;VME+7=I9'1H.B<@+B`H:6YT*21W:61T
M:"`N("<[('-T<F]K92UD87-H87)R87DZ)R`N("1D87-H7VQE;F=T:"`N("<L
M)R`N("1D87-H7W-P86-E("X@)SLG.PH@("`@("`@("1T:&ES+3Y?<W9G+3YA
M9&1#:&EL9"AN97<@6$U,7U-61U],:6YE*&%R<F%Y*"=X,2<@/3X@)'@Q+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=Y,2<@/3X@)'DQ+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X,B<@/3X@)'@R+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=Y,B<@/3X@)'DR+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'-T>6QE*2DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A('!O;'EL:6YE("AA(&YO
M;BUC;&]S960L(&YO;BUF:6QL960@<&]L>6=O;BD@8F%S960@;VX@80H@("`@
M("H@<V5T(&]F('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D=F5R=&EC97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A
M>7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@)'9E<G1I
M8V5S6S!=6R=X)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W86YT('1O
M(&1R87<@=&AE(&QI;F4@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)'=I
M9'1H("`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<&]L>6QI;F4H)'9E<G1S+"`D8V]L;W(L("1W:61T:"`](#$I"B`@
M("!["B`@("`@("`@)'-T>6QE(#T@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE
M>$-O;&]R*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z)R`N("1W:61T:"`N
M("<[9FEL;#IN;VYE.R<["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@<&%T
M:"!E;G1R>2X*("`@("`@("`D<&%T:"`]("<G.PH*("`@("`@("`D9FER<W0@
M/2!T<G5E.PH@("`@("`@(&9O<F5A8V@@*"1V97)T<R!A<R`D=F5R="D@>PH@
M("`@("`@("`@("!I9B`H)&9I<G-T*2!["B`@("`@("`@("`@("`@("`D9FER
M<W0@/2!F86QS93L*("`@("`@("`@("`@("`@("1P871H("X]("=-("<@+B`D
M=F5R=%LG>"==("X@)RPG("X@)'9E<G1;)WDG73L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1P871H("X]("<@3"`G("X@)'9E<G1;
M)W@G72`N("<L)R`N("1V97)T6R=Y)UT["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-6
M1U]0871H*&%R<F%Y*"=D)R`]/B`D<&%T:"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^
M("1S='EL92DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@86X@87)C
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@5&AE('@@
M8V]O<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'D@("`@("!4:&4@>2!C;V]R9&EN871E(&]F('1H92!C96YT<F4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<B`@("`@(%1H92!R861I=7,@;V8@=&AE
M(&%R8RX*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@5&AE('-T87)T
M(&%N9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96YD
M("`@(%1H92!E;F0@86YG;&4@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!S
M=')I;F<@("1C;VQO<B`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(&%R8RX*("`@
M("`J($!P87)A;2!S=')I;F<@("1F:6QL("`@5&AE(&9I;&P@8V]L;W(@;V8@
M=&AE(&%R8R`H9&5F875L=',@=&\@;F]N92DN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%R8R@D>"P@)'DL("1R+"`D<W1A<G0L("1E;F0L("1C;VQO<B`]("=B
M;&%C:R<L("1F:6QL(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1F:6QL*2D@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#HG("X@)'1H
M:7,M/F=E=$AE>$-O;&]R*"1F:6QL*2`N("<[("<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ;F]N93LG.PH@("`@("`@
M('T*("`@("`@("`D<W1Y;&4@+CT@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE
M>$-O;&]R*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z,2<["@H@("`@("`@
M("1M:60@/2!R;W5N9"@H)'-T87)T("L@)&5N9"D@+R`R*3L*"B`@("`@("`@
M+R\@0V%L8W5L871E('1H92!P871H(&5N=')Y+@H@("`@("`@("1P871H(#T@
M)R<["@H@("`@("`@("\O($EF(&9I;&QE9"P@9')A=R!T:&4@;W5T;&EN92X*
M("`@("`@("!I9B`H(65M<'1Y*"1F:6QL*2D@>PH@("`@("`@("`@("`O+R!3
M=&%R="!A="!T:&4@8V5N=&5R(&]F('1H92!E;&QI<'-E('1H92!A<F,@:7,@
M;VXN"B`@("`@("`@("`@("1P871H("X](")-("1X+"1Y("(["@H@("`@("`@
M("`@("`O+R!$<F%W(&]U="!T;R!E;&QI<'-E(&5D9V4N"B`@("`@("`@("`@
M(&QI<W0H)&%R8U@L("1A<F-9*2`]("1T:&ES+3Y?8VER8VQE4&]I;G0H)'-T
M87)T+"`D<B`J(#(I.PH@("`@("`@("`@("`D<&%T:"`N/2`G3"`G("X@<F]U
M;F0H)'@@*R`D87)C6"D@+B`G+"<@+@H@("`@("`@("`@("`@("`@<F]U;F0H
M)'D@*R`D87)C62D@+B`G("<["B`@("`@("`@?0H*("`@("`@("`O+R!$<F%W
M(&%R8W,N"B`@("`@("`@;&ES="@D87)C6"P@)&%R8UDI(#T@)'1H:7,M/E]C
M:7)C;&50;VEN="@D;6ED+"`D<B`J(#(I.PH@("`@("`@("1P871H("X](")!
M("1R+"1R(#`@,"`Q("(@+@H@("`@("`@("`@("!R;W5N9"@D>"`K("1A<F-8
M*2`N("<L)R`N"B`@("`@("`@("`@(')O=6YD*"1Y("L@)&%R8UDI("X@)R`G
M.PH*("`@("`@("!L:7-T*"1A<F-8+"`D87)C62D@/2`D=&AI<RT^7V-I<F-L
M95!O:6YT*"1E;F0L("1R("H@,BD["B`@("`@("`@)'!A=&@@+CT@(D$@)'(L
M)'(@,"`P(#$@(B`N"B`@("`@("`@("`@(')O=6YD*"1X("L@)&%R8U@I("X@
M)RPG("X*("`@("`@("`@("`@<F]U;F0H)'D@*R`D87)C62D@+B`G("<["@H@
M("`@("`@("\O($EF(&9I;&QE9"P@8VQO<V4@=&AE(&]U=&QI;F4N"B`@("`@
M("`@:68@*"%E;7!T>2@D9FEL;"DI('L*("`@("`@("`@("`@)'!A=&@@+CT@
M)UHG.PH@("`@("`@('T*"B`@("`@("`@)'!A=&@@/2!T<FEM*"1P871H*3L*
M"B`@("`@("`@)'1H:7,M/E]S=F<M/F%D9$-H:6QD*&YE=R!834Q?4U9'7U!A
M=&@H87)R87DH)V0G(#T^("1P871H+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'-T
M>6QE*2DI.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M26UA9V4O<W=F+G!H<```````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#0T-S`T`#$P-#$W,S8R-S<S`#`R,#4W-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]);6%G92YP:'`G.PH*+RHJ"B`J
M(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4@2&]R9&5?26UA9V4Z.B!!4$D@
M9F]R(%-71BP@=7-I;F<@=&AE(%!(4`H@*B!-:6YG(&5X=&5N<VEO;BX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO26UA9V4O26UA9V4O<W=F+G!H<"QV(#$N
M,C0N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C(R(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]);6%G90H@*B\*8VQA<W,@2&]R9&5?26UA
M9V5?<W=F(&5X=&5N9',@2&]R9&5?26UA9V4@>PH*("`@("\J*@H@("`@("H@
M0V%P86)I;&ET97,@;V8@=&AI<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C87!A8FEL:71I97,@/2!A<G)A
M>2@G8V%N=F%S)RD["@H@("`@+RHJ"B`@("`@*B!35T8@<F]O="!M;W9I92X*
M("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D
M7VUO=FEE.PH*("`@(&9U;F-T:6]N($AO<F1E7TEM86=E7W-W9B@D<&%R86US
M*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?26UA9V4H)'!A<F%M<RD[
M"@H@("`@("`@("1T:&ES+3Y?;6]V:64@/2`F;F5W(%-71DUO=FEE*"D["B`@
M("`@("`@)'1H:7,M/E]M;W9I92T^<V5T1&EM96YS:6]N*"1T:&ES+3Y?=VED
M=&@L("1T:&ES+3Y?:&5I9VAT*3L*"B`@("`@("`@+R\@1DE8344Z(&AO;F]R
M('1H92`G8F%C:V=R;W5N9"<@<&%R86UE=&5R(&AE<F4N"B`@("`@("`@)'1H
M:7,M/E]M;W9I92T^<V5T0F%C:V=R;W5N9"@P>&9F+"`P>&9F+"`P>&9F*3L*
M("`@("`@("`D=&AI<RT^7VUO=FEE+3YS9712871E*#,P*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("=A<'!L:6-A=&EO;B]X+7-H;V-K=V%V92UF;&%S:"<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$:7-P;&%Y('1H92!M;W9I92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&ES<&QA>2@I"B`@("!["B`@("`@("`@)'1H:7,M/FAE861E
M<G,H*3L*("`@("`@("`D=&AI<RT^7VUO=FEE+3YO=71P=70H*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@<F%W(&1A=&$@9F]R('1H:7,@
M:6UA9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R87<@
M:6UA9V4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F%W*"D*("`@('L*
M("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("1T:&ES+3Y?;6]V:64M/F]U
M='!U="@I.PH@("`@("`@("1D871A(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@
M("`@("`@;V)?96YD7V-L96%N*"D["@H@("`@("`@(')E='5R;B`D9&%T83L*
M("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!C;VQO<B!T:&%T(&-A
M;B!B92!A8V-E<W-E9"!I;B!T:&ES(&]B:F5C="X@5VAE;B!A"B`@("`@*B!C
M;VQO<B!I<R!S970L('1H92!R9V)A('9A;'5E<R!A<F4@<F5T=7)N960@:6X@
M86X@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&YA;64@;V8@=&AE(&-O;&]R+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!R960L(&=R965N+"!B;'5E+"!A;'!H82!V86QU97,@;V8@
M=&AE(&-O;&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A;&QO8V%T94-O;&]R
M*"1N86UE*0H@("`@>PH@("`@("`@(&QI<W0H)'(L("1G+"`D8BD@/2`D=&AI
M<RT^9V5T4D="*"1N86UE*3L*("`@("`@("!R971U<FX@87)R87DH)W)E9"<@
M/3X@)'(L"B`@("`@("`@("`@("`@("`@("`@("=G<F5E;B<@/3X@)&<L"B`@
M("`@("`@("`@("`@("`@("`@("=B;'5E)R`]/B`D8BP*("`@("`@("`@("`@
M("`@("`@("`@)V%L<&AA)R`]/B`R-34I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=$9O;G0H)&9O;G0I"B`@("!["B`@("`@("`@<W=I=&-H("@D9F]N="D@
M>PH@("`@("`@(&-A<V4@)W-A;G,M<V5R:68G.@H@("`@("`@("`@("!R971U
M<FX@)U]S86YS)SL*"B`@("`@("`@8V%S92`G<V5R:68G.@H@("`@("`@("`@
M("!R971U<FX@)U]S97)I9B<["@H@("`@("`@(&-A<V4@)VUO;F]S<&%C92<Z
M"B`@("`@("`@("`@(')E='5R;B`G7W1Y<&5W<FET97(G.PH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("!R971U<FX@)&9O;G0["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1')A=W,@82!T97AT('-T<FEN9R!O;B!T
M:&4@:6UA9V4@:6X@82!S<&5C:69I960@;&]C871I;VXL('=I=&@*("`@("`J
M('1H92!S<&5C:69I960@<W1Y;&4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'1E>'0@("`@("`@5&AE('1E>'0@=&\@9')A
M=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@("`@(%1H92!L969T
M('@@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0@;V8@=&AE('1E>'0@<W1R:6YG
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("`@("`@5&AE('1O<"!Y
M(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T(&]F('1H92!T97AT('-T<FEN9RX*
M("`@("`J($!P87)A;2!S=')I;F<@("1F;VYT("`@("`@(%1H92!F;VYT(&ED
M96YT:69I97(@>6]U('=A;G0@=&\@=7-E(&9O<B!T:&4@=&5X="X*("`@("`J
M($!P87)A;2!S=')I;F<@("1C;VQO<B`@("`@(%1H92!C;VQO<B!T:&%T('EO
M=2!W86YT('1H92!T97AT(&1I<W!L87EE9"!I;BX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1D:7)E8W1I;VX@($%N(&EN=&5G97(@=&AA="!S<&5C:69I97,@
M=&AE(&]R:65N=&%T:6]N(&]F('1H92!T97AT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!T97AT*"1S=')I;F<L("1X+"`D>2P@)&9O;G0@/2`G;6]N;W-P86-E
M)RP@)&-O;&]R(#T@)V)L86-K)RP@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@
M("`@("`@)&-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*
M"B`@("`@("`@:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I(#T]("=724XG*2![
M"B`@("`@("`@("`@("1T97AT(#T@)FYE=R!35T9497AT1FEE;&0H4U=&5$58
M5$9)14Q$7TY/141)5"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1E>'0@/2`F;F5W(%-71E1E>'0H*3L*("`@("`@("!]"B`@("`@("`@)'1E
M>'0M/G-E=$-O;&]R*"1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@
M)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D["B`@("`@("`@)'1E
M>'0M/F%D9%-T<FEN9R@D<W1R:6YG*3L*("`@("`@("`D=&5X="T^<V5T1F]N
M="AN97<@4U=&1F]N="@D=&AI<RT^9V5T1F]N="@D9F]N="DI*3L*"B`@("`@
M("`@)'0@/2`D=&AI<RT^7VUO=FEE+3YA9&0H)'1E>'0I.PH@("`@("`@("1T
M+3YM;W9E5&\H)'@L("1Y*3L*("`@("`@("`D="T^<F]T871E*"1D:7)E8W1I
M;VXI.PH*("`@("`@("!R971U<FX@)'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$<F%W(&$@8VER8VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1X("`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@5&AE('D@8V\M;W)D:6YA=&4@
M;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1R("`@("`@
M5&AE(')A9&EU<R!O9B!T:&4@8VER8VQE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)&-O;&]R("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@8VER8VQE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@("!4:&4@8V]L;W(@=&\@9FEL;"!T
M:&4@8VER8VQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:7)C;&4H)'@L("1Y
M+"`D<BP@)&-O;&]R+"`D9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@("`D
M<R`]("9N97<@4U=&4VAA<&4H*3L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^
M86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1S+3YS971,:6YE*#$L
M("1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E
M)UTL("1C;VQO<ELG86QP:&$G72D["@H@("`@("`@(&EF("@D9FEL;"`A/2`G
M;F]N92<I('L*("`@("`@("`@("`@)&9I;&Q#;VQO<B`]("1T:&ES+3YA;&QO
M8V%T94-O;&]R*"1F:6QL*3L*("`@("`@("`@("`@)&8@/2`D<RT^861D1FEL
M;"@D9FEL;$-O;&]R6R=R960G72P@)&9I;&Q#;VQO<ELG9W)E96XG72P@)&9I
M;&Q#;VQO<ELG8FQU92==+"`D9FEL;$-O;&]R6R=A;'!H82==*3L*("`@("`@
M("`@("`@)',M/G-E=%)I9VAT1FEL;"@D9BD["B`@("`@("`@?0H*("`@("`@
M("`D82`]("1R("H@,"XT,30R,3,U-C([("\O(#T@=&%N*#(R+C4@9&5G*0H@
M("`@("`@("1B(#T@)'(@*B`P+C<P-S$P-C<X,3L@+R\@/2!S<7)T*#(I+S(@
M/2!S:6XH-#4@9&5G*0H*("`@("`@("`D<RT^;6]V95!E;E1O*"1X("L@)'(L
M("1Y*3L*"B`@("`@("`@)',M/F1R87=#=7)V951O*"1X("L@)'(L("1Y("T@
M)&$L("1X("L@)&(L("1Y("T@)&(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54
M;R@D>"`K("1A+"`D>2`M("1R+"`D>"P@)'D@+2`D<BD["B`@("`@("`@)',M
M/F1R87=#=7)V951O*"1X("T@)&$L("1Y("T@)'(L("1X("T@)&(L("1Y("T@
M)&(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`M("1R+"`D>2`M("1A
M+"`D>"`M("1R+"`D>2D["B`@("`@("`@)',M/F1R87=#=7)V951O*"1X("T@
M)'(L("1Y("L@)&$L("1X("T@)&(L("1Y("L@)&(I.PH@("`@("`@("1S+3YD
M<F%W0W5R=F54;R@D>"`M("1A+"`D>2`K("1R+"`D>"P@)'D@*R`D<BD["B`@
M("`@("`@)',M/F1R87=#=7)V951O*"1X("L@)&$L("1Y("L@)'(L("1X("L@
M)&(L("1Y("L@)&(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`K("1R
M+"`D>2`K("1A+"`D>"`K("1R+"`D>2D["@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7VUO=FEE+3YA9&0H)',I.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A
M=R!A('!O;'EG;VX@8F%S960@;VX@82!S970@;V8@=F5R=&EC97,N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@;V8@
M>"!A;F0@>2!L86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=
M6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4
M:&4@8V]L;W(@>6]U('=A;G0@=&\@9')A=R!T:&4@<&]L>6=O;B!W:71H+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I
M;&P@=&AE('!O;'EG;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EG;VXH
M)'9E<G1S+"`D8V]L;W(L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@
M("1C;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["@H@("`@
M("`@(&EF("AI<U]A<G)A>2@D8V]L;W(I("8F(&ES7V%R<F%Y*"1V97)T<RD@
M)B8@*'-I>F5O9B@D=F5R=',I(#X@,BDI('L*("`@("`@("`@("`@)'-H87!E
M(#T@)FYE=R!35T93:&%P92@I.PH@("`@("`@("`@("`D<VAA<&4M/G-E=$QI
M;F4H,2P@)&-O;&]R6R=R960G72P@)&-O;&]R6R=G<F5E;B==+"`D8V]L;W);
M)V)L=64G72P@)&-O;&]R6R=A;'!H82==*3L*"B`@("`@("`@("`@(&EF("@D
M9FEL;"`A/2`G;F]N92<I('L*("`@("`@("`@("`@("`@("1F:6QL0V]L;W(@
M/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL;"D["B`@("`@("`@("`@("`@
M("`D9B`]("1S:&%P92T^861D1FEL;"@D9FEL;$-O;&]R6R=R960G72P@)&9I
M;&Q#;VQO<ELG9W)E96XG72P@)&9I;&Q#;VQO<ELG8FQU92==+"`D9FEL;$-O
M;&]R6R=A;'!H82==*3L*("`@("`@("`@("`@("`@("1S:&%P92T^<V5T4FEG
M:'1&:6QL*"1F*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I<G-T
M7V1O;F4@/2!F86QS93L*("`@("`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S
M("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@*"$D9FER<W1?9&]N92D@
M>PH@("`@("`@("`@("`@("`@("`@("1S:&%P92T^;6]V95!E;E1O*"1V86QU
M95LG>"==+"`D=F%L=65;)WDG72D["B`@("`@("`@("`@("`@("`@("`@)&9I
M<G-T7V1O;F4@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("1F:7)S=%]X
M(#T@)'9A;'5E6R=X)UT["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T7WD@
M/2`D=F%L=65;)WDG73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1S:&%P92T^9')A=TQI;F54;R@D=F%L=65;)W@G72P@)'9A;'5E6R=Y
M)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S:&%P92T^9')A=TQI
M;F54;R@D9FER<W1?>"P@)&9I<G-T7WDI.PH*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?;6]V:64M/F%D9"@D<VAA<&4I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O($EF('1H92!C;VQO<B!I<R!A;B!A<G)A>2!A;F0@
M=&AE('9E<G1I8V5S(&ES(&$@86X@87)R87D*("`@("`@("`@("`@+R\@;V8@
M;6]R92!T:&%N(#(@<&]I;G1S+@H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A
M;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4
M:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E
M(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED
M=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@(%1H92!L:6YE(&-O
M;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M9FEL;"`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N9VQE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96-T86YG;&4H)'@L("1Y+"`D=VED=&@L("1H
M96EG:'0L("1C;VQO<BP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@
M)'9E<G1S6S!=(#T@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@)'DI.PH@("`@
M("`@("1V97)T<ULQ72`](&%R<F%Y*"=X)R`]/B`D>"`K("1W:61T:"P@)WDG
M(#T^("1Y*3L*("`@("`@("`D=F5R='-;,ET@/2!A<G)A>2@G>"<@/3X@)'@@
M*R`D=VED=&@L("=Y)R`]/B`D>2`K("1H96EG:'0I.PH@("`@("`@("1V97)T
M<ULS72`](&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y("L@)&AE:6=H="D[
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^<&]L>6=O;B@D=F5R=',L("1C;VQO
M<BP@)&9I;&PI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A
M;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4
M:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E
M(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED
M=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W5N9"`@(%1H92!W:61T:"!O
M9B!T:&4@8V]R;F5R(')O=6YD:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V]L;W(@("`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(')E8W1A;F=L92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL
M('1H92!R96-T86YG;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O=6YD9612
M96-T86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1R;W5N9"P@)&-O
M;&]R(#T@)V)L86-K)RP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@
M:68@*"1R;W5N9"`\/2`P*2!["B`@("`@("`@("`@("\O($]P=&EM:7IE(&]U
M="!A;GD@8V%L;',@=VET:"!N;R!C;W)N97(@<F]U;F1I;F<N"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F5C=&%N9VQE*"1X+"`D>2P@)'=I9'1H+"`D
M:&5I9VAT+"`D8V]L;W(L("1F:6QL*3L*("`@("`@("!]"@H@("`@("`@("1S
M(#T@)FYE=R!35T93:&%P92@I.PH@("`@("`@("1C;VQO<B`]("1T:&ES+3YA
M;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@)',M/G-E=$QI;F4H,2P@
M)&-O;&]R6R=R960G72P@)&-O;&]R6R=G<F5E;B==+"`D8V]L;W);)V)L=64G
M72P@)&-O;&]R6R=A;'!H82==*3L*"B`@("`@("`@:68@*"1F:6QL("$]("=N
M;VYE)RD@>PH@("`@("`@("`@("`D9FEL;$-O;&]R(#T@)'1H:7,M/F%L;&]C
M871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("`D9B`]("1S+3YA9&1&:6QL
M*"1F:6QL0V]L;W);)W)E9"==+"`D9FEL;$-O;&]R6R=G<F5E;B==+"`D9FEL
M;$-O;&]R6R=B;'5E)UTL("1F:6QL0V]L;W);)V%L<&AA)UTI.PH@("`@("`@
M("`@("`D<RT^<V5T4FEG:'1&:6QL*"1F*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%-E="!C;W)N97(@<&]I;G1S('1O(&%V;VED(&QO=',@;V8@<F5D=6YD
M86YT(&UA=&@N"B`@("`@("`@)'@Q(#T@)'@@*R`D<F]U;F0["B`@("`@("`@
M)'DQ(#T@)'D@*R`D<F]U;F0["@H@("`@("`@("1X,B`]("1X("L@)'=I9'1H
M("T@)')O=6YD.PH@("`@("`@("1Y,B`]("1Y("L@)')O=6YD.PH*("`@("`@
M("`D>#,@/2`D>"`K("1W:61T:"`M("1R;W5N9#L*("`@("`@("`D>3,@/2`D
M>2`K("1H96EG:'0@+2`D<F]U;F0["@H@("`@("`@("1X-"`]("1X("L@)')O
M=6YD.PH@("`@("`@("1Y-"`]("1Y("L@)&AE:6=H="`M("1R;W5N9#L*"B`@
M("`@("`@+R\@4W1A<G0@:6X@=&AE('5P<&5R(&QE9G0N"B`@("`@("`@)'`Q
M(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`Q.#`L(#(R-2D["B`@("`@
M("`@)'`R(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`R,C4L(#(W,"D[
M"@H@("`@("`@("\O(%-T87)T(&%T('1H92!L;W=E<B!L969T(&-O<FYE<B!O
M9B!T:&4@=&]P(&QE9G0@8W5R=F4N"B`@("`@("`@)',M/FUO=F5096Y4;R@D
M>#$@*R`D<#%;)W@Q)UTL("1Y,2`K("1P,5LG>3$G72D["@H@("`@("`@("\O
M($1R87<@=&AE('5P<&5R(&QE9G0@8V]R;F5R+@H@("`@("`@("1S+3YD<F%W
M0W5R=F54;R@D>#$@*R`D<#%;)W@S)UTL("1Y,2`K("1P,5LG>3,G72P@)'@Q
M("L@)'`Q6R=X,B==+"`D>3$@*R`D<#%;)WDR)UTI.PH@("`@("`@("1S+3YD
M<F%W0W5R=F54;R@D>#$@*R`D<#);)W@S)UTL("1Y,2`K("1P,ELG>3,G72P@
M)'@Q("L@)'`R6R=X,B==+"`D>3$@*R`D<#);)WDR)UTI.PH*("`@("`@("`O
M+R!#86QC=6QA=&4@=&AE('5P<&5R(')I9VAT('!O:6YT<RX*("`@("`@("`D
M<#,@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#(W,"P@,S$U*3L*("`@
M("`@("`D<#0@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#,Q-2P@,S8P
M*3L*"B`@("`@("`@+R\@0V]N;F5C="!T:&4@=&]P(&QE9G0@86YD(')I9VAT
M(&-U<G9E<RX*("`@("`@("`D<RT^9')A=TQI;F54;R@D>#(@*R`D<#-;)W@Q
M)UTL("1Y,B`K("1P,ULG>3$G72D["@H@("`@("`@("\O($1R87<@=&AE('5P
M<&5R(')I9VAT(&-O<FYE<BX*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@R
M("L@)'`S6R=X,R==+"`D>3(@*R`D<#-;)WDS)UTL("1X,B`K("1P,ULG>#(G
M72P@)'DR("L@)'`S6R=Y,B==*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H
M)'@R("L@)'`T6R=X,R==+"`D>3(@*R`D<#1;)WDS)UTL("1X,B`K("1P-%LG
M>#(G72P@)'DR("L@)'`T6R=Y,B==*3L*"B`@("`@("`@+R\@0V%L8W5L871E
M('1H92!L;W=E<B!R:6=H="!P;VEN=',N"B`@("`@("`@)'`U(#T@)'1H:7,M
M/E]A<F-0;VEN=',H)')O=6YD+"`P+"`T-2D["B`@("`@("`@)'`V(#T@)'1H
M:7,M/E]A<F-0;VEN=',H)')O=6YD+"`T-2P@.3`I.PH*("`@("`@("`O+R!#
M;VYN96-T('1H92!T;W`@<FEG:'0@86YD(&QO=V5R(')I9VAT(&-U<G9E<RX*
M("`@("`@("`D<RT^9')A=TQI;F54;R@D>#,@*R`D<#5;)W@Q)UTL("1Y,R`K
M("1P-5LG>3$G72D["@H@("`@("`@("\O($1R87<@=&AE(&QO=V5R(')I9VAT
M(&-O<FYE<BX*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@S("L@)'`U6R=X
M,R==+"`D>3,@*R`D<#5;)WDS)UTL("1X,R`K("1P-5LG>#(G72P@)'DS("L@
M)'`U6R=Y,B==*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@S("L@)'`V
M6R=X,R==+"`D>3,@*R`D<#9;)WDS)UTL("1X,R`K("1P-ELG>#(G72P@)'DS
M("L@)'`V6R=Y,B==*3L*"B`@("`@("`@+R\@0V%L8W5L871E('1H92!L;W=E
M<B!L969T('!O:6YT<RX*("`@("`@("`D<#<@/2`D=&AI<RT^7V%R8U!O:6YT
M<R@D<F]U;F0L(#DP+"`Q,S4I.PH@("`@("`@("1P."`]("1T:&ES+3Y?87)C
M4&]I;G1S*"1R;W5N9"P@,3,U+"`Q.#`I.PH*("`@("`@("`O+R!#;VYN96-T
M('1H92!B;W1T;VT@<FEG:'0@86YD(&)O='1O;2!L969T(&-U<G9E<RX*("`@
M("`@("`D<RT^9')A=TQI;F54;R@D>#0@*R`D<#=;)W@Q)UTL("1Y-"`K("1P
M-ULG>3$G72D["@H@("`@("`@("\O($1R87<@=&AE(&QO=V5R(&QE9G0@8V]R
M;F5R+@H@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>#0@*R`D<#=;)W@S)UTL
M("1Y-"`K("1P-ULG>3,G72P@)'@T("L@)'`W6R=X,B==+"`D>30@*R`D<#=;
M)WDR)UTI.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>#0@*R`D<#A;)W@S
M)UTL("1Y-"`K("1P.%LG>3,G72P@)'@T("L@)'`X6R=X,B==+"`D>30@*R`D
M<#A;)WDR)UTI.PH*("`@("`@("`O+R!#;&]S92!T:&4@<VAA<&4N"B`@("`@
M("`@)',M/F1R87=,:6YE5&\H)'@Q("L@)'`Q6R=X,2==+"`D>3$@*R`D<#%;
M)WDQ)UTI.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]M;W9I92T^861D*"1S
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!L:6YE+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@5&AE('@@8V\M;W)D:6YA
M=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DP("`@
M("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>#$@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!E
M;F0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@("`@(%1H92!Y(&-O+6]R
M9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L
M;W(@(%1H92!L:6YE(&-O;&]R+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'=I
M9'1H("!4:&4@=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QI;F4H)'@Q+"`D>3$L("1X,BP@)'DR+"`D8V]L;W(@/2`G8FQA8VLG
M+"`D=VED=&@@/2`Q*0H@("`@>PH@("`@("`@("1C;VQO<B`]("1T:&ES+3YA
M;&QO8V%T94-O;&]R*"1C;VQO<BD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D
M8V]L;W(I*2!["B`@("`@("`@("`@("1S:&%P92`]("9N97<@4U=&4VAA<&4H
M*3L*("`@("`@("`@("`@)'-H87!E+3YS971,:6YE*"1W:61T:"P@)&-O;&]R
M6R=R960G72P@)&-O;&]R6R=G<F5E;B==+"`D8V]L;W);)V)L=64G72P@)&-O
M;&]R6R=A;'!H82==*3L*("`@("`@("`@("`@)'-H87!E+3YM;W9E4&5N5&\H
M)'@Q+"`D>3$I.PH@("`@("`@("`@("`D<VAA<&4M/F1R87=,:6YE5&\H)'@R
M+"`D>3(I.PH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D
M9"@D<VAA<&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W
M(&$@9&%S:&5D(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'@P("`@("`@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@("`@("`@(%1H92!Y(&-O
M+6]R9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1X,2`@("`@("`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE(&5N9"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@("`@("`@("`@5&AE('D@8V\M
M;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@("1C
M;VQO<B`@("`@("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D=VED=&@@("`@("`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1D87-H7VQE;F=T:"`@5&AE(&QE;F=T:"!O
M9B!A(&1A<V@@;VX@=&AE(&1A<VAE9"!L:6YE"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D9&%S:%]S<&%C92`@(%1H92!L96YG=&@@;V8@82!S<&%C92!I;B!T
M:&4@9&%S:&5D(&QI;F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&%S:&5D3&EN
M92@D>#`L("1Y,"P@)'@Q+"`D>3$L("1C;VQO<B`]("=B;&%C:R<L("1W:61T
M:"`](#$L("1D87-H7VQE;F=T:"`](#(L("1D87-H7W-P86-E(#T@,BD*("`@
M('L*("`@("`@("`O+R!'970@=&AE(&QE;F=T:"!O9B!T:&4@;&EN92!I;B!P
M:7AE;',N"B`@("`@("`@)&QI;F5?;&5N9W1H(#T@;6%X*&-E:6PH<W%R="AP
M;W<H*"1X,2`M("1X,"DL(#(I("L@<&]W*"@D>3$@+2`D>3`I+"`R*2DI+"`R
M*3L*"B`@("`@("`@)&-O<U1H971A(#T@*"1X,2`M("1X,"D@+R`D;&EN95]L
M96YG=&@["B`@("`@("`@)'-I;E1H971A(#T@*"1Y,2`M("1Y,"D@+R`D;&EN
M95]L96YG=&@["B`@("`@("`@)&QA<W1X(#T@)'@P.PH@("`@("`@("1L87-T
M>2`]("1Y,#L*"B`@("`@("`@+R\@1')A=R!T:&4@9&%S:&5D(&QI;F4N"B`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QI;F5?;&5N9W1H.R`D:2`K/2`H
M)&1A<VA?;&5N9W1H("L@)&1A<VA?<W!A8V4I*2!["B`@("`@("`@("`@("1X
M(#T@*"1D87-H7VQE;F=T:"`J("1C;W-4:&5T82D@*R`D;&%S='@["B`@("`@
M("`@("`@("1Y(#T@*"1D87-H7VQE;F=T:"`J("1S:6Y4:&5T82D@*R`D;&%S
M='D["@H@("`@("`@("`@("`D=&AI<RT^;&EN92@D;&%S='@L("1L87-T>2P@
M)'@L("1Y+"`D8V]L;W(I.PH*("`@("`@("`@("`@)&QA<W1X(#T@)'@@*R`H
M)&1A<VA?<W!A8V4@*B`D8V]S5&AE=&$I.PH@("`@("`@("`@("`D;&%S='D@
M/2`D>2`K("@D9&%S:%]S<&%C92`J("1S:6Y4:&5T82D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A('!O;'EL:6YE("AA(&YO;BUC
M;&]S960L(&YO;BUF:6QL960@<&]L>6=O;BD@8F%S960@;VX@80H@("`@("H@
M<V5T(&]F('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@
M("1V97)T:6-E<R`@06X@87)R87D@;V8@>"!A;F0@>2!L86)E;&5D(&%R<F%Y
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`H96<N("1V97)T
M:6-E<ULP75LG>"==+"`D=F5R=&EC97-;,%U;)WDG72P@+BXN*2X*("`@("`J
M($!P87)A;2!S=')I;F<@("1C;VQO<B`@("`@5&AE(&-O;&]R('EO=2!W86YT
M('1O(&1R87<@=&AE(&QI;F4@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@
M("1W:61T:"`@("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P;VQY;&EN92@D=F5R=',L("1C;VQO<BP@)'=I9'1H(#T@
M,2D*("`@('L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO
M<B@D8V]L;W(I.PH*("`@("`@("`D<VAA<&4@/2`F;F5W(%-71E-H87!E*"D[
M"B`@("`@("`@)'-H87!E+3YS971,:6YE*"1W:61T:"P@)&-O;&]R6R=R960G
M72P@)&-O;&]R6R=G<F5E;B==+"`D8V]L;W);)V)L=64G72P@)&-O;&]R6R=A
M;'!H82==*3L*"B`@("`@("`@)&9I<G-T7V1O;F4@/2!F86QS93L*("`@("`@
M("!F;W)E86-H("@D=F5R=',@87,@)'9A;'5E*2!["B`@("`@("`@("`@(&EF
M("@A)&9I<G-T7V1O;F4I('L*("`@("`@("`@("`@("`@("1S:&%P92T^;6]V
M95!E;E1O*"1V86QU95LG>"==+"`D=F%L=65;)WDG72D["B`@("`@("`@("`@
M("`@("`D9FER<W1?9&]N92`]('1R=64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'-H87!E+3YD<F%W3&EN951O*"1V86QU95LG>"==+"`D=F%L=65;
M)WDG72D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]M;W9I
M92T^861D*"1S:&%P92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&%N
M(&%R8RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@(%1H
M92!X(&-O+6]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>2`@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!C96YT
M<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<B`@("`@(%1H92!R861I=7,@
M;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@5&AE
M('-T87)T(&%N9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D96YD("`@(%1H92!E;F0@86YG;&4@;V8@=&AE(&%R8RX*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O;&]R("`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(&%R
M8RX*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@5&AE(&9I;&P@8V]L
M;W(@;V8@=&AE(&%R8RX*("`@("`J+PH@("`@9G5N8W1I;VX@87)C*"1X+"`D
M>2P@)'(L("1S=&%R="P@)&5N9"P@)&-O;&]R(#T@)V)L86-K)RP@)&9I;&P@
M/2`G;F]N92<I"B`@("!["B`@("`@("`@)',@/2`F;F5W(%-71E-H87!E*"D[
M"B`@("`@("`@)&-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R
M*3L*("`@("`@("`D<RT^<V5T3&EN92@Q+"`D8V]L;W);)W)E9"==+"`D8V]L
M;W);)V=R965N)UTL("1C;VQO<ELG8FQU92==+"`D8V]L;W);)V%L<&AA)UTI
M.PH*("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@("`@("`@
M("1F:6QL0V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL;"D["B`@
M("`@("`@("`@("1F(#T@)',M/F%D9$9I;&PH)&9I;&Q#;VQO<ELG<F5D)UTL
M("1F:6QL0V]L;W);)V=R965N)UTL("1F:6QL0V]L;W);)V)L=64G72P@)&9I
M;&Q#;VQO<ELG86QP:&$G72D["B`@("`@("`@("`@("1S+3YS9712:6=H=$9I
M;&PH)&8I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1E;F0@+2`D<W1A<G0@
M/#T@-#4I('L*("`@("`@("`@("`@)'!T<R`]("1T:&ES+3Y?87)C4&]I;G1S
M*"1R+"`D<W1A<G0L("1E;F0I.PH@("`@("`@("`@("`D<RT^;6]V95!E;E1O
M*"1X+"`D>2D["B`@("`@("`@("`@("1S+3YD<F%W3&EN951O*"1P='-;)W@Q
M)UT@*R`D>"P@)'!T<ULG>3$G72`K("1Y*3L*("`@("`@("`@("`@)',M/F1R
M87=#=7)V951O*"1P='-;)W@S)UT@*R`D>"P@)'!T<ULG>3,G72`K("1Y+"`D
M<'1S6R=X,B==("L@)'@L("1P='-;)WDR)UT@*R`D>2D["B`@("`@("`@("`@
M("1S+3YD<F%W3&EN951O*"1X+"`D>2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'-E8W1I;VYS(#T@8V5I;"@H)&5N9"`M("1S=&%R="D@+R`T
M-2D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1S96-T:6]N<SL@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@)'!T<R`]("1T:&ES+3Y?87)C4&]I
M;G1S*"1R+"`D<W1A<G0@*R`H)&D@*B`T-2DL("@D<W1A<G0@*R`H*"1I("L@
M,2D@*B`T-2D@/B`D96YD*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#\@)&5N9`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@*"1S=&%R="`K("@H)&D@*R`Q*2`J(#0U*2DI
M.PH*("`@("`@("`@("`@("`@("\O($EF('=E(&%R92!O;B!T:&4@9FER<W0@
M<V5C=&EO;BP@;6]V92!T:&4@<&5N('1O('1H90H@("`@("`@("`@("`@("`@
M+R\@8V5N=')E(&%N9"!D<F%W(&]U="!T;R!T:&4@961G92X*("`@("`@("`@
M("`@("`@(&EF("@D:2`]/2`P("8F("1F:6QL("$]("=N;VYE)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1S+3YM;W9E4&5N5&\H)'@L("1Y*3L*("`@("`@
M("`@("`@("`@("`@("`D<RT^9')A=TQI;F54;R@D<'1S6R=X,2==("L@)'@L
M("1P='-;)WDQ)UT@*R`D>2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1S+3YM;W9E4&5N5&\H)'!T<ULG>#$G72`K
M("1X+"`D<'1S6R=Y,2==("L@)'DI.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("\O($1R87<@=&AE(&%R8RX*("`@("`@("`@("`@("`@
M("1S+3YD<F%W0W5R=F54;R@D<'1S6R=X,R==("L@)'@L("1P='-;)WDS)UT@
M*R`D>2P@)'!T<ULG>#(G72`K("1X+"`D<'1S6R=Y,B==("L@)'DI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2![
M"B`@("`@("`@("`@("`@("`O+R!$<F%W(&$@;&EN92!F<F]M('1H92!E9&=E
M(&)A8VL@=&\@=&AE(&-E;G1R92!T;R!C;&]S90H@("`@("`@("`@("`@("`@
M+R\@;V9F('1H92!S96=M96YT+@H@("`@("`@("`@("`@("`@)',M/F1R87=,
M:6YE5&\H)'@L("1Y*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D9"@D<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$<F%W(&$@<F5C=&%N9VQE(&9I;&QE9"!W:71H(&$@9W)A
M9&EE;G0@9G)O;2`D8V]L;W(Q('1O"B`@("`@*B`D8V]L;W(R+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@(%1H92!L969T('@M8V]O
M<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'D@("`@("`@5&AE('1O<"!Y+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A
M;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1W:61T:"`@(%1H92!W:61T
M:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE
M:6=H="`@5&AE(&AE:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&-O;&]R("`@5&AE(&]U=&QI;F4@8V]L;W(@;V8@=&AE
M(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@("1F:6QL,2`@(%1H
M92!N86UE(&]F('1H92!S=&%R="!C;VQO<B!F;W(@=&AE(&=R861I96YT+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&PR("`@5&AE(&YA;64@;V8@=&AE
M(&5N9"!C;VQO<B!F;W(@=&AE(&=R861I96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G<F%D:65N=%)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H
M="P@)&-O;&]R(#T@)V)L86-K)RP@)&9I;&PQ(#T@)V)L86-K)RP@)&9I;&PR
M(#T@)W=H:71E)RD*("`@('L*("`@("`@("`D<R`]("9N97<@4U=&4VAA<&4H
M*3L*"B`@("`@("`@:68@*"1C;VQO<B`A/2`G;F]N92<I('L*("`@("`@("`@
M("`@)&-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@
M("`@("`@("`@)',M/G-E=$QI;F4H,2P@)&-O;&]R6R=R960G72P@)&-O;&]R
M6R=G<F5E;B==+"`D8V]L;W);)V)L=64G72P@)&-O;&]R6R=A;'!H82==*3L*
M("`@("`@("!]"@H@("`@("`@("1F:6QL,2`]("1T:&ES+3YA;&QO8V%T94-O
M;&]R*"1F:6QL,2D["B`@("`@("`@)&9I;&PR(#T@)'1H:7,M/F%L;&]C871E
M0V]L;W(H)&9I;&PR*3L*("`@("`@("`D9W)A9&EE;G0@/2`F;F5W(%-71D=R
M861I96YT*"D["B`@("`@("`@)&=R861I96YT+3YA9&1%;G1R>2@P+C`L("1F
M:6QL,5LG<F5D)UTL("1F:6QL,5LG9W)E96XG72P@)&9I;&PQ6R=B;'5E)UTL
M("1F:6QL,5LG86QP:&$G72D["B`@("`@("`@)&=R861I96YT+3YA9&1%;G1R
M>2@Q+C`L("1F:6QL,ELG<F5D)UTL("1F:6QL,ELG9W)E96XG72P@)&9I;&PR
M6R=B;'5E)UTL("1F:6QL,ELG86QP:&$G72D["@H@("`@("`@("1F(#T@)',M
M/F%D9$9I;&PH)&=R861I96YT+"!35T9&24Q,7TQ)3D5!4E]'4D%$245.5"D[
M"B`@("`@("`@)&8M/G-C86QE5&\H)'=I9'1H("\@)'1H:7,M/E]W:61T:"D[
M"B`@("`@("`@)&8M/FUO=F54;R@D>"P@)'DI.PH@("`@("`@("1S+3YS9712
M:6=H=$9I;&PH)&8I.PH*("`@("`@("`D=F5R='-;,%T@/2!A<G)A>2@G>"<@
M/3X@)'@L("=Y)R`]/B`D>2D["B`@("`@("`@)'9E<G1S6S%=(#T@87)R87DH
M)W@G(#T^("1X("L@)'=I9'1H+"`G>2<@/3X@)'DI.PH@("`@("`@("1V97)T
M<ULR72`](&%R<F%Y*"=X)R`]/B`D>"`K("1W:61T:"P@)WDG(#T^("1Y("L@
M)&AE:6=H="D["B`@("`@("`@)'9E<G1S6S-=(#T@87)R87DH)W@G(#T^("1X
M+"`G>2<@/3X@)'D@*R`D:&5I9VAT*3L*"B`@("`@("`@)&9I<G-T7V1O;F4@
M/2!F86QS93L*("`@("`@("!F;W)E86-H("@D=F5R=',@87,@)'9E<G0I('L*
M("`@("`@("`@("`@:68@*"$D9FER<W1?9&]N92D@>PH@("`@("`@("`@("`@
M("`@)',M/FUO=F5096Y4;R@D=F5R=%LG>"==+"`D=F5R=%LG>2==*3L*("`@
M("`@("`@("`@("`@("1F:7)S=%]D;VYE(#T@=')U93L*("`@("`@("`@("`@
M("`@("1F:7)S=%]X(#T@)'9E<G1;)W@G73L*("`@("`@("`@("`@("`@("1F
M:7)S=%]Y(#T@)'9E<G1;)WDG73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<RT^9')A=TQI;F54;R@D=F5R=%LG>"==+"`D=F5R=%LG>2==*3L*("`@
M("`@("!]"B`@("`@("`@)',M/F1R87=,:6YE5&\H)&9I<G-T7W@L("1F:7)S
M=%]Y*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D9"@D<RD[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+P``````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,P`P,3<R-C<`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+P``````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S<S`#`R,#4T-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'``````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`Q,S,R,3<`,3`T,3<S-C(W-S,`,#(R-C,S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7T)L
M;V-K7TQA>6]U=%]-86YA9V5R(&-L87-S(&%L;&]W<R!M86YI<'5L871I;VX@
M;V8*("H@2&]R9&5?0FQO8VL@;&%Y;W5T<RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP+'8@,2XT+C(N
M,R`R,#`V+S`S+S`X(#$W.C4T.C`X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXR"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S
M<R!(;W)D95]";&]C:U],87EO=71?36%N86=E<B!["@H@("`@+RHJ"B`@("`@
M*B!/=7(@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;B!I;G-T86YC92X*("`@("`J
M"B`@("`@*B!`=F%R($AO<F1E7T)L;V-K7T-O;&QE8W1I;VX*("`@("`J+PH@
M("`@=F%R("1?8V]L;&5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R
M96YT(&)L;V-K(&QA>6]U="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7VQA>6]U="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!!(&-A8VAE(&9O<B!T:&4@8FQO8VL@;V)J96-T<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V)L;V-K<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@;6%X:6UU;2!N=6UB97(@;V8@
M8V]L=6UN<RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?8V]L=6UN<R`](#`["@H@("`@+RHJ"B`@("`@*B!(87,@=&AE
M(&QA>6]U="!B965N('5P9&%T960@<VEN8V4@:70@=V%S(&EN<W1A;G1I871E
M9"X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?=7!D871E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E
M;G0@8FQO8VL@*&%R<F%Y.B!;<F]W+"!C;VQ=*2X*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1";&]C:R`](&%R
M<F%Y*&YU;&PL(&YU;&PI.PH*("`@("\J*@H@("`@("H@5&AE(&YE=R!R;W<@
M;V8@=&AE(&QA<W0@8VAA;F=E9"!B;&]C:RX*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8VAA;F=E9%]R;W<@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@5&AE(&YE=R!C;VQU;6X@;V8@=&AE(&QA<W0@
M8VAA;F=E9"!B;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?8VAA;F=E9%]C;VP@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E
M7T)L;V-K7T-O;&QE8W1I;VX@)B1C;VQL96-T:6]N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D871A"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T)L;V-K
M7TQA>6]U=%]-86YA9V5R*"8D8V]L;&5C=&EO;BP@)&1A=&$@/2`G)RD*("`@
M('L*("`@("`@("`D=&AI<RT^7V-O;&QE8W1I;VX@/2`F)&-O;&QE8W1I;VX[
M"B`@("`@("`@)'1H:7,M/G5N<V5R:6%L:7IE*"1D871A*3L*"B`@("`@("`@
M+R\@1FEL;"!T:&4@7V-O=F5R960@8V%C:&5S(&%N9"!E;7!T>2!R;W=S+@H@
M("`@("`@("1R;W=S(#T@8V]U;G0H)'1H:7,M/E]L87EO=70I.PH@("`@("`@
M("1E;7!T>2`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D<F]W(#T@,#L@)')O
M=R`\("1R;W=S.R`D<F]W*RLI('L*("`@("`@("`@("`@)&-O;',@/2!C;W5N
M="@D=&AI<RT^7VQA>6]U=%LD<F]W72D["B`@("`@("`@("`@(&EF("@A:7-S
M970H)&5M<'1Y6R1R;W==*2D@>PH@("`@("`@("`@("`@("`@)&5M<'1Y6R1R
M;W==(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W(@*"1C
M;VP@/2`P.R`D8V]L(#P@)&-O;',[("1C;VPK*RD@>PH@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L72DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V)L;V-K<ULD<F]W75LD8V]L
M72`](%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@8FQO8VL@97AI<W1S(&%T('1H
M92!R97%U97-T960@<&]S:71I;VXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)'1H:7,M/E]L87EO=71;
M)')O=UU;)&-O;%TI*2!["B`@("`@("`@("`@("`@("`@("`@)&9I96QD(#T@
M)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%T["@H@("`@("`@("`@("`@("`@
M("`@("1E;7!T>5LD<F]W72`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9FEE;&1;)W=I9'1H)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\("1F:65L9%LG=VED=&@G73L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=UU;)&-O;"`K("1I72`]("=C;W9E<F5D)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&9I96QD6R=H96EG:'0G72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9FEE;&1;)W=I
M9'1H)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&1;
M)W=I9'1H)UT@/2`Q.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\("1F:65L9%LG
M:&5I9VAT)UT[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&-O;%T@/2`G8V]V97)E9"<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,3L@)&H@
M/"`D9FEE;&1;)W=I9'1H)UT[("1J*RLI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VP@
M*R`D:ET@/2`G8V]V97)E9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96UP='E;)')O=R`K
M("1I72`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O+R!3=')I<"!E;7!T>2!B;&]C:W,@9G)O;2!T
M:&4@96YD(&]F('1H92!R;W=S+@H@("`@("`@("`@("!F;W(@*"1C;VP@/2`D
M8V]L<R`M(#$[("1C;VP@/CT@,#L@)&-O;"TM*2!["B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2!\?`H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=
M(#T]("=E;7!T>2<I('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7VQA>6]U=%LD<F]W75LD8V]L72D["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-O;'5M
M;G,@/2!M87@H)'1H:7,M/E]C;VQU;6YS+"!C;W5N="@D=&AI<RT^7VQA>6]U
M=%LD<F]W72DI.PH@("`@("`@('T*"B`@("`@("`@+R\@1FEL;"!A;&P@<F]W
M<R!U<"!T;R!T:&4@<V%M92!L96YG=&@N"B`@("`@("`@)&QA>6]U="`](&%R
M<F%Y*"D["B`@("`@("`@9F]R("@D<F]W(#T@,#L@)')O=R`\("1R;W=S.R`D
M<F]W*RLI('L*("`@("`@("`@("`@)&-O;',@/2!C;W5N="@D=&AI<RT^7VQA
M>6]U=%LD<F]W72D["B`@("`@("`@("`@(&EF("@D8V]L<R`\("1T:&ES+3Y?
M8V]L=6UN<RD@>PH@("`@("`@("`@("`@("`@9F]R("@D8V]L(#T@)&-O;',[
M("1C;VP@/"`D=&AI<RT^7V-O;'5M;G,[("1C;VPK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T@)V5M<'1Y
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D;&%Y;W5T6UT@/2`D=&AI<RT^7VQA>6]U=%LD<F]W73L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?;&%Y;W5T(#T@)&QA>6]U=#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E<FEA;&EZ92!A;F0@<F5T=7)N('1H92!C=7)R96YT
M(&)L;V-K(&QA>6]U="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE
M*"D*("`@('L*("`@("`@("!R971U<FX@<V5R:6%L:7IE*"1T:&ES+3Y?;&%Y
M;W5T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T<R!T:&4@8W5R<F5N
M="!L87EO=70@=&\@=&AE('9A;'5E('-T;W)E9"!I;B!T:&4@<')E9F5R96YC
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('5N<V5R:6%L:7IE*"1D871A*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?;&%Y;W5T(#T@0'5N<V5R:6%L:7IE*"1D
M871A*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S:6YG;&4@
M:6YS=&%N8V4@;V8@=&AE($AO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R(&-L
M87-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64*("`@("`J
M($!P87)A;2!(;W)D95]";&]C:U]#;VQL96-T:6]N("8D8V]L;&5C=&EO;@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&%T80H@("`@("H*("`@("`J($!S=&%T
M:6,*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T)L;V-K7TQA>6]U=%]-
M86YA9V5R("!4:&4@2&]R9&5?0FQO8VM?3&%Y;W5T7TUA;F%G97(@:6YS=&%N
M8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&YA;64L("8D
M8V]L;&5C=&EO;BP@)&1A=&$@/2`G)RD*("`@('L*("`@("`@("!S=&%T:6,@
M)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"%I<W-E="@D:6YS
M=&%N8V5S6R1N86UE72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD;F%M
M95T@/2!N97<@2&]R9&5?0FQO8VM?3&%Y;W5T7TUA;F%G97(H)&-O;&QE8W1I
M;VXL("1D871A*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1I;G-T86YC
M97-;)&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S<R!A(&UO
M9&EF:6-A=&EO;B!T;R!T:&4@8W5R<F5N="!L87EO=70N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<@)&%C=&EO;@H@("`@("H@0'9A<B!I;G1E9V5R("1R
M;W<*("`@("`J($!V87(@:6YT96=E<B`D8V]L"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AA;F1L92@D86-T:6]N+"`D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@
M('-W:71C:"`H)&%C=&EO;BD@>PH@("`@("`@(&-A<V4@)VUO=F55<"<Z"B`@
M("`@("`@8V%S92`G;6]V941O=VXG.@H@("`@("`@(&-A<V4@)VUO=F5,969T
M)SH*("`@("`@("!C87-E("=M;W9E4FEG:'0G.@H@("`@("`@(&-A<V4@)V5X
M<&%N9%5P)SH*("`@("`@("!C87-E("=E>'!A;F1$;W=N)SH*("`@("`@("!C
M87-E("=E>'!A;F1,969T)SH*("`@("`@("!C87-E("=E>'!A;F12:6=H="<Z
M"B`@("`@("`@8V%S92`G<VAR:6YK3&5F="<Z"B`@("`@("`@8V%S92`G<VAR
M:6YK4FEG:'0G.@H@("`@("`@(&-A<V4@)W-H<FEN:U5P)SH*("`@("`@("!C
M87-E("=S:')I;FM$;W=N)SH*("`@("`@("!C87-E("=R96UO=F5";&]C:R<Z
M"B`@("`@("`@("`@("1R97-U;'0@/2!C86QL7W5S97)?9G5N8RAA<G)A>2@F
M)'1H:7,L("1A8W1I;VXI+"`D<F]W+"`D8V]L*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*"1R97-U;'0I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]U
M<&1A=&5D(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@+R\@4V%V92!T:&4@8VAA;F=E<R!M861E('1O(&$@8FQO
M8VLN"B`@("`@("`@8V%S92`G<V%V92<Z"B`@("`@("`@+R\@4V%V92!T:&4@
M8VAA;F=E<R!M861E('1O(&$@8FQO8VL@86YD(&-O;G1I;G5E(&5D:71I;F<N
M"B`@("`@("`@8V%S92`G<V%V92UR97-U;64G.@H@("`@("`@("`@("`O+R!'
M970@<F5Q=65S=&5D(&)L;V-K('1Y<&4N"B`@("`@("`@("`@(&QI<W0H)&YE
M=V%P<"P@)&YE=W1Y<&4I(#T@97AP;&]D92@G.B<L(%5T:6PZ.F=E=$9O<FU$
M871A*"=A<'`G*2D["@H@("`@("`@("`@("`O+R!)<R!T:&ES(&$@;F5W(&)L
M;V-K/PH@("`@("`@("`@("`D;F5W(#T@9F%L<V4["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^:7-%;7!T>2@D<F]W+"`D8V]L*2!\?`H@("`@("`@("`@("`@
M("`@(21T:&ES+3YR;W=%>&ES=',H)')O=RD@?'P*("`@("`@("`@("`@("`@
M("$D=&AI<RT^8V]L17AI<W1S*"1C;VPI*2!["B`@("`@("`@("`@("`@("`O
M+R!#:&5C:R!P97)M:7-S:6]N<RX*("`@("`@("`@("`@("`@(&EF("A(;W)D
M93HZ:&%S4&5R;6ES<VEO;B@G;6%X7V)L;V-K<R<I("$]/2!T<G5E("8F"B`@
M("`@("`@("`@("`@("`@("`@2&]R9&4Z.FAA<U!E<FUI<W-I;VXH)VUA>%]B
M;&]C:W,G*2`\/2`D=&AI<RT^8V]U;G0H*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1M97-S86=E(#T@0&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO
M8VMS+B(I+"!(;W)D93HZ:&%S4&5R;6ES<VEO;B@G;6%X7V)L;V-K<R<I*2P@
M14Y47T-/35!!5"P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W!E<FUS9&5N:65D
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M97-S86=E(#T@2&]R
M9&4Z.F-A;&Q(;V]K*"=?<&5R;7-?:&]O:U]D96YI960G+"!A<G)A>2@G:&]R
M9&4Z;6%X7V)L;V-K<R<I+"`G:&]R9&4G+"`D;65S<V%G92D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=N
M;W1I9FEC871I;VXG72T^<'5S:"@D;65S<V%G92P@)VAO<F1E+F5R<F]R)RP@
M87)R87DH)V-O;G1E;G0N<F%W)RDI.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1N97<@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@+R\@36%K92!S=7)E('1H97)E(&ES
M('-O;65W:&5R92!T;R!P=70@:70N"B`@("`@("`@("`@("`@("`D=&AI<RT^
M861D0FQO8VLH)')O=RP@)&-O;"D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\O($]R(&%N(&5X:7-T:6YG(&]N93\*("`@("`@("`@("`@)&5X:7-T
M<R`](&9A;'-E.PH@("`@("`@("`@("`D8VAA;F=E9"`](&9A;'-E.PH@("`@
M("`@("`@("!I9B`H(21N97<I('L*("`@("`@("`@("`@("`@("\O($=E="!T
M87)G970@8FQO8VL@:6YF;RX*("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H
M:7,M/F=E=$)L;V-K26YF;R@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@("`@
M("1E>&ES=',@/2`D=&AI<RT^:7-";&]C:R@D<F]W+"`D8V]L*3L*("`@("`@
M("`@("`@("`@("\O($AA<R!A(&1I9F9E<F5N="!B;&]C:R!B965N('-E;&5C
M=&5D/PH@("`@("`@("`@("`@("`@:68@*"1E>&ES=',@)B8*("`@("`@("`@
M("`@("`@("`@("`H)&EN9F];)V%P<"==("$]("1N97=A<'`@?'P*("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)V)L;V-K)UT@(3T@)&YE=W1Y<&4I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&-H86YG960@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&YE
M=R!\?"`D8VAA;F=E9"D@>PH@("`@("`@("`@("`@("`@+R\@0VAA;F=E(&%P
M<"!O<B!T>7!E+@H@("`@("`@("`@("`@("`@)&EN9F\@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@)&EN9F];)V%P<"==(#T@)&YE=V%P<#L*("`@("`@
M("`@("`@("`@("1I;F9O6R=B;&]C:R==(#T@)&YE=W1Y<&4["B`@("`@("`@
M("`@("`@("`D<&%R86US(#T@)'1H:7,M/E]C;VQL96-T:6]N+3YG971087)A
M;7,H)&YE=V%P<"P@)&YE=W1Y<&4I.PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'!A<F%M<R!A<R`D;F5W<&%R86TI('L*("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG<&%R86US)UU;)&YE=W!A<F%M72`]("1T:&ES+3Y?8V]L;&5C
M=&EO;BT^9V5T1&5F875L=%9A;'5E*"1N97=A<'`L("1N97=T>7!E+"`D;F5W
M<&%R86TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$)L;V-K26YF;R@D<F]W+"`D8V]L+"`D:6YF;RD["B`@("`@("`@
M("`@('T@96QS96EF("@D97AI<W1S*2!["B`@("`@("`@("`@("`@("`O+R!#
M:&%N9V4@=F%L=65S+@H@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)L;V-K
M26YF;R@D<F]W+"`D8V]L+"!A<G)A>2@G<&%R86US)R`]/B!5=&EL.CIG971&
M;W)M1&%T82@G<&%R86US)RP@87)R87DH*2DI*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7W5P9&%T960@/2!T<G5E.PH@("`@("`@("`@
M("!I9B`H)&%C=&EO;B`]/2`G<V%V92<I('L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("\O($UA:V4@82!B;&]C:R!T
M:&4@8W5R<F5N="!B;&]C:R!F;W(@961I=&EN9RX*("`@("`@("!C87-E("=E
M9&ET)SH*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT0FQO8VL@/2!A<G)A
M>2@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@2&%S('1H92!L87EO=70@8F5E;B!C:&%N
M9V5D('-I;F-E(&ET('=A<R!I;G-T86YT:6%T960_"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T960H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W5P9&%T960["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&-U<G)E;G0@8FQO8VL@<F]W(&%N
M9"!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!;<F]W+"!C
M;VQ="B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-U<G)E;G1";&]C:R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8W5R<F5N=$)L;V-K.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@2&]R9&5?0FQO8VL@870@
M=&AE('-P96-I9FEE9"!P;W-I=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E
M='5R;B!(;W)D95]";&]C:R`@5&AE(&)L;V-K(&9R;VT@=&AA="!P;W-I=&EO
M;B!O<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M(&EF('-O;65T:&EN9R!W96YT('=R;VYG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9V5T0FQO8VLH)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?8FQO8VMS6R1R;W==6R1C;VQ=*2D@>PH@("`@("`@("`@
M("`D9FEE;&0@/2`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L73L*("`@("`@
M("`@("`@)'1H:7,M/E]B;&]C:W-;)')O=UU;)&-O;%T@/0H@("`@("`@("`@
M("`@("`@)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K*"1F:65L
M9%LG87!P)UTL("1F:65L9%LG<&%R86US)UU;)W1Y<&4G72P@)&9I96QD6R=P
M87)A;7,G75LG<&%R86US)UTI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8FQO8VMS6R1R;W==6R1C;VQ=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@8V]O<F1I;F%T97,@;V8@=&AE(&)L;V-K(&-O
M=F5R:6YG('1H92!S<&5C:69I960*("`@("`J(&9I96QD+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@=&]P+6QE9G0@<F]W+6-O;'5M
M;BUC;V]R9&EN871E(&]F('1H92!B;&]C:PH@("`@("H@("`@("`@("`@("`@
M("`@8V]V97)I;F<@=&AE('-P96-I9FEE9"!F:65L9"!O<B!N=6QL(&EF('1H
M92!F:65L9`H@("`@("H@("`@("`@("`@("`@("`@:7,@96UP='DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K070H)')O=RP@)&-O;"D*("`@('L*
M("`@("`@("`O*B!4<FEV:6%L(&-A<V5S(&9I<G-T+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^:7-%;7!T>2@D<F]W+"`D8V]L*2D@>PH@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YI<T-O=F5R
M960H)')O=RP@)&-O;"DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1R
M;W<L("1C;VPI.PH@("`@("`@('T*"B`@("`@("`@+RH@5&AI<R!I<R!A(&-O
M=F5R960@9FEE;&0N("HO"B`@("`@("`@9F]R("@D=&5S="`]("1R;W<@+2`Q
M.R`D=&5S="`^/2`P.R`D=&5S="TM*2!["B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/FES0V]V97)E9"@D=&5S="P@)&-O;"D@)B8*("`@("`@("`@("`@("`@
M("$D=&AI<RT^:7-%;7!T>2@D=&5S="P@)&-O;"D@)B8*("`@("`@("`@("`@
M("`@("1T97-T("L@)'1H:7,M/F=E=$AE:6=H="@D=&5S="P@)&-O;"D@+2`Q
M(#T]("1R;W<I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D=&5S
M="P@)&-O;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9F]R
M("@D=&5S="`]("1C;VP@+2`Q.R`D=&5S="`^/2`P.R`D=&5S="TM*2!["B`@
M("`@("`@("`@(&EF("@A)'1H:7,M/FES0V]V97)E9"@D<F]W+"`D=&5S="D@
M)B8*("`@("`@("`@("`@("`@("$D=&AI<RT^:7-%;7!T>2@D=&5S="P@)&-O
M;"D@)B8*("`@("`@("`@("`@("`@("1T97-T("L@)'1H:7,M/F=E=%=I9'1H
M*"1R;W<L("1T97-T*2`M(#$@/3T@)&-O;"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"1R;W<L("1T97-T*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I
M=&@@<V]M92!U<V5F=6P@:6YF;W)M871I;VX@86)O=70@=&AE('-P96-I9FEE
M9`H@("`@("H@8FQO8VLN"B`@("`@*@H@("`@("H@4F5T=7)N960@:&%S:"!V
M86QU97,Z"B`@("`@*B`G87!P)SH@87!P;&EC871I;VX@;F%M90H@("`@("H@
M)V)L;V-K)SH@8FQO8VL@;F%M90H@("`@("H@)W!A<F%M<R<Z('!A<F%M971E
M<B!H87-H"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!I
M;F9O<FUA=&EO;B!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971";&]C
M:TEN9F\H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2!\?`H@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD<F]W75LD8V]L72`]/2`G96UP='DG*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(BDL("=H;W)D92YE<G)O<B<I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=A<'`G(#T^("1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=A<'`G72P*("`@("`@("`@("`@
M("`@("`@("`@)V)L;V-K)R`]/B`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M75LG<&%R86US)UU;)W1Y<&4G72P*("`@("`@("`@("`@("`@("`@("`@)W!A
M<F%M<R<@/3X@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W!A<F%M<R==
M6R=P87)A;7,G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@8F%T
M8V@@;V8@:6YF;W)M871I;VX@86)O=70@=&AE('-P96-I9FEE9"!B;&]C:RX*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R
M;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU
M;6XN"B`@("`@*B!`<&%R86T@87)R87D@)&EN9F\@("!!(&AA<V@@=VET:"!I
M;F9O<FUA=&EO;B!V86QU97,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!0;W-S:6)L92!E;&5M96YT<R!A<F4Z"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`G87!P)SH@87!P;&EC871I;VX@;F%M90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@)V)L;V-K)SH@8FQO8VL@;F%M90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@)W!A<F%M<R<Z('!A<F%M971E<B!H87-H"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$)L;V-K26YF;R@D<F]W+"`D8V]L+"`D
M:6YF;R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7VQA>6]U=%LD<F]W75LD8V]L72DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)&EN9F];)V%P<"==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG87!P)UT@/2`D:6YF
M;ULG87!P)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG
M8FQO8VLG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;
M)&-O;%U;)W!A<F%M<R==6R=T>7!E)UT@/2`D:6YF;ULG8FQO8VLG73L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=P87)A;7,G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W!A<F%M
M<R==6R=P87)A;7,G72`]("1I;F9O6R=P87)A;7,G73L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W.PH@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(&)L;V-K<R!I;B!T:&4@8W5R<F5N
M="!L87EO=70N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!B;&]C
M:W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT*"D*("`@('L*("`@("`@
M("`D<F]W<R`]("1T:&ES+3YR;W=S*"D["B`@("`@("`@)&-O=6YT(#T@,#L*
M"B`@("`@("`@9F]R("@D<F]W(#T@,#L@)')O=R`\("1R;W=S.R`D<F]W*RLI
M('L*("`@("`@("`@("`@)&-O;',@/2`D=&AI<RT^8V]L=6UN<R@D<F]W*3L*
M("`@("`@("`@("`@9F]R("@D8V]L(#T@,#L@)&-O;"`\("1C;VQS.R`D8V]L
M*RLI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES16UP='DH)')O
M=RP@)&-O;"D@)B8*("`@("`@("`@("`@("`@("`@("`A)'1H:7,M/FES0V]V
M97)E9"@D<F]W+"`D8V]L*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;W5N
M="LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&-O=6YT.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@=&AE(&-U<G)E;G0@
M;&%Y;W5T+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU
M;6)E<B!O9B!R;W=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;W=S*"D*("`@
M('L*("`@("`@("!R971U<FX@8V]U;G0H)'1H:7,M/E]L87EO=70I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(&-O;'5M
M;G,@:6X@=&AE('-P96-I9FEE9"!R;W<@;V8@=&AE"B`@("`@*B!C=7)R96YT
M(&QA>6]U="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!4
M:&4@<F]W('1O(')E='5R;B!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@9G)O;2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@
M8V]L=6UN<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]L=6UN<R@D<F]W*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]L87EO=71;)')O=UTI
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB
M*2P@)')O=RDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@8V]U;G0H)'1H:7,M/E]L87EO=71;)')O=UTI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VAE8VMS('1O('-E92!I9B!A(&=I=F5N(&QO8V%T:6]N
M(&EF(&)E:6YG('5S960@8GD@82!B;&]C:PH@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&QO8V%T:6]N(&ES(&5M<'1Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&ES('1H92!L;V-A=&EO
M;B!I<R!B96EN9R!U<V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5M<'1Y
M*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@<F5T=7)N("%I<W-E="@D=&AI
M<RT^7VQA>6]U=%LD<F]W75LD8V]L72D@?'P@)'1H:7,M/E]L87EO=71;)')O
M=UU;)&-O;%T@/3T@)V5M<'1Y)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@:68@=&AE(&9I96QD(&%T('1H92!S<&5C:69I960@<&]S:71I;VX@
M:7,@8V]V97)E9"!B>0H@("`@("H@86YO=&AE<B!B;&]C:RX*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I
M960@9FEE;&0@:7,@8V]V97)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-#
M;W9E<F5D*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2`_("1T:&ES+3Y?;&%Y;W5T
M6R1R;W==6R1C;VQ=(#T]("=C;W9E<F5D)R`Z(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!I9B!T:&4@<W!E8VEF:65D(&QO8V%T:6]N
M(&ES('1H92!T;W`@;&5F="!F:65L9"!O9@H@("`@("H@82!B;&]C:RX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!S
M<&5C:69I960@<&]S:71I;VX@:7,@82!B;&]C:RP@9F%L<V4@:68*("`@("`J
M("`@("`@("`@("`@("`@("`@=&AE(&9I96QD(&1O97-N)W0@97AI<W0L(&ES
M(&5M<'1Y(&]R(&-O=F5R960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES0FQO
M8VLH)')O=RP@)&-O;"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)O
M=T5X:7-T<R@D<F]W*2`F)B`D=&AI<RT^8V]L17AI<W1S*"1C;VPI("8F"B`@
M("`@("`@("`@("$D=&AI<RT^:7-%;7!T>2@D<F]W+"`D8V]L*2`F)B`A)'1H
M:7,M/FES0V]V97)E9"@D<F]W+"`D8V]L*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@:68@=&AE('-P96-I9FEE9"!B;&]C:R!H87,@8F5E;B!C
M:&%N9V5D(&QA<W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O
M=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@
M02!L87EO=70@8V]L=6UN+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!T:&ES(&)L;V-K(&ES('1H92!L87-T(&]N92!T:&%T('=A
M<R!C:&%N9V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T-H86YG960H)')O
M=RP@)&-O;"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C:&%N9V5D
M7W)O=R`]/3T@)')O=R`F)B`D=&AI<RT^7V-H86YG961?8V]L(#T]/2`D8V]L
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I9B!T:&4@<W!E8VEF
M:65D(&)L;V-K(&UA>2!B92!R96UO=F5D+@H@("`@("H*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H:7,@8FQO8VL@;6%Y
M(&)E(')E;6]V960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4F5M;W9A8FQE
M*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@
M("`@("`D87!P(#T@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)V%P<"==
M.PH@("`@("`@("1T>7!E(#T@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;
M)W!A<F%M<R==6R=T>7!E)UT["B`@("`@("`@)&)L;V-K(#T@)&%P<"`N("<Z
M)R`N("1T>7!E.PH*("`@("`@("`O*B!#:&5C:R!I9B!T:&4@8FQO8VL@:7,@
M82!F:7AE9"!B;&]C:RX@*B\*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1B;&]C
M:RP@)&-O;F9;)W!O<G1A;"==6R=F:7AE9%]B;&]C:W,G72DI('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C
M:R!I9B!W92!H879E('-T:6QL(&%N;W1H97(@8FQO8VL@;V8@=&AE('-A;64@
M='EP92X@*B\*("`@("`@("`D9F]U;F0@/2!F86QS93L*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7VQA>6]U="!A<R`D8W5R7W)O=RD@>PH@("`@("`@("`@
M("!F;W)E86-H("@D8W5R7W)O=R!A<R`D8W5R7V-O;"D@>PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1C=7)?8V]L6R=A<'`G72D@)B8*("`@("`@("`@
M("`@("`@("`@("`D8W5R7V-O;%LG87!P)UT@/3T@)&%P<"`F)@H@("`@("`@
M("`@("`@("`@("`@("1C=7)?8V]L6R=P87)A;7,G75LG='EP92==(#T]("1T
M>7!E*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1F;W5N9"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]U
M;F0@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!54DP@
M=')I9V=E<FEN9R!A;B!A8W1I;VX@=&\@82!B;&]C:PH@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%C=&EO;B`@06X@86-T:6]N('1O('1R:6=G97(N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($%N(%523"!W:71H(&%L;"!N
M96-E<W-A<GD@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M06-T:6]N57)L*"1A8W1I;VXL("1R;W<L("1C;VPI"B`@("!["B`@("`@("`@
M)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ<V5L9E5R;"@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-O;"<@
M/3X@)&-O;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R;W<G(#T^("1R;W<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G86-T:6]N)R`]/B`D86-T:6]N+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYO8V%C:&4G(#T^(&)A
M<V5?8V]N=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*2DI.PH@("`@("`@(')E
M='5R;B`D=7)L("X@)R-B;&]C:R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@8V]N=')O;"`H;&EN:V5D(&%R<F]W*2!F;W(@82!C97)T86EN
M(&%C=&EO;B!O;B!T:&4*("`@("`J('-P96-I9FEE9"!B;&]C:RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!!(&-O;G1R;VP@='EP92!I
M;B!T:&4@9F]R;0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(FUO9&EF
M:6-A=&EO;B]D:7)E8W1I;VXB+B!0;W-S:6)L92!V86QU97,@9F]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!M;V1I9FEC871I;VXZ(&5X<&%N9"P@
M<VAR:6YK+"!M;W9E+B!0;W-S:6)L92!V86QU97,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@(&9O<B!D:7)E8W1I;VXZ('5P+"!D;W=N+"!L969T+"!R
M:6=H="X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O
M=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!L:6YK(&-O;G1A
M:6YI;F<@86X@87)R;W<@<F5P<F5S96YT:6YG('1H92!R97%U97-T960*("`@
M("`J("`@("`@("`@("`@("`@("!C;VYT<F]L+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971#;VYT<F]L*"1T>7!E+"`D<F]W+"`D8V]L*0H@("`@>PH@("`@
M("`@("1T>7!E(#T@97AP;&]D92@G+R<L("1T>7!E*3L*("`@("`@("`D86-T
M:6]N(#T@)'1Y<&5;,%T@+B!U8V9I<G-T*"1T>7!E6S%=*3L*("`@("`@("`D
M=7)L(#T@)'1H:7,M/F=E=$%C=&EO;E5R;"@D86-T:6]N+"`D<F]W+"`D8V]L
M*3L*"B`@("`@("`@<W=I=&-H("@D='EP95LP72D@>PH@("`@("`@(&-A<V4@
M)V5X<&%N9"<Z"B`@("`@("`@("`@("1T:71L92`](%\H(D5X<&%N9"(I.PH@
M("`@("`@("`@("`D:6UG(#T@)VQA<F=E7R<@+B`D='EP95LQ73L*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-H<FEN:R<Z"B`@("`@("`@
M("`@("1T:71L92`](%\H(E-H<FEN:R(I.PH@("`@("`@("`@("`D:6UG(#T@
M)VQA<F=E7R<["@H@("`@("`@("`@("!S=VET8V@@*"1T>7!E6S%=*2!["B`@
M("`@("`@("`@(&-A<V4@)W5P)SH*("`@("`@("`@("`@("`@("1I;6<@+CT@
M)V1O=VXG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=D;W=N)SH*("`@("`@("`@("`@("`@("1I;6<@+CT@)W5P)SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;&5F="<Z
M"B`@("`@("`@("`@("`@("`D:6UG("X]("=R:6=H="<["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W)I9VAT)SH*("`@("`@
M("`@("`@("`@("1I;6<@+CT@)VQE9G0G.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)VUO=F4G.@H@("`@("`@("`@("!S=VET8V@@*"1T>7!E6S%=*2![
M"B`@("`@("`@("`@(&-A<V4@)W5P)SH*("`@("`@("`@("`@("`@("1T:71L
M92`](%\H(DUO=F4@57`B*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G9&]W;B<Z"B`@("`@("`@("`@("`@("`D=&ET;&4@
M/2!?*")-;W9E($1O=VXB*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G;&5F="<Z"B`@("`@("`@("`@("`@("`D=&ET;&4@
M/2!?*")-;W9E($QE9G0B*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G<FEG:'0G.@H@("`@("`@("`@("`@("`@)'1I=&QE
M(#T@7R@B36]V92!2:6=H="(I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1I;6<@/2`D='EP95LQ73L*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!R971U<FX@2&]R
M9&4Z.FQI;FLH)'5R;"P@)'1I=&QE*2`N"B`@("`@("`@("`@($AO<F1E.CII
M;6<H)V)L;V-K+R<@+B`D:6UG("X@)RYP;F<G+"`D=&ET;&4L("<G+"`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO
M83XG.PH@("`@?0H*("`@("\J*@H@("`@("H@1&]E<R!A(')O=R!E>&ES=#\*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!4:&4@<F]W('1O
M(&QO;VL@9F]R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF('1H92!R;W<@97AI<W1S"B`@("`@*B\*("`@(&9U;F-T:6]N(')O=T5X
M:7-T<R@D<F]W*0H@("`@>PH@("`@("`@(')E='5R;B`D<F]W(#P@8V]U;G0H
M)'1H:7,M/E]L87EO=70I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&]E<R!A
M(&-O;'5M;B!E>&ES=#\*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]L("!4:&4@8V]L=6UN('1O(&QO;VL@9F]R"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!C;VQU;6X@97AI<W1S"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;$5X:7-T<R@D8V]L*0H@("`@>PH@("`@("`@
M(')E='5R;B`D8V]L(#P@)'1H:7,M/E]C;VQU;6YS.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H92!W:61T:"!O9B!T:&4@8FQO8VL@870@82!G:79E
M;B!L;V-A=&EO;BX*("`@("`J(%1H:7,@<F5T=7)N<R!T:&4@=VED=&@@:68@
M=&AE<F4@:7,@82!B;&]C:R!A="!T:&ES"B`@("`@*B!L;V-A=&EO;BP@;W1H
M97)W:7-E(')E='5R;G,@,2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4:&4@;G5M8F5R(&]F(&-O;'5M;G,@=&AI<R!B;&]C:R!S<&%N
M<PH@("`@("HO"B`@("!F=6YC=&EO;B!G9717:61T:"@D<F]W+"`D8V]L*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]L87EO=71;)')O
M=UU;)&-O;%TI*2!["B`@("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=
M6R=W:61T:"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W
M75LD8V]L75LG=VED=&@G72`](#$["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG=VED=&@G73L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@:&5I9VAT(&]F('1H92!B;&]C:R!A
M="!A(&=I=F5N(&QO8V%T:6]N+@H@("`@("H@5&AI<R!R971U<FYS('1H92!H
M96EG:'0@:68@=&AE<F4@:7,@82!B;&]C:R!A="!T:&ES"B`@("`@*B!L;V-A
M=&EO;BP@;W1H97)W:7-E(')E='5R;G,@,2X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F(')O=W,@=&AI<R!B;&]C
M:R!S<&%N<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971(96EG:'0H)')O=RP@
M)&-O;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?;&%Y
M;W5T6R1R;W==6R1C;VQ=*2D@>PH@("`@("`@("`@("!R971U<FX@,3L*("`@
M("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W
M75LD8V]L75LG:&5I9VAT)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W==6R1C;VQ=6R=H96EG:'0G72`](#$["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG:&5I9VAT
M)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N(&5M<'1Y(&)L;V-K
M(&%T('1H92!S<&5C:69I960@<&]S:71I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&1";&]C:R@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@(&EF
M("@A)'1H:7,M/G)O=T5X:7-T<R@D<F]W*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^861D4F]W*"1R;W<I.PH@("`@("`@('T*("`@("`@("!I9B`H(21T:&ES
M+3YC;VQ%>&ES=',H)&-O;"DI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$-O
M;"@D8V]L*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R
M;W==6R1C;VQ=(#T@87)R87DH)V%P<"<@/3X@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H96EG:'0G(#T^(#$L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=VED=&@G(#T^(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@G='EP92<@/3X@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"DI*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9',@82!N97<@<F]W('1O('1H92!L87EO=70N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@5&AE(&YU;6)E
M<B!O9B!T:&4@<F]W('1O(&%D9`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&12
M;W<H)')O=RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VQU;6YS(#X@
M,"D@>PH@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W72`](&%R<F%Y
M7V9I;&PH,"P@)'1H:7,M/E]C;VQU;6YS+"`G96UP='DG*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;F5W(&-O;'5M;B!T;R!T
M:&4@;&%Y;W5T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@
M(%1H92!N=6UB97(@;V8@=&AE(&-O;'5M;B!T;R!A9&0*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D0V]L*"1C;VPI"B`@("!["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]L87EO=70@87,@)&ED(#T^("1V86PI('L*("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)&ED75LD8V]L72`]("=E;7!T>2<["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?8V]L=6UN<RLK.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5M;W9E<R!A(&)L;V-K+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E0FQO8VLH)')O=RP@)&-O;"D*("`@('L*("`@("`@("`D=VED
M=&@@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D["B`@("`@("`@)&AE
M:6=H="`]("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D["B`@("`@("`@
M9F]R("@D:2`]("1H96EG:'0@+2`Q.R`D:2`^/2`P.R`D:2TM*2!["B`@("`@
M("`@("`@(&9O<B`H)&H@/2`D=VED=&@@+2`Q.R`D:B`^/2`P.R`D:BTM*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C
M;VP@*R`D:ET@/2`G96UP='DG.PH@("`@("`@("`@("`@("`@:68@*"$D=&AI
M<RT^8V]L17AI<W1S*"1C;VP@*R`D:B`K(#$I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G)E;6]V94-O;$EF16UP='DH)&-O;"`K("1J*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(21T:&ES+3YR;W=%>&ES=',H)')O=R`K("1I("L@,2D@)B8@)'1H:7,M/G)O
M=T5X:7-T<R@D<F]W("L@)&DI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<F5M;W9E4F]W269%;7!T>2@D<F]W("L@)&DI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*
M("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*"B`@("`@("`@
M:68@*"$D=&AI<RT^<F]W17AI<W1S*"1R;W<I*2!["B`@("`@("`@("`@("1R
M;W<M+3L*("`@("`@("`@("`@=VAI;&4@*"1R;W<@/CT@,"`F)B`D=&AI<RT^
M<F5M;W9E4F]W269%;7!T>2@D<F]W*2D@>PH@("`@("`@("`@("`@("`@)')O
M=RTM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H
M:7,M/F-O;$5X:7-T<R@D8V]L*2D@>PH@("`@("`@("`@("`D8V]L+2T["B`@
M("`@("`@("`@('=H:6QE("@D8V]L(#X](#`@)B8@)'1H:7,M/G)E;6]V94-O
M;$EF16UP='DH)&-O;"DI('L*("`@("`@("`@("`@("`@("1C;VPM+3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;6]V97,@82!R;W<@:68@:70G<R!E;7!T>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<F]W("!4:&4@;G5M8F5R(&]F('1H92!R;W<@=&\@=&\@
M8VAE8VL*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE(')O=R!I<R!N;W<@<F5M;W9E9"X*("`@("`J("`@("`@("`@("`@("`@
M("`@1F%L<V4@:68@=&AE(')O=R!S=&EL;"!E>&ES=',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;6]V95)O=TEF16UP='DH)')O=RD*("`@('L*("`@("`@
M("!I9B`H(21T:&ES+3YR;W=%>&ES=',H)')O=RDI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D<F]W<R`](&-O=6YT
M*"1T:&ES+3Y?;&%Y;W5T6R1R;W==*3L*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D<F]W<SL@)&DK*RD@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]L87EO=71;)')O=UU;)&E=*2`F)B`D=&AI<RT^7VQA>6]U=%LD<F]W
M75LD:5T@(3T@)V5M<'1Y)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@('5N<V5T*"1T
M:&ES+3Y?;&%Y;W5T6R1R;W==*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@8V]L=6UN(&EF(&ET)W,@
M96UP='DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@5&AE
M(&YU;6)E<B!O9B!T:&4@8V]L=6UN('1O('1O(&-H96-K"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!C;VQU;6X@:7,@;F]W
M(')E;6]V960N"B`@("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&EF('1H
M92!C;VQU;6X@<W1I;&P@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96UO=F5#;VQ)9D5M<'1Y*"1C;VPI"B`@("!["B`@("`@("`@:68@*"$D=&AI
M<RT^8V]L17AI<W1S*"1C;VPI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@)&-O;',@/2!C;W5N="@D=&AI<RT^7VQA
M>6]U="D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O;',[("1I*RLI
M('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1I75LD
M8V]L72D@)B8@)'1H:7,M/E]L87EO=71;)&E=6R1C;VQ=("$]("=E;7!T>2<I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O;',[
M("1I*RLI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]L87EO=71;)&E=
M6R1C;VQ=*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@36]V97,@82!B;&]C:R!O;F4@<F]W('5P+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O
M=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V955P*"1R;W<L("1C;VPI"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3YR;W=%>&ES=',H)')O=R`M(#$I*2![
M"B`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D
M8V]L*3L*("`@("`@("`@("`@+R\@4V5E(&EF('1H97)E)W,@<F]O;2!T;R!M
M;W9E(&EN=&\*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I9'1H
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T5M<'1Y
M*"1R;W<@+2`Q+"`D8V]L("L@)&DI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&EN7W=A>2`]("1T:&ES+3YG971";&]C:T%T*"1R;W<@+2`Q+"`D8V]L("L@
M)&DI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D:6Y?=V%Y
M*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`D:6Y?=V%Y6S%=(#T]("1C
M;VP@)B8*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%=I9'1H
M*"1I;E]W87E;,%TL("1I;E]W87E;,5TI(#T]("1W:61T:"D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!792!N965D('1O('-W87`@=&AE(&)L;V-K
M<RX*("`@("`@("`@("`@("`@("`@("`@("`@)')E8S$@/2!(;W)D95]!<G)A
M>3HZ9V5T4F5C=&%N9VQE*"1T:&ES+3Y?;&%Y;W5T+"`D<F]W+"`D8V]L+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2P@)'1H
M:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E8S(@/2!(;W)D95]!<G)A>3HZ9V5T4F5C=&%N9VQE*"1T:&ES
M+3Y?;&%Y;W5T+"`D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F=E=$AE:6=H="@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2P@
M)'1H:7,M/F=E=%=I9'1H*"1I;E]W87E;,%TL("1I;E]W87E;,5TI*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@8V]U;G0H
M)')E8S$I.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M;W(@*"1K(#T@,#L@)&L@/"!C;W5N="@D<F5C,5LD:ETI.R`D:RLK*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;
M)&EN7W=A>5LP72`K("1J75LD:6Y?=V%Y6S%=("L@)&M=(#T@)')E8S%;)&I=
M6R1K73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!F;W(@
M*"1J(#T@,#L@)&H@/"!C;W5N="@D<F5C,BD[("1J*RLI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<B`H)&L@/2`P.R`D:R`\(&-O=6YT*"1R
M96,R6R1J72D[("1K*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%LD:6Y?=V%Y6S!=("L@8V]U;G0H)')E8S$I
M("L@)&I=6R1I;E]W87E;,5T@*R`D:UT@/2`D<F5C,ELD:EU;)&M=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E
M9%]R;W<@/2`D:6Y?=V%Y6S!=.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-H86YG961?8V]L(#T@)&EN7W=A>5LQ73L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`O+R!.;W=H97)E('1O(&=O+@H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S="(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&%S=')O=R`]("1R;W<@*R`D
M=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI("T@,3L*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`D<')E=B`]("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T[
M"B`@("`@("`@("`@("`@("`O+R!-;W9E('1O<"!E9&=E"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("T@,5U;)&-O;"`K("1I72`]("1P
M<F5V.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O
M;"`K("1I72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@("`@("\O($UO=F4@
M8F]T=&]M(&5D9V4*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1L
M87-T<F]W75LD8V]L("L@)&E=(#T@)V5M<'1Y)SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"$D=&AI<RT^<F]W17AI<W1S*"1L87-T<F]W("L@
M,2DI('L*("`@("`@("`@("`@("`@("\O(%=A<R!O;B!T:&4@8F]T=&]M(')O
M=PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E;6]V95)O=TEF16UP='DH)&QA
M<W1R;W<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V-H86YG961?<F]W(#T@)')O=R`M(#$["B`@("`@("`@)'1H:7,M/E]C
M:&%N9V5D7V-O;"`]("1C;VP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E
M<R!A(&)L;V-K(&]N92!R;W<@9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UO=F5$;W=N*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@)'=I9'1H
M(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI.PH@("`@("`@("1L87-T
M<F]W(#T@)')O=R`K("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D["B`@
M("`@("`@:68@*"1T:&ES+3YR;W=%>&ES=',H)&QA<W1R;W<I*2!["B`@("`@
M("`@("`@("\O(%-E92!I9B!T:&5R92=S(')O;VT@=&\@;6]V92!I;G1O"B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1W:61T:#L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-%;7!T>2@D;&%S=')O=RP@
M)&-O;"`K("1I*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;E]W87D@/2`D
M=&AI<RT^9V5T0FQO8VM!="@D;&%S=')O=RP@)&-O;"`K("1I*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)&EN7W=A>2D@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN7W=A>5LQ72`]/2`D8V]L("8F"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=
M+"`D:6Y?=V%Y6S%=*2`]/2`D=VED=&@I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@5V4@;F5E9"!T;R!S=V%P('1H92!B;&]C:W,N"B`@("`@("`@
M("`@("`@("`@("`@("`@("1R96,Q(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A
M;F=L92@D=&AI<RT^7VQA>6]U="P@)')O=RP@)&-O;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"DL("1T:&ES+3YG9717:61T
M:"@D<F]W+"`D8V]L*2D["B`@("`@("`@("`@("`@("`@("`@("`@("1R96,R
M(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@
M)&EN7W=A>5LP72P@)&EN7W=A>5LQ72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG
M971(96EG:'0H)&EN7W=A>5LP72P@)&EN7W=A>5LQ72DL("1T:&ES+3YG9717
M:61T:"@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\(&-O=6YT*"1R96,R*3L@)&HK
M*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:R`](#`[
M("1K(#P@8V]U;G0H)')E8S);)&I=*3L@)&LK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:EU;
M)&-O;"`K("1K72`]("1R96,R6R1J75LD:UT["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@8V]U;G0H)')E
M8S$I.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@
M*"1K(#T@,#L@)&L@/"!C;W5N="@D<F5C,5LD:ETI.R`D:RLK*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O
M=R`K(&-O=6YT*"1R96,R*2`K("1J75LD8V]L("L@)&M=(#T@)')E8S%;)&I=
M6R1K73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-H86YG961?<F]W(#T@)&EN7W=A>5LP73L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1I;E]W87E;,5T["B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@3F\@=VAE<F4@=&\@9V\*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\O($UA:V4@<F]O;2!T;R!M;W9E(&EN=&\*("`@("`@("`@("`@
M)'1H:7,M/F%D9%)O=R@D;&%S=')O=RD["B`@("`@("`@?0H*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[("1I*RLI('L*("`@("`@("`@("`@
M)'!R978@/2`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L("L@)&E=.PH@("`@
M("`@("`@("`O+R!-;W9E(&)O='1O;2!E9&=E"B`@("`@("`@("`@("1T:&ES
M+3Y?;&%Y;W5T6R1L87-T<F]W75LD8V]L("L@)&E=(#T@)V-O=F5R960G.PH@
M("`@("`@("`@("`O+R!-;W9E('1O<"!E9&=E"B`@("`@("`@("`@("1T:&ES
M+3Y?;&%Y;W5T6R1R;W<@*R`Q75LD8V]L("L@)&E=(#T@)'!R978["B`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T@/2`G96UP
M='DG.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]
M("1R;W<@*R`Q.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L
M.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V97,@86QL(&)L;V-K<R!B96QO
M=R!A(&-E<G1A:6X@<F]W(&]N92!R;W<@9&]W;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&%L;"!R;W=S(&-O=6QD(&)E
M(&UO=F5D(&1O=VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F5$;W=N0F5L
M;W<H)')O=RD*("`@('L*("`@("`@("`D;6]V960@/2!A<G)A>2@I.PH@("`@
M("`@(&9O<B`H)'D@/2!C;W5N="@D=&AI<RT^7VQA>6]U="D@+2`Q.R`D>2`^
M("1R;W<[("1Y+2TI('L*("`@("`@("`@("`@9F]R("@D>"`](#`[("1X(#P@
M)'1H:7,M/E]C;VQU;6YS.R`D>"LK*2!["B`@("`@("`@("`@("`@("`D8FQO
M8VL@/2`D=&AI<RT^9V5T0FQO8VM!="@D>2P@)'@I.PH@("`@("`@("`@("`@
M("`@:68@*&5M<'1Y*"1B;&]C:RDI('L*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AE;7!T>2@D;6]V961;)&)L;V-K6S%=("X@)SHG("X@)&)L;V-K6S!=72DI
M('L*("`@("`@("`@("`@("`@("`@("`D;6]V961;)&)L;V-K6S%=("X@)SHG
M("X@)&)L;V-K6S!=72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YM;W9E1&]W;B@D8FQO8VM;,%TL("1B;&]C:ULQ72D[
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@36]V97,@82!B;&]C:R!O;F4@8V]L=6UN
M(&QE9G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E3&5F="@D<F]W
M+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^8V]L17AI<W1S*"1C
M;VP@+2`Q*2D@>PH@("`@("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE
M:6=H="@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@+R\@4V5E(&EF('1H97)E
M)W,@<F]O;2!T;R!M;W9E(&EN=&\N"B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A
M)'1H:7,M/FES16UP='DH)')O=R`K("1I+"`D8V]L("T@,2DI('L*("`@("`@
M("`@("`@("`@("`@("`D:6Y?=V%Y(#T@)'1H:7,M/F=E=$)L;V-K070H)')O
M=R`K("1I+"`D8V]L("T@,2D["B`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<U]N=6QL*"1I;E]W87DI("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1I
M;E]W87E;,%T@/3T@)')O=R`F)@H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^9V5T2&5I9VAT*"1I;E]W87E;,%TL("1I;E]W87E;,5TI(#T]("1H
M96EG:'0I('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@;F5E9"!T
M;R!S=V%P('1H92!B;&]C:W,N"B`@("`@("`@("`@("`@("`@("`@("`@("1R
M96,Q(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U
M="P@)')O=RP@)&-O;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H
M)')O=RP@)&-O;"DL("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1R96,R(#T@2&]R9&5?07)R87DZ.F=E
M=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@)&EN7W=A>5LP72P@)&EN7W=A
M>5LQ72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H)&EN7W=A>5LP
M72P@)&EN7W=A>5LQ72DL("1T:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D
M:6Y?=V%Y6S%=*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@
M/2`P.R`D:B`\(&-O=6YT*"1R96,Q*3L@)&HK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H)')E8S%;
M)&I=*3L@)&LK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&%Y;W5T6R1I;E]W87E;,%T@*R`D:EU;)&EN7W=A>5LQ72`K
M("1K72`]("1R96,Q6R1J75LD:UT["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@8V]U;G0H)')E8S(I.R`D
M:BLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1K(#T@
M,#L@)&L@/"!C;W5N="@D<F5C,ELD:ETI.R`D:RLK*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&EN7W=A>5LP
M72`K("1J75LD:6Y?=V%Y6S%=("L@8V]U;G0H)')E8S%;)&I=*2`K("1K72`]
M("1R96,R6R1J75LD:UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1I;E]W87E;,%T["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D:6Y?
M=V%Y6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("\O($YO('=H
M97)E('1O(&=O"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW87)N:6YG)RD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1L87-T8V]L(#T@)&-O;"`K("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L
M*2`M(#$["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[
M("1I*RLI('L*("`@("`@("`@("`@("`@("1P<F5V(#T@)'1H:7,M/E]L87EO
M=71;)')O=R`K("1I75LD8V]L73L*("`@("`@("`@("`@("`@("\O($UO=F4@
M;&5F="!H86YD(&5D9V4*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W<@*R`D:5U;)&-O;"`M(#%=(#T@)'!R978["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VQ=(#T@)V-O=F5R960G
M.PH@("`@("`@("`@("`@("`@+R\@36]V92!R:6=H="!H86YD(&5D9V4*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&QA<W1C
M;VQ=(#T@)V5M<'1Y)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^8V]L17AI<W1S*"1L87-T8V]L("L@,2DI('L*("`@("`@("`@
M("`@("`@("\O(%=A<R!O;B!T:&4@<FEG:'0M;6]S="!C;VQU;6X*("`@("`@
M("`@("`@("`@("1T:&ES+3YR96UO=F5#;VQ)9D5M<'1Y*"1L87-T8V]L*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O
M=R`]("1R;W<["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D
M8V]L("T@,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E
M<R!A(&)L;V-K(&]N92!C;VQU;6X@<FEG:'0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!M;W9E4FEG:'0H)')O=RP@)&-O;"D*("`@('L*("`@("`@("`D
M:&5I9VAT(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*3L*("`@("`@
M("`D;&%S=&-O;"`]("1C;VP@*R`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O
M;"D["B`@("`@("`@:68@*"1T:&ES+3YC;VQ%>&ES=',H)&QA<W1C;VPI*2![
M"B`@("`@("`@("`@("\O(%-E92!I9B!T:&5R92=S(')O;VT@=&\@;6]V92!I
M;G1O+@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&5I9VAT.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T5M<'1Y*"1R
M;W<@*R`D:2P@)&QA<W1C;VPI*2!["B`@("`@("`@("`@("`@("`@("`@)&EN
M7W=A>2`]("1T:&ES+3YG971";&]C:T%T*"1R;W<@*R`D:2P@)&QA<W1C;VPI
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D:6Y?=V%Y*2`F
M)@H@("`@("`@("`@("`@("`@("`@("`@("`D:6Y?=V%Y6S!=(#T]("1R;W<@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$AE:6=H="@D
M:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2`]/2`D:&5I9VAT*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%=E(&YE960@=&\@<W=A<"!T:&4@8FQO8VMS
M+@H@("`@("`@("`@("`@("`@("`@("`@("`D<F5C,2`]($AO<F1E7T%R<F%Y
M.CIG971296-T86YG;&4H)'1H:7,M/E]L87EO=70L("1R;W<L("1C;VPL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI+"`D=&AI
M<RT^9V5T5VED=&@H)')O=RP@)&-O;"DI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5C,B`]($AO<F1E7T%R<F%Y.CIG971296-T86YG;&4H)'1H:7,M
M/E]L87EO=70L("1I;E]W87E;,%TL("1I;E]W87E;,5TL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9V5T2&5I9VAT*"1I;E]W87E;,%TL("1I;E]W87E;,5TI+"`D
M=&AI<RT^9V5T5VED=&@H)&EN7W=A>5LP72P@)&EN7W=A>5LQ72DI.PH@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D
M<F5C,BD[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<B`H)&L@/2`P.R`D:R`\(&-O=6YT*"1R96,R6R1J72D[("1K*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W("L@)&I=6R1C;VP@*R`D:UT@/2`D<F5C,ELD:EU;)&M=.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\
M(&-O=6YT*"1R96,Q*3L@)&HK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H)')E8S%;)&I=*3L@)&LK
M*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T6R1R;W<@*R`D:EU;)&-O;"`K(&-O=6YT*"1R96,R6R1J72D@*R`D
M:UT@/2`D<F5C,5LD:EU;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D:6Y?=V%Y6S!=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@
M)&EN7W=A>5LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O+R!.
M;R!W:&5R92!T;R!G;PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN
M9R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@36%K92!R;V]M('1O(&UO=F4@:6YT
M;RX*("`@("`@("`@("`@)'1H:7,M/F%D9$-O;"@D;&%S=&-O;"D["B`@("`@
M("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK
M*2!["B`@("`@("`@("`@("1P<F5V(#T@)'1H:7,M/E]L87EO=71;)')O=R`K
M("1I75LD8V]L73L*("`@("`@("`@("`@+R\@36]V92!R:6=H="!H86YD(&5D
M9V4*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD;&%S
M=&-O;%T@/2`G8V]V97)E9"<["B`@("`@("`@("`@("\O($UO=F4@;&5F="!H
M86YD(&5D9V4*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I
M75LD8V]L("L@,5T@/2`D<')E=CL*("`@("`@("`@("`@)'1H:7,M/E]L87EO
M=71;)')O=R`K("1I75LD8V]L72`]("=E;7!T>2<["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`D=&AI
M<RT^7V-H86YG961?8V]L(#T@)&-O;"`K(#$["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!-;W9E<R!A;&P@8FQO8VMS(&%F=&5R(&$@8V5R=&%I;B!C;VQU;6X@
M;VYE(&-O;'5M;B!R:6=H="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF(&%L;"!C;VQU;6YS(&-O=6QD(&)E(&UO=F5D
M(')I9VAT+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E4FEG:'1!9G1E<B@D
M8V]L*0H@("`@>PH@("`@("`@("1M;W9E9"`](&%R<F%Y*"D["B`@("`@("`@
M9F]R("@D>"`]("1T:&ES+3Y?8V]L=6UN<R`M(#$[("1X(#X@)&-O;#L@)'@M
M+2D@>PH@("`@("`@("`@("!F;W(@*"1Y(#T@,#L@)'D@/"!C;W5N="@D=&AI
M<RT^7VQA>6]U="D[("1Y*RLI('L*("`@("`@("`@("`@("`@("1B;&]C:R`]
M("1T:&ES+3YG971";&]C:T%T*"1Y+"`D>"D["B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)&)L;V-K*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1M;W9E9%LD8FQO8VM;,5T@+B`G.B<@+B`D8FQO8VM;,%U=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1M;W9E9%LD8FQO8VM;,5T@+B`G.B<@+B`D
M8FQO8VM;,%U=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/FUO=F52:6=H="@D8FQO8VM;,%TL("1B;&]C:ULQ72D["B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@36%K97,@82!B;&]C:R!O;F4@<F]W('1A;&QE
M<B!B>2!M;W9I;F<@=&AE('1O<"!U<"X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5X<&%N9%5P*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YR;W=%>&ES=',H)')O=R`M(#$I*2!["B`@("`@("`@("`@("1W:61T
M:"`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@
M+R\@4V5E(&EF('1H97)E)W,@<F]O;2!T;R!E>'!A;F0@:6YT;PH@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[("1I*RLI('L*("`@("`@
M("`@("`@("`@(&EF("@A)'1H:7,M/FES16UP='DH)')O=R`M(#$L("1C;VP@
M*R`D:2DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YM;W9E
M1&]W;D)E;&]W*"1R;W<@+2`Q*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B*2P@
M)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F]W*RL["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[("1I*RLI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@+2`Q75LD8V]L
M("L@)&E=(#T@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K("1I73L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T@
M/2`G8V]V97)E9"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]L87EO=71;)')O=R`M(#%=6R1C;VQ=6R=H96EG:'0G72`]("1T:&ES+3YG
M971(96EG:'0H)')O=R`M(#$L("1C;VPI("L@,3L*"B`@("`@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W("T@,3L*("`@("`@("`@("`@)'1H
M:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@36%K97,@82!B;&]C:R!O;F4@<F]W('1A;&QE<B!B>2!M
M;W9I;F<@=&AE(&)O='1O;2!D;W=N+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@97AP86YD1&]W;B@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@("1W:61T
M:"`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*3L*("`@("`@("`D;&%S
M=')O=R`]("1R;W<@*R`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI("T@
M,3L*("`@("`@("!I9B`H(21T:&ES+3YR;W=%>&ES=',H)&QA<W1R;W<@*R`Q
M*2D@>PH@("`@("`@("`@("`O+R!!9&0@82!N97<@<F]W+@H@("`@("`@("`@
M("`D=&AI<RT^861D4F]W*"1L87-T<F]W("L@,2D["B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1W:61T:#L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]L87EO=71;)&QA<W1R;W<@*R`Q75LD8V]L("L@)&E=(#T@
M)V-O=F5R960G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VQ=6R=H96EG:'0G72`]("1T:&ES+3YG971(96EG
M:'0H)')O=RP@)&-O;"D@*R`Q.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O(%-E92!I9B!T:&5R92=S(')O;VT@=&\@97AP86YD(&EN=&\*("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T5M<'1Y*"1L87-T<F]W("L@
M,2P@)&-O;"`K("1I*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A)'1H
M:7,M/FUO=F5$;W=N0F5L;W<H)&QA<W1R;W<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S="(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VQA>6]U=%LD;&%S=')O=R`K(#%=6R1C;VP@*R`D
M:5T@/2`G8V]V97)E9"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)VAE:6=H="==(#T@)'1H:7,M/F=E
M=$AE:6=H="@D<F]W+"`D8V]L*2`K(#$["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`D=&AI<RT^7V-H
M86YG961?8V]L(#T@)&-O;#L*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S
M(&$@8FQO8VL@;VYE(&-O;'5M;B!W:61E<B!B>2!M;W9I;F<@=&AE(&QE9G0@
M<VED92!O=70N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@
M02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L
M87EO=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!A;F1,969T
M*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YC;VQ%>&ES
M=',H)&-O;"`M(#$I*2!["B`@("`@("`@("`@("1H96EG:'0@/2`D=&AI<RT^
M9V5T2&5I9VAT*"1R;W<L("1C;VPI.PH@("`@("`@("`@("`O+R!3964@:68@
M=&AE<F4G<R!R;V]M('1O(&5X<&%N9"!I;G1O"B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@("`@
M(&EF("@A)'1H:7,M/FES16UP='DH)')O=R`K("1I+"`D8V]L("T@,2DI('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YM;W9E4FEG:'1!9G1E
M<B@D8V]L("T@,2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW
M87)N:6YG)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;"LK.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L("T@,5T@
M/2`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VQ=.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L72`]("=C;W9E
M<F5D)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U
M=%LD<F]W75LD8V]L("T@,5U;)W=I9'1H)UT@/2`D=&AI<RT^9V5T5VED=&@H
M)')O=RP@)&-O;"`M(#$I("L@,3L*"B`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9%]R;W<@/2`D<F]W.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?
M8V]L(#T@)&-O;"`M(#$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@36%K97,@82!B;&]C:R!O;F4@8V]L=6UN('=I9&5R(&)Y(&UO=FEN9R!T
M:&4@<FEG:'0@<VED92!O=70N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!E
M>'!A;F12:6=H="@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@("1H96EG:'0@
M/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI.PH@("`@("`@("1L87-T
M8V]L(#T@)&-O;"`K("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2`M(#$[
M"B`@("`@("`@:68@*"1T:&ES+3YC;VQ%>&ES=',H)&QA<W1C;VP@*R`Q*2D@
M>PH@("`@("`@("`@("`O+R!3964@:68@=&AE<F4G<R!R;V]M('1O(&5X<&%N
M9"!I;G1O"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[
M("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES16UP='DH
M)')O=R`K("1I+"`D;&%S=&-O;"`K(#$I*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"$D=&AI<RT^;6]V95)I9VAT069T97(H)&QA<W1C;VPI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&AE:6=H=#L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I
M75LD;&%S=&-O;"`K(#%=(#T@)V-O=F5R960G.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=W:61T:"==
M(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI("L@,3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!!9&0@;F5W(&-O;'5M;@H@("`@("`@
M("`@("`D=&AI<RT^861D0V]L*"1L87-T8V]L("L@,2D["B`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&QA<W1C;VP@*R`Q
M72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG=VED=&@G72`]("1T:&ES+3YG9717
M:61T:"@D<F]W+"`D8V]L*2`K(#$["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`D=&AI<RT^7V-H86YG
M961?8V]L(#T@)&-O;#L*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@
M8FQO8VL@;VYE(')O=R!L;W=E<B!B>2!M;W9I;F<@=&AE('1O<"!D;W=N+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O
M=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<VAR:6YK57`H)')O=RP@)&-O;"D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L
M*2`^(#$I('L*("`@("`@("`@("`@)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H
M*"1R;W<L("1C;VPI.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M=VED=&@[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W<@*R`Q75LD8V]L("L@)&E=(#T@)'1H:7,M/E]L87EO=71;)')O=UU;
M)&-O;"`K("1I73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R
M;W==6R1C;VP@*R`D:5T@/2`G96UP='DG.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`Q75LD8V]L75LG:&5I9VAT
M)UT@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<@*R`Q+"`D8V]L*2`M(#$["@H@
M("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=R`K(#$["B`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@;VYE(')O
M=R!L;W=E<B!B>2!M;W9I;F<@=&AE(&)O='1O;2!U<"X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-H<FEN:T1O=VXH)')O=RP@)&-O;"D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`^(#$I('L*
M("`@("`@("`@("`@)&QA<W1R;W<@/2`D<F]W("L@)'1H:7,M/F=E=$AE:6=H
M="@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@("`@("1W:61T:"`]("1T:&ES
M+3YG9717:61T:"@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD;&%S=')O=UU;)&-O;"`K("1I72`]("=E;7!T>2<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;
M)&-O;%U;)VAE:6=H="==(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L
M*2`M(#$["B`@("`@("`@("`@(&EF("@A)'1H:7,M/G)O=T5X:7-T<R@D;&%S
M=')O=R`K(#$I*2!["B`@("`@("`@("`@("`@("`O+R!787,@;VX@=&AE(&)O
M='1O;2!R;W<*("`@("`@("`@("`@("`@("1T:&ES+3YR96UO=F52;W=)9D5M
M<'1Y*"1L87-T<F]W*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H
M:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<["B`@("`@("`@("`@("1T:&ES+3Y?
M8VAA;F=E9%]C;VP@/2`D8V]L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($UA:V5S(&$@8FQO8VL@;VYE(&-O;'5M;B!N87)R;W=E<B!B>2!M
M;W9I;F<@=&AE(&QE9G0@<VED92!I;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-H<FEN:TQE9G0H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI(#X@,2D@>PH@("`@("`@("`@
M("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*3L*("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L
M("L@,5T@/2`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VQ=.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L72`]
M("=E;7!T>2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=UU;)&-O;"`K(#%=6R=W:61T:"==(#T@)'1H:7,M/F=E=%=I
M9'1H*"1R;W<L("1C;VP@*R`Q*2`M(#$["@H@("`@("`@("`@("`D=&AI<RT^
M7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D7V-O;"`]("1C;VP@*R`Q.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($UA:V5S(&$@8FQO8VL@;VYE(&-O;'5M;B!N87)R;W=E<B!B>2!M
M;W9I;F<@=&AE(')I9VAT('-I9&4@:6XN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S:')I;FM2:6=H="@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D@/B`Q*2!["B`@("`@("`@
M("`@("1L87-T8V]L(#T@)&-O;"`K("1T:&ES+3YG9717:61T:"@D<F]W+"`D
M8V]L*2`M(#$["B`@("`@("`@("`@("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I
M9VAT*"1R;W<L("1C;VPI.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA
M>6]U=%LD<F]W("L@)&E=6R1L87-T8V]L72`]("=E;7!T>2<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;
M)W=I9'1H)UT@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D@+2`Q.PH@
M("`@("`@("`@("`D=&AI<RT^<F5M;W9E0V]L269%;7!T>2@D;&%S=&-O;"D[
M"@H@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@
M("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]";&]C:R],87EO=70O5FEE=RYP:'``````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,3`S,3<`,3`T,3<S-C(W-S,`,#(R,38V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@)TAO<F1E+T)R;W=S97(N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<"<["@HO*BH*("H@5&AE($AO
M<F1E7T)L;V-K7TQA>6]U=%]6:65W(&-L87-S(')E<')E<V5N=',@=&AE('5S
M97(@9&5F:6YE9"!P;W)T86P@;&%Y;W5T+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`L=B`Q+C0N,BXR(#(P
M,#8O,#,O,#@@,3<Z-30Z,#@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O
M+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C(*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO
M<F1E7T)L;V-K7TQA>6]U=%]6:65W('L*"B`@("`O*BH*("`@("`J(%1H92!C
M=7)R96YT(&)L;V-K(&QA>6]U="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7VQA>6]U="`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!!;&P@87!P;&EC871I;VYS('5S960@:6X@=&AI<R!L87EO=70N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A
M<'!L:6-A=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0U-3(&QI
M;FL@=&%G<R!P=6QL960@;W5T(&]F(&)L;V-K(&-O;G1E;G0N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]L:6YK5&%G<R`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@2&]R9&5?0FQO8VM?3&%Y;W5T7U9I97<H)&QA>6]U
M="`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&%Y;W5T(#T@0'5N<V5R
M:6%L:7IE*"1L87EO=70I.PH@("`@("`@(&EF("@A)'1H:7,M/E]L87EO=70I
M('L*("`@("`@("`@("`@)'1H:7,M/E]L87EO=70@/2!A<G)A>2@I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E<B!T:&4@8W5R<F5N
M="!L87EO=70@87,@2%1-3"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R!(5$U,(&QA>6]U="X*("`@("`J+PH@("`@9G5N8W1I;VX@=&](=&UL*"D*
M("`@('L*("`@("`@("`D8G)O=W-E<B`]("9"<F]W<V5R.CIS:6YG;&5T;VXH
M*3L*("`@("`@("`D='!L1&ER(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD["B`@("`@("`@)&EN=&5R=F%L(#T@
M)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=S=6UM87)Y7W)E9G)E<VA?
M=&EM92<I.PH*("`@("`@("!O8E]S=&%R="@I.PH*("`@("`@("!E8VAO("<\
M=&%B;&4@8VQA<W,](FYO<&%D9&EN9R(@8V5L;'-P86-I;F<](C8B('=I9'1H
M/2(Q,#`E(CXG.PH*("`@("`@("`D8V]V97)E9"`](&%R<F%Y*"D["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]L87EO=70@87,@)')O=U]N=6T@/3X@)')O
M=RD@>PH@("`@("`@("`@("`D=VED=&@@/2!F;&]O<B@Q,#`@+R!C;W5N="@D
M<F]W*2D["B`@("`@("`@("`@(&5C:&\@)SQT<CXG.PH@("`@("`@("`@("!F
M;W)E86-H("@D<F]W(&%S("1C;VQ?;G5M(#T^("1I=&5M*2!["B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&-O=F5R961;)')O=U]N=6U=*2`F)B!I<W-E
M="@D8V]V97)E9%LD<F]W7VYU;5U;)&-O;%]N=6U=*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1I=&5M*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?87!P;&EC871I;VYS6R1I=&5M6R=A<'`G75T@/2`D
M:71E;5LG87!P)UT["B`@("`@("`@("`@("`@("`@("`@)&)L;V-K(#T@)DAO
M<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K*"1I=&5M6R=A<'`G72P@
M)&ET96U;)W!A<F%M<R==6R=T>7!E)UTL("1I=&5M6R=P87)A;7,G75LG<&%R
M86US)UTI.PH@("`@("`@("`@("`@("`@("`@("1R;W=S<&%N(#T@)&ET96U;
M)VAE:6=H="==.PH@("`@("`@("`@("`@("`@("`@("1C;VQS<&%N(#T@)&ET
M96U;)W=I9'1H)UT["B`@("`@("`@("`@("`@("`@("`@)'=I9'1H("H]("1C
M;VQS<&%N.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1I=&5M6R=H96EG:'0G73L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1C;W9E<F5D6R1R;W=?;G5M("L@)&E=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O=F5R961;)')O=U]N=6T@
M*R`D:5T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1I=&5M
M6R=W:61T:"==.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]V97)E9%LD<F]W7VYU;2`K("1I75LD8V]L7VYU;2`K("1J72`]('1R
M=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&)L;V-K+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H96%D
M97(@/2!?*")%<G)O<B(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8V]N
M=&5N="`]("1B;&]C:RT^9V5T365S<V%G92@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!I;F-L=61E("1T<&Q$:7(@+B`G+W!O<G1A;"]B;&]C:RYI;F,G
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A*"1B;&]C:RP@
M)TAO<F1E7T)L;V-K)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AE
M861E<B`]("1B;&]C:RT^9V5T5&ET;&4H*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E;G0@/2`D8FQO8VLM/F=E=$-O;G1E;G0H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@:6YC;'5D92`D='!L1&ER("X@)R]P;W)T86PO
M8FQO8VLN:6YC)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!E8VAO("<\=&0@=VED=&@](B<@+B`D=VED
M=&@@+B`G)2(^)FYB<W`[/"]T9#XG.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M96-H;R`G/'1D('=I9'1H/2(G("X@)'=I9'1H("X@)R4B/B9N8G-P.SPO=&0^
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E8VAO("<\+W1R/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SPO=&%B
M;&4^)SL*"B`@("`@("`@)&AT;6P@/2!O8E]G971?8VQE86XH*3L*"B`@("`@
M("`@+R\@4W1R:7`@86YY($-34R`\;&EN:SX@=&%G<R!O=70@;V8@=&AE(')E
M='5R;F5D(&-O;G1E;G0@<V\*("`@("`@("`O+R!T:&5Y(&-A;B!B92!H86YD
M;&5D('-E<&5R871E;'DN"B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<O
M/&QI;FL@+BH_<F5L/2)S='EL97-H965T(BXJ/UPO/B\G+"`D:'1M;"P@)&QI
M;FMS*2D@>PH@("`@("`@("`@("`D:'1M;"`]('-T<E]R97!L86-E*"1L:6YK
M<ULP72P@)R<L("1H=&UL*3L*("`@("`@("`@("`@)'1H:7,M/E]L:6YK5&%G
M<R`]("1L:6YK<ULP73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M
M;#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;GD@;&EN:R!T86=S(&9O
M=6YD(&EN('1H92!V:65W+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,:6YK
M5&%G<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&EN:U1A9W,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!L:7-T(&]F(&%L;"!T
M:&4@87!P;&EC871I;VYS('5S960@8GD@8FQO8VMS(&EN('1H:7,@;&%Y;W5T
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@3&ES="!O9B!A<'!L:6-A
M=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%P<&QI8V%T:6]N<R@I
M"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)'1H:7,M/E]A<'!L
M:6-A=&EO;G,I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`S-C4U,0`Q,#0Q-S,V,C<W,P`P,C(Q,#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O0FQO8VLN<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?0FQO8VM?
M0V]L;&5C=&EO;CHZ(&-L87-S('!R;W9I9&5S(&%N($%022!T;R!T:&4@8FQO
M8VMS"B`J("AA<'!L971S*2!F<F%M97=O<FLN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP+'8@,2XS-BXT+C$W
M(#(P,#8O,#,O,#@@,3<Z-3,Z-3(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S
M($AO<F1E7T)L;V-K7T-O;&QE8W1I;VX@>PH*("`@("\J*@H@("`@("H@5VAA
M="!K:6YD(&]F(&)L;V-K<R!A<F4@=V4@8V]L;&5C=&EN9S\@1&5F875L=',@
M=&\@86YY+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7W1Y<&4@/2`G<&]R=&%L)SL*"B`@("`O*BH*("`@("`J($$@:&%S
M:"!S=&]R:6YG('1H92!I;F9O<FUA=&EO;B!A8F]U="!A;&P@879A:6QA8FQE
M(&)L;V-K<R!F<F]M"B`@("`@*B!A;&P@87!P;&EC871I;VYS+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8FQO8VMS(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!K:6YD(&]F(&)L;V-K
M<R!T;R!L:7-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<'!S("`@5&AE(&%P
M<&QI8V%T:6]N<R!W:&]S92!B;&]C:W,@=&\@;&ES="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;B@D='EP92`](&YU;&PL
M("1A<'!S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH
M)'1Y<&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("1T>7!E.PH@
M("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92@D87!P
M<RD["B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&4G75LG8FQO
M8VMS)UU;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8FQO
M8VMS(#T@)B1?4T534TE/3ELG:&]R9&4G75LG8FQO8VMS)UU;)'-I9VYA='5R
M95T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"
M;&]C:RYP:'`G.PH*("`@("`@("!F;W)E86-H("@D<F5G:7-T<GDM/FQI<W1!
M<'!S*"D@87,@)&%P<"D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)&%P<',I
M("8F("%I;E]A<G)A>2@D87!P+"`D87!P<RDI('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)&%P<"DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1B;&]C:V1I<B`]("1R96=I<W1R>2T^9V5T*"=F
M:6QE<F]O="<L("1A<'`I("X@)R]L:6(O0FQO8VLG.PH@("`@("`@("`@("`D
M9&@@/2!`;W!E;F1I<B@D8FQO8VMD:7(I.PH@("`@("`@("`@("!I9B`H:7-?
M<F5S;W5R8V4H)&1H*2D@>PH@("`@("`@("`@("`@("`@=VAI;&4@*"@D9FEL
M92`](')E861D:7(H)&1H*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*'-U8G-T<B@D9FEL92P@+30I(#T]("<N<&AP)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8FQO8VM?;F%M92`](&YU;&P["B`@("`@
M("`@("`@("`@("`@("`@("`@("1B;&]C:U]T>7!E(#T@;G5L;#L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7W)E861A8FQE*"1B;&]C:V1I<B`N
M("<O)R`N("1F:6QE*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:6YC;'5D95]O;F-E("1B;&]C:V1I<B`N("<O)R`N("1F:6QE.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-?;G5L;"@D8FQO8VM?='EP92D@)B8@(6ES7VYU;&PH)'1H:7,M/E]T
M>7!E*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&)L;V-K7W1Y
M<&4@(3T@)'1H:7,M/E]T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1B;&]C:U]N86UE*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B;&]C:W-;
M)&%P<%U;<W5B<W1R*"1F:6QE+"`P+"`M-"E=6R=N86UE)UT@/2`D8FQO8VM?
M;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&-L
M;W-E9&ER*"1D:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E9VES
M=')Y+3YP;W!!<'`H)&%P<"D["B`@("`@("`@?0H*("`@("`@("!U:W-O<G0H
M)'1H:7,M/E]B;&]C:W,L"B`@("`@("`@("`@("`@(&-R96%T95]F=6YC=&EO
M;B@G)&$L("1B)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=G
M;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!S=')C87-E8VUP*"1R96=I<W1R>2T^9V5T*")N86UE(BP@
M)&$I+"`D<F5G:7-T<GDM/F=E="@B;F%M92(L("1B*2D[)RD*("`@("`@("`@
M("`@("`@*3L*"B`@("`@("`@)%]315-324].6R=H;W)D92==6R=B;&]C:W,G
M75LD<VEG;F%T=7)E72`]("8D=&AI<RT^7V)L;V-K<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!S:6YG;&4@:6YS=&%N8V4@;V8@=&AE($AO
M<F1E7T)L;V-K<R!C;&%S<RX*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE(&MI;F0@;V8@8FQO
M8VMS('1O(&QI<W0N"B`@("`@*B!`<&%R86T@87)R87D@)&%P<',@("!4:&4@
M87!P;&EC871I;VYS('=H;W-E(&)L;V-K<R!T;R!L:7-T+@H@("`@("H*("`@
M("`J($!R971U<FX@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;B`@5&AE($AO<F1E
M7T)L;V-K7T-O;&QE8W1I;VX@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH)'1Y<&4@/2!N=6QL+"`D87!P<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*
M("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1T>7!E+"`D
M87!P<RDI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]
M(&YE=R!(;W)D95]";&]C:U]#;VQL96-T:6]N*"1T>7!E+"`D87!P<RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M73L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T0FQO8VLH)&%P<"P@)&YA;64L
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GD["@H@("`@("`@("1P871H(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T
M)RP@)&%P<"D@+B`G+VQI8B]";&]C:R\G("X@)&YA;64@+B`G+G!H<"<["B`@
M("`@("`@)&-L87-S(#T@)TAO<F1E7T)L;V-K7R<@+B`D87!P("X@)U\G("X@
M)&YA;64["B`@("`@("`@:68@*&ES7W)E861A8FQE*"1P871H*2D@>PH@("`@
M("`@("`@("!I;F-L=61E7V]N8V4@)'!A=&@["B`@("`@("`@?0H@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&5R
M<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(B5S(&YO="!F;W5N
M9"XB*2P@)&-L87-S*2D["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H*("`@("`@("`D8FQO8VL@/2`F;F5W("1C;&%S<R@D<&%R86US
M*3L*("`@("`@("!R971U<FX@)&)L;V-K.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('!R971T>2!P<FEN=&5D(&QI<W0@;V8@86QL(&%V86EL
M86)L92!B;&]C:W,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H
M87-H('=I=&@@8FQO8VL@241S(&%S(&ME>7,@86YD(&%P<&QI8V%T:6]N('!L
M=7,@8FQO8VL*("`@("`J("`@("`@("`@("`@("`@(&)L;V-K(&YA;65S(&%S
M('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO8VMS3&ES="@I
M"B`@("!["B`@("`@("`@<W1A=&EC("1B;&]C:W,@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("@A96UP='DH)&)L;V-K<RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1B;&]C:W,["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@)')E9VES=')Y
M.PH*("`@("`@("`O*B!'970@879A:6QA8FQE(&)L;V-K<R!F<F]M(&%L;"!A
M<'!S+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8FQO8VMS(&%S("1A
M<'`@/3X@)&%P<%]B;&]C:W,I('L*("`@("`@("`@("`@9F]R96%C:"`H)&%P
M<%]B;&]C:W,@87,@)&)L;V-K7VED(#T^("1B;&]C:RD@>PH@("`@("`@("`@
M("`@("`@)&)L;V-K<ULD87!P("X@)SHG("X@)&)L;V-K7VED72`]("1R96=I
M<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D@+B`G.B`G("X@)&)L;V-K6R=N86UE
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8FQO8VMS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QA>6]U
M="!H87-H('=I=&@@86QL(&9I>&5D(&)L;V-K<R!A<R!P97(@8V]N9FEG=7)A
M=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@<F5P
M<F5S96YT:6YG(&$@9&5F875L="!L87EO=70@=VET:"!A;&P@9FEX960*("`@
M("`J("`@("`@("`@("`@("`@(&)L;V-K<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1FEX961";&]C:W,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@)&QA>6]U="`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=P;W)T86PG75LG9FEX961?8FQO8VMS)UTI*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1C;VYF6R=P;W)T86PG75LG9FEX961?8FQO8VMS
M)UT@87,@)&)L;V-K*2!["B`@("`@("`@("`@("`@("!L:7-T*"1A<'`L("1T
M>7!E*2`](&5X<&QO9&4H)SHG+"`D8FQO8VLL(#(I.PH@("`@("`@("`@("`@
M("`@)&QA>6]U=%M=(#T@87)R87DH87)R87DH)V%P<"<@/3X@)&%P<"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G
M(#T^(&%R<F%Y*"=T>7!E)R`]/B`D='EP92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A
M;7,G(#T^(&9A;'-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H96EG:'0G(#T^(#$L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=VED=&@G(#T^(#$I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L87EO=70["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V5L96-T('=I9&=E="!W:71H
M(&%L;"!A=F%I;&%B;&4@8FQO8VMS+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-U<E]A<'`@("`@5&AE(&)L;V-K(&9R;VT@=&AI<R!A<'!L:6-A
M=&EO;B!G971S('-E;&5C=&5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W5R
M7V)L;V-K("!4:&4@8FQO8VL@=VET:"!T:&ES(&YA;64@9V5T<R!S96QE8W1E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E;&5C="!T
M86<@=VET:"!A;&P@879A:6QA8FQE(&)L;V-K<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0FQO8VMS5VED9V5T*"1C=7)?87!P(#T@;G5L;"P@)&-U<E]B
M;&]C:R`](&YU;&PL("1O;F-H86YG92`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1W:61G970@/2`G/'-E;&5C
M="!N86UE/2)A<'`B)SL*("`@("`@("!I9B`H)&]N8VAA;F=E*2!["B`@("`@
M("`@("`@("1W:61G970@+CT@)R!O;F-H86YG93TB9&]C=6UE;G0N8FQO8VMF
M;W)M+F%C=&EO;BYV86QU93U<)W-A=F4M<F5S=6UE7"<[9&]C=6UE;G0N8FQO
M8VMF;W)M+G-U8FUI="@I(B<["B`@("`@("`@?0H@("`@("`@("1W:61G970@
M+CT@(CY<;B(["B`@("`@("`@)&)L;V-K<U]L:7-T(#T@)'1H:7,M/F=E=$)L
M;V-K<TQI<W0H*3L*("`@("`@("!F;W)E86-H("@D8FQO8VMS7VQI<W0@87,@
M)&ED(#T^("1N86UE*2!["B`@("`@("`@("`@("1W:61G970@+CT@<W!R:6YT
M9B@B/&]P=&EO;B!V86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:60L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1I9"`]/2`D8W5R7V%P<"`N
M("<Z)R`N("1C=7)?8FQO8VLI(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z
M("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M*3L*("`@("`@("!]"B`@("`@("`@)'=I9&=E="`N/2`B/"]S96QE8W0^7&XB
M.PH*("`@("`@("!R971U<FX@)'=I9&=E=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&]P=&EO;B!T>7!E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971/<'1I;VY4>7!E*"1A<'`L("1B;&]C:RP@)'!A<F%M7VED*0H@
M("`@>PH@("`@("`@("1T:&ES+3YG971087)A;7,H)&%P<"P@)&)L;V-K*3L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG
M<&%R86US)UU;)'!A<F%M7VED75LG='EP92==.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!W:&5T:&5R('1H92!O<'1I;VX@:7,@<F5Q=6ER960@
M;W(@;F]T+B!$969A=6QT<R!T;R!T<G5E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971/<'1I;VY297%U:7)E9"@D87!P+"`D8FQO8VLL("1P87)A;5]I9"D*
M("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD[
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO
M8VM=6R=P87)A;7,G75LD<&%R86U?:61=6R=R97%U:7)E9"==*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R
M86US)UU;)'!A<F%M7VED75LG<F5Q=6ER960G73L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!V86QU97,@9F]R(&%N(&]P
M=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$]P=&EO;E9A;'5E<R@D
M87!P+"`D8FQO8VLL("1P87)A;5]I9"D*("`@('L*("`@("`@("`D=&AI<RT^
M9V5T4&%R86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5]I9%U;
M)W9A;'5E<R==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M=VED9V5T(&YE8V5S<V%R>2!T;R!C;VYF:6=U<F4@=&AI<R!B;&]C:RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T:6]N<U=I9&=E="@D87!P+"`D8FQO
M8VLL("1P87)A;5]I9"P@)'9A;"`](&YU;&PI"B`@("!["B`@("`@("`@)'=I
M9&=E="`]("<G.PH*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B
M;&]C:RD["B`@("`@("`@)'!A<F%M(#T@)'1H:7,M/E]B;&]C:W-;)&%P<%U;
M)&)L;V-K75LG<&%R86US)UU;)'!A<F%M7VED73L*("`@("`@("!I9B`H(6ES
M<V5T*"1P87)A;5LG9&5F875L="==*2D@>PH@("`@("`@("`@("`D<&%R86U;
M)V1E9F%U;'0G72`]("<G.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D
M<&%R86U;)W1Y<&4G72D@>PH@("`@("`@(&-A<V4@)V)O;VQE86XG.@H@("`@
M("`@(&-A<V4@)V-H96-K8F]X)SH*("`@("`@("`@("`@)&-H96-K960@/2`A
M96UP='DH)'9A;%LD<&%R86U?:61=*2`_("<@8VAE8VME9#TB8VAE8VME9"(G
M(#H@)R<["B`@("`@("`@("`@("1W:61G970@/2!S<')I;G1F*"<\:6YP=70@
M='EP93TB8VAE8VMB;W@B(&YA;64](G!A<F%M<ULE<UTB)7,@+SXG+"`D<&%R
M86U?:60L("1C:&5C:V5D*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)V5N=6TG.@H@("`@("`@("`@("`D=VED9V5T(#T@<W!R:6YT9B@G
M/'-E;&5C="!N86UE/2)P87)A;7-;)7-=(CXG+"`D<&%R86U?:60I.PH@("`@
M("`@("`@("!F;W)E86-H("@D<&%R86U;)W9A;'5E<R==(&%S("1K97D@/3X@
M)&YA;64I('L*("`@("`@("`@("`@("`@(&EF("A3=')I;F<Z.FQE;F=T:"@D
M;F%M92D@/B`S,"D@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@<W5B
M<W1R*"1N86UE+"`P+"`R-RD@+B`G+BXN)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1W:61G970@+CT@<W!R:6YT9B@B/&]P=&EO;B!V
M86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1K97DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AI<W-E="@D=F%L
M6R1P87)A;5]I9%TI("8F("1V86Q;)'!A<F%M7VED72`]/2`D:V5Y*2`_("<@
M<V5L96-T960](G-E;&5C=&5D(B<@.B`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1W:61G970@+CT@)SPO<V5L96-T
M/B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=M=6QT:65N
M=6TG.@H@("`@("`@("`@("`D=VED9V5T(#T@<W!R:6YT9B@G/'-E;&5C="!M
M=6QT:7!L93TB;75L=&EP;&4B(&YA;64](G!A<F%M<ULE<UU;72(^)RP@)'!A
M<F%M7VED*3L*("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M6R=V86QU97,G
M72!A<R`D:V5Y(#T^("1N86UE*2!["B`@("`@("`@("`@("`@("!I9B`H4W1R
M:6YG.CIL96YG=&@H)&YA;64I(#X@,S`I('L*("`@("`@("`@("`@("`@("`@
M("`D;F%M92`]('-U8G-T<B@D;F%M92P@,"P@,C<I("X@)RXN+B<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=VED9V5T("X]('-P<FEN
M=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB)7,^)7,\+V]P=&EO;CY<;B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC
M:&%R<R@D:V5Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H:7-S970H)'9A;%LD<&%R86U?:61=*2`F)B!I;E]A<G)A>2@D:V5Y+"`D
M=F%L6R1P87)A;5]I9%TI*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E
M8VEA;&-H87)S*"1N86UE*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1W:61G970@+CT@)SPO<V5L96-T/B<["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E("=M;&5N=6TG.@H@("`@("`@("`@("`O+R!-=6QT:2UL
M979E;"!E;G5M+@H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;"D@)B8@
M:7-S970H)'9A;%LG7U\G("X@)'!A<F%M7VED72DI('L*("`@("`@("`@("`@
M("`@("1F:7)S='9A;"`]("1V86Q;)U]?)R`N("1P87)A;5]I9%T["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&UP(#T@87)R87E?
M:V5Y<R@D<&%R86U;)W9A;'5E<R==*3L*("`@("`@("`@("`@("`@("1F:7)S
M='9A;"`](&-U<G)E;G0H)'1M<"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&)L;V-K=F%L=65S(#T@)'!A<F%M6R=V86QU97,G75LD9FER<W1V86Q=
M.PH@("`@("`@("`@("!A<V]R="@D8FQO8VMV86QU97,I.PH*("`@("`@("`@
M("`@)'=I9&=E="`]('-P<FEN=&8H)SQS96QE8W0@;F%M93TB<&%R86US6U]?
M)7-=(B!O;F-H86YG93TB9&]C=6UE;G0N8FQO8VMF;W)M+F%C=&EO;BYV86QU
M93U<)W-A=F4M<F5S=6UE7"<[9&]C=6UE;G0N8FQO8VMF;W)M+G-U8FUI="@I
M(CXG+"`D<&%R86U?:60I("X@(EQN(CL*("`@("`@("`@("`@9F]R96%C:"`H
M)'!A<F%M6R=V86QU97,G72!A<R`D:V5Y(#T^("1V86QU97,I('L*("`@("`@
M("`@("`@("`@("1N86UE(#T@4W1R:6YG.CIL96YG=&@H)&ME>2D@/B`S,"`_
M(%-T<FEN9SHZ<W5B<W1R*"1K97DL(#`L(#(W*2`N("<N+BXG(#H@)&ME>3L*
M("`@("`@("`@("`@("`@("1W:61G970@+CT@<W!R:6YT9B@B/&]P=&EO;B!V
M86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1K97DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1K97D@/3T@)&9I
M<G-T=F%L(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H
M)&YA;64I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=VED9V5T("X]
M("(\+W-E;&5C=#X\8G(@+SY<;B(["@H@("`@("`@("`@("`D=VED9V5T("X]
M('-P<FEN=&8H(CQS96QE8W0@;F%M93U<(G!A<F%M<ULE<UU<(CY<;B(L("1P
M87)A;5]I9"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1B;&]C:W9A;'5E<R!A
M<R`D:V5Y(#T^("1N86UE*2!["B`@("`@("`@("`@("`@("`D;F%M92`]("A3
M=')I;F<Z.FQE;F=T:"@D;F%M92D@/B`S,"D@/R!3=')I;F<Z.G-U8G-T<B@D
M;F%M92P@,"P@,C<I("X@)RXN+B<@.B`D;F%M93L*("`@("`@("`@("`@("`@
M("1W:61G970@+CT@<W!R:6YT9B@B/&]P=&EO;B!V86QU93U<(B5S7"(E<SXE
M<SPO;W!T:6]N/EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!H=&UL<W!E8VEA;&-H87)S*"1K97DI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V86Q;)'!A<F%M7VED72`]/2`D:V5Y(#\@
M)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=VED9V5T("X]("(\+W-E;&5C
M=#X\8G(@+SY<;B(["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=C;VQO<B<Z"B`@("`@("`@("`@("1V86P@/2!I<W-E="@D8FQO8VLM/E]P
M87)A;7-;)'!A<F%M7VED72D@/R`D8FQO8VLM/E]P87)A;7-;)'!A<F%M7VED
M72`Z("<G.PH@("`@("`@("`@("`D=VED9V5T(#T@<W!R:6YT9B@G/&EN<'5T
M('-T>6QE/2)B86-K9W)O=6YD+6-O;&]R.B5S(B!T>7!E/2)T97AT(B!N86UE
M/2)P87)A;7-;)7-=(B!V86QU93TB)7,B("\^)RP@)'9A;"P@)'!A<F%M7VED
M+"`D=F%L*3L*("`@("`@("`@("`@)'5R;"`@/2`D<F5G:7-T<GDM/F=E="@G
M=V5B<F]O="<L("=H;W)D92<I.PH@("`@("`@("`@("`D=7)L("X](%5T:6PZ
M.F%D9%!A<F%M971E<B@G+W-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`_=&%R9V5T/7!A<F%M<ULG("X@)'!A<F%M7VED("X@)UTG+"`G9F]R;2<L
M("=B;&]C:V9O<FTG*3L*("`@("`@("`@("`@)'=I9&=E="`N/2!S<')I;G1F
M*"<\82!H<F5F/2(E<R(@;VYC;&EC:STB=VEN9&]W+F]P96XH7"<E<UPG+"!<
M)V-O;&]R<&EC:V5R7"<L(%PG=&]O;&)A<CUN;RQL;V-A=&EO;CUN;RQS=&%T
M=7,];F\L<V-R;VQL8F%R<SUN;RQR97-I>F%B;&4];F\L=VED=&@],3(P+&AE
M:6=H=#TR-3`L;&5F=#TQ,#`L=&]P/3$P,%PG*3L@<F5T=7)N(&9A;'-E.R(@
M;VYM;W5S96]U=#TB=VEN9&]W+G-T871U<SU<)UPG.R(@;VYM;W5S96]V97(]
M(G=I;F1O=RYS=&%T=7,]7"<E<UPG.R!R971U<FX@=')U93LB(&-L87-S/2)W
M:61G970B('1A<F=E=#TB8V]L;W)P:6-K97(B/B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=7)L+"`D=7)L+"!?*")#;VQO<B!0:6-K97(B
M*2D["B`@("`@("`@("`@("1W:61G970@+CT@2&]R9&4Z.FEM9R@G8V]L;W)P
M:6-K97(N<&YG)RP@7R@B0V]L;W(@4&EC:V5R(BDL("=H96EG:'0](C$V(B<L
M("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI.PH@("`@("`@("`@
M("`D=VED9V5T("X]("<\+V$^)SL*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@)VEN="<Z"B`@("`@("`@8V%S92`G=&5X="<Z"B`@("`@("`@
M("`@("1W:61G970@/2!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M
M93TB<&%R86US6R5S72(@=F%L=64](B5S(B`O/B<L("1P87)A;5]I9"P@(6ES
M<V5T*"1V86Q;)'!A<F%M7VED72D@/R`D<&%R86U;)V1E9F%U;'0G72`Z("1V
M86Q;)'!A<F%M7VED72D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=E<G)O<B<Z"B`@("`@("`@("`@("1W:61G970@/2`G/'-P86X@8VQA
M<W,](F9O<FTM97)R;W(B/B<@+B`D<&%R86U;)V1E9F%U;'0G72`N("<\+W-P
M86X^)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'=I9&=E=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&YA;64@;V8@=&AE('-P96-I9FEE9"!B;&]C:RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A<'`@("`@06X@87!P;&EC871I;VX@;F%M92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!!(&)L;V-K(&YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!N86UE(&]F('1H92!S
M<&5C:69I960@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H
M)&%P<"P@)&)L;V-K*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]B;&]C:W-;)&%P<%U;)&)L;V-K72DI('L*("`@("`@("`@("`@<F5T=7)N
M('-P<FEN=&8H7R@B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(BDL("1B;&]C:RP@)&%P<"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=N86UE
M)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A;65T
M97(@;&ES="!O9B!T:&4@<W!E8VEF:65D(&)L;V-K+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%P<"`@("!!;B!A<'!L:6-A=&EO;B!N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@($$@8FQO8VL@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H(&%L;"!P
M87)A;71E<B!N86UE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86US
M*"1A<'`L("1B;&]C:RD*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==*2D@>PH@("`@("`@
M("`@("`D8FQO8VM/8B`]("8D=&AI<RT^9V5T0FQO8VLH)&%P<"P@)&)L;V-K
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&)L;V-K3V(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D8FQO8VM/8CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO
M8VM=6R=P87)A;7,G72`]("1B;&]C:T]B+3YG971087)A;7,H*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V)L;V-K<ULD87!P75LD
M8FQO8VM=6R=P87)A;7,G72D@)B8*("`@("`@("`@("`@:7-?87)R87DH)'1H
M:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R86US)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>5]K97ES*"1T:&ES+3Y?8FQO8VMS6R1A<'!=
M6R1B;&]C:UU;)W!A<F%M<R==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92`H8VQE87(@=&5X="D@;F%M92!O9B!T:&4@
M<W!E8VEF:65D('!A<F%M971E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A<'`@("`@06X@87!P;&EC871I;VX@;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&)L;V-K("!!(&)L;V-K(&YA;64N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87)A;2`@02!P87)A;65T97(@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE('-P96-I9FEE9"!P
M87)A;65T97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M3F%M92@D
M87!P+"`D8FQO8VLL("1P87)A;2D*("`@('L*("`@("`@("`D=&AI<RT^9V5T
M4&%R86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5U;)VYA;64G
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1E9F%U;'0@
M=F%L=64@;V8@=&AE('-P96-I9FEE9"!P87)A;65T97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D87!P("`@($%N(&%P<&QI8V%T:6]N(&YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@02!B;&]C:R!N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86T@($$@<&%R86UE=&5R(&YA;64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D969A=6QT('9A
M;'5E(&]F('1H92!S<&5C:69I960@<&%R86UE=&5R(&]R(&YU;&PN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1686QU92@D87!P+"`D8FQO8VLL
M("1P87)A;2D*("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L
M("1B;&]C:RD["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1A
M<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5U;)V1E9F%U;'0G72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C
M:UU;)W!A<F%M<R==6R1P87)A;5U;)V1E9F%U;'0G73L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&EF('1H92!S<&5C:69I960@8FQO8VL@:7,@8W5S=&]M:7IE86)L92!B
M>2!T:&4@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@
M("`@06X@87!P;&EC871I;VX@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&)L;V-K("!!(&)L;V-K(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&ES('1H92!B;&]C:R!I<R!C=7-T;VUI>F5A8FQE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<T5D:71A8FQE*"1A<'`L("1B;&]C:RD*
M("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD[
M"B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B
M;&]C:UU;)W!A<F%M<R==*2`F)@H@("`@("`@("`@("!C;W5N="@D=&AI<RT^
M7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G72D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]";&]C:R]522YP:'``````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#4W-C<`,3`T,3<S-C(W-S,`,#(P,S,Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!#
M;&%S<R!F;W(@<V5T=&EN9R!U<"!(;W)D92!";&]C:W,@=7-I;F<@=&AE($AO
M<F1E7T9O<FTZ.B!C;&%S<V5S+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V
M($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`L=B`Q
M+C@N,3`N-2`R,#`V+S`Q+S`R(#$W.C0V.C,U(&IA;B!%>'`@)`H@*@H@*B!`
M875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L
M87-S($AO<F1E7T)L;V-K7U5)('L*"B`@("!V87(@)%]B;&]C:W,@/2!A<G)A
M>2@I.PH@("`@=F%R("1?9F]R;2`](&YU;&P["B`@("!V87(@)%]V87)S(#T@
M;G5L;#L*"B`@("!F=6YC=&EO;B!(;W)D95]";&]C:U]522@I"B`@("!["B`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:RYP:'`G.PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`G.PH@
M("`@("`@("1T:&ES+3Y?8FQO8VMS(#T@)DAO<F1E7T)L;V-K7T-O;&QE8W1I
M;VXZ.G-I;F=L971O;B@I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$9O<FTH
M)B1F;W)M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9F]R;2`]("8D9F]R;3L*
M("`@('T*"B`@("!F=6YC=&EO;B!S971687)S*"8D=F%R<RD*("`@('L*("`@
M("`@("`D=&AI<RT^7W9A<G,@/2`F)'9A<G,["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5T=7!%9&ET1F]R;2@D9FEE;&0@/2`G8FQO8VLG*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?=F%R<RDI('L*("`@("`@("`@("`@
M+RH@3F\@97AI<W1I;F<@=F%R<R!S970L(&=E="!T:&5M(&YO=RX@*B\*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L97,N<&AP)SL*
M("`@("`@("`@("`@)'1H:7,M/E]V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F
M875L=%9A<FEA8FQE<R@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]A
M*"1T:&ES+3Y?9F]R;2P@)TAO<F1E7T9O<FTG*2D@>PH@("`@("`@("`@("`O
M*B!.;R!E>&ES=&EN9R!V86QI9"!F;W)M(&]B:F5C="!S970@<V\@<V5T('5P
M(&$@;F5W(&]N92X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]&;W)M+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?9F]R;2`]("9(;W)D
M95]&;W)M.CIS:6YG;&5T;VXH)R<L("1T:&ES+3Y?=F%R<RP@7R@B161I="!"
M;&]C:R(I*3L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@8W5R<F5N
M="!V86QU92!O9B!T:&4@8FQO8VL@<V5L96-T:6]N+B`J+PH@("`@("`@("1V
M86QU92`]("1T:&ES+3Y?=F%R<RT^9V5T*"1F:65L9"D["@H@("`@("`@("\J
M($9I96QD('1O('-E;&5C="!A<'!S+B`J+PH@("`@("`@("1A<'!S(#T@)'1H
M:7,M/E]B;&]C:W,M/F=E=$)L;V-K<TQI<W0H*3L*("`@("`@("`D=B`]("8D
M=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*%\H(D%P<&QI8V%T:6]N(BDL("1F
M:65L9"`N("=;87!P72<L("=E;G5M)RP@=')U92P@9F%L<V4L(&YU;&PL(&%R
M<F%Y*"1A<'!S*2D["B`@("`@("`@)'8M/G-E=$]P=&EO;B@G=')A8VMC:&%N
M9V4G+"!T<G5E*3L*"B`@("`@("`@:68@*&5M<'1Y*"1V86QU95LG87!P)UTI
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J
M($EF(&$@8FQO8VL@:&%S(&)E96X@<V5L96-T960L(&]U='!U="!A;GD@;W!T
M:6]N<R!I;G!U="X@*B\*("`@("`@("!L:7-T*"1A<'`L("1B;&]C:RD@/2!E
M>'!L;V1E*"<Z)RP@)'9A;'5E6R=A<'`G72D["@H@("`@("`@("\J($=E="!T
M:&4@;W!T:6]N<R!F;W(@=&AE(')E<75E<W1E9"!B;&]C:RX@*B\*("`@("`@
M("`D;W!T:6]N<R`]("1T:&ES+3Y?8FQO8VMS+3YG971087)A;7,H)&%P<"P@
M)&)L;V-K*3L*"B`@("`@("`@+RH@1V\@=&AR;W5G:"!T:&4@;W!T:6]N<R!F
M;W(@=&AI<R!B;&]C:R!A;F0@<V5T('5P(&%N>2!R97%U:7)E9`H@("`@("`@
M("`J(&5X=')A(&EN<'5T+B`J+PH@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS
M(&%S("1O<'1I;VXI('L*("`@("`@("`@("`@)&YA;64@/2`D=&AI<RT^7V)L
M;V-K<RT^9V5T4&%R86U.86UE*"1A<'`L("1B;&]C:RP@)&]P=&EO;BD["B`@
M("`@("`@("`@("1T>7!E(#T@)'1H:7,M/E]B;&]C:W,M/F=E=$]P=&EO;E1Y
M<&4H)&%P<"P@)&)L;V-K+"`D;W!T:6]N*3L*("`@("`@("`@("`@)')E<75I
M<F5D(#T@)'1H:7,M/E]B;&]C:W,M/F=E=$]P=&EO;E)E<75I<F5D*"1A<'`L
M("1B;&]C:RP@)&]P=&EO;BD["B`@("`@("`@("`@("1V86QU97,@/2`D=&AI
M<RT^7V)L;V-K<RT^9V5T3W!T:6]N5F%L=65S*"1A<'`L("1B;&]C:RP@)&]P
M=&EO;BD["B`@("`@("`@("`@("\J(%1/1$\Z('1H92!S971T:6YG("=S=')I
M;F<G('-H;W5L9"!B92!C:&%N9V5D(&EN(&%L;"!B;&]C:W,*("`@("`@("`@
M("`@("H@=&\@)W1E>'0G('-O('1H870@:70@8V]N9F]R;7,@=VET:"!(;W)D
M95]&;W)M('-Y;G1A>"X@*B\*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=S
M=')I;F<G*2!["B`@("`@("`@("`@("`@("`D='EP92`]("=T97AT)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@
M("`@("`@("`@:68@*"1T>7!E(#T]("=E;G5M)R!\?"`D='EP92`]/2`G;6QE
M;G5M)RD@>PH@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"1V86QU
M97,L('1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M9F]R;2T^861D5F%R:6%B;&4H)&YA;64L("1F:65L9"`N("=;;W!T:6]N<UU;
M)R`N("1O<'1I;VX@+B`G72<L("1T>7!E+"`D<F5Q=6ER960L(&9A;'-E+"!N
M=6QL+"`D<&%R86US*3L*("`@("`@("!]"B`@("!]"@I]"@```````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+P``````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<W,P`P,C$Q-38`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(O9&)M+G!H<```````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`V-#(S`#$P-#$W,S8R-S<S`#`R,C0S,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M4V5S<VEO;DAA;F1L97(Z.B!I;7!L96UE;G1A=&EO;B!F;W(@1$)-(&9I;&5S
M+@H@*B!.3U1%.B!4:&4@4$A0($1"32!F=6YC=&EO;G,@87)E(&1E<')E8V%T
M960N"B`J"B`J($YO(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!P87)A;65T
M97)S(&YE961E9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O9&)M+G!H<"QV(#$N.2XQ,BXW(#(P,#8O
M,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE
M<E]D8FT@97AT96YD<R!397-S:6]N2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@
M*B!/=7(@<&]I;G1E<B!T;R!T:&4@1$)-(&9I;&4L(&EF(&]P96XN"B`@("`@
M*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]D8FT[
M"@H@("`@+RHJ"B`@("`@*B!/<&5N('1H92!397-S:6]N2&%N9&QE<B!B86-K
M96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-A=F5?<&%T:"`@
M("`@5&AE('!A=&@@=&\@=&AE('-E<W-I;VX@;V)J96-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5S<VEO;E]N86UE("!4:&4@;F%M92!O9B!T:&4@<V5S
M<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!O<&5N*"1S879E7W!A=&@L("1S97-S:6]N7VYA;64I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]D8FT@/2!`9&)M;W!E;B@B)'-A=F5?<&%T:"\D<V5S<VEO
M;E]N86UE(BP@)V,G*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]D8FT["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@
M8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@<F5T=7)N($!D8FUC;&]S92@D
M=&AI<RT^7V1B;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D
M871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@
M=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@
M("`@("!I9B`H)&1A=&$@/2!D8FUF971C:"@D=&AI<RT^7V1B;2P@)&ED*2D@
M>PH@("`@("`@("`@("!R971U<FX@8F%S938T7V1E8V]D92AS=6)S='(H)&1A
M=&$L('-T<G!O<R@D9&%T82P@)WPG*2`K(#$I*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D871A('1O('1H92!397-S:6]N
M2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E<W-I;VX@9&%T
M82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@("`@<F5T=7)N
M($!D8FUR97!L86-E*"1T:&ES+3Y?9&)M+"`D:60L('1I;64H*2`N("=\)R`N
M(&)A<V4V-%]E;F-O9&4H)'-E<W-I;VY?9&%T82DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E
M<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H
M92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&5S=')O>2@D:60I"B`@("!["B`@("`@("`@
M:68@*"$H0&1B;61E;&5T92@D=&AI<RT^7V1B;2P@)&ED*2DI('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!D96QE=&4@<V5S
M<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V%R8F%G92!C;VQL96-T('-T86QE('-E<W-I;VYS(&9R;VT@=&AE
M(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&UA>&QI9F5T:6UE("!4:&4@;6%X:6UU;2!A9V4@;V8@82!S
M97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=C*"1M87AL:69E=&EM92`](#,P,"D*("`@('L*("`@("`@("`D97AP
M:7)E9"`]('1I;64H*2`M("1M87AL:69E=&EM93L*("`@("`@("`D:60@/2!D
M8FUF:7)S=&ME>2@D=&AI<RT^7V1B;2D["@H@("`@("`@('=H:6QE("@D:60I
M('L*("`@("`@("`@("`@:68@*"1D871A(#T@9&)M9F5T8V@H)'1H:7,M/E]D
M8FTL("1I9"DI('L*("`@("`@("`@("`@("`@("1A9V4@/2!S=6)S='(H)'1M
M<"P@,"P@<W1R<&]S*"1D871A+"`G?"<I*3L*("`@("`@("`@("`@("`@(&EF
M("@D97AP:7)E9"`^("1A9V4I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9&5S=')O>2@D:60I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D:60@/2!D8FUN97AT:V5Y*"1T:&ES+3Y?9&)M
M+"`D:60I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+VQD87`N<&AP````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,#`V-P`Q,#0Q-S,V,C<W,P`P,C(V,3``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%-E<W-I;VY(86YD;&5R(&EM<&QE;65N=&%T:6]N(&9O<B!,1$%0(&1I<F5C
M=&]R:65S+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@
M)V9O;R<@("`@("`@5&AE(&9O;RX*("H*("H@3W!T:6]N86P@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@
M;&1A<"!S97)V97(N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+VQD87`N<&AP+'8@,2XR+C(N,B`R,#`U
M+S$P+S$X(#$Q.C`Q.C(W(&IA;B!%>'`@)`H@*@H@*B!4:&ES(&-O9&4@:7,@
M861A<'1E9"!F<F]M('1H92!C;VUM96YT<R!A=`H@*B!H='1P.B\O=W=W+G!H
M<"YN970O<V5S<VEO;BUS970M<V%V92UH86YD;&5R+@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7U-E
M<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]L9&%P(&5X
M=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@("`@("H@2&%N9&QE
M(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T:6]N+@H@("`@("H*
M("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?8V]N;CL*
M"B`@("`O*BH*("`@("`J($]P96X@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME
M;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V%V95]P871H("`@
M("!4:&4@<&%T:"!T;R!T:&4@<V5S<VEO;B!O8FIE8W0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S97-S:6]N7VYA;64@(%1H92!N86UE(&]F('1H92!S97-S
M:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&]P96XH)'-A=F5?<&%T:"P@)'-E<W-I;VY?;F%M92D*("`@('L*("`@("`@
M("`D=&AI<RT^7V-O;FX@/2!`;&1A<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US
M6R=H;W-T<W!E8R==+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==*3L*("`@("`@
M("!R971U<FX@0&QD87!?8FEN9"@D=&AI<RT^7V-O;FXL("1T:&ES+3Y?<&%R
M86US6R=D;B==+"`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;&]S92@I"B`@("!["B`@("`@("`@<F5T=7)N($!L9&%P7V-L;W-E*"1T
M:&ES+3Y?8V]N;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D
M871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@
M=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@
M("`@("`D<W(@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]C;VYN+"`D=&AI<RT^
M7W!A<F%M<ULG9&XG72P@(BAC;CTD:60I(BD["B`@("`@("`@)&EN9F\@/2!`
M;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V-O;FXL("1S<BD["B`@("`@("`@
M:68@*"1I;F9O6R=C;W5N="==(#X@,"D@>PH@("`@("`@("`@("!R971U<FX@
M)&EN9F];,%U;)W-E<W-I;VXG75LP73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@5W)I=&4@<V5S<VEO;B!D871A('1O('1H92!397-S:6]N2&%N9&QE
M<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@
M("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J($!P87)A
M;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E<W-I;VX@9&%T82X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D
M:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@("`@)'5P9&%T92`](&%R
M<F%Y*"=O8FIE8W1#;&%S<R<@/3X@87)R87DH)W!H<'-E<W-I;VXG+"`G=&]P
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("=S97-S:6]N)R`]/B`D<V5S
M<VEO;E]D871A*3L*("`@("`@("`D9&X@/2`B8VX])&ED+"(@+B`D=&AI<RT^
M7W!A<F%M<ULG9&XG73L*("`@("`@("!`;&1A<%]D96QE=&4H)'1H:7,M/E]C
M;VYN+"`D9&XI.PH@("`@("`@(')E='5R;B!`;&1A<%]A9&0H)'1H:7,M/E]C
M;VYN+"`D9&XL("1U<&1A=&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S
M=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I
M9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED
M96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5S=')O>2@D:60I"B`@("!["B`@("`@("`@)&1N(#T@(F-N/21I
M9"PB("X@)'1H:7,M/E]P87)A;7-;)V1N)UT["B`@("`@("`@<F5T=7)N($!L
M9&%P7V1E;&5T92@D=&AI<RT^7V-O;FXL("1D;BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A
M('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V,H)&UA>&QI9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@("1S
M<B`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V-O;FXL("1T:&ES+3Y?<&%R86US
M6R=D;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G*&]B:F5C=$-L
M87-S/7!H<'-E<W-I;VXI)RP@87)R87DH)RLG+"`G8VXG*2D["B`@("`@("`@
M)&EN9F\@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V-O;FXL("1S<BD[
M"B`@("`@("`@:68@*"1I;F9O6R=C;W5N="==(#X@,"D@>PH@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D:6YF;ULG8V]U;G0G73L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)&ED(#T@)&EN9F];)&E=6R=C;B==6S!=.PH@("`@
M("`@("`@("`@("`@)&1N(#T@(F-N/21I9"PB("X@)'1H:7,M/E]P87)A;7-;
M)V1N)UT["B`@("`@("`@("`@("`@("`D;&1A<'-T86UP(#T@)&EN9F];)&E=
M6R=M;V1I9GET:6UE<W1A;7`G75LP73L*("`@("`@("`@("`@("`@("1Y96%R
M(#T@<W5B<W1R*"1L9&%P<W1A;7`L(#`L(#0I.PH@("`@("`@("`@("`@("`@
M)&UO;G1H(#T@<W5B<W1R*"1L9&%P<W1A;7`L(#0L(#(I.PH@("`@("`@("`@
M("`@("`@)&1A>2`]('-U8G-T<B@D;&1A<'-T86UP+"`V+"`R*3L*("`@("`@
M("`@("`@("`@("1H;W5R(#T@<W5B<W1R*"1L9&%P<W1A;7`L(#@L(#(I.PH@
M("`@("`@("`@("`@("`@)&UI;G5T92`]('-U8G-T<B@D;&1A<'-T86UP+"`Q
M,"P@,BD["B`@("`@("`@("`@("`@("`D;6]D:69I960@/2!G;6UK=&EM92@D
M:&]U<BP@)&UI;G5T92P@,"P@)&UO;G1H+"`D9&%Y+"`D>65A<BD["B`@("`@
M("`@("`@("`@("!I9B`H=&EM92@I("T@)&UO9&EF:65D(#X]("1M87AL:69E
M=&EM92D@>PH@("`@("`@("`@("`@("`@("`@($!L9&%P7V1E;&5T92@D=&AI
M<RT^7V-O;FXL("1D;BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(O;65M8V%C:&5D+G!H<```````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$V,S<T`#$P-#$W,S8R-S<S`#`R,S8P-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@4V5S<VEO;DAA
M;F1L97(Z.B!I;7!L96UE;G1A=&EO;B!F;W(@;65M8V%C:&5D+@H@*B!M96UC
M86-H960@=V5B<VET93H@:'1T<#HO+W=W=RYD86YG82YC;VTO;65M8V%C:&5D
M+PH@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)VAO<W1S
M<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!M96UC86-H960@<V5R=F5R+@H@
M*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@
M=&\@=&AE(&UE;6-A8VAE9"!S97)V97(N/"]P<F4^"B`J"B`J($]P=&EO;F%L
M('!A<F%M971E<G,Z/'!R93X*("H@("`G<&5R<VES=&5N="<@(%5S92!P97)S
M:7-T96YT($1"(&-O;FYE8W1I;VYS/R`H8F]O;&5A;BD*("H@("`G8V]M<')E
M<W-I;VXG(%5S92!C;VUP<F5S<VEO;B!W:&5N('-T;W)I;F<@<V5S<VEO;G,N
M/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+VUE;6-A8VAE9"YP:'`L=B`Q+C@N,BXY(#(P,#8O
M,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U
M+3(P,#8@4F]N9RU%;B!&86X@/')A9F%N0&EN9F]R+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@(%)O;F<M16X@1F%N(#QR869A;D!I;F9O<BYO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95]3
M97-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA;F1L97)?;65M8V%C
M:&5D(&5X=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@("`@("H@
M0W5R<F5N="!M96UC86-H960@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V1B(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R(&]R(&YO
M="!W92=R92!C;VYN96-T960@=&\@=&AE(&UE;6-A8VAE9`H@("`@("H@<V5R
M=F5R+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V
M87(@)%]C;VYN96-T960@/2!F86QS93L*"B`@("`O*BH*("`@("`J($QO8VL@
M:&%N9&QE+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@
M("`@=F%R("1?9G`["@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D
M(#T@9F%L<V4["B`@("`@("`@("`@(&9O<B`H)&D@/2`P+"`D;B`](&-O=6YT
M*"1T:&ES+3Y?9&(I.R`D:2`\("1N.R`K*R1I*2!["B`@("`@("`@("`@("`@
M("!`;65M8V%C:&5?8VQO<V4H)'1H:7,M/E]D8ELD:5TI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W5N;&]C:U-E<W-I;VXH
M*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E860@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT
M:69I97(@9G)O;2!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N
M(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!S97-S:6]N(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED
M*0H@("`@>PH@("`@("`@("\J($]B=&%I;B!S97-S:6]N(&QO8VLN("HO"B`@
M("`@("`@)'1H:7,M/E]L;V-K4V5S<VEO;B@D:60I.PH*("`@("`@("`O*B!-
M86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&UE;6-A8VAE9"!C;VYN96-T:6]N
M+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D8V]N
M(#T@)'1H:7,M/E]G971#;VY&;W))9"@D:60I.PH@("`@("`@("1R97-U;'0@
M/2!`;65M8V%C:&5?9V5T*"1C;VXL("1I9"D["@H@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@
M<F5T<FEE=FEN9R!S97-S:6]N(&1A=&$@*&ED(#T@)R`N("1I9"`N("<I)RP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("`D=&AI<RT^7W5N;&]C:U-E<W-I;VXH*3L*("`@("`@("`@("`@0'5N;&EN
M:R@D=&AI<RT^7W!A<F%M<ULG;&]C:U]D:7(G72`N("<O;&]C:U\G("X@)&ED
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U)E860@<V5S<VEO;B!D871A("AI9"`]
M("<@+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D871A('1O('1H92!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J($!P
M87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E<W-I;VX@9&%T82X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M92@D:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@("`@+RH@36%K92!S
M=7)E('=E(&AA=F4@82!V86QI9"!M96UC86-H960@8V]N;F5C=&EO;BX@*B\*
M("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@)&QI9F5T:6UE
M(#T@:6YI7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH@("`@("`@
M("1F;&%G<R`]("1T:&ES+3Y?<&%R86US6R=C;VUP<F5S<VEO;B==(#\@345-
M0T%#2$5?0T]-4%)%4U-%1"`Z(#`["B`@("`@("`@)&-O;B`]("1T:&ES+3Y?
M9V5T0V]N1F]R260H)&ED*3L*("`@("`@("`D<F5S=6QT(#T@0&UE;6-A8VAE
M7W-E="@D8V]N+"`D:60L("1S97-S:6]N7V1A=&$L("1F;&%G<RP@)&QI9F5T
M:6UE*3L*"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=%<G)O<B!W<FET:6YG('-E<W-I;VX@9&%T82`H
M:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U=R;W1E('-E<W-I;VX@9&%T
M82`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O<B!A('!A<G1I8W5L
M87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@("H@4V5S<VEO;DAA
M;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-T<F]Y*"1I9"D*("`@('L*("`@
M("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&UE;6-A8VAE9"!C
M;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@
M("`@("`D8V]N(#T@)'1H:7,M/E]G971#;VY&;W))9"@D:60I.PH@("`@("`@
M("1R97-U;'0@/2!`;65M8V%C:&5?9&5L971E*"1C;VXL("1I9"D["@H@("`@
M("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G1F%I;&5D('1O(&1E;&5T92!S97-S:6]N("AI9"`]("<@+B`D:60@
M+B`G*2<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G1&5L971E9"!S97-S:6]N(&1A=&$@*&ED(#T@)R`N
M("1I9"`N("<I)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("1T:&ES+3Y?=6YL;V-K4V5S<VEO;B@I.PH@("`@("`@
M($!U;FQI;FLH)'1H:7,M/E]P87)A;7-;)VQO8VM?9&ER)UT@+B`G+VQO8VM?
M)R`N("1I9"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A
M('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V,H)&UA>&QI9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M;W!E;B!A(&-O;FYE8W1I;VX@=&\@=&AE(&UE;6-A8VAE9"!S97)V97(H<RDN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C
M;VYN96-T960I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M
M<RP@)W-E<W-I;VYH86YD;&5R)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=P;W)T)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<V5S<VEO;B!H86YD;&5R(&UE
M;6-A8VAE9"<I.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;
M)W!E<G-I<W1E;G0G72DI('L*("`@("`@("`@("`@)&-O;FYE8W0@/2`G;65M
M8V%C:&5?8V]N;F5C="<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&-O;FYE8W0@/2`G;65M8V%C:&5?<&-O;FYE8W0G.PH@("`@("`@('T*("`@
M("`@("!F;W(@*"1I(#T@,"P@)&X@/2!C;W5N="@D=&AI<RT^7W!A<F%M<ULG
M:&]S='-P96,G72D[("1I(#P@)&X[("LK)&DI('L*("`@("`@("`@("`@:68@
M*"$D8V]N(#T@0"1C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==
M6R1I72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=P;W)T)UU;)&E=*2D@>PH@("`@("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)T-O=6QD(&YO="!C;VYN96-T('1O(&UE;6-A8VAE
M9"!F;W(@;65M8V%C:&5D(%-E<W-I;VY(86YD;&5R(&%T("<@+B`D=&AI<RT^
M7W!A<F%M<ULG:&]S='-P96,G75LD:5T@+B`G.B<@+B`D=&AI<RT^7W!A<F%M
M<ULG<&]R="==6R1I72`L(%]?1DE,15]?+"!?7TQ)3D5?7RQ014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)T-O;FYE8W1E9"!T;R!M96UC86-H960@9F]R(&UE
M;6-A8VAE9"!397-S:6]N2&%N9&QE<B!A="`G("X@)'1H:7,M/E]P87)A;7-;
M)VAO<W1S<&5C)UU;)&E=("X@)SHG("X@)'1H:7,M/E]P87)A;7-;)W!O<G0G
M75LD:5T@+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&);72`]("1C;VX["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=VET8VAE<R!T
M;R!T:&4@<')O<&5R('-E<G9E<B!B87-E9"!O;B!T:&4@<V5S<VEO;FED+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9V5T0V]N1F]R260H)&ED*0H@("`@>PH@("`@("`@("1H87-H0V]D
M92`](&%B<R@H8W)C,S(H)&ED*2`^/B`Q-BD@)B`P>#=F9F8I.PH@("`@("`@
M(&EF("@H)&YS(#T@8V]U;G0H)'1H:7,M/E]D8BDI(#X@,"D@>PH@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@G57-I;F<@8V]N;F5C=&EO;B`G("X@
M*"1H87-H0V]D92`E("1N<RD@+B`G(&9O<B!I9"`]("<@+B`D:60L("!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&);)&AA<VA#;V1E("4@)&YS73L*("`@("`@("!]
M"@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=.;R!C;VYN96-T:6]N<R!A
M=F%I;&%B;&4@9F]R(&UE;6-A8VAE9"!397-S:6]N2&%N9&QE<BXG+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L;V-K4V5S<VEO;B@D:60I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]F<"`]($!F;W!E;B@D=&AI<RT^7W!A<F%M<ULG
M;&]C:U]D:7(G72`N("<O;&]C:U\G("X@)&ED+"`G=RLG*3L*("`@("`@("!I
M9B`H(21T:&ES+3Y?9G`I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)T-O=6QD(&YO="!O<&5N('-E<W-I;VX@;&]C:R!F;W(@)R`N("1I9"P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("@A0&9L;V-K
M*"1T:&ES+3Y?9G`L($Q/0TM?15@I*2!["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=#;W5L9"!N;W0@;&]C:R!S97-S:6]N("<@+B`D:60L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W5N;&]C:U-E<W-I;VXH*0H@("`@>PH@("`@("`@
M(&EF("AI<U]R97-O=7)C92@D=&AI<RT^7V9P*2D@>PH@("`@("`@("`@("!I
M9B`H(4!F;&]C:R@D=&AI<RT^7V9P+"!,3T-+7U5.*2D@>PH@("`@("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T-O=6QD(&YO="!U;FQO8VL@<V5S
M<VEO;B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!`9F-L;W-E*"1T:&ES+3Y?9G`I.PH@
M("`@("`@('T*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]3
M97-S:6]N2&%N9&QE<B]M>7-Q;"YP:'``````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,C0R,30`,3`T,3<S-C(W-S,`,#(S,#,T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!397-S:6]N
M2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N(&9O<B!->5-13"`H;F%T:79E*2X*
M("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=H;W-T<W!E
M8R<@("`M(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@
M*B`@("=P<F]T;V-O;"<@("`M(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L
M("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`G=7-E<FYA;64G("`@+2!4
M:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S92X*("H@("`G<&%S<W=O<F0G("`@+2!4:&4@<&%S<W=O<F0@87-S;V-I
M871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V1A=&%B87-E)R`@("T@5&AE
M(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=T86)L92<@("`@("`M(%1H
M92!N86UE(&]F('1H92!S97-S:6]N9&%T82!T86)L92!I;B`G9&%T86)A<V4G
M+@H@*B`@("=R;W=L;V-K:6YG)R`M(%=H971H97(@=&\@=7-E(')O=RUL979E
M;"!L;V-K:6YG(&%N9"!T<F%N<V%C=&EO;G,@*$EN;F]$0BD*("H@("`@("`@
M("`@("`@("`@("!O<B!T86)L92UL979E;"!L;V-K:6YG("A->4E304TI+CPO
M<')E/@H@*@H@*B!297%U:7)E9"!F;W(@<V]M92!C;VYF:6=U<F%T:6]N<SH\
M<')E/@H@*B`@("=P;W)T)R`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C
M="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M
M971E<G,Z/'!R93X*("H@("`G<&5R<VES=&5N="<@(%5S92!P97)S:7-T96YT
M($1"(&-O;FYE8W1I;VYS/R`H8F]O;&5A;BD\+W!R93X*("H*("H@5&AE('1A
M8FQE('-T<G5C='5R92!F;W(@=&AE(%-E<W-I;VY(86YD;&5R(&-A;B!B92!F
M;W5N9"!I;@H@*B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N
M9&QE<BYS<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+VUY<W%L+G!H<"QV(#$N,38N,3(N,3,@,C`P
M-B\P,R\R-2`P,#HQ.3HT,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-B!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R
M"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]M>7-Q;"!E>'1E;F1S(%-E<W-I
M;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U
M<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R
M(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@
M("H@07)E('=E(&-O;FYE8W1E9"!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C
M=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@1&ES8V]N
M;F5C="!F<F]M(&1A=&%B87-E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V-O
M;FYE8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A
M;'-E.PH@("`@("`@("`@("!R971U<FX@0&UY<W%L7V-L;W-E*"1T:&ES+3Y?
M9&(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@
M<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96%D*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@
M:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J(%-E<W-I;VX@=&EM96]U
M="P@9&]N)W0@<F5L>2!O;B!G87)B86=E(&-O;&QE8W1I;VXN("HO"B`@("`@
M("`@)'1I;65O=70@/2!T:6UE*"D@+2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA
M>&QI9F5T:6UE)RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#
M5"!S97-S:6]N7V1A=&$@1E)/32`E<R!72$5212!S97-S:6]N7VED(#T@)7,G
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("<@04Y$('-E<W-I;VY?;&%S
M=&UO9&EF:65D(#X@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W%U;W1E*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&EM96]U="D["@H@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<F]W
M;&]C:VEN9R==*2!["B`@("`@("`@("`@("\J(%-T87)T(&$@=')A;G-A8W1I
M;VXN("HO"B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)U-4
M05)4(%1204Y304-424].)RP@)'1H:7,M/E]D8BD["B`@("`@("`@("`@("1Q
M=65R>2`N/2`G($9/4B!54$1!5$4G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)TQ/0TL@5$%"3$53("<@
M+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N("<@5U))5$4G+"`D=&AI<RT^
M7V1B*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@
M("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("\J($QO9R!T
M:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(
M86YD;&5R7VUY<W%L.CIR96%D*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?
M<75E<GDH)'%U97)Y+"`D=&AI<RT^7V1B*3L*("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R(')E
M=')I979I;F<@<V5S<VEO;B!D871A("AI9"`]("<@+B`D:60@+B`G*2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N($!M>7-Q;%]R97-U;'0H)')E<W5L="P@
M,"P@,"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A
M=&$@=&\@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I
M9&5N=&EF:65R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A
M("!4:&4@<V5S<VEO;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=R:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@
M('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B
M87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@G4D503$%#12!)3E1/("5S("AS97-S:6]N7VED
M+"!S97-S:6]N7V1A=&$L('-E<W-I;VY?;&%S=&UO9&EF:65D*2<@+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@)R!604Q515,@*"5S+"`E<RP@)7,I)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92@D
M:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92@D
M<V5S<VEO;E]D871A*2P*("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H
M*2D["@H@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)'%U97)Y+"`D
M=&AI<RT^7V1B*3L*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R86US6R=R;W=L
M;V-K:6YG)UTI('L*("`@("`@("`@("`@0&UY<W%L7W%U97)Y*"=53DQ/0TL@
M5$%"3$53("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/E]D
M8BD["B`@("`@("`@?0H@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@
M("`@("!`;7ES<6Q?<75E<GDH)U)/3$Q"04-+)RP@)'1H:7,M/E]D8BD["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!W<FET:6YG('-E
M<W-I;VX@9&%T82<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@0&UY<W%L7W%U97)Y*"=#3TU-250G+"`D=&AI<RT^7V1B*3L*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y
M('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R
M(&EN('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I
M9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D97-T<F]Y*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@
M:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@
M<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($92
M3TT@)7,@5TA%4D4@<V5S<VEO;E]I9"`]("5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`D=&AI<RT^7W%U
M;W1E*"1I9"DI.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"
M54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P
M<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]M>7-Q;#HZ9&5S
M=')O>2@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@
M("`D<F5S=6QT(#T@0&UY<W%L7W%U97)Y*"1Q=65R>2P@)'1H:7,M/E]D8BD[
M"B`@("`@("`@:68@*"$D=&AI<RT^7W!A<F%M<ULG<F]W;&]C:VEN9R==*2![
M"B`@("`@("`@("`@($!M>7-Q;%]Q=65R>2@G54Y,3T-+(%1!0DQ%4R`G("X@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL("1T:&ES+3Y?9&(I.PH@("`@("`@
M('T*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@0&UY<W%L
M7W%U97)Y*"=23TQ,0D%#2R<L("1T:&ES+3Y?9&(I.PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G1F%I;&5D('1O(&1E;&5T92!S97-S:6]N("AI
M9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@0&UY<W%L7W%U97)Y*"=#3TU-250G+"`D=&AI<RT^7V1B*3L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A('-E<W-I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V,H
M)&UA>&QI9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R
M92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@
M("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE
M(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%
M5$4@1E)/32`E<R!72$5212!S97-S:6]N7VQA<W1M;V1I9FEE9"`\("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+"`H:6YT*2AT:6UE*"D@+2`D;6%X;&EF971I;64I*3L*"B`@("`@("`@
M+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@
M4V5S<VEO;DAA;F1L97)?;7ES<6PZ.F=C*"DZ('%U97)Y(#T@(B5S(B<L("1Q
M=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@
M=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH
M)'%U97)Y+"`D=&AI<RT^7V1B*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R(&=A<F)A9V4@
M8V]L;&5C=&EN9R!O;&0@<V5S<VEO;G,G+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!`;7ES<6Q?869F96-T961?<F]W<R@D
M=&AI<RT^7V1B*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@
M;V8@=&AE('9A;&ED('-E<W-I;VX@:61E;G1I9FEE<G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F('9A;&ED('-E<W-I;VX@:61E
M;G1I9FEE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<W-I;VY)1',H
M*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@
M9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE
M8W0H*3L*"B`@("`@("`@+RH@4V5S<VEO;B!T:6UE;W5T+"!D;VXG="!R96QY
M(&]N(&=A<F)A9V4@8V]L;&5C=&EO;B`J+PH@("`@("`@("1T:6UE;W5T(#T@
M=&EM92@I("T@:6YI7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@<V5S<VEO;E]I9"!&
M4D]-("5S)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`G(%=(15)%('-E
M<W-I;VY?;&%S=&UO9&EF:65D(#X@)7,G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&EM96]U="D["@H@("`@("`@("\J($QO9R!T:&4@<75E
M<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R
M7VUY<W%L.CIG971397-S:6]N241S*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R
M>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2!`;7ES
M<6Q?<75E<GDH)'%U97)Y+"`D=&AI<RT^7V1B*3L*("`@("`@("!I9B`H(21R
M97-U;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R
M(&=E='1I;F<@<V5S<VEO;B!)1',G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1S
M97-S:6]N<R`](&%R<F%Y*"D["@H@("`@("`@('=H:6QE("@D<F]W(#T@;7ES
M<6Q?9F5T8VA?<F]W*"1R97-U;'0I*0H@("`@("`@("`@("`D<V5S<VEO;G-;
M72`]("1R;W=;,%T["@H@("`@("`@(')E='5R;B`D<V5S<VEO;G,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!%<V-A<&4@82!M>7-Q;"!S=')I;F<N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=F%L=64@(%1H92!S=')I;F<@=&\@<75O=&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!Q=6]T960@<W1R:6YG+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<75O=&4H)'9A;'5E*0H@("`@>PH@("`@("`@
M('-W:71C:"`H<W1R=&]L;W=E<BAG971T>7!E*"1V86QU92DI*2!["B`@("`@
M("`@8V%S92`G;G5L;"<Z"B`@("`@("`@("`@(')E='5R;B`G3E5,3"<["@H@
M("`@("`@(&-A<V4@)VEN=&5G97(G.@H@("`@("`@("`@("!R971U<FX@)'9A
M;'5E.PH*("`@("`@("!C87-E("=S=')I;F<G.@H@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@(')E='5R;B`B)R(@+B!`;7ES<6Q?<F5A;%]E<V-A<&5?
M<W1R:6YG*"1V86QU92P@)'1H:7,M/E]D8BD@+B`B)R(["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A(&-O;FYE
M8W1I;VX@=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.F%S<V5R=$1R
M:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@)W-E<W-I;VYH86YD;&5R)RP*
M("`@("`@("`@("`@87)R87DH)VAO<W1S<&5C)RP@)W5S97)N86UE)RP@)V1A
M=&%B87-E)RDL"B`@("`@("`@("`@("=S97-S:6]N(&AA;F1L97(@37E344PG
M*3L*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R
M9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G
M72`]("<G.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=T86)L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72`]("=H;W)D95]S97-S:6]N:&%N9&QE<B<["B`@("`@("`@
M?0H*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E
M;G0G72DI('L*("`@("`@("`@("`@)&-O;FYE8W0@/2`G;7ES<6Q?8V]N;F5C
M="<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;FYE8W0@/2`G
M;7ES<6Q?<&-O;FYE8W0G.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI
M<RT^7V1B(#T@0"1C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*"=#;W5L
M9"!N;W0@8V]N;F5C="!T;R!D871A8F%S92!F;W(@4U%,(%-E<W-I;VY(86YD
M;&5R+B<I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%`;7ES<6Q?<V5L96-T7V1B*"1T:&ES+3Y?<&%R86US6R=D871A
M8F%S92==+"`D=&AI<RT^7V1B*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=#;W5L9"!N;W0@8V]N;F5C
M="!T;R!T86)L92`E<R!F;W(@4U%,(%-E<W-I;VY(86YD;&5R+B<L("1T:&ES
M+3Y?<&%R86US6R=D871A8F%S92==*2P@7U]&24Q%7U\L(%]?3$E.15]?*2D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S4R,@`Q,#0Q-S,V,C<W,P`P,C(V,C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%-E<W-I;VY(86YD;&5R(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G
M<R!B=6EL="UI;B!S97-S:6]N(&AA;F1L97(N"B`J"B`J(%)E<75I<F5D('!A
M<F%M971E<G,Z/'!R93X*("H@("!.;VYE+CPO<')E/@H@*@H@*B!/<'1I;VYA
M;"!P87)A;65T97)S.CQP<F4^"B`J("`@3F]N92X\+W!R93X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O
M;F]N92YP:'`L=B`Q+C,N,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z,S0@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@36%T="!396QS:WD@/'-E
M;'-K>4!C;VQU;6)I82YE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R
M"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]N;VYE(&5X=&5N9',@4V5S<VEO
M;DAA;F1L97(@>PH*("`@("\J*@H@("`@("H@4F5A9"!T:&4@9&%T82!F;W(@
M82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H90H@("`@
M("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D:60I"B`@("!["B`@("`@("`@)&9I
M;&4@/2!S97-S:6]N7W-A=F5?<&%T:"@I("X@1$E214-43U)97U-%4$%2051/
M4B`N("=S97-S7R<@+B`D:60["@H@("`@("`@("1S97-S:6]N7V1A=&$@/2!`
M9FEL95]G971?8V]N=&5N=',H)&9I;&4I.PH@("`@("`@(&EF("@D<V5S<VEO
M;E]D871A(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B*2`N("1F:6QE
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<V5S<VEO;E]D871A.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!T:&4@=F%L:60@
M<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!(&QI<W0@;V8@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4V5S<VEO;DE$<R@I"B`@("!["B`@("`@
M("`@)'-E<W-I;VYS(#T@87)R87DH*3L*"B`@("`@("`@)'!A=&@@/2!S97-S
M:6]N7W-A=F5?<&%T:"@I.PH@("`@("`@("1D(#T@9&ER*&5M<'1Y*"1P871H
M*2`_(%5T:6PZ.F=E=%1E;7!$:7(H*2`Z("1P871H*3L*"B`@("`@("`@=VAI
M;&4@*&9A;'-E("$]/2`H)&5N=')Y(#T@)&0M/G)E860H*2DI('L*("`@("`@
M("`@("`@+RH@36%K92!S=7)E('=E)W)E(&1E86QI;F<@=VET:"!F:6QE<R!T
M:&%T('-T87)T('=I=&@*("`@("`@("`@("`@("H@<V5S<U\N("HO"B`@("`@
M("`@("`@(&EF("AI<U]F:6QE*"1D+3YP871H("X@1$E214-43U)97U-%4$%2
M051/4B`N("1E;G1R>2D@)B8*("`@("`@("`@("`@("`@("%S=')N8VUP*"1E
M;G1R>2P@)W-E<W-?)RP@<W1R;&5N*"=S97-S7R<I*2D@>PH@("`@("`@("`@
M("`@("`@)'-E<W-I;VYS6UT@/2!S=6)S='(H)&5N=')Y+"!S=')L96XH)W-E
M<W-?)RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'-E<W-I;VYS.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]397-S:6]N2&%N9&QE<B]O8VDX+G!H<```````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C0P,S(`,3`T,3<S-C(W-S,`,#(R-3(W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N(&9O<B!/<F%C;&4@
M.&D@*&YA=&EV92DN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*
M("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E
M('-E<G9E<BX*("H@("`G<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P
M<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@)W5S97)N86UE
M)R`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@
M9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C
M:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("=D871A8F%S92<@(%1H92!N
M86UE(&]F('1H92!D871A8F%S92X*("H@("`G=&%B;&4G("`@("!4:&4@;F%M
M92!O9B!T:&4@<V5S<VEO;F1A=&$@=&%B;&4@:6X@)V1A=&%B87-E)RX\+W!R
M93X*("H*("H@4F5Q=6ER960@9F]R('-O;64@8V]N9FEG=7)A=&EO;G,Z/'!R
M93X*("H@("`G<&]R="<@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)W!E<G-I<W1E;G0G("!5<V4@<&5R<VES=&5N="!$
M0B!C;VYN96-T:6]N<S\@*&)O;VQE86XI/"]P<F4^"B`J"B`J(%1H92!T86)L
M92!S=')U8W1U<F4@9F]R('1H92!397-S:6]N2&%N9&QE<B!C86X@8F4@9F]U
M;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L
M97(N;V-I."YS<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+V]C:3@N<&AP+'8@,2XX+C0N,3$@,C`P
M-B\P,B\Q,"`Q.#HT-CHU,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!,:6%M($AO96ME;F=A(#QL:6%M<D!U;6EC:"YE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!,:6%M($AO96ME;F=A(#QL:6%M<D!U
M;6EC:"YE9'4^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(
M;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA;F1L97)?
M;V-I."!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J
M($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*
M("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D
M7V1B.PH*("`@("\J*@H@("`@("H@07)E('=E(&-O;FYE8W1E9"!T;R!T:&4@
M4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@
M*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R
M;B!/0TE,;V=/9F8H)'1H:7,M/E]D8BD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E860@=&AE(&1A
M=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@9G)O;2!T
M:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97-S:6]N(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED*0H@("`@>PH@("`@
M("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N
M;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@
M("`@)'-E;&5C=%]Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A
M=&$@1E)/32`E<R!72$5212!S97-S:6]N7VED(#T@)7,@1D]2(%501$%412<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTL("1T:&ES+3Y?<75O=&4H)&ED*2D["@H@("`@("`@("\J
M($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E
M<W-I;VY(86YD;&5R7V]C:3@Z.G)E860H*3H@<75E<GD@/2`B)7,B)RP@)'-E
M;&5C=%]Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X
M96-U=&4@<75E<GD@*B\*("`@("`@("`D<V5L96-T7W-T871E;65N="`]($]#
M25!A<G-E*"1T:&ES+3Y?9&(L("1S96QE8W1?<75E<GDI.PH@("`@("`@($]#
M245X96-U=&4H)'-E;&5C=%]S=&%T96UE;G0I.PH@("`@("`@(&EF("@A3T-)
M1F5T8VA);G1O*"1S96QE8W1?<W1A=&5M96YT+"`D<F5S=6QT*2D@>PH@("`@
M("`@("`@("`D:6YS97)T7W%U97)Y(#T@<W!R:6YT9B@G24Y315)4($E.5$\@
M)7,@*'-E<W-I;VY?:60L('-E<W-I;VY?;&%S=&UO9&EF:65D+"!S97-S:6]N
M7V1A=&$I(%9!3%5%4R`H)7,L("5S+"!%35!465]"3$]"*"DI(%)%5%523DE.
M1R!S97-S:6]N7V1A=&$@24Y43R`Z8FQO8B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W%U
M;W1E*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<75O=&4H=&EM92@I*2D["B`@("`@("`@("`@("1I;G-E<G1?
M<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BP@)&EN<V5R=%]Q=65R
M>2D["B`@("`@("`@("`@("1L;V(@/2!/0TE.97=$97-C<FEP=&]R*"1T:&ES
M+3Y?9&(I.PH@("`@("`@("`@("!/0TE":6YD0GE.86UE*"1I;G-E<G1?<W1A
M=&5M96YT+"`G.F)L;V(G+"`D;&]B+"`M,2P@4U%,5%]"3$]"*3L*("`@("`@
M("`@("`@3T-)17AE8W5T92@D:6YS97)T7W-T871E;65N="P@3T-)7T1%1D%5
M3%0I.PH@("`@("`@("`@("!I9B`H)'-E<W-I;VY?9&%T82D@>PH@("`@("`@
M("`@("`@("`@)&QO8BT^<V%V92@D<V5S<VEO;E]D871A*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET*"1T:&ES+3Y?
M9&(I.PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1I;G-E<G1?<W1A
M=&5M96YT*3L*("`@("`@("`@("`@3T-)17AE8W5T92@D<V5L96-T7W-T871E
M;65N="D["B`@("`@("`@("`@($]#249E=&-H26YT;R@D<V5L96-T7W-T871E
M;65N="P@)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1V86QU92`]("1R
M97-U;'1;,%TM/FQO860H*3L*("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S
M96QE8W1?<W1A=&5M96YT*3L*("`@("`@("!R971U<FXH)'9A;'5E*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@9&%T82!T;R!T:&4@
M4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9"`@("`@("`@("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S
M:6]N(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=W)I=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@
M("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C
M=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@
M+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S
M<')I;G1F*"=54$1!5$4@)7,@4T54('-E<W-I;VY?;&%S=&UO9&EF:65D(#T@
M)7,L('-E<W-I;VY?9&%T82`]($5-4%197T),3T(H*2!72$5212!S97-S:6]N
M7VED(#T@)7,@4D5455).24Y'('-E<W-I;VY?9&%T82!)3E1/(#IB;&]B)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92AT
M:6UE*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]Q=6]T
M92@D:60I*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'
M(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I
M;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ=W)I=&4H
M*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@+RH@17AE8W5T92!Q=65R>2`J+PH@("`@("`@("1S=&%T96UE
M;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+"`D<75E<GDI.PH@("`@("`@("1L
M;V(@/2!/0TE.97=$97-C<FEP=&]R*"1T:&ES+3Y?9&(I.PH@("`@("`@($]#
M24)I;F1">4YA;64H)'-T871E;65N="P@)SIB;&]B)RP@)&QO8BP@+3$L(%-1
M3%1?0DQ/0BD["B`@("`@("`@3T-)17AE8W5T92@D<W1A=&5M96YT+"!/0TE?
M1$5&055,5"D["B`@("`@("`@:68@*"1S97-S:6]N7V1A=&$I('L*("`@("`@
M("`@("`@)&QO8BT^<V%V92@D<V5S<VEO;E]D871A*3L*("`@("`@("!]"B`@
M("`@("`@)')E<W5L="`]($]#24-O;6UI="@D=&AI<RT^7V1B*3L*("`@("`@
M("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)T5R<F]R('=R:71I;F<@<V5S<VEO;B!D871A)RP@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E<W1R;WD@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA
M<B!S97-S:6]N(&ED96YT:69I97(@:6X@=&AE"B`@("`@*B!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<W1R;WDH)&ED*0H@("`@>PH@("`@
M("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N
M;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@
M("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@
M/2!S<')I;G1F*"`G1$5,151%($923TT@)7,@5TA%4D4@<V5S<VEO;E]I9"`]
M("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P@)'1H:7,M/E]Q=6]T92@D:60I*3L*"B`@("`@("`@+RH@
M3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S
M<VEO;DAA;F1L97)?;V-I.#HZ9&5S=')O>2@I.B!Q=65R>2`]("(E<R(G+"`D
M<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E
M('1H92!Q=65R>2X@*B\*("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H
M)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("`D<F5S=6QT(#T@3T-)17AE
M8W5T92@D<W1A=&5M96YT*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@
M("`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!D96QE=&4@<V5S
M<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A('-E<W-I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V,H
M)&UA>&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@
M=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@
M("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!3
M44P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%
M($923TT@)7,@5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@/"`E<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72P@)'1H:7,M/E]Q=6]T92AT:6UE*"D@+2`D;6%X;&EF971I;64I*3L*"B`@
M("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@
M*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E
M<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ9V,H*3H@<75E<GD@/2`B)7,B
M)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE
M8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)'-T871E;65N="`]($]#25!A
M<G-E*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@)')E<W5L="`]($]#
M245X96-U=&4H)'-T871E;65N="D["B`@("`@("`@:68@*"$D<F5S=6QT*2![
M"B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!G87)B86=E(&-O
M;&QE8W1I;F<@;VQD('-E<W-I;VYS)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T96UE;G0I.PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&$@;&ES="!O9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@=F%L:60@<V5S
M<VEO;B!I9&5N=&EF:65R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5S
M<VEO;DE$<R@I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@
M82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES
M+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!397-S:6]N('1I;65O=70L(&1O
M;B=T(')E;'D@;VX@9V%R8F%G92!C;VQL96-T:6]N("HO"B`@("`@("`@)'1I
M;65O=70@/2!T:6UE*"D@+2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T
M:6UE)RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S
M:6]N7VED($923TT@)7,G("X*("`@("`@("`@("`@("`@("`@("`@("`@("<@
M5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@/B`E<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:6UE;W5T*3L*"B`@("`@("`@+RH@3&]G
M('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO
M;DAA;F1L97)?;V-I.#HZ9V5T4V5S<VEO;DE$<R@I.B!Q=65R>2`]("(E<R(G
M+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C
M=71E('%U97)Y("HO"B`@("`@("`@)'-T871E;65N="`]($]#25!A<G-E*"1T
M:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@3T-)17AE8W5T92@D<W1A=&5M
M96YT*3L*"B`@("`@("`@)'-E<W-I;VYS(#T@87)R87DH*3L*("`@("`@("!W
M:&EL92`H3T-)1F5T8VA);G1O*"1S=&%T96UE;G0L("1R;W<I*2!["B`@("`@
M("`@("`@("1S97-S:6]N<UM=(#T@)')O=ULP73L*("`@("`@("!]"@H@("`@
M("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@("`@("`@<F5T
M=7)N("1S97-S:6]N<SL*("`@('T*"B`@("`O*BH*("`@("`J($5S8V%P92!A
M('-T<FEN9R!F;W(@:6YS97)T:6]N+B!3=&]L96X@9G)O;2!014%2.CI$0BX*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'9A;'5E("!4:&4@<W1R:6YG('1O('%U;W1E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<75O=&5D('-T<FEN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W%U;W1E*"1V86QU92D*("`@('L*("`@("`@("!R
M971U<FX@*"1V86QU92`]/3T@;G5L;"D@/R`G3E5,3"<@.B`B)R(@+B!S=')?
M<F5P;&%C92@B)R(L("(G)R(L("1V86QU92D@+B`B)R(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N;F5C=&EO;B!T;R!T
M:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG
M*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@("`@
M("!A<G)A>2@G:&]S='-P96,G+"`G=7-E<FYA;64G+"`G<&%S<W=O<F0G*2P*
M("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!/<F%C;&4G*3L*"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G:&]R9&5?<V5S
M<VEO;FAA;F1L97(G.PH@("`@("`@('T*"B`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G;V-I7V-O;FYE8W0G*2D@>PH@("`@("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI('L*("`@("`@("`@
M("`@("`@("1C;VYN96-T(#T@)V]C:5]C;VYN96-T)SL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;VYN96-T(#T@)V]C:5]P8V]N
M;F5C="<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI
M('L*("`@("`@("`@("`@("`@("1C;VYN96-T(#T@)T]#24QO9V]N)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;VYN96-T(#T@
M)T]#25!,;V=O;B<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/E]D8B`]($`D8V]N;F5C="@D=&AI
M<RT^7W!A<F%M<ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A
M<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2DI('L*
M("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H)T-O
M=6QD(&YO="!C;VYN96-T('1O(&1A=&%B87-E(&9O<B!344P@4V5S<VEO;DAA
M;F1L97(N)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+W!G<W%L+G!H
M<``````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-S8U,0`Q,#0Q-S,V,C<W,P`P
M,C,P,C4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%!O<W1G<F5344P@4V5S<VEO;B!(86YD;&5R(&9O
M<B!02%`@*&YA=&EV92DN"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@2F]N
M(%!A<FES92`\:F]N0&-S:"YR:70N961U/BX@($%L;"!R:6=H=',@<F5S97)V
M960N"B`J"B`J("!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@(&UO9&EF:6-A
M=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I
M;F<@8V]N9&ET:6]N<PH@*B`@87)E(&UE=#H*("H@(#$N(%)E9&ES=')I8G5T
M:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P
M>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J("`R+B!2961I<W1R
M:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B
M;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H90H@
M*B`@("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R
M;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H*("H@(%1(25,@4T]&
M5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($%55$A/4B!!3D0@0T].5%))0E54
M3U)3(&!@05,@25,G)R!!3D0*("H@($%.62!%6%!215-3($]2($E-4$Q)140@
M5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(
M10H@*B`@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!
M3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@($%212!$
M25-#3$%)345$+B`@24X@3D\@159%3E0@4TA!3$P@5$A%($%55$A/4B!/4B!#
M3TY44DE"551/4E,@0D4@3$E!0DQ%"B`J("!&3U(@04Y9($1)4D5#5"P@24Y$
M25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(@0T].
M4T51545.5$E!3`H@*B`@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)
M34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,*("H@
M($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@
M3U(@0E5324Y%4U,@24Y415)255!424].*0H@*B`@2$]7159%4B!#0553140@
M04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/
M3E1204-4+"!35%))0U0*("H@($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!7
M05D*("H@($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@
M248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8*("H@(%-50T@@1$%-
M04=%+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V1A
M=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S
M=V]R9"<@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE
M)RX*("H@("`G<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O
M;"`H)W1C<"<L("=U;FEX)RDN"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N
M86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J
M"B`J(%)E<75I<F5D(&9O<B!S;VUE(&-O;F9I9W5R871I;VYS("AI+F4N("=P
M<F]T;V-O;"<@/2`G=&-P)RDZ/'!R93X*("H@("`G:&]S='-P96,G("!4:&4@
M:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G<&]R="<@
M("`@("!4:&4@<&]R="!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S92X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@
M*B`@("=P97)S:7-T96YT)R`@57-E('!E<G-I<W1E;G0@1$(@8V]N;F5C=&EO
M;G,_("AB;V]L96%N*0H@*B`@("`@("`@("`@("`@("`@1&5F875L=#H@3D\*
M("H@("`G=&%B;&4G("`@("`@(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T
M82!T86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@("`@("`@1&5F
M875L=#H@)VAO<F1E7W-E<W-I;VYH86YD;&5R)SPO<')E/@H@*@H@*B!4:&4@
M=&%B;&4@<W1R=6-T=7)E(&9O<B!T:&4@4V5S<VEO;DAA;F1L97(@8V%N(&)E
M(&9O=6YD(&EN"B`J(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH
M86YD;&5R+G!G<W%L+G-Q;"X*("H*("H@0V]N=')I8G5T;W)S.CQP<F4^"B`J
M("!*87-O;B!#87)L<V]N("`@("`@("`@("!2971U<FX@86X@96UP='D@<W1R
M:6YG(&]N(&9A:6QE9"!R96%D<PH@*B`@<&%T0'!C<')O9W)A;6UE<BYC;VT@
M("`@4&5R9F]R;2!U<&1A=&4@:6X@82!S:6YG;&4@=')A;G-A8W1I;VX*("H@
M($IO;F%T:&%N($-R;VUP=&]N("`@("`@($QO8VL@<F]W(&9O<B!L:69E(&]F
M('-E<W-I;VX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O<&=S<6PN<&AP+'8@,2XQ,BXQ,"XQ
M-2`R,#`V+S`S+S(S(#$X.C`P.C$W(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R
M("!*;VX@4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*
M8VQA<W,@4V5S<VEO;DAA;F1L97)?<&=S<6P@97AT96YD<R!397-S:6]N2&%N
M9&QE<B!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT
M(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!R97-O
M=7)C90H@("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J($%R
M92!W92!C;VYN96-T960@=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`]
M(&9A;'-E.PH*("`@("\J*@H@("`@("H@0VQO<V4@=&AE(%-E<W-I;VY(86YD
M;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@("\J($1I<V-O;FYE8W0@
M9G)O;2!D871A8F%S92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T
M960I('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!F86QS93L*
M("`@("`@("`@("`@<F5T=7)N($!P9U]C;&]S92@D=&AI<RT^7V1B*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@
M:61E;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E
M<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9"@D:60I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V
M86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?
M8V]N;F5C="@I.PH*("`@("`@("!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)T)%
M1TE..R<I.PH*("`@("`@("`D=&EM96]U="`]('1I;64H*2`M(&EN:5]G970H
M)W-E<W-I;VXN9V-?;6%X;&EF971I;64G*3L*("`@("`@("`D<75E<GD@/2!S
M<')I;G1F*"=314Q%0U0@<V5S<VEO;E]D871A($923TT@)7,@5TA%4D4@)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G<V5S<VEO;E]I9"`]("5S($%.
M1"!S97-S:6]N7VQA<W1M;V1I9FEE9"`^/2`E<R`G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("=&3U(@55!$051%.R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YQ=6]T92@D:60I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1I;65O=70I.PH*("`@("`@("`O*B!,;V<@=&AE('%U
M97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE
M<E]P9W-Q;#HZ)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F5A9"@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y*"1T:&ES+3Y?
M9&(L("1Q=65R>2D["B`@("`@("`@)&1A=&$@/2!P9U]F971C:%]R97-U;'0H
M)')E<W5L="P@,"P@)W-E<W-I;VY?9&%T82<I.PH@("`@("`@('!G7V9R965?
M<F5S=6QT*"1R97-U;'0I.PH*("`@("`@("!R971U<FX@<&%C:R@G2"HG+"`D
M9&%T82D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A
M=&$@=&\@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I
M9&5N=&EF:65R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A
M("!4:&4@<V5S<VEO;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=R:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@
M('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B
M87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("1T:6UE;W5T(#T@=&EM92@I("T@:6YI7V=E="@G<V5S<VEO
M;BYG8U]M87AL:69E=&EM92<I.PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/32`E<R!72$5212`G("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("=S97-S:6]N7VED(#T@)7,@04Y$('-E<W-I
M;VY?;&%S=&UO9&EF:65D(#X]("5S("<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@)T9/4B!54$1!5$4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<75O=&4H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:6UE;W5T*3L*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y*"1T
M:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@)')O=W,@/2!P9U]N=6U?<F]W
M<R@D<F5S=6QT*3L*("`@("`@("!P9U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*
M"B`@("`@("`@:68@*"1R;W=S(#T](#`I('L*("`@("`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*'-E<W-I;VY?:60L("<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S97-S:6]N7VQA<W1M;V1I
M9FEE9"P@<V5S<VEO;E]D871A*2`G("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G5D%,5453("@E<RP@)7,L("5S*3LG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T92@D:60I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H8FEN,FAE>"@D<V5S
M<VEO;E]D871A*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)U501$%412`E<R!3150@<V5S<VEO;E]L87-T;6]D
M:69I960@/2`E<RP@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W-E<W-I;VY?9&%T82`]("5S(%=(15)%('-E<W-I;VY?:60@/2`E<SLG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H8FEN
M,FAE>"@D<V5S<VEO;E]D871A*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G%U;W1E*"1I9"DI.PH@("`@("`@('T*"B`@("`@("`@
M+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@
M4V5S<VEO;DAA;F1L97)?<&=S<6PZ.B<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W=R:71E*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R
M>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2!`<&=?
M<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R('=R
M:71I;F<@<V5S<VEO;B!D871A.B`G("X@<&=?;&%S=%]E<G)O<B@D=&AI<RT^
M7V1B*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1R;W=S
M(#T@<&=?869F96-T961?<F]W<R@D<F5S=6QT*3L*("`@("`@("!P9U]F<F5E
M7W)E<W5L="@D<F5S=6QT*3L*"B`@("`@("`@0'!G7W%U97)Y*"1T:&ES+3Y?
M9&(L("=#3TU-250[)RD["@H@("`@("`@(&EF("@D<F]W<R`A/2`Q*2!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!W<FET:6YG('-E
M<W-I;VX@9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O<B!A
M('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@("H@
M4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-T<F]Y*"1I9"D*
M("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A
M=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T
M*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@<V5S
M<VEO;E]I9"`]("5S.R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/G%U;W1E*"1I9"DI.PH*("`@
M("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J
M+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R
M>2!B>2!397-S:6]N2&%N9&QE<E]P9W-Q;#HZ)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5S=')O>2@I.B!Q=65R>2`]("(E<R(G
M+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C
M=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y
M*"1T:&ES+3Y?9&(L("1Q=65R>2D["@H@("`@("`@($!P9U]Q=65R>2@D=&AI
M<RT^7V1B+"`G0T]-34E4.R<I.PH*("`@("`@("!I9B`H(21R97-U;'0I('L*
M("`@("`@("`@("`@<&=?9G)E95]R97-U;'0H)')E<W5L="D["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=&86EL960@=&\@9&5L971E('-E<W-I
M;VX@*&ED(#T@)R`N("1I9"`N("<I)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!P
M9U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!S=&%L92!S
M97-S:6]N<R!F<F]M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AL:69E=&EM92`@5&AE(&UA
M>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X;&EF971I;64@/2`S,#`I"B`@
M("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A
M8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I
M.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('-E<W-I
M;VY?;&%S=&UO9&EF:65D(#P@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<75O=&4H=&EM92@I("T@)&UA>&QI9F5T:6UE*2D[
M"@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V
M96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,
M(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W!G<W%L.CHG("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=G8R@I.B!Q=65R>2`]("(E<R(G
M+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C
M=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y
M*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@:68@*"$D<F5S=6QT*2![
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!G87)B86=E
M(&-O;&QE8W1I;F<@;VQD('-E<W-I;VYS)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@('T*"B`@("`@("`@<&=?9G)E95]R97-U;'0H)')E<W5L="D[
M"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%<V-A<&4@82!S=')I;F<@9F]R(&EN<V5R=&EO;B!I;G1O('1H92!D871A
M8F%S92X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;'5E("!4:&4@<W1R:6YG('1O('%U;W1E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<75O=&5D('-T<FEN9RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&4H)'9A;'5E*0H@("`@>PH@("`@
M("`@(')E='5R;B`B)R(@+B!A9&1S;&%S:&5S*"1V86QU92D@+B`B)R(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H92!V86QI9"!S
M97-S:6]N(&ED96YT:69I97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($$@;&ES="!O9B!V86QI9"!S97-S:6]N(&ED96YT:69I97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971397-S:6]N241S*"D*("`@('L*("`@("`@
M("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE
M8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@
M("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@
M)U-%3$5#5"!S97-S:6]N7VED($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T
M86)L92==.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@
M;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN
M=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]P9W-Q;#HZ)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9V5T4V5S<VEO;DE$
M<R@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D
M<F5S=6QT(#T@0'!G7W%U97)Y*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@
M("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@('!G7V9R965?<F5S=6QT
M*"1R97-U;'0I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R
M;W(@9V5T=&EN9R!S97-S:6]N($E$<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)'-E<W-I;VYS(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H)')O=R`]('!G
M7V9E=&-H7W)O=R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`D<V5S<VEO;G-;
M72`]("1R;W=;,%T["B`@("`@("`@?0H*("`@("`@("!P9U]F<F5E7W)E<W5L
M="@D<F5S=6QT*3L*"B`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!C;VYN96-T:6]N
M('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S.R!E>&ET<R`H2&]R9&4Z.F9A=&%L*"DI
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@
M("!["B`@("`@("`@:68@*"$D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@
M("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US
M+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=U<V5R;F%M92<L("=D
M871A8F%S92<L("=P87-S=V]R9"<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S97-S:6]N(&AA;F1L97(@<&=S<6PG*3L*"B`@
M("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@
M)VAO<F1E7W-E<W-I;VYH86YD;&5R)SL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&-O;FYE8W0@/2!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES
M=&5N="==*2`_"B`@("`@("`@("`@("`@("`G<&=?8V]N;F5C="<@.B=P9U]P
M8V]N;F5C="<["@H@("`@("`@("`@("`D<&%R86US='(@/2`G)SL*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*2`F
M)@H@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UT@
M/3T@)W1C<"<I('L*("`@("`@("`@("`@("`@("1P87)A;7-T<B`N/2`G(&AO
M<W0])R`N("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==.PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=P;W)T)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M<W1R("X]("<@<&]R=#TG("X@)'1H
M:7,M/E]P87)A;7-;)W!O<G0G73L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D<&%R86US='(@+CT@)R!D8FYA;64])R`N
M("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==("X*("`@("`@("`@("`@("`@
M("<@=7-E<CTG("X@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@+@H@("`@
M("`@("`@("`@("`@)R!P87-S=V]R9#TG("X@)'1H:7,M/E]P87)A;7-;)W!A
M<W-W;W)D)UT["@H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?9&(@/2!`)&-O
M;FYE8W0H)'!A<F%M<W1R*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-O;FYE
M8W1E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(O<V%P9&(N<&AP````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`V,S`W`#$P-#$W,S8R-S<S`#`R,C<V,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]S<6PN<&AP)SL*"B\J*@H@*B!397-S:6]N
M2&%N9&QE<B!I;7!L96UE;G1A=&EO;B!F;W(@4$A0)W,@4$5!4B!D871A8F%S
M92!A8G-T<F%C=&EO;B!L87EE<BX*("H*("H@268@>6]U(&%C8V5S<R!Y;W5R
M(&1A=&%B87-E('1H<F]U9V@@3T1"0RP@>6]U('=I;&P@86QM;W-T(&-E<G1A
M:6YL>2!N965D"B`J('1O(&-H86YG92!02%`G<R!D969A=6QT('9A;'5E(&9O
M<B!O9&)C+F1E9F%U;'1L<FP@*'1H:7,@:7,@82!P:'`N:6YI"B`J('-E='1I
M;F<I+B!4:&4@9&5F875L="!I<R`T,#DV+"!W:&EC:"!I<R!T;V\@<VUA;&P@
M*'EO=7(@<V5S<VEO;B!D871A('=I;&P*("H@8F4@8VAO<'!E9"!O9F8I+"!A
M;F0@<V5T=&EN9R!I="!T;R`P($1/15,@3D]4('=O<FL@+2!T:&%T(&1O97-N
M)W0@;65A;B!N;PH@*B!L:6UI="P@9F]R('-O;64@<F5A<V]N+B!O9&)C+F1E
M9F%U;'1L<FP@/2`S,C<V."!S965M<R!T;R!W;W)K('!R971T>2!W96QL"B`J
M("AU<VEN9R!-4U-13"TR,#`P*2X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@
M9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C;VUM=6YI
M8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`G
M=7-E<FYA;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T
M('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O
M<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V1A=&%B87-E
M)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I
M;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W1A8FQE)R`@("`@5&AE(&YA
M;64@;V8@=&AE('-E<W-I;VYD871A('1A8FQE(&EN("=D871A8F%S92<N("!$
M969A=6QT(&ES"B`J("`@("`@("`@("`@("`@)VAO<F1E7W-E<W-I;VYH86YD
M;&5R)RX\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE
M(%-E<W-I;VY(86YD;&5R(&-A;B!B92!F;W5N9"!I;@H@*B!H;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS87!D8BYS<6PN"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+W-A<&1B+G!H<"QV(#$N,3,N,3(N."`R,#`V+S`Q+S`Q(#(Q.C(X.C,T
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?4V5S<VEO;DAA;F1L97(*("HO"F-L87-S(%-E<W-I;VY(86YD;&5R7W-A
M<&1B(&5X=&5N9',@4V5S<VEO;DAA;F1L97)?<W%L('L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=',@82!N97<@4U%,(%-E<W-I;VY(86YD;&5R(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!397-S:6]N2&%N9&QE<E]S87!D8B@D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D<&%R86US6R=P:'!T>7!E)UT@/2`G;V1B
M8R<["B`@("`@("`@<&%R96YT.CI397-S:6]N2&%N9&QE<E]S<6PH)'!A<F%M
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D871A(&9O<B!A
M('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@
M*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@("`@("`O*B!-
M86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN
M("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)E
M9VEN(&$@=')A;G-A8W1I;VXN("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/F%U=&]C;VUM:70H9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@
M("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/32`E<R!72$52
M12!S97-S:6]N7VED(#T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D:60I*3L*"B`@("`@("`@+RH@3&]G
M('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO
M;DAA;F1L97)?<W%L.CIR96%D*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@=&AE('%U
M97)Y("HO"B`@("`@("`@)')E<W5L="`](&]D8F-?97AE8R@D=&AI<RT^7V1B
M+3YC;VYN96-T:6]N+"`D<75E<GDI.PH@("`@("`@(&]D8F-?;&]N9W)E861L
M96XH)')E<W5L="P@,3`T.#4W-BD["@H@("`@("`@("\J($9E=&-H('1H92!V
M86QU92`J+PH@("`@("`@(&]D8F-?9F5T8VA?<F]W*"1R97-U;'0L(#`I.PH@
M("`@("`@("1D871A(#T@;V1B8U]R97-U;'0H)')E<W5L="P@)W-E<W-I;VY?
M9&%T82<I.PH*("`@("`@("`O*B!#;&5A;B!U<"`J+PH@("`@("`@(&]D8F-?
M9G)E95]R97-U;'0H)')E<W5L="D["@H@("`@("`@(')E='5R;B`D9&%T83L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+W-Q;"YP:'``````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R,S<P,0`Q,#0Q-S,V,C<W,P`P,C(T-C8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%-E<W-I;VY(
M86YD;&5R(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2(&1A=&%B87-E
M(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S
M.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A=&%B87-E('1Y<&4@*&4N
M9RX@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P<F4^"B`J"B`J(%)E<75I
M<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J
M("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S
M97)V97(N"B`J("`@)W!R;W1O8V]L)R`@5&AE(&-O;6UU;FEC871I;VX@<')O
M=&]C;VP@*"=T8W`G+"`G=6YI>"<L(&5T8RXI+@H@*B`@("=D871A8F%S92<@
M(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`G=7-E<FYA;64G("!4
M:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@87-S;V-I871E
M9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V]P=&EO;G,G("`@061D:71I;VYA
M;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=T='DG
M("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J($]P=&EO;F%L
M('!A<F%M971E<G,Z/'!R93X*("H@("`G<&5R<VES=&5N="<@(%5S92!P97)S
M:7-T96YT($1"(&-O;FYE8W1I;VYS/R`H8F]O;&5A;BD*("H@("`G=&%B;&4G
M("`@("`@(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T82!T86)L92!I;B`G
M9&%T86)A<V4G+B`@1&5F875L=`H@*B`@("`@("`@("`@("`@("`@:7,@)VAO
M<F1E7W-E<W-I;VYH86YD;&5R)RX\+W!R93X*("H*("H@5&AE('1A8FQE('-T
M<G5C='5R92!F;W(@=&AE(%-E<W-I;VY(86YD;&5R(&-A;B!B92!F;W5N9"!I
M;@H@*B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS
M<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+W-Q;"YP:'`L=B`Q+C(R+C$P+C$S(#(P,#8O,#$O,#$@
M,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA
M;F1L97)?<W%L(&5X=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@
M("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T
M:6]N+@H@("`@("H*("`@("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R("1?
M9&(["@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE
M<B!O<B!N;W0@=V4G<F4@8V]N;F5C=&5D('1O('1H92!344P@<V5R=F5R+@H@
M("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C
M;VYN96-T960@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-L;W-E('1H92!3
M97-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`O*B!$
M:7-C;VYN96-T(&9R;VT@9&%T86)A<V4N("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@("\J($-L;W-E(&%N>2!O<&5N
M('1R86YS86-T:6]N<RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]D8BT^8V]M
M;6ET*"D["B`@("`@("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U
M92D["@H@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO
M;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B
M86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@
M<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96%D*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A
M('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M
M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)E9VEN(&$@=')A;G-A8W1I;VXN
M("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F%U=&]C;VUM:70H
M9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`O*B!%>&5C=71E('1H
M92!Q=65R>2X@*B\*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-13"YP
M:'`G.PH@("`@("`@("1R97-U;'0@/2!(;W)D95]344PZ.G)E861";&]B*"1T
M:&ES+3Y?9&(L("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`G<V5S<VEO;E]D
M871A)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G<V5S<VEO;E]I9"<@/3X@)&ED*2D["@H@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%=R:71E('-E<W-I;VX@9&%T82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@
M("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D
M<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H
M879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@<V5S
M<VEO;E]I9"!&4D]-("5S(%=(15)%('-E<W-I;VY?:60@/2`_)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*3L*
M("`@("`@("`D=F%L=65S(#T@87)R87DH)&ED*3L*"B`@("`@("`@+RH@3&]G
M('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO
M;DAA;F1L97)?<W%L.CIW<FET92@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q
M=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T3VYE
M*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O4U%,+G!H<"<["B`@("`@("`@:68@*"1R
M97-U;'0I('L*("`@("`@("`@("`@)')E<W5L="`]($AO<F1E7U-13#HZ=7!D
M871E0FQO8B@D=&AI<RT^7V1B+"`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@
M)W-E<W-I;VY?9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-E<W-I;VY?9&%T82P@87)R87DH)W-E<W-I;VY?
M:60G(#T^("1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W-E<W-I;VY?;&%S=&UO9&EF:65D)R`]/B!T
M:6UE*"DI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@2&]R9&5?4U%,.CII;G-E<G1";&]B*"1T:&ES+3Y?9&(L("1T:&ES+3Y?
M<&%R86US6R=T86)L92==+"`G<V5S<VEO;E]D871A)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5S<VEO;E]D871A
M+"!A<G)A>2@G<V5S<VEO;E]I9"<@/3X@)&ED+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=S97-S:6]N7VQA<W1M;V1I9FEE9"<@/3X@=&EM92@I*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G)O;&QB86-K*"D["B`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F-O
M;6UI="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AT<G5E
M*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V1B+3YA
M=71O0V]M;6ET*'1R=64I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U
M;&%R('-E<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(
M86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5S=')O>2@D:60I"B`@("!["B`@
M("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C
M;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@
M("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('-E<W-I;VY?:60@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)&ED*3L*"B`@
M("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@
M*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E
M<GD@8GD@4V5S<VEO;DAA;F1L97)?<W%L.CID97-T<F]Y*"DZ('%U97)Y(#T@
M(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J
M($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^8V]M;6ET*"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL96-T('-T86QE('-E<W-I
M;VYS(&9R;VT@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QI9F5T:6UE("!4:&4@;6%X:6UU
M;2!A9V4@;V8@82!S97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=C*"1M87AL:69E=&EM92`](#,P,"D*("`@('L*
M("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E
M(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@
M("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@<V5S<VEO;E]L
M87-T;6]D:69I960@/"`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==*3L*("`@("`@("`D=F%L=65S(#T@87)R
M87DH=&EM92@I("T@)&UA>&QI9F5T:6UE*3L*"B`@("`@("`@+RH@3&]G('1H
M92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA
M;F1L97)?<W%L.CIG8R@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@
M*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y
M+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U
M;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H
M92!V86QI9"!S97-S:6]N(&ED96YT:69I97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($$@;&ES="!O9B!V86QI9"!S97-S:6]N(&ED96YT:69I
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397-S:6]N241S*"D*("`@
M('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B
M87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("1T:6UE;W5T(#T@=&EM92@I("T@:6YI7V=E="@G<V5S<VEO
M;BYG8U]M87AL:69E=&EM92<I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,
M('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]("=314Q%0U0@<V5S<VEO;E]I
M9"!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@
M("`@("`@("`@)R!72$5212!S97-S:6]N7VQA<W1M;V1I9FEE9"`^(#\G.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D=&EM96]U="D["@H@("`@("`@("\J
M($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E
M<W-I;VY(86YD;&5R7W-Q;#HZ9V5T4V5S<VEO;DE$<R@I.B!Q=65R>2`]("(E
M<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%
M>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D8BT^9V5T0V]L*"1Q=65R>2P@,"P@)'9A;'5E<RD["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A(&-O;FYE8W1I;VX@=&\@=&AE
M(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,[(&5X:71S("A(;W)D93HZ9F%T86PH*2D@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@
M("`@("!I9B`H(21T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@($AO
M<F1E.CIA<W-E<G1$<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=S97-S
M:6]N:&%N9&QE<B<L"B`@("`@("`@("`@("`@("!A<G)A>2@G<&AP='EP92<I
M+`H@("`@("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!344PG*3L*"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E
M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&%T86)A
M<V4G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;
M)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG:&]S='-P96,G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E7W-E
M<W-I;VYH86YD;&5R)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M0V]N;F5C="!T;R!T:&4@4U%,('-E<G9E<B!U<VEN9R!T:&4@<W5P<&QI960*
M("`@("`@("`@("`@("H@<&%R86UE=&5R<RX@*B\*("`@("`@("`@("`@:6YC
M;'5D95]O;F-E("=$0BYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7V1B(#T@
M)D1".CIC;VYN96-T*"1T:&ES+3Y?<&%R86US+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P97)S:7-T96YT)R`]/B`A
M96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1T:&ES+3Y?9&(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))
M3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH*("`@
M("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<W,P`P,3<Q-#``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<S`#`R,#,U-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]C;VYD
M:71I;VYA;%]E;F%B;&4N<&AP````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,T,34`,3`T,3<S
M-C(W-S,`,#(T-C<W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!(;W)D95]&;W)M7T%C=&EO;E]C;VYD
M:71I;VYA;%]E;F%B;&4@:7,@82!(;W)D95]&;W)M7T%C=&EO;B!T:&%T"B`J
M(&5N86)L97,@;W(@9&ES86)L97,@86X@96QE;65N="!B87-E9"!O;B!T:&4@
M=F%L=64@;V8@86YO=&AE<B!E;&5M96YT"B`J"B`J($9O<FUA="!O9B!T:&4@
M)'!A<F%M<R!P87-S960@=&\@=&AE(&-O;G-T<G5C=&]R.@H@*B`\<')E/@H@
M*B`@)'!A<F%M<R`](&%R<F%Y*`H@*B`@("`@("=T87)G970G("`]/B`G6VYA
M;64@;V8@96QE;65N="!T:&ES(&ES(&-O;F1I=&EO;F%L(&]N72<L"B`J("`@
M("`@)V5N86)L960G(#T^("=T<G5E)R!\("=F86QS92<L"B`J("`@("`@)W9A
M;'5E<R<@(#T^(&%R<F%Y*%MT87)G970@=F%L=65S('1O(&-H96-K72D*("H@
M("D["B`J(#PO<')E/@H@*@H@*B!3;R`D<&%R86US(#T@87)R87DH)V9O;R<L
M("=T<G5E)RP@87)R87DH,2P@,BDI('=I;&P@96YA8FQE('1H92!F:65L9"!T
M:&ES"B`J(&%C=&EO;B!I<R!A='1A8VAE9"!T;R!I9B!T:&4@=F%L=64@;V8@
M)V9O;R<@:7,@,2!O<B`R+"!A;F0@9&ES86)L92!I=`H@*B!O=&AE<G=I<V4N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I;VXO8V]N
M9&ET:6]N86Q?96YA8FQE+G!H<"QV(#$N-"XQ,"XS(#(P,#8O,#$O,#$@,C$Z
M,C@Z,3<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36%T
M="!+>6YA<W1O;B`\;6%T=$!K>6YX+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UA='0@2WEN87-T;VX@/&UA='1`:WEN>"YO<F<^"B`J($!P
M86-K86=E($AO<F1E7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?06-T:6]N
M7V-O;F1I=&EO;F%L7V5N86)L92!E>'1E;F1S($AO<F1E7T9O<FU?06-T:6]N
M('L*"B`@("!V87(@)%]T<FEG9V5R(#T@87)R87DH)V]N;&]A9"<I.PH*("`@
M(&9U;F-T:6]N(&=E=$%C=&EO;E-C<FEP="@F)&9O<FTL("1R96YD97)E<BP@
M)'9A<FYA;64I"B`@("!["B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)V9O<FU?:&5L<&5R<RYJ<R<L("=H;W)D92<L('1R=64I.PH*("`@("`@("`D
M9F]R;5]N86UE(#T@)&9O<FTM/F=E=$YA;64H*3L*("`@("`@("`D=&%R9V5T
M(#T@)'1H:7,M/E]P87)A;7-;)W1A<F=E="==.PH@("`@("`@("1E;F%B;&5D
M(#T@)'1H:7,M/E]P87)A;7-;)V5N86)L960G73L*("`@("`@("!I9B`H(6ES
M7W-T<FEN9R@D96YA8FQE9"DI('L*("`@("`@("`@("`@)&5N86)L960@/2`H
M)&5N86)L960I(#\@)W1R=64G(#H@)V9A;'-E)SL*("`@("`@("!]"B`@("`@
M("`@)'9A;',@/2`D=&AI<RT^7W!A<F%M<ULG=F%L=65S)UT["B`@("`@("`@
M)'9A;',@/2`H:7-?87)R87DH)'9A;',I*2`_("1V86QS(#H@87)R87DH)'9A
M;',I.PH@("`@("`@("1A<F=S(#T@(B<D=F%R;F%M92<L("1E;F%B;&5D+"`G
M(B`N(&EM<&QO9&4H(B<L)R(L("1V86QS*2`N("(G(CL*"B`@("`@("`@<F5T
M=7)N(")I9B`H861D179E;G0H9&]C=6UE;G0N)&9O<FU?;F%M92XD=&%R9V5T
M+"`G;VYC:&%N9V4G+"!<(F-H96-K16YA8FQE9"AT:&ES+"`D87)G<RD[7"(I
M*2![("(*("`@("`@("`@("`@+B`B("!C:&5C:T5N86)L960H9&]C=6UE;G0N
M)&9O<FU?;F%M92XD=F%R;F%M92P@)&%R9W,I.R`B"B`@("`@("`@("`@("X@
M)WT[)SL*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO8V]N9&ET:6]N
M86Q?<V5T=F%L=64N<&AP`````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,#$P`#$P-#$W,S8R-S<S
M`#`R-3(W,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@2&]R9&5?1F]R;5]!8W1I;VY?8V]N9&ET:6]N
M86Q?<V5T=F%L=64@:7,@82!(;W)D95]&;W)M7T%C=&EO;B!T:&%T"B`J('-E
M=',@=&AE('9A;'5E(&]F(&]N92!(;W)D95]&;W)M('9A<FEA8FQE(&)A<V5D
M(&]N('1H92!V86QU92!O9B!T:&4*("H@=F%R:6%B;&4@=&AE(&%C=&EO;B!I
M<R!A='1A8VAE9"!T;RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+T%C=&EO;B]C;VYD:71I;VYA;%]S971V86QU92YP:'`L=B`Q+C$Y+C$P
M+C4@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J
M+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]C;VYD:71I;VYA;%]S971V86QU
M92!E>'1E;F1S($AO<F1E7T9O<FU?06-T:6]N('L*"B`@("`O*BH*("`@("`J
M(%=H:6-H($I3(&5V96YT<R!S:&]U;&0@=')I9V=E<B!T:&ES(&%C=&EO;C\*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1R
M:6=G97(@/2!A<G)A>2@G;VYC:&%N9V4G+"`G;VYL;V%D)RD["@H@("`@9G5N
M8W1I;VX@9V5T06-T:6]N4V-R:7!T*"1F;W)M+"`D<F5N9&5R97(L("1V87)N
M86UE*0H@("`@>PH@("`@("`@(')E='5R;B`G;6%P*%PG)R`N("1R96YD97)E
M<BT^7V=E;DE$*"1V87)N86UE+"!F86QS92D@+B`B)RP@)R(@+B`D<F5N9&5R
M97(M/E]G96Y)1"@D=&AI<RT^9V5T5&%R9V5T*"DL(&9A;'-E*2`N("=<)RD[
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!S971686QU97,H)B1V87)S+"`D<V]U
M<F-E5F%L+"`D87)R87E686P@/2!F86QS92D*("`@('L*("`@("`@("`D;6%P
M(#T@)'1H:7,M/E]P87)A;7-;)VUA<"==.PH@("`@("`@("1T87)G970@/2`D
M=&AI<RT^9V5T5&%R9V5T*"D["@H@("`@("`@(&EF("@D87)R87E686PI('L*
M("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)'-O=7)C959A;"DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S;W5R
M8V5686P@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&UA<%LD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<G,M/G-E="@D=&%R9V5T+"`D;6%P6R1V86Q=+"`D:2D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1M87!;)'-O=7)C959A;%TI*2!["B`@("`@
M("`@("`@("`@("`D=F%R<RT^<V5T*"1T87)G970L("1M87!;)'-O=7)C959A
M;%TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N('!R:6YT2F%V85-C<FEP="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]P
M<FEN=$IA=F%38W)I<'13=&%R="@I.PH@("`@("`@("1M87`@/2`D=&AI<RT^
M7W!A<F%M<ULG;6%P)UT["C\^"@IV87(@7VUA<"`](&YE=R!!<G)A>2@\/W!H
M<`HD:2`](#`["F9O<F5A8V@@*"1M87`@87,@)'9A;"D@>PH@("`@:68@*"1I
M(#X@,"D@>PH@("`@("`@(&5C:&\@)RP@)SL*("`@('T*("`@(&5C:&\@)R(G
M("X@)'9A;"`N("<B)SL*("`@("1I*RL["GT_/BD["@IF=6YC=&EO;B!M87`H
M<V]U<F-E260L('1A<F=E=$ED*0I["B`@("!V87(@;F5W=F%L.PH@("`@=F%R
M('-O=7)C92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'-O=7)C94ED*3L*
M("`@('9A<B!E;&5M96YT(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R
M9V5T260I.PH@("`@:68@*&5L96UE;G0I('L*("`@("`@("!I9B`H7VUA<%MS
M;W5R8V4N<V5L96-T961);F1E>%TI('L*("`@("`@("`@("`@;F5W=F%L(#T@
M7VUA<%MS;W5R8V4N<V5L96-T961);F1E>%T["B`@("`@("`@("`@(')E<&QA
M8V4@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&YE=W9A
M;"`]("<G.PH@("`@("`@("`@("!R97!L86-E(#T@9F%L<V4["B`@("`@("`@
M("`@(&9O<B`H:2`](#`[(&D@/"!?;6%P+FQE;F=T:#L@:2LK*2!["B`@("`@
M("`@("`@("`@("!I9B`H96QE;65N="YV86QU92`]/2!?;6%P6VE=*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5P;&%C92`]('1R=64["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("AR97!L86-E*2!["B`@("`@("`@
M("`@(&5L96UE;G0N=F%L=64@/2!N97=V86P["B`@("`@("`@?0H@("`@?0I]
M/#]P:'`*("`@("`@("`D=&AI<RT^7W!R:6YT2F%V85-C<FEP=$5N9"@I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]&;W)M+T%C=&EO;B]R96QO860N<&AP````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$U-S,`,3`T,3<S-C(W-S,`,#(R,S,W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!(;W)D95]&;W)M7T%C=&EO;E]R96QO860@:7,@82!(;W)D95]&;W)M($%C
M=&EO;B!T:&%T(')E;&]A9',@=&AE"B`J(&9O<FT@=VET:"!T:&4@8W5R<F5N
M="`H;F]T('1H92!O<FEG:6YA;"D@=F%L=64@869T97(@=&AE(&9O<FT@96QE
M;65N=`H@*B!T:&%T('1H92!A8W1I;VX@:7,@871T86-H960@=&\@:7,@;6]D
M:69I960N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I
M;VXO<F5L;V%D+G!H<"QV(#$N-RXQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z,3<@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!P86-K86=E
M($AO<F1E7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?06-T:6]N7W)E;&]A
M9"!E>'1E;F1S($AO<F1E7T9O<FU?06-T:6]N('L*"B`@("!V87(@)%]T<FEG
M9V5R(#T@87)R87DH)V]N8VAA;F=E)RD["@H@("`@9G5N8W1I;VX@9V5T06-T
M:6]N4V-R:7!T*"1F;W)M+"`D<F5N9&5R97(L("1V87)N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B`G:68@*'1H:7,N=F%L=64I('L@9&]C=6UE;G0N)R`N
M("1F;W)M+3YG971.86UE*"D@+B`G+F9O<FUN86UE+G9A;'5E/5PG7"<[)R`N
M"B`@("`@("`@("`@("=D;V-U;65N="XG("X@)&9O<FTM/F=E=$YA;64H*2`N
M("<N<W5B;6ET*"D@?2<["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]S=6)M:70N<&AP````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$S-S<`,3`T,3<S-C(W-S,`,#(R,S<V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!(;W)D95]&;W)M7T%C=&EO;E]S=6)M:70@:7,@82!(;W)D95]&
M;W)M($%C=&EO;B!T:&%T('-U8FUI=',@=&AE"B`J(&9O<FT@869T97(@=&AE
M(&9O<FT@96QE;65N="!T:&%T('1H92!A8W1I;VX@:7,@871T86-H960@=&\@
M:7,*("H@;6]D:69I960N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO
M1F]R;2]!8W1I;VXO<W5B;6ET+G!H<"QV(#$N,3`N,3(N-"`R,#`V+S`Q+S`Q
M(#(Q.C(X.C$W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!P86-K86=E($AO<F1E7T9O<FT*("HO"F-L87-S($AO<F1E
M7T9O<FU?06-T:6]N7W-U8FUI="!E>'1E;F1S($AO<F1E7T9O<FU?06-T:6]N
M('L*"B`@("!V87(@)%]T<FEG9V5R(#T@87)R87DH)V]N8VAA;F=E)RD["@H@
M("`@9G5N8W1I;VX@9V5T06-T:6]N4V-R:7!T*"1F;W)M+"`D<F5N9&5R97(L
M("1V87)N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`G9&]C=6UE;G0N)R`N
M("1F;W)M+3YG971.86UE*"D@+B`G+G-U8FUI="@I)SL*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]S=6U?9FEE;&1S+G!H
M<```````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W-C``,3`T,3<S-C(W-S,`,#(S
M,C(R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!(;W)D95]&;W)M7T%C=&EO;E]S=6U?9FEE;&1S(&ES
M(&$@2&]R9&5?1F]R;5]!8W1I;VX@=&AA="!S971S('1H92!T87)G970*("H@
M9FEE;&0@=&\@=&AE('-U;2!O9B!O;F4@;W(@;6]R92!O=&AE<B!N=6UE<FEC
M(&9I96QD<RX*("H*("H@5&AE('!A<F%M<R!A<G)A>2!S:&]U;&0@8V]N=&%I
M;B!T:&4@;F%M97,@;V8@=&AE(&9I96QD<R!W:&EC:"!W:6QL(&)E"B`J('-U
M;6UE9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1F]R;2]&;W)M+T%C=&EO
M;B]S=6U?9FEE;&1S+G!H<"QV(#$N-2XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z
M,3<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36%T="!+
M>6YA<W1O;B`\;6%T=$!K>6YX+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UA='0@2WEN87-T;VX@/&UA='1`:WEN>"YO<F<^"B`J($!P86-K
M86=E($AO<F1E7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?06-T:6]N7W-U
M;5]F:65L9',@97AT96YD<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@=F%R
M("1?=')I9V=E<B`](&%R<F%Y*"=O;FQO860G*3L*"B`@("!F=6YC=&EO;B!G
M971!8W1I;VY38W)I<'0H)B1F;W)M+"`D<F5N9&5R97(L("1V87)N86UE*0H@
M("`@>PH@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=F;W)M7VAE;'!E
M<G,N:G,G+"`G:&]R9&4G+"!T<G5E*3L*"B`@("`@("`@)&9O<FU?;F%M92`]
M("1F;W)M+3YG971.86UE*"D["B`@("`@("`@)&9I96QD<R`]("(G(B`N(&EM
M<&QO9&4H(B<L)R(L("1T:&ES+3Y?<&%R86US*2`N("(G(CL*("`@("`@("`D
M:G,@/2!A<G)A>2@I.PH@("`@("`@("1J<UM=(#T@<W!R:6YT9B@G9&]C=6UE
M;G0N9F]R;7-;7"<E<UPG72YE;&5M96YT<UM<)R5S7"==+F1I<V%B;&5D(#T@
M=')U93LG+`H@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;5]N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92D["B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]P87)A;7,@87,@)&9I96QD*2!["B`@("`@("`@("`@
M("1J<UM=(#T@<W!R:6YT9B@B861D179E;G0H9&]C=6UE;G0N9F]R;7-;)R4Q
M7"1S)UTN96QE;65N='-;)R4R7"1S)UTL(%PB;VYC:&%N9V5<(BP@7")S=6U&
M:65L9',H9&]C=6UE;G0N9F]R;7-;)R4Q7"1S)UTL("<E,UPD<R<L("4T7"1S
M*3M<(BD[(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M7VYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F:65L9',I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(&EM<&QO9&4H(EQN(BP@)&IS*3L*("`@('T*"GT*````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O
M<FTO06-T:6]N+W5P9&%T969I96QD+G!H<```````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S<P,0`Q,#0Q-S,V,C<W,P`P,C,S-3(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7T9O
M<FU?06-T:6]N7W5P9&%T969I96QD(&ES(&$@2&]R9&5?1F]R;5]!8W1I;VX@
M=&AA="!U<&1A=&5S"B`J('1H92!V86QU92!O9B!O;F4@2&]R9&5?1F]R;2!V
M87)I86)L92!A<R!T:&4@=F%R:6%B;&4@=&AE(&%C=&EO;B!I<PH@*B!A='1A
M8VAE9"!T;R!I<R!U<&1A=&5D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO06-T:6]N+W5P9&%T969I96QD+G!H<"QV(#$N-2XQ,BXT(#(P
M,#8O,#$O,#$@,C$Z,C@Z,3<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA
M<W,@2&]R9&5?1F]R;5]!8W1I;VY?=7!D871E9FEE;&0@97AT96YD<R!(;W)D
M95]&;W)M7T%C=&EO;B!["@H@("`@=F%R("1?=')I9V=E<B`](&%R<F%Y*"=O
M;F-H86YG92<L("=O;FQO860G+"`G;VYK97EU<"<I.PH*("`@(&9U;F-T:6]N
M(&=E=$%C=&EO;E-C<FEP="@F)&9O<FTL("8D<F5N9&5R97(L("1V87)N86UE
M*0H@("`@>PH@("`@("`@(')E='5R;B`G=7!D871E1FEE;&0G("X@)'1H:7,M
M/FED*"D@+B`G*"D[)SL*("`@('T*"B`@("!F=6YC=&EO;B!S971686QU97,H
M)B1V87)S+"`D<V]U<F-E5F%L+"`D87)R87E686P@/2!F86QS92D*("`@('L*
M("`@('T*"B`@("!F=6YC=&EO;B!P<FEN=$IA=F%38W)I<'0H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<')I;G1*879A4V-R:7!T4W1A<G0H*3L*("`@("`@
M("`D<&EE8V5S(#T@97AP;&]D92@G)7,G+"`D=&AI<RT^7W!A<F%M<ULG9F]R
M;6%T)UTI.PH@("`@("`@("1F:65L9',@/2`D=&AI<RT^7W!A<F%M<ULG9FEE
M;&1S)UT["B`@("`@("`@)'9A;%]F:7)S="`]("AS=6)S='(H)'1H:7,M/E]P
M87)A;7-;)V9O<FUA="==+"`P+"`R*2`]/2`G)7,G*3L*("`@("`@("!I9B`H
M)'9A;%]F:7)S="D@>PH@("`@("`@("`@("!A<G)A>5]S:&EF="@D<&EE8V5S
M*3L*("`@("`@("!]"B`@("`@("`@:68@*'-U8G-T<B@D=&AI<RT^7W!A<F%M
M<ULG9F]R;6%T)UTL("TR*2`]/2`G)7,G*2!["B`@("`@("`@("`@(&%R<F%Y
M7W!O<"@D<&EE8V5S*3L*("`@("`@("!]"@H@("`@("`@("1A<F=S(#T@87)R
M87DH*3L*("`@("`@("!I9B`H)'9A;%]F:7)S="D@>PH@("`@("`@("`@("`D
M87)G<UM=(#T@(F1O8W5M96YT+F=E=$5L96UE;G1">4ED*"<B("X@87)R87E?
M<VAI9G0H)&9I96QD<RD@+B`B)RDN=F%L=64B.PH@("`@("`@('T*("`@("`@
M("!W:&EL92`H8V]U;G0H)'!I96-E<RDI('L*("`@("`@("`@("`@)&%R9W-;
M72`]("(G(B`N(&%R<F%Y7W-H:69T*"1P:65C97,I("X@(B<B.PH@("`@("`@
M("`@("`D87)G<UM=(#T@(F1O8W5M96YT+F=E=$5L96UE;G1">4ED*"<B("X@
M87)R87E?<VAI9G0H)&9I96QD<RD@+B`B)RDN=F%L=64B.PH@("`@("`@('T*
M/SX*+R\@57!D871E<B!F;W(@/#]P:'`@96-H;R`D=&AI<RT^9V5T5&%R9V5T
M*"D@/SXN"F9U;F-T:6]N('5P9&%T949I96QD/#]P:'`@96-H;R`D=&AI<RT^
M:60H*2`_/B@I"GL*("`@('9A<B!T87)G970@/2!D;V-U;65N="YG971%;&5M
M96YT0GE)9"@G/#]P:'`@96-H;R`D=&AI<RT^9V5T5&%R9V5T*"D@/SXG*3L*
M("`@(&EF("AT87)G970I('L*("`@("`@("!T87)G970N=F%L=64@/2`\/W!H
M<"!E8VAO(&EM<&QO9&4H)R`K("<L('-T<E]R97!L86-E*")<;B(L(")<7&XB
M+"`D87)G<RDI(#\^.PH@("`@?0I]/#]P:'`*("`@("`@("`D=&AI<RT^7W!R
M:6YT2F%V85-C<FEP=$5N9"@I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+U1Y
M<&4O````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-S,`,#(P,#8Q`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'``````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C8S,@`Q,#0Q-S,V,C<W,P`P,C(S-S4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PH*+RHJ"B`J("1(;W)D93H@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<"QV(#$N,RXR
M+C$@,C`P-2\Q,"\Q."`Q,3HP,3HP."!J86X@17AP("0*("H*("H@0'!A8VMA
M9V4@2&]R9&5?1F]R;0H@*B!`<VEN8V4@("!(;W)D92`S+C$*("HO"F-L87-S
M($AO<F1E7T9O<FU?5'EP95]T86)L97-E="!E>'1E;F1S($AO<F1E7T9O<FU?
M5'EP92!["@H@("`@=F%R("1?=F%L=65S.PH@("`@=F%R("1?:&5A9&5R.PH*
M("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E<RP@)&AE861E<BD*("`@('L*("`@
M("`@("`D=&AI<RT^7W9A;'5E<R`]("1V86QU97,["B`@("`@("`@)'1H:7,M
M/E]H96%D97(@/2`D:&5A9&5R.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L
M:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@
M("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?=F%L=65S*2`]/2`P('Q\(&-O=6YT
M*"1V86QU92D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"B`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1I=&5M*2!["B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]V86QU97-;)&ET96U=*2D@
M>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@=')U93L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF
M("@A:7-S970H)&5R<F]R*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B26YV86QI9"!D871A
M('-U8FUI='1E9"XB*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@9G5N8W1I;VX@9V5T2&5A9&5R*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]H96%D97(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F%L=65S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V86QU97,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`G;F%M92<@/3X@7R@B5&%B;&4@
M4V5T(BDL"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")686QU
M97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E
M)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@("`@("`@("`@("=H96%D97(G
M(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B2&5A9&5R<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES
M="<I*2P*("`@("`@("`@("`@*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXN
M<&AP````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-S`S`#$P
M-#$W,S8R-S<S`#`R,3`V-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T9O<FU?06-T
M:6]N(&-L87-S('!R;W9I9&5S(&%N($%022!F;W(@861D:6YG(&%C=&EO;G,@
M=&\*("H@2&]R9&5?1F]R;2!V87)I86)L97,N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T9O<FTO1F]R;2]!8W1I;VXN<&AP+'8@,2XQ.2XQ,"XV(#(P,#8O
M,#$O,#$@,C$Z,C@Z,3<@:F%N($5X<"`D"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA<W,@2&]R
M9&5?1F]R;5]!8W1I;VX@>PH*("`@('9A<B`D7VED.PH@("`@=F%R("1?<&%R
M86US.PH@("`@=F%R("1?=')I9V=E<B`](&YU;&P["@H@("`@9G5N8W1I;VX@
M2&]R9&5?1F]R;5]!8W1I;VXH)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@("1T:&ES+3Y?
M:60@/2!M9#4H;71?<F%N9"@I*3L*("`@('T*"B`@("!F=6YC=&EO;B!G9714
M<FEG9V5R*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T<FEG9V5R
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&ED*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]I9#L*("`@('T*"B`@("!F=6YC=&EO;B!G971!8W1I;VY3
M8W)I<'0H)&9O<FTL("1R96YD97)E<BP@)'9A<FYA;64I"B`@("!["B`@("`@
M("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N('!R:6YT2F%V85-C
M<FEP="@I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@7W!R:6YT2F%V85-C
M<FEP=%-T87)T*"D*("`@('L*("`@("`@("!E8VAO("<\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^/"$M+2<["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W!R:6YT2F%V85-C<FEP=$5N9"@I"B`@("!["B`@("`@("`@96-H;R`G+R\@
M+2T^/"]S8W)I<'0^)SL*("`@('T*"B`@("!F=6YC=&EO;B!G971487)G970H
M*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M=&%R9V5T)UTI(#\@)'1H:7,M/E]P87)A;7-;)W1A<F=E="==(#H@;G5L;#L*
M("`@('T*"B`@("!F=6YC=&EO;B!S971686QU97,H)B1V87)S+"`D<V]U<F-E
M5F%L+"`D:6YD97@@/2!N=6QL+"`D87)R87E686P@/2!F86QS92D*("`@('L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O
M;F-R971E($AO<F1E7T9O<FU?06-T:6]N(&EN<W1A;F-E"B`@("`@*B!B87-E
M9"!O;B`D9F]R;2X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&9O<FT@
M("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?1F]R;5]!8W1I;VX@<W5B
M8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T;R!R971U<FXN
M($EF("1F;W)M(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&EN("1F;W)M6S!=+VQI8B]&;W)M
M+T%C=&EO;B\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1F;W)M6S%=+G!H<"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!F;W)M(&UI9VAT(&YE960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!(;W)D95]&;W)M7T%C=&EO;B`@5&AE(&-O;F-R971E($AO
M<F1E7T9O<FU?06-T:6]N(')E9F5R96YC92P@;W(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D86-T:6]N+"`D<&%R86US(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&%C=&EO;BDI('L*("`@
M("`@("`@("`@)&%P<"`]("1A8W1I;VY;,%T["B`@("`@("`@("`@("1A8W1I
M;VX@/2`D86-T:6]N6S%=.PH@("`@("`@('T*"B`@("`@("`@)&%C=&EO;B`]
M(&)A<V5N86UE*"1A8W1I;VXI.PH@("`@("`@(&EF("AE;7!T>2@D86-T:6]N
M*2!\?"`H<W1R8VUP*"1A8W1I;VXL("=N;VYE)RD@/3T@,"DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-A;FYO="!I;G-T86YT
M:6%T92!A8G-T<F%C="!C;&%S<R!(;W)D95]&;W)M7T%C=&EO;BXG*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I
M;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]&;W)M+T%C=&EO;B\G("X@)&%C=&EO
M;B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]!8W1I;VXO)R`N("1A8W1I;VX@+B`G+G!H
M<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O06-T:6]N+R<@+B`D86-T:6]N("X@)RYP:'`G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1F]R
M;2]!8W1I;VXO)R`N("1A8W1I;VX@+B`G+G!H<"<["B`@("`@("`@?0H*("`@
M("`@("`D8VQA<W,@/2`G2&]R9&5?1F]R;5]!8W1I;VY?)R`N("1A8W1I;VX[
M"B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@
M("`@("1I;G-T86YC92`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1I;G-T86YC92`](%!%05(Z.G)A:7-E
M17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T
M(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC
M93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(')E9F5R96YC92!T;R!A(&-O;F-R971E"B`@("`@*B!(;W)D95]&;W)M7T%C
M=&EO;B!I;G-T86YC92!B87-E9"!O;B`D86-T:6]N+B!)="!W:6QL(&]N;'D*
M("`@("`J(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!(;W)D95]&;W)M
M7T%C=&EO;B!I;G-T86YC92!W:71H"B`@("`@*B!T:&4@<V%M92!P87)A;65T
M97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U
M;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F;W)M(')E;F1E<F5R
M<R`H86YD+`H@("`@("H@=&AU<RP@;75L=&EP;&4@2&]R9&5?1F]R;5]!8W1I
M;VX@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T*("`@("`J("9(
M;W)D95]&;W)M7T%C=&EO;CHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)&%C=&EO;B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R
M9&5?1F]R;5]!8W1I;VX@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN
M8VQU9&5D+B!)9B`D86-T:6]N(&ES(&%N(&%R<F%Y+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@('1H96X@=V4@=VEL;"!L;V]K(&EN("1A8W1I;VY;
M,%TO;&EB+T9O<FTO06-T:6]N+R!F;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)&%C
M=&EO;ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9F]R;2!M:6=H="!N965D
M+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?1F]R;5]!8W1I;VX@(%1H
M92!C;VYC<F5T92!(;W)D95]&;W)M7T%C=&EO;B!R969E<F5N8V4L(&]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92!O;B!A;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D86-T:6]N
M+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A
M;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@
M("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@
M("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D86-T:6]N+"`D<&%R
M86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U
M<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@
M)DAO<F1E7T9O<FU?06-T:6]N.CIF86-T;W)Y*"1A8W1I;VXL("1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA
M='5R95T["B`@("!]"@I]"@``````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<```````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#0Q-S8`,3`T,3<S-C(W-S,`
M,#(Q-#,P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?1F]R;5]296YD97)E<B!C;&%S
M<R!P<F]V:61E<R!(5$U,(&%N9"!O=&AE<B!R96YD97)I;F=S(&]F"B`J(&9O
M<FUS(&9O<B!T:&4@2&]R9&5?1F]R;3HZ('!A8VMA9V4N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`L=B`Q+C$X-2XT
M+C$T(#(P,#8O,#,O,#<@,3DZ-#@Z-#$@8VAU8VL@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#$M,C`P-B!2;V)E<G0@12X@0V]Y;&4@/')O8F5R=&5C;WEL
M94!H;W1M86EL+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%)O
M8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!`
M<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7U)E;F1E
M<F5R('L*"B`@("!V87(@)%]N86UE.PH@("`@=F%R("1?<F5Q=6ER961,96=E
M;F0@/2!F86QS93L*("`@('9A<B`D7W)E<75I<F5D36%R:V5R(#T@)RHG.PH@
M("`@=F%R("1?:&5L<$UA<FME<B`]("<_)SL*("`@('9A<B`D7V]N3&]A9$I3
M(#T@87)R87DH*3L*("`@('9A<B`D7W-H;W=(96%D97(@/2!T<G5E.PH@("`@
M=F%R("1?8V]L<R`](#(["B`@("!V87(@)%]V87)296YD97)E<B`](&YU;&P[
M"B`@("!V87(@)%]F:7)S=$9I96QD(#T@;G5L;#L*("`@('9A<B`D7W-T<FEP
M9612;W=S(#T@=')U93L*"B`@("`O*BH*("`@("`J($1O97,@=&AE('1I=&QE
M(&]F('1H92!F;W)M(&-O;G1A:6X@2%1-3#\@268@<V\L('EO=2!A<F4@<F5S
M<&]N<VEB;&4@9F]R"B`@("`@*B!D;VEN9R!A;GD@;F5E9&5D(&5S8V%P:6YG
M+W-A;FET:7IA=&EO;B!Y;W5R<V5L9BX@3W1H97)W:7-E('1H92!T:71L90H@
M("`@("H@=VEL;"!B92!R=6X@=&AR;W5G:"!H=&UL<W!E8VEA;&-H87)S*"D@
M8F5F;W)E(&)E:6YG(&]U='!U="X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?96YC;V1E5&ET;&4@/2!T<G5E.PH*("`@
M("\J*@H@("`@("H@5VED=&@@;V8@=&AE(&%T=')I8G5T97,@8V]L=6UN+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?871T<D-O;'5M;E=I9'1H(#T@)S$U)2<[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W0@82!N97<@2&]R9&5?1F]R;5]2
M96YD97)E<CHZ+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!4:&ES(&ES(&$@:&%S:"!O9B!R96YD97)E<BUS<&5C:69I8R!P87)A;65T
M97)S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%!O<W-I8FQE(&ME
M>7,Z/&-O9&4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W9A<G)E
M;F1E<F5R7V1R:79E<B<Z('-P96-I9FEE<R!T:&4@9')I=F5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<B!T;R!(;W)D95]5
M25]687)296YD97)E<CHZ9F%C=&]R>2@I+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("=E;F-O9&5?=&ET;&4G.B!`<V5E("1?96YC;V1E5&ET;&4\
M+V-O9&4^"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T9O<FU?4F5N9&5R
M97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1R
M96=I<W1R>3L*("`@("`@("!I9B`H:7-S970H)')E9VES=')Y*2`F)B!I<U]A
M*"1R96=I<W1R>2P@)U)E9VES=')Y)RDI('L*("`@("`@("`@("`@+RH@4F5G
M:7-T<GD@879A:6QA8FQE+"!S;R!U<V4@82!P<F5T='D@:6UA9V4N("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?<F5Q=6ER961-87)K97(@/2!(;W)D93HZ:6UG
M*"=R97%U:7)E9"YP;F<G+"`G*B<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E
M1&ER*"=H;W)D92<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*B!.;R!R96=I<W1R>2!A=F%I;&%B;&4L('5S92!S;VUE=&AI;F<@<&QA:6XN
M("HO"B`@("`@("`@("`@("1T:&ES+3Y?<F5Q=6ER961-87)K97(@/2`G*B<[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG96YC;V1E
M7W1I=&QE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YE;F-O9&54:71L92@D
M<&%R86US6R=E;F-O9&5?=&ET;&4G72D["B`@("`@("`@?0H*("`@("`@("`D
M9')I=F5R(#T@)VAT;6PG.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=V
M87)R96YD97)E<E]D<FEV97(G72DI('L*("`@("`@("`@("`@)&1R:79E<B`]
M("1P87)A;7-;)W9A<G)E;F1E<F5R7V1R:79E<B==.PH@("`@("`@('T*("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U5)+U9A<E)E;F1E<F5R+G!H<"<[
M"B`@("`@("`@)'1H:7,M/E]V87)296YD97)E<B`]("9(;W)D95]525]687)2
M96YD97)E<CHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!S:&]W2&5A9&5R*"1B;V]L*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<VAO=TAE861E<B`]("1B;V]L.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!O<B!R971U<FYS('=H971H97(@=&AE(&9O<FT@=&ET;&4@<VAO
M=6QD(&)E(&5N8V]D960@=VET:`H@("`@("H@:'1M;'-P96-I86QC:&%R<R@I
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1E;F-O9&4@($EF('1R
M=64L('1H92!F;W)M('1I=&QE(&=E=',@96YC;V1E9"X@($EF(&9A;'-E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@=&ET;&4@8V%N(&-O
M;G1A:6X@2%1-3"P@8G5T('1H92!C;&%S<R!U<V5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!I<R!R97-P;VYS:6)L92!T;R!E;F-O9&4@86YY
M('-P96-I86P@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%=H971H97(@=&AE(&9O<FT@=&ET;&4@<VAO=6QD(&)E(&5N8V]D
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D951I=&QE*"1E;F-O9&4@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D96YC;V1E*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V5N8V]D951I=&QE(#T@)&5N8V]D93L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YC;V1E5&ET;&4@
M/2`D96YC;V1E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W!E8VEF>2!T:&4@
M=VED=&@@;V8@=&AE(&%T=')I8G5T92!C;VQU;6X@:6X@=&AE(')E;F1E<F5D
M(&9O<FTN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=VED=&@@(%1H
M92!W:61T:"!O9B!T:&4@871T<FEB=71E(&-O;'5M;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T071T<D-O
M;'5M;E=I9'1H*"1W:61T:"D*("`@('L*("`@("`@("`D=&AI<RT^7V%T=')#
M;VQU;6Y7:61T:"`]("1W:61T:#L*("`@('T*"B`@("!F=6YC=&EO;B!O<&5N
M*"1A8W1I;VXL("1M971H;V0L("1N86UE+"`D96YC='EP92`](&YU;&PI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("`@("`@)&YA
M;64@/2!H=&UL<W!E8VEA;&-H87)S*"1N86UE*3L*("`@("`@("!E8VAO("(\
M9F]R;2!A8W1I;VX]7"(D86-T:6]N7"(@;65T:&]D/5PB)&UE=&AO9%PB(B`N
M("AE;7!T>2@D;F%M92D@/R`G)R`Z("(@;F%M93U<(B1N86UE7"(@:60]7"(D
M;F%M95PB(BD@+B`H:7-?;G5L;"@D96YC='EP92D@/R`G)R`Z("(@96YC='EP
M93U<(B1E;F-T>7!E7"(B*2`N("(^7&XB.PH@("`@("`@(%5T:6PZ.G!F;W)M
M26YP=70H*3L*("`@('T*"B`@("!F=6YC=&EO;B!B96=I;D%C=&EV92@D;F%M
M92P@)&5X=')A(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W)E;F1E
M<D)E9VEN06-T:79E*"1N86UE+"`D97AT<F$I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&)E9VEN26YA8W1I=F4H)&YA;64L("1E>'1R82`](&YU;&PI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]R96YD97)"96=I;DEN86-T:79E*"1N86UE+"`D
M97AT<F$I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)396-T:6]N5&%B
M<R@F)&9O<FTI"B`@("!["B`@("`@("`@+RH@268@:F%V87-C<FEP="!I<R!N
M;W0@879A:6QA8FQE+"!D;R!N;W0@<F5N9&5R('1A8G,N("HO"B`@("`@("`@
M:68@*"$D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=J879A<V-R
M:7!T)RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@)&]P96Y?<V5C=&EO;B`]("1F;W)M+3YG971/<&5N4V5C=&EO;B@I.PH*
M("`@("`@("`O*B!!9&0@=&AE(&IA=F%S8W)I<'0@9F]R('1H92!T;V=G;&EN
M9R!T:&4@<V5C=&EO;G,N("HO"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I
M;&4H)V9O<FU?<V5C=&EO;G,N:G,G+"`G:&]R9&4G*3L*("`@("`@("!E8VAO
M("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^)R`N(")<;B(["B`@
M("`@("`@<')I;G1F*"=V87(@<V5C=&EO;G-?)3$D<R`](&YE=R!(;W)D95]&
M;W)M7U-E8W1I;VYS*%PG)3$D<UPG+"!<)R4R)'-<)RD[)RP*("`@("`@("`@
M("`@("`@)&9O<FTM/F=E=$YA;64H*2P*("`@("`@("`@("`@("`@)&]P96Y?
M<V5C=&EO;BD["B`@("`@("`@96-H;R`B7&XB("X@)SPO<V-R:7!T/B<["@H@
M("`@("`@("\J($QO;W`@=&AR;W5G:"!T:&4@<V5C=&EO;G,@86YD('!R:6YT
M(&]U="!A('1A8B!F;W(@96%C:"X@*B\*("`@("`@("!E8VAO("(\9&EV(&-L
M87-S/5PB=&%B<V5T7"(^/'5L/EQN(CL*("`@("`@("!F;W)E86-H("@D9F]R
M;2T^7W-E8W1I;VYS(&%S("1S96-T:6]N(#T^("1V86PI('L*("`@("`@("`@
M("`@)&-L87-S(#T@*"1S96-T:6]N(#T]("1O<&5N7W-E8W1I;VXI(#\@)R!C
M;&%S<STB86-T:79E5&%B(B<@.B`G)SL*("`@("`@("`@("`@)&IS(#T@<W!R
M:6YT9B@G;VYC;&EC:STB<V5C=&EO;G-?)7,N=&]G9VQE*%PG)7-<)RD[(')E
M='5R;B!F86QS93LB)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R
M;2T^9V5T3F%M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1S96-T
M:6]N*3L*("`@("`@("`@("`@<')I;G1F*"<\;&DE<R!I9#TB)7,B/CQA(&AR
M968](B,B("5S/B5S)7,\+V$^(#PO;&D^)R`N(")<;B(L"B`@("`@("`@("`@
M("`@("`@("`D8VQA<W,L("=?=&%B7R<@+B`D<V5C=&EO;BP@)&IS+`H@("`@
M("`@("`@("`@("`@("`@)&9O<FTM/F=E=%-E8W1I;VY);6%G92@D<V5C=&EO
M;BDL"B`@("`@("`@("`@("`@("`@("`D9F]R;2T^9V5T4V5C=&EO;D1E<V,H
M)'-E8W1I;VXI*3L*("`@("`@("!]"B`@("`@("`@96-H;R`B/"]U;#X\+V1I
M=CX\8G(@8VQA<W,]7")C;&5A<EPB("\^7&XB.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)396-T:6]N0F5G:6XH)B1F;W)M+"`D<V5C=&EO;BD*("`@
M('L*("`@("`@("`O+R!3=')I<&4@86QT97)N871E(')O=W,@:68@=&AA="!O
M<'1I;VX@:7,@='5R;F5D(&]N+@H@("`@("`@(&EF("@D=&AI<RT^7W-T<FEP
M9612;W=S*2!["B`@("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=S
M=')I<&4N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("`@("`@)&-L87-S
M(#T@)R!C;&%S<STB<W1R:7!E9"(G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1C;&%S<R`]("<G.PH@("`@("`@('T*"B`@("`@("`@)&]P96Y?
M<V5C=&EO;B`]("1F;W)M+3YG971/<&5N4V5C=&EO;B@I.PH@("`@("`@(&EF
M("AE;7!T>2@D;W!E;E]S96-T:6]N*2D@>PH@("`@("`@("`@("`D;W!E;E]S
M96-T:6]N(#T@)U]?8F%S92<["B`@("`@("`@?0H@("`@("`@('!R:6YT9B@G
M/&1I=B!I9#TB)7,B('-T>6QE/2)D:7-P;&%Y.B5S.R(^/'1A8FQE)7,@8V5L
M;'-P86-I;F<](C`B/B<L"B`@("`@("`@("`@("`@("=?<V5C=&EO;E\G("X@
M)'-E8W1I;VXL"B`@("`@("`@("`@("`@("@D;W!E;E]S96-T:6]N(#T]("1S
M96-T:6]N(#\@)V)L;V-K)R`Z("=N;VYE)RDL"B`@("`@("`@("`@("`@("1C
M;&%S<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E-E8W1I;VY%;F0H
M*0H@("`@>PH@("`@("`@(&5C:&\@)SPO=&%B;&4^/"]D:78^)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!E;F0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5N
M9&5R16YD*"D["B`@("!]"@H@("`@9G5N8W1I;VX@8VQO<V4H)&9O8W5S(#T@
M=')U92D*("`@('L*("`@("`@("!E8VAO("(\+V9O<FT^7&XB.PH@("`@("`@
M(&EF("@D9F]C=7,@)B8@(65M<'1Y*"1T:&ES+3Y?9FER<W1&:65L9"DI('L*
M("`@("`@("`@("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I
M<'0B/@H\(2TM"G1R>2!["B`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B
M)R`N("1T:&ES+3Y?9FER<W1&:65L9"`N("<B*2YF;V-U<R@I.PI](&-A=&-H
M*&4I('M]"B\O+2T^"CPO<V-R:7!T/@HG.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!L:7-T1F]R;59A<G,H)B1F;W)M*0H@("`@>PH@("`@("`@
M("1V87)I86)L97,@/2`F)&9O<FTM/F=E=%9A<FEA8FQE<RAT<G5E+"!T<G5E
M*3L*("`@("`@("`D=F%R<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1V87)I
M86)L97,I('L*("`@("`@("`@("`@9F]R96%C:"`H)'9A<FEA8FQE<R!A<R`D
M=F%R*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1V87(I*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"$D=F%R+3YI<U)E861O;FQY*"DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A<G-;)'9A<BT^9V5T5F%R
M3F%M92@I72`](#$["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=F%R<ULD=F%R
M72`](#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92].3%,N<&AP)SL*("`@
M("`@("!E8VAO("<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)?9F]R;79A
M<G,B('9A;'5E/2(G("X@0&AT;6QS<&5C:6%L8VAA<G,H<V5R:6%L:7IE*"1V
M87)S*2P@14Y47U%53U1%4RP@3DQ3.CIG971#:&%R<V5T*"DI("X@)R(@+SXG
M.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;F1E<D9O<FU!8W1I=F4H)B1F;W)M
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'1H:7,M/E]R96YD97)&;W)M*"1F
M;W)M+"`D=F%R<RP@=')U92D["B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R
M1F]R;4EN86-T:79E*"8D9F]R;2P@)B1V87)S*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<F5N9&5R1F]R;2@D9F]R;2P@)'9A<G,L(&9A;'-E*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R1F]R;2@F)&9O<FTL("8D=F%R<RP@)&%C
M=&EV92D*("`@('L*("`@("`@("`O*B!)9B!H96QP(&ES('!R97-E;G0@,R!C
M;VQU;6YS(&%R92!N965D960N("HO"B`@("`@("`@)'1H:7,M/E]C;VQS(#T@
M)&9O<FTM/FAA<TAE;'`H*2`_(#,@.B`R.PH*("`@("`@("`D=F%R:6%B;&5S
M(#T@)B1F;W)M+3YG971687)I86)L97,H9F%L<V4I.PH*("`@("`@("`O*B!#
M:&5C:R!F;W(@82!F;W)M('1O:V5N(&5R<F]R+B`J+PH@("`@("`@(&EF("@H
M)'1O:V5N17)R;W(@/2`D9F]R;2T^9V5T17)R;W(H)U]?9F]R;51O:V5N)RDI
M("$]/2!N=6QL*2!["B`@("`@("`@("`@('!R:6YT9B@G/'1R('9A;&EG;CTB
M=&]P(CX\=&0@8V]L<W!A;CTB)60B/CQS<&%N(&-L87-S/2)F;W)M+65R<F]R
M(CXE<SPO<W!A;CX\+W1D/CPO='(^)RP*("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8V]L<RP*("`@("`@("`@("`@("`@("`@("1T;VME;D5R<F]R*3L*
M("`@("`@("!]"@H@("`@("`@("1E<G)O<E]S96-T:6]N(#T@;G5L;#L*("`@
M("`@("!R97-E="@D=F%R:6%B;&5S*3L*("`@("`@("!I9B`H8V]U;G0H)'9A
M<FEA8FQE<RD@/B`Q('Q\(&ME>2@D=F%R:6%B;&5S*2`A/2`G7U]B87-E)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7W)E;F1E<E-E8W1I;VY486)S*"1F;W)M
M*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1V87)I86)L97,@87,@
M)'-E8W1I;VY?:60@/3X@)'-E8W1I;VXI('L*("`@("`@("`@("`@)'1H:7,M
M/E]R96YD97)396-T:6]N0F5G:6XH)&9O<FTL("1S96-T:6]N7VED*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)'-E8W1I;VX@87,@)'9A<BD@>PH@("`@("`@
M("`@("`@("`@)'1Y<&4@/2`D=F%R+3YG9714>7!E3F%M92@I.PH*("`@("`@
M("`@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@("`@(&-A
M<V4@)VAE861E<B<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD
M97)(96%D97(H)'9A<BT^9V5T2'5M86Y.86UE*"DL("1F;W)M+3YG971%<G)O
M<B@D=F%R+3YG971687).86UE*"DI*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=D97-C<FEP=&EO;B<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD97)$97-C<FEP=&EO;B@D
M=F%R+3YG971(=6UA;DYA;64H*2D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G<W!A8V5R)SH*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E;F1E<E-P86-E<B@I.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`@("`@)&ES26YP=70@/2`H)&%C=&EV92`F)B`A)'9A
M<BT^:7-296%D;VYL>2@I*3L*("`@("`@("`@("`@("`@("`@("`D9F]R;6%T
M(#T@)&ES26YP=70@/R`G26YP=70G(#H@)T1I<W!L87DG.PH@("`@("`@("`@
M("`@("`@("`@("1B96=I;B`](")?<F5N9&5R5F%R)'MF;W)M871]0F5G:6XB
M.PH@("`@("`@("`@("`@("`@("`@("1E;F0@/2`B7W)E;F1E<E9A<B1[9F]R
M;6%T?45N9"(["@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3XD8F5G:6XH
M)&9O<FTL("1V87(L("1V87)S*3L*"B`@("`@("`@("`@("`@("`@("`@96-H
M;R`D=&AI<RT^7W9A<E)E;F1E<F5R+3YR96YD97(H)&9O<FTL("1V87(L("1V
M87)S+"`D:7-);G!U="D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/B1E
M;F0H)&9O<FTL("1V87(L("1V87)S*3L*"B`@("`@("`@("`@("`@("`@("`@
M+RH@4')I;G0@86YY(&IA=F%S8W)I<'0@:68@86-T:6]N<R!P<F5S96YT+B`J
M+PH@("`@("`@("`@("`@("`@("`@(&EF("@D=F%R+3YH87-!8W1I;VXH*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3Y?86-T:6]N+3YP<FEN
M=$IA=F%38W)I<'0H*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("\J($ME97`@9FER<W0@9FEE;&0N("HO"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1A8W1I=F4@)B8@96UP='DH)'1H:7,M/E]F:7)S
M=$9I96QD*2`F)B`A)'9A<BT^:7-296%D;VYL>2@I("8F("$D=F%R+3YI<TAI
M9&1E;B@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FER
M<W1&:65L9"`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J($ME97`@<V5C=&EO;B!W
M:71H(&9I<G-T(&5R<F]R+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]N=6QL*"1E<G)O<E]S96-T:6]N*2`F)B`D9F]R;2T^9V5T17)R;W(H)'9A
M<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R7W-E8W1I;VX@
M/2`D<V5C=&EO;E]I9#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?
M<F5N9&5R4V5C=&EO;D5N9"@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<U]N=6QL*"1E<G)O<E]S96-T:6]N*2`F)B`D9F]R;2T^7W-E8W1I;VYS*2![
M"B`@("`@("`@("`@(&5C:&\@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CXG("X*("`@("`@("`@("`@("`@(")<;B(@+B!S<')I;G1F*"=S96-T
M:6]N<U\E<RYT;V=G;&4H7"<E<UPG*3LG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<FTM/F=E=$YA;64H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G)O<E]S96-T:6]N*2`N"B`@("`@("`@("`@
M("`@("`B7&X\+W-C<FEP=#XB.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!S=6)M:70H)'-U8FUI="`](&YU;&PL("1R97-E="`](&9A;'-E*0H@
M("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1S=6)M:70I('Q\(&5M<'1Y*"1S
M=6)M:70I*2!["B`@("`@("`@("`@("1S=6)M:70@/2!?*")3=6)M:70B*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1R97-E="`]/3T@=')U92D@>PH@("`@
M("`@("`@("`D<F5S970@/2!?*")297-E="(I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7W)E;F1E<E-U8FUI="@D<W5B;6ET+"`D<F5S970I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@26UP;&5M96YT871I;VX@<W!E8VEF:6,@8F5G
M:6X@9G5N8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96YD97)"96=I
M;D%C=&EV92@D;F%M92P@)&5X=')A*0H@("`@>PH@("`@("`@(&5C:&\@)SQD
M:78@8VQA<W,](F9O<FTB(&ED/2(G("X@:'1M;'-P96-I86QC:&%R<R@D=&AI
M<RT^7VYA;64I("X@)R(^)SL*("`@("`@("!I9B`H)'1H:7,M/E]S:&]W2&5A
M9&5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5C=&EO;DAE861E<B@D;F%M
M92P@)&5X=')A*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?<F5Q
M=6ER961,96=E;F0I('L*("`@("`@("`@("`@96-H;R`G/'-P86X@8VQA<W,]
M(F9O<FTM97)R;W(B/B<@+B`D=&AI<RT^7W)E<75I<F5D36%R:V5R("X@)SPO
M<W!A;CX@/2`G("X@7R@B4F5Q=6ER960@1FEE;&0B*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!);7!L96UE;G1A=&EO;B!S<&5C:69I8R!B
M96=I;B!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E;F1E<D)E
M9VEN26YA8W1I=F4H)&YA;64L("1E>'1R82D*("`@('L*("`@("`@("!E8VAO
M("<\9&EV(&-L87-S/2)F;W)M(B!I9#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H
M)'1H:7,M/E]N86UE*2`N("<B/B<["B`@("`@("`@:68@*"1T:&ES+3Y?<VAO
M=TAE861E<BD@>PH@("`@("`@("`@("`D=&AI<RT^7W-E8W1I;VY(96%D97(H
M)&YA;64L("1E>'1R82D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@26UP;&5M96YT871I;VX@<W!E8VEF:6,@96YD(&9U;F-T:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<F5N9&5R16YD*"D*("`@('L*("`@("`@("!E
M8VAO("<\+V1I=CXG("X@)'1H:7,M/E]V87)296YD97)E<BT^<F5N9&5R16YD
M*"D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<DAE861E<B@D:&5A9&5R
M+"`D97)R;W(@/2`G)RD*("`@('L*/SX\='(^/'1D(&-L87-S/2)C;VYT<F]L
M(B!W:61T:#TB,3`P)2(@8V]L<W!A;CTB/#]P:'`@96-H;R`D=&AI<RT^7V-O
M;',@/SXB('9A;&EG;CTB8F]T=&]M(CX\<W1R;VYG/CP_<&AP(&5C:&\@)&AE
M861E<B`_/CPO<W1R;VYG/CP_<&AP"B`@("`@("`@:68@*"%E;7!T>2@D97)R
M;W(I*2!["C\^/&)R("\^/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/CP_<&AP
M(&5C:&\@)&5R<F]R(#\^/"]S<&%N/CP_<&AP"B`@("`@("`@?0H_/CPO=&0^
M/"]T<CX*/#]P:'`*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R1&5S8W)I
M<'1I;VXH)'1E>'0I"B`@("!["C\^/'1R/CQT9"!W:61T:#TB,3`P)2(@8V]L
M<W!A;CTB/#]P:'`@96-H;R`D=&AI<RT^7V-O;',@/SXB/CQP('-T>6QE/2)P
M861D:6YG.CAP>"(^/#]P:'`@96-H;R`D=&5X="`_/CPO<#X\+W1D/CPO='(^
M"CP_<&AP"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E-P86-E<B@I"B`@
M("!["C\^/'1R/CQT9"!C;VQS<&%N/2(\/W!H<"!E8VAO("1T:&ES+3Y?8V]L
M<R`_/B(^)FYB<W`[/"]T9#X\+W1R/@H\/W!H<`H@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)3=6)M:70H)'-U8FUI="P@)')E<V5T*0H@("`@>PH_/CQD
M:78@8VQA<W,](F-O;G1R;VPB/@H@(#P_<&AP(&EF("@A:7-?87)R87DH)'-U
M8FUI="DI("1S=6)M:70@/2!A<G)A>2@D<W5B;6ET*3L@9F]R96%C:"`H)'-U
M8FUI="!A<R`D<W5B;6ET8G5T=&]N*3H@/SX*("`@(#QI;G!U="!C;&%S<STB
M8G5T=&]N(B!N86UE/2)S=6)M:71B=71T;VXB('1Y<&4](G-U8FUI="(@=F%L
M=64](CP_<&AP(&5C:&\@)'-U8FUI=&)U='1O;B`_/B(@+SX*("`\/W!H<"!E
M;F1F;W)E86-H.R`_/@H@(#P_<&AP(&EF("@A96UP='DH)')E<V5T*2DZ(#\^
M"B`@("`\:6YP=70@8VQA<W,](F)U='1O;B(@;F%M93TB<F5S971B=71T;VXB
M('1Y<&4](G)E<V5T(B!V86QU93TB/#]P:'`@96-H;R`D<F5S970@/SXB("\^
M"B`@/#]P:'`@96YD:68[(#\^"CPO9&EV/@H\/W!H<`H@("`@?0H*("`@("\O
M($EM<&QE;65N=&%T:6]N('-P96-I9FEC<R`M+2!I;G!U="!V87)I86)L97,N
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71"96=I;B@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&UE<W-A9V4@/2`D9F]R;2T^
M9V5T17)R;W(H)'9A<BD["B`@("`@("`@)&ES=F%L:60@/2!E;7!T>2@D;65S
M<V%G92D["B`@("`@("`@96-H;R`B/'1R('9A;&EG;CU<(G1O<%PB/EQN(CL*
M("`@("`@("!P<FEN=&8H)R`@/'1D)7,@86QI9VX](G)I9VAT(CXE<R5S)7,E
M<SPO=&0^)R`N(")<;B(L"B`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?
M871T<D-O;'5M;E=I9'1H*2`_("<G(#H@)R!W:61T:#TB)R`N("1T:&ES+3Y?
M871T<D-O;'5M;E=I9'1H("X@)R(G+`H@("`@("`@("`@("`@("`D:7-V86QI
M9"`_("<G(#H@)SQS<&%N(&-L87-S/2)F;W)M+65R<F]R(CXG+`H@("`@("`@
M("`@("`@("`D=F%R+3YI<U)E<75I<F5D*"D@/R`G/'-P86X@8VQA<W,](F9O
M<FTM97)R;W(B/B<@+B`D=&AI<RT^7W)E<75I<F5D36%R:V5R("X@)SPO<W!A
M;CXF;F)S<#LG(#H@)R<L"B`@("`@("`@("`@("`@("1V87(M/F=E=$AU;6%N
M3F%M92@I+`H@("`@("`@("`@("`@("`D:7-V86QI9"`_("<G(#H@)SQB<B`O
M/B<@+B`D;65S<V%G92`N("<\+W-P86X^)RD["B`@("`@("`@<')I;G1F*"<@
M(#QT9"5S/B<L"B`@("`@("`@("`@("`@("@H(21V87(M/FAA<TAE;'`H*2`F
M)B`D9F]R;2T^:&%S2&5L<"@I*2`_("<@8V]L<W!A;CTB,B(G(#H@)R<I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71%;F0H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("\J($1I<W!L87D@86YY
M(&1E<V-R:7!T:6]N(&9O<B!T:&4@9FEE;&0N("HO"B`@("`@("`@:68@*"1V
M87(M/FAA<T1E<V-R:7!T:6]N*"DI('L*("`@("`@("`@("`@96-H;R`G/&)R
M("\^)R`N("1V87(M/F=E=$1E<V-R:7!T:6]N*"D["B`@("`@("`@?0H*("`@
M("`@("`O*B!$:7-P;&%Y(&%N>2!H96QP(&9O<B!T:&4@9FEE;&0N("HO"B`@
M("`@("`@:68@*"1V87(M/FAA<TAE;'`H*2D@>PH@("`@("`@("`@("!G;&]B
M86P@)')E9VES=')Y.PH@("`@("`@("`@("!I9B`H:7-S970H)')E9VES=')Y
M*2`F)B!I<U]A*"1R96=I<W1R>2P@)U)E9VES=')Y)RDI('L*("`@("`@("`@
M("`@("`@("1L:6YK(#T@2&5L<#HZ;&EN:R@D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T07!P*"DL("1V87(M/F=E=$AE;'`H*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D;&EN:R`]("<\82!H<F5F/2(C(B!O
M;F-L:6-K/2)A;&5R="A<)R<@+B!A9&1S;&%S:&5S*$!H=&UL<W!E8VEA;&-H
M87)S*"1V87(M/F=E=$AE;'`H*2DI("X@)UPG*3MR971U<FX@9F%L<V4[(CXG
M("X@)'1H:7,M/E]H96QP36%R:V5R("X@)SPO83XG.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5C:&\@(CPO=&0^7&X@(#QT9"!S='EL93U<(G1E>'0M
M86QI9VXZ<FEG:'1<(CXD;&EN:R9N8G-P.R(["B`@("`@("`@?0H*("`@("`@
M("!E8VAO("(\+W1D/EQN/"]T<CY<;B(["B`@("!]"@H@("`@+R\@26UP;&5M
M96YT871I;VX@<W!E8VEF:6-S("TM(&1I<W!L87D@=F%R:6%B;&5S+@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E"96=I;B@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&UE<W-A9V4@/2`D9F]R;2T^9V5T
M17)R;W(H)'9A<BD["B`@("`@("`@)&ES=F%L:60@/2!E;7!T>2@D;65S<V%G
M92D["B`@("`@("`@96-H;R`B/'1R('9A;&EG;CU<(G1O<%PB/EQN(CL*("`@
M("`@("!P<FEN=&8H)R`@/'1D)7,@86QI9VX](G)I9VAT(CXE<SQS=')O;F<^
M)7,\+W-T<F]N9SXE<SPO=&0^)R`N(")<;B(L"B`@("`@("`@("`@("`@(&5M
M<'1Y*"1T:&ES+3Y?871T<D-O;'5M;E=I9'1H*2`_("<G(#H@)R!W:61T:#TB
M)R`N("1T:&ES+3Y?871T<D-O;'5M;E=I9'1H("X@)R(G+`H@("`@("`@("`@
M("`@("`D:7-V86QI9"`_("<G(#H@)SQS<&%N(&-L87-S/2)F;W)M+65R<F]R
M(CXG+`H@("`@("`@("`@("`@("`D=F%R+3YG971(=6UA;DYA;64H*2P*("`@
M("`@("`@("`@("`@)&ES=F%L:60@/R`G)R`Z("<\8G(@+SXG("X@)&UE<W-A
M9V4@+B`G/"]S<&%N/B<I.PH@("`@("`@(&5C:&\@)R`@/'1D/B<["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E%;F0H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(&5C:&\@(CPO=&0^7&X\+W1R
M/EQN(CL*("`@('T*"B`@("!F=6YC=&EO;B!?<V5C=&EO;DAE861E<B@D=&ET
M;&4L("1E>'1R82`]("<G*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)'1I
M=&QE*2D@>PH@("`@("`@("`@("!E8VAO("<\9&EV(&-L87-S/2)H96%D97(B
M/B<["B`@("`@("`@("`@(&EF("@A96UP='DH)&5X=')A*2D@>PH@("`@("`@
M("`@("`@("`@96-H;R`G/'-P86X@<W1Y;&4](F9L;V%T.G)I9VAT(CXG("X@
M)&5X=')A("X@)SPO<W!A;CXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5C:&\@)'1H:7,M/E]E;F-O9&54:71L92`_(&AT;6QS<&5C:6%L8VAA<G,H
M)'1I=&QE*2`Z("1T:71L93L*("`@("`@("`@("`@96-H;R`G/"]D:78^)SL*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!C;VYC<F5T92!(;W)D95]&;W)M7U)E;F1E<F5R(&EN<W1A;F-E
M(&)A<V5D(&]N"B`@("`@*B`D<F5N9&5R97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1R96YD97)E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R
M9&5?1F]R;5]296YD97)E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@<W5B8VQA<W,@=&\@<F5T=7)N+B!4:&4@8V]D92!I<R!D>6YA;6EC86QL
M>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@:6YC;'5D960N($EF
M("1R96YD97)E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!L;V]K(&EN("1R96YD97)E<ELP72]L
M:6(O1F]R;2]296YD97)E<B\@9F]R('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)')E
M;F1E<F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@
M($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I
M;VX@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2!M:6=H
M="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?1F]R;5]296YD
M97)E<B`@5&AE(&-O;F-R971E($AO<F1E7T9O<FU?4F5N9&5R97(@<F5F97)E
M;F-E+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!F
M86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)')E;F1E<F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H:7-?87)R87DH)')E;F1E<F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@
M)')E;F1E<F5R6S!=.PH@("`@("`@("`@("`D<F5N9&5R97(@/2`D<F5N9&5R
M97);,5T["B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@82!B87-E($AO
M<F1E7T9O<FU?4F5N9&5R97(@;V)J96-T(&EF(&YO(&1R:79E<B!I<PH@("`@
M("`@("`J('-P96-I9FEE9"X@*B\*("`@("`@("`D<F5N9&5R97(@/2!B87-E
M;F%M92@D<F5N9&5R97(I.PH@("`@("`@(&EF("AE;7!T>2@D<F5N9&5R97(I
M('Q\("AS=')C;7`H)')E;F1E<F5R+"`G;F]N92<I(#T](#`I*2!["B`@("`@
M("`@("`@("1F;W)M<F5N9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R
M97(H)'!A<F%M<RD["B`@("`@("`@("`@(')E='5R;B`D9F]R;7)E;F1E<F5R
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@
M("`@("`@("!I;F-L=61E7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+T9O<FTO4F5N9&5R97(O)R`N
M("1R96YD97)E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?
M97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]296YD97)E<B\G("X@)')E
M;F1E<F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E;F1E<F5R+R<@+B`D<F5N9&5R97(@
M+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU
M9&5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<B\G("X@)')E;F1E<F5R("X@
M)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?1F]R
M;5]296YD97)E<E\G("X@)')E;F1E<F5R.PH@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D9F]R;7)E;F1E<F5R(#T@
M)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&9O<FUR96YD97)E<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S
M(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F;W)M<F5N9&5R97(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N
M8V4@=&\@82!C;VYC<F5T92!(;W)D95]&;W)M7U)E;F1E<F5R"B`@("`@*B!I
M;G-T86YC92!B87-E9"!O;B`D<F5N9&5R97(N($ET('=I;&P@;VYL>2!C<F5A
M=&4@82!N97<@:6YS=&%N8V4@:68@;F\*("`@("`J($AO<F1E7T9O<FU?4F5N
M9&5R97(@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E
M;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E
M9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F;W)M(')E;F1E<F5R<R`H86YD+`H@
M("`@("H@=&AU<RP@;75L=&EP;&4@2&]R9&5?1F]R;5]296YD97)E<B!I;G-T
M86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&]R9&5?1F]R;5]296YD
M97)E<CHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)')E;F1E<F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]&;W)M7U)E
M;F1E<F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S
M<R!T;R!R971U<FXN(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E9"X@268@)')E;F1E<F5R
M(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&QO;VL@:6X@)')E;F1E<F5R6S!=+VQI8B]&;W)M+U)E
M;F1E<F5R+R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE9"`D<F5N9&5R97);,5TN
M<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&9O<FT@;6EG:'0@;F5E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($AO<F1E7T9O<FU?4F5N9&5R97(@(%1H92!C;VYC
M<F5T92!(;W)D95]&;W)M7U)E;F1E<F5R(')E9F5R96YC92P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@9F%L<V4@;VX@86X@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)')E;F1E<F5R
M+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A
M;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@
M("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@
M("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D<F5N9&5R97(L("1P
M87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA
M='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@
M/2`F2&]R9&5?1F]R;5]296YD97)E<CHZ9F%C=&]R>2@D<F5N9&5R97(L("1P
M87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;
M)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E
M<W,O````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S<S`#`R,#`S,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,C$P-S0`,3`T,3<S-C(W-S,`,#(Q,S$W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@2&]R9&5?0V]M<')E<W-?9&)X(&-L87-S(&%L;&]W<R!D8G@@
M9FEL97,@*&4N9RX@9G)O;2!/=71L;V]K($5X<')E<W,I"B`J('1O(&)E(')E
M860N"B`J"B`J(%1H:7,@8VQA<W,@:7,@8F%S960@;VX@8V]D92!B>3H*("H@
M06YT;VYY(%)A:6IE:V]V(#QD979`<W1R871E9VUA+F)G/@H@*B!H='1P.B\O
M=7)U9',N9V%T97=A>2YB9R]Z96]S+PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP+'8@,2XS+C$R+CD@,C`P-B\P
M,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-O
M;7!R97-S"B`J+PIC;&%S<R!(;W)D95]#;VUP<F5S<U]D8G@@97AT96YD<R!(
M;W)D95]#;VUP<F5S<R!["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]M86EL<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T;7`@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@1&5C;VUP<F5S<V5S(&$@1$)8(&9I;&4@86YD(&=E=',@
M:6YF;W)M871I;VX@9G)O;2!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D871A("!4:&4@9&)X(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!!;GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@<F5Q=65S=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E
M8V]M<')E<W,H)B1D871A+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@
M("`D=&AI<RT^7VUA:6QS(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W1M
M<"`](&%R<F%Y*"D["B`@("`@("`@)'!O<VET:6]N(#T@,'A#-#L*("`@("`@
M("`D:&5A9&5R7VEN9F\@/2!U;G!A8VLH)TQP;W-I=&EO;B],1&%T84QE;F=T
M:"]N2&5A9&5R3&5N9W1H+VY&;&%G0V]U;G0G+"!S=6)S='(H)&1A=&$L("1P
M;W-I=&EO;BP@,3(I*3L*("`@("`@("`D<&]S:71I;VX@*ST@,3(["B`@("`@
M("`@+R\@1V\@=&\@=&AE(&9I<G-T('1A8FQE(&]F9F5S="!A;F0@<')O8V5S
M<R!I="X*("`@("`@("!I9B`H)&AE861E<E]I;F9O6R=P;W-I=&EO;B==(#X@
M,"D@>PH@("`@("`@("`@("`D<&]S:71I;VX@/2`P>#,P.PH@("`@("`@("`@
M("`D8G5F(#T@=6YP86-K*"=,<&]S:71I;VXG+"!S=6)S='(H)&1A=&$L("1P
M;W-I=&EO;BP@-"DI.PH@("`@("`@("`@("`D<&]S:71I;VX@/2`D8G5F6R=P
M;W-I=&EO;B==.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]R96%D
M26YD97@H)&1A=&$L("1P;W-I=&EO;BD["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7VUA:6QS.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A(&YU;&PM=&5R;6EN871E9"!S=')I;F<@9G)O;2!T:&4@<W!E
M8VEF:65D(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&)U9B`@5$]$3PH@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'!O<R`@5$]$3PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96%D4W1R
M:6YG*"8D8G5F+"`D<&]S*0H@("`@>PH@("`@("`@(&EF("@D;&5N(#T@<W1R
M<&]S*'-U8G-T<B@D8G5F+"`D<&]S*2P@8VAR*#`I*2D@>PH@("`@("`@("`@
M("!R971U<FX@<W5B<W1R*"1B=68L("1P;W,L("1L96XI.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`F)&1A=&$@("`@("!43T1/"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<&]S:71I;VX@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?<F5A9$UE<W-A
M9V4H)B1D871A+"`D<&]S:71I;VXI"B`@("!["B`@("`@("`@)&US9R`]("<G
M.PH@("`@("`@("1P87)T(#T@,#L*"B`@("`@("`@:68@*"1P;W-I=&EO;B`^
M(#`I('L*("`@("`@("`@("`@)$EN9&5X271E;7-#;W5N="`](&%R<F%Y7W!O
M<"AU;G!A8VLH)U,G+"!S=6)S='(H)&1A=&$L(#!X0S0L(#0I*2D["B`@("`@
M("`@("`@(&EF("@D26YD97A)=&5M<T-O=6YT(#X@,"D@>PH@("`@("`@("`@
M("`@("`@=VAI;&4@*"1P;W-I=&EO;B`\('-T<FQE;B@D9&%T82DI('L*("`@
M("`@("`@("`@("`@("`@("`D<&%R="LK.PH@("`@("`@("`@("`@("`@("`@
M("1S(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL(#4R."D["B`@("`@("`@
M("`@("`@("`@("`@:68@*'-T<FQE;B@D<RD@/3T@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)&US9U]I=&5M(#T@=6YP86-K*"=,1FEL95!O
M<R],56YK;F]W;B],271E;5-I>F4O3$YE>'1)=&5M+V$U,3)#;VYT96YT)RP@
M)',I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D;7-G7VET96U;)T9I;&50
M;W,G72`A/2`D<&]S:71I;VXI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!F:6QE(&9O<FUA
M="(I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)'!O<VET:6]N("L](#4R.#L*("`@("`@("`@("`@("`@("`@("`D;7-G
M("X]('-U8G-T<B@D;7-G7VET96U;)T-O;G1E;G0G72P@,"P@)&US9U]I=&5M
M6R=)=&5M4VEZ92==*3L*("`@("`@("`@("`@("`@("`@("`D<&]S:71I;VX@
M/2`D;7-G7VET96U;)TYE>'1)=&5M)UT["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1P;W-I=&EO;B`]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M
M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F
M)&1A=&$@("`@("!43T1/"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&]S:71I
M;VX@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!43T1/"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]R96%D365S<V%G94EN9F\H)B1D871A+"`D
M<&]S:71I;VXI"B`@("!["B`@("`@("`@)&UE<W-A9V5?:6YF;R`](&%R<F%Y
M*"D["B`@("`@("`@)&US9U]H96%D97(@/2!U;G!A8VLH)TQP;W-I=&EO;B],
M1&%T84QE;F=T:"]32&5A9&5R3&5N9W1H+U-&;&%G0V]U;G0G+"!S=6)S='(H
M)&1A=&$L("1P;W-I=&EO;BP@,3(I*3L*("`@("`@("!I9B`H)&US9U]H96%D
M97);)W!O<VET:6]N)UT@(3T@)'!O<VET:6]N*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@9FEL92!F;W)M870B
M*2D["B`@("`@("`@?0H@("`@("`@("1P;W-I=&EO;B`K/2`Q,CL*("`@("`@
M("`D;65S<V%G95]I;F9O6R=(96%D97)0;W-I=&EO;B==(#T@)&US9U]H96%D
M97);)W!O<VET:6]N)UT["B`@("`@("`@)&9L86=S(#T@)&US9U]H96%D97);
M)T9L86=#;W5N="==("8@,'A&1CL*("`@("`@("`D1&%T85-I>F4@/2`D;7-G
M7VAE861E<ELG1&%T84QE;F=T:"==("T@)&9L86=S("H@-#L*("`@("`@("`D
M<VEZ92`](#0@*B`D9FQA9W,["B`@("`@("`@)$9L86=S0G5F9F5R(#T@<W5B
M<W1R*"1D871A+"`D<&]S:71I;VXL("1S:7IE*3L*("`@("`@("`D<&]S:71I
M;VX@*ST@)'-I>F4["B`@("`@("`@)'-I>F4@/2`D1&%T85-I>F4["B`@("`@
M("`@)$1A=&%"=69F97(@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@)'-I
M>F4I.PH@("`@("`@("1P;W-I=&EO;B`K/2`D<VEZ93L*("`@("`@("`D;65S
M<V%G95]I;F9O(#T@87)R87DH*3L*"B`@("`@("`@)&9L86=?87)R87D@/2!A
M<G)A>2@*("`@("`@("`@("`@,'@Q(#T^("=-<V=&;&%G<R<L"B`@("`@("`@
M("`@(#!X,B`]/B`G4V5N="<L"B`@("`@("`@("`@(#!X-"`]/B`G<&]S:71I
M;VXG+`H@("`@("`@("`@("`P>#<@/3X@)TUE<W-A9V5)1"<L"B`@("`@("`@
M("`@(#!X."`]/B`G4W5B:F5C="<L"B`@("`@("`@("`@(#!X.2`]/B`G1G)O
M;5]R97!L>2<L"B`@("`@("`@("`@(#!X02`]/B`G4F5F97)E;F-E<R<L"B`@
M("`@("`@("`@(#!X0B`]/B`G3F5W<V=R;W5P)RP*("`@("`@("`@("`@,'A$
M(#T^("=&<F]M)RP*("`@("`@("`@("`@,'A%(#T^("=297!L>5]4;R<L"B`@
M("`@("`@("`@(#!X,3(@/3X@)U)E8V5I=F5D)RP*("`@("`@("`@("`@,'@Q
M,R`]/B`G4F5C96EP="<L"B`@("`@("`@("`@(#!X,4$@/3X@)T%C8V]U;G0G
M+`H@("`@("`@("`@("`P>#%"(#T^("=!8V-O=6YT240G+`H@("`@("`@("`@
M("`P>#@P(#T^("=-<V<G+`H@("`@("`@("`@("`P>#@Q(#T^("=-<V=&;&%G
M<R<L"B`@("`@("`@("`@(#!X.#0@/3X@)W!O<VET:6]N)RP*("`@("`@("`@
M("`@,'@Y,2`]/B`G<VEZ92<L"B`@("`@("`@*3L*"B`@("`@("`@+RH@4')O
M8V5S<R!F;&%G<R`J+PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1F;&%G
M<SL@)&DK*RD@>PH@("`@("`@("`@("`D<&]S(#T@,#L*("`@("`@("`@("`@
M)&8@/2!A<G)A>5]P;W`H=6YP86-K*"=,)RP@<W5B<W1R*"1&;&%G<T)U9F9E
M<BP@)&D@*B`T+"`T*2DI.PH*("`@("`@("`@("`@)&UA<VL@/2`D9B`F(#!X
M1D8["B`@("`@("`@("`@('-W:71C:"`H)&UA<VLI('L*("`@("`@("`@("`@
M8V%S92`P>#$Z"B`@("`@("`@("`@("`@("`D<&]S(#T@)'!O<R`K("@D9B`^
M/B`X*3L*("`@("`@("`@("`@("`@("1M97-S86=E7VEN9F];)TUS9T9L86=S
M)UT@/2!A<G)A>5]P;W`H=6YP86-K*"=#)RP@<W5B<W1R*"1$871A0G5F9F5R
M+"`D<&]S*RLL(#$I*2D["B`@("`@("`@("`@("`@("`D;65S<V%G95]I;F9O
M6R=-<V=&;&%G<R==("L](&%R<F%Y7W!O<"AU;G!A8VLH)T,G+"!S=6)S='(H
M)$1A=&%"=69F97(L("1P;W,K*RP@,2DI*2`J(#(U-CL*("`@("`@("`@("`@
M("`@("1M97-S86=E7VEN9F];)TUS9T9L86=S)UT@*ST@87)R87E?<&]P*'5N
M<&%C:R@G0R<L('-U8G-T<B@D1&%T84)U9F9E<BP@)'!O<RP@,2DI*2`J(#8U
M-3,V.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M(#!X,CH*("`@("`@("`@("`@8V%S92`P>#0Z"B`@("`@("`@("`@("`@("`D
M<&]S("L](&%R<F%Y7W!O<"AU;G!A8VLH)TPG+"!S=6)S='(H)$9L86=S0G5F
M9F5R+"`D:2`J(#0L(#0I*2D@/CX@.#L*("`@("`@("`@("`@("`@("1M97-S
M86=E7VEN9F];)&9L86=?87)R87E;)&UA<VM=72`](&%R<F%Y7W!O<"AU;G!A
M8VLH)TPG+"!S=6)S='(H)$1A=&%"=69F97(L("1P;W,L(#0I*2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@W.@H@("`@
M("`@("`@("!C87-E(#!X.#H*("`@("`@("`@("`@8V%S92`P>#DZ"B`@("`@
M("`@("`@(&-A<V4@,'A!.@H@("`@("`@("`@("!C87-E(#!X0CH*("`@("`@
M("`@("`@8V%S92`P>$0Z"B`@("`@("`@("`@(&-A<V4@,'A%.@H@("`@("`@
M("`@("!C87-E(#!X,3,Z"B`@("`@("`@("`@(&-A<V4@,'@Q03H*("`@("`@
M("`@("`@("`@("1P;W,@*ST@87)R87E?<&]P*'5N<&%C:R@G3"<L('-U8G-T
M<B@D1FQA9W-"=69F97(L("1I("H@-"P@-"DI*2`^/B`X.PH@("`@("`@("`@
M("`@("`@)&UE<W-A9V5?:6YF;ULD9FQA9U]A<G)A>5LD;6%S:UU=(#T@)'1H
M:7,M/E]R96%D4W1R:6YG*"1$871A0G5F9F5R+"`D<&]S*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#$R.@H@("`@("`@
M("`@("`@("`@)'!O<R`K/2!A<G)A>5]P;W`H=6YP86-K*"=,)RP@<W5B<W1R
M*"1&;&%G<T)U9F9E<BP@)&D@*B`T+"`T*2DI(#X^(#@["B`@("`@("`@("`@
M("`@("`D;65S<V%G95]I;F9O6R=296-E:79E9"==(#T@87)R87E?<&]P*'5N
M<&%C:R@G3"<L('-U8G-T<B@D1&%T84)U9F9E<BP@)'!O<RP@-"DI*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#%".@H@
M("`@("`@("`@("`@("`@)'!O<R`K/2!A<G)A>5]P;W`H=6YP86-K*"=,)RP@
M<W5B<W1R*"1&;&%G<T)U9F9E<BP@)&D@*B`T+"`T*2DI(#X^(#@["B`@("`@
M("`@("`@("`@("`D;65S<V%G95]I;F9O6R=!8V-O=6YT240G72`](&EN='9A
M;"@D=&AI<RT^7W)E8613=')I;F<H)$1A=&%"=69F97(L("1P;W,I*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#@P.@H@
M("`@("`@("`@("!C87-E(#!X.#$Z"B`@("`@("`@("`@(&-A<V4@,'@X-#H*
M("`@("`@("`@("`@8V%S92`P>#DQ.@H@("`@("`@("`@("`@("`@)&UE<W-A
M9V5?:6YF;ULD9FQA9U]A<G)A>5LD;6%S:UU=(#T@87)R87E?<&]P*'5N<&%C
M:R@G3"<L('-U8G-T<B@D1FQA9W-"=69F97(L("1I("H@-"P@-"DI*2`^/B`X
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;65S<V%G95]I;F9O.PH@("`@?0H*("`@
M("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("`@("`@5$]$
M3PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<VET:6]N("!43T1/"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]R96%D26YD97@H)B1D871A+"`D<&]S:71I;VXI
M"B`@("!["B`@("`@("`@)&EN9&5X7VAE861E<B`]('5N<&%C:R@G3$9I;&50
M;W,O3%5N:VYO=VXQ+TQ0<F5V26YD97@O3$YE>'1);F1E>"],0V]U;G0O3%5N
M:VYO=VXG+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@,C0I*3L*("`@("`@
M("!I9B`H)&EN9&5X7VAE861E<ELG1FEL95!O<R==("$]("1P;W-I=&EO;BD@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*"));G9A
M;&ED(&9I;&4@9F]R;6%T(BDI.PH@("`@("`@('T*"B`@("`@("`@+R\@4'5S
M:"!I="!I;G1O(&QI<W0@;V8@<')O8V5S<V5D(&ET96US+@H@("`@("`@("1T
M:&ES+3Y?=&UP6R1P;W-I=&EO;ET@/2!T<G5E.PH@("`@("`@(&EF("@H)&EN
M9&5X7VAE861E<ELG3F5X=$EN9&5X)UT@/B`P*2`F)@H@("`@("`@("`@("!E
M;7!T>2@D=&AI<RT^7W1M<%LD:6YD97A?:&5A9&5R6R=.97AT26YD97@G75TI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5A9$EN9&5X*"1D871A+"`D:6YD
M97A?:&5A9&5R6R=.97AT26YD97@G72D["B`@("`@("`@?0H@("`@("`@(&EF
M("@H)&EN9&5X7VAE861E<ELG4')E=DEN9&5X)UT@/B`P*2`F)@H@("`@("`@
M("`@("!E;7!T>2@D=&AI<RT^7W1M<%LD:6YD97A?:&5A9&5R6R=0<F5V26YD
M97@G75TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5A9$EN9&5X*"1D871A
M+"`D:6YD97A?:&5A9&5R6R=0<F5V26YD97@G72D["B`@("`@("`@?0H@("`@
M("`@("1P;W-I=&EO;B`K/2`R-#L*("`@("`@("`D:6-O=6YT(#T@)&EN9&5X
M7VAE861E<ELG0V]U;G0G72`^/B`X.PH@("`@("`@(&EF("@D:6-O=6YT(#X@
M,"D@>PH@("`@("`@("`@("`D8G5F(#T@<W5B<W1R*"1D871A+"`D<&]S:71I
M;VXL(#$R("H@)&EC;W5N="D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1I8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@("`@("1H9')?8G5F
M(#T@<W5B<W1R*"1B=68L("1I("H@,3(L(#$R*3L*("`@("`@("`@("`@("`@
M("1);F1E>$ET96T@/2!U;G!A8VLH)TQ(96%D97)0;W,O3$-H:6QD26YD97@O
M3%5N:VYO=VXG+"`D:&1R7V)U9BD["B`@("`@("`@("`@("`@("!I9B`H)$EN
M9&5X271E;5LG2&5A9&5R4&]S)UT@/B`P*2!["B`@("`@("`@("`@("`@("`@
M("`@)&UA:6Q;)VEN9F\G72`]("1T:&ES+3Y?<F5A9$UE<W-A9V5);F9O*"1D
M871A+"`D26YD97A)=&5M6R=(96%D97)0;W,G72D["B`@("`@("`@("`@("`@
M("`@("`@)&UA:6Q;)V-O;G1E;G0G72`]("1T:&ES+3Y?<F5A9$UE<W-A9V4H
M)&1A=&$L("1M86EL6R=I;F9O)UU;)W!O<VET:6]N)UTI.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;6%I;'-;72`]("1M86EL.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"@D26YD97A)=&5M6R=#:&EL
M9$EN9&5X)UT@/B`P*2`F)@H@("`@("`@("`@("`@("`@("`@(&5M<'1Y*"1T
M:&ES+3Y?=&UP6R1);F1E>$ET96U;)T-H:6QD26YD97@G75TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R96%D26YD97@H)&9P+"`D26YD97A)
M=&5M6R=#:&EL9$EN9&5X)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3(T-``Q,#0Q-S,V,C<W,P`P,C$U
M,30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#;VUP<F5S<U]G>FEP(&-L87-S(&%L
M;&]W<R!G>FEP(&9I;&5S('1O(&)E(')E860N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP+'8@,2XW+C$R+C@@
M,C`P-B\P,2\R.2`Q,#HQ-#HS-B!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0V]M<')E<W,*("HO"F-L87-S($AO
M<F1E7T-O;7!R97-S7V=Z:7`@97AT96YD<R!(;W)D95]#;VUP<F5S<R!["@H@
M("`@+RHJ"B`@("`@*B!'>FEP(&9I;&4@9FQA9W,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]F;&%G<R`](&%R<F%Y*`H@
M("`@("`@("=&5$585"<@("`@(#T^("`P>#`Q+`H@("`@("`@("=&2$-20R<@
M("`@(#T^("`P>#`R+`H@("`@("`@("=&15A44D$G("`@(#T^("`P>#`T+`H@
M("`@("`@("=&3D%-12<@("`@(#T^("`P>#`X+`H@("`@("`@("=&0T]-345.
M5"<@(#T^("`P>#$P"B`@("`I.PH*("`@("\J*@H@("`@("H@1&5C;VUP<F5S
M<R!A(&=Z:7`@9FEL92!A;F0@9V5T(&EN9F]R;6%T:6]N(&9R;VT@:70N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@(%1H92!T87(@9FEL
M92!D871A+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A
M;65T97(@87)R87D@*%5N=7-E9"DN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!U;F-O;7!R97-S960@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5C;VUP<F5S<R@F)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("\J($EF(&=Z:7`@:7,@;F]T(&-O;7!I;&5D(&EN=&\@
M4$A0+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF("@A571I;#HZ97AT96YS
M:6]N17AI<W1S*"=Z;&EB)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1WII<'!E9"!&:6QE("T@9&5C;VUP<F5S<R!I="!F:7)S="X@*B\*("`@("`@
M("`D<&]S:71I;VX@/2`P.PH@("`@("`@("1I;F9O(#T@=6YP86-K*"=#0TTO
M0T9,1R]65&EM92]#6$9,+T-/4R<L('-U8G-T<B@D9&%T82P@)'!O<VET:6]N
M("L@,BDI.PH@("`@("`@("1P;W-I=&EO;B`K/2`Q,#L*"B`@("`@("`@:68@
M*"1I;F9O6R=&3$<G72`F("1T:&ES+3Y?9FQA9W-;)T9%6%1202==*2!["B`@
M("`@("`@("`@("183$5.(#T@=6YP86-K*"=V3&5N9W1H)RP@<W5B<W1R*"1D
M871A+"`D<&]S:71I;VX@*R`P+"`R*2D["B`@("`@("`@("`@("183$5.(#T@
M)%A,14Y;)TQE;F=T:"==.PH@("`@("`@("`@("`D<&]S:71I;VX@*ST@)%A,
M14X@*R`R.PH@("`@("`@('T*"B`@("`@("`@:68@*"1I;F9O6R=&3$<G72`F
M("1T:&ES+3Y?9FQA9W-;)T9.04U%)UTI('L*("`@("`@("`@("`@)&9I;&5N
M86UE4&]S(#T@<W1R<&]S*"1D871A+"`B7'@P(BP@)'!O<VET:6]N*3L*("`@
M("`@("`@("`@)&9I;&5N86UE(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL
M("1F:6QE;F%M95!O<R`M("1P;W-I=&EO;BD["B`@("`@("`@("`@("1P;W-I
M=&EO;B`]("1F:6QE;F%M95!O<R`K(#$["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&EN9F];)T9,1R==("8@)'1H:7,M/E]F;&%G<ULG1D-/34U%3E0G72D@
M>PH@("`@("`@("`@("`D8V]M;65N=%!O<R`]('-T<G!O<R@D9&%T82P@(EQX
M,"(L("1P;W-I=&EO;BD["B`@("`@("`@("`@("1C;VUM96YT(#T@<W5B<W1R
M*"1D871A+"`D<&]S:71I;VXL("1C;VUM96YT4&]S("T@)'!O<VET:6]N*3L*
M("`@("`@("`@("`@)'!O<VET:6]N(#T@)&-O;6UE;G10;W,@*R`Q.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1I;F9O6R=&3$<G72`F("1T:&ES+3Y?9FQA
M9W-;)T9(0U)#)UTI('L*("`@("`@("`@("`@)&AC<F,@/2!U;G!A8VLH)W9#
M4D,G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K(#`L(#(I*3L*("`@("`@
M("`@("`@)&AC<F,@/2`D:&-R8ULG0U)#)UT["B`@("`@("`@("`@("1P;W-I
M=&EO;B`K/2`R.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]($!G>FEN
M9FQA=&4H<W5B<W1R*"1D871A+"`D<&]S:71I;VXL('-T<FQE;B@D9&%T82D@
M+2`D<&]S:71I;VXI*3L*("`@("`@("!I9B`H96UP='DH)')E<W5L="DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82XB*2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O0V]M<')E<W,O=&%R+G!H<```````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`W-S4S`#$P-#$W,S8R-S<S`#`R,3,T,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($AO<F1E7T-O;7!R97-S7W1A<B!C;&%S<R!A;&QO=W,@=&%R(&9I;&5S('1O
M(&)E(')E860N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`L=B`Q+C0N,3(N."`R,#`V+S`Q+S`Q(#(Q.C(X.C$Q
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@
M0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?0V]M<')E<W,*("HO"F-L87-S($AO<F1E7T-O;7!R97-S7W1A<B!E>'1E
M;F1S($AO<F1E7T-O;7!R97-S('L*"B`@("`O*BH*("`@("`J(%1A<B!F:6QE
M('1Y<&5S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?='EP97,@/2!A<G)A>2@*("`@("`@("`P>#`@("`]/B`@)U5N:7@@
M9FEL92<L"B`@("`@("`@,'@S,"`@/3X@("=&:6QE)RP*("`@("`@("`P>#,Q
M("`]/B`@)TQI;FLG+`H@("`@("`@(#!X,S(@(#T^("`G4WEM8F]L:6,@;&EN
M:R<L"B`@("`@("`@,'@S,R`@/3X@("=#:&%R86-T97(@<W!E8VEA;"!F:6QE
M)RP*("`@("`@("`P>#,T("`]/B`@)T)L;V-K('-P96-I86P@9FEL92<L"B`@
M("`@("`@,'@S-2`@/3X@("=$:7)E8W1O<GDG+`H@("`@("`@(#!X,S8@(#T^
M("`G1DE&3R!S<&5C:6%L(&9I;&4G+`H@("`@("`@(#!X,S<@(#T^("`G0V]N
M=&EG=6]U<R!F:6QE)PH@("`@*3L*"B`@("`O*BH*("`@("`J(%1A<B!F:6QE
M(&9L86=S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?9FQA9W,@/2!A<G)A>2@*("`@("`@("`G1E1%6%0G("`@("`]/B`@
M,'@P,2P*("`@("`@("`G1DA#4D,G("`@("`]/B`@,'@P,BP*("`@("`@("`G
M1D585%)!)R`@("`]/B`@,'@P-"P*("`@("`@("`G1DY!344G("`@("`]/B`@
M,'@P."P*("`@("`@("`G1D-/34U%3E0G("`]/B`@,'@Q,`H@("`@*3L*"B`@
M("`O*BH*("`@("`J($1E8V]M<')E<W,@82!T87(@9FEL92!A;F0@9V5T(&EN
M9F]R;6%T:6]N(&9R;VT@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`F)&1A=&$@("!4:&4@=&%R(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y("A5;G5S960I+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!R97%U97-T960@9&%T
M82!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("H@/'!R93X*("`@("`J
M($M%63H@4&]S:71I;VX@:6X@=&AE(&%R<F%Y"B`@("`@*B!604Q515,Z("=A
M='1R)R`@+2T@($9I;&4@871T<FEB=71E<PH@("`@("H@("`@("`@("`G9&%T
M82<@("TM("!287<@9FEL92!C;VYT96YT<PH@("`@("H@("`@("`@("`G9&%T
M92<@("TM("!&:6QE(&UO9&EF:6-A=&EO;B!T:6UE"B`@("`@*B`@("`@("`@
M("=N86UE)R`@+2T@($9I;&5N86UE"B`@("`@*B`@("`@("`@("=S:7IE)R`@
M+2T@($]R:6=I;F%L(&9I;&4@<VEZ90H@("`@("H@("`@("`@("`G='EP92<@
M("TM("!&:6QE('1Y<&4*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D96-O;7!R97-S*"8D9&%T82P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'!O<VET:6]N(#T@,#L*("`@("`@("`D<F5T=7)N7V%R
M<F%Y(#T@87)R87DH*3L*"B`@("`@("`@=VAI;&4@*"1P;W-I=&EO;B`\('-T
M<FQE;B@D9&%T82DI('L*("`@("`@("`@("`@)&EN9F\@/2!`=6YP86-K*")A
M,3`P9FEL96YA;64O83AM;V1E+V$X=6ED+V$X9VED+V$Q,G-I>F4O83$R;71I
M;64O83AC:&5C:W-U;2]#='EP969L86<O83$P,&QI;FLO839M86=I8R]A,G9E
M<G-I;VXO83,R=6YA;64O83,R9VYA;64O83AD979M86IO<B]A.&1E=FUI;F]R
M(BP@<W5B<W1R*"1D871A+"`D<&]S:71I;VXI*3L*"B`@("`@("`@("`@(&EF
M("@A)&EN9F\I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(BDI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<&]S:71I;VX@*ST@-3$R.PH@("`@
M("`@("`@("`D8V]N=&5N=',@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@
M;V-T9&5C*"1I;F9O6R=S:7IE)UTI*3L*("`@("`@("`@("`@)'!O<VET:6]N
M("L](&-E:6PH;V-T9&5C*"1I;F9O6R=S:7IE)UTI("\@-3$R*2`J(#4Q,CL*
M"B`@("`@("`@("`@(&EF("@D:6YF;ULG9FEL96YA;64G72D@>PH@("`@("`@
M("`@("`@("`@)&9I;&4@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G
M871T<B<@/3X@;G5L;"P*("`@("`@("`@("`@("`@("`@("`G9&%T82<@/3X@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`G9&%T92<@/3X@;V-T9&5C*"1I
M;F9O6R=M=&EM92==*2P*("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@
M=')I;2@D:6YF;ULG9FEL96YA;64G72DL"B`@("`@("`@("`@("`@("`@("`@
M)W-I>F4G(#T^(&]C=&1E8R@D:6YF;ULG<VEZ92==*2P*("`@("`@("`@("`@
M("`@("`@("`G='EP92<@/3X@:7-S970H)'1H:7,M/E]T>7!E<ULD:6YF;ULG
M='EP969L86<G75TI(#\@)'1H:7,M/E]T>7!E<ULD:6YF;ULG='EP969L86<G
M75T@.B!N=6QL"B`@("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@("`@
M(&EF("@H)&EN9F];)W1Y<&5F;&%G)UT@/3T@,"D@?'P*("`@("`@("`@("`@
M("`@("`@("`H)&EN9F];)W1Y<&5F;&%G)UT@/3T@,'@S,"D@?'P*("`@("`@
M("`@("`@("`@("`@("`H)&EN9F];)W1Y<&5F;&%G)UT@/3T@,'@S-2DI('L*
M("`@("`@("`@("`@("`@("`@("`O*B!&:6QE(&]R(&9O;&1E<BX@*B\*("`@
M("`@("`@("`@("`@("`@("`D9FEL95LG9&%T82==(#T@)&-O;G1E;G1S.PH*
M("`@("`@("`@("`@("`@("`@("`D;6]D92`](&AE>&1E8RAS=6)S='(H)&EN
M9F];)VUO9&4G72P@-"P@,RDI.PH@("`@("`@("`@("`@("`@("`@("1F:6QE
M6R=A='1R)UT@/0H@("`@("`@("`@("`@("`@("`@("`@("`H*"1I;F9O6R=T
M>7!E9FQA9R==(#T](#!X,S4I(#\@)V0G(#H@)RTG*2`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("@H)&UO9&4@)B`P>#0P,"D@/R`G<B<@.B`G+2<I("X*
M("`@("`@("`@("`@("`@("`@("`@("`@*"@D;6]D92`F(#!X,C`P*2`_("=W
M)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`H*"1M;V1E("8@
M,'@Q,#`I(#\@)W@G(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("@H)&UO9&4@)B`P>#`T,"D@/R`G<B<@.B`G+2<I("X*("`@("`@("`@("`@
M("`@("`@("`@("`@*"@D;6]D92`F(#!X,#(P*2`_("=W)R`Z("<M)RD@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`H*"1M;V1E("8@,'@P,3`I(#\@)W@G
M(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("@H)&UO9&4@)B`P
M>#`P-"D@/R`G<B<@.B`G+2<I("X*("`@("`@("`@("`@("`@("`@("`@("`@
M*"@D;6]D92`F(#!X,#`R*2`_("=W)R`Z("<M)RD@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`H*"1M;V1E("8@,'@P,#$I(#\@)W@G(#H@)RTG*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+RH@
M4V]M92!O=&AE<B!T>7!E+B`J+PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1R971U<FY?87)R87E;72`]("1F:6QE.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*
M("`@('T*"GT*````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O=&YE9BYP:'``````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U,S(T`#$P-#$W,S8R-S<S`#`R
M,34P,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*9&5F:6YE*"=43D5&7U-)1TY!5%5212<L("`@("`@,'@R,C-E
M.68W."D["F1E9FEN92@G5$Y%1E],5DQ?34534T%'12<L("`@(#!X,#$I.PID
M969I;F4H)U1.149?3%9,7T%45$%#2$U%3E0G+"`P>#`R*3L*"F1E9FEN92@G
M5$Y%1E]35%))3D<G+"`P>#`P,#$P,#`P*3L*9&5F:6YE*"=43D5&7T)95$4G
M+"`@(#!X,#`P-C`P,#`I.PID969I;F4H)U1.149?5T]21"<L("`@,'@P,#`W
M,#`P,"D["F1E9FEN92@G5$Y%1E]$5T]21"<L("`P>#`P,#@P,#`P*3L*"F1E
M9FEN92@G5$Y%1E]!4U5"2D5#5"<L("`@5$Y%1E]$5T]21"`@?"`P>#@P,#0I
M.PID969I;F4H)U1.149?04U#3$%34R<L("`@(%1.149?5T]21"`@('P@,'@X
M,#`X*3L*9&5F:6YE*"=43D5&7T%45$%#2$1!5$$G+"!43D5&7T)95$4@("!\
M(#!X.#`P9BD["F1E9FEN92@G5$Y%1E]!1DE,14Y!344G+"`@5$Y%1E]35%))
M3D<@?"`P>#@P,3`I.PID969I;F4H)U1.149?05)%3D1$051!)RP@(%1.149?
M0EE412`@('P@,'@Y,#`R*3L*9&5F:6YE*"=43D5&7T%-05!)05144E,G+"!4
M3D5&7T)95$4@("!\(#!X.3`P-2D["F1E9FEN92@G5$Y%1E]!5D524TE/3B<L
M("`@5$Y%1E]$5T]21"`@?"`P>#DP,#8I.PH*9&5F:6YE*"=43D5&7TU!4$E?
M3E5,3"<L("`@("`@("`@("`P>#`P,#$I.PID969I;F4H)U1.149?34%025]3
M2$]25"<L("`@("`@("`@(#!X,#`P,BD["F1E9FEN92@G5$Y%1E]-05!)7TE.
M5"<L("`@("`@("`@("`@,'@P,#`S*3L*9&5F:6YE*"=43D5&7TU!4$E?1DQ/
M050G+"`@("`@("`@("`P>#`P,#0I.PID969I;F4H)U1.149?34%025]$3U5"
M3$4G+"`@("`@("`@(#!X,#`P-2D["F1E9FEN92@G5$Y%1E]-05!)7T-54E)%
M3D-9)RP@("`@("`@,'@P,#`V*3L*9&5F:6YE*"=43D5&7TU!4$E?05!05$E-
M12<L("`@("`@("`P>#`P,#<I.PID969I;F4H)U1.149?34%025]%4E)/4B<L
M("`@("`@("`@(#!X,#`P82D["F1E9FEN92@G5$Y%1E]-05!)7T)/3TQ%04XG
M+"`@("`@("`@,'@P,#!B*3L*9&5F:6YE*"=43D5&7TU!4$E?3T)*14-4)RP@
M("`@("`@("`P>#`P,&0I.PID969I;F4H)U1.149?34%025])3E0X0EE412<L
M("`@("`@(#!X,#`Q-"D["F1E9FEN92@G5$Y%1E]-05!)7U-44DE.1R<L("`@
M("`@("`@,'@P,#%E*3L*9&5F:6YE*"=43D5&7TU!4$E?54Y)0T]$15]35%))
M3D<G+"`P>#`P,68I.PID969I;F4H)U1.149?34%025]365-424U%)RP@("`@
M("`@(#!X,#`T,"D["F1E9FEN92@G5$Y%1E]-05!)7T-,4TE$)RP@("`@("`@
M("`@,'@P,#0X*3L*9&5F:6YE*"=43D5&7TU!4$E?0DE.05)9)RP@("`@("`@
M("`P>#`Q,#(I.PH*9&5F:6YE*"=43D5&7TU!4$E?051404-(7TQ/3D=?1DE,
M14Y!344G+"`P>#,W,#<I.PID969I;F4H)U1.149?34%025]!5%1!0TA?34E-
M15]404<G+"`@("`@(#!X,S<P12D["@ID969I;F4H)U1.149?34%025].04U%
M1%]465!%7TE$)RP@("`@(#!X,#`P,"D["F1E9FEN92@G5$Y%1E]-05!)7TY!
M345$7U194$5?4U1224Y')RP@,'@P,#`Q*3L*9&5F:6YE*"=43D5&7TU!4$E?
M359?1DQ!1R<L("`@("`@("`@("`P>#$P,#`I.PH*+RHJ"B`J(%1H92!(;W)D
M95]#;VUP<F5S<U]T;F5F(&-L87-S(&%L;&]W<R!-4RU43D5&(&1A=&$@=&\@
M8F4@9&ES<&QA>65D+@H@*@H@*B!4:&4@5$Y%1B!R96YD97)I;F<@:7,@8F%S
M960@;VX@8V]D92!B>3H*("H@("!'<F%H86T@3F]R8G5R>2`\9VYO<F)U<GE`
M8F]N9&-A<BYC;VT^"B`J($]R:6=I;F%L(&1E<VEG;B!B>3H*("H@("!4:&]M
M87,@0F]L;"`\=&)`8F]L;"YC:#XL($UA<FL@4VEM<'-O;B`\9&%M;F5D0'=O
M<FQD+G-T9"YC;VT^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+W1N968N<&AP+'8@,2XV+C$R+CD@,C`P-B\P,2\P,2`R,3HR
M.#HQ,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-O;7!R97-S"B`J+PIC;&%S
M<R!(;W)D95]#;VUP<F5S<U]T;F5F(&5X=&5N9',@2&]R9&5?0V]M<')E<W,@
M>PH*("`@("\J*@H@("`@("H@1&5C;VUP<F5S<R!T:&4@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@5&AE(&1A=&$@=&\@9&5C
M;VUP<F5S<RX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A<G)A
M>2!O9B!A<F=U;65N=',@;F5E9&5D('1O(&1E8V]M<')E<W,@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@9&%T82X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@9&5C;VUP<F5S<V5D(&1A=&$N"B`@("`@*B`@
M("`@("`@("`@("`@("!2971U<FYS(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]M<')E<W,H)&1A=&$L
M("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1O=70@/2!A<G)A
M>2@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]G971I*"1D871A+"`S,BD@/3T@
M5$Y%1E]324=.05154D4I('L*("`@("`@("`@("`@)'1H:7,M/E]G971I*"1D
M871A+"`Q-BD["@H@("`@("`@("`@("!W:&EL92`H<W1R;&5N*"1D871A*2`^
M(#`I('L*("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/E]G971I*"1D
M871A+"`X*2D@>PH@("`@("`@("`@("`@("`@8V%S92!43D5&7TQ63%]-15-3
M04=%.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E365S<V%G
M92@D9&%T82D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92!43D5&7TQ63%]!5%1!0TA-14Y4.@H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&5C;V1E071T86-H;65N="@D9&%T82P@)&]U
M="D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A
M<G)A>5]R979E<G-E*"1O=70I.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$
M3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@9&%T82!S=')I;F<N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D8FET<R`@2&]W(&UA;GD@8FET<R!T;R!R971R
M:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1/1$\*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V=E='@H)B1D871A+"`D8FET<RD*("`@('L*("`@("`@("`D
M=F%L=64@/2!N=6QL.PH*("`@("`@("!I9B`H<W1R;&5N*"1D871A*2`^/2`D
M8FET<RD@>PH@("`@("`@("`@("`D=F%L=64@/2!S=6)S='(H)&1A=&$L(#`L
M("1B:71S*3L*("`@("`@("`@("`@)&1A=&$@/2!S=6)S=')?<F5P;&%C92@D
M9&%T82P@)R<L(#`L("1B:71S*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`F)&1A=&$@(%1H92!D871A('-T<FEN9RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1B:71S("!(;W<@;6%N>2!B:71S('1O(')E=')I979E+@H@("`@
M("H*("`@("`J($!R971U<FX@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T:2@F)&1A=&$L("1B:71S*0H@("`@>PH@("`@("`@("1B>71E<R`]("1B
M:71S("\@.#L*("`@("`@("`D=F%L=64@/2!N=6QL.PH*("`@("`@("!I9B`H
M<W1R;&5N*"1D871A*2`^/2`D8GET97,I('L*("`@("`@("`@("`@)'9A;'5E
M(#T@;W)D*"1D871A6S!=*3L*("`@("`@("`@("`@:68@*"1B>71E<R`^/2`R
M*2!["B`@("`@("`@("`@("`@("`D=F%L=64@*ST@*&]R9"@D9&%T85LQ72D@
M/#P@."D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1B>71E<R`^
M/2`T*2!["B`@("`@("`@("`@("`@("`D=F%L=64@*ST@*&]R9"@D9&%T85LR
M72D@/#P@,38I("L@*&]R9"@D9&%T85LS72D@/#P@,C0I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1D871A(#T@<W5B<W1R7W)E<&QA8V4H)&1A=&$L
M("<G+"`P+"`D8GET97,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V
M86QU93L*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("8D9&%T82`@("`@(%1H92!D871A('-T<FEN9RX*("`@("`J($!P87)A;2!S
M=')I;F<@)&%T=')I8G5T92`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?
M9&5C;V1E071T<FEB=71E*"8D9&%T82P@)&%T=')I8G5T92D*("`@('L*("`@
M("`@("`O*B!$871A+B`J+PH@("`@("`@("1T:&ES+3Y?9V5T>"@D9&%T82P@
M)'1H:7,M/E]G971I*"1D871A+"`S,BDI.PH*("`@("`@("`O*B!#:&5C:W-U
M;2X@*B\*("`@("`@("`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("`@
M("`@("`@(%1H92!D871A('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`F
M)&%T=&%C:&UE;G1?9&%T82`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?
M97AT<F%C=$UA<&E!='1R:6)U=&5S*"1D871A+"`F)&%T=&%C:&UE;G1?9&%T
M82D*("`@('L*("`@("`@("`O*B!.=6UB97(@;V8@871T<FEB=71E<RX@*B\*
M("`@("`@("`D;G5M8F5R(#T@)'1H:7,M/E]G971I*"1D871A+"`S,BD["@H@
M("`@("`@('=H:6QE("@H<W1R;&5N*"1D871A*2`^(#`I("8F("1N=6UB97(M
M+2D@>PH@("`@("`@("`@("`D:&%V95]M=F%L(#T@9F%L<V4["B`@("`@("`@
M("`@("1N=6U?;79A;"`](#$["B`@("`@("`@("`@("1N86UE9%]I9"`]("1V
M86QU92`](&YU;&P["B`@("`@("`@("`@("1A='1R7W1Y<&4@/2`D=&AI<RT^
M7V=E=&DH)&1A=&$L(#$V*3L*("`@("`@("`@("`@)&%T=')?;F%M92`]("1T
M:&ES+3Y?9V5T:2@D9&%T82P@,38I.PH*("`@("`@("`@("`@:68@*"@D871T
M<E]T>7!E("8@5$Y%1E]-05!)7TU67T9,04<I("$](#`I('L*("`@("`@("`@
M("`@("`@("1H879E7VUV86P@/2!T<G5E.PH@("`@("`@("`@("`@("`@)&%T
M=')?='EP92`]("1A='1R7W1Y<&4@)B!^5$Y%1E]-05!)7TU67T9,04<["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@H)&%T=')?;F%M92`^/2`P
M>#@P,#`I("8F("@D871T<E]N86UE(#P@,'A&1D9%*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G971X*"1D871A+"`Q-BD["B`@("`@("`@("`@("`@
M("`D;F%M961?='EP92`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I.PH*("`@
M("`@("`@("`@("`@('-W:71C:"`H)&YA;65D7W1Y<&4I('L*("`@("`@("`@
M("`@("`@(&-A<V4@5$Y%1E]-05!)7TY!345$7U194$5?240Z"B`@("`@("`@
M("`@("`@("`@("`@)&YA;65D7VED(#T@)'1H:7,M/E]G971I*"1D871A+"`S
M,BD["B`@("`@("`@("`@("`@("`@("`@)&%T=')?;F%M92`]("1N86UE9%]I
M9#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E(%1.149?34%025].04U%1%]465!%7U-44DE.1SH*("`@("`@("`@
M("`@("`@("`@("`D871T<E]N86UE(#T@,'@Y.3DY.PH@("`@("`@("`@("`@
M("`@("`@("1I9&QE;B`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I.PH@("`@
M("`@("`@("`@("`@("`@("1D871A;&5N(#T@)&ED;&5N("L@*"@T("T@*"1I
M9&QE;B`E(#0I*2`E(#0I.PH@("`@("`@("`@("`@("`@("`@("1N86UE9%]I
M9"`]('-U8G-T<B@D=&AI<RT^7V=E='@H)&1A=&$L("1D871A;&5N*2P@,"P@
M)&ED;&5N*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1H879E
M7VUV86PI('L*("`@("`@("`@("`@("`@("1N=6U?;79A;"`]("1T:&ES+3Y?
M9V5T:2@D9&%T82P@,S(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S
M=VET8V@@*"1A='1R7W1Y<&4I('L*("`@("`@("`@("`@8V%S92!43D5&7TU!
M4$E?4TA/4E0Z"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V=E
M=&DH)&1A=&$L(#$V*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92!43D5&7TU!4$E?24Y4.@H@("`@("`@("`@("!C87-E(%1.
M149?34%025]"3T],14%..@H@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&YU;5]M=F%L.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E(#T@)'1H:7,M/E]G971I*"1D871A+"`S,BD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@5$Y%1E]-05!)7T9,3T%4.@H@("`@("`@("`@("!C87-E(%1.149?34%0
M25]%4E)/4CH*("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?9V5T
M>"@D9&%T82P@-"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@5$Y%1E]-05!)7T1/54),13H*("`@("`@("`@("`@8V%S92!4
M3D5&7TU!4$E?05!05$E-13H*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?
M0U524D5.0UDZ"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7TE.5#A"651%
M.@H@("`@("`@("`@("!C87-E(%1.149?34%025]365-424U%.@H@("`@("`@
M("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]G971X*"1D871A+"`X*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!43D5&7TU!
M4$E?4U1224Y'.@H@("`@("`@("`@("!C87-E(%1.149?34%025]53DE#3T1%
M7U-44DE.1SH*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?0DE.05)9.@H@
M("`@("`@("`@("!C87-E(%1.149?34%025]/0DI%0U0Z"B`@("`@("`@("`@
M("`@("`D;G5M7W9A;',@/2`H)&AA=F5?;79A;"D@/R`D;G5M7VUV86P@.B`D
M=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*("`@("`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1N=6U?=F%L<SL@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("1L96YG=&@@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*"B`@
M("`@("`@("`@("`@("`@("`@+RH@4&%D('1O(&YE>'0@-"!B>71E(&)O=6YD
M87)Y+B`J+PH@("`@("`@("`@("`@("`@("`@("1D871A;&5N(#T@)&QE;F=T
M:"`K("@H-"`M("@D;&5N9W1H("4@-"DI("4@-"D["@H@("`@("`@("`@("`@
M("`@("`@(&EF("@D871T<E]T>7!E(#T](%1.149?34%025]35%))3D<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&QE;F=T:"`M/2`Q.PH@("`@("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@+RH@4F5A9"!A
M;F0@=')U;F-A=&4@=&\@;&5N9W1H+B`J+PH@("`@("`@("`@("`@("`@("`@
M("1V86QU92`]('-U8G-T<B@D=&AI<RT^7V=E='@H)&1A=&$L("1D871A;&5N
M*2P@,"P@)&QE;F=T:"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4W1O
M<F4@86YY(&EN=&5R97-T:6YG(&%T=')I8G5T97,N("HO"B`@("`@("`@("`@
M('-W:71C:"`H)&%T=')?;F%M92D@>PH@("`@("`@("`@("!C87-E(%1.149?
M34%025]!5%1!0TA?3$].1U]&24Q%3D%-13H*("`@("`@("`@("`@("`@("\J
M(%5S960@:6X@<')E9F5R96YC92!T;R!!1DE,14Y!344@=F%L=64N("HO"B`@
M("`@("`@("`@("`@("`D871T86-H;65N=%]D871A6S!=6R=N86UE)UT@/2!P
M<F5G7W)E<&QA8V4H)R\N*EM<+UTH+BHI)"\G+"`G7#$G+"`D=F%L=64I.PH@
M("`@("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T85LP75LG;F%M92==(#T@
M<W1R7W)E<&QA8V4H(EPP(BP@)R<L("1A='1A8VAM96YT7V1A=&%;,%U;)VYA
M;64G72D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@5$Y%1E]-05!)7T%45$%#2%]-24U%7U1!1SH*("`@("`@("`@("`@("`@
M("\J($ES('1H:7,@979E<B!S970L(&%N9"!W:&%T(&ES(&9O<FUA=#\@*B\*
M("`@("`@("`@("`@("`@("1A='1A8VAM96YT7V1A=&%;,%U;)W1Y<&4G72`]
M('!R96=?<F5P;&%C92@G+UXH+BHI7"\N*B\G+"`G7#$G+"`D=F%L=64I.PH@
M("`@("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T85LP75LG<W5B='EP92==
M(#T@<')E9U]R97!L86-E*"<O+BI<+R@N*BDD+R<L("=<,2<L("1V86QU92D[
M"B`@("`@("`@("`@("`@("`D871T86-H;65N=%]D871A6S!=6R=S=6)T>7!E
M)UT@/2!S=')?<F5P;&%C92@B7#`B+"`G)RP@)&%T=&%C:&UE;G1?9&%T85LP
M75LG<W5B='EP92==*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)B1D871A("!4:&4@9&%T82!S=')I;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]D96-O9&5-97-S86=E*"8D9&%T82D*("`@('L*("`@
M("`@("`D=&AI<RT^7V1E8V]D94%T=')I8G5T92@D9&%T82P@)'1H:7,M/E]G
M971I*"1D871A+"`S,BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)B1D871A("`@("`@("`@("`@5&AE(&1A=&$@<W1R:6YG
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D871T86-H;65N=%]D871A("!43T1/
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96-O9&5!='1A8VAM96YT*"8D9&%T
M82P@)B1A='1A8VAM96YT7V1A=&$I"B`@("!["B`@("`@("`@)&%T=')I8G5T
M92`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I.PH*("`@("`@("!S=VET8V@@
M*"1A='1R:6)U=&4I('L*("`@("`@("!C87-E(%1.149?05)%3D1$051!.@H@
M("`@("`@("`@("`O*B!-87)K<R!S=&%R="!O9B!N97<@871T86-H;65N="X@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]G971X*"1D871A+"`D=&AI<RT^7V=E
M=&DH)&1A=&$L(#,R*2D["@H@("`@("`@("`@("`O*B!#:&5C:W-U;2`J+PH@
M("`@("`@("`@("`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*"B`@("`@("`@
M("`@("\J($%D9"!A(&YE=R!D969A=6QT(&1A=&$@8FQO8VL@=&\@:&]L9"!D
M971A:6QS(&]F('1H:7,*("`@("`@("`@("`@("`@871T86-H;65N="X@4F5V
M97)S92!O<F1E<B!I<R!E87-I97(@=&\@:&%N9&QE(&QA=&5R(2`J+PH@("`@
M("`@("`@("!A<G)A>5]U;G-H:69T*"1A='1A8VAM96YT7V1A=&$L(&%R<F%Y
M*"=T>7!E)R`@("`]/B`G87!P;&EC871I;VXG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=6)T>7!E)R`]
M/B`G;V-T970M<W1R96%M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@("`@/3X@)W5N:VYO=VXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S=')E86TG("`]/B`G)RDI.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92!43D5&7T%&24Q%3D%-13H*("`@("`@("`@("`@+RH@
M4W1R:7`@<&%T:"X@*B\*("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T85LP
M75LG;F%M92==(#T@<')E9U]R97!L86-E*"<O+BI;7"]=*"XJ*20O)RP@)UPQ
M)RP@)'1H:7,M/E]G971X*"1D871A+"`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R
M*2DI.PH@("`@("`@("`@("`D871T86-H;65N=%]D871A6S!=6R=N86UE)UT@
M/2!S=')?<F5P;&%C92@B7#`B+"`G)RP@)&%T=&%C:&UE;G1?9&%T85LP75LG
M;F%M92==*3L*"B`@("`@("`@("`@("\J($-H96-K<W5M("HO"B`@("`@("`@
M("`@("1T:&ES+3Y?9V5T:2@D9&%T82P@,38I.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92!43D5&7T%45$%#2$1!5$$Z"B`@("`@("`@("`@
M("\J(%1H92!A='1A8VAM96YT(&ET<V5L9BX@*B\*("`@("`@("`@("`@)&QE
M;F=T:"`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I.PH@("`@("`@("`@("`D
M871T86-H;65N=%]D871A6S!=6R=S:7IE)UT@/2`D;&5N9W1H.PH@("`@("`@
M("`@("`D871T86-H;65N=%]D871A6S!=6R=S=')E86TG72`]("1T:&ES+3Y?
M9V5T>"@D9&%T82P@)&QE;F=T:"D["@H@("`@("`@("`@("`O*B!#:&5C:W-U
M;2`J+PH@("`@("`@("`@("`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@5$Y%1E]!34%024%45%)3
M.@H@("`@("`@("`@("`D;&5N9W1H(#T@)'1H:7,M/E]G971I*"1D871A+"`S
M,BD["B`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?9V5T>"@D9&%T82P@
M)&QE;F=T:"D["@H@("`@("`@("`@("`O*B!#:&5C:W-U;2`J+PH@("`@("`@
M("`@("`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@("`@("`@("`@)'1H
M:7,M/E]E>'1R86-T36%P:4%T=')I8G5T97,H)'9A;'5E+"`D871T86-H;65N
M=%]D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E071T<FEB=71E*"1D871A+"`D
M871T<FEB=71E*3L*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'``````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`S-#<S,@`Q,#0Q-S,V,C<W,P`P,C$S-3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!&;W(@9&5C;VUP<F5S<R@I+"!R971U<FX@82!L:7-T(&]F(&9I;&5S+VEN
M9F]R;6%T:6]N(&%B;W5T('1H92!Z:7!F:6QE+@H@*B\*9&5F:6YE*"=(3U)$
M15]#3TU04D534U]:25!?3$E35"<L(#$I.PH*+RHJ"B`J($9O<B!D96-O;7!R
M97-S*"DL(')E='5R;B!T:&4@9&%T82!F;W(@86X@:6YD:79I9'5A;"!F:6QE
M(&EN('1H92!Z:7!F:6QE+@H@*B\*9&5F:6YE*"=(3U)$15]#3TU04D534U]:
M25!?1$%402<L(#(I.PH*+RHJ"B`J(%1H92!(;W)D95]#;VUP<F5S<U]Z:7`@
M8VQA<W,@86QL;W=S(%I)4"!F:6QE<R!T;R!B92!C<F5A=&5D(&%N9`H@*B!R
M96%D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP+'8@,2XQ,2XQ,BXQ-"`R,#`V+S`Q+S`R(#$X.C,T.C`T(&IA
M;B!%>'`@)`H@*@H@*B!4:&4@6DE0(&-O;7!R97-S:6]N(&-O9&4@:7,@<&%R
M=&EA;&QY(&)A<V5D(&]N(&-O9&4@9G)O;3H*("H@("!%<FEC($UU96QL97(@
M/&5R:6-`=&AE;65P87)K+F-O;3X*("H@("!H='1P.B\O=W=W+GIE;F0N8V]M
M+V-O9&5X+G!H<#]I9#TU,S4F<VEN9VQE/3$*("H*("H@("!$96EN<S$R-2`\
M=V5B;6%S=&5R0&%T;&%N="YR=3X*("H@("!H='1P.B\O=W=W+GIE;F0N8V]M
M+V-O9&5X+G!H<#]I9#TT-S`F<VEN9VQE/3$*("H*("H@5&AE(%I)4"!C;VUP
M<F5S<VEO;B!D871E(&-O9&4@:7,@<&%R=&EA;&QY(&)A<V5D(&]N(&-O9&4@
M9G)O;0H@*B`@(%!E=&5R($QI<W1I86L@/&UL861Y0'5S97)S+G-O=7)C969O
M<F=E+FYE=#X*("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O
M+FYZ/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]#;VUP<F5S<PH@*B\*8VQA<W,@2&]R9&5?0V]M<')E
M<W-?>FEP(&5X=&5N9',@2&]R9&5?0V]M<')E<W,@>PH*("`@("\J*@H@("`@
M("H@6DE0(&-O;7!R97-S:6]N(&UE=&AO9',N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]M971H;V1S(#T@87)R87DH"B`@
M("`@("`@,'@P(#T^("=.;VYE)RP*("`@("`@("`P>#$@/3X@)U-H<G5N:R<L
M"B`@("`@("`@,'@R(#T^("=3=7!E<B!&87-T)RP*("`@("`@("`P>#,@/3X@
M)T9A<W0G+`H@("`@("`@(#!X-"`]/B`G3F]R;6%L)RP*("`@("`@("`P>#4@
M/3X@)TUA>&EM=6TG+`H@("`@("`@(#!X-B`]/B`G26UP;&]D960G+`H@("`@
M("`@(#!X."`]/B`G1&5F;&%T960G"B`@("`I.PH*("`@("\J*@H@("`@("H@
M0F5G:6YN:6YG(&]F(&-E;G1R86P@9&ER96-T;W)Y(')E8V]R9"X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C=')L1&ER
M2&5A9&5R(#T@(EQX-3!<>#1B7'@P,5QX,#(B.PH*("`@("\J*@H@("`@("H@
M16YD(&]F(&-E;G1R86P@9&ER96-T;W)Y(')E8V]R9"X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C=')L1&ER16YD(#T@
M(EQX-3!<>#1B7'@P-5QX,#9<>#`P7'@P,%QX,#!<>#`P(CL*"B`@("`O*BH*
M("`@("`J($)E9VEN;FEN9R!O9B!F:6QE(&-O;G1E;G1S+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V9I;&5(96%D97(@
M/2`B7'@U,%QX-&)<>#`S7'@P-"(["@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@
M82!:25`@8V]M<')E<W-E9"!F:6QE(&9R;VT@86X@87)R87D@;V8@9FEL92!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@("!4:&4@
M9&%T82!T;R!C;VUP<F5S<RX*("`@("`J(#QP<F4^"B`@("`@*B!297%U:7)E
M<R!A;B!A<G)A>2!O9B!A<G)A>7,@+2!E86-H('-U8F%R<F%Y('-H;W5L9"!C
M;VYT86EN('1H90H@("`@("H@9F]L;&]W:6YG(&9I96QD<SH*("`@("`J("=D
M871A)R`H<W1R:6YG*2`@("TM("!4:&4@9&%T82!T;R!C;VUP<F5S<RX*("`@
M("`J("=N86UE)R`H<W1R:6YG*2`@("TM("!4:&4@<&%T:&YA;64@=&\@=&AE
M(&9I;&4N"B`@("`@*B`G=&EM92<@*&EN=&5G97(I("`M+2`@6V]P=&EO;F%L
M72!4:&4@=&EM97-T86UP('1O('5S92!F;W(@=&AE(&9I;&4N"B`@("`@*B`\
M+W!R93X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE
M=&5R(&%R<F%Y("A5;G5S960I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@6DE0(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;7!R
M97-S*"1D871A+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M8V]N=&5N=',@/2`D8W1R;&1I<B`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A
M8V@@*"1D871A(&%S("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/E]A9&14
M;UI)4$9I;&4H)'9A;"P@)&-O;G1E;G1S+"`D8W1R;&1I<BD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]C<F5A=&5:25!&:6QE*"1C;VYT
M96YT<RP@)&-T<FQD:7(I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C;VUP
M<F5S<R!A(%I)4"!F:6QE(&%N9"!G970@:6YF;W)M871I;VX@9G)O;2!I="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@5&AE('II<&9I
M;&4@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R
M86UE=&5R(&%R<F%Y+@H@("`@("H@/'!R93X*("`@("`J(%1H92!F;VQL;W=I
M;F<@<&%R86UE=&5R<R!A<F4@4D5154E2140Z"B`@("`@*B`G86-T:6]N)R`H
M:6YT96=E<BD@(#T^("!4:&4@86-T:6]N('1O('1A:V4@;VX@=&AE(&1A=&$N
M("!%:71H97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($A/4D1%
M7T-/35!215-37UI)4%],25-4(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!(3U)$15]#3TU04D534U]:25!?1$%402X*("`@("`J"B`@("`@
M*B!4:&4@9F]L;&]W:6YG('!A<F%M971E<G,@87)E(%)%455)4D5$(&9O<B!(
M3U)$15]#3TU04D534U]:25!?1$%402!A;'-O.@H@("`@("H@)VEN9F\G("AA
M<G)A>2D@("`]/B`@5&AE('II<&9I;&4@;&ES="X*("`@("`J("=K97DG("AI
M;G1E9V5R*2`@/3X@(%1H92!P;W-I=&EO;B!O9B!T:&4@9FEL92!I;B!T:&4@
M87)C:&EV92!L:7-T+@H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(')E<75E<W1E9"!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D96-O;7!R97-S*"1D871A+"`D<&%R86US*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D<&%R86US6R=A8W1I;VXG72DI('L*("`@("`@("`@
M("`@:68@*"1P87)A;7-;)V%C=&EO;B==(#T]($A/4D1%7T-/35!215-37UI)
M4%],25-4*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G971:
M:7!);F9O*"1D871A*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;
M)V%C=&EO;B==(#T]($A/4D1%7T-/35!215-37UI)4%]$051!*2!["B`@("`@
M("`@("`@("`@("`O+R!43T1/.B!#:&5C:R!F;W(@<&%R86UE=&5R<RX*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=%II<$1A=&$H)&1A=&$L
M("1P87)A;7-;)VEN9F\G72P@)'!A<F%M<ULG:V5Y)UTI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(I+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B66]U(&UU<W0@<W!E8VEF>2!W
M:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@;&ES="!O9B!F:6QE<R]D871A
M(&9R;VT@=&AE('II<"!A<F-H:79E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("!4
M:&4@>FEP9FEL92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($M%63H@4&]S:71I;VX@:6X@>FEP9FEL90H@("`@("H@("`@("`@("`@("`@
M("`@5D%,5453.B`G871T<B<@("`@+2T@($9I;&4@871T<FEB=71E<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`G8W)C)R`@("`@+2T@($-20R!C
M:&5C:W-U;0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`G8W-I>F4G
M("`@+2T@($-O;7!R97-S960@9FEL92!S:7IE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("=D871E)R`@("`M+2`@1FEL92!M;V1I9FEC871I;VX@
M=&EM90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@("`@
M+2T@($9I;&5N86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=M
M971H;V0G("`M+2`@0V]M<')E<W-I;VX@;65T:&]D"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("=S:7IE)R`@("`M+2`@3W)I9VEN86P@9FEL92!S
M:7IE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@("`M
M+2`@1FEL92!T>7!E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971::7!);F9O
M*"8D9&%T82D*("`@('L*("`@("`@("`D96YT<FEE<R`](&%R<F%Y*"D["@H@
M("`@("`@("\J($=E="!D971A:6QS(&9R;VT@0V5N=')A;"!D:7)E8W1O<GD@
M<W1R=6-T=7)E+B`J+PH@("`@("`@("1F:%-T87)T(#T@<W1R<&]S*"1D871A
M+"`D=&AI<RT^7V-T<FQ$:7)(96%D97(I.PH*("`@("`@("!D;R!["B`@("`@
M("`@("`@(&EF("AS=')L96XH)&1A=&$I(#P@)&9H4W1A<G0@*R`S,2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV
M86QI9"!:25`@9&%T82(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M:6YF;R`]('5N<&%C:R@G=DUE=&AO9"]65&EM92]60U)#,S(O5D-O;7!R97-S
M960O5E5N8V]M<')E<W-E9"]V3&5N9W1H)RP@<W5B<W1R*"1D871A+"`D9FA3
M=&%R="`K(#$P+"`R,"DI.PH@("`@("`@("`@("`D;F%M92`]('-U8G-T<B@D
M9&%T82P@)&9H4W1A<G0@*R`T-BP@)&EN9F];)TQE;F=T:"==*3L*"B`@("`@
M("`@("`@("1E;G1R:65S6R1N86UE72`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)V%T='(G(#T^(&YU;&PL"B`@("`@("`@("`@("`@("`G8W)C)R`]/B!S
M<')I;G1F*"(E,#AS(BP@9&5C:&5X*"1I;F9O6R=#4D,S,B==*2DL"B`@("`@
M("`@("`@("`@("`G8W-I>F4G(#T^("1I;F9O6R=#;VUP<F5S<V5D)UTL"B`@
M("`@("`@("`@("`@("`G9&%T92<@/3X@;G5L;"P*("`@("`@("`@("`@("`@
M("=?9&%T85-T87)T)R`]/B!N=6QL+`H@("`@("`@("`@("`@("`@)VYA;64G
M(#T^("1N86UE+`H@("`@("`@("`@("`@("`@)VUE=&AO9"<@/3X@)'1H:7,M
M/E]M971H;V1S6R1I;F9O6R=-971H;V0G75TL"B`@("`@("`@("`@("`@("`G
M7VUE=&AO9"<@/3X@)&EN9F];)TUE=&AO9"==+`H@("`@("`@("`@("`@("`@
M)W-I>F4G(#T^("1I;F9O6R=5;F-O;7!R97-S960G72P*("`@("`@("`@("`@
M("`@("=T>7!E)R`]/B!N=6QL"B`@("`@("`@("`@("D["@H@("`@("`@("`@
M("`D96YT<FEE<ULD;F%M95U;)V1A=&4G72`]"B`@("`@("`@("`@("`@("!M
M:W1I;64H*"@D:6YF;ULG5&EM92==(#X^(#$Q*2`F(#!X,68I+`H@("`@("`@
M("`@("`@("`@("`@("`@("@H)&EN9F];)U1I;64G72`^/B`U*2`F(#!X,V8I
M+`H@("`@("`@("`@("`@("`@("`@("`@("@H)&EN9F];)U1I;64G72`\/"`Q
M*2`F(#!X,V4I+`H@("`@("`@("`@("`@("`@("`@("`@("@H)&EN9F];)U1I
M;64G72`^/B`R,2D@)B`P>#`W*2P*("`@("`@("`@("`@("`@("`@("`@("`H
M*"1I;F9O6R=4:6UE)UT@/CX@,38I("8@,'@Q9BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@*"@H)&EN9F];)U1I;64G72`^/B`R-2D@)B`P>#=F*2`K(#$Y
M.#`I*3L*"B`@("`@("`@("`@(&EF("AS=')L96XH)&1A=&$I(#P@)&9H4W1A
M<G0@*R`T,RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B26YV86QI9"!:25`@9&%T82(I*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D:6YF;R`]('5N<&%C:R@G=DEN=&5R;F%L+U9%>'1E<FYA
M;"<L('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@*R`S-BP@-BDI.PH*("`@("`@
M("`@("`@)&5N=')I97-;)&YA;65=6R=T>7!E)UT@/2`H)&EN9F];)TEN=&5R
M;F%L)UT@)B`P>#`Q*2`_("=T97AT)R`Z("=B:6YA<GDG.PH@("`@("`@("`@
M("`D96YT<FEE<ULD;F%M95U;)V%T='(G72`]"B`@("`@("`@("`@("`@("`H
M*"1I;F9O6R=%>'1E<FYA;"==("8@,'@Q,"D@/R`G1"<@.B`G+2<I("X*("`@
M("`@("`@("`@("`@("@H)&EN9F];)T5X=&5R;F%L)UT@)B`P>#(P*2`_("=!
M)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@*"@D:6YF;ULG17AT97)N86PG
M72`F(#!X,#,I(#\@)U,G(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`H*"1I
M;F9O6R=%>'1E<FYA;"==("8@,'@P,BD@/R`G2"<@.B`G+2<I("X*("`@("`@
M("`@("`@("`@("@H)&EN9F];)T5X=&5R;F%L)UT@)B`P>#`Q*2`_("=2)R`Z
M("<M)RD["B`@("`@("`@?2!W:&EL92`H*"1F:%-T87)T(#T@<W1R<&]S*"1D
M871A+"`D=&AI<RT^7V-T<FQ$:7)(96%D97(L("1F:%-T87)T("L@-#8I*2`A
M/3T@9F%L<V4I.PH*("`@("`@("`O*B!'970@9&5T86EL<R!F<F]M(&QO8V%L
M(&9I;&4@:&5A9&5R+B`J+PH@("`@("`@("1F:%-T87)T(#T@<W1R<&]S*"1D
M871A+"`D=&AI<RT^7V9I;&5(96%D97(I.PH*("`@("`@("!D;R!["B`@("`@
M("`@("`@(&EF("AS=')L96XH)&1A=&$I(#P@)&9H4W1A<G0@*R`S-"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV
M86QI9"!:25`@9&%T82(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M:6YF;R`]('5N<&%C:R@G=DUE=&AO9"]65&EM92]60U)#,S(O5D-O;7!R97-S
M960O5E5N8V]M<')E<W-E9"]V3&5N9W1H+W9%>'1R84QE;F=T:"<L('-U8G-T
M<B@D9&%T82P@)&9H4W1A<G0@*R`X+"`R-2DI.PH@("`@("`@("`@("`D;F%M
M92`]('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@*R`S,"P@)&EN9F];)TQE;F=T
M:"==*3L*("`@("`@("`@("`@)&5N=')I97-;)&YA;65=6R=?9&%T85-T87)T
M)UT@/2`D9FA3=&%R="`K(#,P("L@)&EN9F];)TQE;F=T:"==("L@)&EN9F];
M)T5X=')A3&5N9W1H)UT["B`@("`@("`@?2!W:&EL92`H<W1R;&5N*"1D871A
M*2`^("1F:%-T87)T("L@,S`@*R`D:6YF;ULG3&5N9W1H)UT@)B8*("`@("`@
M("`@("`@("`@("`H)&9H4W1A<G0@/2!S=')P;W,H)&1A=&$L("1T:&ES+3Y?
M9FEL94AE861E<BP@)&9H4W1A<G0@*R`S,"`K("1I;F9O6R=,96YG=&@G72DI
M("$]/2!F86QS92D["@H@("`@("`@(')E='5R;B!A<G)A>5]V86QU97,H)&5N
M=')I97,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9&%T
M82!F;W(@82!S<&5C:69I8R!A<F-H:79E9"!F:6QE+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)B1D871A("!4:&4@>FEP(&%R8VAI=F4@8V]N=&5N=',N"B`@("`@*B!`<&%R
M86T@87)R87D@)B1I;F9O("`@5&AE(&EN9F]R;6%T:6]N(&%R<F%Y(&9R;VT@
M7V=E=%II<$EN9F\H*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1K97D@("!4
M:&4@<&]S:71I;VX@;V8@=&AE(&9I;&4@:6X@=&AE(&%R8VAI=F4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F:6QE(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971::7!$871A*"8D9&%T82P@)B1I;F9O+"`D
M:V5Y*0H@("`@>PH@("`@("`@(&EF("@H)&EN9F];)&ME>5U;)U]M971H;V0G
M72`]/2`P>#@I("8F(%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G>FQI8B<I*2![
M"B`@("`@("`@("`@("\J($EF('1H92!F:6QE(&AA<R!B965N(&1E9FQA=&5D
M+"!A;F0@>FQI8B!I<R!I;G-T86QL960L"B`@("`@("`@("`@("`@('1H96X@
M:6YF;&%T92!T:&4@9&%T82!A9V%I;BX@*B\*("`@("`@("`@("`@<F5T=7)N
M(&=Z:6YF;&%T92AS=6)S='(H)&1A=&$L("1I;F9O6R1K97E=6R=?9&%T85-T
M87)T)UTL("1I;F9O6R1K97E=6R=C<VEZ92==*2D["B`@("`@("`@?2!E;'-E
M:68@*"1I;F9O6R1K97E=6R=?;65T:&]D)UT@/3T@,'@P*2!["B`@("`@("`@
M("`@("\J($9I;&5S('1H870@87)E;B=T(&-O;7!R97-S960N("HO"B`@("`@
M("`@("`@(')E='5R;B!S=6)S='(H)&1A=&$L("1I;F9O6R1K97E=6R=?9&%T
M85-T87)T)UTL("1I;F9O6R1K97E=6R=C<VEZ92==*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K
M<R!T;R!S964@:68@=&AE(&1A=&$@:7,@82!V86QI9"!:25`@9FEL92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@5&AE(%I)4"!F:6QE
M(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('9A;&ED+"!F86QS92!I9B!I;G9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C:&5C:UII<$1A=&$H)B1D871A*0H@("`@>PH@("`@("`@(&EF("AS=')P
M;W,H)&1A=&$L("1T:&ES+3Y?9FEL94AE861E<BD@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VYV97)T<R!A(%5.25@@=&EM97-T86UP('1O(&$@-"UB>71E
M($1/4R!D871E(&%N9"!T:6UE(&9O<FUA=`H@("`@("H@*&1A=&4@:6X@:&EG
M:"`R+6)Y=&5S+"!T:6UE(&EN(&QO=R`R+6)Y=&5S(&%L;&]W:6YG(&UA9VYI
M='5D90H@("`@("H@8V]M<&%R:7-O;BDN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'5N:7AT
M:6UE("!4:&4@8W5R<F5N="!53DE8('1I;65S=&%M<"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C=7)R96YT(&1A=&4@:6X@82`T+6)Y
M=&4@1$]3(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W5N:7@R1$]3
M5&EM92@D=6YI>'1I;64@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:6UE87)R
M87D@/2`H:7-?;G5L;"@D=6YI>'1I;64I*2`_(&=E=&1A=&4H*2`Z(&=E=&1A
M=&4H)'5N:7AT:6UE*3L*"B`@("`@("`@:68@*"1T:6UE87)R87E;)WEE87(G
M72`\(#$Y.#`I('L*("`@("`@("`@("`@)'1I;65A<G)A>5LG>65A<B==("`@
M(#T@,3DX,#L*("`@("`@("`@("`@)'1I;65A<G)A>5LG;6]N)UT@("`@(#T@
M,3L*("`@("`@("`@("`@)'1I;65A<G)A>5LG;61A>2==("`@(#T@,3L*("`@
M("`@("`@("`@)'1I;65A<G)A>5LG:&]U<G,G72`@(#T@,#L*("`@("`@("`@
M("`@)'1I;65A<G)A>5LG;6EN=71E<R==(#T@,#L*("`@("`@("`@("`@)'1I
M;65A<G)A>5LG<V5C;VYD<R==(#T@,#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`H*"1T:6UE87)R87E;)WEE87(G72`M(#$Y.#`I(#P\(#(U*2!\"B`@
M("`@("`@("`@("`@("`H)'1I;65A<G)A>5LG;6]N)UT@/#P@,C$I('P*("`@
M("`@("`@("`@("`@("@D=&EM96%R<F%Y6R=M9&%Y)UT@/#P@,38I('P*("`@
M("`@("`@("`@("`@("@D=&EM96%R<F%Y6R=H;W5R<R==(#P\(#$Q*2!\"B`@
M("`@("`@("`@("`@("`H)'1I;65A<G)A>5LG;6EN=71E<R==(#P\(#4I('P*
M("`@("`@("`@("`@("`@("@D=&EM96%R<F%Y6R=S96-O;F1S)UT@/CX@,2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@(F9I;&4B('1O('1H92!:
M25`@87)C:&EV92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1F:6QE("`@("`@4V5E($AO<F1E
M7T-O;7!R97-S7WII<#HZ8W)E871E6FEP1FEL92@I+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("8D8V]N=&5N=',@($%N(&%R<F%Y(&]F(&5X:7-T:6YG('II<'!E
M9"!F:6QE<RX*("`@("`J($!P87)A;2!A<G)A>2`F)&-T<FQD:7(@("!!;B!A
M<G)A>2!O9B!C96YT<F%L(&1I<F5C=&]R>2!I;F9O<FUA=&EO;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%D9%1O6DE01FEL92@F)&9I;&4L("8D8V]N=&5N
M=',L("8D8W1R;&1I<BD*("`@('L*("`@("`@("`D9&%T82`]("8D9FEL95LG
M9&%T82==.PH@("`@("`@("1N86UE(#T@<W1R7W)E<&QA8V4H)UQ<)RP@)R\G
M+"`D9FEL95LG;F%M92==*3L*"B`@("`@("`@+RH@4V5E(&EF('1I;64O9&%T
M92!I;F9O<FUA=&EO;B!H87,@8F5E;B!P<F]V:61E9"X@*B\*("`@("`@("`D
M9G1I;64@/2!N=6QL.PH@("`@("`@(&EF("AI<W-E="@D9FEL95LG=&EM92==
M*2D@>PH@("`@("`@("`@("`D9G1I;64@/2`D9FEL95LG=&EM92==.PH@("`@
M("`@('T*"B`@("`@("`@+RH@1V5T('1H92!H97@@=&EM92X@*B\*("`@("`@
M("`D9'1I;64@("`@/2!D96-H97@H)'1H:7,M/E]U;FEX,D1O<U1I;64H)&9T
M:6UE*2D["B`@("`@("`@)&AE>&1T:6UE(#T@8VAR*&AE>&1E8R@D9'1I;65;
M-ET@+B`D9'1I;65;-UTI*2`N"B`@("`@("`@("`@("`@("`@("`@8VAR*&AE
M>&1E8R@D9'1I;65;-%T@+B`D9'1I;65;-5TI*2`N"B`@("`@("`@("`@("`@
M("`@("`@8VAR*&AE>&1E8R@D9'1I;65;,ET@+B`D9'1I;65;,UTI*2`N"B`@
M("`@("`@("`@("`@("`@("`@8VAR*&AE>&1E8R@D9'1I;65;,%T@+B`D9'1I
M;65;,5TI*3L*"B`@("`@("`@)&9R("`]("1T:&ES+3Y?9FEL94AE861E<CL@
M("`O*B!"96=I;B!C<F5A=&EN9R!T:&4@6DE0(&1A=&$N("HO"B`@("`@("`@
M)&9R("X](")<>#$T7'@P,"([("`@("`@("`@("`O*B!697)S:6]N(&YE961E
M9"!T;R!E>'1R86-T+B`J+PH@("`@("`@("1F<B`N/2`B7'@P,%QX,#`B.R`@
M("`@("`@("`@+RH@1V5N97)A;"!P=7)P;W-E(&)I="!F;&%G+B`J+PH@("`@
M("`@("1F<B`N/2`B7'@P.%QX,#`B.R`@("`@("`@("`@+RH@0V]M<')E<W-I
M;VX@;65T:&]D+B`J+PH@("`@("`@("1F<B`N/2`D:&5X9'1I;64[("`@("`@
M("`@("`@+RH@3&%S="!M;V1I9FEC871I;VX@=&EM92]D871E+B`J+PH*("`@
M("`@("`O*B`B3&]C86P@9FEL92!H96%D97(B('-E9VUE;G0N("HO"B`@("`@
M("`@)'5N8U]L96X@/2!S=')L96XH)&1A=&$I.PH@("`@("`@("1C<F,@("`@
M(#T@8W)C,S(H)&1A=&$I.PH@("`@("`@("1Z9&%T82`@(#T@9WIC;VUP<F5S
M<R@D9&%T82D["B`@("`@("`@)'ID871A("`@/2!S=6)S='(H<W5B<W1R*"1Z
M9&%T82P@,"P@<W1R;&5N*"1Z9&%T82D@+2`T*2P@,BD["B`@("`@("`@)&-?
M;&5N("`@/2!S=')L96XH)'ID871A*3L*"B`@("`@("`@)&9R("X]('!A8VLH
M)U8G+"`D8W)C*3L@("`@("`@("`@("`O*B!#4D,@,S(@:6YF;W)M871I;VXN
M("HO"B`@("`@("`@)&9R("X]('!A8VLH)U8G+"`D8U]L96XI.R`@("`@("`@
M("`O*B!#;VUP<F5S<V5D(&9I;&5S:7IE+B`J+PH@("`@("`@("1F<B`N/2!P
M86-K*"=6)RP@)'5N8U]L96XI.R`@("`@("`@+RH@56YC;VUP<F5S<V5D(&9I
M;&5S:7IE+B`J+PH@("`@("`@("1F<B`N/2!P86-K*"=V)RP@<W1R;&5N*"1N
M86UE*2D[("`@+RH@3&5N9W1H(&]F(&9I;&5N86UE+B`J+PH@("`@("`@("1F
M<B`N/2!P86-K*"=V)RP@,"D[("`@("`@("`@("`@("`@+RH@17AT<F$@9FEE
M;&0@;&5N9W1H+B`J+PH@("`@("`@("1F<B`N/2`D;F%M93L@("`@("`@("`@
M("`@("`@("`@("`@+RH@1FEL92!N86UE+B`J+PH*("`@("`@("`O*B`B1FEL
M92!D871A(B!S96=M96YT+B`J+PH@("`@("`@("1F<B`N/2`D>F1A=&$["@H@
M("`@("`@("\J(")$871A(&1E<V-R:7!T;W(B('-E9VUE;G0@*&]P=&EO;F%L
M(&)U="!N96-E<W-A<GD@:68@87)C:&EV92!I<PH@("`@("`@("`@(&YO="!S
M97)V960@87,@9FEL92DN("HO"B`@("`@("`@)&9R("X]('!A8VLH)U8G+"`D
M8W)C*3L*("`@("`@("`D9G(@+CT@<&%C:R@G5B<L("1C7VQE;BD["B`@("`@
M("`@)&9R("X]('!A8VLH)U8G+"`D=6YC7VQE;BD["@H@("`@("`@("\J($%D
M9"!T:&ES(&5N=')Y('1O(&%R<F%Y+B`J+PH@("`@("`@("1O;&1?;V9F<V5T
M(#T@<W1R;&5N*&EM<&QO9&4H)R<L("1C;VYT96YT<RDI.PH@("`@("`@("1C
M;VYT96YT<UM=(#T@)B1F<CL*"B`@("`@("`@+RH@061D('1O(&-E;G1R86P@
M9&ER96-T;W)Y(')E8V]R9"X@*B\*("`@("`@("`D8V1R96,@(#T@)'1H:7,M
M/E]C=')L1&ER2&5A9&5R.PH@("`@("`@("1C9')E8R`N/2`B7'@P,%QX,#`B
M.R`@("`@("`@("`@("`@("`O*B!697)S:6]N(&UA9&4@8GDN("HO"B`@("`@
M("`@)&-D<F5C("X](")<>#$T7'@P,"([("`@("`@("`@("`@("`@("\J(%9E
M<G-I;VX@;F5E9&5D('1O(&5X=')A8W0@*B\*("`@("`@("`D8V1R96,@+CT@
M(EQX,#!<>#`P(CL@("`@("`@("`@("`@("`@+RH@1V5N97)A;"!P=7)P;W-E
M(&)I="!F;&%G("HO"B`@("`@("`@)&-D<F5C("X](")<>#`X7'@P,"([("`@
M("`@("`@("`@("`@("\J($-O;7!R97-S:6]N(&UE=&AO9"`J+PH@("`@("`@
M("1C9')E8R`N/2`D:&5X9'1I;64[("`@("`@("`@("`@("`@("`O*B!,87-T
M(&UO9"!T:6UE+V1A=&4N("HO"B`@("`@("`@)&-D<F5C("X]('!A8VLH)U8G
M+"`D8W)C*3L@("`@("`@("`@("\J($-20R`S,B!I;F9O<FUA=&EO;BX@*B\*
M("`@("`@("`D8V1R96,@+CT@<&%C:R@G5B<L("1C7VQE;BD[("`@("`@("`@
M+RH@0V]M<')E<W-E9"!F:6QE<VEZ92X@*B\*("`@("`@("`D8V1R96,@+CT@
M<&%C:R@G5B<L("1U;F-?;&5N*3L@("`@("`@+RH@56YC;VUP<F5S<V5D(&9I
M;&5S:7IE+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=V)RP@<W1R;&5N
M*"1N86UE*2D[("`O*B!,96YG=&@@;V8@9FEL96YA;64N("HO"B`@("`@("`@
M)&-D<F5C("X]('!A8VLH)W8G+"`P("D[("`@("`@("`@("`@("\J($5X=')A
M(&9I96QD(&QE;F=T:"X@*B\*("`@("`@("`D8V1R96,@+CT@<&%C:R@G=B<L
M(#`@*3L@("`@("`@("`@("`@+RH@1FEL92!C;VUM96YT(&QE;F=T:"X@*B\*
M("`@("`@("`D8V1R96,@+CT@<&%C:R@G=B<L(#`@*3L@("`@("`@("`@("`@
M+RH@1&ES:R!N=6UB97(@<W1A<G0N("HO"B`@("`@("`@)&-D<F5C("X]('!A
M8VLH)W8G+"`P("D[("`@("`@("`@("`@("\J($EN=&5R;F%L(&9I;&4@871T
M<FEB=71E<RX@*B\*("`@("`@("`D8V1R96,@+CT@<&%C:R@G5B<L(#,R("D[
M("`@("`@("`@("`@+RH@17AT97)N86P@9FEL92!A='1R:6)U=&5S("T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V%R8VAI=F4G(&)I="!S970N("HO"B`@("`@("`@)&-D<F5C("X]('!A8VLH
M)U8G+"`D;VQD7V]F9G-E="D[("`@("\J(%)E;&%T:79E(&]F9G-E="!O9B!L
M;V-A;`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!H96%D97(N("HO"B`@("`@("`@)&-D<F5C("X]("1N86UE.R`@
M("`@("`@("`@("`@("`@("`@("\J($9I;&4@;F%M92X@*B\*("`@("`@("`O
M*B!/<'1I;VYA;"!E>'1R82!F:65L9"P@9FEL92!C;VUM96YT(&=O97,@:&5R
M92X@*B\*"B`@("`@("`@+R\@4V%V92!T;R!C96YT<F%L(&1I<F5C=&]R>2!A
M<G)A>2X@*B\*("`@("`@("`D8W1R;&1I<EM=(#T@)B1C9')E8SL*("`@('T*
M"B`@("`O*BH*("`@("`J($-R96%T97,@=&AE(%I)4"!F:6QE+@H@("`@("H@
M3V9F:6-I86P@6DE0(&9I;&4@9F]R;6%T.B!H='1P.B\O=W=W+G!K=V%R92YC
M;VTO87!P;F]T92YT>'0*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%I)4"!F:6QE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E6DE01FEL92@F)&-O;G1E;G1S
M+"`F)&-T<FQ$:7(I"B`@("!["B`@("`@("`@)&1A=&$@/2!I;7!L;V1E*"<G
M+"`D8V]N=&5N=',I.PH@("`@("`@("1D:7(@/2!I;7!L;V1E*"<G+"`D8W1R
M;$1I<BD["@H@("`@("`@(')E='5R;B`D9&%T82`N("1D:7(@+B`D=&AI<RT^
M7V-T<FQ$:7)%;F0@+@H@("`@("`@("`@("`O*B!4;W1A;"`C(&]F(&5N=')I
M97,@(F]N('1H:7,@9&ES:R(N("HO"B`@("`@("`@("`@('!A8VLH)W8G+"!C
M;W5N="@D8W1R;$1I<BDI("X*("`@("`@("`@("`@+RH@5&]T86P@(R!O9B!E
M;G1R:65S(&]V97)A;&PN("HO"B`@("`@("`@("`@('!A8VLH)W8G+"!C;W5N
M="@D8W1R;$1I<BDI("X*("`@("`@("`@("`@+RH@4VEZ92!O9B!C96YT<F%L
M(&1I<F5C=&]R>2X@*B\*("`@("`@("`@("`@<&%C:R@G5B<L('-T<FQE;B@D
M9&ER*2D@+@H@("`@("`@("`@("`O*B!/9F9S970@=&\@<W1A<G0@;V8@8V5N
M=')A;"!D:7(N("HO"B`@("`@("`@("`@('!A8VLH)U8G+"!S=')L96XH)&1A
M=&$I*2`N"B`@("`@("`@("`@("\J(%I)4"!F:6QE(&-O;6UE;G0@;&5N9W1H
M+B`J+PH@("`@("`@("`@("`B7'@P,%QX,#`B.PH@("`@?0H*?0H`````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O````````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,P`P
M,3<Q,#8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]C
M<W8N<&AP````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V
M-S0W`#$P-#$W,S8R-S<S`#`R,#0R-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@2&]R9&5?1&%T82!I
M;7!L96UE;G1A=&EO;B!F;W(@8V]M;6$M<V5P87)A=&5D(&1A=&$@*$-35BDN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP+'8@
M,2XS,"XQ,"XX(#(P,#8O,#$O,C@@,38Z,C$Z-3@@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]$871A"B`J+PIC;&%S<R!(;W)D95]$871A7V-S
M=B!E>'1E;F1S($AO<F1E7T1A=&$@>PH*("`@('9A<B`D7V5X=&5N<VEO;B`]
M("=C<W8G.PH@("`@=F%R("1?8V]N=&5N=%1Y<&4@/2`G=&5X="]C;VUM82US
M97!A<F%T960M=F%L=65S)SL*"B`@("`O*BH*("`@("`J(%1R:65S('1O(&1I
M<V-O=F5R('1H92!#4U8@9FEL92=S('!A<F%M971E<G,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!N86UE(&]F('1H92!F
M:6QE('1O(&EN=F5S=&EG871E+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9R!P
M;W-S:6)L92!K97ES.@H@("`@("H@/'!R93X*("`@("`J("=S97`G.B`@("!4
M:&4@9FEE;&0@<V5P87)A=&]R"B`@("`@*B`G<75O=&4G.B`@5&AE('%U;W1I
M;F<@8VAA<F%C=&5R"B`@("`@*B`G9FEE;&1S)SH@5&AE(&YU;6)E<B!O9B!F
M:65L9',@*&-O;'5M;G,I"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&ES8V]V97)&;W)M870H)&9I;&5N86UE*0H@("`@>PH@("`@("`@
M($!I;F-L=61E7V]N8V4H)T9I;&4O0U-6+G!H<"<I.PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)T9I;&5?0U-6)RDI('L*("`@("`@("`@("`@<F5T=7)N
M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@D9FEL96YA;64I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G<V5P)R`]/B`G
M+"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($EM<&]R=',@
M86YD('!A<G-E<R!A($-35B!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9I;&5N86UE("!4:&4@;F%M92!O9B!T:&4@9FEL92!T;R!P87)S
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97(@("!$;V5S('1H92!F
M:7)S="!L:6YE(&-O;G1A:6X@=&AE(&9I96QD+V-O;'5M;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YA;65S/PH@("`@("H@0'!A<F%M('-T
M<FEN9R`D<V5P("`@("`@(%1H92!F:65L9"]C;VQU;6X@<V5P87)A=&]R+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<75O=&4@("`@(%1H92!Q=6]T:6YG(&-H
M87)A8W1E<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1F:65L9',@("!4:&4@
M;G5M8F5R(&]R(&9I96QD<R]C;VQU;6YS+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8VAA<G-E="`@(%1H92!F:6QE)W,@8VAA<G-E="X@0'-I;F-E($AO<F1E
M(#,N,2X*("`@("`J($!P87)A;2!S=')I;F<@)&-R;&8@("`@("!4:&4@9FEL
M92=S(&QI;F5F965D(&-H87)A8W1E<G,N($!S:6YC92!(;W)D92`S+C$N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!T=V\M9&EM96YS:6]N86P@
M87)R87D@;V8@86QL(&EM<&]R=&5D(&1A=&$@<F]W<RX@($EF"B`@("`@*B`@
M("`@("`@("`@("`@("`D:&5A9&5R('=A<R!T<G5E('1H92!R;W=S(&%R92!A
M<W-O8VEA=&EV92!A<G)A>7,@=VET:"!T:&4*("`@("`J("`@("`@("`@("`@
M("`@(&9I96QD+V-O;'5M;B!N86UE<R!A<R!T:&4@:V5Y<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@:6UP;W)T1FEL92@D9FEL96YA;64L("1H96%D97(@/2!F
M86QS92P@)'-E<"`]("<G+"`D<75O=&4@/2`G)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I96QD<R`](&YU;&PL("1I;7!O<G1?;6%P<&EN9R`](&%R
M<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@;G5L
M;"P@)&-R;&8@/2!N=6QL*0H@("`@>PH@("`@("`@($!I;F-L=61E7V]N8V4H
M)T9I;&4O0U-6+G!H<"<I.PH*("`@("`@("`D9&%T82`](&%R<F%Y*"D["@H@
M("`@("`@("\J($9I;&5?0U-6(&ES('!R97-E;G0N("HO"B`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@G1FEL95]#4U8G*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W=A<FYI;F=S(#T@87)R87DH*3L*"B`@("`@("`@("`@("\J($9I;&5?
M0U-6(&ES(&$@8FET('!I8VMY(&%T('=H870@<&%R86UE=&5R(&ET(&5X<&5C
M=',N("HO"B`@("`@("`@("`@("1C;VYF(#T@87)R87DH*3L*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D<75O=&4I*2!["B`@("`@("`@("`@("`@("`D8V]N
M9ELG<75O=&4G72`]("1Q=6]T93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H96UP='DH)'-E<"DI('L*("`@("`@("`@("`@("`@("1C;VYF6R=S
M97`G72`]("<L)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1C;VYF6R=S97`G72`]("1S97`["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1F:65L9',I('L*("`@("`@("`@("`@("`@("1C;VYF6R=F
M:65L9',G72`]("1F:65L9',["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D8W)L9BDI('L*("`@("`@("`@("`@("`@("1C
M;VYF6R=C<FQF)UT@/2`D8W)L9CL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@4W1R:7`@86YD(&ME97`@=&AE(&9I<G-T(&QI;F4@:68@:70@8V]N
M=&%I;G,@=&AE(&9I96QD"B`@("`@("`@("`@("`J(&YA;65S+B`J+PH@("`@
M("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("`@("`@)&AE860@
M/2!&:6QE7T-35CHZ<F5A9"@D9FEL96YA;64L("1C;VYF*3L*("`@("`@("`@
M("`@("`@(&EF("AI<U]A*"1H96%D+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1H96%D.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI('L*("`@
M("`@("`@("`@("`@("`@("`D:&5A9"`](%-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H)&AE860L("1C:&%R<V5T+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@('=H:6QE
M("@D;&EN92`]($9I;&5?0U-6.CIR96%D*"1F:6QE;F%M92P@)&-O;F8I*2![
M"B`@("`@("`@("`@("`@("!I9B`H:7-?82@D;&EN92P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D;&EN93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-H87)S
M970I*2!["B`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2!3=')I;F<Z.F-O
M;G9E<G1#:&%R<V5T*"1L:6YE+"`D8VAA<G-E="P@3DQ3.CIG971#:&%R<V5T
M*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D:&5A9"DI('L*("`@("`@("`@("`@("`@("`@("`D9&%T85M=(#T@
M)&QI;F4["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1N97=L:6YE(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D:&5A9"D[("1I*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;7!O<G1?;6%P<&EN
M9ULD:&5A9%LD:5U=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&AE861;)&E=(#T@)&EM<&]R=%]M87!P:6YG6R1H96%D6R1I75T["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-E;&P@/2`D;&EN95LD:5T["B`@("`@("`@("`@("`@("`@("`@("`@("1C
M96QL(#T@<')E9U]R97!L86-E*"(O7")<(B\B+"`B7"(B+"`D8V5L;"D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1N97=L:6YE6R1H96%D6R1I75T@/2!E
M;7!T>2@D8V5L;"D@/R`G)R`Z("1C96QL.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&YE=VQI;F4["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F
M<"`]($9I;&5?0U-6.CIG9710;VEN=&5R*"1F:6QE;F%M92P@)&-O;F8I.PH@
M("`@("`@("`@("!I9B`H)&9P("8F("%I<U]A*"1F<"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5W:6YD*"1F<"D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T:&ES+3Y?=V%R;FEN9W,@/2!&:6QE7T-35CHZ
M=V%R;FEN9R@I.PH*("`@("`@("`O*B!&86QL(&)A8VL@=&\@9F=E=&-S=B@I
M+B`J+PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F<"`](&9O<&5N
M*"1F:6QE;F%M92P@)W(G*3L*("`@("`@("`@("`@:68@*"$D9G`I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+RH@4W1R:7`@86YD(&ME97`@=&AE(&9I<G-T(&QI;F4@:68@
M:70@8V]N=&%I;G,@=&AE(&9I96QD"B`@("`@("`@("`@("`@(&YA;65S+B`J
M+PH@("`@("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("`@("`@
M)&AE860@/2!F9V5T8W-V*"1F<"P@,3`R-"P@)'-E<"D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI('L*("`@("`@
M("`@("`@("`@("1H96%D(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D:&5A
M9"P@)&-H87)S970L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!F9V5T8W-V*"1F<"P@,3`R
M-"P@)'-E<"DI('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-H87)S
M970I*2!["B`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2!3=')I;F<Z.F-O
M;G9E<G1#:&%R<V5T*"1L:6YE+"`D8VAA<G-E="P@3DQ3.CIG971#:&%R<V5T
M*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D:&5A9"DI('L*("`@("`@("`@("`@("`@("`@("`D9&%T85M=(#T@
M)&QI;F4["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1N97=L:6YE(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D:&5A9"D[("1I*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;7!O<G1?;6%P<&EN
M9ULD:&5A9%LD:5U=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&AE861;)&E=(#T@)&EM<&]R=%]M87!P:6YG6R1H96%D6R1I75T["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-E;&P@/2`D;&EN95LD:5T["B`@("`@("`@("`@("`@("`@("`@("`@("1C
M96QL(#T@<')E9U]R97!L86-E*"(O7"(O(BP@(EPB7"(B+"`D8V5L;"D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1N97=L:6YE6R1H96%D6R1I75T@/2!E
M;7!T>2@D8V5L;"D@/R`G)R`Z("1C96QL.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&YE=VQI;F4["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9C
M;&]S92@D9G`I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&1A=&$["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!#4U8@9FEL92!F<F]M(&$@
M9VEV96X@9&%T82!S=')U8W1U<F4@86YD(')E='5R;G,@:70@87,@80H@("`@
M("H@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@
M("`@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&1A
M=&$@<V5T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&AE861E<B`@268@=')U
M92P@=&AE(')O=W,@;V8@)&1A=&$@87)E(&%S<V]C:6%T:79E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>7,@=VET:"!F:65L9"!N86UE
M<R!A<R!T:&5I<B!K97ES+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@0U-6(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R=$1A
M=&$H)&1A=&$L("1H96%D97(@/2!F86QS92P@)&5X<&]R=%]M87!P:6YG(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871A*2!\
M?"!C;W5N="@D9&%T82D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<[
M"B`@("`@("`@?0H*("`@("`@("`D97AP;W)T(#T@)R<["B`@("`@("`@)&5O
M;"`](")<;B(["B`@("`@("`@)&AE860@/2!A<G)A>5]K97ES*&-U<G)E;G0H
M)&1A=&$I*3L*("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("!F
M;W)E86-H("@D:&5A9"!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1K97DI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1E>'!O<G1?;6%P<&EN9ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&ME>2`]("1E>'!O<G1?;6%P<&EN9ULD:V5Y73L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`G
M(B<@+B`D:V5Y("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&5X<&]R="`N/2`G+"<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&5X<&]R="`]('-U8G-T<B@D97AP;W)T+"`P+"`M,2D@+B`D96]L.PH@
M("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)')O=RD@>PH@
M("`@("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D:V5Y*2!["B`@("`@("`@
M("`@("`@("`D8V5L;"`]("1R;W=;)&ME>5T["B`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1C96QL*2!\?"`D8V5L;"`]/3T@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("1E>'!O<G0@+CT@)R(G("X@)&-E;&P@+B`G(B<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D97AP;W)T("X]("<L)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D97AP;W)T(#T@<W5B<W1R*"1E
M>'!O<G0L(#`L("TQ*2`N("1E;VP["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&5X<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A($-3
M5B!F:6QE(&9R;VT@82!G:79E;B!D871A('-T<G5C='5R92!A;F0@=')I9V=E
M<G,@:71S"B`@("`@*B!D;W=N;&]A9"X@($ET($1/15,@3D]4(&5X:70@=&AE
M(&-U<G)E;G0@<V-R:7!T(&)U="!O;FQY(&]U='!U=',@=&AE"B`@("`@*B!C
M;W)R96-T(&AE861E<G,@86YD(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEL96YA;64@(%1H92!N86UE(&]F('1H92!F:6QE('1O(&)E
M(&1O=VYL;V%D960N"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@("`@
M02!T=V\M9&EM96YS:6]N86P@87)R87D@8V]N=&%I;FEN9R!T:&4@9&%T80H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('-E="X*("`@("`J($!P
M87)A;2!B;V]L96%N("1H96%D97(@("!)9B!T<G5E+"!T:&4@<F]W<R!O9B`D
M9&%T82!A<F4@87-S;V-I871I=F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>7,@=VET:"!F:65L9"!N86UE<R!A<R!T:&5I<B!K97ES
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1&:6QE*"1F:6QE;F%M92P@
M)&1A=&$L("1H96%D97(@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X<&]R=%]M87!P:6YG(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M97AP;W)T(#T@)'1H:7,M/F5X<&]R=$1A=&$H)&1A=&$L("1H96%D97(L("1E
M>'!O<G1?;6%P<&EN9RD["B`@("`@("`@)$=,3T)!3%-;)V)R;W=S97(G72T^
M9&]W;FQO861(96%D97)S*"1F:6QE;F%M92P@)V%P<&QI8V%T:6]N+V-S=B<L
M(&9A;'-E+"!S=')L96XH)&5X<&]R="DI.PH@("`@("`@(&5C:&\@)&5X<&]R
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%L;"!N96-E<W-A<GD@
M86-T:6]N<R!F;W(@=&AE(&=I=F5N(&EM<&]R="!S=&5P+"!P87)A;65T97)S
M(&%N9`H@("`@("H@9F]R;2!V86QU97,@86YD(')E='5R;G,@=&AE(&YE>'0@
M;F5C97-S87)Y('-T97`N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&%C=&EO;B`@5&AE(&-U<G)E;G0@<W1E<"X@3VYE(&]F('1H92!)35!/4E1?
M*B!C;VYS=&%N=',N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M("`@("!!
M;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG(&YE961E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!F;W(@=&AE(&-U
M<G)E;G0@<W1E<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H
M97(@=&AE(&YE>'0@<W1E<"!A<R!A;B!I;G1E9V5R(&-O;G-T86YT(&]R(&EM
M<&]R=&5D"B`@("`@*B`@("`@("`@("`@("`@("!D871A('-E="!A9G1E<B!T
M:&4@9FEN86P@<W1E<"X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%-T97`H
M)&%C=&EO;BP@)'!A<F%M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=VET
M8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E($E-4$]25%]&24Q%.@H@("`@
M("`@("`@("`D;F5X=%]S=&5P(#T@<&%R96YT.CIN97AT4W1E<"@D86-T:6]N
M+"`D<&%R86TI.PH@("`@("`@("`@("!I9B`H:7-?82@D;F5X=%]S=&5P+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&YE>'1?
M<W1E<#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@36]V92!U<&QO
M861E9"!F:6QE('-O('1H870@=V4@8V%N(')E860@:70@86=A:6X@:6X@=&AE
M(&YE>'0*("`@("`@("`@("`@("`@<W1E<"!A9G1E<B!T:&4@=7-E<B!G879E
M('-O;64@9F]R;6%T(&1E=&%I;',N("HO"B`@("`@("`@("`@("1F:6QE7VYA
M;64@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)VEM<&]R="<L(&9A;'-E*3L*("`@
M("`@("`@("`@:68@*"%M;W9E7W5P;&]A9&5D7V9I;&4H)%]&24Q%4ULG:6UP
M;W)T7V9I;&4G75LG=&UP7VYA;64G72P@)&9I;&5?;F%M92DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=F:6QE
M7VYA;64G72`]("1F:6QE7VYA;64["@H@("`@("`@("`@("`O*B!4<GD@=&\@
M9&ES8V]V97(@=&AE(&9I;&4@9F]R;6%T(&]U<G-E;'9E<RX@*B\*("`@("`@
M("`@("`@)&-O;F8@/2`D=&AI<RT^9&ES8V]V97)&;W)M870H)&9I;&5?;F%M
M92D["B`@("`@("`@("`@(&EF("@A)&-O;F8I('L*("`@("`@("`@("`@("`@
M("1C;VYF(#T@87)R87DH)W-E<"<@/3X@)RPG*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UT@/2!A<G)A>5]M
M97)G92@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UTL("1C;VYF*3L*"B`@("`@
M("`@("`@("\J($-H96-K(&EF(&-H87)S970@=V%S('-P96-I9FEE9"X@*B\*
M("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=C:&%R<V5T
M)UT@/2!5=&EL.CIG971&;W)M1&%T82@G8VAA<G-E="<I.PH*("`@("`@("`@
M("`@+RH@4F5A9"!T:&4@9FEL92=S(&9I<G-T('1W;R!L:6YE<R!T;R!S:&]W
M('1H96T@=&\@=&AE('5S97(N("HO"B`@("`@("`@("`@("1?4T534TE/3ELG
M:6UP;W)T7V1A=&$G75LG9FER<W1?;&EN97,G72`]("<G.PH@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)&9I;&5?;F%M92P@)W(G*3L*("`@("`@("`@("`@
M:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@)&QI;F5?;F\@/2`Q.PH@("`@
M("`@("`@("`@("`@=VAI;&4@*"1L:6YE7VYO(#P@,R`F)B`D;&EN92`](&9G
M971S*"1F<"DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1?
M4T534TE/3ELG:6UP;W)T7V1A=&$G75LG8VAA<G-E="==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;&EN92`](%-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H)&QI;F4L("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG8VAA<G-E="==
M+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1N97=L:6YE(#T@4W1R:6YG.CIL96YG=&@H
M)&QI;F4I(#X@,3`P(#\@(EQN(B`Z("<G.PH@("`@("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FER<W1?;&EN97,G72`N/2!S
M=6)S='(H)&QI;F4L(#`L(#$P,"D@+B`D;F5W;&EN93L*("`@("`@("`@("`@
M("`@("`@("`D;&EN95]N;RLK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B!)35!/4E1?0U-6.PH*("`@("`@
M("!C87-E($E-4$]25%]#4U8Z"B`@("`@("`@("`@("1?4T534TE/3ELG:6UP
M;W)T7V1A=&$G75LG:&5A9&5R)UT@/2!5=&EL.CIG971&;W)M1&%T82@G:&5A
M9&5R)RD["B`@("`@("`@("`@("1I;7!O<G1?;6%P<&EN9R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86U;)VEM<&]R=%]M87!P:6YG
M)UTI*2!["B`@("`@("`@("`@("`@("`D:6UP;W)T7VUA<'!I;F<@/2`D<&%R
M86U;)VEM<&]R=%]M87!P:6YG)UT["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&EM<&]R=%]D871A(#T@)'1H:7,M/FEM<&]R=$9I;&4H)%]315-324].
M6R=I;7!O<G1?9&%T82==6R=F:6QE7VYA;64G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O
M<G1?9&%T82==6R=H96%D97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)W-E<"<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!5=&EL.CIG971&;W)M1&%T82@G<75O=&4G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A
M=&$H)V9I96QD<R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:6UP;W)T7VUA<'!I;F<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP
M;W)T7V1A=&$G75LG8VAA<G-E="==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A
M)UU;)V-R;&8G72D["B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A
M=&$G75LG9&%T82==(#T@)&EM<&]R=%]D871A.PH@("`@("`@("`@("!U;G-E
M="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA<"==*3L*("`@("`@("`@
M("`@<F5T=7)N($E-4$]25%]-05!0140["@H@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@(')E='5R;B!P87)E;G0Z.FYE>'13=&5P*"1A8W1I;VXL("1P
M87)A;2D["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T
M82]I8V%L96YD87(N<&AP````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q,C`W`#$P-#$W,S8R-S<S`#`R,34S-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*+RHJ(%=E(')E;'D@;VX@
M=&AE($AO<F1E7T1A=&%?:6UC.CH@86)S=')A8W0@8VQA<W,N("HO"G)E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O:6UC+G!H<"<["@HO*BH*
M("H@5&AI<R!I<R!I0V%L96YD87(@*'9#86QE;F1A<BDN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T1A=&$O1&%T82]I8V%L96YD87(N<&AP+'8@,2XS,2XQ
M,"XS(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R
M;6]N="`\9F]U<FUO;G1`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]$
M871A"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?1&%T
M85]I8V%L96YD87(@97AT96YD<R!(;W)D95]$871A7VEM8R!["@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O1&%T82]I;6,N<&AP````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`V-#4W`#$P-#$W,S8R-S<S`#`R,#0P,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E("=(;W)D92]I0V%L96YD87(N<&AP)SL*"B\J*@H@*B!!8G-T<F%C="!I
M;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&5?1&%T83HZ($%022!F;W(@24U#
M(&1A=&$@+0H@*B!V0V%R9',@86YD(&E#86QE;F1A<B!D871A+"!E=&,N(%!R
M;W9I9&5S(&$@;G5M8F5R(&]F('5T:6QI='D*("H@;65T:&]D<R!T:&%T('9#
M87)D(&%N9"!I0V%L96YD87(@:6UP;&5M96YT871I;VX@8V%N('-H87)E(&%N
M9"!R96QY"B`J(&]N+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A+T1A
M=&$O:6UC+G!H<"QV(#$N,S(N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C$S(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(
M;W)D95]$871A"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R
M9&5?1&%T85]I;6,@97AT96YD<R!(;W)D95]$871A('L*"B`@("!V87(@)%]I
M0V%L(#T@9F%L<V4["@H@("`@9G5N8W1I;VX@:6UP;W)T1&%T82@D=&5X="D*
M("`@('L*("`@("`@("`D=&AI<RT^7VE#86P@/2`F;F5W($AO<F1E7VE#86QE
M;F1A<B@I.PH*("`@("`@("!I9B`H(21T:&ES+3Y?:4-A;"T^<&%R<V5V0V%L
M96YD87(H)'1E>'0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^7VE#86PM/F=E=$-O;7!O;F5N=',H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($)U:6QD<R!A;B!I0V%L96YD87(@9FEL92!F<F]M(&$@9VEV96X@
M9&%T82!S=')U8W1U<F4@86YD"B`@("`@*B!R971U<FYS(&ET(&%S(&$@<W1R
M:6YG+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@("`@06X@
M87)R87D@8V]N=&%I;FEN9R!(;W)D95]I0V%L96YD87)?=F5V96YT"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C=',*("`@("`J($!P87)A
M;2!S=')I;F<@)&UE=&AO9"`@5&AE(&E4:7`@;65T:&]D('1O('5S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&E#86QE;F1A<B!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1$871A*"1D871A+"`D;65T
M:&]D(#T@)U)%455%4U0G*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,[
M"@H@("`@("`@("1T:&ES+3Y?:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R
M*"D["@H@("`@("`@("1T:&ES+3Y?:4-A;"T^<V5T071T<FEB=71E*"=-151(
M3T0G+"`D;65T:&]D*3L*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D979E
M;G0I('L*("`@("`@("`@("`@)'1H:7,M/E]I0V%L+3YA9&1#;VUP;VYE;G0H
M)&5V96YT*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:4-A
M;"T^97AP;W)T=D-A;&5N9&%R*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"
M=6EL9',@86X@:4-A;&5N9&%R(&9I;&4@9G)O;2!A(&=I=F5N(&1A=&$@<W1R
M=6-T=7)E(&%N9`H@("`@("H@=')I9V=E<G,@:71S(&1O=VYL;V%D+B`@270@
M1$]%4R!.3U0@97AI="!T:&4@8W5R<F5N="!S8W)I<'0@8G5T"B`@("`@*B!O
M;FQY(&]U='!U=',@=&AE(&-O<G)E8W0@:&5A9&5R<R!A;F0@9&%T82X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@(%1H92!N86UE
M(&]F('1H92!F:6QE('1O(&)E(&1O=VYL;V%D960N"B`@("`@*B!`<&%R86T@
M87)R87D@)&1A=&$@("`@("`@($%N(&%R<F%Y(&-O;G1A:6YI;F<@2&]R9&5?
M:4-A;&5N9&%R7W9E=F5N=',*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T
M1FEL92@D9FEL96YA;64L("1D871A*0H@("`@>PH@("`@("`@("1E>'!O<G0@
M/2`D=&AI<RT^97AP;W)T1&%T82@D9&%T82D["B`@("`@("`@)$=,3T)!3%-;
M)V)R;W=S97(G72T^9&]W;FQO861(96%D97)S*"1F:6QE;F%M92P@)W1E>'0O
M8V%L96YD87(G+"!F86QS92P@<W1R;&5N*"1E>'!O<G0I*3L*("`@("`@("!E
M8VAO("1E>'!O<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME<R!A;&P@
M;F5C97-S87)Y(&%C=&EO;G,@9F]R('1H92!G:79E;B!I;7!O<G0@<W1E<"P*
M("`@("`J('!A<F%M971E<G,@86YD(&9O<FT@=F%L=65S(&%N9"!R971U<FYS
M('1H92!N97AT(&YE8V5S<V%R>2!S=&5P+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1A8W1I;VX@(%1H92!C=7)R96YT('-T97`N($]N92!O9B!T
M:&4@24U03U)47RH@8V]N<W1A;G1S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;2`@("`@06X@87-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!N965D
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@
M9F]R('1H92!C=7)R96YT('-T97`N"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%
M:71H97(@=&AE(&YE>'0@<W1E<"!A<R!A;B!I;G1E9V5R(&-O;G-T86YT(&]R
M(&EM<&]R=&5D"B`@("`@*B`@("`@("`@("`@("`@("!D871A('-E="!A9G1E
M<B!T:&4@9FEN86P@<W1E<"X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%-T
M97`H)&%C=&EO;BP@)'!A<F%M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S
M=VET8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E($E-4$]25%]&24Q%.@H@
M("`@("`@("`@("`D;F5X=%]S=&5P(#T@<&%R96YT.CIN97AT4W1E<"@D86-T
M:6]N+"`D<&%R86TI.PH@("`@("`@("`@("!I9B`H:7-?82@D;F5X=%]S=&5P
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&YE
M>'1?<W1E<#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&EM<&]R=%]D
M871A(#T@)'1H:7,M/FEM<&]R=$9I;&4H)%]&24Q%4ULG:6UP;W)T7V9I;&4G
M75LG=&UP7VYA;64G72D["B`@("`@("`@("`@(&EF("AI<U]A*"1I;7!O<G1?
M9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1I;7!O<G1?9&%T83L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N
M('!A<F5N=#HZ;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T1A=&$O;W5T;&]O:V-S=BYP:'``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S0R,P`Q,#0Q-S,V,C<W,P`P,C(P,C8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92`G2&]R9&4O1&%T82]C<W8N<&AP)SL*"B\J*@H@*B!(;W)D95]$871A
M(&EM<&QE;65N=&%T:6]N(&9O<B!/=71L;V]K(&-O;6UA+7-E<&%R871E9"!D
M871A("A#4U8I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A+T1A=&$O
M;W5T;&]O:V-S=BYP:'`L=B`Q+C,N,3`N,R`R,#`U+S$P+S$X(#$Q.C`Q.C`T
M(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]$871A"B`J+PIC;&%S
M<R!(;W)D95]$871A7V]U=&QO;VMC<W8@97AT96YD<R!(;W)D95]$871A7V-S
M=B!["@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!#4U8@9FEL92!F<F]M(&$@
M9VEV96X@9&%T82!S=')U8W1U<F4@86YD(')E='5R;G,@:70@87,@80H@("`@
M("H@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1D871A
M("`@("`@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y(&-O;G1A:6YI;F<@=&AE
M(&1A=&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('-E="X*
M("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97(@("`@($EF('1R=64L('1H
M92!R;W=S(&]F("1D871A(&%R92!A<W-O8VEA=&EV90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87ES('=I=&@@9FEE;&0@;F%M97,@
M87,@=&AE:7(@:V5Y<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE($-35B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1$871A
M*"1D871A+"`D:&5A9&5R(#T@9F%L<V4L("1E>'!O<G1?;6%P<&EN9R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D9&%T82D@?'P@
M8V]U;G0H)&1A=&$I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@
M("`@("`@('T*"B`@("`@("`@)&5X<&]R="`]("<G.PH@("`@("`@("1E;VP@
M/2`B7')<;B(["B`@("`@("`@)&AE860@/2!A<G)A>5]K97ES*&-U<G)E;G0H
M)&1A=&$I*3L*("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("!F
M;W)E86-H("@D:&5A9"!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1K97DI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1E>'!O<G1?;6%P<&EN9ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&ME>2`]("1E>'!O<G1?;6%P<&EN9ULD:V5Y73L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`G
M(B<@+B`D:V5Y("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&5X<&]R="`N/2`G+"<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&5X<&]R="`]('-U8G-T<B@D97AP;W)T+"`P+"`M,2D@+B`D96]L.PH@
M("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)')O=RD@>PH@
M("`@("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D:V5Y*2!["B`@("`@("`@
M("`@("`@("`D8V5L;"`]("1R;W=;)&ME>5T["B`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1C96QL*2!\?"`D8V5L;"`]/3T@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("1C96QL(#T@<')E9U]R97!L86-E*"(O7"(O(BP@(EPB7"(B
M+"`D8V5L;"D["B`@("`@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`G(B<@
M+B`D8V5L;"`N("<B)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1E>'!O<G0@+CT@)RPG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1E>'!O<G0@/2!S=6)S='(H)&5X<&]R="P@,"P@+3$I("X@)&5O;#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D97AP;W)T.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$
M871A+W1S=BYP:'``````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3<W,S``,3`T,3<S-C(W-S,`,#(P-#0P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!(;W)D95]$
M871A(&EM<&QE;65N=&%T:6]N(&9O<B!T86(M<V5P87)A=&5D(&1A=&$@*%13
M5BDN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP
M+'8@,2XR,RXQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*
M("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@*B\*8VQA<W,@2&]R9&5?1&%T85]T
M<W8@97AT96YD<R!(;W)D95]$871A('L*"B`@("!V87(@)%]E>'1E;G-I;VX@
M/2`G='-V)SL*("`@('9A<B`D7V-O;G1E;G14>7!E(#T@)W1E>'0O=&%B+7-E
M<&%R871E9"UV86QU97,G.PH*("`@(&9U;F-T:6]N(&EM<&]R=$1A=&$H)&-O
M;G1E;G1S+"`D:&5A9&5R(#T@9F%L<V4L("1D96QI;6ET97(@/2`B7'0B*0H@
M("`@>PH@("`@("`@("1C;VYT96YT<R`](&5X<&QO9&4H(EQN(BP@)&-O;G1E
M;G1S*3L*("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@:68@*"1H
M96%D97(I('L*("`@("`@("`@("`@)&AE860@/2!E>'!L;V1E*"1D96QI;6ET
M97(L(&%R<F%Y7W-H:69T*"1C;VYT96YT<RDI.PH@("`@("`@('T*("`@("`@
M("!F;W)E86-H("@D8V]N=&5N=',@87,@)&QI;F4I('L*("`@("`@("`@("`@
M:68@*'1R:6TH)&QI;F4I(#T]("<G*2!["B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&EN92`](&5X<&QO
M9&4H)&1E;&EM:71E<BP@)&QI;F4I.PH@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1H96%D*2D@>PH@("`@("`@("`@("`@("`@)&1A=&%;72`]("1L:6YE.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YE=VQI;F4@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)&AE860I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)&YE
M=VQI;F5;)&AE861;)&E=72`](&5M<'1Y*"1L:6YE6R1I72D@/R`G)R`Z("1L
M:6YE6R1I73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D
M871A6UT@/2`D;F5W;&EN93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL
M9',@82!44U8@9FEL92!F<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD
M(')E='5R;G,@:70@87,@80H@("`@("H@<W1R:6YG+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D9&%T82`@("`@($$@='=O+61I;65N<VEO;F%L(&%R
M<F%Y(&-O;G1A:6YI;F<@=&AE(&1A=&$@<V5T+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&AE861E<B`@268@=')U92P@=&AE(')O=W,@;V8@)&1A=&$@87)E
M(&%S<V]C:6%T:79E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>7,@=VET:"!F:65L9"!N86UE<R!A<R!T:&5I<B!K97ES+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@5%-6(&1A=&$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5X<&]R=$1A=&$H)&1A=&$L("1H96%D97(@/2!F86QS
M92D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871A*2!\?"!C;W5N
M="@D9&%T82D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@
M("`@?0H@("`@("`@("1E>'!O<G0@/2`G)SL*("`@("`@("`D:&5A9"`](&%R
M<F%Y7VME>7,H8W5R<F5N="@D9&%T82DI.PH@("`@("`@(&EF("@D:&5A9&5R
M*2!["B`@("`@("`@("`@("1E>'!O<G0@/2!I;7!L;V1E*")<="(L("1H96%D
M*2`N(")<;B(["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1D871A(&%S
M("1R;W<I('L*("`@("`@("`@("`@9F]R96%C:"`H)&AE860@87,@)&ME>2D@
M>PH@("`@("`@("`@("`@("`@)&-E;&P@/2`D<F]W6R1K97E=.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D8V5L;"D@?'P@)&-E;&P@/3T](#`I('L*
M("`@("`@("`@("`@("`@("`@("`D97AP;W)T("X]("1C96QL.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`B7'0B.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1E>'!O<G0@/2!S=6)S='(H)&5X
M<&]R="P@,"P@+3$I("X@(EQN(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1E>'!O<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!44U8@
M9FEL92!F<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD('1R:6=G97)S
M(&ET<R!D;W=N;&]A9"X*("`@("`J($ET($1/15,@3D]4(&5X:70@=&AE(&-U
M<G)E;G0@<V-R:7!T(&)U="!O;FQY(&]U='!U=',@=&AE(&-O<G)E8W0@:&5A
M9&5R<PH@("`@("H@86YD(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9FEL96YA;64@(%1H92!N86UE(&]F('1H92!F:6QE('1O(&)E(&1O
M=VYL;V%D960N"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@("`@02!T
M=V\M9&EM96YS:6]N86P@87)R87D@8V]N=&%I;FEN9R!T:&4@9&%T80H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@('-E="X*("`@("`J($!P87)A
M;2!B;V]L96%N("1H96%D97(@("!)9B!T<G5E+"!T:&4@<F]W<R!O9B`D9&%T
M82!A<F4@87-S;V-I871I=F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>7,@=VET:"!F:65L9"!N86UE<R!A<R!T:&5I<B!K97ES+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1&:6QE*"1F:6QE;F%M92P@)&1A
M=&$L("1H96%D97(@/2!F86QS92D*("`@('L*("`@("`@("`D97AP;W)T(#T@
M)'1H:7,M/F5X<&]R=$1A=&$H)&1A=&$L("1H96%D97(I.PH@("`@("`@("1'
M3$]"04Q36R=B<F]W<V5R)UTM/F1O=VYL;V%D2&5A9&5R<R@D9FEL96YA;64L
M("=T97AT+W1A8BUS97!A<F%T960M=F%L=65S)RP@9F%L<V4L('-T<FQE;B@D
M97AP;W)T*2D["B`@("`@("`@96-H;R`D97AP;W)T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5&%K97,@86QL(&YE8V5S<V%R>2!A8W1I;VYS(&9O<B!T:&4@
M9VEV96X@:6UP;W)T('-T97`L('!A<F%M971E<G,@86YD"B`@("`@*B!F;W)M
M('9A;'5E<R!A;F0@<F5T=7)N<R!T:&4@;F5X="!N96-E<W-A<GD@<W1E<"X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D86-T:6]N("!4:&4@8W5R
M<F5N="!S=&5P+B!/;F4@;V8@=&AE($E-4$]25%\J(&-O;G-T86YT<RX*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86T@("`@($%N(&%S<V]C:6%T:79E(&%R
M<F%Y(&-O;G1A:6YI;F<@;F5E9&5D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!P87)A;65T97)S(&9O<B!T:&4@8W5R<F5N="!S=&5P+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!T:&4@;F5X="!S=&5P
M(&%S(&%N(&EN=&5G97(@8V]N<W1A;G0@;W(@:6UP;W)T960*("`@("`J("`@
M("`@("`@("`@("`@(&1A=&$@<V5T(&%F=&5R('1H92!F:6YA;"!S=&5P+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!N97AT4W1E<"@D86-T:6]N+"`D<&%R86T@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-W:71C:"`H)&%C=&EO;BD@>PH@
M("`@("`@(&-A<V4@24U03U)47T9)3$4Z"B`@("`@("`@("`@("1N97AT7W-T
M97`@/2!P87)E;G0Z.FYE>'13=&5P*"1A8W1I;VXL("1P87)A;2D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1N97AT7W-T97`L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D;F5X=%]S=&5P.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=F;W)M870G72`]/2`G;75L8F5R<GDG('Q\"B`@("`@("`@("`@("`@("`D
M7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9O<FUA="==(#T]("=P:6YE)RD@
M>PH@("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=D
M871A)UT@/2`D=&AI<RT^:6UP;W)T1FEL92@D7T9)3$536R=I;7!O<G1?9FEL
M92==6R=T;7!?;F%M92==*3L*("`@("`@("`@("`@("`@("1F;W)M870@/2`D
M7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9O<FUA="==.PH@("`@("`@("`@
M("`@("`@:68@*"1F;W)M870@/3T@)VUU;&)E<G)Y)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1A<'!+97ES("`](&%R<F%Y*"=A;&EA<R<L("=N86UE)RP@
M)V5M86EL)RP@)V-O;7!A;GDG+"`G=V]R:T%D9')E<W,G+"`G=V]R:U!H;VYE
M)RP@)VAO;650:&]N92<L("=F87@G+"`G;F]T97,G*3L*("`@("`@("`@("`@
M("`@("`@("`D9&%T84ME>7,@/2!A<G)A>2@P+"`Q+"`R+"`S+"`T+"`U+"`V
M+"`W+"`Y*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D9F]R;6%T(#T]
M("=P:6YE)RD@>PH@("`@("`@("`@("`@("`@("`@("1A<'!+97ES(#T@87)R
M87DH)V%L:6%S)RP@)VYA;64G+"`G96UA:6PG+"`G;F]T97,G*3L*("`@("`@
M("`@("`@("`@("`@("`D9&%T84ME>7,@/2!A<G)A>2@P+"`Q+"`R+"`T*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A
M<'!+97ES(&%S("1K97D@/3X@)&%P<"D@>PH@("`@("`@("`@("`@("`@("`@
M("1M87!;)&1A=&%+97ES6R1K97E=72`]("1A<'`["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A
M=&$G72!A<R`D<F]W*2!["B`@("`@("`@("`@("`@("`@("`@)&AA<V@@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D9F]R;6%T(#T]("=M
M=6QB97)R>2<I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H(B]>1W)P.B\B+"`D<F]W6S!=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULQ72`]('!R96=?<F5P
M;&%C92@G+UXH6UXL(ETK*2Q<<RHH+BHI)"\G+"`G)#(@)#$G+"`D<F]W6S%=
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A=&%+97ES
M(&%S("1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AA
M<G)A>5]K97E?97AI<W1S*"1K97DL("1R;W<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&AA<VA;)&ME>5T@/2!S=')I<'-L87-H97,H
M<')E9U]R97!L86-E*"<O7%Q<7'(O)RP@(EQN(BP@)')O=ULD:V5Y72DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1F;W)M
M870@/3T@)W!I;F4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D<F]W*2`\(#,@?'P@<')E9U]M871C:"@B+UXC1$5,151%1"\B+"`D
M<F]W6S!=*2!\?"!P<F5G7VUA=&-H*"(O6R@I72\B+"`D<F]W6S)=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)')O
M=ULQ72`]('!R96=?<F5P;&%C92@G+UXH6UXL(ETK*2Q<<RHH+BHI)"\G+"`G
M)#(@)#$G+"`D<F]W6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&1A=&%+97ES(&%S("1K97DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"1K97DL("1R;W<I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)&ME>5T@
M/2`D<F]W6R1K97E=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1D871A6UT@/2`D:&%S:#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T
M7V1A=&$G75LG9&%T82==(#T@)&1A=&$["B`@("`@("`@("`@("`@("`D7U-%
M4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA<"==(#T@)&UA<#L*("`@("`@("`@
M("`@("`@("1R970@/2`D=&AI<RT^;F5X=%-T97`H24U03U)47T1!5$$L("1P
M87)A;2D["B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@36]V92!U<&QO861E9"!F:6QE('-O('1H
M870@=V4@8V%N(')E860@:70@86=A:6X@:6X@=&AE(&YE>'0@<W1E<`H@("`@
M("`@("`@("`@("!A9G1E<B!T:&4@=7-E<B!G879E('-O;64@9F]R;6%T(&1E
M=&%I;',N("HO"B`@("`@("`@("`@("1U<&QO861E9"`]($)R;W=S97(Z.G=A
M<T9I;&55<&QO861E9"@G:6UP;W)T7V9I;&4G+"!?*")44U8@9FEL92(I*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)'5P;&]A9&5D+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D
M=7!L;V%D960M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&9I;&5?;F%M92`]($AO<F1E.CIG971496UP1FEL92@G:6UP;W)T
M)RP@9F%L<V4I.PH@("`@("`@("`@("!I9B`H(6UO=F5?=7!L;V%D961?9FEL
M92@D7T9)3$536R=I;7!O<G1?9FEL92==6R=T;7!?;F%M92==+"`D9FEL95]N
M86UE*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(I
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R
M=%]D871A)UU;)V9I;&5?;F%M92==(#T@)&9I;&5?;F%M93L*"B`@("`@("`@
M("`@("\J(%)E860@=&AE(&9I;&4G<R!F:7)S="!T=V\@;&EN97,@=&\@<VAO
M=R!T:&5M('1O('1H92!U<V5R+B`J+PH@("`@("`@("`@("`D7U-%4U-)3TY;
M)VEM<&]R=%]D871A)UU;)V9I<G-T7VQI;F5S)UT@/2`G)SL*("`@("`@("`@
M("`@)&9P(#T@0&9O<&5N*"1F:6QE7VYA;64L("=R)RD["B`@("`@("`@("`@
M(&EF("@D9G`I('L*("`@("`@("`@("`@("`@("1L:6YE7VYO(#T@,3L*("`@
M("`@("`@("`@("`@('=H:6QE("@D;&EN95]N;R`\(#,@)B8@)&QI;F4@/2!F
M9V5T<R@D9G`I*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=VQI;F4@/2!3
M=')I;F<Z.FQE;F=T:"@D;&EN92D@/B`Q,#`@/R`B7&XB(#H@)R<["B`@("`@
M("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=F:7)S
M=%]L:6YE<R==("X]('-U8G-T<B@D;&EN92P@,"P@,3`P*2`N("1N97=L:6YE
M.PH@("`@("`@("`@("`@("`@("`@("1L:6YE7VYO*RL["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N($E-4$]2
M5%]44U8["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($E-4$]2
M5%]44U8Z"B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG
M:&5A9&5R)UT@/2!5=&EL.CIG971&;W)M1&%T82@G:&5A9&5R)RD["B`@("`@
M("`@("`@("1I;7!O<G1?9&%T82`]("1T:&ES+3YI;7!O<G1&:6QE*"1?4T53
M4TE/3ELG:6UP;W)T7V1A=&$G75LG9FEL95]N86UE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG
M:6UP;W)T7V1A=&$G75LG:&5A9&5R)UTI.PH@("`@("`@("`@("`D7U-%4U-)
M3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G72`]("1I;7!O<G1?9&%T83L*("`@
M("`@("`@("`@=6YS970H)%]315-324].6R=I;7!O<G1?9&%T82==6R=M87`G
M72D["B`@("`@("`@("`@(')E='5R;B!)35!/4E1?34%04$5$.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T
M=7)N('!A<F5N=#HZ;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M*3L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*?0H`````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O1&%T82]V8V%R9"YP:'``````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,30S`#$P-#$W,S8R-S<S`#`R,#<Q
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]I;6,N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L96YD87(N<&AP)SL*"B\J
M*@H@*B!);7!L96UE;G0@=&AE($AO<F1E7T1A=&$Z.B!!4$D@9F]R('9#87)D
M(&1A=&$N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]V8V%R
M9"YP:'`L=B`Q+C,S+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HQ,R!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7T1A=&$*("HO"F-L87-S($AO<F1E7T1A
M=&%?=F-A<F0@97AT96YD<R!(;W)D95]$871A7VEM8R!["@H@("`@+RHJ"B`@
M("`@*B!%>'!O<G1S('9C86QE;F1A<B!D871A(&%S(&$@<W1R:6YG+B!5;FQI
M:V4@=D5V96YT+"!V0V%R9"!D871A"B`@("`@*B!I<R!N;W0@96YC;&]S960@
M:6X@0D5'24Y\14Y$.G9#86QE;F1A<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&1A=&$@("`@($%N(&%R<F%Y(&-O;G1A:6YI;F<@2&]R9&5?:4-A
M;&5N9&%R7W9C87)D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&]B
M:F5C=',N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@(%1H92!I5&EP
M(&UE=&AO9"!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!I0V%L96YD87(@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP
M;W)T1&%T82@D9&%T82P@)&UE=&AO9"`]("=215%515-4)RD*("`@('L*("`@
M("`@("`D<R`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1V8V%R
M9"D@>PH@("`@("`@("`@("`D<RX]("1V8V%R9"T^97AP;W)T=D-A;&5N9&%R
M*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<SL*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A
M+W9N;W1E+G!H<```````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(S-S(`,3`T,3<S-C(W-S,`,#(P-S4S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+VEM8RYP:'`G.PH*+RHJ"B`J($EM<&QE;65N
M="!T:&4@2&]R9&5?1&%T83HZ($%022!F;W(@=DYO=&4@9&%T82X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+W9N;W1E+G!H<"QV(#$N."XQ
M,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D
M95]$871A"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?
M1&%T85]V;F]T92!E>'1E;F1S($AO<F1E7T1A=&%?:6UC('L*"B`@("`O*BH*
M("`@("`J($5X<&]R=',@=F-A;&5N9&%R(&1A=&$@87,@82!S=')I;F<N(%5N
M;&EK92!V179E;G0L('9.;W1E(&1A=&$*("`@("`J(&ES(&YO="!E;F-L;W-E
M9"!I;B!"14=)3GQ%3D0Z=D-A;&5N9&%R+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D9&%T82`@("`@06X@87)R87D@8V]N=&%I;FEN9R!(;W)D95]I
M0V%L96YD87)?=FYO=&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M;V)J96-T<RX*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE(&E4
M:7`@;65T:&]D('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&E#86QE;F1A<B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E
M>'!O<G1$871A*"1D871A+"`D;65T:&]D(#T@)U)%455%4U0G*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@("1T:&ES+3Y?:4-A;"`]
M("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["@H@("`@("`@("1T:&ES+3Y?:4-A
M;"T^<V5T071T<FEB=71E*"=-151(3T0G+"`D;65T:&]D*3L*("`@("`@("`D
M<R`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1E=F5N="D@>PH@
M("`@("`@("`@("`D<RX]("1E=F5N="T^97AP;W)T=D-A;&5N9&%R*"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D<SL*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O=G1O9&\N<&AP````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(R,0`Q,#0Q-S,V,C<W,P`P,C`W
M-#,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"B\J*B!792!R96QY(&]N('1H92!(;W)D95]$871A7VEM8SHZ(&%B
M<W1R86-T(&-L87-S+B`J+PIR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+VEM8RYP:'`G.PH*+RHJ"B`J($EM<&QE;65N="!T:&4@2&]R9&5?
M1&%T83HZ($%022!F;W(@=E1O9&\@9&%T82X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO1&%T82]$871A+W9T;V1O+G!H<"QV(#$N."XQ,"XS(#(P,#8O,#$O
M,#$@,C$Z,C@Z,3,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]$871A"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?1&%T85]V=&]D;R!E
M>'1E;F1S($AO<F1E7T1A=&%?:6UC('L*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W
M,P`P,3<Q-C$`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X
M="]&:6QT97(O````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S<S`#`R,#0P-@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]B8F-O9&4N<&AP````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3$P-S,`,3`T,3<S-C(W-S,`,#(R,S,T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@IR97%U:7)E7V]N8V4@)TAO<F1E+G!H<"<["@HO*BH*("H@5&AE(%1E>'1?
M1FEL=&5R7V)B8V]D93HZ(&-L87-S(&9I;F1S(&)B8V]D92US='EL92!M87)K
M=7`@*'-E92!B96QO=RD@:6X@80H@*B!B;&]C:R!O9B!T97AT(&%N9"!T=7)N
M<R!I="!I;G1O($A434PN"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J
M(&5N=&ET:65S("TM($EF('1R=64@8F5F;W)E(')E<&QA8VEN9R!B8F-O9&4@
M=VET:"!(5$U,('1A9W,L(&%N>2!(5$U,"B`J("`@("`@("`@("`@(&5N=&ET
M:65S('=I;&P@8F4@<F5P;&%C960N"B`J(#PO<')E/@H@*@H@*B!3=7!P;W)T
M960@8F)C;V1E.@H@*B`\<')E/@H@*B`@("`@6V)=0F]L9"!497AT6R]B70H@
M*B`@("`@6VE=271A;&EC<R!497AT6R]I70H@*B`@("`@6W5=56YD97)L:6YE
M9"!497AT6R]U70H@*B`@("`@6W%U;W1E75%U;W1E9"!497AT6R]Q=6]T95T*
M("H@("`@(%MC96YT97)=0V5N=&5R960@5&5X=%LO8V5N=&5R70H@*@H@*B`@
M("`@3&ES="!O9B!I=&5M<PH@*B`@("`@6VQI<W1="B`J("`@("!;*ET@271E
M;2!O;F4*("H@("`@(%LJ72!)=&5M('1W;PH@*B`@("`@6R]L:7-T70H@*@H@
M*B`@("`@3G5M8F5R960@;&ES=`H@*B`@("`@6VYU;6QI<W1="B`J("`@("!;
M*ET@271E;2!O;F4*("H@("`@(%LJ72!)=&5M('1W;PH@*B`@("`@6R]N=6UL
M:7-T70H@*@H@*B`@("`@6W5R;%UH='1P.B\O=W=W+FAO<F1E+F]R9ULO=7)L
M72`M/B!,:6YK('1O('1H92!A9&1R97-S('5S:6YG('1H90H@*B`@("`@("`@
M(&%D9')E<W,@:71S96QF(&9O<B!T:&4@=&5X="X@(%EO=2!C86X@<W!E8VEF
M>2!T:&4@<')O=&]C;VPZ(&AT='`@;W(*("H@("`@("`@("!H='1P<R!A;F0@
M=&AE('!O<G0N"B`J("`@("!;=7)L77=W=RYH;W)D92YO<F=;+W5R;%T@+3X@
M3&EN:R!T;R!T:&4@861D<F5S<R!U<VEN9R!T:&4@861D<F5S<PH@*B`@("`@
M("`@(&ET<V5L9B!F;W(@=&AE('1E>'0N("!9;W4@8V%N('-P96-I9GD@=&AE
M('!O<G0N("!4:&4@<')O=&]C;VP@:7,@8GD*("H@("`@("`@("!D969A=6QT
M(&AT='`N"B`J("`@("!;=7)L/6AT='`Z+R]W=W<N:&]R9&4N;W)G74QI;FL@
M=&\@2&]R9&5;+W5R;%T@+3X@3&EN:R!T;R!T:&4@861D<F5S<PH@*B`@("`@
M("`@('5S:6YG("),:6YK('1O($AO<F1E(B!F;W(@=&AE('1E>'0N("!9;W4@
M8V%N('-P96-I9GD@=&AE('!R;W1O8V]L.@H@*B`@("`@("`@(&AT='`@;W(@
M:'1T<',@86YD('1H92!P;W)T+@H@*B`@("`@6W5R;#UW=W<N:&]R9&4N;W)G
M74QI;FL@=&\@2&]R9&5;+W5R;%T@+3X@3&EN:R!T;R!T:&4@861D<F5S<R!U
M<VEN9PH@*B`@("`@("`@("),:6YK('1O($AO<F1E(B!F;W(@=&AE('1E>'0N
M("!9;W4@8V%N('-P96-I9GD@=&AE('!O<G0N("!4:&4*("H@("`@("`@("!P
M<F]T;V-O;"!I<R!B>2!D969A=6QT(&AT='`*("H@("`@(%ME;6%I;%UC<&5D
M<FEN86-I0'EA:&]O+F5S6R]E;6%I;%T@+3X@<V5T<R!A(&UA:6QT;R!L:6YK
M+@H@*B`@("`@6V5M86EL/6-P961R:6YA8VE`>6%H;V\N97-=36%I;"!T;R!#
M87)L;W-;+V5M86EL72`M/B!3971S(&$@;6%I;'1O(&QI;FL*("H@("`@("`@
M("!A;F0@=&AE('1E>'0@:7,@(DUA:6P@=&\@0V%R;&]S(BX*("H@/"]P<F4^
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]B
M8F-O9&4N<&AP+'8@,2XX+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#87)L;W,@4&5D<FEN
M86-I(#QC<&5D<FEN86-I0'EA:&]O+F5S/@H@*@H@*B!%;6%I;"!V86QI9&%T
M:6]N(&)A<V5D(&]N($-H=6-K($AA9V5N8G5C:"=S"B`J($UA:6Q?4D9#.#(R
M.CII<U9A;&ED26YE=$%D9')E<W,N"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#87)L;W,@4&5D<FEN86-I(#QC<&5D<FEN86-I0'EA:&]O+F5S/@H@
M*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]B
M8F-O9&4@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&
M:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=E;G1I=&EE<R<@/3X@
M9F%L<V4I.PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C
M97-S87)Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E
M9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@(`EI9B`H)'1H:7,M/E]P87)A
M;7-;)V5N=&ET:65S)UTI('L*("`@("`@("`@("`@)'1E>'0@/2!`:'1M;'-P
M96-I86QC:&%R<R@D=&5X="D["B`@("`)?0H*("`@("`@("!R971U<FX@)'1E
M>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H
M(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T
M=&5R;G,H*0H@("`@>PH@("`@"21R97!L86-E(#T@87)R87DH"B`@("`)("`@
M("=;:5TG(#T^("<\96T^)RP@)ULO:5TG(#T^("<\+V5M/B<L"B`@("`@("`@
M("`@("=;=5TG(#T^("<\=3XG+"`G6R]U72<@/3X@)SPO=3XG+`H@("`@("`@
M("`@("`G6V)=)R`]/B`G/'-T<F]N9SXG+"`G6R]B72<@/3X@)SPO<W1R;VYG
M/B<L"B`@("`@("`@("`@("=;8V5N=&5R72<@/3X@)SQC96YT97(^)RP@)ULO
M8V5N=&5R72<@/3X@)SPO8V5N=&5R/B<L"B`@("`@("`@("`@("=;<75O=&5=
M)R`]/B`G/&)L;V-K<75O=&4^)RP@)ULO<75O=&5=)R`]/B`G/"]B;&]C:W%U
M;W1E/B<L"B`@("`@("`@("`@("=;;&ES=%TG(#T^("<\=6P^)RP@)ULO;&ES
M=%TG(#T^("<\+W5L/B<L"B`@("`@("`@("`@("=;;G5M;&ES=%TG(#T^("<\
M;VP^)RP@)ULO;G5M;&ES=%TG(#T^("<\+V]L/B<L"B`@("`@("`@("`@("=;
M*ETG(#T^("<\;&D^)RD["@H@("`@("`@("\J(%=H96X@8VAE8VMI;F<@55),
M<R!W92!V86QI9&%T92!P87)T(&]F('1H96TL(&)U="!I="!I<R!U<`H@("`@
M("`@("`J('1O('1H92!U<V5R('1O('=R:71E('1H96T@8V]R<F5C=&QY("AI
M;B!P87)T:6-U;&%R('1H90H@("`@("`@("`J('%U97)Y('-T<FEN9RDN($-O
M;F-E<FYI;F<@;6%I;',@=V4@=7-E('1H92!R96=U;&%R"B`@("`@("`@("H@
M97AP<F5S<VEO;B!I;B!-86EL7U)&0S@R,B=S(&ES5F%L:61);F5T061D<F5S
M<R@I(&9U;F-T:6]N+`H@("`@("`@("`J('-L:6=H=&QY(&UO9&EF:65D+B`J
M+PH@("`@("`@("1R96=E>'`@/2!A<G)A>2@*("`@("`@("`@("`@(B-<6W5R
M;%Q=*"AH='1P?&AT='!S*3HO+RA;82UZ02U:7&1=6UQW+5TJ*2A<+EMA+7I!
M+5I<9%U;7'<M72HI*R@Z*%QD*RDI/R@O*%M>/#Y=*RDI*BE<6R]U<FQ<72-5
M(B`]/@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@B)#$B+"`B)#$B*2`N("(D
M,3PO83XB+`H*("`@("`@("`@("`@(B-<6W5R;%P]*"AH='1P?&AT='!S*3HO
M+RA;82UZ02U:7&1=6UQW+5TJ*2A<+EMA+7I!+5I<9%U;7'<M72HI*R@Z*%QD
M*RDI/R@O*%M>/#Y=*RDI*BE<72A;7CP^72LI7%LO=7)L7%TC52(@/3X*("`@
M("`@("`@("`@2&]R9&4Z.FQI;FLH(B0Q(BP@(B0Q(BD@+B`B)#D\+V$^(BP*
M"B`@("`@("`@("`@("(C7%MU<FQ<72@H6V$M>D$M6EQD75M<=RU=*BDH7"Y;
M82UZ02U:7&1=6UQW+5TJ*2LH.BA<9"LI*3\H+RA;7CP^72LI*2HI7%LO=7)L
M7%TC52(@/3X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH(FAT='`Z+R\D,2(L
M(")H='1P.B\O)#$B*2`N("(D,3PO83XB+`H*("`@("`@("`@("`@(B-<6W5R
M;%P]*"A;82UZ02U:7&1=6UQW+5TJ*2A<+EMA+7I!+5I<9%U;7'<M72HI*R@Z
M*%QD*RDI/R@O*%M>/#Y=*RDI*BE<72A;7CP^72LI7%LO=7)L7%TC52(@/3X*
M("`@("`@("`@("`@2&]R9&4Z.FQI;FLH(FAT='`Z+R\D,2(L(")H='1P.B\O
M)#$B*2`N("(D.#PO83XB+`H*("`@("`@("`@("`@(B-<6V5M86EL7%TH*%LJ
M*R$N)EPC)'Q<)UQ<)5PO,"TY82UZ02U:7E]@>WT]/WXZ+5TK*4`H*%LP+3EA
M+7I!+5HM72M<+BDK6S`M.6$M>D$M6EU[,BPT?2DI7%LO96UA:6Q<72-5(B`]
M/@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@B;6%I;'1O.B0Q(BP@(FUA:6QT
M;SHD,2(I("X@(B0Q/"]A/B(L"@H@("`@("`@("`@("`B(UQ;96UA:6Q</2@H
M6RHK(2XF7",D?%PG7%PE7"\P+3EA+7I!+5I>7V![?3T_?CHM72LI0"@H6S`M
M.6$M>D$M6BU=*UPN*2M;,"TY82UZ02U:77LR+#1]*2E<72A;7CP^72LI7%LO
M96UA:6Q<72-5(B`]/@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@B;6%I;'1O
M.B0Q(BP@(FUA:6QT;SHD,2(I("X@(B0U/"]A/B(*("`@("`@("`I.PH*("`@
M("`@("!R971U<FX@87)R87DH)W)E<&QA8V4G(#T^("1R97!L86-E+"`G<F5G
M97AP)R`]/B`D<F5G97AP*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O8VQE86YA<V-I:2YP
M:'```````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,38S`#$P-#$W,S8R-S<S`#`R
M,S(Q-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@4F5M;W9E<R!S;VUE(&-O;6UO;B!E;G1I=&EE<R!A
M;F0@:&EG:"UA<V-I:2!O<B!O=&AE<G=I<V4@;F]N<W1A;F1A<F0*("H@8VAA
M<F%C=&5R<R!C;VUM;VX@:6X@=&5X="!P87-T960@9G)O;2!-:6-R;W-O9G0@
M5V]R9"!I;G1O(&$@8G)O=W-E<BX*("H*("H@5&AI<R!F=6YC=&EO;B!S:&]U
M;&0@3D]4(&)E('5S960@;VX@;F]N+4%30TE)('1E>'0[(&ET(&UA>2!A;F0@
M<')O8F%B;'D*("H@=VEL;"!B=71C:&5R(&]T:&5R(&-H87)A8W1E<B!S971S
M(&EN9&5S8W)I;6EN871E;'DN("!5<V4@:70@;VYL>2!T;R!C;&5A;@H@*B!5
M4RU!4T-)22`H-RUB:70I('1E>'0@=VAI8V@@>6]U('-U<W!E8W0@*&]R(&MN
M;W<I(&UA>2!H879E(&EN=F%L:60@;W(*("H@;F]N+7!R:6YT:6YG(&-H87)A
M8W1E<G,@:6X@:70N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]C;&5A;F%S8VEI+G!H<"QV(#$N,RXR+C0@,C`P-B\P,2\P
M,2`R,3HR.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E>'0*
M("HO"F-L87-S(%1E>'1?1FEL=&5R7V-L96%N87-C:6D@97AT96YD<R!497AT
M7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N
M96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(@<&%T=&5R;G,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@
M8F5F;W)E('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!P<F50<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O?"A;7B-=*BDC+BHO)RP@)'1E>'0L("1R96=S*2D@>PH@("`@("`@
M("`@("`D=&5X="`]("1R96=S6S%=.PH*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&5X="DI('L*("`@("`@("`@("`@("`@("1T97AT(#T@)'1E>'0@+B`B
M7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W
M:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!C;VYT<F]L(&-H
M87)A8W1E<G,N("HO"B`@("`@("`@)')E9V5X<"`](&%R<F%Y*"<O6UQX,#`M
M7'@Q9ETK+R<@/3X@)R<I.PH*("`@("`@("`O*B!4:&4@)Y(G(&5N=')Y(&UA
M>2!L;V]K('=R;VYG+"!D97!E;F1I;F<@;VX@>6]U<B!E9&ET;W(L"B`@("`@
M("`@("H@8G5T(&ET)W,@;F]T("T@=&AA="=S(&YO="!R96%L;'D@82!S:6YG
M;&4@<75O=&4N("HO"B`@("`@("`@)')E<&QA8V4@/2!A<G)A>2AC:'(H,34P
M*2`]/B`G+2<L"B`@("`@("`@("`@("`@("`@("`@("`@("!C:'(H,38W*2`]
M/B`G*B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G@;<G(#T^("<J)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@(">%)R`]/B`G+BXN)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@(">1)R`]/B`B)R(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`GDB<@/3X@(B<B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)Y,G(#T^("<B)RP*("`@("`@("`@("`@("`@("`@("`@("`@(">4)R`]
M/B`G(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`GE2<@/3X@)RHG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)Y8G(#T^("<M)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@(">7)R`]/B`G+2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`GGR<@/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)R8C-C$T-SD[)R`]/B`G+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M)B,V,34W,CLG(#T^("<J)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F
M(S8Q-3DT.R<@/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C
M-C$V-#`[)R`]/B`G+2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V
M,38R,SLG(#T^("<M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F(S8Q
M-C`W.R<@/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C-C$U
M-3,[)R`]/B`G*B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V,34U
M.#LG(#T^("<J)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F(S@R,C8[
M)R`]/B`G*B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,Y-C4X.R<@
M/3X@)SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1R96=E>'`L("=R97!L86-E)R`]
M/B`D<F5P;&%C92D["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]497AT+T9I;'1E<B]D:6US:6=N871U<F4N<&AP````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(S-C,`,3`T,3<S-C(W-S,`,#(S-C$S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!$
M:7-P;&%Y<R!M97-S86=E('-I9VYA='5R97,@;6%R:V5D(&)Y(&$@)RTM("<@
M:6X@=&AE('-T>6QE(&]F('1H90H@*B!#4U,@8VQA<W,@(G-I9VYA='5R92(N
M($-L87-S(&YA;65S(&EN<VED92!T:&4@<VEG;F%T=7)E(&%R90H@*B!P<F5F
M:7AE9"!W:71H(")S:6=N871U<F4M(BX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V1I;7-I9VYA='5R92YP:'`L=B`Q+C(N
M,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?9&EM<VEG;F%T
M=7)E(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@17AE
M8W5T97,@86YY(&-O9&4@;F5C97-S87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@
M9FEL=&5R"B`@("`@*B!P871T97)N<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("!4:&4@=&5X="!A9G1E<B!T:&4@9FEL=&5R:6YG+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]S=%!R;V-E<W,H)'1E>'0I"B`@
M("!["B`@("`@("`@)'!A<G1S(#T@<')E9U]S<&QI="@G?"A<;BTM7',J*#QB
M<B`O/BD_7'(_7&XI?"<L("1T97AT+"`R+"!04D5'7U-03$E47T1%3$E-7T-!
M4%154D4I.PH@("`@("`@(&EF("AC;W5N="@D<&%R=',I(#X@,RD@>PH@("`@
M("`@("`@("`D=&5X="`](&%R<F%Y7W-H:69T*"1P87)T<RD["B`@("`@("`@
M("`@("1T97AT("X]("<\<W!A;B!C;&%S<STB<VEG;F%T=7)E(CXG("X@)'!A
M<G1S6S!=.PH@("`@("`@("`@("`D=&5X="`N/2!P<F5G7W)E<&QA8V4H)WQC
M;&%S<STB*%M>(ETK*2)\)RP@)V-L87-S/2)S:6=N871U<F4M7#$B)RP@)'!A
M<G1S6S)=*3L*("`@("`@("`@("`@)'1E>'0@+CT@)SPO<W!A;CXG.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL
M<RYP:'``````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#0P,``Q,#0Q-S,V
M,C<W,P`P,C(S-C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!497AT7T9I;'1E<E]E;6%I;',Z
M.B!C;&%S<R!F:6YD<R!E;6%I;"!A9&1R97-S97,@:6X@82!B;&]C:R!O9B!T
M97AT(&%N9`H@*B!T=7)N<R!T:&5M(&EN=&\@;&EN:W,N"B`J"B`J(%!A<F%M
M971E<G,Z"B`J(#QP<F4^"B`J(&%L=V%Y<U]M86EL=&\@+2T@268@=')U92P@
M82!M86EL=&\Z(&QI;FL@:7,@9V5N97)A=&5D(&%L=V%Y<RX@($]N;'D@:68@
M;F\*("H@("`@("`@("`@("`@("`@("!M86EL+V-O;7!O<V4@<F5G:7-T<GD@
M05!)(&UE=&AO9"!E>&ES=',@;W1H97)W:7-E+@H@*B!C;&%S<R`@("`@("`@
M("TM($-34R!C;&%S<R!O9B!T:&4@9V5N97)A=&5D(#QA/B!T86<N("!$969A
M=6QT<R!T;R!N;VYE+@H@*B`\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`L=B`Q+C$U+C$P+C@@
M,C`P-B\P,B\Q-R`R,#HP-3HT.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V(%1Y;&5R($-O;&)E<G0@/'1Y;&5R+6AO<F1E;6Q`8V]L
M8F5R=',N=7,^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M5'EL97(@0V]L8F5R="`\='EL97(M:&]R9&5M;$!C;VQB97)T<RYU<SX*("H@
M0&%U=&AO<B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<&%C
M:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]E;6%I;',@
M97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@
M<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=A;'=A>7-?;6%I;'1O)R`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("=C;&%S<R<@/3X@)R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G8V%P:71A;%]T86=S)R`]/B!F
M86QS92D["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E
M<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R
M;G,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@
M("1C;&%S<R`](&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=C;&%S<R==*2`_("<G
M(#H@)R!C;&%S<STB)R`N("1T:&ES+3Y?<&%R86US6R=C;&%S<R==("X@)R(G
M.PH@("`@("`@("1T86<@/2`D=&AI<RT^7W!A<F%M<ULG8V%P:71A;%]T86=S
M)UT@/R`G02<@.B`G82<["@H@("`@("`@("1R96=E>'`@/2`\/#Q%3U(*("`@
M("`@("`@("`@+PH@("`@("`@("`@("`C(%9E<G-I;VX@,3H@;6%I;'1O.B!L
M:6YK<R!W:71H(&%N>2!V86QI9"!E;6%I;"!C:&%R86-T97)S+@H@("`@("`@
M("`@("`C(%!A='1E<FX@,3H@3W5T;&]O:R!P87)E;G1H97-I>F5S(&EN('-Q
M87)E(&)R86-K971S"B`@("`@("`@("`@("A<6UQS*BD_"B`@("`@("`@("`@
M(",@4&%T=&5R;B`R.B!M86EL=&\Z('!R;W1O8V]L('!R969I>`H@("`@("`@
M("`@("`H;6%I;'1O.EQS/RD*("`@("`@("`@("`@(R!0871T97)N(#,Z(&5M
M86EL(&%D9')E<W,*("`@("`@("`@("`@*%M>7'-</R(\72HI"B`@("`@("`@
M("`@(",@4&%T=&5R;B`T('1O(#8Z($]P=&EO;F%L('!A<F%M971E<G,*("`@
M("`@("`@("`@*"A</RDH6UY<<R(\72I;7'<K(S]<+R8]72DI/PH@("`@("`@
M("`@("`C(%!A='1E<FX@-SH@0VQO<VEN9R!/=71L;V]K('-Q=6%R92!B<F%C
M:V5T"B`@("`@("`@("`@("@H/R@Q*5QS*EQ=*2D*"B`@("`@("`@("`@('P*
M("`@("`@("`@("`@(R!697)S:6]N(#(@4&%T=&5R;B`X.B!S:6UP;&4@96UA
M:6P@861D<F5S<V5S+@H@("`@("`@("`@("`H7&);7'<M*RX]72M`6RU!+5HP
M+3DN72I;02U:,"TY72D*("`@("`@("`@("`@(R!0871T97)N(#D@=&\@,3$Z
M($]P=&EO;F%L('!A<F%M971E<G,*("`@("`@("`@("`@*"A</RDH6UY<<R(\
M72I;7'<K(S]<+R8]72DI/PH*("`@("`@("`@("`@+V5I>`I%3U(["@H@("`@
M("`@(&EF("AI<U]A*"1R96=I<W1R>2P@)U)E9VES=')Y)RD@)B8*("`@("`@
M("`@("`@)')E9VES=')Y+3YH87--971H;V0H)VUA:6PO8V]M<&]S92<I("8F
M"B`@("`@("`@("`@("$D=&AI<RT^7W!A<F%M<ULG86QW87ES7VUA:6QT;R==
M*2!["B`@("`@("`@("`@("\J($EF('=E(&AA=F4@82!M86EL+V-O;7!O<V4@
M<F5G:7-T<GD@;65T:&]D+"!U<V4@:70N("HO"B`@("`@("`@("`@("1R97!L
M86-E;65N="`]("=497AT7T9I;'1E<E]E;6%I;',Z.F-A;&QB86-K*%PG)R`N
M("1T86<@+@H@("`@("`@("`@("`@("`@)UPG+"!<)R<@+B`D8VQA<W,@+B`G
M7"<L(%PG)#%<)RP@7"<D,EPG+"!<)R0S7"<L(%PG)#1<)RP@7"<D-EPG+"!<
M)R0W7"<L(%PG)#A<)RP@7"<D.5PG+"!<)R0Q,5PG*2<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+RH@3W1H97)W:7-E+"!G96YE<F%T92!A('-T
M86YD87)D(&UA:6QT;SH@86YD(&QE="!T:&4*("`@("`@("`@("`@("H@8G)O
M=W-E<B!H86YD;&4@:70N("HO"B`@("`@("`@("`@("1R97!L86-E;65N="`]
M(#P\/$5/4`H@("`@("`@("`@("`@("`@)R0X)R`]/3T@)R<@/PH*("`@("`@
M("`@("`@("`@("<D,20R/"1T86<D8VQA<W,@:')E9CTB;6%I;'1O.B0S)#0B
M('1I=&QE/2(G("X@<W!R:6YT9BA?*").97<@365S<V%G92!T;R`E<R(I+"!H
M=&UL<W!E8VEA;&-H87)S*"<D,R<I*2`N"B`@("`@("`@("`@("`@("`G(CXD
M,R0T/"\D=&%G/B0W)R`Z"@H@("`@("`@("`@("`@("`@)SPD=&%G)&-L87-S
M(&AR968](FUA:6QT;SHD."0Y(B!T:71L93TB)R`N('-P<FEN=&8H7R@B3F5W
M($UE<W-A9V4@=&\@)7,B*2P@:'1M;'-P96-I86QC:&%R<R@G)#@G*2D@+@H@
M("`@("`@("`@("`@("`@)R(^)#@D.3PO)'1A9SXG"D5/4#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B!A<G)A>2@D<F5G
M97AP(#T^("1R97!L86-E;65N="DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&-A
M;&QB86-K*"1T86<L("1C;&%S<RP@)&)R86-K970Q+"`D<')O=&]C;VPL("1E
M;6%I;"P@)&%R9W-?;&]N9RP*("`@("`@("`@("`@("`@("`@("`@("1A<F=S
M+"`D8G)A8VME=#(L("1E;6%I;#(L("1A<F=S7VQO;F<R+"`D87)G<S(I"B`@
M("!["B`@("`@("`@:68@*"%E;7!T>2@D96UA:6PR*2D@>PH@("`@("`@("`@
M("`D87)G<R`]("1A<F=S,CL*("`@("`@("`@("`@)&5M86EL(#T@)&5M86EL
M,CL*("`@("`@("`@("`@)&%R9W-?;&]N9R`]("1A<F=S7VQO;F<R.PH@("`@
M("`@('T*("`@("`@("`D97AT<F$@/2!C86QL7W5S97)?9G5N8RAC<F5A=&5?
M9G5N8W1I;VXH)R1A)RP@)R1P/6%R<F%Y*"D[9F]R96%C:"@D82!A<R`D8BE[
M)&(]97AP;&]D92@B/2(L)&(L,BD[)'!;)&);,%U=/4`D8ELQ73M]<F5T=7)N
M("1P.R<I+"!E>'!L;V1E*"<F)RP@)&%R9W,I*3L*("`@("`@("`D=7)L(#T@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)VUA:6PO8V]M<&]S92<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*&%R<F%Y*"=T;R<@/3X@)&5M86EL*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X=')A*2D["B`@("`@("`@)'5R;"`]
M('-T<E]R97!L86-E*"<F86UP.R<L("<F)RP@)'5R;"D["B`@("`@("`@:68@
M*'-U8G-T<B@D=7)L+"`P+"`Q,2D@/3T@)VIA=F%S8W)I<'0Z)RD@>PH@("`@
M("`@("`@("`D:')E9B`]("<C)SL*("`@("`@("`@("`@)&]N8VQI8VL@/2`G
M(&]N8VQI8VL](B<@+B!S=6)S='(H)'5R;"P@,3$I("X@)R(G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1H<F5F(#T@)'5R;#L*("`@("`@("`@
M("`@)&]N8VQI8VL@/2`G)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8G)A8VME=#$@+B`D<')O=&]C;VP@+B`G/"<@+B`D=&%G("X@)&-L87-S("X@
M)R!H<F5F/2(G("X*("`@("`@("`@("`@)&AR968@+B`G(B!T:71L93TB)R`N
M('-P<FEN=&8H7R@B3F5W($UE<W-A9V4@=&\@)7,B*2P@:'1M;'-P96-I86QC
M:&%R<R@D96UA:6PI*2`N("<B)R`N"B`@("`@("`@("`@("1O;F-L:6-K("X@
M)SXG("X@:'1M;'-P96-I86QC:&%R<R@D96UA:6PI("X@)&%R9W-?;&]N9R`N
M("<\+R<@+B`D=&%G("X@)SXG("X@)&)R86-K970R.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O96UO=&EC;VYS+G!H<```
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,C<W`#$P-#$W,S8R-S<S`#`R,S$R
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92YP:'`G.PH*+RHJ"B`J(%1H92!4
M97AT7T9I;'1E<E]E;6]T:6-O;G,Z.B!C;&%S<R!F:6YD<R!E;6]T:6-O;B!S
M=')I;F=S("@@.BDL(&5T8RXI(&EN(&$*("H@8FQO8VL@;V8@=&5X="!A;F0@
M='5R;G,@=&AE;2!I;G1O(&EM86=E(&QI;FMS+@H@*@H@*B!087)A;65T97)S
M.@H@*B`\<')E/@H@*B!E;G1I=&EE<R`M+2!)9B!T<G5E('1H92!H=&UL(&5N
M=&ET>2!V97)S:6]N<R!O9B!T:&4@<&%T=&5R;G,@=VEL;"!B92!U<V5D+@H@
M*B`\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M;W1I8V]N<RYP:'`L=B`Q+C$W+C$P+C<@,C`P-B\P,2\P,2`R
M,3HR.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-
M87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@
M0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?96UO
M=&EC;VYS(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@
M1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G96YT:71I97,G(#T^
M(&9A;'-E*3L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@
M<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710871T
M97)N<R@I"B`@("!["B`@("`@("`@)')E9V5X<"`](&%R<F%Y*"D["B`@("`@
M("`@)&EC;VYP871H(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E
M1&ER*"=H;W)D92<I("X@)R]E;6]T:6-O;G,G.PH*("`@("`@("`O*B!,;V]P
M('1H<F]U9V@@<&]S<VEB;&4@<W1R:6YG(&5M;W1I8V]N<R!A;F0@8V]N=F5R
M="!T;R!G<F%P:&EC<RX@*B\*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T
M26-O;G,H*2!A<R`D<W1R:6YG(#T^("1I8V]N*2!["B`@("`@("`@("`@("1E
M;F1?<&%T=&5R;B`]("=<<R<["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A
M<F%M<ULG96YT:71I97,G72D@>PH@("`@("`@("`@("`@("`@)'-T<FEN9R`]
M(&AT;6QS<&5C:6%L8VAA<G,H)'-T<FEN9RD["B`@("`@("`@("`@("`@("`D
M96YD7W!A='1E<FX@/2`G*%QS?#QB<B`O/BDG.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!#:&5C:R!F;W(@82!S;6EL97D@96ET:&5R(&EM;65D
M:6%T96QY(&%T('1H92!S=&%R="!O9B!A(&QI;F4@;W(*("`@("`@("`@("`@
M("H@9F]L;&]W:6YG(&$@<W!A8V4N(%5S92![?2!A<R!T:&4@<')E9R!D96QI
M;6ET97)S(&%S('1H:7,@:7,@;F]T"B`@("`@("`@("`@("`J(&9O=6YD(&EN
M(&%N>2!S;6EL97DN("HO"B`@("`@("`@("`@("1R96=E>'!;)WLH7GQ<<RDG
M("X@<')E9U]Q=6]T92@D<W1R:6YG*2`N("1E;F1?<&%T=&5R;B`N("=])UT@
M/2`G("<@+B!(;W)D93HZ:6UG*"1I8V]N("X@)RYP;F<G+"`D<W1R:6YG+"`G
M86QI9VX](FUI9&1L92(@=&ET;&4](B<@+B`D<W1R:6YG("X@)R(G+"`D:6-O
M;G!A=&@I("X@*"@D=&AI<RT^7W!A<F%M<ULG96YT:71I97,G72D@/R`G7%PR
M)R`Z("<G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5G
M97AP)R`]/B`D<F5G97AP*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!H87-H('=I=&@@96UO=&EC;VYS(&%N9"!N86UE<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971)8V]N<R@I"B`@("!["B`@("`@("`@+RH@3&ES="!C
M;VUP;&5X('-T<FEN9W,@8F5F;W)E('-I;7!L97(@;VYE<RP@;W1H97)W:7-E
M(&9O<B!E>&%M<&QE(#HH*`H@("`@("`@("`J('=O=6QD(&)E(&UA=&-H960@
M86=A:6YS="`Z*"!B969O<F4@.B@H(&ES(&9O=6YD+B`J+PH@("`@("`@(')E
M='5R;B!A<G)A>2@*("`@("`@("`@("`@)SHO)R`]/B`G9G)U<W1R871E9"<L
M("<Z+2\G(#T^("=F<G5S=')A=&5D)RP*("`@("`@("`@("`@+R\@)SHJ/B<@
M/3X@)V)L=7-H)RP*("`@("`@("`@("`@)SIE)R`]/B`G9&ES87!P;VEN=&5D
M)RP*("`@("`@("`@("`@)STZ*20G(#T^("=M<G0G+`H@("`@("`@("`@("`G
M(WPG(#T^("=H86YG;W9E<B<L("<C+7PG(#T^("=H86YG;W9E<B<L"B`@("`@
M("`@("`@("<Z+4`G(#T^("=S:&]U="<L"B`@("`@("`@("`@("<Z*"@G(#T^
M("=B:6=F<F]W;B<L("<Z0R<@/3X@)V)I9V9R;W=N)RP*("`@("`@("`@("`@
M)SI3)R`]/B`G9&%Z960G+"`G.BU3)R`]/B`G9&%Z960G+`H@("`@("`@("`@
M("`G6$`G(#T^("=A;F=R>2<L"B`@("`@("`@("`@("=8*"<@/3X@)VUA9"<L
M"B`@("`@("`@("`@("\O("<^.BDG(#T^("=D979I;"<L("<^.BTI)R`]/B`G
M9&5V:6PG+`H@("`@("`@("`@("`O+R`G/CIP)R`]/B`G9&5V:6QT;VYG=64G
M+"`G/CHM<"<@/3X@)V1E=FEL=&]N9W5E)RP*("`@("`@("`@("`@+R\@)SXZ
M<"<@/3X@)W)A<W!B97)R>2<L("<^.E`G(#T^("=R87-P8F5R<GDG+`H@("`@
M("`@("`@("`O+R`G)BDG(#T^("=P=6YK)RP*("`@("`@("`@("`@+R\@)R9P
M)R`]/B`G<'5N:W1O;F=U92<L"B`@("`@("`@("`@("\O("<])BDG(#T^("=P
M=6YK;6]H87=K)RP*("`@("`@("`@("`@)SI=)R`]/B`G9W)I;B<L"B`@("`@
M("`@("`@("<C6R<@/3X@)VAU<G0G+"`G(R@G(#T^("=H=7)T)RP@)R,M6R<@
M/3X@)VAU<G0G+"`G(RTH)R`]/B`G:'5R="<L"B`@("`@("`@("`@("<Z3R<@
M/3X@)V5M8F%R<F%S<V5D)RP@)SHM3R<@/3X@)V5M8F%R<F%S<V5D)RP*("`@
M("`@("`@("`@)SI;)R`]/B`G<V%D)RP*("`@("`@("`@("`@+R\@)SXZ0"<@
M/3X@)V5N<F%G960G+`H@("`@("`@("`@("`O+R`G.B8G(#T^("=A;FYO>65D
M)RP*("`@("`@("`@("`@)STH)R`]/B`G=V]R<FEE9"<L("<]+2@G(#T^("=W
M;W)R:65D)RP*("`@("`@("`@("`@)SI\/2<@/3X@)W9A;7!I<F4G+`H@("`@
M("`@("`@("`G.BTH)R`]/B`G9G)O=VXG+`H@("`@("`@("`@("`G.D0G(#T^
M("=B:6=G<FEN)RP*("`@("`@("`@("`@)S@I)R`]/B`G8V]O;"<L"B`@("`@
M("`@("`@("\O($EN($5N9VQI<V@L(#A032!O8V-U<G,@<W5F9FEC:65N=&QY
M(&]F=&5N('1O('-P96-I9FEC86QL>0H@("`@("`@("`@("`O+R!S96%R8V@@
M9F]R(&%N9"!E>&-L=61E"B`@("`@("`@("`@("<X<"@_/"%;36U=7',K*2<@
M/3X@)V-O;VQT;VYG=64G+"`O+R`G.-XG(#T^("=C;V]L=&]N9W5E)RP*("`@
M("`@("`@("`@)SA$)R`]/B`G8V]O;&=R:6XG+`H@("`@("`@("`@("`G.G`G
M(#T^("=T;VYG=65O=70G+"`G.E`G(#T^("=T;VYG=65O=70G+"`O+R`G.MXG
M(#T^("=T;VYG=65O=70G+`H@("`@("`@("`@("`G/SHH)R`]/B`G8V]N9G5S
M960G+"`G)2TH)R`]/B`G8V]N9G5S960G+`H@("`@("`@("`@("`O+R`G.BDF
M)R`]/B`G;&]V92<L"B`@("`@("`@("`@("=/.RTI)R`]/B`G86YG96QW:6YK
M)RP*("`@("`@("`@("`@)SM=)R`]/B`G=VEN:V=R:6XG+`H@("`@("`@("`@
M("`G.W`G(#T^("=W:6YK=&]N9W5E)RP@)SM0)R`]/B`G=VEN:W1O;F=U92<L
M("\O("<[WB<@/3X@)W=I;FMT;VYG=64G+`H@("`@("`@("`@("`G.GPG(#T^
M("=I;F1I9F9E<F5N="<L("<Z+7PG(#T^("=I;F1I9F9E<F5N="<L"B`@("`@
M("`@("`@("<A?"<@/3X@)W1I<F5D)RP@)R$M22<@/3X@)W1I<F5D)RP*("`@
M("`@("`@("`@)WQ))R`]/B`G87-L965P)RP@)WPM22<@/3X@)V%S;&5E<"<L
M"B`@("`@("`@("`@("=/.BDG(#T^("=A;F=E;"<L("=/.BTI)R`]/B`G86YG
M96PG+`H@("`@("`@("`@("`G3SLI)R`]/B`G86YG96QW:6YK)RP*("`@("`@
M("`@("`@)SLM*2<@/3X@)W=I;FLG+`H@("`@("`@("`@("`G.B,I)R`]/B`G
M8VQO=VXG+"`G.F\I)R`]/B`G8VQO=VXG+`H@("`@("`@("`@("`G.BDG(#T^
M("=S;6EL92<L"B`@("`@("`@("`@("<[*2<@/3X@)W=I;FLG+`H@("`@("`@
M("`@("`G.BTI)R`]/B`G<VUI;&4G+`H@("`@("`@("`@("`G.D`G(#T^("=S
M:&]U="<L"B`@("`@("`@("`@("<Z*"<@/3X@)V9R;W=N)RP*("`@("`@("`I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]497AT+T9I;'1E<B]E;G9I<F]N;65N="YP:'``````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$W,#<`,3`T,3<S-C(W-S,`,#(S-#8U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!297!L86-E<R!O8V-U<F5N8V5S(&]F("5605(E('=I=&@@5D%2+"!I9B!6
M05(@97AI<W1S(&EN('1H92!W96)S97)V97(G<PH@*B!E;G9I<F]N;65N="X@
M($EG;F]R97,@86QL('1E>'0@869T97(@82`G(R<@8VAA<F%C=&5R("AS:&5L
M;"US='EL90H@*B!C;VUM96YT<RDN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;G9I<F]N;65N="YP:'`L=B`Q+C,N,3`N
M-"`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?96YV:7)O;FUE;G0@
M97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("1R96=E>'`@/2!A
M<G)A>2@G+UXC+BHD7&XO;2<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("<O7BA;7B-=*BDC+BHD+VTG(#T^("<D,2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("<O)2A;02U:82UZ7UTK*24O92<@/3X@)V=E=&5N=B@B)#$B
M*2<I.PH@("`@("`@(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP
M*3L*("`@('T*"GT`````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3,S-C0`,3`T,3<S-C(W-S,`,#(T,S,S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@IR97%U:7)E7V]N8V4@)TAO<F1E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O4W1R:6YG+G!H<"<["@HO*BH*("H@2&EG:&QI9VAT<R!Q=6]T960@;65S
M<V%G97,@=VET:"!D:69F97)E;G0@8V]L;W)S(&9O<B!T:&4@9&EF9F5R96YT
M('%U;W1I;F<*("H@;&5V96QS+@H@*@H@*B!#4U,@8VQA<W,@;F%M97,@8V%L
M;&5D(")Q=6]T960Q(B`N+B`B<75O=&5D)&QE=F5L(B!M=7-T(&)E('!R97-E
M;G0N("!4:&4*("H@=&5X="!T;R!B92!P87-S960@:6X@;75S="!H879E(&%L
M<F5A9'D@8F5E;B!P87-S960@=&AR;W5G:`H@*B!H=&UL<W!E8VEA;&-H87)S
M*"DN"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J("=H:61E0FQO8VMS
M)R`M+2!(:61E('%U;W1E9"!T97AT(&)L;V-K<R!B>2!D969A=6QT/R!$969A
M=6QT<R!T;R!F86QS92X*("H@)V-I=&5B;&]C:R<@("TM($1I<W!L87D@8VET
M92!B;&]C:W,_($1E9F%U;'1S('1O('1R=64L"B`J(#PO<')E/@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<"QV(#$N-BXX+C@@,C`P-B\P,R\Q-"`R,CHT,SHS.2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8W5R96-A;G1I+F]R9SX*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&-U
M<F5C86YT:2YO<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]H:6=H;&EG:'1Q=6]T
M97,@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT
M97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=H:61E0FQO8VMS)R`]/B!F
M86QS92P@)V-I=&5B;&]C:R<@/3X@=')U92D["@H@("`@+RHJ"B`@("`@*B!%
M>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<F%Y(&)E9F]R92!A<'!L>6EN9R!T
M:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*
M("`@("`@("`O*B!486-K(&$@;F5W;&EN92!O;G1O('1H92!B96=I;FYI;F<@
M;V8@=&AE('-T<FEN9R!S;R!T:&%T('=E"B`@("`@("`@("H@8V]R<F5C=&QY
M(&AI9VAL:6=H="!W:&5N('1H92!F:7)S="!C:&%R86-T97(@:6X@=&AE('-T
M<FEN9R!I<R!A"B`@("`@("`@("H@<75O=&4@8VAA<F%C=&5R+B`J+PH@("`@
M("`@(')E='5R;B`B7&XD=&5X="(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("\J(%)E
M;6]V92!E>'1R82!S<&%C97,@8F5F;W)E('%U;W1E9"!T97AT(&%S('1H92!#
M4U,@9F]R;6%T=&EN9R!W:6QL"B`@("`@("`@("H@875T;VUA=&EC86QL>2!A
M9&0@82!B:70@;V8@<W!A8V4@9F]R('5S+B`J+PH@("`@("`@(&EF("@D=&AI
M<RT^7W!A<F%M<ULG8VET96)L;V-K)UTI('L*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"=R96=E>'`G(#T^(&%R<F%Y*"(O/&)R(%PO/EQS*EQN7',J/&)R
M(%PO/EQS*EQN7',J*"@F9W0[7',_*2LI+VTB(#T^("(\8G(@+SY<;EQ<,2(I
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)A>2!A
M9G1E<B!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&%F=&5R('1H92!F
M:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M
M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;W-T4')O8V5S
M<R@D=&5X="D*("`@('L*("`@("`@("`O*B!#4U,@9&5F:6YE<R`U(&1I9F9E
M<F5N="!C;VQO<G,@9F]R('%U;W1I;F<N("HO"B`@("`@("`@)&QE=F5L(#T@
M-3L*"B`@("`@("`@+RH@061D('-H;W<O:&ED92!T;V=G;&5S(&9O<B!W:&]L
M92!Q=6]T92!B;&]C:W,N("HO"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA
M8V5?8V%L;&)A8VLH(B\H7&XI*"@@*B@F9W0[7',_*2LH/R$@/R9G=#LI+BH_
M*2A<;GPD*2@_(2`J*"9G=#L@/RDK*2DO<R(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,L("=?861D475O=&54
M;V=G;&5S)RDL("1T97AT*3L*"B`@("`@("`@+RH@57-E(&-I=&4@8FQO8VMS
M('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!Q=6]T:6YG(&QE=F5L<RX@*B\*
M("`@("`@("`D8V(@/2`D=&AI<RT^7W!A<F%M<ULG8VET96)L;V-K)UT["B`@
M("`@("`@)&)L86YK;&EN92`]("1Q;&5V96P@/2`P.PH@("`@("`@("1T97AT
M7V]U="`]("<G.PH*("`@("`@("!F;W)E86-H("AE>'!L;V1E*")<;B(L("1T
M97AT*2!A<R`D;&EN92D@>PH@("`@("`@("`@("`D8VQE=F5L(#T@,#L*("`@
M("`@("`@("`@)&UA=&-H97,@/2!A<G)A>2@I.PH@("`@("`@("`@("!I9B`H
M<')E9U]M871C:"@B+UY<<RHH*"9G=#M<<S\I*RDO;2(L("1L:6YE+"`D;6%T
M8VAE<RDI('L*("`@("`@("`@("`@("`@("1C;&5V96P@/2!C;W5N="AP<F5G
M7W-P;&ET*"<O)F=T.UQS/R\G+"`D;6%T8VAE<ULQ72DI("T@,3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"1C8B`F)B!I<W-E="@D;6%T8VAE
M<ULQ72DI('L*("`@("`@("`@("`@("`@("1L:6YE(#T@<W5B<W1R*"1L:6YE
M+"!3=')I;F<Z.FQE;F=T:"@D;6%T8VAE<ULQ72DI.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)&-L979E;"`\("1Q;&5V96PI('L*("`@("`@
M("`@("`@("`@(&9O<B`H)&D@/2`D8VQE=F5L.R`D:2`\("1Q;&5V96P[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`D=&5X=%]O=70@+CT@*"1C8BD@
M/R`G/"]D:78^)R`Z("<\+V9O;G0^)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("@D8V(@)B8@<')E9U]M871C:"@B+UP\8G(@7"\^
M)"\B+"`D;&EN92DI('L*("`@("`@("`@("`@("`@("`@("`D;&EN92`]('-U
M8G-T<B@D;&EN92P@,"P@+38I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V5I9B`H)&-L979E;"`^("1Q;&5V96PI('L*("`@("`@("`@
M("`@("`@(&9O<B`H)&D@/2`R.R`D:2`\/2`D8FQA;FML:6YE.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1E>'1?;W5T(#T@<W5B<W1R*')T<FEM
M*"1T97AT7V]U="DL(#`L("TV*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&9O<B`H)&D@/2`D<6QE=F5L.R`D:2`\("1C;&5V96P[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-B*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T97AT7V]U="`N/2`G/&1I=B!C;&%S<STB8VET
M871I;VX@<75O=&5D)R`N("@H)&D@)2`D;&5V96PI("L@,2D@+B`G(CXG.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T97AT7V]U="`N/2`G/&9O;G0@8VQA<W,](G%U;W1E9"<@+B`H
M*"1I("4@)&QE=F5L*2`K(#$I("X@)R(^)SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@D;&EN92`]/2`G/&)R("\^)RD@>PH@("`@("`@("`@("`@("`@
M*RLD8FQA;FML:6YE.PH@("`@("`@("`@("`@("`@:68@*"1C;&5V96PI('L*
M("`@("`@("`@("`@("`@("`@("`K*R1B;&%N:VQI;F4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M8FQA;FML:6YE(#T@,#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1E
M>'1?;W5T("X]("1L:6YE("X@(EQN(CL*("`@("`@("`@("`@)'%L979E;"`]
M("1C;&5V96P["B`@("`@("`@?0H*("`@("`@("`O*B!296UO=F4@=&AE(&QE
M861I;F<@;F5W;&EN92!W92!A9&1E9"!A8F]V92P@:68@:70G<R!S=&EL;"!T
M:&5R92X@*B\*("`@("`@("!I9B`H)'1E>'1?;W5T6S!=(#T](")<;B(I('L*
M("`@("`@("`@("`@)'1E>'1?;W5T(#T@<W5B<W1R*"1T97AT7V]U="P@,2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1E>'1?;W5T.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!L:6YK<R!T;R!S:&]W(&%N9"!H:61E('%U
M;W1E9"!B;&]C:W,L(&AI9&EN9R!T:&5M(&)Y(&1E9F%U;'0@:68*("`@("`J
M('1H92`G:&ED94)L;V-K<R<@<&%R86UE=&5R(&ES('1R=64N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1M871C:&5S("!4:&4@;6%T8VAE<R!F<F]M('1H92!R96=E>'`N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]A9&11=6]T951O9V=L97,H)&UA=&-H97,I
M"B`@("!["B`@("`@("`@<W1A=&EC("1I(#T@,#L*"B`@("`@("`@+RH@1&]N
M)W0@=&]G9VQE('-M86QL(&)L;V-K<SL@9&]E<VXG="!P<F]V:61E(&$@54D@
M8F5N969I="!A;F0@;&]O:W,*("`@("`@("`@*B!A;FYO>6EN9RX@*B\*("`@
M("`@("`D;&EN97,@/2!S=6)S=')?8V]U;G0H)&UA=&-H97-;,%TL(")<;B(I
M.PH@("`@("`@(&EF("@D;&EN97,@/"`X*2!["B`@("`@("`@("`@(')E='5R
M;B`D;6%T8VAE<ULP73L*("`@("`@("!]"@H@("`@("`@($AO<F1E.CIA9&13
M8W)I<'1&:6QE*"=H:61E86)L92YJ<R<L("=H;W)D92<L('1R=64I.PH@("`@
M("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=Q=6]T94)L;V-K<RYJ<R<L("=H
M;W)D92<I.PH*("`@("`@("`D=&5X="`]("<G.PH@("`@("`@(&EF("@D=&AI
M<RT^7W!A<F%M<ULG8VET96)L;V-K)UTI('L*("`@("`@("`@("`@)'1E>'0@
M/2`G/&)R("\^)SL*("`@("`@("!].PH@("`@("`@("1T97AT("X]("<\9&EV
M(&ED/2)Q=%\G("X@)&D@+B`G(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FQI
M;FLH)R,G+"`G)RP@)W=I9&=E="!T;V=G;&5Q=6]T92<L("<G+"`G=&]G9VQE
M475O=&5";&]C:RA<)R<@+B`D:2`N("=<)RP@7"<G("X@)&QI;F5S("X@)UPG
M*3L@<F5T=7)N(&9A;'-E.R<L("<G+"`G)RP@87)R87DH)W-T>6QE)R`]/B`G
M9F]N="US:7IE.C<P)2<I*2`N"B`@("`@("`@("`@("@D=&AI<RT^7W!A<F%M
M<ULG:&ED94)L;V-K<R==(#\@<W!R:6YT9BA?*");4VAO=R!1=6]T960@5&5X
M="`M("5S(&QI;F5S72(I+"`D;&EN97,I(#H@7R@B6TAI9&4@475O=&5D(%1E
M>'1=(BDI("X*("`@("`@("`@("`@)SPO83X\+V1I=CX\9&EV(&ED/2)Q8E\G
M("X@)&D@+B`G(B<@+B`H)'1H:7,M/E]P87)A;7-;)VAI9&5";&]C:W,G72`_
M("<@<W1Y;&4](F1I<W!L87DZ;F]N93LB)R`Z("<G*2`N("<^)R`N("1M871C
M:&5S6S!=("X@)SPO9&EV/B<["@H@("`@("`@("1I*RL["@H@("`@("`@(')E
M='5R;B`D=&5X=#L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'``````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q-C$S,``Q,#0Q-S,V,C<W,P`P,C,P-3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO*BH*("H@5&%K97,@
M2%1-3"!A;F0@8V]N=F5R=',@:70@=&\@9F]R;6%T=&5D+"!P;&%I;B!T97AT
M+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@*B!C:&%R<V5T("TM(%1H
M92!C:&%R<V5T('1O('5S92!F;W(@:'1M;%]E;G1I='E?9&5C;V1E*"D@8V%L
M;',N"B`J('=I9'1H("`@+2T@5&AE('=R87!P:6YG('=I9'1H+@H@*B!W<F%P
M("`@("TM(%=H971H97(@=&\@=W)A<"!T:&4@=&5X="!O<B!N;W0N"B`J(#PO
M<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:'1M;#)T97AT+G!H<"QV(#$N-"XQ,"XQ,B`R,#`V+S`Q+S`Q(#(Q.C(X
M.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IO;B!!
M8F5R;F%T:'D@/&IO;D!C:'5G9VYU='0N8V]M/@H@*B!/<FEG:6YA;"!S;W5R
M8V4Z(&AT='`Z+R]W=W<N8VAU9V=N=71T+F-O;2]H=&UL,G1E>'0N<&AP"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!!8F5R;F%T
M:'D@/&IO;D!C:'5G9VYU='0N8V]M/@H@*B!`875T:&]R("!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?:'1M
M;#)T97AT(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@
M1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G8VAA<G-E="<@/3X@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("=W:61T:"<@/3X@-S`L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G=W)A<"<@/3X@=')U92D["@H@
M("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<F%Y(&)E
M9F]R92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@
M9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S
M<R@D=&5X="D*("`@('L*("`@("`@("!G;&]B86P@)%]H=&UL,G1E>'1?<W1A
M=&4["@H@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?<&%R86US6R=C:&%R
M<V5T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T
M)UT@/2!I<W-E="@D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UTI
M(#\@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==(#H@)TE33RTX
M.#4Y+3$G.PH@("`@("`@('T*"B`@("`@("`@)%]H=&UL,G1E>'1?<W1A=&5;
M)VQI;FM,:7-T)UT@/2`G)SL*("`@("`@("`D7VAT;6PR=&5X=%]S=&%T95LG
M;&EN:T-O=6YT)UT@/2`P.PH*("`@("`@("!R971U<FX@=')I;2@D=&5X="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E
M<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R
M;G,H*0H@("`@>PH@("`@("`@("1R96=E>'`@/2!A<G)A>2@*("`@("`@("`@
M("`@+R\@3F]N+6QE9V%L(&-A<G)I86=E(')E='5R;BX*("`@("`@("`@("`@
M)R]<<B\G(#T^("<G+`H*("`@("`@("`@("`@+R\@3&5A9&EN9R!A;F0@=')A
M:6QI;F<@=VAI=&5S<&%C92X*("`@("`@("`@("`@)R]>7',J*"XJ/RE<<RHD
M+VTG(#T^("=<,2<L"@H@("`@("`@("`@("`O+R!.;W)M86QI>F4@/&)R/BX*
M("`@("`@("`@("`@)R\\8G);7CY=*CXH6UY<;ETI+VDG(#T^("(\8G(^7&Y<
M7#$B+`H*("`@("`@("`@("`@+R\@3F5W;&EN97,@86YD('1A8G,N"B`@("`@
M("`@("`@("<O6UQN7'1=*R\G(#T^("<@)RP*"B`@("`@("`@("`@("\O(#QS
M8W)I<'0^<R`M+2!W:&EC:"!S=')I<%]T86=S*"D@<W5P<&]S961L>2!H87,@
M<')O8FQE;7,@=VET:"X*("`@("`@("`@("`@)R\\<V-R:7!T6UX^72H^+BH_
M/%PO<V-R:7!T/B]I)R`]/B`G)RP*"B`@("`@("`@("`@("\O(#QS='EL93YS
M("TM('=H:6-H('-T<FEP7W1A9W,H*2!S=7!P;W-E9&QY(&AA<R!P<F]B;&5M
M<R!W:71H+@H@("`@("`@("`@("`G+SQS='EL95M>/ETJ/BXJ/SQ<+W-T>6QE
M/B]I)R`]/B`G)RP*"B`@("`@("`@("`@("\O($-O;6UE;G1S("TM('=H:6-H
M('-T<FEP7W1A9W,H*2!M:6=H="!H879E(&$@<')O8FQE;2!W:71H+@H@("`@
M("`@("`@("`O+R`O+R<O/"$M+2`N*B`M+3XO)R`]/B`G)RP*"B`@("`@("`@
M("`@("\O(&@Q("T@:#,*("`@("`@("`@("`@)R\\:%LQ,C-=6UX^72H^*"XK
M/RD\7"]H6S$R,UT^(#\O:64G(#T^("=S=')T;W5P<&5R*")<;EQN(B`N(%PG
M7#%<)R`N(")<;EQN(BDG+`H*("`@("`@("`@("`@+R\@:#0@+2!H-@H@("`@
M("`@("`@("`G+SQH6S0U-EU;7CY=*CXH+BL_*3Q<+VA;-#4V73X@/R]I92<@
M/3X@)W5C=V]R9',H(EQN7&XB("X@7"=<,5PG("X@(EQN7&XB*2<L"@H@("`@
M("`@("`@("`O+R`\<#X*("`@("`@("`@("`@)R\\<%M>/ETJ/B`_+VDG(#T^
M(")<;EQN("`B+`H*("`@("`@("`@("`@+R\@/&)R/@H@("`@("`@("`@("`G
M+SQB<EM>/ETJ/B`_+VDG(#T^(")<;B(L"@H@("`@("`@("`@("`O+R`\8CX*
M("`@("`@("`@("`@)R\\8EM>/ETJ/B@N*S\I/%PO8CXO:64G(#T^("=S=')T
M;W5P<&5R*%PG7#%<)RDG+`H*("`@("`@("`@("`@+R\@/'-T<F]N9SX*("`@
M("`@("`@("`@)R\\<W1R;VYG6UX^72H^*"XK/RD\7"]S=')O;F<^+VEE)R`]
M/B`G<W1R=&]U<'!E<BA<)UPQ7"<I)RP*("`@("`@("`@("`@)R\\<W!A;EQ<
M<RMS='EL93TB9F]N="UW96EG:'0Z7%QS*F)O;&0N*B(^*"XK/RD\7"]S<&%N
M/B]I92<@/3X@)W-T<G1O=7!P97(H7"=<,5PG*2<L"@H@("`@("`@("`@("`O
M+R`\:3X*("`@("`@("`@("`@)R\\:5M>/ETJ/B@N*S\I/%PO:3XO:2<@/3X@
M)R]<7#$O)RP*"B`@("`@("`@("`@("\O(#QE;3X*("`@("`@("`@("`@)R\\
M96U;7CY=*CXH+BL_*3Q<+V5M/B]I)R`]/B`G+UQ<,2\G+`H*("`@("`@("`@
M("`@+R\@/'4^"B`@("`@("`@("`@("<O/'5;7CY=*CXH+BL_*3Q<+W4^+VDG
M(#T^("=?7%PQ7R<L"@H@("`@("`@("`@("`O+R`\=6P^+SQO;#X@86YD(#PO
M=6P^+SPO;VP^"B`@("`@("`@("`@("<O*#PH=7QO*6Q;7CY=*CY\(#\\7"\H
M=7QO*6P^*2`_+VDG(#T^(")<;EQN(BP*"B`@("`@("`@("`@("\O(#QL:3X*
M("`@("`@("`@("`@)R\@/SQL:5M>/ETJ/B]I)R`]/B`B7&X@("H@(BP*"B`@
M("`@("`@("`@("\O(#QA(&AR968](B(^"B`@("`@("`@("`@("<O/&$@:')E
M9CTB*%M>(ETK*2);7CY=*CXH+BL_*3Q<+V$^+VEE)R`]/B`G5&5X=%]&:6QT
M97)?:'1M;#)T97AT.CI?8G5I;&1,:6YK3&ES="@D1TQ/0D%,4ULB7VAT;6PR
M=&5X=%]S=&%T92)=6R)L:6YK0V]U;G0B72P@7"=<,5PG+"!<)UPR7"<I)RP*
M"B`@("`@("`@("`@("\O(#QH<CX*("`@("`@("`@("`@)R\\:');7CY=*CX@
M/R]I)R`]/B`B7&XM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM7&XB+`H*("`@
M("`@("`@("`@+R\@/'1A8FQE/B!A;F0@/"]T86)L93X*("`@("`@("`@("`@
M)R\H/'1A8FQE6UX^72H^?"`_/%PO=&%B;&4^*2`_+VDG(#T^(")<;EQN(BP*
M"B`@("`@("`@("`@("\O(#QT<CX*("`@("`@("`@("`@)R\@/SQT<EM>/ETJ
M/B`_+VDG(#T^(")<;EQT(BP*"B`@("`@("`@("`@("\O(#QT9#X@86YD(#PO
M=&0^"B`@("`@("`@("`@("<O(#\\=&1;7CY=*CXH+BL_*3Q<+W1D/B`_+VDG
M(#T^("=<,2<@+B`B7'1<="(L"B`@("`@("`@("`@("<O7'1<=#Q<+W1R/B]I
M)R`]/B`G)RP*"B`@("`@("`@("`@("\O(&5N=&ET:65S"B`@("`@("`@("`@
M("<O)FYB<W`[+VDG(#T^("<@)RP*("`@("`@("`@("`@)R\F=')A9&4[+VDG
M(#T^("<H=&TI)RP*("`@("`@("`@("`@)R\F(RA<9"LI.R]E)R`]/B`G4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="A497AT7T9I;'1E<E]H=&UL,G1E>'0Z.E]I
M;G0R=71F."A<)UPQ7"<I+"`B551&+3@B+"`B)R`N("1T:&ES+3Y?<&%R86US
M6R=C:&%R<V5T)UT@+B`G(BDG+`H*("`@("`@("`@("`@+R\@4V]M92!M86EL
M97)S("AE+F<N($AO=&UA:6PI('5S92!T:&4@9F]L;&]W:6YG(&1I=B!T86<@
M87,@82!W87D*("`@("`@("`@("`@+R\@=&\@9&5F:6YE(&$@8FQO8VL@;V8@
M=&5X="X*("`@("`@("`@("`@)R\\9&EV(&-L87-S/7)T93XH+BL_*3Q<+V1I
M=CX@/R]I)R`]/B`G7#$G("X@(EQN(@H@("`@("`@("D["@H@("`@("`@(')E
M='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@869T97(@
M87!P;'EI;F<@=&AE(&9I;'1E<@H@("`@("H@<&%T=&5R;G,N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@869T97(@=&AE
M(&9I;'1E<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&UO9&EF:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O<W10<F]C
M97-S*"1T97AT*0H@("`@>PH@("`@("`@(&=L;V)A;"`D7VAT;6PR=&5X=%]S
M=&%T93L*"B`@("`@("`@+RH@4W1R:7`@86YY(&]T:&5R($A434P@=&%G<RX@
M*B\*("`@("`@("`D=&5X="`]('-T<FEP7W1A9W,H)'1E>'0I.PH*("`@("`@
M("`O*B!#;VYV97)T(&AT;6P@96YT:71I97,N("HO"B`@("`@("`@)'1E>'0@
M/2!`:'1M;%]E;G1I='E?9&5C;V1E*"1T97AT+"!%3E1?455/5$53+"`D=&AI
M<RT^7W!A<F%M<ULG8VAA<G-E="==*3L*"B`@("`@("`@+RH@0G)I;F<@9&]W
M;B!N=6UB97(@;V8@96UP='D@;&EN97,@=&\@,B!M87@N("HO"B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H(B]<;EM;.G-P86-E.EU=*UQN+R(L(")<
M;EQN(BP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"(O
M6UQN77LS+'TO(BP@(EQN7&XB+"`D=&5X="D["@H@("`@("`@("\J(%=R87`@
M=&AE('1E>'0@=&\@82!R96%D86)L92!F;W)M870N("HO"B`@("`@("`@:68@
M*"1T:&ES+3Y?<&%R86US6R=W<F%P)UTI('L*("`@("`@("`@("`@)'1E>'0@
M/2!W;W)D=W)A<"@D=&5X="P@)'1H:7,M/E]P87)A;7-;)W=I9'1H)UTI.PH@
M("`@("`@('T*"B`@("`@("`@+RH@061D(&QI;FL@;&ES="X@*B\*("`@("`@
M("!I9B`H(65M<'1Y*"1?:'1M;#)T97AT7W-T871E6R=L:6YK3&ES="==*2D@
M>PH@("`@("`@("`@("`D=&5X="`N/2`B7&Y<;B(@+B!?*"),:6YK<R(I("X@
M(CI<;B(@+B!S=')?<F5P96%T*"<M)RP@4W1R:6YG.CIL96YG=&@H7R@B3&EN
M:W,B*2D@*R`Q*2`N(")<;B(@+B`D7VAT;6PR=&5X=%]S=&%T95LG;&EN:TQI
M<W0G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(%541BTX(&-H87)A8W1E<B!S
M97%U96YC92!O9B!A(%5N:6-O9&4@=F%L=64N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&YU;2`@02!5;FEC;V1E('9A;'5E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@551&+3@@<W1R:6YG+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?:6YT,G5T9C@H)&YU;2D*("`@('L*("`@("`@("!I
M9B`H)&YU;2`\(#$R."D@>PH@("`@("`@("`@("!R971U<FX@8VAR*"1N=6TI
M.PH@("`@("`@('T*("`@("`@("!I9B`H)&YU;2`\(#(P-#@I('L*("`@("`@
M("`@("`@<F5T=7)N(&-H<B@H)&YU;2`^/B`V*2`K(#$Y,BD@+B!C:'(H*"1N
M=6T@)B`V,RD@*R`Q,C@I.PH@("`@("`@('T*("`@("`@("!I9B`H)&YU;2`\
M(#8U-3,V*2!["B`@("`@("`@("`@(')E='5R;B!C:'(H*"1N=6T@/CX@,3(I
M("L@,C(T*2`N(&-H<B@H*"1N=6T@/CX@-BD@)B`V,RD@*R`Q,C@I("X*("`@
M("`@("`@("`@("`@(&-H<B@H)&YU;2`F(#8S*2`K(#$R."D["B`@("`@("`@
M?0H@("`@("`@(&EF("@D;G5M(#P@,C`Y-S$U,BD@>PH@("`@("`@("`@("!R
M971U<FX@8VAR*"@D;G5M(#X^(#$X*2`K(#(T,"D@+B!C:'(H*"@D;G5M(#X^
M(#$R*2`F(#8S*2`K(#$R."D@+@H@("`@("`@("`@("`@("`@8VAR*"@H)&YU
M;2`^/B`V*2`F(#8S*2`K(#$R."D@+B!C:'(H*"1N=6T@)B`V,RD@*R`Q,C@I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!(96QP97(@9G5N8W1I;VX@8V%L;&5D(&)Y('!R96=?<F5P;&%C
M92@I(&]N(&QI;FL@<F5P;&%C96UE;G0N"B`@("`@*@H@("`@("H@36%I;G1A
M:6YS(&%N(&EN=&5R;F%L(&QI<W0@;V8@;&EN:W,@=&\@8F4@9&ES<&QA>65D
M(&%T('1H92!E;F0*("`@("`J(&]F('1H92!T97AT+"!W:71H(&YU;65R:6,@
M:6YD:6-E<R!T;R!T:&4@;W)I9VEN86P@<&]I;G0@:6X@=&AE"B`@("`@*B!T
M97AT('1H97D@87!P96%R960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;FM?8V]U;G0@
M($-O=6YT97(@=')A8VMI;F<@8W5R<F5N="!L:6YK(&YU;6)E<BX*("`@("`J
M($!P87)A;2!S=')I;F<@("1L:6YK("`@("`@("!54DP@;V8@=&AE(&QI;FLN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9&ES<&QA>2`@("`@4&%R="!O9B!T
M:&4@=&5X="!T;R!A<W-O8VEA=&4@;G5M8F5R('=I=&@N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!L:6YK(')E<&QA8V5M96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8G5I;&1,:6YK3&ES="@D;&EN:U]C;W5N="P@
M)&QI;FLL("1D:7-P;&%Y*0H@("`@>PH@("`@("`@(&=L;V)A;"`D7VAT;6PR
M=&5X=%]S=&%T93L*"B`@("`@("`@)%]H=&UL,G1E>'1?<W1A=&5;)VQI;FM#
M;W5N="==*RL["B`@("`@("`@)%]H=&UL,G1E>'1?<W1A=&5;)VQI;FM,:7-T
M)UT@+CT@)ULG("X@)%]H=&UL,G1E>'1?<W1A=&5;)VQI;FM#;W5N="==("X@
M(ET@)&QI;FM<;B(["B`@("`@("`@<F5T=7)N("1D:7-P;&%Y("X@)ULG("X@
M)%]H=&UL,G1E>'1?<W1A=&5;)VQI;FM#;W5N="==("X@)UTG.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O5&5X="]&:6QT97(O;&EN:W5R;',N<&AP````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`U,C$V`#$P-#$W,S8R-S<S`#`R,C<V,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE(%1E>'1?1FEL=&5R7VQI;FMU<FQS.CH@8VQA<W,@='5R;G,@
M86QL(%523',@:6X@=&AE('1E>'0@:6YT;R!H>7!E<FQI;FMS+@H@*@H@*B!0
M87)A;65T97)S.@H@*B`\<')E/@H@*B!T87)G970@("`M+2!4:&4@;&EN:R!T
M87)G970N("!$969A=6QT<R!T;R!?8FQA;FLN"B`J(&-L87-S("`@("TM(%1H
M92!#4U,@8VQA<W,@;V8@=&AE(&=E;F5R871E9"!L:6YK<RX@($1E9F%U;'1S
M('1O(&YO;F4N"B`J(&YO9F]L;&]W("TM(%=H971H97(@=&\@<V5T('1H92`G
M<F5L/2)N;V9O;&QO=R(G(&%T=')I8G5T92!O;B!L:6YK<RX*("H@8V%P:71A
M;"`@+2T@9V5N97)A=&4@=7!P97)C87-E(#Q!/B!T86=S('-O('EO=2!C86X@
M:VYO=R!W:&EC:"!T86=S('EO=2!J=7-T"B`J("`@("`@("`@("`@(&=E;F5R
M871E9"X@($1E9F%U;'1S('1O(&9A;'-E+@H@*B!C86QL8F%C:R`M+2!!;B!O
M<'1I;VYA;"!C86QL8F%C:R!F=6YC=&EO;B!T:&%T('1H92!54DP@:7,@<&%S
M<V5D('1H<F]U9V@*("H@("`@("`@("`@("`@8F5F;W)E(&)E:6YG('-E="!A
M<R!T:&4@:')E9B!A='1R:6)U=&4N("!-=7-T(&)E(&$@<W1R:6YG('=I=&@*
M("H@("`@("`@("`@("`@=&AE(&9U;F-T:6]N(&YA;64L('1H92!F=6YC=&EO
M;B!M=7-T('1A:V4@=&AE(&]R:6=I;F%L(&%S('1H90H@*B`@("`@("`@("`@
M("!F:7)S="!A;F0@;VYL>2!P87)A;65T97(N"B`J(#PO<')E/@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O;&EN:W5R;',N
M<&AP+'8@,2XQ,2XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@5'EL97(@0V]L8F5R="`\='EL
M97(M:&]R9&5M;$!C;VQB97)T<RYU<SX*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@5'EL97(@0V]L8F5R="`\='EL97(M:&]R9&5M;$!C
M;VQB97)T<RYU<SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X
M=%]&:6QT97)?;&EN:W5R;',@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@
M+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=T
M87)G970G(#T^("=?8FQA;FLG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-L87-S)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=N;V9O
M;&QO=R<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`G8V%P
M:71A;"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`G8V%L
M;&)A8VLG(#T^(&YU;&PI.PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY
M(&-O9&4@;F5C97-S87)Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A
M='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H
M92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/E]P87)A;7-;)V-A<&ET86PG72D@>PH@("`@("`@("`@("`D=&5X
M="`]('-T<E]R97!L86-E*&%R<F%Y*"<\+T$^)RP@)SQ!)RDL(&%R<F%Y*"<\
M+V$^)RP@)SQA)RDL("1T97AT*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H
M('=I=&@@<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9710871T97)N<R@I"B`@("!["B`@("`@("`@)&$@/2`D=&AI<RT^7W!A<F%M
M<ULG8V%P:71A;"==(#\@)T$G(#H@)V$G.PH*("`@("`@("`D8VQA<W,@/2`D
M=&AI<RT^7W!A<F%M<ULG8VQA<W,G73L*("`@("`@("!I9B`H(65M<'1Y*"1C
M;&%S<RDI('L*("`@("`@("`@("`@)&-L87-S(#T@)R!C;&%S<STB)R`N("1C
M;&%S<R`N("<B)SL*("`@("`@("!]"B`@("`@("`@)&YO9F]L;&]W(#T@)'1H
M:7,M/E]P87)A;7-;)VYO9F]L;&]W)UT@/R`G(')E;#TB;F]F;VQL;W<B)R`Z
M("<G.PH*("`@("`@("`D=7)L(#T@)'1H:7,M/E]P87)A;7-;)V-A;&QB86-K
M)UT@/R`G7"<@+B`G("X@)'1H:7,M/E]P87)A;7-;)V-A;&QB86-K)UT@+B`G
M*%PG)#!<)RD@+B!<)R<@.B`G)#`G.PH*("`@("`@("`D<F5G97AP(#T@87)R
M87DH)WPH7'<K*3HO+RA;7EQS(CQ=*EM<=RLC/R\F/5TI?&4G(#T^"B`@("`@
M("`@("`@("`@("`@("`@("`@("=<)SPG("X@)&$@+B`G(&AR968](B<@+B`D
M=7)L("X@)R(G("X@)&YO9F]L;&]W("X@)R!T87)G970](E]B;&%N:R(G("X@
M)&-L87-S("X@)SXD,#PO)R`N("1A("X@)SY<)R<I.PH*("`@("`@("!R971U
M<FX@87)R87DH)W)E9V5X<"<@/3X@)')E9V5X<"D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT
M+T9I;'1E<B]R<W0N<&AP````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$W-38`,3`T,3<S-C(W-S,`,#(Q-S,U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U1E
M>'0O<F535"YP:'`G.PIR97%U:7)E7V]N8V4@)U1E>'0O<F535"]&;W)M871T
M97(N<&AP)SL*"B\J*@H@*B!4:&4@5&5X=%]&:6QT97)?<G-T.CH@8VQA<W,@
M8V]N=F5R=',@<F53=')U8W1U<F5D5&5X="!T;R!(5$U,+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O<G-T+G!H<"QV(#$N
M.2XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R
M;VYO<WES+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED
M(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N
M($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E
M($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7W)S="!E>'1E;F1S
M(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C
M;V1E(&YE8V5S<V%R87D@869T97(@87!P;'EI;F<@=&AE(&9I;'1E<@H@("`@
M("H@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="`@5&AE('1E>'0@869T97(@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!O<W10<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@
M("1D;V-U;65N="`]("9497AT7W)E4U0Z.G!A<G-E*"1T97AT*3L*("`@("`@
M("`D9F]R;6%T=&5R(#T@)E1E>'1?<F535%]&;W)M871T97(Z.F9A8W1O<GDH
M)VAT;6PG*3L*("`@("`@("!R971U<FX@)&9O<FUA='1E<BT^9F]R;6%T*"1D
M;V-U;65N="P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@?0H*?0H`````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]497AT+T9I;'1E<B]S:6UP;&5M87)K=7`N<&AP````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P,C(`,3`T,3<S-C(W-S,`,#(S-C(Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!(:6=H
M;&EG:'1S('-I;7!L92!M87)K=7`@87,@=7-E9"!I;B!E;6%I;',@;W(@=7-E
M;F5T('!O<W1I;F=S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O<VEM<&QE;6%R:W5P+G!H<"QV(#$N,2XQ,"XT(#(P,#8O
M,#$O,#$@,C$Z,C@Z,S@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]4
M97AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]S:6UP;&5M87)K=7`@97AT96YD
M<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S
M:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("1R96=E>'`@/2!A<G)A>2@*
M("`@("`@("`@("`@+R\@0F]L9"X*("`@("`@("`@("`@)R\H7'-\7&XI*%PJ
M6UXJ7'-=*UPJ*2A<<WQ<<GQ<;GP\8G(I+VDG(#T^("=<,3QS=')O;F<^7#(\
M+W-T<F]N9SY<,R<L"@H@("`@("`@("`@("`O+R!5;F1E<FQI;F4N"B`@("`@
M("`@("`@("<O*%QS?%QN*2A?6UY?7'-=*U\I*%QS?%QR?%QN?#QB<BDO:2<@
M/3X@)UPQ/'4^7#(\+W4^7#,G+`H*("`@("`@("`@("`@+R\@271A;&EC+@H@
M("`@("`@("`@("`G.RA<<WQ<;BDH+UM>+UQS72LO*2A<<WQ<<GQ<;GP\8G(I
M.VDG(#T^("=<,3QE;3Y<,CPO96T^7#,G*3L*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=R96=E>'`G(#T^("1R96=E>'`I.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W-P86-E,FAT
M;6PN<&AP```````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#(R-P`Q,#0Q-S,V,C<W
M,P`P,C,Q-C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!S<&%C93)H=&UL(&9I;'1E<B!C;VYV
M97)T<R!H;W)I>F]N=&%L('=H:71E<W!A8V4@=&\@2%1-3"!C;V1E+@H@*@H@
M*B!087)A;65T97)S.@H@*B`\<')E/@H@*B!E;F-O9&4@("`@("TM($A434P@
M96YC;V1E('1H92!T97AT/R`@1&5F875L=',@=&\@9F%L<V4N"B`J(&-H87)S
M970@("`@+2T@0VAA<G-E="!O9B!T:&4@=&5X="X@($1E9F%U;'1S('1O($E3
M3RTX.#4Y+3$N"B`J(&5N8V]D95]A;&P@+2T@4F5P;&%C92!A;&P@<W!A8V5S
M('=I=&@@)FYB<W`[/R`@1&5F875L=',@=&\@9F%L<V4N"B`J(#PO<')E/@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O<W!A
M8V4R:'1M;"YP:'`L=B`Q+C$N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2!-871H:65U($%R;F]L9"`\
M87)N7VUA=$!C;'5B+6EN=&5R;F5T+F9R/@H@*B!#;W!Y<FEG:'0@,C`P-"TR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*B!`875T:&]R("!-871H:65U($%R;F]L9"`\87)N7VUA=$!C;'5B+6EN
M=&5R;F5T+F9R/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!4
M97AT7T9I;'1E<E]S<&%C93)H=&UL(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*
M("`@("\J*@H@("`@("H@1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A
M>2@G96YC;V1E)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("=C:&%R<V5T)R`]/B`G25-/+3@X-3DM,2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G96YC;V1E7V%L;"<@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@
M("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)Y(&)E9F]R92!A<'!L>6EN
M9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V5N8V]D92==*2!["B`@
M("`@("`@("`@("1T97AT(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'1E>'0L($5.
M5%]#3TU0050L("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("1R
M97!L86-E(#T@87)R87DH(EQT(B`]/B`G)FYB<W`[("9N8G-P.R`F;F)S<#L@
M)FYB<W`[("<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G("`G(#T^("<F
M;F)S<#L@)RD["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R97!L86-E)R`]/B`D
M<F5P;&%C92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@
M8V]D92!N96-E<W-A<F%Y(&%F=&5R(&%P<&QY:6YG('1H92!F:6QT97(@<&%T
M=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE
M('1E>'0@869T97(@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!O<W10<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@("1T97AT
M(#T@<W1R7W)E<&QA8V4H)R`@)RP@)R`F;F)S<#LG+"`D=&5X="D["B`@("`@
M("`@:68@*"1T:&ES+3Y?<&%R86US6R=E;F-O9&5?86QL)UTI('L*("`@("`@
M("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G("<L("<F;F)S<#LG+"`D=&5X
M="D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+W1A8G,R<W!A8V5S+G!H<```````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4P
M,P`Q,#0Q-S,V,C<W,P`P,C,S,C8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!497AT7T9I;'1E
M<E]T86)S,G-P86-E<SHZ(&-O;G9E<G1S('1A8G,@:6YT;R!S<&%C97,N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]T86)S
M,G-P86-E<RYP:'`L=B`Q+C,N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P
M86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7W1A8G,R
M<W!A8V5S(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@
M1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G=&%B<W1O<"<@/3X@
M."P@)V)R96%K8VAA<B<@/3X@(EQN(BD["@H@("`@+RHJ"B`@("`@*B!%>&5C
M=71E<R!A;GD@8V]D92!N96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG('1H92!F
M:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@5&AE('1E>'0@8F5F;W)E('1H92!F:6QT97)I;F<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!P<F50<F]C97-S*"1T97AT*0H@("`@>PH@("`@
M("`@("1L:6YE<R`](&5X<&QO9&4H)'1H:7,M/E]P87)A;7-;)V)R96%K8VAA
M<B==+"`D=&5X="D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H
M)&QI;F5S*3L@)&DK*RD@>PH@("`@("`@("`@("!W:&EL92`H*"1P;W,@/2!S
M=')P;W,H)&QI;F5S6R1I72P@(EQT(BDI("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)&Y?<W!A8V4@/2`D=&AI<RT^7W!A<F%M<ULG=&%B<W1O<"==
M("T@*"1P;W,@)2`D=&AI<RT^7W!A<F%M<ULG=&%B<W1O<"==*3L*("`@("`@
M("`@("`@("`@("1N97=?<W1R(#T@<W1R7W)E<&5A="@G("<L("1N7W-P86-E
M*3L*("`@("`@("`@("`@("`@("1L:6YE<ULD:5T@/2!S=6)S=')?<F5P;&%C
M92@D;&EN97-;)&E=+"`D;F5W7W-T<BP@)'!O<RP@,2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H(EQN(BP@)&QI
M;F5S*3L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O=&5X=#)H=&UL+G!H<```````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$R-#8W`#$P-#$W,S8R-S<S`#`R,S`V,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E("=(;W)D92YP:'`G.PH*+RHJ"B`J(%1U<FX@=&5X
M="!I;G1O($A434P@=VET:"!V87)Y:6YG(&QE=F5L<R!O9B!P87)S:6YG+B`@
M1F]R(&YO(&AT;6P*("H@=VAA='-O979E<BP@=7-E(&AT;6QS<&5C:6%L8VAA
M<G,H*2!I;G-T96%D+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@*B!P
M87)S96QE=F5L("TM(%1H92!P87)S96QE=F5L(&]F('1H92!O=71P=70N(%-E
M92!T:&4@;&ES="!O9B!C;VYS=&%N=',@8F5L;W<N"B`J(&-H87)S970@("`@
M+2T@5&AE(&-H87)S970@=&\@=7-E(&9O<B!H=&UL<W!E8VEA;&-H87)S*"D@
M8V%L;',N"B`J(&-L87-S("`@("`@+2T@5&AE($-34R!C;&%S<R!N86UE(&9O
M<B!T:&4@;&EN:W,N"B`J(&YO9F]L;&]W("`@+2T@5VAE=&AE<B!T;R!S970@
M=&AE("=R96P](FYO9F]L;&]W(B<@871T<FEB=71E(&]N(&QI;FMS+@H@*B!C
M86QL8F%C:R`@("TM($%N(&]P=&EO;F%L(&-A;&QB86-K(&9U;F-T:6]N('1H
M870@=&AE(%523"!I<R!P87-S960@=&AR;W5G:`H@*B`@("`@("`@("`@("`@
M(&)E9F]R92!B96EN9R!S970@87,@=&AE(&AR968@871T<FEB=71E+B`@375S
M="!B92!A('-T<FEN9R!W:71H"B`J("`@("`@("`@("`@("`@=&AE(&9U;F-T
M:6]N(&YA;64L('1H92!F=6YC=&EO;B!M=7-T('1A:V4@=&AE(&]R:6=I;F%L
M(&%S('1H90H@*B`@("`@("`@("`@("`@(&9I<G-T(&%N9"!O;FQY('!A<F%M
M971E<BX*("H@/"]P<F4^"B`J"B`J(#QP<F4^"B`J($QI<W0@;V8@=F%L:60@
M8V]N<W1A;G1S(&9O<B!T:&4@<&%R<V4@;&5V96PZ"B`J("TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`J(%1%6%1?2%1-
M3%]005-35$A252`@("`@("`@/2`@3F\@86-T:6]N+B!087-S+71H<F]U9V@N
M($EN8VQU9&5D(&9O<@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;7!L971E;F5S<RX*("H@5$585%](5$U,7U-93E1!6"`@("`@("`@("`]
M("!!;&QO=R!F=6QL(&AT;6PL(&%L<V\@9&\@;&EN92UB<F5A:W,L"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:6XM;&EN:6YG+"!S>6YT87@M
M<&%R<VEN9RX*("H@5$585%](5$U,7TU)0U)/("`@("`@("`@("`]("!-:6-R
M;R!H=&UL("AO;FQY(&QI;F4M8G)E86MS+"!I;BUL:6YE(&QI;FMI;F<I+@H@
M*B!415A47TA434Q?34E#4D]?3$E.2U523"`@(#T@($UI8W)O(&AT;6P@*&]N
M;'D@;&EN92UB<F5A:W,L(&EN+6QI;F4@;&EN:VEN9PH@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]F(%523%-S.R!N;R!E;6%I;"!A9&1R97-S
M97,@87)E(&QI;FME9"DN"B`J(%1%6%1?2%1-3%].3TA434P@("`@("`@("`@
M/2`@3F\@:'1M;"`H86QL('-T<FEP<&5D+"!O;FQY(&QI;F4M8G)E86MS*0H@
M*B!415A47TA434Q?3D](5$U,7TY/0E)%04L@(#T@($YO(&AT;6P@=VAA='-O
M979E<BP@;F\@;&EN92!B<F5A:W,@861D960N"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@26YC;'5D960@9F]R(&-O;7!L971E;F5S<RX*("H@
M/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]T97AT,FAT;6PN<&AP+'8@,2XT+C(N-B`R,#`V+S`R+S$W(#(P.C`U
M.C0Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT
M7T9I;'1E<E]T97AT,FAT;6P@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@
M+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=C
M:&%R<V5T)R`]/B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V-L
M87-S)R`]/B`G9FEX960G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)VYO
M9F]L;&]W)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("=C
M86QL8F%C:R<@/3X@)TAO<F1E.CIE>'1E<FYA;%5R;"<I.PH*("`@("\J*@H@
M("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)Y(&)E9F]R92!A<'!L
M>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@
M=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W!A<F%M<ULG8VAA
M<G-E="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E
M="==(#T@:7-S970H)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==
M*2`_("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72`Z("=)4T\M
M.#@U.2TQ)SL*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&]U="!O;B!S
M:6UP;&4@8V%S97,N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=P
M87)S96QE=F5L)UT@/3T@5$585%](5$U,7U!!4U-42%)5*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&5X=#L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3Y?<&%R86US6R=P87)S96QE=F5L)UT@/3T@5$585%](5$U,7TY/2%1-3%].
M3T)214%+*2!["B`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R
M<R@D=&5X="P@14Y47T-/35!!5"P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G
M72D["B`@("`@("`@?0H*("`@("`@("`O*B!$;R!I;BUL:6YI;F<@;V8@:'1T
M<#HO+WAX>"YX>'@@=&\@;&EN:RP@>'AX0'AX>"YX>'@@=&\@96UA:6PL('!A
M<G0*("`@("`@("`@*B!O;F4N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R
M86US6R=P87)S96QE=F5L)UT@/"!415A47TA434Q?3D](5$U,*2!["B`@("`@
M("`@("`@("\J($UA:V4@<W5R92!T:&%T('1H92!O<FEG:6YA;"!M97-S86=E
M(&1O97-N)W0@8V]N=&%I;B!A;GD@8V%P:71A;`H@("`@("`@("`@("`@*B`\
M+T$^('1A9W,@;W(@;W!E;B`\03X@=&%G<R`L('-O('=E(&-A;B!A<W-U;64@
M=V4@9V5N97)A=&5D"B`@("`@("`@("`@("`J('1H96TN("HO"B`@("`@("`@
M("`@("1T97AT(#T@<W1R7W)E<&QA8V4H87)R87DH)SPO03XG+"`G/$$G*2P@
M87)R87DH)SPO83XG+"`G/&$G*2P@)'1E>'0I.PH@("`@("`@("`@("`D9FEL
M=&5R7V%R<F%Y(#T@87)R87DH)VQI;FMU<FQS)RD["B`@("`@("`@("`@("1F
M:6QT97)?<&%R86US(#T@87)R87DH87)R87DH)V-A;&QB86-K)R`]/B`D=&AI
M<RT^7W!A<F%M<ULG8V%L;&)A8VLG72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;F]F;VQL;W<G(#T^("1T:&ES+3Y?<&%R
M86US6R=N;V9O;&QO=R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C87!I=&%L)R`]/B!T<G5E*2D["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7W!A<F%M<ULG<&%R<V5L979E;"==(#P@5$585%](5$U,
M7TU)0U)/7TQ)3DM54DPI('L*("`@("`@("`@("`@("`@("1F:6QT97)?87)R
M87E;72`]("=E;6%I;',G.PH@("`@("`@("`@("`@("`@)&9I;'1E<E]P87)A
M;7-;72`](&%R<F%Y*"=C87!I=&%L7W1A9W,G(#T^('1R=64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T97AT(#T@5&5X=%]&:6QT97(Z.F9I;'1E
M<B@D=&5X="P@)&9I;'1E<E]A<G)A>2P@)&9I;'1E<E]P87)A;7,I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@1F]R(&QE=F5L(%1%6%1?2%1-3%]-24-23RP@
M5$585%](5$U,7TY/2%1-3"P@<W1A<G0@=VET:`H@("`@("`@("`J(&AT;6QS
M<&5C:6%L8VAA<G,H*2X@*B\*("`@("`@("`D=&5X="`]($!H=&UL<W!E8VEA
M;&-H87)S*"1T97AT+"!%3E1?0T]-4$%4+"`D=&AI<RT^7W!A<F%M<ULG8VAA
M<G-E="==*3L*"B`@("`@("`@+RH@1&\@:6XM;&EN:6YG(&]F(&AT='`Z+R]X
M>'@N>'AX('1O(&QI;FLL('AX>$!X>'@N>'AX('1O(&5M86EL+"!P87)T"B`@
M("`@("`@("H@='=O+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG
M<&%R<V5L979E;"==(#P@5$585%](5$U,7TY/2%1-3"D@>PH@("`@("`@("`@
M("`D<WEN=&%X(#T@87)R87DH"B`@("`@("`@("`@("`@("`G)FQT.T$@:')E
M9CTF<75O=#LG(#T^("<\82<@+B`H96UP='DH)'1H:7,M/E]P87)A;7-;)V-L
M87-S)UTI(#\@)R<@.B`G(&-L87-S/2(G("X@)'1H:7,M/E]P87)A;7-;)V-L
M87-S)UT@+B`G(B<I("X@)R!H<F5F/2(G+`H@("`@("`@("`@("`@("`@)R9Q
M=6]T.R!R96P])G%U;W0[)R`]/B`G(B!R96P](B<L"B`@("`@("`@("`@("`@
M("`G)G%U;W0[('1I=&QE/29Q=6]T.R<@/3X@)R(@=&ET;&4](B<L"B`@("`@
M("`@("`@("`@("`G)G%U;W0[('1A<F=E=#TF<75O=#M?8FQA;FLF<75O=#LF
M9W0[)R`@/3X@)R(@=&%R9V5T/2)?8FQA;FLB/B<L"B`@("`@("`@("`@("`@
M("`G)G%U;W0[(&]N8VQI8VL])G%U;W0[)R`]/B`G(B!O;F-L:6-K/2(G+`H@
M("`@("`@("`@("`@("`@)UPG*3LF<75O=#LF9W0[)R`]/B`G7"<I.R(^)RP*
M("`@("`@("`@("`@("`@("<F<75O=#LF9W0[)R`]/B`@)R(^)RP*("`@("`@
M("`@("`@("`@("\J($]N;'D@<F5C;VYV97)T(&-A<&ET86P@+T$@=&%G<R`M
M('1H92!O;F5S('=E(&=E;F5R871E9"X@*B\*("`@("`@("`@("`@("`@("<F
M;'0[+T$F9W0[)R`]/B`G/"]A/B<*("`@("`@("`@("`@("`@("D["@H@("`@
M("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*&%R<F%Y7VME>7,H)'-Y;G1A
M>"DL("1S>6YT87@L("1T97AT*3L*("`@("`@("`@("`@)'1E>'0@/2!497AT
M7T9I;'1E<CHZ9FEL=&5R*"1T97AT+"`G<W!A8V4R:'1M;"<I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@1&\@=&AE(&)L86YK+6QI;F4@+2TM/B`\8G(@+SX@
M<W5B<W1I='5T:6]N+B`@179E<GEB;V1Y(&=E=',@=&AI<SL*("`@("`@("`@
M*B!I9B!Y;W4@9&]N)W0@=V%N="!E=F5N('1H870L(&IU<W0@<V%V92!T:&4@
M:'1M;'-P96-I86QC:&%R<R@I"B`@("`@("`@("H@=F5R<VEO;B!O9B!T:&4@
M:6YP=70N("HO"B`@("`@("`@)'1E>'0@/2!N;#)B<B@D=&5X="D["@H@("`@
M("`@(')E='5R;B`D=&5X=#L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&
M:6QT97(O=V]R9',N<&AP````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S
M,3$Q`#$P-#$W,S8R-S<S`#`R,C(T-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@1FEL=&5R<R!T:&4@
M9VEV96X@=&5X="!B87-E9"!O;B!T:&4@=V]R9',@9F]U;F0@:6X@82!W;W)D
M(&QI<W0*("H@9FEL92X*("H*("H@4&%R86UE=&5R<SH*("H@/'!R93X*("H@
M=V]R9'-?9FEL92`@+2T@1FEL96YA;64@8V]N=&%I;FEN9R!T:&4@=V]R9',@
M=&\@<F5P;&%C92X*("H@<F5P;&%C96UE;G0@+2T@5&AE(')E<&QA8V5M96YT
M('-T<FEN9RX@($1E9F%U;'1S('1O("(J*BHJ*B(N"B`J(#PO<')E/@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O=V]R9',N
M<&AP+'8@,2XR+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R
M7W=O<F1S(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@
M1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G<F5P;&%C96UE;G0G
M(#T^("<J*BHJ*B<I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@
M=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A='1E<FYS*"D*("`@('L*("`@("`@("`D<F5G97AP(#T@87)R87DH*3L*
M"B`@("`@("`@:68@*$!I<U]R96%D86)L92@D=&AI<RT^7W!A<F%M<ULG=V]R
M9'-?9FEL92==*2D@>PH@("`@("`@("`@("`O*B!296%D('1H92!F:6QE(&%N
M9"!I=&5R871E('1H<F]U9V@@=&AE(&QI;F5S+B`J+PH@("`@("`@("`@("`D
M;&EN97,@/2!F:6QE*"1T:&ES+3Y?<&%R86US6R=W;W)D<U]F:6QE)UTI.PH@
M("`@("`@("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@
M("`@("`@("`@("\J(%-T<FEP('=H:71E<W!A8V4@86YD(&-O;6UE;G1S+B`J
M+PH@("`@("`@("`@("`@("`@)&QI;F4@/2!T<FEM*"1L:6YE*3L*("`@("`@
M("`@("`@("`@("1L:6YE(#T@<')E9U]R97!L86-E*"=\(RXJ)'PG+"`G)RP@
M)&QI;F4I.PH*("`@("`@("`@("`@("`@("\J($9I;'1E<B!T:&4@=&5X="X@
M*B\*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&QI;F4I*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E9V5X<%LB+RA<8BA<=RHI)&QI;F5<8GQ<8B1L
M:6YE*%QW*BE<8BDO:2)=(#T@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V5M96YT
M)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+WAS<RYP:'``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S8R-0`Q
M,#0Q-S,V,C<W,P`P,C$W-#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL=&5R(&%T=&5M
M<'1S('1O(&UA:V4@2%1-3"!S869E(&9O<B!V:65W:6YG+B!)5"!)4R!.3U0@
M4$521D5#5"X@268*("H@>6]U(&5N86)L92!(5$U,('9I97=I;F<L('EO=2!A
M<F4@;W!E;FEN9R!A('-E8W5R:71Y(&AO;&4N(%=I=&@@=&AE(&-U<G)E;G0*
M("H@<W1A=&4@;V8@=&AE('=E8BP@22!B96QI979E('1H870@=&AE(&)E<W0@
M=V4@8V%N(&1O(&ES('1O(&UA:V4@<W5R92!T:&%T"B`J('!E;W!L92`J2TY/
M5RH@2%1-3"!I<R!A('-E8W5R:71Y(&AO;&4L(&-L96%N('5P('=H870@=V4@
M8V%N+"!A;F0@;&5A=F4@:70*("H@870@=&AA="X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+WAS<RYP:'`L=B`Q+C$N,BXS
M(#(P,#8O,#(O,#D@,38Z-#`Z-#$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(
M;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]X<W,@97AT96YD<R!4
M97AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R
M<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W!A<F%M<R`](&%R<F%Y*"=B;V1Y7V]N;'DG(#T^('1R=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5P;&%C92<@/3X@)UA34T-L96%N960G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)W-T<FEP7W-T>6QE<R<@/3X@=')U
M92D["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA
M8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T
M=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H
M*0H@("`@>PH@("`@("`@("1P871T97)N<R`](&%R<F%Y*"D["@H@("`@("`@
M("\J(%)E;6]V97,@2%1-3"!C;VUM96YT<R`H:6YC;'5D:6YG('-O;64@<V-R
M:7!T<R`F('-T>6QE<RDN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US
M6R=S=')I<%]S='EL97,G72D@>PH@("`@("`@("`@("`D<&%T=&5R;G-;)R\\
M(2TM+BH_+2T^+W,G72`]("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAA
M;F=E('-P86-E(&5N=&ET:65S('1O('-P86-E(&-H87)A8W1E<G,N("HO"B`@
M("`@("`@)'!A='1E<FYS6R<O)B,H>#`J,C!\,"HS,BD[/R]I)UT@/2`G("<[
M"@H@("`@("`@("\J($YU:V4@;F]N+7!R:6YT86)L92!C:&%R86-T97)S("AA
M('!L87D@:6X@=&AR964@86-T<RDN("HO"@H@("`@("`@("\J(%)U;&4@,2DN
M(%)E;6]V92!A;&P@8V]N=')O;"!C:&%R86-T97)S+B`J+PH@("`@("`@("\O
M)&1A=&$@/2!P<F5G7W)E<&QA8V4H)R];7'@P,"U<>#`X7'@P92U<>#%F72\G
M+"`G)RP@)&1A=&$I.PH*("`@("`@("`O*B!2=6QE(#$I+B!)9B!W92!H879E
M(&$@<V5M:6-O;&]N+"!I="!I<R!D971E<FUI;FES=&EC86QL>2!D971E8W1A
M8FQE"B`@("`@("`@("H@86YD(&9I>&%B;&4L('=I=&AO=70@:6YT<F]D=6-I
M;F<@8V]L;&%T97)A;"!D86UA9V4N("HO"B`@("`@("`@)'!A='1E<FYS6R<O
M)B-X/S`J*%LY02U$77PQ6S`M,UTI.R]I)UT@/2`G)FYB<W`[)SL*"B`@("`@
M("`@+RH@4G5L92`R*2X@2&5X(&YU;6)E<G,@*'5S=6%L;'D@:&%V:6YG(&%N
M('@@<')E9FEX*2!A<F4@86QS;PH@("`@("`@("`J(&1E=&5R;6EN:7-T:6,L
M(&5V96X@:68@=V4@9&]N)W0@:&%V92!T:&4@<V5M:2X@3F]T92!T:&%T('-O
M;64*("`@("`@("`@*B!B<F]W<V5R<R!W:6QL('1R96%T("8C82!O<B`F(S!A
M(&%S(&$@:&5X(&YU;6)E<B!E=F5N('=I=&AO=70@=&AE('@*("`@("`@("`@
M*B!P<F5F:7@[(&AE;F-E("]X/R\@=VAI8V@@=VEL;"!C;W9E<B!T:&]S92!C
M87-E<R!I;B!T:&ES(')U;&4N("HO"B`@("`@("`@)'!A='1E<FYS6R<O)B-X
M/S`J6SE!+41=*%M>,"TY02U&77PD*2]I)UT@/2`G)FYB<W!<7#$G.PH*("`@
M("`@("`O*B!2=6QE(#,I+B!$96-I;6%L(&YU;6)E<G,@=VET:&]U="!T<F%I
M;&EN9R!S96UI8V]L;VYS+B!4:&4@<')O8FQE;0H@("`@("`@("`J(&ES('1H
M870@<V]M92!B<F]W<V5R<R!W:6QL(&EN=&5R<')E="`F(S$P82!A<R`B7&YA
M(BP@<V]M92!A<PH@("`@("`@("`J("(F(W@Q,&$B('-O('=E(&AA=F4@=&\@
M8VQE86X@=&AE("8C,3`@=&\@8F4@<V%F92!F;W(@=&AE(")<;F$B(&-A<V4*
M("`@("`@("`@*B!A="!T:&4@97AP96YS92!O9B!M86YG;&EN9R!A('9A;&ED
M(&5N=&ET>2!I;B!O=&AE<B!C87-E<RX@*%-O;'5T:6]N"B`@("`@("`@("H@
M9F]R('9A;&ED($A434P@875T:&]R<SH@86QW87ES('5S92!T:&4@<V5M:6-O
M;&]N+BD@*B\*("`@("`@("`D<&%T=&5R;G-;)R\F(S`J*#E\,5LP+3-=*2A;
M7C`M.5U\)"DO:2==(#T@)R9N8G-P7%PR)SL*"B`@("`@("`@+RH@4F5M;W9E
M(&]V97)L>2!L;VYG(&YU;65R:6,@96YT:71I97,N("HO"B`@("`@("`@)'!A
M='1E<FYS6R<O)B-X/S`J6S`M.4$M1EU[-BQ].S\O:2==(#T@)R9N8G-P.R<[
M"@H@("`@("`@("\J(%)E;6]V92!E=F5R>71H:6YG(&]U='-I9&4@;V8@86YD
M(&EN8VQU9&EN9R!T:&4@/&)O9'D^('1A9RX@*B\*("`@("`@("!I9B`H)'1H
M:7,M/E]P87)A;7-;)V)O9'E?;VYL>2==*2!["B`@("`@("`@("`@("1P871T
M97)N<ULG+RXJ/&)O9'E;7CY=*CXO<VDG72`]("<G.PH@("`@("`@("`@("`D
M<&%T=&5R;G-;)R\\7"]B;V1Y/BXJ+W-I)UT@/2`G)SL*("`@("`@("!]"@H@
M("`@("`@("\J($=E="!A;&P@871T<FEB=71E/2)J879A<V-R:7!T.F9O;R@I
M(B!T86=S+B!4:&ES(&ES(&5S<V5N=&EA;&QY('1H90H@("`@("`@("`J(')E
M9V5X("\H/7QU<FQ<*"DH(C\I6UX^72IS8W)I<'0Z+R!B=70@97AP86YD960@
M=&\@8V%T8V@@8V%M;W5F;&%G90H@("`@("`@("`J('=I=&@@<W!A8V5S(&%N
M9"!E;G1I=&EE<RX@*B\*("`@("`@("`D<')E9R`]("<O*"@F(S`J-C$[/WPF
M(W@P*C-$.S]\/2E\)R`N"B`@("`@("`@("`@("`@("`G*"AU?"8C,"HX-3L_
M?"8C>#`J-34[/WPF(S`J,3$W.S]\)B-X,"HW-3L_*5QS*B<@+@H@("`@("`@
M("`@("`@("`@)RAR?"8C,"HX,CL_?"8C>#`J-3([/WPF(S`J,3$T.S]\)B-X
M,"HW,CL_*5QS*B<@+@H@("`@("`@("`@("`@("`@)RAL?"8C,"HW-CL_?"8C
M>#`J-&,[/WPF(S`J,3`X.S]\)B-X,"HV8SL_*5QS*B<@+@H@("`@("`@("`@
M("`@("`@)RA<*"DI*5QS*B<@+@H@("`@("`@("`@("`@("`@)R@F(S`J,S0[
M/WPF(W@P*C(R.S]\(GPF(S`J,SD[/WPF(W@P*C(W.S]\7"<I/R<@+@H@("`@
M("`@("`@("`@("`@)UM>/ETJ7',J)R`N"B`@("`@("`@("`@("`@("`G*'-\
M)B,P*C@S.S]\)B-X,"HU,SL_?"8C,"HQ,34[/WPF(W@P*C<S.S\I7',J)R`N
M"B`@("`@("`@("`@("`@("`G*&-\)B,P*C8W.S]\)B-X,"HT,SL_?"8C,"HY
M.3L_?"8C>#`J-C,[/RE<<RHG("X*("`@("`@("`@("`@("`@("<H<GPF(S`J
M.#([/WPF(W@P*C4R.S]\)B,P*C$Q-#L_?"8C>#`J-S([/RE<<RHG("X*("`@
M("`@("`@("`@("`@("<H:7PF(S`J-S,[/WPF(W@P*C0Y.S]\)B,P*C$P-3L_
M?"8C>#`J-CD[/RE<<RHG("X*("`@("`@("`@("`@("`@("<H<'PF(S`J.#`[
M/WPF(W@P*C4P.S]\)B,P*C$Q,CL_?"8C>#`J-S`[/RE<<RHG("X*("`@("`@
M("`@("`@("`@("<H='PF(S`J.#0[/WPF(W@P*C4T.S]\)B,P*C$Q-CL_?"8C
M>#`J-S0[/RE<<RHG("X*("`@("`@("`@("`@("`@("<H.GPF(S`J-3@[/WPF
M(W@P*C-A.S\I+VDG.PH@("`@("`@("1P871T97)N<ULD<')E9UT@/2`G7#%<
M."<@+B`D=&AI<RT^7W!A<F%M<ULG<F5P;&%C92==.PH*("`@("`@("`O*B!'
M970@86QL(&]N/&9O;SX](F)A<B@I(BX@3D5615(@86QL;W<@=&AE<V4N("HO
M"B`@("`@("`@)'!A='1E<FYS6R<O*%M<<R)<)UTK)R`N"B`@("`@("`@("`@
M("`@("`@("<H;WPF(S`J-SD[/WPF(S`J-&8[/WPF(S`J,3$Q.S]\)B,P*C9F
M.S\I)R`N"B`@("`@("`@("`@("`@("`@("<H;GPF(S`J-S@[/WPF(S`J-&4[
M/WPF(S`J,3$P.S]\)B,P*C9E.S\I)R`N"B`@("`@("`@("`@("`@("`@("=<
M=RLI7',J/2]I)UT@/2`G7#$G("X@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V4G
M72`N("<])SL*"B`@("`@("`@+RH@4F5M;W9E(&%L;"!S8W)I<'1S('-I;F-E
M('1H97D@;6EG:'0@:6YT<F]D=6-E(&=A<F)A9V4@:68@=&AE>2!A<F4*("`@
M("`@("`@*B!N;W0@<75O=&5D('!R;W!E<FQY+B`J+PH@("`@("`@("1P871T
M97)N<ULG?#QS8W)I<'1;7CY=*CXN*C\\+W-C<FEP=#Y\:7,G72`]("<\)R`N
M("1T:&ES+3Y?<&%R86US6R=R97!L86-E)UT@+B`G7W-C<FEP="`O/B<["@H@
M("`@("`@("\J($=E="!A;&P@=&%G<R!T:&%T(&UI9VAT(&-A=7-E('1R;W5B
M;&4@+2`\;V)J96-T/BP@/&5M8F5D/BP@/&)A<V4^+`H@("`@("`@("`J(&5T
M8RX@365T82!R969R97-H97,@86YD(&EF<F%M97,L('1O;RX@*B\*("`@("`@
M("`D;6%L:6-I;W5S(#T@87)R87DH"B`@("`@("`@("`@("<O/"A;7CYA+7I=
M*BDG("X*("`@("`@("`@("`@)RAS?"8C,"HX,SL_?"8C>#`J-3,[/WPF(S`J
M,3$U.S]\)B-X,"HW,SL_*5QS*B<@+@H@("`@("`@("`@("`G*&-\)B,P*C8W
M.S]\)B-X,"HT,SL_?"8C,"HY.3L_?"8C>#`J-C,[/RE<<RHG("X*("`@("`@
M("`@("`@)RAR?"8C,"HX,CL_?"8C>#`J-3([/WPF(S`J,3$T.S]\)B-X,"HW
M,CL_*5QS*B<@+@H@("`@("`@("`@("`G*&E\)B,P*C<S.S]\)B-X,"HT.3L_
M?"8C,"HQ,#4[/WPF(W@P*C8Y.S\I7',J)R`N"B`@("`@("`@("`@("<H<'PF
M(S`J.#`[/WPF(W@P*C4P.S]\)B,P*C$Q,CL_?"8C>#`J-S`[/RE<<RHG("X*
M("`@("`@("`@("`@)RAT?"8C,"HX-#L_?"8C>#`J-30[/WPF(S`J,3$V.S]\
M)B-X,"HW-#L_*5QS*B]I)RP*"B`@("`@("`@("`@("<O/"A;7CYA+7I=*BDG
M("X*("`@("`@("`@("`@)RAE?"8C,"HV.3L_?"8C,"HT-3L_?"8C,"HQ,#$[
M/WPF(S`J-C4[/RE<<RHG("X*("`@("`@("`@("`@)RAM?"8C,"HW-SL_?"8C
M,"HT9#L_?"8C,"HQ,#D[/WPF(S`J-F0[/RE<<RHG("X*("`@("`@("`@("`@
M)RAB?"8C,"HV-CL_?"8C,"HT,CL_?"8C,"HY.#L_?"8C,"HV,CL_*5QS*B<@
M+@H@("`@("`@("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P*C$P,3L_
M?"8C,"HV-3L_*5QS*B<@+@H@("`@("`@("`@("`G*&1\)B,P*C8X.S]\)B,P
M*C0T.S]\)B,P*C$P,#L_?"8C,"HV-#L_*5QS*B]I)RP*"B`@("`@("`@("`@
M("<O/"A;7CYA+7I=*BDG("X*("`@("`@("`@("`@)RAX?"8C,"HX.#L_?"8C
M,"HU.#L_?"8C,"HQ,C`[/WPF(S`J-S@[/RE<<RHG("X*("`@("`@("`@("`@
M)RAM?"8C,"HW-SL_?"8C,"HT9#L_?"8C,"HQ,#D[/WPF(S`J-F0[/RE<<RHG
M("X*("`@("`@("`@("`@)RAL?"8C,"HW-CL_?"8C>#`J-&,[/WPF(S`J,3`X
M.S]\)B-X,"HV8SL_*5QS*B]I)RP*"B`@("`@("`@("`@("<O/"A;7CYA+7I=
M*BDG("X*("`@("`@("`@("`@)RAB?"8C,"HV-CL_?"8C,"HT,CL_?"8C,"HY
M.#L_?"8C,"HV,CL_*5QS*B<@+@H@("`@("`@("`@("`G*&%\)B,P*C8U.S]\
M)B,P*C0Q.S]\)B,P*CDW.S]\)B,P*C8Q.S\I7',J)R`N"B`@("`@("`@("`@
M("<H<WPF(S`J.#,[/WPF(W@P*C4S.S]\)B,P*C$Q-3L_?"8C>#`J-S,[/RE<
M<RHG("X*("`@("`@("`@("`@)RAE?"8C,"HV.3L_?"8C,"HT-3L_?"8C,"HQ
M,#$[/WPF(S`J-C4[/RE<<RHG("X*("`@("`@("`@("`@)UM>;&EN95TO:2<L
M"@H@("`@("`@("`@("`G+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H
M;7PF(S`J-S<[/WPF(S`J-&0[/WPF(S`J,3`Y.S]\)B,P*C9D.S\I7',J)R`N
M"B`@("`@("`@("`@("<H97PF(S`J-CD[/WPF(S`J-#4[/WPF(S`J,3`Q.S]\
M)B,P*C8U.S\I7',J)R`N"B`@("`@("`@("`@("<H='PF(S`J.#0[/WPF(W@P
M*C4T.S]\)B,P*C$Q-CL_?"8C>#`J-S0[/RE<<RHG("X*("`@("`@("`@("`@
M)RAA?"8C,"HV-3L_?"8C,"HT,3L_?"8C,"HY-SL_?"8C,"HV,3L_*5QS*B]I
M)RP*"B`@("`@("`@("`@("<O/"A;7CYA+7I=*BDG("X*("`@("`@("`@("`@
M)RAJ?"8C,"HW-#L_?"8C,"HT83L_?"8C,"HQ,#8[/WPF(S`J-F$[/RE<<RHG
M("X*("`@("`@("`@("`@)RAA?"8C,"HV-3L_?"8C,"HT,3L_?"8C,"HY-SL_
M?"8C,"HV,3L_*5QS*B<@+@H@("`@("`@("`@("`G*'9\)B,P*C@V.S]\)B,P
M*C4V.S]\)B,P*C$Q.#L_?"8C,"HW-CL_*5QS*B<@+@H@("`@("`@("`@("`G
M*&%\)B,P*C8U.S]\)B,P*C0Q.S]\)B,P*CDW.S]\)B,P*C8Q.S\I7',J+VDG
M+`H*("`@("`@("`@("`@)R\\*%M>/F$M>ETJ*2<@+@H@("`@("`@("`@("`G
M*&]\)B,P*C<Y.S]\)B,P*C1F.S]\)B,P*C$Q,3L_?"8C,"HV9CL_*5QS*B<@
M+@H@("`@("`@("`@("`G*&)\)B,P*C8V.S]\)B,P*C0R.S]\)B,P*CDX.S]\
M)B,P*C8R.S\I7',J)R`N"B`@("`@("`@("`@("<H:GPF(S`J-S0[/WPF(S`J
M-&$[/WPF(S`J,3`V.S]\)B,P*C9A.S\I7',J)R`N"B`@("`@("`@("`@("<H
M97PF(S`J-CD[/WPF(S`J-#4[/WPF(S`J,3`Q.S]\)B,P*C8U.S\I7',J)R`N
M"B`@("`@("`@("`@("<H8WPF(S`J-C<[/WPF(W@P*C0S.S]\)B,P*CDY.S]\
M)B-X,"HV,SL_*5QS*B<@+@H@("`@("`@("`@("`G*'1\)B,P*C@T.S]\)B-X
M,"HU-#L_?"8C,"HQ,38[/WPF(W@P*C<T.S\I7',J+VDG+`H*("`@("`@("`@
M("`@)R\\*%M>/F$M>ETJ*2<@+@H@("`@("`@("`@("`G*&E\)B,P*C<S.S]\
M)B-X,"HT.3L_?"8C,"HQ,#4[/WPF(W@P*C8Y.S\I7',J)R`N"B`@("`@("`@
M("`@("<H9GPF(S`J-S`[/WPF(S`J-#8[/WPF(S`J,3`R.S]\)B,P*C8V.S\I
M7',J)R`N"B`@("`@("`@("`@("<H<GPF(S`J.#([/WPF(W@P*C4R.S]\)B,P
M*C$Q-#L_?"8C>#`J-S([/RE<<RHG("X*("`@("`@("`@("`@)RAA?"8C,"HV
M-3L_?"8C,"HT,3L_?"8C,"HY-SL_?"8C,"HV,3L_*5QS*B<@+@H@("`@("`@
M("`@("`G*&U\)B,P*C<W.S]\)B,P*C1D.S]\)B,P*C$P.3L_?"8C,"HV9#L_
M*5QS*B<@+@H@("`@("`@("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P
M*C$P,3L_?"8C,"HV-3L_*5QS*B]I)RD["@H@("`@("`@(&9O<F5A8V@@*"1M
M86QI8VEO=7,@87,@)'!A='1E<FXI('L*("`@("`@("`@("`@)'!A='1E<FYS
M6R1P871T97)N72`]("<\)R`N("1T:&ES+3Y?<&%R86US6R=R97!L86-E)UT@
M+B`G7W1A9R<["B`@("`@("`@?0H*("`@("`@("`O*B!#;VUM96YT(&]U="!S
M='EL92]L:6YK('1A9W,N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US
M6R=S=')I<%]S='EL97,G72D@>PH@("`@("`@("`@("`D<&%T=&5R;G-;)R]<
M<RMS='EL95QS*CTO:2==(#T@)R`G("X@)'1H:7,M/E]P87)A;7-;)W)E<&QA
M8V4G72`N("<])SL*("`@("`@("`@("`@)'!A='1E<FYS6R=\/'-T>6QE6UX^
M72H^*#\Z7',J/%PA+2TI*GQI)UT@/2`G/"$M+2<["B`@("`@("`@("`@("1P
M871T97)N<ULG?"@_.BTM/EQS*BDJ/"]S='EL93Y\:2==(#T@)RTM/B<["B`@
M("`@("`@("`@("1P871T97)N<ULG?"@\;&EN:UM>/ETJ/BE\:2==(#T@)SPA
M+2T@)#$@+2T^)SL*("`@("`@("!]"@H@("`@("`@("\J($$@9F5W(&]T:&5R
M(&UA=&-H97,N("HO"B`@("`@("`@)'!A='1E<FYS6R=\/"A;7CY=*BDF>RXJ
M?2A;7CY=*BD^?"==(#T@)SPF>SM]7#,^)SL*("`@("`@("`D<&%T=&5R;G-;
M)WP\*%M>/ETJ*6UO8VAA.BA;7CY=*BD^?&DG72`]("<\7#$G("X@)'1H:7,M
M/E]P87)A;7-;)W)E<&QA8V4G72`N("<Z7#(^)SL*("`@("`@("`D<&%T=&5R
M;G-;)WP\*%M>/ETJ*6)I;F1I;F<Z*%M>/ETJ*3Y\:2==(#T@)SQ<,2<@+B`D
M=&AI<RT^7W!A<F%M<ULG<F5P;&%C92==("X@)SI<,CXG.PH*("`@("`@("!R
M971U<FX@87)R87DH)W)E9V5X<"<@/3X@)'!A='1E<FYS*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]497AT+W1E<W1S+P``````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S,`,#(P,S(S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+G!H<```````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#4P-``Q,#0Q-S,V,C<W
M,P`P,C$Q,C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*9&5F:6YE
M*"=415A47TA434Q?4$%34U1(4E4G+"`P*3L*9&5F:6YE*"=415A47TA434Q?
M4UE.5$%8)RP@,2D["F1E9FEN92@G5$585%](5$U,7TU)0U)/)RP@,BD["F1E
M9FEN92@G5$585%](5$U,7TU)0U)/7TQ)3DM54DPG+"`S*3L*9&5F:6YE*"=4
M15A47TA434Q?3D](5$U,)RP@-"D["F1E9FEN92@G5$585%](5$U,7TY/2%1-
M3%].3T)214%+)RP@-2D["@HO*BH*("H@5&5X=%]&:6QT97(Z.B!I<R!A('!A
M<F5N="!C;&%S<R!F;W(@9&5F:6YI;F<@<W1A8VMA8FQE('1E>'0@9FEL=&5R
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+G!H<"QV(#$N,34N,BXW(#(P,#8O,#$O,#$@,C$Z,C@Z,S<@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA
M<W,@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL=&5R('!A<F%M
M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N
M>2!P87)A;65T97)S('1H870@=&AE(&9I;'1E<B!I;G-T86YC92!N965D<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]&:6QT97(H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M
M97)G92@D=&AI<RT^7W!A<F%M<RP@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!<'!L:65S(&$@<V5T(&]F('!A='1E<FYS('1O(&$@8FQO8VL@
M;V8@=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@
M("!4:&4@=&5X="!T;R!F:6QT97(N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M='1E<FYS("!4:&4@87)R87D@;V8@<&%T=&5R;G,@=&\@9FEL=&5R('=I=&@N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T<F%N<V9O<FUE
M9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QT97(H)'1E>'0L("1F
M:6QT97)S(#T@87)R87DH*2P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D9FEL=&5R<RDI('L*("`@("`@("`@("`@
M)&9I;'1E<G,@/2!A<G)A>2@D9FEL=&5R<RD["B`@("`@("`@("`@("1P87)A
M;7,@/2!A<G)A>2@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1F:6QT97)S(&%S("1N=6T@/3X@)&9I;'1E<BD@>PH@("`@("`@("`@
M("`D9FEL=&5R3V(@/2`F5&5X=%]&:6QT97(Z.G-I;F=L971O;B@D9FEL=&5R
M+"`D<&%R86US6R1N=6U=*3L*("`@("`@("`@("`@:68@*&ES7V$H)&9I;'1E
M<D]B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&9I;'1E<D]B+3YG971-97-S86=E*"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'!A='1E<FYS(#T@)&9I;'1E<D]B+3YG9710871T97)N<R@I.PH*
M("`@("`@("`@("`@+RH@4')E+7!R;V-E<W-I;F<N("HO"B`@("`@("`@("`@
M("1T97AT(#T@)&9I;'1E<D]B+3YP<F50<F]C97-S*"1T97AT*3L*"B`@("`@
M("`@("`@("\J('-T<E]R97!L86-E*"D@<VEM<&QE('!A='1E<FYS+B`J+PH@
M("`@("`@("`@("!I9B`H:7-S970H)'!A='1E<FYS6R=R97!L86-E)UTI*2![
M"B`@("`@("`@("`@("`@("`D9G)O;2`](&%R<F%Y7VME>7,H)'!A='1E<FYS
M6R=R97!L86-E)UTI.PH@("`@("`@("`@("`@("`@)'1O(#T@87)R87E?=F%L
M=65S*"1P871T97)N<ULG<F5P;&%C92==*3L*("`@("`@("`@("`@("`@("1T
M97AT(#T@<W1R7W)E<&QA8V4H)&9R;VTL("1T;RP@)'1E>'0I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O*B!P<F5G7W)E<&QA8V4@8V]M<&QE>"!P
M871T97)N<RX@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1P871T97)N<ULG
M<F5G97AP)UTI*2!["B`@("`@("`@("`@("`@("`D9G)O;2`](&%R<F%Y7VME
M>7,H)'!A='1E<FYS6R=R96=E>'`G72D["B`@("`@("`@("`@("`@("`D=&\@
M/2!A<G)A>5]V86QU97,H)'!A='1E<FYS6R=R96=E>'`G72D["B`@("`@("`@
M("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@D9G)O;2P@)'1O+"`D=&5X
M="D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%!O<W0M<')O8V5S
M<VEN9RX@*B\*("`@("`@("`@("`@)'1E>'0@/2`D9FEL=&5R3V(M/G!O<W10
M<F]C97-S*"1T97AT*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE
M8V5S<V%R87D@8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(*("`@("`J('!A
M='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H
M92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("!R971U
M<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S
M:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S
M87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL=&5R"B`@("`@*B!P871T97)N
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X
M="!A9G1E<B!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<&]S=%!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@8V]N8W)E=&4@5&5X=%]F:6QT97(@:6YS=&%N8V4@8F%S960@;VX*("`@
M("`J("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV
M97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%1E>'1?1FEL=&5R('-U8F-L87-S
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B!4:&ES
M(&ES(&)A<V5D(&]N('1H92!F:6QT97(@9')I=F5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@*"1D<FEV97(I+B!4:&4@8V]D92!I<R!D>6YA;6EC
M86QL>2!I;F-L=61E9"X@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`D9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:R!I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("1D<FEV97);,%T@9F]R('1H
M92!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%1E>'1?1FEL=&5R("!4:&4@;F5W;'D@8W)E871E9"!C
M;VYC<F5T92!497AT7T9I;'1E<B!I;G-T86YC92P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@
M("`@("`@("`@;&ES="@D9&ER+"`D9')I=F5R*2`]("1D<FEV97(["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1D:7(I*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`D9&ER("X@)R\G("X@)&1R:79E<B`N("<N<&AP)SL*
M("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]&:6QT97(O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O1FEL
M=&5R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S
M(#T@)U1E>'1?1FEL=&5R7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D9FEL=&5R(#T@)FYE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&9I;'1E<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I
M;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1F:6QT97(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T
M92!497AT7T9I;'1E<@H@("`@("H@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E
M<BX@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC90H@("`@("H@
M:68@;F\@5&5X=%]&:6QT97(@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A
M;65T97)S(&-U<G)E;G1L>0H@("`@("H@97AI<W1S+@H@("`@("H*("`@("`J
M(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@='EP97,@;V8@=&5X
M="!F:6QT97)S("AA;F0L"B`@("`@*B!T:'5S+"!M=6QT:7!L92!497AT7T9I
M;'1E<B!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4
M:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1F:6QT97(@/2`F5&5X
M=%]&:6QT97(Z.G-I;F=L971O;B@I.PH@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!497AT7T9I;'1E
M<B!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;BX@5&AI<R!I<R!B87-E9"!O;B!T:&4@9FEL=&5R(&1R:79E<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("@D9')I=F5R*2X@5&AE(&-O9&4@
M:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL
M(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R
M6S!=(&9O<B!T:&4@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S%=+G!H<"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!497AT7T9I;'1E<B`@5&AE(&-O;F-R
M971E(%1E>'1?1FEL=&5R(')E9F5R96YC92P@;W(@9F%L<V4@;VX@86X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@("`@("`@(&EF
M("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E
M<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@
M<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I
M9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@
M("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F5&5X=%]&:6QT97(Z.F9A
M8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+P``
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C(W-S,`,#$V-S8T`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+P``````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W,P`P,C`R,C4`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+P``
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S<S`#`R,3`R,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M24U%+U9I97=E<B]O;V\O8V]M;6]N+GAS;```````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`Q-C<P-S,`,3`T,3<S-C(W-S,`,#(S,#4T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#PA+2T*"B`@(%1H92!#;VYT96YT
M<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@
M=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N
M<V5S"@H@("`@("`@("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI
M8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T
M86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI
M8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R
M($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O
M<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q
M(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*
M("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D
M:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E
M<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N
M<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T
M=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U
M=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U
M="!7251(3U54($%.62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L
M:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3
M($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE
M<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N
M"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET
M:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F
M='=A<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3
M=6ET92`S,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@
M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO
M;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R
M92!S=6)J96-T('1O('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O
M=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U
M(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC
M92!W:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@
M=&AE"B`@($QI8V5N<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L
M:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES
M($QI8V5N<V4@:7,@<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@
M5TE42$]55"!705)204Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@
M3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL
M(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%
M0U13+`H@("!-15)#2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!5
M4E!/4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@
M9F]R('1H92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I
M9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A
M<F4N"@H@("!4:&4@26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L
M($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H
M="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2
M:6=H=',@4F5S97)V960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL
M97-H965T('9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS
M;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@
M("`@("!X;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T
M97AT(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M9')A=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@
M("`@("`@("`@("`@('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY
M+UA33"]&;W)M870B"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T
M<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM
M;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T
M>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S
M+F]R9R\R,#`P+W-V9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@
M("`@('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R
M,V0B"B`@("`@("`@("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S
M+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@
M("`@("`@("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O<V-R:7!T(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T
M97AT(@H@("`@("`@("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@
M("`@("`@("`@("`@('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE
M;65N=',O,2XQ+R(*("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X
M;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I
M9R(*("`@("`@("`@("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB
M:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@97AT
M96YS:6]N+65L96UE;G0M<')E9FEX97,](GAT(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@
M("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R
M9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP
M<F5F:7AE<STB:F%V82(^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*B`M+3X*
M("`@(#PA+2T@*BHJ(&)O9'D@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BH@+2T^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](B\J+V]F9FEC93IB
M;V1Y(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*"B`@("`@("`@/"$M+2!I<T1E8G5G36]D92U35$%25#H@;VYL
M>2!I<T1E8G5G36]D92!P=7)P;W-E.B!S:&]W<R!T:&4@:6YL:6YE9"!S='EL
M92!A='1R:6)U=&5S(&]F('1H92!T96UP;W)A<GD@=F%R:6%B;&4@+2T^"B`@
M("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4@86YD(&YO="@D;W5T
M<'5T5'EP92`]("=#4U-?2$5!1$52)RDB/@H@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB9&5B=6=?=')E95]O9E]S='EL97,B/CQX<VPZ=&5X=#X*
M("`@("`@("`@("`@/"]X<VPZ=&5X=#X\>'-L.F9O<BUE86-H('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL<W1Y;&5S+RHB/@H\>'-L.G1E>'0^
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G1E>'0^/'AS;#IV86QU92UO
M9B!S96QE8W0](FYA;64H*2(O/CQX<VPZ=&5X=#X@/2`\+WAS;#IT97AT/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/@H@("`@("`@("`@
M("`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE
M86-H/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO>'-L
M.FEF/@H@("`@/"$M+2!I<T1E8G5G36]D92U%3D0@+2T^"@H*"0D\(2TM(&YO
M="!U<VEN9R!O9B`G87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT)R!A<R!T:&4@
M8V]N=&5N="!T86)L92!I;F9O<FUA=&EO;B!M:6=T:"!H879E(&)E96X@861D
M960@=&\@)V-O;&QE8W1E9$=L;V)A;$1A=&$G('9A<FEA8FQE("TM/@H@("`@
M("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB0'1E>'0Z<W1Y;&4M
M;F%M92!\($!D<F%W.G-T>6QE+6YA;64@?"!`9')A=SIT97AT+7-T>6QE+6YA
M;64@?"!`=&%B;&4Z<W1Y;&4M;F%M92(^/"$M+2!\($!P<F5S96YT871I;VXZ
M<W1Y;&4M;F%M92`M+3X*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H*
M("`@("`@("`\(2TM(%5S86)I;&ET>2!F96%T=7)E+"!A(&QI;FL@=&\@=&AE
M($-O;G1E;G0@=&%L8F4@86)O=F4@86QL(&QE=F5L(#$@:&5A9&5R("TM/@H@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&-O;G1E;G1486)L94AE861I;F=S(CX*
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9"UC:&EL
M9"UD;V-U;65N="UU<V%B:6QI='DM;&EN:W,B+SX*("`@("`@("`\+WAS;#II
M9CX*"@H)"3QX<VPZ8VAO;W-E/@H)("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M;F]T*"1O=71P=714>7!E(#T@)U=-3"<I(&%N9"!N;W0H)&]U='!U=%1Y<&4@
M/2`G4$%,32<I(CX*"2`@("`@("`@"3QX<VPZ8VAO;W-E/@H)"0D@("`@("`@
M(#PA+2U)9B!T:&4@:6YP=70@9&]C=6UE;G0@:7,@82!G;&]B86P@9&]C=6UE
M;G0@86YD(&5M8F5D(&-H:6QD(&1O8W5M96YT<R`H;&EN:W,I('1H92!T<F%N
M<V9O<FUA=&EO;B!O9B!T:&4@8VAI;&1R96X@=VEL;"!B92!S=&%R=&5D(&%S
M('=E;&PN"@D)"2`@("`@("`@("`@(%1H:7,@:7,@;F5C97-S87)Y(&%S(&-H
M:6QD(&1O8W5M96YT<R!D;R!N;W0@:VYO=R!A;GET:&EN9R!A8F]U="!T:&5I
M<B!E;6)E9&1I;F<@:6YT;R!A(&=L;V)A;"!D;V-U;65N="X@0VAA<'1E<G,@
M;V8@8VAI;&1S"@D)"2`@("`@("`@("`@(&%L=V%Y<R!S=&%R="!T;R!C;W5N
M="!B>2!Z97)O(&EN<W1E860@;V8@8V]N=&EN;W5S;'D@;G5M8F5R:6YG+@H)
M"0D@("`@("`@("`@("!&;W(@=&AI<RP@=&AE(&-H87!T97(@;G5M8F5R<R!O
M9B!T:&4@8W5R<F5N="!D;V-U;65N="`H87,@82!S97%U96YC92!O9B!A(&=L
M;V)A;"!D;V-U;65N="D@:7,@9&5P96YD96YT"@D)"2`@("`@("`@("`@(&]F
M('1H92!N=6UB97(@;V8@8VAA<'1E<B!O9B!T:&4@<V%M92!L979E;"!I;B!P
M<F5C961I;F<@9&]C=6UE;G1S+@H)"0D@("`@("`@("`@("!);B!C87-E(&]F
M(&UU;'1I<&QE(&-H:6QD<F5N+"!F;W(@=7-A8FEL:71Y(')E87-O;G,@<V]M
M92!L:6YK:6YG(&ES(&=O;FYA(&)E(&]F9F5R960@86YD('1H92!54DQS(&]F
M('1H92!C;VYT96YT+71A8FQE+`H)"0D@("`@("`@("`@("!P<F5C961I;F<@
M86YD(&9O;&QO=VEN9R!F:6QE(&AA=F4@=&\@8F4@9VEV96X@9F]R('1H92!T
M<F%N<V9O<FUA=&EO;BX*"0D)("`@("`@("`@("`@+2T^"@D)("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](B\J+T!O9F9I8V4Z8VQA<W,])W1E>'0M9VQO
M8F%L)R!A;F0@+RHO;V9F:6-E.F)O9'DO=&5X=#IS96-T:6]N+W1E>'0Z<V5C
M=&EO;BUS;W5R8V4O0'AL:6YK.FAR968B/@H)"0D)"0D\(2TM('1H92!C:&EL
M9')E;B!W:6QL(&)E(&-A;&QE9"!L871E<B!W:71H(&$@;6]D:69I960@)V-O
M;&QE8W1E9$=L;V)A;$1A=&$G('9A<FEA8FQE("TM/@H)"2`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=')A;G-F;W)M+6=L;V)A
M;"UD;V-U;65N="UA;F0M8VAI;&1R96XB/@H)"2`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"0D@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"0D@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H)"0D)"3QX<VPZ;W1H97)W:7-E/@H)"0D)("`@("`@("`\>'-L
M.F%P<&QY+71E;7!L871E<SX*"0D)"2`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"@D)"0D@("`@("`@(#PO>'-L.F%P<&QY+71E
M;7!L871E<SX*"0D)"0D\+WAS;#IO=&AE<G=I<V4^"@D)"0D\+WAS;#IC:&]O
M<V4^"@D@("`@("`@(#PO>'-L.G=H96X^"@D)"3QX<VPZ;W1H97)W:7-E/@H)
M"2`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"@D)("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"0D@("`@("`@(#PO>'-L
M.F%P<&QY+71E;7!L871E<SX*"0D)/"]X<VPZ;W1H97)W:7-E/@H)"3PO>'-L
M.F-H;V]S93X*"@H*("`@("`@("`\(2TM(%5S86)I;&ET>2!F96%T=7)E+"!A
M(&QI;FL@=&\@=&AE($-O;G1E;G0@=&%L8F4@86)O=F4@86QL(&QE=F5L(#$@
M:&5A9&5R("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&-O;G1E;G1486)L
M94AE861I;F=S(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F%D9"UC:&EL9"UD;V-U;65N="UU<V%B:6QI='DM;&EN:W,B+SX*("`@
M("`@("`\+WAS;#II9CX*"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@("`@
M/"$M+2!D96%C=&EV871I;F<@9&5F875L="!T96UP;&%T92`M+3X*("`@(#QX
M<VPZ=&5M<&QA=&4@;6%T8V@](BHB+SX*"@H@("`@/"$M+2!A;&QO=VEN9R!A
M;&P@;6%T8VAE9"!T97AT(&YO9&5S("TM/@H@("`@/'AS;#IT96UP;&%T92!M
M871C:#TB=&5X="@I(CX*/"$M+2!734P@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"XI(B\^("TM/@H@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H*("`@(#PA+2T@(R,C(R,C(R,C(R,C(R,C(R,C(R`M+3X*("`@(#PA+2T@
M(R,C($E.3$E.12U415A4(",C(R`M+3X*("`@(#PA+2T@(R,C(R,C(R,C(R,C
M(R,C(R,C(R`M+3X*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^
M"B`@("`\(2TM("HJ*B!7:&ET97-P86-E("HJ*B`M+3X*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H
M/2)T97AT.G,B/@H@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W
M<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C92(^"B`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)W:&ET97-P86-E<R(@<V5L96-T/2)`=&5X=#IC
M(B\^"B`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*"B`@("`\(2TM=W)I=&4@=&AE(&YU;6)E<B!O9B`G=VAI=&5S
M<&%C97,G("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W<FET92UB<F5A
M:V%B;&4M=VAI=&5S<&%C92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)W
M:&ET97-P86-E<R(O/@H*("`@("`@("`\(2TM=W)I=&4@='=O('-P86-E(&-H
M87)S(&%S('1H92!N;W)M86P@=VAI=&4@<W!A8V4@8VAA<F%C=&5R('=I;&P@
M8F4@<W1R:7!P960*("`@("`@("`@("`@86YD('1H92!O=&AE<B!I<R!A8FQE
M('1O(&)R96%K("TM/@H@("`@("`@(#QX<VPZ=&5X=#XF(S$V,#L\+WAS;#IT
M97AT/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)'=H:71E<W!A8V5S(#X](#(B
M/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M
M8G)E86MA8FQE+7=H:71E<W!A8V4M,B(^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB=VAI=&5S<&%C97,B('-E;&5C=#TB)'=H:71E
M<W!A8V5S("T@,2(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@
M(#PA+2UW<FET92!T:&4@;G5M8F5R(&]F("=W:&ET97-P86-E<R<@+2T^"B`@
M("`\>'-L.G1E;7!L871E(&YA;64](G=R:71E+6)R96%K86)L92UW:&ET97-P
M86-E+3(B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=VAI=&5S<&%C97,B
M+SX*("`@("`@("`\(2TM=W)I=&4@='=O('-P86-E(&-H87)S(&%S('1H92!N
M;W)M86P@=VAI=&4@<W!A8V4@8VAA<F%C=&5R('=I;&P@8F4@<W1R:7!P960*
M("`@("`@("`@("`@86YD('1H92!O=&AE<B!I<R!A8FQE('1O(&)R96%K("TM
M/@H@("`@("`@(#QX<VPZ=&5X=#X@/"]X<VPZ=&5X=#X*("`@("`@("`\>'-L
M.FEF('1E<W0](B1W:&ET97-P86-E<R`^/2`R(CX*("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6)R96%K86)L92UW:&ET97-P
M86-E(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W
M:&ET97-P86-E<R(@<V5L96-T/2(D=VAI=&5S<&%C97,@+2`Q(B\^"B`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ:68^
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ
M*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(%1E>'1B;W@@*BHJ("TM/@H@("`@/"$M
M+2`J*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!M871C
M:#TB9')A=SIT97AT+6)O>"(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!3
M5$Q912!32$5%5"D@2$5!1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@
M("`@("`@("`@/"$M+2`@("`@("`@("`@("`@("!O<B`@("`@("`@("`@("`@
M("`@("TM/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.
M3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$15(G(&]R("1O=71P=714
M>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](G-P86XB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.FEF('1E<W0](D!F;SIM:6XM:&5I9VAT('P@0'-V9SIW:61T:"(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)S='EL92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H0'-V9SIW:61T:"DB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/FAE
M:6=H=#H@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&9O.FUI
M;BUH96EG:'0B+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M;F]T*$!F;SIM:6XM:&5I9VAT*2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z(#PO>'-L.G1E>'0^
M/'AS;#IV86QU92UO9B!S96QE8W0](D!S=F<Z=VED=&@B+SX\>'-L.G1E>'0^
M.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YH96EG:'0Z(#PO>'-L.G1E
M>'0^/'AS;#IV86QU92UO9B!S96QE8W0](D!F;SIM:6XM:&5I9VAT(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YW:61T:#H@/"]X<VPZ=&5X=#X\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB0'-V9SIW:61T:"(O/CQX<VPZ=&5X=#X[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY
M+71E;7!L871E<R!S96QE8W0](D!D<F%W.FYA;64B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T
M>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@/"$M+2`R1$\@<')O=F4@8F5S="!U<V%G
M92!F;W(@4$%,32`M+3X*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-
M(#,N,B!354)3150@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S<&%N(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M+2`R1$\@<')O
M=F4@8F5S="!U<V%G92!F;W(@5TU,("TM/@H@("`@("`@("`@("`@("`@/"$M
M+2LK*RLK(%=-3"`O(%=!4"`@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#PA+2T@;F\@;F5S
M=&5D('`@=&%G<R!I;B!W;6PQ+C$@86QL;W=E9"`M+3X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R
M86=R87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y
M;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P
M<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\(2TM($E$("\@3D%-
M12!O9B!T97AT+6)O>"`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](D!D
M<F%W.FYA;64B/@H*("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)I9"(^
M"B`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^"B`@("`@
M("`@/"]X<VPZ871T<FEB=71E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@
M("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(%!A
M<F%G<F%P:',@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BH@
M+2T^"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IP('P@9')A=SIP
M86=E(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(
M14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P
M<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N
M,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?24Y,24Y%1"<B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P
M<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR
M(%-50E-%5"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@:6X@<&%L;2!P87)A9W)A<&AS(&-H:6QD<F5N(&]F('1E
M>'0Z;&ES="UI=&5M<R!A<F4@8F5T=&5R('-H;W=N('=I=&AO=70@)W`G('1A
M9RTM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M;F%M92AP87)E;G0Z.BHI(#T@)W1E>'0Z;&ES="UI=&5M)R(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M/"$M+2LK*RLK(%=-3"`O(%=!4"`@*RLK*RLM+3X*("`@("`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#PA+2T@;F\@
M;F5S=&5D('`@=&%G<R!I;B!W;6PQ+C$@86QL;W=E9"`M+3X*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M
M<&%R86=R87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM
M<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!497AT(%-P86X@*BHJ
M("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L
M.G1E;7!L871E(&UA=&-H/2)T97AT.G-P86XB/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'
M(%-43%E%(%-(1454*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!
M1$52)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<W!A
M;B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"@H@("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@
M("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T
M5'EP92`]("=#4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](G-P86XB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S
M+C(@4U5"4T54($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE
M<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@(#PA+2TK*RLK*R!734P@+R!705`@("LK*RLK+2T^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2!N;R!N97-T
M960@<"!T86=S(&EN('=M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R87!H+65L
M96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E
M;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N
M=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP
M;&%T93X*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA
M+2T@*BHJ($AE861I;F=S("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.F@B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H*("`@("`@("`\(2TM($5V97)Y(&AE861I;F<@96QE;65N="!W:6QL(&=E
M="!A;B!U;FEQ=64@86YC:&]R(&9O<B!I=',@9FEL92P@9G)O;2!I=',@:&EE
M87)C:'D@;&5V96P@86YD(&YA;64Z"B`@("`@("`@("`@($9O<B!E>&%M<&QE
M.B`@5&AE(&AE861I;F<@=&ET;&4@)TUY(&9A=F]R:71E(&AE861I;F<G(&UI
M9VAT(&=E="`\82!N86UE/2(Q*S(K,BM->2MF879O<FET92MH96%D:6YG(B\^
M("TM/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&1I<V%B;&5,:6YK961486)L94]F0V]N=&5N="!O<B`D:7-*
M879A1&ES86)L960@;W(@;F]T*"1O=71P=714>7!E(#T@)T-34U](14%$15(G
M*2(^"B`@("`@("`@("`@(#PA+2T@5&AE(%523"!L:6YK:6YG(&]F(&%N('1A
M8FQE+6]F+6-O;G1E;G0@:7,@9'5E('1O(&$@8G5G("AC;7`N(&)U9R!I9",@
M,3`R,S$Q*2!N;W0@;6%P<&5D(&%S(%523"!I;B!T:&4@6$U,+@H@("`@("`@
M("`@("`@("`@($QI;FMI;F<@;V8@=&AE('1A8FQE+6]F+6-O;G1E;G0@8V%N
M('1H97)E9F]R92!O;FQY(&)E(&%R8VAI979E9"!B>2!A('=O<FLM87)O=6YD
M(&EN($A434P@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB8W)E871E+6AE861I;F<B/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M(2TM(&YE8V5S<V%R>2!A<R!A;F-H;W(@9F]R('1H92!C;VYT96YT('1A8FQE
M("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F-R96%T92UH96%D:6YG+6%N8VAO<B(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`@("`@/"$M+2!N
M;R!E;6)E9&1I;F<@=&AE(&]R9VEN86P@:&5A9&5R+"!A<R!A;B!E>'!L:6-I
M="!A;F-H;W(@;6EG:'0@8F4@86QR96%D>2!S970@+2T^"B`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6AE861I;F<B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@9&5F875L="!M
M871C:&EN9R!F;W(@:&5A9&5R(&5L96UE;G1S("TM/@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2)C<F5A=&4M:&5A9&EN9R(^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@
M4U1,644@4TA%150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$
M15(G(CX*"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FAE
M861E<G1Y<"(@<V5L96-T/2)C;VYC870H)V@G+"!`=&5X=#IL979E;"DB+SX*
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)[)&AE861E<G1Y
M<'TB/@H*("`@("`@("`@("`@("`@("`@("`\(2TM(&]U=&QI;F4@<W1Y;&4@
M)W1E>'0Z;6EN+6QA8F5L+7=I9'1H)R!I<R!I;G1E<G!R971E9"!A<R!A($-3
M4R`G;6%R9VEN+6QE9G0G(&%T=')I8G5T92`M+3X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FUI;BUL86)E;"(@<V5L96-T/2(D
M;V9F:6-E.G-T>6QE<R]T97AT.F]U=&QI;F4M<W1Y;&4O=&5X=#IO=71L:6YE
M+6QE=F5L+7-T>6QE6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE
M=F5L72]S='EL93IP<F]P97)T:65S+T!T97AT.FUI;BUL86)E;"UW:61T:"(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&UI;BUL86)E
M;"(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](G-T>6QE(CX\>'-L.G1E>'0^;6%R9VEN+6QE9G0Z/"]X<VPZ=&5X=#X\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)&UI;BUL86)E;"(O/CQX<VPZ=&5X=#X[
M/"]X<VPZ=&5X=#X\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ:68^"@H*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I
M8G5T92!N86UE/2)C;&%S<R(^/'AS;#IV86QU92UO9B!S96QE8W0](G1R86YS
M;&%T92A`=&5X=#IS='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2(O/CPO>'-L
M.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@("`@("`@/"$M+2!W<FET:6YG
M(&]U="!A(&-H87!T97(@;G5M8F5R(&EF(&1E<VER960@*&YO=&EC86)L92!W
M:&5N(&$@8V]R<F5S<&]N9&EN9R`G=&5X=#IO=71L:6YE+7-T>6QE)R!E>&ES
M="`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](G-T<FEN
M9RUL96YG=&@H)&]F9FEC93IS='EL97,O=&5X=#IO=71L:6YE+7-T>6QE+W1E
M>'0Z;W5T;&EN92UL979E;"US='EL95M`=&5X=#IL979E;"`](&-U<G)E;G0H
M*2]`=&5X=#IL979E;%TO0'-T>6QE.FYU;2UF;W)M870I("$](#`B/@H*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&1I<V%B;&5,:6YK
M961486)L94]F0V]N=&5N="!O<B`D:7-*879A1&ES86)L960@;W(@;F]T*"1O
M=71P=714>7!E(#T@)T-34U](14%$15(G*2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!T:&4@8VAA<'1E<B!N=6UB97(@:7,@=&AE
M('-U;2!O9B`G=&5X=#IS=&%R="UV86QU92<@86YD('!R96-E9&EN9R!S:6)L
M:6YG<R!O9B`G=&5X=#IH)R!W:71H('1H92!S86UE("=T97AT.FQE=F5L)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9U<G1H97)M
M;W)E('=H96X@=&AE(&-U<G)E;G0@9&]C=6UE;G0@:7,@<F5F97)E;F-E9"!B
M>2!A(&=L;V)A;"!D;V-U;65N="`M(&%S('!A<G0@;V8@82!W:&]L92!S97%U
M96YC92!O9B!D;V-U;65N=',@+2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1H92!C:&%P=&5R(&YO+B!I<R!D97!E;F1E;G0@;V8@
M=&AE(&%M;W5N="!O9B!S=&%R=&5D(&AE861E<G,@:6X@<')E8V5D:6YG(&1O
M8W5M96YT<RX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($EF('1H92`G=&5X=#IS=&%R="UV86QU92!I<R!N;W0@<V5T('1H92!D969A
M=6QT('9A;'5E(&]F("<Q)R!H87,@=&\@8F4@=&%K96XN("TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M<W1A<G1686QU92(@<V5L96-T/2(D;V9F:6-E.G-T>6QE<R]T97AT.F]U=&QI
M;F4M<W1Y;&4O=&5X=#IO=71L:6YE+6QE=F5L+7-T>6QE6T!T97AT.FQE=F5L
M(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72]`=&5X=#IS=&%R="UV86QU92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)'-T87)T5F%L=64B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(D!T97AT.FQE=F5L/2<Q)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C
M;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@
M8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E
M8V5D:6YG0VAA<'1E<DQE=F5L,0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1S=&%R=%9A
M;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P]
M)S(G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN
M9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E
M>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R
M3&5V96PR"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("L@)'-T87)T5F%L=64B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG,R<B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E
M>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#,*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](D!T97AT.FQE=F5L/2<T)R(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE
M=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1S
M=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z
M;&5V96P])S4G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R
M96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT
M*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#
M:&%P=&5R3&5V96PU"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'-T87)T5F%L=64B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG-B<B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI
M;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E
M;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#8*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<W)R(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T
M97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M0'1E>'0Z;&5V96P])S@G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O
M=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C
M=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C
M961I;F=#:&%P=&5R3&5V96PX"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'-T87)T5F%L
M=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG
M.2<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG
M+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X
M=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),
M979E;#D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<Q,"<B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E
M>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#$P"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("L@)'-T87)T5F%L=64B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E
M;#TG,2<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D
M:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`
M=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T
M97),979E;#$*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S(G(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E
M>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PR"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L
M/2<S)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I
M;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T
M97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E
M<DQE=F5L,PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)`=&5X=#IL979E;#TG-"<B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X
M=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#0*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P]
M)S4G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN
M9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E
M>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R
M3&5V96PU"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("L@,2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](D!T97AT.FQE=F5L/2<V)R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT
M.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K
M(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG
M-R<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG
M+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X
M=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),
M979E;#<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'1E>'0Z;&5V96P])S@G(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PX"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@
M,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<Y
M)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M
M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT
M.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE
M=F5L.0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)`=&5X=#IL979E;#TG,3`G(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PQ,`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K
M(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M
M86)S;VQU=&4M8VAA<'1E<BUN;R(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P<F5C961I;F=#
M:&%P=&5R3&5V96PQ(B`@("!S96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V
M96PQ(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@
M("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^("8C,38P.R`F(S$V,#L\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"B`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$
M(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O
M=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](FAE861E<G1Y<"(@<V5L96-T/2)C;VYC870H
M)V@G+"!`=&5X=#IL979E;"DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)[)&AE861E<G1Y<'TB/@H*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](D!T97AT.G-T>6QE+6YA
M;64B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY
M+71E;7!L871E<SX*"B`@("`@("`@("`@("`@("`@("`@/"$M+2!W<FET:6YG
M(&]U="!A(&-H87!T97(@;G5M8F5R(&EF(&1E<VER960@*&YO=&EC86)L92!W
M:&5N(&$@8V]R<F5S<&]N9&EN9R`G=&5X=#IO=71L:6YE+7-T>6QE)R!E>&ES
M="`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1O9F9I
M8V4Z<W1Y;&5S+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M;&5V
M96PM<W1Y;&5;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=
M+T!T97AT.G-T>6QE+6YA;64B/@H*("`@("`@("`@("`@("`@("`@("`@("`@
M/"$M+2!T:&4@8VAA<'1E<B!N=6UB97(@:7,@=&AE('-U;2!O9B`G=&5X=#IS
M=&%R="UV86QU92<@86YD('!R96-E9&EN9R!S:6)L:6YG<R!O9B`G=&5X=#IH
M)R!W:71H('1H92!S86UE("=T97AT.FQE=F5L)R`M+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E
M9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO
M0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@)&]F9FEC93IS='EL97,O=&5X=#IO=71L:6YE+7-T
M>6QE+W1E>'0Z;W5T;&EN92UL979E;"US='EL95M`=&5X=#IL979E;"`](&-U
M<G)E;G0H*2]`=&5X=#IL979E;%TO0'1E>'0Z<W1A<G0M=F%L=64B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/B`F(S$V,#L@)B,Q-C`[
M/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2`R1$\Z(&%D9"!#:&%P=&5R($YO
M+B!F;W(@4$%,32!A;F0@5TU,(#PM/B!P<F]B;&5M(&YE<W1E9"!A<'!L>2UT
M96UP;&%T97,@+2T^"@H@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@
M4U5"4T54($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)H96%D97)T>7`B('-E;&5C=#TB
M8V]N8V%T*"=H)RP@0'1E>'0Z;&5V96PI(B\^"B`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB>R1H96%D97)T>7!](CX*"@H@("`@("`@("`@
M("`@("`@("`@(#PA+2T@06QL(&-H:6QD<F5N(&-O;G1E;G0@:&%V92!T;R!B
M92!N97-T960@:6X@=&AE('-T>6QE<R`H92YG+B`\:3X\8CY!3ED@0T].5$5.
M5#PO8CX\+VD^*0H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R('1H:7,@
M>'-L.F%P<&QY+71E;7!L871E<R!W:6QL(&)E(&-A;&QE9"!L871E<B`O(&EM
M<&QI8VET("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)C<F5A=&4M871T<FEB=71E+4%,24=.(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!G971T:6YG('1H92!C<W,@<W1Y;&5S(&9O
M<B!T:&4@<W1Y;&4@;F%M92`H;6%P<&5D(&)Y('-T>6QE+6UA<'!I;F<N>'-L
M*2`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82]A;&QS='EL97,O*EMN86UE*"D]8W5R<F5N="@I+T!T97AT.G-T
M>6QE+6YA;65=(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\(2TM*RLK*RL@5TU,
M("\@5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#PA+2T@;F\@;F5S=&5D('`@=&%G<R!I;B!W;6PQ
M+C$@86QL;W=E9"`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ
M*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT<RP@;F%M92@I*5TB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('-I;F-E(&YO(&AE861E
M<B!S='EL97,@97AI<W0L(&%N(&5M<&AA<VES(&ES('5S960@+2T^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)E;2(^"@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!W<FET:6YG(&]U="!A
M(&-H87!T97(@;G5M8F5R(&EF(&1E<VER960@*&YO=&EC86)L92!W:&5N(&$@
M8V]R<F5S<&]N9&EN9R`G=&5X=#IO=71L:6YE+7-T>6QE)R!E>&ES="`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&]F
M9FEC93IS='EL97,O=&5X=#IO=71L:6YE+7-T>6QE+W1E>'0Z;W5T;&EN92UL
M979E;"US='EL95M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E
M;%TO0'1E>'0Z<W1Y;&4M;F%M92(^"@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@=&AE(&-H87!T97(@;G5M8F5R(&ES('1H92!S=6T@
M;V8@)W1E>'0Z<W1A<G0M=F%L=64G(&%N9"!P<F5C961I;F<@<VEB;&EN9W,@
M;V8@)W1E>'0Z:"<@=VET:"!T:&4@<V%M92`G=&5X=#IL979E;"<@+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D;V9F
M:6-E.G-T>6QE<R]T97AT.F]U=&QI;F4M<W1Y;&4O=&5X=#IO=71L:6YE+6QE
M=F5L+7-T>6QE6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L
M72]`=&5X=#IS=&%R="UV86QU92(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#X@)B,Q-C`[("8C,38P.SPO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S
M96QE8W0](D!T97AT.G-T>6QE+6YA;64B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T
M97,^"@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@<VEN8V4@;F\@:&5A9&5R('-T>6QE<R!E>&ES="P@86X@
M96UP:&%S:7,@:7,@=7-E9"`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)E;2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY
M+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!,
M:6YK("`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@
M/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IA('P@9')A=SIA(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC;VUM;VXM
M;&EN:R(^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R96%T92UC;VUM
M;VXM;&EN:R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB;F]T*"1O=71P=714>7!E(#T@)U=-3"<I(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)H<F5F(CX\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB0'AL:6YK.FAR968B+SX\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`@("`@/"$M+3QX<VPZ871T<FEB=71E(&YA
M;64](F-L87-S(CY#;VYT96YT3&EN:SPO>'-L.F%T=')I8G5T93XM+3X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P
M;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM(&YO
M(&YE<W1E9"!P('1A9W,@:6X@=VUL,2XQ(&%L;&]W960@+2T^"B`@("`@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A<"UP87)A9W)A
M<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^/'AS;#IV86QU
M92UO9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T
M97,@<V5L96-T/2)D97-C96YD86YT.CIT97AT*"DB+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^/'AS;#IV86QU92UO9B!S96QE
M8W0](D!X;&EN:SIH<F5F(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E
M;&5C=#TB9&5S8V5N9&%N=#HZ=&5X="@I(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*"B`@("`\(2TM("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!);6%G92!,:6YK("`J*BH@
M+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS
M;#IT96UP;&%T92!M871C:#TB9')A=SII;6%G92(^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#PA
M+2T@3D\@24U!1T53(%-54%!,245$($9/4B!705`@3U(@4$%,32`M+3X*("`@
M("`@("`\>'-L.FEF('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$15(G
M(&]R("1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"@H@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB:6UG(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ:68@=&5S=#TB0'-V9SIW:61T:"(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB=VED=&@B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8V]N=F5R=#)P:7AE
M;"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB=F%L=64B('-E;&5C=#TB0'-V9SIW:61T:"(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`<W9G
M.FAE:6=H="(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB:&5I9VAT(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F-O;G9E<G0R<&EX96PB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G9A;'5E
M(B!S96QE8W0](D!S=F<Z:&5I9VAT(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](G-V9SID97-C(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)A;'0B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W9G
M.F1E<V,B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`\(2TM(&9O<B!I;6%G
M97,@:F%R960@:6X@;W!E;B!O9F9I8V4@9&]C=6UE;G0@+2T^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*$!X;&EN:SIH
M<F5F+"`G(U!I8W1U<F5S+R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"$M+2!C<F5A=&EN9R!A;B!A8G-O;'5T92!H='1P(%523"!T;R!T:&4@<&%C
M:V5D(&EM86=E(&9I;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](G-R8R(^/'AS;#IV86QU92UO9B!S96QE8W0]
M(F-O;F-A="@D:F%R9612;V]T55),+"`G+U!I8W1U<F5S+R<L('-U8G-T<FEN
M9RUA9G1E<BA`>&QI;FLZ:')E9BP@)R-0:6-T=7)E<R\G*2P@)&]P=&EO;F%L
M55),4W5F9FEX*2(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H\(2TM("`@("`@("`@("`@("`@("`@("!$=64@
M=&\@82!85"!B=6<@;F\@1$]3("<Z)R!B969O<F4@1%))5D4@;&5T=&5R(&ES
M(&%L;&]W960L(&ET('=O=6QD(')E<W5L="!I;B!A('5N:V]W;B!P<F]T;V-O
M(&5X8V5P=&EO;BP@8G5T(&$@9FEL92!54DP@9F]R(&$@1$]3"@D)"0D)"7!A
M=&@@;F5E9',@=&AE($12259%(&QE='1E<BP@=&AE<F5F;W)E(&%L;"!R96QA
M=&EV92!54DQS(')E;6%I;B!R96QA=&EV"@H)"0D)"3QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<RA`>&QI;FLZ:')E9BPG+R\G*2!O<B`H<W5B<W1R:6YG*$!X
M;&EN:SIH<F5F+#(L,2D@/2`G.B<I(&]R('-T87)T<RUW:71H*$!X;&EN:SIH
M<F5F+"`G+R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R
M:6)U=&4@;F%M93TB<W)C(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'AL:6YK
M.FAR968B+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`@("`@/"%^?B!C<F5A=&EN9R!A(&%B
M<V]L=71E('!A=&@O55),(&9O<B!T:&4@<F5F97)E;F-E9"!R97-O=7)C92!^
M?CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB<W)C(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1A8G-O;'5T
M95-O=7)C941I<E)E9BP@0'AL:6YK.FAR968L("1O<'1I;VYA;%523%-U9F9I
M>"DB+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@HM+3X*"0D)"0D\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W)C(CX\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB0'AL:6YK.FAR968B+SX\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H*("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O
M;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\
M(2TM(&%D9&EN9R!A(&QI;F4@8G)E86L@=&\@;6%K92!T:&4@<')E<V5N=&%T
M:6]N(&UO<F4@979E;B!W:71H('1H92!/3V\@=FEE=R`M+3X*("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F)R(B\^"B`@("`@("`@/"]X<VPZ:68^
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!O<F1E<F5D(&QI<W0@*BHJ("TM
M/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L
M.G1E;7!L871E(&UA=&-H/2)T97AT.F]R9&5R960M;&ES="(^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA+2TK*RLK
M*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-464Q%(%=!
M62`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O
M=71P=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB;VPB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N
M9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@
M("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U
M='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB;VPB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N
M9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@4U5"4T54($%.1"!7
M05`@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)O;"(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!705`@("LK
M*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!S:6UU;&%T:6YG(&-O;G1E;G0@8G)E86L@;V8@8V%P<W5L
M871E9"!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.G1E>'0Z;&ES="UI=&5M(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A
M;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT<RP@
M;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM('-I;75L871I;F<@8V]N=&5N="!B<F5A:R!O9B!C87!S=6QA=&5D
M(&QI<W0@96QE;65N=',@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B<B(^/"]X<VPZ96QE;65N
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@<VEM=6QA=&EN9R!C;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T
M960@;&ES="!E;&5M96YT<R`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B<B(^/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD
M+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\(2TM
M("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!U;F]R
M9&5R960@;&ES="`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IU;F]R
M9&5R960M;&ES="(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I($A%
M041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)U;"(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA
M;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\(2TM
M*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?24Y,24Y%
M1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G5L(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@
M("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@04Y$(%=!4"!)
M3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)U;"(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N
M="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\(2TM*RLK*RL@5TU,
M("\@5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@(#PA+2T@<VEM=6QA=&EN9R!C;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T
M960@;&ES="!E;&5M96YT<R`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB86YC97-T;W(Z.G1E>'0Z;&ES="UI=&5M(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N
M=&%I;G,H)'=A<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('-I;75L871I;F<@
M8V]N=&5N="!B<F5A:R!O9B!C87!S=6QA=&5D(&QI<W0@96QE;65N=',@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](F)R(CX\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM('-I;75L871I;F<@8V]N=&5N="!B<F5A:R!O9B!C87!S=6QA=&5D(&QI
M<W0@96QE;65N=',@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B<B(^/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*
M("`@(#PA+2T@*BHJ(&QI<W0@:71E;2`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB
M=&5X=#IL:7-T+6ET96TB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454
M*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"B`@("`@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB;&DB/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL
M97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@
M/"$M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TE.
M3$E.140G(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)L
M:2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"@H@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@4U5"4T54($%.1"!7
M05`@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB;&DB/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O
M;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK*RLK
M(%=-3"`O(%=!4"`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H
M)'=A<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!S:6UU;&%T:6YG(&QI<W0@96QE;65N=',@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L
M96-T/2)A;F-E<W1O<CHZ=&5X=#IL:7-T+6ET96TB/BH\+WAS;#IF;W(M96%C
M:#X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/BH@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&QI<W0@:71E;2!B
M<F5A:R!S:6UU;&%T:6]N("AN;W0@:6X@82!T86)L92DM+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H86YC97-T;W(Z.G1A
M8FQE.G1A8FQE+6-E;&PI(&]R(&9O;&QO=VEN9RUS:6)L:6YG.CIT97AT.FQI
M<W0M:71E;2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB8G(B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!S:6UU;&%T:6YG(&QI<W0@96QE;65N=',@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H
M('-E;&5C=#TB86YC97-T;W(Z.G1E>'0Z;&ES="UI=&5M(CXJ/"]X<VPZ9F]R
M+65A8V@^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M*B`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N
M="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\(2TM(&QI<W0@:71E;2!B<F5A:R!S:6UU;&%T:6]N("AN;W0@
M:6X@82!T86)L92DM+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ:68@=&5S=#TB;F]T*&%N8V5S=&]R.CIT86)L93IT86)L92UC96QL*2!O
M<B!F;VQL;W=I;F<M<VEB;&EN9SHZ=&5X=#IL:7-T+6ET96TB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B
M<B(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@
M("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!497AT(%-E8W1I;VX@*&-O;G1A
M:6YS.B!D<F%W.G1E>'0M8F]X*2`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@
M("`@("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z<V5C=&EO;B(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^
M"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*&-O;G1A:6YS*$!T97AT.F1I
M<W!L87DL("=N;VYE)RDI(CX*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@
M4TA%150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52
M)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G-P
M86XB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\(2TM*RLK
M*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.
M140G(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M<W!A;B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PA+2TK
M*RLK*R!004Q-(#,N,B!354)3150@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G
M4$%,32<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB;F%M92AP87)E
M;G0Z.BHI(#T@)W1E>'0Z;&ES="UI=&5M)R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE
M<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK(%=-3"`O(%=!
M4"`@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB;F]T*"1O=71P=714>7!E(#T@
M)U=-3"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)H<F5F(CX\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB0'AL:6YK.FAR968B+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!N;R!N97-T960@<"!T
M86=S(&EN('=M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS
M*"1W87`M<&%R86=R87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*
M"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IL:6YE+6)R96%K(CX*
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8G(B+SX*("`@(#PO>'-L.G1E
M;7!L871E/@H*"CPA+2T*("`@(%1!0DA!3D1,24Y'(%!23T),14TZ(%1A8G,@
M87)E('!O<W-I8FQE('1O(&)E('-H;W=N(&EN('1H92!(5$U,('1E>'0@9FEL
M92P@8G5T('=I;&P@8F4@;&%T97(@<W1R:7!P960@87,@=VAI=&5S<&%C97,N
M"B`@("`@("`@5&\@<')E=F5N="!T:&ES(&]N92!W87D@=V]U;&0@8F4@=&AE
M(%!212!T86<@=VAI8V@@=6YF;W)T=6YA=&5L>2!!3%=!65,@<F5S=6QT(&EN
M=&\@82!L:6YE+6)R96%K+B!.;R!S=7)R;W5N9&EN9R!.3T)2('1A9W,@:&5L
M<"X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G1A8BUS=&]P(CX*
M("`@("`@("`\>'-L.FEF('1E<W0](FYO="AP<F5C961I;F<M<VEB;&EN9SHZ
M=&5X=#IT86(M<W1O<"DB/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB<')E(CX\>'-L.G1E>'0^)B,Y.SPO>'-L.G1E>'0^/'AS;#IF;W(M96%C
M:"!S96QE8W0](F9O;&QO=VEN9RUS:6)L:6YG.CIT97AT.G1A8BUS=&]P(CX\
M>'-L.G1E>'0^)B,Y.SPO>'-L.G1E>'0^/"]X<VPZ9F]R+65A8V@^/"]X<VPZ
M96QE;65N=#X*("`@("`@("`\+WAS;#II9CX*("`@("`\+WAS;#IT96UP;&%T
M93X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G1A8BUS=&]P(CX\
M>'-L.G1E>'0^)B,Y.SPO>'-L.G1E>'0^/"]X<VPZ=&5M<&QA=&4^"BTM/@H@
M("`@/"$M+2!(3U1&25@Z(#@@;F]N+6)R96%K86)L92US<&%C97,@:6YS=&5A
M9"!O9B!A(%1!0B!I<R!A(&AA8VL@<V]M971I;65S(&QE<W,@5&%B<R!A<F4@
M;F5E9&5D(&%N9"!T:&4@8V]D92!M;W)E(&1I9F9I8W5L="!T;R!R96%D("TM
M/@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IT86(M<W1O<"(^"B`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6)R96%K86)L
M92UW:&ET97-P86-E(CX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G=H:71E<W!A8V5S(B!S96QE8W0](C@B+SX*("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/"$M+2!C
M=7)R96YT;'D@=&AE<F4@:&%V92!T;R!B92!A;B!E>'!L:6-I="!C86QL(&]F
M('1H92!S='EL92!A='1R:6)U=&4@;F]D97,L(&UA>6)E('1H92!A='1R:6)U
M=&5S(&YO9&5S(&AA=F4@;F\@<')I;W)I='D@;VYL>2!O<F1E<B!R96QE=F%N
M="TM/@H@("`@/"$M+2!35%)!3D=%.B!C:&5C:V5D('=I=&@@8FEO<GET:&TN
M<WAC(&$@<VEM<&QE('AS;#IA<'!L>2UT96UP;&%T97,@9&ED(&YO="!R96-O
M9VYI8V4@=&AE('-T>6QE<RX@36%Y8F4@8V%U<V5D(&)Y('1H92!T96UP;&%T
M92!M871C:"!O<F1E<C\@("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A
M<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F%P
M<&QY+71E;7!L871E<R!S96QE8W0](D!T97AT.G-T>6QE+6YA;64@?"!`9')A
M=SIS='EL92UN86UE('P@0&1R87<Z=&5X="US='EL92UN86UE('P@0'1A8FQE
M.G-T>6QE+6YA;64B/CPA+2T@?"!`<')E<V5N=&%T:6]N.G-T>6QE+6YA;64@
M+2T^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*("`@("`@("`\>'-L
M.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!M871C
M:#TB0'1E>'0Z<W1Y;&4M;F%M92!\($!D<F%W.G-T>6QE+6YA;64@?"!`9')A
M=SIT97AT+7-T>6QE+6YA;64@?"!`=&%B;&4Z<W1Y;&4M;F%M92(^/"$M+2!\
M($!P<F5S96YT871I;VXZ<W1Y;&4M;F%M92TM/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'
M(%-43%E%(%-(1454*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!
M1$52)R(^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C
M;&%S<R(^/'AS;#IV86QU92UO9B!S96QE8W0](G1R86YS;&%T92@N+"`G+B`E
M*"DO7"<L("<G*2(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)
M3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^/'AS;#IV86QU92UO9B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE<R\J6VYA;64H
M*3UC=7)R96YT*"DO+ETB+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@
M4U5"4T54($E.3$E.140@5T%9("!A;F0@(%=-3"`O(%=!4"`@("LK*RLK+2T^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=0
M04Q-)R!O<B`D;W5T<'5T5'EP92`]("=734PG(CX*("`@("`@("`@("`@("`@
M(#PA+2T@9V5T=&EN9R!T:&4@8W-S('-T>6QE<R!F;W(@=&AE('-T>6QE(&YA
M;64@*&UA<'!E9"!B>2!S='EL92UM87!P:6YG+GAS;"D@+2T^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T>6QE4')O<&5R=&EE<R(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]A;&QS='EL97,O*EMN86UE
M*"D]8W5R<F5N="@I+RY=(B\^"B`@("`@("`@("`@("`@("`\(2TM(&-H86YG
M:6YG('1H92!C;VYT97AT(&YO9&4@+2T^"B`@("`@("`@("`@("`@("`\>'-L
M.F9O<BUE86-H('-E;&5C=#TB<&%R96YT.CHJ(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6YE<W1E9"UF
M;W)M870M=&%G<R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE
M4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IF;W(M
M96%C:#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T
M92!M871C:#TB=&5X=#IS97%U96YC92(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ87!P
M;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@
M(#PO>'-L.G1E;7!L871E/@H*"CPO>'-L.G-T>6QE<VAE970^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O
M;R]G;&]B86Q?9&]C=6UE;G0N>'-L````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(U,C4S-P`Q,#0Q
M-S,V,C<W,P`P,C0W,C(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I
M;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F
M"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@
M("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R
M8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!)
M;F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P
M(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO
M(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R
M87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET
M(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R
M+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T
M:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H
M;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.
M62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y
M(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO
M=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A
M<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U
M;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O
M<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R
M>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O
M('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E
M(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E
M('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,
M:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N
M<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN
M"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@
M<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)2
M04Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@
M24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@
M5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#
M2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/
M3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C
M:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@
M;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@
M26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y
M(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V
M960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I
M;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W
M=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I
M8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT
M97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B
M"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V
M9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R
M,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@
M("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA
M=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM
M;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T
M(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@
M("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@
M('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*
M("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@
M("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ
M8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@97AT96YS:6]N+65L96UE
M;G0M<')E9FEX97,](GAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z=7)L96YC
M;V1E<CTB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YN970N
M55),16YC;V1E<B(*("`@("`@("`@("`@("`@('AM;&YS.G-X9VAE;'!E<CTB
M:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O8V]M+G-U;BYS=&%R+GAS
M;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(B"B`@("`@("`@("`@("`@
M("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N
M;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT
M+7!R969I>&5S/2)J879A(CX*"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM
M("HJ*B!';&]B86P@1&]C=6UE;G0@+2`@5&%B;&4@;V8@0V]N=&5N="`@("`J
M*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*"B`@("`\>'-L.G1E;7!L871E(&UA
M=&-H/2)T97AT.G1A8FQE+6]F+6-O;G1E;G0B/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L
M.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T
M8V@](G1E>'0Z:6YD97@M8F]D>2(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ87!P;'DM
M=&5M<&QA=&5S(&UO9&4](F-O;G1E;G0M=&%B;&4B/@H@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#PO>'-L.F%P
M<&QY+71E;7!L871E<SX*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS
M;#IT96UP;&%T92!M871C:#TB=&5X=#II;F1E>"UT:71L92(@;6]D93TB8V]N
M=&5N="UT86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S
M/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@(#PO>'-L.G1E;7!L
M871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z<F5F97)E;F-E
M+7)E9B(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B\^"@H@("`@("`@(#PA+2T@2F%V82!I<R!N965D960@87,@=V4@
M:&%V92!T;R!E;F-O9&4@=&AE(')E;&%T:79E(&QI;FMS("AB=6<C,3`R,S$Q
M*2`M+3X*("`@("`@("`\>'-L.FEF('1E<W0](FYO="@D:7-*879A1&ES86)L
M960I(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@
M("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/B,\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)E;F-O9&4M
M<W1R:6YG(CX*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!T:&4@<W!A
M8V4@:&%S('1O(&)E(&YO<FUA;&EZ960L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O=&AE<G=I<V4@86X@:6QL96=A;"!A<F=U;65N="!E>&-E<'1I
M;VX@=VEL;"!B92!T:')O=VX@9F]R(%A4+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O9&5D
M(B!S96QE8W0](D!T97AT.G)E9BUN86UE(B\^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L
M.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L
M871E<SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\+WAS
M;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@
M;6%T8V@](G1E>'0Z<F5F97)E;F-E+6UA<FLB/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM
M($IA=F$@:7,@;F5E9&5D(&%S('=E(&AA=F4@=&\@96YC;V1E('1H92!R96QA
M=&EV92!L:6YK<R`H8G5G(S$P,C,Q,2D@+2T^"B`@("`@("`@/'AS;#II9B!T
M97-T/2)N;W0H)&ES2F%V841I<V%B;&5D*2(^"B`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FYA;64B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!T:&4@<W!A8V4@:&%S('1O(&)E(&YO<FUA;&EZ
M960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!O=&AE<G=I<V4@86X@
M:6QL96=A;"!A<F=U;65N="!E>&-E<'1I;VX@=VEL;"!B92!T:')O=VX@9F]R
M(%A4+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)T97AT5&]"945N8V]D960B('-E;&5C=#TB0'1E>'0Z;F%M92(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@("`@("`@("`@("`@
M("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"B`@("`@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z<F5F97)E;F-E+6UA
M<FLM<W1A<G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM($IA=F$@:7,@;F5E9&5D(&%S
M('=E(&AA=F4@=&\@96YC;V1E('1H92!R96QA=&EV92!L:6YK<R`H8G5G(S$P
M,C,Q,2D@+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H)&ES2F%V841I
M<V%B;&5D*2(^"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA;64B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)E
M;F-O9&4M<W1R:6YG(CX*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!T
M:&4@<W!A8V4@:&%S('1O(&)E(&YO<FUA;&EZ960L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!O=&AE<G=I<V4@86X@:6QL96=A;"!A<F=U;65N="!E
M>&-E<'1I;VX@=VEL;"!B92!T:')O=VX@9F]R(%A4+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T97AT5&]"945N
M8V]D960B('-E;&5C=#TB0'1E>'0Z;F%M92(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IA='1R:6)U=&4^"@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)E;F1/9E)E9F5R96YC92(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IF;W(M96%C:"!S96QE8W0](G1E>'0Z<F5F97)E;F-E+6UA<FLM96YD6T!N
M86UE/6-U<G)E;G0H*2]`=&5X=#IN86UE72(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)P;W-I=&EO;B@I(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@
M("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@("`@("`@("`\>'-L.F9O
M<BUE86-H('-E;&5C=#TB9F]L;&]W:6YG+7-I8FQI;F<Z.BI;<&]S:71I;VXH
M*2`F;'0[("1E;F1/9E)E9F5R96YC95TB/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"B`@("`@
M/"$M+2!C;VYT96YT('1A8FQE(&QI;FL@("TM/@H@("`@/'AS;#IT96UP;&%T
M92!M871C:#TB=&5X=#IA(B!M;V1E/2)C;VYT96YT+71A8FQE(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"@H@
M("`@("`@(#PA+2T@1F]R(&%N8VAO<G,@:6X@8V]N=&5N="UH96%D97)S(&$@
M8G5G(&5X:7-T<R`H8W`N(&)U9R!I9",@,3`R,S$Q*2!A;F0@=&AE>2!H879E
M('1O(&)E('=O<FME9"!O=70@<V5P87)A=&5L>2X*("`@("`@("`@("`@0W5R
M<F5N=&QY('1H92!L:6YK('5S960@:6X@=&AE(&-O;G1E;G0M=&%B;&4@;V8@
M86X@3V9F:6-E(%A-3"`H92YG+B!I;B!T:&4@8V]N=&5N="!T86)L92!A<R`G
M(S<N4V]M924R,$5X86UP;&4E,C!(96%D;&EN924W3W5T;&EN92<I"B`@("`@
M("`@("`@(&ES(&YO="!A('9A;&ED(%523"`H8W`N(&)U9R!I9",@,3`R,S$Q
M*2X@3F\@9FEL92!D97-T:6YA=&EO;B!I<R!S<&5C:69I960@;F]R(&5X:7-T
M(&%N>2!A;F-H;W(@96QE;65N="!F;W(@=&AE<V4*("`@("`@("`@("`@;&EN
M:W,@:6X@=&AE($]F9FEC92!834PL(&YO<B!I<R!T:&4@8VAA<'1E<B!N;RX@
M:VYO=VX@:6X@=&AE(&QI;FME9"!F:6QE<RX*("`@("`@("`@("`@02!W;W)K
M87)O=6YD(&9O<B!T:&ES('1R86YS9F]R;6%T:6]N('1H97)E9F]R92!H860@
M=&\@8F4@;6%D92X@5&AI<R!T:6UE+6-O;G-U;6EN9R!M96-H86YI<VT@:7,@
M9&ES86)L960@8GD@9&5F875L="!A;F0*("`@("`@("`@("`@8V%N(&)E(&%C
M=&EV871E9"!B>2!A('!A<F%M971E<B`H:2YE+B`G9&ES86)L94QI;FME9%1A
M8FQE3V9#;VYT96YT)RDN($$@8W)E871I;VX@;V8@86X@86YC:&]R(&ES(&UA
M9&4@9F]R(&5A8V@@:&5A9&5R(&5L96UE;G0N"B`@("`@("`@("`@($%L;"!H
M96%D97(@=&ET;&5S(&=O;FYA(&)E(&5N8V]D:6YG('1O(&)E('5S86)L92!I
M;B!A(')E;&%T:79E(%523"X@+2T^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D9&ES86)L94QI;FME9%1A8FQE
M3V9#;VYT96YT(&]R("1I<TIA=F%$:7-A8FQE9"(^"B`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;6UO;BUL:6YK
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB8W)E871E+6-O;G1E;G0M=&%B;&4M;&EN:R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T
M+6%B<V]L=71E+6-H87!T97(M;F\B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(O/@H*("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1G;&]B86Q$
M;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B/@H*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$9I;&5(96%D:6YG3F\B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M
M8W5R<F5N="UF:6QE+6AE861I;F<M;F\B+SX*("`@("`@("`@("`@("`@(#PO
M>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)T97-T4F5S=6QT(B!S96QE8W0](B1C;VYT96YT5&%B;&5(96%D:6YG
M<R]H96%D:6YG6R1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4@/2!`
M9FEL92UU<FQ=6VYU;6)E<B@D8W5R<F5N=$9I;&5(96%D:6YG3F\I72(O/@H*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M
M9VQO8F%L+6AE861I;F<M;F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C=7)R96YT1FEL94AE861I;F=.;R(@<V5L96-T
M/2)T<F%N<VQA=&4H)'1E<W1297-U;'0O0&%B<V]L=71E+6-H87!T97(M;&5V
M96PL("<K)RP@)RXG*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)P<F5C961I;F=#:&%P=&5R3&5V96PQ(B!S96QE8W0]
M(B1P<F5C961I;F=#:&%P=&5R3&5V96PQ(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H*("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M
M+2!7:&5N('1H92!C:&%P=&5R(&ES(&EN('1H92!G;&]B86P@9&]C=6UE;G0@
M:71S96QF('1H92!L:6YK(&AA<R!T;R!B92!R96QA=&EV92`H92YG+B`C:6YD
M97@I(&$@86)S;VQU=&4@:')E9B!D;V5S(&YO=`H@("`@("`@("`@("`@("`@
M("`@('=O<FL@=VET:"!T:&4@8G)O=W-E<BX@26X@8V%S92!O9B!C:&%P=&5R
M(&EN('1H92!G;&]B86P@9&]C=6UE;G0L('1H92!O=71P=70@55),(&]F('1H
M92!G;&]B86P@9&]C=6UE;G0@=V%S('1A:V5N+B`M+3X*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$9I;&5(96%D:6YG3F\B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)G970M8W5R<F5N="UF:6QE+6AE861I;F<M;F\B+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)T97-T4F5S=6QT(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A+V-O;G1E;G0M=&%B;&4M:&5A9&EN9W,O:&5A9&EN9ULD8V]N=&5N
M=%1A8FQE55),(#T@0&9I;&4M=7)L75MN=6UB97(H)&-U<G)E;G1&:6QE2&5A
M9&EN9TYO*5TB+SX*"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB9V5T+6=L;V)A;"UH96%D:6YG+6YO(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$9I;&5(96%D
M:6YG3F\B('-E;&5C=#TB=')A;G-L871E*"1T97-T4F5S=6QT+T!A8G-O;'5T
M92UC:&%P=&5R+6QE=F5L+"`G*R<L("<N)RDB+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE
M=F5L,2(@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E="UC
M=7)R96YT+69I;&4M:&5A9&EN9RUN;R(^"B`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B
M;&4H)W-X9VAE;'!E<CIG970M8W5R<F5N="UC:&EL9"UH96%D:6YG+6YO)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-X9VAE
M;'!E<CIG970M8W5R<F5N="UC:&EL9"UH96%D:6YG+6YO*"DB+SX*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH
M96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971#=7)R96YT0VAI;&1(96%D
M:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N
M<V9O<FUE<BYG971#=7)R96YT0VAI;&1(96%D:6YG3F\H*2(O/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E="UN
M97AT+6-U<G)E;G0M9FEL92UH96%D:6YG+6YO(CX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](F9I;&4B+SX*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG
M:&5L<&5R.F=E="UN97AT+6-U<G)E;G0M8VAI;&0M:&5A9&EN9RUN;R<I(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP
M97(Z9V5T+6YE>'0M8W5R<F5N="UC:&EL9"UH96%D:6YG+6YO*"1F:6QE*2(O
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A.F-O;2YS=6XN<W1A
M<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=$YE>'1#=7)R
M96YT0VAI;&1(96%D:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N
M4WAG0VAI;&14<F%N<V9O<FUE<BYG971.97AT0W5R<F5N=$-H:6QD2&5A9&EN
M9TYO*"1F:6QE*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L
M.G1E;7!L871E(&YA;64](F=E="UG;&]B86PM:&5A9&EN9RUN;R(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C=7)R96YT1FEL94AE861I;F=.;R(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L
M,2(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F=E="UG
M;&]B86PM:&5A9&EN9RUN;R<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)S>&=H96QP97(Z9V5T+6=L;V)A;"UH96%D:6YG+6YO
M*'-T<FEN9R@D8W5R<F5N=$9I;&5(96%D:6YG3F\I+"!N=6UB97(H)'!R96-E
M9&EN9T-H87!T97),979E;#$I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R
M86YS9F]R;65R+F=E=$=L;V)A;$AE861I;F=.;R<I(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.F-O;2YS=6XN<W1A<BYX
M<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=$=L;V)A;$AE861I
M;F=.;RAS=')I;F<H)&-U<G)E;G1&:6QE2&5A9&EN9TYO*2P@;G5M8F5R*"1P
M<F5C961I;F=#:&%P=&5R3&5V96PQ*2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T
M93X*"@H*"B`@("`\(2TM(&YE8V5S<V%R>2!A<R!A;F-H;W(@9F]R('1H92!C
M;VYT96YT('1A8FQE("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A
M=&4M:&5A9&EN9RUA;F-H;W(B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM"B`@("`@("`@
M0W5R<F5N=&QY('1H92!L:6YK('5S960@:6X@=&AE($]F9FEC92!834P@*&4N
M9RX@:6X@=&AE(&-O;G1E;G0@=&%B;&4@87,@)R,W+E-O;64E,C!%>&%M<&QE
M)3(P2&5A9&QI;F4E-T]U=&QI;F4G*0H@("`@("`@(&ES(&YO="!A('9A;&ED
M(%523"`H8VUP+B!B=6<@:60C(#$P,C,Q,2DN($YO(&9I;&4@9&5S=&EN871I
M;VX@:7,@<W!E8VEF:65D(&YO<B!E>&ES="!A;GD@86YC:&]R(&5L96UE;G0@
M9F]R('1H97-E"B`@("`@("`@;&EN:W,@:6X@=&AE($]F9FEC92!834PN"B`@
M("`@("`@2&5R92!W92!A<F4@8W)E871I;F<@86X@86YC:&]R('=I=&@@=&AE
M('-P86-E(&YO<FUA;&EZ960@=&5X="!O9B!T:&ES(&AE861E<B!A<R!P;W1E
M;G1I86P@:G5M<"!A9&1R97-S(&]F('1H92!C;VYT96YT('1A8FQE("TM/@H*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B/@H*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$9I;&5(96%D
M:6YG3F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)G970M;F5X="UC=7)R96YT+69I;&4M:&5A9&EN9RUN;R(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M9FEL92(@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*"B`@("`@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1E<W1297-U;'0B('-E;&5C=#TB
M)&-O;G1E;G1486)L94AE861I;F=S+VAE861I;F=;)&=L;V)A;$1O8W5M96YT
M4F5F5&]#=7)R96YT1FEL92`]($!F:6QE+75R;%U;;G5M8F5R*"1C=7)R96YT
M1FEL94AE861I;F=.;RE=(B\^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E
M<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM
M97-S86=E/DUA=&-H:6YG(&-H:6QD(&1O8W5M96YT(&AE861E<B!.;RX@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1C=7)R96YT1FEL94AE861I;F=.;R(O/CPO
M>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E
M/F%B<V]L=71E+6-H87!T97(M;&5V96PZ("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1T97-T4F5S=6QT+T!A8G-O;'5T92UC:&%P=&5R+6QE=F5L
M(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE
M<W-A9V4^96YC;V1E9%1I=&QE.B`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&5N8V]D960M=&ET;&4B+SX\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93YG;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4Z(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(B\^
M/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^*BHJ(#PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II
M9CX*"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M92(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D=&5S=%)E<W5L="]`86)S;VQU=&4M8VAA<'1E<BUL979E;"(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^*SPO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D
M=&5S=%)E<W5L="]`96YC;V1E9"UT:71L92(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM(%=H96X@=&AE(&-H
M87!T97(@:7,@:6X@=&AE(&=L;V)A;"!D;V-U;65N="!I='-E;&8@=&AE(&QI
M;FL@:&%S('1O(&)E(')E;&%T:79E("AE+F<N("-I;F1E>"D@82!A8G-O;'5T
M92!H<F5F(&1O97,@;F]T"B`@("`@("`@("`@("`@("`@("`@=V]R:R!W:71H
M('1H92!B<F]W<V5R+B!);B!C87-E(&]F(&-H87!T97(@:6X@=&AE(&=L;V)A
M;"!D;V-U;65N="P@=&AE(&]U='!U="!54DP@;V8@=&AE(&=L;V)A;"!D;V-U
M;65N="!W87,@=&%K96XN("TM/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)C=7)R96YT1FEL94AE861I;F=.;R(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UN97AT+6-U
M<G)E;G0M9FEL92UH96%D:6YG+6YO(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)F:6QE(B!S96QE8W0](B1C;VYT
M96YT5&%B;&554DPB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&5S=%)E<W5L
M="(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT+71A8FQE
M+6AE861I;F=S+VAE861I;F=;)&-O;G1E;G1486)L95523"`]($!F:6QE+75R
M;%U;;G5M8F5R*"1C=7)R96YT1FEL94AE861I;F=.;RE=(B\^"@H@("`@("`@
M("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y-871C:&EN9R!G;&]B86P@9&]C
M=6UE;G0@:&5A9&5R($YO+B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E
M;G1&:6QE2&5A9&EN9TYO(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^86)S;VQU=&4M8VAA<'1E<BUL979E;#H@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&5S=%)E<W5L="]`86)S;VQU=&4M
M8VAA<'1E<BUL979E;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IM97-S86=E/F5N8V]D9614:71L93H@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&5N8V]D960M=&ET
M;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;65S<V%G93YC;VYT96YT5&%B;&554DPZ("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1C;VYT96YT5&%B;&554DPB+SX\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93XJ*BH@/"]X<VPZ;65S
M<V%G93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1T97-T4F5S=6QT+T!A
M8G-O;'5T92UC:&%P=&5R+6QE=F5L(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#XK/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1T97-T4F5S=6QT+T!E;F-O
M9&5D+71I=&QE(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"@H*
M"CPA+2T*"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)T:71L92(@<V5L
M96-T/2)N;W)M86QI>F4M<W!A8V4H+BDB+SX*("`@("`@("`\(7Y^1$].)U0@
M5T]22R`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1I=&QE(B!S96QE8W0](FYO
M<FUA;&EZ92US<&%C92AD97-C96YD86YT.CIT97AT*"DI(B\^("`@("`@("!^
M?CX*("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&5S=%)E<W5L=',B
M('-E;&5C=#TB)&-O;G1E;G1486)L94AE861I;F=S+VAE861I;F=;)&=L;V)A
M;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92`]($!F:6QE+75R;%U;)'1I=&QE
M(#T@0'1I=&QE75MC=7)R96YT*"DO0'1E>'0Z;&5V96P@/2!`;&5V96Q=(B\^
M"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](C$@)FQT.R!C;W5N="@D
M=&5S=%)E<W5L=',I(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^("HJ*B!#055424]..B!-=6QT:7!L92!C:&%P=&5R(&AE861I;F=S('=I
M=&@@<VEM:6QA<B!N86UE<SH@/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^("HJ*B!4:71L93H@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1T:71L92(O/B!,979E;#H@/'AS;#IV86QU92UO9B!S96QE
M8W0](D!T97AT.FQE=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@
M("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](F5N8V]D9614:71L92(@<V5L96-T/2(D=&5S=%)E<W5L=',O0&5N
M8V]D960M=&ET;&4B+SX*("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E;F-O9&5D
M5&ET;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA
M='1R:6)U=&4@;F%M93TB;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1E;F-O9&5D5&ET;&4B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\(7Y^(&5V96X@=VAE;B!I="!I<R!N;W0@?GX^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W16YC;V1E9%1I=&QE
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\(7Y^('1H92!S<&%C92!H87,@=&\@8F4@;F]R;6%L
M:7IE9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H
M97)W:7-E(&%N(&EL;&5G86P@87)G=6UE;G0@97AC97!T:6]N('=I;&P@8F4@
M=&AR;W=N(&9O<B!85'Y^/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O9&5D(B!S
M96QE8W0](B1T:71L92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&YE=T5N
M8V]D9614:71L92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1E<W1297-U;'1S(B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V-O;G1E;G0M=&%B;&4M:&5A
M9&EN9W,O:&5A9&EN9ULD8V]N=&5N=%1A8FQE55),(#T@0&9I;&4M=7)L75LD
M=&ET;&4@/2!`=&ET;&5=6V-U<G)E;G0H*2]`=&5X=#IL979E;"`]($!L979E
M;%TB+SX*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB,2`F;'0[(&-O
M=6YT*"1T97-T4F5S=6QT<RDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;65S<V%G93X@*BHJ($-!551)3TXZ($UU;'1I<&QE(&-H87!T97(@:&5A9&EN
M9W,@=VET:"!S:6UI;&%R(&YA;65S.B`\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@*BHJ(%1I=&QE.B`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)'1I=&QE(B\^($QE=F5L.B`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB0'1E>'0Z;&5V96PB+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@*BHJ(#PO>'-L.FUE<W-A9V4^
M"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](F5N8V]D9614:71L92(@<V5L96-T/2(D=&5S
M=%)E<W5L=',O0&5N8V]D960M=&ET;&4B+SX*("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB)&5N8V]D9614:71L92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&5N
M8V]D9614:71L92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PA?GX@979E;B!W:&5N(&ET(&ES(&YO="!^?CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N97=%
M;F-O9&5D5&ET;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F5N8V]D92US=')I;F<B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PA?GX@=&AE('-P86-E(&AA<R!T
M;R!B92!N;W)M86QI>F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O=&AE<G=I<V4@86X@:6QL96=A;"!A<F=U;65N="!E>&-E<'1I
M;VX@=VEL;"!B92!T:')O=VX@9F]R(%A4?GX^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T97AT5&]"
M945N8V]D960B('-E;&5C=#TB)'1I=&QE(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA;64B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D;F5W16YC;V1E9%1I=&QE(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H*+2T^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@
M(#PA+2T@("`@0U)%051)3TX@3T8@02!#3TY414Y4(%1!0DQ%($Q)3DL@("`@
M+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ("TM/@H*"B`@("`\(2TM(&$@<W!E8VEA;"!B96AA=FEO<B!O9B!T
M97AT.F$*("`@("`@("`H8V%L;&5D(&9R;VT@=&AE("=T97AT.F$G('1E;7!L
M871E*2`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R96%T92UC;VYT
M96YT+71A8FQE+6QI;FLB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="@D;W5T<'5T5'EP92`]("=7
M34PG*2(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E
M9B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](G-T87)T
M<RUW:71H*$!X;&EN:SIH<F5F+"`G(R<I(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-O<G)E8W1(96%D
M:6YG(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V-O;G1E;G0M=&%B
M;&4M:&5A9&EN9W,O:&5A9&EN9UMC=7)R96YT*"DO0'AL:6YK.FAR968@/2!`
M8V]N=&5N="UT86)L92UI9%TB+SX*"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C;W)R96-T2&5A9&EN
M9R]`;W5T+69I;&4M=7)L(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/B,\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]R<F5C
M=$AE861I;F<O0&%B<V]L=71E+6-H87!T97(M;&5V96PB+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^*SPO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1C;W)R96-T2&5A9&EN9R]`96YC;V1E9"UT:71L92(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)C<F5A=&4M8V]M;6]N+6QI;FLB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L
M>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PA+2T@,D1/
M.B!C=7)R96YT;'D@;F\@5TU,('-U<'!O<G0*"B`@("`@("`@("`@("`@("`\
M(7Y^(&YO(&YE<W1E9"!P('1A9W,@:6X@=VUL,2XQ(&%L;&]W960@?GX^"B`@
M("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A<"UP
M87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^/'AS
M;#IV86QU92UO9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT
M96UP;&%T97,@<V5L96-T/2(N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ
M:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](BXB+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/B`@+2T^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H)/"$M+0H)("`@($-214%424].($]&($$@2$5,4$52(%9!4DE!0DQ%($%3
M(%=/4DM!4D]53D0@1D]2(%1(12!#3TY414Y4(%1!0DQ%(%5,4B!"54<*"@H@
M("`@("`@($%S(&YO('9A;&ED(%523"!F<F]M('1H92!C;VYT96YT('1A8FQE
M('1O('1H92!C:&EL9"!D;V-U;65N=',@97AI<W0@:6X@=&AE(&-O;G1E;G0@
M=&%B;&4L"B`@("`@("`@82!W;W)K+6%R;W5N9"!I<R!D;VYE.@H*("`@("`@
M("!&:7)S="!T=V\@:&5L<&5R('9A<FEA8FQE<R!A<F4@8F5I;F<@8W)E871E
M9"X*"B`@("`@("`@3VYE(&-O;G1A:6YI;F<@=&AE(&QI<W0@;V8@86QL(')E
M9F5R96YC97,@;V8@=&AE(&=L;V)A;"!D;V-U;65N=#H*("`@("`@("!C;VYT
M86EN9R!A;&P@=&AE:7(@=&ET;&4L"B`@("`@("`@9F]R(&5X86UP;&4Z"@H@
M("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I=&QE(#$B+SX*("`@
M("`@("`@(`D\8VAA<'1E<BUR968@=&ET;&4](F%4:71L92`R(B\^"B`@("`@
M("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,B\^"B`@("`@("`@
M("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,R\^"@H@("`@("`@(%1H
M92!O=&AE<B!C;VYT86EN:6YG(&%L;"!H96%D:6YG(&9R;VT@=&AE(&-H:6QD
M(&1O8W5M96YT<R!L:6YK960@9G)O;2!T:&4@9VQO8F%L(&1O8W5M96YT+@H@
M("`@("`@(%1H92!V87)I86)L92`G8VAI;&1R96Y(96%D:6YG<R<@8V]N=&%I
M;G,@=&AE:7(@=&ET;&4@86YD('1H92!N=6UB97(@;V8@<')E8V5D:6YG('-I
M;6EL87(@=&ET;&5S+`H@("`@("`@(&9O<B!E>&%M<&QE.@H*"B`@("`@("`@
M("`)/&-H:6QD(&9I;&4M=7)L/2)A55),(CX*("`@("`@("`@(`D)/&AE861I
M;F<@=&ET;&4](F%4:71L93$B(&QE=F5L/2(Q(CX*("`@("`@("`@(`D)/&AE
M861I;F<@=&ET;&4](F%4:71L93(B(&QE=F5L/2(R(CX*("`@("`@("`@(`D)
M/&AE861I;F<@=&ET;&4](F%4:71L93,B(&QE=F5L/2(Q(CX*("`@("`@("`@
M("`@/"]C:&EL9#X*"B`@("`@("`@1F]R(&5A8V@@8VAA<'1E<B!R969E<F5N
M8V4@9G)O;2!T:&4@8V]N=&5N="!T86)L92!T:&4*"B`@("`@("`@(&)Y(&5N
M8V]D:6YG('1H92!C:&%P=&5R(&YA;65S(&]F('1H92!C:&EL9"!D;V-U;65N
M="!W:71H('1H92!J879A(%523$5N8V]D97(@86YD"B`@("`@("`@=7-E('1H
M:7,@87,@82!P87)T(&]F(&$@;&EN:RX@1G5R=&AE<FUO<F4@9F]R(&%L;"!H
M96%D:6YG(&5L96UE;G1S(&$@96YC;V1E9"!A;F-H;W(@=VEL;"!B92!C<F5A
M=&5D(&9R;VT@=&AE(&AE861I;F<N"B`@("`@("`@3&%S="!T:&4@=V]R:V%R
M;W5N9"!P87)S97,@86QL(&-H:6QD<F5N(&1O8W5M96YT<R!F;W(@=&AI<R!A
M;FAO<BP@87,@=&AE<F4@:7,@;F\@9&ES=&EN8W1I;VX@;V8@9FEL97,@9G)O
M;2!T:&4@8V]N=&5N="!T86)L92!E;G1R:65S+@H*("`@("`@("!4:&4@;F5W
M(&%D9&5D(&YO9&4@<V5T('1O('1H92!C;VQL96-T961';&]B86Q$871A('9A
M<FEA8FQE(&-O;F-E<FEN9R!T:&4@8V]N=&5N="!T86)L92!I<R!W<FET=&5N
M(&%S"@H*"0D\8V]N=&5N="UT86)L92UH96%D:6YG<R!C;VYT96YT+71A8FQE
M+75R;#TB85523%]4;U1H94=E;F5R871E9$-O;G1E;G1486)L92(^"B`@("`@
M(`D)/&AE861I;F<@9FEL92UU<FP](F%&:6QE55),5&]4:&5'96YE<F%T961(
M96%D:6YG,2(@;&5V96P](C$B/@H@("`@("`)"3QH96%D:6YG(&9I;&4M=7)L
M/2)A1FEL95523%1O5&AE1V5N97)A=&5D2&5A9&EN9S(B(&QE=F5L/2(R(CX*
M("`@("`@"0D\:&5A9&EN9R!F:6QE+75R;#TB849I;&554DQ4;U1H94=E;F5R
M871E9$AE861I;F<Q(B!L979E;#TB,2(^"B`@("`@(`D)/&AE861I;F<@9FEL
M92UU<FP](F%&:6QE55),5&]4:&5'96YE<F%T961(96%D:6YG,B(@;&5V96P]
M(C(B/@H)"3PO8V]N=&5N="UT86)L92UH96%D:6YG<SX*"@H@("`@("`@(%!R
M96-O;F1I=&EO;G,Z"@D)5&AE(&-O<G)E8W0@<V5Q=65N8V4@;V8@8VAI;&0@
M9&]C=6UE;G1S(&%C8V]R9&EN9R!T;R!T:&4@0V]N=&5N="!486)L92!I<R!N
M96-E<W-A<GDL(&=R86YT960@8GD@=&AE(&]F9FEC92X*"2TM/@H)/'AS;#IT
M96UP;&%T92!N86UE/2)#<F5A=&4M:&5L<&5R+79A<FEA8FQE<RUF;W(M0V]N
M=&5N="U486)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B
M=6=-;V1E(CX\>'-L.FUE<W-A9V4^0W)E871I;VX@;V8@9VQO8F%L(&1O8W5M
M96YT(&AE;'!E<B!V87)I86)L92!F;W(@=&AE(&-O;G1E;G0@=&%B;&4N+BXN
M/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*"B`@("`@("`@/"$M+2!(97)E(&$@
M:&5L<&5R('9A<FEA8FQE(&]F('1H92!C;VYT96YT('1A8FQE(&ES(&-R96%T
M960L(&]F(&%L;"!C:&%P=&5R+7)E9F5R96YC97,@=VAI8V@@<&]I;G0@=&\@
M82!C:&EL9"!D;V-U;65N="X*("`@("`@("`@("`@(&%N("=C:&%P=&5R+7)E
M9B<@96QE;65N="!W:6QL(&)E(&-R96%T960L(&-O;G1A:6YG('1H96ER('1I
M=&QE(&%N9"!T:&4@;G5M8F5R(&]F('!R96-E9&EN9R!S:6UI;&%R('1I=&QE
M<RP*("`@("`@("`@("`@(&9O<B!E>&%M<&QE.@H*("`@("`@("`@("`@("`)
M/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,2(O/@H@("`@("`@("`@("`@
M(`D\8VAA<'1E<BUR968@=&ET;&4](F%4:71L92`R(B\^"B`@("`@("`@("`@
M("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I=&QE(#(B+SX*("`@("`@("`@
M("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,R(O/@H@("`@("`@
M("`@("`M+3X*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-H87!T97)2
M969S+5)41B(^"B`@("`@("`@("`@(#PA+2T@)R\J+R<@87,@=&AE(&9L870@
M86YD('1H92!Z:7!P960@6$U,(&9I;&4@9F]R;6%T(&AA=F4@9&EF9F5R96YT
M(')O;W0@96QE;65N=',@+2T^"B`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@
M<V5L96-T/2(O*B]O9F9I8V4Z8F]D>2]T97AT.G1A8FQE+6]F+6-O;G1E;G0O
M=&5X=#II;F1E>"UB;V1Y+W1E>'0Z<"]T97AT.F$B/@H@("`@("`@("`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)C=7)R96YT5&ET;&4B('-E;&5C=#TB
M;F]R;6%L:7IE+7-P86-E*'-T<FEN9R@N*2DB+SX*("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)C:&%P=&5R+7)E9B(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB=&ET;&4B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E
M;G14:71L92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C
M;VYT96YT+71A8FQE+6ED(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@
M("`\+WAS;#IV87)I86)L93X*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E
M8G5G36]D92(^/'AS;#IM97-S86=E/D9I;FES:&5D('1H92!#<F5A=&EO;B!O
M9B!G;&]B86P@9&]C=6UE;G0@:&5L<&5R('9A<FEA8FQE(&9O<B!T:&4@8V]N
M=&5N="!T86)L92$\+WAS;#IM97-S86=E/CPO>'-L.FEF/@H*"@H*("`@("`@
M("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D-R
M96%T:6]N(&]F(&=L;V)A;"!D;V-U;65N="!H96QP97(@=F%R:6%B;&4@9F]R
M('1H92!C:&EL9"!D;V-U;65N=',N+BXN/"]X<VPZ;65S<V%G93X\+WAS;#II
M9CX*("`@("`@("`\(2TM($AE<F4@82!H96QP97(@=F%R:6%B;&4@;V8@8W)E
M871E9"!F<F]M('1H92!C:&EL9')E;B!D;V-U;65N=',N"B`@("`@("`@("`@
M("!#;VYT86EN9R!A;&P@:&5A9&EN9R!E;&5M96YT<R!F<F]M('1H92!C:&EL
M9"!D;V-U;65N=',N(%-O;64@;W(@86QL(&]F('1H96T@87)E"B`@("`@("`@
M("`@("!C:&%P=&5R<R!R969E<F5N8V5D(&)Y('1H92!';&]B86P@1&]C=6UE
M;G0N"B`@("`@("`@("`@("!4:&4@=F%R:6%B;&4@8V]N=&%I;G,@=&AE:7(@
M=&ET;&4L('1H92!L979E;"!O9B!T:&4@:&5A9&EN9R!A;F0@=&AE(&9I;&4@
M55),(&]F('1H92!C:&EL9"P*("`@("`@("`@("`@(&9O<B!E>&%M<&QE.@H*
M("`@("`@("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L93$B(&QE=F5L/2(Q
M(B!F:6QE+75R;#TB85523#$B/@H@("`@("`@("`@"0D\:&5A9&EN9R!T:71L
M93TB851I=&QE,B(@;&5V96P](C(B(&9I;&4M=7)L/2)A55),,2(^"B`@("`@
M("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4S(B!L979E;#TB,2(@9FEL
M92UU<FP](F%54DPQ(CX*("`@("`@("`@(`D)/&AE861I;F<@=&ET;&4](F%4
M:71L930B(&QE=F5L/2(Q(B!F:6QE+75R;#TB85523#(B/@H@("`@("`@("`@
M"0D\:&5A9&EN9R!T:71L93TB851I=&QE-2(@;&5V96P](C(B(&9I;&4M=7)L
M/2)A55),,B(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4R
M(B!L979E;#TB,R(@9FEL92UU<FP](F%54DPR(CX*("`@("`@("`@(`D)/&AE
M861I;F<@=&ET;&4](F%4:71L938B(&QE=F5L/2(S(B!F:6QE+75R;#TB8552
M3#(B/@H@("`@("`@("`@("`@("`@/&AE861I;F<M8V]U;G0^-SPO:&5A9&EN
M9RUC;W5N=#X*("`@("`@("`@("`@+2T^"B`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)C:&EL9')E;DAE861I;F=S+5)41B(^"B`@("`@("`@("`@(#PA
M+2T@86QL(&AE861E<G,@9G)O;2!C:&EL9')E;B!D;V-U;65N=',@=VEL;"!B
M92!A9&1E9"`M+3X*("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@
M<V5L96-T/2(O*B]O9F9I8V4Z8F]D>2]T97AT.G-E8W1I;VXB(&UO9&4](F-R
M96%T:6]N+6]F+79A<FEA8FQE(B\^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^
M"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S
M<V%G93Y&:6YI<VAE9"!T:&4@0W)E871I;VX@;V8@9VQO8F%L(&1O8W5M96YT
M(&AE;'!E<B!V87)I86)L92!F;W(@=&AE(&-H:6QD(&1O8W5M96YT<R$\+WAS
M;#IM97-S86=E/CPO>'-L.FEF/@H*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H
M)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](D-R96%T92UG;&]B86PM=F%R:6%B;&4M9F]R+4-O;G1E
M;G0M5&%B;&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C:&%P=&5R4F5F<R(@("`@('-E;&5C=#TB>'0Z;F]D92US970H
M)&-H87!T97)2969S+5)41BDB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8VAI;&1R96Y(96%D:6YG<R(@("`@('-E;&5C
M=#TB>'0Z;F]D92US970H)&-H:6QD<F5N2&5A9&EN9W,M4E1&*2(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F9U;F-T:6]N+6%V86EL86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)#<F5A=&4M9VQO
M8F%L+79A<FEA8FQE+69O<BU#;VYT96YT+51A8FQE(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B("`@
M("!S96QE8W0](GAA;&%N.FYO9&5S970H)&-H87!T97)2969S+5)41BDB+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAI
M;&1R96Y(96%D:6YG<R(@("`@('-E;&5C=#TB>&%L86XZ;F]D97-E="@D8VAI
M;&1R96Y(96%D:6YG<RU25$8I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB0W)E871E+6=L;V)A;"UV87)I86)L
M92UF;W(M0V]N=&5N="U486)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C:&%P=&5R4F5F<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8VAI
M;&1R96Y(96%D:6YG<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H*"B`@("`@("`@/'AS;#II9B!T97-T/2(D
M:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`\(2TM(&AE;'!E<B!V87)I86)L
M92!C;VQL96-T:6YG(&%L;"!H96%D:6YG<R!F<F]M('1H92!G;&]B86P@9&]C
M=6UE;G0@9FEL92!C:&EL9')E;BTM/@H@("`@("`@("`@("`\>'-L.F9O<BUE
M86-H('-E;&5C=#TB)&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9R(^"B`@("`@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^(R`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](G!O<VET:6]N*"DB+SX\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/FQE=F5L.B`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`;&5V96PB+SX\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/G1I=&QE.B`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/F5N8V]D960M=&ET;&4Z(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`96YC;V1E9"UT:71L92(O/CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^9FEL92UU<FPZ
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!F:6QE+75R;"(O/CPO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^:&5A9&5R
M+6YO.B`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!H96%D97(M;F\B+SX\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/BHJ
M/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93XJ*CPO>'-L.FUE<W-A9V4^"B`@("`@
M("`@("`@(#QX<VPZ;65S<V%G93XJ*CPO>'-L.FUE<W-A9V4^"@H@("`@("`@
M("`@("`\(2TM(&AE;'!E<B!V87)I86)L92!C;VQL96-T:6YG(&%L;"!H96%D
M:6YG(')E9F5R96YC97,@9G)O;2!T:&4@8V]N=&5N="!T86)L92!O9B!T:&4@
M=&AE(&=L;V)A;"!D;V-U;65N="`M+3X*("`@("`@("`@("`@/'AS;#IM97-S
M86=E/F-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9RUC;W5N=#H@/'AS;#IV86QU
M92UO9B!S96QE8W0](B1C:&EL9')E;DAE861I;F=S+VAE861I;F<M8V]U;G0B
M+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E
M;&5C=#TB)&-H87!T97)2969S+V-H87!T97(M<F5F(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93XC(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)P;W-I
M=&EO;B@I(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX<VPZ
M;65S<V%G93YT:71L93H@/'AS;#IV86QU92UO9B!S96QE8W0](D!T:71L92(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^
M*BH\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*
M("`@("`@("`\+WAS;#II9CX*"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S
M>&=H96QP97(Z<V5T+6AE861I;F<M;F\G*2(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-X9VAE;'!E<CIS970M:&5A9&EN
M9RUN;R@Q*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)S>&=H96QP97(Z<V5T+6-U<G)E;G0M8VAI;&0M;F\H,2DB+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG
M:&5L<&5R.G-E="UC=7)R96YT+6-H:6QD+75R;"AS=')I;F<H)&-H:6QD<F5N
M2&5A9&EN9W,O:&5A9&EN9R]`9FEL92UU<FPI*2(O/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3
M>&=#:&EL9%1R86YS9F]R;65R+G-E=$AE861I;F=.;R<I(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N
M+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971(96%D
M:6YG3F\H,2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI
M;&14<F%N<V9O<FUE<BYS971#=7)R96YT0VAI;&1.;R@Q*2(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.F-O;2YS
M=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+G-E=$-U
M<G)E;G1#:&EL9%5R;"AS=')I;F<H)&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN
M9R]`9FEL92UU<BDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E
M8G5G36]D92(^/'AS;#IM97-S86=E/D-R96%T:6YG(&=L;V)A;"!D;V-U;65N
M="!V87)I86)L92!F;W(@8VAA<'1E<B!R96QA=&EO;G,N+BXN/"]X<VPZ;65S
M<V%G93X\+WAS;#II9CX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-O
M;G1E;G1486)L94AE861I;F=S1VQO8F%L1&%T82U25$8B/@H@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB8V]N=&5N="UT86)L92UH96%D:6YG<R(^
M"B`@("`@("`@("`@("`@("`\(2TM(&%L;"!H96%D:6YG<R!A<F4@;&EN:V5D
M(&9R;VT@=&AE(&-U<G)E;G0@9VQO8F%L(&1O8W5M96YT(&EN<'5T(&9I;&4@
M+2T^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VYT
M96YT+71A8FQE+75R;"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](B1C;VYT96YT5&%B;&554DPB+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@("`\(2TM(&AA
M9"!T;R!U<V4@82!F;W(@;&]O<"P@87,@82!R96-U<G-I;VX@96YD<R!W:71H
M(&%N('-T86-K;W9E<F9L;W<@97AC97!T:6]N(&%F=&5R(&%B;W5T(#8P,"!R
M96-U<G-I=F4@8V%L;',@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=S>&=H96QP97(Z9V5T+6AE861I;F<M;F\G*2(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB
M)&-H87!T97)2969S+V-H87!T97(M<F5F(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S96%R8VA(96%D
M:6YG26Y#:&EL9$1O8W5M96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B("`@
M("`@("`@<V5L96-T/2(D8VAA<'1E<E)E9G,B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAI;&1R
M96Y(96%D:6YG<R(@("`@<V5L96-T/2(D8VAI;&1R96Y(96%D:6YG<R(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C=7)R96YT0VAA<'1E<E)E9DYO(B!S96QE8W0](G!O<VET:6]N
M*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8W5R<F5N=$AE861I;F=.;R(@("`@<V5L96-T/2)S
M>&=H96QP97(Z9V5T+6AE861I;F<M;F\H*2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT
M0VAI;&154DPB("`@("!S96QE8W0](G-X9VAE;'!E<CIG970M8W5R<F5N="UC
M:&EL9"UU<FPH*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT0VAI;&1.;R(@("`@("!S
M96QE8W0](G-X9VAE;'!E<CIG970M8W5R<F5N="UC:&EL9"UN;R@I(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A
M.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R
M+F=E=$AE861I;F=.;R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ9F]R+65A8V@@<V5L96-T/2(D8VAA<'1E<E)E9G,O8VAA<'1E<BUR968B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](G-E87)C:$AE861I;F=);D-H:6QD1&]C=6UE;G0B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C:&%P=&5R4F5F<R(@("`@("`@("!S96QE8W0](B1C:&%P=&5R4F5F
M<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C:&EL9')E;DAE861I;F=S(B`@("!S96QE8W0](B1C
M:&EL9')E;DAE861I;F=S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#:&%P=&5R4F5F
M3F\B('-E;&5C=#TB<&]S:71I;VXH*2(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT2&5A
M9&EN9TYO(B`@("!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L
M<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T2&5A9&EN9TYO*"DB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8W5R<F5N=$-H:6QD55),(B`@("`@<V5L96-T/2)J879A.F-O;2YS
M=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=$-U
M<G)E;G1#:&EL9%5R;"@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#:&EL9$YO(B`@
M("`@('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG
M0VAI;&14<F%N<V9O<FUE<BYG971#=7)R96YT0VAI;&1.;R@I(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@("`@
M("`@("`@/"$M+2!A9&1I;F<@=&AE(&%L<F5A9'D@97AI<VET:6YG(&=L;V)A
M;"!D871A(&5N=FER;VYM96YT("TM/@H@("`@("`@("`@("`\>'-L.F-O<'DM
M;V8@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#PO
M>'-L.G9A<FEA8FQE/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-
M;V1E(CX\>'-L.FUE<W-A9V4^1FEN:7-H960@9VQO8F%L(&1O8W5M96YT('9A
M<FEA8FQE(&9O<B!C:&%P=&5R(')E;&%T:6]N<R$\+WAS;#IM97-S86=E/CPO
M>'-L.FEF/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G>'0Z;F]D92US970G
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M<W1A<G0M<V5L9BUA;F0M8VAI;&1R96XM=')A;G-F;W)M871I;VXB/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B`@("`@("!S96QE8W0](GAT.FYO9&4M<V5T*"1C;VYT
M96YT5&%B;&5(96%D:6YG<T=L;V)A;$1A=&$M4E1&*2(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V
M86EL86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="US96QF+6%N9"UC:&EL9')E
M;BUT<F%N<V9O<FUA=&EO;B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E
M;&5C=#TB>&%L86XZ;F]D97-E="@D8V]N=&5N=%1A8FQE2&5A9&EN9W-';&]B
M86Q$871A+5)41BDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA
M=&4@;F%M93TB<V5A<F-H2&5A9&EN9TEN0VAI;&1$;V-U;65N="(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C:&%P=&5R4F5F<R(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8VAI;&1R96Y(96%D:6YG<R(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8W5R<F5N=$-H87!T97)2969.;R(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8W5R<F5N=$AE861I;F=.;R(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD55),(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)C=7)R96YT0VAI;&1.;R(O/@H*"B`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)C=7)R96YT0VAA<'1E<E)E9B(@("`@("!S
M96QE8W0](B1C:&%P=&5R4F5F<R]C:&%P=&5R+7)E9ELD8W5R<F5N=$-H87!T
M97)2969.;UTB+SX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E
M;G1#:&%P=&5R240B("`@("`@('-E;&5C=#TB)&-U<G)E;G1#:&%P=&5R4F5F
M+T!C;VYT96YT+71A8FQE+6ED(B\^"B`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)C=7)R96YT0VAA<'1E<E1I=&QE(B`@("!S96QE8W0](B1C=7)R96YT
M0VAA<'1E<E)E9B]`=&ET;&4B+SX*"B`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)C=7)R96YT0VAI;&1(96%D:6YG(B`@("!S96QE8W0](B1C:&EL9')E
M;DAE861I;F=S+VAE861I;F=;)&-U<G)E;G1(96%D:6YG3F]=(B\^"B`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)H96%D:6YG5&ET;&4B("`@("`@("`@
M("!S96QE8W0](B1C=7)R96YT0VAI;&1(96%D:6YG+T!T:71L92(O/@H@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB:&5A9&EN9TQE=F5L(B`@("`@("`@
M("`@<V5L96-T/2(D8W5R<F5N=$-H:6QD2&5A9&EN9R]`;&5V96PB+SX*("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FAE861I;F=.;R(@("`@("`@("`@
M("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL9$AE861I;F<O0&AE861E<BUN;R(O
M/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W0VAI;&154DPB("`@
M("`@("`@("`@<V5L96-T/2(D8W5R<F5N=$-H:6QD2&5A9&EN9R]`9FEL92UU
M<FPB+SX*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^*BHJ(&YE=R!H96%D:6YG(#PO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC=7)R96YT0VAA
M<'1E<DE$.B`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1#:&%P
M=&5R240B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^8W5R<F5N=$-H87!T97)4:71L93H@/'AS;#IV86QU92UO9B!S96QE8W0]
M(B1C=7)R96YT0VAA<'1E<E1I=&QE(B\^/"]X<VPZ;65S<V%G93X*("`@("`@
M("`@("`@/'AS;#IM97-S86=E/F-U<G)E;G1#:&%P=&5R240Z("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H87!T97))1"(O/CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC=7)R96YT2&5A9&EN
M9TYO.B`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1(96%D:6YG
M3F\B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^
M:&5A9&EN9U1I=&QE.B`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1H
M96%D:6YG5&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L
M.FUE<W-A9V4^:&5A9&EN9TQE=F5L.B`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1H96%D:6YG3&5V96PB+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`\>'-L.FUE<W-A9V4^:&5A9&EN9TYO.B`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1H96%D:6YG3F\B+SX\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^;F5W0VAI;&154DPZ("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1N97=#:&EL9%523"(O/CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB;W5T1FEL95523"(^"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=6)S=')I;F<M
M8F5F;W)E*"1N97=#:&EL9%523"PG+GAM;"<I(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*'-U8G-T<FEN9RUB
M969O<F4H)&YE=T-H:6QD55),+"<N>&UL)RDL)RYH=&TG*2(O/@H@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](G-U8G-T<FEN9RUB969O<F4H)&YE=T-H:6QD55),+"<N<W@G
M*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(F-O;F-A="AS=6)S=')I;F<M8F5F;W)E*"1N97=#:&EL9%523"PG+G-X)RDL
M)RYH=&TG*2(O/@H@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#IV87)I86)L93X*
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FES0VAA<'1E<DAE861I;F<B
M('-E;&5C=#TB)&AE861I;F=4:71L92`]("1C=7)R96YT0VAA<'1E<E1I=&QE
M(B\^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)I<TYE=T9I;&4B('-E
M;&5C=#TB<W1R:6YG*"1N97=#:&EL9%523"D@(3T@<W1R:6YG*"1C=7)R96YT
M0VAI;&154DPI(B\^"@H*"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES3F5W
M1FEL92(^"B`@("`@("`@("`@(#PA+2T@<F5S970@;V8@=&AE(&%L<F5A9'D@
M8V]L;&5C=&5D(&-H:6QD(&AE861E<G,@+2T^"B`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)C86QC+6-H87!T97(M;G5M8F5R<R(^"B`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQE=F5L(B!S
M96QE8W0](C`B+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`\+WAS;#II9CX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F%B<V]L=71E0VAA<'1E<DQE=F5L(CX*("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F-A;&,M8VAA<'1E<BUN=6UB97)S(CX*("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;&5V96PB('-E;&5C
M=#TB;G5M8F5R*"1H96%D:6YG3&5V96PI(B\^"B`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H*("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB:&5A9&EN9R(^"B`@("`@("`@("`@
M(#PA+2T@;F5C97-S87)Y('1O(&%S($E$(&9R;VT@=&AE(&-O;G1E;G0@=&%B
M;&4@=&\@9V5T('1H92!C;W)R96-T(&AE861I;F<@96QE;65N="`H=&AE(&)U
M9V=Y(%523"!U<V5D(&%S($E$*2TM/@H@("`@("`@("`@("`\>'-L.F%T=')I
M8G5T92!N86UE/2)C;VYT96YT+71A8FQE+6ED(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2(D:7-#:&%P=&5R2&5A9&EN9R(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H87!T97))1"(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#YO;FQY(&$@:&5A9&EN9RP@8G5T(&YO="!A(&-H87!T
M97(\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@
M("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\(2TM(&YO(&]F('1H
M92!U<V5D(&-H:6QD+"!N96-E<W-A<GD@9F]R('%U:6-K(&9I;F1I;F<@;V8@
M8VAA<'1E<G,@;V8@;F5X="!F:6QE("`M+3X*("`@("`@("`@("`@/'AS;#IA
M='1R:6)U=&4@;F%M93TB8VAI;&0M9&]C=6UE;G0M;F\B/@H@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](B1I<TYE=T9I;&4B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1#:&EL9$YO("L@,2(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H:6QD3F\B+SX*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@/"$M+2!T:&4@55),(&]F('1H92!C:&EL9"!D
M;V-U;65N="!S;W5R8V4L(&-O;G1A:6YI;F<@=&AE(&AE861I;F<@+2T^"B`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F9I;&4M=7)L(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;F5W0VAI;&15
M4DPB+SX*("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)O=70M9FEL92UU<FPB/@H@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1O=71&:6QE55),(B\^
M"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB;&5V96PB/@H@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1H96%D:6YG3&5V96PB+SX*("`@("`@("`@
M("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)T:71L92(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)&AE861I;F=4:71L92(O/@H@("`@("`@("`@("`\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F5N
M8V]D960M=&ET;&4B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1C=7)R96YT0VAI;&1(96%D:6YG+T!E;F-O9&5D+71I=&QE(B\^
M"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB86)S;VQU=&4M8VAA<'1E<BUL979E;"(^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&%B<V]L=71E
M0VAA<'1E<DQE=F5L(B\^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*
M("`@("`@("`\+WAS;#IE;&5M96YT/@H*"B`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D8VAI;&1R96Y(96%D:6YG
M<R]H96%D:6YG+6-O=6YT("$]("1C=7)R96YT2&5A9&EN9TYO(CX*("`@("`@
M("`@("`@("`@(#PA+2T@<')O8V5D92!A<R!L;VYG('1H92!L:7-T(&]F(&-H
M:6QD<F5N(&ES;B=N="!W;W)K960@=&AR;W5G:"`M+3X*("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(D:7-#:&%P=&5R2&5A9&EN9R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@9VQO8F%L('9A<FEA8FQE<R!H879E('1O(&)E('-E="P@
M<V\@=&AE(&9O<BUE86-H(&QO;W`@8V%N(&%C8V5S<R!T:&5M("TM/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I
M;&%B;&4H)W-X9VAE;'!E<CIS970M:&5A9&EN9RUN;R<I(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M<WAG:&5L<&5R.G-E="UH96%D:6YG+6YO*"1C=7)R96YT2&5A9&EN9TYO("L@
M,2DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF
M('1E<W0](B1I<TYE=T9I;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.G-E
M="UC=7)R96YT+6-H:6QD+6YO*"1C=7)R96YT0VAI;&1.;R`K(#$I(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)S>&=H96QP97(Z<V5T+6-U<G)E;G0M8VAI;&0M=7)L*'-T
M<FEN9R@D;F5W0VAI;&154DPI*2(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A.F-O;2YS
M=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+G-E=$AE
M861I;F=.;R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH
M96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971(96%D:6YG3F\H)&-U<G)E
M;G1(96%D:6YG3F\@*R`Q*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES3F5W1FEL92(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS
M9F]R;65R+G-E=$-U<G)E;G1#:&EL9$YO*"1C=7)R96YT0VAI;&1.;R`K(#$I
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E
M<BY3>&=#:&EL9%1R86YS9F]R;65R+G-E=$-U<G)E;G1#:&EL9%5R;"@D;F5W
M0VAI;&154DPI(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"$M+2!N;W0@82!C:&%P=&5R(&AE861I;F<L(&-A;&P@:71S96QF('5N=&EL
M(&$@8VAA<'1E<B!R968@:7,@9F]U;F0@;W(@=&AE(&5N9"!O9B!H96%D:6YG
M<R!I<R!R96%C:&5D("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB<V5A<F-H2&5A9&EN9TEN0VAI;&1$;V-U
M;65N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B("`@("`@("`@<V5L96-T/2(D8VAA
M<'1E<E)E9G,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C:&EL9')E;DAE861I;F=S(B`@("!S96QE8W0]
M(B1C:&EL9')E;DAE861I;F=S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H87!T97)2969.
M;R(@<V5L96-T/2(D8W5R<F5N=$-H87!T97)2969.;R(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E
M;G1(96%D:6YG3F\B("`@('-E;&5C=#TB)&-U<G)E;G1(96%D:6YG3F\@*R`Q
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8W5R<F5N=$-H:6QD55),(B`@("`@<V5L96-T/2(D8W5R<F5N
M=$-H:6QD55),(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD3F\B("`@("`@<V5L96-T
M/2(D8W5R<F5N=$-H:6QD3F\B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO
M9&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y!;&P@8VAI
M;&0@9&]C=6UE;G1S(&AA=F4@8F5E;B!W86QK960@=&AR;W5G:"!W:71H;W5T
M(&9I;F1I;F<@=&AE(&-H87!T97(@;F%M92$\+WAS;#IM97-S86=E/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@("`@("`@8VAI;&1R96Y(
M96%D:6YG<R]H96%D:6YG+6-O=6YT.B`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9RUC;W5N="(O/CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/B`@("`@
M("!C=7)R96YT2&5A9&EN9TYO.B`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D8W5R<F5N=$AE861I;F=.;R(O/CPO>'-L.FUE<W-A
M9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"@H*"@D\(2TM($-H87!T97)S(&9R;VT@=&AE($-O;G1E
M;G0@5&%B;&4@:&%V92!C=7)R96YT;'D@;F\@86YC:&]R('1O(&-H:6QD(&1O
M8W5M96YT<R!I;B!/3V\@6$U,+@H)"2!!<R!S;VQU=&EO;BP@=VAE;F5V97(@
M82!A(&=L;V)A;"!D;V-U;65N="`@979E<GD@:&5A9&5R(&]F('1H92!(5$U,
M(&]U='!U="!G971S(&=E="=S(&%N(&%N8VAO<B!I;B!T:&4@5&AE<F5F;W)E
M+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F5N8V]D92US=')I;F<B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB96YC;V1I;F<B('-E;&5C=#TB)U54
M1BTX)R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O
M9&5D(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=U<FQE;F-O9&5R.F5N
M8V]D92<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)U<FQE;F-O9&5R.F5N8V]D92AN;W)M86QI>F4M<W!A8V4H)'1E>'14;T)E
M16YC;V1E9"DL)&5N8V]D:6YG*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=J879A.FIA=F$N;F5T+E523$5N8V]D97(N96YC;V1E)RDB/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z:F%V82YN
M970N55),16YC;V1E<BYE;F-O9&4H<W1R:6YG*&YO<FUA;&EZ92US<&%C92@D
M=&5X=%1O0F5%;F-O9&5D*2DL<W1R:6YG*"1E;F-O9&EN9RDI(B\^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@
M+2T^"B`@("`\(2TM("HJ*B`@5%)!3E-&3U)-051)3TX@3T8@04Q,($-(24Q$
M($1/0U5-14Y44R!/1B!42$4@1TQ/0D%,($1/0U5-14Y44R!"62!54TE.1R!!
M($585$523D%,($A%3%!%4B!#3$%34R`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*B`M+3X*"@H)/"$M+2!A(&YE=R!E;&5M96YT("=C;VYT96YT
M5&%B;&5(96%D:6YG<R<@=VEL;"!B92!A9&1E9"!T;R!T:&4@:&5L<&5R('9A
M<FEA8FQE('1H92!F:7)S="!T:6UE(&$@8VAI;&0@=VEL;"!B92!T<F%N<V9O
M<FUE9"`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB=')A;G-F;W)M+6=L
M;V)A;"UD;V-U;65N="UA;F0M8VAI;&1R96XB/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82]C;VYT96YT+71A8FQE+6AE861I;F=S(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="UC:&EL
M9"UT<F%N<V9O<FUA=&EO;B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"@D@("`@("`@("`@("`\(2TM(%1H
M92!N96-E<W-A<GD@875X:6QI87)Y('9A<FEA8FQE(&AA<VXG="!B=6EL9"!Y
M970N"@D@("`@("`@("`@("!4:&ES('9A<FEA8FQE(&=O;FYA('-T;W)E(&%L
M;"!H96%D97)S("AW:71H(&-H87!T97(@;G5M8F5R<RD@86YD('1H92!54DP@
M;V8@=&AE:7(@9FEL97,@+2T^"@H@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](D-R96%T92UH96QP97(M=F%R:6%B;&5S+69O<BU#
M;VYT96YT+51A8FQE(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H)
M/'AS;#IT96UP;&%T92!N86UE/2)S=&%R="US96QF+6%N9"UC:&EL9')E;BUT
M<F%N<V9O<FUA=&EO;B(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES
M1&5B=6=-;V1E(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F1E8G5G+6-O;G1E;G0M=&%B;&4M:&5A9&EN9W,M=F%R:6%B;&4B/@H@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@
M(#QX<VPZ;65S<V%G93Y087)S:6YG('1H92!G;&]B86P@9&]C=6UE;G0N+BX\
M+WAS;#IM97-S86=E/@H@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`\>'-L
M.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM
M97-S86=E/E!A<G-I;F<@=&AE(&-H:6QD(&1O8W5M96YT<RXN+CPO>'-L.FUE
M<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G-T87)T+6-H:6QD+71R86YS9F]R;6%T:6]N(CX*("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H*"3PO>'-L.G1E;7!L871E/@H*"@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TB<W1A<G0M8VAI;&0M=')A;G-F;W)M871I;VXB/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM
M97-S86=E/E-T87)T:6YG('1H92!C:&EL9"!T<F%N<V9O<FUA=&EO;G,N+BX\
M+WAS;#IM97-S86=E/CPO>'-L.FEF/@H*("`@("`@("`\(2TM($%S('1H92!C
M:&EL9',@;V8@82!G;&]B86P@9&]C=6UE;G0@*'=I=&@@<W5F9FEX("YS>&<I
M(&1O(&YO="!K;F]W(&%N>71H:6YG(&%B;W5T('1H96ER(&=L;V)A;"!P87)E
M;G0L"B`@("`@("`@("`@('1H92!T<F%N<V9O<FUA=&EO;B!O9B!G;&]B86P@
M9&]C=6UE;G1S(&-H:6QD<F5N(&AA=F4@=&\@8F4@9&]N92!I;7!L:7II="X*
M("`@("`@("`@("`@3W1H97)W:7-E('1H92!C:&%P=&5R(&YU;6)E<B!O9B!T
M:&4@8VAI;&1R96X@=VEL;"!A;'=A>7,@<W1A<G0@=VET:"!Z97)O+"!A<R!T
M:&5Y(&1O(&YO="!K;F]W(&%N>71H:6YG(&%B;W5T('1H90H@("`@("`@("`@
M("!P<F]C961I;F<@8VAA<'1E<G,N"B`@("`@("`@("`@($9U<G1H97)M;W)E
M+"!T:&5Y(&1O;B=T(&AA=F4@86YY(&QI;FMS(&%B;W5T('!R96-E961I;F<@
M86YD(&9O;&QO=VEN9R!D;V-U;65N=',@86YD(&YO(&QI;FMI;F<@9F]R('5S
M86)I;&ET>2!R96%S;VYS"B`@("`@("`@("`@(&-O=6QD(&)E(&1O;F4N(%1H
M97)E9F]R92!T:&4@8VAI;&1R96X@:&%V92!T;R!B92!T<F%N<V9O<FUE9"!D
M=7)I;F<@=&AE('1R86YS9F]R;6%T:6]N(&]F(&$@9VQO8F%L("AS>&<I(&1O
M8W5M96YT("TM/@H)"3QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT86)L92UH
M96%D:6YG<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/D-O
M;G1E;G1A8FQE(&1A=&$@97AI<W1S(&%S(&=L;V)A;"!D871A(3PO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IM97-S86=E/DYO($-O;G1E;G1A8FQE(&=L;V)A;"!D871A(&5X:7-T<R$\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ:68^
M"@H@("`@("`@(#PA+2T@8W5R<F5N=&QY('1H:7,@9G5N8W1I;VX@;VYL>2!W
M;W)K<R!W:71H(&YO9&4M<V5T<R!F<F]M(%A4("TM/@H@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM
M879A:6QA8FQE*"=S>&=H96QP97(Z=')A;G-F;W)M+6-H:6QD<F5N)RDB/@H@
M("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z=')A;G-F;W)M
M+6-H:6QD<F5N*"`D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT+71A8FQE
M+6AE861I;F=S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<H
M)&IA<F5D4F]O=%523"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M<FEN9R@D86)S;VQU=&53;W5R8V5$:7)2968I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')I;F<H)&]P=&EO;F%L55),4W5F9FEX*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R:6YG*"1D<&DI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=')I;F<H)&]U='!U=%1Y<&4I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:7-$96)U9TUO9&4I(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M(#QX<VPZ;65S<V%G93Y*879A(&UE=&AO9"!T<F%N<V9O<FU#:&EL9')E;B!T
M;R!T<F%N<V9O<FT@86QL(&-H:6QD<F5N(&]F(&$@9VQO8F%L(&1O8W5M96YT
M(&-O=6QD(&YO="!B92!F;W5N9"X@0F4@<W5R92!T;R!U<V4@=&AE(%A4('!R
M;V-E<W-O<BX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ("!#<F5A=&EO;B!O9B!H96QP97(@
M=F%R:6%B;&4@;V8@=&AE(&AE861I;F=S(&]F(&%L;"!C:&EL9')E;B!D;V-U
M;65N=',@("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB
M+RHO;V9F:6-E.F)O9'DO=&5X=#IS96-T:6]N(B!M;V1E/2)C<F5A=&EO;BUO
M9BUV87)I86)L92(^"B`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F=E=$-H:6QD4F]O=$YO9&4B+SX*"B`@("`@("`@/"$M+2!A9G1E<B!T:&4@
M;&%S="!C:&EL9"!D;V-U;65N="!T:&4@9VQO8F%L(&1O8W5M96YT('=I;&P@
M8F4@<&%R<V5D("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB<&]S:71I;VXH
M*2`](&QA<W0H*2(^"B`@("`@("`@("`@(#PA+2T@<V5A<F-H('1H92!G;&]B
M86P@9&]C=6UE;G0@869T97(@86QL(&-H:6QD(&1O8W5M96YT<R!H879E(&)E
M96X@<V5A<F-H960*"D]$2R!0051#2"!.3R!)3D1%6"!%3$5-14Y4(%=!3E1%
M1"`A(2`M(&YU;&P@<&]I;G1E<B!E>&-E<'1I;VX*("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F=E=%!R979I;W5S2&5A9&5R3F\B/@H@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F9I;&554DPB
M("`@("`@("`@("`@("`@("`@<V5L96-T/2(D8V]N=&5N=%1A8FQE55),(B\^
M"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86UO=6YT
M3V9#=7)R96YT2&5A9&EN9R(@("!S96QE8W0](F-O=6YT*&9O;&QO=VEN9RUS
M:6)L:6YG.CIT97AT.F@I(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(@("!S96QE8W0]
M(F9O;&QO=VEN9RUS:6)L:6YG.CIT97AT.F@B+SX*("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*+2T^"B`@("`@("`@("`@/"$M+2!G970@=&AE
M(&]V97)A;&P@3F\@;V8@2&5A9&5R<R`M+3X*("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB9V5T06QL2&5A9&5R3F\B+SX*("`@("`@("`\
M+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F=E=$-H:6QD4F]O=$YO9&4B/@H@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB9FEL95523"(@("`@<V5L96-T/2)T97AT.G-E8W1I;VXM
M<V]U<F-E+T!X;&EN:SIH<F5F(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@(`D\(2TM(&EF(&%B<V]L=71E(%523"!O<B!A8G-O;'5T92!$
M3U,@4$%42"!O<B!A8G-O;'5T92!5;FEX('!A=&@@+2T^"@D)"3QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@D9FEL95523"PG+R\G*2!O<B`H<W5B<W1R:6YG
M*"1F:6QE55),+#(L,2D@/2`G.B<I(&]R('-T87)T<RUW:71H*"1F:6QE55),
M+"`G+R<I(CX*("`@(`D)"3QX<VPZ=F%R:6%B;&4@;F%M93TB8VAI;&12;V]T
M3F]D92(@<V5L96-T/2)D;V-U;65N="@D9FEL95523"DB+SX*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G9710<F5V:6]U<TAE
M861E<DYO(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB9FEL95523"(@("`@("`@("`@("`@("`@<V5L96-T/2(D9FEL9552
M3"(O/@H@("`@("`@("`@("`@("`@"3PA+2T@3D\@86)S;VQU=&4@<V]U<F-E
M('!A=&@@=VEL;"!B92!A9&1E9"!A<R!P<F5F:7@@+2T^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%M;W5N=$]F0W5R<F5N
M=$AE861I;F<B('-E;&5C=#TB8V]U;G0H)&-H:6QD4F]O=$YO9&4O*B]O9F9I
M8V4Z8F]D>2]D97-C96YD86YT.CIT97AT.F@I(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYO9&54;U-E87)C:$9O<DAE
M861I;F<B('-E;&5C=#TB)&-H:6QD4F]O=$YO9&4O*B]O9F9I8V4Z8F]D>2]D
M97-C96YD86YT.CIT97AT.F@B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@"0D)/'AS;#IV87)I86)L92!N86UE
M/2)C:&EL9%)O;W1.;V1E(B!S96QE8W0](F1O8W5M96YT*&-O;F-A="@D86)S
M;VQU=&53;W5R8V5$:7)2968L)R\G+"1F:6QE55),*2DB+SX*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G9710<F5V:6]U<TAE
M861E<DYO(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB9FEL95523"(@("`@("`@("`@("`@("`@<V5L96-T/2(D9FEL9552
M3"(O/@H@("`@("`@("`@("`@("`@"3PA+2T@=&AE(&%B<V]L=71E('-O=7)C
M92!P871H('=I;&P@8F4@861D960@87,@<')E9FEX("TM/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;6]U;G1/9D-U<G)E
M;G1(96%D:6YG(B!S96QE8W0](F-O=6YT*"1C:&EL9%)O;W1.;V1E+RHO;V9F
M:6-E.F)O9'DO9&5S8V5N9&%N=#HZ=&5X=#IH*2(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N;V1E5&]396%R8VA&;W)(
M96%D:6YG(B!S96QE8W0](B1C:&EL9%)O;W1.;V1E+RHO;V9F:6-E.F)O9'DO
M9&5S8V5N9&%N=#HZ=&5X=#IH(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T4')E=FEO=7-(96%D97).;R(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)F:6QE55),(B\^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)N;V1E5&]396%R8VA&;W)(96%D:6YG(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)A;6]U;G1/9D-U<G)E;G1(96%D:6YG(B\^
M"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z9V5T+7!R979I
M;W5S+6-H:6QD+61O8W5M96YT<RUH96%D:6YG+6-O=6YT)RDB/@H@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9$AE861I;F=)
M;F9O(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(@("!S96QE8W0](B1N;V1E5&]3
M96%R8VA&;W)(96%D:6YG(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F9I;&554DPB("`@("`@("`@("`@("`@("`@<V5L
M96-T/2(D9FEL95523"(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)P<F5V:6]U<TAE861E<B(@("`@("`@("`@('-E;&5C
M=#TB<WAG:&5L<&5R.F=E="UP<F5V:6]U<RUC:&EL9"UD;V-U;65N=',M:&5A
M9&EN9RUC;W5N="@D86UO=6YT3V9#=7)R96YT2&5A9&EN9RDB+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO
M;BUA=F%I;&%B;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X
M9T-H:6QD5')A;G-F;W)M97(N9V5T4')E=FEO=7-#:&EL9$1O8W5M96YT<TAE
M861I;F=#;W5N="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)A9&1(96%D:6YG26YF;R(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYO9&54;U-E87)C:$9O<DAE861I
M;F<B("`@<V5L96-T/2(D;F]D951O4V5A<F-H1F]R2&5A9&EN9R(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)F:6QE55),
M(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&9I;&554DPB+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')E=FEO=7-(
M96%D97(B("`@("`@("`@("!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS
M;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T4')E=FEO=7-#:&EL
M9$1O8W5M96YT<TAE861I;F=#;W5N="@D86UO=6YT3V9#=7)R96YT2&5A9&EN
M9RDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H*
M("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F%D9$AE861I;F=);F9O(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F9I
M;&554DPB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!R979I;W5S2&5A
M9&5R(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)N;V1E5&]396%R8VA&
M;W)(96%D:6YG(B\^"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB<')E
M=FEO=7-(96%D97(R(B!S96QE8W0](FYU;6)E<B@D<')E=FEO=7-(96%D97(I
M(B\^"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1N;V1E5&]396%R
M8VA&;W)(96%D:6YG(CX*"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M
M93TB=&ET;&4B('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"XI(B\^"@H@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N8V]D9614:71L92(^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC;V1E
M+7-T<FEN9R(^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!T:&4@<W!A8V4@
M:&%S('1O(&)E(&YO<FUA;&EZ960L"B`@("`@("`@("`@("`@("`@("`@("`@
M(&]T:&5R=VES92!A;B!I;&QE9V%L(&%R9W5M96YT(&5X8V5P=&EO;B!W:6QL
M(&)E('1H<F]W;B!F;W(@6%0M+3X*("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G1E>'14;T)E16YC;V1E9"(@<V5L96-T/2(D
M=&ET;&4B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](FAE861I;F<B/@H@("`@("`@("`@("`@("`@/"$M
M+2!O9&0@8G5T("=D97-C96YD86YT.G1E>'0H*2<@9&ED;B=T('=O<FLL(&)U
M="`G+B<L('1O(&=E="!A;&P@=&5X="!N;V1E<R!O9B!T:&4@:&5A9&5R("TM
M/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB=&ET;&4B
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&ET;&4B+SX\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)E;F-O
M9&5D+71I=&QE(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&5N8V]D9614:71L
M92(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](FQE=F5L(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1E
M>'0Z;&5V96PB+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)F:6QE+75R;"(^/'AS;#IV86QU92UO9B!S
M96QE8W0](B1F:6QE55),(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:&5A9&5R+6YO(CX\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<&]S:71I;VXH*2`K("1P<F5V:6]U<TAE861E<C(B
M+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T06QL2&5A9&5R3F\B/@H*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F=E="UA;&PM8VAI
M;&0M9&]C=6UE;G1S+6AE861I;F<M8V]U;G0G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D06QL2&5A9&5R3F]%;&5M
M96YT(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB86QL2&5A9&5R(B`@('-E;&5C=#TB<WAG:&5L<&5R.F=E="UA;&PM8VAI
M;&0M9&]C=6UE;G1S+6AE861I;F<M8V]U;G0H*2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL
M86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14
M<F%N<V9O<FUE<BYG971!;&Q#:&EL9$1O8W5M96YT<TAE861I;F=#;W5N="<I
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A
M9&1!;&Q(96%D97).;T5L96UE;G0B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q(96%D97(B("`@<V5L96-T/2)J879A
M.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R
M+F=E=$%L;$-H:6QD1&]C=6UE;G1S2&5A9&EN9T-O=6YT*"DB+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&1!;&Q(96%D97).
M;T5L96UE;G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL2&5A9&5R
M(B\^"@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)H96%D:6YG+6-O=6YT
M(CX*("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1A;&Q(96%D
M97(B+SX*("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@(#PO>'-L.G1E;7!L
M871E/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ
M*B`@0W)E871I;VX@;V8@82!L:6YE(&]F(&QI;FMS(&%T('1H92!B96=I;FYI
M;F<@86YD(&5N9"!O9B!A(&-H:6QD(&1O8W5M96YT('1O(&5N:&%N8V4@=7-A
M8FEL:71Y("`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&0M8VAI;&0M9&]C=6UE;G0M=7-A
M8FEL:71Y+6QI;FMS(CX*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8V5N
M=&5R(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G-M86QL(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#Y;(#PO>'-L.G1E>'0^"@H*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB9VQO8F%L1&]C=6UE
M;G1$:7(B('-E;&5C=#TB<WAG:&5L<&5R.F=E="UG;&]B86PM9&]C=6UE;G0M
M9&ER*"DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M8W5R<F5N=$-H:6QD3F\B('-E;&5C=#TB;G5M8F5R*"1C;VYT96YT5&%B;&5(
M96%D:6YG<R]H96%D:6YG6R1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I
M;&4@/2!`9FEL92UU<FQ=+T!C:&EL9"UD;V-U;65N="UN;RDB+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96%R;&EE<D1O8U523"(@
M<V5L96-T/2(D8V]N=&5N=%1A8FQE2&5A9&EN9W,O:&5A9&EN9ULH)&-U<G)E
M;G1#:&EL9$YO("T@,2D@/2!`8VAI;&0M9&]C=6UE;G0M;F]=+T!O=70M9FEL
M92UU<FPB+SX*/"$M+0H\>'-L.FUE<W-A9V4^9G)O;3H@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B+SX\
M+WAS;#IM97-S86=E/@H\>'-L.FUE<W-A9V4^=&\Z(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D96%R;&EE<D1O8U523"(O/CPO>'-L.FUE<W-A9V4^"CQX<VPZ
M;65S<V%G93Y)<SH@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UR96QA
M=&EV92UF:6QE+7)E9B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G-O=7)C949I;&52968B('-E;&5C=#TB)&=L;V)A;$1O
M8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&:6QE4F5F(B!S96QE8W0]
M(B1E87)L:65R1&]C55),(B\^"B`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*/"]X<VPZ;65S<V%G93XM+3X*"@H@("`@("`@("`@("`@
M("`@/'AS;#II9B!T97-T/2(D96%R;&EE<D1O8U523"(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)H<F5F(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=VAE;B!T:&4@;&EN:W,@<W1A
M<G1S('=I=&@@82`G(R<@:70G<R!A(&QI;FL@=&\@=&AE($-O;G1E;G0@5&%B
M;&4M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)S=&%R=',M=VET:"@D96%R;&EE<D1O8U523"P@)R,G*2(^"@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB9V5T+7)E;&%T:79E+69I;&4M<F5F(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)S;W5R8V5&:6QE4F5F(B!S96QE8W0](B1G;&]B86Q$;V-U;65N
M=%)E9E1O0W5R<F5N=$9I;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&
M:6QE4F5F(B!S96QE8W0](BXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*/"$M+2`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D8V]N=&5N=%1A8FQE55),
M+"`D96%R;&EE<D1O8U523"DB+SXM+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E
M="UR96QA=&EV92UF:6QE+7)E9B(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V]U<F-E
M1FEL95)E9B(@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&
M:6QE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%R9V5T1FEL95)E9B(@<V5L96-T
M/2(D96%R;&EE<D1O8U523"(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H\(2TM"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB8V]N8V%T*"1G;&]B86Q$;V-U;65N=$1I<BP@)&5A<FQI97)$;V-5
M4DPI(B\^+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#Y0<F5V
M:6]U<R!D;V-U;65N=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/B!\(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@
M("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PA+2T@=VAE;B!G;&]B86Q$;V-U;65N=%)E
M9E1O0W5R<F5N=$9I;&4@:7,@=6YS970@=&AE(&-U<G)E;G0@9FEL92!I<R!T
M:&4@0V]N=&5N="!486)L92TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](F-O;G1E;G1486)L941I<B(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M
M;F%M92UO9BUT86)L92UO9BUC;VYT96YT+61O8W5M96YT(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)G970M<F5L871I=F4M9FEL92UR968B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<V]U<F-E1FEL95)E9B(@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U
M<G)E;G1&:6QE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&:6QE4F5F(B!S96QE
M8W0](B1C;VYT96YT5&%B;&5$:7(B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#XC/"]X<VPZ=&5X=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H*/"$M+2`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VYT96YT5&%B;&55
M4DPB+SXM+3X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/D-O;G1E;G0@5&%B;&4\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"@H@
M("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N97AT1&]C55),
M(B!S96QE8W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R]H96%D:6YG6R@D8W5R
M<F5N=$-H:6QD3F\@*R`Q*2`]($!C:&EL9"UD;V-U;65N="UN;UTO0&]U="UF
M:6QE+75R;"(O/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D;F5X
M=$1O8U523"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/B!\(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F$B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)H<F5F(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@=VAE;B!T:&4@;&EN:W,@<W1A<G1S('=I=&@@82`G(R<@:70G<R!A(&QI
M;FL@=&\@=&AE($-O;G1E;G0@5&%B;&4M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=&%R=',M=VET:"@D;F5X=$1O
M8U523"P@)R,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M<F5L871I=F4M9FEL
M92UR968B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-O=7)C949I;&52968B('-E;&5C
M=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G1A<F=E=$9I;&52968B('-E;&5C=#TB+B(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H\(2TM("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1C;VYT96YT5&%B;&554DPL("1N
M97AT1&]C55),*2(O/BTM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M<F5L871I
M=F4M9FEL92UR968B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-O=7)C949I;&52968B
M('-E;&5C=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G1A<F=E=$9I;&52968B('-E;&5C=#TB)&YE>'1$
M;V-54DPB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*/"$M+2`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&=L
M;V)A;$1O8W5M96YT1&ER+"`D;F5X=$1O8U523"DB+SXM+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/DYE>'0@9&]C=6UE;G0\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X@
M73PO>'-L.G1E>'0^"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](F=E="UR96QA=&EV92UF:6QE+7)E9B(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)S;W5R8V5&:6QE4F5F(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)T87)G971&:6QE4F5F(B\^"@H@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N
M8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z9V5T+7)E;&%T:79E+69I;&4M
M<F5F)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G-X9VAE;'!E<CIG970M<F5L871I=F4M9FEL92UR968H<W1R:6YG*"1S;W5R
M8V5&:6QE4F5F*2P@<W1R:6YG*"1T87)G971&:6QE4F5F*2DB+SX*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH
M96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971296QA=&EV949I;&52968G
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V
M83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE
M<BYG971296QA=&EV949I;&52968H<W1R:6YG*"1S;W5R8V5&:6QE4F5F*2P@
M<W1R:6YG*"1T87)G971&:6QE4F5F*2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T+6YA;64M;V8M=&%B
M;&4M;V8M8V]N=&5N="UD;V-U;65N="(^"@H@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=S>&=H96QP97(Z9V5T+6YA;64M;V8M=&%B;&4M;V8M8V]N=&5N="UD
M;V-U;65N="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S>&=H96QP97(Z9V5T+6YA;64M;V8M=&%B;&4M;V8M8V]N=&5N="UD
M;V-U;65N="@I(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z
M8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N
M9V5T3F%M94]F5&%B;&5/9D-O;G1E;G1$;V-U;65N="<I(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.F-O;2YS=6XN<W1A
M<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=$YA;65/9E1A
M8FQE3V9#;VYT96YT1&]C=6UE;G0H*2(O/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`\+WAS;#IT96UP;&%T
M93X*"@H)/'AS;#IT96UP;&%T92!N86UE/2)D96)U9RUC;VYT96YT+71A8FQE
M+6AE861I;F=S+79A<FEA8FQE(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IM97-S86=E
M/CQX<VPZ=&5X=#XJ*BHJ(%1(12!(14%$24Y'(%9!4DE!0DQ%("HJ*BH@/"]X
M<VPZ=&5X=#X\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93YC
M;VYT96YT+71A8FQE+75R;#H@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;&QE
M8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG<R]C;VYT96YT
M+71A8FQE+75R;"(O/CPO>'-L.FUE<W-A9V4^"@H@("`@("`@(#QX<VPZ9F]R
M+65A8V@@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT+71A
M8FQE+6AE861I;F=S+VAE861I;F<B/@H@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^/'AS;#IT97AT/BHJ*BH@;F5W(&AE861I;F<Z("`@("`@("`\+WAS;#IT
M97AT/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC
M;VYT96YT+71A8FQE+6ED.B`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`
M8V]N=&5N="UT86)L92UI9"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@
M(#QX<VPZ;65S<V%G93YC:&EL9"UD;V-U;65N="UN;SH@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)`8VAI;&0M9&]C=6UE;G0M;F\B+SX\+WAS;#IM97-S
M86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^9FEL92UU<FPZ("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&9I;&4M=7)L(B\^/"]X
M<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/F]U="UF:6QE
M+75R;#H@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!O=70M9FEL
M92UU<FPB+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^;&5V96PZ("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB0&QE=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM
M97-S86=E/G1I=&QE.B`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](D!T:71L92(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX
M<VPZ;65S<V%G93YE;F-O9&5D+71I=&QE.B`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)`96YC;V1E9"UT:71L92(O/CPO>'-L.FUE<W-A9V4^"B`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93YA8G-O;'5T92UC:&%P=&5R+6QE=F5L
M.CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`86)S;VQU=&4M8VAA<'1E<BUL979E
M;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H)
M/"]X<VPZ=&5M<&QA=&4^"@H*"3PA+2T@5&\@;6%K92!T:&4@:&5A9&EN9W,@
M=6YI<75E+"!T:&4@86)S;VQU=&4@:&5A9&EN9R!I<R!A9&1E9"!T;R!T:&5M
M"@D@("`@($4N9RX@5&AE(&QE=F5L(#$N,BXS+C0N('=O=6QD(')E<W5L="!I
M;G1O(&$@,2LR*S,K-"!S=')I;F<@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F-A;&,M8VAA<'1E<BUN=6UB97)S(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](FQE=F5L(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H
M96QP97(Z8V%L8RUC:&%P=&5R+6YU;6)E<G,G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.F-A;&,M8VAA<'1E
M<BUN=6UB97)S*"1L979E;"DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L
M92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N
M<V9O<FUE<BYC86QC0VAA<'1E<DYU;6)E<G,G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L
M="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYC86QC0VAA<'1E<DYU;6)E
M<G,H)&QE=F5L*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M(#PO>'-L.F-H;V]S93X*"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"B`@("`\
M>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G`B(&UO9&4](F-O;G1E;G0M=&%B
M;&4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F%L;%1A8E-T
M;W!3='EL97,B('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T
M>6QE.G-T>6QE6T!S='EL93IN86UE(#T@8W5R<F5N="@I+T!T97AT.G-T>6QE
M+6YA;65=+W-T>6QE.G!R;W!E<G1I97,O<W1Y;&4Z=&%B+7-T;W!S(B\^"@H@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T86)L92(^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](F)O<F1E<B(^,#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8VQA<W,B/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`=&5X=#IS='EL92UN86UE(B\^/"]X<VPZ
M871T<FEB=71E/@H\(2TM"CQX<VPZ;65S<V%G93XJ*BHJ*BHJ*BH\+WAS;#IM
M97-S86=E/@H\>'-L.FUE<W-A9V4^4W1Y;&5N86UE.CQX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`=&5X=#IS='EL92UN86UE(B\^/"]X<VPZ;65S<V%G93X*/'AS
M;#IM97-S86=E/G!O<VET:6]N.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U
M;G0H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W`I(B\^/"]X<VPZ
M;65S<V%G93X*+2T^"@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M8V]L9W)O=7`B/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F-R96%T92UC;VPM96QE;65N="(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E
M;&5C=#TB8V]U;G0H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W`I
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"@H*("`@("`@("`@("`@/"$M+2!A;&P@
M96QE;65N=',@8F5F;W)E('1H92!F:7)S="!T86)3=&]P("TM/@H@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1E<W1.;RU25$8B/@H@("`@("`@
M("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2)N;V1E*"DB
M(&UO9&4](F-E;&PM8V]N=&5N="(O/@H@("`@("`@("`@("`\+WAS;#IV87)I
M86)L93X*"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN;V1E+7-E="<I
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&%B3F]D
M95!O<VET:6]N<R(@<V5L96-T/2)X=#IN;V1E+7-E="@D=&5S=$YO+5)41BDB
M+SX*"0D)/'AS;#IE;&5M96YT(&YA;64](G1R(CX*("`@("`@("`@("`@("`@
M"2`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+71D+65L96UE;G1S
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M;&%S=$YO9&50;W-I=&EO;B(@<V5L96-T/2)C;W5N="@D86QL5&%B4W1O<%-T
M>6QE<R]S='EL93IT86(M<W1O<"DB+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB("`@("`@("`@<V5L96-T
M/2(Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL
M97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D95!O<VET:6]N
M<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N
M+6%V86EL86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T
M/2)X86QA;CIN;V1E<V5T*"1T97-T3F\M4E1&*2(O/@H)"0D\>'-L.F5L96UE
M;G0@;F%M93TB='(B/@H@("`@("`@("`@("`@("`)(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)C<F5A=&4M=&0M96QE;65N=',B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N
M(B!S96QE8W0](F-O=6YT*"1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS
M=&]P*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)P;W-I=&EO;B(@("`@("`@("!S96QE8W0](C$B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5&%B4W1O<%-T
M>6QE<R(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I
M;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M(#PO>'-L.F-H;V]S93X*"B`@("`@("`@("`@/"$M+2`\>'-L.G9A<FEA8FQE
M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB>'0Z;F]D92US970H
M)'1E<W1.;RU25$8I(B\^"@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB='(B/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F-R96%T92UT9"UE;&5M96YT<R(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C
M=#TB8V]U;G0H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W`I(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!O
M<VET:6]N(B`@("`@("`@('-E;&5C=#TB,2(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S
M96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E
M;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#XM+3X*"@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M8V]L
M+65L96UE;G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;&%S=$YO9&50
M;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL5&%B4W1O
M<%-T>6QE<R(O/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&%L
M;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W`B/@H@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB8V]L(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^=VED=&@Z(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=R87`M8V5L;"UW:61T:"(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P;W-I=&EO;B(@("`@("`@("!S96QE8W0](G!O<VET:6]N*"DB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L
M;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B+SX*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*("`@(#PO>'-L
M.G1E;7!L871E/@H\(2TM"E-C96YA<FEO<R!T86)S=&]P<PH*,2D@<W1Y;&4Z
M='EP92!O9B!S='EL93IT86(M<W1O<"!I<R`G<FEG:'0G(&%N9"!E87)L:65R
M('1A8E-T;W`@:7,@;F]T(')I9VAT"B`M/B!%87)L:65R('1E>'0M;F]D97,@
M86YD(&9O;&QO=VEN9R!T97AT+6YO9&5S+"!W:6QL(&)E('!U="!I;G1O(&%N
M(&EN;F5R('1A8FQE+"!W:71H('1W;R!41"!F:7)S="!A;&EG;F5D(&QE9G0L
M('=I=&@@<')O8V5D:6YG('1E>'1N;V1E<RP@=&AE(&QA='1E<B!A;&EG;F5D
M(')I9VAT+@H*,BD@<W1Y;&4Z='EP92!I<R`G<FEG:'0G(&%N9"!E87)L:65R
M('1A8E-T;W`@:7,@<FEG:'0*("T^(&9O;&QO=VEN9R!T97AT+6YO9&5S+"!W
M:6QL(&)E('!U="!I;G1O(&$@<FEG:'0@86QI9VYE9"!41`H*,RD@<W1Y;&4Z
M='EP92!I<R`G;F]N+7)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P("=N;VXM
M<FEG:'0G(&%S('=E;&P*("T^('!U="!T:&4@<')E8V5D:6YG('1A8B!S=&]P
M<R!I;G1O(&$@5$0@*&QE9G0@86QI9VYE9"!I<R!D969A=6QT*0H*-"D@9FER
M<W0@<W1Y;&4Z='EP92!W;W5L9"!H879E(&YO(')I9VAT('!R96-E9&EG;B!T
M86)3=&]P"B`M/B!W;W)K<R!W96QL('=I=&@@9FER<W0@<V-E86YR:6]S(#$@
M86YD(#,*"C4I(&QA<W0@<W1Y;&4Z='EP92!W;W5L9"!B92!A('-P96-I86P@
M8V%S92P@:68@:70@=V]U;&0@8F4@;&5F="!A;&EG;F5D+"!B=70@=&AI<R!W
M;VXG="!H87!P96X@:6X@;W5R(&-A<V4N+B`Z1`H*4V-E;F%R:6]S('5N;6%T
M8VAE9#H*+2!T97AT.G-T>6QE<&]S:71I;VX@)V-E;G1E<B<@=VEL;"!N;W0@
M8F4@;6%T8VAE9"!I;B!O=7(@8V%S92`H969F;W)T(&9O<B!N;W1H:6YG*2P@
M=&AE<F4@=VEL;"!B92!O;FQY("=R:6=H="<@86YD(&YO="`G<FEG:'0G"BT@
M268@=&AE(&QA<W0@=&%B4W1O<"!I<R!N;W0@9G)O;2!T97AT.G-T>6QE<&]S
M=&EO;B`G<FEG:'0G+"!T:&4@;&5N9W1H(&]F('1H92!L87-T(&-E;&P@:7,@
M=6YD969I;F5D(&%N9"!A(&1O8W5M96YT(&QE;F=T:"!M=7-T(&)E(&9O=6YD
M+@H@($YO="!H87!P96YS(&EN(&]U<B!G;&]B86P@9&]C=6UE;G0@8V%S92X@
M06QS;R!T:&4@86QG;W)I=&AM(&)E;&]W('=O=6QD(&AA=F4@=&\@8F4@97AP
M86YD960@*&-P+B!S8V5N87)I;R`U*2X*"BTM/@H@("`@/'AS;#IT96UP;&%T
M92!N86UE/2)C<F5A=&4M=&0M96QE;65N=',B/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB<&]S:71I;VXB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F%L;%1A8E-T;W!3='EL97,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](G1A8DYO9&50;W-I=&EO;G,B+SX*/"$M+0H\>'-L.FUE<W-A9V4^*RLK
M*RLK*RL\+WAS;#IM97-S86=E/@H\>'-L.FUE<W-A9V4^4&]S:71I;VXZ(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D<&]S:71I;VXB+SX\+WAS;#IM97-S86=E
M/@H\>'-L.FUE<W-A9V4^;&%S=$YO9&50;W-I=&EO;CH@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N(B\^/"]X<VPZ;65S<V%G93X*
M+2T^"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=%-T>6QE
M5'EP92(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R]S='EL93IT86(M<W1O
M<%LD<&]S:71I;VY=+T!S='EL93IT>7!E(B\^"B`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)E87)L:65R4W1Y;&54>7!E(B!S96QE8W0](B1A;&Q486)3
M=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P6R1P;W-I=&EO;B`M(#%=+T!S='EL
M93IT>7!E(B\^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D8W5R<F5N=%-T>6QE5'EP92`]("=R:6=H="<B/@H@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](B1E87)L:65R4W1Y;&54>7!E(#T@)W)I9VAT
M)R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T*("`@("`@("`@("`@
M("`@("`@("`@("`@,BD@<W1Y;&4Z='EP92!I<R`G<FEG:'0G(&%N9"!E87)L
M:65R('1A8E-T;W`@:7,@<FEG:'0*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("T^(&9O;&QO=VEN9R!T97AT+6YO9&5S+"!W:6QL(&)E('!U="!I;G1O
M(&$@<FEG:'0@86QI9VYE9"!41"`M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ(')I
M9VAT/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O
M<F4M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F5N9&EN
M9U1A8E-T;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O<VET:6]N("L@,2(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](B1L87-T3F]D95!O
M<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB
M)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`\(2TM"B`@("`@("`@("`@("`@("`@("`@("`@
M(#$I('-T>6QE.G1Y<&4@;V8@<W1Y;&4Z=&%B+7-T;W`@:7,@)W)I9VAT)R!A
M;F0@96%R;&EE<B!T86)3=&]P(&ES(&YO="!R:6=H=`H@("`@("`@("`@("`@
M("`@("`@("`@("`@+3X@16%R;&EE<B!T97AT+6YO9&5S(&%N9"!F;VQL;W=I
M;F<@=&5X="UN;V1E<RP@=VEL;"!B92!P=70@:6YT;R!A;B!I;FYE<B!T86)L
M92P@=VET:"!T=V\@5$0@9FER<W0@86QI9VYE9"!L969T+"!W:71H('!R;V-E
M9&EN9R!T97AT;F]D97,L('1H92!L871T97(@86QI9VYE9"!R:6=H="XM+3X*
M/"$M+2!V86QI9"!(5$U,(&)U="!B<F]W<V5R<R!M86ME(&$@;&EN92!B<F5A
M:R`H8F]R9&5R/3`@86YD('!A<F%G<F%P:'-T>6QE(&%L<V\@;6ES<VEN9RDZ
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T
M86)L92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB=&0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB
M969O<F4M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB96YD:6YG5&%B4W1O<%!O<VET:6]N(B`@<V5L96-T/2(D<&]S:71I
M;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB
M)&QA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I
M=&EO;G,B('-E;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T
M9"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R
M:6)U=&4@;F%M93TB<W1Y;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ(')I9VAT/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F=R87`M8V5L;"UC;VYT96YT+6)E9F]R92UT86(M
M<W1O<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)E;F1I
M;F=486)3=&]P4&]S:71I;VXB("!S96QE8W0](B1P;W-I=&EO;B`K(#$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB)&QA<W1.
M;V1E4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B
M('-E;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&0B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O<F4M=&%B+7-T;W`B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB96YD:6YG5&%B4W1O
M<%!O<VET:6]N(B`@<V5L96-T/2(D<&]S:71I;VXB+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB)&QA<W1.;V1E4&]S:71I;VXB
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB)'1A
M8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H\(2TM($]$2R!&14%455)%($Y/
M(%!!1T53"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F%L
M:6=N.B!R:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F=R87`M8V5L;"UC;VYT96YT+6)E9F]R92UT86(M<W1O<"(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F5N9&EN9U1A8E-T
M;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O<VET:6]N("L@,2(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB)&QA<W1.;V1E
M4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS
M(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X@
M("`@("`@("`@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB)&5A<FQI97)3='EL951Y<&4@/2`G<FEG:'0G(CX*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#PA
M+2T*("`@("`@("`@("`@("`@("`@("`@("`S*2!S='EL93IT>7!E(&ES("=N
M;VXM<FEG:'0G(&%N9"!E87)L:65R('1A8E-T;W`@)VYO;BUR:6=H="<@87,@
M=V5L;`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+3X@<'5T('1H92!P
M<F5C961I;F<@=&%B('-T;W!S(&EN=&\@82!41"`H;&5F="!A;&EG;F5D(&ES
M(&1E9F%U;'0I("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB=&0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F=R87`M8V5L;"UC;VYT96YT+6)E
M9F]R92UT86(M<W1O<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB96YD
M:6YG5&%B4W1O<%!O<VET:6]N(B`@<V5L96-T/2(D<&]S:71I;VXB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB;&%S=$YO9&50;W-I=&EO;B(@<V5L96-T/2(D;&%S=$YO9&50;W-I
M=&EO;B(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T
M86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M"B`@("`@("`@/'AS;#II9B!T97-T/2(D<&]S:71I;VX@(3T@)&QA<W1.;V1E
M4&]S:71I;VXB/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB8W)E871E+71D+65L96UE;G1S(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(@<V5L96-T/2(D
M;&%S=$YO9&50;W-I=&EO;B(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G!O<VET:6]N(B`@("`@("`@('-E;&5C=#TB)'!O<VET
M:6]N("L@,2(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL
M97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T
M86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^
M"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X
M<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T
M92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O<F4M=&%B+7-T;W`B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB96YD:6YG5&%B4W1O<%!O<VET
M:6]N(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)T86).;V1E4&]S:71I
M;VYS(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)L87-T3F]D95!O<VET
M:6]N(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&5N9&EN9U1A8E-T;W!0;W-I=&EO;B`](#$B/@H@("`@
M("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@;6]D93TB8V]N=&5N
M="UT86)L92(@<V5L96-T/2)N;V1E*"E;<&]S:71I;VXH*2`F;'0[("1T86).
M;V1E4&]S:71I;VYS+W1A8BUS=&]P+6YO9&4M<&]S:71I;VY;)&5N9&EN9U1A
M8E-T;W!0;W-I=&EO;EU=(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&5N9&EN9U1A8E-T;W!0;W-I=&EO
M;B`^("1L87-T3F]D95!O<VET:6]N(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M87!P;'DM=&5M<&QA=&5S(&UO9&4](F-O;G1E;G0M=&%B;&4B('-E;&5C=#TB
M;F]D92@I6W!O<VET:6]N*"D@/B`D=&%B3F]D95!O<VET:6]N<R]T86(M<W1O
M<"UN;V1E+7!O<VET:6]N6R1E;F1I;F=486)3=&]P4&]S:71I;VX@+2`Q75TB
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@
M;6]D93TB8V]N=&5N="UT86)L92(@<V5L96-T/2)N;V1E*"E;<&]S:71I;VXH
M*2`F;'0[("1T86).;V1E4&]S:71I;VYS+W1A8BUS=&]P+6YO9&4M<&]S:71I
M;VY;)&5N9&EN9U1A8E-T;W!0;W-I=&EO;EU=6W!O<VET:6]N*"D@/B`D=&%B
M3F]D95!O<VET:6]N<R]T86(M<W1O<"UN;V1E+7!O<VET:6]N6R1E;F1I;F=4
M86)3=&]P4&]S:71I;VX@+2`Q75TB/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T
M93X*"B`@("`\>'-L.G1E;7!L871E(&UO9&4](F-O;G1E;G0M=&%B;&4B(&UA
M=&-H/2)T97AT.G,B/@H@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C92(^"B`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)W:&ET97-P86-E<R(@<V5L96-T/2)`=&5X
M=#IC(B\^"B`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2(J(B!M;V1E
M/2)C96QL+6-O;G1E;G0B/@H*("`@("`@("`\>'-L.FEF('1E<W0](FYA;64H
M*2`]("=T97AT.G1A8BUS=&]P)R!O<B`J6VYA;64H*2`]("=T97AT.G1A8BUS
M=&]P)UTB/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&%B+7-T
M;W`M;F]D92UP;W-I=&EO;B(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<&]S:71I;VXH*2(O/@H@("`@("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9W)A<"UC96QL+7=I9'1H(CX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!O<VET:6]N(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B\^"@H@("`@("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&%B4W1O<%!O<VET:6]N(B!S96QE8W0]
M(B1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P6R1P;W-I=&EO;ETO
M0'-T>6QE.G!O<VET:6]N(B\^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=&%B4W1O<%!O<VET
M:6]N+"`G8VTG*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB8W)E871E+6-E;&PM=VED=&@B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W:61T:"(@("`@<V5L96-T/2)N
M=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=&%B4W1O<%!O<VET:6]N+"=C;2<I
M*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)U;FET(B`@("`@<V5L96-T/2(G8VTG(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!O<VET:6]N(B!S96QE8W0](B1P
M;W-I=&EO;B`M(#$B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB86QL5&%B4W1O<%-T>6QE<R(@<V5L96-T/2(D86QL5&%B
M4W1O<%-T>6QE<R(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F-O;G1A:6YS*"1T86)3=&]P4&]S:71I;VXL("=I;B<I
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C
M<F5A=&4M8V5L;"UW:61T:"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G=I9'1H(B`@("!S96QE8W0](FYU;6)E<BAS=6)S
M=')I;F<M8F5F;W)E*"1T86)3=&]P4&]S:71I;VXL)VEN)RDI(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G5N:70B("`@
M("!S96QE8W0](B=I;B<B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<&]S:71I;VXB('-E;&5C=#TB)'!O<VET:6]N("T@
M,2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S
M(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB8V]N=&%I;G,H)'1A8E-T;W!0;W-I=&EO;BP@)V-H)RDB/@H@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC96QL
M+7=I9'1H(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB=VED=&@B("`@('-E;&5C=#TB;G5M8F5R*'-U8G-T<FEN9RUB969O
M<F4H)'1A8E-T;W!0;W-I=&EO;BPG8V@G*2DB+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=6YI="(@("`@('-E;&5C=#TB
M)V-H)R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)P;W-I=&EO;B(@<V5L96-T/2(D<&]S:71I;VX@+2`Q(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%1A8E-T
M;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@D=&%B4W1O<%!O<VET:6]N+"`G<'0G*2(^"B`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-E;&PM=VED=&@B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W:61T
M:"(@("`@<V5L96-T/2)N=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=&%B4W1O
M<%!O<VET:6]N+"=P="<I*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)U;FET(B`@("`@<V5L96-T/2(G<'0G(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!O<VET
M:6]N(B!S96QE8W0](B1P;W-I=&EO;B`M(#$B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5&%B4W1O<%-T>6QE<R(@
M<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R(O/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@
M("`\>'-L.G1E;7!L871E(&YA;64](F-R96%T92UC96QL+7=I9'1H(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](G=I9'1H(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)U;FET(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P
M;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL5&%B4W1O
M<%-T>6QE<R(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](B1P;W-I=&EO;B`^(#$B/@H@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC96QL+7=I9'1H
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M=VED=&@B("`@('-E;&5C=#TB)'=I9'1H("T@;G5M8F5R*'-U8G-T<FEN9RUB
M969O<F4H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W!;)'!O<VET
M:6]N72]`<W1Y;&4Z<&]S:71I;VXL)'5N:70I*2(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)U;FET(B`@("`@<V5L96-T
M/2(D=6YI="(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)P;W-I=&EO;B(@<V5L96-T/2(D<&]S:71I;VX@+2`Q(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%1A
M8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D<&]S
M:71I;VX@/2`Q(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)C;VYC870H)'=I9'1H("T@;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H
M)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W!;)'!O<VET:6]N72]`
M<W1Y;&4Z<&]S:71I;VXL)'5N:70I*2P@)'5N:70I(B\^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D=VED
M=&@L("1U;FET*2(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H\+WAS
M;#IS='EL97-H965T/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O
M+VUA:6Y?:'1M;"YX<VP`````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4V-3,S`#$P-#$W
M,S8R-S<S`#`R,S4S,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE
M(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M<R!O9@H@
M("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@("`@
M("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@
M,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E
M($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC
M+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI
M8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B
M>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI;R!2
M;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R
M>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A
M;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5
M($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ
M+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO
M;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P
M92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!3ED@
M5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O
M9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-5
M3$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N97)A;"!0
M=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H;W5L
M9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE
M<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y
M.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O=6YD
M871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T
M;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T<GD@
M4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*
M("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T
M:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS92!6
M97)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S92!T
M:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC
M96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E;G-E
M(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL+@H*
M("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R
M;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%24D%.
M5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L($E.
M0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)204Y42453(%1(
M050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@34520TA!
M3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.3TXM
M24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF
M:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B
M;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE($EN
M:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@
M36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3
M=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D
M+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N
M/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N
M=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@('AM
M;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&5X
M=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@("`@
M("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@("!X
M;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G
M+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB97(](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@("`@
M("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B
M"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I
M8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID<C-D
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-871H
M+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN
M<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*
M("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@("`@
M("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X
M;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@
M("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@("`@
M("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H
M96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L
M87)K+F-O;2]X="(*("`@("`@("`@("`@("`@('AM;&YS.G-Y<W1E;3TB:'1T
M<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL86YG+E-Y<W1E;2(*
M("`@("`@("`@("`@("`@('AM;&YS.G5R;&5N8V]D97(](FAT='`Z+R]W=W<N
M:F-L87)K+F-O;2]X="]J879A+VIA=F$N;F5T+E523$5N8V]D97(B"B`@("`@
M("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G
M+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM
M;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU
M9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*"B`@("`\>'-L.F]U='!U="!M
M971H;V0@("`@("`](GAM;"(*("`@("`@("`@("`@("`@(&5N8V]D:6YG("`@
M(#TB551&+3@B"B`@("`@("`@("`@("`@("!I;F1E;G0@("`@("`](GEE<R(O
M/@H*"@H@("`@/"$M+2LK*RLK($E.0TQ51$5$(%A33"!-3T153$53("LK*RLK
M+2T^"B`@("`\(2TM(&EN:&5R:71E9"!S='EL92!P<F]P97)T:65S('=I;&P@
M8F4@8V]L;&5C=&5D(&%N9"!W<FET=&5N(&EN(&$@0U-3(&AE861E<B`H0U-3
M*2`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)S='EL95]H96%D97(N>'-L
M(B\^"@H@("`@/"$M+2!I;FAE<FET960@<W1Y;&4@<')O<&5R=&EE<R!W:6QL
M(&)E(&-O;&QE8W1E9"!A;F0@=W)I='1E;B!A<R!H=&UL('!R;W!E<G1I97,@
M:6X@82!T96UP;W)A<GD@=F%R:6%B;&4@*$A434PT+"!004Q-*2`M+3X*("`@
M(#QX<VPZ:6YC;'5D92!H<F5F/2)S='EL95]I;FQI;F5D+GAS;"(O/@H*("`@
M(#PA+2T@;W5R('AM;"!S='EL92!P<F]P97)T:65S('=I;&P@8F4@;6%P<&5D
M('1O($-34R!A;F0@2%1-3#0N>"!P<F]P97)T:65S("TM/@H@("`@/'AS;#II
M;F-L=61E(&AR968](G-T>6QE7VUA<'!I;F<N>'-L(B\^"@H@("`@/"$M+2!C
M;VUM;VX@96QE;65N="!H86YD;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H
M<F5F/2)C;VUM;VXN>'-L(B\^"@H@("`@/"$M+2!T86)L92!H86YD;&EN9R`M
M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)T86)L92YX<VPB+SX*"B`@("`\
M(2TM('!A;&T@:&%N9&QI;F<@+2T^"B`@("`\>'-L.FEN8VQU9&4@:')E9CTB
M<&%L;2YX<VPB+SX*"B`@("`\(2TM(&=L;V)A;"!D;V-U;65N="!H86YD;&EN
M9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)G;&]B86Q?9&]C=6UE;G0N
M>'-L(B\^"@H*"@H*"@H@("`@/"$M+2LK*RLK(%!!4D%-151%4B!&4D]-(%1(
M12!!4%!,24-!5$E/3B!!3D0@1TQ/0D%,(%9!4DE!0DQ%4R`K*RLK*RTM/@H*
M("`@(#PA+2T@34%.1$%43U)9.B!54DP@;V8@;65T82!S=')E86T@+2T^"B`@
M("`\>'-L.G!A<F%M(&YA;64](FUE=&%&:6QE55),(B\^"@H@("`@/"$M+2!-
M04Y$051/4EDZ(%523"!O9B!S='EL97,@<W1R96%M("TM/@H@("`@/'AS;#IP
M87)A;2!N86UE/2)S='EL97-&:6QE55),(B\^"@H@("`@/"$M+2!-04Y$051/
M4EDZ(&9O<B!R97-O;'9I;F<@<F5L871I=F4@;&EN:W,*("`@("`@("!&;W(@
M<F5S;VQV:6YG(')E86QT:79E(&QI;FMS('1O('1H92!P86-K960@4T\@9&]C
M=6UE;G0L(&DN92X@=&AE('!A=&@O55),(&]F('1H92!J87)E9"!S>'<@9FEL
M92`H92YG+B!M971A+GAM;"P@<W1Y;&5S+GAM;"P@;&EN:W,@=&\@9W)A<&AI
M8W,@:6X@82!R96QA=&EV92!D:7)E8W1O<GDI("TM/@H@("`@/'AS;#IP87)A
M;2!N86UE/2)A8G-O;'5T95-O=7)C941I<E)E9B(O/@H*("`@(#PA+2T@3U!4
M24].04P@*&UA;F1A=&]R>2P@=VAE;B!W:&5N('-O=7)C92!I<R!C;VUP<F5S
M<V5D*3H@3F5C97-S87)Y(&9O<B!T:&4@:6X@=&AE('!A8VME9"!/3R!D;V-U
M;65N="!E;6)E9&1E9"!F:6QE<R`H;6]S=&QY(&=R87!H:6-S(&9R;VT@=&AE
M(&-O;7!R97-S960@+U!I8W1U<F4@9&ER*2X*("`@("`@("`@5VAE;B!T:&4@
M3W!E;D]F9FEC92`H3T\I(&9I;&4@:&%S(&)E96X@=6YP86-K960@=&AE(&%B
M<V]L=71E4V]U<F5$:7)2968@8V%N(&)E('1A:V5N+`H@("`@("`@("!/=&AE
M<G=I<V4L(&$@2D%2(%523"!C;W5L9"!B92!C:&]O<V5N(&]R('=H96X@=V]R
M:VEN9R!W:71H($]P96Y/9F9I8V4@82!S;R!C86QL960@4&%C:V%G92U54DP@
M96YC;V1E9"!O=F5R($A45%`@8V%N(&)E('5S960@=&\*("`@("`@("`@86-C
M97-S('1H92!J87)E9"!C;VYT96YT<R!O9B!T:&4@=&AE(&IA<F5D(&1O8W5M
M96YT+B`N("TM/@H@("`@/'AS;#IP87)A;2!N86UE/2)J87)E9%)O;W154DPB
M('-E;&5C=#TB)&%B<V]L=71E4V]U<F-E1&ER4F5F(B\^"@H@("`@/"$M+2!/
M4%1)3TY!3"`H;6%N9&%T;W)Y+"!W:&5N('5S960@:6X@<V5S<VEO;B!B87-E
M9"!E;G9I<F]N;65N="D*("`@("`@("`@57-E9G5L(&9O<B!796)!<'!L:6-A
M=&EO;G,Z(&EF(&$@2%144"!S97-S:6]N(&ES(&YO="!C;V]K:64@8F%S960L
M(%523"!R97=R:71I;F<@:7,@8F5E:6YG('5S960@*'1H92!S97-S:6]N(&ES
M(&%P<&5N9&5D('1O('1H92!54DPI+@H@("`@("`@("!4:&ES(%523"!S97-S
M:6]N(&ES('5S960@=VAE;B!C<F5A=&EN9R!L:6YK<R!T;R!G<F%P:&EC<R!B
M>2!84TQ4+B!/=&AE<G=I<V4@=&AE('5S97(@:&%V="!T;R!L;V<@86=A:6X@
M:6X@9F]R(&5V97)Y(&=R87!H:6,@:&4@=V]U;&0@;&EK92!T;R!S964N("TM
M/@H@("`@/'AS;#IP87)A;2!N86UE/2)O<'1I;VYA;%523%-U9F9I>"(O/@H*
M("`@(#PA+2T@3U!424].04PZ($1022`H9&]T<R!P97(@:6YC:"D@=&AE('-T
M86YD87)D('-O;'5T:6]N(&]F(&=I=F5N('!I8W1U<F5S("AN96-E<W-A<GD@
M9F]R('1H92!C;VYV97)S:6]N(&]F("=C;2<@:6YT;R`G<&EX96PG*2TM/@H@
M("`@/"$M+2!!;'1H;W5G:"!M86YY('!I8W1U<F5S(&AA=F4@=&AE(#DV(&1P
M:2!R97-O;'5T:6]N+"!A(&AI9VAE<B!R97-O;'1I;VX@9VEV92!B971T97(@
M<F5S=6QT<R!F;W(@8V]M;6]N(&)R;W=S97)S("TM/@H@("`@/'AS;#IP87)A
M;2!N86UE/2)D<&DB('-E;&5C=#TB.38B+SX*"B`@("`\(2TM($]05$E/3D%,
M.B!I;B!C87-E(&]F('5S:6YG(&$@9&EF9F5R96YT('!R;V-E<W-O<B!T:&%N
M(&$@2D%602!84TQ4+"!Y;W4@8V%N('5N86)L92!T:&4@2F%V82!F=6YC=&EO
M;F%L:71Y"B`@("`@("`@("AI+F4N(&1E8G5G9VEN9R!T:6UE(&%N9"!E;F-O
M9&EN9R!C:&%P=&5R(&YA;65S(&9O<B!T:&4@8V]N=&5N="UT86)L92!A<R!H
M<F5F(&%N9"!A;F-H;W)S("D@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F1I
M<V%B;&5*879A(B`@("!S96QE8W0](F9A;'-E(B\^"B`@("`\>'-L.G!A<F%M
M(&YA;64](FES2F%V841I<V%B;&5D(B!S96QE8W0](F)O;VQE86XH)&1I<V%B
M;&5*879A*2(O/@H*("`@(#PA+2T@3U!424].04PZ('5S97(M86=E;G0@=VEL
M;"!B92!D:69F97)N=&EA=&5D(&)Y('1H:7,@<&%R86UE=&5R(&=I=F5N(&)Y
M(&%P<&QI8V%T:6]N("AE+F<N(&IA=F$@<V5R=FQE="DM+3X*("`@(#QX<VPZ
M<&%R86T@;F%M93TB;W5T<'5T5'EP92(@<V5L96-T/2(G0U-37TA%041%4B<B
M+SX*("`@(#PA+2T@<V5T(&]F('!O<W-I8FQE(&1E=FEC951Y<',@*%=-3"!I
M<R!S970@:6X@:71S(&]W;B!S=&%R=&9I;&4@;6%I;E]W;6PN>'-L*3H*("`@
M(#QX<VPZ<&%R86T@;F%M93TB;W5T<'5T5'EP92(@<V5L96-T/2(G0U-37TA%
M041%4B<B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB;W5T<'5T5'EP92(@<V5L
M96-T/2(G0U-37TE.3$E.140G(B\^"B`@("`\>'-L.G!A<F%M(&YA;64](F]U
M='!U=%1Y<&4B('-E;&5C=#TB)U!!3$TG(B\^("TM/@H*("`@(#PA+2T@3U!4
M24].04PZ(&9O<B!A8W1I=F%T:6YG('1H92!D96)U9R!M;V1E('-E="!T:&4@
M=F%R:6%B;&4@:&5R92!T;R`G=')U92@I)R!O<B!G:79E(&%N>2!V86QU92!F
M<F]M(&]U='-I9&4@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F1E8G5G(B`@
M("`@("`@('-E;&5C=#TB9F%L<V4B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB
M:7-$96)U9TUO9&4B("`@<V5L96-T/2)B;V]L96%N*"1D96)U9RDB+SX*"CPA
M+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*@H@("`@3U!424].04PZ
M($Y%141%1"!)3B!#3TY.14-424].(%=)5$@@02!'3$]"04P@1$]#54U%3E0@
M+2T^"@H@("`@/"$M+5-534U!4EDZ"B`@("`@("`@(&9O;&QO=VEN9R!P87)A
M;65T97(@=')I9V=E<G,@82`H<75I=&4@=&EM92!C;VYS=6UI;F<I(&5N86)L
M:6YG(&]F(&)O;VMM87)K<R!I;B!T:&4@=&%B;&4M;V8M8V]N=&5N="X*("`@
M("`@("!)3B!$151!24PZ"B`@("`@("`@($-U<G)E;G1L>2!S;VUE(&QI;FMS
M('5S960@:6X@=&AE($]F9FEC92!834P@*&4N9RX@:6X@=&AE(&-O;G1E;G0@
M=&%B;&4@87,@)R,W+E-O;64E,C!%>&%M<&QE)3(P2&5A9&QI;F4E-T]U=&QI
M;F4G*0H@("`@("`@("!I<R!N;W0@82!V86QI9"!54DP@*&-M<"X@8G5G(&ED
M(R`Q,#(S,3$I+B!.;R!F:6QE(&1E<W1I;F%T:6]N(&ES('-P96-I9FEE9"!N
M;W(@97AI<W0@86YY(&%N8VAO<B!E;&5M96YT(&9O<B!T:&5S90H@("`@("`@
M("!L:6YK<R!I;B!T:&4@3V9F:6-E(%A-3"X*("`@("`@("`@02!W;W)K87)O
M=6YD(&9O<B!T:&ES('1R86YS9F]R;6%T:6]N('1H97)E9F]R92!H860@=&\@
M8F4@;6%D92X@5&AI<R!T:6UE+6-O;G-U;6EN9R!M96-H86YI<VT@:7,@9&ES
M86)L960@8GD@9&5F875L="!A;F0*("`@("`@("`@8V%N(&)E(&%C=&EV871E
M9"!B>2!A('!A<F%M971E<B`H:2YE+B`G9&ES86)L94QI;FME9%1A8FQE3V9#
M;VYT96YT)RDN($$@8W)E871I;VX@;V8@86X@86YC:&]R(&ES(&UA9&4@9F]R
M(&5A8V@@:&5A9&5R(&5L96UE;G0N"B`@("`@("`@($%L;"!H96%D97(@=&ET
M;&5S(&=O;FYA(&)E(&5N8V]D:6YG('1O(&)E('5S86)L92!I;B!A(')E;&%T
M:79E(%523"X@("`@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F1I<V%B;&5,
M:6YK961486)L94]F0V]N=&5N="(@<V5L96-T/2)F86QS92@I(B\^"@H@("`@
M/"$M+2!4:&4@8VAA<'1E<B!N=6UB97)S(&]F('1H92!C=7)R96YT(&1O8W5M
M96YT("AA<R!A('-E<75E;F-E(&]F(&$@9VQO8F%L(&1O8W5M96YT*2!I<R!D
M97!E;F1E;G0@;V8@=&AE(&YU;6)E<@H@("`@("`@(&]F(&-H87!T97(@;V8@
M=&AE('-A;64@;&5V96P@:6X@<')E8V5D:6YG(&1O8W5M96YT<RX@+2T^"B`@
M("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#$B("!S
M96QE8W0](C`B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA
M<'1E<DQE=F5L,B(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE
M/2)P<F5C961I;F=#:&%P=&5R3&5V96PS(B`@<V5L96-T/2(P(B\^"B`@("`\
M>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#0B("!S96QE
M8W0](C`B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E
M<DQE=F5L-2(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P
M<F5C961I;F=#:&%P=&5R3&5V96PV(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L
M.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#<B("!S96QE8W0]
M(C`B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE
M=F5L."(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C
M961I;F=#:&%P=&5R3&5V96PY(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L.G!A
M<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#$P(B!S96QE8W0](C`B
M+SX*"B`@("`\(2TM(%A-3"!D;V-U;65N=',@8V]N=&%I;FEN9R!A('1A8FQE
M(&]F(&-O;G1E;G1S+`H@("`@("`@(&=O;FYA(&QI;FL@9F]R('5S86)I;&ET
M>2!R96%S;VX@86)O=F4@96%C:"!C:&%P=&5R('1O('1H92!P<F5C961I;F<@
M86YD(&9O;&QO=VEN9R!D;V-U;65N="!A;F0@=&AE(&-O;G1E;G0@=&%B;&4@
M+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F-O;G1E;G1486)L95523"(O/@H*
M("`@(#PA+2T@3F5E9&5D(&9O<B!T:&4@8G5G('=O<FMA<F]U;F0@;V8@;6ES
M<VEN9R!C;VYT96YT('1A8FQE(&QI;FMS"B`@("`@("`@8GD@=&AI<R!A;6)I
M9V]U<R!(5$U,(')E9F5R96YC97,@9G)O;2!T:&4@8V]N=&5N="!T86)L92!C
M86X@8F4@979O:61E9"TM/@H@("`@/'AS;#IP87)A;2!N86UE/2)G;&]B86Q$
M;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B+SX*"B`@("`\(2TM($YE961E9"!F
M;W(@=&AE(&)U9R!W;W)K87)O=6YD(&]F(&UI<W-I;F<@8V]N=&5N="!T86)L
M92!L:6YK<PH@("`@("`@(&)Y('1H:7,@;F]D92US970@=&AE(')E;&%T:6]N
M(&)E='=E96X@8V]N=&5N="UT86)L92!L:6YK(&%N9"!C:&EL9')E;B!D;V-U
M;65N="!H96%D97(@8V%N(&)E('5N86UB:6=O=7,@97-T86)L:7-H960@+2T^
M"B`@("`\>'-L.G!A<F%M(&YA;64](F-O;G1E;G1486)L94AE861I;F=S(B\^
M"@H*/"$M+2!%3D0@3T8@1TQ/0D%,($1/0U5-14Y4(%-%0U1)3TX**BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BTM/@H*"@H@("`@/"$M+2!W;W)K<R!F
M;W(@;F]R;6%L('-E<&%R871E9"!Z:7!P960@>&UL(&9I;&5S(&%S(&9O<B!F
M;&%T(&9I;'1E<B!S:6YG;&4@>&UL(&9I;&4@9F]R;6%T(&%S('=E;&P@+2T^
M"B`@("`\>'-L.G9A<FEA8FQE(&YA;64](F]F9FEC93IM971A+69I;&4B("`@
M("`@("`@("!S96QE8W0](F1O8W5M96YT*"1M971A1FEL95523"DB+SX*("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB;V9F:6-E.G-T>6QE<RUF:6QE(B`@("`@
M("`@('-E;&5C=#TB9&]C=6UE;G0H)'-T>6QE<T9I;&554DPI(B\^"B`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](F]F9FEC93IF;VYT+61E8VQS(B`@("`@("`@
M("!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+69I;&4O*B]O9F9I8V4Z9F]N="UD
M96-L<R(O/@H@("`@/'AS;#IV87)I86)L92!N86UE/2)O9F9I8V4Z<W1Y;&5S
M(B`@("`@("`@("`@("`@<V5L96-T/2(D;V9F:6-E.G-T>6QE<RUF:6QE+RHO
M;V9F:6-E.G-T>6QE<R(O/@H@("`@/"$M+2!O9F9I8V4Z875T;VUA=&EC+7-T
M>6QE<R!M87D@;V-C=7)E(&EN('1W;R!D:69F97)E;G0@9FEL97,@*&DN9"X@
M8V]N=&5N="YX;6P@86YD('-T>6QE<RYX;6PI+B!&=7)T:&5R;6]R92!T:&4@
M=&]P(&QE=F5L('1A9R!I<R!D:69F97)E;G0@:6X@82!F;&%T('AM;"!F:6QE
M("TM/@H@("`@/'AS;#IV87)I86)L92!N86UE/2)O9F9I8V4Z875T;VUA=&EC
M+7-T>6QE<R(@("`@<V5L96-T/2(O*B]O9F9I8V4Z875T;VUA=&EC+7-T>6QE
M<R(O/@H*("`@(#PA+2T@<VEM<&QE(&1E8VQA<F%T:6]N(&]F(%=-3"!U<V5D
M('1O(&%V;VED('!A<G-E<B!E<G)O<G,@+2T^"B`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](G=A<"UP87)A9W)A<&@M96QE;65N=',M=VET:&]U="UT86)L92UR
M;W<B+SX*("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=V%P+7!A<F%G<F%P:"UE
M;&5M96YT<R(O/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W;6PM<F5P96%T
M+7=R:71E+7)O=R(O/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!B=6EL9"!T:&4@
M<')O<')I871E($A434P@9FEL92`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT
M96UP;&%T92!M871C:#TB+R(^"@H@("`@("`@(#PA+2T\>'-L.FUE<W-A9V4^
M"@H*("`@("`@("!%;G1E<F5D('1H92!S='EL95-H965T<RP@=')A;G-F;W)M
M871I;VX@8F5G:6YS+BXN(#PO>'-L.FUE<W-A9V4^+2T^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&ES1&5B
M=6=-;V1E(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)C:&5C:RUP87)A;65T97(B+SX*"B`@("`@("`@("`@("`@("`\>'-L
M.FEF('1E<W0](FYO="@D:7-*879A1&ES86)L960I(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9&5B=6<M<W1Y;&4M
M8V]L;&5C=&EN9RUT:6UE(B\^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM('1O(&%C8V5S<R!T:&4@=F%R
M:6%B;&4@;&EK92!A(&YO9&4M<V5T(&ET(&ES(&YE8V5S<V%R>2!T;R!C;VYV
M97)T(&ET"B`@("`@("`@("`@("`@("`@("`@(&9R;VT@82!R97-U;'0M=')E
M92UF<F%G;65N="`H4E1&*2!T;R!A(&YO9&4@<V5T('5S:6YG('1H92!*86UE
M<R!#;&%R:R!E>'1E;G-I;VX@+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$M4E1&(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG8W)E871E
M+6%L;"UI;FQI;F4M<W1Y;&5S)R\^"B`@("`@("`@("`@("`@("`\+WAS;#IV
M87)I86)L93X*"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=X=#IN;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](G-T87)T(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](GAT.FYO9&4M<V5T*"1C;VQL96-T961'
M;&]B86Q$871A+5)41BDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC
M=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2)X86QA;CIN;V1E
M<V5T*"1C;VQL96-T961';&]B86Q$871A+5)41BDB+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB3F]D95-E=$9U;F-T:6]N3F]T079A:6QA8FQE(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S
M=&%R="(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB<W1A<G0B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK
M($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$15(@4U193$4@5T%9
M("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T
M5'EP92`]("=#4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB:'1M;"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](FAE860B/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D-34R!H
M96QP97(@=F%R:6%B;&4@=VEL;"!B92!C<F5A=&5D+BXN+CPO>'-L.FUE<W-A
M9V4^/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2=C;VUM;VXM:&5A9&5R+7!R;W!E<G1I97,G+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U
M9TUO9&4B/CQX<VPZ;65S<V%G93Y#4U,@=F%R:6%B;&4@<F5A9'DL(&AE861E
M<B!W:6QL(&)E(&-R96%T960N+BXN/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C;VYS=')U8W1I;F<@=&AE
M(&-S<R!H96%D97(@<VEM=6QA=&EN9R!I;FAE<FET86YC92!O9B!S='EL92UF
M86UI;&EE<R!B>2!S='EL92!O<F1E<B`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64])V-R96%T92UC<W,M<W1Y
M;&5H96%D97(G+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T
M97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y#4U,@:&5A9&5R(&-R
M96%T:6]N(&9I;FES:&5D(3PO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"@H*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F)A8VMG<F]U;F1);6%G9552
M3"(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<&%G
M92UM87-T97(O<W1Y;&4Z<')O<&5R=&EE<R]S='EL93IB86-K9W)O=6YD+6EM
M86=E+T!X;&EN:SIH<F5F(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](F)O9'DB/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM(&)A8VMG<F]U;F0@:6UA9V4@+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ:68@=&5S=#TB)&)A8VMG<F]U;F1);6%G95523"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)B
M86-K9W)O=6YD(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2!F;W(@:6UA9V5S(&IA<F5D(&EN(&]P96X@;V9F:6-E(&1O8W5M
M96YT("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)&)A8VMG<F]U;F1);6%G95523"P@
M)R-0:6-T=7)E<R\G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM(&-R96%T:6YG(&%N(&%B<V]L=71E(&AT='`@55),
M('1O('1H92!C;VYT86EN960O<&%C:V5D(&EM86=E(&9I;&4@+2T^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB8V]N8V%T*"1J87)E9%)O;W154DPL("<O4&EC='5R97,O
M)RP@<W5B<W1R:6YG+6%F=&5R*"1B86-K9W)O=6YD26UA9V554DPL("<C4&EC
M='5R97,O)RDL("1O<'1I;VYA;%523%-U9F9I>"DB+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)S<F,B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D8F%C
M:V=R;W5N9$EM86=E55),(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@<')O8V5S<VEN9R!T:&4@8V]N=&5N="!O9B!T
M:&4@>&UL(&9I;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM
M=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)
M3DQ)3DE.1R`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB:'1M;"(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](FAE860B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG8V]M;6]N+6AE861E
M<BUP<F]P97)T:65S)R\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)B86-K9W)O=6YD26UA9V554DPB('-E;&5C=#TB)&]F9FEC93IA=71O;6%T
M:6,M<W1Y;&5S+W-T>6QE.G!A9V4M;6%S=&5R+W-T>6QE.G!R;W!E<G1I97,O
M<W1Y;&4Z8F%C:V=R;W5N9"UI;6%G92]`>&QI;FLZ:')E9B(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B;V1Y(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/"$M+2!B86-K9W)O=6YD(&EM86=E("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1B86-K9W)O
M=6YD26UA9V554DPB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB8F%C:V=R;W5N9"(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@9F]R(&EM86=E<R!J87)E9"!I
M;B!O<&5N(&]F9FEC92!D;V-U;65N="`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1B
M86-K9W)O=6YD26UA9V554DPL("<C4&EC='5R97,O)RDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C<F5A=&EN9R!A
M;B!A8G-O;'5T92!H='1P(%523"!T;R!T:&4@8V]N=&%I;F5D+W!A8VME9"!I
M;6%G92!F:6QE("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D:F%R9612
M;V]T55),+"`G+U!I8W1U<F5S+R<L('-U8G-T<FEN9RUA9G1E<B@D8F%C:V=R
M;W5N9$EM86=E55),+"`G(U!I8W1U<F5S+R<I+"`D;W!T:6]N86Q54DQ3=69F
M:7@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W)C(CX\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&)A8VMG<F]U;F1);6%G95523"(O/CPO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M
M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H*("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$TM5DE)("@S+C(@2%1-3"!3
M54)3150I("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@/"$M+2!T
M:&4@<')O>'D@=VEL;"!C;VYV97)T('1H92!H=&UL(&9I;&4@;&%T97(@=&\@
M4%%!("TM/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FAT
M;6PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)H
M96%D(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64])W!A;&TM:&5A9&5R+7!R;W!E<G1I97,G+SX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB8F]D>2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@<')O8V5S<VEN9R!T:&4@8V]N=&5N="!O9B!T:&4@>&UL
M(&9I;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM
M=&5M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E
M/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(96%D97(@9F]R($-3
M4U])3DQ)3D5$(&%N9"!#4U-?2$5!1$52("HJ*B`M+3X*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG8V]M;6]N+6AE861E<BUP<F]P
M97)T:65S)SX*("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0]
M(B1O9F9I8V4Z;65T82UF:6QE+RHO;V9F:6-E.FUE=&$O9&,Z=&ET;&4B+SX*
M("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](B1O9F9I8V4Z
M;65T82UF:6QE+RHO;V9F:6-E.FUE=&$O9&,Z9&5S8W)I<'1I;VXB+SX*/"$M
M+3)$3R!A9&0@9G5R=&AE<B!H96%D97(@96QE;65N=',N+@H@("`@("`@(#QX
M<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB)&]F9FEC93IM971A+69I;&4O
M*B]O9F9I8V4Z;65T82]D8SIS=6)J96-T(B\^"B`@("`@("`@/'AS;#IA<'!L
M>2UT96UP;&%T97,@<V5L96-T/2(D;V9F:6-E.FUE=&$M9FEL92\J+V]F9FEC
M93IM971A+VUE=&$Z:V5Y=V]R9'-;<&]S=&ET:6]N*"D],5TB+SXM+3X*("`@
M(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](F1C
M.G1I=&QE(CX*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&ET;&4B/@H@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/@H@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\>'-L
M.G1E;7!L871E(&UA=&-H/2)D8SID97-C<FEP=&EO;B(^"B`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@("`@("`@("`\>'-L.F%T=')I
M8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YD
M97-C<FEP=&EO;CPO>'-L.G1E>'0^"B`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N
M="(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O
M/@H@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM("HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*
M("`@(#PA+2T@*BHJ($UE87-U<FEN9R!T:&4@=&EM92!F;W(@<W1Y;&4@8W)E
M871I;F<@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#QX<VPZ=&5M<&QA
M=&4@;F%M93TB9&5B=6<M<W1Y;&4M8V]L;&5C=&EN9RUT:6UE(CX*"B`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)S=&%R=%1I;64M4E1&(CX*("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>7-T96TZ8W5R<F5N="UT:6UE
M+6UI;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB<WES=&5M.F-U<G)E;G0M=&EM92UM:6QL:7,H*2(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z:F%V82YL86YG
M+E-Y<W1E;2YC=7)R96YT5&EM94UI;&QI<R<I(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IJ879A+FQA;F<N4WES
M=&5M+F-U<G)E;G14:6UE36EL;&ES*"DB+SX*("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\
M+WAS;#IV87)I86)L93X*"@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$M4E1&(CX*("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64])V-R96%T92UA;&PM:6YL:6YE+7-T>6QE<R<O
M/@H@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I
M;&%B;&4H)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IM
M97-S86=E/D-R96%T:6YG('1H92!I;FQI;F4@<W1Y;&5S+BXN+CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T
M87)T5&EM92(@("`@("`@("`@("`@('-E;&5C=#TB;G5M8F5R*'AT.FYO9&4M
M<V5T*"1S=&%R=%1I;64M4E1&*2DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@<V5L96-T
M/2)X=#IN;V1E+7-E="@D8V]L;&5C=&5D1VQO8F%L1&%T82U25$8I(B\^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N9%1I;64B("`@
M("`@("`@("`@("`@('-E;&5C=#TB<WES=&5M.F-U<G)E;G0M=&EM92UM:6QL
M:7,H*2(O/@H*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y4:6UE(&9O
M<B!I;G-T86YT:6%T:6YG('-T>6QE('9A<FEA8FQE.B`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB*"1E;F14:6UE("T@)'-T87)T5&EM92DB+SX@;7,\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G-T87)T(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G>&%L86XZ;F]D
M97-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y#<F5A=&EN
M9R!T:&4@:6YL:6YE('-T>6QE<RXN+BX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S=&%R=%1I;64B("`@("`@
M("`@("`@("!S96QE8W0](FYU;6)E<BAX86QA;CIN;V1E<V5T*"1S=&%R=%1I
M;64M4E1&*2DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M
M93TB96YD5&EM92(@("`@("`@("`@("`@("`@<V5L96-T/2)J879A.FIA=F$N
M;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,H*2(O/@H@("`@("`@("`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B`@("!S96QE8W0](GAA;&%N.FYO9&5S970H)&-O;&QE8W1E9$=L;V)A;$1A
M=&$M4E1&*2(O/@H*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y4:6UE
M(&9O<B!I;G-T86YT:6%T:6YG('-T>6QE('9A<FEA8FQE.B`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB*"1E;F14:6UE("T@)'-T87)T5&EM92DB+SX@;7,\+WAS
M;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G-T87)T(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\
M+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/"$M+2!$
M14)51R!P=7)P;W-E(&]N;'DZ(&-H96-K:6YG('1H92!P87)A;65T97)S(&]F
M('1H:7,@=&5M<&QA=&4M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8VAE
M8VLM<&%R86UE=&5R(CX*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R
M(&1P:3H@/'AS;#IV86QU92UO9B!S96QE8W0](B1D<&DB+SX\+WAS;#IM97-S
M86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@;65T849I;&55
M4DPZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;65T849I;&554DPB+SX\+WAS
M;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@<W1Y
M;&5S1FEL95523#H@/'AS;#IV86QU92UO9B!S96QE8W0](B1S='EL97-&:6QE
M55),(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R
M86UE=&5R(&%B<V]L=71E4V]U<F-E1&ER4F5F.B`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB)&%B<V]L=71E4V]U<F-E1&ER4F5F(B\^/"]X<VPZ;65S<V%G93X*
M("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T
M97),979E;#$@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H
M87!T97),979E;#$B+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S
M<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L,B`Z(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L,B(O/CPO
M>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!P
M<F5C961I;F=#:&%P=&5R3&5V96PS(#H@/'AS;#IV86QU92UO9B!S96QE8W0]
M(B1P<F5C961I;F=#:&%P=&5R3&5V96PS(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T97),
M979E;#0@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H87!T
M97),979E;#0B+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G
M93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L-2`Z(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L-2(O/CPO>'-L
M.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!P<F5C
M961I;F=#:&%P=&5R3&5V96PV(#H@/'AS;#IV86QU92UO9B!S96QE8W0](B1P
M<F5C961I;F=#:&%P=&5R3&5V96PV(B\^/"]X<VPZ;65S<V%G93X*("`@("`@
M("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T97),979E
M;#<@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),
M979E;#<B+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y0
M87)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L."`Z(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L."(O/CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!P<F5C961I
M;F=#:&%P=&5R3&5V96PY(#H@/'AS;#IV86QU92UO9B!S96QE8W0](B1P<F5C
M961I;F=#:&%P=&5R3&5V96PY(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`\
M>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T97),979E;#$P
M.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),979E
M;#$P(B\^/"]X<VPZ;65S<V%G93X*("`@(#PO>'-L.G1E;7!L871E/@H*/"]X
M<VPZ<W1Y;&5S:&5E=#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O;V]O+W!A;&TN>'-L````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0Q-3,W
M`#$P-#$W,S8R-S<S`#`R,C4Q,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI
M<R!F:6QE(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M
M<R!O9@H@("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@
M("`@("`@("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E
M<G-I;VX@,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@
M4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E
M;7,@26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@
M,C`P,"!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT
M;VYI;R!2;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@
M;&EB<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T
M92!I="!A;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T
M:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I
M;VX@,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U
M;F1A=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T
M:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]5
M5"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R
M86YT>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!0
M05)424-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N
M97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U
M('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E
M<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L
M:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@
M($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P
M+"!";W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD
M=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@
M(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C
M="!T;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC
M96YS92!697)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T
M('5S92!T:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T
M:&4@3&EC96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,
M:6-E;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH
M=&UL+@H*("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E
M(&ES('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@
M5T%24D%.5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)
M140L($E.0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)204Y4
M2453(%1(050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@
M34520TA!3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/
M4B!.3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@
M<W!E8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD
M"B`@(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@
M5&AE($EN:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES
M.B!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P
M,B!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E
M<V5R=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V
M97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z
M+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@
M("`@('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M;V9F:6-E(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@
M("`@("`@("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@
M("`@("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R
M;6%T(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N
M=S,N;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB
M97(](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@
M("`@("`@("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P
M,"]S=F<B"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN
M<SID<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY
M."]-871H+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@
M("!X;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C
M<FEP="(*("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@
M("`@("`@("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@
M("`@("!X;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N
M,2\B"B`@("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N
M9FEG/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@
M("`@("`@("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,"]H96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W
M=W<N:F-L87)K+F-O;2]X="(*("`@("`@("`@("`@("`@('AM;&YS.G-Y<W1E
M;3TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL86YG+E-Y
M<W1E;2(*("`@("`@("`@("`@("`@('AM;&YS.GAA;&%N/2)H='1P.B\O>&UL
M+F%P86-H92YO<F<O>&%L86XB"B`@("`@("`@("`@("`@("!X;6QN<SIJ879A
M/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>'-L="]J879A(@H@("`@("`@("`@
M("`@("`@97AC;'5D92UR97-U;'0M<')E9FEX97,](FIA=F$B/@H*("`@(#QX
M<VPZ;W5T<'5T(&-D871A+7-E8W1I;VXM96QE;65N=',](FUE=&$B+SX*"@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@
M/"$M+2`J*BH@<W!E8VEF:6,@<&%L;2!H96%D97(@*BHJ("TM/@H@("`@/"$M
M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TG<&%L;2UH96%D97(M<')O<&5R=&EE<R<^"B`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@("`@("`@("`\>'-L
M.F%T=')I8G5T92!N86UE/2)N86UE(CY086QM0V]M<'5T:6YG4&QA=&9O<FT\
M+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](F-O;G1E;G0B/G1R=64\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB;65T82(^
M"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA;64B/DAA;F1H
M96QD1G)I96YD;'D\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](F-O;G1E;G0B/G1R=64\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(FYA;64B/DAI<W1O<GE,:7-T5&5X=#PO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="(^1&%T96EM86YA
M9V5R)B,Q,#LZ("9A;7`[9&%T92`F86UP.W1I;64\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(FYA;64B/F1E<V-R:7!T:6]N/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VYT96YT(CY3=&%R4&]R=&%L/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)N86UE(CYK97EW;W)D<SPO>'-L.F%T=')I8G5T93X*
M("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="(^<W1A
M<G!O<G1A;"P@<W1A<F]F9FEC92P@<V]F='=A<F4\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(FAT='`M97%U:78B/D-O;G1E;G0M5'EP93PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="(^=&5X="]H
M=&UL.R!C:&%R<V5T/6ES;RTX.#4Y+3$\+WAS;#IA='1R:6)U=&4^"B`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\
M(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@
M(#PA+2T@*BHJ(&-R96%T:6YG('1A8FQE(&%T=')I8G5T97,@*BHJ("TM/@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^
M"@H@("`@/"$M+2!T86)L92!D871A("AT9"D@86YD('1A8FQE(&AE861E<B`H
M=&@I(&%T=')I8G5T97,@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R
M96%T92UA='1R:6)U=&4M04Q)1TXB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB
M8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)V%L:6=N)RDB/@H@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)A;&EG;B(^"B`@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=A;&EG;CIL
M969T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^;&5F
M=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H
M)'-T>6QE4')O<&5R=&EE<RP@)V%L:6=N.G)I9VAT)RDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^<FEG:'0\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YC96YT97(\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`\+WAS
M;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&-R
M96%T:6YG($QI<W0@871T<FEB=71E<R`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"CPA+2T*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6QI<W0M871T<FEB=71E<R(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*"@HA
M(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(0HR(&)E(&EM<&QE;65N=&5D
M"B$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A"@H*("`@(#PO>'-L.G1E
M;7!L871E/@HM+3X*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&-R
M96%T:6YG(&YE<W1E9"!F;W)M870@=&%G<R`H4$%,32`F(%=-3"D@*BHJ("TM
M/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/"$M+2!)=&%L:6,@+2T^"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](F-R96%T92UN97-T960M9F]R;6%T+71A9W,B
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S
M(B\^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G:71A;&EC)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FDB/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)B;VQD
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F)O
M;&0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@0F]L9"`M+3X*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8F]L9"(^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@D<W1Y;&50<F]P97)T:65S+"`G8F]L9"<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)B(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=6YD97)L:6YE(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE4')O
M<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G5N9&5R;&EN92(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE
M4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!5;F1E<FQI;F4@.B!L87-T
M(&9O<FUA="!A='1R:6)U=&4L('=H:6-H(&ES(&%L<V\@=7-E9"!F<F]M(%=-
M3"`M(%=-3"!E;F1S(&AE<F4A("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2)U;F1E<FQI;F4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y
M;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L
M("=U;F1E<FQI;F4G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)U(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=')I:V5T:')O=6=H(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I
M97,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB<W1R:6ME=&AR;W5G:"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B!S96QE
M8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT
M86EN<R@D<W1Y;&50<F]P97)T:65S+"`G=6YD97)L:6YE)RDB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM
M=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"B`@("`\(2TM('-T<FEK971H<F]U9V@@+2T^"B`@
M("`\>'-L.G1E;7!L871E(&YA;64](G-T<FEK971H<F]U9V@B/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)W-T<FEK92<I(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S=')I:V4B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A;&EG;B(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A;&EG
M;B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!!;&EG;FUE;G0@
M+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F%L:6=N(CX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O/@H*("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O
M;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=A;&EG;B<I(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)D:78B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F%L:6=N(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R
M;W!E<G1I97,L("=A;&EG;CIL969T)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#YL969T/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T
M>6QE4')O<&5R=&EE<RP@)V%L:6=N.G)I9VAT)RDB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YR:6=H=#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F-E;G1E<CPO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)F;VYT
M7V-O;6)I;F5D(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50
M<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F9O;G1?8V]M8FEN960B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB
M)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*
M("`@(#PA+2T@0F]T:"!S:7IE(&%N9"!#;VQO<B!F;W(@9F]N="`M+3X*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TB9F]N=%]C;VUB:6YE9"(^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*"B`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C
M;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G8V]L;W(G*2!A;F0@8V]N=&%I
M;G,H)'-T>6QE4')O<&5R=&EE<RP@)W-I>F4G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB9F]N="(^"@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;&]R(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E
M<G1I97,L("=C;VQO<CHC,#`P,#`P)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#XC,#`P,#`P/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^(T9&1D9&1CPO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S:7IE(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U
M8G-T<FEN9RUA9G1E<BAS=6)S=')I;F<M8F5F;W)E*"1S='EL95!R;W!E<G1I
M97,@+"<Z<VEZ92<I+"`G<VEZ93HG*2(O/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@("`@("`@/"$M+2!G
M970@=&AE(&5M8F5D9&5D(&-O;G1E;G0@+2T^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB9F]N=%]S:6UP;&4B/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I
M97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#PA+2T@<VEZ92!O<B!#;VQO<B!F;W(@9F]N="`M
M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9F]N=%]S:6UP;&4B/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)V-O;&]R)RDB/@H@("`@
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F9O;G0B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;&]R(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S
M='EL95!R;W!E<G1I97,L("=C;VQO<CHC,#`P,#`P)RDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC,#`P,#`P/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^(T9&
M1D9&1CPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E
M/@H*("`@("`@("`@("`@("`@("`@("`\(2TM(&=E="!T:&4@96UB961D960@
M8V]N=&5N="`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E
M;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA
M<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=S:7IE)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F9O;G0B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-I>F4B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB<W5B<W1R:6YG+6%F=&5R*'-U8G-T<FEN9RUB969O<F4H)'-T>6QE4')O
M<&5R=&EE<R`L)SIS:7IE)RDL("=S:7IE.B<I(B\^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@("`@("`\
M(2TM(&=E="!T:&4@96UB961D960@8V]N=&5N="`M+3X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`\(2TM(&=E="!T:&4@96UB961D960@8V]N=&5N="`M+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H\+WAS;#IS='EL97-H965T/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V]O;R]S='EL95]H96%D97(N>'-L````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`T,C,S-@`Q,#0Q-S,V,C<W,P`P,C0R,C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/"$M+0H*("`@5&AE($-O;G1E
M;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A=F%I;&%B;&4@<W5B:F5C="!T
M;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F('1H92!F;VQL;W=I;F<@;&EC
M96YS97,*"B`@("`@("`@("`M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@
M3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@("`@+2!3=6X@26YD=7-T<GD@
M4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"@H@("!3=6X@
M36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L(#(P,#`*"B`@($=.52!,97-S
M97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@
M0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H@("`Y
M,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!;'1O+"!#02`Y-#,P,RP@55-!
M"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R
M961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO9&EF>2!I="!U;F1E<B!T:&4@
M=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC
M96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O
M9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I
M8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("`@
M8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM
M<&QI960@=V%R<F%N='D@;V8*("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%
M4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@
M3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL
M<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!A;&]N9R!W
M:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3
M;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L
M(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@,#(Q,3$M,3,P-R`@55-!"@H*
M("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S
M:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT96YT<R!O9B!T:&ES(&9I;&4@
M87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U<W1R>2!3=&%N9&%R9',*("`@
M4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@*'1H92`B3&EC96YS92(I.R!9
M;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@(&5X8V5P="!I;B!C;VUP;&EA
M;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M87D@;V)T86EN(&$@8V]P>2!O
M9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O=W=W+F]P96YO9F9I8V4N;W)G
M+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E('!R;W9I9&5D('5N9&5R('1H
M:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A;B`B05,@25,B(&)A<VES+`H@
M("!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%251(15(@15A04D53
M4R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@(%=)5$A/550@3$E-251!5$E/
M3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T945T%212!)4R!&4D5%($]&($1%
M1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4($9/4B!!(%!!4E1)0U5,05(@
M4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N"B`@(%-E92!T:&4@3&EC96YS
M92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO;G,@9V]V97)N:6YG('EO=7(@
M<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C;VYC97)N:6YG('1H92!3;V9T
M=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L;W!E<B!O9B!T:&4@3W)I9VEN
M86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@0V]P>7)I
M9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@06QL
M(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R:6)U=&]R*',I.B!?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U\*"BTM/@H\>'-L.G-T
M>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]4<F%N<V9O<FTB"B`@
M("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@("`@("`@('AM;&YS.G-T>6QE
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S='EL92(*("`@("`@("`@
M("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIT86)L93TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@("`@("`@("`@("`@("!X;6QN
M<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<F%W:6YG(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y
M.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@("`@('AM;&YS.GAL:6YK/2)H
M='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D871A
M<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIS=F<](FAT='`Z+R]W=W<N
M=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@("`@("`@>&UL;G,Z8VAA<G0]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V-H87)T(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS.FUA=&@](FAT='`Z+R]W=W<N
M=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@("`@("`@("`@("`@("!X;6QN
M<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]F;W)M(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z8VQA<W,]
M(G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z=F5R<VEO;CTB,2XP(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT='`Z+R]P=7)L+F]R9R]D8R]E
M;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@("`@>&UL;G,Z;65T83TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T82(*("`@("`@("`@("`@("`@
M('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#$O8V]N
M9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z:&5L<#TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@("`@("`@("`@('AM;&YS.GAT
M/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B"B`@("`@("`@("`@("`@("!X
M;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J879A+VIA
M=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@("`@("!X;6QN<SIX86QA;CTB
M:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*
M("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S/2)J879A
M(CX*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M("TM/@H@("`@/"$M+2`J*BH@<W1Y;&4@<VAE970@<')O8V5S<VEN9R`J*BH@
M+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M
M+3X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2=C<F5A=&4M8W-S+7-T>6QE
M:&5A9&5R)SX*("`@("`@("`\>'-L.F-O;6UE;G0^"B`@("`@("`@("`@(#QX
M<VPZ=&5X=#Y4:&4@0U-3('-T>6QE(&AE861E<B!M971H;V0@9F]R('-E='1I
M;F<@<W1Y;&5S/"]X<VPZ=&5X=#X*("`@("`@("`\+WAS;#IC;VUM96YT/@H@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S='EL92(^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](G1Y<&4B/G1E>'0O8W-S/"]X<VPZ871T
M<FEB=71E/@H@("`@("`@("`@("`\>'-L.F-O;6UE;G0^"B`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^"@H@("`@("`@(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M9&5F875L
M="US='EL97,B+SX*"B`@("`@("`@("`@("`@("`\(2TM(%1(12!35%E,12!0
M4D]015)42453($]&(%1(12!&25)35"!74DE45$5.(%-464Q%("A005)%3E0I
M($E3($=)5D5.($]55"`M+3X*"B`@("`@("`@("`@("`@("`\(2TM(#$I('-T
M>6QE<R!F<F]M(&]F9FEC93IS='EL97,@87)E('!O<W-I8FQE('!A<F5N="!F
M<F]M(&%L;"`H:71S96QF(&]R(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S*2X*
M("`@("`@("`@("`@("`@("`@("`@5&AE<F5F;W)E('1H97D@87)E(&-R96%T
M960@9FER<W0N"B`@("`@("`@("`@("`@("`@("`@($)E9VEN;FEN9R!W:71H
M('1H92!T;W`M;&5V96P@<&%R96YT<R`H=&AE('-T>6QE<R!W:71H;W5T(&%N
M>2!P87)E;G0I+B`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@
M<V5L96-T/2(D;V9F:6-E.G-T>6QE<R]S='EL93IS='EL95MN;W0H0'-T>6QE
M.G!A<F5N="US='EL92UN86UE*5TB/@H*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P97)T>2UL
M:6YE(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN97,M9F]R+6-H:6QD<F5N
M(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*"B`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^(#PO>'-L.G1E>'0^"@H@("`@("`@("`@("`@
M("`@/"$M+2`R*2!S='EL97,@9G)O;2!O9F9I8V4Z875T;VUA=&EC+7-T>6QE
M<R!C86X@;VYL>2!B92!P87)E;G0@;V8@<W1Y;&5S(&9R;VT@=&AE(&]F9FEC
M93IA=71O;6%T:6,M<W1Y;&5S('-E8W1I;VXN"B`@("`@("`@("`@("`@("`@
M("`@($)E9VEN;FEN9R!W:71H('1O<"UL979E;"!S='EL97,L(&%G86EN+"!A
M;&P@8VAI;&1R96X@<W1Y;&4@=VEL;"!B92!R96-U<G-I=FQY('1R879E<G-E
M9"`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D
M;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;;F]T*$!S='EL
M93IP87)E;G0M<W1Y;&4M;F%M92E=(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P97)T>2UL
M:6YE(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(@<V5L96-T/2)T
M<G5E*"DB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)W<FET92US='EL97!R;W!E<G1Y+6QI;F5S+69O<BUC:&EL9')E;B(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S96%R8VA/;FQY26Y!=71O;6%T:6-3='EL97,B+SX*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@("\O/"]X<VPZ8V]M;65N=#X*
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG=W)I=&4M<W1Y;&5P<F]P97)T>2UL
M:6YE)SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U
M=&]M871I8U-T>6QE<R(O/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(G-T>6QE4')O<&5R=&EE<R(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)W<FET92US='EL92UP<F]P97)T:65S(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL94%T=')I8G5T95!A
M=&@B("`@<V5L96-T/2)C=7)R96YT*"DO<W1Y;&4Z<')O<&5R=&EE<R]`*B(O
M/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO
M>'-L.G9A<FEA8FQE/@H*("`@("`@("`\(2TM(&1O(&YO="!W<FET92!S='EL
M97,@=VET:"!N;R!C<W,@<')O<&5R='D@+2T^"B`@("`@("`@/'AS;#II9B!T
M97-T/2)N;W0H<W1R:6YG+6QE;F=T:"@D<W1Y;&50<F]P97)T:65S*2`](#`I
M(CX*("`@("`@("`@("`@/"$M+2!W<FET92!O=70@=&AE(&YA;64@;V8@=&AE
M(&-U<G)E;G0@*'!A<F5N="D@<W1Y;&4@:6X@=&AE($-34R!H96%D97)S96-T
M:6]N("AE+F<N(")S<&%N+FUY4W1Y;&4B*2`M+3X*("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+6YA;64B/@H@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FES+7!A<F5N="US
M='EL92(@<V5L96-T/2)T<G5E*"DB+SX*("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*"B`@("`@("`@("`@(#PA+2T@=&AE(&YA;65S(&]F(&%L
M;"!S='EL97,@8VAI;&1R96X@=VEL;"!B92!W<FET=&5N(&]U="AO9F9I8V4Z
M<W1Y;&4@04Y$(&]F9FEC93IA=71O;6%T:6,M<W1Y;&4I("TM/@H@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M8VAI;&1R96XM
M<W1Y;&4M;F%M97,B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G!A<F5N=%-T>6QE3F%M92(@("`@("`@("`@<V5L96-T/2)`<W1Y
M;&4Z;F%M92(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G!A<F5N=%-T>6QE1F%M:6QY(B`@("`@("`@<V5L96-T/2)`<W1Y;&4Z
M9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^"B`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@(#PA+2T@=&AE('-T>6QE
M('!R;W!E<G1I97,@;V8@=&AE(&9I<G-T('=R:71T96X@<W1Y;&4@*'!A<F5N
M="D@:7,@9VEV96X@;W5T("TM/@H@("`@("`@(#QX<VPZ=&5X=#X@>PH@("`@
M("`@("`@("`@("`@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@
M/'AS;#IT97AT/GT*("`@("`@("`\+WAS;#IT97AT/@H*("`@("`@("`\+WAS
M;#II9CX*"@H*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*("`@(#PA+2T@4D5#
M55)324].(%=)5$@@14Y$0T].1$E43TXZ(&%D9&EN9R!S='EL92!C;&%S<V5S
M(&9O<B!A;&P@97AI<W1I;F<@8VAI;&1S("TM/@H@("`@/'AS;#IT96UP;&%T
M92!N86UE/2=W<FET92US='EL97!R;W!E<G1Y+6QI;F5S+69O<BUC:&EL9')E
M;B<^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S96%R8VA/;FQY26Y!=71O
M;6%T:6-3='EL97,B+SX*"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P
M87)E;G13='EL94YA;64B("`@('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A<F5N=%-T>6QE1F%M:6QY(B`@
M<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"@H@("`@("`@(#QX<VPZ:68@=&5S
M=#TB;F]T*'-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<RDB/@H@("`@("`@
M("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB+BXO<W1Y;&4Z<W1Y;&5;0'-T
M>6QE.F9A;6EL>3TD<&%R96YT4W1Y;&5&86UI;'D@86YD($!S='EL93IP87)E
M;G0M<W1Y;&4M;F%M93TD<&%R96YT4W1Y;&5.86UE72(^"B`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P
M97)T>2UL:6YE(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P97)T>2UL:6YE<RUF;W(M8VAI;&1R
M96XB+SX*("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@/"]X
M<VPZ:68^"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z
M875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21P
M87)E;G13='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US='EL92UN86UE
M/21P87)E;G13='EL94YA;65=(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN92(^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN
M075T;VUA=&EC4W1Y;&5S(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W
M<FET92US='EL97!R;W!E<G1Y+6QI;F5S+69O<BUC:&EL9')E;B(^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN
M075T;VUA=&EC4W1Y;&5S(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`\+WAS;#IT96UP
M;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W<FET92UD969A=6QT
M+7-T>6QE<R(^"@H@("`@("`@(#PA+2T@<V]M92!D969A=6QT(&%T=')I8G5T
M97,@:6X@>&UL(&AA=F4@=&\@8F4@97AP;&EC:71L>2!S970@:6X@2%1-3"`H
M92YG+B!M87)G:6XM=&]P/2(P(BD@+2T^"B`@("`@("`@/'AS;#IT97AT/BHN
M3T]O7V1E9F%U;'1S/"]X<VPZ=&5X=#X*"B`@("`@("`@("`@("`@("`\>'-L
M.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IS='EL97,O<W1Y;&4Z<W1Y;&4B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O
M;F-A="@G*BXG+"!T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@
M)R<I*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@("`@
M("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z875T
M;VUA=&EC+7-T>6QE<R]S='EL93IS='EL92(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IT97AT/BP@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T
M92A`<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@
M("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`\(2TM(#)$3SH@=&AE(&1E
M9F%U;'1S(&UI9VAT(&)E(&)E='1E<B!C;VQL96-T960@86YD('=R:71T96X@
M:6X@82!S97!A<F%T960@*%A-3"D@9FEL92`M+3X*/'AS;#IT97AT/B!["B`@
M("`@("`@("`@("`@("!M87)G:6XM=&]P.C!C;3L@;6%R9VEN+6)O='1O;3HP
M8VT[('T*("`@("`@("`\+WAS;#IT97AT/@H*("`@("`@("`\>'-L.F9O<BUE
M86-H('-E;&5C=#TB)&]F9FEC93IS='EL97,O<W1Y;&4Z9&5F875L="US='EL
M92(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET
M92UD969A=6QT+7-T>6QE(B\^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@
M("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I
M8RUS='EL97,O<W1Y;&4Z9&5F875L="US='EL92(^"B`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UD969A=6QT+7-T>6QE(B\^
M"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G=R:71E+61E9F%U;'0M<W1Y
M;&4B/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB9F%M:6QY+7-T>6QE
M(B!S96QE8W0](D!S='EL93IF86UI;'DB+SX*"B`@("`@("`@/"$M+2!S;VUE
M(&1E9F%U;'0@871T<FEB=71E<R!F;W(@9F]R;6%T(&9A;6EL:65S("AE+F<N
M(&=R87!H:6-S+"!P87)A9W)A<&AS+"!E=&,N*2!W<FET=&5N(&%S('-T>6QE
M.F1E9F%U;'0M<W1Y;&4@+2T^"B`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H)&9A;6EL>2US='EL92P@)RX@
M)2@I+UPG+"`G)RDL("=?9&5F875L=',G*2(O/@H*("`@("`@("`\>'-L.F9O
M<BUE86-H('-E;&5C=#TB)&]F9FEC93IS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T
M>6QE.F9A;6EL>2`]("1F86UI;'DM<W1Y;&5=(CX*("`@("`@("`@("`@/'AS
M;#IT97AT/BP@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H0'-T>6QE.FYA;64L
M("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*
M("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IA=71O;6%T
M:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D@/2`D9F%M:6QY
M+7-T>6QE72(^"B`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN
M)RP@=')A;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*
M("`@("`@("`\+WAS;#IF;W(M96%C:#X*"@H@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB<W1Y;&50<F]P97)T:65S(CX*("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+7!R;W!E<G1I97,B/@H@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE071T
M<FEB=71E4&%T:"(@("!S96QE8W0](F-U<G)E;G0H*2]S='EL93IP<F]P97)T
M:65S+T`J(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@(#PA+2T@9&\@;F]T('=R
M:71E('-T>6QE<R!W:71H(&YO(&-S<R!P<F]P97)T>2`M+3X*("`@("`@("`\
M>'-L.FEF('1E<W0](FYO="AS=')I;F<M;&5N9W1H*"1S='EL95!R;W!E<G1I
M97,I(#T@,"DB/@H@("`@("`@(#PA+2T@=&AE('-T>6QE('!R;W!E<G1I97,@
M;V8@=&AE(&9I<G-T('=R:71T96X@<W1Y;&4@*'!A<F5N="D@:7,@9VEV96X@
M;W5T("TM/@H@("`@("`@(#QX<VPZ=&5X=#X@>PH@("`@("`@("`@("`@("`@
M/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@/'AS;#IT97AT/GT*
M("`@("`@("`\+WAS;#IT97AT/@H@("`@("`@(#PO>'-L.FEF/@H*("`@(#PO
M>'-L.G1E;7!L871E/@H*"B`@("`\(2TM*RL*("`@("`@("`@(%1H92!P87)E
M;G0@<W1Y;&4@=VEL;"!B92!W<FET=&5N(&]U="$*("`@("`@("`@($9O<B!E
M86-H(%-T>6QE.F9A;6EL>2!A('!R969I>"!M=7-T(&)E(&%D9&5D"B`@("`@
M("`@("`@(#PA14Y42519("4@<W1Y;&5&86UI;'D*("`@("`@("`@("`@(BAP
M87)A9W)A<&A\=&5X='QS96-T:6]N?'1A8FQE?'1A8FQE+6-O;'5M;GQT86)L
M92UR;W=\=&%B;&4M8V5L;'QT86)L92UP86=E?&-H87)T?&=R87!H:6-S?&1E
M9F%U;'1\9')A=VEN9RUP86=E?'!R97-E;G1A=&EO;GQC;VYT<F]L*2(^"B`@
M("`@("`@*RLM+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y
M;&4M;F%M92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)I<RUP87)E;G0M
M<W1Y;&4B+SX*"B`@("`@("`@/"$M+2!4:&ES(&-O;G-T<G5C="!I<R!F;W(@
M;&ES="!E;&5M96YT<RX@5VAE;F5V97(@82!P87)A9W)A<&@@96QE;65N="!I
M<R!B96EN9R!U<V5D(&%S(&-H:6QD(&]F(&$@;&ES="!E;&5M96YT('1H92!N
M86UE('!A<F%G<F%P:"!S='EL92!I<R!B965N('5S960@9F]R"B`@("`@("`@
M("`@('1H92!L:7-T(&ET96TN(%1H:7,@8V%N(&)E('-W:71C:&5D(&%S('1H
M92!P87)A9V%P:"!S='EL92UN86UE(&%N9"!T:&4@;&ES="US='EL92UN86UE
M(&%R92!I;B!T:&4@<V%M92!E;&5M96YT+@H@("`@("`@("`@("!/=&AE<G=I
M<V4@=&AE<F4@=V]U;&0@8F4@9F]R;6%T=&EN9R!E<G)O<G,@*&4N9RX@;6%R
M9VEN+6QE9G0@=VEL;"!B92!U<V5D(&9O<B!T:&4@8V]N=&5N="!I;B!T:&4@
M;&ES="!E;&UE;G0@86YD(&YO="!F;W(@=&AE(&QI<W0@96QE;65N="!I='-E
M;&8I+B`M+3X*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T>6QE+6YA
M;64B/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z;&ES="US='EL92UN86UE(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'-T>6QE
M.FQI<W0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`<W1Y;&4Z;F%M92(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@
M("`@(#QX<VPZ:68@=&5S=#TB;F]T*"1I<RUP87)E;G0M<W1Y;&4I(CX*("`@
M("`@("`@("`@/'AS;#IT97AT/BP@/"]X<VPZ=&5X=#X*("`@("`@("`\+WAS
M;#II9CX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2T@
M;F]R;6%L;'D@)W`N)R!W;W5L9"!B92!U<V5D(&%S($-34R!E;&5M96YT+`H@
M("`@("`@("`@("`@("`@(&)U="!H96%D97(@*&@Q+"!H,BPN+BXI(&%R92!A
M;'-O(&9R;VT@=&AE('-T>6QE.F9A;6EL>2!P87)A9W)A<&@@+2T^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A
M<&@G(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C
M;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L
M("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])W1E>'0G(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@
M=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](D!S='EL93IF86UI;'D])W-E8W1I;VXG(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E
M*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL
M93IF86UI;'D])W1A8FQE)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB8V]N8V%T*"=T86)L92XG+"!T<F%N<VQA=&4H)'-T>6QE
M+6YA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE.F9A;6EL
M>3TG=&%B;&4M8V]L=6UN)R(^"B`@("`@("`@("`@(#PA+2T@87,@8V]L=6UN
M('-T>6QE<R!H879E('1O(&)E(&EN8VQU9&5D(&%S('-P86X@<W1Y;&5S($%&
M5$52('1H92!T86)L92`H;F\@='=O(&-L87-S(&%T=')I8G5T97,@:6X@5$0@
M86QL;W=E9"`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E
M*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])W1A8FQE+7)O
M=R<B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O
M;F-A="@G='(N)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L
M("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])W1A8FQE+6-E;&PG(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H
M)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB
M+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](D!S='EL93IF86UI;'D])W1A8FQE+7!A9V4G(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@
M=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](D!S='EL93IF86UI;'D])V-H87)T)R(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D
M<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z
M9F%M:6QY/2=G<F%P:&EC<R<B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H)'-T>6QE+6YA
M;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE.F9A;6EL>3TG
M9&5F875L="<B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H)'-T>6QE+6YA;64L("<N("4H
M*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE.F9A;6EL>3TG9')A=VEN9RUP
M86=E)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG
M+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=P<F5S96YT871I;VXG
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC
M870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G
M*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])V-O;G1R;VPG(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@
M=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!F:6YD:6YG(&%L;"!S='EL
M92!C:&EL9"!O9B!A('-E8W1I;VX@86YD(&=I=F4@=&AE:7(@<W1Y;&5)9&5N
M=&EF:65R('1O('1H92!O=71P=70@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA
M;64])W=R:71E+6-H:6QD<F5N+7-T>6QE+6YA;65S)SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M92(@<V5L96-T/2)`<W1Y;&4Z
M;F%M92(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&
M86UI;'DB('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^"@H*
M("`@("`@("`\(2TM*BH@=&AE(&YA;65S(&]F(&%L;"!O9F9I8V4Z<W1Y;&5S
M(&-H:6QD<F5N('=I;&P@8F4@=W)I='1E;B!O=70*("`@("`@("`@("`@*BH@
M*&$@875T;VUA=&EC('-T>6QE(&-A;B!O;FQY(&AA=F4@8VAI;&1R96X@:6X@
M=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y;&4@<V5C=&EO;BD@+2T^"@H@("`@
M("`@(#PA+2T@:68@3D]4(&-A;&QE9"!F<F]M(&$@;V9F:6-E.F%U=&]M871I
M8RUS='EL92!P87)E;G0@+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H
M<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S*2(^"B`@("`@("`@("`@(#PA
M+2T@9F]R(&%L;"!C:&EL9')E;B!I;B!T:&4@;V9F:6-E.G-T>6QE('-E8W1I
M;VX@+2T^"B`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(N+B]S
M='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21P87)E;G13='EL949A;6EL>2!A
M;F0@0'-T>6QE.G!A<F5N="US='EL92UN86UE/21P87)E;G13='EL94YA;65=
M(CX*("`@("`@("`@("`@("`@(#PA+2T@=W)I=&4@=&AE('-T>6QE(&YA;64@
M:6X@=&AE(&-S<R!H96%D97(@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&4M;F%M92(O/@H*("`@("`@
M("`@("`@("`@(#PA+2T@<V5A<F-H(&9O<B!C:&EL9"!S='EL97,@+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M
M8VAI;&1R96XM<W1Y;&4M;F%M97,B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B('-E;&5C=#TB
M0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB('-E;&5C=#TB0'-T>6QE
M.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*"B`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@(#PO>'-L
M.FEF/@H*("`@("`@("`\(2TM*BH@=&AE(&YA;65S(&]F(&%L;"!O9F9I8V4Z
M875T;VUA=&EC+7-T>6QE<R!C:&EL9')E;B!W:6QL(&)E('=R:71T96X@;W5T
M("TM/@H*("`@("`@("`\(2TM(&9O<B!A;&P@8VAI;&1R96X@:6X@=&AE(&]F
M9FEC93IA=71O;6%T:6,M<W1Y;&4@<V5C=&EO;B`M+3X*("`@("`@("`\>'-L
M.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T
M>6QE.G-T>6QE6T!S='EL93IF86UI;'D])'!A<F5N=%-T>6QE1F%M:6QY(&%N
M9"!`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64])'!A<F5N=%-T>6QE3F%M95TB
M/@H@("`@("`@("`@("`\(2TM('=R:71E('1H92!S='EL92!N86UE(&EN('1H
M92!C<W,@:&5A9&5R("TM/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB=W)I=&4M<W1Y;&4M;F%M92(O/@H*("`@("`@("`@("`@/"$M
M+2!S96%R8V@@9F]R(&-H:6QD('-T>6QE<R`M+3X*("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6-H:6QD<F5N+7-T>6QE+6YA
M;65S(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P
M87)E;G13='EL94YA;64B('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL949A
M;6EL>2(@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC
M4W1Y;&5S(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@
M("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H\
M+WAS;#IS='EL97-H965T/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]S
M='EL95]I;FQI;F5D+GAS;```````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U-C,R,P`Q,#0Q-S,V
M,C<W,P`P,C0T,C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A
M<F4@;6%D92!A=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@
M96ET:&5R(&]F('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N
M,0H@("`@("`@("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,
M:6-E;G-E(%9E<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL
M($]C=&]B97(L(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@
M3&EC96YS92!697)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@
M4W5N($UI8W)O<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A
M9"P@4&%L;R!!;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@
M:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD
M+V]R"B`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,
M97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@
M87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN
M"@H@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@
M=&AA="!I="!W:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!
M4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*
M("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!
M4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@
M:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A
M;"!0=6)L:6,*("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@
M:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T
M:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N
M+`H@("!-02`@,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T
M86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@
M(%1H92!C;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE
M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R
M<VEO;B`Q+C$@*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI
M<R!F:6QE"B`@(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N
M<V4N(%EO=2!M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A
M="!H='1P.B\O=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@
M(%-O9G1W87)E('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V
M:61E9"!O;B!A;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19
M($]&($%.62!+24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$+"!)3D-,
M541)3D<L"B`@(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4
M(%1(12!33T945T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y4
M04),12P@1DE4($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.
M1E))3D=)3D<N"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC
M('!R;W9I<VEO;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI
M9V%T:6]N<R!C;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET
M:6%L($1E=F5L;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI
M8W)O<WES=&5M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N
M($UI8W)O<WES=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*
M"B`@($-O;G1R:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB
M,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S
M+F]R9R\Q.3DY+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN
M<SIO9F9I8V4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*
M("`@("`@("`@("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G1E>'0]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@
M("`@("!X;6QN<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M=&%B;&4B"B`@("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@
M("`@("`@("`@("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q
M.3DY+WAL:6YK(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@
M("`@("!X;6QN<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@
M("`@('AM;&YS.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-
M871H34PB"B`@("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M<V-R:7!T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@
M("`@("`@("`@("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@
M("`@("!O9F9I8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z9&,](FAT='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O;65T82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L
M<"(*("`@("`@("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R
M:RYC;VTO>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T96T](FAT='`Z
M+R]W=W<N:F-L87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3>7-T96TB"B`@
M("`@("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N
M;W)G+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO
M+WAM;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X
M8VQU9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*"@H*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H@("`@/"$M+2`J*BH@:&%R9"!A='1R:6)U=&5D("AI;FQI;F5D*2!P<F]P
M97)T:65S("`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/"$M+2!215-4
M4DE#5$E/3E,Z"B`@("`@("`@("`@(#$I("!!<R!T:&4@<W1Y;&5S+6YO9&4M
M=F%R:6%B;&5S(&%R92!.3U0@9VQO8F%L+"!T:&4@<W1Y;&4@=F%R:6%B;&5S
M(&%R92!N;W0@9VQO8F%L+"!E:71H97(A(0H@("`@("`@("`@("`R*2`@07,@
M82!L:7-T(&]F(&5L96UE;G1S(&-A;B!O;FQY(&)E(&%D9&5D('1O(&$@=F%R
M:6%B;&4@87,@82!R97-U;'0@=')E92!F<F%G;65N="!T:&4*("`@("`@("`@
M("`@("`@(&5X=&5N<VEO;B!I<R!N96-C97-S87)Y(2$*("`@("TM/@H*("`@
M(#PA+2T@,D1/.B!);FQI;F4@<W1Y;&5S(&1O(&YO="!I;FAE<FET(&9R;VT@
M6$U,(&]F9FEC92!D969A=6QT<R!N;W(@9F]N=#IF86UI;'D@9&5F875L=',@
M87,@=&AE('-T>6QE(&AE861E<B!D;V5S"B`@("`@("`@("`@("`@*&-P+B!S
M='EL97-H965T("=S='EL95]H96%D97(N>'-L)R!A;F0@=&AE("=W<FET92UD
M969A=6QT+7-T>6QE<R<@=&5M<&QA=&4I("TM/@H*("`@(#QX<VPZ=&5M<&QA
M=&4@;F%M93TG8W)E871E+6%L;"UI;FQI;F4M<W1Y;&5S)SX*"B`@("`@("`@
M/"$M+2HJ('1R879E<G-E92!A;&P@<W1Y;&4@=')E97,@86YD('1H96ER(&)R
M86YC:&5S(&-O;&QE8W1I;F<@<W1Y;&4@<')O<&5R=&EE<R`J*BTM/@H@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)A;&QS='EL97,B/@H@("`@("`@(#PA
M+2TJ*B!T<F%V97)S964@86QL(&]F9FEC93IS='EL97,@=')E97,@8F5G:6YN
M:6YG('=I=&@@=&AE('1O<"UL979E;"!S='EL97,J*BTM/@H@("`@("`@("`@
M("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IS='EL97,O<W1Y;&4Z
M<W1Y;&5;;F]T*$!S='EL93IP87)E;G0M<W1Y;&4M;F%M92E=(CX*"B`@("`@
M("`@("`@("`@("`\(2TM*BH@9VEV92!O=70@=&AE('-T>6QE('!R;W!E<G1I
M97,@;V8@=&AE('!A<F5N="!N;V1E("HJ+2T^"B`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG=W)I=&4M8W5R<F5N="UA;F0M:6YH
M97)I=&5D+7-T>6QE+7!R;W!E<G1I97,G/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL97,M;F]D92(@("`@("`@("`@
M("`@("`@("!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+69A;6EL>2(@
M("`@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN
M86UE+71O:V5N:7IE9"(@("`@("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y
M;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`@("`@/"$M+2HJ(&%L
M;"!O9F9I8V4Z<W1Y;&5S(&-H:6QD<F5N(&]F('1H92!C=7)R96YT('1O<"UL
M979E;"!O9F9I8V4Z<W1Y;&5S("HJ+2T^"B`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TG9F]R+6%L;"UT96UP;&%T97,M8VAI;&0M
M<W1Y;&5S)SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<&%R96YT4W1Y;&5.86UE(B`@("`@("`@("`@("`@<V5L96-T/2)`
M<W1Y;&4Z;F%M92(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)P87)E;G13='EL949A;6EL>2(@("`@("`@("`@("!S96QE
M8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@
M("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@
M)R<I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*
M("`@("`@("`@("`@("`@(#PA+2TJ*B!A;&P@;V9F:6-E.F%U=&]M871I8RUS
M='EL97,@8VAI;&1R96X@;V8@=&AE(&-U<G)E;G0@=&]P+6QE=F5L('-T>6QE
M("HJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TG9F]R+6%L;"UA=71O;6%T:6,M8VAI;&0M<W1Y;&5S)SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.
M86UE(B`@("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13
M='EL949A;6EL>2(@("`@("`@("`@("!S96QE8W0](D!S='EL93IF86UI;'DB
M+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T<F%N<VQA
M=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IF
M;W(M96%C:#X*"B`@("`@("`@/"$M+2HJ('1R879E<G-E92!A;&P@;V9F:6-E
M.F%U=&]M871I8RUS='EL97,@=')E97,@8F5G:6YN:6YG('=I=&@@=&AE('1O
M<"UL979E;"!S='EL97,@*BHM+3X*("`@("`@("`@("`@/'AS;#IF;W(M96%C
M:"!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL
M95MN;W0H0'-T>6QE.G!A<F5N="US='EL92UN86UE*5TB/@H@("`@("`@("`@
M("`@("`@/"$M+2HJ(&=I=F4@;W5T('1H92!S='EL92!P<F]P97)T:65S(&]F
M('1H92!P87)E;G0@;F]D92`J*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64])W=R:71E+6-U<G)E;G0M86YD+6EN:&5R:71E
M9"US='EL92UP<F]P97)T:65S)SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@
M("`@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,B+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M9F%M
M:6QY(B`@("`@("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T
M>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E
M*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@("`@("`\(2TM
M*BH@86QL(&-H:6QD<F5N(&]F('1H92!T;W`M;&5V96P@;V9F:6-E.F%U=&]M
M871I8RUS='EL97-S("`J*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64])V9O<BUA;&PM875T;VUA=&EC+6-H:6QD+7-T>6QE
M<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G!A<F5N=%-T>6QE3F%M92(@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE
M.FYA;64B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`
M<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@('-E
M;&5C=#TB=')A;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2=F;W(M86QL+71E;7!L871E<RUC:&EL9"US='EL97,G/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE(B\^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)P87)E;G13='EL949A;6EL>2(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B+SX*"B`@("`@
M("`@/'AS;#IF;W(M96%C:"!S96QE8W0](BXN+W-T>6QE.G-T>6QE6T!S='EL
M93IF86UI;'D])'!A<F5N=%-T>6QE1F%M:6QY(&%N9"!`<W1Y;&4Z<&%R96YT
M+7-T>6QE+6YA;64])'!A<F5N=%-T>6QE3F%M95TB/@H@("`@("`@("`@("`\
M(2TM*BH@9VEV92!O=70@=&AE('-T>6QE('!R;W!E<G1I97,@;V8@=&AE(&-U
M<G)E;G0@;F]D92`J*BTM/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB>R1S='EL92UN86UE+71O:V5N:7IE9'TB/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64])W=R:71E+6-U<G)E;G0M86YD+6EN
M:&5R:71E9"US='EL92UP<F]P97)T:65S)SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@
M("`@("`@("`@<V5L96-T/2(D;V9F:6-E.G-T>6QE<R(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UF86UI;'DB
M("`@("`@("`@("`@("`@("!S96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M
M;F%M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T
M>6QE.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H*("`@("`@("`@("`@/"$M+2HJ(&9O<B!A;&P@=&5M<&QA=&4M8VAI;&1R
M96X@;V8@=&AE(&-U<G)E;G0@;V9F:6-E.G-T>6QE<R`@*BHM+3X*("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64])V9O<BUA;&PM=&5M<&QA
M=&5S+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@("`@<V5L
M96-T/2(D;V9F:6-E.G-T>6QE<R(O/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M92(@("`@("`@("`@("`@
M('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL949A;6EL>2(@("`@("`@("`@
M("!S96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE9"(@("`@
M("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I+UPG
M+"`G)RDB+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@
M("`@("`@("`@(#PA+2TJ*B!F;W(@86QL(&%U=&]M871I8RUC:&EL9')E;B!O
M9B!T:&4@8W5R<F5N="!O9F9I8V4Z<W1Y;&5S("`J*BTM/@H@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG9F]R+6%L;"UA=71O;6%T:6,M
M8VAI;&0M<W1Y;&5S)SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)S='EL97,M;F]D92(@("`@("`@("`@("`@("`@("!S96QE8W0]
M(B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R(O/@H@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M92(@("`@("`@
M("`@("`@('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL949A;6EL>2(@("`@
M("`@("`@("!S96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE
M9"(@("`@("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@
M)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`\+WAS;#IT96UP;&%T
M93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG9F]R+6%L;"UA=71O;6%T
M:6,M8VAI;&0M<W1Y;&5S)SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T
M>6QE<RUN;V1E(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P87)E;G13
M='EL94YA;64B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!A<F5N=%-T
M>6QE1F%M:6QY(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL92UN
M86UE+71O:V5N:7IE9"(O/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C
M=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL
M93IF86UI;'D])'!A<F5N=%-T>6QE1F%M:6QY(&%N9"!`<W1Y;&4Z<&%R96YT
M+7-T>6QE+6YA;64])'!A<F5N=%-T>6QE3F%M95TB/@H@("`@("`@("`@("`\
M(2TM*BH@9VEV92!O=70@=&AE('-T>6QE('!R;W!E<G1I97,@;V8@=&AE(&-U
M<G)E;G0@;F]D92`J*BTM/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB>R1S='EL92UN86UE+71O:V5N:7IE9'TB/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64])W=R:71E+6-U<G)E;G0M86YD+6EN
M:&5R:71E9"US='EL92UP<F]P97)T:65S)SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@
M("`@("`@("`@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,B+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y
M;&4M9F%M:6QY(B`@("`@("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M
M:6QY(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-T>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A
M;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*"B`@("`@("`@("`@(#PA+2TJ*B!F;W(@86QL(&%U=&]M
M871I8RUC:&EL9')E;B!O9B!T:&4@8W5R<F5N="!O9F9I8V4Z875T;VUA=&EC
M+7-T>6QE<R`@*BHM+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64])V9O<BUA;&PM875T;VUA=&EC+6-H:6QD+7-T>6QE<R<^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5S+6YO9&4B
M("`@("`@("`@("`@("`@("`@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS
M='EL97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P87)E;G13='EL94YA;64B("`@("`@("`@("`@("!S96QE8W0](D!S='EL
M93IN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y
M;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T
M<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T
M92!N86UE/2=W<FET92UC=7)R96YT+6%N9"UI;FAE<FET960M<W1Y;&4M<')O
M<&5R=&EE<R<^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL92UF86UI
M;'DB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE
M9"(O/@H*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB>R1S='EL92UN86UE
M+71O:V5N:7IE9'TB/@H@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F-U<G)E;G0M<W1Y;&4M;F%M92(@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A<F5N="US='EL92UN
M86UE(B!S96QE8W0](D!S='EL93IP87)E;G0M<W1Y;&4M;F%M92(O/@H*("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N97<M<')O<&5R='DM;&ES
M="(^"B`@("`@("`@("`@("`@("`\(2TM*BHJ($-/3$Q%0U0@4U193$4@0514
M4DE"551%4R`H;VYL>2!T;W!L979E;"D@*BHJ+2T^"B`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&4M<')O<&5R
M=&EE<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-T>6QE071T<FEB=71E4&%T:"(@("!S96QE8W0](B1S='EL97,M;F]D
M92]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21S='EL92UF86UI;'D@86YD
M($!S='EL93IN86UE/21C=7)R96YT+7-T>6QE+6YA;65=+W-T>6QE.G!R;W!E
M<G1I97,O0"HB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA+2TJ*BH@0$5N9#H@1TE6
M12!/550@06QL($-/3$Q%0U1%1"!35%E,12!!5%1224)55$53("AO;FQY('1O
M<&QE=F5L*2`J*BHM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)S=')I;F<M;&5N9W1H*"1P87)E;G0M<W1Y;&4M;F%M92D],"(^"B`@("`@
M("`@("`@("`@("`\(2TM*BH@:68@;F\@<W1Y;&5087)E;G0@:7,@9VEV96XL
M('1H92!P<F]P97)T:65S(&%R92!G:79E;B!O=70@870@;VYC92`J*BTM/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)N;W)M
M86QI>F4M<W!A8V4H)&YE=RUP<F]P97)T>2UL:7-T*2(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M;F5W+7!R;W!E<G1Y+6YA;65S(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IF;W(M96%C:"!S96QE8W0](B1S='EL97,M;F]D92]S='EL93IS='EL
M95M`<W1Y;&4Z9F%M:6QY/21S='EL92UF86UI;'D@86YD($!S='EL93IN86UE
M/21C=7)R96YT+7-T>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,O0"HB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](FYA;64H*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IF
M;W(M96%C:#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*
M("`@("`@("`@("`@("`@("`@("`\(2TM*BH@9G5R=&AE<B!A='1R:6)U=&5S
M(&]F('1H92!P87)E;G0@<W1Y;&4@;75S="!B92!C;VQL96-T960@*BHM+3X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M861D+7!A<F5N="US='EL92UA='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!R;W!E<G1Y+6YA;64M
M;&ES="(@("`@("`@<V5L96-T/2(D;F5W+7!R;W!E<G1Y+6YA;65S(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VUP;&5T92UP<F]P97)T>2UL:7-T(B`@('-E;&5C=#TB;F]R;6%L:7IE+7-P
M86-E*"1N97<M<')O<&5R='DM;&ES="DB+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M
M92(@("`@("`@<V5L96-T/2(D8W5R<F5N="US='EL92UN86UE(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E
M;G0M<W1Y;&4M;F%M92(@("`@("`@('-E;&5C=#TB)'!A<F5N="US='EL92UN
M86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)S='EL92UF86UI;'DB("`@("`@("`@("`@('-E;&5C=#TB)'-T
M>6QE+69A;6EL>2(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#IE;&5M96YT
M/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F%D9"UP87)E;G0M<W1Y;&4M871T<FEB=71E<R(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)P<F]P97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](F-O;7!L971E+7!R;W!E<G1Y+6QI<W0B+SX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M92(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B+SX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE+69A;6EL>2(O/@H*("`@
M("`@("`\(2TM*BHJ($YE=R!T=V\@8F4@861D960@<')O<&5R='D@;F%M97,@
M=VEL;"!B92!C;VQL96-T960@*&]N;'D@;VYE('9A<FEA8FQE('!E<B!T96UP
M;&%T92D@*BHJ+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N97<M
M<')O<&5R='DM;F%M97,B/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB9V5T+6YE=RUS='EL92UN86UE<R(^"B`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')O<&5R='DM;F%M92UL:7-T(B`@
M("`@("!S96QE8W0](B1P<F]P97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G0M<W1Y;&4M;F%M
M92(@("`@("`@('-E;&5C=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N="US='EL
M92UN86UE(B`@("`@("!S96QE8W0](B1C=7)R96YT+7-T>6QE+6YA;64B+SX*
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS
M;#IV87)I86)L93X*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M(#PA+2TJ*BH@8VAE8VL@:68@=&AE(&YE=R!P87)E;G0@<W1Y;&4@97AI<W0@
M:6X@=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S('-E8W1I;VX@*&1E9FEN
M960@8GD@;F%M92!A;F0@9F%M:6QY*2`J*BHM+3X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS
M='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z;F%M
M93TD8W5R<F5N="US='EL92UN86UE72(^"B`@("`@("`@("`@("`@("`\(2TM
M*BHJ(%)%0U524TE/3CH@861D:6YG(&YE=R!P87)E;G0@<W1Y;&4@871T<FEB
M=71E<R!T;R!T:&4@8W5R<F5N="!S='EL92`J*BHM+3X*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6%T=')I8G5T
M97,B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)G970M;F5W+7-T>6QE+6%T=')I8G5T97,B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;F5W+7!R;W!E<G1Y
M+6YA;65S(B`@("`@("`@("`@<V5L96-T/2(D;F5W+7!R;W!E<G1Y+6YA;65S
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C=7)R96YT+7-T>6QE+6YA;64B("`@("`@("`@("!S96QE8W0](B1C
M=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N="US='EL92UN86UE(B`@("`@
M("`@("`@('-E;&5C=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@/"$M+2HJ*B!%
M;F0@0T].1$E424]..B!T:&4@;&%S="!S='EL92!P87)E;G0@:&%S(&%L<F5A
M9'D@8F5E;B!E>&5C=71E9"`J*BHM+3X*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB;F5W+7!A<F5N="US='EL92UN86UE(B`@<V5L96-T
M/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE
M.F9A;6EL>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64])'!A<F5N="US
M='EL92UN86UE72]`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64B+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)S=')I;F<M;&5N9W1H*"1N97<M<&%R96YT+7-T>6QE
M+6YA;64I/3`B/@H@("`@("`@("`@("`@("`@("`@(#PA+2TJ*B!N;R!F=7)T
M:&5R('!A<F5N="!I<R!F;W5N9"P@=&AE(&=I=F5N('!A<F%M971E<B!P<F]P
M97)T>2UN;V1E(&ES('1H92!F:6YA;"!S='EL92`M+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D8V]M
M<&QE=&4M<')O<&5R='DM;&ES="PD;F5W+7!R;W!E<G1Y+6%T=')I8G5T97,I
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`\(2TM*BH@9G5R=&AE<B!A='1R:6)U=&5S(&]F('1H92!P87)E;G0@<W1Y
M;&4@;75S="!B92!C;VQL96-T960@*BHM+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9"UP87)E;G0M<W1Y
M;&4M871T<FEB=71E<R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<')O<&5R='DM;F%M92UL:7-T(B`@("`@
M("!S96QE8W0](F-O;F-A="@D<')O<&5R='DM;F%M92UL:7-T+"`D;F5W+7!R
M;W!E<G1Y+6YA;65S*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;7!L971E+7!R;W!E<G1Y+6QI<W0B
M("`@<V5L96-T/2)C;VYC870H)&-O;7!L971E+7!R;W!E<G1Y+6QI<W0L)&YE
M=RUP<F]P97)T>2UA='1R:6)U=&5S*2(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M
M;F%M92(@("`@("`@<V5L96-T/2(D<&%R96YT+7-T>6QE+6YA;64B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P87)E;G0M<W1Y;&4M;F%M92(@("`@("`@('-E;&5C=#TB)&YE=RUP87)E
M;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+69A;6EL>2(@("`@("`@("`@
M("`@<V5L96-T/2(D<W1Y;&4M9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M
M+2HJ('1H92!S<&5C:69I8R!S='EL92`H9&5F:6YE9"!B>2!N86UE(&%N9"!F
M86UI;'DI(&UU<W0@8F4@9F]U;F0@:6X@=&AE(&]F9FEC93IS='EL97,@<V5C
M=&EO;B`M+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`\(2TM*BHJ(%)%0U524TE/3CH@861D:6YG(&YE=R!P87)E;G0@
M<W1Y;&4@871T<FEB=71E<R!T;R!T:&4@8W5R<F5N="!S='EL92`J*BHM+3X*
M("`@("`@("`@("`@("`@(#PA+2TJ*BH@861D:6YG(&YE=R!P87)E;G0@<W1Y
M;&4@871T<FEB=71E<R!T;R!T:&4@8W5R<F5N="!S='EL92`J*BHM+3X*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y
M+6%T=')I8G5T97,B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)G970M;F5W+7-T>6QE+6%T=')I8G5T97,B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;F5W
M+7!R;W!E<G1Y+6YA;65S(B`@("`@("`@("`@<V5L96-T/2(D;F5W+7!R;W!E
M<G1Y+6YA;65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B("`@("`@("`@("!S
M96QE8W0](B1C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N="US='EL92UN
M86UE(B`@("`@("`@("`@('-E;&5C=#TB)'!A<F5N="US='EL92UN86UE(B\^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@
M/"$M+2HJ*B!%;F0@0T].1$E424]..B!T:&4@;&%S="!S='EL92!P87)E;G0@
M:&%S(&%L<F5A9'D@8F5E;B!E>&5C=71E9"`J*BHM+3X*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!A<F5N="US='EL92UN86UE
M(B`@<V5L96-T/2(D;V9F:6-E.G-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z
M9F%M:6QY/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T
M>6QE+6YA;65=+T!S='EL93IP87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](G-T<FEN9RUL96YG=&@H)&YE=RUP87)E;G0M<W1Y;&4M
M;F%M92D],"(^"B`@("`@("`@("`@("`@("`@("`@/"$M+2HJ(&YO(&9U<G1H
M97(@<&%R96YT(&ES(&9O=6YD+"!T:&4@9VEV96X@<&%R86UE=&5R('!R;W!E
M<G1Y+6YO9&4@:7,@=&AE(&9I;F%L('-T>6QE("TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1C;VUP
M;&5T92UP<F]P97)T>2UL:7-T+"1N97<M<')O<&5R='DM871T<FEB=71E<RDB
M+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M(#PA+2TJ*B!F=7)T:&5R(&%T=')I8G5T97,@;V8@=&AE('!A<F5N="!S='EL
M92!M=7-T(&)E(&-O;&QE8W1E9"`J*B`@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A9&0M<&%R96YT+7-T
M>6QE+6%T=')I8G5T97,B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G!R;W!E<G1Y+6YA;64M;&ES="(@("`@
M("`@<V5L96-T/2)C;VYC870H)'!R;W!E<G1Y+6YA;64M;&ES="P@)&YE=RUP
M<F]P97)T>2UN86UE<RDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VUP;&5T92UP<F]P97)T>2UL:7-T
M(B`@('-E;&5C=#TB8V]N8V%T*"1C;VUP;&5T92UP<F]P97)T>2UL:7-T+"1N
M97<M<')O<&5R='DM871T<FEB=71E<RDB+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE
M+6YA;64B("`@("`@('-E;&5C=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<&%R96YT+7-T>6QE+6YA;64B("`@("`@("!S96QE8W0](B1N97<M<&%R
M96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UF86UI;'DB("`@("`@("`@
M("`@('-E;&5C=#TB)'-T>6QE+69A;6EL>2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT
M96UP;&%T92!N86UE/2)G970M;F5W+7-T>6QE+6YA;65S(CX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](G!R;W!E<G1Y+6YA;64M;&ES="(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M92(O/@H@("`@
M("`@(#PA+2TJ*B!W:&5R92!T;R!F:6YD('1H92!S<&5C:69I8R!S='EL92`H
M9&5F:6YE9"!B>2!N86UE(&%N9"!F86UI;'DI('=H971E<B!I;B!O9F9I8V4Z
M875T;VUA=&EC+7-T>6QE<R!O<B!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@+2T^
M"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2TJ*B!I9B!T
M:&4@<W!E8VEF:6,@<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M:6QY
M*2!C86X@8F4@9F]U;F0@:6X@=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S
M('-E8W1I;VX@+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;V9F
M:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL
M>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL92UN
M86UE72(^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A
M<F5N="UP<F]P97)T>2UN;V1E(B!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC
M+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A<&@G
M(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T>6QE+6YA;65=+W-T>6QE.G!R
M;W!E<G1I97,B+SX*"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](FYE=RUP<F]P97)T>2UN86UE+6QI<W0B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D<&%R96YT+7!R;W!E<G1Y+6YO
M9&4O0"I;;F]T*&-O;G1A:6YS*"1P<F]P97)T>2UN86UE+6QI<W0L(&YA;64H
M*2DI72(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)N86UE*"DB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IF
M;W(M96%C:#X*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1N97<M<')O<&5R
M='DM;F%M92UL:7-T(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#PA+2TJ*B!T:&4@<W!E8VEF:6,@<W1Y;&4@*&1E9FEN960@8GD@
M;F%M92!A;F0@9F%M:6QY*2!S:&]U;&0@8F4@9F]U;F0@:6X@=&AE(&]F9FEC
M93IS='EL97,@<V5C=&EO;B`M+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A<F5N
M="UP<F]P97)T>2UN;V1E(B!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W-T>6QE
M.G-T>6QE6T!S='EL93IF86UI;'D])W!A<F%G<F%P:"<@86YD($!S='EL93IN
M86UE/21P87)E;G0M<W1Y;&4M;F%M95TO<W1Y;&4Z<')O<&5R=&EE<R(O/@H@
M("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N97<M<')O<&5R
M='DM;F%M92UL:7-T(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE
M86-H('-E;&5C=#TB)'!A<F5N="UP<F]P97)T>2UN;V1E+T`J6VYO="AC;VYT
M86EN<R@D<')O<&5R='DM;F%M92UL:7-T+"!N86UE*"DI*5TB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB;F%M92@I
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@
M("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(O
M/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F=E="UN97<M<W1Y;&4M871T<FEB=71E<R(^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)N97<M<')O<&5R='DM;F%M97,B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M92(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B+SX*"B`@
M("`@("`@/"$M+2HJ('=H97)E('1O(&9I;F0@=&AE('-P96-I9FEC('-T>6QE
M("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@=VAE=&AE<B!I;B!O9F9I
M8V4Z875T;VUA=&EC+7-T>6QE<R!O<B!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@
M+2T^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2TJ*B!I
M9B!T:&4@<W!E8VEF:6,@<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M
M:6QY*2!C86X@8F4@9F]U;F0@:6X@=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y
M;&5S('-E8W1I;VX@+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D
M;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A
M;6EL>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL
M92UN86UE72(^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(G!A<F5N="UP<F]P97)T>2UN;V1E(B!S96QE8W0](B1O9F9I8V4Z875T;VUA
M=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A
M<&@G(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T>6QE+6YA;65=+W-T>6QE
M.G!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+7!R
M;W!E<G1I97,B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<W1Y;&5!='1R:6)U=&50871H(B`@('-E;&5C=#TB)'!A
M<F5N="UP<F]P97)T>2UN;V1E+T`J6V-O;G1A:6YS*"1N97<M<')O<&5R='DM
M;F%M97,L(&YA;64H*2E=(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FYO<FUA
M;&EZ92US<&%C92@D;F5W+7!R;W!E<G1Y+6YA;64M;&ES="DB+SX*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/"$M+2HJ(&]T:&5R=VES
M92!T:&4@<W!E8VEF:6,@<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M
M:6QY*2!S:&]U;&0@8F4@9F]U;F0@:6X@=&AE(&]F9FEC93IS='EL97,@<V5C
M=&EO;B`M+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A<F5N="UP<F]P97)T>2UN
M;V1E(B!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL
M93IF86UI;'D])W!A<F%G<F%P:"<@86YD($!S='EL93IN86UE/21P87)E;G0M
M<W1Y;&4M;F%M95TO<W1Y;&4Z<')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)N97<M<')O<&5R='DM;F%M92UL:7-T
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB=W)I=&4M<W1Y;&4M<')O<&5R=&EE<R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL94%T=')I8G5T95!A
M=&@B("`@<V5L96-T/2(D<&%R96YT+7!R;W!E<G1Y+6YO9&4O0"I;8V]N=&%I
M;G,H)&YE=RUP<F]P97)T>2UN86UE<RP@;F%M92@I*5TB+SX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"1N97<M<')O<&5R='DM;F%M
M92UL:7-T*2(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*/"]X<VPZ
M<W1Y;&5S:&5E=#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R
M+V]O;R]S='EL95]M87!P:6YG+GAS;```````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$Q,#0S,@`Q
M,#0Q-S,V,C<W,P`P,C0T,C(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@
M9FEL92!A<F4@;6%D92!A=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@
M;V8*("`@96ET:&5R(&]F('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@
M("`@("`M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S
M:6]N(#(N,0H@("`@("`@("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O
M=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US
M($EN8RXL($]C=&]B97(L(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P
M,#`@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N
M:6\@4F]A9"P@4&%L;R!!;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI
M8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@
M:70@86YD+V]R"B`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N
M(#(N,2P@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD
M871I;VXN"@H@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE
M(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@
M04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N
M='D@;V8*("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%2
M5$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R
M86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S
M:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@
M1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB
M<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&
M;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@
M0F]S=&]N+`H@("!-02`@,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S
M=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"B`@(%1H92!C;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@
M=&\@=&AE(%-U;B!);F1U<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N
M<V4@5F5R<VEO;B`Q+C$@*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U
M<V4@=&AI<R!F:6QE"B`@(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE
M($QI8V5N<V4N(%EO=2!M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC
M96YS92!A="!H='1P.B\O=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M
M;"X*"B`@(%-O9G1W87)E('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I
M<R!P<F]V:61E9"!O;B!A;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!
M4E)!3E19($]&($%.62!+24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$
M+"!)3D-,541)3D<L"B`@(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%
M4R!42$%4(%1(12!33T945T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%
M4D-(04Y404),12P@1DE4($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@
M3D].+4E.1E))3D=)3D<N"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P
M96-I9FEC('!R;W9I<VEO;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@
M("!O8FQI9V%T:6]N<R!C;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H
M92!);FET:6%L($1E=F5L;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@
M4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@
M8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E
M<G9E9"X*"B`@($-O;G1R:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R
M<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O
M=W=W+G<S+F]R9R\Q.3DY+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@
M("!X;6QN<SIO9F9I8V4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F
M9FEC92(*("`@("`@("`@("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS
M.G1E>'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@
M("`@("`@("`@("!X;6QN<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O=&%B;&4B"B`@("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA
M="(*("`@("`@("`@("`@("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S
M+F]R9R\Q.3DY+WAL:6YK(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@
M("`@("`@("`@("!X;6QN<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O
M<W9G(@H@("`@("`@("`@("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M9'(S9#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@
M("`@("`@("`@('AM;&YS.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O
M36%T:"]-871H34PB"B`@("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z<V-R:7!T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I
M<'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@
M("`@("`@("`@("!O9F9I8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z9&,](FAT='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I
M8V4N;W)G+S(P,#`O;65T82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I
M9STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O:&5L<"(*("`@("`@("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W
M+FIC;&%R:RYC;VTO>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T96T]
M(FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3>7-T
M96TB"B`@("`@("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA
M<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB
M:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@
M("`@(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*"@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)W<FET92US='EL92UP<F]P97)T:65S(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE071T<FEB=71E4&%T:"(O/@H*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK($-3
M4R!04D]015)42453("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<@;W(@)&]U='!U=%1Y
M<&4@/2`G0U-37TE.3$E.140G(CX*"B`@("`@("`@("`@("`@("`\>'-L.F9O
M<BUE86-H('-E;&5C=#TB)'-T>6QE071T<FEB=71E4&%T:"(^"B`@("`@("`@
M("`@("`@("`\(2TM(&ES1&5B=6=-;V1E34534T%'13H*("`@("`@("`@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^($YA;64Z/'AS;#IV86QU92UO9B!S96QE
M8W0](FYA;64H*2(O/B!686QU93H\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O
M/CPO>'-L.FUE<W-A9V4^("`@("`@+2T^"@H*("`@("`@("`@("`@("`@("`@
M("`\(2TM(#PA05143$E35"!S='EL93IP<F]P97)T:65S('-T>6QE.FAO<FEZ
M;VYT86PM<&]S("AF<F]M+6QE9G1\;&5F='QC96YT97)\<FEG:'1\9G)O;2UI
M;G-I9&5\:6YS:61E?&]U='-I9&4I(TE-4$Q)140^+2T^"B`@("`@("`@("`@
M("`@("`@("`@/"$M+2`R1$\Z(&ES(&EN<VED92]F<F]M+6EN<VED92!A;'-O
M(&)E='1E<B!S:&]W86)L92`_("TM/@H@("`@("`@("`@("`@("`@("`@(#PA
M+2T@(2$A(2`R1$\Z(%-T:6QL('1H97)E(&AA=F4@=&\@8F4@<&QA8V5D(&$@
M/&)R(&-L96%R/2=A;&PG+SX@=&\@9&ES86)L92!T:&4@9FQO=R$A(2$M+3X*
M("`@("`@("`@("`@("`@("`@("`\(2TM("`@("`@("`@("!4:&4@3T]O(&%T
M=')I8G5T92`G<W1Y;&4Z;G5M8F5R+7=R87!P960M<&%R86=R87!H<R<@:7,@
M8W5R<F5N=&QY(&EG;F]R960@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2=N86UE*"XI/2)S='EL93IW<F%P(B<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG+CTB;&5F="(G/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^9FQO870Z
M(')I9VAT.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0])RX](G)I9VAT(B<^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YF;&]A=#H@;&5F
M=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA
M;64H+BD@/2`B<W1Y;&4Z:&]R:7IO;G1A;"UP;W,B)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<N/2)L969T(B<^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YA
M;&EG;CH@;&5F=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<N/2)R:6=H="(G/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ
M(')I9VAT.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0])RX](F-E;G1E<B(G/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ(&-E
M;G1E<CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H\(2TM(')E<W5L=',@:6YT;R!A(&)A9"!V:65W("AO=F5R;&%P<&5D
M*2!I;B!-;WII;&QA(#$N,`H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TG;F%M92@N*2`](")T86)L93IA;&EG;B(G/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX](FQE9G0B
M)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F9L;V%T.B!R:6=H=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<N/2)R:6=H="(G/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M9FQO870Z(&QE9G0[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*+2T^"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M(%!!1$1)3D<@9F]R(&%L;"!V87)I871I;VYS.B!F;SIP861D:6YG+"!F;SIP
M861D:6YG+71O<"P@9F\Z<&%D9&EN9RUB;W1T;VTL(&9O.G!A9&1I;F<M;&5F
M="P@9F\Z<&%D9&EN9RUR:6=H="`M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])V-O;G1A:6YS*&YA;64H+BDL(F9O.G!A9&1I
M;F<B*2<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M<&%D9&EN9SH@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\(2TM"B`@("`@("`@("`@("`@("`@("`@("`@(&9O.F)O<F1E
M<@H@("`@("`@("`@("`@("`@("`@("`@("!F;SIB;W)D97(M=&]P"B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O.F)O<F1E<BUB;W1T;VT*("`@("`@("`@
M("`@("`@("`@("`@("`@9F\Z8F]R9&5R+6QE9G0*("`@("`@("`@("`@("`@
M("`@("`@("`@9F\Z8F]R9&5R+7)I9VAT"@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@070@<')E<V5N="P@86QL(&9O=7(@8F]R9&5R<R!M=7-T(&)E
M('-E="!S:6UU;'1A;F5O=7-L>2!B>2!U<VEN9R!E:71H97(*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H92!F;SIB;W)D97(@<')O<&5R='D@;W(@
M8GD@871T86-H:6YG(&%L;"!F;W5R(&]F('1H92!O=&AE<B!B;W)D97(*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('!R;W!E<G1I97,@=&\@86X@:71E
M;2!S970@96QE;65N="X@26X@=&AE(&QA='1E<B!C87-E+"!I9B!O;F4@;W(@
M;6]R90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V8@=&AE('!R;W!E
M<G1I97,@:7,@;6ES<VEN9R!T:&5I<B!V86QU97,@87)E(&%S<W5M960@=&\@
M8F4@;F]N92X@5&AE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!O;FQY
M(&)O<F1E<B!S='EL97,@<W5P<&]R=&5D(&%R92!N;VYE(&]R(&AI9&1E;BP@
M<V]L:60L(&%N9"!D;W5B;&4N($%N>0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;W1H97(@8F]R9&5R('-T>6QE('-P96-I9FEE9"!I<R!D:7-P;&%Y
M960@87,@<V]L:60N(%1R86YS<&%R96YT(&)O<F1E<G,*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R92!N;W0@<W5P<&]R=&5D(&%N9"!T:&4@8F]R
M9&5R('=I9'1H<R!T:&EN+"!M961I=6TL(&%N9"!T:&EC:R!A<F4*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&UA<'!E9"!T;R!L96YG=&AS+B!);B!A
M9&1I=&EO;BP@;VYL>2!S;VUE(&1I<W1I;F-T(&)O<F1E<B!W:61T:',@87)E
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=7!P;W)T960N(%5N<W5P
M<&]R=&5D('=I9'1H<R!A<F4@<F]U;F1E9"!U<"!T;R!T:&4@;F5X="!S=7!P
M;W)T960*("`@("`@("`@("`@("`@("`@("`@("`@("`@('=I9'1H+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@268@=&AE<F4@87)E(&YO('!A9&1I
M;F<@<')O<&5R=&EE<R!S<&5C:69I960@=VET:&EN('1H92!S86UE"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I=&5M('-E="!E;&5M96YT+"!A(&1E
M9F%U;'0@<&%D9&EN9R!I<R!U<V5D(&9O<B!S:61E<R!T:&%T(&AA=F4@80H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8F]R9&5R+B!!('9A;'5E(&]F
M(#!C;2!I<R!U<V5D(&9O<B!S:61E<R!W:71H;W5T(&$@8F]R9&5R+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*&-P+B!W9"US;RUX;6PM=&5X="YS
M9'<I"B`@("`@("`@("`@("`@("`@("`@("`@("TM/@H*/"$M+3)$3R!35$%2
M5#H@8VAA;F=E(&UE87-U<F5M96YT(&5Q=6%L;'D@+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIB;W)D
M97(B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8VAA;F=I
M;F<@=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@+2T^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O
M;G1A:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUW:61T:#H\+WAS;#IT97AT/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F;W)E*"XL)V-H("<I
M(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUS='EL93H\+WAS
M;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F;W)E
M*'-U8G-T<FEN9RUA9G1E<B@N+"=C:"`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L;W(Z/"]X<VPZ=&5X=#X\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*'-U8G-T<FEN9RUA9G1E
M<B@N+"=C:"`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H+BP@)V-M)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7=I9'1H.CPO>'-L.G1E>'0^
M/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG("<I
M(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUS='EL93H\+WAS
M;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F;W)E
M*'-U8G-T<FEN9RUA9G1E<B@N+"=C;2`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L;W(Z/"]X<VPZ=&5X=#X\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*'-U8G-T<FEN9RUA9G1E
M<B@N+"=C;2`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H+BP@)W!T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7=I9'1H.CPO>'-L.G1E>'0^
M/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG("<I
M(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUS='EL93H\+WAS
M;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F;W)E
M*'-U8G-T<FEN9RUA9G1E<B@N+"=P="`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L;W(Z/"]X<VPZ=&5X=#X\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*'-U8G-T<FEN9RUA9G1E
M<B@N+"=P="`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F)O<F1E<BUT
M;W`B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB
M;W)D97(M=&]P.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N
M(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F)O<F1E<BUB;W1T;VTB)SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M8F]T
M=&]M.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0])VYA;64H+BD](F9O.F)O<F1E<BUL969T(B<^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+6QE9G0Z(#PO>'-L
M.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M
M92@N*3TB9F\Z8F]R9&5R+7)I9VAT(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7)I9VAT.B`\+WAS;#IT97AT/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T
M>6QE.F-O;'5M;BUW:61T:"(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R93H@:6YC:"!T
M;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X<VPZ
M=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R92@N
M+"=C:"<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X
M<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M;F%M92@N*3TB<W1Y;&4Z<F]W+6AE:6=H="(G/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R
M93H@:6YC:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^:&5I
M9VAT.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN
M9RUB969O<F4H+BPG8V@G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/FAE:6=H=#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^
M/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2=N86UE*"XI/2)F;SIW:61T:"(G/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A
M<W5R93H@:6YC:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R
M:6YG+6)E9F]R92@N+"=C:"<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O
M/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H\(2TM,D1/($5.1#H@8VAA;F=E(&UE87-U<F5M
M96YT(&5Q=6%L;'D@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT+7-T>6QE(B<^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B
M<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E>'0^.CPO>'-L
M.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M
M92@N*3TB<W1Y;&4Z9F]N="UN86UE(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^9F]N="UF86UI;'DZ/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](F-O;G1E;G0B('-E;&5C=#TB+B(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;V9F:6-E.F9O
M;G0M9&5C;',O<W1Y;&4Z9F]N="UD96-L6T!S='EL93IN86UE/21C;VYT96YT
M72]`9F\Z9F]N="UF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.FEF('1E<W0](F-O;G1A:6YS*"1O9F9I8V4Z9F]N
M="UD96-L<R]S='EL93IF;VYT+61E8VQ;0'-T>6QE.FYA;64])&-O;G1E;G1=
M+T!S='EL93IF;VYT+7-T>6QE+6YA;64L("=)=&%L:6,G*2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F9O;G0M<W1Y;&4Z
M:71A;&EC.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.FEF('1E<W0](F-O;G1A:6YS*"1O9F9I8V4Z9F]N="UD96-L<R]S='EL93IF
M;VYT+61E8VQ;0'-T>6QE.FYA;64])&-O;G1E;G1=+T!S='EL93IF;VYT+7-T
M>6QE+6YA;64L("=";VQD)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YF;VYT+7=E:6=H=#IB;VQD.R`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT+7=E
M:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^
M/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N
M(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F9O;G0M<VEZ92(G/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U
M8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS
M;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@
M/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA
M;64H+BD](F9O.F9O;G0M9F%M:6QY(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R
M*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E>'0^/'AS;#IV
M86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z8V]L
M;W(B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M92@N*2P@)SHG*2(O/CQX
M<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O
M/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2=N86UE*"XI/2)F;SIM87)G:6XM;&5F="(G/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U
M8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS
M;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@
M/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA
M;64H+BD](F9O.FUA<F=I;BUR:6=H="(G/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E
M<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ
M=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.FUA
M<F=I;BUT;W`B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M92@N*2P@)SHG
M*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIM87)G:6XM8F]T=&]M(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E
M>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L
M.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TG;F%M92@N*3TB9F\Z;&EN92UH96EG:'0B)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I
M;F<M869T97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X
M=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI
M/2)F;SIT97AT+6%L:6=N(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM($E-4$]25$%.5"!I<R!N96-E<W-A<GD@87,@=&%B;&4@8V5L;"!V
M86QU92!A;&EG;FUE;G0@:7,@9&5C:61E9"!B>2!R=6YT:6UE(&]V97(@=&AE
M('9A;'5E='EP90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!/
M=&AE<G=I<V4@82!T86)L92!C96QL('-T>6QE+6-L87-S('=I;&P@04Q705E3
M(&)E(&]V97)W<FET=&5N(&)Y('1H92!R=6XM=&EM92!V86QU92`M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N
M=&%I;G,H+BP@)W-T87)T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^=&5X="UA;&EG;CIL969T("$@:6UP;W)T
M86YT.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=E;F0G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT97AT
M+6%L:6=N.G)I9VAT("$@:6UP;W)T86YT.R`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT97AT
M+6%L:6=N.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0])RXG+SX\
M>'-L.G1E>'0^("$@:6UP;W)T86YT.R`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIT97AT+6EN9&5N
M="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS
M;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^
M/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G1E>'0M8F%C:V=R;W5N9"UC;VQO
M<B(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)A
M8VMG<F]U;F0M8V]L;W(Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIB86-K9W)O=6YD+6-O;&]R
M(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F%C
M:V=R;W5N9"UC;VQO<CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.F)A8VMG<F]U;F0M:6UA
M9V4B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB
M86-K9W)O=6YD+6EM86=E.G5R;"@\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`>&QI;FLZ:')E9B(O/CQX<VPZ=&5X=#XI.R`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(D!S='EL93IR97!E870@/2`G<F5P96%T)R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB86-K9W)O=6YD+7)E<&5A
M=#IR97!E870[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/F)A8VMG<F]U;F0M<F5P96%T.FYO
M+7)E<&5A=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=&5X
M="US:&%D;W<@:7,@82!#4U,R(&9E871U<F4@86YD('EE="!N;W0@8V]M;6]N
M('5S960@:6X@=7-E<BUA9V5N=',@+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIT97AT+7-H861O=R(G
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT
M97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0])VYA;64H+BD](G-T>6QE.G1E>'0M8W)O<W-I;F<M;W5T(B<^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0])VYO="@N
M/2)N;VYE(BDG/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YT97AT+61E8V]R871I;VXZ;&EN92UT:')O=6=H.R`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IT
M97AT+75N9&5R;&EN92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#II9B!T97-T/2=N;W0H+CTB;F]N92(I)SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X="UD96-O<F%T:6]N.G5N
M9&5R;&EN93L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M;F%M92@N*3TB<W1Y;&4Z=&5X="UP;W-I=&EO;B(G/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2=C;VYT86EN<R@N+"`B<W5B
M(BDG/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YV97)T:6-A;"UA;&EG;CIS=6([(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ:68@=&5S=#TG8V]N=&%I;G,H+BP@(G-U<"(I)SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=F5R
M=&EC86PM86QI9VXZ<W5P.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@:7-$
M96)U9TUO9&5-15-304=%.@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^3F\@=')A;G-F;W)M871I;VX@:6UP;&5M96YT960@9F]R
M(&%T=')I8G5T92UT>7`@/'AS;#IV86QU92UO9B!S96QE8W0](FYA;64H+BDB
M+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^+2T^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N
M,B!354)3150@04Y$(%=!4"!04D]015)42453("`K*RLK*RTM/@H@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ9F]R
M+65A8V@@<V5L96-T/2(D<W1Y;&5!='1R:6)U=&50871H(CX*("`@("`@("`@
M("`@("`@("`@("`\(2TM(&ES1&5B=6=-;V1E34534T%'13H*("`@("`@("`@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^($YA;64Z/'AS;#IV86QU92UO9B!S
M96QE8W0](FYA;64H*2(O/B!686QU93H\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M+B(O/CPO>'-L.FUE<W-A9V4^("`@("`@+2T^"@H@("`@("`@("`@("`@("`@
M("`@(#PA+2T@0E5'(%=/4DL@05)/54Y$.@H@("`@("`@("`@("`@("`@("`@
M($1U92!T;R!A(&)U9R!I;B!T:&4@6%0@4')O8V5S<V]R+"!I="!I<R!N;W0@
M<&]S<VEB;&4@=&\@8W)E871E('-E<G9E<F%L(&5L96UE;G1S(&EN('9A<FEA
M8FQE(&%N9"!S96%R8V@@;W9E<B!T:&5M+`H@("`@("`@("`@("`@("`@("`@
M(&%F=&5R(&5X<&QI8VET(&-O;G9E<G-I;VX@=&\@;F]D97-E=`H@("`@("`@
M("`@("`@("`@("`@(%1H:7,@9V5N97)A=&5D('-T:6YG(&ED96YT:69I97(@
M<VAA;&P@8F4@;&%T97(@8VAA;F=E9"!B86-K('1O(&$@<V5T(&]F(&5L96UE
M;G1S"B`@("`@("`@("`@("`@("`@("`@+2T^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2TJ
M*BH@1D]234%4($%45%))0E5415,@*BHJ+2T^"@H@("`@("`@("`@("`@("`@
M("`@("`@("`\(2TM($ET86QI8R`M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F9O;G0M<W1Y;&4B)SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB8V]N
M=&%I;G,H+BP@)VET86QI8R<I(&]R(&-O;G1A:6YS*"XL("=O8FQI<75E)RDB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YI
M=&%L:6,L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@0F]L9&9A8V4@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE
M*"XI/2)F;SIF;VYT+7=E:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#II9B!T97-T/2)C;VYT86EN<R@N+"`G8F]L9"<I(&]R(&-O
M;G1A:6YS*"XL("=B;VQD97(G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/F)O;&0L(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PA+2T@56YD97)L:6YE("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z=&5X="UU;F1E<FQI;F4B
M)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YU;F1E
M<FQI;F4L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM($%L:6=N
M;65N="`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0])VYA;64H+BD](F9O.G1E>'0M86QI9VXB)SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)W-T
M87)T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^86QI9VXZ;&5F="P@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@N
M+"`G96YD)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G1E>'0^86QI9VXZ<FEG:'0L(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H+BP@)V-E;G1E<B<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/F%L:6=N.F-E;G1E<BP@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@<W1R:6ME=&AR;W5G:"`M+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE
M.G1E>'0M8W)O<W-I;F<M;W5T(B<^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^<W1R:6ME+"`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!&;VYT("T@<VEZ92`H4&%L;3H@96UU;&%T;W(@=')A;G-F
M;W)M960@<VEZ97,@=&\@879A:6QA8FQE('-E="`H92YG+B`S,"!T;R`H<')O
M8F%B;'DI(#DI+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT+7-I>F4B)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YS:7IE.CPO>'-L.G1E>'0^/'AS
M;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.G-I>F4L(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM($9O;G0@+2!#;VQO<B`H4$%,
M33H@8G5T(&UO<W1L>2!O;FQY(#(@879A:6QA8FQE*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8FQA8VL@*",P,#`P,#`I"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!G<F%Y("@C.#`X,#@P*2AR96YD97)E9"!A<R!D87)K
M(&=R87DI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S:6QV97(@*"-#
M,$,P0S`I*')E;F1E<F5D(&%S(&QI9VAT(&=R87DI"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!W:&ET92`H(T9&1D9&1BDM+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F-O;&]R
M(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB8V]N=&%I;G,H+B`L("<C1D9&1D9&)RD@;W(@8V]N=&%I;G,H+B`L("<C
M9F9F9F9F)RD@;W(@8V]N=&%I;G,H+B`L("=W:&ET92<I(&]R(&-O;G1A:6YS
M*"X@+"`G5TA)5$4G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YC;VQO<CHC1D9&1D9&+"`\+WAS;#IT97AT/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YC;VQO<CHC,#`P,#`P+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*"@H@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM*BHJ(%1!0DQ%($%45%))0E5415,@*BHJ+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT
M+7-I>F4B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YS:7IE.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\
M>'-L.G1E>'0^.G-I>F4L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IC;VQU;6XM=VED=&@B)SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8VAA;F=I;F<@=&AE
M(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS
M*"XL("=C:"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S
M96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG8V@G*2(O/CQX<VPZ=&5X=#XZ
M=VED=&@L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^/'AS;#IV
M86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.G=I9'1H.R`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD]
M(G-T>6QE.G)O=RUH96EG:'0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@8VAA;F=I;F<@=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@
M=&\@:6X@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/FAE:6=H=#H\+WAS
M;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F;W)E
M*"XL)V-H)RDB+SX\>'-L.G1E>'0^.FAE:6=H=#L@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M:&5I9VAT.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\
M>'-L.G1E>'0^.FAE:6=H=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IW:61T:"(G/B`\(2TM
M96%R;&EE<B!F;SIW:61T:"TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R93H@:6YC:"!T
M;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X<VPZ
M=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R92@N
M+"=C:"<I(B\^/'AS;#IT97AT/CIW:61T:#L@/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED
M=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ
M=&5X=#XZ=VED=&@[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"CPA+2T@,D1/.B!.04U)3D<@0T].5D5.
M5$E/3B!V87)I86)L92!A<F4@=W)I='1E;B!W:71H("<M)R!I;G-T96%D(&]F
M(&-A<V4M<V5N<VET:79E('=R:71I;F<@+2T^"@H*"B`@("`\(2TM("HJ*BHJ
M($U%05-54D5-14Y4($-/3E9%4E-)3TY3("HJ*BHJ"@H@("`@("H@,2!C96YT
M:6UE=&5R(#T@,3`@;6T*"B`@("`@*B`Q(&EN8V@@/2`R-2XT(&UM"B`@("`@
M("`@5VAI;&4@=&AE($5N9VQI<V@@:&%V92!A;')E861Y('-E96X@=&AE(&QI
M9VAT("AR96%D.B!T:&4@;65T<FEC('-Y<W1E;2DL('1H92!54PH@("`@("`@
M(')E;6%I;G,@;&]Y86P@=&\@=&AI<R!M961I979A;"!S>7-T96TN"@H@("`@
M("H@,2!D:61O="!P;VEN="`](#`N,S<V,#8U(&UM"B`@("`@("`@("`@(%1H
M92!D:61O="!S>7-T96T@;W)I9VEN871E9"!I;B!&<F%N8V4@8G5T('=A<R!U
M<V5D(&EN(&UO<W0@;V8@175R;W!E"@H@("`@("H@,2!P:6-A('!O:6YT(#T@
M,"XS-3$T-B!M;0H@("`@("`@("`@("!4:&4@4&EC82!P;VEN=',@<WES=&5M
M('=A<R!D979E;&]P960@:6X@16YG;&%N9"!A;F0@:7,@=7-E9"!I;B!'<F5A
M="U"<FET86EN(&%N9"!T:&4@55,N"@H@("`@("H@,2!0;W-T4V-R:7!T('!O
M:6YT(#T@,"XS-3(W-S$S."!M;0H@("`@("`@("`@("!7:&5N($%D;V)E(&-R
M96%T960@4&]S=%-C<FEP="P@=&AE>2!A9&1E9"!T:&5I<B!O=VX@<WES=&5M
M(&]F('!O:6YT<RX*("`@("`@("`@("`@5&AE<F4@87)E(&5X86-T;'D@-S(@
M4&]S=%-C<FEP="!P;VEN=',@:6X@,2!I;F-H+@H*("`@("`J(#$@<&EX96P@
M/2`P+C(V-#4X,S,S+BX@;6T@("`H8GD@.38@9'!I*0H@("`@("`@("`@("!-
M;W-T('!I8W1U<F5S(&AA=F4@=&AE(#DV(&1P:2!R97-O;'5T:6]N+"!B=70@
M=&AE(&1P:2!V87)I86)L92!M87D@=F%R>2!B>2!S='EL97-H965T('!A<F%M
M971E<@H@("`@+2T^"@H*("`@(#PA+2T@8VAA;F=I;F<@;65A<W5R92!T;R!M
M;2`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8V]N=F5R=#)M;2(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)V86QU92(O/@H*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-E;G1I;65T97(M:6XM;6TB("`@("`@("`@('-E;&5C
M=#TB,3`B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FEN8V@M:6XM;6TB
M("`@("`@("`@("`@("`@('-E;&5C=#TB,C4N-"(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB9&ED;W0M<&]I;G0M:6XM;6TB("`@("`@("`@<V5L96-T
M/2(P+C,W-C`V-2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&EC82UP
M;VEN="UI;BUM;2(@("`@("`@("`@<V5L96-T/2(P+C,U,30V(B\^"@H@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H)'9A;'5E+"`G8VTG*2(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O
M<F4H)'9A;'5E+"=C;2<@*2D@*B`D8V5N=&EM971E<BUI;BUM;2DB+SX*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F-O;G1A:6YS*"1V86QU92P@)VEN)RDB/@H@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M
M8F5F;W)E*"1V86QU92PG:6XG("DI("H@)&EN8V@M:6XM;6TI(B\^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<R@D=F%L=64L("=D<'0G*2(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB
M969O<F4H)'9A;'5E+"=D<'0G*2D@*B`D9&ED;W0M<&]I;G0M:6XM;6TI(B\^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=P<'0G*2(^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T
M<FEN9RUB969O<F4H)'9A;'5E+"=P<'0G*2D@*B`D<&EC82UP;VEN="UI;BUM
M;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/"$M+2!C:&%N9VEN9R!M96%S=7)E('1O(&-M("TM/@H@("`@/'AS;#IT
M96UP;&%T92!N86UE/2)C;VYV97)T,F-M(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](G9A;'5E(B\^"@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V5N
M=&EM971E<BUI;BUM;2(@("`@("`@("`@<V5L96-T/2(Q,"(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB:6YC:"UI;BUM;2(@("`@("`@("`@("`@("`@
M<V5L96-T/2(R-2XT(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)D:61O
M="UP;VEN="UI;BUM;2(@("`@("`@("!S96QE8W0](C`N,S<V,#8U(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)P:6-A+7!O:6YT+6EN+6UM(B`@("`@
M("`@("!S96QE8W0](C`N,S4Q-#8B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L
M("=M;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=M;2<I
M*2!D:78@)&-E;G1I;65T97(M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D
M=F%L=64L("=I;B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L
M("=I;B<I*2!D:78@)&-E;G1I;65T97(M:6XM;6T@*B`D:6YC:"UI;BUM;2DB
M+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V1P="<I(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B
M<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P="<I*2!D:78@)&-E;G1I;65T97(M
M:6XM;6T@*B`D9&ED;W0M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@D=F%L=64L("=P<'0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A
M;'5E+"=P<'0G*2D@9&EV("1C96YT:6UE=&5R+6EN+6UM("H@)'!I8V$M<&]I
M;G0M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](B1V86QU92(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S=7)E('1O(&EN8V@@*&-P+B!S
M96-T:6]N(&-O;6UE;G0I("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C
M;VYV97)T,FEN8V@B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=F%L=64B
M+SX*"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C96YT:6UE=&5R+6EN+6UM
M(B`@("`@("`@("!S96QE8W0](C$P(B\^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)I;F-H+6EN+6UM(B`@("`@("`@("`@("`@("!S96QE8W0](C(U+C0B
M+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F1I9&]T+7!O:6YT+6EN+6UM
M(B`@("`@("`@('-E;&5C=#TB,"XS-S8P-C4B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G!I8V$M<&]I;G0M:6XM;6TB("`@("`@("`@('-E;&5C=#TB
M,"XS-3$T-B(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)VUM)RDB/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E
M<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)VUM)RDI(&1I=B`D:6YC:"UI
M;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V-M)RDB/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E
M<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)V-M)RDI(&1I=B`D:6YC:"UI
M;BUM;2`J("1C96YT:6UE=&5R+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H
M)'9A;'5E+"`G9'!T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU
M92PG9'!T)RDI(&1I=B`D:6YC:"UI;BUM;2`J("1D:61O="UP;VEN="UI;BUM
M;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)W!P="<I(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H
M<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)W!P="<I*2!D:78@)&EN8V@M:6XM
M;6T@*B`D<&EC82UP;VEN="UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S=7)E
M('1O(&1P="`H8W`N('-E8W1I;VX@8V]M;65N="D@+2T^"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](F-O;G9E<G0R9'!T(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](G9A;'5E(B\^"@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V5N
M=&EM971E<BUI;BUM;2(@("`@("`@("`@<V5L96-T/2(Q,"(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB:6YC:"UI;BUM;2(@("`@("`@("`@("`@("`@
M<V5L96-T/2(R-2XT(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)D:61O
M="UP;VEN="UI;BUM;2(@("`@("`@("!S96QE8W0](C`N,S<V,#8U(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)P:6-A+7!O:6YT+6EN+6UM(B`@("`@
M("`@("!S96QE8W0](C`N,S4Q-#8B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L
M("=M;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=M;2<I
M*2!D:78@)&1I9&]T+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H
M)'9A;'5E+"`G8VTG*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E
M+"`G8VTG*2D@9&EV("1D:61O="UP;VEN="UI;BUM;2`J("1C96YT:6UE=&5R
M+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G:6XG*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M
M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G:6XG*2D@9&EV("1D:61O
M="UP;VEN="UI;BUM;2`J("1I;F-H+6EN+6UM*2(O/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H)'9A;'5E+"`G<'!T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V
M86QU92PG<'!T)RDI(&1I=B`D9&ED;W0M<&]I;G0M:6XM;6T@*B`D<&EC82UP
M;VEN="UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H*("`@(#PA+2T@8VAA;F=I;F<@;65A<W5R92!T;R!P<'0@*&-P
M+B!S96-T:6]N(&-O;6UE;G0I("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2)C;VYV97)T,G!P="(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)V86QU
M92(O/@H*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-E;G1I;65T97(M:6XM
M;6TB("`@("`@("`@('-E;&5C=#TB,3`B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](FEN8V@M:6XM;6TB("`@("`@("`@("`@("`@('-E;&5C=#TB,C4N
M-"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9&ED;W0M<&]I;G0M:6XM
M;6TB("`@("`@("`@<V5L96-T/2(P+C,W-C`V-2(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB<&EC82UP;VEN="UI;BUM;2(@("`@("`@("`@<V5L96-T
M/2(P+C,U,30V(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G;6TG*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M
M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G;6TG*2D@9&EV("1P:6-A
M+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G8VTG
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U
M;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G8VTG*2D@9&EV
M("1P:6-A+7!O:6YT+6EN+6UM("H@)&-E;G1I;65T97(M:6XM;6TI(B\^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)C;VYT86EN<R@D=F%L=64L("=I;B<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG
M+6)E9F]R92@D=F%L=64L("=I;B<I*2!D:78@)'!I8V$M<&]I;G0M:6XM;6T@
M*B`D:6YC:"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V1P
M="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R
M;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P="<I*2!D
M:78@)'!I8V$M<&]I;G0M:6XM;6T@*B`D9&ED;W0M<&]I;G0M:6XM;6TI(B\^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(B1V86QU92(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA
M+2T@8VAA;F=I;F<@;65A<W5R92!T;R!P:7AE;"!B>2!V:6$@<&%R86UE=&5R
M('!R;W9I9&5D(&1P:2`H9&]T<R!P97(@:6YC:"D@<W1A;F1A<F0@9F%C=&]R
M("AC<"X@<V5C=&EO;B!C;VUM96YT*2`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TB8V]N=F5R=#)P:7AE;"(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)V86QU92(O/@H*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-E;G1I;65T
M97(M:6XM;6TB("`@("`@("`@('-E;&5C=#TB,3`B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](FEN8V@M:6XM;6TB("`@("`@("`@("`@("`@('-E;&5C
M=#TB,C4N-"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9&ED;W0M<&]I
M;G0M:6XM;6TB("`@("`@("`@<V5L96-T/2(P+C,W-C`V-2(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB<&EC82UP;VEN="UI;BUM;2(@("`@("`@("`@
M<V5L96-T/2(P+C,U,30V(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P
M:7AE;"UI;BUM;2(@("`@("`@("`@("`@("!S96QE8W0](B1I;F-H+6EN+6UM
M(&1I=B`D9'!I(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G;6TG*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M
M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G;6TG*2D@9&EV("1P:7AE
M;"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V-M)RDB/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU
M;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)V-M)RDI(&1I=B`D<&EX
M96PM:6XM;6T@*B`D8V5N=&EM971E<BUI;BUM;2DB+SX*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A
M:6YS*"1V86QU92P@)VEN)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V
M86QU92P@)VEN)RDI(&1I=B`D<&EX96PM:6XM;6T@*B`D:6YC:"UI;BUM;2DB
M+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V1P="<I(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B
M<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P="<I*2!D:78@)'!I>&5L+6EN+6UM
M("H@)&1I9&]T+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=F%L=64B+SX*("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O
M;V\O=&%B;&4N>'-L````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#,W,#``,3`T
M,3<S-C(W-S,`,#(R-C0Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I
M;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F
M"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@
M("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R
M8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!)
M;F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P
M(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO
M(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R
M87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET
M(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R
M+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T
M:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H
M;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.
M62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y
M(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO
M=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A
M<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U
M;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O
M<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R
M>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O
M('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E
M(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E
M('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,
M:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N
M<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN
M"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@
M<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)2
M04Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@
M24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@
M5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#
M2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/
M3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C
M:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@
M;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@
M26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y
M(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V
M960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I
M;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W
M=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I
M8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT
M97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B
M"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V
M9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R
M,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@
M("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA
M=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM
M;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T
M(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@
M("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@
M('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*
M("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@
M("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ
M8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H
M='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A
M8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT
M='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@
M("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*("`@(#PA+2T@
M=&%B;&4@<F]W(&AA;F1L:6YG("TM/@H@("`@/'AS;#II;F-L=61E(&AR968]
M(G1A8FQE7W)O=W,N>'-L(B\^"B`@("`\(2TM('1A8FQE(&-O;'5M;B!H86YD
M;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)T86)L95]C;VQU;6YS
M+GAS;"(O/@H@("`@/"$M+2!T86)L92!C96QL(&AA;F1L:6YG("TM/@H@("`@
M/'AS;#II;F-L=61E(&AR968](G1A8FQE7V-E;&QS+GAS;"(O/@H*"@H@("`@
M/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@;6%I
M;B!T86)L92`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1A8FQE.G1A8FQE('P@
M=&%B;&4Z<W5B+71A8FQE(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/"$M+2!A('1A8FQE('=I
M;&P@;VYL>2!B92!C<F5A=&5D(&EF('1H92`B<V-E;F%R:6\B(&ES(&%C=&EV
M92`M+3X*("`@("`@("`\>'-L.FEF('1E<W0](G-T<FEN9RUL96YG=&@H=&%B
M;&4Z<V-E;F%R:6\O0'1A8FQE.FES+6%C=&EV92D@/2`P(CX*("`@("`@("`@
M("`@/"$M+2!C;VQL96-T:6YG(&%L;"!V:7-I8FQE(")T86)L93IT86)L92UR
M;W<B(&5L96UE;G1S(&]F('1H92!T86)L92`M+3X*("`@("`@("`@("`@/'AS
M;#IV87)I86)L92!N86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S(B!S96QE8W0]
M(G1A8FQE.G1A8FQE+7)O=UMN;W0H0'1A8FQE.G9I<VEB:6QI='D@/2`G8V]L
M;&%P<V4G(&]R($!T86)L93IV:7-I8FEL:71Y(#T@)V9I;'1E<B<I70H@("`@
M("`@("`@("`@("`@("`@('P@("`@=&%B;&4Z=&%B;&4M:&5A9&5R+7)O=W,O
M9&5S8V5N9&%N=#HZ=&%B;&4Z=&%B;&4M<F]W6VYO="A`=&%B;&4Z=FES:6)I
M;&ET>2`]("=C;VQL87!S92<@;W(@0'1A8FQE.G9I<VEB:6QI='D@/2`G9FEL
M=&5R)RE="B`@("`@("`@("`@("`@("`@("`@?"`@("!T86)L93IT86)L92UR
M;W<M9W)O=7`O9&5S8V5N9&%N=#HZ=&%B;&4Z=&%B;&4M<F]W6VYO="A`=&%B
M;&4Z=FES:6)I;&ET>2`]("=C;VQL87!S92<@;W(@0'1A8FQE.G9I<VEB:6QI
M='D@/2`G9FEL=&5R)RE=(B\^"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@/"$M+2!F;W(@86QL(&)U="!705`O5TU,(&1E=FEC
M97,@82!T86)L92!B;W)D97(@8VAE8VL@:7,@9&]N92`H8W`N(")C:&5C:RUF
M;W(M=&%B;&4M8F]R9&5R(BD@+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB;F]T*"1O=71P=714>7!E(#T@)U=-3"<I(CX*"B`@("`@("`@
M("`@("`@("`@("`@/"$M+2!!<R!T:&4@86QI9VYM96YT(&]F(&$@=&%B;&4@
M:7,@8GD@)V%L:6=N)R!A='1R:6)U="!I<R!D97!R96-A=&5D(&%N9"!A<R!T
M:&4@0U-3("=F;&]A="<@871T<FEB=71E(&YO="!W96QL(&1I<W!L87EE9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@('=E(&1O(&$@;&ET=&QE('1R:6-K
M(&)Y(&5N8V%P<W5L871I;F<@=&AE('1A8FQE('=I=&@@82!A;&EG;F5D("=D
M:78G(&5L96UE;G0M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](G1A8FQE+6%L:6=N;65N="(@<V5L96-T/2(D;V9F:6-E.F%U
M=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.FYA;64@/2!C=7)R
M96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,O0'1A
M8FQE.F%L:6=N(B\^"@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R
M:6YG+6QE;F=T:"@D=&%B;&4M86QI9VYM96YT*2`A/2`P(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)D:78B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](F%L:6=N(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG)'1A8FQE+6%L:6=N;65N
M=#TB;&5F="(@;W(@)'1A8FQE+6%L:6=N;65N=#TB;6%R9VEN<R(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^;&5F=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])R1T
M86)L92UA;&EG;FUE;G0](G)I9VAT(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G)I9VAT/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TG)'1A8FQE+6%L:6=N;65N=#TB8V5N
M=&5R(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/F-E;G1E<CPO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)T86)L92(^"@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](D!T86)L
M93IS='EL92UN86UE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E
M;7!L871E<SX*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PA+2T@=V]R:V%R;W5N9"P@<V5T('1A8FQE(&)O<F1E<B!A='1R:6)U="!I
M9B!A;GD@8V5L;"UB;W)D97(@97AI<W1S"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C:&5C
M:RUF;W(M=&%B;&4M8F]R9&5R(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q6:7-I
M8FQE5&%B;&52;W=S(B!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;'5M
M;BUS='EL92UV87)I86)L92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L
M951A8FQE4F]W<R(@<V5L96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&%B;&4B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C
M=#TB0'1A8FQE.G-T>6QE+6YA;64B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E
M;7!L871E<SX*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M
M+2!W;W)K87)O=6YD+"!S970@=&%B;&4@8F]R9&5R(&%T=')I8G5T(&EF(&%N
M>2!C96QL+6)O<F1E<B!E>&ES=',*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8VAE8VLM9F]R+71A
M8FQE+6)O<F1E<B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S
M(B!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X@("TM
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)C<F5A=&4M8V]L=6UN+7-T>6QE+79A<FEA8FQE(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F%L;%9I<VEB;&5486)L95)O=W,B('-E;&5C=#TB)&%L
M;%9I<VEB;&5486)L95)O=W,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@/"$M+2!F;W(@5TU,(&1E=FEC97,@;VYL
M>2!!4T-)22!T86)L92!A<F4@=W)I='1E;B!A<R!T86)L97,@87)E(&YO="!I
M;7!L96UE;G1E9"!W:61L97DN"B`@("`@("`@("`@("`@("`@("`@($)E9VEN
M;FEN9R!F<F]M("=R97!E870M=W)I=&4M<F]W)R!T:&4@=&5M<&QA=&5S(&%R
M92!H86YD;&5D(&)Y('1H92!T86)L95]W;6PN>'-L('-T>6QE<VAE970@+2T^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F-R96%T92UC;VQU;6XM<W1Y;&4M=F%R:6%B;&4B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A
M;&Q6:7-I8FQE5&%B;&52;W=S(B`@<V5L96-T/2(D86QL5FES:6)L951A8FQE
M4F]W<R(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#II9CX*("`@(#PO>'-L
M.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M
M8V]L=6UN+7-T>6QE+79A<FEA8FQE(CX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F%L;%9I<VEB;&5486)L95)O=W,B+SX*"B`@("`@("`@/"$M+2!A
M;&P@8V]L=6UN<R!O9B!T:&4@=&%B;&4@+2T^"B`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)A;&Q486)L94-O;'5M;G,B('-E;&5C=#TB=&%B;&4Z=&%B
M;&4M8V]L=6UN('P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T86)L93IT86)L92UC;VQU;6XM9W)O=7`O
M9&5S8V5N9&%N=#HZ=&%B;&4Z=&%B;&4M8V]L=6UN('P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T86)L
M93IT86)L92UH96%D97(M8V]L=6UN<R]D97-C96YD86YT.CIT86)L93IT86)L
M92UC;VQU;6XB+SX*("`@("`@("`\(2TM(&%L;$-O;'5M;E-T>6QE16YT<FEE
M<SH@0V]N=&%I;FEN9R!A;&P@8V]L=6UN<R!O9B!T:&4@=&%B;&4L(&AI9&1E
M;B!A;F0@=FEE=V5D+@H@("`@("`@("`@("`M(&EF(&$@8V]L=6UN(&ES(&AI
M9&1E;BP@:70@8V]N=&%I;G,@=&AE(&AI9&1E;B!A='1R:6)U=&4L(&]T:&5R
M=VES92!T:&4@<W1Y;&4M<')O<&5R=&EE<R!W:6QL(&)E('-T;W)E9`H@("`@
M("`@("`@("`M(&EF(&$@8V]L=6UN(&ES(&)E:6YG(')E<&5A=&5D+"!E86-H
M(')E<&5A=&5D(&-O;'5M;B!I<R!E>'!L:6-I=&QY('=R:71T96X@87,@96YT
M<GD@:6X@=&AI<R!V87)I86)L92X*("`@("`@("`@("`@("!,871E<B`H9'5R
M:6YG('1E;7!L871E(")W<FET92UC96QL(BD@=&AE('-T>6QE(&]F('1H92!C
M;VQU;6X@=VEL;"!B92!M:7AE9"!W:71H('1H92!C96QL+7-T>6QE(&)Y('5S
M:6YG"B`@("`@("`@("`@("`@=&AE('!O<VET:6]N*"D@;V8@=&AE(&-O;'5M
M;B!E;G1R>2!A;F0@8V]M<&%R:6YG(&ET('=I=&@@=&AE(&ET97)A=&EN9R!C
M96QL(&YU;6)E<BX@+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)A
M;&Q#;VQU;6Y3='EL945N=')I97,M4E1&(CX*("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&5S+65N=')I
M97,B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;%1A8FQE0V]L=6UN<R(@("`@("!S96QE8W0](B1A;&Q486)L94-O;'5M
M;G,B+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAT
M.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F-R96%T92UT86)L92(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@
M("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A
M8FQE4F]W<R(@("`@("!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2)X=#IN;V1E+7-E="@D
M86QL0V]L=6UN4W1Y;&5%;G1R:65S+5)41BDB+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B
M;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+71A8FQE(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q6
M:7-I8FQE5&%B;&52;W=S(B`@("`@('-E;&5C=#TB)&%L;%9I<VEB;&5486)L
M95)O=W,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](GAA;&%N
M.FYO9&5S970H)&%L;$-O;'5M;E-T>6QE16YT<FEE<RU25$8I(B\^"B`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+71A
M8FQE(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;%9I<VEB;&54
M86)L95)O=W,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M
M;E-T>6QE16YT<FEE<R(O/@H*"B`@("`@("`@/"$M+2!3;VUE($]F9FEC92!#
M86QC(&1O8W5M96YT<R!S:6UU;&%T92!A(&)A8VMG<F]U;F0@8GD@<F5P96%T
M:6YG('1H92!L87-T(&-E;&P@=6YT:6P@96YD(&]F('-P86-E"B`@("`@("`@
M("`@("`H5&AE('9A;'5E(&]F(")T86)L93IN=6UB97(M8V]L=6UN<RUR97!E
M871E9"(@:7,@96YO=7)M;W5S*2X@5W)I=&EN9R!O=70@86QL('1H97-E(&-E
M;&QS('=O=6QD(&)E(&9A=&%L+@H@("`@("`@("`@("`@5&AE<F5F;W)E+"!T
M:&ES(&=L;V)A;"!V87)I86)L92!S:&]W<R!U<R!T:&4@;&]N9V5S="!R;W<@
M=VET:"!C;VYT96YT+@H*("`@("`@("!%87)L:65R(&]N;'D@=&AE('9I97=A
M8FQE(&-O;'5M;G,@=V5R92!L:7-T960L(&)U="!I="!I<R!E87-I97(@=&\@
M:&%N9&QE('=I=&@@86QL(&-O;'5M;G,Z"B`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)M87A2;W=,96YG=&@B('-E;&5C=#TB8V]U;G0H)&%L;$-O;'5M
M;E-T>6QE16YT<FEE<R]C;VQU;6XM<W1Y;&4M96YT<GE;;F]T*$!C;VQU;6XM
M:&ED9&5N+69L86<I72DB+SX@+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)M87A2;W=,96YG=&@B('-E;&5C=#TB8V]U;G0H)&%L;$-O;'5M;E-T
M>6QE16YT<FEE<R]C;VQU;6XM<W1Y;&4M96YT<GDI(B\^"@H*("`@("`@("`\
M(2TM:7-$96)U9TUO9&4M4U1!4E0M+3X*("`@("`@("`\>'-L.FEF('1E<W0]
M(B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YM87A2
M;W=,96YG=&@Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;6%X4F]W3&5N9W1H
M(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)N=6UB97)/9DAI9&1E;D-O;'5M;G,B('-E;&5C=#TB8V]U;G0H)&%L
M;$-O;'5M;E-T>6QE16YT<FEE<R]C;VQU;6XM<W1Y;&4M96YT<GE;0&-O;'5M
M;BUH:61D96XM9FQA9UTI(B\^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YN
M=6UB97)/9DAI9&1E;D-O;'5M;G,Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D
M;G5M8F5R3V9(:61D96Y#;VQU;6YS(B\^/"]X<VPZ;65S<V%G93X*("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G1A8FQE+61E8G5G+6%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(^"B`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B!S96QE8W0]
M(B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS;#II9CX*("`@("`@("`\(2TM
M:7-$96)U9TUO9&4M14Y$+2T^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=734PG(CX*
M("`@("`@("`@("`@("`@(#PA+2T@;6%T8VAI;F<@86QL(')O=W,@+2!W92!C
M86X@;F]T('5S92!X<VPZ87!P;'DM=&5M<&QA=&4@=VET:"!A(&YO9&4M<V5T
M('!A<F%M971E<B!A<R!B>2!A(&)U9R!I;B!85"`H2F%M97,@0VQA<FLI"B`@
M("`@("`@("`@("`@("`@("`@("AH97)E.B!A;&Q#;VQU;6Y3='EL945N=')I
M97,I('=I;&P@8F4@:6YT97)P<F5T960@87,@82!R97-U;'0@=')E92!F<F%G
M;65N="P@=VAE<F4@;F\@<V5A<F-H(&5X<')E<W-I;VX@*%A0871H*2!C86X@
M8F4@=7-E9`H@("`@("`@("`@("`@("`@("`@("`R1$\Z0TA%0TL@5TE42"!8
M04Q!3BTM/@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0]
M(B1A;&Q6:7-I8FQE5&%B;&52;W=S(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=VUL+7)E<&5A="UW<FET92UR;W<B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S
M96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYU;6)E<BUR;W=S
M+7)E<&5A=&5D(B`@("`@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M<F5P
M96%T960B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D
M;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#PA+2T@;6%T8VAI;F<@86QL(')O=W,@
M+2!W92!C86X@;F]T('5S92!X<VPZ87!P;'DM=&5M<&QA=&4@=VET:"!A(&YO
M9&4M<V5T('!A<F%M971E<B!A<R!B>2!A(&)U9R!I;B!85"`H2F%M97,@0VQA
M<FLI"B`@("`@("`@("`@("`@("`@("`@("AH97)E.B!A;&Q#;VQU;6Y3='EL
M945N=')I97,I('=I;&P@8F4@:6YT97)P<F5T960@87,@82!R97-U;'0@=')E
M92!F<F%G;65N="P@=VAE<F4@;F\@<V5A<F-H(&5X<')E<W-I;VX@*%A0871H
M*2!C86X@8F4@=7-E9`H@("`@("`@("`@("`@("`@("`@("`R1$\Z0TA%0TL@
M5TE42"!804Q!3B`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@
M<V5L96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G)E<&5A="UW<FET92UR
M;W<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@
M("!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYU;6)E<BUR
M;W=S+7)E<&5A=&5D(B`@("`@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M
M<F5P96%T960B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T
M/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H
M/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($A%
M3%!%4CH@=&%B;&4@8F]R9&5R("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\(2TM(&]N;'D@;VYE('1A
M8FQE(&)O<F1E<B!F;W(@2%1-3#0@;W(@0U-3(&1E=FEC97,@=VAI8V@@8V]N
M=&%I;B!O;F4@;W(@;6]R92`G9F\Z8F]R9&5R+71O<"<@871T<FEB=71E<R`H
M<&%R<R!P<F\@=&]T;RP@:68@;VYE(&5X:7-T('1H92!O=&AE<B!U<W5A;&QY
M(&5X:7-T+"!T;V\I("TM/@H@("`@/"$M+2!T:&ES('=A<R!A('=O<FLM87)O
M=6YD(&9O<B!T:&4@;F5T<V-A<&4@-"YX>"!B=70@;F]T(&QO;F=E<B!N96-E
M<W-A<GD@9F]R($UO>FEL;&$@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F-H96-K+69O<BUT86)L92UB;W)D97(B/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(O/@H*("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](G-T87)T5&EM92(^"B`@("`@("`@("`@(#QX<VPZ:68@
M=&5S=#TB)&ES1&5B=6=-;V1E(&%N9"!N;W0H)&ES2F%V841I<V%B;&5D*2(^
M"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>7-T
M96TZ8W5R<F5N="UT:6UE+6UI;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-Y<W1E;3IC=7)R96YT+71I
M;64M;6EL;&ES*"DB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO
M;BUA=F%I;&%B;&4H)VIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC=7)R96YT5&EM
M94UI;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](FIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC=7)R96YT5&EM
M94UI;&QI<R@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X
M<VPZ:68^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@(#PA+2T@
M8VAE8VMS(&EF(&]N92!C96QL("AT86)L93IT86)L92UC96QL*2!O9B!T:&4@
M<F]W<R!O9B!T:&ES('1A8FQE("AA;&Q6:7-I8FQE5&%B;&52;W=S*2!C;VYT
M86EN<R!A(&)O<F1E<B!S='EL92`H:2YE+B!F;SIB;W)D97(M=&]P*0H@("`@
M("`@("`@("`@268@;VYL>2!O;F4@<VEN9VQE(&)O<F1E<B!E;&5M96YT(&5X
M:7-T+"!T:&4@=VAO;&4@=&%B;&4@=VEL;"!G971S('!R92UD969I;F5D(&)O
M<F1E<G,@*'-I;7!L92!H975R:7-T:6,@9F]R(&)E='1E<B!B<F]W<V5R(&1I
M<W!L87DI("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&%L;%9I<VEB;&54
M86)L95)O=W,O=&%B;&4Z=&%B;&4M8V5L;%M`=&%B;&4Z<W1Y;&4M;F%M93TO
M*B\J+W-T>6QE.G-T>6QE6W-T>6QE.G!R;W!E<G1I97,O0&9O.F)O<F1E<BUT
M;W!=+T!S='EL93IN86UE72(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](F)O<F1E<B(^,3PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB8F]R9&5R8V]L;W(B/B,P,#`P,#`\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(F-E;&QP861D:6YG(CXR/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)C96QL<W!A8VEN9R(^,#PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<&%G92UB
M<F5A:RUI;G-I9&4B/G!A9V4M8G)E86LM:6YS:61E.F%V;VED/"]X<VPZ871T
M<FEB=71E/@H@("`@("`@(#PO>'-L.FEF/@H*"B`@("`@("`@/"$M+2!C:&5C
M:R!T:&4@=&EM92!F;W(@8F]R9&5R8VAE8VMI;F<@*&1E8G5G*2TM/@H@("`@
M("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(&%N9"!N;W0H)&ES2F%V
M841I<V%B;&5D*2(^"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M96YD5&EM92(^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=S>7-T96TZ8W5R<F5N="UT:6UE+6UI;&QI<R<I(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-Y<W1E;3IC
M=7)R96YT+71I;64M;6EL;&ES*"DB+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC
M=7)R96YT5&EM94UI;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC
M=7)R96YT5&EM94UI;&QI<R@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93Y4:6UE(&9O<B!C:&5C:VEN9R!";W)D97)3='EL93H@/'AS;#IV86QU92UO
M9B!S96QE8W0](B@D96YD5&EM92`M("1S=&%R=%1I;64I(B\^(&US/"]X<VPZ
M;65S<V%G93X*("`@("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E
M/@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O
M;R]T86)L95]C96QL<RYX<VP`````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V-C(W,@`Q,#0Q
M-S,V,C<W,P`P,C0P,S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL
M92!A<F4@;6%D92!A=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*
M("`@96ET:&5R(&]F('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@
M("`M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N
M(#(N,0H@("`@("`@("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C
M92!,:6-E;G-E(%9E<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN
M8RXL($]C=&]B97(L(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L
M:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@
M8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@
M4F]A9"P@4&%L;R!!;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A
M<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@
M86YD+V]R"B`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.
M52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N
M,2P@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I
M;VXN"@H@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO
M<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9
M(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@
M;V8*("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#
M54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@
M4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U
M;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N
M97)A;"!0=6)L:6,*("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R
M>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N
M9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S
M=&]N+`H@("!-02`@,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y
M(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M"B`@(%1H92!C;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@
M=&AE(%-U;B!);F1U<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@
M5F5R<VEO;B`Q+C$@*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@
M=&AI<R!F:6QE"B`@(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI
M8V5N<V4N(%EO=2!M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS
M92!A="!H='1P.B\O=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*
M"B`@(%-O9G1W87)E('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P
M<F]V:61E9"!O;B!A;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!
M3E19($]&($%.62!+24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$+"!)
M3D-,541)3D<L"B`@(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!4
M2$%4(%1(12!33T945T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(
M04Y404),12P@1DE4($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].
M+4E.1E))3D=)3D<N"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I
M9FEC('!R;W9I<VEO;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O
M8FQI9V%T:6]N<R!C;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!)
M;FET:6%L($1E=F5L;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N
M($UI8W)O<WES=&5M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@
M4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E
M9"X*"B`@($-O;G1R:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO
M;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W
M+G<S+F]R9R\Q.3DY+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X
M;6QN<SIO9F9I8V4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC
M92(*("`@("`@("`@("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G1E
M>'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@
M("`@("`@("!X;6QN<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O=&%B;&4B"B`@("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*
M("`@("`@("`@("`@("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R
M9R\Q.3DY+WAL:6YK(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@
M("`@("`@("!X;6QN<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S
M9#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@
M("`@("`@('AM;&YS.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T
M:"]-871H34PB"B`@("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z<V-R:7!T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B
M"B`@("`@("`@("`@("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@
M("`@("`@("!O9F9I8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z9&,](FAT='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O;65T82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M:&5L<"(*("`@("`@("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC
M;&%R:RYC;VTO>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T96T](FAT
M='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3>7-T96TB
M"B`@("`@("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C
M:&4N;W)G+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T
M<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@
M(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*"@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA
M+2T@*BHJ('=R:71E(')E<&5A=&EN9R!T86)L92!C96QL<R`J*BH@+2T^"B`@
M("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H*"B`@("`\(2TM(&UA=&-H:6YG(&-E;&QS('1O(&=I=F4@;W5T("T^(&-O
M=F5R960@=&%B;&4@8V5L;',@87)E(&YO="!W<FET=&5N(&]U="`M+3X*("`@
M(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1A8FQE.G1A8FQE+6-E;&PB/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@(#PA+2T@<&]S:71I;VX@;V8@=&AE(&-U<G)E;G0@:6YP=70@8V5L
M;"!T;R!G970@=&AE(&-O<G)E8W0@8V]L=6T@<W1Y;&4@*&AI9&1E;B!A<F4@
M86QS;R!C;W5N=&5D*2TM/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL
M0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)M87A2;W=,96YG=&@B+SX*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$
M96)U9TUO9&4B/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^"BTM+2TM+2TM
M+2TM+2TM/B!T86)L93IT86)L92UC96QL(&AA<R!B965N(&5N=&5R960@=VET
M:"!N;V1E('9A;'5E.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CPO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YT86)L93IN=6UB
M97(M8V]L=6UN<RUR97!E871E9#H@+3QX<VPZ=F%L=64M;V8@<V5L96-T/2)`
M=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960B+SXM/"]X<VPZ;65S<V%G
M93X*("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F-R96%T92UC;VQU;6XM<&]S:71I;VXM=F%R:6%B;&4B/@H@
M("`@("`@("`@("`\(2TM('!O<VET:6]N(&]F('1H92!C=7)R96YT(&EN<'5T
M(&-E;&P@=&\@9V5T('1H92!C;W)R96-T(&-O;'5M('-T>6QE("AH:61D96X@
M87)E(&%L<V\@8V]U;G1E9"DM+3X*("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D
M86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@("`@("`@('-E
M;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F-R96%T92UC;VQU;6XM<&]S:71I;VXM=F%R:6%B;&4B/@H@
M("`@("`@(#PA+2T@<&]S:71I;VX@;V8@=&AE(&-U<G)E;G0@:6YP=70@8V5L
M;"!T;R!G970@=&AE(&-O<G)E8W0@8V]L=6T@<W1Y;&4@*&AI9&1E;B!A<F4@
M86QS;R!C;W5N=&5D*2TM/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL
M0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)M87A2;W=,96YG=&@B+SX*"B`@("`@("`@/"$M+2!C;VQU;6X@<&]S
M:71I;VX@;F5E9&5D(&9O<B!S='EL97,L(&5S<"X@9F]R(&-O;'5M;BUH:61D
M96XM9FQA9R`M+3X*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!R96-E
M9&EN9RUC;VQU;6YS(CX*("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE
M8W0](G!R96-E9&EN9RUS:6)L:6YG.CHJ(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)Q=6%N=&ET>2(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)S=')I;F<M;&5N9W1H*$!T86)L93IN=6UB97(M8V]L=6UN
M<RUR97!E871E9"D@/2`P(CXQ/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^/'AS;#IV86QU92UO9B!S96QE8W0]
M(D!T86)L93IN=6UB97(M8V]L=6UN<RUR97!E871E9"(O/CPO>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IF
M;W(M96%C:#X*("`@("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO
M;BUA=F%I;&%B;&4H)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UT86)L92UC96QL(CX*
M("`@("`@("`@("`@("`@("`@("`\(2TM('!O<VET:6]N(&]F('1H92!C=7)R
M96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R96-T(&-O;'5M('-T>6QE
M("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R
M:65S(B`@("!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W
M3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M=6UN+7!O<VET:6]N(B`@("`@("`@("!S96QE8W0](G-U;2AX=#IN;V1E+7-E
M="@D<')E8V5D:6YG+6-O;'5M;G,I+W%U86YT:71Y*2`K(#$B+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X86QA;CIN;V1E<V5T)RDB/@H@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UT
M86)L92UC96QL(CX*("`@("`@("`@("`@("`@("`@("`\(2TM('!O<VET:6]N
M(&]F('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R96-T
M(&-O;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L
M=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N
M=')I97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2
M;W=,96YG=&@B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L=6UN+7!O<VET:6]N(B`@("`@("`@("!S96QE8W0](G-U
M;2AX86QA;CIN;V1E<V5T*"1P<F5C961I;F<M8V]L=6UN<RDO<75A;G1I='DI
M("L@,2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](DYO9&53971&=6YC=&EO;DYO=$%V86EL86)L92(O/@H@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UT86)L
M92UC96QL(B\^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+71A8FQE+6-E;&PB/@H@("`@("`@
M(#PA+2T@<&]S:71I;VX@;V8@=&AE(&-U<G)E;G0@:6YP=70@8V5L;"!T;R!G
M970@=&AE(&-O<G)E8W0@8V]L=6T@<W1Y;&4@*&AI9&1E;B!A<F4@86QS;R!C
M;W5N=&5D*2TM/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M
M87A2;W=,96YG=&@B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;'5M
M;BUP;W-I=&EO;B(O/@H*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U
M9TUO9&4B/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^3D57(%9!3%5%.B!C
M;VQU;6XM<&]S:71I;VXZ("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O;'5M
M;BUP;W-I=&EO;B(O/BT\+WAS;#IM97-S86=E/@H@("`@("`@(#PO>'-L.FEF
M/@H*"B`@("`@("`@/"$M+2!A(&AI9&1E;B!C;VQU;6X@=VEL;"!G:79E(&]U
M="!N;W1H:6YG("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*"1A;&Q#
M;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N
M*"D@/2`D8V]L=6UN+7!O<VET:6]N72]`8V]L=6UN+6AI9&1E;BUF;&%G*2(^
M"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"$M
M+2!W:&5N('1H92!C;VQU;6YS(&%R92!N;W0@<F5P96%T960@=&AE(&YE>'0@
M8V]L=6UN+7!O<VET:6]N<R!R86ES97,@=7`@=&\@,2P@;W1H97)W:7-E('5P
M('1O('1H92!A;6]U;G0@;V8@<F5P96%T960@8V]L=6UN<R`M+3X*("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B;&4Z;G5M8F5R+6-O;'5M
M;G,M<F5P96%T960B/@H@("`@("`@("`@("`@("`@("`@(#PA+2T@=W)I=&5S
M(&UU;'1I<&QE(&5N=')I97,@;V8@82!C96QL("TM/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)R97!E870M=W)I=&4M
M8V5L;"(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E
M;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7!O<VET
M:6]N(B`@("`@("`@("!S96QE8W0](B1C;VQU;6XM<&]S:71I;VXB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA
M>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)N=6UB97(M8V]L=6UN<RUR97!E871E9"(@('-E;&5C=#TB0'1A8FQE
M.FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B\^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`\(2TM('=R:71E<R!A;B!E;G1R>2!O9B!A(&-E;&P@
M+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G=R:71E+6-E;&PB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R
M:65S(B`@("!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;'5M;BUP;W-I=&EO;B(@("`@("`@("`@<V5L96-T/2(D8V]L=6UN+7!O<VET
M:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA
M>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#II9CX*"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M<F5P96%T+7=R:71E+6-E;&PB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](FUA>%)O=TQE;F=T:"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB;G5M8F5R+6-O;'5M;G,M<F5P96%T960B+SX*"B`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#PA+2T@,D1/.B!4:&ES(&ES('1H92!C=7)R
M96YT('=O<FMA<F]U;F0@86=A:6YS="!T:&4@8F%C:V=R;W5N9"!S:6UU;&%T
M:6]N(&)Y(&%N("=E;F1L97-S)R!R97!E871I;F<@8V5L;"`M+3X*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](B1N=6UB97(M8V]L=6UN<RUR97!E871E
M9"`^(#$@86YD("1M87A2;W=,96YG=&@@/B`D8V]L=6UN+7!O<VET:6]N(CX*
M"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/BLK*RLK*RLK*R!S
M=&%R=&EN9R!C96QL('=R:71I;F<@*RLK*RLK*RLK/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^;G5M8F5R+6-O;'5M
M;G,M<F5P96%T960Z("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&YU;6)E<BUC
M;VQU;6YS+7)E<&5A=&5D(B\^+3PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IM97-S86=E/FUA>%)O=TQE;F=T:#H@+3QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^+3PO>'-L.FUE<W-A9V4^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/F-O;'5M;BUP;W-I
M=&EO;CH@+3QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]L=6UN+7!O<VET:6]N
M(B\^+3PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*
M"B`@("`@("`@("`@("`@("`\(2TM('=R:71E<R!A;B!E;G1R>2!O9B!A(&-E
M;&P@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB=W)I=&4M8V5L;"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S
M96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7!O<VET:6]N
M(B`@("`@("`@("!S96QE8W0](B1C;VQU;6XM<&]S:71I;VXB+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N
M9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`\(2TM(')E<&5A="!C86QL:6YG('1H:7,@;65T:&]D('5N=&EL(&%L
M;"!E;&5M96YT<R!W<FET=&5N(&]U="`M+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.FUE<W-A9V4^*RLK*RLK*RLK(&-E;&P@<F5P971I=&EO;B`K*RLK
M*RLK*RL\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^
M"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<F5P
M96%T+7=R:71E+6-E;&PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@
M<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO
M;B(@("`@("`@("`@<V5L96-T/2(D8V]L=6UN+7!O<VET:6]N("L@,2(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2
M;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N
M=6UB97(M8V]L=6UN<RUR97!E871E9"(@('-E;&5C=#TB)&YU;6)E<BUC;VQU
M;6YS+7)E<&5A=&5D("T@,2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM(#)$3SH@
M5&AI<R!I<R!T:&4@8W5R<F5N="!W;W)K87)O=6YD(&%G86EN<W0@=&AE(&)A
M8VMG<F]U;F0@<VEM=6QA=&EO;B!B>2!A;B`G96YD;&5S<R<@<F5P96%T:6YG
M(&-E;&P@+2T^"B`@("`@("`@("`@("`@("`\(2TM("`@("`@5VAE;B!T:&4@
M;6%X4F]W3&5N9W1H(&ES(')E86-H960@82!L87-T(&5N=')Y(&]F(&$@8V5L
M;"!I<R!W<FET=&5N("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G=R:71E+6-E;&PB/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@
M("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T
M>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;'5M;BUP;W-I=&EO;B(@("`@("`@("`@<V5L96-T/2(D8V]L=6UN+7!O
M<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X
M4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](G=R:71E+6-E;&PB/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(O/@H*"B`@("`@("`@/'AS;#II
M9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^5W)I=&5497-T("T^($EF(&YO=&AI;F<@8F5T=V5E;B`G+2<@=W)I=&4@
M8V5L;"`M/'AS;#IV86QU92UO9B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N
M=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N*"D@/2`D8V]L=6UN
M+7!O<VET:6]N72]`8V]L=6UN+6AI9&1E;BUF;&%G(B\^+3PO>'-L.FUE<W-A
M9V4^"B`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`\>'-L.FEF('1E
M<W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y
M6W!O<VET:6]N*"D@/2`D8V]L=6UN+7!O<VET:6]N72]`8V]L=6UN+6AI9&1E
M;BUF;&%G(CX*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B
M=6=-;V1E(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^5$%"
M3$4@0T],54U.(&ES(&AI9&1E;B$\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/"$M+2!A(&AI9&1E;B!C;VQU
M;6X@=VEL;"!G:79E(&]U="!N;W1H:6YG("TM/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R]C;VQU;6XM<W1Y
M;&4M96YT<GE;<&]S:71I;VXH*2`]("1C;VQU;6XM<&]S:71I;VY=+T!C;VQU
M;6XM:&ED9&5N+69L86<B/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T
M/2(D:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93Y404),12!#3TQ534X@:7,@:&ED9&5N(3PO>'-L.FUE<W-A9V4^"B`@
M("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*"B`@("`@("`@("`@(#PA+2T@3D]4(&$@:&ED9&5N(&-O;'5M;B`M+3X*
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"@H@("`@("`@("`@("`@("`@
M/"$M+2!A('1A8FQE(&ES(&$@=&%B;&4@:&5A9&5R+"!W:&5N(&ET(&AA<R!A
M(")T86)L93IT86)L92UH96%D97(M<F]W<R(@86YC97-T;W(@+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1A8FQE1&%T851Y<&4B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.G1A8FQE
M.G1A8FQE+6AE861E<BUR;W=S(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#YT:#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/G1D/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#PA
M+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-4
M64Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)[)'1A8FQE1&%T
M851Y<&5](CX*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF
M('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IM97-S86=E/@HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B<\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1A
M8FQE1&%T851Y<&4B+SXG(&5L96UE;G0@:&%S(&)E96X@861D960A/"]X<VPZ
M;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF
M/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7-P86YN960B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;'-P
M86XB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7-P86YN
M960B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II
M9CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M0'1A8FQE.FYU;6)E<BUR;W=S+7-P86YN960B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G)O=W-P86XB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUR;W=S+7-P86YN960B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"@H*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@*BHJ('1H92!C96QL
M+7-T>6QE("HJ*B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@5&AE(&-E;&P@<W1Y;&4@:&%S(&YO(&-O;F-L=7-I;VX@=VET:"!T:&4@
M8V]L=6UN('-T>6QE+"!S;R!W92!S=VET8V@@=&AE(&]R9&5R+W!R:6]R:71I
M97,@9'5E('1O(&)R;W=S97(@:7-S=65S"@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%1H92!C96QL+7-T>6QE(&1E<&5N9',@;VX@='=O(&%T
M=')I8G5T97,Z"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$I
M('1A8FQE.G-T>6QE+6YA;64@+2!T:&4@<W1Y;&4@<')O<&5R=&EE<R!O9B!C
M96QL+B!7:&5N('1H97D@97AI<W0L(&$@9&5F875L="!A;&EG;F5M96YT("AC
M<"X@8F5L;W<I('=I;&P@8F4@861D960@9F]R('1H90H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M(&]F(&YO(&%L:6=N;65N="!I;B!T:&4@<W1Y;&4@97AI<W0N"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#(I('1A8FQE.G9A;'5E+71Y<&4@
M+2!T:&4@=F%L=64@='EP92!O9B!T:&4@=&%B;&4M8V5L;"!G:79I;F<@=&AE
M(&1E9F%U;'0@86QI9VYM96YT<RX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0GD@9&5F875L="!A('-T
M<FEN9R!V86QU92!I<R!L969T(&%L:6=N960L(&%L;"!O=&AE<B!A<F4@86QI
M9VYE9#IR:6=H="X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T
M86)L93IS='EL92UN86UE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B/@H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@0T5,3"U3
M5%E,13H@86QI9VYM96YT(&)Y('1A8FQE.G9A;'5E+71Y<&4@*'=I=&AO=70@
M97AI<W1I;F<@=&%B;&4Z<W1Y;&4M;F%M92DM+3X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M8V5L;%-T>6QE(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T
M>6QE<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R:6YG+6QE;F=T:"@D8V5L;%-T
M>6QE*2`^(#`@86YD(&YO="AC;VYT86EN<R@D8V5L;%-T>6QE+"`G=&5X="UA
M;&EG;B<I*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@0T5,3"U35%E,13H@86QI9VYM96YT(&)Y('1A
M8FQE.G9A;'5E+71Y<&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@;F\@86QI9VYM96YT(&EN('1H
M92!C96QL('-T>6QE+"!T:&4@86QI9VYM96YT(&)A<V5D(&]N('1H92!T86)L
M93IV86QU92UT>7!E('=I;&P@8F4@861D960@+2T^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T86)L93IV86QU92UT>7!E(&%N
M9"!N;W0H0'1A8FQE.G9A;'5E+71Y<&4@/2`G<W1R:6YG)RDB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&-O;&QE8W1E9$=L
M;V)A;$1A=&$O86QL<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H*2]`=&%B;&4Z
M<W1Y;&4M;F%M95TL("=T97AT+6%L:6=N.G)I9VAT.R`G*2(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&-O;&QE8W1E9$=L;V)A
M;$1A=&$O86QL<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H*2]`=&%B;&4Z<W1Y
M;&4M;F%M95TL("=T97AT+6%L:6=N.FQE9G0[("<I(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\(2TM($-%3$PM4U193$4Z(&%L:6=N;65N="!B>2!T
M86)L93IV86QU92UT>7!E("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&YO($-34R!S='EL92!P<F]P
M97)T:65S(&5X:7-T+"!O;FQY(&%L:6=N;65N="!F<F]M('1H92!T86)L93IV
M86QU92UT>7!E('=I;&P@8F4@=7-E9"`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB0'1A8FQE.G9A;'5E+71Y<&4@86YD(&YO
M="A`=&%B;&4Z=F%L=64M='EP92`]("=S=')I;F<G*2(^=&5X="UA;&EG;CIR
M:6=H=#L@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/G1E>'0M
M86QI9VXZ;&5F=#L@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&-O;'5M;BUS='EL92`H9&ES
M:G5N8W0@;V8@8V5L;"!S='EL92`M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM(#)$3SH@;VYL>2!A8G-O;'5T('-T
M>6QE<R!A<F4@<W5P<&]R=&5D+"!R96QA=&EV92!S='EL97,@*&DN92X@)W-T
M>6QE.G)E;"UC;VQU;6XM=VED=&@G(&4N9RX@=VET:"!V86QU92`B.#DS,RHB
M(&%R92!I9VYO<F5D+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@27-S=64Z(&)R;W=S97)S("AN;W0@<W5R92!I9B!#
M4U,I(&1O97,@;F]T('-U<'!O<G0@=&AE("<J)R!R96QA=&EO;G-H:7`L(&]N
M;'D@=&AE("<E)RP@=VAE<F4@=&AE('-U;2!I<R!A;'=A>7,@)S$P,"<A"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!&
M;W(@=&AI<RP@:70@:7,@96%S:65R('1O('=O<FL@;VX@=VET:"!T:&4@86)S
M;VQU=&4@=F%L=65S+"!I;G-T96%D(&]F(&-A;&-U;&%T:6YG('1H92!V86QU
M97,@9F]R(#$P,"4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1A;&Q#;VQU;6Y3
M='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N*"D])&-O
M;'5M;BUP;W-I=&EO;ETB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM($-%3$PM4U193$4Z('1A8FQE.G-T>6QE
M+6YA;64@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](F-L87-S(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)T<F%N<VQA=&4H0'1A8FQE.G-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM($-%3$PM4U193$4Z
M(&%L:6=N;65N="!B>2!T86)L93IV86QU92UT>7!E("AW:71H;W5T(&5X:7-T
M:6YG('1A8FQE.G-T>6QE+6YA;64I+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM(&YO('1A8FQE.G-T>6QE+6YA;64@
M97AI<W0L(&]N;'D@86QI9VYM96YT(&9R;VT@=&AE('1A8FQE.G9A;'5E+71Y
M<&4@=VEL;"!B92!U<V5D("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T
M86)L93IV86QU92UT>7!E(&%N9"!N;W0H0'1A8FQE.G9A;'5E+71Y<&4@/2`G
M<W1R:6YG)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T97AT+6%L:6=N.G)I9VAT.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1E>'0M86QI9VXZ;&5F=#L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!);B!C87-E(&]F(&YO(&-E;&P@8V]N=&5N="!A(&YO;BUB
M<F5A:V%B;&4@<W!A8V4@=VEL;"!B92!I;G-E<G1E9`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&\@;6%K92!T:&4@8G)O=W-E<B!S
M:&]W('1H92!T86)L92UC96QL(&=R:60@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="AC:&EL9#HZ=&5X
M="@I*2!A;F0@;F]T*&-H:6QD.CHJ*2(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X@)B,Q-C`[/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM("HJ
M*B!T:&4@8V]L=6UN+7-T>6QE("HJ*B`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"$M+2`@=&AE(&-O;'5M;B!S='EL92!H87,@
M;F\@8V]N8VQU<VEO;B!W:71H('1H92!C96QL('-T>6QE+"!S;R!W92!S=VET
M8V@@=&AE(&]R9&5R+W!R:6]R:71I97,@9'5E('1O(&)R;W=S97(@:7-S=65S
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)S<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-L87-S(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R]C
M;VQU;6XM<W1Y;&4M96YT<GE;<&]S:71I;VXH*2`]("1C;VQU;6XM<&]S:71I
M;VY=+T!S='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E
M<SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@
M("`@("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@
M("LK*RLK+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)[)'1A8FQE1&%T851Y<&5]
M(CX*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N;F5D(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VQS
M<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N
M;F5D(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M:68^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(D!T86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)R;W=S<&%N
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](D!T86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB<W1Y;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@8V5L;"US='EL92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$O86QL<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H*2]`=&%B;&4Z<W1Y;&4M
M;F%M95TB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M(&-O;'5M;BUS='EL92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT
M<FEE<R]C;VQU;6XM<W1Y;&4M96YT<GE;<&]S:71I;VXH*3TD8V]L=6UN+7!O
M<VET:6]N72(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@5$%"3$4Z5D%,544M5%E012`M('1H92!V86QU92!O9B!A('1A8FQE+6-E
M;&P@=VEL;"!B92!A;&EG;F5D(&QE9G0@8GD@9&5F875L="!O;FQY(&5X;&EC
M:70@;F]N+7-T<FEN9R!I<R!A;&EG;F5D.G)I9VAT+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B
M;&4Z=F%L=64M='EP92!A;F0@;F]T*$!T86)L93IV86QU92UT>7!E(#T@)W-T
M<FEN9R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#YT97AT+6%L:6=N.G)I9VAT.SPO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IT97AT/G1E>'0M86QI9VXZ;&5F=#L\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB
M=71E/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@)B,Q-C`@
M:7,@82!N;VXM8G)E86MA8FQE('-P86-E+"!N96-E<W-A<GD@=&\@;6%K92!T
M;R!T:&4@8G)O=W-E<B!S:&]W('1H92!T86)L92UC96QL(&=R:60@+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](FYO="AC
M:&EL9#HZ=&5X="@I*2!A;F0@;F]T*&-H:6QD.CHJ*2(^("8C,38P.SPO>'-L
M.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT
M96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!0
M04Q-($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)[)'1A8FQE
M1&%T851Y<&5](CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M:68@=&5S=#TB0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7-P86YN960B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](F-O;'-P86XB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUC;VQU
M;6YS+7-P86YN960B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#II9CX*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.FEF('1E<W0](D!T86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE
M/2)R;W=S<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!T86)L93IN=6UB97(M<F]W<RUS
M<&%N;F5D(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY
M+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/"$M+2LK*RLK
M(%=-3"!705D@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](B1O=71P=714>7!E(#T@)U=-3"<B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H)&%L;$-O;'5M;E-T>6QE16YT
M<FEE<R]C;VQU;6XM<W1Y;&4M96YT<GE;;&%S="@I(#T@)&-O;'5M;BUP;W-I
M=&EO;ETI(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T
M97,^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/BP@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T
M97,^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB8G(B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I
M97=E<B]O;V\O=&%B;&5?8V]L=6UN<RYX<VP`````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C0V
M-#4`,3`T,3<S-C(W-S,`,#(T-#$P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T
M:&ES(&9I;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E
M<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@
M("`@("`@("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@
M5F5R<VEO;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D
M<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES
M=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R
M86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H
M="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!
M;G1O;FEO(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI
M<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB
M=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F
M('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R
M<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&
M;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN
M('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(
M3U54($%.62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A
M<G)A;G1Y(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!
M(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'
M96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9
M;W4@<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S
M<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES
M(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*
M("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S
M,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!)
M;F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*
M("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J
M96-T('1O('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,
M:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N
M;W0@=7-E('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H
M('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@
M($QI8V5N<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E
M+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N
M<V4@:7,@<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]5
M5"!705)204Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U0
M3$E%1"P@24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!
M3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@
M("!-15)#2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L
M($]2($Y/3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H
M92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A
M;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@
M("!4:&4@26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@
M:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R
M,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@
M4F5S97)V960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T
M('9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T
M<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]O9F9I8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X
M;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@
M("`@("`@('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&
M;W)M870B"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W
M=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU
M;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R
M,#`P+W-V9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM
M;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@
M("`@("`@("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q
M.3DX+TUA=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@
M("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M<V-R:7!T(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@
M("`@("`@("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@
M("`@("`@('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O
M,2XQ+R(*("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC
M;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@
M("`@("`@("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R
M9R\R,#`P+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO
M+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES
M=&5M/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N
M4WES=&5M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X
M;6PN87!A8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA
M=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@
M("`@("`@("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*("`@
M(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!#<F5A=&4@=&%B;&4@8V]L=6UN<R!S
M='EL92!V87)I86)L92`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L
M.G1E;7!L871E(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&5S+65N=')I97,B
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL5&%B;&5#;VQU;6YS
M(B\^"@H@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D86QL5&%B;&5#
M;VQU;6YS(CX*"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8V]L
M=6UN+7-T>6QE+65N=')Y(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M+V%L;'-T>6QE<R\J6VYA;64H*2`]('1R86YS;&%T92AC=7)R96YT*"DO0'1A
M8FQE.G-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I72(O/@H@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)N;W0H0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D*2(^"B`@("`@
M("`@("`@("`@("`@("`@/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C;VQU
M;6X@:6X@=&AE(&-O;'5M;G,M=F%R:6%B;&4@+2T^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9&EN9RUC;VQU;6XM
M<W1Y;&4M96YT<GDB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B!S96QE8W0](B1C
M;VQU;6XM<W1Y;&4M96YT<GDB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@(#PA+2T@3F\@:&EG:&5R(')E<&5T:71I;VX@;V8@
M8V5L;',@9W)E871E<B!T:&%N(#0@9F]R('1H92!L87-T(&%N9"!S96-O;F0@
M;&%S="!C;VQU;6X@+2T^"B`@("`@("`@("`@("`@("`\(2TM(&$@:&%C:R!F
M;W(@=&AE('-A;7!L92!D;V-U;65N="`G5V%E:')U;F=S=6UR96-H;F5R+G-X
M8R!H879I;F<@,C,P(')E<&5A=&5D(&-O;'5M;G,@:6X@=&AE('-E8V]N9"!L
M87-T(&-O;'5M;B`M+3X*("`@("`@("`@("`@("`@(#PA+2T@/S\_(#QX<VPZ
M=VAE;B!T97-T/2(H<&]S:71I;VXH*2`](&QA<W0H*2!O<B`H<&]S:71I;VXH
M*2`]("AL87-T*"D@+2`Q*2D@86YD($!T86)L93IN=6UB97(M8V]L=6UN<RUR
M97!E871E9"`F;'0[(#4I(CX@/S\_+2T^"B`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB<&]S:71I;VXH*2`](&QA<W0H*2!O<B!P;W-I=&EO;B@I
M(#T@*&QA<W0H*2`M(#$I(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FEF
M('1E<W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUR97!E871E9"`F;'0[(#4B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('=R:71E<R!A;B!E;G1R
M>2!O9B!A(&-O;'5M;B!I;B!T:&4@8V]L=6UN<RUV87)I86)L92`M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(G)E<&5A="UA9&1I;F<M8V]L=6UN+7-T>6QE+65N=')Y(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU
M;6XM<W1Y;&4M96YT<GDB("`@("`@('-E;&5C=#TB)&-O;'5M;BUS='EL92UE
M;G1R>2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B`@<V5L96-T
M/2(Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!R97!E871E9"!C;VQU
M;7,@=VEL;"!B92!W<FET=&5N(&5X<&QI8VET('-E=F5R86P@=&EM97,@:6X@
M=&AE('9A<FEA8FQE+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](G)E<&5A="UA9&1I;F<M8V]L=6UN+7-T>6QE+65N
M=')Y(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;'5M;BUS='EL92UE;G1R>2(@("`@("`@("`@('-E;&5C=#TB
M)&-O;'5M;BUS='EL92UE;G1R>2(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;G5M8F5R+6-O;'5M;G,M<F5P96%T
M960B("`@("`@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T
M960B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@5U))5$53(%1(12!215!%051%
M1"!#3TQ534X@4U193$4@15A03$E#250@05,@04X@14Q%345.5"!)3B!42$4@
M0T],54U.4RU605))04),12`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M<F5P96%T+6%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)N=6UB97(M8V]L=6UN<RUR97!E871E9"(O/@H*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1N=6UB97(M8V]L=6UN<RUR97!E871E9"`^(#$B/@H@("`@("`@("`@
M("`@("`@/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C;VQU;6X@:6X@=&AE
M(&-O;'5M;G,M=F%R:6%B;&4@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB861D:6YG+6-O;'5M;BUS='EL92UE;G1R>2(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;'5M;BUS='EL92UE;G1R>2(@("!S96QE8W0](B1C;VQU;6XM<W1Y;&4M96YT
M<GDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\(2TM(')E<&5A="!C86QL:6YG('1H:7,@;65T:&]D
M('5N=&EL(&%L;"!E;&5M96YT<R!W<FET=&5N(&]U="`M+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)R97!E870M861D:6YG
M+6-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUS='EL92UE;G1R>2(@("`@("`@
M<V5L96-T/2(D8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYU;6)E<BUC;VQU;6YS+7)E
M<&5A=&5D(B`@<V5L96-T/2(D;G5M8F5R+6-O;'5M;G,M<F5P96%T960@+2`Q
M(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@(#PA+2T@=W)I=&5S(&%N(&5N=')Y(&]F(&$@
M8V]L=6UN(&EN('1H92!C;VQU;6YS+79A<FEA8FQE("TM/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9&EN9RUC;VQU;6XM
M<W1Y;&4M96YT<GDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQU;6XM<W1Y;&4M96YT<GDB("`@<V5L96-T/2(D8V]L
M=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA
M+2T@5$A%($-/3%5-3BU35%E,12!74DE412U0051415).($9/4B!%04-(($-/
M3%5-3B!74DE45$5.($E.($$@5D%224%"3$4@+2T^"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B\^"@H@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)C;VQU;6XM<W1Y;&4M96YT<GDB/@H@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)`=&%B;&4Z=FES:6)I;&ET>2`]("=C;VQL87!S92<@;W(@
M0'1A8FQE.G9I<VEB:6QI='D@/2`G9FEL=&5R)R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]L=6UN+6AI9&1E;BUF;&%G
M(CYT<G5E/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@(&YA;64](G1A8FQE.G-T>6QE
M+6YA;64B("`@("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'1A8FQE.G-T>6QE
M+6YA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4M;F%M92(^/'AS;#IV86QU92UO
M9B!S96QE8W0](B1T86)L93IS='EL92UN86UE(B\^/"]X<VPZ871T<FEB=71E
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D
M8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\(2TM
M:7-$96)U9TUO9&4M4U1!4E0M+3X*("`@(#PA+2T@9VEV:6YG(&]U="!T:&4@
M)V%L;$-O;'5M;E-T>6QE)R!V87)I86)L93H*("`@("`@("!&;W(@96%C:"`G
M8V]L=6UN+7-T>6QE+65N=')Y)R!O9B!T:&4@)V%L;$-O;'5M;E-T>6QE16YT
M<FEE<R<@=F%R:6%B;&4@=&AE('-T>6QE+6YA;64@:7,@9VEV96X@;W5T+@H@
M("`@("`@($EN(&-A<V4@;V8@)V-O;'5M;BUH:61D96XM9FQA9R<@871T<FEB
M=71E('1H92!T97AT("=#;VQU;6X@:7,@:&ED9&5N(&ES(&=I=F5N(&]U="XM
M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB=&%B;&4M9&5B=6<M86QL0V]L
M=6UN4W1Y;&5%;G1R:65S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H*("`@("`@("`\(2TM(&1E8G5G(&]U
M='!U="!A<R!T86)L92!S=6UM87)Y(&%T=')I8G5T(&EN(&AT;6P@+2T^"B`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W5M;6%R>2(^"B`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)T86)L92UD96)U9RUC;VQU
M;6XM;W5T(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)A;&Q#;VQU;6Y3='EL945N=')I97,B('-E;&5C=#TB)&%L;$-O;'5M;E-T
M>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`\(2TM(&1E8G5G
M(&]U='!U="!T;R!C;VYS;VQE("TM/@H@("`@("`@(#QX<VPZ;65S<V%G93X*
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G1A8FQE+61E
M8G5G+6-O;'5M;BUO=70B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@<V5L96-T/2(D86QL
M0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ;65S<V%G93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G1A8FQE+61E8G5G
M+6-O;'5M;BUO=70B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L
M=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@(#QX<VPZ=&5X=#X*("`@
M("`@("`@("`@1&5B=6=);F9O<FUA=&EO;CH@1F]R(&5A8V@@)V-O;'5M;BUS
M='EL92UE;G1R>2<@;V8@=&AE("=A;&Q#;VQU;6Y3='EL945N=')I97,G('9A
M<FEA8FQE('1H92!S='EL92UN86UE(&ES(&=I=F5N(&]U="X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@26X@8V%S92!O9B`G8V]L=6UN+6AI9&1E
M;BUF;&%G)R!A='1R:6)U=&4@=&AE('1E>'0@)V-O;'5M;B!I<R!H:61D96XG
M(&ES(&=I=F5N(&]U="X*("`@("`@("`@("`@/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D86QL0V]L=6UN4W1Y
M;&5%;G1R:65S+V-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)`8V]L=6UN+6AI9&1E;BUF;&%G(CX*("`@("`@("`@("`@/'AS;#IT97AT
M/B`@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'-T>6QE+6YA
M;64B+SX\>'-L.G1E>'0^8V]L=6UN(&ES(&AI9&1E;CPO>'-L.G1E>'0^/'AS
M;#IT97AT/@H@("`@("`@("`@("`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`\>'-L.G1E>'0^("`\+WAS;#IT97AT/CQX<VPZ=F%L
M=64M;V8@<V5L96-T/2)`<W1Y;&4M;F%M92(O/CQX<VPZ=&5X=#X@/2`\+WAS
M;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/@H@
M("`@("`@("`@("`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@(#PO
M>'-L.G1E;7!L871E/@H@("`@/"$M+6ES1&5B=6=-;V1E+45.1"TM/@H*/"]X
M<VPZ<W1Y;&5S:&5E=#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O5FEE=V5R+V]O;R]T86)L95]R;W=S+GAS;```````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q-S4R-0`Q,#0Q-S,V,C<W,P`P,C,W,C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/"$M+0H*("`@5&AE
M($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A=F%I;&%B;&4@<W5B
M:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F('1H92!F;VQL;W=I
M;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@("`@+2!3=6X@26YD
M=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"@H@
M("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L(#(P,#`*"B`@($=.
M52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@
M("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC
M+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!;'1O+"!#02`Y-#,P
M,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U
M(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO9&EF>2!I="!U;F1E
M<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*
M("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES:&5D(&)Y('1H92!&
M<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES(&QI8G)A<GD@:7,@
M9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U
M;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@
M=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!3E1!0DE,2519(&]R
M($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'
M3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@
M9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@
M;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!A
M;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@
M1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@
M4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@,#(Q,3$M,3,P-R`@
M55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS
M92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT96YT<R!O9B!T:&ES
M(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U<W1R>2!3=&%N9&%R
M9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@*'1H92`B3&EC96YS
M92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@(&5X8V5P="!I;B!C
M;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M87D@;V)T86EN(&$@
M8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O=W=W+F]P96YO9F9I
M8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E('!R;W9I9&5D('5N
M9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A;B`B05,@25,B(&)A
M<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%251(15(@
M15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@(%=)5$A/550@3$E-
M251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T945T%212!)4R!&4D5%
M($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N"B`@(%-E92!T:&4@
M3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO;G,@9V]V97)N:6YG
M('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C;VYC97)N:6YG('1H
M92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L;W!E<B!O9B!T:&4@
M3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@
M0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*
M("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R:6)U=&]R*',I.B!?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U\*"BTM/@H\
M>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]4<F%N<V9O
M<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@("`@("`@('AM;&YS
M.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S='EL92(*("`@
M("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R
M9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIT86)L93TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@("`@("`@("`@("`@
M("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<F%W
M:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N
M;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@("`@('AM;&YS.GAL
M:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIS=F<](FAT='`Z
M+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V-H87)T(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS.FUA=&@](FAT='`Z
M+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@("`@("`@("`@("`@
M("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]F;W)M
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z
M8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z=F5R<VEO;CTB
M,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT='`Z+R]P=7)L+F]R
M9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@("`@>&UL;G,Z;65T
M83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T82(*("`@("`@("`@
M("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z:&5L<#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@("`@("`@("`@('AM
M;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B"B`@("`@("`@("`@
M("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J
M879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@("`@("!X;6QN<SIX
M86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O
M:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S
M/2)J879A(CX*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@=W)I=&4@
M*&5X<&QI8VET*2!R97!E871I;F<@=&%B;&4@<F]W<R`J*BH@+2T^"B`@("`\
M(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G)E<&5A="UW<FET
M92UR;W<B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)N=6UB
M97(M<F]W<RUR97!E871E9"(@<V5L96-T/2(Q(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)M87A2;W=,96YG=&@B+SX*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#PA+2T@=W)I=&4@86X@96YT<GD@;V8@82!R;W<@
M86YD(')E<&5A="!C86QL:6YG('1H:7,@;65T:&]D('5N=&EL(&%L;"!E;&5M
M96YT<R!A<F4@=W)I='1E;B!O=70@+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(D;G5M8F5R+7)O=W,M<F5P96%T960@/B`Q(&%N9"`H=&%B;&4Z
M=&%B;&4M8V5L;"]T97AT*"D@;W(@=&%B;&4Z=&%B;&4M8V5L;"\J*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M
M<F]W(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C
M=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@
M("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@("`@("`\(2TM
M(#)$3SH@=&%K92!V87)I86)L92!F<F]M('1H92!O=71P=70@;V8@<F5P96%T
M960@=W)I=&4M<F]W(&%N9"!I=&5R871E(&=I=FEN9R!O=70@=&AE('9A<FEA
M8FQE("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G)E<&5A="UW<FET92UR;W<B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@
M("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE
M16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA
M>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(FYU;6)E<BUR;W=S+7)E<&5A=&5D(B`@("`@<V5L96-T/2(D;G5M8F5R+7)O
M=W,M<F5P96%T960@+2`Q(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\(2TM('=R:71E(&$@<VEN9VQE(&5N=')Y(&]F(&$@<F]W("TM/@H@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UR;W<B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B`@("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O
M;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%
M;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X
M4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](G=R:71E+7)O=R(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(O/@H*"B`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](G1R(CX*("`@("`@("`@("`@/"$M+2!W<FET:6YG('1H
M92!S='EL92!O9B!T:&4@<F]W("TM/@H@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TG861D+7-T>6QE+7!R;W!E<G1I97,G/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@(#QX<VPZ
M:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M;65S<V%G93X**BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B=T<B<@96QE;65N
M="!H87,@8F5E;B!A9&1E9"$\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\
M+WAS;#II9CX*"B`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E
M;&5C=#TB=&%B;&4Z=&%B;&4M8V5L;"(^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H
M(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@
M("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($A%3%!%
M4CH@=&%B;&4@<W1Y;&5S("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F%D9"US='EL92UP<F]P97)T:65S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB;F]D92UP;W-I=&EO;B(O/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-4
M3%E%(%-(1454*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52
M)R(^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;&%S
M<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G1R86YS;&%T92A`=&%B;&4Z<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDB
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N
M,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A+V%L;'-T>6QE<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE
M.G-T>6QE+6YA;65=(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H\+WAS;#IS='EL97-H965T/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,T,#<`,3`T,3<S-C(W
M-S,`,#(Q-#<Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?9&5B(&-L87-S
M(')E;F1E<G,@;W5T(&QI<W1S(&]F(&9I;&5S(&EN($1E8FEA;B!P86-K86=E
M<R!B>0H@*B!U<VEN9R!T:&4@9'!K9R!T;V]L('1O('%U97)Y('1H92!P86-K
M86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`L=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P
M961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE
M=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]D96(@97AT96YD<R!-24U%7U9I
M97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@=&AE(&1A=&$N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S
M('1H92!V:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!R96YD97)E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO
M8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J($-H96-K('1O(&UA:V4@
M<W5R92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES=',N("HO"B`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S6R=H;W)D92==6R=D96(G
M75LG;&]C871I;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@
M+B!S<')I;G1F*%\H(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB*2P@
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;)VQO8V%T:6]N)UTI("X@
M)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D=&UP7V1E8B`]($AO<F1E
M.CIG971496UP1FEL92@G:&]R9&5?9&5B)RD["@H@("`@("`@("1F:"`](&9O
M<&5N*"1T;7!?9&5B+"`G=R<I.PH@("`@("`@(&9W<FET92@D9F@L("1T:&ES
M+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@("`@(&9C;&]S92@D
M9F@I.PH*("`@("`@("`D9F@@/2!P;W!E;B@D;6EM95]D<FEV97)S6R=H;W)D
M92==6R=D96(G75LG;&]C871I;VXG72`N("(@+68@)'1M<%]D96(@,CXF,2(L
M("=R)RD["B`@("`@("`@=VAI;&4@*"@D<F,@/2!F9V5T<R@D9F@L(#@Q.3(I
M*2D@>PH@("`@("`@("`@("`D9&%T82`N/2`D<F,["B`@("`@("`@?0H@("`@
M("`@('!C;&]S92@D9F@I.PH*("`@("`@("!R971U<FX@)SQP<F4^)R`N(&AT
M;6QS<&5C:6%L8VAA<G,H)&1A=&$I("X@)SPO<')E/B<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H
M92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G
M=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O9&5F875L="YP:'``
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,3<W`#$P-#$W,S8R-S<S`#`R
M,C,V-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7V1E9F%U;'0@8VQA<W,@
M<VEM<&QY('!R:6YT<R!O=70@=&AE(&5N8V%P<W5L871E9`H@*B!C;VYT96YT
M+B`@270@97AI<W1S(&%S(&$@9F%L;&)A8VL@:68@;F\@;W1H97(@:6YT96QL
M:6=E;G0@<F5N9&5R:6YG"B`J(&UE8VAA;FES;2!C;W5L9"!B92!U<V5D+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E9F%U
M;'0N<&AP+'8@,2XY+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D
M>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R
M"B`J+PIC;&%S<R!-24U%7U9I97=E<E]D969A=6QT(&5X=&5N9',@34E-15]6
M:65W97(@>PH*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O96YR:6-H
M960N<&AP````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P,3,Q`#$P-#$W,S8R
M-S<S`#`R,C4Q,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7V5N<FEC:&5D
M(&-L87-S(')E;F1E<G,@;W5T('!L86EN('1E>'0@9G)O;0H@*B!E;G)I8VAE
M9"!C;VYT96YT('1A9W,L(&%L82!21D,@,3@Y-BX*("H*("H@0GD@4D9#+"!W
M92!M=7-T(&1O('1H92!M:6YI;6%L(&-O;F9O<FUA;F-E(&UE87-U<F5S(&]F
M.B!!(&UI;FEM86P*("H@=&5X="]E;G)I8VAE9"!I;7!L96UE;G1A=&EO;B!I
M<R!O;F4@=&AA="!C;VYV97)T<R`B/#PB('1O("(\(BP*("H@<F5M;W9E<R!E
M=F5R>71H:6YG(&)E='=E96X@82`\<&%R86T^(&-O;6UA;F0@86YD('1H92!N
M97AT(&)A;&%N8VEN9PH@*B`\+W!A<F%M/B!R96UO=F5S(&%L;"!O=&AE<B!F
M;W)M871T:6YG(&-O;6UA;F1S("AA;&P@=&5X="!E;F-L;W-E9`H@*B!I;B!A
M;F=L92!B<F%C:V5T<RDL(&%N9"!O=71S:61E(&]F(#QN;V9I;&P^(&5N=FER
M;VYM96YT<R!C;VYV97)T<PH@*B!A;GD@<V5R:65S(&]F(&X@0U),1G,@=&\@
M;BTQ($-23$9S+"!A;F0@8V]N=F5R=',@86YY(&QO;F4@0U),1@H@*B!P86ER
M<R!T;R!34$%#12X*("H*("H@5V4@9&]N)W0@<75A;&EF>2!A<R!W92!D;VXG
M="!C=7)R96YT;'D@=')A8VL@=&AE(#QN;V9I;&P^"B`J(&5N=FER;VYM96YT
M+"!T:&%T(&ES('=E(&1O($-23$8@8V]N=F5R<VEO;B!E=F5N(&EF(#QN;V9I
M;&P^(&ES"B`J('-P96-I9FEE9"!I;B!T:&4@=&5X="P@8G5T('=E)W)E(&-L
M;W-E(&%T(&QE87-T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+V5N<FEC:&5D+G!H<"QV(#$N,C,N,3`N-B`R,#`V+S`Q+S`Q
M(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V
M($5R:6,@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA
M<RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!%<FEC(%)O<W1E
M='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@*B!`
M<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W
M97(*("HO"F-L87-S($U)345?5FEE=V5R7V5N<FEC:&5D(&5X=&5N9',@34E-
M15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R
M<F5N=&QY('-E="!C;VYT96YT<R!I;B!(5$U,(&9O<FUA="X@5&AE"B`@("`@
M*B`D;6EM95]P87)T(&-L87-S('9A<FEA8FQE(&AA<R!T:&4@:6YF;W)M871I
M;VX@=&\@<F5N9&5R(&]U="P*("`@("`J(&5N8V%P<W5L871E9"!I;B!A($U)
M345?4&%R="!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@I
M"B`@("!["B`@("`@("`@:68@*"@D=&5X="`]("1T:&ES+3YM:6UE7W!A<G0M
M/F=E=$-O;G1E;G1S*"DI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H=')I;2@D=&5X="D@
M/3T@)R<I('L*("`@("`@("`@("`@<F5T=7)N("1T97AT.PH@("`@("`@('T*
M"B`@("`@("`@+R\@5V4@861D('-P86-E(&%T('1H92!B96=I;FYI;F<@86YD
M(&5N9"!O9B!T:&4@<W1R:6YG(&%S(&ET('=I;&P*("`@("`@("`O+R!M86ME
M('-O;64@<F5G=6QA<B!E>'!R97-S:6]N(&-H96-K<R!L871E<B!M=6-H(&5A
M<VEE<B`H<V\@=V4*("`@("`@("`O+R!D;VXG="!H879E('1O('=O<G)Y(&%B
M;W5T('-T87)T+V5N9"!O9B!L:6YE(&-H87)A8W1E<G,I"B`@("`@("`@)'1E
M>'0@/2`G("<@+B`D=&5X="`N("<@)SL*"B`@("`@("`@+R\@5V4@;F5E9"!T
M;R!P<F5S97)V92`\/"!T86=S+"!S;R!M87`@=&AE;2!T;R!A<V-I:2`Q(&]R
M(&%S8VEI(#(U-0H@("`@("`@("\O(%=E(&UA:V4@=&AE(&%S<W5M<'1I;VX@
M:&5R92!T:&%T('1H97)E('=O=6QD(&YE=F5R(&)E(&%N(&%S8VEI"B`@("`@
M("`@+R\@,2!I;B!A;B!E;6%I;"P@=VAI8V@@;6%Y(&YO="!B92!V86QI9"P@
M8G5T('-E96US(')E87-O;F%B;&4N+BX*("`@("`@("`O+R!A<V-I:2`R-34@
M=V]U;&0@=V]R:R!I9B!F;W(@<V]M92!R96%S;VX@>6]U(&1O;B=T(&QI:V4@
M87-C:6D@,0H@("`@("`@("\O(&%S8VEI(#`@9&]E<R!.3U0@<V5E;2!T;R!W
M;W)K(&9O<B!T:&ES+"!T:&]U9V@@22=M(&YO="!S=7)E('=H>0H@("`@("`@
M("1T97AT(#T@<W1R7W)E<&QA8V4H)SP\)RP@8VAR*#$I+"`D=&5X="D["@H@
M("`@("`@("\O(%)E;6]V92!A;GD@=6YR96-O9VYI>F5D('1A9W,@:6X@=&AE
M('1E>'0@*'9I82!21D,@;6EN:6UA;"!S<&5C<RD*("`@("`@("`O+R!A;GD@
M=&%G<R!W92!J=7-T(&1O;B=T('=A;G0@=&\@:6UP;&5M96YT(&-A;B!A;'-O
M(&)E(')E;6]V960@:&5R90H@("`@("`@("\O($YO=&4@=&AA="!T:&ES('=I
M;&P@<F5M;W9E(&%N>2!H=&UL(&QI;FMS+"!B=70@=&AI<R!I<R!I;G1E;F1E
M9`H@("`@("`@("1I;7!L96UE;G1E9%1A9W,@/2`G/'!A<F%M/CQB;VQD/CQI
M=&%L:6,^/'5N9&5R;&EN93X\9FEX960^/&5X8V5R<'0^)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<\<VUA;&QE<CX\8FEG9V5R/CQC96YT97(^
M/&-O;&]R/CQF;VYT9F%M:6QY/B<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/&9L=7-H;&5F=#X\9FQU<VAR:6=H=#X\9FQU<VAB;W1H/CQP87)A
M:6YD96YT/B<["B`@("`@("`@+R\@)'5N26UP;&5M96YT961486=S(#T@)SQN
M;V9I;&P^/&QA;F<^)SL*("`@("`@("`D=&5X="`]('-T<FEP7W1A9W,H)'1E
M>'0L("1I;7!L96UE;G1E9%1A9W,I.PH*("`@("`@("`O+R!R97-T;W)E('1H
M92`\/"!T86=S(&%S(#P@=&%G<R!N;W<N+BX*("`@("`@("`D=&5X="`]('-T
M<E]R97!L86-E*&-H<B@Q*2P@)SP\)RP@)'1E>'0I.PH@("`@("`@("\O("1T
M97AT(#T@<W1R7W)E<&QA8V4H8VAR*#(U-2DL("<\)RP@)'1E>'0I.PH*("`@
M("`@("`O+R!'970@8V]L;W(@<&%R86UE=&5R<R!I;G1O(&$@;6]R92!U<V5A
M8FQE(&9O<FUA="X*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+SQC
M;VQO<CX\<&%R86T^*%M<9&$M9D$M1ETK*2PH6UQD82UF02U&72LI+"A;7&1A
M+69!+49=*RD\7"]P87)A;3XO56ES)RP@)SQC;VQO<B!R/5PQ(&<]7#(@8CU<
M,SXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\\
M8V]L;W(^/'!A<F%M/BAR961\8FQU97QG<F5E;GQY96QL;W=\8WEA;GQM86=E
M;G1A?&)L86-K?'=H:71E*3Q<+W!A<F%M/B]5:7,G+"`G/&-O;&]R(&X]7#$^
M)RP@)'1E>'0I.PH*("`@("`@("`O+R!'970@9F]N="!F86UI;'D@<&%R86UE
M=&5R<R!I;G1O(&$@;6]R92!U<V5A8FQE(&9O<FUA="X*("`@("`@("`D=&5X
M="`]('!R96=?<F5P;&%C92@G+SQF;VYT9F%M:6QY/CQP87)A;3XH7'<K*3Q<
M+W!A<F%M/B]5:7,G+"`G/&9O;G1F86UI;'D@9CU<,3XG+"`D=&5X="D["@H@
M("`@("`@("\O($IU<W0@<F5M;W9E(&%N>2!R96UA:6YI;F<@<&%R86UE=&5R
M<R`M+2!W92!W;VXG="!U<V4*("`@("`@("`O+R!T:&5M+B!!;GD@=&%G<R!W
M:71H('!A<F%M971E<G,@=&AA="!W92!W86YT('1O(&EM<&QE;65N=`H@("`@
M("`@("\O('=I;&P@:&%V92!T;R!C;VUE(&)E9F]R92!T:&ES(%-O;65D87D@
M=V4@:&]P92!T;R!U<V4@=&AE<V4*("`@("`@("`O+R!T86=S("AE+F<N(&9O
M<B`\8V]L;W(^/'!A<F%M/B!T86=S*0H@("`@("`@("1T97AT(#T@<')E9U]R
M97!L86-E*"<O/'!A<F%M/BXJ/%PO<&%R86T^+U5I<R<L("<G+"`D=&5X="D[
M"@H@("`@("`@("\O(%-I;F=L92!L:6YE(&)R96%K<R!B96-O;64@<W!A8V5S
M+"!D;W5B;&4@;&EN92!B<F5A:W,@87)E(&$*("`@("`@("`O+R!R96%L(&)R
M96%K+B!4:&ES(&YE961S('1O(&1O(#QN;V9I;&P^('1R86-K:6YG('1O(&)E
M"B`@("`@("`@+R\@8V]M<&QI86YT(&)U="!W92!D;VXG="!W86YT('1O(&1E
M86P@=VET:"!S=&%T92!A="!T:&ES"B`@("`@("`@+R\@=&EM92P@<V\@=V4@
M9F%K92!I="!S;VUE(&1A>2!W92!S:&]U;&0@<F5W<FET92!T:&ES('1O"B`@
M("`@("`@+R\@:&%N9&QE(#QN;V9I;&P^(&-O<G)E8W1L>2X*("`@("`@("`D
M=&5X="`]('!R96=?<F5P;&%C92@G+RA;7EQN72E<<EQN*%M>7')=*2\G+"`G
M7#$@7#(G+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H
M)R\H7')<;BE<<EQN+R<L("=<,2<L("1T97AT*3L*"B`@("`@("`@+R\@5V4@
M=')Y('1O('!R;W1E8W0@86=A:6YS="!B860@<W1U9F8@:&5R92X*("`@("`@
M("`D=&5X="`]($!H=&UL<W!E8VEA;&-H87)S*"1T97AT+"!%3E1?455/5$53
M+"`D=&AI<RT^;6EM95]P87)T+3YG971#:&%R<V5T*"DI.PH*("`@("`@("`O
M+R!.;W<@8V]N=F5R="!T:&4@:VYO=VX@=&%G<R!T;R!H=&UL+B!4<GD@=&\@
M<F5M;W9E(&%N>2!T86<*("`@("`@("`O+R!P87)A;65T97)S('1O('-T;W`@
M<&5O<&QE(&9R;VT@=')Y:6YG('1O('!U;&P@82!F87-T(&]N90H@("`@("`@
M("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V)O;&0N*B9G
M=#LH+BHI)FQT.UPO8F]L9"9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)F;VYT
M+7=E:6=H=#H@8F]L9"(^7#$\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T
M97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.VET86QI8RXJ)F=T
M.R@N*BDF;'0[7"]I=&%L:6,F9W0[+U5I<R<L("<\<W!A;B!S='EL93TB9F]N
M="US='EL93H@:71A;&EC(CY<,3PO<W!A;CXG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[=6YD97)L:6YE
M+BHF9W0[*"XJ*29L=#M<+W5N9&5R;&EN929G=#LO56ES)RP@)SQS<&%N('-T
M>6QE/2)T97AT+61E8V]R871I;VXZ('5N9&5R;&EN92(^7#$\+W-P86X^)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E7V-A;&QB86-K
M*"<O*#\\(29L=#LI)FQT.V-O;&]R('(]*%M<9&$M9D$M1ETK*2!G/2A;7&1A
M+69!+49=*RD@8CTH6UQD82UF02U&72LI)F=T.R@N*BDF;'0[7"]C;VQO<B9G
M=#LO56ES)RP@87)R87DH)'1H:7,L("=C;VQO<FEZ92<I+"`D=&5X="D["B`@
M("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[8V]L
M;W(@;CTH<F5D?&)L=65\9W)E96Y\>65L;&]W?&-Y86Y\;6%G96YT87QB;&%C
M:WQW:&ET92DF9W0[*"XJ*29L=#M<+V-O;&]R)F=T.R]5:7,G+"`G/'-P86X@
M<W1Y;&4](F-O;&]R.B!<,2(^7#(\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@
M("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9O;G1F86UI
M;'DF9W0[*"XJ*29L=#M<+V9O;G1F86UI;'DF9W0[+U5I<R<L("=<,2<L("1T
M97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[
M*29L=#MF;VYT9F%M:6QY(&8]*%QW*RDF9W0[*"XJ*29L=#M<+V9O;G1F86UI
M;'DF9W0[+U5I<R<L("<\<W!A;B!S='EL93TB9F]N="UF86UI;'DZ(%PQ(CY<
M,CPO<W!A;CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA
M8V4H)R\H/SPA)FQT.RDF;'0[<VUA;&QE<BXJ)F=T.R]5:7,G+"`G/'-P86X@
M<W1Y;&4](F9O;G0M<VEZ93H@<VUA;&QE<B(^)RP@)'1E>'0I.PH@("`@("`@
M("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.UPO<VUA;&QE
M<B9G=#LO56ES)RP@)SPO<W!A;CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@
M/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[8FEG9V5R+BHF9W0[+U5I
M<R<L("<\<W!A;B!S='EL93TB9F]N="US:7IE.B!L87)G97(B/B<L("1T97AT
M*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L
M=#M<+V)I9V=E<B9G=#LO56ES)RP@)SPO<W!A;CXG+"`D=&5X="D["B`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[9FEX960N
M*B9G=#LH+BHI)FQT.UPO9FEX960F9W0[+U5I<R<L("<\9F]N="!F86-E/2)F
M:7AE9"(^7#$\+V9O;G0^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E
M9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V-E;G1E<BXJ)F=T.R@N*BDF;'0[
M7"]C96YT97(F9W0[+U5I<R<L("<\9&EV(&%L:6=N/2)C96YT97(B/EPQ/"]D
M:78^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O
M*#\\(29L=#LI)FQT.V9L=7-H;&5F="XJ)F=T.R@N*BDF;'0[7"]F;'5S:&QE
M9G0F9W0[+U5I<R<L("<\9&EV(&%L:6=N/2)L969T(CY<,3PO9&EV/B<L("1T
M97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[
M*29L=#MF;'5S:')I9VAT+BHF9W0[*"XJ*29L=#M<+V9L=7-H<FEG:'0F9W0[
M+U5I<R<L("<\9&EV(&%L:6=N/2)R:6=H="(^7#$\+V1I=CXG+"`D=&5X="D[
M"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[
M9FQU<VAB;W1H+BHF9W0[*"XJ*29L=#M<+V9L=7-H8F]T:"9G=#LO56ES)RP@
M)SQD:78@86QI9VX](FIU<W1I9GDB/EPQ/"]D:78^)RP@)'1E>'0I.PH@("`@
M("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.W!A<F%I
M;F1E;G0N*B9G=#LH+BHI)FQT.UPO<&%R86EN9&5N="9G=#LO56ES)RP@)SQB
M;&]C:W%U;W1E/EPQ/"]B;&]C:W%U;W1E/B<L("1T97AT*3L*("`@("`@("`D
M=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#ME>&-E<G!T+BHF
M9W0[*"XJ*29L=#M<+V5X8V5R<'0F9W0[+U5I<R<L("<\8FQO8VMQ=6]T93Y<
M,3PO8FQO8VMQ=6]T93XG+"`D=&5X="D["@H@("`@("`@("\O(%)E<&QA8V4@
M/#P@=VET:"`\(&YO=R`H9G)O;2!T<F%N<VQA=&5D($A434P@9F]R;2DN"B`@
M("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G)FQT.R9L=#LG+"`G)FQT.R<L
M("1T97AT*3L*"B`@("`@("`@+R\@3F]W('=E(')E;6]V92!T:&4@;&5A9&EN
M9R]T<F%I;&EN9R!S<&%C92!W92!A9&1E9"!A="!T:&4*("`@("`@("`O+R!S
M=&%R="X*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+UX@*"XJ*2`D
M+W,G+"`G7#$G+"`D=&5X="D["@H@("`@("`@("\O($UA:V4@55),<R!C;&EC
M:V%B;&4N"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]497AT+T9I;'1E
M<BYP:'`G.PH@("`@("`@("1T97AT(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D
M=&5X="P@)VQI;FMU<FQS)RP@87)R87DH)V-A;&QB86-K)R`]/B`G2&]R9&4Z
M.F5X=&5R;F%L57)L)RDI.PH*("`@("`@("`O+R!7;W)D=W)A<"`M+2!N;W1E
M('1H:7,@8V]U;&0@:6UP86-T(&]N(&]U<B!A8F]V92!21D,*("`@("`@("`O
M+R!C;VUP;&EA;F-E("I)1BH@=V4@:&]N;W)E9"!N;V9I;&P@=&%G<R`H=VAI
M8V@@=V4@9&]N)W0*("`@("`@("`O+R!Y970I+@H@("`@("`@("1T97AT(#T@
M<W1R7W)E<&QA8V4H(EQT(BP@)R`@("`@("`@)RP@)'1E>'0I.PH@("`@("`@
M("1T97AT(#T@<W1R7W)E<&QA8V4H)R`@)RP@)R`F;F)S<#LG+"`D=&5X="D[
M"B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@B7&X@(BP@(EQN)FYB<W`[
M(BP@)'1E>'0I.PH@("`@("`@(&EF("@D=&5X=%LP72`]/2`G("<I('L*("`@
M("`@("`@("`@)'1E>'0@/2`G)FYB<W`[)R`N('-U8G-T<B@D=&5X="P@,2D[
M"B`@("`@("`@?0H@("`@("`@("1T97AT(#T@;FPR8G(H)'1E>'0I.PH@("`@
M("`@("1T97AT(#T@)SQP(&-L87-S/2)F:7AE9"(^)R`N("1T97AT("X@)SPO
M<#XG.PH*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@9G5N8W1I
M;VX@8V]L;W)I>F4H)&-O;&]R<RD*("`@('L*("`@("`@("!F;W(@*"1I(#T@
M,3L@)&D@/"`T.R`D:2LK*2!["B`@("`@("`@("`@("1C;VQO<G-;)&E=(#T@
M<W!R:6YT9B@G)3`R6"<L(')O=6YD*&AE>&1E8R@D8V]L;W)S6R1I72D@+R`R
M-34I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("<\<W!A;B!S='EL93TB
M8V]L;W(Z(",G("X@)&-O;&]R<ULQ72`N("1C;VQO<G-;,ET@+B`D8V]L;W)S
M6S-=("X@)R(^)R`N("1C;VQO<G-;-%T@+B`G/"]S<&%N/B<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&]F
M('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O=71P=70N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-C,P`#$P-#$W,S8R-S<S`#`R,C4W
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]S;W5R
M8V4N<&AP)SL*"B\J*@H@*B!4:&4@34E-15]6:65W97)?96YS8W)I<'0@8VQA
M<W,@<F5N9&5R<R!O=70@=F%R:6]U<R!C;VYT96YT"B`J(&EN($A434P@9F]R
M;6%T(&)Y('5S:6YG($=.52!%;G-C<FEP="X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`L=B`Q+C,Y+C$P
M+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A
M<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS
M"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%
M7U9I97=E<E]E;G-C<FEP="!E>'1E;F1S($U)345?5FEE=V5R7W-O=7)C92![
M"@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!D871A('5S:6YG($5N
M<V-R:7!T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M;GD@<&%R86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@9&%T82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV97)S.PH*("`@("`@("`O*B!#
M:&5C:R!T;R!M86ME('-U<F4@=&AE('!R;V=R86T@86-T=6%L;'D@97AI<W1S
M+B`J+PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG96YS8W)I<'0G75LG;&]C871I;VXG72DI('L*("`@("`@("`@
M("`@<F5T=7)N("<\<')E/B<@+B!S<')I;G1F*%\H(E1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2XB*2P@)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YS
M8W)I<'0G75LG;&]C871I;VXG72D@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@
M("`@("`@("\J($-R96%T92!T96UP;W)A<GD@9FEL97,@9F]R(&EN<'5T('1O
M($5N<V-R:7!T+B!.;W1E('1H870@=V4*("`@("`@("`@("!C86YN;W0@=7-E
M(&$@<&EP92P@<VEN8V4@96YS8W)I<'0@;75S="!H879E(&%C8V5S<R!T;R!T
M:&4*("`@("`@("`@("!W:&]L92!F:6QE('1O(&1E=&5R;6EN92!I=',@='EP
M92!F;W(@8V]L;W5R960@<WEN=&%X"B`@("`@("`@("`@:&EG:&QI9VAT:6YG
M+B`J+PH@("`@("`@("1T;7!I;B`]($AO<F1E.CIG971496UP1FEL92@G16YS
M8W)I<'1);B<I.PH*("`@("`@("`O*B!7<FET92!T:&4@8V]N=&5N=',@;V8@
M;W5R(&)U9F9E<B!T;R!T:&4@=&5M<&]R87)Y(&EN<'5T(&9I;&4N("HO"B`@
M("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N
M=',H*3L*("`@("`@("`D9F@@/2!F;W!E;B@D=&UP:6XL("=W8B<I.PH@("`@
M("`@(&9W<FET92@D9F@L("1C;VYT96YT<RP@<W1R;&5N*"1C;VYT96YT<RDI
M.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`O*B!%>&5C=71E('1H
M92!E;G-C<FEP="!C;VUM86YD+B`J+PH@("`@("`@("1L86YG(#T@97-C87!E
M<VAE;&QA<F<H)'1H:7,M/E]T>7!E5&],86YG*"1T:&ES+3YM:6UE7W!A<G0M
M/F=E=%1Y<&4H*2DI.PH@("`@("`@("1R97-U;'1S(#T@<VAE;&Q?97AE8R@D
M;6EM95]D<FEV97)S6R=H;W)D92==6R=E;G-C<FEP="==6R=L;V-A=&EO;B==
M("X@(B`M121L86YG("TM;&%N9W5A9V4]:'1M;"`M+6-O;&]R("TM;W5T<'5T
M/2T@/"`D=&UP:6XB*3L*"B`@("`@("`@+RH@4W1R:7`@;W5T('1H92!E>'1R
M86YE;W5S($A434P@9G)O;2!%;G-C<FEP="P@86YD(&]U='!U="!I="X@*B\*
M("`@("`@("`D<F5S7V%R<B`]('!R96=?<W!L:70H)R]</%PO/W!R95P^+VDG
M+"`D<F5S=6QT<RD["B`@("`@("`@:68@*&-O=6YT*"1R97-?87)R*2`]/2`S
M*2!["B`@("`@("`@("`@("1R97-U;'1S(#T@=')I;2@D<F5S7V%R<ELQ72D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!%9'5C871E9"!'=65S<R!A="!W:&5T
M:&5R('=E(&%R92!I;FQI;F4@;W(@;F]T+B`J+PH@("`@("`@(&EF("AH96%D
M97)S7W-E;G0H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FQI;F5.
M=6UB97(H)')E<W5L=',I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!5=&EL.CIB=69F97)/=71P=70H)W)E<75I<F4G+"`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O
M8V]M;6]N+6AE861E<BYI;F,G*2`N"B`@("`@("`@("`@("`@("`D=&AI<RT^
M;&EN94YU;6)E<B@D<F5S=6QT<RD@+@H@("`@("`@("`@("`@("`@571I;#HZ
M8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@9&5T97)M:6YE('=H870@;&%N9W5A9V4@=&\@=7-E(&9O<B!T:&4@
M96YS8W)I<'0@<')O9W)A;0H@("`@("H@9G)O;2!A($U)344@='EP92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T>7!E("!4:&4@34E-12!T>7!E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@96YS8W)I<'0@)VQA;F=U86=E)R!P87)A
M;65T97(@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?='EP951O3&%N
M9R@D='EP92D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN+TUA9VEC+G!H<"<["@H@("`@("`@("1E>'0@/2!-
M24U%7TUA9VEC.CI-24U%5&]%>'0H)'1Y<&4I.PH*("`@("`@("!S=VET8V@@
M*"1E>'0I('L*("`@("`@("!C87-E("=C<R<Z"B`@("`@("`@("`@(')E='5R
M;B`G:F%V82<["@H@("`@("`@(&-A<V4@)V5L)SH*("`@("`@("`@("`@<F5T
M=7)N("=E;&ES<"<["@H@("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("!R
M971U<FX@)V,G.PH*("`@("`@("!C87-E("=#)SH*("`@("`@("!C87-E("=(
M)SH*("`@("`@("!C87-E("=C8R<Z"B`@("`@("`@8V%S92`G:&@G.@H@("`@
M("`@(&-A<V4@)V,K*R<Z"B`@("`@("`@8V%S92`G8WAX)SH*("`@("`@("!C
M87-E("=C<'`G.@H@("`@("`@("`@("!R971U<FX@)V-P<"<["@H@("`@("`@
M(&-A<V4@)VAT;2<Z"B`@("`@("`@8V%S92`G<VAT;6PG.@H@("`@("`@(&-A
M<V4@)WAM;"<Z"B`@("`@("`@("`@(')E='5R;B`G:'1M;"<["@H@("`@("`@
M(&-A<V4@)VIS)SH*("`@("`@("`@("`@<F5T=7)N("=J879A<V-R:7!T)SL*
M"B`@("`@("`@8V%S92`G<&%S)SH*("`@("`@("`@("`@<F5T=7)N("=P87-C
M86PG.PH*("`@("`@("!C87-E("=A;"<Z"B`@("`@("`@8V%S92`G8V=I)SH*
M("`@("`@("!C87-E("=P;"<Z"B`@("`@("`@8V%S92`G<&TG.@H@("`@("`@
M("`@("!R971U<FX@)W!E<FPG.PH*("`@("`@("!C87-E("=P<R<Z"B`@("`@
M("`@("`@(')E='5R;B`G<&]S='-C<FEP="<["@H@("`@("`@(&-A<V4@)W9B
M)SH*("`@("`@("`@("`@<F5T=7)N("=V8F$G.PH*("`@("`@("!C87-E("=V
M:&0G.@H@("`@("`@("`@("!R971U<FX@)W9H9&PG.PH*("`@("`@("!C87-E
M("=P871C:"<Z"B`@("`@("`@8V%S92`G9&EF9B<Z"B`@("`@("`@("`@(')E
M='5R;B`G9&EF9G4G.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R
M971U<FX@)&5X=#L*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O:'1M;"YP:'``````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-3$S
M`#$P-#$W,S8R-S<S`#`R,3<P,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R
M7VAT;6P@8VQA<W,@<F5N9&5R<R!O=70@2%1-3"!T97AT('=I=&@@86X@969F
M;W)T('1O"B`J(')E;6]V92!P;W1E;G1I86QL>2!M86QI8VEO=7,@8V]D92X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<"QV(#$N,30N-"XQ.2`R,#`V+S`R+S$V(#$V.C0T.C$T(&-H=6-K($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D
M9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*
M;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E
M+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]H=&UL(&5X
M=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U
M="!T:&4@8W5R<F5N=&QY('-E="!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE('9I97=E
M<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(')E;F1E<F5D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D
M<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C
M;&5A;DA434PH)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&:6QT97)S(&%C=&EV92!C;VYT96YT+"!D
M97)E9F5R96YC97,@97AT97)N86P@;&EN:W,L(&1E=&5C=',@<&AI<VAI;F<L
M"B`@("`@*B!E=&,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@5&AE($A434P@9&%T
M82X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-L96%N960@
M2%1-3"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VQE86Y(5$U,*"1D
M871A*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E<BP@)'!R969S.PH*
M("`@("`@("`D<&AI<VA?=V%R;B`](&9A;'-E.PH*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@("`D871T
M86-H;65N="`]($U)345?0V]N=&5N=',Z.G9I97=!<T%T=&%C:&UE;G0H*3L*
M"B`@("`@("`@+RH@1&5A;"!W:71H(#QB87-E/B!T86=S(&EN('1H92!(5$U,
M+"!S:6YC92!T:&5Y('=I;&P@<V-R97<@=7`@;W5R(&]W;@H@("`@("`@("`J
M(')E;&%T:79E('!A=&AS+B`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M/&)A<V4@:')E9CTB/RA;7B(^(%TJ*2(_(#]<+S\^+VDG+"`D9&%T82P@)&UA
M=&-H97,I*2!["B`@("`@("`@("`@("1B87-E(#T@)&UA=&-H97-;,5T["B`@
M("`@("`@("`@(&EF("AS=6)S='(H)&)A<V4L("TQ+"`Q*2`A/2`G+R<I('L*
M("`@("`@("`@("`@("`@("1B87-E("X]("<O)SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@4F5C=7)S:79E;'D@8V%L;"!?8VQE86Y(5$U,*"D@
M=&\@<')E=F5N="!C;&5V97(@9FEE;F1S(&9R;VT*("`@("`@("`@("`@("H@
M<VYE86MI;F<@;F%S='D@=&AI;F=S(&EN=&\@=&AE('!A9V4@=FEA("1B87-E
M+B`J+PH@("`@("`@("`@("`D8F%S92`]("1T:&ES+3Y?8VQE86Y(5$U,*"1B
M87-E*3L*("`@("`@("!]"@H@("`@("`@("\J($%T=&5M<'0@=&\@9FEX('!A
M=&AS('1H870@=V5R92!R96QY:6YG(&]N(&$@/&)A<V4^('1A9RX@*B\*("`@
M("`@("!I9B`H(65M<'1Y*"1B87-E*2D@>PH@("`@("`@("`@("`D<&%T=&5R
M;B`](&%R<F%Y*"=\<W)C/2A;(EPG72DH6UXZ(EPG72LI7#%\:2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)WQS<F,]*%M>.B`^(EPG72LI?&DG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=\:')E9CT@*BA;(EPG
M72DH6UXZ(EPG72LI7#%\:2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)WQH<F5F/2A;7CH@/B)<)UTK*7QI)RD["B`@("`@("`@("`@("1R97!L
M86-E(#T@87)R87DH)W-R8SU<,2<@+B`D8F%S92`N("=<,EPQ)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<W)C/2<@+B`D8F%S92`N("=<,2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAR968]7#$G("X@)&)A
M<V4@+B`G7#)<,2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAR
M968])R`N("1B87-E("X@)UPQ)RD["B`@("`@("`@("`@("1D871A(#T@<')E
M9U]R97!L86-E*"1P871T97)N+"`D<F5P;&%C92P@)&1A=&$I.PH@("`@("`@
M('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]497AT+T9I;'1E<BYP
M:'`G.PH@("`@("`@("1S=')I<%]S='EL97,@/2`A)&%T=&%C:&UE;G0@?'P*
M("`@("`@("`@("`@*"1B<F]W<V5R+3YI<T)R;W=S97(H)VUO>FEL;&$G*2`F
M)@H@("`@("`@("`@("`@)&)R;W=S97(M/F=E=$UA:F]R*"D@/3T@-"D@?'P*
M("`@("`@("`@("`@)&)R;W=S97(M/FES0G)O=W-E<B@G;7-I92<I.PH@("`@
M("`@("1D871A(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D9&%T82P@)WAS<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=B
M;V1Y7V]N;'DG(#T^("$D871T86-H;65N="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W-T<FEP7W-T>6QE<R<@/3X@)'-T
M<FEP7W-T>6QE<RDI.PH*("`@("`@("`O*B!#:&5C:R!F;W(@<&AI<VAI;F<@
M97AP;&]I=',N("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]H<F5F7',J
M/5QS*ELB7"==/UQS*BAH='1P?&AT='!S?&9T<"DZ7"]<+UQD>S$L,WU<+EQD
M>S$L,WU<+EQD>S$L,WU<+EQD>S$L,WTO:2<L("1D871A*2D@>PH@("`@("`@
M("`@("`O*B!#:&5C:R`Q.B!#:&5C:R!F;W(@25`@861D<F5S<R!L:6YK<RX@
M*B\*("`@("`@("`@("`@)'!H:7-H7W=A<FX@/2!T<G5E.PH@("`@("`@('T@
M96QS96EF("AP<F5G7VUA=&-H7V%L;"@G+VAR969<<RH]7',J6R)<)UT_7',J
M*#\Z:'1T<'QH='1P<WQF='`I.EPO7"\H6UY<<R)<)SY=*RE;(EPG73];7CY=
M*CY<<RHH/SHH/SIH='1P?&AT='!S?&9T<"DZ7"]<+RD_*"XJ/RD\7"]A+VES
M)RP@)&1A=&$L("1M*2D@>PH@("`@("`@("`@("`O*B`D;5LQ72`]($QI;FL[
M("1M6S)=(#T@5&%R9V5T"B`@("`@("`@("`@("`J($-H96-K(#(Z($-H96-K
M(&9O<B!L:6YK<R!T:&%T('!O:6YT('1O(&$@9&EF9F5R96YT(&AO<W0@=&AA
M;@H@("`@("`@("`@("`@*B!T:&4@=&%R9V5T('5R;#L@:68@=&%R9V5T(&QO
M;VMS(&QI:V4@82!D;VUA:6X@;F%M92P@8VAE8VL@:70*("`@("`@("`@("`@
M("H@86=A:6YS="!T:&4@;&EN:RX@*B\*("`@("`@("`@("`@)&QI;FMS(#T@
M8V]U;G0H)&U;,%TI.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M;&EN:W,[("1I*RLI('L*("`@("`@("`@("`@("`@("1M6S%=6R1I72`]('-T
M<G1O;&]W97(H=7)L9&5C;V1E*"1M6S%=6R1I72DI.PH@("`@("`@("`@("`@
M("`@)&U;,EU;)&E=(#T@<W1R=&]L;W=E<BAP<F5G7W)E<&QA8V4H)R]>*&AT
M='!\:'1T<'-\9G1P*3I<+UPO+R<L("<G+"!S=')I<%]T86=S*"1M6S)=6R1I
M72DI*3L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7ELN+5]<
M9&$M>ETK7"Y;82UZ77LR+'TO:2<L("1M6S)=6R1I72D@)B8*("`@("`@("`@
M("`@("`@("`@("!S=')P;W,H)&U;,5U;)&E=+"`D;5LR75LD:5TI("$]/2`P
M("8F"B`@("`@("`@("`@("`@("`@("`@<W1R<&]S*"1M6S)=6R1I72P@)&U;
M,5U;)&E=*2`A/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("\J($1O;B=T
M(&-O;G-I9&5R('1H92!L:6YK(&$@<&AI<VAI;F<@;&EN:R!I9B!T:&4@9&]M
M86EN"B`@("`@("`@("`@("`@("`@("`@("H@:7,@=&AE('-A;64@;VX@8F]T
M:"!L:6YK<R`H92YG+B!A9'1R86-K:6YG+F5X86UP;&4N8V]M"B`@("`@("`@
M("`@("`@("`@("`@("H@)B!W=W<N97AA;7!L92YC;VTI+B`J+PH@("`@("`@
M("`@("`@("`@("`@('!R96=?;6%T8V@H)R]<+C\H6UY<+EPO72M<+EM>7"Y<
M+UTK*5PO+R<L("1M6S%=6R1I72P@)&AO<W0Q*3L*("`@("`@("`@("`@("`@
M("`@("!P<F5G7VUA=&-H*"<O7"X_*%M>7"Y<+UTK7"Y;7EPN7"]=*RDH7"\N
M*BD_)"\G+"`D;5LR75LD:5TL("1H;W-T,BD["B`@("`@("`@("`@("`@("`@
M("`@:68@*"$H8V]U;G0H)&AO<W0Q*2`F)B!C;W5N="@D:&]S=#(I*2!\?`H@
M("`@("`@("`@("`@("`@("`@("`@("!S=')C87-E8VUP*"1H;W-T,5LQ72P@
M)&AO<W0R6S%=*2`A/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<&AI<VA?=V%R;B`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!4<GD@=&\@9&5R969E<B!A;&P@97AT97)N86P@<F5F97)E;F-E<RX@
M*B\*("`@("`@("`D9&%T82`]('!R96=?<F5P;&%C95]C86QL8F%C:R@G+VAR
M969<<RH]7',J*%LB7"==*3\H*#\H,2E;7EPQ72H_?%M>7',^72LI*2@_*#$I
M7#%\*2]I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C<F5A=&5?9G5N8W1I;VXH)R1M)RP@)W)E='5R;B!<)VAR968](EPG("X@
M*'-T<FQE;B@D;5LR72D@)B8@)&U;,EU[,'T@/3T@7"<C7"<@/R`D;5LR72`Z
M($AO<F1E.CIE>'1E<FYA;%5R;"@D;5LR72DI("X@7"<B7"<[)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$I.PH*("`@
M("`@("`O*B!0<F5P96YD('!H:7-H:6YG('=A<FYI;F<N("HO"B`@("`@("`@
M:68@*"1P:&ES:%]W87)N*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`G.PH@("`@("`@("`@("`D8V]N=&5N
M=',@/2`F;F5W($U)345?0V]N=&5N=',H;F5W($U)345?4&%R="@I*3L*("`@
M("`@("`@("`@)'!H:7-H7W=A<FYI;F<@/2!S<')I;G1F*%\H(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P
M<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA
M=&EO;BXB*2P@7R@B5V%R;FEN9R(I*3L*("`@("`@("`@("`@:68@*"1C;VYT
M96YT<RT^=FEE=T%S071T86-H;65N="@I*2!["B`@("`@("`@("`@("`@("`D
M<&AI<VA?=V%R;FEN9R`]("<\<W!A;B!S='EL93TB8F%C:V=R;W5N9"UC;VQO
M<CHC9F9D,&%F.V-O;&]R.F)L86-K(CXG("X@4W1R:6YG.CIC;VYV97)T0VAA
M<G-E="@D<&AI<VA?=V%R;FEN9RP@3DQ3.CIG971#:&%R<V5T*"DL("1T:&ES
M+3YM:6UE7W!A<G0M/F=E=$-H87)S970H*2D@+B`G/"]S<&%N/CQB<B`O/B<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!H:7-H7W=A<FYI;F<@/2`D
M8V]N=&5N=',M/F9O<FUA=%-T871U<TUS9R@D<&AI<VA?=V%R;FEN9RP@;G5L
M;"P@=')U92P@)VUI;653=&%T=7-787)N:6YG)RD["B`@("`@("`@("`@(&EF
M("AS=')I<W1R*"1D871A+"`G/&)O9'DG*2`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1D871A(#T@)'!H:7-H7W=A<FYI;F<@+B`D9&%T83L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D871A(#T@<')E
M9U]R97!L86-E*"<O*"XJ/&)O9'DN*C\^*2@N*BDO:2<L("<D,2<@+B`D<&AI
M<VA?=V%R;FEN9R`N("<D,B<L("1D871A*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!C;VYT96YT+71Y<&4@;V8@=&AE(')E;F1E<F5D
M('1E>'0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%
M($-O;G1E;G0M5'EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I
M"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+T-O;G1E
M;G1S+G!H<"<["B`@("`@("`@<F5T=7)N($U)345?0V]N=&5N=',Z.G9I97=!
M<T%T=&%C:&UE;G0H*2`_("1T:&ES+3YM:6UE7W!A<G0M/F=E=%1Y<&4H=')U
M92D@.B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'``````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C8Q,0`Q,#0Q-S,V,C<W,P`P,C(R,#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!-24U%7U9I97=E<E]I;6%G97,@8VQA<W,@86QL;W=S(&EM86=E<R!T;R!B
M92!D:7-P;&%Y960N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6UA9V5S+G!H<"QV(#$N,3@N."XY(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D
M92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S
M($U)345?5FEE=V5R7VEM86=E<R!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@8V]N=&5N="UT>7!E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="UT>7!E(&]F('1H
M92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@
M>PH@("`@("`@("1T>7!E(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T5'EP92@I
M.PH@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YI<T)R;W=S97(H
M)VUO>FEL;&$G*2`F)@H@("`@("`@("`@("`H)'1Y<&4@/3T@)VEM86=E+W!J
M<&5G)RDI('L*("`@("`@("`@("`@+RH@:6UA9V4O:G!E9R!A;F0@:6UA9V4O
M<&IP96<@*F%P<&5A<BH@=&\@8F4@=&AE('-A;64*("`@("`@("`@("`@("H@
M96YT:71Y+"!B=70@36]Z:6QL82!D;VXG="!S965M('1O('=A;G0@=&\@86-C
M97!T('1H90H@("`@("`@("`@("`@*B!L871T97(N("!&;W(@;W5R('!U<G!O
M<V5S+"!W92!W:6QL('1R96%T('1H96T@=&AE"B`@("`@("`@("`@("`J('-A
M;64N("HO"B`@("`@("`@("`@(')E='5R;B`G:6UA9V4O:G!E9R<["B`@("`@
M("`@?2!E;'-E:68@*"1T>7!E(#T]("=I;6%G92]X+7!N9R<I('L*("`@("`@
M("`@("`@+RH@:6UA9V4O>"UP;F<@:7,@97%U:79A;&5N="!T;R!I;6%G92]P
M;F<N("HO"B`@("`@("`@("`@(')E='5R;B`G:6UA9V4O<&YG)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1Y<&4["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@2%1-3"!O=71P=70@
M9F]R(&$@:F%V87-C<FEP="!A=71O+7)E<VEZ92!V:65W('=I;F1O=RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<FP@("`@5&AE(%523"!W:&EC:"!C;VYT86EN<R!T:&4@
M86-T=6%L(&EM86=E(&1A=&$N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T:71L
M92`@5&AE('1I=&QE('1O('5S92!F;W(@=&AE('!A9V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W!O<'5P26UA9V57:6YD;W<H)'5R;"P@)'1I=&QE*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E<CL*"B`@("`@("`@)'-T<B`]
M(#P\/$5/1`H\:'1M;#X*/&AE860^"CQT:71L93XD=&ET;&4\+W1I=&QE/@H\
M<W1Y;&4@='EP93TB=&5X="]C<W,B/CPA+2T@8F]D>2![(&UA<F=I;CHP<'@[
M('!A9&1I;F<Z,'!X.R!]("TM/CPO<W1Y;&4^"D5/1#L*"B`@("`@("`@+RH@
M3VYL>2!U<V4@:F%V87-C<FEP="!I9B!W92!A<F4@=7-I;F<@82!$3TT@8V%P
M86)L92!B<F]W<V5R+B`J+PH@("`@("`@(&EF("@D8G)O=W-E<BT^9V5T1F5A
M='5R92@G9&]M)RDI('L*("`@("`@("`@("`@+RH@5')A;G-L871E("<F86UP
M)R!E;G1I=&EE<R!T;R`G)B<@9F]R($I3(%523"!L:6YK<RX@*B\*("`@("`@
M("`@("`@)'5R;"`]('-T<E]R97!L86-E*"<F86UP.R<L("<F)RP@)'5R;"D[
M"@H@("`@("`@("`@("`O*B!-;WII;&QA(&%N9"!)12!D971E<FUI;F4@=VEN
M9&]W(&1I;65N<VEO;G,@:6X@9&EF9F5R96YT('=A>7,N("HO"B`@("`@("`@
M("`@(&EF("@D8G)O=W-E<BT^:7-"<F]W<V5R*"=M<VEE)RDI('L*("`@("`@
M("`@("`@("`@("1I5VED=&A?8V]D92`]("=D;V-U;65N="YB;V1Y+F-L:65N
M=%=I9'1H.R<["B`@("`@("`@("`@("`@("`D:4AE:6=H=%]C;V1E(#T@)V1O
M8W5M96YT+F)O9'DN8VQI96YT2&5I9VAT.R<["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D:5=I9'1H7V-O9&4@/2`G=VEN9&]W+FEN
M;F5R5VED=&@[)SL*("`@("`@("`@("`@("`@("1I2&5I9VAT7V-O9&4@/2`G
M=VEN9&]W+FEN;F5R2&5I9VAT.R<["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($IA=F%S8W)I<'0@9&ES<&QA>2X@*B\*("`@("`@("`@("`@)&QO
M861I;F<@/2!?*"),;V%D:6YG+BXN(BD["B`@("`@("`@("`@("1S='(@+CT@
M/#P\14]$"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*9G5N8W1I
M;VX@<F5S:7IE5VEN9&]W*"D@>PH@("`@=VEN9&]W+FUO=F54;R@P+"`P*3L*
M("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=S<&QA<V@G*2YS='EL92YD
M:7-P;&%Y(#T@)VYO;F4G.PH@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)V1I<W!?:6UA9V4G*2YS='EL92YD:7-P;&%Y(#T@)V)L;V-K)SL*("`@('9A
M<B!I5VED=&@@/2!D;V-U;65N="YI;6%G97-;,%TN=VED=&@@+2`D:5=I9'1H
M7V-O9&4*("`@('9A<B!I2&5I9VAT(#T@9&]C=6UE;G0N:6UA9V5S6S!=+FAE
M:6=H="`M("1I2&5I9VAT7V-O9&4*("`@('=I;F1O=RYR97-I>F5">2AI5VED
M=&@L(&E(96EG:'0I.PH@("`@<V5L9BYF;V-U<R@I.R`*?0H\+W-C<FEP=#X\
M+VAE860^"CQB;V1Y(&]N;&]A9#TB<F5S:7IE5VEN9&]W*"D[(CX\<W!A;B!I
M9#TB<W!L87-H(B!S='EL93TB8V]L;W(Z9W)A>3MF;VYT+69A;6EL>3IS86YS
M+7-E<FEF.W!A9&1I;F<Z,G!X.R(^)&QO861I;F<\+W-P86X^/&EM9R!I9#TB
M9&ES<%]I;6%G92(@<W1Y;&4](F1I<W!L87DZ;F]N93LB('-R8STB)'5R;"(@
M+SX\+V)O9'D^/"]H=&UL/@I%3T0["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+RH@3F]N+6IA=F%S8W)I<'0@9&ES<&QA>2X@*B\*("`@("`@("`@
M("`@)&EM9U]T>'0@/2!?*"));6%G92(I.PH@("`@("`@("`@("`D<W1R("X]
M(#P\/$5/1`H\+VAE860^"CQB;V1Y(&)G8V]L;W(](B-F9F9F9F8B('1O<&UA
M<F=I;CTB,"(@;6%R9VEN:&5I9VAT/2(P(B!L969T;6%R9VEN/2(P(B!M87)G
M:6YW:61T:#TB,"(^"CQI;6<@8F]R9&5R/2(P(B!S<F,](B1U<FPB(&%L=#TB
M)&EM9U]T>'0B("\^"CPO8F]D>3X*/"]H=&UL/@I%3T0["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'-T<CL*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<```````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#,T-#``,3`T,3<S-C(W-S,`,#(R,S<T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@34E-15]6:65W97)?;7-E>&-E;"!C;&%S<R!R96YD97)S(&]U="!-:6-R
M;W-O9G0@17AC96P*("H@9&]C=6UE;G1S(&EN($A434P@9F]R;6%T(&)Y('5S
M:6YG('1H92!X;$AT;6P@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<"QV(#$N,C`N,3`N-R`R
M,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D
M>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@
M0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE
M=V5R7VUS97AC96P@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@
M("`@*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@9&%T82!U<VEN9R!X;&AT
M;6PN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P
M87)A;7,@=&AI<R!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J($-H96-K('1O
M(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES=',N("HO"B`@
M("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S6R=H;W)D92==
M6R=M<V5X8V5L)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R
M;B`G/'!R93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC96PG75LG
M;&]C871I;VXG72D@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@("`@("`@("1D
M871A(#T@)R<["B`@("`@("`@)'1M<%]X;',@/2!(;W)D93HZ9V5T5&5M<$9I
M;&4H)VAO<F1E7VUS97AC96PG*3L*"B`@("`@("`@)&9H(#T@9F]P96XH)'1M
M<%]X;',L("=W)RD["B`@("`@("`@9G=R:71E*"1F:"P@)'1H:7,M/FUI;65?
M<&%R="T^9V5T0V]N=&5N=',H*2D["B`@("`@("`@9F-L;W-E*"1F:"D["@H@
M("`@("`@("1F:"`]('!O<&5N*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS
M97AC96PG75LG;&]C871I;VXG72`N("(@+6YH("1T;7!?>&QS(#(^)C$B+"`G
M<B<I.PH@("`@("`@('=H:6QE("@H)')C(#T@9F=E=',H)&9H+"`X,3DR*2DI
M('L*("`@("`@("`@("`@)&1A=&$@+CT@)')C.PH@("`@("`@('T*("`@("`@
M("!P8VQO<V4H)&9H*3L*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O
M9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U
M<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<```````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`S-3$R`#$P-#$W,S8R-S<S`#`R,S4P,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)
M345?5FEE=V5R7VUS<&]W97)P;VEN="!C;&%S<R!R96YD97)S(&]U="!-:6-R
M;W-O9G0@4&]W97)P;VEN=`H@*B!D;V-U;65N=',@:6X@2%1-3"!F;W)M870@
M8GD@=7-I;F<@=&AE('AL2'1M;"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`L=B`Q
M+C$S+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R
M96-O:6PN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-
M861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S
M<R!-24U%7U9I97=E<E]M<W!O=V5R<&]I;G0@97AT96YD<R!-24U%7U9I97=E
M<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT(&1A
M=&$@=7-I;F<@<'!T:'1M;"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O
M;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,[
M"@H@("`@("`@("\J($-H96-K('1O(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A
M8W1U86QL>2!E>&ES=',N("HO"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D
M;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W!O=V5R<&]I;G0G75LG;&]C871I
M;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!S<')I;G1F
M*%\H(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H
M)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB*2P@)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG;7-P;W=E<G!O:6YT)UU;)VQO8V%T:6]N)UTI("X@
M)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D9&%T82`]("<G.PH@("`@
M("`@("1T;7!?<'!T(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=H;W)D95]M<W!O
M=V5R<&]I;G0G*3L*"B`@("`@("`@)&9H(#T@9F]P96XH)'1M<%]P<'0L("=W
M)RD["B`@("`@("`@9G=R:71E*"1F:"P@)'1H:7,M/FUI;65?<&%R="T^9V5T
M0V]N=&5N=',H*2D["B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@("`@("1F
M:"`]('!O<&5N*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS<&]W97)P;VEN
M="==6R=L;V-A=&EO;B==("X@(B`D=&UP7W!P="`R/B8Q(BP@)W(G*3L*("`@
M("`@("!W:&EL92`H*"1R8R`](&9G971S*"1F:"P@.#$Y,BDI*2!["B`@("`@
M("`@("`@("1D871A("X]("1R8SL*("`@("`@("!]"B`@("`@("`@<&-L;W-E
M*"1F:"D["@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E
M;F1E<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT
M+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VUS=V]R9"YP:'``````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-3$R-``Q,#0Q-S,V,C<W,P`P,C(R-3``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I
M97=E<E]M<W=O<F0@8VQA<W,@<F5N9&5R<R!O=70@36EC<F]S;V9T(%=O<F0*
M("H@9&]C=6UE;G1S(&EN($A434P@9F]R;6%T(&)Y('5S:6YG('1H92!W=E=A
M<F4@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP+'8@,2XR-2XQ,"XX(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI
M;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I
M;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D
M95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?;7-W;W)D(&5X
M=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U
M="!T:&4@8W5R<F5N="!D871A('5S:6YG('=V5V%R92X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I
M97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L
M("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J($-H96-K('1O(&UA:V4@<W5R
M92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES=',N("HO"B`@("`@("`@:68@
M*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O<F0G
M75LG;&]C871I;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@
M+B!S<')I;G1F*%\H(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB*2P@
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VQO8V%T:6]N)UTI
M("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D9&%T82`]("<G.PH@
M("`@("`@("1T;7!?=V]R9"`@(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=M<W=O
M<F0G*3L*("`@("`@("`D=&UP7V]U='!U="`]($AO<F1E.CIG971496UP1FEL
M92@G;7-W;W)D)RD["B`@("`@("`@)'1M<%]D:7(@("`@/2!(;W)D93HZ9V5T
M5&5M<$1I<B@I.PH@("`@("`@("1T;7!?9FEL92`@(#T@<W1R7W)E<&QA8V4H
M)'1M<%]D:7(@+B`G+R<L("<G+"`D=&UP7V]U='!U="D["@H@("`@("`@(&EF
M("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1A<F=S(#T@)R`M>"`G("X@
M9&ER;F%M92@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O<F0G75LG;&]C
M871I;VXG72D@+B`B7%QW=DAT;6PN>&UL("UD("1T;7!?9&ER("TQ("1T;7!?
M=V]R9"`^("1T;7!?;W5T<'5T(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=F5R<VEO;B`](&5X96,H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M;7-W;W)D)UU;)VQO8V%T:6]N)UT@+B`G("TM=F5R<VEO;B<I.PH@("`@("`@
M("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`G,"XW+C`G*2`^
M/2`P*2!["B`@("`@("`@("`@("`@("`D87)G<R`]("(@+2UC:&%R<V5T/2(@
M+B!.3%,Z.F=E=$-H87)S970H*2`N("(@+2UT87)G971D:7(])'1M<%]D:7(@
M)'1M<%]W;W)D("1T;7!?9FEL92(["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D87)G<R`]("(@)'1M<%]W;W)D("1T;7!?;W5T<'5T
M(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&9H(#T@9F]P
M96XH)'1M<%]W;W)D+"`G=R<I.PH@("`@("`@(&9W<FET92@D9F@L("1T:&ES
M+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@("`@(&9C;&]S92@D
M9F@I.PH*("`@("`@("!E>&5C*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS
M=V]R9"==6R=L;V-A=&EO;B==("X@)&%R9W,I.PH*("`@("`@("!I9B`H(69I
M;&5?97AI<W1S*"1T;7!?;W5T<'5T*2D@>PH@("`@("`@("`@("!R971U<FX@
M7R@B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B*3L*
M("`@("`@("!]"@H@("`@("`@("1F:"`](&9O<&5N*"1T;7!?;W5T<'5T+"`G
M<B<I.PH@("`@("`@('=H:6QE("@H)')C(#T@9F=E=',H)&9H+"`X,3DR*2DI
M('L*("`@("`@("`@("`@)&1A=&$@+CT@)')C.PH@("`@("`@('T*("`@("`@
M("!F8VQO<V4H)&9H*3L*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O
M9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U
M<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+G!H<```
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,C(Q`#$P-#$W,S8R-S<S
M`#`R,34S,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7V]O;R!C;&%S<R!R
M96YD97)S(&]U="!/<&5N3V9F:6-E+F]R9PH@*B!D;V-U;65N=',@:6X@2%1-
M3"!F;W)M870N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;V]O+G!H<"QV(#$N,30N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(U
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J
M=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E
M<@H@*B\*8VQA<W,@34E-15]6:65W97)?;V]O(&5X=&5N9',@34E-15]6:65W
M97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N="!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@
M<&%R86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D=7-E7WAS;'0@/2!5=&EL.CIE>'1E;G-I;VY%>&ES=',H
M)WAS;'0G*2!\?"!F=6YC=&EO;E]E>&ES=',H)V1O;7AM;%]X<VQT7W-T>6QE
M<VAE971?9FEL92<I.PH@("`@("`@(&EF("@D=7-E7WAS;'0I('L*("`@("`@
M("`@("`@)'1M<&1I<B`](%5T:6PZ.F-R96%T951E;7!$:7(H=')U92D["B`@
M("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R97-S
M+G!H<"<["B`@("`@("`@)'AM;%]T86=S("`](&%R<F%Y*"=T97AT.G`G+"`G
M=&%B;&4Z=&%B;&4@)RP@)W1A8FQE.G1A8FQE+7)O=R<L("=T86)L93IT86)L
M92UC96QL)RP@)W1A8FQE.FYU;6)E<BUC;VQU;6YS+7-P86YN960])RD["B`@
M("`@("`@)&AT;6Q?=&%G<R`](&%R<F%Y*"=P)RP@)W1A8FQE(&)O<F1E<CTB
M,"(@8V5L;'-P86-I;F<](C$B(&-E;&QP861D:6YG/2(P(B`G+"`G='(@8F=C
M;VQO<CTB(V-C8V-C8R(G+"`G=&0G+"`G8V]L<W!A;CTG*3L*("`@("`@("`D
M>FEP(#T@)DAO<F1E7T-O;7!R97-S.CIS:6YG;&5T;VXH)WII<"<I.PH@("`@
M("`@("1L:7-T(#T@)'II<"T^9&5C;VUP<F5S<R@D=&AI<RT^;6EM95]P87)T
M+3YG971#;VYT96YT<R@I+`H@("`@("`@("`@("!A<G)A>2@G86-T:6]N)R`]
M/B!(3U)$15]#3TU04D534U]:25!?3$E35"DI.PH@("`@("`@(&9O<F5A8V@@
M*"1L:7-T(&%S("1K97D@/3X@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F
M:6QE6R=N86UE)UT@/3T@)V-O;G1E;G0N>&UL)R!\?`H@("`@("`@("`@("`@
M("`@)&9I;&5;)VYA;64G72`]/2`G<W1Y;&5S+GAM;"<@?'P*("`@("`@("`@
M("`@("`@("1F:6QE6R=N86UE)UT@/3T@)VUE=&$N>&UL)RD@>PH@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/2`D>FEP+3YD96-O;7!R97-S*"1T:&ES+3YM
M:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DL"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH)V%C=&EO;B<@/3X@2$]21$5?0T]-4%)%4U-?6DE07T1!5$$L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VEN9F\G("`@/3X@)&QI<W0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VME>2<@("`@/3X@)&ME>2DI.PH@
M("`@("`@("`@("`@("`@:68@*"1U<V5?>'-L="D@>PH@("`@("`@("`@("`@
M("`@("`@("1F<"`](&9O<&5N*"1T;7!D:7(@+B`D9FEL95LG;F%M92==+"`G
M=R<I.PH@("`@("`@("`@("`@("`@("`@(&9W<FET92@D9G`L("1C;VYT96YT
M*3L*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@
M("`@("`@('T@96QS96EF("@D9FEL95LG;F%M92==(#T]("=C;VYT96YT+GAM
M;"<I('L*("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="`]('-T<E]R97!L
M86-E*"1X;6Q?=&%G<RP@)&AT;6Q?=&%G<RP@)&-O;G1E;G0I.PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D8V]N=&5N=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(55T:6PZ
M.F5X=&5N<VEO;D5X:7-T<R@G>'-L="<I*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V1O
M;7AM;%]X<VQT7W-T>6QE<VAE971?9FEL92<I*2!["B`@("`@("`@("`@("\O
M(%5S92!$3TU834P*("`@("`@("`@("`@)'AS;'0@/2!D;VUX;6Q?>'-L=%]S
M='EL97-H965T7V9I;&4H9&ER;F%M92A?7T9)3$5?7RD@+B`G+V]O;R]M86EN
M7VAT;6PN>'-L)RD["B`@("`@("`@("`@("1D;VT@(#T@9&]M>&UL7V]P96Y?
M9FEL92@D=&UP9&ER("X@)V-O;G1E;G0N>&UL)RD["B`@("`@("`@("`@("1R
M97-U;'0@/2!`)'AS;'0M/G!R;V-E<W,H)&1O;2P@87)R87DH)VUE=&%&:6QE
M55),)R`]/B`D=&UP9&ER("X@)VUE=&$N>&UL)RP@)W-T>6QE<T9I;&554DPG
M(#T^("1T;7!D:7(@+B`G<W1Y;&5S+GAM;"<L("=D:7-A8FQE2F%V82<@/3X@
M=')U92DI.PH@("`@("`@("`@("!R971U<FX@4W1R:6YG.CIC;VYV97)T0VAA
M<G-E="@D>'-L="T^<F5S=6QT7V1U;7!?;65M*"1R97-U;'0I+"`G551&+3@G
M+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@57-E(%A33%0*("`@("`@("`@("`@)'AS;'0@/2!X<VQT7V-R
M96%T92@I.PH@("`@("`@("`@("`D<F5S=6QT(#T@0'AS;'1?<')O8V5S<R@D
M>'-L="P@)'1M<&1I<B`N("=C;VYT96YT+GAM;"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&1I<FYA;64H7U]&24Q%7U\I("X@)R]O
M;V\O;6%I;E]H=&UL+GAS;"<L(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=M971A1FEL95523"<@/3X@
M)'1M<&1I<B`N("=M971A+GAM;"<L("=S='EL97-&:6QE55),)R`]/B`D=&UP
M9&ER("X@)W-T>6QE<RYX;6PG+"`G9&ES86)L94IA=F$G(#T^('1R=64I*3L*
M("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@>'-L=%]E<G)O<B@D>'-L="D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@>'-L=%]F<F5E*"1X<VQT*3L*("`@("`@("`@("`@<F5T=7)N
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)')E<W5L="P@)U541BTX)RP@3DQ3
M.CIG971#:&%R<V5T*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E
M<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT
M;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O<&1F+G!H<```````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q-3,Q`#$P-#$W,S8R-S<S`#`R,34P-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?
M5FEE=V5R7W!D9B!C;&%S<R!S:6UP;'D@;W5T<'5T<R!T:&4@4$1&(&9I;&4@
M=VET:"!T:&4@8V]N=&5N="UT>7!E"B`J("=A<'!L:6-A=&EO;B]P9&8G(&5N
M86)L:6YG('=E8B!B<F]W<V5R<R!W:71H(&$@4$1&('9I97=E<B!P;'5G:6X@
M=&\@=FEE=PH@*B!T:&4@4$1&(&9I;&4@:6YS:61E('1H92!B<F]W<V5R+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W!D9BYP
M:'`L=B`Q+C,N,3(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]P9&8@
M97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M=&AE(&-O;G1E;G0M='EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&-O;G1E;G0M='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)V%P
M<&QI8V%T:6]N+W!D9B<["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(O<&AP+G!H<```````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R-C8P`#$P-#$W,S8R-S<S`#`R,34R-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]S;W5R8V4N<&AP)SL*"B\J*@H@
M*B!4:&4@34E-15]6:65W97)?<&AP(&-L87-S(')E;F1E<G,@;W5T('-Y;G1A
M>"UH:6=H;&EG:'1E9"!02%`@8V]D90H@*B!I;B!(5$U,(&9O<FUA="X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]P:'`N<&AP
M+'8@,2XR,BXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S
M<R!-24U%7U9I97=E<E]P:'`@97AT96YD<R!-24U%7U9I97=E<E]S;W5R8V4@
M>PH*("`@("\J*@H@("`@("H@4F5N9&5R<R!O=70@=&AE(&-O;G1E;G1S+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE
M=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D<F5S=6QT<R`]('1R:6TH<W1R7W)E<&QA8V4H87)R87DH(EQN(BP@
M)SQB<B`O/B<I+"!A<G)A>2@G)RP@(EQN(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&AI9VAL:6=H=%]S=')I;F<H)'1H:7,M/FUI
M;65?<&%R="T^9V5T0V]N=&5N=',H*2P@=')U92DI*3L*"B`@("`@("`@+R\@
M161U8V%T960@1W5E<W,@870@=VAE=&AE<B!W92!A<F4@:6YL:6YE(&]R(&YO
M="X*("`@("`@("!I9B`H:&5A9&5R<U]S96YT*"DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YL:6YE3G5M8F5R*"1R97-U;'1S*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@571I;#HZ8G5F9F5R3W5T<'5T
M*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA
M=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUH96%D97(N:6YC)RD@+@H@("`@
M("`@("`@("`@("`@)'1H:7,M/FQI;F5.=6UB97(H)')E<W5L=',I("X*("`@
M("`@("`@("`@("`@(%5T:6PZ.F)U9F9E<D]U='!U="@G<F5Q=6ER92<L("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I
M("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<I.PH@("`@("`@('T*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]P;&%I;BYP
M:'``````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4T-S8`,3`T,3<S-C(W
M-S,`,#(R,#4R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?<&QA:6X@8VQA
M<W,@<F5N9&5R<R!O=70@<&QA:6X@=&5X="!W:71H(%523',@;6%D90H@*B!I
M;G1O(&AY<&5R;&EN:W,@*&EF('9I97=I;F<@:6YL:6YE*2X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]P;&%I;BYP:'`L=B`Q
M+C$X+C8N,3`@,C`P-B\P,2\R,R`Q-3HS-3HP-B!S;'5S87)Z($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R
M9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E
M7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]P;&%I;B!E>'1E
M;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@
M=&AE(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;GD@<&%R86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N
M=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP)SL*"B`@("`@("`@)'1E>'0@/2`D=&AI<RT^;6EM95]P
M87)T+3YG971#;VYT96YT<R@I.PH*("`@("`@("`O*B!#:&5C:R!F;W(@)V9L
M;W=E9"<@=&5X="!D871A+B`J+PH@("`@("`@("1F;&]W960@/2`H)'1H:7,M
M/FUI;65?<&%R="T^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)V9O<FUA="<I
M(#T]("=F;&]W960G*3L*("`@("`@("!I9B`H)&9L;W=E9"D@>PH@("`@("`@
M("`@("`D=&5X="`]("1T:&ES+3Y?9F]R;6%T1FQO=V5D*"1T97AT*3L*("`@
M("`@("!]"@H@("`@("`@("\J($EF(&-A;&QI;F<@87,@86X@871T86-H;65N
M="!F<F]M('9I97<N<&AP+"!W92!D;R!N;W0@=V%N=`H@("`@("`@("`@('1O
M(&%L=&5R('1H92!T97AT(&EN(&%N>2!W87D@=VET:"!(5$U,+B`J+PH@("`@
M("`@(&EF("A-24U%7T-O;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T97AT.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP
M)SL*("`@("`@("`@("`@<F5T=7)N(%1E>'1?1FEL=&5R.CIF:6QT97(H)'1E
M>'0L("=T97AT,FAT;6PG+"!A<G)A>2@G<&%R<V5L979E;"<@/3X@5$585%](
M5$U,7TU)0U)/+"`G8VAA<G-E="<@/3X@;G5L;"P@)V-L87-S)R`]/B!N=6QL
M*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP
M92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E
M*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP)SL*("`@("`@("!R971U<FX@*$U)345?0V]N=&5N=',Z.G9I
M97=!<T%T=&%C:&UE;G0H*2D@/R`D=&AI<RT^;6EM95]P87)T+3YG9714>7!E
M*'1R=64I(#H@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R
M<V5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)M870@9FQO=V5D('1E
M>'0@9F]R($A434P@;W5T<'5T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@("`@5&AE('1E>'0@=&\@9F]R;6%T+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&]P="`@("!4:&4@;W!T:6UA;"!L96YG=&@@=&\@=W)A<"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1M87@@("`@5&AE(&UA>&EM=6T@;&5N
M9W1H('1O('=R87`N(#`@;65A;G,@9&]N)W0@=W)A<"X*("`@("`J($!P87)A
M;2!B;V]L96%N("1D96QS<"`@5V%S('1E>'0@8W)E871E9"!W:71H($1E;%-P
M(&9O<FUA='1I;F<_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!F;W)M871T960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9O<FUA
M=$9L;W=E9"@D=&5X="P@)&]P="`](&YU;&PL("1M87@@/2!N=6QL+"`D9&5L
M<W`@/2!N=6QL*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G5&5X="]&
M;&]W960N<&AP)SL*("`@("`@("`D9FQO=V5D(#T@)FYE=R!497AT7T9L;W=E
M9"@D=&AI<RT^;6EM95]P87)T+3YR97!L86-E14],*"1T97AT+"`B7&XB*2P@
M)'1H:7,M/FUI;65?<&%R="T^9V5T0VAA<G-E="@I*3L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&]P="DI('L*("`@("`@("`@("`@)&9L;W=E9"T^<V5T3W!T
M3&5N9W1H*"1O<'0I.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH
M)&UA>"DI('L*("`@("`@("`@("`@)&9L;W=E9"T^<V5T36%X3&5N9W1H*"1M
M87@I.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)&1E;'-P*2D@
M>PH@("`@("`@("`@("`D9FQO=V5D+3YS971$96Q3<"@D9&5L<W`I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&9L;W=E9"T^=&]&:7AE9"@I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q-C$R-@`Q,#0Q-S,V,C<W,P`P,C$U,C4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!-24U%7U9I97=E<E]R87(@8VQA<W,@<F5N9&5R<R!O=70@=&AE
M(&-O;G1E;G1S(&]F("YR87(@87)C:&EV97,@:6X@2%1-3`H@*B!F;W)M870N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<"QV(#$N,3@N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y
M(#QA;FEL0')E8V]I;"YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC
M:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL
M0')E8V]I;"YO<F<^"B`J($!A=71H;W(@($UI8VAA96P@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6
M:65W97)?<F%R(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@
M("H@4F%R(&-O;7!R97-S:6]N(&UE=&AO9',N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]M971H;V1S(#T@87)R87DH"B`@
M("`@("`@,'@S,"`@/3X@("=3=&]R92<L"B`@("`@("`@,'@S,2`@/3X@("=&
M87-T97-T)RP*("`@("`@("`P>#,R("`]/B`@)T9A<W0G+`H@("`@("`@(#!X
M,S,@(#T^("`G3F]R;6%L)RP*("`@("`@("`P>#,T("`]/B`@)T=O;V0G+`H@
M("`@("`@(#!X,S4@(#T^("`G0F5S="<*("`@("D["@H@("`@+RHJ"B`@("`@
M*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S('5S:6YG
M(')A<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY
M('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T
M0V]N=&5N=',H*3L*"B`@("`@("`@+RH@36%K92!S=7)E('1H:7,@:7,@82!V
M86QI9"!R87(@9FEL92X@*B\*("`@("`@("!I9B`H)'1H:7,M/F-H96-K4F%R
M1&%T82@D8V]N=&5N=',I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@)SQP<F4^)R`N(%\H(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N(BD@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH*("`@("`@
M("`D<F%R1&%T82`]("1T:&ES+3YG971287)$871A*"1C;VYT96YT<RD["B`@
M("`@("`@)&9I;&5#;W5N="`](&-O=6YT*"1R87)$871A*3L*"B`@("`@("`@
M)'1E>'0@(#T@)SQS=')O;F<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT
M9BA?*")#;VYT96YT<R!O9B!<(B5S7"(B*2P@)'1H:7,M/FUI;65?<&%R="T^
M9V5T3F%M92@I*2D@+B`G.CPO<W1R;VYG/B<@+B`B7&XB.PH@("`@("`@("1T
M97AT("X]("<\=&%B;&4^/'1R/CQT9"!A;&EG;CTB;&5F="(^/'1T/CQS<&%N
M(&-L87-S/2)F:7AE9"(^)SL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL
M06QL4W!A8V5S*%\H(D%R8VAI=F4@3F%M92(I("X@)SH@("<@+B`D=&AI<RT^
M;6EM95]P87)T+3YG971.86UE*"DI("X@(EQN(CL*("`@("`@("`D=&5X="`N
M/2!497AT.CIH=&UL06QL4W!A8V5S*%\H(D%R8VAI=F4@1FEL92!3:7IE(BD@
M+B`G.B`G("X@<W1R;&5N*"1C;VYT96YT<RD@+B`G(&)Y=&5S)RD@+B`B7&XB
M.PH@("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H*"1F:6QE
M0V]U;G0@(3T@,2D@/R!S<')I;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&5S
M(BDL("1F:6QE0V]U;G0I(#H@<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F
M:6QE(BDL("1F:6QE0V]U;G0I*3L*("`@("`@("`D=&5X="`N/2`B7&Y<;B([
M"B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@("`@
M("`@("`@("`@("`@("`@<W1R7W!A9"A?*")&:6QE($YA;64B*2P@("`@(#4P
M+"`G("<L(%-44E]0041?4DE'2%0I("X*("`@("`@("`@("`@("`@("`@("`@
M<W1R7W!A9"A?*")!='1R:6)U=&5S(BDL("`@(#$P+"`G("<L(%-44E]0041?
M3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(E-I>F4B
M*2P@("`@("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@
M("`@("`@("`@("`@('-T<E]P860H7R@B36]D:69I960@1&%T92(I+"`Q.2P@
M)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R
M7W!A9"A?*")-971H;V0B*2P@("`@("`@(#$P+"`G("<L(%-44E]0041?3$5&
M5"D@+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(E)A=&EO(BDL
M("`@("`@("`@(#<L("<@)RP@4U127U!!1%],1494*0H@("`@("`@("`@("`@
M("`@("D@+B`B7&XB.PH*("`@("`@("`D=&5X="`N/2!S=')?<F5P96%T*"<M
M)RP@,3`V*2`N(")<;B(["@H@("`@("`@(&9O<F5A8V@@*"1R87)$871A(&%S
M("1V86PI('L*("`@("`@("`@("`@)')A=&EO(#T@*&5M<'1Y*"1V86Q;)W-I
M>F4G72DI(#\@,"`Z(#$P,"`J("@D=F%L6R=C<VEZ92==("\@)'9A;%LG<VEZ
M92==*3L*("`@("`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E
M<R@*("`@("`@("`@("`@("`@("`@("`@("`@('-T<E]P860H)'9A;%LG;F%M
M92==+"`U,"P@)R`G+"!35%)?4$%$7U))1TA4*2`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')?<&%D*"1V86Q;)V%T='(G72P@,3`L("<@)RP@4U12
M7U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("!S=')?<&%D
M*"1V86Q;)W-I>F4G72P@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("!S=')?<&%D*'-T<F9T:6UE*"(E9"TE8BTE
M62`E2#HE32(L("1V86Q;)V1A=&4G72DL(#$Y+"`G("<L(%-44E]0041?3$5&
M5"D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"@D=F%L6R=M
M971H;V0G72P@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')?<&%D*'-P<FEN=&8H(B4Q+C%F)24B+"`D<F%T
M:6\I+"`W+"`G("<L(%-44E]0041?3$5&5"D*("`@("`@("`@("`@("`@("`@
M("`@*2`N(")<;B(["B`@("`@("`@?0H*("`@("`@("`D=&5X="`N/2!S=')?
M<F5P96%T*"<M)RP@,3`V*2`N(")<;B(["B`@("`@("`@)'1E>'0@+CT@)SPO
M<W!A;CX\+W1T/CPO=&0^/"]T<CX\+W1A8FQE/B<["@H@("`@("`@(')E='5R
M;B!N;#)B<B@D=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!-24U%('1Y<&4@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@34E-12!T>7!E(&]F('1H:7,@<&%R="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1O('-E92!I9B!T:&4@
M9&%T82!I<R!A('9A;&ED(%)A<B!A<F-H:79E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)B1D871A("!4:&4@<F%R(&%R8VAI=F4@9&%T82X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=F%L:60L(&9A
M;'-E(&EF(&EN=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K4F%R
M1&%T82@F)&1A=&$I"B`@("!["B`@("`@("`@)&9I;&5(96%D97(@/2`B7'@U
M,EQX-C%<>#<R7'@R,5QX,6%<>#`W7'@P,"(["B`@("`@("`@:68@*'-T<G!O
M<R@D9&%T82P@)&9I;&5(96%D97(I(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!L:7-T(&]F(&9I;&5S+V1A=&$@9G)O;2!T:&4@<F%R(&%R8VAI
M=F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@(%1H92!R
M87(@87)C:&EV92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($M%63H@4&]S:71I;VX@:6X@4D%2(&%R8VAI=F4*("`@("`J("`@("`@("`@
M("`@("`@(%9!3%5%4SH@)V%T='(G("`@("TM("!&:6QE(&%T=')I8G5T97,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&4G("`@("TM("!&
M:6QE(&UO9&EF:6-A=&EO;B!T:6UE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("=C<VEZ92<@("`M+2`@0V]M<')E<W-E9"!F:6QE('-I>F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@)VUE=&AO9"<@("TM("!#;VUP
M<F5S<VEO;B!M971H;V0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M)VYA;64G("`@("TM("!&:6QE;F%M90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`G<VEZ92<@("`@+2T@($]R:6=I;F%L(&9I;&4@<VEZ90H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971287)$871A*"8D9&%T82D*("`@('L*("`@
M("`@("`D<F5T=7)N7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@)&)L;V-K
M4W1A<G0@/2!S=')P;W,H)&1A=&$L(")<>#4R7'@V,5QX-S)<>#(Q7'@Q85QX
M,#=<>#`P(BD["B`@("`@("`@)'!O<VET:6]N(#T@)&)L;V-K4W1A<G0@*R`W
M.PH*("`@("`@("!W:&EL92`H)'!O<VET:6]N(#P@<W1R;&5N*"1D871A*2D@
M>PH@("`@("`@("`@("`D:&5A9%]C<F,@("`]('-U8G-T<B@D9&%T82P@)'!O
M<VET:6]N("L@,"P@,BD["B`@("`@("`@("`@("1H96%D7W1Y<&4@(#T@;W)D
M*'-U8G-T<B@D9&%T82P@)'!O<VET:6]N("L@,BP@,2DI.PH@("`@("`@("`@
M("`D:&5A9%]F;&%G<R`]('5N<&%C:R@G=D9L86=S)RP@<W5B<W1R*"1D871A
M+"`D<&]S:71I;VX@*R`S+"`R*2D["B`@("`@("`@("`@("1H96%D7V9L86=S
M(#T@)&AE861?9FQA9W-;)T9L86=S)UT["B`@("`@("`@("`@("1H96%D7W-I
M>F4@(#T@=6YP86-K*"=V4VEZ92<L('-U8G-T<B@D9&%T82P@)'!O<VET:6]N
M("L@-2P@,BDI.PH@("`@("`@("`@("`D:&5A9%]S:7IE("`]("1H96%D7W-I
M>F5;)U-I>F4G73L*"B`@("`@("`@("`@("1P;W-I=&EO;B`K/2`W.PH@("`@
M("`@("`@("`D:&5A9%]S:7IE("T](#<["@H@("`@("`@("`@("!S=VET8V@@
M*"1H96%D7W1Y<&4I('L*"B`@("`@("`@("`@(&-A<V4@,'@W,SH*("`@("`@
M("`@("`@("`@("\J($%R8VAI=F4@:&5A9&5R("HO"B`@("`@("`@("`@("`@
M("`D<&]S:71I;VX@*ST@)&AE861?<VEZ93L*"B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@W-#H*("`@("`@("`@("`@("`@
M("1F:6QE(#T@87)R87DH*3L*"B`@("`@("`@("`@("`@("`O*B!&:6QE($AE
M861E<B`J+PH@("`@("`@("`@("`@("`@)&EN9F\@/2!U;G!A8VLH)U9086-K
M960O5E5N<&%C:V5D+T-/4R]60U)#,S(O5E1I;64O0U9E<G-I;VXO0TUE=&AO
M9"]V3&5N9W1H+W9!='1R:6(G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BDI
M.PH*("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@/2!S=6)S='(H)&1A
M=&$L("1P;W-I=&EO;B`K(#(U+"`D:6YF;ULG3&5N9W1H)UTI.PH@("`@("`@
M("`@("`@("`@)&9I;&5;)W-I>F4G72`]("1I;F9O6R=5;G!A8VME9"==.PH@
M("`@("`@("`@("`@("`@)&9I;&5;)V-S:7IE)UT@/2`D:6YF;ULG4&%C:V5D
M)UT["@H@("`@("`@("`@("`@("`@)&9I;&5;)V1A=&4G72`](&UK=&EM92@H
M*"1I;F9O6R=4:6UE)UT@/CX@,3$I("8@,'@Q9BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("@H)&EN9F];)U1I;64G72`^/B`U
M*2`F(#!X,V8I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`H*"1I;F9O6R=4:6UE)UT@/#P@,2D@)B`P>#-E*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"@D:6YF;ULG5&EM92==
M(#X^(#(Q*2`F(#!X,#<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@/CX@,38I("8@,'@Q9BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@H*"1I;F9O
M6R=4:6UE)UT@/CX@,C4I("8@,'@W9BD@*R`X,"DI.PH*("`@("`@("`@("`@
M("`@("1F:6QE6R=M971H;V0G72`]("1T:&ES+3Y?;65T:&]D<ULD:6YF;ULG
M365T:&]D)UU=.PH*("`@("`@("`@("`@("`@("1F:6QE6R=A='1R)UT@(#T@
M)R<["B`@("`@("`@("`@("`@("`D9FEL95LG871T<B==("X]("@D:6YF;ULG
M071T<FEB)UT@)B`P>#$P*2`_("=$)R`Z("<M)SL*("`@("`@("`@("`@("`@
M("1F:6QE6R=A='1R)UT@+CT@*"1I;F9O6R=!='1R:6(G72`F(#!X,C`I(#\@
M)T$G(#H@)RTG.PH@("`@("`@("`@("`@("`@)&9I;&5;)V%T='(G72`N/2`H
M)&EN9F];)T%T=')I8B==("8@,'@P,RD@/R`G4R<@.B`G+2<["B`@("`@("`@
M("`@("`@("`D9FEL95LG871T<B==("X]("@D:6YF;ULG071T<FEB)UT@)B`P
M>#`R*2`_("=()R`Z("<M)SL*("`@("`@("`@("`@("`@("1F:6QE6R=A='1R
M)UT@+CT@*"1I;F9O6R=!='1R:6(G72`F(#!X,#$I(#\@)U(G(#H@)RTG.PH*
M("`@("`@("`@("`@("`@("1R971U<FY?87)R87E;72`]("1F:6QE.PH*("`@
M("`@("`@("`@("`@("1P;W-I=&EO;B`K/2`D:&5A9%]S:7IE.PH@("`@("`@
M("`@("`@("`@)'!O<VET:6]N("L]("1I;F9O6R=086-K960G73L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@("1P;W-I=&EO;B`K/2`D:&5A9%]S:7IE.PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1A9&1?<VEZ92DI('L*("`@("`@("`@("`@("`@
M("`@("`D<&]S:71I;VX@*ST@)&%D9%]S:7IE.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O<F5P;W)T+G!H<```````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`U,#<V`#$P-#$W,S8R-S<S`#`R,C(U-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($U)345?5FEE=V5R7W)E<&]R="!C;&%S<R!I<R!A('=R87!P
M97(@=7-E9"!T;R!L;V%D('1H92!A<'!R;W!R:6%T90H@*B!-24U%7U9I97=E
M<B!F;W(@;75L=&EP87)T+W)E<&]R="!D871A("A21D,@,S0V,BDN"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F5P;W)T+G!H
M<"QV(#$N-BXQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L
M;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W)E<&]R
M="!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%-T;W)E
M<R!T:&4@34E-15]6:65W97(@;V8@=&AE('-P96-I9FEE9"!P<F]T;V-O;"X*
M("`@("`J"B`@("`@*B!`=F%R($U)345?5FEE=V5R"B`@("`@*B\*("`@('9A
M<B`D7W9I97=E<CL*"B`@("`O*BH*("`@("`J(%)E;F1E<B!T:&4@;75L=&EP
M87)T+W)E<&]R="!D871A+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!!;B!A<G)A>2!O9B!P87)A;65T97)S(&YE961E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`O*B!'970@=&AE(&%P<')O<')I871E($U)345?5FEE
M=V5R(&9O<B!T:&4@<')O=&]C;VP@<W!E8VEF:65D+B`J+PH@("`@("`@(&EF
M("@A*"1T:&ES+3Y?<F5S;VQV959I97=E<B@I*2D@>PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!296YD97(@=7-I;F<@=&AE
M(&QO861E9"!-24U%7U9I97=E<B!O8FIE8W0N("HO"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=FEE=V5R+3YR96YD97(H)'!A<F%M<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!C;VYT96YT+71Y<&4@;V8@=&AE(%9I
M97=E<B!U<V5D('1O('9I97<@=&AE('!A<G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@($$@8V]N=&5N="UT>7!E('-T<FEN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@+RH@1V5T('1H
M92!A<'!R;W!R:6%T92!-24U%7U9I97=E<B!F;W(@=&AE('!R;W1O8V]L('-P
M96-I9FEE9"X@*B\*("`@("`@("!I9B`H(2@D=&AI<RT^7W)E<V]L=F56:65W
M97(H*2DI('L*("`@("`@("`@("`@<F5T=7)N("=A<'!L:6-A=&EO;B]O8W1E
M="US=')E86TG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W9I97=E<BT^9V5T5'EP92@I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($QO860@82!-24U%7U9I97=E<B!A8V-O<F1I;F<@
M=&\@=&AE(')E<&]R="UT>7!E('!A<F%M971E<B!S=&]R960*("`@("`J(&EN
M('1H92!-24U%7U!A<G0@=&\@<F5N9&5R+B!)9B!U;G-U8V-E<W-F=6PL('1R
M>2!T;R!L;V%D(&$@9V5N97)I8PH@("`@("H@;75L=&EP87)T($U)345?5FEE
M=V5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5S;VQV959I97=E
M<B@I"B`@("!["B`@("`@("`@)'9I97=E<B`](&YU;&P["@H@("`@("`@(&EF
M("AE;7!T>2@D=&AI<RT^7W9I97=E<BDI('L*("`@("`@("`@("`@:68@*"$H
M)'1Y<&4@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT5'EP95!A<F%M
M971E<B@G<F5P;W)T+71Y<&4G*2DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'9I97=E<B`]
M("9-24U%7U9I97=E<CHZ9F%C=&]R>2@D=&AI<RT^;6EM95]P87)T+"`G;65S
M<V%G92\G("X@4W1R:6YG.CIL;W=E<B@D='EP92DI.PH@("`@("`@("`@("!I
M9B`H96UP='DH)'9I97=E<BD@?'P*("`@("`@("`@("`@("`@("A3=')I;F<Z
M.FQO=V5R*&=E=%]C;&%S<R@D=FEE=V5R*2D@/3T@)VUI;65?=FEE=V5R7V1E
M9F%U;'0G*2D@>PH@("`@("`@("`@("`@("`@:68@*"$H)'9I97=E<B`]("9-
M24U%7U9I97=E<CHZ9F%C=&]R>2@D=&AI<RT^;6EM95]P87)T+"`D=&AI<RT^
M;6EM95]P87)T+3YG9710<FEM87)Y5'EP92@I("X@)R\J)RDI*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?=FEE=V5R(#T@
M)'9I97=E<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#8U,#``,3`T,3<S-C(W-S,`,#(Q-S0R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6
M:65W97)?<F9C.#(R(&-L87-S(')E;F1E<G,@;W5T(&UE<W-A9V5S(&9R;VT@
M=&AE"B`J(&UE<W-A9V4O<F9C.#(R(&-O;G1E;G0@='EP92X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP+'8@
M,2XX+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N
M961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W)F8S@R,B!E>'1E
M;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@
M=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@86YY('!A<F%M971E
M<G,@;F5E9&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M<F5N9&5R960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P87)T(#T@)'1H:7,M
M/FUI;65?<&%R=#L*("`@("`@("`D<&%R="T^=')A;G-F97)$96-O9&5#;VYT
M96YT<R@I.PH*("`@("`@("`D=&5X="`]("1P87)T+3YG971#;VYT96YT<R@I
M.PH@("`@("`@(&EF("@A)'1E>'0I('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]-24U%+T-O;G1E;G1S+G!H<"<["B`@("`@("`@("`@("1C
M;VYT96YT<R`]("9N97<@34E-15]#;VYT96YT<RAN97<@34E-15]087)T*"DI
M.PH@("`@("`@("`@("!R971U<FX@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--
M<V<H7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("1T97AT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;F1E<B!O=70@871T86-H;65N="!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@=VET:"!A;GD@<&%R
M86UE=&5R<R!N965D960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!R96YD97)E9"!T97AT(&EN($A434PN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F1E<D%T=&%C:&UE;G1);F9O*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("1M<V<@/2`G)SL*"B`@("`@("`@+RH@1V5T('1H92!T
M97AT(&]F('1H92!P87)T+B`@4VEN8V4@=V4@;F5E9"!T;R!L;V]K(&9O<B!T
M:&4@96YD(&]F"B`@("`@("`@("H@=&AE(&AE861E<G,@8GD@<V5A<F-H:6YG
M(&9O<B!T:&4@0U),1D-23$8@<V5Q=65N8V4L('5S90H@("`@("`@("`J(&=E
M=$-A;F]N:6-A;$-O;G1E;G1S*"D@=&\@;6%K92!S=7)E('=E(&%R92!G971T
M:6YG('1H92!T97AT('=I=&@*("`@("`@("`@*B!#4DQ&)W,N("HO"B`@("`@
M("`@)'1E>'0@/2`D=&AI<RT^;6EM95]P87)T+3YG971#86YO;FEC86Q#;VYT
M96YT<R@I.PH*("`@("`@("`O*B!396%R8V@@9F]R('1H92!E;F0@;V8@=&AE
M(&AE861E<B!T97AT("A#4DQ&0U),1BDN("HO"B`@("`@("`@)'1E>'0@/2!S
M=6)S='(H)'1E>'0L(#`L('-T<G!O<R@D=&5X="P@(EQR7&Y<<EQN(BDI.PH*
M("`@("`@("`O*B!'970@=&AE(&QI<W0@;V8@:&5A9&5R<R!N;W<N("HO"B`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C='5R92YP:'`G
M.PH@("`@("`@("1H96%D97)S(#T@34E-15]3=')U8W1U<F4Z.G!A<G-E34E-
M14AE861E<G,H)'1E>'0L('1R=64L('1R=64I.PH*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@("`D8V]N
M=&5N=',@/2`F;F5W($U)345?0V]N=&5N=',H;F5W($U)345?4&%R="@I*3L*
M("`@("`@("`D;7-G(#T@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--<V<H7R@B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB*2P@2&]R9&4Z.FEM9R@G:6YF;U]I8V]N+G!N
M9R<L(%\H(DEN9F\B*2P@)VAE:6=H=#TB,38B('=I9'1H/2(Q-B(G+"`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI+"!F86QS
M92D["@H@("`@("`@("1M<V<@+CT@)SQS<&%N(&-L87-S/2)F:7AE9"(^)SL*
M"B`@("`@("`@)&AE861E<E]A<G)A>2`](&%R<F%Y*`H@("`@("`@("`@("`G
M9&%T92<@/3X@7R@B1&%T92(I+`H@("`@("`@("`@("`G<W5B:F5C="<@/3X@
M7R@B4W5B:F5C="(I+`H@("`@("`@("`@("`G9G)O;2<@/3X@7R@B1G)O;2(I
M+`H@("`@("`@("`@("`G=&\G(#T^(%\H(E1O(BD*("`@("`@("`I.PH@("`@
M("`@("1H96%D97)?;W5T<'5T(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C
M:"`H)&AE861E<E]A<G)A>2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1H96%D97)S6R1K97E=*2D@>PH@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1H96%D97)S6R1K97E=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1H96%D97)S6R1K97E=(#T@)&AE861E<G-;)&ME>5U;,%T[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:&5A9&5R7V]U
M='!U=%M=(#T@)SQS=')O;F<^)R`N("1V86P@+B`G.CPO<W1R;VYG/B`G("X@
M)&AE861E<G-;)&ME>5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@
M("`@("`D;7-G("X](&EM<&QO9&4H(CQB<B`O/EQN(BP@5&5X=%]&:6QT97(Z
M.F9I;'1E<B@D:&5A9&5R7V]U='!U="P@)V5M86EL<R<I*2`N("<\+W-P86X^
M)SL*"B`@("`@("`@<F5T=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&9O<B!T:&4@<F5N9&5R
M960@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O
M;G1E;G0@='EP92!O9B!T:&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+W!L86EN.R!C
M:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O<FEC:'1E>'0N<&AP````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$U-#,W`#$P-#$W,S8R-S<S`#`R,C4W-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?
M5FEE=V5R7W)I8VAT97AT(&-L87-S(')E;F1E<G,@;W5T($A434P@=&5X="!F
M<F]M('1E>'0O<FEC:'1E>'0*("H@8V]N=&5N="!T86=S+"`H4D9#(#$X.38@
M6S<N,2XS72DN"B`J"B`J($$@;6EN:6UA;"!R:6-H=&5X="!I;7!L96UE;G1A
M=&EO;B!I<R!O;F4@=&AA="!S:6UP;'D@8V]N=F5R=',@(CQL=#XB('1O"B`J
M("(\(BP@8V]N=F5R=',@0U),1G,@=&\@4U!!0T4L(&-O;G9E<G1S(#QN;#X@
M=&\@82!N97=L:6YE(&%C8V]R9&EN9R!T;PH@*B!L;V-A;"!N97=L:6YE(&-O
M;G9E;G1I;VXL(')E;6]V97,@979E<GET:&EN9R!B971W965N(&$@/&-O;6UE
M;G0^(&-O;6UA;F0*("H@86YD('1H92!N97AT(&)A;&%N8VEN9R`\+V-O;6UE
M;G0^(&-O;6UA;F0L(&%N9"!R96UO=F5S(&%L;"!O=&AE<@H@*B!O=&AE<B!F
M;W)M871T:6YG(&-O;6UA;F1S("AA;&P@=&5X="!E;F-L;W-E9"!I;B!A;F=L
M92!B<F%C:V5T<RDN"B`J"B`J(%=E(&EM<&QE;65N="!T:&4@9F]L;&]W:6YG
M('1A9W,Z"B`J(#QB;VQD/BP@/&ET86QI8SXL(#QF:7AE9#XL(#QS;6%L;&5R
M/BP@/&)I9V=E<CXL(#QU;F1E<FQI;F4^+"`\8V5N=&5R/BP*("H@/&9L=7-H
M;&5F=#XL(#QF;'5S:')I9VAT/BP@/&EN9&5N=#XL(#QS=6)S8W)I<'0^+"`\
M97AC97)P=#XL(#QP87)A9W)A<&@^+`H@*B`\<VEG;F%T=7)E/BP@/&-O;6UE
M;G0^+"`\;F\M;W`^+"`\;'0^+"`\;FP^"B`J"B`J(%1H92!F;VQL;W=I;F<@
M=&%G<R!A<F4@:6UP;&5M96YT960@9&EF9F5R96YT;'D@=&AA;B!D97-C<FEB
M960@:6X@=&AE(%)&0PH@*B`H9'5E('1O(&QI;6ET871I;VYS(&EN($A434P@
M;W5T<'5T*3H*("H@/&AE861I;F<^("T@3W5T<'5T(&%S(&-E;G1E<F5D+"!B
M;VQD('1E>'0N"B`J(#QF;V]T:6YG/B`M($]U='!U="!A<R!C96YT97)E9"P@
M8F]L9"!T97AT+@H@*B`\;G`^("`@("`@+2!/=71P=70@87,@<&%R86=R87!H
M(&)R96%K+@H@*@H@*B!4:&4@9F]L;&]W:6YG('1A9W,@87)E($Y/5"!I;7!L
M96UE;G1E9#H*("H@/&EN9&5N=')I9VAT/BP@/&]U=&1E;G0^+"`\;W5T9&5N
M=')I9VAT/BP@/'-A;65P86=E/BP@/&ES;RTX.#4Y+5@^+`H@*B`\=7,M87-C
M:6D^+`H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)I8VAT97AT+G!H<"QV(#$N-"XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!3
M;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?
M5FEE=V5R7W)I8VAT97AT(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J
M*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N=&QY('-E="!C;VYT96YT
M<R!I;B!(5$U,(&9O<FUA="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O
M;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"@D=&5X="`]("1T:&ES+3YM
M:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H=')I
M;2@D=&5X="D@/3T@)R<I('L*("`@("`@("`@("`@<F5T=7)N("1T97AT.PH@
M("`@("`@('T*"B`@("`@("`@+RH@57-E('-T<E]I<F5P;&%C92@I(&EF('5S
M:6YG(%!(4"`U+C`K+B`J+PH@("`@("`@("1H87-?<W1R7VER97!L86-E(#T@
M9G5N8W1I;VY?97AI<W1S*"=S=')?:7)E<&QA8V4G*3L*"B`@("`@("`@+RH@
M5V4@861D('-P86-E(&%T('1H92!B96=I;FYI;F<@86YD(&5N9"!O9B!T:&4@
M<W1R:6YG(&%S(&ET('=I;&P*("`@("`@("`@*B!M86ME('-O;64@<F5G=6QA
M<B!E>'!R97-S:6]N(&-H96-K<R!L871E<B!M=6-H(&5A<VEE<B`H<V\@=V4*
M("`@("`@("`@*B!D;VXG="!H879E('1O('=O<G)Y(&%B;W5T('-T87)T+V5N
M9"!O9B!L:6YE(&-H87)A8W1E<G,I+B`J+PH@("`@("`@("1T97AT(#T@)R`G
M("X@)'1E>'0@+B`G("<["@H@("`@("`@("\J(%)E;6]V92!E=F5R>71H:6YG
M(&)E='=E96X@/&-O;6UE;G0^('1A9W,N("HO"B`@("`@("`@)'1E>'0@/2!P
M<F5G7W)E<&QA8V4H)R\\8V]M;65N="XJ/BXJ/%PO8V]M;65N=#XO56ES)RP@
M)R<L("1T97AT*3L*"B`@("`@("`@+RH@4F5M;W9E(&%N>2!U;G)E8V]G;FEZ
M960@=&%G<R!I;B!T:&4@=&5X="X@(%=E(&1O;B=T(&YE960@/&YO+6]P/@H@
M("`@("`@("`J(&EN("1T86=S('-I;F-E(&ET(&1O97-N)W0@9&\@86YY=&AI
M;F<@86YY=V%Y+B`@06QL(#QC;VUM96YT/B!T86=S"B`@("`@("`@("H@:&%V
M92!A;')E861Y(&)E96X@<F5M;W9E9"X@*B\*("`@("`@("`D=&%G<R`]("<\
M8F]L9#X\:71A;&EC/CQF:7AE9#X\<VUA;&QE<CX\8FEG9V5R/CQU;F1E<FQI
M;F4^/&-E;G1E<CX\9FQU<VAL969T/CQF;'5S:')I9VAT/CQI;F1E;G0^/'-U
M8G-C<FEP=#X\97AC97)P=#X\<&%R86=R87!H/CQS:6=N871U<F4^/&QT/CQN
M;#XG.PH@("`@("`@("1T97AT(#T@<W1R:7!?=&%G<R@D=&5X="P@)'1A9W,I
M.PH*("`@("`@("`O*B`\;'0^(&)E8V]M97,@82`G/"<N($-23$8@8F5C;VUE
M<R!A(%-004-%+B`J+PH@("`@("`@(&EF("@D:&%S7W-T<E]I<F5P;&%C92D@
M>PH@("`@("`@("`@("`D=&5X="`]('-T<E]I<F5P;&%C92AA<G)A>2@G/&QT
M/B<L(")<<EQN(BDL(&%R<F%Y*"<F;'0[)RP@)R`G*2P@)'1E>'0I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E
M*&%R<F%Y*"<O/&QT/B]I)RP@(B]<<EQN+R(I+"!A<G)A>2@G)FQT.R<L("<@
M)RDL("1T97AT*3L*("`@("`@("!]"@H@("`@("`@("\J(%=E('1R>2!T;R!P
M<F]T96-T(&%G86EN<W0@8F%D('-T=69F(&AE<F4N("HO"B`@("`@("`@)'1E
M>'0@/2!`:'1M;'-P96-I86QC:&%R<R@D=&5X="P@14Y47U%53U1%4RP@)'1H
M:7,M/FUI;65?<&%R="T^9V5T0VAA<G-E="@I*3L*"B`@("`@("`@+RH@/&YL
M/B!B96-O;65S(&$@;F5W;&EN92`H/&)R("\^*3L*("`@("`@("`@*B`\;G`^
M(&)E8V]M97,@82!P87)A9W)A<&@@8G)E86L@*#QP("\^*2X@*B\*("`@("`@
M("!I9B`H)&AA<U]S=')?:7)E<&QA8V4I('L*("`@("`@("`@("`@)'1E>'0@
M/2!S=')?:7)E<&QA8V4H87)R87DH)R9L=#MN;"9G=#LG+"`G)FQT.VYP)F=T
M.R<I+"!A<G)A>2@G/&)R("\^)RP@)SQP("\^)RDL("1T97AT*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92AA
M<G)A>2@G+R@_/"$F;'0[*29L=#MN;"XJ)F=T.R]5:7,G+"`G+R@_/"$F;'0[
M*29L=#MN<"XJ)F=T.R]5:7,G*2P@87)R87DH)SQB<B`O/B<L("<\<"`O/B<I
M+"`D=&5X="D["B`@("`@("`@?0H*("`@("`@("`O*B!.;W<@8V]N=F5R="!T
M:&4@:VYO=VX@=&%G<R!T;R!H=&UL+B!4<GD@=&\@<F5M;W9E(&%N>2!T86<*
M("`@("`@("`@*B!P87)A;65T97)S('1O('-T;W`@<&5O<&QE(&9R;VT@=')Y
M:6YG('1O('!U;&P@82!F87-T(&]N92X@*B\*("`@("`@("`D=&5X="`]('!R
M96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MB;VQD+BHF9W0[*"XJ*29L=#M<
M+V)O;&0F9W0[+U5I<R<L("<\<W!A;B!S='EL93TB9F]N="UW96EG:'0Z(&)O
M;&0B/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#MI=&%L:6,N*B9G=#LH+BHI)FQT.UPO
M:71A;&EC)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M<W1Y;&4Z(&ET
M86QI8R(^7#$\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E
M9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9I>&5D+BHF9W0[*"XJ*29L=#M<
M+V9I>&5D)F=T.R]5:7,G+"`G/&9O;G0@9F%C93TB9FEX960B/EPQ/"]F;VYT
M/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_
M/"$F;'0[*29L=#MS;6%L;&5R+BHF9W0[+U5I<R<L("<\<W!A;B!S='EL93TB
M9F]N="US:7IE.B!S;6%L;&5R(CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@
M/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[7"]S;6%L;&5R)F=T.R]5
M:7,G+"`G/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#MB:6=G97(N*B9G=#LO56ES)RP@)SQS
M<&%N('-T>6QE/2)F;VYT+7-I>F4Z(&QA<F=E<B(^)RP@)'1E>'0I.PH@("`@
M("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.UPO8FEG
M9V5R)F=T.R]5:7,G+"`G/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X
M="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MU;F1E<FQI;F4N*B9G
M=#LH+BHI)FQT.UPO=6YD97)L:6YE)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4]
M(G1E>'0M9&5C;W)A=&EO;CH@=6YD97)L:6YE(CY<,3PO<W!A;CXG+"`D=&5X
M="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF
M;'0[8V5N=&5R+BHF9W0[*"XJ*29L=#M<+V-E;G1E<B9G=#LO56ES)RP@)SQD
M:78@86QI9VX](F-E;G1E<B(^7#$\+V1I=CXG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[9FQU<VAL969T
M+BHF9W0[*"XJ*29L=#M<+V9L=7-H;&5F="9G=#LO56ES)RP@)SQD:78@86QI
M9VX](FQE9G0B/EPQ/"]D:78^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@
M<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9L=7-H<FEG:'0N*B9G=#LH
M+BHI)FQT.UPO9FQU<VAR:6=H="9G=#LO56ES)RP@)SQD:78@86QI9VX](G)I
M9VAT(CY<,3PO9&EV/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#MI;F1E;G0N*B9G=#LH+BHI)FQT.UPO
M:6YD96YT)F=T.R]5:7,G+"`G/&)L;V-K<75O=&4^7#$\+V)L;V-K<75O=&4^
M)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\
M(29L=#LI)FQT.V5X8V5R<'0N*B9G=#LH+BHI)FQT.UPO97AC97)P="9G=#LO
M56ES)RP@)SQC:71E/EPQ/"]C:71E/B<L("1T97AT*3L*("`@("`@("`D=&5X
M="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MS=6)S8W)I<'0N*B9G
M=#LH+BHI)FQT.UPO<W5B<V-R:7!T)F=T.R]5:7,G+"`G/'-U8CY<,3PO<W5B
M/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_
M/"$F;'0[*29L=#MS=7!E<G-C<FEP="XJ)F=T.R@N*BDF;'0[7"]S=7!E<G-C
M<FEP="9G=#LO56ES)RP@)SQS=7`^7#$\+W-U<#XG+"`D=&5X="D["B`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[:&5A9&EN
M9RXJ)F=T.R@N*BDF;'0[7"]H96%D:6YG)F=T.R]5:7,G+"`G/&)R("\^/&1I
M=B!A;&EG;CTB8V5N=&5R(B!S='EL93TB9F]N="UW96EG:'0Z(&)O;&0B/EPQ
M/"]D:78^/&)R("\^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R
M97!L86-E*"<O*#\\(29L=#LI)FQT.V9O;W1I;F<N*B9G=#LH+BHI)FQT.UPO
M9F]O=&EN9R9G=#LO56ES)RP@)SQB<B`O/CQD:78@86QI9VX](F-E;G1E<B(@
M<W1Y;&4](F9O;G0M=V5I9VAT.B!B;VQD(CY<,3PO9&EV/CQB<B`O/B<L("1T
M97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[
M*29L=#MP87)A9W)A<&@N*B9G=#LH+BHI)FQT.UPO<&%R86=R87!H)F=T.R]5
M:7,G+"`G/'`^7#$\+W`^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E
M9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.W-I9VYA='5R92XJ)F=T.R@N*BDF
M;'0[7"]S:6=N871U<F4F9W0[+U5I<R<L("<\861D<F5S<SY<,3PO861D<F5S
M<SXG+"`D=&5X="D["@H@("`@("`@("\J($YO=R!W92!R96UO=F4@=&AE(&QE
M861I;F<O=')A:6QI;F<@<W!A8V4@=V4@861D960@870@=&AE('-T87)T+B`J
M+PH@("`@("`@("1T97AT(#T@<W5B<W1R*"1T97AT+"`Q+"`M,2D["@H@("`@
M("`@("\J(%=O<F1W<F%P+B`J+PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA
M8V4H(EQT(BP@)R`@("`@("`@)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@
M<W1R7W)E<&QA8V4H)R`@)RP@)R`F;F)S<#LG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!S=')?<F5P;&%C92@B7&X@(BP@(EQN)FYB<W`[(BP@)'1E>'0I
M.PH@("`@("`@(&EF("@D=&5X=%LP72`]/2`G("<I('L*("`@("`@("`@("`@
M)'1E>'0@/2`G)FYB<W`[)R`N('-U8G-T<B@D=&5X="P@,2D["B`@("`@("`@
M?0H@("`@("`@("1T97AT(#T@;FPR8G(H)'1E>'0I.PH@("`@("`@("1T97AT
M(#T@)SQP(&-L87-S/2)F:7AE9"(^)R`N("1T97AT("X@)SPO<#XG.PH*("`@
M("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT
M96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N
M="!T>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R
M<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H
M<```````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#0U`#$P-#$W,S8R
M-S<S`#`R,34S-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W)P;2!C;&%S
M<R!R96YD97)S(&]U="!L:7-T<R!O9B!F:6QE<R!I;B!24$T*("H@<&%C:V%G
M97,@8GD@=7-I;F<@=&AE(')P;2!T;V]L('1O('%U97)Y('1H92!P86-K86=E
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P
M;2YP:'`L=B`Q+C$R+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D
M>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R
M"B`J+PIC;&%S<R!-24U%7U9I97=E<E]R<&T@97AT96YD<R!-24U%7U9I97=E
M<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!24$T@8V]N=&5N
M=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P
M87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV97)S.PH*("`@("`@("`O*B!#
M:&5C:R!T;R!M86ME('-U<F4@=&AE('!R;V=R86T@86-T=6%L;'D@97AI<W1S
M+B`J+PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG<G!M)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E
M='5R;B`G/'!R93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O
M('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)P;2==6R=L
M;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@)&1A
M=&$@/2`G)SL*("`@("`@("`D=&UP7W)P;2`]($AO<F1E.CIG971496UP1FEL
M92@G:&]R9&5?<G!M)RD["@H@("`@("`@("1F:"`](&9O<&5N*"1T;7!?<G!M
M+"`G=R<I.PH@("`@("`@(&9W<FET92@D9F@L("1T:&ES+3YM:6UE7W!A<G0M
M/F=E=$-O;G1E;G1S*"DI.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@
M("`D9F@@/2!P;W!E;B@D;6EM95]D<FEV97)S6R=H;W)D92==6R=R<&TG75LG
M;&]C871I;VXG72`N("(@+7%I<"`D=&UP7W)P;2`R/B8Q(BP@)W(G*3L*("`@
M("`@("!W:&EL92`H*"1R8R`](&9G971S*"1F:"P@.#$Y,BDI*2!["B`@("`@
M("`@("`@("1D871A("X]("1R8SL*("`@("`@("!]"B`@("`@("`@<&-L;W-E
M*"1F:"D["@H@("`@("`@(')E='5R;B`G/'!R93XG("X@:'1M;&5N=&ET:65S
M*"1D871A*2`N("<\+W!R93XG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N
M=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E
M;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA
M<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W-E8W5R:71Y+G!H
M<``````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-34Q-``Q,#0Q-S,V,C<W,P`P
M,C(V,#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]S96-U<FET>2!C;&%S
M<R!I<R!A('=R87!P97(@=7-E9"!T;R!L;V%D('1H92!A<'!R;W!R:6%T90H@
M*B!-24U%7U9I97=E<B!F;W(@<V5C=7)E(&UU;'1I<&%R="!M97-S86=E<R`H
M9&5F:6YE9"!B>2!21D,@,3@T-RDN(%1H:7,*("H@8VQA<W,@:&%N9&QE<R!M
M=6QT:7!A<G0O<VEG;F5D(&%N9"!M=6QT:7!A<G0O96YC<GEP=&5D(&1A=&$N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<V5C
M=7)I='DN<&AP+'8@,2XV+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W
M97)?<V5C=7)I='D@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@
M("`@*B!3=&]R97,@=&AE($U)345?5FEE=V5R(&]F('1H92!S<&5C:69I960@
M<V5C=7)I='D@<')O=&]C;VPN"B`@("`@*@H@("`@("H@0'9A<B!-24U%7U9I
M97=E<@H@("`@("HO"B`@("!V87(@)%]V:65W97(["@H@("`@+RHJ"B`@("`@
M*B!4:&4@)&UI;65?<&%R="!C;&%S<R!V87)I86)L92!H87,@=&AE(&EN9F]R
M;6%T:6]N('1O(')E;F1E<@H@("`@("H@;W5T+"!E;F-A<'-U;&%T960@:6X@
M82!-24U%7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2`D<&%R
M86US(&UI>&5D("!4:&4@<&%R86UE=&5R<R`H:68@86YY*2!T;R!P87-S('1O
M('1H92!U;F1E<FQY:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M34E-15]6:65W97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%)E
M;F1E<FEN9R!O9B!T:&4@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J($=E
M="!T:&4@87!P<F]P<FEA=&4@34E-15]6:65W97(@9F]R('1H92!P<F]T;V-O
M;"!S<&5C:69I960N("HO"B`@("`@("`@:68@*"$H)'1H:7,M/E]R97-O;'9E
M5FEE=V5R*"DI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@
M("`@("`@("\J(%)E;F1E<B!U<VEN9R!T:&4@;&]A9&5D($U)345?5FEE=V5R
M(&]B:F5C="X@*B\*("`@("`@("!R971U<FX@)'1H:7,M/E]V:65W97(M/G)E
M;F1E<B@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&-O;G1E;G0M='EP92!O9B!T:&4@5FEE=V5R('5S960@=&\@=FEE=R!T
M:&4@<&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!C;VYT
M96YT+71Y<&4@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E
M*"D*("`@('L*("`@("`@("`O*B!'970@=&AE(&%P<')O<')I871E($U)345?
M5FEE=V5R(&9O<B!T:&4@<')O=&]C;VP@<W!E8VEF:65D+B`J+PH@("`@("`@
M(&EF("@A*"1T:&ES+3Y?<F5S;VQV959I97=E<B@I*2D@>PH@("`@("`@("`@
M("!R971U<FX@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=FEE=V5R+3YG
M9714>7!E*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]A
M9"!A($U)345?5FEE=V5R(&%C8V]R9&EN9R!T;R!T:&4@<')O=&]C;VP@<&%R
M86UE=&5R('-T;W)E9`H@("`@("H@:6X@=&AE($U)345?4&%R="!T;R!R96YD
M97(N($EF('5N<W5C8V5S<V9U;"P@=')Y('1O(&QO860@82!G96YE<FEC"B`@
M("`@*B!M=6QT:7!A<G0@34E-15]6:65W97(N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]R97-O;'9E5FEE=V5R*"D*("`@('L*("`@("`@("`D=FEE
M=V5R(#T@;G5L;#L*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=FEE=V5R
M*2D@>PH@("`@("`@("`@("`D<')O=&]C;VP@/2`D=&AI<RT^;6EM95]P87)T
M+3YG971#;VYT96YT5'EP95!A<F%M971E<B@G<')O=&]C;VPG*3L*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1P<F]T;V-O;"DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=FEE
M=V5R(#T@)DU)345?5FEE=V5R.CIF86-T;W)Y*"1T:&ES+3YM:6UE7W!A<G0L
M("1P<F]T;V-O;"D["B`@("`@("`@("`@(&EF("AE;7!T>2@D=FEE=V5R*2!\
M?`H@("`@("`@("`@("`@("`@*%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1V
M:65W97(I*2`]/2`G;6EM95]V:65W97)?9&5F875L="<I*2!["B`@("`@("`@
M("`@("`@("`D=FEE=V5R(#T@)DU)345?5FEE=V5R.CIF86-T;W)Y*"1T:&ES
M+3YM:6UE7W!A<G0L("1T:&ES+3YM:6UE7W!A<G0M/F=E=%!R:6UA<GE4>7!E
M*"D@+B`G+RHG*3L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=FEE=V5R
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M7W9I97=E<B`]("1V:65W97(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O<VEM<&QE+G!H<```````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,S4W`#$P-#$W,S8R-S<S`#`R,C(S,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($U)345?5FEE=V5R7W-I;7!L92!C;&%S<R!R96YD97)S(&]U="!P;&%I
M;B!T97AT('=I=&AO=70@86YY"B`J(&UO9&EF:6-A=&EO;G,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<VEM<&QE+G!H<"QV
M(#$N,2XV+C4@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S
M<R!-24U%7U9I97=E<E]S:6UP;&4@97AT96YD<R!-24U%7U9I97=E<B!["@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@='EP92!O9B!T:&4@<F5N
M9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M34E-12UT>7!E(&]F('1H92!O=71P=70@8V]N=&5N="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT
M+W!L86EN)SL*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O<V]U<F-E+G!H<```````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-#0W`#$P-#$W,S8R-S<S`#`R,C(T,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($U)345?5FEE=V5R7W-O=7)C92!C;&%S<R!I<R!A(&-L87-S
M(&9O<B!A;GD@=FEE=V5R('1H870@=V%N=',*("H@=&\@<')O=FED92!L:6YE
M(&YU;6)E<G,@=&\@97AT96YD+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W-O=7)C92YP:'`L=B`Q+CDN,3`N.2`R,#`V+S`Q
M+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(
M;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?<V]U<F-E
M(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@061D(&QI
M;F4@;G5M8F5R<R!T;R!A(&)L;V-K(&]F(&-O9&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V]D92`@5&AE(&-O9&4@=&\@;G5M8F5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L:6YE3G5M8F5R*"1C;V1E+"`D;&EN96)R96%K
M(#T@(EQN(BD*("`@('L*("`@("`@("`D;&EN97,@/2!S=6)S=')?8V]U;G0H
M)&-O9&4L("1L:6YE8G)E86LI("L@,3L*("`@("`@("`D:'1M;"`]("<\=&%B
M;&4@8VQA<W,](FQI;F5.=6UB97)E9"(@8V5L;'-P86-I;F<](C`B/CQT<CX\
M=&@^)SL*("`@("`@("!F;W(@*"1L(#T@,3L@)&P@/#T@)&QI;F5S.R`D;"LK
M*2!["B`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQA(&ED/2)L)7,B
M(&AR968](B-L)7,B/B5S/"]A/CQB<B`O/B<L("1L+"`D;"P@)&PI("X@(EQN
M(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO=&@^/'1D
M/B<@+B`D8V]D92`N("<\+W1D/CPO='(^/"]T86)L93XG.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T
M:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@
M)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]S<F-H:6=H;&ET92YP:'``````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8U-C(`
M,3`T,3<S-C(W-S,`,#(S,C4Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+W-O=7)C92YP:'`G.PH*+RHJ"B`J(%1H92!-24U%7U9I
M97=E<E]S<F-H:6=H;&ET92!C;&%S<R!R96YD97)S(&]U="!V87)I;W5S(&-O
M;G1E;G0@:6X@2%1-3`H@*B!F;W)M870@8GD@=7-I;F<@4V]U<F-E+6AI9VAL
M:6=H="X*("H*("H@4V]U<F-E+6AI9VAL:6=H=#H@:'1T<#HO+W=W=RYG;G4N
M;W)G+W-O9G1W87)E+W-R8RUH:6=H;&ET92\*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`L=B`Q+C$T
M+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC
M;&%S<R!-24U%7U9I97=E<E]S<F-H:6=H;&ET92!E>'1E;F1S($U)345?5FEE
M=V5R7W-O=7)C92!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C
M=7)R96YT;'D@<V5T(&-O;G1E;G1S('5S:6YG(%-O=7)C92UH:6=H;&EG:'0*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M
M971E<G,@=&AE('9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J($-H96-K
M('1O(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES=',N("HO
M"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S6R=H;W)D
M92==6R=S<F-H:6=H;&ET92==6R=L;V-A=&EO;B==*2D@>PH@("`@("`@("`@
M("!R971U<FX@)SQP<F4^)R`N('-P<FEN=&8H7R@B5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+B(I+"`D;6EM95]D<FEV97)S6R=H;W)D92==6R=S<F-H
M:6=H;&ET92==6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0W)E871E('1E;7!O<F%R>2!F:6QE<R!F;W(@5V5B8W!P
M+B`J+PH@("`@("`@("1T;7!I;B`@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)U-R
M8TEN)RD["B`@("`@("`@)'1M<&]U="`]($AO<F1E.CIG971496UP1FEL92@G
M4W)C3W5T)RP@9F%L<V4I.PH*("`@("`@("`O*B!7<FET92!T:&4@8V]N=&5N
M=',@;V8@;W5R(&)U9F9E<B!T;R!T:&4@=&5M<&]R87)Y(&EN<'5T(&9I;&4N
M("HO"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T
M0V]N=&5N=',H*3L*("`@("`@("`D9F@@/2!F;W!E;B@D=&UP:6XL("=W8B<I
M.PH@("`@("`@(&9W<FET92@D9F@L("1C;VYT96YT<RP@<W1R;&5N*"1C;VYT
M96YT<RDI.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`O*B!$971E
M<FUI;F4@=&AE(&QA;F=U86=E(&9R;VT@=&AE(&UI;64@='EP92X@*B\*("`@
M("`@("`D;&%N9R`]("<G.PH@("`@("`@('-W:71C:"`H)'1H:7,M/FUI;65?
M<&%R="T^9V5T5'EP92@I*2!["B`@("`@("`@8V%S92`G=&5X="]X+6IA=F$G
M.@H@("`@("`@("`@("`D;&%N9R`]("=J879A)SL*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@)W1E>'0O>"UC<W)C)SH*("`@("`@("!C87-E
M("=T97AT+W@M8RLK<W)C)SH*("`@("`@("!C87-E("=T97AT+V-P<"<Z"B`@
M("`@("`@("`@("1L86YG(#T@)V-P<"<["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]X+7!E<FPG.@H@("`@("`@("`@
M("`D;&%N9R`]("=P97)L)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)V%P<&QI8V%T:6]N+W@M<&AP)SH*("`@("`@("!C87-E("=X+65X
M=&5N<VEO;B]P:'!S)SH*("`@("`@("!C87-E("=X+65X=&5N<VEO;B]P:'`S
M<R<Z"B`@("`@("`@8V%S92`G87!P;&EC871I;VXO>"UH='1P9"UP:'`G.@H@
M("`@("`@(&-A<V4@)V%P<&QI8V%T:6]N+W@M:'1T<&0M<&AP,R<Z"B`@("`@
M("`@8V%S92`G87!P;&EC871I;VXO>"UH='1P9"UP:'!S)SH*("`@("`@("`@
M("`@)&QA;F<@/2`G<&AP,R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=A<'!L:6-A=&EO;B]X+7!Y=&AO;B<Z"B`@("`@("`@("`@("1L
M86YG(#T@)W!Y=&AO;B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@+R\@)&QA;F<@/2`G<')O;&]G)SL*("`@("`@("`@("`@+R\@8G)E86L[
M"@H@("`@("`@("`@("`O+R`D;&%N9R`]("=F;&5X)SL*("`@("`@("`@("`@
M+R\@8G)E86L["@H@("`@("`@("`@("`O+R`D;&%N9R`]("=C:&%N9V5L;V<G
M.PH@("`@("`@("`@("`O+R!B<F5A:SL*"B`@("`@("`@("`@("\O("1L86YG
M(#T@)W)U8GDG.PH@("`@("`@("`@("`O+R!B<F5A:SL*("`@("`@("!]"@H@
M("`@("`@("\J($5X96-U=&4@4V]U<F-E+4AI9VAL:71E+B`J+PH@("`@("`@
M(&5X96,H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<W)C:&EG:&QI=&4G75LG
M;&]C871I;VXG72`N("(@+2US<F,M;&%N9R`D;&%N9R`M+6]U="UF;W)M870@
M>&AT;6P@+2UI;G!U="`D=&UP:6X@+2UO=71P=70@)'1M<&]U="(I.PH@("`@
M("`@("1R97-U;'1S(#T@9FEL95]G971?8V]N=&5N=',H)'1M<&]U="D["B`@
M("`@("`@=6YL:6YK*"1T;7!O=70I.PH*("`@("`@("`O*B!%9'5C871E9"!'
M=65S<R!A="!W:&5T:&5R('=E(&%R92!I;FQI;F4@;W(@;F]T+B`J+PH@("`@
M("`@(&EF("AH96%D97)S7W-E;G0H*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/FQI;F5.=6UB97(H)')E<W5L=',I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!5=&EL.CIB=69F97)/=71P=70H)W)E<75I
M<F4G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G
M:&]R9&4G*2`N("<O8V]M;6]N+6AE861E<BYI;F,G*2`N"B`@("`@("`@("`@
M("`@("`D=&AI<RT^;&EN94YU;6)E<B@D<F5S=6QT<RD@+@H@("`@("`@("`@
M("`@("`@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O
M;6UO;BUF;V]T97(N:6YC)RD["B`@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<```````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-#4V
M`#$P-#$W,S8R-S<S`#`R,34T-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R
M7W1G>B!C;&%S<R!R96YD97)S(&]U="!P;&%I;B!O<B!G>FEP<&5D('1A<F)A
M;&QS(&EN($A434PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<"QV(#$N,S<N,3`N,3,@,C`P-B\P,2\R-B`Q,#HR
M,CHT-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL
M($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA
M=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`875T:&]R("!-:6-H865L
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@
M("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO
M"F-L87-S($U)345?5FEE=V5R7W1G>B!E>'1E;F1S($U)345?5FEE=V5R('L*
M"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@
M=&%R(&9I;&4@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C
M;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M0V]M<')E<W,N<&AP)SL*"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/FUI
M;65?<&%R="T^9V5T0V]N=&5N=',H*3L*"B`@("`@("`@+RH@3VYL>2!D96-O
M;7!R97-S(&=Z:7!P960@9FEL97,N("HO"B`@("`@("`@)'-U8G1Y<&4@/2`D
M=&AI<RT^;6EM95]P87)T+3YG9713=6)4>7!E*"D["B`@("`@("`@:68@*"@D
M<W5B='EP92`]/2`G>"UC;VUP<F5S<V5D+71A<B<I('Q\"B`@("`@("`@("`@
M("@D<W5B='EP92`]/2`G=&=Z)RD@?'P*("`@("`@("`@("`@*"1S=6)T>7!E
M(#T]("=X+71G>B<I('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G9WII
M<"<I('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G>"UG>FEP)RD@?'P*
M("`@("`@("`@("`@*"1S=6)T>7!E(#T]("=X+6=Z:7`M8V]M<')E<W-E9"<I
M('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G>"UG=&%R)RDI('L*("`@
M("`@("`@("`@)&=Z:7`@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L971O;B@G
M9WII<"<I.PH@("`@("`@("`@("`D8V]N=&5N=',@/2`D9WII<"T^9&5C;VUP
M<F5S<R@D8V]N=&5N=',I.PH@("`@("`@("`@("!I9B`H96UP='DH)&-O;G1E
M;G1S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!?*")5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(BD@+B`G/"]P<F4^
M)SL*("`@("`@("`@("`@?2!E;'-E:68@*&ES7V$H)&-O;G1E;G1S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N
M("1C;VYT96YT<RT^9V5T365S<V%G92@I("X@)SPO<')E/B<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D<W5B='EP92`]/2`G9WII
M<"<@?'P*("`@("`@("`@("`@)'-U8G1Y<&4@/3T@)W@M9WII<"<@?'P*("`@
M("`@("`@("`@)'-U8G1Y<&4@/3T@)W@M9WII<"UC;VUP<F5S<V5D)RD@>PH@
M("`@("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O34E-12]-86=I8RYP:'`G.PH@("`@("`@("`@("`D;6EM
M95]T>7!E(#T@34E-15]-86=I8SHZ86YA;'EZ941A=&$H)&-O;G1E;G1S+"!I
M<W-E="@D8V]N9ELG;6EM92==6R=M86=I8U]D8B==*2`_("1C;VYF6R=M:6UE
M)UU;)VUA9VEC7V1B)UT@.B!N=6QL*3L*("`@("`@("`@("`@:68@*"$D;6EM
M95]T>7!E*2!["B`@("`@("`@("`@("`@("`D;6EM95]T>7!E(#T@7R@B56YK
M;F]W;B(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`G/'!R
M93XG("X@7R@B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(BD@
M+B`D;6EM95]T>7!E("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`O
M*B!/8G1A:6X@=&AE(&QI<W0@;V8@9FEL97,O9&%T82!I;B!T:&4@=&%R(&9I
M;&4N("HO"B`@("`@("`@)'1A<B`]("9(;W)D95]#;VUP<F5S<SHZ<VEN9VQE
M=&]N*"=T87(G*3L*"B`@("`@("`@)'1A<D1A=&$@/2`D=&%R+3YD96-O;7!R
M97-S*"1C;VYT96YT<RD["B`@("`@("`@:68@*&ES7V$H)'1A<D1A=&$L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B`D
M=&%R1&%T82T^9V5T365S<V%G92@I("X@)SPO<')E/B<["B`@("`@("`@?0H*
M("`@("`@("`D9FEL94-O=6YT(#T@8V]U;G0H)'1A<D1A=&$I.PH*("`@("`@
M("!I;F-L=61E7V]N8V4@)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@)'1E
M>'0@(#T@)SQS=')O;F<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?
M*")#;VYT96YT<R!O9B!<(B5S7"(B*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T
M3F%M92@I*2D@+B`G.CPO<W1R;VYG/B<@+B`B7&XB.PH@("`@("`@("1T97AT
M("X]("<\=&%B;&4^/'1R/CQT9"!A;&EG;CTB;&5F="(^/'1T/CQS<&%N(&-L
M87-S/2)F:7AE9"(^)SL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL
M4W!A8V5S*%\H(D%R8VAI=F4@3F%M92(I("X@)SH@("<@+B`D=&AI<RT^;6EM
M95]P87)T+3YG971.86UE*"DI("X@(EQN(CL*("`@("`@("`D=&5X="`N/2!4
M97AT.CIH=&UL06QL4W!A8V5S*%\H(D%R8VAI=F4@1FEL92!3:7IE(BD@+B`G
M.B`G("X@<W1R;&5N*"1C;VYT96YT<RD@+B`G(&)Y=&5S)RD@+B`B7&XB.PH@
M("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H*"1F:6QE0V]U
M;G0@(3T@,2D@/R!S<')I;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&5S(BDL
M("1F:6QE0V]U;G0I(#H@<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE
M(BDL("1F:6QE0V]U;G0I*3L*("`@("`@("`D=&5X="`N/2`B7&Y<;B(["B`@
M("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@("`@("`@
M("`@("`@("`@("`@<W1R7W!A9"A?*")&:6QE($YA;64B*2P@("`@(#8R+"`G
M("<L(%-44E]0041?4DE'2%0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R
M7W!A9"A?*")!='1R:6)U=&5S(BDL("`@(#$U+"`G("<L(%-44E]0041?3$5&
M5"D@+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(E-I>F4B*2P@
M("`@("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@
M("`@("`@("`@('-T<E]P860H7R@B36]D:69I960@1&%T92(I+"`Q.2P@)R`G
M+"!35%)?4$%$7TQ%1E0I"B`@("`@("`@("`@("`@("`@*2`N(")<;B(["@H@
M("`@("`@("1T97AT("X]('-T<E]R97!E870H)RTG+"`Q,#8I("X@(EQN(CL*
M"B`@("`@("`@9F]R96%C:"`H)'1A<D1A=&$@87,@)'9A;"D@>PH@("`@("`@
M("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H"B`@("`@("`@("`@
M("`@("`@("`@("`@('-T<E]P860H)'9A;%LG;F%M92==+"`V,BP@)R`G+"!3
M5%)?4$%$7U))1TA4*2`N"B`@("`@("`@("`@("`@("`@("`@("`@('-T<E]P
M860H)'9A;%LG871T<B==+"`Q-2P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"@D=F%L6R=S:7IE)UTL(#$P
M+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("`@
M("!S=')?<&%D*'-T<F9T:6UE*"(E9"TE8BTE62`E2#HE32(L("1V86Q;)V1A
M=&4G72DL(#$Y+"`G("<L(%-44E]0041?3$5&5"D*("`@("`@("`@("`@("`@
M("`@("`I("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@("1T97AT("X]('-T
M<E]R97!E870H)RTG+"`Q,#8I("X@(EQN(CL*("`@("`@("`D=&5X="`N/2`G
M/"]S<&%N/CPO='0^/"]T9#X\+W1R/CPO=&%B;&4^)SL*"B`@("`@("`@<F5T
M=7)N(&YL,F)R*"1T97AT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@8V]N=&5N="UT>7!E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T
M97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]C<W,N<&AP
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V-C``,3`T,3<S-C(W
M-S,`,#(Q-3,S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+W-O=7)C92YP:'`G.PH*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]C<W,@
M8VQA<W,@<F5N9&5R<R!#4U,@<V]U<F-E(&%S($A434P@=VET:"!A;B!E9F9O
M<G0*("H@=&\@<F5M;W9E('!O=&5N=&EA;&QY(&UA;&EC:6]U<R!C;V1E+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V-S<RYP
M:'`L=B`Q+C$N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(T(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA
M<W,@34E-15]6:65W97)?8W-S(&5X=&5N9',@34E-15]6:65W97)?<V]U<F-E
M('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S
M970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($%N>2!P87)A;65T97)S('1H92!V:65W97(@;6%Y(&YE960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!T97AT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&YU;&PI"B`@
M("!["B`@("`@("`@)&-S<R`](&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/FUI
M;65?<&%R="T^9V5T0V]N=&5N=',H*2P@14Y47TY/455/5$53*3L*("`@("`@
M("`D8W-S(#T@<')E9U]R97!L86-E7V-A;&QB86-K*"<A*'U\7"HO*2XJ/RA[
M?"]<*BDA<R<L(&%R<F%Y*"1T:&ES+"`G7VAA;F1L97,G*2P@)&-S<RD["B`@
M("`@("`@)&-S<R`]('!R96=?<F5P;&%C95]C86QL8F%C:R@G(7M;7GU=*GTA
M<R<L(&%R<F%Y*"1T:&ES+"`G7V%T=')I8G5T97,G*2P@)&-S<RD["B`@("`@
M("`@)&-S<R`]('!R96=?<F5P;&%C95]C86QL8F%C:R@G(2]<*BXJ/UPJ+R%S
M)RP@87)R87DH)'1H:7,L("=?8V]M;65N=',G*2P@)&-S<RD["B`@("`@("`@
M)&-S<R`]('1R:6TH)&-S<RD["@H@("`@("`@("\O($5D=6-A=&5D($=U97-S
M(&%T('=H971H97(@=V4@87)E(&EN;&EN92!O<B!N;W0N"B`@("`@("`@:68@
M*&AE861E<G-?<V5N="@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;&EN94YU;6)E<B@D8W-S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G
M+V-O;6UO;BUH96%D97(N:6YC)RD@+@H@("`@("`@("`@("`@("`@)'1H:7,M
M/FQI;F5.=6UB97(H)&-S<RD@+@H@("`@("`@("`@("`@("`@571I;#HZ8G5F
M9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC
M)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]C;VUM96YT<R@D
M;6%T8VAE<RD*("`@('L*("`@("`@("`D<&%T=&5R;G-;72`]("<A*&AT='`Z
M+R];+UQW+2Y=*RDA<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G/&$@:')E
M9CTB7%PQ(CY<7#$\+V$^)SL*"B`@("`@("`@)&-O;6UE;G1S(#T@<')E9U]R
M97!L86-E*"1P871T97)N<RP@)')E<&QA8V5S+"`D;6%T8VAE<ULP72D["@H@
M("`@("`@(')E='5R;B`G/'-P86X@8VQA<W,](F-O;6UE;G0B/B<@+B`D8V]M
M;65N=',@+B`G/"]S<&%N/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7V%T=')I
M8G5T97,H)&UA=&-H97,I"B`@("!["B`@("`@("`@+R\@071T<FEB=71E<RX*
M("`@("`@("`D<&%T=&5R;G-;72`]("<A*%LM7'==*UQS*BDZ(7,G.PH@("`@
M("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L87-S/2)A='1R(B(^7%PQ/"]S
M<&%N/CHG.PH*("`@("`@("`O+R!686QU97,N"B`@("`@("`@)'!A='1E<FYS
M6UT@/2`G(3HH7',J*2@N*S\I*%QS*CLI(7,G.PH@("`@("`@("1R97!L86-E
M<UM=(#T@)SI<7#$\<W!A;B!C;&%S<STB=F%L=64B/EQ<,CPO<W!A;CX\<W!A
M;B!C;&%S<STB96]L(CY<7#,\+W-P86X^)SL*"B`@("`@("`@+R\@55),<RX*
M("`@("`@("`D<&%T=&5R;G-;72`]("<A*'5R;%PH6UPG(ET_*2@N*C\I*%M<
M)R)=/UPI*2%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\<W!A;B!C;&%S
M<STB=7)L(CY<7#$\<W!A;B!C;&%S<STB9FEL92(^7%PR/"]S<&%N/EQ<,SPO
M<W!A;CXG.PH*("`@("`@("`O+R!#;VQO<G,N"B`@("`@("`@)'!A='1E<FYS
M6UT@/2`G(2@C6ULZ>&1I9VET.EU=>S,L-GTI(7,G.PH@("`@("`@("1R97!L
M86-E<UM=(#T@)SQS<&%N(&-L87-S/2)C;VQO<B(^7%PQ/"]S<&%N/B<["@H@
M("`@("`@("\O(%!A<F5N=&AE<V5S+@H@("`@("`@("1P871T97)N<UM=(#T@
M)R$H>WQ]*2%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\<W!A;B!C;&%S
M<STB<&%R96YT:&5S97,B/EQ<,3PO<W!A;CXG.PH*("`@("`@("`O+R!5;FET
M>2X*("`@("`@("`D<&%T=&5R;G-;72`]("<A*&5M?'!X?"4I7&(A<R<["B`@
M("`@("`@)')E<&QA8V5S6UT@/2`G/&5M/EQ<,3PO96T^)SL*"B`@("`@("`@
M<F5T=7)N('!R96=?<F5P;&%C92@D<&%T=&5R;G,L("1R97!L86-E<RP@)&UA
M=&-H97-;,%TI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]H86YD;&5S*"1M871C
M:&5S*0H@("`@>PH@("`@("`@("\O($A434P@5&%G<RX*("`@("`@("`D<&%T
M=&5R;G-;72`]("<A7&(H8F]D>7QH7&1\87QS<&%N?&1I=GQA8W)O;GEM?'-M
M86QL?'-T<F]N9WQE;7QP<F5\=6Q\;VQ\;&E\<"E<8B%S)SL*("`@("`@("`D
M<F5P;&%C97-;72`]("<\<W!A;B!C;&%S<STB:'1A9R(^7%PQ/"]S<&%N/EQ<
M,B<["@H@("`@("`@("\O($E$<RX*("`@("`@("`D<&%T=&5R;G-;72`]("<A
M*"-;+5QW72LI(7,G.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L
M87-S/2)I9"(^7%PQ/"]S<&%N/B<["@H@("`@("`@("\O($-L87-S+@H@("`@
M("`@("1P871T97)N<UM=(#T@)R$H7"Y;+5QW72LI7&(A<R<["B`@("`@("`@
M)')E<&QA8V5S6UT@/2`G/'-P86X@8VQA<W,](F-L87-S(CY<7#$\+W-P86X^
M)SL*"B`@("`@("`@+R\@345407,N"B`@("`@("`@)'!A='1E<FYS6UT@/2`G
M(2@Z;&EN:WPZ=FES:71E9'PZ:&]V97)\.F%C=&EV97PZ9FER<W0M;&5T=&5R
M*2%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\<W!A;B!C;&%S<STB;65T
M86,B/EQ<,3PO<W!A;CXG.PH*("`@("`@("!R971U<FX@<')E9U]R97!L86-E
M*"1P871T97)N<RP@)')E<&QA8V5S+"`D;6%T8VAE<ULP72D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP
M:'``````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#0P`#$P-#$W,S8R
M-S<S`#`R,38W,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W1N968@8VQA
M<W,@86QL;W=S($U3+51.148@871T86-H;65N=',@=&\@8F4@9&ES<&QA>65D
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP+'8@,2XQ,RXQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6
M:65W97)?=&YE9B!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@
M("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G0@=&YE9B!D871A+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T
M:&4@=FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R97-S+G!H<"<["@H@("`@("`@("1T
M;F5F(#T@)DAO<F1E7T-O;7!R97-S.CIS:6YG;&5T;VXH)W1N968G*3L*"B`@
M("`@("`@)&1A=&$@/2`G/'1A8FQE(&)O<F1E<CTB,2(^)SL*("`@("`@("`D
M:6YF;R`]("1T;F5F+3YD96-O;7!R97-S*"1T:&ES+3YM:6UE7W!A<G0M/F=E
M=$-O;G1E;G1S*"DI.PH@("`@("`@(&EF("AE;7!T>2@D:6YF;RD@?'P@:7-?
M82@D:6YF;RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9&%T82`N
M/2`G/'1R/CQT9#XG("X@7R@B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+B(I("X@)SPO=&0^/"]T<CXG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1D871A("X]("<\='(^/'1D/B<@+B!?*").86UE(BD@
M+B`G/"]T9#X\=&0^)R`N(%\H(DUI;64@5'EP92(I("X@)SPO=&0^/"]T<CXG
M.PH@("`@("`@("`@("!F;W)E86-H("@D:6YF;R!A<R`D<&%R="D@>PH@("`@
M("`@("`@("`@("`@)&1A=&$@+CT@)SQT<CX\=&0^)R`N("1P87)T6R=N86UE
M)UT@+B`G/"]T9#X\=&0^)R`N("1P87)T6R=T>7!E)UT@+B`G+R<@+B`D<&%R
M=%LG<W5B='EP92==("X@)SPO=&0^/"]T<CXG.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1D871A("X]("<\+W1A8FQE/B<["@H@("`@("`@
M(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T
M:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y
M<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970]
M)R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<```
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-S0U-@`Q,#0Q-S,V,C<W,P`P
M,C(P-3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]V8V%R9"!C;&%S<R!R
M96YD97)S(&]U="!V0V%R9',@:6X@2%1-3"!F;W)M870N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP+'8@,2XS
M-"XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,`H@*B!`<&%C
M:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?
M=F-A<F0@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!2
M96YD97(@;W5T('1H92!V8V%R9"!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E
M<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD
M97(H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>2P@)'!R969S.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+VE#
M86QE;F1A<BYP:'`G.PH*("`@("`@("`D87!P(#T@9F%L<V4["B`@("`@("`@
M)&1A=&$@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I.PH@("`@
M("`@("1H=&UL(#T@)R<["B`@("`@("`@)&EM<&]R=%]M<V<@/2!N=6QL.PH@
M("`@("`@("1T:71L92`](%\H(G9#87)D(BD["@H@("`@("`@("1I0V%L(#T@
M)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21I0V%L+3YP
M87)S979#86QE;F1A<B@D9&%T82DI('L*("`@("`@("`@("`@)&EM<&]R=%]M
M<V<@/2!?*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H571I;#HZ9V5T
M1F]R;41A=&$H)VEM<&]R="<I("8F"B`@("`@("`@("`@(%5T:6PZ.F=E=$9O
M<FU$871A*"=S;W5R8V4G*2`F)@H@("`@("`@("`@("`D<F5G:7-T<GDM/FAA
M<TUE=&AO9"@G8V]N=&%C=',O:6UP;W)T)RDI('L*("`@("`@("`@("`@)'-O
M=7)C92`](%5T:6PZ.F=E=$9O<FU$871A*"=S;W5R8V4G*3L*("`@("`@("`@
M("`@)&-O;G1A8W1S(#T@)')E9VES=')Y+3YC86QL*"=C;VYT86-T<R]I;7!O
M<G0G+"!A<G)A>2@D9&%T82P@)W1E>'0O>"UV8V%R9"<L("1S;W5R8V4I*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)&-O;G1A8W1S+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`D:6UP;W)T7VUS9R`](%\H(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@D:4-A;"T^
M9V5T0V]M<&]N96YT0V]U;G0H*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`@
M("`@)&EM<&]R=%]M<V<@/2!?*")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:6UP;W)T7VUS
M9R`](%\H(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:'1M;"`@/2!5=&EL.CIB=69F
M97)/=71P=70H)VEN8VQU9&4G+"`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S
M)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUH96%D97(N:6YC)RD["B`@("`@("`@
M)&AT;6P@+CT@)SQT86)L92!C96QL<W!A8VEN9STB,2(@8F]R9&5R/2(P(B!C
M96QL<&%D9&EN9STB,2(^)SL*("`@("`@("!I9B`H(6ES7VYU;&PH)&EM<&]R
M=%]M<V<I*2!["B`@("`@("`@("`@("1H=&UL("X]("<\='(^/'1D(&-O;'-P
M86X](C(B(&-L87-S/2)H96%D97(B/B<@+B`D:6UP;W)T7VUS9R`N("<\+W1D
M/CPO='(^/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^)SL*("`@("`@("!](&5L
M<V5I9B`H)')E9VES=')Y+3YH87--971H;V0H)V-O;G1A8W1S+VEM<&]R="<I
M("8F"B`@("`@("`@("`@("`@("`@("1R96=I<W1R>2T^:&%S365T:&]D*"=C
M;VYT86-T<R]S;W5R8V5S)RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQT
M<CX\=&0@8V]L<W!A;CTB,B(@8VQA<W,](FAE861E<B(^/&9O<FT@86-T:6]N
M/2(G("X@)%]315)615);)U!(4%]314Q&)UT@+B`G(B!M971H;V0](F=E="(@
M;F%M93TB=F-A<F1?:6UP;W)T(CXG("X@571I;#HZ9F]R;4EN<'5T*"D["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1?1T54(&%S("1K97D@/3X@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1K97DI("X@)R(@=F%L=64]
M(B<@+B!H=&UL<W!E8VEA;&-H87)S*"1V86PI("X@)R(@+SXG.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D<V]U<F-E<R`]("1R96=I<W1R>2T^8V%L
M;"@G8V]N=&%C=',O<V]U<F-E<R<L(&%R<F%Y*'1R=64I*3L*("`@("`@("`@
M("`@:68@*&-O=6YT*"1S;W5R8V5S*2`^(#$I('L*("`@("`@("`@("`@("`@
M("1H=&UL("X]("<\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N
M(B!N86UE/2)I;7!O<G0B('9A;'5E/2(G("X@7R@B061D('1O(&%D9')E<W,@
M8F]O:SHB*2`N("<B("\^)SL*("`@("`@("`@("`@("`@("1H=&UL("X]("<\
M<V5L96-T(&YA;64](G-O=7)C92(^)SL*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1S;W5R8V5S(&%S("1K97D@/3X@)&QA8F5L*2!["B`@("`@("`@("`@
M("`@("`@("`@)'-E;&5C=&5D(#T@*"1K97D@/3T@)'!R969S+3YG971686QU
M92@G861D7W-O=7)C92<I*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G
M)SL*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU
M93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@+B`G(B<@+B`D<V5L96-T
M960@+B`G/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1L86)E;"D@+B`G/"]O<'1I
M;VX^)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1H=&UL("X]("<\:6YP=70@='EP93TB<W5B;6ET
M(B!C;&%S<STB8G5T=&]N(B!N86UE/2)I;7!O<G0B('9A;'5E/2(G("X@7R@B
M061D('1O(&UY(&%D9')E<W,@8F]O:R(I("X@)R(@+SXG.PH@("`@("`@("`@
M("`@("`@)'-O=7)C92`](&%R<F%Y7VME>7,H)'-O=7)C97,I.PH@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(G-O=7)C92(@=F%L=64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1S;W5R8V5;
M,%TI("X@)R(@+SXG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D:'1M
M;"`N/2`G/"]F;W)M/CPO=&0^/"]T<CX\='(^/'1D/B9N8G-P.SPO=&0^/"]T
M<CXG.PH@("`@("`@('T*"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A
M8V@@*"1I0V%L+3YG971#;VUP;VYE;G1S*"D@87,@)'9C*2!["B`@("`@("`@
M("`@(&EF("@D:2`^(#`I('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<\
M='(^/'1D/B9N8G-P.SPO=&0^/"]T<CXG.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("LK)&D["@H@("`@("`@("`@("`D:'1M;"`N/2`G/'1R/CQT9"!C
M;VQS<&%N/2(R(B!C;&%S<STB:&5A9&5R(CXG.PH@("`@("`@("`@("`D9G5L
M;&YA;64@/2`D=F,M/F=E=$%T=')I8G5T941E9F%U;'0H)T9.)RP@9F%L<V4I
M.PH@("`@("`@("`@("!I9B`H)&9U;&QN86UE("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@)&9U;&QN86UE.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1H=&UL("X]("<\+W1D/CPO='(^)SL*"B`@("`@("`@
M("`@("1N(#T@)'9C+3YP<FEN=&%B;&5.86UE*"D["B`@("`@("`@("`@(&EF
M("@A96UP='DH)&XI*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI
M<RT^7W)O=RA?*").86UE(BDL("1N*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&%L:6%S97,@/2`D=F,M/F=E=$%T=')I8G5T959A;'5E<R@G04Q)
M05,G*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1A;&EA<V5S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O
M=RA?*")!;&EA<R(I+"!I;7!L;V1E*"<\8G(@+SXG+"`D86QI87-E<RDI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1B:7)T:&1A>7,@/2`D=F,M/F=E
M=$%T=')I8G5T959A;'5E<R@G0D1!62<I.PH@("`@("`@("`@("!I9B`H(6ES
M7V$H)&)I<G1H9&%Y<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B0FER=&AD87DB*2P@9&%T92@G
M62UM+60G+"`D8FER=&AD87ES6S!=*2D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1L86)E;',@/2`D=F,M/F=E=$%L;$%T=')I8G5T97,H)TQ!0D5,
M)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1L86)E;',@87,@)&QA8F5L*2![
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&QA8F5L6R=P87)A;7,G75LG
M5%E012==*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L86)E
M;%LG<&%R86US)UU;)U194$4G72!A<R`D='EP92D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;&%B96Q;)W!A<F%M<R==6U-T<FEN9SHZ=7!P97(H)'1Y
M<&4I72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1L86)E;%LG<&%R
M86US)UU;)TA/344G72DI('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`D=&AI<RT^7W)O=RA?*")(;VUE($%D9')E<W,B*2P@;FPR8G(H)&QA8F5L
M6R=V86QU92==*2D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H
M)&QA8F5L6R=P87)A;7,G75LG5T]22R==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(E=O<FL@061D<F5S<R(I+"!N
M;#)B<B@D;&%B96Q;)W9A;'5E)UTI*3L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H
M7R@B061D<F5S<R(I+"!N;#)B<B@D;&%B96Q;)W9A;'5E)UTI*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@1F]R
M('9#87)D(#,N,"X*("`@("`@("`@("`@)&%D<G,@/2`D=F,M/F=E=$%L;$%T
M=')I8G5T97,H)T%$4B<I.PH@("`@("`@("`@("!F;W)E86-H("@D861R<R!A
M<R`D:71E;2D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P
M87)A;7,G75LG5%E012==*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-?87)R87DH)&ET96U;)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E012==(#T@87)R
M87DH)&ET96U;)W!A<F%M<R==6R=465!%)UTI.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UT@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:71E;5LG<&%R86US)UU;)U=/
M4DLG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ET96U;)W!A<F%M
M<R==6R=465!%)UU;72`]("=73U)+)SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G
M75LG2$]-12==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:71E;5LG
M<&%R86US)UU;)U194$4G75M=(#T@)TA/344G.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1A9&1R
M97-S(#T@)&ET96U;)W9A;'5E<R==.PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&ET96U;)W!A<F%M<R==6R=465!%)UT@87,@)&%D<BD@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("A3=')I;F<Z.G5P<&5R*"1A9'(I(#T]("=(3TU%
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D82`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%2
M1%]!1%)?4U12145472DI("`@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?0412
M7U-44D5%5%T[('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1A9&1R97-S6U9#05)$7T%$4E],3T-!3$E465TI*2![("1A6UT@/2`D861D
M<F5S<UM60T%21%]!1%)?3$]#04Q)5%E=.R!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?4D5'24].72DI
M("`@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ET[('T*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$
M7T%$4E]03U-40T]$15TI*2![("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?
M4$]35$-/1$5=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D861D<F5S<UM60T%21%]!1%)?0T]53E1265TI*2`@>R`D85M=(#T@)&%D
M9')E<W-;5D-!4D1?04127T-/54Y44EE=.R!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(DAO;64@061D<F5S<R(I
M+"!N;#)B<BAI;7!L;V1E*")<;B(L("1A*2DI.PH*("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D861R*2`]/2`G5T]22R<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&$@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?
M04127U-44D5%5%TI*2`@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]3
M5%)%151=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M861D<F5S<UM60T%21%]!1%)?3$]#04Q)5%E=*2D@>R`D85M=(#T@)&%D9')E
M<W-;5D-!4D1?04127TQ/0T%,251973L@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ETI*2`@
M('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]214=)3TY=.R!]"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!
M1%)?4$]35$-/1$5=*2D@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127U!/
M4U1#3T1%73L@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&%D9')E<W-;5D-!4D1?04127T-/54Y44EE=*2D@('L@)&%;72`]("1A9&1R
M97-S6U9#05)$7T%$4E]#3U5.5%)973L@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")7;W)K($%D9')E<W,B*2P@
M;FPR8G(H:6UP;&]D92@B7&XB+"`D82DI*3L*"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&$@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E
M<W-;5D-!4D1?04127U-44D5%5%TI*2`@('L@)&%;72`]("1A9&1R97-S6U9#
M05)$7T%$4E]35%)%151=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?3$]#04Q)5%E=*2D@>R`D85M=
M(#T@)&%D9')E<W-;5D-!4D1?04127TQ/0T%,251973L@?0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127U)%
M1TE/3ETI*2`@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]214=)3TY=
M.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S
M<UM60T%21%]!1%)?4$]35$-/1$5=*2D@>R`D85M=(#T@)&%D9')E<W-;5D-!
M4D1?04127U!/4U1#3T1%73L@?0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127T-/54Y44EE=*2D@('L@)&%;
M72`]("1A9&1R97-S6U9#05)$7T%$4E]#3U5.5%)973L@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")!9&1R97-S
M(BDL(&YL,F)R*&EM<&QO9&4H(EQN(BP@)&$I*2D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D;G5M8F5R<R`]("1V8RT^9V5T06QL071T<FEB=71E<R@G5$5,
M)RD["@H@("`@("`@("`@("!F;W)E86-H("@D;G5M8F5R<R!A<R`D;G5M8F5R
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&YU;6)E<ELG<&%R86US
M)UU;)U194$4G72DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M;G5M8F5R6R=P87)A;7,G75LG5%E012==(&%S("1T>7!E*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1N=6UB97);)W!A<F%M<R==6U-T<FEN9SHZ=7!P
M97(H)'1Y<&4I72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N=6UB
M97);)W!A<F%M<R==6R=&05@G72DI('L*("`@("`@("`@("`@("`@("`@("`D
M:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")&87@B*2P@)&YU;6)E<ELG=F%L=64G
M72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D;G5M8F5R6R=P87)A;7,G75LG2$]-12==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?
M*")(;VUE(%!H;VYE(BDL("1N=6UB97);)W9A;'5E)UTI.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("AI<W-E="@D;G5M8F5R6R=P87)A;7,G75LG
M5T]22R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D
M=&AI<RT^7W)O=RA?*")7;W)K(%!H;VYE(BDL("1N=6UB97);)W9A;'5E)UTI
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D;G5M8F5R
M6R=P87)A;7,G75LG0T5,3"==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")#96QL(%!H;VYE(BDL("1N=6UB
M97);)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H
M(E!H;VYE(BDL("1N=6UB97);)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&%D9')E<W-E<R`]("1V8RT^9V5T06QL071T<FEB=71E<R@G14U!
M24PG*3L*("`@("`@("`@("`@)&5M86EL<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1A9&1R97-S97,@87,@)&%D9')E<W,I('L*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<ULG<&%R86US)UU;)U194$4G
M72DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D861D<F5S<ULG
M<&%R86US)UU;)U194$4G72!A<R`D='EP92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D861D<F5S<ULG<&%R86US)UU;4W1R:6YG.CIU<'!E<B@D='EP
M92E=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D96UA:6P@/2`G/&$@:')E9CTB)SL*
M("`@("`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G;6%I
M;"]C;VUP;W-E)RDI('L*("`@("`@("`@("`@("`@("`@("`D96UA:6P@+CT@
M)')E9VES=')Y+3YC86QL*"=M86EL+V-O;7!O<V4G+"!A<G)A>2AA<G)A>2@G
M=&\G(#T^("1A9&1R97-S6R=V86QU92==*2DI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D96UA:6P@+CT@)VUA:6QT
M;SHG("X@)&%D9')E<W-;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D96UA:6P@+CT@)R(^)R`N("1A9&1R97-S6R=V86QU
M92==("X@)SPO83XG.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R
M97-S6R=P87)A;7,G75LG4%)%1B==*2D@>PH@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y7W5N<VAI9G0H)&5M86EL<RP@)&5M86EL*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&5M86EL<UM=(#T@
M)&5M86EL.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H8V]U;G0H)&5M86EL<RDI('L*("`@("`@("`@("`@("`@
M("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(D5M86EL(BDL(&EM<&QO9&4H)SQB
M<B`O/B<L("1E;6%I;',I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'1I=&QE(#T@)'9C+3YG971!='1R:6)U=&5686QU97,H)U1)5$Q%)RD["B`@
M("`@("`@("`@(&EF("@A:7-?82@D=&ET;&4L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(E1I=&QE
M(BDL("1T:71L95LP72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R
M;VQE(#T@)'9C+3YG971!='1R:6)U=&5686QU97,H)U)/3$4G*3L*("`@("`@
M("`@("`@:68@*"%I<U]A*"1R;VQE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")2;VQE(BDL("1R
M;VQE6S!=*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]R9R`]("1V
M8RT^9V5T071T<FEB=71E5F%L=65S*"=/4D<G*3L*("`@("`@("`@("`@:68@
M*"%I<U]A*"1O<F<L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(D-O;7!A;GDB*2P@)&]R9ULP72D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1N;W1E<R`]("1V8RT^9V5T
M071T<FEB=71E5F%L=65S*"=.3U1%)RD["B`@("`@("`@("`@(&EF("@A:7-?
M82@D;F]T97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1H
M=&UL("X]("1T:&ES+3Y?<F]W*%\H(DYO=&5S(BDL(&YL,F)R*"1N;W1E<ULP
M72DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=7)L(#T@)'9C+3YG
M971!='1R:6)U=&5686QU97,H)U523"<I.PH@("`@("`@("`@("!I9B`H(6ES
M7V$H)'5R;"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@)'1H:7,M/E]R;W<H7R@B55),(BDL("<\82!H<F5F/2(G("X@)'5R
M;%LP72X@)R(@=&%R9V5T/2)?8FQA;FLB/B<@+B`D=7)L6S!=("X@)SPO83XG
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&AT;6P@+CT@
M)SPO=&%B;&4^)SL*("`@("`@("`D:'1M;"`N/2!5=&EL.CIB=69F97)/=71P
M=70H)VEN8VQU9&4G+"`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO
M<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)RD["@H@("`@("`@(')E='5R
M;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F]W*"1L86)E;"P@)'9A
M;'5E*0H@("`@>PH@("`@("`@(')E='5R;B`G/'1R/CQT9"!C;&%S<STB:71E
M;2(@=F%L:6=N/2)T;W`B/B<@+B`D;&%B96P@+B`G/"]T9#X\=&0@8VQA<W,]
M(FET96TB('9A;&EG;CTB=&]P(CXG("X@)'9A;'5E("X@(CPO=&0^/"]T<CY<
M;B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N
M=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O
M=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E
M=$-H87)S970H*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O=V5B8W!P+G!H<```````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`V,S,T`#$P-#$W,S8R-S<S`#`R,C(R,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?
M5FEE=V5R7W=E8F-P<"!C;&%S<R!R96YD97)S(&]U="!V87)I;W5S(&-O;G1E
M;G0*("H@:6X@2%1-3"!F;W)M870@8GD@=7-I;F<@5V5B($,@4&QU<R!0;'5S
M+@H@*@H@*B!796(@0R!0;'5S('!L=7,Z(&AT='`Z+R]W96)C<'`N<V]U<F-E
M9F]R9V4N;F5T+PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`L=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR
M.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]W96)C
M<'`@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD
M97(@;W5T('1H92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S('5S:6YG(%=E8B!#
M(%!L=7,@4&QU<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]#;VYT96YT<RYP:'`G.PH@
M("`@("`@("1A='1A8VAM96YT(#T@34E-15]#;VYT96YT<SHZ=FEE=T%S071T
M86-H;65N="@I.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U<F4@=&AE
M('!R;V=R86T@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;)VQO
M8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R
M:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==6R=L;V-A=&EO;B==*2`N("<\
M+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1E;7!O<F%R
M>2!F:6QE<R!F;W(@5V5B8W!P+B`J+PH@("`@("`@("1T;7!I;B`@/2!(;W)D
M93HZ9V5T5&5M<$9I;&4H)U=E8F-P<$EN)RD["B`@("`@("`@)'1M<&]U="`]
M($AO<F1E.CIG971496UP1FEL92@G5V5B8W!P3W5T)RD["@H@("`@("`@("\J
M(%=R:71E('1H92!C;VYT96YT<R!O9B!O=7(@8G5F9F5R('1O('1H92!T96UP
M;W)A<GD@:6YP=70@9FEL92X@*B\*("`@("`@("`D8V]N=&5N=',@/2`D=&AI
M<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I.PH@("`@("`@("1F:"`](&9O
M<&5N*"1T;7!I;BP@)W=B)RD["B`@("`@("`@9G=R:71E*"1F:"P@)&-O;G1E
M;G1S+"!S=')L96XH)&-O;G1E;G1S*2D["B`@("`@("`@9F-L;W-E*"1F:"D[
M"@H@("`@("`@("\J($=E="!T:&4@97AT96YS:6]N(&9O<B!T:&4@;6EM92!T
M>7!E+B`J+PH@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O34E-12]-86=I
M8RYP:'`G.PH@("`@("`@("1E>'0@/2!-24U%7TUA9VEC.CI-24U%5&]%>'0H
M)'1H:7,M/FUI;65?<&%R="T^9V5T5'EP92@I*3L*"B`@("`@("`@+RH@17AE
M8W5T92!796(@0R!0;'5S(%!L=7,N(%-P96-I9GEI;F<@=&AE(&EN(&%N9"!O
M=70@9FEL97,@9&ED;B=T"B`@("`@("`@("`@=V]R:R!F;W(@;64@8G5T('!I
M<&5S(&1I9"X@*B\*("`@("`@("!E>&5C*"1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W=E8F-P<"==6R=L;V-A=&EO;B==("X@(B`M+7!I<&4@+2UP:7!E("UX
M/21E>'0@+6P@+6$@+70@/"`D=&UP:6X@/B`D=&UP;W5T(BD["B`@("`@("`@
M)')E<W5L=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&UP;W5T*3L*"B`@("`@
M("`@+RH@268@=V4@87)E(&YO="!D:7-P;&%Y:6YG(&EN;&EN92P@86QL('1H
M92!F;W)M871T:6YG(&ES(&%L<F5A9'D*("`@("`@("`@*B!D;VYE(&9O<B!U
M<RX@*B\*("`@("`@("!I9B`H)&%T=&%C:&UE;G0I('L*("`@("`@("`@("`@
M+RH@5&AE(&9I<G-T(#(@;&EN97,@87)E('1H92!#;VYT96YT+51Y<&4@;&EN
M92!A;F0@82!B;&%N:R!L:6YE"B`@("`@("`@("`@("`J('-O('=E('-H;W5L
M9"!R96UO=F4@=&AE;2!B969O<F4@;W5T<'5T=&EN9RX@*B\*("`@("`@("`@
M("`@<F5T=7)N('!R96=?<F5P;&%C92@B+RXJ7&XN*EQN+R(L("<G+"`D<F5S
M=6QT<RP@,2D["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S
M='EL92!S:&5E="P@<F5M;W9I;F<@86YY(&=L;V)A;"!B;V1Y(&9O<FUA='1I
M;F<*("`@("`@("`@*B!I9B!W92=R92!D:7-P;&%Y:6YG(&EN;&EN92X@*B\*
M("`@("`@("`D<F5S(#T@<')E9U]S<&QI="@G.R@\+W-T>6QE/BE\*#QS='EL
M92!T>7!E/2)T97AT+V-S<R(^*3LG+"`D<F5S=6QT<RD["B`@("`@("`@)'-T
M>6QE(#T@)')E<ULQ73L*("`@("`@("`D<W1Y;&4@/2!P<F5G7W)E<&QA8V4H
M)R]<;F)O9'E<<RL_>RXJ/WTO<R<L("<G+"`D<W1Y;&4I.PH*("`@("`@("`O
M*B!%>'1R86-T('1H92!C;VYT96YT+B`J+PH@("`@("`@("1R97,@/2!P<F5G
M7W-P;&ET*"<O7#Q<+S]P<F5</B\G+"`D<F5S=6QT<RD["B`@("`@("`@)&)O
M9'D@/2`D<F5S6S%=.PH*("`@("`@("!R971U<FX@)SQS='EL93XG("X@)'-T
M>6QE("X@)SPO<W1Y;&4^/&1I=B!C;&%S<STB=V5B8W!P(B!S='EL93TB=VAI
M=&4M<W!A8V4Z<')E.V9O;G0M9F%M:6QY.FUO;F]S<&%C92(^)R`N("1B;V1Y
M("X@)SPO9&EV/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E
M(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@
M+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,#8V-P`Q,#0Q-S,V,C<W,P`P,C$U-#<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%
M7U9I97=E<E]Z:7`@8VQA<W,@<F5N9&5R<R!O=70@=&AE(&-O;G1E;G1S(&]F
M(%I)4"!F:6QE<R!I;B!(5$U,"B`J(&9O<FUA="X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP+'8@,2XS,"XQ,"XQ
M,"`R,#`V+S`R+S$P(#$S.C4T.C`T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,"TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN
M>CX*("H@0'-I;F-E("`@2&]R9&4@,BXP"B`J($!P86-K86=E($AO<F1E7TU)
M345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]Z:7`@97AT96YD<R!-
M24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C
M=7)R96YT('II<"!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D
M(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5N
M9&5R*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3W5T<'5T('1H92!F:6QE(&QI<W0N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]N=&5N=',@(%1H92!C;VYT96YT<R!O9B!T:&4@>FEP(&%R8VAI
M=F4N"B`@("`@*B!`<&%R86T@;6EX960@)&-A;&QB86-K("`@5&AE(&-A;&QB
M86-K(&9U;F-T:6]N('1O('5S92!O;B!T:&4@>FEP9FEL90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!L:7-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<F5N9&5R*"1C;VYT96YT<RP@)&-A;&QB86-K(#T@;G5L
M;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R97-S
M+G!H<"<["@H@("`@("`@("1Z:7`@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L
M971O;B@G>FEP)RD["@H@("`@("`@("\J($UA:V4@<W5R92!T:&ES(&ES(&$@
M=F%L:60@>FEP(&9I;&4N("HO"B`@("`@("`@:68@*"1Z:7`M/F-H96-K6FEP
M1&%T82@D8V]N=&5N=',I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@)SQP<F4^)R`N(%\H(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N(BD@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@("`@
M("`@("1Z:7!);F9O(#T@)'II<"T^9&5C;VUP<F5S<R@D8V]N=&5N=',L(&%R
M<F%Y*"=A8W1I;VXG(#T^($A/4D1%7T-/35!215-37UI)4%],25-4*2D["B`@
M("`@("`@:68@*&ES7V$H)'II<$EN9F\L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1Z:7!);F9O+3YG971-97-S86=E*"D["B`@("`@
M("`@?0H@("`@("`@("1F:6QE0V]U;G0@/2!C;W5N="@D>FEP26YF;RD["@H@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH*("`@("`@
M("`D=&5X="`]("<\<W1R;VYG/B<@+B!H=&UL<W!E8VEA;&-H87)S*'-P<FEN
M=&8H7R@B0V]N=&5N=',@;V8@7"(E<UPB(BDL("1T:&ES+3YM:6UE7W!A<G0M
M/F=E=$YA;64H*2DI("X@)SH\+W-T<F]N9SXG("X@(EQN(CL*("`@("`@("`D
M=&5X="`N/2`G/'1A8FQE/CQT<CX\=&0@86QI9VX](FQE9G0B/CQT=#X\<W!A
M;B!C;&%S<STB9FEX960B/B<["B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M
M;$%L;%-P86-E<RA?*")!<F-H:79E($YA;64B*2`N("<Z("<@+B`D=&AI<RT^
M;6EM95]P87)T+3YG971.86UE*"DI("X@(EQN(CL*("`@("`@("`D=&5X="`N
M/2!497AT.CIH=&UL06QL4W!A8V5S*%\H(D%R8VAI=F4@1FEL92!3:7IE(BD@
M+B`G.B`G("X@<W1R;&5N*"1C;VYT96YT<RD@+B`G(&)Y=&5S)RD@+B`B7&XB
M.PH@("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H*"1F:6QE
M0V]U;G0@(3T@,2D@/R!S<')I;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&5S
M(BDL("1F:6QE0V]U;G0I(#H@<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F
M:6QE(BDL("1F:6QE0V]U;G0I*3L*("`@("`@("`D=&5X="`N/2`B7&Y<;B([
M"B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@("`@
M("`@("`@("`@("`@("`@<W1R7W!A9"A?*")&:6QE($YA;64B*2P@("`@("`U
M,"P@)R`G+"!35%)?4$%$7U))1TA4*2`N"B`@("`@("`@("`@("`@("`@("`@
M('-T<E]P860H7R@B071T<FEB=71E<R(I+"`@("`@,3`L("<@)RP@4U127U!!
M1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B4VEZ
M92(I+"`@("`@("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@
M("`@("`@("`@("`@("`@('-T<E]P860H7R@B36]D:69I960@1&%T92(I+"`@
M,3DL("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@
M('-T<E]P860H7R@B365T:&]D(BDL("`@("`@("`@,3`L("<@)RP@4U127U!!
M1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B0U)#
M(BDL("`@("`@("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@
M("`@("`@("`@("`@("`@('-T<E]P860H7R@B4F%T:6\B*2P@("`@("`@("`@
M(#<L("<@)RP@4U127U!!1%],1494*0H@("`@("`@("`@("`@("`@("D@+B`B
M7&XB.PH*("`@("`@("`D=&5X="`N/2!S=')?<F5P96%T*"<M)RP@,3$V*2`N
M(")<;B(["@H@("`@("`@(&9O<F5A8V@@*"1Z:7!);F9O(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`D<F%T:6\@/2`H96UP='DH)'9A;%LG<VEZ
M92==*2D@/R`P(#H@,3`P("H@*"1V86Q;)V-S:7IE)UT@+R`D=F%L6R=S:7IE
M)UTI.PH*("`@("`@("`@("`@)'9A;%LG;F%M92==(#T@<W1R7W!A9"@D=F%L
M6R=N86UE)UTL(#4P+"`G("<L(%-44E]0041?4DE'2%0I.PH@("`@("`@("`@
M("`D=F%L6R=A='1R)UT@/2!S=')?<&%D*"1V86Q;)V%T='(G72P@,3`L("<@
M)RP@4U127U!!1%],1494*3L*("`@("`@("`@("`@)'9A;%LG<VEZ92==(#T@
M<W1R7W!A9"@D=F%L6R=S:7IE)UTL(#$P+"`G("<L(%-44E]0041?3$5&5"D[
M"B`@("`@("`@("`@("1V86Q;)V1A=&4G72`]('-T<E]P860H<W1R9G1I;64H
M(B5D+25B+259("5(.B5-(BP@)'9A;%LG9&%T92==*2P@,3DL("<@)RP@4U12
M7U!!1%],1494*3L*("`@("`@("`@("`@)'9A;%LG;65T:&]D)UT@/2!S=')?
M<&%D*"1V86Q;)VUE=&AO9"==+"`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I.PH@
M("`@("`@("`@("`D=F%L6R=C<F,G72`]('-T<E]P860H)'9A;%LG8W)C)UTL
M(#$P+"`G("<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1V86Q;)W)A
M=&EO)UT@/2!S=')?<&%D*'-P<FEN=&8H(B4Q+C%F)24B+"`D<F%T:6\I+"`W
M+"`G("<L(%-44E]0041?3$5&5"D["@H@("`@("`@("`@("`D=F%L(#T@87)R
M87E?;6%P*&%R<F%Y*"=497AT)RP@)VAT;6Q!;&Q3<&%C97,G*2P@)'9A;"D[
M"@H@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)&-A;&QB86-K*2D@>PH@("`@
M("`@("`@("`@("`@)'9A;"`](&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@
M)&ME>2P@)'9A;"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T97AT
M("X]("1V86Q;)VYA;64G72`N("1V86Q;)V%T='(G72`N("1V86Q;)W-I>F4G
M72`N"B`@("`@("`@("`@("`@("`@("`@("1V86Q;)V1A=&4G72`N("1V86Q;
M)VUE=&AO9"==("X@)'9A;%LG8W)C)UT@+@H@("`@("`@("`@("`@("`@("`@
M("`D=F%L6R=R871I;R==("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@("1T
M97AT("X]('-T<E]R97!E870H)RTG+"`Q,38I("X@(EQN(CL*("`@("`@("`D
M=&5X="`N/2`G/"]S<&%N/CPO='0^/"]T9#X\+W1R/CPO=&%B;&4^)SL*"B`@
M("`@("`@<F5T=7)N(&YL,F)R*"1T97AT*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@8V]N=&5N="UT>7!E"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E
M="@I.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<```````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4P,#,T`#$P
M-#$W,S8R-S<S`#`R,3`T-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE(&1E<V-R:7!T:6]N(&]F
M($AO<F1E('1O('5S92!I;B!T:&4@)U5S97(M06=E;G0Z)R!H96%D97(N"B`J
M+PID969I;F4H)TA/4D1%7T%'14Y47TA%041%4B<L("=(;W)D92!!<'!L:6-A
M=&EO;B!&<F%M97=O<FL@,RXQ)RD["@HO*BH*("H@5&AE($U)345?2&5A9&5R
M<SHZ(&-L87-S(&-O;G1A:6YS(&=E;F5R:6,@9G5N8W1I;VYS(')E;&%T960@
M=&\*("H@:&%N9&QI;F<@=&AE(&AE861E<G,@;V8@;6%I;"!M97-S86=E<RX*
M("H*("H@5&AE(&1E9F%U;'0@8VAA<F%C=&5R('-E="!T;R!U<V4@9F]R(&AE
M861E<G,@<VAO=6QD(&)E(&1E9FEN960@:6X@=&AE"B`J('9A<FEA8FQE("1'
M3$]"04Q36R=M:6UE7VAE861E<G,G75LG9&5F875L=%]C:&%R<V5T)UT@*&1E
M9F%U;'1S('1O(%53+4%30TE)"B`J('!E<B!21D,@,C`T-2DN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<"QV(#$N,CDN
M,3`N,3@@,C`P-B\P,R\R-"`Q-3HT-3HS-R!S;'5S87)Z($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?34E-10H@*B\*8VQA<W,@34E-15](96%D97)S('L*"B`@("`O*BH*("`@
M("`J(%1H92!I;G1E<FYA;"!H96%D97)S(&%R<F%Y+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:&5A9&5R<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!#86-H960@;W5T<'5T(&]F('1H92!-24U%
M7U-T<G5C='5R93HZ<&%R<V5-24U%2&5A9&5R<R@I(&-O;6UA;F0N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A;&Q(96%D
M97)S.PH*("`@("\J*@H@("`@("H@0V%C:&5D(&]U='!U="!O9B!T:&4@:6UA
M<%]F971C:&AE861E<B@I(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?:&5A9&5R5&5X=#L*"B`@("`O*BH*
M("`@("`J(%1H92!H96%D97(@;V)J96-T(')E='5R;F5D(&9R;VT@:6UA<%]H
M96%D97)I;F9O*"DN"B`@("`@*@H@("`@("H@0'9A<B!S=&1#;&%S<PH@("`@
M("HO"B`@("!V87(@)%]H96%D97)/8FIE8W0["@H@("`@+RHJ"B`@("`@*B!4
M:&4@:6YT97)N86P@9FQA9W,@87)R87DN"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]F;&%G<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!4:&4@57-E<BU!9V5N="!S=')I;F<@=&\@=7-E+@H@("`@
M("H@5$A)4R!604Q512!32$]53$0@0D4@3U9%4E))1$5.($)9($%,3"!354)#
M3$%34T53+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7V%G96YT(#T@2$]21$5?04=%3E1?2$5!1$52.PH*("`@("\J*@H@
M("`@("H@5&AE('-E<75E;F-E('1O('5S92!A<R!%3TP@9F]R('1H92!H96%D
M97)S+@H@("`@("H@5&AE(&1E9F%U;'0@:7,@8W5R<F5N=&QY('1O(&]U='!U
M="!T:&4@14],('-E<75E;F-E(&EN=&5R;F%L;'D@87,*("`@("`J(&IU<W0@
M(EQN(B!I;G-T96%D(&]F('1H92!C86YO;FEC86P@(EQR7&XB(')E<75I<F5D
M(&EN(%)&0R`X,C(@)B`R,#0U+@H@("`@("H@5&\@8F4@4D9#(&-O;7!L86EN
M="P@=&AE(&9U;&P@/$-2/CQ,1CX@14],(&-O;6)I;F%T:6]N('-H;W5L9"!B
M92!U<V5D"B`@("`@*B!W:&5N('-E;F1I;F<@82!M97-S86=E+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5O;"`](")<
M;B(["@H@("`@+RHJ"B`@("`@*B!4:&4@:6YD97@@;V8@=&AE(&UE<W-A9V4N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7VEN9&5X.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("!4:&4@;65S<V%G92!I;F1E
M>"!T;R!P87)S92!H96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!-24U%
M7TAE861E<G,H)&EN9&5X(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^
M7VEN9&5X(#T@)&EN9&5X.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A(')E9F5R96YC92!T;R!A(&-U<G)E;G1L>2!O<&5N($E-05`@<W1R96%M
M+@H@("`@("H@5$A)4R!604Q512!32$]53$0@0D4@3U9%4E))1$5.($)9($%,
M3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!R971U<FX@<F5S;W5R8V4@
M($%N($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F7V=E=%-T<F5A;2@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!F=6QL(&QI<W0@;V8@
M:&5A9&5R<R!F<F]M('1H92!I;6%P7V9E=&-H:&5A9&5R*"D@9G5N8W1I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%-E92!I;6%P7V9E=&-H
M:&5A9&5R*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$AE861E<E1E>'0H
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7VEN9&5X*2`F
M)B!E;7!T>2@D=&AI<RT^7VAE861E<E1E>'0I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?:&5A9&5R5&5X="`]($!I;6%P7V9E=&-H:&5A9&5R*"1T:&ES+3Y?
M9V5T4W1R96%M*"DL("1T:&ES+3Y?:6YD97@L($947U5)1"D["B`@("`@("`@
M("`@(&EF("@A96UP='DH)$=,3T)!3%-;)VUI;65?:&5A9&5R<R==6R=D969A
M=6QT7V-H87)S970G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:&5A
M9&5R5&5X="`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'1H:7,M/E]H96%D
M97)497AT+"`D1TQ/0D%,4ULG;6EM95]S=')U8W1U<F4G75LG9&5F875L=%]C
M:&%R<V5T)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/E]H96%D97)497AT.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!F=6QL(&QI<W0@;V8@:&5A9&5R<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9&5C;V1E("!$96-O9&4@=&AE(&AE861E
M<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4V5E($U)345?4W1R
M=6-T=7)E.CIP87)S94U)345(96%D97)S*"DN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%L;$AE861E<G,H)&1E8V]D92`]('1R=64I"B`@("!["B`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C='5R92YP:'`G.PH*
M("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]I;F1E>"D@)B8@96UP='DH
M)'1H:7,M/E]A;&Q(96%D97)S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%L
M;$AE861E<G,@/2!-24U%7U-T<G5C='5R93HZ<&%R<V5-24U%2&5A9&5R<R@D
M=&AI<RT^9V5T2&5A9&5R5&5X="@I+"`D9&5C;V1E*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V%L;$AE861E<G,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE(&AE861E<B!O8FIE8W0@9G)O;2!I;6%P
M7VAE861E<FEN9F\H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L87-S
M("!3964@:6UA<%]H96%D97)I;F9O*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$AE861E<D]B:F5C="@I"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1T:&ES+3Y?:6YD97@I("8F(&5M<'1Y*"1T:&ES+3Y?:&5A9&5R3V)J96-T
M*2D@>PH@("`@("`@("`@("`D<W1R96%M(#T@)'1H:7,M/E]G9713=')E86TH
M*3L*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)/8FIE8W0@/2!`:6UA<%]H
M96%D97)I;F9O*"1S=')E86TL($!I;6%P7VUS9VYO*"1S=')E86TL("1T:&ES
M+3Y?:6YD97@I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7VAE861E<D]B:F5C=#L*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD('1H
M92!H96%D97(@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&1E8V]D92`@34E-12!D96-O9&4@=&AE(&AE861E<G,_"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&)U:6QD2&5A9&5R<R@D9&5C;V1E(#T@=')U92D*("`@('L*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:&5A9&5R<RDI('L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AR
M;W5G:"!T:&4@;&ES="!O9B!A;&P@:&5A9&5R<RX@*B\*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^9V5T06QL2&5A9&5R<R@D9&5C;V1E*2!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@D:V5Y+"`D
M=F%L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9"!T
M:&4@9FQA9W,@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD1FQA
M9W,H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]F;&%G<RDI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1V5T('1H92!)34%0(&AE861E<B!O8FIE8W0N("HO"B`@("`@("`@)&]B(#T@
M)'1H:7,M/F=E=$AE861E<D]B:F5C="@I.PH@("`@("`@(&EF("@A:7-?;V)J
M96-T*"1O8BDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@+RH@56YS965N(&9L86<@*B\*("`@("`@("!I9B`H*"1O8BT^56YS
M965N(#T]("=5)RD@?'P@*"1O8BT^4F5C96YT(#T]("=.)RDI('L*("`@("`@
M("`@("`@)'1H:7,M/E]F;&%G<ULG=6YS965N)UT@/2!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4F5C96YT(&9L86<@*B\*("`@("`@("!I9B`H*"1O
M8BT^4F5C96YT(#T]("=.)RD@?'P@*"1O8BT^4F5C96YT(#T]("=2)RDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]F;&%G<ULG<F5C96YT)UT@/2!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@06YS=V5R960@9FQA9R`J+PH@("`@("`@
M(&EF("@D;V(M/D%N<W=E<F5D(#T]("=!)RD@>PH@("`@("`@("`@("`D=&AI
M<RT^7V9L86=S6R=A;G-W97)E9"==(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@("\J($1R869T(&9L86<@*B\*("`@("`@("!I9B`H:7-S970H)&]B+3Y$
M<F%F="D@)B8@*"1O8BT^1')A9G0@/3T@)U@G*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V9L86=S6R=D<F%F="==(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@("\J($9L86=G960@9FQA9R`J+PH@("`@("`@(&EF("@D;V(M/D9L86=G
M960@/3T@)T8G*2!["B`@("`@("`@("`@("1T:&ES+3Y?9FQA9W-;)V9L86=G
M960G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!$96QE=&5D(&9L
M86<@*B\*("`@("`@("!I9B`H)&]B+3Y$96QE=&5D(#T]("=$)RD@>PH@("`@
M("`@("`@("`D=&AI<RT^7V9L86=S6R=D96QE=&5D)UT@/2!T<G5E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&EN=&5R
M;F%L(&AE861E<B!A<G)A>2!I;B!A<G)A>2!F;W)M870N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE(&AE861E<G,@:6X@87)R87D@9F]R;6%T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T%R<F%Y*"D*("`@('L*("`@("`@
M("`D<F5T=7)N7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]H96%D97)S(&%S("1O8BD@>PH@("`@("`@("`@("`D96]L(#T@
M)'1H:7,M/F=E=$5/3"@I.PH@("`@("`@("`@("`D:&5A9&5R(#T@)&]B6R=H
M96%D97(G73L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1O8ELG=F%L=64G
M72DI('L*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXO34E-12YP:'`G.PH@("`@("`@("`@("`@("`@)')E
M='5R;E]A<G)A>5LD:&5A9&5R72`]($U)344Z.G=R87!(96%D97)S*"1H96%D
M97(L(')E<V5T*"1O8ELG=F%L=64G72DI.PH@("`@("`@("`@("`@("`@;F5X
M="@D;V);)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@=VAI;&4@*&QI<W0H
M+"1V86PI(#T@96%C:"@D;V);)W9A;'5E)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)')E='5R;E]A<G)A>5LD:&5A9&5R72`N/2`D96]L("X@)&AE861E
M<B`N("<Z("<@+B!-24U%.CIW<F%P2&5A9&5R<R@D:&5A9&5R+"`D=F%L+"`D
M96]L*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1R971U<FY?87)R87E;)&AE861E<ET@/2`D;V);
M)W9A;'5E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5T=7)N7V%R<F%Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@:6YT97)N86P@:&5A9&5R(&%R<F%Y(&EN('-T<FEN9R!F;W)M
M870N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!H96%D97)S
M(&EN('-T<FEN9R!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4W1R
M:6YG*"D*("`@('L*("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I.PH@
M("`@("`@("1T97AT(#T@)R<["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M:&5A9&5R<R!A<R`D;V(I('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M;V);)W9A;'5E)UTI*2!["B`@("`@("`@("`@("`@("`D;V);)W9A;'5E)UT@
M/2!A<G)A>2@D;V);)W9A;'5E)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1O8ELG=F%L=64G72!A<R`D96YT<GDI('L*("`@("`@
M("`@("`@("`@("1T97AT("X]("1O8ELG:&5A9&5R)UT@+B`G.B`G("X@)&5N
M=')Y("X@)&5O;#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T97AT("X@)&5O;#L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M;F5R871E('1H92`G4F5C96EV960G(&AE861E<B!F;W(@=&AE(%=E8B!B<F]W
M<V5R+3Y(;W)D92!H;W`*("`@("`J("AA='1E;7!T<R!T;R!C;VYF;W)M('1O
M(&=U:61E;&EN97,@:6X@4D9#(#(X,C$I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1296-E:79E9$AE861E<B@I"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1?4T525D526R=(5%107UA?1D]25T%21$5$7T9/4B==*2D@>PH@("`@("`@
M("`@("`O*B!4:&ES(&EN9&EC871E<R!T:&4@=7-E<B!I<R!C;VYN96-T:6YG
M('1H<F]U9V@@82!P<F]X>2X@*B\*("`@("`@("`@("`@)')E;6]T95]P871H
M(#T@97AP;&]D92@G+"<L("1?4T525D526R=(5%107UA?1D]25T%21$5$7T9/
M4B==*3L*("`@("`@("`@("`@)')E;6]T95]A9&1R(#T@)')E;6]T95]P871H
M6S!=.PH@("`@("`@("`@("`D<F5M;W1E(#T@0&=E=&AO<W1B>6%D9'(H)')E
M;6]T95]A9&1R*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5M
M;W1E7V%D9'(@/2`D7U-%4E9%4ELG4D5-3U1%7T%$1%(G73L*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1?4T525D526R=214U/5$5?2$]35"==*2D@>PH@("`@
M("`@("`@("`@("`@)')E;6]T92`]($!G971H;W-T8GEA9&1R*"1R96UO=&5?
M861D<BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<F5M;W1E(#T@)%]315)615);)U)%34]415](3U-4)UT["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@)')E8V5I=F5D(#T@)V9R;VT@)R`N("1R
M96UO=&4@+B`G("@G.PH*("`@("`@("!I9B`H(65M<'1Y*"1?4T525D526R=2
M14U/5$5?241%3E0G72DI('L*("`@("`@("`@("`@)')E8V5I=F5D("X]("1?
M4T525D526R=214U/5$5?241%3E0G72`N("=`)R`N("1R96UO=&4@+B`G("<[
M"B`@("`@("`@?2!E;'-E:68@*"1R96UO=&4@(3T@)%]315)615);)U)%34]4
M15]!1$12)UTI('L*("`@("`@("`@("`@)')E8V5I=F5D("X]("1R96UO=&4@
M+B`G("<["B`@("`@("`@?0H@("`@("`@("1R96-E:79E9"`N/2`G6R<@+B`D
M<F5M;W1E7V%D9'(@+B`G72D@)SL*"B`@("`@("`@:68@*"%E;7!T>2@D1TQ/
M0D%,4ULG8V]N9B==6R=S97)V97(G75LG;F%M92==*2D@>PH@("`@("`@("`@
M("`D<V5R=F5R7VYA;64@/2`D1TQ/0D%,4ULG8V]N9B==6R=S97)V97(G75LG
M;F%M92==.PH@("`@("`@('T@96QS96EF("@A96UP='DH)%]315)615);)U-%
M4E9%4E].04U%)UTI*2!["B`@("`@("`@("`@("1S97)V97)?;F%M92`]("1?
M4T525D526R=315)615)?3D%-12==.PH@("`@("`@('T@96QS96EF("@A96UP
M='DH)%]315)615);)TA45%!?2$]35"==*2D@>PH@("`@("`@("`@("`D<V5R
M=F5R7VYA;64@/2`D7U-%4E9%4ELG2%144%](3U-4)UT["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'-E<G9E<E]N86UE(#T@)W5N:VYO=VXG.PH@
M("`@("`@('T*("`@("`@("`D<F5C96EV960@+CT@)V)Y("<@+B`D<V5R=F5R
M7VYA;64@+B`G("A(;W)D92!-24U%(&QI8G)A<GDI('=I=&@@2%144#L@)SL*
M"B`@("`@("`@)')E8V5I=F5D("X](&1A=&4H)W(G*3L*"B`@("`@("`@)'1H
M:7,M/F%D9$AE861E<B@G4F5C96EV960G+"`D<F5C96EV960I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE("=-97-S86=E+4E$)R!H96%D
M97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$UE<W-A9V5)9$AE861E<B@I
M"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B]-24U%+G!H<"<["B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G
M365S<V%G92U)1"<L($U)344Z.F=E;F5R871E365S<V%G94E$*"DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE("=297-E;G0G(&AE861E
M<G,@*&-O;F9O<FUS('1O(&=U:61E;&EN97,@:6X*("`@("`J(%)&0R`R.#(R
M(%LS+C8N-ETI+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9R;VT@
M(%1H92!A9&1R97-S('1O('5S92!F;W(@)U)E<V5N="U&<F]M)RX*("`@("`J
M($!P87)A;2!S=')I;F<@)'1O("`@(%1H92!A9&1R97-S('1O('5S92!F;W(@
M)U)E<V5N="U4;R<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%)E<V5N=$AE
M861E<G,H)&9R;VTL("1T;RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+TU)344N<&AP)SL*"B`@("`@("`@
M+RH@5V4@9&]N)W0@<V5T(%)E<V5N="U396YD97(L(%)E<V5N="U#8RP@;W(@
M4F5S96YT+4)C8RX@*B\*("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=297-E
M;G0M1&%T92<L(&1A=&4H)W(G*2D["B`@("`@("`@)'1H:7,M/F%D9$AE861E
M<B@G4F5S96YT+49R;VTG+"`D9G)O;2D["B`@("`@("`@)'1H:7,M/F%D9$AE
M861E<B@G4F5S96YT+51O)RP@)'1O*3L*("`@("`@("`D=&AI<RT^861D2&5A
M9&5R*"=297-E;G0M365S<V%G92U)1"<L($U)344Z.F=E;F5R871E365S<V%G
M94E$*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@9&5L:79E
M<GD@<F5C96EP="!H96%D97)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1O("!4:&4@861D<F5S<R!T:&4@<F5C96EP="!S:&]U;&0@8F4@;6%I
M;&5D('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1$96QI=F5R>5)E8V5I
M<'1(96%D97)S*"1T;RD*("`@('L*("`@("`@("`O*B!4:&ES(&ES(&]L9"!S
M96YD;6%I;"`H<')E+3@N-RD@8F5H879I;W(N("HO"B`@("`@("`@)'1H:7,M
M/F%D9$AE861E<B@G4F5T=7)N+5)E8V5I<'0M5&\G+"`D=&\I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE('5S97(@86=E;G0@9&5S8W)I
M<'1I;VX@:&5A9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1!9V5N=$AE
M861E<B@I"B`@("!["B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G57-E<BU!
M9V5N="<L("1T:&ES+3Y?86=E;G0I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@=7-E<B!A9V5N="!D97-C<FEP=&EO;B!H96%D97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U<V5R(&%G96YT(&AE
M861E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06=E;G1(96%D97(H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%G96YT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D(&$@:&5A9&5R('1O('1H92!H96%D97(@87)R87DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4:&4@:&5A
M9&5R(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@(%1H92!H
M96%D97(@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$AE861E<B@D
M:&5A9&5R+"`D=F%L=64I"B`@("!["B`@("`@("`@)&AE861E<B`]('1R:6TH
M)&AE861E<BD["B`@("`@("`@)&QC2&5A9&5R(#T@4W1R:6YG.CIL;W=E<B@D
M:&5A9&5R*3L*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VAE861E<G-;
M)&QC2&5A9&5R72DI('L*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R1L
M8TAE861E<ET@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M7VAE861E<G-;)&QC2&5A9&5R75LG:&5A9&5R)UT@/2`D:&5A9&5R.PH@("`@
M("`@("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=6R=V86QU92==(#T@)'9A
M;'5E.PH@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=6R=?86QT
M97(G72`](&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E(&$@
M:&5A9&5R(&9R;VT@=&AE(&AE861E<B!A<G)A>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5M;W9E2&5A9&5R*"1H96%D97(I"B`@("!["B`@
M("`@("`@)&AE861E<B`]('1R:6TH)&AE861E<BD["B`@("`@("`@)&QC2&5A
M9&5R(#T@4W1R:6YG.CIL;W=E<B@D:&5A9&5R*3L*("`@("`@("!U;G-E="@D
M=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@82!V86QU92!F;W(@82!P87)T:6-U;&%R(&AE861E<B!/3DQ9
M(&EF('1H870@:&5A9&5R(&ES('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)'9A;'5E("`@5&AE(&AE861E<B!V86QU92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=F%L=64@=V%S('-E="P@
M9F%L<V4@:68@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971686QU92@D
M:&5A9&5R+"`D=F%L=64I"B`@("!["B`@("`@("`@)&QC2&5A9&5R(#T@4W1R
M:6YG.CIL;W=E<B@D:&5A9&5R*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]H96%D97)S6R1L8TAE861E<ETI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M:&5A9&5R<ULD;&-(96%D97)=6R=V86QU92==(#T@)'9A;'5E.PH@("`@("`@
M("`@("`D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R75LG7V%L=&5R)UT@/2!T
M<G5E.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N('1H92!H96%D97(@
M:6X@=&AE(&-O<G)E8W0@8V%S92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1H96%D97(@(%1H92!H96%D97(@=&\@<V5A<F-H(&9O<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('9A;'5E(&9O<B!T:&4@9VEV
M96X@:&5A9&5R+@H@("`@("H@("`@("`@("`@("`@("`@($EF('1H92!H96%D
M97(@:7,@;F]T(&9O=6YD+"!R971U<FYS(&YU;&PN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-T<FEN9R@D:&5A9&5R*0H@("`@>PH@("`@("`@("1L8TAE
M861E<B`](%-T<FEN9SHZ;&]W97(H)&AE861E<BD["B`@("`@("`@<F5T=7)N
M("AI<W-E="@D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R72DI(#\@)'1H:7,M
M/E]H96%D97)S6R1L8TAE861E<EU;)VAE861E<B==(#H@;G5L;#L*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'0@=&\@<F5T=7)N('1H92!V86QU92!F
M;W(@82!G:79E;B!H96%D97(N"B`@("`@*B!4:&4@9F]L;&]W:6YG(&AE861E
M<B!F:65L9',@8V%N(&]N;'D@:&%V92`Q(&5N=')Y+"!S;R!I9B!D=7!L:6-A
M=&4*("`@("`J(&5N=')I97,@97AI<W0L('1H92!F:7)S="!V86QU92!W:6QL
M(&)E('5S960Z"B`@("`@*B`@("H@5&\L($9R;VTL($-C+"!"8V,L($1A=&4L
M(%-E;F1E<BP@4F5P;'DM=&\L($UE<W-A9V4M240L($EN+5)E<&QY+51O+`H@
M("`@("H@("`@(%)E9F5R96YC97,L(%-U8FIE8W0@*%)&0R`R.#(R(%LS+C9=
M*0H@("`@("H@("`J($%L;"!,:7-T($AE861E<G,@*%)&0R`R,S8Y(%LS72D*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D
M97(@=&\@<V5A<F-H(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@=F%L=64@9F]R('1H92!G:79E;B!H96%D97(N"B`@("`@*B`@("`@
M("`@("`@("`@("!)9B!T:&4@:&5A9&5R(&ES(&YO="!F;W5N9"P@<F5T=7)N
M<R!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971686QU92@D:&5A9&5R
M*0H@("`@>PH@("`@("`@("1H96%D97(@/2!3=')I;F<Z.FQO=V5R*"1H96%D
M97(I.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]H96%D97)S6R1H96%D
M97)=*2D@>PH@("`@("`@("`@("`D<VEN9VQE(#T@87)R87DH)W1O)RP@)V9R
M;VTG+"`G8V,G+"`G8F-C)RP@)V1A=&4G+"`G<V5N9&5R)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R97!L>2UT;R<L("=M97-S86=E+6ED)RP@
M)VEN+7)E<&QY+71O)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M969E<F5N8V5S)RP@)W-U8FIE8W0G+"`G>"UP<FEO<FET>2<I.PH@("`@("`@
M("`@("`D<VEN9VQE(#T@87)R87E?;65R9V4H)'-I;F=L92P@87)R87E?:V5Y
M<R@D=&AI<RT^;&ES=$AE861E<G,H*2DI.PH@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)'1H:7,M/E]H96%D97)S6R1H96%D97)=6R=V86QU92==*2`F)@H@
M("`@("`@("`@("`@("`@:6Y?87)R87DH)&AE861E<BP@)'-I;F=L92DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VAE861E<G-;)&AE861E
M<EU;)W9A;'5E)UU;,%T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D97)S6R1H96%D97)=6R=V86QU
M92==.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@2&%S('1H92!H96%D97(@8F5E;B!A;'1E<F5D(&9R;VT@=&AE(&]R:6=I
M;F%L/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE861E<B`@5&AE
M(&AE861E<B!T;R!A;F%L>7IE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!T:&4@:&5A9&5R(&AA<R!B965N(&%L=&5R960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%L=&5R961(96%D97(H)&AE861E<BD*("`@
M('L*("`@("`@("`D;&-(96%D97(@/2!3=')I;F<Z.FQO=V5R*"1H96%D97(I
M.PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]H96%D97)S6R1L8TAE
M861E<ETI*2`_("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=6R=?86QT97(G
M72`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@5')A;G-F;W)M<R!A
M($AE861E<B!V86QU92!U<VEN9R!T:&4@;&ES="!O9B!F=6YC=&EO;G,@<')O
M=FED960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4
M:&4@:&5A9&5R('1O(&%L=&5R+@H@("`@("H@0'!A<F%M(&UI>&5D("1F=6YC
M<R`@("!!(&9U;F-T:6]N+"!O<B!A;B!A<G)A>2!O9B!F=6YC=&EO;G,N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%1H92!F=6YC=&EO;G,@=VEL
M;"!B92!P97)F;W)M960@9G)O;2!R:6=H="!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!L969T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9716
M86QU94)Y1G5N8W1I;VXH)&AE861E<BP@)&9U;F-S*0H@("`@>PH@("`@("`@
M("1H96%D97(@/2!3=')I;F<Z.FQO=V5R*"1H96%D97(I.PH*("`@("`@("!I
M9B`H:7-?87)R87DH)&9U;F-S*2D@>PH@("`@("`@("`@("`D9G5N8W,@/2!A
M<G)A>5]R979E<G-E*"1F=6YC<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&9U;F-S(#T@87)R87DH)&9U;F-S*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)&AE861E<ETI*2!["B`@
M("`@("`@("`@("1V86P@/2`D=&AI<RT^9V5T5F%L=64H)&AE861E<BD["B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@("`@("`@
M("`@)'9A;"`](&EM<&QO9&4H(EQN(BP@)'9A;"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@9F]R96%C:"`H)&9U;F-S(&%S("1F=6YC*2!["B`@("`@
M("`@("`@("`@("`D=F%L(#T@8V%L;%]U<V5R7V9U;F,H)&9U;F,L("1V86PI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YS971686QU92@D
M:&5A9&5R+"`D=F%L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&0@86YY($U)344@:&5A9&5R<R!R97%U:7)E9"!F;W(@=&AE($U)345?
M4&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P
M87)T("!4:&4@34E-15]087)T(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D34E-14AE861E<G,H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@
M9F]R96%C:"`H)&UI;65?<&%R="T^:&5A9&5R*&%R<F%Y*"DI(&%S("1H96%D
M(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@D:&5A
M9"P@)'9A;"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!L:7-T(&]F(&%D9')E<W-E<R!F;W(@82!H96%D97(@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;V)S("!!;B!A<G)A>2!O
M9B!H96%D97(@;V)J96-T<R`H4V5E(&EM87!?:&5A9&5R:6YF;R@I"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@9F]R('1H92!O8FIE8W0@<W1R=6-T=7)E
M*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!O
M8FIE8W1S+@H@("`@("H@/'!R93X*("`@("`J($]B:F5C="!E;&5M96YT<SH*
M("`@("`J("=A9&1R97-S)R`@("T@($9U;&P@861D<F5S<PH@("`@("H@)VAO
M<W0G("`@("`@+2`@2&]S="!N86UE"B`@("`@*B`G:6YN97(G("`@("`M("!4
M<FEM;65D+"!B87)E(&%D9')E<W,*("`@("`J("=P97)S;VYA;"<@("T@(%!E
M<G-O;F%L('-T<FEN9PH@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%D9')E<W-E<T9R;VU/8FIE8W0H)&]B<RD*("`@('L*("`@("`@
M("`D<F5T07)R87D@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1O8G,I('Q\(&5M<'1Y*"1O8G,I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5T07)R87D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D;V)S(&%S
M("1O8BD@>PH@("`@("`@("`@("`O*B!%;G-U<F4@=V4G<F4@=V]R:VEN9R!W
M:71H(&EN:71I86QI>F5D('9A;'5E<RX@*B\*("`@("`@("`@("`@:68@*&ES
M<V5T*"1O8BT^<&5R<V]N86PI*2!["B`@("`@("`@("`@("`@("`D;V(M/G!E
M<G-O;F%L(#T@34E-13HZ9&5C;V1E*"1O8BT^<&5R<V]N86PI.PH@("`@("`@
M("`@("`@("`@:68@*"AS=6)S='(H)&]B+3YP97)S;VYA;"P@,"P@,2D@/3T@
M)R(G*2`F)@H@("`@("`@("`@("`@("`@("`@("AS=6)S='(H)&]B+3YP97)S
M;VYA;"P@+3$I(#T]("<B)RDI('L*("`@("`@("`@("`@("`@("`@("`D;V(M
M/G!E<G-O;F%L(#T@<W5B<W1R*"1O8BT^<&5R<V]N86PL(#$L("TQ*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1O8BT^<&5R<V]N86P@/2`G)SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*&ES<V5T*"1O8BT^;6%I;&)O>"DI('L*("`@("`@("`@
M("`@("`@("\J($1O;B=T('!R;V-E<W,@:6YV86QI9"!A9&1R97-S97,N("HO
M"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1O8BT^;6%I;&)O>"P@)U5.
M15A014-4141?1$%405]!1E1%4E]!1$1215-3)RD@(3T](&9A;'-E('Q\"B`@
M("`@("`@("`@("`@("`@("`@<W1R<&]S*"1O8BT^;6%I;&)O>"P@)TE.5D%,
M241?041$4D534R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&]B+3YM86EL8F]X(#T@)R<["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("@A:7-S970H)&]B+3YH;W-T*2D@
M>PH@("`@("`@("`@("`@("`@)&]B+3YH;W-T(#T@)R<["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J($=E;F5R871E('1H92!N97<@;V)J96-T+B`J
M+PH@("`@("`@("`@("`D;F5W3V(@/2`F;F5W('-T9$-L87-S.PH@("`@("`@
M("`@("`D;F5W3V(M/F%D9')E<W,@/2!-24U%.CIA9&1R3V)J96-T,E-T<FEN
M9R@D;V(L(&%R<F%Y*"=U;F1I<V-L;W-E9"UR96-I<&EE;G1S0"<L("=5;F1I
M<V-L;W-E9"!R96-I<&EE;G1S0"<I*3L*("`@("`@("`@("`@)&YE=T]B+3YH
M;W-T(#T@)&]B+3YH;W-T.PH@("`@("`@("`@("`D;F5W3V(M/FEN;F5R(#T@
M34E-13HZ=')I;45M86EL061D<F5S<RA-24U%.CIR9F,X,C)7<FET94%D9')E
M<W,H)&]B+3YM86EL8F]X+"`D;V(M/FAO<W0L("<G*2D["B`@("`@("`@("`@
M("1N97=/8BT^<&5R<V]N86P@/2`D;V(M/G!E<G-O;F%L.PH*("`@("`@("`@
M("`@)')E=$%R<F%Y6UT@/2`F)&YE=T]B.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R971!<G)A>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&QI<W0@;V8@=F%L:60@;6%I;&EN9R!L:7-T(&AE861E<G,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@=F%L:60@
M;6%I;&EN9R!L:7-T(&AE861E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M<W1(96%D97)S*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH"B`@("`@
M("`@("`@("\J(%)&0R`R,S8Y("HO"B`@("`@("`@("`@("=L:7-T+6AE;'`G
M("`@("`@("`@/3X@(%\H(DQI<W0M2&5L<"(I+`H@("`@("`@("`@("`G;&ES
M="UU;G-U8G-C<FEB92<@(#T^("!?*"),:7-T+55N<W5B<V-R:6)E(BDL"B`@
M("`@("`@("`@("=L:7-T+7-U8G-C<FEB92<@("`@/3X@(%\H(DQI<W0M4W5B
M<V-R:6)E(BDL"B`@("`@("`@("`@("=L:7-T+6]W;F5R)R`@("`@("`@/3X@
M(%\H(DQI<W0M3W=N97(B*2P*("`@("`@("`@("`@)VQI<W0M<&]S="<@("`@
M("`@("`]/B`@7R@B3&ES="U0;W-T(BDL"B`@("`@("`@("`@("=L:7-T+6%R
M8VAI=F4G("`@("`@/3X@(%\H(DQI<W0M07)C:&EV92(I+`H@("`@("`@("`@
M("`O*B!21D,@,CDQ.2`J+PH@("`@("`@("`@("`G;&ES="UI9"<@("`@("`@
M("`@(#T^("!?*"),:7-T+4ED(BD*("`@("`@("`I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&\@86YY(&UA:6QI;F<@;&ES="!H96%D97)S(&5X:7-T/PH@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!A;GD@;6%I
M;&EN9R!L:7-T(&AE861E<G,@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QI<W1(96%D97)S17AI<W0H*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YL:7-T2&5A9&5R<R@I(&%S("1V86P@/3X@)'-T<BD@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]H96%D97)S6R1V86Q=*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E=',@82!N97<@<W1R:6YG('1O('5S92!F;W(@14],<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;VP@(%1H92!S=')I;F<@=&\@=7-E
M(&9O<B!%3TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971%3TPH)&5O;"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V5O;"`]("1E;VP["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=')I;F<@=&\@=7-E
M(&9O<B!%3TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%3TPH*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5O;#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&9L86<@<W1A='5S+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&9L86<@($ES('1H:7,@9FQA9R!S970_"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!&;&%G<SH@<F5C96YT+"!U;G-E96XL
M(&%N<W=E<F5D+"!D<F%F="P@:6UP;W)T86YT+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&9L86<@:&%S(&)E96X@<V5T+"!F
M86QS92!I9B!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9L86<H)&9L
M86<I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V9L86=S6U-T
M<FEN9SHZ;&]W97(H)&9L86<I72DI('L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<')I
M;6%R>2!F<F]M(&%D9')E<W,@*&9I<G-T(&%D9')E<W,@:6X@=&AE($9R;VTZ
M(&AE861E<BDN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F
M<F]M(&%D9')E<W,@*'5S97)`:&]S="DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$9R;VU!9&1R97-S*"D*("`@('L*("`@("`@("!I9B`H(2@D;V(@/2`D
M=&AI<RT^9V5T3V(H)V9R;VTG*2DI('L*("`@("`@("`@("`@<F5T=7)N(&YU
M;&P["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)
M344N<&AP)SL*"B`@("`@("`@<F5T=7)N('1R:6TH34E-13HZ=')I;45M86EL
M061D<F5S<RA-24U%.CIR9F,X,C)7<FET94%D9')E<W,H)&]B6S!=+3YM86EL
M8F]X+"`H:7-S970H)&]B6S!=+3YH;W-T*2D@/R`D;V);,%TM/FAO<W0@.B`G
M)RP@)R<I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!H96%D97(@
M9G)O;2!T:&4@:&5A9&5R(&]B:F5C="X*("`@("`J"B`@("`@*B!`=&]D;R!2
M97!L86-E('=I=&@@9V5T3V(H*2!F<F]M($E-4"=S($E-4%](96%D97)S(&9O
M<B!(;W)D92`T+C`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEE
M;&0@("`@5&AE(&]B:F5C="!F:65L9"!T;R!R971R:65V92`H<V5E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!I;6%P7VAE861E<FEN9F\H*2!F
M;W(@=&AE(&QI<W0@;V8@9FEE;&1S*2X*("`@("`J($!P87)A;2!B;V]L96%N
M("1D96-O9&4@(%-H;W5L9"!T:&4@<F5T=7)N('9A;'5E(&)E($U)344@9&5C
M;V1E9#\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($ET('=I;&P@
M;VYL>2!B92!D96-O9&5D(&EF(&ET(&ES(&YO="!A;B!O8FIE8W0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&ET<V5L9BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@9FEE;&0@<F5Q=65S=&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971/8B@D9FEE;&0L("1D96-O9&4@/2!F86QS92D*
M("`@('L*("`@("`@("`D9&%T82`](&%R<F%Y*"D["@H@("`@("`@("1O8B`]
M("1T:&ES+3YG971(96%D97)/8FIE8W0H*3L*("`@("`@("!I9B`H(6ES7V]B
M:F5C="@D;V(I*2!["B`@("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D;V(M/B1F:65L9"DI('L*("`@("`@
M("`@("`@)&1A=&$@/2`D;V(M/B1F:65L9#L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D9&5C;V1E*2`F)B`A:7-?;V)J96-T*"1D871A*2`F)B`A:7-?87)R
M87DH)&1A=&$I*2!["B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@)TAO
M<F1E+TU)344N<&AP)SL*("`@("`@("`@("`@("`@("1D871A(#T@34E-13HZ
M9&5C;V1E*"1D871A*3L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)$=,
M3T)!3%-;)VUI;65?:&5A9&5R<R==6R=D969A=6QT7V-H87)S970G72DI('L*
M("`@("`@("`@("`@("`@("`@("`D9&%T82`](%-T<FEN9SHZ8V]N=F5R=$-H
M87)S970H)&1A=&$L("1'3$]"04Q36R=M:6UE7W-T<G5C='5R92==6R=D969A
M=6QT7V-H87)S970G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H:7-?<W1R:6YG*"1D871A
M*2D@/R!S=')T<B@D9&%T82P@(EQT(BP@)R`G*2`Z("1D871A.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]-86=I8RYP:'``````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P-38U`#$P-#$W,S8R
M-S<S`#`R,#4R,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?36%G:6,Z.B!C;&%S<R!P
M<F]V:61E<R!A;B!I;G1E<F9A8V4@=&\@9&5T97)M:6YE(&$*("H@34E-12!T
M>7!E(&9O<B!V87)I;W5S(&-O;G1E;G0L(&EF(&ET('!R;W9I9&5D('=I=&@@
M9&EF9F5R96YT"B`J(&QE=F5L<R!O9B!I;F9O<FUA=&EO;BX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+TUA9VEC+G!H<"QV(#$N-3(N."XQ
M,B`R,#`V+S`Q+S`Q(#(Q.C(X.C(T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO
M<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R
M9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O
M<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?34E-10H@*B\*8VQA<W,@34E-15]-86=I8R!["@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@8V]P>2!O9B!T:&4@34E-12!E>'1E;G-I
M;VX@;6%P+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!-24U%(&5X=&5N<VEO;B!M87`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9?9V5T36EM945X=&5N<VEO;DUA<"@I
M"B`@("!["B`@("`@("`@<W1A=&EC("1M:6UE7V5X=&5N<VEO;E]M87`["@H@
M("`@("`@(&EF("@A:7-S970H)&UI;65?97AT96YS:6]N7VUA<"DI('L*("`@
M("`@("`@("`@<F5Q=6ER92!D:7)N86UE*%]?1DE,15]?*2`N("<O;6EM92YM
M87!P:6YG+G!H<"<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&UI;65?
M97AT96YS:6]N7VUA<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!C;W!Y(&]F('1H92!-24U%(&UA9VEC(&9I;&4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE($U)344@;6%G:6,@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]G
M971-:6UE36%G:6-&:6QE*"D*("`@('L*("`@("`@("!S=&%T:6,@)&UI;65?
M;6%G:6,["@H@("`@("`@(&EF("@A:7-S970H)&UI;65?;6%G:6,I*2!["B`@
M("`@("`@("`@(')E<75I<F4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+VUI;64N
M;6%G:6,N<&AP)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;6EM95]M
M86=I8SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'0@=&\@8V]N=F5R
M="!A(&9I;&4@97AT96YS:6]N('1O(&$@34E-12!T>7!E+"!B87-E9`H@("`@
M("H@;VX@=&AE(&=L;V)A;"!(;W)D92!A;F0@87!P;&EC871I;VX@<W!E8VEF
M:6,@8V]N9FEG(&9I;&5S+@H@("`@("H*("`@("`J($EF('=E(&-A;FYO="!M
M87`@=&AE(&9I;&4@97AT96YS:6]N('1O(&$@<W!E8VEF:6,@='EP92P@=&AE
M;@H@("`@("H@=V4@9F%L;"!B86-K('1O(&$@8W5S=&]M($U)344@:&%N9&QE
M<B`G>"UE>'1E;G-I;VXO)&5X="<L('=H:6-H"B`@("`@*B!C86X@8F4@=7-E
M9"!A<R!A(&YO<FUA;"!-24U%('1Y<&4@:6YT97)N86QL>2!T:')O=6=H;W5T
M($AO<F1E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5X="`@5&AE
M(&9I;&4@97AT96YS:6]N('1O(&)E(&UA<'!E9"!T;R!A($U)344@='EP92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@='EP92!O
M9B!T:&4@9FEL92!E>'1E;G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X
M=%1O34E-12@D97AT*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D97AT*2D@
M>PH@("`@("`@("`@(')E='5R;B`G87!P;&EC871I;VXO;V-T970M<W1R96%M
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97AT(#T@4W1R:6YG
M.CIL;W=E<B@D97AT*3L*("`@("`@("`@("`@)&UA<"`]("9-24U%7TUA9VEC
M.CI?9V5T36EM945X=&5N<VEO;DUA<"@I.PH@("`@("`@("`@("`D<&]S(#T@
M,#L*("`@("`@("`@("`@=VAI;&4@*"%I<W-E="@D;6%P6R1E>'1=*2`F)B`D
M<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'!O<R`]('-T<G!O
M<R@D97AT+"`G+B<I.PH@("`@("`@("`@("`@("`@:68@*"1P;W,@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&5X="`]('-U8G-T<B@D97AT
M+"`D<&]S("L@,2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("AI<W-E="@D;6%P6R1E>'1=*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1M87!;)&5X=%T["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@)W@M97AT96YS:6]N+R<@+B`D
M97AT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP="!T;R!C;VYV97)T(&$@9FEL96YA;64@=&\@82!-24U%
M('1Y<&4L(&)A<V5D(&]N('1H92!G;&]B86P@2&]R9&4*("`@("`J(&%N9"!A
M<'!L:6-A=&EO;B!S<&5C:69I8R!C;VYF:6<@9FEL97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE;F%M92!T;R!B
M92!M87!P960@=&\@82!-24U%('1Y<&4N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D=6YK;F]W;B`@2&]W('-H;W5L9"!U;FMN;W=N(&5X=&5N<VEO;G,@8F4@
M:&%N9&QE9#\@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T
M<G5E+"!W:6QL(')E='5R;B`G>"UE>'1E;G-I;VXO*B<@='EP97,N("!)9@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"!W:6QL(')E
M='5R;B`G87!P;&EC871I;VXO;V-T970M<W1R96%M)RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@='EP92!O9B!T:&4@9FEL96YA
M;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I;&5N86UE5&]-24U%*"1F:6QE
M;F%M92P@)'5N:VYO=VX@/2!T<G5E*0H@("`@>PH@("`@("`@("1P;W,@/2!S
M=')L96XH)&9I;&5N86UE*2`K(#$["B`@("`@("`@)'1Y<&4@/2`G)SL*"B`@
M("`@("`@)&UA<"`]("9-24U%7TUA9VEC.CI?9V5T36EM945X=&5N<VEO;DUA
M<"@I.PH@("`@("`@(&9O<B`H)&D@/2`P.PH@("`@("`@("`@("`@)&D@/#T@
M)&UA<%LG7U]-05A015))3T1?7R==("8F"B`@("`@("`@("`@("`@("`@<W1R
M<G!O<RAS=6)S='(H)&9I;&5N86UE+"`P+"`D<&]S("T@,2DL("<N)RD@(3T]
M(&9A;'-E.PH@("`@("`@("`@("`@)&DK*RD@>PH@("`@("`@("`@("`D<&]S
M(#T@<W1R<G!O<RAS=6)S='(H)&9I;&5N86UE+"`P+"`D<&]S("T@,2DL("<N
M)RD@*R`Q.PH@("`@("`@('T*("`@("`@("`D='EP92`]($U)345?36%G:6,Z
M.F5X=%1O34E-12AS=6)S='(H)&9I;&5N86UE+"`D<&]S*2D["@H@("`@("`@
M(&EF("AE;7!T>2@D='EP92D@?'P*("`@("`@("`@("`@*"$D=6YK;F]W;B`F
M)B`H<W1R<&]S*"1T>7!E+"`G>"UE>'1E;G-I;VXG*2`A/3T@9F%L<V4I*2D@
M>PH@("`@("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A
M;2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T>7!E
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'0@=&\@
M8V]N=F5R="!A($U)344@='EP92!T;R!A(&9I;&4@97AT96YS:6]N+"!B87-E
M9`H@("`@("H@;VX@=&AE(&=L;V)A;"!(;W)D92!A;F0@87!P;&EC871I;VX@
M<W!E8VEF:6,@8V]N9FEG(&9I;&5S+@H@("`@("H*("`@("`J($EF('=E(&-A
M;FYO="!M87`@=&AE('1Y<&4@=&\@82!F:6QE(&5X=&5N<VEO;BP@=V4@<F5T
M=7)N(&9A;'-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M(%1H92!-24U%('1Y<&4@=&\@8F4@;6%P<&5D('1O(&$@9FEL92!E>'1E;G-I
M;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F:6QE(&5X
M=&5N<VEO;B!O9B!T:&4@34E-12!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!-24U%5&]%>'0H)'1Y<&4I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T
M>7!E*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D:V5Y(#T@87)R87E?<V5A<F-H*"1T>7!E+"!-24U%7TUA9VEC
M.CI?9V5T36EM945X=&5N<VEO;DUA<"@I*3L*("`@("`@("!I9B`H)&ME>2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@;&ES="@D;6%J;W(L("1M:6YO<BD@
M/2!E>'!L;V1E*"<O)RP@)'1Y<&4I.PH@("`@("`@("`@("!I9B`H)&UA:F]R
M(#T]("=X+65X=&5N<VEO;B<I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M;6EN;W(["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*'-T<G!O<R@D
M;6EN;W(L("=X+2<I(#T]/2`P*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M<W5B<W1R*"1M:6YO<BP@,BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D:V5Y.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5S
M97,@=F%R:6%N=',@;V8@=&AE(%5.25@@(F9I;&4B(&-O;6UA;F0@=&\@871T
M96UP="!T;R!D971E<FUI;F4@=&AE"B`@("`@*B!-24U%('1Y<&4@;V8@86X@
M=6YK;F]W;B!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@("`@("!4:&4@<&%T:"!T;R!T:&4@9FEL92!T;R!A;F%L>7IE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6%G:6-?9&(@(%!A=&@@=&\@=&AE(&UI;64@
M;6%G:6,@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!-24U%('1Y<&4@;V8@=&AE(&9I;&4N("!2971U<FYS(&9A;'-E(&EF
M('1H92!F:6QE"B`@("`@*B`@("`@("`@("`@("`@("`@='EP92!I<VXG="!R
M96-O9VYI>F5D(&]R(&%N(&5R<F]R(&AA<'!E;F5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A;F%L>7IE1FEL92@D<&%T:"P@)&UA9VEC7V1B(#T@;G5L;"D*
M("`@('L*("`@("`@("`O*B!)9B!T:&4@4$A0($UI;65T>7!E(&5X=&5N<VEO
M;B!I<R!A=F%I;&%B;&4L('5S92!T:&%T+B`J+PH@("`@("`@(&EF("A5=&EL
M.CIE>'1E;G-I;VY%>&ES=',H)V9I;&5I;F9O)RDI('L*("`@("`@("`@("`@
M:68@*&5M<'1Y*"1M86=I8U]D8BDI('L*("`@("`@("`@("`@("`@("1R97,@
M/2!`9FEN9F]?;W!E;BA&24Q%24Y&3U]-24U%*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R97,@/2!`9FEN9F]?;W!E;BA&24Q%
M24Y&3U]-24U%+"`D;6%G:6-?9&(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@D<F5S*2!["B`@("`@("`@("`@("`@("`D='EP92`](&9I;F9O
M7V9I;&4H)')E<RP@)'!A=&@I.PH@("`@("`@("`@("`@("`@9FEN9F]?8VQO
M<V4H)')E<RD["@H@("`@("`@("`@("`@("`@+RH@4F5M;W9E(&%N>2!A9&1I
M=&EO;F%L(&EN9F]R;6%T:6]N+B`J+PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H87)R87DH)SLG+"`G+"<L("=<7#`G*2!A<R`D<V5P87)A=&]R*2!["B`@
M("`@("`@("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D='EP92P@)'-E<&%R
M871O<BD["B`@("`@("`@("`@("`@("`@("`@:68@*"1P;W,@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@<G1R:6TH<W5B
M<W1R*"1T>7!E+"`P+"`D<&]S*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"=\7EMA+7HP+3E=*R];+BUA+7HP+3E=*R1\:2<L("1T>7!E*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D='EP93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*%5T
M:6PZ.F5X=&5N<VEO;D5X:7-T<R@G;6EM95]M86=I8R<I*2!["B`@("`@("`@
M("`@(')E='5R;B!T<FEM*&UI;65?8V]N=&5N=%]T>7!E*"1P871H*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@57-E(&$@8G5I;'0M:6X@
M;6%G:6,@9FEL92X@*B\*("`@("`@("`@("`@)&UI;65?;6%G:6,@/2`F34E-
M15]-86=I8SHZ7V=E=$UI;65-86=I8T9I;&4H*3L*("`@("`@("`@("`@:68@
M*"$H)&9P(#T@0&9O<&5N*"1P871H+"`G<F(G*2DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F
M;W)E86-H("@D;6EM95]M86=I8R!A<R`D;V9F<V5T(#T^("1O9&%T82D@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&]D871A(&%S("1L96YG=&@@/3X@
M)&QD871A*2!["B`@("`@("`@("`@("`@("`@("`@0&9S965K*"1F<"P@)&]F
M9G-E="P@4T5%2U]3150I.PH@("`@("`@("`@("`@("`@("`@("1L;V]K=7`@
M/2!`9G)E860H)&9P+"`D;&5N9W1H*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1L9&%T85LD;&]O:W5P72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D;&1A=&%;)&QO;VMU<%T["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&9C;&]S92@D9G`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*"B`@("`O*BH*("`@("`J(%5S97,@=F%R:6%N=',@;V8@=&AE
M(%5.25@@(F9I;&4B(&-O;6UA;F0@=&\@871T96UP="!T;R!D971E<FUI;F4@
M=&AE"B`@("`@*B!-24U%('1Y<&4@;V8@86X@=6YK;F]W;B!B>71E('-T<F5A
M;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("`@5&AE
M(&9I;&4@9&%T82!T;R!A;F%L>7IE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;6%G:6-?9&(@(%!A=&@@=&\@=&AE(&UI;64@;6%G:6,@9&%T86)A<V4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%('1Y<&4@;V8@
M=&AE(&9I;&4N("!2971U<FYS(&9A;'-E(&EF('1H92!F:6QE"B`@("`@*B`@
M("`@("`@("`@("`@("`@='EP92!I<VXG="!R96-O9VYI>F5D(&]R(&%N(&5R
M<F]R(&AA<'!E;F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!A;F%L>7IE1&%T
M82@D9&%T82P@)&UA9VEC7V1B(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!)
M9B!T:&4@4$A0($UI;65T>7!E(&5X=&5N<VEO;B!I<R!A=F%I;&%B;&4L('5S
M92!T:&%T+B`J+PH@("`@("`@(&EF("A5=&EL.CIE>'1E;G-I;VY%>&ES=',H
M)V9I;&5I;F9O)RDI('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1M86=I8U]D
M8BDI('L*("`@("`@("`@("`@("`@("1R97,@/2!`9FEN9F]?;W!E;BA&24Q%
M24Y&3U]-24U%*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1R97,@/2!`9FEN9F]?;W!E;BA&24Q%24Y&3U]-24U%+"`D;6%G:6-?
M9&(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)')E<RD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D='EP92`](&9I;F9O7V)U9F9E<B@D<F5S+"`D9&%T82D[
M"B`@("`@("`@("`@(&9I;F9O7V-L;W-E*"1R97,I.PH*("`@("`@("`@("`@
M+RH@4F5M;W9E(&%N>2!A9&1I=&EO;F%L(&EN9F]R;6%T:6]N+B`J+PH@("`@
M("`@("`@("`D<&]S(#T@<W1R<&]S*"1T>7!E+"`G.R<I.PH@("`@("`@("`@
M("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T>7!E
M(#T@<G1R:6TH<W5B<W1R*"1T>7!E+"`P+"`D<&]S*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D='EP92P@)RPG*3L*("`@
M("`@("`@("`@:68@*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`D='EP92`](')T<FEM*'-U8G-T<B@D='EP92P@,"P@)'!O<RDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D='EP93L*("`@("`@("!]
M"@H@("`@("`@("\J(%5S92!A(&)U:6QT+6EN(&UA9VEC(&9I;&4N("HO"B`@
M("`@("`@)&UI;65?;6%G:6,@/2`F34E-15]-86=I8SHZ7V=E=$UI;65-86=I
M8T9I;&4H*3L*("`@("`@("!F;W)E86-H("@D;6EM95]M86=I8R!A<R`D;V9F
M<V5T(#T^("1O9&%T82D@>PH@("`@("`@("`@("!F;W)E86-H("@D;V1A=&$@
M87,@)&QE;F=T:"`]/B`D;&1A=&$I('L*("`@("`@("`@("`@("`@("1L;V]K
M=7`@/2!S=6)S='(H)&1A=&$L("1O9F9S970L("1L96YG=&@I.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D;&1A=&%;)&QO;VMU<%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1L9&%T85LD;&]O:W5P73L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<```````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(T,C0Q`#$P-#$W,S8R-S<S`#`R,3`V
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]087)T
M+G!H<"<["@HO*BH*("H@5&AE($U)345?365S<V%G93HZ(&-L87-S('!R;W9I
M9&5S(&UE=&AO9',@9F]R(&-R96%T:6YG(&%N9"!M86YI<'5L871I;F<*("H@
M34E-12!E;6%I;"!M97-S86=E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP+'8@,2XW-BXQ,"XQ,B`R,#`V+S`Q+S`Q
M(#(Q.C(X.C(T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%
M"B`J+PIC;&%S<R!-24U%7TUE<W-A9V4@97AT96YD<R!-24U%7U!A<G0@>PH*
M("`@("\J*@H@("`@("H@2&%S('1H92!M97-S86=E(&)E96X@<&%R<V5D('9I
M82!B=6EL9$UE<W-A9V4H*3\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?8G5I;&0@/2!F86QS93L*"B`@("`O*BH*("`@
M("`J(%1H92!S97)V97(@=&\@9&5F875L="!U;G%U86QI9FEE9"!A9&1R97-S
M97,@=&\N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?9&5F875L=%-E<G9E<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<B`M(&-R96%T97,@82!N97<@34E-12!E;6%I;"!M97-S86=E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'1397)V97(@
M(%1H92!S97)V97(@=&\@9&5F875L="!U;G%U86QI9FEE9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@861D<F5S<V5S('1O+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!-24U%7TUE<W-A9V4H)&1E9F%U;'1397)V97(@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1D969A=6QT4V5R
M=F5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1E9F%U;'1397)V97(@/2`D
M7U-%4E9%4ELG4T525D527TY!344G73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7V1E9F%U;'1397)V97(@/2`D9&5F875L=%-E<G9E
M<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!-
M24U%7TUE<W-A9V4@;V)J96-T(&9R;VT@82!-24U%7U!A<G0@;V)J96-T+@H@
M("`@("H@5&AI<R!F=6YC=&EO;B!C86X@8F4@8V%L;&5D('-T871I8V%L;'D@
M=FEA.@H@("`@("H@("`@34E-15]-97-S86=E.CIC;VYV97)T34E-15!A<G0H
M*3L*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T
M("!4:&4@34E-15]087)T(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@
M)'-E<G9E<B`@("`@("`@(%1H92!S97)V97(@=&\@9&5F875L="!U;G%U86QI
M9FEE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D
M<F5S<V5S('1O+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]-97-S86=E
M("!4:&4@;F5W($U)345?365S<V%G92!O8FIE8W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9C;VYV97)T34E-15!A<G0H)B1M:6UE7W!A<G0L("1S97)V97(@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A)&UI;65?<&%R="T^9V5T34E-
M14ED*"DI('L*("`@("`@("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED*#$I
M.PH@("`@("`@('T*"B`@("`@("`@)&UI;65?;65S<V%G92`]("9N97<@34E-
M15]-97-S86=E*"1S97)V97(I.PH@("`@("`@("1M:6UE7VUE<W-A9V4M/F%D
M9%!A<G0H)&UI;65?<&%R="D["B`@("`@("`@)&UI;65?;65S<V%G92T^8G5I
M;&1-97-S86=E*"D["@H@("`@("`@(')E='5R;B`D;6EM95]M97-S86=E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@=&AI<R!M97-S86=E+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&5M86EL("`@(%1H92!A9&1R97-S
M(&QI<W0@=&\@<V5N9"!T;RX*("`@("`J($!P87)A;2!M:7AE9"`F)&AE861E
M<G,@(%1H92!-24U%7TAE861E<G,@;V)J96-T(&AO;&1I;F<@=&AI<R!M97-S
M86=E)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&AE861E<G,L
M(&]R(&$@:&%S:"!W:71H(&AE861E<BT^=F%L=64@;6%P<&EN9W,N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D<FEV97(@("!4:&4@36%I;"!D<FEV97(@=&\@
M=7-E("AS:6YC92!(;W)D92`S+C`N-"DN"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@("!!;GD@<&%R86UE=&5R<R!N96-E<W-A<GD@9F]R('1H92!-
M86EL(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@*'-I
M;F-E($AO<F1E(#,N,"XT*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E;F0H)&5M86EL+"`F)&AE861E<G,L("1D<FEV
M97(@/2!N=6QL+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8["B`@("`@("`@<W1A=&EC("1M86EL97(["@H@("`@("`@
M(&EF("@A:7-S970H)&UA:6QE<BDI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=-86EL+G!H<"<["B`@("`@("`@("`@(&EF("@A:7-S970H)&1R:79E
M<BDI('L*("`@("`@("`@("`@("`@("1D<FEV97(@/2`D8V]N9ELG;6%I;&5R
M)UU;)W1Y<&4G73L*("`@("`@("`@("`@("`@("1P87)A;7,@/2`D8V]N9ELG
M;6%I;&5R)UU;)W!A<F%M<R==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1M86EL97(@/2!-86EL.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@
M("`@("`@('T*"B`@("`@("`@)&US9R`]("1T:&ES+3YT;U-T<FEN9R@I.PH@
M("`@("`@(&EF("AI<U]O8FIE8W0H)&AE861E<G,I*2!["B`@("`@("`@("`@
M("1H96%D97)!<G)A>2`]("1T:&ES+3YE;F-O9&4H)&AE861E<G,M/G1O07)R
M87DH*2P@)'1H:7,M/F=E=$-H87)S970H*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&AE861E<D%R<F%Y(#T@)'1H:7,M/F5N8V]D92@D:&5A
M9&5R<RP@)'1H:7,M/F=E=$-H87)S970H*2D["B`@("`@("`@?0H*("`@("`@
M("`O*B!-86ME('-U<F4@=&AE(&UE<W-A9V4@:&%S(&$@=')A:6QI;F<@;F5W
M;&EN92X@*B\*("`@("`@("!I9B`H<W5B<W1R*"1M<V<L("TQ*2`A/2`B7&XB
M*2!["B`@("`@("`@("`@("1M<V<@+CT@(EQN(CL*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2`D;6%I;&5R+3YS96YD*$U)344Z.F5N8V]D94%D9')E
M<W,H)&5M86EL*2P@)&AE861E<D%R<F%Y+"`D;7-G*3L*"B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2`F)@H@("`@("`@("`@("`D
M8V]N9ELG;6%I;&5R)UU;)W1Y<&4G72`]/2`G<V5N9&UA:6PG*2!["B`@("`@
M("`@("`@("\O($EN=&5R<')E="!R971U<FX@=F%L=65S(&%S(&1E9FEN960@
M:6X@+W5S<B]I;F-L=61E+W-Y<V5X:71S+F@*("`@("`@("`@("`@<W=I=&-H
M("@D<F5S=6QT+3YG971#;V1E*"DI('L*("`@("`@("`@("`@8V%S92`V-#H@
M+R\@15A?55-!1T4*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I
M;#H@)R`N(%\H(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(I("X@)R`H-C0I
M)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`V
M-3H@+R\@15A?1$%404524@H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E
M;F1M86EL.B`G("X@7R@B9&%T82!F;W)M870@97)R;W(B*2`N("<@*#8U*2<[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-C8Z
M("\O($587TY/24Y0550*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD
M;6%I;#H@)R`N(%\H(F-A;FYO="!O<&5N(&EN<'5T(BD@+B`G("@V-BDG.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8W.B`O
M+R!%6%].3U5315(*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I
M;#H@)R`N(%\H(F%D9')E<W-E92!U;FMN;W=N(BD@+B`G("@V-RDG.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8X.B`O+R!%
M6%].3TA/4U0*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@
M)R`N(%\H(FAO<W0@;F%M92!U;FMN;W=N(BD@+B`G("@V."DG.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8Y.B`O+R!%6%]5
M3D%604E,04),10H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL
M.B`G("X@7R@B<V5R=FEC92!U;F%V86EL86)L92(I("X@)R`H-CDI)SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W,#H@+R\@
M15A?4T]&5%=!4D4*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I
M;#H@)R`N(%\H(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(BD@+B`G("@W,"DG
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<Q
M.B`O+R!%6%]/4T524@H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M
M86EL.B`G("X@7R@B<WES=&5M(&5R<F]R(BD@+B`G("@W,2DG.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<R.B`O+R!%6%]/
M4T9)3$4*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N
M(%\H(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B*2`N("<@*#<R*2<[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-S,Z
M("\O($587T-!3E1#4D5!5`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E
M;F1M86EL.B`G("X@7R@B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(I("X@
M)R`H-S,I)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`W-#H@+R\@15A?24]%4E(*("`@("`@("`@("`@("`@("1E<G)O<B`]
M("=S96YD;6%I;#H@)R`N(%\H(FEN<'5T+V]U='!U="!E<G)O<B(I("X@)R`H
M-S0I)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`W-3H@+R\@15A?5$5-4$9!24P*("`@("`@("`@("`@("`@("1E<G)O<B`]
M("=S96YD;6%I;#H@)R`N(%\H(G1E;7!O<F%R>2!F86EL=7)E(BD@+B`G("@W
M-2DG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M(#<V.B`O+R!%6%]04D]43T-/3`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@
M)W-E;F1M86EL.B`G("X@7R@B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(BD@
M+B`G("@W-BDG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E(#<W.B`O+R!%6%].3U!%4DT*("`@("`@("`@("`@("`@("1E<G)O
M<B`]("=S96YD;6%I;#H@)R`N(%\H(G!E<FUI<W-I;VX@9&5N:65D(BD@+B`G
M("@W-RDG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E(#<X.B`O+R!%6%]#3TY&24<*("`@("`@("`@("`@("`@("1E<G)O<B`]
M("=S96YD;6%I;#H@)R`N(%\H(F-O;F9I9W5R871I;VX@97)R;W(B*2`N("<@
M*#<X*2<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@-SDZ("\O($587TY/5$9/54Y$"B`@("`@("`@("`@("`@("`D97)R;W(@
M/2`G<V5N9&UA:6PZ("<@+B!?*")E;G1R>2!N;W0@9F]U;F0B*2`N("<@*#<Y
M*2<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("`D97)R;W(@/2`D<F5S=6QT.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1E
M<G)O<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1A:V4@82!S970@;V8@:&5A9&5R<R!A;F0@
M;6%K92!S=7)E('1H97D@87)E(&5N8V]D960@<')O<&5R;'DN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97)S("`@5&AE(&AE861E<G,@=&\@
M96YC;V1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H
M87)A8W1E<B!S970@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!A<G)A>2!O9B!E;F-O9&5D(&AE861E<G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5N8V]D92@D:&5A9&5R<RP@)&-H87)S970I"B`@("!["B`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["@H@("`@("`@
M("1A9&1R97-S2V5Y<R`](&%R<F%Y*"=4;R<L("=#8R<L("="8V,G+"`G1G)O
M;2<I.PH@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("!I9B`H:6Y?87)R87DH)&ME>2P@)&%D9')E<W-+
M97ES*2D@>PH@("`@("`@("`@("`@("`@)'1E>'0@/2!-24U%.CIE;F-O9&5!
M9&1R97-S*"1V86PL("1C:&%R<V5T+"`D=&AI<RT^7V1E9F%U;'1397)V97(I
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)'1E>'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&5X="`]("1V86P["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&5X="`]($U)344Z.F5N8V]D92@D=F%L+"`D8VAA<G-E="D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&AE861E<G-;)&ME>5T@/2!-24U%
M.CIW<F%P2&5A9&5R<R@D:V5Y+"`D=&5X="P@)'1H:7,M/F=E=$5/3"@I*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:&5A9&5R<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9"!T:&4@<')O<&5R('-E="!O9B!-24U%(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92!T;R!A;B!A<G)A>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&AE861E<G,@(%1H92!H96%D97)S('1O(&%D9"!T
M:&4@34E-12!H96%D97)S('1O+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!F=6QL('-E="!O9B!H96%D97)S(&EN8VQU9&EN9R!-24U%(&AE
M861E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AE861E<B@D:&5A9&5R<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@+RH@4&5R(%)&0R`R,#0U(%LT72P@
M=&AI<R!-55-4(&%P<&5A<B!I;B!T:&4@;65S<V%G92!H96%D97)S+B`J+PH@
M("`@("`@("1H96%D97)S6R=-24U%+59E<G-I;VXG72`]("<Q+C`G.PH*("`@
M("`@("!I9B`H)'1H:7,M/E]B=6EL9"D@>PH@("`@("`@("`@("!R971U<FX@
M<&%R96YT.CIH96%D97(H)&AE861E<G,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YE;F-O9&4H)'1H:7,M/FAE861E<B@D:&5A9&5R<RDL
M("1T:&ES+3YG971#:&%R<V5T*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@96YT:7)E(&UE<W-A9V4@8V]N=&5N=',L
M(&EN8VQU9&EN9R!H96%D97)S+"!A<R!A('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N8V]D960L(&=E;F5R871E9"!M97-S
M86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?8G5I;&0I('L*("`@("`@("`@("`@<F5T=7)N
M('!A<F5N=#HZ=&]3=')I;F<H9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YT;U-T<FEN9R@I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($)U:6QD(&UE<W-A9V4@9G)O;2!C=7)R96YT(&-O;G1E
M;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9$UE<W-A9V4H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V)U:6QD*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V9L
M86=S6R=S9714>7!E)UTI*2!["B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI
M<RT^7W!A<G1S*2`^(#$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9714
M>7!E*"=M=6QT:7!A<G0O;6EX960G*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("\J($-O<'D@=&AE(&EN9F]R;6%T:6]N(&9R;VT@
M=&AE('-I;F=L92!P87)T('1O('1H92!C=7)R96YT"B`@("`@("`@("`@("`@
M("`@("!B87-E('!A<G0N("HO"B`@("`@("`@("`@("`@("!I9B`H*"1O8E9A
M<G,@/2!G971?;V)J96-T7W9A<G,H<F5S970H)'1H:7,M/E]P87)T<RDI*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O8E9A<G,@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3XD
M:V5Y(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-E
M="!T:&4@8G5I;&0@9FQA9R!N;W<N("HO"B`@("`@("`@)'1H:7,M/E]B=6EL
M9"`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F
M(&%L;"!-24U%('-U8G!A<G1S+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%N(&%R<F%Y(&]F('1H92!-24U%7U!A<G0@<W5B<&%R=',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!A<G1S*"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/E]B=6EL9"D@>PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIG
M971087)T<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG
M971087)T<R@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@8F%S92!P87)T(&]F('1H92!M97-S86=E+B!4:&ES(&9U;F-T
M:6]N(&1O97,@3D]4"B`@("`@*B!R971U<FX@82!R969E<F5N8V4@=&\@;6%K
M92!S=7)E('1H870@=&AE('=H;VQE($U)345?365S<V%G90H@("`@("H@;V)J
M96-T(&ES;B=T(&%C8VED96YT86QL>2!M;V1I9FEE9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N($U)345?365S<V%G92`@5&AE(&)A<V4@34E-15]087)T(&]F
M('1H92!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971"87-E4&%R
M="@I"B`@("!["B`@("`@("`@)'1H:7,M/F)U:6QD365S<V%G92@I.PH@("`@
M("`@(')E='5R;B`D=&AI<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I
M979E(&$@<W!E8VEF:6,@34E-12!P87)T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ED("!4:&4@34E-15]087)T($E$('-T<FEN9RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@5&AE($U)345?4&%R="!R97%U
M97-T960L(&]R(&9A;'-E(&EF('1H92!P87)T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F=E=%!A<G0H)&ED*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V)U:6QD
M*2!["B`@("`@("`@("`@("1P87)T(#T@<&%R96YT.CIG971087)T*"1I9"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F)U:6QD365S
M<V%G92@I.PH@("`@("`@("`@("`D<&%R="`]("1T:&ES+3YG971087)T*"1I
M9"D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1P87)T+"`G34E-15]-
M97-S86=E)RDI('L*("`@("`@("`@("`@)&YE=W!A<G0@/2`F;F5W($U)345?
M4&%R="@I.PH@("`@("`@("`@("`D<VMI<"`](&%R<F%Y*"=?8G5I;&0G+"`G
M7V1E9F%U;'1397)V97(G*3L*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?
M:V5Y<RAG971?;V)J96-T7W9A<G,H)'!A<G0I*2!A<R`D:V5Y*2!["B`@("`@
M("`@("`@("`@("`O*B!)9VYO<F4@;&]C86P@=F%R:6%B;&5S('1H870@87)E
M;B=T(&$@<&%R="!O9B!T:&4@;W)I9VEN86P*("`@("`@("`@("`@("`@("`J
M(&-L87-S+B`J+PH@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D:V5Y
M+"`D<VMI<"DI('L*("`@("`@("`@("`@("`@("`@("`D;F5W<&%R="T^)&ME
M>2`]("8D<&%R="T^)&ME>3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)&YE=W!A<G0["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1P87)T.PH@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+VUI;64N;6%G
M:6,N<&AP````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C<T,S4`,3`T
M,3<S-C(W-S,`,#(Q-3$W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!$871A(&9I;&4@=7-E9"!B>2!-
M24U%7TUA9VEC.CHN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-
M12]M:6UE+FUA9VEC+G!H<"QV(#$N-2`R,#`T+S`S+S(P(#(R.C0U.C,W(&IA
M;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J+PHD;6EM95]M
M86=I8ULP75LS,%U;(EPQ-#5<,38V7#$T,5PQ-31<-#!<-#)<,30U7#$W,%PQ
M-#5<,30S7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ
M-31<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P
M;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,C1=6R)<,30U7#$V
M-EPQ-#%<,34T7#0P7#0R7#$T-5PQ-S!<,30U7#$T,UPT,%PU-UPQ-C5<,38S
M7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A
M<'!L:6-A=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LR,UU;(EPQ,#-<
M,34W7#$U-5PQ-35<,34W7#$U-EPT,%PQ-C-<,38U7#$T,EPQ-#1<,34Q7#$V
M,EPQ-#5<,30S7#$V-%PQ-3=<,38R7#$U,5PQ-#5<,38S7#<R7#0P(ET@/2`G
M=&5X="]X+7!A=&-H)SL*)&UI;65?;6%G:6-;,%U;,C-=6R)<-S5<-S1<,34T
M7#$U,5PQ-C-<,38T7#<V7#$U-EPW-%PQ-C!<,38R7#$U-UPQ-C1<,34W7#$T
M,UPQ-3=<,34T7#0P7#$T,EPQ-#)<,34V7#4U7#$U-2)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR,EU;(EPQ,#%<,3$U7#$P,5PQ
M,39<,3`T7#$P,5PW,EPT,%PQ,C1<,3`Q7#$R,%PQ,#5<,3(S7#$R-%PQ,#%<
M,3(R7#$R-%PT,%PQ,#1<,3`Q7#$R-%PQ,#4B72`]("=A<'!L:6-A=&EO;B]X
M+6%M86YD82UH96%D97(G.PHD;6EM95]M86=I8ULP75LR,EU;(EPQ,#=<,3`V
M7#8Q7#$R,%PQ,#%<,3(T7#$P,UPQ,3!<-C%<-C!<-C!<-C!<,3$Q7#$P-%PT
M,UPV,%PV,%PV,%PV,%PV,%PV,EPV,")=(#T@)V%U9&EO+W@M9W5S+7!A=&-H
M)SL*)&UI;65?;6%G:6-;,%U;,C)=6R)<,3`W7#$P-EPV,5PQ,C!<,3`Q7#$R
M-%PQ,#-<,3$P7#8Q7#8Q7#8P7#8P7#$Q,5PQ,#1<-#-<-C!<-C!<-C!<-C!<
M-C!<-C)<-C`B72`]("=A=61I;R]X+6=U<RUP871C:"<["B1M:6UE7VUA9VEC
M6S!=6S(R75LB7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<
M,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P
M(ET@/2`G87!P;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S(R75LB
M7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ
M-31<-3=<,30R7#$U,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P
M;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PQ
M,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T
M,EPQ-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N
M+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,C)=6R)<-#-<-#%<,3%<-3=<,38U
M7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X+7!E<FPG
M.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V
M,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$V
M-%PQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?
M;6%G:6-;,%U;,C)=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T
M7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V
M,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;
M,C)=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<
M,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]
M("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S
M7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<
M-3=<,30R7#$U,5PQ-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC
M871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PT,%PU
M-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ
M-3%<,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M
M<&5R;"<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#0P7#4W7#$V-5PQ
M-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<
M-3=<,38T7#$T,UPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC<V@G.PHD
M;6EM95]M86=I8ULP75LR,5U;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU
M-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ
M-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP
M75LR,5U;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T
M,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$W,EPQ-C-<,34P(ET@/2`G
M87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT
M,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W
M7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO
M>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT,5PT,%PU-UPQ-C5<
M,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V
M7#4W7#$W,EPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM
M95]M86=I8ULP75LR,5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<
M,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S
M7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LR
M,5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<
M,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P
M<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,C%=6R)<-#-<-#%<
M-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X
M+6%W:R<["B1M:6UE7VUA9VEC6S!=6S(Q75LB7#0S7#0Q7#4W7#$V-5PQ-C-<
M,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<
M,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI
M;65?;6%G:6-;,%U;,C%=6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<,34T
M7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C1<,30S7#$V
M,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=
M6S(P75LB7#$T-5PQ-C9<,30Q7#$U-%PT,%PT,EPQ-#5<,3<P7#$T-5PQ-#-<
M-#!<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P
M;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,C!=6R)<-#-<-#%<
M,3%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM
M95]M86=I8ULP75LR,%U;(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ
M-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-#4B
M72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S(P75LB7#0S7#0Q
M7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R
M7#$U,5PQ-39<-3=<,30Q7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+7-H
M)SL*)&UI;65?;6%G:6-;,%U;,C!=6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<
M-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-S)<
M,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M>G-H)SL*)&UI;65?;6%G:6-;
M,%U;,3E=6R)<,3`S7#$V,EPQ-#5<,30Q7#$V-%PQ-3%<,38V7#$T-5PT,%PQ
M,C9<,34W7#$U,5PQ-#-<,30U7#0P7#$P-EPQ-3%<,34T7#$T-2)=(#T@)V%U
M9&EO+W@M=F]C)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<-#%<-S1<,30Q7#$V
M,EPQ-#-<,34P7#<V7#$U-EPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<
M,3,W7#$S-UPQ,S=<,3`U(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE
M7VUA9VEC6S!=6S$Y75LB7#0Q7#<T7#$T,5PQ-C)<,30S7#$U,%PW-EPQ-39<
M,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPV-EPV-%PQ,#4B72`]
M("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<-#-<
M-#%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM
M95]M86=I8ULP75LQ.%U;(EPQ,#9<,34Q7#$Q-%PQ-#5<,3(S7#$V-%PQ,#%<
M,38R7#$R-%PQ-#9<,3$Q7#$U-%PQ,#5<,38S7#$R-%PQ-#%<,3(R7#$V-")=
M(#T@)W1E>'0O>"UA<'!L92UB:6YS8VEI)SL*)&UI;65?;6%G:6-;,%U;,3A=
M6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q
M7#$U-%PU-UPQ-C1<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S
M:"<["B1M:6UE7VUA9VEC6S!=6S$X75LB7#0U7#0Q7#$R,%PQ,C-<-35<,3`Q
M7#$T-%PQ-3=<,30R7#$T-5PQ,#9<,34W7#$U-EPQ-C1<-35<-C%<-39<-C`B
M72`]("=F;VYT+W1Y<&4Q)SL*)&UI;65?;6%G:6-;,%U;,3==6R)<-#-<-#%<
M-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-C1<
M,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA
M9VEC6S!=6S$V75LB7#$P-5PQ-S!<,38T7#$T-5PQ-39<,30T7#$T-5PQ-#1<
M-#!<,3$U7#$U-UPQ-#1<,38U7#$U-%PQ-#5<-S(B72`]("=A=61I;R]X+69T
M,BUM;V0G.PHD;6EM95]M86=I8ULP75LQ-EU;(EPQ,C-<,38T7#$T,5PQ-C)<
M,38T7#$P-EPQ-3=<,34V7#$V-%PQ,35<,30U7#$V-%PQ-C)<,34Q7#$T,UPQ
M-C,B72`]("=F;VYT+W@M<W5N;W,M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S$V
M75LB7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W
M7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI
M;65?;6%G:6-;,%U;,39=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<
M,30R7#$U,5PQ-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I
M;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ-EU;(EPT,UPT,5PQ,5PU-UPQ
M-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B
M72`]("=A<'!L:6-A=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LQ-EU;
M(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ
M-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE
M7VUA9VEC6S!=6S$V75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T
M,EPQ-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N
M+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,39=6R)<-#-<-#%<-#!<-3=<,38U
M7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@
M/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,39=6R)<
M-S1<,3$U7#$T,5PQ-3-<,30U7#$V,EPQ,#1<,34Q7#$T,UPQ-C1<,34Q7#$U
M-UPQ-39<,30Q7#$V,EPQ-S$B72`]("=A<'!L:6-A=&EO;B]X+69R86UE;6%K
M97(G.PHD;6EM95]M86=I8ULP75LQ-EU;(EPW-%PQ,35<,30Q7#$U,UPQ-#5<
M,38R7#$R,UPQ-#-<,38R7#$T-5PQ-#5<,34V7#$P-EPQ-3=<,34V7#$V-")=
M(#T@)V9O;G0O>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;,35=6R)<
M-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,30Q
M7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC
M6S!=6S$U75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<
M,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD
M;6EM95]M86=I8ULP75LQ-5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO
M;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$U75LB7#0S7#0Q7#4W7#$V-5PQ
M-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@
M)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,35=6R)<-#-<
M-#%<-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ
M-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;
M,%U;,31=6R)<-#%<-S1<,30Q7#$V,EPQ-#-<,34P7#<V7#$U-EPQ-#1<,30U
M7#$T,EPQ-3%<,30Q7#$U-B)=(#T@)V%P<&QI8V%T:6]N+W@M9'!K9R<["B1M
M:6UE7VUA9VEC6S!=6S$T75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T
M,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA
M=VLG.PHD;6EM95]M86=I8ULP75LQ-%U;(EPW-%PT,5PQ,#1<,3$W7#$P,UPQ
M,C1<,3,Q7#$R,%PQ,#5<-#!<,3$P7#$R-%PQ,35<,3$T(ET@/2`G=&5X="]H
M=&UL)SL*)&UI;65?;6%G:6-;,%U;,31=6R)<-S1<-#%<,30T7#$U-UPQ-#-<
M,38T7#$W,5PQ-C!<,30U7#0P7#$U,%PQ-C1<,34U7#$U-")=(#T@)W1E>'0O
M:'1M;"<["B1M:6UE7VUA9VEC6S!=6S$S75LB7#$P-UPQ,3%<,3$U7#$R,%PT
M,%PQ,#=<,38R7#$T,5PQ-#1<,34Q7#$T-5PQ-39<,38T(ET@/2`G87!P;&EC
M871I;VXO>"UG:6UP+6=R861I96YT)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<
M,3(R7#$T-5PQ-C1<,38U7#$V,EPQ-39<-35<,3(P7#$T,5PQ-C1<,34P7#<R
M(ET@/2`G;65S<V%G92]R9F,X,C(G.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT
M,UPT,5PQ,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ-3`B72`]
M("=A<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<
M-#%<,3%<-3=<,30R7#$U,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G
M87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT
M,5PQ,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A
M<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q
M7#$Q7#4W7#$T,EPQ-3%<,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P
M<&QI8V%T:6]N+W@M<&5R;"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q
M7#$Q7#4W7#$T,EPQ-3%<,34V7#4W7#$V-%PQ-#-<,38S7#$U,")=(#T@)V%P
M<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<
M-#!<-3=<,30R7#$U,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@/2`G87!P
M;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#0P
M7#4W7#$T,EPQ-3%<,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI
M8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<
M-3=<,30R7#$U,5PQ-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC
M871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU
M-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A
M=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU
M-UPQ-#)<,34Q7#$U-EPU-UPQ-C1<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A
M=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#$Q7#4W
M7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO
M>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,5U;(EPT,UPT,5PQ,5PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H
M)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<,3%<-3=<,30R7#$U,5PQ
M-39<-3=<,34S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS:"<["B1M
M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#0P7#4W7#$T,EPQ-3%<,34V7#4W
M7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M
M86=I8ULP75LQ,5U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#-<
M,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;
M,%U;,3%=6R)<-#-<-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<,34S7#$V,UPQ
M-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS:"<["B1M:6UE7VUA9VEC6S!=6S$Q
M75LB7#0S7#0Q7#4W7#$T,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S7#$U,")=
M(#T@)V%P<&QI8V%T:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LQ,5U;(EPT
M,UPT,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A
M<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q
M7#4W7#$T,EPQ-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI
M8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<
M,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I
M;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<,30R
M7#$U,5PQ-39<-3=<,38T7#$T,UPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO
M>"UC<V@G.PHD;6EM95]M86=I8ULP75LQ,%U;(EPQ,#)<,34Q7#$V-%PQ-35<
M,30Q7#$V,%PQ-#9<,34Q7#$U-%PQ-#4B72`]("=I;6%G92]U;FMN;W=N)SL*
M)&UI;65?;6%G:6-;,%U;,3!=6R)<,3(S7#$R-%PQ,#%<,3(R7#$R-%PQ,#9<
M,3$W7#$Q-EPQ,C1<-#`B72`]("=F;VYT+W@M8F1F)SL*)&UI;65?;6%G:6-;
M,%U;,3!=6R)<-#-<-#%<,3%<-3=<,30R7#$U,5PQ-39<-3=<,38R7#$T,R)=
M(#T@)W1E>'0O<V-R:7!T)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<
M,3%<-3=<,30R7#$U,5PQ-39<-3=<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N
M+W@M<V@G.PHD;6EM95]M86=I8ULP75LQ,%U;(EPT,UPT,5PT,%PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-C)<,30S(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M
M86=I8ULP75LQ,%U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C-<
M,34P(ET@/2`G87!P;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S$P
M75LB7#0S7#0Q7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G
M87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,%U;(EPT,UPT
M,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T
M:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<-3=<,30R
M7#$U,5PQ-39<-3=<,34S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS
M:"<["B1M:6UE7VUA9VEC6S!=6S$P75LB7#<T7#$Q-5PQ-#%<,34S7#$T-5PQ
M-C)<,3`V7#$U,5PQ-31<,30U(ET@/2`G87!P;&EC871I;VXO>"UF<F%M96UA
M:V5R)SL*)&UI;65?;6%G:6-;,%U;.5U;(EPQ,C)<,30U7#$T,UPQ-#5<,34Q
M7#$V-EPQ-#5<,30T7#<R(ET@/2`G;65S<V%G92]R9F,X,C(G.PHD;6EM95]M
M86=I8ULP75LY75LB7#$R,UPQ-C1<,30Q7#$V,EPQ-C1<,3`V7#$U-UPQ-39<
M,38T(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M86=I8ULP75LY
M75LB7#(Q,5PQ,31<,3,R7#$Q-UPP7#$U7#$R7#,R7#$R(ET@/2`G87!P;&EC
M871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-#-<-#%<-3=<,30R
M7#$U,5PQ-39<-3=<,38R7#$T,R)=(#T@)W1E>'0O<V-R:7!T)SL*)&UI;65?
M;6%G:6-;,%U;.5U;(EPT,UPT,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C-<,34P
M(ET@/2`G87!P;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6SE=6R)<
M-35<,38R7#$U-UPQ-35<-C%<,30V7#$V,UPU-5PV,")=(#T@)V%P<&QI8V%T
M:6]N+W@M9FEL97-Y<W1E;2<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-S1<,3`R
M7#$U-UPQ-3=<,34S7#$P-EPQ-3%<,34T7#$T-2)=(#T@)V%P<&QI8V%T:6]N
M+W@M9G)A;65M86ME<B<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,3$W7#$U-EPQ
M-31<,3<Q7#0P7#$U,5PQ-39<-#`B72`]("=T97AT+W@M<&%T8V@G.PHD;6EM
M95]M86=I8ULP75LX75LB7#$T-UPQ-3%<,34U7#$V,%PT,%PQ-S!<,30S7#$T
M-B)=(#T@)V%P<&QI8V%T:6]N+W@M9VEM<"UI;6%G92<["B1M:6UE7VUA9VEC
M6S!=6SA=6R)<,34U7#$V,UPQ-#=<,30S7#$T,5PQ-C1<-C!<-C$B72`]("=A
M<'!L:6-A=&EO;B]X+6QO8V%L92<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,S)<
M,30Q7#$V,EPQ-#-<,34P7#$U,5PQ-C9<,30U(ET@/2`G87!P;&EC871I;VXO
M9&%T82<["B1M:6UE7VUA9VEC6S!=6SA=6R)<-#%<-S1<,3(P7#$P-%PQ,#9<
M-S9<-#%<,34V(ET@/2`G87!P;&EC871I;VXO>"UP<F]F)SL*)&UI;65?;6%G
M:6-;,%U;.%U;(EPW-%PQ,35<,3$Q7#$P-EPQ,#9<,34Q7#$U-%PQ-#4B72`]
M("=A<'!L:6-A=&EO;B]X+69R86UE;6%K97(G.PHD;6EM95]M86=I8ULP75LW
M75LB7#$P,5PQ-C)<,38T7#$U,5PQ-#-<,34T7#$T-2)=(#T@)VUE<W-A9V4O
M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S==6R)<,3(P7#$P,UPQ,#1<,3,W7#$Q
M-UPQ,C!<,3`Q(ET@/2`G>"]X+7!H;W1O+6-D+6]V97)F:65W+69I;&4G.PHD
M;6EM95]M86=I8ULP75LW75LB7#,U,5PU-%PQ7#$Q,EPQ,#%<,3$U7#$Q(ET@
M/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S==6R)<-#%<
M-S1<,30Q7#$V,EPQ-#-<,34P7#<V(ET@/2`G87!P;&EC871I;VXO>"UA<B<[
M"B1M:6UE7VUA9VEC6S!=6S==6R)<-S)<-#!<,38S7#$U,%PQ-#5<,34T7#$U
M-")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LV75LB
M7#$Q-EPQ-C5<,3`V7#$U,5PQ-31<,30U(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6S9=6R)<,3$V7#,V-5PQ,#9<,S4Q7#$U-%PS
M-#4B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-EU;
M(EPV,%PV-UPV,%PV-UPV,%PV,2)=(#T@)V%P<&QI8V%T:6]N+W@M8W!I;R<[
M"B1M:6UE7VUA9VEC6S!=6S9=6R)<-C!<-C=<-C!<-C=<-C!<-C(B72`]("=A
M<'!L:6-A=&EO;B]X+6-P:6\G.PHD;6EM95]M86=I8ULP75LV75LB7#8P7#8W
M7#8P7#8W7#8P7#8W(ET@/2`G87!P;&EC871I;VXO>"UC<&EO)SL*)&UI;65?
M;6%G:6-;,%U;-EU;(EPW-%PQ,35<,30Q7#$U,UPQ-#5<,38R(ET@/2`G87!P
M;&EC871I;VXO>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPW
M-%PQ,C1<,3$Q7#$R-%PQ,31<,3`U(ET@/2`G=&5X="]H=&UL)SL*)&UI;65?
M;6%G:6-;,%U;-EU;(EPW-%PQ-C1<,34Q7#$V-%PQ-31<,30U(ET@/2`G=&5X
M="]H=&UL)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPP7#%<,%PP7#`B72`]("=F
M;VYT+W1T9B<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,%PT7#,V7#(Q,EPR,#`B
M72`]("=A<'!L:6-A=&EO;B]C;W)E)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ
M,#)<,3`Q7#$P,EPQ,S%<,3$T(ET@/2`G;65S<V%G92]X+6=N=2UR;6%I;"<[
M"B1M:6UE7VUA9VEC6S!=6S5=6R)<,3`R7#$P-5PQ,#=<,3$Q7#$Q-B)=(#T@
M)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#-<
M,34W7#$V,EPQ-#5<,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF
M:6QE)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#1<-C%<-39<-C!<,34B72`]
M("=F;VYT+W@M<W!E961O)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#9<,38R
M7#$U-UPQ-35<-S(B72`]("=M97-S86=E+W)F8S@R,B<["B1M:6UE7VUA9VEC
M6S!=6S5=6R)<,3$U7#$P,5PQ,C-<,3,W7#$R-2)=(#T@)V%U9&EO+W@M;75L
M=&EM871E+6UO9"<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,3(P7#$Q-UPQ,S9<
M,3(Q7#$T,")=(#T@)W1E>'0O=FYD+FUS+7=O<F0G.PHD;6EM95]M86=I8ULP
M75LU75LB7#$R,%PQ-#%<,38T7#$U,%PW,B)=(#T@)VUE<W-A9V4O;F5W<R<[
M"B1M:6UE7VUA9VEC6S!=6S5=6R)<,3,P7#$V,EPQ-#5<,30V7#<R(ET@/2`G
M;65S<V%G92]N97=S)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ-#1<,34Q7#$T
M-EPQ-#9<-#`B72`]("=T97AT+W@M<&%T8V@G.PHD;6EM95]M86=I8ULP75LU
M75LB7#(R-5PV-%PV,EPV,EPS,S8B72`]("=A<'!L:6-A=&EO;B]X+6QO8V%L
M92<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,S,V7#8R7#8R7#8T7#(R-2)=(#T@
M)V%P<&QI8V%T:6]N+W@M;&]C86QE)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW
M-%PQ,3!<,3`U7#$P,5PQ,#0B72`]("=T97AT+VAT;6PG.PHD;6EM95]M86=I
M8ULP75LU75LB7#<T7#$Q,%PQ,C1<,3$U7#$Q-")=(#T@)W1E>'0O:'1M;"<[
M"B1M:6UE7VUA9VEC6S!=6S5=6R)<-S1<,34P7#$T-5PQ-#%<,30T(ET@/2`G
M=&5X="]H=&UL)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW-%PQ-3!<,38T7#$U
M-5PQ-30B72`]("=T97AT+VAT;6PG.PHD;6EM95]M86=I8ULP75LU75LB7#<U
M7#<T7#$T,5PQ-C)<-S8B72`]("=A<'!L:6-A=&EO;B]X+6%R)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPP7#!<,%PS,30B72`]("=A<'!L:6-A=&EO;B]X+65X
M96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#!<-")=
M(#T@)V9O;G0O>"US;F8G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#$P
M-R)=(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#!<,%PQ7#$Q,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T
M86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<,5PQ,34B72`]
M("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,%PP7#%<,3$W(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A
M8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#(P,2)=(#T@
M)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT
M75LB7#!<,%PQ7#(P-R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M
M86=I8ULP75LT75LB7#!<,%PQ7#(V,R)=(#T@)W9I9&5O+VUP96<G.PHD;6EM
M95]M86=I8ULP75LT75LB7#!<,%PQ7#(W,B)=(#T@)W9I9&5O+VUP96<G.PHD
M;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#8B72`]("=A<'!L:6-A=&EO;B]X
M+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#(P
M,5PQ-30B72`]("=A<'!L:6-A=&EO;B]X+6%P;"UW;W)K<W!A8V4G.PHD;6EM
M95]M86=I8ULP75LT75LB7#!<,%PS-S=<,30U(ET@/2`G87!P;&EC871I;VXO
M>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PS-S=<
M,34U(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,%PP7#-<,S0W(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PS7#,V,R)=(#T@)V%P<&QI8V%T
M:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP
M7#$T-%PQ-C-<-38B72`]("=A=61I;R]B87-I8R<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,%PQ7#(R7#$R-R)=(#T@)V%P<&QI8V%T:6]N+V-O<F4G.PHD;6EM
M95]M86=I8ULP75LT75LB7#!<,C)<,S(V7#(P-R)=(#T@)VEM86=E+W@Q,2<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PS7#(S,UPS-34B72`]("=A<'!L:6-A
M=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#-<,C,S7#,U-B)=
M(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#!<
M-5PR-EPP(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,%PU7#(V7#<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPP7#5<-C%<,30R(ET@/2`G87!P;&EC871I;VXO>"UD
M8B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PV7#(U7#$T,2)=(#T@)V%P<&QI
M8V%T:6]N+W@M9&(G.PHD;6EM95]M86=I8ULP75LT75LB7#$P,UPQ,C1<,3$U
M7#$P-B)=(#T@)V%U9&EO+W@M8VUF)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ
M,#5<,3$U7#$Q-UPQ,#0B72`]("=A=61I;R]X+65M;V0G.PHD;6EM95]M86=I
M8ULP75LT75LB7#$P-EPQ,#9<,3$Q7#$Q-")=(#T@)V9O;G0O='1F)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPQ,#9<,3$W7#$Q-EPQ,C0B72`]("=F;VYT+W@M
M=F9O;G0G.PHD;6EM95]M86=I8ULP75LT75LB7#$P-UPQ,#1<,3`R7#$Q-2)=
M(#T@)V%P<&QI8V%T:6]N+W@M9V1B;2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,3`W7#$Q,5PQ,#9<-S`B72`]("=I;6%G92]G:68G.PHD;6EM95]M86=I8ULP
M75LT75LB7#$P7#$V7#$R7#$W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,3$P7#$R,%PQ,#%<,3$S(ET@/2`G87!P;&EC
M871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3$Q7#$Q,5PQ,39<
M-C$B72`]("=I;6%G92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,3%<
M,3$Q7#4R7#`B72`]("=I;6%G92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPQ,31<,3`T7#$Q,%PQ-3$B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPQ,31<,3(W7#$P-EPQ,38B72`]("=F;VYT+W1Y
M<&4Q)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,35<,3$U7#!<-3(B72`]("=I
M;6%G92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,35<,3$W7#$R-EPQ
M,3$B72`]("=V:61E;R]X+7-G:2UM;W9I92<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,3$U7#$R-%PQ-3!<,30T(ET@/2`G875D:6\O;6ED:2<["B1M:6UE7VUA
M9VEC6S!=6S1=6R)<,3$U7#(T-UPS-39<,S4P(ET@/2`G9F]N="]X+6AP+7=I
M;F1O=W,G.PHD;6EM95]M86=I8ULP75LT75LB7#$Q-EPQ,C1<,3(R7#$Q,R)=
M(#T@)V%U9&EO+W@M;75L=&ET<F%C:R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,3(P7#$Q,UPS7#0B72`]("=A<'!L:6-A=&EO;B]Z:7`G.PHD;6EM95]M86=I
M8ULP75LT75LB7#$R,EPQ,3%<,3`V7#$P-B)=(#T@)V%U9&EO+W@M=V%V)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C)<,30Q7#$V,EPT,2)=(#T@)V%P<&QI
M8V%T:6]N+W@M<F%R)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C-<,3(Q7#$R
M,UPQ,3`B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPQ,C1<,3`Q7#$P-%PQ,C,B72`]("=A<'!L:6-A=&EO;B]X+71A9',M
M9V%M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3(U7#$P,UPV,EPS,B)=(#T@
M)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#$R-5PQ
M,39<-C!<-C4B72`]("=A=61I;R]X+6UI:VUO9"UU;FDG.PHD;6EM95]M86=I
M8ULP75LT75LB7#$R7#$W7#$P7#$V(ET@/2`G87!P;&EC871I;VXO9&%T82<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,3,Q7#(T-EPQ-3)<,C(U(ET@/2`G>"]X
M+6EM86=E+7-U;BUR87-T97(G.PHD;6EM95]M86=I8ULP75LT75LB7#$T-5PS
M-S=<,%PP(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,34P7#$V,UPQ-3%<-C$B72`]("=I;6%G92]X+6IP96<M<')O<')I
M971A<GDG.PHD;6EM95]M86=I8ULP75LT75LB7#$V7#$P7#$W7#$R(ET@/2`G
M87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3<W7#$P
M-5PQ,31<,3`V(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#$W7#$R7#$V7#$P(ET@/2`G87!P;&EC
M871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,5PQ,S!<-#%<,C0V
M(ET@/2`G87!P;&EC871I;VXO8V]R92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,5PQ-#9<,30S7#$V,")=(#T@)V9O;G0O>"UP8V8G.PHD;6EM95]M86=I8ULP
M75LT75LB7#(Q,5PQ,C!<,3$V7#$P-R)=(#T@)VEM86=E+W@M<&YG)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPR,UPQ,C=<,C,R7#,Q-B)=(#T@)V%P<&QI8V%T
M:6]N+W@M9V1B;2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$P
M-")=(#T@)V9O;G0O>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPR,UPQ-S)<-3%<,3`W(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM
M95]M86=I8ULP75LT75LB7#(S7#$W,EPU,5PQ,C`B72`]("=F;VYT+W@M<W5N
M;W,M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$R,2)=
M(#T@)V9O;G0O>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR
M-%PR7#$S,5PS,2)=(#T@)V9O;G0O>"UL:6)G<G@G.PHD;6EM95]M86=I8ULP
M75LT75LB7#(V,%PV,5PV,UPQ-#`B72`]("=A<'!L:6-A=&EO;B]X+6)O;W1A
M8FQE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$P7#%<,3`B72`]("=A<'!L
M:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,EPQ,%PQ7#8B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL
M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,%PQ7#<B72`]("=A<'!L:6-A
M=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,EPQ,%PS-S=<,30U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3)<,5PQ,")=(#T@)V%P<&QI8V%T
M:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR
M7#$R7#%<-R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$R7#,W-UPQ-#4B72`]("=A<'!L:6-A
M=&EO;B]X+6QI8G)A<GDM9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ
M,UPQ7#$P(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD
M;6EM95]M86=I8ULP75LT75LB7#)<,3-<,5PQ,R)=(#T@)V%P<&QI8V%T:6]N
M+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$S
M7#%<,34B72`]("=A<'!L:6-A=&EO;B]X+6QI8G)A<GDM9FEL92<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,EPQ,UPQ7#$V(ET@/2`G87!P;&EC871I;VXO>"UL
M:6)R87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3-<,5PV(ET@
M/2`G87!P;&EC871I;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,EPQ,UPQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M
M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ7#$P(ET@/2`G87!P
M;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT
M75LB7#)<,31<,5PQ,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF
M:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$T7#%<,30B72`]("=A<'!L
M:6-A=&EO;B]X+6QI<W`G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,31<,5PQ
M-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPR7#$T7#%<,38B72`]("=A<'!L:6-A=&EO;B]X+6QI8G)A
M<GDM9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ7#8B72`]("=A
M<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,EPQ-%PQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M
M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PS-S=<,30U(ET@/2`G
M87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT
M75LB7#)<,C!<,5PQ,")=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF
M:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#(P7#%<,3,B72`]("=A<'!L
M:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,EPR,%PQ7#$U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C!<,5PQ-B)=(#T@)V%P<&QI8V%T
M:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#(P
M7#%<-B)=(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#)<,C!<,5PW(ET@/2`G87!P;&EC871I;VXO>"UE>&5C
M=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C1<,5PQ,")=
M(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPR7#(T7#%<,3,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U
M=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ7#$U(ET@
M/2`G87!P;&EC871I;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,EPR-%PQ7#$V(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I
M;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C1<,5PV(ET@/2`G87!P;&EC
M871I;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR
M-%PQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,S8Q7#8P7#$P,%PR-S,B72`]("=I;6%G92]X
M+6-M=2UR87-T97(G.PHD;6EM95]M86=I8ULP75LT75LB7#,V-EPS-C9<,S8V
M7#,V-B)=(#T@)V%P<&QI8V%T:6]N+W@M<&,M9FQO<'!Y)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPS-S=<,3`V7#$Q-UPQ,38B72`]("=F;VYT+W@M9&]S)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPT,5PW-%PQ-#%<,38R(ET@/2`G87!P;&EC
M871I;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-#-<-#%<,3%<-3<B
M72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-#-<-#%<
M-#!<-3<B72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M-3)<,3(S7#$R-%PQ,#$B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPU,EPU,EPU,EPT,")=(#T@)W1E>'0O>"UP871C:"<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<-39<,38R7#$T,5PS-S4B72`]("=A=61I
M;R]X+7!N+7)E86QA=61I;R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-39<,38S
M7#$U-EPQ-#0B72`]("=A=61I;R]B87-I8R<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<-C%<,30S7#$V-UPT,")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM
M95]M86=I8ULP75LT75LB7#8Q7#(W-EPP7#`B72`]("=T97AT+W9N9"YM<RUW
M;W)D)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPV,EPV,EPV-UPW,")=(#T@)V%P
M<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#<T7#$Q-5PQ
M,35<,3$T(ET@/2`G87!P;&EC871I;VXO>"UF<F%M96UA:V5R)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPW-%PQ-#%<,38R7#<V(ET@/2`G87!P;&EC871I;VXO
M>"UA<B<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,3`R7#$S,EPQ-3`B72`]("=A
M<'!L:6-A=&EO;B]X+6)Z:7`R)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ,#9<
M,3`Q7#$R,B)=(#T@)V%U9&EO+VUO9"<["B1M:6UE7VUA9VEC6S!=6S-=6R)<
M,3$U7#$R-%PQ,34B72`]("=A=61I;R]X+6UU;'1I=')A8VLG.PHD;6EM95]M
M86=I8ULP75LS75LB7#$R,UPQ,#)<,3$Q(ET@/2`G875D:6\O>"US8FDG.PHD
M;6EM95]M86=I8ULP75LS75LB7#$R-%PQ,3=<,3`S(ET@/2`G875D:6\O>"UT
M;V,G.PHD;6EM95]M86=I8ULP75LS75LB7#$R7#$P-UPQ,30B72`]("=A<'!L
M:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ-#9<,34T7#$T
M,R)=(#T@)V%P<&QI8V%T:6]N+W@M9F]N="<["B1M:6UE7VUA9VEC6S!=6S-=
M6R)<,30V7#$U-%PQ-#8B72`]("=F;VYT+W@M9FEG;&5T)SL*)&UI;65?;6%G
M:6-;,%U;,UU;(EPS,UPQ,#5<,S,B72`]("=I;6%G92]X+7!C;"UH<"<["B1M
M:6UE7VUA9VEC6S!=6S-=6R)<,S-<,30S7#,S(ET@/2`G87!P;&EC871I;VXO
M9&%T82<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,S<W7#,W-UPQ-S0B72`]("=A
M<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPS-S=<,S<W
M7#$W-B)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS
M75LB7#,W-UPS-S=<,3<W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE
M7VUA9VEC6S!=6S-=6R)<-#-<-#%<-#`B72`]("=T97AT+W-C<FEP="<["B1M
M:6UE7VUA9VEC6S!=6S-=6R)<-#-<-#%<-3<B72`]("=T97AT+W-C<FEP="<[
M"B1M:6UE7VUA9VEC6S!=6S-=6R)<-%PT-5PT,2)=(#T@)V%P<&QI8V%T:6]N
M+W!O<W1S8W)I<'0G.PHD;6EM95]M86=I8ULP75LS75LB7#4U7#$U,%PU-2)=
M(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS75LB7#8Q
M7#$T,UPQ-C<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPP7#`B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL
M92<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3`R7#$Q-2)=(#T@)VEM86=E+W@M
M8FUP)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,#)<,3,R(ET@/2`G87!P;&EC
M871I;VXO>"UB>FEP)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,3%<,3`S(ET@
M/2`G:6UA9V4O>"UI8V\G.PHD;6EM95]M86=I8ULP75LR75LB7#$Q,EPQ,38B
M72`]("=A=61I;R]X+38V.2UM;V0G.PHD;6EM95]M86=I8ULP75LR75LB7#$Q
M-5PQ,S(B72`]("=A<'!L:6-A=&EO;B]X+6US+61O<RUE>&5C=71A8FQE)SL*
M)&UI;65?;6%G:6-;,%U;,EU;(EPQ,C!<-C$B72`]("=I;6%G92]X+7!O<G1A
M8FQE+6)I=&UA<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P7#8R(ET@/2`G
M:6UA9V4O>"UP;W)T86)L92UG<F%Y;6%P)SL*)&UI;65?;6%G:6-;,%U;,EU;
M(EPQ,C!<-C,B72`]("=I;6%G92]X+7!O<G1A8FQE+7!I>&UA<"<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<,3(P7#8T(ET@/2`G:6UA9V4O>"UP;W)T86)L92UB
M:71M87`G.PHD;6EM95]M86=I8ULP75LR75LB7#$R,%PV-2)=(#T@)VEM86=E
M+W@M<&]R=&%B;&4M9W)A>6UA<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P
M7#8V(ET@/2`G:6UA9V4O>"UP;W)T86)L92UP:7AM87`G.PHD;6EM95]M86=I
M8ULP75LR75LB7#$U,5PQ-#8B72`]("=A=61I;R]X+38V.2UM;V0G.PHD;6EM
M95]M86=I8ULP75LR75LB7#$V,5PS,#<B72`]("=A<'!L:6-A=&EO;B]X+6-P
M:6\G.PHD;6EM95]M86=I8ULP75LR75LB7#$V-EPS-S<B72`]("=A<'!L:6-A
M=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$Q,")=(#T@)V%P
M<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;
M,EU;(EPQ7#$Q,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE
M)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$R-")=(#T@)V%P<&QI8V%T:6]N
M+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,3(U(ET@/2`G87!P;&EC
M871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB
M7#%<,38P(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD
M;6EM95]M86=I8ULP75LR75LB7#%<,38Q(ET@/2`G87!P;&EC871I;VXO>"UE
M>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,3<U(ET@
M/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I
M8ULP75LR75LB7#%<,3<W(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE
M+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,C`B72`]("=A<'!L:6-A
M=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S)=6R)<
M,5PR,#,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M
M:6UE7VUA9VEC6S!=6S)=6R)<,5PR,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE
M8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#(Q,")=(#T@
M)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPQ7#(Q-R)=(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G
M.PHD;6EM95]M86=I8ULP75LR75LB7#%<,C(T(ET@/2`G87!P;&EC871I;VXO
M>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,C(W
M(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M
M86=I8ULP75LR75LB7#%<,S,R(ET@/2`G>"]X+6EM86=E+7-G:2<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<,5PS-B)=(#T@)V9O;G0O>"UV9F]N="<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<,5PV(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A
M8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#,P-UPQ-C$B72`]("=A
M<'!L:6-A=&EO;B]X+6)C<&EO)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS,3-<
M-2)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB
M7#,U,EPQ-#`B72`]("=A<'!L:6-A=&EO;B]X+6%R:B<["B1M:6UE7VUA9VEC
M6S!=6S)=6R)<,S8W7#$S,2)=(#T@)V9O;G0O>"UT97@G.PHD;6EM95]M86=I
M8ULP75LR75LB7#,V-UPR,#,B72`]("=F;VYT+W@M=&5X)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPS-C=<,S$R(ET@/2`G9F]N="]X+71E>"<["B1M:6UE7VUA
M9VEC6S!=6S)=6R)<,S9<,2)=(#T@)V9O;G0O>"UV9F]N="<["B1M:6UE7VUA
M9VEC6S!=6S)=6R)<,S<U7#$V-B)=(#T@)V%P<&QI8V%T:6]N+W@M;'IH)SL*
M)&UI;65?;6%G:6-;,%U;,EU;(EPS-S9<,38V(ET@/2`G87!P;&EC871I;VXO
M9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S<W7#$T-2)=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W-UPQ-34B72`]
M("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-S=<
M,38V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,S<W7#,S,")=(#T@)VEM86=E+VIP96<G.PHD;6EM95]M86=I8ULP75LR
M75LB7#,W-UPS-R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I
M8ULP75LR75LB7#,W7#(Q,R)=(#T@)V%P<&QI8V%T:6]N+W@M9WII<"<["B1M
M:6UE7VUA9VEC6S!=6S)=6R)<,S=<,C,U(ET@/2`G87!P;&EC871I;VXO8V]M
M<')E<W,G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(S-B)=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(S-R)=(#T@
M)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(T
M,")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB
M7#,W7#,V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=
M6S)=6R)<,S=<,S<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPS-UPS-S<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI
M;65?;6%G:6-;,%U;,EU;(EPT-5PT,2)=(#T@)V%P<&QI8V%T:6]N+W!O<W1S
M8W)I<'0G.PHD;6EM95]M86=I8ULP75LR75LB7#1<-C8B72`]("=F;VYT+VQI
M;G5X+7!S9B<["B1M:6UE7VUA9VEC6S!=6S)=6R)<-3=<-3<B72`]("=T97AT
M+V-P<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<-5PQ(ET@/2`G87!P;&EC871I
M;VXO>"UL;V-A;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#9<,2)=(#T@)V%P
M<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;
M,EU;(EPV7#(B72`]("=A<'!L:6-A=&EO;B]X+6%L86XM861V96YT=7)E+6=A
M;64G.PHD;6EM95]M86=I8ULP75LR75LB7#=<,2)=(#T@)V%P<&QI8V%T:6]N
M+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,5U;,UU;(EPQ,C!<
M,3$V7#$P-R)=(#T@)VEM86=E+W@M<&YG)SL*)&UI;65?;6%G:6-;,5U;,UU;
M(EPQ,C=<,3(P7#$P,R)=(#T@)V%P<&QI8V%T:6]N+W9N9"YW;W)D<&5R9F5C
M="<["B1M:6UE7VUA9VEC6S)=6S9=6R)<-35<,34T7#$U,%PV-%PV,%PU-2)=
M(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU
M-5PQ-31<,34P7#$T-%PU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI
M;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P7#8P7#4U(ET@/2`G87!P;&EC
M871I;VXO>"UL:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-3!<
M-C%<-34B72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=
M6S5=6R)<-35<,34T7#$U,%PV,EPU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA
M)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P7#8S7#4U(ET@/2`G
M87!P;&EC871I;VXO>"UL:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U
M-%PQ-3!<-C1<-34B72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA
M9VEC6S)=6S5=6R)<-35<,34T7#$U,%PV-5PU-2)=(#T@)V%P<&QI8V%T:6]N
M+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,3<R7#$V,UPU
M-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;
M(EPU-5PQ-31<,3<R7#8T7#4U(ET@/2`G87!P;&EC871I;VXO>"UL:&$G.PHD
M;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-S)<-C5<-34B72`]("=A<'!L
M:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S)=6R)<,%PR,2)=(#T@
M)V9O;G0O>"UT97@M=&9M)SL*)&UI;65?;6%G:6-;,EU;,EU;(EPP7#(R(ET@
M/2`G9F]N="]X+71E>"UT9FTG.PHD;6EM95]M86=I8ULT75LT75LB7#$U-5PQ
M-#1<,30Q7#$V-")=(#T@)W9I9&5O+W%U:6-K=&EM92<["B1M:6UE7VUA9VEC
M6S1=6S1=6R)<,34U7#$U-UPQ-3=<,38V(ET@/2`G=FED96\O<75I8VMT:6UE
M)SL*)&UI;65?;6%G:6-;-%U;-%U;(EPQ-C!<,34Q7#$V,%PQ-#4B72`]("=A
M<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;-%U;-%U;(EPQ-C!<,38R
M7#$U-UPQ-#8B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;
M-%U;,EU;(EPR-3=<,C$B72`]("=V:61E;R]F;&DG.PHD;6EM95]M86=I8ULT
M75LR75LB7#(U-UPR,B)=(#T@)W9I9&5O+V9L8R<["B1M:6UE7VUA9VEC6S9=
M6S$X75LB7#0U7#0Q7#$R,%PQ,C-<-35<,3`Q7#$T-%PQ-3=<,30R7#$T-5PQ
M,#9<,34W7#$U-EPQ-C1<-35<-C%<-39<-C`B72`]("=F;VYT+W1Y<&4Q)SL*
M)&UI;65?;6%G:6-;-UU;,C)=6R)<,S4W7#(P7#8P7#8P7#8P7#8P7#8P7#8P
M7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P(ET@
M/2`G87!P;&EC871I;VXO8V]R92<["B1M:6UE7VUA9VEC6S==6S1=6R)<,%PQ
M,#5<,3`W7#$P,2)=(#T@)V9O;G0O>"UD;W,G.PHD;6EM95]M86=I8ULW75LT
M75LB7#!<,3(V7#$Q,5PQ,#0B72`]("=F;VYT+W@M9&]S)SL*)&UI;65?;6%G
M:6-;.%U;-%U;(EPR,UPQ-S)<-3-<,3`U(ET@/2`G9F]N="]X+7-U;F]S+6YE
M=W,G.PHD;6EM95]M86=I8ULX75LT75LB7#(S7#$W,EPU,UPQ,3`B72`]("=F
M;VYT+W@M<W5N;W,M;F5W<R<["B1M:6UE7VUA9VEC6S$P75LR-5U;(EPT,UPT
M,%PQ,C1<,34P7#$U,5PQ-C-<-#!<,34Q7#$V,UPT,%PQ-#%<-#!<,38S7#$U
M,%PQ-#5<,34T7#$U-%PT,%PQ-#%<,38R7#$T,UPQ-3!<,34Q7#$V-EPQ-#4B
M72`]("=A<'!L:6-A=&EO;B]X+7-H87(G.PHD;6EM95]M86=I8ULR,%U;-%U;
M(EPQ,#=<,3$Q7#$Q-5PQ,C`B72`]("=A<'!L:6-A=&EO;B]X+6=I;7`M8G)U
M<V@G.PHD;6EM95]M86=I8ULR,%U;-%U;(EPQ,#=<,3(P7#$P,5PQ,C0B72`]
M("=A<'!L:6-A=&EO;B]X+6=I;7`M<&%T=&5R;B<["B1M:6UE7VUA9VEC6S(P
M75LT75LB7#,W-5PS,#1<,C0W7#,S-")=(#T@)V%P<&QI8V%T:6]N+W@M>F]O
M)SL*)&UI;65?;6%G:6-;,C%=6SA=6R)<-#%<,3(S7#$P,UPQ,C)<,3`U7#$P
M,5PQ,35<-#$B72`]("=A=61I;R]X+7-T,BUM;V0G.PHD;6EM95]M86=I8ULR
M-%U;-%U;(EPP7#!<,S4R7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M9'5M<"<[
M"B1M:6UE7VUA9VEC6S(T75LT75LB7#!<,%PS-3)<,34T(ET@/2`G87!P;&EC
M871I;VXO>"UD=6UP)SL*)&UI;65?;6%G:6-;,C1=6S1=6R)<,%PP7#,U,EPQ
M-34B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,C1=6S1=
M6R)<,%PP7#,U,EPQ-38B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?
M;6%G:6-;-C5=6S1=6R)<,3`V7#$P-EPQ,3%<,3$T(ET@/2`G9F]N="]T=&8G
M.PHD;6EM95]M86=I8ULV-5U;-%U;(EPQ,31<,3(W7#$P-EPQ,38B72`]("=F
M;VYT+W1Y<&4Q)SL*)&UI;65?;6%G:6-;,C4W75LX75LB7#$V-5PQ-C-<,38T
M7#$T,5PQ-C)<-#!<-#!<-C`B72`]("=A<'!L:6-A=&EO;B]X+6=T87(G.PHD
M;6EM95]M86=I8ULR-3==6S9=6R)<,38U7#$V,UPQ-C1<,30Q7#$V,EPV,")=
M(#T@)V%P<&QI8V%T:6]N+W@M=&%R)SL*)&UI;65?;6%G:6-;,#<W-%U;,EU;
M(EPS,S)<,C<V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC
M6S$P.#!=6S1=6R)<,3`S7#$P-%PW,%PV,2)=(#T@)V%U9&EO+W@M;VMT86QY
M>F5R+6UO9"<["B1M:6UE7VUA9VEC6S$P.#!=6S1=6R)<,3`V7#$Q-%PQ,C1<
M-C0B72`]("=A=61I;R]X+7-T87)T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC
M6S$P.#!=6S1=6R)<,3$U7#0Q7#$Q,UPT,2)=(#T@)V%U9&EO+W@M<')O=')A
M8VME<BUM;V0G.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#$Q-5PU-EPQ,3-<
M-38B72`]("=A=61I;R]X+7!R;W1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;
M,3`X,%U;-%U;(EPQ,3=<,3$S7#$R-%PQ,#$B72`]("=A=61I;R]X+6]K=&%L
M>7IE<BUM;V0G.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#8Q7#8V7#$P,UPQ
M,38B72`]("=A=61I;R]X+71A:V5T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC
M6S$P.#!=6S1=6R)<-C-<-C)<,3`S7#$Q-B)=(#T@)V%U9&EO+W@M=&%K971R
M86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPV-%PQ,#-<,3$P
M7#$Q-B)=(#T@)V%U9&EO+W@M9F%S='1R86-K97(M;6]D)SL*)&UI;65?;6%G
M:6-;,3`X,%U;-%U;(EPV-EPQ,#-<,3$P7#$Q-B)=(#T@)V%U9&EO+W@M9F%S
M='1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPW,%PQ,#-<
M,3$P7#$Q-B)=(#T@)V%U9&EO+W@M9F%S='1R86-K97(M;6]D)SL*)&UI;65?
M;6%G:6-;,C`T.%U;-UU;(EPQ,C!<,3`S7#$P-%PQ,S=<,3$Q7#$R,%PQ,3$B
M72`]("=X+W@M<&AO=&\M8V0M<&%C:RUF:6QE)SL*)&UI;65?;6%G:6-;,C`X
M,%U;,CE=6R)<,3$U7#$U,5PQ-#-<,38R7#$U-UPQ-C-<,34W7#$T-EPQ-C1<
M-#!<,3`U7#$W,%PQ-#-<,30U7#$U-%PT,%PV-5PU-EPV,%PT,%PQ,C=<,34W
M7#$V,EPQ-3-<,38S7#$U,%PQ-#5<,30U7#$V-")=(#T@)V%P<&QI8V%T:6]N
M+W9N9"YM<RUE>&-E;"<["B1M:6UE7VUA9VEC6S(P.#!=6S(W75LB7#$Q-5PQ
M-3%<,30S7#$V,EPQ-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$R-UPQ-3=<,38R
M7#$T-%PT,%PV-EPU-EPV,%PT,%PQ,#1<,34W7#$T,UPQ-C5<,34U7#$T-5PQ
M-39<,38T(ET@/2`G=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA9VEC6S(P
M.#!=6S(V75LB7#$P-%PQ-3=<,30S7#$V-5PQ-35<,30U7#$U-EPQ-C1<,34W
M7#0P7#$Q-5PQ-3%<,30S7#$V,EPQ-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$R
M-UPQ-3=<,38R7#$T-%PT,%PV-B)=(#T@)W1E>'0O=FYD+FUS+7=O<F0G.PHD
M;6EM95]M86=I8ULR,3$R75LY75LB7#$Q-5PQ,C-<,3(W7#$U-UPQ-C)<,30T
M7#$P-%PQ-3=<,30S(ET@/2`G=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA
M9VEC6S(Q,31=6S5=6R)<,3`R7#$U,5PQ-#9<,30V7#8U(ET@/2`G87!P;&EC
M871I;VXO=FYD+FUS+65X8V5L)SL*)&UI;65?;6%G:6-;-#`Y.%U;-UU;(EPQ
M,#1<,3$W7#$R,UPQ,#9<,3$W7#$Q-EPQ,C0B72`]("=F;VYT+W@M9&]S)SL*
M)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<,C-<,3<W(ET@/2`G87!P;&EC
M871I;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=
M6R)<,C-<,C$W(ET@/2`G87!P;&EC871I;VXO>"UF:6QE<WES=&5M)SL*)&UI
M;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<-#1<,34P(ET@/2`G87!P;&EC871I
M;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<
M-#1<,3<P(ET@/2`G87!P;&EC871I;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?
M;6%G:6-;-S`W-SDY-C!=6S)=6R)<,S4W7#$R,R)=(#T@)V%P<&QI8V%T:6]N
M+W@M;&EN=7@M97AT,F9S)SL*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<```````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`Q,#4P-C``,3`T,3<S-C(W-S,`,#(Q,C<Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+TUE<W-A9V4N<&AP
M)SL*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]M:6UE7V1R
M:79E<G,N<&AP)SL*"B\J*@H@*B!4:&4@;F%M92!O9B!T:&4@55),('!A<F%M
M971E<B!T:&%T(&AO;&1S('1H92!-24U%7T-O;G1E;G1S(&-A8VAE"B`J(&ED
M96YT:69I97(N"B`J+PID969I;F4H)TU)345?0T].5$5.5%-?0T%#2$4G+"`G
M;6EM96-A8VAE)RD["@HO*BH*("H@1&ES<&QA>2!A='1A8VAM96YT(&EN9F]R
M;6%T:6]N(&EN(&QI<W0@9F]R;6%T+@H@*B\*9&5F:6YE*"=-24U%7T-/3E1%
M3E137T1)4U!,05E?5%E015],25-4)RP@,"D["@HO*BH*("H@1&ES<&QA>2!A
M='1A8VAM96YT(&EN9F]R;6%T:6]N(&EN;&EN92!W:71H(&%T=&%C:&UE;G0N
M"B`J+PID969I;F4H)TU)345?0T].5$5.5%-?1$E34$Q!65]465!%7TE.3$E.
M12<L(#$I.PH*+RHJ"B`J($1I<W!L87D@871T86-H;65N="!I;F9O<FUA=&EO
M;B!B;W1H(&EN(&QI<W0@9F]R;6%T(&%N9"!I;FQI;F4@=VET:`H@*B!A='1A
M8VAM96YT+@H@*B\*9&5F:6YE*"=-24U%7T-/3E1%3E137T1)4U!,05E?5%E0
M15]"3U1()RP@,BD["@HO*BH*("H@5&AE($U)345?0V]N=&5N=',Z.B!C;&%S
M<R!C;VYT86EN<R!F=6YC=&EO;G,@<F5L871E9"!T;R!H86YD;&EN9R!T:&4@
M;W5T<'5T"B`J(&]F($U)344@8V]N=&5N="X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<"QV(#$N,3(Y+C0N,S,@,C`P
M-B\P,R\P."`Q-CHT,#HS.2!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U(&1I
M9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA
M96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)344*("HO
M"F-L87-S($U)345?0V]N=&5N=',@>PH*("`@("\J*@H@("`@("H@5&AE($U)
M345?365S<V%G92!O8FIE8W0@9F]R('1H92!M97-S86=E+@H@("`@("H*("`@
M("`J($!V87(@34E-15]-97-S86=E"B`@("`@*B\*("`@('9A<B`D7VUE<W-A
M9V4["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-15]-97-S86=E(&]B:F5C="!W
M92!U<V4@=VAE;B!C86-H:6YG+@H@("`@("H*("`@("`J($!V87(@34E-15]-
M97-S86=E"B`@("`@*B\*("`@('9A<B`D7V-A8VAE;65S<V%G93L*"B`@("`O
M*BH*("`@("`J(%1H92!A='1A8VAM96YT<R!L:7-T+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?871C(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%1H92!M97-S86=E('!A<G1S(&QI<W0N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)T<R`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@<W5M;6%R>2!P87)T<R!L
M:7-T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?<W5M;6%R>2`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@<W5M
M;6%R>2!T>7!E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7W-U;6UA<GE4>7!E(#T@;G5L;#L*"B`@("`O*BH*("`@("`J
M(%1H92!#86-H95]S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V5S<VEO;D-A8VAE240@
M/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE($U)345?5FEE=V5R(&]B:F5C
M="!C86-H92X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7W9I97=E<D-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%1H92!A='1A8VAM96YT(&1I<W!L87D@='EP92!T;R!U<V4N"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V1I<W!L87E4
M>7!E(#T@34E-15]#3TY414Y44U]$25-03$%97U194$5?0D]42#L*"B`@("`O
M*BH*("`@("`J(%1H92!-24U%(&EN9&5X(&ME>2!T;R!U<V4N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;6EM96ME>2`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@86-T:6]N240@=F%L=64@9F]R
M('9A<FEO=7,@86-T:6]N<RX*("`@("`J("=D;W=N;&]A9"<@("TM("!$;W=N
M;&]A9&EN9R!A('!A<G0O871T86-H;65N="X*("`@("`J("=V:65W)R`@("`@
M("TM("!6:65W:6YG(&$@<&%R="]A='1A8VAM96YT+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=FEE=TE$(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J(%-H;W<@=&AE(&QI;FMS(&EN('1H92!S=6UM
M87)I97,_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@
M('9A<B`D7VQI;FMS(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1H92!B87-E
M($U)345?0V]N=&5N=',@;V)J96-T+@H@("`@("H*("`@("`J($!V87(@34E-
M15]#;VYT96YT<PH@("`@("HO"B`@("!V87(@)%]B87-E(#T@;G5L;#L*"B`@
M("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@;65S<V%G92]R9F,X,C(@;&5V
M96QS(&QA8F5L960@87,@)V%T=&%C:&UE;G1S)R!O9B!T:&4*("`@("`J(&-U
M<G)E;G0@<&%R="X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M+PH@("`@=F%R("1?871T86-H.#(R(#T@,#L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7TUE<W-A9V4@
M)&UE<W-A9V5/8B`@5&AE(&]B:F5C="!T;R!W;W)K('=I=&@N"B`@("`@*B!`
M<&%R86T@87)R87D@)'9I97=)1"`@("`@("`@("`@(%1H92!A8W1I;VY)1"!V
M86QU97,@9F]R('9I97=I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<&%R=',O871T86-H;65N=',N"B`@("`@*B!`<&%R86T@
M87)R87D@)B1C;VYT96YT<R`@("`@("`@($%R<F%Y(&-O;G1A:6YI;F<@82!S
M:6YG;&4@=F%L=64Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&$@<F5F97)E;F-E('1O('1H92!B87-E(&]B:F5C="X*("`@("`J
M("A4:&ES(&QA<W0@<&%R86UE=&5R(&YE961S('1O(&)E(&AA;F1L960@=FEA
M(&%N(&%R<F%Y(&)E8V%U<V4@4$A0(#P*("`@("`J("`U+C`@9&]E<VXG="!H
M86YD;&4@;W!T:6]N86P@<&]I;G1E<B!P87)A;65T97)S(&]T:&5R=VES92XI
M"B`@("`@*B\*("`@(&9U;F-T:6]N($U)345?0V]N=&5N=',H)&UE<W-A9V5/
M8BP@)'9I97=)1"`](&%R<F%Y*"DL("1C;VYT96YT<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]M97-S86=E(#T@)&UE<W-A9V5/8CL*("`@
M("`@("`D=&AI<RT^7V-A8VAE;65S<V%G92`](%5T:6PZ.F-L;VYE3V)J96-T
M*"1M97-S86=E3V(I.PH@("`@("`@("1T:&ES+3Y?=FEE=TE$(#T@)'9I97=)
M1#L*"B`@("`@("`@+RH@0W)E871E('1H92!P;VEN=&5R('1O('1H92!B87-E
M(&]B:F5C="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1C;VYT96YT<RDI('L*
M("`@("`@("`@("`@)'!T<B`](')E<V5T*"1C;VYT96YT<RD["B`@("`@("`@
M("`@("1O;&1?<'1R(#T@)B1P='(M/F=E=$)A<V5/8FIE8W10='(H*3L*("`@
M("`@("`@("`@)'1H:7,M/E]B87-E(#T@)&]L9%]P='(["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@96YT:7)E(&)O9'D@
M;V8@=&AE(&UE<W-A9V4N"B`@("`@*B!9;W4@<')O8F%B;'D@=V%N="!T;R!O
M=F5R<FED92!T:&ES(&9U;F-T:6]N(&EN(&%N>2!S=6)C;&%S<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0@;V8@=&AE(&)O9'D@
M;V8@=&AE(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)O9'DH
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUE<W-A9V4M/G1O4W1R
M:6YG*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!R87<@
M=&5X="!F;W(@;VYE('-E8W1I;VX@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B!9
M;W4@<')O8F%B;'D@=V%N="!T;R!O=F5R<FED92!T:&ES(&9U;F-T:6]N(&EN
M(&%N>2!S=6)C;&%S<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@5&AE($E$(&]F('1H92!-24U%7U!A<G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!T97AT(&]F('1H92!P87)T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971";V1Y4&%R="@D:60I"B`@("!["B`@("`@("`@:68@
M*"@D<&%R="`]("8D=&AI<RT^9V5T34E-15!A<G0H)&ED*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1P87)T+3YG971#;VYT96YT<R@I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!-24U%7TUE<W-A9V4@;V)J
M96-T(&9O<B!T:&4@;6%I;"!M97-S86=E+@H@("`@("H*("`@("`J($!R971U
M<FX@34E-15]-97-S86=E("!!($U)345?365S<V%G92!O8FIE8W0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$U)345-97-S86=E*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]M97-S86=E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1F5T8V@@82!P87)T(&]F(&$@34E-12!M97-S86=E+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1I9"`@5&AE($U)344@:6YD97@@;V8@=&AE
M('!A<G0@<F5Q=65S=&5D+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]0
M87)T("!4:&4@<F%W($U)344@<&%R="!A<VME9"!F;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9G971-24U%4&%R="@D:60I"B`@("!["B`@("`@("`@)'!A
M<G0@/2`D=&AI<RT^7VUE<W-A9V4M/F=E=%!A<G0H)&ED*3L*("`@("`@("!R
M971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296)U:6QD('1H
M92!-24U%7U!A<G0@<W1R=6-T=7)E(&]F(&$@;65S<V%G92X*("`@("`J(%EO
M=2!P<F]B86)L>2!W86YT('1O(&]V97)R:61E('1H:7,@9G5N8W1I;VX@:6X@
M86YY('-U8F-L87-S+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]-97-S
M86=E("!!($U)345?365S<V%G92!O8FIE8W0@=VET:"!A;&P@;V8@=&AE(&)O
M9'D@=&5X=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('-T;W)E9"!I
M;B!T:&4@:6YD:79I9'5A;"!-24U%7U!A<G1S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96)U:6QD365S<V%G92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;65S<V%G93L*("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H('!A
M<G0@;V8@82!-24U%(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&ED("`@5&AE($U)344@240@;V8@=&AE('!A<G0@<F5Q=65S=&5D
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;"`@268@=&AI<R!I<R!A(&AE
M861E<B!P87)T+"!S:&]U;&0@=V4@<F5T=7)N(&%L;"!T97AT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!I;B!T:&4@8F]D>3\*("`@("`J"B`@("`@
M*B!`<F5T=7)N($U)345?4&%R="`@5&AE($U)345?4&%R="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F=E=%)A=TU)345087)T*"1I9"P@)&%L;"`](&9A;'-E
M*0H@("`@>PH@("`@("`@("1M:6UE7W!A<G0@/2`F)'1H:7,M/F=E=$U)3450
M87)T*"1I9"D["B`@("`@("`@:68@*"%I<U]A*"1M:6UE7W!A<G0L("=-24U%
M7U!A<G0G*2D@>PH@("`@("`@("`@("`D;6EM95]P87)T(#T@;G5L;#L*("`@
M("`@("`@("`@<F5T=7)N("1M:6UE7W!A<G0["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!A;&P@=&5X="!I<R!R97%U97-T960L(&-H86YG92!T:&4@240@
M;F]W+B`J+PH@("`@("`@(&EF("@D86QL("8F("1M:6UE7W!A<G0M/F=E=$EN
M9F]R;6%T:6]N*"=H96%D97(G*2D@>PH@("`@("`@("`@("`D:60@/2!S=6)S
M='(H)&ED+"`P+"!S=')R<&]S*"1I9"P@)RXG*2D["B`@("`@("`@?0H*("`@
M("`@("`O*B!/;FQY('-E="!C;VYT96YT<R!I9B!T:&5R92!I<R!C=7)R96YT
M;'D@;F]N92!I;B!T:&4@34E-12!087)T+B`J+PH@("`@("`@(&EF("@A)&UI
M;65?<&%R="T^9V5T0V]N=&5N=',H*2D@>PH@("`@("`@("`@("`D;6EM95]P
M87)T+3YS971#;VYT96YT<R@D=&AI<RT^9V5T0F]D>5!A<G0H)&ED*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&UI;65?<&%R=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($9E=&-H('!A<G0@;V8@82!-24U%(&UE<W-A9V4@86YD
M(&1E8V]D92!I="P@:68@:70@:7,@8F%S95\V-"!O<@H@("`@("H@<7!R:6YT
M(&5N8V]D960N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@
M5&AE($U)344@240@;V8@=&AE('!A<G0@<F5Q=65S=&5D+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&%L;"`@268@=&AI<R!I<R!A(&AE861E<B!P87)T+"!S
M:&]U;&0@=V4@<F5T=7)N(&%L;"!T97AT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!I;B!T:&4@8F]D>3\*("`@("`J"B`@("`@*B!`<F5T=7)N($U)
M345?4&%R="`@5&AE($U)345?4&%R="!W:71H(&ET<R!C;VYT96YT<R!D96-O
M9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1&5C;V1E9$U)345087)T
M*"1I9"P@)&%L;"`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@H)&UI;65?
M<&%R="`]("8D=&AI<RT^9V5T4F%W34E-15!A<G0H)&ED+"`D86QL*2DI('L*
M("`@("`@("`@("`@)&UI;65?<&%R="T^=')A;G-F97)$96-O9&5#;VYT96YT
M<R@I.PH@("`@("`@("`@("`O+R!.;V]P+@H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1M:6UE7W!A<G0@/2!N=6QL.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&UI;65?<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@871T86-H;65N="!L:7-T("A(5$U,('1A8FQE(&9O<FUA="DN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L:7-T(&]F(&%T
M=&%C:&UE;G1S(&9O<FUA='1E9"!I;G1O($A434PN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$%T=&%C:&UE;G1S*"D*("`@('L*("`@("`@("`D;7-G(#T@
M)R<["@H@("`@("`@("1A:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]A=&,I
M.PH@("`@("`@(&YA='-O<G0H)&%K97ES*3L*("`@("`@("!F;W)E86-H("@D
M86ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`D;7-G("X]("1T:&ES+3Y?
M87)R87E4;U1A8FQE4F]W*"1T:&ES+3Y?871C6R1K97E=*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D;7-G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!M97-S86=E(&QI<W0@*$A434P@=&%B;&4@9F]R;6%T*2X*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYE9G)A;64@(%-H;W5L
M9"!T:&4@;W5T<'5T(&)E(&1E<VEG;F5D(&9O<B!D:7-P;&%Y(&EN(&$*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<VEN9VQE(&9R86UE/PH@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;65S<V%G92!F;W)M
M871T960@:6YT;R!(5$U,+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-97-S
M86=E*"1O;F5F<F%M92`](&9A;'-E*0H@("`@>PH@("`@("`@("1M<V<@/2`G
M)SL*("`@("`@("`D;7-G0V]U;G0@/2!C;W5N="@D=&AI<RT^7W!A<G1S*3L*
M("`@("`@("`D<&%R=$1I<W!L87EE9"`](&9A;'-E.PH*("`@("`@("!I9B`H
M)&]N969R86UE*2!["B`@("`@("`@("`@("1M<V<@+CT@)SQS='EL92!T>7!E
M/2)T97AT+V-S<R(^+F]N969R('MP861D:6YG.C%P>#L@;6%R9VEN+6)O='1O
M;3HQ<'@[(&)O<F1E<CHQ<'@@9&%S:&5D(",P,&,[(&)A8VMG<F]U;F0Z(V5E
M9CL@8V]L;W(Z(S`P-GT\+W-T>6QE/B<@+B`B7&XB.PH@("`@("`@('T*"B`@
M("`@("`@+R\@5$]$3SH@5&5M<&]R87)Y(&AA8VL@=&\@9&ES<&QA>2!H96%D
M97(@:6YF;R!F;W(@82!M97-S86=E('=I=&@@;VYE"B`@("`@("`@+R\@34E-
M12!P87)T('1H870@8V%N;F]T(&)E(&1I<W!L87EE9"!I;FQI;F4N"B`@("`@
M("`@:68@*"$D;7-G0V]U;G0@?'P@*"1M<V=#;W5N="`]/2`Q("8F("%R97-E
M="@D=&AI<RT^7W!A<G1S*2DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=%-U
M;6UA<GDH)'1H:7,M/E]M97-S86=E+"`G<&%R="<I.PH@("`@("`@("`@("`D
M;7-G0V]U;G0@/2`Q.PH@("`@("`@('T*("`@("`@("`@("`@"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]P87)T<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]S=6UM87)Y6R1K97E=*2`F
M)@H@("`@("`@("`@("`@("`@*"@H)&US9T-O=6YT(#T](#$I("8F(&5M<'1Y
M*"1V86QU92DI('Q\("@D;7-G0V]U;G0@/B`Q*2DI('L*("`@("`@("`@("`@
M("`@("1M<V<@+CT@)SQT<CX\=&0^)SL*("`@("`@("`@("`@("`@(&EF("@D
M;VYE9G)A;64I('L*("`@("`@("`@("`@("`@("`@("`D;7-G("X]("<\=&%B
M;&4@8VQA<W,](F]N969R(CXG.PH@("`@("`@("`@("`@("`@("`@("1S=6UM
M87)Y(#T@)'1H:7,M/E]S=6UM87)Y6R1K97E=.PH@("`@("`@("`@("`@("`@
M("`@("1S=6UM87)Y(#T@87)R87E?;65R9V4H87)R87E?<W!L:6-E*"1S=6UM
M87)Y+"`P+"`Q*2P@87)R87E?<W!L:6-E*"1S=6UM87)Y+"`Q*2D["B`@("`@
M("`@("`@("`@("`@("`@)&US9R`N/2`D=&AI<RT^7V%R<F%Y5&]486)L95)O
M=R@D<W5M;6%R>2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1M<V<@+CT@)SQT86)L93XG.PH@("`@("`@("`@("`@
M("`@("`@("1M<V<@+CT@)'1H:7,M/E]A<G)A>51O5&%B;&52;W<H)'1H:7,M
M/E]S=6UM87)Y6R1K97E=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1M<V<@+CT@)SPO=&%B;&4^/"]T9#X\+W1R/B<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D=F%L=64I*2!["B`@("`@
M("`@("`@("`@("`D;7-G("X]("<\='(^/'1D(&-L87-S/2)T97AT(CXG("X@
M)'9A;'5E("X@)SPO=&0^/"]T<CXG.PH@("`@("`@("`@("`@("`@)'!A<G1$
M:7-P;&%Y960@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H(21P87)T1&ES<&QA>65D*2!["B`@("`@("`@("`@("1M<V<@
M+CT@)SQT<CX\=&0@8VQA<W,](G1E>'0B(&%L:6=N/2)L969T(CX\96T^)R`N
M(%\H(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+B(I("X@)SPO96T^/"]T9#X\+W1R/B<["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("`O*BH*("`@("`J($5X<&%N
M9',@86X@87)R87D@:6YT;R!A('1A8FQE(')O=RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%R
M<F%Y("!4:&4@87)R87D@=&\@97AP86YD+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@87)R87D@97AP86YD960@=&\@82!(5$U,('1A8FQE
M(')O=RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V%R<F%Y5&]486)L95)O=R@D
M87)R87DI"B`@("!["B`@("`@("`@)'1E>'0@/2`G/'1R('9A;&EG;CTB;6ED
M9&QE(CXG.PH*("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&5L96TI('L*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D96QE;2DI('L*("`@("`@("`@("`@
M("`@("1T97AT("X]("(\=&0^)&5L96TF;F)S<#L\+W1D/EQN(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT("X@(CPO
M='(^7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9&%T
M82!F;W(@82!S<&5C:69I8R!-24U%(&EN9&5X+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED("`@("!4:&4@34E-12!I;F1E>"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&9I96QD("!4:&4@9FEE;&0@=&\@<F5T=7)N("AM97-S
M86=E+"!A=&,L('-U;6UA<GDI"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!T97AT(&-U<G)E;G1L>2!S970@9F]R('1H870@:6YD97@N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN9&5X*"1I9"P@)&9I96QD*0H@("`@
M>PH@("`@("`@("1F:65L9"`]("=?)R`N("1F:65L9#L*("`@("`@("!I9B`H
M:7-?87)R87DH)'1H:7,M/B1F:65L9"D@)B8@87)R87E?:V5Y7V5X:7-T<R@D
M:60L("1T:&ES+3XD9FEE;&0I*2!["B`@("`@("`@("`@("1E;G1R>2`]("1T
M:&ES+3XD9FEE;&0["B`@("`@("`@("`@(')E='5R;B`D96YT<GE;)&ED73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S('1H92!M97-S
M86=E('1E>'0@86YD('-U;6UA<GD@9F]R(&$@<W!E8VEF:6,@34E-12!I;F1E
M>"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE($U)344@
M:6YD97@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94EN9&5X*"1I9"D*
M("`@('L*("`@("`@("!U;G-E="@D=&AI<RT^7W!A<G1S6R1I9%TI.PH@("`@
M("`@('5N<V5T*"1T:&ES+3Y?<W5M;6%R>5LD:61=*3L*("`@("`@("!U;G-E
M="@D=&AI<RT^7V%T8ULD:61=*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN92!I9B!W92!C86X@*&%N9"!K;F]W(&AO=R!T;RD@:6YL:6YE(&$@
M34E-12!087)T+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M
M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@<&%R="!C86X@8F4@:6YL:6YE9"X*
M("`@("`J("`@("`@("`@("`@("`@("`@1F%L<V4@:68@:70@8V%N;F]T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C86Y$:7-P;&%Y26YL:6YE*"8D;6EM95]P
M87)T*0H@("`@>PH@("`@("`@("1V:65W97(@/2`F)'1H:7,M/F=E=$U)3456
M:65W97(H)&UI;65?<&%R="D["@H@("`@("`@("\J($9I<G-T(&-H96-K.B!4
M:&4@34E-12!H96%D97)S(&%L;&]W('1H92!P87)T('1O(&)E(&EN;&EN960N
M"B`@("`@("`@("H@2&]W979E<BP@:68@=V4@87)E(&%L<F5A9'D@:6X@=FEE
M=R!M;V1E+"!T:&5N('=E(&-A;B!S:VEP('1H:7,*("`@("`@("`@*B!C:&5C
M:RX@*B\*("`@("`@("!I9B`H(21T:&ES+3YV:65W07-!='1A8VAM96YT*"D@
M)B8*("`@("`@("`@("`@*"1M:6UE7W!A<G0M/F=E=$1I<W!O<VET:6]N*"D@
M(3T@)VEN;&EN92<I("8F"B`@("`@("`@("`@("$D=FEE=V5R+3YF;W)C94EN
M;&EN959I97<H*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`O*B!396-O;F0@8VAE8VL@*'-A=F4@=&AE(&UO<W0@
M97AP96YS:79E(&9O<B!L87-T*3H*("`@("`@("`@*B!#:&5C:R!T;R!S964@
M:68@=&AE(&1R:79E<B!I<R!S970@=&\@:6YL:6YE+B`J+PH@("`@("`@(')E
M='5R;B`H:7-?82@D=FEE=V5R+"`G34E-15]6:65W97(G*2`F)B`D=FEE=V5R
M+3YC86Y$:7-P;&%Y26YL:6YE*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T($U)345?5FEE=V5R(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M34E-15]087)T("8D;6EM95]P87)T("!!($U)345?4&%R="!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!-24U%7U9I97=E<B`@5&AE($U)345?5FEE
M=V5R(&]B:F5C="P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9G971-24U%5FEE=V5R*"8D;6EM95]P87)T*0H@("`@>PH@("`@
M("`@("\J($UA:V4@<W5R92!W92!H879E(&$@34E-15]087)T('1O('!R;V-E
M<W,N("HO"B`@("`@("`@:68@*&5M<'1Y*"1M:6UE7W!A<G0I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O5FEE=V5R+G!H<"<["@H@
M("`@("`@("1K97D@/2`D;6EM95]P87)T+3YG9715;FEQ=65)1"@I("X@)WPG
M("X@)&UI;65?<&%R="T^9V5T5'EP92@I.PH@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]V:65W97)#86-H95LD:V5Y72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]V:65W97)#86-H95LD:V5Y72`]("9-24U%7U9I97=E<CHZ9F%C=&]R
M>2@D;6EM95]P87)T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7W9I97=E<D-A8VAE6R1K97E=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!-24U%($-O;G1E;G0M5'EP92!O=71P=70@8GD@82!-24U%7U9I
M97=E<B!F;W(@82!P87)T:6-U;&%R"B`@("`@*B!-24U%7U!A<G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@02!-24U%
M7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@34E-12!T>7!E(&]U='!U="!B>2!T:&4@34E-15]6:65W97(L(&]R(&9A
M;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$U)3456:65W97)4>7!E*"8D;6EM95]P87)T*0H@
M("`@>PH@("`@("`@(&EF("@H)'9I97=E<B`]("8D=&AI<RT^9V5T34E-159I
M97=E<B@D;6EM95]P87)T*2DI('L*("`@("`@("`@("`@<F5T=7)N("1V:65W
M97(M/F=E=%1Y<&4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@:V5Y('1O('5S92!F;W(@82!P87)T:6-U;&%R($U)345?
M4&%R="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!!($U)345?4&%R
M="!O8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;W9E<G)I9&4@("`@
M("!297-P96-T('1H92!-24U%(&ME>2!O=F5R<FED92!V86QU93\*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N:7%U92!I9&5N=&EF:65R
M(&]F('1H92!-24U%7U!A<G0N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T
M=7)N<R!F86QS92!I9B!N;R!K97D@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G971-24U%2V5Y*"8D;6EM95]P87)T+"`D;W9E<G)I9&4@/2!T<G5E
M*0H@("`@>PH@("`@("`@("1I9"`]("1T:&ES+3YG971-24U%2V5Y3W9E<G)I
M9&4H*3L*"B`@("`@("`@:68@*"1O=F5R<FED92`F)B`A:7-?;G5L;"@D:60I
M*2!["B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&ED(#T@)&UI;65?<&%R="T^9V5T34E-14ED*"D["B`@
M("`@("`@("`@(&EF("AI<U]N=6QL*"1I9"DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D:60["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!-24U%(&ME>2!O=F5R<FED
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@:V5Y
M(&]V97)R:61E("T@;G5L;"!I9B!N;R!O=F5R<FED92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T34E-14ME>4]V97)R:61E*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]M:6UE:V5Y.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T<R!A;B!O=F5R<FED92!F;W(@=&AE($U)344@:V5Y+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&UI;65K97D*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T34E-14ME>4]V97)R:61E*"1M:6UE:V5Y(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7VUI;65K97D@/2`D;6EM96ME>3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-H;W5L9"!W92!D:7-P;&%Y(&QI;FMS(&9O<B!T:&4@
M<W5M;6%R:65S/PH@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S:&]W
M("!3:&]W('1H92!S=6UM87)Y(&QI;FMS/PH@("`@("HO"B`@("!F=6YC=&EO
M;B!S:&]W4W5M;6%R>4QI;FMS*"1S:&]W(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H(6ES7VYU;&PH)'-H;W<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;&EN:W,@/2`D<VAO=SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7VQI;FMS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R(&$@34E-
M12!087)T+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE
M7W!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;F1E<DU)345087)T*"8D;6EM95]P87)T*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)E;F1E<DU)345087)T*"1M:6UE7W!A<G0L
M(&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E<B!-24U%(%!A
M<G0@871T86-H;65N="!I;F9O+@H@("`@("H*("`@("`J($!P87)A;2!-24U%
M7U!A<G0@)B1M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<DU)345!='1A8VAM96YT26YF;R@F
M)&UI;65?<&%R="D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R96YD
M97)-24U%4&%R="@D;6EM95]P87)T+"!T<G5E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;F1E<B!-24U%(%!A<G0@9&%T82X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T
M("8D;6EM95]P87)T("!!($U)345?4&%R="!O8FIE8W0N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D871T86-H;65N="`@("!296YD97(@34E-12!087)T(&%T
M=&%C:&UE;G0@:6YF;S\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96YD
M97)-24U%4&%R="@F)&UI;65?<&%R="P@)&%T=&%C:&UE;G0@/2!F86QS92D*
M("`@('L*("`@("`@("`O*B!'970@=&AE($U)345?5FEE=V5R(&]B:F5C="!F
M;W(@=&AI<R!-24U%('!A<G0@*B\*("`@("`@("`D=FEE=V5R(#T@)B1T:&ES
M+3YG971-24U%5FEE=V5R*"1M:6UE7W!A<G0I.PH@("`@("`@(&EF("@A:7-?
M82@D=FEE=V5R+"`G34E-15]6:65W97(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D;7-G(#T@)R<["@H@("`@("`@
M("1M:6UE7W!A<G0M/G1R86YS9F5R1&5C;V1E0V]N=&5N=',H*3L*"B`@("`@
M("`@+RH@268@=&AI<R!I<R!A('1E>'0O*B!P87)T+"!!3D0@=&AE('1E>'0@
M:7,@:6X@82!D:69F97)E;G0@8VAA<F%C=&5R"B`@("`@("`@("H@<V5T('1H
M86X@=&AE(&)R;W=S97(L(&-O;G9E<G0@=&\@=&AE(&-U<G)E;G0@8VAA<F%C
M=&5R('-E="X*("`@("`@("`@*B!!9&1I=&EO;F%L;'DL(&EF('1H92!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@551&+3@L(&=I=F4@=&AE"B`@("`@("`@
M("H@=7-E<B!A(&QI;FL@=&\@;W!E;B!T:&4@<&%R="!I;B!A(&YE=R!W:6YD
M;W<@=VET:"!T:&4@8V]R<F5C=`H@("`@("`@("`J(&-H87)A8W1E<B!S970N
M("HO"B`@("`@("`@)&-H87)S970@/2`D;6EM95]P87)T+3YG971#:&%R<V5T
M*"D["B`@("`@("`@:68@*"1C:&%R<V5T*2!["B`@("`@("`@("`@("1C:&%R
M<V5T7W5P<&5R(#T@4W1R:6YG.CIU<'!E<B@D8VAA<G-E="D["B`@("`@("`@
M("`@(&EF("@H)&-H87)S971?=7!P97(@(3T@)U53+4%30TE))RD@)B8*("`@
M("`@("`@("`@("`@("$D=&AI<RT^=FEE=T%S071T86-H;65N="@I*2!["B`@
M("`@("`@("`@("`@("`D9&5F875L=%]C:&%R<V5T(#T@4W1R:6YG.CIU<'!E
M<BA.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@("`@("!I9B`H)&-H
M87)S971?=7!P97(@(3T@)&1E9F%U;'1?8VAA<G-E="D@>PH@("`@("`@("`@
M("`@("`@("`@("1M:6UE7W!A<G0M/G-E=$-O;G1E;G1S*%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H)&UI;65?<&%R="T^9V5T0V]N=&5N=',H*2P@)&-H87)S
M970L("1D969A=6QT7V-H87)S970I*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&1E9F%U;'1?8VAA<G-E="`A/2`G551&+3@G*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1S=&%T=7,@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-P<FEN=&8H7R@B5&AI<R!M97-S86=E('=A<R!W<FET
M=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O
M=VXN(BDL(&AT;6QS<&5C:6%L8VAA<G,H)&-H87)S970I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B268@:70@:7,@;F]T(&1I
M<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN
M9&]W+B(I+"`D=&AI<RT^;&EN:U9I97=*4R@D;6EM95]P87)T+"`G=FEE=U]A
M='1A8V@G+"!?*")C;&EC:R!H97)E(BDI*0H@("`@("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@("`@("`@("`@("`@("`@("`@("`D;7-G(#T@)'1H:7,M
M/F9O<FUA=%-T871U<TUS9R@D<W1A='5S+"!N=6QL+"!F86QS92D@+B`D;7-G
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'9I97=E<BT^<V5T34E-
M15!A<G0H)&UI;65?<&%R="D["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"8D
M=&AI<RD["B`@("`@("`@:68@*"1A='1A8VAM96YT*2!["B`@("`@("`@("`@
M("1M<V<@+CT@)'9I97=E<BT^<F5N9&5R071T86-H;65N=$EN9F\H)'!A<F%M
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&US9R`N/2`D=FEE
M=V5R+3YR96YD97(H)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&US9SL*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD('1H92!M97-S
M86=E(&1E8VED:6YG('=H870@34E-12!087)T<R!T;R!S:&]W+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@1F%L<V4@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&)U:6QD365S<V%G92@I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]A=&,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?<&%R=',@
M/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?<W5M;6%R>2`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@A:7-?82@D=&AI<RT^7VUE<W-A9V4L("=-24U%7TUE
M<W-A9V4G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!.;W<@9&ES<&QA>2!T:&4@<&%R=',N("HO"B`@("`@
M("`@)&UI;65?<&%R="`]("1T:&ES+3Y?;65S<V%G92T^9V5T0F%S95!A<G0H
M*3L*("`@("`@("`D=&AI<RT^8G5I;&1-97-S86=E4&%R="@D;6EM95]P87)T
M*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!0<F]C97-S97,@82!-24U%7U!A<G0@86YD('-T;W)E<R!T:&4@9&ES<&QA
M>2!I;F9O<FUA=&EO;B!I;B!T:&4@:6YT97)N86P*("`@("`J(&-L87-S('9A
M<FEA8FQE<RX*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM
M95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!P<F]C97-S+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8G5I;&1-97-S86=E4&%R="@F)&UI;65?
M<&%R="D*("`@('L*("`@("`@("`D;7-G(#T@)R<["@H@("`@("`@("\J($EF
M('=E(&-A;B=T(&1I<W!L87D@=&AE('!A<G0@:6YL:6YE+"!A9&0@:70@=&\@
M=&AE(&%T=&%C:&UE;G0*("`@("`@("`@("!L:7-T+B!)9B!T:&4@34E-12!)
M1"!O9B!T:&4@8W5R<F5N="!P87)T(&ES("<P)RP@=&AE;B!F;W)C92!A"B`@
M("`@("`@("`@<F5N9&5R(&]F('1H92!P87)T("AS:6YC92!I="!I<R!T:&4@
M8F%S92!P87)T(&%N9"P@=VET:&]U=`H@("`@("`@("`@(&%T=&5M<'1I;F<@
M=&\@<F5N9&5R+"!T:&4@;65S<V%G92!W:6QL($%,5T%94R!A<'!E87(@96UP
M='DN("HO"B`@("`@("`@:68@*"$D=&AI<RT^8V%N1&ES<&QA>4EN;&EN92@D
M;6EM95]P87)T*2`F)@H@("`@("`@("`@("`H)&UI;65?<&%R="T^9V5T34E-
M14ED*"D@(3T@,"DI('L*("`@("`@("`@("`@+RH@3F]T(&1I<W!L87EI;F<@
M:6YL:6YE.R!A9&0@=&\@=&AE(&%T=&%C:&UE;G1S(&QI<W0N("HO"B`@("`@
M("`@("`@(&EF("@H)'1H:7,M/E]D:7-P;&%Y5'EP92`]/2!-24U%7T-/3E1%
M3E137T1)4U!,05E?5%E015],25-4*2!\?`H@("`@("`@("`@("`@("`@*"1T
M:&ES+3Y?9&ES<&QA>51Y<&4@/3T@34E-15]#3TY414Y44U]$25-03$%97U19
M4$5?0D]42"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9713=6UM87)Y
M*"1M:6UE7W!A<G0L("=A='1A8VAM96YT)RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"@D=&AI<RT^7V1I<W!L87E4>7!E(#T]($U)345?0T].
M5$5.5%-?1$E34$Q!65]465!%7TE.3$E.12D@?'P*("`@("`@("`@("`@("`@
M("@D=&AI<RT^7V1I<W!L87E4>7!E(#T]($U)345?0T].5$5.5%-?1$E34$Q!
M65]465!%7T)/5$@I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4W5M
M;6%R>2@D;6EM95]P87)T+"`G<&%R="<I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!#:&5C:R!T;R!S964@:68@86YY(&%T=&%C:&UE;G0@:6YF
M;W)M871I;VX@8V%N(&)E(')E;F1E<F5D(&)Y"B`@("`@("`@("`@("`@('1H
M92!-24U%7U9I97=E<BX@*B\*("`@("`@("`@("`@)&US9R`]("1T:&ES+3YR
M96YD97)-24U%071T86-H;65N=$EN9F\H)&UI;65?<&%R="D["B`@("`@("`@
M("`@(&EF("@A96UP='DH)&US9RDI('L*("`@("`@("`@("`@("`@("1K97D@
M/2`D=&AI<RT^7V=E=$U)345+97DH)&UI;65?<&%R="D["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<G1S6R1K97E=(#T@)&US9SL*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M<V<@/2`D=&AI<RT^
M<F5N9&5R34E-15!A<G0H)&UI;65?<&%R="D["B`@("`@("`@("`@("1K97D@
M/2`D=&AI<RT^7V=E=$U)345+97DH)&UI;65?<&%R="D["B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]A='1A8V@X,C(I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R='-;)&ME>5T@/2`D;7-G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("\J(%-O;64@34E-15]6:65W97)S('-E="!T:&4@<W5M;6%R>2!B
M>2!T:&5M96QV97,L('-O(&]N;'D*("`@("`@("`@("`@("H@861D('1O(&%T
M=&%C:&UE;G0O:6YL:6YE(&QI<W1S(&EF(&YO=&AI;F<@:&%S(&)E96X@<V5T
M"B`@("`@("`@("`@("`J(&%S(&]F('EE="X@*B\*("`@("`@("`@("`@:68@
M*"@H)&UI;65?<&%R="T^9V5T5'EP92@I("$]("=M=6QT:7!A<G0O;6EX960G
M*2!\?`H@("`@("`@("`@("`@("`@("%E;7!T>2@D;7-G*2D@)B8*("`@("`@
M("`@("`@("`@("%E;7!T>2@D:V5Y*2`F)@H@("`@("`@("`@("`@("`@(21T
M:&ES+3YG971);F1E>"@D:V5Y+"`G<W5M;6%R>2<I*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T4W5M;6%R>2@D;6EM95]P87)T+"`G<&%R="<I.PH@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?871T86-H.#(R("8F"B`@("`@
M("`@("`@("`@("`@("`@*"@D=&AI<RT^7V1I<W!L87E4>7!E(#T]($U)345?
M0T].5$5.5%-?1$E34$Q!65]465!%7TQ)4U0I('Q\"B`@("`@("`@("`@("`@
M("`@("`@*"1T:&ES+3Y?9&ES<&QA>51Y<&4@/3T@34E-15]#3TY414Y44U]$
M25-03$%97U194$5?0D]42"DI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=%-U;6UA<GDH)&UI;65?<&%R="P@)V%T=&%C:&UE;G0G*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*"1M:6UE7W!A<G0M/F=E=$EN9F]R;6%T:6]N*"=H96%D97(G*2D@
M>PH@("`@("`@("`@("`O*B!)9B!T:&ES(&ES(&UE<W-A9V4O<F9C.#(R('!A
M<G0L(&%N9"!I="!I<R!M87)K960@87,@86X*("`@("`@("`@("`@("H@871T
M86-H;65N="P@=V4@;F5E9"!T;R!L970@9G5T=7)E(&-A;&QS('1O(&)U:6QD
M365S<V%G95!A<G0H*0H@("`@("`@("`@("`@*B!K;F]W('1H870@:70@<VAO
M=6QD(&UA<FL@96UB961D960@<&%R=',@87,@;F]T('9I97=A8FQE"B`@("`@
M("`@("`@("`J(&EN;&EN92X@*B\*("`@("`@("`@("`@)&EN8W)E;65N=%\X
M,C(@/2!F86QS93L*("`@("`@("`@("`@:68@*"@D;6EM95]P87)T+3YG9714
M>7!E*"D@/3T@)VUE<W-A9V4O<F9C.#(R)RD@)B8*("`@("`@("`@("`@("`@
M("@D;6EM95]P87)T+3YG971$:7-P;W-I=&EO;B@I(#T]("=A='1A8VAM96YT
M)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?871T86-H.#(R*RL["B`@
M("`@("`@("`@("`@("`D:6YC<F5M96YT7S@R,B`]('1R=64["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@*"1M:6UE7W!A<G0M/F=E=%!A
M<G1S*"D@87,@)'!A<G0I('L*("`@("`@("`@("`@("`@("1M<V<@+CT@)'1H
M:7,M/F)U:6QD365S<V%G95!A<G0H)'!A<G0I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H)&EN8W)E;65N=%\X,C(I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?871T86-H.#(R+2T["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;7-G.PH@("`@?0H*("`@("\J*@H@("`@
M("H@07)E('=E('9I97=I;F<@=&AI<R!P86=E(&%S(&%N(&%T=&%C:&UE;G0@
M=&AR;W5G:"!V:65W+G!H<#\*("`@("`J(%1H:7,@;65T:&]D(&-A;B!A;'-O
M(&)E(&-A;&QE9"!V:6$@34E-15]#;VYT96YT<SHZ=FEE=T%S071T86-H;65N
M="@I+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1P;W!U<"`@268@
M=')U92P@86QS;R!C:&5C:R!I9B!W92!A<F4@=FEE=VEN9R!A='1A8VAM96YT
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&EN('!O<'5P('9I97<@
M=VEN9&]W+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!W92!A<F4@=FEE=VEN9R!T:&ES('!A<G0@87,@86X@871T86-H;65N=`H@
M("`@("H@("`@("`@("`@("`@("`@("!T:')O=6=H('9I97<N<&AP+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!V:65W07-!='1A8VAM96YT*"1P;W!U<"`](&9A
M;'-E*0H@("`@>PH@("`@("`@(')E='5R;B`H*'-T<G!O<R@D7U-%4E9%4ELG
M4$A07U-%3$8G72P@)W9I97<N<&AP)RD@(3T](&9A;'-E*2`F)@H@("`@("`@
M("`@("`@("`@*"$D<&]P=7`@?'P@571I;#HZ9V5T1F]R;41A=&$H)W!O<'5P
M7W9I97<G*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A('-U;6UA
M<GD@96YT<GDN"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI
M;65?<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T>7!E("`@("`@("`@("!4:&4@<W5M;6%R>2!C86-H92!T;R!U
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-U;6UA<GDH)B1M:6UE7W!A
M<G0L("1T>7!E*0H@("`@>PH@("`@("`@(&EF("@D='EP92`]/2`G871T86-H
M;65N="<I('L*("`@("`@("`@("`@)&-A8VAE(#T@)B1T:&ES+3Y?871C.PH@
M("`@("`@('T@96QS96EF("@D='EP92`]/2`G<&%R="<I('L*("`@("`@("`@
M("`@)&-A8VAE(#T@)B1T:&ES+3Y?<W5M;6%R>3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D:V5Y
M(#T@)'1H:7,M/E]G971-24U%2V5Y*"1M:6UE7W!A<G0I.PH*("`@("`@("`D
M=&AI<RT^7W-U;6UA<GE4>7!E(#T@)'1Y<&4["B`@("`@("`@)'-U;6UA<GD@
M/2`D=&AI<RT^<&%R=%-U;6UA<GDH)&UI;65?<&%R="P@;G5L;"D["B`@("`@
M("`@)'1H:7,M/E]S=6UM87)Y5'EP92`](&YU;&P["@H@("`@("`@(&EF("@A
M96UP='DH)'-U;6UA<GDI*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P87)T<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R='-;)&ME>5T@/2!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1C86-H95LD:V5Y72`]("1S=6UM87)Y.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@<W5M;6%R:7II;F<@82!P
M87)T(&]F(&$@34E-12!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2!-
M24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@=&\@<W5M;6%R
M:7IE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&=U97-S("`@("`@("`@27,@
M=&AI<R!A('1E;7!O<F%R>2!G=65S<V5D+71Y<&4@<&%R=#\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<W5M;6%R>2!O9B!T:&4@<&%R="X*
M("`@("`J("`@("`@("`@("`@("`@(%LP72`]($EC;VX*("`@("`J("`@("`@
M("`@("`@("`@(%LQ72`]($E-05`@240*("`@("`J("`@("`@("`@("`@("`@
M(%LR72`]($1E<V-R:7!T:6]N"B`@("`@*B`@("`@("`@("`@("`@("!;,UT@
M/2!-24U%(%1Y<&4*("`@("`J("`@("`@("`@("`@("`@(%LT72`](%-I>F4*
M("`@("`J("`@("`@("`@("`@("`@(%LU72`]($1O=VYL;V%D(&QI;FLO:6-O
M;@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)T4W5M;6%R>2@F)&UI;65?<&%R
M="P@)&=U97-S(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&%T=&%C:&UE;G0@
M/2`H)&UI;65?<&%R="T^9V5T1&ES<&]S:71I;VXH*2`]/2`G871T86-H;65N
M="<I.PH@("`@("`@("1B>71E<R`]("1M:6UE7W!A<G0M/F=E=$)Y=&5S*"D[
M"B`@("`@("`@)&1E<V-R:7!T:6]N(#T@:'1M;'-P96-I86QC:&%R<R@D;6EM
M95]P87)T+3YG971$97-C<FEP=&EO;BAT<G5E+"!T<G5E*2D["B`@("`@("`@
M)'-U;6UA<GD@/2!A<G)A>2@I.PH@("`@("`@("1T>7!E(#T@:'1M;'-P96-I
M86QC:&%R<R@D;6EM95]P87)T+3YG9714>7!E*"DI.PH@("`@("`@("1V:65W
M97(@/2`F)'1H:7,M/F=E=$U)3456:65W97(H)&UI;65?<&%R="D["B`@("`@
M("`@:68@*"$D=FEE=V5R*2!["B`@("`@("`@("`@(')E='5R;B`D<W5M;6%R
M>3L*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R;B!I9B!W92!S=&EL;"!D
M:61N)W0@9FEN9"!A(&YA=&EV92!M:6UE('9I97=E<@H@("`@("`@("`J(&9O
M<B!A(&=U97-S960@;6EM92!T>7!E+B`J+PH@("`@("`@(&EF("@D9W5E<W,@
M)B8@:7-?82@D=FEE=V5R+"`G34E-15]6:65W97)?9&5F875L="<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<W5M;6%R>3L*("`@("`@("!]"@H@("`@("`@
M("\J($=E="!T:&4@34E-12!I9"!I;F1E>"X@*B\*("`@("`@("`D:60@/2`D
M=&AI<RT^7V=E=$U)345+97DH)&UI;65?<&%R="D["@H@("`@("`@("\J($EC
M;VX@8V]L=6UN+B`J+PH@("`@("`@("1S=6UM87)Y6UT@/2!(;W)D93HZ:6UG
M*"1V:65W97(M/F=E=$EC;VXH)'1Y<&4I+"!N=6QL+"!N=6QL+"`G)RD["@H@
M("`@("`@("\J($YU;6)E<B!C;VQU;6XN("HO"B`@("`@("`@:68@*"@D=&AI
M<RT^7V1I<W!L87E4>7!E(#T]($U)345?0T].5$5.5%-?1$E34$Q!65]465!%
M7T)/5$@I("8F"B`@("`@("`@("`@("%I<U]N=6QL*"1T:&ES+3Y?<W5M;6%R
M>51Y<&4I*2!["B`@("`@("`@("`@("1S=6UM87)Y6UT@/2`G/&$@:60](FUI
M;65?8V]N=&5N='-?)R`N("1T:&ES+3Y?<W5M;6%R>51Y<&4@+B`G7R<@+B`D
M:60@+B`G(B!H<F5F/2(C;6EM95]C;VYT96YT<U\G("X@*"@D=&AI<RT^7W-U
M;6UA<GE4>7!E(#T]("=A='1A8VAM96YT)RD@/R=P87)T)R`Z("=A='1A8VAM
M96YT)RD@+B`G7R<@+B`D:60@+B`G(CXG("X@)&ED("X@)SPO83XG.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1S=6UM87)Y6UT@/2`D:60["B`@
M("`@("`@?0H*("`@("`@("`O*B!.86UE+W1E>'0@<&%R="!C;VQU;6XN("HO
M"B`@("`@("`@:68@*"$D=&AI<RT^7VQI;FMS('Q\"B`@("`@("`@("`@("@A
M)&%T=&%C:&UE;G0@)B8@96UP='DH)&)Y=&5S*2D@('Q\"B`@("`@("`@("`@
M("%I<W-E="@D=&AI<RT^7W9I97=)1%LG=FEE=R==*2!\?`H@("`@("`@("`@
M("!I<U]A*"1V:65W97(L("=-24U%7U9I97=E<E]D969A=6QT)RDI('L*("`@
M("`@("`@("`@)'-U;6UA<GE;72`]("1D97-C<FEP=&EO;CL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<&%R86U?87)R87D@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!I9B`H)&=U97-S(#T]/2!T<G5E*2!["B`@("`@("`@("`@
M("`@("`D<&%R86U?87)R87E;)V-T>7!E)UT@/2`D='EP93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<W5M;6%R>5M=(#T@)'1H:7,M/FQI;FM6:65W
M2E,H)&UI;65?<&%R="P@)'1H:7,M/E]V:65W241;)W9I97<G72P@)&1E<V-R
M:7!T:6]N+"!N=6QL+"!N=6QL+"`D<&%R86U?87)R87DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@34E-12!T>7!E(&-O;'5M;BX@*B\*("`@("`@("!I9B`H
M)&=U97-S*2!["B`@("`@("`@("`@("1S=6UM87)Y6UT@/2`G/&5M/B<@+B!S
M<')I;G1F*%\H(E9I97<@87,@)7,B*2P@)'1Y<&4I("X@)SPO96T^)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@)ULG("X@
M)'1Y<&4@+B`G72<["B`@("`@("`@?0H*("`@("`@("`O*B!3:7IE($-O;'5M
M;BX@*B\*("`@("`@("`D<VEZ92`]("1M:6UE7W!A<G0M/F=E=%-I>F4H=')U
M92D["B`@("`@("`@:68@*"%E;7!T>2@D8GET97,I("8F"B`@("`@("`@("`@
M("@D;6EM95]P87)T+3YG971#=7)R96YT16YC;V1I;F<H*2`]/2`G8F%S938T
M)RDI('L*("`@("`@("`@("`@+RH@1G)O;2!21D,@,C`T-2!;-BXX73H@(BXN
M+G1H92!E;F-O9&5D(&1A=&$@87)E(&-O;G-I<W1E;G1L>0H@("`@("`@("`@
M("`@("!O;FQY(&%B;W5T(#,S('!E<F-E;G0@;&%R9V5R('1H86X@=&AE('5N
M96YC;V1E9"!D871A+B(@*B\*("`@("`@("`@("`@)'-I>F4@/2!N=6UB97)?
M9F]R;6%T*&UA>"@H*"1B>71E<R`J(#`N-S4I("\@,3`R-"DL(#$I*3L*("`@
M("`@("`@("`@)'-U;6UA<GE;72`]("<\86-R;VYY;2!T:71L93TB)R`N(%\H
M(D%P<')O>&EM871E(%-I>F4B*2`N("<B/B<@+B!S<')I;G1F*%\H(B5S($M"
M(BDL("1S:7IE*2`N("<\+V%C<F]N>6T^)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<W5M;6%R>5M=(#T@<W!R:6YT9BA?*"(E<R!+0B(I+"`D
M<VEZ92D["B`@("`@("`@?0H*("`@("`@("`O*B!$;W=N;&]A9"!C;VQU;6XN
M("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VQI;FMS('Q\"B`@("`@("`@("`@
M(&ES7VYU;&PH)'-I>F4I('Q\"B`@("`@("`@("`@("%I<W-E="@D=&AI<RT^
M7W9I97=)1%LG9&]W;FQO860G72DI('L*("`@("`@("`@("`@)'-U;6UA<GE;
M72`](&YU;&P["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-U;6UA
M<GE;72`]("1T:&ES+3YL:6YK5FEE=R@D;6EM95]P87)T+"`D=&AI<RT^7W9I
M97=)1%LG9&]W;FQO860G72P@2&]R9&4Z.FEM9R@G9&]W;FQO860N<&YG)RP@
M7R@B1&]W;FQO860B*2P@;G5L;"P@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M=$EM86=E1&ER*"=H;W)D92<I*2P@87)R87DH)VIS=&5X="<@/3X@<W!R:6YT
M9BA?*")$;W=N;&]A9"`E<R(I+"`D;6EM95]P87)T+3YG971$97-C<FEP=&EO
M;BAT<G5E+"!T<G5E*2DI+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("\J
M($EF('1H92!-24U%(%1Y<&4@:7,@87!P;&EC871I;VXO;V-T970M<W1R96%M
M+"!T<GD@=&\@=7-E"B`@("`@("`@("`@=&AE(&9I;&4@97AT96YS:6]N('1O
M(&1E=&5R;6EN92!T:&4@86-T=6%L($U)344@='EP92X@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]L:6YK<R`F)@H@("`@("`@("`@("`A)&=U97-S("8F"B`@
M("`@("`@("`@("%I<U]N=6QL*"1S:7IE*2`F)@H@("`@("`@("`@("`H)'1Y
M<&4@/3T@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<I('Q\"B`@("`@("`@
M("`@("@D='EP92`]/2`G87!P;&EC871I;VXO8F%S938T)RDI('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]-86=I
M8RYP:'`G.PH@("`@("`@("`@("`D;F5W7W1Y<&4@/2!-24U%7TUA9VEC.CIF
M:6QE;F%M951O34E-12A-24U%.CID96-O9&4H)&UI;65?<&%R="T^9V5T3F%M
M92@I*2D["B`@("`@("`@("`@(&EF("@D;F5W7W1Y<&4@(3T@)V%P<&QI8V%T
M:6]N+V]C=&5T+7-T<F5A;2<I('L*("`@("`@("`@("`@("`@("1T96UP7W!A
M<G0@/2`D;6EM95]P87)T.PH@("`@("`@("`@("`@("`@)'1E;7!?<&%R="T^
M<V5T5'EP92@D;F5W7W1Y<&4I.PH@("`@("`@("`@("`@("`@)'-U;6UA<GD@
M/2!A<G)A>5]M87`H"B`@("`@("`@("`@("`@("`@("`@8W)E871E7V9U;F-T
M:6]N*"<D82P@)&(G+"`G<F5T=7)N(&5M<'1Y*"1B*2`_("1A(#H@)&$@+B!<
M)SQB<B`O/EPG("X@)&([)RDL"B`@("`@("`@("`@("`@("`@("`@)'-U;6UA
M<GDL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!A<G13=6UM87)Y*"1T
M96UP7W!A<G0L('1R=64I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1S=6UM87)Y.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!54DP@=&\@=&AE('9I97<N<&AP('!A9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@5&AE($U)345?
M4&%R="!O8FIE8W0@=&\@=FEE=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1A
M8W1I;VY)1"`@("`@(%1H92!!8W1I;VY)1"!T;R!P97)F;W)M+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("`@02!L:7-T(&]F(&%N>2!A
M9&1I=&EO;F%L('!A<F%M971E<G,@=&AA=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;F5E9"!T;R!B92!P87-S960@=&\@=FEE=RYP
M:'`N("AK97D@/0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;F%M92D*("`@("`J($!P87)A;2!B;V]L96%N("1D;&]A9"`@("`@("`@
M(%-H;W5L9"!W92!G96YE<F%T92!A(&1O=VYL;V%D(&QI;FL_"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!54DP@=&\@=FEE=RYP:'`N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('5R;%9I97<H)B1M:6UE7W!A<G0L("1A8W1I
M;VY)1"P@)'!A<F%M<R`](&%R<F%Y*"DL("1D;&]A9"`](&9A;'-E*0H@("`@
M>PH@("`@("`@("\J($=E="!T:&4@34E-12!)1"!F;W(@=&AI<R!P87)T+B`J
M+PH@("`@("`@("1I9"`]("AI<W-E="@D<&%R86US6R=I9"==*2D@/R`D<&%R
M86US6R=I9"==(#H@)&UI;65?<&%R="T^9V5T34E-14ED*"D["@H@("`@("`@
M("\J($%D9"!T:&4@;F5C97-S87)Y(&QO8V%L('!A<F%M971E<G,N("HO"B`@
M("`@("`@)'!A<F%M<ULG86-T:6]N240G72`]("1A8W1I;VY)1#L*("`@("`@
M("`D<&%R86US6R=I9"==(#T@)&ED.PH@("`@("`@("1P87)A;7,@/2!A<G)A
M>5]M97)G92@D<&%R86US+"`D=&AI<RT^8V%C:&5)1%523%!A<F%M*"DI.PH*
M("`@("`@("!I9B`H)&1L;V%D*2!["B`@("`@("`@("`@("1U<FP@/2!(;W)D
M93HZ9&]W;FQO8615<FPH)&UI;65?<&%R="T^9V5T3F%M92AT<G5E+"!T<G5E
M*2P@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5R
M;"`](%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ87!P;&EC871I;VY5<FPH
M)W9I97<N<&AP)RDL("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1U<FP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!A(&QI
M;FL@=&\@=&AE('9I97<N<&AP('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M($U)345?4&%R="`F)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@
M=&\@=FEE=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VY)1"`@("`@
M(%1H92!A8W1I;VY)1"!V86QU92X*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@("`@("`@("`@(%1H92!L:6YK('1E>'0N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@("`@("`@("!!(&QI<W0@;V8@861D:71I;VYA;"!P87)A
M;65T97)S+@H@("`@("H@("`G8VQA<W,G("`@("`@("T@(%1H92!#4U,@8VQA
M<W,@=&\@=7-E+@H@("`@("H@("`G:G-T97AT)R`@("`@("T@(%1H92!*4R!T
M97AT('1O('5S92X*("`@("`J("`@)W9I97=P87)A;7,G("`M("!!(&QI<W0@
M;V8@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&%T(&YE960@=&\@8F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("!P87-S960@=&\@=FEE=RYP:'`N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&QO860@("`@("`@("!3:&]U;&0@
M=V4@9V5N97)A=&4@82!D;W=N;&]A9"!L:6YK/PH@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!!($A434P@:')E9B!L:6YK('1O('9I97<N<&AP+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:6YK5FEE=R@F)&UI;65?<&%R="P@)&%C
M=&EO;DE$+"`D=&5X="P@)'!A<F%M<R`](&%R<F%Y*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`D9&QO860@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M(6ES<V5T*"1P87)A;7-;)V-L87-S)UTI*2!["B`@("`@("`@("`@("1P87)A
M;7-;)V-L87-S)UT@/2!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES
M<V5T*"1P87)A;7-;)VIS=&5X="==*2D@>PH@("`@("`@("`@("`D<&%R86US
M6R=J<W1E>'0G72`]("1T97AT.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES
M<V5T*"1P87)A;7-;)W9I97=P87)A;7,G72DI('L*("`@("`@("`@("`@)'!A
M<F%M<ULG=FEE=W!A<F%M<R==(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D9&QO860I('L*("`@("`@("`@("`@)'=I;F1O=R`](&YU;&P[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'=I;F1O=R`]("=V:65W
M7R<@+B!A8G,H8W)C,S(H;6EC<F]T:6UE*"DI*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!(;W)D93HZ;&EN:R@D=&AI<RT^=7)L5FEE=R@D;6EM95]P
M87)T+"`D86-T:6]N240L("1P87)A;7-;)W9I97=P87)A;7,G72P@)&1L;V%D
M*2P@)'!A<F%M<ULG:G-T97AT)UTL("1P87)A;7-;)V-L87-S)UTL("1W:6YD
M;W<I("X@)'1E>'0@+B`G/"]A/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M96YE<F%T92!A(&IA=F%S8W)I<'0@;&EN:R!T;R!T:&4@=FEE=RYP:'`@<&%G
M92X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T
M("!4:&4@34E-15]087)T(&]B:F5C="!T;R!V:65W+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&%C=&EO;DE$("`@("`@5&AE($%C=&EO;DE$('1O('!E<F9O
M<FTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@("`@("`@("!4:&4@
M;&EN:R!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:G-T97AT("`@("`@
M("`@5&AE($IA=F%S8W)I<'0@;&EN:R!T97AT+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8W-S("`@("`@("`@("`@5&AE($-34R!C;&%S<R!T;R!U<V4N"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@("`@("!!(&QI<W0@;V8@
M86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&%T"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!N965D('1O(&)E('!A<W-E9"!T;R!V
M:65W+G!H<"X@*&ME>2`]"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!N86UE*0H@("`@("H@0'!A<F%M(&)O;VQE86X@)'=I9&=E="`@
M("`@("`@268@=')U92!U<V4@2&]R9&4Z.G=I9&=E="@I('1O(&=E;F5R871E
M+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&4Z
M.FQI;FLH*2!O=&AE<G=I<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@($$@2%1-3"!H<F5F(&QI;FL@=&\@=FEE=RYP:'`N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI;FM6:65W2E,H)B1M:6UE7W!A<G0L("1A8W1I;VY)1"P@
M)'1E>'0L("1J<W1E>'0@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@
M("`D8W-S(#T@;G5L;"P@)'!A<F%M<R`](&%R<F%Y*"DL("1W:61G970@/2!F
M86QS92D*("`@('L*("`@("`@("`O*B!)9B!V:65W:6YG('9I82!V:65W+G!H
M<"P@=V4@9&]N)W0@=V%N="!A($I3(&QI;FLN("HO"B`@("`@("`@:68@*"1T
M:&ES+3YV:65W07-!='1A8VAM96YT*"DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YL:6YK5FEE=R@D;6EM95]P87)T+"`D86-T:6]N240L("1T97AT
M+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D:G-T
M97AT*2D@>PH@("`@("`@("`@("`D:G-T97AT(#T@<W!R:6YT9BA?*")6:65W
M("5S(BDL("1M:6UE7W!A<G0M/F=E=$1E<V-R:7!T:6]N*'1R=64L('1R=64I
M*3L*("`@("`@("!]"B`@("`@("`@)'!A<F%M<ULG<&]P=7!?=FEE=R==(#T@
M,3L*"B`@("`@("`@)'5R;"`]("1T:&ES+3YU<FQ6:65W*"1M:6UE7W!A<G0L
M("1A8W1I;VY)1"P@)'!A<F%M<RD["@H@("`@("`@(&EF("@A*"1I9"`]("1M
M:6UE7W!A<G0M/F=E=$U)345)9"@I*2D@>PH@("`@("`@("`@("`D:60@/2!A
M8G,H8W)C,S(H<V5R:6%L:7IE*"1M:6UE7W!A<G0I*2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'=I9&=E="D@>PH@("`@("`@("`@("!R971U<FX@2&]R
M9&4Z.G=I9&=E="@G(R<L("1J<W1E>'0L("1C<W,L(&YU;&PL(")V:65W*"<B
M("X@)'5R;"`N("(G+"`G(B`N("1I9"`N("(G*3L@<F5T=7)N(&9A;'-E.R(L
M("1T97AT*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M2&]R9&4Z.FQI;FLH)R,G+"`D:G-T97AT+"`D8W-S+"!N=6QL+"`B=FEE=R@G
M(B`N("1U<FP@+B`B)RP@)R(@+B`D:60@+B`B)RD[(')E='5R;B!F86QS93LB
M*2`N("1T97AT("X@)SPO83XG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%!R:6YT<R!O=70@=&AE('-T871U<R!M97-S86=E(&9O<B!A(&=I
M=F5N($U)344@4&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M<V<@("`@(%1H92!M97-S86=E('1O(&]U='!U="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&EM9R`@("`@06X@:6UA9V4@;&EN:R!T;R!A9&0@=&\@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M;65S<V%G92X*("`@("`J($!P87)A;2!B;V]L96%N("1P<FEN="`@3W5T<'5T
M('1H:7,@;65S<V%G92!W:&5N(&EN(&$@<')I;G0@=FEE=S\*("`@("`J($!P
M87)A;2!S=')I;F<@)&-L87-S("`@06X@;W!T:6]N86P@<W1Y;&4@9F]R('1H
M92!S=&%T=7,@8F]X+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@9F]R;6%T=&5D('-T871U<R!M97-S86=E('-T<FEN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9F]R;6%T4W1A='5S37-G*"1M<V<L("1I;6<@/2!N=6QL
M+"`D<')I;G1A8FQE(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8VQA<W,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R
M87DH)&US9RDI('L*("`@("`@("`@("`@)&US9R`](&%R<F%Y*"1M<V<I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@268@=V4@87)E('9I97=I;F<@87,@86X@
M871T86-H;65N="P@9&]N)W0@<')I;G0@2%1-3"!C;V1E+B`J+PH@("`@("`@
M(&EF("@D=&AI<RT^=FEE=T%S071T86-H;65N="@I*2!["B`@("`@("`@("`@
M(')E='5R;B!I;7!L;V1E*")<;B(L("1M<V<I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES7VYU;&PH)&-L87-S*2D@>PH@("`@("`@("`@("`D8VQA<W,@
M/2`G;6EM95-T871U<TUE<W-A9V4G.PH@("`@("`@('T*("`@("`@("`D=&5X
M="`]("<\=&%B;&4@8VQA<W,](B<@+B`D8VQA<W,@+B`G(CXG.PH*("`@("`@
M("`O*B!)9B!N;R!I;6%G92P@<VEM<&QY('!R:6YT(&]U="!T:&4@;65S<V%G
M92X@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D:6UG*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D;7-G(&%S("1V86PI('L*("`@("`@("`@("`@("`@("1T
M97AT("X]("<\='(^/'1D/B<@+B`D=F%L("X@)SPO=&0^/"]T<CXG("X@(EQN
M(CL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T97AT("X]("<\='(^/'1D('9A;&EG;CTB;6ED9&QE(CXG("X@)&EM9R`N
M("<F;F)S<#L\+W1D/B<["B`@("`@("`@("`@("1T97AT("X]("<\=&0^)SL*
M"B`@("`@("`@("`@(&EF("AC;W5N="@D;7-G*2`]/2`Q*2!["B`@("`@("`@
M("`@("`@("`D=&5X="`N/2`D;7-G6S!=.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@)SQT86)L93XG.PH@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&US9R!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1E>'0@+CT@)SQT<CX\=&0^)R`N("1V86P@+B`G/"]T9#X\
M+W1R/B<@+B`B7&XB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'1E>'0@+CT@)SPO=&%B;&4^)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&5X="`N/2`G/"]T9#X\+W1R/B<@+B`B7&XB.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T97AT("X@)SPO=&%B;&4^)SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!A('!O:6YT97(@=&\@=&AE(&)A<V4@;V)J
M96-T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%)E='5R;G,@82!P
M;VEN=&5R('1O('1H92!B87-E(&]B:F5C="X*("`@("`J("`@("`@("`@("`@
M("`@(%)E='5R;G,@9F%L<V4@:68@=&AE<F4@:7,@;F\@8F%S92!O8FIE8W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971"87-E3V)J96-T4'1R*"D*("`@
M('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7V)A<V4I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]B87-E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E="!T:&4@34E-15]#;VYT96YT<SHZ(&]B:F5C="!T
M;R!B92!C86-H960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@5&AE(&-A8VAE($])1"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V%D9$-A8VAE*"D*("`@('L*("`@("`@("!I
M9B`H:7-?;G5L;"@D=&AI<RT^7W-E<W-I;VY#86-H94E$*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-E<W-I;VY#86-H94E$(#T@)'1H:7,M/E]C<F5A=&5#
M86-H94E$*"D["B`@("`@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T
M:6]N*&%R<F%Y*"8D=&AI<RP@)U]A9&1#86-H95-H=71D;W=N)RDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5S<VEO;D-A8VAE240[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@=6YI<75E(&-A8VAE
M($E$(&9O<B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!U;FEQ=64@
M8V%C:&4@240N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5#86-H94E$
M*"D*("`@('L*("`@("`@("!R971U<FX@;60U*&UI8W)O=&EM92@I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-A=F5S(&$@8V]P>2!O9B!T:&4@34E-15]#
M;VYT96YT<R!O8FIE8W0@870@=&AE(&5N9"!O9B!A(')E<75E<W0N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]A9&1#86-H95-H=71D;W=N*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+U-E<W-I;VY/8FIE8W1S+G!H<"<["B`@("`@("`@)&-A8VAE
M(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*"B`@("`@
M("`@+RH@1&]N)W0@<V%V92!T:&4@34E-15]6:65W97(@8V%C:&5D(&]B:F5C
M=',@<VEN8V4@=&AE<F4@:7,@;F\@96%S>0H@("`@("`@("`@('=A>2!T;R!R
M96=E;F5R871E('1H96T@;VX@8V%C:&4@<F5L;V%D+B`J+PH@("`@("`@("1T
M:&ES+3Y?=FEE=V5R0V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("`O*B!#;W!Y
M('1H92!-24U%7TUE<W-A9V4@8V%C:&4@;V)J96-T('1O('1H92!?;65S<V%G
M92!V87)I86)L92X@*B\*("`@("`@("`D=&AI<RT^7VUE<W-A9V4@/2`D=&AI
M<RT^7V-A8VAE;65S<V%G93L*"B`@("`@("`@)&-A8VAE+3YS=&]R92@D=&AI
M<RT^7W-E<W-I;VY#86-H94E$+"`D=&AI<RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!C86-H960@34E-15]#;VYT96YT<SHZ(&]B:F5C
M="X*("`@("`J(%1H:7,@9G5N8W1I;VX@<VAO=6QD(&)E(&-A;&QE9"!S=&%T
M:6-A;&QY(&4N9RXZ"B`@("`@*B`D<'1R(#T@)DU)345?0V]N=&5N=',Z.F=E
M=$-A8VAE*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%C:&5I
M9"`@5&AE(&-A8VAE($E$('1O('5S92X@($EF(&5M<'1Y+"!W:6QL('5S92!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-A8VAE($E$(&QO
M8V%T960@:6X@=&AE(%523"!P87)A;65T97(@;F%M960*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@($U)345?0T].5$5.5%-?0T%#2$4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!-24U%7T-O;G1E;G1S("!4:&4@34E-15]#;VYT
M96YT<R!O8FIE8W0L(&]R(&YU;&P@:68@:70@9&]E<R!N;W0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9G971#86-H92@D8V%C:&5I9"`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*&ES7VYU;&PH)&-A8VAE:60I*2!["B`@("`@("`@("`@("1C86-H96ED
M(#T@571I;#HZ9V5T1F]R;41A=&$H34E-15]#3TY414Y44U]#04-(12D["B`@
M("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY/
M8FIE8W1S+G!H<"<["B`@("`@("`@)&-A8VAE(#T@)DAO<F1E7U-E<W-I;VY/
M8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@("`@("`D8V]N=&5N=',@/2`F)&-A
M8VAE+3YQ=65R>2@D8V%C:&5I9"D["B`@("`@("`@<F5T=7)N("1C;VYT96YT
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!T:&4@8W5R<F5N="!O8FIE
M8W0@=&\@=&AE(&-A8VAE+"!A;F0@<F5T=7)N('1H92!C86-H92!I9&5N=&EF
M:65R"B`@("`@*B!T;R!B92!U<V5D(&EN(%523',N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@5&AE('!A<F%M971E<B!K97DO=F%L=64@<V5T('1O
M('5S92!I;B!54DQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!C86-H94E$55),
M4&%R86TH*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2A-24U%7T-/3E1%
M3E137T-!0TA%(#T^("1T:&ES+3Y?861D0V%C:&4H*2D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]-1$XN<&AP````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#(R-S,R`#$P-#$W,S8R-S<S`#`R,#$Q-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($U)345?341..CH@8VQA<W,@:6UP;&5M96YT<R!-97-S86=E($1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;G,@87,*("H@9&5S8W)I8F5D(&)Y(%)&0R`R,CDX
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<"QV
M(#$N-"XQ,"XX(#(P,#8O,#$O,C0@,C$Z,S(Z-38@<VQU<V%R>B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!C=7)E8V%N=&DN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&-U<F5C86YT:2YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J
M+PIC;&%S<R!-24U%7TU$3B!["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-15](
M96%D97)S(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R($U)345?2&5A9&5R
M<PH@("`@("HO"B`@("!V87(@)%]H96%D97)S.PH*("`@("\J*@H@("`@("H@
M5&AE('1E>'0@;V8@=&AE(&]R:6=I;F%L(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;7-G=&5X="`](&9A
M;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M($U)345?2&5A9&5R<R`D;6EM95]H96%D97)S("!!($U)345?
M2&5A9&5R<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N($U)345?341.
M*"1M:6UE7VAE861E<G,@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M:&5A9&5R<R`]("1M:6UE7VAE861E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!A9&1R97-S('1O(')E='5R;B!T:&4@341.('1O+@H@
M("`@("H@4F5T=7)N<R!N=6QL(&EF(&YO($U$3B!I<R!R97%U97-T960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!A9&1R97-S('1O('-E
M;F0@=&AE($U$3B!T;RX@4F5T=7)N<R!N=6QL(&EF(&YO"B`@("`@*B`@("`@
M("`@("`@("`@("`@341.(&ES(')E<75E<W1E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T341.4F5T=7)N061D<B@I"B`@("!["B`@("`@("`@+RH@4D9#
M(#(R.3@@6S(N,5T@<F5Q=6ER97,@=&AE($1I<W!O<VET:6]N+4YO=&EF:6-A
M:6]N+51O(&AE861E<@H@("`@("`@("`J(&9O<B!A;B!-1$X@=&\@8F4@8W)E
M871E9"X@*B\*("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D97)S+3YG9716
M86QU92@G1&ES<&]S:71I;VXM3F]T:69I8V%T:6]N+51O)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!)<R!U<V5R(&EN<'5T(')E<75I<F5D('1O('-E;F0@
M=&AE($U$3C\*("`@("`J($5X<&QI8VET(&-O;F9I<FUA=&EO;B!I<R!N965D
M960@:6X@<V]M92!C87-E<R!T;R!P<F5V96YT(&UA:6P@;&]O<',*("`@("`J
M(&%N9"!T:&4@=7-E(&]F($U$3G,@9F]R(&UA:6P@8F]M8FEN9RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($ES(&5X<&QI8VET('5S97(@:6YP
M=70@<F5Q=6ER960@=&\@<V5N9"!T:&4@341./PH@("`@("HO"B`@("!F=6YC
M=&EO;B!U<V5R0V]N9FER;6%T:6]N3F5E9&5D*"D*("`@('L*("`@("`@("`D
M<F5T=7)N7W!A=&@@/2`D=&AI<RT^7VAE861E<G,M/F=E=%9A;'5E*"=2971U
M<FXM4&%T:"<I.PH*("`@("`@("`O*B!21D,@,C(Y."!;,BXQ73H@17AP;&EC
M:70@8V]N9FER;6%T:6]N(&ES(&YE961E9"!I9B!T:&5R92!I<R!N;PH@("`@
M("`@("`J(%)E='5R;BU0871H(&EN('1H92!H96%D97(N($%L<V\L(")I9B!T
M:&4@;65S<V%G92!C;VYT86EN<R!M;W)E"B`@("`@("`@("H@=&AA;B!O;F4@
M4F5T=7)N+5!A=&@@:&5A9&5R+"!T:&4@:6UP;&5M96YT871I;VX@;6%Y(%M=
M('1R96%T('1H90H@("`@("`@("`J('-I='5A=&EO;B!A<R!A(&9A:6QU<F4@
M;V8@=&AE(&-O;7!A<FES;VXN("HO"B`@("`@("`@:68@*&5M<'1Y*"1R971U
M<FY?<&%T:"D@?'P@:7-?87)R87DH)')E='5R;E]P871H*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?
M;VYC92`G36%I;"]21D,X,C(N<&AP)SL*("`@("`@("`D<&%R<V5R(#T@)FYE
M=R!-86EL7U)&0S@R,B@I.PH*("`@("`@("`O*B!21D,@,C(Y."!;,BXQ73H@
M17AP;&EC:70@8V]N9FER;6%T:6]N(&ES(&YE961E9"!I9B!T:&5R92!I<R!M
M;W)E"B`@("`@("`@("H@=&AA;B!O;F4@9&ES=&EN8W0@861D<F5S<R!I;B!T
M:&4@1&ES<&]S:71I;VXM3F]T:69I8V%T:6]N+51O"B`@("`@("`@("H@:&5A
M9&5R+B`J+PH@("`@("`@("1A9&1R7V%R<B`]("1P87)S97(M/G!A<G-E061D
M<F5S<TQI<W0H)'1H:7,M/F=E=$U$3E)E='5R;D%D9'(H*2P@;G5L;"P@;G5L
M;"P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1A9&1R7V%R<BP@)U!%05)?
M17)R;W(G*2!\?"`H8V]U;G0H)&%D9')?87)R*2`^(#$I*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@4D9#(#(R
M.3@@6S(N,5T@<W1A=&5S('1H870@(DU$3G,@4TA/54Q$($Y/5"!B92!S96YT
M(&%U=&]M871I8V%L;'D*("`@("`@("`@*B!I9B!T:&4@861D<F5S<R!I;B!T
M:&4@1&ES<&]S:71I;VXM3F]T:69I8V%T:6]N+51O(&AE861E<B!D:69F97)S
M"B`@("`@("`@("H@9G)O;2!T:&4@861D<F5S<R!I;B!T:&4@4F5T=7)N+5!A
M=&@@:&5A9&5R+B(@5&AI<R!C;VUP87)I<V]N(&ES"B`@("`@("`@("H@8V%S
M92US96YS:71I=F4@9F]R('1H92!M86EL8F]X('!A<G0@86YD(&-A<V4M:6YS
M96YS:71I=F4@9F]R('1H90H@("`@("`@("`J(&AO<W0@<&%R="X@*B\*("`@
M("`@("`D<F5T7V%R<B`]("1P87)S97(M/G!A<G-E061D<F5S<TQI<W0H)')E
M='5R;E]P871H+"!N=6QL+"!N=6QL+"!F86QS92D["B`@("`@("`@:68@*"%I
M<U]A*"1R971?87)R+"`G4$5!4E]%<G)O<B<I("8F"B`@("`@("`@("`@("@H
M)&%D9')?87)R6S!=+3YM86EL8F]X("$]("1R971?87)R6S!=+3YM86EL8F]X
M*2!\?`H@("`@("`@("`@("`H4W1R:6YG.CIL;W=E<B@D861D<E]A<G);,%TM
M/FAO<W0I("$](%-T<FEN9SHZ;&]W97(H)')E=%]A<G);,%TM/FAO<W0I*2DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7:&5N(&=E
M;F5R871I;F<@=&AE($U$3BP@<VAO=6QD('=E(')E='5R;B!T:&4@96YI=')E
M('1E>'0@;V8@=&AE"B`@("`@*B!O<FEG:6YA;"!M97-S86=E/R`@5&AE(&1E
M9F%U;'0@:7,@;F\@+2!W92!O;FQY(')E='5R;B!T:&4@:&5A9&5R<R!O9@H@
M("`@("H@=&AE(&]R:6=I;F%L(&UE<W-A9V4N($EF('1H92!T97AT(&ES('!A
M<W-E9"!I;B!V:6$@=&AI<R!M971H;V0L('=E"B`@("`@*B!W:6QL(')E='5R
M;B!T:&4@96YT:7)E(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@5&AE('1E>'0@;V8@=&AE(&]R:6=I;F%L(&UE<W-A9V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&]R:6=I;F%L365S<V%G951E>'0H)'1E
M>'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]M<V=T97AT(#T@)'1E>'0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@341.(&%C8V]R9&EN
M9R!T;R!T:&4@<W!E8VEF:6-A=&EO;G,@;&ES=&5D(&EN(%)&0PH@("`@("H@
M,C(Y."!;,UTN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%C=&EO
M;B`@(%=A<R!T:&ES($U$3B!T>7!E(&$@<F5S=6QT(&]F(&$@;6%N=6%L(&%C
M=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&]N('!A<G0@
M;V8@=&AE('5S97(_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V5N9&EN9R`@
M5V%S('1H:7,@341.('-E;G0@87,@82!R97-U;'0@;V8@82!M86YU86P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!A8W1I;VX@;VX@<&%R="!O
M9B!T:&4@=7-E<C\*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@("!4
M:&4@='EP92!O9B!A8W1I;VX@<&5R9F]R;65D(&)Y('1H92!U<V5R+@H@("`@
M("H@/'!R93X*("`@("`J(%!E<B!21D,@,C(Y."!;,RXR+C8N,ET@=&AE(&9O
M;&QO=VEN9R!T>7!E<R!A<F4@=F%L:60Z"B`@("`@*B`]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@("`@
M*B`G9&ES<&QA>65D)PH@("`@("H@)V1I<W!A=&-H960G"B`@("`@*B`G<')O
M8V5S<V5D)PH@("`@("H@)V1E;&5T960G"B`@("`@*B`G9&5N:65D)PH@("`@
M("H@)V9A:6QE9"<*("`@("`J(#PO<')E/@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1M;V0@("`@("`@(%1H92!L:7-T(&]F(&UO9&EF:6-A=&EO;G,N"B`@("`@
M*B`\<')E/@H@("`@("H@4&5R(%)&0R`R,CDX(%LS+C(N-BXS72!T:&4@9F]L
M;&]W:6YG(&UO9&EF:6-A=&EO;G,@87)E('9A;&ED.@H@("`@("H@/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B`@("`@*B`G97)R;W(G"B`@("`@*B`G=V%R;FEN9R<*("`@
M("`J("=S=7!E<G-E9&5D)PH@("`@("H@)V5X<&ER960G"B`@("`@*B`G;6%I
M;&)O>"UT97)M:6YA=&5D)PH@("`@("H@/"]P<F4^"B`@("`@*B!`<&%R86T@
M87)R87D@)&5R<B`@("`@("`@268@)'1Y<&4@:7,@)V9A:6QU92<@;W(@)&UO
M9"!I<R!E:71H97(@)V5R<F]R)PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&]R("=W87)N:6YG)RP@=&AE(&%D9&ET:6]N86P@:6YF;W)M871I
M;VX@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!P<F]V:61E
M+B`@2V5Y(&ES('1H92!T>7!E(&]F(&UO9&EF:6-A=&EO;BP*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!V86QU92!I<R!T:&4@=&5X="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(%!%
M05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G96YE<F%T92@D86-T:6]N+"`D<V5N9&EN9RP@)'1Y<&4L("1M;V0@/2!A
M<G)A>2@I+"`D97)R(#T@87)R87DH*2D*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344O2&5A9&5R<RYP:'`G.PH@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O34E-12]-97-S86=E+G!H<"<["B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH*("`@("`@("`O*B!3970@=7`@
M<V]M92!V87)I86)L97,@=V4@=7-E(&QA=&5R+B`J+PH@("`@("`@("1I9&5N
M=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@)&9R;VU?
M861D<B`]("1I9&5N=&ET>2T^9V5T1&5F875L=$9R;VU!9&1R97-S*"D["@H@
M("`@("`@("1T;R`]("1T:&ES+3YG971-1$Y2971U<FY!9&1R*"D["@H@("`@
M("`@("1U82`]("1T:&ES+3Y?:&5A9&5R<RT^9V5T06=E;G1(96%D97(H*3L*
M"B`@("`@("`@)&]R:6=?<F5C:7`@/2`D=&AI<RT^7VAE861E<G,M/F=E=%9A
M;'5E*"=/<FEG:6YA;"U296-I<&EE;G0G*3L*("`@("`@("!I9B`H(65M<'1Y
M*"1O<FEG7W)E8VEP*2`F)B!I<U]A<G)A>2@D;W)I9U]R96-I<"DI('L*("`@
M("`@("`@("`@)&]R:6=?<F5C:7`@/2`D;W)I9U]R96-I<%LP73L*("`@("`@
M("!]"@H@("`@("`@("1M<V=?:60@/2`D=&AI<RT^7VAE861E<G,M/F=E=%9A
M;'5E*"=-97-S86=E+4E$)RD["@H@("`@("`@("\J($-R96%T92!T:&4@1&ES
M<&]S:71I;VX@9FEE;&0@;F]W("A21D,@,C(Y."!;,RXR+C9=*2X@*B\*("`@
M("`@("`D9&ES<&\@/2`G1&ES<&]S:71I;VXZ("<@+@H@("`@("`@("`@("`@
M("`@("@H)&%C=&EO;BD@/R`G;6%N=6%L+6%C=&EO;B<@.B`G875T;VUA=&EC
M+6%C=&EO;B<I("X*("`@("`@("`@("`@("`@("`G+R<@+@H@("`@("`@("`@
M("`@("`@("@H)'-E;F1I;F<I(#\@)TU$3BUS96YT+6UA;G5A;&QY)R`Z("=-
M1$XM<V5N="UA=71O;6%T:6-A;&QY)RD@+@H@("`@("`@("`@("`@("`@("<[
M("<@+@H@("`@("`@("`@("`@("`@("1T>7!E.PH@("`@("`@(&EF("@A96UP
M='DH)&UO9"DI('L*("`@("`@("`@("`@)&1I<W!O("X]("<O)R`N(&EM<&QO
M9&4H)RP@)RP@)&UO9"D["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=7`@
M=&AE(&UA:6P@:&5A9&5R<RX@*B\*("`@("`@("`D;7-G7VAE861E<G,@/2`F
M;F5W($U)345?2&5A9&5R<R@I.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D
M365S<V%G94ED2&5A9&5R*"D["B`@("`@("`@)&US9U]H96%D97)S+3YA9&1!
M9V5N=$AE861E<B@D=6$I.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A
M9&5R*"=$871E)RP@9&%T92@G<B<I*3L*("`@("`@("`D;7-G7VAE861E<G,M
M/F%D9$AE861E<B@G1G)O;2<L("1F<F]M7V%D9'(I.PH@("`@("`@("1M<V=?
M:&5A9&5R<RT^861D2&5A9&5R*"=4;R<L("1T:&ES+3YG971-1$Y2971U<FY!
M9&1R*"DI.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=3=6)J
M96-T)RP@7R@B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(BDI.PH*("`@("`@
M("`O*B!-1$YS(&%R92!A('-U8G1Y<&4@;V8@)VUU;'1I<&%R="]R97!O<G0G
M+B`J+PH@("`@("`@("1M<V<@/2`F;F5W($U)345?365S<V%G92@I.PH@("`@
M("`@("1M<V<M/G-E=%1Y<&4H)VUU;'1I<&%R="]R97!O<G0G*3L*("`@("`@
M("`D;7-G+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G<F5P;W)T+71Y<&4G
M+"`G9&ES<&]S:71I;VXM;F]T:69I8V%T:6]N)RD["@H@("`@("`@("\J(%1H
M92!F:7)S="!P87)T(&ES(&$@:'5M86X@<F5A9&%B;&4@;65S<V%G92X@*B\*
M("`@("`@("`D<&%R=%]O;F4@/2`F;F5W($U)345?4&%R="@G=&5X="]P;&%I
M;B<I.PH@("`@("`@("1P87)T7V]N92T^<V5T0VAA<G-E="A.3%,Z.F=E=$-H
M87)S970H*2D["B`@("`@("`@:68@*"1T>7!E(#T]("=D:7-P;&%Y960G*2![
M"B`@("`@("`@("`@("1P87)T7V]N92T^<V5T0V]N=&5N=',H<W!R:6YT9BA?
M*")4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<
M(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN5&AI<R!I<R!N;R!G=6%R86YT
M964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O
M;V0N(BDL("1T:&ES+3Y?:&5A9&5R<RT^9V5T5F%L=64H)T1A=&4G*2P@)'1H
M:7,M/E]H96%D97)S+3YG971686QU92@G5&\G*2P@)'1H:7,M/E]H96%D97)S
M+3YG971686QU92@G4W5B:F5C="<I*2D["B`@("`@("`@?0H@("`@("`@("\O
M(%1/1$\Z($UE<W-A9V5S(&9O<B!O=&AE<B!N;W1I9FEC871I;VX@='EP97,N
M"B`@("`@("`@)&US9RT^861D4&%R="@D<&%R=%]O;F4I.PH*("`@("`@("`O
M*B!4:&4@<V5C;VYD('!A<G0@:7,@82!M86-H:6YE+7!A<G-E86)L92!D97-C
M<FEP=&EO;BX@*B\*("`@("`@("`D<&%R=%]T=V\@/2`F;F5W($U)345?4&%R
M="@G;65S<V%G92]D:7-P;W-I=&EO;BUN;W1I9FEC871I;VXG*3L*("`@("`@
M("`D<&%R=%]T=V\M/G-E=$-O;G1E;G1S*"=297!O<G1I;F<M54$Z("<@+B`D
M1TQ/0D%,4ULG8V]N9B==6R=S97)V97(G75LG;F%M92==("X@)SL@)R`N("1U
M82`N(")<;B(I.PH@("`@("`@(&EF("@A96UP='DH)&]R:6=?<F5C:7`I*2![
M"B`@("`@("`@("`@("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)T]R:6=I
M;F%L+5)E8VEP:65N=#H@<F9C.#(R.R<@+B`D;W)I9U]R96-I<"`N(")<;B(I
M.PH@("`@("`@('T*("`@("`@("`D<&%R=%]T=V\M/F%P<&5N9$-O;G1E;G1S
M*"=&:6YA;"U296-I<&EE;G0Z(')F8S@R,CLG("X@)&9R;VU?861D<B`N(")<
M;B(I.PH@("`@("`@(&EF("@A96UP='DH)&US9U]I9"DI('L*("`@("`@("`@
M("`@)'!A<G1?='=O+3YA<'!E;F1#;VYT96YT<R@G3W)I9VEN86PM365S<V%G
M92U)1#H@<F9C.#(R.R<@+B`D;7-G7VED("X@(EQN(BD["B`@("`@("`@?0H@
M("`@("`@("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)&1I<W!O("X@(EQN
M(BD["B`@("`@("`@:68@*"@D='EP92`]/2`G9F%I;&5D)RD@)B8@:7-S970H
M)&5R<ELG9F%I;&5D)UTI*2!["B`@("`@("`@("`@("1P87)T7W1W;RT^87!P
M96YD0V]N=&5N=',H)T9A:6QU<F4Z("<@+B`D97)R6R=F86EL960G72`N(")<
M;B(I.PH@("`@("`@('T*("`@("`@("!I9B`H:6Y?87)R87DH)V5R<F]R)RP@
M)&UO9"D@)B8@:7-S970H)&5R<ELG97)R;W(G72DI('L*("`@("`@("`@("`@
M)'!A<G1?='=O+3YA<'!E;F1#;VYT96YT<R@G17)R;W(Z("<@+B`D97)R6R=E
M<G)O<B==("X@(EQN(BD["B`@("`@("`@?0H@("`@("`@(&EF("AI;E]A<G)A
M>2@G=V%R;FEN9R<L("1M;V0I("8F(&ES<V5T*"1E<G);)W=A<FYI;F<G72DI
M('L*("`@("`@("`@("`@)'!A<G1?='=O+3YA<'!E;F1#;VYT96YT<R@G5V%R
M;FEN9SH@)R`N("1E<G);)W=A<FYI;F<G72`N(")<;B(I.PH@("`@("`@('T*
M("`@("`@("`D;7-G+3YA9&1087)T*"1P87)T7W1W;RD["@H@("`@("`@("\J
M(%1H92!T:&ER9"!P87)T(&ES('1H92!T97AT(&]F('1H92!O<FEG:6YA;"!M
M97-S86=E+B`@4D9#(#(R.3@@6S-="B`@("`@("`@("H@86QL;W=S('5S('1O
M(')E='5R;B!O;FQY(&$@<&]R=&EO;B!O9B!T:&4@96YT:7)E(&UE<W-A9V4@
M+2!T:&ES"B`@("`@("`@("H@:7,@;&5F="!U<"!T;R!T:&4@=7-E<BX@*B\*
M("`@("`@("`D<&%R=%]T:')E92`]("9N97<@34E-15]087)T*"=M97-S86=E
M+W)F8S@R,B<I.PH@("`@("`@("1P87)T7W1H<F5E+3YS971#;VYT96YT<R@D
M=&AI<RT^7VAE861E<G,M/G1O4W1R:6YG*"DI.PH@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]M<V=T97AT*2D@>PH@("`@("`@("`@("`D<&%R=%]T:')E
M92T^87!P96YD0V]N=&5N=',H(EQN(B`N("1T:&ES+3Y?;7-G=&5X="D["B`@
M("`@("`@?0H@("`@("`@("1M<V<M/F%D9%!A<G0H)'!A<G1?=&AR964I.PH*
M("`@("`@("`D;7-G7VAE861E<G,M/F%D9$U)345(96%D97)S*"1M<V<I.PH*
M("`@("`@("!R971U<FX@)&US9RT^<V5N9"@D=&\L("1M<V=?:&5A9&5R<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!-1$X@*')E860@<F5C96EP
M="D@<F5Q=65S="!H96%D97)S('1O('1H92!-24U%7TAE861E<G,@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7TAE861E<G,@)B1H96%D;V(@
M(%1H92!-24U%7TAE861E<G,@;V)J96-T('1O(&%D9"!T:&4@:&5A9&5R<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T;R`@("`@("`@("`@("!4:&4@861D<F5S<R!T
M:&4@<F5C96EP="!S:&]U;&0@8F4@;6%I;&5D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T;RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D341.4F5Q=65S=$AE861E<G,H)B1H96%D;V(L("1T;RD*("`@('L*("`@
M("`@("`O*B!4:&ES(&ES('1H92!21D,@,C(Y."!W87D@;V8@<F5Q=65S=&EN
M9R!A(')E8V5I<'0N("HO"B`@("`@("`@)&AE861O8BT^861D2&5A9&5R*"=$
M:7-P;W-I=&EO;BU.;W1I9FEC871I;VXM5&\G+"`D=&\I.PH@("`@?0H*?0H`
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O4&%R="YP:'``````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R,S(Q,0`Q,#0Q-S,V
M,C<W,P`P,C`T,#``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H
M<"<["G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO34E-
M12YP:'`G.PH*+RHJ"B`J(%1H92!C:&%R86-T97(H<RD@=7-E9"!I;G1E<FYA
M;&QY(&9O<B!%3TQS+@H@*B\*9&5F:6YE*"=-24U%7U!!4E1?14],)RP@(EQN
M(BD["@HO*BH*("H@5&AE(&-H87)A8W1E<B!S=')I;F<@9&5S:6=N871E9"!B
M>2!21D-S(#@R,B\R,#0U('1O(&1E<VEG;F%T92!%3TQS(&EN($U)344*("H@
M;65S<V%G97,N"B`J+PID969I;F4H)TU)345?4$%25%]21D-?14],)RP@(EQR
M7&XB*3L*"B\J($1E9F%U;'0@34E-12!P87)A;65T97)S+B`J+PH*+RHJ"B`J
M(%1H92!D969A=6QT($U)344@8VAA<F%C=&5R('-E="X*("HO"F1E9FEN92@G
M34E-15]$149!54Q47T-(05)3150G+"`G=7,M87-C:6DG*3L*"B\J*@H@*B!4
M:&4@9&5F875L="!-24U%(&1E<V-R:7!T:6]N+@H@*B\*9&5F:6YE*"=-24U%
M7T1%1D%53%1?1$530U))4%1)3TXG+"!?*")U;FYA;65D(BDI.PH*+RHJ"B`J
M(%1H92!D969A=6QT($U)344@9&ES<&]S:71I;VXN"B`J+PID969I;F4H)TU)
M345?1$5&055,5%]$25-03U-)5$E/3B<L("=I;FQI;F4G*3L*"B\J*@H@*B!4
M:&4@9&5F875L="!-24U%(&5N8V]D:6YG+@H@*B\*9&5F:6YE*"=-24U%7T1%
M1D%53%1?14Y#3T1)3D<G+"`G-V)I="<I.PH*+RHJ"B`J(%1H92!-24U%7U!A
M<G0Z.B!C;&%S<R!P<F]V:61E<R!A('=R87!P97(@87)O=6YD($U)344@<&%R
M=',@86YD(&UE=&AO9',*("H@9F]R(&1E86QI;F<@=VET:"!T:&5M+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`L=B`Q+C$W
M-RXT+C(P(#(P,#8O,#,O,#D@,C$Z-3DZ,S$@8VAU8VL@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@
M0'!A8VMA9V4@2&]R9&5?34E-10H@*B\*8VQA<W,@34E-15]087)T('L*"B`@
M("`O*BH*("`@("`J(%1H92!T>7!E("AE>"XZ('1E>'0I(&]F('1H:7,@<&%R
M="X*("`@("`J(%!E<B!21D,@,C`T-2P@=&AE(&1E9F%U;'0@:7,@)V%P<&QI
M8V%T:6]N)RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]T>7!E(#T@)V%P<&QI8V%T:6]N)SL*"B`@("`O*BH*("`@("`J
M(%1H92!S=6)T>7!E("AE>"XZ('!L86EN*2!O9B!T:&ES('!A<G0N"B`@("`@
M*B!097(@4D9#(#(P-#4L('1H92!D969A=6QT(&ES("=O8W1E="US=')E86TG
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W-U8G1Y<&4@/2`G;V-T970M<W1R96%M)SL*"B`@("`O*BH*("`@("`J(%1H
M92!B;V1Y(&]F('1H92!P87)T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7V-O;G1E;G1S(#T@)R<["@H@("`@+RHJ"B`@
M("`@*B!4:&4@9&5S:7)E9"!T<F%N<V9E<B!E;F-O9&EN9R!O9B!T:&ES('!A
M<G0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?=')A;G-F97)%;F-O9&EN9R`]($U)345?1$5&055,5%]%3D-/1$E.1SL*
M"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT('1R86YS9F5R(&5N8V]D:6YG
M(&]F('1H92!C;VYT96YT<R!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W5R<F5N=$5N8V]D:6YG
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%-H;W5L9"!T:&4@;65S<V%G92!B
M92!E;F-O9&5D('9I82`W+6)I=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?96YC;V1E-V)I="`]('1R=64["@H@("`@
M+RHJ"B`@("`@*B!4:&4@9&5S8W)I<'1I;VX@;V8@=&AI<R!P87)T+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1E<V-R
M:7!T:6]N(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&ES<&]S:71I;VX@
M;V8@=&AI<R!P87)T("AI;FQI;F4@;W(@871T86-H;65N="DN"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9&ES<&]S:71I
M;VX@/2!-24U%7T1%1D%53%1?1$E34$]3251)3TX["@H@("`@+RHJ"B`@("`@
M*B!4:&4@9&ES<&]S:71I;VX@<&%R86UE=&5R<R!O9B!T:&ES('!A<G0N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]D:7-P
M;W-I=&EO;E!A<F%M971E<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M5&AE(&-O;G1E;G0@='EP92!P87)A;65T97)S(&]F('1H:7,@<&%R="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-O;G1E
M;G14>7!E4&%R86UE=&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<W5B<&%R=',@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R=',@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@26YF;W)M871I;VXO4W1A=&ES=&EC<R!O;B!T:&4@<W5B
M<&%R="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7VEN9F]R;6%T:6]N(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H
M92!L:7-T(&]F($-)1',@9F]R('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-I9',@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@5&AE($U)344@240@;V8@=&AI<R!P87)T+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUI;65I
M9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@<V5Q=65N8V4@=&\@=7-E
M(&%S($5/3"!F;W(@=&AI<R!P87)T+@H@("`@("H@5&AE(&1E9F%U;'0@:7,@
M8W5R<F5N=&QY('1O(&]U='!U="!T:&4@14],('-E<75E;F-E(&EN=&5R;F%L
M;'D@87,*("`@("`J(&IU<W0@(EQN(B!I;G-T96%D(&]F('1H92!C86YO;FEC
M86P@(EQR7&XB(')E<75I<F5D(&EN(%)&0R`X,C(@)B`R,#0U+@H@("`@("H@
M5&\@8F4@4D9#(&-O;7!L86EN="P@=&AE(&9U;&P@/$-2/CQ,1CX@14],(&-O
M;6)I;F%T:6]N('-H;W5L9"!B92!U<V5D"B`@("`@*B!W:&5N('-E;F1I;F<@
M82!M97-S86=E+@H@("`@("H@270@:7,@;F]T(&-R=6-I86P@:&5R92!S:6YC
M92!T:&4@4$A0+U!%05(@;6%I;&EN9R!F=6YC=&EO;G,@=VEL;"!H86YD;&4*
M("`@("`J('1H92!%3TP@9&5T86EL<RX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]E;VP@/2!-24U%7U!!4E1?14],.PH*
M("`@("\J*@H@("`@("H@26YT97)N86P@8VQA<W,@9FQA9W,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]F;&%G<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!087)T("T^($E$(&UA<'!I;F<@8V%C
M:&4N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]I9&UA<"`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!5;FEQ=64@34E-
M15]087)T(&)O=6YD87)Y('-T<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]B;W5N9&%R>2`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!$969A=6QT('9A;'5E(&9O<B!T:&ES(%!A<G0G<R!S:7IE
M+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@
M)%]B>71E<R`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="U)1"!F
M;W(@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V-O;G1E;G1I9"`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!-24U%7U!A<G0@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;6EM971Y<&4@("`@(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE
M('!A<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@("`@5&AE
M(&)O9'D@;V8@=&AE('!A<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R
M<V5T("`@("`@5&AE(&-H87)A8W1E<B!S970@;V8@=&AE('!A<G0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D:7-P;W-I=&EO;B`@5&AE(&-O;G1E;G0@9&ES
M<&]S:71I;VX@;V8@=&AE('!A<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1E
M;F-O9&EN9R`@("`@5&AE(&-O;G1E;G0@96YC;V1I;F<@;V8@=&AE(&-O;G1E
M;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!-24U%7U!A<G0H)&UI;65T>7!E
M(#T@;G5L;"P@)&-O;G1E;G1S(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@
M("`@("`D8VAA<G-E="`]($U)345?1$5&055,5%]#2$%24T54+"`D9&ES<&]S
M:71I;VX@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("1E;F-O9&EN
M9R`](&YU;&PI"B`@("!["B`@("`@("`@+RH@0W)E871E('1H92!U;FEQ=64@
M34E-15]087)T(&)O=6YD87)Y('-T<FEN9RX@*B\*("`@("`@("`D=&AI<RT^
M7V=E;F5R871E0F]U;F1A<GDH*3L*"B`@("`@("`@+RH@5&AE(&-H87)A8W1E
M<B!S970@<VAO=6QD(&%L=V%Y<R!B92!S970L(&5V96X@:68@=V4@87)E(&1E
M86QI;F<*("`@("`@("`@*B!W:71H($-O;G1E;G0M5'EP97,@;W1H97(@=&AA
M;B!T97AT+RHN("HO"B`@("`@("`@)'1H:7,M/G-E=$-H87)S970H)&-H87)S
M970I.PH*("`@("`@("!I9B`H(6ES7VYU;&PH)&UI;65T>7!E*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T5'EP92@D;6EM971Y<&4I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES7VYU;&PH)&-O;G1E;G1S*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^<V5T0V]N=&5N=',H)&-O;G1E;G1S+"`D96YC;V1I;F<I.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)&1I<W!O<VET:6]N*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<V5T1&ES<&]S:71I;VXH)&1I<W!O<VET
M:6]N*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE
M(&-O;G1E;G0M9&ES<&]S:71I;VX@;V8@=&AI<R!P87)T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1I<W!O<VET:6]N("!4:&4@8V]N=&5N="UD
M:7-P;W-I=&EO;B!T;R!S970@*&EN;&EN92!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%T=&%C:&UE;G0I+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971$:7-P;W-I=&EO;B@D9&ES<&]S:71I;VXI"B`@("!["B`@
M("`@("`@)&1I<W!O<VET:6]N(#T@4W1R:6YG.CIL;W=E<B@D9&ES<&]S:71I
M;VXI.PH*("`@("`@("!I9B`H*"1D:7-P;W-I=&EO;B`]/2`G:6YL:6YE)RD@
M?'P@*"1D:7-P;W-I=&EO;B`]/2`G871T86-H;65N="<I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?9&ES<&]S:71I;VX@/2`D9&ES<&]S:71I;VX["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!C;VYT96YT+61I
M<W!O<VET:6]N(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('!A<G0G<R!C;VYT96YT+61I<W!O<VET:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971$:7-P;W-I=&EO;B@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&ES<&]S:71I;VX["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3970@=&AE(&YA;64@;V8@=&AI<R!P87)T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@5&AE(&YA;64@=&\@<V5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971.86UE*"1N86UE*0H@("`@>PH@("`@("`@
M("1T:&ES+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G;F%M92<L("1N86UE
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@;F%M92!O9B!T:&ES
M('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1E8V]D92`@
M($U)344@9&5C;V1E(&1E<V-R:7!T:6]N/PH@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&1E9F%U;'0@($EF('1H92!N86UE('!A<F%M971E<B!D;V5S;B=T(&5X
M:7-T+"!S:&]U;&0@=V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!U<V4@=&AE(&1E9F%U;'0@;F%M92!F<F]M('1H92!D97-C<FEP=&EO;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<C\*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE('!A
M<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H)&1E8V]D92`](&9A
M;'-E+"`D9&5F875L="`](&9A;'-E*0H@("`@>PH@("`@("`@("1N86UE(#T@
M)'1H:7,M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=N86UE)RD["@H@("`@
M("`@(&EF("@D9&5F875L="`F)B!E;7!T>2@D;F%M92DI('L*("`@("`@("`@
M("`@)&YA;64@/2!P<F5G7W)E<&QA8V4H)WQ<5WPG+"`G7R<L("1T:&ES+3YG
M971$97-C<FEP=&EO;BAF86QS92P@=')U92DI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1D96-O9&4I('L*("`@("`@("`@("`@<F5T=7)N('1R:6TH34E-
M13HZ9&5C;V1E*"1N86UE*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1N86UE.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!T:&4@8F]D>2!C;VYT96YT<R!O9B!T:&ES('!A<G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=',@(%1H92!P87)T(&)O
M9'DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;F-O9&EN9R`@5&AE(&-U<G)E
M;G0@96YC;V1I;F<@;V8@=&AE(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971#;VYT96YT<R@D8V]N=&5N=',L("1E;F-O9&EN9R`](&YU;&PI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYT96YT<R`]("1C;VYT96YT<SL*
M("`@("`@("`D=&AI<RT^7V9L86=S6R=C;VYT96YT<U-E="==(#T@=')U93L*
M("`@("`@("`D=&AI<RT^7V-U<G)E;G1%;F-O9&EN9R`]("AI<U]N=6QL*"1E
M;F-O9&EN9RDI(#\@)'1H:7,M/F=E=$-U<G)E;G1%;F-O9&EN9R@I(#H@34E-
M13HZ96YC;V1I;F<H)&5N8V]D:6YG+"!-24U%7U-44DE.1RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&0@=&\@=&AE(&)O9'D@8V]N=&5N=',@;V8@=&AI
M<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G1S
M("!4:&4@8V]N=&5N=',@=&\@87!P96YD('1O('1H92!C=7)R96YT('!A<G0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!B;V1Y+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D96YC;V1I;F<@(%1H92!C=7)R96YT(&5N8V]D:6YG
M(&]F('1H92!C;VYT96YT<RX@268@;F]T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W!E8VEF:65D+"!W:6QL('1R>2!T;R!A=71O(&1E=&5R
M;6EN92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!E;F-O
M9&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@87!P96YD0V]N=&5N=',H)&-O
M;G1E;G1S+"`D96YC;V1I;F<@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES
M+3YS971#;VYT96YT<R@D=&AI<RT^7V-O;G1E;G1S("X@)&-O;G1E;G1S+"`D
M96YC;V1I;F<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQE87)S('1H92!B
M;V1Y(&-O;G1E;G1S(&]F('1H:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VQE87)#;VYT96YT<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYT
M96YT<R`]("<G.PH@("`@("`@("1T:&ES+3Y?9FQA9W-;)V-O;G1E;G1S4V5T
M)UT@/2!F86QS93L*("`@("`@("`D=&AI<RT^7V-U<G)E;G1%;F-O9&EN9R`]
M(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&)O9'D@
M;V8@=&AE('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R87<@8F]D>2!O9B!T:&4@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T0V]N=&5N=',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-O
M;G1E;G1S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N
M=&5N=',@:6X@<W1R:6-T(%)&0R`X,C(@)B`R,#0U(&]U='!U="`M(&YA;65L
M>2P@86QL"B`@("`@*B!N97=L:6YE<R!E;F0@=VET:"!T:&4@8V%N;VYI8V%L
M(#Q#4CX\3$8^('-E<75E;F-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@96YT:7)E($U)344@<&%R="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T0V%N;VYI8V%L0V]N=&5N=',H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<F5P;&%C945/3"@D=&AI<RT^7V-O;G1E;G1S+"!-24U%7U!!
M4E1?4D9#7T5/3"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4<F%N<V9E<B!E
M;F-O9&4@=&AE(&-O;G1E;G1S("AT;R!T:&4@=')A;G-F97(@96YC;V1I;F<@
M:61E;G1I9FEE9"!V:6$*("`@("`J(&=E=%1R86YS9F5R16YC;V1I;F<H*2D@
M86YD('-E="!A<R!T:&4@<&%R="=S(&YE=R!C;VYT96YT<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@=')A;G-F97)%;F-O9&5#;VYT96YT<R@I"B`@("!["B`@
M("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/G1R86YS9F5R16YC;V1E*"D["B`@
M("`@("`@)'1H:7,M/E]C=7)R96YT16YC;V1I;F<@/2`D=&AI<RT^7V9L86=S
M6R=L87-T5')A;G-F97)%;F-O9&4G73L*("`@("`@("`D=&AI<RT^<V5T0V]N
M=&5N=',H)&-O;G1E;G1S+"`D=&AI<RT^7V-U<G)E;G1%;F-O9&EN9RD["B`@
M("`@("`@)'1H:7,M/G-E=%1R86YS9F5R16YC;V1I;F<H)'1H:7,M/E]C=7)R
M96YT16YC;V1I;F<I.PH@("`@?0H*("`@("\J*@H@("`@("H@5')A;G-F97(@
M9&5C;V1E('1H92!C;VYT96YT<R!A;F0@<V5T('1H96T@87,@=&AE(&YE=R!C
M;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-F97)$96-O9&5#
M;VYT96YT<R@I"B`@("!["B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/G1R
M86YS9F5R1&5C;V1E*"D["B`@("`@("`@)'1H:7,M/E]C=7)R96YT16YC;V1I
M;F<@/2`D=&AI<RT^7V9L86=S6R=L87-T5')A;G-F97)$96-O9&4G73L*("`@
M("`@("`D=&AI<RT^<V5T5')A;G-F97)%;F-O9&EN9R@D=&AI<RT^7V-U<G)E
M;G1%;F-O9&EN9RD["@H@("`@("`@("\J($1O;B=T('-E="!C;VYT96YT<R!I
M9B!T:&5Y(&%R92!E;7!T>2P@8F5C875S92!T:&ES('=I;&P@9&\@<W1U9F8*
M("`@("`@("`@("!L:6ME(')E<V5T('1H92!I;G1E<FYA;"!B>71E<R!F:65L
M9"P@979E;B!T:&]U9V@@=V4@<VAO=6QD;B=T(&1O"B`@("`@("`@("`@=&AA
M="`H=&AE('5S97(@:&%S('1H96ER(')E87-O;G,@=&\@<V5T('1H92!B>71E
M<R!F:65L9"!T;R!A"B`@("`@("`@("`@;F]N+7IE<F\@=F%L=64@=VET:&]U
M="!P=71T:6YG('1H92!C;VYT96YT<R!I;G1O('1H:7,@<&%R="X@*B\*("`@
M("`@("!I9B`H<W1R;&5N*"1C;VYT96YT<RDI('L*("`@("`@("`@("`@)'1H
M:7,M/G-E=$-O;G1E;G1S*"1C;VYT96YT<RP@)'1H:7,M/E]C=7)R96YT16YC
M;V1I;F<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@;6EM971Y<&4@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&UI;65T>7!E("!4:&4@;6EM971Y<&4@=&\@<V5T("AE>"XZ
M('1E>'0O<&QA:6XI+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9714>7!E*"1M
M:6UE='EP92D*("`@('L*("`@("`@("`O*B!21D,@,C`T-3H@06YY(&5N=&ET
M>2!W:71H('5N<F5C;V=N:7IE9"!E;F-O9&EN9R!M=7-T(&)E('1R96%T960*
M("`@("`@("`@("!A<R!I9B!I="!H87,@82!#;VYT96YT+51Y<&4@;V8@(F%P
M<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2(*("`@("`@("`@("!R96=A<F1L97-S
M(&]F('=H870@=&AE($-O;G1E;G0M5'EP92!F:65L9"!A8W1U86QL>2!S87ES
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W1R86YS9F5R16YC;V1I;F<@/3T@
M)W@M=6YK;F]W;B<I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4V5T('1H92`G<V5T5'EP92<@9FQA9RX@*B\*("`@("`@
M("`D=&AI<RT^7V9L86=S6R=S9714>7!E)UT@/2!T<G5E.PH*("`@("`@("!L
M:7-T*"1T:&ES+3Y?='EP92P@)'1H:7,M/E]S=6)T>7!E*2`](&5X<&QO9&4H
M)R\G+"!3=')I;F<Z.FQO=V5R*"1M:6UE='EP92DI.PH@("`@("`@(&EF("@H
M)'1Y<&4@/2!-24U%.CIT>7!E*"1T:&ES+3Y?='EP92P@34E-15]35%))3D<I
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1Y<&4@/2`D='EP93L*"B`@("`@
M("`@("`@("\J(%-E="!T:&4@8F]U;F1A<GD@<W1R:6YG(&9O<B`G;75L=&EP
M87)T+RHG('!A<G1S+B`J+PH@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)VUU
M;'1I<&%R="<I('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/F=E=$-O
M;G1E;G14>7!E4&%R86UE=&5R*"=B;W5N9&%R>2<I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=B;W5N
M9&%R>2<L("1T:&ES+3Y?9V5N97)A=&5";W5N9&%R>2@I*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YC;&5A<D-O;G1E;G14>7!E4&%R86UE=&5R*"=B;W5N9&%R>2<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]T>7!E(#T@)W@M=6YK;F]W;B<["B`@("`@("`@("`@("1T:&ES
M+3YC;&5A<D-O;G1E;G14>7!E4&%R86UE=&5R*"=B;W5N9&%R>2<I.PH@("`@
M("`@('T*("`@('T*"B`@("`@+RHJ"B`@("`@("H@1V5T('1H92!F=6QL($U)
M344@0V]N=&5N="U4>7!E(&]F('1H:7,@<&%R="X*("`@("`@*@H@("`@("`J
M($!P87)A;2!B;V]L96%N("1C:&%R<V5T("!!<'!E;F0@8VAA<F%C=&5R('-E
M="!I;F9O<FUA=&EO;B!T;R!T:&4@96YD(&]F"B`@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!C;VYT96YT('1Y<&4@:68@=&AI<R!I<R!A
M('1E>'0O*B!P87)T+@H@("`@("`J"B`@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!M:6UE='EP92!O9B!T:&ES('!A<G0*("`@("`@*B`@("`@("`@("`@
M("`@("`@*&5X+CH@=&5X="]P;&%I;CL@8VAA<G-E=#UU<RUA<V-I:2DN"B`@
M("`@("HO"B`@("`@9G5N8W1I;VX@9V5T5'EP92@D8VAA<G-E="`](&9A;'-E
M*0H@("`@('L*("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W1Y<&4I('Q\
M("%I<W-E="@D=&AI<RT^7W-U8G1Y<&4I*2!["B`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@('T*("`@("`@("`@)'!T>7!E(#T@)'1H:7,M
M/F=E=%!R:6UA<GE4>7!E*"D["B`@("`@("`@("1T>7!E(#T@)'!T>7!E("X@
M)R\G("X@)'1H:7,M/F=E=%-U8E1Y<&4H*3L*("`@("`@("`@:68@*"1C:&%R
M<V5T("8F("@D<'1Y<&4@/3T@)W1E>'0G*2D@>PH@("`@("`@("`@("`@)'1Y
M<&4@+CT@)SL@8VAA<G-E=#TG("X@)'1H:7,M/F=E=$-H87)S970H*3L*("`@
M("`@("`@?0H@("`@("`@("!R971U<FX@)'1Y<&4["B`@("`@?0H*("`@("\J
M*@H@("`@("H@268@=&AE('-U8G1Y<&4@;V8@82!-24U%('!A<G0@:7,@=6YR
M96-O9VYI>F5D(&)Y(&%N(&%P<&QI8V%T:6]N+"!T:&4*("`@("`J(&1E9F%U
M;'0@='EP92!S:&]U;&0@8F4@=7-E9"!I;G-T96%D("A3964@4D9#(#(P-#8I
M+B`@5&AI<R!M971H;V0*("`@("`J(')E='5R;G,@=&AE(&1E9F%U;'0@<W5B
M='EP92!F;W(@82!P87)T:6-U;&%R('!R:6UA<GD@34E-12!4>7!E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5F875L="!M:6UE='EP
M92!O9B!T:&ES('!A<G0@*&5X+CH@=&5X="]P;&%I;BDN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$1E9F%U;'14>7!E*"D*("`@('L*("`@("`@("!S=VET
M8V@@*"1T:&ES+3YG9710<FEM87)Y5'EP92@I*2!["B`@("`@("`@8V%S92`G
M=&5X="<Z"B`@("`@("`@("`@("\J(%)&0R`R,#0V("@T+C$N-"DZ('1E>'0@
M<&%R=',@9&5F875L="!T;R!T97AT+W!L86EN+B`J+PH@("`@("`@("`@("!R
M971U<FX@)W1E>'0O<&QA:6XG.PH*("`@("`@("!C87-E("=M=6QT:7!A<G0G
M.@H@("`@("`@("`@("`O*B!21D,@,C`T-B`H-2XQ+C,I.B!M=6QT:7!A<G0@
M<&%R=',@9&5F875L="!T;R!M=6QT:7!A<G0O;6EX960N("HO"B`@("`@("`@
M("`@(')E='5R;B`G;75L=&EP87)T+VUI>&5D)SL*"B`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@+RH@4D9#(#(P-#8@*#0N,BP@-"XS+"`T+C0L(#0N
M-2XS+"`U+C(N-"DZ(&%L;"!O=&AE<G,@9&5F875L="!T;PH@("`@("`@("`@
M("`@("!A<'!L:6-A=&EO;B]O8W1E="US=')E86TN("HO"B`@("`@("`@("`@
M(')E='5R;B`G87!P;&EC871I;VXO;V-T970M<W1R96%M)SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('!R:6UA<GD@='EP92!O
M9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!P<FEM87)Y($U)344@='EP92!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!R:6UA<GE4>7!E*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H
M92!S=6)T>7!E(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE($U)344@<W5B='EP92!O9B!T:&ES('!A<G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%-U8E1Y<&4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W-U8G1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M970@=&AE(&-H87)A8W1E<B!S970@;V8@=&AI<R!P87)T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@<V5T
M(&]F('1H:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0VAA<G-E
M="@D8VAA<G-E="D*("`@('L*("`@("`@("`D=&AI<RT^<V5T0V]N=&5N=%1Y
M<&5087)A;65T97(H)V-H87)S970G+"`D8VAA<G-E="D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE(&-H87)A8W1E<B!S970@=&\@=7-E(&9O<B!O
M9B!T:&ES('!A<G0N("!2971U<FYS(&$@8VAA<G-E="!F;W(*("`@("`J(&%L
M;"!T>7!E<R`H;F]T(&IU<W0@)W1E>'0O*B<I('-I;F-E('=E('5S92!T:&ES
M(&-H87)S970@=&\@9&5T97)M:6YE"B`@("`@*B!H;W<@=&\@96YC;V1E('1E
M>'0@:6X@34E-12!H96%D97)S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8VAA<F%C=&5R('-E="!O9B!T:&ES('!A<G0N("!2971U<FYS
M(&YU;&P@:68@=&AE<F4*("`@("`J("`@("`@("`@("`@("`@("!I<R!N;R!C
M:&%R86-T97(@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#:&%R<V5T
M*"D*("`@('L*("`@("`@("`D8VAA<G-E="`]("1T:&ES+3YG971#;VYT96YT
M5'EP95!A<F%M971E<B@G8VAA<G-E="<I.PH@("`@("`@(')E='5R;B`H96UP
M='DH)&-H87)S970I*2`_(&YU;&P@.B`D8VAA<G-E=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@9&5S8W)I<'1I;VX@;V8@=&AI<R!P87)T+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1E<V-R:7!T:6]N("!4:&4@
M9&5S8W)I<'1I;VX@;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971$97-C<FEP=&EO;B@D9&5S8W)I<'1I;VXI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]D97-C<FEP=&EO;B`]($U)344Z.F5N8V]D92@D9&5S8W)I<'1I
M;VXL("1T:&ES+3YG971#:&%R<V5T*"DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!D97-C<FEP=&EO;B!O9B!T:&ES('!A<G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&1E8V]D92`@($U)344@9&5C;V1E(&1E
M<V-R:7!T:6]N/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1E9F%U;'0@($EF
M('1H92!N86UE('!A<F%M971E<B!D;V5S;B=T(&5X:7-T+"!S:&]U;&0@=V4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!U<V4@=&AE(&1E9F%U
M;'0@;F%M92!F<F]M('1H92!D97-C<FEP=&EO;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('!A<F%M971E<C\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&1E<V-R:7!T:6]N(&]F('1H:7,@<&%R="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T1&5S8W)I<'1I;VXH)&1E8V]D92`](&9A
M;'-E+"`D9&5F875L="`](&9A;'-E*0H@("`@>PH@("`@("`@("1D97-C(#T@
M)'1H:7,M/E]D97-C<FEP=&EO;CL*"B`@("`@("`@:68@*"1D969A=6QT("8F
M(&5M<'1Y*"1D97-C*2D@>PH@("`@("`@("`@("`D9&5S8R`]("1T:&ES+3YG
M971.86UE*"D["B`@("`@("`@("`@(&EF("AE;7!T>2@D9&5S8RDI('L*("`@
M("`@("`@("`@("`@("1D97-C(#T@34E-15]$149!54Q47T1%4T-225!424].
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&1E8V]D
M92D@>PH@("`@("`@("`@("!R971U<FX@34E-13HZ9&5C;V1E*"1D97-C*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)&1E<V,["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T<F%N<V9E
M<B!E;F-O9&EN9R!T;R!U<V4@9F]R('1H:7,@<&%R="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1E;F-O9&EN9R`@5&AE('1R86YS9F5R(&5N8V]D
M:6YG('1O('5S92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5')A;G-F97)%
M;F-O9&EN9R@D96YC;V1I;F<I"B`@("!["B`@("`@("`@:68@*"@D;6EM95]E
M;F-O9&EN9R`]($U)344Z.F5N8V]D:6YG*"1E;F-O9&EN9RP@34E-15]35%))
M3D<I*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1R86YS9F5R16YC;V1I;F<@
M/2`D;6EM95]E;F-O9&EN9SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O*B!21D,@,C`T-3H@06YY(&5N=&ET>2!W:71H('5N<F5C;V=N:7IE9"!E
M;F-O9&EN9R!M=7-T(&)E('1R96%T960*("`@("`@("`@("`@("`@87,@:68@
M:70@:&%S(&$@0V]N=&5N="U4>7!E(&]F(")A<'!L:6-A=&EO;B]O8W1E="US
M=')E86TB"B`@("`@("`@("`@("`@(')E9V%R9&QE<W,@;V8@=VAA="!T:&4@
M0V]N=&5N="U4>7!E(&9I96QD(&%C='5A;&QY('-A>7,N("HO"B`@("`@("`@
M("`@("1T:&ES+3YS9714>7!E*"=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG
M*3L*("`@("`@("`@("`@)'1H:7,M/E]T<F%N<V9E<D5N8V]D:6YG(#T@)W@M
M=6YK;F]W;B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D
M(&$@34E-12!S=6)P87)T+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A
M<G0@)&UI;65?<&%R="`@061D(&$@34E-15]087)T('-U8G!A<G0@=&\@=&AE
M(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M34E-15]087)T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YD97@@("`@("`@
M("!4:&4@:6YD97@@;V8@=&AE(&%D9&5D($U)345?4&%R="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D4&%R="@D;6EM95]P87)T+"`D:6YD97@@/2!N=6QL
M*0H@("`@>PH@("`@("`@("\J($%D9"!T:&4@<&%R="!T;R!T:&4@<&%R=',@
M;&ES="X@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D:6YD97@I*2!["B`@("`@
M("`@("`@(&5N9"@D=&AI<RT^7W!A<G1S*3L*("`@("`@("`@("`@)&ED(#T@
M:V5Y*"1T:&ES+3Y?<&%R=',I("L@,3L*("`@("`@("`@("`@)'!T<B`]("8D
M=&AI<RT^7W!A<G1S.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M='(@/2`F)'1H:7,M/E]P87)T1FEN9"@D:6YD97@L("1T:&ES+3Y?<&%R=',L
M('1R=64I.PH@("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')R<&]S*"1I;F1E
M>"P@)RXG*2DI('L*("`@("`@("`@("`@("`@("1I9"`]('-U8G-T<B@D:6YD
M97@L("1P;W,@*R`Q*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1I9"`]("1I;F1E>#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@4V5T('1H92!-24U%($E$(&EF(&ET(&AA<R!N;W0@86QR
M96%D>2!B965N('-E="X@*B\*("`@("`@("!I9B`H)&UI;65?<&%R="T^9V5T
M34E-14ED*"D@/3T](&YU;&PI('L*("`@("`@("`@("`@)&UI;65?<&%R="T^
M<V5T34E-14ED*"1I9"D["B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T
M:&4@<&%R="!N;W<N("HO"B`@("`@("`@)'!T<ELD:61=(#T@)&UI;65?<&%R
M=#L*"B`@("`@("`@+RH@0VQE87(@=&AE($E$("T^(%!A<G0@;6%P<&EN9R!C
M86-H92X@*B\*("`@("`@("`D=&AI<RT^7VED;6%P(#T@87)R87DH*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@86QL($U)344@<W5B
M<&%R=',N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M;V8@=&AE($U)345?4&%R="!S=6)P87)T<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&%R=',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M<G1S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@82!S<&5C:69I
M8R!-24U%('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@
M(%1H92!-24U%7U!A<G0@240@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U
M<FX@34E-15]087)T("!4:&4@34E-15]087)T(')E<75E<W1E9"P@;W(@9F%L
M<V4@:68@=&AE('!A<G0*("`@("`J("`@("`@("`@("`@("`@("`@("!D;V5S
M;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)T*"1I9"D*
M("`@('L*("`@("`@("`D;6EM96ED(#T@)'1H:7,M/F=E=$U)345)9"@I.PH*
M("`@("`@("`O*B!4:&ES('=I;&P@8V]N=F5R="`G(RXP)R!T;R!S:6UP;'D@
M)R,G+"!W:&EC:"!I<R!H;W<@=&AE('!A<G0@:7,*("`@("`@("`@*B!I;G1E
M<FYA;&QY('-T;W)E9"X@*B\*("`@("`@("`D<V5A<F-H7VED(#T@)&ED.PH@
M("`@("`@(&EF("@H)'-T<B`]('-T<G)C:'(H)&ED+"`G+B<I*2`F)@H@("`@
M("`@("`@("`H)'-T<B`]/2`G+C`G*2D@>PH@("`@("`@("`@("`D<V5A<F-H
M7VED(#T@<W5B<W1R*"1S96%R8VA?:60L(#`L("TR*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E='5R;B!T:&ES('!A<G0@:68Z"B`@("`@("`@("`@,2D@
M5&AE<F4@:7,@;VYL>2!O;F4@<&%R="`H92YG+B!T:&4@34E-12!)1"!I<R`P
M+"!O<B!T:&4*("`@("`@("`@("`@("!-24U%($E$(&ES(#$@86YD('1H97)E
M(&%R92!N;R!S=6)P87)T<RX*("`@("`@("`@("`R*2`D:60@;6%T8VAE<R!T
M:&ES('!A<G1S($U)344@240N("HO"B`@("`@("`@:68@*"@D<V5A<F-H7VED
M(#T](#`I('Q\"B`@("`@("`@("`@("@H)'-E87)C:%]I9"`]/2`Q*2`F)B`A
M8V]U;G0H)'1H:7,M/E]P87)T<RDI('Q\"B`@("`@("`@("`@("@A96UP='DH
M)&UI;65I9"D@)B8@*"1S96%R8VA?:60@/3T@)&UI;65I9"DI*2!["B`@("`@
M("`@("`@("1P87)T(#T@)'1H:7,["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'!A<G0@/2`D=&AI<RT^7W!A<G1&:6YD*"1I9"P@)'1H:7,M/E]P
M87)T<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'!A<G0@)B8*("`@("`@
M("`@("`@*"1S96%R8VA?:60@(3T@)&ED*2`F)@H@("`@("`@("`@("`H)'!A
M<G0M/F=E=%1Y<&4H*2`]/2`G;65S<V%G92]R9F,X,C(G*2D@>PH@("`@("`@
M("`@("`D<F5T7W!A<G0@/2!5=&EL.CIC;&]N94]B:F5C="@D<&%R="D["B`@
M("`@("`@("`@("1R971?<&%R="T^7W!A<G1S(#T@87)R87DH*3L*("`@("`@
M("`@("`@<F5T=7)N("1R971?<&%R=#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!A($U)
M345?4&%R="!S=6)P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("!4:&4@34E-12!087)T('1O(&1E;&5T92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5M;W9E4&%R="@D:60I"B`@("!["B`@("`@("`@:68@*"@D<'1R
M(#T@)B1T:&ES+3Y?<&%R=$9I;F0H)&ED+"`D=&AI<RT^7W!A<G1S*2DI('L*
M("`@("`@("`@("`@=6YS970H)'!T<BD["B`@("`@("`@("`@("1T:&ES+3Y?
M:61M87`@/2!A<G)A>2@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($%L=&5R(&$@8W5R<F5N="!-24U%('-U8G!A<G0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("!4:&4@34E-12!087)T
M($E$('1O(&%L=&5R+@H@("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM95]P
M87)T("!4:&4@34E-12!087)T('1O('-T;W)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A;'1E<E!A<G0H)&ED+"`D;6EM95]P87)T*0H@("`@>PH@("`@("`@
M(&EF("@H)'!T<B`]("8D=&AI<RT^7W!A<G1&:6YD*"1I9"P@)'1H:7,M/E]P
M87)T<RDI*2!["B`@("`@("`@("`@("1P='(@/2`D;6EM95]P87)T.PH@("`@
M("`@("`@("`D=&AI<RT^7VED;6%P(#T@87)R87DH*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!U<V5D('1O(&9I;F0@82!S
M<&5C:69I8R!-24U%(%!A<G0@8GD@240N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@
M("`@("!4:&4@34E-15]087)T($E$('-T<FEN9RX*("`@("`J($!P87)A;2!A
M<G)A>2`F)'!A<G1S("`@("`@02!L:7-T(&]F($U)345?4&%R="!O8FIE8W1S
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E=&%R<F%Y("!2971U<FX@82!P
M;VEN=&5R('1O('1H92!A<G)A>2!T:&%T('-T;W)E<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H=V]U;&0@<W1O<F4I('1H92!P87)T(')A
M=&AE<B!T:&%N('1H92!P87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&ET<V5L9C\*("`@("`J+PH@("`@9G5N8W1I;VX@)E]P87)T1FEN
M9"@D:60L("8D<&%R=',L("1R971A<G)A>2`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\J(%!O:6YT97)S(&1O;B=T('!E<G-I<W0@=&AR;W5G:"!S97-S:6]N
M<SL@=&AE<F5F;W)E+"!W92!M=7-T(&UA:V4*("`@("`@("`@*B!S=7)E('1H
M870@=&AE($ED36%P(&ES(&1E<W1R;WEE9"!A="!T:&4@96YD(&]F(&5A8V@@
M<F5Q=65S="X*("`@("`@("`@*B!(;W<@8V%N('=E(&1O('1H:7,_(%=E(&-H
M96-K('1O('-E92!I9B`D7VED;6%P(&-O;G1A:6YS(&%N(&%R<F%Y"B`@("`@
M("`@("H@;V8@34E-15]087)T<R!O<B!A;B!A<G)A>2!O9B!A<G)A>7,N("HO
M"B`@("`@("`@)&-H96-K(#T@<F5S970H)'1H:7,M/E]I9&UA<"D["B`@("`@
M("`@:68@*&5M<'1Y*"1C:&5C:RD@?'P@(6ES7V$H)&-H96-K+"`G34E-15]0
M87)T)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]I9&UA<"`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?9V5N97)A=&5)9$UA<"@D=&AI<RT^7W!A
M<G1S*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5T87)R87DI('L*("`@
M("`@("`@("`@:68@*"1P;W,@/2!S=')R<&]S*"1I9"P@)RXG*2D@>PH@("`@
M("`@("`@("`@("`@)&ED(#T@<W5B<W1R*"1I9"P@,"P@)'!O<RD["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)'!A<G1S
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]I9&UA<%LD:61=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]I9&UA<%LD:61=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1P87)T(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R;B`D<&%R=#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@82!M87!P
M:6YG(&]F($U)345?4&%R=',@=VET:"!T:&5I<B!-24U%($E$<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)B1P87)T<R`@06X@87)R87D@;V8@34E-15]087)T<R!T;R!M87`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G96YE<F%T94ED36%P*"8D<&%R=',I
M"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D<&%R=',I*2!["B`@("`@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'!A<G1S*2!A<R`D:V5Y*2!["B`@
M("`@("`@("`@("`@("`D<'1R(#T@)B1P87)T<ULD:V5Y73L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:61M87!;)'!T<BT^9V5T34E-14ED*"E=(#T@)B1P
M='(["B`@("`@("`@("`@("`@("`D=&AI<RT^7V=E;F5R871E261-87`H)'!T
M<BT^7W!A<G1S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9"!I;F9O<FUA=&EO;B!A8F]U="!T:&4@34E-15]0
M87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!4:&4@
M:6YF;W)M871I;VX@;&%B96PN"B`@("`@*B!`<&%R86T@;6EX960@)&1A=&$@
M("`@5&AE(&EN9F]R;6%T:6]N('1O('-T;W)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971);F9O<FUA=&EO;B@D;&%B96PL("1D871A*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?:6YF;W)M871I;VY;)&QA8F5L72`]("1D871A.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@:6YF;W)M871I;VX@86)O=70@
M=&AE($U)345?4&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L
M86)E;"`@5&AE(&EN9F]R;6%T:6]N(&QA8F5L+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1H92!I;F9O<FUA=&EO;B!R97%U97-T960N"B`@("`@
M*B`@("`@("`@("`@("`@("!2971U<FYS(&9A;'-E(&EF("1L86)E;"!I<R!N
M;W0@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);F9O<FUA=&EO;B@D
M;&%B96PI"B`@("!["B`@("`@("`@<F5T=7)N("AI<W-E="@D=&AI<RT^7VEN
M9F]R;6%T:6]N6R1L86)E;%TI*2`_("1T:&ES+3Y?:6YF;W)M871I;VY;)&QA
M8F5L72`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@9&ES
M<&]S:71I;VX@<&%R86UE=&5R('1O('1H:7,@<&%R="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1L86)E;"`@5&AE(&1I<W!O<VET:6]N('!A<F%M
M971E<B!L86)E;"X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("!4:&4@
M9&ES<&]S:71I;VX@<&%R86UE=&5R(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$1I<W!O<VET:6]N4&%R86UE=&5R*"1L86)E;"P@)&1A=&$I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]D:7-P;W-I=&EO;E!A<F%M971E<G-;)&QA
M8F5L72`]("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@9&ES
M<&]S:71I;VX@<&%R86UE=&5R(&9R;VT@=&AI<R!P87)T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!4:&4@9&ES<&]S:71I;VX@<&%R
M86UE=&5R(&QA8F5L+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@9&%T82!R97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T
M=7)N<R!F86QS92!I9B`D;&%B96P@:7,@;F]T('-E="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1&ES<&]S:71I;VY087)A;65T97(H)&QA8F5L*0H@("`@
M>PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]D:7-P;W-I=&EO;E!A
M<F%M971E<G-;)&QA8F5L72DI(#\@)'1H:7,M/E]D:7-P;W-I=&EO;E!A<F%M
M971E<G-;)&QA8F5L72`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T(&%L;"!P87)A;65T97)S(&9R;VT@=&AE($-O;G1E;G0M1&ES<&]S:71I
M;VX@:&5A9&5R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R
M<F%Y(&]F(&%L;"!T:&4@<&%R86UE=&5R<PH@("`@("H@("`@("`@("`@("`@
M("`@4F5T=7)N<R!T:&4@96UP='D@87)R87D@:68@;F\@<&%R86UE=&5R<R!S
M970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%L;$1I<W!O<VET:6]N4&%R
M86UE=&5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&ES<&]S
M:71I;VY087)A;65T97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@
M8V]N=&5N="!T>7!E('!A<F%M971E<B!T;R!T:&ES('!A<G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!D:7-P;W-I=&EO;B!P
M87)A;65T97(@;&%B96PN"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@
M5&AE(&1I<W!O<VET:6]N('!A<F%M971E<B!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971#;VYT96YT5'EP95!A<F%M971E<B@D;&%B96PL("1D871A
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S
M6R1L86)E;%T@/2`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J($-L96%R
M<R!A(&-O;G1E;G0@='EP92!P87)A;65T97(@9G)O;2!T:&ES('!A<G0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!D:7-P;W-I
M=&EO;B!P87)A;65T97(@;&%B96PN"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M871A("`@5&AE(&1I<W!O<VET:6]N('!A<F%M971E<B!D871A+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;&5A<D-O;G1E;G14>7!E4&%R86UE=&5R*"1L86)E
M;"D*("`@('L*("`@("`@("!U;G-E="@D=&AI<RT^7V-O;G1E;G14>7!E4&%R
M86UE=&5R<ULD;&%B96Q=*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M(&-O;G1E;G0@='EP92!P87)A;65T97(@9G)O;2!T:&ES('!A<G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!C;VYT96YT('1Y
M<&4@<&%R86UE=&5R(&QA8F5L+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@9&%T82!R97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@
M("`@4F5T=7)N<R!F86QS92!I9B`D;&%B96P@:7,@;F]T('-E="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)&QA8F5L
M*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]C;VYT96YT
M5'EP95!A<F%M971E<G-;)&QA8F5L72DI(#\@)'1H:7,M/E]C;VYT96YT5'EP
M95!A<F%M971E<G-;)&QA8F5L72`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&%L;"!P87)A;65T97)S(&9R;VT@=&AE($-O;G1E;G0M5'EP
M92!H96%D97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R
M87D@;V8@86QL('1H92!P87)A;65T97)S"B`@("`@*B`@("`@("`@("`@("`@
M("!2971U<FYS('1H92!E;7!T>2!A<G)A>2!I9B!N;R!P87)A;65T97)S('-E
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06QL0V]N=&5N=%1Y<&5087)A
M;65T97)S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT
M5'EP95!A<F%M971E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@
M;F5W('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D96]L("!4:&4@<W1R:6YG('1O('5S92!F;W(@14],<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T14],*"1E;VPI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]E;VP@/2`D96]L.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!S=')I;F<@=&\@=7-E(&9O<B!%3TQS+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<W1R:6YG('1O('5S92!F;W(@14],<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T14],*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]E;VP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M=&AE(&%P<')O<')I871E($U)344@:&5A9&5R<R!F;W(@=&AI<R!P87)T('1O
M(&%N(&5X:7-T:6YG(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D:&5A9&5R<R`@06X@87)R87D@;V8@86YY(&]T:&5R(&AE861E<G,@9F]R
M('1H92!P87)T+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!H
M96%D97)S+"!W:71H('1H92!-24U%(&AE861E<G,@861D960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&AE861E<B@D:&5A9&5R<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)&5O;"`]("1T:&ES+3YG971%3TPH*3L*("`@("`@("`D<'1Y
M<&4@/2`D=&AI<RT^9V5T4')I;6%R>51Y<&4H*3L*("`@("`@("`D<W1Y<&4@
M/2`D=&AI<RT^9V5T4W5B5'EP92@I.PH*("`@("`@("`O*B!'970@=&AE(&-H
M87)A8W1E<B!S970@9F]R('1H:7,@<&%R="X@*B\*("`@("`@("`D8VAA<G-E
M="`]("1T:&ES+3YG971#:&%R<V5T*"D["@H@("`@("`@("\J($=E="!T:&4@
M0V]N=&5N="U4>7!E("T@=&AI<R!I<R!!3%=!65,@<F5Q=6ER960N("HO"B`@
M("`@("`@)&-T>7!E(#T@)'1H:7,M/F=E=%1Y<&4H=')U92D["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/F=E=$%L;$-O;G1E;G14>7!E4&%R86UE=&5R<R@I
M(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("\J(%-K:7`@=&AE
M(&-H87)S970@:V5Y('-I;F-E('1H870@=V]U;&0@:&%V92!A;')E861Y(&)E
M96X*("`@("`@("`@("`@("H@861D960@=&\@)&-T>7!E(&)Y(&=E=%1Y<&4H
M*2X@*B\*("`@("`@("`@("`@:68@*"1K97D@/3T@)V-H87)S970G*2!["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D8W1Y<&4@+CT@)SL@)R`N("1K97D@+B`G/2(G("X@<W1R7W)E<&QA
M8V4H)R(G+"`G7"(G+"!-24U%.CIE;F-O9&4H)'9A;'5E+"`D8VAA<G-E="DI
M("X@)R(G.PH@("`@("`@('T*("`@("`@("`D:&5A9&5R<ULG0V]N=&5N="U4
M>7!E)UT@/2!-24U%.CIW<F%P2&5A9&5R<R@G0V]N=&5N="U4>7!E)RP@)&-T
M>7!E+"`D96]L*3L*"B`@("`@("`@+RH@1V5T('1H92!D97-C<FEP=&EO;BP@
M:68@86YY+B`J+PH@("`@("`@(&EF("@H)&1E<V-R:7`@/2`D=&AI<RT^9V5T
M1&5S8W)I<'1I;VXH*2DI('L*("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E
M;G0M1&5S8W)I<'1I;VXG72`]($U)344Z.G=R87!(96%D97)S*"=#;VYT96YT
M+41E<V-R:7!T:6]N)RP@34E-13HZ96YC;V1E*"1D97-C<FEP+"`D8VAA<G-E
M="DL("1E;VPI.PH@("`@("`@('T*"B`@("`@("`@+RH@4D9#(#(P-#4@6S1=
M("T@;65S<V%G92]R9F,X,C(@86YD(&UE<W-A9V4O<&%R=&EA;"!R97%U:7)E
M('1H90H@("`@("`@("`@($U)344M5F5R<VEO;B!H96%D97(@;VYL>2!I9B!T
M:&5Y('1H96US96QV97,@8VQA:6T@=&\@8F4@34E-10H@("`@("`@("`@(&-O
M;7!L:6%N="X@*B\*("`@("`@("!I9B`H*"1P='EP92`]/2`G;65S<V%G92<I
M("8F"B`@("`@("`@("`@("@H)'-T>7!E(#T]("=R9F,X,C(G*2!\?"`H)'-T
M>7!E(#T]("=P87)T:6%L)RDI("8F"B`@("`@("`@("`@("AS=')P;W,H)'1H
M:7,M/E]C;VYT96YT<RP@)TU)344M5F5R<VEO;CH@,2XP)RD@(3T](&9A;'-E
M*2D@>PH@("`@("`@("`@("`D:&5A9&5R<ULG34E-12U697)S:6]N)UT@/2`G
M,2XP)SL*("`@("`@("!]"@H@("`@("`@("\J(&UE<W-A9V4O*B!P87)T<R!R
M97%U:7)E(&YO(&%D9&ET:6]N86P@:&5A9&5R(&EN9F]R;6%T:6]N+B`J+PH@
M("`@("`@(&EF("@D<'1Y<&4@/3T@)VUE<W-A9V4G*2!["B`@("`@("`@("`@
M(')E='5R;B`D:&5A9&5R<SL*("`@("`@("!]"@H@("`@("`@("\J($1O;B=T
M('-H;W<@0V]N=&5N="U$:7-P;W-I=&EO;B!F;W(@;75L=&EP87)T(&UE<W-A
M9V5S('5N;&5S<PH@("`@("`@("`@('1H97)E(&ES(&$@;F%M92!P87)A;65T
M97(N("HO"B`@("`@("`@)&YA;64@/2`D=&AI<RT^9V5T3F%M92@I.PH@("`@
M("`@(&EF("@H)'!T>7!E("$]("=M=6QT:7!A<G0G*2!\?"`A96UP='DH)&YA
M;64I*2!["B`@("`@("`@("`@("1D:7-P(#T@)'1H:7,M/F=E=$1I<W!O<VET
M:6]N*"D["@H@("`@("`@("`@("`O*B!!9&0@86YY(&1I<W!O<VET:6]N('!A
M<F%M971E<B!I;F9O<FUA=&EO;BP@:68@879A:6QA8FQE+B`J+PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("`@("`@)&1I
M<W`@+CT@)SL@)R`N("=F:6QE;F%M93TB)R`N($U)344Z.F5N8V]D92@D;F%M
M92P@)&-H87)S970I("X@)R(G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D:&5A9&5R<ULG0V]N=&5N="U$:7-P;W-I=&EO;B==(#T@34E-13HZ=W)A
M<$AE861E<G,H)T-O;G1E;G0M1&ES<&]S:71I;VXG+"`D9&ES<"P@)&5O;"D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!!9&0@=')A;G-F97(@96YC;V1I;F<@
M:6YF;W)M871I;VXN("HO"B`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<G72`]("1T:&ES+3YG9714<F%N<V9E<D5N8V]D:6YG
M*"D["@H@("`@("`@("\J($%D9"!C;VYT96YT($E$(&EN9F]R;6%T:6]N+B`J
M+PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7V-O;G1E;G1I9"DI('L*
M("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M240G72`]("1T:&ES+3Y?
M8V]N=&5N=&ED.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H96%D97)S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!E;G1I<F4@<&%R
M="!I;B!-24U%(&9O<FUA="X@26YC;'5D97,@:&5A9&5R<R!O;B!R97%U97-T
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97)S("!);F-L
M=61E('1H92!-24U%(&AE861E<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!-24U%('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M=&]3=')I;F<H)&AE861E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1E;VP@
M/2`D=&AI<RT^9V5T14],*"D["B`@("`@("`@)'!T>7!E(#T@)'1H:7,M/F=E
M=%!R:6UA<GE4>7!E*"D["@H@("`@("`@(&EF("@D:&5A9&5R<RD@>PH@("`@
M("`@("`@("`D=&5X="`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI
M<RT^:&5A9&5R*"D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@
M("`D=&5X="`N/2`D:V5Y("X@)SH@)R`N("1V86P@+B`D96]L.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T97AT("X]("1E;VP["B`@("`@("`@?0H*
M("`@("`@("`O*B!!;GD@:6YF;W)M871I;VX@86)O=70@82!M97-S86=E+RH@
M:7,@96UB961D960@:6X@=&AE(&UE<W-A9V4*("`@("`@("`@("!C;VYT96YT
M<R!T:&5M<V5L9BX@4VEM<&QY(&]U='!U="!T:&4@8V]N=&5N=',@;V8@=&AE
M('!A<G0*("`@("`@("`@("!D:7)E8W1L>2!A;F0@<F5T=7)N+B`J+PH@("`@
M("`@(&EF("@D<'1Y<&4@/3T@)VUE<W-A9V4G*2!["B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&5X="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&5X
M="`N("1T:&ES+3Y?8V]N=&5N=',["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT<SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T97AT*2D@
M>PH@("`@("`@("`@("`D=&5X="`N/2`D=&AI<RT^=')A;G-F97)%;F-O9&4H
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&5X="`]("1T:&ES
M+3YT<F%N<V9E<D5N8V]D92@I.PH@("`@("`@('T*"B`@("`@("`@+RH@1&5A
M;"!W:71H(&UU;'1I<&%R="!M97-S86=E<RX@*B\*("`@("`@("!I9B`H)'!T
M>7!E(#T]("=M=6QT:7!A<G0G*2!["B`@("`@("`@("`@("1B;W5N9&%R>2`]
M('1R:6TH)'1H:7,M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=B;W5N9&%R
M>2<I+"`G(B<I.PH@("`@("`@("`@("!I9B`H(7-T<FQE;B@D=&AI<RT^7V-O
M;G1E;G1S*2D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@)U1H:7,@;65S
M<V%G92!I<R!I;B!-24U%(&9O<FUA="XG("X@)&5O;#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T4&%R=',H*2!A<R`D
M<&%R="D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@)&5O;"`N("<M+2<@
M+B`D8F]U;F1A<GD@+B`D96]L.PH@("`@("`@("`@("`@("`@)&]L9$5/3"`]
M("1P87)T+3YG971%3TPH*3L*("`@("`@("`@("`@("`@("1P87)T+3YS971%
M3TPH)&5O;"D["B`@("`@("`@("`@("`@("`D=&5X="`N/2`D<&%R="T^=&]3
M=')I;F<H=')U92D["B`@("`@("`@("`@("`@("`D<&%R="T^<V5T14],*"1O
M;&1%3TPI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T97AT("X]("1E
M;VP@+B`G+2TG("X@)&)O=6YD87)Y("X@)RTM)R`N("1E;VP["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!E;F-O9&5D('!A<G0@:6X@<W1R:6-T(%)&0R`X,C(@
M)B`R,#0U(&]U='!U="`M(&YA;65L>2P@86QL"B`@("`@*B!N97=L:6YE<R!E
M;F0@=VET:"!T:&4@8V%N;VYI8V%L(#Q#4CX\3$8^('-E<75E;F-E+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97)S("!);F-L=61E('1H
M92!-24U%(&AE861E<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!E;G1I<F4@34E-12!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T
M;T-A;F]N:6-A;%-T<FEN9R@D:&5A9&5R<R`]('1R=64I"B`@("!["B`@("`@
M("`@)'-T<FEN9R`]("1T:&ES+3YT;U-T<FEN9R@D:&5A9&5R<RD["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR97!L86-E14],*"1S=')I;F<L($U)345?4$%2
M5%]21D-?14],*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W92!M
M86ME('-U<F4@=&AE(&UE<W-A9V4@:7,@96YC;V1E9"!V:6$@-RUB:70@*&4N
M9RX@=&\@861H97)E"B`@("`@*B!T;R!M86EL(&1E;&EV97)Y('-T86YD87)D
M<R!S=6-H(&%S(%)&0R`R.#(Q*3\*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D=7-E-V)I="`@57-E(#<M8FET(&5N8V]D:6YG/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S=')I8W0W8FET*"1U<V4W8FET*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?96YC;V1E-V)I="`]("1U<V4W8FET.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H92!T<F%N<V9E<B!E;F-O9&EN9R!F;W(@=&AE('!A
M<G0@8F%S960@;VX@=&AE('5S97(@<F5Q=65S=&5D"B`@("`@*B!T<F%N<V9E
M<B!E;F-O9&EN9R!A;F0@=&AE(&-U<G)E;G0@8V]N=&5N=',@;V8@=&AE('!A
M<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T<F%N<V9E
M<BUE;F-O9&EN9R!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%1R86YS9F5R16YC;V1I;F<H*0H@("`@>PH@("`@("`@("1E;F-O9&EN
M9R`]("1T:&ES+3Y?=')A;G-F97)%;F-O9&EN9SL*("`@("`@("`D<'1Y<&4@
M/2`D=&AI<RT^9V5T4')I;6%R>51Y<&4H*3L*("`@("`@("`D=&5X="`]('-T
M<E]R97!L86-E*"1T:&ES+3YG971%3TPH*2P@)R`G+"`D=&AI<RT^7V-O;G1E
M;G1S*3L*"B`@("`@("`@+RH@268@=&AE<F4@87)E(&YO(&-O;G1E;G1S+"!R
M971U<FX@=VAA=&5V97(@=&AE(&-U<G)E;G0@=F%L=64@;V8*("`@("`@("`@
M("`D7W1R86YS9F5R16YC;V1I;F<@:7,N("HO"B`@("`@("`@:68@*&5M<'1Y
M*"1T97AT*2D@>PH@("`@("`@("`@("!R971U<FX@)&5N8V]D:6YG.PH@("`@
M("`@('T*"B`@("`@("`@<W=I=&-H("@D<'1Y<&4I('L*("`@("`@("!C87-E
M("=M97-S86=E)SH*("`@("`@("`@("`@+RH@4D9#(#(P-#8@6S4N,BXQ72`M
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V5S(&]N;'D@86QL;W<@-V)I="P*("`@
M("`@("`@("`@("`@.&)I="P@86YD(&)I;F%R>2!E;F-O9&EN9W,N($EF('1H
M92!C=7)R96YT(&5N8V]D:6YG(&ES(&5I=&AE<@H@("`@("`@("`@("`@("!B
M87-E-C0@;W(@<2UP+"!S=VET8V@@:70@=&\@.&)I="!I;G-T96%D+@H@("`@
M("`@("`@("`@("!21D,@,C`T-B!;-2XR+C(L(#4N,BXS+"`U+C(N-%T@+2!!
M;&P@;W1H97(@;65S<V%G92\J(&UE<W-A9V5S"B`@("`@("`@("`@("`@(&]N
M;'D@86QL;W<@-V)I="!E;F-O9&EN9W,N("HO"B`@("`@("`@("`@("1E;F-O
M9&EN9R`]("@D=&AI<RT^9V5T4W5B5'EP92@I(#T]("=R9F,X,C(G*2`_("<X
M8FET)R`Z("<W8FET)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)W1E>'0G.@H@("`@("`@("`@("!I9B`H34E-13HZ:7,X8FET*"1T97AT
M*2D@>PH@("`@("`@("`@("`@("`@)&5N8V]D:6YG(#T@*"1T:&ES+3Y?96YC
M;V1E-V)I="D@/R`G<75O=&5D+7!R:6YT86)L92<@.B`G.&)I="<["B`@("`@
M("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"(O*#\Z7&Y\7BE;7EQN77LY
M.3DL?2@_.EQN?"0I+R(L("1T97AT*2D@>PH@("`@("`@("`@("`@("`@+RH@
M268@=&AE('1E>'0@:7,@;&]N9V5R('1H86X@.3DX(&-H87)A8W1E<G,@8F5T
M=V5E;@H@("`@("`@("`@("`@("`@("H@;&EN96)R96%K<RP@=7-E('%U;W1E
M9"UP<FEN=&%B;&4@96YC;V1I;F<@=&\@96YS=7)E('1H90H@("`@("`@("`@
M("`@("`@("H@=&5X="!W:6QL(&YO="!B92!C:&]P<&5D("AI+F4N(&)Y('-E
M;F1M86EL(&EF(&)E:6YG('-E;G0*("`@("`@("`@("`@("`@("`J(&%S(&UA
M:6P@=&5X="DN("HO"B`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2`G<75O
M=&5D+7!R:6YT86)L92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&EF("A-24U%.CII
M<SAB:70H)'1E>'0I*2!["B`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2`H
M)'1H:7,M/E]E;F-O9&4W8FET*2`_("=B87-E-C0G(#H@)SAB:70G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@
M("`@+RH@3F5E9"!T;R!D;R!O;F4@;&%S="!C:&5C:R!F;W(@8FEN87)Y(&1A
M=&$@:68@96YC;V1I;F<@:7,@-V)I="!O<@H@("`@("`@("`J(#AB:70N("!)
M9B!T:&4@;65S<V%G92!C;VYT86EN<R!A($Y53$P@8VAA<F%C=&5R(&%T(&%L
M;"P@=&AE(&UE<W-A9V4*("`@("`@("`@*B!-55-4(&)E(&EN(&)I;F%R>2!F
M;W)M870N(%)&0R`R,#0V(%LR+C<L(#(N."P@,BXY72X@42U0(&%N9"!B87-E
M-C0*("`@("`@("`@*B!C86X@:&%N9&QE(&)I;F%R>2!D871A(&9I;F4@<V\@
M;F\@;F5E9"!T;R!S=VET8V@@=&AO<V4@96YC;V1I;F=S+B`J+PH@("`@("`@
M(&EF("@H*"1E;F-O9&EN9R`]/2`G.&)I="<I('Q\("@D96YC;V1I;F<@/3T@
M)S=B:70G*2D@)B8*("`@("`@("`@("`@<')E9U]M871C:"@G+UQX,#`O)RP@
M)'1E>'0I*2!["B`@("`@("`@("`@("1E;F-O9&EN9R`]("@D=&AI<RT^7V5N
M8V]D93=B:70I(#\@)V)A<V4V-"<@.B`G8FEN87)Y)SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D96YC;V1I;F<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971R:65V97,@=&AE(&-U<G)E;G0@96YC;V1I;F<@;V8@=&AE(&-O;G1E
M;G1S(&EN('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!C=7)R96YT(&5N8V]D:6YG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971#=7)R96YT16YC;V1I;F<H*0H@("`@>PH@("`@("`@(')E='5R;B`H
M:7-?;G5L;"@D=&AI<RT^7V-U<G)E;G1%;F-O9&EN9RDI(#\@)'1H:7,M/E]T
M<F%N<V9E<D5N8V]D:6YG(#H@)'1H:7,M/E]C=7)R96YT16YC;V1I;F<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!%;F-O9&5S('1H92!C;VYT96YT<R!W:71H
M('1H92!P87)T)W,@=')A;G-F97(@96YC;V1I;F<N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!E;F-O9&5D('1E>'0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1R86YS9F5R16YC;V1E*"D*("`@('L*("`@("`@("`D96YC
M;V1I;F<@/2`D=&AI<RT^9V5T5')A;G-F97)%;F-O9&EN9R@I.PH@("`@("`@
M("1E;VP@/2`D=&AI<RT^9V5T14],*"D["@H@("`@("`@("\J(%-E="!T:&4@
M)VQA<W14<F%N<V9E<D5N8V]D92<@9FQA9R!S;R!T:&%T('1R86YS9F5R16YC
M;V1E0V]N=&5N=',H*0H@("`@("`@("`@(&-A;B!S879E(&$@8V%L;"!T;R!G
M9714<F%N<V9E<D5N8V]D:6YG*"DN("HO"B`@("`@("`@)'1H:7,M/E]F;&%G
M<ULG;&%S=%1R86YS9F5R16YC;V1E)UT@/2`D96YC;V1I;F<["@H@("`@("`@
M("\J($EF(&-O;G1E;G1S(&%R92!E;7!T>2P@;W(@8V]N=&5N=',@87)E(&%L
M<F5A9'D@96YC;V1E9"!T;R!T:&4*("`@("`@("`@("!C;W)R96-T(&5N8V]D
M:6YG+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF("@A<W1R;&5N*"1T:&ES
M+3Y?8V]N=&5N=',I('Q\"B`@("`@("`@("`@("@D96YC;V1I;F<@/3T@)'1H
M:7,M/E]C=7)R96YT16YC;V1I;F<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-O;G1E;G1S.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D
M96YC;V1I;F<I('L*("`@("`@("`O*B!"87-E-C0@16YC;V1I;F<Z(%-E92!2
M1D,@,C`T-2P@<V5C=&EO;B`V+C@@*B\*("`@("`@("!C87-E("=B87-E-C0G
M.@H@("`@("`@("`@("`O*B!+965P:6YG('1H97-E('1W;R!L:6YE<R!S97!A
M<F%T92!S965M<R!T;R!U<V4@;75C:"!L97-S"B`@("`@("`@("`@("`@(&UE
M;6]R>2!T:&%N(&-O;6)I;FEN9R!T:&5M("AA<R!O9B!02%`@-"XS*2X@*B\*
M("`@("`@("`@("`@)&5N8V]D961?8V]N=&5N=',@/2!B87-E-C1?96YC;V1E
M*"1T:&ES+3Y?8V]N=&5N=',I.PH@("`@("`@("`@("!R971U<FX@8VAU;FM?
M<W!L:70H)&5N8V]D961?8V]N=&5N=',L(#<V+"`D96]L*3L*"B`@("`@("`@
M+RH@475O=&5D+5!R:6YT86)L92!%;F-O9&EN9SH@4V5E(%)&0R`R,#0U+"!S
M96-T:6]N(#8N-R`J+PH@("`@("`@(&-A<V4@)W%U;W1E9"UP<FEN=&%B;&4G
M.@H@("`@("`@("`@("`D;W5T<'5T(#T@34E-13HZ<75O=&5D4')I;G1A8FQE
M16YC;V1E*"1T:&ES+3Y?8V]N=&5N=',L("1E;VPI.PH@("`@("`@("`@("!I
M9B`H*"1E;VQL96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D96]L*2DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!S=6)S='(H)&]U='!U="P@,"P@)&5O;&QE
M;F=T:"`J("TQ*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D;W5T<'5T.PH@("`@("`@("`@("!]"@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F5P;&%C945/3"@D
M=&AI<RT^7V-O;G1E;G1S*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96-O9&5S('1H92!C;VYT96YT<R!O9B!T:&4@<&%R="!T;R!E:71H
M97(@82`W8FET(&]R(#AB:70@96YC;V1I;F<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!D96-O9&5D('1E>'0N"B`@("`@*B`@("`@("`@
M("`@("`@("`@4F5T=7)N<R!T:&4@96UP='D@<W1R:6YG(&EF('1H97)E(&ES
M(&YO('1E>'0@=&\@9&5C;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N
M<V9E<D1E8V]D92@I"B`@("!["B`@("`@("`@)&5N8V]D:6YG(#T@)'1H:7,M
M/F=E=$-U<G)E;G1%;F-O9&EN9R@I.PH*("`@("`@("`O*B!)9B!T:&4@8V]N
M=&5N=',@87)E(&5M<'1Y+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF("@A
M<W1R;&5N*"1T:&ES+3Y?8V]N=&5N=',I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==(#T@)&5N8V]D:6YG.PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT<SL*("`@("`@("!]
M"@H@("`@("`@('-W:71C:"`H)&5N8V]D:6YG*2!["B`@("`@("`@8V%S92`G
M8F%S938T)SH*("`@("`@("`@("`@)&UE<W-A9V4@/2!B87-E-C1?9&5C;V1E
M*"1T:&ES+3Y?8V]N=&5N=',I.PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S
M6R=L87-T5')A;G-F97)$96-O9&4G72`]("<X8FET)SL*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@)W%U;W1E9"UP<FEN=&%B;&4G.@H@("`@
M("`@("`@("`D;65S<V%G92`]('!R96=?<F5P;&%C92@B+SU<<C]<;B\B+"`G
M)RP@)'1H:7,M/E]C;VYT96YT<RD["B`@("`@("`@("`@("1M97-S86=E(#T@
M)'1H:7,M/G)E<&QA8V5%3TPH)&UE<W-A9V4I.PH@("`@("`@("`@("`D;65S
M<V%G92`]('%U;W1E9%]P<FEN=&%B;&5?9&5C;V1E*"1M97-S86=E*3L*("`@
M("`@("`@("`@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R1&5C;V1E)UT@
M/2`H34E-13HZ:7,X8FET*"1M97-S86=E*2D@/R`G.&)I="<@.B`G-V)I="<[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`O*B!3=7!P;W)T(&9O<B!U
M=65N8V]D960@96YC;V1I;F<@+2!A;'1H;W5G:"!N;W0@<F5Q=6ER960@8GD@
M4D9#<RP*("`@("`@("`@("!S;VUE(&UA:6QE<G,@;6%Y('-T:6QL(&5N8V]D
M92!T:&ES('=A>2X@*B\*("`@("`@("!C87-E("=U=65N8V]D92<Z"B`@("`@
M("`@8V%S92`G>"UU=65N8V]D92<Z"B`@("`@("`@8V%S92`G>"UU=64G.@H@
M("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=C;VYV97)T7W5U9&5C
M;V1E)RDI('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@8V]N=F5R=%]U
M=65N8V]D92@D=&AI<RT^7V-O;G1E;G1S*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"]M:6UE1&5C
M;V1E+G!H<"<["B`@("`@("`@("`@("`@("`D9FEL97,@/2`F36%I;%]M:6UE
M1&5C;V1E.CIU=61E8V]D92@D=&AI<RT^7V-O;G1E;G1S*3L*("`@("`@("`@
M("`@("`@("1M97-S86=E(#T@)&9I;&5S6S!=6R=F:6QE9&%T82==.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"]M:6UE
M1&5C;V1E+G!H<"<["B`@("`@("`@("`@("1F:6QE<R`]("9-86EL7VUI;65$
M96-O9&4Z.G5U9&5C;V1E*"1T:&ES+3Y?8V]N=&5N=',I.PH@("`@("`@("`@
M("`D;65S<V%G92`]("1F:6QE<ULP75LG9FEL961A=&$G73L*("`@("`@("`@
M("`@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R1&5C;V1E)UT@/2`G.&)I
M="<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R
M1&5C;V1E)UTI("8F"B`@("`@("`@("`@("`@("`H)'1H:7,M/E]F;&%G<ULG
M;&%S=%1R86YS9F5R1&5C;V1E)UT@(3T@)&5N8V]D:6YG*2D@>PH@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^<F5P;&%C945/3"@D=&AI<RT^
M7V-O;G1E;G1S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1M97-S86=E(#T@)'1H:7,M/E]C;VYT96YT<SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=L87-T5')A;G-F97)$96-O
M9&4G72`]("1E;F-O9&EN9SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&UE<W-A9V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3<&QI="!T:&4@8V]N=&5N=',@;V8@=&AE(&-U<G)E;G0@4&%R="!I
M;G1O(&ET<R!R97-P96-T:79E('-U8G!A<G1S+`H@("`@("H@:68@:70@:7,@
M;75L=&EP87)T($U)344@96YC;V1I;F<N(%5N;&EK92!T:&4@:6UA<%\J*"D@
M9G5N8W1I;VYS+"!T:&ES"B`@("`@*B!W:6QL('!R97-E<G9E(&%L;"!-24U%
M(&AE861E<B!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&4@8F]U;F1A
M<GD@8V]N=&5N="UT>7!E('!A<F%M971E<B!M=7-T(&)E('-E="!F;W(@=&AI
M<R!F=6YC=&EO;B!T;PH@("`@("H@=V]R:R!C;W)R96-T;'DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!C;VYT96YT<R!W
M97)E('-U8V-E<W-F=6QL>2!S<&QI="X*("`@("`J("`@("`@("`@("`@("`@
M("`@1F%L<V4@:68@86YY(&5R<F]R(&]C8W5R<F5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S<&QI=$-O;G1E;G1S*"D*("`@('L*("`@("`@("!I9B`H(2@D
M8F]U;F1A<GD@/2`D=&AI<RT^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)V)O
M=6YD87)Y)RDI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A<W1R;&5N*"1T:&ES+3Y?8V]N=&5N=',I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("1E;VP@/2`D=&AI<RT^9V5T14],*"D["B`@("`@("`@)')E='9A;'5E(#T@
M9F%L<V4["@H@("`@("`@(&9O<F5A8V@@*&5X<&QO9&4H)&5O;"P@)'1H:7,M
M/E]C;VYT96YT<RD@87,@)&QI;F4I('L*("`@("`@("`@("`@)'!O<R`]('-T
M<G!O<R@D;&EN92P@)RTM)R`N("1B;W5N9&%R>2D["B`@("`@("`@("`@(&EF
M("@H)'!O<R`]/3T@9F%L<V4I("8F(&ES<V5T*"1P87)T7W!T<BDI('L*("`@
M("`@("`@("`@("`@("1D871A6UT@/2`D;&EN93L*("`@("`@("`@("`@?2!E
M;'-E:68@*"1P;W,@/3T](#`I('L*("`@("`@("`@("`@("`@("1R971V86QU
M92`]('1R=64["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<G1?<'1R
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R='-;)'!A<G1?
M<'1R72T^<V5T0V]N=&5N=',H:6UP;&]D92@D96]L+"`D9&%T82DI.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R='-;)'!A<G1?<'1R72T^<W!L
M:71#;VYT96YT<R@I.PH@("`@("`@("`@("`@("`@("`@(&YE>'0H)'1H:7,M
M/E]P87)T<RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@(')E<V5T*"1T:&ES+3Y?<&%R=',I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A*2D@>PH@("`@
M("`@("`@("`@("`@("`@('5N<V5T*"1D871A*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@("1P87)T7W!T<B`](&ME>2@D=&AI<RT^7W!A<G1S*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971V86QU93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E<&QA8V4@;F5W;&EN97,@:6X@=&AI
M<R!P87)T)W,@8V]N=&5N=',@=VET:"!T:&]S92!S<&5C:69I960@8GD@96ET
M:&5R"B`@("`@*B!T:&4@9VEV96X@;F5W;&EN92!S97%U96YC92!O<B!T:&4@
M<&%R="=S(&-U<G)E;G0@14],('-E='1I;F<N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@<F5P;&%C92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&5O;"`@(%1H92!%3TP@<V5Q=65N8V4@=&\@=7-E
M+B!)9B!N;W0@<')E<V5N="P@=7-E<R!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@('!A<G0G<R!C=7)R96YT($5/3"!S971T:6YG+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5X="!W:71H('1H92!N97=L
M:6YE<R!R97!L86-E9"!B>2!T:&4@9&5S:7)E9`H@("`@("H@("`@("`@("`@
M("`@("`@(&YE=VQI;F4@<V5Q=65N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E<&QA8V5%3TPH)'1E>'0L("1E;VP@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<U]N=6QL*"1E;VPI*2!["B`@("`@("`@("`@("1E;VP@/2`D=&AI
M<RT^9V5T14],*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!P<F5G7W)E
M<&QA8V4H(B]<<C]<;B\B+"`D96]L+"`D=&5X="D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@=&AE('5N:7%U92!-24U%7U!A<G0@8F]U;F1A<GD@
M<W1R:6YG(&=E;F5R871E9"!F;W(@=&AI<R!O8FIE8W0N"B`@("`@*B!4:&ES
M(&UA>2!N;W0@8F4@=&AE(&)O=6YD87)Y('-T<FEN9R!U<V5D('=H96X@8G5I
M;&1I;F<@=&AE(&UE<W-A9V4*("`@("`J('-I;F-E(&$@=7-E<B!D969I;F5D
M("=B;W5N9&%R>2<@0V]N=&5N="U4>7!E('!A<F%M971E<B!W:6QL(&]V97)R
M:61E"B`@("`@*B!T:&ES('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=6YI<75E(&)O=6YD87)Y('-T<FEN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T56YI<75E240H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V)O=6YD87)Y.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T
M97)M:6YE('1H92!S:7IE(&]F(&$@34E-15]087)T(&%N9"!I=',@8VAI;&0@
M;65M8F5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%-I>F4@
M;V8@=&AE($U)345?4&%R="P@:6X@8GET97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$)Y=&5S*"D*("`@('L*("`@("`@("`D8GET97,@/2`P.PH*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]F;&%G<ULG8V]N=&5N='-3970G72D@
M)B8@)'1H:7,M/E]B>71E<RD@>PH@("`@("`@("`@("`D8GET97,@/2`D=&AI
M<RT^7V)Y=&5S.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^9V5T4')I;6%R
M>51Y<&4H*2`]/2`G;75L=&EP87)T)RD@>PH@("`@("`@("`@("!F;W)E86-H
M("@D=&AI<RT^9V5T4&%R=',H*2!A<R`D<&%R="D@>PH@("`@("`@("`@("`@
M("`@+RH@4VMI<"!M=6QT:7!A<G0@96YT<FEE<R`H<VEN8V4@=&AI<R!M87D@
M<F5S=6QT(&EN(&1O=6)L90H@("`@("`@("`@("`@("`@("`@8V]U;G1I;F<I
M+B`J+PH@("`@("`@("`@("`@("`@:68@*"1P87)T+3YG9710<FEM87)Y5'EP
M92@I("$]("=M=6QT:7!A<G0G*2!["B`@("`@("`@("`@("`@("`@("`@)&)Y
M=&5S("L]("1P87)T+3YG971">71E<R@I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@
M*"1T:&ES+3YG9710<FEM87)Y5'EP92@I(#T]("=T97AT)RD@>PH@("`@("`@
M("`@("`@("`@)&)Y=&5S(#T@4W1R:6YG.CIL96YG=&@H)'1H:7,M/E]C;VYT
M96YT<RP@)'1H:7,M/F=E=$-H87)S970H*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D8GET97,@/2!S=')L96XH)'1H:7,M/E]C
M;VYT96YT<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8GET97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!L:6-I=&QY
M('-E="!T:&4@<VEZ92`H:6X@8GET97,I(&]F('1H:7,@<&%R="X@5&AI<R!V
M86QU92!W:6QL(&]N;'D*("`@("`J(&)E(')E='5R;F5D("AV:6$@9V5T0GET
M97,H*2D@:68@=&AE<F4@87)E(&YO(&-O;G1E;G1S(&-U<G)E;G1L>2!S970N
M"B`@("`@*B!4:&ES(&9U;F-T:6]N(&ES('5S969U;"!F;W(@<V5T=&EN9R!T
M:&4@<VEZ92!O9B!T:&4@<&%R="!W:&5N('1H90H@("`@("H@8V]N=&5N=',@
M;V8@=&AE('!A<G0@87)E(&YO="!F=6QL>2!L;V%D960@*&DN92X@8W)E871I
M;F<@82!-24U%7U!A<G0*("`@("`J(&]B:F5C="!F<F]M($E-05`@:&5A9&5R
M(&EN9F]R;6%T:6]N('=I=&AO=70@;&]A9&EN9R!T:&4@9&%T82!O9B!T:&4*
M("`@("`J('!A<G0I+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1B
M>71E<R`@5&AE('-I>F4@;V8@=&AI<R!P87)T(&EN(&)Y=&5S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971">71E<R@D8GET97,I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]B>71E<R`]("1B>71E<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($]U='!U="!T:&4@<VEZ92!O9B!T:&ES($U)345?4&%R="!I;B!+0BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4VEZ92!O9B!T:&4@34E-15]0
M87)T+"!I;B!S=')I;F<@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713:7IE*"D*("`@('L*("`@("`@("`D8GET97,@/2`D=&AI<RT^9V5T0GET
M97,H*3L*("`@("`@("!I9B`H96UP='DH)&)Y=&5S*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&)Y=&5S.PH@("`@("`@('T*"B`@("`@("`@)&QO8V%L96EN
M9F\@/2!.3%,Z.F=E=$QO8V%L94EN9F\H*3L*("`@("`@("!R971U<FX@;G5M
M8F5R7V9O<FUA="@D8GET97,@+R`Q,#(T+"`R+"`D;&]C86QE:6YF;ULG9&5C
M:6UA;%]P;VEN="==+"`D;&]C86QE:6YF;ULG=&AO=7-A;F1S7W-E<"==*3L*
M("`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@=&\@=&AE(&QI<W0@;V8@0TE$
M<R!F;W(@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M8VED<R`@02!L:7-T(&]F($U)344@241S(&]F('1H92!P87)T+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!+97D@+2!-24U%($E$"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@(%9A;'5E("T@0TE$(&9O<B!T:&4@<&%R=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1#240H)&-I9',@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?8VED<R`K/2`D8VED<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&QI<W0@;V8@0TE$<R!F;W(@=&AI<R!P
M87)T+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F
M($-)1',@9F]R('1H:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M0TE$3&ES="@I"B`@("!["B`@("`@("`@87-O<G0H)'1H:7,M/E]C:61S+"!3
M3U)47U-44DE.1RD["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VED<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE($-O;G1E;G0M240@:&5A9&5R
M(&9O<B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VED("!5<V4@=&AI<R!#240@*&EF(&YO="!A;')E861Y('-E="DN("!%;'-E
M+"!G96YE<F%T92!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(')A;F1O
M;2!#240N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-O;G1E;G1)1"@D8VED
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7V-O
M;G1E;G1I9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT:60@/2`H
M:7-?;G5L;"@D8VED*2D@/R`H8F%S95]C;VYV97)T*&UI8W)O=&EM92@I+"`Q
M,"P@,S8I("X@)T`G("X@)%]315)615);)U-%4E9%4E].04U%)UTI(#H@)&-I
M9#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=&ED
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@0V]N=&5N="U)
M1"!F;W(@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@0V]N=&5N="U)1"!F;W(@=&AI<R!P87)T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971#;VYT96YT240H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-O;G1E;G1I9#L*("`@('T*"B`@("`O*BH*("`@("`J($%L=&5R
M('1H92!-24U%($E$(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M:6UE:60@(%1H92!-24U%($E$+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971-24U%260H)&UI;65I9"D*("`@('L*("`@("`@("`D=&AI
M<RT^7VUI;65I9"`]("1M:6UE:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!-24U%($E$(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@240N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$U)345)9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?;6EM96ED.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<F5L871I=F4@34E-12!)1"!O9B!T:&ES('!A<G0N"B`@("`@*B!E+F<N+"!I
M9B!T:&4@8F%S92!P87)T(&AA<R!-24U%($E$(&]F(#(L(&%N9"!Y;W4@=V%N
M="!T:&4@9FER<W0*("`@("`J('-U8G!A<G0@;V8@=&AE(&)A<V4@<&%R="P@
M=&AE(')E;&%T:79E($U)344@240@:7,@,BXQ+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED("!4:&4@<F5L871I=F4@<&%R="!)1"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;&%T:79E($U)344@240N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E;&%T:79E34E-14ED*"1I9"D*
M("`@('L*("`@("`@("`D<F5L(#T@)'1H:7,M/F=E=$U)345)9"@I.PH@("`@
M("`@(')E='5R;B`H96UP='DH)')E;"DI(#\@)&ED(#H@)')E;"`N("<N)R`N
M("1I9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!M87!P:6YG
M(&]F(&%L;"!-24U%($E$<R!T;R!T:&5I<B!C;VYT96YT+71Y<&5S+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($M%63H@34E-12!)1"P@5D%,544Z
M($-O;G1E;G0@='EP90H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYT96YT5'EP
M94UA<"@I"B`@("!["B`@("`@("`@)&UA<"`](&%R<F%Y*"1T:&ES+3YG971-
M24U%260H*2`]/B`D=&AI<RT^9V5T5'EP92@I*3L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W!A<G1S(&%S("1V86PI('L*("`@("`@("`@("`@)&UA<"`K
M/2`D=F%L+3YC;VYT96YT5'EP94UA<"@I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&UA<#L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E('1H
M92!U;FEQ=64@8F]U;F1A<GD@<W1R:6YG("AI9B!N;W0@86QR96%D>2!D;VYE
M*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&)O=6YD87)Y('-T<FEN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E;F5R871E0F]U;F1A<GDH*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?8F]U;F1A<GDI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?8F]U;F1A<GD@/2`G/5\G("X@8F%S95]C;VYV97)T*&UI
M8W)O=&EM92@I+"`Q,"P@,S8I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]B;W5N9&%R>3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]3=')U8W1U
M<F4N<&AP````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,#`P`#$P
M-#$W,S8R-S<S`#`R,30W,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]-97-S86=E+G!H<"<["G)E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O4&%R="YP:'`G.PIR97%U:7)E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN+TU)344N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]-24U%+TU)344O4W1R=6-T=7)E+G!H<"QV(#$N.#<N,3`N
M,3@@,C`P-B\P,R\R-"`P-3HS.3HS-B!S;'5S87)Z($5X<"`D"B`J"B`J(%1H
M92!-24U%7U-T<G5C='5R93HZ(&-L87-S('!R;W9I9&5S(&UE=&AO9',@9F]R
M(&1E86QI;F<@=VET:"!-24U%(&UA:6PN"B`J"B`J(%1H92!D969A=6QT(&-H
M87)A8W1E<B!S970@=&\@=7-E(&9O<B!M97-S86=E<R!S:&]U;&0@8F4@9&5F
M:6YE9"!I;B!T:&4*("H@=F%R:6%B;&4@)$=,3T)!3%-;)VUI;65?<W1R=6-T
M=7)E)UU;)V1E9F%U;'1?8VAA<G-E="==("AD969A=6QT<R!T;R!54RU!4T-)
M20H@*B!P97(@4D9#(#(P-#4I+@H@*@H@*B!43T1/.B!#;VYV97)T('1O($]/
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@
M,2XS"B`J($!P86-K86=E($AO<F1E7TU)344*("HO"F-L87-S($U)345?4W1R
M=6-T=7)E('L*"B`@("`O*BH*("`@("`J($=I=F5N('1H92!R97-U;'1S(&]F
M(&EM87!?9F5T8VAS=')U8W1U<F4H*2P@<&%R<V4@=&AE('-T<G5C='5R90H@
M("`@("H@;V8@=&AE(&UE<W-A9V4L(&9I9W5R:6YG(&]U="!C;W)R96-T(&)O
M9'EP87)T(&YU;6)E<G,L(&5T8RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1D
M0VQA<W,@)&)O9'D@(%1H92!R97-U;'0@;V8@:6UA<%]F971C:'-T<G5C='5R
M92@I+@H@("`@("H*("`@("`J($!R971U<FX@)DU)345?365S<V%G92`@5&AE
M(&UE<W-A9V4@<&%R<V5D(&EN=&\@82!-24U%7TUE<W-A9V4@;V)J96-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<&%R<V4H)&)O9'DI"B`@("!["B`@("`@
M("`@)&US9T]B(#T@)FYE=R!-24U%7TUE<W-A9V4H*3L*("`@("`@("`D;7-G
M3V(M/F%D9%!A<G0H34E-15]3=')U8W1U<F4Z.E]P87)S92@D8F]D>2DI.PH@
M("`@("`@("1M<V=/8BT^8G5I;&1-97-S86=E*"D["@H@("`@("`@("1P='(@
M/2!A<G)A>2@F)&US9T]B*3L*("`@("`@("!-24U%7U-T<G5C='5R93HZ7V%D
M9$UU;'1I<&%R=$EN9F\H)'!T<BD["@H@("`@("`@(')E='5R;B`D;7-G3V([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!T:&4@<F5S=6QT<R!O9B!I
M;6%P7V9E=&-H<W1R=6-T=7)E*"DL('!A<G-E('1H92!S=')U8W1U<F4*("`@
M("`J(&]F('1H92!M97-S86=E+"!F:6=U<FEN9R!O=70@8V]R<F5C="!B;V1Y
M<&%R="!N=6UB97)S+"!E=&,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T9$-L87-S("1B;V1Y("!4:&4@
M<F5S=6QT(&]F(&EM87!?9F5T8VAS=')U8W1U<F4H*2X*("`@("`J($!P87)A
M;2!S=')I;F<@)')E9B`@("`@5&AE(&-U<G)E;G0@8F]D>7!A<G0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B:F5C
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]P87)S92@D8F]D>2P@)')E9B`]
M(#`I"B`@("!["B`@("`@("`@<W1A=&EC("1M97-S86=E+"`D;75L=&EP87)T
M.PH*("`@("`@("!I9B`H(6ES<V5T*"1M97-S86=E*2D@>PH@("`@("`@("`@
M("`D;65S<V%G92`]($U)344Z.G1Y<&4H)VUE<W-A9V4G*3L*("`@("`@("`@
M("`@)&UU;'1I<&%R="`]($U)344Z.G1Y<&4H)VUU;'1I<&%R="<I.PH@("`@
M("`@('T*"B`@("`@("`@)&UI;65?<&%R="`]("9N97<@34E-15]087)T*"D[
M"@H@("`@("`@("\J(%1O<"!M=6QT:7!A<G1S(&1O;B=T(&=E="!T:&5I<B!O
M=VX@;&EN92X@*B\*("`@("`@("!I9B`H96UP='DH)')E9BD@)B8*("`@("`@
M("`@("`@*"%I<W-E="@D8F]D>2T^='EP92D@?'P@*"1B;V1Y+3YT>7!E("$]
M("1M=6QT:7!A<G0I*2D@>PH@("`@("`@("`@("`D<F5F(#T@,3L*("`@("`@
M("!]"@H@("`@("`@($U)345?4W1R=6-T=7)E.CI?<V5T26YF;R@D8F]D>2P@
M)&UI;65?<&%R="P@)')E9BD["@H@("`@("`@(&EF("AI<W-E="@D8F]D>2T^
M='EP92D@)B8@*"1B;V1Y+3YT>7!E(#T]("1M97-S86=E*2`F)@H@("`@("`@
M("`@("`D8F]D>2T^:69S=6)T>7!E("8F("@D8F]D>2T^<W5B='EP92`]/2`G
M4D9#.#(R)RDI('L*("`@("`@("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED
M*"1R968@+B`G+C`G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M;6EM95]P87)T+3YS971-24U%260H)')E9BD["B`@("`@("`@?0H*("`@("`@
M("`O*B!$96%L('=I=&@@;75L=&EP87)T(&1A=&$N("HO"B`@("`@("`@:68@
M*&ES<V5T*"1B;V1Y+3YP87)T<RDI('L*("`@("`@("`@("`@)'-U8E]I9"`]
M(#$["B`@("`@("`@("`@(&9O<F5A8V@@*"1B;V1Y+3YP87)T<R!A<R`D<W5B
M7W!A<G0I('L*("`@("`@("`@("`@("`@("\J($%R92!W92!D96%L:6YG('=I
M=&@@82!M=6QT:7!A<G0@;65S<V%G93\@*B\*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D8F]D>2T^='EP92D@)B8@*"1B;V1Y+3YT>7!E(#T]("1M97-S
M86=E*2`F)@H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1S=6)?<&%R="T^
M='EP92D@)B8@*"1S=6)?<&%R="T^='EP92`]/2`D;75L=&EP87)T*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1S=6)?<F5F(#T@)')E9CL*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'-U8E]R968@
M/2`H96UP='DH)')E9BDI(#\@)'-U8E]I9"`Z("1R968@+B`G+B<@+B`D<W5B
M7VED.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UI;65?
M<&%R="T^861D4&%R="A-24U%7U-T<G5C='5R93HZ7W!A<G-E*"1S=6)?<&%R
M="P@)'-U8E]R968I+"`D<W5B7VED*RLI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&UI;65?<&%R=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($=I=F5N(&$@;6EM92!P87)T(&9R;VT@:6UA<%]F971C:'-T
M<G5C='5R92@I+"!M=6YG92!I="!I;G1O(&$*("`@("`J('5S969U;"!F;W)M
M(&%N9"!M86ME('-U<F4@=&AA="!A;GD@<&%R86UE=&5R<R!W:&EC:"!A<F4@
M;6ES<VEN9PH@("`@("H@87)E(&=I=F5N(&1E9F%U;'0@=F%L=65S+@H@("`@
M("H*("`@("`J(%1O('-P96-I9GD@=&AE(&1E9F%U;'0@8VAA<F%C=&5R('-E
M="P@9&5F:6YE('1H92!G;&]B86P@=F%R:6%B;&4*("`@("`J("1'3$]"04Q3
M6R=M:6UE7W-T<G5C=71R92==6R=D969A=6QT7V-H87)S970G72X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1D0VQA<W,@)'!A<G0@(%1H92!O<FEG:6YA;"!P87)T(&EN9F\N"B`@("`@
M*B!`<&%R86T@34E-15]087)T("8D;V(@($$@34E-15]087)T(&]B:F5C="X*
M("`@("`J($!P87)A;2!S=')I;F<@)')E9B`@("`@5&AE($E$(&]F('1H:7,@
M<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$EN9F\H)'!A<G0L("8D
M;V(L("1R968I"B`@("!["B`@("`@("`@+RH@4W1O<F4@0V]N=&5N="UT>7!E
M(&EN9F]R;6%T:6]N+B`J+PH@("`@("`@("1P<FEM87)Y7W1Y<&4@/2`H:7-S
M970H)'!A<G0M/G1Y<&4I*2`_(%-T<FEN9SHZ;&]W97(H)'!A<G0M/G1Y<&4I
M(#H@34E-13HZ='EP92@G=&5X="<I.PH@("`@("`@("1S96-?='EP92`]("@D
M<&%R="T^:69S=6)T>7!E("8F("1P87)T+3YS=6)T>7!E*2`_(%-T<FEN9SHZ
M;&]W97(H)'!A<G0M/G-U8G1Y<&4I(#H@)W@M=6YK;F]W;B<["B`@("`@("`@
M)&]B+3YS9714>7!E*"1P<FEM87)Y7W1Y<&4@+B`G+R<@+B`D<V5C7W1Y<&4I
M.PH*("`@("`@("`O*B!3970@=')A;G-F97(@96YC;V1I;F<N("HO"B`@("`@
M("`@:68@*&ES<V5T*"1P87)T+3YE;F-O9&EN9RDI('L*("`@("`@("`@("`@
M)&5N8V]D:6YG(#T@)'!A<G0M/F5N8V]D:6YG.PH@("`@("`@("`@("`D;V(M
M/G-E=%1R86YS9F5R16YC;V1I;F<H)&5N8V]D:6YG*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D96YC;V1I;F<@/2!N=6QL.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4V5T('1R86YS9F5R(&1I<W!O<VET:6]N+B`J+PH@("`@
M("`@("1O8BT^<V5T1&ES<&]S:71I;VXH*"1P87)T+3YI9F1I<W!O<VET:6]N
M*2`_(%-T<FEN9SHZ;&]W97(H)'!A<G0M/F1I<W!O<VET:6]N*2`Z($U)345?
M1$5&055,5%]$25-03U-)5$E/3BD["@H@("`@("`@("\J($EF("=B;V1Y)R!I
M<R!S970L('-E="!A<R!T:&4@8V]N=&5N=',@;V8@=&AE('!A<G0N("HO"B`@
M("`@("`@:68@*&ES<V5T*"1P87)T+3YB;V1Y*2D@>PH@("`@("`@("`@("`D
M;V(M/G-E=$-O;G1E;G1S*"1P87)T+3YB;V1Y+"`D96YC;V1I;F<I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@)V)Y=&5S)R!I<R!S970L('-T;W)E(&%S
M(&EN9F]R;6%T:6]N('9A<FEA8FQE+B`J+PH@("`@("`@(&EF("AI<W-E="@D
M<&%R="T^8GET97,I*2!["B`@("`@("`@("`@("1O8BT^<V5T0GET97,H)'!A
M<G0M/F)Y=&5S*3L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@<&%R
M="=S(&ED96YT:69I8V%T:6]N('-T<FEN9RP@:68@879A:6QA8FQE+B`J+PH@
M("`@("`@(&EF("@A96UP='DH)')E9BD@)B8@)'!A<G0M/FEF:60I('L*("`@
M("`@("`@("`@)&]B+3YS971#;VYT96YT240H)'!A<G0M/FED*3L*("`@("`@
M("!]"@H@("`@("`@("\J(%-E="!T:&4@9&5F875L="!C:&%R86-T97(@<V5T
M+B`J+PH@("`@("`@("1O8BT^<V5T0VAA<G-E="AI<W-E="@D1TQ/0D%,4ULG
M;6EM95]S=')U8W1U<F4G75LG9&5F875L=%]C:&%R<V5T)UTI(#\@)$=,3T)!
M3%-;)VUI;65?<W1R=6-T=7)E)UU;)V1E9F%U;'1?8VAA<G-E="==(#H@34E-
M15]$149!54Q47T-(05)3150I.PH*"B`@("`@("`@+RH@1V\@=&AR;W5G:"!T
M:&4@8V]N=&5N="UT>7!E('!A<F%M971E<G,L(&EF(&%N>2X@*B\*("`@("`@
M("!F;W)E86-H("A-24U%7U-T<G5C='5R93HZ7V=E=%!A<F%M971E<G,H)'!A
M<G0L(#$I(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H)&ME
M>2`]/2`G8VAA<G-E="<I('L*("`@("`@("`@("`@("`@("1O8BT^<V5T0VAA
M<G-E="@D=F%L*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1O8BT^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)&ME>2P@)'9A;"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($=O('1H<F]U
M9V@@=&AE(&1I<W!O<VET:6]N('!A<F%M971E<G,L(&EF(&%N>2X@*B\*("`@
M("`@("!F;W)E86-H("A-24U%7U-T<G5C='5R93HZ7V=E=%!A<F%M971E<G,H
M)'!A<G0L(#(I(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D;V(M
M/G-E=$1I<W!O<VET:6]N4&%R86UE=&5R*"1K97DL("1V86PI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4V5T('1H92!N86UE+B`J+PH@("`@("`@(&EF("@D
M;V(M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=F:6QE;F%M92<I*2!["B`@
M("`@("`@("`@("1O8BT^<V5T3F%M92@D;V(M/F=E=$-O;G1E;G14>7!E4&%R
M86UE=&5R*"=F:6QE;F%M92<I*3L*("`@("`@("!](&5L<V5I9B`H)&]B+3YG
M971$:7-P;W-I=&EO;E!A<F%M971E<B@G9FEL96YA;64G*2D@>PH@("`@("`@
M("`@("`D;V(M/G-E=$YA;64H)&]B+3YG971$:7-P;W-I=&EO;E!A<F%M971E
M<B@G9FEL96YA;64G*2D["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE
M(&1E<V-R:7!T:6]N+B`J+PH@("`@("`@(&EF("AI<W-E="@D<&%R="T^9&5S
M8W)I<'1I;VXI*2!["B`@("`@("`@("`@("1O8BT^<V5T1&5S8W)I<'1I;VXH
M)'!A<G0M/F1E<V-R:7!T:6]N*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@86QL('!A<F%M971E<G,@9F]R(&$@9VEV96X@<&]R=&EO
M;B!O9B!A(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T9$-L87-S("1P87)T("!4:&4@;W)I
M9VEN86P@<&%R="!I;F9O+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'1Y<&4@
M("!4:&4@<&%R86UE=&5R('1Y<&4@=&\@<F5T<FEE=F4N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(#$@/2!C;VYT96YT"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(#(@/2!D:7-P;W-I=&EO;@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F('!A<F%M971E<B!K97DO=F%L
M=64@<&%I<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971087)A;65T97)S
M*"1P87)T+"`D='EP92D*("`@('L*("`@("`@("`D<&%R86U?;&ES="`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("@D='EP92`]/2`Q*2!["B`@("`@("`@("`@
M("1P='EP92`]("=P87)A;65T97)S)SL*("`@("`@("!](&5L<V5I9B`H)'1Y
M<&4@/3T@,BD@>PH@("`@("`@("`@("`D<'1Y<&4@/2`G9'!A<F%M971E<G,G
M.PH@("`@("`@('T*("`@("`@("`D<&5X:7-T<R`]("=I9B<@+B`D<'1Y<&4[
M"@H@("`@("`@(&EF("@D<&%R="T^)'!E>&ES=',I('L*("`@("`@("`@("`@
M9F]R96%C:"`H)'!A<G0M/B1P='EP92!A<R`D<&%R86TI('L*("`@("`@("`@
M("`@("`@("1P87)A;2T^=F%L=64@/2!S=')?<F5P;&%C92AA<G)A>2@B7'0B
M+"`G7"(G*2P@87)R87DH)R`G+"`G(B<I+"`D<&%R86TM/G9A;'5E*3L*"B`@
M("`@("`@("`@("`@("`D<F5S(#T@34E-13HZ9&5C;V1E4D9#,C(S,2@D<&%R
M86TM/F%T=')I8G5T92`N("<])R`N("1P87)A;2T^=F%L=64I.PH@("`@("`@
M("`@("`@("`@:68@*"1R97,I('L*("`@("`@("`@("`@("`@("`@("`D<&%R
M86TM/F%T=')I8G5T92`]("1R97-;)V%T=')I8G5T92==.PH@("`@("`@("`@
M("`@("`@("`@("1P87)A;2T^=F%L=64@/2`D<F5S6R=V86QU92==.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9I96QD(#T@4W1R:6YG
M.CIL;W=E<B@D<&%R86TM/F%T=')I8G5T92D["B`@("`@("`@("`@("`@("!I
M9B`H)&9I96QD(#T]("=T>7!E)RD@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@H)'1Y<&4@/2!-24U%.CIT>7!E*"1P87)A;2T^=F%L=64I*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R86U?;&ES=%LG='EP92==(#T@)'1Y
M<&4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D<&%R86U?;&ES=%LD9FEE;&1=
M(#T@)'!A<F%M+3YV86QU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A;5]L:7-T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!S<&5C:6%L(&EN9F]R;6%T
M:6]N(&9O<B!C97)T86EN($U)344@='EP97,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D<&%R
M=',@(%1H92!L:7-T(&]F('!A<G1S(&-O;G1A:6YE9"!W:71H:6X@=&AE(&UU
M;'1I<&%R=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="X*
M("`@("`J($!P87)A;2!A<G)A>2`D:6YF;R`@("!);F9O<FUA=&EO;B!A8F]U
M="!T:&4@;75L=&EP87)T('-T<G5C='5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V%D9$UU;'1I<&%R=$EN9F\H)B1P87)T<RP@)&EN9F\@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<&%R=',I*2!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*&%R<F%Y
M7VME>7,H)'!A<G1S*2!A<R`D:V5Y*2!["B`@("`@("`@("`@("1P='(@/2`F
M)'!A<G1S6R1K97E=.PH@("`@("`@("`@("`D;F5W7VEN9F\@/2`D:6YF;SL*
M"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG86QT)UTI*2!["B`@("`@
M("`@("`@("`@("`D<'1R+3YS971);F9O<FUA=&EO;B@G86QT97)N871I=F4G
M+"`H:7-?;G5L;"@D:6YF;ULG86QT)UTI*2`_("<M)R`Z("1I;F9O6R=A;'0G
M72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O
M6R=R96QA=&5D)UTI*2!["B`@("`@("`@("`@("`@("`D<'1R+3YS971);F9O
M<FUA=&EO;B@G<F5L871E9%]P87)T)RP@)&EN9F];)W)E;&%T960G72T^9V5T
M34E-14ED*"DI.PH@("`@("`@("`@("`@("`@:68@*"1I9"`]("1P='(M/F=E
M=$-O;G1E;G1)1"@I*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9F];)W)E
M;&%T960G72T^861D0TE$*&%R<F%Y*"1P='(M/F=E=$U)345)9"@I(#T^("1I
M9"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("AI<W-E="@D:6YF;ULG<F9C.#(R)UTI*2!["B`@("`@("`@("`@
M("`@("`D<'1R+3YS971);F9O<FUA=&EO;B@G<F9C.#(R7W!A<G0G+"`D:6YF
M;ULG<F9C.#(R)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S=VET
M8V@@*"1P='(M/F=E=%1Y<&4H*2D@>PH@("`@("`@("`@("!C87-E("=M=6QT
M:7!A<G0O86QT97)N871I=F4G.@H@("`@("`@("`@("`@("`@)&YE=U]I;F9O
M6R=A;'0G72`]("1P='(M/F=E=$U)345)9"@I.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=M=6QT:7!A<G0O<F5L871E9"<Z
M"B`@("`@("`@("`@("`@("`D;F5W7VEN9F];)W)E;&%T960G72`]("8D<'1R
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=M
M97-S86=E+W)F8S@R,B<Z"B`@("`@("`@("`@("`@("`D;F5W7VEN9F];)W)F
M8S@R,B==(#T@)'!T<BT^9V5T34E-14ED*"D["B`@("`@("`@("`@("`@("`D
M<'1R+3YS971);F9O<FUA=&EO;B@G:&5A9&5R)RP@=')U92D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@34E-
M15]3=')U8W1U<F4Z.E]A9&1-=6QT:7!A<G1);F9O*"1P='(M/E]P87)T<RP@
M)&YE=U]I;F9O*3L*("`@("`@("!]"B`@("!]"@H*("`@("\J*@H@("`@("H@
M071T96UP=',@=&\@8G5I;&0@82!-24U%7TUE<W-A9V4@;V)J96-T(&9R;VT@
M82!T97AT(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@5&AE('1E>'0@;V8@=&AE($U)344@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N($U)345?365S<V%G92`@02!-24U%7TUE<W-A9V4@;V)J
M96-T+"!O<B!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)G!A<G-E5&5X=$U)345-97-S86=E*"1T97AT*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92`G36%I;"]M:6UE1&5C;V1E+G!H<"<["@H@("`@("`@("\J
M(%-E="!U<"!T:&4@;W!T:6]N<R!F;W(@=&AE(&UI;65$96-O9&4@8VQA<W,N
M("HO"B`@("`@("`@)&1E8V]D95]A<F=S(#T@87)R87DH*3L*("`@("`@("`D
M9&5C;V1E7V%R9W-;)VEN8VQU9&5?8F]D:65S)UT@/2!T<G5E.PH@("`@("`@
M("1D96-O9&5?87)G<ULG9&5C;V1E7V)O9&EE<R==(#T@9F%L<V4["B`@("`@
M("`@)&1E8V]D95]A<F=S6R=D96-O9&5?:&5A9&5R<R==(#T@9F%L<V4["@H@
M("`@("`@("1M:6UE1&5C;V1E(#T@)FYE=R!-86EL7VUI;65$96-O9&4H)'1E
M>'0L($U)345?4$%25%]%3TPI.PH@("`@("`@(&EF("@A*"1S=')U8W1U<F4@
M/2`D;6EM941E8V]D92T^9&5C;V1E*"1D96-O9&5?87)G<RDI*2!["B`@("`@
M("`@("`@("1M97-S86=E(#T@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+RH@4'5T('1H92!O8FIE8W0@:6YT;R!I;6%P7W!A<G-E<W1R
M=6-T=7)E*"D@9F]R;2X@*B\*("`@("`@("`@("`@34E-15]3=')U8W1U<F4Z
M.E]C;VYV97)T36EM941E8V]D941A=&$H)'-T<G5C='5R92D["@H@("`@("`@
M("`@("`D;65S<V%G92`]($U)345?4W1R=6-T=7)E.CIP87)S92@D<W1R=6-T
M=7)E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;65S<V%G93L*("`@
M('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&AE(&]U='!U="!F<F]M(&UI
M;65$96-O9&4Z.F1E8V]D92@I(&EN=&\@82!S=')U8W1U<F4@=&AA=`H@("`@
M("H@;6%T8VAE<R!I;6%P7V9E=&-H<W1R=6-T=7)E*"D@;W5T<'5T+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=&1#;&%S<R`F)&]B("!4:&4@;W5T<'5T(&9R;VT@;6EM941E8V]D93HZ
M9&5C;V1E*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYV97)T36EM941E
M8V]D941A=&$H)B1O8BD*("`@('L*("`@("`@("`O*B!0<FEM87)Y(&-O;G1E
M;G0M='EP92X@*B\*("`@("`@("`D;V(M/G1Y<&4@/2!I;G1V86PH34E-13HZ
M='EP92@D;V(M/F-T>7!E7W!R:6UA<GDI*3L*"B`@("`@("`@+RH@4V5C;VYD
M87)Y(&-O;G1E;G0M='EP92X@*B\*("`@("`@("!I9B`H:7-S970H)&]B+3YC
M='EP95]S96-O;F1A<GDI*2!["B`@("`@("`@("`@("1O8BT^<W5B='EP92`]
M(%-T<FEN9SHZ=7!P97(H)&]B+3YC='EP95]S96-O;F1A<GDI.PH@("`@("`@
M("`@("`D;V(M/FEF<W5B='EP92`](#$["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&]B+3YI9G-U8G1Y<&4@/2`P.PH@("`@("`@('T*"B`@("`@
M("`@+RH@0V]N=&5N="!T<F%N<V9E<B!E;F-O9&EN9RX@*B\*("`@("`@("!I
M9B`H:7-S970H)&]B+3YH96%D97)S6R=C;VYT96YT+71R86YS9F5R+65N8V]D
M:6YG)UTI*2!["B`@("`@("`@("`@("1O8BT^96YC;V1I;F<@/2!-24U%.CIE
M;F-O9&EN9R@D;V(M/FAE861E<G-;)V-O;G1E;G0M=')A;G-F97(M96YC;V1I
M;F<G72D["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYT96YT+71Y<&4@86YD
M($1I<W!O<VET:6]N('!A<F%M971E<G,N("HO"B`@("`@("`@)'!A<F%M7W1Y
M<&5S(#T@87)R87D@*"=C='EP95]P87)A;65T97)S)R`]/B`G<&%R86UE=&5R
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D7W!A<F%M971E
M<G,G(#T^("=D<&%R86UE=&5R<R<I.PH@("`@("`@(&9O<F5A8V@@*"1P87)A
M;5]T>7!E<R!A<R`D<&%R86U?:V5Y(#T^("1P87)A;5]V86QU92D@>PH@("`@
M("`@("`@("`D:69?=F%R(#T@)VEF)R`N("1P87)A;5]V86QU93L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1O8BT^)'!A<F%M7VME>2DI('L*("`@("`@("`@
M("`@("`@("1O8BT^)&EF7W9A<B`](#$["B`@("`@("`@("`@("`@("`D;V(M
M/B1P87)A;5]V86QU92`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D;V(M/B1P87)A;5]K97D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@("`@("`@("`@("`@)&YE=T]B(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@
M("`@("`@("`@("`@("`D;F5W3V(M/F%T=')I8G5T92`]("1K97D["B`@("`@
M("`@("`@("`@("`@("`@)&YE=T]B+3YV86QU92`]("1V86P["B`@("`@("`@
M("`@("`@("`@("`@87)R87E?<'5S:"@D;V(M/B1P87)A;5]V86QU92P@)&YE
M=T]B*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1O8BT^)&EF7W9A<B`](#`["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J($-O;G1E;G0M1&ES<&]S:71I;VXN
M("HO"B`@("`@("`@:68@*&ES<V5T*"1O8BT^:&5A9&5R<ULG8V]N=&5N="UD
M:7-P;W-I=&EO;B==*2D@>PH@("`@("`@("`@("`D;V(M/FEF9&ES<&]S:71I
M;VX@/2`Q.PH@("`@("`@("`@("`D:&1R(#T@)&]B+3YH96%D97)S6R=C;VYT
M96YT+61I<W!O<VET:6]N)UT["B`@("`@("`@("`@("1P;W,@/2!S=')P;W,H
M)&AD<BP@)SLG*3L*("`@("`@("`@("`@:68@*"1P;W,@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`D:&1R(#T@<W5B<W1R*"1H9'(L(#`L("1P;W,I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1O8BT^9&ES<&]S:71I;VX@
M/2`D:&1R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O8BT^:69D
M:7-P;W-I=&EO;B`](#`["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYT96YT
M+4E$+B`J+PH@("`@("`@(&EF("AI<W-E="@D;V(M/FAE861E<G-;)V-O;G1E
M;G0M:60G72DI('L*("`@("`@("`@("`@)&]B+3YI9FED(#T@,3L*("`@("`@
M("`@("`@)&]B+3YI9"`]("1O8BT^:&5A9&5R<ULG8V]N=&5N="UI9"==.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O8BT^:69I9"`](#`["B`@
M("`@("`@?0H*("`@("`@("`O*B!'970@9FEL92!S:7IE("AI9B`G8F]D>2<@
M=&5X="!I<R!S970I+B`J+PH@("`@("`@(&EF("AI<W-E="@D;V(M/F)O9'DI
M*2!["B`@("`@("`@("`@("1O8BT^8GET97,@/2!S=')L96XH)&]B+3YB;V1Y
M*3L*("`@("`@("!]"@H@("`@("`@("\J(%!R;V-E<W,@<&%R=',@86QS;RX@
M*B\*("`@("`@("!I9B`H:7-S970H)&]B+3YP87)T<RDI('L*("`@("`@("`@
M("`@9F]R96%C:"`H87)R87E?:V5Y<R@D;V(M/G!A<G1S*2!A<R`D:V5Y*2![
M"B`@("`@("`@("`@("`@("!-24U%7U-T<G5C='5R93HZ7V-O;G9E<G1-:6UE
M1&5C;V1E1&%T82@D;V(M/G!A<G1S6R1K97E=*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!A<G)A
M>2!C;VYS:7-T:6YG(&]F($U)344@:&5A9&5R+W9A;'5E('!A:7)S+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE861E<G,@("`@($$@=&5X="!S
M=')I;F<@8V]N=&%I;FEN9R!T:&4@:&5A9&5R<R`H92YG+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;W5T<'5T(&9R;VT@:6UA<%]F971C
M:&AE861E<B@I*2X*("`@("`J($!P87)A;2!B;V]L96%N("1D96-O9&4@("`@
M(%-H;W5L9"!T:&4@:&5A9&5R<R!B92!D96-O9&5D/PH@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&QO=V5R8V%S92`@4VAO=6QD('1H92!K97ES(&)E(&EN(&QO
M=V5R8V%S93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A
M>2!C;VYS:7-T:6YG(&]F('1H92!H96%D97(@;F%M92!A<R!T:&4@:V5Y(&%N
M9`H@("`@("H@("`@("`@("`@("`@("`@=&AE(&AE861E<B!V86QU92!A<R!T
M:&4@=F%L=64N"B`@("`@*B`@("`@("`@("`@("`@("!!(&AE861E<B!W:71H
M(&UU;'1I<&QE(&5N=')I97,@=VEL;"!B92!S=&]R960@:6X*("`@("`J("`@
M("`@("`@("`@("`@("=V86QU92<@87,@86X@87)R87DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!A<G-E34E-14AE861E<G,H)&AE861E<G,L("1D96-O9&4@
M/2!T<G5E+"`D;&]W97)C87-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&AE
M861E<B`]("<G.PH@("`@("`@("1O8B`](&%R<F%Y*"D["@H@("`@("`@(&9O
M<F5A8V@@*&5X<&QO9&4H(EQN(BP@)&AE861E<G,I(&%S("1V86PI('L*("`@
M("`@("`@("`@:68@*"1D96-O9&4I('L*("`@("`@("`@("`@("`@("1V86P@
M/2!-24U%.CID96-O9&4H)'9A;"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H(B]>*%M>7'-=*RE<.B@N*BDO(BP@)'9A;"P@
M)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`D=F%L(#T@=')I;2@D;6%T
M8VAE<ULR72D["B`@("`@("`@("`@("`@("`D:&5A9&5R(#T@)&UA=&-H97-;
M,5T["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]B6R1H96%D97)=*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&]B6R1H96%D
M97)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&5M<"`]("1O8ELD
M:&5A9&5R73L*("`@("`@("`@("`@("`@("`@("`@("`@)&]B6R1H96%D97)=
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&]B6R1H96%D
M97)=6UT@/2`D=&5M<#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)&]B6R1H96%D97)=6UT@/2`D=F%L.PH@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'9A;"`]("<@)R`N('1R
M:6TH)'9A;"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A96UP
M='DH)&AE861E<BDI('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;V);
M)&AE861E<ETI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1O8ELD:&5A9&5R72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@96YD
M*"1O8ELD:&5A9&5R72D["B`@("`@("`@("`@("`@("`@("`@("`@("1O8ELD
M:&5A9&5R75MK97DH)&]B6R1H96%D97)=*5T@+CT@)'9A;#L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;V);)&AE861E<ET@+CT@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1O
M8ELD:&5A9&5R72`]("1V86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H)&QO=V5R8V%S92D@
M/R!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&]B+"!#05-%7TQ/5T52*2`Z("1O
M8CL*("`@('T*"GT*+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(N<&AP````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#,T-C$Q`#$P-#$W,S8R-S<S`#`R,#<T,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($U)345?5FEE=V5R.CH@8VQA<W,@<')O=FED97,@86X@86)S=')A8W1E9"!I
M;G1E<F9A8V4@=&\*("H@<F5N9&5R(&]U="!-24U%('1Y<&5S(&EN=&\@2%1-
M3"!F;W)M870N("!)="!D97!E;F1S(&]N(&$*("H@<V5T(&]F($U)345?5FEE
M=V5R7RH@9')I=F5R<R!W:&EC:"!H86YD;&4@=&AE(&%C='5A;"!R96YD97)I
M;F<L"B`J(&%N9"!A;'-O(&$@8V]N9FEG=7)A=&EO;B!F:6QE('1O(&UA<"!-
M24U%('1Y<&5S('1O(&1R:79E<G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(N<&AP+'8@,2XV-"XQ,"XY(#(P,#8O,#$O,#$@
M,C$Z,C@Z,C0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E
M8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(
M;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97(@>PH*("`@
M("\J*@H@("`@("H@5&AE($U)345?4&%R="!O8FIE8W0@=&\@<F5N9&5R+@H@
M("`@("H*("`@("`J($!V87(@34E-15]087)T"B`@("`@*B\*("`@('9A<B`D
M;6EM95]P87)T.PH*("`@("\J*@H@("`@("H@0V]N9FEG=7)A=&EO;B!P87)A
M;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?8V]N9B`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!G971$<FEV
M97(@8V%C:&4N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]D<FEV97)#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!&;W)C92!V:65W:6YG(&]F(&$@<&%R="!I;FQI;F4L(')E9V%R9&QE<W,@
M;V8@=&AE($-O;G1E;G0M1&ES<&]S:71I;VX*("`@("`J(&]F('1H92!-24U%
M(%!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@
M('9A<B`D7V9O<F-E:6YL:6YE(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!!
M='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!-24U%7U9I97=E<E\J(&]B
M:F5C="!B87-E9"!O;B!T:&4*("`@("`J('1Y<&4@;V8@34E-15]087)T('!A
M<W-E9"!O;G1O(&ET+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@
M)B1M:6UE7W!A<G0@(%)E9F5R96YC92!T;R!A($U)345?4&%R="!O8FIE8W0@
M=VET:"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EN9F]R;6%T:6]N('1O(&)E(')E;F1E<F5D+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;6EM95]T>7!E("`@("`@57-E('1H:7,@34E-12!T>7!E(&EN<W1E
M860@;V8@=&AE('1Y<&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T;W)E9"!I;B!T:&4@)&UI;65?<&%R="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N($U)345?5FEE=V5R("!4:&4@34E-15]6:65W97(@;V)J96-T
M+"!O<B!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A
M8W1O<GDH)B1M:6UE7W!A<G0L("1M:6UE7W1Y<&4@/2!N=6QL*0H@("`@>PH@
M("`@("`@("\J($-H96-K('1H870@=V4@:&%V92!A('9A;&ED($U)345?4&%R
M="!O8FIE8W0@*B\*("`@("`@("!I9B`H(6ES7V$H)&UI;65?<&%R="P@)TU)
M345?4&%R="<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\J($1E=&5R;6EN92!D<FEV97(@='EP92!F<F]M('1H
M92!-24U%('1Y<&4@*B\*("`@("`@("!I9B`H96UP='DH)&UI;65?='EP92DI
M('L*("`@("`@("`@("`@)&UI;65?='EP92`]("1M:6UE7W!A<G0M/F=E=%1Y
M<&4H*3L*("`@("`@("`@("`@:68@*&5M<'1Y*"1M:6UE7W1Y<&4I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1V:65W97(@/2!F86QS93L*"B`@("`@("`@+RH@
M4W!A=VX@=&AE(')E;&5V86YT(&1R:79E<BP@86YD(')E='5R;B!I="`H;W(@
M9F%L<V4@;VX@9F%I;'5R92D@*B\*("`@("`@("!I9B`H*"1O8B`]($U)345?
M5FEE=V5R.CII;F-L=61E1')I=F5R*"1M:6UE7W1Y<&4I*2D@>PH@("`@("`@
M("`@("`D8VQA<W,@/2`H*"1O8BT^;6]D=6QE(#T]("=H;W)D92<I(#\@)R<@
M.B`D;V(M/FUO9'5L92`N("=?)RD@+B`G34E-15]6:65W97)?)R`N("1O8BT^
M9')I=F5R.PH@("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI
M('L*("`@("`@("`@("`@("`@("1V:65W97(@/2`F;F5W("1C;&%S<R@D;6EM
M95]P87)T+"`D1TQ/0D%,4ULG;6EM95]D<FEV97)S)UU;)&]B+3YM;V1U;&5=
M6R1O8BT^9')I=F5R72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=FEE=V5R.PH@("`@?0H*("`@("\J*@H@("`@("H@26YC
M;'5D92!T:&4@8V]D92!F;W(@=&AE(')E;&5V86YT(&1R:79E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M:6UE7W1Y<&4@(%1H92!#;VYT96YT
M+71Y<&4@;V8@=&AE('!A<G0@=&\@8F4@<F5N9&5R960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=&1#;&%S<R`@4V5E($U)345?1')I=F5R.CIG971$<FEV
M97(H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YC;'5D941R:79E<B@D;6EM
M95]T>7!E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@
M("`@("\J($9I9W5R92!T:&4@8V]R<F5C="!D<FEV97(@9F]R('1H:7,@34E-
M12!T>7!E+B!)9B!T:&5R92!I<R!N;PH@("`@("`@("`@(&%P<&QI8V%T:6]N
M+7-P96-I9FEC(&UO9'5L92P@82!G96YE<F%L($AO<F1E(&]N92!W:6QL(&%T
M=&5M<'0@=&\*("`@("`@("`@("!B92!U<V5D+B`J+PH@("`@("`@(&EF("@H
M)&]B(#T@34E-15]6:65W97(Z.F=E=$1R:79E<B@D;6EM95]T>7!E+"`D<F5G
M:7-T<GDM/F=E=$%P<"@I*2DI('L*("`@("`@("`@("`@+RH@26YC;'5D92!T
M:&4@8VQA<W,N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92!-24U%7U9I
M97=E<CHZ<F5S;VQV941R:79E<B@D;V(M/F1R:79E<BP@)&]B+3YM;V1U;&4I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R(&9O<B!-24U%7U9I97=E<@H@("`@("H*
M("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%)E9F5R96YC
M92!T;R!A($U)345?4&%R="!O8FIE8W0@=VET:"!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N('1O(&)E(')E
M;F1E<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!-24U%7U9I97=E<B@F)&UI
M;65?<&%R="P@)&-O;F8@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3YM:6UE7W!A<G0@/2`F)&UI;65?<&%R=#L*("`@("`@("`D=&AI<RT^7V-O
M;F8@/2`D8V]N9CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE($U)
M345?4&%R="!O8FIE8W0@9F]R('1H92!C;&%S<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!2969E<F5N8V4@=&\@82!-
M24U%7U!A<G0@;V)J96-T('=I=&@@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;B!T;R!B92!R96YD97)E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T34E-15!A<G0H)B1M:6UE7W!A<G0I
M"B`@("!["B`@("`@("`@)'1H:7,M/FUI;65?<&%R="`]("8D;6EM95]P87)T
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%('1Y<&4@
M;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N("!4:&ES(&-A;B!B90H@("`@("H@
M;W9E<G)I9&1E;B!B>2!T:&4@:6YD:79I9'5A;"!D<FEV97)S+"!D97!E;F1I
M;F<@;VX@=VAA="!F;W)M870*("`@("`J('1H97D@;W5T<'5T(&EN+B!">2!D
M969A=6QT+"!I="!P87-S97,@=&AR;W5G:"!T:&4@34E-12!T>7!E(&]F"B`@
M("`@*B!T:&4@;V)J96-T+"!O<B!R97!L86-E<R!C=7-T;VT@97AT96YS:6]N
M('1Y<&5S('=I=&@*("`@("`J("=T97AT+W!L86EN)R!T;R!L970@=&AE(&)R
M;W=S97(@9&\@82!B97-T+6=U97-S(')E;F1E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@34E-12UT>7!E(&]F('1H92!O=71P=70@8V]N=&5N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3YM:6UE7W!A<G0M/F=E=%!R:6UA<GE4>7!E*"D@/3T@
M)W@M97AT96YS:6]N)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E>'0O<&QA
M:6XG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;6EM95]P87)T+3YG9714>7!E*'1R=64I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@<F5N9&5R960@=F5R<VEO;B!O
M9B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J(%-H;W5L9"!B92!O=F5R<FED
M9&5N(&)Y(&EN9&EV:61U86P@9')I=F5R<R!T;R!P97)F;W)M(&-U<W1O;2!T
M87-K<RX*("`@("`J(%1H92`D;6EM95]P87)T(&-L87-S('9A<FEA8FQE(&AA
M<R!T:&4@:6YF;W)M871I;VX@=&\@<F5N9&5R+`H@("`@("H@96YC87!S=6QA
M=&5D(&EN(&$@34E-15]087)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)'!A<F%M<R`@06YY(&]P=&EO;F%L('!A<F%M971E<G,@=&AI
M<R!D<FEV97(@;F5E9',@870*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!R=6YT:6UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!296YD
M97)E9"!V97)S:6]N(&]F('1H92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F1E<B@D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T97AT+VAT;6P@;W5T<'5T('5S960@87,@
M86QT97)N871I=F4@;W5T<'5T('=H96X@=&AE(&9U;&QY"B`@("`@*B!R96YD
M97)E9"!O8FIE8W0@8V%N;F]T("AO<B!S:&]U;&0@;F]T*2!B92!D:7-P;&%Y
M960N("!&;W(@97AA;7!L92P*("`@("`J('1H:7,@9G5N8W1I;VX@<VAO=6QD
M(&)E('5S960@9F]R($U)344@871T86-H;65N=',@=&AA="!C86YN;W0@8F4*
M("`@("`J('9I97=E9"!I;FQI;F4L('=H97)E('1H92!U<V5R(&UA>2!B92!G
M:79E;B!O<'1I;VYS(&]N(&AO=R!T;R!V:65W"B`@("`@*B!T:&4@871T86-H
M;65N="X*("`@("`J(%-H;W5L9"!B92!O=F5R<FED9&5N(&)Y(&EN9&EV:61U
M86P@9')I=F5R<R!T;R!P97)F;W)M(&-U<W1O;2!T87-K<RX*("`@("`J(%1H
M92`D;6EM95]P87)T(&-L87-S('9A<FEA8FQE(&AA<R!T:&4@:6YF;W)M871I
M;VX@=&\@<F5N9&5R+`H@("`@("H@96YC87!S=6QA=&5D(&EN(&$@34E-15]0
M87)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M
M<R`@06YY(&]P=&EO;F%L('!A<F%M971E<G,@=&AI<R!D<FEV97(@;F5E9',@
M870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R=6YT:6UE+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!497AT+VAT;6P@<F5N9&5R960@
M:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<D%T=&%C
M:&UE;G1);F9O*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($-A;B!T
M:&ES(&1R:79E<B!R96YD97(@=&AE('1H92!D871A(&EN;&EN93\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&1R:79E<B!C
M86X@9&ES<&QA>2!I;FQI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A;D1I
M<W!L87E);FQI;F4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T0V]N
M9FEG4&%R86TH)VEN;&EN92<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A(&1R:79E
M<B!A;F0@86X@87!P;&EC871I;VXL('1H:7,@<F5T=7)N<R!T:&4@9G5L;'D*
M("`@("`J('%U86QI9FEE9"!F:6QE<WES=&5M('!A=&@@=&\@=&AE(&1R:79E
M<B!S;W5R8V4@9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M<FEV97(@($1R:79E<B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P
M("`@("!!<'!L:6-A=&EO;B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!&:6QE<WES=&5M('!A=&@@;V8@=&AE(&1R:79E<B]A<'!L:6-A
M=&EO;B!Q=65R:65D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-O;'9E1')I
M=F5R*"1D<FEV97(@/2`G9&5F875L="<L("1A<'`@/2`G:&]R9&4G*0H@("`@
M>PH@("`@("`@(&EF("@D87!P(#T]("=H;W)D92<I('L*("`@("`@("`@("`@
M<F5T=7)N(&1I<FYA;64H7U]&24Q%7U\I("X@)R]6:65W97(O)R`N("1D<FEV
M97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YA<'!L:6-A=&EO;G-;)&%P<%U;
M)V9I;&5R;V]T)UT@+B`G+VQI8B]-24U%+U9I97=E<B\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E
M;B!A;B!I;G!U="!-24U%('1Y<&4@86YD(&$@;6]D=6QE(&YA;64L('1H:7,@
M9G5N8W1I;VX*("`@("`J(')E<V]L=F5S(&ET(&EN=&\@82!S<&5C:69I8R!O
M=71P=70@9')I=F5R('=H:6-H(&-A;B!H86YD;&4@:70N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6EM951Y<&4@($U)344@='EP92!T;R!R97-O
M;'9E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D=6QE("`@($UO9'5L92!I
M;B!W:&EC:"!T;R!S96%R8V@@9F]R('1H92!D<FEV97(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=&1#;&%S<R`@3V)J96-T('=I=&@@=&AE(&9O;&QO=VEN
M9R!I=&5M<SH*("`@("`J(#QP<F4^"B`@("`@*B`G9')I=F5R)R`@+2T@($YA
M;64@;V8@9')I=F5R("AE+F<N("=E;G-C<FEP="<I"B`@("`@*B`G97AA8W0G
M("`@+2T@(%=A<R!T:&4@9')I=F5R(&%N9"!E>&%C="!M871C:#\@*'1R=64O
M9F%L<V4I"B`@("`@*B`G;6]D=6QE)R`@+2T@(%1H92!M;V1U;&4@8V]N=&%I
M;FEN9R!D<FEV97(@*&4N9RX@)VAO<F1E)RD*("`@("`J(#PO<')E/@H@("`@
M("H@4F5T=7)N<R!F86QS92!I9B!D<FEV97(@8V]U;&0@;F]T(&)E(&9O=6YD
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$<FEV97(H)&UI;654>7!E+"`D
M;6]D=6QE(#T@)VAO<F1E)RD*("`@('L*("`@("`@("!G;&]B86P@)&UI;65?
M9')I=F5R<RP@)&UI;65?9')I=F5R<U]M87`["@H@("`@("`@("1C86-H94YA
M;64@/2`D;6EM951Y<&4@+B`G?"<@+B`D;6]D=6QE.PH@("`@("`@(&EF("AI
M<W-E="@D=&AI<RD@)B8@:7-S970H)'1H:7,M/E]D<FEV97)#86-H95LD8V%C
M:&5.86UE72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R
M0V%C:&5;)&-A8VAE3F%M95T["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R
M(#T@)R<["B`@("`@("`@)&5X86-T1')I=F5R(#T@9F%L<V4["@H@("`@("`@
M(&QI<W0H)'!R:6UA<GE?='EP92P@*2`](&5X<&QO9&4H)R\G+"`D;6EM951Y
M<&4L(#(I.PH@("`@("`@("1A;&Q3=6(@/2`D<')I;6%R>5]T>7!E("X@)R\J
M)SL*"B`@("`@("`@+RH@268@=&AE(&UO9'5L92!D;V5S;B=T(&5X:7-T(&EN
M("1M:6UE7V1R:79E<G-?;6%P+"!C:&5C:R!F;W(*("`@("`@("`@("!(;W)D
M92!V:65W97)S+B`J+PH@("`@("`@(&EF("@A:7-S970H)&UI;65?9')I=F5R
M<U]M87!;)&UO9'5L95TI("8F("1M;V1U;&4@(3T@)VAO<F1E)RD@>PH@("`@
M("`@("`@("!R971U<FX@34E-15]6:65W97(Z.F=E=$1R:79E<B@D;6EM951Y
M<&4L("=H;W)D92<I.PH@("`@("`@('T*"B`@("`@("`@)&1R(#T@)B1M:6UE
M7V1R:79E<G-;)&UO9'5L95T["B`@("`@("`@)&UA<"`]("8D;6EM95]D<FEV
M97)S7VUA<%LD;6]D=6QE73L*"B`@("`@("`@+RH@268@86X@;W9E<G)I9&4@
M97AI<W1S(&9O<B!T:&ES($U)344@='EP92P@=&AE;B!U<V4@=&AA="`J+PH@
M("`@("`@(&EF("AI<W-E="@D;6%P6R=O=F5R<FED97,G75LD;6EM951Y<&5=
M*2D@>PH@("`@("`@("`@("`D9')I=F5R(#T@)&UA<%LG;W9E<G)I9&5S)UU;
M)&UI;654>7!E73L*("`@("`@("`@("`@)&5X86-T1')I=F5R(#T@=')U93L*
M("`@("`@("!](&5L<V5I9B`H:7-S970H)&UA<%LG;W9E<G)I9&5S)UU;)&%L
M;%-U8ETI*2!["B`@("`@("`@("`@("1D<FEV97(@/2`D;6%P6R=O=F5R<FED
M97,G75LD86QL4W5B73L*("`@("`@("`@("`@)&5X86-T1')I=F5R(#T@=')U
M93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)&UA<%LG<F5G:7-T97)E9"==
M*2D@>PH@("`@("`@("`@("`O*B!)=&5R871E('1H<F]U9V@@=&AE(&QI<W0@
M;V8@<F5G:7-T97)E9"!D<FEV97)S+"!A;F0@<V5E(&EF"B`@("`@("`@("`@
M("`@('1H:7,@34E-12!T>7!E(&5X:7-T<R!I;B!T:&4@34E-12!T>7!E<R!T
M:&%T('1H97D@8VQA:6T@=&\*("`@("`@("`@("`@("`@:&%N9&QE+B!)9B!T
M:&4@9')I=F5R(&AA;F1L97,@:70L('1H96X@87-S:6=N(&ET(&%S('1H90H@
M("`@("`@("`@("`@("!R96YD97)I;F<@9')I=F5R+B!)9B!W92!F:6YD(&$@
M9V5N97)I8R!H86YD;&5R+"!K965P(&ET97)A=&EN9PH@("`@("`@("`@("`@
M("!T;R!S964@:68@=V4@8V%N(&9I;F0@82!S<&5C:69I8R!H86YD;&5R+B`J
M+PH@("`@("`@("`@("!F;W)E86-H("@D;6%P6R=R96=I<W1E<F5D)UT@87,@
M)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1M:6UE5'EP
M92P@)&1R6R1V86Q=6R=H86YD;&5S)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&1R:79E<B`]("1V86P["B`@("`@("`@("`@("`@("`@("`@)&5X86-T
M1')I=F5R(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@('T@96QS96EF("AI;E]A<G)A>2@D86QL4W5B+"`D9');
M)'9A;%U;)VAA;F1L97,G72DI('L*("`@("`@("`@("`@("`@("`@("`D9')I
M=F5R(#T@)'9A;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+RH@268@=&AI<R!I<R!A;B!A<'!L:6-A=&EO
M;B!S<&5C:69I8R!M;V1U;&4L(&%N9"!A;B!E>&%C="!M871C:"!W87,*("`@
M("`@("`@("!N;W0@9F]U;F0L('-E87)C:"!F;W(@82!(;W)D92UW:61E('-P
M96-I9FEC(&1R:79E<BX@3VYL>2!U<V4@=&AE"B`@("`@("`@("`@2&]R9&4M
M<W!E8VEF:6,@9')I=F5R(&EF(&ET(&ES($Y/5"!T:&4@)V1E9F%U;'0G(&1R
M:79E<B!!3D0@=&AE"B`@("`@("`@("`@2&]R9&4@9')I=F5R(&ES(&%N(&5X
M86-T(&UA=&-H+B`J+PH@("`@("`@(&EF("@A)&5X86-T1')I=F5R("8F("1M
M;V1U;&4@(3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`D;V(@/2!-24U%7U9I
M97=E<CHZ9V5T1')I=F5R*"1M:6UE5'EP92P@)VAO<F1E)RD["B`@("`@("`@
M("`@(&EF("AE;7!T>2@D9')I=F5R*2!\?`H@("`@("`@("`@("`@("`@*"@D
M;V(M/F1R:79E<B`A/2`G9&5F875L="<I("8F("1O8BT^97AA8W0I*2!["B`@
M("`@("`@("`@("`@("`D9')I=F5R(#T@)&]B+3YD<FEV97(["B`@("`@("`@
M("`@("`@("`D;6]D=6QE(#T@)VAO<F1E)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@268@=&AE("=D969A=6QT)R!D<FEV97(@97AI
M<W1S(&EN('1H:7,@;6]D=6QE+"!F86QL(&)A8VL@=&\@=&AA="X@*B\*("`@
M("`@("!I9B`H96UP='DH)&1R:79E<BD@)B8*("`@("`@("`@("`@0&ES7V9I
M;&4H34E-15]6:65W97(Z.G)E<V]L=F5$<FEV97(H)V1E9F%U;'0G+"`D;6]D
M=6QE*2DI('L*("`@("`@("`@("`@)&1R:79E<B`]("=D969A=6QT)SL*("`@
M("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D9')I=F5R*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V1R:79E<D-A8VAE6R1C86-H94YA;65=(#T@9F%L<V4[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;V(@/2!N97<@<W1D0VQA<W,["B`@("`@("`@("`@("1O
M8BT^9')I=F5R(#T@)&1R:79E<CL*("`@("`@("`@("`@)&]B+3YE>&%C="`@
M/2`D97AA8W1$<FEV97(["B`@("`@("`@("`@("1O8BT^;6]D=6QE(#T@)&UO
M9'5L93L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D<FEV97)#86-H95LD8V%C:&5.86UE72`]("1O
M8CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&]B.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@34E-12!T>7!E
M+"!T:&ES(&9U;F-T:6]N('=I;&P@<F5T=7)N(&%N(&%P<')O<')I871E"B`@
M("`@*B!I8V]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;654
M>7!E("!4:&4@34E-12!T>7!E('1H870@=V4@;F5E9"!A;B!I8V]N(&9O<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%523"!T;R!T:&4@
M87!P<F]P<FEA=&4@:6-O;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26-O
M;B@D;6EM951Y<&4I"B`@("!["B`@("`@("`@)&%P<"`]("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG971!<'`H*3L*("`@("`@("`D;V(@/2!-24U%7U9I97=E
M<CHZ7V=E=$EC;VXH)&UI;654>7!E+"`D87!P*3L*"B`@("`@("`@:68@*"1O
M8B`]/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H)&%P<"`A/2`G:&]R9&4G
M*2!["B`@("`@("`@("`@("`@("`D;V)(;W)D92`]($U)345?5FEE=V5R.CI?
M9V5T26-O;B@D;6EM951Y<&4L("=H;W)D92<I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N("@D;V)(;W)D92`]/3T@;G5L;"D@/R!N=6QL(#H@)&]B2&]R9&4M
M/G5R;#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"@D
M;V(M/FUA=&-H("$]/2`P*2`F)B`H)&%P<"`A/2`G:&]R9&4G*2D@>PH@("`@
M("`@("`@("`D;V)(;W)D92`]($U)345?5FEE=V5R.CI?9V5T26-O;B@D;6EM
M951Y<&4L("=H;W)D92<I.PH@("`@("`@("`@("!I9B`H)&]B+3YM871C:"`A
M/3T@;G5L;"`F)B`D;V(M/FUA=&-H(#P]("1O8DAO<F1E+3YM871C:"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1O8BT^=7)L.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1O8DAO<F1E+3YU<FP[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)&]B+3YU<FP["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1VEV96X@86X@:6YP=70@34E-12!T>7!E(&%N9"!M;V1U;&4L('1H:7,@
M9G5N8W1I;VX@<F5T=7)N<R!T:&4*("`@("`J(%523"!O9B!A;B!I8V]N('1H
M870@8V%N(&)E(&%S<V]C:6%T960@=VET:"!I=`H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI
M;654>7!E("!-24U%('1Y<&4@=&\@9V5T('1H92!I8V]N(&9O<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T9$-L87-S("!U<FPZ("`@55),('1O(&%N(&EC
M;VXL(&]R(&YU;&P@:68@;F]N90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O=6QD(&)E(&9O=6YD+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@97AA8W0Z($AO=R!E>&%C="!T:&4@;6%T8V@@:7,N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@,"`]/B`G97AA8W0G+"`Q(#T^("=P<FEM
M87)Y)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`R(#T^("=D
M<FEV97(G+"`S(#T^("=D969A=6QT)PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&]R(&YU;&PN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971)
M8V]N*"1M:6UE5'EP92P@)&UO9'5L92`]("=H;W)D92<I"B`@("!["B`@("`@
M("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("1O8B`]($U)345?
M5FEE=V5R.CIG971$<FEV97(H)&UI;654>7!E+"`D;6]D=6QE*3L*("`@("`@
M("!I9B`H(6ES7V]B:F5C="@D;V(I*2!["B`@("`@("`@("`@(')E='5R;B!A
M<G)A>2AF86QS92P@;G5L;"D["B`@("`@("`@?0H@("`@("`@("1D<FEV97(@
M/2`D;V(M/F1R:79E<CL*"B`@("`@("`@;&ES="@D<')I;6%R>5]T>7!E+"D@
M/2!E>'!L;V1E*"<O)RP@)&UI;654>7!E+"`R*3L*("`@("`@("`D86QL4W5B
M(#T@)'!R:6UA<GE?='EP92`N("<O*B<["B`@("`@("`@)')E=$]B(#T@)FYE
M=R!S=&1#;&%S<R@I.PH@("`@("`@("1R971/8BT^;6%T8V@@/2!N=6QL.PH@
M("`@("`@("1R971/8BT^=7)L(#T@;G5L;#L*"B`@("`@("`@+RH@268@=&AE
M(&UO9'5L92!D;V5S;B=T(&5X:7-T(&EN("1M:6UE7V1R:79E<G,L(')E='5R
M;B!N;W<N("HO"B`@("`@("`@:68@*"%I<W-E="@D;6EM95]D<FEV97)S6R1M
M;V1U;&5=*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@)&1R(#T@)B1M:6UE7V1R:79E<G-;)&UO9'5L95T["@H@("`@
M("`@("\J($EF(&$@<W!E8VEF:6,@:6-O;B!F;W(@=&AI<R!D<FEV97(@86YD
M(&UI;65T>7!E(&ES(&1E9FEN960L"B`@("`@("`@("`@=&AE;B!U<V4@=&AA
M="X@*B\*("`@("`@("!I9B`H:7-S970H)&1R6R1D<FEV97)=6R=I8V]N<R==
M*2D@>PH@("`@("`@("`@("`D:6-O;F1R(#T@)B1M:6UE7V1R:79E<G-;)&UO
M9'5L95U;)&1R:79E<EU;)VEC;VYS)UT["B`@("`@("`@("`@("1I8V]N3&ES
M="`](&%R<F%Y*"1M:6UE5'EP92`]/B`P+"`D86QL4W5B(#T^(#$L("=D969A
M=6QT)R`]/B`R*3L*("`@("`@("`@("`@9F]R96%C:"`H)&EC;VY,:7-T(&%S
M("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I
M8V]N9');)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)')E=$]B+3YU
M<FP@/2`D:6-O;F1R6R1K97E=.PH@("`@("`@("`@("`@("`@("`@("1R971/
M8BT^;6%T8V@@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!4<GD@=&\@=7-E(&$@9&5F875L="!I8V]N(&EF(&YO;F4@86QR
M96%D>2!O8G1A:6YE9"X@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D<F5T3V(M
M/G5R;"D@)B8@:7-S970H)&1R6R=D969A=6QT)UTI*2!["B`@("`@("`@("`@
M("1D<B`]("8D;6EM95]D<FEV97)S6R1M;V1U;&5=6R=D969A=6QT)UT["B`@
M("`@("`@("`@(&EF("AI<W-E="@D9');)VEC;VYS)UU;)V1E9F%U;'0G72DI
M('L*("`@("`@("`@("`@("`@("1R971/8BT^=7)L(#T@)&1R6R=D969A=6QT
M)UU;)VEC;VYS)UU;)V1E9F%U;'0G73L*("`@("`@("`@("`@("`@("1R971/
M8BT^;6%T8V@@/2`S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H(6ES7VYU;&PH)')E=$]B+3YU<FPI*2!["B`@("`@("`@("`@("1R
M971/8BT^=7)L(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER
M*"1M;V1U;&4I("X@)R]M:6UE+R<@+B`D<F5T3V(M/G5R;#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<F5T3V(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!C:&%R86-T97(@<V5T('5S960@9F]R('1H92!6:65W
M97(N"B`@("`@*B!3:&]U;&0@8F4@;W9E<G)I9&1E;B!B>2!I;F1I=FED=6%L
M(&1R:79E<G,@=&\@<&5R9F]R;2!C=7-T;VT@=&%S:W,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!C:&%R86-T97(@<V5T('5S960@8GD@
M=&AI<R!6:65W97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-H87)S970H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;6EM95]P87)T+3YG971#
M:&%R<V5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!C;VYF
M:6=U<F%T:6]N('!A<F%M971E<B!F;W(@=&AE(&-U<G)E;G0@=FEE=V5R+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A<F%M("!4:&4@<&%R86UE
M=&5R(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('9A
M;'5E(&]F('1H92!P87)A;65T97([(')E='5R;G,@;G5L;"!I9B!T:&4@<&%R
M86UE=&5R"B`@("`@*B`@("`@("`@("`@("`@("!D;V5S;B=T(&5X:7-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971#;VYF:6=087)A;2@D<&%R86TI"B`@
M("!["B`@("`@("`@<F5T=7)N("AI<W-E="@D=&AI<RT^7V-O;F9;)'!A<F%M
M72DI(#\@)'1H:7,M/E]C;VYF6R1P87)A;5T@.B!N=6QL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4VAO=6QD('=E(&9O<F-E('9I97=I;F<@;V8@=&AI<R!-
M24U%(%!A<G0@:6YL:6YE+"!R96=A<F1L97-S(&]F('1H90H@("`@("H@0V]N
M=&5N="U$:7-P;W-I=&EO;B!O9B!T:&4@34E-12!087)T/PH@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@1F]R8V4@=FEE=VEN9R!I;FQI;F4_"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9O<F-E26YL:6YE5FEE=R@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9F]R8V5I;FQI;F4["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]M:6UE+FUA<'!I;F<N<&AP````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4S,S0P`#$P-#$W,S8R-S<S`#`R,C`V
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS(&$@;6%P<&EN9R!O9B!C
M;VUM;VX@9FEL92!E>'1E;G-I;VYS('1O"B`J($U)344@='EP97,N($ET(&AA
M<R!B965N(&%U=&]M871I8V%L;'D@9V5N97)A=&5D(&9R;VT@=&AE"B`J(&AO
M<F1E+W-C<FEP=',O;6EM95]M87!P:6YG(&1I<F5C=&]R>2X*("H*("H@04Q,
M(&-H86YG97,@<VAO=6QD(&)E(&UA9&4@=&\@:&]R9&4O<V-R:7!T<R]M:6UE
M7VUA<'!I;F<O;6EM92YT>7!E<RYH;W)D90H@*B!O<B!E;'-E('1H97D@=VEL
M;"!B92!L;W-T('=H96X@=&AI<R!F:6QE(&ES(')E9V5N97)A=&5D+@H@*@H@
M*B!!;GD@=6YK;F]W;B!F:6QE(&5X=&5N<VEO;G,@=VEL;"!A=71O;6%T:6-A
M;&QY(&)E(&UA<'!E9"!T;PH@*B`G>"UE>'1E;G-I;VXO/&5X=#XG('=H97)E
M(#QE>'0^(&ES('1H92!U;FMN;W=N(&9I;&4@97AT96YS:6]N+@H@*@H@*B!`
M<&%C:V%G92!(;W)D95]-24U%"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)
M344O34E-12]M:6UE+FUA<'!I;F<N<&AP+'8@,2XQ,2XR+C,@,C`P-B\P,B\Q
M,"`Q,#HS-SHS,R!J86X@17AP("0*("H*("H@1V5N97)A=&5D.B`P,B\Q,"\P
M-B`P,#HQ.#HT-2!B>2!S;'5S87)Z(&]N(&)I9W=O<FTN8W5R96-A;G1I+F]R
M9PH@*B\*)&UI;65?97AT96YS:6]N7VUA<"`](&%R<F%Y*`HG7U]-05A015))
M3T1?7R<@/3X@)S$G+`H@("`@)S-D<R<@("`@("`@("`@(#T^("=I;6%G92]X
M+3-D<R<L"B`@("`G0DQ%3D0G("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M8FQE;F1E<B<L"B`@("`G0R<@("`@("`@("`@("`@/3X@)W1E>'0O>"UC*RMS
M<F,G+`H@("`@)T-34TPG("`@("`@("`@(#T^("=T97AT+V-S<R<L"B`@("`G
M3E-6)R`@("`@("`@("`@/3X@)W9I9&5O+W@M;G-V)RP*("`@("=005(R)R`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP87(R)RP*("`@("=832<@("`@
M("`@("`@("`]/B`G875D:6\O>"UM;V0G+`H@("`@)UHG("`@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+6-O;7!R97-S)RP*("`@("=A)R`@("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UA<F-H:79E)RP*("`@("=A8G<G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UA8FEW;W)D)RP*("`@("=A8G<N
M0U)!4TA%1"<@("`]/B`G87!P;&EC871I;VXO>"UA8FEW;W)D)RP*("`@("=A
M8G<N9WHG("`@("`@("`]/B`G87!P;&EC871I;VXO>"UA8FEW;W)D)RP*("`@
M("=A8S,G("`@("`@("`@("`]/B`G875D:6\O86,S)RP*("`@("=A9&(G("`@
M("`@("`@("`]/B`G=&5X="]X+6%D87-R8R<L"B`@("`G861S)R`@("`@("`@
M("`@/3X@)W1E>'0O>"UA9&%S<F,G+`H@("`@)V%F;2<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+69O;G0M869M)RP*("`@("=A9R<@("`@("`@("`@
M("`]/B`G:6UA9V4O>"UA<'!L:7@M9W)A<&AI8W,G+`H@("`@)V%I)R`@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]I;&QU<W1R871O<B<L"B`@("`G86EF
M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M86EF9B<L"B`@("`G86EF8R<@("`@
M("`@("`@/3X@)V%U9&EO+W@M86EF9B<L"B`@("`G86EF9B<@("`@("`@("`@
M/3X@)V%U9&EO+W@M86EF9B<L"B`@("`G86PG("`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M<&5R;"<L"B`@("`G87)J)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M87)J)RP*("`@("=A<R<@("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UA<'!L:7@M<W!R96%D<VAE970G+`H@("`@)V%S8R<@("`@
M("`@("`@(#T^("=T97AT+W!L86EN)RP*("`@("=A<V8G("`@("`@("`@("`]
M/B`G=FED96\O>"UM<RUA<V8G+`H@("`@)V%S<"<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6%S<"<L"B`@("`G87-X)R`@("`@("`@("`@/3X@)W9I
M9&5O+W@M;7,M87-F)RP*("`@("=A=&]M)R`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO871O;2MX;6PG+`H@("`@)V%U)R`@("`@("`@("`@(#T^("=A=61I
M;R]B87-I8R<L"B`@("`G879I)R`@("`@("`@("`@/3X@)W9I9&5O+W@M;7-V
M:61E;R<L"B`@("`G87<G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M87!P;&EX+7=O<F0G+`H@("`@)V)A:R<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+71R87-H)RP*("`@("=B8W!I;R<@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UB8W!I;R<L"B`@("`G8F1F)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M9F]N="UB9&8G+`H@("`@)V)I8B<@("`@("`@("`@(#T^("=T
M97AT+W@M8FEB=&5X)RP*("`@("=B:6XG("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO;V-T970M<W1R96%M)RP*("`@("=B;&5N9"<@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UB;&5N9&5R)RP*("`@("=B;&5N9&5R)R`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UB;&5N9&5R)RP*("`@("=B;7`G("`@("`@("`@
M("`]/B`G:6UA9V4O8FUP)RP*("`@("=B>B<@("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UB>FEP)RP*("`@("=B>C(G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UB>FEP)RP*("`@("=C)R`@("`@("`@("`@("`]/B`G=&5X
M="]X+6-S<F,G+`H@("`@)V,K*R<@("`@("`@("`@(#T^("=T97AT+W@M8RLK
M<W)C)RP*("`@("=C8R<@("`@("`@("`@("`]/B`G=&5X="]X+6,K*W-R8R<L
M"B`@("`G8V1F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;F5T8V1F
M)RP*("`@("=C9'(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F-O
M<F5L+61R87<G+`H@("`@)V-E<B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+7@U,#DM8V$M8V5R="<L"B`@("`G8V5R="<@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M>#4P.2UC82UC97)T)RP*("`@("=C9VDG("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UC9VDG+`H@("`@)V-G;2<@("`@("`@("`@
M(#T^("=I;6%G92]C9VTG+`H@("`@)V-H;2<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6-H;2<L"B`@("`G8VAR="<@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M:V-H87)T)RP*("`@("=C;&%S<R<@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UJ879A)RP*("`@("=C;',G("`@("`@("`@("`]/B`G=&5X
M="]X+71E>"<L"B`@("`G8W!I;R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M8W!I;R<L"B`@("`G8W!I;RYG>B<@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M8W!I;RUC;VUP<F5S<V5D)RP*("`@("=C<'`G("`@("`@("`@("`]/B`G
M=&5X="]X+6,K*W-R8R<L"B`@("`G8W!T)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+VUA8RUC;VUP86-T<')O)RP*("`@("=C<G0G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UX-3`Y+6-A+6-E<G0G+`H@("`@)V-S)R`@("`@
M("`@("`@(#T^("=T97AT+W@M8W-H87)P)RP*("`@("=C<V@G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UC<V@G+`H@("`@)V-S<R<@("`@("`@("`@
M(#T^("=T97AT+V-S<R<L"B`@("`G8W-V)R`@("`@("`@("`@/3X@)W1E>'0O
M>"UC;VUM82US97!A<F%T960M=F%L=65S)RP*("`@("=C=7(G("`@("`@("`@
M("`]/B`G:6UA9V4O>"UW:6XM8FET;6%P)RP*("`@("=C>'@G("`@("`@("`@
M("`]/B`G=&5X="]X+6,K*W-R8R<L"B`@("`G9"<@("`@("`@("`@("`@/3X@
M)W1E>'0O>"UD<W)C)RP*("`@("=D870G("`@("`@("`@("`]/B`G=FED96\O
M;7!E9R<L"B`@("`G9&)F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M9&)A<V4G+`H@("`@)V1C)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+61C+7)O;2<L"B`@("`G9&-L)R`@("`@("`@("`@/3X@)W1E>'0O>"UD8VPG
M+`H@("`@)V1C;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]D:6-O;2<L
M"B`@("`G9&-R)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9&ER96-T
M;W(G+`H@("`@)V1E8B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61E
M8B<L"B`@("`G9&5R)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M>#4P
M.2UC82UC97)T)RP*("`@("=D97-K=&]P)R`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UD97-K=&]P)RP*("`@("=D:6$G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UD:6$M9&EA9W)A;2<L"B`@("`G9&EF9B<@("`@("`@("`@/3X@
M)W1E>'0O>"UP871C:"<L"B`@("`G9&ER)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M9&ER96-T;W(G+`H@("`@)V1J=B<@("`@("`@("`@(#T^("=I
M;6%G92]V;F0N9&IV=2<L"B`@("`G9&IV=2<@("`@("`@("`@/3X@)VEM86=E
M+W9N9"YD:G9U)RP*("`@("=D;&PG("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO;V-T970M<W1R96%M)RP*("`@("=D;6<G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO;V-T970M<W1R96%M)RP*("`@("=D;7,G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO;V-T970M<W1R96%M)RP*("`@("=D;V,G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO;7-W;W)D)RP*("`@("=D<VPG("`@("`@
M("`@("`]/B`G=&5X="]X+61S;"<L"B`@("`G9'1D)R`@("`@("`@("`@/3X@
M)W1E>'0O>"UD=&0G+`H@("`@)V1V:2<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+61V:2<L"B`@("`G9'=G)R`@("`@("`@("`@/3X@)VEM86=E+W9N
M9"YD=V<G+`H@("`@)V1X9B<@("`@("`@("`@(#T^("=I;6%G92]V;F0N9'AF
M)RP*("`@("=D>'(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UD:7)E
M8W1O<B<L"B`@("`G96=O;B<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M96=O;B<L"B`@("`G96PG("`@("`@("`@("`@/3X@)W1E>'0O>"UE;6%C<RUL
M:7-P)RP*("`@("=E<',G("`@("`@("`@("`]/B`G:6UA9V4O>"UE<',G+`H@
M("`@)V5P<V8G("`@("`@("`@(#T^("=I;6%G92]X+65P<R<L"B`@("`G97!S
M:2<@("`@("`@("`@/3X@)VEM86=E+W@M97!S)RP*("`@("=E=&AE;64G("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UE+71H96UE)RP*("`@("=E='@G("`@
M("`@("`@("`]/B`G=&5X="]X+7-E=&5X="<L"B`@("`G97AE)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M;7,M9&]S+65X96-U=&%B;&4G+`H@("`@
M)V5Z)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]A;F1R97<M:6YS970G
M+`H@("`@)V8G("`@("`@("`@("`@(#T^("=T97AT+W@M9F]R=')A;B<L"B`@
M("`G9FEG)R`@("`@("`@("`@/3X@)VEM86=E+W@M>&9I9R<L"B`@("`G9FET
M<R<@("`@("`@("`@/3X@)VEM86=E+W@M9FET<R<L"B`@("`G9FQA8R<@("`@
M("`@("`@/3X@)V%U9&EO+W@M9FQA8R<L"B`@("`G9FQC)R`@("`@("`@("`@
M/3X@)W9I9&5O+W@M9FQI8R<L"B`@("`G9FQI)R`@("`@("`@("`@/3X@)W9I
M9&5O+W@M9FQI8R<L"B`@("`G9FQW)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M:VEV:6\G+`H@("`@)V9O)R`@("`@("`@("`@(#T^("=T97AT+W@M
M>'-L9F\G+`H@("`@)V<S)R`@("`@("`@("`@(#T^("=I;6%G92]F87@M9S,G
M+`H@("`@)V=B)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=A;65B
M;WDM<F]M)RP*("`@("=G8W)D)R`@("`@("`@("`]/B`G=&5X="]D:7)E8W1O
M<GDG+`H@("`@)V=E;B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=E
M;F5S:7,M<F]M)RP*("`@("=G9R<@("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"US;7,M<F]M)RP*("`@("=G:68G("`@("`@("`@("`]/B`G:6UA9V4O
M9VEF)RP*("`@("=G;&%D92<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UG
M;&%D92<L"B`@("`G9VUO)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M9V5T=&5X="UT<F%N<VQA=&EO;B<L"B`@("`G9VYC)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M9VYU8V%S:"<L"B`@("`G9VYU8V%S:"<@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M9VYU8V%S:"<L"B`@("`G9VYU;65R:6,G("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M9VYU;65R:6,G+`H@("`@)V=R82<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=R87!H:71E)RP*("`@("=G<F%M
M)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO<W)G<R<L"B`@("`G9W)X;6PG
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W-R9W,K>&UL)RP*("`@("=G<V8G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UF;VYT+71Y<&4Q)RP*("`@
M("=G<VTG("`@("`@("`@("`]/B`G875D:6\O>"UG<VTG+`H@("`@)V=T87(G
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=T87(G+`H@("`@)V=Z)R`@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=Z:7`G+`H@("`@)V@G("`@
M("`@("`@("`@(#T^("=T97AT+W@M8VAD<B<L"B`@("`G:"LK)R`@("`@("`@
M("`@/3X@)W1E>'0O>"UC:&1R)RP*("`@("=H9&8G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UH9&8G+`H@("`@)VAH)R`@("`@("`@("`@(#T^("=T
M97AT+W@M8RLK:&1R)RP*("`@("=H<"<@("`@("`@("`@("`]/B`G=&5X="]X
M+6-H9'(G+`H@("`@)VAP9VPG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V
M;F0N:'`M:'!G;"<L"B`@("`G:'%X)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+VUA8RUB:6YH97@T,"<L"B`@("`G:',G("`@("`@("`@("`@/3X@)W1E
M>'0O>"UH87-K96QL)RP*("`@("=H=&TG("`@("`@("`@("`]/B`G=&5X="]H
M=&UL)RP*("`@("=H=&UL)R`@("`@("`@("`]/B`G=&5X="]H=&UL)RP*("`@
M("=I8V(G("`@("`@("`@("`]/B`G:6UA9V4O>"UI8V(G+`H@("`@)VEC92<@
M("`@("`@("`@(#T^("=X+6-O;F9E<F5N8V4O>"UC;V]L=&%L:R<L"B`@("`G
M:6-O)R`@("`@("`@("`@/3X@)VEM86=E+W@M:6-O)RP*("`@("=I8W,G("`@
M("`@("`@("`]/B`G=&5X="]C86QE;F1A<B<L"B`@("`G:61L)R`@("`@("`@
M("`@/3X@)W1E>'0O>"UI9&PG+`H@("`@)VEE9B<@("`@("`@("`@(#T^("=I
M;6%G92]I968G+`H@("`@)VEF8B<@("`@("`@("`@(#T^("=T97AT+V-A;&5N
M9&%R)RP*("`@("=I9F8G("`@("`@("`@("`]/B`G:6UA9V4O>"UI9F8G+`H@
M("`@)VEG97,G("`@("`@("`@(#T^("=M;V1E;"]I9V5S)RP*("`@("=I9W,G
M("`@("`@("`@("`]/B`G;6]D96PO:6=E<R<L"B`@("`G:6QB;2<@("`@("`@
M("`@/3X@)VEM86=E+W@M:6QB;2<L"B`@("`G:7-O)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M8V0M:6UA9V4G+`H@("`@)VET)R`@("`@("`@("`@
M(#T^("=A=61I;R]X+6ET)RP*("`@("=J87(G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UJ87(G+`H@("`@)VIA=F$G("`@("`@("`@(#T^("=T97AT
M+W@M:F%V82<L"B`@("`G:FYG)R`@("`@("`@("`@/3X@)VEM86=E+W@M:FYG
M)RP*("`@("=J;FQP)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UJ879A
M+6IN;'`M9FEL92<L"B`@("`G:G`R)R`@("`@("`@("`@/3X@)VEM86=E+VIP
M96<R,#`P)RP*("`@("=J<&<G("`@("`@("`@("`]/B`G:6UA9V4O:G!E9R<L
M"B`@("`G:G!E)R`@("`@("`@("`@/3X@)VEM86=E+VIP96<G+`H@("`@)VIP
M96<G("`@("`@("`@(#T^("=I;6%G92]J<&5G)RP*("`@("=J<'(G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UJ8G5I;&1E<BUP<F]J96-T)RP*("`@
M("=J<'@G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UJ8G5I;&1E<BUP
M<F]J96-T)RP*("`@("=J<R<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UJ879A<V-R:7!T)RP*("`@("=K87(G("`@("`@("`@("`]/B`G875D:6\O
M;6ED:2<L"B`@("`G:V%R8F]N)R`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M:V%R8F]N)RP*("`@("=K9&5L;FLG("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UD97-K=&]P)RP*("`@("=K9F\G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UK9F]R;75L82<L"B`@("`G:VEL)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M:VEL;'5S=')A=&]R)RP*("`@("=K;VXG("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UK;VYT;W5R)RP*("`@("=K<&TG("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UK<&]V;6]D96QE<B<L"B`@("`G:W!R)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W!R97-E;G1E<B<L"B`@("`G
M:W!T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W!R97-E;G1E<B<L
M"B`@("`G:W)A)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W)I=&$G
M+`H@("`@)VMS<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MS<')E
M860G+`H@("`@)VMU9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MU
M9V%R)RP*("`@("=K=V0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK
M=V]R9"<L"B`@("`G:W=T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M:W=O<F0G+`H@("`@)VQA)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+7-H87)E9"UL:6)R87)Y+6QA)RP*("`@("=L871E>"<@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UL871E>"<L"B`@("`G;&AA)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M;&AA)RP*("`@("=L:',G("`@("`@("`@("`]/B`G
M=&5X="]X+6QI=&5R871E+6AA<VME;&PG+`H@("`@)VQH>B<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+6QH>B<L"B`@("`G;&]G)R`@("`@("`@("`@
M/3X@)W1E>'0O>"UL;V<G+`H@("`@)VQT>"<@("`@("`@("`@(#T^("=T97AT
M+W@M=&5X)RP*("`@("=L=V\G("`@("`@("`@("`]/B`G:6UA9V4O>"UL=V\G
M+`H@("`@)VQW;V(G("`@("`@("`@(#T^("=I;6%G92]X+6QW;R<L"B`@("`G
M;'=S)R`@("`@("`@("`@/3X@)VEM86=E+W@M;'=S)RP*("`@("=L>7@G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UL>7@G+`H@("`@)VQZ:"<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6QH82<L"B`@("`G;'IO)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;'IO<"<L"B`@("`G;2<@("`@("`@
M("`@("`@/3X@)W1E>'0O>"UO8FIC<W)C)RP*("`@("=M,34G("`@("`@("`@
M("`]/B`G875D:6\O>"UM;V0G+`H@("`@)VTS=2<@("`@("`@("`@(#T^("=A
M=61I;R]X+6UP96=U<FPG+`H@("`@)VTT82<@("`@("`@("`@(#T^("=A=61I
M;R]X+6TT82<L"B`@("`G;31U)R`@("`@("`@("`@/3X@)W9I9&5O+W9N9"YM
M<&5G=7)L)RP*("`@("=M86XG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UT<F]F9BUM86XG+`H@("`@)VUA=&AM;"<@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]M871H;6PK>&UL)RP*("`@("=M9"<@("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UG96YE<VES+7)O;2<L"B`@("`G;64G("`@("`@("`@("`@
M/3X@)W1E>'0O>"UT<F]F9BUM92<L"B`@("`G;65S:"<@("`@("`@("`@/3X@
M)VUO9&5L+VUE<V@G+`H@("`@)VUG<"<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+6UA9VEC<&]I;G0G+`H@("`@)VUI9"<@("`@("`@("`@(#T^("=A
M=61I;R]M:61I)RP*("`@("=M:61I)R`@("`@("`@("`]/B`G875D:6\O;6ED
M:2<L"B`@("`G;6EF)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;6EF
M)RP*("`@("=M:W8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UM871R
M;W-K82<L"B`@("`G;6TG("`@("`@("`@("`@/3X@)W1E>'0O>"UT<F]F9BUM
M;2<L"B`@("`G;6UL)R`@("`@("`@("`@/3X@)W1E>'0O;6%T:&UL)RP*("`@
M("=M;F<G("`@("`@("`@("`]/B`G=FED96\O>"UM;F<G+`H@("`@)VUO8R<@
M("`@("`@("`@(#T^("=T97AT+W@M;6]C)RP*("`@("=M;V0G("`@("`@("`@
M("`]/B`G875D:6\O>"UM;V0G+`H@("`@)VUO;W8G("`@("`@("`@(#T^("=V
M:61E;R]Q=6EC:W1I;64G+`H@("`@)VUO=B<@("`@("`@("`@(#T^("=V:61E
M;R]Q=6EC:W1I;64G+`H@("`@)VUO=FEE)R`@("`@("`@(#T^("=V:61E;R]X
M+7-G:2UM;W9I92<L"B`@("`G;7`R)R`@("`@("`@("`@/3X@)W9I9&5O+VUP
M96<G+`H@("`@)VUP,R<@("`@("`@("`@(#T^("=A=61I;R]M<&5G)RP*("`@
M("=M<&4G("`@("`@("`@("`]/B`G=FED96\O;7!E9R<L"B`@("`G;7!E9R<@
M("`@("`@("`@/3X@)W9I9&5O+VUP96<G+`H@("`@)VUP9R<@("`@("`@("`@
M(#T^("=V:61E;R]M<&5G)RP*("`@("=M<&=A)R`@("`@("`@("`]/B`G875D
M:6\O;7!E9R<L"B`@("`G;7,G("`@("`@("`@("`@/3X@)W1E>'0O>"UT<F]F
M9BUM<R<L"B`@("`G;7-H)R`@("`@("`@("`@/3X@)VUO9&5L+VUE<V@G+`H@
M("`@)VUS;V0G("`@("`@("`@(#T^("=I;6%G92]X+6US;V0G+`H@("`@)VUS
M>"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6US>"UR;VTG+`H@("`@
M)VUT;2<@("`@("`@("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G;7AU)R`@
M("`@("`@("`@/3X@)W9I9&5O+W9N9"YM<&5G=7)L)RP*("`@("=N-C0G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UN-C0M<F]M)RP*("`@("=N8B<@
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO;6%T:&5M871I8V$G+`H@("`@
M)VYC)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6YE=&-D9B<L"B`@
M("`G;F5S)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;F5S+7)O;2<L
M"B`@("`G;G-V)R`@("`@("`@("`@/3X@)W9I9&5O+W@M;G-V)RP*("`@("=O
M)R`@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UO8FIE8W0G+`H@("`@
M)V]B:B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71G:68G+`H@("`@
M)V]D82<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]O9&$G+`H@("`@)V]D
M8B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O
M8W5M96YT+F1A=&%B87-E)RP*("`@("=O9&,G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YC:&%R="<L"B`@("`G
M;V1F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N
M9&]C=6UE;G0N9F]R;75L82<L"B`@("`G;V1G)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N9W)A<&AI8W,G+`H@
M("`@)V]D:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N
M;W!E;F1O8W5M96YT+FEM86=E)RP*("`@("=O9&TG("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YT97AT+6UA<W1E
M<B<L"B`@("`G;V1P)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO
M87-I<RYO<&5N9&]C=6UE;G0N<')E<V5N=&%T:6]N)RP*("`@("=O9',G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N
M="YS<')E861S:&5E="<L"B`@("`G;V1T)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N=&5X="<L"B`@("`G;V=G
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+V]G9R<L"B`@("`G;VQD)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=')A<V@G+`H@("`@)V]L96\G
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6]L96\G+`H@("`@)V]O="<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M
M96YT+G1E>'0G+`H@("`@)V]T9R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+F=R87!H:6-S+71E;7!L871E)RP*
M("`@("=O=&@G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES
M+F]P96YD;V-U;65N="YT97AT+7=E8B<L"B`@("`G;W1P)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N<')E<V5N
M=&%T:6]N+71E;7!L871E)RP*("`@("=O=',G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YS<')E861S:&5E="UT
M96UP;&%T92<L"B`@("`G;W1T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N=&5X="UT96UP;&%T92<L"B`@("`G
M<"<@("`@("`@("`@("`@/3X@)W1E>'0O>"UP87-C86PG+`H@("`@)W`Q,B<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!K8W,Q,B<L"B`@("`G<#=S
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W!K8W,W+7-I9VYA='5R92<L
M"B`@("`G<&%R,B<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&%R,B<L
M"B`@("`G<&%S)R`@("`@("`@("`@/3X@)W1E>'0O>"UP87-C86PG+`H@("`@
M)W!A=&-H)R`@("`@("`@(#T^("=T97AT+W@M<&%T8V@G+`H@("`@)W!B;2<@
M("`@("`@("`@(#T^("=I;6%G92]X+7!O<G1A8FQE+6)I=&UA<"<L"B`@("`G
M<&-D)R`@("`@("`@("`@/3X@)VEM86=E+W@M<&AO=&\M8V0G+`H@("`@)W!C
M9B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M<&-F)RP*("`@
M("=P8V8N6B<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UF;VYT+71Y<&4Q
M)RP*("`@("=P8VPG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FAP
M+7!C;"<L"B`@("`G<&1B)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N
M9"YP86QM)RP*("`@("=P9&8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M<&1F)RP*("`@("=P96TG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UX
M-3`Y+6-A+6-E<G0G+`H@("`@)W!E<FPG("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+7!E<FPG+`H@("`@)W!F82<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+69O;G0M='EP93$G+`H@("`@)W!F8B<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+69O;G0M='EP93$G+`H@("`@)W!F>"<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+7!K8W,Q,B<L"B`@("`G<&=M)R`@("`@("`@
M("`@/3X@)VEM86=E+W@M<&]R=&%B;&4M9W)A>6UA<"<L"B`@("`G<&=N)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M8VAE<W,M<&=N)RP*("`@("=P
M9W`G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO<&=P)RP*("`@("=P:'`G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP:'`G+`H@("`@)W!H<#,G
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!H<"<L"B`@("`G<&AP-"<@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&AP)RP*("`@("=P:6-T)R`@
M("`@("`@("`]/B`G:6UA9V4O>"UP:6-T)RP*("`@("=P:6-T,2<@("`@("`@
M("`]/B`G:6UA9V4O>"UP:6-T)RP*("`@("=P:6-T,B<@("`@("`@("`]/B`G
M:6UA9V4O>"UP:6-T)RP*("`@("=P;"<@("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UP97)L)RP*("`@("=P;',G("`@("`@("`@("`]/B`G875D:6\O
M>"US8W!L<R<L"B`@("`G<&TG("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M<&5R;"<L"B`@("`G<&YG)R`@("`@("`@("`@/3X@)VEM86=E+W!N9R<L
M"B`@("`G<&YM)R`@("`@("`@("`@/3X@)VEM86=E+W@M<&]R=&%B;&4M86YY
M;6%P)RP*("`@("=P;R<@("`@("`@("`@("`]/B`G=&5X="]X+6=E='1E>'0M
M=')A;G-L871I;VXG+`H@("`@)W!O="<@("`@("`@("`@(#T^("=T97AT+W@M
M9V5T=&5X="UT<F%N<VQA=&EO;BUT96UP;&%T92<L"B`@("`G<'!M)R`@("`@
M("`@("`@/3X@)VEM86=E+W@M<&]R=&%B;&4M<&EX;6%P)RP*("`@("=P<',G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+7!O=V5R<&]I;G0G
M+`H@("`@)W!P="<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;7,M
M<&]W97)P;VEN="<L"B`@("`G<'!Z)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YM<RUP;W=E<G!O:6YT)RP*("`@("=P<R<@("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO<&]S='-C<FEP="<L"B`@("`G<',N9WHG("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M9WIP;W-T<V-R:7!T)RP*("`@("=P<V0G
M("`@("`@("`@("`]/B`G:6UA9V4O>"UP<V0G+`H@("`@)W!S9B<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M;&EN=7@M<'-F)RP*("`@("=P
M<VED)R`@("`@("`@("`]/B`G875D:6\O<')S+G-I9"<L"B`@("`G<'<G("`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<'<G+`H@("`@)W!Y)R`@("`@
M("`@("`@(#T^("=T97AT+W@M<'ET:&]N)RP*("`@("=P>6,G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UP>71H;VXM8GET96-O9&4G+`H@("`@)W!Y
M;R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!Y=&AO;BUB>71E8V]D
M92<L"B`@("`G<6EF)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<7<G
M+`H@("`@)W%T)R`@("`@("`@("`@(#T^("=V:61E;R]Q=6EC:W1I;64G+`H@
M("`@)W%T=G(G("`@("`@("`@(#T^("=V:61E;R]Q=6EC:W1I;64G+`H@("`@
M)W)A)R`@("`@("`@("`@(#T^("=A=61I;R]X+7!N+7)E86QA=61I;R<L"B`@
M("`G<F%M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M<&XM<F5A;&%U9&EO)RP*
M("`@("=R87(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UR87(G+`H@
M("`@)W)A<R<@("`@("`@("`@(#T^("=I;6%G92]X+6-M=2UR87-T97(G+`H@
M("`@)W)D9B<@("`@("`@("`@(#T^("=T97AT+W)D9B<L"B`@("`G<F5J)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<F5J96-T)RP*("`@("=R9V(G
M("`@("`@("`@("`]/B`G:6UA9V4O>"UR9V(G+`H@("`@)W)L92<@("`@("`@
M("`@(#T^("=I;6%G92]R;&4G+`H@("`@)W)M)R`@("`@("`@("`@(#T^("=A
M=61I;R]X+7!N+7)E86QA=61I;R<L"B`@("`G<F]F9B<@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M=')O9F8G+`H@("`@)W)P;2<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+7)P;2<L"B`@("`G<G-S)R`@("`@("`@("`@/3X@
M)W1E>'0O<G-S)RP*("`@("=R=&8G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO<G1F)RP*("`@("=R='@G("`@("`@("`@("`]/B`G=&5X="]R:6-H=&5X
M="<L"B`@("`G<S-M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M<S-M)RP*("`@
M("=S86TG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UA;6EP<F\G+`H@
M("`@)W-C;2<@("`@("`@("`@(#T^("=T97AT+W@M<V-H96UE)RP*("`@("=S
M9&$G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO
M;BYD<F%W)RP*("`@("=S9&,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M=FYD+G-T87)D:79I<VEO;BYC86QC)RP*("`@("=S9&0G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYI;7!R97-S)RP*("`@
M("=S9'`G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I
M<VEO;BYI;7!R97-S)RP*("`@("=S9',G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+G-T87)D:79I<VEO;BYC:&%R="<L"B`@("`G<V1W)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN=W)I=&5R
M)RP*("`@("=S9VDG("`@("`@("`@("`]/B`G:6UA9V4O>"US9VDG+`H@("`@
M)W-G;"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES
M:6]N+G=R:71E<B<L"B`@("`G<V=M)R`@("`@("`@("`@/3X@)W1E>'0O<V=M
M;"<L"B`@("`G<V=M;"<@("`@("`@("`@/3X@)W1E>'0O<V=M;"<L"B`@("`G
M<V@G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VAE;&QS8W)I<'0G
M+`H@("`@)W-H87(G("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7-H87(G
M+`H@("`@)W-H=&UL)R`@("`@("`@(#T^("=T97AT+VAT;6PG+`H@("`@)W-I
M86<G("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7-I86<G+`H@("`@)W-I
M9"<@("`@("`@("`@(#T^("=A=61I;R]P<G,N<VED)RP*("`@("=S:6LG("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT<F%S:"<L"B`@("`G<VEL;R<@
M("`@("`@("`@/3X@)VUO9&5L+VUE<V@G+`H@("`@)W-I="<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]S='5F9FET)RP*("`@("=S:V0G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UK;V%N)RP*("`@("=S:VTG("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UK;V%N)RP*("`@("=S:W`G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UK;V%N)RP*("`@("=S:W0G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UK;V%N)RP*("`@("=S;&LG("`@("`@("`@
M("`]/B`G=&5X="]S<')E861S:&5E="<L"B`@("`G<VUD)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN;6%I;"<L"B`@("`G
M<VUF)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I
M;VXN;6%T:"<L"B`@("`G<VUI)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W-M:6PG+`H@("`@)W-M:6PG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]S
M;6EL)RP*("`@("=S;6PG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO<VUI
M;"<L"B`@("`G<VUS)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VUS
M+7)O;2<L"B`@("`G<VYD)R`@("`@("`@("`@/3X@)V%U9&EO+V)A<VEC)RP*
M("`@("=S;R<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"US:&%R961L
M:6(G+`H@("`@)W-P9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+69O
M;G0M<W!E961O)RP*("`@("=S<&PG("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UF=71U<F5S<&QA<V@G+`H@("`@)W-Q;"<@("`@("`@("`@(#T^("=T
M97AT+W@M<W%L)RP*("`@("=S<F,G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UW86ES+7-O=7)C92<L"B`@("`G<W1C)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F-A;&,N=&5M<&QA=&4G+`H@("`@)W-T
M9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YD<F%W
M+G1E;7!L871E)RP*("`@("=S=&DG("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO=FYD+G-U;BYX;6PN:6UP<F5S<RYT96UP;&%T92<L"B`@("`G<W1M)R`@
M("`@("`@("`@/3X@)V%U9&EO+W@M<W1M)RP*("`@("=S='<G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN=W)I=&5R+G1E;7!L871E
M)RP*("`@("=S='DG("`@("`@("`@("`]/B`G=&5X="]X+71E>"<L"B`@("`G
M<W5N)R`@("`@("`@("`@/3X@)VEM86=E+W@M<W5N+7)A<W1E<B<L"B`@("`G
M<W8T8W!I;R<@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<W8T8W!I;R<L"B`@
M("`G<W8T8W)C)R`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<W8T8W)C)RP*
M("`@("=S=F<G("`@("`@("`@("`]/B`G:6UA9V4O<W9G*WAM;"<L"B`@("`G
M<W=F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VAO8VMW879E+69L
M87-H)RP*("`@("=S>&,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+G-U;BYX;6PN8V%L8R<L"B`@("`G<WAD)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W9N9"YS=6XN>&UL+F1R87<G+`H@("`@)W-X9R<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET97(N9VQO8F%L)RP*
M("`@("=S>&DG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-U;BYX
M;6PN:6UP<F5S<R<L"B`@("`G<WAM)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YS=6XN>&UL+FUA=&@G+`H@("`@)W-X=R<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET97(G+`H@("`@)W-Y;&LG
M("`@("`@("`@(#T^("=T97AT+W-P<F5A9'-H965T)RP*("`@("=T)R`@("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT<F]F9B<L"B`@("`G=&%R)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=&%R)RP*("`@("=T87(N6B<@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT87)Z)RP*("`@("=T87(N8GHG
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UB>FEP+6-O;7!R97-S960M=&%R
M)RP*("`@("=T87(N8GHR)R`@("`@("`]/B`G87!P;&EC871I;VXO>"UB>FEP
M+6-O;7!R97-S960M=&%R)RP*("`@("=T87(N9WHG("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UC;VUP<F5S<V5D+71A<B<L"B`@("`G=&%R+FQZ;R<@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M='IO)RP*("`@("=T8VPG("`@("`@("`@
M("`]/B`G=&5X="]X+71C;"<L"B`@("`G=&5X)R`@("`@("`@("`@/3X@)W1E
M>'0O>"UT97@G+`H@("`@)W1E>&DG("`@("`@("`@(#T^("=T97AT+W@M=&5X
M:6YF;R<L"B`@("`G=&5X:6YF;R<@("`@("`@/3X@)W1E>'0O>"UT97AI;F9O
M)RP*("`@("=T9V$G("`@("`@("`@("`]/B`G:6UA9V4O>"UT9V$G+`H@("`@
M)W1G>B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6-O;7!R97-S960M
M=&%R)RP*("`@("=T:&5M92<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT
M:&5M92<L"B`@("`G=&EF)R`@("`@("`@("`@/3X@)VEM86=E+W1I9F8G+`H@
M("`@)W1I9F8G("`@("`@("`@(#T^("=I;6%G92]T:69F)RP*("`@("=T:R<@
M("`@("`@("`@("`]/B`G=&5X="]X+71C;"<L"B`@("`G=&]R<F5N="<@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M8FET=&]R<F5N="<L"B`@("`G='(G("`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=')O9F8G+`H@("`@)W1S)R`@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6QI;F=U:7-T)RP*("`@("=T
M<W8G("`@("`@("`@("`]/B`G=&5X="]T86(M<V5P87)A=&5D+79A;'5E<R<L
M"B`@("`G='1F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UT
M=&8G+`H@("`@)W1X="<@("`@("`@("`@(#T^("=T97AT+W!L86EN)RP*("`@
M("=T>F\G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT>F\G+`H@("`@
M)W5I)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61E<VEG;F5R)RP*
M("`@("=U:6PG("`@("`@("`@("`]/B`G=&5X="]X+75I;"<L"B`@("`G=6QT
M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M;6]D)RP*("`@("=U;FDG("`@("`@
M("`@("`]/B`G875D:6\O>"UM;V0G+`H@("`@)W5R:2<@("`@("`@("`@(#T^
M("=T97AT+W@M=7)I)RP*("`@("=U<FPG("`@("`@("`@("`]/B`G=&5X="]X
M+75R:2<L"B`@("`G=7-T87(G("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M=7-T87(G+`H@("`@)W9C9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+6-D;&EN:R<L"B`@("`G=F-F)R`@("`@("`@("`@/3X@)W1E>'0O9&ER96-T
M;W)Y)RP*("`@("=V8W,G("`@("`@("`@("`]/B`G=&5X="]C86QE;F1A<B<L
M"B`@("`G=F-T)R`@("`@("`@("`@/3X@)W1E>'0O9&ER96-T;W)Y)RP*("`@
M("=V9F(G("`@("`@("`@("`]/B`G=&5X="]C86QE;F1A<B<L"B`@("`G=F]B
M)R`@("`@("`@("`@/3X@)W9I9&5O+VUP96<G+`H@("`@)W9O8R<@("`@("`@
M("`@(#T^("=A=61I;R]X+79O8R<L"B`@("`G=F]R)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN=W)I=&5R)RP*("`@("=V
M<FUL)R`@("`@("`@("`]/B`G;6]D96PO=G)M;"<L"B`@("`G=G-D)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YV:7-I;R<L"B`@("`G=GAM;"<@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9O:6-E>&UL*WAM;"<L"B`@("`G
M=V%V)R`@("`@("`@("`@/3X@)V%U9&EO+W@M=V%V)RP*("`@("=W87@G("`@
M("`@("`@("`]/B`G875D:6\O>"UM<RUW87@G+`H@("`@)W=B,2<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+7%U871T<F]P<F\G+`H@("`@)W=B,B<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7%U871T<F]P<F\G+`H@("`@
M)W=B,R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7%U871T<F]P<F\G
M+`H@("`@)W=B;7`G("`@("`@("`@(#T^("=I;6%G92]V;F0N=V%P+G=B;7`G
M+`H@("`@)W=B>&UL)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N=V%P
M+G=B>&UL)RP*("`@("=W:S$G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M=FYD+FQO='5S+3$M,BTS)RP*("`@("=W:S,G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+FQO='5S+3$M,BTS)RP*("`@("=W:S0G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO=FYD+FQO='5S+3$M,BTS)RP*("`@("=W:W,G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FQO='5S+3$M,BTS)RP*
M("`@("=W;2<@("`@("`@("`@("`]/B`G=FED96\O>"UM<RUW;2<L"B`@("`G
M=VUA)R`@("`@("`@("`@/3X@)V%U9&EO+W@M;7,M=VUA)RP*("`@("=W;60G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UM<RUW;60G+`H@("`@)W=M
M9B<@("`@("`@("`@(#T^("=I;6%G92]X+7=M9B<L"B`@("`G=VUL)R`@("`@
M("`@("`@/3X@)W1E>'0O=FYD+G=A<"YW;6PG+`H@("`@)W=M;&,G("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N=V%P+G=M;&,G+`H@("`@)W=M;',G
M("`@("`@("`@(#T^("=T97AT+W9N9"YW87`N=VUL<V-R:7!T)RP*("`@("=W
M;6QS8R<@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G=A<"YW;6QS8W)I
M<'1C)RP*("`@("=W;78G("`@("`@("`@("`]/B`G=FED96\O>"UM<RUW;78G
M+`H@("`@)W=M>"<@("`@("`@("`@(#T^("=V:61E;R]X+6US+7=M>"<L"B`@
M("`G=VUZ)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;7,M=VUZ)RP*
M("`@("=W<&0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G=O<F1P
M97)F96-T)RP*("`@("=W<&<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UW<&<G+`H@("`@)W=R:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+6US=W)I=&4G+`H@("`@)W=R;"<@("`@("`@("`@(#T^("=M;V1E;"]V<FUL
M)RP*("`@("=W=G@G("`@("`@("`@("`]/B`G=FED96\O>"UM<RUW=G@G+`H@
M("`@)WAA8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=N=6-A<V@G
M+`H@("`@)WAB96PG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7AB96PG
M+`H@("`@)WAB;2<@("`@("`@("`@(#T^("=I;6%G92]X+7AB:71M87`G+`H@
M("`@)WAC9B<@("`@("`@("`@(#T^("=I;6%G92]X+7AC9B<L"B`@("`G>&-F
M+F)Z,B<@("`@("`@/3X@)VEM86=E+W@M8V]M<')E<W-E9"UX8V8G+`H@("`@
M)WAC9BYG>B<@("`@("`@(#T^("=I;6%G92]X+6-O;7!R97-S960M>&-F)RP*
M("`@("=X:'0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>&AT;6PK>&UL
M)RP*("`@("=X:'1M;"<@("`@("`@("`]/B`G87!P;&EC871I;VXO>&AT;6PK
M>&UL)RP*("`@("=X:2<@("`@("`@("`@("`]/B`G875D:6\O>"UX:2<L"B`@
M("`G>&QA)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E
M;"<L"B`@("`G>&QC)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM
M<RUE>&-E;"<L"B`@("`G>&QD)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W9N9"YM<RUE>&-E;"<L"B`@("`G>&QL)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G>&QM)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G>&QS)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G>&QT)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G
M>&QW)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L
M"B`@("`G>&TG("`@("`@("`@("`@/3X@)V%U9&EO+W@M>&TG+`H@("`@)WAM
M:2<@("`@("`@("`@(#T^("=T97AT+W@M>&UI)RP*("`@("=X;6PG("`@("`@
M("`@("`]/B`G=&5X="]X;6PG+`H@("`@)WAP;2<@("`@("`@("`@(#T^("=I
M;6%G92]X+7AP:7AM87`G+`H@("`@)WAS;"<@("`@("`@("`@(#T^("=T97AT
M+W@M>'-L="<L"B`@("`G>'-L9F\G("`@("`@("`@/3X@)W1E>'0O>"UX<VQF
M;R<L"B`@("`G>'-L="<@("`@("`@("`@/3X@)W1E>'0O>"UX<VQT)RP*("`@
M("=X=6PG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUO>FEL;&$N
M>'5L*WAM;"<L"B`@("`G>'=D)R`@("`@("`@("`@/3X@)VEM86=E+W@M>'=I
M;F1O=V1U;7`G+`H@("`@)WAY>B<@("`@("`@("`@(#T^("=C:&5M:6-A;"]X
M+7AY>B<L"B`@("`G>F%B=R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M86)I=V]R9"<L"B`@("`G>FEP)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+WII<"<L"B`@("`G>F]O)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M>F]O)RP*("`@("<Q,C,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+FQO='5S+3$M,BTS)RP*("`@("<V-CDG("`@("`@("`@("`]/B`G875D:6\O
M>"UM;V0G"BD[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O2&ES=&]R>2YP:'``````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V-#(W`#$P-#$W,S8R-S<S`#`R,#0Q
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&AE($AI<W1O<GDZ.B!C;&%S<R!P<F]V:61E<R!A(&UE
M=&AO9"!O9B!T<F%C:VEN9R!C:&%N9V5S(&EN($AO<F1E"B`J(&]B:F5C=',L
M('-T;W)E9"!I;B!A(%-13"!T86)L92X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO2&ES=&]R>2](:7-T;W)Y+G!H<"QV(#$N,C@N,BXQ,B`R,#`V+S`S+S`S
M(#(S.C`P.C(X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO
M<F1E7TAI<W1O<GD*("HO"F-L87-S($AO<F1E7TAI<W1O<GD@>PH*("`@("\J
M*@H@("`@("H@4&]I;G1E<B!T;R!A($1"(&EN<W1A;F-E('1O(&UA;F%G92!T
M:&4@:&ES=&]R>2X*("`@("`J"B`@("`@*B!`=F%R($1""B`@("`@*B\*("`@
M('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@2&ES=&]R>2!I;G-T86YC92X*
M("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@
M;F\@2&ES=&]R>2!I;G-T86YC90H@("`@("H@8W5R<F5N=&QY(&5X:7-T<RX*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z
M("1V87(@/2`F2&ES=&]R>3HZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`
M<F5T=7)N($AO<F1E7TAI<W1O<GD@(%1H92!C;VYC<F5T92!(:7-T;W)Y(')E
M9F5R96YC92P@;W(@9F%L<V4@;VX@86X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T
M;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D:&ES=&]R>3L*"B`@("`@("`@
M:68@*"%I<W-E="@D:&ES=&]R>2DI('L*("`@("`@("`@("`@)&AI<W1O<GD@
M/2`F;F5W($AO<F1E7TAI<W1O<GDH*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:&ES=&]R>3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95](:7-T;W)Y*"D*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("AE;7!T>2@D
M8V]N9ELG<W%L)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2!014%2
M.CIR86ES945R<F]R*%\H(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE
M9"XB*2D["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)T1"+G!H
M<"<["B`@("`@("`@)'1H:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D8V]N9ELG
M<W%L)UTI.PH*("`@("`@("`O*B!3970@1$(@<&]R=&%B:6QI='D@;W!T:6]N
M<RX@*B\*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G1$)?8V]M;6]N
M)RDI('L*("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YP:'!T>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)4
M04))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$
M0E]03U)404))3$E465]25%))32D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],
M3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]G<R!A;B!E
M=F5N="!T;R!A;B!I=&5M)W,@:&ES=&]R>2!L;V<N(%1H92!I=&5M(&UU<W0@
M8F4@=6YI<75E;'D*("`@("`J(&ED96YT:69I960@8GD@)&=U:60N($%N>2!O
M=&AE<B!D971A:6QS(&%B;W5T('1H92!E=F5N="!A<F4@<&%S<V5D(&EN"B`@
M("`@*B`D871T<FEB=71E<RX@4W1A;F1A<F0@<W5G9V5S=&5D(&%T=')I8G5T
M97,@87)E.@H@("`@("H*("`@("`J("`@)W=H;R<@/3X@5&AE(&ED(&]F('1H
M92!U<V5R('1H870@<&5R9F]R;65D('1H92!A8W1I;VX@*'=I;&P@8F4@861D
M960*("`@("`J("`@("`@("`@("`@875T;VUA=&EC86QL>2!I9B!N;W0@<')E
M<V5N="DN"B`@("`@*@H@("`@("H@("`G=',G(#T^(%1I;65S=&%M<"!O9B!T
M:&4@86-T:6]N("AT:&ES('=I;&P@8F4@861D960@875T;VUA=&EC86QL>2!I
M9@H@("`@("H@("`@("`@("`@(&ET(&ES(&YO="!P<F5S96YT*2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1G=6ED("`@("`@("`@("`@5&AE('5N
M:7%U92!I9&5N=&EF:65R(&]F('1H92!E;G1R>2!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%D9"!T;RX*("`@("`J($!P87)A
M;2!A<G)A>2`D871T<FEB=71E<R`@("`@("!4:&4@:&%S:"!O9B!N86UE(#T^
M('9A;'5E(&5N=')I97,@=&AA=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&1E<V-R:6)E('1H:7,@979E;G0N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D<F5P;&%C94%C=&EO;B`@268@)&%T=')I8G5T97-;)V%C
M=&EO;B==(&ES(&%L<F5A9'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!P<F5S96YT(&EN('1H92!I=&5M)W,@:&ES=&]R>2!L;V<L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=7!D871E
M('1H870@96YT<GD@:6YS=&5A9"!O9B!C<F5A=&EN9R!A"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;F5W(&]N92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C
M97-S+"!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QO9R@D9W5I9"P@)&%T=')I8G5T97,@/2!A<G)A>2@I+"`D<F5P;&%C
M94%C=&EO;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1T:&ES
M+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&(["B`@("`@("`@?0H*("`@("`@("`D:&ES=&]R>2`]("8D=&AI
M<RT^9V5T2&ES=&]R>2@D9W5I9"D["B`@("`@("`@:68@*"$D:&ES=&]R>2!\
M?"!I<U]A*"1H:7-T;W)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D:&ES=&]R>3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T
M>2@D871T<FEB=71E<ULG=VAO)UTI*2!["B`@("`@("`@("`@("1A='1R:6)U
M=&5S6R=W:&\G72`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1A='1R:6)U=&5S6R=T<R==*2D@>PH@("`@("`@("`@
M("`D871T<FEB=71E<ULG=',G72`]('1I;64H*3L*("`@("`@("!]"@H@("`@
M("`@("\J($EF('=E('=A;G0@=&\@<F5P;&%C92!A;B!E;G1R>2!W:71H('1H
M92!S86UE(&%C=&EO;BP@=')Y(&%N9"!F:6YD"B`@("`@("`@("H@;VYE+B!4
M<F%C:R!W:&5T:&5R(&]R(&YO="!W92!S=6-C965D(&EN("1D;VYE+"!S;R!W
M92!K;F]W('=H971H97(*("`@("`@("`@*B!O<B!N;W0@=&\@861D('1H92!E
M;G1R>2!L871E<BX@*B\*("`@("`@("`D9&]N92`](&9A;'-E.PH@("`@("`@
M(&EF("@D<F5P;&%C94%C=&EO;B`F)B`A96UP='DH)&%T=')I8G5T97-;)V%C
M=&EO;B==*2D@>PH@("`@("`@("`@("`D8V]U;G0@/2!C;W5N="@D:&ES=&]R
M>2T^9&%T82D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N
M=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:&ES=&]R
M>2T^9&%T85LD:5U;)V%C=&EO;B==*2`F)@H@("`@("`@("`@("`@("`@("`@
M("1H:7-T;W)Y+3YD871A6R1I75LG86-T:6]N)UT@/3T@)&%T=')I8G5T97-;
M)V%C=&EO;B==*2!["@H@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!A
M<G)A>2@D871T<FEB=71E<ULG=',G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)W=H;R==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D871T<FEB=71E<ULG
M9&5S8R==*2`_("1A='1R:6)U=&5S6R=D97-C)UT@.B!N=6QL*3L*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D871T<FEB=71E<ULG=',G72D["B`@("`@
M("`@("`@("`@("`@("`@=6YS970H)&%T=')I8G5T97-;)W=H;R==*3L*("`@
M("`@("`@("`@("`@("`@("!U;G-E="@D871T<FEB=71E<ULG9&5S8R==*3L*
M("`@("`@("`@("`@("`@("`@("!U;G-E="@D871T<FEB=71E<ULG86-T:6]N
M)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF("@D871T<FEB=71E<RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2!S97)I86QI>F4H
M)&%T=')I8G5T97,I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1V86QU97-;72`](&YU;&P["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1V86QU97-;
M72`]("1H:7-T;W)Y+3YD871A6R1I75LG:60G73L*"B`@("`@("`@("`@("`@
M("`@("`@)'(@/2`D=&AI<RT^7V1B+3YQ=65R>2@G55!$051%(&AO<F1E7VAI
M<W1O<FEE<R!3150@:&ES=&]R>5]T<R`](#\L)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R!H:7-T;W)Y7W=H;R`](#\L)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!H:7-T
M;W)Y7V1E<V,@/2`_+"<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<@:&ES=&]R>5]E>'1R82`](#\@5TA%4D4@:&ES=&]R>5]I
M9"`](#\G+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("1D;VYE(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@268@=V4G<F4@;F]T(')E<&QA8VEN9R!B>2!A8W1I
M;VXL(&]R(&EF('=E(&1I9&XG="!F:6YD(&%N(&5N=')Y('1O"B`@("`@("`@
M("H@<F5P;&%C92P@:6YS97)T(&$@;F5W(')O=RX@*B\*("`@("`@("!I9B`H
M(21D;VYE*2!["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^
M7V1B+3YN97AT260H)VAO<F1E7VAI<W1O<FEE<R<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&=U:60L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D871T<FEB=71E<ULG=',G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1A='1R:6)U=&5S6R=W:&\G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&ES<V5T*"1A='1R:6)U=&5S6R=D97-C)UTI(#\@)&%T=')I
M8G5T97-;)V1E<V,G72`Z(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I<W-E="@D871T<FEB=71E<ULG86-T:6]N)UTI(#\@)&%T=')I8G5T
M97-;)V%C=&EO;B==(#H@;G5L;"D["B`@("`@("`@("`@('5N<V5T*"1A='1R
M:6)U=&5S6R=T<R==*3L*("`@("`@("`@("`@=6YS970H)&%T=')I8G5T97-;
M)W=H;R==*3L*("`@("`@("`@("`@=6YS970H)&%T=')I8G5T97-;)V1E<V,G
M72D["B`@("`@("`@("`@('5N<V5T*"1A='1R:6)U=&5S6R=A8W1I;VXG72D[
M"B`@("`@("`@("`@(&EF("@D871T<FEB=71E<RD@>PH@("`@("`@("`@("`@
M("`@)'9A;'5E<UM=(#T@<V5R:6%L:7IE*"1A='1R:6)U=&5S*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1V86QU97-;72`](&YU
M;&P["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D
M8BT^<75E<GDH)TE.4T525"!)3E1/(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R
M>5]I9"P@;V)J96-T7W5I9"P@:&ES=&]R>5]T<RP@:&ES=&]R>5]W:&\L(&AI
M<W1O<GE?9&5S8RP@:&ES=&]R>5]A8W1I;VXL(&AI<W1O<GE?97AT<F$I)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@5D%,5453("@_+"`_
M+"`_+"`_+"`_+"`_+"`_*2<L("1V86QU97,I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!(:7-T
M;W)Y3V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&YA;65D(&AI<W1O<GD*
M("`@("`J(&5N=')Y+"!W:71H('1H92!D871A(')E=')I979E9"!A<'!R;W!R
M:6%T96QY+B`D875T;V-R96%T92!H87,*("`@("`J(&YO(&%F9F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G=6ED("`@("`@("`@5&AE(&YA
M;64@;V8@=&AE(&AI<W1O<GD@96YT<GD@=&\@<F5T<FEE=F4N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@1&5P<F5C871E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F=E=$AI<W1O<GDH)&=U:60L("1A=71O8W)E871E
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1F86QS92`](&9A;'-E.PH@
M("`@("`@("`@("!R971U<FX@)&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)')O=W,@/2`D=&AI<RT^7V1B+3YG971!;&PH)U-%3$5#5"`J($923TT@:&]R
M9&5?:&ES=&]R:65S(%=(15)%(&]B:F5C=%]U:60@/2`_)RP@87)R87DH)&=U
M:60I+"!$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@("1H:7-T;W)Y(#T@
M)FYE=R!(:7-T;W)Y3V)J96-T*"1G=6ED+"`D<F]W<RD["B`@("`@("`@<F5T
M=7)N("1H:7-T;W)Y.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9',@:&ES
M=&]R>2!O8FIE8W1S(&)Y('1I;65S=&%M<"P@86YD(&]P=&EO;F%L;'D@9FEL
M=&5R(&]N(&]T:&5R"B`@("`@*B!F:65L9',@87,@=V5L;"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;7`@("`@(%1H92!C;VUP87)I<V]N(&]P
M97)A=&]R("@\+"`^+"`\/2P@/CTL(&]R(#TI('1O"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&-H96-K('1H92!T:6UE<W1A;7!S('=I=&@N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D=',@("`@(%1H92!T:6UE<W1A;7`@=&\@
M8V]M<&%R92!A9V%I;G-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:6QT97)S
M("!!;B!A<G)A>2!O9B!A9&1I=&EO;F%L("A!3D1E9"D@8W)I=&5R:6$N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@($5A8V@@87)R87D@=F%L=64@
M<VAO=6QD(&)E(&%N(&%R<F%Y('=I=&@@,PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!E;G1R:65S.@H@("`@("H@/'!R93X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("=O<"<@("`@+2!T:&4@;W!E<F%T;W(@=&\@
M8V]M<&%R92!T:&ES(&9I96QD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=VET:"X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("=F:65L9"<@+2!T:&4@:&ES=&]R>2!F:65L9"!B96EN9R!C;VUP
M87)E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("AI+F4N("=A8W1I;VXG*2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("=V86QU92<@+2!T:&4@=F%L=64@=&\@8VAE8VL@9F]R("AI+F4N("=A
M9&0G*2X*("`@("`J(#PO<')E/@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R
M96YT("!4:&4@<&%R96YT(&AI<W1O<GD@=&\@<W1A<G0@<V5A<F-H:6YG(&%T
M+B!)9B!N;VXM96UP='DL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M('=I;&P@8F4@<V5A<F-H960@9F]R('=I=&@@82!,24M%("<D<&%R96YT.B4G
M(&-L875S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A
M>2!O9B!H:7-T;W)Y(&]B:F5C="!I9',L(&]R(&%N(&5M<'1Y(&%R<F%Y(&EF
M"B`@("`@*B`@("`@("`@("`@("`@("!N;VYE(&UA=&-H960@=&AE(&-R:71E
M<FEA+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971">51I;65S=&%M<"@D8VUP
M+"`D=',L("1F:6QT97)S(#T@87)R87DH*2P@)'!A<F5N="`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O*B!"=6EL9"!T:&4@=&EM97-T86UP('1E<W0N("HO"B`@("`@("`@
M)'=H97)E(#T@87)R87DH(FAI<W1O<GE?=',@)&-M<"`D=',B*3L*"B`@("`@
M("`@+RH@061D(&%D9&ET:6]N86P@9FEL=&5R<RP@:68@=&AE<F4@87)E(&%N
M>2X@*B\*("`@("`@("!I9B`H)&9I;'1E<G,I('L*("`@("`@("`@("`@9F]R
M96%C:"`H)&9I;'1E<G,@87,@)&9I;'1E<BD@>PH@("`@("`@("`@("`@("`@
M)'=H97)E6UT@/2`G:&ES=&]R>5\G("X@)&9I;'1E<ELG9FEE;&0G72`N("<@
M)R`N("1F:6QT97);)V]P)UT@+B`G("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D
M9FEL=&5R6R=V86QU92==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*"1P87)E;G0I('L*("`@("`@("`@("`@)'=H97)E6UT@/2`G
M;V)J96-T7W5I9"!,24M%("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D<&%R96YT
M("X@)SHE)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]D
M8BT^9V5T07-S;V,H)U-%3$5#5"!$25-424Y#5"!O8FIE8W1?=6ED+"!H:7-T
M;W)Y7VED($923TT@:&]R9&5?:&ES=&]R:65S(%=(15)%("<@+B!I;7!L;V1E
M*"<@04Y$("<L("1W:&5R92DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@=&EM97-T86UP(&]F('1H92!M;W-T(')E8V5N="!C:&%N9V4@=&\@
M)&=U:60N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W5I9"`@("!4
M:&4@;F%M92!O9B!T:&4@:&ES=&]R>2!E;G1R>2!T;R!R971R:65V92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&%C=&EO;B`@06X@86-T:6]N.B`G861D)RP@
M)VUO9&EF>2<L("=D96QE=&4G+"!E=&,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@=&EM97-T86UP+"!O<B`P(&EF(&YO(&UA=&-H:6YG
M(&5N=')Y(&ES(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!8W1I
M;VY4:6UE<W1A;7`H)&=U:60L("1A8W1I;VXI"B`@("!["B`@("`@("`@+RH@
M5&AI<R!I;7!L96UE;G1A=&EO;B!S=&EL;"!W;W)K<RP@8G5T('=E('-H;W5L
M9"!B92!A8FQE('1O"B`@("`@("`@("H@9V5T(&UU8V@@9F%S=&5R(&YO=R!W
M:71H(&$@4T5,14-4($U!6"AH:7-T;W)Y7W1S*0H@("`@("`@("`J("XN+B!Q
M=65R>2X@*B\*("`@("`@("`D:&ES=&]R>2`]("8D=&AI<RT^9V5T2&ES=&]R
M>2@D9W5I9"D["B`@("`@("`@:68@*"$D:&ES=&]R>2!\?"!I<U]A*"1H:7-T
M;W)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@
M("`@("`@('T*"B`@("`@("`@)&QA<W0@/2`P.PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D:&ES=&]R>2T^9&%T82DI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)&AI<W1O<GDM/F1A=&$@87,@)&5N=')Y*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&5N=')Y6R=A8W1I;VXG72`]/2`D86-T:6]N("8F("1E;G1R>5LG=',G
M72`^("1L87-T*2!["B`@("`@("`@("`@("`@("`@("`@)&QA<W0@/2`D96YT
M<GE;)W1S)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;&%S=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;6]V92!O;F4@;W(@;6]R92!H:7-T;W)Y(&5N=')I97,@8GD@
M;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&YA;65S("!4:&4@
M:&ES=&]R>2!E;G1R:65S('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E0GE.86UE<R@D;F%M97,I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D:61S(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("@D;F%M97,@87,@)&YA;64I('L*("`@("`@
M("`@("`@)&ED<UM=(#T@)'1H:7,M/E]D8BT^<75O=&4H)&YA;64I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"=$14Q%
M5$4@1E)/32!H;W)D95]H:7-T;W)I97,@5TA%4D4@;V)J96-T7W5I9"!)3B`H
M)R`N(&EM<&QO9&4H)RPG+"`D:61S*2`N("<I)RD["B`@("!]"@I]"@HO*BH*
M("H@0VQA<W,@9F]R('!R97-E;G1I;F<@2&ES=&]R>2!I;F9O<FUA=&EO;BX*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95](
M:7-T;W)Y"B`J+PIC;&%S<R!(:7-T;W)Y3V)J96-T('L*"B`@("!V87(@)'5I
M9#L*("`@('9A<B`D9&%T82`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@2&ES
M=&]R>4]B:F5C="@D=6ED+"`D9&%T82`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@)'1H:7,M/G5I9"`]("1U:60["@H@("`@("`@(&EF("@A)&1A=&$@?'P@
M:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D<F]W
M*2!["B`@("`@("`@("`@("1H:7-T;W)Y(#T@87)R87DH)V%C=&EO;B<@/3X@
M)')O=ULG:&ES=&]R>5]A8W1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G9&5S8R<@/3X@)')O=ULG:&ES=&]R>5]D97-C)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W=H;R<@/3X@)')O=ULG:&ES=&]R
M>5]W:&\G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:60G(#T^
M("1R;W=;)VAI<W1O<GE?:60G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=',G(#T^("1R;W=;)VAI<W1O<GE?=',G72D["B`@("`@("`@("`@
M(&EF("@D<F]W6R=H:7-T;W)Y7V5X=')A)UTI('L*("`@("`@("`@("`@("`@
M("1E>'1R82`]($!U;G-E<FEA;&EZ92@D<F]W6R=H:7-T;W)Y7V5X=')A)UTI
M.PH@("`@("`@("`@("`@("`@:68@*"1E>'1R82D@>PH@("`@("`@("`@("`@
M("`@("`@("1H:7-T;W)Y(#T@87)R87E?;65R9V4H)&AI<W1O<GDL("1E>'1R
M82D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/F1A=&%;72`]("1H:7-T;W)Y.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!G971$871A*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/F1A=&$["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O0V]N9FEG+G!H<```````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,30S-C8R`#$P-#$W,S8R-S<S`#`R
M,#$V-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($-O;F9I9SHZ('!A8VMA9V4@<')O=FED97,@
M82!F<F%M97=O<FL@9F]R(&UA;F%G:6YG('1H90H@*B!C;VYF:6=U<F%T:6]N
M(&]F($AO<F1E(&%P<&QI8V%T:6]N<RP@=W)I=&EN9R!C;VYF+G!H<"!F:6QE
M<R!F<F]M"B`J(&-O;F8N>&UL('-O=7)C92!F:6QE<RP@9V5N97)A=&EN9R!U
M<V5R(&EN=&5R9F%C97,L(&5T8RX*("H*("H@5&AE($AO<F1E7T-O;F9I9U].
M;V1E($1/32!C;&%S<V5S(&%N9"!S=6)C;&%S<V5S"B`J("A(;W)D95]#;VYF
M:6=?1&]C=6UE;G0L($AO<F1E7T-O;F9I9U]%;&5M96YT*2!A<F4@<VEM<&QY
M(&UA<W-A9V5D"B`J(&9R;VT@8V]D92!W<FET=&5N(&)Y('1O(&5M=6QA=&4@
M4$A0-"=S($1/35A-3"!E>'1E;G-I;VX@=VET:"!02%`U)W,*("H@1$]-('-U
M<'!O<G0N($]N;'D@8VAA;F=E<R!A<F4@;F%M:6YG(&%N9"!S>6YT86-T:6,@
M<W5G87(O2&]R9&4*("H@8V]D:6YG('-T86YD87)D<SL@86QL(&-R961I="!G
M;V5S('1O($%L97AA;F1R92!A;F0@=&AE(&-O9&4@:7,@=7-E9`H@*B!W:71H
M(&AI<R!P97)M:7-S:6]N+B!(:7,@;W)I9VEN86P@8V]D92!C86X@8F4@9F]U
M;F0@870Z"B`J"B`J("`@:'1T<#HO+V%L97AA;F1R92YA;&%P971I=&4N;F5T
M+V1O8RUA;&5X+V1O;7AM;"UP:'`T+7!H<#4O"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+T-O;F9I9RYP:'`L=B`Q+C@P+C(N,34@,C`P
M-B\P,R\Q,"`P,#HQ,SHS,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?1G)A;65W;W)K"B`J+PIC;&%S<R!(;W)D95]#;VYF:6<@>PH*
M("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE(&-O;F9I9W5R960@87!P
M;&EC871I;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?87!P.PH*("`@("\J*@H@("`@("H@5&AE(%A-3"!T<F5E(&]F
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@=')A=F5R<V5D('1O(&%N"B`@("`@
M*B!A<W-O8VEA=&EV92!A<G)A>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7WAM;$-O;F9I9U1R964@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@5&AE(&-O;G1E;G0@;V8@=&AE(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?<&AP0V]N9FEG.PH*("`@("\J*@H@("`@("H@5&AE
M(&-O;G1E;G0@;V8@=&AE(&]L9"!C;VYF:6=U<F%T:6]N(&9I;&4N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;VQD0V]N
M9FEG.PH*("`@("\J*@H@("`@("H@5&AE(&UA;G5A;"!C;VYF:6=U<F%T:6]N
M(&EN(&9R;VYT(&]F('1H92!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P<F5#
M;VYF:6<["@H@("`@+RHJ"B`@("`@*B!4:&4@;6%N=6%L(&-O;F9I9W5R871I
M;VX@869T97(@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!O<W1#;VYF
M:6<["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="`D8V]N9B!A<G)A>2!O
M9B!T:&4@8V]N9FEG=7)E9"!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1#;VYF:6<@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE($-64R!V97)S:6]N('1A9R!O
M9B!T:&4@8V]N9BYX;6P@9FEL92!W:&EC:"!W:6QL(&)E(&-O<&EE9"!I;G1O
M('1H90H@("`@("H@8V]N9BYP:'`@9FEL92X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]V97)S:6]N5&%G(#T@)R<["@H@
M("`@+RHJ"B`@("`@*B!4:&4@;&EN92!M87)K:6YG('1H92!B96=I;B!O9B!T
M:&4@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8V]N9FEG0F5G:6X@/2`B+RH@
M0T].1DE'(%-405)4+B!$3R!.3U0@0TA!3D=%($%.651(24Y'($E.($]2($%&
M5$52(%1(25,@3$E.12X@*B]<;B(["@H@("`@+RHJ"B`@("`@*B!4:&4@;&EN
M92!M87)K:6YG('1H92!E;F0@;V8@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7V-O;F9I9T5N9"`]("(O*B!#3TY&24<@14Y$+B!$3R!.3U0@0TA!3D=%
M($%.651(24Y'($E.($]2($)%1D]212!42$E3($Q)3D4N("HO7&XB.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D87!P("!4:&4@;F%M92!O9B!T:&4@87!P;&EC871I;VX@=&\@
M8F4@8V]N9FEG=7)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?0V]N
M9FEG*"1A<'`I"B`@("!["B`@("`@("`@)'1H:7,M/E]A<'`@/2`D87!P.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@=&AE(&%P<&QI8V%T:6]N)W,@
M8V]N9BYX;6P@9FEL92!A;F0@8G5I;&1S(&%N(&%S<V]C:6%T:79E"B`@("`@
M*B!A<G)A>2!F<F]M(&ET<R!834P@=')E92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!R97!R97-E;G1I;F<@
M=&AE(&-O;F9I9W5R871I;VX@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5A9%A-3$-O;F9I9R@I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H
M:7,M/E]X;6Q#;VYF:6=4<F5E*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@("`@(&=L;V)A;"`D<F5G
M:7-T<GD["B`@("`@("`@("`@("1P871H(#T@)')E9VES=')Y+3YG970H)V9I
M;&5R;V]T)RP@)'1H:7,M/E]A<'`I("X@)R]C;VYF:6<G.PH*("`@("`@("`@
M("`@+RH@1F5T8V@@=&AE(&-U<G)E;G0@8V]N9BYP:'`@8V]N=&5N=',N("HO
M"B`@("`@("`@("`@($!E=F%L*"1T:&ES+3YG97102%!#;VYF:6<H*2D["B`@
M("`@("`@("`@(&EF("AI<W-E="@D8V]N9BDI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8W5R<F5N=$-O;F9I9R`]("1C;VYF.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O*B!,;V%D('1H92!$3TT@;V)J96-T+B`J+PH@("`@
M("`@("`@("`D9&]C(#T@2&]R9&5?0V]N9FEG7T1O8W5M96YT.CIF86-T;W)Y
M*"1P871H("X@)R]C;VYF+GAM;"<I.PH*("`@("`@("`@("`@+RH@0VAE8VL@
M:68@=&AE<F4@:7,@82!#5E,@=F5R<VEO;B!T86<@86YD('-T;W)E(&ET+B`J
M+PH@("`@("`@("`@("`D;F]D92`]("1D;V,M/F9I<G-T7V-H:6QD*"D["B`@
M("`@("`@("`@('=H:6QE("@A96UP='DH)&YO9&4I*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&YO9&4M/G1Y<&4@/3T@6$U,7T-/34U%3E1?3D]$12D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7"0N*C]C;VYF
M7"YX;6PL=B`N*C\@+BI<)"\G+"`D;F]D92T^;F]D95]V86QU92@I+"`D;6%T
M8V@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F5R<VEO
M;E1A9R`]("1M871C:%LP72`N(")<;B(["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1N;V1E(#T@)&YO9&4M/FYE>'1?<VEB
M;&EN9R@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!087)S92!T
M:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@("`@("`@("1T:&ES+3Y?>&UL0V]N
M9FEG5')E92`](&%R<F%Y*"D["B`@("`@("`@("`@("1R;V]T(#T@)&1O8RT^
M<F]O="@I.PH@("`@("`@("`@("!I9B`H)')O;W0M/FAA<U]C:&EL9%]N;V1E
M<R@I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&5V96PH)'1H
M:7,M/E]X;6Q#;VYF:6=4<F5E+"`D<F]O="T^8VAI;&1?;F]D97,H*2P@)R<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H
M:7,M/E]X;6Q#;VYF:6=4<F5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@9FEL92!C;VYT96YT(&]F('1H92!C=7)R96YT(&-O;F9I9W5R
M871I;VX@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('5N<&%R<V5D(&-O;F9I9W5R871I;VX@9FEL92!C;VYT96YT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G97102%!#;VYF:6<H*0H@("`@>PH@("`@("`@(&EF
M("AI<U]N=6QL*"1T:&ES+3Y?;VQD0V]N9FEG*2D@>PH@("`@("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("`D<&%T:"`]("1R96=I<W1R
M>2T^9V5T*"=F:6QE<F]O="<L("1T:&ES+3Y?87!P*2`N("<O8V]N9FEG)SL*
M("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P871H("X@)R]C;VYF+G!H
M<"<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]L9$-O;F9I9R`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1P871H("X@)R]C;VYF+G!H<"<I.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V]L9$-O;F9I9RDI('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V]L9$-O;F9I9R`]('!R96=?<F5P
M;&%C92@G+SQ</W!H<%QN/R\G+"`G)RP@)'1H:7,M/E]O;&1#;VYF:6<I.PH@
M("`@("`@("`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)'1H:7,M/E]O;&1#
M;VYF:6<L("1T:&ES+3Y?8V]N9FEG0F5G:6XI.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!R94-O;F9I9R`]('-U8G-T<B@D=&AI<RT^7V]L9$-O
M;F9I9RP@,"P@)'!O<RD["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;VQD0V]N9FEG(#T@<W5B<W1R*"1T:&ES+3Y?;VQD0V]N9FEG+"`D<&]S
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'!O<R`]('-T<G!O<R@D=&AI<RT^7V]L9$-O;F9I9RP@)'1H:7,M/E]C;VYF
M:6=%;F0I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!O<W1#;VYF
M:6<@/2!S=6)S='(H)'1H:7,M/E]O;&1#;VYF:6<L("1P;W,@*R!S=')L96XH
M)'1H:7,M/E]C;VYF:6=%;F0I*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]O;&1#;VYF:6<@/2!S=6)S='(H)'1H:7,M/E]O;&1#;VYF:6<L
M(#`L("1P;W,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;VQD0V]N9FEG(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;VQD0V]N9FEG.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5N97)A=&5S('1H92!C;VYT96YT(&]F('1H92!A<'!L
M:6-A=&EO;B=S(&-O;F9I9W5R871I;VX@9FEL92X*("`@("`J"B`@("`@*B!`
M<&%R86T@5F%R:6%B;&5S("1F;W)M=F%R<R`@5&AE('!R;V-E<W-E9"!C;VYF
M:6=U<F%T:6]N(&9O<FT@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&-O;G1E;G0@;V8@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E4$A00V]N
M9FEG*"1F;W)M=F%R<RD*("`@('L*("`@("`@("`D=&AI<RT^<F5A9%A-3$-O
M;F9I9R@I.PH@("`@("`@("1T:&ES+3YG97102%!#;VYF:6<H*3L*"B`@("`@
M("`@)'1H:7,M/E]P:'!#;VYF:6<@/2`B/#]P:'!<;B(["B`@("`@("`@)'1H
M:7,M/E]P:'!#;VYF:6<@+CT@)'1H:7,M/E]P<F5#;VYF:6<["B`@("`@("`@
M)'1H:7,M/E]P:'!#;VYF:6<@+CT@)'1H:7,M/E]C;VYF:6="96=I;CL*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?=F5R<VEO;E1A9RDI('L*("`@("`@
M("`@("`@)'1H:7,M/E]P:'!#;VYF:6<@+CT@)R\O("<@+B`D=&AI<RT^7W9E
M<G-I;VY486<["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?9V5N97)A=&50
M2%!#;VYF:6<H)'1H:7,M/E]X;6Q#;VYF:6=4<F5E+"`G)RP@)&9O<FUV87)S
M*3L*("`@("`@("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`D=&AI<RT^7V-O;F9I
M9T5N9#L*("`@("`@("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`D=&AI<RT^7W!O
M<W1#;VYF:6<["@H@("`@("`@(')E='5R;B`D=&AI<RT^7W!H<$-O;F9I9SL*
M("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE(&ET96US(&9O<B!A('!A<G0@;V8@=&AE(&-O;F9I9W5R871I
M;VX*("`@("`J('1R964N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1S96-T:6]N("!!;B!A<W-O
M8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG('1H92!P87)T(&]F('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!T<F%V97)S960@6$U,(&-O;F9I
M9W5R871I;VX@=')E92!T:&%T('-H;W5L9"!B90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!P<F]C97-S960N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P<F5F:7@@($$@8V]N9FEG=7)A=&EO;B!P<F5F:7@@9&5T97)M:6YI;F<@
M=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<&]S
M:71I;VX@:6YS:61E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4N(%1H:7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@<')E9FEX('=I;&P@8F4@=')A
M;G-L871E9"!T;R!K97ES(&]F('1H92`D8V]N9@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2!I;B!T:&4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@9FEL92X*("`@("`J($!P87)A;2!687)I86)L97,@)&9O<FUV87)S
M("!4:&4@<')O8V5S<V5D(&-O;F9I9W5R871I;VX@9F]R;2!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5N97)A=&502%!#;VYF:6<H)'-E8W1I;VXL
M("1P<F5F:7@L("1F;W)M=F%R<RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1S96-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("!F;W)E86-H("@D<V5C=&EO;B!A<R`D;F%M92`]/B`D8V]N
M9FEG:71E;2D@>PH@("`@("`@("`@("`D<')E9FEX961N86UE(#T@96UP='DH
M)'!R969I>"D@/R`D;F%M92`Z("1P<F5F:7@@+B`G?"<@+B`D;F%M93L*("`@
M("`@("`@("`@)&-O;F9I9VYA;64@/2!S=')?<F5P;&%C92@G?"<L("=?7R<L
M("1P<F5F:7AE9&YA;64I.PH@("`@("`@("`@("`D<75O=&4@/2`A:7-S970H
M)&-O;F9I9VET96U;)W%U;W1E)UTI('Q\("1C;VYF:6=I=&5M6R=Q=6]T92==
M("$]/2!F86QS93L*("`@("`@("`@("`@:68@*"1C;VYF:6=I=&5M(#T]("=P
M;&%C96AO;&1E<B<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&AP0V]N
M9FEG("X]("<D8V]N9EM<)R<@+B!S=')?<F5P;&%C92@G?"<L("=<)UU;7"<G
M+"`D<')E9FEX*2`N("(G72`](&%R<F%Y*"D[7&XB.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)&-O;F9I9VET96U;)W-W:71C:"==*2D@>PH@("`@
M("`@("`@("`@("`@)'9A;"`]("1F;W)M=F%R<RT^9V5T17AI<W1S*"1C;VYF
M:6=N86UE+"`D=V%S<V5T*3L*("`@("`@("`@("`@("`@(&EF("@A)'=A<W-E
M="D@>PH@("`@("`@("`@("`@("`@("`@("1V86P@/2!I<W-E="@D8V]N9FEG
M:71E;5LG9&5F875L="==*2`_("1C;VYF:6=I=&5M6R=D969A=6QT)UT@.B!N
M=6QL.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1C;VYF:6=I=&5M6R=S=VET8V@G75LD=F%L72DI('L*("`@("`@("`@
M("`@("`@("`@("`D=F%L=64@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D<75O=&4@)B8@)'9A;'5E("$]("=T<G5E)R`F)B`D=F%L=64@(3T@
M)V9A;'-E)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`B
M)R(@+B`D=F%L=64@+B`B)R(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5N97)A=&502%!#;VYF:6<H)&-O
M;F9I9VET96U;)W-W:71C:"==6R1V86Q=6R=F:65L9',G72P@)'!R969I>"P@
M)&9O<FUV87)S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1C;VYF:6=I=&5M6R=?='EP92==*2D@>PH@("`@("`@
M("`@("`@("`@)'9A;"`]("1F;W)M=F%R<RT^9V5T17AI<W1S*"1C;VYF:6=N
M86UE+"`D=V%S<V5T*3L*("`@("`@("`@("`@("`@(&EF("@A)'=A<W-E="D@
M>PH@("`@("`@("`@("`@("`@("`@("1V86P@/2!I<W-E="@D8V]N9FEG:71E
M;5LG9&5F875L="==*2`_("1C;VYF:6=I=&5M6R=D969A=6QT)UT@.B!N=6QL
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1T>7!E(#T@
M)&-O;F9I9VET96U;)U]T>7!E)UT["B`@("`@("`@("`@("`@("!S=VET8V@@
M*"1T>7!E*2!["B`@("`@("`@("`@("`@("!C87-E("=M=6QT:65N=6TG.@H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D96YC=F%L<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86P@87,@)'8I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E;F-V86QS6UT@/2`D=&AI<RT^
M7W%U;W1E*"1V*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`D87)R87EV86P@/2`B)R(@+B!I;7!L;V1E*"=<
M)RP@7"<G+"`D96YC=F%L<RD@+B`B)R(["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D87)R87EV86P@/3T@(B<G(BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%R<F%Y=F%L(#T@)R<["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D87)R87EV86P@/2`G)SL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)V%R<F%Y
M*"<@+B`D87)R87EV86P@+B`G*2<["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G8F]O;&5A;B<Z"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES7V)O;VPH)'9A;"DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@)'9A;"`_("=T<G5E)R`Z("=F86QS92<[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E(#T@*"1V86P@/3T@)V]N)RD@/R`G=')U92<@.B`G
M9F%L<V4G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=S=')I;F=L:7-T
M)SH*("`@("`@("`@("`@("`@("`@("`D=F%L=65S(#T@97AP;&]D92@G+"<L
M("1V86PI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'9A
M;'5E<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@(F%R
M<F%Y*"<B("X@)'1H:7,M/E]Q=6]T92AT<FEM*"1V86QU97,I*2`N("(G*2([
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N8W9A;',@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1V*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D96YC=F%L<UM=(#T@)'1H:7,M/E]Q=6]T92AT
M<FEM*"1V*2D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%R<F%Y=F%L(#T@(B<B("X@:6UP;&]D92@G7"<L
M(%PG)RP@)&5N8W9A;',I("X@(B<B.PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)&%R<F%Y=F%L(#T]("(G)R(I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A<G)A>79A;"`]("<G.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("=A<G)A
M>2@G("X@)&%R<F%Y=F%L("X@)RDG.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("=I;G0G.@H@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L("$]("<G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("AI;G0I)'9A
M;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G;V-T86PG.@H@("`@("`@
M("`@("`@("`@("`@("1V86QU92`]('-P<FEN=&8H)S`E;R<L(&]C=&1E8R@D
M=F%L*2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G:&5A9&5R)SH*("`@("`@("`@("`@("`@(&-A<V4@)V1E
M<V-R:7!T:6]N)SH*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@(&EF("@D
M=F%L("$]("<G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M("1V86P["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<75O=&4@)B8@
M)'9A;'5E("$]("=T<G5E)R`F)B`D=F%L=64@(3T@)V9A;'-E)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@(B<B("X@)'1H:7,M
M/E]Q=6]T92@D=F%L=64I("X@(B<B.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]G96YE<F%T95!(4$-O;F9I9R@D
M8V]N9FEG:71E;2P@)'!R969I>&5D;F%M92P@)&9O<FUV87)S*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU92DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]("<D8V]N9EM<)R<@
M+B!S=')?<F5P;&%C92@G7U\G+"`G7"==6UPG)RP@)&-O;F9I9VYA;64I("X@
M)UPG72`]("<@+B`D=F%L=64@+B`B.UQN(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!U;G-E="@D=F%L=64I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%!A<G-E<R!O;F4@;&5V96P@;V8@=&AE(&-O;F9I9W5R871I
M;VX@6$U,('1R964@:6YT;R!T:&4@87-S;V-I871I=F4*("`@("`J(&%R<F%Y
M(&-O;G1A:6YI;F<@=&AE('1R879E<G-E9"!C;VYF:6=U<F%T:6]N('1R964N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("8D8V]N9B`@("`@5&AE(&%L<F5A9'D@97AI<W1I;F<@
M87)R87D@=VAE<F4@=&AE('!R;V-E<W-E9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,('1R964@<&]R=&EO;B!S:&]U;&0@8F4@87!P96YD
M960@=&\N"B`@("`@*B!`<&%R86T@87)R87D@)&-H:6QD<F5N("!!;B!A<G)A
M>2!C;VYT86EN:6YG('1H92!834P@;F]D97,@;V8@=&AE(&QE=F5L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!T:&%T('-H;W5L9"!B92!P87)S
M960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C='@@("`@("!!('-T<FEN9R!R
M97!R97-E;G1I;F<@=&AE(&-U<G)E;G0@<&]S:71I;VX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("AC;VYT97AT('!R969I>"D@:6YS:61E('1H
M92!C;VYF:6=U<F%T:6]N(%A-3`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E3&5V96PH
M)B1C;VYF+"`D8VAI;&1R96XL("1C='@I"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH*("`@("`@("!F;W)E
M86-H("@D8VAI;&1R96X@87,@)&YO9&4I('L*("`@("`@("`@("`@:68@*"1N
M;V1E+3YT>7!E("$](%A-3%]%3$5-14Y47TY/1$4I('L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1N86UE
M(#T@)&YO9&4M/F=E=%]A='1R:6)U=&4H)VYA;64G*3L*("`@("`@("`@("`@
M)&1E<V,@/2!497AT7T9I;'1E<CHZ9FEL=&5R*"1N;V1E+3YG971?871T<FEB
M=71E*"=D97-C)RDL("=L:6YK=7)L<R<L(&%R<F%Y*"=C86QL8F%C:R<@/3X@
M)TAO<F1E.CIE>'1E<FYA;%5R;"<I*3L*("`@("`@("`@("`@)')E<75I<F5D
M(#T@(2@D;F]D92T^9V5T7V%T=')I8G5T92@G<F5Q=6ER960G*2`]/2`G9F%L
M<V4G*3L*("`@("`@("`@("`@)'%U;W1E(#T@(2@D;F]D92T^9V5T7V%T=')I
M8G5T92@G<75O=&4G*2`]/2`G9F%L<V4G*3L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D8W1X*2D@>PH@("`@("`@("`@("`@("`@)&-U<F-T>"`]("1C='@@
M+B`G?"<@+B`D;F%M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1C=7)C='@@/2`D;F%M93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@<W=I=&-H("@D;F]D92T^=&%G;F%M92D@>PH@("`@("`@("`@("!C
M87-E("=C;VYF:6=D97-C<FEP=&EO;B<Z"B`@("`@("`@("`@("`@("!I9B`H
M96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!M
M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G9&5S8W)I
M<'1I;VXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E<V,G(#T^(%1E>'1?1FEL=&5R.CIF:6QT97(H)'1H:7,M/E]D969A=6QT
M*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2DL("=L
M:6YK=7)L<R<L(&%R<F%Y*"=C86QL8F%C:R<@/3X@)TAO<F1E.CIE>'1E<FYA
M;%5R;"<I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)V-O;F9I9VAE861E<B<Z"B`@("`@("`@("`@("`@("!I9B`H96UP
M='DH)&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!M9#4H
M;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G:&5A9&5R)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL
M>51E>'0H)&YO9&4I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)V-O;F9I9W-W:71C:"<Z"B`@("`@("`@("`@("`@("!I
M9B`H)'%U;W1E*2!["B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'0@/2`D
M=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E
M>'0H)&YO9&4I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&1E9F%U;'0@/2`D=&AI<RT^7V1E9F%U;'1287<H)&-U
M<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE72`](&%R
M<F%Y*"=D97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S=VET8V@G(#T^("1T:&ES+3Y?9V5T4W=I=&-H5F%L
M=65S*"1N;V1E+"`D8W1X*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D969A=6QT)R`]/B`D9&5F875L="D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9V5N=6TG.@H@
M("`@("`@("`@("`@("`@)'9A;'5E<R`]("1T:&ES+3Y?9V5T16YU;59A;'5E
M<R@D;F]D92D["B`@("`@("`@("`@("`@("!I9B`H)'%U;W1E*2!["B`@("`@
M("`@("`@("`@("`@("`@)&1E9F%U;'0@/2`D=&AI<RT^7V1E9F%U;'0H)&-U
M<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&1E9F%U
M;'0@/2`D=&AI<RT^7V1E9F%U;'1287<H)&-U<F-T>"P@)'1H:7,M/E]G971.
M;V1E3VYL>51E>'0H)&YO9&4I*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y*"=?='EP92<@/3X@)V5N
M=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M<75I<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<75O=&4G(#T^("1Q=6]T92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU97,G(#T^("1V86QU97,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@
M/3X@)&1E<V,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&5F875L="<@/3X@)&1E9F%U;'0I.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=C;VYF:6=L:7-T)SH*("`@("`@("`@
M("`@("`@("1D969A=6QT(#T@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L(&YU
M;&PI.PH@("`@("`@("`@("`@("`@:68@*"1D969A=6QT(#T]/2!N=6QL*2![
M"B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'0@/2`D=&AI<RT^7V=E=$YO
M9&5/;FQY5&5X="@D;F]D92D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-?87)R87DH)&1E9F%U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@)&1E
M9F%U;'0@/2!I;7!L;V1E*"<L("<L("1D969A=6QT*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y*"=?
M='EP92<@/3X@)W-T<FEN9VQI<W0G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)&1E
M<V,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F
M875L="<@/3X@)&1E9F%U;'0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("=C;VYF:6=M=6QT:65N=6TG.@H@("`@("`@("`@
M("`@("`@)'9A;'5E<R`]("1T:&ES+3Y?9V5T16YU;59A;'5E<R@D;F]D92D[
M"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H
M<"<["B`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y
M<&4G(#T^("=M=6QT:65N=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B`D=F%L
M=65S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1E9F%U;'0G(#T^($AO<F1E7T%R<F%Y.CIV86QU97-4;TME>7,H
M)'1H:7,M/E]D969A=6QT*"1C=7)C='@L(&5X<&QO9&4H)RPG+"`D=&AI<RT^
M7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI*2DI.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=C;VYF:6=P87-S=V]R9"<Z"B`@
M("`@("`@("`@("`@("`D8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^
M("=P87-S=V]R9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<F5Q=6ER960G(#T^("1R97%U:7)E9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`D9&5S8RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D
M=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E
M>'0H)&YO9&4I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)V-O;F9I9W-T<FEN9R<Z"B`@("`@("`@("`@("`@("`D8V]N
M9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@)')E
M<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W5R8W1X
M+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI*3L*("`@("`@("`@
M("`@("`@(&EF("@D8V]N9ELD;F%M95U;)V1E9F%U;'0G72`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95U;)V1E9F%U;'0G
M72`]("=F86QS92<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&-O;F9;
M)&YA;65=6R=D969A=6QT)UT@/3T]('1R=64I('L*("`@("`@("`@("`@("`@
M("`@("`D8V]N9ELD;F%M95U;)V1E9F%U;'0G72`]("=T<G5E)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G8V]N9FEG8F]O;&5A;B<Z"B`@("`@("`@("`@("`@("`D9&5F
M875L="`]("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*3L*("`@("`@
M("`@("`@("`@(&EF("AE;7!T>2@D9&5F875L="D@?'P@)&1E9F%U;'0@/3T]
M("=F86QS92<I('L*("`@("`@("`@("`@("`@("`@("`D9&5F875L="`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D9&5F875L="`]('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=B
M;V]L96%N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R97%U:7)E9"<@/3X@)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES
M+3Y?9&5F875L="@D8W5R8W1X+"`D9&5F875L="DI.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=C;VYF:6=I;G1E9V5R)SH*
M("`@("`@("`@("`@("`@("1V86QU97,@/2`D=&AI<RT^7V=E=$5N=6U686QU
M97,H)&YO9&4I.PH@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=(#T@87)R
M87DH)U]T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@)')E<75I<F5D+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@)'9A
M;'5E<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@
M)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*2D["B`@("`@("`@("`@
M("`@("!I9B`H)&YO9&4M/F=E=%]A='1R:6)U=&4H)V]C=&%L)RD@/3T@)W1R
M=64G("8F"B`@("`@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=6R=D969A
M=6QT)UT@(3T@)R<I('L*("`@("`@("`@("`@("`@("`@("`D8V]N9ELD;F%M
M95U;)U]T>7!E)UT@/2`G;V-T86PG.PH@("`@("`@("`@("`@("`@("`@("1C
M;VYF6R1N86UE75LG9&5F875L="==(#T@<W!R:6YT9B@G,"5O)RP@)'1H:7,M
M/E]D969A=6QT*"1C=7)C='@L(&]C=&1E8R@D=&AI<RT^7V=E=$YO9&5/;FQY
M5&5X="@D;F]D92DI*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W!H<"<Z"B`@
M("`@("`@("`@("`@("`D8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^
M("=P:'`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E<75I<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<75O=&4G(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^("1T:&ES+3Y?9&5F875L=%)A=R@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO
M9&5/;FQY5&5X="@D;F]D92DI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G8V]N9FEG<W%L)SH*("`@("`@("`@("`@("`@
M("1C;VYF6R1N;V1E+3YG971?871T<FEB=71E*"=S=VET8VAN86UE)RE=(#T@
M)'1H:7,M/E]C;VYF:6=344PH)&-T>"P@)&YO9&4I.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=C;VYF:6=V9G,G.@H@("`@
M("`@("`@("`@("`@)&-O;F9;)&YO9&4M/F=E=%]A='1R:6)U=&4H)W-W:71C
M:&YA;64G*5T@/2`D=&AI<RT^7V-O;F9I9U9&4R@D8W1X+"`D;F]D92D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I
M9W-E8W1I;VXG.@H@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=(#T@87)R
M87DH*3L*("`@("`@("`@("`@("`@("1C=7(@/2`F)&-O;F9;)&YA;65=.PH@
M("`@("`@("`@("`@("`@:68@*"1N;V1E+3YH87-?8VAI;&1?;F]D97,H*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,979E;"@D8W5R
M+"`D;F]D92T^8VAI;&1?;F]D97,H*2P@)&-U<F-T>"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)V-O;F9I9W1A8B<Z"B`@("`@("`@("`@("`@("`D:V5Y(#T@;60U*&UI
M8W)O=&EM92@I*3L*("`@("`@("`@("`@("`@("1C;VYF6R1K97E=(#T@87)R
M87DH)W1A8B<@/3X@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`D9&5S8RD["B`@("`@("`@("`@("`@("!I
M9B`H)&YO9&4M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)S94QE=F5L*"1C;VYF+"`D;F]D92T^8VAI;&1?
M;F]D97,H*2P@)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W!L86-E:&]L
M9&5R)SH*("`@("`@("`@("`@("`@("1C;VYF6VUD-2AM:6-R;W1I;64H*2E=
M(#T@)W!L86-E:&]L9&5R)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE
M72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D8W5R(#T@)B1C;VYF6R1N
M86UE73L*("`@("`@("`@("`@("`@(&EF("@D;F]D92T^:&%S7V-H:6QD7VYO
M9&5S*"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&5V
M96PH)&-U<BP@)&YO9&4M/F-H:6QD7VYO9&5S*"DL("1C=7)C='@I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!C;VYF:6=U<F%T:6]N('1R964@9F]R(&%N(%-13"!B86-K96YD(&-O
M;F9I9W5R871I;VX@=&\*("`@("`J(')E<&QA8V4@82`\8V]N9FEG<W%L/B!T
M86<N"B`@("`@*B!3=6)N;V1E<R!W:6QL(&)E('!A<G-E9"!A;F0@861D960@
M=&\@8F]T:"!T:&4@2&]R9&4@9&5F875L=',@86YD('1H90H@("`@("H@0W5S
M=&]M(&-O;F9I9W5R871I;VX@<&%R=',N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W1X("`@
M("`@("`@5&AE(&-O;G1E>'0@;V8@=&AE(#QC;VYF:6=S<6P^('1A9RX*("`@
M("`J($!P87)A;2!$;VU.;V1E("1N;V1E("`@("`@(%1H92!$;VU.;V1E(')E
M<')E<V5N=&%T:6]N(&]F('1H92`\8V]N9FEG<W%L/@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&%G+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<W=I=&-H;F%M92`@268@1&]M3F]D92!I<R!N;W0@<V5T+"!T:&4@=F%L
M=64@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M86<G<R!S=VET8VAN86UE(&%T=')I8G5T92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!344P@
M8V]N9FEG=7)A=&EO;B!T<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N
M9FEG4U%,*"1C='@L("1N;V1E(#T@;G5L;"P@)'-W:71C:&YA;64@/2`G9')I
M=F5R8V]N9FEG)RD*("`@('L*("`@("`@("`D<&5R<VES=&5N="`](&%R<F%Y
M*`H@("`@("`@("`@("`G7W1Y<&4G(#T^("=B;V]L96%N)RP*("`@("`@("`@
M("`@)W)E<75I<F5D)R`]/B!F86QS92P*("`@("`@("`@("`@)V1E<V,G(#T^
M("=297%U97-T('!E<G-I<W1E;G0@8V]N;F5C=&EO;G,_)RP*("`@("`@("`@
M("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQP97)S
M:7-T96YT)RP@9F%L<V4I*3L*("`@("`@("`D:&]S='-P96,@/2!A<G)A>2@*
M("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("=R
M97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@)V1E<V,G(#T^("=$871A
M8F%S92!S97)V97(O:&]S="<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D
M=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\:&]S='-P96,G+"`G)RDI.PH@("`@
M("`@("1U<V5R;F%M92`](&%R<F%Y*`H@("`@("`@("`@("`G7W1Y<&4G(#T^
M("=T97AT)RP*("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@
M("`@("`@("`G9&5S8R<@/3X@)U5S97)N86UE('1O(&-O;FYE8W0@=&\@=&AE
M(&1A=&%B87-E(&%S)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES
M+3Y?9&5F875L="@D8W1X("X@)WQU<V5R;F%M92<L("<G*2D["B`@("`@("`@
M)'!A<W-W;W)D(#T@87)R87DH"B`@("`@("`@("`@("=?='EP92<@/3X@)W1E
M>'0G+`H@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@("`@
M("`@("`G9&5S8R<@/3X@)U!A<W-W;W)D('1O(&-O;FYE8W0@=VET:"<L"B`@
M("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N
M("=\<&%S<W=O<F0G+"`G)RDI.PH@("`@("`@("1D871A8F%S92`](&%R<F%Y
M*`H@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@
M)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@("`@("`@("`G9&5S8R<@/3X@)T1A
M=&%B87-E(&YA;64@=&\@=7-E)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQD871A8F%S92<L("<G*2D["B`@
M("`@("`@)'-O8VME="`](&%R<F%Y*`H@("`@("`@("`@("`G7W1Y<&4G(#T^
M("=T97AT)RP*("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS92P*("`@
M("`@("`@("`@)V1E<V,G(#T^("=,;V-A=&EO;B!O9B!53DE8('-O8VME="<L
M"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T
M>"`N("=\<V]C:V5T)RP@)R<I*3L*("`@("`@("`D<&]R="`](&%R<F%Y*`H@
M("`@("`@("`@("`G7W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G<F5Q
M=6ER960G(#T^(&9A;'-E+`H@("`@("`@("`@("`G9&5S8R<@/3X@)U!O<G0@
M=&AE($1"(&ES(')U;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"<L"B`@("`@
M("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\
M<&]R="<L(&YU;&PI*3L*("`@("`@("`D<')O=&]C;VP@/2!A<G)A>2@*("`@
M("`@("`@("`@)V1E<V,G(#T^("=(;W<@<VAO=6QD('=E(&-O;FYE8W0@=&\@
M=&AE(&1A=&%B87-E/R<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI
M<RT^7V1E9F%U;'0H)&-T>"`N("=\<')O=&]C;VPG+"`G=6YI>"<I+`H@("`@
M("`@("`@("`G<W=I=&-H)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=U
M;FEX)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@
M)U5.25@@4V]C:V5T<R<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=S;V-K970G(#T^
M("1S;V-K970I*2P*("`@("`@("`@("`@("`@("=T8W`G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G5$-0+TE0)RP*("`@("`@
M("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@)W!O<G0G(#T^("1P;W)T*2DI*3L*("`@("`@("`D;7ES
M<6Q?<')O=&]C;VP@/2`D<')O=&]C;VP["B`@("`@("`@)&UY<W%L7W!R;W1O
M8V]L6R=S=VET8V@G75LG=&-P)UU;)V9I96QD<R==6R=P;W)T)UU;)V1E9F%U
M;'0G72`]("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQP;W)T)RP@,S,P-BD[
M"B`@("`@("`@)&-H87)S970@/2!A<G)A>2@*("`@("`@("`@("`@)U]T>7!E
M)R`]/B`G=&5X="<L"B`@("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U92P*
M("`@("`@("`@("`@)V1E<V,G(#T^("=);G1E<FYA;&QY('5S960@8VAA<G-E
M="<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H
M)&-T>"`N("=\8VAA<G-E="<L("=I<V\M.#@U.2TQ)RDI.PH*("`@("`@("`D
M;V-I.%]F:65L9',@/2!A<G)A>2@*("`@("`@("`@("`@)W!E<G-I<W1E;G0G
M(#T^("1P97)S:7-T96YT+`H@("`@("`@("`@("`G=7-E<FYA;64G(#T^("1U
M<V5R;F%M92P*("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`D<&%S<W=O<F0I
M.PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V]C:5]C;VYN96-T)RDI
M('L*("`@("`@("`@("`@)&]C:3A?9FEE;&1S6R=D871A8F%S92==(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@
M("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@("`@
M("=D97-C)R`]/B`G1&%T86)A<V4@;F%M92!O<B!%87-Y($-O;FYE8W0@<&%R
M86UE=&5R)RP*("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^
M7V1E9F%U;'0H)&-T>"`N("=\9&%T86)A<V4G+"`G:&]R9&4G*2D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&]C:3A?9FEE;&1S6R=H;W-T<W!E
M8R==(#T@87)R87DH"B`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT
M)RP*("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G1&%T86)A<V4@;F%M92!O<B!%87-Y($-O
M;FYE8W0@<&%R86UE=&5R)RP*("`@("`@("`@("`@("`@("=D969A=6QT)R`]
M/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\:&]S='-P96,G+"`G:&]R9&4G
M*2D["B`@("`@("`@?0H@("`@("`@("1O8VDX7V9I96QD<ULG8VAA<G-E="==
M(#T@)&-H87)S970["@H@("`@("`@("1C=7-T;VU?9FEE;&1S(#T@87)R87DH
M"B`@("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@
M)V1E<V,G(#T^("=7:&%T(&1A=&%B87-E(&)A8VME;F0@<VAO=6QD('=E('5S
M93\G+`H@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT
M*"1C='@@+B`G?'!H<'1Y<&4G+"`G9F%L<V4G*2P*("`@("`@("`@("`@)W-W
M:71C:"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G9F%L<V4G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G6TYO;F5=)RP*
M("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@I*2P*("`@
M("`@("`@("`@("`@("=D8F%S92<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@)V1E<V,G(#T^("=D0F%S92<L"B`@("`@("`@("`@("`@("`@("`@
M)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=D
M871A8F%S92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D97-C)R`]/B`G06)S;VQU=&4@<&%T:"!T;R!T:&4@9&%T86)A
M<V4@9FEL92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&1A=&%B87-E)RP@)R<I
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)VUO9&4G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G96YU;2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U1H92!M
M;V1E('1O(&]P96X@=&AE(&9I;&4@=VET:"<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`P(#T^("=296%D($]N;'DG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#(@/3X@)U)E860@5W)I=&4G*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^
M7V1E9F%U;'0H)&-T>"`N("=\;6]D92<L(#(I*2P*"B`@("`@("`@("`@("`@
M("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@
M("`@("`@)VEB87-E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G
M9&5S8R<@/3X@)T9I<F5B:7)D+TEN=&5R0F%S92<L"B`@("`@("`@("`@("`@
M("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("=D8G-Y;G1A>"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G7W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I
M86YT('1O('5S92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q
M=6ER960G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W9A;'5E<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VEB87-E)R`]/B`G26YT97)"87-E)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9FER96)I<F0G(#T^("=&:7)E8FER9"<I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES
M+3Y?9&5F875L="@D8W1X("X@)WQD8G-Y;G1A>"<L("=F:7)E8FER9"<I*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S
M:7-T96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^
M("1H;W-T<W!E8RP*("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE
M)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S
M=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M9&%T86)A<V4G(#T^("1D871A8F%S92P*("`@("`@("`@("`@("`@("`@("`@
M("`@)V)U9F9E<G,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)U]T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D97-C)R`]/B`G5&AE(&YU;6)E<B!O9B!D871A8F%S92!B=69F
M97)S('1O(&%L;&]C871E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&)U
M9F9E<G,G+"!N=6QL*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=D:6%L
M96-T)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?
M='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9&5S8R<@/3X@)U1H92!D969A=6QT(%-13"!D:6%L96-T(&9O<B!A;GD@<W1A
M=&5M96YT(&5X96-U=&5D('=I=&AI;B!A(&-O;FYE8W1I;VXN)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M
M/E]D969A=6QT*"1C='@@+B`G?&1I86QE8W0G+"!N=6QL*2DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("=R;VQE)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=2;VQE)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D
M969A=6QT*"1C='@@+B`G?')O;&4G+"!N=6QL*2DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@
M("`@("`@)V9B<W%L)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G
M9&5S8R<@/3X@)T9R;VYT8F%S92<L"B`@("`@("`@("`@("`@("`@("`@)V9I
M96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=P97)S
M:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@("`@("`@
M("`@)VAO<W1S<&5C)R`]/B`D:&]S='-P96,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("=U<V5R;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G<&%S<W=O<F0G(#T^("1P87-S=V]R9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@)V1A=&%B87-E)R`]/B`D9&%T86)A<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@
M("`@("`@("`@("`@("`@)VEF>"<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@)V1E<V,G(#T^("=);F9O<FUI>"<L"B`@("`@("`@("`@("`@("`@
M("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("=P97)S:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@
M("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^("1D871A8F%S92P*("`@
M("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL
M"B`@("`@("`@("`@("`@("`G;7-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)V1E<V,G(#T^("=M4U%,)RP*("`@("`@("`@("`@("`@("`@
M("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@("`@("`@("`@
M("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<&]R="<@/3X@)'!O<G0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I*2P*
M("`@("`@("`@("`@("`@("=M<W-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)V1E<V,G(#T^("=-4R!344P@4V5R=F5R)RP*("`@("`@("`@
M("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W
M;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&]R="<@/3X@)'!O<G0L
M"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B
M87-E+`H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H
M87)S970I*2P*("`@("`@("`@("`@("`@("=M>7-Q;"<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=->5-13"<L"B`@("`@("`@
M("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("=P97)S:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@
M("`@("`@("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B`D:&]S='-P96,L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=U<V5R;F%M92<@/3X@)'5S97)N86UE
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&%S<W=O<F0G(#T^("1P87-S
M=V]R9"P*("`@("`@("`@("`@("`@("`@("`@("`@)W!R;W1O8V]L)R`]/B`D
M;7ES<6Q?<')O=&]C;VPL"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A
M8F%S92<@/3X@)&1A=&%B87-E+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@("`@("`@("`@("`@("=M>7-Q
M;&DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G
M37E344P@*&UY<W%L:2DG+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N
M="<@/3X@)'!E<G-I<W1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=H
M;W-T<W!E8R<@/3X@)&AO<W1S<&5C+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G=7-E<FYA;64G(#T^("1U<V5R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@)W!A<W-W;W)D)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=P;W)T)R`]/B`D<&]R="P*("`@("`@("`@("`@("`@("`@
M("`@("`@)W-O8VME="<@/3X@)'-O8VME="P*("`@("`@("`@("`@("`@("`@
M("`@("`@)V1A=&%B87-E)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@
M("`@("`@)V]C:3@G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D
M97-C)R`]/B`G3W)A8VQE)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S
M)R`]/B`D;V-I.%]F:65L9',I+`H@("`@("`@("`@("`@("`@)V]D8F,G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G3T1"0R<L
M"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT)R`]/B`D<&5R<VES=&5N
M="P*("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E
M<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@
M)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G:&]S='-P96,G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E
M)R`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S
M8R<@/3X@)T133B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F
M875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&AO<W1S<&5C)RP@
M)R<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V1B<WEN=&%X)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?='EP92<@/3X@
M)V5N=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^
M("=4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@=7-E)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W%L.3(G(#T^("=3
M44PY,B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%C8V5S
M<R<@/3X@)T%C8V5S<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1B,B<@/3X@)T1",B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W-O;&ED)R`]/B`G4V]L:60G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=N879I<VEO;B<@/3X@)TYA=FES:6]N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;7-S<6PG(#T^("=-4R!344P@
M4V5R=F5R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<WEB
M87-E)R`]/B`G4WEB87-E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;7ES<6PG(#T^("=->5-13"<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VUY<W%L:2<@/3X@)TUY4U%,("AM>7-Q;&DI)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D
M8W1X("X@)WQD8G-Y;G1A>"<L("=S<6PY,B<I*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)V-U<G-O<B<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G7W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D97-C)R`]/B`G0W5R<V]R('1Y<&4G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W%U;W1E)R`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;G5L;"<@/3X@)TYO
M;F4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=344Q?0U52
M7T1%1D%53%0G(#T^("=$969A=6QT)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G4U%,7T-54E]54T5?1%))5D52)R`]/B`G57-E($1R:79E
M<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U-13%]#55)?
M55-%7T]$0D,G(#T^("=5<V4@3T1"0R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U-13%]#55)?55-%7TE&7TY%141%1"<@/3X@)U5S92!)
M9B!.965D960G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A
M=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\8W5R<V]R)RP@;G5L
M;"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H
M87)S970I*2P*("`@("`@("`@("`@("`@("=P9W-Q;"<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=0;W-T9W)E4U%,)RP*("`@
M("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E
M8RP*("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E
M<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@
M)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G<')O=&]C;VPG
M(#T^("1P<F]T;V-O;"P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B
M87-E)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C
M:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)W-Q;&ET
M92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=3
M44QI=&4G+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X
M="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^
M('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@
M)T%B<V]L=71E('!A=&@@=&\@=&AE(&1A=&%B87-E(&9I;&4G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F
M875L="@D8W1X("X@)WQD871A8F%S92<L("<G*2DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("=M;V1E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=?='EP92<@/3X@)V]C=&%L)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D97-C)R`]/B`G5&AE(&UO9&4@=&\@;W!E;B!T:&4@
M9FEL92!W:71H)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A
M=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\;6]D92<L("<P-C0T
M)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H
M87)S970I*2P*("`@("`@("`@("`@("`@("=S>6)A<V4G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G4WEB87-E)RP*("`@("`@
M("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A
M<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^
M("1D871A8F%S92P*("`@("`@("`@("`@("`@("`@("`@("`@)V%P<&YA;64G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E
M)R`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S
M8R<@/3X@)T%P<&QI8V%T:6]N($YA;64G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T
M>"`N("=\87!P;F%M92<L("<G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI*2D["@H@("`@("`@(&EF("AI<W-E
M="@D;F]D92D@)B8@)&YO9&4M/F=E=%]A='1R:6)U=&4H)V)A<V5C;VYF:6<G
M*2`]/2`G=')U92<I('L*("`@("`@("`@("`@<F5T=7)N("1C=7-T;VU?9FEE
M;&1S.PH@("`@("`@('T*"B`@("`@("`@)&-O;F9I9R`](&%R<F%Y*`H@("`@
M("`@("`@("`G9&5S8R<@/3X@)T1R:79E<B!C;VYF:6=U<F%T:6]N)RP*("`@
M("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@
M)WPG("X@*&ES<V5T*"1N;V1E*2`_("1N;V1E+3YG971?871T<FEB=71E*"=S
M=VET8VAN86UE)RD@.B`D<W=I=&-H;F%M92DL("=H;W)D92<I+`H@("`@("`@
M("`@("`G<W=I=&-H)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=H;W)D
M92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=(
M;W)D92!D969A=6QT<R<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@
M/3X@87)R87DH*2DL"B`@("`@("`@("`@("`@("`G8W5S=&]M)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T-U<W1O;2!P87)A
M;65T97)S)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@;60U*&UI8W)O=&EM92@I*2`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?='EP92<@
M/3X@)V1E<V-R:7!T:6]N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D97-C)R`]/B`G06YY('!A<F%M971E<G,@=&AA="!T:&4@<W1O<F%G92!D
M<FEV97(@;F5E9',N)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("=P:'!T
M>7!E)R`]/B`D8W5S=&]M7V9I96QD<RDI*2D["@H@("`@("`@(&EF("AI<W-E
M="@D;F]D92D@)B8@)&YO9&4M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@("`@
M("`@("`@("1C=7(@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=&AI<RT^7W!A
M<G-E3&5V96PH)&-U<BP@)&YO9&4M/F-H:6QD7VYO9&5S*"DL("1C='@I.PH@
M("`@("`@("`@("`D8V]N9FEG6R=S=VET8V@G75LG:&]R9&4G75LG9FEE;&1S
M)UT@/2!A<G)A>5]M97)G92@D8V]N9FEG6R=S=VET8V@G75LG:&]R9&4G75LG
M9FEE;&1S)UTL("1C=7(I.PH@("`@("`@("`@("`D8V]N9FEG6R=S=VET8V@G
M75LG8W5S=&]M)UU;)V9I96QD<R==(#T@87)R87E?;65R9V4H)&-O;F9I9ULG
M<W=I=&-H)UU;)V-U<W1O;2==6R=F:65L9',G72P@)&-U<BD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&-O;F9I9SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&-O;F9I9W5R871I;VX@=')E92!F;W(@82!61E,@
M8F%C:V5N9"!C;VYF:6=U<F%T:6]N('1O"B`@("`@*B!R97!L86-E(&$@/&-O
M;F9I9W9F<SX@=&%G+@H@("`@("H@4W5B;F]D97,@=VEL;"!B92!P87)S960@
M86YD(&%D9&5D('1O(&)O=&@@=&AE($AO<F1E(&1E9F%U;'1S(&%N9"!T:&4*
M("`@("`J($-U<W1O;2!C;VYF:6=U<F%T:6]N('!A<G1S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-T>"`@("!4:&4@8V]N=&5X="!O9B!T:&4@/&-O;F9I9W9F<SX@=&%G
M+@H@("`@("H@0'!A<F%M($1O;4YO9&4@)&YO9&4@(%1H92!$;VU.;V1E(')E
M<')E<V5N=&%T:6]N(&]F('1H92`\8V]N9FEG=F9S/@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@('1A9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!61E,@8V]N9FEG
M=7)A=&EO;B!T<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N9FEG5D93
M*"1C='@L("1N;V1E*0H@("`@>PH@("`@("`@("1S<6P@/2`D=&AI<RT^7V-O
M;F9I9U-13"@D8W1X("X@)WQP87)A;7,G*3L*("`@("`@("`D8V]N9FEG(#T*
M("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`G9&5S8R<@/3X@
M)U=H870@5D93(&1R:79E<B!S:&]U;&0@=V4@=7-E/R<L"B`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?"<@
M+B`D;F]D92T^9V5T7V%T=')I8G5T92@G<W=I=&-H;F%M92<I+"`G:&]R9&4G
M*2P*("`@("`@("`@("`@("`@("=S=VET8V@G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("=H;W)D92<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G2&]R9&4@9&5F875L=',G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@I*2P*("`@("`@
M("`@("`@("`@("`@("`G9FEL92<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G1FEL97,@;VX@=&AE(&QO8V%L('-Y<W1E
M;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9F<W)O;W0G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1E<V,G(#T^("=7:&5R92!O;B!T:&4@<F5A;"!F:6QE
M<WES=&5M('-H;W5L9"!(;W)D92!U<V4@87,@<F]O="!O9B!T:&4@=FER='5A
M;"!F:6QE<WES=&5M/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\
M<&%R86US?'9F<W)O;W0G+"`G+W1M<"<I*2DI*2P*("`@("`@("`@("`@("`@
M("`@("`G<W%L)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E<V,G(#T^("=344P@9&%T86)A<V4G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D<FEV97)C;VYF:6<G(#T^("1S<6PI*2DI*3L*"B`@
M("`@("`@)&-A<V5S(#T@)'1H:7,M/E]G9713=VET8VA686QU97,H)&YO9&4L
M("1C='@@+B`G?'!A<F%M<R<I.PH@("`@("`@(&9O<F5A8V@@*"1C87-E<R!A
M<R`D8V%S92`]/B`D9FEE;&1S*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M8V]N9FEG6R=S=VET8V@G75LD8V%S95TI*2!["B`@("`@("`@("`@("`@("`D
M8V]N9FEG6R=S=VET8V@G75LD8V%S95U;)V9I96QD<R==6R=P87)A;7,G72`]
M(&%R<F%Y7VUE<F=E*"1C;VYF:6=;)W-W:71C:"==6R1C87-E75LG9FEE;&1S
M)UU;)W!A<F%M<R==+"`D9FEE;&1S6R=F:65L9',G72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V]N9FEG.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&-E<G1A:6X@=F%L=64@9G)O;2!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N(&%R<F%Y(&]R"B`@("`@*B!A(&1E
M9F%U;'0@=F%L=64L(&EF(&YO="!F;W5N9"X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C='@@
M("`@($$@<W1R:6YG(')E<')E<V5N=&EN9R!T:&4@:V5Y(&]F('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYF:6=U<F%T:6]N(&%R<F%Y
M('1O(')E='5R;BX*("`@("`J($!P87)A;2!M:7AE9"`D9&5F875L="`@5&AE
M(&1E9F%U;'0@=F%L=64@=&\@<F5T=7)N(&EF('1H92!K97D@=V%S;B=T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&9O=6YD+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($5I=&AE<B!T:&4@=F%L=64@;V8@=&AE(&-O
M;F9I9W5R871I;VX@87)R87DG<R!R97%U97-T960*("`@("`J("`@("`@("`@
M("`@("`@(&ME>2!O<B!T:&4@9&5F875L="!V86QU92!I9B!T:&4@:V5Y('=A
M<VXG="!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E9F%U;'0H)&-T
M>"P@)&1E9F%U;'0I"B`@("!["B`@("`@("`@)&-T>"`](&5X<&QO9&4H)WPG
M+"`D8W1X*3L*("`@("`@("`D<'1R(#T@)'1H:7,M/E]C=7)R96YT0V]N9FEG
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1C='@I.R`D:2LK
M*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'!T<ELD8W1X6R1I75TI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)&1E9F%U;'0["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<'1R(#T@)'!T<ELD8W1X6R1I
M75T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES7W-T
M<FEN9R@D<'1R*2D@>PH@("`@("`@("`@("!R971U<FX@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D<'1R+"`G:7-O+3@X-3DM,2<I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D<'1R.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!C97)T86EN('9A;'5E(&9R;VT@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;B!F:6QE(&]R"B`@("`@*B!A(&1E
M9F%U;'0@=F%L=64L(&EF(&YO="!F;W5N9"X*("`@("`J($ET(&1O97,@3D]4
M(')E='5R;B!T:&4@86-T=6%L('9A;'5E+"!B=70@=&AE(%!(4"!E>'!R97-S
M:6]N(&%S('5S960*("`@("`J(&EN('1H92!C;VYF:6=U<F%T:6]N(&9I;&4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8W1X("`@("!!('-T<FEN9R!R97!R97-E;G1I;F<@
M=&AE(&ME>2!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N9FEG=7)A=&EO;B!A<G)A>2!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@
M;6EX960@)&1E9F%U;'0@(%1H92!D969A=6QT('9A;'5E('1O(')E='5R;B!I
M9B!T:&4@:V5Y('=A<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!F;W5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@
M=&AE('9A;'5E(&]F('1H92!C;VYF:6=U<F%T:6]N(&9I;&4G<R!R97%U97-T
M960*("`@("`J("`@("`@("`@("`@("`@(&ME>2!O<B!T:&4@9&5F875L="!V
M86QU92!I9B!T:&4@:V5Y('=A<VXG="!F;W5N9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V1E9F%U;'1287<H)&-T>"P@)&1E9F%U;'0I"B`@("!["B`@("`@
M("`@)&-T>"`](&5X<&QO9&4H)WPG+"`D8W1X*3L*("`@("`@("`D<&%T=&5R
M;B`]("<O7EPD8V]N9EQ;7"<G("X@:6UP;&]D92@B)UQ=7%LG(BP@)&-T>"D@
M+B`G7"=<72`]("@N*BD[)"]M)SL*("`@("`@("!I9B`H<')E9U]M871C:"@D
M<&%T=&5R;BP@)'1H:7,M/F=E=%!(4$-O;F9I9R@I+"`D;6%T8VAE<RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1M871C:&5S6S%=.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&1E9F%U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!C;VYT96YT(&]F(&%L;"!T97AT(&YO9&4@8VAI;&1R96X@
M;V8@=&AE('-P96-I9FEE9"!N;V1E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!$;VU.;V1E("1N;V1E("!!
M($1O;4YO9&4@;V)J96-T('=H;W-E('1E>'0@;F]D92!C:&EL9')E;B!T;R!R
M971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYC
M871E;F%T960@=F%L=65S(&]F(&%L;"!T97AT(&YO9&5S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T3F]D94]N;'E497AT*"1N;V1E*0H@("`@>PH@("`@
M("`@("1T97AT(#T@)R<["B`@("`@("`@:68@*"$D;F]D92T^:&%S7V-H:6QD
M7VYO9&5S*"DI('L*("`@("`@("`@("`@<F5T=7)N("1N;V1E+3YG971?8V]N
M=&5N="@I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;F]D92T^8VAI
M;&1?;F]D97,H*2!A<R`D=&YO9&4I('L*("`@("`@("`@("`@:68@*"1T;F]D
M92T^='EP92`]/2!834Q?5$585%].3T1%*2!["B`@("`@("`@("`@("`@("`D
M=&5X="`N/2`D=&YO9&4M/F-O;G1E;G0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<FEM*"1T97AT*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@87-S;V-I871I=F4@87)R87D@8V]N=&%I
M;FEN9R!A;&P@<&]S<VEB;&4@=F%L=65S(&]F('1H90H@("`@("H@<W!E8VEF
M:65D(#QC;VYF:6=E;G5M/B!T86<N"B`@("`@*B!4:&4@:V5Y<R!C;VYT86EN
M('1H92!A8W1U86P@96YU;2!V86QU97,@=VAI;&4@=&AE('9A;'5E<R!C;VYT
M86EN('1H96ER"B`@("`@*B!C;W)R97-P;VYD:6YG(&1E<V-R:7!T:6]N<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@1&]M3F]D92`D;F]D92`@5&AE($1O;4YO9&4@<F5P<F5S96YT871I
M;VX@;V8@=&AE(#QC;VYF:6=E;G5M/B!T86<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!W:&]S92!V86QU97,@<VAO=6QD(&)E(')E='5R;F5D+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%S<V]C:6%T:79E(&%R
M<F%Y('=I=&@@86QL('!O<W-I8FQE(&5N=6T@=F%L=65S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T16YU;59A;'5E<R@D;F]D92D*("`@('L*("`@("`@
M("`D=F%L=65S(#T@87)R87DH*3L*("`@("`@("!I9B`H(21N;V1E+3YH87-?
M8VAI;&1?;F]D97,H*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*
M("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&YO9&4M/F-H:6QD7VYO9&5S
M*"D@87,@)'9N;V1E*2!["B`@("`@("`@("`@(&EF("@D=FYO9&4M/G1Y<&4@
M/3T@6$U,7T5,14U%3E1?3D]$12`F)@H@("`@("`@("`@("`@("`@)'9N;V1E
M+3YT86=N86UE(#T]("=V86QU97,G*2!["B`@("`@("`@("`@("`@("!I9B`H
M(21V;F]D92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1V;F]D92T^8VAI;&1?;F]D97,H*2!A<R`D
M=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E+3YT>7!E
M(#T](%A-3%]%3$5-14Y47TY/1$4I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1V86QU92T^=&%G;F%M92`]/2`G8V]N9FEG<W!E8VEA;"<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VAA
M;F1L95-P96-I86QS*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("@D=F%L=64M/G1A9VYA;64@/3T@)W9A;'5E)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0@/2`D=F%L=64M/F=E=%]C
M;VYT96YT*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5S8R`]
M("1V86QU92T^9V5T7V%T=')I8G5T92@G9&5S8R<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9&5S8RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S6R1T97AT72`]("1D97-C
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S6R1T97AT72`]("1T
M97AT.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D=F%L=65S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(&UU;'1I9&EM96YS:6]N86P@87-S;V-I871I=F4@87)R87D@<F5P<F5S96YT
M:6YG('1H92!S<&5C:69I960*("`@("`J(#QC;VYF:6=S=VET8V@^('1A9RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@1&]M3F]D92`F)&YO9&4@(%1H92!$;VU.;V1E(')E<')E<V5N=&%T
M:6]N(&]F('1H92`\8V]N9FEG<W=I=&-H/@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!T86<@=&\@<')O8V5S<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!R97!R97-E;G1I;F<@
M=&AE(&YO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9713=VET8VA686QU
M97,H)B1N;V1E+"`D8W5R8W1X*0H@("`@>PH@("`@("`@(&EF("@A)&YO9&4M
M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@I.PH@("`@("`@('T*("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*("`@
M("`@("!F;W)E86-H("@D;F]D92T^8VAI;&1?;F]D97,H*2!A<R`D8V%S92D@
M>PH@("`@("`@("`@("!I9B`H)&-A<V4M/G1Y<&4@/3T@6$U,7T5,14U%3E1?
M3D]$12D@>PH@("`@("`@("`@("`@("`@)&YA;64@/2`D8V%S92T^9V5T7V%T
M=')I8G5T92@G;F%M92<I.PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD;F%M
M95T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD;F%M95U;
M)V1E<V,G72`]("1C87-E+3YG971?871T<FEB=71E*"=D97-C)RD["B`@("`@
M("`@("`@("`@("`D=F%L=65S6R1N86UE75LG9FEE;&1S)UT@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@:68@*"1C87-E+3YH87-?8VAI;&1?;F]D97,H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,979E;"@D
M=F%L=65S6R1N86UE75LG9FEE;&1S)UTL("1C87-E+3YC:&EL9%]N;V1E<R@I
M+"`D8W5R8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)'9A;'5E<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@87-S;V-I871I=F4@87)R87D@8V]N=&%I
M;FEN9R!T:&4@<&]S<VEB;&4@=F%L=65S(&]F(&$*("`@("`J(#QC;VYF:6=S
M<&5C:6%L/B!T86<@87,@=7-E9"!I;G-I9&4@;V8@96YU;2!C;VYF:6=U<F%T
M:6]N<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@1&]M3F]D92`D;F]D92`@5&AE($1O;4YO9&4@<F5P<F5S
M96YT871I;VX@;V8@=&AE(#QC;VYF:6=S<&5C:6%L/@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@('1A9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!P;W-S:6)L92!V
M86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H86YD;&53<&5C:6%L<R@D
M;F]D92D*("`@('L*("`@("`@("!S=VET8V@@*"1N;V1E+3YG971?871T<FEB
M=71E*"=N86UE)RDI('L*("`@("`@("!C87-E("=L:7-T+6AO<F1E+6%P<',G
M.@H@("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@("1A
M<'!S(#T@2&]R9&5?07)R87DZ.G9A;'5E<U1O2V5Y<R@D<F5G:7-T<GDM/FQI
M<W1!<'!S*&%R<F%Y*"=H:61D96XG+"`G;F]T;V]L8F%R)RP@)V%C=&EV92<I
M*2D["B`@("`@("`@("`@(&%S;W)T*"1A<'!S*3L*("`@("`@("`@("`@<F5T
M=7)N("1A<'!S.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M;&ES="UH;W)D92UL86YG=6%G97,G.@H@("`@("`@("`@("!G;&]B86P@)&YL
M<SL*("`@("`@("`@("`@<F5T=7)N("1N;'-;)VQA;F=U86=E<R==.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G;&ES="UB;&]C:W,G.@H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP)SL*("`@("`@("`@("`@)&-O;&QE8W1I;VX@/2`F2&]R9&5?0FQO
M8VM?0V]L;&5C=&EO;CHZ<VEN9VQE=&]N*"=P;W)T86PG*3L*("`@("`@("`@
M("`@<F5T=7)N("1C;VQL96-T:6]N+3YG971";&]C:W-,:7-T*"D["@H@("`@
M("`@(&-A<V4@)VQI<W0M8VQI96YT+69I96QD<R<Z"B`@("`@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@("1F(#T@87)R87DH*3L*("`@
M("`@("`@("`@:68@*"1R96=I<W1R>2T^:&%S365T:&]D*"=C;&EE;G1S+V=E
M=$-L:65N=%-O=7)C92<I*2!["B`@("`@("`@("`@("`@("`D861D<F5S<V)O
M;VL@/2`D<F5G:7-T<GDM/F-A;&PH)V-L:65N=',O9V5T0VQI96YT4V]U<F-E
M)RD["B`@("`@("`@("`@("`@("`D9FEE;&1S(#T@)')E9VES=')Y+3YC86QL
M*"=C;&EE;G1S+V9I96QD<R<L(&%R<F%Y*"1A9&1R97-S8F]O:RDI.PH@("`@
M("`@("`@("`@("`@:68@*"%I<U]A*"1F:65L9',L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEE;&1S(&%S("1F
M:65L9"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9ELD9FEE;&1;)VYA
M;64G75T@/2`D9FEE;&1;)VQA8F5L)UT["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B`D9CL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE('-P96-I9FEE9"!S=')I;F<@=VET:"!E<V-A<&5D('-I;F=L
M92!Q=6]T97,*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@($$@<W1R:6YG('1O(&5S
M8V%P92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-P96-I
M9FEE9"!S=')I;F<@=VET:"!S:6YG;&4@<75O=&5S(&)E:6YG(&5S8V%P960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]Q=6]T92@D<W1R:6YG*0H@("`@>PH@
M("`@("`@(')E='5R;B!S=')?<F5P;&%C92@B)R(L(")<)R(L("1S=')I;F<I
M.PH@("`@?0H*?0H*+RHJ"B`J($$@2&]R9&5?1F]R;3HZ(&9O<FT@=&AA="!I
M;7!L96UE;G1S(&$@=7-E<B!I;G1E<F9A8V4@9F]R('1H92!C;VYF:6<*("H@
M<WES=&5M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7T9R86UE=V]R:PH@*B\*8VQA<W,@0V]N9FEG1F]R;2!E>'1E;F1S
M($AO<F1E7T9O<FT@>PH*("`@("\J*@H@("`@("H@1&]N)W0@=7-E(&9O<FT@
M=&]K96YS(&9O<B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M("T@=VAI;&4*("`@
M("`J(&=E;F5R871I;F<@8V]N9FEG=7)A=&EO;B!I;F9O+"!T:&EN9W,@;&EK
M92!T:&4@5&]K96X@<WES=&5M"B`@("`@*B!M:6=H="!N;W0@=V]R:R!C;W)R
M96-T;'DN(%1H:7,@<V%V97,@<V]M92!H96%D86-H97,N"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W5S949O<FU4;VME
M;B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N=&%I;G,@=&AE($AO<F1E
M7T-O;F9I9R!O8FIE8W0@=&AA="!T:&ES(&9O<FT@<F5P<F5S96YT<RX*("`@
M("`J"B`@("`@*B!`=F%R($AO<F1E7T-O;F9I9PH@("`@("HO"B`@("!V87(@
M)%]X;6Q#;VYF:6<["@H@("`@+RHJ"B`@("`@*B!#;VYT86EN<R!T:&4@5F%R
M:6%B;&5S(&]B:F5C="!O9B!T:&ES(&9O<FTN"B`@("`@*@H@("`@("H@0'9A
M<B!687)I86)L97,*("`@("`J+PH@("`@=F%R("1?=F%R<SL*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!687)I
M86)L97,@)B1V87)S("!4:&4@5F%R:6%B;&5S(&]B:F5C="!O9B!T:&ES(&9O
M<FTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@("`@("`@("`@5&AE
M(&YA;64@;V8@=&AE(&%P<&QI8V%T:6]N('1H870@=&AI<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;F9I9W5R871I;VX@9F]R
M;2!I<R!F;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($-O;F9I9T9O<FTH)B1V
M87)S+"`D87!P*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?1F]R;2@D
M=F%R<RD["@H@("`@("`@("1T:&ES+3Y?>&UL0V]N9FEG(#T@)FYE=R!(;W)D
M95]#;VYF:6<H)&%P<"D["B`@("`@("`@)'1H:7,M/E]V87)S(#T@)B1V87)S
M.PH@("`@("`@("1C;VYF:6<@/2`D=&AI<RT^7WAM;$-O;F9I9RT^<F5A9%A-
M3$-O;F9I9R@I.PH@("`@("`@("1T:&ES+3YA9&1(:61D96XH)R<L("=A<'`G
M+"`G=&5X="<L('1R=64I.PH@("`@("`@("1T:&ES+3Y?8G5I;&1687)I86)L
M97,H)&-O;F9I9RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@=&AE
M(&9O<FT@8F%S960@;VX@=&AE('-P96-I9FEE9"!L979E;"!O9B!T:&4@8V]N
M9FEG=7)A=&EO;B!T<F5E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9FEG("`@5&AE('!O
M<G1I;VX@;V8@=&AE(&-O;F9I9W5R871I;VX@=')E92!F;W(@=&AA=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9F]R;2!F:65L9',@<VAO
M=6QD(&)E(&-R96%T960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F:7@@
M($$@<W1R:6YG(')E<')E<V5N=&EN9R!T:&4@8W5R<F5N="!P;W-I=&EO;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;G-I9&4@=&AE(&-O;F9I
M9W5R871I;VX@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD5F%R
M:6%B;&5S*"1C;VYF:6<L("1P<F5F:7@@/2`G)RD*("`@('L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1C;VYF:6<I*2!["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&-O;F9I9R!A<R`D;F%M92`]
M/B`D8V]N9FEG:71E;2D@>PH@("`@("`@("`@("`D<')E9FEX961N86UE(#T@
M96UP='DH)'!R969I>"D@/R`D;F%M92`Z("1P<F5F:7@@+B`G?"<@+B`D;F%M
M93L*("`@("`@("`@("`@)'9A<FYA;64@/2!S=')?<F5P;&%C92@G?"<L("=?
M7R<L("1P<F5F:7AE9&YA;64I.PH@("`@("`@("`@("`D9&5S8W)I<'1I;VX@
M/2!N=6QL.PH@("`@("`@("`@("!I9B`H)&-O;F9I9VET96T@/3T@)W!L86-E
M:&]L9&5R)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T@96QS96EF("AI<W-E="@D8V]N9FEG:71E;5LG=&%B)UTI*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T4V5C=&EO;B@D8V]N9FEG:71E;5LG
M=&%B)UTL("1C;VYF:6=I=&5M6R=D97-C)UTI.PH@("`@("`@("`@("!](&5L
M<V5I9B`H:7-S970H)&-O;F9I9VET96U;)W-W:71C:"==*2D@>PH@("`@("`@
M("`@("`@("`@)'-E;&5C=&5D(#T@)'1H:7,M/E]V87)S+3YG971%>&ES=',H
M)'9A<FYA;64L("1W87-S970I.PH@("`@("`@("`@("`@("`@)'9A<E]P87)A
M;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)'-E;&5C=%]O<'1I;VX@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@:68@*&ES7V)O;VPH)&-O;F9I9VET
M96U;)V1E9F%U;'0G72DI('L*("`@("`@("`@("`@("`@("`@("`D8V]N9FEG
M:71E;5LG9&5F875L="==(#T@)&-O;F9I9VET96U;)V1E9F%U;'0G72`_("=T
M<G5E)R`Z("=F86QS92<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D8V]N9FEG:71E;5LG<W=I=&-H)UT@87,@)&]P=&EO
M;B`]/B`D8V%S92D@>PH@("`@("`@("`@("`@("`@("`@("1V87)?<&%R86US
M6R1O<'1I;VY=(#T@)&-A<V5;)V1E<V,G73L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&]P=&EO;B`]/2`D8V]N9FEG:71E;5LG9&5F875L="==*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1S96QE8W1?;W!T:6]N(#T@9F%L<V4[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A)'=A<W-E="D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-E;&5C=&5D(#T@)&]P=&EO;CL*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V(#T@)B1T
M:&ES+3YA9&1687)I86)L92@D8V]N9FEG:71E;5LG9&5S8R==+"`D=F%R;F%M
M92P@)V5N=6TG+"!T<G5E+"!F86QS92P@;G5L;"P@87)R87DH)'9A<E]P87)A
M;7,L("1S96QE8W1?;W!T:6]N*2D["B`@("`@("`@("`@("`@("!I9B`H87)R
M87E?:V5Y7V5X:7-T<R@G9&5F875L="<L("1C;VYF:6=I=&5M*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1V+3YS971$969A=6QT*"1C;VYF:6=I=&5M6R=D
M969A=6QT)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'9?86-T:6]N(#T@)DAO<F1E7T9O<FU?06-T:6]N.CIF86-T;W)Y*"=R96QO
M860G*3L*("`@("`@("`@("`@("`@("1V+3YS971!8W1I;VXH)'9?86-T:6]N
M*3L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<V5L96-T960I("8F(&ES
M<V5T*"1C;VYF:6=I=&5M6R=S=VET8V@G75LD<V5L96-T961=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8G5I;&1687)I86)L97,H)&-O;F9I
M9VET96U;)W-W:71C:"==6R1S96QE8W1E9%U;)V9I96QD<R==+"`D<')E9FEX
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1C;VYF:6=I=&5M6R=?='EP92==*2D@>PH@("`@("`@("`@("`@("`@
M)')E<75I<F5D(#T@*&ES<V5T*"1C;VYF:6=I=&5M6R=R97%U:7)E9"==*2D@
M/R`D8V]N9FEG:71E;5LG<F5Q=6ER960G72`Z('1R=64["B`@("`@("`@("`@
M("`@("`D='EP92`]("1C;VYF:6=I=&5M6R=?='EP92==.PH@("`@("`@("`@
M("`@("`@:68@*"1T>7!E(#T]("=M=6QT:65N=6TG('Q\("1T>7!E(#T]("=H
M96%D97(G('Q\"B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/3T@)V1E<V-R
M:7!T:6]N)RD@>PH@("`@("`@("`@("`@("`@("`@("1R97%U:7)E9"`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1T
M>7!E(#T]("=M=6QT:65N=6TG('Q\("1T>7!E(#T]("=E;G5M)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1V87)?<&%R86US(#T@87)R87DH)&-O;F9I9VET
M96U;)W9A;'5E<R==*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'9A<E]P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=P:'`G
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G=&5X="<["B`@("`@
M("`@("`@("`@("`@("`@)&1E<V-R:7!T:6]N(#T@)T5N=&5R(&$@=F%L:60@
M4$A0(&5X<')E<W-I;VXN)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1V(#T@)B1T:&ES+3YA9&1687)I86)L92@D8V]N9FEG:71E;5LG
M9&5S8R==+"`D=F%R;F%M92P@)'1Y<&4L("1R97%U:7)E9"P@9F%L<V4L("1D
M97-C<FEP=&EO;BP@)'9A<E]P87)A;7,I.PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1C;VYF:6=I=&5M6R=D969A=6QT)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@)'8M/G-E=$1E9F%U;'0H)&-O;F9I9VET96U;)V1E9F%U;'0G
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V)U:6QD5F%R:6%B;&5S*"1C;VYF:6=I
M=&5M+"`D<')E9FEX961N86UE*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"GT*"F-L87-S($AO<F1E7T-O;F9I9U]$;V-U;65N="!E>'1E;F1S
M($AO<F1E7T-O;F9I9U].;V1E('L*"B`@("!F=6YC=&EO;B!F86-T;W)Y*"1F
M:6QE*0H@("`@>PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V1O;7AM
M;%]O<&5N7V9I;&4G*2D@>PH@("`@("`@("`@("!R971U<FX@9&]M>&UL7V]P
M96Y?9FEL92@D9FEL92D["B`@("`@("`@?2!E;'-E:68@*'9E<G-I;VY?8V]M
M<&%R92AP:'!V97)S:6]N*"DL("<U)RP@)SX])RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1D;V,@/2!N97<@2&]R9&5?0V]N9FEG7T1O8W5M96YT*"1F:6QE
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH
M)T1/32!S=7!P;W)T(&YO="!P<F5S96YT+B<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N($AO<F1E7T-O;F9I
M9U]$;V-U;65N="@D9FEL96YA;64I"B`@("!["B`@("`@("`@)'1H:7,M/FYO
M9&4@/2!N97<@1$]-1&]C=6UE;G0H*3L*("`@("`@("`D=&AI<RT^;F]D92T^
M;&]A9"@D9FEL96YA;64I.PH@("`@?0H*("`@(&9U;F-T:6]N(')O;W0H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D<F]O="`](&YE=R!(;W)D95]#;VYF:6=?
M16QE;65N="@D=&AI<RT^;F]D92T^9&]C=6UE;G1%;&5M96YT*3L*("`@('T*
M"GT*"F-L87-S($AO<F1E7T-O;F9I9U].;V1E('L*"B`@("!V87(@)&YO9&4[
M"@H@("`@9G5N8W1I;VX@2&]R9&5?0V]N9FEG7TYO9&4H)&%$;VU.;V1E*2![
M)'1H:7,M/FYO9&4])&%$;VU.;V1E.WT*"B`@("!F=6YC=&EO;B!?7V=E="@D
M;F%M92D*("`@('L*("`@("`@("!S=VET8V@@*"1N86UE*2!["B`@("`@("`@
M8V%S92`G='EP92<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;F]D92T^
M;F]D951Y<&4["@H@("`@("`@(&-A<V4@)W1A9VYA;64G.@H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FYO9&4M/G1A9TYA;64["@H@("`@("`@(&-A<V4@
M)V-O;G1E;G0G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/G1E
M>'1#;VYT96YT.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&-H:6QD
M7VYO9&5S*"D*("`@('L*("`@("`@("`D;F]D94QI<W0@/2`D=&AI<RT^;F]D
M92T^8VAI;&1.;V1E<SL*("`@("`@("`D;F]D95-E="`](&%R<F%Y*"D["B`@
M("`@("`@:68@*&ES<V5T*"1N;V1E3&ES="DI('L*("`@("`@("`@("`@)&D@
M/2`P.PH@("`@("`@("`@("!W:&EL92`H)&YO9&4@/2`D;F]D94QI<W0M/FET
M96TH)&DI*2!["B`@("`@("`@("`@("`@("`D;F]D95-E=%M=(#T@;F5W($AO
M<F1E7T-O;F9I9U]%;&5M96YT*"1N;V1E*3L*("`@("`@("`@("`@("`@("1I
M*RL["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1N
M;V1E4V5T.PH@("`@?0H*("`@(&9U;F-T:6]N(&9I<G-T7V-H:6QD*"D*("`@
M('L*("`@("`@("!R971U<FX@;F5W($AO<F1E7T-O;F9I9U]%;&5M96YT*"1T
M:&ES+3YN;V1E+3YF:7)S=$-H:6QD*3L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971?8V]N=&5N="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YN;V1E
M+3YT97AT0V]N=&5N=#L*("`@('T*"B`@("!F=6YC=&EO;B!H87-?8VAI;&1?
M;F]D97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F]D92T^:&%S
M0VAI;&1.;V1E<R@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&YE>'1?<VEB;&EN
M9R@I"B`@("!["B`@("`@("`@<F5T=7)N(&YE=R!(;W)D95]#;VYF:6=?16QE
M;65N="@D=&AI<RT^;F]D92T^;F5X=%-I8FQI;F<I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&YO9&5?=F%L=64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^;F]D92T^;F]D959A;'5E.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?0V]N
M9FEG7T5L96UE;G0@97AT96YD<R!(;W)D95]#;VYF:6=?3F]D92!["@H@("`@
M9G5N8W1I;VX@9V5T7V%T=')I8G5T92@D;F%M92D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/FYO9&4M/F=E=$%T=')I8G5T92@D;F%M92D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TAE;'`N<&AP````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-C4Q-P`Q,#0Q-S,V
M,C<W,P`P,3<V-#<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J*@H@*B!287<@:&5L<"!I;B!T:&4@<W1R:6YG
M+@H@*B\*9&5F:6YE*"=(14Q07U-/55)#15]205<G+"`P*3L*"B\J*@H@*B!(
M96QP('1E>'0@:7,@:6X@82!F:6QE+@H@*B\*9&5F:6YE*"=(14Q07U-/55)#
M15]&24Q%)RP@,2D["@HO*BH*("H@5&AE($AE;'`Z.B!C;&%S<R!P<F]V:61E
M<R!A;B!I;G1E<F9A8V4@=&\@=&AE(&]N;&EN92!H96QP('-U8G-Y<W1E;2X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`L
M=B`Q+C8X+C@N,3@@,C`P-B\P,R\P,B`P-3HR-SHS-2!S;'5S87)Z($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!087)I
M<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`
M<&%C:V%G92!(;W)D95]&<F%M97=O<FL*("HO"F-L87-S($AE;'`@>PH*("`@
M("\J*@H@("`@("H@2&%N9&QE(&9O<B!T:&4@6$U,('!A<G-E<B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@
M)%]P87)S97(@/2`P.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&)U9F9E<B!T
M;R!H;VQD('1H92!834P@:&5L<"!S;W5R8V4N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8G5F9F5R(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@240@;V8@=&AE(')E
M<75E<W1E9"!H96QP(&5N=')Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7W)E<45N=')Y(#T@)R<["@H@("`@+RHJ"B`@
M("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@240@;V8@=&AE(&-U<G)E;G0@
M:&5L<"!E;G1R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]C=7)%;G1R>2`]("<G.PH*("`@("\J*@H@("`@("H@4W1R
M:6YG(&-O;G1A:6YI;F<@=&AE(&9O<FUA='1E9"!O=71P=70N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;W5T<'5T(#T@
M)R<["@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE
M<B!W92=R92!I;G-I9&4@82`\:&5L<#X@8FQO8VLN"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VEN2&5L<"`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@
M=V4G<F4@:6YS:61E('1H92!R97%U97-T960@8FQO8VLN"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VEN0FQO8VL@/2!F
M86QS93L*"B`@("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T
M:&5R('=E)W)E(&EN<VED92!A(#QT:71L93X@8FQO8VLN"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VEN5&ET;&4@/2!F
M86QS93L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!A;B!I;F1E
M>"!O9B!A;&P@;V8@=&AE(&AE;'`@96YT<FEE<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V5N=')I97,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&-H87)S
M970@;V8@=&AE(%A-3"!D871A('-O=7)C92X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C:&%R<V5T(#T@)VES;RTX.#4Y
M+3$G.PH*("`@("\J*@H@("`@("H@2&%S:"!O9B!U<V5R+61E9FEN960@9G5N
M8W1I;VX@:&%N9&QE<G,@9F]R('1H92!834P@96QE;65N=',N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]H86YD;&5R<R`]
M(&%R<F%Y*`H@("`@("`@("=H96QP)R`@("`@/3X@("=?:&5L<$AA;F1L97(G
M+`H@("`@("`@("=E;G1R>2<@("`@/3X@("=?96YT<GE(86YD;&5R)RP*("`@
M("`@("`G=&ET;&4G("`@(#T^("`G7W1I=&QE2&%N9&QE<B<L"B`@("`@("`@
M)VAE861I;F<G("`]/B`@)U]H96%D:6YG2&%N9&QE<B<L"B`@("`@("`@)W!A
M<F$G("`@("`]/B`@)U]P87)A2&%N9&QE<B<L"B`@("`@("`@)W)E9B<@("`@
M("`]/B`@)U]R969(86YD;&5R)RP*("`@("`@("`G97)E9B<@("`@(#T^("`G
M7V5R969(86YD;&5R)RP*("`@("`@("`G:')E9B<@("`@(#T^("`G7VAR969(
M86YD;&5R)RP*("`@("`@("`G8B<@("`@("`@(#T^("`G7V)(86YD;&5R)RP*
M("`@("`@("`G:2<@("`@("`@(#T^("`G7VE(86YD;&5R)RP*("`@("`@("`G
M<')E)R`@("`@(#T^("`G7W!R94AA;F1L97(G+`H@("`@("`@("=T:7`G("`@
M("`@/3X@("=?=&EP2&%N9&QE<B<L"B`@("`@("`@)W=A<FXG("`@("`]/B`@
M)U]W87)N2&%N9&QE<B<*("`@("D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1S;W5R8V4@(%1H
M92!S;W5R8V4@;V8@=&AE(%A-3"!H96QP(&1A=&$L(&)A<V5D(&]N('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@2$5,4%]33U520T5?*B!C
M;VYS=&%N=',N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<F<@("`@("!3;W5R
M8V4M9&5P96YD96YT(&%R9W5M96YT(&9O<B!T:&ES($AE;'`*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;F-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!(96QP*"1S;W5R8V4L("1A<F<@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D;&%N9W5A9V4L("1N;',["@H@("`@("`@(&EF("@A571I
M;#HZ97AT96YS:6]N17AI<W1S*"=X;6PG*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<B@G5&AE(%A-3"!F=6YC=&EO;G,@
M87)E(&YO="!A=F%I;&%B;&4N(%)E8G5I;&0@4$A0('=I=&@@+2UW:71H+7AM
M;"XG*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7V-H87)S970@/2!I<W-E="@D;FQS6R=C:&%R<V5T
M<R==6R1L86YG=6%G95TI(#\@)&YL<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=
M(#H@)TE33RTX.#4Y+3$G.PH*("`@("`@("`O*B!0;W!U;&%T92`D=&AI<RT^
M7V)U9F9E<B!B87-E9"!O;B`D<V]U<F-E+B`J+PH@("`@("`@('-W:71C:"`H
M)'-O=7)C92D@>PH@("`@("`@(&-A<V4@2$5,4%]33U520T5?4D%7.@H@("`@
M("`@("`@("`D=&AI<RT^7V)U9F9E<B`]("1A<F<["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E($A%3%!?4T]54D-%7T9)3$4Z"B`@("`@("`@
M("`@(&EF("A`9FEL95]E>&ES=',H)&%R9ULP72D@)B8@0&9I;&5S:7IE*"1A
M<F=;,%TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V)U9F9E<B`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1A<F=;,%TI.PH@("`@("`@("`@("!](&5L<V5I
M9B`H0&9I;&5?97AI<W1S*"1A<F=;,5TI("8F($!F:6QE<VEZ92@D87)G6S%=
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B=69F97(@/2!F:6QE7V=E
M=%]C;VYT96YT<R@D87)G6S%=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8G5F9F5R(#T@)R<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("1T:&ES+3Y?8G5F9F5R(#T@)R<["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T
M:&4@2%1-3"!L:6YK('1H870@=VEL;"!P;W`@=7`@82!H96QP('=I;F1O=R!F
M;W(@=&AE"B`@("`@*B!R97%U97-T960@=&]P:6,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;6]D=6QE("!4:&4@;F%M92!O9B!T:&4@8W5R<F5N
M="!(;W)D92!M;V1U;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;W!I8R`@
M(%1H92!H96QP('1O<&EC('1O(&)E(&1I<W!L87EE9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@=&\@8W)E871E('1H92!H96QP
M(&QI;FLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;FLH)&UO9'5L92P@)'1O
M<&EC*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9BP@)')E9VES=')Y+"`D
M8G)O=W-E<CL*"B`@("`@("`@:68@*"%(;W)D93HZ<VAO=U-E<G9I8V4H)VAE
M;'`G*2D@>PH@("`@("`@("`@("!R971U<FX@)R9N8G-P.R<["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&)R;W=S97(M/FAA<T9E871U<F4H)VIA=F%S8W)I
M<'0G*2D@>PH@("`@("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G<&]P
M=7`N:G,G+"`G:&]R9&4G*3L*("`@("`@("!]"@H@("`@("`@("1U<FP@/2!(
M;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@
M+B`G+W-E<G9I8V5S+VAE;'`O)RP@=')U92D["B`@("`@("`@)'5R;"`](%5T
M:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!A<G)A>2@G;6]D=6QE)R`]/B`D;6]D
M=6QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1O<&EC)R`]/B`D=&]P:6,I*3L*("`@("`@("`D:'1M;"`]($AO
M<F1E.CIL:6YK*"1U<FPL(%\H(DAE;'`B*2P@)R<L("=H;W)D96AE;'!W:6XG
M+"`G<&]P=7`H=&AI<RYH<F5F*3L@<F5T=7)N(&9A;'-E.R<I.PH*("`@("`@
M("!R971U<FX@)&AT;6P@+B!(;W)D93HZ:6UG*"=H96QP+G!N9R<L(%\H(DAE
M;'`B*2P@)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(G+"`D<F5G:7-T<GDM/F=E
M=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)SL*("`@('T*"B`@("`O*BH*
M("`@("`J($-L96%N<R!U<"!T:&4@2&5L<"!C;&%S<R!R97-O=7)C97,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VQE86YU<"@I"B`@("!["B`@("`@("`@)'1H:7,M/E]B=69F97(@/2`G
M)SL*("`@("`@("!R971U<FX@>&UL7W!A<G-E<E]F<F5E*"1T:&ES+3Y?<&%R
M<V5R*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO;VMS('5P('1H92!R97%U
M97-T960@96YT<GD@:6X@=&AE(%A-3"!H96QP(&)U9F9E<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1E;G1R>2`@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&5N=')Y($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V]K=7`H)&5N
M=')Y*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W5T<'5T(#T@)R<["B`@("`@
M("`@)'1H:7,M/E]R97%%;G1R>2`](%-T<FEN9SHZ=7!P97(H)&5N=')Y*3L*
M("`@("`@("!I9B`H(21T:&ES+3Y?<&%R<V5R*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?:6YI="@I.PH@("`@("`@('T*("`@("`@("!X;6Q?<&%R<V4H)'1H
M:7,M/E]P87)S97(L("1T:&ES+3Y?8G5F9F5R+"!T<G5E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H(&]F(&%L;"!O9B!T:&4@=&]P
M:6-S(&EN('1H:7,@:&5L<"!B=69F97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@2&%S:"!O9B!A;&P@;V8@=&AE('1O<&EC<R!I;B!T:&ES(&)U
M9F9E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@=&]P:6-S*"D*("`@('L*("`@
M("`@("!I9B`H(21T:&ES+3Y?<&%R<V5R*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?:6YI="@I.PH@("`@("`@('T*("`@("`@("!X;6Q?<&%R<V4H)'1H:7,M
M/E]P87)S97(L("1T:&ES+3Y?8G5F9F5R+"!T<G5E*3L*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?96YT<FEE<SL*("`@('T*"B`@("`O*BH*("`@("`J($1I
M<W!L87D@=&AE(&-O;G1E;G1S(&]F('1H92!F;W)M871T960@;W5T<'5T(&)U
M9F9E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES<&QA>2@I"B`@("!["B`@
M("`@("`@96-H;R`D=&AI<RT^7V]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($EN:71I86QZ97,@=&AE(%A-3"!P87)S97(N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!2971U<FYS('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:70H*0H@("`@>PH@("`@("`@("\J
M($-R96%T92!A(&YE=R!P87)S97(@86YD('-E="!I=',@9&5F875L="!P<F]P
M97)T:65S+B`J+PH@("`@("`@("1T:&ES+3Y?<&%R<V5R(#T@>&UL7W!A<G-E
M<E]C<F5A=&4H*3L*("`@("`@("!X;6Q?<V5T7V]B:F5C="@D=&AI<RT^7W!A
M<G-E<BP@)'1H:7,I.PH@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO;B@D
M=&AI<RT^7W!A<G-E<BP@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L(&9A;'-E
M*3L*("`@("`@("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D=&AI<RT^7W!A
M<G-E<BP@)U]S=&%R=$5L96UE;G0G+"`G7V5N9$5L96UE;G0G*3L*("`@("`@
M("!X;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'1H:7,M/E]P87)S
M97(L("=?9&5F875L=$AA;F1L97(G*3L*"B`@("`@("`@<F5T=7)N("@D=&AI
M<RT^7W!A<G-E<B`A/2`P*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5S97(M
M9&5F:6YE9"!F=6YC=&EO;B!C86QL8F%C:R!F;W(@<W1A<G0@96QE;65N=',N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&]B:F5C="`D<&%R<V5R("!(86YD;&4@=&\@=&AE('!A<G-E<B!I
M;G-T86YC92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&YA
M;64@;V8@=&AI<R!834P@96QE;65N="X*("`@("`J($!P87)A;2!A<G)A>2`D
M871T<G,@("`@3&ES="!O9B!T:&ES(&5L96UE;G0G<R!A='1R:6)U=&5S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<W1A<G1%;&5M96YT*"1P87)S97(L("1N
M86UE+"`D871T<G,I"B`@("!["B`@("`@("`@+RH@0V%L;"!T:&4@87-S:6=N
M960@:&%N9&QE<B!F;W(@=&AI<R!E;&5M96YT+"!I9B!O;F4@:7,*("`@("`@
M("`@*B!A=F%I;&%B;&4N("HO"B`@("`@("`@:68@*&EN7V%R<F%Y*"1N86UE
M+"!A<G)A>5]K97ES*"1T:&ES+3Y?:&%N9&QE<G,I*2D@>PH@("`@("`@("`@
M("!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H:7,L("1T:&ES+3Y?:&%N9&QE
M<G-;)&YA;65=*2P@=')U92P@)&%T=')S*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!5<V5R+61E9FEN960@9G5N8W1I;VX@8V%L;&)A8VL@
M9F]R(&5N9"!E;&5M96YT<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1P87)S97(@($AA;F1L
M92!T;R!T:&4@<&%R<V5R(&EN<W1A;F-E+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("!4:&4@;F%M92!O9B!T:&ES(%A-3"!E;&5M96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?96YD16QE;65N="@D<&%R<V5R+"`D;F%M92D*
M("`@('L*("`@("`@("`O*B!#86QL('1H92!A<W-I9VYE9"!H86YD;&5R(&9O
M<B!T:&ES(&5L96UE;G0L(&EF(&]N92!I<R!A=F%I;&%B;&4N("HO"B`@("`@
M("`@:68@*&EN7V%R<F%Y*"1N86UE+"!A<G)A>5]K97ES*"1T:&ES+3Y?:&%N
M9&QE<G,I*2D@>PH@("`@("`@("`@("!C86QL7W5S97)?9G5N8RAA<G)A>2@F
M)'1H:7,L("1T:&ES+3Y?:&%N9&QE<G-;)&YA;65=*2P@9F%L<V4I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5S97(M9&5F:6YE9"!F=6YC
M=&EO;B!C86QL8F%C:R!F;W(@8VAA<F%C=&5R(&1A=&$N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C
M="`D<&%R<V5R("!(86YD;&4@=&\@=&AE('!A<G-E<B!I;G-T86YC92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@4W1R:6YG(&]F(&-H87)A8W1E
M<B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5F875L=$AA;F1L97(H
M)'!A<G-E<BP@)&1A=&$I"B`@("!["B`@("`@("`@)&1A=&$@/2!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1D871A+"!V97)S:6]N7V-O;7!A<F4H>F5N9%]V
M97)S:6]N*"DL("<R)RP@)SPG*2`_("1T:&ES+3Y?8VAA<G-E="`Z("=55$8M
M."<I.PH@("`@("`@(&EF("@D=&AI<RT^7VEN5&ET;&4I('L*("`@("`@("`@
M("`@)'1H:7,M/E]E;G1R:65S6R1T:&ES+3Y?8W5R16YT<GE=("X]("1D871A
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H
M:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]
M(&AT;6QS<&5C:6%L8VAA<G,H)&1A=&$I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\:&5L
M<#X@=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I
M8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A
M;2!A<G)A>2`D871T<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I
M8G5T97,@*$YO="!U<V5D*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7VAE;'!(
M86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D=&AI<RT^7VEN2&5L<"`]("1S=&%R=%1A9R`_("!T<G5E(#H@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@96QE;65N="!H86YD;&5R
M(&9O<B!T:&4@/&5N=')Y/B!T86<N"B`@("`@*B!!='1R:6)U=&5S.B!I9`H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H
M971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D
M871T<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]E;G1R>4AA;F1L97(H)'-T87)T5&%G+"`D
M871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A)'-T87)T5&%G
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6Y";&]C:R`](&9A;'-E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1I9"`](%-T<FEN9SHZ=7!P97(H
M)&%T=')S6R=I9"==*3L*("`@("`@("`@("`@)'1H:7,M/E]C=7)%;G1R>2`]
M("1I9#L*("`@("`@("`@("`@)'1H:7,M/E]E;G1R:65S6R1I9%T@/2`G)SL*
M("`@("`@("`@("`@)'1H:7,M/E]I;D)L;V-K(#T@*"1I9"`]/2`D=&AI<RT^
M7W)E<45N=')Y*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!8
M34P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@/'1I=&QE/B!T86<N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE
M<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R
M<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<R`H3F]T('5S
M960I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&5(86YD;&5R*"1S=&%R
M=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^
M7VEN5&ET;&4@/2`D<W1A<G1486<["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(
M96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7V]U='!U="`N/2`D<W1A<G1486<@/R`G/&@Q/B<@.B`G/"]H,3XG.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L
M97(@9F]R('1H92`\:&5A9&EN9SX@=&%G+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R
M=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC
M92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T
M('1A9RX*("`@("`J($!P87)A;2`@87)R87D@)&%T=')S("`@("`@061D:71I
M;VYA;"!E;&5M96YT(&%T=')I8G5T97,@*$YO="!U<V5D*2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VAE861I;F=(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@
M)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T("X]("1S=&%R=%1A9R`_("<\:#(^)R`Z("<\+V@R/B<["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F
M;W(@=&AE(#QP87)A/B!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!"
M;V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@("!!9&1I=&EO;F%L(&5L
M96UE;G0@871T<FEB=71E<R`H3F]T('5S960I+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&%R84AA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^
M7VEN0FQO8VLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'-T
M87)T5&%G(#\@)SQP/B<@.B`G/"]P/B<["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QR968^
M('1A9RX*("`@("`J(%)E<75I<F5D(&%T=')I8G5T97,Z($5.5%)9+"!-3T15
M3$4*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN
M9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R
M87D@)&%T=')S("`@("`@($%D9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5F2&%N9&QE<B@D<W1A<G1486<L
M("1A='1R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?
M:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("!I9B`H
M)'-T87)T5&%G("8F(&ES<V5T*"1A='1R<ULG;6]D=6QE)UTI("8F(&ES<V5T
M*"1A='1R<ULG96YT<GDG72DI('L*("`@("`@("`@("`@("`@("1U<FP@/2!5
M=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G-E;&95<FPH*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W-H;W<G
M(#T^("=E;G1R>2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=M;V1U;&4G(#T^("1A='1R<ULG;6]D=6QE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T;W!I8R<@(#T^("1A='1R<ULG96YT<GDG72DI.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@2&]R9&4Z.FQI;FLH)'5R;"D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U="`N/2`G/"]A/B<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@
M/&5R968^('1A9RX*("`@("`J(%)E<75I<F5D(&5L96UE;G1S.B!54DP*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T
M:&5R('1H:7,@:6YS=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T
M=')S("`@("`@($%D9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?97)E9DAA;F1L97(H)'-T87)T5&%G+"`D871T
M<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L
M<"`F)B`D=&AI<RT^7VEN0FQO8VLI('L*("`@("`@("`@("`@:68@*"1S=&%R
M=%1A9RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@2&]R
M9&4Z.FQI;FLH)&%T=')S6R=U<FPG72P@;G5L;"P@)R<L("=?8FQA;FLG*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T<'5T("X]("<\+V$^)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H
M92`\:')E9CX@=&%G+@H@("`@("H@4F5Q=6ER960@96QE;65N=',Z('5R;"P@
M87!P+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T
M:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A
M<G)A>2`D871T<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H<F5F2&%N9&QE<B@D<W1A<G14
M86<L("1A='1R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("!I
M9B`H)'-T87)T5&%G*2!["B`@("`@("`@("`@("`@("!G;&]B86P@)')E9VES
M=')Y.PH@("`@("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)')E9VES
M=')Y+3YG970H)W=E8G)O;W0G+"`D871T<G-;)V%P<"==*2`N("<O)R`N("1A
M='1R<ULG=7)L)UTI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@
M+CT@2&]R9&4Z.FQI;FLH)'5R;"P@;G5L;"P@)R<L("=?8FQA;FLG*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T("X]("<\+V$^)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`F
M;'0[8B9G=#L@=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A
M;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@("`J
M($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT
M(&%T=')I8G5T97,@*$YO="!U<V5D*2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V)(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1S=&%R=%1A9R`_
M("<\<W1R;VYG/B<@.B`G/"]S=')O;F<^)SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@)FQT
M.VDF9W0[('1A9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A<G1486<@($)O;VQE86X@
M:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@:7,@80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%R="!T86<N"B`@("`@*B!`
M<&%R86T@87)R87D@)&%T=')S("`@("`@($%D9&ET:6]N86P@96QE;65N="!A
M='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:4AA;F1L97(H)'-T
M87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI('L*("`@("`@("`@
M("`@)'1H:7,M/E]O=71P=70@+CT@)'-T87)T5&%G(#\@)SQE;3XG(#H@)SPO
M96T^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@96QE
M;65N="!H86YD;&5R(&9O<B!T:&4@)FQT.W!R929G=#L@=&%G+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@
M=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@
M("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]P<F5(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@
M)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X]("1S=&%R=%1A9R`_("<\<')E/B<@.B`G/"]P<F4^)SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@96QE;65N="!H86YD;&5R(&9O
M<B!T:&4@/'1I<#X@=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O
M;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@
M("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@061D:71I;VYA;"!E;&5M
M96YT(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:7!(86YD
M;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1S=&%R=%1A9R`_("<\96T@
M8VQA<W,](FAE;'!4:7`B/B<@.B`G/"]E;3XG.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\
M=V%R;CX@=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I
M;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P
M87)A;2!A<G)A>2`D871T<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T
M=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]W87)N2&%N9&QE<B@D
M<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@
M("`@("`D=&AI<RT^7V]U='!U="`N/2`D<W1A<G1486<@/R`G/&5M(&-L87-S
M/2)H96QP5V%R;B(^)R`Z("<\+V5M/B<["B`@("`@("`@?0H@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-96YU+G!H<```````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C0V-38`,3`T
M,3<S-C(W-S,`,#$W-C8T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@ID969I;F4H)TA/4D1%7TU%3E5?4$]37TQ!
M4U0G+"`Y.3DI.PH*9&5F:6YE*"=(3U)$15]-14Y57TU!4TM?3D].12<L("`@
M("`P*3L*9&5F:6YE*"=(3U)$15]-14Y57TU!4TM?2$5,4"<L("`@("`Q*3L*
M9&5F:6YE*"=(3U)$15]-14Y57TU!4TM?3$]'24XG+"`@("`R*3L*9&5F:6YE
M*"=(3U)$15]-14Y57TU!4TM?4%)%1E,G+"`@("`T*3L*9&5F:6YE*"=(3U)$
M15]-14Y57TU!4TM?4%)/0DQ%32<L("`X*3L*9&5F:6YE*"=(3U)$15]-14Y5
M7TU!4TM?04Q,)RP@("`@(#$U*3L*"B\J*@H@*B!4:&4@365N=3HZ(&-L87-S
M('!R;W9I9&5S('-T86YD87)D:7IE9"!M971H;V1S(&9O<B!C<F5A=&EN9R!M
M96YU<R!I;@H@*B!(;W)D92!A<'!L:6-A=&EO;G,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP+'8@,2XS-2XR+C$P(#(P
M,#8O,#$O,#$@,C$Z,C@Z,C`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ
M;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA
M9V4@2&]R9&5?1G)A;65W;W)K"B`J+PIC;&%S<R!-96YU('L*"B`@("`O*BH*
M("`@("`J($UE;G4@87)R87DN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]M96YU(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($UA<VL@9&5F:6YI;F<@=VAA="!G96YE<F%L($AO<F1E(&QI;FMS(&%R
M92!S:&]W;B!I;B!T:&ES($UE;G4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D7VUA<VL["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!-96YU*"1M87-K(#T@
M2$]21$5?345.55]-05-+7T%,3"D*("`@('L*("`@("`@("`O*B!-96YU:71E
M;2!M87-K+B`J+PH@("`@("`@("1T:&ES+3Y?;6%S:R`]("1M87-K.PH*("`@
M("`@("`O*B!,;V-A=&EO;B!O9B!T:&4@;65N=69I;&4N("HO"B`@("`@("`@
M)'1H:7,M/E]M96YU9FEL92`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)V9I;&5R;V]T)RD@+B`G+V-O;F9I9R]M96YU+G!H<"<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&0@86X@:71E;2!T;R!T:&4@;65N=2!A<G)A>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@("`@(%-T<FEN9R!C
M;VYT86EN:6YG('1H92!V86QU92!F;W(@=&AE(&AY<&5R;&EN:RX*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&QA8F5L(&9O<B!T:&ES(&UE;G4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@)&EC;VX@
M("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9I;&5N86UE(&]F('1H92!I
M;6%G90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!I8V]N('1O
M(&1I<W!L87D@9F]R('1H:7,@;65N=2!I=&5M+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:6-O;E]P871H("!)9B!T:&4@:6-O;B!L:79E<R!I;B!A(&YO;BUD
M969A=6QT(&1I<F5C=&]R>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=VAE<F4@:7,@:70_"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87)G
M970@("`@($EF('1H92!L:6YK(&YE961S('1O(&]P96X@:6X@86YO=&AE<B!F
M<F%M92!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!W:6YD
M;W<L('=H870@:7,@:71S(&YA;64_"B`@("`@*B!`<&%R86T@<W1R:6YG("1O
M;F-L:6-K("`@($]N8VQI8VL@:F%V87-C<FEP="P@:68@9&5S:7)E9"X*("`@
M("`J($!P87)A;2!S=')I;F<@)&-L87-S("`@("`@0U-3(&-L87-S(&9O<B!T
M:&4@;65N=2!I=&5M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5&AE(&ED("A.3U0@9W5A<F%N=&5E9"!T;R!B92!A;B!A<G)A>2!I;F1E>"D@
M;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@(&ET96T@:G5S="!A9&1E
M9"!T;R!T:&4@;65N=2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1U<FPL
M("1T97AT+"`D:6-O;B`]("<G+"`D:6-O;E]P871H(#T@;G5L;"P*("`@("`@
M("`@("`@("`@("`D=&%R9V5T(#T@)R<L("1O;F-L:6-K(#T@;G5L;"P@)&-L
M87-S(#T@;G5L;"D*("`@('L*("`@("`@("`D<&]S(#T@8V]U;G0H)'1H:7,M
M/E]M96YU*3L*("`@("`@("!I9B`H(21P;W,@?'P@*"1P;W,@+2`Q("$](&UA
M>"AA<G)A>5]K97ES*"1T:&ES+3Y?;65N=2DI*2D@>PH@("`@("`@("`@("`D
M<&]S(#T@8V]U;G0H)'1H:7,M/E]M96YU*3L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?;65N=5LD<&]S72`]"B`@("`@("`@("`@(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@)W5R;"<@/3X@)'5R;"P*("`@("`@("`@("`@("`@("=T
M97AT)R`]/B`D=&5X="P*("`@("`@("`@("`@("`@("=I8V]N)R`]/B`D:6-O
M;BP*("`@("`@("`@("`@("`@("=I8V]N7W!A=&@G(#T^("1I8V]N7W!A=&@L
M"B`@("`@("`@("`@("`@("`G=&%R9V5T)R`]/B`D=&%R9V5T+`H@("`@("`@
M("`@("`@("`@)V]N8VQI8VLG(#T^("1O;F-L:6-K+`H@("`@("`@("`@("`@
M("`@)V-L87-S)R`]/B`D8VQA<W,*("`@("`@("`@("`@*3L*"B`@("`@("`@
M<F5T=7)N("1P;W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86X@:71E
M;2!T;R!T:&4@;65N=2!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<FP@("`@("`@(%-T<FEN9R!C;VYT86EN:6YG('1H92!V86QU92!F
M;W(@=&AE(&AY<&5R;&EN:RX*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@
M("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&QA8F5L(&9O<B!T:&ES(&UE
M;G4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@:71E;2X*("`@
M("`J($!P87)A;2!S=')I;F<@)&EC;VX@("`@("`@4W1R:6YG(&-O;G1A:6YI
M;F<@=&AE(&9I;&5N86UE(&]F('1H92!I;6%G90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I8V]N('1O(&1I<W!L87D@9F]R('1H:7,@;65N
M=2!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6-O;E]P871H("!)9B!T
M:&4@:6-O;B!L:79E<R!I;B!A(&YO;BUD969A=6QT(&1I<F5C=&]R>2P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=VAE<F4@:7,@:70_"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T87)G970@("`@($EF('1H92!L:6YK(&YE
M961S('1O(&]P96X@:6X@86YO=&AE<B!F<F%M92!O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!W:6YD;W<L('=H870@:7,@:71S(&YA;64_
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;F-L:6-K("`@($]N8VQI8VL@:F%V
M87-C<FEP="P@:68@9&5S:7)E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-L
M87-S("`@("`@0U-3(&-L87-S(&9O<B!T:&4@;65N=2!I=&5M+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&ED("A.3U0@9W5A<F%N=&5E
M9"!T;R!B92!A;B!A<G)A>2!I;F1E>"D@;V8@=&AE(&ET96T*("`@("`J("`@
M("`@("`@("`@("`@("`@:G5S="!A9&1E9"!T;R!T:&4@;65N=2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D07)R87DH)&ET96TI"B`@("!["B`@("`@("`@
M)'!O<R`](&-O=6YT*"1T:&ES+3Y?;65N=2D["B`@("`@("`@:68@*"$D<&]S
M('Q\("@D<&]S("T@,2`A/2!M87@H87)R87E?:V5Y<R@D=&AI<RT^7VUE;G4I
M*2DI('L*("`@("`@("`@("`@)'!O<R`](&-O=6YT*"1T:&ES+3Y?;65N=2D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VUE;G5;)'!O<UT@/2`D:71E
M;3L*"B`@("`@("`@<F5T=7)N("1P;W,["B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T4&]S:71I;VXH)&ED+"`D<&]S*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]M96YU6R1I9%TI('Q\(&ES<V5T*"1T:&ES+3Y?;65N=5LD
M<&]S72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)&ET96T@/2`D=&AI<RT^7VUE;G5;)&ED73L*("`@("`@("!U
M;G-E="@D=&AI<RT^7VUE;G5;)&ED72D["B`@("`@("`@)'1H:7,M/E]M96YU
M6R1P;W-=(#T@)&ET96T["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!U;F]R9&5R960@;&ES="!R97!R
M97-E;G1I;F<@=&AE(&QI<W0@;V8@;65N=2!I=&5M<RX@4W1Y;&EN9PH@("`@
M("H@:7,@9&]N92!T:')O=6=H($-34RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@06X@=6YO<F1E<F5D(&QI<W0@;V8@;65N=2!E;&5M96YT<R!T
M:&%T(&-A;B!B92!E;G1I<F5L>0H@("`@("H@("`@("`@("`@("`@("`@('-T
M>6QE9"!W:71H($-34RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"D*
M("`@('L*("`@("`@("!G;&]B86P@)&-O;F8L("1R96=I<W1R>2P@)'!R969S
M.PH*("`@("`@("`D9W)A<&AI8W,@/2`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I.PH@("`@("`@("1A<'`@/2`D<F5G:7-T<GDM/F=E=$%P<"@I
M.PH*("`@("`@("!I9B`H)'1H:7,M/E]M87-K("$]/2!(3U)$15]-14Y57TU!
M4TM?3D].12D@>PH@("`@("`@("`@("`O*B!!9&0@86YY(&-U<W1O;2!M96YU
M(&ET96US+B`J+PH@("`@("`@("`@("`D=&AI<RT^861D4VET94QI;FMS*"D[
M"@H@("`@("`@("`@("`O*B!!9&0@86YY(&%P<"!M96YU(&ET96US+B`J+PH@
M("`@("`@("`@("`D=&AI<RT^861D07!P3&EN:W,H*3L*("`@("`@("!]"@H@
M("`@("`@("\J($%D9"!S971T:6YG<R!L:6YK+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^7VUA<VL@)B!(3U)$15]-14Y57TU!4TM?4%)%1E,@)B8@)'5R;"`]
M($AO<F1E.CIG971397)V:6-E3&EN:R@G;W!T:6]N<R<L("1A<'`I*2!["B`@
M("`@("`@("`@("1T:&ES+3YA9&0H)'5R;"P@7R@B7T]P=&EO;G,B*2P@)W!R
M969S+G!N9R<L("1G<F%P:&EC<RD["B`@("`@("`@?0H*("`@("`@("`O*B!!
M9&0@<')O8FQE;2!L:6YK+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7VUA<VL@
M)B!(3U)$15]-14Y57TU!4TM?4%)/0DQ%32`F)B`D<')O8FQE;5]L:6YK(#T@
M2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=P<F]B;&5M)RP@)&%P<"DI('L*("`@
M("`@("`@("`@)'1H:7,M/F%D9"@D<')O8FQE;5]L:6YK+"!?*")0<F]B;&5M
M(BDL("=P<F]B;&5M+G!N9R<L("1G<F%P:&EC<RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!!9&0@:&5L<"!L:6YK+B`J+PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O2&5L<"YP:'`G.PH@("`@("`@(&EF("@D=&AI<RT^7VUA<VL@
M)B!(3U)$15]-14Y57TU!4TM?2$5,4"`F)B`D:&5L<%]L:6YK(#T@2&]R9&4Z
M.F=E=%-E<G9I8V5,:6YK*"=H96QP)RP@)&%P<"DI('L*("`@("`@("`@("`@
M)'1H:7,M/F%D9"@D:&5L<%]L:6YK+"!?*")?2&5L<"(I+"`G:&5L<%]I;F1E
M>"YP;F<G+"`D9W)A<&AI8W,L("=H96QP)RP@)W!O<'5P*'1H:7,N:')E9BD[
M(')E='5R;B!F86QS93LG*3L*("`@("`@("!]"@H@("`@("`@("\J($QO9VEN
M+TQO9V]U="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]M87-K("8@2$]21$5?
M345.55]-05-+7TQ/1TE.*2!["B`@("`@("`@("`@("\J($EF('1H92!S:61E
M8F%R(&ES;B=T(&%L=V%Y<R!S:&]W;BP@8G5T(&ES('-O;65T:6UE<PH@("`@
M("`@("`@("`@*B!S:&]W;BP@=&AE;B!L;V=O=70@;&EN:W,@<VAO=6QD(&)E
M('1O('1H92!P87)E;G0*("`@("`@("`@("`@("H@9G)A;64N("HO"B`@("`@
M("`@("`@("1A=71H7W1A<F=E="`](&YU;&P["B`@("`@("`@("`@(&EF("@D
M8V]N9ELG;65N=2==6R=A;'=A>7,G72!\?"`D<')E9G,M/F=E=%9A;'5E*"=S
M:&]W7W-I9&5B87(G*2D@>PH@("`@("`@("`@("`@("`@)&%U=&A?=&%R9V5T
M(#T@)U]P87)E;G0G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M075T:#HZ9V5T075T:"@I*2!["B`@("`@("`@("`@("`@("!I9B`H)&QO9V]U
M=%]L:6YK(#T@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=L;V=O=70G+"`D87!P
M+"`A)'!R969S+3YG971686QU92@G<VAO=U]S:61E8F%R)RDI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F%D9"@D;&]G;W5T7VQI;FLL(%\H(E],
M;V<@;W5T(BDL("=L;V=O=70N<&YG)RP@)&=R87!H:6-S+"`D875T:%]T87)G
M970L(&YU;&PL("=?7VYO<V5L96-T:6]N)RD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H)&QO
M9VEN7VQI;FL@/2!(;W)D93HZ9V5T4V5R=FEC94QI;FLH)VQO9VEN)RP@)&%P
M<"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1L;V=I;E]L
M:6YK+"!?*")?3&]G(&EN(BDL("=L;V=I;BYP;F<G+"`D9W)A<&AI8W,L("1A
M=71H7W1A<F=E="P@;G5L;"P@)U]?;F]S96QE8W1I;VXG*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M3F\@;F5E9"!T;R!R971U<FX@86X@96UP='D@;&ES="!I9B!T:&5R92!A<F4@
M;F\@;65N=0H@("`@("`@("`J(&ET96US+B`J+PH@("`@("`@(&EF("@A8V]U
M;G0H)'1H:7,M/E]M96YU*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@
M("`@("`@?0H*("`@("`@("`O*B!3;W)T('1O(&UA=&-H(&5X<&QI8VET;'D@
M<V5T('!O<VET:6]N<RX@*B\*("`@("`@("!K<V]R="@D=&AI<RT^7VUE;G4I
M.PH@("`@("`@(&EF("@A96UP='DH)$=,3T)!3%-;)VYL<R==6R=R=&PG75LD
M1TQ/0D%,4ULG;&%N9W5A9V4G75TI*2`@>PH@("`@("`@("`@("`D=&AI<RT^
M7VUE;G4@/2!A<G)A>5]R979E<G-E*"1T:&ES+3Y?;65N=2D@.PH@("`@("`@
M('T*"B`@("`@("`@)&UE;G5?=FEE=R`]("1P<F5F<RT^9V5T5F%L=64H)VUE
M;G5?=FEE=R<I.PH@("`@("`@("1O=71P=70@/2`G/'5L/B<["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]M96YU(&%S("1M*2!["B`@("`@("`@("`@("\J
M($ET96T@8VQA<W,@86YD('-E;&5C=&5D(&EN9&EC871I;VXN("HO"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&U;)V-L87-S)UTI*2!["B`@("`@("`@("`@
M("`@("`O*B!4<GD@=&\@;6%T8V@@=&AE(&ET96TG<R!P871H(&%G86EN<W0@
M=&AE(&-U<G)E;G0*("`@("`@("`@("`@("`@("`J('-C<FEP="!F:6QE;F%M
M92!A<R!W96QL(&%S(&]T:&5R('!O<W-I8FQE(%523',@=&\*("`@("`@("`@
M("`@("`@("`J('1H:7,@<V-R:7!T+B`J+PH@("`@("`@("`@("`@("`@:68@
M*$UE;G4Z.FES4V5L96-T960H)&U;)W5R;"==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1M6R=C;&%S<R==(#T@)V-U<G)E;G0G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)&U;)V-L87-S)UT@/3T]("=?
M7VYO<V5L96-T:6]N)RD@>PH@("`@("`@("`@("`@("`@=6YS970H)&U;)V-L
M87-S)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)8V]N+B`J
M+PH@("`@("`@("`@("`D:6-O;B`]("<G.PH@("`@("`@("`@("!I9B`H)&UE
M;G5?=FEE=R`]/2`G:6-O;B<@?'P@)&UE;G5?=FEE=R`]/2`G8F]T:"<I('L*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&U;)VEC;VY?<&%T:"==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1M6R=I8V]N7W!A=&@G72`](&YU;&P[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:6-O;B`]($AO
M<F1E.CII;6<H)&U;)VEC;VXG72P@2&]R9&4Z.G-T<FEP06-C97-S2V5Y*"1M
M6R=T97AT)UTI+"`G)RP@)&U;)VEC;VY?<&%T:"==*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@3&EN:RX@*B\*("`@("`@("`@("`@)&%C8V5S
M<VME>2`]($AO<F1E.CIG971!8V-E<W-+97DH)&U;)W1E>'0G72D["B`@("`@
M("`@("`@("1L:6YK(#T@2&]R9&4Z.FQI;FLH)&U;)W5R;"==+"`D;65N=5]V
M:65W(#T]("=I8V]N)R`_("1M6R=T97AT)UT@.B`G)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I<W-E="@D;5LG8VQA<W,G72D@/R`D;5LG
M8VQA<W,G72`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&ES<V5T*"1M6R=T87)G970G72D@/R`D;5LG=&%R9V5T)UT@.B`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D;5LG;VYC;&EC
M:R==*2`_("1M6R=O;F-L:6-K)UT@.B`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G)RP@)&%C8V5S<VME>2D["@H@("`@("`@("`@("`D
M;W5T<'5T("X]('-P<FEN=&8H(EQN/&QI/B5S)7,\8G(@+SXE<SPO83X\+VQI
M/B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&EN:RP@)&EC
M;VXL("@D;65N=5]V:65W("$]("=I8V]N)RD@/R!(;W)D93HZ:&EG:&QI9VAT
M06-C97-S2V5Y*"1M6R=T97AT)UTL("1A8V-E<W-K97DI(#H@)R<I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70@+B`G/"]U;#XG.PH@("`@
M?0H*("`@("\J*@H@("`@("H@06YY(&QI;FMS('1O(&]T:&5R($AO<F1E(&%P
M<&QI8V%T:6]N<R!D969I;F5D(&EN(&%N(&%P<&QI8V%T:6]N)W,@8V]N9FEG
M"B`@("`@*B!F:6QE(&)Y('1H92`D8V]N9ELG;65N=2==6R=A<'!S)UT@87)R
M87D@87)E(&%D9&5D('1O('1H92!M96YU(&%R<F%Y+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&1!<'!,:6YK<R@I"B`@("!["B`@("`@("`@9VQO8F%L("1C
M;VYF+"`D<F5G:7-T<GD["@H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG;65N
M=2==6R=A<'!S)UTI("8F(&ES7V%R<F%Y*"1C;VYF6R=M96YU)UU;)V%P<',G
M72DI('L*("`@("`@("`@("`@9F]R96%C:"`H)&-O;F9;)VUE;G4G75LG87!P
M<R==(&%S("1A<'`I('L*("`@("`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM
M/F=E="@G<W1A='5S)RP@)&%P<"D@(3T@)VEN86-T:79E)R`F)B`D<F5G:7-T
M<GDM/FAA<U!E<FUI<W-I;VXH)&%P<"P@4$5235-?4TA/5RDI('L*("`@("`@
M("`@("`@("`@("`@("`D=7)L(#T@)')E9VES=')Y+3YG971);FET:6%L4&%G
M92@D87!P*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V$H)'5R;"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^861D*$AO<F1E.CIU<FPH)'5R;"DL("1R96=I<W1R>2T^9V5T*"=N86UE
M)RP@)&%P<"DL("1R96=I<W1R>2T^9V5T*"=I8V]N)RP@)&%P<"DL("<G*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M86YY(&]T:&5R(&QI;FMS(&9O=6YD(&EN("1T:&ES+3Y?;65N=69I;&4@=&\@
M8F4@:6YC;'5D960@:6X@=&AE"B`@("`@*B!M96YU+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&13:71E3&EN:W,H*0H@("`@>PH@("`@("`@(&EF("A`:7-?
M<F5A9&%B;&4H)'1H:7,M/E]M96YU9FEL92DI('L*("`@("`@("`@("`@:6YC
M;'5D92`D=&AI<RT^7VUE;G5F:6QE.PH@("`@("`@("`@("!I9B`H:7-S970H
M)%]M96YU*2`F)B!I<U]A<G)A>2@D7VUE;G4I*2!["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D7VUE;G4@87,@)&UE;G5I=&5M*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F%D9$%R<F%Y*"1M96YU:71E;2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:W,@=&\@<V5E(&EF('1H92!C=7)R96YT('5R;"!M
M871C:&5S('1H92!G:79E;B!U<FPN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R('1H92!G:79E;B!54DP@:7,@=&AE(&-U<G)E;G0@
M;&]C871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4V5L96-T960H)'5R
M;"D*("`@('L*("`@("`@("`D<V5R=F5R7W5R;"`]('!A<G-E7W5R;"@D7U-%
M4E9%4ELG4$A07U-%3$8G72D["B`@("`@("`@)&-H96-K7W5R;"`]('!A<G-E
M7W5R;"@D=7)L*3L*"B`@("`@("`@+RH@5')Y('1O(&UA=&-H('1H92!I=&5M
M)W,@<&%T:"!A9V%I;G-T('1H92!C=7)R96YT('-C<FEP=`H@("`@("`@("`@
M(&9I;&5N86UE(&%S('=E;&P@87,@;W1H97(@<&]S<VEB;&4@55),<R!T;R!T
M:&ES('-C<FEP="X@*B\*("`@("`@("!I9B`H:7-S970H)&-H96-K7W5R;%LG
M<&%T:"==*2`F)@H@("`@("`@("`@("`H*"1C:&5C:U]U<FQ;)W!A=&@G72`]
M/2`D<V5R=F5R7W5R;%LG<&%T:"==*2!\?`H@("`@("`@("`@("`@*"1C:&5C
M:U]U<FQ;)W!A=&@G72`N("=I;F1E>"YP:'`G(#T]("1S97)V97)?=7)L6R=P
M871H)UTI('Q\"B`@("`@("`@("`@("`H)&-H96-K7W5R;%LG<&%T:"==("X@
M)R]I;F1E>"YP:'`G(#T]("1S97)V97)?=7)L6R=P871H)UTI*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U)E9VES=')Y+G!H<```````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#$Q,C$T,``Q,#0Q-S,V,C<W,P`P,C`U-3(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"B\J*B!$;R!N;W0@
M<W1A<G0@82!S97-S:6]N+B`J+PID969I;F4H)TA/4D1%7U-%4U-)3TY?3D].
M12<L(#$I.PH*+RHJ($1O(&YO="!W<FET92!C:&%N9V5S('1O('-E<W-I;VXN
M("HO"F1E9FEN92@G2$]21$5?4T534TE/3E]214%$3TY,62<L(#(I.PH*+RHJ
M"B`J(%1H92!296=I<W1R>3HZ(&-L87-S('!R;W9I9&5S(&$@<V5T(&]F(&UE
M=&AO9',@9F]R(&-O;6UU;FEC871I;VX*("H@8F5T=V5E;B!(;W)D92!A<'!L
M:6-A=&EO;G,@86YD(&ME97!I;F<@=')A8VL@;V8@87!P;&EC871I;VX*("H@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;BX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP+'8@,2XR-#,N,BXR,"`R
M,#`V+S`R+S$R(#(R.C0W.C$U(&UR=6)I;G-K($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO
M<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P
M961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!A=71H;W(@
M($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]&<F%M97=O<FL*("HO
M"F-L87-S(%)E9VES=')Y('L*"B`@("`O*BH*("`@("`J($AA<V@@<W1O<FEN
M9R!A;&P@;V8@=&AE(&MN;W=N('-E<G9I8V5S(&%N9"!C86QL8F%C:W,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<&E#
M86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(87-H('-T;W)I;F<@
M86QL(&MN;W=N(&1A=&$@='EP97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]T>7!E0V%C:&4@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@2&%S:"!S=&]R:6YG(&%L;"!O9B!T:&4@<F5G:7-T97)E
M9"!I;G1E<F9A8V5S('1H870@87!P;&EC871I;VYS"B`@("`@*B!P<F]V:61E
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M:6YT97)F86-E<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(87-H('-T
M;W)I;F<@:6YF;W)M871I;VX@;VX@96%C:"!R96=I<W1R>2UA=V%R92!A<'!L
M:6-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D87!P;&EC871I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%-T86-K(&]F(&EN+75S92!A<'!L:6-A=&EO;G,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<'!3=&%C:R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!1=6EC:R!P;VEN=&5R('1O('1H92!C=7)R
M96YT(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V-U<G)E;G1!<'`@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@0V%C:&4@;V8@)'!R969S(&]B:F5C=',*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!R969S0V%C:&4@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@0V%C:&4@;V8@87!P;&EC871I;VX@8V]N
M9FEG=7)A=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]C;VYF0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@07)E('=E('5S:6YG(')E9VES=')Y(&-A8VAI;F<_"B`@("`@*@H@("`@
M("H@0'!A<F%M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?=7-E8V%C:&4@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J(%5P9&%T92!T:&5S92!C86-H92!E
M;G1R:65S(&]N('-H=71D;W=N+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]U<&1A=&5C86-H92`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE<V4@;71I;64@96YT<FEE<R!O;B!S
M:'5T9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D*("`@("`J+PH@
M("`@=F%R("1?=7!D871E;71I;64@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@1&]N)W0@=7!D871E(&-A8VAE(&%T(&5N9"!O9B!R97%U97-T/PH@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VYO
M8V%C:&4@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R969E
M<F5N8V4@=&\@=&AE(&=L;V)A;"!296=I<W1R>2!O8FIE8W0L(&]N;'D*("`@
M("`J(&-R96%T:6YG(&ET(&EF(&ET(&1O97-N)W0@86QR96%D>2!E>&ES="X*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z
M("1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*"D*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<V5S<VEO;E]F;&%G<R`@06YY('-E<W-I
M;VX@9FQA9W,N"B`@("`@*@H@("`@("H@0')E='5R;B!296=I<W1R>2`@5&AE
M($AO<F1E(%)E9VES=')Y(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F<VEN9VQE=&]N*"1S97-S:6]N7V9L86=S(#T@,"D*("`@('L*("`@("`@
M("!S=&%T:6,@)')E9VES=')Y.PH*("`@("`@("!I9B`H(6ES<V5T*"1R96=I
M<W1R>2DI('L*("`@("`@("`@("`@)')E9VES=')Y(#T@;F5W(%)E9VES=')Y
M*"1S97-S:6]N7V9L86=S*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<F5G:7-T<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!N97<@
M<F5G:7-T<GD@:6YS=&%N8V4N(%-H;W5L9"!N979E<B!B92!C86QL960@97AC
M97!T"B`@("`@*B!B>2`F4F5G:7-T<GDZ.G-I;F=L971O;B@I+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1S97-S:6]N7V9L86=S("!!;GD@<V5S
M<VEO;B!F;&%G<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@4F5G:7-T<GDH)'-E<W-I;VY?9FQA9W,@/2`P
M*0H@("`@>PH@("`@("`@("\J($EM<&]R="!A;F0@9VQO8F%L($AO<F1E)W,@
M8V]N9FEG=7)A=&EO;B!V86QU97,N("HO"B`@("`@("`@)'1H:7,M/FEM<&]R
M=$-O;F9I9R@G:&]R9&4G*3L*"B`@("`@("`@+RH@4W1A<G0@82!S97-S:6]N
M+B`J+PH@("`@("`@(&EF("@D<V5S<VEO;E]F;&%G<R`F($A/4D1%7U-%4U-)
M3TY?3D].12D@>PH@("`@("`@("`@("`O*B!.979E<B!S=&%R="!A('-E<W-I
M;VX@:68@=&AE('-E<W-I;VX@9FQA9W,@:6YC;'5D90H@("`@("`@("`@("`@
M("!(3U)$15]315-324].7TY/3D4N("HO"B`@("`@("`@("`@("1?4T534TE/
M3B`](&%R<F%Y*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R
M9&4Z.G-E='5P4V5S<VEO;DAA;F1L97(H*3L*("`@("`@("`@("`@0'-E<W-I
M;VY?<W1A<G0H*3L*("`@("`@("`@("`@:68@*"1S97-S:6]N7V9L86=S("8@
M2$]21$5?4T534TE/3E]214%$3TY,62D@>PH@("`@("`@("`@("`@("`@+RH@
M0VQO<V4@=&AE('-E<W-I;VX@:6UM961I871E;'D@<V\@;F\@8VAA;F=E<R!C
M86X@8F4*("`@("`@("`@("`@("`@("`@(&UA9&4@8G5T('9A;'5E<R!A<F4@
M<W1I;&P@879A:6QA8FQE+B`J+PH@("`@("`@("`@("`@("`@0'-E<W-I;VY?
M=W)I=&5?8VQO<V4H*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=7-E8V%C:&4@/2!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("\J($-A;&P@86YY(&9U;F-T:6]N('1R:6=G97)S('=H
M:6-H(&UA>2!H879E(&)E96X@<V5T(&EN('1H90H@("`@("`@("`@("`@*B!S
M97-S:6]N+B`J+PH@("`@("`@("`@("!(;W)D93HZ<V5S<VEO;D-A;&QB86-K
M<R@I.PH@("`@("`@('T*"B`@("`@("`@+RH@26YI=&EA;&EZ92!T:&4@;&]C
M86QI>F%T:6]N(')O=71I;F5S(&%N9"!V87)I86)L97,N("HO"B`@("`@("`@
M3DQ3.CIS971,86YG*"D["B`@("`@("`@3DQ3.CIS971497AT9&]M86EN*"=H
M;W)D92<L($A/4D1%7T)!4T4@+B`G+VQO8V%L92<L($Y,4SHZ9V5T0VAA<G-E
M="@I*3L*("`@("`@("!3=')I;F<Z.G-E=$1E9F%U;'1#:&%R<V5T*$Y,4SHZ
M9V5T0VAA<G-E="@I*3L*"B`@("`@("`@)')E9U]M=&EM92`](&9I;&5M=&EM
M92A(3U)$15]"05-%("X@)R]C;VYF:6<O<F5G:7-T<GDN<&AP)RD["@H@("`@
M("`@("\J($QO860@<F5G:7-T<GD@:6YF;W)M871I;VX@9G)O;2!T:&4@<V5S
M<VEO;BP@:68@879A:6QA8FQE+B`J+PH@("`@("`@(&EF("@A96UP='DH)%]3
M15-324].6R=?<F5G:7-T<GEC86-H92==*2`F)@H@("`@("`@("`@("`H)%]3
M15-324].6R=?<F5G:7-T<GEM=&EM92==6R=R96=I<W1R>2YP:'`G72`]/2`D
M<F5G7VUT:6UE*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D7U-%4U-)3TY;
M)U]R96=I<W1R>6-A8VAE)UT@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^)&ME>2`]("1V86P["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!296%D('1H92!R96=I<W1R
M>2!C;VYF:6=U<F%T:6]N(&9I;&4N("HO"B`@("`@("`@("`@(')E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]C;VYF:6<O<F5G:7-T<GDN<&AP)SL*"B`@
M("`@("`@("`@("\J(%-T;W`@<WES=&5M(&EF($AO<F1E(&ES(&EN86-T:79E
M+B`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/F%P<&QI8V%T:6]N<ULG:&]R
M9&4G75LG<W1A='5S)UT@/3T@)VEN86-T:79E)RD@>PH@("`@("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%\H(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@4V-A;B!F;W(@86QL($%027,@<')O=FED
M960@8GD@96%C:"!A<'`L(&%N9"!S970@;W1H97(*("`@("`@("`@("`@("H@
M8V]M;6]N(&1E9F%U;'1S(&QI:V4@=&5M<&QA=&5S(&%N9"!G<F%P:&EC<RX@
M*B\*("`@("`@("`@("`@)&%P<$QI<W0@/2!A<G)A>5]K97ES*"1T:&ES+3YA
M<'!L:6-A=&EO;G,I.PH@("`@("`@("`@("!F;W)E86-H("@D87!P3&ES="!A
M<R`D87!P3F%M92D@>PH@("`@("`@("`@("`@("`@)&%P<"`]("8D=&AI<RT^
M87!P;&EC871I;VYS6R1A<'!.86UE73L*("`@("`@("`@("`@("`@(&EF("@H
M)&%P<%LG<W1A='5S)UT@/3T@)VAE861I;F<G*2!\?`H@("`@("`@("`@("`@
M("`@("`@("@D87!P6R=S=&%T=7,G72`]/2`G:6YA8W1I=F4G*2!\?`H@("`@
M("`@("`@("`@("`@("`@("@D87!P6R=S=&%T=7,G72`]/2`G861M:6XG("8F
M("%!=71H.CII<T%D;6EN*"DI*2!["B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&%P<%LG<')O=FED97,G72DI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&%P<%LG<')O=FED97,G72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&%P<%LG<')O=FED97,G72!A<R`D
M:6YT97)F86-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEN=&5R9F%C97-;)&EN=&5R9F%C95T@/2`D87!P3F%M93L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YT97)F86-E
M<ULD87!P6R=P<F]V:61E<R==72`]("1A<'!.86UE.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&%P<%LG=&5M<&QA=&5S)UTI("8F(&ES<V5T*"1A<'!;)V9I
M;&5R;V]T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&%P<%LG=&5M<&QA
M=&5S)UT@/2`D87!P6R=F:6QE<F]O="==("X@)R]T96UP;&%T97,G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D87!P
M6R=J<W5R:2==*2`F)B!I<W-E="@D87!P6R=W96)R;V]T)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&%P<%LG:G-U<FDG72`]("1A<'!;)W=E8G)O;W0G
M72`N("<O:G,G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D87!P6R=J<V9S)UTI("8F(&ES<V5T*"1A<'!;)V9I;&5R
M;V]T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&%P<%LG:G-F<R==(#T@
M)&%P<%LG9FEL97)O;W0G72`N("<O:G,G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D87!P6R=T:&5M97-U<FDG72D@
M)B8@:7-S970H)&%P<%LG=V5B<F]O="==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1A<'!;)W1H96UE<W5R:2==(#T@)&%P<%LG=V5B<F]O="==("X@)R]T
M:&5M97,G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D87!P6R=T:&5M97-F<R==*2`F)B!I<W-E="@D87!P6R=F:6QE
M<F]O="==*2D@>PH@("`@("`@("`@("`@("`@("`@("1A<'!;)W1H96UE<V9S
M)UT@/2`D87!P6R=F:6QE<F]O="==("X@)R]T:&5M97,G.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#;&5A<B!O
M=70@=&AE($%022`F(%1Y<&4@8V%C:&5S+"!I9B!T:&5Y(&5X:7-T<RX@*B\*
M("`@("`@("`@("`@)'1H:7,M/E]A<&E#86-H92`]("1T:&ES+3Y?='EP94-A
M8VAE(#T@87)R87DH*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5687)S
M*&%R<F%Y*"=A<'!L:6-A=&EO;G,G+"`G7VEN=&5R9F%C97,G+"`G7V%P:4-A
M8VAE)RP@)U]T>7!E0V%C:&4G*2P@87)R87DH)W)E9VES=')Y+G!H<"<@/3X@
M)')E9U]M=&EM92DI.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1H
M92!G;&]B86P@4&5R;7,@;V)J96-T+B`J+PH@("`@("`@("1'3$]"04Q36R=P
M97)M<R==(#T@)E!E<FUS.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@+RH@071T
M86-H(&IA=F%S8W)I<'0@;F]T:69I8V%T:6]N(&QI<W1E;F5R+B`J+PH@("`@
M("`@("1N;W1I9FEC871I;VX@/2`F3F]T:69I8V%T:6]N.CIS:6YG;&5T;VXH
M*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YA='1A8V@H)VIA=F%S8W)I<'0G
M*3L*"B`@("`@("`@+RH@4F5G:7-T97(@86-C97-S(&ME>2!L;V=G97(@9F]R
M('1R86YS;&%T;W)S+B`J+PH@("`@("`@(&EF("A`)$=,3T)!3%-;)V-O;F8G
M75LG;&]G7V%C8V5S<VME>7,G72D@>PH@("`@("`@("`@("!R96=I<W1E<E]S
M:'5T9&]W;E]F=6YC=&EO;BAC<F5A=&5?9G5N8W1I;VXH)R<L("=(;W)D93HZ
M9V5T06-C97-S2V5Y*&YU;&PL(&YU;&PL('1R=64I.R<I*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!L:7-T(&]F('9A<FEA8FQE
M(&YA;65S(&%N9"!M;V1I9FEC871I;VX@=&EM97,@=&\@8F4@8V%C:&5D+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D=F%R<R`@("!!(&QI<W0@;V8@=F%R:6%B;&4@;F%M97,@
M=&\@8F4@8V%C:&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1M=&EM97,@($$@
M;&ES="!O9B!F:6QE(&UO9&EF:6-A:6]N('1I;65S('1O(&)E(&-A8VAE9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-A8VAE5F%R<R@D=F%R<R`](&%R<F%Y
M*"DL("1M=&EM97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D
M<F5G8V%C:&5S:'5T9&]W;B`](&9A;'-E.PH*("`@("`@("!I9B`H)'1H:7,M
M/E]U<V5C86-H92D@>PH@("`@("`@("`@("`D=&AI<RT^7W5P9&%T96-A8VAE
M(#T@87)R87E?;65R9V4H)'1H:7,M/E]U<&1A=&5C86-H92P@)'9A<G,I.PH@
M("`@("`@("`@("`D=&AI<RT^7W5P9&%T96UT:6UE(#T@87)R87E?;65R9V4H
M)'1H:7,M/E]U<&1A=&5M=&EM92P@)&UT:6UE<RD["B`@("`@("`@("`@(&EF
M("@A)')E9V-A8VAE<VAU=&1O=VXI('L*("`@("`@("`@("`@("`@(')E9VES
M=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U]S:'5T9&]W
M;F-A8VAE)RDI.PH@("`@("`@("`@("`@("`@)')E9V-A8VAE<VAU=&1O=VX@
M/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4W1O<F5S(&-A8VAE86)L92!M96UB97(@=F%R:6%B;&5S(&EN
M('1H92!S97-S:6]N(&%T('-H=71D;W=N+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<VAU=&1O=VYC86-H
M92@I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3BD@)B8@075T
M:#HZ9V5T075T:"@I("8F("$D=&AI<RT^7VYO8V%C:&4I('L*("`@("`@("`@
M("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)U]R96=I<W1R>6-A8VAE)UTI*2![
M"B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)U]R96=I<W1R>6-A8VAE)UT@
M/2!A<G)A>2@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H
M("AA<G)A>5]U;FEQ=64H)'1H:7,M/E]U<&1A=&5C86-H92D@87,@)'9A;"D@
M>PH@("`@("`@("`@("`@("`@)%]315-324].6R=?<F5G:7-T<GEC86-H92==
M6R1V86Q=(#T@)'1H:7,M/B1V86P["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@A:7-S970H)%]315-324].6R=?<F5G:7-T<GEM=&EM92==*2D@
M>PH@("`@("`@("`@("`@("`@)%]315-324].6R=?<F5G:7-T<GEM=&EM92==
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C
M:"`H87)R87E?=6YI<75E*"1T:&ES+3Y?=7!D871E;71I;64I(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R=?<F5G:7-T
M<GEM=&EM92==6R1K97E=(#T@)'9A;#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-L96%R('1H92!R96=I<W1R>2!C
M86-H92X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-L96%R0V%C:&4H*0H@("`@>PH@("`@("`@('5N<V5T
M*"1?4T534TE/3ELG7W)E9VES=')Y8V%C:&4G72D["B`@("`@("`@)'1H:7,M
M/E]N;V-A8VAE(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($9I;&QS
M('1H92!R96=I<W1R>2=S($%022!C86-H92!W:71H('1H92!A=F%I;&%B;&4@
M<V5R=FEC97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]F:6QL05!)0V%C:&4H*0H@("`@>PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]A<&E#86-H92DI('L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'-T871U<R`](&%R<F%Y*"=A
M8W1I=F4G+"`G;F]T;V]L8F%R)RP@)VAI9&1E;B<I.PH@("`@("`@(&EF("A!
M=71H.CII<T%D;6EN*"DI('L*("`@("`@("`@("`@)'-T871U<UM=(#T@)V%D
M;6EN)SL*("`@("`@("!]"B`@("`@("`@)&%P<',@/2`D=&AI<RT^;&ES=$%P
M<',H)'-T871U<RD["B`@("`@("`@9F]R96%C:"`H)&%P<',@87,@)&%P<"D@
M>PH@("`@("`@("`@("`D7W-E<G9I8V5S(#T@)%]T>7!E<R`](&YU;&P["B`@
M("`@("`@("`@("1A<&D@/2`D=&AI<RT^9V5T*"=F:6QE<F]O="<L("1A<'`I
M("X@)R]L:6(O87!I+G!H<"<["B`@("`@("`@("`@(&EF("AI<U]R96%D86)L
M92@D87!I*2D@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("1A<&D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D7W-E<G9I
M8V5S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A<&E#86-H95LD87!P
M72`](&%R<F%Y*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V%P:4-A8VAE6R1A<'!=(#T@)%]S97)V:6-E<SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)%]T>7!E<RDI('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1?='EP97,@87,@)'1Y<&4@/3X@
M)'!A<F%M<RD@>PH@("`@("`@("`@("`@("`@("`@("\J(%!R969I>"!N;VXM
M2&]R9&4@='EP97,@=VET:"!T:&4@87!P;&EC871I;VX*("`@("`@("`@("`@
M("`@("`@("`@*B!N86UE+B`J+PH@("`@("`@("`@("`@("`@("`@("1P<F5F
M:7@@/2`D87!P(#T]("=H;W)D92<@/R`G)R`Z("(D>V%P<'U?(CL*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W1Y<&5#86-H95LD<')E9FEX("X@)'1Y
M<&5=(#T@)'!A<F%M<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C86-H959A<G,H87)R87DH
M)U]A<&E#86-H92<L("=?='EP94-A8VAE)RDI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&$@;&ES="!O9B!T:&4@:6YS=&%L;&5D(&%N9"!R96=I
M<W1E<F5D(&%P<&QI8V%T:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@("`D9FEL=&5R("`@("`@06X@87)R87D@;V8@=&AE('-T871U<V5S('1H
M870@<VAO=6QD(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N960N($1E9F%U;'1S('1O(&YO;BUH:61D96XN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D87-S;V,@("`@("`@07-S;V-I871I=F4@87)R87D@
M=VET:"!A<'`@;F%M97,@87,@:V5Y<RX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!L979E;"!T;R!C:&5C:R!F
M;W(@:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;&ES="X@1&5F875L=',@=&\@4$5235-?4TA/5RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!,:7-T(&]F(&%P<',@<F5G:7-T97)E9"!W:71H($AO
M<F1E+B!)9B!N;PH@("`@("H@("`@("`@("`@("`@("`@87!P;&EC871I;VYS
M(&%R92!D969I;F5D(')E='5R;G,@86X@96UP='D@87)R87DN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QI<W1!<'!S*"1F:6QT97(@/2!N=6QL+"`D87-S;V,@
M/2!F86QS92P@)'!E<FUI<W-I;VX@/2!015)-4U]32$]7*0H@("`@>PH@("`@
M("`@("1A<'!S(#T@87)R87DH*3L*("`@("`@("!I9B`H:7-?;G5L;"@D9FEL
M=&5R*2D@>PH@("`@("`@("`@("`D9FEL=&5R(#T@87)R87DH)VYO=&]O;&)A
M<B<L("=A8W1I=F4G*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YA<'!L:6-A=&EO;G,@87,@)&%P<"`]/B`D<&%R86US*2!["B`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2@D<&%R86US6R=S=&%T=7,G72P@)&9I;'1E
M<BD@)B8*("`@("`@("`@("`@("`@("AD969I;F5D*"=!551(7TA!3D1,15(G
M*2!\?"`D=&AI<RT^:&%S4&5R;6ES<VEO;B@D87!P+"`D<&5R;6ES<VEO;BDI
M*2!["B`@("`@("`@("`@("`@("`D87-S;V,@/R`D87!P<ULD87!P72`]("1A
M<'`@.B`D87!P<UM=(#T@)&%P<#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1A<'!S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A;&P@879A:6QA8FQE(')E9VES=')Y($%027,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE($%022!L:7-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L:7-T05!)<R@I"B`@("!["B`@("`@("`@<W1A=&EC("1A
M<&ES(#T@87)R87DH*3L*("`@("`@("!I9B`H)&%P:7,I('L*("`@("`@("`@
M("`@<F5T=7)N("1A<&ES.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M87)R87E?:V5Y<R@D=&AI<RT^7VEN=&5R9F%C97,I(&%S("1I;G1E<F9A8V4I
M('L*("`@("`@("`@("`@0&QI<W0H)&%P:2P@*2`](&5X<&QO9&4H)R\G+"`D
M:6YT97)F86-E*3L*("`@("`@("`@("`@)&%P:7-;72`]("1A<&D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@87)R87E?=6YI<75E*"1A<&ES*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL(&]F('1H92!A=F%I;&%B
M;&4@<F5G:7-T<GD@;65T:&]D<RP@;W(@86QT97)N871E;'D*("`@("`J(&]N
M;'D@=&AO<V4@9F]R(&$@<W!E8VEF:65D($%022X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A<&D@($1E9FEN97,@=&AE($%022!F;W(@=VAI8V@@
M=&AE(&UE=&AO9',@<VAA;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N960N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&UE=&AO9"!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T365T:&]D
M<R@D87!I(#T@;G5L;"D*("`@('L*("`@("`@("`D;65T:&]D<R`](&%R<F%Y
M*"D["@H@("`@("`@("1T:&ES+3Y?9FEL;$%024-A8VAE*"D["@H@("`@("`@
M(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/F%P<&QI8V%T:6]N<RD@87,@
M)&%P<"D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%P<&QI8V%T
M:6]N<ULD87!P75LG<')O=FED97,G72DI('L*("`@("`@("`@("`@("`@("1P
M<F]V:61E<R`]("1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W!R;W9I9&5S
M)UT["B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P<F]V:61E<RDI
M('L*("`@("`@("`@("`@("`@("`@("`D<')O=FED97,@/2!A<G)A>2@D<')O
M=FED97,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'!R;W9I9&5S(#T@87)R87DH*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)'!R;W9I9&5S(&%S("1M
M971H;V0I('L*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&UE=&AO9"P@
M)R\G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M;G5L;"@D87!I*2!\?`H@("`@("`@("`@("`@("`@("`@("`@("`H<W5B<W1R
M*"1M971H;V0L(#`L('-T<FQE;B@D87!I*2D@/3T@)&%P:2DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&UE=&AO9'-;72`]("1M971H;V0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES
M7VYU;&PH)&%P:2D@?'P@*"1M971H;V0@/3T@)&%P:2DI('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]A<&E#86-H95LD87!P72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y
M<R@D=&AI<RT^7V%P:4-A8VAE6R1A<'!=*2!A<R`D<V5R=FEC92D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&UE=&AO9'-;72`]("1M971H;V0@
M+B`G+R<@+B`D<V5R=FEC93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y7W5N:7%U
M92@D;65T:&]D<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L
M;"!O9B!T:&4@879A:6QA8FQE(')E9VES=')Y(&1A=&$@='EP97,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&1A=&$@='EP92!L:7-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T5'EP97,H*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?9FEL;$%024-A8VAE*"D["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?='EP94-A8VAE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(&UE=&AO9"=S('-I9VYA='5R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M971H;V0@(%1H92!F=6QL(&YA;64@;V8@=&AE(&UE=&AO9"!T;R!C
M:&5C:R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!T=V\@
M9&EM96YS:6]N86P@87)R87DN(%1H92!F:7)S="!E;&5M96YT(&-O;G1A:6YS
M(&%N"B`@("`@*B`@("`@("`@("`@("`@("!A<G)A>2!W:71H('1H92!P87)A
M;65T97(@;F%M97,L('1H92!S96-O;F0@;VYE('1H92!R971U<FX*("`@("`J
M("`@("`@("`@("`@("`@('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%-I9VYA='5R92@D;65T:&]D*0H@("`@>PH@("`@("`@(&EF("@A*"1A<'`@
M/2`D=&AI<RT^:&%S365T:&]D*"1M971H;V0I*2D@>PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9I;&Q!4$E#86-H
M92@I.PH*("`@("`@("!`;&ES="@L("1F=6YC=&EO;BD@/2!E>'!L;V1E*"<O
M)RP@)&UE=&AO9"D["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?87!I0V%C
M:&5;)&%P<%U;)&9U;F-T:6]N75LG='EP92==*2`F)@H@("`@("`@("`@("!I
M<W-E="@D=&AI<RT^7V%P:4-A8VAE6R1A<'!=6R1F=6YC=&EO;EU;)V%R9W,G
M72DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1T:&ES+3Y?87!I0V%C
M:&5;)&%P<%U;)&9U;F-T:6]N75LG87)G<R==+"`D=&AI<RT^7V%P:4-A8VAE
M6R1A<'!=6R1F=6YC=&EO;EU;)W1Y<&4G72D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF(&%N(&EN=&5R9F%C92!I<R!I
M;7!L96UE;G1E9"!B>2!A;B!A8W1I=F4@87!P;&EC871I;VXN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:6YT97)F86-E("!4:&4@:6YT97)F86-E
M('1O(&-H96-K(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M:&4@87!P;&EC871I;VX@:6UP;&5M96YT:6YG("1I;G1E<F9A8V4@:68@=V4@
M:&%V92!I="P*("`@("`J("`@("`@("`@("`@("`@(&9A;'-E(&EF('1H92!I
M;G1E<F9A8V4@:7,@;F]T(&EM<&QE;65N=&5D+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!H87-);G1E<F9A8V4H)&EN=&5R9F%C92D*("`@('L*("`@("`@("!R
M971U<FX@(65M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72D@
M/PH@("`@("`@("`@("`D=&AI<RT^7VEN=&5R9F%C97-;)&EN=&5R9F%C95T@
M.@H@("`@("`@("`@("!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN92!I9B!A(&UE=&AO9"!H87,@8F5E;B!R96=I<W1E<F5D('=I=&@@
M=&AE(')E9VES=')Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE
M=&AO9"`@5&AE(&9U;&P@;F%M92!O9B!T:&4@;65T:&]D('1O(&-H96-K(&9O
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@("`@3VYL>2!C:&5C:R!T
M:&ES(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1H92!A<'!L:6-A=&EO;B!I;7!L96UE;G1I;F<@)&UE=&AO9"!I9B!W92!H
M879E(&ET+`H@("`@("H@("`@("`@("`@("`@("`@9F%L<V4@:68@=&AE(&UE
M=&AO9"!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87--
M971H;V0H)&UE=&AO9"P@)&%P<"`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7VYU;&PH)&%P<"DI('L*("`@("`@("`@("`@0&QI<W0H)&EN=&5R9F%C
M92P@)&-A;&PI(#T@97AP;&]D92@G+R<L("1M971H;V0I.PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD;65T:&]D72DI('L*
M("`@("`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7VEN=&5R9F%C97-;)&UE
M=&AO9%T["B`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)'1H:7,M/E]I
M;G1E<F9A8V5S6R1I;G1E<F9A8V5=*2D@>PH@("`@("`@("`@("`@("`@)&%P
M<"`]("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E73L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C86QL
M(#T@)&UE=&AO9#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9FEL;$%0
M24-A8VAE*"D["@H@("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M/E]A<&E#
M86-H95LD87!P75LD8V%L;%TI(#\@)&%P<"`Z(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!H;V]K(&-O<G)E<W!O;F1I;F<@=&\@
M=&AE(&1E9F%U;'0@<&%C:V%G92!T:&%T"B`@("`@*B!P<F]V:61E<R!T:&4@
M9G5N8W1I;VYA;&ET>2!R97%U97-T960@8GD@=&AE("1M971H;V0*("`@("`J
M('!A<F%M971E<BX@)&UE=&AO9"!I<R!A('-T<FEN9R!C;VYS:7-T:6YG(&]F
M"B`@("`@*B`B<&%C:V%G971Y<&4O;65T:&]D;F%M92(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@;65T:&]D('1O(&-A;&PN
M"B`@("`@*B!`<&%R86T@87)R87D@)&%R9W,@("`@($%R9W5M96YT<R!T;R!T
M:&4@;65T:&]D+@H@("`@("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J
M("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V%L;"@D;65T:&]D+"`D87)G<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@0&QI<W0H)&EN=&5R9F%C92P@)&-A;&PI(#T@97AP
M;&]D92@G+R<L("1M971H;V0I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?:6YT97)F86-E<ULD;65T:&]D72DI('L*("`@("`@("`@("`@)&%P<"`]
M("1T:&ES+3Y?:6YT97)F86-E<ULD;65T:&]D73L*("`@("`@("!](&5L<V5I
M9B`H(65M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72DI('L*
M("`@("`@("`@("`@)&%P<"`]("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F
M86-E73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G5&AE(&UE=&AO9"`B)R`N("1M971H;V0@+B`G(B!I
M<R!N;W0@9&5F:6YE9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN)RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/F-A;&Q">5!A8VMA9V4H)&%P
M<"P@)&-A;&PL("1A<F=S*3L*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U
M="!T:&4@:&]O:R!C;W)R97-P;VYD:6YG('1O('1H92!S<&5C:69I8R!P86-K
M86=E(&YA;65D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@
M(%1H92!A<'!L:6-A=&EO;B!B96EN9R!C86QL960N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C86QL("!4:&4@;65T:&]D('1O(&-A;&PN"B`@("`@*B!`<&%R
M86T@87)R87D@)&%R9W,@("!!<F=U;65N=',@=&\@=&AE(&UE=&AO9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@("!2971U
M<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-A;&Q">5!A8VMA9V4H)&%P<"P@)&-A;&PL("1A<F=S(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`O*B!.;W1E.B!C86QL:6YG(&AA<TUE=&AO9"@I(&UA
M:V5S('-U<F4@=&AA="!W92=V92!C86-H960*("`@("`@("`@*B`D87!P)W,@
M<V5R=FEC97,@86YD(&EN8VQU9&5D('1H92!!4$D@9FEL92P@<V\@=V4@9&]N
M)W0@=')Y"B`@("`@("`@("H@=&\@9&\@:70@86=A:6X@97AP;&EC:71L>2!I
M;B!T:&ES(&UE=&AO9"X@*B\*("`@("`@("!I9B`H(21T:&ES+3YH87--971H
M;V0H)&-A;&PL("1A<'`I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H)U1H92!M971H;V0@(B5S(B!I<R!N;W0@9&5F
M:6YE9"!I;B!T:&4@05!)(&9O<B`E<RXG+"`D8V%L;"P@)&%P<"DI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@3&]A9"!T:&4@05!)(&YO=RX@*B\*("`@("`@
M("!I9B`H(65M<'1Y*"1?4T534TE/3ELG7W)E9VES=')Y8V%C:&4G75LG7V%P
M:4-A8VAE)UTI*2!["B`@("`@("`@("`@("1A<&D@/2`D=&AI<RT^9V5T*"=F
M:6QE<F]O="<L("1A<'`I("X@)R]L:6(O87!I+G!H<"<["B`@("`@("`@("`@
M(&EF("AI<U]R96%D86)L92@D87!I*2D@>PH@("`@("`@("`@("`@("`@:6YC
M;'5D95]O;F-E("1A<&D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J($UA:V4@<W5R92!T:&%T('1H92!F=6YC=&EO;B!A8W1U86QL>2!E
M>&ES=',N("HO"B`@("`@("`@)&9U;F-T:6]N(#T@)U\G("X@)&%P<"`N("=?
M)R`N("1C86QL.PH@("`@("`@(&EF("@A9G5N8W1I;VY?97AI<W1S*"1F=6YC
M=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U1H92!F=6YC=&EO;B!I;7!L96UE;G1I;F<@)R`N("1C86QL("X@)R`H)R`N
M("1F=6YC=&EO;B`N("<I(&ES(&YO="!D969I;F5D(&EN("<@+B`D87!P("X@
M)UPG<R!!4$DN)RD["B`@("`@("`@?0H*("`@("`@("`D8VAE8VM097)M<R`]
M(&ES<V5T*"1T:&ES+3Y?87!I0V%C:&5;)&%P<%U;)&-A;&Q=6R=C:&5C:W!E
M<FUS)UTI(#\*("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?87!I0V%C
M:&5;)&%P<%U;)&-A;&Q=6R=C:&5C:W!E<FUS)UT@.B!T<G5E.PH*("`@("`@
M("`O*B!3=VET8V@@87!P;&EC871I;VX@8V]N=&5X=',@;F]W+"!I9B!N96-E
M<W-A<GDL(&)E9F]R90H@("`@("`@("`J(&EN8VQU9&EN9R!A;GD@9FEL97,@
M=VAI8V@@;6EG:'0@9&\@:70@9F]R('5S+B!2971U<FX@86X*("`@("`@("`@
M*B!E<G)O<B!I;6UE9&EA=&5L>2!I9B!P=7-H07!P*"D@9F%I;',N("HO"B`@
M("`@("`@)'!U<VAE9"`]("1T:&ES+3YP=7-H07!P*"1A<'`L("1C:&5C:U!E
M<FUS*3L*("`@("`@("!I9B`H:7-?82@D<'5S:&5D+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<'5S:&5D.PH@("`@("`@('T*"B`@
M("`@("`@)')E<R`](&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1F=6YC=&EO;BP@
M)&%R9W,I.PH*("`@("`@("`O*B!)9B!W92!C:&%N9V5D(&%P<&QI8V%T:6]N
M(&-O;G1E>'0@:6X@=&AE(&-O=7)S92!O9B!T:&ES"B`@("`@("`@("H@8V%L
M;"P@=6YD;R!T:&%T(&-H86YG92!N;W<N("HO"B`@("`@("`@:68@*"1P=7-H
M960@/3T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/G!O<$%P<"@I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@=&AE(&AO;VL@8V]R<F5S<&]N9&EN9R!T;R!T:&4@
M9&5F875L="!P86-K86=E('1H870*("`@("`J('!R;W9I9&5S('1H92!F=6YC
M=&EO;F%L:71Y(')E<75E<W1E9"!B>2!T:&4@)&UE=&AO9`H@("`@("H@<&%R
M86UE=&5R+B`D;65T:&]D(&ES(&$@<W1R:6YG(&-O;G-I<W1I;F<@;V8*("`@
M("`J(")P86-K86=E='EP92]M971H;V1N86UE(BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1M971H;V0@(%1H92!M971H;V0@=&\@;&EN:R!T;RX*
M("`@("`J($!P87)A;2!A<G)A>2`D87)G<R`@("`@07)G=6UE;G1S('1O('1H
M92!M971H;V0N"B`@("`@*B!`<&%R86T@;6EX960@)&5X=')A("`@($5X=')A
M+"!N;VXM<W1A;F1A<F0@87)G=6UE;G1S('1O('1H92!M971H;V0N"B`@("`@
M*@H@("`@("H@0')E='5R;B`@5$]$3PH@("`@("H@("`@("`@("`@4F5T=7)N
M<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M:6YK*"1M971H;V0L("1A<F=S(#T@87)R87DH*2P@)&5X=')A(#T@)R<I"B`@
M("!["B`@("`@("`@0&QI<W0H)&EN=&5R9F%C92P@)&-A;&PI(#T@97AP;&]D
M92@G+R<L("1M971H;V0I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M:6YT97)F86-E<ULD;65T:&]D72DI('L*("`@("`@("`@("`@)&%P<"`]("1T
M:&ES+3Y?:6YT97)F86-E<ULD;65T:&]D73L*("`@("`@("!](&5L<V5I9B`H
M(65M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72DI('L*("`@
M("`@("`@("`@)&%P<"`]("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G5&AE(&UE=&AO9"`B)R`N("1M971H;V0@+B`G(B!I<R!N
M;W0@9&5F:6YE9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN)RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/FQI;FM">5!A8VMA9V4H)&%P<"P@
M)&-A;&PL("1A<F=S+"`D97AT<F$I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3W5T<'5T('1H92!H;V]K(&-O<G)E<W!O;F1I;F<@=&\@=&AE('-P96-I9FEC
M('!A8VMA9V4@;F%M960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M87!P("`@5&AE(&%P<&QI8V%T:6]N(&)E:6YG(&-A;&QE9"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-A;&P@(%1H92!M971H;V0@=&\@;&EN:R!T;RX*("`@
M("`J($!P87)A;2!A<G)A>2`D87)G<R`@($%R9W5M96YT<R!T;R!T:&4@;65T
M:&]D+@H@("`@("H@0'!A<F%M(&UI>&5D("1E>'1R82`@17AT<F$L(&YO;BUS
M=&%N9&%R9"!A<F=U;65N=',@=&\@=&AE(&UE=&AO9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@("!2971U<FYS(%!%05)?
M17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;FM">5!A
M8VMA9V4H)&%P<"P@)&-A;&PL("1A<F=S(#T@87)R87DH*2P@)&5X=')A(#T@
M)R<I"B`@("!["B`@("`@("`@+RH@3F]T93H@8V%L;&EN9R!H87--971H;V0@
M;6%K97,@<W5R92!T:&%T('=E)W9E(&-A8VAE9"`D87!P)W,*("`@("`@("`@
M*B!S97)V:6-E<R!A;F0@:6YC;'5D960@=&AE($%022!F:6QE+"!S;R!W92!D
M;VXG="!T<GD@=&\@9&\*("`@("`@("`@*B!I="!I="!A9V%I;B!E>'!L:6-I
M=&QY(&EN('1H:7,@;65T:&]D+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/FAA
M<TUE=&AO9"@D8V%L;"P@)&%P<"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)U1H92!M971H;V0@(B<@+B`D8V%L;"`N("<B(&ES
M(&YO="!D969I;F5D(&EN("<@+B`D87!P("X@)UPG<R!!4$DN)RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=&AE(&QI;FL@:7,@9&5F:6YE
M9"X@*B\*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]A<&E#86-H95LD87!P
M75LD8V%L;%U;)VQI;FLG72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)U1H92!L:6YK("<@+B`D8V%L;"`N("<@:7,@;F]T(&1E
M9FEN960@:6X@)R`N("1A<'`@+B`G7"=S($%022XG*3L*("`@("`@("!]"@H@
M("`@("`@("\J($EN:71I86P@;&EN:R!V86QU92X@*B\*("`@("`@("`D;&EN
M:R`]("1T:&ES+3Y?87!I0V%C:&5;)&%P<%U;)&-A;&Q=6R=L:6YK)UT["@H@
M("`@("`@("\J($9I;&P@:6X@:'1M;"UE;F-O9&5D(&%R9W5M96YT<RX@*B\*
M("`@("`@("!F;W)E86-H("@D87)G<R!A<R`D:V5Y(#T^("1V86PI('L*("`@
M("`@("`@("`@)&QI;FL@/2!S=')?<F5P;&%C92@G)2<@+B`D:V5Y("X@)R4G
M+"!H=&UL96YT:71I97,H)'9A;"DL("1L:6YK*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W=E8G)O
M;W0G72DI('L*("`@("`@("`@("`@)&QI;FL@/2!S=')?<F5P;&%C92@G)6%P
M<&QI8V%T:6]N)2<L("1T:&ES+3YG970H)W=E8G)O;W0G+"`D87!P*2P@)&QI
M;FLI.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5P;&%C92!H=&UL96YC;V1E
M9"!A<F=U;65N=',@=&AA="!H879E;B=T(&)E96X@<W!E8VEF:65D('=I=&@*
M("`@("`@("`@("!A;B!E;7!T>2!S=')I;F<@*'1H:7,@:7,@=VAE<F4@=&AE
M(&1E9F%U;'0@=V]U;&0@8F4@<W5B<W1I='5T960*("`@("`@("`@("!I;B!A
M('-T<FEC=&5R(')E9VES=')Y(&EM<&QE;65N=&%T:6]N*2X@*B\*("`@("`@
M("`D;&EN:R`]('!R96=?<F5P;&%C92@G?"4N*R5\52<L("<G+"`D;&EN:RD[
M"@H@("`@("`@("\J($9I;&P@:6X@=7)L96YC;V1E9"!A<F=U;65N=',N("HO
M"B`@("`@("`@9F]R96%C:"`H)&%R9W,@87,@)&ME>2`]/B`D=F%L*2!["B`@
M("`@("`@("`@("1L:6YK(#T@<W1R7W)E<&QA8V4H)WPG("X@4W1R:6YG.CIL
M;W=E<B@D:V5Y*2`N("=\)RP@=7)L96YC;V1E*"1V86PI+"`D;&EN:RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!!<'!E;F0@86YY(&5X=')A+"!N;VXM<W1A
M;F1A<F0@87)G=6UE;G1S+B`J+PH@("`@("`@(&EF("AI<U]A<G)A>2@D97AT
M<F$I*2!["B`@("`@("`@("`@("1E>'1R85]A<F=S(#T@)R<["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1E>'1R82!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@("`@("1E>'1R85]A<F=S("XM("<F)R`N('5R;&5N8V]D92@D:V5Y
M*2`N("<])R`N('5R;&5N8V]D92@D=F%L*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1E>'1R85]A<F=S(#T@)&5X=')A
M.PH@("`@("`@('T*("`@("`@("`D;&EN:R`]('-T<E]R97!L86-E*"=\97AT
M<F%\)RP@)&5X=')A7V%R9W,L("1L:6YK*3L*"B`@("`@("`@+RH@4F5P;&%C
M92!H=&UL+65N8V]D960@87)G=6UE;G1S('1H870@:&%V96XG="!B965N('-P
M96-I9FEE9"!W:71H"B`@("`@("`@("`@86X@96UP='D@<W1R:6YG("AT:&ES
M(&ES('=H97)E('1H92!D969A=6QT('=O=6QD(&)E('-U8G-T:71U=&5D"B`@
M("`@("`@("`@:6X@82!S=')I8W1E<B!R96=I<W1R>2!I;7!L96UE;G1A=&EO
M;BDN("HO"B`@("`@("`@)&QI;FL@/2!P<F5G7W)E<&QA8V4H)WQ<?"XK7'Q\
M52<L("<G+"`D;&EN:RD["@H@("`@("`@(')E='5R;B`D;&EN:SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E<&QA8V4@86YY("5A<'!L:6-A=&EO;B4@<W1R
M:6YG<R!W:71H('1H92!F:6QE<WES=&5M('!A=&@@=&\@=&AE"B`@("`@*B!A
M<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("!4:&4@87!P;&EC871I;VX@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87!P("`@5&AE(&%P<&QI8V%T:6]N(&)E:6YG(&-A;&QE9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@("!2971U<FYS
M(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P
M<&QI8V%T:6]N1FEL95!A=&@H)'!A=&@L("1A<'`@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AI<U]N=6QL*"1A<'`I*2!["B`@("`@("`@("`@("1A<'`@
M/2`D=&AI<RT^7V-U<G)E;G1!<'`["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%TI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B7"(E<UPB
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB*2P@
M)&%P<"DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E
M*"<E87!P;&EC871I;VXE)RP@)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG
M9FEL97)O;W0G72P@)'!A=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P
M;&%C92!A;GD@)6%P<&QI8V%T:6]N)2!S=')I;F=S('=I=&@@=&AE('=E8B!P
M871H('1O('1H92!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@87!P;&EC871I;VX@<W1R:6YG+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D87!P("`@5&AE(&%P<&QI8V%T:6]N(&)E:6YG(&-A
M;&QE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@
M("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%P<&QI8V%T:6]N5V5B4&%T:"@D<&%T:"P@)&%P<"`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D87!P*2D@>PH@("`@("`@
M("`@("`D87!P(#T@)'1H:7,M/E]C=7)R96YT07!P.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('-T<E]R97!L86-E*"<E87!P;&EC871I;VXE)RP@)'1H
M:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG=V5B<F]O="==+"`D<&%T:"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&-U<G)E;G0@87!P;&EC871I
M;VXL(&%D9&EN9R!I="!T;R!T:&4@=&]P(&]F('1H92!(;W)D90H@("`@("H@
M87!P;&EC871I;VX@<W1A8VLN($EF('1H:7,@:7,@=&AE(&9I<G-T(&%P<&QI
M8V%T:6]N('1O(&)E"B`@("`@*B!P=7-H960L(')E=')I979E('-E<W-I;VX@
M:6YF;W)M871I;VX@87,@=V5L;"X*("`@("`J"B`@("`@*B!P=7-H07!P*"D@
M86QS;R!R96%D<R!T:&4@87!P;&EC871I;VXG<R!C;VYF:6=U<F%T:6]N(&9I
M;&4@86YD"B`@("`@*B!S971S('5P(&ET<R!G;&]B86P@)&-O;F8@:&%S:"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D87!P("`@("`@("`@5&AE
M(&YA;64@;V8@=&AE(&%P<&QI8V%T:6]N('1O('!U<V@N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D8VAE8VM097)M<R`@36%K92!S=7)E('1H870@=&AE(&-U
M<G)E;G0@=7-E<B!H87,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!P97)M:7-S:6]N<R!T;R!T:&4@87!P;&EC871I;VX@8F5I;F<@;&]A
M9&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L
M=',@=&\@=')U92X@4VAO=6QD($].3%D@8F4@9&ES86)L960@8GD*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S>7-T96T@<V-R:7!T<R`H
M8W)O;B!J;V)S+"!E=&,N*2!A;F0@<V-R:7!T<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H870@:&%N9&QE(&QO9VEN+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(%]A
M<'!3=&%C:R!W87,@;6]D:69I960N"B`@("`@*B`@("`@("`@("`@("`@("`@
M(%)E='5R;B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P=7-H07!P*"1A<'`L("1C:&5C:U!E<FUS(#T@=')U92D*("`@('L*
M("`@("`@("!I9B`H)&%P<"`]/2`D=&AI<RT^7V-U<G)E;G1!<'`I('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0F%I;"!O=70@:68@87!P;&EC871I;VX@:7,@;F]T('!R97-E;G0@;W(@:6YA
M8W1I=F4N("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^87!P;&EC871I
M;VYS6R1A<'!=*2!\?`H@("`@("`@("`@("`D=&AI<RT^87!P;&EC871I;VYS
M6R1A<'!=6R=S=&%T=7,G72`]/2`G:6YA8W1I=F4G('Q\"B`@("`@("`@("`@
M("@D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=S=&%T=7,G72`]/2`G861M
M:6XG("8F("%!=71H.CII<T%D;6EN*"DI*2!["B`@("`@("`@("`@($AO<F1E
M.CIF871A;"@D87!P("X@)R!I<R!N;W0@86-T:79A=&5D)RP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('!E<FUI<W-I
M;VYS(&-H96-K:6YG(&ES(')E<75E<W1E9"P@<F5T=7)N(&%N(&5R<F]R(&EF
M"B`@("`@("`@("H@=&AE(&-U<G)E;G0@=7-E<B!D;V5S(&YO="!H879E(')E
M860@<&5R;7,@=&\@=&AE"B`@("`@("`@("H@87!P;&EC871I;VX@8F5I;F<@
M;&]A9&5D+B!792!A;&QO=R!A8V-E<W,Z"B`@("`@("`@("H*("`@("`@("`@
M*B`@+2!4;R!A;&P@861M:6YS+@H@("`@("`@("`J("`M(%1O(&%L;"!A=71H
M96YT:6-A=&5D('5S97)S(&EF(&YO('!E<FUI<W-I;VX@:7,@<V5T(&]N("1A
M<'`N"B`@("`@("`@("H@("T@5&\@86YY;VYE('=H;R!I<R!A;&QO=V5D(&)Y
M(&%N(&5X<&QI8VET($%#3"!O;B`D87!P+B`J+PH@("`@("`@(&EF("@D8VAE
M8VM097)M<R`F)B`A)'1H:7,M/FAA<U!E<FUI<W-I;VXH)&%P<"DI('L*("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G57-E<B`E<R!D
M;V5S(&YO="!H879E(%)%040@<&5R;6ES<VEO;B!F;W(@)7,G+"!!=71H.CIG
M971!=71H*"DL("1A<'`I+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M*2P@075T:#HZ9V5T075T:"@I+"`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=
M6R=N86UE)UTI+"`G<&5R;6ES<VEO;E]D96YI960G*3L*("`@("`@("!]"@H@
M("`@("`@("\J($EM<&]R="!T:&ES(&%P<&QI8V%T:6]N)W,@8V]N9FEG=7)A
M=&EO;B!V86QU97,N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^:6UP
M;W)T0V]N9FEG*"1A<'`I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<W5C8V5S<SL*
M("`@("`@("!]"@H@("`@("`@("\J($QO860@<')E9F5R96YC97,@869T97(@
M=&AE(&-O;F9I9W5R871I;VX@:&%S(&)E96X@;&]A9&5D('1O"B`@("`@("`@
M("H@;6%K92!S=7)E('1H92!P<F5F<R!F:6QE(&AA<R!A;&P@=&AE(&EN9F]R
M;6%T:6]N(&ET(&YE961S+B`J+PH@("`@("`@("1T:&ES+3YL;V%D4')E9G,H
M)&%P<"D["@H@("`@("`@("\J(%)E<V5T('1H92!L86YG=6%G92!I;B!C87-E
M('1H97)E(&ES(&$@9&EF9F5R96YT(&]N90H@("`@("`@("`J('-E;&5C=&5D
M(&EN('1H92!P<F5F97)E;F-E<RX@*B\*("`@("`@("`D;&%N9W5A9V4@/2`G
M)SL*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=
M*2`F)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W!R969S0V%C:&5;)&%P
M<%TM/E]P<F5F<ULG;&%N9W5A9V4G72DI('L*("`@("`@("`@("`@)&QA;F=U
M86=E(#T@)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=+3YG971686QU92@G;&%N
M9W5A9V4G*3L*("`@("`@("!]"B`@("`@("`@3DQ3.CIS971,86YG*"1L86YG
M=6%G92D["B`@("`@("`@3DQ3.CIS971497AT9&]M86EN*"1A<'`L("1T:&ES
M+3YA<'!L:6-A=&EO;G-;)&%P<%U;)V9I;&5R;V]T)UT@+B`G+VQO8V%L92<L
M($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("!3=')I;F<Z.G-E=$1E9F%U
M;'1#:&%R<V5T*$Y,4SHZ9V5T0VAA<G-E="@I*3L*"B`@("`@("`@+RH@3VYC
M92!W92!K;F]W(&5V97)Y=&AI;F<@<W5C8V5E9&5D(&%N9"!I<R!I;B!A(&-O
M;G-I<W1E;G0*("`@("`@("`@*B!S=&%T92!A9V%I;BP@<'5S:"!T:&4@;F5W
M(&%P<&QI8V%T:6]N(&]N=&\@=&AE('-T86-K+B`J+PH@("`@("`@("1T:&ES
M+3Y?87!P4W1A8VM;72`]("1A<'`["B`@("`@("`@)'1H:7,M/E]C=7)R96YT
M07!P(#T@)&%P<#L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296UO=F4@=&AE(&-U<G)E;G0@87!P(&9R;VT@=&AE(&%P
M<&QI8V%T:6]N('-T86-K+"!S971T:6YG('1H92!C=7)R96YT"B`@("`@*B!A
M<'`@=&\@=VAI8VAE=F5R(&%P<"!W87,@8W5R<F5N="!B969O<F4@=&AI<R!O
M;F4@=&]O:R!O=F5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@;F%M92!O9B!T:&4@87!P;&EC871I;VX@=&AA="!W87,@<&]P<&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P;W!!<'`H*0H@("`@>PH@("`@("`@("\J
M(%!O<"!T:&4@8W5R<F5N="!A<'!L:6-A=&EO;B!O9F8@;V8@=&AE('-T86-K
M+B`J+PH@("`@("`@("1P<F5V:6]U<R`](&%R<F%Y7W!O<"@D=&AI<RT^7V%P
M<%-T86-K*3L*"B`@("`@("`@+RH@26UP;W)T('1H92!N97<@86-T:79E(&%P
M<&QI8V%T:6]N)W,@8V]N9FEG=7)A=&EO;B!V86QU97,*("`@("`@("`@*B!A
M;F0@<V5T('1H92!G971T97AT(&1O;6%I;B!A;F0@=&AE('!R969E<G)E9"!L
M86YG=6%G92X@*B\*("`@("`@("`D=&AI<RT^7V-U<G)E;G1!<'`@/2!C;W5N
M="@D=&AI<RT^7V%P<%-T86-K*2`_(&5N9"@D=&AI<RT^7V%P<%-T86-K*2`Z
M(&YU;&P["B`@("`@("`@:68@*"1T:&ES+3Y?8W5R<F5N=$%P<"D@>PH@("`@
M("`@("`@("`D=&AI<RT^:6UP;W)T0V]N9FEG*"1T:&ES+3Y?8W5R<F5N=$%P
M<"D["B`@("`@("`@("`@("1T:&ES+3YL;V%D4')E9G,H)'1H:7,M/E]C=7)R
M96YT07!P*3L*("`@("`@("`@("`@)&QA;F=U86=E(#T@)$=,3T)!3%-;)W!R
M969S)UTM/F=E=%9A;'5E*"=L86YG=6%G92<I.PH@("`@("`@("`@("!I9B`H
M:7-S970H)&QA;F=U86=E*2D@>PH@("`@("`@("`@("`@("`@3DQ3.CIS971,
M86YG*"1L86YG=6%G92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@3DQ3
M.CIS971497AT9&]M86EN*"1T:&ES+3Y?8W5R<F5N=$%P<"P@)'1H:7,M/F%P
M<&QI8V%T:6]N<ULD=&AI<RT^7V-U<G)E;G1!<'!=6R=F:6QE<F]O="==("X@
M)R]L;V-A;&4G+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@(%-T
M<FEN9SHZ<V5T1&5F875L=$-H87)S970H3DQ3.CIG971#:&%R<V5T*"DI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P<F5V:6]U<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@8W5R<F5N="!A<'!L:6-A=&EO;B`M
M('1H92!A<'`@870@=&AE('1O<"!O9B!T:&4@87!P;&EC871I;VX*("`@("`J
M('-T86-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R
M<F5N="!A<'!L:6-A=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T07!P
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C=7)R96YT07!P.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@<&5R;6ES<VEO;G,@;VX@86X@
M87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7
M:&5T:&5R(&]R(&YO="!A8V-E<W,@:7,@86QL;W=E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:&%S4&5R;6ES<VEO;B@D87!P+"`D<&5R;6ES<VEO;B`](%!%
M4DU37U)%040I"B`@("!["B`@("`@("`@<F5T=7)N($%U=&@Z.FES061M:6XH
M*2!\?`H@("`@("`@("`@("`H)$=,3T)!3%-;)W!E<FUS)UTM/F5X:7-T<R@D
M87!P*0H@("`@("`@("`@("`@/R`D1TQ/0D%,4ULG<&5R;7,G72T^:&%S4&5R
M;6ES<VEO;B@D87!P+"!!=71H.CIG971!=71H*"DL("1P97)M:7-S:6]N*0H@
M("`@("`@("`@("`@.B`H8F]O;"E!=71H.CIG971!=71H*"DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5A9',@=&AE(&-O;F9I9W5R871I;VX@=F%L=65S
M(&9O<B!T:&4@9VEV96X@87!P;&EC871I;VX@86YD(&EM<&]R=',*("`@("`J
M('1H96T@:6YT;R!T:&4@9VQO8F%L("1C;VYF('9A<FEA8FQE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&YA;64@;V8@=&AE(&%P
M<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I;7!O<G1#;VYF:6<H)&%P<"D*("`@('L*("`@("`@("`O
M*B!$;VXG="!M86ME(&-O;F9I9R!F:6QE<R!G;&]B86P@)')E9VES=')Y('1H
M96US96QV97,N("HO"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@
M("`@+RH@0V%C:&4@8V]N9FEG('9A;'5E<R!S;R!T:&%T('=E(&1O;B=T(')E
M+7)E860@9FEL97,@;VX@979E<GD*("`@("`@("`@*B!P;W!!<'`H*2!C86QL
M+B`J+PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C;VYF0V%C:&5;)&%P
M<%TI*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C;VYF0V%C
M:&5;)VAO<F1E)UTI*2!["B`@("`@("`@("`@("`@("`D8V]N9B`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("`@("`@
M("`@)'-U8V-E<W,@/2!I;F-L=61E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]C
M;VYF+G!H<"<["B`@("`@("`@("`@("`@("`D97)R;W)S(#T@;V)?9V5T7V-O
M;G1E;G1S*"D["B`@("`@("`@("`@("`@("!O8E]E;F1?8VQE86XH*3L*("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&5R<F]R<RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O
M(&EM<&]R="!(;W)D92!C;VYF:6=U<F%T:6]N.B`G("X@<W1R:7!?=&%G<R@D
M97)R;W)S*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H(21S=6-C97-S*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!I;7!O<G0@2&]R9&4@8V]N9FEG
M=7)A=&EO;BXG*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`O*B!);FET:6%L($AO<F1E+7=I9&4@<V5T=&EN9W,N("HO"@H@("`@("`@
M("`@("`@("`@+RH@4V5T('1H92!E<G)O<B!R97!O<G1I;F<@;&5V96P@:6X@
M86-C;W)D86YC92!W:71H"B`@("`@("`@("`@("`@("`@*B!T:&4@8V]N9FEG
M('-E='1I;F=S+B`J+PH@("`@("`@("`@("`@("`@97)R;W)?<F5P;W)T:6YG
M*"1C;VYF6R=D96)U9U]L979E;"==*3L*"B`@("`@("`@("`@("`@("`O*B!3
M970@=&AE(&UA>&EM=6T@97AE8W5T:6]N('1I;64@:6X@86-C;W)D86YC92!W
M:71H"B`@("`@("`@("`@("`@("`@*B!T:&4@8V]N9FEG('-E='1I;F=S+B`J
M+PH@("`@("`@("`@("`@("`@0'-E=%]T:6UE7VQI;6ET*"1C;VYF6R=M87A?
M97AE8U]T:6UE)UTI.PH*("`@("`@("`@("`@("`@("\J(%-E="!T:&4@=6UA
M<VL@86-C;W)D:6YG('1O(&-O;F9I9R!S971T:6YG<RX@*B\*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D8V]N9ELG=6UA<VLG72DI('L*("`@("`@("`@
M("`@("`@("`@("!U;6%S:R@D8V]N9ELG=6UA<VLG72D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M8V]N9B`]("1T:&ES+3Y?8V]N9D-A8VAE6R=H;W)D92==.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&%P<"`A/3T@)VAO<F1E)RD@>PH@("`@
M("`@("`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@("`@("`@("`@("1S=6-C
M97-S(#T@:6YC;'5D92`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=F:6QE
M<F]O="==("X@)R]C;VYF:6<O8V]N9BYP:'`G.PH@("`@("`@("`@("`@("`@
M)&5R<F]R<R`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@("`@("`@("`@
M;V)?96YD7V-L96%N*"D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1E
M<G)O<G,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)T9A:6QE9"!T;R!I;7!O<G0@87!P;&EC871I;VX@8V]N9FEG
M=7)A=&EO;B!F;W(@)R`N("1A<'`@+B`G.B`G("X@<W1R:7!?=&%G<R@D97)R
M;W)S*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M(21S=6-C97-S*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!I;7!O<G0@87!P;&EC871I;VX@8V]N
M9FEG=7)A=&EO;B!F;W(@)R`N("1A<'`I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-A8VAE5F%R<RAA
M<G)A>2@G7V-O;F9#86-H92<I*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M9D-A8VAE6R1A<'!=(#T@)B1C;VYF.PH@("`@("`@('T*"B`@("`@("`@)$=,
M3T)!3%-;)V-O;F8G72`]("8D=&AI<RT^7V-O;F9#86-H95LD87!P73L*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($QO861S
M('1H92!P<F5F97)E;F-E<R!F;W(@=&AE(&-U<G)E;G0@=7-E<B!F;W(@=&AE
M(&-U<G)E;G0@87!P;&EC871I;VX*("`@("`J(&%N9"!I;7!O<G1S('1H96T@
M:6YT;R!T:&4@9VQO8F%L("1P<F5F<R!V87)I86)L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!N86UE(&]F('1H92!A<'!L:6-A
M=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9%!R969S*"1A<'`@/2!N
M=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D<')E9G-?9&5F875L="`](&9A
M;'-E.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+G!H<"<[
M"@H@("`@("`@(&EF("@D87!P(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1A
M<'`@/2`D=&AI<RT^7V-U<G)E;G1!<'`["B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!T:&5R92!I<R!N;R!L;V=G960@:6X@=7-E<BP@<F5T=7)N(&%N(&5M
M<'1Y(%!R969S.CH*("`@("`@("`@*B!O8FIE8W0@=VET:"!J=7-T(&1E9F%U
M;'0@<')E9F5R96YC97,N("HO"B`@("`@("`@:68@*"%!=71H.CIG971!=71H
M*"DI('L*("`@("`@("`@("`@)'!R969S(#T@)E!R969S.CIF86-T;W)Y*"=N
M;VYE)RP@)&%P<"P@)R<L("<G+"!N=6QL+"!F86QS92D["B`@("`@("`@("`@
M("1P<F5F<RT^<F5T<FEE=F4H*3L*("`@("`@("`@("`@)'1H:7,M/E]P<F5F
M<T-A8VAE6R1A<'!=(#T@)B1P<F5F<SL*("`@("`@("`@("`@)$=,3T)!3%-;
M)W!R969S)UT@/2`F)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=.PH@("`@("`@
M("`@("`D<')E9G-?9&5F875L="`]('1R=64["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@("\J($-A8VAE('!R969S(&]B:F5C=',@
M<V\@=&AA="!W92!D;VXG="!R92UL;V%D('1H96T@;VX@979E<GD*("`@("`@
M("`@*B!P;W!!<'`H*2!C86QL+B`J+PH@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P<F5F<T-A8VAE6R1A<'!=*2!\?`H@("`@("`@("`@("`A96UP='DH
M)'!R969S7V1E9F%U;'0I*2!["B`@("`@("`@("`@("1P<F5F<R`]("90<F5F
M<SHZ9F%C=&]R>2@D1TQ/0D%,4ULG8V]N9B==6R=P<F5F<R==6R=D<FEV97(G
M72P@)&%P<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($%U=&@Z.F=E=$%U=&@H*2P@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O
M<F0G*2D["B`@("`@("`@("`@("1P<F5F<RT^<F5T<FEE=F4H*3L*("`@("`@
M("`@("`@)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=(#T@)B1P<F5F<SL*("`@
M("`@("!]"@H@("`@("`@("1'3$]"04Q36R=P<F5F<R==(#T@)B1T:&ES+3Y?
M<')E9G-#86-H95LD87!P73L*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&]A
M9"!P<F5F97)E;F-E<R!F<F]M(&%N(&%P<&QI8V%T:6]N(&]R("AI9B!N;R!A
M<'!L:6-A=&EO;B!I<PH@("`@("H@<W!E8VEF:65D*2!F<F]M($%,3"!A<'!L
M:6-A=&EO;G,N(%5S969U;"!W:&5N(&$@=7-E<B!H87,@;&]G9V5D"B`@("`@
M*B!O=70@8G5T('EO=2!N965D('1O(&-O;G1I;G5E(&]N('1H92!S86UE('!A
M9V4L(&5T8RX*("`@("`J"B`@("`@*B!!9G1E<B!U;FQO861I;F<L(&EF('1H
M97)E(&ES(&%N(&%P<&QI8V%T:6]N(&]N('1H92!A<'`@<W1A8VL@=&\*("`@
M("`J(&QO860@<')E9F5R96YC97,@9G)O;2P@=&AE;B!W92!R96QO860@82!F
M<F5S:"!S970N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4
M:&4@87!P;&EC871I;VX@=&\@=6YL;V%D('!R969R96YC97,@9F]R+B!)9B!N
M=6QL+`H@("`@("H@("`@("`@("`@("`@("`@("`@("!!3$P@<')E9F5R96YC
M97,@87)E(')E<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;FQO8610<F5F
M<R@D87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&%P<"`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R969S0V%C:&4@/2!A<G)A>2@I
M.PH@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7W!R969S0V%C:&5;
M)&%P<%TI*2!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<')E9G-#86-H
M95LD87!P72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?8W5R<F5N=$%P<"D@
M>PH@("`@("`@("`@("`D=&AI<RT^;&]A9%!R969S*"D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!R97%U97-T960@8V]N
M9FEG=7)A=&EO;B!P87)A;65T97(@9F]R('1H92!S<&5C:69I960*("`@("`J
M(&%P<&QI8V%T:6]N+B!)9B!N;R!A<'!L:6-A=&EO;B!I<R!S<&5C:69I960L
M('1H92!V86QU92!O9@H@("`@("H@)'1H:7,M/E]C=7)R96YT07!P("AT:&4@
M8W5R<F5N="!A<'!L:6-A=&EO;BD@:7,@=7-E9"X@2&]W979E<BP*("`@("`J
M(&EF('1H92!P87)A;65T97(@:7,@;F]T('!R97-E;G0@9F]R('1H870@87!P
M;&EC871I;VXL('1H90H@("`@("H@2&]R9&4M=VED92!V86QU92!I<R!U<V5D
M(&EN<W1E860N($EF('1H870@:7,@;F]T('!R97-E;G0L('=E"B`@("`@*B!R
M971U<FX@;G5L;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A
M;65T97(@(%1H92!C;VYF:6=U<F%T:6]N('9A;'5E('1O(')E=')I979E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("`@("!4:&4@87!P;&EC871I
M;VX@=&\@9V5T('1H92!V86QU92!F;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!R97%U97-T960@<&%R86UE=&5R+"!O<B!N=6QL(&EF
M(&ET(&ES(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D<&%R
M86UE=&5R+"`D87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L
M;"@D87!P*2D@>PH@("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]C=7)R96YT
M07!P.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YA<'!L
M:6-A=&EO;G-;)&%P<%U;)'!A<F%M971E<ETI*2!["B`@("`@("`@("`@("1P
M=F%L(#T@)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LD<&%R86UE=&5R73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)'!A<F%M971E<B`]
M/2`G:6-O;B<I('L*("`@("`@("`@("`@("`@("1P=F%L(#T@)'1H:7,M/E]G
M971)8V]N*"1A<'`I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'!V86P@/2!I<W-E="@D=&AI<RT^87!P;&EC871I;VYS6R=H;W)D
M92==6R1P87)A;65T97)=*2`_("1T:&ES+3YA<'!L:6-A=&EO;G-;)VAO<F1E
M)UU;)'!A<F%M971E<ET@.B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'!A<F%M971E<B`]/2`G;F%M92<I('L*("`@("`@
M("`@("`@<F5T=7)N(%\H)'!V86PI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`D<'9A;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&=6YC=&EO;B!T;R!W;W)K(&]U="!A;B!A<'!L:6-A=&EO;B=S
M(&=R87!H:6-S(%5222P@=&%K:6YG(&EN=&\@86-C;W5N=`H@("`@("H@86YY
M('1H96UE<R!D:7)E8W1O<FEE<R!T:&%T(&UA>2!B92!S970@=7`N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC871I;VX@
M9F]R('=H:6-H('1O(&=E="!T:&4@:6UA9V4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@9&ER96-T;W)Y+B!)9B!B;&%N:R!W:6QL(&1E9F%U;'0@=&\@
M8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@("`@("!A<'!L:6-A=&EO
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&EM86=E(&1I
M<F5C=&]R>2!U<FD@<&%T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26UA
M9V5$:7(H)&%P<"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1A
M<'`I*2!["B`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7V-U<G)E;G1!<'`[
M"B`@("`@("`@?0H*("`@("`@("!S=&%T:6,@)&EM9U]D:7(@/2!A<G)A>2@I
M.PH@("`@("`@(&EF("AI<W-E="@D:6UG7V1I<ELD87!P72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1I;6=?9&ER6R1A<'!=.PH@("`@("`@('T*"B`@("`@
M("`@+RH@5&AI<R!I<R!T:&4@9&5F875L="!L;V-A=&EO;B!F;W(@=&AE(&=R
M87!H:6-S+B`J+PH@("`@("`@("1I;6=?9&ER6R1A<'!=(#T@)'1H:7,M/F=E
M="@G=&AE;65S=7)I)RP@)&%P<"D@+B`G+V=R87!H:6-S)SL*"B`@("`@("`@
M<W1A=&EC("1T:&5M95]I8V]N<SL*"B`@("`@("`@+RH@1FEG=7)E(&]U="!I
M9B!T:&ES(&ES(&=O:6YG('1O(&)E(&]V97)R:61D96X@8GD@86YY('1H96UE
M"B`@("`@("`@("H@<V5T=&EN9W,N("HO"B`@("`@("`@:68@*&ES<V5T*"1'
M3$]"04Q36R=P<F5F<R==*2`F)@H@("`@("`@("`@("`H)'1H96UE(#T@)$=,
M3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=T:&5M92<I*2`F)@H@("`@("`@
M("`@("`H:7-S970H)'1H96UE7VEC;VYS*2!\?`H@("`@("`@("`@("`@*"A`
M:6YC;'5D92`D=&AI<RT^9V5T*"=T:&5M97-F<R<L("=H;W)D92<I("X@)R\G
M("X@)'1H96UE("X@)R]I;F9O+G!H<"<I("8F"B`@("`@("`@("`@("`@:7-S
M970H)'1H96UE7VEC;VYS*2DI("8F"B`@("`@("`@("`@(&EN7V%R<F%Y*"1A
M<'`L("1T:&5M95]I8V]N<RDI('L*("`@("`@("`@("`@)&EM9U]D:7);)&%P
M<%T@/2`D=&AI<RT^9V5T*"=T:&5M97-U<FDG+"`D87!P*2`N("<O)R`N("1T
M:&5M92`N("<O9W)A<&AI8W,G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;6=?9&ER6R1A<'!=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@<&%T:"!T;R!A;B!A<'!L:6-A=&EO;B=S(&EC;VXL(')E<W!E8W1I
M;F<@=VAE=&AE<B!T:&4*("`@("`J(&-U<G)E;G0@=&AE;64@:&%S(&ET<R!O
M=VX@:6-O;G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC871I;VX@
M9F]R('=H:6-H('1O(&=E="!T:&4@:6-O;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$EC;VXH)&%P<"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$EM86=E1&ER*"1A<'`I("X@)R\G("X@)&%P<"`N("<N<&YG)SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%%U97)Y('1H92!I;FET:6%L('!A9V4@9F]R
M(&%N(&%P<&QI8V%T:6]N("T@=&AE('=E8G)O;W0L(&EF('1H97)E(&ES(&YO
M"B`@("`@*B!I;FET:6%L7W!A9V4@<V5T+"!A;F0@=&AE(&EN:71I86Q?<&%G
M92P@:68@:70@:7,@<V5T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%P<"`@5&AE(&YA;64@;V8@=&AE(&%P<&QI8V%T:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!54DP@<&]I;G1I;F<@=&\@=&AE(&EN:71A
M;"!P86=E(&]F('1H92!A<'!L:6-A=&EO;BX*("`@("`J("`@("`@("`@("`@
M("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$EN:71I86Q086=E*"1A<'`@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AI<U]N=6QL*"1A<'`I*2!["B`@("`@("`@("`@("1A<'`@
M/2`D=&AI<RT^7V-U<G)E;G1!<'`["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%TI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B7"(E<UPB
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB*2P@
M)&%P<"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/F%P<&QI
M8V%T:6]N<ULD87!P75LG=V5B<F]O="==("X@)R\G("X@*&ES<V5T*"1T:&ES
M+3YA<'!L:6-A=&EO;G-;)&%P<%U;)VEN:71I86Q?<&%G92==*2`_("1T:&ES
M+3YA<'!L:6-A=&EO;G-;)&%P<%U;)VEN:71I86Q?<&%G92==(#H@)R<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("HO
M"B`@("!F=6YC=&EO;B!?7V=E="@D87!I*0H@("`@>PH@("`@("`@(&EF("AI
M;E]A<G)A>2@D87!I+"`D=&AI<RT^;&ES=$%027,H*2DI('L*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!296=I<W1R>4-A;&QE<B@D=&AI<RP@)&%P:2D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VQO;F4@<VAO=6QD(&YE
M=F5R(&)E(&-A;&QE9"!O;B!296=I<W1R>2!O8FIE8W1S+B!)9B!I="!I<RP@
M9&EE+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J+PH@
M("`@9G5N8W1I;VX@7U]C;&]N92@I"B`@("!["B`@("`@("`@2&]R9&4Z.F9A
M=&%L*"=296=I<W1R>2!O8FIE8W1S('-H;W5L9"!N979E<B!B92!C;&]N960N
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@('T*"GT*"B\J*@H@*B!`<&%C
M:V%G92!(;W)D95]&<F%M97=O<FL*("H@0'-I;F-E($AO<F1E(#,N,0H@*B\*
M8VQA<W,@4F5G:7-T<GE#86QL97(@>PH*("`@('9A<B`D<F5G:7-T<GD["B`@
M("!V87(@)&%P:3L*"B`@("!F=6YC=&EO;B!?7V-O;G-T<G5C="@D<F5G:7-T
M<GDL("1A<&DI"B`@("!["B`@("`@("`@)'1H:7,M/G)E9VES=')Y(#T@)')E
M9VES=')Y.PH@("`@("`@("1T:&ES+3YA<&D@/2`D87!I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]?8V%L;"@D;65T:&]D+"`D87)G<RD*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G)E9VES=')Y+3YC86QL*"1T:&ES+3YA<&D@+B`G
M+R<@+B`D;65T:&]D+"`D87)G<RD["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="YP:'``````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S0W`#$P
M-#$W,S8R-S<S`#`Q-S<P,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE(%1E>'0Z.B!C;&%S<R!P
M<F]V:61E<R!C;VUM;VX@;65T:&]D<R!F;W(@;6%N:7!U;&%T:6YG('1E>'0N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U1E>'0N<&AP
M+'8@,2XR+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HR,"!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\
M:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K
M86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'0@>PH*("`@("\J*@H@("`@
M("H@0V]N=F5R="!A(&QI;F4@;V8@=&5X="!T;R!D:7-P;&%Y('!R;W!E<FQY
M(&EN($A434PN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@
M5&AE('-T<FEN9R!O9B!T97AT('1O(&-O;G9E<G0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!(5$U,+6-O;7!L:6%N="!C;VYV97)T960@
M=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@:'1M;%-P86-E<R@D=&5X="`]
M("<G*0H@("`@>PH@("`@("`@('-T871I8R`D8VAA<G-E=#L*("`@("`@("!I
M9B`H(6ES<V5T*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]
M($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@)'1E>'0@
M/2!`:'1M;'-P96-I86QC:&%R<R@D=&5X="P@14Y47T-/35!!5"P@)&-H87)S
M970I.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H(EQT(BP@)R9N8G-P
M.R`F;F)S<#L@)FYB<W`[("9N8G-P.R`G+"`D=&5X="D["B`@("`@("`@)'1E
M>'0@/2!S=')?<F5P;&%C92@G("`G+"`G)FYB<W`[("<L("1T97AT*3L*("`@
M("`@("`D=&5X="`]('-T<E]R97!L86-E*"<@("<L("<@)FYB<W`[)RP@)'1E
M>'0I.PH*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!386UE(&%S(&AT;6Q3<&%C97,H*2!B=70@8V]N=F5R=',@86QL('-P
M86-E<R!T;R`F;F)S<#L*("`@("`J"B`@("`@*B!`<V5E(&AT;6Q3<&%C97,H
M*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!S=')I
M;F<@;V8@=&5X="!T;R!C;VYV97)T+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@2%1-3"UC;VUP;&EA;G0@8V]N=F5R=&5D('1E>'0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&AT;6Q!;&Q3<&%C97,H)'1E>'0@/2`G)RD*
M("`@('L*("`@("`@("`D=&5X="`](%1E>'0Z.FAT;6Q3<&%C97,H)'1E>'0I
M.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)R`G+"`G)FYB<W`[)RP@
M)'1E>'0I.PH*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@I]"@``````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92])9&5N=&ET>2YP:'``````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,S$V-S4`,3`T,3<S-C(W-S,`,#(P-34P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&%N(&EN=&5R9F%C92!T;R!A;&P@
M:61E;G1I=&EE<R!A('5S97(@;6EG:'0@:&%V92X@271S"B`J(&UE=&AO9',@
M=&%K92!C87)E(&]F(&%N>2!S:71E+7-P96-I9FEC(')E<W1R:6-T:6]N<R!C
M;VYF:6=U<F5D(&EN('!R969S+G!H<`H@*B!A;F0@8V]N9BYP:'`N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<"QV(#$N
M-3`N,3`N,3$@,C`P-B\P,2\R,"`P,3HS,#HP-2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#$M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS+C4*("H@
M0'!A8VMA9V4@2&]R9&5?261E;G1I='D*("HO"F-L87-S($ED96YT:71Y('L*
M"B`@("`O*BH*("`@("`J($%R<F%Y(&-O;G1A:6YI;F<@86QL('1H92!U<V5R
M)W,@:61E;G1I=&EE<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7VED96YT:71I97,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@02!P;VEN=&5R('1O('1H92!U<V5R)W,@<W1A;F1A<F0@:61E;G1I
M='DN"B`@("`@*B!4:&ES(&]N92!I<R!U<V5D(&)Y('1H92!M971H;V1S(')E
M='5R;FEN9R!V86QU97,@:68@;F\@;W1H97(@;VYE(&ES"B`@("`@*B!S<&5C
M:69I960N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@
M('9A<B`D7V1E9F%U;'0@/2`P.PH*("`@("\J*@H@("`@("H@5&AE('5S97(@
M=VAO<V4@:61E;G1I=&EE<R!T:&5S92!A<F4N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=7-E<B`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!!<G)A>2!C;VYT86EN:6YG(&%L;"!O9B!T:&4@<')O<&5R
M=&EE<R!I;B!T:&ES(&ED96YT:71Y+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<')O<&5R=&EE<R`](&%R<F%Y*"=I9"<L
M("=F=6QL;F%M92<L("=F<F]M7V%D9'(G*3L*"B`@("`O*BH*("`@("`J(%)E
M9F5R96YC92!T;R!T:&4@<')E9G,@;V)J96-T('1H870@=&AI<R!)9&5N=&ET
M>2!P;VEN=',@=&\N"B`@("`@*@H@("`@("H@0'9A<B!0<F5F<PH@("`@("HO
M"B`@("!V87(@)%]P<F5F<SL*"B`@("`O*BH*("`@("`J(%)E861S(&%L;"!T
M:&4@=7-E<B=S(&ED96YT:71I97,@9G)O;2!T:&4@<')E9G,@;V)J96-T(&]R
M(&)U:6QD<R!A(&YE=PH@("`@("H@:61E;G1I='D@9G)O;2!T:&4@<W1A;F1A
M<F0@=F%L=65S(&=I=F5N(&EN('!R969S+G!H<"X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R("!)9B!S<&5C:69I960L('=E(')E860@86YO
M=&AE<B!U<V5R)W,@:61E;G1I=&EE<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@:6YS=&5A9"!O9B!T:&4@8W5R<F5N="!U<V5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!)9&5N=&ET>2@D=7-E<B`](&YU;&PI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]U<V5R(#T@)'5S97(["B`@("`@("`@:68@*&ES7VYU;&PH
M)'5S97(I('Q\("1U<V5R(#T]($%U=&@Z.F=E=$%U=&@H*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!R969S(#T@)B1'3$]"04Q36R=P<F5F<R==.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<')E9G,@/2`F4')E
M9G,Z.G-I;F=L971O;B@D1TQ/0D%,4ULG8V]N9B==6R=P<F5F<R==6R=D<FEV
M97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!<'`H*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R
M+"`G)RP@;G5L;"P@9F%L<V4I.PH@("`@("`@("`@("`D=&AI<RT^7W!R969S
M+3YR971R:65V92@I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V1E9F%U
M;'0@/2`D=&AI<RT^7W!R969S+3YG971686QU92@G9&5F875L=%]I9&5N=&ET
M>2<I.PH*("`@("`@("!I9B`H(2@D=&AI<RT^7VED96YT:71I97,@/2!`=6YS
M97)I86QI>F4H)'1H:7,M/E]P<F5F<RT^9V5T5F%L=64H)VED96YT:71I97,G
M+"!F86QS92DI*2D@>PH@("`@("`@("`@("`O*B!#;VYV97)T(&ED96YT:71I
M97,@9G)O;2!T:&4@;VQD(&9O<FUA="X@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]I9&5N=&ET:65S(#T@=6YS97)I86QI>F4H)'1H:7,M/E]P<F5F<RT^9V5T
M5F%L=64H)VED96YT:71I97,G*2D["B`@("`@("`@?2!E;'-E:68@*&ES7V%R
M<F%Y*"1T:&ES+3Y?:61E;G1I=&EE<RDI('L*("`@("`@("`@("`@)'1H:7,M
M/E]I9&5N=&ET:65S(#T@)'1H:7,M/E]P<F5F<RT^8V]N=F5R=$9R;VU$<FEV
M97(H)'1H:7,M/E]I9&5N=&ET:65S+"!.3%,Z.F=E=$-H87)S970H*2D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&1E9F%U
M;'0@:61E;G1I='D@:68@;F]N92!E>&ES=',@>65T(&%N9"!S971S('1H92!P
M<F5F97)E;F-E<PH@("`@("H@=7`@:68@=&AE(&ED96YT:71I97,@87)E(&QO
M8VME9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D=&AI<RT^7VED96YT:71I97,I('Q\("AC;W5N
M="@D=&AI<RT^7VED96YT:71I97,I(#P](#`I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?<')O<&5R=&EE<R!A<R`D:V5Y*2!["B`@("`@("`@
M("`@("`@("`D:61E;G1I='E;)&ME>5T@/2`D=&AI<RT^7W!R969S+3YG9716
M86QU92@D:V5Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H96UP
M='DH)&ED96YT:71Y6R=I9"==*2D@>PH@("`@("`@("`@("`@("`@)&ED96YT
M:71Y6R=I9"==(#T@7R@B1&5F875L="!)9&5N=&ET>2(I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D=&AI<RT^7VED96YT:71I97,@/2!A<G)A>2@D
M:61E;G1I='DI.PH@("`@("`@("`@("`D=&AI<RT^=F5R:69Y*#`I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?<')E9G,M/FES3&]C:V5D*"=D
M969A=6QT7VED96YT:71Y)RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]P<F]P97)T:65S(&%S("1K97DI('L*("`@("`@("`@("`@("`@("1V
M86QU92`]("1T:&ES+3YG971686QU92@D:V5Y*3L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E(#T@:6UP;&]D92@B7&XB+"`D=F%L=64I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5F<RT^<V5T5F%L=64H
M)&ME>2P@)'9A;'5E*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<')E9G,M
M/G-E=$1I<G1Y*"1K97DL(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%-A=F5S(&%L;"!I9&5N=&ET:65S
M(&EN('1H92!P<F5F<R!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M879E*"D*("`@('L*("`@("`@("`D:61E;G1I=&EE<R`]("1T:&ES+3Y?:61E
M;G1I=&EE<SL*("`@("`@("!I9B`H:7-?87)R87DH)&ED96YT:71I97,I*2![
M"B`@("`@("`@("`@("1I9&5N=&ET:65S(#T@)'1H:7,M/E]P<F5F<RT^8V]N
M=F5R=%1O1')I=F5R*"1I9&5N=&ET:65S+"!.3%,Z.F=E=$-H87)S970H*2D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!R969S+3YS971686QU92@G
M:61E;G1I=&EE<R<L('-E<FEA;&EZ92@D:61E;G1I=&EE<RDL(&9A;'-E*3L*
M("`@("`@("`D=&AI<RT^7W!R969S+3YS971686QU92@G9&5F875L=%]I9&5N
M=&ET>2<L("1T:&ES+3Y?9&5F875L="D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&1S(&$@;F5W(&5M<'1Y(&ED96YT:71Y('1O('1H92!A<G)A>2!O9B!I
M9&5N=&ET:65S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE
M('!O:6YT97(@=&\@=&AE(&-R96%T960@:61E;G1I='D*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D*"D*("`@('L*("`@("`@("`D=&AI<RT^7VED96YT:71I
M97-;72`](&%R<F%Y*"D["B`@("`@("`@<F5T=7)N(&-O=6YT*"1T:&ES+3Y?
M:61E;G1I=&EE<RD@+2`Q.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E
M<R!A;B!I9&5N=&ET>2!F<F]M('1H92!A<G)A>2!O9B!I9&5N=&ET:65S+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9&5N=&ET>2`@5&AE('!O
M:6YT97(@=&\@=&AE(&ED96YT:71Y('1O(&)E(')E;6]V960*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5M;W9E9"!I9&5N=&ET>0H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96QE=&4H)&ED96YT:71Y*0H@("`@>PH@("`@
M("`@("1D96QE=&5D(#T@87)R87E?<W!L:6-E*"1T:&ES+3Y?:61E;G1I=&EE
M<RP@)&ED96YT:71Y+"`Q*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VED
M96YT:71I97,@87,@)&ED(#T^("1N=6QL*2!["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^<V5T1&5F875L="@D:60I*2!["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^<V%V
M92@I.PH@("`@("`@(')E='5R;B`D9&5L971E9#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!P;VEN=&5R('1O('1H92!C=7)R96YT(&1E9F%U
M;'0@:61E;G1I='DN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@<&]I;G1E<B!T;R!T:&4@8W5R<F5N="!D969A=6QT(&ED96YT:71Y"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'0H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1E9F%U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971S('1H92!C=7)R96YT(&1E9F%U;'0@:61E;G1I='DN"B`@("`@*B!)
M9B!T:&4@:61E;G1I='D@9&]E<VXG="!E>&ES="P@=&AE(&]L9"!D969A=6QT
M(&ED96YT:71Y('-T87ES('1H92!S86UE+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I9&5N=&ET>2`@5&AE('!O:6YT97(@=&\@=&AE(&YE=R!D
M969A=6QT(&ED96YT:71Y"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T1&5F875L="@D:61E;G1I='DI"B`@("!["B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?:61E;G1I=&EE<ULD:61E;G1I='E=*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V1E9F%U;'0@/2`D:61E;G1I='D["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@<')O<&5R='D@9G)O;2!O;F4@;V8@=&AE(&ED
M96YT:71I97,N($EF('1H:7,@=F%L=64@9&]E<VXG=`H@("`@("H@97AI<W0@
M;W(@:7,@;&]C:V5D+"!T:&4@<')O<&5R='D@:7,@<F5T<FEE=F5D(&9R;VT@
M=&AE('!R969S(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:V5Y("`@("`@("!4:&4@<')O<&5R='D@=&\@<F5T<FEE=F4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D:61E;G1I='D@(%1H92!I9&5N=&ET>2!T;R!R
M971R:65V92!T:&4@<')O<&5R='D@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@=F%L=64@;V8@=&AE('!R;W!E<G1Y+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971686QU92@D:V5Y+"`D:61E;G1I='D@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&ED96YT:71Y*2!\?"`A:7-S
M970H)'1H:7,M/E]I9&5N=&ET:65S6R1I9&5N=&ET>5TI*2!["B`@("`@("`@
M("`@("1I9&5N=&ET>2`]("1T:&ES+3Y?9&5F875L=#L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]I9&5N=&ET:65S6R1I9&5N=&ET
M>5U;)&ME>5TI('Q\("1T:&ES+3Y?<')E9G,M/FES3&]C:V5D*"1K97DI*2![
M"B`@("`@("`@("`@("1V86P@/2`D=&AI<RT^7W!R969S+3YG971686QU92@D
M:V5Y*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L(#T@)'1H
M:7,M/E]I9&5N=&ET:65S6R1I9&5N=&ET>5U;)&ME>5T["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'9A;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@86X@87)R87D@=VET:"!T:&4@<W!E8VEF:65D('!R;W!E<G1Y(&9R
M;VT@86QL(&5X:7-T:6YG"B`@("`@*B!I9&5N=&ET:65S+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ME>2`@5&AE('!R;W!E<G1Y('1O(')E=')I
M979E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!A<G)A>2!W
M:71H('1H92!V86QU97,@9G)O;2!A;&P@:61E;G1I=&EE<PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971!;&PH)&ME>2D*("`@('L*("`@("`@("`D;&ES="`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I9&5N=&ET:65S
M(&%S("1I9&5N=&ET>2`]/B`D;G5L;"D@>PH@("`@("`@("`@("`D;&ES=%LD
M:61E;G1I='E=(#T@)'1H:7,M/F=E=%9A;'5E*"1K97DL("1I9&5N=&ET>2D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;&ES=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@82!P<F]P97)T>2!W:71H(&$@<W!E8VEF:65D('9A
M;'5E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("`@("`@
M5&AE('!R;W!E<G1Y('1O('-E=`H@("`@("H@0'!A<F%M(&UI>&5D("1V86P@
M("`@("`@("!4:&4@=F%L=64@=&\@=VAI8V@@=&AE('!R;W!E<G1Y('-H;W5L
M9"!B92!S970*("`@("`J($!P87)A;2!I;G1E9V5R("1I9&5N=&ET>2`@5&AE
M(&ED96YT:71Y('1O('-E="!T:&4@<')O<&5R='D@:6XN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N
M(&9A:6QU<F4@*'!R;W!E<G1Y('=A<R!L;V-K960I"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%9A;'5E*"1K97DL("1V86PL("1I9&5N=&ET>2`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D:61E;G1I='DI*2!["B`@("`@
M("`@("`@("1I9&5N=&ET>2`]("1T:&ES+3Y?9&5F875L=#L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A)'1H:7,M/E]P<F5F<RT^:7-,;V-K960H)&ME>2DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=&ET:65S6R1I9&5N=&ET>5U;
M)&ME>5T@/2`D=F%L.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF(&%L;"!P
M<F]P97)T:65S(&%R92!L;V-K960@86YD('1H97)E9F]R92!N;W1H:6YG(&EN
M('1H90H@("`@("H@:61E;G1I=&EE<R!C86X@8F4@8VAA;F=E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@86QL('!R;W!E<G1I
M97,@87)E(&QO8VME9"P@9F%L<V4@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&ES3&]C:V5D*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7W!R;W!E<G1I97,@87,@)&ME>2D@>PH@("`@("`@("`@("!I9B`H(21T
M:&ES+3Y?<')E9G,M/FES3&]C:V5D*"1K97DI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T<G5E(&EF('1H92!G:79E;B!A9&1R97-S(&)E;&]N9W,@=&\@;VYE(&]F
M('1H92!I9&5N=&ET:65S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ME>2`@("!4:&4@:61E;G1I='D@:V5Y('1O('-E87)C:"X*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;'5E("!4:&4@=F%L=64@=&\@<V5A<F-H(&9O<B!I
M;B`D:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T:&4@)'9A;'5E('=A<R!F;W5N9"!I;B`D:V5Y+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!H87-686QU92@D:V5Y+"`D=F%L=65!*0H@("`@>PH@("`@("`@
M("1L:7-T(#T@)'1H:7,M/F=E=$%L;"@D:V5Y*3L*("`@("`@("!F;W)E86-H
M("@D;&ES="!A<R`D=F%L=65"*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H
M4W1R:6YG.CIL;W=E<B@D=F%L=65!*2P@4W1R:6YG.CIL;W=E<B@D=F%L=65"
M*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!697)I9FEE<R!A;F0@<V%N:71I>F5S
M(&%L;"!I9&5N=&ET>2!P<F]P97)T:65S+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I9&5N=&ET>2`@5&AE(&ED96YT:71Y('1O('9E<FEF>2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQ\;V)J96-T("!4<G5E(&EF('1H
M92!P<F]P97)T:65S(&%R92!V86QI9"!O<B!A(%!%05)?17)R;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@('=I=&@@86X@97)R;W(@9&5S8W)I<'1I
M;VX@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!V97)I9GDH)&ED
M96YT:71Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1I9&5N
M=&ET>2DI('L*("`@("`@("`@("`@)&ED96YT:71Y(#T@)'1H:7,M/E]D969A
M=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^9V5T5F%L=64H
M)VED)RP@)&ED96YT:71Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T5F%L
M=64H)VED)RP@7R@B56YN86UE9"(I+"`D:61E;G1I='DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4D9#(#(X,C(@6S,N,BXU72!D;V5S(&YO="!A;&QO=R!T
M:&4@)UPG(&-H87)A8W1E<B!T;R!B92!U<V5D(&EN('1H90H@("`@("`@("`J
M('!E<G-O;F%L('!O<G1I;VX@;V8@86X@92UM86EL('-T<FEN9RX@*B\*("`@
M("`@("!I9B`H<W1R<&]S*"1T:&ES+3YG971686QU92@G9G5L;&YA;64G+"`D
M:61E;G1I='DI+"`G7%PG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B66]U(&-A;FYO="!H879E('1H92`G
M7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E<R!T:&4@9G)O;2!A9&1R97-S('1O('5S92!F;W(@=&AE(&1E
M9F%U;'0@:61E;G1I='DN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&9U;&QN86UE("!);F-L=61E('1H92!F=6QL;F%M92!I;F9O<FUA=&EO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E9F%U;'0@9G)O
M;2!A9&1R97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT1G)O
M;4%D9')E<W,H)&9U;&QN86UE(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&9R
M;VU?861D<B`]("<G.PH*("`@("`@("!I9B`H)&9U;&QN86UE*2!["B`@("`@
M("`@("`@("1N86UE(#T@)'1H:7,M/F=E=%9A;'5E*"=F=6QL;F%M92<I.PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("`@
M("`@)&9R;VU?861D<B`]("1N86UE("X@)R`G.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D861D<B`]("1T:&ES+3YG971686QU92@G9G)O
M;5]A9&1R)RD["B`@("`@("`@:68@*&5M<'1Y*"1A9&1R*2D@>PH@("`@("`@
M("`@("`D861D<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9G)O;5]A9&1R("X@)SPG("X@)&%D9'(@+B`G/B<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC
M<F5T92!)9&5N=&ET>2!I;G-T86YC92!B87-E9"!O;B`D='EP92X*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@)'1Y<&4@("!4:&4@='EP92!O9B!C;VYC
M<F5T92!)9&5N=&ET>2!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!4:&ES(&ES(&)A<V5D(&]N('1H92!S=&]R86=E
M(&1R:79E<B`H)'1Y<&4I+B!4:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF("1T>7!E(&ES
M(&%N(&%R<F%Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@=&AE;B!W
M92!W:6QL(&QO;VL@:6X@)'1Y<&5;,%TO;&EB+TED96YT:71Y+R!F;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@('1H92!S=6)C;&%S<R!I;7!L96UE
M;G1A=&EO;B!N86UE9"`D='EP95LQ72YP:'`N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R("!)9B!S<&5C:69I960L('=E(')E860@86YO=&AE<B!U<V5R
M)W,@:61E;G1I=&EE<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@:6YS
M=&5A9"!O9B!T:&4@8W5R<F5N="!U<V5R+@H@("`@("H*("`@("`J($!R971U
M<FX@261E;G1I='D@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($ED96YT
M:71Y(&EN<W1A;F-E+"!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@
M("`@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y
M*"1T>7!E(#T@)VYO;F4G+"`D=7-E<B`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1T>7!E*2D@>PH@("`@("`@("`@("`D87!P(#T@)'1Y
M<&5;,%T["B`@("`@("`@("`@("1T>7!E(#T@)'1Y<&5;,5T["B`@("`@("`@
M?0H*("`@("`@("`O*B!2971U<FX@82!B87-E($ED96YT:71Y(&]B:F5C="!I
M9B!N;R!D<FEV97(@:7,@<W!E8VEF:65D+B`J+PH@("`@("`@("1T>7!E(#T@
M8F%S96YA;64H)'1Y<&4I.PH@("`@("`@(&EF("AE;7!T>2@D='EP92D@?'P@
M*'-T<F-M<"@D='EP92P@)VYO;F4G*2`]/2`P*2D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V4@/2`F;F5W($ED96YT:71Y*"1U<V5R*3L*("`@("`@("`@("`@
M)&EN<W1A;F-E+3YI;FET*"D["B`@("`@("`@("`@(')E='5R;B`D:6YS=&%N
M8V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O261E;G1I='DO)R`N("1T
M>7!E("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+TED96YT:71Y+R<@+B`D='EP92`N("<N
M<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R])9&5N=&ET>2\G("X@)'1Y<&4@+B`G+G!H<"<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O
M261E;G1I='DO)R`N("1T>7!E("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@
M("`D8VQA<W,@/2`G261E;G1I='E?)R`N("1T>7!E.PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V4@
M/2`F;F5W("1C;&%S<R@D=7-E<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I
M;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*
M"B`@("`@("`@)&EN<W1A;F-E+3YI;FET*"D["B`@("`@("`@<F5T=7)N("1I
M;G-T86YC93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E
M='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($ED96YT:71Y(&EN<W1A
M;F-E(&)A<V5D(&]N"B`@("`@*B`D='EP92X@270@=VEL;"!O;FQY(&-R96%T
M92!A(&YE=R!I;G-T86YC92!I9B!N;R!)9&5N=&ET>2!I;G-T86YC92!W:71H
M"B`@("`@*B!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N
M"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L
M92!T>7!E<R!O9B!I9&5N=&ET:65S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT
M:7!L92!)9&5N=&ET>2!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J
M"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@
M/2`F261E;G1I='DZ.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1T>7!E("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@261E;G1I='D@
M<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@5&AI<R!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@*"1T>7!E
M*2X@5&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!C;V1E(&ES(&1Y
M;F%M:6-A;&QY(&EN8VQU9&5D+B!)9B`D='EP92!I<R!A;B!A<G)A>2P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@('1H96X@=V4@=VEL;"!L;V]K(&EN
M("1T>7!E6S!=+VQI8B])9&5N=&ET>2\@9F]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!T:&4@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@
M)'1Y<&5;,5TN<&AP+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@268@
M<W!E8VEF:65D+"!W92!R96%D(&%N;W1H97(@=7-E<B=S(&ED96YT:71I97,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&-U
M<G)E;G0@=7-E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N($ED96YT:71Y("!4
M:&4@8V]N8W)E=&4@261E;G1I='D@<F5F97)E;F-E+"!O<B!F86QS92!O;B!A
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D='EP
M92`]("=N;VYE)RP@)'5S97(@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I
M8R`D:6YS=&%N8V5S.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI
M('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@
M?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1T>7!E
M+"`D=7-E<BDI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72`]("9)9&5N=&ET>3HZ9F%C=&]R>2@D='EP92P@)'5S97(I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92YP:'``````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S4S-S0`,3`T,3<S-C(W-S,`,#(P
M,#`Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U5T:6PN<&AP)SL*"B\J*@H@
M*B!4:&ES(&-L87-S(&1E9FEN97,@=&AE($AO<F1E7TEM86=E.CH@05!)+"!A
M;F0@86QS;R!P<F]V:61E<R!S;VUE"B`J('5T:6QI='D@9G5N8W1I;VYS+"!S
M=6-H(&%S(&=E;F5R871I;F<@:&EG:&QI9VAT<R!O9B!A(&-O;&]R+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]);6%G92]);6%G92YP:'`L=B`Q+C,Y+C$P
M+C$S(#(P,#8O,#$O,#$@,C$Z,C@Z,C(@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E($AO<F1E7TEM86=E"B`J+PIC;&%S<R!(;W)D95]);6%G92![
M"@H@("`@+RHJ"B`@("`@*B!#=7)R96YT(&-O;&]R+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W)G8B`]("=F9C`P,#`G
M.PH*("`@("\J*@H@("`@("H@0F%C:V=R;W5N9"!C;VQO<BX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]B86-K9W)O=6YD
M(#T@)W=H:71E)SL*"B`@("`O*BH*("`@("`J($]B<V5R=F5R<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]B<V5R=F5R
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#87!A8FEL:71E<R!O9B!T
M:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7V-A<&%B:6QI=&EE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!4:&4@8W5R<F5N="!I;6%G92!D871A+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1A=&$@/2`G)SL*"B`@("`O
M*BH*("`@("`J(%1H92!C=7)R96YT(&EM86=E(&ED+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VED(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!W:61T:"!O9B!T:&4@:6UA9V4@9&%T
M82X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R
M("1?=VED=&@@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@:&5I
M9VAT(&]F('1H92!I;6%G92!D871A+@H@("`@("H*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("HO"B`@("!V87(@)%]H96EG:'0@/2`P.PH*("`@("\J*@H@
M("`@("H@02!D:7)E8W1O<GD@9F]R('1E;7!O<F%R>2!F:6QE<RX*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T;7!D:7([
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1R9V(@(%1H92!B87-E(&-O;&]R(&9O<B!G96YE<F%T
M960@<&EX96QS+VEM86=E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?
M26UA9V4H)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W1M<&1I<B`]
M("1P87)A;7-;)W1E;7`G73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG
M=VED=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]W:61T:"`]("1P87)A
M;7-;)W=I9'1H)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D<&%R
M86US6R=H96EG:'0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]H96EG:'0@
M/2`D<&%R86US6R=H96EG:'0G73L*("`@("`@("!]"B`@("`@("`@:68@*"%E
M;7!T>2@D<&%R86US6R=R9V(G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]R
M9V(@/2`D<&%R86US6R=R9V(G73L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/E]B86-K9W)O=6YD(#T@:7-S970H)'!A<F%M<ULG8F%C:V=R;W5N9"==*2`_
M("1P87)A;7-;)V)A8VMG<F]U;F0G72`Z("=W:&ET92<["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T0V%P86)I;&ET:65S*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]C87!A8FEL:71I97,["B`@("!]"@H@("`@9G5N8W1I;VX@
M:&%S0V%P86)I;&ET>2@D8V%P86)I;&ET>2D*("`@('L*("`@("`@("!R971U
M<FX@:6Y?87)R87DH)&-A<&%B:6QI='DL("1T:&ES+3Y?8V%P86)I;&ET:65S
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971,:6YK*"1U<FPL("1T:71L92`]
M("<G*0H@("`@>PH@("`@("`@(')E='5R;B!(;W)D93HZ:6UG*"1U<FPL("1T
M:71L92P@)R<L("<G*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E
M(&EM86=E(&AE861E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AE861E<G,H
M*0H@("`@>PH@("`@("`@(&AE861E<B@G0V]N=&5N="UT>7!E.B`G("X@)'1H
M:7,M/F=E=$-O;G1E;G14>7!E*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V%L8W5L871E(&$@;&EG:'1E<B`H;W(@9&%R:V5R*2!V97)S:6]N(&]F(&$@
M8V]L;W(N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O;&]R("`@06X@2%1-3"!C;VQO<BP@92YG+CH@(V9F
M9F9C8RX*("`@("`J($!P87)A;2!S=')I;F<@)&9A8W1O<B`@5$]$3PH@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!!(&UO9&EF:65D($A434P@8V]L
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>4-O;&]R*"1C;VQO<BP@
M)&9A8W1O<B`](#!X,3$I"B`@("!["B`@("`@("`@)'(@/2!H97AD96,H<W5B
M<W1R*"1C;VQO<BP@,2P@,BDI("L@)&9A8W1O<CL*("`@("`@("`D9R`](&AE
M>&1E8RAS=6)S='(H)&-O;&]R+"`S+"`R*2D@*R`D9F%C=&]R.PH@("`@("`@
M("1B(#T@:&5X9&5C*'-U8G-T<B@D8V]L;W(L(#4L(#(I*2`K("1F86-T;W([
M"@H@("`@("`@("1R(#T@;6EN*&UA>"@D<BP@,"DL(#(U-2D["B`@("`@("`@
M)&<@/2!M:6XH;6%X*"1G+"`P*2P@,C4U*3L*("`@("`@("`D8B`](&UI;BAM
M87@H)&(L(#`I+"`R-34I.PH*("`@("`@("!R971U<FX@)R,G("X@<W1R7W!A
M9"AD96-H97@H)'(I+"`R+"`G,"<L(%-44E]0041?3$5&5"D@+B!S=')?<&%D
M*&1E8VAE>"@D9RDL(#(L("<P)RP@4U127U!!1%],1494*2`N('-T<E]P860H
M9&5C:&5X*"1B*2P@,BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V%L8W5L871E(&$@;6]R92!I;G1E;G-E('9E<G-I;VX@
M;V8@82!C;VQO<BX*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("!!;B!(5$U,(&-O;&]R+"!E+F<N
M.B`C9F9F9F-C+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F%C=&]R("!43T1/
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@;6]R92!I;G1E;G-E
M($A434P@8V]L;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO<F5);G1E;G-E
M0V]L;W(H)&-O;&]R+"`D9F%C=&]R(#T@,'@Q,2D*("`@('L*("`@("`@("`D
M<B`](&AE>&1E8RAS=6)S='(H)&-O;&]R+"`Q+"`R*2D["B`@("`@("`@)&<@
M/2!H97AD96,H<W5B<W1R*"1C;VQO<BP@,RP@,BDI.PH@("`@("`@("1B(#T@
M:&5X9&5C*'-U8G-T<B@D8V]L;W(L(#4L(#(I*3L*"B`@("`@("`@:68@*"1R
M(#X]("1G("8F("1R(#X]("1B*2!["B`@("`@("`@("`@("1G(#T@)&<@+R`D
M<CL*("`@("`@("`@("`@)&(@/2`D8B`O("1R.PH*("`@("`@("`@("`@)'(@
M*ST@)&9A8W1O<CL*("`@("`@("`@("`@)&<@/2!F;&]O<B@D9R`J("1R*3L*
M("`@("`@("`@("`@)&(@/2!F;&]O<B@D8B`J("1R*3L*("`@("`@("!](&5L
M<V5I9B`H)&<@/CT@)'(@)B8@)&<@/CT@)&(I('L*("`@("`@("`@("`@)'(@
M/2`D<B`O("1G.PH@("`@("`@("`@("`D8B`]("1B("\@)&<["@H@("`@("`@
M("`@("`D9R`K/2`D9F%C=&]R.PH@("`@("`@("`@("`D<B`](&9L;V]R*"1R
M("H@)&<I.PH@("`@("`@("`@("`D8B`](&9L;V]R*"1B("H@)&<I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R(#T@)'(@+R`D8CL*("`@("`@
M("`@("`@)&<@/2`D9R`O("1B.PH*("`@("`@("`@("`@)&(@*ST@)&9A8W1O
M<CL*("`@("`@("`@("`@)'(@/2!F;&]O<B@D<B`J("1B*3L*("`@("`@("`@
M("`@)&<@/2!F;&]O<B@D9R`J("1B*3L*("`@("`@("!]"@H@("`@("`@("1R
M(#T@;6EN*&UA>"@D<BP@,"DL(#(U-2D["B`@("`@("`@)&<@/2!M:6XH;6%X
M*"1G+"`P*2P@,C4U*3L*("`@("`@("`D8B`](&UI;BAM87@H)&(L(#`I+"`R
M-34I.PH*("`@("`@("!R971U<FX@)R,G("X@<W1R7W!A9"AD96-H97@H)'(I
M+"`R+"`G,"<L(%-44E]0041?3$5&5"D@+B!S=')?<&%D*&1E8VAE>"@D9RDL
M(#(L("<P)RP@4U127U!!1%],1494*2`N('-T<E]P860H9&5C:&5X*"1B*2P@
M,BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@8G)I9VAT;F5S<R!O9B!A(&-O;&]R+@H@("`@("H*("`@
M("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO
M<B`@06X@2%1-3"!C;VQO<BP@92YG+CH@(V9F9F9C8RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@(%1H92!B<FEG:'1N97-S(&]N(&$@<V-A;&4@
M;V8@,"!T;R`R-34N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)R:6=H=&YE<W,H
M)&-O;&]R*0H@("`@>PH@("`@("`@("1R(#T@:&5X9&5C*'-U8G-T<B@D8V]L
M;W(L(#$L(#(I*3L*("`@("`@("`D9R`](&AE>&1E8RAS=6)S='(H)&-O;&]R
M+"`S+"`R*2D["B`@("`@("`@)&(@/2!H97AD96,H<W5B<W1R*"1C;VQO<BP@
M-2P@,BDI.PH*("`@("`@("!R971U<FX@<F]U;F0H*"@D<B`J(#(Y.2D@*R`H
M)&<@*B`U.#<I("L@*"1B("H@,3$T*2D@+R`Q,#`P*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!G97121T(H)&-O;&]R;F%M92D*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+TEM86=E+W)G8BYP:'`G
M.PH@("`@("`@(')E='5R;B!I<W-E="@D1TQ/0D%,4ULG:&]R9&5?:6UA9V5?
M<F=B7V-O;&]R<R==6R1C;VQO<FYA;65=*2`_"B`@("`@("`@("`@("1'3$]"
M04Q36R=H;W)D95]I;6%G95]R9V)?8V]L;W)S)UU;)&-O;&]R;F%M95T@.@H@
M("`@("`@("`@("!A<G)A>2@P+"`P+"`P*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971(97A#;VQO<B@D8V]L;W)N86UE*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O26UA9V4O<F=B+G!H<"<[
M"B`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=H;W)D95]I;6%G95]R9V)?
M8V]L;W)S)UU;)&-O;&]R;F%M95TI*2!["B`@("`@("`@("`@(&QI<W0H)'(L
M("1G+"`D8BD@/2`D1TQ/0D%,4ULG:&]R9&5?:6UA9V5?<F=B7V-O;&]R<R==
M6R1C;VQO<FYA;65=.PH@("`@("`@("`@("!R971U<FX@)R,G("X@<W1R7W!A
M9"AD96-H97@H;6EN*"1R+"`R-34I*2P@,BP@)S`G+"!35%)?4$%$7TQ%1E0I
M("X@<W1R7W!A9"AD96-H97@H;6EN*"1G+"`R-34I*2P@,BP@)S`G+"!35%)?
M4$%$7TQ%1E0I("X@<W1R7W!A9"AD96-H97@H;6EN*"1B+"`R-34I*2P@,BP@
M)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`G8FQA8VLG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1R87<@82!S:&%P960@<&]I;G0@870@=&AE('-P96-I9FEE9"`H
M>"QY*2!P;VEN="X@57-E9G5L(&9O<@H@("`@("H@<V-A='1E<B!D:6%G<F%M
M<RP@9&5B=6<@<&]I;G1S+"!E=&,N($1R87=S('-Q=6%R97,L(&-I<F-L97,L
M"B`@("`@*B!D:6%M;VYD<RP@86YD('1R:6%N9VQE<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>"`@("`@5&AE('@@8V]O<F1I;F%T92!O9B!T
M:&4@<&]I;G0@=&\@8G)U<V@N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@
M("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@<&]I;G0@=&\@8G)U<V@N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@5&AE(&-O;&]R('1O(&)R=7-H
M('1H92!P;VEN="!W:71H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<VAA<&4@
M(%=H870@8G)U<V@@=&\@=7-E/R!$969A=6QT<R!T;R!A('-Q=6%R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8G)U<V@H)'@L("1Y+"`D8V]L;W(@/2`G8FQA
M8VLG+"`D<VAA<&4@/2`G<W%U87)E)RD*("`@('L*("`@("`@("!S=VET8V@@
M*"1S:&%P92D@>PH@("`@("`@(&-A<V4@)W1R:6%N9VQE)SH*("`@("`@("`@
M("`@)'9E<G1S6S!=(#T@87)R87DH)W@G(#T^("1X("L@,RP@)WDG(#T^("1Y
M("L@,RD["B`@("`@("`@("`@("1V97)T<ULQ72`](&%R<F%Y*"=X)R`]/B`D
M>"P@)WDG(#T^("1Y("T@,RD["B`@("`@("`@("`@("1V97)T<ULR72`](&%R
M<F%Y*"=X)R`]/B`D>"`M(#,L("=Y)R`]/B`D>2`K(#,I.PH@("`@("`@("`@
M("`D=&AI<RT^<&]L>6=O;B@D=F5R=',L("1C;VQO<BP@)&-O;&]R*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V-I<F-L92<Z"B`@("`@
M("`@("`@("1T:&ES+3YC:7)C;&4H)'@L("1Y+"`S+"`D8V]L;W(L("1C;VQO
M<BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=D:6%M;VYD
M)SH*("`@("`@("`@("`@)'9E<G1S6S!=(#T@87)R87DH)W@G(#T^("1X("T@
M,RP@)WDG(#T^("1Y*3L*("`@("`@("`@("`@)'9E<G1S6S%=(#T@87)R87DH
M)W@G(#T^("1X+"`G>2<@/3X@)'D@*R`S*3L*("`@("`@("`@("`@)'9E<G1S
M6S)=(#T@87)R87DH)W@G(#T^("1X("L@,RP@)WDG(#T^("1Y*3L*("`@("`@
M("`@("`@)'9E<G1S6S-=(#T@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@)'D@
M+2`S*3L*("`@("`@("`@("`@)'1H:7,M/G!O;'EG;VXH)'9E<G1S+"`D8V]L
M;W(L("1C;VQO<BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=S<75A<F4G.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES
M+3YR96-T86YG;&4H)'@@+2`R+"`D>2`M(#(L(#0L(#0L("1C;VQO<BP@)&-O
M;&]R*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@061D(&%N(&]B<V5R=F5R('1O('1H:7,@:6UA9V4N(%1H
M92!O8G-E<G9E<B!W:6QL(&)E(&YO=&EF:65D"B`@("`@*B!W:&5N('1H92!I
M;6%G92=S(&-H86YG97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$]B<V5R
M=F5R*"1M971H;V0L("8D;V)J96-T*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;V)S97)V97)S6UT@/2!A<G)A>2@D;65T:&]D+"`F)&]B:F5C="D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,970@;V)S97)V97)S(&MN;W<@=&AA="!S;VUE
M=&AI;F<@:&%P<&5N960@=V]R=&@@86-T:6YG(&]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!N;W1I9GE/8G-E<G9E<G,H*0H@("`@>PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?;V)S97)V97)S*3L@*RLD:2D@
M>PH@("`@("`@("`@("`D;V)J(#T@)B1T:&ES+3Y?;V)S97)V97)S6R1I75LQ
M73L*("`@("`@("`@("`@)&UE=&AO9"`]("1T:&ES+3Y?;V)S97)V97)S6R1I
M75LP73L*("`@("`@("`@("`@)&]B:BT^)&UE=&AO9"@D=&AI<RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5S970@=&AE(&EM86=E(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T*"D*("`@('L*("`@("`@
M("`D=&AI<RT^7V1A=&$@/2`G)SL*("`@("`@("`D=&AI<RT^7VED(#T@)R<[
M"B`@("`@("`@)'1H:7,M/E]W:61T:"`](&YU;&P["B`@("`@("`@)'1H:7,M
M/E]H96EG:'0@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?8F%C:V=R;W5N9"`]
M("=W:&ET92<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&AE:6=H
M="!A;F0@=VED=&@@;V8@=&AE(&-U<G)E;G0@:6UA9V4@9&%T82X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!H87-H('=I=&@@)W=I9'1H)R!C
M;VYT86EN:6YG('1H92!W:61T:"P*("`@("`J("`@("`@("`@("`@("`@("=H
M96EG:'0G(&-O;G1A:6YI;F<@=&AE(&AE:6=H="!O9B!T:&4@:6UA9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I;65N<VEO;G,H*0H@("`@>PH@("`@
M("`@("1T;7`@/2`D=&AI<RT^=&]&:6QE*"D["B`@("`@("`@)&1E=&%I;',@
M/2!`9V5T:6UA9V5S:7IE*"1T;7`I.PH@("`@("`@('5N;&EN:R@D=&UP*3L*
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=W:61T:"<@/3X@)&1E=&%I;'-;,%TL
M"B`@("`@("`@("`@("`@("`@("`@("=H96EG:'0G(#T^("1D971A:6QS6S%=
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO860@=&AE(&EM86=E(&1A=&$@
M9G)O;2!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@("`@("`@("!!;B!A<F)I=')A<GD@:60@9F]R('1H92!I;6%G92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&EM86=E7V1A=&$@(%1H92!D871A('1O('5S
M92!F;W(@=&AE(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V%D4W1R
M:6YG*"1I9"P@)&EM86=E7V1A=&$I"B`@("!["B`@("`@("`@:68@*"1I9"`A
M/2`D=&AI<RT^7VED*2!["B`@("`@("`@("`@("1T:&ES+3YR97-E="@I.PH@
M("`@("`@("`@("`D=&AI<RT^7V1A=&$@/2`D:6UA9V5?9&%T83L*("`@("`@
M("`@("`@)'1H:7,M/E]I9"`]("1I9#L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!,;V%D('1H92!I;6%G92!D871A(&9R;VT@82!F:6QE+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@9G5L
M;"!P871H(&%N9"!F:6QE;F%M92!T;R!T:&4@9FEL92!T;R!L;V%D"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&EM86=E(&1A=&$@9G)O
M;2X@5&AE(&9I;&5N86UE('=I;&P@86QS;R!B90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('5S960@9F]R('1H92!I;6%G92!I9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!014%2($5R<F]R(&EF(&9I;&4@9&]E
M<R!N;W0@97AI<W0@;W(@8V]U;&0@;F]T(&)E(&QO861E9`H@("`@("H@("`@
M("`@("`@("`@("`@;W1H97)W:7-E($Y53$P@:68@<W5C8V5S<V9U;"!O<B!A
M;')E861Y(&QO861E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9$9I;&4H
M)&9I;&5N86UE*0H@("`@>PH@("`@("`@(&EF("@D9FEL96YA;64@(3T@)'1H
M:7,M/E]I9"D@>PH@("`@("`@("`@("`D=&AI<RT^<F5S970H*3L*("`@("`@
M("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL96YA;64I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G5&AE(&EM86=E(&9I
M;&4@)R`N("1I;6%G92`N("<@9&]E<R!N;W0@97AI<W0N)RD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&%T82`](&9I;&5?9V5T
M7V-O;G1E;G1S*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:60@/2`D9FEL96YA;64["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V]U;&0@;F]T
M(&QO860@=&AE(&EM86=E(&9I;&4@)R`N("1I;6%G92D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=&]&:6QE*"1D871A
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1M<"`](%5T:6PZ.F=E=%1E;7!&
M:6QE*"=I;6<G+"!F86QS92P@)'1H:7,M/E]T;7!D:7(I.PH@("`@("`@("1F
M<"`]($!F;W!E;B@D=&UP+"`G=V(G*3L*("`@("`@("!F=W)I=&4H)&9P+"`D
M9&%T82`_("1D871A(#H@)'1H:7,M/G)A=R@I*3L*("`@("`@("!F8VQO<V4H
M)&9P*3L*("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O*BH*("`@
M("`J($1I<W!L87D@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1I<W!L87DH*0H@("`@>PH@("`@("`@("1T:&ES+3YH96%D97)S
M*"D["B`@("`@("`@96-H;R`D=&AI<RT^<F%W*"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!R87<@9&%T82!F;W(@=&AI<R!I;6%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V]N=F5R="`@268@=')U
M92P@=&AE(&EM86=E(&1A=&$@=VEL;"!B92!R971U<FYE9"!I;B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T87)G970@9F]R;6%T+"!I
M;F1E<&5N9&5N=&QY(&9R;VT@86YY(&EM86=E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@;W!E<F%T:6]N<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(')A=R!I;6%G92!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R87<H)&-O;G9E<G0@/2!F86QS92D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&%N('@L>2!P86ER(&]N(&-I<F-L92P@87-S=6UI;F<@8V5N=&5R(&ES(#`L
M,"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@9&]U8FQE("1D96=R965S("`@(%1H92!D96=R965S(&]F(&%R
M8R!T;R!G970@=&AE('!O:6YT(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1D:6%M971E<B`@5&AE(&1I86UE=&5R(&]F('1H92!C:7)C;&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@*'@@8V]O<F1I;F%T92P@>2!C;V]R
M9&EN871E*2!O9B!T:&4@<&]I;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M:7)C;&50;VEN="@D9&5G<F5E<RP@)&1I86UE=&5R*0H@("`@>PH@("`@("`@
M("\O($%V;VED('!R;V)L96US('=I=&@@9&]U8FQE<RX*("`@("`@("`D9&5G
M<F5E<R`K/2`P+C`P,#$["@H@("`@("`@(')E='5R;B!A<G)A>2AC;W,H9&5G
M,G)A9"@D9&5G<F5E<RDI("H@*"1D:6%M971E<B`O(#(I+`H@("`@("`@("`@
M("`@("`@("`@("!S:6XH9&5G,G)A9"@D9&5G<F5E<RDI("H@*"1D:6%M971E
M<B`O(#(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!P;VEN="!C;V]R
M9&EN871E<R!A="!T:&4@;&EM:71S(&]F(&%N(&%R8RX@3VYL>2!V86QI9"!F
M;W(*("`@("`J(&%N9VQE<R`H)&5N9"`M("1S=&%R="D@/#T@-#4@9&5G<F5E
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<B`@("`@(%1H92!R861I=7,@;V8@=&AE(&%R
M8RX*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@5&AE('-T87)T:6YG
M(&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@96YD
M:6YG(&%N9VQE+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!S
M=&%R="!P;VEN="P@96YD('!O:6YT+"!A;F0@86YC:&]R('!O:6YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?87)C4&]I;G1S*"1R+"`D<W1A<G0L("1E;F0I
M"B`@("!["B`@("`@("`@+R\@4W1A<G0@<&]I;G0N"B`@("`@("`@)'!T<ULG
M>#$G72`]("1R("H@8V]S*&1E9S)R860H)'-T87)T*2D["B`@("`@("`@)'!T
M<ULG>3$G72`]("1R("H@<VEN*&1E9S)R860H)'-T87)T*2D["@H@("`@("`@
M("\O($5N9"!P;VEN="X*("`@("`@("`D<'1S6R=X,B==(#T@)'(@*B!C;W,H
M9&5G,G)A9"@D96YD*2D["B`@("`@("`@)'!T<ULG>3(G72`]("1R("H@<VEN
M*&1E9S)R860H)&5N9"DI.PH*("`@("`@("`O+R!!;F-H;W(@<&]I;G0N"B`@
M("`@("`@)&$S(#T@*"1S=&%R="`K("1E;F0I("\@,CL*("`@("`@("`D<C,@
M/2`D<B`O(&-O<RAD96<R<F%D*"@D96YD("T@)'-T87)T*2`O(#(I*3L*("`@
M("`@("`D<'1S6R=X,R==(#T@)'(S("H@8V]S*&1E9S)R860H)&$S*2D["B`@
M("`@("`@)'!T<ULG>3,G72`]("1R,R`J('-I;BAD96<R<F%D*"1A,RDI.PH*
M("`@("`@("!R971U<FX@)'!T<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7TEM86=E(&EN<W1A
M;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7TEM86=E
M('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N+B!4:&ES(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("@D9')I=F5R*2X@5&AE(&-O9&4@
M:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL
M(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R
M6S!=+VQI8B]);6%G92\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);
M,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E
M<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@2&]R9&5?26UA9V5\8F]O;&5A;B`@5&AE(&YE=VQY(&-R96%T960@8V]N
M8W)E=&4@2&]R9&5?26UA9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:6YS=&%N8V4L(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI
M('L*("`@("`@("`@("`@;&ES="@D87!P+"`D9')I=F5R*2`]("1D<FEV97([
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O26UA9V4O)R`N("1D<FEV97(@
M+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N
M86UE*%]?1DE,15]?*2`N("<O26UA9V4O)R`N("1D<FEV97(@+B`G+G!H<"<I
M*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O26UA9V4O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O26UA9V4O
M)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C;&%S
M<R`]("=(;W)D95]);6%G95\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA
M<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&EM86=E(#T@)FYE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&EM86=E(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO
M;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&EM86=E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@
M2&]R9&5?26UA9V4@:6YS=&%N8V4@8F%S960*("`@("`J(&]N("1D<FEV97(N
M($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@2&]R
M9&5?26UA9V4*("`@("`J(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE
M=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO
M=6QD(&)E('5S960@:68@;75L=&EP;&4@='EP97,@;V8@:6UA9V4@<F5N9&5R
M97)S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT:7!L92!(;W)D95]);6%G92!I
M;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&]R9&5?26UA9V4Z
M.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV
M97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7TEM86=E('-U8F-L87-S
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B!4:&ES
M(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("@D9')I=F5R*2X@5&AE(&-O9&4@:7,@9'EN86UI
M8V%L;'D@:6YC;'5D960N($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL@:6X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S!=+VQI8B])
M;6%G92\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG
M(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C
M;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?
M26UA9V5\8F]O;&5A;B`@5&AE(&-O;F-R971E($AO<F1E7TEM86=E(')E9F5R
M96YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG
M;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@<W1A=&EC("1I;G-T86YC97,["B`@("`@("`@:68@*"%I<W-E="@D:6YS
M=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH*3L*
M("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R
M87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H)&EN
M<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E72`]("9(;W)D95]);6%G93HZ9F%C=&]R>2@D9')I=F5R
M+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N
M8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TMO;&%B+G!H<```````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$V-#(Q,``Q,#0Q-S,V,C<W,P`P,3<W-S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*B!7
M92!R97%U:7)E('1H92!B87-E($AO<F1E(&QI8G)A<GDN("HO"G)E<75I<F5?
M;VYC92`G2&]R9&4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP
M:'`G.PH*+RHJ(%=E(&YE960@=&AE(%-T<FEN9R`F($Y,4R!L:6)R87)I97,@
M9F]R(&-H87)A8W1E<B!S970@8V]N=F5R<VEO;G,L(&5T8RX@*B\*<F5Q=6ER
M95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92].3%,N<&AP)SL*"B\J*B!792!N965D('1H92!(;W)D92!-24U%(&QI8G)A
M<GD@=&\@9&5A;"!W:71H($U)344@;65S<V%G97,L(&]B=FEO=7-L>2`Z+2DN
M("HO"G)E<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+TU)344O4&%R="YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+TU)344O365S<V%G92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T
M=7)E+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7TMO;&%B(&QI8G)A<GD@<F5Q
M=6ER97,@=F5R<VEO;B`^/2`Q+C`N,R!O9B!.971?24U!4"`H:2YE+B!A('9E
M<G-I;VX*("H@=&AA="!I;F-L=61E<R!S=7!P;W)T(&9O<B!T:&4@04Y.3U1!
M5$5-3U)%($E-05`@97AT96YS:6]N*2X@5&AE(&QA=&5S=`H@*B!V97)S:6]N
M(&]F($YE=%])34%0(&-A;B!B92!O8G1A:6YE9"!F<F]M(&AT='`Z+R]P96%R
M+G!H<"YN970O9V5T+TYE=%])34%0"B`J+PIR97%U:7)E7V]N8V4@)TYE="])
M34%0+G!H<"<["@HO*BH*("H@5&AE(&-H87)A8W1E<B!S97%U96YC92!U<V5D
M(&)Y(&$@*$MO;&%B*2!#>7)U<R!)34%0('-E<G9E<B!T;R!S97!A<F%T92!L
M:6YE<PH@*B!W:71H:6X@82!M97-S86=E+@H@*B\*9&5F:6YE*"=+3TQ!0E].
M15=,24Y%)RP@(EQR7&XB*3L*"B\J*@H@*B!4:&4@8VAA<F%C=&5R('5S960@
M=&\@9&5L:6UI="!S=6)F;VQD97)S('=I=&AI;B!A("A+;VQA8BD@0WER=7,@
M9F]L9&5R"B`J(&AI97)A<F-H>2X*("HO"F1E9FEN92@G2T],04)?1D],1$52
M7T1%3$E-)RP@)R\G*3L*"B\J*@H@*B!4:&4@<F]O="!O9B!T:&4@2V]L86(@
M86YN;W1A=&EO;B!H:65R87)C:'DL('5S960@;VX@=&AE('9A<FEO=7,@24U!
M4"!F;VQD97(*("H@=&AA="!A<F4@=7-E9"!B>2!+;VQA8B!C;&EE;G1S+@H@
M*B\*9&5F:6YE*"=+3TQ!0E]!3DY/5%]23T]4)RP@)R]V96YD;W(O:V]L86(O
M)RD["@HO*BH*("H@5&AE(&%N;F]T871I;VXL(&%S(&1E9FEN960@8GD@=&AE
M($MO;&%B(&9O<FUA="!S<&5C+"!T:&%T(&ES('5S960@=&\@<W1O<F4*("H@
M:6YF;W)M871I;VX@86)O=70@=VAA="!G<F]U<'=A<F4@9F]R;6%T('1H92!F
M;VQD97(@8V]N=&%I;G,N"B`J+PID969I;F4H)TM/3$%"7T%.3D]47T9/3$1%
M4E]465!%)RP@2T],04)?04Y.3U1?4D]/5"`N("=F;VQD97(M='EP92<I.PH*
M+RHJ"B`J($$@2&]R9&4M<W!E8VEF:6,@86YN;W1A=&EO;B!T:&%T('-T;W)E
M<R!T:&4@54E$(&]F('1H92!(;W)D92!S:&%R92!T:&%T"B`J(&-O<G)E<W!O
M;F1S('1O('1H92!)34%0(&9O;&1E<BX@5&AI<R!I<R!U<V5D(&EN('1H92!S
M>6YC:')O;FES871I;VX@<')O8V5S<PH@*B!O9B!T:&4@24U!4"!F;VQD97(@
M;&ES="!A;F0@=&AE($AO<F1E('-H87)E(&QI<W0N"B`J+PID969I;F4H)TM/
M3$%"7T%.3D]47U-(05)%7U5)1"<L($M/3$%"7T%.3D]47U)/3U0@+B`G:"US
M:&%R92UU:60G*3L*"B\J*@H@*B!4:&4@6"T@:&5A9&5R('5S960@=&\@<W1O
M<F4@82!C;W!Y(&]F('1H92!+;VQA8B!O8FIE8W0@='EP92!S=')I;F<@9F]R
M('1H90H@*B!O8FIE8W0@='EP92!T:&%T(&ES(&-O;G1A:6YE9"!W:71H:6X@
M=&AE(&5M86EL(&UE<W-A9V4N"B`J+PID969I;F4H)TM/3$%"7TA%041%4E]4
M65!%)RP@)U@M2V]L86(M5'EP92<I.PH*+RHJ"B`J($%N(&EN9&5X(&EN=&\@
M=&AE("1?4T534TE/3B!A<G)A>2!W:&EC:"!I<R!U<V5D('1O(&-A8VAE('=H
M870@87!P;&EC871I;VX*("H@=V%S(&QA<W0@<WEN8VAR;VYI<V5D.R!T:&ES
M('!R979E;G1S('5S(&9R;VT@8V]N=&EN=6]U<VQY(')E+7-Y;F-H<F]N:7-I
M;F<*("H@;VX@979E<GD@<&%G92!L;V%D('=I=&AI;B!A('-I;F=L92!A<'!L
M:6-A=&EO;BX*("HO"F1E9FEN92@G2T],04)?3$%35%]364Y#2$5$7T%04"<L
M("=K;VQA8E]L87-T7W-Y;F-H961?87!P)RD["@HO*BH*("H@06X@:6YD97@@
M:6YT;R!T:&4@)%]315-324].(&%R<F%Y('=H:6-H(&ES('5S960@=&\@8V%C
M:&4@82!M87!P:6YG(&]F('-H87)E"B`J(%5)1',@=&\@24U!4"!F;VQD97)S
M.R!T:&ES(&ES('5S960@8GD@=&AE('9A<FEO=7,@87!P;&EC871I;VX@9')I
M=F5R<R!W:&5N"B`J(&]P96YI;F<@82!S<&5C:69I8R!S:&%R92P@:6X@;W)D
M97(@=&\@:VYO=R!W:&%T('1H92!C;W)R97-P;VYD:6YG($E-05`*("H@9F]L
M9&5R('1H870@;75S="!B92!O<&5N960@:7,N"B`J+PID969I;F4H)TM/3$%"
M7U-(05)%7TU!4"<L("=K;VQA8E]S:&%R95]M87`G*3L*"B\J*@H@*B!4:&4@
M<')E9FEX(&9O<B!A;&P@2V]L86(@9W)O=7!W87)E(&]B:F5C="!M:6UE('1Y
M<&4@<W1R:6YG<RX@16%C:"!O8FIE8W0*("H@='EP92!H87,@=&AI<R!S=')I
M;F<@:6X@8V]M;6]N+"!W:71H(&$@<W5F9FEX(&]F(&4N9RX@)VYO=&4G+"`G
M979E;G0G+"!E=&,N"B`J('1O(&EN9&EC871E('=H870@=&AE('-P96-I9FEC
M($MO;&%B(&=R;W5P=V%R92!F;W)M870@:7,N"B`J+PID969I;F4H)TM/3$%"
M7TU)345?5%E015]04D5&25@G+"`G87!P;&EC871I;VXO>"UV;F0N:V]L86(N
M)RD["@HO*BH*("H@5&AE('-T<FEN9R!U<V5D('1O(&ED96YT:69Y('1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@:6X@=F%R:6]U<PH@*B!P
M;&%C97,@*&4N9RX@:6X@2V]L86(@;V)J96-T<R!G96YE<F%T960@8GD@=&AE
M(&QI8G)A<GDI+@H@*B\*9&5F:6YE*"=+3TQ!0E]04D]$54-47TE$)RP@)VAO
M<F1E+VMO;&%B+S$N,"<I.PH*+RHJ"B`J(%1H92!(;W)D95]+;VQA8B!L:6)R
M87)Y(&ES(&)O=&@@86X@;V)J96-T('5S960@8GD@87!P;&EC871I;VX@9')I
M=F5R<R!T;PH@*B!C;VUM=6YI8V%T92!W:71H(&$@2V]L86(@<V5R=F5R+"!A
M<R!W96QL(&%S(&$@=71I;&ET>2!L:6)R87)Y('!R;W9I9&EN9PH@*B!S979E
M<F%L(&9U;F-T:6]N<R!T;R!H96QP(&EN('1H92!)34%0(&9O;&1E<B`\+3X@
M2&]R9&4@4VAA<F4@<WEN8VAR;VYI<V%T:6]N"B`J('!R;V-E<W,N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<"QV(#$N,C8N,3`N
M,30@,C`P-B\P,R\R-R`R,CHT,3HT-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!(;W)D92!0<F]J96-T("AH='1P.B\O:&]R9&4N;W)G
M+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%-T=6%R="!":6YG92`\
M;VUI8W)O;D!M:6=H='DN8V\N>F$^"B`J($!P86-K86=E($AO<F1E7TMO;&%B
M"B`J+PIC;&%S<R!+;VQA8B!["@HO+R!#;&%S<R!I;G1E<F9A8V4*"B`@("`O
M*BH*("`@("`J(%1H92!C=7)R96YT(&%P<&QI8V%T:6]N('1H870@=&AI<R!+
M;VQA8B!O8FIE8W0@:6YS=&%N8V4@:7,@8V%T97)I;F<@=&\N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?87!P.PH*("`@
M("\J*@H@("`@("H@3W5R($YE=%])34%0(&]B:F5C="P@=7-E9"!T;R!C;VUM
M=6YI8V%T92!W:71H('1H92!#>7)U<R!S97)V97(N"B`@("`@*@H@("`@("H@
M0'9A<B!.971?24U!4`H@("`@("HO"B`@("!V87(@)%]I;6%P(#T@;G5L;#L*
M"B`@("`O*BH*("`@("`J($$@8V%C:&5D('9E<G-I;VX@;V8@2V]L86(Z.F=E
M=$%P<$-O;G-T<R@D=&AI<RT^7V%P<"D@=&AA="!I<R!U<V5D(&EN"B`@("`@
M*B!S979E<F%L(&]F('1H92!+;VQA8CHZ(&9U;F-T:6]N<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%P<%]C;VYS=',[
M"@H@("`@+RHJ"B`@("`@*B!!('-H;W)T8W5T('1O("1T:&ES+3Y?87!P7V-O
M;G-T<ULG;6EM95]T>7!E7W-U9F9I>"=="B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?;V)J96-T7W1Y<&4["@H@("`@+RHJ
M"B`@("`@*B!4:&4@9G5L;"!M:6UE('1Y<&4@<W1R:6YG(&]F('1H92!C=7)R
M96YT($MO;&%B(&]B:F5C="!F;W)M870@=V4G<F4*("`@("`J(&1E86QI;F<@
M=VET:"X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]M:6UE7W1Y<&4["@H@("`@+RHJ"B`@("`@*B!4:&4@*&5N8V]D960I
M(&YA;64@;V8@=&AE($E-05`@9F]L9&5R('1H870@8V]R<F5S<&]N9',@=&\@
M=&AE(&-U<G)E;G0*("`@("`J('-H87)E+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V9O;&1E<CL*"B`@("`O*BH*("`@
M("`J(%1H92!-24U%7TUE<W-A9V4@;V)J96-T('1H870@8V]N=&%I;G,@=&AE
M(&-U<G)E;G1L>2!L;V%D960@;65S<V%G92X@5&AI<PH@("`@("H@:7,@=7-E
M9"!W:&5N('5P9&%T:6YG(&%N(&]B:F5C="P@:6X@;W)D97(@=&\@<')E<V5R
M=F4@979E<GET:&EN9R!E;'-E"B`@("`@*B!W:71H:6X@=&AE(&UE<W-A9V4@
M=&AA="!W92!D;VXG="!K;F]W(&AO=R!T;R!H86YD;&4N"B`@("`@*@H@("`@
M("H@0'9A<B!-24U%7TUE<W-A9V4*("`@("`J+PH@("`@=F%R("1?;65S<V%G
M93L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&-O;G1A:6YI;F<@)%]M97-S
M86=E)W,@:&5A9&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7VAE861E<G,["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-
M12!I9&5N=&EF:65R(&]F('1H92!+;VQA8B!G<F]U<'=A<F4@;V)J96-T('=I
M=&AI;B`D=&AI<RT^7VUE<W-A9V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?;6EM95]I9#L*"B`@("`O*BH*("`@("`J
M(%1H92`H2V]L86(I(%5)1"!O9B`D=&AI<RT^7VUE<W-A9V4N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=6ED.PH*("`@
M("\J*@H@("`@("H@5&AE($1O;41O8W5M96YT(&]B:F5C="!T:&%T(&-O;G1A
M:6YS('1H92!834P@1$]-('1R964@;V8@=&AE(&-U<G)E;G1L>0H@("`@("H@
M;&]A9&5D(&=R;W5P=V%R92!O8FIE8W0N(%=E(&-A8VAE('1H:7,@:&5R92!T
M;R!E;G-U<F4@<')E<V5R=F%T:6]N(&]F"B`@("`@*B!U;FMN;W=N(&9I96QD
M<R!W:&5N(')E+7-A=FEN9R!T:&4@;V)J96-T+@H@("`@("H*("`@("`J($!V
M87(@1&]M1&]C=6UE;G0*("`@("`J+PH@("`@=F%R("1?>&UL.PH*("`@("\J
M*@H@("`@("H@5&AE($E-05`@;65S<V%G92!N=6UB97(@;V8@)'1H:7,M/E]M
M97-S86=E+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]M<V=?;F\["@H@("`@9G5N8W1I;VX@9V5T54E$*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]U:60["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T36EM951Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7VUI;65?='EP93L*("`@('T*"B`@("!F=6YC=&EO;B!+;VQA8B@I"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)'1H:7,M/E]A
M<'`@/2`D<F5G:7-T<GDM/F=E=$%P<"@I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&]P96XH)'-H87)E7W5I9"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8[
M"@H@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=D;VUX;6PG
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(I*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#;VYS=',H
M)'1H:7,M/E]A<'`I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?87!P7V-O
M;G-T<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]A<'!?8V]N<W1S.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]O
M8FIE8W1?='EP92`]("1T:&ES+3Y?87!P7V-O;G-T<ULG;6EM95]T>7!E7W-U
M9F9I>"==.PH@("`@("`@("1T:&ES+3Y?;6EM95]T>7!E(#T@2T],04)?34E-
M15]465!%7U!2149)6"`N("1T:&ES+3Y?;V)J96-T7W1Y<&4["@H@("`@("`@
M("1C=7)R96YT7W5S97(@/2!!=71H.CIG971!=71H*"D["B`@("`@("`@)&YD
M>"`]('-T<G!O<R@D8W5R<F5N=%]U<V5R+"`G0"<I.PH@("`@("`@("1U<V5R
M(#T@)&YD>"`]/3T@9F%L<V4@/R`D8W5R<F5N=%]U<V5R(#H@<W5B<W1R*"1C
M=7)R96YT7W5S97(L(#`L("1N9'@I.PH@("`@("`@("1D;VUA:6X@/2!S=')S
M='(H)&-U<G)E;G1?=7-E<BP@)T`G*3L*"B`@("`@("`@)'-H87)E7VUA<"`]
M($MO;&%B.CIG9713:&%R94UA<"@I.PH@("`@("`@(&EF("AE;7!T>2@D<VAA
M<F5?;6%P6R1S:&%R95]U:61=*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@("`@("1F;VQD97(@/2`D<VAA<F5?;6%P6R1S
M:&%R95]U:61=.PH*("`@("`@("`O+R!4<F%N<VQA=&4@<F5M;W1E+7-Y;G1A
M>"!F;VQD97)S('1H870@=V4@;W=N('1O(&QO8V%L+7-Y;G1A>"!S;R!T:&%T
M"B`@("`@("`@+R\@=V4@8V%N(&]P96X@=&AE;2!P<F]P97)L>0H@("`@("`@
M('!R96=?;6%T8V@H(CMU<V5R+RA;7B]=*RDO*%M>0%TK*2A`+BHI/SLB+"`D
M9F]L9&5R+"`D;6%T8VAE<RD["@H@("`@("`@("1U<V5R7V1O;6%I;B`](&ES
M<V5T*"1M871C:&5S6S-=*2`_("1M871C:&5S6S-=(#H@)&1O;6%I;CL*("`@
M("`@("!I9B`H)&UA=&-H97-;,5T@/3T@)'5S97(@)B8@)'5S97)?9&]M86EN
M(#T]("1D;VUA:6XI('L*("`@("`@("`@("`@)&9O;&1E<B`]("))3D)/6"\D
M;6%T8VAE<ULR72(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9O
M;&1E<B`](")U<V5R+R1M871C:&5S6S%=+R1M871C:&5S6S)=(CL*("`@("`@
M("`@("`@:68@*"1U<V5R7V1O;6%I;B`A/2`D9&]M86EN*2!["B`@("`@("`@
M("`@("`@("`D9F]L9&5R("X]("1U<V5R7V1O;6%I;CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]F;VQD97(@/2`D9F]L9&5R
M.PH*("`@("`@("`D=&AI<RT^7VEM87`@/2`F;F5W($YE=%])34%0*"1C;VYF
M6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G75LG
M:6UA<"==6R=P;W)T)UTI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6UA
M<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;6%P.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6UA<"T^;&]G:6XH)&-U<G)E;G1?=7-E<BP@075T:#HZ9V5T0W)E9&5N=&EA
M;"@G<&%S<W=O<F0G*2P@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6UA<"T^<V5L96-T36%I;&)O>"@D=&AI<RT^7V9O;&1E<BD["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]I;6%P+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@("1T:&ES
M+3Y?:6UA<"`](&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(&9I;F1/8FIE8W0H)'5I9"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YS96%R8V@H
M(E-50DI%0U0@7"(D=6ED7"(B*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1R97-U;'0I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S(BDL("1U:60I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S
M=6QT6S!=.PH@("`@?0H*("`@(&9U;F-T:6]N(&QI<W1/8FIE8W1S*"D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/E]I;6%P+3YS96%R8V@H)TA%041%4B`B)R`N($M/3$%"7TA%041%
M4E]465!%("X@)R(@(B<@+B`D=&AI<RT^7VUI;65?='EP92`N("<B)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@9FEN9$]B:F5C=',H)&-R:71E<FEA*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM87`M/G-E87)C:"@D8W)I=&5R:6$I.PH@("`@?0H*("`@("\O
M(%1/1$\Z('=R:71E(&$@9G5N8W1I;VX@=&AA="!I<R!A8FQE('1O(&QO;VL@
M=&AR;W5G:"!A;&P@9F]L9&5R<R!O9B!T:&4*("`@("\O('1Y<&4@=V4G<F4@
M:6YT97)E<W1E9"!I;BP@;&]O:VEN9R!F;W(@86X@;V)J96-T('=I=&@@82!S
M<&5C:69I8R!5240N(%1H:7,*("`@("\O(&ES(&YE961E9"!F;W(@=&AE(&=E
M=$)Y1U5)1"@I(&9U;F-T:6]N<R!I;B!T:&4@=F%R:6]U<R!A<'!L:6-A=&EO
M;B!D<FEV97)S+@H*("`@(&9U;F-T:6]N(&UO=F5/8FIE8W0H)'5I9"P@)&YE
M=U]S:&%R92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`D;7-G7VYO(#T@)'1H:7,M/F9I;F1/8FIE8W0H)'5I9"D["B`@("`@
M("`@:68@*&ES7V$H)&US9U]N;RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&US9U]N;SL*("`@("`@("!]"@H@("`@("`@("1S:&%R
M95]M87`@/2!+;VQA8CHZ9V5T4VAA<F5-87`H*3L*("`@("`@("!I9B`H96UP
M='DH)'-H87)E7VUA<%LD;F5W7W-H87)E72DI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")(;W)D92]+;VQA8CH@
M56YK;F]W;B!S:&%R92!<(B5S7"(B*2P@)&YE=U]S:&%R92DI.PH@("`@("`@
M('T*"B`@("`@("`@)&YE=U]F;VQD97(@/2`D<VAA<F5?;6%P6R1N97=?<VAA
M<F5=.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YC;W!Y365S
M<V%G97,H)&YE=U]F;VQD97(L("1M<V=?;F\I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]I;6%P+3YD96QE=&5-97-S86=E<R@D;7-G7VYO*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6UA<"T^97AP=6YG92@I.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V
M94]B:F5C=',H)&]B:F5C=',L("1I<U]M<V=N;R`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?87)R
M87DH)&]B:F5C=',I*2!["B`@("`@("`@("`@("1O8FIE8W1S(#T@87)R87DH
M)&]B:F5C=',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1I<U]M<V=N;R`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&YE=U]O8FIE8W1S(#T@87)R87DH
M*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1O8FIE8W1S(&%S("1O8FIE8W0I
M('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9FEN9$]B:F5C
M="@D;V)J96-T*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M;F5W7V]B:F5C='-;72`]("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1O8FIE8W1S(#T@)&YE=U]O8FIE8W1S.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA<"T^9&5L971E365S<V%G97,H
M)&]B:F5C=',I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YE>'!U;F=E*"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V94%L;$]B
M:F5C=',H*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/F1E;&5T94UE<W-A9V5S*"1T
M:&ES+3YL:7-T3V)J96-T<R@I*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M9G5N8W1I;VX@)FQO861/8FIE8W0H)'5I9"P@)&ES7VUS9VYO(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1I<U]M<V=N;R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)'5I9"`]("1T
M:&ES+3YF:6YD3V)J96-T*"1U:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'5I9#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]H96%D97)S(#T@)'1H:7,M/E]I;6%P+3YG971087)S961(96%D97)S*"1U
M:60I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:&5A9&5R<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("1M97-S86=E7W1E>'0@/2`D=&AI<RT^7VEM87`M/F=E
M=$UE<W-A9V5S*"1U:60I.PH@("`@("`@(&EF("AI<U]A*"1M97-S86=E7W1E
M>'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1M97-S
M86=E7W1E>'0["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH)&UE
M<W-A9V5?=&5X="DI('L*("`@("`@("`@("`@)&UE<W-A9V5?=&5X="`](&%R
M<F%Y7W-H:69T*"1M97-S86=E7W1E>'0I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]M<V=?;F\@/2`D=6ED.PH@("`@("`@("1T:&ES+3Y?;65S<V%G
M92`]("9-24U%7U-T<G5C='5R93HZ<&%R<V5497AT34E-14UE<W-A9V4H)&UE
M<W-A9V5?=&5X="D["@H@("`@("`@("1P87)T<R`]("1T:&ES+3Y?;65S<V%G
M92T^8V]N=&5N=%1Y<&5-87`H*3L*("`@("`@("!I9B`H*"1T:&ES+3Y?;6EM
M95]I9"`](&%R<F%Y7W-E87)C:"@D=&AI<RT^7VUI;65?='EP92P@)'!A<G1S
M*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)T(#T@)'1H:7,M/E]M
M97-S86=E+3YG971087)T*"1T:&ES+3Y?;6EM95]I9"D["B`@("`@("`@("`@
M("1T97AT(#T@)'!A<G0M/G1R86YS9F5R1&5C;V1E*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<R(I+"`D=&AI<RT^7VUI;65?='EP92P@)'5I9"DI
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]X;6P@/2!`9&]M>&UL7V]P
M96Y?;65M*"1T97AT+"!$3TU834Q?3$]!1%]005)324Y'('P*("`@("`@("`@
M("`@1$]-6$U,7TQ/041?0T]-4$Q%5$5?05144E,@?"!$3TU834Q?3$]!1%]3
M54)35$E4551%7T5.5$E42453('P*("`@("`@("`@("`@1$]-6$U,7TQ/041?
M1$].5%]+14507T),04Y+4RP@)&5R<F]R*3L*("`@("`@("!I9B`H(65M<'1Y
M*"1E<G)O<BDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(BDL("1T:&ES+3Y?;V)J96-T
M7W1Y<&4L("1U:60I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?=6ED
M(#T@)'1H:7,M/F=E=%9A;"@G=6ED)RD["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?>&UL+3YD;V-U;65N=%]E;&5M96YT*"D["B`@("!]"@H@("`@9G5N8W1I
M;VX@)FYE=T]B:F5C="@D=6ED*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7VEM87`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?;7-G7VYO(#T@+3$["@H@("`@("`@
M("1T:&ES+3Y?;65S<V%G92`]("9N97<@34E-15]-97-S86=E*"D["@H@("`@
M("`@("1K;VQA8E]T97AT(#T@<W!R:6YT9BA?*")4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VAT='`Z+R]W=W<N:V]L86(N;W)G+VMO;&%B,BUC
M;&EE;G1S+FAT;6PG*3L*"B`@("`@("`@)'!A<G0@/2`F;F5W($U)345?4&%R
M="@G=&5X="]P;&%I;B<L(%-T<FEN9SHZ=W)A<"@D:V]L86)?=&5X="P@-S8L
M($M/3$%"7TY%5TQ)3D4L($Y,4SHZ9V5T0VAA<G-E="@I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@
M("`@("`D<&%R="T^<V5T5')A;G-F97)%;F-O9&EN9R@G<75O=&5D+7!R:6YT
M86)L92<I.PH@("`@("`@("1T:&ES+3Y?;65S<V%G92T^861D4&%R="@D<&%R
M="D["@H@("`@("`@("1P87)T(#T@)FYE=R!-24U%7U!A<G0H)'1H:7,M/E]M
M:6UE7W1Y<&4L("<G+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@)'!A
M<G0M/G-E=%1R86YS9F5R16YC;V1I;F<H)W%U;W1E9"UP<FEN=&%B;&4G*3L*
M("`@("`@("`D=&AI<RT^7VUE<W-A9V4M/F%D9%!A<G0H)'!A<G0I.PH*("`@
M("`@("`D<&%R=',@/2`D=&AI<RT^7VUE<W-A9V4M/F-O;G1E;G14>7!E36%P
M*"D["B`@("`@("`@:68@*"@D=&AI<RT^7VUI;65?:60@/2!A<G)A>5]S96%R
M8V@H)'1H:7,M/E]M:6UE7W1Y<&4L("1P87)T<RDI(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@
M=&AE('!A<G0@;V8@='EP92`E<R(I+"`D=&AI<RT^7VUI;65?='EP92DI.PH@
M("`@("`@('T*"B`@("`@("`@)&AE861E<G,@/2`F;F5W($U)345?2&5A9&5R
M<R@I.PH@("`@("`@("1H96%D97)S+3YA9&1(96%D97(H)T9R;VTG+"!!=71H
M.CIG971!=71H*"DI.PH@("`@("`@("1H96%D97)S+3YA9&1(96%D97(H)U1O
M)RP@075T:#HZ9V5T075T:"@I*3L*("`@("`@("`D:&5A9&5R<RT^861D2&5A
M9&5R*"=3=6)J96-T)RP@)'5I9"D["B`@("`@("`@)&AE861E<G,M/F%D9$AE
M861E<B@G57-E<BU!9V5N="<L($M/3$%"7U!23T150U1?240I.PH@("`@("`@
M("1H96%D97)S+3YA9&1(96%D97(H)U)E<&QY+51O)RP@)R<I.PH@("`@("`@
M("1H96%D97)S+3YA9&1(96%D97(H)T1A=&4G+"!D871E*"=R)RDI.PH@("`@
M("`@("1H96%D97)S+3YA9&1(96%D97(H2T],04)?2$5!1$527U194$4L("1T
M:&ES+3Y?;6EM95]T>7!E*3L*("`@("`@("`D:&5A9&5R<RT^861D34E-14AE
M861E<G,H)'1H:7,M/E]M97-S86=E*3L*"B`@("`@("`@)'1H:7,M/E]H96%D
M97)S(#T@)&AE861E<G,M/G1O07)R87DH*3L*"B`@("`@("`@)'1H:7,M/E]X
M;6P@/2!D;VUX;6Q?;W!E;E]M96TH"B`@("`@("`@("`@("<\/WAM;"!V97)S
M:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M."(_/B<@+@H@("`@("`@("`@("`G
M/"<@+B`D=&AI<RT^7V]B:F5C=%]T>7!E("X@)R!V97)S:6]N/2(Q+C`B/B<@
M+@H@("`@("`@("`@("`G/'5I9#XG("X@)'5I9"`N("<\+W5I9#XG("X*("`@
M("`@("`@("`@)SQB;V1Y/CPO8F]D>3XG("X*("`@("`@("`@("`@)SQC871E
M9V]R:65S/CPO8V%T96=O<FEE<SXG("X*("`@("`@("`@("`@)SQC<F5A=&EO
M;BUD871E/B<@+B!+;VQA8CHZ96YC;V1E1&%T951I;64H*2`N("<\+V-R96%T
M:6]N+61A=&4^)R`N"B`@("`@("`@("`@("<\<V5N<VET:79I='D^<'5B;&EC
M/"]S96YS:71I=FET>3XG("X*("`@("`@("`@("`@)SPO)R`N("1T:&ES+3Y?
M;V)J96-T7W1Y<&4@+B`G/B<L"B`@("`@("`@("`@($1/35A-3%],3T%$7U!!
M4E-)3D<@?"!$3TU834Q?3$]!1%]#3TU03$5415]!5%124R!\"B`@("`@("`@
M("`@($1/35A-3%],3T%$7U-50E-425155$5?14Y4251)15,@?"!$3TU834Q?
M3$]!1%]$3TY47TM%15!?0DQ!3DM3+`H@("`@("`@("`@("`D97)R;W(*("`@
M("`@("`I.PH@("`@("`@(&EF("@A96UP='DH)&5R<F]R*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S(BDL("1U:60I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M=6ED(#T@)'5I9#L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?>&UL+3YD;V-U
M;65N=%]E;&5M96YT*"D["B`@("!]"@H@("`@9G5N8W1I;VX@<V%V94]B:F5C
M="@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/G-E=%9A;"@G;&%S="UM;V1I9FEC871I;VXM9&%T92<L($MO;&%B
M.CIE;F-O9&5$871E5&EM92@I*3L*("`@("`@("`D=&AI<RT^<V5T5F%L*"=P
M<F]D=6-T+6ED)RP@2T],04)?4%)/1%5#5%])1"D["@H@("`@("`@("1P87)T
M(#T@)FYE=R!-24U%7U!A<G0H)'1H:7,M/E]M:6UE7W1Y<&4L("1T:&ES+3Y?
M>&UL+3YD=6UP7VUE;2AT<G5E*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`D<&%R="T^<V5T
M5')A;G-F97)%;F-O9&EN9R@G<75O=&5D+7!R:6YT86)L92<I.PH@("`@("`@
M("1T:&ES+3Y?;65S<V%G92T^86QT97)087)T*"1T:&ES+3Y?;6EM95]I9"P@
M)'!A<G0I.PH*("`@("`@("!I9B`H)'1H:7,M/E]M<V=?;F\@(3T@+3$I('L*
M("`@("`@("`@("`@)'1H:7,M/G)E;6]V94]B:F5C=',H)'1H:7,M/E]M<V=?
M;F\L('1R=64I.PH@("`@("`@('T*"B`@("`@("`@)&AE861E<G,@/2`F;F5W
M($U)345?2&5A9&5R<R@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:&5A
M9&5R<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&AE861E<G,M
M/F%D9$AE861E<B@D:V5Y+"`D=F%L*3L*("`@("`@("!]"@H@("`@("`@("1M
M97-S86=E(#T@2V]L86(Z.FMO;&%B3F5W;&EN97,H)&AE861E<G,M/G1O4W1R
M:6YG*"D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]M97-S86=E+3YT;U-T<FEN9RAF86QS92DI.PH*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YA<'!E;F1-97-S86=E*"1M97-S
M86=E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]M<V=?;F\@/2`D=&AI<RT^9FEN9$]B:F5C="@D=&AI
M<RT^7W5I9"D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]M<V=?;F\L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;7-G
M7VYO.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@9G5N8W1I;VX@)F=E=$-U<G)E;G1/8FIE8W0H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7WAM;"T^9&]C=6UE;G1?96QE;65N="@I.PH@("`@
M?0H*("`@(&9U;F-T:6]N("9G971%;&5M*"1N86UE+"`F)'!A<F5N="D*("`@
M('L*("`@("`@("`D96QE;65N=',@/2`F)'1H:7,M/F=E=$%L;$5L96US*"1N
M86UE+"`D<&%R96YT*3L*"B`@("`@("`@:68@*&5M<'1Y*"1E;&5M96YT<RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1E;&5M96YT<ULP73L*("`@('T*"B`@("!F=6YC=&EO;B`F
M9V5T06QL16QE;7,H)&YA;64L("8D<&%R96YT*0H@("`@>PH@("`@("`@(')E
M='5R;B`D<&%R96YT+3YG971?96QE;65N='-?8GE?=&%G;F%M92@D;F%M92D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=%)O;W1%;&5M*"1N86UE*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^9V5T16QE;2@D;F%M92P@)'1H:7,M
M/F=E=$-U<G)E;G1/8FIE8W0H*2D["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E
M=$%L;%)O;W1%;&5M<R@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/F=E=$%L;$5L96US*"1N86UE+"`D=&AI<RT^9V5T0W5R<F5N=$]B:F5C
M="@I*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96Q%;&5M*"1N86UE+"`F)'!A
M<F5N="D*("`@('L*("`@("`@("`D96QE;65N="`]("8D=&AI<RT^9V5T16QE
M;2@D;F%M92P@)'!A<F5N="D["B`@("`@("`@:68@*"1E;&5M96YT(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'!A<F5N="T^<F5M;W9E7V-H:6QD*"1E;&5M96YT*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!D96Q!;&Q%;&5M<R@D;F%M92P@)B1P87)E;G0I
M"B`@("!["B`@("`@("`@)&5L96UE;G1S(#T@)B1T:&ES+3YG971!;&Q%;&5M
M<R@D;F%M92P@)'!A<F5N="D["B`@("`@("`@9F]R("@D:2`](#`L("1J(#T@
M8V]U;G0H)&5L96UE;G1S*3L@)&D@/"`D:CL@)&DK*RD@>PH@("`@("`@("`@
M("`D<&%R96YT+3YR96UO=F5?8VAI;&0H)&5L96UE;G1S6R1I72D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&1E;$%L;%)O;W1%;&5M<R@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/F1E;$%L;$5L96US*"1N86UE+"`D=&AI<RT^9V5T0W5R<F5N=$]B
M:F5C="@I*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96Q2;V]T16QE;2@F)&5L
M96UE;G0I"B`@("!["B`@("`@("`@:68@*"1E;&5M96YT(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D<F]O
M="`]("8D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I.PH@("`@("`@(')E='5R
M;B`D<F]O="T^<F5M;W9E7V-H:6QD*"1E;&5M96YT*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971%;&5M5F%L*"8D<&%R96YT+"`D;F%M92P@)&1E9F%U;'0@
M/2`P*0H@("`@>PH@("`@("`@(&EF("@D<&%R96YT(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@)&1E9F%U;'0["B`@("`@("`@?0H*("`@("`@
M("`D96QE;65N="`]("8D=&AI<RT^9V5T16QE;2@D;F%M92P@)'!A<F5N="D[
M"B`@("`@("`@:68@*"1E;&5M96YT(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("!R971U<FX@)&1E9F%U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&5L96UE;G0M/F=E=%]C;VYT96YT*"D["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T16QE;5-T<B@F)'!A<F5N="P@)&YA;64L("1D969A=6QT(#T@)R<I"B`@
M("!["B`@("`@("`@:68@*"1P87)E;G0@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@(')E='5R;B`D9&5F875L=#L*("`@("`@("!]"@H@("`@("`@("1E;&5M
M96YT(#T@)B1T:&ES+3YG971%;&5M*"1N86UE+"`D<&%R96YT*3L*("`@("`@
M("!I9B`H)&5L96UE;G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R
M;B`D9&5F875L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1E;&5M96YT+3YG971?8V]N=&5N="@I+"`G=71F
M+3@G*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971686PH)&YA;64L("1D969A
M=6QT(#T@,"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5L96U6
M86PH)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H*2P@)&YA;64L("1D969A=6QT
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G9713='(H)&YA;64L("1D969A=6QT
M(#T@)R<I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971%;&5M4W1R
M*"1T:&ES+3YG971#=7)R96YT3V)J96-T*"DL("1N86UE+"`D9&5F875L="D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@)FEN:71%;&5M*"1N86UE+"`F)'!A<F5N
M="D*("`@('L*("`@("`@("!I9B`H)'!A<F5N="`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@)'!A<F5N="`]("1T:&ES+3YG971#=7)R96YT3V)J96-T*"D[
M"B`@("`@("`@?0H*("`@("`@("`D96QE;65N="`]("1T:&ES+3YG971%;&5M
M*"1N86UE+"`D<&%R96YT*3L*"B`@("`@("`@:68@*"1E;&5M96YT(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`D96QE;65N="`]("1P87)E;G0M/F%P<&5N
M9%]C:&EL9"@D=&AI<RT^7WAM;"T^8W)E871E7V5L96UE;G0H)&YA;64I*3L*
M("`@("`@("!]"@H@("`@("`@("1C:&EL9')E;B`]("1E;&5M96YT+3YC:&EL
M9%]N;V1E<R@I.PH@("`@("`@(&9O<F5A8V@@*"1C:&EL9')E;B!A<R`D8VAI
M;&0I('L*("`@("`@("`@("`@:68@*"1C:&EL9"T^;F]D95]T>7!E*"D@/3T@
M6$U,7U1%6%1?3D]$12D@>PH@("`@("`@("`@("`@("`@)&5L96UE;G0M/G)E
M;6]V95]C:&EL9"@D8VAI;&0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&5L96UE;G0["B`@("!]"@H@("`@9G5N8W1I;VX@
M)FEN:712;V]T16QE;2@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/FEN:71%;&5M*"1N86UE+"`D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I
M*3L*("`@('T*"B`@("!F=6YC=&EO;B`F87!P96YD16QE;2@D;F%M92P@)B1P
M87)E;G0I"B`@("!["B`@("`@("`@<F5T=7)N("1P87)E;G0M/F%P<&5N9%]C
M:&EL9"@D=&AI<RT^7WAM;"T^8W)E871E7V5L96UE;G0H)&YA;64I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B`F87!P96YD4F]O=$5L96TH)&YA;64I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YA<'!E;F1%;&5M*"1N86UE+"`D=&AI
M<RT^9V5T0W5R<F5N=$]B:F5C="@I*3L*("`@('T*"B`@("!F=6YC=&EO;B`F
M<V5T16QE;59A;"@F)'!A<F5N="P@)&YA;64L("1V86QU92`]("<G*0H@("`@
M>PH@("`@("`@("1E;&5M96YT(#T@)B1T:&ES+3YI;FET16QE;2@D;F%M92P@
M)'!A<F5N="D["B`@("`@("`@)&5L96UE;G0M/G-E=%]C;VYT96YT*"1V86QU
M92D["@H@("`@("`@(')E='5R;B`D96QE;65N=#L*("`@('T*"B`@("!F=6YC
M=&EO;B`F<V5T16QE;5-T<B@F)'!A<F5N="P@)&YA;64L("1V86QU92`]("<G
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5T16QE;59A;"@D<&%R
M96YT+"`D;F%M92P@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L($Y,
M4SHZ9V5T0VAA<G-E="@I+"`G=71F+3@G*2D["B`@("!]"@H@("`@9G5N8W1I
M;VX@)G-E=%9A;"@D;F%M92P@)'9A;'5E(#T@)R<I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YS971%;&5M5F%L*"1T:&ES+3YG971#=7)R96YT3V)J
M96-T*"DL("1N86UE+"`D=F%L=64I.PH@("`@?0H*("`@(&9U;F-T:6]N("9S
M9713='(H)&YA;64L("1V86QU92`]("<G*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<V5T16QE;5-T<B@D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I
M+"`D;F%M92P@)'9A;'5E*3L*("`@('T*"B\O(%5T:6QI='D@;&EB<F%R>2!I
M;G1E<F9A8V4*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S=')I;F<@8V]N
M=&%I;FEN9R!T:&4@8W5R<F5N="!55$,@9&%T92!I;B!T:&4@9F]R;6%T"B`@
M("`@*B!P<F5S8W)I8F5D(&)Y('1H92!+;VQA8B!&;W)M870@4W!E8VEF:6-A
M=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-U<G)E
M;G0@551#(&1A=&4@:6X@=&AE(&9O<FUA="`G65E962U-32U$1"<N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5N8V]D941A=&4H)&1A=&4@/2!F86QS92D*("`@
M('L*("`@("`@("!I9B`H)&1A=&4@/3T](#`I('L*("`@("`@("`@("`@<F5T
M=7)N(#`["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=')F=&EM92@G)5DM
M)6TM)60G+"`D9&%T92`]/3T@9F%L<V4@/R!T:6UE*"D@.B`D9&%T92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@54Y)6"!T:6UE<W1A;7`@
M8V]R<F5S<&]N9&EN9R!T:&4@9VEV96X@9&%T92!S=')I;F<@=VAI8V@@:7,@
M:6X*("`@("`J('1H92!F;W)M870@<')E<V-R:6)E9"!B>2!T:&4@2V]L86(@
M1F]R;6%T(%-P96-I9FEC871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T92`@5&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@
M9&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!U;FEX
M('1I;65S=&%M<"!C;W)R97-P;VYD:6YG('1O("1D871E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!D96-O9&5$871E*"1D871E*0H@("`@>PH@("`@("`@(&EF
M("AE;7!T>2@D9&%T92DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@
M("`@?0H*("`@("`@("!L:7-T*"1Y96%R+"`D;6]N=&@L("1D87DI(#T@97AP
M;&]D92@G+2<L("1D871E*3L*("`@("`@("!R971U<FX@;6MT:6UE*#`L(#`L
M(#`L("1M;VYT:"P@)&1A>2P@)'EE87(I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('-T<FEN9R!C;VYT86EN:6YG('1H92!C=7)R96YT(%54
M0R!D871E(&%N9"!T:6UE(&EN('1H92!F;W)M870*("`@("`J('!R97-C<FEB
M960@8GD@=&AE($MO;&%B($9O<FUA="!3<&5C:69I8V%T:6]N+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("`@(%1H92!C=7)R96YT(%540R!D871E
M(&%N9"!T:6UE(&EN('1H92!F;W)M870*("`@("`J("`@("`@("`@("`@("`@
M("`@("=965E9+4U-+41$5&AH.FUM.G-S6B<L('=H97)E('1H92!4(&%N9"!:
M(&%R92!L:71E<F%L"B`@("`@*B`@("`@("`@("`@("`@("`@("!C:&%R86-T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-O9&5$871E5&EM92@D9&%T
M971I;64@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)&1A=&5T:6UE(#T]
M/2`P*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@9VUS=')F=&EM92@G)5DM)6TM)614)4@Z)4TZ)5-:)RP@)&1A
M=&5T:6UE(#T]/2!F86QS92`_('1I;64H*2`Z("1D871E=&EM92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@54Y)6"!T:6UE<W1A;7`@8V]R
M<F5S<&]N9&EN9R!T:&4@9VEV96X@9&%T92UT:6UE('-T<FEN9R!W:&EC:`H@
M("`@("H@:7,@:6X@=&AE(&9O<FUA="!P<F5S8W)I8F5D(&)Y('1H92!+;VQA
M8B!&;W)M870@4W!E8VEF:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D871E=&EM92`@5&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O
M9B!T:&4@9&%T92`F('1I;64N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M9V5R("!4:&4@=6YI>"!T:6UE<W1A;7`@8V]R<F5S<&]N9&EN9R!T;R`D9&%T
M971I;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D941A=&54:6UE*"1D
M871E=&EM92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1A=&5T:6UE*2D@
M>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"@H@("`@("`@(&QI
M<W0H)'EE87(L("1M;VYT:"P@)&1A>2P@)&AO=7(L("1M:6YU=&4L("1S96-O
M;F0I"B`@("`@("`@("`@(#T@<W-C86YF*"1D871E=&EM92P@)R5D+25D+25D
M5"5D.B5D.B5D6B<I.PH@("`@("`@(')E='5R;B!G;6UK=&EM92@D:&]U<BP@
M)&UI;G5T92P@)'-E8V]N9"P@)&UO;G1H+"`D9&%Y+"`D>65A<BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@54Y)6"!T:6UE<W1A;7`@8V]R
M<F5S<&]N9&EN9R!T:&4@9VEV96X@9&%T92!O<B!D871E+71I;64*("`@("`J
M('-T<FEN9R!W:&EC:"!I<R!I;B!E:71H97(@9F]R;6%T('!R97-C<FEB960@
M8GD@=&AE($MO;&%B($9O<FUA=`H@("`@("H@4W!E8VEF:6-A=&EO;BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871E("!4:&4@<W1R:6YG(')E
M<')E<V5N=&%T:6]N(&]F('1H92!D871E("@F('1I;64I+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE('5N:7@@=&EM97-T86UP(&-O<G)E
M<W!O;F1I;F<@=&\@)&1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D
M941A=&5/<D1A=&54:6UE*"1D871E*0H@("`@>PH@("`@("`@(&EF("AE;7!T
M>2@D9&%T92DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@*'-T<FQE;B@D9&%T92D@/3T@,3`@/R!+;VQA8CHZ
M9&5C;V1E1&%T92@D9&%T92D@.B!+;VQA8CHZ9&5C;V1E1&%T951I;64H)&1A
M=&4I*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96-O9&5&=6QL1&%Y1&%T92@D
M9&%T92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1A=&4I*2!["B`@("`@
M("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("AS
M=')L96XH)&1A=&4I(#T](#$P(#\@2V]L86(Z.F1E8V]D941A=&4H)&1A=&4I
M*S(T*C8P*C8P(#H@2V]L86(Z.F1E8V]D941A=&54:6UE*"1D871E*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@<&5R8V5N=&%G951O0F]O;&5A;B@D<&5R8V5N
M=&%G92D*("`@('L*("`@("`@("!R971U<FX@)'!E<F-E;G1A9V4@/3T@,3`P
M(#\@)S$G(#H@)S`G.PH@("`@?0H*("`@(&9U;F-T:6]N(&)O;VQE86Y4;U!E
M<F-E;G1A9V4H)&)O;VQE86XI"B`@("!["B`@("`@("`@<F5T=7)N("1B;V]L
M96%N(#\@)S$P,"<@.B`G,"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV
M97)T<R!A('-T<FEN9R!I;B!T:&4@8W5R<F5N="!C:&%R86-T97(@<V5T('1O
M(&%N($E-05`@551&+3<@<W1R:6YG+`H@("`@("H@<W5I=&%B;&4@9F]R('5S
M92!A<R!T:&4@;F%M92!O9B!A;B!)34%0(&9O;&1E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@=&5X="!I;B!T:&4@8W5R<F5N
M="!C:&%R86-T97(@<V5T('1O(&-O;G9E<G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@("`@)&YA;64@96YC;V1E9"!I;B!T:&4@24U!4"!V87)I
M871I;VX@;V8@551&+3<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D94EM
M87!&;VQD97).86UE*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1N86UE+"!.3%,Z.F=E=$-H87)S970H*2P@
M)U541C<M24U!4"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@
M82!S=')I;F<@:6X@=&AE($E-05`@=F%R:6%T:6]N(&]F(%541BTW(&EN=&\@
M82!S=')I;F<@:6X@=&AE"B`@("`@*B!C=7)R96YT(&-H87)A8W1E<B!S970N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE('1E>'0@
M:6X@24U!4"!55$8M-R!T;R!C;VYV97)T+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("`@("1N86UE(&5N8V]D960@:6X@=&AE(&-U<G)E;G0@8VAA
M<F%C=&5R('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E26UA<$9O
M;&1E<DYA;64H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N(%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)&YA;64L("=55$8W+4E-05`G*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;G9E<G1S(&%L;"!N97=L:6YE<R`H:6X@1$]3+"!-
M04,@)B!53DE8(&9O<FUA="D@:6X@=&AE('-P96-I9FEE9"!T97AT"B`@("`@
M*B!T;R!U;FEX+7-T>6QE("A,1BD@9F]R;6%T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O(&-O;G9E<G0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@("1T97AT('=I=&@@86QL(&YE=VQI
M;F5S(')E<&QA8V5D(&)Y($Q&+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;FEX
M3F5W;&EN97,H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P
M;&%C92@B+UQR7&Y\7&Y\7'(O<R(L(")<;B(L("1T97AT*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;G9E<G1S(&%L;"!N97=L:6YE<R`H:6X@1$]3+"!-
M04,@)B!53DE8(&9O<FUA="D@:6X@=&AE('-P96-I9FEE9"!T97AT"B`@("`@
M*B!T;R!+;VQA8B`H0WER=7,I(&9O<FUA="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!C;VYV97)T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("`D=&5X="!W:71H(&%L;"!N97=L:6YE
M<R!R97!L86-E9"!B>2!+3TQ!0E].15=,24Y%+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!K;VQA8DYE=VQI;F5S*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R
M;B!P<F5G7W)E<&QA8V4H(B]<<EQN?%QN?%QR+W,B+"!+3TQ!0E].15=,24Y%
M+"`D=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U
M;F9O;&1E9"!R97!R97-E;G1A=&EO;B!O9B!T:&4@9VEV96X@=&5X="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!U
M;F9O;&0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U;F9O
M;&1E9"!R97!R97-E;G1A=&EO;B!O9B`D=&5X="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=6YF;VQD5&5X="@D=&5X="D*("`@('L*("`@("`@("!R971U<FX@
M<')E9U]R97!L86-E*"(O7')<;EL@7'1=*R\B+"`B(BP@)'1E>'0I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A<'!L:6-A
M=&EO;BUS<&5C:69I8R!C;VYS=&%N=',L('1H870@87)E('5S960@:6X*("`@
M("`J(&$@9V5N97)I8R!M86YN97(@=&AR;W5G:&]U="!T:&4@;&EB<F%R>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A
M=&EO;B!W:&]S92!C;VYS=&%N=',@=&\@<75E<GDN"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@06X@87)R87D@;V8@87!P;&EC871I;VXM<W!E8VEF
M:6,@8V]N<W1A;G1S(&EF("1A<'`@:7,@80H@("`@("H@("`@("`@("`@("`@
M("`@<W5P<&]R=&5D(&%P<&QI8V%T:6]N+"!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&EF("1A<'`@:7,*("`@("`J("`@("`@("`@("`@("`@(&YO="!S=7!P
M;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%P<$-O;G-T<R@D87!P
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)&%P<"D@>PH@("`@("`@(&-A<V4@
M)VUN96UO)SH*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)VUI;65?='EP95]S=69F:7@G("`@("`@/3X@)VYO=&4G+`H@("`@
M("`@("`@("`@("`@)V1E9F%U;'1?9F]L9&5R7VYA;64G("`@/3X@7R@B3F]T
M97,B*2P*("`@("`@("`@("`@("`@("=S:&%R95]N86UE)R`@("`@("`@("`@
M(#T^(%\H(FYO=&5P860B*2P*("`@("`@("`@("`@("`@("=D969A=6QT7W-H
M87)E7VYA;64G("`@(#T^(%\H(B5S)W,@3F]T97!A9"(I+`H@("`@("`@("`@
M("`I.PH*("`@("`@("!C87-E("=K<F]N;VQI=&@G.@H@("`@("`@("`@("!R
M971U<FX@87)R87DH"B`@("`@("`@("`@("`@("`G;6EM95]T>7!E7W-U9F9I
M>"<@("`@("`]/B`G979E;G0G+`H@("`@("`@("`@("`@("`@)V1E9F%U;'1?
M9F]L9&5R7VYA;64G("`@/3X@7R@B0V%L96YD87(B*2P*("`@("`@("`@("`@
M("`@("=S:&%R95]N86UE)R`@("`@("`@("`@(#T^(%\H(F-A;&5N9&%R(BDL
M"B`@("`@("`@("`@("`@("`G9&5F875L=%]S:&%R95]N86UE)R`@("`]/B!?
M*"(E<R=S($-A;&5N9&%R(BDL"B`@("`@("`@("`@("D["@H@("`@("`@(&-A
M<V4@)W1U<F)A)SH*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)VUI;65?='EP95]S=69F:7@G("`@("`@/3X@)V-O;G1A8W0G
M+`H@("`@("`@("`@("`@("`@)V1E9F%U;'1?9F]L9&5R7VYA;64G("`@/3X@
M7R@B0V]N=&%C=',B*2P*("`@("`@("`@("`@("`@("=S:&%R95]N86UE)R`@
M("`@("`@("`@(#T^(%\H(F%D9')E<W,@8F]O:R(I+`H@("`@("`@("`@("`@
M("`@)V1E9F%U;'1?<VAA<F5?;F%M92<@("`@/3X@7R@B)7,G<R!!9&1R97-S
M($)O;VLB*2P*("`@("`@("`@("`@*3L*"B`@("`@("`@8V%S92`G;F%G)SH*
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VUI
M;65?='EP95]S=69F:7@G("`@("`@/3X@)W1A<VLG+`H@("`@("`@("`@("`@
M("`@)V1E9F%U;'1?9F]L9&5R7VYA;64G("`@/3X@7R@B5&%S:W,B*2P*("`@
M("`@("`@("`@("`@("=S:&%R95]N86UE)R`@("`@("`@("`@(#T^(%\H(G1A
M<VL@;&ES="(I+`H@("`@("`@("`@("`@("`@)V1E9F%U;'1?<VAA<F5?;F%M
M92<@("`@/3X@7R@B)7,G<R!487-K;&ES="(I+`H@("`@("`@("`@("`I.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B*2P@)&%P<"DI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@24U!
M4"!!0TP@<W1R:6YG(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&=I=F5N($AO<F1E
M('!E<FUI<W-I;VYS"B`@("`@*B!V86QU92X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<&5R;7,@(%1H92!(;W)D92!P97)M:7-S:6]N<R!V86QU
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1O=VYE<B`@5VEL;"!T:&4@04-,
M('-T<FEN9R!B92!U<V5D(&9O<B!T:&4@9F]L9&5R(&]W;F5R/PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!4:&ES(&EN8VQU9&5S('1H92`G82<@
M<FEG:'1S(&EN('1H92!!0TP@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@24U!4"!!0TP@<W1R:6YG(&-O<G)E<W!O;F1I;F<@
M=&\@)'!E<FUS(&%N9"`D;W=N97(N"B`@("`@*B\*("`@(&9U;F-T:6]N('!E
M<FUS5&]!0TPH)'!E<FUS+"`D;W=N97(@/2!T<G5E*0H@("`@>PH@("`@("`@
M("1R97-U;'0@/2`D;W=N97(@/R`G82<@.B`G)SL*("`@("`@("!I9B`H)'!E
M<FUS("8@4$5235-?4TA/5RD@>PH@("`@("`@("`@("`D<F5S=6QT("X]("=L
M)SL*("`@("`@("!]"B`@("`@("`@:68@*"1P97)M<R`F(%!%4DU37U)%040I
M('L*("`@("`@("`@("`@)')E<W5L="`N/2`G<B<["B`@("`@("`@?0H@("`@
M("`@(&EF("@D<&5R;7,@)B!015)-4U]%1$E4*2!["B`@("`@("`@("`@("1R
M97-U;'0@+CT@)VES=V,G.PH@("`@("`@('T*("`@("`@("!I9B`H)'!E<FUS
M("8@4$5235-?1$5,151%*2!["B`@("`@("`@("`@("1R97-U;'0@+CT@)V0G
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@2&]R9&4@<&5R;6ES<VEO;G,@=F%L
M=64@8V]R<F5S<&]N9&EN9R!T;R!T:&4@9VEV96X@24U!4"!!0TP*("`@("`J
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8VQ?<W1R
M:6YG("!4:&4@24U!4"!!0TP@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@5&AE($AO<F1E('!E<FUI<W-I;VYS('9A;'5E(&-O<G)E
M<W!O;F1I;F<@=&\*("`@("`J("`@("`@("`@("`@("`@("`@)&%C;%]S=')I
M;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%C;%1O4&5R;7,H)&%C;%]S=')I
M;F<I"B`@("!["B`@("`@("`@)')E<W5L="`](#`["@H@("`@("`@(&9O<B`H
M)&D@/2`P+"`D:B`]('-T<FQE;B@D86-L7W-T<FEN9RD[("1I(#P@)&H[("1I
M*RLI('L*("`@("`@("`@("`@<W=I=&-H("@D86-L7W-T<FEN9ULD:5TI('L*
M("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT
M('P](%!%4DU37U-(3U<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)W(G.@H@("`@("`@("`@("`@("`@)')E<W5L="!\/2!0
M15)-4U]214%$.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E("=I)SH*("`@("`@("`@("`@("`@("1R97-U;'0@?#T@4$5235-?
M141)5#L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G9"<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT('P](%!%4DU37T1%3$54
M13L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T97,@86X@87-S;V-I871I=F4@87)R87D@;W5T(&]F(&%N
M($E-05`@04-,(&QI<W0@87,@<F5T=7)N960@8GD@=&AE"B`@("`@*B!.971?
M24U!4"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A8VP@
M(%1H92!)34%0($%#3"!A<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&ME>7,@87)E
M(&EN9&EV:61U86P@=7-E<G,*("`@("`J("`@("`@("`@("`@("`@(&%N9"!T
M:&4@=F%L=65S('1H92!!0TP@<W1R:6YG(&9O<B!T:&4@<W!E8VEF:6,@=7-E
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@86-L5&]!<G)A>2@D86-L*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A*"1A8VPL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1A8VP["B`@("`@("`@?0H*("`@("`@("`D<F5S
M=6QT(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D86-L(&%S("1U<V5R
M*2!["B`@("`@("`@("`@("1R97-U;'1;)'5S97);)U5315(G75T@/2`D=7-E
M<ELG4DE'2%13)UT["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@('T*"B`@("!F=6YC=&EO;B!G9713:&%R94UA<"@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&5M<'1Y*"1?4T534TE/3EM+3TQ!0E]32$%215]-05!=
M*0H@("`@("`@("`@/R!A<G)A>2@I"B`@("`@("`@("`Z('5N<V5R:6%L:7IE
M*"1?4T534TE/3EM+3TQ!0E]32$%215]-05!=*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!S9713:&%R94UA<"@D<VAA<F5?;6%P*0H@("`@>PH@("`@("`@("1?
M4T534TE/3EM+3TQ!0E]32$%215]-05!=(#T@<V5R:6%L:7IE*"1S:&%R95]M
M87`I.PH@("`@?0H*("`@(&9U;F-T:6]N('5P9&%T94UA<'!E9%-H87)E*"8D
M<VAA<F5?;6%P+"`D<VAA<F5?=6ED+"`D:6UA<%]F;VQD97(I"B`@("!["B`@
M("`@("`@)'-H87)E7VUA<%LD<VAA<F5?=6ED72`]("1I;6%P7V9O;&1E<CL*
M("`@('T*"B`@("!F=6YC=&EO;B!G9713:&%R94UA<'!I;F<H)B1S:&%R95]M
M87`L("1S:&%R95]U:60L("1D;F5?<F5S=6QT(#T@)R<I"B`@("!["B`@("`@
M("`@<F5T=7)N(&5M<'1Y*"1S:&%R95]M87!;)'-H87)E7W5I9%TI(#\@)&1N
M95]R97-U;'0@.B`D<VAA<F5?;6%P6R1S:&%R95]U:61=.PH@("`@?0H*("`@
M(&9U;F-T:6]N(')E;6]V94UA<'!E9%-H87)E*"8D<VAA<F5?;6%P+"`D<VAA
M<F5?=6ED*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<VAA<F5?;6%P6R1S
M:&%R95]U:61=*2D@>PH@("`@("`@("`@("!U;G-E="@D<VAA<F5?;6%P6R1S
M:&%R95]U:61=*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M>6YC:')O;FES97,@=&AE(%!E<FUS(&]F(&$@2&]R9&4@<VAA<F4@=&\@=&AE
M($%#3"!O9B!A;B!)34%0(&9O;&1E<BP*("`@("`J(&-R96%T:6YG('1H92!F
M;VQD97(@:68@;F5C97-S87)Y+B!)="!A;'-O('-E=',@=&AE(&YE8V5S<V%R
M>2!A;FYO=&%T:6]N<PH@("`@("H@:6YD:6-A=&EN9R!W:&%T(&=R;W5P=V%R
M92!F;W)M870@='EP92!I<R!C;VYT86EN960@=VET:&EN('1H92!F;VQD97(L
M"B`@("`@*B!A;F0@=VAA="!(;W)D92!S:&%R92!I="!C;W)R97-P;VYD<R!T
M;RX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1I;6%P("`@02!R969E
M<F5N8V4@=&\@82!.971?24U!4"!O8FIE8W0@=&AA="!I<R!A;')E861Y"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&5D(&%N9"!A=71H
M96YT:6-A=&5D('1O('1H92!C;W)R96-T('-E<G9E<BX*("`@("`J($!P87)A
M;2!O8FIE8W0@)'-H87)E("!!(')E9F5R96YC92!T;R!T:&4@2&]R9&4@<VAA
M<F4@;V)J96-T('1H870@=V4@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:6YT97)E<W1E9"!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&%P
M<%]C;VYS=',@($$@<F5F97)E;F-E('1O('1H92!R97-U;'0@;V8@82!G971!
M<'!#;VYS=',H*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V%L;"!F;W(@=&AE(&-U<G)E;G0@2&]R9&4@87!P;&EC871I;VXN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@2&]R9&4O2V]L86(@:6YT96=R871I
M;VXM<W5P<&]R=&5D(&%P<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,L(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<WEN8VAR;VYI<V53:&%R92@F
M)&EM87`L("8D<VAA<F4L("8D87!P7V-O;G-T<RD*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8["@H@("`@("`@(&EF("AE;7!T>2@D<VAA<F4I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@
M<VAA<F4@;V)J96-T(BDI.PH@("`@("`@('T*"B`@("`@("`@)'-H87)E7W5I
M9"`]("1S:&%R92T^9V5T3F%M92@I.PH@("`@("`@("1O=VYE<B`]("1S:&%R
M92T^9V5T*"=O=VYE<B<I.PH@("`@("`@("1D969A=6QT(#T@)'-H87)E7W5I
M9"`]/2`D;W=N97(["@H@("`@("`@("1N9'@@/2!S=')P;W,H)&]W;F5R+"`G
M0"<I.PH@("`@("`@("1U<V5R(#T@)&YD>"`]/3T@9F%L<V4@/R`D;W=N97(@
M.B!S=6)S='(H)&]W;F5R+"`P+"`D;F1X*3L*("`@("`@("`D9&]M86EN(#T@
M<W1R<W1R*"1O=VYE<BP@)T`G*3L*"B`@("`@("`@)&9O;&1E<E]T>7!E(#T@
M)&%P<%]C;VYS='-;)VUI;65?='EP95]S=69F:7@G72`N("@D9&5F875L="`_
M("<N9&5F875L="<@.B`G)RD["B`@("`@("`@)&9O;&1E<E]N86UE(#T@(G5S
M97(O)'5S97(O(B`N("@D9&5F875L="`_("1A<'!?8V]N<W1S6R=D969A=6QT
M7V9O;&1E<E]N86UE)UT@.B`D<VAA<F4M/F=E="@G;F%M92<I*2`N("1D;VUA
M:6X["B`@("`@("`@+R]+;VQA8CHZ96YC;V1E26UA<$9O;&1E<DYA;64H)&1E
M9F%U;'0@/R`D87!P7V-O;G-T<ULG9&5F875L=%]F;VQD97)?;F%M92==(#H@
M)'-H87)E+3YG970H)VYA;64G*2D["B`@("`@("`@:68@*&ES7V$H)&9O;&1E
M<E]N86UE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M9F]L9&5R7VYA;64["B`@("`@("`@?0H*("`@("`@("`D<VAA<F5?;6%P(#T@
M2V]L86(Z.F=E=%-H87)E36%P*"D["@H@("`@("`@("1O;&1?9F]L9&5R(#T@
M2V]L86(Z.F=E=%-H87)E36%P<&EN9R@D<VAA<F5?;6%P+"`D<VAA<F5?=6ED
M*3L*"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YM86EL8F]X17AI<W0H)&9O
M;&1E<E]N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1F;VQD97)?;F%M92`A/2`D;VQD7V9O;&1E<BD@
M>PH@("`@("`@("`@("!I9B`H)')E<W5L="`F)B`D;VQD7V9O;&1E<BD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',B*2P@)&9O;&1E<E]N86UE+"`D;VQD7V9O
M;&1E<BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&]L9%]F
M;VQD97(I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D:6UA<"T^<F5N
M86UE36%I;&)O>"@D;VQD7V9O;&1E<BP@)&9O;&1E<E]N86UE*3L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1R97-U;'0@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)&EM87`M/F-R96%T
M94UA:6QB;W@H)&9O;&1E<E]N86UE*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@1W)A;G0@=&AE($-Y<G5S
M($%D;6EN:7-T<F%T;W(@8W)E871E("8@9&5L971E(&%C8V5S<R`H;F5E9&5D
M"B`@("`@("`@+R\@9F]R('1H92!A9&UI;G5S97(@=&\@9&5L971E('1H92!M
M86EL8F]X('=H96X@<F5M;W9I;F<@<VAA<F5S*0H@("`@("`@("1R97-U;'0@
M/2`D:6UA<"T^<V5T04-,*"1F;VQD97)?;F%M92P@)&-O;F9;)VMO;&%B)UU;
M)VEM87`G75LG861M:6YU<V5R)UTL("=C9"<I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D86-L(#T@2V]L86(Z.F%C
M;%1O07)R87DH)&EM87`M/F=E=$%#3"@D9F]L9&5R7VYA;64I*3L*("`@("`@
M("!I9B`H:7-?82@D86-L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D86-L.PH@("`@("`@('T*"B`@("`@("`@)'!E<FT@/2`F)'-H
M87)E+3YG971097)M:7-S:6]N*"D["B`@("`@("`@)'!E<FU?;&ES="`]("1P
M97)M+3YG9715<V5R4&5R;6ES<VEO;G,H*3L*"B`@("`@("`@9F]R96%C:"`H
M)'!E<FU?;&ES="!A<R`D=7-E<B`]/B`D=7-E<E]P97)M<RD@>PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)&EM87`M/G-E=$%#3"@D9F]L9&5R7VYA;64L("1U
M<V5R+"!+;VQA8CHZ<&5R;7-4;T%C;"@D=7-E<E]P97)M<RP@)'5S97(@/3T@
M)&]W;F5R*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!U;G-E="@D86-L6R1U<V5R72D[
M"B`@("`@("`@?0H*("`@("`@("`O+R!-86ME('-U<F4@=V4@9&]N)W0@9&5L
M971E('1H92!C=7)R96YT('5S97(@;W(@=&AE($-Y<G5S"B`@("`@("`@+R\@
M061M:6YI<W1R871O<B!F<F]M('1H92!F;VQD97(G<R!!0TPL(&]R(&5L<V4@
M=V4G;&P@8F4@;&]C:V5D(&]U=`H@("`@("`@('5N<V5T*"1A8VQ;)&]W;F5R
M72D["B`@("`@("`@=6YS970H)&%C;%LD8V]N9ELG:V]L86(G75LG:6UA<"==
M6R=A9&UI;G5S97(G75TI.PH*("`@("`@("!F;W)E86-H("@D86-L(&%S("1U
M<V5R(#T^("1U<V5R7V%C;"D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)&EM
M87`M/F1E;&5T94%#3"@D9F]L9&5R7VYA;64L("1U<V5R*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^<V5T06YN;W1A=&EO;BA+
M3TQ!0E]!3DY/5%]&3TQ$15)?5%E012P@87)R87DH)W9A;'5E+G-H87)E9"<@
M/3X@)&9O;&1E<E]T>7!E*2P@)&9O;&1E<E]N86UE*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1I
M;6%P+3YS971!;FYO=&%T:6]N*$M/3$%"7T%.3D]47U-(05)%7U5)1"P@87)R
M87DH)W9A;'5E+G-H87)E9"<@/3X@)'-H87)E7W5I9"DL("1F;VQD97)?;F%M
M92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@($MO;&%B.CIU<&1A=&5-87!P9613:&%R92@D<VAA<F5?;6%P+"`D<VAA
M<F5?=6ED+"`D9F]L9&5R7VYA;64I.PH@("`@("`@($MO;&%B.CIS9713:&%R
M94UA<"@D<VAA<F5?;6%P*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@9G5N8W1I;VX@=7!D871E4VAA<F4H)B1S:&%R92D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y+"`D;F]T:69I8V%T:6]N.PH*("`@("`@
M("`D87!P(#T@)')E9VES=')Y+3YG971!<'`H*3L*("`@("`@("!I9B`H87)R
M87E?<V5A<F-H*"1A<'`L(&%R<F%Y*"=M;F5M;R<L("=N86<G+"`G='5R8F$G
M+"`G:W)O;F]L:71H)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H
M96UP='DH)%]315-324].6TM/3$%"7TQ!4U1?4UE.0TA%1%]!4%!=*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1A<'`@/2`D7U-%4U-)3TY;2T],04)?3$%35%]364Y#2$5$
M7T%04%T["B`@("`@("`@?0H*("`@("`@("`D87!P7V-O;G-T<R`]($MO;&%B
M.CIG971!<'!#;VYS=',H)&%P<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]C
M;VYS=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]($MO;&%B.CI?=7!D
M871E4VAA<F4H)'-H87)E+"`D87!P7V-O;G-T<RD["B`@("`@("`@)&ED(#T@
M)'-H87)E+3YG970H)VYA;64G*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S(%PB)7-<(CH@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A<'!?8V]N<W1S6R=S:&%R95]N86UE)UTL
M("1I9"P@)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F
M=6YC=&EO;B!?=7!D871E4VAA<F4H)B1S:&%R92P@)B1A<'!?8V]N<W1S*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&EM87`@/2`F
M;F5W($YE=%])34%0*"1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==
M+"`D8V]N9ELG:V]L86(G75LG:6UA<"==6R=P;W)T)UTI.PH@("`@("`@(&EF
M("AI<U]A*"1I;6%P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6UA<#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D:6UA
M<"T^;&]G:6XH)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UTL
M("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)V%D;6EN<'<G72P@9F%L<V4L(&9A
M;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]($MO;&%B.CIS>6YC:')O;FES95-H87)E*"1I;6%P
M+"`D<VAA<F4L("1A<'!?8V]N<W1S*3L*"B`@("`@("`@)&EM87`M/F1I<V-O
M;FYE8W0H*3L*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M9G5N8W1I;VX@<F5M;W9E4VAA<F4H)B1S:&%R92D*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y+"`D;F]T:69I8V%T:6]N.PH*("`@("`@("`D87!P
M(#T@)')E9VES=')Y+3YG971!<'`H*3L*"B`@("`@("`@+R\@5V4@;VYL>2!R
M96UO=F4@<VAA<F5S(&EF($MO;&%B(&EN=&5G<F%T:6]N(&ES(&5N86)L960L
M(&%N9"!I9B!W92=V90H@("`@("`@("\O('!R979I;W5S;'D@<WEN8VAR;VYI
M<V5D('1H92!S:&%R97,@;&ES="`H:2YE+B!W92!K;F]W('=H870@24U!4`H@
M("`@("`@("\O(&9O;&1E<B!C;W)R97-P;VYD<R!T;R!T:&4@9VEV96X@<VAA
M<F4I+@H@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=K;VQA
M8B==6R=E;F%B;&5D)UTI('Q\"B`@("`@("`@("`@("@A96UP='DH)%]315-3
M24].6TM/3$%"7TQ!4U1?4UE.0TA%1%]!4%!=*2`F)@H@("`@("`@("`@("`@
M)%]315-324].6TM/3$%"7TQ!4U1?4UE.0TA%1%]!4%!=("$]("1A<'`I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("1A<'!?8V]N<W1S(#T@2V]L86(Z.F=E=$%P<$-O;G-T<R@D87!P*3L*("`@
M("`@("!I9B`H:7-?82@D87!P7V-O;G-T<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D
M<F5S=6QT(#T@2V]L86(Z.E]R96UO=F53:&%R92@D<VAA<F4I.PH@("`@("`@
M("1I9"`]("1S:&%R92T^9V5T*"=N86UE)RD["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&%P<%]C;VYS='-;)W-H87)E7VYA;64G
M72P@)&ED+"`D<F5S=6QT+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!](&5L<V5I9B`H)')E<W5L="`]/3T@=')U92D@>PH@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%P<%]C;VYS
M='-;)W-H87)E7VYA;64G72P@)&ED*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96UO=F53:&%R92@F)'-H87)E*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D8V]N9CL*"B`@("`@("`@:68@*&5M<'1Y*"1S:&%R92DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!S:&%R
M92!O8FIE8W0B*2D["B`@("`@("`@?0H*("`@("`@("`D<VAA<F5?=6ED(#T@
M)'-H87)E+3YG971.86UE*"D["@H@("`@("`@("1S:&%R95]M87`@/2!+;VQA
M8CHZ9V5T4VAA<F5-87`H*3L*"B`@("`@("`@)&9O;&1E<B`]($MO;&%B.CIG
M9713:&%R94UA<'!I;F<H)'-H87)E7VUA<"P@)'-H87)E7W5I9"D["B`@("`@
M("`@:68@*&5M<'1Y*"1F;VQD97(I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@)&EM87`@/2`F;F5W($YE=%])34%0
M*"1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L
M86(G75LG:6UA<"==6R=P;W)T)UTI.PH@("`@("`@(&EF("AI<U]A*"1I;6%P
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6UA<#L*
M("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^;&]G:6XH)&-O
M;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UTL("1C;VYF6R=K;VQA
M8B==6R=I;6%P)UU;)V%D;6EN<'<G72P@9F%L<V4L(&9A;'-E*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L
M="`]("1I;6%P+3YD96QE=&5-86EL8F]X*"1F;VQD97(I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D:6UA<"T^9&ES
M8V]N;F5C="@I.PH*("`@("`@("!+;VQA8CHZ<F5M;W9E36%P<&5D4VAA<F4H
M)'-H87)E7VUA<"P@)'-H87)E7W5I9"D["@H@("`@("`@($MO;&%B.CIS9713
M:&%R94UA<"@D<VAA<F5?;6%P*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@9G5N8W1I;VX@<WEN8VAR;VYI<V53:&%R97,H)B1S:&%R97,L
M("1A<'`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=C;VYF
M)UU;)VMO;&%B)UU;)V5N86)L960G72D@?'P*("`@("`@("`@("`@87)R87E?
M<V5A<F-H*"1A<'`L(&%R<F%Y*"=M;F5M;R<L("=N86<G+"`G='5R8F$G+"`G
M:W)O;F]L:71H)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("`O+R!4=7)B82!D;V5S;B=T('5S92!S:&%R
M97,L('-O('=E(&IU<W0@8W)E871E(&$@9'5M;7D@<VAA<F4@;&ES="`F"B`@
M("`@("`@+R\@9&5F875L="!S:&%R92!H97)E('1O(&UA:V4@<W5R92!T:&4@
M9F]L;&]W:6YG(&-O9&4@=V]R:W,N"B`@("`@("`@:68@*&5M<'1Y*"1S:&%R
M97,I("8F("1A<'`@/3T@)W1U<F)A)RD@>PH@("`@("`@("`@("`D<VAA<F5S
M(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)&%P<"D["@H@("`@("`@("`@
M("`D87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#;VYS=',H)&%P<"D["@H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<[
M"B`@("`@("`@("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N
M*"D["B`@("`@("`@("`@("1N86UE(#T@)&ED96YT:71Y+3YG971686QU92@G
M9G5L;&YA;64G*3L*("`@("`@("`@("`@:68@*'1R:6TH)&YA;64I(#T]("<G
M*2!["B`@("`@("`@("`@("`@("`D;F%M92`]($%U=&@Z.G)E;6]V94AO;VLH
M075T:#HZ9V5T075T:"@I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<VAA<F4@/2`F)'-H87)E<RT^;F5W4VAA<F4H075T:#HZ9V5T075T:"@I*3L*
M("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"!S<')I;G1F*"1A<'!?
M8V]N<W1S6R=D969A=6QT7W-H87)E7VYA;64G72P@)&YA;64I*3L*("`@("`@
M("`@("`@)'-H87)E<RT^861D4VAA<F4H)'-H87)E*3L*("`@("`@("!]"@H@
M("`@("`@("\O($-H96-K(&EF('=E)W9E(&%L<F5A9'D@<WEN8VAR;VYI<V5D
M('1H92!)34%0(&9O;&1E<B!L:7-T.R!I9B!W92!H879E"B`@("`@("`@+R\@
M=&AE;B!E>&ET(&5A<FQY+B!&;VQD97(@<WEN8VAR;VYI<V%T:6]N(&ES(&1O
M;F4@;VX@87!P;&EC871I;VX*("`@("`@("`O+R!S=&%R='5P("T@=&AI<R!I
M;F-L=61E<R!S=VET8VAI;F<@8F5T=V5E;B!A<'!L:6-A=&EO;G,@87,@=V5L
M;"!A<PH@("`@("`@("\O('5P;VX@:6YI=&EA;"!L;V=I;BX*("`@("`@("!I
M9B`H(65M<'1Y*"1?4T534TE/3EM+3TQ!0E],05-47U-93D-(141?05!072D@
M)B8*("`@("`@("`@("`@)%]315-324].6TM/3$%"7TQ!4U1?4UE.0TA%1%]!
M4%!=(#T]("1A<'`I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M"B`@("`@("`@9VQO8F%L("1N;W1I9FEC871I;VX["@H@("`@("`@("1R97-U
M;'0@/2!+;VQA8CHZ7W-Y;F-H4VAA<F5S*"1S:&%R97,I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(I+"`D<F5S=6QT+3YG
M971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3>6YC:')O;FES97,@=&AE($E-05`@9F]L9&5R
M(&QI<W0@86YD('1H92!(;W)D92!S:&%R92!L:7-T+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@82!S=6-C97-S9G5L('-Y;F-H<F]N
M:7-A=&EO;BP@9F%L<V4@=VAE;B!A"B`@("`@*B`@("`@("`@("`@("`@("!S
M>6YC:')O;FES871I;VX@:7,@;F]T(')E<75I<F5D("AI+F4N(&UU;'1I<&QE
M('!A9V4@;&]A9',*("`@("`J("`@("`@("`@("`@("`@(&EN(&$@<VEN9VQE
M(&%P<&QI8V%T:6]N*2P@;W(@82!014%27T5R<F]R(&]B:F5C="!O;@H@("`@
M("H@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-Y;F-H4VAA<F5S*"8D<VAA<F5S*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<F5G:7-T<GDL("1C;VYF.PH*("`@("`@("`D87!P(#T@)')E9VES=')Y
M+3YG971!<'`H*3L*"B`@("`@("`@+R\@3W1H97)W:7-E('=E(&YE960@=&\@
M;6%P('1H92!C=7)R96YT($E-05`@9F]L9&5R(&QI<W0@=&\@=&AE"B`@("`@
M("`@+R\@87!P;&EC871I;VYS('-H87)E(&QI<W0N"@H@("`@("`@("\O($UA
M:V4@<W5R92!T:&ES(&ES(&)E:6YG(&-A;&QE9"!F<F]M(&$@:VYO=VX@87!P
M;&EC871I;VX*("`@("`@("`D87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#
M;VYS=',H)&%P<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]C;VYS=',L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<'!?8V]N<W1S
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0V]N;F5C="!T;R!T:&4@24U!4"!S
M97)V97(*("`@("`@("`D:6UA<"`]("9N97<@3F5T7TE-05`H)&-O;F9;)VMO
M;&%B)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P
M)UU;)W!O<G0G72D["B`@("`@("`@:68@*&ES7V$H)&EM87`L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;6%P.PH@("`@("`@('T*
M"B`@("`@("`@+R\@3&]G:6X@=7-I;F<@=&AE(&-U<G)E;G0@2&]R9&4@8W)E
M9&5N=&EA;',*("`@("`@("`D8W5R<F5N=%]U<V5R(#T@075T:#HZ9V5T075T
M:"@I.PH@("`@("`@("1N9'@@/2!S=')P;W,H)&-U<G)E;G1?=7-E<BP@)T`G
M*3L*("`@("`@("`D=7-E<B`]("1N9'@@/3T](&9A;'-E(#\@)&-U<G)E;G1?
M=7-E<B`Z('-U8G-T<B@D8W5R<F5N=%]U<V5R+"`P+"`D;F1X*3L*("`@("`@
M("`D9&]M86EN(#T@<W1R<W1R*"1C=7)R96YT7W5S97(L("=`)RD["B`@("`@
M("`@)')E<W5L="`]("1I;6%P+3YL;V=I;B@D8W5R<F5N=%]U<V5R+"!!=71H
M.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I+"!F86QS92P@9F%L<V4I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O
M+R!/8G1A:6X@82!L:7-T(&]F(&%L;"!F;VQD97)S('1H92!C=7)R96YT('5S
M97(@:&%S(&%C8V5S<R!T;PH@("`@("`@("1F;VQD97)?;&ES="`]("1I;6%P
M+3YG971-86EL8F]X97,H*3L*("`@("`@("!I9B`H:7-?82@D9F]L9&5R7VQI
M<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F;VQD
M97)?;&ES=#L*("`@("`@("!]"@H@("`@("`@("\O(%=E)W)E(&]N;'D@:6YT
M97)E<W1E9"!I;B!T:&4@9F]L9&5R<R!O9B!T:&4@<W!E8VEF:6,@<F5S;W5R
M8V4@='EP90H@("`@("`@("\O(&9O<B!T:&4@8W5R<F5N="!A<'!L:6-A=&EO
M;BP@<V\@9FEL=&5R(&]U="!T:&4@<F5S=`H@("`@("`@("1L;V-A;%]F;VQD
M97)S(#T@87)R87DH*3L*("`@("`@("`D<F5M;W1E7V9O;&1E<G,@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1F;VQD97)?;&ES="!A<R`D9F]L9&5R
M*2!["B`@("`@("`@("`@("1A;FYO=&%T:6]N(#T@)&EM87`M/F=E=$%N;F]T
M871I;VXH2T],04)?04Y.3U1?1D],1$527U194$4L("=V86QU92YS:&%R960G
M+"`D9F]L9&5R*3L*("`@("`@("`@("`@:68@*&ES7V$H)&%N;F]T871I;VXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D86YN
M;W1A=&EO;CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@268@=&AE
M<F4@:7,@;F\@86YN;W1A=&EO;B!T:&5N('=E('1R96%T(&ET(&%S(&$@<W1A
M;F1A<F0@;6%I;`H@("`@("`@("`@("`O+R!F;VQD97(@*&DN92X@=V4@:6=N
M;W)E(&ET*2X*("`@("`@("`@("`@:68@*&5M<'1Y*"1A;FYO=&%T:6]N*2D@
M>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\O($EF('1H92!F;VQD97(@:7,@;V8@=&AE(&-O<G)E8W0@
M='EP92!T:&5N('=E(&%D9"!I="!T;R!O=7(@;&ES=`H@("`@("`@("`@("`O
M+R!O9B!F;VQD97)S('1H870@<VAO=6QD(&-O<G)E<W!O;F0@=&\@82!S:&%R
M92X@2&5R92!W92!G970@86YY"B`@("`@("`@("`@("\O(&]T:&5R(&%D9&ET
M:6]N86P@:6YF;W)M871I;VX@=V4@;6%Y(&YE960L('-U8V@@87,@=VAE=&AE
M<B!T:&4*("`@("`@("`@("`@+R\@9F]L9&5R('=A<R!P<F5V:6]U<VQY(&UA
M<'!E9"!T;R!A('-H87)E+"!I=',@04-,+"!I=',@;W=N97(@*&EF"B`@("`@
M("`@("`@("\O(&ET(&ES(&$@<VAA<F5D(&9O;&1E<BD@86YD(&ET<R!D:7-P
M;&%Y(&YA;64N"B`@("`@("`@("`@("1T>7!E(#T@97AP;&]D92@G+B<L("1A
M;FYO=&%T:6]N*3L*("`@("`@("`@("`@:68@*"1T>7!E6S!=(#T]("1A<'!?
M8V]N<W1S6R=M:6UE7W1Y<&5?<W5F9FEX)UTI('L*("`@("`@("`@("`@("`@
M("1A8VP@/2!+;VQA8CHZ86-L5&]!<G)A>2@D:6UA<"T^9V5T04-,*"1F;VQD
M97(I*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1A8VPL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&%C;#L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!3:VEP('1H92!#
M>7)U<R!!9&UI;FES=')A=&]R"B`@("`@("`@("`@("`@("!U;G-E="@D86-L
M6R1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)V%D;6EN=7-E<B==72D["@H@("`@
M("`@("`@("`@("`@)'-H87)E7W5I9"`]("1I;6%P+3YG971!;FYO=&%T:6]N
M*$M/3$%"7T%.3D]47U-(05)%7U5)1"P@)W9A;'5E+G-H87)E9"<L("1F;VQD
M97(I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)'-H87)E7W5I9"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<VAA
M<F5?=6ED.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@('!R
M96=?;6%T8V@H(CLH24Y"3UA\=7-E<B\H6UXO72LI*2\H6UY`72LI*$`N*BD_
M.R(L("1F;VQD97(L("1M871C:&5S*3L*"B`@("`@("`@("`@("`@("`D9&5F
M875L="`]("@A96UP='DH)'1Y<&5;,5TI("8F("1T>7!E6S%=(#T]("=D969A
M=6QT)RD["@H@("`@("`@("`@("`@("`@:68@*"1M871C:&5S6S%=(#T]("=)
M3D)/6"<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&1E9F%U;'0I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])
M9&5N=&ET>2YP:'`G.PH@("`@("`@("`@("`@("`@("`@("`@("`D:61E;G1I
M='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN86UE
M)RD["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AT<FEM*"1N86UE*2`]
M/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!!
M=71H.CIR96UO=F5(;V]K*"1C=7)R96YT7W5S97(I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M<W!R:6YT9B@D87!P7V-O;G-T<ULG9&5F875L=%]S:&%R95]N86UE)UTL("1N
M86UE*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&9O;&1E<B`]("1A<'!?
M8V]N<W1S6R=D969A=6QT7V9O;&1E<E]N86UE)UT["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@
M/2`D9F]L9&5R(#T@2V]L86(Z.F1E8V]D94EM87!&;VQD97).86UE*"1M871C
M:&5S6S-=*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@("1F;VQD97(@/2`B=7-E<B\D=7-E<B\D9F]L9&5R)&1O;6%I;B([
M"@H@("`@("`@("`@("`@("`@("`@("1L;V-A;%]F;VQD97)S6R1F;VQD97)=
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=S:&%R95]U:60G
M("`@("`]/B`D<VAA<F5?=6ED+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M86-L)R`@("`@("`@("`@/3X@)&%C;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@)VYA;64G("`@("`@("`@(#T^("1N86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G9&5F875L="<@("`@("`@/3X@)&1E9F%U;'0L"B`@("`@("`@
M("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'5S97)?9&]M86EN(#T@:7-S970H)&UA=&-H97-;
M-%TI(#\@)&UA=&-H97-;-%T@.B`D9&]M86EN.PH@("`@("`@("`@("`@("`@
M("`@("1F;VQD97(@/2!I<W-E="@D;6%T8VAE<ULT72D@/R`D9F]L9&5R(#H@
M)&9O;&1E<B`N("1U<V5R7V1O;6%I;CL*("`@("`@("`@("`@("`@("`@("`D
M;W=N97(@/2`D;6%T8VAE<ULR72`N("1U<V5R7V1O;6%I;CL*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&1E9F%U;'0I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I
M;F=L971O;B@G;F]N92<L("1O=VYE<BD["B`@("`@("`@("`@("`@("`@("`@
M("`@("1N86UE(#T@)&ED96YT:71Y+3YG971686QU92@G9G5L;&YA;64G*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*'1R:6TH)&YA;64I(#T]("<G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]($%U=&@Z
M.G)E;6]V94AO;VLH)&]W;F5R*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]('-P<FEN=&8H)&%P
M<%]C;VYS='-;)V1E9F%U;'1?<VAA<F5?;F%M92==+"`D;F%M92D["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2!+;VQA8CHZ9&5C;V1E26UA<$9O;&1E<DYA;64H)&UA=&-H
M97-;,UTI.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`@("`@)')E;6]T95]F;VQD97)S6R1F;VQD97)=(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=S:&%R95]U:60G("`@("`]/B`D<VAA<F5?
M=6ED+`H@("`@("`@("`@("`@("`@("`@("`@("`G86-L)R`@("`@("`@("`@
M/3X@)&%C;"P*("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@("`@
M("`@(#T^("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@("`@("`@/3X@)&1E9F%U;'0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=O=VYE<B<@("`@("`@("`]/B`D;W=N97(L"B`@("`@("`@("`@("`@("`@
M("`@*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+R\@5V4@;F]W(&UA<"!T:&4@<F5M86EN:6YG(&9O;&1E
M<B!L:7-T('1O('1H92!C=7)R96YT(&%P<&QI8V%T:6]N<PH@("`@("`@("\O
M('-H87)E(&QI<W0L('1O('-Y;F-H($AO<F1E('=I=&@@;W1H97(@2V]L86(@
M8VQI96YT<R!T:&%T(&UA>2!H879E"B`@("`@("`@+R\@<')E=FEO=7-L>2!M
M;V1I9FEE9"!T:&4@9W)O=7!W87)E(&9O;&1E<G,*"B`@("`@("`@)&EM87`M
M/F1I<V-O;FYE8W0H*3L*("`@("`@("`D:6UA<"`]("9N97<@3F5T7TE-05`H
M)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA
M8B==6R=I;6%P)UU;)W!O<G0G72D["B`@("`@("`@:68@*&ES7V$H)&EM87`L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;6%P.PH@
M("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YL;V=I;B@D8V]N
M9ELG:V]L86(G75LG:6UA<"==6R=A9&UI;G5S97(G72P@)&-O;F9;)VMO;&%B
M)UU;)VEM87`G75LG861M:6YP=R==+"!F86QS92P@9F%L<V4I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R!43T1/
M.B!S964@:68@=&AE<F4@:7,@82!M;W)E(&%C8W5R871E('=A>2!O9B!L:7-T
M:6YG(&%L;"!S:&%R97,@=&AA=`H@("`@("`@("\O(&%R92!A8V-E<W-I8FQE
M+"!R96=A<F1L97-S(&]F('=H870@<&5R;6ES<VEO;G,@=&AE('5S97(@:&%S
M("AI+F4N(&EF"B`@("`@("`@+R\@=&AE('5S97(@:&%S(&%T(&QE87-T(&]N
M92!P97)M:7-S:6]N(&QE=F5L('1O('1H92!S:&%R92P@=&AE('-H87)E"B`@
M("`@("`@+R\@<VAO=6QD(&)E(&EN(&]N92!O9B!T:&5S92!L:7-T<RDN"B`@
M("`@("`@)&QO8V%L7W-H87)E<R`]("1S:&%R97,M/FQI<W13:&%R97,H)&-U
M<G)E;G1?=7-E<BP@4$5235-?4TA/5RP@)&-U<G)E;G1?=7-E<BD["B`@("`@
M("`@)&%L;%]S:&%R97,@/2`D<VAA<F5S+3YL:7-T4VAA<F5S*"1C=7)R96YT
M7W5S97(L(%!%4DU37U-(3U<I.PH@("`@("`@("1R96UO=&5?<VAA<F5S(#T@
M87)R87E?9&EF9E]A<W-O8R@D86QL7W-H87)E<RP@)&QO8V%L7W-H87)E<RD[
M"B`@("`@("`@2V]L86(Z.G-E=%-H87)E36%P*&%R<F%Y*"DI.PH@("`@("`@
M("1S:&%R95]M87`@/2!A<G)A>2@I.PH*("`@("`@("`O+R!.;W<@<WEN8VAR
M;VYI<V4@=&AE(&9O;&1E<B!L:7-T('=I=&@@=&AE('-H87)E(&QI<W0*("`@
M("`@("!F;W)E86-H("@D;&]C86Q?9F]L9&5R<R!A<R`D9F]L9&5R(#T^("1A
M='1R<RD@>PH@("`@("`@("`@("!I9B`H96UP='DH)&%T=')S6R=S:&%R95]U
M:60G72DI('L*("`@("`@("`@("`@("`@("\O($YO('-H87)E(&-O<G)E<W!O
M;F1S('1O('1H:7,@9F]L9&5R+"!S;R!C<F5A=&4@;VYE"B`@("`@("`@("`@
M("`@("`D=6ED(#T@96UP='DH)&%T=')S6R=D969A=6QT)UTI(#\@;60U*&UI
M8W)O=&EM92@I*2`Z("1C=7)R96YT7W5S97(["B`@("`@("`@("`@("`@("`D
M<VAA<F4@/2`F)'-H87)E<RT^;F5W4VAA<F4H)'5I9"D["B`@("`@("`@("`@
M("`@("`D<VAA<F4M/G-E="@G;F%M92<L("1A='1R<ULG;F%M92==*3L*("`@
M("`@("`@("`@("`@("1S:&%R97,M/F%D9%-H87)E*"1S:&%R92D["@H@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1I;6%P+3YS971!;FYO=&%T:6]N*$M/
M3$%"7T%.3D]47U-(05)%7U5)1"P@87)R87DH)W9A;'5E+G-H87)E9"<@/3X@
M)'5I9"DL("1F;VQD97(I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@($MO;&%B.CIU<&1A=&5-87!P9613:&%R92@D<VAA<F5?;6%P+"`D=6ED
M+"`D9F]L9&5R*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("\O($]T:&5R=VES92!T:&5R92!I<R!A('-H87)E(&-O<G)E<W!O;F1I
M;F<@=&\@=&AI<R!F;VQD97(*("`@("`@("`@("`@("`@(&EF("@A)'-H87)E
M<RT^97AI<W1S*"1A='1R<ULG<VAA<F5?=6ED)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@268@:70G<R!N;W0@<')E<V5N="!F;W(@=VAA=&5V97(@
M<F5A<V]N+"!C<F5A=&4@:70*("`@("`@("`@("`@("`@("`@("`D<VAA<F4@
M/2`F)'-H87)E<RT^;F5W4VAA<F4H)&%T=')S6R=S:&%R95]U:60G72D["B`@
M("`@("`@("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"`D871T<G-;
M)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@)'-H87)E<RT^861D4VAA
M<F4H)'-H87)E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@+R\@3W1H97)W:7-E(&-H96-K('1H870@:70@:7,@;F%M
M960@8V]R<F5C=&QY"B`@("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1L
M;V-A;%]S:&%R97-;)&%T=')S6R=S:&%R95]U:60G75T["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1S:&%R92T^9V5T*"=N86UE)RD@(3T@)&%T=')S6R=N
M86UE)UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-H87)E+3YS970H
M)VYA;64G+"`D871T<G-;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@($MO;&%B.CIU
M<&1A=&5-87!P9613:&%R92@D<VAA<F5?;6%P+"`D871T<G-;)W-H87)E7W5I
M9"==+"`D9F]L9&5R*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-U
M<G)E;G1?=7-E<G,@/2`D<VAA<F4M/FQI<W15<V5R<R@I.PH*("`@("`@("`@
M("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@("`@("`@
M("`@("1M=7-T7W-A=F4@/2!F86QS93L*"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1A='1R<ULG86-L)UT@87,@)'5S97(@/3X@)&%C;"D@>PH@("`@("`@("`@
M("`@("`@)'!E<FUS(#T@2V]L86(Z.F%C;%1O4&5R;7,H)&%C;"D["B`@("`@
M("`@("`@("`@("!I9B`H)'!E<FUS("$]("1'3$]"04Q36R=P97)M<R==+3YG
M971097)M:7-S:6]N<R@D<&5R;2P@)'5S97(I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R+"`D<&5R;7,L
M(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`D;75S=%]S879E(#T@=')U
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1N9'@@/2!A
M<G)A>5]S96%R8V@H)'5S97(L("1C=7)R96YT7W5S97)S*3L*("`@("`@("`@
M("`@("`@(&EF("@D;F1X("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1C=7)R96YT7W5S97)S6R1N9'A=*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)&-U
M<G)E;G1?=7-E<G,@87,@)'5S97(I('L*("`@("`@("`@("`@("`@(&EF("@D
M1TQ/0D%,4ULG<&5R;7,G72T^9V5T4&5R;6ES<VEO;G,H)'!E<FTL("1U<V5R
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D<&5R;2T^<F5M
M;W9E57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%4DU37T%,3"P@9F%L<V4I.PH@
M("`@("`@("`@("`@("`@("`@("1M=7-T7W-A=F4@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&UU
M<W1?<V%V92D@>PH@("`@("`@("`@("`@("`@)'-H87)E+3YS971097)M:7-S
M:6]N*"1P97)M+"!F86QS92D["B`@("`@("`@("`@("`@("`D<VAA<F4M/G-A
M=F4H*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M871T<G-;)W-H87)E7W5I9"==*2D@>PH@("`@("`@("`@("`@("`@=6YS970H
M)&QO8V%L7W-H87)E<ULD871T<G-;)W-H87)E7W5I9"==72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@=6YS970H)&QO8V%L7W-H87)E<ULD
M8W5R<F5N=%]U<V5R72D["@H@("`@("`@("\O(%5P9&%T92!S:&%R97,@=&AA
M="!A<F4@;F]T(&]W;F5D(&)Y('1H92!C=7)R96YT('5S97(@*&]N;'D@:68@
M=&AE<F4*("`@("`@("`O+R!A<F4@<VAA<F5D(&9O;&1E<G,@86-C97-S:6)L
M92!T;R!T:&4@8W5R<F5N="!U<V5R*0H@("`@("`@(&EF("@A96UP='DH)')E
M;6]T95]F;VQD97)S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D<F5M;W1E
M7V9O;&1E<G,@87,@)&9O;&1E<B`]/B`D871T<G,I('L*("`@("`@("`@("`@
M("`@(&EF("AE;7!T>2@D871T<G-;)W-H87)E7W5I9"==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1U:60@/2!E;7!T>2@D871T<G-;)V1E9F%U;'0G72D@
M/R!M9#4H;6EC<F]T:6UE*"DI(#H@)&%T=')S6R=O=VYE<B==.PH@("`@("`@
M("`@("`@("`@("`@("1S:&%R92`]("8D<VAA<F5S+3YN97=3:&%R92@D=6ED
M*3L*("`@("`@("`@("`@("`@("`@("`D<VAA<F4M/G-E="@G;W=N97(G+"`D
M871T<G-;)V]W;F5R)UTI.PH@("`@("`@("`@("`@("`@("`@("1S:&%R92T^
M<V5T*"=N86UE)RP@)&%T=')S6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@
M("`@("1S:&%R97,M/F%D9%-H87)E*"1S:&%R92D["@H@("`@("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D:6UA<"T^<V5T06YN;W1A=&EO;BA+3TQ!0E]!
M3DY/5%]32$%215]5240L(&%R<F%Y*"=V86QU92YS:&%R960G(#T^("1U:60I
M+"`D9F]L9&5R*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`@("`@2V]L86(Z.G5P9&%T94UA<'!E9%-H87)E*"1S:&%R
M95]M87`L("1U:60L("1F;VQD97(I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H(21S:&%R97,M/F5X:7-T<R@D
M871T<G-;)W-H87)E7W5I9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<VAA<F4@/2`F)'-H87)E<RT^;F5W4VAA<F4H)&%T=')S6R=S:&%R95]U
M:60G72D["B`@("`@("`@("`@("`@("`@("`@("`@("1S:&%R92T^<V5T*"=O
M=VYE<B<L("1A='1R<ULG;W=N97(G72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1S:&%R92T^<V5T*"=N86UE)RP@)&%T=')S6R=N86UE)UTI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<VAA<F5S+3YA9&13:&%R92@D<VAA<F4I
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%1H92!S:&%R92!E>&ES=',@9VQO8F%L;'DL(&)U="!M
M87D@;F]T('EE="!B92!L:7-T960*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1R96UO=&5?<VAA<F5S6R1A='1R<ULG<VAA<F5?=6ED)UU=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1S
M:&%R97,M/F=E=%-H87)E*"1A='1R<ULG<VAA<F5?=6ED)UTI.PH@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-H87)E(#T@)B1R96UO=&5?<VAA<F5S6R1A='1R<ULG<VAA
M<F5?=6ED)UU=.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D<VAA<F4M/F=E="@G;F%M92<I("$]("1A
M='1R<ULG;F%M92==*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<VAA<F4M/G-E="@G;F%M92<L("1A='1R<ULG;F%M92==*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`@("`@2V]L86(Z.G5P9&%T94UA<'!E9%-H87)E*"1S:&%R
M95]M87`L("1A='1R<ULG<VAA<F5?=6ED)UTL("1F;VQD97(I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1C=7)R96YT7W5S97)S(#T@
M)'-H87)E+3YL:7-T57-E<G,H*3L*"B`@("`@("`@("`@("`@("`D<&5R;2`]
M("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("`@("`@("`@("1M
M=7-T7W-A=F4@/2!F86QS93L*"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M871T<G-;)V%C;"==(&%S("1U<V5R(#T^("1A8VPI('L*("`@("`@("`@("`@
M("`@("`@("`D<&5R;7,@/2!+;VQA8CHZ86-L5&]097)M<R@D86-L*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'!E<FUS("$]("1'3$]"04Q36R=P97)M
M<R==+3YG971097)M:7-S:6]N<R@D<&5R;2P@)'5S97(I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E
M<BP@)'!E<FUS+"!F86QS92D["B`@("`@("`@("`@("`@("`@("`@("`@("1M
M=7-T7W-A=F4@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D;F1X(#T@87)R87E?<V5A<F-H*"1U<V5R+"`D8W5R
M<F5N=%]U<V5R<RD["B`@("`@("`@("`@("`@("`@("`@:68@*"1N9'@@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1C=7)R
M96YT7W5S97)S6R1N9'A=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&-U<G)E
M;G1?=7-E<G,@87,@)'5S97(I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)$=,3T)!3%-;)W!E<FUS)UTM/F=E=%!E<FUI<W-I;VYS*"1P97)M+"`D=7-E
M<BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P97)M
M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?04Q,+"!F86QS
M92D["B`@("`@("`@("`@("`@("`@("`@("`@("1M=7-T7W-A=F4@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("!I9B`H)&UU<W1?<V%V92D@>PH@("`@("`@("`@("`@
M("`@("`@("1S:&%R92T^<V5T4&5R;6ES<VEO;B@D<&5R;2P@9F%L<V4I.PH@
M("`@("`@("`@("`@("`@("`@("1S:&%R92T^<V%V92@I.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&%T=')S6R=S
M:&%R95]U:60G72DI('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D<F5M
M;W1E7W-H87)E<ULD871T<G-;)W-H87)E7W5I9"==72D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($9I
M;F%L;'DL(')E;6]V92!A;GD@97AT<F$@<VAA<F5S('=E(&UA>2!H879E("AT
M:&5S92!W97)E(&]N8V4@9F]L9&5R<PH@("`@("`@("\O('1H870@=V5R92!S
M=6)S97%U96YT;'D@9&5L971E9"!B>2!A;F]T:&5R($MO;&%B(&-L:65N="DN
M(%1H:7,@:7,@;VYL>0H@("`@("`@("\O(&1O;F4@9F]R('-H87)E<R!T:&%T
M('1H92!C=7)R96YT('5S97(@;W=N<RP@:2YE+B!S:&%R97,@=&AA="!W97)E
M"B`@("`@("`@+R\@<W5B9F]L9&5R<R!O9B!T:&4@8W5R<F5N="!U<V5R<R<@
M24Y"3U@N"B`@("`@("`@9F]R96%C:"`H)&QO8V%L7W-H87)E<R!A<R`D<VAA
M<F4I('L*("`@("`@("`@("`@)')E<W5L="`]("1S:&%R97,M/G)E;6]V95-H
M87)E*"1S:&%R92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!&;W(@<F5M
M;W1E('-H87)E<RP@=V4@<VEM<&QY(')E;6]V92!T:&4@8W5R<F5N="!U<V5R
M(&9R;VT@=&AE('-H87)E<PH@("`@("`@("\O('!E<FUI<W-I;VYS(&QI<W0N
M"B`@("`@("`@9F]R96%C:"`H)')E;6]T95]S:&%R97,@87,@)'5I9"`]/B`D
M<VAA<F4I('L*("`@("`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M
M:7-S:6]N*"D["B`@("`@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES
M<VEO;B@D8W5R<F5N=%]U<V5R+"!015)-4U]!3$PL(&9A;'-E*3L*("`@("`@
M("`@("`@)'-H87)E+3YS971097)M:7-S:6]N*"1P97)M+"!F86QS92D["B`@
M("`@("`@("`@("1S:&%R92T^<V%V92@I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@06YD('=E)W)E(&1O;F4A($1I<V-O;FYE8W0@9G)O;2!)34%0+"!S970@
M=&AE(&QA<W0@<WEN8V@G960@87!P"B`@("`@("`@+R\@9FQA9R!T;R!T:&4@
M8W5R<F5N="!A<'!L:6-A=&EO;BP@86YD('5P9&%T92!T:&4@<VAA<F4@;6%P
M+@H@("`@("`@("1I;6%P+3YD:7-C;VYN96-T*"D["@H@("`@("`@("1?4T53
M4TE/3EM+3TQ!0E],05-47U-93D-(141?05!072`]("1A<'`["B`@("`@("`@
M2V]L86(Z.G-E=%-H87)E36%P*"1S:&%R95]M87`I.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&=R
M;W5P=V%R92!T>7!E(&]F('1H92!G:79E;B!)34%0(&9O;&1E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@;V)J96-T("1M86EL8F]X("!4:&4@;6%I;&)O>"!O
M9B!I;G1E<F5S="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!('-T
M<FEN9R!I;F1I8V%T:6YG('1H92!G<F]U<'=A<F4@='EP92!O9B`D;6%I;&)O
M>"!O<@H@("`@("H@("`@("`@("`@("`@("`@8F]O;&5A;B`B9F%L<V4B(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-86EL8F]X5'EP92@D
M;6%I;&)O>"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M("1T>7!E(#T@9F%L<V4["@H@("`@("`@("\O($-O;FYE8W0@=&\@=&AE($E-
M05`@<V5R=F5R"B`@("`@("`@)&EM87`@/2`F;F5W($YE=%])34%0*"1C;VYF
M6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G75LG
M:6UA<"==6R=P;W)T)UTI.PH@("`@("`@(&EF("AI<U]A*"1I;6%P+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=5
M;F%B;&4@=&\@8V]N;F5C="!T;R!T:&4@2V]L86(@24U!4"!S97)V97(G+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M(')E='5R;B`D='EP93L*("`@("`@("!]"@H@("`@("`@("\O($QO9VEN('5S
M:6YG('1H92!C=7)R96YT($AO<F1E(&-R961E;G1I86QS"B`@("`@("`@)')E
M<W5L="`]("1I;6%P+3YL;V=I;BA!=71H.CIG971!=71H*"DL($%U=&@Z.F=E
M=$-R961E;G1I86PH)W!A<W-W;W)D)RDL(&9A;'-E+"!F86QS92D["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@G56YA8FQE('1O(&%U=&AE;G1I8V%T
M92!W:71H('1H92!+;VQA8B!)34%0('-E<G9E<B<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@)&EM87`M/F1I<V-O
M;FYE8W0H*3L*("`@("`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@("`@('T*
M"B`@("`@("`@+R\@3V)T86EN('1H92!G<F]U<'=A<F4@86YN;W1A=&EO;B!O
M9B`D;6%I;&)O>`H@("`@("`@("1A;FYO=&%T:6]N(#T@)&EM87`M/F=E=$%N
M;F]T871I;VXH2T],04)?04Y.3U1?1D],1$527U194$4L("=V86QU92YS:&%R
M960G+"`D;6%I;&)O>"D["B`@("`@("`@:68@*"%I<U]A*"1A;FYO=&%T:6]N
M+"`G4$5!4E]%<G)O<B<I("8F("%E;7!T>2@D86YN;W1A=&EO;BDI('L*("`@
M("`@("`@("`@)'1Y<&4@/2!E>'!L;V1E*"<N)RP@)&%N;F]T871I;VXI.PH@
M("`@("`@("`@("!I9B`H*"%E;7!T>2@D='EP95LQ72D@)B8@)'1Y<&5;,5T@
M/3T@)V1E9F%U;'0G*2!\?"`H96UP='DH)'1Y<&5;,5TI*2D@>PH@("`@("`@
M("`@("`@("`@)'1Y<&4@/2`D='EP95LP73L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*"B`@("`@("`@
M<F5T=7)N("1T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@
M;&ES="!O9B!A;&P@24U!4"!F;VQD97)S("AI;F-L=61I;F<@=&AE:7(@9W)O
M=7!W87)E('1Y<&4I('1H870*("`@("`J('1H92!C=7)R96YT('5S97(@:&%S
M(&%C8V-E<W,@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@;V8@87)R87DH)&9O;&1E<FYA;64L("1F;VQD97)T>7!E*2!I=&5M
M<R`H96UP='D*("`@("`J("`@("`@("`@("`@("`@(&]N(&5R<F]R*2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<G,H*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&9O;&1E<G,@/2!A<G)A>2@I.PH*
M("`@("`@("`O+R!#;VYN96-T('1O('1H92!)34%0('-E<G9E<@H@("`@("`@
M("1I;6%P(#T@)FYE=R!.971?24U!4"@D8V]N9ELG:V]L86(G75LG:6UA<"==
M6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<&]R="==*3L*
M("`@("`@("!I9B`H:7-?82@D:6UA<"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G56YA8FQE('1O(&-O;FYE8W0@
M=&\@=&AE($MO;&%B($E-05`@<V5R=F5R)RP@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)&9O;&1E<G,[
M"B`@("`@("`@?0H*("`@("`@("`O+R!,;V=I;B!U<VEN9R!T:&4@8W5R<F5N
M="!(;W)D92!C<F5D96YT:6%L<PH@("`@("`@("1R97-U;'0@/2`D:6UA<"T^
M;&]G:6XH075T:#HZ9V5T075T:"@I+"!!=71H.CIG971#<F5D96YT:6%L*"=P
M87-S=V]R9"<I+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U5N86)L92!T;R!A=71H96YT:6-A=&4@=VET:"!T:&4@2V]L
M86(@24U!4"!S97)V97(G+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@("1I;6%P+3YD:7-C;VYN96-T*"D["B`@("`@
M("`@("`@(')E='5R;B`D9F]L9&5R<SL*("`@("`@("!]"@H@("`@("`@("\O
M($]B=&%I;B!A(&QI<W0@;V8@86QL(&9O;&1E<G,@=&AE(&-U<G)E;G0@=7-E
M<B!H87,@86-C97-S('1O"B`@("`@("`@)&9O;&1E<E]L:7-T(#T@)&EM87`M
M/F=E=$UA:6QB;WAE<R@I.PH@("`@("`@(&EF("AI<U]A*"1F;VQD97)?;&ES
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G56YA8FQE('1O(&]B=&%I;B!)34%0(&9O;&1E<B!L:7-T)RP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`D
M:6UA<"T^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("!R971U<FX@)&9O;&1E
M<G,["B`@("`@("`@?0H*("`@("`@("`O+R!)=&5R871E(&]V97(@86QL('1H
M92!F;VQD97)S(&]B=&%I;FEN9R!T:&5I<B!G<F]U<'=A<F4@='EP97,*("`@
M("`@("!F;W)E86-H("@D9F]L9&5R7VQI<W0@87,@)&9O;&1E<BD@>PH@("`@
M("`@("`@("`D9F]L9&5R='EP92`]("=M86EL)SL*"B`@("`@("`@("`@("1A
M;FYO=&%T:6]N(#T@)&EM87`M/F=E=$%N;F]T871I;VXH2T],04)?04Y.3U1?
M1D],1$527U194$4L("=V86QU92YS:&%R960G+"`D9F]L9&5R*3L*("`@("`@
M("`@("`@:68@*"%I<U]A*"1A;FYO=&%T:6]N+"`G4$5!4E]%<G)O<B<I("8F
M("%E;7!T>2@D86YN;W1A=&EO;BDI('L*("`@("`@("`@("`@("`@("1T>7!E
M(#T@97AP;&]D92@G+B<L("1A;FYO=&%T:6]N*3L*("`@("`@("`@("`@("`@
M(&EF("@H(65M<'1Y*"1T>7!E6S%=*2`F)B`D='EP95LQ72`]/2`G9&5F875L
M="<I('Q\("AE;7!T>2@D='EP95LQ72DI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&9O;&1E<G1Y<&4@/2`D='EP95LP73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9O;&1E<G-;72`](&%R<F%Y
M*"1F;VQD97(L("1F;VQD97)T>7!E*3L*("`@("`@("!]"@H@("`@("`@("1I
M;6%P+3YD:7-C;VYN96-T*"D["@H@("`@("`@(')E='5R;B`D9F]L9&5R<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%1R:6=G97)S('1H92!F<F5E8G5S>2!U
M<&1A=&4@9F]R('1H92!G:79E;B!S:&%R92!U:60N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N(%1R=64@:68@=7!D871E('=A<R!S=6-C97-S9G5L
M;"P@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<FEG
M9V5R1G)E94)U<WE5<&1A=&4H)'-H87)E7W5I9"D*("`@('L*("`@("`@("`D
M<VAA<F5?;6%P(#T@2V]L86(Z.F=E=%-H87)E36%P*"D["B`@("`@("`@:68@
M*&5M<'1Y*"1S:&%R95]M87!;)'-H87)E7W5I9%TI*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1F;VQD97)?<&%T
M:"`]("1S:&%R95]M87!;)'-H87)E7W5I9%T["@H@("`@("`@("\O($E-05`@
M<&%T:"!I<R!E:71H97(@+TE.0D]8+SQP871H/D!D;VUA:6X@;W(@+W5S97(O
M<V]M96]N92\\<&%T:#Y`9&]M86EN"B`@("`@("`@+R\@<W1R:7`@9&]M86EN
M"B`@("`@("`@)&5N9"`]('-T<G)P;W,H)&9O;&1E<E]P871H+"`G0"<I.PH@
M("`@("`@("1F;VQD97(@/2!S=6)S='(H)&9O;&1E<E]P871H+"`P+"`D96YD
M*3L*"B`@("`@("`@:68@*"$D9F]L9&5R6S!=(#T]("<O)RD@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1S96-O;F1?
M<VQA<V@@/2!S=')P;W,H)&9O;&1E<BP@)R\G+"`Q*3L*("`@("`@("!I9B`H
M)'-E8V]N9%]S;&%S:"`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T<FYC;7`H)&9O;&1E
M<BP@)R])3D)/6"\G+"`W*2`]/2`P*2!["B`@("`@("`@("`@("1F;VQD97(@
M/2!!=71H.CIG971!=71H*"DN<W5B<W1R*"1F;VQD97(L("1S96-O;F1?<VQA
M<V@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F;VQD97(@/2!S
M=6)S='(H)&9O;&1E<BP@)'-E8V]N9%]S;&%S:"`K(#$I.PH@("`@("`@('T*
M("`@("`@("`D=7)L(#T@)VAT='!S.B\O)R`N("1'3$]"04Q36R=C;VYF)UU;
M)VMO;&%B)UU;)VEM87`G75LG<V5R=F5R)UT@+B`G+V9R965B=7-Y+W1R:6=G
M97(O)R`N("1F;VQD97(@+B`G+G!F8B<["@H@("`@("`@("\O(&YO=R!S=&%R
M="!T:&4@<F5Q=65S=`H@("`@("`@(')E<75I<F5?;VYC92`G2%144"]297%U
M97-T+G!H<"<["B`@("`@("`@)&AT='`@/2!N97<@2%144%]297%U97-T*"1U
M<FPL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=M
M971H;V0G(#T^("='150G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=&EM96]U="<@/3X@-2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V%L;&]W4F5D:7)E8W1S)R`]/B!T<G5E
M*2D["B`@("`@("`@)&AT='`M/G-E=$)A<VEC075T:"A!=71H.CIG971!=71H
M*"DL($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RDI.PH*("`@("`@
M("!`)&AT='`M/G-E;F1297%U97-T*"D["B`@("`@("`@:68@*"1H='1P+3YG
M971297-P;VYS94-O9&4H*2`A/2`R,#`I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@=')I9V=E
M<B!F<F5E+V)U<WD@=7!D871E(&9O<B`E<R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D96UA:6PI*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3$1!4"YP:'``````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,3,S`#$P
M-#$W,S8R-S<S`#`Q-S0V-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AI<R!I<R!A('5T:6QI='D@
M8VQA<W,L(&5V97)Y(&UE=&AO9"!I<R!S=&%T:6,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TQ$05`O3$1!4"YP:'`L=B`Q+C4N,3(N,3`@,C`P-B\P,2\P
M,2`R,3HR.#HR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO
M<F1E7TQ$05`*("HO"F-L87-S($AO<F1E7TQ$05`@>PH*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@8F]O;&5A;B!E>'!R97-S:6]N('5S:6YG('1H92!S<&5C
M:69I960@;W!E<F%T;W(N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&QH<R`@5&AE(&%T=')I8G5T92!T;R!T
M97-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W`@("!4:&4@;W!E<F%T;W(N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1R:',@(%1H92!C;VUP87)I<V]N('9A
M;'5E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@3$1!4"!S
M96%R8V@@9G)A9VUE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD0VQA
M=7-E*"1L:',L("1O<"P@)')H<RD*("`@('L*("`@("`@("!S=VET8V@@*"1O
M<"D@>PH@("`@("`@(&-A<V4@)TQ)2T4G.@H@("`@("`@("`@("!R971U<FX@
M96UP='DH)')H<RD@/PH@("`@("`@("`@("`@("`@<W!R:6YT9B@G*"5S/2HI
M)RP@)&QH<RD@.@H@("`@("`@("`@("`@("`@<W!R:6YT9B@G*"5S/2HE<RHI
M)RP@)&QH<RP@2&]R9&5?3$1!4#HZ<75O=&4H)')H<RDI.PH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@G*"5S)7,E<RDG
M+"`D;&AS+"`D;W`L($AO<F1E7TQ$05`Z.G%U;W1E*"1R:',I*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%<V-A<&4@8VAA<F%C=&5R<R!W
M:71H('-P96-I86P@;65A;FEN9R!I;B!,1$%0('-E87)C:&5S+@H@("`@("H*
M("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M;&%U<V4@(%1H92!S=')I;F<@=&\@97-C87!E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@97-C87!E9"!S=')I;F<N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('%U;W1E*"1C;&%U<V4I"B`@("!["B`@("`@("`@<F5T=7)N
M('-T<E]R97!L86-E*&%R<F%Y*"=<7"<L("`@)R@G+"`@)RDG+"`@)RHG+"`@
M(EPP(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=<7#5C
M)RP@)UPH)RP@)UPI)RP@)UPJ)RP@(EQ<,#`B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-L875S92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M86ME(&%N(&%R<F%Y(&]F($1.(&5L96UE;G1S(&%N9"!P<F]P97)L>2!Q=6]T
M92!I="!A8V-O<F1I;F<@=&\@4D9#"B`@("`@*B`Q-#@U+@H@("`@("H*("`@
M("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<G1S
M("!!;B!A<G)A>2!O9B!T=7!L97,@8V]N=&%I;FEN9R!T:&4@871T<FEB=71E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!N86UE(&%N9"!T:&%T(&%T
M=')I8G5T92=S('9A;'5E('=H:6-H(&UA:V4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@('5P('1H92!$3BX@17AA;7!L93H*("`@("`J"B`@("`@*B`@
M("`D<&%R=',@/2!A<G)A>2@P(#T^(&%R<F%Y*"=C;B<L("=*;VAN(%-M:71H
M)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`Q(#T^(&%R<F%Y*"=D8R<L
M("=E>&%M<&QE)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`R(#T^(&%R
M<F%Y*"=D8R<L("=C;VTG*2D["B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!P<F]P97)L>2!Q=6]T960@<W1R:6YG($1.+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!Q=6]T941.*"1P87)T<RD*("`@('L*("`@("`@("`D9&X@
M/2`G)SL*("`@("`@("`D8V]U;G0@/2!C;W5N="@D<&%R=',I.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@
M("!I9B`H)&D@/B`P*2!["B`@("`@("`@("`@("`@("`D9&X@+CT@)RPG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1D;B`N/2`D<&%R='-;)&E=6S!=
M("X@)STG.PH*("`@("`@("`@("`@+R\@4V5E(&EF('=E(&YE960@=&\@<75O
M=&4@=&AE('9A;'5E+@H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<
M<WQ<<R1\7'-<<WQ;+"L](EQR7&X\/B,[72\G+"`D<&%R='-;)&E=6S%=*2D@
M>PH@("`@("`@("`@("`@("`@)&1N("X]("<B)R`N('-T<E]R97!L86-E*"<B
M)RP@)UQ<(B<L("1P87)T<ULD:5U;,5TI("X@)R(G.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&1N("X]("1P87)T<ULD:5U;,5T[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&X[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+G!H<```````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C<Q-C8`,3`T,3<S-C(W-S,`,#$W-3$R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*B!792!N965D('1O("AU;F9O<G1U;F%T96QY*2!H87)D(&-O9&4@
M=&AE<V4@8V]N<W1A;G1S(&)E8V%U<V4@=&AE>2!R97-I9&4@:6X*("H@=&AE
M(&EM87`@;6]D=6QE+"!W:&EC:"!I<R!N;W0@<F5Q=6ER960@9F]R($AO<F1E
M+@H@*B!4:&5S92!C;VYS=&%N=',@87)E(&9O=6YD(&EN('1H92!55RUI;6%P
M(&,M8VQI96YT(&1I<W1R:6)U=&EO;CH*("H@("!F='`Z+R]F='`N8V%C+G=A
M<VAI;F=T;VXN961U+VEM87`O"B`J(%1H92!C;VYS=&%N=',@87!P96%R(&EN
M('1H92!F:6QE(&EN8VQU9&4O;6%I;"YH("HO"G)E<75I<F5?;VYC92`G2&]R
M9&4O571I;"YP:'`G.PII9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G:6UA
M<"<I*2!["B`@("`O*B!0<FEM87)Y(&)O9'D@='EP97,@*B\*("`@(&1E9FEN
M92@G5%E0151%6%0G+"`P*3L*("`@(&1E9FEN92@G5%E014U53%1)4$%25"<L
M(#$I.PH@("`@9&5F:6YE*"=465!%34534T%'12<L(#(I.PH@("`@9&5F:6YE
M*"=465!%05!03$E#051)3TXG+"`S*3L*("`@(&1E9FEN92@G5%E014%51$E/
M)RP@-"D["B`@("!D969I;F4H)U194$5)34%'12<L(#4I.PH@("`@9&5F:6YE
M*"=465!%5DE$14\G+"`V*3L*("`@(&1E9FEN92@G5%E014]42$52)RP@."D[
M"@H@("`@+RH@0F]D>2!E;F-O9&EN9W,@*B\*("`@(&1E9FEN92@G14Y#-T))
M5"<L(#`I.PH@("`@9&5F:6YE*"=%3D,X0DE4)RP@,2D["B`@("!D969I;F4H
M)T5.0T))3D%262<L(#(I.PH@("`@9&5F:6YE*"=%3D-"05-%-C0G+"`S*3L*
M("`@(&1E9FEN92@G14Y#455/5$5$4%))3E1!0DQ%)RP@-"D["B`@("!D969I
M;F4H)T5.0T]42$52)RP@-2D["GT*"B\J*@H@*B!/;&1E<B!V97)S:6]N<R!O
M9B!02%`G<R!I;6%P(&5X=&5N<VEO;B!D;VXG="!D969I;F4@5%E014U/1$5,
M+@H@*B\*:68@*"%D969I;F5D*"=465!%34]$14PG*2D@>PH@("`@9&5F:6YE
M*"=465!%34]$14PG+"`W*3L*?0H*+RHJ"B`J(%)E='5R;B!A(&-O9&4@9F]R
M('1Y<&4H*2]E;F-O9&EN9R@I+@H@*B\*9&5F:6YE*"=-24U%7T-/1$4G+"`Q
M*3L*"B\J*@H@*B!2971U<FX@82!S=')I;F<@9F]R('1Y<&4H*2]E;F-O9&EN
M9R@I+@H@*B\*9&5F:6YE*"=-24U%7U-44DE.1R<L(#(I.PH*"B\J*@H@*B!4
M:&4@34E-13HZ(&-L87-S('!R;W9I9&5S(&UE=&AO9',@9F]R(&1E86QI;F<@
M=VET:"!-24U%('-T86YD87)D<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M34E-12]-24U%+G!H<"QV(#$N,3,Y+C0N,C`@,C`P-B\P,R\R-"`P-#HR.3HU
M,B!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%
M"B`J+PIC;&%S<R!-24U%('L*"B`@("`O*BH*("`@("`J($$@;&ES=&EN9R!O
M9B!T:&4@86QL;W=E9"!-24U%('1Y<&5S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1M:6UE7W1Y<&5S(#T@87)R87DH"B`@
M("`@("`@5%E0151%6%0@/3X@)W1E>'0G+`H@("`@("`@(%194$5-54Q425!!
M4E0@/3X@)VUU;'1I<&%R="<L"B`@("`@("`@5%E014U%4U-!1T4@/3X@)VUE
M<W-A9V4G+`H@("`@("`@(%194$5!4%!,24-!5$E/3B`]/B`G87!P;&EC871I
M;VXG+`H@("`@("`@(%194$5!541)3R`]/B`G875D:6\G+`H@("`@("`@(%19
M4$5)34%'12`]/B`G:6UA9V4G+`H@("`@("`@(%194$56241%3R`]/B`G=FED
M96\G+`H@("`@("`@(%194$5-3T1%3"`]/B`G;6]D96PG+`H@("`@("`@(%19
M4$5/5$A%4B`]/B`G;W1H97(G"B`@("`I.PH*("`@("\J*@H@("`@("H@02!L
M:7-T:6YG(&]F('1H92!A;&QO=V5D($U)344@96YC;V1I;F=S+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1M:6UE7V5N8V]D
M:6YG<R`](&%R<F%Y*`H@("`@("`@($5.0S="250@/3X@)S=B:70G+`H@("`@
M("`@($5.0SA"250@/3X@)SAB:70G+`H@("`@("`@($5.0T))3D%262`]/B`G
M8FEN87)Y)RP*("`@("`@("!%3D-"05-%-C0@/3X@)V)A<V4V-"<L"B`@("`@
M("`@14Y#455/5$5$4%))3E1!0DQ%(#T^("=Q=6]T960M<')I;G1A8FQE)RP*
M("`@("`@("!%3D-/5$A%4B`]/B`G=6YK;F]W;B<*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!&:6QT97(@9F]R(%)&0S@R,BX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)')F8S@R,E]F:6QT97(@/2`B*"D\
M/D`L.SI<7%PB6UU<,5PR7#-<-%PU7#9<-UPQ,%PQ,5PQ,EPQ,UPQ-%PQ-5PQ
M-EPQ-UPR,%PR,5PR,EPR,UPR-%PR-5PR-EPR-UPS,%PS,5PS,EPS,UPS-%PS
M-5PS-EPS-UPQ-S<B.PH*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!A
M('-T<FEN9R!C;VYT86EN<R`X+6)I="!C:&%R86-T97)S+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@5&AE('-T<FEN9R!T;R!C:&5C
M:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@:70@
M9&]E<RP@9F%L<V4@:68@:70@9&]E<VXG="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7,X8FET*"1S=')I;F<I"B`@("!["B`@("`@("`@<F5T=7)N("AI<U]S
M=')I;F<H)'-T<FEN9RD@)B8@<')E9U]M871C:"@G+UM<>#@P+5QX9F9=+R<L
M("1S=')I;F<I*3L*("`@('T*"B`@("`O*BH*("`@("`J($5N8V]D97,@82!S
M=')I;F<@8V]N=&%I;FEN9R!N;VXM05-#24D@8VAA<F%C=&5R<R!A8V-O<F1I
M;F<@=&\@4D9#(#(P-#<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@("`@5&AE('1E>'0@=&\@96YC;V1E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S970@;V8@=&AE('1E>'0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT+"!E;F-O
M9&5D(&]N;'D@:68@:70@8V]N=&%I;G,@;F]N+4%30TE)"B`@("`@*B`@("`@
M("`@("`@("`@("`@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M96YC;V1E*"1T97AT+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@
M+RH@4F5T=7)N(&EF(&YO=&AI;F<@;F5E9',@=&\@8F4@96YC;V1E9"X@*B\*
M("`@("`@("!I9B`H(4U)344Z.FES.&)I="@D=&5X="DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T97AT.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7VYU
M;&PH)&-H87)S970I*2!["B`@("`@("`@("`@("1C:&%R<V5T(#T@3DQ3.CIG
M971#:&%R<V5T*"D["B`@("`@("`@?0H*("`@("`@("`D8VAA<G-E="`](%-T
M<FEN9SHZ;&]W97(H)&-H87)S970I.PH@("`@("`@("1L:6YE(#T@)R<["@H@
M("`@("`@("\J($=E="!T:&4@;&ES="!O9B!E;&5M96YT<R!I;B!T:&4@<W1R
M:6YG+B`J+PH@("`@("`@("1S:7IE(#T@<')E9U]M871C:%]A;&PH)R\H6UY<
M<UTK*2A;7'-=*BDO)RP@)'1E>'0L("1M871C:&5S+"!04D5'7U-%5%]/4D1%
M4BD["@H@("`@("`@(&9O<F5A8V@@*"1M871C:&5S(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("!I9B`H34E-13HZ:7,X8FET*"1V86Q;,5TI*2![
M"B`@("`@("`@("`@("`@("!I9B`H*"@D:V5Y("L@,2D@/"`D<VEZ92D@)B8*
M("`@("`@("`@("`@("`@("`@("!-24U%.CII<SAB:70H)&UA=&-H97-;)&ME
M>2`K(#%=6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@("1L:6YE("X]($U)
M344Z.E]E;F-O9&4H)'9A;%LQ72`N("1V86Q;,ETL("1C:&%R<V5T*2`N("<@
M)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&QI;F4@+CT@34E-13HZ7V5N8V]D92@D=F%L6S%=+"`D8VAA<G-E="D@
M+B`D=F%L6S)=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&QI;F4@+CT@)'9A;%LQ72`N("1V86Q;
M,ET["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!R
M=')I;2@D;&EN92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G1E<FYA;"!R
M96-U<G-I=F4@9G5N8W1I;VX@=&\@4D9#(#(P-#<@96YC;V1E(&$@<W1R:6YG
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@("`@(%1H92!T97AT('1O(&5N8V]D92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@
M<V5T(&]F('1H92!T97AT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=&5X="P@96YC;V1E9"!O;FQY(&EF(&ET(&-O;G1A:6YS(&YO;BU!
M4T-)20H@("`@("H@("`@("`@("`@("`@("`@(&-H87)A8W1E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]E;F-O9&4H)'1E>'0L("1C:&%R<V5T*0H@("`@
M>PH@("`@("`@("1C:&%R7VQE;B`]('-T<FQE;B@D8VAA<G-E="D["B`@("`@
M("`@)'1X=%]L96X@/2!S=')L96XH)'1E>'0I("H@,CL*"B`@("`@("`@+RH@
M4D9#(#(P-#<@6S)=('-T871E<R!T:&%T(&YO(&5N8V]D960@=V]R9"!C86X@
M8F4@;6]R92!T:&%N(#<U"B`@("`@("`@("`@8VAA<F%C=&5R<R!L;VYG+B!)
M9B!L;VYG97(L('EO=2!M=7-T('-P;&ET('1H92!W;W)D+B`J+PH@("`@("`@
M(&EF("@H)'1X=%]L96X@*R`D8VAA<E]L96X@*R`W*2`^(#<U*2!["B`@("`@
M("`@("`@("1P;W,@/2!I;G1V86PH*#8X("T@)&-H87)?;&5N*2`O(#(I.PH@
M("`@("`@("`@("!R971U<FX@34E-13HZ7V5N8V]D92AS=6)S='(H)'1E>'0L
M(#`L("1P;W,I+"`D8VAA<G-E="D@+B`G("<@+B!-24U%.CI?96YC;V1E*'-U
M8G-T<B@D=&5X="P@)'!O<RDL("1C:&%R<V5T*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)ST_)R`N("1C:&%R<V5T("X@)S]B/R<@
M+B!T<FEM*&)A<V4V-%]E;F-O9&4H)'1E>'0I*2`N("<_/2<["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@16YC;V1E<R!A(&QI;F4@=FEA('%U
M;W1E9"UP<FEN=&%B;&4@96YC;V1I;F<N"B`@("`@*B!7<F%P<R!L:6YE<R!A
M="`W-B!C:&%R86-T97)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@(%1H92!T97AT('1O(&5N8V]D92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&5O;"`@(%1H92!%3TP@<V5Q=65N8V4@=&\@=7-E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<75O=&5D+7!R:6YT86)L92!E;F-O
M9&5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&5D4')I;G1A
M8FQE16YC;V1E*"1T97AT+"`D96]L*0H@("`@>PH@("`@("`@("1O=71P=70@
M/2`G)SL*"B`@("`@("`@9F]R96%C:"`H<')E9U]S<&QI="@B+UQR/UQN+R(L
M("1T97AT*2!A<R`D;&EN92D@>PH@("`@("`@("`@("`O*B!792!N965D('1O
M(&=O(&-H87)A8W1E<B!B>2!C:&%R86-T97(@=&AR;W5G:"!T:&4@;&EN92X@
M*B\*("`@("`@("`@("`@)&QE;F=T:"`]('-T<FQE;B@D;&EN92D["B`@("`@
M("`@("`@("1C=7)R96YT7VQI;F4@/2`G)SL*("`@("`@("`@("`@)&-U<G)E
M;G1?;&5N9W1H(#T@,#L*"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1L96YG=&@[("1I*RLI('L*("`@("`@("`@("`@("`@("1C:&%R(#T@<W5B
M<W1R*"1L:6YE+"`D:2P@,2D["B`@("`@("`@("`@("`@("`D87-C:6D@/2!O
M<F0H)&-H87(I.PH*("`@("`@("`@("`@("`@("\J(%-P86-E<R!O<B!T86)S
M(&%T('1H92!E;F0@;V8@=&AE(&QI;F4@87)E($Y/5"!A;&QO=V5D+@H@("`@
M("`@("`@("`@("`@("H@06QS;RP@0VAA<F%C=&5R<R!I;B!!4T-)22!B96QO
M=R`S,B!O<B!A8F]V92`Q,C8@04Y$(#8Q"B`@("`@("`@("`@("`@("`@*B!M
M=7-T(&)E(&5N8V]D960N("HO"B`@("`@("`@("`@("`@("!I9B`H*"@H)&%S
M8VEI(#T]/2`Y*2!\?"`H)&%S8VEI(#T]/2`S,BDI("8F("@D:2`]/2`H)&QE
M;F=T:"`M(#$I*2D@?'P*("`@("`@("`@("`@("`@("`@("`H*"1A<V-I:2`\
M(#,R*2!\?"`H)&%S8VEI(#X@,3(V*2!\?"`H)&%S8VEI(#T]/2`V,2DI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&-H87(@/2`G/2<@+B!3=')I;F<Z.G5P
M<&5R*'-P<FEN=&8H)R4P,G,G+"!D96-H97@H)&%S8VEI*2DI.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J($QI;F5S(&UU<W0@8F4@
M-S8@8VAA<F%C=&5R<R!O<B!L97-S+B`J+PH@("`@("`@("`@("`@("`@)&-H
M87)?;&5N9W1H(#T@<W1R;&5N*"1C:&%R*3L*("`@("`@("`@("`@("`@("1C
M=7)R96YT7VQE;F=T:"`K/2`D8VAA<E]L96YG=&@["B`@("`@("`@("`@("`@
M("!I9B`H)&-U<G)E;G1?;&5N9W1H(#X@-S8I('L*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1C=7)R96YT7VQI;F4@+B`G/2<@+B`D96]L.PH@
M("`@("`@("`@("`@("`@("`@("1C=7)R96YT7VQI;F4@/2`G)SL*("`@("`@
M("`@("`@("`@("`@("`D8W5R<F5N=%]L96YG=&@@/2`D8VAA<E]L96YG=&@[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8W5R<F5N=%]L
M:6YE("X]("1C:&%R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1O=71P
M=70@+CT@)&-U<G)E;G1?;&EN92`N("1E;VP["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J($5N8V]D
M97,@82!S=')I;F<@8V]N=&%I;FEN9R!E;6%I;"!A9&1R97-S97,@86-C;W)D
M:6YG('1O(%)&0R`R,#0W+@H@("`@("H*("`@("`J(%1H:7,@9&EF9F5R<R!F
M<F]M($U)344Z.F5N8V]D92@I(&)E8V%U<V4@:70@:V5E<',@96UA:6P@861D
M<F5S<V5S(&QE9V%L+`H@("`@("H@;VYL>2!E;F-O9&EN9R!T:&4@<&5R<V]N
M86P@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M861D<F5S<V5S("!4:&4@96UA:6P@861D<F5S<V5S('1O(&5N8V]D92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&-H87)S970@("`@5&AE(&-H87)A8W1E<B!S
M970@;V8@=&AE('1E>'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D969S97)V
M97(@(%1H92!D969A=6QT(&1O;6%I;B!T;R!A<'!E;F0@=&\@;6%I;&)O>&5S
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5X="P@96YC
M;V1E9"!O;FQY(&EF(&ET(&-O;G1A:6YS(&YO;BUA<V-I:0H@("`@("H@("`@
M("`@("`@("`@("`@(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5N8V]D94%D9')E<W,H)&%D9')E<W-E<RP@)&-H87)S970@/2!N=6QL+"`D
M9&5F<V5R=F5R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)&%D9')E<W-E<RDI('L*("`@("`@("`@("`@)&%D9')?87)R(#T@)&%D9')E
M<W-E<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!P87)S94%D
M9')E<W-,:7-T*"D@9&]E<R!N;W0@<')O8V5S<R!T:&4@;G5L;"!E;G1R>0H@
M("`@("`@("`@("`@*B`G=6YD:7-C;&]S960M<F5C:7!I96YT<SH[)R!C;W)R
M96-T;'DN("HO"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O=6YD:7-C
M;&]S960M<F5C:7!I96YT<SI<<RH[+VDG+"!T<FEM*"1A9&1R97-S97,I*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1A9&1R97-S97,["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"]21D,X,C(N
M<&AP)SL*("`@("`@("`@("`@)'!A<G-E<B`]("9N97<@36%I;%]21D,X,C(H
M*3L*("`@("`@("`@("`@)&%D9')?87)R(#T@)'!A<G-E<BT^<&%R<V5!9&1R
M97-S3&ES="@D861D<F5S<V5S+"`D9&5F<V5R=F5R+"!T<G5E+"!F86QS92D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1A9&1R7V%R<BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1A9&1R7V%R<CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1E>'0@/2`G)SL*("`@("`@
M("!I9B`H:7-?87)R87DH)&%D9')?87)R*2D@>PH@("`@("`@("`@("!F;W)E
M86-H("@D861D<E]A<G(@87,@)&%D9'(I('L*("`@("`@("`@("`@("`@("\O
M($-H96-K(&9O<B!G<F]U<',N"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1A9&1R+3YG<F]U<&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)'1E
M>'0@+CT@34E-13HZ96YC;V1E*"1A9&1R+3YG<F]U<&YA;64L("1C:&%R<V5T
M*2`N("<Z("<@+B!-24U%.CIE;F-O9&5!9&1R97-S*"1A9&1R+3YA9&1R97-S
M97,I("X@)SLG.PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D861D
M<BT^<&5R<V]N86PI*2!["B`@("`@("`@("`@("`@("`@("`@)'!E<G-O;F%L
M(#T@)R<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@H<W5B<W1R*"1A9&1R+3YP97)S;VYA;"P@,"P@,2D@/3T@
M)R(G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`H<W5B<W1R*"1A9&1R
M+3YP97)S;VYA;"P@+3$I(#T]("<B)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%D9'(M/G!E<G-O;F%L(#T@<W5B<W1R*"1A9&1R+3YP97)S;VYA
M;"P@,2P@+3$I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D<&5R<V]N86P@/2!-24U%.CIE;F-O9&4H)&%D9'(M/G!E<G-O
M;F%L+"`D8VAA<G-E="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H<W1R;&5N*"1T97AT*2`A/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1E>'0@+CT@)RP@)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1T97AT("X]($U)344Z.G1R:6U%;6%I;$%D9')E<W,H34E-
M13HZ<F9C.#(R5W)I=&5!9&1R97-S*"1A9&1R+3YM86EL8F]X+"`D861D<BT^
M:&]S="P@)'!E<G-O;F%L*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M8V]D97,@86X@4D9#(#(P-#<M96YC;V1E9"!S=')I;F<N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG("`@("`@5&AE('1E>'0@=&\@9&5C
M;V1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&]?8VAA<G-E="`@5&AE(&-H
M87)S970@=&AA="!T:&4@=&5X="!S:&]U;&0@8F4@9&5C;V1E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!D96-O9&5D('1E>'0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1E8V]D92@D<W1R:6YG+"`D=&]?8VAA<G-E="`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1S=')I;F<L("<]
M/R<I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("1S=')I;F<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!486ME(&]U="!A;GD@<W!A8V5S(&)E
M='=E96X@;75L=&EP;&4@96YC;V1E9"!W;W)D<RX@*B\*("`@("`@("`D<W1R
M:6YG(#T@<')E9U]R97!L86-E*"=\7#\]7',]7#]\)RP@)S\]/3\G+"`D<W1R
M:6YG*3L*"B`@("`@("`@+RH@4V%V92!A;GD@<')E8V5D:6YG('1E>'0N("HO
M"B`@("`@("`@)'!R96-E9&EN9R`]('-U8G-T<B@D<W1R:6YG+"`P+"`D<&]S
M*3L*"B`@("`@("`@)'-E87)C:"`]('-U8G-T<B@D<W1R:6YG+"`D<&]S("L@
M,BD["B`@("`@("`@)&0Q(#T@<W1R<&]S*"1S96%R8V@L("<_)RD["B`@("`@
M("`@:68@*"1D,2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("1S
M=')I;F<["B`@("`@("`@?0H*("`@("`@("`D8VAA<G-E="`]('-U8G-T<B@D
M<W1R:6YG+"`D<&]S("L@,BP@)&0Q*3L*("`@("`@("`D<V5A<F-H(#T@<W5B
M<W1R*"1S96%R8V@L("1D,2`K(#$I.PH*("`@("`@("`D9#(@/2!S=')P;W,H
M)'-E87)C:"P@)S\G*3L*("`@("`@("!I9B`H)&0R(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@)'-T<FEN9SL*("`@("`@("!]"@H@("`@("`@
M("1E;F-O9&EN9R`]('-U8G-T<B@D<V5A<F-H+"`P+"`D9#(I.PH@("`@("`@
M("1S96%R8V@@/2!S=6)S='(H)'-E87)C:"P@)&0R("L@,2D["@H@("`@("`@
M("1E;F0@/2!S=')P;W,H)'-E87)C:"P@)S\])RD["B`@("`@("`@:68@*"1E
M;F0@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1E;F0@/2!S=')L96XH)'-E
M87)C:"D["B`@("`@("`@?0H*("`@("`@("`D96YC;V1E9%]T97AT(#T@<W5B
M<W1R*"1S96%R8V@L(#`L("1E;F0I.PH@("`@("`@("1R97-T(#T@<W5B<W1R
M*"1S=')I;F<L("AS=')L96XH)'!R96-E9&EN9R`N("1C:&%R<V5T("X@)&5N
M8V]D:6YG("X@)&5N8V]D961?=&5X="D@*R`V*2D["@H@("`@("`@(&EF("@A
M:7-S970H)'1O7V-H87)S970I*2!["B`@("`@("`@("`@("1T;U]C:&%R<V5T
M(#T@3DQ3.CIG971#:&%R<V5T*"D["B`@("`@("`@?0H*("`@("`@("!S=VET
M8V@@*"1E;F-O9&EN9RD@>PH@("`@("`@(&-A<V4@)U$G.@H@("`@("`@(&-A
M<V4@)W$G.@H@("`@("`@("`@("`D96YC;V1E9%]T97AT(#T@<W1R7W)E<&QA
M8V4H)U\G+"`G("<L("1E;F-O9&5D7W1E>'0I.PH@("`@("`@("`@("`D9&5C
M;V1E9"`]('!R96=?<F5P;&%C92@G+STH6S`M.6$M9EU[,GTI+VEE)RP@)V-H
M<B@P>%PQ*2<L("1E;F-O9&5D7W1E>'0I.PH@("`@("`@("`@("`D9&5C;V1E
M9"`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&1E8V]D960L("1C:&%R<V5T
M+"`D=&]?8VAA<G-E="D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=")SH*("`@("`@("!C87-E("=B)SH*("`@("`@("`@("`@)&1E8V]D
M960@/2!B87-E-C1?9&5C;V1E*"1E;F-O9&5D7W1E>'0I.PH@("`@("`@("`@
M("`D9&5C;V1E9"`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&1E8V]D960L
M("1C:&%R<V5T+"`D=&]?8VAA<G-E="D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D9&5C;V1E9"`]("<]/R<@
M+B`D8VAA<G-E="`N("<_)R`N("1E;F-O9&EN9R`N("<_)R`N("1E;F-O9&5D
M7W1E>'0@+B`G/STG.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<')E8V5D:6YG("X@)&1E8V]D960@+B!-24U%.CID
M96-O9&4H)')E<W0L("1T;U]C:&%R<V5T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($1E8V]D97,@86X@4D9#(#(R,S$M96YC;V1E9"!S=')I;F<N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG("`@5&AE(&5N=&ER92!S
M=')I;F<@=&\@9&5C;V1E+"!I;F-L=61I;F<@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!P87)A;65T97(@;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T('1H870@=&AE('1E>'0@
M<VAO=6QD(&)E(&1E8V]D960@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE(&1E8V]D960@=&5X="P@;W(@=&AE(&]R:6=I;F%L('-T<FEN
M9R!I9B!I="!W87,@;F]T"B`@("`@*B`@("`@("`@("`@("`@("!E;F-O9&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&521D,R,C,Q*"1S=')I;F<L
M("1T;U]C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H*"1P;W,@
M/2!S=')P;W,H)'-T<FEN9RP@)RHG*2D@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S
M970H)'1O7V-H87)S970I*2!["B`@("`@("`@("`@("1T;U]C:&%R<V5T(#T@
M3DQ3.CIG971#:&%R<V5T*"D["B`@("`@("`@?0H*("`@("`@("`D871T<FEB
M=71E(#T@<W5B<W1R*"1S=')I;F<L(#`L("1P;W,I.PH@("`@("`@("1C:&%R
M<V5T(#T@)&QA;F<@/2!N=6QL.PH@("`@("`@("1O=71P=70@/2`G)SL*"B`@
M("`@("`@+RH@1V5T('1H92!C:&%R86-T97(@<V5T(&%N9"!L86YG=6%G92!U
M<V5D(&EN('1H92!E;F-O9&EN9RP@:68*("`@("`@("`@*B!A;GDN("HO"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H(B]>6UX]72M<*EP]*%M>)UTJ*2<H6UXG
M72HI)R\B+"`D<W1R:6YG+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)&-H
M87)S970@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@)&QA;F<@/2`D;6%T
M8VAE<ULR73L*("`@("`@("`@("`@)'-T<FEN9R`]('-T<E]R97!L86-E*"1C
M:&%R<V5T("X@(B<B("X@)&QA;F<@+B`B)R(L("<G+"`D<W1R:6YG*3L*("`@
M("`@("!]"@H@("`@("`@("1L:6YE<R`]('!R96=?<W!L:70H)R\G("X@<')E
M9U]Q=6]T92@D871T<FEB=71E*2`N("<H/SI<*EQD*2HO)RP@)'-T<FEN9RD[
M"B`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@
M("`@("1P;W,@/2!S=')P;W,H)&QI;F4L("<J/2<I.PH@("`@("`@("`@("!I
M9B`H)'!O<R`]/3T@,"D@>PH@("`@("`@("`@("`@("`@)&QI;F4@/2!S=6)S
M='(H)&QI;F4L(#(I.PH@("`@("`@("`@("`@("`@)&QI;F4@/2!S=')?<F5P
M;&%C92@G7R<L("<E,C`G+"`D;&EN92D["B`@("`@("`@("`@("`@("`D;&EN
M92`]('-T<E]R97!L86-E*"<])RP@)R4G+"`D;&EN92D["B`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]('5R;&1E8V]D92@D;&EN92D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D;&EN92`]('-U8G-T<B@D;&EN
M92P@,2D["B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1L:6YE.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!21D,@,C(S,2!U<V5S
M('%U;W1E9"!P<FEN=&%B;&4@96YC;V1I;F<N("HO"B`@("`@("`@:68@*"%I
M<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D;W5T<'5T(#T@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="@D;W5T<'5T+"`D8VAA<G-E="P@)'1O7V-H
M87)S970I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@
M("`@("`@("`G871T<FEB=71E)R`]/B`D871T<FEB=71E+`H@("`@("`@("`@
M("`G=F%L=64G(#T^("1O=71P=70*("`@("`@("`I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@268@86X@96UA:6P@861D<F5S<R!H87,@;F\@<&5R<V]N86P@
M:6YF;W)M871I;VXL(&=E="!R:60@;V8@86YY(&%N9VQE"B`@("`@*B!B<F%C
M:V5T<R`H/#XI(&%R;W5N9"!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A9&1R97-S("!4:&4@861D<F5S<R!T;R!T<FEM+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@=')I;6UE9"!A9&1R97-S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!T<FEM16UA:6Q!9&1R97-S*"1A9&1R97-S*0H@
M("`@>PH@("`@("`@("1A9&1R97-S(#T@=')I;2@D861D<F5S<RD["@H@("`@
M("`@(&EF("@H<W5B<W1R*"1A9&1R97-S+"`P+"`Q*2`]/2`G/"<I("8F("AS
M=6)S='(H)&%D9')E<W,L("TQ*2`]/2`G/B<I*2!["B`@("`@("`@("`@("1A
M9&1R97-S(#T@<W5B<W1R*"1A9&1R97-S+"`Q+"`M,2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&%D9')E<W,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!"=6EL9',@86X@4D9#(#@R,B!C;VUP;&EA;G0@96UA:6P@861D<F5S<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("`@36%I;&)O
M>"!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&]S="`@("`@($1O;6%I
M;B!N86UE(&]F(&UA:6QB;W@G<R!H;W-T+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&5R<V]N86P@(%!E<G-O;F%L(&YA;64@<&AR87-E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]R<F5C=&QY(&5S8V%P960@86YD
M('%U;W1E9`H@("`@("H@("`@("`@("`@("`@("`@("(D<&5R<V]N86P@/"1M
M86EL8F]X0"1H;W-T/B(@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M9F,X,C)7<FET94%D9')E<W,H)&UA:6QB;W@L("1H;W-T(#T@;G5L;"P@)'!E
M<G-O;F%L(#T@)R<I"B`@("!["B`@("`@("`@)&%D9')E<W,@/2`G)SL*"B`@
M("`@("`@:68@*"%E;7!T>2@D<&5R<V]N86PI*2!["B`@("`@("`@("`@("1V
M87)S(#T@9V5T7V-L87-S7W9A<G,H)TU)344G*3L*("`@("`@("`@("`@)&%D
M9')E<W,@+CT@34E-13HZ7W)F8S@R,D5N8V]D92@D<&5R<V]N86PL("1V87)S
M6R=R9F,X,C)?9FEL=&5R)UT@+B`G+B<I.PH@("`@("`@("`@("`D861D<F5S
M<R`N/2`G(#PG.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1H
M;W-T*2D@>PH@("`@("`@("`@("`D861D<F5S<R`N/2!-24U%.CI?<F9C.#(R
M16YC;V1E*"1M86EL8F]X*3L*("`@("`@("`@("`@:68@*'-U8G-T<B@D:&]S
M="P@,"P@,2D@(3T@)T`G*2!["B`@("`@("`@("`@("`@("`D861D<F5S<R`N
M/2`G0"<@+B`D:&]S=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*"%E;7!T>2@D<&5R<V]N86PI*2!["B`@("`@("`@("`@("1A9&1R
M97-S("X]("<^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D861D<F5S
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($5X<&QO9&5S(&$@4D9#(#@R,B!S
M=')I;F<L(&EG;F]R:6YG(&$@9&5L:6UI=&5R(&EF('!R96-E9&5D(&)Y(&$@
M(EPB"B`@("`@*B!C:&%R86-T97(L(&]R(&EF(&1E;&EM:71E<B!I<R!I;G-I
M9&4@<VEN9VQE(&]R(&1O=6)L92!Q=6]T97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<W1R("`@("`@("!4:&4@4D9#(#@R,B!S=')I;F<N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D96QI;6ET97(@(%1H92!D96QI;71E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@97AP;&]D960@<W1R
M:6YG(&EN(&%N(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!R9F,X,C)%
M>'!L;V1E*"1S='(L("1D96QI;6ET97(I"B`@("!["B`@("`@("`@)&%R<B`]
M(&%R<F%Y*"D["B`@("`@("`@)&UA=&-H(#T@,#L*("`@("`@("`D<75O=&5S
M(#T@87)R87DH)R(G+"`B)R(I.PH@("`@("`@("1I;E]Q=6]T92`](&YU;&P[
M"B`@("`@("`@)&EN7V=R;W5P(#T@9F%L<V4["B`@("`@("`@)'!R978@/2!N
M=6QL.PH*("`@("`@("!I9B`H96UP='DH)'-T<BDI('L*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"1S='(I.PH@("`@("`@('T*"B`@("`@("`@:68@*&EN
M7V%R<F%Y*"1S=')[,'TL("1Q=6]T97,I*2!["B`@("`@("`@("`@("1I;E]Q
M=6]T92`]("1S=')[,'T["B`@("`@("`@?2!E;'-E:68@*"1S=')[,'T@/3T@
M)SHG*2!["B`@("`@("`@("`@("1I;E]G<F]U<"`]('1R=64["B`@("`@("`@
M?2!E;'-E:68@*"1S=')[,'T@/3T@)&1E;&EM:71E<BD@>PH@("`@("`@("`@
M("`D87)R6UT@/2`G)SL*("`@("`@("`@("`@)&UA=&-H(#T@,3L*("`@("`@
M("!]"@H@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\('-T<FQE;B@D<W1R*3L@
M)&DK*RD@>PH@("`@("`@("`@("`D8VAA<B`]("1S=')[)&E].PH@("`@("`@
M("`@("!I9B`H:6Y?87)R87DH)&-H87(L("1Q=6]T97,I*2!["B`@("`@("`@
M("`@("`@("!I9B`H)'!R978@(3T]("=<7"<I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&EN7W%U;W1E(#T]/2`D8VAA<BD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:6Y?<75O=&4@/2!N=6QL.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("AI<U]N=6QL*"1I;E]Q=6]T92DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN7W%U;W1E(#T@)&-H87(["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V5I9B`H)&EN7V=R;W5P*2!["B`@("`@("`@("`@("`@("!I9B`H)&-H87(@
M/3T@)SLG*2!["B`@("`@("`@("`@("`@("`@("`@)&%R<EM=(#T@<W5B<W1R
M*"1S='(L("1M871C:"P@)&D@+2`D;6%T8V@@*R`Q*3L*("`@("`@("`@("`@
M("`@("`@("`D;6%T8V@@/2`D:2`K(#$["B`@("`@("`@("`@("`@("`@("`@
M)&EN7V=R;W5P(#T@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS96EF("@D8VAA<B`]/2`G.B<I('L*("`@("`@("`@("`@("`@
M("1I;E]G<F]U<"`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("@D8VAA
M<B`]/2`D9&5L:6UI=&5R("8F"B`@("`@("`@("`@("`@("`@("`@("`D<')E
M=B`A/3T@)UQ<)R`F)@H@("`@("`@("`@("`@("`@("`@("`@:7-?;G5L;"@D
M:6Y?<75O=&4I*2!["B`@("`@("`@("`@("`@("`D87)R6UT@/2!S=6)S='(H
M)'-T<BP@)&UA=&-H+"`D:2`M("1M871C:"D["B`@("`@("`@("`@("`@("`D
M;6%T8V@@/2`D:2`K(#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!R
M978@/2`D8VAA<CL*("`@("`@("!]"@H@("`@("`@(&EF("@D;6%T8V@@(3T@
M)&DI('L*("`@("`@("`@("`@+RH@5&AE('-T<FEN9R!E;F1E9"!W:71H;W5T
M(&$@)&1E;&EM:71E<BX@*B\*("`@("`@("`@("`@)&%R<EM=(#T@<W5B<W1R
M*"1S='(L("1M871C:"P@)&D@+2`D;6%T8V@I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1A<G(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME<R!A
M;B!A9&1R97-S(&]B:F5C="P@87,@<F5T=7)N960@8GD@:6UA<%]H96%D97(H
M*2!F;W(@97AA;7!L92P@86YD"B`@("`@*B!F;W)M871S(&ET(&%S(&$@<W1R
M:6YG+@H@("`@("H*("`@("`J($]B:F5C="!F;W)M870@9F]R('1H92!A9&1R
M97-S(")*;VAN($1O92`\:F]H;E]D;V5`97AA;7!L92YC;VT^(B!I<SH*("`@
M("`J(#QP<F4^"B`@("`@*B`@("1O8FIE8W0M/G!E<G-O;F%L(#T@4&5R<V]N
M86P@;F%M92`H(DIO:&X@1&]E(BD*("`@("`J("`@)&]B:F5C="T^;6%I;&)O
M>"`@/2!4:&4@=7-E<B=S(&UA:6QB;W@@*")J;VAN7V1O92(I"B`@("`@*B`@
M("1O8FIE8W0M/FAO<W0@("`@(#T@5&AE(&AO<W0@=&AE(&UA:6QB;W@@:7,@
M;VX@*")E>&%M<&QE+F-O;2(I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1D0VQA<W,@)&]B("`@5&AE(&%D9')E<W,@;V)J96-T('1O
M(&)E('1U<FYE9"!I;G1O(&$@<W1R:6YG+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1F:6QT97(@($$@=7-E<D!E>&%M<&QE+F-O;2!S='EL92!B87)E(&%D9')E
M<W,@=&\@:6=N;W)E+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($5I
M=&AE<B!S:6YG;&4@<W1R:6YG(&]R(&%N(&%R<F%Y(&]F('-T<FEN9W,N("!)
M9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!A9&1R97-S(&UA
M=&-H97,@)&9I;'1E<BP@86X@96UP='D@<W1R:6YG('=I;&P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!B92!R971U<FYE9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9O<FUA='1E9"!A9&1R97-S("A%>&%M
M<&QE.B!*;VAN($1O90H@("`@("H@("`@("`@("`@("`@("`@(#QJ;VAN7V1O
M94!E>&%M<&QE+F-O;3XI+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1R3V)J
M96-T,E-T<FEN9R@D;V(L("1F:6QT97(@/2`G)RD*("`@('L*("`@("`@("`O
M*B!)9B!T:&4@<&5R<V]N86P@;F%M92!I<R!S970L(&1E8V]D92!I="X@*B\*
M("`@("`@("`D;V(M/G!E<G-O;F%L(#T@:7-S970H)&]B+3YP97)S;VYA;"D@
M/R!-24U%.CID96-O9&4H)&]B+3YP97)S;VYA;"D@.B`G)SL*"B`@("`@("`@
M+RH@268@8F]T:"!T:&4@;6%I;&)O>"!A;F0@=&AE(&AO<W0@87)E(&5M<'1Y
M+"!R971U<FX@86X@96UP='D*("`@("`@("`@("!S=')I;F<N("!)9B!W92!J
M=7-T(&QE="!T:&ES(&-A<V4@9F%L;"!T:')O=6=H+"!T:&4@8V%L;"!T;PH@
M("`@("`@("`@($U)344Z.G)F8S@R,E=R:71E061D<F5S<R@I('=I;&P@96YD
M('5P(')E='5R;B!J=7-T(&$@)T`G+"!W:&EC:`H@("`@("`@("`@(&ES('5N
M9&5S:7)A8FQE+B`J+PH@("`@("`@(&EF("AE;7!T>2@D;V(M/FUA:6QB;W@I
M("8F(&5M<'1Y*"1O8BT^:&]S="DI('L*("`@("`@("`@("`@<F5T=7)N("<G
M.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('1H97-E('1W;R!V
M87)I86)L97,@:&%V92!S;VUE('-O<G0@;V8@=F%L=64N("HO"B`@("`@("`@
M:68@*"%I<W-E="@D;V(M/FUA:6QB;W@I*2!["B`@("`@("`@("`@("1O8BT^
M;6%I;&)O>"`]("<G.PH@("`@("`@('T@96QS96EF("@D;V(M/FUA:6QB;W@@
M/3T@)W5N9&ES8VQO<V5D+7)E8VEP:65N=',G*2!["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D;V(M/FAO
M<W0I*2!["B`@("`@("`@("`@("1O8BT^:&]S="`]("<G.PH@("`@("`@('T*
M"B`@("`@("`@+RH@1FEL=&5R(&]U="!U;G=A;G1E9"!A9&1R97-S97,@8F%S
M960@;VX@=&AE("1F:6QT97(@<W1R:6YG+B`J+PH@("`@("`@(&EF("@D9FEL
M=&5R*2!["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&9I;'1E<BDI('L*
M("`@("`@("`@("`@("`@("1F:6QT97(@/2!A<G)A>2@D9FEL=&5R*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D9FEL=&5R(&%S("1F
M*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D9BP@)&]B+3YM
M86EL8F]X("X@)T`G("X@)&]B+3YH;W-T*2`]/2`P*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@=&AE('1R:6UM
M960L(&9O<FUA='1E9"!E;6%I;"!A9&1R97-S+B`J+PH@("`@("`@(')E='5R
M;B!-24U%.CIT<FEM16UA:6Q!9&1R97-S*$U)344Z.G)F8S@R,E=R:71E061D
M<F5S<R@D;V(M/FUA:6QB;W@L("1O8BT^:&]S="P@)&]B+3YP97)S;VYA;"DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5&%K97,@86X@87)R87D@;V8@861D
M<F5S<R!O8FIE8W1S+"!A<R!R971U<FYE9"!B>2!I;6%P7VAE861E<FEN9F\H
M*2P*("`@("`J(&9O<B!E>&%M<&QE+"!A;F0@<&%S<V5S(&5A8V@@;V8@=&AE
M;2!T:')O=6=H($U)344Z.F%D9')/8FIE8W0R4W1R:6YG*"DN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1A9&1R97-S97,@(%1H92!A<G)A>2!O9B!A
M9&1R97-S(&]B:F5C=',N"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@
M("`@02!U<V5R0&5X86UP;&4N8V]M('-T>6QE(&)A<F4@861D<F5S<R!T;PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&EG;F]R92X@($EF(&%N
M>2!A9&1R97-S(&UA=&-H97,@)&9I;'1E<BP@:70*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!W:6QL(&YO="!B92!I;F-L=61E9"!I;B!T:&4@
M9FEN86P@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!
M;&P@;V8@=&AE(&%D9')E<W-E<R!I;B!A(&-O;6UA+61E;&EM:71E9"!S=')I
M;F<N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!T:&4@96UP='D@
M<W1R:6YG(&]N(&5R<F]R+VYO(&%D9')E<W-E<R!F;W5N9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D<D%R<F%Y,E-T<FEN9R@D861D<F5S<V5S+"`D9FEL
M=&5R(#T@)R<I"B`@("!["B`@("`@("`@)&%D9'),:7-T(#T@87)R87DH*3L*
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D861D<F5S<V5S*2D@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D
M861D<F5S<V5S(&%S("1A9&1R*2!["B`@("`@("`@("`@("1V86P@/2!-24U%
M.CIA9&1R3V)J96-T,E-T<FEN9R@D861D<BP@)&9I;'1E<BD["B`@("`@("`@
M("`@(&EF("@A96UP='DH)'9A;"DI('L*("`@("`@("`@("`@("`@("1B87)E
M061D<B`](%-T<FEN9SHZ;&]W97(H34E-13HZ8F%R94%D9')E<W,H)'9A;"DI
M.PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D861D<DQI<W1;)&)A<F5!
M9&1R72DI('L*("`@("`@("`@("`@("`@("`@("`D861D<DQI<W1;)&)A<F5!
M9&1R72`]("1V86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D861D<DQI<W0I*2!["B`@
M("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@:6UP;&]D92@G+"`G+"`D861D<DQI<W0I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&)A<F4@861D
M<F5S<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R97-S("`@
M(%1H92!A9&1R97-S('-T<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&1E
M9G-E<G9E<B`@5&AE(&1E9F%U;'0@9&]M86EN('1O(&%P<&5N9"!T;R!M86EL
M8F]X97,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;75L=&EP;&4@(%-H;W5L
M9"!W92!R971U<FX@;75L=&EP;&4@<F5S=6QT<S\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!)9B`D;75L=&EP;&4@:7,@9F%L<V4L(')E='5R;G,@
M=&AE(&UA:6QB;WA`:&]S="!E+6UA:6P*("`@("`J("`@("`@("`@("`@("`@
M(&%D9')E<W,N("!)9B`D;75L=&EP;&4@:7,@=')U92P@<F5T=7)N<R!A;B!A
M<G)A>2!O9@H@("`@("H@("`@("`@("`@("`@("`@=&AE<V4@861D<F5S<V5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!B87)E061D<F5S<R@D861D<F5S<RP@
M)&1E9G-E<G9E<B`](&YU;&PL("1M=6QT:7!L92`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1A9&1R97-S3&ES="`](&%R<F%Y*"D["@H@("`@("`@("\J(%5S
M92!B=6EL="UI;B!)34%0(&9U;F-T:6]N(&]N;'D@:68@879A:6QA8FQE(&%N
M9"!I9B!N;W0@<&%R<VEN9PH@("`@("`@("`J(&1I<W1R:6)U=&EO;B!L:7-T
M<R!B96-A=7-E(&ET(&1O97-N)W0@<&%R<V4@9&ES=')I8G5T:6]N(&QI<W1S
M"B`@("`@("`@("H@<')O<&5R;'DN("HO"B`@("`@("`@:68@*%5T:6PZ.F5X
M=&5N<VEO;D5X:7-T<R@G:6UA<"<I("8F('-T<G!O<R@D861D<F5S<RP@)SHG
M*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)&9R;VT@/2!I;6%P7W)F8S@R
M,E]P87)S95]A9')L:7-T*"1A9&1R97-S+"`D9&5F<V5R=F5R*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO4D9#
M.#(R+G!H<"<["B`@("`@("`@("`@("1P87)S97(@/2!N97<@36%I;%]21D,X
M,C(H*3L*("`@("`@("`@("`@)&9R;VT@/2`D<&%R<V5R+3YP87)S94%D9')E
M<W-,:7-T*"1A9&1R97-S+"`D9&5F<V5R=F5R+"!F86QS92P@9F%L<V4I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D9G)O;2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1M=6QT:7!L92`_(&%R<F%Y*"D@.B`G
M)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M)&9R;VT@87,@)&5N=')Y*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D96YT
M<GDM/FUA:6QB;W@I("8F"B`@("`@("`@("`@("`@("`D96YT<GDM/FUA:6QB
M;W@@(3T@)W5N9&ES8VQO<V5D+7)E8VEP:65N=',G("8F"B`@("`@("`@("`@
M("`@("`D96YT<GDM/FUA:6QB;W@@(3T@)U5.15A014-4141?1$%405]!1E1%
M4E]!1$1215-3)RD@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R
M>2T^:&]S="DI('L*("`@("`@("`@("`@("`@("`@("`D861D<F5S<TQI<W1;
M72`]("1E;G1R>2T^;6%I;&)O>"`N("=`)R`N("1E;G1R>2T^:&]S=#L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&%D
M9')E<W-,:7-T6UT@/2`D96YT<GDM/FUA:6QB;W@["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;75L=&EP;&4@/R`D861D<F5S<TQI<W0@.B!A<G)A>5]P;W`H)&%D9')E<W-,
M:7-T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%%U;W1E<R!A;F0@97-C87!E
M<R!T:&4@9VEV96X@<W1R:6YG(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S='(@("`@(%1H92!S=')I;F<@=&\@8F4@<75O=&5D(&%N9"!E<V-A<&5D
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL=&5R("!!(&QI<W0@;V8@8VAA
M<F%C=&5R<R!T:&%T(&UA:V4@:70@;F5C97-S87)Y('1O"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('%U;W1E('1H92!S=')I;F<@:68@=&AE>2!O
M8V-U<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O<G)E
M8W1L>2!Q=6]T960@86YD(&5S8V%P960@<W1R:6YG+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<F9C.#(R16YC;V1E*"1S='(L("1F:6QT97(@/2`G)RD*("`@
M('L*("`@("`@("!I9B`H96UP='DH)&9I;'1E<BDI('L*("`@("`@("`@("`@
M)'9A<G,@/2!G971?8VQA<W-?=F%R<R@G34E-12<I.PH@("`@("`@("`@("`D
M9FEL=&5R(#T@)'9A<G-;)W)F8S@R,E]F:6QT97(G72`N("<@)SL*("`@("`@
M("!]"@H@("`@("`@("\O(%-T<FEP(&1O=6)L92!Q=6]T97,@:68@=&AE>2!A
M<F4@87)O=6YD('1H92!S=')I;F<@86QR96%D>2X*("`@("`@("!I9B`H<W5B
M<W1R*"1S='(L(#`L(#$I(#T]("<B)R`F)B!S=6)S='(H)'-T<BP@+3$I(#T]
M("<B)RD@>PH@("`@("`@("`@("`D<W1R(#T@<W5B<W1R*"1S='(L(#$L("TQ
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')C<W!N*"1S='(L("1F:6QT
M97(I("$]('-T<FQE;B@D<W1R*2D@>PH@("`@("`@("`@("`D<W1R(#T@<W1R
M7W)E<&QA8V4H)UPB)RP@)R(G+"`D<W1R*3L*("`@("`@("`@("`@<F5T=7)N
M("<B)R`N('-T<E]R97!L86-E*"<B)RP@)UQ<(B<L('-T<E]R97!L86-E*"=<
M7"<L("=<7%Q<)RP@)'-T<BDI("X@)R(G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D<W1R.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE($U)344@='EP92!F;W(@=&AE(&=I=F5N
M(&EN<'5T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:6YP=70@("`@
M($5I=&AE<B!T:&4@34E-12!C;V1E(&]R('1Y<&4@<W1R:6YG+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&9O<FUA="`@268@34E-15]#3T1%+"!R971U<FX@
M8V]D92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($EF($U)345?
M4U1224Y'+"!R971U<FYS(&QO=V5R8V%S92!S=')I;F<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@4V5E(&%B;W9E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!T>7!E*"1I;G!U="P@)&9O<FUA="`](&YU;&PI"B`@("!["B`@("`@
M("`@<F5T=7)N($U)344Z.E]G971#;V1E*"1I;G!U="P@)&9O<FUA="P@)VUI
M;65?='EP97,G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M($U)344@96YC;V1I;F<@9F]R('1H92!G:79E;B!I;G!U="X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&EN<'5T("`@("!%:71H97(@=&AE($U)344@
M8V]D92!O<B!E;F-O9&EN9R!S=')I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9F]R;6%T("!)9B!-24U%7T-/1$4L(')E='5R;B!C;V1E+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@268@34E-15]35%))3D<L(')E='5R
M;G,@;&]W97)C87-E('-T<FEN9RX*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@($EF(&YO="!S970L(')E='5R;G,@=&AE(&]P<&]S:71E('9A;'5E
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%-E92!A8F]V92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@96YC;V1I;F<H)&EN<'5T+"`D9F]R;6%T(#T@
M;G5L;"D*("`@('L*("`@("`@("!R971U<FX@34E-13HZ7V=E=$-O9&4H)&EN
M<'5T+"`D9F]R;6%T+"`G;6EM95]E;F-O9&EN9W,G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E=')I979E<R!-24U%(&5N8V]D:6YG+W1Y<&4@9&%T82!F
M<F]M('1H92!I;G1E<FYA;"!A<G)A>7,N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I;G!U="`@
M("!%:71H97(@=&AE($U)344@8V]D92!O<B!E;F-O9&EN9R!S=')I;F<N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@($EF($U)345?0T]$12P@<F5T
M=7)N<R!C;V1E+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!)9B!-
M24U%7U-44DE.1RP@<F5T=7)N<R!L;W=E<F-A<V4@<W1R:6YG+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!)9B!N=6QL+"!R971U<FYS('1H92!O
M<'!P;W-I=&4@=F%L=64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@
M(%1H92!N86UE(&]F('1H92!I;G1E<FYA;"!A<G)A>2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!3964@86)O=F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G971#;V1E*"1I;G!U="P@)&9O<FUA="P@)'1Y<&4I"B`@("!["B`@
M("`@("`@)&YU;65R:6,@/2!I<U]N=6UE<FEC*"1I;G!U="D["B`@("`@("`@
M:68@*"$D;G5M97)I8RD@>PH@("`@("`@("`@("`D:6YP=70@/2!3=')I;F<Z
M.FQO=V5R*"1I;G!U="D["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1F
M;W)M870I('L*("`@("`@("!C87-E($U)345?0T]$13H*("`@("`@("`@("`@
M:68@*"1N=6UE<FEC*2!R971U<FX@)&EN<'5T.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92!-24U%7U-44DE.1SH*("`@("`@("`@("`@:68@
M*"$D;G5M97)I8RD@<F5T=7)N("1I;G!U=#L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H*("`@("`@("`D=F%R<R`](&=E=%]C;&%S<U]V87)S*"=-
M24U%)RD["@H@("`@("`@(&EF("@D;G5M97)I8RD@>PH@("`@("`@("`@("!I
M9B`H:7-S970H)'9A<G-;)'1Y<&5=6R1I;G!U=%TI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'9A<G-;)'1Y<&5=6R1I;G!U=%T["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H*"1S96%R8V@@
M/2!A<G)A>5]S96%R8V@H)&EN<'5T+"`D=F%R<ULD='EP95TI*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1S96%R8V@["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5N97)A=&5S(&$@365S<V%G92U)1"!S=')I;F<@8V]N9F]R;6EN
M9R!T;R!21D,@,C@R,B!;,RXV+C1=(&%N9"!T:&4*("`@("`J('-T86YD87)D
M<R!O=71L:6YE9"!I;B`G9')A9G0M:65T9BUU<V5F;W(M;65S<V%G92UI9"TP
M,2YT>'0G+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@($$@;65S<V%G
M92!)1"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E365S
M<V%G94E$*"D*("`@('L*("`@("`@("!R971U<FX@)SPG("X@9&%T92@G66UD
M2&ES)RD@+B`G+B<@+@H@("`@("`@("`@("!S=6)S='(H8F%S95]C;VYV97)T
M*&UI8W)O=&EM92@I("X@;71?<F%N9"@I+"`Q,"P@,S8I+"`M,38I("X*("`@
M("`@("`@("`@)T`G("X@)%]315)615);)U-%4E9%4E].04U%)UT@+B`G/B<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S('!R;W!E<B!L:6YE8G)E86MS
M('1O(&$@:&5A9&5R('-T<FEN9RX*("`@("`J(%)&0R`R.#(R(%LR+C(N,UT@
M<V%Y<R!T:&%T(&AE861E<G,@4TA/54Q$(&)E('=R87!P960@870@-S@@8VAA
M<F%C=&5R<RX*("`@("`J($AO=V5V97(L('-I;F-E('=E(&UA>2!B92!D96%L
M:6YG('=I=&@@<75O=&5D('1E>'0@=&AA="!C;VYT86EN<R!S<&%C97,L"B`@
M("`@*B!S=')I8W0@=W)A<'!I;F<@870@-S@@8VAA<F%C=&5R<R!M87D@861D
M('5N=V%N=&5D(&YE=VQI;F5S(&%N9"!T86)S('1O"B`@("`@*B!T:&4@<75O
M=&5D('!A<F%M971E<BX@(%1H92!C;W)R96-T('=A>2!T;R!G970@87)O=6YD
M('1H:7,@:7,@=&\@96YC;V1E"B`@("`@*B!P87)A971E<G,@86-C;W)D:6YG
M('1O(%)&0R`R,C,Q+B`@2&]W979E<BP@<VEN8V4@;6]S="!M86EL97)S(&1O
M(&YO=`H@("`@("H@<V5E;2!T;R!S=7!P;W)T('1H:7,L('=E('=I;&P@:6YS
M=&5A9"!S:6UP;'D@=7-E(&QO;F<@;&EN97,N("!21D,@,C@R,@H@("`@("H@
M<V%Y<R!H96%D97)S(%-(3U5,1"!O;FQY(&)E(#<X(&-H87)A8W1E<G,@82!L
M:6YE+"!B=70@86QS;R!S87ES('1H870*("`@("`J(&$@:&5A9&5R(&QI;F4@
M35535"!N;W0@8F4@;6]R92!T:&%N(#DY."!C:&%R86-T97)S+B`@5&AE<F5F
M;W)E+"!T:&4*("`@("`J(&-O;7!R;VUI<V4@:7,@=&\@<'5T(&5A8V@@<&%R
M86UE=&5R(&]N(&$@<V5P87)A=&4@;&EN92!A;F0@8VAO<"!I=`H@("`@("H@
M;VYL>2!I9B!I="!I<R!L;VYG97(@=&AA;B`Y.3@@8VAA<F%C=&5R<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@
M;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@5&AE('1E>'0@
M;V8@=&AE(&AE861E<B!F:65L9"X*("`@("`J($!P87)A;2!S=')I;F<@)&5O
M;"`@("`@5&AE($5/3"!S=')I;F<@=&\@=7-E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@:&5A9&5R('1E>'0L('=I=&@@;&EN96)R96%K
M<R!I;G-E<G1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)A<$AE861E<G,H
M)&AE861E<BP@)'1E>'0L("1E;VP@/2`B7')<;B(I"B`@("!["B`@("`@("`@
M)&AE861E<B`](')T<FEM*"1H96%D97(I.PH*("`@("`@("`O*B!296UO=F4@
M86YY(&5X:7-T:6YG(&QI;F5B<F5A:W,N("HO"B`@("`@("`@)'1E>'0@/2!P
M<F5G7W)E<&QA8V4H(B]<<C]<;EQS/R\B+"`G("<L("1T97AT*3L*("`@("`@
M("`D=&5X="`]("1H96%D97(@+B`G.B`G("X@<G1R:6TH)'1E>'0I.PH*("`@
M("`@("`D96]L;&5N9W1H(#T@<W1R;&5N*"1E;VPI.PH@("`@("`@("1H96%D
M97)?;&]W97(@/2!S=')T;VQO=V5R*"1H96%D97(I.PH*("`@("`@("!I9B`H
M*"1H96%D97)?;&]W97(@(3T@)V-O;G1E;G0M='EP92<I("8F"B`@("`@("`@
M("`@("@D:&5A9&5R7VQO=V5R("$]("=C;VYT96YT+61I<W!O<VET:6]N)RDI
M('L*("`@("`@("`@("`@+RH@5W)A<"!T:&4@;&EN92X@*B\*("`@("`@("`@
M("`@)&QI;F4@/2!W;W)D=W)A<"@D=&5X="P@-S4L("1E;VP@+B`B7'0B*3L*
M"B`@("`@("`@("`@("\J($UA:V4@<W5R92!T:&5R92!A<F4@;F\@96UP='D@
M;&EN97,N("HO"B`@("`@("`@("`@("1L:6YE(#T@<')E9U]R97!L86-E*"<O
M)R`N("1E;VP@+B`B7'1<<RHB("X@)&5O;"`N(")<="\B+"`G+R<@+B`D96]L
M("X@(EQT+R(L("1L:6YE*3L*"B`@("`@("`@("`@(')E='5R;B!S=6)S='(H
M)&QI;F4L('-T<FQE;B@D:&5A9&5R*2`K(#(I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4W!L:70@=&AE(&QI;F4@8GD@=&AE(%)&0R!P87)A;65T97(@<V5P
M87)A=&]R("<[)RX@*B\*("`@("`@("`D<&%R86US(#T@<')E9U]S<&QI="@B
M+UQS*CM<<RHO(BP@)'1E>'0I.PH*("`@("`@("`D;&EN92`]("<G.PH@("`@
M("`@("1L96YG=&@@/2`Q,#`P("T@)&5O;&QE;F=T:#L*("`@("`@("`D<&%R
M86UC;W5N="`](&-O=6YT*"1P87)A;7,I.PH*("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1C;W5N="`]/B`D=F%L*2!["B`@("`@("`@("`@("\J($EF
M(&QO;F=E<B!T:&%N(%)&0R!A;&QO=W,L('1H96X@<VEM<&QY(&-H;W`@;V9F
M('1H92!E>&-E<W,N("HO"B`@("`@("`@("`@("1M;W)E<&%R86US(#T@*"@D
M8V]U;G0@*R`Q*2`A/2`D<&%R86UC;W5N="D["B`@("`@("`@("`@("1M87AL
M96YG=&@@/2`D;&5N9W1H("T@*"%E;7!T>2@D;&EN92D@/R`Q(#H@,"D@+2`H
M*"1M;W)E<&%R86US*2`_(#$@.B`P*3L*("`@("`@("`@("`@:68@*'-T<FQE
M;B@D=F%L*2`^("1M87AL96YG=&@I('L*("`@("`@("`@("`@("`@("1V86P@
M/2!S=6)S='(H)'9A;"P@,"P@)&UA>&QE;F=T:"D["@H@("`@("`@("`@("`@
M("`@+RH@268@=V4@:&%V92!A;B!O<&5N:6YG('%U;W1E+"!A9&0@82!C;&]S
M:6YG('%U;W1E(&%F=&5R"B`@("`@("`@("`@("`@("`@*B!C:&]P<&EN9R!T
M:&4@<F5S="!O9B!T:&4@=&5X="X@*B\*("`@("`@("`@("`@("`@(&EF("AS
M=')P;W,H)'9A;"P@)R(G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("`@("`D=F%L(#T@<W5B<W1R*"1V86PL(#`L("TQ*3L*("`@("`@("`@("`@
M("`@("`@("`D=F%L("X]("<B)SL*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("@A96UP='DH)&QI;F4I*2!["B`@
M("`@("`@("`@("`@("`D;&EN92`N/2`B7'0B.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1L:6YE("X]("1V86P@+B`H*"1M;W)E<&%R86US*2`_("<[
M)R`Z("<G*2`N("1E;VP["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<W5B
M<W1R*"1L:6YE+"!S=')L96XH)&AE861E<BD@*R`R+"`H)&5O;&QE;F=T:"`J
M("TQ*2D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H
M+G!H<```````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q
M,C,S-C$`,3`T,3<S-C(W-S,`,#$W-C4R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@<&%R86UE
M=&5R(&YA;64@9F]R('1H92!L;V=O=70@<F5A<V]N+@H@*B\*9&5F:6YE*"=!
M551(7U)%05-/3E]005)!32<L("=L;V=O=71?<F5A<V]N)RD["@HO*BH*("H@
M5&AE('!A<F%M971E<B!N86UE(&9O<B!T:&4@;&]G;W5T(&UE<W-A9V4@=7-E
M9"!W:71H('1Y<&4*("H@05542%]214%33TY?34534T%'12X*("HO"F1E9FEN
M92@G05542%]214%33TY?35-'7U!!4D%-)RP@)VQO9V]U=%]M<V<G*3L*"B\J
M*@H@*B!4:&4@)V)A9&QO9VEN)R!R96%S;VXN"B`J"B`J(%1H92!F;VQL;W=I
M;F<@)W)E87-O;G,G(&9O<B!T:&4@;&]G;W5T('-C<F5E;B!A<F4@<F5C;V=N
M:7IE9#H*("H@/'!R93X*("H@("`G8F%D;&]G:6XG("`@+2T@($)A9"!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0*("H@("`G8G)O=W-E<B<@("`@+2T@($$@
M8G)O=W-E<B!C:&%N9V4@=V%S(&1E=&5C=&5D"B`J("`@)V9A:6QE9"<@("`@
M("TM("!,;V=I;B!F86EL960*("H@("`G;&]G;W5T)R`@("`@+2T@($QO9V]U
M="!D=64@=&\@=7-E<B!R97%U97-T"B`J("`@)VUE<W-A9V4G("`@("TM("!,
M;V=O=70@=VET:"!C=7-T;VT@;65S<V%G92!I;B!!551(7U)%05-/3E]-4T=?
M4$%204T*("H@("`G<V5S<VEO;B<@("`@+2T@($QO9V]U="!D=64@=&\@<V5S
M<VEO;B!E>'!I<F%T:6]N"B`J("`@)W-E<W-I;VYI<"<@("TM("!,;V=O=70@
M9'5E('1O(&-H86YG92!O9B!)4"!A9&1R97-S(&1U<FEN9R!S97-S:6]N"B`J
M(#PO<')E/@H@*B\*9&5F:6YE*"=!551(7U)%05-/3E]"041,3T=)3B<L("=B
M861L;V=I;B<I.PH*+RHJ"B`J(%1H92`G8G)O=W-E<B<@<F5A<V]N+@H@*B\*
M9&5F:6YE*"=!551(7U)%05-/3E]"4D]74T52)RP@)V)R;W=S97(G*3L*"B\J
M*@H@*B!4:&4@)V9A:6QE9"<@<F5A<V]N+@H@*B\*9&5F:6YE*"=!551(7U)%
M05-/3E]&04E,140G+"`G9F%I;&5D)RD["@HO*BH*("H@5&AE("=E>'!I<F5D
M)R!R96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7T584$E2140G+"`G
M97AP:7)E9"<I.PH*+RHJ"B`J(%1H92`G;&]G;W5T)R!R96%S;VXN"B`J+PID
M969I;F4H)T%55$A?4D5!4T].7TQ/1T]55"<L("=L;V=O=70G*3L*"B\J*@H@
M*B!4:&4@)VUE<W-A9V4G(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%3
M3TY?34534T%'12<L("=M97-S86=E)RD["@HO*BH*("H@5&AE("=S97-S:6]N
M)R!R96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7U-%4U-)3TXG+"`G
M<V5S<VEO;B<I.PH*+RHJ"B`J(%1H92`G<V5S<VEO;FEP)R!R96%S;VXN"B`J
M+PID969I;F4H)T%55$A?4D5!4T].7U-%4U-)3TY)4"<L("=S97-S:6]N:7`G
M*3L*"B\J*@H@*B!4:&4@075T:#HZ(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N
M(&%B<W1R86-T960@:6YT97)F86-E(&EN=&\@=&AE('9A<FEO=7,*("H@8F%C
M:V5N9',@9F]R('1H92!(;W)D92!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"YP:'`L=B`Q+C$T,BXQ
M,"XR,2`R,#`V+S`Q+S$X(#$R.C(P.C`R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H('L*"B`@("`O
M*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T
M:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@
M:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`]
M(&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO
M=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9W)O=7!S)R`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]
M/B!F86QS92D["@H@("`O*BH*("`@("H@2&%S:"!C;VYT86EN:6YG('!A<F%M
M971E<G,N"B`@("`J"B`@("`J($!V87(@87)R87D*("`@("HO"B`@("!V87(@
M)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&-R961E
M;G1I86QS(&-U<G)E;G1L>2!B96EN9R!A=71H96YT:6-A=&5D+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]A=71H0W)E9&5N=&EA;',@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F%M92!O9B!T:&4@
M8V]N8W)E=&4@075T:"!I;7!L96UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE($%U=&@@:6UP;&5M96YT871I;VX@;F%M92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1')I=F5R*"D*("`@('L*("`@("`@
M("!R971U<FX@<W1R7W)E<&QA8V4H)V%U=&A?)RP@)R<L('-T<G1O;&]W97(H
M9V5T7V-L87-S*"1T:&ES*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN
M9',@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI
M9"P@86YD(&EF(')E<75E<W1E9"P*("`@("`J(&UA<FL@=&AE('5S97(@87,@
M;&]G9V5D(&EN(&EN('1H92!C=7)R96YT('-E<W-I;VXN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!C
M:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C
M<F5D96YT:6%L<R!T;R!C:&5C:RX*("`@("`J($!P87)A;2!B;V]L96%N("1L
M;V=I;B`@("`@(%=H971H97(@=&\@;&]G('1H92!U<V5R(&EN+B!)9B!F86QS
M92P@=V4G;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]N
M;'D@=&5S="!T:&4@8W)E9&5N=&EA;',@86YD('=O;B=T(&UO9&EF>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&-U<G)E;G0@<V5S
M<VEO;BX@1&5F875L=',@=&\@=')U92X*("`@("`J($!P87)A;2!S=')I;F<@
M)')E86QM("`@("`@(%1H92!A=71H96YT:6-A=&EO;B!R96%L;2!T;R!C:&5C
M:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@
M;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',L("1L
M;V=I;B`]('1R=64L("1R96%L;2`](&YU;&PI"B`@("!["B`@("`@("`@9VQO
M8F%L("1C;VYF.PH*("`@("`@("`D875T:"`](&9A;'-E.PH@("`@("`@("1U
M<V5R260@/2!T<FEM*"1U<V5R260I.PH*("`@("`@("!I9B`H(65M<'1Y*"1C
M;VYF6R=H;V]K<R==6R=P<F5A=71H96YT:6-A=&4G72DI('L*("`@("`@("`@
M("`@:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP
M:'`G.PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?
M:&]O:U]P<F5A=71H96YT:6-A=&4G*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"%C86QL7W5S97)?9G5N8R@G7VAO<F1E7VAO;VM?<')E875T:&5N=&EC871E
M)RP@)'5S97))9"P@)&-R961E;G1I86QS+"`D<F5A;&TI*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?9V5T075T:$5R<F]R*"D@(3T@0554
M2%]214%33TY?34534T%'12D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]&04E,140I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J(%-T;W)E('1H92!C<F5D96YT:6%L<R!B96EN9R!C
M:&5C:V5D('-O('1H870@<W5B8VQA<W-E<R!C86X@;6]D:69Y"B`@("`@("`@
M("H@=&AE;2!I9B!N96-E<W-A<GD@*&QI:V4@=')A;G-P87)E;G0@875T:"!D
M;V5S*2X@*B\*("`@("`@("`D=&AI<RT^7V%U=&A#<F5D96YT:6%L<R`](&%R
M<F%Y*`H@("`@("`@("`@("`G=7-E<DED)R`]/B`D=7-E<DED+`H@("`@("`@
M("`@("`G8W)E9&5N=&EA;',G(#T^("1C<F5D96YT:6%L<RP*("`@("`@("`@
M("`@)W)E86QM)R`]/B`D<F5A;&TL"B`@("`@("`@("`@("=C:&%N9V5297%U
M97-T960G(#T^(&9A;'-E"B`@("`@("`@*3L*"B`@("`@("`@:68@*"1A=71H
M96YT:6-A=&5D(#T@)'1H:7,M/E]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R
M961E;G1I86QS*2D@>PH@("`@("`@("`@("!I9B`H:7-?82@D875T:&5N=&EC
M871E9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH
M)&-O;F9;)VAO;VMS)UU;)W!O<W1A=71H96YT:6-A=&4G72DI('L*("`@("`@
M("`@("`@("`@(&EN8VQU9&5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF:6<O
M:&]O:W,N<&AP)SL*("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)U]H;W)D95]H;V]K7W!O<W1A=71H96YT:6-A=&4G*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@A8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K
M7W!O<W1A=71H96YT:6-A=&4G+"`D=7-E<DED+"`D8W)E9&5N=&EA;',L("1R
M96%L;2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M9V5T075T:$5R<F]R*"D@(3T@05542%]214%33TY?34534T%'12D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H
M05542%]214%33TY?1D%)3$5$*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&QO9VEN*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T075T:"@D=&AI<RT^7V%U=&A#<F5D96YT:6%L<ULG=7-E
M<DED)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V%U=&A#<F5D96YT:6%L<ULG8W)E9&5N=&EA;',G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?875T:$-R961E;G1I86QS6R=R
M96%L;2==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A=71H0W)E9&5N=&EA;'-;)V-H86YG95)E<75E<W1E9"==*3L*("`@("`@
M("`@("`@("`@("1A=71H(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]C:&5C:U-E<W-I;VY)4"@I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H
M05542%]214%33TY?4T534TE/3DE0*3L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES
M+3Y?8VAE8VM"<F]W<V5R4W1R:6YG*"DI('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"4D]74T52*3L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D875T:"`]('1R=64["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D875T:#L*("`@('T*
M"B`@("`O*BH*("`@("`J($9O<FUA=',@82!P87-S=V]R9"!U<VEN9R!T:&4@
M8W5R<F5N="!E;F-R>7!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!L86EN=&5X="`@("`@(%1H92!P;&%I;G1E>'0@<&%S<W=O<F0@=&\@
M96YC<GEP="X*("`@("`J($!P87)A;2!S=')I;F<@)'-A;'0@("`@("`@("`@
M(%1H92!S86QT('1O('5S92!T;R!E;F-R>7!T('1H92!P87-S=V]R9"X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($EF(&YO="!P<F5S
M96YT+"!A(&YE=R!S86QT('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&=E;F5R871E9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&5N8W)Y<'1I;VX@("`@(%1H92!K:6YD(&]F('!A<W=O<F0@96YC<GEP
M=&EO;B!T;R!U<V4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!$969A=6QT<R!T;R!M9#4M:&5X+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'-H;W=?96YC<GEP="`@4V]M92!P87-S=V]R9"!S>7-T96US('!R97!E
M;F0@=&AE(&MI;F0@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5N8W)Y<'1I;VX@=&\@=&AE(&-R>7!T960@<&%S<W=O<F0@*'M3
M2$%]+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@971C
M*2X@1&5F875L=',@=&\@9F%L<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!E;F-R>7!T960@<&%S<W=O<F0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$-R>7!T961087-S=V]R9"@D<&QA:6YT97AT+"`D<V%L="`]
M("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;F-R>7!T
M:6]N(#T@)VUD-2UH97@G+"`D<VAO=U]E;F-R>7!T(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@+RH@1V5T('1H92!S86QT('1O('5S92X@*B\*("`@("`@("`D
M<V%L="`]($%U=&@Z.F=E=%-A;'0H)&5N8W)Y<'1I;VXL("1S86QT+"`D<&QA
M:6YT97AT*3L*"B`@("`@("`@+RH@16YC<GEP="!T:&4@<&%S<W=O<F0N("HO
M"B`@("`@("`@<W=I=&-H("@D96YC<GEP=&EO;BD@>PH@("`@("`@(&-A<V4@
M)W!L86EN)SH*("`@("`@("`@("`@<F5T=7)N("1P;&%I;G1E>'0["@H@("`@
M("`@(&-A<V4@)VUS860G.@H@("`@("`@("`@("!R971U<FX@4W1R:6YG.CIC
M;VYV97)T0VAA<G-E="@G(B<@+B`D<&QA:6YT97AT("X@)R(G+"`G25-/+3@X
M-3DM,2<L("=55$8M,39,12<I.PH*("`@("`@("!C87-E("=S:&$G.@H@("`@
M("`@("`@("`D96YC<GEP=&5D(#T@8F%S938T7V5N8V]D92AM:&%S:"A-2$%3
M2%]32$$Q+"`D<&QA:6YT97AT*2D["B`@("`@("`@("`@(')E='5R;B`H)'-H
M;W=?96YC<GEP="D@/R`G>U-(07TG("X@)&5N8W)Y<'1E9"`Z("1E;F-R>7!T
M960["@H@("`@("`@(&-A<V4@)V-R>7!T)SH*("`@("`@("!C87-E("=C<GEP
M="UD97,G.@H@("`@("`@(&-A<V4@)V-R>7!T+6UD-2<Z"B`@("`@("`@8V%S
M92`G8W)Y<'0M8FQO=V9I<V@G.@H@("`@("`@("`@("!R971U<FX@*"1S:&]W
M7V5N8W)Y<'0@/R`G>V-R>7!T?2<@.B`G)RD@+B!C<GEP="@D<&QA:6YT97AT
M+"`D<V%L="D["@H@("`@("`@(&-A<V4@)VUD-2UB87-E-C0G.@H@("`@("`@
M("`@("`D96YC<GEP=&5D(#T@8F%S938T7V5N8V]D92AM:&%S:"A-2$%32%]-
M1#4L("1P;&%I;G1E>'0I*3L*("`@("`@("`@("`@<F5T=7)N("@D<VAO=U]E
M;F-R>7!T*2`_("=[340U?2<@+B`D96YC<GEP=&5D(#H@)&5N8W)Y<'1E9#L*
M"B`@("`@("`@8V%S92`G<W-H82<Z"B`@("`@("`@("`@("1E;F-R>7!T960@
M/2!B87-E-C1?96YC;V1E*&UH87-H*$U(05-(7U-(03$L("1P;&%I;G1E>'0@
M+B`D<V%L="D@+B`D<V%L="D["B`@("`@("`@("`@(')E='5R;B`H)'-H;W=?
M96YC<GEP="D@/R`G>U-32$%])R`N("1E;F-R>7!T960@.B`D96YC<GEP=&5D
M.PH*("`@("`@("!C87-E("=S;60U)SH*("`@("`@("`@("`@)&5N8W)Y<'1E
M9"`](&)A<V4V-%]E;F-O9&4H;6AA<V@H34A!4TA?340U+"`D<&QA:6YT97AT
M("X@)'-A;'0I("X@)'-A;'0I.PH@("`@("`@("`@("!R971U<FX@*"1S:&]W
M7V5N8W)Y<'0I(#\@)WM3340U?2<@+B`D96YC<GEP=&5D(#H@)&5N8W)Y<'1E
M9#L*"B`@("`@("`@8V%S92`G87!R;60U)SH*("`@("`@("`@("`@)&QE;F=T
M:"`]('-T<FQE;B@D<&QA:6YT97AT*3L*("`@("`@("`@("`@)&-O;G1E>'0@
M/2`D<&QA:6YT97AT("X@)R1A<'(Q)"<@+B`D<V%L=#L*("`@("`@("`@("`@
M)&)I;F%R>2`]($%U=&@Z.E]B:6XH;60U*"1P;&%I;G1E>'0@+B`D<V%L="`N
M("1P;&%I;G1E>'0I*3L*"B`@("`@("`@("`@(&9O<B`H)&D@/2`D;&5N9W1H
M.R`D:2`^(#`[("1I("T](#$V*2!["B`@("`@("`@("`@("`@("`D8V]N=&5X
M="`N/2!S=6)S='(H)&)I;F%R>2P@,"P@*"1I(#X@,38@/R`Q-B`Z("1I*2D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R("@D:2`]("1L96YG=&@[
M("1I(#X@,#L@)&D@/CX](#$I('L*("`@("`@("`@("`@("`@("1C;VYT97AT
M("X]("@D:2`F(#$I(#\@8VAR*#`I(#H@)'!L86EN=&5X='LP?3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&)I;F%R>2`]($%U=&@Z.E]B:6XH;60U
M*"1C;VYT97AT*2D["@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q
M,#`P.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D;F5W(#T@*"1I("8@,2D@
M/R`D<&QA:6YT97AT(#H@<W5B<W1R*"1B:6YA<GDL(#`L,38I.PH@("`@("`@
M("`@("`@("`@:68@*"1I("4@,RD@>PH@("`@("`@("`@("`@("`@("`@("1N
M97<@+CT@)'-A;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H)&D@)2`W*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=R`N/2`D
M<&QA:6YT97AT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&YE=R`N/2`H)&D@)B`Q*2`_('-U8G-T<B@D8FEN87)Y+"`P+"`Q-BD@.B`D
M<&QA:6YT97AT.PH@("`@("`@("`@("`@("`@)&)I;F%R>2`]($%U=&@Z.E]B
M:6XH;60U*"1N97<I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'`@
M/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`U.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("`D:R`]("1I("L@-CL*("`@("`@("`@
M("`@("`@("1J(#T@)&D@*R`Q,CL*("`@("`@("`@("`@("`@(&EF("@D:B`]
M/2`Q-BD@>PH@("`@("`@("`@("`@("`@("`@("1J(#T@-3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1P6UT@/2!!=71H.CI?=&]!4%)-
M1#4H*&]R9"@D8FEN87)Y6R1I72D@/#P@,38I('P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*&]R9"@D8FEN87)Y6R1K72D@/#P@
M."D@?`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H
M;W)D*"1B:6YA<GE;)&I=*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#4I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R
M971U<FX@)R1A<'(Q)"<@+B`D<V%L="`N("<D)R`N(&EM<&QO9&4H)R<L("1P
M*2`N($%U=&@Z.E]T;T%04DU$-2AO<F0H)&)I;F%R>5LQ,5TI+"`S*3L*"B`@
M("`@("`@8V%S92`G;60U+6AE>"<Z"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N("@D<VAO=U]E;F-R>7!T*2`_("=[340U?2<@+B!M9#4H
M)'!L86EN=&5X="D@.B!M9#4H)'!L86EN=&5X="D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-A;'0@9F]R('1H92!A<'!R
M;W!R:6%T92!K:6YD(&]F('!A<W-W;W)D(&5N8W)Y<'1I;VXN"B`@("`@*B!/
M<'1I;VYA;&QY('1A:V5S(&$@<V5E9"!A;F0@82!P;&%I;G1E>'0@<&%S<W=O
M<F0L('1O(&5X=')A8W0@=&AE('-E960*("`@("`J(&]F(&%N(&5X:7-T:6YG
M('!A<W-W;W)D+"!O<B!F;W(@96YC<GEP=&EO;B!T>7!E<R!T:&%T('5S92!T
M:&4@<&QA:6YT97AT"B`@("`@*B!I;B!T:&4@9V5N97)A=&EO;B!O9B!T:&4@
M<V%L="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;F-R>7!T:6]N
M("!4:&4@:VEN9"!O9B!P87-W;W)D(&5N8W)Y<'1I;VX@=&\@=7-E+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@;60U
M+6AE>"X*("`@("`J($!P87)A;2!S=')I;F<@)'-E960@("`@("`@(%1H92!S
M965D('1O(&=E="!T:&4@<V%L="!F<F]M("AP<F]B86)L>2!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!P<F5V:6]U<VQY(&=E;F5R871E
M9"!P87-S=V]R9"DN($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!G96YE<F%T:6YG(&$@;F5W('-E960N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@("!4:&4@<&QA:6YT97AT('!A<W-W
M;W)D('1H870@=V4G<F4@9V5N97)A=&EN9PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@82!S86QT(&9O<BX@1&5F875L=',@=&\@;F]N92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&=E;F5R871E9"!O
M<B!E>'1R86-T960@<V%L="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V%L
M="@D96YC<GEP=&EO;B`]("=M9#4M:&5X)RP@)'-E960@/2`G)RP@)'!L86EN
M=&5X="`]("<G*0H@("`@>PH@("`@("`@("\O($5N8W)Y<'0@=&AE('!A<W-W
M;W)D+@H@("`@("`@('-W:71C:"`H)&5N8W)Y<'1I;VXI('L*("`@("`@("!C
M87-E("=C<GEP="<Z"B`@("`@("`@8V%S92`G8W)Y<'0M9&5S)SH*("`@("`@
M("`@("`@:68@*"1S965D*2!["B`@("`@("`@("`@("`@("!R971U<FX@<W5B
M<W1R*'!R96=?<F5P;&%C92@G?%Y[8W)Y<'1]?&DG+"`G)RP@)'-E960I+"`P
M+"`R*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E
M='5R;B!S=6)S='(H;60U*&UT7W)A;F0H*2DL(#`L(#(I.PH@("`@("`@("`@
M("!]"@H@("`@("`@(&-A<V4@)V-R>7!T+6UD-2<Z"B`@("`@("`@("`@(&EF
M("@D<V5E9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G
M7W)E<&QA8V4H)WQ>>V-R>7!T?7QI)RP@)R<L("1S965D*2P@,"P@,3(I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<D
M,20G("X@<W5B<W1R*&UD-2AM=%]R86YD*"DI+"`P+"`X*2`N("<D)SL*("`@
M("`@("`@("`@?0H*("`@("`@("!C87-E("=C<GEP="UB;&]W9FES:"<Z"B`@
M("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>>V-R>7!T?7QI)RP@)R<L("1S965D
M*2P@,"P@,38I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("<D,B0G("X@<W5B<W1R*&UD-2AM=%]R86YD*"DI+"`P+"`Q
M,BD@+B`G)"<["B`@("`@("`@("`@('T*"B`@("`@("`@8V%S92`G<W-H82<Z
M"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>>U-32$%]?"<L("<G+"`D<V5E
M9"DL("TR,"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!R971U<FX@;6AA<VA?:V5Y9V5N7W,R:RA-2$%32%]32$$Q+"`D<&QA:6YT
M97AT+"!S=6)S='(H<&%C:R@G:"HG+"!M9#4H;71?<F%N9"@I*2DL(#`L(#@I
M+"`T*3L*("`@("`@("`@("`@?0H*("`@("`@("!C87-E("=S;60U)SH*("`@
M("`@("`@("`@:68@*"1S965D*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M<W5B<W1R*'!R96=?<F5P;&%C92@G?%Y[4TU$-7U\)RP@)R<L("1S965D*2P@
M+3$V*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E
M='5R;B!M:&%S:%]K97EG96Y?<S)K*$U(05-(7TU$-2P@)'!L86EN=&5X="P@
M<W5B<W1R*'!A8VLH)V@J)RP@;60U*&UT7W)A;F0H*2DI+"`P+"`X*2P@-"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@8V%S92`G87!R;60U)SH*("`@("`@
M("`@("`@+RH@-C0@8VAA<F%C=&5R<R!T:&%T(&%R92!V86QI9"!F;W(@05!2
M340U('!A<W-W;W)D<RX@*B\*("`@("`@("`@("`@)$%04DU$-2`]("<N+S`Q
M,C,T-38W.#E!0D-$149'2$E*2TQ-3D]045)35%565UA96F%B8V1E9F=H:6IK
M;&UN;W!Q<G-T=79W>'EZ)SL*"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)R]>
M7"1A<'(Q7"0H+GLX?2DN*B\G+"`G7%PQ)RP@)'-E960I+"`P+"`X*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S86QT(#T@)R<[
M"B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-A;'0@+CT@)$%04DU$-7MR86YD*#`L
M(#8S*7T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U
M<FX@)'-A;'0["B`@("`@("`@("`@('T*"B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($=E;F5R871E<R!A(')A;F1O;2P@:&]P969U;&QY('!R;VYO=6YC
M96%B;&4L('!A<W-W;W)D+B!4:&ES(&-A;B!B92!U<V5D"B`@("`@*B!W:&5N
M(')E<V5T=&EN9R!A=71O;6%T:6-A;&QY(&$@=7-E<B=S('!A<W-W;W)D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G96Y286YD;VU087-S=V]R9"@I"B`@("![
M"B`@("`@("`@)'9O=V5L<R`@("`]("=A96EO=7DG.PH@("`@("`@("1C;VYS
M=&%N=',@/2`G8F-D9F=H:FML;6YP<7)S='9W>'HG.PH@("`@("`@("1N=6UB
M97)S("`@/2`G,#$R,S0U-C<X.2<["@H@("`@("`@("\J($%L=&5R;F%T92!C
M;VYS=&%N="!A;F0@=F]W96P@<F%N9&]M(&-H87)S('=I=&@@='=O(')A;F1O
M;2!N=6UB97)S"B`@("`@("`@("H@870@=&AE(&5N9"X@5&AI<R!S:&]U;&0@
M<')O9'5C92!A(&9A:7)L>2!P<F]N;W5N8V5A8FQE('!A<W-W;W)D+B`J+PH@
M("`@("`@("1C:&%R<ULP72`]('-U8G-T<B@D8V]N<W1A;G1S+"!M=%]R86YD
M*#`L('-T<FQE;B@D8V]N<W1A;G1S*2`M(#$I+"`Q*3L*("`@("`@("`D8VAA
M<G-;,5T@/2!S=6)S='(H)'9O=V5L<RP@;71?<F%N9"@P+"!S=')L96XH)'9O
M=V5L<RD@+2`Q*2P@,2D["B`@("`@("`@)&-H87)S6S)=(#T@<W5B<W1R*"1C
M;VYS=&%N=',L(&UT7W)A;F0H,"P@<W1R;&5N*"1C;VYS=&%N=',I("T@,2DL
M(#$I.PH@("`@("`@("1C:&%R<ULS72`]('-U8G-T<B@D=F]W96QS+"!M=%]R
M86YD*#`L('-T<FQE;B@D=F]W96QS*2`M(#$I+"`Q*3L*("`@("`@("`D8VAA
M<G-;-%T@/2!S=6)S='(H)&-O;G-T86YT<RP@;71?<F%N9"@P+"!S=')L96XH
M)&-O;G-T86YT<RD@+2`Q*2P@,2D["B`@("`@("`@)&-H87)S6S5=(#T@<W5B
M<W1R*"1N=6UB97)S+"!M=%]R86YD*#`L('-T<FQE;B@D;G5M8F5R<RD@+2`Q
M*2P@,2D["B`@("`@("`@)&-H87)S6S9=(#T@<W5B<W1R*"1N=6UB97)S+"!M
M=%]R86YD*#`L('-T<FQE;B@D;G5M8F5R<RD@+2`Q*2P@,2D["@H@("`@("`@
M(')E='5R;B!I;7!L;V1E*"<G+"`D8VAA<G,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@061D<R!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L
M<RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&%D9"X*("`@
M("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L
M<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N
M=&EA;',I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)W5N<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&5S
M(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*
M("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&]L9$E$("`@("`@("!4:&4@;VQD('5S97))9"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YE=TE$("`@("`@("!4:&4@;F5W('5S97))9"X*("`@("`J($!P
M87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@("!4:&4@;F5W(&-R961E;G1I86QS
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E
M;G1I86QS*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=U;G-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E
M<R!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;6]V955S97(H)'5S97))9"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($-A;&QS(&%L;"!A<'!L:6-A=&EO;G,G(')E;6]V955S97(@05!)(&UE
M=&AO9',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4
M:&4@=7-E<DED('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R1&%T
M82@D=7-E<DED*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@
M("`@("`@(&9O<F5A8V@@*"1R96=I<W1R>2T^;&ES=$%P<',H87)R87DH)VYO
M=&]O;&)A<B<L("=H:61D96XG+"`G86-T:79E)RP@)V%D;6EN)RDI(&%S("1A
M<'`I('L*("`@("`@("`@("`@:68@*"1R96=I<W1R>2T^:&%S365T:&]D*"=R
M96UO=F55<V5R1&%T82<L("1A<'`I*2!["B`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)')E9VES=')Y+3YC86QL0GE086-K86=E*"1A<'`L
M("=R96UO=F55<V5R1&%T82<L(&%R<F%Y*"1U<V5R260I*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T
M<R!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@
M;V8@=7-E<DED<RP@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=U;G-U<'!O<G1E9"<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF("1U<V5R260@97AI<W1S
M(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="`D=7-E
M<DED(&%L<F5A9'D@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES
M=',H)'5S97))9"D*("`@('L*("`@("`@("!R971U<FX@:6Y?87)R87DH)'5S
M97))9"P@)'1H:7,M/FQI<W15<V5R<R@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%U=&]M871I8R!A=71H96YT:6-A=&EO;CH@1FEN9',@;W5T(&EF('1H
M92!C;&EE;G0@;6%T8VAE<R!A;B!A;&QO=V5D($E0"B`@("`@*B!B;&]C:RX*
M("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C;&EE;G0@:7,@86QL;W=E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-P87)E;G0H*0H@("`@>PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K<R!I9B!T:&5R92!I<R!A('-E<W-I;VX@=VET:"!V86QI9"!A=71H(&EN
M9F]R;6%T:6]N+B!F;W(@=&AE"B`@("`@*B!S<&5C:69I960@=7-E<BX@268@
M=&AE<F4@:7-N)W0L(&)U="!T:&4@8V]N9FEG=7)E9"!!=71H(&1R:79E<B!S
M=7!P;W)T<PH@("`@("H@=')A;G-P87)E;G0@875T:&5N=&EC871I;VXL('1H
M96X@=V4@=')Y('1H870N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<F5A;&T@(%1H92!A=71H96YT:6-A=&EO;B!R96%L;2!T;R!C:&5C:RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H
M92!U<V5R(&ES(&%U=&AE;G1I8V%T960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES075T:&5N=&EC871E9"@D<F5A;&T@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<W-E="@D7U-%4U-)3TY;)U]?875T:"==*2D@>PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1?4T534TE/3ELG7U]A=71H)UU;)V%U=&AE;G1I8V%T
M960G72D@)B8*("`@("`@("`@("`@("`@("%E;7!T>2@D7U-%4U-)3TY;)U]?
M875T:"==6R=U<V5R260G72D@)B8*("`@("`@("`@("`@("`@("@D7U-%4U-)
M3TY;)U]?875T:"==6R=R96%L;2==(#T]("1R96%L;2DI('L*("`@("`@("`@
M("`@("`@(&EF("@A075T:#HZ7V-H96-K4V5S<VEO;DE0*"DI('L*("`@("`@
M("`@("`@("`@("`@("!!=71H.CI?<V5T075T:$5R<F]R*$%55$A?4D5!4T].
M7U-%4U-)3TY)4"D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"%!=71H.CI?8VAE8VM"<F]W
M<V5R4W1R:6YG*"DI('L*("`@("`@("`@("`@("`@("`@("!!=71H.CI?<V5T
M075T:$5R<F]R*$%55$A?4D5!4T].7T)23U=315(I.PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%1R
M>2!T<F%N<W!A<F5N="!A=71H96YT:6-A=&EO;B!N;W<N"B`@("`@("`@)&%U
M=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1'3$]"04Q36R=C;VYF)UU;)V%U=&@G
M75LG9')I=F5R)UTI.PH@("`@("`@(&EF("@D875T:"T^:&%S0V%P86)I;&ET
M>2@G=')A;G-P87)E;G0G*2`F)@H@("`@("`@("`@("`D875T:"T^=')A;G-P
M87)E;G0H*2D@>PH@("`@("`@("`@("!R971U<FX@075T:#HZ:7-!=71H96YT
M:6-A=&5D*"1R96%L;2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT
M;'D@;&]G9V5D(&EN('5S97(L(&EF('1H97)E(&ES(&]N92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E<DED(&]F('1H92!C=7)R96YT
M('5S97(L(&]R(&9A;'-E(&EF(&YO('5S97(@:7,*("`@("`J("`@("`@("`@
M("`@("`@(&QO9V=E9"!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T075T
M:"@I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG7U]A=71H
M)UTI*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)%]315-324].6R=?7V%U
M=&@G75LG875T:&5N=&EC871E9"==*2`F)@H@("`@("`@("`@("`@("`@(65M
M<'1Y*"1?4T534TE/3ELG7U]A=71H)UU;)W5S97))9"==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1?4T534TE/3ELG7U]A=71H)UU;)W5S97))9"==
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=VAE=&AE<B!T:&4@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!R97%U97-T960@82!P87-S=V]R9"!C
M:&%N9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N(%=H971H97(@
M=&AE(&)A8VME;F0@<F5Q=65S=&5D(&$@<&%S<W=O<F0@8VAA;F=E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<U!A<W-W;W)D0VAA;F=E4F5Q=65S=&5D*"D*
M("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=?7V%U=&@G72D@
M)B8*("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG7U]A=71H)UU;)V%U
M=&AE;G1I8V%T960G72D@)B8*("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/
M3ELG7U]A=71H)UU;)V-H86YG95)E<75E<W1E9"==*2D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<F5N=&QY
M(&QO9V=E9"UI;B!U<V5R('=I=&AO=70@86YY(&1O;6%I;B!I;F9O<FUA=&EO
M;@H@("`@("H@*&4N9RXL(&)O8D!E>&%M<&QE+F-O;2!W;W5L9"!B92!R971U
M<FYE9"!A<R`G8F]B)RDN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5&AE('5S97(@240@;V8@=&AE(&-U<G)E;G0@=7-E<BP@;W(@9F%L<V4@:68@
M;F\@=7-E<@H@("`@("H@("`@("`@("`@("`@("`@:7,@;&]G9V5D(&EN+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971"87)E075T:"@I"B`@("!["B`@("`@
M("`@)'5S97(@/2!!=71H.CIG971!=71H*"D["B`@("`@("`@:68@*"1U<V5R
M*2!["B`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)'5S97(L("=`)RD["B`@
M("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@)'5S97(@/2!S=6)S='(H)'5S97(L(#`L("1P;W,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97(["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D;VUA:6X@;V8@8W5R<F5N=&QY
M(&QO9V=E9"UI;B!U<V5R("AE+F<N+"!B;V)`97AA;7!L92YC;VT*("`@("`J
M('=O=6QD(&)E(')E='5R;F5D(&%S("=E>&%M<&QE+F-O;2<I+@H@("`@("H*
M("`@("`J($!S:6YC92!(;W)D92`S+C`N-@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!D;VUA:6X@<W5F9FEX(&]F('1H92!C=7)R96YT('5S
M97(L(&]R(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!=71H1&]M
M86EN*"D*("`@('L*("`@("`@("!I9B`H)'5S97(@/2!!=71H.CIG971!=71H
M*"DI('L*("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D=7-E<BP@)T`G*3L*
M("`@("`@("`@("`@:68@*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@<W5B<W1R*"1U<V5R+"`D<&]S("L@,2D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75E<W1E9"!C<F5D96YT
M:6%L(&9O<B!T:&4@8W5R<F5N=&QY(&QO9V=E9"!I;B!U<V5R+"!I9@H@("`@
M("H@<')E<V5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<F5D
M96YT:6%L("!4:&4@8W)E9&5N=&EA;"!T;R!R971R:65V92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5Q=65S=&5D(&-R961E;G1I86PL
M(&]R(&9A;'-E(&EF(&YO('5S97(@:7,*("`@("`J("`@("`@("`@("`@("`@
M(&QO9V=E9"!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W)E9&5N=&EA
M;"@D8W)E9&5N=&EA;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1?4T53
M4TE/3ELG7U]A=71H)UTI("8F"B`@("`@("`@("`@("%E;7!T>2@D7U-%4U-)
M3TY;)U]?875T:"==6R=A=71H96YT:6-A=&5D)UTI*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O4V5C<F5T+G!H<"<["B`@("`@("`@("`@
M("1C<F5D96YT:6%L<R`]($!U;G-E<FEA;&EZ92A396-R970Z.G)E860H4V5C
M<F5T.CIG971+97DH)V%U=&@G*2P@)%]315-324].6R=?7V%U=&@G75LG8W)E
M9&5N=&EA;',G72DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A<G)A>2@D
M8W)E9&5N=&EA;',I("8F"B`@("`@("`@("`@(&ES<V5T*"1C<F5D96YT:6%L
M<ULD8W)E9&5N=&EA;%TI*2!["B`@("`@("`@("`@(')E='5R;B`D8W)E9&5N
M=&EA;'-;)&-R961E;G1I86Q=.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('1H92!R97%U97-T960@8W)E9&5N=&EA;"!F;W(@=&AE(&-U
M<G)E;G1L>2!L;V=G960@:6X@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C<F5D96YT:6%L("!4:&4@8W)E9&5N=&EA;"!T;R!S970N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@("`@("!4:&4@=F%L=64@=&\@
M<V5T('1H92!C<F5D96YT:6%L('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971#<F5D96YT:6%L*"1C<F5D96YT:6%L+"`D=F%L=64I"B`@("!["B`@("`@
M("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)U]?875T:"==*2`F)@H@("`@("`@
M("`@("`A96UP='DH)%]315-324].6R=?7V%U=&@G75LG875T:&5N=&EC871E
M9"==*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E8W)E
M="YP:'`G.PH@("`@("`@("`@("`D8W)E9&5N=&EA;',@/2!`=6YS97)I86QI
M>F4H4V5C<F5T.CIR96%D*%-E8W)E=#HZ9V5T2V5Y*"=A=71H)RDL("1?4T53
M4TE/3ELG7U]A=71H)UU;)V-R961E;G1I86QS)UTI*3L*("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1C<F5D96YT:6%L<RDI('L*("`@("`@("`@("`@("`@
M("1C<F5D96YT:6%L<ULD8W)E9&5N=&EA;%T@/2`D=F%L=64["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8W)E9&5N=&EA;',@/2!A
M<G)A>2@D8W)E9&5N=&EA;"`]/B`D=F%L=64I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1?4T534TE/3ELG7U]A=71H)UU;)V-R961E;G1I86QS)UT@
M/2!396-R970Z.G=R:71E*%-E8W)E=#HZ9V5T2V5Y*"=A=71H)RDL('-E<FEA
M;&EZ92@D8W)E9&5N=&EA;',I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S(&$@=F%R:6%B;&4@:6X@=&AE('-E<W-I;VX@<V%Y:6YG
M('1H870@875T:&]R:7IA=&EO;B!H87,@<W5C8V5E9&5D+`H@("`@("H@;F]T
M92!W:&EC:"!U<V5R260@=V%S(&%U=&AO<FEZ960L(&%N9"!N;W1E('=H96X@
M=&AE(&QO9VEN('1O;VL@<&QA8V4N"B`@("`@*@H@("`@("H@268@82!U<V5R
M(&YA;64@:&]O:R!W87,@9&5F:6YE9"!I;B!T:&4@8V]N9FEG=7)A=&EO;BP@
M:70@9V5T<R!A<'!L:65D"B`@("`@*B!T;R!T:&4@=7-E<DED(&%T('1H:7,@
M<&]I;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@
M("`@("`@("`@5&AE('5S97))9"!W:&\@:&%S(&)E96X@875T:&]R:7IE9"X*
M("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@("`@("`@(%1H92!C
M<F5D96YT:6%L<R!O9B!T:&4@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@
M)')E86QM("`@("`@("`@("`@(%1H92!A=71H96YT:6-A=&EO;B!R96%L;2!T
M;R!U<V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8VAA;F=E4F5Q=65S=&5D
M("!7:&5T:&5R('1O(')E<75E<W0@=&AA="!T:&4@=7-E<B!C:&%N9V4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H96ER('!A
M<W-W;W)D+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971!=71H*"1U<V5R260L
M("1C<F5D96YT:6%L<RP@)')E86QM(#T@;G5L;"P@)&-H86YG95)E<75E<W1E
M9"`](&9A;'-E*0H@("`@>PH@("`@("`@("1U<V5R260@/2!T<FEM*"1U<V5R
M260I.PH@("`@("`@("1U<V5R260@/2!!=71H.CIA9&1(;V]K*"1U<V5R260I
M.PH*("`@("`@("`O*B!)9B!W92=R92!A;')E861Y('-E="!W:71H('1H:7,@
M=7-E<DED+"!D;VXG="!C;VYT:6YU92X@*B\*("`@("`@("!I9B`H:7-S970H
M)%]315-324].6R=?7V%U=&@G75LG=7-E<DED)UTI("8F"B`@("`@("`@("`@
M("1?4T534TE/3ELG7U]A=71H)UU;)W5S97))9"==(#T]("1U<V5R260I('L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@0VQE
M87(@86YY(&5X:7-T:6YG(&EN9F\N("HO"B`@("`@("`@)'1H:7,M/F-L96%R
M075T:"@D<F5A;&TI.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E
M8W)E="YP:'`G.PH@("`@("`@("1C<F5D96YT:6%L<R`](%-E8W)E=#HZ=W)I
M=&4H4V5C<F5T.CIG971+97DH)V%U=&@G*2P@<V5R:6%L:7IE*"1C<F5D96YT
M:6%L<RDI.PH*("`@("`@("!I9B`H(65M<'1Y*"1R96%L;2DI('L*("`@("`@
M("`@("`@)'5S97))9"`N/2`G0"<@+B`D<F5A;&T["B`@("`@("`@?0H*("`@
M("`@("`D7U-%4U-)3TY;)U]?875T:"==(#T@87)R87DH"B`@("`@("`@("`@
M("=A=71H96YT:6-A=&5D)R`]/B!T<G5E+`H@("`@("`@("`@("`G=7-E<DED
M)R`]/B`D=7-E<DED+`H@("`@("`@("`@("`G8W)E9&5N=&EA;',G(#T^("1C
M<F5D96YT:6%L<RP*("`@("`@("`@("`@)W)E86QM)R`]/B`D<F5A;&TL"B`@
M("`@("`@("`@("=T:6UE<W1A;7`G(#T^('1I;64H*2P*("`@("`@("`@("`@
M)W)E;6]T95]A9&1R)R`]/B!I<W-E="@D7U-%4E9%4ELG4D5-3U1%7T%$1%(G
M72D@/R`D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72`Z(&YU;&PL"B`@("`@("`@
M("`@("=B<F]W<V5R)R`]/B`D1TQ/0D%,4ULG8G)O=W-E<B==+3YG971!9V5N
M=%-T<FEN9R@I+`H@("`@("`@("`@("`G8VAA;F=E4F5Q=65S=&5D)R`]/B`D
M8VAA;F=E4F5Q=65S=&5D"B`@("`@("`@*3L*"B`@("`@("`@+RH@4F5L;V%D
M('!R969E<F5N8V5S(&9O<B!T:&4@;F5W('5S97(N("HO"B`@("`@("`@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/FQO8610<F5F<R@I.PH@("`@("`@($Y,4SHZ
M<V5T3&%N9R@D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)VQA;F=U86=E
M)RDI.PH*("`@("`@("`O*B!&971C:"!T:&4@=7-E<B=S(&QA<W0@;&]G:6X@
M=&EM92X@*B\*("`@("`@("`D;VQD7VQO9VEN(#T@0'5N<V5R:6%L:7IE*"1'
M3$]"04Q36R=P<F5F<R==+3YG971686QU92@G;&%S=%]L;V=I;B<I*3L*"B`@
M("`@("`@+RH@1&ES<&QA>2!I="P@:68@=V4@:&%V92!A(&YO=&EF:6-A=&EO
M;B!O8FIE8W0@86YD('1H90H@("`@("`@("`J('-H;W=?;&%S=%]L;V=I;B!P
M<F5F97)E;F-E(&ES(&%C=&EV92X@*B\*("`@("`@("!I9B`H:7-S970H)$=,
M3T)!3%-;)VYO=&EF:6-A=&EO;B==*2`F)B`D1TQ/0D%,4ULG<')E9G,G72T^
M9V5T5F%L=64H)W-H;W=?;&%S=%]L;V=I;B<I*2!["B`@("`@("`@("`@(&EF
M("AE;7!T>2@D;VQD7VQO9VEN6R=T:6UE)UTI*2!["B`@("`@("`@("`@("`@
M("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/G!U<V@H7R@B3&%S="!L;V=I
M;CH@3F5V97(B*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;VQD7VQO9VEN6R=H
M;W-T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF
M:6-A=&EO;B==+3YP=7-H*'-P<FEN=&8H7R@B3&%S="!L;V=I;CH@)7,B*2P@
M<W1R9G1I;64H)R5C)RP@)&]L9%]L;V=I;ELG=&EM92==*2DL("=H;W)D92YM
M97-S86=E)RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"AS<')I
M;G1F*%\H(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B*2P@<W1R9G1I;64H)R5C
M)RP@)&]L9%]L;V=I;ELG=&EM92==*2P@)&]L9%]L;V=I;ELG:&]S="==*2P@
M)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@4V5T('1H92!U<V5R)W,@;&%S
M=%]L;V=I;B!I;F9O<FUA=&EO;BX*("`@("`@("`D:&]S="`](&5M<'1Y*"1?
M4T525D526R=(5%107UA?1D]25T%21$5$7T9/4B==*0H@("`@("`@("`@("`_
M("1?4T525D526R=214U/5$5?041$4B=="B`@("`@("`@("`@(#H@)%]315)6
M15);)TA45%!?6%]&3U)705)$141?1D]2)UT["B`@("`@("`@)&QA<W1?;&]G
M:6X@/2!A<G)A>2@G=&EM92<@/3X@=&EM92@I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VAO<W0G(#T^($!G971H;W-T8GEA9&1R*"1H;W-T*2D[
M"B`@("`@("`@)$=,3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=L87-T7VQO
M9VEN)RP@<V5R:6%L:7IE*"1L87-T7VQO9VEN*2D["@H@("`@("`@(&EF("@D
M8VAA;F=E4F5Q=65S=&5D*2!["B`@("`@("`@("`@("1'3$]"04Q36R=N;W1I
M9FEC871I;VXG72T^<'5S:"A?*")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YH
M87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@("`@("`@("`@("`@("`@+RH@
M02!B:70@;V8@82!K;'5D9V4N("!54DP@:7,@<V5T(&9R;VT@=&AE(&QO9VEN
M('-C<F5E;BP@8G5T"B`@("`@("`@("`@("`@("`@*B!W92!A<F5N)W0@8V]M
M<&QE=&5L>2!C97)T86EN('=E(&=O="!H97)E(&9R;VT@=&AE(&QO9VEN"B`@
M("`@("`@("`@("`@("`@*B!S8W)E96XN("!3;R!A;GD@<V-R965N('=H:6-H
M(&-A;&QS('-E=$%U=&@H*2!W:&EC:"!H87,@80H@("`@("`@("`@("`@("`@
M("H@=7)L('=I;&P@96YD('5P(&=O:6YG('1H97)E+B`@4VAO=6QD(&)E($]+
M+B`J+PH@("`@("`@("`@("`@("`@)'5R;%]P87)A;2`](%5T:6PZ.F=E=$9O
M<FU$871A*"=U<FPG*3L*"B`@("`@("`@("`@("`@("!I9B`H)'5R;%]P87)A
M;2D@>PH@("`@("`@("`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*%5T
M:6PZ.G)E;6]V95!A<F%M971E<B@D=7)L7W!A<F%M+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S97-S:6]N7VYA;64H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=')U92D["B`@("`@("`@("`@("`@("`@("`@)')E='5R
M;E]T;R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<O
M:6YD97@N<&AP)SL*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7W1O(#T@
M571I;#HZ861D4&%R86UE=&5R*"1R971U<FY?=&\L("=U<FPG+"`D=7)L*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)')E='5R;E]T;R`]($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G=V5B<F]O="<L("=H;W)D92<I"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)R]I;F1E>"YP:'`G*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`G*3L*("`@("`@("`@
M("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W)E
M='5R;E]T;R<@/3X@)')E='5R;E]T;RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&9A;'-E*3L*"B`@("`@("`@
M("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@
M("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0VQE87)S(&%N>2!A=71H96YT:6-A=&EO;B!T;VME
M;G,@:6X@=&AE(&-U<G)E;G0@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1R96%L;2`@5&AE(&%U=&AE;G1I8V%T:6]N(')E86QM('1O
M(&-L96%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A<D%U=&@H)')E86QM
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1R96%L;2D@)B8@
M:7-S970H)%]315-324].6R=?7V%U=&@G75LD<F5A;&U=*2D@>PH@("`@("`@
M("`@("`D7U-%4U-)3TY;)U]?875T:"==6R1R96%L;5T@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`D7U-%4U-)3TY;)U]?875T:"==6R1R96%L;5U;)V%U=&AE
M;G1I8V%T960G72`](&9A;'-E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D
M7U-%4U-)3TY;)U]?875T:"==*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;
M)U]?875T:"==(#T@87)R87DH*3L*("`@("`@("`@("`@)%]315-324].6R=?
M7V%U=&@G75LG875T:&5N=&EC871E9"==(#T@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`O*B!296UO=F4@=&AE('5S97(G<R!C86-H960@<')E9F5R96YC
M97,@:68@=&AE>2!A<F4@<')E<V5N="X@*B\*("`@("`@("!I9B`H:7-S970H
M)$=,3T)!3%-;)W)E9VES=')Y)UTI*2!["B`@("`@("`@("`@("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YU;FQO8610<F5F<R@I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($ES('1H92!C=7)R96YT('5S97(@86X@861M:6YI
M<W1R871O<C\*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P97)M:7-S
M:6]N("!!;&QO=R!U<V5R<R!W:71H('1H:7,@<&5R;6ES<VEO;B!A9&UI;B!A
M8V-E<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN('1H
M92!C=7)R96YT(&-O;G1E>'0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R
M;6QE=F5L("!4:&4@;&5V96P@;V8@<&5R;6ES<VEO;G,@=&\@8VAE8VL@9F]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H4$5235-?141)
M5"P@4$5235-?1$5,151%+"!E=&,I+B!$969A=6QT<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&\@4$5235-?141)5"X*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97(@("`@("`@(%1H92!U<V5R('1O(&-H96-K+B!$
M969A=6QT<R!T;R!!=71H.CIG971!=71H*"DN"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&ES(&ES(&%N(&%D;6EN
M('5S97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES061M:6XH)'!E<FUI<W-I
M;VX@/2!N=6QL+"`D<&5R;6QE=F5L(#T@;G5L;"P@)'5S97(@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*"1U<V5R
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T
M:"@I.PH@("`@("`@('T*"B`@("`@("`@:68@*$!I<U]A<G)A>2@D8V]N9ELG
M875T:"==6R=A9&UI;G,G72DI('L*("`@("`@("`@("`@:68@*"1U<V5R("8F
M(&EN7V%R<F%Y*"1U<V5R+"`D8V]N9ELG875T:"==6R=A9&UI;G,G72DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH)'!E<FUI<W-I;VXI*2![
M"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1P97)M;&5V96PI*2!["B`@("`@
M("`@("`@("`@("`D<&5R;6QE=F5L(#T@4$5235-?141)5#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W!E<FUS)UTM/FAA
M<U!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<V5R+"`D<&5R;6QE=F5L*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M*BH*("`@("`J($%P<&QI97,@82!H;V]K(&1E9FEN960@8GD@=&AE(&9U;F-T
M:6]N(%]U<V5R;F%M95]H;V]K7V9R;VUB86-K96YD*"D@=&\*("`@("`J('1H
M92!G:79E;B!U<V5R(&YA;64@:68@=&AI<R!F=6YC=&EO;B!E>&ES=',@86YD
M('5S97(@:&]O:W,@87)E(&5N86)L960N"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@<VAO=6QD(&)E(&-A;&QE9"!I9B!A(&)A8VME;F0G<R!U<V5R(&YA
M;64@;F5E9',@=&\@8F4*("`@("`J(&-O;G9E<G1E9"!T;R!A("AU;FEQ=64I
M($AO<F1E('5S97(@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R260@(%1H92!O<FEG:6YA;"!U<V5R(&YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!U<V5R(&YA;64@=VET:"!T:&4@:&]O
M:R!A<'!L:65D('1O(&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1(;V]K
M*"1U<V5R260I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@
M("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=U<V5R;F%M92==*2D@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O8V]N9FEG
M+VAO;VMS+G!H<"<["B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H
M)U]U<V5R;F%M95]H;V]K7V9R;VUB86-K96YD)RDI('L*("`@("`@("`@("`@
M("`@("1U<V5R260@/2!C86QL7W5S97)?9G5N8R@G7W5S97)N86UE7VAO;VM?
M9G)O;6)A8VME;F0G+"`D=7-E<DED*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1U<V5R260["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!<'!L:65S(&$@:&]O:R!D969I;F5D(&)Y('1H92!F=6YC=&EO;B!?
M=7-E<FYA;65?:&]O:U]T;V)A8VME;F0H*2!T;PH@("`@("H@=&AE(&=I=F5N
M('5S97(@;F%M92!I9B!T:&ES(&9U;F-T:6]N(&5X:7-T<R!A;F0@=7-E<B!H
M;V]K<R!A<F4@96YA8FQE9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!S
M:&]U;&0@8F4@8V%L;&5D(&EF(&$@2&]R9&4@=7-E<B!N86UE(&YE961S('1O
M(&)E(&-O;G9E<G1E9`H@("`@("H@=&\@82!B86-K96YD)W,@=7-E<B!N86UE
M(&]R(&1I<W!L87EE9"!T;R!T:&4@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R260@(%1H92!(;W)D92!U<V5R(&YA;64N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U<V5R(&YA;64@=VET:"!T
M:&4@:&]O:R!A<'!L:65D('1O(&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96UO=F5(;V]K*"1U<V5R260I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF
M.PH*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=U<V5R;F%M
M92==*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("`@("`@("`@(&EF("AF=6YC=&EO
M;E]E>&ES=',H)U]U<V5R;F%M95]H;V]K7W1O8F%C:V5N9"<I*2!["B`@("`@
M("`@("`@("`@("`D=7-E<DED(#T@8V%L;%]U<V5R7V9U;F,H)U]U<V5R;F%M
M95]H;V]K7W1O8F%C:V5N9"<L("1U<V5R260I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97))9#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%%U97)I97,@=&AE(&-U<G)E;G0@075T:"!O8FIE8W0@=&\@
M9FEN9"!O=70@:68@:70@<W5P<&]R=',@=&AE(&=I=F5N"B`@("`@*B!C87!A
M8FEL:71Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A<&%B:6QI
M='D@(%1H92!C87!A8FEL:71Y('1O('1E<W0@9F]R+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-A<&%B:6QI
M='D@:7,@<W5P<&]R=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-#87!A
M8FEL:71Y*"1C87!A8FEL:71Y*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP
M='DH)'1H:7,M/F-A<&%B:6QI=&EE<ULD8V%P86)I;&ET>5TI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@55))(&]F('1H92!L;V=I;B!S
M8W)E96X@9F]R('1H92!C=7)R96YT(&%U=&AE;G1I8V%T:6]N"B`@("`@*B!M
M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@
M87!P;&EC871I;VX@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L
M("!4:&4@55),('1O(')E9&ER96-T('1O(&%F=&5R(&QO9VEN+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]G:6X@<V-R965N(%5222X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]G:6Y38W)E96XH)&%P<"`]("=H
M;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8[
M"B`@("`@("`@)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H
M)UU;)V1R:79E<B==*3L*("`@("`@("!R971U<FX@)&%U=&@M/E]G971,;V=I
M;E-C<F5E;B@D87!P+"`D=7)L*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&YA;65D('!A<F%M971E<B!F;W(@=&AE(&-U<G)E;G0@875T
M:"!D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86T@
M(%1H92!P87)A;65T97(@=&\@9F5T8V@N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!P87)A;65T97(G<R!V86QU92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4&%R86TH)'!A<F%M*0H@("`@>PH@("`@("`@(')E='5R
M;B!I<W-E="@D=&AI<RT^7W!A<F%M<ULD<&%R86U=*2`_("1T:&ES+3Y?<&%R
M86US6R1P87)A;5T@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@;F%M92!O9B!T:&4@875T:&5N=&EC871I;VX@<')O=FED97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!5<V5D(&)Y
M(')E8W5R<VEV92!C86QL<R!W:&5N('5N=&%N9VQI;F<@8V]M<&]S:71E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&%U=&@N"B`@("`@*B!`<&%R
M86T@87)R87D@("1P87)A;7,@(%5S960@8GD@<F5C=7)S:79E(&-A;&QS('=H
M96X@=6YT86YG;&EN9R!C;VUP;W-I=&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@875T:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&YA;64@;V8@=&AE(&1R:79E<B!C=7)R96YT;'D@<')O=FED:6YG"B`@
M("`@*B`@("`@("`@("`@("`@("`@875T:&5N=&EC871I;VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!R;W9I9&5R*"1D<FEV97(@/2!N=6QL+"`D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@(&EF("AI<U]N=6QL*"1D<FEV97(I*2!["B`@("`@("`@("`@("1D<FEV
M97(@/2`D8V]N9ELG875T:"==6R=D<FEV97(G73L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'!A<F%M
M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V%U=&@G+`H@("`@("`@("`@
M("`@("`@:7-?87)R87DH)&1R:79E<BD@/R`D9')I=F5R6S%=(#H@)&1R:79E
M<BD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1R:79E<B`]/2`G87!P;&EC
M871I;VXG*2!["B`@("`@("`@("`@(')E='5R;B!I<W-E="@D<&%R86US6R=A
M<'`G72D@/R`D<&%R86US6R=A<'`G72`Z("=A<'!L:6-A=&EO;B<["B`@("`@
M("`@?2!E;'-E:68@*"1D<FEV97(@/3T@)V-O;7!O<VET92<I('L*("`@("`@
M("`@("`@:68@*"@D;&]G:6Y?9')I=F5R(#T@075T:#HZ7V=E=$1R:79E<D)Y
M4&%R86TH)VQO9VEN<V-R965N7W-W:71C:"<L("1P87)A;7,I*2`F)@H@("`@
M("`@("`@("`@("`@(65M<'1Y*"1P87)A;7-;)V1R:79E<G,G75LD;&]G:6Y?
M9')I=F5R72DI('L*("`@("`@("`@("`@("`@(')E='5R;B!!=71H.CIG9710
M<F]V:61E<B@D<&%R86US6R=D<FEV97)S)UU;)&QO9VEN7V1R:79E<EU;)V1R
M:79E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&ES<V5T*"1P87)A;7-;)V1R:79E<G,G75LD;&]G:6Y?9')I=F5R75LG
M<&%R86US)UTI(#\@)'!A<F%M<ULG9')I=F5R<R==6R1L;V=I;E]D<FEV97)=
M6R=P87)A;7,G72`Z(&YU;&PI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B`G8V]M<&]S:71E)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)&1R:79E<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!L;V=O=70@<F5A<V]N+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG($]N92!O9B!T:&4@;&]G;W5T(')E87-O;G,@
M*'-E92!T:&4@05542%],3T=/551?*@H@("`@("H@("`@("`@("`@("`@("`@
M8V]N<W1A;G1S(&9O<B!T:&4@=F%L:60@<F5A<V]N<RDN("!2971U<FYS(&YU
M;&P@:68@=&AE<F4*("`@("`J("`@("`@("`@("`@("`@(&ES(&YO(&QO9V]U
M="!R96%S;VX@<')E<V5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]G
M;W5T4F5A<V]N*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;
M)U]?875T:&5R<F]R)UU;)W1Y<&4G72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1'3$]"04Q36R=?7V%U=&AE<G)O<B==6R=T>7!E)UT["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%5T:6PZ.F=E=$9O<FU$871A*$%5
M5$A?4D5!4T].7U!!4D%-*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!S=&%T=7,@<W1R:6YG('1O('5S92!F;W(@;&]G
M;W5T(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@;&]G;W5T(')E87-O;B!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$QO9V]U=%)E87-O;E-T<FEN9R@I"B`@("!["B`@("`@("`@<W=I=&-H
M("A!=71H.CIG971,;V=O=71296%S;VXH*2D@>PH@("`@("`@(&-A<V4@0554
M2%]214%33TY?4T534TE/3CH*("`@("`@("`@("`@)'1E>'0@/2!S<')I;G1F
M*%\H(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+B(I+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RDI
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!!551(7U)%05-/
M3E]315-324].25`Z"B`@("`@("`@("`@("1T97AT(#T@<W!R:6YT9BA?*")9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(BDL("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)VYA;64G*2D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E($%55$A?4D5!4T].7T)23U=315(Z"B`@("`@("`@("`@
M("1T97AT(#T@<W!R:6YT9BA?*")9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G
M*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($%55$A?4D5!
M4T].7TQ/1T]55#H*("`@("`@("`@("`@)'1E>'0@/2!?*")9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N(BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E($%55$A?4D5!4T].7T9!24Q%1#H*("`@("`@("`@("`@)'1E>'0@
M/2!?*"),;V=I;B!F86EL960N(BD["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E($%55$A?4D5!4T].7T)!1$Q/1TE..@H@("`@("`@("`@("`D
M=&5X="`](%\H(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(BD["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($%55$A?4D5!4T].7T584$E2
M140Z"B`@("`@("`@("`@("1T97AT(#T@7R@B66]U<B!L;V=I;B!H87,@97AP
M:7)E9"XB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@0554
M2%]214%33TY?34534T%'13H*("`@("`@("`@("`@:68@*&ES<V5T*"1'3$]"
M04Q36R=?7V%U=&AE<G)O<B==6R=M<V<G72DI('L*("`@("`@("`@("`@("`@
M("1T97AT(#T@)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;)VUS9R==.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1E>'0@/2!5=&EL
M.CIG971&;W)M1&%T82A!551(7U)%05-/3E]-4T=?4$%204TI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`D=&5X="`]("<G.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E;F5R871E<R!T:&4@8V]R<F5C="!P87)A;65T97)S('1O('!A
M<W,@=&\@=&AE(&=I=F5N(&QO9V]U="!54DPN"B`@("`@*@H@("`@("H@268@
M;F\@<F5A<V]N+VUS9R!I<R!P87-S960@:6XL('5S92!T:&4@8W5R<F5N="!G
M;&]B86P@875T:&5N=&EC871I;VX*("`@("`J(&5R<F]R(&UE<W-A9V4N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("!4:&4@55),('1O
M(')E9&ER96-T('1O+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5A<V]N("!4
M:&4@<F5A<V]N(&9O<B!L;V=O=70N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M<V<@("`@($EF(')E87-O;B!I<R!!551(7U)%05-/3E]-15-304=%+"!T:&4@
M;65S<V%G92!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!D:7-P
M;&%Y('1O('1H92!U<V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1,;V=O
M=71087)A;65T97)S*"1U<FPL("1R96%S;VX@/2!N=6QL+"`D;7-G(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D<F5A<V]N*2D@>PH@("`@
M("`@("`@("`D<F5A<V]N(#T@075T:#HZ9V5T3&]G;W5T4F5A<V]N*"D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)')E87-O;BD@>PH@("`@("`@("`@("`D
M=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL($%55$A?4D5!4T].7U!!
M4D%-+"`D<F5A<V]N+"!F86QS92D["B`@("`@("`@("`@(&EF("@D<F5A<V]N
M(#T]($%55$A?4D5!4T].7TU%4U-!1T4I('L*("`@("`@("`@("`@("`@(&EF
M("AI<U]N=6QL*"1M<V<I*2!["B`@("`@("`@("`@("`@("`@("`@)&US9R`]
M($%U=&@Z.F=E=$QO9V]U=%)E87-O;E-T<FEN9R@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E
M<B@D=7)L+"!!551(7U)%05-/3E]-4T=?4$%204TL("1M<V<L(&9A;'-E*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<FP[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!54DD@;V8@=&AE
M(&QO9VEN('-C<F5E;B!F;W(@=&AI<R!A=71H96YT:6-A=&EO;B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC871I;VX@=&\@=7-E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("!4:&4@55),('1O(')E9&ER96-T
M('1O(&%F=&5R(&QO9VEN+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;&]G:6X@<V-R965N(%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$QO9VEN4V-R965N*"1A<'`@/2`G:&]R9&4G+"`D=7)L(#T@)R<I"B`@
M("!["B`@("`@("`@)&QO9VEN(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)&%P<"D@+B`G+VQO9VEN+G!H<"<L
M('1R=64I.PH@("`@("`@(&EF("@A96UP='DH)'5R;"DI('L*("`@("`@("`@
M("`@)&QO9VEN(#T@571I;#HZ861D4&%R86UE=&5R*"1L;V=I;BP@)W5R;"<L
M("1U<FPI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&QO9VEN.PH@("`@
M?0H*("`@("\J*@H@("`@("H@075T:&5N=&EC871I;VX@<W1U8BX*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@($9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E
M*"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!E<G)O<B!M97-S86=E(&9O<B!A;B!I;G9A;&ED
M(&%U=&AE;G1I8V%T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!T>7!E
M(&]F(&5R<F]R("A!551(7U)%05-/3B!C;VYS=&%N="DN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M<V<@("!4:&4@97)R;W(@;65S<V%G92]R96%S;VX@9F]R
M(&EN=F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&%U=&AE;G1I
M8V%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T075T:$5R<F]R*"1T
M>7!E+"`D;7-G(#T@;G5L;"D*("`@('L*("`@("`@("`D1TQ/0D%,4ULG7U]A
M=71H97)R;W(G72`](&%R<F%Y*"D["B`@("`@("`@)$=,3T)!3%-;)U]?875T
M:&5R<F]R)UU;)W1Y<&4G72`]("1T>7!E.PH@("`@("`@("1'3$]"04Q36R=?
M7V%U=&AE<G)O<B==6R=M<V<G72`]("1M<V<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!E<G)O<B!T>7!E(&9O<B!A;B!I;G9A;&ED(&%U
M=&AE;G1I8V%T:6]N(&]R(&9A;'-E(&]N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T075T:$5R<F]R*"D*("`@('L*("`@("`@("!I9B`H:7-S
M970H)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;)W1Y<&4G72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1'3$]"04Q36R=?7V%U=&AE<G)O<B==6R=T>7!E)UT[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!A<'!R;W!R:6%T92!A=71H96YT:6-A
M=&EO;B!D<FEV97(L(&EF(&%N>2P@<V5L96-T:6YG(&)Y('1H90H@("`@("H@
M<W!E8VEF:65D('!A<F%M971E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@
M("`@(%1H92!P87)A;65T97(@;F%M92X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("`@("`@("`@5&AE('!A<F%M971E<B!L:7-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9')I=F5R<&%R86US("!!(&QI<W0@;V8@<&%R86UE=&5R
M<R!T;R!P87-S('1O('1H92!D<FEV97(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971$<FEV97)">5!A<F%M*"1N86UE+"`D<&%R86US+"`D9')I=F5R<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULD;F%M95TI("8F"B`@("`@("`@("`@(&9U;F-T:6]N7V5X:7-T<R@D<&%R
M86US6R1N86UE72DI('L*("`@("`@("`@("`@<F5T=7)N(&-A;&Q?=7-E<E]F
M=6YC7V%R<F%Y*"1P87)A;7-;)&YA;65=+"`D9')I=F5R<&%R86US*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&5R9F]R;7,@8VAE8VL@;VX@<V5S<VEO;B!T;R!S964@:68@25`@
M061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4*("`@("`J(&QA<W0@86-C
M97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!)4"!!9&1R97-S(&ES('1H
M92!S86UE("AO<B!T:&4@8VAE8VL@:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@9&ES86)L960I+"!F86QS92!I9B!T:&4@861D<F5S<R!H87,@8VAA;F=E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K4V5S<VEO;DE0*"D*("`@
M('L*("`@("`@("!R971U<FX@*&5M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)V%U
M=&@G75LG8VAE8VMI<"==*2!\?`H@("`@("`@("`@("`@("`@*&ES<V5T*"1?
M4T534TE/3ELG7U]A=71H)UU;)W)E;6]T95]A9&1R)UTI("8F("1?4T534TE/
M3ELG7U]A=71H)UU;)W)E;6]T95]A9&1R)UT@/3T@)%]315)615);)U)%34]4
M15]!1$12)UTI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O<FUS(&-H
M96-K(&]N('-E<W-I;VX@=&\@<V5E(&EF(&)R;W=S97(@<W1R:6YG(&AA<R!C
M:&%N9V5D('-I;F-E"B`@("`@*B!T:&4@;&%S="!A8V-E<W,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF(&)R;W=S97(@<W1R:6YG(&ES('1H92!S86UE+"!F
M86QS92!I9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@<W1R:6YG(&AA
M<R!C:&%N9V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM"<F]W<V5R
M4W1R:6YG*"D*("`@('L*("`@("`@("!R971U<FX@*&5M<'1Y*"1'3$]"04Q3
M6R=C;VYF)UU;)V%U=&@G75LG8VAE8VMB<F]W<V5R)UTI('Q\"B`@("`@("`@
M("`@("`@("`D7U-%4U-)3TY;)U]?875T:"==6R=B<F]W<V5R)UT@/3T@)$=,
M3T)!3%-;)V)R;W=S97(G72T^9V5T06=E;G13=')I;F<H*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T<R!T;R!A;&QO=V5D(#8T(&-H87)A8W1E
M<G,@9F]R($%04DU$-2!P87-S=V]R9',N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'9A;'5E
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]U;G0*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@)'9A;'5E(&-O;G9E<G1E9"!T;R!T:&4@-C0@340U
M(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T;T%04DU$-2@D
M=F%L=64L("1C;W5N="D*("`@('L*("`@("`@("`O*B`V-"!C:&%R86-T97)S
M('1H870@87)E('9A;&ED(&9O<B!!4%)-1#4@<&%S<W=O<F1S+B`J+PH@("`@
M("`@("1!4%)-1#4@/2`G+B\P,3(S-#4V-S@Y04)#1$5&1TA)2DM,34Y/4%%2
M4U155E=865IA8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>B<["@H@("`@("`@
M("1A<')M9#4@/2`G)SL*("`@("`@("`D8V]U;G0@/2!A8G,H)&-O=6YT*3L*
M("`@("`@("!W:&EL92`H+2TD8V]U;G0I('L*("`@("`@("`@("`@)&%P<FUD
M-2`N/2`D05!2340U6R1V86QU92`F(#!X,V9=.PH@("`@("`@("`@("`D=F%L
M=64@/CX](#8["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D87!R;60U.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@:&5X861E8VEM86P@<W1R
M:6YG('1O(&)I;F%R>2!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE>"`@2&5X(&1A
M=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($)I;F%R>2!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8FEN*"1H97@I"B`@("!["B`@("`@
M("`@)&)I;B`]("<G.PH@("`@("`@("1L96YG=&@@/2!S=')L96XH)&AE>"D[
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QE;F=T:#L@)&D@*ST@,BD@
M>PH@("`@("`@("`@("`D=&UP(#T@<W-C86YF*'-U8G-T<B@D:&5X+"`D:2P@
M,BDL("<E>"<I.PH@("`@("`@("`@("`D8FEN("X](&-H<BAA<G)A>5]S:&EF
M="@D=&UP*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8FEN.PH@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E
M=&4@075T:"!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T
M92!!=71H('-U8F-L87-S('1O(')E='5R;BX@5&AI<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E
M<B`H)&1R:79E<BDN(%1H92!C;V1E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF("1D<FEV97(@:7,@
M86X@87)R87DL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AE;B!W
M92!W:6QL(&QO;VL@:6X@)&1R:79E<ELP72]L:6(O075T:"\@9F]R('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('-U8F-L87-S(&EM<&QE;65N
M=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L
M(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D
M+@H@("`@("H*("`@("`J($!R971U<FX@075T:"`@5&AE(&YE=VQY(&-R96%T
M960@8V]N8W)E=&4@075T:"!I;G-T86YC92P@;W(@9F%L<V4@;VX@86X*("`@
M("`J("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("`D87!P
M(#T@)&1R:79E<ELP73L*("`@("`@("`@("`@)&1R:79E<B`]("1D<FEV97);
M,5T["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R
M:79E<BD["@H@("`@("`@(&EF("AE;7!T>2@D9')I=F5R*2!\?"`H)&1R:79E
M<B`]/2`G;F]N92<I*2!["B`@("`@("`@("`@("1A=71H(#T@)FYE=R!!=71H
M*"D["B`@("`@("`@("`@(')E='5R;B`D875T:#L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A
M;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=A=71H)RP@)&1R:79E<BD[
M"B`@("`@("`@?0H*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`Q
M*3L*("`@("`@("`D:6YC;'5D95]E<G)O<B`]("<G.PH@("`@("`@(&EF("@A
M96UP='DH)&%P<"DI('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L
M:6(O075T:"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]!=71H+R<@+B`D
M9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)'!H<%]E<G)O<FUS9RDI('L*("`@("`@("`@("`@)&EN8VQU9&5?97)R;W(@
M/2`D<&AP7V5R<F]R;7-G.PH@("`@("`@('T*("`@("`@("!I;FE?<F5S=&]R
M92@G=')A8VM?97)R;W)S)RD["@H@("`@("`@("1C;&%S<R`]("=!=71H7R<@
M+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`D875T:"`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A=71H(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@G075T:"!$<FEV97(@*"<@+B`D8VQA<W,@+B`G*2!N;W0@9F]U
M;F0G("X@*"1I;F-L=61E7V5R<F]R(#\@)SH@)R`N("1I;F-L=61E7V5R<F]R
M(#H@)R<I("X@)RXG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D875T
M:#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(')E9F5R96YC92!T;R!A(&-O;F-R971E($%U=&@@:6YS=&%N8V4@8F%S960@
M;VX*("`@("`J("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@
M:6YS=&%N8V4@:68@;F\@075T:"!I;G-T86YC92!W:71H"B`@("`@*B!T:&4@
M<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@
M("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!A=71H96YT:6-A
M=&EO;B!S;W5R8V5S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT:7!L92!!=71H
M(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9!=71H.CIS:6YG
M;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@075T:"!S=6)C;&%S<R!T;R!R971U<FXN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%1H:7,@:7,@8F%S960@
M;VX@=&AE('-T;W)A9V4@9')I=F5R("@D9')I=F5R*2X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC
M;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T
M97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N($%U=&@@(%1H92!C;VYC<F5T92!!=71H(')E9F5R96YC92P@;W(@9F%L
M<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T
M;VXH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<W1A
M=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H:7-?;G5L
M;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E
M=$1R:79E<D-O;F9I9R@G875T:"<L"B`@("`@("`@("`@("`@("!I<U]A<G)A
M>2@D9')I=F5R*2`_("1D<FEV97);,5T@.B`D9')I=F5R*3L*("`@("`@("!]
M"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E
M<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("AE;7!T>2@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)D%U=&@Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TY,4RYP:'``````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`T,#,V-``Q,#0Q-S,V,C<W,P`P,3<T,#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!.
M3%,Z.B!C;&%S<R!P<F]V:61E<R!.871I=F4@3&%N9W5A9V4@4W5P<&]R="X@
M5&AI<R!I;F-L=61E<R!C;VUM;VX*("H@;65T:&]D<R!F;W(@:&%N9&QI;F<@
M;&%N9W5A9V4@9&5T96-T:6]N(&%N9"!S96QE8W1I;VXL('1I;65Z;VYE<RP@
M86YD"B`J(&AO<W1N86UE+3YC;W5N=')Y(&QO;VMU<',N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TY,4R].3%,N<&AP+'8@,2XX,BXT+C$S(#(P,#8O,#$O
M,C0@,#<Z-3`Z,C8@<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95].3%,*("HO"F-L87-S($Y,4R!["@H@("`@+RHJ"B`@("`@*B!396QE
M8W1S('1H92!M;W-T('!R969E<G)E9"!L86YG=6%G92!F;W(@=&AE(&-U<G)E
M;G0@8VQI96YT('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!S96QE8W1E9"!L86YG=6%G92!A8F)R979I871I;VXN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E;&5C="@I"B`@("!["B`@("`@("`@9VQO8F%L
M("1N;',L("1P<F5F<SL*"B`@("`@("`@)&QA;F<@/2!5=&EL.CIG971&;W)M
M1&%T82@G;F5W7VQA;F<G*3L*"B`@("`@("`@+RH@1FER<W0L(&-H96-K(&EF
M(&QA;F=U86=E('!R968@:7,@;&]C:V5D(&%N9"P@:68@<V\L('-E="!I="!T
M;R!I=',*("`@("`@("`@("!V86QU92`J+PH@("`@("`@(&EF("AI<W-E="@D
M<')E9G,I("8F("1P<F5F<RT^:7-,;V-K960H)VQA;F=U86=E)RDI('L*("`@
M("`@("`@("`@)&QA;F=U86=E(#T@)'!R969S+3YG971686QU92@G;&%N9W5A
M9V4G*3L*("`@("`@("`O*B!#:&5C:R!I9B!T:&4@=7-E<B!S96QE8W1E9"!A
M(&QA;F=U86=E(&9R;VT@=&AE(&QO9VEN('-C<F5E;B`J+PH@("`@("`@('T@
M96QS96EF("@A96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@("1L86YG=6%G
M92`]("1L86YG.PH@("`@("`@("\J($-H96-K(&EF('=E(&AA=F4@82!L86YG
M=6%G92!S970@:6X@82!C;V]K:64@*B\*("`@("`@("!](&5L<V5I9B`H:7-S
M970H)%]315-324].6R=H;W)D95]L86YG=6%G92==*2D@>PH@("`@("`@("`@
M("`D;&%N9W5A9V4@/2`D7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UT["B`@
M("`@("`@+RH@57-E('-I=&4M=VED92!D969A=6QT+"!I9B!O;F4@:7,@9&5F
M:6YE9"`J+PH@("`@("`@('T@96QS96EF("@A96UP='DH)&YL<ULG9&5F875L
M=',G75LG;&%N9W5A9V4G72DI('L*("`@("`@("`@("`@)&QA;F=U86=E(#T@
M)&YL<ULG9&5F875L=',G75LG;&%N9W5A9V4G73L*("`@("`@("`O*B!4<GD@
M8G)O=W-E<BUA8V-E<'1E9"!L86YG=6%G97,N("HO"B`@("`@("`@?2!E;'-E
M:68@*"%E;7!T>2@D7U-%4E9%4ELG2%144%]!0T-%4%1?3$%.1U5!1T4G72DI
M('L*("`@("`@("`@("`@+RH@5&AE(&)R;W=S97(@<W5P<&QI97,@82!L:7-T
M+"!S;R!R971U<FX@=&AE(&9I<G-T('9A;&ED(&]N92X@*B\*("`@("`@("`@
M("`@)&)R;W=S97)?;&%N9W,@/2!E>'!L;V1E*"<L)RP@)%]315)615);)TA4
M5%!?04-#15!47TQ!3D=504=%)UTI.PH@("`@("`@("`@("!F;W)E86-H("@D
M8G)O=W-E<E]L86YG<R!A<R`D;&%N9RD@>PH@("`@("`@("`@("`@("`@+RH@
M4W1R:7`@<75A;&ET>2!V86QU92!F;W(@;&%N9W5A9V4@*B\*("`@("`@("`@
M("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D;&%N9RP@)SLG*2D@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&QA;F<@/2!S=6)S='(H)&QA
M;F<L(#`L("1P;W,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&QA;F<@/2!.3%,Z.E]M87`H=')I;2@D;&%N9RDI.PH@("`@("`@("`@
M("`@("`@:68@*$Y,4SHZ:7-686QI9"@D;&%N9RDI('L*("`@("`@("`@("`@
M("`@("`@("`D;&%N9W5A9V4@/2`D;&%N9SL*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\J
M($EN(&-A<V4@;F\@9G5L;"!M871C:"P@<V%V92!B97-T(&=U97-S(&)A<V5D
M(&]N('!R969I>"`J+PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R
M=&EA;%]L86YG*2`F)@H@("`@("`@("`@("`@("`@("`@($Y,4SHZ:7-686QI
M9"A.3%,Z.E]M87`H<W5B<W1R*"1L86YG+"`P+"`R*2DI*2!["B`@("`@("`@
M("`@("`@("`@("`@)'!A<G1I86Q?;&%N9R`]($Y,4SHZ7VUA<"AS=6)S='(H
M)&QA;F<L(#`L(#(I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D;&%N9W5A9V4I*2![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R=&EA;%]L86YG*2D@>PH@("`@
M("`@("`@("`@("`@)&QA;F=U86=E(#T@)'!A<G1I86Q?;&%N9SL*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($YO(&1I8V4@875T
M;RUD971E8W1I;F<L(&1E9F%U;'0@=&\@55,@16YG;&ES:"X@*B\*("`@("`@
M("`@("`@("`@("1L86YG=6%G92`]("=E;E]54R<["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!B87-E;F%M92@D;&%N9W5A9V4I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;&%N9W5A9V4N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%N9R`@5&AE(&QA;F=U86=E
M(&%B8G)E=FEA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3&%N9R@D
M;&%N9R`](&YU;&PI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%
M7T)!4T4@+B`G+V-O;F9I9R]N;',N<&AP)SL*"B`@("`@("`@:68@*&5M<'1Y
M*"1L86YG*2!\?"`A3DQ3.CII<U9A;&ED*"1L86YG*2D@>PH@("`@("`@("`@
M("`D;&%N9R`]($Y,4SHZ<V5L96-T*"D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)$=,3T)!3%-;)VQA;F=U86=E)UTI*2!["B`@("`@("`@("`@
M(&EF("@D1TQ/0D%,4ULG;&%N9W5A9V4G72`]/2`D;&%N9RD@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-L96%R0V%C:&4H*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)$=,3T)!3%-;)VQA
M;F=U86=E)UT@/2`D;&%N9SL*("`@("`@("`D7U-%4U-)3TY;)VAO<F1E7VQA
M;F=U86=E)UT@/2`D;&%N9SL*"B`@("`@("`@+RH@1FER<W0@=')Y(&QA;F=U
M86=E('=I=&@@=&AE(&-U<G)E;G0@8VAA<G-E="X@*B\*("`@("`@("`D;&%N
M9U]C:&%R<V5T(#T@)&QA;F<@+B`G+B<@+B!.3%,Z.F=E=$-H87)S970H*3L*
M("`@("`@("!I9B`H)&QA;F=?8VAA<G-E="`A/2!S971L;V-A;&4H3$-?04Q,
M+"`D;&%N9U]C:&%R<V5T*2D@>PH@("`@("`@("`@("`O*B!.97AT('1R>2!L
M86YG=6%G92!W:71H(&ET<R!D969A=6QT(&-H87)S970N("HO"B`@("`@("`@
M("`@(&=L;V)A;"`D;FQS.PH@("`@("`@("`@("`D8VAA<G-E="`]("%E;7!T
M>2@D;FQS6R=C:&%R<V5T<R==6R1L86YG72D@/R`D;FQS6R=C:&%R<V5T<R==
M6R1L86YG72`Z("=)4T\M.#@U.2TQ)SL*("`@("`@("`@("`@)&QA;F=?8VAA
M<G-E="`]("1L86YG("X@)RXG("X@)&-H87)S970["B`@("`@("`@("`@($Y,
M4SHZ7V-A8VAE9$-H87)S970H,"P@)&-H87)S970I.PH@("`@("`@("`@("!I
M9B`H)&QA;F=?8VAA<G-E="`A/2!S971L;V-A;&4H3$-?04Q,+"`D;&%N9U]C
M:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@+RH@070@;&%S="!T<GD@;&%N
M9W5A9V4@<V]L96QY+B`J+PH@("`@("`@("`@("`@("`@)&QA;F=?8VAA<G-E
M="`]("1L86YG.PH@("`@("`@("`@("`@("`@<V5T;&]C86QE*$Q#7T%,3"P@
M)&QA;F=?8VAA<G-E="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@0'!U=&5N=B@G3$%.1STG("X@)&QA;F=?8VAA<G-E="D["B`@("`@("`@
M0'!U=&5N=B@G3$%.1U5!1T4])R`N("1L86YG7V-H87)S970I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@9V5T=&5X="!D;VUA:6XN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("`@("!4:&4@87!P;&EC
M871I;VX@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&1I<F5C=&]R>2`@
M5&AE(&1I<F5C=&]R>2!W:&5R92!T:&4@87!P;&EC871I;VXG<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!,0U]-15-304=%4R!D:7)E8W1O
M<GD@<F5S:61E<RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@("`@
M5&AE(&-H87)S970N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1E>'1D;VUA
M:6XH)&%P<"P@)&1I<F5C=&]R>2P@)&-H87)S970I"B`@("!["B`@("`@("`@
M8FEN9'1E>'1D;VUA:6XH)&%P<"P@)&1I<F5C=&]R>2D["B`@("`@("`@=&5X
M=&1O;6%I;B@D87!P*3L*"B`@("`@("`@+RH@5&AE(&5X:7-T96YC92!O9B!T
M:&ES(&9U;F-T:6]N(&1E<&5N9',@;VX@=&AE('!L871F;W)M+B`J+PH@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V)I;F1?=&5X=&1O;6%I;E]C;V1E
M<V5T)RDI('L*("`@("`@("`@("`@3DQ3.CI?8V%C:&5D0VAA<G-E="@P+"!B
M:6YD7W1E>'1D;VUA:6Y?8V]D97-E="@D87!P+"`D8VAA<G-E="DI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%H96%D97)S7W-E;G0H*2D@>PH@("`@("`@
M("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]H=&UL.R!C:&%R<V5T
M/2<@+B`D8VAA<G-E="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1&5T97)M:6YE<R!W:&5T:&5R('1H92!S=7!P;&EE9"!L86YG=6%G92!I
M<R!V86QI9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86YG=6%G
M92`@5&AE(&%B8G)E=FEA=&5D(&YA;64@;V8@=&AE(&QA;F=U86=E+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@;&%N9W5A
M9V4@:7,@=F%L:60L(&9A;'-E(&EF(&ET)W,@;F]T"B`@("`@*B`@("`@("`@
M("`@("`@("`@('9A;&ED(&]R('5N:VYO=VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES5F%L:60H)&QA;F=U86=E*0H@("`@>PH@("`@("`@(')E='5R;B`A
M96UP='DH)$=,3T)!3%-;)VYL<R==6R=L86YG=6%G97,G75LD;&%N9W5A9V5=
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($UA<',@;&%N9W5A9V5S('=I=&@@
M8V]M;6]N('1W;RUL971T97(@8V]D97,@*'-U8V@@87,@;FPI('1O('1H90H@
M("`@("H@9G5L;"!G971T97AT(&-O9&4@*&EN('1H:7,@8V%S92P@;FQ?3DPI
M+B!2971U<FYS('1H92!L86YG=6%G90H@("`@("H@=6YM;V1I9FEE9"!I9B!I
M="!I<VXG="!A;B!A;&EA<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86YG=6%G92`@5&AE
M(&QA;F=U86=E(&-O9&4@=&\@;6%P+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@;6%P<&5D(&QA;F=U86=E(&-O9&4N"B`@("`@*B\*"B`@
M("!F=6YC=&EO;B!?;6%P*"1L86YG=6%G92D*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*("`@("`@("`D86QI87-E
M<R`]("8D1TQ/0D%,4ULG;FQS)UU;)V%L:6%S97,G73L*"B`@("`@("`@+R\@
M5')A;G-L871E('1H92`D;&%N9W5A9V4@=&\@9V5T(&)R;V%D97(@;6%T8VAE
M<RX*("`@("`@("`O+R`H96<N(&1E+41%('-H;W5L9"!M871C:"!D95]$12D*
M("`@("`@("`D=')A;G-?;&%N9R`]('-T<E]R97!L86-E*"<M)RP@)U\G+"`D
M;&%N9W5A9V4I.PH@("`@("`@("1L86YG7W!A<G1S(#T@97AP;&]D92@G7R<L
M("1T<F%N<U]L86YG*3L*("`@("`@("`D=')A;G-?;&%N9R`](%-T<FEN9SHZ
M;&]W97(H)&QA;F=?<&%R='-;,%TI.PH@("`@("`@(&EF("AI<W-E="@D;&%N
M9U]P87)T<ULQ72DI('L*("`@("`@("`@("`@)'1R86YS7VQA;F<@+CT@)U\G
M("X@4W1R:6YG.CIU<'!E<B@D;&%N9U]P87)T<ULQ72D["B`@("`@("`@?0H*
M("`@("`@("`O+R!3964@:68@=V4@9V5T(&$@;6%T8V@@9F]R('1H:7,*("`@
M("`@("!I9B`H(65M<'1Y*"1A;&EA<V5S6R1T<F%N<U]L86YG72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1A;&EA<V5S6R1T<F%N<U]L86YG73L*("`@("`@
M("!]"@H@("`@("`@("\O($EF('=E(&=E="!T:&%T(&9A<B!D;W=N+"!T:&4@
M;&%N9W5A9V4@8V%N;F]T(&)E(&9O=6YD+@H@("`@("`@("\O(%)E='5R;B`D
M=')A;G-?;&%N9RX*("`@("`@("!R971U<FX@)'1R86YS7VQA;F<["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R<V5T(&9O<B!T:&4@
M8W5R<F5N="!L86YG=6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D;W)I9VEN86P@($EF('1R=64@<F5T=7)N<R!T:&4@;W)I9VEN86P@8VAA
M<G-E="!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=')A;G-L871I;VXL('1H92!A8W1U86QL>2!U<V5D(&]N92!O=&AE<G=I<V4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C:&%R86-T97(@
M<V5T('1H870@<VAO=6QD(&)E('5S960@=VET:"!T:&4@8W5R<F5N=`H@("`@
M("H@("`@("`@("`@("`@("`@(&QO8V%L92!S971T:6YG<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0VAA<G-E="@D;W)I9VEN86P@/2!F86QS92D*("`@
M('L*("`@("`@("!G;&]B86P@)&QA;F=U86=E+"`D;FQS.PH*("`@("`@("`O
M*B!'970@8V%C:&5D(')E<W5L=',N("HO"B`@("`@("`@)&-A8VAE2V5Y(#T@
M:6YT=F%L*"1O<FEG:6YA;"D["B`@("`@("`@)&-H87)S970@/2!.3%,Z.E]C
M86-H961#:&%R<V5T*"1C86-H94ME>2D["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("!R971U<FX@)&-H87)S970["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&]R:6=I;F%L*2!["B`@("`@("`@("`@
M("1C:&%R<V5T(#T@96UP='DH)&YL<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=
M*2`_("=)4T\M.#@U.2TQ)R`Z("1N;'-;)V-H87)S971S)UU;)&QA;F=U86=E
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+T)R;W=S97(N<&AP)SL*("`@("`@("`@("`@)&)R;W=S97(@/2`F
M0G)O=W-E<CHZ<VEN9VQE=&]N*"D["@H@("`@("`@("`@("!I9B`H)&)R;W=S
M97(M/FAA<T9E871U<F4H)W5T9B<I("8F"B`@("`@("`@("`@("`@("`H571I
M;#HZ97AT96YS:6]N17AI<W1S*"=I8V]N=B<I('Q\"B`@("`@("`@("`@("`@
M("`@571I;#HZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2D@>PH@("`@
M("`@("`@("`@("`@)&-H87)S970@/2`G551&+3@G.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D8VAA<G-E="DI('L*
M("`@("`@("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$5X=&5R;F%L0VAA<G-E
M="@I.PH@("`@("`@('T*"B`@("`@("`@3DQ3.CI?8V%C:&5D0VAA<G-E="@D
M8V%C:&5+97DL("1C:&%R<V5T*3L*("`@("`@("!R971U<FX@)&-H87)S970[
M"B`@("!]"@H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!C
M:&%R<V5T(&]F('1H92!E;G9I<F]N;65N=`H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@8VAA<F%C=&5R('-E="!T:&%T('-H;W5L9"!B92!U
M<V5D('=I=&@@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@("`@("!L
M;V-A;&4@<V5T=&EN9W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5X=&5R
M;F%L0VAA<G-E="@I"B`@("!["B`@("`@("`@9VQO8F%L("1L86YG=6%G92P@
M)&YL<SL*"B`@("`@("`@+RH@1V5T(&-A8VAE9"!R97-U;'1S+B`J+PH@("`@
M("`@("1C:&%R<V5T(#T@3DQ3.CI?8V%C:&5D0VAA<G-E="@R*3L*("`@("`@
M("!I9B`H(6ES7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@(')E='5R
M;B`D8VAA<G-E=#L*("`@("`@("!]"@H@("`@("`@("1L86YG7V-H87)S970@
M/2!S971L;V-A;&4H3$-?04Q,+"`P*3L*("`@("`@("!I9B`H<W1R<&]S*"1L
M86YG7V-H87)S970L("<[)RD@/3T](&9A;'-E("8F"B`@("`@("`@("`@('-T
M<G!O<R@D;&%N9U]C:&%R<V5T+"`G+R<I(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("`D;&%N9U]C:&%R<V5T(#T@97AP;&]D92@G+B<L("1L86YG7V-H87)S
M970I.PH@("`@("`@("`@("!I9B`H*&-O=6YT*"1L86YG7V-H87)S970I(#T]
M(#(I("8F("%E;7!T>2@D;&%N9U]C:&%R<V5T6S%=*2D@>PH@("`@("`@("`@
M("`@("`@3DQ3.CI?8V%C:&5D0VAA<G-E="@R+"`D;&%N9U]C:&%R<V5T6S%=
M*3L*("`@("`@("`@("`@("`@(')E='5R;B`D;&%N9U]C:&%R<V5T6S%=.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"%E;7!T
M>2@D;FQS6R=C:&%R<V5T<R==6R1L86YG=6%G95TI*2`_("1N;'-;)V-H87)S
M971S)UU;)&QA;F=U86=E72`Z("=)4T\M.#@U.2TQ)SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@;W(@<F5T=7)N<R!T:&4@8VAA<G-E="!U<V5D('5N
M9&5R(&-E<G1A:6X@8V]N9&ET:6]N<RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YD97@@
M("!4:&4@240@;V8@82!C86-H92!S;&]T+B`P(&9O<B!T:&4@54D@8VAA<G-E
M="P@,0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R('1H92!T
M<F%N<VQA=&EO;B!C:&%R<V5T(&%N9"`R(&9O<B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&5X=&5R;F%L(&-H87)S970N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C:&%R<V5T("!)9B!S<&5C:69I960L('1H:7,@8VAA
M<G-E="!W:6QL(&)E('-T;W)E9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&=I=F5N(&-A8VAE('-L;W0N($]T:&5R=VES92!T:&4@
M8V]N=&5N="!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('-P96-I9FEE9"!C86-H92!S;&]T('=I;&P@8F4@<F5T=7)N960N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C86-H961#:&%R<V5T*"1I;F1E>"P@)&-H87)S
M970@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@
M("`@(&EF("@A:7-S970H)&-A8VAE*2D@>PH@("`@("`@("`@("`D8V%C:&4@
M/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C:&%R<V5T(#T]
M(&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1C86-H95LD:6YD
M97A=*2`_("1C86-H95LD:6YD97A=(#H@;G5L;#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D8V%C:&5;)&EN9&5X72`]("1C:&%R<V5T.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)S
M970@=&\@=7-E(&9O<B!O=71G;VEN9R!E;6%I;',N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!P<F5F97)R960@8VAA<G-E="!F;W(@;W5T
M9V]I;F<@;6%I;',@8F%S960@;VX*("`@("`J("`@("`@("`@("`@("`@("!T
M:&4@=7-E<B=S('!R969E<F5N8V5S(&%N9"!T:&4@8W5R<F5N="!L86YG=6%G
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T16UA:6Q#:&%R<V5T*"D*("`@
M('L*("`@("`@("!G;&]B86P@)'!R969S+"`D;&%N9W5A9V4L("1N;',["@H@
M("`@("`@("1C:&%R<V5T(#T@)'!R969S+3YG971686QU92@G<V5N9&EN9U]C
M:&%R<V5T)RD["B`@("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI('L*("`@
M("`@("`@("`@<F5T=7)N("1C:&%R<V5T.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@:7-S970H)&YL<ULG96UA:6QS)UU;)&QA;F=U86=E72D@/R`D;FQS
M6R=E;6%I;',G75LD;&%N9W5A9V5=(#H*("`@("`@("`@("`@("`@*&ES<V5T
M*"1N;'-;)V-H87)S971S)UU;)&QA;F=U86=E72D@/R`D;FQS6R=C:&%R<V5T
M<R==6R1L86YG=6%G95T@.B`G25-/+3@X-3DM,2<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0VAE8VL@=&\@<V5E(&EF(&-H87)A8W1E<B!S970@:7,@=F%L
M:60@9F]R(&AT;6QS<&5C:6%L8VAA<G,H*2!C86QL<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<F%C=&5R('-E="!T
M;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($ES(&-H
M87)S970@=F%L:60@9F]R('1H92!C=7)R96YT('-Y<W1E;3\*("`@("`J+PH@
M("`@9G5N8W1I;VX@8VAE8VM#:&%R<V5T*"1C:&%R<V5T*0H@("`@>PH@("`@
M("`@('-T871I8R`D8VAE8VL["@H@("`@("`@(&EF("AI<U]N=6QL*"1C:&%R
M<V5T*2!\?"!E;7!T>2@D8VAA<G-E="DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1C:&5C:ULD
M8VAA<G-E=%TI*2!["B`@("`@("`@("`@(')E='5R;B`D8VAE8VM;)&-H87)S
M971=.PH@("`@("`@('T@96QS96EF("@A:7-S970H)&-H96-K*2D@>PH@("`@
M("`@("`@("`D8VAE8VL@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@
M)'9A;&ED(#T@=')U93L*"B`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S
M)RP@,2D["B`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)R<L($5.5%]#3TU0
M050L("1C:&%R<V5T*3L*("`@("`@("!I9B`H:7-S970H)'!H<%]E<G)O<FUS
M9RDI('L*("`@("`@("`@("`@)'9A;&ED(#T@9F%L<V4["B`@("`@("`@?0H@
M("`@("`@(&EN:5]R97-T;W)E*"=T<F%C:U]E<G)O<G,G*3L*"B`@("`@("`@
M)&-H96-K6R1C:&%R<V5T72`]("1V86QI9#L*"B`@("`@("`@<F5T=7)N("1V
M86QI9#L*("`@('T*"B`@("\J*@H@("`@("H@4V5T<R!T:&4@8VAA<G-E="X*
M("`@("`J($EN(&=E;F5R86PL('1H92!A<'!L:65D(&-H87)S970@:7,@875T
M;VUA=&EC86QL>2!D971E<FUI;F5D(&)Y(&)R;W=S97(*("`@("`J(&QA;F=U
M86=E(&%N9"!B<F]W<V5R(&-A<&%B:6QI=&EE<R!A;F0@=&AE<F4G<R!N;R!N
M965D('1O(&UA;G5A;&QY(&-A;&P*("`@("`J('-E=$-H87)S970N($AO=V5V
M97(@9F]R(&AE861L97-S("A24$,I(&]P97)A=&EO;G,@=&AE(&-H87)S970@
M;6%Y(&)E"B`@("`@*B!S970@;6%N=6%L;'D@=&\@96YS=7)E(&-O<G)E8W0@
M8VAA<F%C=&5R(&-O;G9E<G-I;VX@:6X@=&AE(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@268@<W!E8VEF:65D+"!T
M:&ES(&-H87)S970@=VEL;"!B92!S=&]R960@:6X@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!G:79E;B!C86-H92!S;&]T+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@(%1H92!)1"!O9B!A(&-A
M8VAE('-L;W0N(#`@9F]R('1H92!522!C:&%R<V5T+"`Q"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@=&AE('1R86YS;&%T:6]N(&-H87)S
M970@86YD(#(@9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@97AT97)N86P@8VAA<G-E="X@1&5F875L=',@=&\@,#H@=&AI<R!I<R!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-H87)S970@<F5T
M=7)N960@8GD@9V5T0VAA<G-E="!A;F0@=7-E9"!F;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G9E<G-I;VXN"B`@("`@*B\*"B`@("!F
M=6YC=&EO;B!S971#:&%R<V5T*"1C:&%R<V5T+"1I;F1E>"`](#`I"B`@("![
M"B`@("`@("`@3DQ3.CI?8V%C:&5D0VAA<G-E="@D:6YD97@L("1C:&%R<V5T
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&-U<G)E;G0@=&EM
M97IO;F4L(&EF(&%V86EL86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M5&EM95IO;F4H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@
M("`@("1T>B`]("1P<F5F<RT^9V5T5F%L=64H)W1I;65Z;VYE)RD["B`@("`@
M("`@:68@*"%E;7!T>2@D='HI*2!["B`@("`@("`@("`@($!P=71E;G8H)U1:
M/2<@+B`D='HI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@;&]C86QE(&EN9F\@<F5T=7)N960@8GD@;&]C86QE8V]N=B@I+"!B
M=70@8V%C:&4@:70L('1O"B`@("`@*B!A=F]I9"!R97!E871E9"!C86QL<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5S=6QT<R!O9B!L
M;V-A;&5C;VYV*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO8V%L94EN
M9F\H*0H@("`@>PH@("`@("`@('-T871I8R`D;&-?:6YF;SL*"B`@("`@("`@
M:68@*"%I<W-E="@D;&-?:6YF;RDI('L*("`@("`@("`@("`@)&QC7VEN9F\@
M/2!L;V-A;&5C;VYV*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QC
M7VEN9F\["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&QA;F=U86=E
M(&EN9F\@<F5T=7)N960@8GD@;FQ?;&%N9VEN9F\H*2P@8G5T(&-A8VAE(&ET
M+"!T;PH@("`@("H@879O:60@<F5P96%T960@8V%L;',N"B`@("`@*@H@("`@
M("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!C;VYS
M="`D:71E;2`@5&AE(&QA;F=I;F9O(&ET96T@=&\@<F5T=7)N+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!R97-U;'1S(&]F(&YL7VQA;F=I
M;F9O*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QA;F=);F9O*"1I=&5M
M*0H@("`@>PH@("`@("`@('-T871I8R`D;FQ?:6YF;R`](&%R<F%Y*"D["@H@
M("`@("`@(&EF("@A:7-S970H)&YL7VEN9F];)&ET96U=*2D@>PH@("`@("`@
M("`@("`D;FQ?:6YF;ULD:71E;5T@/2!N;%]L86YG:6YF;R@D:71E;2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&YL7VEN9F];)&ET96U=.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T(&-O=6YT<GD@:6YF;W)M871I;VX@9G)O
M;2!A(&AO<W1N86UE(&]R($E0(&%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:&]S="`@5&AE(&AO<W1N86UE(&]R($E0(&%D9')E<W,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@3VX@<W5C8V5S<RP@<F5T
M=7)N(&%N(&%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9R!E;G1R:65S.@H@("`@
M("H@("`@("`@("`@("`@("`@)V-O9&4G("`]/B`@0V]U;G1R>2!#;V1E"B`@
M("`@*B`@("`@("`@("`@("`@("`G;F%M92<@(#T^("!#;W5N=')Y($YA;64*
M("`@("`J("`@("`@("`@("`@("`@($]N(&9A:6QU<F4L(')E='5R;B!F86QS
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]U;G1R>4)Y2&]S="@D:&]S
M="D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("\J($QI
M<W0@;V8@9V5N97)I8R!D;VUA:6YS('1H870@=V4@:VYO=R!I<R!N;W0@:6X@
M=&AE(&-O=6YT<GD@5$Q$"B`@("`@("`@("`@;&ES="X@4V5E.B!H='1P.B\O
M=W=W+FEA;F$N;W)G+V=T;&0O9W1L9"YH=&T@*B\*("`@("`@("`D9V5N97)I
M8R`](&%R<F%Y*`H@("`@("`@("`@("`G865R;R<L("=B:7HG+"`G8V]M)RP@
M)V-O;W`G+"`G961U)RP@)V=O=B<L("=I;F9O)RP@)VEN="<L("=M:6PG+`H@
M("`@("`@("`@("`G;75S975M)RP@)VYA;64G+"`G;F5T)RP@)V]R9R<L("=P
M<F\G"B`@("`@("`@*3L*"B`@("`@("`@)&-H96-K2&]S="`]("1H;W-T.PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EQD*UPN7&0K7"Y<9"M<+EQD*R0O
M)RP@)&AO<W0I*2!["B`@("`@("`@("`@("1C:&5C:TAO<W0@/2!`9V5T:&]S
M=&)Y861D<B@D:&]S="D["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE
M(%1,1"!O9B!T:&4@:&]S=&YA;64N("HO"B`@("`@("`@)'!O<R`]('-T<G)P
M;W,H)&-H96-K2&]S="P@)RXG*3L*("`@("`@("!I9B`H)'!O<R`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M("`@("`D9&]M86EN(#T@4W1R:6YG.CIL;W=E<BAS=6)S='(H)&-H96-K2&]S
M="P@)'!O<R`K(#$I*3L*"B`@("`@("`@+RH@5')Y(&QO;VMU<"!V:6$@5$Q$
M(&9I<G-T+B`J+PH@("`@("`@(&EF("@A:6Y?87)R87DH)&1O;6%I;BP@)&=E
M;F5R:6,I*2!["B`@("`@("`@("`@(')E<75I<F4@)TAO<F1E+TY,4R]T;&0N
M<&AP)SL*("`@("`@("`@("`@:68@*&ES<V5T*"1T;&1;)&1O;6%I;ETI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH)V-O9&4G(#T^("1D;VUA
M:6XL("=N86UE)R`]/B`D=&QD6R1D;VUA:6Y=*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+RH@5')Y($=E;TE0(&QO;VMU<"!N97AT+B`J
M+PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;)V=E;VEP)UU;)V1A=&%F:6QE
M)UTI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O3DQ3+T=E
M;TE0+G!H<"<["B`@("`@("`@("`@("1G96]I<"`]("9.3%-?1V5O25`Z.G-I
M;F=L971O;B@D8V]N9ELG9V5O:7`G75LG9&%T869I;&4G72D["B`@("`@("`@
M("`@("1I9"`]("1G96]I<"T^8V]U;G1R>4ED0GE.86UE*"1C:&5C:TAO<W0I
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1I9"DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@G8V]D92<@/3X@4W1R:6YG.CIL;W=E<B@D1TQ/
M0D%,4ULG1T5/25!?0T]53E1265]#3T1%4R==6R1I9%TI+"`G;F%M92<@/3X@
M)$=,3T)!3%-;)T=%3TE07T-/54Y44EE?3D%-15,G75LD:61=*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A($AO<F1E(&EM86=E(&QI;FL@
M=&\@=&AE(&-O=6YT<GD@9FQA9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1H;W-T("!4:&4@:&]S=&YA;64@;W(@25`@861D<F5S<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&EM86=E(%523"P@;W(@=&AE
M(&5M<'1Y('-T<FEN9R!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5N97)A=&5&;&%G26UA9V5">4AO<W0H)&AO<W0I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)&1A=&$@/2!.3%,Z.F=E=$-O
M=6YT<GE">4AO<W0H)&AO<W0I.PH@("`@("`@(&EF("@D9&%T82`A/3T@9F%L
M<V4I('L*("`@("`@("`@("`@)&EM9R`]("1D871A6R=C;V1E)UT@+B`G+G!N
M9R<["B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D<F5G:7-T<GDM/F=E
M="@G=&AE;65S9G,G+"`G:&]R9&4G*2`N("<O9W)A<&AI8W,O9FQA9W,O)R`N
M("1I;6<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@2&]R9&4Z.FEM9R@D
M:6UG+"`D9&%T85LG;F%M92==+"!A<G)A>2@G=&ET;&4G(#T^("1D871A6R=N
M86UE)UTI+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I("X@)R]F
M;&%G<R<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("=;)R`N("1D871A6R=N86UE)UT@+B`G72<["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@96ET:&5R(&$@<W!E8VEF:6,@;W(@86QL($E3
M3RTS,38V(&-O=6YT<GD@;F%M97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]D92`@5&AE($E33R`S,38V(&-O=6YT<GD@8V]D92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!)9B!A(&-O=6YT<GD@8V]D92!H87,@
M8F5E;B!R97%U97-T960@=VEL;"!R971U<FX@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("!C;W)R97-P;VYD:6YG(&-O=6YT<GD@;F%M92X@268@96UP='D@
M=VEL;"!R971U<FX@86X*("`@("`J("`@("`@("`@("`@("`@(&%R<F%Y(&]F
M(&%L;"!T:&4@8V]U;G1R>2!C;V1E<R!A;F0@=&AE:7(@;F%M97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9G971#;W5N=')Y25-/*"1C;V1E(#T@)R<I"B`@
M("!["B`@("`@("`@<W1A=&EC("1C;W5N=')I97,@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("AE;7!T>2@D8V]U;G1R:65S*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+TY,4R]C;W5N=')I97,N<&AP)SL*("`@("`@("!]
M"B`@("`@("`@:68@*&5M<'1Y*"1C;V1E*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&-O=6YT<FEE<SL*("`@("`@("!](&5L<V5I9B`H:7-S970H)&-O=6YT
M<FEE<ULD8V]D95TI*2!["B`@("`@("`@("`@(')E='5R;B`D8V]U;G1R:65S
M6R1C;V1E73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O36]B:6QE
M+G!H<```````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3`W
M,#8W`#$P-#$W,S8R-S<S`#`R,#$V-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@2&]R
M9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?8V%R9"!E>'1E;F1S
M($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@("!V87(@)%]N86UE.PH@("`@
M=F%R("1?=&ET;&4["B`@("!V87(@)%]F;W)M.PH@("`@=F%R("1?96QE;65N
M=',@/2!A<G)A>2@I.PH@("`@=F%R("1?<V]F=&ME>7,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@5&AE(&YA;64@;V8@=&AI<R!C87)D+B!#86X@
M8F4@=7-E9"!I;B!A;F-H;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!L:6YK<RX*("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE("!)9B!A('-T
M<FEN9R!I<R!P<F]V:61E9"!H97)E+"!I="!W:6QL(&)E(&1I<W!L87EE9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN('1H92!(5$U,('1I=&QE
M(&)A<BP@<F5S<&5C=&EV96QY('-O;65W:&5R92!O;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@('1H92!705`@9&ES<&QA>2X@57-I;F<@82!T:71L
M92!Y;W4@=VEL;"!N;W)M86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&AA=F4@=&\@<W!E;F0@;VYE(&]F('EO=7(@9F5W(&QI;F5S(&]N('EO
M=7(@5T%0"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&ES<&QA>2X@
M0V]N<VED97(@=&AA="!S;VUE(%=!4"!P:&]N97,O4T1+)W,@86YD"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@:&%N9&AE;&0@9&5V:6-E<R!D;VXG
M="!D:7-P;&%Y('1H92!T:71L92!A="!A;&PN"B`@("`@*B\*("`@(&9U;F-T
M:6]N($AO<F1E7TUO8FEL95]C87)D*"1N86UE(#T@;G5L;"P@)'1I=&QE(#T@
M;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@
M("`@("`D=&AI<RT^7W1I=&QE(#T@)'1I=&QE.PH@("`@?0H*("`@(&9U;F-T
M:6]N("9A9&0H)B1E;&5M96YT*0H@("`@>PH@("`@("`@('-T871I8R`D;&EN
M:W-E=$%D9&5D.PH*("`@("`@("!I9B`H(6ES7V$H)&5L96UE;G0L("=(;W)D
M95]-;V)I;&5?96QE;65N="<I*2!["B`@("`@("`@("`@("1E<G)O<B`](%!%
M05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@96QE;65N="XG*3L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!](&5L<V5I9B`H:7-?82@D96QE
M;65N="P@)TAO<F1E7TUO8FEL95]T97AT)RD@?'P*("`@("`@("`@("`@("`@
M("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]T86)L92<I('Q\"B`@
M("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?
M:6UA9V4G*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT+"`G
M2&]R9&5?36]B:6QE7VQI;FLG*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A
M*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7W!H;VYE)RD@?'P*("`@("`@("`@
M("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]R=6QE)RDI
M('L*("`@("`@("`@("`@)&)L;V-K(#T@)FYE=R!(;W)D95]-;V)I;&5?8FQO
M8VLH)&5L96UE;G0I.PH@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@
M/2`F)&)L;V-K.PH@("`@("`@('T@96QS96EF("AI<U]A*"1E;&5M96YT+"`G
M2&]R9&5?36]B:6QE7V)L;V-K)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]E
M;&5M96YT<UM=(#T@)B1E;&5M96YT.PH@("`@("`@('T@96QS96EF("AI<U]A
M*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7V9O<FTG*2D@>PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?9F]R;2DI('L*("`@("`@("`@("`@("`@
M("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)T-A<F1S(&UA>2!O;FQY(&-O
M;G1A:6X@;VYE($9O<FT@96QE;65N="XG*3L*("`@("`@("`@("`@("`@(')E
M='5R;B`D97)R;W(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]E;&5M96YT<UM=(#T@)B1E;&5M96YT.PH@("`@("`@("`@("`D=&AI<RT^
M7V9O<FT@/2`F)&5L96UE;G0["B`@("`@("`@?2!E;'-E:68@*&ES7V$H)&5L
M96UE;G0L("=(;W)D95]-;V)I;&5?;&EN:W-E="<I*2!["B`@("`@("`@("`@
M(&EF("@A96UP='DH)&QI;FMS971!9&1E9"DI('L*("`@("`@("`@("`@("`@
M("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)T-A<F1S(&UA>2!O;FQY(&-O
M;G1A:6X@;VYE($QI;FMS970@96QE;65N="XG*3L*("`@("`@("`@("`@("`@
M(')E='5R;B`D97)R;W(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&)L
M;V-K(#T@)FYE=R!(;W)D95]-;V)I;&5?8FQO8VLH)&5L96UE;G0I.PH@("`@
M("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&)L;V-K.PH@("`@("`@
M("`@("`D;&EN:W-E=$%D9&5D(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=4:&ES(&5L
M96UE;G0@;75S="!B92!I;G-I9&4@86X@87!P<F]P<FEA=&4@8V]N=&%I;F5R
M(&5L96UE;G0N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&5L96UE;G0["B`@("!]"@H@("`@9G5N
M8W1I;VX@<V]F=&ME>2@D=7)L+"`D;&%B96PI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]S;V9T:V5Y<UM=(#T@87)R87DH)W5R;"<@/3X@)'5R;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^("1L86)E
M;"D["B`@("!]"@I]"@HO*BH*("H@2&]R9&5?36]B:6QE.CH*("H*("H@2&]R
M9&4@05!)(&9O<B!G96YE<F%T:6YG($UO8FEL92!C;VYT96YT+B!);F-L=61E
M<R!N=6UE<F]U<R!U=&EL:71Y"B`J(&9U;F-T:6]N<RP@9V5N97)A;&EZ960@
M96QE;65N="!C;&%S<V5S+"!A;F0@<F5N9&5R97)S(&9O<B!M87)K=7`*("H@
M;&%N9W5A9V5S(&EN8VQU9&EN9R!734PL($A$34PL(&%N9"!#2%1-3"X*("H*
M("H@5&AI<R!C;&%S<R!I<R!T:&4@=&]P(&QE=F5L(&-L87-S(&]F(&%L;"!(
M;W)D95]-;V)I;&4@8VQA<W-E<RX@66]U<@H@*B!P86=E('-H;W5L9"!C;VYS
M:7-T(&]F(&5X86-T;'D@;VYE($AO<F1E7TUO8FEL92!O8FIE8W0N($%P<')O
M<')I871E"B`J(&UA<FMU<"`M($EM;V1E+"!734PL($A$34PL(&5T8RX@+2!I
M<R!G96YE<F%T960@8GD@=&AE(&%P<')O<')I871E"B`J(')E;F1E<F5R(&]B
M:F5C=`H@*@H@*B!$;R!N;W0@;W9E<G-T=69F($AO<F1E7TUO8FEL92!O8FIE
M8W1S+B!296UE;6)E<B!T:&%T(&$@;&]T(&]F(%=!4`H@*B!C;&EE;G1S(&-A
M;FYO="!H86YD;&4@;6]R92!T:&%N(&%B;W5T(#$T,#`@8GET92!O9B!C;VUP
M:6QE9"!D871A+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY4&%G92`](&YE
M=R!(;W)D95]-;V)I;&4H*3L*("H@)&UY4&%G92`](&YE=R!(;W)D95]-;V)I
M;&4H)TUY(%=!4"!P86=E)RD["B`J("1M>5!A9V4@/2!N97<@2&]R9&5?36]B
M:6QE*"<G+"`G8V5N=&5R)RD["B`J"B`J("\O($UO<F4@<W1U9F8*("H*("H@
M)&UY4&%G92T^861D*"1M>51E>'0I.PH@*@H@*B`O+R!-;W)E(&ET96US"B`J
M"B`J("1M>5!A9V4M/G)E;F1E<B@I.PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]-;V)I;&4O36]B:6QE+G!H<"QV(#$N,S(N,3`N."`R,#`V+S`Q+S`Q(#(Q
M.C(X.C(V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-
M;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL92!E>'1E;F1S($AO<F1E7TUO
M8FEL95]C87)D('L*"B`@("!V87(@)%]T:71L93L*("`@('9A<B`D7V5L96UE
M;G1S(#T@87)R87DH*3L*("`@('9A<B`D7V-A<F1S(#T@87)R87DH*3L*("`@
M('9A<B`D7V1E8G5G(#T@9F%L<V4["@H@("`@+R\@1&5C:61E('=H971H97(@
M=&AE('-I;75L871O<B!D979I8V4@:7,@=&\@8F4@=7-E9"X@3VYL>2!A9F9E
M8W1S"B`@("`O+R!(5$U,(&)R;W=S97(@;W5T<'5T+@H@("`@=F%R("1?<VEM
M=6QA=&]R(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE("!)9B!A('-T<FEN
M9R!I<R!P<F]V:61E9"!H97)E+"!I="!W:6QL(&)E(&1I<W!L87EE9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&EN('1H92!(5$U,('1I=&QE(&)A
M<BP@<F5S<&5C=&EV96QY('-O;65W:&5R92!O;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('1H92!705`@9&ES<&QA>2X@57-I;F<@82!T:71L92!Y
M;W4@=VEL;"!N;W)M86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&AA=F4@=&\@<W!E;F0@;VYE(&]F('EO=7(@9F5W(&QI;F5S(&]N('EO=7(@
M5T%0"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&ES<&QA>2X@0V]N
M<VED97(@=&AA="!S;VUE(%=!4"!P:&]N97,O4T1+)W,@86YD"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@:&%N9&AE;&0@9&5V:6-E<R!D;VXG="!D
M:7-P;&%Y('1H92!T:71L92!A="!A;&PN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A9V5N="`@268@<W!E8VEF:65D+"!U<V4@:6YS=&5A9"!O9B!(5%107U53
M15)?04=%3E0N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL92@D
M=&ET;&4@/2!N=6QL+"`D86=E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?;G5L;"@D=&ET;&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&ET
M;&4@/2`D=&ET;&4["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+T)R;W=S97(N<&AP)SL*("`@("`@("`D8G)O=W-E<B`]("9"<F]W
M<V5R.CIS:6YG;&5T;VXH)&%G96YT*3L*"B`@("`@("`@:68@*"1B<F]W<V5R
M+3YH87-&96%T=7)E*"=H=&UL)RDI('L*("`@("`@("`@("`@)&UL(#T@)VAT
M;6PG.PH@("`@("`@('T@96QS96EF("@D8G)O=W-E<BT^:&%S1F5A='5R92@G
M=VUL)RDI('L*("`@("`@("`@("`@)&UL(#T@)W=M;"<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&UL(#T@)VAT;6PG.PH@("`@("`@('T*"B`@
M("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]-;V)I
M;&4O4F5N9&5R97(N<&AP)SL*("`@("`@("`D=&AI<RT^7W)E;F1E<F5R(#T@
M)DAO<F1E7TUO8FEL95]296YD97)E<CHZ<VEN9VQE=&]N*"1M;"P@)&)R;W=S
M97(I.PH@("`@?0H*("`@(&9U;F-T:6]N("9A9&0H)B1E;&5M96YT*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7V-A
M<F0G*2D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]E;&5M96YT
M<RDI('L*("`@("`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R
M;W(H)UEO=2!C86YN;W0@;6EX($AO<F1E7TUO8FEL95]C87)D<R!A;F0@;W1H
M97(@96QE;65N=',@870@=&AE(&1E8VL@;&5V96PN)RD["B`@("`@("`@("`@
M("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D=&AI<RT^7W5S:6YG0V%R9',@/2!T<G5E.PH@("`@("`@("`@("`D=&AI
M<RT^7V-A<F1S6UT@/2`F)&5L96UE;G0["@H@("`@("`@("`@("!R971U<FX@
M)&5L96UE;G0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&-O
M=6YT*"1T:&ES+3Y?8V%R9',I*2!["B`@("`@("`@("`@("`@("`D97)R;W(@
M/2!014%2.CIR86ES945R<F]R*"=9;W4@8V%N;F]T(&UI>"!(;W)D95]-;V)I
M;&5?8V%R9',@86YD(&]T:&5R(&5L96UE;G1S(&%T('1H92!D96-K(&QE=F5L
M+B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ861D*"1E;&5M96YT
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8W1I=F%T97,@
M=&AE(&)U:6QT+6EN(&1E=FEC92!S:6UU;&%T;W(@;VX@8FEG<V-R965N(&)R
M;W=S97)S+@H@("`@("H@5&AE(&1E=FEC92!S:6UU;&%T;W(@:7,@;VYL>2!F
M=6QL>2UF=6YC=&EO;F%L(&EN($EN=&5R;F5T"B`@("`@*B!%>'!L;W)E<BP@
M8F5C875S92!T:&4@;&%Y;W5T(')E<75I<F5S(&$@<V-R;VQL86)L92!T86)L
M90H@("`@("H@96QE;65N="X@3W1H97(@8G)O=W-E<G,@=VEL;"!F86EL('1O
M('-H;W<@8V]N=&5N="!O;B!P86=E<PH@("`@("H@;&]N9V5R('1H86X@82!S
M:6YG;&4@<V-R965N+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<V53:6UU;&%T
M;W(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<VEM=6QA=&]R(#T@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@=&AE('!A9V4@:6X@=&AE
M(&%P<')O<')I871E(&UA<FMU<"!L86YG=6%G92X@1&5P96YD:6YG"B`@("`@
M*B!O;B!T:&4@<F5N9&5R97(@='EP92P@2%1-3"`H<'5R92!(5$U,+"!H86YD
M:&5L9&9R:65N9&QY($%V86YT1V\*("`@("`J($A434PL(&DM;6]D92!C2%1-
M3"P@34U,*2P@5TU,(&]R($A$34P@8V]D92!I<R!C<F5A=&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("`D=&AI<RT^
M7W)E;F1E<F5R+3YR96YD97(H)'1H:7,I.PH@("`@?0H*?0H*+RHJ"B`J($!P
M86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7V5L
M96UE;G0@>PH*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]E;&5M96YT*"D*
M("`@('L*("`@('T*"B`@("!F=6YC=&EO;B!G970H)&%T=')I8G5T92D*("`@
M('L*("`@("`@("`D871T<B`]("=?)R`N("1A='1R:6)U=&4["B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3XD871T<BDI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3XD871T<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T
M*"1A='1R:6)U=&4L("1V86QU92D*("`@('L*("`@("`@("`D871T<B`]("=?
M)R`N("1A='1R:6)U=&4["B`@("`@("`@)'1H:7,M/B1A='1R(#T@)'9A;'5E
M.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*
M8VQA<W,@2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT(&5X=&5N9',@2&]R9&5?
M36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7VYA;64["B`@("!V87(@)%]V
M86QU93L*("`@('9A<B`D7VQA8F5L.PH@("`@=F%R("1?<VEZ93L*("`@('9A
M<B`D7VUA>&QE;F=T:#L*("`@('9A<B`D7W1Y<&4["B`@("!V87(@)%]F;W)M
M870["B`@("!V87(@)%]M;V1E.PH*("`@("\J*@H@("`@("H@4V5T(&EN<'5T
M(&UO9&4O:7-T>6QE(&9O<B!J87!A;F5S92!-34PO:2UM;V1E(&1E=FEC97,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D92`@26YP=70@;6]D
M92P@;VYE(&]F.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@)V%L<&AA
M)R`H9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=K871A
M:V%N82<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=H:7)A9V%N82<*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("=N=6UE<FEC)PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971-;V1E*"1M;V1E*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;6]D92`]("1M;V1E.PH*("`@("`@("`O+R!-87`@=&AE(&UO9&4@
M:6YT;R!A;B!A<'!R;W!R:6%T92!F;W)M870@<W1R:6YG+"!U<V5D(&9O<@H@
M("`@("`@("\O(%=-3"!A;F0@2$1-3"X@268@82!F;W)M870@<W1R:6YG('=A
M<R!P<F]V:61E9"!E87)L:65R+"!I=`H@("`@("`@("\O('=I;&P@8F4@;W9E
M<G=R:71T96XN"B`@("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A
M<V4@)VAI<F%G86YA)SH*("`@("`@("!C87-E("=K871A:V%N82<Z"B`@("`@
M("`@("`@("1T:&ES+3Y?9F]R;6%T(#T@)RI-)SL*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@)V%L<&AA)SH*("`@("`@("`@("`@)'1H:7,M
M/E]F;W)M870@/2`G*FTG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`G;G5M97)I8R<Z"B`@("`@("`@("`@("1T:&ES+3Y?9F]R;6%T(#T@
M)RI.)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*?0H*
M+RHJ"B`J(%1H:7,@8VQA<W,@9&5F:6YE<R!A(&9O<FT@=VET:"!V87)I;W5S
M('!O<W-I8FQE(&EN<'5T(&5L96UE;G1S+B!4:&4*("H@:6YP=70@96QE;65N
M=',@:&%V92!T;R!B92!D969I;F5D(&%S('-E<&%R871E(&]B:F5C=',@86YD
M(&%R90H@*B!L:6YK960@=&\@=&AE(&9O<FT@=VET:"!A('-P96-I86P@(F%D
M9"(@9G5N8W1I;VXN($]N92!(;W)D95]-;V)I;&4*("H@;V)J96-T(&-A;B!C
M;VYT86EN(&]N;'D@;VYE($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C="X*("H*
M("H@17AA;7!L97,Z"B`J"B`J("1M>5!A9V4@/2!N97<@2&]R9&5?36]B:6QE
M*"XN+BD["B`J"B`J("1M>49O<FT@/2!N97<@2&]R9&5?36]B:6QE7V9O<FTH
M(B]M>6YE>'1P86=E+G=M;"(I.PH@*B`D;7E497AT(#T@;F5W($AO<F1E7TUO
M8FEL95]T97AT*"XN+BD["B`J("1M>49O<FTM/F%D9"@D;7E497AT*3L*("H@
M)&UY26YP=70@/2!N97<@2&]R9&5?36]B:6QE7VEN<'5T*"XN+BD["B`J("1M
M>49O<FTM/F%D9"@D;7E);G!U="D["B`J("1M>5-U8FUI="`](&YE=R!(;W)D
M95]-;V)I;&5?<W5B;6ET*"XN+BD["B`J("1M>49O<FTM/F%D9"@D;7E3=6)M
M:70I.PH@*@H@*B`D;7E086=E+3YA9&0H)&UY1F]R;2D["B`J"B`J("1M>5!A
M9V4M/G)E;F1E<B@I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL95]T97AT"B`J
M($!S964@2&]R9&5?36]B:6QE7VEM86=E"B`J($!S964@2&]R9&5?36]B:6QE
M7W1A8FQE"B`J($!S964@2&]R9&5?36]B:6QE7VEN<'5T"B`J($!S964@2&]R
M9&5?36]B:6QE7W1E>'1A<F5A"B`J($!S964@2&]R9&5?36]B:6QE7W-E;&5C
M=`H@*B!`<V5E($AO<F1E7TUO8FEL95]R861I;PH@*B!`<V5E($AO<F1E7TUO
M8FEL95]C:&5C:V)O>`H@*B!`<V5E($AO<F1E7TUO8FEL95]S=6)M:70*("H@
M0'-E92!(;W)D95]-;V)I;&5?<G5L90H@*@H@*B!`<&%C:V%G92!(;W)D95]-
M;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]F;W)M(&5X=&5N9',@2&]R
M9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W5R;#L*("`@('9A<B`D
M7VUE=&AO9#L*("`@('9A<B`D7V5L96UE;G1S(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7)L("`@("`@($%D9')E<W,@=VAE<F4@=&AE('5S97(@:6YP=70@
M:7,@<V5N="!T;RX*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@("`G
M<&]S="<@*&1E9F%U;'0I(&]R("=G970G+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'-E<W-I;VX@(%!R97-E<G9E('1H92!S97-I;VX@:60@:6X@=&AE(&9O
M<FT_($1E9F%U;'1S('1O('1R=64N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7TUO8FEL95]F;W)M*"1U<FPL("1M971H;V0@/2`G<&]S="<L("1S97-S
M:6]N(#T@=')U92D*("`@('L*("`@("`@("`D=&AI<RT^7W5R;"`]("1U<FP[
M"B`@("`@("`@)'1H:7,M/E]M971H;V0@/2`D;65T:&]D.PH*("`@("`@("!I
M9B`H)'-E<W-I;VX@)B8@(6%R<F%Y7VME>5]E>&ES=',H<V5S<VEO;E]N86UE
M*"DL("1?0T]/2TE%*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D*&YE=R!(
M;W)D95]-;V)I;&5?:&ED9&5N*'-E<W-I;VY?;F%M92@I+"!S97-S:6]N7VED
M*"DI*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@)F%D9"@F)&9O
M<FU%;&5M96YT*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1F;W)M16QE;65N
M="P@)TAO<F1E7TUO8FEL95]S=6)M:70G*2D@>PH@("`@("`@("`@("`D9F]R
M;45L96UE;G0M/E]F;W)M(#T@)B1T:&ES.PH@("`@("`@("`@("`D8FQO8VL@
M/2`F;F5W($AO<F1E7TUO8FEL95]B;&]C:R@D9F]R;45L96UE;G0I.PH@("`@
M("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&)L;V-K.PH@("`@("`@
M('T@96QS96EF("AI<U]A*"1F;W)M16QE;65N="P@)TAO<F1E7TUO8FEL95]H
M:61D96XG*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1F;W)M16QE;65N
M="P@)TAO<F1E7TUO8FEL95]B;&]C:R<I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?96QE;65N='-;72`]("8D9F]R;45L96UE;G0["B`@("`@("`@?2!E;'-E
M:68@*&ES7V$H)&9O<FU%;&5M96YT+"`G2&]R9&5?36]B:6QE7V9O<FU%;&5M
M96YT)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D9F]R;45L96UE;G0L
M("=(;W)D95]-;V)I;&5?=&5X="<I('Q\"B`@("`@("`@("`@("`@("`@(&ES
M7V$H)&9O<FU%;&5M96YT+"`G2&]R9&5?36]B:6QE7W1A8FQE)RD@?'P*("`@
M("`@("`@("`@("`@("`@:7-?82@D9F]R;45L96UE;G0L("=(;W)D95]-;V)I
M;&5?<G5L92<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&9O<FU%;&5M
M96YT+"`G2&]R9&5?36]B:6QE7VEM86=E)RDI('L*("`@("`@("`@("`@)&)L
M;V-K(#T@)FYE=R!(;W)D95]-;V)I;&5?8FQO8VLH)&9O<FU%;&5M96YT*3L*
M("`@("`@("`@("`@)'1H:7,M/E]E;&5M96YT<UM=(#T@)B1B;&]C:SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES
M945R<F]R*"=3<&5C:69I960@96QE;65N="!C86YN;W0@8F4@:6YS:61E(&$@
M9F]R;2XG*3L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9F]R;45L96UE;G0["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T1&5F875L=',H*0H@("`@>PH@("`@("`@("1D969A=6QT<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]E;&5M96YT<R!A
M<R`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?
M8VQA<W,H)'9A;"DI*2!["B`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL
M95]H:61D96XG.@H@("`@("`@("`@("`@("`@)&1E9F%U;'1S6UT@/2!A<G)A
M>2@G;F%M92<@/3X@)'9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;"T^9V5T*"=V
M86QU92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:&ED9&5N)R`]/B!T<G5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7V)L;V-K)SH*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86PM/E]E;&5M96YT<R!A<R`D8G9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA
M<W,H)&)V86PI*2D@>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E
M7VUO8FEL95]C:&5C:V)O>"<Z"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D8G9A;"T^:7-#:&5C:V5D*"DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D969A=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1B=F%L+3YG
M970H)VYA;64G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D8G9A;"T^9V5T*"=V86QU92<I
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R
M9&5?;6]B:6QE7VEN<'5T)SH*("`@("`@("`@("`@("`@("`@("!C87-E("=H
M;W)D95]M;V)I;&5?=&5X=&%R96$G.@H@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)VAO<F1E7VUO8FEL95]S96QE8W0G.@H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)VAO<F1E7VUO8FEL95]R861I;R<Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("1D969A=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1B=F%L+3YG
M970H)VYA;64G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=F%L=64G(#T^("1B=F%L+3YG970H)W9A;'5E)RDI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7VAI9&1E;B<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D969A=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1B
M=F%L+3YG970H)VYA;64G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1B=F%L+3YG970H)W9A;'5E
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VAI9&1E;B<@/3X@=')U92D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I
M;&5?=&%B;&4G.@H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M8G9A;"T^7W)O=W,@87,@)')O=RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)')O=RT^7V-O;'5M;G,@87,@)&-O;"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E
M<BAG971?8VQA<W,H)&-O;"DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7V-H96-K8F]X)SH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1C;VPM/FES0VAE
M8VME9"@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5F875L='-;72`](&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T
M*"=N86UE)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)&)V86PM/F=E
M="@G=F%L=64G*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO
M<F1E7VUO8FEL95]I;G!U="<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W1E>'1A<F5A)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?<V5L
M96-T)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H
M;W)D95]M;V)I;&5?<F%D:6\G.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5F875L='-;72`](&%R<F%Y*"=N86UE)R`]/B`D8G9A
M;"T^9V5T*"=N86UE)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D8G9A;"T^
M9V5T*"=V86QU92<I*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)VAO<F1E7VUO8FEL95]H:61D96XG.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5F875L='-;72`](&%R<F%Y*"=N86UE
M)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]
M/B`D8G9A;"T^9V5T*"=V86QU92<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H:61D96XG(#T^
M('1R=64I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D9&5F875L=',["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1V5T5F%R
M<R@I"B`@("!["B`@("`@("`@+R\@1&5T97)M:6YE(&%L;"!E;&5M96YT<R!T
M:&%T(&AA=F4@=&\@8F4@<W5B;6ET=&5D+@H@("`@("`@("1G971V87)S(#T@
M87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5L96UE;G1S(&%S
M("1V86PI('L*("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*&=E=%]C
M;&%S<R@D=F%L*2DI('L*("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE
M7V)L;V-K)SH*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86PM/E]E;&5M
M96YT<R!A<R`D8G9A;"D@>PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H
M<W1R=&]L;W=E<BAG971?8VQA<W,H)&)V86PI*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]I;G!U="<Z"B`@("`@("`@("`@
M("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7VAI9&1E;B<Z"B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W1E>'1A<F5A)SH*("`@
M("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?<V5L96-T)SH*
M("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?8VAE8VMB
M;W@G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]R
M861I;R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1G971V87)S6UT@/2`D
M8G9A;"T^9V5T*"=N86UE)RD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?
M=&%B;&4G.@H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D8G9A
M;"T^7W)O=W,@87,@)')O=RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)')O=RT^7V-O;'5M;G,@87,@)&-O;"D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG
M971?8VQA<W,H)&-O;"DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7VEN<'5T)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?:&ED9&5N
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D
M95]M;V)I;&5?=&5X=&%R96$G.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]S96QE8W0G.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]C:&5C
M:V)O>"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G
M:&]R9&5?;6]B:6QE7W)A9&EO)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&=E='9A<G-;72`]("1C;VPM/F=E="@G;F%M92<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9V5T
M=F%R<SL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S(&AO;&1S('1E>'0M
M;&5V96P@96QE;65N=',@9F]R('5S92!I;B!(;W)D95]-;V)I;&4@;W(*("H@
M2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T<RX*("H*("H@17AA;7!L97,Z"B`J
M"B`J("1B;&]C:R`](&YE=R!(;W)D95]-;V)I;&5?8FQO8VLH(DAE;&QO(%=!
M4"$B*3L*("H@)'1E>'0@/2!N97<@2&]R9&5?36]B:6QE7W1E>'0H(E=E;&-O
M;64@=&\@2&]R9&5?36]B:6QE(BP@)V(G*3L*("H@)&)L;V-K+3YA9&0H)'1E
M>'0I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL90H@*B!`<V5E($AO<F1E7TUO
M8FEL95]F;W)M"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA
M<W,@2&]R9&5?36]B:6QE7V)L;V-K(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L
M96UE;G0@>PH*("`@('9A<B`D7V5L96UE;G1S(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D96QE;65N=',@($%N>2!E;&5M96YT<R`H82!S:6YG;&4@;VYE(&]R
M(&%N(&%R<F%Y*2!T;R!F:6QL('1H:7,@8FQO8VL@=VET:"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7V)L;V-K*"8D96QE;65N=',I"B`@
M("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1E;&5M96YT<RDI('L*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D96QE;65N=',I*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^861D*"1E;&5M96YT<RD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D96QE;65N=',@87,@)&5L
M96UE;G0I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1E;&5M
M96YT*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B`F861D*"8D96QE;65N="D*("`@('L*
M("`@("`@("!I9B`H(6ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?96QE
M;65N="<I*2!["B`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R
M;W(H)TEN=F%L:60@96QE;65N="XG*3L*("`@("`@("!](&5L<V5I9B`H:7-?
M82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]T97AT)RD@?'P*("`@("`@("`@
M("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]T86)L92<I
M('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-
M;V)I;&5?:6UA9V4G*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M
M96YT+"`G2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT)RD@?'P*("`@("`@("`@
M("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]L:6YK)RD@
M?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO
M8FEL95]L:6YK<V5T)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE
M;65N="P@)TAO<F1E7TUO8FEL95]P:&]N92<I('Q\"B`@("`@("`@("`@("`@
M("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?<G5L92<I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D96QE;65N=#L*("`@
M("`@("`@("`@<F5T=7)N("1E;&5M96YT.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H92!E;&5M
M96YT(&ES(&YO="!A;&QO=V5D(&EN<VED92!A(&)L;V-K+B<I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@?0H*?0H*+RHJ"B`J(%1H
M:7,@8VQA<W,@:6YS97)T<R!P;&%I;B!T97AT(&EN=&\@82!(;W)D95]-;V)I
M;&5?8FQO8VL@;W(@80H@*B!(;W)D95]-;V)I;&5?<F]W(&]B:F5C="X*("H*
M("H@17AA;7!L97,Z"B`J"B`J("1M>51E>'0Q(#T@;F5W($AO<F1E7TUO8FEL
M95]T97AT*")(96QL;R!705`A(BD["B`J("1M>51E>'0R(#T@;F5W($AO<F1E
M7TUO8FEL95]T97AT*")796QC;VUE('1O($AO<F1E7TUO8FEL92(L("=B)RD[
M"B`J("1M>51E>'0S(#T@;F5W($AO<F1E7TUO8FEL95]T97AT*")';V]D($UO
M<FYI;F<B+"!A<G)A>2@G8B<L("=B:6<G*2D["B`J"B`J($!S964@2&]R9&5?
M36]B:6QE7V)L;V-K"B`J($!S964@2&]R9&5?36]B:6QE7W)O=PH@*@H@*B!`
M<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]T
M97AT(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D
M7W1E>'0@/2`G)SL*("`@('9A<B`D7V%T=')I8G5T97,@/2!A<G)A>2@I.PH@
M("`@=F%R("1?;&EN96)R96%K<R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@
M5&AE('1E>'0@8V]N=&5N="!O9B!T:&4@96QE;65N="X*("`@("`J($!P87)A
M;2!A<G)A>2`D871T<FEB=71E<R`@5&5X="!A='1R:6)U=&5S+B!!;GD@;V8Z
M"B`@("`@*B`@("=B)PH@("`@("H@("`G=2<*("`@("`J("`@)VDG"B`@("`@
M*B`@("=B:6<G"B`@("`@*B`@("=S;6%L;"<*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?36]B:6QE7W1E>'0H)'1E>'0L("1A='1R:6)U=&5S(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W1E>'0@/2`D=&5X=#L*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1A='1R:6)U=&5S*2D@>PH@("`@("`@("`@
M("`D871T<FEB=71E<R`](&%R<F%Y*"1A='1R:6)U=&5S*3L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S(#T@)&%T=')I8G5T97,["B`@
M("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!A;&QO=W,@=&\@:6YS97)T(&)I
M=&UA<"!I;6%G97,@:6YT;R!A($AO<F1E7TUO8FEL95]B;&]C:RP*("H@2&]R
M9&5?36]B:6QE7V9O<FT@;W(@2&]R9&5?36]B:6QE7W)O=R!O8FIE8W0N"B`J
M"B`J($5X86UP;&5S.@H@*@H@*B`D:6UA9V4@/2!N97<@2&]R9&5?36]B:6QE
M7VEM86=E*"<O<&%T:"]T;R]I;6%G92YW8FUP)RP*("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:&5I9VAT)R`]/B`Q,#`L("=W
M:61T:"<@/3X@,3`P*2D["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V)L;V-K
M"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H@0'-E92!(;W)D95]-;V)I
M;&5?<F]W"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@
M2&]R9&5?36]B:6QE7VEM86=E(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE
M;G0@>PH*("`@('9A<B`D7W-R8R`]("<G.PH@("`@=F%R("1?871T<FEB=71E
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<W)C("`@("`@("!4:&4@<V]U<F-E(&QO8V%T
M:6]N(&]F('1H92!I;6%G92X*("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB
M=71E<R`@26UA9V4@871T<FEB=71E<RX@06YY(&]F.@H@("`@("H@("`G86QI
M9VXG"B`@("`@*B`@("=A;'0G"B`@("`@*B`@("=H96EG:'0G"B`@("`@*B`@
M("=H<W!A8V4G"B`@("`@*B`@("=V<W!A8V4G"B`@("`@*B`@("=W:61T:"<*
M("`@("`J("`@)V-L87-S)PH@("`@("H@("`G:60G"B`@("`@*B\*("`@(&9U
M;F-T:6]N($AO<F1E7TUO8FEL95]I;6%G92@D<W)C+"`D871T<FEB=71E<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]S<F,@/2`D<W)C.PH@
M("`@("`@("1T:&ES+3Y?871T<FEB=71E<R`]("1A='1R:6)U=&5S.PH@("`@
M?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@86QL;W=S('1O(&EN<V5R="!T86)L
M97,@:6YT;R!A($AO<F1E7TUO8FEL92!O<@H@*B!(;W)D95]-;V)I;&5?9F]R
M;2!O8FIE8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D;7E486)L92`](&YE
M=R!(;W)D95]-;V)I;&5?=&%B;&4H*3L*("H*("H@)')O=S$@/2!N97<@2&]R
M9&5?36]B:6QE7W)O=R@I.PH@*B`D<F]W,2T^861D*"1I;6%G93$I.PH@*B`D
M<F]W,2T^861D*"1T97AT,2D["B`J("1M>51A8FQE+3YA9&0H)')O=S$I.PH@
M*@H@*B`D<F]W,B`](&YE=R!(;W)D95]-;V)I;&5?<F]W*"D["B`J("1R;W<R
M+3YA9&0H)&EM86=E,BD["B`J("1R;W<R+3YA9&0H)'1E>'0R*3L*("H@)&UY
M5&%B;&4M/F%D9"@D<F]W,BD["B`J"B`J("1M>41E8VLM/F%D9"@D;7E486)L
M92D["B`J"B`J($!S964@2&]R9&5?36]B:6QE"B`J($!S964@2&]R9&5?36]B
M:6QE7V9O<FT*("H@0'-E92!(;W)D95]-;V)I;&5?<F]W"B`J"B`J($!P86-K
M86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7W1A8FQE
M(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W)O
M=W,@/2!A<G)A>2@I.PH@("`@=F%R("1?8F]R9&5R(#T@;G5L;#L*("`@('9A
M<B`D7W!A9&1I;F<@/2!N=6QL.PH@("`@=F%R("1?<W!A8VEN9R`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@2&]R9&5?36]B:6QE7W)O=R!O8FIE
M8W0@=&\@2&]R9&5?36]B:6QE7W1A8FQE+@H@("`@("H*("`@("`J($!P87)A
M;2!(;W)D95]-;V)I;&5?<F]W("1R;W<@(%1H92!R;W<@;V)J96-T('1O(&%D
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@)F%D9"@F)')O=RD*("`@('L*("`@
M("`@("!I9B`H(6ES7V$H)')O=RP@)TAO<F1E7TUO8FEL95]R;W<G*2D@>PH@
M("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=2;W=S(&UU
M<W0@8F4@2&]R9&5?36]B:6QE7W)O=R!O8FIE8W1S+B<I.PH@("`@("`@("`@
M("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]R
M;W=S6UT@/2`F)')O=SL*("`@("`@("!R971U<FX@)')O=SL*("`@('T*"GT*
M"B\J*@H@*B!4:&ES(&-L87-S(&1E9FEN97,@=&AE(')O=W,@=&AA="!A($AO
M<F1E7TUO8FEL95]T86)L92!O8FIE8W0*("H@8V]N<VES=',@;V8N"B`J"B`J
M($5X86UP;&5S.@H@*@H@*B`D:6UA9V4Q(#T@;F5W($AO<F1E7TUO8FEL95]I
M;6%G92@B;7E?:6UA9V4N=V)M<"(L(")M>5]I;6%G92YP;F<B+"`B.BTI(BD[
M"B`J("1T97AT,2`](&YE=R!(;W)D95]-;V)I;&5?=&5X="@B;7D@=&5X="(I
M.PH@*B`D<F]W,2`](&YE=R!(;W)D95]-;V)I;&5?<F]W*"D["B`J("1R;W<Q
M+3YA9&0H)&EM86=E,2D["B`J("1R;W<Q+3YA9&0H*3L*("H@)')O=S$M/F%D
M9"@D=&5X=#$I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL95]T86)L90H@*B!`
M<V5E($AO<F1E7TUO8FEL95]T97AT"B`J($!S964@2&]R9&5?36]B:6QE7VEM
M86=E"B`J($!S964@2&]R9&5?36]B:6QE7VQI;FL*("H*("H@0'!A8VMA9V4@
M2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?<F]W(&5X=&5N
M9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7V-O;'5M;G,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@061D<R!A(&-O;'5M;B!E;&5M
M96YT('1O(&$@2&]R9&5?36]B:6QE7W)O=R!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M($AO<F1E7TUO8FEL95]E;&5M96YT("1C96QL16QE;65N="`@
M0V%N(&)E(&$@2&]R9&5?36]B:6QE7W1E>'0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="P@82!(;W)D
M95]-;V)I;&5?:6UA9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]B:F5C="P@82!(;W)D95]-;V)I;&5?;&EN
M:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;V)J96-T(&]R(&YU;&PN(%1H92!L871T97(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<W5L=',@
M:6X@86X@96UP='D@8V5L;"X*("`@("`J+PH@("`@9G5N8W1I;VX@)F%D9"@D
M8V5L;$5L96UE;G0@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]O8FIE
M8W0H)&-E;&Q%;&5M96YT*2D@>PH@("`@("`@("`@("!I9B`H(6ES7V$H)&-E
M;&Q%;&5M96YT+"`G2&]R9&5?36]B:6QE7W1E>'0G*2`F)@H@("`@("`@("`@
M("`@("`@(6ES7V$H)&-E;&Q%;&5M96YT+"`G2&]R9&5?36]B:6QE7VQI;FLG
M*2`F)@H@("`@("`@("`@("`@("`@(6ES7V$H)&-E;&Q%;&5M96YT+"`G2&]R
M9&5?36]B:6QE7VEM86=E)RDI('L*("`@("`@("`@("`@("`@("1E<G)O<B`]
M(%!%05(Z.G)A:7-E17)R;W(H)U1A8FQE(&-E;&QS(&-A;B!O;FQY(&-O;G1A
M:6X@=&5X="P@;&EN:W,L(&]R(&EM86=E<RXG*3L*("`@("`@("`@("`@("`@
M(')E='5R;B`D97)R;W(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/E]C;VQU;6YS6UT@/2`F)&-E;&Q%;&5M96YT.PH@("`@("`@("`@("!R
M971U<FX@)&-E;&Q%;&5M96YT.PH@("`@("`@('T@96QS96EF("@A:7-?;G5L
M;"@D8V5L;$5L96UE;G0I*2!["B`@("`@("`@("`@("1T(#T@)FYE=R!(;W)D
M95]-;V)I;&5?=&5X="@D8V5L;$5L96UE;G0I.PH@("`@("`@("`@("`D=&AI
M<RT^7V-O;'5M;G-;72`]("8D=#L*("`@("`@("`@("`@<F5T=7)N("1T.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?8V]L=6UN<UM=
M(#T@)B1C96QL16QE;65N=#L*("`@("`@("`@("`@<F5T=7)N("1C96QL16QE
M;65N=#L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V]L=6UN
M0V]U;G0H*0H@("`@>PH@("`@("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V-O
M;'5M;G,I.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@
M82!T97AT(&EN<'5T(&9I96QD(&EN(&$@2&]R9&5?36]B:6QE7V9O<FT@;V)J
M96-T+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY26YP=70Q(#T@;F5W($AO
M<F1E7TUO8FEL95]I;G!U="@G8VED)RP@)R<L("=#=7-T;VUE<B!)1"<I.PH@
M*@H@*B`D;7E);G!U=#(@/2!N97<@2&]R9&5?36]B:6QE7VEN<'5T*"=C:60G
M+"`G)RP@)T-U<W1O;65R($E$)RP@)RI.)RD["B`J("1M>4EN<'5T,BT^<V5T
M7W-I>F4H-BD["B`J("1M>4EN<'5T,BT^<V5T7VUA>&QE;F=T:"@V*3L*("H*
M("H@)&UY26YP=70S(#T@;F5W($AO<F1E7TUO8FEL95]I;G!U="@G<'<G+"`G
M)RP@)U!A<W-W;W)D)RP@)RI.)RD["B`J("1M>4EN<'5T,RT^<V5T7W-I>F4H
M."D["B`J("1M>4EN<'5T,RT^<V5T7VUA>&QE;F=T:"@X*3L*("H@)&UY26YP
M=70S+3YS971?='EP92@G<&%S<W=O<F0G*3L*("H*("H@0'-E92!(;W)D95]-
M;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L
M87-S($AO<F1E7TUO8FEL95]I;G!U="!E>'1E;F1S($AO<F1E7TUO8FEL95]F
M;W)M16QE;65N="!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5F%R:6%B;&4@:6X@
M=VAI8V@@=&AE(&EN<'5T(&ES('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&1E<W1I;F%T:6]N(%523"X*("`@("`J($!P87)A
M;2!S=')I;F<@)'9A;'5E("`@26YI=&EA;"!V86QU92!T:&%T('=I;&P@8F4@
M<')E<V5N=&5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!I;G!U="!F:65L9"X*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("`@
M1&5S8W)I8F5S('EO=7(@:6YP=70@9FEE;&0@;VX@=&AE('-U<F9E<B=S"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@('-C<F5E;B]D:7-P;&%Y+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!);G!U="!F;W)M870@8V]D
M92!A8V-O<F1I;F<@=&\@=&AE(%=!4"!S=&%N9&%R9"X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@06QL;W=S('1H92!705`@=7-E<B!C;&EE;G0@
M92YG+B!T;R!I;G!U="!O;FQY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(&1I9VET<R!A;F0@;F\@8VAA<F%C=&5R<RX@3VX@86X@2%1-3"!G96YE
M<F%T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<&%G92!T:&ES
M(&9O<FUA="!H87,@;F\@<VEG;FEF:6-A;F-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!(;W)D95]-;V)I;&5?:6YP=70H)&YA;64L("1V86QU92P@)&QA8F5L
M(#T@)R<L("1F;W)M870@/2`G*DTG*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L=64[
M"B`@("`@("`@)'1H:7,M/E]L86)E;"`]("1L86)E;#L*("`@("`@("`D=&AI
M<RT^7V9O<FUA="`]("1F;W)M870["B`@("`@("`@)'1H:7,M/E]T>7!E(#T@
M)W1E>'0G.PH@("`@("`@("1T:&ES+3Y?;6]D92`]("=A;'!H82<["B`@("!]
M"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A;B!I;G!U="!T97AT
M87)E82!I;B!A($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C="X*("H*("H@17AA
M;7!L97,Z"B`J"B`J("1M>4%R96$Q(#T@;F5W($AO<F1E7TUO8FEL95]T97AT
M87)E82@G9F(G+"`G)RP@)T9E961B86-K)RD["B`J("1M>4%R96$R(#T@;F5W
M($AO<F1E7TUO8FEL95]T97AT87)E82@G;7-G)RP@)T5N=&5R(&UE<W-A9V4@
M:&5R92`N+BXG+"`G365S<V%G92<L(#0P+"`U*3L*("H*("H@0'-E92!(;W)D
M95]-;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO
M"F-L87-S($AO<F1E7TUO8FEL95]T97AT87)E82!E>'1E;F1S($AO<F1E7TUO
M8FEL95]F;W)M16QE;65N="!["@H@("`@=F%R("1?<F]W<SL*("`@('9A<B`D
M7V-O;',["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@5F%R:6%B;&4@:6X@=VAI8V@@
M=&AE(&EN<'5T(&ES('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@9&5S=&EN871I;VX@55),+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=F%L=64@($EN:71I86P@=F%L=64@=&AA="!W:6QL(&)E('!R97-E;G1E
M9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T97AT87)E
M82X*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!$97-C<FEB97,@>6]U
M<B!T97AT87)E82!O;B!T:&4@<W5R9F5R)W,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!S8W)E96XO9&ES<&QA>2X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1R;W=S("!2;W=S+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;',@
M($-O;'5M;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]T
M97AT87)E82@D;F%M92P@)'9A;'5E+"`D;&%B96PL("1R;W=S(#T@,RP@)&-O
M;',@/2`Q-BD*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*
M("`@("`@("`D=&AI<RT^7W9A;'5E(#T@)'9A;'5E.PH@("`@("`@("1T:&ES
M+3Y?;&%B96P@/2`D;&%B96P["B`@("`@("`@)'1H:7,M/E]R;W=S(#T@)')O
M=W,["B`@("`@("`@)'1H:7,M/E]C;VQS(#T@)&-O;',["B`@("`@("`@)'1H
M:7,M/E]M;V1E(#T@)V%L<&AA)SL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L
M87-S('!R;W9I9&5S(&$@<V5L96-T(&5L96UE;G0@:6X@82!(;W)D95]-;V)I
M;&5?9F]R;2!O8FIE8W0N"B`J($ET(&%L;&]W<R!T;R!C<F5A=&4@;W!T:6UI
M>F5D(%=-3"!F;W(@5T%0(&1E=FEC97,@=VAI8V@@87)E(&-A<&%B;&4*("H@
M=&\@:6YT97)P<F5T92!T:&4@3W!E;G=A=F4@1U5)(&5X=&5N<VEO;G,@9F]R
M(%=-3"`Q+C,N($%L;"!O=&AE<@H@*B!734P@9&5V:6-E<R!R96-E:79E(%=-
M3"`Q+C$@8V]M<&%T:6)L92!M87)K=7`@8V]D92P@=VAI8V@@:7,@<75I=&4*
M("H@<VEM:6QA<B!T;R!T:&4@;6%R:W5P(&-O9&4@8W)E871E9"!B>2!T:&4@
M2&]R9&5?36]B:6QE7W)A9&EO(&-L87-S+@H@*@H@*B!%>&%M<&QE<SH*("H*
M("H@)&UY4V5L96-T(#T@;F5W($AO<F1E7TUO8FEL95]S96QE8W0H)V-O;&]R
M)RD["B`J("1M>5-E;&5C="T^861D*"=";'5E)RP@)V(G*3L*("H@)&UY4V5L
M96-T+3YA9&0H)U)E9"<L("=R)RP@=')U92D["B`J("1M>5-E;&5C="T^861D
M*"=996QL;W<G+"`G>2<I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M
M"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?
M36]B:6QE7W-E;&5C="!E>'1E;F1S($AO<F1E7TUO8FEL95]F;W)M16QE;65N
M="!["@H@("`@=F%R("1?='EP93L*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!687)I86)L92!I;B!W:&EC:"!T:&4@
M:6YF;W)M871I;VX@86)O=70@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("!S96QE8W1E9"!O<'1I;VX@:7,@<V5N="!T;R!T:&4@9&5S=&EN871I
M;VX@55),+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5'EP92!O9B!S
M96QE8W0@87)E83H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=P;W!U
M<"<Z('!O<'5P('1H92!W:&]L92!S96QE8W1I;VX@;&ES=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@)W-P:6XG.B`@<F]T871E(&]P=&EO;G,@;VX@
M82!705`@9&5V:6-E('-C<F5E;B`H3U<*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#$N,R!'54D@;VYL>2DN"B`@("`@*B\*("`@(&9U
M;F-T:6]N($AO<F1E7TUO8FEL95]S96QE8W0H)&YA;64L("1T>7!E(#T@)W!O
M<'5P)RD*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@
M("`@("`D=&AI<RT^7W1Y<&4@/2`D='EP93L*("`@("`@("`D=&AI<RT^7W9A
M;'5E(#T@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@;VYE(&]P
M=&EO;B!T;R!A($AO<F1E7TUO8FEL95]S96QE8W0@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("`@("`@("`@1&5S8W)I8F5S
M('1H92!O<'1I;VX@;VX@=&AE('-U<F9E<B=S"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-C<F5E;B]D:7-P;&%Y+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=F%L=64@("`@("`@("!686QU92!S96YT(&EN('1H92`B
M;F%M92(@=F%R:6%B;&4L(&EF('1H:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:7,@=&AE(&]P=&EO;B!S96QE8W1E9"X*("`@("`J
M($!P87)A;2!B;V]L96%N("1I<U]S96QE8W1E9"`@06QL;W=E9"!V86QU97,@
M87)E('1R=64@;W(@9F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D
M;&%B96PL("1V86QU92P@)&ES7W-E;&5C=&5D(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]O<'1I;VYS6UT@/2!A<G)A>2@G;&%B96PG(#T^("1L
M86)E;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU
M92<@/3X@)'9A;'5E*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]V
M86QU92D@?'P@)&ES7W-E;&5C=&5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M=F%L=64@/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J(%1H
M:7,@8VQA<W,@<')O=FED97,@82!R861I;R!B=71T;VX@96QE;65N="!I;B!A
M($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J
M"B`J("1M>5)A9&EO(#T@;F5W($AO<F1E7TUO8FEL95]R861I;R@G8V]U;G1R
M>2<I.PH@*B`D;7E2861I;RT^861D*"=&:6YL86YD)RP@)T8G*3L*("H@)&UY
M4F%D:6\M/F%D9"@G1V5R;6%N>2<L("=')RP@=')U92D["B`J("1M>5)A9&EO
M+3YA9&0H)U-W961E;B<L("=3)RD["B`J"B`J($!S964@2&]R9&5?36]B:6QE
M7V9O<FT*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(
M;W)D95]-;V)I;&5?<F%D:6\@97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L
M96UE;G0@>PH*("`@('9A<B`D7V)U='1O;G,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!687)I86)L92!I;B!W:&EC:"!T:&4@:6YF;W)M871I;VX@
M86)O=70@=&AE('!R97-S960@8G5T=&]N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!I<R!S96YT('1O('1H92!D97-T:6YA=&EO;B!54DPN"B`@("`@
M*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]R861I;R@D;F%M92D*("`@
M('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI
M<RT^7W9A;'5E(#T@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M;VYE(')A9&EO(&)U='1O;B!T;R!A($AO<F1E7TUO8FEL95]R861I;R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@("`@("`@
M($1E<V-R:6)E<R!T:&4@<F%D:6]B=71T;VX@;VX@=&AE('-U<F9E<B=S"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<V-R965N+V1I<W!L
M87DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@("`@("`@5F%L=64@
M<V5N="!I;B!T:&4@(FYA;64B('9A<FEA8FQE+"!I9B!T:&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G5T=&]N(&ES('-E;&5C=&5D
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&ES7V-H96-K960@($%L;&]W960@
M=F%L=65S(&%R92!T<G5E(&]R(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&0H)&QA8F5L+"`D=F%L=64L("1I<U]C:&5C:V5D(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]B=71T;VYS6UT@/2!A<G)A>2@G;&%B96PG
M(#T^("1L86)E;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=V86QU92<@/3X@)'9A;'5E*3L*"B`@("`@("`@:68@*"$D=&AI<RT^7W9A
M;'5E('Q\("@D:7-?8VAE8VME9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]V
M86QU92`]("1V86QU93L*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@5&AI
M<R!C;&%S<R!P<F]V:61E<R!A('-I;F=L92!C:&5C:V)O>"!E;&5M96YT(&EN
M(&$@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*
M("H*("H@)&UY0VAE8VMB;W@@/2!N97<@2&]R9&5?36]B:6QE7V-H96-K8F]X
M*"=A9VUT)RP@)WEE<R<L("=)(&%G<F5E)RD["B`J("1M>4-H96-K8F]X(#T@
M;F5W($AO<F1E7TUO8FEL95]C:&5C:V)O>"@G86=M="<L("=Y97,G+"`G22!A
M9W)E92<L(&9A;'-E*3L*("H@)&UY0VAE8VMB;W@@/2!N97<@2&]R9&5?36]B
M:6QE7V-H96-K8F]X*"=A9VUT)RP@)WEE<R<L("=)(&%G<F5E)RP@=')U92D[
M"B`J"B`J($!N;W1E(%1H92!F:7)S="!A;F0@<V5C;VYD(&5X86UP;&5S(&%R
M92!I9&5N=&EC86PN"B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*
M("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I
M;&5?8VAE8VMB;W@@97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L96UE;G0@
M>PH*("`@('9A<B`D7V-H96-K960["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("!6
M87)I86)L92!I;B!W:&EC:"`B=F%L=64B(&ES('-E;G0@=&\@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@9&5S=&EN871I;VX@55),+"!I
M9B!T:&4@8F]X(&ES(&-H96-K960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V
M86QU92`@("`@4V5E(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E
M;"`@("`@1&5S8W)I8F5S('1H92!C:&5C:V)O>"!O;B!T:&4@<W5R9F5R)W,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!S8W)E96XO9&ES<&QA
M>2X*("`@("`J($!P87)A;2!B;V]L96%N("1C:&5C:V5D("!!;&QO=V5D('9A
M;'5E<R!A<F4@=')U92!O<B!F86QS92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?36]B:6QE7V-H96-K8F]X*"1N86UE+"`D=F%L=64L("1L86)E;"P@
M)&-H96-K960@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@
M(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]V86QU92`]("1V86QU93L*("`@
M("`@("`D=&AI<RT^7VQA8F5L(#T@)&QA8F5L.PH@("`@("`@("1T:&ES+3Y?
M8VAE8VME9"`]("1C:&5C:V5D.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0VAE
M8VME9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAE8VME9#L*
M("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&AI9&1E;B!E
M;&5M96YT<R!I;B!(;W)D95]-;V)I;&5?9F]R;2!O8FIE8W1S+@H@*@H@*B!%
M>&%M<&QE<SH*("H*("H@)&AI9&1E;B`](&YE=R!(;W)D95]-;V)I;&5?:&ED
M9&5N*"=I;G1E<FYA;%]R969E<F5N8V4G+"`G,#@Q-30W,3$G*3L*("H*("H@
M0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D95]-
M;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]H:61D96X@97AT96YD<R!(
M;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M5F%R:6%B;&4@:6X@=VAI8V@@)'9A;'5E(&ES('-E;G0@=&\@=&AE(&1E<W1I
M;F%T:6]N(%523"X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("!3964@
M;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7VAI9&1E
M;B@D;F%M92P@)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F%M92`]
M("1N86UE.PH@("`@("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L=64["B`@("!]
M"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A('-U8FUI="!B=71T
M;VX@9F]R(&$@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T+B!/;F4*("H@2&]R
M9&5?36]B:6QE7V9O<FT@;V)J96-T(&-A;B!C;VYT86EN(&]N;'D@;VYE($AO
M<F1E7TUO8FEL95]S=6)M:70@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H@
M)&UY4W5B;6ET(#T@)FYE=R!(;W)D95]-;V)I;&5?<W5B;6ET*"=3=6)M:70G
M*3L*("H@)&UY4W5B;6ET(#T@)FYE=R!(;W)D95]-;V)I;&5?<W5B;6ET*"=3
M=6)M:70G+"`G=7-E<E]P<F5S<V5D)RD["B`J"B`J($!S964@2&]R9&5?36]B
M:6QE7V9O<FT*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S
M<R!(;W)D95]-;V)I;&5?<W5B;6ET(&5X=&5N9',@2&]R9&5?36]B:6QE7V9O
M<FU%;&5M96YT('L*"B`@("!V87(@)%]F;W)M.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E
M;"`@5VAA="=S('=R:71T96X@;VX@=&AE(&)U='1O;BX*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("!687)I86)L92!I;B!W:&EC:"`B;&%B96PB(&ES
M('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&5S
M=&EN871I;VX@55),+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I
M;&5?<W5B;6ET*"1L86)E;"P@)&YA;64@/2`G)RD*("`@('L*("`@("`@("`D
M=&AI<RT^7VQA8F5L(#T@)&QA8F5L.PH@("`@("`@("1T:&ES+3Y?;F%M92`]
M("1N86UE.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@
M82!L:6YK(&EN(&$@2&]R9&5?36]B:6QE+"!(;W)D95]-;V)I;&5?;&EN:W-E
M="!O<@H@*B!(;W)D95]-;V)I;&5?=&%B;&4@;V)J96-T+@H@*@H@*B!%>&%M
M<&QE<SH*("H*("H@)&UY4&%G92`](&YE=R!(;W)D95]-;V)I;&4H+BXN*3L*
M("H*("H@)&UY3&EN:R`](&YE=R!(;W)D95]-;V)I;&5?;&EN:R@G0V]N=&EN
M=64G+"`G+VUY;F5X='!A9V4N=VUL)RD["B`J("1M>5!A9V4M/F%D9"@D;7E,
M:6YK*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&4*("H@0'-E92!(;W)D95]-
M;V)I;&5?;&EN:W-E=`H@*B!`<V5E($AO<F1E7TUO8FEL95]T86)L90H@*@H@
M*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL
M95]L:6YK(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A
M<B`D7VQA8F5L.PH@("`@=F%R("1?=7)L.PH@("`@=F%R("1?=&ET;&4["B`@
M("!V87(@)%]A8V-E<W-K97D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!$97-C<FEB
M97,@=&AE(&QI;FL@;VX@=&AE('-U<F9E<B=S('-C<F5E;B]D:7-P;&%Y+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@($YE>'0@9&5S=&EN871I;VX@
M861D<F5S<RX@35535"!B92!V86QI9"!834P@*"9A;7`[(&EN<W1E860@;V8@
M)BP@971C+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T:71L92`@268@82!S
M=')I;F<@:7,@<')O=FED960@:&5R92P@:70@=VEL;"!B92!D:7-P;&%Y960*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@2%1-3"!B<F]W
M<V5R('-T871U<R!B87(@9'5R:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(DUO=7-E3W9E<B(L(')E<W!E8W1I=F5L>2!S;VUE=VAE<F4@;VX@
M=&AE(%=!4`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1I<W!L87DN
M($EN(&]R9&5R('1O('=O<FL@=V5L;"!W:71H(&$@8G)O860@<F%N9V4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!O9B!U<V5R(&%G96YT<RP@:V5E
M<"!Y;W5R('1I=&QE('5N9&5R(#8*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-
M;V)I;&5?;&EN:R@D;&%B96PL("1U<FPL("1T:71L92`]("<G*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;&%B96P@/2`D;&%B96P["B`@("`@("`@)'1H:7,M
M/E]U<FP@/2`D=7)L.PH@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4[
M"@H@("`@("`@("\O($YO(&%C8V5S<VME>2!A<W-I9VYE9"!B>2!D969A=6QT
M.R!C86X@8F4@87-S:6=N960@;&%T97(*("`@("`@("`O+R!F<F]M(&$@2&]R
M9&5?36]B:6QE7VQI;FMS970@;V)J96-T(&EF(')E<75I<F5D+@H@("`@("`@
M("1T:&ES+3Y?86-C97-S:V5Y(#T@;G5L;#L*("`@('T*"GT*"B\J*@H@*B!4
M:&ES(&-L87-S('!R;W9I9&5S(&$@<&AO;F4@;G5M8F5R(&EN(&$@2&]R9&5?
M36]B:6QE(&]B:F5C="X@268@<W5P<&]R=&5D(&)Y"B`J('1H96ER(&UO8FEL
M92!D979I8V4L('5S97)S(&-A;B!E<W1A8FQI<V@@82!V;VEC92!C;VYN96-T
M:6]N('1O('1H90H@*B!S<&5C:69I960@;G5M8F5R+@H@*@H@*B!%>&%M<&QE
M<SH*("H*("H@)&UY4&AO;F4@/2`F;F5W($AO<F1E7TUO8FEL95]P:&]N92@G
M,3(S+30U-C<X)RP@)T-!3$PG*3L*("H@)&UY4&%G92T^861D*"1M>5!H;VYE
M*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&4*("H*("H@0'!A8VMA9V4@2&]R
M9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?<&AO;F4@97AT96YD
M<R!(;W)D95]-;V)I;&5?96QE;65N="!["@H@("`@=F%R("1?;&%B96P["B`@
M("!V87(@)%]N=6UB97(["B`@("!V87(@)%]T:71L93L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&AO;F5?;G5M8F5R("!0:&]N92!N=6UB97(@=&\@9&EA;"X*("`@("`J($!P
M87)A;2!S=')I;F<@)'1I=&QE("`@("`@("`@268@82!S=')I;F<@:7,@<')O
M=FED960@:&5R92P@=&AE(&-A;&P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G5T=&]N(&]N(&$@5T%0+TA$34P@9&5V:6-E('=I;&P@
M8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96YA8FQE
M9"X@26X@;W)D97(@=&\@=V]R:R!W96QL('=I=&@*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@82!B<F]A9"!R86YG92!O9B!U<V5R(&%G
M96YT<RP@:V5E<"!Y;W5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1I=&QE('5N9&5R(#8@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?36]B:6QE7W!H;VYE*"1P:&]N95]N=6UB97(L("1T
M:71L92`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&%B96P@/2`D<&AO
M;F5?;G5M8F5R.PH@("`@("`@("1T:&ES+3Y?;G5M8F5R(#T@<')E9U]R97!L
M86-E*"=\7$1\)RP@)R<L("1P:&]N95]N=6UB97(I.PH@("`@("`@("1T:&ES
M+3Y?=&ET;&4@/2`D=&ET;&4["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S
M<R!D969I;F5S(&$@<V5T(&]F(&QI;FMS+B!4:&4@;&EN:W,@:&%V92!T;R!B
M92!D969I;F5D(&%S"B`J('-E<&%R871E($AO<F1E7TUO8FEL95]L:6YK(&]B
M:F5C=',@86YD(&%R92!A='1A8VAE9"!T;R!T:&4@;&EN:W-E=`H@*B!W:71H
M(&$@<W!E8VEA;"`B861D(B!F=6YC=&EO;BX@($9O<B!705`@9&5V:6-E<R!B
M<F]W<V5R+61E<&5N9&5N=`H@*B!734P@8V]D92!W:6QL(&)E(&-R96%T960N
M($]N(&%L;"!54"UB<F]W<V5R+6)A<V5D(%=!4"!D979I8V5S"B`J(&QI;FMS
M971S(&%L;&]W(&5A<VEE<B!N879I9V%T:6]N('1H<F]U9V@@5TU,(&1E8VMS
M(&)Y('5S:6YG('1H90H@*B`B;VYP:6-K(B!734P@;W!T:6]N(&%N9"!T:&5R
M969O<F4@87)E(&EM<')O=FEN9R!T:&4@(G5S86)I;&ET>2(@;V8*("H@86X@
M87!P;&EC871I;VXN($EN<W1E860@;V8@<&%I;F9U;&QY(&YA=FEG871I;F<@
M=&AR;W5G:"!T:&4@;&EN:W,*("H@(G-P;W)T<RT^9F]O=&)A;&PM/G)E<W5L
M=',M/G1O9&%Y(B!T:&4@;6]B:6QE('5S97(@92YG+B!C86X@<')E<W,*("H@
M(C(T,S$B(&]N('1H92!K97EP860@=&\@96YT97(@:&ES(&9A=F]R:71E(&1E
M8VLN($9O<B!A;&P@;W1H97(@5T%0"B`J(&1E=FEC97,@;F]R;6%L(#QA/B!T
M86=S(&%R92!C<F5A=&5D+B!/;F4@2&]R9&5?36]B:6QE(&]B:F5C="!C86X*
M("H@8V]N=&%I;B!O;FQY(&]N92!L:6YK<V5T(&]B:F5C="X*("H*("H@17AA
M;7!L97,Z"B`J"B`J("1M>5!A9V4@/2!N97<@2&]R9&5?36]B:6QE*"XN+BD[
M"B`J"B`J("1M>4QI;FMS970@/2!N97<@2&]R9&5?36]B:6QE7VQI;FMS970H
M*3L*("H@)&UY3&EN:S$@/2!N97<@2&]R9&5?36]B:6QE7VQI;FLH(E!H;VYE
M8F]O:R(L("(O=V%P+W!H;VYE8F]O:RYW;6PB*3L*("H@)&UY3&EN:W-E="T^
M861D*"1M>4QI;FLQ*3L*("H@)&UY3&EN:S(@/2!N97<@2&]R9&5?36]B:6QE
M7VQI;FLH(D1A=&5";V]K(BP@(B]W87`O9&%T96)O;VLN=VUL(BD["B`J("1M
M>4QI;FMS970M/F%D9"@D;7E,:6YK,BD["B`J"B`J("1M>5!A9V4M/F%D9"@D
M;7E,:6YK<V5T*3L*("H*("H@)&UY4&%G92T^<F5N9&5R*"D["B`J"B`J($!S
M964@2&]R9&5?36]B:6QE7VQI;FL*("H@0'-E92!(;W)D95]-;V)I;&4*("H*
M("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I
M;&5?;&EN:W-E="!E>'1E;F1S($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@
M("!V87(@)%]E;&5M96YT<SL*"B`@("`O*BH*("`@("`J($%D9',@82!(;W)D
M95]-;V)I;&5?;&EN:R!O8FIE8W0@=&\@2&]R9&5?36]B:6QE7VQI;FMS970N
M"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7TUO8FEL95]L:6YK("1L:6YK
M("!4:&4@;&EN:R!O8FIE8W0@=&\@861D+@H@("`@("H*("`@("`J($!S964@
M2&]R9&5?36]B:6QE7VQI;FL*("`@("`J+PH@("`@9G5N8W1I;VX@)F%D9"@F
M)&QI;FLI"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1L:6YK+"`G2&]R9&5?
M36]B:6QE7VQI;FLG*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR
M86ES945R<F]R*"=,:6YK<R!M=7-T(&)E($AO<F1E7TUO8FEL95]L:6YK(&]B
M:F5C=',N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&QI;FL["B`@("`@
M("`@)&QI;FLM/G-E="@G86-C97-S:V5Y)RP@8V]U;G0H)'1H:7,M/E]E;&5M
M96YT<RDI.PH*("`@("`@("!R971U<FX@)&QI;FL["B`@("!]"@I]"@HO*BH*
M("H@5&AI<R!C;&%S<R!W:6QL(&-A=7-E(&$@:&]R:7IO;G1A;"!R=6QE('1O
M(&)E(&1R87=N(&%C<F]S<R!T:&4@<V-R965N+B`@66]U"B`J(&-A;B!U<V4@
M:70@=&\@<V5P87)A=&4@=&5X="!P87)A9W)A<&AS(&EN($AO<F1E7TUO8FEL
M92!O<B!(;W)D95]-;V)I;&5?9F]R;0H@*B!O8FIE8W1S+@H@*@H@*B!%>&%M
M<&QE<SH*("H*("H@)&UY1&5F875L=%)U;&4@/2!N97<@2&]R9&5?36]B:6QE
M7W)U;&4H*3L*("H@)&UY4W!E8VEA;%)U;&4@/2!N97<@2&]R9&5?36]B:6QE
M7W)U;&4H)S8P)2<L(#0I.PH@*@H@*B`D;7E086=E+3YA9&0H)&UY1&5F875L
M=%)U;&4I.PH@*@H@*B`D;7E086=E+3YA9&0H)&UY4W!E8VEA;%)U;&4I.PH@
M*@H@*B!`<V5E($AO<F1E7TUO8FEL90H@*B!`<V5E($AO<F1E7TUO8FEL95]F
M;W)M"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R
M9&5?36]B:6QE7W)U;&4@97AT96YD<R!(;W)D95]-;V)I;&5?96QE;65N="![
M"@H@("`@=F%R("1?=VED=&@["B`@("!V87(@)%]S:7IE.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D=VED=&@@(%!E<F-E;G1A9V4@;V8@<V-R965N('=I9'1H(&]R(&%B<V]L
M=71E('9A;'5E(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&YU
M;6)E<B!O9B!P:7AE;',@*&4N9RX@(C4P)2(L(#$P,"DN"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<VEZ92`@($AE:6=H="!O9B!T:&4@;&EN92!T;R!B92!D
M<F%W;B!I;B!P:7AE;',N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO
M8FEL95]R=6QE*"1W:61T:"`]("<G+"`D<VEZ92`]("<G*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?=VED=&@@/2`D=VED=&@["B`@("`@("`@)'1H:7,M/E]S
M:7IE(#T@)'-I>F4["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXN<&AP````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<P,S(`,3`T,3<S-C(W-S,`,#(Q
M,S<T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@3F]T:69I8V%T:6]N.CH@8VQA<W,@<')O=FED
M97,@82!S=6)J96-T+6]B<V5R=F5R('!A='1E<FX@9F]R"B`J(')A:7-I;F<@
M86YD('-H;W=I;F<@;65S<V%G97,@;V8@9&EF9F5R96YT('1Y<&5S(&%N9"!T
M;R!D:69F97)E;G0*("H@;&ES=&5N97)S+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+G!H<"QV(#$N-#8N,BXQ
M,2`R,#`V+S`Q+S$X(#$U.C$Y.C`Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@
M2&]R9&5?3F]T:69I8V%T:6]N"B`J+PIC;&%S<R!.;W1I9FEC871I;VX@>PH*
M("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG(&%L;"!A='1A8VAE9"!L
M:7-T96YE<B!O8FIE8W1S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?;&ES=&5N97)S(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J(%1H92!N86UE(&]F('1H92!S97-S:6]N('9A<FEA8FQE('=H97)E
M('=E('-T;W)E('1H92!M97-S86=E<RX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]S=&%C:R`]("=H;W)D94UE<W-A9V53
M=&%C:W,G.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T
M;R!T:&4@9VQO8F%L($YO=&EF:6-A=&EO;B!O8FIE8W0L(&]N;'D*("`@("`J
M(&-R96%T:6YG(&ET(&EF(&ET(&1O97-N)W0@86QR96%D>2!E>&ES="X*("`@
M("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z"B`@
M("`@*B`@("1N;W1I9FEC871I;VX@/2`F3F]T:69I8V%T:6]N.CIS:6YG;&5T
M;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T86-K("!4:&4@
M;F%M92!O9B!T:&4@;65S<V%G92!S=&%C:R!T;R!U<V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!.;W1I9FEC871I;VX@(%1H92!(;W)D92!.;W1I9FEC871I
M;VX@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH
M)'-T86-K(#T@)VAO<F1E365S<V%G95-T86-K<R<I"B`@("!["B`@("`@("`@
M<W1A=&EC("1N;W1I9FEC871I;VX@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H
M(6ES<V5T*"1N;W1I9FEC871I;VY;)'-T86-K72DI('L*("`@("`@("`@("`@
M)&YO=&EF:6-A=&EO;ELD<W1A8VM=(#T@;F5W($YO=&EF:6-A=&EO;B@D<W1A
M8VLI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1N;W1I9FEC871I;VY;
M)'-T86-K73L*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QI>F4@=&AE
M(&YO=&EF:6-A=&EO;B!S>7-T96TL('-E="!U<"!A;GD@;F5E9&5D('-E<W-I
M;VX*("`@("`J('9A<FEA8FQE<RP@971C+B!3:&]U;&0@;F5V97(@8F4@8V%L
M;&5D(&5X8V5P="!B>0H@("`@("H@)DYO=&EF:6-A=&EO;CHZ<VEN9VQE=&]N
M*"D["B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1A8VL@(%1H92!N
M86UE(&]F('1H92!M97-S86=E('-T86-K('1O('5S92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@3F]T:69I8V%T:6]N*"1S=&%C:R`]("=H;W)D94UE<W-A9V53
M=&%C:W,G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<W1A8VL@/2`D<W1A8VL[
M"@H@("`@("`@("\J($UA:V4@<W5R92!T:&4@;65S<V%G92!S=&%C:R!I<R!R
M96=I<W1E<F5D(&EN('1H92!S97-S:6]N+`H@("`@("`@("`J(&%N9"!O8G1A
M:6X@82!G;&]B86PM<V-O<&4@<F5F97)E;F-E('1O(&ET+B`J+PH@("`@("`@
M(&EF("@A:7-S970H)%]315-324].6R1T:&ES+3Y?<W1A8VM=*2D@>PH@("`@
M("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UT@/2!A<G)A>2@I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E9VES=&5R<R!A(&QI
M<W1E;F5R('=I=&@@=&AE(&YO=&EF:6-A=&EO;B!O8FIE8W0@86YD(&EN8VQU
M9&5S"B`@("`@*B!T:&4@;F5C97-S87)Y(&QI8G)A<GD@9FEL92!D>6YA;6EC
M86QL>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%1H
M92!N86UE(&]F('1H92!L:7-T96YE<B!T;R!A='1A8V@N(%1H97-E(&YA;65S
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&UU<W0@8F4@=6YI<75E
M.R!F=7)T:&5R(&QI<W1E;F5R<R!W:71H('1H92!S86UE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&YA;64@=VEL;"!B92!I9VYO<F5D+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A(&QI<W1E
M;F5R(&1R:79E<B!M:6=H=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!N965D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@("!4:&4@8VQA
M<W,@;F%M92!F<F]M('=H:6-H('1H92!D<FEV97(@=V%S"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&EN<W1A;G1I871E9"!I9B!N;W0@=&AE(&1E
M9F%U;'0@;VYE+B!)9B!G:79E;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!Y;W4@:&%V92!T;R!I;F-L=61E('1H92!L:6)R87)Y(&9I;&4@8V]N
M=&%I;FEN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!T:&ES(&-L
M87-S('EO=7)S96QF+B!4:&ES(&ES('5S969U;"!I9B!Y;W4@=V%N=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;&ES=&5N97(@9')I=F5R
M('1O(&)E(&]V97)R:61E;B!B>2!A;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!A<'!L:6-A=&EO;B=S(&EM<&QE;65N=&%T:6]N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F871T86-H*"1L:7-T96YE<BP@)'!A<F%M<R`](&%R
M<F%Y*"DL("1C;&%S<R`](&YU;&PI"B`@("!["B`@("`@("`@)&QI<W1E;F5R
M(#T@8F%S96YA;64H)&QI<W1E;F5R*3L*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<ETI*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES7VYU;&PH)&-L87-S*2D@>PH@("`@("`@("`@("!`
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R].;W1I9FEC871I
M;VXO3&ES=&5N97(O)R`N("1L:7-T96YE<B`N("<N<&AP)SL*("`@("`@("`@
M("`@)&-L87-S(#T@)TYO=&EF:6-A=&EO;E],:7-T96YE<E\G("X@)&QI<W1E
M;F5R.PH@("`@("`@('T*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S
M<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R
M72`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1?4T534TE/3ELD=&AI<RT^7W-T86-K75LD;&ES=&5N97)=*2D@>PH@
M("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?<W1A8VM=6R1L:7-T
M96YE<ET@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H)TYO=&EF:6-A=&EO;B!L:7-T96YE<B`E<R!N;W0@9F]U;F0N)RP@
M)&QI<W1E;F5R*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5M;W9E(&$@;&ES=&5N97(@9G)O;2!T:&4@;F]T:69I8V%T:6]N(&QI<W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&ES=&YE<B`@5&AE(&YA
M;64@;V8@=&AE(&QI<W1E;F5R('1O(&1E=&%C:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5T86-H*"1L:7-T96YE<BD*("`@('L*("`@("`@("`D;&ES=&5N
M97(@/2!B87-E;F%M92@D;&ES=&5N97(I.PH@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R72DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G3F]T:69I8V%T:6]N
M(&QI<W1E;F5R("5S(&YO="!F;W5N9"XG+"`D;&ES=&5N97(I*3L*("`@("`@
M("!]"@H@("`@("`@("1L:7-T(#T@)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E
M;F5R73L*("`@("`@("!U;G-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N
M97)=*3L*("`@("`@("!U;G-E="@D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;
M)&QI<W0M/F=E=$YA;64H*5TI.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D(&%N(&5V96YT('1O('1H92!(;W)D92!M
M97-S86=E('-T86-K+@H@("`@("H*("`@("`J(%1H92!E=F5N="!T>7!E('!A
M<F%M971E<B!S:&]U;&0@8F5G:6X@=VET:"`G:&]R9&4N)R!U;FQE<W,@=&AE
M"B`@("`@*B!A<'!L:6-A=&EO;B!D969I;F5S(&ET<R!O=VX@3F]T:69I8V%T
M:6]N7TQI<W1E;F5R('-U8F-L87-S('1H870*("`@("`J(&AA;F1L97,@861D
M:71I;VYA;"!C;V1E<RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&5V
M96YT("`@3F]T:69I8V%T:6]N7T5V96YT(&]B:F5C="!O<B!M97-S86=E('-T
M<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1T>7!E("!4:&4@='EP92!O
M9B!M97-S86=E.B`G:&]R9&4N97)R;W(G+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("=H;W)D92YW87)N:6YG)RP@)VAO<F1E+G-U8V-E<W,G+"!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YM97-S86=E
M)RX*("`@("`J($!P87)A;2!A<G)A>2`D9FQA9W,@("!!<G)A>2!O9B!O<'1I
M;VYA;"!F;&%G<R!T:&%T('=I;&P@8F4@<&%S<V5D('1O('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(')E9VES=&5R960@;&ES=&5N97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P=7-H*"1E=F5N="P@)'1Y<&4@/2!N=6QL
M+"`D9FQA9W,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M979E;G0L("=.;W1I9FEC871I;VY?179E;G0G*2`F)@H@("`@("`@("`@("`A
M:7-?82@D979E;G0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@+RH@
M5')A;G-P87)E;G1L>2!C<F5A=&4@82!.;W1I9FEC871I;VY?179E;G0@;V)J
M96-T(&%N9`H@("`@("`@("`@("`@*B!S970@=&AE(&UE<W-A9V4@871T<FEB
M=71E+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+TYO=&EF:6-A=&EO;B]%=F5N="YP:'`G.PH@("`@("`@("`@
M("`D979E;G0@/2`F;F5W($YO=&EF:6-A=&EO;E]%=F5N="@D979E;G0I.PH@
M("`@("`@('T*("`@("`@("!I9B`H:7-?82@D979E;G0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D='EP92DI('L*("`@("`@
M("`@("`@("`@("1T>7!E(#T@)VAO<F1E+F5R<F]R)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D979E;G0L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H(6ES<V5T*"1T>7!E*2D@>PH@("`@("`@("`@("`D='EP92`]
M("=H;W)D92YM97-S86=E)SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?;&ES=&5N97)S(&%S("1L:7-T96YE<BD@>PH@("`@("`@("`@
M("!I9B`H)&QI<W1E;F5R+3YH86YD;&5S*"1T>7!E*2D@>PH@("`@("`@("`@
M("`@("`@)%]315-324].6R1T:&ES+3Y?<W1A8VM=6R1L:7-T96YE<BT^9V5T
M3F%M92@I75M=(#T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G='EP92<@
M/3X@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)V-L87-S)R`]
M/B!G971?8VQA<W,H)&5V96YT*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`G979E;G0G(#T^('-E<FEA;&EZ92@D979E;G0I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("=F;&%G<R<@/3X@<V5R:6%L:7IE*"1F;&%G<RDI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4&%S<V5S('1H92!M97-S86=E('-T86-K('1O(&%L;"!L:7-T96YE<G,@86YD
M(&%S:W,@=&AE;2!T;PH@("`@("H@:&%N9&QE('1H96ER(&UE<W-A9V5S+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@06X@87)R87D@
M8V]N=&%I;FEN9R!D:7-P;&%Y(&]P=&EO;G,@9F]R('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!L:7-T96YE<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YO=&EF>2@D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*"%I<W-E="@D;W!T:6]N<ULG;&ES=&5N97)S)UTI*2!["B`@("`@
M("`@("`@("1O<'1I;VYS6R=L:7-T96YE<G,G72`](&%R<F%Y7VME>7,H)'1H
M:7,M/E]L:7-T96YE<G,I.PH@("`@("`@('T@96QS96EF("@A:7-?87)R87DH
M)&]P=&EO;G-;)VQI<W1E;F5R<R==*2D@>PH@("`@("`@("`@("`D;W!T:6]N
M<ULG;&ES=&5N97)S)UT@/2!A<G)A>2@D;W!T:6]N<ULG;&ES=&5N97)S)UTI
M.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;W!T:6]N<ULG;&ES=&5N
M97)S)UT@87,@)&QI<W1E;F5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&ES
M=&5N97)S6R1L:7-T96YE<ETM/FYO=&EF>2@D7U-%4U-)3TY;)'1H:7,M/E]S
M=&%C:UU;)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R72T^9V5T3F%M92@I
M72P@)&]P=&EO;G,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@;G5M8F5R(&]F(&YO=&EF:6-A=&EO;B!M97-S86=E<R!I
M;B!T:&4@<W1A8VLN"B`@("`@*@H@("`@("H@0&%U=&AO<B!$879I9"!5;&5V
M:71C:"`\9&%V:61U0&5V97)Y9&YS+FYE=#X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M>5]L:7-T96YE<B`@5&AE(&YA;64@;V8@=&AE(&QI<W1E
M;F5R+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E
M<B!O9B!M97-S86=E<R!I;B!T:&4@<W1A8VLN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O=6YT*"1M>5]L:7-T96YE<B`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*&ES7VYU;&PH)&UY7VQI<W1E;F5R*2D@>PH@("`@("`@("`@("`D8V]U
M;G0@/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQI<W1E;F5R
M<R!A<R`D;&ES=&5N97(I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;)&QI<W1E;F5R+3YG971.86UE*"E=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;W5N="`K/2!C;W5N="@D7U-%
M4U-)3TY;)'1H:7,M/E]S=&%C:UU;)&QI<W1E;F5R+3YG971.86UE*"E=*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)&-O=6YT.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!`8V]U;G0H)%]315-324].6R1T:&ES+3Y?<W1A8VM=6R1T:&ES+3Y?
M;&ES=&5N97)S6R1M>5]L:7-T96YE<ETM/F=E=$YA;64H*5TI.PH@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4&5R;7,N
M<&AP````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,Q
M,3<Q`#$P-#$W,S8R-S<S`#`R,#`S-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*+RHJ($5X:7-T96YC92!O9B!O
M8FIE8W0@:7,@:VYO=VX@+2!O8FIE8W0@:7,@<VAO=VX@=&\@=7-E<BX@*B\*
M9&5F:6YE*"=015)-4U]32$]7)RP@,BD["@HO*BH@0V]N=&5N=',@;V8@=&AE
M(&]B:F5C="!C86X@8F4@<F5A9"X@*B\*9&5F:6YE*"=015)-4U]214%$)RP@
M-"D["@HO*BH@0V]N=&5N=',@;V8@=&AE(&]B:F5C="!C86X@8F4@961I=&5D
M+B`J+PID969I;F4H)U!%4DU37T5$250G+"`X*3L*"B\J*B!4:&4@;V)J96-T
M(&-A;B!B92!D96QE=&5D+B`J+PID969I;F4H)U!%4DU37T1%3$5412<L(#$V
M*3L*"B\J*@H@*B!!(&)I=&UA<VL@;V8@86QL('!O<W-I8FQE('!E<FUI<W-I
M;VX@=F%L=65S+B!5<V5F=6P@9F]R"B`J(')E;6]V95AX>%!E<FUI<W-I;VXH
M*2P@=6YS971097)M*"DL(&5T8RX*("HO"F1E9FEN92@G4$5235-?04Q,)RP@
M4$5235-?4TA/5R!\(%!%4DU37U)%040@?"!015)-4U]%1$E4('P@4$5235-?
M1$5,151%*3L*"B\J*@H@*B!4:&4@4&5R;7,Z.B!C;&%S<R!P<F]V:61E<R!T
M:&4@2&]R9&4@<&5R;6ES<VEO;G,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`L=B`Q+C@P+C$P+C@@,C`P-B\P,2\P
M,2`R,3HR.#HS,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G
M92!(;W)D95]097)M<PH@*B\*8VQA<W,@4&5R;7,@>PH*("`@("\J*@H@("`@
M("H@0V%C:&5S(&EN9F]R;6%T:6]N(&%B;W5T(&%P<&QI8V%T:6]N('!E<FUI
M<W-I;VYS+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?87!P;&EC871I;VY097)M:7-S:6]N<SL*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&%V86EL86)L92!P97)M:7-S:6]N<R!F;W(@82!G:79E
M;B!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4
M:&4@<&5R;6ES<VEO;B=S(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@06X@87)R87D@;V8@879A:6QA8FQE('!E<FUI<W-I;VYS(&%N9"!T
M:&5I<B!T:71L97,@;W(*("`@("`J("`@("`@("`@("`@("`@(&9A;'-E(&EF
M(&YO="!S=6(@<&5R;6ES<VEO;G,@97AI<W0@9F]R('1H:7,@;&5V96PN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$%V86EL86)L92@D;F%M92D*("`@('L*
M("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("!I9B`H96UP='DH
M)&YA;64I*2!["B`@("`@("`@("`@("\J($YO(&YA;64@<&%S<V5D+"!S;R!T
M;W`@;&5V96P@<&5R;6ES<VEO;G,@87)E(')E<75E<W1E9"X@5&AE<V4*("`@
M("`@("`@("`@("H@8V%N(&]N;'D@8F4@87!P;&EC871I;VYS+B`J+PH@("`@
M("`@("`@("`D87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H87)R87DH)VYO
M=&]O;&)A<B<L("=A8W1I=F4G+"`G:&ED9&5N)RDL('1R=64I.PH@("`@("`@
M("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1A<'!S*2!A<R`D87!P*2!["B`@
M("`@("`@("`@("`@("`D87!P<ULD87!P72`]("1R96=I<W1R>2T^9V5T*"=N
M86UE)RP@)&%P<"D@+B`G("@G("X@)&%P<"`N("<I)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!A<V]R="@D87!P<RD["B`@("`@("`@("`@(')E='5R
M;B`D87!P<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!.86UE
M(&AA<R!B965N('!A<W-E9"P@97AP;&]D92!T:&4@;F%M92!T;R!G970@86QL
M('1H92!L979E;',@:6X*("`@("`@("`@("`@("H@<&5R;6ES<VEO;B!B96EN
M9R!R97%U:7-T960L('=I=&@@=&AE(&%P<"!A<R!T:&4@9FER<W0@;&5V96PN
M("HO"B`@("`@("`@("`@("1L979E;',@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`D;&5V96QS(#T@97AP;&]D92@G.B<L("1N86UE*3L*"B`@("`@("`@("`@
M("\J($9I<G-T(&QE=F5L(&ES(&%L=V%Y<R!A<'`N("HO"B`@("`@("`@("`@
M("1A<'`@/2`D;&5V96QS6S!=.PH*("`@("`@("`@("`@+RH@4F5T=7)N(&5M
M<'1Y(&EF(&YO(&%P<"!D969I;F5D($%022!M971H;V0@9F]R('!R;W9I9&EN
M9PH@("`@("`@("`@("`@*B!P97)M:7-S:6]N(&EN9F]R;6%T:6]N+B`J+PH@
M("`@("`@("`@("!I9B`H(21R96=I<W1R>2T^:&%S365T:&]D*"=P97)M<R<L
M("1A<'`I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($-A;&P@=&AE(&%P<"=S('!E<FUI
M<W-I;VX@9G5N8W1I;VX@=&\@<F5T=7)N('1H92!P97)M:7-S:6]N<PH@("`@
M("`@("`@("`@*B!S<&5C:69I8R!T;R!T:&ES(&%P<"X@*B\*("`@("`@("`@
M("`@)'!E<FUS(#T@)'1H:7,M/F=E=$%P<&QI8V%T:6]N4&5R;6ES<VEO;G,H
M)&%P<"D["B`@("`@("`@("`@(&EF("AI<U]A*"1P97)M<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1P97)M<SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A
M>2YP:'`G.PH@("`@("`@("`@("`O*B!'970@=&AE('!A<G0@;V8@=&AE(&%P
M<"=S('!E<FUI<W-I;VYS(&)A<V5D(&]N('1H92!P97)M:7-S:6]N"B`@("`@
M("`@("`@("`J(&YA;64@<F5Q=65S=&5D+B`J+PH@("`@("`@("`@("`D8VAI
M;&1R96X@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D<&5R;7-;)W1R964G
M72P@)&QE=F5L<RD["B`@("`@("`@("`@(&EF("@D8VAI;&1R96X@/3T](&9A
M;'-E('Q\"B`@("`@("`@("`@("`@("`A:7-?87)R87DH)&-H:6QD<F5N*2!\
M?`H@("`@("`@("`@("`@("`@(6-O=6YT*"1C:&EL9')E;BDI('L*("`@("`@
M("`@("`@("`@("\J($YO(&%R<F%Y(&]F(&-H:6QD<F5N(&%V86EL86)L92!F
M;W(@=&AI<R!P97)M:7-S:6]N(&YA;64N("HO"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1P97)M
M<U]L:7-T(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&-H:6QD
M<F5N(&%S("1P97)M7VME>2`]/B`D<&5R;5]V86PI('L*("`@("`@("`@("`@
M("`@("1P97)M<U]L:7-T6R1P97)M7VME>5T@/2`D<&5R;7-;)W1I=&QE)UU;
M)&YA;64@+B`G.B<@+B`D<&5R;5]K97E=.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B`D<&5R;7-?;&ES=#L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S:&]R="!N86UE(&]F(&%N(&]B
M:F5C="P@=&AE(&QA<W0@<&]R=&EO;B!O9B!T:&4@9G5L;"!N86UE+@H@("`@
M("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@;F%M92!O9B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@;V)J96-T)W,@<VAO<G0@;F%M92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4VAO<G1.86UE*"1N86UE*0H@("`@>PH@
M("`@("`@("\J($EF('1H97)E(&%R92!S979E<F%L(&-O;7!O;F5N=',@=&\@
M=&AE(&YA;64L(&5X<&QO9&4@86YD"B`@("`@("`@("H@9V5T('1H92!L87-T
M(&]N92P@;W1H97)W:7-E(&IU<W0@<F5T=7)N('1H92!N86UE+B`J+PH@("`@
M("`@(&EF("AS=')P;W,H)&YA;64L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>5]P;W`H97AP;&]D92@G.B<L("1N86UE*2D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1N86UE.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@<&5R;6ES
M<VEO;B!N86UE+"!R971U<FYS('1H92!T:71L92!F;W(@=&AA="!P97)M:7-S
M:6]N(&)Y"B`@("`@*B!L;V]K:6YG(&ET('5P(&EN('1H92!A<'!L:6-A=&EO
M;G,G<R!P97)M:7-S:6]N(&%P:2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@<&5R;6ES<VEO;G,G<R!N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@=&ET;&4@9F]R('1H92!P97)M:7-S
M:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714:71L92@D;F%M92D*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D;&5V96QS
M(#T@97AP;&]D92@G.B<L("1N86UE*3L*("`@("`@("!I9B`H8V]U;G0H)&QE
M=F5L<RD@/3T@,2D@>PH@("`@("`@("`@("!R971U<FX@)')E9VES=')Y+3YG
M970H)VYA;64G+"`D;F%M92D@+B`G("@G("X@)&YA;64@+B`G*2<["B`@("`@
M("`@?0H@("`@("`@("1P97)M(#T@87)R87E?<&]P*"1L979E;',I.PH*("`@
M("`@("`O*B!&:7)S="!L979E;"!I<R!A;'=A>7,@87!P+B`J+PH@("`@("`@
M("1A<'`@/2`D;&5V96QS6S!=.PH*("`@("`@("`O*B!2971U<FX@96UP='D@
M:68@;F\@87!P(&1E9FEN960@05!)(&UE=&AO9"!F;W(@<')O=FED:6YG('!E
M<FUI<W-I;VX*("`@("`@("`@*B!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I
M9B`H(21R96=I<W1R>2T^:&%S365T:&]D*"=P97)M<R<L("1A<'`I*2!["B`@
M("`@("`@("`@(')E='5R;B!097)M<SHZ9V5T4VAO<G1.86UE*"1N86UE*3L*
M("`@("`@("!]"@H@("`@("`@("1A<'!?<&5R;7,@/2`D=&AI<RT^9V5T07!P
M;&EC871I;VY097)M:7-S:6]N<R@D87!P*3L*"B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1A<'!?<&5R;7-;)W1I=&QE)UU;)&YA;65=*0H@("`@("`@("`@("`_
M("1A<'!?<&5R;7-;)W1I=&QE)UU;)&YA;65=("X@)R`H)R`N($1A=&%4<F5E
M.CIG9713:&]R=$YA;64H)&YA;64I("X@)RDG"B`@("`@("`@("`@(#H@1&%T
M851R964Z.F=E=%-H;W)T3F%M92@D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T('!E<FUI<W-I;VYS(&EM
M<&QE;65N=&5D(&)Y(&%N(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!S
M:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M<'`@($%N(&%P<&QI8V%T:6]N(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@2&%S:"!W:71H('!E<FUI<W-I;VYS(&EN9F]R;6%T:6]N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971!<'!L:6-A=&EO;E!E<FUI<W-I;VYS
M*"1A<'`I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V%P<&QI
M8V%T:6]N4&5R;6ES<VEO;G-;)&%P<%TI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?87!P;&EC871I;VY097)M:7-S:6]N<ULD87!P72`]("1'3$]"04Q36R=R
M96=I<W1R>2==+3YC86QL0GE086-K86=E*"1A<'`L("=P97)M<R<I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?87!P;&EC871I;VY097)M
M:7-S:6]N<ULD87!P73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!N97<@<&5R;6ES<VEO;G,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!P97)M:7-S:6]N)W,@;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(%!E<FUI<W-I;VYS("!!(&YE=R!P97)M:7-S:6]N
M<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9N97=097)M:7-S:6]N
M*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S
M92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@4&5R;6ES<VEO;B!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@
M;F%M960@<&5R;6ES<VEO;BP*("`@("`J('=I=&@@=&AE('5S97)S(&%N9"!O
M=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!P97)M
M:7-S:6]N('1O(')E=')I979E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T
M4&5R;6ES<VEO;B@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(BDI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(%!E<FUI<W-I;VX@;V)J96-T(&-O<G)E<W!O;F1I
M;F<@=&\@=&AE(&=I=F5N('5N:7%U92!)1"P@=VET:`H@("`@("H@=&AE('5S
M97)S(&%N9"!O=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!U;FEQ=64@
M240@;V8@=&AE('!E<FUI<W-I;VX@=&\@<F5T<FEE=F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9G971097)M:7-S:6]N0GE)9"@D8VED*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A
M=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N
M<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<&5R;6ES<VEO;B!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+B!4:&4@<&5R;6ES<VEO;B!M=7-T(&9I
M<G-T"B`@("`@*B!B92!C<F5A=&5D('=I=&@@4&5R;3HZ;F5W4&5R;6ES<VEO
M;B@I+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<PH@("`@("H@861D960@
M=&\@:70L(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@4&5R;6ES<VEO;B`D<&5R;2`@5&AE(&YE=R!P97)M
M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&5R;6ES<VEO;B@F
M)'!E<FTI"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V
M97,@82!P97)M:7-S:6]N(&9R;VT@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2!P
M97)M86YE;G1L>2X*("`@("`J"B`@("`@*B!`<&%R86T@4&5R;6ES<VEO;B`D
M<&5R;2`@5&AE('!E<FUI<W-I;VX@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&9O<F-E("`@($9O<F-E('1O(')E;6]V92!E=F5R>2!C:&EL
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E4&5R;6ES<VEO;B@F)'!E
M<FTL("1F;W)C92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&:6YD<R!O=70@=VAA="!R:6=H=',@=&AE(&=I=F5N('5S97(@
M:&%S('1O('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`D<&5R;6ES<VEO;B`@5&AE(&9U;&P@<&5R;6ES<VEO;B!N86UE(&]F('1H
M92!O8FIE8W0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8VAE8VL@=&AE('!E<FUI<W-I;VYS(&]F+"!O<B!T:&4@4&5R;6ES<VEO;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@(%1H92!U<V5R('1O(&-H96-K
M(&9O<BX@1&5F875L=',@=&\@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@
M)&-R96%T;W(@("`@5&AE('5S97(@=VAO(&-R96%T960@=&AE(&5V96YT+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($$@8FET;6%S:R!O9B!P97)M
M:7-S:6]N<R!T:&4@=7-E<B!H87,L(&9A;'-E(&EF('1H97)E"B`@("`@*B`@
M("`@("`@("`@("`@("!A<F4@;F]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&5R;6ES<VEO;G,H)'!E<FUI<W-I;VXL("1U<V5R(#T@;G5L;"P@)&-R
M96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R
M92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT
M('1O('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!U;FEQ=64@:61E;G1I9FEE<B!O9B!T:&ES('!E<FUI
M<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(%!E<FUI<W-I;VX@)'!E<FUI
M<W-I;VX@(%1H92!P97)M:7-S:6]N(&]B:F5C="!T;R!G970@=&AE($E$(&]F
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('5N:7%U92!I
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&5R;6ES<VEO;DED*"1P97)M
M:7-S:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S
M92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD
M<R!O=70@:68@=&AE('5S97(@:&%S('1H92!S<&5C:69I960@<FEG:'1S('1O
M('1H92!G:79E;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N('1O(&-H96-K+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'5S97(@("`@("`@(%1H92!U<V5R('1O(&-H
M96-K(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M("`@("`@("!4
M:&4@<&5R;6ES<VEO;B!L979E;"!N965D960@9F]R(&%C8V5S<RX*("`@("`J
M($!P87)A;2!S=')I;F<@("1C<F5A=&]R("`@("!4:&4@8W)E871O<B!O9B!T
M:&4@979E;G0*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=&AE('5S97(@:&%S('1H92!S<&5C:69I960@<&5R;6ES<VEO;G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL
M("1U<V5R+"`D<&5R;2P@)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I
M9B!A('!E<FUI<W-I;VX@97AI<W1S(&EN('1H92!S>7-T96TN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I
M;VX@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!P97)M:7-S:6]N(&5X:7-T<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@97AI<W1S*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T
M(&]F('!A<F5N="!P97)M:7-S:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C:&EL9"`@5&AE(&YA;64@;V8@=&AE(&-H:6QD('1O(')E=')I
M979E('!A<F5N=',@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($$@:&%S:"!W:71H(&%L;"!P87)E;G1S(&EN(&$@=')E92!F;W)M870N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=',H)&-H:6QD*0H@("`@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!P97)M:7-S
M:6]N<R!O9B!T:&4@<WES=&5M(&EN(&$@=')E92!F;W)M870N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I=&@@86QL('!E<FUI<W-I
M;VYS(&EN(&$@=')E92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%1R964H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!H87-H(&]F('1H92!A=F%I;&%B
M;&4@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE(&%V86EL86)L92!P97)M:7-S:6]N<R!A<R!A(&AA<V@N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!E<FUS07)R87DH*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2A015)-4U]32$]7(#T^(%\H(E-H;W<B*2P*("`@("`@("`@
M("`@("`@("`@("`@4$5235-?4D5!1"`]/B!?*")296%D(BDL"B`@("`@("`@
M("`@("`@("`@("`@(%!%4DU37T5$250@/3X@7R@B161I="(I+`H@("`@("`@
M("`@("`@("`@("`@("!015)-4U]$14Q%5$4@/3X@7R@B1&5L971E(BDI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@:6YT96=E<B!V86QU92!O
M9B!P97)M:7-S:6]N<R!R971U<FYS(&%N(&%R<F%Y"B`@("`@*B!R97!R97-E
M;G1A=&EO;B!O9B!T:&4@:6YT96=E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:6YT("!4:&4@:6YT96=E<B!R97!R97-E;G1A=&EO;B!O9B!P
M97)M:7-S:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YT96=E<E1O07)R
M87DH)&EN="D*("`@('L*("`@("`@("!S=&%T:6,@)&%R<F%Y(#T@87)R87DH
M*3L*("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1I;G1=*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&%R<F%Y6R1I;G1=.PH@("`@("`@('T*"B`@("`@("`@
M)&%R<F%Y6R1I;G1=(#T@87)R87DH*3L*"B`@("`@("`@+RH@1V5T('1H92!A
M=F%I;&%B;&4@<&5R;7,@87)R87DN("HO"B`@("`@("`@)'!E<FUS(#T@4&5R
M;7,Z.F=E=%!E<FUS07)R87DH*3L*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H
M(&5A8V@@<&5R;2!A;F0@8VAE8VL@:68@:71S('9A;'5E(&ES(&EN8VQU9&5D
M(&EN('1H90H@("`@("`@("`J(&EN=&5G97(@<F5P<F5S96YT871I;VXN("HO
M"B`@("`@("`@9F]R96%C:"`H)'!E<FUS(&%S("1V86P@/3X@)&QA8F5L*2![
M"B`@("`@("`@("`@(&EF("@D:6YT("8@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@)&%R<F%Y6R1I;G1=6R1V86Q=(#T@=')U93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A<G)A>5LD:6YT73L*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E
M(%!E<FUS(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP92!O9B!T:&4@8V]N
M8W)E=&4@4&5R;7,@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@=&\@<F5T=7)N+B`@5&AE(&-L87-S(&YA;64@:7,@8F%S960@;VX@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('!E<FUS(&1R:79E
M<B`H)&1R:79E<BDN("!4:&4@8V]D92!I<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(%!E<FUS?&)O;VQE86X@(%1H92!N97=L>2!C<F5A=&5D(&-O
M;F-R971E(%!E<FUS(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F9A8W1O<GDH)&1R:79E<B`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*&ES7VYU;&PH)&1R:79E<BDI('L*("`@("`@("`@("`@)'!E<FUS(#T@
M)FYE=R!097)M<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EN
M8VQU9&5?;VYC92`G2&]R9&4O4&5R;7,O)R`N("1D<FEV97(@+B`G+G!H<"<[
M"B`@("`@("`@("`@("1C;&%S<R`]("=097)M<U\G("X@)&1R:79E<CL*("`@
M("`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@
M("`@("`@("`D<&5R;7,@/2`F;F5W("1C;&%S<R@I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E<FUS(#T@9F%L<V4["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&5R;7,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E
M<F5N8V4@=&\@82!C;VYC<F5T92!097)M<R!I;G-T86YC92X*("`@("`J($ET
M('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@4&5R;7,@
M:6YS=&%N8V4*("`@("`J(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)E!E
M<FUS.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!R971U<FX@4&5R;7-\
M8F]O;&5A;B`@5&AE(&-O;F-R971E(%!E<FT@<F5F97)E;F-E+"!O<B!F86QS
M92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I
M"B`@("!["B`@("`@("`@<W1A=&EC("1P97)M.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1P97)M*2D@>PH@("`@("`@("`@("`D<&5R;2`]("9097)M<SHZ9F%C
M=&]R>2@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG9&%T871R964G75LG9')I
M=F5R)UTI(#\@)V1A=&%T<F5E)R`Z(&YU;&PI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1P97)M.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O4')E9G,N<&AP````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#8R,#0U`#$P-#$W,S8R-S<S`#`R,#`S,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+R\@4')E9F5R
M96YC92!C;VYS=&%N=',@*&)I=&UA<VMS*0H*+RHJ"B`J(%!R969E<F5N8V4@
M:7,@861M:6YI<W1R871I=F5L>2!L;V-K960N"B`J+PID969I;F4H)U]04D5&
M7TQ/0TM%1"<L(#$I.PH*+RHJ"B`J(%!R969E<F5N8V4@:7,@<VAA<F5D(&%M
M;VYG<W0@87!P;&EC871I;VYS+@H@*B\*9&5F:6YE*"=?4%)%1E]32$%2140G
M+"`R*3L*"B\J*@H@*B!0<F5F97)E;F-E('9A;'5E(&AA<R!B965N(&-H86YG
M960N"B`J+PID969I;F4H)U]04D5&7T1)4E19)RP@-"D["@HO*BH*("H@4')E
M9F5R96YC92!V86QU92!I<R!T:&4@87!P;&EC871I;VX@9&5F875L="X*("HO
M"F1E9FEN92@G7U!2149?1$5&055,5"<L(#@I.PH*<F5Q=6ER95]O;F-E("=(
M;W)D92]3=')I;F<N<&AP)SL*"B\J*@H@*B!4:&4@4')E9G,Z.B!C;&%S<R!P
M<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C=&5D(&EN=&5R9F%C92!I;G1O('1H
M90H@*B!V87)I;W5S('!R969E<F5N8V5S('-T;W)A9V4@;65D:75M<RX@($ET
M(&%L<V\@:6YC;'5D97,@86QL(&]F('1H90H@*B!F=6YC=&EO;G,@9F]R(')E
M=')I979I;F<L('-T;W)I;F<L(&%N9"!C:&5C:VEN9R!P<F5F97)E;F-E('9A
M;'5E<RX*("H*("H@5$]$3SH@9&]C=6UE;G0@=&AE(&9O<FUA="!O9B!T:&4@
M)%]P<F5F<R!H87-H(&AE<F4*("H*("H@)%]P<F5F<ULJ<')E9B!N86UE*ET@
M/2!A<G)A>2@*("H@("`@("=V86QU92<@(#T^("I$969A=6QT('9A;'5E*BP*
M("H@("`@("=L;V-K960G(#T^("IB;V]L96%N*BP*("H@("`@("=S:&%R960G
M(#T^("IB;V]L96%N*BP*("H@("`@("=T>7!E)R`@(#T^("=C:&5C:V)O>"<*
M("H@("`@("`@("`@("`@("`@("=T97AT)PH@*B`@("`@("`@("`@("`@("`@
M)W!A<W-W;W)D)PH@*B`@("`@("`@("`@("`@("`@)W1E>'1A<F5A)PH@*B`@
M("`@("`@("`@("`@("`@)W-E;&5C="<*("H@("`@("`@("`@("`@("`@("=N
M=6UB97(G"B`J("`@("`@("`@("`@("`@("`G:6UP;&EC:70G"B`J("`@("`@
M("`@("`@("`@("`G<W!E8VEA;"<*("H@("`@("`@("`@("`@("`@("=L:6YK
M)R`M(%1H97)E(&UU<W0@8F4@82!F:65L9"!N86UE9"!E:71H97(@)W5R;"<*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("AI;G1E<FYA;"!A<'!L:6-A
M=&EO;B!L:6YK*2!O<B`G>'5R;"<*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("AE>'1E<FYA;"!A<'!L:6-A=&EO;B!L:6YK*2!I9B!T:&ES('1Y<&4@
M:7,@=7-E9"X*("H@("`@("`@("`@("`@("`@("=E;G5M)PH@*B`@("`@)V5N
M=6TG("`@/3X@5$]$3RP*("H@("`@("=D97-C)R`@(#T^(%\H*D1E<V-R:7!T
M:6]N('-T<FEN9RHI+`H@*B`@("`@)VAE;'`G("`@/3X@*DYA;64@;V8@=&AE
M(&5N=')Y(&EN('1H92!834P@:&5L<"!F:6QE*@H@*B`I.PH@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`L=B`Q+C$S-RXQ,"XR,"`R
M,#`V+S`R+S(X(#`V.C`V.C0V('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E
M7U!R969S"B`J+PIC;&%S<R!0<F5F<R!["@H@("`@+RHJ"B`@("`@*B!(87-H
M(&AO;&1I;F<@86QL(&]F('1H92!U<V5R)W,@<')E9F5R96YC97,N($5A8V@@
M<')E9F5R96YC92!I<PH@("`@("H@:71S96QF(&$@:&%S:"P@<V\@=&AI<R!W
M:6QL('5L=&EM871E;'D@8F4@;75L=&DM9&EM96YS:6]N86PN"B`@("`@*@H@
M("`@("H@6RIP<F5F(&YA;64J72`]/B!!<G)A>2@*("`@("`J("`@("!;9%T@
M(#T^("`J9&5F875L="!V86QU92H*("`@("`J("`@("!;;5T@(#T^("`J<')E
M9B!M87-K*@H@("`@("H@("`@(%MV72`@/3X@("IP<F5F('9A;'5E*@H@("`@
M("H@*0H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<')E9G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA
M;64@;V8@=&AI<R!S8V]P92X@5&AI<R!I<R!U<V5D('1O"B`@("`@*B!M86EN
M=&%I;B!T:&4@87!P;&EC871I;VX@<V-O<&4@8F5T=V5E;B!S971S(&]F('!R
M969E<F5N8V5S+B!">0H@("`@("H@9&5F875L="P@86QL('!R969E<F5N8V5S
M(&)E;&]N9R!T;R!T:&4@(F=L;V)A;"(@*$AO<F1E*2!S8V]P92X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S8V]P92`]
M("=H;W)D92<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T
M:&4@8W5R<F5N="!U<V5R;F%M92X@5&AI<R!I;F1I8V%T97,@=&AE(&]W;F5R
M(&]F('1H90H@("`@("H@<')E9F5R96YC97,N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=7-E<B`]("<G.PH*("`@("\J
M*@H@("`@("H@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@<')E9F5R96YC
M92!C86-H:6YG('-H;W5L9"!B92!U<V5D+@H@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C86-H:6YG(#T@9F%L<V4["@H@
M("`@+RHJ"B`@("`@*B!(87-H(&AO;&1I;F<@<')E9F5R96YC97,@=VET:"!H
M;V]K(&9U;F-T:6]N<R!D969I;F5D+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?:&]O:W,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@2&%V92!W92!R=6X@:&]O:R!F=6YC=&EO;G,@>65T/PH@("`@
M("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]H;V]K
M<T-A;&QE9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!$969A=6QT(&-O;G-T
M<G5C=&]R("AM=7-T(&)E(&-A;&QE9"!F<F]M(&5A8V@@97AT96YD:6YG(&-L
M87-S(&EN('1H96ER"B`@("`@*B!C;VYS=')U8W1O<G,@=FEA('!A<F5N=#HZ
M4')E9G,H*2DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%!R969S*"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W-H=71D;W=N*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!C:&%R<V5T('5S960@8GD@=&AE(&-O;F-R971E
M('!R969E<F5N8V4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE('!R969E<F5N8V4@8F%C:V5N9"=S(&-H87)S970N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-H87)S970H*0H@("`@>PH@("`@("`@(')E
M='5R;B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%5P9&%T97,@=&AE('-E<W-I;VXM8F%S960@<')E9F5R96YC97,@8V%C:&4@
M*&EF(&%V86EL86)L92DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<')E9B`@5&AE('!R969E<F5N8V4@=&\@=7!D871E+B`@268@96UP='DL('=I
M;&P@=7!D871E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T:&4@96YT
M:7)E(&-A8VAE('=I=&@@=&AE(&-U<G)E;G0@<V5T(&]F('!R969S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C86-H955P9&%T92@D<')E9B`](&YU;&PI"B`@
M("!["B`@("`@("`@+RH@4F5T=7)N(&EM;65D:6%T96QY(&EF(&-A8VAI;F<@
M:7,@9&ES86)L960N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7V-A8VAI;F<I
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&ES<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G72DI('L*("`@("`@("`@
M("`@:68@*&ES7VYU;&PH)'!R968I*2!["B`@("`@("`@("`@("`@("`D<')E
M9G,@/2`D=&AI<RT^7W!R969S.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'!R969S(#T@87)R87DH)'!R968@/3X@)'1H:7,M/E]P
M<F5F<ULD<')E9ETI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!0
M;&%C92!E86-H('!R969E<F5N8V4@:6X@=&AE(&-A8VAE(&%C8V]R9&EN9R!T
M;R!I=',*("`@("`@("`@("`@("H@<V-O<&4N("HO"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1P<F5F<R!A<R`D;F%M92`]/B`D<')E9BD@>PH@("`@("`@("`@
M("`@("`@)'-C;W!E(#T@)'1H:7,M/F=E=%-C;W!E*"1N86UE*3L*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)W!R969S7V-A8VAE)UU;
M)'-C;W!E72DI('L*("`@("`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)W!R
M969S7V-A8VAE)UU;)'-C;W!E75LD;F%M95T@/2`D<')E9CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%1R:65S('1O(&9I;F0@=&AE(')E<75E<W1E9"!P<F5F97)E
M;F-E<R!I;B!T:&4@8V%C:&4N($EF('1H97D@97AI<W0L"B`@("`@*B!U<&1A
M=&4@=&AE("1P<F5F<R!H87-H('=I=&@@=&AE(&-A8VAE9"!V86QU97,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A8VAE
M3&]O:W5P*"D*("`@('L*("`@("`@("`O*B!2971U<FX@:6UM961I871E;'D@
M:68@8V%C:&EN9R!I<R!D:7-A8FQE9"X@*B\*("`@("`@("!I9B`H(21T:&ES
M+3Y?8V%C:&EN9RD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=P<F5F<U]C86-H
M92==6R=H;W)D92==*2`F)@H@("`@("`@("`@("!I<W-E="@D7U-%4U-)3TY;
M)W!R969S7V-A8VAE)UU;)'1H:7,M/E]S8V]P95TI*2!["@H@("`@("`@("`@
M("`O*B!297-T;W)E(&=L;V)A;"!P<F5F97)E;F-E<RX@*B\*("`@("`@("`@
M("`@)'1H:7,M/E]P<F5F<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?<')E9G,L
M("1?4T534TE/3ELG<')E9G-?8V%C:&4G75LG:&]R9&4G72P@)%]315-324].
M6R=P<F5F<U]C86-H92==6R1T:&ES+3Y?<V-O<&5=*3L*"B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&YE=R!P<F5F97)E;F-E
M(&5N=')Y('1O('1H92`D<')E9G,@:&%S:"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P<F5F("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@
M=&\@861D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L("`@(%1H92!I;FET
M:6%L('9A;'5E(&]F('1H92!P<F5F97)E;F-E+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&UA<VL@(%1H92!I;FET:6%L(&)I=&UA<VL@;V8@=&AE('!R969E
M<F5N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D<')E9BP@)'9A;"`]
M("<G+"`D;6%S:R`](#`I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3Y?<')E9G,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<')E9G-;)'!R
M969=(#T@87)R87DH)W8G(#T^("1V86PL("=M)R`]/B`D;6%S:RP@)V0G(#T^
M("1V86PI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V
M97,@82!P<F5F97)E;F-E(&5N=')Y(&9R;VT@=&AE("1P<F5F<R!H87-H+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F
M('1H92!P<F5F97)E;F-E('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E*"1P<F5F*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M=&AI<RT^7W!R969S*2D@>PH@("`@("`@("`@("`D<V-O<&4@/2`D=&AI<RT^
M9V5T4V-O<&4H)'!R968I.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!R
M969S6R1P<F5F72D["B`@("`@("`@("`@('5N<V5T*"1?4T534TE/3ELG<')E
M9G-?8V%C:&4G75LD<V-O<&5=6R1P<F5F72D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@9VEV96X@<')E9F5R96YC97,@*"1P
M<F5F*2!T;R!T:&4@<W!E8VEF:65D('9A;'5E"B`@("`@*B`H)'9A;"DL(&EF
M('1H92!P<F5F97)E;F-E(&ES(&UO9&EF:6%B;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<')E9B`@("`@(%1H92!N86UE(&]F('1H92!P<F5F
M97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;"`@
M("`@("!4:&4@;F5W('9A;'5E(&9O<B!T:&ES('!R969E<F5N8V4N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D8V]N=F5R="`@268@=')U92!T:&4@<')E9F5R
M96YC92!V86QU92!G971S(&-O;G9E<G1E9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9R;VT@=&AE(&-U<G)E;G0@8VAA<G-E="!T;R!T:&4@
M8F%C:V5N9"=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@8VAA
M<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE('9A;'5E('=A<R!S=6-C97-S9G5L;'D@<V5T+"!F86QS92!O;B!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%9A;'5E*"1P<F5F+"`D=F%L+"`D8V]N=F5R="`]('1R=64I
M"B`@("!["B`@("`@("`@+RH@17AI="!E87)L>2!I9B!T:&ES('!R969E<F5N
M8V4@:7,@;&]C:V5D(&]R(&1O97-N)W0@97AI<W0N("HO"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!R969S6R1P<F5F72D@?'P@)'1H:7,M/FES3&]C
M:V5D*"1P<F5F*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]S971686QU92@D<')E9BP@
M)'9A;"P@=')U92P@)&-O;G9E<G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?
M<V5T*"1N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YS971686QU92@D;F%M92P@)'9A;'5E*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E=',@=&AE(&=I=F5N('!R969E<F5N8V5S("@D<')E9BD@=&\@=&AE
M('-P96-I9FEE9"!V86QU90H@("`@("H@*"1V86PI+"!W:&5T:&5R(&]R(&YO
M="!T:&4@<')E9F5R96YC92!I<R!U<V5R+6UO9&EF:6%B;&4L('5N<V5T"B`@
M("`@*B!T:&4@9&5F875L="!B:70L(&%N9"!S970@=&AE(&1I<G1Y(&)I="X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("1P<F5F("`@("!4:&4@;F%M92!O9B!T:&4@<')E
M9F5R96YC92!T;R!M;V1I9GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=F%L
M("`@("`@5&AE(&YE=R!V86QU92!F;W(@=&AI<R!P<F5F97)E;F-E+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&1I<G1Y("`@(%1R=64@:68@=V4@<VAO=6QD
M(&UA<FL@=&AE(&YE=R!V86QU92!A<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&1I<G1Y("AC:&%N9V5D*2X*("`@("`J($!P87)A;2!B;V]L
M96%N("1C;VYV97)T("!)9B!T<G5E('1H92!P<F5F97)E;F-E('9A;'5E(&=E
M=',@8V]N=F5R=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M9G)O;2!T:&4@8W5R<F5N="!C:&%R<V5T('1O('1H92!B86-K96YD)W,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!C:&%R<V5T+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@=F%L=64@=V%S
M('-U8V-E<W-F=6QL>2!S970L(&9A;'-E(&]N(&$*("`@("`J("`@("`@("`@
M("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=%9A
M;'5E*"1P<F5F+"`D=F%L+"`D9&ER='D@/2!T<G5E+"`D8V]N=F5R="`]('1R
M=64I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H
M)&-O;G9E<G0I('L*("`@("`@("`@("`@)'9A;"`]("1T:&ES+3YC;VYV97)T
M5&]$<FEV97(H)'9A;"P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@=&AE('!R969E<F5N8V4G<R!V86QU92!I<R!A;')E
M861Y(&5Q=6%L('1O("1V86PL(&1O;B=T"B`@("`@("`@("H@8F]T:&5R(&-H
M86YG:6YG(&ET+B!#:&%N9VEN9R!I="!W;W5L9"!S970@=&AE(")D:7)T>2(@
M8FET+`H@("`@("`@("`J(&-A=7-I;F<@86X@=6YN96-E<W-A<GD@=7!D871E
M(&QA=&5R(&]N(&EN('1H92!S=&]R86=E"B`@("`@("`@("H@<F]U=&EN92X@
M*B\*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F5F<ULD<')E9ETI("8F
M"B`@("`@("`@("`@("@H)'1H:7,M/E]P<F5F<ULD<')E9EU;)W8G72`]/2`D
M=F%L*2`F)@H@("`@("`@("`@("`@(21T:&ES+3YI<T1E9F%U;'0H)'!R968I
M*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@
M("`@("\J($-H96-K('1O('-E92!I9B!T:&4@=F%L=64@97AC965D<R!T:&4@
M86QL;W=A8FQE('-T;W)A9V4*("`@("`@("`@*B!L:6UI="X@*B\*("`@("`@
M("!I9B`H:7-S970H)&-O;F9;)W!R969S)UU;)VUA>'-I>F4G72DI('L*("`@
M("`@("`@("`@:68@*'-T<FQE;B@D=F%L*2`^("1C;VYF6R=P<F5F<R==6R=M
M87AS:7IE)UTI('L*("`@("`@("`@("`@("`@(&=L;V)A;"`D;F]T:69I8V%T
M:6]N.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N;W1I9FEC871I;VXI
M*2!["B`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS
M<')I;G1F*%\H(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@
M<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ92(I+"`D<')E9BDL("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@07-S:6=N
M('1H92!N97<@=F%L=64L('5N<V5T('1H92`B9&5F875L="(@8FET+"!A;F0@
M<V5T('1H90H@("`@("`@("`@(")D:7)T>2(@8FET+B`J+PH@("`@("`@(&EF
M("AE;7!T>2@D=&AI<RT^7W!R969S6R1P<F5F75LG;2==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!R969S6R1P<F5F75LG;2==(#T@,#L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]P<F5F<ULD<')E9EU;)W8G72`]("1V86P["B`@
M("`@("`@)'1H:7,M/G-E=$1E9F%U;'0H)'!R968L(&9A;'-E*3L*("`@("`@
M("!I9B`H)&1I<G1Y*2!["B`@("`@("`@("`@("1T:&ES+3YS971$:7)T>2@D
M<')E9BP@=')U92D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^8V%C:&55
M<&1A=&4H)'!R968I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('9A;'5E(&]F('1H92!R97%U97-T
M960@<')E9F5R96YC92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M<F5F("`@("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@<F5T<FEE
M=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V]N=F5R="`@268@=')U92!T
M:&4@<')E9F5R96YC92!V86QU92!G971S(&-O;G9E<G1E9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9R;VT@=&AE(&)A8VME;F0G<R!C:&%R
M<V5T('1O('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('9A;'5E(&]F('1H92!P<F5F97)E;F-E+"!N=6QL(&EF(&ET(&1O97-N
M)W0@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%9A;'5E*"1P<F5F
M+"`D8V]N=F5R="`]('1R=64I"B`@("!["B`@("`@("`@<W1A=&EC("1C:&%R
M<V5T.PH@("`@("`@(&EF("@A:7-S970H)&-H87)S970I*2!["B`@("`@("`@
M("`@("1C:&%R<V5T(#T@3DQ3.CIG971#:&%R<V5T*"D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@*&ES<V5T*"1T:&ES+3Y?<')E9G-;)'!R969=6R=V
M)UTI*2`_"B`@("`@("`@("`@("@D8V]N=F5R="`_"B`@("`@("`@("`@("`D
M=&AI<RT^8V]N=F5R=$9R;VU$<FEV97(H)'1H:7,M/E]P<F5F<ULD<')E9EU;
M)W8G72P@)&-H87)S970I(#H*("`@("`@("`@("`@("1T:&ES+3Y?<')E9G-;
M)'!R969=6R=V)UTI(#H*("`@("`@("`@("`@;G5L;#L*("`@('T*"B`@("!F
M=6YC=&EO;B!?7V=E="@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/F=E=%9A;'5E*"1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J($UO
M9&EF:65S('1H92`B;&]C:V5D(B!B:70@9F]R('1H92!G:79E;B!P<F5F97)E
M;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@("!4:&4@
M;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!M;V1I9GDN"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D8F]O;"`@5&AE(&YE=R!B;V]L96%N('9A;'5E(&9O<B!T
M:&4@(FQO8VME9"(@8FET+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V-K
M960H)'!R968L("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T36%S
M:R@D<')E9BP@)&)O;VPL(%]04D5&7TQ/0TM%1"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!S=&%T92!O9B!T:&4@(FQO8VME9"(@8FET
M(&9O<B!T:&4@9VEV96X@<')E9F5R96YC92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P<F5F("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T
M;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1H92!B
M;V]L96%N('-T871E(&]F("1P<F5F)W,@(FQO8VME9"(@8FET+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<TQO8VME9"@D<')E9BD*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]G971-87-K*"1P<F5F+"!?4%)%1E],3T-+140I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@36]D:69I97,@=&AE(")S:&%R960B(&)I
M="!F;W(@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<')E9B`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E
M('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("!4:&4@
M;F5W(&)O;VQE86X@=F%L=64@9F]R('1H92`B<VAA<F5D(B!B:70N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=%-H87)E9"@D<')E9BP@)&)O;VPI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]S971-87-K*"1P<F5F+"`D8F]O;"P@7U!2149?
M4TA!4D5$*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-T
M871E(&]F('1H92`B<VAA<F5D(B!B:70@9F]R('1H92!G:79E;B!P<F5F97)E
M;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N
M86UE(&]F('1H92!P<F5F97)E;F-E('1O(&-H96-K+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5&AE(&)O;VQE86X@<W1A=&4@;V8@)'!R968G
M<R`B<VAA<F5D(B!B:70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4VAA<F5D
M*"1P<F5F*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$UA<VLH
M)'!R968L(%]04D5&7U-(05)%1"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-
M;V1I9FEE<R!T:&4@(F1I<G1Y(B!B:70@9F]R('1H92!G:79E;B!P<F5F97)E
M;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@("`@("!4
M:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!M;V1I9GDN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D8F]O;"`@("`@5&AE(&YE=R!B;V]L96%N('9A;'5E
M(&9O<B!T:&4@(F1I<G1Y(B!B:70N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$1I<G1Y*"1P<F5F+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E
M=$UA<VLH)'!R968L("1B;V]L+"!?4%)%1E]$25)462D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!S=&%T92!O9B!T:&4@(F1I<G1Y(B!B
M:70@9F]R('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E
M('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5&AE
M(&)O;VQE86X@<W1A=&4@;V8@)'!R968G<R`B9&ER='DB(&)I="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:7-$:7)T>2@D<')E9BD*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]G971-87-K*"1P<F5F+"!?4%)%1E]$25)462D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-;V1I9FEE<R!T:&4@(F1E9F%U;'0B(&)I
M="!F;W(@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<')E9B`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E
M('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("!4:&4@
M;F5W(&)O;VQE86X@=F%L=64@9F]R('1H92`B9&5F875L="(@8FET+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971$969A=6QT*"1P<F5F+"`D8F]O;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7W-E=$UA<VLH)'!R968L("1B;V]L+"!?4%)%
M1E]$149!54Q4*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&1E9F%U;'0@=F%L=64@;V8@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE(&YA;64@;V8@=&AE
M('!R969E<F5N8V4@=&\@9V5T('1H92!D969A=6QT(&9O<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@("`@("!4:&4@<')E9F5R96YC92=S(&1E
M9F%U;'0@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'0H
M)'!R968I"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^7W!R
M969S6R1P<F5F75LG9"==*2`_"B`@("`@("`@("`@("1T:&ES+3Y?<')E9G-;
M)'!R969=6R=D)UT@.@H@("`@("`@("`@("`G)SL*("`@('T*"B`@("`O*BH*
M("`@("`J($1E=&5R;6EN97,@:68@=&AE(&-U<G)E;G0@<')E9F5R96YC92!V
M86QU92!I<R!T:&4@9&5F875L=`H@("`@("H@=F%L=64@9G)O;2!P<F5F<RYP
M:'`@;W(@82!U<V5R(&1E9FEN960@=F%L=64*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P<F5F("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T
M;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=&AE('!R969E<F5N8V4@:7,@=&AE(&%P<&QI8V%T:6]N(&1E9F%U;'0*
M("`@("`J("`@("`@("`@("`@("`@("`@=F%L=64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&ES1&5F875L="@D<')E9BD*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]G971-87-K*"1P<F5F+"!?4%)%1E]$149!54Q4*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E=',@=&AE('9A;'5E(&9O<B!A(&=I=F5N(&UA
M<VLN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<')E9B`@(%1H92!N86UE(&]F('1H92!P<F5F
M97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L
M("!4:&4@;F5W(&)O;VQE86X@=F%L=64@9F]R('1H92`B9&5F875L="(@8FET
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA<VL@(%1H92!M87-K('1O(&%D
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$UA<VLH)'!R968L("1B;V]L
M+"`D;6%S:RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F5F
M<ULD<')E9ETI*2!["B`@("`@("`@("`@(&EF("@D8F]O;"`A/2`D=&AI<RT^
M7V=E=$UA<VLH)'!R968L("1M87-K*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"1B;V]L*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5F<ULD
M<')E9EU;)VTG72!\/2`D;6%S:SL*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5F<ULD<')E9EU;)VTG
M72`F/2!^)&UA<VL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!B;V]L
M96%N('-T871E(&9O<B!A(&=I=F5N(&UA<VLN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E
M9B`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1M87-K("!4:&4@;6%S:R!T;R!G970N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4:&4@8F]O;&5A;B!S=&%T
M92!F;W(@=&AE(&=I=F5N(&UA<VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971-87-K*"1P<F5F+"`D;6%S:RD*("`@('L*("`@("`@("!R971U<FX@:7-S
M970H)'1H:7,M/E]P<F5F<ULD<')E9EU;)VTG72D@/R`H)'1H:7,M/E]P<F5F
M<ULD<')E9EU;)VTG72`F("1M87-K*2`Z(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!W:&5T:&5R('1H92!C=7)R96YT('!R969E
M<F5N8V4@:7,@96UP='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<')E9B`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@8VAE8VLN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!P<F5F
M97)E;F-E(&ES(&5M<'1Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5M<'1Y
M*"1P<F5F*0H@("`@>PH@("`@("`@(')E='5R;B!E;7!T>2@D=&AI<RT^7W!R
M969S6R1P<F5F75LG=B==*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('-C;W!E(&]F('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P
M<F5F97)E;F-E('1O(&5X86UI;F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!S8V]P92!O9B!T:&4@)'!R968N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-C;W!E*"1P<F5F*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^:7-3:&%R960H)'!R968I*2!["B`@("`@("`@("`@(')E='5R;B`G:&]R
M9&4G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W-C;W!E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!A(&QI<W0@;V8@(F1I<G1Y(B!P<F5F97)E;F-E<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@;&ES="!O9B`B9&ER='DB('!R969E<F5N8V5S(&EN("1T:&ES
M+3Y?<')E9G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7)T>5!R969S*"D*
M("`@('L*("`@("`@("`D9&ER='E?<')E9G,@/2!A<G)A>2@I.PH*("`@("`@
M("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?<')E9G,I(&%S("1P<F5F
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-$:7)T>2@D<')E9BDI('L*
M("`@("`@("`@("`@("`@("1D:7)T>5]P<F5F<UM=(#T@)'!R968["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&ER='E?<')E
M9G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO9"!S:&]U;&0@
M8F4@;W9E<G)I9&1E;B!B>2!A('-U8F-L87-S"B`@("`@*B!I;7!L96UE;G1A
M=&EO;BX@270G<R!H97)E('1O(')E=&%I;B!C;V1E(&EN=&5G<FET>2!I;B!T
M:&4@8V%S90H@("`@("H@=&AA="!N;R!S=6)C;&%S<R!I<R!L;V%D960@*"1D
M<FEV97(@/3T@)VYO;F4G*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5T<FEE
M=F4H*0H@("`@>PH@("`@("`@("\J($QO860@9&5F875L=',@=&\@;6%K92!S
M=7)E('=E(&AA=F4@86QL('!R969E<F5N8V5S+B`J+PH@("`@("`@("1T:&ES
M+3Y?<V5T1&5F875L=',H)VAO<F1E)RD["B`@("`@("`@)'1H:7,M/E]S971$
M969A=6QT<R@D=&AI<RT^7W-C;W!E*3L*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&ES(&%N(&%B<W1R86-T(&UE
M=&AO9"!T:&%T('-H;W5L9"!B92!O=F5R<FED9&5N(&)Y(&$*("`@("`J('-U
M8F-L87-S(&EM<&QE;65N=&%T:6]N+B!)="=S(&AE<F4@=&\@<F5T86EN(&-O
M9&4@:6YT96=R:71Y(&EN"B`@("`@*B!T:&4@8V%S92!T:&%T(&YO('-U8F-L
M87-S(&ES(&QO861E9"`H)&1R:79E<B`]/2`G;F]N92<I+@H@("`@("H*("`@
M("`J(%1H:7,@9G5N8W1I;VX@=VEL;"!B92!R=6X@870@=&AE(&5N9"!O9B!E
M=F5R>2!R97%U97-T(&%S(&$*("`@("`J('-H=71D;W=N(&9U;F-T:6]N("AR
M96=I<W1E<F5D(&)Y('1H92!0<F5F<SHZ(&-O;G-T<G5C=&]R*2X@($%L;`H@
M("`@("H@<')E9G,@=VET:"!T:&4@9&ER='D@8FET('-E="!W:6QL(&)E('-A
M=F5D('1O('1H92!S=&]R86=E"B`@("`@*B!B86-K96YD(&%T('1H:7,@=&EM
M93L@=&AU<RP@=&AE<F4@:7,@;F\@;F5E9"!T;R!M86YU86QL>2!C86QL"B`@
M("`@*B`D<')E9G,M/G-T;W)E*"D@979E<GD@=&EM92!A('!R969E<F5N8V4@
M:7,@8VAA;F=E9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@
M("`@9G5N8W1I;VX@<W1O<F4H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!P<F]V:61E
M<R!C;VUM;VX@8VQE86YU<"!F=6YC=&EO;G,@9F]R(&%L;"!O9B!T:&4@9')I
M=F5R"B`@("`@*B!I;7!L96UE;G1A=&EO;G,N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&%L;"`@0VQE86X@=7`@86QL($AO<F1E('!R969E<F5N
M8V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A;G5P*"1A;&P@/2!F86QS
M92D*("`@('L*("`@("`@("`O*B!296UO=F4@=&AI<R!S8V]P92!F<F]M('1H
M92!P<F5F97)E;F-E<R!C86-H92P@:68@:70*("`@("`@("`@("!E>&ES=',N
M("HO"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G
M75LD=&AI<RT^7W-C;W!E72DI('L*("`@("`@("`@("`@=6YS970H)%]315-3
M24].6R=P<F5F<U]C86-H92==6R1T:&ES+3Y?<V-O<&5=*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%!E<F9O<FT@82!(;W)D92UW:61E(&-L96%N=7`_("HO
M"B`@("`@("`@:68@*"1A;&PI('L*("`@("`@("`@("`@+RH@1&5S=')O>2!T
M:&4@8V]N=&5N=',@;V8@=&AE('!R969E<F5N8V5S(&AA<V@N("HO"B`@("`@
M("`@("`@("1T:&ES+3Y?<')E9G,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@
M+RH@1&5S=')O>2!T:&4@8V]N=&5N=',@;V8@=&AE('!R969E<F5N8V5S(&-A
M8VAE+B`J+PH@("`@("`@("`@("!I9B`H:7-S970H)%]315-324].6R=P<F5F
M<U]C86-H92==*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)%]315-324].
M6R=P<F5F<U]C86-H92==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($-L96%R<R!A;&P@<')E9F5R96YC97,@9G)O
M;2!T:&4@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE87(H*0H@
M("`@>PH@("`@("`@("1T:&ES+3YC;&5A;G5P*'1R=64I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]N=F5R=',@82!V86QU92!F<F]M('1H92!D<FEV97(G
M<R!C:&%R<V5T('1O('1H92!S<&5C:69I960@8VAA<G-E="X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)'9A;'5E("`@("!!('9A;'5E('1O(&-O;G9E
M<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E
M="!T;R!C;VYV97)T('1O+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1H92!C;VYV97)T960@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;G9E<G1&<F]M1')I=F5R*"1V86QU92P@)&-H87)S970I"B`@("!["B`@("`@
M("`@<F5T=7)N("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E
M<G1S(&$@=F%L=64@9G)O;2!T:&4@<W!E8VEF:65D(&-H87)S970@=&\@=&AE
M(&1R:79E<B=S(&-H87)S970N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1V86QU92`@02!V86QU92!T;R!C;VYV97)T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@8V]N=F5R="!F<F]M+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!C;VYV97)T960@=F%L
M=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G14;T1R:79E<B@D=F%L
M=64L("1C:&%R<V5T*0H@("`@>PH@("`@("`@(')E='5R;B`D=F%L=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0;W!U;&%T97,@=&AE("1P<F5F<R!H87-H
M('=I=&@@;F5W(&5N=')I97,@86YD(&5X=&5R;F%L;'D@9&5F:6YE9`H@("`@
M("H@9&5F875L="!V86QU97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87!P("!4:&4@87!P;&EC871I;VX@=&\@;&]A9"!D969A=6QT<R!F;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971$969A=6QT<R@D87!P*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@)&9I;&5N86UE
M(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I
M9R]P<F5F<RYP:'`G.PH*("`@("`@("`O*B!%;G-U<F4@=&AA="!T:&4@9&5F
M875L=',@9G)O;2!T:&ES(&9I;&4@87)E(&]N;'D@<F5A9"!O;F-E+@H@("`@
M("`@("`@($%L<V\L(&UA:V4@<W5R92!W92!C86X@<F5A9"!T:&ES(&9I;&4N
M("HO"B`@("`@("`@:68@*"%`:7-?<F5A9&%B;&4H)&9I;&5N86UE*2D@>PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!296%D
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4N(%1H92`D7W!R969S(&%R<F%Y+"!W
M:&EC:"!W:6QL(&)E"B`@("`@("`@("`@:6X@;&]C86P@<V-O<&4L(&ES(&%S
M<W5M960@=&\@:&]L9"!T:&4@9&5F875L="!V86QU97,N("HO"B`@("`@("`@
M:6YC;'5D92`D9FEL96YA;64["B`@("`@("`@9F]R96%C:"`H)%]P<F5F<R!A
M<R`D<')E9B`]/B`D<'9A;',I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1P
M=F%L<ULG=F%L=64G72D@)B8*("`@("`@("`@("`@("`@(&ES<V5T*"1P=F%L
M<ULG;&]C:V5D)UTI("8F"B`@("`@("`@("`@("`@("!I<W-E="@D<'9A;'-;
M)W-H87)E9"==*2`F)@H@("`@("`@("`@("`@("`@*"1P=F%L<ULG='EP92==
M("$]("=L:6YK)RD@)B8*("`@("`@("`@("`@("`@("@D<'9A;'-;)W1Y<&4G
M72`A/2`G<W!E8VEA;"<I*2!["B`@("`@("`@("`@("`@("`D<')E9B`]('-T
M<E]R97!L86-E*"<N)RP@)U\G+"`D<')E9BD["B`@("`@("`@("`@("`@("`D
M;6%S:R`](#`["B`@("`@("`@("`@("`@("!I9B`H)'!V86QS6R=L;V-K960G
M72D@>PH@("`@("`@("`@("`@("`@("`@("1M87-K('P](%]04D5&7TQ/0TM%
M1#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D<'9A
M;'-;)W-H87)E9"==('Q\("1A<'`@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1M87-K('P](%]04D5&7U-(05)%1#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1M87-K("8]('Y?4%)%1E]$25)463L*
M("`@("`@("`@("`@("`@("1M87-K('P](%]04D5&7T1%1D%53%0["@H@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9"@D<')E9BP@)'!V86QS6R=V86QU92==
M+"`D;6%S:RD["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1P=F%L<ULG
M:&]O:R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T2&]O
M:R@D<')E9BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\J(%5P9&%T92!T:&4@<')E9F5R96YC97,@8V%C
M:&4@=VET:"!T:&4@9&5F875L=',N("HO"B`@("`@("`@)'1H:7,M/F-A8VAE
M57!D871E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!097)F;W)M<R!S:'5T
M9&]W;B!A8W1I=FET:65S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?<VAU=&1O=VXH*0H@("`@>PH@("`@
M("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@
M)W-T;W)E)RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@061D("1P<F5F('1O
M('1H92!L:7-T(&]F('!R969E<F5N8V5S('=I=&@@:&]O:R!F=6YC=&EO;G,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE('!R969E
M<F5N8V4@=VET:"!A(&AO;VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971(
M;V]K*"1P<F5F*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&]O:W-;72`]("1P
M<F5F.PH@("`@?0H*("`@("\J*@H@("`@("H@069T97(@<')E9F5R96YC97,@
M:&%V92!B965N(&QO861E9"P@<V5T(&%N>2!L;V-K960@;W(@96UP='D*("`@
M("`J('!R969E<F5N8V5S('1H870@:&%V92!H;V]K<R!T;R!T:&4@<F5S=6QT
M(&]F('1H92!H;V]K+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L;$AO;VMS
M*"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]H;V]K<T-A
M;&QE9"DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]H;V]K<T-A;&QE9"`]('1R=64["@H@("`@("`@(&EF("@A
M8V]U;G0H)'1H:7,M/E]H;V]K<RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("!I
M;F-L=61E("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("=H;W)D92<I("X@
M)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7VAO;VMS(&%S("1P<F5F*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-,
M;V-K960H)'!R968I('Q\"B`@("`@("`@("`@("`@("`A)'1H:7,M/F=E=%9A
M;'5E*"1P<F5F*2!\?`H@("`@("`@("`@("`@("`@)'1H:7,M/FES1&5F875L
M="@D<')E9BDI('L*("`@("`@("`@("`@("`@("1F=6YC(#T@)U]P<F5F<U]H
M;V]K7R<@+B`D<')E9CL*("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E
M>&ES=',H)&9U;F,I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S
M971686QU92@D<')E9BP@)&9U;F,H)'1H:7,M/E]U<V5R*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!0<F5F
M<R!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D9')I=F5R("`@("!4:&4@='EP92!O9B!C;VYC<F5T92!0
M<F5F<R!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W
M:6QL(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9')I=F5R6S!=+VQI8B]0<F5F<R\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D
M("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@
M("`@(%1H92!S8V]P92!F;W(@=&AI<R!S970@;V8@<')E9F5R96YC97,N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@5&AE(&YA;64@;V8@=&AE
M('5S97(@=VAO(&]W;G,@=&AI<R!S970@;V8*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!P<F5F97)E;F-E<RX*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A<W-W;W)D("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("1U
M<V5R+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!C;VYN96-T:6]N('!A<F%M
M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&-A8VAI;F<@(%-H;W5L9"!C86-H:6YG(&)E('5S960_"B`@("`@
M*@H@("`@("H@0')E='5R;B!0<F5F<R`@5&AE(&YE=VQY(&-R96%T960@8V]N
M8W)E=&4@4')E9G,@:6YS=&%N8V4L(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@
M("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)&1R:79E<BP@)'-C;W!E(#T@)VAO<F1E)RP@)'5S97(@/2`G)RP@)'!A
M<W-W;W)D(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@
M;G5L;"P@)&-A8VAI;F<@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@)&1R:79E<ELP
M73L*("`@("`@("`@("`@)&1R:79E<B`]("1D<FEV97);,5T["B`@("`@("`@
M?0H*("`@("`@("`O*B!!='1E;7!T('1O(')E9VES=&5R("AC86-H92D@=&AE
M("1P<F5F<R!H87-H(&EN('-E<W-I;VX*("`@("`@("`@*B!S=&]R86=E+B`J
M+PH@("`@("`@(&EF("@D8V%C:&EN9RD@>PH@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G72DI('L*("`@("`@("`@("`@
M("`@("1?4T534TE/3ELG<')E9G-?8V%C:&4G72`](&%R<F%Y*"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M
M92@D9')I=F5R*3L*("`@("`@("!I9B`H96UP='DH)&1R:79E<BD@?'P@)&1R
M:79E<B`]/2`G;F]N92<I('L*("`@("`@("`@("`@)'!R969S(#T@)FYE=R!0
M<F5F<R@I.PH@("`@("`@("`@("`D<')E9G,M/E]S8V]P92`]("1S8V]P93L*
M("`@("`@("`@("`@<F5T=7)N("1P<F5F<SL*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@
M/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=P<F5F<R<L("1D<FEV97(I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@268@)'!A<F%M<ULG=7-E<E]H;V]K)UT@
M:7,@9&5F:6YE9"P@=7-E(&ET('1O(')E=')I979E('1H90H@("`@("`@("`@
M('9A;'5E('1O('5S92!F;W(@=&AE('5S97)N86UE("@D=&AI<RT^7W5S97(I
M+B!/=&AE<G=I<V4L"B`@("`@("`@("`@:G5S="!U<V4@=&AE('9A;'5E('!A
M<W-E9"!I;B!T:&4@)'5S97(@<&%R86UE=&5R+B`J+PH@("`@("`@(&EF("@A
M96UP='DH)'!A<F%M<ULG=7-E<E]H;V]K)UTI("8F"B`@("`@("`@("`@(&9U
M;F-T:6]N7V5X:7-T<R@D<&%R86US6R=U<V5R7VAO;VLG72DI('L*("`@("`@
M("`@("`@)'5S97(@/2!C86QL7W5S97)?9G5N8R@D<&%R86US6R=U<V5R7VAO
M;VLG72P@)'5S97(I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D
M87!P*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+U!R969S
M+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL
M95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U!R969S+R<@+B`D9')I
M=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+U!R969S+R<@+B`D9')I=F5R("X@)RYP:'`G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@
M)TAO<F1E+U!R969S+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*
M"B`@("`@("`@)&-L87-S(#T@)U!R969S7R<@+B`D9')I=F5R.PH@("`@("`@
M(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D<')E
M9G,@/2`F;F5W("1C;&%S<R@D=7-E<BP@)'!A<W-W;W)D+"`D<V-O<&4L("1P
M87)A;7,L("1C86-H:6YG*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<')E9G,@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N
M(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<')E9G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!0
M<F5F<R!I;G-T86YC92!B87-E9"!O;@H@("`@("H@)&1R:79E<BX@270@=VEL
M;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!0<F5F<R!I;G-T
M86YC90H@("`@("H@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L
M>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I
M9B!M=6QT:7!L92!P<F5F97)E;F-E('-O=7)C97,@*&%N9"P@=&AU<RP*("`@
M("`J(&UU;'1I<&QE(%!R969S(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@
M)'9A<B`]("90<F5F<SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&1R:79E<B`@("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@4')E
M9G,@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL
M;"!L;V]K(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@)&1R
M:79E<ELP72]L:6(O4')E9G,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D
M9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!S=')I;F<@)'-C;W!E("`@
M("!4:&4@<V-O<&4@9F]R('1H:7,@<V5T(&]F('!R969E<F5N8V5S+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!N86UE(&]F('1H92!U
M<V5R('=H;R!O=VYS('1H:7,@<V5T(&]F"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P87-S=V]R9"`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`D=7-E
M<BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@;W(@8V]N;F5C=&EO;B!P87)A;65T
M97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J($!P87)A;2!B;V]L
M96%N("1C86-H:6YG("!3:&]U;&0@8V%C:&EN9R!B92!U<V5D/PH@("`@("H*
M("`@("`J($!R971U<FX@4')E9G,@(%1H92!C;VYC<F5T92!0<F5F<R!R969E
M<F5N8V4L(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1S8V]P92`]("=H;W)D92<L("1U
M<V5R(#T@)R<L("1P87-S=V]R9"`]("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86US(#T@;G5L;"P@)&-A8VAI;F<@/2!T<G5E*0H@("`@>PH@
M("`@("`@('-T871I8R`D:6YS=&%N8V5S(#T@87)R87DH*3L*"B`@("`@("`@
M:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'!A<F%M<R`]
M($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W!R969S)RP@)&1R:79E<BD["B`@
M("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y
M*"1D<FEV97(L("1U<V5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E
M="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=(#T@)E!R969S.CIF86-T;W)Y*"1D<FEV97(L
M("1S8V]P92P@)'5S97(L("1P87-S=V]R9"P@)'!A<F%M<RP@)&-A8VAI;F<I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA
M='5R95T["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]21$\N<&AP````````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8S,#0`,3`T
M,3<S-C(W-S,`,#$W,S<T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!-86EN(%)$3R!F:6QE+@H@*@H@
M*B!`<&%C:V%G92!21$\*("HO"@HO*BH*("H@4D1/(&-L87-S("A286UP86=E
M($1A=&$@3V)J96-T<RDN($5N=&ET>2!C;&%S<V5S(&5X=&5N9"!T:&ES"B`J
M(&)A<V4@8VQA<W,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U)$3R]21$\N
M<&AP+'8@,2XQ,"XR+C$@,C`P-2\Q,"\Q."`Q,3HP,3HR,B!J86X@17AP("0*
M("H*("H@0'!A8VMA9V4@4D1/"B`J+PIA8G-T<F%C="!C;&%S<R!21$\@:6UP
M;&5M96YT<R!)=&5R871O<D%G9W)E9V%T92!["@H@("`@+RHJ"B`@("`@*B!&
M:6YD(&UO9&4@9F]R(')E='5R;FEN9R!J=7-T('1H92!F:7)S="!M871C:&EN
M9R!R97-U;'0N(%1H90H@("`@("H@8F%C:V5N9"!W:6QL(&QI;6ET('1H92!S
M96%R8V@@:68@<&]S<VEB;&4L(&%N9"!O;FQY(&$@<VEN9VQE"B`@("`@*B!O
M8FIE8W0@=VEL;"!B92!R971U<FYE9"`H;W(@;G5L;"DN"B`@("`@*B\*("`@
M(&-O;G-T($9)3D1?1DE24U0@/2`G4D1/7T9)3D1?1DE24U0G.PH*("`@("\J
M*@H@("`@("H@1FEN9"!M;V1E(&9O<B!R971U<FYI;F<@86QL(')E<W5L=',N
M($5V96X@:68@;F\@<F5S=6QT<R!A<F4*("`@("`J(&9O=6YD(&%N(&5M<'1Y
M(&ET97)A=&]R('=I;&P@8F4@<F5T=7)N960N"B`@("`@*B\*("`@(&-O;G-T
M($9)3D1?04Q,(#T@)U)$3U]&24Y$7T%,3"<["@H@("`@+RHJ"B`@("`@*B\*
M("`@(&-O;G-T($].15]43U]/3D4@/2`Q.PH@("`@8V]N<W0@3TY%7U1/7TU!
M3ED@/2`R.PH@("`@8V]N<W0@34%.65]43U]/3D4@/2`S.PH@("`@8V]N<W0@
M34%.65]43U]-04Y9(#T@-#L*"B`@("`O*BH*("`@("`J(%1H92!21$]?36%P
M<&5R(&EN<W1A;F-E(&%S<V]C:6%T960@=VET:"!T:&ES(%)$3R!O8FIE8W0N
M(%1H90H@("`@("H@36%P<&5R('1A:V5S(&-A<F4@;V8@86QL(&)A8VME;F0@
M86-C97-S+@H@("`@("H*("`@("`J($!S964@4D1/7TUA<'!E<@H@("`@("H@
M0'9A<B!21$]?36%P<&5R("1M87!P97(*("`@("`J+PH@("`@<')O=&5C=&5D
M("1M87!P97(["@H@("`@+RHJ"B`@("`@*B!4:&ES(&]B:F5C="=S('-E="!O
M9B!P<F]P97)T:65S+@H@("`@("H*("`@("`J($!V87(@87)R87D@)&9I96QD
M<PH@("`@("HO"B`@("!P<F]T96-T960@)&9I96QD<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!)9B!S970@=&\@86X@87)R87DL('1H:7,@=VEL;"!B
M92!A(&1E;GD@;&ES="!F;W(@86QL(&UA<W,M<V5T"B`@("`@*B!F=6YC=&EO
M;G,@*&YE=R!21$\H*2P@4D1/.CIS971&:65L9',H*2DN($9I96QD<R!L:7-T
M960@:&5R90H@("`@("H@=VEL;"!N;W0@8F4@<V5T(&)Y('1H;W-E(&9U;F-T
M:6]N<RX*("`@("`J"B`@("`@*B!)9B`D9FEE;&1S06QL;W<@:7,@<V5T+"`D
M9FEE;&1S1&5N>2`\96T^=VEL;"!N;W0@8F4@=7-E9#PO96T^"B`@("`@*B!A
M<R`D9FEE;&1S06QL;W<@:7,@;6]R92!R97-T<FEC=&EV92X*("`@("`J"B`@
M("`@*B!`<V5E("1F:65L9'-!;&QO=PH@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!P<F]T96-T960@)&9I96QD<T1E;GD@/2!N=6QL.PH*("`@("\J
M*@H@("`@("H@268@<V5T('1O(&%N(&%R<F%Y+"!T:&ES('=I;&P@8F4@86X@
M97AP;&EC:70@86QL;W<@;&ES="!F;W(@86QL"B`@("`@*B!M87-S+7-E="!F
M=6YC=&EO;G,@*&YE=R!21$\H*2P@4D1/.CIS971&:65L9',H*2DN($9I96QD
M<PH@("`@("H@/&5M/FYO=#QE;3X@;&ES=&5D(&AE<F4@=VEL;"!B92!I9VYO
M<F5D+@H@("`@("H*("`@("`J(%1H:7,@=VEL;"!O=F5R<FED92!A;GD@)&9I
M96QD<T1E;GD@<V5T=&EN9W,N"B`@("`@*@H@("`@("H@0'-E92`D9FEE;&1S
M1&5N>0H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!P<F]T96-T960@
M)&9I96QD<T%L;&]W(#T@;G5L;#L*"B`@("`O*BH*("`@("`J"B`@("`@*B\*
M("`@('!R;W1E8W1E9"`D<F5L871I;VYS:&EP<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*@H@("`@("HO"B`@("!P<F]T96-T960@)')E;&%T:6]N<VAI
M<$-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%)$3R!C;VYS=')U
M8W1O<BX@0V%N(&)E(&-A;&QE9"!D:7)E8W1L>2!B>2!A('!R;V=R86UM97(L
M(&]R(&ES"B`@("`@*B!C86QL960@:6X@4D1/7TUA<'!E<CHZ;6%P*"DN(%1A
M:V5S(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F"B`@("`@*B!I;FET:6%L('!R
M;W!E<G1Y('9A;'5E<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&9I
M96QD<R!);FET:6%L('!R;W!E<G1Y('9A;'5E<R!F;W(@=&AE(&YE=R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'-E92!21$]?36%P<&5R.CIM87`H*0H@("`@
M("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@7U]C;VYS=')U8W0H)&9I96QD<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/F9I96QD<R`]("1T:&ES
M+3YV86QI9&%T92@D9FEE;&1S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=H
M96X@4D1/(&]B:F5C=',@87)E(&-L;VYE9"P@=6YS970@=&AE('5N:7%U92!)
M9"!T:&%T"B`@("`@*B!I9&5N=&EF:65S('1H96T@<V\@=&AA="!T:&5Y(&-A
M;B!B92!M;V1I9FEE9"!A;F0@<V%V960@=&\@=&AE"B`@("`@*B!B86-K96YD
M(&%S(&YE=R!O8FIE8W1S+B!)9B!Y;W4@9&]N)W0@<F5A;&QY('=A;G0@82!N
M97<@;V)J96-T+`H@("`@("H@9&]N)W0@8VQO;F4N"B`@("`@*B\*("`@('!U
M8FQI8R!F=6YC=&EO;B!?7V-L;VYE*"D*("`@('L*("`@("`@("!U;G-E="@D
M=&AI<RT^9FEE;&1S6R1T:&ES+3YM87!P97(M/F1E<V-R:6)E*"DM/FME>5TI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@06QL;W<@=7-I;F<@)')D;RT^9F]O
M('1O(&%C8V5S<R!T:&4@<')O<&5R='D@*'=H:6-H(&UA>2!B92!A"B`@("`@
M*B!F:65L9"!O<B!A(')E;&%T:6]N<VAI<"D@(F9O;R(N($EF(&$@9FEE;&0@
M;W(@<F5L871I;VYS:&EP"B`@("`@*B`B9F]O(B!I<R!N;W0@<')E<V5N="!T
M:&5N(&YU;&P@:7,@<F5T=7)N960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<')O<&5R='D@5&AE(&YA;64@;V8@=&AE('!R;W!E<G1Y('1O(&%C
M8V5S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1H92!V86QU92!O
M9B`D<')O<&5R='D@;W(@;G5L;"X*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T
M:6]N(%]?9V5T*"1P<F]P97)T>2D*("`@('L*("`@("`@("`O+R!2971U<FX@
M9FEE;&1S(&9I<G-T+@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9FEE;&1S
M6R1P<F]P97)T>5TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9FEE
M;&1S6R1P<F]P97)T>5T["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F
M;W(@8V%C:&5D(')E;&%T:6]N<VAI<"!D871A+@H@("`@("`@(&EF("@D<F5L
M871I;VYS:&EP(#T@)'1H:7,M/F-A8VAE*"1P<F]P97)T>2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1R96QA=&EO;G-H:7`["B`@("`@("`@?0H*("`@("`@
M("`O+R!4<GD@=&\@9FEN9"!A(')E;&%T:6]N<VAI<"!F:7)S="!B>2!T:&4@
M9VEV96X@;F%M92P@=&AE;B!B>0H@("`@("`@("\O("1P<F]P97)T>2`N("=?
M:60G+@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<F5L871I;VYS:&EP<ULD
M<')O<&5R='E=*2D@>PH@("`@("`@("`@("`D<F5L(#T@)'1H:7,M/G)E;&%T
M:6]N<VAI<'-;)'!R;W!E<G1Y73L*("`@("`@("!](&5L<V5I9B`H:7-S970H
M)'1H:7,M/G)E;&%T:6]N<VAI<'-;)'!R;W!E<G1Y("X@)U]I9"==*2D@>PH@
M("`@("`@("`@("`D<F5L(#T@)'1H:7,M/G)E;&%T:6]N<VAI<'-;)'!R;W!E
M<G1Y("X@)U]I9"==.PH@("`@("`@('T*"B`@("`@("`@+R\@268@=V4@9&ED
M;B=T(&9I;F0@82!R96QA=&EO;G-H:7`L(')E='5R;BX*("`@("`@("!I9B`H
M(21R96PI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*
M("`@("`@("`O+R!4<GD@=&\@9FEN9"!T:&4@36%P<&5R(&-L87-S(&9O<B!T
M:&4@;V)J96-T('1H90H@("`@("`@("\O(')E;&%T:6]N<VAI<"!I<R!W:71H
M+"!A;F0@9F%I;"!I9B!W92!C86XG="X*("`@("`@("!I9B`H:7-S970H)')E
M;%LG;6%P<&5R)UTI*2!["B`@("`@("`@("`@("1M(#T@;F5W("1R96Q;)VUA
M<'!E<B==*"D["B`@("`@("`@?2!E;'-E:68@*&-L87-S7V5X:7-T<RAU8W=O
M<F1S*"1P<F]P97)T>2D@+B`G36%P<&5R)RDI('L*("`@("`@("`@("`@)&-L
M87-S(#T@=6-W;W)D<R@D<')O<&5R='DI("X@)TUA<'!E<B<["B`@("`@("`@
M("`@("1M(#T@;F5W("1C;&%S<R@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@+R\@0F%S
M960@;VX@=&AE(&MI;F0@;V8@<F5L871I;VYS:&EP+"!F971C:"!T:&4@87!P
M<F]P<FEA=&4*("`@("`@("`O+R!O8FIE8W1S(&%N9"!F:6QL('1H92!C86-H
M92X*("`@("`@("!S=VET8V@@*"1R96Q;)W1Y<&4G72D@>PH@("`@("`@(&-A
M<V4@<V5L9CHZ3TY%7U1/7T].13H*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YC86-H92@D<')O<&5R='DL("1M+3YF:6YD*"1T:&ES+3YF:65L9'-;)')E
M;%LG9F]R96EG;DME>2==72DI.PH*("`@("`@("!C87-E('-E;&8Z.D].15]4
M3U]-04Y9.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-A8VAE*"1P<F]P
M97)T>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;2T^9FEN
M9"AS96QF.CI&24Y$7T%,3"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@D;2T^9&5S8W)I8F4H*2T^:V5Y(#T^("1T
M:&ES+3YF:65L9'-;)')E;%LG9F]R96EG;DME>2==72DI*3L*"B`@("`@("`@
M8V%S92!S96QF.CI-04Y97U1/7T].13H*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YC86-H92@D<')O<&5R='DL("1M+3YF:6YD*"1T:&ES+3YF:65L9'-;
M)')E;%LG9F]R96EG;DME>2==72DI.PH*("`@("`@("!C87-E('-E;&8Z.DU!
M3EE?5$]?34%.63H*("`@("`@("`@("`@)&UA<'!E<B`]("1T:&ES+3YG971-
M87!P97(H*3L*("`@("`@("`@("`@)&ME>2`]("1M87!P97(M/F1E<V-R:6)E
M*"DM/FME>3L*("`@("`@("`@("`@)&-R:71E<FEA(#T@;F5W(%)$3U]#<FET
M97)I;VXH*3L*("`@("`@("`@("`@)&-R:71E<FEA+3YA9&1296QA=&EO;G-H
M:7`H)&UA<'!E<BP@)')E;%LG:F]I;D-O;G1A:6YE<B==+"!A<G)A>2@D:V5Y
M(#T^("1T:&ES+3Y?7V=E="@D:V5Y*2DI.PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F-A8VAE*"1P<F]P97)T>2P@)&TM/F9I;F0H<V5L9CHZ1DE.1%]!
M3$PL("1C<FET97)I82DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($%L;&]W('5S:6YG("1R9&\M/F9O;R`]("=B87(G('1O('-E="!P<F]P
M97)T>2!V86QU97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')O
M<&5R='D@5&AE(&YA;64@;V8@=&AE('!R;W!E<G1Y('1O('-E="X*("`@("`J
M($!P87)A;2!M:7AE9"`D=F%L=64@5&AE(&YE=R!V86QU92!F;W(@)'!R;W!E
M<G1Y+@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@7U]S970H)'!R;W!E
M<G1Y+"`D=F%L=64I"B`@("!["B`@("`@("`@)'1H:7,M/F9I96QD<ULD<')O
M<&5R='E=(#T@)'9A;'5E.PH@("`@?0H*("`@('!U8FQI8R!F=6YC=&EO;B!I
M<T-A8VAE9"@D<F5L871I;VYS:&EP*0H@("`@>PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T<R!T:&4@8V%C:&5D('9A;'5E(&9O<B`D<F5L871I;VYS:&EP
M+"!A;F0@<F5T=7)N<R!T:&4@;F5W"B`@("`@*B!V86QU92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1R96QA=&EO;G-H:7`@5&AE(')E;&%T:6]N
M<VAI<"!T;R!S970N"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E(%1H92!R
M96QA=&EO;G-H:7`@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M(%1H92!N97<@8V%C:&4@=F%L=64N"B`@("`@*B\*("`@('!U8FQI8R!F=6YC
M=&EO;B!C86-H92@D<F5L871I;VYS:&EP+"`D=F%L=64@/2!N=6QL*0H@("`@
M>PH@("`@("`@("\O($EF('=E('=E<F4@9VEV96X@82!N97<@=F%L=64L('-T
M;W)E(&ET+@H@("`@("`@(&EF("@A:7-?;G5L;"@D=F%L=64I*2!["B`@("`@
M("`@("`@("1T:&ES+3YR96QA=&EO;G-H:7!#86-H95LD<F5L871I;VYS:&EP
M72`]("1V86QU93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!I<W-E="@D
M=&AI<RT^<F5L871I;VYS:&EP0V%C:&5;)')E;&%T:6]N<VAI<%TI(#\@)'1H
M:7,M/G)E;&%T:6]N<VAI<$-A8VAE6R1R96QA=&EO;G-H:7!=(#H@;G5L;#L*
M("`@('T*"B`@("`O*BH*("`@("`J($-L96%R(&-A8VAE9"!R96QA=&EO;G-H
M:7`@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96QA=&EO
M;G-H:7`@268@;F\@<F5L871I;VYS:&EP(&ES('-P96-I9FEE9"!A;&P@<F5L
M871I;VYS:&EP<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('=I;&P@8F4@8VQE87)E9#L@;W1H97)W:7-E(&]N;'D@=&AE(&=I=F5N(')E
M;&%T:6]N<VAI<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('=I;&P@8F4@8VQE87)E9"X*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N
M(&-L96%R0V%C:&4H)')E;&%T:6]N<VAI<"`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*"1R96QA=&EO;G-H:7`I('L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YR96QA=&EO;G-H:7!#86-H95LD<F5L871I;VYS:&EP72DI('L*
M("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YR96QA=&EO;G-H:7!#86-H
M95LD<F5L871I;VYS:&EP72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^<F5L871I;VYS:&EP0V%C:&4@/2!A
M<G)A>2@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($EM<&QE
M;65N="!T:&4@271E<F%T;W)!9V=R96=A=&4@<&%T=&5R;BX@5VAE;B!A('-I
M;F=L92!21$\*("`@("`J(&]B:F5C="!I<R!I=&5R871E9"!O=F5R+"!W92!R
M971U<FX@86X@:71E<F%T;W(@=&AA="!L;V]P<R!O=F5R"B`@("`@*B!E86-H
M('!R;W!E<G1Y(&]F('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!!<G)A>4ET97)A=&]R(%1H92!)=&5R871O<B!I;G-T86YC92X*("`@("`J
M+PH@("`@<'5B;&EC(&9U;F-T:6]N(&=E=$ET97)A=&]R*"D*("`@('L*("`@
M("`@("!R971U<FX@;F5W($%R<F%Y271E<F%T;W(H)'1H:7,M/F9I96QD<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@86X@4D1/7TUA<'!E<B!I;G-T
M86YC92!T:&%T(&-A;B!B92!U<V5D('1O(&UA;F%G92!T:&ES"B`@("`@*B!O
M8FIE8W0N(%1H92!-87!P97(@:6YS=&%N8V4@8V%N(&-O;64@9G)O;2!A(&9E
M=R!P;&%C97,Z"B`@("`@*@H@("`@("H@+2!)9B!T:&4@8VQA<W,@/%)$3T-L
M87-S3F%M93Y-87!P97(@97AI<W1S+"!I="!W:6QL(&)E('5S960*("`@("`J
M("`@875T;VUA=&EC86QL>2X*("`@("`J"B`@("`@*B`M($%N>2!21$\@:6YS
M=&%N8V4@8W)E871E9"!W:71H(%)$3U]-87!P97(Z.FUA<"@I('=I;&P@:&%V
M92!A"B`@("`@*B`@("1M87!P97(@;V)J96-T('-E="!A=71O;6%T:6-A;&QY
M+@H@("`@("H*("`@("`J("T@4W5B8VQA<W-E<R!C86X@;W9E<G)I9&4@9V5T
M36%P<&5R*"D@=&\@<F5T=7)N('1H92!C;W)R96-T"B`@("`@*B`@(&UA<'!E
M<B!O8FIE8W0N"B`@("`@*@H@("`@("H@+2!4:&4@<')O9W)A;6UE<B!C86X@
M8V%L;"!21$\Z.G-E=$UA<'!E<B@D;6%P<&5R*2!T;R!P<F]V:61E(&$*("`@
M("`J("`@;6%P<&5R(&]B:F5C="X*("`@("`J"B`@("`@*B!!;B!21$]?17AC
M97!T:6]N('=I;&P@8F4@=&AR;W=N(&EF(&YO;F4@;V8@=&AE<V4@8V]N9&ET
M:6]N<R!A<F4*("`@("`J(&UE="X*("`@("`J"B`@("`@*B!`<F5T=7)N(%)$
M3U]-87!P97(@5&AE($UA<'!E<B!I;G-T86YC92!M86YA9VEN9R!T:&ES(&]B
M:F5C="X*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N(&=E=$UA<'!E<B@I
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^;6%P<&5R*2!["B`@("`@("`@
M("`@("1C;&%S<R`](&=E=%]C;&%S<R@D=&AI<RD@+B`G36%P<&5R)SL*("`@
M("`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^;6%P<&5R(#T@;F5W("1C;&%S<R@I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@=&AR;W<@;F5W(%)$3U]%
M>&-E<'1I;VXH)TYO(%)$3U]-87!P97(@;V)J96-T(&9O=6YD+B!/=F5R<FED
M92!G971-87!P97(H*2!O<B!D969I;F4@=&AE("<@+B!G971?8VQA<W,H)'1H
M:7,I("X@)TUA<'!E<B!C;&%S<RXG*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YM87!P97(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!<W-O8VEA=&4@=&AI<R!21$\@;V)J96-T('=I=&@@=&AE
M(%)$3U]-87!P97(@:6YS=&%N8V4@=&AA=`H@("`@("H@=VEL;"!M86YA9V4@
M:70N($-A;&QE9"!A=71O;6%T:6-A;&QY(&)Y(%)$3U]-87!P97(Z;6%P*"DN
M"B`@("`@*@H@("`@("H@0'!A<F%M(%)$3U]-87!P97(@)&UA<'!E<B!4:&4@
M4D1/7TUA<'!E<B!T;R!M86YA9V4@=&AI<R!21$\@;V)J96-T+@H@("`@("H*
M("`@("`J($!S964@4D1/7TUA<'!E<CHZ;6%P*"D*("`@("`J+PH@("`@<'5B
M;&EC(&9U;F-T:6]N('-E=$UA<'!E<BA21$]?36%P<&5R("1M87!P97(I"B`@
M("!["B`@("`@("`@)'1H:7,M/FUA<'!E<B`]("1M87!P97(["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@86X@87-S;V-I871I=F4@87)R87D@;V8@86QL
M(&]F('1H:7,@;V)J96-T)W,@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y($%L;"!P<F]P97)T:65S(&9O<B`D=&AI<RX*("`@("`J+PH@("`@
M<'5B;&EC(&9U;F-T:6]N(&=E=$9I96QD<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YF:65L9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@
M86QL(&]F('1H:7,@;V)J96-T)W,@9FEE;&1S(&EN(&]N92!G;RX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)&9I96QD<R!!;B!A<W-O8VEA=&EV92!A
M<G)A>2!O9B!P<F]P97)T>2!N86UE<R`]/@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@<')O<&5R='D@=F%L=65S+@H@("`@("H*("`@("`J($!S964@
M=F%L:61A=&4H*0H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@<V5T1FEE
M;&1S*"1F:65L9',I"B`@("!["B`@("`@("`@)'1H:7,M/F9I96QD<R`]("1T
M:&ES+3YV86QI9&%T92@D9FEE;&1S*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%9A;&ED871E(&$@<V5T(&]F('!R;W!E<G1Y(&ME>7,O=F%L=65S(&%G86EN
M<W0@)&9I96QD<T1E;GD@86YD"B`@("`@*B`D9FEE;&1S06QL;W<N(%-U8F-L
M87-S97,@8V%N(&%N9"!S:&]U;&0@861D(&%D9&ET:6]N86P*("`@("`J('9A
M;&ED871I;VX@=VAE<F4@87!P<F]P<FEA=&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1F:65L9',@5&AE('!R;W!E<G1I97,@=&\@=F%L:61A=&4N
M"B`@("`@*@H@("`@("H@0'-E92`D9FEE;&1S1&5N>0H@("`@("H@0'-E92`D
M9FEE;&1S06QL;W<*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N('9A;&ED
M871E*"1F:65L9',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YF:65L9'-!
M;&QO=RD@>PH@("`@("`@("`@("`O+R!296UO=F4@86YY(&9I96QD<R!T:&%T
M(&%R92!N;W0@97AP;&EC:71L>2!A;&QO=V5D+@H@("`@("`@("`@("!F;W)E
M86-H("AA<G)A>5]K97ES*"1F:65L9',I(&%S("1F:65L9"D@>PH@("`@("`@
M("`@("`@("`@:68@*"%I;E]A<G)A>2@D9FEE;&0L("1T:&ES+3YF:65L9'-!
M;&QO=RDI('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D9FEE;&1S6R1F
M:65L9%TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E:68@*"1T:&ES+3YF:65L9'-$96YY*2!["B`@("`@("`@("`@
M("\O(%)E;6]V92!A;GD@97AP;&EC:71L>2!D96YI960@9FEE;&1S+@H@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^9FEE;&1S1&5N>2!A<R`D9FEE;&0I
M('L*("`@("`@("`@("`@("`@('5N<V5T*"1F:65L9'-;)&9I96QD72D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9FEE;&1S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V%V92!A;GD@8VAA;F=E<R!T;R!T
M:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@4W5C
M8V5S<RX*("`@("`J+PH@("`@<'5B;&EC(&9U;F-T:6]N('-A=F4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^9V5T36%P<&5R*"DM/G5P9&%T92@D
M=&AI<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@=&AI<R!O8FIE
M8W0@9G)O;2!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!P=6)L:6,@
M9G5N8W1I;VX@9&5L971E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$UA<'!E<B@I+3YD96QE=&4H)'1H:7,I(#T](#$["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@
M=&AI<R!O8FIE8W0N(%1H92!D969A=6QT"B`@("`@*B!I;7!L96UE;G1A=&EO
M;B!J=7-T(')E='5R;G,@82!D=6UP(&]F('1H92!P=6)L:6,@<')O<&5R=&EE
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!3=')I;F<@<F5P<F5S
M96YT871I;VX@;V8@)'1H:7,N"B`@("`@*B\*("`@('!U8FQI8R!F=6YC=&EO
M;B!T;U-T<FEN9R@I"B`@("!["B`@("`@("`@<F5T=7)N('!R:6YT7W(H)'1H
M:7,L('1R=64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&%N(%A-
M3"!R97!R97-E;G1A=&EO;B!O9B!T:&ES(&]B:F5C="X@5&AE(&1E9F%U;'0*
M("`@("`J(&EM<&QE;65N=&%T:6]N(&ES('5N;&EK96QY('1O(&)E('5S969U
M;"!I;B!M;W-T(&-A<V5S(&%N9`H@("`@("H@<VAO=6QD(&)E(&]V97)R:61D
M96X@8GD@<W5B8VQA<W-E<R!T;R!B92!D;VUA:6XM87!P<F]P<FEA=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@6$U,(')E<')E<V5N=&%T:6]N
M(&]F("1T:&ES+@H@("`@("HO"B`@("!P=6)L:6,@9G5N8W1I;VX@=&]8;6PH
M*0H@("`@>PH@("`@("`@("1D;V,@/2!N97<@1$]-1&]C=6UE;G0H)S$N,"<I
M.PH*("`@("`@("`D<F]O="`]("1D;V,M/F%P<&5N9$-H:6QD*"1D;V,M/F-R
M96%T945L96UE;G0H9V5T7V-L87-S*"1T:&ES*2DI.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YG971&:65L9',H*2!A<R`D9FEE;&0@/3X@)'9A;'5E*2![
M"B`@("`@("`@("`@("1F(#T@)')O;W0M/F%P<&5N9$-H:6QD*"1D;V,M/F-R
M96%T945L96UE;G0H)&9I96QD*2D["B`@("`@("`@("`@("1F+3YA<'!E;F1#
M:&EL9"@D9&]C+3YC<F5A=&5497AT3F]D92@D=F%L=64I*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9&]C+3YS879E6$U,*"D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]24$,N<&AP````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`Q,#,`
M,3`T,3<S-C(W-S,`,#$W,S8S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?4E!#.CH@
M8VQA<W,@<')O=FED97,@82!S970@;V8@<V5R=F5R(&%N9"!C;&EE;G0@;65T
M:&]D<R!F;W(*("H@4E!#(&-O;6UU;FEC871I;VXN"B`J"B`J(%1/1$\Z"B`J
M("T@26YT<F]S<&5C=&EO;B!D;V-U;65N=&%T:6]N(&%N9"!M971H;V0@<VEG
M;F%T=7)E<RX*("H*("H@15A!35!,13H*("H@/&-O9&4^"B`J("1R97-P;VYS
M92`]($AO<F1E7U)00SHZ<F5Q=65S="@G>&UL<G!C)RP*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H='1P.B\O;&]C86QH;W-T.C@P+VAO
M<F1E+W)P8RYP:'`G"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8V]N=&%C=',N<V5A<F-H)RP*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*&%R<F%Y*"=J86XG*2P@87)R87DH)VQO8V%L<W%L
M)RDL"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G;F%M92<L("=E;6%I;"<I*2P*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=U<V5R)R`]/B!!=71H.CIG971!=71H*"DL
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%S
M<R<@/3X@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G*2DI.PH@*B`\
M+V-O9&4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U)00R]24$,N<&AP+'8@
M,2XW+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HS,R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7U)00PH@*B\*8VQA<W,@2&]R9&5?4E!#('L*"B`@("`O
M*BH*("`@("`J(%=H971H97(@=V4@;F5E9"!A;B!A=71H;W)I>F5D('5S97(@
M;W(@;F]T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?875T:&]R:7IE(#T@
M=')U93L*"B`@("`O*BH*("`@("`J(%)00R!S97)V97(@8V]N<W1R=6-T;W(*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!R971U<FX@
M;V)J96-T("`@06X@4E!#('-E<G9E<B!I;G-T86YC92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?4E!#*"D*("`@('L*("`@("`@("!R96=I<W1E<E]S
M:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@D=&AI<RP@)W-H=71D;W=N)RDI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VQE86YS('5P('1H92!24$,@<V5R=F5R
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S:'5T9&]W;B@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:R!A=71H96YT:6-A=&EO;BX@1&EF9F5R96YT(&)A8VME;F1S(&UA>2!H86YD
M;&4*("`@("`J(&%U=&AE;G1I8V%T:6]N(&EN(&1I9F9E<F5N="!W87ES+B!4
M:&4@8F%S92!C;&%S<R!I;7!L96UE;G1A=&EO;@H@("`@("H@8VAE8VMS(&9O
M<B!(5%10($%U=&AE;G1I8V%T:6]N(&%G86EN<W0@=&AE($AO<F1E(&%U=&@@
M<V5T=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS
M('1R=64@:68@875T:&5N=&EC871I;VX@:7,@<W5C8V5S<V9U;"X*("`@("`J
M("`@("`@("`@("`@("`@("`@4VAO=6QD('-E;F0@87!P<F]P<FEA=&4@(FYO
M="!A=71H;W)I>F5D(B!H96%D97)S"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&]R(&]T:&5R(')E<W!O;G-E(&-O9&5S+V)O9'D@:68@875T:"!F86EL<RP*
M("`@("`J("`@("`@("`@("`@("`@("`@86YD('1A:V4@8V%R92!O9B!E>&ET
M:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71H;W)I>F4H*0H@("`@>PH@
M("`@("`@(&EF("@A)'1H:7,M/E]A=71H;W)I>F4I('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D875T:"`]("9!=71H
M.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=D<FEV97(G
M72D["@H@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG4$A07T%55$A?55-%
M4B==*2D@>PH@("`@("`@("`@("`D=7-E<B`]("1?4T525D526R=02%!?0554
M2%]54T52)UT["B`@("`@("`@("`@("1P87-S(#T@)%]315)615);)U!(4%]!
M551(7U!7)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1U<V5R
M*0H@("`@("`@("`@("!\?"`A)&%U=&@M/F%U=&AE;G1I8V%T92@D=7-E<BP@
M87)R87DH)W!A<W-W;W)D)R`]/B`D<&%S<RDI*2!["B`@("`@("`@("`@(&AE
M861E<B@G5U=7+4%U=&AE;G1I8V%T93H@0F%S:6,@<F5A;&T](DAO<F1E(%)0
M0R(G*3L*("`@("`@("`@("`@:&5A9&5R*"=(5%10+S$N,"`T,#$@56YA=71H
M;W)I>F5D)RD["B`@("`@("`@("`@(&5C:&\@)S0P,2!5;F%U=&AO<FEZ960G
M.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(')E<75E<W0@
M8F]D>2!I;G!U="X@1&EF9F5R96YT(%)00R!B86-K96YD<R!C86X@;W9E<G)I
M9&4*("`@("`J('1H:7,@=&\@<F5T=7)N(&%N(&]P96X@<W1R96%M('1O('!H
M<#HO+W-T9&EN+"!F;W(@:6YS=&%N8V4@+0H@("`@("H@=VAA=&5V97(@:7,@
M96%S:65S="!T;R!H86YD;&4@:6X@=&AE(&=E=%)E<W!O;G-E*"D@;65T:&]D
M+@H@("`@("H*("`@("`J(%1H92!B87-E(&-L87-S(&EM<&QE;65N=&%T:6]N
M(&QO;VMS(&9O<B`D2%144%]205=?4$]35%]$051!(&%N9`H@("`@("H@<F5T
M=7)N<R!T:&%T(&EF(&ET)W,@879A:6QA8FQE.R!O=&AE<G=I<V4L(&ET(')E
M='5R;G,@=&AE"B`@("`@*B!C;VYT96YT<R!O9B!P:'`Z+R]S=&1I;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@:6YP=70@+2!A('-T<FEN
M9R`H9&5F875L="DL(&$@9FEL96AA;F1L92P@971C+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971);G!U="@I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1'
M3$]"04Q36R=(5%107U)!5U]03U-47T1!5$$G72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1'3$]"04Q36R=(5%107U)!5U]03U-47T1!5$$G73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@:6UP;&]D92@B7')<;B(L
M(&9I;&4H)W!H<#HO+VEN<'5T)RDI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E;F1S(&%N(%)00R!R97%U97-T('1O('1H92!S97)V97(@
M86YD(')E='5R;G,@=&AE(')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("!4:&4@<F%W(')E<75E<W0@<W1R:6YG+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O
M;2!T:&4@<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS
M92@D<F5Q=65S="D*("`@('L*("`@("`@("!R971U<FX@7R@B;F]T(&EM<&QE
M;65N=&5D(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE($-O;G1E
M;G0M5'EP92!O9B!T:&4@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!-24U%($-O;G1E;G0M5'EP92!O9B!T:&4@4E!#(')E
M<W!O;G-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS94-O;G1E
M;G14>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O>&UL)SL*("`@
M('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!24$,@<F5Q=65S="!A;F0@
M<V5N9',@:70@=&\@=&AE(%)00R!S97)V97(N"B`@("`@*@H@("`@("H@5&AI
M<R!S=&%T:6-A;&QY(&-A;&QE9"!M971H;V0@:7,@86-T=6%L;'D@=&AE(%)0
M0R!C;&EE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R
M("`@(%1H92!P<F]T;V-O;"!D<FEV97(@=&\@=7-E+B!#=7)R96YT;'D@)W-O
M87`G"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@86YD("=X;6QR
M<&,G(&%R92!A=F%I;&%B;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@
M("`@("`@5&AE('!A=&@@=&\@=&AE(%)00R!S97)V97(@;VX@=&AE(&-A;&QE
M9"!H;W-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("`@(%1H92!M
M971H;V0@=&\@8V%L;"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@
M("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@;F5C97-S87)Y('!A<F%M971E<G,@
M9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&UE=&AO
M9"!C86QL+@H@("`@("H@0'!A<F%M("1O<'1I;VYS("`@("`@("`@($%S<V]C
M:6%T:79E(&%R<F%Y(&]F('!A<F%M971E<G,@9&5P96YD:6YG(&]N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('-E;&5C=&5D('!R;W1O
M8V]L(&1R:79E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@
M("`@("`@5&AE(')E='5R;F5D(')E<W5L="!F<F]M('1H92!M971H;V0@;W(@
M82!014%2"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@97)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<75E
M<W0H)&1R:79E<BP@)'5R;"P@)&UE=&AO9"P@)'!A<F%M<R`](&YU;&PL("1O
M<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)&1R:79E<BDI('L*("`@("`@("`@("`@;&ES="@D87!P+"`D9')I=F5R*2`]
M("1D<FEV97(["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA
M;64H)&1R:79E<BD["@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("1A<'`@+B`G+VQI8B]24$,O)R`N("1D
M<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T
M<RAD:7)N86UE*%]?1DE,15]?*2`N("<O4E!#+R<@+B`D9')I=F5R("X@)RYP
M:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+U)00R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]24$,O
M)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C;&%S
M<R`]("=(;W)D95]24$-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@(')E='5R;B!C86QL7W5S
M97)?9G5N8RAA<G)A>2@D8VQA<W,L("=R97%U97-T)RDL("1U<FPL("1M971H
M;V0L("1P87)A;7,L("1O<'1I;VYS*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@
M)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E
M(%)00R!S97)V97(@:6YS=&%N8V4@8F%S960@;VX*("`@("`J("1D<FEV97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E
M(&]F(&-O;F-R971E(%)00R!S=6)C;&%S<R!T;R!R971U<FXN($EF"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<B!I<R!A;B!A<G)A>2P@
M=&AE;B!W92!W:6QL(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`D9')I=F5R6S!=+VQI8B]24$,O(&9O<B!T:&4@<W5B8VQA<W,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE
M9"`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T
M:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO
M;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N($AO<F1E7U)00R`@5&AE(&YE=VQY(&-R96%T960@8V]N
M8W)E=&4@2&]R9&5?4E!#('-E<G9E<B!I;G-T86YC92P*("`@("`J("`@("`@
M("`@("`@("`@("`@("!O<B!A(%!%05)?17)R;W(@;VX@86X@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@
M>PH@("`@("`@("`@("!L:7-T*"1A<'`L("1D<FEV97(I(#T@)&1R:79E<CL*
M("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R
M*3L*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)&%P<"`N("<O;&EB+U)00R\G("X@)&1R:79E<B`N("<N
M<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]24$,O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@
M("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M4E!#+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+U)00R\G("X@)&1R:79E
M<B`N("<N<&AP)SL*("`@("`@("!]"B`@("`@("`@)&-L87-S(#T@)TAO<F1E
M7U)00U\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C
M;&%S<RDI('L*("`@("`@("`@("`@)')P8R`]("9N97<@)&-L87-S*"1P87)A
M;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PH@("`@("`@("`@("`D<G!C(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@
M9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')P8SL*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R
M96YC92!T;R!A(&-O;F-R971E(%)00R!S97)V97(*("`@("`J(&EN<W1A;F-E
M(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@
M:6YS=&%N8V4*("`@("`J(&EF(&YO(%)00R!S97)V97(@:6YS=&%N8V4@=VET
M:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>0H@("`@("H@97AI<W1S
M+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP
M;&4@4E!#('-E<G9E<G,@*&%N9"!T:'5S+"!M=6QT:7!L92!24$,*("`@("`J
M('-E<G9E<B!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&]R
M9&5?4E!#.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@4E!#('-U8F-L87-S
M('1O(')E='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@2&]R9&5?4E!#("!4:&4@8V]N8W)E=&4@2&]R9&5?4E!#('-E
M<G9E<B!R969E<F5N8V4L(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("!014%27T5R<F]R(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@
M("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ
M92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%A<G)A
M>5]K97E?97AI<W1S*"1S:6=N871U<F4L("1I;G-T86YC97,I*2!["B`@("`@
M("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R9&5?4E!#.CIF
M86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]286UP86=E+G!H<```````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,34`,3`T,3<S-C(W
M-S,`,#(P,S(Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!286UP86=E(&)A<V4@9FEL92X*("H*("H@
M0'!A8VMA9V4@4F%M<&%G90H@*B\*"B\J*@H@*B!286UP86=E($%U=&]L;V%D
M97(N"B`J+PIF=6YC=&EO;B!?7V%U=&]L;V%D*"1C;&%S<VYA;64I"GL*("`@
M(&EN8VQU9&5?;VYC92`G2&]R9&4G("X@1$E214-43U)97U-%4$%2051/4B`N
M('-T<E]R97!L86-E*"=?)RP@1$E214-43U)97U-%4$%2051/4BP@)&-L87-S
M;F%M92D@+B`G+G!H<"<["GT*"B\J*@H@*B!#;W)E(&-L87-S+@H@*@H@*B!`
M<&%C:V%G92!286UP86=E"B`J+PIC;&%S<R!286UP86=E('L*"B`@("!P=6)L
M:6,@9G5N8W1I;VX@7U]C;VYS=')U8W0H*0H@("`@>PH@("`@?0H*("`@('!U
M8FQI8R!F=6YC=&EO;B!?7V-A;&PH)&TL("1A*0H@("`@>PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O4U%,+G!H<```````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#,T,#<R`#$P-#$W,S8R-S<S`#`Q-S0Q,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AI<R!I<R!A('5T:6QI='D@8VQA<W,L(&5V97)Y(&UE=&AO
M9"!I<R!S=&%T:6,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-13"]344PN
M<&AP+'8@,2XS,"XR+C$V(#(P,#8O,#$O,3@@,3DZ,S`Z-3@@8F5N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B`@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E7U-13`H@*B\*8VQA
M<W,@2&]R9&5?4U%,('L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!B;V]L
M96%N(&5X<')E<W-I;VX@=7-I;F<@=&AE('-P96-I9FEE9"!O<&5R871O<BX@
M57-E<PH@("`@("H@9&%T86)A<V4M<W!E8VEF:6,@8V%S=&EN9RP@:68@;F5C
M97-S87)Y+@H@("`@("H*("`@("`J($!P87)A;2!$0B`D9&)H("`@("`@("!4
M:&4@4$5!4CHZ1$(@9&%T86)A<V4@;V)J96-T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;&AS("`@(%1H92!C;VQU;6X@;W(@97AP<F5S<VEO;B!T;R!T97-T
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W`@("`@(%1H92!O<&5R871O<BX*
M("`@("`J($!P87)A;2!S=')I;F<@)')H<R`@("!4:&4@8V]M<&%R:7-O;B!V
M86QU92X*("`@("`J($!P87)A;2!B;V]L96%N("1B:6YD("!)9B!T<G5E+"!T
M:&4@;65T:&]D(')E='5R;G,@=&AE('%U97)Y(&%N9"!A(&QI<W0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!O9B!V86QU97,@<W5I=&%B;&4@9F]R
M(&)I;F1I;F<@87,@86X@87)R87DN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!344P@=&5S="!F<F%G;65N="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8G5I;&1#;&%U<V4H)B1D8F@L("1L:',L("1O<"P@)')H<RP@)&)I
M;F0@/2!F86QS92D*("`@('L*("`@("`@("!S=VET8V@@*"1O<"D@>PH@("`@
M("`@(&-A<V4@)WPG.@H@("`@("`@(&-A<V4@)R8G.@H@("`@("`@("`@("!S
M=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G<&=S
M<6PG.@H@("`@("`@("`@("`@("`@+R\@3VYL>2!09U-13"`W+C,K('5N9&5R
M<W1A;F1S(%-13#DY("=324U)3$%2(%1/)SL@=7-E"B`@("`@("`@("`@("`@
M("`O+R!^(&9O<B!G<F5A=&5R(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+@H@
M("`@("`@("`@("`@("`@)'%U97)Y(#T@)T-!4T4@5TA%3B!#05-4*"5S($%3
M(%9!4D-(05(I('X@7"=>+3];,"TY72LD7"<@5$A%3B`H0T%35"@E<R!!4R!)
M3E1%1T52*2`E<R`E<RD@/#X@,"!%3%-%($9!3%-%($5.1"<["B`@("`@("`@
M("`@("`@("!I9B`H)&)I;F0I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@87)R87DH<W!R:6YT9BA(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)'%U
M97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&QH<RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?4U%,.CIE<V-A
M<&50<F5P87)E*"1L:',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;W`I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<_)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"AI;G0I
M)')H<RDI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@<W!R:6YT9B@D<75E<GDL("1L:',L("1L:',L("1O
M<"P@*&EN="DD<FAS*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&-A<V4@)V]C:3@G.@H@("`@("`@("`@("`@("`@+R\@3W)A8VQE('5S97,@
M)B!F;W(@=F%R:6%B;&5S+B!792!N965D('1O('5S92!T:&4@8FET86YD"B`@
M("`@("`@("`@("`@("`O+R!F=6YC=&EO;B!T:&%T(&ES(&%V86EL86)L92P@
M8G5T(&UA>2!B92!U;G-U<'!O<G1E9"X*("`@("`@("`@("`@("`@("1Q=65R
M>2`]("=B:71A;F0H)7,L("5S*2`]("5S)SL*("`@("`@("`@("`@("`@(&EF
M("@D8FEN9"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS
M<')I;G1F*$AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D<75E<GDI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E7U-1
M3#HZ97-C87!E4')E<&%R92@D;&AS*2P@)S\G+"`G/R<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@H:6YT*21R:',L("AI;G0I
M)')H<RDI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@<W!R:6YT9B@D<75E<GDL("1L:',L("AI;G0I)')H
M<RP@*&EN="DD<FAS*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@("`@("\O($U34U%,(&UU<W0@
M:&%V92!A('9A;&ED(&)O;VQE86X@97AP<F5S<VEO;@H@("`@("`@("`@("`@
M("`@)'%U97)Y(#T@)RA#05-%(%=(14X@25-.54U%4DE#*"5S*2`](#$@5$A%
M3B`H)7,@)B`E<RD@14Q312`E<R!%3D0I(#T@)7,G.PH@("`@("`@("`@("`@
M("`@:68@*"1B:6YD*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*'-P<FEN=&8H2&]R9&5?4U%,.CIE<V-A<&50<F5P87)E*"1Q=65R>2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R
M9&5?4U%,.CIE<V-A<&50<F5P87)E*"1L:',I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E
M<&%R92@D;&AS*2P@)S\G+"`G/R<L("<_)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"AI;G0I)')H<RP@*&EN="DD<FAS("T@
M,2P@*&EN="DD<FAS*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"1Q=65R>2P@)&QH<RP@
M)&QH<RP@*&EN="DD<FAS+"`H:6YT*21R:',@+2`Q+"`H:6YT*21R:',I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@8V%S92`G;V1B8R<Z"B`@
M("`@("`@("`@("`@("`O+R!/1$)#(&UU<W0@:&%V92!A('9A;&ED(&)O;VQE
M86X@97AP<F5S<VEO;@H@("`@("`@("`@("`@("`@)'%U97)Y(#T@)R@E<R`F
M("5S*2`]("5S)SL*("`@("`@("`@("`@("`@(&EF("@D8FEN9"D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F*$AO<F1E7U-1
M3#HZ97-C87!E4')E<&%R92@D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R
M92@D;&AS*2P@)S\G+"`G/R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@H:6YT*21R:',L("AI;G0I)')H<RDI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M<W!R:6YT9B@D<75E<GDL("1L:',L("AI;G0I)')H<RP@*&EN="DD<FAS*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("!I9B`H)&)I;F0I('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@87)R87DH)&QH<R`N("<@)R`N($AO<F1E7U-13#HZ97-C87!E4')E
M<&%R92@D;W`I("X@)R`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH*&EN="DD<FAS*2D["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D;&AS("X@)R`G("X@
M)&]P("X@)R`G("X@*&EN="DD<FAS.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@(&-A<V4@)WXG.@H@("`@("`@("`@("!I9B`H
M)&1B:"T^<&AP='EP92`]/2`G;7ES<6PG*2!["B`@("`@("`@("`@("`@("`D
M;W`@/2`G4D5'15A0)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)&)I;F0I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D;&AS("X@
M)R`G("X@)&]P("X@)R`_)RP@87)R87DH)')H<RDI.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1L:',@+B`G("<@+B`D
M;W`@+B`G("<@+B`D<FAS.PH@("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@
M)TE.)SH*("`@("`@("`@("`@:68@*"1B:6YD*2!["B`@("`@("`@("`@("`@
M("`O+R!792!N965D('1O(&)I;F0@96%C:"!M96UB97(@;V8@=&AE($E.(&-L
M875S90H@("`@("`@("`@("`@("`@+R\@<V5P87)A=&5L>2!T;R!E;G-U<F4@
M<')O<&5R('%U;W1I;F<N"B`@("`@("`@("`@("`@("!I9B`H<W5B<W1R*"1R
M:',L(#`L(#$I(#T]("<H)RD@>PH@("`@("`@("`@("`@("`@("`@("1R:',@
M/2!S=6)S='(H)')H<RP@,2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H<W5B<W1R*"1R:',L("TQ*2`]/2`G*2<I('L*("`@("`@
M("`@("`@("`@("`@("`D<FAS(#T@<W5B<W1R*"1R:',L(#`L("TQ*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!)9B!W92!U<V4@
M=&AI<R!W:71H('%U;W1E9"!S=')I;F=S(&EN<W1E860@;V8*("`@("`@("`@
M("`@("`@("\O(&EN=&5G97(@:61S+"!W92!W:6QL(&AA=F4@861D:71I;VYA
M;"!P<F]B;&5M<R!T;PH@("`@("`@("`@("`@("`@+R\@<V]L=F4@870@<V]M
M92!P;VEN="X*("`@("`@("`@("`@("`@("1I9',@/2!P<F5G7W-P;&ET*"<O
M7',J+%QS*B\G+"`D<FAS*3L*"B`@("`@("`@("`@("`@("!R971U<FX@87)R
M87DH)&QH<R`N("<@24X@*#\G("X@<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H
M)&ED<RD@+2`Q*2`N("<I)RP@)&ED<RD["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!R971U<FX@)&QH<R`N("<@24X@)R`N("1R:',[
M"B`@("`@("`@("`@('T*"B`@("`@("`@8V%S92`G3$E+12<Z"B`@("`@("`@
M("`@(&EF("@D9&)H+3YP:'!T>7!E(#T]("=P9W-Q;"<I('L*("`@("`@("`@
M("`@("`@("1Q=65R>2`]("<E<R!)3$E+12`E<R<["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<75E<GD@/2`G3$]715(H)7,I($Q)
M2T4@3$]715(H)7,I)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)&)I;F0I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F
M*"1Q=65R>2P@2&]R9&5?4U%,.CIE<V-A<&50<F5P87)E*"1L:',I+"`G/R<I
M+"!A<G)A>2@G)2<@+B`D<FAS("X@)R4G*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@D<75E<GDL("1L
M:',L("1D8F@M/G%U;W1E*"<E)R`N("1R:',@+B`G)2<I*3L*("`@("`@("`@
M("`@?0H*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!I9B`H)&)I;F0I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D;&AS("X@)R`G("X@
M2&]R9&5?4U%,.CIE<V-A<&50<F5P87)E*"1O<"D@+B`G(#\G+"!A<G)A>2@D
M<FAS*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@)&QH<R`N("<@)R`N("1O<"`N("<@)R`N("1D8F@M/G%U;W1E*"1R
M:',I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@17-C87!E<R!A;&P@8VAA<F%C=&5R<R!I;B!A('-T<FEN9R!T:&%T
M(&%R92!P;&%C96AO;&1E<G,@9F]R('1H90H@("`@("H@<')E<&%R92]E>&5C
M=71E(&UE=&AO9',@;V8@=&AE($1"('!A8VMA9V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<75E<GD@($$@<W1R:6YG('1O(&5S8V%P92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O<G)E8W1L>2!E<V-A
M<&5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@97-C87!E4')E<&%R
M92@D<75E<GDI"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G
M+UL_(29=+R<L("=<7%Q<)#`G+"`D<75E<GDI.PH@("`@?0H*("`@(&9U;F-T
M:6]N(')E861";&]B*"8D9&)H+"`D=&%B;&4L("1F:65L9"P@)&-R:71E<FEA
M*0H@("`@>PH@("`@("`@(&EF("@A8V]U;G0H)&-R:71E<FEA*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G66]U(&UU<W0@<W!E
M8VEF>2!T:&4@9F5T8V@@8W)I=&5R:6$G*3L*("`@("`@("!]"@H@("`@("`@
M("1W:&5R92`]("<G.PH*("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X
M*2!["B`@("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1C<FET97)I82!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D=VAE<F4I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'=H97)E("X]("<@04Y$("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H96UP='DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1W:&5R92`N/2`D:V5Y("X@)R!)4R!.54Q,)SL*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E("X]("1K
M97D@+B`G(#T@)R`N("1D8F@M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%T96UE;G0@
M/2!/0TE087)S92@D9&)H+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@
M5TA%4D4@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9FEE;&0L("1T86)L92P@)'=H97)E*2D["B`@("`@("`@("`@
M($]#245X96-U=&4H)'-T871E;65N="D["B`@("`@("`@("`@(&EF("A/0TE&
M971C:$EN=&\H)'-T871E;65N="P@)&QO8BDI('L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D;&]B6S!=+3YL;V%D*"D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@4$5!4CHZ<F%I<V5%<G)O
M<B@G56YA8FQE('1O(&QO860@4U%,($1A=&$G*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T96UE;G0I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M9F]R96%C:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1W:&5R92DI('L*("`@("`@("`@("`@
M("`@("`@("`D=VAE<F4@+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1W:&5R92`N/2`D:V5Y("X@)R`]("<@+B`D9&)H
M+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R
M97-U;'0@/2`D9&)H+3YG971/;F4H<W!R:6YT9B@G4T5,14-4("5S($923TT@
M)7,@5TA%4D4@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I96QD+"`D=&%B;&4L("1W:&5R92DI.PH*("`@("`@
M("`@("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@("`@("!C
M87-E("=P9W-Q;"<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@<&%C:R@G
M2"<@+B!S=')L96XH)')E<W5L="DL("1R97-U;'0I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*("`@(&9U;F-T:6]N(&EN<V5R=$)L;V(H
M)B1D8F@L("1T86)L92P@)&9I96QD+"`D9&%T82P@)&%T=')I8G5T97,I"B`@
M("!["B`@("`@("`@)&9I96QD<R`](&%R<F%Y*"D["B`@("`@("`@)'9A;'5E
M<R`](&%R<F%Y*"D["@H@("`@("`@('-W:71C:"`H)&1B:"T^9&)S>6YT87@I
M('L*("`@("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@9F]R96%C:"`H
M)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@
M("`@("1F:65L9'-;72`]("1K97D["B`@("`@("`@("`@("`@("`D=F%L=65S
M6UT@/2`D9&)H+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H)&1B:"T^8V]N;F5C=&EO
M;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H
M)TE.4T525"!)3E1/("5S("@E<RP@)7,I)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<@5D%,5453("@E<RP@14U05%E?
M0DQ/0B@I*2!215154DY)3D<@)7,@24Y43R`Z8FQO8B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T86)L92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G
M+"`G+"`D9FEE;&1S*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I96QD+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1V86QU97,I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&0I
M*3L*"B`@("`@("`@("`@("1L;V(@/2!/0TE.97=$97-C<FEP=&]R*"1D8F@M
M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("!/0TE":6YD0GE.86UE*"1S=&%T
M96UE;G0L("<Z8FQO8B<L("1L;V(L("TQ+"!344Q47T),3T(I.PH@("`@("`@
M("`@("!/0TE%>&5C=71E*"1S=&%T96UE;G0L($]#25]$149!54Q4*3L*("`@
M("`@("`@("`@)&QO8BT^<V%V92@D9&%T82D["B`@("`@("`@("`@("1R97-U
M;'0@/2!/0TE#;VUM:70H)&1B:"T^8V]N;F5C=&EO;BD["B`@("`@("`@("`@
M("1L;V(M/F9R964H*3L*("`@("`@("`@("`@3T-)1G)E95-T871E;65N="@D
M<W1A=&5M96YT*3L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0@/R!T<G5E
M(#H@4$5!4CHZ<F%I<V5%<G)O<B@G56YK;F]W;B!%<G)O<B<I.PH*("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@)&9I96QD<UM=
M(#T@)&ME>3L*("`@("`@("`@("`@("`@("1V86QU97-;72`]("1V86QU93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M24Y315)4($E.5$\@)7,@*"5S+"`E<RD@5D%,5453("@E<RDG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T86)L92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1F:65L9',I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F:65L9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G/R<@+B!S=')?<F5P96%T*"<L(#\G+"!C;W5N="@D
M=F%L=65S*2DI.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@
M("`@('-W:71C:"`H)&1B:"T^9&)S>6YT87@I('L*("`@("`@("!C87-E("=M
M<W-Q;"<Z"B`@("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@("`@("`D=F%L
M=65S6UT@/2!B:6XR:&5X*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1V86QU97-;72`]("1D871A
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%
M0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS
M<')I;G1F*"=344P@475E<GD@8GD@2&]R9&5?4U%,.CII;G-E<G1";&]B*"DZ
M('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('5P9&%T94)L;V(H)B1D8F@L("1T86)L92P@)&9I96QD
M+"`D9&%T82P@)'=H97)E+"`D86QS;W5P9&%T92D*("`@('L*("`@("`@("`D
M9FEE;&1S(#T@87)R87DH*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*
M"B`@("`@("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@(&-A
M<V4@)V]C:3@G.@H@("`@("`@("`@("`D=VAE<F5S=')I;F<@/2`G)SL*("`@
M("`@("`@("`@9F]R96%C:"`H)'=H97)E(&%S("1K97D@/3X@)'9A;'5E*2![
M"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1W:&5R97-T<FEN9RDI('L*
M("`@("`@("`@("`@("`@("`@("`D=VAE<F5S=')I;F<@+CT@)R!!3D0@)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1W:&5R97-T<FEN
M9R`N/2`D:V5Y("X@)R`]("<@+B`D9&)H+3YQ=6]T92@D=F%L=64I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H
M)&1B:"T^8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%("5S($9/
M4B!54$1!5$4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9FEE;&0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG*2D["@H@("`@("`@("`@
M("!/0TE%>&5C=71E*"1S=&%T96UE;G0L($]#25]$149!54Q4*3L*("`@("`@
M("`@("`@3T-)1F5T8VA);G1O*"1S=&%T96UE;G0L("1L;V(I.PH@("`@("`@
M("`@("`D;&]B6S!=+3YS879E*"1D871A*3L*("`@("`@("`@("`@)')E<W5L
M="`]($]#24-O;6UI="@D9&)H+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@
M)&QO8ELP72T^9G)E92@I.PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT
M*"1S=&%T96UE;G0I.PH@("`@("`@("`@("!R971U<FX@)')E<W5L="`_('1R
M=64@.B!014%2.CIR86ES945R<F]R*"=5;FMN;W=N($5R<F]R)RD["@H@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1U<&1A=&5S=')I;F<@/2`G)SL*
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1A;'-O=7!D871E(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("`@("`D=7!D871E<W1R:6YG("X]("1K97D@+B`G(#T@/RP@)SL*
M("`@("`@("`@("`@("`@("1V86QU97-;72`]("1V86QU93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=7!D871E<W1R:6YG("X]("1F:65L9"`N("<@
M/2`_)SL*("`@("`@("`@("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@
M("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@(&-A<V4@)W!G
M<W%L)SH*("`@("`@("`@("`@("`@("1V86QU97-;72`](&)I;C)H97@H)&1A
M=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)&1A=&$["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1W:&5R97-T<FEN9R`]("<G.PH@("`@
M("`@("`@("!F;W)E86-H("@D=VAE<F4@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E<W1R:6YG*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`G($%.1"`G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG
M("X]("1K97D@+B`G(#T@/R<["B`@("`@("`@("`@("`@("`D=F%L=65S6UT@
M/2`D=F%L=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1Q=65R>2`]
M('-P<FEN=&8H)U501$%412`E<R!3150@)7,@5TA%4D4@)7,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T86)L92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=7!D871E<W1R:6YG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1W:&5R97-T<FEN9RD["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%
M0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS
M<')I;G1F*"=344P@475E<GD@8GD@2&]R9&5?4U%,.CIU<&1A=&5";&]B*"DZ
M('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@(')E='5R
M;B`D9&)H+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0G5I;&0@86X@4U%,(%-%5"!C;&%U<V4N"B`@("`@*@H@("`@
M("H@5&AI<R!F=6YC=&EO;B!T86ME<R!A;B!A<G)A>2!I;B!T:&4@9F]R;2!C
M;VQU;6X@/3X@=F%L=64@86YD(')E='5R;G,*("`@("`J(&%N(%-13"!3150@
M8VQA=7-E("AW:71H;W5T('1H92!3150@:V5Y=V]R9"D@=VET:"!T:&4@=F%L
M=65S('!R;W!E<FQY"B`@("`@*B!Q=6]T960N("!&;W(@97AA;7!L92P@=&AE
M(&9O;&QO=VEN9SH*("`@("`J"B`@("`@*B`@("`@(&%R<F%Y*"=F;V\G(#T^
M(#$L"B`@("`@*B`@("`@("`@("`@("=B87(G(#T^("=H96QL;R<I"B`@("`@
M*@H@("`@("H@=V]U;&0@<F5S=6QT(&EN('1H92!F<F%G;65N=#H*("`@("`J
M"B`@("`@*B`@("`@(&9O;R`](#$L(&)A<B`]("=H96QL;R<*("`@("`J"B`@
M("`@*B!`<&%R86T@1$(@)&1B:"`@("`@("`@5&AE(%!%05(Z.D1"(&1A=&%B
M87-E(&]B:F5C="X*("`@("`J($!P87)A;2!A<G)A>2`D=F%L=65S("!4:&4@
M87)R87D@;V8@8V]L=6UN(#T^('9A;'5E('!A:7)S+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@4U%,(%-%5"!F<F%G;65N="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=7!D871E5F%L=65S*"8D9&)H+"`D=F%L=65S*0H@
M("`@>PH@("`@("`@("1R970@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@
M*"1V86QU97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)')E
M=%M=(#T@)&ME>2`N("<@/2`G("X@*"1V86QU92`]/3T@;G5L;"`_("=.54Q,
M)R`Z("1D8F@M/G%U;W1E*"1V86QU92DI.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@:6UP;&]D92@G+"`G+"`D<F5T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($)U:6QD(&%N(%-13"!)3E-%4E0O5D%,5453(&-L875S92X*("`@("`J
M"B`@("`@*B!4:&ES(&9U;F-T:6]N('1A:V5S(&%N(&%R<F%Y(&EN('1H92!F
M;W)M(&-O;'5M;B`]/B!V86QU92!A;F0@<F5T=7)N<PH@("`@("H@86X@4U%,
M(&9R86=M96YT('-P96-I9GEI;F<@=&AE(&-O;'5M;B!N86UE<R!A;F0@:6YS
M97)T('9A;'5E<RP@=VET:`H@("`@("H@=&AE('9A;'5E<R!P<F]P97)L>2!Q
M=6]T960N("!&;W(@97AA;7!L92P@=&AE(&9O;&QO=VEN9SH*("`@("`J"B`@
M("`@*B`@("`@(&%R<F%Y*"=F;V\G(#T^(#$L"B`@("`@*B`@("`@("`@("`@
M("=B87(G(#T^("=H96QL;R<I"B`@("`@*@H@("`@("H@=V]U;&0@<F5S=6QT
M(&EN('1H92!F<F%G;65N=#H*("`@("`J"B`@("`@*B`@("`@("@@9F]O+"!B
M87(@*2!604Q515,@*"`Q+"`G:&5L;&\G("D*("`@("`J"B`@("`@*B!`<&%R
M86T@1$(@)&1B:"`@("`@("`@5&AE(%!%05(Z.D1"(&1A=&%B87-E(&]B:F5C
M="X*("`@("`J($!P87)A;2!A<G)A>2`D=F%L=65S("!4:&4@87)R87D@;V8@
M8V]L=6UN(#T^('9A;'5E('!A:7)S+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@4U%,(&9R86=M96YT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I;G-E<G1686QU97,H)B1D8F@L("1V86QU97,I"B`@("!["B`@("`@("`@
M)&-O;'5M;G,@/2!A<G)A>2@I.PH@("`@("`@("1V86QS(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1K97D@/3X@)'9A;'5E*2![
M"B`@("`@("`@("`@("1C;VQU;6YS6UT@/2`D:V5Y.PH@("`@("`@("`@("`D
M=F%L<UM=(#T@)'9A;'5E(#T]/2!N=6QL(#\@)TY53$PG(#H@)&1B:"T^<75O
M=&4H)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("<H("<@+B!I
M;7!L;V1E*"<L("<L("1C;VQU;6YS*2`N("<@*2!604Q515,@*"`G("X@:6UP
M;&]D92@G+"`G+"`D=F%L<RD@+B`G("DG.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V-H961U;&5R+G!H<```
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U-3(W`#$P-#$W
M,S8R-S<S`#`R,#8W,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92YP:'`G.PIR
M97%U:7)E7V]N8V4@)U9&4RYP:'`G.PH*+RHJ"B`J($AO<F1E7U-C:&5D=6QE
M<@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]38VAE9'5L97(O4V-H961U;&5R
M+G!H<"QV(#$N,C,N,3`N."`R,#`U+S$R+S`Q(#$U.C(W.C(S(&-H=6-K($5X
M<"`D"B`J"B`J($!P86-K86=E($AO<F1E7U-C:&5D=6QE<@H@*B\*8VQA<W,@
M2&]R9&5?4V-H961U;&5R('L*"B`@("`O*BH*("`@("`J($YA;64@;V8@=&AE
M('-L965P(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W-L965P.PH*("`@("\J*@H@("`@("H@061J=7-T
M;65N="!F86-T;W(@=&\@<VQE97`@:6X@;6EC<F]S96-O;F1S+@H@("`@("H*
M("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]S;&5E<%]A
M9&H["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@
M*B!&:6=U<F5S(&]U="!H;W<@=V4@8V%N(&)E<W0@<VQE97`@=VET:"!M:6-R
M;W-E8V]N9"!P<F5C:7-I;VX*("`@("`J(&)A<V5D(&]N('=H870@<&QA=&9O
M<FT@=V4G<F4@<G5N;FEN9R!O;BX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R
M9&5?4V-H961U;&5R*"D*("`@('L*("`@("`@("!I9B`H<W5B<W1R*%!(4%]/
M4RP@,"P@,RD@/3T@)U=)3B<I('L*("`@("`@("`@("`@)'1H:7,M/E]S;&5E
M<"`]("=S;&5E<"<["B`@("`@("`@("`@("1T:&ES+3Y?<VQE97!?861J(#T@
M,3`P,#`P,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-L965P(#T@)W5S;&5E<"<["B`@("`@("`@("`@("1T:&ES+3Y?<VQE97!?
M861J(#T@,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86EN
M(&QO;W`O86-T:6]N(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!R=6XH*0H@("`@>PH@("`@?0H*("`@
M("\J*@H@("`@("H@4')E<V5R=F4@=&AE(&EN=&5R;F%L('-T871E(&]F('1H
M92!S8VAE9'5L97(@;V)J96-T('1H870@=V4@87)E"B`@("`@*B!P87-S960L
M(&%N9"!S879E(&ET('1O('1H92!(;W)D92!61E,@8F%C:V5N9"X@2&]R9&5?
M4V-H961U;&5R"B`@("`@*B!O8FIE8W1S('-H;W5L9"!D969I;F4@7U]S;&5E
M<"@I(&%N9"!?7W=A:V5U<"@I('-E<FEA;&EZ871I;VX*("`@("`J(&-A;&QB
M86-K<R!F;W(@86YY=&AI;F<@=&AA="!N965D<R!T;R!B92!D;VYE(&%T(&]B
M:F5C=`H@("`@("H@<V5R:6%L:7IA=&EO;B!O<B!D97-E<FEA;&EZ871I;VX@
M+2!H86YD;&EN9R!D871A8F%S90H@("`@("H@8V]N;F5C=&EO;G,L(&5T8RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D:60@($%N(&ED('1O('5N
M:7%U96QY(&ED96YT:69Y('1H:7,@<V-H961U;&5R(&9R;VT*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@;W1H97)S(&]F('1H92!S86UE(&-L87-S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F4H)&ED(#T@)R<I"B`@("![
M"B`@("`@("`@)'9F<R`]("961E,Z.G-I;F=L971O;B@D1TQ/0D%,4ULG8V]N
M9B==6R=V9G,G75LG='EP92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G=F9S)RP@)$=,3T)!3%-;
M)V-O;F8G75LG=F9S)UU;)W1Y<&4G72DI.PH@("`@("`@(&EF("AI<U]A*"1V
M9G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)'9F<RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`D<F5S=6QT(#T@)'9F<RT^=W)I=&5$871A*"<N:&]R9&4O<V-H961U;&5R
M)RP@4W1R:6YG.CIL;W=E<BAG971?8VQA<W,H)'1H:7,I*2`N("1I9"P@<V5R
M:6%L:7IE*"1T:&ES*2P@=')U92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5S=&]R
M92!A($AO<F1E7U-C:&5D=6QE<B!O8FIE8W0@9G)O;2!T:&4@8V%C:&4N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-L87-S("`@("!4:&4@;F%M
M92!O9B!T:&4@2&]R9&5?4V-H961U;&5R(&]B:F5C="!T;R!R97-T;W)E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&ED("`@("`@("!!;B!I9"!T;R!U;FEQ
M=65L>2!I9&5N=&EF>2!T:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-C:&5D=6QE<B!F<F]M(&]T:&5R<R!O9B!T:&4@<V%M92!C;&%S
M<RX*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O<V%V92`@075T;VUA=&EC
M86QL>2!S=&]R92`H<V5R:6%L:7IE*2!T:&4@<F5T=7)N960*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T(&%T('-C<FEP="!S:'5T
M9&]W;BX*("`@("`J"B`@("`@*B!`<V5E($AO<F1E7U-C:&5D=6QE<CHZ<V5R
M:6%L:7IE*"D*("`@("`J+PH@("`@9G5N8W1I;VX@)G5N<V5R:6%L:7IE*"1C
M;&%S<RP@)&ED(#T@)R<L("1A=71O<V%V92`]('1R=64I"B`@("!["B`@("`@
M("`@+R\@3F5E9"!A(&QO=V5R8V%S92!V97)S:6]N(&]F('1H92!C;&%S<VYA
M;64L(&%N9"!A(&1E9F%U;'0*("`@("`@("`O+R!I;G-T86YC92!O9B!T:&4@
M<V-H961U;&5R(&]B:F5C="!I;B!C87-E('=E(&-A;B=T(')E=')I979E"B`@
M("`@("`@+R\@;VYE+@H@("`@("`@("1C;&%S<R`]('-T<G1O;&]W97(H)&-L
M87-S*3L*("`@("`@("`D<V-H961U;&5R(#T@)FYE=R`D8VQA<W,["@H@("`@
M("`@("1V9G,@/2`F5D93.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG
M=F9S)UU;)W1Y<&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W9F<R<L("1'3$]"04Q36R=C;VYF
M)UU;)W9F<R==6R=T>7!E)UTI*3L*("`@("`@("!I9B`H:7-?82@D=F9S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"1V9G,L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%T82`]("1V9G,M/G)E860H
M)RYH;W)D92]S8VAE9'5L97(G+"`D8VQA<W,@+B`D:60I.PH@("`@("`@("`@
M("!I9B`H:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&1A=&$L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<V-H961U;&5R(#T@0'5N<V5R:6%L:7IE*"1D871A
M*3L*("`@("`@("`@("`@("`@(&EF("@A)'-C:&5D=6QE<BD@>PH@("`@("`@
M("`@("`@("`@("`@("1S8VAE9'5L97(@/2`F;F5W("1C;&%S<SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*"1A=71O<V%V92D@>PH@("`@("`@("`@("!R96=I<W1E<E]S:'5T9&]W
M;E]F=6YC=&EO;BAA<G)A>2@F)'-C:&5D=6QE<BP@)W-E<FEA;&EZ92<I*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<V-H961U;&5R.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4&QA=&9O<FTM:6YD97!E;F1A;G0@<VQE97`@)&US
M96,@;6EC<F]S96-O;F1S+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1M<V5C("!-:6-R;W-E8V]N9',@=&\@<VQE97`N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-L965P*"1M<V5C*0H@("`@>PH@("`@("`@(&-A;&Q?=7-E<E]F
M=6YC*"1T:&ES+3Y?<VQE97`L("1M<V5C("\@)'1H:7,M/E]S;&5E<%]A9&HI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R(&EN<W1A;F-E(&)A<V5D(&]N("1D
M<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H
M92!T>7!E(&]F(&-O;F-R971E($AO<F1E7U-C:&5D=6QE<B!S=6)C;&%S<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R
M:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B](;W)D95]3
M8VAE9'5L97(O(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H
M<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@
M<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO
M<F1E7U-C:&5D=6QE<B`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R
M9&5?4V-H961U;&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M:6YS=&%N8V4L(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@("`@
M("`@)&%P<"`]("1D<FEV97);,%T["B`@("`@("`@("`@("1D<FEV97(@/2`D
M9')I=F5R6S%=.PH@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`](&)A<V5N
M86UE*"1D<FEV97(I.PH*("`@("`@("!I9B`H96UP='DH)&1R:79E<BD@?'P@
M*'-T<F-M<"@D9')I=F5R+"`G;F]N92<I(#T](#`I*2!["B`@("`@("`@("`@
M("1S8VAE9'5L97(@/2`F;F5W($AO<F1E7U-C:&5D=6QE<B@I.PH@("`@("`@
M("`@("!R971U<FX@)'-C:&5D=6QE<CL*("`@("`@("!]"@H@("`@("`@(&EF
M("@A96UP='DH)&%P<"DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G
M+VQI8B]38VAE9'5L97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O
M4V-H961U;&5R+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@
M("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U-C:&5D=6QE
M<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O+R!5<V4@:6YC;'5D95]O;F-E(&AE<F4@=&\@879O:60@82!F
M871A;"!E<G)O<B!I9B!T:&4*("`@("`@("`@("`@+R\@8VQA<W,@:7-N)W0@
M9F]U;F0N"B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+U-C:&5D
M=6QE<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]"B`@("`@("`@
M)&-L87-S(#T@)TAO<F1E7U-C:&5D=6QE<E\G("X@)&1R:79E<CL*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)'-C
M:&5D=6QE<B`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1S8VAE9'5L97(@/2!014%2.CIR86ES945R<F]R
M*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N
M9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<V-H961U;&5R.PH@
M("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F
M97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R"B`@("`@*B!I
M;G-T86YC92!B87-E9"!O;B`D9')I=F5R+B!)="!W:6QL(&]N;'D@8W)E871E
M(&$@;F5W(&EN<W1A;F-E"B`@("`@*B!I9B!N;R!(;W)D95]38VAE9'5L97(@
M:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S"B`@("`@*B!C=7)R
M96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S
M960@:68@;75L=&EP;&4@<V-H961U;&5R<R`H86YD+"!T:'5S+"!M=6QT:7!L
M90H@("`@("H@2&]R9&5?4V-H961U;&5R(&EN<W1A;F-E<RD@87)E(')E<75I
M<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME
M9"!A<SH@)'9A<B`]("9(;W)D95]38VAE9'5L97(Z.G-I;F=L971O;B@I"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP92!O
M9B!C;VYC<F5T92!(;W)D95]38VAE9'5L97(@<W5B8VQA<W,@=&\*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I
M;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT
M(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]38VAE9'5L97(@
M(%1H92!C;VYC<F5T92!(;W)D95]38VAE9'5L97(@<F5F97)E;F-E+"!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E(&]N(&%N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N
M8V5S(#T@87)R87DH*3L*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ
M92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E
M="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E7U-C:&5D=6QE<CHZ9F%C=&]R
M>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O4V5C<F5T+G!H<```````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,C(P`#$P-#$W,S8R-S<S`#`R,#$V-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE(%-E8W)E=#HZ(&-L87-S('!R;W9I9&5S(&%N($%022!F
M;W(@96YC<GEP=&EN9R!A;F0@9&5C<GEP=&EN9PH@*B!S;6%L;"!P:65C97,@
M;V8@9&%T82!W:71H('1H92!U<V4@;V8@82!S:&%R960@:V5Y+@H@*@H@*B!4
M:&4@4V5C<F5T.CH@9G5N8W1I;VYS('5S92!T:&4@2&]R9&4@0VEP:&5R.CH@
M8VQA<W,@:68@;6-R>7!T(&ES(&YO=`H@*B!A=F%I;&%B;&4N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U-E8W)E="]396-R970N<&AP+'8@,2XT-2XQ,"XW
M(#(P,#8O,#,O,#(@,#4Z,C4Z,3`@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]396-R970*("HO"F-L87-S(%-E8W)E="!["@H@
M("`@+RHJ"B`@("`@*B!486ME(&$@<VUA;&P@<&EE8V4@;V8@9&%T82!A;F0@
M96YC<GEP="!I="!W:71H(&$@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&ME>2`@("`@(%1H92!K97D@=&\@=7-E(&9O<B!E;F-R>7!T:6]N
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@5&AE('!L86EN=&5X
M="!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M8VEP:&5R=&5X="!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M92@D:V5Y+"`D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H571I;#HZ97AT
M96YS:6]N17AI<W1S*"=M8W)Y<'0G*2D@>PH@("`@("`@("`@("`D=&0@/2!`
M;6-R>7!T7VUO9'5L95]O<&5N*$U#4EE05%]'3U-4+"`G)RP@34-265!47TU/
M1$5?14-"+"`G)RD["B`@("`@("`@("`@(&EF("@D=&0I('L*("`@("`@("`@
M("`@("`@("1I=B`]($!M8W)Y<'1?8W)E871E7VEV*&UC<GEP=%]E;F-?9V5T
M7VEV7W-I>F4H)'1D*2P@34-265!47U)!3D0I.PH@("`@("`@("`@("`@("`@
M0&UC<GEP=%]G96YE<FEC7VEN:70H)'1D+"`D:V5Y+"`D:78I.PH@("`@("`@
M("`@("`@("`@)&5N8W)Y<'1E9%]D871A(#T@0&UC<GEP=%]G96YE<FEC*"1T
M9"P@)&UE<W-A9V4I.PH@("`@("`@("`@("`@("`@0&UC<GEP=%]G96YE<FEC
M7V1E:6YI="@D=&0I.PH*("`@("`@("`@("`@("`@(')E='5R;B`D96YC<GEP
M=&5D7V1A=&$["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('-T
M871I8R`D8VEP:&5R0V%C:&4@/2!A<G)A>2@I.PH@("`@("`@("1C86-H94ED
M>"`](&UD-2@D:V5Y*3L*"B`@("`@("`@:68@*"%I<W-E="@D8VEP:&5R0V%C
M:&5;)&-A8VAE261X72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]#:7!H97(N<&AP)SL*"B`@("`@("`@("`@("1C:7!H97)#86-H95LD
M8V%C:&5)9'A=(#T@)DAO<F1E7T-I<&AE<CHZ9F%C=&]R>2@G8FQO=V9I<V@G
M*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C86-H94ED>%TM/G-E=$)L
M;V-K36]D92@G;V9B-C0G*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C
M86-H94ED>%TM/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8VEP:&5R0V%C:&5;)&-A8VAE261X72T^96YC<GEP="@D;65S<V%G
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@;65S<V%G92!E
M;F-R>7!T960@=VET:"!396-R970Z.G=R:71E*"DN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@5&AE(&ME>2!T;R!U<V4@9F]R(&1E
M8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!4:&4@
M8VEP:&5R=&5X="!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<&QA:6YT97AT(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E860H)&ME>2P@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@:68@
M*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G;6-R>7!T)RDI('L*("`@("`@("`@
M("`@)'1D(#T@0&UC<GEP=%]M;V1U;&5?;W!E;BA-0U)94%1?1T]35"P@)R<L
M($U#4EE05%]-3T1%7T5#0BP@)R<I.PH@("`@("`@("`@("!I9B`H)'1D*2![
M"B`@("`@("`@("`@("`@("`D:78@/2!`;6-R>7!T7V-R96%T95]I=BAM8W)Y
M<'1?96YC7V=E=%]I=E]S:7IE*"1T9"DL($U#4EE05%]204Y$*3L*("`@("`@
M("`@("`@("`@($!M8W)Y<'1?9V5N97)I8U]I;FET*"1T9"P@)&ME>2P@)&EV
M*3L*("`@("`@("`@("`@("`@("1D96-R>7!T961?9&%T82`]($!M9&5C<GEP
M=%]G96YE<FEC*"1T9"P@)&-I<&AE<G1E>'0I.PH@("`@("`@("`@("`@("`@
M0&UC<GEP=%]G96YE<FEC7V1E:6YI="@D=&0I.PH*("`@("`@("`@("`@("`@
M("\O(%-T<FEP('!A9&1I;F<@8VAA<F%C=&5R<RX*("`@("`@("`@("`@("`@
M(')E='5R;B!R=')I;2@D9&5C<GEP=&5D7V1A=&$L(")<,"(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!S=&%T:6,@)&-I<&AE<D-A8VAE
M.PH@("`@("`@("1C86-H94ED>"`](&UD-2@D:V5Y*3L*"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D8VEP:&5R0V%C:&4I('Q\("%I<W-E="@D8VEP:&5R0V%C
M:&5;)&-A8VAE261X72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]#:7!H97(N<&AP)SL*"B`@("`@("`@("`@("1C:7!H97)#86-H95LD
M8V%C:&5)9'A=(#T@)DAO<F1E7T-I<&AE<CHZ9F%C=&]R>2@G8FQO=V9I<V@G
M*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C86-H94ED>%TM/G-E=$)L
M;V-K36]D92@G;V9B-C0G*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C
M86-H94ED>%TM/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8VEP:&5R0V%C:&5;)&-A8VAE261X72T^9&5C<GEP="@D8VEP:&5R
M=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!A('-E8W)E
M="!K97D@*&9O<B!E;F-R>7!T:6]N*2P@96ET:&5R('5S:6YG(&$@<F%N9&]M
M"B`@("`@*B!M9#4@<W1R:6YG(&%N9"!S=&]R:6YG(&ET(&EN(&$@8V]O:VEE
M(&EF('1H92!U<V5R(&AA<R!C;V]K:65S"B`@("`@*B!E;F%B;&5D+"!O<B!M
M=6YG:6YG('-O;64@:VYO=VX@=F%L=65S(&EF('1H97D@9&]N)W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y;F%M92`@5&AE(&YA;64@;V8@
M=&AE(&ME>2!T;R!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!S96-R970@:V5Y('1H870@:&%S(&)E96X@9V5N97)A=&5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971+97DH)&ME>6YA;64@/2`G9V5N97)I8R<I
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D=&EM96]U
M="`]("1C;VYF6R=S97-S:6]N)UU;)W1I;65O=70G72`_('1I;64H*2`K("1C
M;VYF6R=S97-S:6]N)UU;)W1I;65O=70G72`Z(#`["@H@("`@("`@(&EF("AI
M<W-E="@D7T-/3TM)15LD8V]N9ELG<V5S<VEO;B==6R=N86UE)UU=*2D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)%]#3T]+245;)&ME>6YA;64@+B`G7VME
M>2==*2D@>PH@("`@("`@("`@("`@("`@)&ME>2`]("1?0T]/2TE%6R1K97EN
M86UE("X@)U]K97DG73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1K97D@/2!M9#4H;71?<F%N9"@I*3L*("`@("`@("`@("`@("`@
M("1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72`]("1K97D["B`@("`@("`@
M("`@("`@("!`<V5T8V]O:VEE*"1K97EN86UE("X@)U]K97DG+"`D:V5Y+"`D
M=&EM96]U="P@)&-O;F9;)V-O;VMI92==6R=P871H)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTL("1C
M;VYF6R=U<V5?<W-L)UT@/3T@,2`_(#$@.B`P*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1K97D@/2!S97-S:6]N7VED
M*"D["B`@("`@("`@("`@($!S971C;V]K:64H)&ME>6YA;64@+B`G7VME>2<L
M("1K97DL("1T:6UE;W5T+"`D8V]N9ELG8V]O:VEE)UU;)W!A=&@G72P*("`@
M("`@("`@("`@("`@("`@("`@("`D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==
M+"`D8V]N9ELG=7-E7W-S;"==(#T](#$@/R`Q(#H@,"D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&ME>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!A('-E8W)E="!K97DL(&5I=&AE<B!F<F]M(&$@8V]O:VEE+"!O<B!I
M9B!T:&4@8V]O:VEE"B`@("`@*B!I<VXG="!T:&5R92P@87-S=6UE('=E(&%R
M92!U<VEN9R!A(&UU;F=E9"!V97)S:6]N(&]F(&$@:VYO=VX*("`@("`J(&)A
M<V4@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y;F%M
M92`@5&AE(&YA;64@;V8@=&AE(&ME>2!T;R!G970N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!S96-R970@:V5Y+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971+97DH)&ME>6YA;64@/2`G9V5N97)I8R<I"B`@("!["B`@
M("`@("`@<W1A=&EC("1K97EC86-H92`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@A:7-S970H)&ME>6-A8VAE6R1K97EN86UE72DI('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72DI('L*("`@
M("`@("`@("`@("`@("1K97EC86-H95LD:V5Y;F%M95T@/2`D7T-/3TM)15LD
M:V5Y;F%M92`N("=?:V5Y)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@("`@("`@("`D:V5Y
M8V%C:&5;)&ME>6YA;65=(#T@<V5S<VEO;E]I9"@I.PH@("`@("`@("`@("`@
M("`@0'-E=&-O;VMI92@D:V5Y;F%M92`N("=?:V5Y)RP@)&ME>6-A8VAE6R1K
M97EN86UE72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)W-E
M<W-I;VXG75LG=&EM96]U="==(#\@=&EM92@I("L@)&-O;F9;)W-E<W-I;VXG
M75LG=&EM96]U="==(#H@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;F9;)V-O;VMI92==6R=P871H)UTL("1C;VYF6R=C;V]K:64G75LG9&]M
M86EN)UTL("1C;VYF6R=U<V5?<W-L)UT@/3T@,2`_(#$@.B`P*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1K97EC86-H95LD
M:V5Y;F%M95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@82!S96-R
M970@:V5Y(&5N=')Y(&9R;VT@=&AE(&-U<G)E;G0@8V]O:VEE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ME>6YA;64@(%1H92!N86UE(&]F('1H
M92!K97D@=&\@8VQE87(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF(&ME>2!E>&ES=&5D+"!F86QS92!I9B!N;W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-L96%R2V5Y*"1K97EN86UE(#T@)V=E;F5R:6,G*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D7T-/3TM)15LD1TQ/0D%,4ULG8V]N
M9B==6R=S97-S:6]N)UU;)VYA;64G75TI("8F"B`@("`@("`@("`@(&ES<V5T
M*"1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72DI('L*("`@("`@("`@("`@
M=6YS970H)%]#3T]+245;)&ME>6YA;64@+B`G7VME>2==*3L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]397)I86QI>F4N<&AP````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,C(Q,3<`,3`T,3<S-C(W-S,`,#(P-C<U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@ID
M969I;F4H)U-%4DE!3$E:15]53DM.3U=.)RP@+3$I.PID969I;F4H)U-%4DE!
M3$E:15].3TY%)RP@,"D["F1E9FEN92@G4T5224%,25I%7U=$1%@G+"`Q*3L*
M9&5F:6YE*"=315))04Q)6D5?0EI)4"<L(#(I.PID969I;F4H)U-%4DE!3$E:
M15])34%0."<L(#,I.PID969I;F4H)U-%4DE!3$E:15])34%0551&-R<L(#0I
M.PID969I;F4H)U-%4DE!3$E:15])34%0551&."<L(#4I.PID969I;F4H)U-%
M4DE!3$E:15]"05-)0R<L(#8I.PID969I;F4H)U-%4DE!3$E:15]'6E]$149,
M051%)RP@-RD["F1E9FEN92@G4T5224%,25I%7T=:7T-/35!215-3)RP@."D[
M"F1E9FEN92@G4T5224%,25I%7T=:7T5.0T]$)RP@.2D["F1E9FEN92@G4T52
M24%,25I%7T)!4T4V-"<L(#$P*3L*9&5F:6YE*"=315))04Q)6D5?4U%,6$U,
M)RP@,3$I.PID969I;F4H)U-%4DE!3$E:15]205<G+"`Q,BD["F1E9FEN92@G
M4T5224%,25I%7U523"<L(#$S*3L*9&5F:6YE*"=315))04Q)6D5?551&-R<L
M(#$T*3L*"B\J*B!5<V4@4T5224%,25I%7U541C<@86YD(%-%4DE!3$E:15]"
M05-)0R!S=&%C:V5D+B`@*B\*9&5F:6YE*"=315))04Q)6D5?551&-U]"05-)
M0R<L(#$U*3L*"@HO*BH*("H@5&AE(%-E<FEA;&EZ93HZ(&-L87-S('!R;W9I
M9&5S('9A<FEO=7,@;65T:&]D<R!O9B!E;F-A<'-U;&%T:6YG(&1A=&$N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<FEA;&EZ92]397)I86QI>F4N<&AP
M+'8@,2XR-2XQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@4W1E<&AA;F4@2'5T:&5R(#QS:'5T
M:&5R0&)I9V9O;W0N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*("H@0'-I
M;F-E("`@2&]R9&4@,BXP"B`J($!P86-K86=E($AO<F1E7U-E<FEA;&EZ90H@
M*B\*8VQA<W,@2&]R9&5?4V5R:6%L:7IE('L*"B`@("`O*BH*("`@("`J(%-E
M<FEA;&EZ92!A('9A;'5E+@H@("`@("H*("`@("`J(%-E92!T:&4@;&ES="!O
M9B!C;VYS=&%N=',@870@=&AE('1O<"!O9B!T:&4@9FEL92!F;W(@=&AE('-E
M<FEA;&EZ:6YG"B`@("`@*B!T96-H;FEQ=65S('1H870@8V%N(&)E('5S960N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A("`@(%1H92!D871A
M('1O(&)E('-E<FEA;&EZ960N"B`@("`@*B!`<&%R86T@;6EX960@)&UO9&4@
M("`@5&AE(&UO9&4@;V8@<V5R:6%L:7IA=&EO;BX@0V%N(&)E(&5I=&AE<B!A
M('-I;F=L90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UO9&4@;W(@
M87)R87D@;V8@;6]D97,N("!)9B!A<G)A>2P@=VEL;"!B90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@('-E<FEA;&EZ960@:6X@=&AE(&]R9&5R('!R
M;W9I9&5D+@H@("`@("H@0'!A<F%M(&UI>&5D("1P87)A;7,@($%N>2!A9&1I
M=&EO;F%L('!A<F%M971E<G,@=&AE('-E<FEA;&EZ871I;VX@;65T:&]D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER97,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97)I86QI>F5D(&1A=&$N"B`@
M("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F4H)&1A=&$L("1M
M;V1E(#T@87)R87DH4T5224%,25I%7T)!4TE#*2P@)'!A<F%M<R`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;6]D92DI('L*("`@("`@
M("`@("`@)&UO9&4@/2!A<G)A>2@D;6]D92D["B`@("`@("`@?0H*("`@("`@
M("`O*B!2971U<FX@;F]W(&EF(&YO(&1A=&$N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1D871A*2`F)B`A:7-?87)R87DH)&1A=&$I*2!["B`@("`@("`@("`@
M(')E='5R;B`D9&%T83L*("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H
M<F]U9V@@=&AE(&QI<W0@;V8@<V5R:6%L:7II;F<@;6]D97,N("HO"B`@("`@
M("`@9F]R96%C:"`H)&UO9&4@87,@)'9A;"D@>PH@("`@("`@("`@("`O*B!#
M:&5C:R!T;R!M86ME('-U<F4@=&AE(&UO9&4@:7,@<W5P<&]R=&5D+B`J+PH@
M("`@("`@("`@("!I9B`H(4AO<F1E7U-E<FEA;&EZ93HZ:&%S0V%P86)I;&ET
M>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U5N<W5P<&]R=&5D('-E<FEA;&EZ871I;VX@='EP92<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W-E<FEA
M;&EZ92@D9&%T82P@)'9A;"P@)'!A<F%M<RD["B`@("`@("`@("`@(&EF("AI
M<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5R:6%L:7IE(&1A=&$N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("8D9&%T82`@("`@("`@("`@(%1H92!D871A('1O(&)E
M('-E<FEA;&EZ960N"B`@("`@*B!`<&%R86T@;6EX960@)&UO9&4@("`@("`@
M("`@("`@5&AE(&UO9&4@;V8@<V5R:6%L:7IA=&EO;BX@0V%N(&)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96ET:&5R(&$@<VEN
M9VQE(&UO9&4@;W(@87)R87D@;V8@;6]D97,N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@268@87)R87DL('=I;&P@8F4@<V5R:6%L
M:7IE9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!O<F1E<B!P<F]V:61E9"X*("`@("`J($!P87)A;2!M:7AE9"`D<&%R
M86US("!!;GD@861D:71I;VYA;"!P87)A;65T97)S('1H92!S97)I86QI>F%T
M:6]N(&UE=&AO9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E<75I
M<F5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5R:6%L:7IE*"8D9&%T82P@
M)&UO9&4L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)&UO9&4I('L*("`@("`@("!C87-E(%-%4DE!3$E:15].3TY%.@H@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?0EI)4#H*("`@
M("`@("`@("`@)&1A=&$@/2!B>F-O;7!R97-S*"1D871A+"`Y+"`S,"D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]71$18
M.@H@("`@("`@("`@("`D9&%T82`]('=D9'A?<V5R:6%L:7IE7W9A;'5E*"1D
M871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,
M25I%7TE-05`X.@H@("`@("`@("`@("`D9&%T82`](&EM87!?.&)I="@D9&%T
M82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:
M15])34%0551&-SH*("`@("`@("`@("`@)&1A=&$@/2!I;6%P7W5T9C=?96YC
M;V1E*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M4T5224%,25I%7TE-05!55$8X.@H@("`@("`@("`@("`D9&%T82`](&EM87!?
M=71F."@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(%-%4DE!3$E:15]'6E]$149,051%.@H@("`@("`@("`@("`D9&%T82`](&=Z
M9&5F;&%T92@D9&%T82P@.2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(%-%4DE!3$E:15]"05-)0SH*("`@("`@("`@("`@)&1A=&$@/2!S
M97)I86QI>F4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!315))04Q)6D5?1UI?0T]-4%)%4U,Z"B`@("`@("`@("`@("1D871A
M(#T@9WIC;VUP<F5S<R@D9&%T82P@.2D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(%-%4DE!3$E:15]"05-%-C0Z"B`@("`@("`@("`@("1D
M871A(#T@8F%S938T7V5N8V]D92@D9&%T82D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]%3D-/1#H*("`@("`@("`@
M("`@)&1A=&$@/2!G>F5N8V]D92@D9&%T82P@.2D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]205<Z"B`@("`@("`@("`@
M("1D871A(#T@<F%W=7)L96YC;V1E*"1D871A*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7U523#H*("`@("`@("`@("`@
M)&1A=&$@/2!U<FQE;F-O9&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92!315))04Q)6D5?4U%,6$U,.@H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@("`@("`@("1S<6PR>&UL(#T@
M)FYE=R!X;6Q?<W%L,GAM;"@I.PH@("`@("`@("`@("`D9&%T82`]("1S<6PR
M>&UL+3YG971834PH)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92!315))04Q)6D5?551&-SH*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]3=')I;F<N<&AP)SL*("`@("`@("`@("`@)&1A=&$@/2!3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D871A+"`D<&%R86US+"`G=71F+3<G
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%
M7U541C=?0D%324,Z"B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W-E
M<FEA;&EZ92@D9&%T82P@4T5224%,25I%7U541C<L("1P87)A;7,I.PH@("`@
M("`@("`@("!(;W)D95]397)I86QI>F4Z.E]S97)I86QI>F4H)&1A=&$L(%-%
M4DE!3$E:15]"05-)0RP@)'!A<F%M<RD["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5N<V5R:6%L:7IE(&$@
M=F%L=64N"B`@("`@*@H@("`@("H@4V5E('1H92!L:7-T(&]F(&-O;G-T86YT
M<R!A="!T:&4@=&]P(&]F('1H92!F:6QE(&9O<B!T:&4@<V5R:6%L:7II;F<*
M("`@("`J('1E8VAN:7%U97,@=&AA="!C86X@8F4@=7-E9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&1A=&$@("`@("`@("`@("`@5&AE(&1A=&$@
M=&\@8F4@=6YS97)I86QI>F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("1M;V1E
M("`@(%1H92!M;V1E(&]F('5N<V5R:6%L:7IA=&EO;BX@($-A;B!B92!E:71H
M97(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('-I;F=L92!M;V1E
M(&]R(&%R<F%Y(&]F(&UO9&5S+B`@268@87)R87DL('=I;&P@8F4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E<FEA;&EZ960@:6X@=&AE(&]R
M9&5R('!R;W9I9&5D+@H@("`@("H@0'!A<F%M(&UI>&5D("1P87)A;7,@($%N
M>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AE('5N<V5R:6%L:7IA=&EO;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UE=&AO9"!R97%U:7)E<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N<V5R:6%L:7IE
M9"!D871A+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%
M<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@=6YS97)I86QI
M>F4H)&1A=&$L("1M;V1E(#T@4T5224%,25I%7T)!4TE#+"`D<&%R86US(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1M;V1E*2D@>PH@
M("`@("`@("`@("`D;6]D92`](&%R<F%Y*"1M;V1E*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E='5R;B!N;W<@:68@;F\@9&%T82X@*B\*("`@("`@("!I
M9B`H96UP='DH)&1A=&$I*2!["B`@("`@("`@("`@(')E='5R;B`D9&%T83L*
M("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H<F]U9V@@=&AE(&QI<W0@
M;V8@=6YS97)I86QI>FEN9R!M;V1E<RX@*B\*("`@("`@("!F;W)E86-H("@D
M;6]D92!A<R`D=F%L*2!["B`@("`@("`@("`@("\J($-H96-K('1O(&UA:V4@
M<W5R92!T:&4@;6]D92!I<R!S=7!P;W)T960N("HO"B`@("`@("`@("`@(&EF
M("@A2&]R9&5?4V5R:6%L:7IE.CIH87-#87!A8FEL:71Y*"1V86PI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YS=7!P
M;W)T960@=6YS97)I86QI>F%T:6]N('1Y<&4G*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!(;W)D95]397)I86QI>F4Z.E]U;G-E<FEA;&EZ92@D9&%T
M82P@)'9A;"P@)'!A<F%M<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1D871A
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D871A.PH@
M("`@?0H*("`@("\J*@H@("`@("H@56YS97)I86QI>F4@9&%T82X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)B1D871A("`@5&AE(&1A=&$@=&\@8F4@=6YS97)I86QI>F5D+@H@
M("`@("H@0'!A<F%M(&UI>&5D("1M;V1E("`@(%1H92!M;V1E(&]F('5N<V5R
M:6%L:7IA=&EO;BX@0V%N(&)E(&5I=&AE<B!A"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<VEN9VQE(&UO9&4@;W(@87)R87D@;V8@;6]D97,N("!)
M9B!A<G)A>2P@=VEL;"!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M('5N<V5R:6%L:7IE9"!I;B!T:&4@;W)D97(@<')O=FED960N"B`@("`@*B!`
M<&%R86T@;6EX960@)'!A<F%M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R
M<R!T:&4@=6YS97)I86QI>F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@;65T:&]D(')E<75I<F5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M=6YS97)I86QI>F4H)B1D871A+"`D;6]D92P@)'!A<F%M<R`](&YU;&PI"B`@
M("!["B`@("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@4T52
M24%,25I%7TY/3D4Z"B`@("`@("`@8V%S92!315))04Q)6D5?4U%,6$U,.@H@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?4D%7
M.@H@("`@("`@("`@("`D9&%T82`](')A=W5R;&1E8V]D92@D9&%T82D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]54DPZ
M"B`@("`@("`@("`@("1D871A(#T@=7)L9&5C;V1E*"1D871A*3L*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7U=$1%@Z"B`@
M("`@("`@("`@("1D871A(#T@=V1D>%]D97-E<FEA;&EZ92@D9&%T82D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]"6DE0
M.@H@("`@("`@("`@("`D9&%T82`](&)Z9&5C;VUP<F5S<R@D9&%T82P@9F%L
M<V4I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)
M6D5?24U!4%541C<Z"B`@("`@("`@("`@("1D871A(#T@:6UA<%]U=&8W7V1E
M8V]D92@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(%-%4DE!3$E:15]"05-)0SH*("`@("`@("`@("`@)&1A=&$@/2!`=6YS97)I
M86QI>F4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92!315))04Q)6D5?1UI?1$5&3$%413H*("`@("`@("`@("`@)&1A=&$@/2!G
M>FEN9FQA=&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!315))04Q)6D5?0D%3138T.@H@("`@("`@("`@("`D9&%T82`](&)A
M<V4V-%]D96-O9&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92!315))04Q)6D5?1UI?0T]-4%)%4U,Z"B`@("`@("`@("`@("1D
M871A(#T@9WIU;F-O;7!R97-S*"1D871A*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@4T5224%,25I%7U541C<Z"B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["B`@("`@("`@("`@("1D
M871A(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&%T82P@)W5T9BTW)RP@
M)'!A<F%M<RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%
M4DE!3$E:15]55$8W7T)!4TE#.@H@("`@("`@("`@("!(;W)D95]397)I86QI
M>F4Z.E]U;G-E<FEA;&EZ92@D9&%T82P@4T5224%,25I%7T)!4TE#+"`D<&%R
M86US*3L*("`@("`@("`@("`@2&]R9&5?4V5R:6%L:7IE.CI?=6YS97)I86QI
M>F4H)&1A=&$L(%-%4DE!3$E:15]55$8W+"`D<&%R86US*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VL@=VAE=&AE<B!O<B!N;W0@82!S97)I86QI>F%T:6]N(&UE=&AO9"!I<R!S
M=7!P;W)T960N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UO9&4@
M(%1H92!S97)I86QI>F%T:6]N(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@<W5P<&]R=&5D+"!F86QS92!I9B!N;W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI='DH)&UO9&4I"B`@
M("!["B`@("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@4T52
M24%,25I%7T):25`Z"B`@("`@("`@("`@(')E='5R;B!5=&EL.CIE>'1E;G-I
M;VY%>&ES=',H)V)Z,B<I.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]71$18
M.@H@("`@("`@("`@("!R971U<FX@571I;#HZ97AT96YS:6]N17AI<W1S*"=W
M9&1X)RD["@H@("`@("`@(&-A<V4@4T5224%,25I%7TE-05!55$8W.@H@("`@
M("`@(&-A<V4@4T5224%,25I%7TE-05!55$8X.@H@("`@("`@(&-A<V4@4T52
M24%,25I%7TE-05`X.@H@("`@("`@("`@("!R971U<FX@571I;#HZ97AT96YS
M:6]N17AI<W1S*"=I;6%P)RD["@H@("`@("`@(&-A<V4@4T5224%,25I%7T=:
M7T1%1DQ!5$4Z"B`@("`@("`@8V%S92!315))04Q)6D5?1UI?0T]-4%)%4U,Z
M"B`@("`@("`@8V%S92!315))04Q)6D5?1UI?14Y#3T0Z"B`@("`@("`@("`@
M(')E='5R;B!5=&EL.CIE>'1E;G-I;VY%>&ES=',H)WIL:6(G*3L*"B`@("`@
M("`@8V%S92!315))04Q)6D5?4U%,6$U,.@H@("`@("`@("`@("!R971U<FX@
M0&EN8VQU9&5?;VYC92`G6$U,+W-Q;#)X;6PN<&AP)SL*"B`@("`@("`@8V%S
M92!315))04Q)6D5?3D].13H*("`@("`@("!C87-E(%-%4DE!3$E:15]"05-)
M0SH*("`@("`@("!C87-E(%-%4DE!3$E:15]"05-%-C0Z"B`@("`@("`@8V%S
M92!315))04Q)6D5?4D%7.@H@("`@("`@(&-A<V4@4T5224%,25I%7U523#H*
M("`@("`@("!C87-E(%-%4DE!3$E:15]55$8W.@H@("`@("`@(&-A<V4@4T52
M24%,25I%7U541C=?0D%324,Z"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W-C,S
M`#$P-#$W,S8R-S<S`#`R,38W-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@4V5S<VEO;DAA;F1L97(Z
M.B!D969I;F5S(&%N($%022!F;W(@:6UP;&5M96YT:6YG(&-U<W1O;2!S97-S
M:6]N"B`J(&AA;F1L97)S(&9O<B!02%`N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<"QV(#$N,3,N
M,3`N."`R,#`V+S`S+S$P(#`P.C$T.C0R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4V5S<VEO;DAA;F1L97(*("HO
M"F-L87-S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J($AA<V@@
M8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!397-S:6]N
M2&%N9&QE<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@4V5S<VEO;DAA;F1L97(H)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D
M<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@8V]N8W)E=&4@4V5S<VEO;DAA;F1L97(@:6YS=&%N8V4@8F%S960@
M;VX*("`@("`J("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!397-S:6]N2&%N9&QE
M<B!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FXN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T
M97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!397-S:6]N
M2&%N9&QE<B!I;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@(&9A
M;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R
M>2@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@("`@("`@)&%P<"`]("1D<FEV
M97);,%T["B`@("`@("`@("`@("1D<FEV97(@/2`D9')I=F5R6S%=.PH@("`@
M("`@('T*"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH*
M("`@("`@("!I9B`H:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+G!H<"<["B`@("`@("`@("`@("1P87)A;7,@
M/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=S97-S:6]N:&%N9&QE<B<L("1D
M<FEV97(I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+U-E<W-I;VY(86YD
M;&5R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`
M9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U-E<W-I;VY(86YD
M;&5R+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U-E<W-I;VY(86YD;&5R
M+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+U-E<W-I;VY(86YD;&5R+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S
M(#T@)U-E<W-I;VY(86YD;&5R7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D:&%N9&QE<B`]
M("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1H86YD;&5R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F
M:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&AA;F1L97(["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C
M;VYC<F5T92!397-S:6]N2&%N9&QE<@H@("`@("H@:6YS=&%N8V4@8F%S960@
M;VX@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC
M90H@("`@("H@:68@;F\@4V5S<VEO;DAA;F1L97(@:6YS=&%N8V4@=VET:"!T
M:&4@<V%M92!P87)A;65T97)S"B`@("`@*B!C=7)R96YT;'D@97AI<W1S+@H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@
M)'9A<B`]("9397-S:6]N2&%N9&QE<CHZ<VEN9VQE=&]N*"D*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%-E92!397-S:6]N2&%N9&QE
M<CHZ9F%C=&]R>2@I+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!3
M964@4V5S<VEO;DAA;F1L97(Z.F9A8W1O<GDH*2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@8W)E871E9"!C;VYC<F5T92!397-S:6]N2&%N
M9&QE<B!I;G-T86YC92P@;W(@9F%L<V4*("`@("`J("`@("`@("`@("`@("`@
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D
M<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D
M:6YS=&%N8V5S(#T@87)R87DH*3L*"B`@("`@("`@)'-I9VYA='5R92`]('-E
M<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@
M*&5M<'1Y*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@
M("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F4V5S<VEO;DAA;F1L97(Z.F9A
M8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"B`@("`O*BH*
M("`@("`J($]P96X@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@
M*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<V%V95]P871H("`@("!4:&4@<&%T:"!T;R!T:&4@<V5S<VEO;B!O8FIE
M8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7VYA;64@(%1H92!N
M86UE(&]F('1H92!S97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&]P96XH)'-A=F5?<&%T:"P@)'-E<W-I;VY?;F%M
M92D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($-L;W-E('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@
M("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E860@=&AE(&1A=&$@9F]R
M(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@9G)O;2!T:&4*("`@
M("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S
M97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M860H)&ED*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5W)I=&4@<V5S<VEO;B!D871A('1O('1H92!397-S:6]N2&%N9&QE<B!B86-K
M96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I
M9FEE<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE
M('-E<W-I;VX@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!W<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E
M9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A
M(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@
M("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE
M('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D97-T<F]Y*"1I9"D*("`@('L*("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!S=&%L92!S
M97-S:6]N<R!F<F]M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@
M("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1M87AL:69E=&EM92`@5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M8R@D;6%X;&EF971I;64@/2`S,#`I"B`@("!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF(&$@<V5S<VEO;B!B96QO;F=S
M('1O(&%N(&%U=&AE;G1I8V%T960@=7-E<BX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S
M:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$@:71S96QF+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)')E='5R;E]U<V5R("!)9B!T<G5E+"!R971U<FX@=&AE
M('5S97(@<V5S<VEO;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;GQS=')I;F<@(%1R=64@;W(@=&AE('5S97(G<R!S97-S:6]N(&1A=&$@
M:68@=&AE('-E<W-I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&)E;&]N9W,@=&\@86X@875T:&5N=&EC871E9"!U<V5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?:7-!=71H96YT:6-A=&5D*"1S97-S:6]N7V1A=&$L("1R
M971U<FY?9&%T82`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M<V5S<VEO;E]D871A*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`D=F%R<R`]('!R96=?<W!L:70H)R\H6V$M>BQ!
M+5I=*RE<?"\G+"`D<V5S<VEO;E]D871A+"`M,2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@4%)%1U]34$Q)5%].3U]%35!462!\(%!214=?4U!,251?
M1$5,24U?0T%05%5212D["@H@("`@("`@("1A=71H(#T@87)R87E?<V5A<F-H
M*"=A=71H)RP@)'9A<G,I.PH@("`@("`@(&EF("AE;7!T>2@D875T:"DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)&1A=&$@/2!U;G-E<FEA;&EZ92@D=F%R<ULD875T:"`K(#%=*3L*("`@("`@
M("!I9B`H96UP='DH)&1A=&$I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&1A=&%;)V%U=&AE
M;G1I8V%T960G72DI('L*("`@("`@("`@("`@<F5T=7)N("1R971U<FY?9&%T
M82`_("1D871A(#H@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@82!L:7-T(&]F('1H92!V86QI9"!S97-S:6]N(&ED96YT:69I
M97)S+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($$@;&ES="!O9B!V86QI9"!S97-S:6]N(&ED96YT:69I
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397-S:6]N241S*"D*("`@
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P
M<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!T
M:&4@;G5M8F5R(&]F(&-U<G)E;G1L>2!L;V=G960@:6X@=7-E<G,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!!(&-O=6YT(&]F(&QO9V=E9"!I
M;B!U<V5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1!=71H96YT:6-A
M=&5D57-E<G,H*0H@("`@>PH@("`@("`@("1C;W5N="`](#`["@H@("`@("`@
M("1S97-S:6]N<R`]("1T:&ES+3YG971397-S:6]N241S*"D["B`@("`@("`@
M:68@*&ES7V$H)'-E<W-I;VYS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<V5S<VEO;G,["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D<V5S<VEO;G,@87,@)&ED*2!["B`@("`@("`@("`@("1D871A(#T@
M)'1H:7,M/G)E860H)&ED*3L*("`@("`@("`@("`@:68@*&ES7V$H)&1A=&$L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T
M83L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES+3Y?:7-!
M=71H96YT:6-A=&5D*"1D871A*2D@>PH@("`@("`@("`@("`@("`@)&-O=6YT
M*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8V]U;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O
M9B!C=7)R96YT;'D@;&]G9V5D(&EN('5S97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($$@;&ES="!O9B!L;V=G960@:6X@=7-E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QI<W1!=71H96YT:6-A=&5D57-E<G,H)&1A=&4@
M/2!F86QS92D*("`@('L*("`@("`@("`D=7-E<G,@/2!A<G)A>2@I.PH*("`@
M("`@("`D<V5S<VEO;G,@/2`D=&AI<RT^9V5T4V5S<VEO;DE$<R@I.PH@("`@
M("`@(&EF("AI<U]A*"1S97-S:6]N<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-E<W-I;VYS.PH@("`@("`@('T*"B`@("`@("`@
M9F]R96%C:"`H)'-E<W-I;VYS(&%S("1I9"D@>PH@("`@("`@("`@("`D9&%T
M82`]("1T:&ES+3YR96%D*"1I9"D["B`@("`@("`@("`@(&EF("AI<U]A*"1D
M871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&1A=&$["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1D871A(#T@)'1H
M:7,M/E]I<T%U=&AE;G1I8V%T960H)&1A=&$L('1R=64I.PH@("`@("`@("`@
M("!I9B`H)&1A=&$@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=7-E
M<B`]("1D871A6R=U<V5R260G73L*("`@("`@("`@("`@("`@(&EF("@D9&%T
M92D@>PH@("`@("`@("`@("`@("`@("`@("1U<V5R(#T@9&%T92@G<B<L("1D
M871A6R=T:6UE<W1A;7`G72D@+B`G("`G("X@)'5S97(["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D=7-E<G-;72`]("1U<V5R.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97)S.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+U-E<W-I;VY/8FIE8W1S+G!H<```````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q-34R-@`Q,#0Q-S,V,C<W,P`P,C$W,3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!(;W)D95]397-S:6]N3V)J96-T<SHZ(&-L87-S('!R;W9I9&5S
M(&$@=V%Y(&9O<B!S=&]R:6YG(&1A=&$*("H@*'5S=6%L;'DL(&)U="!N;W0@
M;F5C97-S87)I;'DL(&]B:F5C=',I(&EN('1H92!C=7)R96YT('5S97(G<PH@
M*B!S97-S:6]N+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]397-S:6]N3V)J
M96-T<R]397-S:6]N3V)J96-T<RYP:'`L=B`Q+C8N,3(N."`R,#`V+S`Q+S`Q
M(#(Q.C(X.C,U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=7$*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R
M9&5?4V5S<VEO;D]B:F5C=',*("HO"F-L87-S($AO<F1E7U-E<W-I;VY/8FIE
M8W1S('L*"B`@("`O*BH*("`@("`J(%1H92!L:7-T(&]F(&]I9',@=&\@<')U
M;F4@870@=&AE(&5N9"!O9B!A(')E<75E<W0N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P<G5N94QI<W0@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('-T;W)E+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VYA;64@/2`G
M:&]R9&5?<V5S<VEO;E]O8FIE8W1S)SL*"B`@("`O*BH*("`@("`J($%L;&]W
M('-T;W)E*"D@=&\@;W9E<G=R:71E(&-U<G)E;G0@;V)J96-T<S\*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?;W9E<G=R
M:71E(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@;6%X:6UU;2!N=6UB
M97(@;V8@;V)J96-T<R!T:&%T('1H92!S=&]R92!S:&]U;&0@:&]L9"X*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<VEZ
M92`](#(P.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T
M;R!T:&4@9VQO8F%L($AO<F1E7U-E<W-I;VY/8FIE8W1S(&]B:F5C="P*("`@
M("`J(&]N;'D@8W)E871I;F<@:70@:68@:70@9&]E<VXG="!A;')E861Y(&5X
M:7-T+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME
M9"!A<SH*("`@("`J("`@)&]B:F5C='-T;W)E(#T@)DAO<F1E7U-E<W-I;VY/
M8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@("`J"B`@("`@*B!`<F5T=7)N($AO
M<F1E7U-E<W-I;VY/8FIE8W1S("!4:&4@2&]R9&5?4V5S<VEO;D]B:F5C=',@
M:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@
M("`@>PH@("`@("`@('-T871I8R`D;V)J96-T.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1O8FIE8W0I*2!["B`@("`@("`@("`@("1O8FIE8W0@/2!N97<@2&]R
M9&5?4V5S<VEO;D]B:F5C=',H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A
M;65T97(@87)R87DN"B`@("`@*B`\<')E/@H@("`@("H@3W!T:6]N86P@4&%R
M86UE=&5R<SH*("`@("`J("=N86UE)R`@+2T@(%1H92!N86UE(&]F('1H92!S
M97-S:6]N('9A<FEA8FQE('1O('-T;W)E('1H92!O8FIE8W1S(&EN+@H@("`@
M("H@)W-I>F4G("`M+2`@5&AE(&UA>&EM=6T@<VEZ92!O9B!T:&4@*&YO;BUP
M<G5N86)L92D@;V)J96-T('-T;W)E+@H@("`@("H@/"]P<F4^"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7U-E<W-I;VY/8FIE8W1S*"1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=N86UE
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;F%M92`]("1P87)A;7-;)VYA
M;64G73L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=S
M:7IE)UTI("8F(&ES7VEN="@D<&%R86US6R=S:7IE)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<VEZ92`]("1P87)A;7-;)W-I>F4G73L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<F%P<&5R(&%R;W5N9"!S=&]R92!T
M:&%T('=I;&P@<F5T=7)N('1H92!O:60@:6YS=&5A9"X*("`@("`J"B`@("`@
M*B!`<V5E('-T;W)E"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A
M("`@("!4:&4@9&%T82!T;R!S=&]R92!I;B!T:&4@<V5S<VEO;B!S=&]R92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1P<G5N92`@268@9F%L<V4L('1H:7,@
M;V)J96-T('=I;&P@;F]T(&)E('!R=6YE9"!F<F]M('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!S=&]R92!I9B!T:&4@;6%X:6UU;2!S=&]R
M92!S:7IE(&ES(&5X8V5E9&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@340U('-T<FEN9R!R97!R97-E;G1I;F<@=&AE(&]B:F5C="=S
M($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R94]I9"@D9&%T82P@)'!R
M=6YE(#T@=')U92D*("`@('L*("`@("`@("`D;VED(#T@)'1H:7,M/F]I9"@D
M9&%T82D["B`@("`@("`@)'1H:7,M/G-T;W)E*"1O:60L("1D871A+"`D<')U
M;F4I.PH@("`@("`@(')E='5R;B`D;VED.PH@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<W1O<F4@86X@;V)J96-T(&EN('1H92!S97-S:6]N
M('-T;W)E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]I9"`@("`@
M3V)J96-T($E$('5S960@87,@=&AE('-T;W)A9V4@:V5Y+@H@("`@("H@0'!A
M<F%M(&UI>&5D("1D871A("`@("!4:&4@9&%T82!T;R!S=&]R92!I;B!T:&4@
M<V5S<VEO;B!S=&]R92X*("`@("`J($!P87)A;2!B;V]L96%N("1P<G5N92`@
M268@9F%L<V4L('1H:7,@;V)J96-T('=I;&P@;F]T(&)E('!R=6YE9"!F<F]M
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S=&]R92!I9B!T
M:&4@;6%X:6UU;2!S=&]R92!S:7IE(&ES(&5X8V5E9&5D+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@D;VED+"`D
M9&%T82P@)'!R=6YE(#T@=')U92D*("`@('L*("`@("`@("`O*B!3970@=7`@
M;V)J96-T(&YO=RX@*B\*("`@("`@("`D9&%T84]B:F5C="`](&%R<F%Y*"D[
M"B`@("`@("`@)&1A=&%/8FIE8W1;)V1A=&$G72`]('-E<FEA;&EZ92@D9&%T
M82D["B`@("`@("`@)&1A=&%/8FIE8W1;)W!R=6YE)UT@/2`D<')U;F4["@H@
M("`@("`@(&EF("@A:7-S970H)%]315-324].6R1T:&ES+3Y?;F%M95TI*2![
M"B`@("`@("`@("`@("1?4T534TE/3ELD=&AI<RT^7VYA;65=(#T@87)R87DH
M*3L*("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U
M;F4G72`](#`["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]O=F5R
M=W)I=&4@?'P@(6ES<V5T*"1?4T534TE/3ELD=&AI<RT^7VYA;65=6R1O:61=
M*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LD;VED
M72`]("1D871A3V)J96-T.PH@("`@("`@("`@("!I9B`H)'!R=6YE*2!["B`@
M("`@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N
M92==*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-H
M96-K(&9O<B!P<G5N86)L92!/:61S+B`J+PH@("`@("`@("1T:&ES+3Y?<')U
M;F5/:61S*"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3W9E<G=R:71E<R!A(&-U<G)E;G0@96QE;65N="!I;B!T:&4@
M;V)J96-T('-T;W)E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]I
M9"`@("`@3V)J96-T($E$('5S960@87,@=&AE('-T;W)A9V4@:V5Y+@H@("`@
M("H@0'!A<F%M(&UI>&5D("1D871A("`@("!4:&4@9&%T82!T;R!S=&]R92!I
M;B!T:&4@<V5S<VEO;B!S=&]R92X*("`@("`J($!P87)A;2!B;V]L96%N("1P
M<G5N92`@268@9F%L<V4L('1H:7,@;V)J96-T('=I;&P@;F]T(&)E('!R=6YE
M9"!F<F]M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S=&]R
M92!I9B!T:&4@;6%X:6UU;2!S=&]R92!S:7IE(&ES(&5X8V5E9&5D+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!O=F5R=W)I
M=&4H)&]I9"P@)&1A=&$L("1P<G5N92`]('1R=64I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]O=F5R=W)I=&4@/2!T<G5E.PH@("`@("`@("1S=6-C97-S(#T@
M)'1H:7,M/G-T;W)E*"1O:60L("1D871A+"`D<')U;F4I.PH@("`@("`@("1T
M:&ES+3Y?;W9E<G=R:71E(#T@9F%L<V4["B`@("`@("`@<F5T=7)N("1S=6-C
M97-S.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T<FEV
M92!A;B!O8FIE8W0@9G)O;2!T:&4@<W1O<F4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;VED("`@3V)J96-T($E$('1O('%U97)Y+@H@("`@("H@
M0'!A<F%M(&5N=6T@)'1Y<&4@("`@3D]4(%53140*("`@("`J($!P87)A;2!I
M;G1E9V5R("1V86P@($Y/5"!54T5$"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5&AE(')E<75E<W1E9"!O8FIE8W0L(&]R(&9A;'-E(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9Q=65R>2@D;VED+"`D='EP92`]
M(&YU;&PL("1V86P@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H
M)%]315-324].6R1T:&ES+3Y?;F%M95TI('Q\"B`@("`@("`@("`@("AI<U]N
M=6QL*"1O:60I('Q\("%I<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LD
M;VED72DI*2!["B`@("`@("`@("`@("1O8FIE8W0@/2!F86QS93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;V)J96-T(#T@=6YS97)I86QI>F4H
M)%]315-324].6R1T:&ES+3Y?;F%M95U;)&]I9%U;)V1A=&$G72D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D;V)J96-T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T<R!T:&4@<')U;F4@9FQA9R!O;B!A('-T;W)E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O:60@("`@(%1H92!O8FIE
M8W0@240N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<')U;F4@(%1R=64@=&\@
M86QL;W<@<')U;FEN9RP@9F%L<V4@9F]R(&YO('!R=6YI;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=%!R=6YE1FQA9R@D;VED+"`D<')U;F4I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELD=&AI<RT^7VYA;65=6R1O
M:61=*2`F)@H@("`@("`@("`@("`H)%]315-324].6R1T:&ES+3Y?;F%M95U;
M)&]I9%U;)W!R=6YE)UT@(3T@)'!R=6YE*2D@>PH@("`@("`@("`@("`D7U-%
M4U-)3TY;)'1H:7,M/E]N86UE75LD;VED75LG<')U;F4G72`]("1P<G5N93L*
M("`@("`@("`@("`@:68@*"1P<G5N92D@>PH@("`@("`@("`@("`@("`@)%]3
M15-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G72LK.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?
M;F%M95U;)U]?<')U;F4G72TM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S(&%N($])1"!F;W(@86X@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@5&AE
M(&1A=&$@=&\@<W1O<F4@:6X@=&AE('-T;W)E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("1O:60@($%N(&]B:F5C="!)1"!T;R!U<V4@87,@=&AE
M('-T;W)A9V4@:V5Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!O:60H)&1A=&$I
M"B`@("!["B`@("`@("`@<F5T=7)N(&UD-2AS97)I86QI>F4H)&1A=&$I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E('1H92!L:7-T(&]F('!R
M=6YA8FQE(&]I9',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]P<G5N94]I9',H*0H@("`@>PH@("`@("`@
M(&EF("AI<U]N=6QL*"1T:&ES+3Y?<')U;F5,:7-T*2`F)@H@("`@("`@("`@
M("!I<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N92==*2`F
M)@H@("`@("`@("`@("`H)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U
M;F4G72`^("1T:&ES+3Y?<VEZ92DI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M<G5N94QI<W0@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D7U-%
M4U-)3TY;)'1H:7,M/E]N86UE72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@("`@(&EF("@D=F%L6R=P<G5N92==*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P<G5N94QI<W1;72`]("1K97D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5G:7-T97)?<VAU
M=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G7W!R=6YE)RDI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%!R=6YE(&]L9"!S=&]R92!E
M;G1R:65S(&%T(')E<75E<W0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P<G5N92@I"B`@
M("!["B`@("`@("`@)'!R=6YE3VED<R`](&%R<F%Y7W-L:6-E*"1T:&ES+3Y?
M<')U;F5,:7-T+"`P+"`D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N
M92==("T@)'1H:7,M/E]S:7IE*3L*("`@("`@("!F;W)E86-H("@D<')U;F5/
M:61S(&%S("1V86PI('L*("`@("`@("`@("`@=6YS970H)%]315-324].6R1T
M:&ES+3Y?;F%M95U;)'9A;%TI.PH@("`@("`@('T*("`@("`@("`D7U-%4U-)
M3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N92==("T](&-O=6YT*"1P<G5N94]I
M9',I.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-H87)E
M+G!H<```````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W
M,S<W,@`Q,#0Q-S,V,C<W,P`P,C`P,C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R
M9&4O1&%T851R964N<&AP)SL*"B\J*@H@*B!(;W)D95]3:&%R93HZ('!R;W9I
M9&5S(&%N(&EN=&5R9F%C92!T;R!A;&P@<VAA<F5S(&$@=7-E<B!M:6=H="!H
M879E+B`@271S"B`J(&UE=&AO9',@=&%K92!C87)E(&]F(&%N>2!S:71E+7-P
M96-I9FEC(')E<W1R:6-T:6]N<R!C;VYF:6=U<F5D(&EN(&EN('1H90H@*B!A
M<'!L:6-A=&EO;B=S('!R969S+G!H<"!A;F0@8V]N9BYP:'`@9FEL97,N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U-H87)E+U-H87)E+G!H<"QV(#$N,3$Q
M+C(N,38@,C`P-B\P,2\P,2`R,3HR.#HS-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C
M:RYQ8RYC83X*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!);F9O=&5C:R!);G1E
M<FYE="`\=V5B;6%S=&5R0&EN9F]T96-K+G%C+F-A/@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]E;"!686YD86P@/&IV86YD
M86Q`:6YF;W1E8VLN<6,N8V$^"B`J($!A=71H;W(@($UI:V4@0V]C:')A;64@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?4VAA<F4*("HO"F-L87-S($AO<F1E7U-H
M87)E('L*"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@82!$871A5')E92!I
M;G-T86YC92!T;R!M86YA9V4O<W1O<F4@<VAA<F5S"B`@("`@*@H@("`@("H@
M0'9A<B!$871A5')E90H@("`@("HO"B`@("!V87(@)%]D871A=')E93L*"B`@
M("`O*BH*("`@("`J(%1H92!A<'!L:6-A=&EO;B!W92=R92!M86YA9VEN9R!S
M:&%R97,@9F]R+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V%P<#L*"B`@("`O*BH*("`@("`J(%1H92!S=6)C;&%S<R!O
M9B!$871A5')E94]B:F5C="!T;R!I;G-T86YT:6%T92!S:&%R97,@87,N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<VAA
M<F5/8FIE8W0@/2`G1&%T851R965/8FIE8W1?4VAA<F4G.PH*("`@("\J*@H@
M("`@("H@02!C86-H92!O9B!A;&P@<VAA<F5S('1H870@:&%V92!B965N(')E
M=')I979E9"P@<V\@=V4@9&]N)W0@:&ET('1H90H@("`@("H@8F%C:V5N9"!A
M9V%I;B!A;F0@86=A:6X@9F]R('1H96TN"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]C86-H92`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!#86-H92!U<V5D(&9O<B!L:7-T4VAA<F5S*"DN"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]L:7-T8V%C
M:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@02!L:7-T(&]F(&]B:F5C
M=',@=&AA="!W92=R92!C=7)R96YT;'D@<V]R=&EN9RP@9F]R(')E9F5R96YC
M92!D=7)I;F<@=&AE"B`@("`@*B!S;W)T:6YG(&%L9V]R:71H;2X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-O<G1,:7-T
M.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E
M;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?4VAA<F4@:6YS=&%N8V4N($ET"B`@
M("`@*B!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AO
M<F1E7U-H87)E(&EN<W1A;F-E(&-U<G)E;G1L>0H@("`@("H@97AI<W1S+@H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*
M("`@("`J("`@/&-O9&4^)'9A<B`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N
M*"1A<'`I.SPO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M<'`@(%1H92!A<'!L:6-A=&EO;G,@=&AA="!T:&4@<VAA<F5S(')E;&%T97,@
M=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]3:&%R92`@5&AE(&-O
M;F-R971E(%-H87)E(')E9F5R96YC92P@;W(@9F%L<V4@;VX@86X@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&%P<"D*("`@('L*
M("`@("`@("!S=&%T:6,@)'-H87)E<SL*"B`@("`@("`@:68@*"%I<W-E="@D
M<VAA<F5S6R1A<'!=*2D@>PH@("`@("`@("`@("`D<VAA<F5S6R1A<'!=(#T@
M;F5W($AO<F1E7U-H87)E*"1A<'`I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1S:&%R97-;)&%P<%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H
M92!A<'!L:6-A=&EO;B!T:&%T('1H92!S:&%R97,@8F5L;VYG('1O+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!(;W)D95]3:&%R92@D87!P*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D8V]N9BP@)')E9VES=')Y.PH*("`@("`@("!I9B`H96UP
M='DH)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH)UEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E
M(&)A8VME;F0@=&\@=7-E(%-H87)E<RXG+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`]("1C;VYF6R=D871A=')E
M92==6R=D<FEV97(G73L*("`@("`@("`D=&AI<RT^7V%P<"`]("1A<'`["B`@
M("`@("`@)'1H:7,M/E]D871A=')E92`]("9$871A5')E93HZ<VEN9VQE=&]N
M*`H@("`@("`@("`@("`D9')I=F5R+`H@("`@("`@("`@("!A<G)A>5]M97)G
M92A(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1D<FEV97(I
M+"!A<G)A>2@G9W)O=7`G(#T^("=H;W)D92YS:&%R97,N)R`N("1A<'`I*0H@
M("`@("`@("D["@H@("`@("`@($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO
M;VM?<VAA<F5?:6YI="<L(&%R<F%Y*"1T:&ES+"`D87!P*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!$871A5')E92!I;G-T86YC92!U
M<V5D('1O(&UA;F%G92!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!R971U
M<FX@1&%T851R964@(%1H:7,@<VAA<F4G<R!$871A5')E92!I;G-T86YC92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$1A=&%4<F5E*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]D871A=')E93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!$871A5')E94]B:F5C=%]3:&%R92!O8FIE8W0@
M8V]R<F5S<&]N9&EN9R!T;R!T:&4@9VEV96X@<VAA<F4*("`@("`J(&YA;64L
M('=I=&@@=&AE(&1E=&%I;',@<F5T<FEE=F5D(&%P<')O<')I871E;'DN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@
M=&AE('-H87)E('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@
M1&%T851R965/8FIE8W1?4VAA<F4@(%1H92!R97%U97-T960@<VAA<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G9713:&%R92@D;F%M92D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]C86-H95LD;F%M95TI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V-A8VAE6R1N86UE73L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?8V%C:&5;)&YA;65=(#T@)B1T:&ES+3Y?9&%T
M871R964M/F=E=$]B:F5C="@D;F%M92P@)'1H:7,M/E]S:&%R94]B:F5C="D[
M"B`@("`@("`@:68@*"%I<U]A*"1T:&ES+3Y?8V%C:&5;)&YA;65=+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5;)&YA;65=
M+3YS9713:&%R94]B*"1T:&ES*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V-A8VAE6R1N86UE73L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!$871A5')E94]B:F5C=%]3:&%R92!O8FIE8W0@8V]R<F5S
M<&]N9&EN9R!T;R!T:&4@9VEV96X@=6YI<75E"B`@("`@*B!)1"P@=VET:"!T
M:&4@9&5T86EL<R!R971R:65V960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:60@(%1H92!I9"!O9B!T:&4@<VAA<F4@
M=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E94]B
M:F5C=%]3:&%R92`@5&AE(')E<75E<W1E9"!S:&%R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F=E=%-H87)E0GE)9"@D8VED*0H@("`@>PH@("`@("`@("1S
M:&%R92`]("1T:&ES+3Y?9&%T871R964M/F=E=$]B:F5C=$)Y260H)&-I9"P@
M)'1H:7,M/E]S:&%R94]B:F5C="D["B`@("`@("`@:68@*"%I<U]A*"1S:&%R
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D<VAA<F4M/G-E=%-H
M87)E3V(H)'1H:7,I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-H87)E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!$
M871A5')E94]B:F5C=%]3:&%R92!O8FIE8W1S(&-O<G)E<W!O;F1I;F<@=&\@
M=&AE"B`@("`@*B!G:79E;B!S970@;V8@=6YI<75E($E$<RP@=VET:"!T:&4@
M9&5T86EL<R!R971R:65V960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&-I9',@(%1H92!A<G)A>2!O9B!I9',@=&\@<F5T
M<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(')E<75E
M<W1E9"!S:&%R97,N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G9713:&%R97,H
M)&-I9',I"B`@("!["B`@("`@("`@)'-H87)E<R`]("1T:&ES+3Y?9&%T871R
M964M/F=E=$]B:F5C=',H)&-I9',L("1T:&ES+3Y?<VAA<F5/8FIE8W0I.PH@
M("`@("`@(&EF("AI<U]A*"1S:&%R97,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1S:&%R97,["B`@("`@("`@?0H*("`@("`@("`D
M:V5Y<R`](&%R<F%Y7VME>7,H)'-H87)E<RD["B`@("`@("`@9F]R96%C:"`H
M)&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("!I9B`H:7-?82@D<VAA<F5S
M6R1K97E=+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'-H87)E<ULD:V5Y73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'1H:7,M/E]C86-H95LD:V5Y72`]("8D<VAA<F5S6R1K97E=.PH@("`@("`@
M("`@("`D<VAA<F5S6R1K97E=+3YS9713:&%R94]B*"1T:&ES*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<VAA<F5S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(&YE=R!S:&%R92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE('-H87)E)W,@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7U-H87)E("!!(&YE
M=R!S:&%R92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9N97=3:&%R
M92@D;F%M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&YA;64I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=3:&%R92!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>2<I.PH@("`@("`@('T*("`@("`@("`D<VAA
M<F4@/2`F;F5W("1T:&ES+3Y?<VAA<F5/8FIE8W0H)&YA;64I.PH@("`@("`@
M("1S:&%R92T^<V5T1&%T851R964H)'1H:7,M/E]D871A=')E92D["B`@("`@
M("`@)'-H87)E+3YS9713:&%R94]B*"1T:&ES*3L*("`@("`@("`D<VAA<F4M
M/G-E="@G;W=N97(G+"!!=71H.CIG971!=71H*"DI.PH*("`@("`@("!R971U
M<FX@)'-H87)E.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('-H87)E
M('1O('1H92!S:&%R97,@<WES=&5M+B!4:&4@<VAA<F4@;75S="!F:7)S="!B
M92!C<F5A=&5D('=I=&@*("`@("`J($AO<F1E7U-H87)E.CIN97=3:&%R92@I
M+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!D971A:6QS(&%D9&5D('1O(&ET+`H@
M("`@("H@8F5F;W)E('1H:7,@9G5N8W1I;VX@:7,@8V%L;&5D+@H@("`@("H*
M("`@("`J($!P87)A;2!$871A5')E94]B:F5C=%]3:&%R92`D<VAA<F4@(%1H
M92!N97<@<VAA<F4@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;GQ014%27T5R<F]R("!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9%-H87)E*"1S:&%R92D*("`@('L*("`@("`@
M("!I9B`H(6ES7V$H)'-H87)E+"`G1&%T851R965/8FIE8W1?4VAA<F4G*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4VAA<F5S
M(&UU<W0@8F4@1&%T851R965/8FIE8W1?4VAA<F4@;V)J96-T<R!O<B!E>'1E
M;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@("1P97)M(#T@
M)B1'3$]"04Q36R=P97)M<R==+3YN97=097)M:7-S:6]N*"1S:&%R92T^9V5T
M3F%M92@I*3L*("`@("`@("!I9B`H:7-?82@D<&5R;2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'!E<FT["B`@("`@("`@?0H*("`@
M("`@("`O*B!':79E('1H92!O=VYE<B!F=6QL(&%C8V5S<R`J+PH@("`@("`@
M("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D<VAA<F4M/F=E="@G;W=N97(G
M*2P@4$5235-?4TA/5RP@9F%L<V4I.PH@("`@("`@("1P97)M+3YA9&15<V5R
M4&5R;6ES<VEO;B@D<VAA<F4M/F=E="@G;W=N97(G*2P@4$5235-?4D5!1"P@
M9F%L<V4I.PH@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D<VAA
M<F4M/F=E="@G;W=N97(G*2P@4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@
M("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D<VAA<F4M/F=E="@G;W=N97(G
M*2P@4$5235-?1$5,151%+"!F86QS92D["@H@("`@("`@("1S:&%R92T^<V5T
M4&5R;6ES<VEO;B@D<&5R;2P@9F%L<V4I.PH*("`@("`@("`D<F5S=6QT(#T@
M2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:&%R95]A9&0G+"!A<G)A
M>2@D<VAA<F4I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VAO<F1E)RP@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^861D
M*"1S:&%R92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@<VAA
M<F4@9G)O;2!T:&4@<VAA<F5S('-Y<W1E;2!P97)M86YE;G1L>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?4VAA<F4@)'-H87)E("!4
M:&4@<VAA<F4@=&\@<F5M;W9E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;GQ014%27T5R<F]R("!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;6]V95-H87)E*"1S:&%R92D*("`@('L*("`@
M("`@("!I9B`H(6ES7V$H)'-H87)E+"`G1&%T851R965/8FIE8W1?4VAA<F4G
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4VAA
M<F5S(&UU<W0@8F4@1&%T851R965/8FIE8W1?4VAA<F4@;V)J96-T<R!O<B!E
M>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@("1R97-U
M;'0@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-H87)E7W)E;6]V
M92<L(&%R<F%Y*"1S:&%R92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]R9&4G+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T
M<F5E+3YR96UO=F4H)'-H87)E*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K<R!T;R!S964@:68@82!S:&%R92!H87,@86YY(&-H:6QD('-H87)E<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?4VAA<F4@)'-H
M87)E("!4:&4@<VAA<F4@=&\@8VAE8VL@9F]R(&-H:6QD<F5N+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@<W!E8VEF:65D
M('-H87)E(&AA<R!C:&EL9"!S:&%R97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&AA<T-H:6QD<F5N*"1S:&%R92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H
M)'-H87)E+"`G1&%T851R965/8FIE8W1?4VAA<F4G*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4VAA<F5S(&UU<W0@8F4@1&%T
M851R965/8FIE8W1?4VAA<F4@;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S
M<RXG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H8F]O;"DD=&AI<RT^
M7V1A=&%T<F5E+3YG971.=6UB97)/9D-H:6QD<F5N*"1S:&%R92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<VAA<F4G<R!D:7)E8W0@<&%R
M96YT(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S:&%R
M92`@1V5T('1H92!P87)E;G0@;V8@=&AI<R!S:&%R92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7U-H87)E("!4:&4@<&%R96YT('-H
M87)E+"!I9B!I="!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G9710
M87)E;G0H)&-H:6QD*0H@("`@>PH@("`@("`@("1I9"`]("1T:&ES+3Y?9&%T
M871R964M/F=E=%!A<F5N="@D8VAI;&0I.PH@("`@("`@(&EF("AI<U]A*"1I
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&ED.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"$D:60@?'P@*"1I9"`]/2!$051!5%)%
M15]23T]4*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R
M<F]R*"=087)E;G0@9&]E<R!N;W0@97AI<W0N)RD["B`@("`@("`@("`@(')E
M='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=%-H87)E0GE)9"@D:60I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@240@;V8@82!S:&%R92X*("`@("`J"B`@("`@*B!`<&%R86T@
M1&%T851R965/8FIE8W1?4VAA<F4@(%1H92!S:&%R92!T;R!R971U<FX@=&AE
M($E$(&]F+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('-H
M87)E)W,@240@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9713:&%R94ED*"1S:&%R92D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T260H)'-H87)E+3YG971.86UE
M*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@571I;&ET>2!F=6YC=&EO;B!T
M;R!B92!U<V5D('=I=&@@=6%S;W)T*"D@9F]R('-O<G1I;F<@87)R87ES(&]F
M"B`@("`@*B!(;W)D95]3:&%R92!O8FIE8W1S+@H@("`@("H@17AA;7!L93H\
M8V]D93X*("`@("`J('5A<V]R="@D;&ES="P@87)R87DH)TAO<F1E7U-H87)E
M)RP@)U]S;W)T4VAA<F5S)RDI.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<V]R
M=%-H87)E<R@D82P@)&(I"B`@("!["B`@("`@("`@)&%087)T<R`](&5X<&QO
M9&4H)SHG+"`D82T^9V5T3F%M92@I*3L*("`@("`@("`D8E!A<G1S(#T@97AP
M;&]D92@G.B<L("1B+3YG971.86UE*"DI.PH*("`@("`@("`D;6EN(#T@;6EN
M*&-O=6YT*"1A4&%R=',I+"!C;W5N="@D8E!A<G1S*2D["B`@("`@("`@)&ED
M02`]("<G.PH@("`@("`@("1I9$(@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D;6EN.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@D:61!*2![
M"B`@("`@("`@("`@("`@("`D:61!("X]("<Z)SL*("`@("`@("`@("`@("`@
M("1I9$(@+CT@)SHG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I9$$@
M+CT@)&%087)T<ULD:5T["B`@("`@("`@("`@("1I9$(@+CT@)&)087)T<ULD
M:5T["@H@("`@("`@("`@("!I9B`H)&ED02`A/2`D:61"*2!["B`@("`@("`@
M("`@("`@("`D8W5R02`](&ES<V5T*"1T:&ES+3Y?<V]R=$QI<W1;)&ED05TI
M(#\@)'1H:7,M/E]S;W)T3&ES=%LD:61!72T^9V5T*"=N86UE)RD@.B`G)SL*
M("`@("`@("`@("`@("`@("1C=7)"(#T@:7-S970H)'1H:7,M/E]S;W)T3&ES
M=%LD:61"72D@/R`D=&AI<RT^7W-O<G1,:7-T6R1I9$)=+3YG970H)VYA;64G
M*2`Z("<G.PH@("`@("`@("`@("`@("`@<F5T=7)N('-T<FYA=&-A<V5C;7`H
M)&-U<D$L("1C=7)"*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N(&-O=6YT*"1A4&%R=',I(#X@8V]U;G0H)&)087)T<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!S:&%R92!E>&ES=',@
M:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M:&%R92`@5&AE('-H87)E('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@<VAA<F4@97AI<W1S+"!F86QS92!O
M=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D<VAA<F4I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F5X:7-T
M<R@D<VAA<F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M8V]U;G0@;V8@86QL('-H87)E<R!T:&%T("1U<V5R:60@:&%S(&%C8V5S<R!T
M;RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7-E<FED("`@("`@
M5&AE('5S97)I9"!O9B!T:&4@=7-E<B!T;R!C:&5C:R!A8V-E<W,@9F]R+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FT@("`@("`@(%1H92!L979E;"!O
M9B!P97)M:7-S:6]N<R!R97%U:7)E9"X*("`@("`J($!P87)A;2!M:7AE9"`@
M("1A='1R:6)U=&5S("!297-T<FEC="!T:&4@<VAA<F5S(&-O=6YT960@=&\@
M=&AO<V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!M871C
M:&EN9R`D871T<FEB=71E<RX@06X@87)R87D@;V8*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A='1R:6)U=&4O=F%L=65S('!A:7)S(&]R
M(&$@<VAA<F4@;W=N97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!U<V5R;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@
M("`@("!4:&4@<&%R96YT('-H87)E('1O('-T87)T('-E87)C:&EN9R!A="X*
M("`@("`J($!P87)A;2!B;V]L96%N("1A;&Q,979E;',@("!2971U<FX@86QL
M(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L
M=',@=&\@86QL(&QE=F5L<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@($YU;6)E<B!O9B!S:&%R97,@=&AE('5S97(@:&%S(&%C8V5S<R!T;RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G13:&%R97,H)'5S97)I9"P@)'!E
M<FT@/2!015)-4U]32$]7+"`D871T<FEB=71E<R`](&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R96YT(#T@1$%40512145?4D]/5"P@)&%L
M;$QE=F5L<R`]('1R=64I"B`@("!["B`@("`@("`@)&ME>2`]('-E<FEA;&EZ
M92AA<G)A>2@D=&AI<RT^7V%P<"P@)'5S97)I9"P@)'!E<FTL("1A='1R:6)U
M=&5S+"`D<&%R96YT+"`D86QL3&5V96QS+"`G8V]U;G0G*2D["B`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3Y?;&ES=&-A8VAE6R1K97E=*2D@>PH@("`@("`@
M("`@("`D8W)I=&5R:6$@/2`D=&AI<RT^9V5T4VAA<F5#<FET97)I82@D=7-E
M<FED+"`D<&5R;2P@)&%T=')I8G5T97,I.PH@("`@("`@("`@("`D=&AI<RT^
M7VQI<W1C86-H95LD:V5Y72`]("1T:&ES+3Y?9&%T871R964M/F-O=6YT0GE!
M='1R:6)U=&5S*"1C<FET97)I82P@)'!A<F5N="P@)&%L;$QE=F5L<RP@)VED
M)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]L:7-T8V%C
M:&5;)&ME>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R
M<F%Y(&]F(&%L;"!S:&%R97,@=&AA="`D=7-E<FED(&AA<R!A8V-E<W,@=&\N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5S97)I9"`@("`@("!4
M:&4@=7-E<FED(&]F('1H92!U<V5R('1O(&-H96-K(&%C8V5S<R!F;W(N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;2`@("`@("`@(%1H92!L979E;"!O
M9B!P97)M:7-S:6]N<R!R97%U:7)E9"X*("`@("`J($!P87)A;2!M:7AE9"`@
M("1A='1R:6)U=&5S("`@4F5S=')I8W0@=&AE('-H87)E<R!C;W5N=&5D('1O
M('1H;W-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&UA
M=&-H:6YG("1A='1R:6)U=&5S+B!!;B!A<G)A>2!O9@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A='1R:6)U=&4O=F%L=65S('!A:7)S
M(&]R(&$@<VAA<F4@;W=N97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=7-E<FYA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%R
M96YT("`@("`@(%1H92!P87)E;G0@<VAA<F4@=&\@<W1A<G0@<V5A<F-H:6YG
M(&%T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@("!2971U
M<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_
M($1E9F%U;'1S('1O(&%L;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!L979E;',N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;2`@
M("`@("`@(%1H92!S:&%R92!T;R!S=&%R="!L:7-T:6YG(&%T+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-O=6YT("`@("`@("!4:&4@;G5M8F5R(&]F('-H
M87)E<R!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y
M7VYA;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@
M("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME
M>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M9&ER96-T:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!S:&%R97,@=&AE('5S
M97(@:&%S(&%C8V5S<R!T;RX*("`@("`J+PH@("`@9G5N8W1I;VX@)FQI<W13
M:&%R97,H)'5S97)I9"P@)'!E<FT@/2!015)-4U]32$]7+"`D871T<FEB=71E
M<R`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R96YT(#T@
M1$%40512145?4D]/5"P@)&%L;$QE=F5L<R`]('1R=64L("1F<F]M(#T@,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N="`](#`L("1S;W)T8GE?
M;F%M92`](&YU;&PL("1S;W)T8GE?:V5Y(#T@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("1K
M97D@/2!S97)I86QI>F4H87)R87DH)'1H:7,M/E]A<'`L("1U<V5R:60L("1P
M97)M+"`D871T<FEB=71E<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)E;G0L("1A;&Q,979E;',L("1F<F]M+"`D8V]U;G0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64L("1S;W)T
M8GE?:V5Y+"`D9&ER96-T:6]N*2D["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES
M+3Y?;&ES=&-A8VAE6R1K97E=*2D@>PH@("`@("`@("`@("`D8W)I=&5R:6$@
M/2`D=&AI<RT^9V5T4VAA<F5#<FET97)I82@D=7-E<FED+"`D<&5R;2P@)&%T
M=')I8G5T97,I.PH@("`@("`@("`@("`D<VAA<F5L:7-T(#T@)'1H:7,M/E]D
M871A=')E92T^9V5T0GE!='1R:6)U=&5S*`H@("`@("`@("`@("`@("`@)&-R
M:71E<FEA+"`D<&%R96YT+"`D86QL3&5V96QS+"`G:60G+"`D9G)O;2P@)&-O
M=6YT+`H@("`@("`@("`@("`@("`@)'-O<G1B>5]N86UE+"`D<V]R=&)Y7VME
M>2P@)&1I<F5C=&EO;BD["B`@("`@("`@("`@(&EF("AI<U]A*"1S:&%R96QI
M<W0L("=014%27T5R<F]R)RD@?'P@(6-O=6YT*"1S:&%R96QI<W0I*2!["B`@
M("`@("`@("`@("`@("`O*B!)9B!W92!G;W0@8F%C:R!A;B!E<G)O<B!O<B!A
M;B!E;7!T>2!A<G)A>2P@<&%S<R!I="!B86-K('1O"B`@("`@("`@("`@("`@
M("`@*B!T:&4@8V%L;&5R+B`J+PH@("`@("`@("`@("`@("`@<F5T=7)N("1S
M:&%R96QI<W0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($UA:V4@
M<W5R92!G9713:&%R97,H*2!D:61N)W0@<F5T=7)N(&%N(&5R<F]R+B`J+PH@
M("`@("`@("`@("`D<VAA<F5S(#T@)B1T:&ES+3YG9713:&%R97,H87)R87E?
M:V5Y<R@D<VAA<F5L:7-T*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1S:&%R
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<VAA<F5S.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VQI
M<W1C86-H95LD:V5Y72`]("8D<VAA<F5S.PH@("`@("`@("`@("`D=&AI<RT^
M7W-O<G1,:7-T(#T@)'1H:7,M/E]L:7-T8V%C:&5;)&ME>5T["B`@("`@("`@
M("`@('5A<V]R="@D=&AI<RT^7VQI<W1C86-H95LD:V5Y72P@87)R87DH)'1H
M:7,L("=?<V]R=%-H87)E<R<I*3L*("`@("`@("`@("`@)'1H:7,M/E]S;W)T
M3&ES="`](&YU;&P["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@2&]R
M9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:&%R95]L:7-T)RP@87)R87DH
M)'5S97)I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M97)M+"`D871T<FEB=71E<RP@)'1H:7,M/E]L:7-T8V%C:&5;)&ME>5TI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E)RP@9F%L
M<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]L:7-T8V%C:&5;)&ME>5T["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!,:7-T<R`J86QL*B!S:&%R97,@9F]R('1H92!C=7)R
M96YT(&%P<"]S:&%R92P@<F5G87)D;&5S<R!O9@H@("`@("H@<&5R;6ES<VEO
M;G,N(%1H:7,@:7,@9F]R(&%D;6EN(&9U;F-T:6]N86QI='D@86YD('-C<FEP
M=&EN9R!T;V]L<RP@86YD"B`@("`@*B!S:&]U;&1N)W0@8F4@8V%L;&5D(&9R
M;VT@=7-E<BUL979E;"!C;V1E(0H@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1P87)E;G0@(%-T87)T('1H92!L:7-T:6YG(&%T(&$@8V5R=&%I;B!P
M;VEN="!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('1R
M964N($1E9F%U;'1S('1O($1!5$%44D5%7U)/3U0L('1H92!R;V]T+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($%L;"!S:&%R97,@9F]R('1H92!C
M=7)R96YT(&%P<"]S:&%R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$%L
M;%-H87)E<R@D<&%R96YT(#T@1$%40512145?4D]/5"D*("`@('L*("`@("`@
M("`D<VAA<F5L:7-T(#T@)'1H:7,M/E]D871A=')E92T^9V5T*$1!5$%44D5%
M7T9/4DU!5%]&3$%4+"`D<&%R96YT+"!T<G5E*3L*("`@("`@("!I9B`H:7-?
M82@D<VAA<F5L:7-T+"`G4$5!4E]%<G)O<B<I('Q\("%C;W5N="@D<VAA<F5L
M:7-T*2D@>PH@("`@("`@("`@("`O+R!)9B!W92!G;W0@8F%C:R!A;B!E<G)O
M<B!O<B!A;B!E;7!T>2!A<G)A>2P@:G5S="!R971U<FX@:70N"B`@("`@("`@
M("`@(')E='5R;B`D<VAA<F5L:7-T.PH@("`@("`@('T*("`@("`@("!U;G-E
M="@D<VAA<F5L:7-T6R1P87)E;G1=*3L*"B`@("`@("`@)'-H87)E<R`]("8D
M=&AI<RT^9V5T4VAA<F5S*&%R<F%Y7VME>7,H)'-H87)E;&ES="DI.PH@("`@
M("`@(&EF("AI<U]A*"1S:&%R97,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1S:&%R97,["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7W-O<G1,:7-T(#T@)'-H87)E<SL*("`@("`@("!U87-O<G0H)'-H87)E
M<RP@87)R87DH)'1H:7,L("=?<V]R=%-H87)E<R<I*3L*("`@("`@("`D=&AI
M<RT^7W-O<G1,:7-T(#T@;G5L;#L*"B`@("`@("`@<F5T=7)N("1S:&%R97,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&-R
M:71E<FEA(&9O<B!Q=65R>6EN9R!S:&%R97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'5S97)I9"`@("`@(%1H92!U<V5R:60@;V8@=&AE('5S
M97(@=&\@8VAE8VL@86-C97-S(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1P97)M("`@("`@("!4:&4@;&5V96P@;V8@<&5R;6ES<VEO;G,@<F5Q=6ER
M960N"B`@("`@*B!`<&%R86T@;6EX960@("`D871T<FEB=71E<R`@4F5S=')I
M8W0@=&AE('-H87)E<R!R971U<FYE9"!T;R!T:&]S92!W:&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!H879E('1H97-E(&%T=')I8G5T
M92!V86QU97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&-R
M:71E<FEA('1R964@9F]R(&9E=&-H:6YG('1H:7,@=7-E<B=S('-H87)E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VAA<F5#<FET97)I82@D=7-E<FED
M+"`D<&5R;2`](%!%4DU37U-(3U<L("1A='1R:6)U=&5S(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1U<V5R:60I*2!["B`@("`@("`@("`@
M("1C<FET97)I82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)T]2)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`O+R`H;W=N97(@/3T@)'5S97)I
M9"D*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L
M("=T97-T)R`]/B`G;W=N97(G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=F:65L9"<@/3X@)W9A;'5E)RP@)V]P)R`]/B`G/2<L("=T
M97-T)R`]/B`D=7-E<FED*2DI+`H*("`@("`@("`@("`@("`@("`@("`O+R`H
M;F%M92`]/2!P97)M7W5S97)S(&%N9"!K97D@/3T@)'5S97)I9"!A;F0@=F%L
M("8@)'!E<FTI"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L("=O<"<@
M/3X@)STG+"`G=&5S="<@/3X@)W!E<FU?=7-E<G,G*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VME>2<L("=O<"<@
M/3X@)STG+"`G=&5S="<@/3X@)'5S97)I9"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@
M)R8G+"`G=&5S="<@/3X@)'!E<FTI*2DL"@H@("`@("`@("`@("`@("`@("`@
M("\O("AN86UE(#T]('!E<FU?8W)E871O<B!A;F0@=F%L("8@)'!E<FTI"B`@
M("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L("=O<"<@/3X@)STG+"`G=&5S
M="<@/3X@)W!E<FU?8W)E871O<B<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)V9I96QD)R`]/B`G=F%L=64G+"`G;W`G(#T^("<F)RP@
M)W1E<W0G(#T^("1P97)M*2DI+`H*("`@("`@("`@("`@("`@("`@("`O+R`H
M;F%M92`]/2!P97)M7V1E9F%U;'0@86YD('9A;"`F("1P97)M*0H@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G
M04Y$)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^
M("=P97)M7V1E9F%U;'0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=F:65L9"<@/3X@)W9A;'5E)RP@)V]P)R`]/B`G)B<L("=T97-T
M)R`]/B`D<&5R;2DI*2DI.PH*("`@("`@("`@("`@+R\@268@=&AE('5S97(@
M:&%S(&%N>2!G<F]U<"!M96UB97)S:&EP<RP@8VAE8VL@9F]R('1H;W-E(&%L
M<V\N"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP
M)SL*("`@("`@("`@("`@)&=R;W5P(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*
M("`@("`@("`@("`@)&=R;W5P<R`]("1G<F]U<"T^9V5T1W)O=7!-96UB97)S
M:&EP<R@D=7-E<FED+"!T<G5E*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1G
M<F]U<',L("=014%27T5R<F]R)RD@)B8@8V]U;G0H)&=R;W5P<RDI('L*("`@
M("`@("`@("`@("`@("\O("AN86UE(#T]('!E<FU?9W)O=7!S(&%N9"!K97D@
M:6X@*"1G<F]U<',I(&%N9"!V86P@)B`D<&5R;2D*("`@("`@("`@("`@("`@
M("1C<FET97)I85LG3U(G75M=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^
M("=P97)M7V=R;W5P<R<I+`H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G9FEE;&0G(#T^("=K97DG+"`G;W`G(#T^("=)3B<L("=T97-T)R`]/B`G
M*"<@+B!I;7!L;V1E*"<L("<L(&%R<F%Y7VME>7,H)&=R;W5P<RDI("X@)RDG
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G
M=F%L=64G+"`G;W`G(#T^("<F)RP@)W1E<W0G(#T^("1P97)M*2DI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-R:71E
M<FEA(#T@87)R87DH"B`@("`@("`@("`@("`@("`G04Y$)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L
M("=O<"<@/3X@)STG+"`G=&5S="<@/3X@)W!E<FU?9W5E<W0G*2P*("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G=F%L=64G+"`G;W`G
M(#T^("<F)RP@)W1E<W0G(#T^("1P97)M*2DI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1A='1R:6)U=&5S*2D@>PH@("`@("`@("`@("`O
M+R!"=6EL9"!A='1R:6)U=&4O:V5Y(&9I;'1E<BX*("`@("`@("`@("`@9F]R
M96%C:"`H)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@("1C<FET97)I82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`D
M8W)I=&5R:6$L"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)TI/24XG(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE
M;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`D:V5Y*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I
M96QD)R`]/B`G=F%L=64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("1V86QU
M92DI*2DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@A96UP
M='DH)&%T=')I8G5T97,I*2!["B`@("`@("`@("`@("\O(%)E<W1R:6-T('1O
M('-H87)E<R!O=VYE9"!B>2!T:&4@=7-E<B!S<&5C:69I960@:6X@=&AE"B`@
M("`@("`@("`@("\O("1A='1R:6)U=&5S('-T<FEN9RX*("`@("`@("`@("`@
M)&-R:71E<FEA(#T@87)R87DH"B`@("`@("`@("`@("`@("`G04Y$)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`D8W)I=&5R:6$L"B`@("`@("`@
M("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=*
M3TE.)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^
M("=O=VYE<B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V9I96QD)R`]/B`G=F%L=64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("1A
M='1R:6)U=&5S*2DI*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-R
M:71E<FEA.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@
M("`J($!S964@4&5R;7,Z.F=E=%!E<FUI<W-I;VYS"B`@("`@*@H@("`@("H@
M0'!A<F%M(%1/1$\*("`@("`J($!P87)A;2!43T1/"B`@("`@*@H@("`@("H@
M0')E='5R;B!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!E<FUI<W-I
M;VYS*"1S:&%R92P@)'5S97(@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?82@D<VAA<F4L("=$871A5')E94]B:F5C=%]3:&%R92<I*2!["B`@("`@
M("`@("`@("1S:&%R92`]("8D=&AI<RT^9V5T4VAA<F4H)'-H87)E*3L*("`@
M("`@("!]"@H@("`@("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO
M;B@I.PH@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<&5R;7,G72T^9V5T4&5R
M;6ES<VEO;G,H)'!E<FTL("1U<V5R*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE($ED96YT:71Y(&9O<B!A('!A<G1I8W5L87(@<VAA<F4@
M;W=N97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1S:&%R92`@5&AE
M('-H87)E('1O(&9E=&-H('1H92!)9&5N=&ET>2!F;W(@+2!E:71H97(@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@;F%M92P@;W(@
M=&AE($1A=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R969E<F5N8V4G<R!V86QU92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F=E=$ED96YT:71Y0GE3:&%R92@D<VAA<F4I
M"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1S:&%R92P@)T1A=&%4<F5E3V)J
M96-T7U-H87)E)RDI('L*("`@("`@("`@("`@)'-H87)E(#T@)'1H:7,M/F=E
M=%-H87)E*"1S:&%R92D["B`@("`@("`@("`@(&EF("AI<U]A*"1S:&%R92P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("`D;W=N97(@/2`D<VAA
M<F4M/F=E="@G;W=N97(G*3L*("`@("`@("!R971U<FX@)')E="`]("9)9&5N
M=&ET>3HZ<VEN9VQE=&]N*"=N;VYE)RP@)&]W;F5R*3L*("`@('T*"GT*"B\J
M*@H@*B!%>'1E;G-I;VX@;V8@=&AE($1A=&%4<F5E3V)J96-T(&-L87-S(&9O
M<B!S=&]R:6YG(%-H87)E(&EN9F]R;6%T:6]N(&EN('1H90H@*B!$871A5')E
M92!D<FEV97(N($EF('EO=2!W86YT('1O('-T;W)E('-P96-I86QI>F5D(%-H
M87)E(&EN9F]R;6%T:6]N+"!Y;W4*("H@<VAO=6QD(&5X=&5N9"!T:&ES(&-L
M87-S(&EN<W1E860@;V8@97AT96YD:6YG($1A=&%4<F5E3V)J96-T(&1I<F5C
M=&QY+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?4VAA<F4*("HO"F-L87-S($1A=&%4<F5E3V)J96-T7U-H87)E
M(&5X=&5N9',@1&%T851R965/8FIE8W0@>PH*("`@("\J*@H@("`@("H@5&AE
M($AO<F1E7U-H87)E(&]B:F5C="!W:&EC:"!T:&ES('-H87)E(&-A;64@9G)O
M;2`M(&YE961E9"!F;W(*("`@("`J('5P9&%T:6YG(&1A=&$@:6X@=&AE(&)A
M8VME;F0@=&\@;6%K92!C:&%N9V5S('-T:6-K+"!E=&,N"B`@("`@*@H@("`@
M("H@0'9A<B!(;W)D95]3:&%R90H@("`@("HO"B`@("!V87(@)%]S:&%R94]B
M.PH*("`@("\J*@H@("`@("H@5&AE($1A=&%4<F5E3V)J96-T7U-H87)E(&-O
M;G-T<G5C=&]R+B!*=7-T(&UA:V5S('-U<F4@=&\@8V%L;"!T:&4@<&%R96YT
M"B`@("`@*B!C;VYS=')U8W1O<B!S;R!T:&%T('1H92!S:&%R92=S(&YA;64@
M:7,@<V5T('!R;W!E<FQY+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("!4:&4@:60@;V8@=&AE('-H87)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!$871A5')E94]B:F5C=%]3:&%R92@D:60I"B`@("!["B`@("`@("`@<&%R
M96YT.CI$871A5')E94]B:F5C="@D:60I.PH@("`@("`@(&EF("AI<U]N=6QL
M*"1T:&ES+3YD871A*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T82`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S;V-I
M871E<R!A(%-H87)E(&]B:F5C="!W:71H('1H:7,@<VAA<F4N"B`@("`@*@H@
M("`@("H@0'!A<F%M($AO<F1E7U-H87)E("1S:&%R94]B("!4:&4@4VAA<F4@
M;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9713:&%R94]B*"8D<VAA
M<F5/8BD*("`@('L*("`@("`@("`D=&AI<RT^7W-H87)E3V(@/2`F)'-H87)E
M3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H:7,@<VAA<F4G
M<R!P87)E;G0@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R
M965/8FIE8W1?4VAA<F4@(%1H92!P87)E;G0@<VAA<F4L(&EF(&ET(&5X:7-T
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!A<F5N="@I"B`@("!["B`@
M("`@("`@)'!A<F5N="`]("1T:&ES+3Y?<VAA<F5/8BT^9V5T4&%R96YT*"1T
M:&ES*3L*("`@("`@("!R971U<FX@)'!A<F5N=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($=I=F5S(&$@=7-E<B!A(&-E<G1A:6X@<')I=FEL96=E(&9O<B!T
M:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)I
M9"`@("`@("!4:&4@=7-E<FED(&]F('1H92!U<V5R+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'!E<FUI<W-I;VX@($$@4$5235-?*B!C;VYS=&%N="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D57-E<E!E<FUI<W-I;VXH)'5S97)I9"P@
M)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E
M=%!E<FUI<W-I;VXH*3L*("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I
M;VXH)'5S97)I9"P@)'!E<FUI<W-I;VXL(&9A;'-E*3L*("`@("`@("`D=&AI
M<RT^<V5T4&5R;6ES<VEO;B@D<&5R;2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296UO=F5S(&$@8V5R=&%I;B!P<FEV:6QE9V4@9F]R(&$@=7-E<B!F<F]M
M('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E
M<FED("`@("`@(%1H92!U<V5R:60@;V8@=&AE('5S97(N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@02!015)-4U\J(&-O;G-T86YT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R4&5R;6ES<VEO;B@D=7-E
M<FED+"`D<&5R;6ES<VEO;BD*("`@('L*("`@("`@("`D<&5R;2`]("8D=&AI
M<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@("1P97)M+3YR96UO=F55<V5R
M4&5R;6ES<VEO;B@D=7-E<FED+"`D<&5R;6ES<VEO;BP@9F%L<V4I.PH@("`@
M("`@("1T:&ES+3YS971097)M:7-S:6]N*"1P97)M*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=I=F5S(&$@9W)O=7`@8V5R=&%I;B!P<FEV:6QE9V5S(&9O
M<B!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R
M;W5P("`@("`@("!4:&4@9W)O=7`@=&\@861D('!E<FUI<W-I;VYS(&9O<BX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N("!!(%!%4DU37RH@
M8V]N<W1A;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$=R;W5P4&5R;6ES
M<VEO;B@D9W)O=7`L("1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@("1P97)M
M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@("`@)'!E<FTM/F%D
M9$=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L("1P97)M:7-S:6]N+"!F86QS92D[
M"B`@("`@("`@)'1H:7,M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5M;W9E<R!A(&-E<G1A:6X@<')I=FEL96=E(&9R
M;VT@82!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U
M<"`@("`@("`@(%1H92!G<F]U<"!T;R!R96UO=F4@<&5R;6ES<VEO;G,@9G)O
M;2X*("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@02!015)-
M4U\J(&-O;G-T86YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5'<F]U
M<%!E<FUI<W-I;VXH)&=R;W5P+"`D<&5R;6ES<VEO;BD*("`@('L*("`@("`@
M("`D<&5R;2`]("8D=&AI<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@("1P
M97)M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P+"`D<&5R;6ES<VEO
M;BP@9F%L<V4I.PH@("`@("`@("1T:&ES+3YS971097)M:7-S:6]N*"1P97)M
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@:68@82!U
M<V5R(&AA<R!A(&=I=F5N('!E<FUI<W-I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<FED("`@("`@(%1H92!U<V5R:60@;V8@=&AE('5S
M97(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@02!015)-
M4U\J(&-O;G-T86YT('1O('1E<W0@9F]R+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8W)E871O<B`@("`@(%1H92!C<F5A=&]R(&]F('1H92!E=F5N="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T("1U
M<V5R:60@:&%S("1P97)M:7-S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!H
M87-097)M:7-S:6]N*"1U<V5R:60L("1P97)M:7-S:6]N+"`D8W)E871O<B`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"1U<V5R:60@/3T@)'1H:7,M/F=E
M="@G;W=N97(G*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<&5R;7,G72T^:&%S4&5R
M;6ES<VEO;B@D=&AI<RT^9V5T4&5R;6ES<VEO;B@I+"`D=7-E<FED+"`D<&5R
M;6ES<VEO;BP@)&-R96%T;W(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M
M;W9E<R!A('5S97(@9G)O;2!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97)I9"`@5&AE('5S97)I9"!O9B!T:&4@=7-E<B!T
M;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S
M97)I9"D*("`@('L*("`@("`@("`O*B!296UO=F4@86QL("1U<V5R:60G<R!P
M97)M:7-S:6]N<RX@*B\*("`@("`@("`D<&5R;2`]("8D=&AI<RT^9V5T4&5R
M;6ES<VEO;B@I.PH@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO
M;B@D=7-E<FED+"!015)-4U]32$]7+"!F86QS92D["B`@("`@("`@)'!E<FTM
M/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R:60L(%!%4DU37U)%040L(&9A
M;'-E*3L*("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S
M97)I9"P@4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@("1P97)M+3YR96UO
M=F55<V5R4&5R;6ES<VEO;B@D=7-E<FED+"!015)-4U]$14Q%5$4L(&9A;'-E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@8V]N
M=&%I;FEN9R!A;&P@=&AE('5S97)I9',@;V8@=&AE('5S97)S('=I=&@@86-C
M97-S('1O"B`@("`@*B!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1P97)M7VQE=F5L("!,:7-T(&]N;'D@=7-E<G,@=VET:"!T
M:&ES('!E<FUI<W-I;VX@;&5V96PN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@1&5F875L=',@=&\@86QL('5S97)S+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!U<V5R<R!W:71H(&%C8V5S<R!T;R!T
M:&ES('-H87)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H)'!E
M<FU?;&5V96P@/2!N=6QL*0H@("`@>PH@("`@("`@("1P97)M(#T@)B1T:&ES
M+3YG971097)M:7-S:6]N*"D["B`@("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H
M)'!E<FTM/F=E=%5S97)097)M:7-S:6]N<R@D<&5R;5]L979E;"DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!C;VYT86EN:6YG
M(&%L;"!T:&4@9W)O=7!I9',@;V8@=&AE(&=R;W5P<R!W:71H(&%C8V5S<PH@
M("`@("H@=&\@=&AI<R!S:&%R92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<&5R;5]L979E;"`@3&ES="!O;FQY('5S97)S('=I=&@@=&AI<R!P
M97)M:7-S:6]N(&QE=F5L+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($1E9F%U;'1S('1O(&%L;"!U<V5R<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@241S(&]F('1H92!G<F]U<',@=VET:"!A8V-E
M<W,@=&\@=&AI<R!S:&%R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$=R
M;W5P<R@D<&5R;5]L979E;"`](&YU;&PI"B`@("!["B`@("`@("`@)'!E<FT@
M/2`F)'1H:7,M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("!R971U<FX@87)R
M87E?:V5Y<R@D<&5R;2T^9V5T1W)O=7!097)M:7-S:6]N<R@D<&5R;5]L979E
M;"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J
M($!P87)A;2!43T1/"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("!4
M3T1/"B`@("`@*@H@("`@("H@0')E='5R;B!43T1/"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%!E<FUI<W-I;VXH)B1P97)M+"`D=7!D871E(#T@=')U92D*
M("`@('L*("`@("`@("`D=&AI<RT^9&%T85LG<&5R;2==(#T@)'!E<FTM/F=E
M=$1A=&$H*3L*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@
M("H@0')E='5R;B!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971097)M
M:7-S:6]N*"D*("`@('L*("`@("`@("`D<&5R;2`]("9N97<@1&%T851R965/
M8FIE8W1?4&5R;6ES<VEO;B@D=&AI<RT^9V5T3F%M92@I*3L*("`@("`@("`D
M<&5R;2T^9&%T82`](&ES<V5T*"1T:&ES+3YD871A6R=P97)M)UTI(#\@)'1H
M:7,M/F1A=&%;)W!E<FTG72`Z(&%R<F%Y*"D["@H@("`@("`@(')E='5R;B`D
M<&5R;3L*("`@('T*"B`@("`O*BH*("`@("`J($9O<F-E<R!A;&P@8VAI;&1R
M96X@;V8@=&AI<R!S:&%R92!T;R!I;FAE<FET('1H92!P97)M:7-S:6]N<R!S
M970@;VX@=&AI<PH@("`@("H@<VAA<F4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:&5R:71097)M:7-S:6]N
M<R@I"B`@("!["B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I
M;VXH*3L*("`@("`@("`D8VAI;&1R96X@/2`D=&AI<RT^7W-H87)E3V(M/FQI
M<W1!;&Q3:&%R97,H)'1H:7,M/F=E=$YA;64H*2D["B`@("`@("`@:68@*&ES
M7V$H)&-H:6QD<F5N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D8VAI;&1R96X["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D
M8VAI;&1R96X@87,@)&-H:6QD*2!["B`@("`@("`@("`@("1C:&EL9"T^<V5T
M4&5R;6ES<VEO;B@D<&5R;2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-A=F5S(&%N>2!C:&%N9V5S
M('1O('1H:7,@;V)J96-T('1O('1H92!B86-K96YD('!E<FUA;F5N=&QY+B!.
M97<@;V)J96-T<PH@("`@("H@87)E(&%D9&5D(&EN<W1E860N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N('P@4$5!4E]%<G)O<B`@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S879E*"D*("`@
M('L*("`@("`@("`D<F5S=6QT(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?
M:&]O:U]S:&%R95]M;V1I9GDG+"!A<G)A>2@D=&AI<RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4G+"!F86QS92D["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!P87)E;G0Z.G-A=F4H*3L*("`@('T*"B`@("`O*BH*("`@("`J($UA<',@
M=&AI<R!O8FIE8W0G<R!A='1R:6)U=&5S(&9R;VT@=&AE(&1A=&$@87)R87D@
M:6YT;R!A(&9O<FUA="!T:&%T('=E"B`@("`@*B!C86X@<W1O<F4@:6X@=&AE
M(&%T=')I8G5T97,@<W1O<F%G92!B86-K96YD+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)'!E<FUS;VYL>2`@3VYL>2!P<F]C97-S('!E<FUI<W-I;VYS/R!,971S('-U
M8F-L87-S97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]V
M97)R:61E('!A<G0@;V8@=&AI<R!M971H;V0@=VAI;&4@:&%N9&QI;F<*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H96ER(&%D9&ET:6]N
M86P@871T<FEB=71E<R!S97!E<F%T96QY+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%1H92!A='1R:6)U=&5S(&%R<F%Y+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=&]!='1R:6)U=&5S*"1P97)M<V]N;'D@/2!F86QS92D*("`@
M('L*("`@("`@("`O+R!$969A=6QT('1O(&YO(&%T=')I8G5T97,N"B`@("`@
M("`@)&%T=')I8G5T97,@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^9&%T82!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("!I
M9B`H)&ME>2`]/2`G<&5R;2<I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1V86QU92!A<R`D='EP92`]/B`D<&5R;7,I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'!E<FUS*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D<&5R;7,@87,@)&UE;6)E<B`]/B`D<&5R;2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;72`]
M(&%R<F%Y*"=N86UE)R`]/B`G<&5R;5\G("X@)'1Y<&4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VME>2<@
M/3X@)&UE;6)E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1P97)M*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6UT@/2!A<G)A
M>2@G;F%M92<@/3X@)W!E<FU?)R`N("1T>7!E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VME>2<@/3X@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%L=64G(#T^("1P97)M<RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H(21P97)M<V]N
M;'DI('L*("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6UT@/2!A<G)A>2@G
M;F%M92<@/3X@)&ME>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:V5Y)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=F%L=64G(#T^("1V86QU92D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D871T<FEB=71E<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&EN(&$@;&ES="!O9B!A='1R:6)U
M=&5S(&9R;VT@=&AE(&)A8VME;F0@86YD(&UA<',@:70@=&\@;W5R"B`@("`@
M*B!I;G1E<FYA;"!D871A(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R:6)U
M=&5S("`@5&AE(&QI<W0@;V8@871T<FEB=71E<R!F<F]M('1H92!B86-K96YD
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H871T<FEB=71E
M(&YA;64L(&ME>2P@86YD('9A;'5E*2X*("`@("`J($!P87)A;2!B;V]L96%N
M("1P97)M<V]N;'D@($]N;'D@<')O8V5S<R!P97)M:7-S:6]N<S\@3&5T<R!S
M=6)C;&%S<V5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!O
M=F5R<FED92!P87)T(&]F('1H:7,@;65T:&]D('=H:6QE(&AA;F1L:6YG"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&5I<B!A9&1I=&EO
M;F%L(&%T=')I8G5T97,@<V5P97)A=&5L>2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V9R;VU!='1R:6)U=&5S*"1A='1R:6)U=&5S+"`D<&5R;7-O;FQY(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@+R\@26YI=&EA;&EZ92!D871A(&%R<F%Y
M+@H@("`@("`@("1T:&ES+3YD871A6R=P97)M)UT@/2!A<G)A>2@I.PH*("`@
M("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1A='1R6R=N86UE)UTL(#`L(#0I(#T]("=P97)M
M)RD@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D871T<ELG:V5Y)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)W!E<FTG75MS
M=6)S='(H)&%T=');)VYA;64G72P@-2E=6R1A='1R6R=K97DG75T@/2`D871T
M<ELG=F%L=64G73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F1A=&%;)W!E<FTG75MS=6)S='(H)&%T=');
M)VYA;64G72P@-2E=(#T@)&%T=');)W9A;'5E)UT["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS96EF("@A)'!E<FUS;VYL>2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F1A=&%;)&%T=');)VYA;64G75T@/2`D871T
M<ELG=F%L=64G73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5M
M<&QA=&4N<&AP````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#4R,S,S`#$P-#$W,S8R-S<S`#`R,#4R-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@2&]R9&4@5&5M
M<&QA=&4@<WES=&5M+B!!9&%P=&5D(&9R;VT@8E1E;7!L871E(&)Y($)R:6%N
M($QO>FEE<@H@*B`\8G)I86Y`;6%S<V%S<VDN;F5T/BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP+'8@,2XS."XQ,"XX
M(#(P,#8O,#$O,C(@,3DZ,3(Z,C8@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95]496UP;&%T90H@*B\*8VQA<W,@2&]R9&5?5&5M
M<&QA=&4@>PH*("`@("\J*@H@("`@("H@3W!T:6]N('9A;'5E<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@1&ER96-T;W)Y('1H870@=&5M
M<&QA=&5S('-H;W5L9"!B92!R96%D(&9R;VTN"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8F%S97!A=&@@/2`G)SL*"B`@
M("`O*BH*("`@("`J(%)E<V5T('1E;7!L871E('9A<FEA8FQE<R!A9G1E<B!P
M87)S:6YG/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]R97-E=%9A<G,@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&%G
M("AS8V%L87(I('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W-C86QA<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@3&]O<"!T86<@=F%L=65S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?87)R87ES(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($-L;V]P('1A9R!V86QU97,N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C87)R87ES(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J($EF('1A9R!V86QU97,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]I9G,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@3F%M92!O9B!C86-H960@=&5M<&QA=&4@9FEL92X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T
M96UP;&%T949I;&4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V%C:&5D('-O
M=7)C92!O9B!T96UP;&%T92!F:6QE+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7W1E;7!L871E(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+B!#86X@<V5T('1H92!T96UP;&%T92!B
M87-E('!A=&@@86YD('=H971H97(@;W(@;F]T"B`@("`@*B!T;R!D<F]P('1E
M;7!L871E('9A<FEA8FQE<R!A9G1E<B!A('!A<G-I;F<@82!T96UP;&%T92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8F%S97!A=&@@("!4:&4@
M9&ER96-T;W)Y('=H97)E('1E;7!L871E<R!A<F4@<F5A9"!F<F]M+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)')E<V5T5F%R<R`@1')O<"!T96UP;&%T92!V
M87)S(&%F=&5R('!A<G-I;F<@82!T96UP;&%T93\*("`@("`J+PH@("`@9G5N
M8W1I;VX@2&]R9&5?5&5M<&QA=&4H)&)A<V5P871H(#T@;G5L;"P@)')E<V5T
M5F%R<R`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1B87-E
M<&%T:"DI('L*("`@("`@("`@("`@)'1H:7,M/E]B87-E<&%T:"`]("1B87-E
M<&%T:#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]R97-E=%9A<G,@/2`H
M8F]O;"DD<F5S971687)S.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A
M;B!O<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W!T:6]N
M("!4:&4@;W!T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@;6EX960@("1V86P@
M("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T3W!T:6]N*"1O<'1I;VXL("1V86PI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS6R1O<'1I;VY=(#T@)'9A;#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!T:&4@=&5M<&QA=&4@8V]N=&5N=',@=&\@82!S=')I;F<N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5M<&QA=&4@(%1H92!T96UP
M;&%T92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971496UP;&%T92@D
M=&5M<&QA=&4I"B`@("!["B`@("`@("`@)'1H:7,M/E]T96UP;&%T92`]("1T
M96UP;&%T93L*("`@("`@("`D=&AI<RT^7W1E;7!L871E1FEL92`]("=S=')I
M;F<G.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!O<'1I;VXG
M<R!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VX@
M(%1H92!O<'1I;VX@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@;W!T:6]N)W,@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$]P=&EO;B@D;W!T:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)&]P=&EO;ETI(#\@)'1H:7,M/E]O<'1I;VYS6R1O
M<'1I;VY=(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@82!T
M86<L(&QO;W`L(&]R(&EF('9A<FEA8FQE+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F=\87)R87D@)'1A9R`@($5I=&AE<B!T:&4@=&%G(&YA;64@;W(@
M82!H87-H('=I=&@@=&%G(&YA;65S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<R!K97ES(&%N9"!T86<@=F%L=65S(&%S('9A;'5E<RX*
M("`@("`J($!P87)A;2!M:7AE9"`@("`@("`@)'9A<B`@(%1H92!V86QU92!T
M;R!R97!L86-E('1H92!T86<@=VET:"X*("`@("`J($!P87)A;2!B;V]L96%N
M("`@("`@)&ES268@($ES('1H:7,@9F]R(&%N(#QI9CH^('1A9S\@*$1E9F%U
M;'0Z(&YO*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T*"1T86<L("1V87(L
M("1I<TEF(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M86<I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T86<@87,@)'1486<@/3X@
M)'1687(I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS970H)'1486<L("1T
M5F%R+"`D:7-)9BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H
M:7-?87)R87DH)'9A<BDI('L*("`@("`@("`@("`@)'1H:7,M/E]A<G)A>7-;
M)'1A9UT@/2`D=F%R.PH@("`@("`@("`@("!I9B`H)&ES268I('L*("`@("`@
M("`@("`@("`@("\O($IU<W0@<W1O<F4@=&AE('-A;64@=F%R:6%B;&4@=&AA
M="!W92!S=&]R960@:6X*("`@("`@("`@("`@("`@("\O("1T:&ES+3Y?87)R
M87ES("T@:68@=V4@9&]N)W0@;6]D:69Y(&ET+"!02%`G<PH@("`@("`@("`@
M("`@("`@+R\@<F5F97)E;F-E(&-O=6YT:6YG(&5N<W5R97,@=V4G<F4@;F]T
M('5S:6YG(&%N>0H@("`@("`@("`@("`@("`@+R\@861D:71I;VYA;"!M96UO
M<GD@:&5R92X*("`@("`@("`@("`@("`@("1T:&ES+3Y?:69S6R1T86==(#T@
M)'9A<CL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?<V-A;&%R<ULD=&%G72`]("1V87(["B`@("`@("`@("`@
M(&EF("@D:7-)9BD@>PH@("`@("`@("`@("`@("`@+R\@2G5S="!S=&]R92!T
M:&4@<V%M92!V87)I86)L92!T:&%T('=E('-T;W)E9"!I;@H@("`@("`@("`@
M("`@("`@+R\@)'1H:7,M/E]S8V%L87)S("T@:68@=V4@9&]N)W0@;6]D:69Y
M(&ET+"!02%`G<PH@("`@("`@("`@("`@("`@+R\@<F5F97)E;F-E(&-O=6YT
M:6YG(&5N<W5R97,@=V4G<F4@;F]T('5S:6YG(&%N>0H@("`@("`@("`@("`@
M("`@+R\@861D:71I;VYA;"!M96UO<GD@:&5R92X*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:69S6R1T86==(#T@)'9A<CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('9A;'5E
M(&]F(&$@=&%G(&]R(&QO;W`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&%G("!4:&4@=&%G(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5&AE('1A9R!V86QU92!O<B!N=6QL(&EF('1H92!T86<@:&%S;B=T
M(&)E96X@<V5T('EE="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T*"1T86<I
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?87)R87ES6R1T86==
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]A<G)A>7-;)'1A9UT[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-C86QA<G-;
M)'1A9UTI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W-C86QA<G-;
M)'1A9UT["B`@("`@("`@?0H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!V86QU97,@9F]R(&$@8VQO;W`N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%G("`@5&AE(&YA;64@;V8@=&AE
M(&-L;V]P+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A>2`@5&AE('9A;'5E
M<R!F;W(@=&AE(&-L;V]P+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C87-E<R`@
M5&AE(&-A<V5S("AT97-T('9A;'5E<RD@9F]R('1H92!C;&]O<',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$-L;V]P*"1T86<L("1A<G)A>2P@)&-A<V5S
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V%R<F%Y<ULD=&%G72`](&%R<F%Y
M*`H@("`@("`@("`@("`G87)R87DG(#T^("1A<G)A>2P*("`@("`@("`@("`@
M)V-A<V5S)R`]/B`D8V%S97,*("`@("`@("`I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5S971S('1H92!T96UP;&%T92!V87)I86)L97,N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'-C86QA<G,@(%)E<V5T('-C86QA<B`H
M8F%S:6,@=&%G*2!V87)I86)L97,_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M87)R87ES("`@4F5S970@;&]O<"!V87)I86)L97,_"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D8V%R<F%Y<R`@4F5S970@8VQO;W`@=F%R:6%B;&5S/PH@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&EF<R`@("`@(%)E<V5T(&EF('9A<FEA8FQE
M<S\*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S971687)S*"1S8V%L87)S+"`D
M87)R87ES+"`D8V%R<F%Y<RP@)&EF<RD*("`@('L*("`@("`@("!I9B`H)'-C
M86QA<G,@/3T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/E]S8V%L87)S
M(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@:68@*"1A<G)A>7,@/3T]
M('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/E]A<G)A>7,@/2!A<G)A>2@I
M.PH@("`@("`@('T*("`@("`@("!I9B`H)&-A<G)A>7,@/3T]('1R=64I('L*
M("`@("`@("`@("`@)'1H:7,M/E]C87)R87ES(#T@87)R87DH*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"1I9G,@/3T]('1R=64I('L*("`@("`@("`@("`@
M)'1H:7,M/E]I9G,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E=')I979E(&QI<W0@;V8@8FQO8VMS('!R97-E;G0@:6X@
M=&AE('1E;7!L871E('-O=7)C92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F:6QE;F%M92`@5&AE(&9I;&4@=&\@9F5T8V@@=&AE('1E;7!L871E
M(&9R;VTN"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!;B!A<G)A>2!O9B!A<'!L
M:6-A=&EO;G,L(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&ES=$)L;V-K<R@I"B`@("!["B`@("`@("`@)&)L;V-K
M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<\8FQO
M8VLZ*%MA+7I!+5HP+3E?72LZ6V$M>D$M6C`M.5]=*RD^)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T96UP;&%T92P@)&UA=&-H97,L
M(%!214=?4T547T]21$52*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;6%T
M8VAE<R!A<R`D;6%T8V@I('L*("`@("`@("`@("`@("`@("1B;&]C:W-;72`]
M("1M871C:%LQ73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1B;&]C:W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C:&5S
M(&$@=&5M<&QA=&4@9G)O;2!T:&4@<W!E8VEF:65D(&9I;&4@86YD(')E='5R
M;B!T:&4@<&%R<V5D"B`@("`@*B!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9I;&4@=&\@9F5T8V@@=&AE
M('1E;7!L871E(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!P87)S960@=&5M<&QA=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E
M=&-H*"1F:6QE;F%M92D*("`@('L*("`@("`@("`D8V]N=&5N=',@/2`D=&AI
M<RT^7V=E=%1E;7!L871E*"1F:6QE;F%M92D["B`@("`@("`@:68@*&ES7V$H
M)&-O;G1E;G1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D8V]N=&5N=',["B`@("`@("`@?0H*("`@("`@("`O+R!087)S92!A;F0@
M<F5T=7)N('1H92!C;VYT96YT<RX*("`@("`@("!R971U<FX@)'1H:7,M/G!A
M<G-E*"1C;VYT96YT<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@
M86QL('9A<FEA8FQE<R]T86=S(&EN('1H92!T96UP;&%T92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE('5N<&%R<V5D('1E
M;7!L871E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R
M<V5D('1E;7!L871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S92@D8V]N
M=&5N=',@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A)&-O;G1E;G1S*2![
M"B`@("`@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3Y?=&5M<&QA=&4["B`@
M("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S(&EF<RX*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?:69S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7VEF<R!A<R`D=&%G(#T^("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94EF*"1T86<L("1C;VYT96YT
M<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%!R;V-E
M<W,@=&%G<RX*("`@("`@("`D<V5A<F-H(#T@87)R87DH*3L*("`@("`@("`D
M<F5P;&%C92`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]S
M8V%L87)S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1S96%R
M8VA;72`]("1T:&ES+3Y?9V5T5&%G*"1K97DI.PH@("`@("`@("`@("`D<F5P
M;&%C95M=(#T@)'9A;'5E.PH@("`@("`@('T*("`@("`@("!I9B`H8V]U;G0H
M)'-E87)C:"DI('L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA
M8V4H)'-E87)C:"P@)')E<&QA8V4L("1C;VYT96YT<RD["B`@("`@("`@?0H*
M("`@("`@("`O+R!0<F]C97-S(&QO;W!S(&%N9"!A<G)A>7,N"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]A<G)A>7,@87,@)&ME>2`]/B`D87)R87DI('L*
M("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94QO;W`H)&ME
M>2P@)&%R<F%Y+"`D8V]N=&5N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4')O8V5S<R!C;&]O<',N"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C87)R
M87ES(&%S("1K97D@/3X@)&%R<F%Y*2!["B`@("`@("`@("`@("1C;VYT96YT
M<R`]("1T:&ES+3Y?<&%R<V5#;&]O<"@D:V5Y+"`D87)R87DL("1C;VYT96YT
M<RD["B`@("`@("`@?0H*("`@("`@("`O+R!087)S92!G971T97AT('1A9W,L
M(&EF('1H92!O<'1I;VX@:7,@96YA8FQE9"X*("`@("`@("!I9B`H)'1H:7,M
M/F=E=$]P=&EO;B@G9V5T=&5X="<I*2!["B`@("`@("`@("`@("1C;VYT96YT
M<R`]("1T:&ES+3Y?<&%R<V5'971T97AT*"1C;VYT96YT<RD["B`@("`@("`@
M?0H*("`@("`@("`O+R!087)S92!E;6)E9&1E9"!B;&]C:W,*("`@("`@("!I
M9B`H)'1H:7,M/F=E=$]P=&EO;B@G8FQO8VMS)RDI('L*("`@("`@("`@("`@
M)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94)L;V-K<R@D8V]N=&5N=',I.PH@
M("`@("`@('T*"B`@("`@("`@+R\@4F5S970@=&5M<&QA=&4@9&%T82!U;FQE
M<W,@=V4G<F4@<W5P<&]S960@=&\@:V5E<"!I=`H@("`@("`@("\O(&%R;W5N
M9"X*("`@("`@("!I9B`H)'1H:7,M/E]R97-E=%9A<G,I('L*("`@("`@("`@
M("`@)'1H:7,M/G)E<V5T5F%R<RAF86QS92P@=')U92P@=')U92P@9F%L<V4I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@4F5T=7)N('!A<G-E9"!T96UP;&%T
M92X*("`@("`@("!R971U<FX@)&-O;G1E;G1S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!F=6QL('-T87)T(&%N9"!E;F0@=&%G<R!F;W(@82!N
M86UE9"!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%G"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D:7)E8W1I=F4@(%1H92!K:6YD(&]F('1A9R`M('1A9RP@:68L(&QO
M;W`L(&-L;V]P+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@("=B)R`]
M/B!3=&%R="!T86<N"B`@("`@*B`@("`@("`@("`@("`@("`G92<@/3X@16YD
M('1A9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%1A9W,H)'1A9RP@)&1I
M<F5C=&EV92D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)V(G(#T^("<\
M)R`N("1D:7)E8W1I=F4@+B`G.B<@+B`D=&%G("X@)SXG+`H@("`@("`@("`@
M("`@("`@("`@("`G92<@/3X@)SPO)R`N("1D:7)E8W1I=F4@+B`G.B<@+B`D
M=&%G("X@)SXG*3L*("`@('T*"B`@("`O*BH*("`@("`J($9O<FUA=',@82!S
M8V%L87(@=&%G("AD969A=6QT(&9O<FUA="!I<R`\=&%G.FYA;64^*2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T86<@(%1H92!N86UE(&]F('1H92!T86<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F=6QL('1A9R!W:71H('1H92!C
M=7)R96YT('-T87)T+V5N9"!D96QI;6ET97)S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9V5T5&%G*"1T86<I"B`@("!["B`@("`@("`@<F5T=7)N("<\=&%G
M.B<@+B`D=&%G("X@)R`O/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'1R
M86-T<R!A('!O<G1I;VX@;V8@82!T96UP;&%T92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'0@
M("`@("`@("`@(%1H92!T86<@=&\@97AT<F%C="X@2&%S:"!F;W)M870@:7,Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1;)V(G72`M
M(%1H92!S=&%R="!T86<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=%LG92==("T@5&AE(&5N9"!T86<*("`@("`J($!P87)A;2!S=')I
M;F<@)B1C;VYT96YT<R`@5&AE('1E;7!L871E('1O(&5X=')A8W0@9G)O;2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%-T871E;65N="@D="P@)B1C;VYT
M96YT<RD*("`@('L*("`@("`@("`O+R!,;V-A=&4@=&AE('-T871E;65N="X*
M("`@("`@("`D<&]S(#T@<W1R<&]S*"1C;VYT96YT<RP@)'1;)V(G72D["B`@
M("`@("`@:68@*"1P;W,@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T86=?;&5N9W1H(#T@<W1R
M;&5N*"1T6R=B)UTI.PH@("`@("`@("1F<&]S(#T@)'!O<R`K("1T86=?;&5N
M9W1H.PH@("`@("`@("1L<&]S(#T@<W1R<&]S*"1C;VYT96YT<RP@)'1;)V4G
M72D["B`@("`@("`@)&QE;F=T:"`]("1L<&]S("T@)&9P;W,["@H@("`@("`@
M("\O($5X=')A8W0@)B!R971U<FX@=&AE('-T871E;65N="X*("`@("`@("!R
M971U<FX@<W5B<W1R*"1C;VYT96YT<RP@)&9P;W,L("1L96YG=&@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&=E='1E>'0@=&%G<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE('5N<&%R<V5D
M(&-O;G1E;G0@;V8@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!P87)S960@8V]N=&5N=',@;V8@=&AE(&=E='1E>'0@8FQO
M8VMS+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5'971T97AT*"1C;VYT
M96YT<RD*("`@('L*("`@("`@("`O+R!'970@=&AE('1A9W,@)B!L;V]P+@H@
M("`@("`@("1T(#T@87)R87DH)V(G(#T^("<\9V5T=&5X=#XG+`H@("`@("`@
M("`@("`@("`@("`@)V4G(#T^("<\+V=E='1E>'0^)RD["B`@("`@("`@=VAI
M;&4@*"1T97AT(#T@)'1H:7,M/E]G9713=&%T96UE;G0H)'0L("1C;VYT96YT
M<RDI('L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'1;
M)V(G72`N("1T97AT("X@)'1;)V4G72P@7R@D=&5X="DL("1C;VYT96YT<RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V]N=&5N=',["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!087)S97,@8FQO8VL@=&%G<RX*("`@("`J"B`@("`@
M*B!(97)E('=E('!A<G-E(&)L;V-K('1A9W,@:6X@=&AE(&9O<FTZ"B`@("`@
M*@H@("`@("H@(#QB;&]C:SIA<'`Z;F%M93X*("`@("`J("`@/'!A<F%M.F9O
M;SYF;V\@<&%R86UE=&5R)W,@=F%L=64\+W!A<F%M.F9O;SX*("`@("`J("`@
M/'!A<F%M.F)A<CYB87(@<&%R86UE=&5R)W,@=F%L=64\+W!A<F%M.F)A<CX*
M("`@("`J("`@/'-E<FEA;#IB87H^<SHR,3HB8F%Z('!A<F%M971E<B=S('9A
M;'5E(CL\+W-E<FEA;#IB87H^"B`@("`@*B`@/"]B;&]C:SIA<'`Z;F%M93X*
M("`@("`J"B`@("`@*B`N+BX@86YD(')E<&QA8V4@=&AE;2!W:71H(')E;F1E
M<F5D(&%P<&QI8V%T:6]N(&)L;V-K<RX*("`@("`J"B`@("`@*B!";&]C:R!P
M87)A;65T97)S(&%R92!P<F]V:61E9"!W:71H('1H92!N97-T960@(G!A<F%M
M.F9O;R(@86YD"B`@("`@*B`B<V5R:6%L.F9O;R(@=&%G<RX@(%1H92!S97)I
M86PM<W1Y;&4@=&%G<R!T86ME(&$@<V5R:6%L:7IE9"!02%`*("`@("`J('9A
M;'5E+"!S;R!Y;W4@8V%N('5S92!I="!T;R!P<F]V:61E(&%R<F%Y+"!B;V]L
M96%N+"!A;F0@8V]M<&QE>`H@("`@("H@='EP92!P87)A;65T97)S+B`@5&AE
M('!A<F%M+7-T>6QE('1A9W,@<')O=FED92!S=')I;F<@<&%R86UE=&5R<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE('5N<&%R<V5D(&-O;G1E;G1S
M(&]F('1H92!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<&%R<V5D(&-O;G1E;G1S(&]F('1H92!F:6QE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<&%R<V5";&]C:W,H)&-O;G1E;G1S*0H@("`@>PH@("`@("`@
M(')E='5R;B!P<F5G7W)E<&QA8V4H)R$\8FQO8VLZ*%MA+7I!+5I?,"TY72LI
M.BA;82UZ02U:7S`M.5TK*3XH+BH_*2<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)SPO8FQO8VLZ*%MA+7I!+5I?,"TY72LI.BA;82UZ02U:7S`M
M.5TK*3XA<V4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(EPD=&AI
M<RT^7W!A<G-E0FQO8VLH)UQ<,2<L("=<7#(G+"`G7%PS)RDB+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($AA;F1L92!T:&4@8V]N=&5N=',@;V8@;VYE(&)L;V-K('1A
M9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W!A<G-E0FQO8VLH)&%P<"P@)&YA;64L("1C;VYT96YT<RD*
M("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+G!H<"<[
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T:6]N
M+G!H<"<["@H@("`@("`@("\O(%5N9&\@<')E9U]R97!L86-E*"D@96YC;V1I
M;F<@<W1R86YG96YE<W,N"B`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA
M8V4H)UQ<(B<L("<B)RP@)&-O;G1E;G1S*3L*"B`@("`@("`@+R\@1FEN9"!B
M;&]C:R=S('!A<F%M971E<G,N"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<A/'!A<F%M.BA;82UZ02U:
M7S`M.5TK*3XH+BH_*2<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M/"]P87)A;3HH6V$M>D$M6E\P+3E=*RD^(7,G+"`D8V]N=&5N=',L("1M871C
M:&5S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("!04D5'7U-%5%]/4D1%
M4BDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&UA=&-H97,@87,@)&UA=&-H
M*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R1M871C:%LQ75T@/2!H=&UL
M7V5N=&ET>5]D96-O9&4H)&UA=&-H6S)=*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!I9B`H<')E9U]M871C:%]A;&PH)R$\<V5R:6%L.BA;
M82UZ02U:7S`M.5TK*3XH+BH_*2<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/"]S97)I86PZ*%MA+7I!+5I?,"TY72LI/B%S)RP@)&-O;G1E;G1S
M+"`D;6%T8VAE<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@4%)%1U]3
M151?3U)$15(I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M871C:&5S(&%S
M("1M871C:"D@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULD;6%T8VA;,5U=
M(#T@=6YS97)I86QI>F4H:'1M;%]E;G1I='E?9&5C;V1E*"1M871C:%LR72DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!#;VYS=')U
M8W0@=&AE(&)L;V-K+@H@("`@("`@("1B;&]C:R`]("9(;W)D95]";&]C:U]#
M;VQL96-T:6]N.CIG971";&]C:R@D87!P+"`D;F%M92P@)'!A<F%M<RD["B`@
M("`@("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1R97-U;'0@/2`G/'-T<F]N9SXG("X@<W!R:6YT9BA?*")%<G)O
M<B!C<F5A=&EN9R!B;&]C:SH@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8FQO8VLM/F=E=$UE<W-A9V4H*2D@+B`G/"]S
M=')O;F<^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@)&)L;V-K+3YG971#;VYT96YT*"D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`G/'-T<F]N9SXG("X@<W!R:6YT9BA?*")%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1R97-U;'0M/F=E=$UE<W-A9V4H*2D@+B`G/"]S=')O
M;F<^)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@82!G:79E
M;B!I9B!S=&%T96UE;G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%G("`@("`@(%1H92!N
M86UE(&]F('1H92!I9B!B;&]C:R!T;R!P87)S92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;G1E;G1S("!4:&4@=6YP87)S960@8V]N=&5N=',@;V8@=&AE
M(&EF(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M<&%R<V5D(&-O;G1E;G1S(&]F('1H92!I9B!B;&]C:RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W!A<G-E268H)'1A9RP@)&-O;G1E;G1S+"`D:V5Y(#T@;G5L
M;"D*("`@('L*("`@("`@("`O+R!'970@=&AE('1A9W,@)B!I9B!S=&%T96UE
M;G0N"B`@("`@("`@)'0@/2`D=&AI<RT^7V=E=%1A9W,H)'1A9RP@)VEF)RD[
M"B`@("`@("`@)&5T(#T@)'1H:7,M/E]G971486=S*"1T86<L("=E;'-E)RD[
M"@H@("`@("`@("\O(&5X<&QO9&4@=&AE('1A9RP@<V\@=V4@:&%V92!T:&4@
M8V]R<F5C="!K97ES(&9O<B!T:&4@87)R87D*("`@("`@("!I9B`H:7-S970H
M)&ME>2DI('L*("`@("`@("`@("`@;&ES="@D=&<L("1K*2`](&5X<&QO9&4H
M)RXG+"`D=&%G*3L*("`@("`@("!]"B`@("`@("`@=VAI;&4@*"1I9B`]("1T
M:&ES+3Y?9V5T4W1A=&5M96YT*"1T+"`D8V]N=&5N=',I*2!["B`@("`@("`@
M("`@("\O($-H96-K(&9O<B!E;'-E('-T871E;65N="X*("`@("`@("`@("`@
M:68@*"1E;'-E(#T@)'1H:7,M/E]G9713=&%T96UE;G0H)&5T+"`D:68I*2![
M"B`@("`@("`@("`@("`@("`O+R!0<F]C97-S('1H92!I9B!S=&%T96UE;G0N
M"B`@("`@("`@("`@("`@("!I9B`H*&ES<V5T*"1K97DI("8F("1T:&ES+3Y?
M:69S6R1T9UU;)&ME>5U;)&M=*2!\?`H@("`@("`@("`@("`@("`@("`@("AI
M<W-E="@D=&AI<RT^7VEF<ULD=&%G72D@)B8@)'1H:7,M/E]I9G-;)'1A9UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@)')E<&QA8V4@/2!S=')?<F5P;&%C
M92@D971;)V(G72`N("1E;'-E("X@)&5T6R=E)UTL("<G+"`D:68I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5P
M;&%C92`]("1E;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@4')O8V5S<R!T:&4@:68@<W1A
M=&5M96YT+@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1K97DI*2!["B`@
M("`@("`@("`@("`@("`@("`@)')E<&QA8V4@/2`D=&AI<RT^7VEF<ULD=&==
M6R1K97E=6R1K72`_("1I9B`Z(&YU;&P["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1R97!L86-E(#T@)'1H:7,M/E]I
M9G-;)'1A9UT@/R`D:68@.B!N=6QL.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!087)S92!T:&4@=&5M<&QA=&4N
M"B`@("`@("`@("`@("1C;VYT96YT<R`]('-T<E]R97!L86-E*"1T6R=B)UT@
M+B`D:68@+B`D=%LG92==+"`D<F5P;&%C92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@
M("`@("\O(%)E='5R;B!P87)S960@=&5M<&QA=&4N"B`@("`@("`@<F5T=7)N
M("1C;VYT96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!T:&4@
M9VEV96X@87)R87D@9F]R(&%N>2!L;V]P<R!O<B!O=&AE<B!U<V5S(&]F('1H
M92!A<G)A>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86<@("`@("`@5&AE(&YA;64@;V8@
M=&AE(&QO;W`@=&\@<&%R<V4N"B`@("`@*B!`<&%R86T@87)R87D@("1A<G)A
M>2`@("`@5&AE('9A;'5E<R!F;W(@=&AE(&QO;W`N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;VYT96YT<R`@5&AE('5N<&%R<V5D(&-O;G1E;G1S(&]F('1H
M92!L;V]P+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R
M<V5D(&-O;G1E;G1S(&]F('1H92!L;V]P+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<&%R<V5,;V]P*"1T86<L("1A<G)A>2P@)&-O;G1E;G1S*0H@("`@>PH@
M("`@("`@("\O($=E="!T:&4@=&%G<R`F(&QO;W`N"B`@("`@("`@)'0@/2`D
M=&AI<RT^7V=E=%1A9W,H)'1A9RP@)VQO;W`G*3L*("`@("`@("`D;&]O<"`]
M("1T:&ES+3Y?9V5T4W1A=&5M96YT*"1T+"`D8V]N=&5N=',I.PH*("`@("`@
M("`O+R!3964@:68@=V4@:&%V92!A(&1I=FED97(N"B`@("`@("`@)&P@/2`D
M=&AI<RT^7V=E=%1A9W,H)'1A9RP@)V1I=FED97(G*3L*("`@("`@("`D9&EV
M:61E<B`]("1T:&ES+3Y?9V5T4W1A=&5M96YT*"1L+"`D;&]O<"D["B`@("`@
M("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)&Q;)V(G72`N("1D:79I9&5R
M("X@)&Q;)V4G72P@)R<L("1C;VYT96YT<RD["@H@("`@("`@("\O(%!R;V-E
M<W,@=&AE(&%R<F%Y+@H@("`@("`@(&1O('L*("`@("`@("`@("`@)'!A<G-E
M9"`]("<G.PH@("`@("`@("`@("`D9FER<W0@/2!T<G5E.PH@("`@("`@("`@
M("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&D@/2`D;&]O<#L*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?;G5M97)I8R@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=F%L=64@87,@)&ME>3(@/3X@)'9A;'5E,BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%L=64R*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%)E<&QA8V4@
M87-S;V-I871I=F4@87)R87D@=&%G<RX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D86%?=&%G(#T@)'1A9R`N("<N)R`N("1K97DR.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I(#T@<W1R7W)E<&QA8V4H
M)'1H:7,M/E]G971486<H)&%A7W1A9RDL("1V86QU93(L("1I*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1T86<L
M("<N)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"@D
M<&]S("$]/2!F86QS92D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(65M<'1Y*"1T:&ES+3Y?:69S6W-U8G-T<B@D=&%G+"`P+"`D
M<&]S*5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:69S6R1A85]T86==(#T@)'9A;'5E,CL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&D@/2`D=&AI<RT^7W!A<G-E268H
M)&%A7W1A9RP@)&DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^7VEF<ULD86%?=&%G72D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!#:&5C:R!T;R!S964@:68@:70G<R!A(&YE<W1E9"!L;V]P+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I(#T@)'1H:7,M/E]P87)S
M94QO;W`H)'1A9R`N("<N)R`N("1K97DR+"`D=F%L=64R+"`D:2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&D@/2!S=')?<F5P;&%C92@D=&AI<RT^7V=E=%1A9R@D=&%G*2P@)&ME
M>2P@)&DI.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D
M:V5Y*2`F)B`A:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1C;VYT96YT<R`]('-T<E]R97!L86-E*"1T:&ES+3Y?9V5T5&%G*"1T
M86<@+B`G+B<@+B`D:V5Y*2P@)'9A;'5E+"`D8V]N=&5N=',I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D=F%L=64I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&D@/2!S=')?<F5P;&%C92@D=&AI<RT^7V=E=%1A
M9R@D=&%G("X@)R<I+"`D=F%L=64L("1L;V]P*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&D@/2!N=6QL.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O(%!A<G-E(&-O;F1I
M=&EO;G,@:6X@=&AE(&%R<F%Y+@H@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7VEF<ULD=&%G75LD:V5Y72D@)B8@:7-?87)R87DH)'1H:7,M
M/E]I9G-;)'1A9UU;)&ME>5TI("8F(&-O=6YT*"1T:&ES+3Y?:69S6R1T86==
M6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?:69S6R1T86==6R1K97E=(&%S("1C5&%G(#T^("1C5F%L=64I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&D@/2`D=&AI<RT^7W!A<G-E268H)'1A
M9R`N("<N)R`N("1C5&%G+"`D:2P@)&ME>2D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($%D
M9"!T:&4@<&%R<V5D(&ET97)A=&EO;BX*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D:2DI('L*("`@("`@("`@("`@("`@("`@("`O+R!)9B!I="=S(&YO
M="!T:&4@9FER<W0@=&EM92!T:')O=6=H+"!P<F5F:7@@=&AE"B`@("`@("`@
M("`@("`@("`@("`@+R\@;&]O<"!D:79I9&5R+"!I9B!T:&5R92!I<R!O;F4N
M"B`@("`@("`@("`@("`@("`@("`@:68@*"$D9FER<W0I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&D@/2`D9&EV:61E<B`N("1I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D<&%R<V5D("X](')T
M<FEM*"1I*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M+R!.;R!L;VYG97(@=&AE(&9I<G-T('1I;64@=&AR;W5G:"X*("`@("`@("`@
M("`@("`@("1F:7)S="`](&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R!297!L86-E('1H92!P87)S960@<&EE8V5S(&]F('1H92!T96UP
M;&%T92X*("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'1;
M)V(G72`N("1L;V]P("X@)'1;)V4G72P@)'!A<G-E9"P@)&-O;G1E;G1S*3L*
M("`@("`@("!]('=H:6QE("@D;&]O<"`]("1T:&ES+3Y?9V5T4W1A=&5M96YT
M*"1T+"`D8V]N=&5N=',I*3L*"B`@("`@("`@<F5T=7)N("1C;VYT96YT<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!T:&4@9VEV96X@8V%S92!L
M;V]P("AC;&]O<"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%G("`@("`@(%1H92!N86UE
M(&]F('1H92!C;&]O<"!T;R!P87)S92X*("`@("`J($!P87)A;2!A<G)A>2`@
M)&%R<F%Y("`@("!4:&4@=F%L=65S(&9O<B!T:&4@8VQO;W`N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE('5N<&%R<V5D(&-O;G1E;G1S
M(&]F('1H92!C;&]O<"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('!A<G-E9"!C;VYT96YT<R!O9B!T:&4@8VQO;W`N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]P87)S94-L;V]P*"1T86<L("1A<G)A>2P@)&-O;G1E;G1S
M*0H@("`@>PH@("`@("`@("\O($=E="!T:&4@=&%G<R`F(&-L;V]P+@H@("`@
M("`@("1T(#T@)'1H:7,M/E]G971486=S*"1T86<L("=C;&]O<"<I.PH*("`@
M("`@("!W:&EL92`H)&QO;W`@/2`D=&AI<RT^7V=E=%-T871E;65N="@D="P@
M)&-O;G1E;G1S*2D@>PH@("`@("`@("`@("`O+R!3970@=7`@=&AE(&-A<V5S
M+@H@("`@("`@("`@("`D87)R87E;)V-A<V5S)UU;72`]("=D969A=6QT)SL*
M("`@("`@("`@("`@)&-A<V5?8V]N=&5N="`](&%R<F%Y*"D["@H@("`@("`@
M("`@("`O+R!'970@=&AE(&-A<V4@<W1R:6YG<RX*("`@("`@("`@("`@9F]R
M96%C:"`H)&%R<F%Y6R=C87-E<R==(&%S("1C87-E*2!["B`@("`@("`@("`@
M("`@("`D8W1A9W-;)&-A<V5=(#T@)'1H:7,M/E]G971486=S*"1C87-E+"`G
M8V%S92<I.PH@("`@("`@("`@("`@("`@)&-A<V5?8V]N=&5N=%LD8V%S95T@
M/2`D=&AI<RT^7V=E=%-T871E;65N="@D8W1A9W-;)&-A<V5=+"`D;&]O<"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%!R;V-E<W,@=&AE(&-L
M;V]P+@H@("`@("`@("`@("`D<&%R<V5D(#T@)R<["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1A<G)A>5LG87)R87DG72!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`@("`@:68@*&ES7VYU;65R:6,H)&ME>2D@)B8@:7-?87)R
M87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@("\O(%-E="!U<"!T
M:&4@8V%S97,N"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU
M95LG8V%S92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N
M=%]C87-E(#T@)'9A;'5E6R=C87-E)UT["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8V%S
M92`]("=D969A=6QT)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@=6YS970H)'9A;'5E6R=C87-E)UTI.PH@("`@("`@("`@
M("`@("`@("`@("1I(#T@)&-A<V5?8V]N=&5N=%LD8W5R<F5N=%]C87-E73L*
M"B`@("`@("`@("`@("`@("`@("`@+R\@3&]O<"!T:')O=6=H(&5A8V@@=F%L
M=64N"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1K
M97DR(#T^("1V86QU93(I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1V86QU93(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:2`]("1T:&ES+3Y?<&%R<V5,;V]P*"1T86<@+B`G+B<@+B`D:V5Y
M,BP@)'9A;'5E,BP@)&DI.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&D@/2!S=')?<F5P
M;&%C92@D=&AI<RT^7V=E=%1A9R@D=&%G("X@)RXG("X@)&ME>3(I+"`D=F%L
M=64R+"`D:2D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@+R\@061D('1H92!P87)S960@:71E<F%T:6]N+@H@("`@("`@("`@("`@
M("`@)'!A<G-E9"`N/2!R=')I;2@D:2D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\O(%!A<G-E('1H92!C;&]O<"X*("`@("`@("`@("`@)&-O;G1E
M;G1S(#T@<W1R7W)E<&QA8V4H)'1;)V(G72`N("1L;V]P("X@)'1;)V4G72P@
M)'!A<G-E9"P@)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D8V]N=&5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C:"!T:&4@
M8V]N=&5N=',@;V8@82!T96UP;&%T92!I;G1O("1T:&ES+3Y?=&5M<&QA=&4[
M(&-A8VAE"B`@("`@*B!T:&4@9FEL96YA;64@:6X@)'1H:7,M/E]T96UP;&%T
M949I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@($QO8V%T:6]N(&]F('1E
M;7!L871E(&9I;&4@;VX@9&ES:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&QO861E9"!T96UP;&%T92!C;VYT96YT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T5&5M<&QA=&4H)&9I;&5N86UE(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&9I;&5N86UE*2`F)B`H)&9I;&5N
M86UE("$]("1T:&ES+3Y?=&5M<&QA=&5&:6QE*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W1E;7!L871E(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-?;G5L;"@D=&AI<RT^7W1E;7!L871E*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]T96UP;&%T93L*("`@("`@("!]"@H@("`@("`@("\O
M($=E="!T:&4@8V]N=&5N=',@;V8@=&AE(&9I;&4N"B`@("`@("`@)&9I;&4@
M/2`D=&AI<RT^7V)A<V5P871H("X@)&9I;&5N86UE.PH@("`@("`@("1C;VYT
M96YT<R`]($!F:6QE7V=E=%]C;VYT96YT<R@D9FEL92D["B`@("`@("`@:68@
M*"1C;VYT96YT<R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB
M*2P@)&9I;&4I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?=&5M<&QA
M=&4@/2`D8V]N=&5N=',["B`@("`@("`@)'1H:7,M/E]T96UP;&%T949I;&4@
M/2`D9FEL96YA;64["@H@("`@("`@(')E='5R;B`D=&AI<RT^7W1E;7!L871E
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1I;65R+G!H<```````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$U-@`Q,#0Q-S,V,C<W
M,P`P,C`P,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%-I;7!L92!I;G1E<F9A8V4@9F]R('1I;6EN
M9R!O<&5R871I;VYS+V%C=&EO;G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U1I;65R+U1I;65R+G!H<"QV(#$N-BXQ,"XR(#(P,#4O,3`O,3@@,3$Z,#$Z
M,S0@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7U1I;65R"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?5&EM97(@>PH*("`@
M("\J*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S=&%R
M="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?:61X(#T@,#L*"B`@("`O*BH*("`@("`J(%!U<V@@
M82!N97<@=&EM97(@<W1A<G0@;VX@<W1A8VLN"B`@("`@*B\*("`@(&9U;F-T
M:6]N('!U<V@H*0H@("`@>PH@("`@("`@(&QI<W0H)&US+"`D<RD@/2!E>'!L
M;V1E*"<@)RP@;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?<W1A<G1;
M)'1H:7,M/E]I9'@K*UT@/2!F;&]O<B@D;7,@*B`Q,#`P*2`K(#$P,#`@*B`D
M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%!O<"!T:&4@;&%T97-T('1I;65R
M('-T87)T(&%N9"!R971U<FX@=&AE(&1I9F9E<F5N8V4@=VET:"!T:&4*("`@
M("`J(&-U<G)E;G0@=&EM92X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]P*"D*
M("`@('L*("`@("`@("!A<W-E<G0H)'1H:7,M/E]I9'@@/B`P*3L*("`@("`@
M("!L:7-T*"1M<RP@)',I(#T@97AP;&]D92@G("<L(&UI8W)O=&EM92@I*3L*
M("`@("`@("`D971I;64@/2!F;&]O<B@D;7,@*B`Q,#`P*2`K("@Q,#`P("H@
M)',I.PH@("`@("`@("1T:&ES+3Y?:61X+2T["B`@("`@("`@<F5T=7)N("1E
M=&EM92`M("1T:&ES+3Y?<W1A<G1;)'1H:7,M/E]I9'A=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N(&$@<F5F97)E;F-E('1O(&$@9VQO8F%L($AO
M<F1E7U1I;65R(&5N9VEN92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L
M971O;B@I"B`@("!["B`@("`@("`@<W1A=&EC("1T:6UE<CL*"B`@("`@("`@
M:68@*"%I<W-E="@D=&EM97(I*2!["B`@("`@("`@("`@("1T:6UE<B`](&YE
M=R!(;W)D95]4:6UE<B@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:6UE<CL*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O5&]K96XN<&AP````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$S,S,Q`#$P-#$W,S8R-S<S`#`R,#`R-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7U1O:V5N.CH@8VQA
M<W,@<')O=FED97,@82!C;VUM;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@:6YT
M;R!T:&4*("H@=F%R:6]U<R!T;VME;B!G96YE<F%T:6]N(&UE9&EU;7,N($ET
M(&%L<V\@:6YC;'5D97,@86QL(&]F('1H90H@*B!F=6YC=&EO;G,@9F]R(')E
M=')I979I;F<L('-T;W)I;F<L(&%N9"!C:&5C:VEN9R!T;VME;G,N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U1O:V5N+U1O:V5N+G!H<"QV(#$N,S,N-BXW
M(#(P,#8O,#$O,#$@,C$Z,C@Z,SD@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@36%X($MA;&EK82`\;6%X0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA>"!+86QI:V$@
M/&UA>$!H;W)D92YO<F<^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?5&]K96X*("HO"F-L87-S($AO<F1E7U1O:V5N('L*"B`@
M("`O*BH*("`@("`J($AA<V@@;V8@<&%R86UE=&5R<R!N96-E<W-A<GD@=&\@
M=7-E('1H92!C:&]S96X@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@<&%R86UE=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5&]K96XH)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@96YC;V1E4F5M;W1E
M061D<F5S<R@I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=2
M14U/5$5?041$4B==*2D@>PH@("`@("`@("`@("!R971U<FX@8F%S938T7V5N
M8V]D92@D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E<R!A(&-O;FYE8W1I;VX@:60@86YD(')E
M='5R;G,@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5E9"`@
M02!U;FEQ=64@240@=&\@8F4@:6YC;'5D960@:6X@=&AE('1O:V5N+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@:68@:70@;F5E9',@=&\@8F4@;6]R
M92!U;FEQ=64@=&AA;B!T:6UE("AI;B!S96-O;F1S*0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@86YD('1H92!R96UO=&4@25`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@("!4:&4@9V5N97)A=&5D(&ED('-T<FEN9RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5)9"@D<V5E9"`]("<G*0H@
M("`@>PH@("`@("`@(')E='5R;B!M9#4H=&EM92@I("X@)UU;)R`N("1S965D
M("X@)UU;)R`N($AO<F1E7U1O:V5N.CIE;F-O9&5296UO=&5!9&1R97-S*"DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF('1H92!G:79E;B!T
M;VME;B!H87,@8F5E;B!P<F5V:6]U<VQY('5S960N($9I<G-T"B`@("`@*B!P
M=7)G97,@86QL(&5X<&ER960@=&]K96YS+B!4:&5N(')E=')I979E<R!C=7)R
M96YT('1O:V5N<R!F;W(*("`@("`J('1H92!G:79E;B!I<"!A9&1R97-S+B!)
M9B!T:&4@<W!E8VEF:65D('1O:V5N('=A<R!N;W0@9F]U;F0L"B`@("`@*B!A
M9&1S(&ET+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1O:V5N("!4
M:&4@=F%L=64@;V8@=&AE('1O:V5N('1O(&-H96-K+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@("`@("!4<G5E(&EF('1H92!T;VME;B!H87,@
M;F]T(&)E96X@=7-E9"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F
M86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('9E<FEF>2@D
M=&]K96XI"B`@("!["B`@("`@("`@)'1H:7,M/G!U<F=E*"D["B`@("`@("`@
M:68@*"1T:&ES+3YE>&ES=',H)'1O:V5N*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YA9&0H)'1O:V5N*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!4:&ES(&ES(&%N(&%B<W1R86-T(&UE=&AO9"!T:&%T('-H;W5L
M9"!B92!O=F5R<FED9&5N(&)Y(&$*("`@("`J('-U8F-L87-S(&EM<&QE;65N
M=&%T:6]N+B!4:&4@8F%S92!I;7!L96UE;G1A=&EO;B!A;&QO=W,@86QL"B`@
M("`@*B!T;VME;B!V86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5&AI<R!I<R!A;B!A8G-T<F%C="!M971H;V0@=&AA="!S:&]U
M;&0@8F4@;W9E<G)I9&1E;B!B>2!A"B`@("`@*B!S=6)C;&%S<R!I;7!L96UE
M;G1A=&EO;BX@5&AE(&)A<V4@:6UP;&5M96YT871I;VX@86QL;W=S(&%L;`H@
M("`@("H@=&]K96X@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H
M*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5&AI<R!I<R!A;B!A8G-T<F%C="!M971H;V0@=&AA="!S:&]U;&0@
M8F4@;W9E<G)I9&1E;B!B>2!A"B`@("`@*B!S=6)C;&%S<R!I;7!L96UE;G1A
M=&EO;BX@5&AE(&)A<V4@:6UP;&5M96YT871I;VX@86QL;W=S(&%L;`H@("`@
M("H@=&]K96X@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!P=7)G92@I
M"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]4;VME
M;B!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D
M95]4;VME;B!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W
M:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I
M=F5R6S!=+VQI8B]4;VME;B\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV
M97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S
M:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M
M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R
M971U<FX@2&]R9&5?5&]K96X@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E
M($AO<F1E7U1O:V5N(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@9F%L<V4@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L
M:7-T*"1A<'`L("1D<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!]"@H@("`@
M("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@
M*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)&%P
M<"`N("<O;&EB+U1O:V5N+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@
M('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+U1O:V5N+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U1O:V5N+R<@+B`D
M9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M($!I;F-L=61E7V]N8V4@)TAO<F1E+U1O:V5N+R<@+B`D9')I=F5R("X@)RYP
M:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7U1O:V5N
M7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S
M*2D@>PH@("`@("`@("`@("`D=&]K96X@/2`F;F5W("1C;&%S<R@D<&%R86US
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&]K96X@/2`F;F5W
M($AO<F1E7U1O:V5N*"1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T;VME;CL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7U1O:V5N
M(&EN<W1A;F-E(&)A<V5D"B`@("`@*B!O;B`D9')I=F5R+@H@("`@("H*("`@
M("`J($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@
M2&]R9&5?5&]K96X@:6YS=&%N8V4@=VET:"!T:&4*("`@("`J('-A;64@<&%R
M86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@
M<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@='EP97,@;V8@=&]K96X@9V5N
M97)A=&]R<R`H86YD+"!T:'5S+`H@("`@("H@;75L=&EP;&4@2&]R9&5?5&]K
M96X@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.@H@("`@("H@/&-O9&4^)'9A
M<B`]("9(;W)D95]4;VME;CHZ<VEN9VQE=&]N*"D[/"]C;V1E/@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC
M<F5T92!(;W)D95]4;VME;B!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@
M=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!I;B`D9')I=F5R6S!=+VQI8B]4;VME;B\@9F]R('1H92!S=6)C;&%S<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA
M;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R
M871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T
M:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@2&]R9&5?5&]K96X@(%1H92!C;VYC<F5T92!(;W)D
M95]4;VME;B!R969E<F5N8V4L(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I
M.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA
M<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D
M:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N
M8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E7U1O:V5N.CIF86-T;W)Y*"1D<FEV
M97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T
M86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4
M<F5E+G!H<```````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,S8V-S,`,3`T,3<S-C(W-S,`,#$W-C8Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@1&ES<&QA
M>2!E>'1R82!C;VQU;6YS('1O('1H92!L969T(&]F('1H92!M86EN('1R964N
M"B`J+PID969I;F4H)TA/4D1%7U12145?15A44D%?3$5&5"<L(#`I.PH*+RHJ
M"B`J($1I<W!L87D@97AT<F$@8V]L=6UN<R!T;R!T:&4@<FEG:'0@;V8@=&AE
M(&UA:6X@=')E92X*("HO"F1E9FEN92@G2$]21$5?5%)%15]%6%1205]224=(
M5"<L(#$I.PH*+RHJ"B`J(%1H92!P<F5C961I;F<@=&5X="P@8F5F;W)E('1H
M92!(;W)D95]4<F5E(&EN<W1A;F-E(&YA;64L('5S960@9F]R"B`J(&-O;&QA
M<'-E+V5X<&%N9"!S=6)M:7-S:6]N<RX*("HO"F1E9FEN92@G2$]21$5?5%)%
M15]43T='3$4G+"`G:'1?=&]G9VQE7R<I.PH*+RHJ"B`J(%1H92!(;W)D95]4
M<F5E.CH@8VQA<W,@<')O=FED97,@82!T<F5E('9I97<@;V8@:&EE<F%R8VAI
M8V%L(&EN9F]R;6%T:6]N+B!)=`H@*B!A;&QO=W,@9F]R(&5X<&%N9&EN9R]C
M;VQL87!S:6YG(&]F(&)R86YC:&5S(&%N9"!M86EN=&%I;G,@=&AE:7(@<W1A
M=&4N($ET"B`J(&-A;B!W;W)K('1O9V5T:&5R('=I=&@@=&AE($AO<F1E7U1R
M964@:F%V87-C<FEP="!C;&%S<R!T;R!A8VAI979E('1H:7,@:6X*("H@1$A4
M34P@;VX@<W5P<&]R=&5D(&)R;W=S97)S+@H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP+'8@
M,2XT-BXV+C$Q(#(P,#8O,#$O,#$@,C$Z,C@Z-#`@:F%N($5X<"`D"B`J"B`J
M($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P
M86-K86=E($AO<F1E7U1R964*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC
M;&%S<R!(;W)D95]4<F5E('L*"B`@("`O*BH*("`@("`J(%1H92!N86UE(&]F
M('1H:7,@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?:6YS=&%N8V4@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@2&%S:"!W:71H(&AE861E<B!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VAE861E<B`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!C;VYT86EN:6YG(&%L;"!T
M:&4@=')E92!N;V1E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7VYO9&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%1H92!T;W`M;&5V96P@;F]D97,@:6X@=&AE('1R964N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]R;V]T7VYO9&5S(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($ME97`@8V]U;G0@;V8@:&]W(&UA
M;GD@97AT<F$@8V]L=6UN<R!T:&5R92!A<F4@;VX@=&AE(&QE9G0@<VED90H@
M("`@("H@;V8@=&AE(&YO9&4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D7V5X=')A7V-O;'-?;&5F="`](#`["@H@("`@
M+RHJ"B`@("`@*B!+965P(&-O=6YT(&]F(&AO=R!M86YY(&5X=')A(&-O;'5M
M;G,@=&AE<F4@87)E(&]N('1H92!R:6=H="!S:61E"B`@("`@*B!O9B!T:&4@
M;F]D92X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?97AT<F%?8V]L<U]R:6=H="`](#`["@H@("`@+RHJ"B`@("`@*B!/
M<'1I;VX@=F%L=65S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?;W!T:6]N<R`](&%R<F%Y*"=L:6YE<R<@/3X@=')U92D[
M"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@=&AE('-O<G1I;F<@8W)I=&5R:6$@
M=&5M<&]R87)I;'DN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?<V]R=$-R:71E<FEA.PH*("`@("\J*@H@("`@("H@57-E
M('-E<W-I;VX@=&\@<W1O<F4@8V%C:&5D(%1R964@9&%T83\*("`@("`J"B`@
M("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?=7-E<V5S<VEO
M;B`]('1R=64["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@=&AE('1R964@8F4@
M<F5N9&5R960@<W1A=&EC86QL>3\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?<W1A=&EC(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C
M;VYC<F5T92!(;W)D95]4<F5E"B`@("`@*B!I;G-T86YC92!B87-E9"!O;B`D
M;F%M92!A;F0@)')E;F1E<F5R+B!)="!W:6QL(&]N;'D@8W)E871E(&$*("`@
M("`J(&YE=R!I;G-T86YC92!I9B!N;R!(;W)D95]4<F5E(&EN<W1A;F-E('=I
M=&@@=&AE('-A;64@<&%R86UE=&5R<PH@("`@("H@8W5R<F5N=&QY(&5X:7-T
M<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@
M87,Z"B`@("`@*B`@("1V87(@/2`F2&]R9&5?5')E93HZ<VEN9VQE=&]N*"1N
M86UE6RP@)')E;F1E<F5R72D["B`@("`@*@H@("`@("H@0'-T871I8PH@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`@)&YA;64@("`@("!`<V5E($AO<F1E
M7U1R964Z.F9A8W1O<GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96YD97)E
M<B`@0'-E92!(;W)D95]4<F5E.CIF86-T;W)Y+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("`D<&%R86US("`@($!S964@2&]R9&5?5')E93HZ9F%C=&]R>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U1R964@(%1H92!C;VYC<F5T92!(
M;W)D95]4<F5E(')E9F5R96YC92P@;W(@4$5!4E]%<G)O<B!O;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D;F%M92P@)')E;F1E<F5R+"`D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y
M*"D["@H@("`@("`@("1I9"`]("1N86UE("X@)SHG("X@)')E;F1E<F5R("X@
M)SHG("X@<V5R:6%L:7IE*"1P87)A;7,I.PH@("`@("`@(&EF("@A:7-S970H
M)&EN<W1A;F-E<ULD:61=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1I
M9%T@/2`F2&]R9&5?5')E93HZ9F%C=&]R>2@D;F%M92P@)')E;F1E<F5R+"`D
M<&%R86US*3L*("`@("`@("`@("`@:68@*"$D:6YS=&%N8V5S6R1I9%TM/FES
M4W5P<&]R=&5D*"DI('L*("`@("`@("`@("`@("`@("1R96YD97)E<B`]($AO
M<F1E7U1R964Z.F9A;&QB86-K*"1R96YD97)E<BD["B`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<F5N9&5R97(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)')E;F1E<F5R.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N($AO<F1E7U1R964Z.G-I;F=L
M971O;B@D;F%M92P@)')E;F1E<F5R+"`D<&%R86US*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)&ED73L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O
M;F-R971E($AO<F1E7U1R964@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'-T
M871I8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("!4
M:&4@;F%M92!O9B!T:&ES('1R964@:6YS=&%N8V4N"B`@("`@*B!`<&%R86T@
M;6EX960@("1R96YD97)E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?
M5')E92!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;BX@5&AI<R!I<R!B87-E9"!O;B!T:&4@<F5N9&5R:6YG(&1R
M:79E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("@D<F5N9&5R
M97(I+B!4:&4@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J
M($!P87)A;2!A<G)A>2`@)'!A<F%M<R`@("!!;GD@861D:71I;VYA;"!P87)A
M;65T97)S('1H92!C;VYS=')U8W1O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&YE961S+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?
M5')E92`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?5')E92!I
M;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@4$5!4E]%
M<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH
M)&YA;64L("1R96YD97)E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@+RH@4F5Q=6ER92!T:&4@<F5N9&5R97(@;&EB+B`J+PH@("`@("`@
M(&EN8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O5')E92\G("X@
M)')E;F1E<F5R("X@)RYP:'`G.PH*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?
M5')E95\G("X@)')E;F1E<F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H
M)&-L87-S*2D@>PH@("`@("`@("`@("`D=')E92`]("9N97<@)&-L87-S*"1N
M86UE+"`D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=')E92`](%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")<(B5S7"(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(BDL("1R96YD97)E<BDI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T<F5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5')Y('1O(&9A;&P@8F%C:R!T;R!A('-I;7!L97(@<F5N9&5R97(N"B`@
M("`@*@H@("`@("H@0'!A<F%N('-T<FEN9R`D<F5N9&5R97(@(%1H92!R96YD
M97)E<B!T:&%T('=E(&-A;B=T(&AA;F1L92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!\(%!%05)?17)R;W(@(%1H92!N97AT(&)E<W0@<F5N9&5R
M97(L(&]R(&%N(&5R<F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF('=E)W9E(')U;B!O=70@;V8@<F5N9&5R97)S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!F86QL8F%C:R@D<F5N9&5R97(I"B`@("!["B`@("`@
M("`@<W=I=&-H("@D<F5N9&5R97(I('L*("`@("`@("!C87-E("=J879A<V-R
M:7!T)SH*("`@("`@("`@("`@<F5T=7)N("=H=&UL)SL*"B`@("`@("`@8V%S
M92`G:'1M;"<Z"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=O=70@;V8@<F5N9&5R97)S)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@("!4:&4@;F%M92!O9B!T:&ES('1R964@:6YS=&%N8V4N
M"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@($%D9&ET:6]N86P@<&%R
M86UE=&5R<RX*("`@("`J(#QP<F4^"B`@("`@*B`G;F]S97-S:6]N)R`@+2T@
M("AB;V]L96%N*2!)9B!T<G5E+"!D;R!N;W0@<W1O<F4@=')E92!D871A(&EN
M('-E<W-I;VXN"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?5')E92@D;F%M92P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I;G-T86YC92`]("1N86UE.PH@("`@("`@("1T:&ES
M+3Y?=7-E<V5S<VEO;B`](&5M<'1Y*"1P87)A;7-;)VYO<V5S<VEO;B==*3L*
M"B`@("`@("`@+RH@4V5T('5P('1H92!S97-S:6]N(&9O<B!L871E<B!T;R!S
M879E('1R964@<W1A=&5S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W5S97-E
M<W-I;VX@)B8*("`@("`@("`@("`@(6ES<V5T*"1?4T534TE/3ELG:&]R9&5?
M=')E92==6R1T:&ES+3Y?:6YS=&%N8V5=*2D@>PH@("`@("`@("`@("`D7U-%
M4U-)3TY;)VAO<F1E7W1R964G75LD=&AI<RT^7VEN<W1A;F-E72`](&%R<F%Y
M*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R<R!T
M:&4@=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A=&EC
M("!)9B!T<G5E('1H92!T<F5E(&YO9&5S(&-A;B=T(&)E(&5X<&%N9&5D(&%N
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@8V]L;&%P<V5D(&%N
M9"!T:&4@=')E92!G971S(')E;F1E<F5D(&5X<&%N9&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96YD97)4<F5E*"1S=&%T:6,@/2!F86QS92D*("`@('L*
M("`@("`@("!E8VAO("1T:&ES+3YG9714<F5E*"1S=&%T:6,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!A;B!O<'1I;VXN"B`@("`@*B!!=F%I;&%B
M;&4@;W!T:6]N<SH*("`@("`J(#QP<F4^"B`@("`@*B`@(&%L=&5R;F%T92`@
M("`M+2`@06QT97)N871E('-H861I;F<@:6X@=&AE('1A8FQE/R`H8F]O;&5A
M;BD*("`@("`J("`@:&ED94AE861E<G,@("TM("!$;VXG="!R96YD97(@86YY
M($A434P@9F]R('1H92!H96%D97(@<F]W+"!J=7-T('5S92!T:&4@=VED=&AS
M+@H@("`@("H@("!C;&%S<R`@("`@("`@+2T@(%1H92!C;&%S<R!T;R!U<V4@
M9F]R('1H92!T86)L92X@*'-T<FEN9RD*("`@("`J("`@;&EN97,@("`@("`@
M("TM("!3:&]W('1R964@;&EN97,_("AB;V]L96%N*0H@("`@("H@("!M=6QT
M:6QI;F4@("`@+2T@($1O('1H92!N;V1E(&QA8F5L<R!C;VYT86EN(&QI;F5B
M<F5A:W,_("AB;V]L96%N*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1O<'1I;VX@(%1H92!O<'1I;VX@;F%M92`M;W(M(&%N
M(&%R<F%Y(&]F(&]P=&EO;B!N86UE+W9A;'5E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<&%I<G,N"B`@("`@*B!`<&%R86T@;6EX960@)'9A;"`@
M("`@5&AE(&]P=&EO;B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971/<'1I;VXH)&]P=&EO;G,L("1V86QU92`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D;W!T:6]N<RDI('L*("`@("`@("`@("`@)&]P
M=&EO;G,@/2!A<G)A>2@D;W!T:6]N<R`]/B`D=F%L=64I.PH@("`@("`@('T*
M"B`@("`@("`@9F]R96%C:"`H)&]P=&EO;G,@87,@)&]P=&EO;B`]/B`D=F%L
M=64I('L*("`@("`@("`@("`@)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=(#T@
M)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@
M86X@;W!T:6]N)W,@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;W!T:6]N("`@5&AE(&YA;64@;V8@=&AE(&]P=&EO;B!T;R!F971C:"X*
M("`@("`J($!P87)A;2!B;V]L96%N("1H=&UL("`@(%1R=64@;W(@9F%L<V4@
M=VAE=&AE<B!T;R!F;W)M870@=&AE(')E='5R;B!V86QU90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@:6X@:'1M;"X@1&5F875L=',@=&\@9F%L
M<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D969A=6QT("!!(&1E9F%U;'0@
M=F%L=64@=&\@=7-E(&EN(&-A<V4@;F]N92!I<R!S970@9F]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@<F5Q=65S=&5D(&]P=&EO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@;W!T:6]N)W,@=F%L
M=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$]P=&EO;B@D;W!T:6]N+"`D
M:'1M;"`](&9A;'-E+"`D9&5F875L="`](&YU;&PI"B`@("!["B`@("`@("`@
M)'9A;'5E(#T@;G5L;#L*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)&]P=&EO;ETI("8F("%I<U]N=6QL*"1D969A=6QT*2D@>PH@("`@
M("`@("`@("`O*B!297%U97-T960@;W!T:6]N(&AA<R!N;W0@8F5E;B!B=70@
M=&AE<F4@:7,@80H@("`@("`@("`@("`@*B!D969A=6QT+B`J+PH@("`@("`@
M("`@("`D=F%L=64@/2`D9&5F875L=#L*("`@("`@("!](&5L<V5I9B`H:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=*2D@>PH@("`@("`@("`@("`O
M*B!297%U97-T960@;W!T:6]N(&AA<R!B965N('-E="P@9V5T(&ET<R!V86QU
M92X@*B\*("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]O<'1I;VYS6R1O
M<'1I;VY=.PH@("`@("`@('T*"B`@("`@("`@:68@*"1H=&UL("8F("%I<U]N
M=6QL*"1V86QU92DI('L*("`@("`@("`@("`@+RH@1F]R;6%T('9A;'5E(&9O
M<B!H=&UL(&]U='!U="X@*B\*("`@("`@("`@("`@)'9A;'5E(#T@<W!R:6YT
M9B@G("5S/2(E<R(G+"`D;W!T:6]N+"`D=F%L=64I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@82!N;V1E('1O('1H92!N;V1E('1R964@87)R87DN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&ED("`@("`@("`@("!4:&4@=6YI<75E(&YO
M9&4@:60N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@("`@(%1H
M92!P87)E;G0G<R!U;FEQ=64@;F]D92!I9"X*("`@("`J($!P87)A;2!S=')I
M;F<@("1L86)E;"`@("`@("`@5&AE('1E>'0@;&%B96P@9F]R('1H92!N;V1E
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&EN9&5N="`@("`@("!$97!R96-A
M=&5D+"!T:&ES(&ES(&-A;&-U;&%T960@875T;VUA=&EC86QL>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B87-E9"!O;B!T:&4@<&%R
M96YT(&YO9&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D97AP86YD960@("`@
M($ES('1H:7,@;&5V96P@97AP86YD960@;W(@;F]T+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("`@)'!A<F%M<R`@("`@("!!;GD@;W1H97(@<&%R86UE=&5R<R!T
M;R!S970@*$!S964*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@861D3F]D95!A<F%M<R@I(&9O<B!F=6QL(&1E=&%I;',I+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("`@)&5X=')A7W)I9VAT("!!;GD@;W1H97(@8V]L=6UN
M<R!T;R!D:7-P;&%Y('1O('1H92!R:6=H="!O9@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@=')E92X*("`@("`J($!P87)A;2!A
M<G)A>2`@("1E>'1R85]L969T("`@06YY(&]T:&5R(&-O;'5M;G,@=&\@9&ES
M<&QA>2!T;R!T:&4@;&5F="!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M3F]D92@D:60L("1P87)E;G0L("1L86)E;"P@)&EN9&5N="P@)&5X<&%N9&5D
M(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y
M*"DL("1E>'1R85]R:6=H="`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@
M("`@("1E>'1R85]L969T(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI
M<RT^7VYO9&5S6R1I9%U;)VQA8F5L)UT@/2`D;&%B96P["@H@("`@("`@(&EF
M("@D=&AI<RT^7W5S97-E<W-I;VXI('L*("`@("`@("`@("`@)'-E<W-I;VY?
M<W1A=&4@/2`D7U-%4U-)3TY;)VAO<F1E7W1R964G75LD=&AI<RT^7VEN<W1A
M;F-E73L*("`@("`@("`@("`@)'1O9V=L95]I9"`](%5T:6PZ.F=E=$9O<FU$
M871A*$A/4D1%7U12145?5$]'1TQ%("X@)'1H:7,M/E]I;G-T86YC92D["B`@
M("`@("`@("`@(&EF("@D:60@/3T@)'1O9V=L95]I9"D@>PH@("`@("`@("`@
M("`@("`@+RH@5V4@:&%V92!A('5R;"!T;V=G;&4@<F5Q=65S="!F;W(@=&AI
M<R!N;V1E+B`J+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1S97-S:6]N
M7W-T871E6R=E>'!A;F1E9"==6R1I9%TI*2!["B`@("`@("`@("`@("`@("`@
M("`@+RH@57-E('-E<W-I;VX@<W1A=&4@:68@:70@:7,@<V5T+B`J+PH@("`@
M("`@("`@("`@("`@("`@("1E>'!A;F1E9"`]("@A)'-E<W-I;VY?<W1A=&5;
M)V5X<&%N9&5D)UU;)&ED72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("\J($]T:&5R=VES92!U<V4@=VAA="!W87,@
M<&%S<V5D('1H<F]U9V@@=&AE"B`@("`@("`@("`@("`@("`@("`@("H@9G5N
M8W1I;VXN("HO"B`@("`@("`@("`@("`@("`@("`@)&5X<&%N9&5D(#T@*"$D
M97AP86YD960I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("\J(%-A=F4@=&AI<R!S=&%T92!T;R!S97-S:6]N+B`J+PH@("`@("`@("`@
M("`@("`@)%]315-324].6R=H;W)D95]T<F5E)UU;)'1H:7,M/E]I;G-T86YC
M95U;)V5X<&%N9&5D)UU;)&ED72`]("1E>'!A;F1E9#L*("`@("`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1S97-S:6]N7W-T871E6R=E>'!A;F1E9"==6R1I
M9%TI*2!["B`@("`@("`@("`@("`@("`O*B!)9B!W92!H879E(&$@<V%V960@
M<V5S<VEO;B!S=&%T92!U<V4@:70N("HO"B`@("`@("`@("`@("`@("`D97AP
M86YD960@/2`D<V5S<VEO;E]S=&%T95LG97AP86YD960G75LD:61=.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VYO9&5S6R1I
M9%U;)V5X<&%N9&5D)UT@/2`D97AP86YD960["@H@("`@("`@("\J($EF(&%N
M>2!P87)A;7,@:6YC;'5D960@:&5R92!A9&0@=&AE;2!N;W<N("HO"B`@("`@
M("`@:68@*"%E;7!T>2@D<&%R86US*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M861D3F]D95!A<F%M<R@D:60L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@268@86YY(&5X=')A(&-O;'5M;G,@:6YC;'5D960@:&5R92!A9&0@
M=&AE;2!N;W<N("HO"B`@("`@("`@:68@*"%E;7!T>2@D97AT<F%?<FEG:'0I
M*2!["B`@("`@("`@("`@("1T:&ES+3YA9&1.;V1E17AT<F$H)&ED+"!(3U)$
M15]44D5%7T585%)!7U))1TA4+"`D97AT<F%?<FEG:'0I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(65M<'1Y*"1E>'1R85]L969T*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^861D3F]D945X=')A*"1I9"P@2$]21$5?5%)%15]%6%1205],
M1494+"`D97AT<F%?;&5F="D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M;G5L;"@D<&%R96YT*2D@>PH@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1I
M9"P@)'1H:7,M/E]R;V]T7VYO9&5S*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R;V]T7VYO9&5S6UT@/2`D:60["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]N;V1E
M<ULD<&%R96YT75LG8VAI;&1R96XG72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;F]D97-;)'!A<F5N=%U;)V-H:6QD<F5N)UT@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)&ED+"`D
M=&AI<RT^7VYO9&5S6R1P87)E;G1=6R=C:&EL9')E;B==*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]N;V1E<ULD<&%R96YT75LG8VAI;&1R96XG75M=
M(#T@)&ED.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@061D<R!A9&1I=&EO;F%L('!A<F%M971E<G,@=&\@82!N;V1E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("!4:&4@=6YI
M<75E(&YO9&4@:60N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY
M(&]T:&5R('!A<F%M971E<G,@=&\@<V5T+@H@("`@("H@/'!R93X*("`@("`J
M(&-L87-S("`@("`M+2`@0U-3(&-L87-S('1O('5S92!W:71H('1H:7,@;F]D
M90H@("`@("H@:6-O;B`@("`@("TM("!)8V]N('1O(&1I<W!L87D@;F5X="!N
M;V1E"B`@("`@*B!I8V]N86QT("`@+2T@($%L="!T97AT('1O('5S92!F;W(@
M=&AE(&EC;VX*("`@("`J(&EC;VYD:7(@("`M+2`@26-O;B!D:7)E8W1O<GD*
M("`@("`J(&EC;VYO<&5N("`M+2`@26-O;B!T;R!I;F1I8V%T92!T:&ES(&YO
M9&4@87,@97AP86YD960*("`@("`J(&]N8VQI8VL@("`M+2`@3VYC;&EC:R!E
M=F5N="!A='1A8VAE9"!T;R!T:&ES(&YO9&4*("`@("`J('5R;"`@("`@("`M
M+2`@55),('1O(&QI;FL@=&AE(&YO9&4@=&\*("`@("`J('5R;&-L87-S("`M
M+2`@0U-3(&-L87-S(&9O<B!T:&4@;F]D92=S(%523`H@("`@("H@=&%R9V5T
M("`@("TM("!487)G970@9F]R('1H92`G=7)L)R!L:6YK"B`@("`@*B`\+W!R
M93X*("`@("`J+PH@("`@9G5N8W1I;VX@861D3F]D95!A<F%M<R@D:60L("1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH
M)'!A<F%M<RDI('L*("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"1P87)A
M;7,I.PH@("`@("`@('T*"B`@("`@("`@)&%L;&]W960@/2!A<G)A>2@*("`@
M("`@("`@("`@)V-L87-S)RP@)VEC;VXG+"`G:6-O;F%L="<L("=I8V]N9&ER
M)RP@)VEC;VYO<&5N)RP*("`@("`@("`@("`@)V]N8VQI8VLG+"`G=7)L)RP@
M)W5R;&-L87-S)RP@)W1A<F=E="<L"B`@("`@("`@*3L*"B`@("`@("`@9F]R
M96%C:"`H)'!A<F%M<R!A<R`D<&%R86U?:60@/3X@)'!A<F%M7W9A;"D@>PH@
M("`@("`@("`@("`O*B!3970@;VYL>2!A;&QO=V5D(&%N9"!N;VXM;G5L;"!P
M87)A;7,N("HO"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D<&%R86U?:60L
M("1A;&QO=V5D*2`F)B`A:7-?;G5L;"@D<&%R86U?=F%L*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R1P87)A;5]I9%T@/2`D<&%R
M86U?=F%L.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@061D<R!E>'1R82!C;VQU;6YS('1O(&)E(&1I<W!L87EE9"!T
M;R!T:&4@<VED92!O9B!T:&4@;F]D92X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@("`D:60@("`@(%1H92!U;FEQ=64@;F]D92!I9"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1S:61E("`@5VAI8V@@<VED92!T;R!P;&%C92!T:&4@
M97AT<F$@8V]L=6UN<R!O;BX*("`@("`J($!P87)A;2!A<G)A>2`@("1E>'1R
M82`@17AT<F$@8V]L=6UN<R!T;R!D:7-P;&%Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&1.;V1E17AT<F$H)&ED+"`D<VED92P@)&5X=')A*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?87)R87DH)&5X=')A*2D@>PH@("`@("`@("`@("`D
M97AT<F$@/2!A<G)A>2@D97AT<F$I.PH@("`@("`@('T*"B`@("`@("`@)&-O
M;%]C;W5N="`](&-O=6YT*"1E>'1R82D["@H@("`@("`@('-W:71C:"`H)'-I
M9&4I('L*("`@("`@("!C87-E($A/4D1%7U12145?15A44D%?3$5&5#H*("`@
M("`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=E>'1R82==6TA/4D1%7U12
M145?15A44D%?3$5&5%T@/2`D97AT<F$["B`@("`@("`@("`@(&EF("@D8V]L
M7V-O=6YT(#X@)'1H:7,M/E]E>'1R85]C;VQS7VQE9G0I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97AT<F%?8V]L<U]L969T(#T@)&-O;%]C;W5N=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92!(3U)$15]44D5%7T585%)!7U))1TA4.@H@("`@("`@("`@("`D=&AI<RT^
M7VYO9&5S6R1I9%U;)V5X=')A)UU;2$]21$5?5%)%15]%6%1205]224=(5%T@
M/2`D97AT<F$["B`@("`@("`@("`@(&EF("@D8V]L7V-O=6YT(#X@)'1H:7,M
M/E]E>'1R85]C;VQS7W)I9VAT*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V5X=')A7V-O;'-?<FEG:'0@/2`D8V]L7V-O=6YT.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-O<G1S('1H92!T<F5E(&)Y('1H92!S<&5C:69I960@;F]D92!P
M<F]P97)T>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<FET97)I
M82`@5&AE(&YO9&4@<')O<&5R='D@=&\@<V]R="!B>2X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I9"`@("`@("!5<V5D(&EN=&5R;F%L;'D@9F]R(')E8W5R
M<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R="@D8W)I=&5R:6$L("1I
M9"`]("TQ*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]N;V1E
M<ULD:61=6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&-R:71E<FEA(#T]("=K97DG*2!["B`@
M("`@("`@("`@(&MS;W)T*"1T:&ES+3Y?;F]D97-;)&ED75LG8VAI;&1R96XG
M72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S;W)T
M0W)I=&5R:6$@/2`D8W)I=&5R:6$["B`@("`@("`@("`@('5S;W)T*"1T:&ES
M+3Y?;F]D97-;)&ED75LG8VAI;&1R96XG72P@87)R87DH)'1H:7,L("=?<V]R
M="<I*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;F]D
M97-;)&ED75LG8VAI;&1R96XG72!A<R`D8VAI;&0I('L*("`@("`@("`@("`@
M)'1H:7,M/G-O<G0H)&-R:71E<FEA+"`D8VAI;&0I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($AE;'!E<B!M971H;V0@9F]R('-O<G0H*2!T
M;R!C;VUP87)E('1W;R!T<F5E(&5L96UE;G1S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<V]R="@D82P@
M)&(I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VYO9&5S6R1A
M75LD=&AI<RT^7W-O<G1#<FET97)I85TI*2!["B`@("`@("`@("`@(')E='5R
M;B`Q.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;F]D
M97-;)&)=6R1T:&ES+3Y?<V]R=$-R:71E<FEA72DI('L*("`@("`@("`@("`@
M<F5T=7)N("TQ.PH@("`@("`@('T*("`@("`@("!R971U<FX@<W1R8V]L;"@D
M=&AI<RT^7VYO9&5S6R1A75LD=&AI<RT^7W-O<G1#<FET97)I85TL"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N;V1E<ULD8EU;)'1H:7,M/E]S
M;W)T0W)I=&5R:6%=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=VAE=&AE<B!T:&4@<W!E8VEF:65D(&YO9&4@:7,@8W5R<F5N=&QY(&5X<&%N
M9&5D+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:60@(%1H92!U;FEQ
M=64@;F]D92!I9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE('-P96-I9FEE9"!N;V1E(&ES(&5X<&%N9&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<T5X<&%N9&5D*"1I9"D*("`@('L*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD:61=*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]N;V1E<ULD:61=6R=E>'!A;F1E9"==.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&1S(&-O;'5M;B!H96%D97)S('1O('1H92!T<F5E('1A8FQE+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D:&5A9&5R("!!;B!A<G)A>2!C;VYT
M86EN:6YG(&AA<VAE<R!W:71H(&AE861E<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&EN9F]R;6%T:6]N+B!4:&4@9F]L;&]W:6YG(&ME>7,@87)E
M(&%L;&]W960Z"B`@("`@*B`\<')E/@H@("`@("H@:'1M;"`@+2T@5&AE($A4
M34P@8V]N=&5N="!O9B!T:&4@:&5A9&5R(&-E;&P*("`@("`J('=I9'1H("TM
M(%1H92!W:61T:"!O9B!T:&4@:&5A9&5R(&-E;&P*("`@("`J(&%L:6=N("TM
M(%1H92!A;&EG;FUE;G0@:6YS:61E('1H92!H96%D97(@8V5L;`H@("`@("H@
M8VQA<W,@+2T@5&AE($-34R!C;&%S<R!O9B!T:&4@:&5A9&5R(&-E;&P*("`@
M("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!S971(96%D97(H)&AE
M861E<BD*("`@('L*("`@("`@("`D=&AI<RT^7VAE861E<B`]("1H96%D97([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&EN9&5N="!L979E;"!F
M;W(@96%C:"!N;V1E(&EN('1H92!T<F5E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8G5I;&1);F1E;G1S*"1N;V1E<RP@)&EN9&5N="`](#`I"B`@("!["B`@
M("`@("`@9F]R96%C:"`H)&YO9&5S(&%S("1I9"D@>PH@("`@("`@("`@("`D
M=&AI<RT^7VYO9&5S6R1I9%U;)VEN9&5N="==(#T@)&EN9&5N=#L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N
M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V)U:6QD26YD96YT<R@D
M=&AI<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N)UTL("1I;F1E;G0@*R`Q*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O07)R87DN<&AP````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$W,3(S`#$P-#$W,S8R-S<S`#`R,#`R-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($AO<F1E7T%R<F%Y.CH@8VQA<W,@<')O=FED97,@=F%R:6]U<R!M971H;V1S
M(&9O<B!A<G)A>2!M86YI<'5L871I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U5T:6PO07)R87DN<&AP+'8@,2XR-BXR+C@@,C`P-B\P,2\P,2`R,3HR
M.#HT,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO
M+F-O;3X*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`
M875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?571I;`H@*B\*8VQA
M<W,@2&]R9&5?07)R87D@>PH*("`@("\J*@H@("`@("H@4')E<&%R92!A(&QI
M<W0@;V8@861D<F5S<V5S(&9O<B!S=&]R86=E+@H@("`@("H@3F%M96QY+"!T
M<FEM<R!A;F0@;&]W97)C87-E<R!A;&P@861D<F5S<V5S(&%N9"!T:&5N('-O
M<G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A9&1R("!4:&4@;&ES
M="!O9B!A9&1R97-S97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE(&QI<W0@;V8@861D<F5S<V5S+"!P<F5P87)E9"!F;W(@<W1O<F%G92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<')E<&%R94%D9')E<W-,:7-T*"1A9&1R
M*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!A;GD@97AT<F$@<W!A8V4@:6X@
M=&AE(&%D9')E<W,@86YD(&UA:V4@:70@;&]W97)C87-E+B`J+PH@("`@("`@
M("1A9&1R(#T@87)R87E?;6%P*"=T<FEM)RP@)&%D9'(I.PH@("`@("`@("1A
M9&1R(#T@87)R87E?;6%P*&%R<F%Y*"=3=')I;F<G+"`G;&]W97(G*2P@)&%D
M9'(I.PH*("`@("`@("`O*B!296UO=F4@9'5P;&EC871E(&5N=')I97,N("HO
M"B`@("`@("`@)&%D9'(@/2!A<G)A>5]U;FEQ=64H)&%D9'(I.PH*("`@("`@
M("`O*B!3;W)T('1H92!L:7-T+B`J+PH@("`@("`@('5S;W)T*"1A9&1R+"!A
M<G)A>2@G2&]R9&5?07)R87DG+"`G<V]R=$%D9')E<W-,:7-T)RDI.PH*("`@
M("`@("!R971U<FX@)&%D9'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!U<V5D(&)Y('5S;W)T*"D@=&\@<V]R="!A;B!A9&1R97-S(&QI<W0N
M"B`@("`@*B!E+F<N('5S;W)T*"1F;V\L(&%R<F%Y*"=(;W)D95]!<G)A>2<L
M("=S;W)T061D<F5S<TQI<W0G*2D["B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D82`@061D<F5S<R`C,2X*("`@("`J($!P87)A;2!S=')I;F<@)&(@
M($%D9')E<W,@(S(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`M
M,2P@,"P@;W(@,2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$%D9')E<W-,
M:7-T*"1A+"`D8BD*("`@('L*("`@("`@("`D82`](&5X<&QO9&4H)T`G+"`D
M82D["B`@("`@("`@)&(@/2!E>'!L;V1E*"=`)RP@)&(I.PH*("`@("`@("`O
M*B!/;F4@;V8@=&AE(&%D9')E<W-E<R!D;V5S;B=T(&AA=F4@82!H;W-T(&YA
M;64N("HO"B`@("`@("`@:68@*&5M<'1Y*"1A6S!=*2D@>PH@("`@("`@("`@
M("!A<G)A>5]S:&EF="@D82D["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D8ELP72DI('L*("`@("`@("`@("`@87)R87E?<VAI9G0H)&(I.PH@("`@
M("`@('T*("`@("`@("!I9B`H8V]U;G0H)&$I("$](&-O=6YT*"1B*2D@>PH@
M("`@("`@("`@("!R971U<FX@*&-O=6YT*"1A*2`^(&-O=6YT*"1B*2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!4:&4@861D<F5S<V5S(&AA=F4@9&EF9F5R
M96YT(&AO<W1N86UE(&]R(&YO="!H;W-T;F%M92!A;F0*("`@("`@("`@("!D
M:69F97)E;G0@;6%I;&)O>"!N86UE<RX@*B\*("`@("`@("!I9B`H)&%;*&-O
M=6YT*"1A*2`M(#$I72`A/2`D8ELH8V]U;G0H)&(I("T@,2E=*2!["B`@("`@
M("`@("`@(')E='5R;B!S=')C;7`H)&%;*&-O=6YT*"1A*2`M(#$I72P@)&);
M*&-O=6YT*"1B*2`M(#$I72D["B`@("`@("`@?0H*("`@("`@("`O*B!#;VUP
M87)E(&UA:6QB;W@@;F%M97,N("HO"B`@("`@("`@<F5T=7)N('-T<F-M<"@D
M85LP72P@)&);,%TI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R=',@86X@
M87)R87D@;VX@82!S<&5C:69I960@:V5Y+B!)9B!T:&4@:V5Y(&1O97,@;F]T
M(&5X:7-T+`H@("`@("H@9&5F875L=',@=&\@=&AE(&9I<G-T(&ME>2!O9B!T
M:&4@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D87)R87D@
M("`@("`@5&AE(&%R<F%Y('1O(&)E('-O<G1E9"P@<&%S<V5D(&)Y(')E9F5R
M96YC92X*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("`@("`@(%1H92!K
M97D@8GD@=VAI8V@@=&\@<V]R="X@268@;F]T('-P96-I9FEE9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE;B!T:&4@9FER<W0@:V5Y
M(&ES('5S960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("!3
M;W)T(&1I<F5C=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#`@/2!A<V-E;F1I;F<@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@,2`](&1E<V-E;F1I;F<*("`@("`J($!P87)A
M;2!B;V]L96%N("1A<W-O8VEA=&4@($ME97`@:V5Y('9A;'5E(&%S<V]C:6%T
M:6]N/PH@("`@("HO"B`@("!F=6YC=&EO;B!A<G)A>5-O<G0H)B1A<G)A>2P@
M)&ME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P+"`D87-S;V-I871E(#T@=')U
M92D*("`@('L*("`@("`@("`O*B!2971U<FX@:68@=&AE(&%R<F%Y(&ES(&5M
M<'1Y+B`J+PH@("`@("`@(&EF("AE;7!T>2@D87)R87DI*2!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($EF(&YO(&ME>2!T
M;R!S;W)T(&)Y(&ES('-P96-I9FEE9"P@=7-E('1H92!F:7)S="!K97DN("HO
M"B`@("`@("`@:68@*&ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)&ME
M>7,@/2!A<G)A>5]K97ES*&5A8V@H)&%R<F%Y*2D["B`@("`@("`@("`@("1K
M97D@/2`D:V5Y<ULP73L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T
M:&4@9G5N8W1I;VX@=&AA="!W:6QL(&)E('5S960@=&\@<V]R="!T:&4@:V5Y
M<RX@*B\*("`@("`@("!I9B`H)&1I<F5C=&EO;BD@>PH@("`@("`@("`@("`D
M9G5N8W1I;VX@/2!S<')I;G1F*"=R971U<FX@<W1R8V]L;"A3=')I;F<Z.FQO
M=V5R*"1B6UPG)3$D<UPG72P@=')U92DL(%-T<FEN9SHZ;&]W97(H)&%;7"<E
M,21S7"==+"!T<G5E*2D[)RP@)&ME>2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&9U;F-T:6]N(#T@<W!R:6YT9B@G<F5T=7)N('-T<F-O;&PH
M4W1R:6YG.CIL;W=E<B@D85M<)R4Q)'-<)UTL('1R=64I+"!3=')I;F<Z.FQO
M=V5R*"1B6UPG)3$D<UPG72P@=')U92DI.R<L("1K97DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0V%L;"!T:&4@87!P<F]P<FEA=&4@<V]R="!F=6YC=&EO
M;BX@*B\*("`@("`@("!I9B`H)&%S<V]C:6%T92D@>PH@("`@("`@("`@("!U
M87-O<G0H)&%R<F%Y+"!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L("1F=6YC
M=&EO;BDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5S;W)T*"1A
M<G)A>2P@8W)E871E7V9U;F-T:6]N*"<D82P@)&(G+"`D9G5N8W1I;VXI*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A;B!(5$U,
M('1Y<&4@87)R87D@9FEE;&0@(F5X86UP;&5;:V5Y,5U;:V5Y,EU;:V5Y,UTB
M(&)R96%K<R!U<`H@("`@("H@=&AE(&ME>7,@<V\@=&AA="!T:&5Y(&-O=6QD
M(&)E('5S960@=&\@<F5F97)E;F-E(&$@<F5G=6QA<B!02%`@87)R87DN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@(%1H92!F:65L9"!N
M86UE('1O(&)E(&5X86UI;F5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&)A
M<V4@(%-E="!T;R!T:&4@8F%S92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("8D:V5Y<R`@(%-E="!T;R!T:&4@;&ES="!O9B!K97ES+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-E<W,L(&9A;'-E
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!<G)A>5!A<G1S
M*"1F:65L9"P@)B1B87-E+"`F)&ME>7,I"B`@("!["B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)WPH6UY<6UTJ*2@H7%M;7EQ;7%U=*EQ=*2LI?"<L("1F:65L
M9"P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("1B87-E(#T@)&UA=&-H97-;
M,5T["B`@("`@("`@("`@("1K97ES(#T@97AP;&]D92@G75LG+"`D;6%T8VAE
M<ULR72D["B`@("`@("`@("`@("1K97ES6S!=(#T@<W5B<W1R*"1K97ES6S!=
M+"`Q*3L*("`@("`@("`@("`@)&ME>7-;8V]U;G0H)&ME>7,I("T@,5T@/2!S
M=6)S='(H)&ME>7-;8V]U;G0H)&ME>7,I("T@,5TL(#`L('-T<FQE;B@D:V5Y
M<UMC;W5N="@D:V5Y<RD@+2`Q72D@+2`Q*3L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5S:6YG(&%N
M(&%R<F%Y(&]F(&ME>7,@:71A<F%T92!T:')O=6=H('1H92!A<G)A>2!F;VQL
M;W=I;F<@=&AE"B`@("`@*B!K97ES('1O(&9I;F0@=&AE(&9I;F%L(&ME>2!V
M86QU92X@268@82!V86QU92!I<R!P87-S960@=&AE;B!S970*("`@("`J('1H
M870@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D87)R87D@
M(%1H92!A<G)A>2!T;R!B92!U<V5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D
M:V5Y<R`@(%1H92!K97D@<&%T:"!T;R!F;VQL;W<@87,@86X@87)R87DN"B`@
M("`@*B!`<&%R86T@87)R87D@)'9A;'5E("`@268@<V5T('1H92!T87)G970@
M96QE;65N="!W:6QL(&AA=F4@=&AI<R!V86QU92!S970*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!T;R!I="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@9FEN86P@=F%L=64@;V8@=&AE(&ME>2!P871H+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971%;&5M96YT*"8D87)R87DL("8D:V5Y<RP@
M)'9A;'5E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)&ME>7,I
M*2!["B`@("`@("`@("`@("1K97D@/2!A<G)A>5]S:&EF="@D:V5Y<RD["B`@
M("`@("`@("`@(&EF("AI<W-E="@D87)R87E;)&ME>5TI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@2&]R9&5?07)R87DZ.F=E=$5L96UE;G0H)&%R<F%Y
M6R1K97E=+"`D:V5Y<RP@)'9A;'5E*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D=F%L
M=64I*2!["B`@("`@("`@("`@("`@("`D87)R87D@/2`D=F%L=64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1A<G)A>3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5C=&%N9VQE(&]F
M(&$@='=O+61I;65N<VEO;F%L(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`F)&%R<F%Y("`@(%1H92!A<G)A>2!T;R!E>'1R86-T('1H92!R
M96-T86YG;&4@9G)O;2X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@("`@
M(%1H92!S=&%R="!R;W<@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C;VP@("`@(%1H92!S=&%R="!C;VQU;6X@;V8@=&AE(')E
M8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H
M96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!E>'1R86-T960@<F5C=&%N9VQE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4F5C=&%N9VQE*"8D87)R87DL
M("1R;W<L("1C;VPL("1H96EG:'0L("1W:61T:"D*("`@('L*("`@("`@("`D
M<F5C(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1Y(#T@)')O=SL@)'D@/"`D
M<F]W("L@)&AE:6=H=#L@)'DK*RD@>PH@("`@("`@("`@("`D<F5C6UT@/2!A
M<G)A>5]S;&EC92@D87)R87E;)'E=+"`D8V]L+"`D=VED=&@I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)')E8SL*("`@('T*"B`@("`O*BH*("`@("`J
M($=I=F5N(&%N(&%R<F%Y+"!R971U<FYS(&%N(&%S<V]C:6%T:79E(&%R<F%Y
M('=I=&@@96%C:"!E;&5M96YT(&ME>0H@("`@("H@9&5R:79E9"!F<F]M(&ET
M<R!V86QU92X*("`@("`J($9O<B!E>&%M<&QE.@H@("`@("H@("!A<G)A>2@P
M(#T^("=F;V\G+"`Q(#T^("=B87(G*0H@("`@("H@=V]U;&0@8F5C;VUE.@H@
M("`@("H@("!A<G)A>2@G9F]O)R`]/B`G9F]O)RP@)V)A<B<@/3X@)V)A<B<I
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A>2`@06X@87)R87D@
M;V8@=F%L=65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R
M<F%Y('=I=&@@:V5Y<R!T:&4@<V%M92!A<R!V86QU97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('9A;'5E<U1O2V5Y<R@D87)R87DI"B`@("!["B`@("`@("`@
M)&UA<'!E9"`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S
M("1V86QU92D@>PH@("`@("`@("`@("`D;6%P<&5D6R1V86QU95T@/2`D=F%L
M=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;6%P<&5D.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A;B!A<G)A>2!B>2!U<VEN9R!O;F4@
M87)R87D@9F]R(&ME>7,@86YD(&%N;W1H97(@9F]R"B`@("`@*B!I=',@=F%L
M=65S+B!/;FQY(&5X:7-T<R!I;B!02%`U+"!S;R!W92!C86QL(&%R<F%Y7V-O
M;6)I;F4@:68@:70*("`@("`J(&5X:7-T<R!A;F0@;W1H97)W:7-E(&5M=6QA
M=&4@:70N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1K97ES("`@($ME
M>2!A<G)A>2X*("`@("`J($!P87)A;2!A<G)A>2`D=F%L=65S("!686QU92!A
M<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&86QS92!I9B!T
M:&5R92!A<F4@;F\@96QE;65N=',L(&]R('1H92!C;VUB:6YE9"!A<G)A>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V]M8FEN92@D:V5Y<RP@)'9A;'5E<RD*
M("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=A<G)A>5]C;VUB
M:6YE)RDI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7V-O;6)I;F4H)&ME
M>7,L("1V86QU97,I.PH@("`@("`@('T*"B`@("`@("`@)'-I>F4@/2!C;W5N
M="@D:V5Y<RD["B`@("`@("`@:68@*"@D<VEZ92`A/2!C;W5N="@D=F%L=65S
M*2D@?'P@*"1S:7IE(#T](#`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)'@@/2`P.R`D>"`\("1S:7IE
M.R`D>"LK*2!["B`@("`@("`@("`@("1A<G)A>5LD:V5Y<ULD>%U=(#T@)'9A
M;'5E<ULD>%T["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D87)R87D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-T<FEN9RYP:'``````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-#<Q-@`Q,#0Q-S,V,C<W,P`P
M,C`R,C4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"B1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72`]
M("=I<V\M.#@U.2TQ)SL*"B\J*@H@*B!4:&4@4W1R:6YG.CH@8VQA<W,@<')O
M=FED97,@<W1A=&EC(&UE=&AO9',@9F]R(&-H87)S970@86YD(&QO8V%L92!S
M869E"B`J('-T<FEN9R!M86YI<'5L871I;VXN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U5T:6PO4W1R:6YG+G!H<"QV(#$N-#,N-BXQ,R`R,#`V+S`S+S$S
M(#`Y.C0V.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?571I;`H@
M*B\*8VQA<W,@4W1R:6YG('L*"B`@("`O*BH*("`@("`J($-A8VAE<R!T:&4@
M<F5S=6QT(&]F(&5X=&5N<VEO;E]L;V%D960H*2!C86QL<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1E>'0@(%1H92!E>'1E;G-I;VX@;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($ES('1H92!E>'1E;G-I
M;VX@;&]A9&5D/PH@("`@("H*("`@("`J($!S964@571I;#HZ97AT96YS:6]N
M17AI<W1S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@97AT96YS:6]N17AI<W1S
M*"1E>'0I"B`@("!["B`@("`@("`@<W1A=&EC("1C86-H92`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@A:7-S970H)&-A8VAE6R1E>'1=*2D@>PH@("`@("`@
M("`@("`D8V%C:&5;)&5X=%T@/2!E>'1E;G-I;VY?;&]A9&5D*"1E>'0I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C86-H95LD97AT73L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E=',@82!D969A=6QT(&-H87)S970@=&AA="!T
M:&4@4W1R:6YG.CH@;65T:&]D<R!W:6QL('5S92!I9B!N;VYE(&ES"B`@("`@
M*B!E>'!L:6-I=&5L>2!S<&5C:69I960N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E(&%S('1H92!D
M969A=6QT(&]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5F875L=$-H
M87)S970H)&-H87)S970I"B`@("!["B`@("`@("`@)$=,3T)!3%-;)U](3U)$
M15]35%))3D=?0TA!4E-%5"==(#T@)&-H87)S970["B`@("`@("`@:68@*%-T
M<FEN9SHZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I("8F"B`@("`@("`@
M("`@(&9U;F-T:6]N7V5X:7-T<R@G;6)?<F5G97A?96YC;V1I;F<G*2D@>PH@
M("`@("`@("`@("!`;6)?<F5G97A?96YC;V1I;F<H)&-H87)S970I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@<W1R:6YG
M(&9R;VT@;VYE(&-H87)S970@=&\@86YO=&AE<BX*("`@("`J"B`@("`@*B!7
M;W)K<R!O;FQY(&EF(&5I=&AE<B!T:&4@:6-O;G8@;W(@=&AE(&UB<W1R:6YG
M(&5X=&5N<VEO;@H@("`@("H@87)E('!R97-E;G0@86YD(&)E<W0@:68@8F]T
M:"!A<F4@879A:6QA8FQE+@H@("`@("H@5&AE(&]R:6=I;F%L('-T<FEN9R!I
M<R!R971U<FYE9"!I9B!C;VYV97)S:6]N(&9A:6QE9"!O<B!N;VYE"B`@("`@
M*B!O9B!T:&4@97AT96YS:6]N<R!W97)E(&%V86EL86)L92X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&EN<'5T("!4:&4@9&%T82!T;R!B92!C;VYV
M97)T960N($EF("1I;G!U="!I<R!A;B!A;B!A<G)A>2P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@('1H92!A<G)A>2=S('9A;'5E<R!G970@8V]N=F5R
M=&5D(')E8W5R<VEV96QY+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9G)O;2`@
M5&AE('-T<FEN9R=S(&-U<G)E;G0@8VAA<G-E="X*("`@("`J($!P87)A;2!S
M=')I;F<@)'1O("`@(%1H92!C:&%R<V5T('1O(&-O;G9E<G0@=&AE('-T<FEN
M9R!T;RX@268@;F]T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!S<&5C
M:69I960L('1H92!G;&]B86P@=F%R:6%B;&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("1?2$]21$5?4U1224Y'7T-(05)3150@=VEL;"!B92!U<V5D
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=F5R=&5D
M('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=$-H87)S970H
M)&EN<'5T+"`D9G)O;2P@)'1O(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!'
M970@=&AE('5S97(G<R!D969A=6QT(&-H87)A8W1E<B!S970@:68@;F]N92!P
M87-S960@:6XN("HO"B`@("`@("`@:68@*&ES7VYU;&PH)'1O*2D@>PH@("`@
M("`@("`@("`D=&\@/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54
M)UT["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&4@9G)O;2!A;F0@=&\@
M8VAA<F%C=&5R('-E=',@87)E(&ED96YT:6-A;"P@<F5T=7)N(&YO=RX@*B\*
M("`@("`@("`D9G)O;2`](%-T<FEN9SHZ;&]W97(H)&9R;VTI.PH@("`@("`@
M("1T;R`](%-T<FEN9SHZ;&]W97(H)'1O*3L*("`@("`@("!I9B`H)&9R;VT@
M/3T@)'1O*2!["B`@("`@("`@("`@(')E='5R;B`D:6YP=70["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-?87)R87DH)&EN<'5T*2D@>PH@("`@("`@("`@
M("`D=&UP(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&EN<'5T
M(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'1M<%M3=')I
M;F<Z.E]C;VYV97)T0VAA<G-E="@D:V5Y+"`D9G)O;2P@)'1O*5T@/2!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86PL("1F<F]M+"`D=&\I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-?;V)J96-T*"1I;G!U="DI('L*("`@("`@("`@("`@)'9A
M<G,@/2!G971?;V)J96-T7W9A<G,H)&EN<'5T*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)'9A<G,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@
M("`D:6YP=70M/B1K97D@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86PL
M("1F<F]M+"`D=&\I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B`D:6YP=70["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W-T<FEN9R@D
M:6YP=70I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YP=70["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@4W1R:6YG.CI?8V]N=F5R=$-H87)S970H)&EN
M<'5T+"`D9G)O;2P@)'1O*3L*("`@('T*"B`@("`O*BH*("`@("`J($EN=&5R
M;F%L(&9U;F-T:6]N('5S960@=&\@9&\@8VAA<G-E="!C;VYV97)S:6]N+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D:6YP=70@(%-E92!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T
M*"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1F<F]M("!3964@4W1R:6YG.CIC
M;VYV97)T0VAA<G-E="@I+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@("`@
M4V5E(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H*2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&-O;G9E<G1E9"!S=')I;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;VYV97)T0VAA<G-E="@D:6YP=70L("1F<F]M+"`D
M=&\I"B`@("!["B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("`O*B!5
M<V4@=71F.%];96Y\9&5=8V]D92@I(&EF('!O<W-I8FQE+B`J+PH@("`@("`@
M("1F<F]M7V-H96-K(#T@*"@D9G)O;2`]/2`G:7-O+3@X-3DM,2<I('Q\("@D
M9G)O;2`]/2`G=7,M87-C:6DG*2D["B`@("`@("`@:68@*"1F<F]M7V-H96-K
M("8F("@D=&\@/3T@)W5T9BTX)RDI('L*("`@("`@("`@("`@<F5T=7)N('5T
M9CA?96YC;V1E*"1I;G!U="D["B`@("`@("`@?0H*("`@("`@("`D=&]?8VAE
M8VL@/2`H*"1T;R`]/2`G:7-O+3@X-3DM,2<I('Q\("@D=&\@/3T@)W5S+6%S
M8VEI)RDI.PH@("`@("`@(&EF("@H)&9R;VT@/3T@)W5T9BTX)RD@)B8@)'1O
M7V-H96-K*2!["B`@("`@("`@("`@(')E='5R;B!U=&8X7V1E8V]D92@D:6YP
M=70I.PH@("`@("`@('T*"B`@("`@("`@+RH@1FER<W0@=')Y(&EC;VYV('=I
M=&@@=')A;G-L:71E<F%T:6]N+B`J+PH@("`@("`@(&EF("@H)&9R;VT@(3T@
M)W5T9C<M:6UA<"<I("8F"B`@("`@("`@("`@("@D=&\@(3T@)W5T9C<M:6UA
M<"<I("8F"B`@("`@("`@("`@(%-T<FEN9SHZ97AT96YS:6]N17AI<W1S*"=I
M8V]N=B<I*2!["B`@("`@("`@("`@("\J(%=E(&YE960@=&\@=&%C:R!A;B!E
M>'1R82!C:&%R86-T97(@=&5M<&]R87)I;'D@8F5C875S90H@("`@("`@("`@
M("`@*B!O9B!A(&)U9R!I;B!I8V]N=B@I(&EF('1H92!L87-T(&-H87)A8W1E
M<B!I<R!N;W0@82`W"B`@("`@("`@("`@("`J(&)I="!!4T-)22!C:&%R86-T
M97(N("HO"B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I
M.PH@("`@("`@("`@("`D;W5T<'5T(#T@0&EC;VYV*"1F<F]M+"`D=&\@+B`G
M+R]44D%.4TQ)5"<L("1I;G!U="`N("=X)RD["B`@("`@("`@("`@("1O=71P
M=70@/2`H:7-S970H)'!H<%]E<G)O<FUS9RDI(#\@9F%L<V4@.B`@4W1R:6YG
M.CIS=6)S='(H)&]U='!U="P@,"P@+3$L("1T;RD["B`@("`@("`@("`@(&EN
M:5]R97-T;W)E*"=T<F%C:U]E<G)O<G,G*3L*("`@("`@("!]"@H@("`@("`@
M("\J($YE>'0@=')Y(&UB<W1R:6YG+B`J+PH@("`@("`@(&EF("@A)&]U='!U
M="`F)B!3=')I;F<Z.F5X=&5N<VEO;D5X:7-T<R@G;6)S=')I;F<G*2D@>PH@
M("`@("`@("`@("`D;W5T<'5T(#T@0&UB7V-O;G9E<G1?96YC;V1I;F<H)&EN
M<'5T+"`D=&\L("1F<F]M*3L*("`@("`@("!]"@H@("`@("`@("\J($%T(&QA
M<W0@=')Y(&EM87!?=71F-U];96Y\9&5=8V]D92!I9B!A<'!R;W!R:6%T92X@
M*B\*("`@("`@("!I9B`H(21O=71P=70@)B8@4W1R:6YG.CIE>'1E;G-I;VY%
M>&ES=',H)VEM87`G*2D@>PH@("`@("`@("`@("!I9B`H)&9R;VU?8VAE8VL@
M)B8@*"1T;R`]/2`G=71F-RUI;6%P)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!`:6UA<%]U=&8W7V5N8V]D92@D:6YP=70I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@H)&9R;VT@/3T@)W5T9C<M:6UA<"<I("8F("1T
M;U]C:&5C:RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N($!I;6%P7W5T9C=?
M9&5C;V1E*"1I;G!U="D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`H(21O=71P=70I(#\@)&EN<'5T(#H@)&]U='!U=#L*("`@
M('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@<W1R:6YG(&QO=V5R8V%S92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<W1R:6YG("`@5&AE('-T
M<FEN9R!T;R!B92!C;VYV97)T960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M;&]C86QE("`@268@=')U92!T:&4@<W1R:6YG('=I;&P@8F4@8V]N=F5R=&5D
M(&)A<V5D(&]N(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!G
M:79E;B!C:&%R<V5T+"!L;V-A;&4@:6YD97!E;F1E;G0@96QS92X*("`@("`J
M($!P87)A;2!S=')I;F<@("1C:&%R<V5T("!)9B`D;&]C86QE(&ES('1R=64L
M('1H92!C:&%R<V5T('1O('5S92!W:&5N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=F5R=&EN9RX@268@;F]T('!R;W9I9&5D('1H92!C
M=7)R96YT(&-H87)S970N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!S=')I;F<@=VET:"!L;W=E<F-A<V4@8VAA<F%C=&5R<PH@("`@("HO
M"B`@("!F=6YC=&EO;B!L;W=E<B@D<W1R:6YG+"`D;&]C86QE(#T@9F%L<V4L
M("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&QO=V5R
M<SL*"B`@("`@("`@:68@*"1L;V-A;&4I('L*("`@("`@("`@("`@+RH@5&AE
M(&5X:7-T96YC92!O9B!M8E]S=')T;VQO=V5R*"D@9&5P96YD<R!O;B!T:&4@
M<&QA=&9O<FTN("HO"B`@("`@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N<VEO
M;D5X:7-T<R@G;6)S=')I;F<G*2`F)@H@("`@("`@("`@("`@("`@9G5N8W1I
M;VY?97AI<W1S*"=M8E]S=')T;VQO=V5R)RDI('L*("`@("`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1C:&%R<V5T(#T@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E="`]($!M
M8E]S=')T;VQO=V5R*"1S=')I;F<L("1C:&%R<V5T*3L*("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)')E="DI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)')E=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@<W1R=&]L;W=E<B@D<W1R:6YG*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A:7-S970H)&QO=V5R<RDI('L*("`@("`@("`@
M("`@)&QO=V5R<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)&QO=V5R<ULD<W1R:6YG72DI('L*("`@("`@("`@("`@)&QA;F=U
M86=E(#T@<V5T;&]C86QE*$Q#7T-465!%+"`P*3L*("`@("`@("`@("`@<V5T
M;&]C86QE*$Q#7T-465!%+"`G96Y?55,G*3L*("`@("`@("`@("`@)&QO=V5R
M<ULD<W1R:6YG72`]('-T<G1O;&]W97(H)'-T<FEN9RD["B`@("`@("`@("`@
M('-E=&QO8V%L92A,0U]#5%E012P@)&QA;F=U86=E*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;&]W97)S6R1S=')I;F==.PH@("`@?0H*("`@("\J
M*@H@("`@("H@36%K97,@82!S=')I;F<@=7!P97)C87-E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("1S=')I;F<@("!4:&4@<W1R:6YG('1O(&)E
M(&-O;G9E<G1E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1L;V-A;&4@("!)
M9B!T<G5E('1H92!S=')I;F<@=VEL;"!B92!C;VYV97)T960@8F%S960@;VX@
M80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&=I=F5N(&-H87)S
M970L(&QO8V%L92!I;F1E<&5N9&5N="!E;'-E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&-H87)S970@($EF("1L;V-A;&4@:7,@=')U92P@=&AE(&-H87)S
M970@=&\@=7-E('=H96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYV97)T:6YG+B!)9B!N;W0@<')O=FED960@=&AE(&-U<G)E;G0@8VAA
M<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN
M9R!W:71H('5P<&5R8V%S92!C:&%R86-T97)S"B`@("`@*B\*("`@(&9U;F-T
M:6]N('5P<&5R*"1S=')I;F<L("1L;V-A;&4@/2!F86QS92P@)&-H87)S970@
M/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D=7!P97)S.PH*("`@("`@
M("!I9B`H)&QO8V%L92D@>PH@("`@("`@("`@("`O*B!4:&4@97AI<W1E;F-E
M(&]F(&UB7W-T<G1O=7!P97(H*2!D97!E;F1S(&]N('1H90H@("`@("`@("`@
M("`@*B!P;&%T9F]R;2X@*B\*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X
M:7-T<R@G;6)?<W1R=&]U<'!E<B<I*2!["B`@("`@("`@("`@("`@("!I9B`H
M:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("`@("`D8VAA
M<G-E="`]("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R970@/2!`;6)?<W1R
M=&]U<'!E<B@D<W1R:6YG+"`D8VAA<G-E="D["B`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1R970I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1R970["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N('-T<G1O=7!P97(H)'-T<FEN9RD["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(6ES<V5T*"1U<'!E<G,I*2!["B`@("`@("`@("`@("1U
M<'!E<G,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T
M*"1U<'!E<G-;)'-T<FEN9UTI*2!["B`@("`@("`@("`@("1L86YG=6%G92`]
M('-E=&QO8V%L92A,0U]#5%E012P@,"D["B`@("`@("`@("`@('-E=&QO8V%L
M92A,0U]#5%E012P@)V5N7U53)RD["B`@("`@("`@("`@("1U<'!E<G-;)'-T
M<FEN9UT@/2!S=')T;W5P<&5R*"1S=')I;F<I.PH@("`@("`@("`@("!S971L
M;V-A;&4H3$-?0U194$4L("1L86YG=6%G92D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'5P<&5R<ULD<W1R:6YG73L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!S=')I;F<@=VET:"!T:&4@9FER<W0@;&5T=&5R(&-A
M<&ET86QI>F5D(&EF(&ET(&ES"B`@("`@*B!A;'!H86)E=&EC+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@("1S=')I;F<@("!4:&4@<W1R:6YG('1O
M(&)E(&-A<&ET86QI>F5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8V%L
M92`@($EF('1R=64@=&AE('-T<FEN9R!W:6QL(&)E(&-O;G9E<G1E9"!B87-E
M9"!O;B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9VEV96X@
M8VAA<G-E="P@;&]C86QE(&EN9&5P96YD96YT(&5L<V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E+"!D969A
M=6QT<R!T;R!C=7)R96YT(&-H87)S970N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!C87!I=&%L:7IE9"!S=')I;F<N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('5C9FER<W0H)'-T<FEN9RP@)&QO8V%L92`](&9A;'-E+"`D
M8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1L;V-A;&4I('L*
M("`@("`@("`@("`@)&9I<G-T(#T@4W1R:6YG.CIS=6)S='(H)'-T<FEN9RP@
M,"P@,2P@)&-H87)S970I.PH@("`@("`@("`@("!I9B`H4W1R:6YG.CII<T%L
M<&AA*"1F:7)S="P@)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`D<W1R
M:6YG(#T@4W1R:6YG.CIU<'!E<B@D9FER<W0L('1R=64L("1C:&%R<V5T*2`N
M(%-T<FEN9SHZ<W5B<W1R*"1S=')I;F<L(#$L(&YU;&PL("1C:&%R<V5T*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S
M=')I;F<@/2!3=')I;F<Z.G5P<&5R*'-U8G-T<B@D<W1R:6YG+"`P+"`Q*2P@
M9F%L<V4I("X@<W5B<W1R*"1S=')I;F<L(#$I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'-T<FEN9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@<&%R="!O9B!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S=')I;F<@("!4:&4@<W1R:6YG('1O(&)E(&-O;G9E<G1E9"X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@(%1H92!P87)T)W,@<W1A<G0@
M<&]S:71I;VXL('IE<F\@8F%S960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M;&5N9W1H("!4:&4@<&%R="=S(&QE;F=T:"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&-H87)S970@(%1H92!C:&%R<V5T('1O('5S92!W:&5N(&-A;&-U;&%T
M:6YG('1H92!P87)T)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('!O<VET:6]N(&%N9"!L96YG=&@L(&1E9F%U;'1S('1O(&-U<G)E;G0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-H87)S970N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=')I;F<G<R!P87)T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S=6)S='(H)'-T<FEN9RP@)'-T87)T+"`D;&5N
M9W1H(#T@;G5L;"P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("A3=')I;F<Z.F5X=&5N<VEO;D5X:7-T<R@G;6)S=')I;F<G*2D@>PH@("`@
M("`@("`@("!I9B`H:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@
M("`@("1C:&%R<V5T(#T@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%
M5"==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1L
M96YG=&@I*2!["B`@("`@("`@("`@("`@("`D;&5N9W1H(#T@4W1R:6YG.CIL
M96YG=&@H)'-T<FEN9RP@)&-H87)S970I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1R970@/2!`;6)?<W5B<W1R*"1S=')I;F<L("1S=&%R="P@)&QE
M;F=T:"P@)&-H87)S970I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1R970I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H:7-?;G5L;"@D;&5N9W1H*2D@>PH@
M("`@("`@("`@("`D;&5N9W1H(#T@4W1R:6YG.CIL96YG=&@H)'-T<FEN9RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=6)S='(H)'-T<FEN9RP@)'-T
M87)T+"`D;&5N9W1H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&-H87)A8W1E<B`H;F]T(&)Y=&4I(&QE;F=T:"!O9B!A('-T<FEN9RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@(%1H92!S=')I
M;F<@=&\@<F5T=7)N('1H92!L96YG=&@@;V8N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C:&%R<V5T(%1H92!C:&%R<V5T('1O('5S92!W:&5N(&-A;&-U;&%T
M:6YG('1H92!S=')I;F<G<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!L96YG=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S
M=')I;F<G<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L96YG=&@H)'-T
M<FEN9RP@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N
M=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]("1'3$]"
M04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G73L*("`@("`@("!]"B`@("`@
M("`@)&-H87)S970@/2!3=')I;F<Z.FQO=V5R*"1C:&%R<V5T*3L*("`@("`@
M("!I9B`H)&-H87)S970@/3T@)W5T9BTX)R!\?"`D8VAA<G-E="`]/2`G=71F
M."<I('L*("`@("`@("`@("`@<F5T=7)N('-T<FQE;BAU=&8X7V1E8V]D92@D
M<W1R:6YG*2D["B`@("`@("`@?0H@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N
M<VEO;D5X:7-T<R@G;6)S=')I;F<G*2D@>PH@("`@("`@("`@("`D<F5T(#T@
M0&UB7W-T<FQE;B@D<W1R:6YG+"`D8VAA<G-E="D["B`@("`@("`@("`@(&EF
M("@A96UP='DH)')E="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5T
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=')L
M96XH)'-T<FEN9RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N=6UE<FEC('!O<VET:6]N(&]F('1H92!F:7)S="!O8V-U<G)E;F-E(&]F
M("1N965D;&4*("`@("`J(&EN('1H92`D:&%Y<W1A8VL@<W1R:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&AA>7-T86-K("!4:&4@<W1R:6YG
M('1O('-E87)C:"!T:')O=6=H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5E
M9&QE("`@(%1H92!S=')I;F<@=&\@<V5A<F-H(&9O<BX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1O9F9S970@("!!;&QO=W,@=&\@<W!E8VEF>2!W:&EC:"!C
M:&%R86-T97(@:6X@:&%Y<W1A8VL*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!T;R!S=&%R="!S96%R8VAI;F<N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C:&%R<V5T("`@5&AE(&-H87)S970@=&\@=7-E('=H96X@<V5A<F-H
M:6YG(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F5E9&QE('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M(%1H92!P;W-I=&EO;B!O9B!F:7)S="!O8V-U<G)E;F-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P;W,H)&AA>7-T86-K+"`D;F5E9&QE+"`D;V9F<V5T(#T@
M,"P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("A3=')I;F<Z
M.F5X=&5N<VEO;D5X:7-T<R@G;6)S=')I;F<G*2D@>PH@("`@("`@("`@("!I
M9B`H:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("1C:&%R
M<V5T(#T@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L
M(#$I.PH@("`@("`@("`@("`D<F5T(#T@0&UB7W-T<G!O<R@D:&%Y<W1A8VLL
M("1N965D;&4L("1O9F9S970L("1C:&%R<V5T*3L*("`@("`@("`@("`@:6YI
M7W)E<W1O<F4H)W1R86-K7V5R<F]R<R<I.PH@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1P:'!?97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)')E=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M<W1R<&]S*"1H87ES=&%C:RP@)&YE961L92P@)&]F9G-E="D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG('!A9&1E9"!T;R!A(&-E
M<G1A:6X@;&5N9W1H('=I=&@@86YO=&AE<B!S=')I;F<N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@8F5H879E<R!E>&%C=&QY(&QI:V4@<W1R7W!A9"!B
M=70@:7,@;75L=&EB>71E('-A9F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:6YP=70@("`@5&AE('-T<FEN9R!T;R!B92!P861D960N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;&5N9W1H("!4:&4@;&5N9W1H(&]F('1H92!R
M97-U;'1I;F<@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%D("`@
M("`@5&AE('-T<FEN9R!T;R!P860@=&AE(&EN<'5T('-T<FEN9R!W:71H+B!-
M=7-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!B92!I;B!T:&4@
M<V%M92!C:&%R<V5T(&QI:V4@=&AE(&EN<'5T('-T<FEN9RX*("`@("`J($!P
M87)A;2!C;VYS="`D='EP92`@("`@(%1H92!P861D:6YG('1Y<&4N($]N92!O
M9B!35%)?4$%$7TQ%1E0L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!35%)?4$%$7U))1TA4+"!O<B!35%)?4$%$7T)/5$@N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!O9B!T:&4@:6YP=70@
M86YD('1H92!P861D:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')I;F=S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M<&%D9&5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<&%D*"1I;G!U
M="P@)&QE;F=T:"P@)'!A9"`]("<@)RP@)'1Y<&4@/2!35%)?4$%$7U))1TA4
M+`H@("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@
M("`@("`D;6)?;&5N9W1H(#T@4W1R:6YG.CIL96YG=&@H)&EN<'5T+"`D8VAA
M<G-E="D["B`@("`@("`@)'-B7VQE;F=T:"`]('-T<FQE;B@D:6YP=70I.PH@
M("`@("`@("1P861?;&5N9W1H(#T@4W1R:6YG.CIL96YG=&@H)'!A9"P@)&-H
M87)S970I.PH*("`@("`@("`O*B!2971U<FX@:68@=V4@86QR96%D>2!H879E
M('1H92!L96YG=&@N("HO"B`@("`@("`@:68@*"1M8E]L96YG=&@@/CT@)&QE
M;F=T:"D@>PH@("`@("`@("`@("!R971U<FX@)&EN<'5T.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4VAO<G1C=70@9F]R('-I;F=L92!B>71E('-T<FEN9W,N
M("HO"B`@("`@("`@:68@*"1M8E]L96YG=&@@/3T@)'-B7VQE;F=T:"`F)B`D
M<&%D7VQE;F=T:"`]/2!S=')L96XH)'!A9"DI('L*("`@("`@("`@("`@<F5T
M=7)N('-T<E]P860H)&EN<'5T+"`D;&5N9W1H+"`D<&%D+"`D='EP92D["B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@8V%S
M92!35%)?4$%$7TQ%1E0Z"B`@("`@("`@("`@("1L969T(#T@)&QE;F=T:"`M
M("1M8E]L96YG=&@["B`@("`@("`@("`@("1O=71P=70@/2!3=')I;F<Z.G-U
M8G-T<BAS=')?<F5P96%T*"1P860L(&-E:6PH)&QE9G0@+R`D<&%D7VQE;F=T
M:"DI+"`P+"`D;&5F="P@)&-H87)S970I("X@)&EN<'5T.PH@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!C87-E(%-44E]0041?0D]42#H*("`@("`@("`@
M("`@)&QE9G0@/2!F;&]O<B@H)&QE;F=T:"`M("1M8E]L96YG=&@I("\@,BD[
M"B`@("`@("`@("`@("1R:6=H="`](&-E:6PH*"1L96YG=&@@+2`D;6)?;&5N
M9W1H*2`O(#(I.PH@("`@("`@("`@("`D;W5T<'5T(#T@4W1R:6YG.CIS=6)S
M='(H<W1R7W)E<&5A="@D<&%D+"!C96EL*"1L969T("\@)'!A9%]L96YG=&@I
M*2P@,"P@)&QE9G0L("1C:&%R<V5T*2`N"B`@("`@("`@("`@("`@("`D:6YP
M=70@+@H@("`@("`@("`@("`@("`@4W1R:6YG.CIS=6)S='(H<W1R7W)E<&5A
M="@D<&%D+"!C96EL*"1R:6=H="`O("1P861?;&5N9W1H*2DL(#`L("1R:6=H
M="P@)&-H87)S970I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E
M(%-44E]0041?4DE'2%0Z"B`@("`@("`@("`@("1R:6=H="`]("1L96YG=&@@
M+2`D;6)?;&5N9W1H.PH@("`@("`@("`@("`D;W5T<'5T(#T@)&EN<'5T("X@
M4W1R:6YG.CIS=6)S='(H<W1R7W)E<&5A="@D<&%D+"!C96EL*"1R:6=H="`O
M("1P861?;&5N9W1H*2DL(#`L("1R:6=H="P@)&-H87)S970I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)A<',@=&AE('1E>'0@;V8@82!M
M97-S86=E+@H@("`@("H*("`@("`J($!T;V1O($UA:V4@;75L=&EB>71E+7-A
M=F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("`@("`@
M4W1R:6YG(&-O;G1A:6YI;F<@=&AE('1E>'0@=&\@=W)A<"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1L96YG=&@@("`@(%=R87`@)'1E>'0@870@=&AI<R!N
M=6UB97(@;V8@8VAA<F%C=&5R<RX*("`@("`J($!P87)A;2!S=')I;F<@)&)R
M96%K7V-H87(@($-H87)A8W1E<BAS*2!T;R!U<V4@=VAE;B!B<F5A:VEN9R!L
M:6YE<RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@("`@($-H87)A
M8W1E<B!S970@=&\@=7-E('=H96X@8G)E86MI;F<@;&EN97,N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<75O=&4@("`@("!)9VYO<F4@;&EN97,@=&AA="!A
M<F4@=W)A<'!E9"!W:71H('1H92`G/B<*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-H87)A8W1E<B`H4D9#(#(V-#8I/R!)9B!T<G5E+"!W
M92!D;VXG=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5M
M;W9E(&%N>2!P861D:6YG('=H:71E<W!A8V4@870@=&AE(&5N9"!O9@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('-T<FEN9RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE('=R87!P960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)A<"@D
M=&5X="P@)&QE;F=T:"`](#@P+"`D8G)E86M?8VAA<B`](")<;B(L("1C:&%R
M<V5T(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@)'%U;W1E(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@)'!A<F%G<F%P:',@/2!A<G)A>2@I.PH*("`@("`@
M("!F;W)E86-H("AP<F5G7W-P;&ET*"<O7'(_7&XO)RP@)'1E>'0I(&%S("1I
M;G!U="D@>PH@("`@("`@("`@("!I9B`H)'%U;W1E("8F("AS=')P;W,H)&EN
M<'5T+"`G/B<I(#T]/2`P*2D@>PH@("`@("`@("`@("`@("`@)&QI;F4@/2`D
M:6YP=70["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O
M*B!792!N965D('1O(&AA;F1L92!T:&4@57-E;F5T+7-T>6QE('-I9VYA='5R
M92!L:6YE"B`@("`@("`@("`@("`@("`@*B!S97!A<F%T96QY.R!S:6YC92!T
M:&4@<W!A8V4@869T97(@=&AE('1W;R!D87-H97,@:7,*("`@("`@("`@("`@
M("`@("`J(%)%455)4D5$+"!W92!D;VXG="!W86YT('1O('1R:6T@=&AE(&QI
M;F4N("HO"B`@("`@("`@("`@("`@("!I9B`H)&EN<'5T("$]("<M+2`G*2![
M"B`@("`@("`@("`@("`@("`@("`@)&EN<'5T(#T@<G1R:6TH)&EN<'5T*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1L:6YE(#T@=V]R
M9'=R87`H)&EN<'5T+"`D;&5N9W1H+"`D8G)E86M?8VAA<BD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1P87)A9W)A<&AS6UT@/2`D;&EN93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!I;7!L;V1E*"1B<F5A:U]C:&%R+"`D
M<&%R86=R87!H<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R
M=64@:68@=&AE(&5V97)Y(&-H87)A8W1E<B!I;B!T:&4@<&%R86UE=&5R(&ES
M(&%N"B`@("`@*B!A;'!H86)E=&EC(&-H87)A8W1E<BX@5&AI<R!M971H;V0@
M9&]E<VXG="!W;W)K('=I=&@@86YY(&-H87)S970*("`@("`J(&]T:&5R('1H
M86X@=&AE(&-U<G)E;G0@8VAA<G-E="!Y970N"B`@("`@*@H@("`@("H@0'!A
M<F%M("1S=')I;F<@("!4:&4@<W1R:6YG('1O('1E<W0N"B`@("`@*B!`<&%R
M86T@)&-H87)S970@(%1H92!C:&%R<V5T('1O('5S92!W:&5N('1E<W1I;F<@
M=&AE('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE('!A<F%M971E<B!W87,@86QP:&%B971I8R!O;FQY+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<T%L<&AA*"1S=')I;F<L("1C:&%R<V5T(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H4W1R:6YG.CIE>'1E;G-I;VY%>&ES
M=',H)VUB<W1R:6YG)RDI('L*("`@("`@("`@("`@)&]L9%]C:&%R<V5T(#T@
M;6)?<F5G97A?96YC;V1I;F<H*3L*("`@("`@("`@("`@:68@*"1C:&%R<V5T
M("$]("1O;&1?8VAA<G-E="D@>PH@("`@("`@("`@("`@("`@0&UB7W)E9V5X
M7V5N8V]D:6YG*"1C:&%R<V5T*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D86QP:&$@/2`A;6)?97)E9U]M871C:"@G6UY;.F%L<&AA.EU=)RP@)'-T
M<FEN9RD["B`@("`@("`@("`@(&EF("@D8VAA<G-E="`A/2`D;VQD7V-H87)S
M970I('L*("`@("`@("`@("`@("`@($!M8E]R96=E>%]E;F-O9&EN9R@D;VQD
M7V-H87)S970I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D
M86QP:&$["B`@("`@("`@?0H*("`@("`@("!R971U<FX@8W1Y<&5?86QP:&$H
M)'-T<FEN9RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@
M:68@979E<GD@8VAA<F%C=&5R(&EN('1H92!P87)A;65T97(@:7,@82!L;W=E
M<F-A<V4*("`@("`J(&QE='1E<B!I;B!T:&4@8W5R<F5N="!L;V-A;&4N"B`@
M("`@*@H@("`@("H@0'!A<F%M("1S=')I;F<@("!4:&4@<W1R:6YG('1O('1E
M<W0N"B`@("`@*B!`<&%R86T@)&-H87)S970@(%1H92!C:&%R<V5T('1O('5S
M92!W:&5N('1E<W1I;F<@=&AE('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('!A<F%M971E<B!W87,@;&]W97)C
M87-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<TQO=V5R*"1S=')I;F<L("1C
M:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@*"A3=')I;F<Z
M.FQO=V5R*"1S=')I;F<L('1R=64L("1C:&%R<V5T*2`]/3T@)'-T<FEN9RD@
M)B8*("`@("`@("`@("`@("`@(%-T<FEN9SHZ:7-!;'!H82@D<W1R:6YG+"`D
M8VAA<G-E="DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T<G5E
M(&EF(&5V97)Y(&-H87)A8W1E<B!I;B!T:&4@<&%R86UE=&5R(&ES(&%N"B`@
M("`@*B!U<'!E<F-A<V4@;&5T=&5R(&EN('1H92!C=7)R96YT(&QO8V%L92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@("!4:&4@<W1R
M:6YG('1O('1E<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4
M:&4@8VAA<G-E="!T;R!U<V4@=VAE;B!T97-T:6YG('1H92!S=')I;F<N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!P87)A
M;65T97(@=V%S('5P<&5R8V%S92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-5
M<'!E<B@D<W1R:6YG+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@
M<F5T=7)N("@H4W1R:6YG.CIU<'!E<B@D<W1R:6YG+"!T<G5E+"`D8VAA<G-E
M="D@/3T]("1S=')I;F<I("8F"B`@("`@("`@("`@("`@("!3=')I;F<Z.FES
M06QP:&$H)'-T<FEN9RP@)&-H87)S970I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%!E<F9O<FUS(&$@;75L=&EB>71E('-A9F4@<F5G97@@;6%T8V@@<V5A
M<F-H(&]N('1H92!T97AT('!R;W9I9&5D+@H@("`@("H*("`@("`J($!S:6YC
M92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT
M("`@("!4:&4@=&5X="!T;R!S96%R8V@N"B`@("`@*B!`<&%R86T@87)R87D@
M)')E9V5X("`@("!4:&4@<F5G=6QA<B!E>'!R97-S:6]N<R!T;R!U<V4L('=I
M=&AO=70@<&5R;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<F5G
M97@@9&5L:6UI=&5R<R`H92YG+B`G+R<@;W(@)WPG*2X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@<V5T(&]F('1H92!T
M97AT+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!M871C:&5S
M(&%R<F%Y(&9R;VT@=&AE(&9I<G-T(')E9V5X('1H870@;6%T8VAE<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5G97A-871C:"@D=&5X="P@)')E9V5X+"`D
M8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D8VAA
M<G-E="DI('L*("`@("`@("`@("`@)')E9V5X(#T@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D<F5G97@L("1C:&%R<V5T+"`G=71F+3@G*3L*("`@("`@("`@
M("`@)'1E>'0@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1T97AT+"`D8VAA
M<G-E="P@)W5T9BTX)RD["B`@("`@("`@?0H*("`@("`@("`D;6%T8VAE<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)')E9V5X(&%S("1V86PI('L*
M("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\G("X@)'9A;"`N("<O=2<L
M("1T97AT+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C
M:&%R<V5T*2D@>PH@("`@("`@("`@("`D;6%T8VAE<R`](%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H)&UA=&-H97,L("=U=&8M."<L("1C:&%R<V5T*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;6%T8VAE<SL*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]5=&EL+G!H
M<```````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C8V
M,C<`,3`T,3<S-C(W-S,`,#$W-S`Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@HO*BH*("H@17)R;W(@8V]D92!F
M;W(@82!M:7-S:6YG(&1R:79E<B!C;VYF:6=U<F%T:6]N+@H@*B\*9&5F:6YE
M*"=(3U)$15]%4E)/4E]$4DE615)?0T].1DE'7TU)4U-)3D<G+"`Q*3L*"B\J
M*@H@*B!%<G)O<B!C;V1E(&9O<B!A;B!I;F-O;7!L971E(&1R:79E<B!C;VYF
M:6=U<F%T:6]N+@H@*B\*9&5F:6YE*"=(3U)$15]%4E)/4E]$4DE615)?0T].
M1DE')RP@,BD["@HO*BH*("H@5&AE(%5T:6PZ.B!C;&%S<R!P<F]V:61E<R!G
M96YE<F%L;'D@=7-E9G5L(&UE=&AO9',@;V8@9&EF9F5R96YT(&MI;F1S+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP+'8@,2XS.#0N
M-BXQ-2`R,#`V+S`S+S(X(#$R.C,Q.C$R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A
M<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E($AO<F1E7U5T:6P*("HO"F-L87-S(%5T:6P@>PH*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A;B!O8FIE8W0G<R!C;&]N92X*("`@("`J"B`@
M("`@*B!`<&%R86T@;V)J96-T("8D;V)J("!4:&4@;V)J96-T('1O(&-L;VYE
M+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!4:&4@8VQO;F5D(&]B
M:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F-L;VYE3V)J96-T*"8D;V)J
M*0H@("`@>PH@("`@("`@("\J($-L;VYI;F<@9&]E<R`J;F]T*B!C=7)R96YT
M;'D@=V]R:R!I9B!U<VEN9R!02%`@-2X*("`@("`@("`@*B!4:&ES(&ES(&$@
M:VYO=VX@4$A0(&ES<W5E.B!H='1P.B\O8G5G<RYP:'`N;F5T+V)U9RYP:'`_
M:60],C<R-C@*("`@("`@("`@*B!4:&5R969O<F4L('=O<FL@87)O=6YD('1H
M:7,@:7-S=64@8GD@=7-I;F<@=&AE(%!(4"`T"B`@("`@("`@("H@<V5R:6%L
M:7IE+W5N<V5R:6%L:7IE(&-L;VYE(&AA8VLN("HO"B`@("`@("`@+RH*("`@
M("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R<VEO;B@I+"`G,B<L
M("<^)RDI('L*("`@("`@("`@("`@<F5T=7)N(&-L;VYE*"1O8FHI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1N97=/8FH@/2`D;V)J.PH@("`@
M("`@("`@("!R971U<FX@)&YE=T]B:CL*("`@("`@("!]"B`@("`@("`@*B\*
M("`@("`@("`D<F5T(#T@=6YS97)I86QI>F4H<V5R:6%L:7IE*"1O8FHI*3L*
M("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O*BH*("`@("`J($)U
M9F9E<G,@=&AE(&]U='!U="!F<F]M(&$@9G5N8W1I;VX@8V%L;"P@;&EK92!R
M96%D9FEL92@I(&]R"B`@("`@*B!H:6=H;&EG:'1?<W1R:6YG*"DL('1H870@
M<')I;G1S('1H92!O=71P=70@9&ER96-T;'DL('-O('1H870@:6YS=&5A9"!I
M=`H@("`@("H@8V%N(&)E(')E='5R;F5D(&%S(&$@<W1R:6YG(&%N9"!U<V5D
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9U;F-T:6]N("!4:&4@
M9G5N8W1I;VX@=&\@<G5N+@H@("`@("H@0'!A<F%M(&UI>&5D("1A<F<Q("`@
M("`@($9I<G-T(&%R9W5M96YT('1O("1F=6YC=&EO;B@I+@H@("`@("H@0'!A
M<F%M(&UI>&5D("1A<F<R("`@("`@(%-E8V]N9"!A<F=U;65N="!T;R`D9G5N
M8W1I;VXH*2X*("`@("`J($!P87)A;2!M:7AE9"`D87)G+BXN("`@("`N+BX*
M("`@("`J($!P87)A;2!M:7AE9"`D87)G3B`@("`@("!.=&@@87)G=6UE;G0@
M=&\@)&9U;F-T:6]N*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!O=71P=70@;V8@=&AE(&9U;F-T:6]N+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!B=69F97)/=71P=70H*0H@("`@>PH@("`@("`@(&EF("AF=6YC7VYU
M;5]A<F=S*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@("1I;F-L=61E(#T@9F%L<V4["B`@("`@("`@)&%R
M9W,@/2!F=6YC7V=E=%]A<F=S*"D["B`@("`@("`@)&9U;F-T:6]N(#T@87)R
M87E?<VAI9G0H)&%R9W,I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D9G5N8W1I
M;VXI*2!["B`@("`@("`@("`@(&EF("@A:7-?8V%L;&%B;&4H)&9U;F-T:6]N
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E:68@*"@D9G5N8W1I;VX@/3T@)VEN8VQU9&4G
M*2!\?`H@("`@("`@("`@("`@("`@("`H)&9U;F-T:6]N(#T]("=I;F-L=61E
M7V]N8V4G*2!\?`H@("`@("`@("`@("`@("`@("`H)&9U;F-T:6]N(#T]("=R
M97%U:7)E)RD@?'P*("`@("`@("`@("`@("`@("`@*"1F=6YC=&EO;B`]/2`G
M<F5Q=6ER95]O;F-E)RDI('L*("`@("`@("`@("`@)&EN8VQU9&4@/2!T<G5E
M.PH@("`@("`@('T@96QS96EF("@A9G5N8W1I;VY?97AI<W1S*"1F=6YC=&EO
M;BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@;V)?<W1A<G0H*3L*("`@("`@("!I9B`H)&EN8VQU9&4I('L*("`@
M("`@("`@("`@)&9I;&4@/2!I;7!L;V1E*"<L)RP@)&%R9W,I.PH@("`@("`@
M("`@("!S=VET8V@@*"1F=6YC=&EO;BD@>PH@("`@("`@("`@("!C87-E("=I
M;F-L=61E)SH*("`@("`@("`@("`@("`@(&EN8VQU9&4@)&9I;&4["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VEN8VQU9&5?
M;VYC92<Z"B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@)&9I;&4["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W)E<75I
M<F4G.@H@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL93L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G<F5Q=6ER95]O;F-E
M)SH*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`D9FEL93L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F-?87)R87DH)&9U;F-T:6]N
M+"`D87)G<RD["B`@("`@("`@?0H@("`@("`@("1O=71P=70@/2!O8E]G971?
M8V]N=&5N=',H*3L*("`@("`@("!O8E]E;F1?8VQE86XH*3L*"B`@("`@("`@
M<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@
M=&\@<V5E(&EF(&$@=F%L=64@:&%S(&)E96X@<V5T(&)Y('1H92!S8W)I<'0@
M86YD(&YO="!B>2!'150L"B`@("`@*B!03U-4+"!O<B!C;V]K:64@:6YP=70N
M(%1H92!V86QU92!B96EN9R!C:&5C:V5D($U54U0@8F4@:6X@=&AE(&=L;V)A
M;`H@("`@("H@<V-O<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=F%R;F%M92`@5&AE('9A<FEA8FQE(&YA;64@=&\@8VAE8VLN"B`@("`@*B!`
M<&%R86T@;6EX960@)&1E9F%U;'0@("!$969A=6QT('9A;'5E(&EF('1H92!V
M87)I86)L92!I<VXG="!P<F5S96YT"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!O<B!W87,@<W!E8VEF:65D(&)Y('1H92!U<V5R+B!$969A=6QT
M<R!T;R!N=6QL+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@0'-I
M;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!R971U<FX@;6EX960@("1D
M969A=6QT(&EF('1H92!V87(@:7,@:6X@=7-E<B!I;G!U="!O<B!N;W0@<')E
M<V5N="P*("`@("`J("`@("`@("`@("`@("`@('1H92!V87)I86)L92!V86QU
M92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO;DEN<'5T5F%R
M*"1V87)N86UE+"`D9&5F875L="`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES<V5T*"1?1T546R1V87)N86UE72D@?'P*("`@("`@("`@("`@:7-S970H
M)%]03U-46R1V87)N86UE72D@?'P*("`@("`@("`@("`@:7-S970H)%]#3T]+
M245;)'9A<FYA;65=*2D@>PH@("`@("`@("`@("!R971U<FX@)&1E9F%U;'0[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1'
M3$]"04Q36R1V87)N86UE72D@/R`D1TQ/0D%,4ULD=F%R;F%M95T@.B`D9&5F
M875L=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@
M;F%M93UV86QU92!P86ER('1O('1H92!E;F0@;V8@86X@55),+"!T86MI;F<@
M8V%R92!O9B!W:&5T:&5R"B`@("`@*B!T:&5R92!A<F4@97AI<W1I;F<@<&%R
M86UE=&5R<R!A;F0@=VAE=&AE<B!T;R!U<V4@/RP@)B!O<B`F86UP.R!A<R!T
M:&4*("`@("`J(&=L=64N("!!;&P@9&%T82!W:6QL(&)E('5R;&5N8V]D960N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("`@(%1H92!5
M4DP@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M971E<B`@
M16ET:&5R('1H92!N86UE/79A;'5E('!A:7(@=&\@861D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@*$1%4%)%0T%4140I("UO<BT*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;F%M92!V86QU92`M;W(M
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@86X@87)R87D@;V8@
M;F%M92]V86QU92!P86ER<RX*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E
M("`@("!)9B!S<&5C:69I960L('1H92!V86QU92!P87)T("@D<&%R86UE=&5R
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE;B!A<W-U
M;65D('1O(&IU<W0@8F4@=&AE('!A<F%M971E<B!N86UE*2X*("`@("`J($!P
M87)A;2!B;V]L96%N("1E;F-O9&4@("!)9B!T<G5E+"!A;F0@=V4@9&]N)W0@
M:&%V92!A<F=U;65N="!S97!A<F%T;W)S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@>65T+"!T:&4@87)G=6UE;G0@<V5P87)A=&]R(&=E=',@
M96YC;V1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO
M9&EF:65D(%523"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&%R86UE=&5R
M*"1U<FPL("1P87)A;65T97(L("1V86QU92`](&YU;&PL("1E;F-O9&4@/2!T
M<G5E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<&%R86UE=&5R*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'5R;#L*("`@("`@("!]"@H@("`@("`@("\J
M($UA:V4@<W5R92!T;R!H879E(&%N(&%R<F%Y+B`J+PH@("`@("`@(&EF("@A
M:7-?87)R87DH)'!A<F%M971E<BDI('L*("`@("`@("`@("`@)&%D9"`](&%R
M<F%Y*"1P87)A;65T97(@/3X@)'9A;'5E*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D861D(#T@)'!A<F%M971E<CL*("`@("`@("!]"@H@("`@
M("`@("1A<F<@/2`D96YC;V1E(#\@)R9A;7`[)R`Z("<F)SL*("`@("`@("!I
M9B`H*"1P;W,@/2!S=')P;W,H)'5R;"P@)S\G*2D@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@("1G;'5E(#T@)S\G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\J($-H96-K(&EF('1H92!A<F=U;65N="!S97!A<F%T;W(@:&%S
M(&)E96X@86QR96%D>0H@("`@("`@("`@("`@*B!H=&UL96YT:71I97,M:7IE
M9"!I;B!T:&4@55),+B`J+PH@("`@("`@("`@("`D<75E<GD@/2!S=6)S='(H
M)'5R;"P@)'!O<R`K(#$I.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+STN*C\F86UP.RXJ/STO)RP@)'%U97)Y*2D@>PH@("`@("`@("`@("`@("`@
M)&%R9R`]("<F86UP.R<["B`@("`@("`@("`@("`@("`D<75E<GD@/2!S=')T
M<B@D<75E<GDL(&%R<F%Y7V9L:7`H9V5T7VAT;6Q?=')A;G-L871I;VY?=&%B
M;&4H2%1-3%]%3E1)5$E%4RDI*3L*("`@("`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R\]+BH_)BXJ/STO)RP@)'%U97)Y*2D@>PH@("`@("`@("`@
M("`@("`@)&%R9R`]("<F)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<&%I<G,@/2!E>'!L;V1E*"1A<F<L("1Q=65R>2D["B`@("`@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<&%I<G,@
M87,@)'!A:7(I('L*("`@("`@("`@("`@("`@("1P86ER(#T@97AP;&]D92@G
M/2<L("1P86ER+"`R*3L*("`@("`@("`@("`@("`@("1P87)A;7-;)'!A:7);
M,%U=(#T@8V]U;G0H)'!A:7(I(#T](#(@/R`D<&%I<ELQ72`Z("<G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1G;'5E(#T@)&%R9SL*("`@("`@("!]
M"@H@("`@("`@("1U<FQ?<&%R86US(#T@87)R87DH*3L*("`@("`@("!F;W)E
M86-H("@D861D(&%S("1P87)A;65T97(@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@(&EF("@A:7-S970H)'!A<F%M<ULD<&%R86UE=&5R72DI('L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1V86PI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'5R;%]P87)A;7-;72`]('5R;&5N8V]D92@D<&%R
M86UE=&5R*2`N("=;73TG("X@=7)L96YC;V1E*"1V86PI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'5R;%]P87)A;7-;72`]('5R;&5N8V]D92@D<&%R86UE
M=&5R*2`N("<])R`N('5R;&5N8V]D92@D=F%L=64I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U
M;G0H)'5R;%]P87)A;7,I*2!["B`@("`@("`@("`@(')E='5R;B`D=7)L("X@
M)&=L=64@+B!I;7!L;V1E*"1A<F<L("1U<FQ?<&%R86US*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'5R;#L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&YA;64]=F%L=64@<&%I<G,@
M9G)O;2!A(%523"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@
M("`@5&AE(%523"!T;R!M;V1I9GDN"B`@("`@*B!`<&%R86T@;6EX960@)')E
M;6]V92`@16ET:&5R(&$@<VEN9VQE('!A<F%M971E<B!T;R!R96UO=F4@;W(@
M86X@87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O9B!P87)A
M;65T97)S('1O(')E;6]V92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&UO9&EF:65D(%523"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M
M;W9E4&%R86UE=&5R*"1U<FPL("1R96UO=F4I"B`@("!["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<F5M;W9E*2D@>PH@("`@("`@("`@("`D<F5M;W9E(#T@
M87)R87DH)')E;6]V92D["B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@
M:6UM961I871E;'D@:68@=&AE<F4@87)E(&YO('!A<F%M971E<G,@=&\@<F5M
M;W9E+B`J+PH@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D=7)L+"`G/R<I
M*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("1U<FP["B`@("`@
M("`@?0H*("`@("`@("`D96YT:71I97,@/2!F86QS93L*("`@("`@("!L:7-T
M*"1U<FPL("1Q=65R>2D@/2!E>'!L;V1E*"<_)RP@)'5R;"P@,BD["@H@("`@
M("`@("\J($-H96-K(&EF('1H92!A<F=U;65N="!S97!A<F%T;W(@:&%S(&)E
M96X@86QR96%D>0H@("`@("`@("`J(&AT;6QE;G1I=&EE<RUI>F5D(&EN('1H
M92!54DPN("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\]+BH_)F%M<#LN
M*C\]+R<L("1Q=65R>2DI('L*("`@("`@("`@("`@)&5N=&ET:65S(#T@=')U
M93L*("`@("`@("`@("`@)'%U97)Y(#T@<W1R='(H)'%U97)Y+"!A<G)A>5]F
M;&EP*&=E=%]H=&UL7W1R86YS;&%T:6]N7W1A8FQE*$A434Q?14Y4251)15,I
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(&QI<W0@;V8@<&%R
M86UE=&5R<RX@*B\*("`@("`@("`D<&%I<G,@/2!E>'!L;V1E*"<F)RP@)'%U
M97)Y*3L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("!F;W)E
M86-H("@D<&%I<G,@87,@)'!A:7(I('L*("`@("`@("`@("`@)'!A:7(@/2!E
M>'!L;V1E*"<])RP@)'!A:7(L(#(I.PH@("`@("`@("`@("`D<&%R86US6R1P
M86ER6S!=72`](&-O=6YT*"1P86ER*2`]/2`R(#\@)'!A:7);,5T@.B`G)SL*
M("`@("`@("!]"@H@("`@("`@("\J(%)E;6]V92!T:&4@<&%R86UE=&5R<RX@
M*B\*("`@("`@("!F;W)E86-H("@D<F5M;W9E(&%S("1P87)A;2D@>PH@("`@
M("`@("`@("!U;G-E="@D<&%R86US6R1P87)A;5TI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%C;W5N="@D<&%R86US*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'5R;#L*("`@("`@("!]"@H@("`@("`@("\J($9L871T96X@87)R87ES
M+@H@("`@("`@("`J($9)6$U%.B!S:&]U;&0@:&%N9&QE(&UO<F4@=&AA;B!O
M;F4@87)R87D@;&5V96P@<V]M96AO=RX@*B\*("`@("`@("`D861D(#T@87)R
M87DH*3L*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;"DI('L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1V86P@87,@)'8I('L*("`@("`@("`@("`@
M("`@("`@("`D861D6UT@/2`D:V5Y("X@)UM=/2<@+B`D=CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1A9&1;72`]("1K97D@+B`G/2<@+B`D=F%L.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D<75E<GD@/2!I;7!L;V1E*"<F)RP@)&%D9"D[
M"B`@("`@("`@:68@*"1E;G1I=&EE<RD@>PH@("`@("`@("`@("`D<75E<GD@
M/2!H=&UL96YT:71I97,H)'%U97)Y*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=7)L("X@)S\G("X@)'%U97)Y.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('5R;"!W:71H('1H92`G;F]C86-H92<@<&%R86UE=&5R
M(&%D9&5D+"!I9B!T:&4@8G)O=W-E<B!I<PH@("`@("H@8G5G9WD@86YD(&-A
M8VAE<R!O;&0@55),<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<FP@(%1H92!54DP@=&\@;6]D:69Y+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<F5Q=65S=&5D(%5222X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F]C86-H955R;"@D=7)L*0H@("`@>PH@("`@("`@('-T871I8R`D<F%N
M9%]N=6T["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0G)O=W-E<BYP
M:'`G.PH@("`@("`@("1B<F]W<V5R(#T@)D)R;W=S97(Z.G-I;F=L971O;B@I
M.PH*("`@("`@("`O*B!792!M87D@;F5E9"!T;R!S970@82!D=6UM>2!P87)A
M;65T97(@)VYO8V%C:&4G('-I;F-E('-O;64*("`@("`@("`@*B!B<F]W<V5R
M<R!D;R!N;W0@86QW87ES(&AO;F]R('1H92`G;F\M8V%C:&4G(&AE861E<BX@
M*B\*("`@("`@("!I9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=C86-H95]S86UE
M7W5R;"<I*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)')A;F1?;G5M*2D@
M>PH@("`@("`@("`@("`@("`@)')A;F1?;G5M(#T@8F%S95]C;VYV97)T*&UI
M8W)O=&EM92@I+"`Q,"P@,S8I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)VYO8V%C:&4G+"`D
M<F%N9%]N=6TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`D=7)L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!H:61D96X@9F]R;2!I;G!U="!C;VYT86EN:6YG('1H92!S97-S:6]N
M(&YA;64@86YD(&ED+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1A
M<'!E;F1?<V5S<VEO;B`@,"`](&]N;'D@:68@;F5E9&5D+"`Q(#T@86QW87ES
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@:&ED9&5N(&9O
M<FT@:6YP=70L(&EF(&YE961E9"]R97%U97-T960N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&9O<FU);G!U="@D87!P96YD7W-E<W-I;VX@/2`P*0H@("`@>PH@
M("`@("`@(&EF("@D87!P96YD7W-E<W-I;VX@/3T@,2!\?`H@("`@("`@("`@
M("`A:7-S970H)%]#3T]+245;<V5S<VEO;E]N86UE*"E=*2D@>PH@("`@("`@
M("`@("!R971U<FX@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B<@+B!H
M=&UL<W!E8VEA;&-H87)S*'-E<W-I;VY?;F%M92@I*2`N("<B('9A;'5E/2(G
M("X@:'1M;'-P96-I86QC:&%R<RAS97-S:6]N7VED*"DI("X@(EPB("\^7&XB
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<FEN=',@82!H:61D96X@
M9F]R;2!I;G!U="!C;VYT86EN:6YG('1H92!S97-S:6]N(&YA;64@86YD(&ED
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1A<'!E;F1?<V5S<VEO
M;B`@,"`](&]N;'D@:68@;F5E9&5D+"`Q(#T@86QW87ES+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P9F]R;4EN<'5T*"1A<'!E;F1?<V5S<VEO;B`](#`I"B`@
M("!["B`@("`@("`@96-H;R!5=&EL.CIF;W)M26YP=70H)&%P<&5N9%]S97-S
M:6]N*3L*("`@('T*"B`@("`O*BH*("`@("`J($EF(&UA9VEC7W%U;W1E<U]G
M<&,@:7,@:6X@=7-E+"!R=6X@<W1R:7!S;&%S:&5S*"D@;VX@)'9A<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D=F%R("!4:&4@<W1R:6YG('1O
M('5N+7%U;W1E+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@("1V87(L(&UI;G5S(&%N>2!M86=I8R!Q=6]T97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1I<W!E;$UA9VEC475O=&5S*"8D=F%R*0H@("`@
M>PH@("`@("`@('-T871I8R`D;6%G:6-?<75O=&5S.PH*("`@("`@("!I9B`H
M(6ES<V5T*"1M86=I8U]Q=6]T97,I*2!["B`@("`@("`@("`@("1M86=I8U]Q
M=6]T97,@/2!G971?;6%G:6-?<75O=&5S7V=P8R@I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1M86=I8U]Q=6]T97,I('L*("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D=F%R*2D@>PH@("`@("`@("`@("`@("`@)'9A<B`]('-T<FEP
M<VQA<VAE<R@D=F%R*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&%R<F%Y7W=A;&LH)'9A<BP@87)R87DH)U5T:6PG+"`G9&ES<&5L
M36%G:6-1=6]T97,G*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=F%R.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!A
M(&9O<FT@=F%R:6%B;&4@9G)O;2!'150@;W(@4$]35"!D871A+"!S=')I<'!E
M9"!O9B!M86=I8R!Q=6]T97,@:68*("`@("`J(&YE8V5S<V%R>2X@268@=&AE
M('9A<FEA8FQE(&ES('-O;65H;W<@<V5T(&EN(&)O=&@@=&AE($=%5"!D871A
M(&%N9"!T:&4*("`@("`J(%!/4U0@9&%T82P@=&AE('9A;'5E(&9R;VT@=&AE
M(%!/4U0@9&%T82!W:6QL(&)E(')E='5R;F5D(&%N9"!T:&4@1T54"B`@("`@
M*B!V86QU92!W:6QL(&)E(&EG;F]R960N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=F%R("`@("`@5&AE(&YA;64@;V8@=&AE(&9O<FT@=F%R:6%B
M;&4@=&\@;&]O:R!F;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D969A=6QT
M("!4:&4@=F%L=64@=&\@<F5T=7)N(&EF('1H92!V87)I86)L92!I<R!N;W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H97)E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8VQE86YE9"!F;W)M('9A<FEA
M8FQE+"!O<B`D9&5F875L="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F]R
M;41A=&$H)'9A<BP@)&1E9F%U;'0@/2!N=6QL*0H@("`@>PH@("`@("`@(')E
M='5R;B`H*"1V86P@/2!5=&EL.CIG9710;W-T*"1V87(I*2`A/3T@;G5L;"D*
M("`@("`@("`@("`@/R`D=F%L(#H@571I;#HZ9V5T1V5T*"1V87(L("1D969A
M=6QT*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@82!F;W)M('9A<FEA
M8FQE(&9R;VT@1T54(&1A=&$L('-T<FEP<&5D(&]F(&UA9VEC('%U;W1E<R!I
M9@H@("`@("H@;F5C97-S87)Y+B!4:&ES(&9U;F-T:6]N('=I;&P@3D]4(')E
M='5R;B!A(%!/4U0@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=F%R("`@("`@5&AE(&YA;64@;V8@=&AE(&9O<FT@=F%R:6%B;&4@
M=&\@;&]O:R!F;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D969A=6QT("!4
M:&4@=F%L=64@=&\@<F5T=7)N(&EF('1H92!V87)I86)L92!I<R!N;W0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H97)E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8VQE86YE9"!F;W)M('9A<FEA8FQE
M+"!O<B`D9&5F875L="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1V5T*"1V
M87(L("1D969A=6QT(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@*&ES
M<V5T*"1?1T546R1V87)=*2D*("`@("`@("`@("`@/R!5=&EL.CID:7-P96Q-
M86=I8U%U;W1E<R@D7T=%5%LD=F%R72D*("`@("`@("`@("`@.B`D9&5F875L
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@82!F;W)M('9A<FEA8FQE
M(&9R;VT@4$]35"!D871A+"!S=')I<'!E9"!O9B!M86=I8R!Q=6]T97,@:68*
M("`@("`J(&YE8V5S<V%R>2X@5&AI<R!F=6YC=&EO;B!W:6QL($Y/5"!R971U
M<FX@82!'150@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=F%R("`@("`@5&AE(&YA;64@;V8@=&AE(&9O<FT@=F%R:6%B;&4@=&\@
M;&]O:R!F;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D969A=6QT("!4:&4@
M=F%L=64@=&\@<F5T=7)N(&EF('1H92!V87)I86)L92!I<R!N;W0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@('1H97)E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@8VQE86YE9"!F;W)M('9A<FEA8FQE+"!O
M<B`D9&5F875L="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&]S="@D=F%R
M+"`D9&5F875L="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N("AI<W-E
M="@D7U!/4U1;)'9A<ETI*0H@("`@("`@("`@("`_(%5T:6PZ.F1I<W!E;$UA
M9VEC475O=&5S*"1?4$]35%LD=F%R72D*("`@("`@("`@("`@.B`D9&5F875L
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&QO8V%T
M:6]N(&]F('1H92!S>7-T96T@=&5M<&]R87)Y(&1I<F5C=&]R>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!D:7)E8W1O<GD@;F%M92!W:&EC
M:"!C86X@8F4@=7-E9"!F;W(@=&5M<"!F:6QE<RX*("`@("`J("`@("`@("`@
M("`@("`@("!2971U<FYS(&9A;'-E(&EF(&]N92!C;W5L9"!N;W0@8F4@9F]U
M;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1E;7!$:7(H*0H@("`@>PH@
M("`@("`@("\J($9I<G-T+"!T<GD@4$A0)W,@=7!L;V%D7W1M<%]D:7(@9&ER
M96-T:79E+B`J+PH@("`@("`@("1T;7`@/2!I;FE?9V5T*"=U<&QO861?=&UP
M7V1I<B<I.PH*("`@("`@("`O*B!/=&AE<G=I<V4L('1R>2!T;R!D971E<FUI
M;F4@=&AE(%1-4$1)4B!E;G9I<F]N;65N=`H@("`@("`@("`J('9A<FEA8FQE
M+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`D
M=&UP(#T@9V5T96YV*"=435!$25(G*3L*("`@("`@("!]"@H@("`@("`@("\J
M($EF('=E('-T:6QL(&-A;FYO="!D971E<FUI;F4@82!V86QU92P@=&AE;B!C
M>6-L92!T:')O=6=H(&$*("`@("`@("`@*B!L:7-T(&]F('!R97-E="!P;W-S
M:6)I;&ET:65S+B`J+PH@("`@("`@("1T;7!?;&]C871I;VYS(#T@87)R87DH
M)R]T;7`G+"`G+W9A<B]T;7`G+"`G8SI<5U5496UP)RP@)V,Z7'1E;7`G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V,Z7'=I;F1O=W-<=&5M
M<"<L("=C.EQW:6YN=%QT96UP)RD["B`@("`@("`@=VAI;&4@*&5M<'1Y*"1T
M;7`I("8F(&-O=6YT*"1T;7!?;&]C871I;VYS*2D@>PH@("`@("`@("`@("`D
M=&UP7V-H96-K(#T@87)R87E?<VAI9G0H)'1M<%]L;V-A=&EO;G,I.PH@("`@
M("`@("`@("!I9B`H0&ES7V1I<B@D=&UP7V-H96-K*2D@>PH@("`@("`@("`@
M("`@("`@)'1M<"`]("1T;7!?8VAE8VL["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J($EF(&ET(&ES('-T:6QL(&5M<'1Y+"!W92!H879E
M(&9A:6QE9"P@<V\@<F5T=7)N(&9A;'-E.PH@("`@("`@("`J(&]T:&5R=VES
M92!R971U<FX@=&AE(&1I<F5C=&]R>2!D971E<FUI;F5D+B`J+PH@("`@("`@
M(')E='5R;B!E;7!T>2@D=&UP*2`_(&9A;'-E(#H@)'1M<#L*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T97,@82!T96UP;W)A<GD@9FEL96YA;64@9F]R
M('1H92!L:69E=&EM92!O9B!T:&4@<V-R:7!T+"!A;F0*("`@("`J("AO<'1I
M;VYA;&QY*2!R96=I<W1E<B!I="!T;R!B92!D96QE=&5D(&%T(')E<75E<W0@
M<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9FEX
M("`@4')E9FEX('1O(&UA:V4@=&AE('1E;7!O<F%R>2!N86UE(&UO<F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(')E8V]G;FEZ86)L92X*("`@
M("`J($!P87)A;2!B;V]L96%N("1D96QE=&4@($1E;&5T92!T:&4@9FEL92!A
M="!T:&4@96YD(&]F('1H92!R97%U97-T/PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&ER("`@("`@1&ER96-T;W)Y('1O(&-R96%T92!T:&4@=&5M<&]R87)Y
M(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V5C=7)E("!)9B!D
M96QE=&EN9R!F:6QE+"!S:&]U;&0@=V4@<V5C=7)E;'D@9&5L971E('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9FEL93\*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@(%)E='5R;G,@=&AE(&9U;&P@<&%T:"UN
M86UE('1O('1H92!T96UP;W)A<GD@9FEL92X*("`@("`J("`@("`@("`@("`@
M("`@("`@4F5T=7)N<R!F86QS92!I9B!A('1E;7`@9FEL92!C;W5L9"!N;W0@
M8F4@8W)E871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&5M<$9I;&4H
M)'!R969I>"`]("<G+"`D9&5L971E(#T@=')U92P@)&1I<B`]("<G+"`D<V5C
M=7)E(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1D:7(I('Q\
M("%I<U]D:7(H)&1I<BDI('L*("`@("`@("`@("`@)'1M<%]D:7(@/2!5=&EL
M.CIG971496UP1&ER*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1M<%]D:7(@/2`D9&ER.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y
M*"1T;7!?9&ER*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D=&UP7V9I;&4@/2!T96UP;F%M*"1T;7!?9&ER+"`D
M<')E9FEX*3L*"B`@("`@("`@+RH@268@=&AE(&9I;&4@=V%S(&-R96%T960L
M('1H96X@<F5G:7-T97(@:70@9F]R(&1E;&5T:6]N(&%N9"!R971U<FX@*B\*
M("`@("`@("!I9B`H96UP='DH)'1M<%]F:6QE*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@
M*"1D96QE=&4I('L*("`@("`@("`@("`@("`@(%5T:6PZ.F1E;&5T94%T4VAU
M=&1O=VXH)'1M<%]F:6QE+"!T<G5E+"`D<V5C=7)E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)'1M<%]F:6QE.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!T96UP;W)A<GD@9&ER96-T
M;W)Y(&EN('1H92!S>7-T96TG<R!T96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1D96QE=&4@("!$96QE=&4@=&AE
M('1E;7!O<F%R>2!D:7)E8W1O<GD@870@=&AE(&5N9"!O9@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!R97%U97-T/PH@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5M<%]D:7(@(%5S92!T:&ES('1E;7!O<F%R>2!D:7)E
M8W1O<GD@87,@=&AE(&1I<F5C=&]R>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@('=H97)E('1H92!T96UP;W)A<GD@9&ER96-T;W)Y('=I;&P@
M8F4@8W)E871E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('!A=&AN86UE('1O('1H92!N97<@=&5M<&]R87)Y(&1I<F5C=&]R>2X*("`@
M("`J("`@("`@("`@("`@("`@("!2971U<FYS(&9A;'-E(&EF(&1I<F5C=&]R
M>2!N;W0@8W)E871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E5&5M
M<$1I<B@D9&5L971E(#T@=')U92P@)'1E;7!?9&ER(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H:7-?;G5L;"@D=&5M<%]D:7(I*2!["B`@("`@("`@("`@
M("1T96UP7V1I<B`](%5T:6PZ.F=E=%1E;7!$:7(H*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AE;7!T>2@D=&5M<%]D:7(I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@9FER
M<W0@."!C:&%R86-T97)S(&]F(&$@<F%N9&]M('-T<FEN9R!T;R!U<V4@87,@
M82!T96UP;W)A<GD*("`@("`@("`@("!D:7)E8W1O<GD@;F%M92X@*B\*("`@
M("`@("!D;R!["B`@("`@("`@("`@("1T96UP7V1I<B`N/2`G+R<@+B!S=6)S
M='(H8F%S95]C;VYV97)T*&UT7W)A;F0H*2`N(&UI8W)O=&EM92@I+"`Q,"P@
M,S8I+"`P+"`X*3L*("`@("`@("!]('=H:6QE("AF:6QE7V5X:7-T<R@D=&5M
M<%]D:7(I*3L*"B`@("`@("`@)&]L9%]U;6%S:R`]('5M87-K*#`P,#`I.PH@
M("`@("`@(&EF("@A;6MD:7(H)'1E;7!?9&ER+"`P-S`P*2D@>PH@("`@("`@
M("`@("`D=&5M<%]D:7(@/2!F86QS93L*("`@("`@("!](&5L<V5I9B`H)&1E
M;&5T92D@>PH@("`@("`@("`@("!5=&EL.CID96QE=&5!=%-H=71D;W=N*"1T
M96UP7V1I<BD["B`@("`@("`@?0H@("`@("`@('5M87-K*"1O;&1?=6UA<VLI
M.PH*("`@("`@("!R971U<FX@)'1E;7!?9&ER.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@8V%N;VYI8V%L('!A=&@@;V8@=&AE('-T<FEN
M9RX@($QI:V4@4$A0)W,@8G5I;'0M:6X*("`@("`J(')E86QP871H*"D@97AC
M97!T('1H92!D:7)E8W1O<GD@;F5E9"!N;W0@97AI<W0@;VX@=&AE(&QO8V%L
M('-E<G9E<BX*("`@("`J"B`@("`@*B!!;&=O<FET:&EM(&QO;W-E;'D@8F%S
M960@;VX@8V]D92!F<F]M('1H92!097)L($9I;&4Z.E-P96,Z.E5N:7@@;6]D
M=6QE"B`@("`@*B`H=F5R<VEO;B`Q+C4I+@H@("`@("H*("`@("`J($!S:6YC
M92!(;W)D92`S+C`N-0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@($$@9FEL92!P871H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@8V%N;VYI8V%L:7IE9"!F:6QE('!A=&@N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E86Q0871H*"1P871H*0H@("`@>PH@("`@("`@("\J(%-T86YD
M87)D:7IE(&]N(%5.25@@9&ER96-T;W)Y('-E<&%R871O<G,N("HO"B`@("`@
M("`@:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I(#T]("=724XG*2!["B`@("`@
M("`@("`@("1P871H(#T@<W1R7W)E<&QA8V4H)UQ<)RP@)R\G+"`D<&%T:"D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!X>"\O+R]X>"`M/B!X>"]X>`H@("`@
M("`@("`J('AX+RXO+B]X>"`M/B!X>"]X>"`J+PH@("`@("`@("1P871H(#T@
M<')E9U]R97!L86-E*&%R<F%Y*")\+RM\(BP@(D`H+UPN*2LH+WQ<6B@_(5QN
M*2E`(BDL(&%R<F%Y*"<O)RP@)R\G*2P@)'!A=&@I.PH*("`@("`@("`O*B`N
M+WAX("T^('AX("HO"B`@("`@("`@:68@*"1P871H("$]("<N+R<I('L*("`@
M("`@("`@("`@)'!A=&@@/2!P<F5G7W)E<&QA8V4H(GQ>*%PN+RDK?"(L("<G
M+"`D<&%T:"D["B`@("`@("`@?0H*("`@("`@("`O*B`O+BXO+BXO>'@@+3X@
M>'@@*B\*("`@("`@("`D<&%T:"`]('!R96=?<F5P;&%C92@B?%XO*%PN7"XO
M/RDK?"(L("<O)RP@)'!A=&@I.PH*("`@("`@("`O*B!X>"\@+3X@>'@@*B\*
M("`@("`@("!I9B`H)'!A=&@@(3T@)R\G*2!["B`@("`@("`@("`@("1P871H
M(#T@<')E9U]R97!L86-E*")\+UQ:*#\A7&XI?"(L("<G+"`D<&%T:"D["B`@
M("`@("`@?0H*("`@("`@("`O*B`O>'@O+BX@+3X@+R`J+PH@("`@("`@('=H
M:6QE("AS=')P;W,H)'!A=&@L("<O+BXG*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@)'!A=&@@/2!P<F5G7W)E<&QA8V4H(GPO6UXO72LO7"Y<+GPB+"`G
M)RP@)'!A=&@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&5M<'1Y*"1P
M871H*2`_("<O)R`Z("1P871H.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M
M;W9E<R!G:79E;B!E;&5M96YT<R!A="!R97%U97-T('-H=71D;W=N+@H@("`@
M("H*("`@("`J($EF(&-A;&QE9"!W:71H(&$@9FEL96YA;64@=VEL;"!D96QE
M=&4@=&AA="!F:6QE(&%T(')E<75E<W0@<VAU=&1O=VX[(&EF"B`@("`@*B!C
M86QL960@=VET:"!A(&1I<F5C=&]R>2!W:6QL(')E;6]V92!T:&%T(&1I<F5C
M=&]R>2!A;F0@86QL(&9I;&5S(&EN('1H870*("`@("`J(&1I<F5C=&]R>2!A
M="!R97%U97-T('-H=71D;W=N+@H@("`@("H*("`@("`J($EF(&-A;&QE9"!W
M:71H(&YO(&%R9W5M96YT<RP@<F5T=7)N(&%L;"!E;&5M96YT<R!T;R!B92!D
M96QE=&5D("AT:&ES"B`@("`@*B!S:&]U;&0@;VYL>2!B92!D;VYE(&)Y(%5T
M:6PZ.E]D96QE=&5!=%-H=71D;W=N*2X*("`@("`J"B`@("`@*B!4:&4@9FER
M<W0@=&EM92!I="!I<R!C86QL960L(&ET(&EN:71I86QI>F5S('1H92!A<G)A
M>2!A;F0@<F5G:7-T97)S"B`@("`@*B!5=&EL.CI?9&5L971E0713:'5T9&]W
M;B@I(&%S(&$@<VAU=&1O=VX@9G5N8W1I;VX@+2!N;R!N965D('1O(&1O('-O
M"B`@("`@*B!M86YU86QL>2X*("`@("`J"B`@("`@*B!4:&4@<V5C;VYD('!A
M<F%M971E<B!A;&QO=W,@=&AE('5N<F5G:7-T97)I;F<@;V8@<')E=FEO=7-L
M>2!R96=I<W1E<F5D"B`@("`@*B!E;&5M96YT<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QE;F%M92`@(%1H92!F:6QE;F%M92!T;R!B92!D
M96QE=&5D(&%T('1H92!E;F0@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E<75E<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<F5G:7-T97(@($EF('1R=64L('1H96X@<F5G:7-T97(@=&AE(&5L96UE;G0@
M9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E;&5T:6]N
M+"!O=&AE<G=I<V4L('5N<F5G:7-T97(@:70N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<V5C=7)E("`@($EF(&1E;&5T:6YG(&9I;&4L('-H;W5L9"!W92!S
M96-U<F5L>2!D96QE=&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&AE(&9I;&4_"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T94%T4VAU
M=&1O=VXH)&9I;&5N86UE(#T@9F%L<V4L("1R96=I<W1E<B`]('1R=64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S96-U<F4@/2!F86QS92D*
M("`@('L*("`@("`@("!S=&%T:6,@)&1I<G,L("1F:6QE<RP@)'-E8W5R961E
M;#L*"B`@("`@("`@+RH@26YI=&EA;&EZ871I;VX@;V8@=F%R:6%B;&5S(&%N
M9"!S:'5T9&]W;B!F=6YC=&EO;G,N("HO"B`@("`@("`@:68@*&ES7VYU;&PH
M)&1I<G,I*2!["B`@("`@("`@("`@("1D:7)S(#T@87)R87DH*3L*("`@("`@
M("`@("`@)&9I;&5S(#T@87)R87DH*3L*("`@("`@("`@("`@)'-E8W5R961E
M;"`](&%R<F%Y*"D["B`@("`@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U
M;F-T:6]N*&%R<F%Y*"=5=&EL)RP@)U]D96QE=&5!=%-H=71D;W=N)RDI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1F:6QE;F%M92D@>PH@("`@("`@("`@
M("!I9B`H)')E9VES=&5R*2!["B`@("`@("`@("`@("`@("!I9B`H0&ES7V1I
M<B@D9FEL96YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)&1I<G-;)&9I
M;&5N86UE72`]('1R=64["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1F:6QE<ULD9FEL96YA;65=(#T@=')U93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D<V5C=7)E*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-E8W5R961E;%LD9FEL96YA;65=(#T@
M=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@('5N<V5T*"1D:7)S6R1F:6QE;F%M95TI.PH@("`@
M("`@("`@("`@("`@=6YS970H)&9I;&5S6R1F:6QE;F%M95TI.PH@("`@("`@
M("`@("`@("`@=6YS970H)'-E8W5R961E;%LD9FEL96YA;65=*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!A
M<G)A>2@D9&ER<RP@)&9I;&5S+"`D<V5C=7)E9&5L*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(')E9VES=&5R960@9FEL97,@
M870@<F5Q=65S="!S:'5T9&]W;BX*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T
M:6]N('-H;W5L9"!N979E<B!B92!C86QL960@;6%N=6%L;'D[(&ET(&ES(')E
M9VES=&5R960@87,@80H@("`@("H@<VAU=&1O=VX@9G5N8W1I;VX@8GD@571I
M;#HZ9&5L971E0713:'5T9&]W;B@I(&%N9"!C86QL960@875T;VUA=&EC86QL
M>0H@("`@("H@870@=&AE(&5N9"!O9B!T:&4@<F5Q=65S="X@270@=VEL;"!R
M971R:65V92!T:&4@;&ES="!O9B!F;VQD97)S(&%N9`H@("`@("H@9FEL97,@
M=&\@9&5L971E(&9R;VT@571I;#HZ9&5L971E0713:'5T9&]W;B@I)W,@<W1A
M=&EC(&%R<F%Y+"!A;F0@=&AE;@H@("`@("H@:71E<F%T92!T:')O=6=H+"!D
M96QE=&EN9R!F;VQD97)S(')E8W5R<VEV96QY+@H@("`@("H*("`@("`J($-O
M;G1A:6YS(&-O9&4@9G)O;2!G<&=?9G5N8W1I;VYS+G!H<"X*("`@("`J($-O
M<'ER:6=H="`H8RD@,C`P,BTR,#`S($)R879E<F]C:R!696YT=7)E<PH@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9&5L971E0713:'5T9&]W;B@I"B`@("!["B`@("`@("`@)')E9VES=&5R
M960@/2!5=&EL.CID96QE=&5!=%-H=71D;W=N*"D["B`@("`@("`@)&1I<G,@
M/2`D<F5G:7-T97)E9%LP73L*("`@("`@("`D9FEL97,@/2`D<F5G:7-T97)E
M9%LQ73L*("`@("`@("`D<V5C=7)E(#T@)')E9VES=&5R961;,ET["@H@("`@
M("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92`]/B`D=F%L*2!["B`@("`@
M("`@("`@("\J($1E;&5T92!F:6QE<R`J+PH@("`@("`@("`@("!I9B`H)'9A
M;"`F)B!`9FEL95]E>&ES=',H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`O
M*B!3:&]U;&0@=V4@<V5C=7)E;'D@9&5L971E('1H92!F:6QE(&)Y(&]V97)W
M<FET:6YG('1H90H@("`@("`@("`@("`@("`@("`@9&%T82!W:71H(&$@<F%N
M9&]M('-T<FEN9S\@*B\*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<V5C
M=7)E6R1F:6QE72DI('L*("`@("`@("`@("`@("`@("`@("`D<F%N9&]M7W-T
M<B`]("<G.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&9I;&5S:7IE*"1F:6QE*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<F%N9&]M7W-T<B`N/2!C:'(H;71?<F%N9"@P+"`R-34I*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&9P(#T@
M9F]P96XH)&9I;&4L("=R*R<I.PH@("`@("`@("`@("`@("`@("`@(&9W<FET
M92@D9G`L("1R86YD;VU?<W1R*3L*("`@("`@("`@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@($!U
M;FQI;FLH)&9I;&4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D9&ER<R!A<R`D9&ER(#T^("1V86PI('L*("`@("`@("`@
M("`@+RH@1&5L971E(&1I<F5C=&]R:65S("HO"B`@("`@("`@("`@(&EF("@D
M=F%L("8F($!F:6QE7V5X:7-T<R@D9&ER*2D@>PH@("`@("`@("`@("`@("`@
M+RH@36%K92!S=7)E(&1I<F5C=&]R>2!I<R!E;7!T>2X@*B\*("`@("`@("`@
M("`@("`@("1D:7)?8VQA<W,@/2!D:7(H)&1I<BD["B`@("`@("`@("`@("`@
M("!W:&EL92`H9F%L<V4@(3T]("@D96YT<GD@/2`D9&ER7V-L87-S+3YR96%D
M*"DI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1E;G1R>2`A/2`G+B<@
M)B8@)&5N=')Y("$]("<N+B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M0'5N;&EN:R@D9&ER("X@)R\G("X@)&5N=')Y*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&ER
M7V-L87-S+3YC;&]S92@I.PH@("`@("`@("`@("`@("`@0')M9&ER*"1D:7(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@3W5T<'5T<R!J879A<V-R:7!T(&-O9&4@=&\@8VQO<V4@=&AE(&-U<G)E
M;G0@=VEN9&]W+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O9&4@
M($%N>2!A9&1T:6]N86P@:F%V87-C<FEP="!C;V1E('1O(')U;B!B969O<F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@(&-L;W-I;F<@=&AE('=I;F1O
M=RX*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V57:6YD;W=*4R@D8V]D92`]
M("<G*0H@("`@>PH@("`@("`@(&5C:&\@)SQS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(CXG("X@)&-O9&4@+@H@("`@("`@("`@("`G=VEN9&]W+F-L
M;W-E*"D[/"]S8W)I<'0^)SL*("`@('T*"B`@("`O*BH*("`@("`J($-A8VAE
M<R!T:&4@<F5S=6QT(&]F(&5X=&5N<VEO;E]L;V%D960H*2!C86QL<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1E>'0@(%1H92!E>'1E;G-I;VX@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@($ES('1H92!E>'1E;G-I;VX@;&]A9&5D
M/PH@("`@("HO"B`@("!F=6YC=&EO;B!E>'1E;G-I;VY%>&ES=',H)&5X="D*
M("`@('L*("`@("`@("!S=&%T:6,@)&-A8VAE(#T@87)R87DH*3L*"B`@("`@
M("`@:68@*"%I<W-E="@D8V%C:&5;)&5X=%TI*2!["B`@("`@("`@("`@("1C
M86-H95LD97AT72`](&5X=&5N<VEO;E]L;V%D960H)&5X="D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1E>'1=.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5')I97,@=&\@;&]A9"!A(%!(4"!E>'1E;G-I;VXL(&)E:&%V
M:6YG(&-O<G)E8W1L>2!F;W(@86QL(&]P97)A=&EN9PH@("`@("H@<WES=&5M
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E>'0@(%1H92!E>'1E
M;G-I;VX@=&\@;&]A9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE(&5X=&5N<VEO;B!I<R!N;W<@;&]A9&5D+"!F86QS92!I
M9B!N;W0N"B`@("`@*B`@("`@("`@("`@("`@("`@(%1R=64@8V%N(&UE86X@
M=&AA="!T:&4@97AT96YS:6]N('=A<R!A;')E861Y(&QO861E9"P*("`@("`J
M("`@("`@("`@("`@("`@("`@3U(@=V%S(&QO861E9"!D>6YA;6EC86QL>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9$5X=&5N<VEO;B@D97AT*0H@("`@
M>PH@("`@("`@("\J($EF("1E>'0@:7,@86QR96%D>2!L;V%D960L(&]U<B!W
M;W)K(&ES(&1O;F4N("HO"B`@("`@("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X
M:7-T<R@D97AT*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\J(%-E92!I9B!W92!C86X@8V%L;"!D;"@I(&%T(&%L
M;"P@8GD@=&AE(&-U<G)E;G0@:6YI('-E='1I;F=S+B`J+PH@("`@("`@(&EF
M("@H:6YI7V=E="@G96YA8FQE7V1L)RD@(3T@,2D@?'P@*&EN:5]G970H)W-A
M9F5?;6]D92<I(#T](#$I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@(&EF("AS=6)S='(H4$A07T]3+"`P+"`S*2`]
M/2`G5TE.)RD@>PH@("`@("`@("`@("`D<W5F9FEX(#T@)V1L;"<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<W=I=&-H("A02%!?3U,I('L*("`@
M("`@("`@("`@8V%S92`G2%`M55@G.@H@("`@("`@("`@("`@("`@)'-U9F9I
M>"`]("=S;"<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)T%)6"<Z"B`@("`@("`@("`@("`@("`D<W5F9FEX(#T@)V$G.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=/4U@G
M.@H@("`@("`@("`@("`@("`@)'-U9F9I>"`]("=B=6YD;&4G.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@)'-U9F9I>"`]("=S;R<["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!`9&PH)&5X="`N("<N)R`N("1S=69F:7@I
M('Q\($!D;"@G<&AP7R<@+B`D97AT("X@)RXG("X@)'-U9F9I>"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@86QL(&YE8V5S<V%R>2!P87)A
M;65T97)S(&9O<B!A(&1R:79E<B=S(&-O;F9I9W5R871I;VX@87)E('-E=`H@
M("`@("H@86YD(')E='5R;G,@82!014%27T5R<F]R(&EF('-O;65T:&EN9R!I
M<R!M:7-S:6YG+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("`@5&AE(&-O;F9I9W5R871I;VX@87)R87D@=VET:"!A;&P@<&%R86UE=&5R
M<RX*("`@("`J($!P87)A;2!A<G)A>2`D9FEE;&1S("`@06X@87)R87D@=VET
M:"!M86YD871O<GD@<&%R86UE=&5R(&YA;65S(&9O<B!T:&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(&1R:79E<BX*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@5&AE(&-L96%R('1E>'0@;F%M92!O9B!T:&4@9')I
M=F5R+B!)9B!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<W!E
M8VEF:65D+"!T:&4@87!P;&EC871I;VX@;F%M92!W:6QL(&)E('5S960N"B`@
M("`@*B!`<&%R86T@87)R87D@)&EN9F\@("`@($$@:&%S:"!C;VYT86EN:6YG
M(&1E=&%I;&5D(&EN9F]R;6%T:6]N(&%B;W5T('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!D<FEV97(N(%=I;&P@8F4@<&%S<V5D(&%S('1H
M92!U<V5R26YF;R!T;R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T1')I
M=F5R0V]N9FEG*"1P87)A;7,L("1F:65L9',L("1N86UE+"`D:6YF;R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)&EN9F\@/2!A<G)A>5]M97)G92@D:6YF
M;RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P87)A;7,G
M(#T^("1P87)A;7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9FEE;&1S)R`]/B`D9FEE;&1S+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VYA;64G(#T^("1N86UE*2D["@H@("`@("`@(&EF("@A
M:7-?87)R87DH)'!A<F%M<RD@?'P@(6-O=6YT*"1P87)A;7,I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ=&AR;W=%<G)O<BAS<')I;G1F*%\H(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB*2P@)&YA;64I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(3U)$15]%
M4E)/4E]$4DE615)?0T].1DE'7TU)4U-)3D<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O*3L*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1F:65L9',@87,@)&9I96QD*2!["B`@("`@("`@("`@(&EF
M("@A:7-S970H)'!A<F%M<ULD9FEE;&1=*2D@>PH@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ=&AR;W=%<G)O<BAS<')I;G1F*%\H(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(BDL("1F:65L9"P@
M)&YA;64I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@2$]21$5?15)23U)?1%))5D527T-/3D9)1RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!F
M;W)M870@<W1R:6YG('1O(&)E('5S960@8GD@<W1R9G1I;64H*2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@($$@9F]R;6%T('-T<FEN
M9R!A<R!U<V5D(&)Y(&1A=&4H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@02!F;W)M870@<W1R:6YG(&%S('-I;6EL87(@87,@<&]S<VEB;&4@
M=&\@)&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&%T93)S=')F=&EM
M92@D9F]R;6%T*0H@("`@>PH@("`@("`@("1D871E4WEM8F]L<R`](&%R<F%Y
M*"=A)RP@)T$G+"`G9"<L("=$)RP@)T8G+"`G9R<L("=')RP@)V@G+"`G2"<L
M("=I)RP@)VHG+"`G;"<L("=M)RP@)TTG+"`G;B<L("=R)RP@)W,G+"`G5"<L
M("=W)RP@)U<G+"`G>2<L("=9)RP@)WHG+"`G;2]D+UDG+"`G32<L(")<;B(L
M("=G.FD@82<L("='.FDG+"`B7'0B+"`G2#II.G,G+"`G)2<I.PH@("`@("`@
M("1S=')F=&EM95-Y;6)O;',@/2!A<G)A>2@G)7`G+"`G)7`G+"`G)60G+"`G
M)6$G+"`G)4(G+"`G)4DG+"`G)4@G+"`G)4DG+"`G)4@G+"`G)4TG+"`G)64G
M+"`G)4$G+"`G)6TG+"`G)6(G+"`G)6TG+"`G)6$L("5E("5B("59("54("5:
M)RP@)R53)RP@)R5:)RP@)R5W)RP@)R56)RP@)R5Y)RP@)R59)RP@)R5J)RP@
M)R5$)RP@)R5H)RP@)R5N)RP@)R5R)RP@)R52)RP@)R5T)RP@)R54)RP@)R4E
M)RD["@H@("`@("`@("1R97-U;'0@/2`G)SL*("`@("`@("!F;W(@*"1P;W,@
M/2`P.R`D<&]S(#P@<W1R;&5N*"1F;W)M870I.RD@>PH@("`@("`@("`@("!F
M;W(@*"1S>6UB;VP@/2`P.R`D<WEM8F]L(#P@8V]U;G0H)&1A=&53>6UB;VQS
M*3L@)'-Y;6)O;"LK*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1F
M;W)M870L("1D871E4WEM8F]L<ULD<WEM8F]L72P@)'!O<RD@/3T]("1P;W,I
M('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT("X]("1S=')F=&EM95-Y
M;6)O;'-;)'-Y;6)O;%T["B`@("`@("`@("`@("`@("`@("`@)'!O<R`K/2!S
M=')L96XH)&1A=&53>6UB;VQS6R1S>6UB;VQ=*3L*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1R97-U;'0@+CT@<W5B<W1R*"1F;W)M870L("1P
M;W,L(#$I.PH@("`@("`@("`@("`D<&]S*RL["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!F;W)M870@<W1R:6YG('1O(&)E('5S960@8GD@9&%T92@I+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@02!F;W)M870@<W1R
M:6YG(&%S('5S960@8GD@<W1R9G1I;64H*2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@02!F;W)M870@<W1R:6YG(&%S('-I;6EL87(@87,@<&]S
M<VEB;&4@=&\@)&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R9G1I
M;64R9&%T92@D9F]R;6%T*0H@("`@>PH@("`@("`@("1D871E4WEM8F]L<R`]
M(&%R<F%Y*"=A)RP@)T$G+"`G9"<L("=$)RP@)T8G+"`G9R<L("=')RP@)V@G
M+"`G2"<L("=I)RP@)VHG+"`G;"<L("=M)RP@)TTG+"`G;B<L("=R)RP@)W,G
M+"`G5"<L("=W)RP@)U<G+"`G>2<L("=9)RP@)WHG+"`G;2]D+UDG+"`G32<L
M(")<;B(L("=G.FD@82<L("='.FDG+"`B7'0B+"`G2#II.G,G+"`G)2<I.PH@
M("`@("`@("1S=')F=&EM95-Y;6)O;',@/2!A<G)A>2@G)7`G+"`G)7`G+"`G
M)60G+"`G)6$G+"`G)4(G+"`G)4DG+"`G)4@G+"`G)4DG+"`G)4@G+"`G)4TG
M+"`G)64G+"`G)4$G+"`G)6TG+"`G)6(G+"`G)6TG+"`G)6$L("5E("5B("59
M("54("5:)RP@)R53)RP@)R5:)RP@)R5W)RP@)R56)RP@)R5Y)RP@)R59)RP@
M)R5J)RP@)R5$)RP@)R5H)RP@)R5N)RP@)R5R)RP@)R52)RP@)R5T)RP@)R54
M)RP@)R4E)RD["@H@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@D<W1R9G1I
M;653>6UB;VQS+"`D9&%T95-Y;6)O;',L("1F;W)M870I.PH@("`@?0H*?0H*
M:68@*"%F=6YC=&EO;E]E>&ES=',H)U\G*2D@>PH@("`@9G5N8W1I;VX@7R@D
M<W1R:6YG*0H@("`@>PH@("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&)I;F1T97AT9&]M86EN*"D*("`@('L*("`@('T*"B`@
M("!F=6YC=&EO;B!T97AT9&]M86EN*"D*("`@('L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M5F%R:6%B;&5S+G!H<```````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$U-38T`#$P-#$W,S8R-S<S`#`R,#8V-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M("=(;W)D92]5=&EL+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O07)R87DN
M<&AP)SL*"B\J*@H@*B!687)I86)L97,Z.B!C;&%S<RX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO571I;"]687)I86)L97,N<&AP+'8@,2XX+C$P+C8@,C`P
M-B\P,R\R."`Q,CHS,3HQ,B!J86X@17AP("0*("H*("H@0&%U=&AO<B`@4F]B
M97)T($4N($-O>6QE(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<&%C:V%G92!(;W)D95]5=&EL"B`J+PIC;&%S<R!687)I86)L97,@>PH*("`@
M('9A<B`D7W9A<G,["B`@("!V87(@)%]E>'!E8W1E9%9A<FEA8FQE<R`](&%R
M<F%Y*"D["@H@("`@9G5N8W1I;VX@5F%R:6%B;&5S*"1V87)S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=F%R<RDI('L*("`@("`@
M("`@("`@)'9A<G,@/2!5=&EL.CID:7-P96Q-86=I8U%U;W1E<R@D7U)%455%
M4U0I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'9A<G-;)U]F;W)M
M=F%R<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B
M;&5S(#T@0'5N<V5R:6%L:7IE*"1V87)S6R=?9F]R;79A<G,G72D["B`@("`@
M("`@("`@('5N<V5T*"1V87)S6R=?9F]R;79A<G,G72D["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?=F%R<R`]("1V87)S.PH@("`@?0H*("`@(&9U;F-T
M:6]N("9G971$969A=6QT5F%R:6%B;&5S*"D*("`@('L*("`@("`@("`D=F%R
M<R`]("9N97<@5F%R:6%B;&5S*%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?
M4D5154535"DI.PH@("`@("`@(')E='5R;B`D=F%R<SL*("`@('T*"B`@("!F
M=6YC=&EO;B!E>&ES=',H)'9A<FYA;64I"B`@("!["B`@("`@("`@:68@*&-O
M=6YT*"1T:&ES+3Y?97AP96-T961687)I86)L97,I("8F"B`@("`@("`@("`@
M("1T:&ES+3Y?97AI<W1S*"1T:&ES+3Y?97AP96-T961687)I86)L97,L("1V
M87)N86UE+"!F86QS92DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7V5X:7-T<R@D=&AI<RT^
M7W9A<G,L("1V87)N86UE+"!F86QS92D["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T*"1V87)N86UE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5T17AI<W1S
M*"1T:&ES+3Y?=F%R<RP@)'9A<FYA;64L("1V86QU92D["B`@("`@("`@<F5T
M=7)N("1V86QU93L*("`@('T*"B`@("!F=6YC=&EO;B!G971%>&ES=',H)'9A
M<FYA;64L("8D97AI<W1S*0H@("`@>PH@("`@("`@("1E>&ES=',@/2`D=&AI
M<RT^7V=E=$5X:7-T<R@D=&AI<RT^7W9A<G,L("1V87)N86UE+"`D=F%L=64I
M.PH@("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T*"1V87)N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@)&ME>7,@/2!A
M<G)A>2@I.PH@("`@("`@(&EF("@A2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R
M=',H)'9A<FYA;64L("1B87-E+"`D:V5Y<RDI('L*("`@("`@("`@("`@)'1H
M:7,M/E]V87)S6R1V87)N86UE72`]("1V86QU93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1K97ES+"`D8F%S92D["B`@
M("`@("`@("`@("1P;&%C92`]("8D=&AI<RT^7W9A<G,["@H@("`@("`@("`@
M("!W:&EL92`H8V]U;G0H)&ME>7,I*2!["B`@("`@("`@("`@("`@("`D:V5Y
M(#T@87)R87E?<VAI9G0H)&ME>7,I.PH@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D<&QA8V5;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'!L
M86-E6R1K97E=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1P;&%C92`]("8D<&QA8V5;)&ME>5T["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1P;&%C92`]("1V86QU93L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@;65R9V4H)'9A<G,I"B`@("!["B`@("`@("`@
M9F]R96%C:"`H)'9A<G,@87,@)'9A<FYA;64@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("1T:&ES+3YS970H)'9A<FYA;64L("1V86QU92D["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N(&%D9"@D=F%R;F%M92P@)'9A;'5E*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^97AI<W1S*"1V87)N86UE*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?=F%R<ULD=F%R;F%M95T@/2`D=F%L=64["B`@("!]"@H@("`@9G5N
M8W1I;VX@<F5M;W9E*"1V87)N86UE*0H@("`@>PH@("`@("`@($AO<F1E7T%R
M<F%Y.CIG971!<G)A>5!A<G1S*"1V87)N86UE+"`D8F%S92P@)&ME>7,I.PH@
M("`@("`@(&EF("@A:7-?;G5L;"@D8F%S92DI('L*("`@("`@("`@("`@)'!T
M<B`]("8D=&AI<RT^7W9A<G-;)&)A<V5=.PH@("`@("`@("`@("`D96YD(#T@
M8V]U;G0H)&ME>7,I("T@,3L*("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@
M87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1P=');)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&5N9"`]/2`D
M:V5Y*2!["B`@("`@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E*"1P='(L
M(&%R<F%Y7W-E87)C:"@D=F%L+"!A<G)A>5]K97ES*"1P='(I*2P@,2D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1P
M='(@/2`F)'!T<ELD=F%L73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3Y?=F%R<ULD=F%R;F%M95TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($9I;F0@;W5T('=H971H97(@;W(@;F]T("1V87)N86UE('=A<R!S
M970@:6X@)&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1A<G)A>2`@("`@("`@("`@
M("`@("`@("!4:&4@87)R87D@=&\@<V5A<F-H(&EN("AU<W5A;&QY"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96ET
M:&5R("1T:&ES+3Y?=F%R<R!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97AP96-T961687)I86)L
M97,I+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'9A<FYA;64@("`@("`@("`@
M("`@("`@(%1H92!N86UE(&]F('1H92!V87)I86)L92!T;R!L;V]K"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-H96-K17AP96-T961687)I86)L
M97,@($EF('=E(&1O;B=T(&9I;F0@)'9A<FYA;64L"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<VAO=6QD('=E(&-H
M96-K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<R!T;R!S964*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B!S
M:&]U;&0@:&%V92!E>&ES=&5D("AL:6ME(&$*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&5C:V)O>"!O<B!S96QE
M8W0@;75L=&EP;&4I+@H@("`@("H*("`@("`J($!R971U<FX@(%=H971H97(@
M;W(@;F]T('1H92!V87)I86)L92!W87,@<V5T("AO<BP@:68@=V4G=F4@8VAE
M8VME9`H@("`@("H@("`@("`@("`@)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE
M<RP@<VAO=6QD(&AA=F4@8F5E;B!S970I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?97AI<W1S*"1A<G)A>2P@)'9A<FYA;64L("1C:&5C:T5X<&5C=&5D5F%R
M:6%B;&5S(#T@=')U92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G
M971%>&ES=',H)&%R<F%Y+"`D=F%R;F%M92P@)'9A;'5E+"`D8VAE8VM%>'!E
M8W1E9%9A<FEA8FQE<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C:"!T
M:&4@<F5Q=65S=&5D('9A<FEA8FQE("@D=F%R;F%M92D@:6YT;R`D=F%L=64L
M(&%N9"!R971U<FX*("`@("`J('=H971H97(@;W(@;F]T('1H92!V87)I86)L
M92!W87,@<V5T(&EN("1A<G)A>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D87)R87D@("`@
M("`@("`@("`@("`@("`@5&AE(&%R<F%Y('1O('-E87)C:"!I;B`H=7-U86QL
M>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5I=&AE<B`D=&AI<RT^7W9A<G,@;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D
M5F%R:6%B;&5S*2X*("`@("`J($!P87)A;2!S=')I;F<@("1V87)N86UE("`@
M("`@("`@("`@("`@("!4:&4@;F%M92!O9B!T:&4@=F%R:6%B;&4@=&\@;&]O
M:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<BX*("`@("`J($!P87)A;2!M:7AE9"`@)B1V86QU92`@("`@("`@
M("`@("`@("`@("`D=F%R;F%M92=S('9A;'5E(&=E=',@87-S:6=N960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M;RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&ES('9A<FEA8FQE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-H
M96-K17AP96-T961687)I86)L97,@($EF('=E(&1O;B=T(&9I;F0@)'9A<FYA
M;64L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<VAO=6QD('=E(&-H96-K"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'!E8W1E9%9A<FEA
M8FQE<R!T;R!S964*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B!I="!S:&]U;&0@:&%V92!E>&ES=&5D("AL:6ME
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@82!C:&5C:V)O>"!O<B!S96QE8W0@;75L=&EP;&4I+@H@("`@("H*("`@
M("`J($!R971U<FX@(%=H971H97(@;W(@;F]T('1H92!V87)I86)L92!W87,@
M<V5T("AO<BP@:68@=V4G=F4@8VAE8VME9`H@("`@("H@("`@("`@("`@)'1H
M:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@<VAO=6QD(&AA=F4@8F5E;B!S970I
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T17AI<W1S*"1A<G)A>2P@)'9A
M<FYA;64L("8D=F%L=64L("1C:&5C:T5X<&5C=&5D5F%R:6%B;&5S(#T@=')U
M92D*("`@('L*("`@("`@("!I9B`H2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R
M=',H)'9A<FYA;64L("1B87-E+"`D:V5Y<RDI('L*("`@("`@("`@("`@:68@
M*"%I<W-E="@D87)R87E;)&)A<V5=*2D@>PH@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@;G5L;#L*("`@("`@("`@("`@("`@("\O($EF('=E)W)E('-U<'!O
M<V5D('1O(&-H96-K("1T:&ES+3Y?97AP96-T961687)I86)L97,L(&1O('-O
M+`H@("`@("`@("`@("`@("`@+R\@8G5T(&UA:V4@<W5R92!N;W0@=&\@8VAE
M8VL@:70@86=A:6XN"B`@("`@("`@("`@("`@("!R971U<FX@)&-H96-K17AP
M96-T961687)I86)L97,@/R`D=&AI<RT^7V5X:7-T<R@D=&AI<RT^7V5X<&5C
M=&5D5F%R:6%B;&5S+"`D=F%R;F%M92P@9F%L<V4I(#H@9F%L<V4["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V5A<F-H<W!A8V4@
M/2`F)&%R<F%Y6R1B87-E73L*("`@("`@("`@("`@("`@('=H:6QE("AC;W5N
M="@D:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@87)R87E?
M<VAI9G0H)&ME>7,I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'-E87)C:'-P86-E6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%L=64@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!)
M9B!W92=R92!S=7!P;W-E9"!T;R!C:&5C:PH@("`@("`@("`@("`@("`@("`@
M("`@("`O+R`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S+"!D;R!S;RP@8G5T
M(&UA:V4*("`@("`@("`@("`@("`@("`@("`@("`@+R\@<W5R92!N;W0@=&\@
M8VAE8VL@:70@86=A:6XN"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D8VAE8VM%>'!E8W1E9%9A<FEA8FQE<R`_("1T:&ES+3Y?97AI<W1S*"1T
M:&ES+3Y?97AP96-T961687)I86)L97,L("1V87)N86UE+"!F86QS92D@.B!F
M86QS93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)'-E87)C:'-P86-E(#T@)B1S96%R8VAS<&%C95LD:V5Y73L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V86QU92`]("1S96%R8VAS
M<&%C93L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9A;'5E(#T@:7-S
M970H)&%R<F%Y6R1V87)N86UE72D@/R`D87)R87E;)'9A<FYA;65=(#H@;G5L
M;#L*("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1V86QU92DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H
M)&-H96-K17AP96-T961687)I86)L97,I('L*("`@("`@("`@("`@("`@("\O
M($EF('=E)W)E('-U<'!O<V5D('1O(&-H96-K"B`@("`@("`@("`@("`@("`O
M+R`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S+"!D;R!S;RP@8G5T(&UA:V4@
M<W5R92!N;W0*("`@("`@("`@("`@("`@("\O('1O(&-H96-K(&ET(&%G86EN
M+@H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AI<W1S*"1T:&ES
M+3Y?97AP96-T961687)I86)L97,L("1V87)N86UE+"!F86QS92D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5D,N<&AP````````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,T,3`S`#$P-#$W
M,S8R-S<S`#`Q-S(U-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@4V]R=&EN9R!O<'1I;VYS"B`J+PID
M969I;F4H)U9#7U-/4E1?3D].12<L(#`I.R`@("`@("`@+R\@9&]N)W0@<V]R
M=`ID969I;F4H)U9#7U-/4E1?04=%)RP@,2D[("`@("`@("`@+R\@<V]R="!B
M>2!A9V4*9&5F:6YE*"=60U]33U)47TY!344G+"`R*3L@("`@("`@("\O('-O
M<G0@8GD@9FEL96YA;64*9&5F:6YE*"=60U]33U)47U)%5B<L(#,I.R`@("`@
M("`@("\O('-O<G0@8GD@<F5V:7-I;VX@;G5M8F5R"F1E9FEN92@G5D-?4T]2
M5%]!551(3U(G+"`T*3L@("`@("`O+R!S;W)T(&)Y(&%U=&AO<B!N86UE"@ID
M969I;F4H)U9#7U-/4E1?05-#14Y$24Y')RP@,"D[("`@+R\@87-C96YD:6YG
M(&]R9&5R"F1E9FEN92@G5D-?4T]25%]$15-#14Y$24Y')RP@,2D[("`O+R!D
M97-C96YD:6YG(&]R9&5R"@ID969I;F4H)U9#7U=)3D1/5U,G+"!S=6)S='(H
M4$A07T]3+"`P+"`S*2`]/2`G5TE.)RD["@HO*BH*("H@5F5R<VEO;B!#;VYT
M<F]L(&=E;F5R86QI>F5D(&QI8G)A<GDN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U9#+U9#+G!H<"QV(#$N,3(N."XW(#(P,#4O,3$O,#<@,#DZ-3`Z,#`@
M:F%N($5X<"`D"B`J"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60R!["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<V]U<F-E(')O;W0@;V8@=&AE(')E<&]S:71O
M<GDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O=7)C97)O;W0["@H@("`@
M+RHJ"B`@("`@*B!(87-H('=I=&@@=&AE(&QO8V%T:6]N<R!O9B!A;&P@;F5C
M97-S87)Y(&)I;F%R:65S+@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]P871H<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(87-H
M(&-A8VAI;F<@=&AE('!A<G-E9"!U<V5R<R!F:6QE+@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]U<V5R<SL*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@<V]U<F-E(')O;W0@9F]R('1H:7,@<F5P;W-I=&]R>2P@
M=VET:"!N;R!T<F%I;&EN9R`O"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%-O=7)C92!R;V]T(&9O<B!T:&ES(')E<&]S:71O<GDN"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-O=7)C97)O;W0H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W-O=7)C97)O;W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!L;V-A=&EO;B!O9B!T:&4@<W!E8VEF:65D(&)I;F%R>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B:6YA<GD@($%N(&5X=&5R
M;F%L('!R;V=R86T@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86Y\<W1R:6YG("!4:&4@;&]C871I;VX@;V8@=&AE(&5X=&5R;F%L('!R;V=R
M86T@;W(@9F%L<V4@:68*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&ET('=A<VXG="!S<&5C:69I960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A=&@H)&)I;F%R>2D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P871H<ULD8FEN87)Y72DI('L*("`@("`@("`@("`@:68@*%9#7U=)3D1/
M5U,I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A=&AS6R1B
M:6YA<GE=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&ES7V5X96-U=&%B;&4H)'1H:7,M/E]P871H<ULD8FEN87)Y72D@
M/R`D=&AI<RT^7W!A=&AS6R1B:6YA<GE=(#H@9F%L<V4["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%!A<G-E('1H92!U<V5R<R!F:6QE+"!I9B!P<F5S96YT
M(&EN('1H92!S;W5R8V4@<F]O="P@86YD(')E='5R;@H@("`@("H@82!H87-H
M(&-O;G1A:6YI;F<@=&AE(')E<75I<VET92!I;F9O<FUA=&EO;BP@:V5Y960@
M;VX@=&AE"B`@("`@*B!U<V5R;F%M92P@86YD('=I=&@@=&AE("=D97-C)RPG
M;F%M92<L(&%N9"`G;6%I;"<@=F%L=65S(&EN<VED92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86Y\87)R87D@($9A;'-E(&EF('1H92!F:6QE(&ES
M(&YO="!P<F5S96YT+"!O=&AE<G=I<V4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]U<V5R<R!P;W!U;&%T960@=VET:"!T:&4@9&%T
M80H@("`@("HO"B`@("!F=6YC=&EO;B!G9715<V5R<R@D=7-E<G-F:6QE*0H@
M("`@>PH@("`@("`@("\J($-H96-K('1H870@=V4@:&%V96XG="!A;')E861Y
M('!A<G-E9"!U<V5R<RX@*B\*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]U
M<V5R<RD@)B8@:7-?87)R87DH)'1H:7,M/E]U<V5R<RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=7-E<G,["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(4!I<U]F:6QE*"1U<V5R<V9I;&4I('Q\("$H)&9L(#T@0&9O<&5N*"1U
M<V5R<V9I;&4L(%9#7U=)3D1/5U,@/R`G<F(G(#H@)W(G*2DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]U<V5R<R`](&%R<F%Y*"D["@H@("`@("`@("\J($1I<V-A<F0@=&AE(&9I
M<G-T(&QI;F4L('-I;F-E(&ET)VQL(&)E('1H92!H96%D97(@:6YF;RX@*B\*
M("`@("`@("!F9V5T<R@D9FPL(#0P.38I.PH*("`@("`@("`O*B!087)S92!T
M:&4@<F5S="!O9B!T:&4@;&EN97,@:6YT;R!A(&AA<V@L(&ME>65D(&]N"B`@
M("`@("`@("H@=7-E<FYA;64N("HO"B`@("`@("`@=VAI;&4@*"1L:6YE(#T@
M9F=E=',H)&9L+"`T,#DV*2D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@G+UY<<RHD+R<L("1L:6YE*2D@8V]N=&EN=64["B`@("`@("`@("`@(&EF
M("@A<')E9U]M871C:"@G+UXH7'<K*5QS*R@N*RE<<RLH6UQW7"Y<+5Q?72M`
M6UQW7"Y<+5Q?72LI7',K*"XJ*20O)RP@)&QI;F4L("1R96=S*2D@8V]N=&EN
M=64["B`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)')E9W-;,5U=6R=N86UE
M)UT@/2!T<FEM*"1R96=S6S)=*3L*("`@("`@("`@("`@)'1H:7,M/E]U<V5R
M<ULD<F5G<ULQ75U;)VUA:6PG72`]('1R:6TH)')E9W-;,UTI.PH@("`@("`@
M("`@("`D=&AI<RT^7W5S97)S6R1R96=S6S%=75LG9&5S8R==(#T@=')I;2@D
M<F5G<ULT72D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]U
M<V5R<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R
M;B!A(&-O;F-R971E(%9#(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F
M(&-O;F-R971E(%9#('-U8F-L87-S('1O(')E='5R;BX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!4:&4@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L
M=61E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@;W(@('!A<F%M971E<G,@82!S=6)C;&%S
M<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@5D,@(%1H92!N
M97=L>2!C<F5A=&5D(&-O;F-R971E(%9#(&EN<W1A;F-E+"!O<B!014%27T5R
M<F]R(&]N"B`@("`@*B`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@)U9#+R<@+B`D9')I=F5R
M("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=60U\G("X@)&1R:79E<CL*
M("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@)'9C(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'9C(#T@4$5!4CHZ<F%I<V5%<G)O<B@D8VQA<W,@
M+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=F,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@
M82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!60R!I;G-T86YC92!B87-E9`H@
M("`@("H@;VX@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I
M;G-T86YC92!I9B!N;R!60PH@("`@("H@:6YS=&%N8V4@=VET:"!T:&4@<V%M
M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@
M5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F:6QE
M(&)A8VME;F1S("AA;F0L"B`@("`@*B!T:'5S+"!M=6QT:7!L92!60R!I;G-T
M86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F5D,Z.G-I;F=L971O;B@I
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E
M(&]F(&-O;F-R971E(%9#('-U8F-L87-S('1O(')E='5R;BX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!4:&4@8V]D92!I<R!D>6YA;6EC86QL>2!I
M;F-L=61E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@
M8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@;W(@<&%R86UE=&5R<R!A('-U8F-L
M87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!60R`@5&AE
M(&-O;F-R971E(%9#(')E9F5R96YC92P@;W(@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L
M("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS
M=&%N8V5S.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@
M("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P
M87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA
M='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@
M/2`F5D,Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*
M"GT*"B\J*@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?1&EF9B!["@H@
M("`@+RHJ"B`@("`@*B!/8G1A:6X@82!T<F5E(&-O;G1A:6YI;F<@:6YF;W)M
M871I;VX@86)O=70@=&AE(&-H86YG97,@8F5T=V5E;@H@("`@("H@='=O(')E
M=FES:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)')A=R`@06X@
M87)R87D@;V8@;&EN97,@;V8@=&AE(')A=R!U;FEF:65D(&1I9F8L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@;F]R;6%L;'D@;V)T86EN960@=&AR;W5G
M:"!60U]$:69F.CIG970H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M"B`@("`@*@H@("`@("H@0'1O9&\@9&]C=6UE;G0@=&AI<R!T:&]R;W5G:&QY
M+"!A<R!T:&4@9F]R;6%T(&ES(&$@8FET(&-O;7!L97@N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&AU;6%N4F5A9&%B;&4H)')A=RD*("`@('L*("`@("`@("`D
M<F5T(#T@87)R87DH*3L*"B`@("`@("`@+RH@2&]L9"!T:&4@;&5F="!A;F0@
M<FEG:'0@8V]L=6UN<R!O9B!L:6YE<R!F;W(@8VAA;F=E"B`@("`@("`@("H@
M8FQO8VMS+B`J+PH@("`@("`@("1C;VQS(#T@87)R87DH87)R87DH*2P@87)R
M87DH*2D["B`@("`@("`@)'-T871E(#T@)V5M<'1Y)SL*"B`@("`@("`@+RH@
M271E<F%T92!T:')O=6=H(&5V97)Y(&QI;F4@;V8@=&AE(&1I9F8N("HO"B`@
M("`@("`@9F]R96%C:"`H)')A=R!A<R`D;&EN92D@>PH@("`@("`@("`@("`O
M*B!,;V]K(&9O<B!A(&AE861E<B!W:&EC:"!I;F1I8V%T97,@=&AE('-T87)T
M(&]F(&$@9&EF9@H@("`@("`@("`@("`@*B!C:'5N:RX@*B\*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>0$`@7"TH6S`M.5TK*2XJ7"LH6S`M.5TK
M*2XJ0$`H+BHI+R<L("1L:6YE+"`D<F5G<RDI('L*("`@("`@("`@("`@("`@
M("\J(%!U<V@@86YY('!R979I;W5S(&AE861E<B!I;F9O<FUA=&EO;B!T;R!T
M:&4@<F5T=7)N"B`@("`@("`@("`@("`@("`@*B!S=&%C:RX@*B\*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&%T82DI('L*("`@("`@("`@("`@("`@
M("`@("`D<F5T6UT@/2`D9&%T83L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1D871A(#T@87)R87DH)W1Y<&4G(#T^("=H96%D97(G+"`G
M;VQD;&EN92<@/3X@)')E9W-;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=N97=L:6YE)R`]/B`D<F5G<ULR72P@)V-O;G1E;G1S)SX@87)R
M87DH*2D["B`@("`@("`@("`@("`@("`D9&%T85LG9G5N8W1I;VXG72`](&ES
M<V5T*"1R96=S6S-=*3\D<F5G<ULS73HG)SL*("`@("`@("`@("`@("`@("1S
M=&%T92`]("=D=6UP)SL*("`@("`@("`@("`@?2!E;'-E:68@*"1S=&%T92`A
M/2`G96UP='DG*2!["B`@("`@("`@("`@("`@("`O*B!792!A<F4@:6X@82!C
M:'5N:RP@<V\@<W!L:70@;W5T('1H92!A8W1I;VX@*"LO+2D*("`@("`@("`@
M("`@("`@("`J(&%N9"!T:&4@;&EN92X@*B\*("`@("`@("`@("`@("`@('!R
M96=?;6%T8V@H)R]>*%M<*UPM(%TI*"XJ*2\G+"`D;&EN92P@)')E9W,I.PH@
M("`@("`@("`@("`@("`@:68@*&-O=6YT*"1R96=S*2`^(#(I('L*("`@("`@
M("`@("`@("`@("`@("`D86-T:6]N(#T@)')E9W-;,5T["B`@("`@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/2`D<F5G<ULR73L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&%C=&EO;B`]("<@)SL*
M("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="`]("<G.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@D86-T:6]N(#T]("<K)RD@
M>PH@("`@("`@("`@("`@("`@("`@("\J(%1H:7,@:7,@:G5S="!A;B!A9&1I
M=&EO;B!L:6YE+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("@D<W1A=&4@
M/3T@)V1U;7`G('Q\("1S=&%T92`]/2`G861D)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`O*B!3=&%R="!A9&1I;F<@=&\@=&AE(&%D9&ET:6]N('-T
M86-K+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D8V]L<ULP75M=(#T@
M)&-O;G1E;G0["B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=A
M9&0G.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("\J(%1H:7,@:7,@:6YS:61E(&$@8VAA;F=E(&)L;V-K
M+"!S;R!S=&%R=`H@("`@("`@("`@("`@("`@("`@("`@("`@*B!A8V-U;75L
M871I;F<@;&EN97,N("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T
M92`]("=C:&%N9V4G.PH@("`@("`@("`@("`@("`@("`@("`@("`D8V]L<ULQ
M75M=(#T@)&-O;G1E;G0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1A8W1I;VX@/3T@)RTG*2!["B`@("`@("`@
M("`@("`@("`@("`@+RH@5&AI<R!I<R!A(')E;6]V86P@;&EN92X@*B\*("`@
M("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G<F5M;W9E)SL*("`@("`@("`@
M("`@("`@("`@("`D8V]L<ULP75M=(#T@)&-O;G1E;G0["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J($%N(&5M<'1Y
M(&)L;V-K('=I=&@@;F\@86-T:6]N+B`J+PH@("`@("`@("`@("`@("`@("`@
M('-W:71C:"`H)'-T871E*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G
M861D)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S
M)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G861D)RP@)VQI;F5S)R`]/B`D8V]L
M<ULP72D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@("`@("!C87-E("=R96UO=F4G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`O*B!792!H879E('-O;64@<F5M;W9A;"!L:6YE<R!P96YD:6YG
M(&EN(&]U<@H@("`@("`@("`@("`@("`@("`@("`@("`@*B!S=&%C:RP@<V\@
M9FQU<V@@=&AE;2X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;
M)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G<F5M;W9E)RP@)VQI
M;F5S)R`]/B`D8V]L<ULP72`I.PH@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G8VAA;F=E)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@+RH@5V4@:&%V92!B;W1H(')E;6]V92!A
M;F0@861D:71I;VX@;&EN97,L('-O"B`@("`@("`@("`@("`@("`@("`@("`@
M("`J('1H:7,@:7,@82!C:&%N9V4@8FQO8VLN("HO"B`@("`@("`@("`@("`@
M("`@("`@("`@("1D871A6R=C;VYT96YT<R==6UT@/2!A<G)A>2@G='EP92<@
M/3X@)V-H86YG92<L("=O;&0G(#T^("1C;VQS6S!=+"`G;F5W)R`]/B`D8V]L
M<ULQ72D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8V]L<R`](&%R
M<F%Y*&%R<F%Y*"DL(&%R<F%Y*"DI.PH@("`@("`@("`@("`@("`@("`@("1D
M871A6R=C;VYT96YT<R==6UT@/2!A<G)A>2@G='EP92<@/3X@)V5M<'1Y)RP@
M)VQI;F4G(#T^("1C;VYT96YT*3L*("`@("`@("`@("`@("`@("`@("`D<W1A
M=&4@/2`G9'5M<"<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\J($IU<W0@9FQU<V@@86YY(')E;6%I;FEN
M9R!E;G1R:65S(&EN('1H92!C;VQU;6YS('-T86-K+B`J+PH@("`@("`@('-W
M:71C:"`H)'-T871E*2!["B`@("`@("`@8V%S92`G861D)SH*("`@("`@("`@
M("`@)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G861D
M)RP@)VQI;F5S)R`]/B`D8V]L<ULP72D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E("=R96UO=F4G.@H@("`@("`@("`@("`O*B!792!H879E
M('-O;64@<F5M;W9A;"!L:6YE<R!P96YD:6YG(&EN(&]U<B!S=&%C:RP@<V\*
M("`@("`@("`@("`@("H@9FQU<V@@=&AE;2X@*B\*("`@("`@("`@("`@)&1A
M=&%;)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G<F5M;W9E)RP@
M)VQI;F5S)R`]/B`D8V]L<ULP72`I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92`G8VAA;F=E)SH*("`@("`@("`@("`@+RH@5V4@:&%V92!B
M;W1H(')E;6]V92!A;F0@861D:71I;VX@;&EN97,L('-O('1H:7,@:7,@80H@
M("`@("`@("`@("`@*B!C:&%N9V4@8FQO8VLN("HO"B`@("`@("`@("`@("1D
M871A6R=C;VYT96YT<R==6UT@/2!A<G)A>2@G='EP92<@/3X@)V-H86YG92<L
M("=O;&0G(#T^("1C;VQS6S!=+"`G;F5W)R`]/B`D8V]L<ULQ72D["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1D
M871A*2D@>PH@("`@("`@("`@("`D<F5T6UT@/2`D9&%T83L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K
M86=E(%9#"B`J+PIC;&%S<R!60U]&:6QE('L*"B`@("!V87(@)')E<#L*("`@
M('9A<B`D9&ER.PH@("`@=F%R("1N86UE.PH@("`@=F%R("1L;V=S.PH@("`@
M=F%R("1R979S.PH@("`@=F%R("1H96%D.PH@("`@=F%R("1Q=6EC:VQO9SL*
M("`@('9A<B`D<WEM<F5V.PH@("`@=F%R("1R979S>6T["B`@("!V87(@)&)R
M86YC:&5S.PH*("`@(&9U;F-T:6]N('-E=%)E<&]S:71O<GDH)B1R97`I"B`@
M("!["B`@("`@("`@)'1H:7,M/G)E<"`]("8D<F5P.PH@("`@?0H*?0H*+RHJ
M"B`J(%9#(')E=FES:6]N<R!C;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@
M36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R
M("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C
M:V%G92!60PH@*B\*8VQA<W,@5D-?4F5V:7-I;VX@>PH*("`@("\J*@H@("`@
M("H@5F%L:61A=&EO;B!F=6YC=&EO;B!T;R!E;G-U<F4@=&AA="!A(')E=FES
M:6]N(&YU;6)E<B!I<R!O9B!T:&4*("`@("`J(')I9VAT(&9O<FTN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L("!686QU92!T;R!C:&5C:RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@:70@:7,@
M82!R979I<VEO;B!N=6UB97(*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:60H
M)'9A;"D*("`@('L*("`@("`@("!R971U<FX@)'9A;"`F)B!P<F5G7VUA=&-H
M*"<O7EM<9%PN72LD+R<L("1V86PI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1VEV96X@82!R979I<VEO;B!N=6UB97(L(')E;6]V92!A(&=I=F5N(&YU;6)E
M<B!O9B!P;W)T:6]N<R!F<F]M"B`@("`@*B!I="X@1F]R(&5X86UP;&4L(&EF
M('=E(')E;6]V92`R('!O<G1I;VYS(&]F(#$N,BXS+C0L('=E(&%R90H@("`@
M("H@;&5F="!W:71H(#$N,BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1V86P@("`@("!);G!U="!R979I<VEO;@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&%M;W5N="`@3G5M8F5R(&]F('!O<G1I;VYS('1O('-T<FEP"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%-T<FEP<&5D(')E=FES:6]N(&YU
M;6)E<@H@("`@("HO"B`@("!F=6YC=&EO;B!S=')I<"@D=F%L+"`D86UO=6YT
M*0H@("`@>PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1V86PI
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@
M("`@)'!O<R`](#`["B`@("`@("`@=VAI;&4@*"1A;6]U;G0M+2`^(#`@)B8@
M*"1P;W,@/2!S=')R<&]S*"1V86PL("<N)RDI("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`D=F%L(#T@<W5B<W1R*"1V86PL(#`L("1P;W,I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'!O<R`A/3T@9F%L<V4@/R`D=F%L(#H@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@<VEZ92!O9B!A(')E=FES
M:6]N(&YU;6)E<B!I<R!T:&4@;G5M8F5R(&]F('!O<G1I;VYS(&ET(&AA<RX*
M("`@("`J($9O<B!E>&%M<&QE+"`Q+#(N,RXT(&ES(&]F('-I>F4@-"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86P@(%)E=FES:6]N(&YU;6)E
M<B!T;R!D971E<FUI;F4@<VEZ92!O9@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@4VEZ92!O9B!R979I<VEO;B!N=6UB97(*("`@("`J+PH@("`@
M9G5N8W1I;VX@<VEZ96]F*"1V86PI"B`@("!["B`@("`@("`@:68@*"%60U]2
M979I<VEO;CHZ=F%L:60H)'9A;"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("AS=6)S=')?8V]U;G0H
M)'9A;"P@)RXG*2`K(#$I.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@
M82!V86QI9"!R979I<VEO;B!N=6UB97(L('1H:7,@=VEL;"!R971U<FX@=&AE
M(')E=FES:6]N"B`@("`@*B!N=6UB97(@9G)O;2!W:&EC:"!I="!B<F%N8VAE
M9"X@268@:70@8V%N;F]T(&)E(&1E=&5R;6EN960L('1H96X*("`@("`J(&9A
M;'-E(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'9A;"`@4F5V:7-I;VX@;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG?&)O;VQE86X@($)R86YC:"!P;VEN="!R979I<VEO;BP@;W(@9F%L
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)R86YC:%!O:6YT*"1V86PI"B`@
M("!["B`@("`@("`@+RH@0VAE8VL@:68@=V4@:&%V92!A('9A;&ED(')E=FES
M:6]N(&YU;6)E<B`J+PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED
M*"1V86PI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\J($EF(&ET<R!O;B!T:&4@=')U;FLL(&]R(&ES(&%N(&]D
M9"!S:7IE+"!R970@9F%L<V4@*B\*("`@("`@("!I9B`H5D-?4F5V:7-I;VXZ
M.G-I>F5O9B@D=F%L*2`\(#,@?'P@*%9#7U)E=FES:6]N.CIS:7IE;V8H)'9A
M;"D@)2`R*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!3=')I<"!O9F8@='=O(')E=FES:6]N('!O<G1I;VYS
M+"!A;F0@<F5T=7)N(&ET("HO"B`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N
M.CIS=')I<"@D=F%L+"`R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N
M('1W;R!35DX@<F5V:7-I;VX@;G5M8F5R<RP@=&AI<R!F:6=U<F5S(&]U="!W
M:&EC:"!O;F4@:7,*("`@("`J(&=R96%T97(@=&AA;B!T:&4@;W1H97(@8GD@
M<W1E<'!I;F<@86QO;F<@=&AE(&1E8VEM86P@<&]I;G1S"B`@("`@*B!U;G1I
M;"!A(&1I9F9E<F5N8V4@:7,@9F]U;F0L(&%T('=H:6-H('!O:6YT(&$@<VEG
M;B!C;VUP87)I<V]N"B`@("`@*B!O9B!T:&4@='=O(&ES(')E='5R;F5D+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E=C$@(%!E<FEO9"!D96QI
M;6ET960@<F5V:7-I;VX@;G5M8F5R"B`@("`@*B!`<&%R86T@<W1R:6YG("1R
M978R("!396-O;F0@<&5R:6]D(&1E;&EM:71E9"!R979I<VEO;B!N=6UB97(*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#$@:68@=&AE(&9I<G-T
M(&ES(&=R96%T97(L("TQ(&EF('1H92!S96-O;F0@:68@9W)E871E<BP*("`@
M("`J("`@("`@("`@("`@("`@("`@86YD(#`@:68@=&AE>2!A<F4@97%U86P*
M("`@("`J+PH@("`@9G5N8W1I;VX@8VUP*"1R978Q+"`D<F5V,BD*("`@('L*
M("`@("`@("!R971U<FX@=F5R<VEO;E]C;VUP87)E*"1R978Q+"`D<F5V,BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QO9VEC86P@<F5V
M:7-I;VX@8F5F;W)E('1H:7,@;VYE+B!.;W)M86QL>2P@=&AI<PH@("`@("H@
M=VEL;"!B92!T:&4@<F5V:7-I;VX@;6EN=7,@;VYE+"!B=70@:6X@=&AE(&-A
M<V4@;V8@82!N97<*("`@("`J(&)R86YC:"P@=V4@<W1R:7`@;V9F('1H92!L
M87-T('1W;R!D96-I;6%L('!L86-E<R!T;R!R971U<FX@=&AE"B`@("`@*B!O
M<FEG:6YA;"!B<F%N8V@@<&]I;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F5V("!2979I<VEO;B!N=6UB97(@=&\@9&5C<F5M96YT+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG?&)O;VQE86X@(%)E=FES:6]N(&YU
M;6)E<BP@;W(@9F%L<V4@:68@;F]N92!C;W5L9"!B90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@9&5T97)M:6YE9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<')E=B@D<F5V*0H@("`@>PH@("`@("`@("1L87-T7V1O="`]('-T
M<G)P;W,H)')E=BP@)RXG*3L*("`@("`@("`D=F%L(#T@<W5B<W1R*"1R978L
M("LK)&QA<W1?9&]T*3L*"B`@("`@("`@:68@*"TM)'9A;"`^(#`I('L*("`@
M("`@("`@("`@<F5T=7)N('-U8G-T<B@D<F5V+"`P+"`D;&%S=%]D;W0I("X@
M)'9A;#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&%S=%]D;W0M
M+3L*("`@("`@("`@("`@=VAI;&4@*"TM)&QA<W1?9&]T*2!["B`@("`@("`@
M("`@("`@("!I9B`H)')E=ELD;&%S=%]D;W1=(#T]("<N)RD@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`@<W5B<W1R*"1R978L(#`L("1L87-T7V1O
M="D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)')E=ELD;&%S=%]D;W1=
M(#T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A(')E=FES:6]N(&YU;6)E<B!O
M9B!T:&4@9F]R;2!X+GDN,"YZ+"!T:&ES(')E;6%P<R!I=`H@("`@("H@:6YT
M;R!T:&4@87!P<F]P<FEA=&4@8G)A;F-H(&YU;6)E<BP@=VAI8V@@:7,@>"YY
M+GH*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978@($5V96XM9&EG
M:70@<F5V:7-I;VX@;G5M8F5R(&]F(&$@8G)A;F-H"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@($]D9"UD:6=I="!"<F%N8V@@;G5M8F5R"B`@("`@
M*B\*("`@(&9U;F-T:6]N('1O0G)A;F-H*"1R978I"B`@("!["B`@("`@("`@
M+RH@0VAE8VL@:68@=V4@:&%V92!A('9A;&ED(')E=FES:6]N(&YU;6)E<B`J
M+PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF
M("@H)&5N9"`]('-T<G)P;W,H)')E=BP@)RXG*2D@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R
M979;)&5N9%T@/2`P.PH@("`@("`@(&EF("@H)&5N9#(@/2!S=')R<&]S*"1R
M978L("<N)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@<W5B
M<W1R*"1R978L("LK)&5N9"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M<W5B<W1R7W)E<&QA8V4H)')E=BP@)RXG+"`D96YD,BP@*"1E;F0M)&5N9#(K
M,2DI.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M:4-A;&5N9&%R+G!H<```````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,3$Q,C0R`#$P-#$W,S8R-S<S`#`R,#8R-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@0VQA<W,@
M<F5P<F5S96YT:6YG(&E#86QE;F1A<B!F:6QE<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE;F1A<BYP:'`L=B`Q+C4W+C0N,C8@
M,C`P-B\P,R\R."`P.#HP-3HT-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O
M+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R
M9&5?:4-A;&5N9&%R('L*"B`@("`O*BH*("`@("`J(%1H92!P87)E;G0@*&-O
M;G1A:6YI;F<I(&E#86QE;F1A<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A
M<B!(;W)D95]I0V%L96YD87(*("`@("`J+PH@("`@=F%R("1?8V]N=&%I;F5R
M(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92]V86QU92!P86ER
M<R!O9B!A='1R:6)U=&5S(&9O<B!T:&ES(&]B:F5C="`H54E$+`H@("`@("H@
M1%135$%25"P@971C+BDN(%=H:6-H(&%R92!P<F5S96YT(&1E<&5N9',@;VX@
M=&AE(&]B:F5C="!A;F0@;VX*("`@("`J('=H870@:VEN9"!O9B!C;VUP;VYE
M;G0@:70@:7,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]A='1R:6)U=&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($%N>2!C:&EL9')E;B`H8V]N=&%I;F5D*2!I0V%L96YD87(@8V]M<&]N96YT
M<R!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7V-O;7!O;F5N=',@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@06-C;W)D:6YG('1O(%)&0R`R-#(U+"!W92!S:&]U;&0@86QW
M87ES('5S92!#4DQ&+71E<FUI;F%T960@;&EN97,N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;F5W;&EN92`](")<<EQN
M(CL*"B`@("`O*BH*("`@("`J(&E#86QE;F1A<B!F;W)M870@=F5R<VEO;B`H
M9&EF9F5R96YT(&)E:&%V:6]R(&9O<B`Q+C`@86YD(#(N,`H@("`@("H@97-P
M96-I86QL>2!W:71H(')E8W5R<FEN9R!E=F5N=',I+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W9E<G-I;VX["@H@("`@
M9G5N8W1I;VX@2&]R9&5?:4-A;&5N9&%R*"1V97)S:6]N(#T@)S(N,"<I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]V97)S:6]N(#T@)'9E<G-I;VX["B`@("`@
M("`@)'1H:7,M/G-E=$%T=')I8G5T92@G5D524TE/3B<L("1V97)S:6]N*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(')E9F5R96YC92!T;R!A
M(&YE=R!C;VUP;VYE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@("`@("`D='EP92`@("`@("!4:&4@='EP92!O9B!C;VUP;VYE;G0@=&\@
M<F5T=7)N"B`@("`@*B!`<&%R86T@2&]R9&5?:4-A;&5N9&%R("1C;VYT86EN
M97(@($$@8V]N=&%I;F5R('1H870@=&AI<R!C;VUP;VYE;G0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!B92!A<W-O
M8VEA=&5D('=I=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@(%)E
M9F5R96YC92!T;R!A($AO<F1E7VE#86QE;F1A<E\J(&]B:F5C="!A<R!S<&5C
M:69I960N"B`@("`@*B\*("`@(&9U;F-T:6]N("9N97=#;VUP;VYE;G0H)'1Y
M<&4L("8D8V]N=&%I;F5R*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4W1R:6YG+G!H<"<["B`@("`@("`@)'1Y<&4@/2!3=')I;F<Z.FQO
M=V5R*"1T>7!E*3L*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?:4-A;&5N9&%R
M7R<@+B`D='EP93L*("`@("`@("!`:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]I0V%L96YD87(O)R`N("1T>7!E("X@)RYP:'`G.PH@("`@
M("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D
M8V]M<&]N96YT(#T@)FYE=R`D8VQA<W,H*3L*("`@("`@("`@("`@:68@*"1C
M;VYT86EN97(@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D8V]M<&]N
M96YT+3Y?8V]N=&%I;F5R(#T@)B1C;VYT86EN97(["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!3:&]U;&0@<F5T=7)N
M(&%N(&1U;6UY('@M=6YK;F]W;B!T>7!E(&-L87-S(&AE<F4N"B`@("`@("`@
M("`@("1C;VUP;VYE;G0@/2!F86QS93L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1C;VUP;VYE;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE
M('9A;'5E(&]F(&%N(&%T=')I8G5T92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@("!4:&4@;F%M92!O9B!T:&4@871T<FEB=71E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("`@5&AE('9A;'5E(&]F('1H
M92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("!!
M<G)A>2!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;B!P87)A;65T97)S(&9O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!A='1R:6)U=&4N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D87!P96YD("!4<G5E('1O(&%P<&5N
M9"!T:&4@871T<FEB=71E+"!&86QS92!T;R!R97!L86-E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@9FER<W0@;6%T8VAI;F<@871T<FEB
M=71E(&9O=6YD+@H@("`@("H@0'!A<F%M(&%R<F%Y("1V86QU97,@("`@07)R
M87D@<F5P<F5S96YT871I;VX@;V8@)'9A;'5E+B`@1F]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!C;VUM82]S96UI8V]L;VX@<V5P97)A=&5D
M(&QI<W1S(&]F('9A;'5E<RX@($EF"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!N;W0@<V5T('5S92`D=F%L=64@87,@<VEN9VQE(&%R<F%Y(&5L
M96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$%T=')I8G5T92@D;F%M
M92P@)'9A;'5E+"`D<&%R86US(#T@87)R87DH*2P@)&%P<&5N9"`]('1R=64L
M("1V86QU97,@/2!F86QS92D*("`@('L*("`@("`@("`O+R!-86ME('-U<F4@
M=V4@=7!D871E('1H92!I;G1E<FYA;"!F;W)M870@=F5R<VEO;B!I9@H@("`@
M("`@("\O('-E=$%T=')I8G5T92@G5D524TE/3B<L("XN+BD@:7,@8V%L;&5D
M+@H@("`@("`@(&EF("@D;F%M92`]/2`G5D524TE/3B<I('L*("`@("`@("`@
M("`@)'1H:7,M/E]V97)S:6]N(#T@)'9A;'5E.PH@("`@("`@('T*"B`@("`@
M("`@)&9O=6YD(#T@)&%P<&5N9#L*("`@("`@("!I9B`H(21V86QU97,I('L*
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1V86QU92D["B`@("`@("`@
M?0H@("`@("`@("1K97ES(#T@87)R87E?:V5Y<R@D=&AI<RT^7V%T=')I8G5T
M97,I.PH@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@
M("`@("`@:68@*"1F;W5N9"D@8G)E86L["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7V%T=')I8G5T97-;)&ME>5U;)VYA;64G72`]/2!3=')I;F<Z.G5P<&5R
M*"1N86UE*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S
M6R1K97E=6R=P87)A;7,G72`]("1P87)A;7,["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)W9A;'5E)UT@/2`D=F%L=64["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)W9A;'5E
M<R==(#T@)'9A;'5E<SL*("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D87!P96YD
M('Q\("$D9F]U;F0I('L*("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S
M6UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=N86UE)R`@("`@(#T^(%-T
M<FEN9SHZ=7!P97(H)&YA;64I+`H@("`@("`@("`@("`@("`@)W!A<F%M<R<@
M("`@/3X@)'!A<F%M<RP*("`@("`@("`@("`@("`@("=V86QU92<@("`@(#T^
M("1V86QU92P*("`@("`@("`@("`@("`@("=V86QU97,G("`@(#T^("1V86QU
M97,*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('!A<F%M971E<BAS*2!F;W(@86X@*&%L<F5A9'D@97AI<W1I
M;F<I(&%T=')I8G5T92X@(%1H90H@("`@("H@<&%R86UE=&5R('-E="!I<R!M
M97)G960@:6YT;R!T:&4@97AI<W1I;F<@<V5T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("!4:&4@;F%M92!O9B!T:&4@871T<FEB=71E
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%R<F%Y(&-O;G1A:6YI
M;F<@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!F;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!T:&ES(&%T=')I8G5T92X*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!I9B!N;R!A='1R
M:6)U=&4@)&YA;64@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9710
M87)A;65T97(H)&YA;64L("1P87)A;7,I"B`@("!["B`@("`@("`@)&ME>7,@
M/2!A<G)A>5]K97ES*"1T:&ES+3Y?871T<FEB=71E<RD["B`@("`@("`@9F]R
M96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]A='1R:6)U=&5S6R1K97E=6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG<&%R86US)UT@
M/0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*"1T:&ES+3Y?871T
M<FEB=71E<ULD:V5Y75LG<&%R86US)UTL("1P87)A;7,I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@=F%L=64@;V8@86X@871T<FEB=71E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!N86UE(&]F('1H92!A='1R:6)U
M=&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<&%R86US("!2971U<FX@=&AE
M('!A<F%M971E<G,@9F]R('1H:7,@871T<FEB=71E(&EN<W1E860*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&]F(&ET<R!V86QU92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("AO8FIE8W0I("!014%27T5R<F]R(&EF
M('1H92!A='1R:6)U=&4@9&]E<R!N;W0@97AI<W0N"B`@("`@*B`@("`@("`@
M("`@("`@("AS=')I;F<I("!4:&4@=F%L=64@;V8@=&AE(&%T=')I8G5T92X*
M("`@("`J("`@("`@("`@("`@("`@*&%R<F%Y*2`@(%1H92!P87)A;65T97)S
M(&9O<B!T:&4@871T<FEB=71E(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!M=6QT:7!L92!V86QU97,@9F]R(&%N(&%T=')I8G5T92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T071T<FEB=71E*"1N86UE+"`D<&%R86US
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)')E<W5L="`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S("1A='1R:6)U
M=&4I('L*("`@("`@("`@("`@:68@*"1A='1R:6)U=&5;)VYA;64G72`]/2`D
M;F%M92D@>PH@("`@("`@("`@("`@("`@:68@*"1P87)A;7,I('L*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT6UT@/2`D871T<FEB=71E6R=P87)A;7,G
M73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)')E<W5L=%M=(#T@)&%T=')I8G5T95LG=F%L=64G73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M(6-O=6YT*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M4$5!4BYP:'`G.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G071T<FEB=71E("(G("X@)&YA;64@+B`G(B!.;W0@1F]U;F0G*3L*("`@
M("`@("!](&EF("AC;W5N="@D<F5S=6QT*2`]/2`Q("8F("$D<&%R86US*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT6S!=.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE('9A;'5E<R!O9B!A;B!A='1R
M:6)U=&4@87,@86X@87)R87DN("!-=6QT:7!L92!V86QU97,*("`@("`J(&%R
M92!P;W-S:6)L92!D=64@=&\Z"B`@("`@*@H@("`@("H@(&$I(&UU;'1I<&QC
M92!O8V-U<F5N8V5S(&]F("=N86UE)PH@("`@("H@(&(I("AU;G-E8V%P9"D@
M8V]M;6$@<V5P97)A=&5D(&QI<W1S+@H@("`@("H*("`@("`J(%-O(&9O<B!A
M('9C87)D(&QI:V4@(DM%63IA+&)<;DM%63IC(B!G971!='1R:6)U=&5S5F%L
M=65S*"=+15DG*0H@("`@("H@=VEL;"!R971U<FX@87)R87DH)V$G+"=B)RPG
M8R<I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1N86UE("`@(%1H
M92!N86UE(&]F('1H92!A='1R:6)U=&4N"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("AO8FIE8W0I("!014%27T5R<F]R(&EF('1H92!A='1R:6)U=&4@9&]E<R!N
M;W0@97AI<W0N"B`@("`@*B`@("`@("`@("`@("`@("AA<G)A>2D@("!-=6QT
M:7!L92!V86QU97,@9F]R(&%N(&%T=')I8G5T92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T071T<FEB=71E5F%L=65S*"1N86UE*0H@("`@>PH@("`@("`@
M("1R97-U;'0@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M871T<FEB=71E<R!A<R`D871T<FEB=71E*2!["B`@("`@("`@("`@(&EF("@D
M871T<FEB=71E6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2!A<G)A>5]M97)G92@D871T<FEB=71E6R=V86QU97,G72P@
M)')E<W5L="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@
M*"%C;W5N="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G071T<FEB=71E("(G("X@)&YA;64@+B`G(B!.;W0@1F]U
M;F0G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!V86QU92!O9B!A;B!A='1R
M:6)U=&4L(&]R(&$@<W!E8VEF:65D(&1E9F%U;'0@=F%L=64*("`@("`J(&EF
M('1H92!A='1R:6)U=&4@9&]E<R!N;W0@97AI<W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@("!4:&4@;F%M92!O9B!T:&4@871T<FEB
M=71E+@H@("`@("H@0'!A<F%M(&UI>&5D("1D969A=6QT("!7:&%T('1O(')E
M='5R;B!I9B!T:&4@871T<FEB=71E('-P96-I9FEE9"!B>0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`D;F%M92!D;V5S(&YO="!E>&ES="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("AS=')I;F<I(%1H92!V86QU92!O
M9B`D;F%M92X*("`@("`J("`@("`@("`@("`@("`@*&UI>&5D*2`@)&1E9F%U
M;'0@:68@)&YA;64@9&]E<R!N;W0@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%T=')I8G5T941E9F%U;'0H)&YA;64L("1D969A=6QT(#T@)R<I
M"B`@("!["B`@("`@("`@)'9A;'5E(#T@)'1H:7,M/F=E=$%T=')I8G5T92@D
M;F%M92D["B`@("`@("`@<F5T=7)N(&ES7V$H)'9A;'5E+"`G4$5!4E]%<G)O
M<B<I(#\@)&1E9F%U;'0@.B`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296UO=F4@86QL(&]C8W5R96YC97,@;V8@86X@871T<FEB=71E+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H
M92!A='1R:6)U=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94%T=')I
M8G5T92@D;F%M92D*("`@('L*("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H
M)'1H:7,M/E]A='1R:6)U=&5S*3L*("`@("`@("!F;W)E86-H("@D:V5Y<R!A
M<R`D:V5Y*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V%T=')I8G5T97-;
M)&ME>5U;)VYA;64G72`]/2`D;F%M92D@>PH@("`@("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A='1R:6)U=&5S
M(&9O<B!A;&P@=&%G<R!O<B!F;W(@82!G:79E;B!T86<N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&%G("!2971U<FX@871T<FEB=71E<R!F;W(@
M=&AI<R!T86<L(&]R(&%L;"!A='1R:6)U=&5S(&EF"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@(&YO="!G:79E;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!;B!A<G)A>2!C;VYT86EN:6YG(&%L;"!T:&4@871T<FEB=71E
M<R!A;F0@=&AE:7(@='EP97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%L
M;$%T=')I8G5T97,H)'1A9R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D
M=&%G(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]A
M='1R:6)U=&5S.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&%T
M=')I8G5T92D@>PH@("`@("`@("`@("!I9B`H)&%T=')I8G5T95LG;F%M92==
M(#T]("1T86<I('L*("`@("`@("`@("`@("`@("1R97-U;'1;72`]("1A='1R
M:6)U=&4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!V0V%L96YD
M87(@8V]M<&]N96YT("AE9R!V179E;G0L('94:6UE>F]N92P@971C+BDN"B`@
M("`@*@H@("`@("H@0'!A<F%M($AO<F1E7VE#86QE;F1A<B`D8V]M<&]N96YT
M("!#;VUP;VYE;G0@*'-U8F-L87-S*2!T;R!A9&0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$-O;7!O;F5N="@D8V]M<&]N96YT*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A*"1C;VUP;VYE;G0L("=(;W)D95]I0V%L96YD87(G*2D@>PH@
M("`@("`@("`@("`D8V]M<&]N96YT+3Y?8V]N=&%I;F5R(#T@)B1T:&ES.PH@
M("`@("`@("`@("`D=&AI<RT^7V-O;7!O;F5N='-;72`]("8D8V]M<&]N96YT
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&%L
M;"!T:&4@8V]M<&]N96YT<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!<G)A>2!O9B!(;W)D95]I0V%L96YD87(@;V)J96-T<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0V]M<&]N96YT<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8V]M<&]N96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@8VQA<W-E<R`H96YT<GD@='EP97,I('=E(&AA=F4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@2&%S:"!W:71H(&-L87-S(&YA
M;65S($AO<F1E7VE#86QE;F1A<E]X>'@@87,@:V5Y<PH@("`@("H@("`@("`@
M("`@("`@("`@86YD(&YU;6)E<B!O9B!C;VUP;VYE;G1S(&]F('1H:7,@8VQA
M<W,@87,@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;7!O;F5N
M=$-L87-S97,H*0H@("`@>PH@("`@("`@("1R(#T@87)R87DH*3L*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7V-O;7!O;F5N=',@87,@)&,I('L*("`@("`@
M("`@("`@)&-N(#T@<W1R=&]L;W=E<BAG971?8VQA<W,H)&,I*3L*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1R6R1C;ETI*2!["B`@("`@("`@("`@("`@("`D
M<ELD8VY=(#T@,3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1R6R1C;ETK*SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R.PH@("`@?0H*("`@("\J*@H@("`@("H@3G5M8F5R(&]F
M(&-O;7!O;F5N=',@:6X@=&AI<R!C;VYT86EN97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!.=6UB97(@;V8@8V]M<&]N96YT<R!I;B!T:&ES
M(&-O;G1A:6YE<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]M<&]N96YT
M0V]U;G0H*0H@("`@>PH@("`@("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V-O
M;7!O;F5N=',I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@82!S
M<&5C:69I8R!C;VUP;VYE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&ED>"`@5&AE(&EN9&5X(&]F('1H92!O8FIE8W0@=&\@<F5T<FEE=F4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@("`H8F]O;&5A;BD@1F%L
M<V4@:68@=&AE(&EN9&5X(&1O97,@;F]T(&5X:7-T+@H@("`@("H@("`@("`@
M("`@("`@("`@("`H2&]R9&5?:4-A;&5N9&%R7RHI(%1H92!R97%U97-T960@
M8V]M<&]N96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VUP;VYE;G0H
M)&ED>"D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C;VUP;VYE
M;G1S6R1I9'A=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VUP
M;VYE;G1S6R1I9'A=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,
M;V-A=&5S('1H92!F:7)S="!C:&EL9"!C;VUP;VYE;G0@;V8@=&AE('-P96-I
M9FEE9"!C;&%S<RP@86YD"B`@("`@*B!R971U<FYS(&$@<F5F97)E;F-E('1O
M('1H:7,@8V]M<&]N96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1Y<&4@(%1H92!T>7!E(&]F(&-O;7!O;F5N="!T;R!F:6YD+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@*&)O;VQE86XI($9A;'-E(&EF(&YO('-U
M8F-O;7!O;F5N="!O9B!T:&4@<W!E8VEF:65D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!C;&%S<R!E>&ES=',N"B`@("`@*B`@("`@("`@("`@
M("`@("A(;W)D95]I0V%L96YD87)?*BD@02!R969E<F5N8V4@=&\@=&AE(')E
M<75E<W1E9"!C;VUP;VYE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F:6YD
M0V]M<&]N96YT*"1C:&EL9&-L87-S*0H@("`@>PH@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["B`@("`@("`@)&-H:6QD8VQA<W,@
M/2`G2&]R9&5?:4-A;&5N9&%R7R<@+B!3=')I;F<Z.FQO=V5R*"1C:&EL9&-L
M87-S*3L*("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]C;VUP
M;VYE;G1S*3L*("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@
M("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?8V]M<&]N96YT<ULD:V5Y72P@
M)&-H:6QD8VQA<W,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]C;VUP;VYE;G1S6R1K97E=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;&5A<G,@=&AE(&E#86QE;F1A<B!O8FIE8W0@*')E<V5T<R!T:&4@8V]M<&]N
M96YT<R!A;F0@871T<FEB=71E<PH@("`@("H@87)R87ES*2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8VQE87(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]M
M<&]N96YT<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S
M(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A<R!V
M0V%L96YD87(@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1V
M0V%L96YD87(H*0H@("`@>PH@("`@("`@("\O($1E9F%U;'0@=F%L=65S+@H@
M("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)U!23T1)1"==(#T@)RTO+U1H
M92!(;W)D92!0<F]J96-T+R](;W)D95]I0V%L96YD87(@3&EB<F%R>2<@+B`H
M9&5F:6YE9"@G2$]21$5?5D524TE/3B<I(#\@)RP@2&]R9&4@)R`N(&-O;G-T
M86YT*"=(3U)$15]615)324].)RD@.B`G)RD@+B`G+R]%3B<["B`@("`@("`@
M)')E<75I<F5D071T<FEB=71E<ULG34542$]$)UT@/2`G4%5"3$E32"<["@H@
M("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9$%T=')I8G5T97,@87,@)&YA;64@
M/3X@)&1E9F%U;'1?=F%L=64I('L*("`@("`@("`@("`@:68@*&ES7V$H)'1H
M:7,M/F=E=&%T=')I8G5T92@D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)&YA;64L("1D969A
M=6QT7W9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?97AP;W)T=D1A=&$H)U9#04Q%3D1!4B<I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@17AP;W)T('1H:7,@96YT<GD@87,@82!H87-H
M(&%R<F%Y('=I=&@@=&%G(&YA;65S(&%S(&ME>7,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'!A<F%M<TEN2V5Y<PH@("`@("H@("`@("`@("`@
M("`@("`@268@9F%L<V4L('1H92!O<&5R871I;VX@8V%N(&)E('%U:71E(&QO
M<W-Y(&%S('1H90H@("`@("H@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!A
M<F4@:6=N;W)E9"!W:&5N(&)U:6QD:6YG('1H92!A<G)A>2!K97ES+@H@("`@
M("H@("`@("`@("`@("`@("`@4V\@:68@>6]U(&5X<&]R="!A('9C87)D('=I
M=&@*("`@("`J("`@("`@("`@("`@("`@($Q!0D5,.U194$4]5T]22SIF;V\*
M("`@("`J("`@("`@("`@("`@("`@($Q!0D5,.U194$4]2$]-13IB87(*("`@
M("`J("`@("`@("`@("`@("`@('1H92!R97-U;'1I;F<@:&%S:"!C;VYT86EN
M<R!O;FQY(&]N92!L86)E;"!F:65L9"$*("`@("`J("`@("`@("`@("`@("`@
M($EF('-E="!T;R!T<G5E+"!A<G)A>2!K97ES(&QO;VL@;&EK92`G3$%"14P[
M5%E013U73U)+)PH@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H(&%R<F%Y
M('=I=&@@=&%G(&YA;65S(&%S(&ME>7,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1O2&%S:"@D<&%R86US26Y+97ES(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)&AA<V@@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T
M<FEB=71E<R!A<R`D82D@('L*("`@("`@("`@("`@)&L@/2`D85LG;F%M92==
M.PH@("`@("`@("`@("!I9B`H)'!A<F%M<TEN2V5Y<R`F)B!I<U]A<G)A>2@D
M85LG<&%R86US)UTI*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D85LG
M<&%R86US)UT@87,@)'`@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`D
M:R`N/2`B.R1P/21V(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:&%S:%LD:UT@/2`D85LG=F%L=64G73L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D:&%S:#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%!A<G-E<R!A('-T<FEN9R!C;VYT86EN:6YG('9#86QE;F1A<B!D871A
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@(%1H92!D
M871A('1O('!A<G-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F%S92`@("`@
M5&AE('1Y<&4@;V8@=&AE(&)A<V4@;V)J96-T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8VAA<G-E="`@5&AE(&5N8V]D:6YG(&-H87)S970@9F]R("1T97AT
M+B!$969A=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M=71F+3@N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8VQE87(@("!)9B!T<G5E
M(&-L96%R<R!T:&4@:4-A;"!O8FIE8W0@8F5F;W)E('!A<G-I;F<N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W-F=6P@
M:6UP;W)T+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!A<G-E=D-A;&5N9&%R*"1T97AT+"`D8F%S92`]("=60T%,14Y$05(G+"`D
M8VAA<G-E="`]("=U=&8M."<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8VQE87(@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@D8VQE87(I('L*
M("`@("`@("`@("`@)'1H:7,M/F-L96%R*"D["B`@("`@("`@?0H@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O*$)%1TE..B<@+B`D8F%S92`N("=<<C]<;C\I
M*%M<5UQW72HI*$5.1#HG("X@)&)A<V4@+B`G7'(_7&X_*2]I)RP@)'1E>'0L
M("1M871C:&5S*2D@>PH@("`@("`@("`@("`D=D-A;"`]("1M871C:&5S6S)=
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%1E>'0@:7-N)W0@
M96YC;&]S960@:6X@0D5'24XZ5D-!3$5.1$%2"B`@("`@("`@("`@("\O("XN
M($5.1#I60T%,14Y$05(N(%=E)VQL('1R>2!T;R!P87)S92!I="!A;GEW87DN
M"B`@("`@("`@("`@("1V0V%L(#T@)'1E>'0["B`@("`@("`@?0H*("`@("`@
M("`O+R!!;&P@<W5B8V]M<&]N96YT<RX*("`@("`@("`D;6%T8VAE<R`](&YU
M;&P["B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<O0D5'24XZ*%M<5UQW
M72HI*%QR7&Y\7')\7&XI*%M<5UQW72HI14Y$.EPQ*%QR7&Y\7')\7&XI+U5I
M)RP@)'9#86PL("1M871C:&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M;6%T8VAE<ULP72!A<R`D:V5Y(#T^("1D871A*2!["B`@("`@("`@("`@("`@
M("`D='EP92`]("1M871C:&5S6S%=6R1K97E=.PH@("`@("`@("`@("`@("`@
M)&-O;7!O;F5N="`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O;7!O;F5N="AT
M<FEM*"1T>7!E*2P@)'1H:7,I.PH@("`@("`@("`@("`@("`@:68@*"1C;VUP
M;VYE;G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(E5N86)L92!T;R!C<F5A=&4@;V)J96-T(&9O
M<B!T>7!E("1T>7!E(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D8V]M<&]N96YT+3YP87)S979#86QE;F1A<B@D9&%T82D["@H@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9$-O;7!O;F5N="@D8V]M<&]N96YT*3L*
M"B`@("`@("`@("`@("`@("`O+R!296UO=F4@9G)O;2!T:&4@=D-A;&5N9&%R
M(&1A=&$N"B`@("`@("`@("`@("`@("`D=D-A;"`]('-T<E]R97!L86-E*"1D
M871A+"`G)RP@)'9#86PI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!5;F9O;&0@86YY(&9O;&1E9"!L:6YE<RX*("`@("`@("`D=D-A
M;"`]('!R96=?<F5P;&%C92@G+UM<<EQN72M;(%QT72\G+"`G)RP@)'9#86PI
M.PH*("`@("`@("`O+R!5;F9O;&0@(G%U;W1E9"!P<FEN=&%B;&4B(&9O;&1E
M9"!L:6YE<R!L:6ME.@H@("`@("`@("\O("!"3T19.T5.0T]$24Y'/5%53U1%
M1"U04DE.5$%"3$4Z/0H@("`@("`@("\O("!A;F]T:&5R/3(P;&EN93T*("`@
M("`@("`O+R`@;&%S=#TR,&QI;F4*("`@("`@("!I9B`H<')E9U]M871C:%]A
M;&PH)R]>*%M>.ETK.UQS*D5.0T]$24Y'/5%53U1%1"U04DE.5$%"3$4H+BH]
M7'(_7&XI*R@N*EM>/5TI/UQR/UQN*2]M52<L("1V0V%L+"`D;6%T8VAE<RDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&UA=&-H97-;,5T@87,@)',I('L*
M("`@("`@("`@("`@("`@("1R(#T@<')E9U]R97!L86-E*"<O/5QR/UQN+R<L
M("<G+"`D<RD["B`@("`@("`@("`@("`@("`D=D-A;"`]('-T<E]R97!L86-E
M*"1S+"`D<BP@)'9#86PI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!087)S92!T:&4@<F5M86EN:6YG(&%T=')I8G5T97,N"B`@("`@
M("`@:68@*'!R96=?;6%T8VA?86QL*"<O*"XJ*3HH6UY<<EQN72HI6UQR7&Y=
M*R\G+"`D=D-A;"P@)&UA=&-H97,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1M871C:&5S6S!=(&%S("1A='1R:6)U=&4I('L*("`@("`@("`@("`@("`@
M('!R96=?;6%T8V@H)R\H6UX[7CI=*BDH*#M;7CI=*BD_*3HH6UY<<EQN72HI
M6UQR7&Y=*B\G+"`D871T<FEB=71E+"`D<&%R=',I.PH@("`@("`@("`@("`@
M("`@)'1A9R`]("1P87)T<ULQ73L*("`@("`@("`@("`@("`@("1V86QU92`]
M("1P87)T<ULT73L*("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I
M.PH*("`@("`@("`@("`@("`@("\O(%!A<G-E('!A<F%M971E<G,N"B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1P87)T<ULR72DI('L*("`@("`@("`@
M("`@("`@("`@("!P<F5G7VUA=&-H7V%L;"@G+SLH*%M>.SU=*BDH/2A;7CM=
M*BDI/RDO)RP@)'!A<G1S6S)=+"`D<&%R86U?<&%R=',I.PH@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1P87)A;5]P87)T<ULR72!A<R`D:V5Y(#T^
M("1P87)A;4YA;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M5F%L=64@/2`D<&%R86U?<&%R='-;-%U;)&ME>5T["B`@("`@("`@("`@("`@
M("`@("`@("`@("1P87)A;7-;4W1R:6YG.CIU<'!E<B@D<&%R86U.86UE*5T@
M/2`D<&%R86U686QU93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@0VAA<G-E="!A;F0@96YC
M;V1I;F<@:&%N9&QI;F<N"B`@("`@("`@("`@("`@("!I9B`H*&ES<V5T*"1P
M87)A;7-;)T5.0T]$24Y')UTI"B`@("`@("`@("`@("`@("`@("`@("8F(%-T
M<FEN9SHZ=7!P97(H)'!A<F%M<ULG14Y#3T1)3D<G72D@/3T@)U%53U1%1"U0
M4DE.5$%"3$4G*0H@("`@("`@("`@("`@("`@("`@('Q\(&ES<V5T*"1P87)A
M;7-;)U%53U1%1"U04DE.5$%"3$4G72DI('L*"B`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E(#T@<75O=&5D7W!R:6YT86)L95]D96-O9&4H)'9A;'5E*3L*
M("`@("`@("`@("`@("`@("`@("`O+R!1=6]T960@<')I;G1A8FQE(&ES(&YO
M<FUA;&QY(&5N8V]D960@87,@=71F+3@N"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1P87)A;7-;)T-(05)3150G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M=F%L=64L("1P87)A;7-;)T-(05)3150G72D["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("=U=&8M."<I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D<&%R86US6R=#2$%24T54)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1P
M87)A;7-;)T-(05)3150G72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("\O($%S('!E<B!21D,@,C(W.2P@87-S=6UE
M(%541C@@:68@=V4@9&]N)W0@:&%V92!A;@H@("`@("`@("`@("`@("`@("`@
M("\O(&5X<&QI8VET(&-H87)S970@<&%R86UE=&5R+@H@("`@("`@("`@("`@
M("`@("`@("1V86QU92`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E
M+"`D8VAA<G-E="D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@<W=I=&-H("@D=&%G*2!["B`@("`@("`@("`@("`@("`O+R!$871E(&9I
M96QD<RX*("`@("`@("`@("`@("`@(&-A<V4@)T-/35!,151%1"<Z"B`@("`@
M("`@("`@("`@("!C87-E("=#4D5!5$5$)SH*("`@("`@("`@("`@("`@(&-A
M<V4@)TQ!4U0M34]$249)140G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971!='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941A=&54:6UE*"1V
M86QU92DL("1P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&-A<V4@)T)$05DG.@H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941A
M=&4H)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G1%1%3D0G.@H@("`@("`@("`@
M("`@("`@8V%S92`G1%135$%25"<Z"B`@("`@("`@("`@("`@("!C87-E("=$
M5%-404U0)SH*("`@("`@("`@("`@("`@(&-A<V4@)T1512<Z"B`@("`@("`@
M("`@("`@("!C87-E("=!04Q!4DTG.@H@("`@("`@("`@("`@("`@8V%S92`G
M4D5#55)214Y#12U)1"<Z"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1P87)A;7-;)U9!3%5%)UTI("8F("1P87)A;7-;)U9!3%5%)UT@/3T@)T1!
M5$4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R
M:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941A=&4H)'9A;'5E*2P@)'!A<F%M
M<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"`D=&AI<RT^
M7W!A<G-E1&%T951I;64H)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&-A<V4@)U1224='15(G.@H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=604Q512==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H)'!A<F%M<ULG5D%,544G72`]/2`G1$%412U424U%
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T
M=')I8G5T92@D=&%G+"`D=&AI<RT^7W!A<G-E1&%T951I;64H)'9A;'5E*2P@
M)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E
M*"1T86<L("1T:&ES+3Y?<&%R<V5$=7)A=&EO;B@D=F%L=64I+"`D<&%R86US
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M971!='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941U<F%T:6]N*"1V86QU
M92DL("1P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!#;VUM82!S
M97!E<F%T960@9&%T97,N"B`@("`@("`@("`@("`@("!C87-E("=%6$1!5$4G
M.@H@("`@("`@("`@("`@("`@8V%S92`G4D1!5$4G.@H@("`@("`@("`@("`@
M("`@("`@("1D871E<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@
M<')E9U]M871C:%]A;&PH)R\L*%M>+%TJ*2\G+"`G+"<@+B`D=F%L=64L("1V
M86QU97,I.PH*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=65S
M6S%=(&%S("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M97-;72`]("1T:&ES+3Y?<&%R<V5$871E*"1V86QU92D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R
M:6)U=&4H)'1A9RP@:7-S970H)&1A=&5S6S!=*2`_("1D871E<ULP72`Z(&YU
M;&PL("1P87)A;7,L('1R=64L("1D871E<RD["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@1'5R871I;VX@9FEE;&1S
M+@H@("`@("`@("`@("`@("`@8V%S92`G1%52051)3TXG.@H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P
M87)S941U<F%T:6]N*"1V86QU92DL("1P87)A;7,I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("\O(%!E<FEO9"!O9B!T
M:6UE(&9I96QD<RX*("`@("`@("`@("`@("`@(&-A<V4@)T92145"55-9)SH*
M("`@("`@("`@("`@("`@("`@("`D<&5R:6]D<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("`@("`@<')E9U]M871C:%]A;&PH)R\L*%M>+%TJ*2\G+"`G
M+"<@+B`D=F%L=64L("1V86QU97,I.PH@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1V86QU97-;,5T@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1P97)I;V1S6UT@/2`D=&AI<RT^7W!A<G-E4&5R:6]D*"1V
M86QU92D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L(&ES<V5T*"1P97)I;V1S
M6S!=*2`_("1P97)I;V1S6S!=(#H@;G5L;"P@)'!A<F%M<RP@=')U92P@)'!E
M<FEO9',I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@("\O(%540R!O9F9S970@9FEE;&1S+@H@("`@("`@("`@("`@("`@
M8V%S92`G5%I/1D93151&4D]-)SH*("`@("`@("`@("`@("`@(&-A<V4@)U1:
M3T9&4T545$\G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R
M:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S955T8T]F9G-E="@D=F%L=64I+"`D
M<&%R86US*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("`O+R!);G1E9V5R(&9I96QD<RX*("`@("`@("`@("`@("`@(&-A
M<V4@)U!%4D-%3E0M0T]-4$Q%5$4G.@H@("`@("`@("`@("`@("`@8V%S92`G
M4%))3U))5%DG.@H@("`@("`@("`@("`@("`@8V%S92`G4D5014%4)SH*("`@
M("`@("`@("`@("`@(&-A<V4@)U-%455%3D-%)SH*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L(&EN='9A;"@D=F%L=64I
M+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("`O+R!'96\@9FEE;&1S+@H@("`@("`@("`@("`@("`@8V%S
M92`G1T5/)SH*("`@("`@("`@("`@("`@("`@("`D9FQO871S(#T@97AP;&]D
M92@G.R<L("1V86QU92D["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=L
M871I='5D92==(#T@9FQO871V86PH)&9L;V%T<ULP72D["B`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E6R=L;VYG:71U9&4G72`](&9L;V%T=F%L*"1F;&]A
M='-;,5TI.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U
M=&4H)'1A9RP@)'9A;'5E+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!296-U<G-I;VX@9FEE;&1S
M+@H@("`@("`@("`@("`@("`@8V%S92`G15A254Q%)SH*("`@("`@("`@("`@
M("`@(&-A<V4@)U)254Q%)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T071T<FEB=71E*"1T86<L('1R:6TH)'9A;'5E*2P@)'!A<F%M<RD["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@
M0412(&%N($X@87)E(&QI<W1S('-E<&5R871E9"!B>2!U;F5S8V%P960@<V5M
M:2UC;VQO;G,N"B`@("`@("`@("`@("`@("!C87-E("=!1%(G.@H@("`@("`@
M("`@("`@("`@8V%S92`G3B<Z"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@=')I;2@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("\O($%S(&]F
M(')F8R`R-#(V(#(N-"XR('-E;6DM8V]L;VXL(&-O;6UA+"!A;F0*("`@("`@
M("`@("`@("`@("`@("`O+R!C;VQO;B!M=7-T(&)E(&5S8V%P960@*&-O;6UA
M(&ES('5N97-C87!E9"!A9G1E<@H@("`@("`@("`@("`@("`@("`@("\O('-P
M;&ET=&EN9R!B96QO=RDN"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M<W1R7W)E<&QA8V4H87)R87DH)UQ<;B<L("=<7#LG+"`G7%PZ)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H
M:7,M/E]N97=L:6YE+"`G.R<L("<Z)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E*3L*"B`@("`@("`@("`@("`@
M("`@("`@+R\@4W!L:70@8GD@=6YE<V-A<&5D('-E;6DM8V]L;VYS.@H@("`@
M("`@("`@("`@("`@("`@("1V86QU97,@/2!P<F5G7W-P;&ET*"<O*#\\(5Q<
M7%PI.R\G+"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M<W1R7W)E<&QA8V4H)UQ<.R<L("<[)RP@)'9A;'5E*3L*("`@("`@("`@("`@
M("`@("`@("`D=F%L=65S(#T@<W1R7W)E<&QA8V4H)UQ<.R<L("<[)RP@)'9A
M;'5E<RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T
M92@D=&%G+"!T<FEM*"1V86QU92DL("1P87)A;7,L('1R=64L("1V86QU97,I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M("\O(%-T<FEN9R!F:65L9',N"B`@("`@("`@("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`@("`@("`@("1V86QU92`]('1R:6TH)'9A;'5E*3L*("`@
M("`@("`@("`@("`@("`@("`O+R!!<R!O9B!R9F,@,C0R-B`R+C0N,B!S96UI
M+6-O;&]N+"!C;VUM82P@86YD"B`@("`@("`@("`@("`@("`@("`@+R\@8V]L
M;VX@;75S="!B92!E<V-A<&5D("AC;VUM82!I<R!U;F5S8V%P960@869T97(*
M("`@("`@("`@("`@("`@("`@("`O+R!S<&QI='1I;F<@8F5L;W<I+@H@("`@
M("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*&%R<F%Y*"=<
M7&XG+"`G7%P[)RP@)UQ<.B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?;F5W;&EN92P@)SLG+"`G
M.B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1V86QU92D["@H@("`@("`@("`@("`@("`@("`@("\O(%-P;&ET(&)Y('5N
M97-C87!E9"!C;VUM87,Z"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E<R`]
M('!R96=?<W!L:70H)R\H/SPA7%Q<7"DL+R<L)'9A;'5E*3L*("`@("`@("`@
M("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92@G7%PL)RP@)RPG+"`D
M=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!S=')?<F5P
M;&%C92@G7%PL)RP@)RPG+"`D=F%L=65S*3L*"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"!T<FEM*"1V86QU92DL("1P
M87)A;7,L('1R=64L("1V86QU97,I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($5X<&]R="!T:&ES(&-O;7!O;F5N="!I;B!V0V%L(&9O<FUA="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B87-E("!4:&4@='EP92!O9B!T:&4@
M8F%S92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('9#
M86P@9F]R;6%T(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E>'!O<G1V
M1&%T82@D8F%S92`]("=60T%,14Y$05(G*0H@("`@>PH@("`@("`@("1R97-U
M;'0@/2`G0D5'24XZ)R`N(%-T<FEN9SHZ=7!P97(H)&)A<V4I("X@)'1H:7,M
M/E]N97=L:6YE.PH*("`@("`@("`O+R!%;G-U<F4@=&AA="!V97)S:6]N(&ES
M('1H92!F:7)S="!A='1R:6)U=&4N"B`@("`@("`@)')E<W5L="`N/2`G5D52
M4TE/3CHG("X@)'1H:7,M/E]V97)S:6]N("X@)'1H:7,M/E]N97=L:6YE.PH*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&%T=')I
M8G5T92D@>PH@("`@("`@("`@("`D;F%M92`]("1A='1R:6)U=&5;)VYA;64G
M73L*("`@("`@("`@("`@:68@*"1N86UE(#T]("=615)324].)RD@>PH@("`@
M("`@("`@("`@("`@+R\@06QR96%D>2!D;VYE+@H@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1P87)A;7-?
M<W1R(#T@)R<["B`@("`@("`@("`@("1P87)A;7,@/2`D871T<FEB=71E6R=P
M87)A;7,G73L*("`@("`@("`@("`@:68@*"1P87)A;7,I('L*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M7VYA;64@/3X@)'!A
M<F%M7W9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@+R\@4VMI<"!#2$%2
M4T54(&9O<B!I0V%L96YD87(@,BXP(&1A=&$L(&YO=`H@("`@("`@("`@("`@
M("`@("`@("\O(&%L;&]W960N"B`@("`@("`@("`@("`@("`@("`@:68@*"1P
M87)A;5]N86UE(#T]("=#2$%24T54)R`F)B`D=&AI<RT^7W9E<G-I;VX@/3T@
M)S(N,"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1P87)A
M;7-?<W1R("X]("([)'!A<F%M7VYA;64])'!A<F%M7W9A;'5E(CL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'9A;'5E
M(#T@)&%T=')I8G5T95LG=F%L=64G73L*("`@("`@("`@("`@<W=I=&-H("@D
M;F%M92D@>PH@("`@("`@("`@("`O+R!$871E(&9I96QD<RX*("`@("`@("`@
M("`@8V%S92`G0T]-4$Q%5$5$)SH*("`@("`@("`@("`@8V%S92`G0U)%051%
M1"<Z"B`@("`@("`@("`@(&-A<V4@)T1#4D5!5$5$)SH*("`@("`@("`@("`@
M8V%S92`G3$%35"U-3T1)1DE%1"<Z"B`@("`@("`@("`@("`@("`D=F%L=64@
M/2`D=&AI<RT^7V5X<&]R=$1A=&54:6UE*"1V86QU92D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T1414Y$)SH*("`@("`@
M("`@("`@8V%S92`G1%135$%25"<Z"B`@("`@("`@("`@(&-A<V4@)T144U1!
M35`G.@H@("`@("`@("`@("!C87-E("=$544G.@H@("`@("`@("`@("!C87-E
M("=!04Q!4DTG.@H@("`@("`@("`@("!C87-E("=214-54E)%3D-%+4E$)SH*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=604Q512==*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&%R86US6R=604Q512==(#T]
M("=$051%)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`D
M=&AI<RT^7V5X<&]R=$1A=&4H)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`D
M=&AI<RT^7V5X<&]R=$1A=&54:6UE*"1V86QU92D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V5X<&]R=$1A=&54:6UE*"1V86QU
M92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("\O($-O;6UA('-E<&5R871E9"!D871E<RX*("`@("`@
M("`@("`@8V%S92`G15A$051%)SH*("`@("`@("`@("`@8V%S92`G4D1!5$4G
M.@H@("`@("`@("`@("`@("`@)&1A=&5S(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D9&%T92D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=604Q512==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<ULG5D%,544G72`]/2`G
M1$%412<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871E<UM=
M(#T@)'1H:7,M/E]E>'!O<G1$871E*"1D871E*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)U9!3%5%)UT@/3T@)U!%4DE/
M1"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871E<UM=(#T@
M)'1H:7,M/E]E>'!O<G1097)I;V0H)&1A=&4I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&5S6UT@/2`D=&AI<RT^7V5X<&]R=$1A=&54:6UE*"1D871E*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1D871E<UM=(#T@)'1H
M:7,M/E]E>'!O<G1$871E5&EM92@D9&%T92D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@:6UP;&]D92@G+"<L("1D871E<RD["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)U1224='15(G.@H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1P87)A;7-;)U9!3%5%)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1P87)A;7-;)U9!3%5%)UT@/3T@)T1!5$4M5$E-12<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]E
M>'!O<G1$871E5&EM92@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("@D<&%R86US6R=604Q512==(#T]("=$55)!5$E/3B<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]E>'!O<G1$
M=7)A=&EO;B@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@)'1H:7,M/E]E>'!O<G1$=7)A=&EO;B@D=F%L=64I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O
M+R!$=7)A=&EO;B!F:65L9',N"B`@("`@("`@("`@(&-A<V4@)T154D%424].
M)SH*("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?97AP;W)T1'5R
M871I;VXH)'9A;'5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@+R\@4&5R:6]D(&]F('1I;64@9FEE;&1S+@H@("`@("`@("`@("!C
M87-E("=&4D5%0E5362<Z"B`@("`@("`@("`@("`@("`D=F%L=65?<W1R(#T@
M)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)'!E<FEO
M9"D@>PH@("`@("`@("`@("`@("`@("`@("1V86QU95]S='(@+CT@96UP='DH
M)'9A;'5E7W-T<BD@/R`G)R`Z("<L)SL*("`@("`@("`@("`@("`@("`@("`D
M=F%L=65?<W1R("X]("1T:&ES+3Y?97AP;W)T4&5R:6]D*"1P97)I;V0I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'9A
M;'5E7W-T<CL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M+R\@551#(&]F9G-E="!F:65L9',N"B`@("`@("`@("`@(&-A<V4@)U1:3T9&
M4T541E)/32<Z"B`@("`@("`@("`@(&-A<V4@)U1:3T9&4T545$\G.@H@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]E>'!O<G15=&-/9F9S970H
M)'9A;'5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M+R\@26YT96=E<B!F:65L9',N"B`@("`@("`@("`@(&-A<V4@)U!%4D-%3E0M
M0T]-4$Q%5$4G.@H@("`@("`@("`@("!C87-E("=04DE/4DE462<Z"B`@("`@
M("`@("`@(&-A<V4@)U)%4$5!5"<Z"B`@("`@("`@("`@(&-A<V4@)U-%455%
M3D-%)SH*("`@("`@("`@("`@("`@("1V86QU92`]("(D=F%L=64B.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!'96\@9FEE;&1S
M+@H@("`@("`@("`@("!C87-E("='14\G.@H@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@)'9A;'5E6R=L871I='5D92==("X@)RPG("X@)'9A;'5E6R=L;VYG
M:71U9&4G73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M+R\@4F5C=7)R96YC92!F:65L9',N"B`@("`@("`@("`@(&-A<V4@)T584E5,
M12<Z"B`@("`@("`@("`@(&-A<V4@)U)254Q%)SH*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("\O($%S(&]F(')F8R`R-#(V(#(N-"XR('-E;6DM8V]L;VXL(&-O;6UA+"!A
M;F0@8V]L;VX*("`@("`@("`@("`@("`@("\O(&UU<W0@8F4@97-C87!E9"X@
M17AC;'5D92!-04E,5$\Z('1H;W5G:"X@5&AI<R!I<R!A(&AA8VLA"B`@("`@
M("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92AA<G)A>2@G.R<L("<Z
M)RP@)RPG+"`G34%)3%1/7%PZ)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G7%P[)RP@)UQ<.B<L("=<7"PG+"`G34%)
M3%1/.B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)T5.0T]$24Y')UTI
M("8F"B`@("`@("`@("`@("`@("`D<&%R86US6R=%3D-/1$E.1R==(#T]("=1
M54]4140M4%))3E1!0DQ%)R`F)B!S=')L96XH=')I;2@D=F%L=64I*2`^(#`I
M('L*("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*")<<B(L
M("<G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)')E<W5L="`N/2`B)&YA
M;64D<&%R86US7W-T<CH](B`N("1T:&ES+3Y?;F5W;&EN90H@("`@("`@("`@
M("`@("`@("`@("X@)'1H:7,M/E]Q=6]T9610<FEN=&%B;&5%;F-O9&4H)'9A
M;'5E*0H@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/E]N97=L:6YE.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&%T=')?<W1R
M:6YG(#T@(B1N86UE)'!A<F%M<U]S='(Z)'9A;'5E(CL*("`@("`@("`@("`@
M("`@("1R97-U;'0@+CT@)'1H:7,M/E]F;VQD3&EN92@D871T<E]S=')I;F<I
M("X@)'1H:7,M/E]N97=L:6YE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-O;7!O;F5N=',@87,@)&-O;7!O
M;F5N="D@>PH@("`@("`@("`@("`D<F5S=6QT("X]("1C;VUP;VYE;G0M/F5X
M<&]R='9#86QE;F1A<B@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M97-U;'0@+B`G14Y$.B<@+B`D8F%S92`N("1T:&ES+3Y?;F5W;&EN93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%!A<G-E(&$@551#($]F9G-E="!F:65L9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E571C3V9F<V5T*"1T97AT*0H@
M("`@>PH@("`@("`@("1O9F9S970@/2!A<G)A>2@I.PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O*%PK?"TI*%LP+3E=>S)]*2A;,"TY77LR?2DH6S`M.5U[
M,GTI/R\G+"`D=&5X="P@)'1I;65087)T<RDI('L*("`@("`@("`@("`@)&]F
M9G-E=%LG86AE860G72`@/2`H8F]O;"DH)'1I;65087)T<ULQ72`]/2`G*R<I
M.PH@("`@("`@("`@("`D;V9F<V5T6R=H;W5R)UT@("`](&EN='9A;"@D=&EM
M95!A<G1S6S)=*3L*("`@("`@("`@("`@)&]F9G-E=%LG;6EN=71E)UT@/2!I
M;G1V86PH)'1I;65087)T<ULS72D["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&EM95!A<G1S6S1=*2D@>PH@("`@("`@("`@("`@("`@)&]F9G-E=%LG<V5C
M;VYD)UT@/2!I;G1V86PH)'1I;65087)T<ULT72D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N("1O9F9S970["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($5X<&]R="!A(%540R!/9F9S970@9FEE;&0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]E>'!O<G15=&-/9F9S970H)'9A;'5E*0H@("`@
M>PH@("`@("`@("1O9F9S970@/2`D=F%L=65;)V%H96%D)UT@/R`G*R<@.B`G
M+2<["B`@("`@("`@)&]F9G-E="`N/2!S<')I;G1F*"<E,#)D)3`R9"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU95LG:&]U<B==+"`D=F%L
M=65;)VUI;G5T92==*3L*("`@("`@("!I9B`H:7-S970H)'9A;'5E6R=S96-O
M;F0G72DI('L*("`@("`@("`@("`@)&]F9G-E="`N/2!S<')I;G1F*"<E,#)D
M)RP@)'9A;'5E6R=S96-O;F0G72D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&]F9G-E=#L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E(&$@5&EM
M92!097)I;V0@9FEE;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95!E
M<FEO9"@D=&5X="D*("`@('L*("`@("`@("`D<&5R:6]D4&%R=',@/2!E>'!L
M;V1E*"<O)RP@)'1E>'0I.PH*("`@("`@("`D<W1A<G0@/2`D=&AI<RT^7W!A
M<G-E1&%T951I;64H)'!E<FEO9%!A<G1S6S!=*3L*"B`@("`@("`@:68@*"1D
M=7)A=&EO;B`]("1T:&ES+3Y?<&%R<V5$=7)A=&EO;B@D<&5R:6]D4&%R='-;
M,5TI*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G<W1A<G0G(#T^("1S
M=&%R="P@)V1U<F%T:6]N)R`]/B`D9'5R871I;VXI.PH@("`@("`@('T@96QS
M96EF("@D96YD(#T@)'1H:7,M/E]P87)S941A=&54:6UE*"1P97)I;V1087)T
M<ULQ72DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=S=&%R="<@/3X@
M)'-T87)T+"`G96YD)R`]/B`D96YD*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%>'!O<G0@82!4:6UE(%!E<FEO9"!F:65L9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V5X<&]R=%!E<FEO9"@D=F%L=64I"B`@("!["B`@
M("`@("`@)'!E<FEO9"`]("1T:&ES+3Y?97AP;W)T1&%T951I;64H)'9A;'5E
M6R=S=&%R="==*3L*("`@("`@("`D<&5R:6]D("X]("<O)SL*("`@("`@("!I
M9B`H:7-S970H)'9A;'5E6R=D=7)A=&EO;B==*2D@>PH@("`@("`@("`@("`D
M<&5R:6]D("X]("1T:&ES+3Y?97AP;W)T1'5R871I;VXH)'9A;'5E6R=D=7)A
M=&EO;B==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R:6]D
M("X]("1T:&ES+3Y?97AP;W)T1&%T951I;64H)'9A;'5E6R=E;F0G72D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D<&5R:6]D.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4&%R<V4@82!$871E5&EM92!F:65L9"!I;G1O(&$@=6YI>"!T
M:6UE<W1A;7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S941A=&54:6UE
M*"1T97AT*0H@("`@>PH@("`@("`@("1D871E4&%R=',@/2!E>'!L;V1E*"=4
M)RP@)'1E>'0I.PH@("`@("`@(&EF("AC;W5N="@D9&%T95!A<G1S*2`A/2`R
M("8F("%E;7!T>2@D=&5X="DI('L*("`@("`@("`@("`@+R\@3F]T(&$@9&%T
M971I;64@9FEE;&0@8G5T(&UA>2!B92!J=7-T(&$@9&%T92!F:65L9"X*("`@
M("`@("`@("`@:68@*"$D9&%T92`]("1T:&ES+3Y?<&%R<V5$871E*"1T97AT
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(')E='5R;B!`9VUM:W1I;64H,"P@,"P@,"P@)&1A
M=&5;)VUO;G1H)UTL("1D871E6R=M9&%Y)UTL("1D871E6R=Y96%R)UTI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"$D9&%T92`]("1T:&ES+3Y?<&%R<V5$
M871E*"1D871E4&%R='-;,%TI*2!["B`@("`@("`@("`@(')E='5R;B`D9&%T
M93L*("`@("`@("!]"B`@("`@("`@:68@*"$D=&EM92`]("1T:&ES+3Y?<&%R
M<V54:6UE*"1D871E4&%R='-;,5TI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&EM93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&EM95LG>F]N92==(#T]
M("=55$,G*2!["B`@("`@("`@("`@(')E='5R;B!`9VUM:W1I;64H)'1I;65;
M)VAO=7(G72P@)'1I;65;)VUI;G5T92==+"`D=&EM95LG<V5C;VYD)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5;)VUO;G1H)UTL("1D
M871E6R=M9&%Y)UTL("1D871E6R=Y96%R)UTI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!`;6MT:6UE*"1T:6UE6R=H;W5R)UTL("1T
M:6UE6R=M:6YU=&4G72P@)'1I;65;)W-E8V]N9"==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T95LG;6]N=&@G72P@)&1A=&5;)VUD87DG72P@
M)&1A=&5;)WEE87(G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@17AP;W)T(&$@1&%T951I;64@9FEE;&0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]E>'!O<G1$871E5&EM92@D=F%L=64I"B`@("!["B`@("`@("`@)'1E
M;7`@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-?;V)J96-T*"1V86QU92D@
M)B8@(6ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@)'1Z(#T@9&%T
M92@G3R<L("1V86QU92D["B`@("`@("`@("`@("146D]F9G-E="`]("@S-C`P
M("H@<W5B<W1R*"1T>BP@,"P@,RDI("L@*#8P("H@<W5B<W1R*&1A=&4H)T\G
M+"`D=F%L=64I+"`S+"`R*2D["B`@("`@("`@("`@("1V86QU92`M/2`D5%I/
M9F9S970["@H@("`@("`@("`@("`D=&5M<%LG>F]N92==("`@/2`G551#)SL*
M("`@("`@("`@("`@)'1E;7!;)WEE87(G72`@(#T@9&%T92@G62<L("1V86QU
M92D["B`@("`@("`@("`@("1T96UP6R=M;VYT:"==("`](&1A=&4H)VXG+"`D
M=F%L=64I.PH@("`@("`@("`@("`D=&5M<%LG;61A>2==("`@/2!D871E*"=J
M)RP@)'9A;'5E*3L*("`@("`@("`@("`@)'1E;7!;)VAO=7(G72`@(#T@9&%T
M92@G1R<L("1V86QU92D["B`@("`@("`@("`@("1T96UP6R=M:6YU=&4G72`]
M(&1A=&4H)VDG+"`D=F%L=64I.PH@("`@("`@("`@("`D=&5M<%LG<V5C;VYD
M)UT@/2!D871E*"=S)RP@)'9A;'5E*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D9&%T94]B(#T@;F5W($AO<F1E7T1A=&4H)'9A;'5E*3L*("`@
M("`@("`@("`@<F5T=7)N($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=$1A=&54
M:6UE*"1D871E3V(M/G1I;65S=&%M<"@I*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!(;W)D95]I0V%L96YD87(Z.E]E>'!O<G1$871E*"1T96UP*2`N
M("=4)R`N($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=%1I;64H)'1E;7`I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@82!4:6UE(&9I96QD+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<&%R<V54:6UE*"1T97AT*0H@("`@>PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O*%LP+3E=>S)]*2A;,"TY77LR?2DH6S`M
M.5U[,GTI*%HI/R\G+"`D=&5X="P@)'1I;65087)T<RDI('L*("`@("`@("`@
M("`@)'1I;65;)VAO=7(G72`](&EN='9A;"@D=&EM95!A<G1S6S%=*3L*("`@
M("`@("`@("`@)'1I;65;)VUI;G5T92==(#T@:6YT=F%L*"1T:6UE4&%R='-;
M,ETI.PH@("`@("`@("`@("`D=&EM95LG<V5C;VYD)UT@/2!I;G1V86PH)'1I
M;65087)T<ULS72D["B`@("`@("`@("`@(&EF("AI<W-E="@D=&EM95!A<G1S
M6S1=*2D@>PH@("`@("`@("`@("`@("`@)'1I;65;)WIO;F4G72`]("=55$,G
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1I;65;
M)WIO;F4G72`]("=,;V-A;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("1T:6UE.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M>'!O<G0@82!4:6UE(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP
M;W)T5&EM92@D=F%L=64I"B`@("!["B`@("`@("`@)'1I;64@/2!S<')I;G1F
M*"<E,#)D)3`R9"4P,F0G+`H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L
M=65;)VAO=7(G72P@)'9A;'5E6R=M:6YU=&4G72P@)'9A;'5E6R=S96-O;F0G
M72D["B`@("`@("`@:68@*"1V86QU95LG>F]N92==(#T]("=55$,G*2!["B`@
M("`@("`@("`@("1T:6UE("X]("=:)SL*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:6UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@82!$871E
M(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5$871E*"1T97AT
M*0H@("`@>PH@("`@("`@("1P87)T<R`](&5X<&QO9&4H)U0G+"`D=&5X="D[
M"B`@("`@("`@:68@*&-O=6YT*"1P87)T<RD@/3T@,BD@>PH@("`@("`@("`@
M("`D=&5X="`]("1P87)T<ULP73L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M<')E9U]M871C:"@G+UXH7&1[-'TI+3\H7&1[,GTI+3\H7&1[,GTI)"\G+"`D
M=&5X="P@)&UA=&-H*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)WEE87(G(#T^("1M871C
M:%LQ72P*("`@("`@("`@("`@("`@("`@("`@)VUO;G1H)R`]/B`D;6%T8VA;
M,ETL"B`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B`D;6%T8VA;,UTI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP;W)T(&$@1&%T92!F:65L9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R=$1A=&4H)'9A;'5E*0H@("`@
M>PH@("`@("`@(&EF("AI<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@("`@("`@
M("`D=F%L=64@/2!A<G)A>2@G>65A<B<@/3X@)'9A;'5E+3YY96%R+"`G;6]N
M=&@G(#T^("1V86QU92T^;6]N=&@L("=M9&%Y)R`]/B`D=F%L=64M/FUD87DI
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@<W!R:6YT9B@G)3`T9"4P,F0E
M,#)D)RP@)'9A;'5E6R=Y96%R)UTL("1V86QU95LG;6]N=&@G72P@)'9A;'5E
M6R=M9&%Y)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@82!$=7)A
M=&EO;B!686QU92!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E
M1'5R871I;VXH)'1E>'0I"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R\H6RM=/WQ;+5TI4"@H6S`M.5TK5RE\*%LP+3E=*T0I?"DH5"@H6S`M.5TK
M2"E\*%LP+3E=*TTI?"A;,"TY72M3*2DK*3\O)RP@=')I;2@D=&5X="DL("1D
M=7)V86QU92DI('L*("`@("`@("`@("`@+R\@5V5E:W,N"B`@("`@("`@("`@
M("1D=7)A=&EO;B`](#<@*B`X-C0P,"`J(&EN='9A;"@D9'5R=F%L=65;,UTI
M.PH*("`@("`@("`@("`@:68@*&-O=6YT*"1D=7)V86QU92D@/B`T*2!["B`@
M("`@("`@("`@("`@("`O+R!$87ES+@H@("`@("`@("`@("`@("`@)&1U<F%T
M:6]N("L](#@V-#`P("H@:6YT=F%L*"1D=7)V86QU95LT72D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&-O=6YT*"1D=7)V86QU92D@/B`U*2![
M"B`@("`@("`@("`@("`@("`O+R!(;W5R<RX*("`@("`@("`@("`@("`@("1D
M=7)A=&EO;B`K/2`S-C`P("H@:6YT=F%L*"1D=7)V86QU95LW72D["@H@("`@
M("`@("`@("`@("`@+R\@36EN<RX*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9'5R=F%L=65;.%TI*2!["B`@("`@("`@("`@("`@("`@("`@)&1U<F%T
M:6]N("L](#8P("H@:6YT=F%L*"1D=7)V86QU95LX72D["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@+R\@4V5C<RX*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9'5R=F%L=65;.5TI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1U<F%T:6]N("L](&EN='9A;"@D9'5R=F%L=65;.5TI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3
M:6=N+@H@("`@("`@("`@("!I9B`H)&1U<G9A;'5E6S%=(#T]("(M(BD@>PH@
M("`@("`@("`@("`@("`@)&1U<F%T:6]N("H]("TQ.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!R971U<FX@)&1U<F%T:6]N.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@82!D=7)A=&EO;B!V86QU92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R=$1U<F%T:6]N*"1V86QU92D*("`@
M('L*("`@("`@("`D9'5R871I;VX@/2`G)SL*("`@("`@("!I9B`H)'9A;'5E
M(#P@,"D@>PH@("`@("`@("`@("`D=F%L=64@*CT@+3$["B`@("`@("`@("`@
M("1D=7)A=&EO;B`N/2`G+2<["B`@("`@("`@?0H@("`@("`@("1D=7)A=&EO
M;B`N/2`G4"<["@H@("`@("`@("1W965K<R`](&9L;V]R*"1V86QU92`O("@W
M("H@.#8T,#`I*3L*("`@("`@("`D=F%L=64@/2`D=F%L=64@)2`H-R`J(#@V
M-#`P*3L*("`@("`@("!I9B`H)'=E96MS*2!["B`@("`@("`@("`@("1D=7)A
M=&EO;B`N/2`D=V5E:W,@+B`G5R<["B`@("`@("`@?0H*("`@("`@("`D9&%Y
M<R`](&9L;V]R*"1V86QU92`O("@X-C0P,"DI.PH@("`@("`@("1V86QU92`]
M("1V86QU92`E("@X-C0P,"D["B`@("`@("`@:68@*"1D87ES*2!["B`@("`@
M("`@("`@("1D=7)A=&EO;B`N/2`D9&%Y<R`N("=$)SL*("`@("`@("!]"@H@
M("`@("`@(&EF("@D=F%L=64I('L*("`@("`@("`@("`@)&1U<F%T:6]N("X]
M("=4)SL*"B`@("`@("`@("`@("1H;W5R<R`](&9L;V]R*"1V86QU92`O(#,V
M,#`I.PH@("`@("`@("`@("`D=F%L=64@/2`D=F%L=64@)2`S-C`P.PH@("`@
M("`@("`@("!I9B`H)&AO=7)S*2!["B`@("`@("`@("`@("`@("`D9'5R871I
M;VX@+CT@)&AO=7)S("X@)T@G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D;6EN<R`](&9L;V]R*"1V86QU92`O(#8P*3L*("`@("`@("`@("`@)'9A
M;'5E(#T@)'9A;'5E("4@-C`["B`@("`@("`@("`@(&EF("@D;6EN<RD@>PH@
M("`@("`@("`@("`@("`@)&1U<F%T:6]N("X]("1M:6YS("X@)TTG.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'9A;'5E*2!["B`@("`@("`@
M("`@("`@("`D9'5R871I;VX@+CT@)'9A;'5E("X@)U,G.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1U<F%T:6]N.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!F;VQD960@=F5R<VEO;B!O
M9B!A(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F;VQD3&EN92@D;&EN
M92D*("`@('L*("`@("`@("`D;&EN92`]('!R96=?<F5P;&%C92@B+UQR7&Y\
M7&Y\7'(O(BP@)UQN)RP@)&QI;F4I.PH@("`@("`@(&EF("AS=')L96XH)&QI
M;F4I(#X@-S4I('L*("`@("`@("`@("`@)&9O;&1E9&QI;F4@/2`G)SL*("`@
M("`@("`@("`@=VAI;&4@*"%E;7!T>2@D;&EN92DI('L*("`@("`@("`@("`@
M("`@("1M87A,:6YE(#T@<W5B<W1R*"1L:6YE+"`P+"`W-2D["B`@("`@("`@
M("`@("`@("`D8W5T4&]I;G0@/2!M87@H-C`L(&UA>"AS=')R<&]S*"1M87A,
M:6YE+"`G.R<I+"!S=')R<&]S*"1M87A,:6YE+"`G.B<I*2`K(#$I.PH*("`@
M("`@("`@("`@("`@("1F;VQD961L:6YE("X]("AE;7!T>2@D9F]L9&5D;&EN
M92DI(#\*("`@("`@("`@("`@("`@("`@("!S=6)S='(H)&QI;F4L(#`L("1C
M=710;VEN="D@.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;F5W;&EN
M92`N("<@)R`N('-U8G-T<B@D;&EN92P@,"P@)&-U=%!O:6YT*3L*"B`@("`@
M("`@("`@("`@("`D;&EN92`]("AS=')L96XH)&QI;F4I(#P]("1C=710;VEN
M="D@/R`G)R`Z('-U8G-T<B@D;&EN92P@)&-U=%!O:6YT*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)&9O;&1E9&QI;F4["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D;&EN93L*("`@('T*"B`@("`O*BH*("`@("`J
M($-O;G9E<G0@86X@.&)I="!S=')I;F<@=&\@82!Q=6]T960M<')I;G1A8FQE
M('-T<FEN9R!A8V-O<F1I;F<*("`@("`J('1O(%)&0S(P-#4L('-E8W1I;VX@
M-BXW+@H@("`@("H*("`@("`J(%5S97,@:6UA<%\X8FET(&EF(&%V86EL86)L
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;G!U="`@5&AE('-T
M<FEN9R!T;R!B92!E;F-O9&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<75O=&5D+7!R:6YT86)L92!E;F-O9&5D('-T<FEN9RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W%U;W1E9%!R:6YT86)L945N8V]D92@D:6YP
M=70@/2`G)RD*("`@('L*("`@("`@("`O+R!)9B!I;6%P7SAB:70H*2!I<R!A
M=F%I;&%B;&4L('5S92!I="X*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"=I;6%P7SAB:70G*2D@>PH@("`@("`@("`@("!R971U<FX@:6UA<%\X8FET
M*"1I;G!U="D["B`@("`@("`@?0H*("`@("`@("`O+R!2871H97(@9'5M8B!R
M97!L86-M96YT.B!J=7-T(&5N8V]D92!E=F5R>71H:6YG+@H@("`@("`@("1H
M97@@/2!A<G)A>2@G,"<L("<Q)RP@)S(G+"`G,R<L("<T)RP@)S4G+"`G-B<L
M("<W)RP@)S@G+"`G.2<L"B`@("`@("`@("`@("`@("`@("`@("=!)RP@)T(G
M+"`G0R<L("=$)RP@)T4G+"`G1B<I.PH*("`@("`@("`D;W5T<'5T(#T@)R<[
M"B`@("`@("`@)&QE;B`]('-T<FQE;B@D:6YP=70I.PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1L96X[("LK)&DI('L*("`@("`@("`@("`@)&,@/2!S
M=6)S='(H)&EN<'5T+"`D:2P@,2D["B`@("`@("`@("`@("1D96,@/2!O<F0H
M)&,I.PH@("`@("`@("`@("`D;W5T<'5T("X]("<])R`N("1H97A;9FQO;W(H
M)&1E8R`O(#$V*5T@+B`D:&5X6V9L;V]R*"1D96,@)2`Q-BE=.PH@("`@("`@
M("`@("!I9B`H*"1I("L@,2D@)2`R-2`]/2`P*2!["B`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]("(]7')<;B(["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#8S,#(V`#$P-#$W,S8R-S<S`#`R,3$W-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*+RHJ"B`J($1O('1A<VL@>65A<FQY("A&:7)S="!L;V=I;B!A9G1E<B]O
M;B!*86YU87)Y(#$I+@H@*B\*9&5F:6YE*"=-04E.5$5.04Y#15]914%23%DG
M+"`Q*3L*"B\J*@H@*B!$;R!T87-K(&UO;G1H;'D@*$9I<G-T(&QO9VEN(&%F
M=&5R+V]N(&9I<G-T(&]F(&UO;G1H*2X*("HO"F1E9FEN92@G34%)3E1%3D%.
M0T5?34].5$A,62<L(#(I.PH*+RHJ"B`J($1O('1A<VL@=V5E:VQY("A&:7)S
M="!L;V=I;B!A9G1E<B]O;B!A(%-U;F1A>2DN"B`J+PID969I;F4H)TU!24Y4
M14Y!3D-%7U=%14M,62<L(#,I.PH*+RHJ"B`J($1O('1A<VL@9&%I;'D@*$9I
M<G-T(&QO9VEN(&]F('1H92!D87DI+@H@*B\*9&5F:6YE*"=-04E.5$5.04Y#
M15]$04E,62<L(#0I.PH*+RHJ"B`J($1O('1A<VL@979E<GD@;&]G:6XN"B`J
M+PID969I;F4H)TU!24Y414Y!3D-%7T5615)9)RP@-2D["@HO*BH*("H@1&\@
M=&%S:R!O;B!F:7)S="!L;V=I;B!O;FQY+@H@*B\*9&5F:6YE*"=-04E.5$5.
M04Y#15]&25)35%],3T=)3B<L(#8I.PH*+RHJ"B`J($-O;F9I<FUA=&EO;BUS
M='EL92!O=71P=70@9F]R(&UA:6YT96YA;F-E('!A9V4N"B`J+PID969I;F4H
M)TU!24Y414Y!3D-%7T]55%!55%]#3TY&25)-)RP@-RD["@HO*BH*("H@06=R
M965M96YT+7-T>6QE(&]U='!U="!F;W(@;6%I;G1E;F%N8V4@<&%G92X*("HO
M"F1E9FEN92@G34%)3E1%3D%.0T5?3U544%547T%'4D5%)RP@."D["@HO*BH*
M("H@3F]T:6-E+7-T>6QE(&]U='!U="!F;W(@;6%I;G1E;F%N8V4@<&%G92X*
M("HO"F1E9FEN92@G34%)3E1%3D%.0T5?3U544%547TY/5$E#12<L(#DI.PH*
M+RHJ"B`J(%1H92!N86UE(&]F('1H92!54DP@<&%R86UE=&5R('1H870@:6YD
M:6-A=&5S('1H870@=&AE(&UA:6YT96YA;F-E('1A<VMS(&%R90H@*B!C;VUP
M;&5T960N"B`J+PID969I;F4H)TU!24Y414Y!3D-%7T1/3D5?4$%204TG+"`G
M;6%I;G1E;F%N8V5?9&]N92<I.PH*+RH@26YT97)V86QS(&AA<V@@+2!U<V5D
M('1O(&)U:6QD('-E;&5C="!T86)L97,@:6X@<')E9F5R96YC97,@;65N=2X@
M*B\*)&EN=&5R=F%L<R`](&%R<F%Y*"D["B1I;G1E<G9A;'-;34%)3E1%3D%.
M0T5?645!4DQ972`@/2!?*")996%R;'DB*3L*)&EN=&5R=F%L<UM-04E.5$5.
M04Y#15]-3TY42$Q972`](%\H(DUO;G1H;'DB*3L*)&EN=&5R=F%L<UM-04E.
M5$5.04Y#15]7145+3%E=("`](%\H(E=E96ML>2(I.PHD:6YT97)V86QS6TU!
M24Y414Y!3D-%7T1!24Q972`@(#T@7R@B1&%I;'DB*3L*)&EN=&5R=F%L<UM-
M04E.5$5.04Y#15]%5D5265T@("`](%\H(D5V97)Y($QO9VEN(BD["B1'3$]"
M04Q36R=I;G1E<G9A;',G72`]("8D:6YT97)V86QS.PH*+RHJ"B`J(%1H92!-
M86EN=&5N86YC93HZ(&-L87-S('!R;W9I9&5S(&$@<V5T(&]F(&UE=&AO9',@
M9F]R(&1E86QI;F<@=VET:`H@*B!M86EN=&5N86YC92!O<&5R871I;VYS(')U
M;B!U<&]N(&QO9VEN('1O($AO<F1E(&%P<&QI8V%T:6]N<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP+'8@
M,2XU,BXQ,"XQ,R`R,#`V+S`Q+S`Q(#(Q.C(X.C(V(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#$N,RXU"B`J($!P86-K86=E
M($AO<F1E7TUA:6YT96YA;F-E"B`J+PIC;&%S<R!-86EN=&5N86YC92!["@H@
M("`@+RHJ"B`@("`@*B!(87-H(&AO;&1I;F<@;6%I;G1E;F%N8V4@<')E9F5R
M96YC92!N86UE<RX*("`@("`J(%-Y;G1A>#H@(%!2149.04U%(#T^(&EN=&5R
M=F%L"B`@("`@*B!686QI9"!I;G1E<G9A;',@87)E.B!-04E.5$5.04Y#15]9
M14%23%DL($U!24Y414Y!3D-%7TU/3E1(3%DL"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!-04E.5$5.04Y#15]7145+3%DL($U!24Y414Y!3D-%7T1!
M24Q9+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@34%)3E1%3D%.0T5?
M159%4EDL("!-04E.5$5.04Y#15]&25)35%],3T=)3@H@("`@("H@3W!E<F%T
M:6]N<R!W:6QL(&)E(')U;B!I;B!T:&4@;W)D97(@=&AE>2!A<'!E87(@:6X@
M=&AE(&%R<F%Y("T*("`@("`J("`@34%+12!355)%($953D-424].4R!!4D4@
M24X@5$A%($-/4E)%0U0@3U)$15(A"B`@("`@*B!/<&5R871I;VYS(&-A;B!A
M<'!E87(@;6]R92!T:&%N(&]N8V4@+2!T:&5Y('=I;&P@;VYL>2!B92!R=6X@
M;VYC92!P97(*("`@("`J("`@;&]G:6X@=&AO=6=H("AT:&4@;W!E<F%T:6]N
M('=I;&P@<G5N('1H92!F:7)S="!T:6UE(&ET(&ES('-E96X@:6X*("`@("`J
M("`@=&AE(&%R<F%Y*2X*("`@("`J"B`@("`@*B!4:&ES(&%R<F%Y('-H;W5L
M9"!B92!F:6QL960@:6X@9F]R(&5A8V@@2&]R9&4@;6]D=6QE('1H870@97AT
M96YD<PH@("`@("H@("!T:&4@36%I;G1E;F%N8V4@8VQA<W,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&UA:6YT7W1A<VMS
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%5.25@@=&EM97-T86UP(&]F
M('1H92!L87-T(&UA:6YT96YA;F-E(')U;B!F;W(@=7-E<BX*("`@("`J"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?;&%S=%)U;B`]
M(#`["@H@("`@+RHJ"B`@("`@*B!4:&4@36%I;G1E;F%N8V5?5&%S:VQI<W0@
M;V)J96-T(&9O<B!T:&ES(&QO9VEN+@H@("`@("H*("`@("`J($!V87(@36%I
M;G1E;F%N8V5?5&%S:VQI<W0*("`@("`J+PH@("`@=F%R("1?=&%S:VQI<W0[
M"@H@("`@+RHJ"B`@("`@*B!!<G)A>2!T;R!S=&]R92!-86EN=&5N86YC95]4
M87-K(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]T87-K0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@36%I;G1E;F%N8V5?
M*B!O8FIE8W0@8F%S960@;VX@=&AE(&UO9'5L90H@("`@("H@;F%M92!P87-S
M960@:6YT;R!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1U
M;&4@(%1H92!N86UE(&]F('1H92!(;W)D92!M;V1U;&4N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT86EN:6YG(&%D9&ET:6]N
M86P@9&%T82!N965D960@8GD@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!R971U<FX@36%I
M;G1E;F%N8V4@(%1H92!-86EN=&5N86YC92!O8FIE8W0L(&]R(&9A;'-E(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D;6]D=6QE
M+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PH*("`@("`@("`O*B!3<&%W;B!T:&4@<F5L979A;G0@9')I=F5R
M+"!A;F0@<F5T=7)N(&ET("AO<B!F86QS92!O;B!F86EL=7)E*2X@*B\*("`@
M("`@("!I;F-L=61E7V]N8V4@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@
M)&UO9'5L92D@+B`G+VQI8B]-86EN=&5N86YC92\G("X@)&UO9'5L92`N("<N
M<&AP)SL*("`@("`@("`D8VQA<W,@/2`G36%I;G1E;F%N8V5?)R`N("1M;V1U
M;&4["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@
M("`@("`@("1M86EN=&5N86YC92`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M86EN=&5N86YC92`](&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M86EN=&5N86YC93L*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!T
M:&4@9F]L;&]W:6YG(&5N=')I97,Z"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@)VQA<W1?;6%I;G1E;F%N8V4G(#T^(%1H92!L87-T('1I;64@;6%I
M;G1E;F%N8V4@=V%S(')U;B`H=6YI>"!T:6UE<W1A;7`I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!-86EN=&5N86YC92@D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`O*B!3970@=&AE(&-L87-S('9A<FEA8FQE("1?;&%S=%)U
M;BX@*B\*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG;&%S=%]M86EN=&5N
M86YC92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQA<W12=6X@/2`D<&%R
M86US6R=L87-T7VUA:6YT96YA;F-E)UT["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W)E=')I979E5&%S:VQI<W0H*3L*("`@("`@("`D=&AI<RT^7W-H
M=71D;W=N*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!M86EN=&5N86YC
M92!O<&5R871I;VYS(&YE961E9"!F;W(@=&AI<R!L;V=I;BX@(%1H:7,@9G5N
M8W1I;VX*("`@("`J('=I;&P@9V5N97)A=&4@=&AE(&QI<W0@;V8@=&%S:W,@
M=&\@<&5R9F]R;2!D=7)I;F<@=&AI<R!L;V=I;@H@("`@("H@86YD('=I;&P@
M<F5D:7)E8W0@=&\@=&AE(&UA:6YT96YA;F-E('!A9V4@:68@;F5C97-S87)Y
M+B`@5&AI<PH@("`@("H@:7,@=&AE(&9U;F-T:6]N('1H870@<VAO=6QD(&)E
M(&-A;&QE9"!F<F]M('1H92!A<'!L:6-A=&EO;B!U<&]N"B`@("`@*B!L;V=I
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N36%I;G1E;F%N8V4H*0H@("`@
M>PH@("`@("`@("\J($-H96-K('1O('-E92!I9B!W92!A<F4@9FEN:7-H960@
M=VET:"!M86EN=&5N86YC90H@("`@("`@("`J(&]P97)A=&EO;G,N("HO"B`@
M("`@("`@:68@*"%5=&EL.CIG971&;W)M1&%T82A-04E.5$5.04Y#15]$3TY%
M7U!!4D%-*2D@>PH@("`@("`@("`@("`O*B!$971E<FUI;F4@:68@=V4@<VAO
M=6QD(')E9&ER96-T('1O('1H92!M86EN=&5N86YC92!P86=E+B`J+PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]N965D36%I;G1E;F%N8V5086=E*"D@(3T]
M(&YU;&PI('L*("`@("`@("`@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@
M+B`D=&AI<RT^7V=E=$UA:6YT96YA;F-E55),*"DL('1R=64I.PH@("`@("`@
M("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@1FEN86QL>2P@<G5N(&%N>2!T87-K<R!T:&%T(&YE960@=&\@8F4@
M97AE8W5T960N("HO"B`@("`@("`@)'1H:7,M/E]D;TUA:6YT96YA;F-E5&%S
M:W,H*3L*("`@('T*"B`@("`O*BH*("`@("`J($1O('1H92!N96-E<W-A<GD@
M;6%I;G1E;F%N8V4@=&%S:W,@9F]R('1H:7,@;&]A9&EN9R!O9B!T:&4@;6%I
M;G1E;F%N8V4*("`@("`J('!A9V4N("!4:&ES(&ES('1H92!F=6YC=&EO;B!T
M:&%T(&ES(&-A;&QE9"!F<F]M('1H92!M86EN=&5N86YC92!P86=E"B`@("`@
M*B!E=F5R>2!T:6UE(&ET(&ES(&QO861E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!D:7-P;&%Y(')E<75I<F5D(&9O<B!T:&4@;6%I
M;G1E;F%N8V4@<&%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N36%I;G1E
M;F%N8V5086=E*"D*("`@('L*("`@("`@("`O*B!3:&]U;&0@=V4@<G5N(&%N
M>2!T87-K<S\@*B\*("`@("`@("`D=&AI<RT^7V1O36%I;G1E;F%N8V5487-K
M<R@I.PH*("`@("`@("`O*B!'970@=&AE(&QI<W0@;V8@=&%S:W,@=V4@;F5E
M9"!T;R!D:7-P;&%Y('1O('1H92!U<V5R+B`J+PH@("`@("`@("1T87-K7VYO
M(#T@)'1H:7,M/E]N965D36%I;G1E;F%N8V5086=E*"D["B`@("`@("`@)'1A
M<VMS(#T@)'1H:7,M/E]T87-K;&ES="T^9V5T3&ES="@I.PH*("`@("`@("`O
M*B!296UO=F4@)VYE=V9L86<G(&9R;VT@9FER<W0@=&%S:RX@*B\*("`@("`@
M("!I9B`H(21T:&ES+3Y?=&%S:VQI<W0M/G!R;V-E<W-E9"AT<G5E*2D@>PH@
M("`@("`@("`@("!I9B`H8V]U;G0H)'1A<VMS*2D@>PH@("`@("`@("`@("`@
M("`@<F5S970H)'1A<VMS*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%S
M:VQI<W0M/G-E=$YE=U!A9V4H:V5Y*"1T87-K<RDL(&9A;'-E*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1T87-K
M7VYO*2D@>PH@("`@("`@("`@("`D=&%S:W,@/2!A<G)A>5]S;&EC92@D=&%S
M:W,L(#`L("1T87-K7VYO("L@,2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M8V]U;G0H)'1A<VMS*2D@>PH@("`@("`@("`@("!R97-E="@D=&%S:W,I.PH@
M("`@("`@("`@("`D86-T:6]N(#T@)'1A<VMS6VME>2@D=&%S:W,I75LG9&ES
M<&QA>2==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A8W1I;VX@
M/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1A8W1I
M;VXL(&%R<F%Y7VME>7,H)'1A<VMS*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!I;F9O<FUA=&EO;F%L('1E>'0@;65S<V%G92!O;B!W
M:&%T('1H92!O<&5R871I;VX@:7,*("`@("`J(&%B;W5T('1O(&1O+B!!;'-O
M(&EN9&EC871E<R!W:&5T:&5R('1H92!B;W@@<VAO=6QD(&)E(&-H96-K960*
M("`@("`J(&)Y(&1E9F%U;'0@;W(@;F]T+B!/<&5R871I;VYS('1H870@:&%V
M92!B965N(&QO8VME9"!B>2!T:&4*("`@("`J(&%D;6EN('=I;&P@<F5T=7)N
M(&YU;&PN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@3F%M
M92!O9B!T:&4@;W!E<F%T:6]N('1O(&=E="!I;F9O<FUA=&EO;B!F;W(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@,7-T(&5L96UE;G0@+2!$97-C
M<FEP=&EO;B!O9B!W:&%T('1H92!O<&5R871I;VX@:7,@86)O=70*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@9&\@9'5R:6YG('1H
M:7,@;&]G:6XN"B`@("`@*B`@("`@("`@("`@("`@("`R;F0@96QE;65N="`M
M(%=H971H97(@=&AE('!R969E<F5N8V4@:7,@<V5T('1O(&]N(&]R(&YO="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:6YF;TUA:6YT96YA;F-E*"1P<F5F*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@("\J($EF('1H
M92!P<F5F97)E;F-E(&AA<R!B965N(&QO8VME9"!B>2!T:&4@861M:6XL(&1O
M(&YO="!S:&]W"B`@("`@("`@("`@=&AE('5S97(N("HO"B`@("`@("`@:68@
M*"1P<F5F<RT^:7-,;V-K960H)'!R968I*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@("1M;V0@/2`F)'1H:7,M/E]L;V%D36]D
M=6QE*"1P<F5F*3L*("`@("`@("!R971U<FX@87)R87DH)&UO9"T^9&5S8W)I
M8F5-86EN=&5N86YC92@I+"`D<')E9G,M/F=E=%9A;'5E*"1P<F5F*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@=F%R:6%B;&4@;F%M97,@=&\@
M=7-E(&9O<B!C<F5A=&EN9R!S96QE8W0@=&%B;&5S(&EN('1H90H@("`@("H@
M<')E9F5R96YC97,@;65N=2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;B!A<G)A>2!O9B!V87)I86)L92!N86UE<R!T;R!B92!I;7!O<G1E9"!I
M;G1O('1H90H@("`@("H@("`@("`@("`@("`@("`@<')E9G,N<&AP(&YA;65S
M<&%C92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T26YT97)V86Q0<F5F
M<R@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)')E
M='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*&%R<F%Y
M7VME>7,H)'1H:7,M/FUA:6YT7W1A<VMS*2!A<R`D=F%L*2!["B`@("`@("`@
M("`@(&EF("@A)'!R969S+3YI<TQO8VME9"@D=F%L("X@)U]I;G1E<G9A;"<I
M*2!["B`@("`@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6UT@/2`D=F%L("X@
M)U]I;G1E<G9A;%]O<'1I;VYS)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1R971U<FY?87)R87D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!/=71P=70@:&ED9&5N(&9O<B!E;&5M96YT<R!F;W(@=&AE(%!/
M4U0@9F]R;2!T;R!E;G-U<F4@=&AE(&-A;&QI;F<*("`@("`J('-C<FEP="!H
M87,@=&AE('-A;64@4$]35"!E;&5M96YT<R!A<R!W:&5N('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS"B`@("`@*B!F:7)S="!R=6XN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M(&1A=&$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!O<W1$871A*"D*("`@('L*("`@("`@("`D=&5X="`]
M("<G.PH*("`@("`@("!I9B`H*"1D871A(#T@)'1H:7,M/E]T87-K;&ES="T^
M9V5T4&]S=$1A=&$H*2DI('L*("`@("`@("`@("`@9F]R96%C:"`H)&1A=&$@
M87,@)&YA;64@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@
M)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1N86UE*2`N("<B('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D
M=F%L*2`N("<B("\^)R`N(")<;B(["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@55),(&YE961E9"!F;W(@=&AE(&UA:6YT96YA;F-E(&9O
M<FTN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!54DP@=&\@
M<F5D:7)E8W0@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UA:6YT96YA
M;F-E1F]R;5523"@I"B`@("!["B`@("`@("!I9B`H)'1H:7,M/E]N965D36%I
M;G1E;F%N8V5086=E*"D@(3T](&YU;&PI('L*("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]G971-86EN=&5N86YC95523"@I.PH@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G971);FET:6%L4&%G95523"@I
M.PH@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!T:&4@
M;&ES="!O9B!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@87)E(&%V86EL
M86)L90H@("`@("H@9F]R('1H:7,@<V5S<VEO;B`H<W1O<F5D(&EN(&$@36%I
M;G1E;F%N8V5?5&%S:VQI<W0@;V)J96-T*2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E
M='5R;G,@=')U92!I9B!L:7-T('=A<R!C<F5A=&5D+@H@("`@("H@("`@("`@
M("`@("`@("`@("!&86QS92!I9B!N;W0@*&4N9RX@;&ES="!A;')E861Y(&5X
M:7-T<RDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5487-K3&ES="@I
M"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@+RH@0W)E
M871E(&$@;F5W($UA:6YT96YA;F-E7U1A<VML:7-T(&]B:F5C="X@*B\*("`@
M("`@("`D=&AI<RT^7W1A<VML:7-T(#T@)FYE=R!-86EN=&5N86YC95]487-K
M;&ES="@I.PH*("`@("`@("`O*B!#<F5A=&4@=&EM92!O8FIE8W1S(&9O<B!T
M;V1A>2=S(&1A=&4@86YD(&QA<W0@;&]G:6X@9&%T92X@*B\*("`@("`@("`D
M;&%S=%]D871E(#T@9V5T9&%T92@D=&AI<RT^7VQA<W12=6XI.PH@("`@("`@
M("1C=7)?9&%T92`@/2!G971D871E*"D["@H@("`@("`@("\J($=O('1H<F]U
M9V@@96%C:"!I=&5M(&EN("1M86EN=%]T87-K<R!A;F0@9&5T97)M:6YE(&EF
M('=E(&YE960@=&\*("`@("`@("`@("!R=6X@:70@9'5R:6YG('1H:7,@;6%I
M;G1E;F%N8V4@<G5N+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YM86EN
M=%]T87-K<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@+RH@4VMI
M<"!I=&5M(&EF(&ET(&%L<F5A9'D@87!P96%R<R!I;B!T:&4@=&%S:W,@;&ES
M="X@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?=&%S:VQI<W0M/FEN3&ES
M="@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($1E=&5R;6EN92!T:&4@8V]R<F5C="!I
M;G1E<G9A;"!F;W(@=&AE(&ET96TN("HO"B`@("`@("`@("`@(&EF("@H)&EN
M=&5R=F%L(#T@)'!R969S+3YG971686QU92@D:V5Y("X@)U]I;G1E<G9A;"<I
M*2D@>PH@("`@("`@("`@("`@("`@)'9A;"`]("1I;G1E<G9A;#L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&%D9%1A<VL@/2!F86QS93L*"B`@("`@
M("`@("`@("\J($9)4E-4($Q/1TE.($]015)!5$E/3E,@*B\*("`@("`@("`@
M("`@+RH@268@)%]L87-T4G5N(&ES(&5M<'1Y("@](#`I+"!T:&ES(&ES('1H
M92!F:7)S="!T:6UE('1H92!U<V5R"B`@("`@("`@("`@("`@(&AA<R!L;V=G
M960@:6XN($1O;B=T(')U;B!A;GD@;W1H97(@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!O;@H@("`@("`@("`@("`@("!T:&4@9FER<W0@;&]G:6XN("HO"B`@
M("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VQA<W12=6XI*2!["B`@("`@
M("`@("`@("`@("!I9B`H)'9A;"`]/2!-04E.5$5.04Y#15]&25)35%],3T=)
M3BD@>PH@("`@("`@("`@("`@("`@("`@("1A9&1487-K(#T@=')U93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M645!4DQ97T]015)!5$E/3E,@*B\*("`@("`@("`@("`@96QS96EF("@H)'9A
M;"`]/2!-04E.5$5.04Y#15]914%23%DI("8F"B`@("`@("`@("`@("`@("`@
M("`@*"1C=7)?9&%T95LG>65A<B==(#X@)&QA<W1?9&%T95LG>65A<B==*2D@
M>PH@("`@("`@("`@("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!-3TY42$Q9($]015)!5$E/3E,@*B\*("`@
M("`@("`@("`@96QS96EF("@H)'9A;"`]/2!-04E.5$5.04Y#15]-3TY42$Q9
M*2`F)@H@("`@("`@("`@("`@("`@("`@("@H)&-U<E]D871E6R=Y96%R)UT@
M/B`D;&%S=%]D871E6R=Y96%R)UTI('Q\("@D8W5R7V1A=&5;)VUO;B==(#X@
M)&QA<W1?9&%T95LG;6]N)UTI*2D@>PH@("`@("`@("`@("`@("`@)&%D9%1A
M<VL@/2!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!7145+
M3%D@3U!%4D%424].4R`J+PH@("`@("`@("`@("!E;'-E:68@*"@D=F%L(#T]
M($U!24Y414Y!3D-%7U=%14M,62D@)B8*("`@("`@("`@("`@("`@("`@("`H
M*"1C=7)?9&%T95LG=V1A>2==(#P@)&QA<W1?9&%T95LG=V1A>2==*2!\?"`H
M*'1I;64H*2`M(#8P-#@P,"D@/B`D=&AI<RT^7VQA<W12=6XI*2D@>PH@("`@
M("`@("`@("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!$04E,62!/4$52051)3TY3("HO"B`@("`@("`@("`@
M(&5L<V5I9B`H*"1V86P@/3T@34%)3E1%3D%.0T5?1$%)3%DI("8F"B`@("`@
M("`@("`@("`@("`@("`@*"@D8W5R7V1A=&5;)WEE87(G72`^("1L87-T7V1A
M=&5;)WEE87(G72D@?'P@*"1C=7)?9&%T95LG>61A>2==(#X@)&QA<W1?9&%T
M95LG>61A>2==*2DI('L*("`@("`@("`@("`@("`@("1A9&1487-K(#T@=')U
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@159%4ED@3$]'24X@
M3U!%4D%424].4R`J+PH@("`@("`@("`@("!E;'-E:68@*"1V86P@/3T@34%)
M3E1%3D%.0T5?159%4EDI('L*("`@("`@("`@("`@("`@("1A9&1487-K(#T@
M=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`O*B!3:VEP('1H92!T
M87-K(&EF(&%N>2!O9B!T:&4@9F]L;&]W:6YG.@H@("`@("`@("`@("`@("`K
M(%1H:7,@=&%S:R!D;V5S(&YO="!N965D('1O(&)E(')U;B!I;B!T:&ES(&QO
M9VEN"B`@("`@("`@("`@("`@("L@5&AI<R!T87-K(&ES(&YO="!S970@:6X@
M=&AE('!R969E<F5N8V5S("HO"B`@("`@("`@("`@(&EF("@A)&%D9%1A<VL@
M?'P@(21P<F5F<RT^9V5T5F%L=64H)&ME>2DI(&-O;G1I;G5E.PH*("`@("`@
M("`@("`@+RH@3&]A9"!T:&4@=&%S:R!M;V1U;&4@;F]W+B`J+PH@("`@("`@
M("`@("`D;6]D(#T@)B1T:&ES+3Y?;&]A9$UO9'5L92@D:V5Y*3L*"B`@("`@
M("`@("`@("\J($1E=&5R;6EN92!I9B!T:&ES('1A<VL@:&%S(&%L<F5A9'D@
M8F5E;B!C;VYF:7)M960O<V5T('9I82!S;VUE"B`@("`@("`@("`@("`@('-O
M<G0@;V8@861M:6X@<V5T=&EN9RX@06QS;RP@:68@=&AE('5S97(O861M:6X@
M:&%S('-E="!T:&4*("`@("`@("`@("`@("`@)V-O;F9I<FU?;6%I;G1E;F%N
M8V4G(&9L86<L('-K:7`@8V]N9FER;6%T:6]N+B`J+PH@("`@("`@("`@("`D
M8V]N9FER;65D(#T@9F%L<V4["B`@("`@("`@("`@(&EF("@D<')E9G,M/FES
M3&]C:V5D*"1K97DI('Q\"B`@("`@("`@("`@("`@("`A)'!R969S+3YG9716
M86QU92@G8V]N9FER;5]M86EN=&5N86YC92<I*2!["B`@("`@("`@("`@("`@
M("`D8V]N9FER;65D(#T@=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@061D('1H92!T87-K('1O('1H92!T87-K;&ES="X@*B\*("`@("`@
M("`@("`@)'1H:7,M/E]T87-K;&ES="T^861D5&%S:R@D:V5Y+"`D8V]N9FER
M;65D+"`D;6]D+3YG971$:7-P;&%Y5'EP92@I*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,;V%D(&UO9'5L92`H:68@;F]T(&%L<F5A9'D@
M;&]A9&5D*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1N86UE("!.86UE(&]F('1H92!M
M;V1U;&4@=&\@;&]A9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($UA:6YT96YA
M;F-E7U1A<VL@($$@<F5F97)E;F-E('1O('1H92!R97%U97-T960@;6]D=6QE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F7VQO861-;V1U;&4H)&UO9&YA;64I
M"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W1A<VM#86-H95LD;6]D;F%M95TI*2!["B`@("`@
M("`@("`@(&EN8VQU9&5?;VYC92`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G
M+"`D=&AI<RT^7W1A<VML:7-T+3YG971-;V1U;&4H*2D@+B`G+VQI8B]-86EN
M=&5N86YC92]487-K+R<@+B`D;6]D;F%M92`N("<N<&AP)SL*("`@("`@("`@
M("`@)&-L87-S(#T@)TUA:6YT96YA;F-E7U1A<VM?)R`N("1M;V1N86UE.PH@
M("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=&%S:T-A8VAE6R1M;V1N86UE72`]("9N97<@
M)&-L87-S.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(I+"`D8VQA
M<W,I*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&%S:T-A8VAE6R1M;V1N
M86UE73L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@55),(&9O<B!T
M:&4@:6YI=&EA;"!P86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@55),(&9O<B!T
M:&4@:6YI=&EA;"!P86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T26YI
M=&EA;%!A9V554DPH*0H@("`@>PH@("`@("`@(')E='5R;B!5=&EL.CIA9&10
M87)A;65T97(H)'1H:7,M/E]T87-K;&ES="T^9V5T5&%R9V5T*"DL(&%R<F%Y
M*$U!24Y414Y!3D-%7T1/3D5?4$%204T@/3X@,2P@)V1O;6%I;G1E;F%N8V4G
M(#T^(#$I+"!N=6QL+"!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE(%523"!F;W(@=&AE(&UA:6YT96YA;F-E('!A9V4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!54DP@9F]R('1H92!M86EN=&5N86YC92!P86=E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5T36%I;G1E;F%N8V554DPH*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("\J(%=E(&YE960@
M=&\@<&%S<R!T:&4@8V%C:&4@240@86YD("=M;V1U;&4G('!A<F%M971E<G,N
M("HO"B`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H
M)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP)RP@=')U92D["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E
M<B@D=7)L+"!A<G)A>2@G;6]D=6QE)R`]/B`D=&AI<RT^7W1A<VML:7-T+3YG
M971-;V1U;&4H*2P@)V1O;6%I;G1E;F%N8V4G(#T^(#$I+"!N=6QL+"!F86QS
M92D["@H@("`@("`@(')E='5R;B`D=7)L.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5G:7-T97(@=&AE('-H=71D;W=N(&9U;F-T:6]N(&9O<B!S=&]R:6YG
M('1H92!M86EN=&5N86YC90H@("`@("H@=&%S:VQI<W0N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:'5T
M9&]W;B@I"B`@("!["B`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I
M;VXH87)R87DH)B1T:&ES+"`G7V-A8VAE5&%S:VQI<W0G*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#86-H92!T:&4@;6%I;G1E;F%N8V4@=&%S:VQI<W0@
M8F5T=V5E;B!P86=E(')E<75E<W1S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%C:&5487-K;&ES="@I
M"B`@("!["B`@("`@("`@)%]315-324].6R=H;W)D95]M86EN=&5N86YC95]T
M87-K;&ES="==(#T@<V5R:6%L:7IE*"1T:&ES+3Y?=&%S:VQI<W0I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@8V%C:&5D(&UA:6YT96YA
M;F-E('1A<VML:7-T(&]R(&UA:V5S('-U<F4@;VYE(&ES"B`@("`@*B!C<F5A
M=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<F5T<FEE=F5487-K;&ES="@I"B`@("!["B`@("`@("`@
M:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&5?;6%I;G1E;F%N8V5?=&%S:VQI
M<W0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]T87-K;&ES="`]('5N<V5R
M:6%L:7IE*"1?4T534TE/3ELG:&]R9&5?;6%I;G1E;F%N8V5?=&%S:VQI<W0G
M72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]C<F5A
M=&5487-K;&ES="@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($5X96-U=&4@86QL(&-O;F9I<FUE9"!T87-K<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1O36%I;G1E
M;F%N8V5487-K<R@I"B`@("!["B`@("`@("`@)'1A<VMS(#T@)'1H:7,M/E]T
M87-K;&ES="T^9V5T3&ES="@I.PH*("`@("`@("!F;W)E86-H("@D=&%S:W,@
M87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF("@D=F%L6R=N97=P
M86=E)UTI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W1A<VML:7-T
M+3YP<F]C97-S960H*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=&%S:VQI<W0M/G-E=$YE=U!A9V4H)&ME>2P@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T@
M96QS96EF("@D=F%L6R=C;VYF:7)M960G72!\?`H@("`@("`@("`@("`@("`@
M("`@("`@571I;#HZ9V5T1F]R;41A=&$H)&ME>2`N("=?8V]N9FER;2<I*2![
M"B`@("`@("`@("`@("`@("`O*B!097)F;W)M(&UA:6YT96YA;F-E(&EF(&-O
M;F9I<FUE9"X@*B\*("`@("`@("`@("`@("`@("1M;V0@/2`F)'1H:7,M/E]L
M;V%D36]D=6QE*"1K97DI.PH@("`@("`@("`@("`@("`@)&UO9"T^9&]-86EN
M=&5N86YC92@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M=&%S:VQI<W0M/G)E;6]V951A<VLH)&ME>2D["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!W92=V92!S=6-C97-S9G5L;'D@8V]M<&QE=&5D(&5V97)Y('1A
M<VL@:6X@=&AE(&QI<W0@*&]R"B`@("`@("`@("H@<VMI<'!E9"!I="DL(')E
M8V]R9"!N;W<@87,@=&AE(&QA<W0@=&EM92!M86EN=&5N86YC92!W87,*("`@
M("`@("`@*B!R=6XN("HO"B`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7W1A
M<VML:7-T+3YG971,:7-T*"DI*2!["B`@("`@("`@("`@("1'3$]"04Q36R=P
M<F5F<R==+3YS971686QU92@G;&%S=%]M86EN=&5N86YC92<L('1I;64H*2D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&\@86YY(&]F('1H
M92!T87-K<R!R97%U:7)E('1H92!M86EN=&5N86YC92!P86=E/PH@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5&AE(&ME>2!O9B!T:&4@=&%S:R!T:&%T(')E<75I<F5S('1H
M92!M86EN=&5N86YC90H@("`@("H@("`@("`@("`@("`@("`@("!P86=E+B!2
M971U<FYS(&YU;&P@:68@=&AE(&UA:6YT96YA;F-E('!A9V4@:7,@;F\*("`@
M("`J("`@("`@("`@("`@("`@("`@;&]N9V5R(&YE961E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VYE961-86EN=&5N86YC95!A9V4H*0H@("`@>PH@("`@
M("`@("1I(#T@,#L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1A<VML:7-T
M+3YG971,:7-T*"D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF
M("@D=F%L6R=N97=P86=E)UTI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86Q;
M)W!R;V-E<W,G72D@)B8*("`@("`@("`@("`@("`@("%5=&EL.CIG971&;W)M
M1&%T82@G9&]M86EN=&5N86YC92<I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W1A<VML:7-T+3YS971.97=086=E*"1K97DL('1R=64I.PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1I*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*
M"GT*"B\J*@H@*B!4:&4@36%I;G1E;F%N8V5?5&%S:VQI<W0Z.B!C;&%S<R!I
M<R!U<V5D('1O('-T;W)E('1H92!L:7-T(&]F(&UA:6YT96YA;F-E"B`J('1A
M<VMS('1H870@;F5E9"!T;R!B92!R=6X@9'5R:6YG('1H:7,@;&]G:6XN"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7TUA:6YT96YA;F-E"B`J+PIC;&%S<R!-86EN=&5N86YC95]487-K
M;&ES="!["@H@("`@+RHJ"B`@("`@*B!4:&4@2&]R9&4@;6]D=6QE(')U;FYI
M;F<@=&AE(&UA:6YT96YA;F-E('1A<VMS+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUO9'5L93L*"B`@("`O*BH*("`@
M("`J(%1H92!54DP@;V8@=&AE('=E8B!P86=E('1O(&QO860@869T97(@;6%I
M;G1E;F%N8V4@:7,@8V]M<&QE=&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?=&%R9V5T.PH*("`@("\J*@H@("`@("H@
M4$]35"!D871A(&9O<B!T:&4@8V%L;&EN9R!S8W)I<'0N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P;W-T9&%T83L*"B`@
M("`O*BH*("`@("`J(%1H92!L:7-T(&]F('1A<VMS('1O(')U;B!D=7)I;F<@
M=&AI<R!L;V=I;BX*("`@("`J"B`@("`@*B!+15DZ("`@(%1A<VL@;F%M90H@
M("`@("H@5D%,544Z("!!<G)A>2`]/B`H"B`@("`@*B`@("`@("`@("`@)V-O
M;F9I<FUE9"<@(#T^("!B;V]L96%N+`H@("`@("H@("`@("`@("`@("=D:7-P
M;&%Y)R`@("`]/B`@:6YT96=E<BP*("`@("`J("`@("`@("`@("`G;F5W<&%G
M92<@("`@/3X@(&)O;VQE86XL"B`@("`@*B`@("`@("`@("`@)W!R;V-E<W,G
M("`@(#T^("!B;V]L96%N"B`@("`@*B`@("`@("`@("D*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1A<VMS(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($EN=&5R;F%L(&9L86<@9F]R(&%D9%1A<VLH
M*2X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?861D1FQA9R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@2&%S('1H92!T
M87-K;&ES="!B965N('!R;V-E<W-E9"!Y970_"B`@("`@*@H@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W!R;V-E<W-E9"`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($UA:6YT96YA;F-E7U1A<VML:7-T*"D*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D=&AI<RT^7VUO9'5L92`]("1R
M96=I<W1R>2T^9V5T07!P*"D["B`@("`@("`@)'1H:7,M/E]T87)G970@/2!(
M;W)D93HZ<V5L9E5R;"AT<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@82!T87-K('1O('1H92!T87-K;&ES="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1K97D@("`@("`@("!4:&4@;F%M92!O9B!T:&4@=&%S:R!T
M;R!P97)F;W)M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-O;F9I<FUE9"`@
M2&%S('1H92!T87-K(&)E96X@8V]N9FER;65D/PH@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&1I<W!L87D@("`@5&AE(&1I<W!L87D@='EP92!O9B!T:&4@=&%S
M:RX*("`@("`J+PH@("`@9G5N8W1I;VX@861D5&%S:R@D:V5Y+"`D8V]N9FER
M;65D+"`D9&ES<&QA>2D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<VMS6R1K
M97E=(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W1A<VMS6R1K97E=6R=C
M;VYF:7)M960G72`]("1C;VYF:7)M960["B`@("`@("`@)'1H:7,M/E]T87-K
M<ULD:V5Y75LG9&ES<&QA>2==(#T@)&1I<W!L87D["@H@("`@("`@(&EF("@H
M)&1I<W!L87D@/3T@34%)3E1%3D%.0T5?3U544%547T%'4D5%*2!\?`H@("`@
M("`@("`@("`H)&1I<W!L87D@/3T@34%)3E1%3D%.0T5?3U544%547TY/5$E#
M12DI('L*("`@("`@("`@("`@)'1H:7,M/E]T87-K<ULD:V5Y75LG;F5W<&%G
M92==(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/E]A9&1&;&%G(#T@9F%L
M<V4["B`@("`@("`@?2!E;'-E:68@*"@D8V]N9FER;65D(#T](&9A;'-E*2`F
M)B`H(21T:&ES+3Y?861D1FQA9RDI('L*("`@("`@("`@("`@)'1H:7,M/E]T
M87-K<ULD:V5Y75LG;F5W<&%G92==(#T@=')U93L*("`@("`@("`@("`@)'1H
M:7,M/E]A9&1&;&%G(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7W1A<VMS6R1K97E=6R=N97=P86=E)UT@/2!F86QS93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!N97=P
M86=E(&9L86<@9F]R(&$@=&%S:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T87-K("!4:&4@;F%M92!O9B!T:&4@=&%S:R!T;R!A;'1E<BX*("`@
M("`J($!P87)A;2!S=')I;F<@)&9L86<@($AO=R!T;R!S970@=&AE(&9L86<N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$YE=U!A9V4H)'1A<VLL("1F;&%G
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:6Y,:7-T*"1T87-K*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W1A<VMS6R1T87-K75LG;F5W<&%G92==(#T@
M)&9L86<["B`@("`@("`@("`@("1T:&ES+3Y?=&%S:W-;)'1A<VM=6R=P<F]C
M97-S)UT@/2`A)&9L86<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5M;W9E<R!T:&4@=&%S:R!F<F]M('1H92!T87-K;&ES="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87-K("!4:&4@;F%M92!O9B!T:&4@
M=&%S:R!T;R!A;'1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E5&%S
M:R@D=&%S:RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FEN3&ES="@D=&%S
M:RDI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]T87-K<ULD=&%S:UTI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H:7,@=&%S
M:R!A;')E861Y(&EN('1H92!T87-K;&ES=#\*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T87-K("!4:&4@;F%M92!O9B!T:&4@=&%S:RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AE('1A<VL@:7,@
M86QR96%D>2!I;B!T:&4@=&%S:VQI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&EN3&ES="@D=&%S:RD*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H
M:7,M/E]T87-K<ULD=&%S:UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!L:7-T(&]F('1A<VMS+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!L:7-T(&]F('1A<VMS('1H870@<W1I;&P@;F5E9"!T;R!B
M92!D;VYE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,:7-T*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]T87-K<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@2&]R9&4@;6]D=6QE('1H92!T87-K<R!A<F4@
M<G5N;FEN9R!U;F1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE($AO<F1E(&UO9'5L92!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971-;V1U;&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUO9'5L
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@4$]35"!D871A
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!03U-4(&1A=&$@
M9G)O;2!T:&4@:6YI=&EA;"!54DPN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!O<W1$871A*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P;W-T
M9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@55),(&]F
M('1H92!W96(@<&%G92!T;R!L;V%D(&%F=&5R(&UA:6YT96YA;F-E(&ES(&-O
M;7!L971E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&%R
M9V5T(%523"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&%R9V5T*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T87)G970["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3971S+V1I<W!L87ES('1H92!F;&%G('1O('-H;W<@=&AA
M="!T87-K;&ES="!H87,@8F5E;B!P<F]C97-S960@870*("`@("`J(&QE87-T
M(&]N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-E="`@4V5T
M('1H92!F;&%G/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@2&%S
M('1H92!T87-K;&ES="!B965N('!R;V-E<W-E9"!B969O<F4_"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!R;V-E<W-E9"@D<V5T(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)')E='9A;'5E(#T@)'1H:7,M/E]P<F]C97-S960["B`@("`@("`@
M:68@*"1S970I('L*("`@("`@("`@("`@)'1H:7,M/E]P<F]C97-S960@/2!T
M<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E='9A;'5E.PH@("`@
M?0H*?0H*+RHJ"B`J($%B<W1R86-T(&-L87-S('1O(&%L;&]W(&9O<B!M;V1U
M;&%R:7IA=&EO;B!O9B!S<&5C:69I8R!M86EN=&5N86-E('1A<VMS+@H@*@H@
M*B!&;W(@=&AI<R!E>'!L86YA=&EO;BP@=&AE('-P96-I9FEC($AO<F1E(&%P
M<&QI8V%T:6]N('EO=2!W86YT('1O(&-R96%T90H@*B!M86EN=&5N86YC92!A
M8W1I;VYS(&9O<B!W:6QL(&)E(&QA8F5L960@2$]21$5!4%`N"B`J"B`J(%1O
M(&%D9"!A(&YE=R!M86EN=&5N86YC92!T87-K+"!Y;W4@;F5E9"!T;R!D;R!T
M:&4@9F]L;&]W:6YG.@H@*B!;,5T@061D('!R969E<F5N8V4@=&\@(DA/4D1%
M05!0+V-O;F9I9R]P<F5F<RYP:'`B(&9I;&4N"B`J("`@("`H5&AE(&YA;64@
M;V8@=&AI<R!P<F5F97)E;F-E('=I;&P@8F4@<F5F97)R960@=&\@87,@4%)%
M1DY!344I"B`J("`@("!4:&ES('!R969E<F5N8V4@<VAO=6QD(&)E(&]F('1Y
M<&4@)V-H96-K8F]X)R`H:2YE+B`Q(#T@;VX[(#`@/2!O9F8I+@H@*B`@("`@
M6T]P=&EO;F%L.ET@($%D9"!A('!R969E<F5N8V4@:6X@<')E9G,N<&AP(&]F
M('1H92!N86UE"B`J("`@("`@("`@("`@("`@("`@)U!2149.04U%7VEN=&5R
M=F%L)R!T;R!A;&QO=R!T:&4@=7-E<B!T;R!S970@=&AE(&EN=&5R=F%L+@H@
M*B`@("`@("`@("`@("`@("`@("=D969A=6QT)R!V86QU92!S:&]U;&0@8F4@
M<V5T('1O('1H92!V86QU97,@;V8@=&AE(&EN=&5R=F%L"B`J("`@("`@("`@
M("`@("`@("`@8V]N<W1A;G1S(&%B;W9E+@H@*B`@("`@("`@("`@("`@("`@
M($EF('1H:7,@<')E9F5R96YC92!D;V5S;B=T(&5X:7-T+"!T:&4@9&5F875L
M="!I;G1E<G9A;`H@*B`@("`@("`@("`@("`@("`@('5S960@=VEL;"!B92!T
M:&4@;VYE('1H870@87!P96%R<R!I;B`D;6%I;G1?=&%S:W,N"B`J(%LR72!#
M<F5A=&4@82!D:7)E8W1O<GD@;F%M960@(DA/4D1%05!0+VQI8B]-86EN=&5N
M86YC92(N"B`J(%LS72!#<F5A=&4@82!C;&%S<R!E;G1I=&QE9"!-86EN=&5N
M86YC95](3U)$14%04"!T:&%T(&5X=&5N9',@=&AE"B`J("`@("!-86EN=&5N
M86YC92!C;&%S<RX*("H@("`@(%1H:7,@8VQA<W,@<VAO=6QD(&-O;G1A:6X@
M;VYL>2!T:&4@87!P;&EC871I;VX@<W!E8VEF:6,@9&5F:6YI=&EO;G,@;V8*
M("H@("`@("1M86EN=%]T87-K<R`H<V5E(&%B;W9E(&9O<B!D97-C<FEP=&EO
M;BDN"B`J("`@("!3879E('1H:7,@9FEL92!A<R`B2$]21$5!4%`O;&EB+TUA
M:6YT96YA;F-E+TA/4D1%05!0+G!H<"(N"B`J(%LT72!#<F5A=&4@82!D:7)E
M8W1O<GD@=&ET;&5D(")(3U)$14%04"]L:6(O36%I;G1E;F%N8V4O5&%S:R(N
M"B`J(%LU72!#<F5A=&4@;6]D=6QE<R!I;B!(3U)$14%04"]L:6(O36%I;G1E
M;F%N8V4O5&%S:R!N86UE9"`G4%)%1DY!344N<&AP)PH@*B`@("`@=&AA="!E
M>'1E;F0@=&AE($UA:6YT96YA;F-E7U1A<VL@8VQA<W,N"B`J("`@("!4:&4@
M8VQA<W,@<VAO=6QD(&)E(&YA;65D($UA:6YT96YA;F-E7U1A<VM?4%)%1DY!
M344N"B`J("`@("!4:&4@8VQA<W,@<VAO=6QD(&1E8VQA<F4@=&AE(&9O;&QO
M=VEN9R!T=V\@;65T:&]D<SH*("H@("`@("`@)V1O36%I;G1E;F%N8V4G("T@
M5&AI<R!I<R!T:&4@9G5N8W1I;VX@=&AA="!I<R!R=6X@=&\@9&\@=&AE"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@('-P96-I9FEE9"!M86EN=&5N86YC
M92!O<&5R871I;VXN"B`J("`@("`@("=D97-C<FEB94UA:6YT96YA;F-E)R`M
M(%1H:7,@9G5N8W1I;VX@<V5T<R!T:&4@<')E9F5R96YC92!T97AT"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%N9"!T97AT('1O(&)E('5S
M960@;VX@=&AE(&-O;F9I<FUA=&EO;@H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!P86=E+B`@4VAO=6QD(')E='5R;B!A(&1E<V-R:7!T:6]N
M(&]F('=H870*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@>6]U
M<B`G9&]-86EN=&5N86YC92<@9G5N8W1I;VX@:7,@86)O=70@=&\@9&\N"B`J
M("`@("!.96ET:&5R(&9U;F-T:6]N(')E<75I<F5S(&%N>2!P87)A;65T97)S
M('!A<W-E9"!I;BX*("H*("H@5&AE<F4@87)E(#,@9&EF9F5R96YT('1Y<&5S
M(&]F(&UA:6YT96YA;F-E("AS970@=FEA("1?9&ES<&QA>5]T>7!E*3H*("H@
M6S%=($U!24Y414Y!3D-%7T]55%!55%]#3TY&25)-"B`J("`@("!%86-H(&]U
M='!U="!F<F]M(&1E<V-R:6)E36%I;G1E;F%N8V4H*2!W:6QL(&AA=F4@82!C
M:&5C:V)O>"!A<W-O8VEA=&5D"B`J("`@("!W:71H(&ET+B!&;W(@96%C:"!C
M:&5C:V)O>"!S96QE8W1E9"P@9&]-86EN=&5N86YC92@I(&9O<B!T:&%T('1A
M<VL@=VEL;`H@*B`@("`@8F4@<G5N+B!-;W)E('1H86X@,2!C;VYF:7)M871I
M;VX@;65S<V%G92!C86X@8F4@9&ES<&QA>65D(&]N('1H90H@*B`@("`@;6%I
M;G1E;F%N8V4@<&%G92!A="!O;F-E+@H@*@H@*B!;,ET@34%)3E1%3D%.0T5?
M3U544%547T%'4D5%"B`J("`@("!4:&4@;W5T<'5T(&9R;VT@9&5S8W)I8F5-
M86EN=&5N86YC92@I('-H;W5L9"!B92!T97AT(&%S:VEN9R!T:&4@=7-E<B!T
M;PH@*B`@("`@86=R964O9&ES86=R964@=&\@<W!E8VEF:65D('1E<FUS+B!)
M9B`G>65S)R!I<R!S96QE8W1E9"P@=&AE(%!/4U0*("H@("`@('9A<FEA8FQE
M("=A9W)E92<@=VEL;"!B92!S970N($EF("=N;R<@:7,@<V5L96-T960L('1H
M92!03U-4('9A<FEA8FQE"B`J("`@("`G;F]T7V%G<F5E)R!W:6QL(&)E('-E
M="X@26X@96ET:&5R(&-A<V4L(&1O36%I;G1E;F%N8V4H*2!W:6QL($%,5T%9
M4R!B90H@*B`@("`@<G5N+@H@*B`@("`@*B!4:&ES('-T>6QE('=I;&P@8F4@
M9&ES<&QA>65D(&]N(&ET<R!O=VXL('-E<&%R871E(&UA:6YT96YA;F-E('!A
M9V4N("H*("H*("H@6S-=($U!24Y414Y!3D-%7T]55%!55%].3U1)0T4*("H@
M("`@(%1H92!O=71P=70@9G)O;2!D97-C<FEB94UA:6YT96YA;F-E*"D@<VAO
M=6QD(&)E(&%N>2!N;VXM:6YT97)A8W1I=F4@=&5X=`H@*B`@("`@9&5S:7)E
M9"X@5&AE<F4@=VEL;"!B92!A('-I;F=L92`G0VQI8VL@=&\@0V]N=&EN=64G
M(&)U='1O;B!B96QO=R!T:&ES"B`J("`@("!T97AT+B!D;TUA:6YT96YA;F-E
M*"D@=VEL;"!!3%=!65,@8F4@<G5N+@H@*B`@("`@*B!4:&ES('-T>6QE('=I
M;&P@8F4@9&ES<&QA>65D(&]N(&ET<R!O=VXL('-E<&%R871E(&UA:6YT96YA
M;F-E('!A9V4N("H*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`Q
M+C,N-0H@*B!`<&%C:V%G92!(;W)D95]-86EN=&5N86YC90H@*B\*8VQA<W,@
M36%I;G1E;F%N8V5?5&%S:R!["@H@("`@+RHJ"B`@("`@*B!4:&4@<W1Y;&4@
M;V8@=&AE(&UA:6YT96YA;F-E('!A9V4@;W5T<'5T+@H@("`@("H@4&]S<VEB
M;&4@=F%L=65S.B!-04E.5$5.04Y#15]/5510551?0T].1DE232P*("`@("`J
M("`@("`@("`@("`@("`@("`@34%)3E1%3D%.0T5?3U544%547T%'4D5%+`H@
M("`@("H@("`@("`@("`@("`@("`@("!-04E.5$5.04Y#15]/5510551?3D]4
M24-%"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D7V1I<W!L87E?='EP92`]($U!24Y414Y!3D-%7T]55%!55%]#3TY&25)-
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N
M8W1I;VX@36%I;G1E;F%N8V5?5&%S:R@I"B`@("!["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$;R!M86EN=&5N86YC92!O<&5R871I;VX@*&EF(&ET(&AA<R!B
M965N(&-O;F9I<FUE9"DN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!7:&5T:&5R('1H92!M86EN=&5N86YC92!O<&5R871I;VX@=V%S('-U8V-E
M<W-F=6P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@;F]T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D;TUA:6YT96YA;F-E*"D*("`@('L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@9&5S
M8W)I<'1I;VX@:6YF;W)M871I;VX@9F]R('1H92!M86EN=&5N86YC92!P86=E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!$97-C<FEP=&EO;B!T
M:&%T('=I;&P@8F4@9&ES<&QA>65D(&]N('1H92!M86EN=&5N86YC90H@("`@
M("H@("`@("`@("`@("`@("`@(&-O;F9I<FUA=&EO;B!P86=E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D97-C<FEB94UA:6YT96YA;F-E*"D*("`@('L*("`@
M("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!D97-I<F5D(&]U='!U="!T>7!E(&9O<B!T:&4@;6%I;G1E;F%N8V4@
M<&%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($1E<VER960@
M;W5T<'5T('1Y<&4@9F]R('1H92!M86EN=&5N86YC92!C;VYF:7)M871I;VX*
M("`@("`J("`@("`@("`@("`@("`@("`@<&%G92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1&ES<&QA>51Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1I<W!L87E?='EP93L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+G!H<```````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C<R-P`Q,#0Q-S,V,C<W,P`P,C`P,#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!A8G-T<F%C="!(;W)D95]";&]C:SHZ(&-L87-S(')E
M<')E<V5N=',@82!S:6YG;&4@8FQO8VL@=VET:&EN"B`J('1H92!";&]C:W,@
M9G)A;65W;W)K+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:RYP:'`L=B`Q+C,S+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HP."!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K('L*"B`@("`O*BH*("`@("`J
M($)L;V-K('-P96-I9FEC('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@07!P;&EC871I;VX@=&AA="!T:&ES(&)L;V-K(&]R
M:6=I;F%T960@9G)O;2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]A<'`["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87E\8F]O;&5A;B`D<&%R86US
M("!!;GD@<&%R86UE=&5R<R!T:&4@8FQO8VL@;F5E9',N($EF(&9A;'-E+`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&1E9F%U
M;'0@<&%R86UE=&5R('=I;&P@8F4@=7-E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?0FQO8VLH)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*"1P87)A;7,@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)A
M;7,@/2`D=&AI<RT^9V5T4&%R86US*"D["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1P87)A;7,@87,@)&YA;64@/3X@)'!A<F%M*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULD;F%M95T@/2`D<&%R86U;)V1E9F%U;'0G73L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!A<'!L:6-A=&EO;B!T:&%T('1H:7,@
M8FQO8VL@8F5L;VYG<R!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&%P<&QI8V%T:6]N(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$%P<"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?87!P.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;GD@<V5T=&%B;&4@<&%R
M86UE=&5R<R!F;W(@=&AI<R!B;&]C:RX@5&AI<R!I<R!A"B`@("`@*B!S=&%T
M:6,@;65T:&]D+B!)="!D;V5S("IN;W0J(')E9F5R96YC92`D=&AI<RT^7W!A
M<F%M<SL@=&AA="!I<PH@("`@("H@9F]R(')U;G1I;64@<&%R86UE=&5R<R`H
M=&AE(&-H;VEC97,@;6%D92!F<F]M('1H97-E(&]P=&EO;G,I+@H@("`@("H*
M("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4
M:&4@8FQO8VLG<R!C;VYF:6=U<F%B;&4@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%R86US*"D*("`@('L*("`@("`@("!G;&]B86P@
M)')E9VES=')Y.PH*("`@("`@("`O*B!3=VET8V@@87!P;&EC871I;VX@8V]N
M=&5X=',L(&EF(&YE8V5S<V%R>2X@4F5T=7)N(&%N(&5R<F]R"B`@("`@("`@
M("H@:6UM961I871E;'D@:68@<'5S:$%P<"@I(&9A:6QS+B`J+PH@("`@("`@
M("1A<'!?<'5S:&5D(#T@)')E9VES=')Y+3YP=7-H07!P*"1T:&ES+3Y?87!P
M*3L*("`@("`@("!I9B`H:7-?82@D87!P7W!U<VAE9"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&%P<%]P=7-H960M/F=E=$UE<W-A
M9V4H*3L*("`@("`@("!]"@H@("`@("`@("1P87)A;7,@/2`D=&AI<RT^7W!A
M<F%M<R@I.PH*("`@("`@("`O*B!)9B!W92!C:&%N9V5D(&%P<&QI8V%T:6]N
M(&-O;G1E>'0@:6X@=&AE(&-O=7)S92!O9B!T:&ES"B`@("`@("`@("H@8V%L
M;"P@=6YD;R!T:&%T(&-H86YG92!N;W<N("HO"B`@("`@("`@:68@*"1A<'!?
M<'5S:&5D(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1R96=I<W1R>2T^<&]P
M07!P*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1E>'0@=&\@9V\@:6X@
M=&AE('1I=&QE(&]F('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@5&AI<R!F
M=6YC=&EO;B!H86YD;&5S('1H92!C:&%N9VEN9R!O9B!C=7)R96YT(&%P<&QI
M8V%T:6]N(&%S"B`@("`@*B!N965D960@<V\@8V]D92!I<R!E>&5C=71E9"!I
M;B!T:&4@<V-O<&4@;V8@=&AE(&%P<&QI8V%T:6]N('1H90H@("`@("H@8FQO
M8VL@;W)I9VEN871E9"!F<F]M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8FQO8VLG<R!T:71L92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T5&ET;&4H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@
M("`@("`@("\J(%-W:71C:"!A<'!L:6-A=&EO;B!C;VYT97AT<RP@:68@;F5C
M97-S87)Y+B!2971U<FX@86X@97)R;W(*("`@("`@("`@*B!I;6UE9&EA=&5L
M>2!I9B!P=7-H07!P*"D@9F%I;',N("HO"B`@("`@("`@)&%P<%]P=7-H960@
M/2`D<F5G:7-T<GDM/G!U<VA!<'`H)'1H:7,M/E]A<'`I.PH@("`@("`@(&EF
M("AI<U]A*"1A<'!?<'5S:&5D+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D87!P7W!U<VAE9"T^9V5T365S<V%G92@I.PH@("`@("`@
M('T*"B`@("`@("`@)'1I=&QE(#T@)'1H:7,M/E]T:71L92@I.PH*("`@("`@
M("`O*B!)9B!W92!C:&%N9V5D(&%P<&QI8V%T:6]N(&-O;G1E>'0@:6X@=&AE
M(&-O=7)S92!O9B!T:&ES"B`@("`@("`@("H@8V%L;"P@=6YD;R!T:&%T(&-H
M86YG92!N;W<N("HO"B`@("`@("`@:68@*"1A<'!?<'5S:&5D(#T]/2!T<G5E
M*2!["B`@("`@("`@("`@("1R96=I<W1R>2T^<&]P07!P*"D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1I=&QE.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@8V]N=&5N="!F;W(@=&AI<R!B;&]C:RX*("`@("`J
M"B`@("`@*B!4:&ES(&9U;F-T:6]N(&AA;F1L97,@=&AE(&-H86YG:6YG(&]F
M(&-U<G)E;G0@87!P;&EC871I;VX@87,*("`@("`J(&YE961E9"!S;R!C;V1E
M(&ES(&5X96-U=&5D(&EN('1H92!S8V]P92!O9B!T:&4@87!P;&EC871I;VX@
M=&AE"B`@("`@*B!B;&]C:R!O<FEG:6YA=&5D(&9R;VTN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!B;&]C:R=S(&-O;G1E;G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G0H*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("\J(%-W:71C:"!A<'!L:6-A=&EO
M;B!C;VYT97AT<RP@:68@;F5C97-S87)Y+B!2971U<FX@86X@97)R;W(*("`@
M("`@("`@*B!I;6UE9&EA=&5L>2!I9B!P=7-H07!P*"D@9F%I;',N("HO"B`@
M("`@("`@)&%P<%]P=7-H960@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)'1H:7,M
M/E]A<'`I.PH@("`@("`@(&EF("AI<U]A*"1A<'!?<'5S:&5D+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D87!P7W!U<VAE9"T^9V5T
M365S<V%G92@I.PH@("`@("`@('T*"B`@("`@("`@)&-O;G1E;G0@/2`D=&AI
M<RT^7V-O;G1E;G0H*3L*"B`@("`@("`@+RH@268@=V4@8VAA;F=E9"!A<'!L
M:6-A=&EO;B!C;VYT97AT(&EN('1H92!C;W5R<V4@;V8@=&AI<PH@("`@("`@
M("`J(&-A;&PL('5N9&\@=&AA="!C:&%N9V4@;F]W+B`J+PH@("`@("`@(&EF
M("@D87!P7W!U<VAE9"`]/3T@=')U92D@>PH@("`@("`@("`@("`D<F5G:7-T
M<GDM/G!O<$%P<"@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;VYT
M96YT.PH@("`@?0H*("`@(&9U;F-T:6]N(&)U:6QD5')E92@F)'1R964L("1I
M;F1E;G0@/2`P+"`D<&%R96YT(#T@;G5L;"D*("`@('L*("`@("`@("!G;&]B
M86P@)')E9VES=')Y.PH*("`@("`@("`O*B!3=VET8V@@87!P;&EC871I;VX@
M8V]N=&5X=',L(&EF(&YE8V5S<V%R>2X@4F5T=7)N(&%N(&5R<F]R"B`@("`@
M("`@("H@:6UM961I871E;'D@:68@<'5S:$%P<"@I(&9A:6QS+B`J+PH@("`@
M("`@("1A<'!?<'5S:&5D(#T@)')E9VES=')Y+3YP=7-H07!P*"1T:&ES+3Y?
M87!P*3L*("`@("`@("!I9B`H:7-?82@D87!P7W!U<VAE9"P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&%P<%]P=7-H960M/F=E=$UE
M<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8G5I;&14<F5E
M*"1T<F5E+"`D:6YD96YT+"`D<&%R96YT*3L*"B`@("`@("`@+RH@268@=V4@
M8VAA;F=E9"!A<'!L:6-A=&EO;B!C;VYT97AT(&EN('1H92!C;W5R<V4@;V8@
M=&AI<PH@("`@("`@("`J(&-A;&PL('5N9&\@=&AA="!C:&%N9V4@;F]W+B`J
M+PH@("`@("`@(&EF("@D87!P7W!U<VAE9"`]/3T@=')U92D@>PH@("`@("`@
M("`@("`D<F5G:7-T<GDM/G!O<$%P<"@I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1I=&QE('1O(&=O(&EN('1H:7,@
M8FQO8VLN"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!B;&]C:R!T:71L92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*("`@("`@("!R971U<FX@)R<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A;65T97)S(&YE
M961E9"!B>2!B;&]C:RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8FQO8VLG<R!P87)A;65T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@
M("!R971U<FX@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AI<R!B;&]C:R=S(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!B;&]C:R=S
M(&-O;G1E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@
M('L*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H:7,@8FQO8VLG<R!C;VYT96YT+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8FQO
M8VLG<R!C;VYT96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&14<F5E
M*"8D=')E92P@)&EN9&5N="`](#`L("1P87)E;G0@/2!N=6QL*0H@("`@>PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-,22YP
M:'``````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R
M,C`T,P`Q,#0Q-S,V,C<W,P`P,3<S-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7T-,23HZ
M($%022!F;W(@8F%S:6,@8V]M;6%N9"UL:6YE(&9U;F-T:6]N86QI='DO8VAE
M8VMS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<"QV(#$N
M-#(N-BXQ,"`R,#`V+S`Q+S`Q(#(Q.C(X.C`Y(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-,20H@*B\*8VQA<W,@2&]R9&5?
M0TQ)('L*"B`@("`O*BH*("`@("`J($%R92!W92!R=6YN:6YG(&]N(&$@8V]N
M<V]L93\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?8V]N<V]L93L*"B`@("`O*BH*("`@("`J(%1H92!N97=L:6YE('-T
M<FEN9R!T;R!U<V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?;F5W;&EN93L*"B`@("`O*BH*("`@("`J(%1H92!I;F1E
M;G0@<W1R:6YG('1O('5S92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]I;F1E;G0["@H@("`@+RHJ"B`@("`@*B!4:&4@
M<W1R:6YG('1O(&UA<FL@=&AE(&)E9VEN;FEN9R!O9B!B;VQD('1E>'0N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8F]L
M9%]S=&%R="`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('-T<FEN9R!T;R!M
M87)K('1H92!E;F0@;V8@8F]L9"!T97AT+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)O;&1?96YD(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<W1R:6YG<R!T;R!M87)K('1H92!B96=I;FYI;F<@
M;V8@8V]L;W5R960@=&5X="X*("`@("`J+PH@("`@=F%R("1?<F5D7W-T87)T
M("`@(#T@)R<["B`@("!V87(@)%]G<F5E;E]S=&%R="`@/2`G)SL*("`@('9A
M<B`D7WEE;&QO=U]S=&%R="`]("<G.PH@("`@=F%R("1?8FQU95]S=&%R="`@
M(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@<W1R:6YG<R!T;R!M87)K('1H
M92!E;F0@;V8@8V]L;W5R960@=&5X="X*("`@("`J+PH@("`@=F%R("1?<F5D
M7V5N9"`@("`@(#T@)R<["B`@("!V87(@)%]G<F5E;E]E;F0@("`@/2`G)SL*
M("`@('9A<B`D7WEE;&QO=U]E;F0@("`]("<G.PH@("`@=F%R("1?8FQU95]E
M;F0@("`@(#T@)R<["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<VEN9VQE
M(&EN<W1A;F-E(&]F('1H92!(;W)D95]#3$D@8VQA<W,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D
M:6YS=&%N8V4["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V4I*2!["B`@
M("`@("`@("`@("1I;G-T86YC92`](&YE=R!(;W)D95]#3$DH*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1I;G-T86YC93L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E=&5C="!T:&4@8W5R<F5N="!E;G9I<F]N;65N="`H=V5B('-E
M<G9E<B!O<B!C;VYS;VQE*2!A;F0@<V5T<PH@("`@("H@:6YT97)N86P@=F%L
M=65S(&%C8V]R9&EN9VQY+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]#
M3$DH*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N<V]L92`]("1T:&ES+3YR
M=6YN:6YG1G)O;4-,22@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]C;VYS;VQE
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;F5W;&EN92`](")<;B(["B`@("`@
M("`@("`@("1T:&ES+3Y?:6YD96YT("`]("<@("`@)SL*"B`@("`@("`@("`@
M("1T97)M(#T@9V5T96YV*"=415)-)RD["B`@("`@("`@("`@(&EF("@D=&5R
M;2D@>PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>*'AT97)M
M?'9T,C(P?&QI;G5X*2\G+"`D=&5R;2DI('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V)O;&1?<W1A<G0@("`](")<>#%B6S%M(CL*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E9%]S=&%R="`@("`](")<>#%B6S`Q.S,Q
M;2(["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G<F5E;E]S=&%R="`@
M/2`B7'@Q8ELP,3LS,FTB.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M>65L;&]W7W-T87)T(#T@(EQX,6);,#$[,S-M(CL*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V)L=65?<W1A<G0@("`](")<>#%B6S`Q.S,T;2(["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B;VQD7V5N9"`]("1T:&ES+3Y?
M<F5D7V5N9"`]("1T:&ES+3Y?9W)E96Y?96YD(#T@)'1H:7,M/E]Y96QL;W=?
M96YD(#T@)'1H:7,M/E]B;'5E7V5N9"`](")<>#%B6S!M(CL*("`@("`@("`@
M("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7G9T,3`P+R<L("1T97)M
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8F]L9%]S=&%R="`]
M(")<>#%B6S%M(CL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V)O;&1?
M96YD("`@/2`B7'@Q8ELP;2(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VYE
M=VQI;F4@/2`G/&)R("\^)SL*("`@("`@("`@("`@)'1H:7,M/E]I;F1E;G0@
M(#T@<W1R7W)E<&5A="@G)FYB<W`[)RP@-"D["@H@("`@("`@("`@("`D=&AI
M<RT^7V)O;&1?<W1A<G0@("`]("<\<W1R;VYG/B<["B`@("`@("`@("`@("1T
M:&ES+3Y?8F]L9%]E;F0@("`@(#T@)SPO<W1R;VYG/B<["B`@("`@("`@("`@
M("1T:&ES+3Y?<F5D7W-T87)T("`@(#T@)SQS<&%N('-T>6QE/2)C;VQO<CIR
M960B/B<["B`@("`@("`@("`@("1T:&ES+3Y?9W)E96Y?<W1A<G0@(#T@)SQS
M<&%N('-T>6QE/2)C;VQO<CIG<F5E;B(^)SL*("`@("`@("`@("`@)'1H:7,M
M/E]Y96QL;W=?<W1A<G0@/2`G/'-P86X@<W1Y;&4](F-O;&]R.GEE;&QO=R(^
M)SL*("`@("`@("`@("`@)'1H:7,M/E]B;'5E7W-T87)T("`@/2`G/'-P86X@
M<W1Y;&4](F-O;&]R.F)L=64B/B<["B`@("`@("`@("`@("1T:&ES+3Y?<F5D
M7V5N9"`]("1T:&ES+3Y?9W)E96Y?96YD(#T@)'1H:7,M/E]Y96QL;W=?96YD
M(#T@)'1H:7,M/E]B;'5E7V5N9"`]("<\+W-P86X^)SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0<FEN=',@)'1E>'0@;VX@82!S:6YG;&4@
M;&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&5X="`@5&AE
M('1E>'0@=&\@<')I;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<')E("`@
M268@=')U92!T:&4@;&EN96)R96%K(&ES('!R:6YT960@8F5F;W)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=&AE('1E>'0@:6YS=&5A9"!O9B!A
M9G1E<B!I="X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5L;B@D=&5X="`]
M("<G+"`D<')E(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1P<F4I('L*
M("`@("`@("`@("`@96-H;R`D=&AI<RT^7VYE=VQI;F4@+B`D=&5X=#L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("1T97AT("X@)'1H:7,M
M/E]N97=L:6YE.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&EN9&5N=&5D('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!I;F1E;G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&EN9&5N="@D=&5X="D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;F1E;G0@+B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!B;VQD('9E<G-I;VX@;V8@)'1E>'0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@8F]L9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8F]L9"@D=&5X="D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]B;VQD7W-T87)T("X@)'1E>'0@+B`D=&AI<RT^
M7V)O;&1?96YD.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E
M9"!V97)S:6]N(&]F("1T97AT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@(%1H92!T97AT('1O('!R:6YT(&EN(')E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5D*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)E9%]S=&%R="`N("1T97AT("X@)'1H:7,M/E]R961?96YD.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&=R965N('9E<G-I;VX@
M;V8@)'1E>'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@
M5&AE('1E>'0@=&\@<')I;G0@:6X@9W)E96XN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=R965N*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V=R965N7W-T87)T("X@)'1E>'0@+B`D=&AI<RT^7V=R965N7V5N9#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!B;'5E('9E<G-I;VX@;V8@
M)'1E>'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE
M('1E>'0@=&\@<')I;G0@:6X@8FQU92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8FQU92@D=&5X="D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B;'5E
M7W-T87)T("X@)'1E>'0@+B`D=&AI<RT^7V)L=65?96YD.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A('EE;&QO=R!V97)S:6]N(&]F("1T97AT
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT
M('1O('!R:6YT(&EN('EE;&QO=RX*("`@("`J+PH@("`@9G5N8W1I;VX@>65L
M;&]W*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7WEE;&QO
M=U]S=&%R="`N("1T97AT("X@)'1H:7,M/E]Y96QL;W=?96YD.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&ES<&QA>7,@82!M97-S86=E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&5V96YT("!4:&4@;65S<V%G92!S=')I;F<N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@5&AE('1Y<&4@;V8@;65S
M<V%G93H@)V-L:2YE<G)O<B<L("=C;&DN=V%R;FEN9R<L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@)V-L:2YS=6-C97-S)RP@;W(@)V-L:2YM97-S
M86=E)RX*("`@("`J+PH@("`@9G5N8W1I;VX@;65S<V%G92@D;65S<V%G92P@
M)'1Y<&4@/2`G8VQI+FUE<W-A9V4G*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)'1Y<&4I('L*("`@("`@("!C87-E("=C;&DN97)R;W(G.@H@("`@("`@("`@
M("`D='EP95]M97-S86=E(#T@)'1H:7,M/G)E9"@G6R!%4E)/4B$@72`G*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V-L:2YW87)N:6YG
M)SH*("`@("`@("`@("`@)'1Y<&5?;65S<V%G92`]("1T:&ES+3YY96QL;W<H
M)UL@(%=!4DX@(%T@)RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=C;&DN<W5C8V5S<R<Z"B`@("`@("`@("`@("1T>7!E7VUE<W-A9V4@
M/2`D=&AI<RT^9W)E96XH)UL@("!/2R`@(%T@)RD["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=C;&DN;65S<V%G92<Z"B`@("`@("`@("`@
M("1T>7!E7VUE<W-A9V4@/2`D=&AI<RT^8FQU92@G6R`@24Y&3R`@72`G*3L*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M=W)I=&5L;B@D='EP95]M97-S86=E("X@)&UE<W-A9V4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&ES<&QA>7,@82!F871A;"!E<G)O<B!M97-S86=E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5R<F]R("!4:&4@97)R;W(@
M=&5X="!T;R!D:7-P;&%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!F871A;"@D
M97)R;W(I"B`@("!["B`@("`@("`@)'1H:7,M/G=R:71E;&XH)'1H:7,M/G)E
M9"@G/3T]/3T]/3T]/3T]/3T]/3T]/3TG*2D["B`@("`@("`@)'1H:7,M/G=R
M:71E;&XH*3L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@D=&AI<RT^<F5D*%\H
M(D9A=&%L($5R<F]R.B(I*2D["B`@("`@("`@)'1H:7,M/G=R:71E;&XH)'1H
M:7,M/G)E9"@D97)R;W(I*3L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@I.PH@
M("`@("`@("1T:&ES+3YW<FET96QN*"1T:&ES+3YR960H)ST]/3T]/3T]/3T]
M/3T]/3T]/3T])RDI.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!0<F]M<'1S(&9O<B!A('5S97(@<F5S<&]N<V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<')O;7!T("!4:&4@;65S<V%G92!T;R!D:7-P
M;&%Y('=H96X@<')O;7!T:6YG('1H92!U<V5R+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1C:&]I8V5S("!4:&4@8VAO:6-E<R!A=F%I;&%B;&4@=&\@=&AE('5S
M97(@;W(@;G5L;"!F;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!T97AT(&EN<'5T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!U<V5R)W,@<F5S<&]N<V4@=&\@=&AE('!R;VUP="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<')O;7!T*"1P<F]M<'0L("1C:&]I8V5S(#T@;G5L;"D*("`@
M('L*("`@("`@("`O+R!-86EN(&5V96YT(&QO;W`@=&\@8V%P='5R92!T;W`@
M;&5V96P@8V]M;6%N9"X*("`@("`@("!W:&EL92`H=')U92D@>PH@("`@("`@
M("`@("`O+R!0<FEN="!O=70@=&AE('!R;VUP="!M97-S86=E+@H@("`@("`@
M("`@("`D=&AI<RT^=W)I=&5L;B@D<')O;7!T("X@)R`G+"`A:7-?87)R87DH
M)&-H;VEC97,I*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1C:&]I8V5S
M*2`F)B`A96UP='DH)&-H;VEC97,I*2!["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D8VAO:6-E<R!A<R`D:V5Y(#T^("1C:&]I8V4I('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W)I=&5L;B@D=&AI<RT^:6YD96YT*"<H)R`N
M("1T:&ES+3YB;VQD*"1K97DI("X@)RD@)R`N("1C:&]I8V4I*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3YW<FET96QN*%\H
M(E1Y<&4@>6]U<B!C:&]I8V4Z("(I+"!T<G5E*3L*("`@("`@("`@("`@("`@
M($!O8E]F;'5S:"@I.PH*("`@("`@("`@("`@("`@("\O($=E="!T:&4@=7-E
M<B!C:&]I8V4N"B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2!T<FEM*&9G
M971S*%-41$E.*2D["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-H;VEC
M97-;)')E<W!O;G-E72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W!O;G-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W)I=&5L;BAS<')I;G1F*%\H(EPB)7-<(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(BDL("1R97-P;VYS92DI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('1R:6TH9F=E=',H4U1$24XI*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296%D<R!E=F5R>71H:6YG('1H870@:7,@<V5N="!T:')O=6=H
M('-T86YD87)D(&EN<'5T(&%N9"!R971U<FYS(&ET"B`@("`@*B!A<R!A('-I
M;F=L92!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!C;VYT96YT<R!O9B!T:&4@<W1A;F1A<F0@:6YP=70N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E8613=&1I;B@I"B`@("!["B`@("`@("`@)&EN(#T@)R<[
M"B`@("`@("`@=VAI;&4@*"%F96]F*%-41$E.*2D@>PH@("`@("`@("`@("`D
M:6X@+CT@9F=E=',H4U1$24XL(#$P,C0I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&EN.PH@("`@?0H*("`@("\J*@H@("`@("H@0TQ)('-C<FEP=',@
M<VAO=6QD;B=T('1I;65O=70L('-O('1R>2!T;R!S970@=&AE('1I;64@;&EM
M:70@=&\*("`@("`J(&YO;F4N($%L<V\@:6YI=&EA;&EZ92!A(&9E=R!V87)I
M86)L97,@:6X@)%]315)615(@=&AA="!A<F5N)W0*("`@("`J('!R97-E;G0@
M9G)O;2!T:&4@0TQ)+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@("`@0'-E=%]T:6UE7VQI
M;6ET*#`I.PH@("`@("`@(&]B7VEM<&QI8VET7V9L=7-H*'1R=64I.PH@("`@
M("`@(&EN:5]S970H)VAT;6Q?97)R;W)S)RP@9F%L<V4I.PH@("`@("`@("1?
M4T525D526R=(5%107TA/4U0G72`]("<Q,C<N,"XP+C$G.PH@("`@("`@("1?
M4T525D526R=315)615)?3D%-12==(#T@)S$R-RXP+C`N,2<["B`@("`@("`@
M)%]315)615);)U-%4E9%4E]03U)4)UT@/2`G)SL*("`@("`@("`D7U-%4E9%
M4ELG4D5-3U1%7T%$1%(G72`]("<G.PH@("`@("`@("1?4T525D526R=02%!?
M4T5,1B==(#T@:7-S970H)&%R9W8I(#\@)&%R9W9;,%T@.B`G)SL*("`@("`@
M("!I9B`H(61E9FEN960H)U-41$E.)RDI('L*("`@("`@("`@("`@9&5F:6YE
M*"=35$1)3B<L(&9O<&5N*"=P:'`Z+R]S=&1I;B<L("=R)RDI.PH@("`@("`@
M('T*("`@("`@("!I9B`H(61E9FEN960H)U-41$]55"<I*2!["B`@("`@("`@
M("`@(&1E9FEN92@G4U1$3U54)RP@9F]P96XH)W!H<#HO+W-T9&]U="<L("=R
M)RDI.PH@("`@("`@('T*("`@("`@("!I9B`H(61E9FEN960H)U-41$524B<I
M*2!["B`@("`@("`@("`@(&1E9FEN92@G4U1$15)2)RP@9F]P96XH)W!H<#HO
M+W-T9&5R<B<L("=R)RDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($UA:V4@<W5R92!W92=R92!B96EN9R!C86QL960@9G)O;2!T:&4@8V]M
M;6%N9"!L:6YE+"!A;F0@;F]T('9I80H@("`@("H@=&AE('=E8BX*("`@("`J
M"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('=E(&%R92P@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R=6YN:6YG1G)O;4-,22@I"B`@("!["B`@("`@("`@)'-A
M<&D@/2!P:'!?<V%P:5]N86UE*"D["B`@("`@("`@:68@*"1S87!I(#T]("=C
M;&DG*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D<V%P:2`]/2`G8V=I)R`F)B!E;7!T
M>2@D7U-%4E9%4ELG4T525D527TY!344G72D["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]"<F]W<V5R+G!H<```````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3$U,#<`,3`T,3<S-C(W-S,`,#(P
M,S<S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ
M"B`J(%1H92!"<F]W<V5R.CH@8VQA<W,@<')O=FED97,@8V%P86)I;&ET>2!I
M;F9O<FUA=&EO;B!F;W(@=&AE(&-U<G)E;G0*("H@=V5B(&-L:65N="X*("H*
M("H@0G)O=W-E<B!I9&5N=&EF:6-A=&EO;B!I<R!P97)F;W)M960@8GD@97AA
M;6EN:6YG('1H92!(5%107U5315)?04=%3E0*("H@96YV:7)O;FUE;G0@=F%R
M:6%B;&4@<')O=FED960@8GD@=&AE('=E8B!S97)V97(N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`L=B`Q+C$U,RXR+C0R
M(#(P,#8O,#,O,34@,3<Z,#`Z,#(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I
M<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`
M<&%C:V%G92!(;W)D95]"<F]W<V5R"B`J+PIC;&%S<R!"<F]W<V5R('L*"B`@
M("`O*BH*("`@("`J($UA:F]R('9E<G-I;VX@;G5M8F5R+@H@("`@("H*("`@
M("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]M86IO<E9E<G-I
M;VX@/2`P.PH*("`@("\J*@H@("`@("H@36EN;W(@=F5R<VEO;B!N=6UB97(N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7VUI;F]R5F5R<VEO;B`](#`["@H@("`@+RHJ"B`@("`@*B!"<F]W<V5R(&YA
M;64N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?8G)O=W-E<B`]("<G.PH*("`@("\J*@H@("`@("H@1G5L;"!U<V5R(&%G
M96YT('-T<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]A9V5N="`]("<G.PH*("`@("\J*@H@("`@("H@3&]W97(M
M8V%S92!U<V5R(&%G96YT('-T<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]L;W=E<D%G96YT(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!(5%107T%#0T505"!S=')I;F<*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A8V-E<'0@/2`G)SL*"B`@
M("`O*BH*("`@("`J(%!L871F;W)M('1H92!B<F]W<V5R(&ES(')U;FYI;F<@
M;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?<&QA=&9O<FT@/2`G)SL*"B`@("`O*BH*("`@("`J($MN;W=N(')O8F]T
M<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W)O8F]T<R`](&%R<F%Y*`H@("`@("`@("\J(%1H92!M;W-T(&-O;6UO;B!O
M;F5S+B`J+PH@("`@("`@("=';V]G;&5B;W0G+`H@("`@("`@("=M<VYB;W0G
M+`H@("`@("`@("=3;'5R<"<L"B`@("`@("`@)UEA:&]O)RP*("`@("`@("`O
M*B!4:&4@<F5S="!A;'!H86)E=&EC86QL>2X@*B\*("`@("`@("`G87!P:64G
M+`H@("`@("`@("=!<F%C:&YO:61E82<L"B`@("`@("`@)T%R8VAI=&5X=%-P
M:61E<B<L"B`@("`@("`@)T%S:R!*965V97,G+`H@("`@("`@("="+6PM:2UT
M+7HM0F]T)RP*("`@("`@("`G0F%I9'5S<&ED97(G+`H@("`@("`@("="96-O
M;65";W0G+`H@("`@("`@("=C9F5T8V@G+`H@("`@("`@("=#;VYV97)A0W)A
M=VQE<B<L"B`@("`@("`@)T5X=')A8W1O<E!R;R<L"B`@("`@("`@)T9!4U0M
M5V5B0W)A=VQE<B<L"B`@("`@("`@)T9$4T4@<F]B;W0G+`H@("`@("`@("=F
M:61O)RP*("`@("`@("`G9FEN9&QI;FMS)RP*("`@("`@("`G1G)A;F-I<R<L
M"B`@("`@("`@)V=E8VMO8F]T)RP*("`@("`@("`G1VEG86)O="<L"B`@("`@
M("`@)T=I<F%F86)O="<L"B`@("`@("`@)V=R=6(M8VQI96YT)RP*("`@("`@
M("`G1W5L;&EV97(G+`H@("`@("`@("=(5%1R86-K)RP*("`@("`@("`G:6%?
M87)C:&EV97(G+`H@("`@("`@("=I0T-R87=L97(G+`H@("`@("`@("=);F9O
M4V5E:R<L"B`@("`@("`@)VMI;FIA8F]T)RP*("`@("`@("`G2TE4+49I<F5B
M86QL)RP*("`@("`@("`G;&%R8FEN)RP*("`@("`@("`G3$5)02<L"B`@("`@
M("`@)VQM<W!I9&5R)RP*("`@("`@("`G;'=P+71R:79I86PG+`H@("`@("`@
M("=,>6-O<U]3<&ED97(G+`H@("`@("`@("=-961I87!A<G1N97)S+4=O;V=L
M92<L"B`@("`@("`@)TUU<V-A=$9E<G)E="<L"B`@("`@("`@)TYA=F5R0F]T
M)RP*("`@("`@("`G3VUN:45X<&QO<F5R7T)O="<L"B`@("`@("`@)W!O;'EB
M;W0G+`H@("`@("`@("=0;VUP;W,G+`H@("`@("`@("=2=69U<T)O="<L"B`@
M("`@("`@)U-C;V]T97(G+`H@("`@("`@("=3965K8F]T)RP*("`@("`@("`G
M5&5O;6$G+`H@("`@("`@("=4:&53=4)O="<L"B`@("`@("`@)U1U<FYI=&EN
M0F]T)RP*("`@("`@("`G56QT<F%S965K)RP*("`@("`@("`G5FEO;&%";W0G
M+`H@("`@("`@("=V;WEA9V5R)RP*("`@("`@("`G=V5B8F%N9&ET)RP*("`@
M("`@("`G=W=W+F%L;6%D96XN:6)M+F-O;2]C<R]C<F%W;&5R)RP*("`@("`@
M("`G>6%C>2<L"B`@("`@("`@)UIY0F]R9R<L"B`@("`I.PH*("`@("\J*@H@
M("`@("H@27,@=&AI<R!A(&UO8FEL92!B<F]W<V5R/PH@("`@("H*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]M;V)I;&4@/2!F86QS
M93L*"B`@("`O*BH*("`@("`J($9E871U<F5S+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9F5A='5R97,@/2!A<G)A>2@*
M("`@("`@("`G:'1M;"<@("`@("`@/3X@=')U92P*("`@("`@("`G:&1M;"<@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W=M;"<@("`@("`@(#T^(&9A;'-E
M+`H@("`@("`@("=I;6%G97,G("`@("`]/B!T<G5E+`H@("`@("`@("=I9G)A
M;65S)R`@("`]/B!F86QS92P*("`@("`@("`G9G)A;65S)R`@("`@/3X@=')U
M92P*("`@("`@("`G=&%B;&5S)R`@("`@/3X@=')U92P*("`@("`@("`G:F%V
M82<@("`@("`@/3X@=')U92P*("`@("`@("`G:F%V87-C<FEP="<@/3X@=')U
M92P*("`@("`@("`G9&]M)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W5T
M9B<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=R=&4G("`@("`@("`]/B!F
M86QS92P*("`@("`@("`G:&]M97!A9V4G("`@/3X@9F%L<V4L"B`@("`@("`@
M)V%C8V5S<VME>2<@(#T^(&9A;'-E+`H@("`@("`@("=O<'1G<F]U<"<@("`]
M/B!F86QS92P*("`@("`@("`G>&UL:'1T<')E<2<@/3X@9F%L<V4L"B`@("`@
M("`@)V-I=&4G("`@("`@(#T^(&9A;'-E+`H@("`@*3L*"B`@("`O*BH*("`@
M("`J(%%U:7)K<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?<75I<FMS(#T@87)R87DH"B`@("`@("`@)V%V;VED7W!O<'5P
M7W=I;F1O=W,G("`@("`@("`]/B!F86QS92P*("`@("`@("`G8G)E86M?9&ES
M<&]S:71I;VY?:&5A9&5R)R`@(#T^(&9A;'-E+`H@("`@("`@("=B<F5A:U]D
M:7-P;W-I=&EO;E]F:6QE;F%M92<@/3X@9F%L<V4L"B`@("`@("`@)V)R;VME
M;E]M=6QT:7!A<G1?9F]R;2<@("`@("`]/B!F86QS92P*("`@("`@("`G8G5G
M9WE?8V]M<')E<W-I;VXG("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=C
M86-H95]S86UE7W5R;"<@("`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M)V-A8VAE7W-S;%]D;W=N;&]A9',G("`@("`@("`]/B!F86QS92P*("`@("`@
M("`G9&]U8FQE7VQI;F5B<F5A:U]T97AT87)E82<@(#T^(&9A;'-E+`H@("`@
M("`@("=E;7!T>5]F:6QE7VEN<'5T7W9A;'5E)R`@("`@/3X@9F%L<V4L"B`@
M("`@("`@)VUU<W1?8V%C:&5?9F]R;7,G("`@("`@("`@("`]/B!F86QS92P*
M("`@("`@("`G;F]?9FEL96YA;65?<W!A8V5S)R`@("`@("`@(#T^(&9A;'-E
M+`H@("`@("`@("=N;U]H:61D96Y?;W9E<F9L;W=?=&%B;&5S)R`@/3X@9F%L
M<V4L"B`@("`@("`@)V]W7V=U:5\Q+C,G("`@("`@("`@("`@("`@("`]/B!F
M86QS92P*("`@("`@("`G<&YG7W1R86YS<&%R96YC>2<@("`@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("=S8W)O;&QB87)?:6Y?=V%Y)R`@("`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)W-C<F]L;%]T9',G("`@("`@("`@("`@("`@
M("`]/B!F86QS92P*("`@("`@("`G=VEN9&]W961?8V]N=')O;',G("`@("`@
M("`@(#T^(&9A;'-E+`H@("`@*3L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@
M=FEE=V%B;&4@:6UA9V4@34E-12!S=6)T>7!E<RX*("`@("`J(%1H:7,@;&ES
M="!O9B!V:65W86)L92!I;6%G97,@=V]R:W,@9F]R($E%(&%N9"!.971S8V%P
M92]-;WII;&QA+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?:6UA9V5S(#T@87)R87DH)VIP96<G+"`G9VEF)RP@)W!N9R<L
M("=P:G!E9R<L("=X+7!N9R<L("=B;7`G*3L*"B`@("`O*BH*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!R969E<F5N8V4@=&\@=&AE(&=L;V)A;"!"<F]W
M<V5R(&]B:F5C="P@;VYL>2!C<F5A=&EN9R!I=`H@("`@("H@:68@:70@9&]E
M<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M(&UU<W0@8F4@:6YV;VME9"!A<SH\<')E/@H@("`@("H@("`D8G)O=W-E<B`]
M("9"<F]W<V5R.CIS:6YG;&5T;VXH6R1U<V5R06=E;G1;+"`D86-C97!T75TI
M.SPO<')E/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)!9V5N
M="`@5&AE(&)R;W=S97(@<W1R:6YG('1O('!A<G-E+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D86-C97!T("`@("!4:&4@2%144%]!0T-%4%0@<V5T=&EN9W,@
M=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@0G)O=W-E<B`@5&AE($)R
M;W=S97(@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N
M*"1U<V5R06=E;G0@/2!N=6QL+"`D86-C97!T(#T@;G5L;"D*("`@('L*("`@
M("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*"B`@("`@("`@:68@*"%I<W-E="@D
M:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H
M87)R87DH)'5S97)!9V5N="P@)&%C8V5P="DI.PH@("`@("`@(&EF("AE;7!T
M>2@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=(#T@;F5W($)R;W=S97(H)'5S97)!9V5N="P@
M)&%C8V5P="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E73L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A
M(&)R;W=S97(@:6YS=&%N8V4@*$-O;G-T<G5C=&]R*2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R06=E;G0@(%1H92!B<F]W<V5R('-T<FEN
M9R!T;R!P87)S92X*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5P="`@("`@
M5&AE($A45%!?04-#15!4('-E='1I;F=S('1O('5S92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@0G)O=W-E<B@D=7-E<D%G96YT(#T@;G5L;"P@)&%C8V5P="`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/FUA=&-H*"1U<V5R06=E;G0L
M("1A8V-E<'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S('1H92!U
M<V5R(&%G96YT('-T<FEN9R!A;F0@:6YI=&ET:6%L:7IE<R!T:&4@;V)J96-T
M('=I=&@*("`@("`J(&%L;"!T:&4@:VYO=VX@9F5A='5R97,@86YD('%U:7)K
M<R!F;W(@=&AE(&=I=F5N(&)R;W=S97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<D%G96YT("!4:&4@8G)O=W-E<B!S=')I;F<@=&\@<&%R
M<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8V-E<'0@("`@(%1H92!(5%10
M7T%#0T505"!S971T:6YG<R!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&UA=&-H*"1U<V5R06=E;G0@/2!N=6QL+"`D86-C97!T(#T@;G5L;"D*("`@
M('L*("`@("`@("`O+R!3970@;W5R(&%G96YT('-T<FEN9RX*("`@("`@("!I
M9B`H:7-?;G5L;"@D=7-E<D%G96YT*2D@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)%]315)615);)TA45%!?55-%4E]!1T5.5"==*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9V5N="`]('1R:6TH)%]315)615);)TA45%!?55-%
M4E]!1T5.5"==*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?86=E;G0@/2`D=7-E<D%G96YT.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7VQO=V5R06=E;G0@/2!3=')I;F<Z.FQO=V5R
M*"1T:&ES+3Y?86=E;G0I.PH*("`@("`@("`O+R!3970@;W5R(&%C8V5P="!S
M=')I;F<N"B`@("`@("`@:68@*&ES7VYU;&PH)&%C8V5P="DI('L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1?4T525D526R=(5%107T%#0T505"==*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A8V-E<'0@/2!3=')I;F<Z.FQO=V5R
M*'1R:6TH)%]315)615);)TA45%!?04-#15!4)UTI*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?86-C97!T
M(#T@4W1R:6YG.CIL;W=E<B@D86-C97!T*3L*("`@("`@("!]"@H@("`@("`@
M("\O($-H96-K(&9O<B!55$8@<W5P<&]R="X*("`@("`@("!I9B`H:7-S970H
M)%]315)615);)TA45%!?04-#15!47T-(05)3150G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<L('-T<G!O<RA3=')I;F<Z.FQO
M=V5R*"1?4T525D526R=(5%107T%#0T505%]#2$%24T54)UTI+"`G=71F)RD@
M(3T](&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]A9V5N="DI('L*("`@("`@("`@("`@)'1H:7,M/E]S9710;&%T9F]R
M;2@I.PH*("`@("`@("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7VQO=V5R06=E
M;G0L("=M;V)I;&5E>'!L;W)E<B<I("$]/2!F86QS92!\?`H@("`@("`@("`@
M("`@("`@<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)V]P96YW879E)RD@
M(3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@("!S=')P;W,H)'1H:7,M/E]L
M;W=E<D%G96YT+"`G;W!E<F$@;6EN:2<I("$]/2!F86QS92!\?`H@("`@("`@
M("`@("`@("`@<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)V]P97)A;6EN
M:2<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)V9R86UE<R<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=%%U:7)K*"=A=F]I9%]P;W!U<%]W:6YD;W=S)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@
M("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"=\3W!E<F%;+R!=*%LP+3DN
M72LI?"<L("1T:&ES+3Y?86=E;G0L("1V97)S:6]N*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)V]P97)A)RD["B`@("`@
M("`@("`@("`@("`@("`@("!L:7-T*"1T:&ES+3Y?;6%J;W)697)S:6]N+"`D
M=&AI<RT^7VUI;F]R5F5R<VEO;BD@/2!E>'!L;V1E*"<N)RP@)'9E<G-I;VY;
M,5TI.PH@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)VIA=F%S8W)I<'0G+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS9711=6ER:R@G;F]?9FEL96YA;65?<W!A8V5S)RD["@H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?;6%J;W)697)S:6]N(#X](#<I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G9&]M)RD["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEF<F%M97,G
M*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G86-C
M97-S:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)V]P=&=R;W5P)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=%%U:7)K*"=D;W5B;&5?;&EN96)R96%K7W1E>'1A<F5A)RD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M
M/E]L;W=E<D%G96YT+"`G96QA:6YE+R<I("$]/2!F86QS92!\?`H@("`@("`@
M("`@("`@("`@("`@("`@<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)W!A
M;&US;W5R8V4G*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("`@
M('-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=D:6=I=&%L('!A=&AS)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E
M<B@G<&%L;2<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)VEM86=E<R<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=F<F%M97,G+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS9711=6ER:R@G879O:61?<&]P=7!?=VEN9&]W<R<I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@
M("`@("`@("!](&5L<V5I9B`H*'!R96=?;6%T8V@H)WQ-4TE%("A;,"TY+ETK
M*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI('Q\"B`@("`@("`@("`@
M("`@("`@("`@("`H<')E9U]M871C:"@G?$EN=&5R;F5T($5X<&QO<F5R+RA;
M,"TY+ETK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI*2!["@H@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VUS:64G*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G8V%C:&5?<W-L7V1O=VYL;V%D
M<R<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=C86-H95]S
M86UE7W5R;"<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=B
M<F5A:U]D:7-P;W-I=&EO;E]F:6QE;F%M92<I.PH*("`@("`@("`@("`@("`@
M(&EF("AS=')P;W,H)'9E<G-I;VY;,5TL("<N)RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`@("`@;&ES="@D=&AI<RT^7VUA:F]R5F5R<VEO;BP@
M)'1H:7,M/E]M:6YO<E9E<G-I;VXI(#T@97AP;&]D92@G+B<L("1V97)S:6]N
M6S%=*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]M86IO<E9E<G-I;VX@/2`D=F5R<VEO;ELQ73L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VUI;F]R5F5R<VEO;B`](#`["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@244@*#P@-RD@
M;VX@5VEN9&]W<R!D;V5S(&YO="!S=7!P;W)T(&%L<&AA('1R86YS<&%R96YC
M>2!I;@H@("`@("`@("`@("`@("`@("H@4$Y'(&EM86=E<RX@*B\*("`@("`@
M("`@("`@("`@(&EF("@H)'1H:7,M/E]M86IO<E9E<G-I;VX@/"`W*2`F)@H@
M("`@("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)R]W:6YD;W=S+VDG+"`D
M=&AI<RT^7V%G96YT*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M9711=6ER:R@G<&YG7W1R86YS<&%R96YC>2<I.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("\J($E%(#8@*'!R92U34#$I(&%N9"`U+C4@
M*'!R92U34#$I(&AA=F4@8G5G9WD@8V]M<')E<W-I;VXN"B`@("`@("`@("`@
M("`@("`@*B!4:&4@=F5R<VEO;G,@869F96-T960@87)E(&%S(&9O;&QO=W,Z
M"B`@("`@("`@("`@("`@("`@*B`V+C`P+C(T-C(N,#`P,"`@26YT97)N970@
M17AP;&]R97(@-B!0=6)L:6,@4')E=FEE=R`H0F5T82D*("`@("`@("`@("`@
M("`@("`J(#8N,#`N,C0W.2XP,#`V("!);G1E<FYE="!%>'!L;W)E<B`V(%!U
M8FQI8R!0<F5V:65W("A"971A*0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!2969R97-H"B`@("`@("`@("`@("`@("`@*B`V+C`P+C(V
M,#`N,#`P,"`@26YT97)N970@17AP;&]R97(@-B`H5VEN9&]W<R!84"D*("`@
M("`@("`@("`@("`@("`J(#4N-3`N,S@R-2XQ,S`P("!);G1E<FYE="!%>'!L
M;W)E<B`U+C4@1&5V96QO<&5R(%!R979I97<@*$)E=&$I"B`@("`@("`@("`@
M("`@("`@*B`U+C4P+C0P,S`N,C0P,"`@26YT97)N970@17AP;&]R97(@-2XU
M("8@26YT97)N970@5&]O;',@0F5T80H@("`@("`@("`@("`@("`@("H@-2XU
M,"XT,3,T+C`Q,#`@($EN=&5R;F5T($5X<&QO<F5R(#4N-2!F;W(@5VEN9&]W
M<R!-92`H-"XY,"XS,#`P*0H@("`@("`@("`@("`@("`@("H@-2XU,"XT,3,T
M+C`V,#`@($EN=&5R;F5T($5X<&QO<F5R(#4N-0H@("`@("`@("`@("`@("`@
M("H@-2XU,"XT,S`X+C(Y,#`@($EN=&5R;F5T($5X<&QO<F5R(#4N-2!!9'9A
M;F-E9"!396-U<FET>2!0<FEV86-Y($)E=&$*("`@("`@("`@("`@("`@("`J
M"B`@("`@("`@("`@("`@("`@*B!3964Z"B`@("`@("`@("`@("`@("`@*B`]
M/3T]"B`@("`@("`@("`@("`@("`@*B!H='1P.B\O<W5P<&]R="YM:6-R;W-O
M9G0N8V]M+VMB+S$V-#4S.3L*("`@("`@("`@("`@("`@("`J(&AT='`Z+R]S
M=7!P;W)T+FUI8W)O<V]F="YC;VTO9&5F875L="YA<W!X/W-C:60]:V([96XM
M=7,[43,Q,C0Y-BD*("`@("`@("`@("`@("`@("`J(&AT='`Z+R]S=7!P;W)T
M+FUI8W)O<V]F="YC;VTO9&5F875L="YA<W!X/W-C:60]:V([96XM=7,[43,Q
M,S<Q,@H@("`@("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`@("`D:65?
M=F5R<R`]("1T:&ES+3YG971)159E<G-I;VXH*3L*("`@("`@("`@("`@("`@
M("1B=6=G>5]L:7-T(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)S8L
M,#`L,C0V,BPP,#`P)RP@)S8L,#`L,C0W.2PP,#`V)RP@)S8L,#`L,C8P,"PP
M,#`P)RP*("`@("`@("`@("`@("`@("`@("`G-2PU,"PS.#(U+#$S,#`G+"`G
M-2PU,"PT,#,P+#(T,#`G+"`G-2PU,"PT,3,T+#`Q,#`G+`H@("`@("`@("`@
M("`@("`@("`@("<U+#4P+#0Q,S0L,#8P,"<L("<U+#4P+#0S,#@L,CDP,"<*
M("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("!I9B`H(6ES7VYU
M;&PH)&EE7W9E<G,I("8F(&EN7V%R<F%Y*"1I95]V97)S+"`D8G5G9WE?;&ES
M="DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V)U
M9V=Y7V-O;7!R97-S:6]N)RD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@+RH@4V]M92!(86YD:&5L9',@:&%V92!T:&5I<B!S8W)E96X@
M<F5S;VQU=&EO;B!I;B!T:&4*("`@("`@("`@("`@("`@("`J('5S97(@86=E
M;G0@<W1R:6YG+"!W:&EC:"!W92!C86X@=7-E('1O(&QO;VL@9F]R"B`@("`@
M("`@("`@("`@("`@*B!M;V)I;&4@86=E;G1S+B`J+PH@("`@("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R\[("@Q,C!X,38P?#(T,'@R.#!\,C0P>#,R
M,'PS,C!X,S(P*5PI+R<L("1T:&ES+3Y?86=E;G0I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/E]M86IO<E9E
M<G-I;VXI('L*("`@("`@("`@("`@("`@(&-A<V4@-SH*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(#$N-"D[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V1O;2<I
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I9G)A
M;65S)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)W5T9B<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E
M*"=R=&4G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G:&]M97!A9V4G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G86-C97-S:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)V]P=&=R;W5P)RD["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)WAM;&AT='!R97$G*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)W-C<F]L;&)A<E]I;E]W87DG
M*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E(#8Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)VIA=F%S8W)I<'0G+"`Q+C0I.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=D;VTG*3L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T1F5A='5R92@G:69R86UE<R<I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=U=&8G*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G<G1E)RD["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAO;65P86=E)RD["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U
M<"<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=X
M;6QH='1P<F5Q)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U
M:7)K*"=S8W)O;&QB87)?:6Y?=V%Y)RD["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=%%U:7)K*"=B<F]K96Y?;75L=&EP87)T7V9O<FTG*3L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)W=I;F1O=V5D7V-O
M;G1R;VQS)RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`U.@H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^9V5T4&QA=&9O<FTH*2`]/2`G;6%C)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(#$N,BD[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=O
M<'1G<F]U<"<I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("\O($U3244@-2!F;W(@5VEN9&]W<RX*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S
M8W)I<'0G+"`Q+C0I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=X;6QH='1P<F5Q)RD["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^7VUI;F]R5F5R<VEO;B`^/2`U*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M<G1E)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M475I<FLH)W=I;F1O=V5D7V-O;G1R;VQS)RD["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEF<F%M97,G*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=71F)RD["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAO;65P86=E)RD["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V%C8V5S<VME
M>2<I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VUI;F]R5F5R
M<VEO;B`]/2`U*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M9711=6ER:R@G8G)E86M?9&ES<&]S:71I;VY?:&5A9&5R)RD["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G8G)O:V5N7VUU;'1I
M<&%R=%]F;W)M)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@-#H*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP
M="<L(#$N,BD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)V%C8V5S<VME>2<I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^7VUI;F]R5F5R<VEO;B`^(#`I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M("`@("!C87-E(#,Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)VIA=F%S8W)I<'0G+"`Q+C$I.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS9711=6ER:R@G879O:61?<&]P=7!?=VEN9&]W<R<I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?$%.5$9R97-C;R\H6S`M
M.5TK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=F<F5S8V\G*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XQ*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G879O:61?<&]P=7!?
M=VEN9&]W<R<I.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T:&ES
M+3Y?;&]W97)!9V5N="P@)V%V86YT9V\G*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=A=F%N=&=O)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@
M('T@96QS96EF("AP<F5G7VUA=&-H*"=\2V]N<75E<F]R+RA;,"TY72LI?"<L
M("1T:&ES+3Y?86=E;G0L("1V97)S:6]N*2!\?`H@("`@("`@("`@("`@("`@
M("`@("`@<')E9U]M871C:"@G?%-A9F%R:2\H6S`M.5TK*5PN/RA;,"TY72LI
M/WPG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI('L*("`@("`@("`@("`@
M("`@("\O($MO;G%U97)O<B!A;F0@07!P;&4G<R!3869A<FD@8F]T:"!U<V4@
M=&AE($M(5$U,"B`@("`@("`@("`@("`@("`O+R!R96YD97)I;F<@96YG:6YE
M+@H@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VMO;G%U97)O
M<B<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=E;7!T>5]F
M:6QE7VEN<'5T7W9A;'5E)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M475I<FLH)VYO7VAI9&1E;E]O=F5R9FQO=U]T86)L97,G*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;6%J;W)697)S:6]N(#T@)'9E<G-I;VY;,5T["B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'9E<G-I;VY;,ETI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]M:6YO<E9E<G-I;VX@/2`D=F5R<VEO
M;ELR73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H
M<W1R<&]S*"1T:&ES+3Y?86=E;G0L("=3869A<FDG*2`A/3T@9F%L<V4@)B8*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUA:F]R5F5R<VEO;B`^/2`V
M,"D@>PH@("`@("`@("`@("`@("`@("`@("\O(%-A9F%R:2X*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=71F)RD["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q
M+C0I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=D
M;VTG*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M:69R86UE<R<I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VUA
M:F]R5F5R<VEO;B`^(#$R-2!\?`H@("`@("`@("`@("`@("`@("`@("`@("`H
M)'1H:7,M/E]M86IO<E9E<G-I;VX@/3T@,3(U("8F"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUI;F]R5F5R<VEO;B`^/2`Q*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G86-C97-S
M:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=X;6QH='1P<F5Q)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!+
M;VYQ=65R;W(N"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)VIA=F%S8W)I<'0G+"`Q+C$I.PH@("`@("`@("`@("`@("`@("`@('-W
M:71C:"`H)'1H:7,M/E]M86IO<E9E<G-I;VXI('L*("`@("`@("`@("`@("`@
M("`@("!C87-E(#,Z"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=D;VTG*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)VEF<F%M97,G*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?$UO
M>FEL;&$O*%LP+3DN72LI?"<L("1T:&ES+3Y?86=E;G0L("1V97)S:6]N*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VUO>FEL;&$G
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G;75S=%]C86-H
M95]F;W)M<R<I.PH*("`@("`@("`@("`@("`@(&QI<W0H)'1H:7,M/E]M86IO
M<E9E<G-I;VXL("1T:&ES+3Y?;6EN;W)697)S:6]N*2`](&5X<&QO9&4H)RXG
M+"`D=F5R<VEO;ELQ72D["B`@("`@("`@("`@("`@("!S=VET8V@@*"1T:&ES
M+3Y?;6%J;W)697)S:6]N*2!["B`@("`@("`@("`@("`@("!C87-E(#4Z"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YG9710;&%T9F]R;2@I(#T]
M("=W:6XG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS9711
M=6ER:R@G8G)E86M?9&ES<&]S:71I;VY?9FEL96YA;64G*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)VIA=F%S8W)I<'0G+"`Q+C0I.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=D;VTG*3L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G86-C97-S:V5Y)RD["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V]P=&=R;W5P)RD["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)WAM;&AT='!R97$G
M*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G8VET
M92<I.PH@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\<G8Z
M*"XJ*5PI?"<L("1T:&ES+3Y?86=E;G0L("1R979I<VEO;BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1R979I<VEO;ELQ72`^/2`Q*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M:69R86UE<R<I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D<F5V:7-I;VY;,5T@/CT@,2XS*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M<G1E)RD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`T.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XS*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T475I<FLH)V)U9V=Y7V-O;7!R97-S:6]N)RD["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`S.@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(#$I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G8G5G9WE?8V]M<')E
M<W-I;VXG*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ,
M>6YX+RA;,"TY72LI?"<L("1T:&ES+3Y?86=E;G0L("1V97)S:6]N*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VQY;G@G*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I;6%G97,G+"!F86QS
M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G9G)A;65S
M)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)VIA=F%S8W)I<'0G+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T475I<FLH)V%V;VED7W!O<'5P7W=I;F1O=W,G*3L*("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ,:6YK<R!<*"A;,"TY72LI?"<L("1T
M:&ES+3Y?86=E;G0L("1V97)S:6]N*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$)R;W=S97(H)VQI;FMS)RD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G:6UA9V5S)RP@9F%L<V4I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)V9R86UE<R<L(&9A;'-E*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L
M<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=A=F]I9%]P
M;W!U<%]W:6YD;W=S)RD["B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA
M=&-H*"=\2&]T2F%V82\H6S`M.5TK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R
M<VEO;BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=H
M;W1J879A)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@("`@("`@?2!E;'-E:68@*'-T
M<G!O<R@D=&AI<RT^7V%G96YT+"`G55`O)RD@(3T](&9A;'-E('Q\"B`@("`@
M("`@("`@("`@("`@("`@("!S=')P;W,H)'1H:7,M/E]A9V5N="P@)U50+D(G
M*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("`@('-T<G!O<R@D
M=&AI<RT^7V%G96YT+"`G55`N3"<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)W5P)RD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G:'1M;"<L(&9A;'-E*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAD;6PG*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=W;6PG*3L*"B`@
M("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1T:&ES+3Y?86=E;G0L("='54DG
M*2`A/3T@9F%L<V4@)B8*("`@("`@("`@("`@("`@("`@("!S=')P;W,H)'1H
M:7,M/E]A9V5N="P@)U50+DQI;FLG*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("`@("`O*B!4:&4@9&5V:6-E(&%C8V5P=',@3W!E;G=A=F4@1U5)
M(&5X=&5N<VEO;G,@9F]R"B`@("`@("`@("`@("`@("`@("`@("H@5TU,(#$N
M,RX@3F]N+550+DQI;FL@9V%T97=A>7,@<V]M971I;65S(&AA=F4*("`@("`@
M("`@("`@("`@("`@("`@*B!P<F]B;&5M<RP@<V\@97AC;'5D92!T:&5M+B`J
M+PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G;W=?9W5I
M7S$N,R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R
M<&]S*"1T:&ES+3Y?86=E;G0L("=8:6EN;R\G*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=X:6EN;R<I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAD;6PG*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=W;6PG*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E
M;'-E:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G4&%L;7-C87!E+R<I("$]
M/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H
M)W!A;&US8V%P92<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)VIA=F%S8W)I<'0G+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G:&1M;"<I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$9E871U<F4H)W=M;"<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M
M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T
M:&ES+3Y?86=E;G0L("=.;VMI82<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VYO:VEA)RD["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G:'1M;"<L(&9A;'-E*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=W;6PG*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=X:'1M;"<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L
M<V5I9B`H<W1R<&]S*"1T:&ES+3Y?86=E;G0L("=%<FEC<W-O;B<I("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)V5R
M:6-S<V]N)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M:'1M;"<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=W;6PG*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@
M=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7VQO
M=V5R06=E;G0L("=W87`G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YS971"<F]W<V5R*"=W87`G*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=H=&UL)RP@9F%L<V4I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"!F86QS92D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:&1M;"<I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W=M;"<I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)V1O8V]M;R<I
M("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@("`@("`@<W1R<&]S*"1T
M:&ES+3Y?;&]W97)!9V5N="P@)W!O<G1A;&UM;2<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VEM;V1E)RD["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:6UA9V5S)RP@9F%L
M<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@
M("`@("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)T)L86-K
M0F5R<GDG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M971"<F]W<V5R*"=B;&%C:V)E<G)Y)RD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G:'1M;"<L(&9A;'-E*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAD;6PG*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=W;6PG*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E
M;'-E:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G34]4+2<I("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VUO=&]R
M;VQA)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:'1M
M;"<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E
M*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$9E871U<F4H)VAD;6PG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=W;6PG*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B
M:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI
M<RT^7VQO=V5R06=E;G0L("=J+2<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VUM;"<I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%T8V@@=&AE('!L871F;W)M
M(&]F('1H92!B<F]W<V5R+@H@("`@("H*("`@("`J(%1H:7,@:7,@82!P<F5T
M='D@<VEM<&QI<W1I8R!I;7!L96UE;G1A=&EO;BP@8G5T(&ET)W,@:6YT96YD
M960*("`@("`J('1O(&QE="!U<R!T96QL('=H870@;&EN92!B<F5A:W,@=&\@
M<V5N9"P@<V\@:70G<R!G;V]D(&5N;W5G:`H@("`@("H@9F]R(&ET<R!P=7)P
M;W-E+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`R+C(*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-E=%!L871F;W)M*"D*("`@('L*("`@("`@("!I9B`H
M<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)W=I;F0G*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@)'1H:7,M/E]P;&%T9F]R;2`]("=W:6XG.PH@("`@
M("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT+"`G;6%C
M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&QA=&9O<FT@
M/2`G;6%C)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7W!L871F;W)M(#T@)W5N:7@G.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@8W5R<F5N=&QY(&UA=&-H960@<&QA=&9O<FTN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U<V5R)W,@<&QA
M=&9O<FTN"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#(N,@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9710;&%T9F]R;2@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&QA=&9O<FT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S('1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8G)O=W-E<B`@5&AE(&)R;W=S97(@=&\@<V5T(&%S(&-U<G)E
M;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$)R;W=S97(H)&)R;W=S97(I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]B<F]W<V5R(#T@)&)R;W=S97(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@:68@=&AE(&=I=F5N(&)R
M;W=S97(@:7,@=&AE('-A;64@87,@=&AE(&-U<G)E;G0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8G)O=W-E<B`@5&AE(&)R;W=S97(@=&\@8VAE
M8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!)<R!T:&4@9VEV
M96X@8G)O=W-E<B!T:&4@<V%M92!A<R!T:&4@8W5R<F5N=#\*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-"<F]W<V5R*"1B<F]W<V5R*0H@("`@>PH@("`@("`@
M(')E='5R;B`H)'1H:7,M/E]B<F]W<V5R(#T]/2`D8G)O=W-E<BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$;R!W92!C;VYS:61E<B!T:&4@8W5R<F5N="!B
M<F]W<V5R('1O(&)E(&$@;6]B:6QE(&1E=FEC93\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=V4@9&\L(&9A;'-E(&EF('=E(&1O
M;B=T+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<TUO8FEL92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;6]B:6QE.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5T97)M:6YE<R!I9B!T:&4@8G)O=W-E<B!I<R!A(')O8F]T(&]R
M(&YO="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M8G)O=W-E<B!I<R!A(&MN;W=N(')O8F]T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I<U)O8F]T*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)O
M8F]T<R!A<R`D<F]B;W0I('L*("`@("`@("`@("`@:68@*'-T<G!O<R@D=&AI
M<RT^7V%G96YT+"`D<F]B;W0I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE
M=F4@=&AE(&-U<G)E;G0@8G)O=W-E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&-U<G)E;G0@8G)O=W-E<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0G)O=W-E<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8G)O=W-E<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E('1H
M92!C=7)R96YT(&)R;W=S97(G<R!M86IO<B!V97)S:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE(&-U<G)E;G0@8G)O=W-E<B=S(&UA
M:F]R('9E<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UA:F]R*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M86IO<E9E<G-I;VX["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!T:&4@8W5R<F5N="!B<F]W
M<V5R)W,@;6EN;W(@=F5R<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(%1H92!C=7)R96YT(&)R;W=S97(G<R!M:6YO<B!V97)S:6]N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971-:6YO<B@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?;6EN;W)697)S:6]N.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F4@=&AE(&-U<G)E;G0@8G)O=W-E<B=S('9E<G-I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C=7)R96YT(&)R
M;W=S97(G<R!V97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971697)S
M:6]N*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M86IO<E9E<G-I
M;VX@+B`G+B<@+B`D=&AI<RT^7VUI;F]R5F5R<VEO;CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@9G5L;"!B<F]W<V5R(&%G96YT('-T<FEN
M9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&)R;W=S97(@
M86=E;G0@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!9V5N=%-T
M<FEN9R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?86=E;G0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3970@=6YI<75E(&)E:&%V:6]R(&9O<B!T
M:&4@8W5R<F5N="!B<F]W<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'%U:7)K("!4:&4@8F5H879I;W(@=&\@<V5T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=F%L=64@(%-P96-I86P@8F5H879I;W(@<&%R86UE=&5R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S9711=6ER:R@D<75I<FLL("1V86QU92`]
M('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]Q=6ER:W-;)'%U:7)K72`]
M("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K('5N:7%U92!B
M96AA=FEO<B!F;W(@=&AE(&-U<G)E;G0@8G)O=W-E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1Q=6ER:R`@5&AE(&)E:&%V:6]R('1O(&-H96-K
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@1&]E<R!T:&4@8G)O
M=W-E<B!H879E('1H92!B96AA=FEO<B!S970_"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AA<U%U:7)K*"1Q=6ER:RD*("`@('L*("`@("`@("!R971U<FX@(65M
M<'1Y*"1T:&ES+3Y?<75I<FMS6R1Q=6ER:UTI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F4@=6YI<75E(&)E:&%V:6]R(&9O<B!T:&4@8W5R<F5N
M="!B<F]W<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U:7)K
M("!4:&4@8F5H879I;W(@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!V86QU92!F;W(@=&AE(')E<75E<W1E9"!B96AA
M=FEO<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T475I<FLH)'%U:7)K*0H@
M("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W%U:7)K<ULD<75I
M<FM=*0H@("`@("`@("`@("`@("`_("1T:&ES+3Y?<75I<FMS6R1Q=6ER:UT*
M("`@("`@("`@("`@("`@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T(&-A<&%B:6QI=&EE<R!F;W(@=&AE(&-U<G)E;G0@8G)O=W-E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F96%T=7)E("!4:&4@8V%P86)I
M;&ET>2!T;R!S970N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@("!3
M<&5C:6%L(&-A<&%B:6QI='D@<&%R86UE=&5R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971&96%T=7)E*"1F96%T=7)E+"`D=F%L=64@/2!T<G5E*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9F5A='5R97-;)&9E871U<F5=(#T@)'9A;'5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@=&AE(&-U<G)E;G0@8G)O
M=W-E<B!C87!A8FEL:71I97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F5A='5R92`@5&AE(&-A<&%B:6QI='D@=&\@8VAE8VLN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!$;V5S('1H92!B<F]W<V5R(&AA=F4@
M=&AE(&-A<&%B:6QI='D@<V5T/PH@("`@("HO"B`@("!F=6YC=&EO;B!H87-&
M96%T=7)E*"1F96%T=7)E*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH
M)'1H:7,M/E]F96%T=7)E<ULD9F5A='5R95TI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F4@=&AE(&-U<G)E;G0@8G)O=W-E<B!C87!A8FEL:71Y
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9E871U<F4@(%1H92!C
M87!A8FEL:71Y('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=F%L=64@;V8@=&AE(')E<75E<W1E9"!C87!A8FEL:71Y
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&96%T=7)E*"1F96%T=7)E*0H@
M("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V9E871U<F5S6R1F
M96%T=7)E72D*("`@("`@("`@("`@("`@/R`D=&AI<RT^7V9E871U<F5S6R1F
M96%T=7)E70H@("`@("`@("`@("`@("`Z(&YU;&P["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$971E<FUI;F4@:68@=V4@87)E('5S:6YG(&$@<V5C=7)E("A3
M4TPI(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('5S:6YG(%-33"P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!U<VEN9U-33$-O;FYE8W1I;VXH*0H@("`@>PH@("`@("`@
M(')E='5R;B`H*&ES<V5T*"1?4T525D526R=(5%104R==*2`F)@H@("`@("`@
M("`@("`@("`@("@D7U-%4E9%4ELG2%144%,G72`]/2`G;VXG*2D@?'P*("`@
M("`@("`@("`@("`@(&=E=&5N=B@G4U-,7U!23U1/0T],7U9%4E-)3TXG*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S97)V97(@<')O
M=&]C;VP@:6X@=7-E(&]N('1H92!C=7)R96YT('-E<G9E<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A45%`@<V5R=F5R('!R;W1O8V]L
M('9E<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$A45%!0<F]T;V-O
M;"@I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=315)615)?
M4%)/5$]#3TPG72DI('L*("`@("`@("`@("`@:68@*"@D<&]S(#T@<W1R<G!O
M<R@D7U-%4E9%4ELG4T525D527U!23U1/0T],)UTL("<O)RDI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@<W5B<W1R*"1?4T525D526R=315)615)?4%)/
M5$]#3TPG72P@)'!O<R`K(#$I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN92!I9B!F:6QE<R!C86X@8F4@=7!L;V%D960@=&\@=&AE('-Y<W1E
M;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($EF('5P;&]A9',@
M86QL;W=E9"P@<F5T=7)N<R!T:&4@;6%X:6UU;2!S:7IE(&]F('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("!U<&QO860@:6X@8GET97,N("!2971U<FYS
M(#`@:68@=7!L;V%D<R!A<F4@;F]T"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&%L;&]W960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%L;&]W1FEL955P;&]A
M9',H*0H@("`@>PH@("`@("`@(&EF("AI;FE?9V5T*"=F:6QE7W5P;&]A9',G
M*2D@>PH@("`@("`@("`@("!I9B`H*"1D:7(@/2!I;FE?9V5T*"=U<&QO861?
M=&UP7V1I<B<I*2`F)@H@("`@("`@("`@("`@("`@(6ES7W=R:71A8FQE*"1D
M:7(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9FEL97-I>F4@/2!I;FE?9V5T*"=U<&QO861?;6%X
M7V9I;&5S:7IE)RD["B`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAS
M=6)S='(H)&9I;&5S:7IE+"`M,2P@,2DI*2!["B`@("`@("`@("`@(&-A<V4@
M)VLG.@H@("`@("`@("`@("`@("`@)&9I;&5S:7IE(#T@:6YT=F%L*&9L;V%T
M=F%L*"1F:6QE<VEZ92D@*B`Q,#(T*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@("`@("`D9FEL
M97-I>F4@/2!I;G1V86PH9FQO871V86PH)&9I;&5S:7IE*2`J(#$P,C0@*B`Q
M,#(T*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@("1F:6QE<VEZ92`](&EN='9A;"@D9FEL
M97-I>F4I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'!O<W1S:7IE(#T@:6YI7V=E="@G<&]S=%]M87A?<VEZ
M92<I.PH@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H<W5B<W1R*"1P
M;W-T<VEZ92P@+3$L(#$I*2D@>PH@("`@("`@("`@("!C87-E("=K)SH*("`@
M("`@("`@("`@("`@("1P;W-T<VEZ92`](&EN='9A;"AF;&]A='9A;"@D<&]S
M='-I>F4I("H@,3`R-"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("`@("`@)'!O<W1S:7IE(#T@
M:6YT=F%L*&9L;V%T=F%L*"1P;W-T<VEZ92D@*B`Q,#(T("H@,3`R-"D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`D<&]S='-I>F4@/2!I;G1V86PH)'!O<W1S:7IE*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B!M:6XH)&9I;&5S:7IE+"`D<&]S='-I>F4I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@=&AE(&9I;&4@=V%S
M('5P;&]A9&5D(&]R(&YO="X@($EF(&YO="P@=VEL;"!R971U<FX@=&AE"B`@
M("`@*B!A<'!R;W!R:6%T92!E<G)O<B!M97-S86=E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I96QD("!4:&4@;F%M92!O9B!T:&4@9FEE;&0@
M8V]N=&%I;FEN9R!T:&4@=7!L;V%D960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@(%1H
M92!F:6QE(&1E<V-R:7!T:6]N('-T<FEN9R!T;R!U<V4@:6X@=&AE(&5R<F]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;65S<V%G92X@($1E9F%U
M;'0Z("=F:6QE)RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('=A<T9I;&55<&QO861E9"@D9FEE;&0L("1N86UE(#T@;G5L
M;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B`@
M("`@("`@:68@*&ES7VYU;&PH)&YA;64I*2!["B`@("`@("`@("`@("1N86UE
M(#T@7R@B9FEL92(I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$H)'5P;&]A
M9%-I>F4@/2!"<F]W<V5R.CIA;&QO=T9I;&55<&QO861S*"DI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+B(I*3L*("`@("`@("!]"@H@("`@("`@("\J($=E
M="!A;GD@:6YD97@@;VX@=&AE(&9I96QD(&YA;64N("HO"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("1I;F1E>"`]
M($AO<F1E7T%R<F%Y.CIG971!<G)A>5!A<G1S*"1F:65L9"P@)&)A<V4L("1K
M97ES*3L*"B`@("`@("`@:68@*"1I;F1E>"D@>PH@("`@("`@("`@("`O*B!)
M;F1E>"!P<F5S96YT+"!F971C:"!T:&4@97)R;W(@=F%R('1O(&-H96-K+B`J
M+PH@("`@("`@("`@("`D:V5Y<U]P871H(#T@87)R87E?;65R9V4H87)R87DH
M)&)A<V4L("=E<G)O<B<I+"`D:V5Y<RD["B`@("`@("`@("`@("1E<G)O<B`]
M($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?1DE,15,L("1K97ES7W!A=&@I
M.PH*("`@("`@("`@("`@+RH@26YD97@@<')E<V5N="P@9F5T8V@@=&AE('1M
M<%]N86UE('9A<B!T;R!C:&5C:RX@*B\*("`@("`@("`@("`@)&ME>7-?<&%T
M:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B87-E+"`G=&UP7VYA;64G*2P@)&ME
M>7,I.PH@("`@("`@("`@("`D=&UP7VYA;64@/2!(;W)D95]!<G)A>3HZ9V5T
M16QE;65N="@D7T9)3$53+"`D:V5Y<U]P871H*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O*B!.;R!I;F1E>"P@<VEM<&QE('-E="!U<"!O9B!V
M87)S('1O(&-H96-K+B`J+PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1?1DE,
M15-;)&9I96QD72DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(DYO(&9I;&4@=7!L;V%D960B*2P@55!,3T%$7T524E].
M3U]&24Q%*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D97)R;W(@/2`D
M7T9)3$536R1F:65L9%U;)V5R<F]R)UT["B`@("`@("`@("`@("1T;7!?;F%M
M92`]("1?1DE,15-;)&9I96QD75LG=&UP7VYA;64G73L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A:7-S970H)%]&24Q%4RD@?'P@*"1E<G)O<B`]/2!54$Q/
M041?15)27TY/7T9)3$4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(I+"`D;F%M
M92DL(%503$]!1%]%4E)?3D]?1DE,12D["B`@("`@("`@?2!E;'-E:68@*"@D
M97)R;W(@/3T@55!,3T%$7T524E]/2RD@)B8@:7-?=7!L;V%D961?9FEL92@D
M=&UP7VYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS96EF("@H)&5R<F]R(#T](%503$]!1%]%4E)?24Y)7U-)6D4I('Q\
M"B`@("`@("`@("`@("`@("`@("@D97)R;W(@/3T@55!,3T%$7T524E]&3U)-
M7U-)6D4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A
M;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB*2P@)&YA;64L("1U<&QO8613:7IE
M*2P@)&5R<F]R*3L*("`@("`@("!](&5L<V5I9B`H)&5R<F]R(#T](%503$]!
M1%]%4E)?4$%25$E!3"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L
M;V%D960N(BDL("1N86UE*2P@)&5R<F]R*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!H96%D97)S(&9O<B!A(&)R;W=S
M97(@9&]W;FQO860N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL
M96YA;64@(%1H92!F:6QE;F%M92!O9B!T:&4@9&]W;FQO860N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C5'EP92`@("`@5&AE(&-O;G1E;G0M='EP92!D97-C
M<FEP=&EO;B!O9B!T:&4@9FEL92X*("`@("`J($!P87)A;2!B;V]L96%N("1I
M;FQI;F4@("!4<G5E(&EF(&EN;&EN92P@9F%L<V4@:68@871T86-H;65N="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-,96YG=&@@("!4:&4@8V]N=&5N="UL
M96YG=&@@;V8@=&AI<R!F:6QE+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D
M92`R+C(*("`@("`J+PH@("`@9G5N8W1I;VX@9&]W;FQO861(96%D97)S*"1F
M:6QE;F%M92`]("=U;FMN;W=N)RP@)&-4>7!E(#T@;G5L;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YL:6YE(#T@9F%L<V4L("1C3&5N9W1H
M(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!296UO=F4@;&EN96)R96%K<R!F
M<F]M(&9I;&4@;F%M97,N("HO"B`@("`@("`@)&9I;&5N86UE(#T@<W1R7W)E
M<&QA8V4H87)R87DH(EQR7&XB+"`B7'(B+"`B7&XB*2P@)R`G+"`D9FEL96YA
M;64I.PH*("`@("`@("`O*B!3;VUE(&)R;W=S97)S(&1O;B=T(&QI:V4@<W!A
M8V5S(&EN('1H92!F:6QE;F%M92X@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA
M<U%U:7)K*"=N;U]F:6QE;F%M95]S<&%C97,G*2D@>PH@("`@("`@("`@("`D
M9FEL96YA;64@/2!S=')T<B@D9FEL96YA;64L("<@)RP@)U\G*3L*("`@("`@
M("!]"@H@("`@("`@("\J($U3244@9&]E<VXG="!L:6ME(&UU;'1I<&QE('!E
M<FEO9',@:6X@=&AE(&9I;&4@;F%M92X@0V]N=F5R=`H@("`@("`@("`@(&%L
M;"!P97)I;V1S("AE>&-E<'0@=&AE(&QA<W0@;VYE*2!T;R!U;F1E<G-C;W)E
M<RX@*B\*("`@("`@("!I9B`H)'1H:7,M/FES0G)O=W-E<B@G;7-I92<I*2![
M"B`@("`@("`@("`@(&EF("@H)'!O<R`]('-T<G)P;W,H)&9I;&5N86UE+"`G
M+B<I*2D@>PH@("`@("`@("`@("`@("`@)&9I;&5N86UE(#T@<W1R='(H<W5B
M<W1R*"1F:6QE;F%M92P@,"P@)'!O<RDL("<N)RP@)U\G*2`N('-U8G-T<B@D
M9FEL96YA;64L("1P;W,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!#;VYT96YT+51Y<&4O0V]N=&5N="U$:7-P;W-I=&EO;B!(96%D
M97(N("HO"B`@("`@("`@:68@*"1I;FQI;F4I('L*("`@("`@("`@("`@:68@
M*"%I<U]N=6QL*"1C5'EP92DI('L*("`@("`@("`@("`@("`@(&AE861E<B@G
M0V]N=&5N="U4>7!E.B`G("X@=')I;2@D8U1Y<&4I*3L*("`@("`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3YI<T)R;W=S97(H)VUS:64G*2D@>PH@("`@("`@
M("`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z(&%P<&QI8V%T:6]N+W@M
M;7-D;W=N;&]A9"<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z(&%P<&QI8V%T:6]N+V]C=&5T
M+7-T<F5A;2<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&AE861E<B@G
M0V]N=&5N="U$:7-P;W-I=&EO;CH@:6YL:6YE.R!F:6QE;F%M93TB)R`N("1F
M:6QE;F%M92`N("<B)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YI<T)R;W=S97(H)VUS:64G*2D@>PH@("`@("`@("`@("`@
M("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z(&%P<&QI8V%T:6]N+W@M;7-D;W=N
M;&]A9"<I.PH@("`@("`@("`@("!](&5L<V5I9B`H(6ES7VYU;&PH)&-4>7!E
M*2D@>PH@("`@("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z("<@
M+B!T<FEM*"1C5'EP92DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z(&%P<&QI8V%T:6]N+V]C
M=&5T+7-T<F5A;2<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M)'1H:7,M/FAA<U%U:7)K*"=B<F5A:U]D:7-P;W-I=&EO;E]H96%D97(G*2D@
M>PH@("`@("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT+41I<W!O<VET:6]N
M.B!F:6QE;F%M93TB)R`N("1F:6QE;F%M92`N("<B)RD["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M1&ES
M<&]S:71I;VXZ(&%T=&%C:&UE;G0[(&9I;&5N86UE/2(G("X@)&9I;&5N86UE
M("X@)R(G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M0V]N=&5N="U,96YG=&@@2&5A9&5R+B`J+PH@("`@("`@(&EF("@A:7-?;G5L
M;"@D8TQE;F=T:"DI('L*("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT+4QE
M;F=T:#H@)R`N("1C3&5N9W1H*3L*("`@("`@("!]"@H@("`@("`@("\J($]V
M97)W<FET92!0<F%G;6$Z(&%N9"!O=&AE<B!C86-H:6YG(&AE861E<G,@9F]R
M($E%+B`J+PH@("`@("`@(&EF("@D=&AI<RT^:&%S475I<FLH)V-A8VAE7W-S
M;%]D;W=N;&]A9',G*2D@>PH@("`@("`@("`@("!H96%D97(H)T5X<&ER97,Z
M(#`G*3L*("`@("`@("`@("`@:&5A9&5R*"=#86-H92U#;VYT<F]L.B!M=7-T
M+7)E=F%L:61A=&4L('!O<W0M8VAE8VL],"P@<')E+6-H96-K/3`G*3L*("`@
M("`@("`@("`@:&5A9&5R*"=0<F%G;6$Z('!U8FQI8R<I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@82!B<F]W<V5R
M(&-A;B!D:7-P;&%Y(&$@9VEV96X@34E-12!T>7!E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&UI;65T>7!E("!4:&4@34E-12!T>7!E('1O(&-H
M96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T
M:&4@8G)O=W-E<B!C86X@9&ES<&QA>2!T:&4@34E-12!T>7!E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<U9I97=A8FQE*"1M:6UE='EP92D*("`@('L*("`@
M("`@("`D;6EM971Y<&4@/2!3=')I;F<Z.FQO=V5R*"1M:6UE='EP92D["B`@
M("`@("`@;&ES="@D='EP92P@)'-U8G1Y<&4I(#T@97AP;&]D92@G+R<L("1M
M:6UE='EP92D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]A8V-E<'0I
M*2!["B`@("`@("`@("`@("1W:6QD8V%R9%]M871C:"`](&9A;'-E.PH*("`@
M("`@("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7V%C8V5P="P@)&UI;65T>7!E
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<W1R<&]S*"1T:&ES+3Y?
M86-C97!T+"`G*B\J)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D
M=VEL9&-A<F1?;6%T8V@@/2!T<G5E.PH@("`@("`@("`@("`@("`@:68@*"1T
M>7!E("$]("=I;6%G92<I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@:6UA9V4O:G!E9R!A;F0@:6UA9V4O<&IP96<@*F%P<&5A<BH@
M=&\@8F4@=&AE('-A;64*("`@("`@("`@("`@("H@96YT:71Y+"!B=70@36]Z
M:6QL82!D;V5S;B=T('-E96T@=&\@=V%N="!T;R!A8V-E<'0@=&AE"B`@("`@
M("`@("`@("`J(&QA='1E<BX@($9O<B!O=7(@<'5R<&]S97,L('=E('=I;&P@
M=')E870@=&AE;2!T:&4*("`@("`@("`@("`@("H@<V%M92X@*B\*("`@("`@
M("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)VUO>FEL;&$G*2`F)@H@("`@
M("`@("`@("`@("`@*"1M:6UE='EP92`]/2`G:6UA9V4O<&IP96<G*2`F)@H@
M("`@("`@("`@("`@("`@*'-T<G!O<R@D=&AI<RT^7V%C8V5P="P@)VEM86=E
M+VIP96<G*2`A/3T@9F%L<V4I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"$D=VEL9&-A
M<F1?;6%T8V@I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^:&%S
M1F5A='5R92@G:6UA9V5S)RD@?'P@*"1T>7!E("$]("=I;6%G92<I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!I;E]A<G)A>2@D<W5B='EP92P@)'1H:7,M/E]I;6%G97,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@17-C87!E(&-H87)A8W1E<G,@:6X@:F%V87-C
M<FEP="!C;V1E(&EF('1H92!B<F]W<V5R(')E<75I<F5S(&ET+@H@("`@("H@
M)3(S+"`E,C8L(&%N9"`E,D(@*&9O<B!)12D@86YD("4R-R!N965D('1O(&)E
M(&5S8V%P960@;W(@96QS90H@("`@("H@:G-C<FEP="!W:6QL(&EN=&5R<')E
M="!I="!A<R!A('-I;F=L92!Q=6]T92P@<&]U;F0@<VEG;BP@;W(*("`@("`J
M(&%M<&5R<V%N9"!A;F0@<F5F=7-E('1O('=O<FLN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V]D92`@5&AE($I3(&-O9&4@=&\@97-C87!E+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@97-C87!E9"!C;V1E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&5*4T-O9&4H)&-O9&4I"B`@
M("!["B`@("`@("`@)&9R;VT@/2`D=&\@/2!A<G)A>2@I.PH*("`@("`@("!I
M9B`H)'1H:7,M/FES0G)O=W-E<B@G;7-I92<I('Q\"B`@("`@("`@("`@("@D
M=&AI<RT^:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8@*"1T:&ES+3YG971-86IO
M<B@I(#X](#4I*2D@>PH@("`@("`@("`@("`D9G)O;2`](&%R<F%Y*"<E,C,G
M+"`G)3(V)RP@)R4R0B<I.PH@("`@("`@("`@("`D=&\@/2!A<G)A>2AU<FQE
M;F-O9&4H)R4R,R<I+"!U<FQE;F-O9&4H)R4R-B<I+"!U<FQE;F-O9&4H)R4R
M0B<I*3L*("`@("`@("!]"B`@("`@("`@)&9R;VU;72`]("<E,C<G.PH@("`@
M("`@("1T;UM=(#T@)UPE,C<G.PH*("`@("`@("!R971U<FX@<W1R7W)E<&QA
M8V4H)&9R;VTL("1T;RP@)&-O9&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!)12!V97)S:6]N(&EN('1H92!S97-S:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'9E<B`@5&AE($E%(%9E<G-I;VX@<W1R:6YG
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971)159E<G-I;VXH)'9E<BD*("`@
M('L*("`@("`@("`D7U-%4U-)3TY;)U]?8G)O=W-E<B==(#T@87)R87DH"B`@
M("`@("`@("`@("=I95]V97)S:6]N)R`]/B`D=F5R"B`@("`@("`@*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@244@=F5R<VEO;B!S=&]R
M960@:6X@=&AE('-E<W-I;VXL(&EF(&%V86EL86)L92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@244@5F5R<VEO;B!S=')I;F<@;W(@;G5L
M;"!I9B!N;R!S=')I;F<@:7,@<W1O<F5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971)159E<G-I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D
M7U-%4U-)3TY;)U]?8G)O=W-E<B==6R=I95]V97)S:6]N)UTI(#\@)%]315-3
M24].6R=?7V)R;W=S97(G75LG:65?=F5R<VEO;B==(#H@;G5L;#L*("`@('T*
M"B`@("`O*BH*("`@("`J($5X<&QI8VET(&1I<V%B;&EN9R!O9B!J879A<V-R
M:7!T+@H@("`@("H@5&AI<R!W:6QL(&]V97)R:61E(&%N>2!A=71O;6%T:6,@
M9&5T96-T:6]N(&]F(&%V86EL86)L92!J879A<V-R:7!T"B`@("`@*B!S=7!P
M;W)T(&EN('1H92!U<V5R)W,@8G)O=W-E<BX@5&AI<R!F=6YC=&EO;B!I<R!C
M86QL960@87,@<&%R="!O9B!T:&4*("`@("`J('-E<W-I;VX@8V%L;&)A8VMS
M+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&ES86)L94IA=F%S8W)I<'0H*0H@("`@>PH@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=D;VTG+"!F86QS92D["B`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)W)T92<L(&9A;'-E*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#86-H92YP:'``
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30P,3$`
M,3`T,3<S-C(W-S,`,#$W-S0S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V%C:&4Z
M.B!C;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C=&5D(&EN=&5R9F%C
M92!I;G1O"B`J('1H92!V87)I;W5S(&-A8VAI;F<@8F%C:V5N9',N("!)="!A
M;'-O('!R;W9I9&5S(&9U;F-T:6]N<R!F;W(*("H@8VAE8VMI;F<@:6XL(')E
M=')I979I;F<L(&%N9"!F;'5S:&EN9R!A(&-A8VAE+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]#86-H92]#86-H92YP:'`L=B`Q+C,Q+C$P+C$Q(#(P,#8O
M,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D
M:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?0V%C:&4*("HO"F-L87-S($AO<F1E
M7T-A8VAE('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C="!A(&YE=R!(;W)D
M95]#86-H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@(%!A<F%M971E<B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?0V%C:&4H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M+RH@3VYL>2!D;R!G87)B86=E(&-O;&QE8W1I;VX@:68@87-K960@9F]R+"!A
M;F0@=&AE;B!O;FQY(#$E(&]F('1H90H@("`@("`@("`J('1I;64@=V4@8W)E
M871E(&%N(&]B:F5C="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;
M)V=C)UTI("8F"B`@("`@("`@("`@("AR86YD*#`L(#DY*2`]/2`P*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V1O1T,H)'!A<F%M<ULG9V,G72D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T<FEE
M=F4@82!C86-H960@;V)J96-T(&%N9"!R971U<FX@:70@=&\@=&AE"B`@("`@
M*B!C86QL97(N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!/8FIE8W0@240@=&\@<75E
M<GDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE
M(&]F('1H92!O8FIE8W0@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@:68@;F]N92!W87,@
M9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D:V5Y+"`D;&EF971I
M;64@/2`Q*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O('-T;W)E(&%N(&]B:F5C="!I;B!T
M:&4@8V%C:&4N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@3V)J96-T($E$('5S960@87,@=&AE
M(&-A8VAI;F<@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D("`D9&%T82`@1&%T
M82!T;R!S=&]R92!I;B!T:&4@8V%C:&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D:V5Y+"`D9&%T82D*("`@('L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(&1I<F5C=&QY(&]U='!U="!A(&-A8VAE9"!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&ME>2`@("`@("!/8FIE8W0@240@=&\@<75E<GDN"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H92!O8FIE
M8W0@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!#
M86-H960@9&%T82P@;W(@9F%L<V4@:68@;F]N92!W87,@9F]U;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&]U='!U="@D:V5Y+"`D;&EF971I;64@/2`Q*0H@
M("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H96-K<R!I9B!A(&=I=F5N(&ME>2!E>&ES=',@:6X@=&AE(&-A8VAE
M+"!V86QI9"!F;W(@=&AE(&=I=F5N"B`@("`@*B!L:69E=&EM92X*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D:V5Y("`@("`@($-A8VAE(&ME>2!T;R!C:&5C:RX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1L:69E=&EM92`@3&EF971I;64@;V8@=&AE(&ME>2!I;B!S
M96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@17AI<W1A
M;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)&ME>2P@)&QI9F5T
M:6UE(#T@,2D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!%>'!I<F4@86YY(&5X:7-T:6YG(&1A=&$@9F]R('1H
M92!G:79E;B!K97DN"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!#86-H92!K97D@=&\@97AP:7)E
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4W5C8V5S<R!O<B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!I<F4H)&ME>2D*("`@
M('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($1O(&%N>2!G87)B86=E(&-O;&QE8W1I;VX@;F5E9&5D(&9O<B!T:&4@9')I
M=F5R+@H@("`@("H*("`@("`J($!P<FEV871E"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-E8W,@(%1H
M92!M:6YI;75M(&%M;W5N="!O9B!T:6UE("AI;B!S96-O;F1S*2!R97%U:7)E
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&)E9F]R92!A(&-A8VAE
M(&ET96T@:7,@<F5M;W9E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1O1T,H
M)'-E8W,I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]#86-H92!I;G-T86YC92!B87-E
M9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I
M=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]#86-H92!S=6)C;&%S
M<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@
M)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]#86-H
M92\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N
M>2!A9&1I=&EO;F%L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N
M9FEG=7)A=&EO;B!O<B!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UI9VAT(&YE960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!(;W)D95]#86-H92`@5&AE(&YE=VQY(&-R
M96%T960@8V]N8W)E=&4@2&]R9&5?0V%C:&4@:6YS=&%N8V4L(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!F86QS92!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2![
M"B`@("`@("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D
M9')I=F5R(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@("`@("`@("1D<FEV
M97(@/2!B87-E;F%M92@D9')I=F5R*3L*("`@("`@("!I9B`H96UP='DH)&1R
M:79E<BD@?'P@)&1R:79E<B`]/2`G;F]N92<I('L*("`@("`@("`@("`@)&-A
M8VAE(#T@)FYE=R!(;W)D95]#86-H92@D<&%R86US*3L*("`@("`@("`@("`@
M<F5T=7)N("1C86-H93L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH
M)&%P<"DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E("1A<'`@+B`G+VQI
M8B]#86-H92\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I
M9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]#86-H92\G
M("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@:6YC;'5D95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]#86-H92\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D
M95]O;F-E("=(;W)D92]#86-H92\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]#86-H95\G("X@)&1R
M:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@
M("`@("`@("`@)&-A8VAE(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A8VAE(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@
M9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE.PH@
M("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F
M97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?0V%C:&4*("`@("`J(&EN<W1A
M;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N
M97<@:6YS=&%N8V4*("`@("`J(&EF(&YO($AO<F1E7T-A8VAE(&EN<W1A;F-E
M('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D*("`@("`J(&5X
M:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU
M;'1I<&QE(&-A8VAE(&)A8VME;F1S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT
M:7!L92!(;W)D95]#86-H92!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@
M("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z"B`@
M("`@*B`D=F%R(#T@)DAO<F1E7T-A8VAE.CIS:6YG;&5T;VXH*0H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC
M<F5T92!(;W)D95]#86-H92!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@
M=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!I;B`D9')I=F5R6S!=+VQI8B]#86-H92\@9F]R('1H92!S=6)C;&%S<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA
M;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R
M871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T
M:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@2&]R9&5?0V%C:&4@(%1H92!C;VYC<F5T92!(;W)D
M95]#86-H92!R969E<F5N8V4L(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D["@H@("`@("`@("1S
M:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI
M.PH@("`@("`@(&EF("AE;7!T>2@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@
M>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E
M7T-A8VAE.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O0VEP:&5R+G!H<```````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`V,#0T`#$P-#$W,S8R-S<S`#`R,#$V,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($AO<F1E7T-I<&AE<CHZ(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N(&%B<W1R
M86-T960@:6YT97)F86-E('1O"B`J('9A<FEO=7,@0VEP:&5R<R!F;W(@96YC
M<GEP=&EO;B!O9B!A<F)I=')A<GD@;&5N9W1H('!I96-E<R!O9B!D871A+@H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+G!H<"QV(#$N,38N,3(N."`R,#`V
M+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@
M("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S
M<R!(;W)D95]#:7!H97(@>PH*("`@("\J*@H@("`@("H@5&AE(&)L;V-K(&UO
M9&4@9F]R('1H92!C:7!H97(@8VAA:6YI;F<*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]B;&]C:TUO9&4@/2`G0T)#)SL*
M"B`@("`O*BH*("`@("`J(%1H92!I;FET:6%L:7IA=&EO;B!V96-T;W(*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I=B`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&)L;V-K(&UO9&4@9F]R
M(&-I<&AE<B!C:&%I;FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1B;&]C:TUO9&4@(%1H92!N97<@8FQO8VMM;V1E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971";&]C:TUO9&4H)&)L;V-K36]D92D*("`@('L*("`@("`@
M("`D=&AI<RT^7V)L;V-K36]D92`]("1B;&]C:TUO9&4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3970@=&AE($E6+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&EV("!4:&4@;F5W($E6+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971)5B@D:78I"B`@("!["B`@("`@("`@)'1H:7,M/E]I=B`]("1I=CL*("`@
M('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&QA:6YT97AT("!4:&4@9&%T82!T;R!E
M;F-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC
M<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)'!L
M86EN=&5X="D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+T-I<&AE<B]";&]C:TUO9&4N<&AP)SL*("`@("`@("`D
M8FQO8VM-;V1E(#T@)DAO<F1E7T-I<&AE<E]";&]C:TUO9&4Z.F9A8W1O<GDH
M)'1H:7,M/E]B;&]C:TUO9&4I.PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI
M<RT^7VEV*2D@>PH@("`@("`@("`@("`D8FQO8VM-;V1E+3YS971)5B@D=&AI
M<RT^7VEV*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8FQO8VM-;V1E
M+3YE;F-R>7!T*"1T:&ES+"`D<&QA:6YT97AT*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VEP:&5R=&5X="`@5&AE(&1A=&$@=&\@9&5C<GEP="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T*"1C:7!H97)T97AT*0H@
M("`@>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O0VEP:&5R+T)L;V-K36]D92YP:'`G.PH@("`@("`@("1B;&]C:TUO9&4@
M/2`F2&]R9&5?0VEP:&5R7T)L;V-K36]D93HZ9F%C=&]R>2@D=&AI<RT^7V)L
M;V-K36]D92D["B`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?:78I*2![
M"B`@("`@("`@("`@("1B;&]C:TUO9&4M/G-E=$E6*"1T:&ES+3Y?:78I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1B;&]C:TUO9&4M/F1E8W)Y<'0H
M)'1H:7,L("1C:7!H97)T97AT*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7T-I<&AE<B!I;G-T
M86YC92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:7!H97(@(%1H
M92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T-I<&AE<B!S=6)C;&%S<R!T;PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A
M9&1I=&EO;F%L('!A<F%M971E<G,@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R
M971U<FX@2&]R9&5?0VEP:&5R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T
M92!(;W)D95]#:7!H97(@:6YS=&%N8V4L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@;W(@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F9A8W1O<GDH)&-I<&AE<BP@)'!A<F%M<R`](&YU;&PI"B`@
M("!["B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1C:7!H97(I.PH*("`@
M("`@("!I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]#
M:7!H97(O)R`N("1C:7!H97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O0VEP:&5R+R<@+B`D
M8VEP:&5R("X@)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S(#T@
M)TAO<F1E7T-I<&AE<E\G("X@)&-I<&AE<CL*("`@("`@("!I9B`H8VQA<W-?
M97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&-I<&AE<B`]("9N97<@
M)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1C:7!H97(@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N
M(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D8VEP:&5R.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T-O;7!R97-S+G!H<```````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-S4R-P`Q,#0Q-S,V,C<W,P`P,C`U-3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!(;W)D95]#;VUP<F5S<SHZ(&-L87-S('!R;W9I9&5S(&%N($%022!F;W(@
M=F%R:6]U<R!C;VUP<F5S<VEO;@H@*B!T96-H;FEQ=65S('1H870@8V%N(&)E
M('5S960@8GD@2&]R9&4@87!P;&EC871I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<RYP:'`L=B`Q+C<N,3(N,3`@,C`P
M-B\P,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#;VUP<F5S<PH@
M*B\*8VQA<W,@2&]R9&5?0V]M<')E<W,@>PH*("`@("\J*@H@("`@("H@071T
M96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R9&5?0V]M<')E<W,@:6YS
M=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?0V]M
M<')E<W,@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL
M;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E
M<ELP72]L:6(O0V]M<')E<W,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I
M=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA
M<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!A('-U
M8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D
M95]#;VUP<F5S<R`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?
M0V]M<')E<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1A
M;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@
M(&QI<W0H)&%P<"P@)&1R:79E<BD@/2`D9')I=F5R.PH@("`@("`@('T*"B`@
M("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH*("`@("`@("!I
M9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D
M87!P("X@)R]L:6(O0V]M<')E<W,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?
M*2`N("<O0V]M<')E<W,O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O0V]M
M<')E<W,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O0V]M<')E<W,O)R`N
M("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@
M/2`G2&]R9&5?0V]M<')E<W-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1C;VUP<F5S<R`]
M("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1C;VUP<F5S<R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1C;VUP<F5S<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M
M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E
M7T-O;7!R97-S(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9')I=F5R+B!)
M="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO"B`@("`@
M*B!(;W)D95]#;VUP<F5S<R!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M
M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z"B`@("`@*B`@("1V87(@/2`F2&]R
M9&5?0V]M<')E<W,Z.G-I;F=L971O;B@I.PH@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D9')I=F5R("!3964@2&]R9&5?0V]M<')E<W,Z.F9A8W1O<GDH
M*2X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!3964@2&]R9&5?0V]M
M<')E<W,Z.F9A8W1O<GDH*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E
M7T-O;7!R97-S("!4:&4@8V]N8W)E=&4@2&]R9&5?0V]M<')E<W,@<F5F97)E
M;F-E+"!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH
M)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A
M=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D<VEG;F%T=7)E
M(#T@;60U*'-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2DI.PH@
M("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*
M("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D95]#
M;VUP<F5S<SHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M971E<B!A<G)A>2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@2&]R9&5?0V]M<')E<W,H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP<F5S<R!T:&4@
M9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@5&AE
M(&1A=&$@=&\@8V]M<')E<W,N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@06X@87)R87D@;V8@87)G=6UE;G1S(&YE961E9"!T;R!C;VUP<F5S<R!T
M:&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]M
M<')E<W-E9"!D871A+@H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!0
M14%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]M<')E<W,H)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U<'!O<G1E9"<I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C;VUP<F5S<R!T:&4@9&%T82X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@5&AE(&1A=&$@
M=&\@9&5C;VUP<F5S<RX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M;B!A<G)A>2!O9B!A<F=U;65N=',@;F5E9&5D('1O(&1E8V]M<')E<W,@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&%T82X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9&5C;VUP<F5S<V5D(&1A=&$N"B`@
M("`@*B`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O;7!R97-S*"1D
M871A+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G56YS=7!P;W)T960G*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-R>7!T+G!H<```````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C4W-P`Q,#0Q-S,V,C<W,P`P
M,C`P-C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#<GEP=#HZ(&-L87-S('!R;W9I
M9&5S(&%N($%022!F;W(@=F%R:6]U<R!C<GEP=&]G<F%P:&EC"B`J('-Y<W1E
M;7,@=7-E9"!B>2!(;W)D92!A<'!L:6-A=&EO;G,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<"QV(#$N,C<N,3`N.2`R,#`V+S`Q
M+S`Q(#(Q.C(X.C$R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-R>7!T"B`J+PIC;&%S
M<R!(;W)D95]#<GEP="!["@H@("`@+RHJ"B`@("`@*B!4:&4@=&5M<&]R87)Y
M(&1I<F5C=&]R>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?=&5M<&1I<CL*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7T-R>7!T(&EN<W1A
M;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T-R>7!T
M('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N+B!)9B`D9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O
M:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN("1D<FEV97);,%TO
M;&EB+T-R>7!T+R!F;W(@=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP
M:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A
M:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@82!S=6)C;&%S<R!M
M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0W)Y<'0@
M(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($AO<F1E7T-R>7!T(&EN<W1A
M;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@9F%L<V4@;VX@
M86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV
M97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L:7-T*"1A<'`L("1D<FEV
M97(I(#T@)&1R:79E<CL*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R;B!A
M(&)A<V4@2&]R9&5?0W)Y<'0@;V)J96-T(&EF(&YO(&1R:79E<B!I<R!S<&5C
M:69I960N("HO"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I
M.PH@("`@("`@(&EF("AE;7!T>2@D9')I=F5R*2!\?"`H<W1R8VUP*"1D<FEV
M97(L("=N;VYE)RD@/3T@,"DI('L*("`@("`@("`@("`@)&-R>7!T(#T@)FYE
M=R!(;W)D95]#<GEP="@I.PH@("`@("`@("`@("!R971U<FX@)&-R>7!T.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+T-R>7!T+R<@+B`D9')I=F5R("X@
M)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+T-R>7!T+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+T-R>7!T+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T-R>7!T+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@
M/2`G2&]R9&5?0W)Y<'1?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1C<GEP="`]("9N97<@
M)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1C<GEP="`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@
M;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1C<GEP=#L*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO
M<F1E7T-R>7!T(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9')I=F5R+B!)
M="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO"B`@("`@
M*B!(;W)D95]#<GEP="!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E
M<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L
M9"!B92!U<V5D(&EF(&UU;'1I<&QE(&-R>7!T;R!B86-K96YD<R`H86YD+"!T
M:'5S+`H@("`@("H@;75L=&EP;&4@2&]R9&5?0W)Y<'0@:6YS=&%N8V5S*2!A
M<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B
M92!I;G9O:V5D(&%S.B`D=F%R(#T@)DAO<F1E7T-R>7!T.CIS:6YG;&5T;VXH
M*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP
M92!O9B!C;VYC<F5T92!(;W)D95]#<GEP="!S=6)C;&%S<R!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A
M;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]#<GEP="\@9F]R('1H92!S
M=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N
M=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L
M(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D
M+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0W)Y<'0@(%1H92!C;VYC
M<F5T92!(;W)D95]#<GEP="!R969E<F5N8V4L(&]R(&9A;'-E(&]N(&%N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*"B`@("`@("`@
M:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N
M8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@
M/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@
M(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D95]#<GEP=#HZ
M9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3W5T<'5T<R!E<G)O<B!M97-S86=E(&EF('=E(&%R92!N;W0@
M=7-I;F<@82!S96-U<F4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(%!%05)?17)R;W(@(%)E='5R;G,@82!014%27T5R<F]R(&]B:F5C="!I
M9B!T:&5R92!I<R!N;R!S96-U<F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@8V]N;F5C=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5Q=6ER95-E
M8W5R94-O;FYE8W1I;VXH*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E
M<CL*"B`@("`@("`@:68@*"$D8G)O=W-E<BT^=7-I;F=34TQ#;VYN96-T:6]N
M*"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BXB*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@16YC<GEP="!T:&4@<F5Q=65S=&5D(&1A=&$N"B`@("`@*B!4:&ES(&UE
M=&AO9"!S:&]U;&0@8F4@<')O=FED960@8GD@86QL(&-L87-S97,@=&AA="!E
M>'1E;F0@2&]R9&5?0W)Y<'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&%T82`@(%1H92!D871A('1O(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@06X@87)R87D@;V8@87)G=6UE;G1S(&YE961E9"!T
M;R!E;F-R>7!T('1H92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!E;F-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M96YC<GEP="@D9&%T82P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP
M="!T:&4@<F5Q=65S=&5D(&1A=&$N"B`@("`@*B!4:&ES(&UE=&AO9"!S:&]U
M;&0@8F4@<')O=FED960@8GD@86QL(&-L87-S97,@=&AA="!E>'1E;F0@2&]R
M9&5?0W)Y<'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@
M(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@06X@87)R87D@;V8@87)G=6UE;G1S(&YE961E9"!T;R!D96-R>7!T
M('1H92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!D
M96-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP="@D
M9&%T82P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5T=7)N
M("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&$@=&5M<&]R
M87)Y(&9I;&4@=&AA="!W:6QL(&)E(&1E;&5T960@870@=&AE(&5N9"!O9B!T
M:&ES"B`@("`@*B!P<F]C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1D97-C<FEP("!$
M97-C<FEP=&EO;B!S=')I;F<@=&\@=7-E(&EN(&9I;&5N86UE+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&1E;&5T92`@($1E;&5T92!T:&4@9FEL92!A=71O
M;6%T:6-A;&QY/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!&:6QE
M;F%M92!O9B!A('1E;7!O<F%R>2!F:6QE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8W)E871E5&5M<$9I;&4H)&1E<V-R:7`@/2`G:&]R9&4M8W)Y<'0G+"`D
M9&5L971E(#T@=')U92D*("`@('L*("`@("`@("!R971U<FX@571I;#HZ9V5T
M5&5M<$9I;&4H)&1E<V-R:7`L("1D96QE=&4L("1T:&ES+3Y?=&5M<&1I<BP@
M=')U92D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T1A=&$N<&AP````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`S,#<S-0`Q,#0Q-S,V,C<W,P`P,3<V,C0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PH*+R\@26UP;W)T(&-O;G-T86YT<PHO*BH@26UP;W)T
M(&%L<F5A9'D@;6%P<&5D(&-S=B!D871A+B`@("`@("`@*B\@9&5F:6YE*"=)
M35!/4E1?34%04$5$)RP@,2D["B\J*B!-87`@9&%T92!A;F0@=&EM92!E;G1R
M:65S(&]F(&-S=B!D871A+B`J+R!D969I;F4H)TE-4$]25%]$051%5$E-12<L
M(#(I.PHO*BH@26UP;W)T(&=E;F5R:6,@0U-6(&1A=&$N("`@("`@("`@("`@
M("`@*B\@9&5F:6YE*"=)35!/4E1?0U-6)RP@,RD["B\J*B!);7!O<G0@35,@
M3W5T;&]O:R!D871A+B`@("`@("`@("`@("`@("`J+R!D969I;F4H)TE-4$]2
M5%]/551,3T]+)RP@-"D["B\J*B!);7!O<G0@=D-A;&5N9&%R+VE#86QE;F1A
M<B!D871A+B`@("`@("`J+R!D969I;F4H)TE-4$]25%])0T%,14Y$05(G+"`U
M*3L*+RHJ($EM<&]R="!V0V%R9',N("`@("`@("`@("`@("`@("`@("`@("`@
M("HO(&1E9FEN92@G24U03U)47U9#05)$)RP@-BD["B\J*B!);7!O<G0@9V5N
M97)I8R!T<W8@9&%T82X@("`@("`@("`@("`@("`J+R!D969I;F4H)TE-4$]2
M5%]44U8G+"`W*3L*+RHJ($EM<&]R="!-=6QB97)R>2!A9&1R97-S(&)O;VL@
M9&%T82`@("`@("HO(&1E9FEN92@G24U03U)47TU53$)%4E)9)RP@."D["B\J
M*B!);7!O<G0@4&EN92!A9&1R97-S(&)O;VL@9&%T82X@("`@("`@("`J+R!D
M969I;F4H)TE-4$]25%]024Y%)RP@.2D["B\J*B!);7!O<G0@9FEL92X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`J+R!D969I;F4H)TE-4$]25%]&24Q%
M)RP@,3$I.PHO*BH@26UP;W)T(&1A=&$N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*B\@9&5F:6YE*"=)35!/4E1?1$%402<L(#$R*3L*"B\O($5X<&]R
M="!C;VYS=&%N=',*+RHJ($5X<&]R="!G96YE<FEC($-35B!D871A+B`J+R!D
M969I;F4H)T584$]25%]#4U8G+"`Q,#`I.PHO*BH@17AP;W)T(&E#86QE;F1A
M<B!D871A+B`@("HO(&1E9FEN92@G15A03U)47TE#04Q%3D1!4B<L(#$P,2D[
M"B\J*B!%>'!O<G0@=D-A<F1S+B`@("`@("`@("`@*B\@9&5F:6YE*"=%6%!/
M4E1?5D-!4D0G+"`Q,#(I.PHO*BH@17AP;W)T(%135B!D871A+B`@("`@("`@
M("HO(&1E9FEN92@G15A03U)47U135B<L(#$P,RD["B\J*B!%>'!O<G0@3W5T
M;&]O:R!#4U8@9&%T82X@*B\@9&5F:6YE*"=%6%!/4E1?3U543$]/2T-35B<L
M(#$P-"D["@HO*BH*("H@06)S=')A8W0@8VQA<W,@=&\@:&%N9&QE(&1I9F9E
M<F5N="!K:6YD<R!O9B!$871A(&9O<FUA=',@86YD('1O"B`J(&AE;'`@9&%T
M82!E>&-H86YG92!B971W965N($AO<F1E(&%P<&QI8V%T:6]N<R!A;F0@97AT
M97)N86P@<V]U<F-E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<"QV(#$N.#`N,3`N,3$@,C`P-B\P,2\R."`Q-3HU,CHP-2!C:'5C
M:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T1A=&$*("HO"F-L87-S($AO
M<F1E7T1A=&$@97AT96YD<R!014%2('L*"B`@("!V87(@)%]E>'1E;G-I;VX[
M"B`@("!V87(@)%]C;VYT96YT5'EP92`]("=T97AT+W!L86EN)SL*"B`@("`O
M*BH*("`@("`J($$@;&ES="!O9B!W87)N:6YG<R!R86ES960@9'5R:6YG('1H
M92!L87-T(&]P97)A=&EO;BX*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@
M,RXQ"B`@("`@*B\*("`@('9A<B`D7W=A<FYI;F=S(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J(%-T=6(@=&\@:6UP;W)T('!A<W-E9"!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I;7!O<G1$871A*"D*("`@('L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-T=6(@=&\@<F5T=7)N(&5X<&]R=&5D(&1A=&$N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R=$1A=&$H*0H@("`@>PH@("`@?0H*
M("`@("\J*@H@("`@("H@4W1U8B!T;R!I;7!O<G0@82!F:6QE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I;7!O<G1&:6QE*"1F:6QE;F%M92P@)&AE861E<B`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("1D871A(#T@9FEL95]G971?8V]N=&5N
M=',H)&9I;&5N86UE*3L*("`@("`@("!R971U<FX@)'1H:7,M/FEM<&]R=$1A
M=&$H)&1A=&$L("1H96%D97(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1U
M8B!T;R!E>'!O<G0@9&%T82!T;R!A(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5X<&]R=$9I;&4H*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@
M5')I97,@=&\@9&5T97)M:6YE('1H92!E>'!E8W1E9"!N97=L:6YE(&-H87)A
M8W1E<B!B87-E9"!O;B!T:&4*("`@("`J('!L871F;W)M(&EN9F]R;6%T:6]N
M('!A<W-E9"!B>2!T:&4@8G)O=W-E<B=S(&%G96YT(&AE861E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&=U97-S960@97AP96-T960@
M;F5W;&EN92!C:&%R86-T97)S+"!E:71H97(@7&XL(%QR"B`@("`@*B`@("`@
M("`@("`@("`@("`@;W(@7')<;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3F5W;&EN92@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"
M<F]W<V5R+G!H<"<["B`@("`@("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN
M9VQE=&]N*"D["@H@("`@("`@('-W:71C:"`H)&)R;W=S97(M/F=E=%!L871F
M;W)M*"DI('L*("`@("`@("!C87-E("=W:6XG.@H@("`@("`@("`@("!R971U
M<FX@(EQR7&XB.PH*("`@("`@("!C87-E("=M86,G.@H@("`@("`@("`@("!R
M971U<FX@(EQR(CL*"B`@("`@("`@8V%S92`G=6YI>"<Z"B`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@<F5T=7)N(")<;B(["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$9I;&5N86UE*"1B87-E;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@)&)A<V5N86UE("X@)RXG("X@)'1H:7,M/E]E>'1E
M;G-I;VX["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V]N=&5N=%1Y<&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;G1E;G14>7!E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@;V8@=V%R;FEN9W,@
M=&AA="!H879E(&)E96X@<F%I<V5D(&1U<FEN9R!T:&4@;&%S=`H@("`@("H@
M;W!E<F%T:6]N+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!("AP;W-S:6)L>2!E;7!T>2D@
M;&ES="!O9B!W87)N:6YG<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=V%R;FEN
M9W,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W=A<FYI;F=S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N
M8W)E=&4@2&]R9&5?1&%T82!I;G-T86YC92!B87-E9"!O;B`D9F]R;6%T+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9F]R;6%T("!4:&4@='EP92!O
M9B!C;VYC<F5T92!(;W)D95]$871A('-U8F-L87-S('1O"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N+B!)9B`D9F]R;6%T(&ES(&%N(&%R
M<F%Y+"!T:&5N('=E('=I;&P@;&]O:PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&EN("1F;W)M871;,%TO;&EB+T1A=&$O(&9O<B!T:&4@<W5B8VQA
M<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO
M;B!N86UE9"`D9F]R;6%T6S%=+G!H<"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7T1A=&$@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($AO<F1E
M7T1A=&$@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C
M=&]R>2@D9F]R;6%T*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9F]R
M;6%T*2D@>PH@("`@("`@("`@("`D87!P(#T@)&9O<FUA=%LP73L*("`@("`@
M("`@("`@)&9O<FUA="`]("1F;W)M871;,5T["B`@("`@("`@?0H*("`@("`@
M("`D9F]R;6%T(#T@8F%S96YA;64H)&9O<FUA="D["@H@("`@("`@(&EF("AE
M;7!T>2@D9F]R;6%T*2!\?"`H<W1R8VUP*"1F;W)M870L("=N;VYE)RD@/3T@
M,"DI('L*("`@("`@("`@("`@)&1A=&$@/28@;F5W($AO<F1E7T1A=&$H*3L*
M("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N
M("<O;&EB+T1A=&$O)R`N("1F;W)M870@+B`G+G!H<"<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]$871A+R<@
M+B`D9F]R;6%T("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@
M/2`G2&]R9&5?1&%T85\G("X@)&9O<FUA=#L*("`@("`@("!I9B`H8VQA<W-?
M97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&1A=&$@/28@;F5W("1C
M;&%S<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D871A(#T@
M4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L
M87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!(;W)D95]$871A(&EN
M<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9F]R;6%T+B!)="!W:6QL(&]N;'D@
M8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AO<F1E7T1A=&$*("`@("`J
M(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@
M97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@
M;75L=&EP;&4@9&%T82!S;W5R8V5S("AA;F0L('1H=7,L(&UU;'1I<&QE"B`@
M("`@*B!(;W)D95]$871A(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A
M<B`]("9(;W)D95]$871A.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&9O<FUA="`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R
M9&5?1&%T82!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]$871A
M("!4:&4@8V]N8W)E=&4@2&]R9&5?1&%T82!R969E<F5N8V4L(&]R(&9A;'-E
M(&]N(&%N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1F;W)M870I"B`@("!["B`@
M("`@("`@<W1A=&EC("1I;G-T86YC97,["B`@("`@("`@:68@*"%I<W-E="@D
M:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H
M)&9O<FUA="D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N
M871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=
M(#T@)DAO<F1E7T1A=&$Z.F9A8W1O<GDH)&9O<FUA="D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*
M"B`@("`O*BH*("`@("`J($UA<',@82!D871E+W1I;64@<W1R:6YG('1O(&%N
M(&%S<V]C:6%T:79E(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&4@("`@("`@
M5&AE(&1A=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@($]N
M92!O9B`G9&%T92<L("=T:6UE)R!O<B`G9&%T971I;64G+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&5L:6UI=&5R("!4:&4@8VAA<F%C=&5R('1H870@<V5P
M97)A=&5S('1H92!D:69F97)E;G0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9&%T92]T:6UE('!A<G1S+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F]R;6%T("`@("!)9B`G86UP;2<@86YD("1D871E(&-O;G1A:6YS(&$@
M=&EM92!W92!A<W-U;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&AA="!I="!I<R!I;B!!32]032!F;W)M870N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!D871E(&]R('1I;64@:6X@25-/(&9O<FUA
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@;6%P1&%T92@D9&%T92P@)'1Y<&4L
M("1D96QI;6ET97(L("1F;W)M870@/2!N=6QL*0H@("`@>PH@("`@("`@('-W
M:71C:"`H)'1Y<&4I('L*("`@("`@("!C87-E("=D871E)SH*("`@("`@("!C
M87-E("=M;VYT:&1A>2<Z"B`@("`@("`@8V%S92`G;6]N=&AD87EY96%R)SH*
M("`@("`@("`@("`@)&1A=&5S(#T@97AP;&]D92@D9&5L:6UI=&5R+"`D9&%T
M92D["B`@("`@("`@("`@(&EF("AC;W5N="@D9&%T97,I("$](#,I('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D9&%T93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D:6YD97@@/2!A<G)A>5]F;&EP*&5X<&QO9&4H)R\G+"`D9F]R
M;6%T*2D["B`@("`@("`@("`@(')E='5R;B`D9&%T97-;)&EN9&5X6R=Y96%R
M)UU=("X@)RTG("X@)&1A=&5S6R1I;F1E>%LG;6]N=&@G75T@+B`G+2<@+B`D
M9&%T97-;)&EN9&5X6R=M9&%Y)UU=.PH*("`@("`@("!C87-E("=T:6UE)SH*
M("`@("`@("`@("`@)&1A=&5S(#T@97AP;&]D92@D9&5L:6UI=&5R+"`D9&%T
M92D["B`@("`@("`@("`@(&EF("AC;W5N="@D9&%T97,I(#P@,B!\?"!C;W5N
M="@D9&%T97,I(#X@,RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871E
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D9F]R;6%T(#T]("=A
M;7!M)RD@>PH@("`@("`@("`@("`@("`@:68@*'-T<G!O<RAS=')T;VQO=V5R
M*"1D871E<UMC;W5N="@D9&%T97,I+3%=*2P@)W!M)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1D871E<ULP72`A/3T@)S$R)RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;,%T@*ST@,3(["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1D871E<ULP72`]/2`G,3(G*2!["B`@("`@("`@("`@("`@("`@("`@)&1A
M=&5S6S!=(#T@)S`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&1A=&5S6V-O=6YT*"1D871E<RDM,5T@/2`H:6YT*2`D9&%T97-;8V]U
M;G0H)&1A=&5S*2TQ73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@)&1A=&5S6S!=("X@)SHG("X@)&1A=&5S6S%=("X@*&-O=6YT*"1D871E
M<RD@/3T@,R`_("@G.B<@+B`D9&%T97-;,ETI(#H@)SHP,"<I.PH*("`@("`@
M("!C87-E("=D871E=&EM92<Z"B`@("`@("`@("`@(')E='5R;B`G)SL*"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&%K97,@86QL(&YE8V5S
M<V%R>2!A8W1I;VYS(&9O<B!T:&4@9VEV96X@:6UP;W)T('-T97`L('!A<F%M
M971E<G,@86YD"B`@("`@*B!F;W)M('9A;'5E<R!A;F0@<F5T=7)N<R!T:&4@
M;F5X="!N96-E<W-A<GD@<W1E<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D86-T:6]N("!4:&4@8W5R<F5N="!S=&5P+B!/;F4@;V8@=&AE($E-
M4$]25%\J(&-O;G-T86YT<RX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86T@
M("`@($%N(&%S<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@;F5E9&5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&9O<B!T
M:&4@8W5R<F5N="!S=&5P+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M($5I=&AE<B!T:&4@;F5X="!S=&5P(&%S(&%N(&EN=&5G97(@8V]N<W1A;G0@
M;W(@:6UP;W)T960*("`@("`J("`@("`@("`@("`@("`@(&1A=&$@<V5T(&%F
M=&5R('1H92!F:6YA;"!S=&5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT
M4W1E<"@D86-T:6]N+"`D<&%R86T@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M("\J($9I<G-T('-T97`N("HO"B`@("`@("`@:68@*&ES7VYU;&PH)&%C=&EO
M;BDI('L*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==(#T@
M87)R87DH*3L*("`@("`@("`@("`@<F5T=7)N($E-4$]25%]&24Q%.PH@("`@
M("`@('T*"B`@("`@("`@<W=I=&-H("@D86-T:6]N*2!["B`@("`@("`@8V%S
M92!)35!/4E1?1DE,13H*("`@("`@("`@("`@+RH@4V%N:71I>F4@=7!L;V%D
M960@9FEL92X@*B\*("`@("`@("`@("`@)&EM<&]R=%]F;W)M870@/2!5=&EL
M.CIG971&;W)M1&%T82@G:6UP;W)T7V9O<FUA="<I.PH@("`@("`@("`@("`D
M8VAE8VM?=7!L;V%D(#T@0G)O=W-E<CHZ=V%S1FEL955P;&]A9&5D*"=I;7!O
M<G1?9FEL92<L("1P87)A;5LG9FEL95]T>7!E<R==6R1I;7!O<G1?9F]R;6%T
M72D["B`@("`@("`@("`@(&EF("AI<U]A*"1C:&5C:U]U<&QO860L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D8VAE8VM?=7!L
M;V%D.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D7T9)3$536R=I
M;7!O<G1?9FEL92==6R=S:7IE)UT@/#T@,"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE(&9I;&4@8V]N=&%I;F5D
M(&YO(&1A=&$N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1?4T53
M4TE/3ELG:6UP;W)T7V1A=&$G75LG9F]R;6%T)UT@/2`D:6UP;W)T7V9O<FUA
M=#L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24U03U)47TU!
M4%!%1#H*("`@("`@("`@("`@)&1A=&%+97ES(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V1A=&%+97ES)RP@)R<I.PH@("`@("`@("`@("`D87!P2V5Y<R`](%5T
M:6PZ.F=E=$9O<FU$871A*"=A<'!+97ES)RP@)R<I.PH@("`@("`@("`@("!I
M9B`H96UP='DH)&1A=&%+97ES*2!\?"!E;7!T>2@D87!P2V5Y<RDI('L*("`@
M("`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(EEO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96=I<W1R
M>2T^9V5T*"=N86UE)RDI*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M9&%T84ME>7,@/2!E>'!L;V1E*")<="(L("1D871A2V5Y<RD["B`@("`@("`@
M("`@("1A<'!+97ES(#T@97AP;&]D92@B7'0B+"`D87!P2V5Y<RD["B`@("`@
M("`@("`@("1M87`@/2!A<G)A>2@I.PH@("`@("`@("`@("`D9&%T97,@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D87!P2V5Y<R!A<R`D:V5Y
M(#T^("1A<'`I('L*("`@("`@("`@("`@("`@("1M87!;)&1A=&%+97ES6R1K
M97E=72`]("1A<'`["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M
M6R=T:6UE7V9I96QD<R==*2`F)@H@("`@("`@("`@("`@("`@("`@(&ES<V5T
M*"1P87)A;5LG=&EM95]F:65L9',G75LD87!P72DI('L*("`@("`@("`@("`@
M("`@("`@("`D9&%T97-;)&1A=&%+97ES6R1K97E=75LG='EP92==(#T@)'!A
M<F%M6R=T:6UE7V9I96QD<R==6R1A<'!=.PH@("`@("`@("`@("`@("`@("`@
M("1D871E<ULD9&%T84ME>7-;)&ME>5U=6R=V86QU97,G72`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("`@("`@
M("`@("\J($)U:6QD(&%N(&5X86UP;&4@87)R87D@;V8@=7`@=&\@,3`@9&%T
M92]T:6UE(&9I96QD<RX@*B\*("`@("`@("`@("`@("`@("`@("!W:&EL92`H
M)&D@/"!C;W5N="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G72D@
M)B8@8V]U;G0H)&1A=&5S6R1D871A2V5Y<ULD:V5Y75U;)W9A;'5E<R==*2`\
M(#$P*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)%]3
M15-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;)&E=6R1D871A2V5Y<ULD
M:V5Y75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;
M)&1A=&%+97ES6R1K97E=75LG=F%L=65S)UU;72`]("1?4T534TE/3ELG:6UP
M;W)T7V1A=&$G75LG9&%T82==6R1I75LD9&%T84ME>7-;)&ME>5U=.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("1I*RL["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T
M7V1A=&$G75LG;6%P)UT@/2`D;6%P.PH@("`@("`@("`@("!I9B`H8V]U;G0H
M)&1A=&5S*2`^(#`I('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP
M;W)T7V1A=&$G75LG9&%T97,G72`]("1D871E<SL*("`@("`@("`@("`@("`@
M(')E='5R;B!)35!/4E1?1$%4151)344["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YN97AT4W1E<"A)35!/4E1?1$%402P@)'!A
M<F%M*3L*"B`@("`@("`@8V%S92!)35!/4E1?1$%4151)344Z"B`@("`@("`@
M8V%S92!)35!/4E1?1$%403H*("`@("`@("`@("`@:68@*"1A8W1I;VX@/3T@
M24U03U)47T1!5$5424U%*2!["B`@("`@("`@("`@("`@("`D9&5L:6UI=&5R
M(#T@571I;#HZ9V5T1F]R;41A=&$H)V1E;&EM:71E<B<I.PH@("`@("`@("`@
M("`@("`@)&9O<FUA="`](%5T:6PZ.F=E=$9O<FU$871A*"=F;W)M870G*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG9&%T82==*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(BDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("\J($)U:6QD('1H92!R97-U;'0@9&%T82!S
M970@87,@86X@87-S;V-I871I=F4@87)R87DN("HO"B`@("`@("`@("`@("1D
M871A(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)%]315-324].
M6R=I;7!O<G1?9&%T82==6R=D871A)UT@87,@)')O=RD@>PH@("`@("`@("`@
M("`@("`@)&1A=&%?<F]W(#T@87)R87DH*3L*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1R;W<@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P
M)UU;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M87!P961?
M:V5Y(#T@)%]315-324].6R=I;7!O<G1?9&%T82==6R=M87`G75LD:V5Y73L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1A8W1I;VX@/3T@24U03U)4
M7T1!5$5424U%("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`A96UP
M='DH)'9A;"D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T
M*"1P87)A;5LG=&EM95]F:65L9',G72D@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&ES<V5T*"1P87)A;5LG=&EM95]F:65L9',G75LD;6%P<&5D
M7VME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L(#T@
M)'1H:7,M/FUA<$1A=&4H)'9A;"P@)'!A<F%M6R=T:6UE7V9I96QD<R==6R1M
M87!P961?:V5Y72P@)&1E;&EM:71E<ELD:V5Y72P@)&9O<FUA=%LD:V5Y72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&%?<F]W6R1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P
M)UU;)&ME>5U=(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&1A=&%?
M<F]W.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9&%T83L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@=&AE('-E
M<W-I;VX@9&%T82!U<"!A;F0@<F5M;W9E<R!A;GD@=7!L;V%D960@86YD(&UO
M=F5D"B`@("`@*B!F:6QE<RX@268@82!F=6YC=&EO;B!C86QL960@(E]C;&5A
M;G5P*"DB(&5X:7-T<RP@=&AI<R!G971S"B`@("`@*B!C86QL960@=&]O+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($EF(%]C;&5A;G5P*"D@=V%S
M(&-A;&QE9"P@=&AE(')E='5R;B!V86QU92!O9B!T:&ES(&-A;&PN"B`@("`@
M*B`@("`@("`@("`@("`@("!4:&ES('-H;W5L9"!B92!T:&4@=F%L=64@;V8@
M=&AE(&9I<G-T(&EM<&]R="!S=&5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&5A;G5P*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=I
M;7!O<G1?9&%T82==6R=F:6QE7VYA;64G72DI('L*("`@("`@("`@("`@0'5N
M;&EN:R@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I;&5?;F%M92==*3L*
M("`@("`@("!]"B`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==(#T@
M87)R87DH*3L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?8VQE86YU
M<"<I*2!["B`@("`@("`@("`@(')E='5R;B!?8VQE86YU<"@I.PH@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A5')E
M92YP:'``````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-#,V
M,#0`,3`T,3<S-C(W-S,`,#(P-#0T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@HO*BH*("H@3&ES="!E=F5R>2!O
M8FIE8W0@:6X@86X@87)R87DL('-I;6EL87(@=&\@4$5!4B]H=&UL+VUE;G4N
M<&AP+@H@*B\*9&5F:6YE*"=$051!5%)%15]&3U)-051?5%)%12<L(#$I.PH*
M+RHJ"B`J($=E="!A(&9U;&P@;&ES="`M(&%N(&%R<F%Y(&]F(&ME>7,N"B`J
M+PID969I;F4H)T1!5$%44D5%7T9/4DU!5%]&3$%4)RP@,BD["@HO*BH*("H@
M5&AE(')O;W0@96QE;65N="`H=&]P+6QE=F5L('!A<F5N="D@;V8@96%C:"!$
M871A5')E92!G<F]U<"X*("HO"F1E9FEN92@G1$%40512145?4D]/5"<L("TQ
M*3L*"B\J*@H@*B!"=6EL9"!A(&YO<FUA;"!S96QE8W0@<75E<GDN"B`J+PID
M969I;F4H)T1!5$%44D5%7T)524Q$7U-%3$5#5"<L(#`I.PH*+RHJ"B`J($)U
M:6QD(&$@8V]U;G0@;VYL>2!Q=65R>2X*("HO"F1E9FEN92@G1$%40512145?
M0E5)3$1?0T]53E0G+"`Q*3L*"B\J*@H@*B!4:&4@1&%T851R964Z.B!C;&%S
M<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C=&5D(&EN=&5R9F%C92!I;G1O
M('1H90H@*B!V87)I;W5S(&)A8VME;F1S(&9O<B!T:&4@2&]R9&4@1&%T851R
M964@<WES=&5M+@H@*@H@*B!!('!I96-E(&]F(&1A=&$@:7,@:G5S="!A('1I
M=&QE('1H870@:7,@<V%V960@:6X@=&AE('!A9V4@9F]R('1H92!N=6QL"B`J
M(&1R:79E<B!O<B!C86X@8F4@<V%V960@:6X@82!D871A8F%S92!T;R!B92!A
M8V-E<W-E9"!F<F]M(&5V97)Y=VAE<F4N($5V97)Y"B`J('-T;W)E9"!O8FIE
M8W0@;75S="!H879E(&$@9&EF9F5R96YT(&YA;64@*&EN<VED92!E86-H(&=R
M;W5P:60I+@H@*@H@*B!297%U:7)E9"!V86QU97,@9F]R("1P87)A;7,Z/'!R
M93X*("H@("`G9W)O=7`G("TM($1E9FEN92!E86-H(&=R;W5P(&]F(&]B:F5C
M=',@=V4@=V%N="!T;R!B=6EL9"X\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964N<&AP+'8@,2XQ-3$N,BXQ-B`R,#`V
M+S`Q+S`Q(#(Q.C(X.C$S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`S(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*
M("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED
M"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%-T97!H
M86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95]$871A5')E90H@*B\*8VQA
M<W,@1&%T851R964@>PH*("`@("\J*@H@("`@("H@07)R87D@;V8@86QL(&1A
M=&$Z(&EN9&5X960@8GD@:60N(%1H92!F;W)M870@:7,Z(&%R<F%Y*&ED(#T^
M"B`@("`@*B`G;F%M92<@/3X@;F%M92P@)W!A<F5N="<@/3X@<&%R96YT*2X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V1A
M=&$@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@02!H87-H('1H870@8V%N
M(&)E('5S960@=&\@;6%P(&$@9G5L;"!O8FIE8W0@;F%M90H@("`@("H@*'!A
M<F5N=#IC:&EL9#IO8FIE8W0I('1O('1H870@;V)J96-T)W,@=6YI<75E($E$
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M;F%M94UA<"`](&%R<F%Y*"D["@H@("`@("\J*@H@("`@("H@06-T=6%L(&%T
M=')I8G5T92!S;W)T:6YG(&AA<V@N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]S;W)T2&%S:"`](&YU;&P["@H@("`@+RHJ
M"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@
M8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T
M97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!792!A;'=A>7,@;F5E9"`G9W)O=7`G+"!A('-T<FEN9R!T
M:&%T(&1E9FEN97,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M<')E9FEX(&9O<B!E86-H('-E="!O9B!H:65R87)C:&EC86P@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@1&%T851R964H)'!A<F%M<R`](&YU;&PI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A('!A<F%M971E<B!O9B!T:&ES($1A
M=&%4<F5E(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<F%M("!4:&4@<&%R86UE=&5R('1O(')E='5R;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@<&%R86UE=&5R)W,@=F%L=64@;W(@;G5L
M;"!I9B!I="!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971087)A;2@D<&%R86TI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T
M:&ES+3Y?<&%R86US6R1P87)A;5TI(#\@)'1H:7,M/E]P87)A;7-;)'!A<F%M
M72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&%N(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O8FIE8W0@(%1H
M92!O8FIE8W0@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M("1F;W)C92`@("`@
M("`@("!&;W)C92!R96UO=F%L(&]F(&5V97)Y(&-H:6QD(&]B:F5C=#\*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E*"1O8FIE8W0L("1F;W)C92`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1O8FIE8W0L("=$871A5')E
M94]B:F5C="<I*2!["B`@("`@("`@("`@("1O8FIE8W0@/2`D;V)J96-T+3YG
M971.86UE*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YE>&ES
M=',H)&]B:F5C="DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)&]B:F5C="`N("<@9&]E<R!N;W0@97AI<W0G*3L*("`@("`@("!]
M"@H@("`@("`@("1C:&EL9')E;B`]("1T:&ES+3YG971.=6UB97)/9D-H:6QD
M<F5N*"1O8FIE8W0I.PH@("`@("`@(&EF("@D8VAI;&1R96XI('L*("`@("`@
M("`@("`@+RH@5$]$3SH@<F5M;W9E(&-H:6QD<F5N(&EF("1F;W)C92`]/2!T
M<G5E("HO"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(BDL
M(&-O=6YT*"1C:&EL9')E;BDI*3L*("`@("`@("!]"@H@("`@("`@("1I9"`]
M("1T:&ES+3YG971)9"@D;V)J96-T*3L*("`@("`@("`D<&ED(#T@)'1H:7,M
M/F=E=%!A<F5N="@D;V)J96-T*3L*("`@("`@("`D;W)D97(@/2`D=&AI<RT^
M7V1A=&%;)&ED75LG;W)D97(G73L*("`@("`@("!U;G-E="@D=&AI<RT^7V1A
M=&%;)&ED72D["B`@("`@("`@=6YS970H)'1H:7,M/E]N86UE36%P6R1I9%TI
M.PH*("`@("`@("`O+R!3:&EF="!D;W=N('1H92!O<F1E<B!P;W-I=&EO;G,N
M"B`@("`@("`@)'1H:7,M/E]R96]R9&5R*"1P:60L("1O<F1E<BD["@H@("`@
M("`@(')E='5R;B`D:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S
M(&%L;"!$871A5')E92!O8FIE8W1S(&]W;F5D(&)Y(&$@8V5R=&%I;B!U<V5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@($$@=7-E<B!N
M86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R1&%T82@D=7-E
M<BD*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T
M('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V92!A;B!O
M8FIE8W0@=&\@82!N97<@<&%R96YT+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D;V)J96-T("`@("`@5&AE(&]B:F5C="!T;R!M;W9E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F5W<&%R96YT("!4:&4@;F5W('!A<F5N="!O8FIE
M8W0N($1E9F%U;'1S('1O('1H92!R;V]T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!M;W9E*"1O8FIE8W0L("1N97=P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1C:60@/2`D=&AI<RT^9V5T260H)&]B:F5C="D["B`@("`@("`@:68@
M*&ES7V$H)&-I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=/8FIE8W0@=&\@;6]V92!D
M;V5S(&YO="!E>&ES=#H@)7,G+"`D8VED+3YG971-97-S86=E*"DI*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A:7-?;G5L;"@D;F5W<&%R96YT*2D@>PH@
M("`@("`@("`@("`D<&ED(#T@)'1H:7,M/F=E=$ED*"1N97=P87)E;G0I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*"=.97<@<&%R96YT(&1O97,@;F]T(&5X:7-T.B`E<R<L("1P:60M/F=E=$UE
M<W-A9V4H*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'!I9"`]($1!5$%44D5%7U)/3U0["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7V1A=&%;)&-I9%U;)W!A<F5N="==(#T@)'!I9#L*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N
M9V4@86X@;V)J96-T)W,@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@("1O;&1?;V)J96-T("`@("`@(%1H92!O;&0@;V)J96-T+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F5W7V]B:F5C=%]N86UE("!4:&4@;F5W(&]B:F5C
M="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;64H)&]L9%]O8FIE
M8W0L("1N97=?;V)J96-T7VYA;64I"B`@("!["B`@("`@("`@+RH@0VAE8VL@
M=VAE=&AE<B!T:&4@;V)J96-T(&5X:7-T<R!A="!A;&P@*B\*("`@("`@("!I
M9B`H(21T:&ES+3YE>&ES=',H)&]L9%]O8FIE8W0I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"1O;&1?;V)J96-T("X@)R!D;V5S
M(&YO="!E>&ES="<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R
M(&1U<&QI8V%T97,@+2!G970@<&%R96YT(&%N9"!C<F5A=&4@;F5W(&]B:F5C
M=`H@("`@("`@("`J(&YA;64@*B\*("`@("`@("`D<&%R96YT(#T@)'1H:7,M
M/F=E=$YA;64H)'1H:7,M/F=E=%!A<F5N="@D;VQD7V]B:F5C="DI.PH@("`@
M("`@(&EF("@D=&AI<RT^97AI<W1S*"1P87)E;G0@+B`G.B<@+B`D;F5W7V]B
M:F5C=%]N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G1'5P;&EC871E(&YA;64@)R`N("1N97=?;V)J96-T7VYA;64I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4F5P;&%C92!T:&4@;VQD(&YA;64@=VET
M:"!T:&4@;F5W(&]N92!I;B!T:&4@8V%C:&4@*B\*("`@("`@("`D;VQD7V]B
M:F5C=%]I9"`]("1T:&ES+3YG971)9"@D;VQD7V]B:F5C="D["B`@("`@("`@
M)'1H:7,M/E]D871A6R1O;&1?;V)J96-T7VED75LG;F%M92==(#T@)&YE=U]O
M8FIE8W1?;F%M93L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&%N9V5S('1H92!O<F1E<B!O9B!T:&4@8VAI;&1R96X@
M;V8@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M<F5N="`@5&AE(&9U;&P@:60@<&%T:"!O9B!T:&4@<&%R96YT(&]B:F5C="X*
M("`@("`J($!P87)A;2!M:7AE9"`D;W)D97(@("`@268@86X@87)R87D@:70@
M<W!E8VEF:65S('1H92!N97<@<&]S:71I;VYS(&9O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!A;&P@8VAI;&0@;V)J96-T<RX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@268@86X@:6YT96=E<B!A;F0@)&-I9"!I
M<R!S<&5C:69I960L('1H92!P;W-I=&EO;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!W:&5R92!T:&4@8VAI;&0@<W!E8VEF:65D(&)Y("1C:60@
M:7,@:6YS97)T960N($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("1C:60@:7,@;F]T('-P96-I9FEE9"P@=&AE('!O<VET:6]N(&=E=',@9&5L
M971E9"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8V%U<VEN9R!T
M:&4@9F]L;&]W:6YG('!O<VET:6]N<R!T;R!S:&EF="!U<"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1C:60@("`@4V5E("1O<F1E<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5O<F1E<B@D<&%R96YT<RP@)&]R9&5R(#T@;G5L;"P@)&-I
M9"`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M86YG92!O<F1E<B!O9B!C:&EL9')E;B!O9B!A;B!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&ED("`@("!4:&4@<&%R96YT(&]B:F5C
M="!I9"!S=')I;F<@<&%T:"X*("`@("`J($!P87)A;2!M:7AE9"`D;W)D97(@
M("`@4W!E8VEF:6,@;F5W(&]R9&5R('!O<VET:6]N(&]R(&%N(&%R<F%Y(&-O
M;G1A:6YI;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&YE
M=R!P;W-I=&EO;G,@9F]R('1H92!G:79E;B!P87)E;G0N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D8VED("`@($EF('!R;W9I9&5D(&EN9&EC871E<R!I;G-E
M<G1I;VX@;V8@82!N97<@8VAI;&0@=&\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@=&AE('!A<F5N="!T;R!A=F]I9"!I;F-R96UE;G1I;F<@:70@
M=VAE;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S:&EF=&EN9R!U
M<"!A;&P@;W1H97(@8VAI;&1R96XG<R!O<F1E<BX@268@;F]T"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@('!R;W9I9&5D(&EN9&EC871E<R!D96QE
M=&EO;BP@<V\@<VAI9G0@86QL(&]T:&5R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@('!O<VET:6]N<R!D;W=N(&]N92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W)E;W)D97(H)'!I9"P@)&]R9&5R(#T@;G5L;"P@)&-I9"`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;W)D97(I("8F("%I
M<U]N=6QL*"1O<F1E<BDI('L*("`@("`@("`@("`@+R\@4VEN9VQE('5P9&%T
M92`H861D+V1E;"DN"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C:60I*2![
M"B`@("`@("`@("`@("`@("`O+R!.;R!I9"!G:79E;B!S;R!S:'5F9FQE(&1O
M=VXN"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1A=&$@87,@
M)&-?:V5Y(#T^("1C7W9A;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V1A=&%;)&-?:V5Y75LG<&%R96YT)UT@/3T@)'!I9`H@("`@("`@
M("`@("`@("`@("`@("`@("`F)B`D=&AI<RT^7V1A=&%;)&-?:V5Y75LG;W)D
M97(G72`^("1O<F1E<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1A=&%;)&-?:V5Y75LG;W)D97(G72TM.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("\O(%=E(&AA=F4@86X@:60@<V\@<VAU9F9L92!U
M<"X*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9&%T82!A<R`D
M8U]K97D@/3X@)&-?=F%L*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C
M7VME>2`A/2`D8VED("`F)B`D=&AI<RT^7V1A=&%;)&-?:V5Y75LG<&%R96YT
M)UT@/3T@)'!I9`H@("`@("`@("`@("`@("`@("`@("`@("`F)B`D=&AI<RT^
M7V1A=&%;)&-?:V5Y75LG;W)D97(G72`^/2`D;W)D97(I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D871A6R1C7VME>5U;)V]R9&5R)UTK
M*SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&]R9&5R
M*2`F)B!C;W5N="@D;W)D97(I*2!["B`@("`@("`@("`@("\O($UU;'1I('5P
M9&%T92X*("`@("`@("`@("`@9F]R96%C:"`H)&]R9&5R(&%S("1O<F1E<E]P
M;W-I=&EO;B`]/B`D8VED*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1A
M=&%;)&-I9%U;)V]R9&5R)UT@/2`D;W)D97)?<&]S:71I;VX["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!L:6-I
M=&QY('-E="!T:&4@;W)D97(@9F]R(&$@9&%T871R964@;V)J96-T+@H@("`@
M("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1I9"`@("`@5&AE(&1A=&%T<F5E(&]B:F5C="!I9"!T;R!C:&%N9V4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;W)D97(@(%1H92!N97<@;W)D97(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]R9&5R*"1I9"P@)&]R9&5R*0H@
M("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@<W5P
M<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$>6YA;6EC86QL>2!D
M971E<FUI;F5S('1H92!O8FIE8W0@8VQA<W,N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1A='1R:6)U=&5S("!4:&4@<V5T(&]F(&%T=')I8G5T97,@
M=&AA="!C;VYT86EN('1H92!C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I;F9O<FUA=&EO;BX@1&5F875L=',@=&\@1&%T851R965/
M8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D969I;F5/8FIE8W1#;&%S
M<R@D871T<FEB=71E<RD*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y
M.PH*("`@("`@("`D8VQA<W,@/2`G1&%T851R965/8FIE8W0G.PH@("`@("`@
M(&EF("@A:7-?87)R87DH)&%T=')I8G5T97,I*2!["B`@("`@("`@("`@(')E
M='5R;B`D8VQA<W,["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D871T
M<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@("`@("!I9B`H)&%T=');)VYA
M;64G72`]/2`G1&%T851R964G*2!["B`@("`@("`@("`@("`@("!I9B`H)&%T
M=');)VME>2==(#T]("=O8FIE8W1#;&%S<R<I('L*("`@("`@("`@("`@("`@
M("`@("`D8VQA<W,@/2`D871T<ELG=F%L=64G73L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@96QS96EF("@D871T<ELG
M:V5Y)UT@/3T@)V]B:F5C=%1Y<&4G*2!["B`@("`@("`@("`@("`@("`@("`@
M)')E<W5L="`](&5X<&QO9&4H)R\G+"`D871T<ELG=F%L=64G72D["B`@("`@
M("`@("`@("`@("`@("`@)&-L87-S(#T@)')E9VES=')Y+3YC86QL0GE086-K
M86=E*"1R97-U;'1;,%TL("=D969I;F5#;&%S<R<L(&%R<F%Y*"=T>7!E)R`]
M/B`D<F5S=6QT6S%=*2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D8VQA<W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@1&%T851R965/8FIE8W0@*&]R('-U8F-L87-S*2!O8FIE8W0@;V8@
M=&AE(&1A=&$@:6X@=&AE"B`@("`@*B!O8FIE8W0@9&5F:6YE9"!B>2`D;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]B:F5C="`@5&AE
M(&]B:F5C="!T;R!F971C:#H@)W!A<F5N=#IS=6(M<&%R96YT.FYA;64G+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@("!3=6)C;&%S<R!O9B!$871A
M5')E94]B:F5C="!T;R!U<V4N($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T+B!.=6QL(&9O<F-E<R!T
M:&4@9')I=F5R('1O(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@:6YT;R!T:&4@871T<FEB=71E<R!T86)L92!T;R!D971E<FUI;F4@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('-U8F-L87-S('1O('5S
M92X@268@;F]N92!I<R!F;W5N9"!I="!U<V5S"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F9V5T3V)J96-T*"1O8FIE8W0L("1C;&%S<R`]("=$871A5')E94]B
M:F5C="<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1O8FIE8W0I*2!["B`@
M("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)TYO(&]B:F5C
M="!R97%U97-T960N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7VQO860H)&]B:F5C="D["B`@("`@
M("`@:68@*"$D=&AI<RT^97AI<W1S*"1O8FIE8W0I*2!["B`@("`@("`@("`@
M("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)&]B:F5C="`N("<@;F]T(&9O
M=6YD+B<I.PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*
M"B`@("`@("`@)'5S95]A='1R:6)U=&5S(#T@:7-?;G5L;"@D8VQA<W,I('Q\
M(&ES7V-A;&QA8FQE*&%R<F%Y*"1C;&%S<RP@)U]F<F]M071T<FEB=71E<R<I
M*3L*("`@("`@("!I9B`H)'5S95]A='1R:6)U=&5S*2!["B`@("`@("`@("`@
M("1A='1R:6)U=&5S(#T@)'1H:7,M/F=E=$%T=')I8G5T97,H)'1H:7,M/F=E
M=$ED*"1O8FIE8W0I*3L*("`@("`@("`@("`@:68@*&ES7V$H)&%T=')I8G5T
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M871T<FEB=71E<SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES
M7VYU;&PH)&-L87-S*2D@>PH@("`@("`@("`@("`@("`@)&-L87-S(#T@)'1H
M:7,M/E]D969I;F5/8FIE8W1#;&%S<R@D871T<FEB=71E<RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1C
M;&%S<RDI('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O
M<B@D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@("1D871A3V(@/2`F;F5W("1C
M;&%S<R@D;V)J96-T*3L*("`@("`@("`D9&%T84]B+3YS971$871A5')E92@D
M=&AI<RD["B`@("`@("`@+RH@268@=&AE(&-L87-S(&AA<R!A(%]F<F]M071T
M<FEB=71E<R!M971H;V0L(&QO860@9&%T82!F<F]M"B`@("`@("`@("H@=&AE
M(&%T=')I8G5T97,@8F%C:V5N9"X@*B\*("`@("`@("!I9B`H)'5S95]A='1R
M:6)U=&5S*2!["B`@("`@("`@("`@("1D871A3V(M/E]F<F]M071T<FEB=71E
M<R@D871T<FEB=71E<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+RH@3W1H97)W:7-E(&QO860@:70@9G)O;2!T:&4@;VQD(&1A=&$@<W1O<F%G
M92!F:65L9"X@*B\*("`@("`@("`@("`@)&1A=&%/8BT^<V5T1&%T82@D=&AI
M<RT^9V5T1&%T82@D=&AI<RT^9V5T260H)&]B:F5C="DI*3L*("`@("`@("!]
M"@H@("`@("`@("1D871A3V(M/G-E=$]R9&5R*"1T:&ES+3YG971/<F1E<B@D
M;V)J96-T*2D["B`@("`@("`@<F5T=7)N("1D871A3V(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@1&%T851R965/8FIE8W0@*&]R('-U8F-L
M87-S*2!O8FIE8W0@;V8@=&AE(&1A=&$@:6X@=&AE"B`@("`@*B!O8FIE8W0@
M=VET:"!T:&4@240@)&ED+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1I9"`@("!!;B!O8FIE8W0@:60N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M;&%S<R`@4W5B8VQA<W,@;V8@1&%T851R965/8FIE8W0@=&\@=7-E+B!$969A
M=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@($1A=&%4<F5E
M3V)J96-T+B!.=6QL(&9O<F-E<R!T:&4@9')I=F5R('1O(&QO;VL*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I;G1O('1H92!A='1R:6)U=&5S('1A
M8FQE('1O(&1E=&5R;6EN92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!S=6)C;&%S<R!T;R!U<V4N($EF(&YO;F4@:7,@9F]U;F0@:70@=7-E
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T3V)J96-T0GE)9"@D:60L("1C
M;&%S<R`]("=$871A5')E94]B:F5C="<I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1I9"DI('L*("`@("`@("`@("`@)&]B:F5C="`](%!%05(Z.G)A:7-E
M17)R;W(H)TYO(&ED(')E<75E<W1E9"XG*3L*("`@("`@("`@("`@<F5T=7)N
M("1O8FIE8W0["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]L;V%D0GE)9"@D:60I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`D=7-E7V%T=')I8G5T97,@/2!I<U]N=6QL*"1C
M;&%S<RD@?'P@:7-?8V%L;&%B;&4H87)R87DH)&-L87-S+"`G7V9R;VU!='1R
M:6)U=&5S)RDI.PH@("`@("`@(&EF("@D=7-E7V%T=')I8G5T97,I('L*("`@
M("`@("`@("`@)&%T=')I8G5T97,@/2`D=&AI<RT^9V5T071T<FEB=71E<R@D
M:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D871T<FEB=71E<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1A='1R:6)U=&5S
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-?;G5L;"@D8VQA
M<W,I*2!["B`@("`@("`@("`@("`@("`D8VQA<W,@/2`D=&AI<RT^7V1E9FEN
M94]B:F5C=$-L87-S*"1A='1R:6)U=&5S*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D8VQA<W,@+B`G
M(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@("1N86UE(#T@)'1H
M:7,M/F=E=$YA;64H)&ED*3L*("`@("`@("`D9&%T84]B(#T@)FYE=R`D8VQA
M<W,H)&YA;64I.PH@("`@("`@("1D871A3V(M/G-E=$1A=&%4<F5E*"1T:&ES
M*3L*("`@("`@("`O*B!)9B!T:&4@8VQA<W,@:&%S(&$@7V9R;VU!='1R:6)U
M=&5S(&UE=&AO9"P@;&]A9"!D871A(&9R;VT*("`@("`@("`@*B!T:&4@871T
M<FEB=71E<R!B86-K96YD+B`J+PH@("`@("`@(&EF("@D=7-E7V%T=')I8G5T
M97,I('L*("`@("`@("`@("`@)&1A=&%/8BT^7V9R;VU!='1R:6)U=&5S*"1A
M='1R:6)U=&5S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!/
M=&AE<G=I<V4@;&]A9"!I="!F<F]M('1H92!O;&0@9&%T82!S=&]R86=E(&9I
M96QD+B`J+PH@("`@("`@("`@("`D9&%T84]B+3YS971$871A*"1T:&ES+3YG
M971$871A*"1I9"DI.PH@("`@("`@('T*"B`@("`@("`@)&1A=&%/8BT^<V5T
M3W)D97(H)'1H:7,M/F=E=$]R9&5R*"1N86UE*2D["B`@("`@("`@<F5T=7)N
M("1D871A3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R
M<F%Y(&]F($1A=&%4<F5E3V)J96-T("AO<B!S=6)C;&%S<RD@;V)J96-T<PH@
M("`@("H@8V]R<F5S<&]N9&EN9R!T;R!T:&4@;V)J96-T<R!I;B`D:61S+"!W
M:71H('1H92!O8FIE8W0*("`@("`J(&YA;65S(&%S('1H92!K97ES(&]F('1H
M92!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ED<R`@("`@
M06X@87)R87D@;V8@;V)J96-T(&ED<RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&-L87-S("!3=6)C;&%S<R!O9B!$871A5')E94]B:F5C="!T;R!U<V4N($1E
M9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@1&%T851R
M965/8FIE8W0N($YU;&P@9F]R8V5S('1H92!D<FEV97(@=&\@;&]O:PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&EN=&\@=&AE(&%T=')I8G5T97,@
M=&%B;&4@=&\@9&5T97)M:6YE('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@('-U8F-L87-S('1O('5S92X@268@;F]N92!I<R!F;W5N9"!I="!U
M<V5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@1&%T851R965/8FIE
M8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971/8FIE8W1S*"1I9',L("1C
M;&%S<R`]("=$871A5')E94]B:F5C="<I"B`@("!["B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?;&]A9$)Y260H)&ED<RD["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1D969I;F5#;&%S<R`](&ES
M7VYU;&PH)&-L87-S*3L*("`@("`@("`D871T<FEB=71E<R`](&ES7VYU;&PH
M)&-L87-S*2!\?"!I<U]C86QL86)L92AA<G)A>2@D8VQA<W,L("=?9G)O;4%T
M=')I8G5T97,G*2D["@H@("`@("`@(&EF("@D871T<FEB=71E<RD@>PH@("`@
M("`@("`@("`D9&%T82`]("1T:&ES+3YG971!='1R:6)U=&5S*"1I9',I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D871A(#T@)'1H:7,M/F=E
M=$1A=&$H)&ED<RD["B`@("`@("`@?0H*("`@("`@("`D;V)J96-T<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&ED<R!A<R`D:60I('L*("`@("`@
M("`@("`@)&YA;64@/2`D=&AI<RT^9V5T3F%M92@D:60I.PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1N86UE*2`F)B`A96UP='DH)&1A=&%;)&ED72DI('L*
M("`@("`@("`@("`@("`@(&EF("@D9&5F:6YE0VQA<W,I('L*("`@("`@("`@
M("`@("`@("`@("`D8VQA<W,@/2`D=&AI<RT^7V1E9FEN94]B:F5C=$-L87-S
M*"1D871A6R1I9%TI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D8VQA<W,@+B`G(&YO
M="!F;W5N9"XG*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D;V)J96-T<ULD;F%M95T@/2`F;F5W("1C;&%S<R@D;F%M92D["B`@("`@
M("`@("`@("`@("`D;V)J96-T<ULD;F%M95TM/G-E=$1A=&%4<F5E*"1T:&ES
M*3L*("`@("`@("`@("`@("`@(&EF("@D871T<FEB=71E<RD@>PH@("`@("`@
M("`@("`@("`@("`@("1O8FIE8W1S6R1N86UE72T^7V9R;VU!='1R:6)U=&5S
M*"1D871A6R1I9%TI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D;V)J96-T<ULD;F%M95TM/G-E=$1A=&$H)&1A=&%;
M)&ED72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;V)J
M96-T<ULD;F%M95TM/G-E=$]R9&5R*"1T:&ES+3YG971/<F1E<B@D;F%M92DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]B
M:F5C=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@82!L:7-T(&]F
M(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1F;W)M
M870@("`@("!&;W)M870@;V8@=&AE(&5X<&]R=`H@("`@("H@0'!A<F%M('-T
M<FEN9R`@("1S=&%R=&QE868@("!4:&4@;F%M92!O9B!T:&4@;&5A9B!F<F]M
M('=H:6-H('=E('-T87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H92!E>'!O<G0@=')E92X*("`@("`J($!P87)A;2!B;V]L96%N
M("`D<F5L;V%D("`@("`@4F4M;&]A9"!T:&4@<F5Q=65S=&5D(&-H=6YK/R!$
M969A=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F86QS92`H;VYL>2!W:&%T(&ES(&-U<G)E;G1L>2!L;V%D960I+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@("1R;V]T;F%M92`@("!4:&4@;&%B96P@=&\@
M=7-E(&9O<B!T:&4@<F]O="!E;&5M96YT+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!$051!5%)%15]23T]4+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@("1M87AD97!T:"`@("!4:&4@;6%X:6UU
M;2!N=6UB97(@;V8@;&5V96QS('1O(')E='5R;BX*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@1$%40512145?4D]/
M5"P@=VAI8V@@:7,@;F\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;&EM:70N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@)&QO8614<F5E
M("`@($QO860@82!T<F5E('-T87)T:6YG(&%T("1R;V]T+"!O<B!J=7-T('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U97-T
M960@;&5V96P@86YD(&1I<F5C="!P87)E;G1S/PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V96PN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`@)'-O<G1B>5]N86UE($%T=')I8G5T
M92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S=')I
M;F<@("`D<V]R=&)Y7VME>2`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O
M<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`@)&1I<F5C=&EO;B`@(%-O
M<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@=')E92!R97!R97-E;G1A=&EO;B!O9B!T:&4@;V)J
M96-T<RP@;W(@82!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@("!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)&9O<FUA="P@
M)'-T87)T;&5A9B`]($1!5$%44D5%7U)/3U0L("1R96QO860@/2!F86QS92P*
M("`@("`@("`@("`@("`@("`D<F]O=&YA;64@/2!$051!5%)%15]23T]4+"`D
M;6%X9&5P=&@@/2`M,2P@)&QO8614<F5E(#T@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL
M+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("`O*B!3970@<V]R=&EN
M9R!H87-H("HO"B`@("`@("`@:68@*"%I<U]N=6QL*"1S;W)T8GE?;F%M92D@
M?'P@(6ES7VYU;&PH)'-O<G1B>5]N86UE*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W-O<G1(87-H(#T@1&%T851R964Z.G-O<G1(87-H*"1S=&%R=&QE868L
M("1S;W)T8GE?;F%M92P@)'-O<G1B>5]K97DL("1D:7)E8W1I;VXI.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]L;V%D*"1S=&%R=&QE868L("1L;V%D
M5')E92P@)')E;&]A9"P@)'-O<G1B>5]N86UE+"`D<V]R=&)Y7VME>2P@)&1I
M<F5C=&EO;BD["B`@("`@("`@)&]U="`](&%R<F%Y*"D["@H@("`@("`@('-W
M:71C:"`H)&9O<FUA="D@>PH@("`@("`@(&-A<V4@1$%40512145?1D]234%4
M7U12144Z"B`@("`@("`@("`@("1S=&%R=&ED(#T@)'1H:7,M/F=E=$ED*"1S
M=&%R=&QE868L("1M87AD97!T:"D["B`@("`@("`@("`@(&EF("AI<U]A*"1S
M=&%R=&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'-T87)T:60["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]E>'1R86-T06QL3&5V96Q4<F5E*"1O=70L("1S=&%R=&ED+"`D;6%X9&5P
M=&@I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!$051!5%)%
M15]&3U)-051?1DQ!5#H*("`@("`@("`@("`@)'-T87)T:60@/2`D=&AI<RT^
M9V5T260H)'-T87)T;&5A9BD["B`@("`@("`@("`@(&EF("AI<U]A*"1S=&%R
M=&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'-T87)T:60["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]E
M>'1R86-T06QL3&5V96Q,:7-T*"1O=70L("1S=&%R=&ED+"`D;6%X9&5P=&@I
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1O=71;1$%40512145?4D]/5%TI
M*2!["B`@("`@("`@("`@("`@("`D;W5T6T1!5$%44D5%7U)/3U1=(#T@)')O
M;W1N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G3F]T('-U<'!O<G1E9"<I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<U]N=6QL*"1T:&ES+3Y?<V]R=$AA<V@I*2!["B`@("`@("`@("`@("\J
M(%)E<V5T('-O<G1I;F<@:&%S:"X@*B\*("`@("`@("`@("`@)'1H:7,M/E]S
M;W)T2&%S:"`](&YU;&P["B`@("`@("`@("`@("\J(%)E=F5R<V4@<VEN8V4@
M=&AE(&%T=')I8G5T92!S;W)T:6YG(&-O;6)I;F5D('=I=&@@=')E92!U<"UW
M87)D"B`@("`@("`@("`@("`J('-O<G1I;F<@<')O9'5C97,@82!R979E<G-E
M9"!O8FIE8W0@;W)D97(N("HO"B`@("`@("`@("`@("1O=70@/2!A<G)A>5]R
M979E<G-E*"1O=70L('1R=64I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1O=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;W5N=',@;V)J96-T<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=&%R=&QE868@(%1H92!N
M86UE(&]F('1H92!L96%F(&9R;VT@=VAI8V@@=V4@<W1A<G0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]U;G1I;F<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F('1H92!O8FIE8W1S
M(&)E;&]W("1S=&%R=&QE868N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT
M*"1S=&%R=&QE868@/2!$051!5%)%15]23T]4*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V-O=6YT*"1S=&%R=&QE868I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E(&%T=')I8G5T92!S;W)T(&AA<V@*("`@("`J"B`@
M("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)')O;W0@("`@("`@("!4:&4@;F%M92!O9B!T:&4@;&5A9B!F<F]M
M('=H:6-H('=E('-T87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H92!E>'!O<G0@=')E92X*("`@("`J($!P87)A;2!S=')I;F<@
M("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T
M:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@("!!='1R
M:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I
M;F<*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@<V]R="!H87-H
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G1(87-H*"1R;V]T+"`D<V]R=&)Y
M7VYA;64@/2!N=6QL+"`D<V]R=&)Y7VME>2`](&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("!R971U
M<FX@<W!R:6YT9B@G)7,M)7,M)7,M)7,G+"`D<F]O="P@)'-O<G1B>5]N86UE
M+"`D<V]R=&)Y7VME>2P@)&1I<F5C=&EO;BD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!%>'!O<G0@82!L:7-T(&]F(&]B:F5C=',@:G5S="!L:6ME(&=E="@I
M(&%B;W9E+"!B=70@=7-E<R!A;@H@("`@("H@;V)J96-T(&ED('1O(&9E=&-H
M('1H92!L:7-T(&]F(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&-O
M;G-T86YT("1F;W)M870@("`@1F]R;6%T(&]F('1H92!E>'!O<G0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D<W1A<G1L96%F("!4:&4@:60@;V8@=&AE(&QE
M868@9G)O;2!W:&EC:"!W92!S=&%R="!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&5X<&]R="!T<F5E+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)')E;&]A9"`@("`@4F5L;V%D('1H92!R97%U97-T960@8VAU;FL_
M($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F86QS92`H;VYL>2!W:&%T(&ES(&-U<G)E;G1L>2!L;V%D960I+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)')O;W1N86UE("`@5&AE(&QA8F5L('1O('5S
M92!F;W(@=&AE(')O;W0@96QE;65N="X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1E9F%U;'1S('1O($1!5$%44D5%7U)/3U0N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;6%X9&5P=&@@("!4:&4@;6%X:6UU;2!N=6UB
M97(@;V8@;&5V96QS('1O(')E='5R;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@1&5F875L=',@=&\@1$%40512145?4D]/5"P@=VAI8V@@
M:7,@;F\@;&EM:70N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M('1R964@<F5P<F5S96YT871I;VX@;V8@=&AE(&]B:F5C=',L(&]R(&$@4$5!
M4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T0GE)9"@D9F]R;6%T+"`D<W1A<G1L96%F
M(#T@1$%40512145?4D]/5"P@)')E;&]A9"`](&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`D<F]O=&YA;64@/2!$051!5%)%15]23T]4+"`D;6%X9&5P
M=&@@/2`M,2D*("`@('L*("`@("`@("`D=&AI<RT^7VQO861">4ED*"1S=&%R
M=&QE868I.PH@("`@("`@("1O=70@/2!A<G)A>2@I.PH*("`@("`@("!S=VET
M8V@@*"1F;W)M870I('L*("`@("`@("!C87-E($1!5$%44D5%7T9/4DU!5%]4
M4D5%.@H@("`@("`@("`@("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;%1R964H
M)&]U="P@)'-T87)T;&5A9BP@)&UA>&1E<'1H*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@1$%40512145?1D]234%47T9,050Z"B`@("`@
M("`@("`@("1T:&ES+3Y?97AT<F%C=$%L;$QE=F5L3&ES="@D;W5T+"`D<W1A
M<G1L96%F+"`D;6%X9&5P=&@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1O
M=71;1$%40512145?4D]/5%TI*2!["B`@("`@("`@("`@("`@("`D;W5T6T1!
M5$%44D5%7U)/3U1=(#T@)')O;W1N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F]T('-U<'!O<G1E9"<I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@;&ES="!O9B!A;&P@9W)O=7!S("AR;V]T(&YO9&5S
M*2!O9B!T:&4@9&%T82!T<F5E+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!T:&4@9W)O=7`@241S"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$=R;W5P<R@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E(&1A=&$@9F]R(&%N(&]B:F5C="!F<F]M('1H92!D871A=')E95]D
M871A(&9I96QD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!O8FIE8W0@:60@=&\@9F5T
M8V@L(&]R(&%N(&%R<F%Y(&]F(&]B:F5C="!I9',N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$1A=&$H)&-I9"D*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@26UP;W)T(&$@;&ES="!O9B!O8FIE8W1S+B!5<V5D(&)Y(&1R
M:79E<G,@=&\@<&]P=6QA=&4@=&AE(&EN=&5R;F%L"B`@("`@*B`D7V1A=&$@
M87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&1A=&$@("`@
M(%1H92!D871A('1O(&EM<&]R="X*("`@("`J($!P87)A;2!S=')I;F<@("1C
M:&%R<V5T("!4:&4@8VAA<G-E="!T;R!C;VYV97)T('1H92!O8FIE8W0@;F%M
M92!F<F]M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&1A=&$L("1C:&%R
M<V5T(#T@;G5L;"D*("`@('L*("`@("`@("`D8V%T<R`](&%R<F%Y*"D["B`@
M("`@("`@)&-I9',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1D871A
M(&%S("1I9"`]/B`D8V%T*2!["B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D
M8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("1C871;,5T@/2!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1C871;,5TL("1C:&%R<V5T*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D8VED<ULD8V%T6S!=72`]("1C871;,5T["B`@
M("`@("`@("`@("1C<&%R96YT<ULD8V%T6S!=72`]("1C871;,ET["B`@("`@
M("`@("`@("1C;W)D97)S6R1C871;,%U=(#T@)&-A=%LS73L*("`@("`@("`@
M("`@)'-O<F1E<G-;)&-A=%LP75T@/2`D:60["B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D8VED<R!A<R`D:60@/3X@)&YA;64I('L*("`@("`@("`@
M("`@)'1H:7,M/E]D871A6R1I9%U;)VYA;64G72`]("1N86UE.PH@("`@("`@
M("`@("`D=&AI<RT^7V1A=&%;)&ED75LG;W)D97(G72`]("1C;W)D97)S6R1I
M9%T["B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7W-O<G1(87-H
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D871A6R1I9%U;)W-O<G1E
M<B==6R1T:&ES+3Y?<V]R=$AA<VA=(#T@)'-O<F1E<G-;)&ED73L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1C<&%R96YT<ULD:61=
M*2D@>PH@("`@("`@("`@("`@("`@)'!A<F5N=',@/2!E>'!L;V1E*"<Z)RP@
M<W5B<W1R*"1C<&%R96YT<ULD:61=+"`Q*2D["B`@("`@("`@("`@("`@("`D
M<&%R(#T@)'!A<F5N='-;8V]U;G0H)'!A<F5N=',I("T@,5T["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1A=&%;)&ED75LG<&%R96YT)UT@/2`D<&%R.PH*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N86UE36%P6R1P
M87)=*2D@>PH@("`@("`@("`@("`@("`@("`@("\O($EF('=E)W9E(&%L<F5A
M9'D@;&]A9&5D('1H92!D:7)E8W0@<&%R96YT(&]F"B`@("`@("`@("`@("`@
M("`@("`@+R\@=&AI<R!O8FIE8W0L('5S92!T:&%T('1O(&9I;F0@=&AE(&9U
M;&P@;F%M92X*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VYA;65-87!;
M)&ED72`]("1T:&ES+3Y?;F%M94UA<%LD<&%R72`N("<Z)R`N("1N86UE.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O
M+R!/=&AE<G=I<V4L(')U;B!T:')O=6=H('!A<F5N=',@;VYE(&)Y(&]N92!T
M;PH@("`@("`@("`@("`@("`@("`@("\O(&)U:6QD(&ET('5P+@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;F%M94UA<%LD:61=(#T@)R<["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F5N=',@87,@)'!A<DE$*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-I9'-;)'!A
M<DE$72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;F%M94UA<%LD:61=("X]("<Z)R`N("1C:61S6R1P87))1%T["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]N86UE36%P6R1I9%T@/2!S=6)S='(H
M)'1H:7,M/E]N86UE36%P6R1I9%TL(#$I("X@)SHG("X@)&YA;64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1A=&%;)&ED75LG<&%R96YT)UT@/2!$051!5%)%15]2
M3T]4.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]N86UE36%P6R1I9%T@/2`D
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'1R86-T(&]N92!L979E
M;"!O9B!D871A(&9O<B!A('!A<F5N="!L96%F+"!S;W)T960@9FER<W0@8GD*
M("`@("`J('1H96ER(&]R9&5R(&%N9"!T:&5N(&)Y(&YA;64N(%1H:7,@9G5N
M8W1I;VX@:7,@82!W87D@=&\@9V5T(&$*("`@("`J(&-O;&QE8W1I;VX@;V8@
M)&QE868G<R!C:&EL9')E;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1L96%F("!.86UE(&]F('1H92!P87)E;G0@9G)O;2!W:&EC:"!T;R!S=&%R
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]E>'1R86-T3VYE3&5V96PH)&QE868@/2!$051!5%)%15]23T]4
M*0H@("`@>PH@("`@("`@("1O=70@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?9&%T82!A<R`D:60@/3X@)'9A;',I('L*("`@("`@("`@
M("`@:68@*"1V86QS6R=P87)E;G0G72`]/2`D;&5A9BD@>PH@("`@("`@("`@
M("`@("`@)&]U=%LD:61=(#T@)'9A;',["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?<V]R=$AA<V@I*2![
M"B`@("`@("`@("`@('5A<V]R="@D;W5T+"!A<G)A>2@D=&AI<RP@)U]C;7`G
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=6%S;W)T*"1O=70L
M(&%R<F%Y*"1T:&ES+"`G7V-M<%-O<G1E9"<I*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D;W5T.PH@("`@?0H*("`@("\J*@H@("`@("H@17AT<F%C
M="!A;&P@;&5V96QS(&]F(&1A=&$L('-T87)T:6YG(&9R;VT@82!G:79E;B!P
M87)E;G0*("`@("`J(&QE868@:6X@=&AE(&1A=&%T<F5E+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D;W5T("`@("`@("`@5&AI<R!I<R!A;B!I=&5R
M871I;F<@9G5N8W1I;VXL('-O("1O=70@:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%S<V5D(&)Y(')E9F5R96YC92!T;R!C;VYT86EN
M('1H92!R97-U;'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@
M(%1H92!N86UE(&]F('1H92!P87)E;G0@9G)O;2!W:&EC:"!T;R!B96=I;BX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1M87AD97!T:"`@36%X(&]F(&QE=F5L
M<R!O9B!D97!T:"!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`;F]T92!)9B!N
M;W1H:6YG(&ES(')E='5R;F5D('1H870@;65A;G,@=&AE<F4@:7,@;F\@8VAI
M;&0L(&)U=`H@("`@("H@9&]N)W0@9F]R9V5T('1O(&%D9"!T:&4@<&%R96YT
M(&EF(&%N>2!S=6)S97%U96YT(&]P97)A=&EO;G,@87)E"B`@("`@*B!R97%U
M:7)E9"$*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X=')A8W1!;&Q,979E;%1R
M964H)B1O=70L("1P87)E;G0@/2!$051!5%)%15]23T]4+"`D;6%X9&5P=&@@
M/2`M,2D*("`@('L*("`@("`@("!I9B`H)&UA>&1E<'1H(#T](#`I('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&]U
M=%LD<&%R96YT72`]('1R=64["@H@("`@("`@("1K(#T@)'1H:7,M/E]E>'1R
M86-T3VYE3&5V96PH)'!A<F5N="D["B`@("`@("`@9F]R96%C:"`H)&L@87,@
M)&]B:F5C="`]/B`D=BD@>PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O
M=71;)'!A<F5N=%TI*2!["B`@("`@("`@("`@("`@("`D;W5T6R1P87)E;G1=
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T6R1P
M87)E;G1=6R1O8FIE8W1=(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/E]E
M>'1R86-T06QL3&5V96Q4<F5E*"1O=71;)'!A<F5N=%TL("1O8FIE8W0L("1M
M87AD97!T:"`M(#$I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($5X=')A8W0@86QL(&QE=F5L<R!O9B!D871A+"!S=&%R=&EN9R!F<F]M(&%N
M>2!P87)E;G0@:6X*("`@("`J('1H92!T<F5E+@H@("`@("H*("`@("`J(%)E
M='5R;F5D(&%R<F%Y(&9O<FUA=#H@87)R87DH<&%R96YT(#T^(&%R<F%Y*&-H
M:6QD(#T^('1R=64I*0H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;W5T
M("`@("`@("`@5&AI<R!I<R!A;B!I=&5R871I;F<@9G5N8W1I;VXL('-O("1O
M=70@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<&%S<V5D
M(&)Y(')E9F5R96YC92!T;R!C;VYT86EN('1H92!R97-U;'0N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<&%R96YT("`@(%1H92!N86UE(&]F('1H92!P87)E
M;G0@9G)O;2!W:&EC:"!T;R!B96=I;BX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1M87AD97!T:"`@36%X(&YU;6)E<B!O9B!L979E;',@;V8@9&5P=&@@=&\@
M8VAE8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E>'1R86-T06QL3&5V96Q,
M:7-T*"8D;W5T+"`D<&%R96YT(#T@1$%40512145?4D]/5"P@)&UA>&1E<'1H
M(#T@+3$I"B`@("!["B`@("`@("`@:68@*"1M87AD97!T:"`]/2`P*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O
M(%1H:7,@:7,@<F5D=6YD86YT(&UO<W0@;V8@=&AE('1I;64L('-O(&UA:V4@
M<W5R92!W92!N965D('1O"B`@("`@("`@+R\@9&\@:70N"B`@("`@("`@:68@
M*&5M<'1Y*"1O=71;)'!A<F5N=%TI*2!["B`@("`@("`@("`@("1O=71;)'!A
M<F5N=%T@/2`D=&AI<RT^9V5T3F%M92@D<&%R96YT*3L*("`@("`@("!]"@H@
M("`@("`@("1K(#T@87)R87E?:V5Y<R@D=&AI<RT^7V5X=')A8W1/;F5,979E
M;"@D<&%R96YT*2D["B`@("`@("`@9F]R96%C:"`H)&L@87,@)&]B:F5C="D@
M>PH@("`@("`@("`@("`D;W5T6R1O8FIE8W1=(#T@)'1H:7,M/F=E=$YA;64H
M)&]B:F5C="D["B`@("`@("`@("`@("1T:&ES+3Y?97AT<F%C=$%L;$QE=F5L
M3&ES="@D;W5T+"`D;V)J96-T+"`D;6%X9&5P=&@@+2`Q*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8VAI;&0G<R!D:7)E
M8W0@<&%R96YT($E$+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D8VAI
M;&0@($5I=&AE<B!T:&4@;V)J96-T+"!A;B!A<G)A>2!C;VYT86EN:6YG('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@<&%T:"!E;&5M96YT<RP@
M;W(@=&AE(&]B:F5C="!N86UE(&9O<B!W:&EC:`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@=&\@;&]O:R!U<"!T:&4@<&%R96YT)W,@240N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=6YI<75E($E$(&]F('1H
M92!P87)E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N="@D8VAI
M;&0I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&-H:6QD+"`G1&%T851R965/
M8FIE8W0G*2D@>PH@("`@("`@("`@("`D8VAI;&0@/2`D8VAI;&0M/F=E=$YA
M;64H*3L*("`@("`@("!]"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E=$ED*"1C
M:&EL9"D["B`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/E]D871A6R1I9%U;)W!A<F5N="==.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&$@)&-H:6QD)W,@9&ER96-T('!A<F5N="!)1"X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VAI;&1)9"`@1V5T('1H
M92!P87)E;G0@;V8@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@=6YI<75E($E$(&]F('1H92!P87)E;G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=$)Y260H)&-H:6QD260I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]L;V%D0GE)9"@D8VAI;&1)9"D["B`@("`@("`@
M<F5T=7)N(&ES<V5T*"1T:&ES+3Y?9&%T85LD8VAI;&1)9%TI(#\*("`@("`@
M("`@("`@)'1H:7,M/E]D871A6R1C:&EL9$ED75LG<&%R96YT)UT@.@H@("`@
M("`@("`@("!014%2.CIR86ES945R<F]R*"1C:&EL9$ED("X@)R!N;W0@9F]U
M;F0G*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@<&%R
M96YT<R!A;&P@=&AE('=A>2!U<"!T;R!T:&4@<F]O="!O8FIE8W0@9F]R"B`@
M("`@*B`D8VAI;&0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&-H
M:6QD("`@5&AE(&YA;64@;V8@=&AE(&-H:6QD"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D9V5T:61S("!)9B!T<G5E+"!R971U<FX@<&%R96YT($E$<SL@;W1H
M97)W:7-E+"!R971U<FX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&YA;65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%MC:&EL9%T@
M6W!A<F5N=%T@:6X@82!T<F5E(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&%R96YT<R@D8VAI;&0L("1G971I9',@/2!F86QS92D*("`@('L*
M("`@("`@("`D<&ED(#T@)'1H:7,M/F=E=%!A<F5N="@D8VAI;&0I.PH@("`@
M("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!A<F5N=',@;F]T(&9O=6YD
M.B`G("X@)'!I9"T^9V5T365S<V%G92@I*3L*("`@("`@("!]"B`@("`@("`@
M)'!N86UE(#T@)'1H:7,M/F=E=$YA;64H)'!I9"D["B`@("`@("`@:68@*"1G
M971I9',I('L*("`@("`@("`@("`@)'!A<F5N=',@/2!A<G)A>2@D<&ED(#T^
M('1R=64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)E;G1S
M(#T@87)R87DH)'!N86UE(#T^('1R=64I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1P:60@(3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("!I9B`H
M)&=E=&ED<RD@>PH@("`@("`@("`@("`@("`@)'!A<F5N='-;)'!I9%T@/2`D
M=&AI<RT^9V5T4&%R96YT<R@D<&YA;64L("1G971I9',I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!A<F5N='-;)'!N86UE72`]
M("1T:&ES+3YG971087)E;G1S*"1P;F%M92P@)&=E=&ED<RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%R96YT<SL*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@<&%R96YT<R!A;&P@
M=&AE('=A>2!U<"!T;R!T:&4@<F]O="!O8FIE8W0@9F]R"B`@("`@*B`D8VAI
M;&0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-H:6QD260@(%1H
M92!I9"!O9B!T:&4@8VAI;&0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F5N
M=',@("`@5&AE(&%R<F%Y+"!A<R!W92!B=6EL9"!I="!U<"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!(&9L870@;&ES="!O9B!A;&P@;V8@=&AE
M('!A<F5N=',@;V8@)&-H:6QD+`H@("`@("H@("`@("`@("`@("`@("`@:&%S
M:&5D(&EN("1I9"`]/B`D;F%M92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%!A<F5N=$QI<W0H)&-H:6QD260L("1P87)E;G1S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("`D<&ED(#T@)'1H:7,M/F=E=%!A<F5N=$)Y260H
M)&-H:6QD260I.PH@("`@("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!A
M<F5N=',@;F]T(&9O=6YD.B`G("X@)'!I9"T^9V5T365S<V%G92@I*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D<&ED("$]($1!5$%44D5%7U)/3U0I('L*
M("`@("`@("`@("`@)'!A<F5N='-;)'!I9%T@/2`D=&AI<RT^9V5T3F%M92@D
M<&ED*3L*("`@("`@("`@("`@)'!A<F5N=',@/2`D=&AI<RT^9V5T4&%R96YT
M3&ES="@D<&ED+"`D<&%R96YT<RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'!A<F5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!P87)E
M;G0@240@<W1R:6YG("AI9#IC:60@9F]R;6%T*2!F;W(@=&AE('-P96-I9FEE
M9"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1O8FIE8W0@
M(%1H92!O8FIE8W0@=&\@<F5T=7)N(&$@<&%R96YT('-T<FEN9R!F;W(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F=\4$5!4E]%<G)O<B`@5&AE($E$
M(")P871H(B!T;R!T:&4@<&%R96YT(&]B:F5C="!O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971087)E;G1)9%-T<FEN9R@D;V)J96-T
M*0H@("`@>PH@("`@("`@("1P=')E92`]("1T:&ES+3YG971087)E;G1S*"1O
M8FIE8W0L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1P=')E92P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'!T<F5E.PH@("`@("`@
M('T*"B`@("`@("`@)'!I9',@/2`G)SL*("`@("`@("!W:&EL92`H*&QI<W0H
M)&ED+"`D<&%R96YT*2`](&5A8V@H)'!T<F5E*2D@)B8@:7-?87)R87DH)'!A
M<F5N="DI('L*("`@("`@("`@("`@)'!I9',@/2`G.B<@+B`D:60@+B`D<&ED
M<SL*("`@("`@("`@("`@)'!T<F5E(#T@)'!A<F5N=#L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<&ED<SL*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@;G5M8F5R(&]F(&-H:6QD<F5N(&%N(&]B:F5C="!H87,L(&]N;'D@
M8V]U;G1I;F<@:6UM961I871E"B`@("`@*B!C:&EL9')E;BP@;F]T(&=R86YD
M8VAI;&1R96XL(&5T8RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'!A
M<F5N="`@16ET:&5R('1H92!O8FIE8W0@;W(@=&AE(&YA;64@9F]R('=H:6-H
M('1O(&-O=6YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AE(&-H
M:6QD<F5N+"!D969A=6QT<R!T;R!T:&4@<F]O=`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("A$051!5%)%15]23T]4*2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3G5M8F5R
M3V9#:&EL9')E;B@D<&%R96YT(#T@1$%40512145?4D]/5"D*("`@('L*("`@
M("`@("!I9B`H:7-?82@D<&%R96YT+"`G1&%T851R965/8FIE8W0G*2D@>PH@
M("`@("`@("`@("`D<&%R96YT(#T@)'!A<F5N="T^9V5T3F%M92@I.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7VQO860H)'!A<F5N="D["B`@("`@("`@
M)&]U="`]("1T:&ES+3Y?97AT<F%C=$]N94QE=F5L*"1T:&ES+3YG971)9"@D
M<&%R96YT*2D["B`@("`@("`@<F5T=7)N(&ES7V%R<F%Y*"1O=70I(#\@8V]U
M;G0H)&]U="D@.B`P.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@
M86X@;V)J96-T(&5X:7-T<R!O<B!N;W0N(%1H92!R;V]T(&5L96UE;G0@1$%4
M0512145?4D]/5"!A;'=A>7,@97AI<W1S+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D;V)J96-T("!4:&4@;F%M92!O9B!T:&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@;V)J96-T
M(&5X:7-T<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E>&ES=',H)&]B:F5C="D*("`@('L*("`@("`@("!I9B`H96UP='DH)&]B
M:F5C="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-?82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@
M>PH@("`@("`@("`@("`D;V)J96-T(#T@)&]B:F5C="T^9V5T3F%M92@I.PH@
M("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D;V)J96-T*2D@>PH@("`@("`@
M("`@("`D;V)J96-T(#T@:6UP;&]D92@G.B<L("1O8FIE8W0I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1O8FIE8W0@/3T@1$%40512145?4D]/5"D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1I
M9$UA<"`](&%R<F%Y7V9L:7`H)'1H:7,M/E]N86UE36%P*3L*("`@("`@("!I
M9B`H:7-S970H)&ED36%P6R1O8FIE8W1=*2D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&]A9"@D;V)J
M96-T*3L*("`@("`@("`D:61-87`@/2!A<G)A>5]F;&EP*"1T:&ES+3Y?;F%M
M94UA<"D["B`@("`@("`@<F5T=7)N(&ES<V5T*"1I9$UA<%LD;V)J96-T72D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&YA;64@;V8@86X@;V)J
M96-T(&9R;VT@:71S(&ED+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1I9"`@5&AE(&ED(&9O<B!W:&EC:"!T;R!L;V]K('5P('1H92!N86UE+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$YA;64H)&ED*0H@("`@>PH@("`@("`@("\J($EF(&YO(&ED(&]R
M(&EF(&ED(&ES(&$@4$5!4B!E<G)O<BP@<F5T=7)N(&YU;&PN("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1I9"D@?'P@:7-?82@D:60L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!C:&5C:VEN9R!N86UE(&]F(')O;W0L(')E='5R;B!$051!5%)%
M15]23T]4+B`J+PH@("`@("`@(&EF("@D:60@/3T@1$%40512145?4D]/5"D@
M>PH@("`@("`@("`@("!R971U<FX@1$%40512145?4D]/5#L*("`@("`@("!]
M"@H@("`@("`@("\J($EF(&9O=6YD(&EN('1H92!N86UE(&UA<"P@<F5T=7)N
M('1H92!N86UE+B`J+PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65-
M87!;)&ED72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;F%M94UA
M<%LD:61=.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]T(&9O=6YD(&EN(&YA
M;64@;6%P+"!T<GD@;&]A9&EN9R!T:&ES(&ED(&EN=&\@=&AE(&YA;64*("`@
M("`@("`@*B!M87`N("HO"B`@("`@("`@)'1H:7,M/E]L;V%D0GE)9"@D:60I
M.PH*("`@("`@("`O*B!)9B!I9"!L;V%D960@<F5T=7)N('1H92!N86UE+"!O
M=&AE<G=I<V4@<F5T=7)N(&YU;&PN("HO"B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3Y?;F%M94UA<%LD:61=*2`_"B`@("`@("`@("`@("1T:&ES+3Y?
M;F%M94UA<%LD:61=(#H*("`@("`@("`@("`@;G5L;#L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@:60@;V8@86X@;V)J96-T(&9R;VT@:71S(&YA
M;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1N86UE("!%:71H97(@
M=&AE(&]B:F5C="P@86X@87)R87D@8V]N=&%I;FEN9R!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@<&%T:"!E;&5M96YT<RP@;W(@=&AE(&]B:F5C
M="!N86UE(&9O<B!W:&EC:`H@("`@("H@("`@("`@("`@("`@("`@("`@("!T
M;R!L;V]K('5P('1H92!I9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971)9"@D;F%M92D*("`@('L*("`@
M("`@("`O*B!#:&5C:R!I9B`D;F%M92!I<R!N;W0@82!S=')I;F<N("HO"B`@
M("`@("`@:68@*&ES7V$H)&YA;64L("=$871A5')E94]B:F5C="<I*2!["B`@
M("`@("`@("`@("\J($1A=&%4<F5E3V)J96-T+"!G970@=&AE('-T<FEN9R!N
M86UE+B`J+PH@("`@("`@("`@("`D;F%M92`]("1N86UE+3YG971.86UE*"D[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1N86UE*2D@>PH@("`@("`@
M("`@("`O*B!0871H(&%R<F%Y+"!I;7!L;V1E('1O(&=E="!T:&4@<W1R:6YG
M(&YA;64N("HO"B`@("`@("`@("`@("1N86UE(#T@:6UP;&]D92@G.B<L("1N
M86UE*3L*("`@("`@("!]"@H@("`@("`@("\J($EF(&-H96-K:6YG(&ED(&]F
M(')O;W0L(')E='5R;B!$051!5%)%15]23T]4+B`J+PH@("`@("`@(&EF("@D
M;F%M92`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@(')E='5R;B!$
M051!5%)%15]23T]4.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@
M=&AE(&YA;64@86-T=6%L;'D@97AI<W1S+"!I9B!N;W0@<F5T=7)N(&$@4$5!
M4@H@("`@("`@("`J(&5R<F]R+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/F5X
M:7-T<R@D;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)&YA;64@+B`G(&1O97,@;F]T(&5X:7-T)RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!&;&EP('1H92!N86UE(&UA<"!T;R!L;V]K('5P('1H92!I
M9"!U<VEN9R!T:&4@;F%M92!A<R!K97DN("HO"B`@("`@("`@)&ED36%P(#T@
M87)R87E?9FQI<"@D=&AI<RT^7VYA;65-87`I.PH@("`@("`@(')E='5R;B`D
M:61-87!;)&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!O
M<F1E<B!P;W-I=&EO;B!O9B!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1C:&EL9"`@16ET:&5R('1H92!O8FIE8W0@;W(@=&AE(&YA
M;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&]B:F5C="=S
M(&]R9&5R('!O<VET:6]N(&]R(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971/<F1E<B@D8VAI;&0I"B`@("!["B`@
M("`@("`@:68@*&ES7V$H)&-H:6QD+"`G1&%T851R965/8FIE8W0G*2D@>PH@
M("`@("`@("`@("`D8VAI;&0@/2`D8VAI;&0M/F=E=$YA;64H*3L*("`@("`@
M("!]"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E=$ED*"1C:&EL9"D["B`@("`@
M("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D:60["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-S970H
M)'1H:7,M/E]D871A6R1I9%U;)V]R9&5R)UTI(#\*("`@("`@("`@("`@)'1H
M:7,M/E]D871A6R1I9%U;)V]R9&5R)UT@.@H@("`@("`@("`@("!N=6QL.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5P;&%C92!A;&P@;V-C=7)E;F-E<R!O
M9B`G.B<@:6X@86X@;V)J96-T(&YA;64@=VET:"`G+B<N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N8V]D960@
M;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC;V1E3F%M92@D;F%M92D*
M("`@('L*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)SHG+"`G+B<L("1N
M86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<VAO<G0@;F%M
M92!O9B!A;B!O8FIE8W0L(')E='5R;G,@;VYL>2!T:&4@;&%S="!P;W)T:6]N
M(&]F('1H90H@("`@("H@9G5L;"!N86UE+B!&;W(@9&ES<&QA>2!P=7)P;W-E
M<R!O;FQY+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;V)J96-T)W,@<VAO
M<G0@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VAO<G1.86UE*"1N
M86UE*0H@("`@>PH@("`@("`@("\J($EF('1H97)E(&%R92!S979E<F%L(&-O
M;7!O;F5N=',@=&\@=&AE(&YA;64L(&5X<&QO9&4@86YD(&=E="!T:&4*("`@
M("`@("`@*B!L87-T(&]N92P@;W1H97)W:7-E(&IU<W0@<F5T=7)N('1H92!N
M86UE+B`J+PH@("`@("`@(&EF("AS=')P;W,H)&YA;64L("<Z)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("1N86UE(#T@97AP;&]D92@G.B<L("1N86UE
M*3L*("`@("`@("`@("`@)&YA;64@/2!A<G)A>5]P;W`H)&YA;64I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&YA;64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@=')E92!S;W)T960@8GD@=&AE('-P96-I9FEE9"!A
M='1R:6)U=&4@;F%M92!A;F0O;W(@:V5Y+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1R;V]T("`@("`@("`@5VAI8V@@<&]R=&EO
M;B!O9B!T:&4@=')E92!T;R!S;W)T+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1E9F%U;'1S('1O(&%L;"!O9B!I="X*("`@("`J($!P
M87)A;2!B;V]L96%N("1L;V%D5')E92`@("!3;W)T('1H92!T<F5E('-T87)T
M:6YG(&%T("1R;V]T+"!O<B!J=7-T('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E<75E<W1E9"!L979E;"!A;F0@9&ER96-T('!A
M<F5N=',_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F
M875L=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V]R=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN
M9RX*("`@("`J($!P87)A;2!S=')I;F<@)'-O<G1B>5]K97D@("!!='1R:6)U
M=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1D:7)E8W1I;VX@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4V]R=&5D5')E92@D<F]O="P@)&QO8614
M<F5E(#T@9F%L<V4L("1S;W)T8GE?;F%M92`](&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1S;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C=&EO
M;B`](#`I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M86X@;V)J96-T+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D;V)J96-T("`@("`@("!4:&4@;V)J96-T('1O
M(&%D9"`H<W1R:6YG(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@1&%T851R965/8FIE8W0I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&ED7V%S7VYA;64@(%1R=64@;W(@9F%L<V4@=&\@:6YD:6-A=&4@:68@;V)J
M96-T($E$(&ES('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8F4@=7-E9"!A<R!O8FIE8W0@;F%M92X@57-E9"!I;B!S:71U871I;VYS
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VAE<F4@=&AE
M<F4@:7,@;F\@879A:6QA8FQE('5N:7%U92!I;G!U="!F;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0@;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D*"1O8FIE8W0L("1I9%]A<U]N86UE(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO
M="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@("1N86UE("!4
M:&4@<VAO<G0@;V)J96-T(&YA;64N"B`@("`@*B!`<&%R86T@:6YT96=E<B`@
M)&ED("`@(%1H92!N97<@;V)J96-T)W,@=6YI<75E($E$+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@("1P:60@("!4:&4@=6YI<75E($E$(&]F('1H92!O8FIE
M8W0G<R!P87)E;G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`@)&]R9&5R(%1H
M92!O<F1E<FEN9R!D871A(&9O<B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&0H
M)&YA;64L("1I9"P@)'!I9"P@)&]R9&5R(#T@)R<I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]D871A6R1I9%T@/2!A<G)A>2@G;F%M92<@/3X@)&YA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R96YT)R`]/B`D
M<&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]R9&5R
M)R`]/B`D;W)D97(I.PH@("`@("`@("1T:&ES+3Y?;F%M94UA<%LD:61=(#T@
M)&YA;64["@H@("`@("`@("\J(%-H:69T(&%L;VYG('1H92!O<F1E<B!P;W-I
M=&EO;G,N("HO"B`@("`@("`@)'1H:7,M/E]R96]R9&5R*"1P:60L("1O<F1E
M<BP@)&ED*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971R:65V92!D871A(&9O<B!A;B!O8FIE8W0@9G)O;2!T:&4@
M:&]R9&5?9&%T871R965?871T<FEB=71E<PH@("`@("H@=&%B;&4N"B`@("`@
M*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@?"!A<G)A>2`D8VED("!4:&4@;V)J96-T(&ED('1O(&9E=&-H+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!A;B!A<G)A>2!O
M9B!O8FIE8W0@:61S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@
M:&%S:"!O9B!A='1R:6)U=&5S+"!O<B!A(&UU;'1I+6QE=F5L(&AA<V@*("`@
M("`J("`@("`@("`@("`@("`@(&]F(&]B:F5C="!I9',@/3X@=&AE:7(@871T
M<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T071T<FEB=71E<R@D
M8VED*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N
M;W0@<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!N=6UB97(@;V8@;V)J96-T<R!M871C:&EN9R!A('-E="!O9B!A='1R
M:6)U=&4@8W)I=&5R:6$N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0'-E92!B=6EL9$%T=')I8G5T95%U97)Y*"D*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@("`D8W)I=&5R:6$@("!4:&4@87)R87D@;V8@
M8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@("!4
M:&4@<&%R96YT(&YO9&4@=&\@<W1A<G0@<V5A<F-H:6YG(&9R;VTN"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("!2971U<FX@86QL(&QE=F5L
M<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C:&EL9')E;B!O9B`D<&%R96YT/R!$969A=6QT<R!T;R!A
M;&P@;&5V96QS+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)')E<W1R:6-T("`@
M3VYL>2!R971U<FX@871T<FEB=71E<R!W:71H('1H92!S86UE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A='1R:6)U=&5?;F%M92!O<B!A
M='1R:6)U=&5?:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT0GE!='1R
M:6)U=&5S*"1C<FET97)I82P@)'!A<F5N="`]($1!5$%44D5%7U)/3U0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D86QL3&5V96QS(#T@=')U
M92P@)')E<W1R:6-T(#T@)VYA;64G*0H@("`@>PH@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=N;W0@<W5P<&]R=&5D)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<V5T(&]F(&]B:F5C="!I9',@8F%S960@
M;VX@82!S970@;V8@871T<FEB=71E(&-R:71E<FEA+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H*("`@("`J($!S964@8G5I;&1!='1R:6)U=&51
M=65R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&-R:71E<FEA
M("`@("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D<&%R96YT("`@("`@(%1H92!P87)E;G0@;F]D92!T;R!S=&%R="!S
M96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&Q,979E
M;',@("`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&EL9')E;B!O
M9B`D<&%R96YT/R!$969A=6QT<R!T;R!A;&P@;&5V96QS+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)')E<W1R:6-T("`@("!/;FQY(')E='5R;B!A='1R:6)U
M=&5S('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@871T<FEB=71E7VYA;64@;W(@871T<FEB=71E7VED+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&9R;VT@("`@("`@("!4:&4@;V)J96-T('1O
M('-T87)T('1O(&9E=&-H:6YG"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]U
M;G0@("`@("`@(%1H92!N=6UB97(@;V8@;V)J96-T<R!T;R!F971C:`H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M
M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@("!3;W)T(&1I
M<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T0GE!='1R:6)U=&5S*"1C<FET97)I82P@)'!A<F5N="`]($1!5$%44D5%
M7U)/3U0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L;$QE=F5L
M<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RP@)&9R;VT@/2`P+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N="`](#`L("1S;W)T8GE?
M;F%M92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O
M<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V]R=',@241S(&)Y(&%T=')I8G5T92!V
M86QU97,N($E$<R!W:71H;W5T(&%T=')I8G5T97,@=VEL;"!B92!A9&1E9"!T
M;PH@("`@("H@=&AE(&5N9"!O9B!T:&4@<V]R=&5D(&QI<W0N"B`@("`@*@H@
M("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1U
M;F]R9&5R961?:61S("!!<G)A>2!O9B!I9',@=&\@<V]R="X*("`@("`J($!P
M87)A;2!A<G)A>2`D<V]R=&)Y7VYA;64@("`@071T<FEB=71E(&YA;64@=&\@
M=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?
M:V5Y("`@("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@
M("`J($!P87)A;2!A<G)A>2`D9&ER96-T:6]N("`@("`@4V]R="!D:7)E8W1I
M;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`M
M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#$@+2!D97-C96YD:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@4V]R=&5D(&ED<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$)Y071T
M<FEB=71E<R@D=6YO<F1E<F5D7VED<RP@)'-O<G1B>5]N86UE(#T@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]K97D@/2!N
M=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@57!D871E('1H92!D871A(&EN(&%N(&]B:F5C="X@1&]E<R!N
M;W0@8VAA;F=E('1H92!O8FIE8W0G<PH@("`@("H@<&%R96YT(&]R(&YA;64L
M(&IU<W0@<V5R:6%L:7IE9"!D871A(&]R(&%T=')I8G5T97,N"B`@("`@*@H@
M("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E
M("1O8FIE8W0@($$@1&%T851R964@;V)J96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!U<&1A=&5$871A*"1O8FIE8W0I"B`@("!["B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-O<G0@='=O(&]B:F5C=',@8GD@=&AE:7(@;W)D97(@
M9FEE;&0L(&%N9"!I9B!T:&%T(&ES('1H92!S86UE+`H@("`@("H@86QP:&%B
M971I8V%L;'D@*&-A<V4@:6YS96YS:71I=F4I(&)Y(&YA;64N"B`@("`@*@H@
M("`@("H@66]U(&YE=F5R(&-A;&P@=&AI<R!F=6YC=&EO;CL@:70G<R!U<V5D
M(&EN('5A<V]R="@I(&-A;&QS+B!$;PH@("`@("H@3D]4('5S92!U<V]R="@I
M.R!Y;W4G;&P@;&]S92!K97D@/3X@=F%L=64@87-S;V-I871I;VYS+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D82`@5&AE(&9I<G-T(&]B:F5C=`H@
M("`@("H@0'!A<F%M(&%R<F%Y("1B("!4:&4@<V5C;VYD(&]B:F5C=`H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@,2!I9B`D82!S:&]U;&0@8F4@
M9FER<W0L"B`@("`@*B`@("`@("`@("`@("`@("`@+3$@:68@)&(@<VAO=6QD
M(&)E(&9I<G-T+`H@("`@("H@("`@("`@("`@("`@("`@("`P(&EF('1H97D@
M87)E(&5N=&ER96QY(&5Q=6%L+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VUP
M*"1A+"`D8BD*("`@('L*("`@("`@("!I9B`H)&%;)V]R9&5R)UT@/B`D8ELG
M;W)D97(G72D@>PH@("`@("`@("`@("!R971U<FX@,3L*("`@("`@("!](&5L
M<V5I9B`H)&%;)V]R9&5R)UT@/"`D8ELG;W)D97(G72D@>PH@("`@("`@("`@
M("!R971U<FX@+3$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N('-T<F-A<V5C;7`H)&%;)VYA;64G72P@)&);)VYA;64G72D["B`@("`@
M("`@?0H@("`@?0H*("`@("`O*BH*("`@("`J(%-O<G1S('1W;R!O8FIE8W1S
M(&)Y('1H96ER('-O<G1E<B!H87-H(&9I96QD+@H@("`@("H*("`@("`J(%EO
M=2!N979E<B!C86QL('1H:7,@9G5N8W1I;VX[(&ET)W,@=7-E9"!I;B!U87-O
M<G0H*2!C86QL<RX@1&\@3D]4('5S90H@("`@("H@=7-O<G0H*3L@>6]U)VQL
M(&QO<V4@:V5Y(#T^('9A;'5E(&%S<V]C:6%T:6]N<RX*("`@("`J"B`@("`@
M*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A("!4:&4@9FER<W0@;V)J96-T"B`@("`@*B!`<&%R86T@87)R87D@)&(@
M(%1H92!S96-O;F0@;V)J96-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M9V5R("`Q(&EF("1A('-H;W5L9"!B92!F:7)S="P*("`@("`J("`@("`@("`@
M("`@("`@("`M,2!I9B`D8B!S:&]U;&0@8F4@9FER<W0L"B`@("`@*B`@("`@
M("`@("`@("`@("`@(#`@:68@=&AE>2!A<F4@96YT:7)E;'D@97%U86PN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;7!3;W)T960H)&$L("1B*0H@("`@>PH@
M("`@("`@(&EF("@D85LG<V]R=&5R)UU;)'1H:7,M/E]S;W)T2&%S:%T@/"`D
M8ELG<V]R=&5R)UU;)'1H:7,M/E]S;W)T2&%S:%TI('L*("`@("`@("`@("`@
M<F5T=7)N(#$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(#`["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@<F5T=7)N(&$@8V]N8W)E=&4@1&%T851R964@:6YS=&%N8V4@8F%S960@
M;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E
M<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@1&%T851R964@<W5B8VQA<W,@=&\@
M<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%1H:7,@:7,@
M8F%S960@;VX@=&AE('-T;W)A9V4@9')I=F5R("@D9')I=F5R*2X@5&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]D92!I<R!D>6YA;6EC86QL
M>2!I;F-L=61E9"X@268@)&1R:79E<B!I<R!A;B!A<G)A>2P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!T:&5N('=E('=I;&P@;&]O:R!I;B`D9')I
M=F5R6S!=+VQI8B]$871A5')E92\@9F]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@=&AE('-U8F-L87-S(&EM<&QE;65N=&%T:6]N(&YA;65D("1D
M<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@($AE<F4L('=E(&YE960@)V=R;W5P)R`](&$@<W1R
M:6YG('1H870@9&5F:6YE<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M('1O<"UL979E;"!G<F]U<',@;V8@;V)J96-T<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N($1A=&%4<F5E("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!$
M871A5')E92!I;G-T86YC92P@;W(@9F%L<V4*("`@("`J("`@("`@("`@("`@
M("`@("`@(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C
M=&]R>2@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("`D
M9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("AI<U]N
M=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@/2!(;W)D93HZ
M9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1D<FEV97(I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I*2!["B`@("`@("`@("`@
M("1D<FEV97(@/2`G;G5L;"<["B`@("`@("`@?0H*("`@("`@("!I;F-L=61E
M7V]N8V4@)TAO<F1E+T1A=&%4<F5E+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@
M("`@("`@("1C;&%S<R`]("=$871A5')E95\G("X@)&1R:79E<CL*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&1T
M(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&1T(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI
M=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@
M?0H@"B`@("`@("`@<F5T=7)N("1D=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E
M($1A=&%4<F5E(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@*B`D9')I=F5R+@H@
M("`@("H*("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N
M8V4@:68@;F\@1&%T851R964@:6YS=&%N8V4@=VET:"!T:&4@<V%M90H@("`@
M("H@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J
M(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@1&%T851R964@<V]U
M<F-E<R`H86YD+"!T:'5S+"!M=6QT:7!L90H@("`@("H@1&%T851R964@:6YS
M=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)D1A=&%4<F5E.CIS:6YG
M;&5T;VXH*3L*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@
M5'EP92!O9B!C;VYC<F5T92!$871A5')E92!S=6)C;&%S<R!T;R!R971U<FXL
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8F%S960@;VX@<W1O<F%G
M92!D<FEV97(@*"1D<FEV97(I+B!4:&4@8V]D92!I<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+B!)9B`D9')I
M=F5R(&ES(&%N(&%R<F%Y+"!T:&5N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@;&]O:R!I;B`D9')I=F5R6S!=+VQI8B]$871A5')E92\@9F]R('-U
M8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6UP;&5M96YT
M871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@
M8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E92`@5&AE(&-O;F-R971E
M($1A=&%4<F5E(')E9F5R96YC92P@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M
M<R`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["B`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@/2!(;W)D
M93HZ9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1D<FEV97(I.PH@("`@
M("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D
M9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N
M8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S
M:6=N871U<F5=(#T@)D1A=&%4<F5E.CIF86-T;W)Y*"1D<FEV97(L("1P87)A
M;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I
M9VYA='5R95T["B`@("!]"@I]"@HO*BH*("H@0VQA<W,@=&AA="!C86X@8F4@
M97AT96YD960@=&\@<V%V92!A<F)I=')A<GD@:6YF;W)M871I;VX@87,@<&%R
M="!O9B!A('-T;W)E9`H@*B!O8FIE8W0N"B`J"B`J($!A=71H;W(@(%-T97!H
M86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95]$871A5')E90H@*B\*8VQA
M<W,@1&%T851R965/8FIE8W0@>PH*("`@("\J*@H@("`@("H@5&AI<R!O8FIE
M8W0G<R!$871A5')E92!I;G-T86YC92X*("`@("`J"B`@("`@*B!`=F%R($1A
M=&%4<F5E"B`@("`@*B\*("`@('9A<B`D9&%T871R964["@H@("`@+RHJ"B`@
M("`@*B!+97DM=F%L=64@:&%S:"!T:&%T('=I;&P@8F4@<V5R:6%L:7IE9"X*
M("`@("`J"B`@("`@*B!`<V5E(&=E=$1A=&$H*0H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&1A=&$@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@5&AE('5N:7%U92!N86UE(&]F('1H:7,@;V)J96-T+@H@("`@("H@
M5&AE<V4@;F%M97,@:&%V92!T:&4@<V%M92!R97%U:7)E;65N=',@87,@;W1H
M97(@;V)J96-T(&YA;65S("T@=&AE>2!M=7-T"B`@("`@*B!B92!U;FEQ=64L
M(&5T8RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)&YA;64["@H@("`@+RHJ"B`@("`@*B!)9B!T:&ES(&]B:F5C="!H87,@
M;W)D97)I;F<@9&%T82P@<W1O<F4@:70@:&5R92X*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1O<F1E<B`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!$871A5')E94]B:F5C="!C;VYS=')U8W1O<BX*("`@
M("`J($IU<W0@<V5T<R!T:&4@)&YA;64@<&%R86UE=&5R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!O8FIE8W0@;F%M92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@1&%T851R965/8FIE8W0H)&YA;64I"B`@("![
M"B`@("`@("`@)'1H:7,M/G-E=$YA;64H)&YA;64I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!T:&4@>T!L:6YK($1A=&%4<F5E?2!I;G-T86YC92!U
M<V5D('1O(')E=')I979E('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!$871A5')E92`D9&%T871R964@($$@>T!L:6YK($1A=&%4<F5E?2!I
M;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&%T851R964H)B1D
M871A=')E92D*("`@('L*("`@("`@("`D=&AI<RT^9&%T871R964@/2`F)&1A
M=&%T<F5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;F%M92!O
M9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4
M:&4@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F%M93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@=&AE(&YA;64@;V8@=&AI<R!O8FIE8W0N"B`@
M("`@*@H@("`@("H@3D]413H@57-E('=I=&@@8V%U=&EO;BX@5&AI<R!M87D@
M=&AR;W<@;W5T(&]F('-Y;F,@=&AE(&-A8VAE9"!D871A=')E90H@("`@("H@
M=&%B;&5S(&EF(&YO="!U<V5D('!R;W!E<FQY+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE('1O('-E="!T:&ES(&]B:F5C
M="=S(&YA;64@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$YA;64H)&YA
M;64I"B`@("!["B`@("`@("`@)'1H:7,M/FYA;64@/2`D;F%M93L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE('-H;W)T(&YA;64@;V8@=&AI<R!O
M8FIE8W0N"B`@("`@*B!&;W(@9&ES<&QA>2!P=7)P;W-E<R!O;FQY+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;V)J96-T)W,@<VAO<G0@
M;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VAO<G1.86UE*"D*("`@
M('L*("`@("`@("!R971U<FX@1&%T851R964Z.F=E=%-H;W)T3F%M92@D=&AI
M<RT^;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!)1"!O
M9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&]B:F5C="=S($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971)9"@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A=')E92T^9V5T260H
M)'1H:7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@9&%T82!A
M<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@:6YT97)N
M86P@9&%T82!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%T82@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@9&%T82!A<G)A>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@(%1H92!D871A(&%R<F%Y('1O('-T;W)E(&EN=&5R
M;F%L;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1A=&$H)&1A=&$I"B`@
M("!["B`@("`@("`@)'1H:7,M/F1A=&$@/2`D9&%T83L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE(&]R9&5R(&]F('1H:7,@;V)J96-T(&EN(&ET
M<R!O8FIE8W0@8V]L;&5C=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D;W)D97(*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W)D97(H)&]R
M9&5R*0H@("`@>PH@("`@("`@("1T:&ES+3YO<F1E<B`]("1O<F1E<CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AI<R!O8FIE8W0G<R!P87)E
M;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@("!3=6)C
M;&%S<R!O9B!$871A5')E94]B:F5C="!T;R!U<V4N($1E9F%U;'1S('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T+B!.
M=6QL(&9O<F-E<R!T:&4@9')I=F5R('1O(&QO;VL*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@:6YT;R!T:&4@871T<FEB=71E<R!T86)L92!T;R!D
M971E<FUI;F4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('-U
M8F-L87-S('1O('5S92X@268@;F]N92!I<R!F;W5N9"!I="!U<V5S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T+@H@("`@
M("H*("`@("`J($!R971U<FX@1&%T851R965/8FIE8W0@(%1H:7,@;V)J96-T
M)W,@<&%R96YT"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971087)E;G0H)&-L
M87-S(#T@)T1A=&%4<F5E3V)J96-T)RD*("`@('L*("`@("`@("`D:60@/2`D
M=&AI<RT^9&%T871R964M/F=E=%!A<F5N="@D=&AI<RD["B`@("`@("`@:68@
M*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D:60["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^9&%T871R
M964M/F=E=$]B:F5C=$)Y260H)&ED+"`D8VQA<W,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A(&-H:6QD(&]F('1H:7,@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@8VAI
M;&0G<R!N86UE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@
M($EF('1R=64@86YD(&YO(&-H:6QD('=I=&@@=&AE(&=I=F5N(&YA;64*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E>&ES=',L(&]N92!G
M971S(&-R96%T960N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971#:&EL9"@D
M;F%M92P@)&%U=&]C<F5A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@("1N86UE
M(#T@)'1H:7,M/F=E=%-H;W)T3F%M92@I("X@)SHG("X@)&YA;64["@H@("`@
M("`@("\J($EF('1H92!C:&EL9"!S:&]U;&1N)W0@9V5T(&-R96%T960L('=E
M(&1O;B=T(&-H96-K(&9O<B!I=',*("`@("`@("`@*B!E>&ES=&%N8V4@=&\@
M<F5T=7)N('1H92`B;F]T(&9O=6YD(B!E<G)O<B!O9@H@("`@("`@("`J(&=E
M=$]B:F5C="@I+B`J+PH@("`@("`@(&EF("@A)&%U=&]C<F5A=&4@?'P@)'1H
M:7,M/F1A=&%T<F5E+3YE>&ES=',H)&YA;64I*2!["B`@("`@("`@("`@("1C
M:&EL9"`]("8D=&AI<RT^9&%T871R964M/F=E=$]B:F5C="@D;F%M92D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-H:6QD(#T@)FYE=R!$871A
M5')E94]B:F5C="@D;F%M92D["B`@("`@("`@("`@("1C:&EL9"T^<V5T1&%T
M851R964H)'1H:7,M/F1A=&%T<F5E*3L*("`@("`@("`@("`@)'1H:7,M/F1A
M=&%T<F5E+3YA9&0H)&-H:6QD*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D8VAI;&0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E<R!A;GD@8VAA
M;F=E<R!T;R!T:&ES(&]B:F5C="!T;R!T:&4@8F%C:V5N9"!P97)M86YE;G1L
M>2X@3F5W(&]B:F5C=',*("`@("`J(&%R92!A9&1E9"!I;G-T96%D+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^9&%T871R964M/F5X:7-T<R@D=&AI
M<RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD871A=')E92T^=7!D
M871E1&%T82@D=&AI<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YD871A=')E92T^861D*"1T:&ES*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@=&AI<R!O8FIE8W0@9G)O
M;2!T:&4@8F%C:V5N9"!P97)M86YE;G1L>2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@4$5!4E]%<G)O<B!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^9&%T871R964M/G)E;6]V92@D=&AI<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'971S(&]N92!O9B!T:&4@871T<FEB=71E<R!O
M9B!T:&4@;V)J96-T+"!O<B!N=6QL(&EF(&ET(&ES;B=T(&1E9FEN960N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D871T<FEB=71E("!4:&4@871T
M<FEB=71E('1O(&=E="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M:&4@=F%L=64@;V8@=&AE(&%T=')I8G5T92P@;W(@;G5L;"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T*"1A='1R:6)U=&4I"B`@("!["B`@("`@("`@<F5T
M=7)N(&ES<V5T*"1T:&ES+3YD871A6R1A='1R:6)U=&5=*0H@("`@("`@("`@
M("`_("1T:&ES+3YD871A6R1A='1R:6)U=&5="B`@("`@("`@("`@(#H@;G5L
M;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@;VYE(&]F('1H92!A='1R
M:6)U=&5S(&]F('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D871T<FEB=71E("!4:&4@871T<FEB=71E('1O('-E="X*("`@("`J
M($!P87)A;2!M:7AE9"`D=F%L=64@("`@("`@5&AE('9A;'5E(&9O<B`D871T
M<FEB=71E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&%T=')I8G5T92P@
M)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3YD871A6R1A='1R:6)U=&5=
M(#T@)'9A;'5E.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M1&%T92YP:'``````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#,S-3,P`#$P-#$W,S8R-S<S`#`Q-S8R-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*9&5F:6YE*"=(3U)$
M15]$051%7U-53D1!62<L("`@(#`I.PID969I;F4H)TA/4D1%7T1!5$5?34].
M1$%9)RP@("`@,2D["F1E9FEN92@G2$]21$5?1$%415]454531$%9)RP@("`R
M*3L*9&5F:6YE*"=(3U)$15]$051%7U=%1$Y%4T1!62<L(#,I.PID969I;F4H
M)TA/4D1%7T1!5$5?5$A54E-$05DG+"`@-"D["F1E9FEN92@G2$]21$5?1$%4
M15]&4DE$05DG+"`@("`U*3L*9&5F:6YE*"=(3U)$15]$051%7U-!5%521$%9
M)RP@(#8I.PH*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?4U5.1$%9)RP@("`@
M,2D["F1E9FEN92@G2$]21$5?1$%415]-05-+7TU/3D1!62<L("`@(#(I.PID
M969I;F4H)TA/4D1%7T1!5$5?34%32U]454531$%9)RP@("`T*3L*9&5F:6YE
M*"=(3U)$15]$051%7TU!4TM?5T5$3D531$%9)RP@."D["F1E9FEN92@G2$]2
M1$5?1$%415]-05-+7U1(55)31$%9)RP@,38I.PID969I;F4H)TA/4D1%7T1!
M5$5?34%32U]&4DE$05DG+"`@(#,R*3L*9&5F:6YE*"=(3U)$15]$051%7TU!
M4TM?4T%455)$05DG+"`V-"D["F1E9FEN92@G2$]21$5?1$%415]-05-+7U=%
M14M$05E3)RP@-C(I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]7145+14Y$
M)RP@(#8U*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?04Q,1$%94R<L(#$R
M-RD["@ID969I;F4H)TA/4D1%7T1!5$5?34%32U]314-/3D0G+"`@("`Q*3L*
M9&5F:6YE*"=(3U)$15]$051%7TU!4TM?34E.551%)RP@("`@,BD["F1E9FEN
M92@G2$]21$5?1$%415]-05-+7TA/55(G+"`@("`@(#0I.PID969I;F4H)TA/
M4D1%7T1!5$5?34%32U]$05DG+"`@("`@("`X*3L*9&5F:6YE*"=(3U)$15]$
M051%7TU!4TM?34].5$@G+"`@("`Q-BD["F1E9FEN92@G2$]21$5?1$%415]-
M05-+7UE%05(G+"`@("`@,S(I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]!
M3$Q005)44R<L(#8S*3L*"B\J*@H@*B!(;W)D92!$871E('=R87!P97(O;&]G
M:6,@8VQA<W,L(&EN8VQU9&EN9R!S;VUE(&-A;&-U;&%T:6]N"B`J(&9U;F-T
M:6]N<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T92]$871E+G!H<"QV
M(#$N."XQ,"XV(#(P,#4O,3(O,S$@,C$Z-3`Z,#0@8VAU8VL@17AP("0*("H*
M("H@0'!A8VMA9V4@2&]R9&5?1&%T90H@*B\*8VQA<W,@2&]R9&5?1&%T92![
M"@H@("`@+RHJ"B`@("`@*B!996%R"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D>65A<CL*"B`@("`O*BH*("`@("`J($UO
M;G1H"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D;6]N=&@["@H@("`@+RHJ"B`@("`@*B!$87D*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1M9&%Y.PH*("`@("\J*@H@
M("`@("H@2&]U<@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO
M"B`@("!V87(@)&AO=7(@/2`P.PH*("`@("\J*@H@("`@("H@36EN=71E"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D;6EN
M(#T@,#L*"B`@("`O*BH*("`@("`J(%-E8V]N9`H@("`@("H*("`@("`J($!V
M87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)'-E8R`](#`["@H@("`@+RHJ
M"B`@("`@*B!"=6EL9"!A(&YE=R!D871E(&]B:F5C="X@268@)&1A=&4@8V]N
M=&%I;G,@9&%T92!P87)T<RP@=7-E('1H96T*("`@("`J('1O(&EN:71I86QI
M>F4@=&AE(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?1&%T
M92@D9&%T92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D
M871E*2!\?"!I<U]O8FIE8W0H)&1A=&4I*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1D871E(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@
M:68@*&EN7V%R<F%Y*"1K97DL(&%R<F%Y*"=Y96%R)RP@)VUO;G1H)RP@)VUD
M87DG+"`G:&]U<B<L("=M:6XG+"`G<V5C)RDI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/B1K97D@/2`H:6YT*21V86P["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H(6ES7VYU;&PH
M)&1A=&4I*2!["B`@("`@("`@("`@("\O($UA=&-H(%E965DM34TM1$0@2$@Z
M34TZ4U,@86YD(%E965E-341$2$A-35-3+@H@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+RA<9'LT?2DM/RA<9'LR?2DM/RA<9'LR?2D@/RA<9'LR?2DZ
M/RA<9'LR?2DZ/RA<9'LR?2DO)RP@)&1A=&4L("1P87)T<RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YY96%R(#T@*&EN="DD<&%R='-;,5T["B`@("`@
M("`@("`@("`@("`D=&AI<RT^;6]N=&@@/2`H:6YT*21P87)T<ULR73L*("`@
M("`@("`@("`@("`@("1T:&ES+3YM9&%Y(#T@*&EN="DD<&%R='-;,UT["B`@
M("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`]("AI;G0I)'!A<G1S6S1=.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/FUI;B`]("AI;G0I)'!A<G1S6S5=.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E8R`]("AI;G0I)'!A<G1S6S9=.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@5')Y(&%S
M(&$@=&EM97-T86UP+@H@("`@("`@("`@("`@("`@)'!A<G1S(#T@0&=E=&1A
M=&4H)&1A=&4I.PH@("`@("`@("`@("`@("`@:68@*"1P87)T<RD@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YY96%R(#T@)'!A<G1S6R=Y96%R)UT[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUO;G1H(#T@)'!A<G1S6R=M
M;VXG73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;61A>2`]("1P87)T
M<ULG;61A>2==.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R(#T@
M)'!A<G1S6R=H;W5R<R==.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM
M:6X@/2`D<&%R='-;)VUI;G5T97,G73L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5C(#T@)'!A<G1S6R=S96-O;F1S)UT["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE('5N:7@@=&EM97-T86UP(')E<')E<V5N=&%T:6]N
M(&]F('1H:7,@9&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M($$@=6YI>"!T:6UE<W1A;7`N"B`@("`@*B\*("`@(&9U;F-T:6]N('1I;65S
M=&%M<"@I"B`@("!["B`@("`@("`@<F5T=7)N($!M:W1I;64H)'1H:7,M/FAO
M=7(L("1T:&ES+3YM:6XL("1T:&ES+3YS96,L("1T:&ES+3YM;VYT:"P@)'1H
M:7,M/FUD87DL("1T:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@=6YI>"!T:6UE<W1A;7`@<F5P<F5S96YT871I;VX@;V8@
M=&AI<R!D871E+"`Q,CHP,&%M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@02!U;FEX('1I;65S=&%M<"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&%T97-T86UP*"D*("`@('L*("`@("`@("!R971U<FX@0&UK=&EM92@P+"`P
M+"`P+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YM9&%Y+"`D=&AI<RT^>65A<BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&ES3&5A<%EE87(H)'EE87(I"B`@("!["B`@("`@("`@:68@*'-T
M<FQE;B@D>65A<BD@(3T@-"!\?"!P<F5G7VUA=&-H*"<O7$0O)RP@)'EE87(I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`H*"1Y96%R("4@-"`]/2`P("8F("1Y96%R("4@,3`P("$]
M(#`I('Q\("1Y96%R("4@-#`P(#T](#`I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@9&%Y(&]F('1H92!Y96%R("@Q+3,V-BD@=&AA="!C
M;W)R97-P;VYD<R!T;R!T:&4*("`@("`J(&9I<G-T(&1A>2!O9B!T:&4@9VEV
M96X@=V5E:RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=V5E:R`@
M5&AE('=E96L@;V8@=&AE('EE87(@=&\@9FEN9"!T:&4@9FER<W0@9&%Y(&]F
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'EE87(@(%1H92!Y96%R('1O(&-A
M;&-U;&%T92!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@9&%Y(&]F('1H92!Y96%R(&]F('1H92!F:7)S="!D87D@;V8@=&AE(&=I
M=F5N('=E96LN"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I<G-T1&%Y3V97965K
M*"1W965K+"`D>65A<BD*("`@('L*("`@("`@("`D:F%N,2`]("9N97<@2&]R
M9&5?1&%T92AA<G)A>2@G>65A<B<@/3X@)'EE87(L("=M;VYT:"<@/3X@,2P@
M)VUD87DG(#T^(#$I*3L*("`@("`@("`D<W1A<G0@/2`D:F%N,2T^9&%Y3V97
M965K*"D["B`@("`@("`@:68@*"1S=&%R="`^($A/4D1%7T1!5$5?5$A54E-$
M05DI('L*("`@("`@("`@("`@)'-T87)T("T](#<["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`H*"1W965K("H@-RD@+2`H-R`K("1S=&%R="DI("L@,3L*
M("`@('T*"B`@("`O*BH*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BD*("`@('L*("`@("`@
M("!I9B`H)&UO;G1H(#T](#(I('L*("`@("`@("`@("`@:68@*$AO<F1E7T1A
M=&4Z.FES3&5A<%EE87(H)'EE87(I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@,CD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@,C@["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)&UO
M;G1H(#T](#0@?'P@)&UO;G1H(#T](#8@?'P@)&UO;G1H(#T](#D@?'P@)&UO
M;G1H(#T](#$Q*2!["B`@("`@("`@("`@(')E='5R;B`S,#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,S$["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!D87D@;V8@=&AE('=E96L@
M*#`@/2!3=6YD87DL(#8@/2!3871U<F1A>2D@;V8@=&AI<PH@("`@("H@;V)J
M96-T)W,@9&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!D87D@;V8@=&AE('=E96LN"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A>4]F
M5V5E:R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM;VYT:"`^(#(I('L*
M("`@("`@("`@("`@)&UO;G1H(#T@)'1H:7,M/FUO;G1H("T@,CL*("`@("`@
M("`@("`@)'EE87(@/2`D=&AI<RT^>65A<CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;6]N=&@@/2`D=&AI<RT^;6]N=&@@*R`Q,#L*("`@("`@
M("`@("`@)'EE87(@/2`D=&AI<RT^>65A<B`M(#$["B`@("`@("`@?0H*("`@
M("`@("`D9&%Y(#T@*&9L;V]R*"@Q,R`J("1M;VYT:"`M(#$I("\@-2D@*PH@
M("`@("`@("`@("`@("`@)'1H:7,M/FUD87D@*R`H)'EE87(@)2`Q,#`I("L*
M("`@("`@("`@("`@("`@(&9L;V]R*"@D>65A<B`E(#$P,"D@+R`T*2`K"B`@
M("`@("`@("`@("`@("!F;&]O<B@H)'EE87(@+R`Q,#`I("\@-"D@+2`R("H*
M("`@("`@("`@("`@("`@(&9L;V]R*"1Y96%R("\@,3`P*2`K(#<W*3L*"B`@
M("`@("`@<F5T=7)N("AI;G0I*"1D87D@+2`W("H@9FQO;W(H)&1A>2`O(#<I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1A>2!N=6UB
M97(@;V8@=&AE('EE87(@*#`@=&\@,S8U+S,V-BDN"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4:&4@9&%Y(&]F('1H92!Y96%R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D87E/9EEE87(H*0H@("`@>PH@("`@("`@("1M;VYT
M:%1O=&%L<R`](&%R<F%Y*#`L(#,Q+"`U.2P@.3`L(#$R,"P@,34Q+"`Q.#$L
M(#(Q,BP@,C0S+"`R-S,L(#,P-"P@,S,T*3L*("`@("`@("`D9&%Y3V9996%R
M(#T@)'1H:7,M/FUD87D@*R`D;6]N=&A4;W1A;'-;)'1H:7,M/FUO;G1H("T@
M,5T["B`@("`@("`@:68@*$AO<F1E7T1A=&4Z.FES3&5A<%EE87(H)'1H:7,M
M/GEE87(I("8F("1T:&ES+3YM;VYT:"`^(#(I('L*("`@("`@("`@("`@)&1A
M>4]F665A<BLK.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D87E/9EEE
M87(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=E96L@;V8@=&AE
M('EE87(L(&9I<G-T($UO;F1A>2!I<R!F:7)S="!D87D@;V8@9FER<W0*("`@
M("`J('=E96LN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@
M=V5E:R!N=6UB97(N"B`@("`@*B\*("`@(&9U;F-T:6]N('=E96M/9EEE87(H
M*0H@("`@>PH@("`@("`@(')E='5R;B!D871E*"=7)RP@)'1H:7,M/G1I;65S
M=&%M<"@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;G5M
M8F5R(&]F('=E96MS(&EN('1H92!G:79E;B!Y96%R("@U,B!O<B`U,RDN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'EE87(@(%1H92!Y96%R('1O
M(&-O=6YT('1H92!N=6UB97(@;V8@=V5E:W,@:6XN"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("1N=6U7965K<R`@("`@(%1H92!N=6UB97(@;V8@
M=V5E:W,@:6X@)'EE87(N"B`@("`@*B\*("`@(&9U;F-T:6]N('=E96MS26Y9
M96%R*"1Y96%R*0H@("`@>PH@("`@("`@("\O($9I;F0@=&AE(&QA<W0@5&AU
M<G-D87D@;V8@=&AE('EE87(N"B`@("`@("`@)&1A>2`](#,Q.PH@("`@("`@
M('=H:6QE("AD871E*"=W)RP@;6MT:6UE*#`L(#`L(#`L(#$R+"`D9&%Y+"`D
M>65A<BDI("$]($A/4D1%7T1!5$5?5$A54E-$05DI('L*("`@("`@("`@("`@
M)&1A>2TM.PH@("`@("`@('T*"B`@("`@("`@)&1A=&4@/2`F;F5W($AO<F1E
M7T1A=&4H87)R87DH)WEE87(G(#T^("1Y96%R+"`G;6]N=&@G(#T^(#$R+"`G
M;61A>2<@/3X@)&1A>2DI.PH@("`@("`@(')E='5R;B`D9&%T92T^=V5E:T]F
M665A<B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!D871E(&]F
M('1H:7,@;V)J96-T('1O('1H92`D;G1H('=E96MD87D@;V8@)'=E96MD87DN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=E96MD87D@(%1H92!D
M87D@;V8@=&AE('=E96L@*#`@/2!3=6YD87DL(&5T8RDN"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;G1H("`@("`@5&AE("1N=&@@)'=E96MD87D@=&\@<V5T
M('1O("AD969A=6QT<R!T;R`Q*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M3G1H5V5E:V1A>2@D=V5E:V1A>2P@)&YT:"`](#$I"B`@("!["B`@("`@("`@
M:68@*"1W965K9&%Y(#P@2$]21$5?1$%415]354Y$05D@?'P@)'=E96MD87D@
M/B!(3U)$15]$051%7U-!5%521$%9*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YM9&%Y(#T@,3L*("`@
M("`@("`D9FER<W0@/2`D=&AI<RT^9&%Y3V97965K*"D["B`@("`@("`@:68@
M*"1W965K9&%Y(#P@)&9I<G-T*2!["B`@("`@("`@("`@("1T:&ES+3YM9&%Y
M(#T@."`K("1W965K9&%Y("T@)&9I<G-T.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YM9&%Y(#T@)'=E96MD87D@+2`D9FER<W0@*R`Q
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;61A>2`K/2`W("H@)&YT:"`M
M(#<["@H@("`@("`@("1T:&ES+3YC;W)R96-T*"D["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&1U;7`H)'!R969I>"`]("<G
M*0H@("`@>PH@("`@("`@(&5C:&\@*"1P<F5F:7@@/R`D<')E9FEX("X@)SH@
M)R`Z("<G*2`N("1T:&ES+3YY96%R("X@)RTG("X@)'1H:7,M/FUO;G1H("X@
M)RTG("X@)'1H:7,M/FUD87D@+B`B/&)R/EQN(CL*("`@('T*"B`@("`O*BH*
M("`@("`J($ES('1H92!D871E(&-U<G)E;G1L>2!R97!R97-E;G1E9"!B>2!T
M:&ES(&]B:F5C="!A('9A;&ED(&1A=&4_"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!686QI9&ET>2P@8V]U;G1I;F<@;&5A<"!Y96%R<RP@971C
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U9A;&ED*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/GEE87(@/"`P('Q\("1T:&ES+3YY96%R(#X@.3DY.2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!C:&5C:V1A=&4H)'1H:7,M/FUO;G1H+"`D=&AI<RT^;61A>2P@
M)'1H:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]R<F5C="!A
M;GD@;W9E<BT@;W(@=6YD97)F;&]W<R!I;B!A;GD@;V8@=&AE(&1A=&4G<R!M
M96UB97)S+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87-K("!7
M92!M87D@;F]T('=A;G0@=&\@8V]R<F5C="!S;VUE(&]V97)F;&]W<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]R<F5C="@D;6%S:R`]($A/4D1%7T1!5$5?
M34%32U]!3$Q005)44RD*("`@('L*("`@("`@("!I9B`H)&UA<VL@)B!(3U)$
M15]$051%7TU!4TM?4T5#3TY$*2!["B`@("`@("`@("`@('=H:6QE("@D=&AI
M<RT^<V5C(#P@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FUI;BTM.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E8R`K/2`V,#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!W:&EL92`H)'1H:7,M/G-E8R`^(#4Y*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^;6EN*RL["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5C("T](#8P.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&UA<VL@)B!(3U)$15]$051%7TU!4TM?34E.551%*2!["B`@("`@
M("`@("`@('=H:6QE("@D=&AI<RT^;6EN(#P@,"D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/FAO=7(M+3L*("`@("`@("`@("`@("`@("1T:&ES+3YM:6X@
M*ST@-C`["B`@("`@("`@("`@('T*("`@("`@("`@("`@=VAI;&4@*"1T:&ES
M+3YM:6X@/B`U.2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(K*SL*
M("`@("`@("`@("`@("`@("1T:&ES+3YM:6X@+3T@-C`["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("@D;6%S:R`F($A/4D1%7T1!5$5?
M34%32U](3U52*2!["B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^:&]U<B`\
M(#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3YM9&%Y+2T["B`@("`@("`@
M("`@("`@("`D=&AI<RT^:&]U<B`K/2`R-#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!W:&EL92`H)'1H:7,M/FAO=7(@/B`R,RD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/FUD87DK*SL*("`@("`@("`@("`@("`@("1T:&ES+3YH
M;W5R("T](#(T.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&UA<VL@)B!(3U)$15]$051%7TU!4TM?34].5$@I('L*("`@("`@("`@
M("`@=VAI;&4@*"1T:&ES+3YM;VYT:"`^(#$R*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^>65A<BLK.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUO;G1H
M("T](#$R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('=H:6QE("@D=&AI
M<RT^;6]N=&@@/"`Q*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^>65A<BTM
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUO;G1H("L](#$R.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&UA<VL@)B!(3U)$15]$
M051%7TU!4TM?1$%9*2!["B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^;61A
M>2`^($AO<F1E7T1A=&4Z.F1A>7-);DUO;G1H*"1T:&ES+3YM;VYT:"P@)'1H
M:7,M/GEE87(I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;61A>2`M/2!(
M;W)D95]$871E.CID87ES26Y-;VYT:"@D=&AI<RT^;6]N=&@L("1T:&ES+3YY
M96%R*3L*("`@("`@("`@("`@("`@("1T:&ES+3YM;VYT:"LK.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F-O<G)E8W0H2$]21$5?1$%415]-05-+7TU/3E1(
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!W:&EL92`H)'1H:7,M/FUD
M87D@/"`Q*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;6]N=&@M+3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YC;W)R96-T*$A/4D1%7T1!5$5?34%32U]-
M3TY42"D["B`@("`@("`@("`@("`@("`D=&AI<RT^;61A>2`K/2!(;W)D95]$
M871E.CID87ES26Y-;VYT:"@D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($-O;7!A<F4@=&AI<R!D871E('1O(&%N;W1H97(@9&%T92!O8FIE8W0@=&\@
M<V5E('=H:6-H(&]N92!I<PH@("`@("H@9W)E871E<B`H;&%T97(I+B!!<W-U
M;65S('1H870@=&AE(&1A=&5S(&%R92!I;B!T:&4@<V%M90H@("`@("H@=&EM
M97IO;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871E("!4:&4@
M9&%T92!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@/3T@(#`@:68@=&AE(&1A=&5S(&%R92!E<75A;`H@("`@("H@("`@
M("`@("`@("`@("`@("`^/2`@,2!I9B!T:&ES(&1A=&4@:7,@9W)E871E<B`H
M;&%T97(I"B`@("`@*B`@("`@("`@("`@("`@("`@(#P]("TQ(&EF('1H92!O
M=&AE<B!D871E(&ES(&=R96%T97(@*&QA=&5R*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;VUP87)E1&%T92@D9&%T92D*("`@('L*("`@("`@("!I9B`H(6ES
M7V$H)&1A=&4L("=(;W)D95]$871E)RDI('L*("`@("`@("`@("`@)&1A=&4@
M/2`F;F5W($AO<F1E7T1A=&4H)&1A=&4I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1T:&ES+3YY96%R("$]("1D871E+3YY96%R*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^>65A<B`M("1D871E+3YY96%R.PH@("`@("`@('T@
M96QS96EF("@D=&AI<RT^;6]N=&@@(3T@)&1A=&4M/FUO;G1H*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;6]N=&@@+2`D9&%T92T^;6]N=&@["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM9&%Y
M("T@)&1A=&4M/FUD87D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@0V]M<&%R92!T:&ES('1O(&%N;W1H97(@9&%T92!O8FIE8W0@8GD@=&EM
M92P@=&\@<V5E('=H:6-H(&]N90H@("`@("H@:7,@9W)E871E<B`H;&%T97(I
M+B!!<W-U;65S('1H870@=&AE(&1A=&5S(&%R92!I;B!T:&4@<V%M90H@("`@
M("H@=&EM97IO;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871E
M("!4:&4@9&%T92!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@/3T@(#`@:68@=&AE(&1A=&5S(&%R92!E<75A;`H@("`@
M("H@("`@("`@("`@("`@("`@("`^/2`@,2!I9B!T:&ES(&1A=&4@:7,@9W)E
M871E<B`H;&%T97(I"B`@("`@*B`@("`@("`@("`@("`@("`@(#P]("TQ(&EF
M('1H92!O=&AE<B!D871E(&ES(&=R96%T97(@*&QA=&5R*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VUP87)E5&EM92@D9&%T92D*("`@('L*("`@("`@("!I
M9B`H(6ES7V$H)&1A=&4L("=(;W)D95]$871E)RDI('L*("`@("`@("`@("`@
M)&1A=&4@/2`F;F5W($AO<F1E7T1A=&4H)&1A=&4I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1T:&ES+3YH;W5R("$]("1D871E+3YH;W5R*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^:&]U<B`M("1D871E+3YH;W5R.PH@("`@
M("`@('T@96QS96EF("@D=&AI<RT^;6EN("$]("1D871E+3YM:6XI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YM:6X@+2`D9&%T92T^;6EN.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V5C("T@
M)&1A=&4M/G-E8SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VUP87)E('1H:7,@=&\@86YO=&AE<B!D871E(&]B:F5C="P@:6YC;'5D:6YG
M('1I;65S+"!T;R!S964*("`@("`J('=H:6-H(&]N92!I<R!G<F5A=&5R("AL
M871E<BDN($%S<W5M97,@=&AA="!T:&4@9&%T97,@87)E(&EN('1H90H@("`@
M("H@<V%M92!T:6UE>F]N92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&1A=&4@(%1H92!D871E('1O(&-O;7!A<F4@=&\N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("`]/2`@,"!I9B!T:&4@9&%T97,@87)E(&5Q=6%L
M"B`@("`@*B`@("`@("`@("`@("`@("`@(#X]("`Q(&EF('1H:7,@9&%T92!I
M<R!G<F5A=&5R("AL871E<BD*("`@("`J("`@("`@("`@("`@("`@("`@/#T@
M+3$@:68@=&AE(&]T:&5R(&1A=&4@:7,@9W)E871E<B`H;&%T97(I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;7!A<F5$871E5&EM92@D9&%T92D*("`@('L*
M("`@("`@("!I9B`H(6ES7V$H)&1A=&4L("=(;W)D95]$871E)RDI('L*("`@
M("`@("`@("`@)&1A=&4@/2`F;F5W($AO<F1E7T1A=&4H)&1A=&4I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1D:69F(#T@)'1H:7,M/F-O;7!A<F5$871E
M*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@)&1I9F8["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC;VUP87)E5&EM
M92@D9&%T92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M('1H92!T:6UE(&]F9G-E="!F;W(@;&]C86P@=&EM92!Z;VYE+@H@("`@("H*
M("`@("`J($!P87)A;2!B;V]L96%N("1C;VQO;B`@4&QA8V4@82!C;VQO;B!B
M971W965N(&AO=7)S(&%N9"!M:6YU=&5S/PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:6UE>F]N92!O9F9S970@87,@82!S=')I;F<@:6X@=&AE
M(&9O<FUA="`K2$@Z34TN"B`@("`@*B\*("`@(&9U;F-T:6]N('1Z3V9F<V5T
M*"1C;VQO;B`]('1R=64I"B`@("!["B`@("`@("`@)'-E8W,@/2!D871E*"=:
M)RP@)'1H:7,M/G1I;65S=&%M<"@I*3L*"B`@("`@("`@:68@*"1S96-S(#P@
M,"D@>PH@("`@("`@("`@("`D<VEG;B`]("<M)SL*("`@("`@("`@("`@)'-E
M8W,@/2`M)'-E8W,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-I
M9VX@/2`G*R<["B`@("`@("`@?0H@("`@("`@("1C;VQO;B`]("1C;VQO;B`_
M("<Z)R`Z("<G.PH@("`@("`@("1M:6YS(#T@:6YT=F%L*"@D<V5C<R`K(#,P
M*2`O(#8P*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G)7,E,#)D)7,E,#)D
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D<VEG;BP@)&UI;G,@+R`V,"P@
M)&-O;&]N+"`D;6EN<R`E(#8P*3L*("`@('T*"B`@("`O*BH*("`@("`J($9O
M<FUA="!T:6UE(&EN($E33RTX-C`Q(&9O<FUA="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@1&%T92!A;F0@=&EM92!I;B!)4T\M.#8P,2!F;W)M
M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES;S@V,#%$871E5&EM92@I"B`@
M("!["B`@("`@("`@)'1Z;V9F(#T@)'1H:7,M/G1Z3V9F<V5T*"D["B`@("`@
M("`@)&1A=&4@/2`D=&AI<RT^>65A<B`N("<M)R`N("1T:&ES+3YM;VYT:"`N
M("<M)R`N("1T:&ES+3YM9&%Y.PH@("`@("`@("1T:6UE(#T@)'1H:7,M/FAO
M=7(@+B`G.B<@+B`D=&AI<RT^;6EN("X@)SHG("X@)'1H:7,M/G-E8SL*"B`@
M("`@("`@<F5T=7)N("1D871E("X@)U0G("X@)'1I;64@+B`D='IO9F8["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&;W)M870@=&EM92!I;B!21D,@,C@R,B!F
M;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($1A=&4@86YD
M('1I;64@:6X@4D9#(#(X,C(@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R9F,R.#(R1&%T951I;64H*0H@("`@>PH@("`@("`@(')E='5R;B!D871E
M*"=$+"!J($T@62!(.FDZ<R`G+"`D=&AI<RT^=&EM97-T86UP*"DI("X@)'1H
M:7,M/G1Z3V9F<V5T*&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@("`J($9O
M<FUA="!T:6UE(&EN(%)&0R`S,S,Y(&9O<FUA="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@1&%T92!A;F0@=&EM92!I;B!21D,@,S,S.2!F;W)M
M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(')F8S,S,SE$871E5&EM92@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&1A=&4H)UDM;2UD7%1(.FDG+"`D=&AI<RT^
M=&EM97-T86UP*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1F]R;6%T('1I
M;64@=&\@<W1A;F1A<F0@)V-T:6UE)R!F;W)M870N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@($1A=&4@86YD('1I;64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-4:6UE*"1T:6UE(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T
M=7)N(&1A=&4H)T0@32!J($@Z:3IS(%DG+"`D=&AI<RT^=&EM97-T86UP*"DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1F]R;6%T(&1A=&4@86YD('1I;64@
M=7-I;F<@<W1R9G1I;64H*2!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@('-T<F9T:6UE*"D@9F]R;6%T=&5D(&1A=&4@86YD('1I;64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<F9T:6UE*"1F;W)M870I"B`@("![
M"B`@("`@("`@<F5T=7)N('-T<F9T:6UE*"1F;W)M870L("1T:&ES+3YT:6UE
M<W1A;7`H*2D["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T5D
M:71O<BYP:'``````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-S<Q-0`Q,#0Q-S,V,C<W,P`P,C`R,#,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($5D:71O<B!#
M;&%S<PH@*@H@*B!4:&4@161I=&]R.CH@<&%C:V%G92!P<F]V:61E<R!A;B!R
M=&4@961I=&]R(&9O<B!T:&4@2&]R9&4*("H@07!P;&EC871I;VX@1G)A;65W
M;W)K+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]%9&ET;W(O161I=&]R+G!H
M<"QV(#$N."XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,30@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@3G5N;R!,;W5R96ER;R`\;G5N;T!C
M;RYS87!O+G!T/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@3G5N;R!,
M;W5R96ER;R`\;G5N;T!C;RYS87!O+G!T/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?161I=&]R"B`J+PIC;&%S<R!(;W)D95]%
M9&ET;W(@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7T5D:71O<B@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R
M;B!A(&-O;F-R971E($AO<F1E7T5D:71O<B!I;G-T86YC92!B87-E9"!O;B`D
M9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4
M:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]%9&ET;W(@<W5B8VQA<W,@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN($EF("1D<FEV
M97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O1')I=F5R+R!F
M;W(@=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D
M9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI
M9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]%9&ET;W(@
M(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($AO<F1E7T5D:71O<B!I;G-T
M86YC92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O<B!F86QS92!O
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E
M<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1D<FEV97(I*2!["B`@("`@("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@
M("`@("`@("`@("`D9')I=F5R(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@
M("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*("`@("`@("!I
M9B`H96UP='DH)&1R:79E<BD@?'P@)&1R:79E<B`]/2`G;F]N92<I('L*("`@
M("`@("`@("`@)&5D:71O<B`]("9N97<@2&]R9&5?161I=&]R*"1P87)A;7,I
M.PH@("`@("`@("`@("!R971U<FX@)&5D:71O<CL*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<U]N=6QL*"1P87)A;7,I("8F(&-L87-S7V5X:7-T<R@G2&]R
M9&4G*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E
M<D-O;F9I9R@G961I=&]R)RP@)&1R:79E<BD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(&=L;V)A;"`D<F5G
M:7-T<GD["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D<F5G:7-T<GDM/F=E
M="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+T5D:71O<B\G("X@)&1R:79E
M<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]%9&ET;W(O)R`N("1D<FEV97(@+B`G+G!H
M<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O161I=&]R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T5D
M:71O<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@
M("1C;&%S<R`]("=(;W)D95]%9&ET;W)?)R`N("1D<FEV97(["B`@("`@("`@
M:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1E9&ET
M;W(@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D961I=&]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@
M9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&5D:71O<CL*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A
M(&-O;F-R971E($AO<F1E7T5D:71O<@H@("`@("H@:6YS=&%N8V4@8F%S960@
M;VX@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC
M90H@("`@("H@:68@;F\@2&]R9&5?161I=&]R(&EN<W1A;F-E('=I=&@@=&AE
M('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D*("`@("`J(&5X:7-T<RX*("`@
M("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE(&-A
M8VAE(&)A8VME;F1S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT:7!L92!(;W)D
M95]%9&ET;W(@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.@H@("`@("H@)'9A
M<B`]("9(;W)D95]%9&ET;W(Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO
M<F1E7T5D:71O<B!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W
M92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D
M9')I=F5R6S!=+VQI8B]%9&ET;W(O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D
M9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P
M87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@
M*B!`<VEN8V4@2&]R9&4@,BXR"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D
M95]%9&ET;W(@(%1H92!C;VYC<F5T92!(;W)D95]%9&ET;W(@<F5F97)E;F-E
M+"!O<B!F86QS92!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N
M8V5S.PH*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@
M("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES7VYU;&PH)'!A<F%M<RD@)B8@8VQA<W-?97AI<W1S*"=(;W)D
M92<I*2!["B`@("`@("`@("`@("1P87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R
M0V]N9FEG*"=C86-H92<L("1D<FEV97(I.PH@("`@("`@('T*"B`@("`@("`@
M)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US
M*2D["B`@("`@("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1S:6=N871U<F4L
M("1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA
M='5R95T@/2`F2&]R9&5?161I=&]R.CIF86-T;W)Y*"1D<FEV97(L("1P87)A
M;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I
M9VYA='5R95T["B`@("!]"@I]"@``````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T9O<FTN<&AP````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#,R,S(W-0`Q,#0Q-S,V,C<W,P`P,3<V-C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J($AO<F1E7T9O<FT@36%S=&5R($-L87-S+@H@*@H@*B!4:&4@
M2&]R9&5?1F]R;3HZ('!A8VMA9V4@<')O=FED97,@9F]R;2!R96YD97)I;F<L
M('9A;&ED871I;VXL(&%N9`H@*B!O=&AE<B!F=6YC=&EO;F%L:71Y(&9O<B!T
M:&4@2&]R9&4@07!P;&EC871I;VX@1G)A;65W;W)K+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP+'8@,2XS,#8N,BXT-R`R,#`V+S`S
M+S`Y(#(S.C$T.C,Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR
M,#`V(%)O8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M
M/@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]B
M97)T($4N($-O>6QE(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC
M;&%S<R!(;W)D95]&;W)M('L*"B`@("!V87(@)%]N86UE(#T@)R<["B`@("!V
M87(@)%]T:71L92`]("<G.PH@("`@=F%R("1?97AT<F$@/2`G)SL*("`@('9A
M<B`D7W9A<G,["B`@("!V87(@)%]S=6)M:70@/2!A<G)A>2@I.PH@("`@=F%R
M("1?<F5S970@/2!F86QS93L*("`@('9A<B`D7V5R<F]R<R`](&%R<F%Y*"D[
M"B`@("!V87(@)%]S=6)M:71T960@/2!N=6QL.PH@("`@=F%R("1?<V5C=&EO
M;G,@/2!A<G)A>2@I.PH@("`@=F%R("1?;W!E;E]S96-T:6]N(#T@;G5L;#L*
M("`@('9A<B`D7V-U<G)E;G1396-T:6]N(#T@87)R87DH*3L*("`@('9A<B`D
M7W9A<FEA8FQE<R`](&%R<F%Y*"D["B`@("!V87(@)%]H:61D96Y687)I86)L
M97,@/2!A<G)A>2@I.PH@("`@=F%R("1?=7-E1F]R;51O:V5N(#T@=')U93L*
M("`@('9A<B`D7V%U=&]F:6QL960@/2!F86QS93L*("`@('9A<B`D7V5N8W1Y
M<&4@/2!N=6QL.PH@("`@=F%R("1?:&5L<"`](&9A;'-E.PH*("`@(&9U;F-T
M:6]N($AO<F1E7T9O<FTH)B1V87)S+"`D=&ET;&4@/2`G)RP@)&YA;64@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@>PH@("`@
M("`@("`@("`D;F%M92`](%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1T:&ES
M*2D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W9A<G,@/2`F)'9A<G,[
M"B`@("`@("`@)'1H:7,M/E]T:71L92`]("1T:71L93L*("`@("`@("`D=&AI
M<RT^7VYA;64@/2`D;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1F;W)M+"`F)'9A<G,L("1T:71L92`]("<G+"`D;F%M92`](&YU;&PI
M"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@("1S
M:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&9O<FTL("1V87)S+"`D=&ET
M;&4L("1N86UE*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1F
M;W)M*2D@>PH@("`@("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72`]("9N97<@)&9O<FTH)'9A<G,L("1T:71L92P@)&YA;64I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72`]("9N97<@2&]R9&5?1F]R;2@D=F%R<RP@)'1I=&QE+"`D;F%M
M92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@(&9U;F-T:6]N('-E
M=%9A<G,H)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<R`]("8D
M=F%R<SL*("`@('T*"B`@("!F=6YC=&EO;B!G9714:71L92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=&ET;&4["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5T5&ET;&4H)'1I=&QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&ET
M;&4@/2`D=&ET;&4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T17AT<F$H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5X=')A.PH@("`@?0H*("`@
M(&9U;F-T:6]N('-E=$5X=')A*"1E>'1R82D*("`@('L*("`@("`@("`D=&AI
M<RT^7V5X=')A(#T@)&5X=')A.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$YA
M;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VYA;64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971S(&]R(&=E=',@=VAE=&AE<B!T:&4@9F]R
M;2!S:&]U;&0@8F4@=F5R:69I960@8GD@=&]K96YS+@H@("`@("H@5&]K96YS
M(&%R92!U<V5D('1O('9E<FEF>2!T:&%T(&$@9F]R;2!I<R!O;FQY('-U8FUI
M='1E9"!O;F-E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1T;VME
M;B`@268@<W!E8VEF:65D+"!S971S('=H971H97(@=&\@=7-E(&9O<FT@=&]K
M96YS+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!F
M;W)M('1O:V5N<R!A<F4@8F5I;F<@=7-E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=7-E5&]K96XH)'1O:V5N(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)'1O:V5N*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W5S949O
M<FU4;VME;B`]("1T;VME;CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=7-E1F]R;51O:V5N.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M('1H92!R96YD97)E<B!F;W(@=&AI<R!F;W)M+"!E:71H97(@82!C=7-T;VT@
M<F5N9&5R97(@;W(@=&AE"B`@("`@*B!S=&%N9&%R9"!O;F4N"B`@("`@*@H@
M("`@("H@5&\@=7-E(&$@8W5S=&]M(&9O<FT@<F5N9&5R97(L('EO=7(@9F]R
M;2!C;&%S<R!N965D<R!T;PH@("`@("H@;W9E<G)I9&4@=&AI<R!F=6YC=&EO
M;CH*("`@("`J(#QC;V1E/@H@("`@("H@9G5N8W1I;VX@)F=E=%)E;F1E<F5R
M*"D*("`@("`J('L*("`@("`J("`@("`D<B`]("9N97<@0W5S=&]M1F]R;5)E
M;F1E<F5R*"D["B`@("`@*B`@("`@<F5T=7)N("1R.PH@("`@("H@?0H@("`@
M("H@/"]C;V1E/@H@("`@("H*("`@("`J("XN+B!W:&5R92!#=7-T;VU&;W)M
M4F5N9&5R97(@:7,@=&AE(&-L87-S;F%M92!O9B!T:&4@8W5S=&]M"B`@("`@
M*B!R96YD97)E<B!C;&%S<RP@=VAI8V@@<VAO=6QD(&5X=&5N9"!(;W)D95]&
M;W)M7U)E;F1E<F5R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@;V8@<F5N9&5R97(M<W!E8VEF:6,@<&%R86UE=&5R<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="!(;W)D95]&;W)M7U)E;F1E
M<F5R("!4:&4@9F]R;2!R96YD97)E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F=E=%)E;F1E<F5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PH@("`@
M("`@("1R96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@D<&%R
M86US*3L*("`@("`@("!R971U<FX@)')E;F1E<F5R.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9G9714>7!E*"1T>7!E+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D='EP95]C;&%S<R`]("=(;W)D95]&;W)M7U1Y<&5?)R`N
M("1T>7!E.PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1T>7!E7V-L87-S
M*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9B@G3F]N97AI<W1A;G0@8VQA<W,@(B5S(B!F;W(@9FEE;&0@='EP92`B)7,B
M)RP@)'1Y<&5?8VQA<W,L("1T>7!E*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@("`@("1T>7!E7V]B(#T@)FYE=R`D='EP95]C;&%S
M<R@I.PH@("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"8D='EP
M95]O8BP@)VEN:70G*2P@)'!A<F%M<RD["B`@("`@("`@<F5T=7)N("1T>7!E
M7V]B.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-E8W1I;VXH)'-E8W1I;VX@
M/2`G)RP@)&1E<V,@/2`G)RP@)&EM86=E(#T@)R<L("1E>'!A;F1E9"`]('1R
M=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]C=7)R96YT4V5C=&EO;B`]("1S
M96-T:6]N.PH@("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]S96-T:6]N<RD@
M)B8@(21T:&ES+3YG971/<&5N4V5C=&EO;B@I*2!["B`@("`@("`@("`@("1T
M:&ES+3YS971/<&5N4V5C=&EO;B@D<V5C=&EO;BD["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=6R=D97-C)UT@/2`D9&5S
M8SL*("`@("`@("`D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG97AP86YD
M960G72`]("1E>'!A;F1E9#L*("`@("`@("`D=&AI<RT^7W-E8W1I;VYS6R1S
M96-T:6]N75LG:6UA9V4G72`]("1I;6%G93L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971396-T:6]N1&5S8R@D<V5C=&EO;BD*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]S96-T:6]N<ULD<V5C=&EO;EU;)V1E<V,G73L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971396-T:6]N26UA9V4H)'-E8W1I;VXI"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=6R=I
M;6%G92==.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$]P96Y396-T:6]N*"1S
M96-T:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<RT^<V5T*"=?7V9O
M<FU/<&5N4V5C=&EO;B<L("1S96-T:6]N*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971/<&5N4V5C=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=F%R<RT^9V5T*"=?7V9O<FU/<&5N4V5C=&EO;B<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=%-E8W1I;VY%>'!A;F1E9%-T871E*"1S96-T:6]N+"`D
M8F]O;&5A;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D8F]O;&5A;BD@
M>PH@("`@("`@("`@("`O*B!/;FQY('1H92!B;V]L96%N('9A;'5E(&ES(')E
M<75I<F5D+B`J+PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]S96-T:6]N
M<ULD<V5C=&EO;EU;)V5X<&%N9&5D)UT["B`@("`@("`@?0H*("`@("`@("`O
M*B!.965D('1O(')E='5R;B!T:&4@=F%L=65S(&9O<B!U<V4@:6X@<W1Y;&5S
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG
M97AP86YD960G72D@>PH@("`@("`@("`@("!R971U<FX@)V)L;V-K)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)VYO;F4G.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F%D9%9A<FEA8FQE*"1H=6UA;DYA;64L("1V87).86UE+"`D
M='EP92P@)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M96%D;VYL>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^:6YS97)T5F%R:6%B;&5"969O<F4H;G5L
M;"P@)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D+"`D<F5A
M9&]N;'DL("1D97-C<FEP=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B`F:6YS97)T5F%R:6%B
M;&5"969O<F4H)&)E9F]R92P@)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E
M9"P@)')E861O;FQY(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<V-R:7!T:6]N(#T@;G5L;"P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'1Y<&4@/2`F)'1H:7,M/F=E=%1Y<&4H
M)'1Y<&4L("1P87)A;7,I.PH@("`@("`@("1V87(@/2`F;F5W($AO<F1E7T9O
M<FU?5F%R:6%B;&4H)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D
M+"`D<F5A9&]N;'DL("1D97-C<FEP=&EO;BD["@H@("`@("`@("\J(%-E="!T
M:&4@9F]R;2!O8FIE8W0@<F5F97)E;F-E(&EN('1H92!V87(N("HO"B`@("`@
M("`@)'9A<BT^<V5T1F]R;4]B*"1T:&ES*3L*"B`@("`@("`@:68@*"1V87(M
M/F=E=%1Y<&5.86UE*"D@/3T@)V5N=6TG("8F"B`@("`@("`@("`@(&-O=6YT
M*"1V87(M/F=E=%9A;'5E<R@I*2`]/2`Q*2!["B`@("`@("`@("`@("1V86QS
M(#T@87)R87E?:V5Y<R@D=F%R+3YG971686QU97,H*2D["B`@("`@("`@("`@
M("1T:&ES+3Y?=F%R<RT^861D*"1V87(M/G9A<DYA;64L("1V86QS6S!=*3L*
M("`@("`@("`@("`@)'9A<BT^7V%U=&]F:6QL960@/2!T<G5E.PH@("`@("`@
M('T@96QS96EF("@D=F%R+3YG9714>7!E3F%M92@I(#T]("=F:6QE)R!\?`H@
M("`@("`@("`@("`@("`@("`D=F%R+3YG9714>7!E3F%M92@I(#T]("=I;6%G
M92<I('L*("`@("`@("`@("`@)'1H:7,M/E]E;F-T>7!E(#T@)VUU;'1I<&%R
M="]F;W)M+61A=&$G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]C=7)R96YT4V5C=&EO;BDI('L*("`@("`@("`@("`@)'1H:7,M/E]C
M=7)R96YT4V5C=&EO;B`]("=?7V)A<V4G.PH@("`@("`@('T*"B`@("`@("`@
M:68@*&ES7VYU;&PH)&)E9F]R92DI('L*("`@("`@("`@("`@)'1H:7,M/E]V
M87)I86)L97-;)'1H:7,M/E]C=7)R96YT4V5C=&EO;EU;72`]("8D=F%R.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N=6T@/2`P.PH@("`@("`@
M("`@("!W:&EL92`H:7-S970H)'1H:7,M/E]V87)I86)L97-;)'1H:7,M/E]C
M=7)R96YT4V5C=&EO;EU;)&YU;5TI("8F"B`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W9A<FEA8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N75LD;G5M
M72T^9V5T5F%R3F%M92@I("$]("1B969O<F4I('L*("`@("`@("`@("`@("`@
M("1N=6TK*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I;VY=6R1N
M=6U=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H
M:7,M/E]C=7)R96YT4V5C=&EO;EU;72`]("8D=F%R.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H
M:7,M/E]C=7)R96YT4V5C=&EO;ET@/2!A<G)A>5]M97)G92@*("`@("`@("`@
M("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA8FQE<ULD=&AI
M<RT^7V-U<G)E;G1396-T:6]N72P@,"P@)&YU;2DL"B`@("`@("`@("`@("`@
M("`@("`@87)R87DH)B1V87(I+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M7W-L:6-E*"1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I
M;VY=+"`D;G5M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=F%R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A
M('9A<FEA8FQE(&9R;VT@=&AE(&9O<FTN"B`@("`@*@H@("`@("H@07,@;VYL
M>2!V87)I86)L97,@8V%N(&)E('!A<W-E9"!B>2!R969E<F5N8V4L('EO=2!N
M965D('1O(&-A;&P@=&AI<PH@("`@("H@;65T:&]D('1H:7,@=V%Y(&EF('=A
M;G0@=&\@<&%S<R!A('9A<FEA8FQE(&YA;64Z"B`@("`@*B`\8V]D93X*("`@
M("`J("1F;W)M+3YR96UO=F5687)I86)L92@D=F%R(#T@)W9A<FYA;64G*3L*
M("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?1F]R
M;5]687)I86)L97QS=')I;F<@)'9A<B`@16ET:&5R('1H92!V87)I86)L92=S
M(&YA;64@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@=F%R:6%B;&4@=&\@<F5M;W9E(&9R;VT@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE('9A<FEA8FQE('=A<R!F;W5N9"`H86YD(&1E;&5T960I+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96UO=F5687)I86)L92@F)'9A<BD*("`@('L*("`@
M("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?=F%R:6%B;&5S*2!A
M<R`D<V5C=&EO;BD@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES
M*"1T:&ES+3Y?=F%R:6%B;&5S6R1S96-T:6]N72D@87,@)&DI('L*("`@("`@
M("`@("`@("`@(&EF("@H:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L
M92<I("8F("1T:&ES+3Y?=F%R:6%B;&5S6R1S96-T:6]N75LD:5T@/3T]("1V
M87(I('Q\"B`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3Y?=F%R:6%B;&5S
M6R1S96-T:6]N75LD:5TM/F=E=%9A<DYA;64H*2`]/2`D=F%R*2D@>PH@("`@
M("`@("`@("`@("`@("`@("\O(%-L:6-E(&]U="!T:&4@=F%R:6%B;&4@=&\@
M8F4@<F5M;W9E9"X*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A<FEA
M8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72`](&%R<F%Y7VUE<F=E*`H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A
M<FEA8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72P@,"P@)&DI+`H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA
M8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72P@)&D@*R`Q*2D["@H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9A9&1(:61D96XH)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E
M+"`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("1R96%D;VYL
M>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M='EP92`]("8D=&AI<RT^9V5T5'EP92@D='EP92P@)'!A<F%M<RD["B`@("`@
M("`@)'9A<B`]("9N97<@2&]R9&5?1F]R;5]687)I86)L92@D:'5M86Y.86UE
M+"`D=F%R3F%M92P@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5Q=6ER960L("1R96%D;VYL>2P@)&1E<V-R:7!T
M:6]N*3L*("`@("`@("`D=F%R+3YH:61E*"D["B`@("`@("`@)'1H:7,M/E]H
M:61D96Y687)I86)L97-;72`]("8D=F%R.PH@("`@("`@(')E='5R;B`D=F%R
M.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971687)I86)L97,H)&9L870@/2!T
M<G5E+"`D=VET:$AI9&1E;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D
M9FQA="D@>PH@("`@("`@("`@("`D=F%R<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?=F%R:6%B;&5S(&%S("1S96-T:6]N*2![
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<V5C=&EO;B!A<R`D=F%R*2![
M"B`@("`@("`@("`@("`@("`@("`@)'9A<G-;72`]("1V87(["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1W:71H
M2&ED9&5N*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI
M9&1E;E9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A<G-;72`]("1V87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N("1V87)S.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9A<FEA8FQE<SL*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T0G5T=&]N<R@D<W5B;6ET+"`D
M<F5S970@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)'-U8FUI="`]/3T@
M=')U92!\?"!I<U]N=6QL*"1S=6)M:70I('Q\(&5M<'1Y*"1S=6)M:70I*2![
M"B`@("`@("`@("`@("\J($1E9F%U;'0@=&\@)U-U8FUI="<N("HO"B`@("`@
M("`@("`@("1S=6)M:70@/2!A<G)A>2A?*")3=6)M:70B*2D["B`@("`@("`@
M?2!E;'-E:68@*"%I<U]A<G)A>2@D<W5B;6ET*2D@>PH@("`@("`@("`@("`O
M*B!$969A=6QT('1O(&%R<F%Y(&EF(&YO="!P87-S960N("HO"B`@("`@("`@
M("`@("1S=6)M:70@/2!A<G)A>2@D<W5B;6ET*3L*("`@("`@("!]"B`@("`@
M("`@+RH@3VYL>2!I9B`D<F5S970@:7,@<W1R:6-T;'D@=')U92!I;G-E<G0@
M9&5F875L="`G4F5S970G+B`J+PH@("`@("`@(&EF("@D<F5S970@/3T]('1R
M=64I('L*("`@("`@("`@("`@)')E<V5T(#T@7R@B4F5S970B*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?<W5B;6ET(#T@)'-U8FUI=#L*("`@("`@
M("`D=&AI<RT^7W)E<V5T(#T@)')E<V5T.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&%P<&5N9$)U='1O;G,H)'-U8FUI="D*("`@('L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1S=6)M:70I*2!["B`@("`@("`@("`@("1S=6)M:70@/2!A<G)A
M>2@D<W5B;6ET*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<W5B;6ET
M(#T@87)R87E?;65R9V4H)'1H:7,M/E]S=6)M:70L("1S=6)M:70I.PH@("`@
M?0H*("`@(&9U;F-T:6]N('!R97-E<G9E5F%R0GE0;W-T*"8D=F%R<RP@)'9A
M<FYA;64L("1A;'1?=F%R;F%M92`]("<G*0H@("`@>PH@("`@("`@("1V86QU
M92`]("1V87)S+3YG971%>&ES=',H)'9A<FYA;64L("1W87-S970I.PH*("`@
M("`@("`O*B!)9B!A;B!A;'1E<FYA=&4@;F%M92!I<R!G:79E;B!U;F1E<B!W
M:&EC:"!T;R!P<F5S97)V92!U<V4@=&AA="X@*B\*("`@("`@("!I9B`H)&%L
M=%]V87)N86UE*2!["B`@("`@("`@("`@("1V87)N86UE(#T@)&%L=%]V87)N
M86UE.PH@("`@("`@('T*"B`@("`@("`@:68@*"1W87-S970I('L*("`@("`@
M("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@D=F%R;F%M92P@)'9A
M;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!R97-E<G9E5F%R0GE0
M;W-T*"1V87)N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S
M("1I9"`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!R97-E
M<G9E5F%R0GE0;W-T*"1V87)N86UE("X@)ULG("X@)&ED("X@)UTG+"`D=F%L
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1V87)N86UE(#T@:'1M;'-P96-I86QC:&%R<R@D=F%R;F%M92D["B`@("`@
M("`@("`@("1V86QU92`](&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*3L*("`@
M("`@("`@("`@<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E
M<R(@=F%L=64](B5S(B`O/B<@+B`B7&XB+`H@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`D=F%L=64I.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!O<&5N*"8D<F5N9&5R97(L("8D=F%R
M<RP@)&%C=&EO;BP@)&UE=&AO9"`]("=G970G+"`D96YC='EP92`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&5N8W1Y<&4I("8F("%I<U]N
M=6QL*"1T:&ES+3Y?96YC='EP92DI('L*("`@("`@("`@("`@)&5N8W1Y<&4@
M/2`D=&AI<RT^7V5N8W1Y<&4["B`@("`@("`@?0H@("`@("`@("1R96YD97)E
M<BT^;W!E;B@D86-T:6]N+"`D;65T:&]D+"`D=&AI<RT^7VYA;64L("1E;F-T
M>7!E*3L*("`@("`@("`D<F5N9&5R97(M/FQI<W1&;W)M5F%R<R@D=&AI<RD[
M"@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N86UE*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!R97-E<G9E5F%R0GE0;W-T*"=F;W)M;F%M92<L("1T
M:&ES+3Y?;F%M92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]U
M<V5&;W)M5&]K96XI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]4;VME;BYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7W!R97-E<G9E5F%R
M0GE0;W-T*"=?7V9O<FU4;VME;E\G("X@)'1H:7,M/E]N86UE+"!(;W)D95]4
M;VME;CHZ9V5N97)A=&5)9"@D=&AI<RT^7VYA;64I*3L*("`@("`@("!]"@H@
M("`@("`@("\J($QO;W`@=&AR;W5G:"!V87)S(&%N9"!C:&5C:R!F;W(@86YY
M('-P96-I86P@8V%S97,@=&\@<')E<V5R=F4N("HO"B`@("`@("`@)'9A<FEA
M8FQE<R`]("1T:&ES+3YG971687)I86)L97,H*3L*("`@("`@("!F;W)E86-H
M("@D=F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@+RH@4')E<V5R
M=F4@=F%L=64@:68@8VAA;F=E(&AA<R!T;R!B92!T<F%C:V5D+B`J+PH@("`@
M("`@("`@("!I9B`H)'9A<BT^9V5T3W!T:6]N*"=T<F%C:V-H86YG92<I*2![
M"B`@("`@("`@("`@("`@("`D=F%R;F%M92`]("1V87(M/F=E=%9A<DYA;64H
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D
M=F%R<RP@)'9A<FYA;64L("=?7V]L9%\G("X@)'9A<FYA;64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI
M9&1E;E9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("1T:&ES+3YP
M<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<BT^9V5T5F%R3F%M92@I*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@8VQO<V4H)B1R96YD97)E
M<BD*("`@('L*("`@("`@("`D<F5N9&5R97(M/F-L;W-E*"D["B`@("!]"@H@
M("`@9G5N8W1I;VX@<F5N9&5R06-T:79E*"8D<F5N9&5R97(L("8D=F%R<RP@
M)&%C=&EO;BP@)&UE=&AO9"`]("=G970G+"`D96YC='EP92`](&YU;&PL("1F
M;V-U<R`]('1R=64I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&5N8W1Y
M<&4I("8F("%I<U]N=6QL*"1T:&ES+3Y?96YC='EP92DI('L*("`@("`@("`@
M("`@)&5N8W1Y<&4@/2`D=&AI<RT^7V5N8W1Y<&4["B`@("`@("`@?0H@("`@
M("`@("1R96YD97)E<BT^;W!E;B@D86-T:6]N+"`D;65T:&]D+"`D=&AI<RT^
M9V5T3F%M92@I+"`D96YC='EP92D["B`@("`@("`@)')E;F1E<F5R+3YL:7-T
M1F]R;59A<G,H)'1H:7,I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M;F%M92DI('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S
M="@G9F]R;6YA;64G+"`D=&AI<RT^7VYA;64I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1T:&ES+3Y?=7-E1F]R;51O:V5N*2!["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O5&]K96XN<&AP)SL*("`@("`@("`@("`@)'1H
M:7,M/E]P<F5S97)V959A<D)Y4&]S="@G7U]F;W)M5&]K96Y?)R`N("1T:&ES
M+3Y?;F%M92P@2&]R9&5?5&]K96XZ.F=E;F5R871E260H)'1H:7,M/E]N86UE
M*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]S96-T
M:6]N<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S
M="@G7U]F;W)M3W!E;E-E8W1I;VXG+"`D=&AI<RT^9V5T3W!E;E-E8W1I;VXH
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@=F%R<R!A
M;F0@8VAE8VL@9F]R(&%N>2!S<&5C:6%L(&-A<V5S('1O"B`@("`@("`@("H@
M<')E<V5R=F4N("HO"B`@("`@("`@)'9A<FEA8FQE<R`]("1T:&ES+3YG9716
M87)I86)L97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S(&%S("1V
M87(I('L*("`@("`@("`@("`@+RH@4')E<V5R=F4@=F%L=64@:68@8VAA;F=E
M(&AA<R!T;R!B92!T<F%C:V5D+B`J+PH@("`@("`@("`@("!I9B`H)'9A<BT^
M9V5T3W!T:6]N*"=T<F%C:V-H86YG92<I*2!["B`@("`@("`@("`@("`@("`D
M=F%R;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64L("=?
M7V]L9%\G("X@)'9A<FYA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E;E9A<FEA8FQE<R!A<R`D
M=F%R*2!["B`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D
M=F%R<RP@)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"@H@("`@("`@
M("1R96YD97)E<BT^8F5G:6Y!8W1I=F4H)'1H:7,M/F=E=%1I=&QE*"DL("1T
M:&ES+3YG971%>'1R82@I*3L*("`@("`@("`D<F5N9&5R97(M/G)E;F1E<D9O
M<FU!8W1I=F4H)'1H:7,L("1V87)S*3L*("`@("`@("`D<F5N9&5R97(M/G-U
M8FUI="@D=&AI<RT^7W-U8FUI="P@)'1H:7,M/E]R97-E="D["B`@("`@("`@
M)')E;F1E<F5R+3YE;F0H*3L*("`@("`@("`D<F5N9&5R97(M/F-L;W-E*"1F
M;V-U<RD["B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R26YA8W1I=F4H)B1R
M96YD97)E<BP@)'9A<G,I"B`@("!["B`@("`@("`@)')E;F1E<F5R+3YB96=I
M;DEN86-T:79E*"1T:&ES+3YG9714:71L92@I+"`D=&AI<RT^9V5T17AT<F$H
M*2D["B`@("`@("`@)')E;F1E<F5R+3YR96YD97)&;W)M26YA8W1I=F4H)'1H
M:7,L("1V87)S*3L*("`@("`@("`D<F5N9&5R97(M/F5N9"@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('!R97-E<G9E*"1V87)S*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7W5S949O<FU4;VME;BD@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?
M<')E<V5R=F5687)">5!O<W0H)U]?9F]R;51O:V5N7R<@+B`D=&AI<RT^7VYA
M;64L($AO<F1E7U1O:V5N.CIG96YE<F%T94ED*"1T:&ES+3Y?;F%M92DI.PH@
M("`@("`@('T*"B`@("`@("`@)'9A<FEA8FQE<R`]("1T:&ES+3YG971687)I
M86)L97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S(&%S("1V87(I
M('L*("`@("`@("`@("`@)'9A<FYA;64@/2`D=F%R+3YG971687).86UE*"D[
M"@H@("`@("`@("`@("`O*B!3879E('9A;'5E(&]F(&EN9&EV:61U86P@8V]M
M<&]N96YT<RX@*B\*("`@("`@("`@("`@<W=I=&-H("@D=F%R+3YG9714>7!E
M3F%M92@I*2!["B`@("`@("`@("`@(&-A<V4@)W!A<W-W;W)D8V]N9FER;2<Z
M"B`@("`@("`@("`@(&-A<V4@)V5M86EL8V]N9FER;2<Z"B`@("`@("`@("`@
M("`@("`D=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE
M("X@)UMO<FEG:6YA;%TG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S
M97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G6V-O;F9I<FU=)RD[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VUO
M;G1H>65A<B<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^<')E<V5R=F5687)"
M>5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMM;VYT:%TG*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA
M;64@+B`G6WEE87)=)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)VUO;G1H9&%Y>65A<B<Z"B`@("`@("`@("`@("`@("`D
M=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMM
M;VYT:%TG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y
M4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G6V1A>5TG*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@
M+B`G6WEE87)=)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'1H:7,M/G!R97-E<G9E5F%R0GE0;W-T*"1V
M87)S+"`D=F%R;F%M92D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?:&ED9&5N5F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@
M)'1H:7,M/G!R97-E<G9E5F%R0GE0;W-T*"1V87)S+"`D=F%R+3YG971687).
M86UE*"DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!U;G-E=%9A
M<G,H)B1V87)S*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG9716
M87)I86)L97,H*2!A<R`D=F%R*2!["B`@("`@("`@("`@("1V87)S+3YR96UO
M=F4H)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$;V5S('1H92!A8W1I;VX@;V8@=F%L:61A=&EN9R!T:&4@
M9F]R;2P@8VAE8VMI;F<@:68@:70@<F5A;&QY(&AA<R!B965N"B`@("`@*B!S
M=6)M:71T960@8GD@8V%L;&EN9R!I<U-U8FUI='1E9"@I(&%N9"!I9B!T<G5E
M(&1O97,@86YY(&]N4W5B;6ET*"D*("`@("`J(&-A;&QS(&9O<B!V87(@='EP
M97,@:6X@=&AE(&9O<FTN(%1H92!?<W5B;6ET=&5D('9A<B!I<R!T:&5N(')E
M8VAE8VME9"X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?5F%R:6%B;&5S
M("1V87)S"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@("`@("`@("1C86Y!=71O
M9FEL;"`@0V%N('1H92!F;W)M(&)E('9A;&ED('=I=&AO=70*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B96EN9R!S=6)M
M:71T960_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('1H92!F;W)M(&ES('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!V86QI
M9&%T92@F)'9A<G,L("1C86Y!=71O1FEL;"`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\J($=E="!S=6)M:71T960@<W1A='5S+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^:7-3=6)M:71T960H*2!\?"`D8V%N075T;T9I;&PI('L*("`@("`@
M("`@("`@+RH@1F]R;2!W87,@<W5B;6ET=&5D(&]R(&-A;B!A=71O9FEL;#L@
M8VAE8VL@9F]R(&%N>2!V87)I86)L90H@("`@("`@("`@("`@*B!T>7!E<R<@
M;VY3=6)M:70H*2X@*B\*("`@("`@("`@("`@)'1H:7,M/F]N4W5B;6ET*"1V
M87)S*3L*"B`@("`@("`@("`@("\J(%)E8VAE8VL@<W5B;6ET=&5D('-T871U
M<RX@*B\*("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-3=6)M:71T960H*2`F
M)B`A)&-A;D%U=&]&:6QL*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O*B!&;W)M(&AA<R!N;W0@8F5E;B!S=6)M:71T960[(')E='5R;B!F86QS
M92X@*B\*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)&UE<W-A9V4@/2`G)SL*("`@("`@("`D=&AI<RT^7V%U=&]F:6QL
M960@/2!T<G5E.PH*("`@("`@("!I9B`H)'1H:7,M/E]U<V5&;W)M5&]K96XI
M('L*("`@("`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@(&EF("AI
M<W-E="@D8V]N9ELG=&]K96XG72DI('L*("`@("`@("`@("`@("`@("\J($EF
M('1H97)E(&ES(&$@8V]N9FEG=7)E9"!T;VME;B!S>7-T96TL('-E="!I="!U
M<"X@*B\*("`@("`@("`@("`@("`@("1T;VME;E-O=7)C92`]("9(;W)D95]4
M;VME;CHZ<VEN9VQE=&]N*"1C;VYF6R=T;VME;B==6R=D<FEV97(G72P@2&]R
M9&4Z.F=E=$1R:79E<D-O;F9I9R@G=&]K96XG+"`D8V]N9ELG=&]K96XG75LG
M9')I=F5R)UTI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("\J($1E9F%U;'0@=&\@=&AE(&9I;&4@<WES=&5M(&EF(&YO(&-O;F9I
M9RX@*B\*("`@("`@("`@("`@("`@("1T;VME;E-O=7)C92`]("9(;W)D95]4
M;VME;CHZ<VEN9VQE=&]N*"=F:6QE)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"$D=&]K96Y3;W5R8V4M/G9E<FEF>2@D=F%R<RT^9V5T*"=?
M7V9O<FU4;VME;E\G("X@)'1H:7,M/E]N86UE*2DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?97)R;W)S6R=?7V9O<FU4;VME;B==(#T@7R@B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T5F%R
M:6%B;&5S*"D@87,@)'9A<BD@>PH@("`@("`@("`@("`D=&AI<RT^7V%U=&]F
M:6QL960@/2`D=F%R+3Y?875T;V9I;&QE9"`F)B`D=&AI<RT^7V%U=&]F:6QL
M960["B`@("`@("`@("`@(&EF("@A)'9A<BT^=F%L:61A=&4H)'9A<G,L("1M
M97-S86=E*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<G-;)'9A
M<BT^9V5T5F%R3F%M92@I72`]("1M97-S86=E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]A=71O9FEL;&5D*2!["B`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?97)R;W)S6R=?7V9O<FU4;VME;B==
M*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:&ED9&5N
M5F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@:68@*"$D=F%R+3YV
M86QI9&%T92@D=F%R<RP@)&UE<W-A9V4I*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V5R<F]R<ULD=F%R+3YG971687).86UE*"E=(#T@)&UE<W-A9V4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^:7-686QI9"@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-L96%R5F%L:61A
M=&EO;B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]E<G)O<G,@/2!A<G)A>2@I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$5R<F]R*"1V87(I"B`@("!["B`@
M("`@("`@:68@*&ES7V$H)'9A<BP@)TAO<F1E7T9O<FU?5F%R:6%B;&4G*2D@
M>PH@("`@("`@("`@("`D;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]("1V87(["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V5R<F]R<ULD;F%M
M95TI(#\@)'1H:7,M/E]E<G)O<G-;)&YA;65=(#H@;G5L;#L*("`@('T*"B`@
M("!F=6YC=&EO;B!S971%<G)O<B@D=F%R+"`D;65S<V%G92D*("`@('L*("`@
M("`@("!I9B`H:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L92<I*2![
M"B`@("`@("`@("`@("1N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1N86UE(#T@)'9A<CL*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/E]E<G)O<G-;)&YA;65=(#T@)&UE<W-A9V4[
M"B`@("!]"@H@("`@9G5N8W1I;VX@8VQE87)%<G)O<B@D=F%R*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A*"1V87(L("=(;W)D95]&;W)M7U9A<FEA8FQE)RDI
M('L*("`@("`@("`@("`@)&YA;64@/2`D=F%R+3YG971687).86UE*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YA;64@/2`D=F%R.PH@("`@
M("`@('T*("`@("`@("!U;G-E="@D=&AI<RT^7V5R<F]R<ULD;F%M95TI.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H*0H@("`@>PH@("`@("`@(')E
M='5R;B`H)'1H:7,M/E]A=71O9FEL;&5D('Q\(&-O=6YT*"1T:&ES+3Y?97)R
M;W)S*2`]/2`P*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>&5C=71E*"8D=F%R
M<RD*("`@('L*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G5V%R;FEN9SH@
M2&]R9&5?1F]R;3HZ97AE8W5T92@I(&-A;&QE9"P@<VAO=6QD(&)E(&]V97)R
M:61D96XG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H('1H92!F:65L9"!V86QU97,@
M;V8@=&AE('-U8FUI='1E9"!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!6
M87)I86)L97,@)'9A<G,@(%1H92!687)I86)L97,@;V)J96-T+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1I;F9O("`@("`@07)R87D@=&\@8F4@9FEL;&5D('=I
M=&@@=&AE('-U8FUI='1E9"!F:65L9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);F9O
M*"8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5T26YF
M;T9R;VU687)I86)L97,H)'1H:7,M/F=E=%9A<FEA8FQE<R@I+"`D=F%R<RP@
M)&EN9F\I.PH@("`@("`@("1T:&ES+3Y?9V5T26YF;T9R;VU687)I86)L97,H
M)'1H:7,M/E]H:61D96Y687)I86)L97,L("1V87)S+"`D:6YF;RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!&971C:"!T:&4@9FEE;&0@=F%L=65S(&9R;VT@
M82!G:79E;B!A<G)A>2!O9B!V87)I86)L97,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`D=F%R
M:6%B;&5S("!!;B!A<G)A>2!O9B!(;W)D95]&;W)M7U9A<FEA8FQE(&]B:F5C
M=',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9F5T8V@@
M9G)O;2X*("`@("`J($!P87)A;2!O8FIE8W0@)'9A<G,@("`@("`@5&AE(%9A
M<FEA8FQE<R!O8FIE8W0N"B`@("`@*B!`<&%R86T@87)R87D@("1I;F9O("`@
M("`@(%1H92!A<G)A>2!T;R!B92!F:6QL960@=VET:"!T:&4@<W5B;6ET=&5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9I96QD('9A;'5E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$EN9F]&<F]M5F%R:6%B;&5S
M*"1V87)I86)L97,L("8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@(&9O
M<F5A8V@@*"1V87)I86)L97,@87,@)'9A<BD@>PH@("`@("`@("`@("!I9B`H
M)'9A<BT^:7-!<G)A>59A;"@I*2!["B`@("`@("`@("`@("`@("`D=F%R+3YG
M971);F9O*"1V87)S+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D=F%L=65S*2D@>PH@("`@("`@("`@("`@("`@("`@("1V87).
M86UE(#T@<W1R7W)E<&QA8V4H)UM=)RP@)R<L("1V87(M/F=E=%9A<DYA;64H
M*2D["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D
M:2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I
M75LD=F%R3F%M95T@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@
M("`@("`@("`@(&EF("A(;W)D95]!<G)A>3HZ9V5T07)R87E087)T<R@D=F%R
M+3YG971687).86UE*"DL("1B87-E+"`D:V5Y<RDI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R1B87-E72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)&)A<V5=(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'!O:6YT97(@
M/2`F)&EN9F];)&)A<V5=.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("AC
M;W5N="@D:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2`]
M(&%R<F%Y7W-H:69T*"1K97ES*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D<&]I;G1E<ELD:V5Y72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R1K97E=(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<&]I;G1E<B`]("8D<&]I;G1E<ELD:V5Y73L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T26YF;R@D=F%R<RP@
M)'!O:6YT97(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D=F%R+3YG971);F9O*"1V87)S+"`D:6YF;ULD=F%R+3YG
M971687).86UE*"E=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!H87-(96QP*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]H96QP.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!I9B!T:&ES(&9O<FT@:&%S(&)E96X@<W5B
M;6ET=&5D(&]R(&YO="X@268@=&AE(&-L87-S"B`@("`@*B!V87(@7W-U8FUI
M='1E9"!I<R!N=6QL('1H96X@:70@=VEL;"!C:&5C:R!F;W(@=&AE('!R97-E
M;F-E(&]F"B`@("`@*B!T:&4@9F]R;6YA;64@:6X@=&AE(&9O<FT@=F%R:6%B
M;&5S+@H@("`@("H*("`@("`J($]T:&5R(&5V96YT<R!C86X@97AP;&EC:71L
M>2!S970@=&AE(%]S=6)M:71T960@=F%R:6%B;&4@=&\*("`@("`J(&9A;'-E
M('1O(&EN9&EC871E(&$@9F]R;2!S=6)M:70@8G5T(&YO="!F;W(@86-T=6%L
M('!O<W1I;F<@;V8*("`@("`J(&1A=&$@*&5G+B!O;D-H86YG92!E=F5N=',@
M=&\@=7!D871E('1H92!D:7-P;&%Y(&]F(&9I96QD<RDN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]R(&9A;'-E(&EN9&EC871I;F<@
M:68@=&AE(&9O<FT@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@
M<W5B;6ET=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U-U8FUI='1E9"@I
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]S=6)M:71T960I
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W9A<G,M/F=E="@G9F]R;6YA
M;64G*2`]/2`D=&AI<RT^9V5T3F%M92@I*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-U8FUI='1E9"`]('1R=64["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-U8FUI='1E9"`](&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]S=6)M:71T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@
M=&AE<F4@:7,@86YY=&AI;F<@=&\@9&\@;VX@=&AE('-U8FUI<W-I;VX@;V8@
M=&AE(&9O<FT@8GD*("`@("`J(&QO;W!I;F<@=&AR;W5G:"!E86-H('9A<FEA
M8FQE)W,@;VY3=6)M:70H*2!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@2&]R9&5?5F%R:6%B;&5S("1V87)S"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&]N4W5B;6ET*"8D=F%R<RD*("`@('L*("`@("`@("`O*B!,;V]P('1H<F]U
M9V@@86QL('9A<G,@86YD(&-H96-K(&EF('1H97)E)W,@86YY=&AI;F<@=&\@
M9&\@;VX*("`@("`@("`@*B!S=6)M:70N("HO"B`@("`@("`@)'9A<FEA8FQE
M<R`]("1T:&ES+3YG971687)I86)L97,H*3L*("`@("`@("!F;W)E86-H("@D
M=F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@)'9A<BT^='EP92T^
M;VY3=6)M:70H)'9A<BP@)'9A<G,I.PH@("`@("`@("`@("`O*B!)9B!C:&%N
M9V5S('1O('9A<B!B96EN9R!T<F%C:V5D(&1O;B=T(')E9VES=&5R('1H92!F
M;W)M(&%S"B`@("`@("`@("`@("`J('-U8FUI='1E9"!I9B!O;&0@=F%L=64@
M86YD(&YE=R!V86QU92!D:69F97(N("HO"B`@("`@("`@("`@(&EF("@D=F%R
M+3YG971/<'1I;VXH)W1R86-K8VAA;F=E)RDI('L*("`@("`@("`@("`@("`@
M("1V87)N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@("`@("`@
M("`@:68@*"%I<U]N=6QL*"1V87)S+3YG970H)V9O<FUN86UE)RDI("8F"B`@
M("`@("`@("`@("`@("`@("`@)'9A<G,M/F=E="@D=F%R;F%M92D@(3T@)'9A
M<G,M/F=E="@G7U]O;&1?)R`N("1V87)N86UE*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<W5B;6ET=&5D(#T@9F%L<V4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!%>'!L:6-I=&QY('-E=',@=&AE('-T871E(&]F('1H92!F;W)M
M('-U8FUI="X*("`@("`J"B`@("`@*B!!;B!E=F5N="!C86X@;W9E<G)I9&4@
M=&AE(&%U=&]M871I8R!D971E<FUI;F%T:6]N(&]F('1H92!S=6)M:70@<W1A
M=&4*("`@("`J(&EN('1H92!I<U-U8FUI='1E9"@I(&9U;F-T:6]N+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%T92`@5VAE=&AE<B!T;R!S
M970@=&AE('-T871E(&]F('1H92!F;W)M(&%S(&)E:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('-U8FUI='1E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T4W5B;6ET=&5D*"1S=&%T92`]('1R=64I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]S=6)M:71T960@/2`D<W1A=&4["B`@("!]"@I]"@HO*BH*
M("H@2&]R9&5?1F]R;5]4>7!E($-L87-S"B`J"B`J($!A=71H;W(@(%)O8F5R
M="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!`<&%C
M:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7U1Y<&4@>PH*
M("`@(&9U;F-T:6]N($AO<F1E7T9O<FU?5'EP92@I"B`@("!["B`@("!]"@H@
M("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@
M;VY3=6)M:70H*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H
M)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@
M("`@)&UE<W-A9V4@/2`G/'-T<F]N9SY%<G)O<CH\+W-T<F]N9SX@2&]R9&5?
M1F]R;5]4>7!E.CII<U9A;&ED*"D@8V%L;&5D("T@<VAO=6QD(&)E(&]V97)R
M:61D96X\8G(@+SXG.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("!F=6YC=&EO;B!G9714>7!E3F%M92@I"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*("`@("`@("!R971U<FX@<W1R
M7W)E<&QA8V4H)VAO<F1E7V9O<FU?='EP95\G+"`G)RP@4W1R:6YG.CIL;W=E
M<BAG971?8VQA<W,H)'1H:7,I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M5F%L=65S*"D*("`@('L*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@
M('L*("`@("`@("`D:6YF;R`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@
M('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]S<&%C97(@97AT96YD<R!(
M;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A
M8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I
M"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O
M=71;)VYA;64G72`](%\H(E-P86-E<B(I.PH@("`@("`@(')E='5R;B`D86)O
M=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?=V5A=&AE<F1O
M=&-O;2!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?<F5G
M97@["B`@("!V87(@)%]S:7IE.PH@("`@=F%R("1?;6%X;&5N9W1H.PH*("`@
M("\J*@H@("`@("H@5&AE(&EN:71I86QI<V%T:6]N(&9U;F-T:6]N(&9O<B!T
M:&4@=&5X="!V87)I86)L92!T>7!E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E9V5X("`@
M("`@($%N>2!V86QI9"!02%`@4$-212!P871T97)N('-Y;G1A>"!T:&%T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!N965D<R!T;R!B92!M
M871C:&5D(&9O<B!T:&4@9FEE;&0@=&\@8F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G-I9&5R960@=F%L:60N($EF(&QE9G0@96UP
M='D@=F%L:61I='D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('=I;&P@8F4@8VAE8VME9"!O;FQY(&9O<B!R97%U:7)E9"!F:65L9',*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('=H971H97(@=&AE>2!A
M<F4@96UP='D@;W(@;F]T+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@268@=7-I;F<@=&AI<R!R96=E>"!T97-T(&ET(&ES(&%D=FES86)L
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@96YT97(@
M82!D97-C<FEP=&EO;B!F;W(@=&AI<R!F:65L9"!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=V%R;B!T:&4@=7-E<B!W:&%T(&ES(&5X
M<&5C=&5D+"!A<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&=E;F5R871E9"!E<G)O<B!M97-S86=E(&ES('%U:71E(&=E;F5R:6,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%N9"!W:6QL(&YO
M="!G:79E(&%N>2!I;F1I8V%T:6]N('=H97)E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@<F5G97@@9F%I;&5D+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'-I>F4@("`@("`@5&AE('-I>F4@;V8@=&AE(&EN<'5T
M(&9I96QD+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QE;F=T:"`@5&AE
M(&UA>"!N=6UB97(@;V8@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:6YI="@D<F5G97@@/2`G)RP@)'-I>F4@/2`T,"P@)&UA>&QE;F=T:"`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]R96=E>"`@("`@/2`D<F5G
M97@["B`@("`@("`@)'1H:7,M/E]S:7IE("`@("`@/2`D<VEZ93L*("`@("`@
M("`D=&AI<RT^7VUA>&QE;F=T:"`]("1M87AL96YG=&@["B`@("!]"@H@("`@
M9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S
M<V%G92D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;6%X;&5N
M9W1H*2`F)B!3=')I;F<Z.FQE;F=T:"@D=F%L=64I(#X@)'1H:7,M/E]M87AL
M96YG=&@I('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E9A
M;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(I+"`D=&AI
M<RT^7VUA>&QE;F=T:"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G4V5R=FEC97,O5V5A=&AE
M<BYP:'`G.PH@("`@("`@("1W96%T:&5R1&]T0V]M(#T@)E-E<G9I8V5S7U=E
M871H97(Z.G-E<G9I8V4H)U=E871H97)$;W1#;VTG*3L*("`@("`@("`D=V5A
M=&AE<D1O=$-O;2T^<V5T06-C;W5N=$1A=&$H)SQ087)T;F5R240^)RP@)SQ,
M:6-E;G-E2V5Y/B<I.PH@("`@("`@("1S96%R8V@@/2`D=V5A=&AE<D1O=$-O
M;2T^<V5A<F-H3&]C871I;VXH)'9A;'5E*3L*"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1S96%R8V@I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5F%L
M:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(I("X@:6UP;&]D92@G+"`G
M+"`D<V5A<F-H*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T@96QS96EF("AI<U]A*"1S96%R8V@L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@)&UE<W-A9V4@/2`D<V5A<F-H+3YG971-97-S86=E*"D["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<VEZ93L*("`@('T*"B`@("!F=6YC=&EO;B!G971-87A,96YG=&@H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUA>&QE;F=T:#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O
M=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B5V5A
M=&AE<BYC;VTB*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH
M"B`@("`@("`@("`@("=R96=E>"<@("`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B4F5G97@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`G<VEZ92<@("`@("`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@
M("`@("=M87AL96YG=&@G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B36%X:6UU
M;2!L96YG=&@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@*3L*("`@("`@("!R971U<FX@
M)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VAE861E
M<B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-6
M86QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@
M("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B2&5A9&5R(BD["B`@("`@("`@
M<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]D97-C<FEP=&EO;B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@
M9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S
M<V%G92D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@
M/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B1&5S8W)I
M<'1I;VXB*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*+RHJ
M"B`J(%-I;7!L>2!R96YD97)S(&ET<R!R87<@=F%L=64@:6X@8F]T:"!A8W1I
M=F4@86YD(&EN86-T:79E(')E;F1E<FEN9RX*("HO"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]H=&UL(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`]
M(&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")(5$U,(BD[
M"B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E
M7T9O<FU?5'EP95]N=6UB97(@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*
M("`@('9A<B`D7V9R86-T:6]N.PH*("`@(&9U;F-T:6]N(&EN:70H)&9R86-T
M:6]N(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7V9R86-T:6]N(#T@
M)&9R86-T:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@
M*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I("8F("@H<W1R
M:6YG*2AD;W5B;&4I)'9A;'5E("$]/2`D=F%L=64I*2!["B`@("`@("`@("`@
M("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("AE;7!T
M>2@D=F%L=64I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@268@;6%T8VAE9"P@=&AE;B!T:&ES(&ES(&$@8V]R
M<F5C="!N=6UE<FEC('9A;'5E+B`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"1T:&ES+3Y?9V5T5F%L:61A=&EO;E!A='1E<FXH*2P@)'9A;'5E*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M
M97-S86=E(#T@7R@B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO
M;B!?9V5T5F%L:61A=&EO;E!A='1E<FXH*0H@("`@>PH@("`@("`@('-T871I
M8R`D<&%T=&5R;B`]("<G.PH@("`@("`@(&EF("@A96UP='DH)'!A='1E<FXI
M*2!["B`@("`@("`@("`@(')E='5R;B`D<&%T=&5R;CL*("`@("`@("!]"@H@
M("`@("`@("\J($=E="!C=7)R96YT(&QO8V%L92!I;F9O<FUA=&EO;BX@*B\*
M("`@("`@("`D;&EN9F\@/2!.3%,Z.F=E=$QO8V%L94EN9F\H*3L*"B`@("`@
M("`@+RH@0G5I;&0@=&AE('!A='1E<FXN("HO"B`@("`@("`@)'!A='1E<FX@
M/2`G*"TI/R<["@H@("`@("`@("\J($]N;'D@8VAE8VL@=&AO=7-A;F1S('-E
M<&%R871O<G,@:68@;&]C86QE(&AA<R!A;GDN("HO"B`@("`@("`@:68@*"%E
M;7!T>2@D;&EN9F];)VUO;E]T:&]U<V%N9'-?<V5P)UTI*2!["B`@("`@("`@
M("`@("\J(%)E9V5X('1O(&-H96-K(&9O<B!C;W)R96-T('1H;W5S86YD<R!S
M97!A<F%T;W)S("AI9B!A;GDI+B`J+PH@("`@("`@("`@("`D<&%T=&5R;B`N
M/2`G*"A<9"LI?"@H7&1[,"PS?3\I*%LG("X@)&QI;F9O6R=M;VY?=&AO=7-A
M;F1S7W-E<"==("X@)UU<9'LS?2DJ/RDI)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O*B!.;R!L;V-A;&4@=&AO=7-A;F1S('-E<&%R871O<BP@
M8VAE8VL@9F]R(&]N;'D@9&EG:71S+B`J+PH@("`@("`@("`@("`D<&%T=&5R
M;B`N/2`G*%QD*RDG.PH@("`@("`@('T*("`@("`@("`O*B!)9B!N;R!D96-I
M;6%L('!O:6YT('-P96-I9FEE9"!D969A=6QT('1O(&1O="X@*B\*("`@("`@
M("!I9B`H96UP='DH)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN="==*2D@>PH@
M("`@("`@("`@("`D;&EN9F];)VUO;E]D96-I;6%L7W!O:6YT)UT@/2`G+B<[
M"B`@("`@("`@?0H@("`@("`@("\J(%)E9V5X('1O(&-H96-K(&9O<B!C;W)R
M96-T(&1E8VEM86QS("AI9B!A;GDI+B`J+PH@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7V9R86-T:6]N*2D@>PH@("`@("`@("`@("`D9G)A8W1I;VX@/2`G
M*B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9R86-T:6]N(#T@
M)WLP+"<@+B`D=&AI<RT^7V9R86-T:6]N("X@)WTG.PH@("`@("`@('T*("`@
M("`@("`D<&%T=&5R;B`N/2`G*%LG("X@)&QI;F9O6R=M;VY?9&5C:6UA;%]P
M;VEN="==("X@)UTH7&0G("X@)&9R86-T:6]N("X@)RDI/R<["@H@("`@("`@
M("\J(%!U="!T;V=E=&AE<B!T:&4@=VAO;&4@<F5G97@@<&%T=&5R;BX@*B\*
M("`@("`@("`D<&%T=&5R;B`]("<O7B<@+B`D<&%T=&5R;B`N("<D+R<["@H@
M("`@("`@(')E='5R;B`D<&%T=&5R;CL*("`@('T*"B`@("!F=6YC=&EO;B!G
M971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@("`D
M=F%L=64@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@
M("`@)&QI;F9O(#T@3DQ3.CIG971,;V-A;&5);F9O*"D["B`@("`@("`@)'9A
M;'5E(#T@<W1R7W)E<&QA8V4H)&QI;F9O6R=M;VY?=&AO=7-A;F1S7W-E<"==
M+"`G)RP@)'9A;'5E*3L*("`@("`@("`D:6YF;R`]('-T<E]R97!L86-E*"1L
M:6YF;ULG;6]N7V1E8VEM86Q?<&]I;G0G72P@)RXG+"`D=F%L=64I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@
M("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?
M*").=6UB97(B*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*
M8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VEN="!E>'1E;F1S($AO<F1E7T9O<FU?
M5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D
M=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A<BT^:7-2
M97%U:7)E9"@I("8F(&5M<'1Y*"1V86QU92D@)B8@*"AS=')I;F<I*&EN="DD
M=F%L=64@(3T]("1V86QU92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?
M*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E
M*2!\?"!P<F5G7VUA=&-H*"<O7ELP+3E=*R0O)RP@)'9A;'5E*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S
M86=E(#T@7R@B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S
M+B(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A
M>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B26YT96=E<B(I.PH@
M("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&
M;W)M7U1Y<&5?;V-T86P@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F
M)B!E;7!T>2@D=F%L=64I("8F("@H<W1R:6YG*2AI;G0I)'9A;'5E("$]/2`D
M=F%L=64I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M
M871C:"@G+UY;,"TW72LD+R<L("1V86QU92DI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(BD["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@
M("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")/8W1A;"(I.PH@("`@("`@(')E
M='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?
M:6YT3&ES="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I
M;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E
M<75I<F5D*"DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I
M96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\?"!P<F5G
M7VUA=&-H*"<O7ELP+3D@+%TK)"\G+"`D=F%L=64I*2!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?
M*")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<R(I.PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD
M('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@
M("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==
M(#T@7R@B26YT96=E<B!L:7-T(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*
M("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]T97AT(&5X=&5N9',@
M2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]R96=E>#L*("`@('9A<B`D
M7W-I>F4["B`@("!V87(@)%]M87AL96YG=&@["@H@("`@+RHJ"B`@("`@*B!4
M:&4@:6YI=&EA;&ES871I;VX@9G5N8W1I;VX@9F]R('1H92!T97AT('9A<FEA
M8FQE('1Y<&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5G97@@("`@("`@06YY('9A;&ED
M(%!(4"!00U)%('!A='1E<FX@<WEN=&%X('1H870*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&YE961S('1O(&)E(&UA=&-H960@9F]R('1H
M92!F:65L9"!T;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N<VED97)E9"!V86QI9"X@268@;&5F="!E;7!T>2!V86QI9&ET>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!B92!C:&5C
M:V5D(&]N;'D@9F]R(')E<75I<F5D(&9I96QD<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=VAE=&AE<B!T:&5Y(&%R92!E;7!T>2!O<B!N
M;W0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!U<VEN
M9R!T:&ES(')E9V5X('1E<W0@:70@:7,@861V:7-A8FQE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T;R!E;G1E<B!A(&1E<V-R:7!T:6]N
M(&9O<B!T:&ES(&9I96QD('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!W87)N('1H92!U<V5R('=H870@:7,@97AP96-T960L(&%S('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9V5N97)A=&5D
M(&5R<F]R(&UE<W-A9V4@:7,@<75I=&4@9V5N97)I8PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@86YD('=I;&P@;F]T(&=I=F4@86YY(&EN
M9&EC871I;VX@=VAE<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H92!R96=E>"!F86EL960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<VEZ92`@("`@("!4:&4@<VEZ92!O9B!T:&4@:6YP=70@9FEE;&0N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;6%X;&5N9W1H("!4:&4@;6%X(&YU;6)E<B!O
M9B!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;FET*"1R96=E
M>"`]("<G+"`D<VEZ92`](#0P+"`D;6%X;&5N9W1H(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W)E9V5X("`@("`]("1R96=E>#L*("`@("`@("`D
M=&AI<RT^7W-I>F4@("`@("`]("1S:7IE.PH@("`@("`@("1T:&ES+3Y?;6%X
M;&5N9W1H(#T@)&UA>&QE;F=T:#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A
M;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@
M("`@("`@("1V86QI9"`]('1R=64["@H@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]M87AL96YG=&@I("8F(%-T<FEN9SHZ;&5N9W1H*"1V86QU92D@/B`D
M=&AI<RT^7VUA>&QE;F=T:"D@>PH@("`@("`@("`@("`D=F%L:60@/2!F86QS
M93L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(I+"`D=&AI<RT^7VUA
M>&QE;F=T:"D["B`@("`@("`@?2!E;'-E:68@*"1V87(M/FES4F5Q=6ER960H
M*2`F)B!E;7!T>2@D=&AI<RT^7W)E9V5X*2D@>PH@("`@("`@("`@("`D=F%L
M:60@/2!S=')L96XH=')I;2@D=F%L=64I*2`^(#`["@H@("`@("`@("`@("!I
M9B`H(21V86QI9"D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E:68@*"%E;7!T>2@D=&AI<RT^7W)E9V5X*2D@>PH@("`@("`@
M("`@("`D=F%L:60@/2!P<F5G7VUA=&-H*"1T:&ES+3Y?<F5G97@L("1V86QU
M92D["@H@("`@("`@("`@("!I9B`H(21V86QI9"D@>PH@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@/2!?*")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'9A;&ED.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T36%X3&5N9W1H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]M87AL96YG=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@
M("`D86)O=71;)VYA;64G72`](%\H(E1E>'0B*3L*("`@("`@("`D86)O=71;
M)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R96=E>"<@("`@(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B4F5G97@B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@
M("`@("`G<VEZ92<@("`@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B`G:6YT)RDL"B`@("`@("`@("`@("=M87AL96YG=&@G(#T^(&%R<F%Y*"=L
M86)E;"<@/3X@7R@B36%X:6UU;2!L96YG=&@B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@
M*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R
M9&5?1F]R;5]4>7!E7W-T<FEN9VQI<W0@97AT96YD<R!(;W)D95]&;W)M7U1Y
M<&5?=&5X="!["@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F
M:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("![
M"B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA
M;64G72`](%\H(E-T<FEN9R!L:7-T(BD["B`@("`@("`@)&%B;W5T6R=P87)A
M;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G<F5G97@G("`@("`]/B!A<G)A
M>2@G;&%B96PG(#T^(%\H(E)E9V5X(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2P*("`@("`@("`@("`@
M)W-I>F4G("`@("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:7IE(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN
M="<I+`H@("`@("`@("`@("`G;6%X;&5N9W1H)R`]/B!A<G)A>2@G;&%B96PG
M(#T^(%\H(DUA>&EM=6T@;&5N9W1H(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("D["B`@
M("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]C96QL<&AO;F4@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*
M("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F
M)&UE<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U93L*"B`@("`@
M("`@:68@*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=F%L
M:60@/2!S=')L96XH=')I;2@D=F%L=64I*2`^(#`["B`@("`@("`@("`@(&EF
M("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L:60@/2!P<F5G7VUA=&-H*"<O
M7EPK/UM<9"@I7"U<+R!=*B0O)RP@)'9A;'5E*3L*("`@("`@("`@("`@:68@
M*"$D=F%L:60I('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I
M=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N(BD["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=F%L:60["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R
M87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D-E;&QP:&]N92(I
M.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D
M95]&;W)M7U1Y<&5?:7!A9&1R97-S(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E
M7W1E>'0@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@
M)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U
M93L*"B`@("`@("`@:68@*'-T<FQE;BAT<FEM*"1V86QU92DI(#X@,"D@>PH@
M("`@("`@("`@("`D:7`@/2!E>'!L;V1E*"<N)RP@)'9A;'5E*3L*("`@("`@
M("`@("`@)'9A;&ED(#T@*&-O=6YT*"1I<"D@/3T@-"D["B`@("`@("`@("`@
M(&EF("@D=F%L:60I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I<"!A
M<R`D<&%R="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5M97)I
M8R@D<&%R="D@?'P*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/B`R
M-34@?'P*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/"`P*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(BD["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V5I9B`H)'9A<BT^:7-297%U:7)E9"@I*2![
M"B`@("`@("`@("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@("`@("`D;65S
M<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G
M;F%M92<@/3X@7R@B25`@061D<F5S<R(I*3L*("`@('T*"GT*"F-L87-S($AO
M<F1E7T9O<FU?5'EP95]L;VYG5&5X="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP
M95]T97AT('L*"B`@("!V87(@)%]R;W=S.PH@("`@=F%R("1?8V]L<SL*("`@
M('9A<B`D7VAE;'!E<B`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@:6YI="@D
M<F]W<R`](#@L("1C;VQS(#T@.#`L("1H96QP97(@/2`G)RD*("`@('L*("`@
M("`@("`D=&AI<RT^7W)O=W,@/2`D<F]W<SL*("`@("`@("`D=&AI<RT^7V-O
M;',@/2`D8V]L<SL*("`@("`@("`D=&AI<RT^7VAE;'!E<B`]("1H96QP97([
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4F]W<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F]W<SL*("`@('T*"B`@("!F=6YC=&EO;B!G971#
M;VQS*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VQS.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&AA<TAE;'!E<B@D;W!T:6]N(#T@)R<I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VXI*2!["B`@("`@("`@("`@("\J
M($YO(&]P=&EO;B!S<&5C:69I960L(&-H96-K(&EF(&%N>2!H96QP97)S(&AA
M=F4@8F5E;@H@("`@("`@("`@("`@*B!A8W1I=F%T960N("HO"B`@("`@("`@
M("`@(')E='5R;B`A96UP='DH)'1H:7,M/E]H96QP97(I.PH@("`@("`@('T@
M96QS96EF("AE;7!T>2@D=&AI<RT^7VAE;'!E<BDI('L*("`@("`@("`@("`@
M+RH@3F\@:&5L<&5R<R!A8W1I=F%T960@870@86QL+"!R971U<FX@9F%L<V4N
M("HO"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O*B!#:&5C:R!I9B!G:79E;B!H96QP97(@:&%S(&)E
M96X@86-T:79A=&5D+B`J+PH@("`@("`@("`@("!R971U<FX@:6Y?87)R87DH
M)&]P=&EO;BP@)'1H:7,M/E]H96QP97(I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O
M=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B3&]N
M9R!T97AT(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@
M("`@("`@("`@("`G<F]W<R<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU
M;6)E<B!O9B!R;W=S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("`@("`G8V]L<R<@("`]/B!A
M<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C;VQU;6YS(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@
M("`@("`@("`@("`G:&5L<&5R)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DAE
M;'!E<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@
M(#T^("=B;V]L96%N)RD*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D86)O
M=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8V]U;G1E9%1E
M>'0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&5?;&]N9U1E>'0@>PH*("`@('9A
M<B`D7V-H87)S.PH*("`@(&9U;F-T:6]N(&EN:70H)')O=W,@/2!N=6QL+"`D
M8V]L<R`](&YU;&PL("1C:&%R<R`](#$P,#`I"B`@("!["B`@("`@("`@<&%R
M96YT.CII;FET*"1R;W=S+"`D8V]L<RD["B`@("`@("`@)'1H:7,M/E]C:&%R
M<R`]("1C:&%R<SL*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R
M+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@("1V
M86QI9"`]('1R=64["@H@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"DI
M('L*("`@("`@("`@("`@)&QE;F=T:"`](%-T<FEN9SHZ;&5N9W1H*'1R:6TH
M)'9A;'5E*2D["@H@("`@("`@("`@("!I9B`H)&QE;F=T:"`\/2`P*2!["B`@
M("`@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@("`@
M("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@
M("`@("`@("`@?2!E;'-E:68@*"1L96YG=&@@/B`D=&AI<RT^7V-H87)S*2![
M"B`@("`@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@
M("`@("1M97-S86=E(#T@<W!R:6YT9BA?*")4:&5R92!A<F4@=&]O(&UA;GD@
M8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S
M(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB*2P@
M4W1R:6YG.CIL96YG=&@H=')I;2@D=F%L=64I*2P@)'1H:7,M/E]C:&%R<RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L
M:60["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0VAA<G,H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-H87)S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y
M*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")#;W5N=&5D('1E>'0B
M*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@
M("`@("=R;W=S)R`@/3X@87)R87DH)VQA8F5L)R`]/B!?*").=6UB97(@;V8@
M<F]W<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@
M/3X@)VEN="<I+`H@("`@("`@("`@("`G8V]L<R<@(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B3G5M8F5R(&]F(&-O;'5M;G,B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`@("`@
M)V-H87)S)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C:&%R
M86-T97)S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M("`]/B`G:6YT)RD*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D86)O=70[
M"B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?861D<F5S<R!E>'1E
M;F1S($AO<F1E7T9O<FU?5'EP95]L;VYG5&5X="!["@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH
M*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D%D9')E<W,B*3L*("`@
M("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R
M;W=S)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!R;W=S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G
M*2P*("`@("`@("`@("`@)V-O;',G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B
M3G5M8F5R(&]F(&-O;'5M;G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)VEN="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T
M.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V9I;&4@97AT96YD
M<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V
M87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M:68@*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=7!L;V%D
M960@/2!"<F]W<V5R.CIW87-&:6QE57!L;V%D960H)'9A<BT^9V5T5F%R3F%M
M92@I*3L*("`@("`@("`@("`@:68@*&ES7V$H)'5P;&]A9&5D+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1U<&QO861E
M9"T^9V5T365S<V%G92@I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L
M("8D:6YF;RD*("`@('L*("`@("`@("`D;F%M92`]("1V87(M/F=E=%9A<DYA
M;64H*3L*("`@("`@("`D=7!L;V%D960@/2!"<F]W<V5R.CIW87-&:6QE57!L
M;V%D960H)&YA;64I.PH@("`@("`@(&EF("@D=7!L;V%D960@/3T]('1R=64I
M('L*("`@("`@("`@("`@)&EN9F];)VYA;64G72`]("1?1DE,15-;)&YA;65=
M6R=N86UE)UT["B`@("`@("`@("`@("1I;F9O6R=T>7!E)UT@/2`D7T9)3$53
M6R1N86UE75LG='EP92==.PH@("`@("`@("`@("`D:6YF;ULG=&UP7VYA;64G
M72`]("1?1DE,15-;)&YA;65=6R=T;7!?;F%M92==.PH@("`@("`@("`@("`D
M:6YF;ULG9FEL92==(#T@)%]&24Q%4ULD;F%M95U;)W1M<%]N86UE)UT["B`@
M("`@("`@("`@("1I;F9O6R=E<G)O<B==(#T@)%]&24Q%4ULD;F%M95U;)V5R
M<F]R)UT["B`@("`@("`@("`@("1I;F9O6R=S:7IE)UT@/2`D7T9)3$536R1N
M86UE75LG<VEZ92==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)VYA
M;64G(#T^(%\H(D9I;&4@=7!L;V%D(BDI.PH@("`@?0H*?0H*8VQA<W,@2&]R
M9&5?1F]R;5]4>7!E7VEM86=E(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*
M"B`@("`O*BH*("`@("`J($AA<R!A(&9I;&4@8F5E;B!U<&QO861E9"!O;B!T
M:&ES(&9O<FT@<W5B;6ET/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@
M("`@("HO"B`@("!V87(@)%]U<&QO861E9"`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!3:&]W('1H92!U<&QO860@8G5T=&]N/PH@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W7W5P;&]A9"`]('1R
M=64["@H@("`@+RHJ"B`@("`@*B!3:&]W('1H92!O<'1I;VX@=&\@=7!L;V%D
M(&%L<V\@;W)I9VEN86P@;F]N+6UO9&EF:65D(&EM86=E/PH@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W7VME97!O
M<FEG/2!F86QS93L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!T
M:&4@<')E=FEO=7-L>2!U<&QO861E9"!I;6%G92!I;F9O+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:6UG(#T@87)R87DH
M*3L*"B`@("!F=6YC=&EO;B!I;FET*"1S:&]W7W5P;&]A9"`]('1R=64L("1S
M:&]W7VME97!O<FEG(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M:&]W7W5P;&]A9"`@(#T@)'-H;W=?=7!L;V%D.PH@("`@("`@("1T:&ES+3Y?
M<VAO=U]K965P;W)I9R`]("1S:&]W7VME97!O<FEG.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&]N4W5B;6ET*"8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@
M+RH@1V5T('1H92!U<&QO860N("HO"B`@("`@("`@)'1H:7,M/E]G9715<&QO
M860H)'9A<G,L("1V87(I.PH*("`@("`@("`O*B!)9B!T:&ES('=A<R!D;VYE
M('1H<F]U9V@@=&AE('5P;&]A9"!B=71T;VX@;W9E<G)I9&4@=&AE('-U8FUI
M='1E9`H@("`@("`@("`J('9A;'5E(&]F('1H92!F;W)M+B`J+PH@("`@("`@
M(&EF("@D=F%R<RT^9V5T*"=?9&]?)R`N("1V87(M/F=E=%9A<DYA;64H*2DI
M('L*("`@("`@("`@("`@)'9A<BT^9F]R;2T^<V5T4W5B;6ET=&5D*&9A;'-E
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A
M<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D
M9FEE;&0@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["@H@("`@
M("`@("\J($=E="!T:&4@=7!L;V%D+B`J+PH@("`@("`@("1T:&ES+3Y?9V5T
M57!L;V%D*"1V87)S+"`D=F%R*3L*"B`@("`@("`@+RH@5&AE('5P;&]A9"!G
M96YE<F%T960@82!014%2($5R<F]R+B`J+PH@("`@("`@(&EF("AI<U]A*"1T
M:&ES+3Y?=7!L;V%D960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M+RH@3F]T(')E<75I<F5D(&%N9"!N;R!I;6%G92!U<&QO860@871T96UP=&5D
M+B`J+PH@("`@("`@("`@("!I9B`H(21V87(M/FES4F5Q=6ER960H*2`F)B!E
M;7!T>2@D9FEE;&1;)VEM9R==*2`F)@H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]U<&QO861E9"T^9V5T0V]D92@I(#T](#0I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M*"1T:&ES+3Y?=7!L;V%D960M/F=E=$-O9&4H*2`]/2!54$Q/041?15)27TY/
M7T9)3$4I("8F"B`@("`@("`@("`@("`@("!E;7!T>2@D9FEE;&1;)VEM9R==
M*2D@>PH@("`@("`@("`@("`@("`@+RH@3F]T:&EN9R!U<&QO861E9"!A;F0@
M;F\@;VQD97(@=7!L;V%D+B`J+PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y
M*"1F:65L9%LG:6UG)UTI*2!["B`@("`@("`@("`@("`@("`O*B!.;W1H:6YG
M('5P;&]A9&5D(&)U="!O;&1E<B!U<&QO860@<')E<V5N="X@*B\*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@+RH@4V]M92!O=&AE<B!E<G)O<B!M97-S86=E+B`J
M+PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7W5P;&]A9&5D
M+3YG971-97-S86=E*"D["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@
M)B1I;F9O*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@=7!L;V%D+B`J+PH@
M("`@("`@("1T:&ES+3Y?9V5T57!L;V%D*"1V87)S+"`D=F%R*3L*"B`@("`@
M("`@+RH@1V5T(&EM86=E('!A<F%M<R!S=&]R960@:6X@=&AE(&AI9&1E;B!F
M:65L9"X@*B\*("`@("`@("`D=F%L=64@/2`D=F%R+3YG971686QU92@D=F%R
M<RD["B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7VEM9SL*("`@("`@("!I9B`H
M96UP='DH)&EN9F];)V9I;&4G72DI('L*("`@("`@("`@("`@=6YS970H)&EN
M9F];)V9I;&4G72D["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@
M("`@("`@:68@*"1T:&ES+3Y?<VAO=U]K965P;W)I9RD@>PH@("`@("`@("`@
M("`D:6YF;ULG:V5E<%]O<FEG)UT@/2`A96UP='DH)'9A;'5E6R=K965P7V]R
M:6<G72D["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE('5P;&]A9&5D
M('9A;'5E("AE:71H97(@=')U92!O<B!014%27T5R<F]R*2X@*B\*("`@("`@
M("`D:6YF;ULG=7!L;V%D960G72`]("8D=&AI<RT^7W5P;&]A9&5D.PH*("`@
M("`@("`O*B!)9B!A(&UO9&EF:65D(&9I;&4@97AI<W1S(&UO=F4@:70@;W9E
M<B!T:&4@;W)I9VEN86PN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<VAO=U]K
M965P;W)I9R`F)B`D:6YF;ULG:V5E<%]O<FEG)UTI('L*("`@("`@("`@("`@
M+RH@4F5Q=65S=&5D('1H92!S879I;F<@;V8@;W)I9VEN86P@9FEL92!A;'-O
M+B`J+PH@("`@("`@("`@("`D:6YF;ULG;W)I9U]F:6QE)UT@/2!(;W)D93HZ
M9V5T5&5M<$1I<B@I("X@)R\G("X@)&EN9F];)V9I;&4G73L*("`@("`@("`@
M("`@)&EN9F];)V9I;&4G72`]($AO<F1E.CIG971496UP1&ER*"D@+B`G+VUO
M9%\G("X@)&EN9F];)V9I;&4G73L*("`@("`@("`@("`@+RH@0VAE8VL@:68@
M82!M;V1I9FEE9"!F:6QE(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D:6YF;ULG9FEL92==*2D@>PH@("`@("`@
M("`@("`@("`@)&EN9F];)V9I;&4G72`]("1I;F9O6R=O<FEG7V9I;&4G73L*
M("`@("`@("`@("`@("`@('5N<V5T*"1I;F9O6R=O<FEG7V9I;&4G72D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!3
M879I;F<@;V8@;W)I9VEN86P@;F]T(')E<75I<F5D+B`J+PH@("`@("`@("`@
M("`D;6]D7V9I;&4@/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R]M;V1?)R`N
M("1I;F9O6R=F:6QE)UT["B`@("`@("`@("`@("1I;F9O6R=F:6QE)UT@/2!(
M;W)D93HZ9V5T5&5M<$1I<B@I("X@)R\G("X@)&EN9F];)V9I;&4G73L*"B`@
M("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D;6]D7V9I;&4I*2!["B`@("`@
M("`@("`@("`@("`O*B!5;FQI;FL@9FER<W0@*&AA<R!T;R!B92!D;VYE(&]N
M(%=I;F1O=W,@;6%C:&EN97,_*2`J+PH@("`@("`@("`@("`@("`@=6YL:6YK
M*"1I;F9O6R=F:6QE)UTI.PH@("`@("`@("`@("`@("`@<F5N86UE*"1M;V1?
M9FEL92P@)&EN9F];)V9I;&4G72D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!U<&QO860@86YD('-E
M=',@=7`@=&AE('5P;&]A9"!D871A(&%R<F%Y+B!%:71H97(*("`@("`J(&9E
M=&-H97,@86X@=7!L;V%D(&1O;F4@=VET:"!T:&ES('-U8FUI="!O<B!R971R
M:65S('-T;W)E9`H@("`@("H@=7!L;V%D(&EN9F\N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]G9715<&QO860H)B1V87)S+"`F)'9A<BD*("`@('L*("`@("`@
M("`O*B!$;VXG="!B;W1H97(@=VET:"!T:&ES(&9U;F-T:6]N(&EF(&%L<F5A
M9'D@8V%L;&5D(&%N9"!S970*("`@("`@("`@*B!U<"!V87)S+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]I;6<I*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@9FEL
M92!H87,@8F5E;B!U<&QO861E9"X@*B\*("`@("`@("`D=F%R;F%M92`]("1V
M87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`D=&AI<RT^7W5P;&]A9&5D(#T@
M0G)O=W-E<CHZ=V%S1FEL955P;&]A9&5D*"1V87)N86UE("X@)UMN97==)RD[
M"@H@("`@("`@(&EF("@D=&AI<RT^7W5P;&]A9&5D(#T]/2!T<G5E*2!["B`@
M("`@("`@("`@("\J($$@9FEL92!H87,@8F5E;B!U<&QO861E9"!O;B!T:&ES
M('-U8FUI="X@4V%V92!T;R!T96UP(&1I<B!F;W(*("`@("`@("`@("`@("H@
M<')E=FEE=R!W;W)K+B`J+PH@("`@("`@("`@("`D=&AI<RT^7VEM9ULG='EP
M92==(#T@)'1H:7,M/F=E=%5P;&]A9&5D1FEL951Y<&4H)'9A<FYA;64@+B`G
M6VYE=UTG*3L*"B`@("`@("`@("`@("\J($=E="!T:&4@;W1H97(@<&%R=',@
M;V8@=&AE('5P;&]A9"X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("`@("!(;W)D95]!<G)A>3HZ9V5T
M07)R87E087)T<R@D=F%R;F%M92`N("=;;F5W72<L("1B87-E+"`D:V5Y<RD[
M"@H@("`@("`@("`@("`O*B!'970@=&AE('1E;7!O<F%R>2!F:6QE(&YA;64N
M("HO"B`@("`@("`@("`@("1K97ES7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A
M>2@D8F%S92P@)W1M<%]N86UE)RDL("1K97ES*3L*("`@("`@("`@("`@)'1H
M:7,M/E]I;6=;)V9I;&4G72`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?
M1DE,15,L("1K97ES7W!A=&@I.PH*("`@("`@("`@("`@+RH@1V5T('1H92!A
M8W1U86P@9FEL92!N86UE+B`J+PH@("`@("`@("`@("`D:V5Y<U]P871H/2!A
M<G)A>5]M97)G92AA<G)A>2@D8F%S92P@)VYA;64G*2P@)&ME>7,I.PH@("`@
M("`@("`@("`D=&AI<RT^7VEM9ULG;F%M92==(#T@2&]R9&5?07)R87DZ.F=E
M=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D["@H@("`@("`@("`@("`O
M*B!'970@=&AE(&9I;&4@<VEZ92X@*B\*("`@("`@("`@("`@)&ME>7-?<&%T
M:#T@87)R87E?;65R9V4H87)R87DH)&)A<V4L("=S:7IE)RDL("1K97ES*3L*
M("`@("`@("`@("`@)'1H:7,M/E]I;6=;)W-I>F4G72`]($AO<F1E7T%R<F%Y
M.CIG971%;&5M96YT*"1?1DE,15,L("1K97ES7W!A=&@I.PH*("`@("`@("`@
M("`@+RH@1V5T(&%N>2!E>&ES=&EN9R!V86QU97,@9F]R('1H92!I;6%G92!U
M<&QO860@9FEE;&0N("HO"B`@("`@("`@("`@("1U<&QO860@/2`D=F%R<RT^
M9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@("`@("1U<&QO861;
M)VEM9R==(#T@0'5N<V5R:6%L:7IE*"1U<&QO861;)VEM9R==*3L*"B`@("`@
M("`@("`@("\J($=E="!T:&4@=&5M<"!F:6QE(&EF(&%L<F5A9'D@;VYE('5P
M;&]A9&5D+"!O=&AE<G=I<V4@8W)E871E(&$*("`@("`@("`@("`@("H@;F5W
M('1E;7!O<F%R>2!F:6QE+B`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1U
M<&QO861;)VEM9R==6R=F:6QE)UTI*2!["B`@("`@("`@("`@("`@("`D=&UP
M7V9I;&4@/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R\G("X@)'5P;&]A9%LG
M:6UG)UU;)V9I;&4G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T;7!?9FEL92`]($AO<F1E.CIG971496UP1FEL92@G2&]R9&4G
M+"!F86QS92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($UO=F4@
M=&AE(&)R;W=S97(@8W)E871E9"!T96UP(&9I;&4@=&\@=&AE(&YE=R!T96UP
M(&9I;&4N("HO"B`@("`@("`@("`@(&UO=F5?=7!L;V%D961?9FEL92@D=&AI
M<RT^7VEM9ULG9FEL92==+"`D=&UP7V9I;&4I.PH@("`@("`@("`@("`D=&AI
M<RT^7VEM9ULG9FEL92==(#T@8F%S96YA;64H)'1M<%]F:6QE*3L*"B`@("`@
M("`@("`@("\J(%-T;W)E('1H92!U<&QO861E9"!I;6%G92!F:6QE(&1A=&$@
M=&\@=&AE(&AI9&1E;B!F:65L9"X@*B\*("`@("`@("`@("`@)'5P;&]A9%LG
M:6UG)UT@/2!S97)I86QI>F4H)'1H:7,M/E]I;6<I.PH@("`@("`@("`@("`D
M=F%R<RT^<V5T*"1V87(M/F=E=%9A<DYA;64H*2P@)'5P;&]A9"D["B`@("`@
M("`@?2!E;'-E:68@*"1T:&ES+3Y?=7!L;V%D960I('L*("`@("`@("`@("`@
M+RH@1FEL92!H87,@;F]T(&)E96X@=7!L;V%D960N("HO"B`@("`@("`@("`@
M("1U<&QO860@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7W5P;&]A9&5D+3YG971#;V1E*"D@/3T@
M-"`F)B`A96UP='DH)'5P;&]A9%LG:6UG)UTI*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VEM9R`]($!U;G-E<FEA;&EZ92@D=7!L;V%D6R=I;6<G72D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T57!L;V%D961&:6QE5'EP92@D9FEE;&0I"B`@("!["B`@("`@("`@+RH@
M1V5T(&%N>2!I;F1E>"!O;B!T:&4@9FEE;&0@;F%M92X@*B\*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@)&EN9&5X
M(#T@2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H)&9I96QD+"`D8F%S92P@
M)&ME>7,I.PH*("`@("`@("!I9B`H)&EN9&5X*2!["B`@("`@("`@("`@("\J
M($EN9&5X('!R97-E;G0L(&9E=&-H('1H92!M:6UE('1Y<&4@=F%R('1O(&-H
M96-K+B`J+PH@("`@("`@("`@("`D:V5Y<U]P871H(#T@87)R87E?;65R9V4H
M87)R87DH)&)A<V4L("=T>7!E)RDL("1K97ES*3L*("`@("`@("`@("`@)'1Y
M<&4@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P
M871H*3L*("`@("`@("`@("`@)&ME>7-?<&%T:#T@87)R87E?;65R9V4H87)R
M87DH)&)A<V4L("=T;7!?;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("1T
M;7!?;F%M92`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?1DE,15,L("1K
M97ES7W!A=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO
M(&EN9&5X+"!S:6UP;&4@<V5T('5P(&]F('9A<G,@=&\@8VAE8VLN("HO"B`@
M("`@("`@("`@("1T>7!E(#T@)%]&24Q%4ULD9FEE;&1=6R=T>7!E)UT["B`@
M("`@("`@("`@("1T;7!?;F%M92`]("1?1DE,15-;)&9I96QD75LG=&UP7VYA
M;64G73L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D='EP92D@?'P@
M*"1T>7!E(#T]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2D@>PH@("`@
M("`@("`@("`O*B!4>7!E('=A<VXG="!S970@;VX@=7!L;V%D+"!T<GD@86YA
M;&ES:6YG('1H92!U<&QO860N("HO"B`@("`@("`@("`@(&=L;V)A;"`D8V]N
M9CL*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUA9VEC
M+G!H<"<["B`@("`@("`@("`@(&EF("@A*"1T>7!E(#T@34E-15]-86=I8SHZ
M86YA;'EZ949I;&4H)'1M<%]N86UE+"!I<W-E="@D8V]N9ELG;6EM92==6R=M
M86=I8U]D8B==*2`_("1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UT@.B!N=6QL
M*2DI('L*("`@("`@("`@("`@("`@(&EF("@D:6YD97@I('L*("`@("`@("`@
M("`@("`@("`@("`O*B!'970@=&AE(&YA;64@=F%L=64N("HO"B`@("`@("`@
M("`@("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B
M87-E+"`G;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@)&YA
M;64@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P
M871H*3L*"B`@("`@("`@("`@("`@("`@("`@+RH@5V]R:R!O=70@=&AE('1Y
M<&4@9G)O;2!T:&4@9FEL92!N86UE+B`J+PH@("`@("`@("`@("`@("`@("`@
M("1T>7!E(#T@34E-15]-86=I8SHZ9FEL96YA;654;TU)344H)&YA;64I.PH*
M("`@("`@("`@("`@("`@("`@("`O*B!3970@=&AE('1Y<&4N("HO"B`@("`@
M("`@("`@("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y
M*"1B87-E+"`G='EP92<I+"`D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@
M2&]R9&5?07)R87DZ.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"P@
M)'1Y<&4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`O*B!7;W)K(&]U="!T:&4@='EP92!F<F]M('1H92!F:6QE(&YA
M;64N("HO"B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2!-24U%7TUA9VEC
M.CIF:6QE;F%M951O34E-12@D7T9)3$536R1F:65L9%U;)VYA;64G72D["@H@
M("`@("`@("`@("`@("`@("`@("\J(%-E="!T:&4@='EP92X@*B\*("`@("`@
M("`@("`@("`@("`@("`D7T9)3$536R1F:65L9%U;)W1Y<&4G72`]($U)345?
M36%G:6,Z.F9I;&5N86UE5&]-24U%*"1?1DE,15-;)&9I96QD75LG;F%M92==
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3&]A9',@86YY(&5X:7-T:6YG(&EM86=E(&1A=&$@:6YT;R!T:&4@:6UA9V4@
M9FEE;&0N(%)E<75I<F5S('1H870@=&AE"B`@("`@*B!A<G)A>2`D:6UA9V4@
M<&%S<V5D('1O(&ET(&-O;G1A:6YS('1H92!S=')U8W1U<F4Z"B`@("`@*B`@
M("1I;6%G95LG;&]A9"==6R=F:6QE)UT@+2!T:&4@9FEL96YA;64@;V8@=&AE
M(&EM86=E.PH@("`@("H@("`D:6UA9V5;)VQO860G75LG9&%T82==("T@=&AE
M(')A=R!I;6%G92!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D:6UA9V4@(%1H92!I;6%G
M92!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861);6%G941A=&$H
M)B1I;6%G92D*("`@('L*("`@("`@("`O*B!.;R!E>&ES=&EN9R!I;6%G92!D
M871A('1O(&QO860N("HO"B`@("`@("`@:68@*"%I<W-E="@D:6UA9V5;)VQO
M860G72DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4V%V92!T:&4@9&%T82!T;R!T:&4@=&5M<"!D:7(N("HO"B`@("`@
M("`@)'1M<%]F:6QE(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*2`N("<O)R`N("1I
M;6%G95LG;&]A9"==6R=F:6QE)UT["B`@("`@("`@:68@*"1F9"`](&9O<&5N
M*"1T;7!?9FEL92P@)W<G*2D@>PH@("`@("`@("`@("!F=W)I=&4H)&9D+"`D
M:6UA9V5;)VQO860G75LG9&%T82==*3L*("`@("`@("`@("`@9F-L;W-E*"1F
M9"D["B`@("`@("`@?0H*("`@("`@("`D:6UA9V5;)VEM9R==(#T@<V5R:6%L
M:7IE*&%R<F%Y*"=F:6QE)R`]/B`D:6UA9V5;)VQO860G75LG9FEL92==*2D[
M"B`@("`@("`@=6YS970H)&EM86=E6R=L;V%D)UTI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`]
M(&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*"));6%G92!U
M<&QO860B*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@
M("`@("`@("`@("=S:&]W7W5P;&]A9"<@("`]/B!A<G)A>2@G;&%B96PG(#T^
M(%\H(E-H;W<@=7!L;V%D(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G='EP92<@(#T^("=B;V]L96%N)RDL"B`@("`@("`@("`@
M("=S:&]W7VME97!O<FEG)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86PB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)V)O;VQE86XG*2D["B`@
M("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]B;V]L96%N(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@
M("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M
M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@
M>PH@("`@("`@("1I;F9O(#T@4W1R:6YG.CIL;W=E<B@D=F%R<RT^9V5T*"1V
M87(M/F=E=%9A<DYA;64H*2DI(#T]("=O;B<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R
M87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E1R=64@;W(@9F%L
M<V4B*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@
M2&]R9&5?1F]R;5]4>7!E7VQI;FL@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@
M>PH*("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E<RD*("`@('L*("`@("`@("`D
M=&AI<RT^=F%L=65S(#T@)'9A;'5E<SL*("`@('T*"B`@("!F=6YC=&EO;B!I
M<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@
M>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D[
M"B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*"),:6YK(BD["B`@("`@("`@
M<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]E;6%I;"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?
M86QL;W=?;75L=&D@/2!F86QS93L*("`@('9A<B`D7W-T<FEP7V1O;6%I;B`]
M(&9A;'-E.PH@("`@=F%R("1?;&EN:U]C;VUP;W-E(#T@9F%L<V4["B`@("!V
M87(@)%]L:6YK7VYA;64@/2!N=6QL.PH*("`@(&9U;F-T:6]N(&EN:70H)&%L
M;&]W7VUU;'1I(#T@9F%L<V4L("1S=')I<%]D;VUA:6X@/2!F86QS92P*("`@
M("`@("`@("`@("`@("`@)&QI;FM?8V]M<&]S92`](&9A;'-E+"`D;&EN:U]N
M86UE(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7V%L;&]W7VUU;'1I
M(#T@)&%L;&]W7VUU;'1I.PH@("`@("`@("1T:&ES+3Y?<W1R:7!?9&]M86EN
M(#T@)'-T<FEP7V1O;6%I;CL*("`@("`@("`D=&AI<RT^7VQI;FM?8V]M<&]S
M92`]("1L:6YK7V-O;7!O<V4["B`@("`@("`@)'1H:7,M/E]L:6YK7VYA;64@
M/2`D;&EN:U]N86UE.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V
M87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I*2!["B`@
M("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS
M96EF("@A96UP='DH)'9A;'5E*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@("`@("1P87)S97(@/2`F
M;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@("`@("1P87)S961?96UA:6P@
M/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1V86QU92P@9F%L<V4L('1R
M=64I.PH*("`@("`@("`@("`@:68@*&ES7V$H)'!A<G-E9%]E;6%I;"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D<&%R
M<V5D7V5M86EL+3YG971-97-S86=E*"D["B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"@A)'1H
M:7,M/E]A;&QO=U]M=6QT:2D@)B8@8V]U;G0H)'!A<G-E9%]E;6%I;"D@/B`Q
M*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(D]N;'D@;VYE(&5M
M86EL(&%D9')E<W,@86QL;W=E9"XB*3L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H96UP='DH
M)'!A<G-E9%]E;6%I;%LP72T^;6%I;&)O>"DI('L*("`@("`@("`@("`@("`@
M("1M97-S86=E(#T@7R@B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+B(I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD
M('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@
M("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==
M(#T@7R@B16UA:6PB*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R
M87DH"B`@("`@("`@("`@("=A;&QO=U]M=6QT:2<@/3X@87)R87DH)VQA8F5L
M)R`]/B!?*")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=B;V]L96%N
M)RDL"B`@("`@("`@("`@("=S=')I<%]D;VUA:6XG(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=B
M;V]L96%N)RDL"B`@("`@("`@("`@("=L:6YK7V-O;7!O<V4G(#T^(&%R<F%Y
M*"=L86)E;"<@/3X@7R@B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)V)O;VQE86XG*2P*
M("`@("`@("`@("`@)VQI;FM?;F%M92<@/3X@87)R87DH)VQA8F5L)R`]/B!?
M*")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G(#T^("=T97AT)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@
M("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?;6%T<FEX(&5X=&5N9',@
M2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]C;VQS.PH@("`@=F%R("1?
M<F]W<SL*("`@('9A<B`D7VUA=')I>#L*("`@('9A<B`D7VYE=U]I;G!U=#L*
M"B`@("`O*BH*("`@("`J($EN:71I86QI>F5S('1H92!V87)I86)L92X*("`@
M("`J"B`@("`@*B!`97AA;7!L90H@("`@("H@:6YI="AA<G)A>2@G0V]L=6UN
M($$G+"`G0V]L=6UN($(G*2P*("`@("`J("`@("`@87)R87DH,2`]/B`G4F]W
M($]N92<L(#(@/3X@)U)O=R`R)RP@,R`]/B`G4F]W(#,G*2P*("`@("`J("`@
M("`@87)R87DH87)R87DH=')U92P@=')U92P@9F%L<V4I+`H@("`@("H@("`@
M("`@("`@("!A<G)A>2AT<G5E+"!F86QS92P@=')U92DL"B`@("`@*B`@("`@
M("`@("`@(&%R<F%Y*&9A<VQE+"!T<G5E+"!F86QS92DI+`H@("`@("H@("`@
M("!A<G)A>2@G4F]W(#0G+"`G4F]W(#4G*2D["B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1C;VQS("`@("`@("`@("`@("`@02!L:7-T(&]F(&-O;'5M
M;B!H96%D97)S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1R;W=S("`@("`@("`@
M("`@("`@02!H87-H('=I=&@@<F]W($E$<R!A<R!T:&4@:V5Y<R!A;F0@<F]W
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L86)E
M;',@87,@=&AE('9A;'5E<RX*("`@("`J($!P87)A;2!A<G)A>2`D;6%T<FEX
M("`@("`@("`@("`@($$@='=O(&1I;65N<VEO;F%L(&AA<V@@=VET:"!T:&4@
M9FEE;&0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('9A;'5E<RX*("`@("`J($!P87)A;2!B;V]L96%N?&%R<F%Y("1N97=?:6YP
M=70@($EF('1R=64L(&$@9G)E92!T97AT(&9I96QD('1O(&%D9"!A(&YE=PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F]W(&ES
M(&1I<W!L87EE9"!O;B!T:&4@=&]P+"!A('-E;&5C=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8F]X(&EF('1H:7,@<&%R86UE
M=&5R(&ES(&$@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H)&-O
M;',L("1R;W=S(#T@87)R87DH*2P@)&UA=')I>"`](&%R<F%Y*"DL("1N97=?
M:6YP=70@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7V-O;',@("`@
M("`@/2`D8V]L<SL*("`@("`@("`D=&AI<RT^7W)O=W,@("`@("`@/2`D<F]W
M<SL*("`@("`@("`D=&AI<RT^7VUA=')I>"`@("`@/2`D;6%T<FEX.PH@("`@
M("`@("1T:&ES+3Y?;F5W7VEN<'5T("`]("1N97=?:6YP=70["B`@("!]"@H@
M("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D
M;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971#;VQS*"D@("`@('L@<F5T=7)N("1T:&ES+3Y?8V]L
M<SL@?0H@("`@9G5N8W1I;VX@9V5T4F]W<R@I("`@("![(')E='5R;B`D=&AI
M<RT^7W)O=W,[('T*("`@(&9U;F-T:6]N(&=E=$UA=')I>"@I("`@>R!R971U
M<FX@)'1H:7,M/E]M871R:7@[('T*("`@(&9U;F-T:6]N(&=E=$YE=TEN<'5T
M*"D@>R!R971U<FX@)'1H:7,M/E]N97=?:6YP=70[('T*"B`@("!F=6YC=&EO
M;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@
M("`D=F%L=65S(#T@)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@
M("`@("`@(&EF("@A96UP='DH)'9A;'5E<ULG;B==6R=R)UTI("8F(&ES<V5T
M*"1V86QU97-;)VXG75LG=B==*2D@>PH@("`@("`@("`@("`D;F5W7W)O=R`]
M("1V86QU97-;)VXG75LG<B==.PH@("`@("`@("`@("`D=F%L=65S6R=R)UU;
M)&YE=U]R;W==(#T@)'9A;'5E<ULG;B==6R=V)UT["B`@("`@("`@("`@('5N
M<V5T*"1V86QU97-;)VXG72D["B`@("`@("`@?0H*("`@("`@("`D:6YF;R`]
M("AI<W-E="@D=F%L=65S6R=R)UTI(#\@)'9A;'5E<ULG<B==(#H@87)R87DH
M*2D["B`@("!]"@H@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@
M("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?
M*")&:65L9"!M871R:7@B*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@
M87)R87DH"B`@("`@("`@("`@("=C;VQS)R`]/B!A<G)A>2@G;&%B96PG(#T^
M(%\H(D-O;'5M;B!T:71L97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2D["B`@("`@("`@<F5T=7)N
M("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]E;6%I
M;$-O;F9I<FT@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T
M:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I
M"B`@("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T
M>2@D=F%L=65;)V]R:6=I;F%L)UTI*2!["B`@("`@("`@("`@("1M97-S86=E
M(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"1V86QU95LG
M;W)I9VEN86PG72`A/2`D=F%L=65;)V-O;F9I<FTG72D@>PH@("`@("`@("`@
M("`D;65S<V%G92`](%\H(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(I
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+U)&0S@R,BYP:'`G.PH@
M("`@("`@("`@("`D<&%R<V5R(#T@)FYE=R!-86EL7U)&0S@R,B@I.PH@("`@
M("`@("`@("`D<&%R<V5D7V5M86EL(#T@)'!A<G-E<BT^<&%R<V5!9&1R97-S
M3&ES="@D=F%L=65;)V]R:6=I;F%L)UTL(&9A;'-E+"!T<G5E*3L*"B`@("`@
M("`@("`@(&EF("AC;W5N="@D<&%R<V5D7V5M86EL*2`^(#$I('L*("`@("`@
M("`@("`@("`@("1M97-S86=E(#T@7R@B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AE;7!T>2@D<&%R<V5D7V5M
M86EL6S!=+3YM86EL8F]X*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2!?*")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N
M(BD["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U
M="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;B(I.PH@("`@("`@(')E='5R;B`D86)O=70[
M"B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?<&%S<W=O<F0@97AT
M96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H
M)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@
M("`@)'9A;&ED(#T@=')U93L*"B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER
M960H*2D@>PH@("`@("`@("`@("`D=F%L:60@/2!S=')L96XH=')I;2@D=F%L
M=64I*2`^(#`["@H@("`@("`@("`@("!I9B`H(21V86QI9"D@>PH@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D
M+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O
M=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@
M("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T
M6R=N86UE)UT@/2!?*")087-S=V]R9"(I.PH@("`@("`@(')E='5R;B`D86)O
M=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?<&%S<W=O<F1#
M;VYF:7)M(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC=&EO
M;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@
M("`@>PH@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"D@)B8@96UP='DH
M)'9A;'5E6R=O<FEG:6YA;"==*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]
M(%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=F%L=65;)V]R
M:6=I;F%L)UT@(3T@)'9A;'5E6R=C;VYF:7)M)UTI('L*("`@("`@("`@("`@
M)&UE<W-A9V4@/2!?*")087-S=V]R9',@;75S="!M871C:"XB*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T26YF;R@F)'9A<G,L("8D
M=F%R+"`F)&EN9F\I"B`@("!["B`@("`@("`@)'9A;'5E(#T@)'9A<G,M/F=E
M="@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@("1I;F9O(#T@)'9A;'5E
M6R=O<FEG:6YA;"==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN
M9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O
M=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@
M)&%B;W5T6R=N86UE)UT@/2!?*")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(
M;W)D95]&;W)M7U1Y<&5?96YU;2!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92![
M"@H@("`@=F%R("1?=F%L=65S.PH@("`@=F%R("1?<')O;7!T.PH*("`@(&9U
M;F-T:6]N(&EN:70H)'9A;'5E<RP@)'!R;VUP="`](&YU;&PI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]V86QU97,@/2`D=F%L=65S.PH*("`@("`@("!I9B`H
M)'!R;VUP="`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R;VUP
M="`](%\H(BTM('-E;&5C="`M+2(I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3Y?<')O;7!T(#T@)'!R;VUP=#L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L
M=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A<BT^:7-297%U
M:7)E9"@I("8F("1V86QU92`]/2`G)R`F)B`A:7-S970H)'1H:7,M/E]V86QU
M97-;)'9A;'5E72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]V86QU
M97,I(#T](#`@?'P@:7-S970H)'1H:7,M/E]V86QU97-;)'9A;'5E72D@?'P*
M("`@("`@("`@("`@*"1T:&ES+3Y?<')O;7!T("8F(&5M<'1Y*"1V86QU92DI
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@
M("`@)&UE<W-A9V4@/2!?*"));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(I.PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G9716
M86QU97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;'5E<SL*
M("`@('T*"B`@("!F=6YC=&EO;B!G9710<F]M<'0H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!R;VUP=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I
M.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B1')O<"!D;W=N(&QI<W0B
M*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@
M("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S('1O
M('-E;&5C="!F<F]M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@("`@("`@)W!R;VUP
M="<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")0<F]M<'0@=&5X="(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI
M.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D
M95]&;W)M7U1Y<&5?;6QE;G5M(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*
M"B`@("!V87(@)%]V86QU97,["B`@("!V87(@)%]P<F]M<'1S.PH*("`@(&9U
M;F-T:6]N(&EN:70H)B1V86QU97,L("1P<F]M<'1S(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W9A;'5E<R`]("8D=F%L=65S.PH*("`@("`@("!I
M9B`H)'!R;VUP=',@/3T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/E]P
M<F]M<'1S(#T@87)R87DH7R@B+2T@<V5L96-T("TM(BDL(%\H(BTM('-E;&5C
M="`M+2(I*3L*("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1P<F]M<'1S
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R;VUP=',@/2!A<G)A>2@D<')O
M;7!T<RP@)'!R;VUP=',I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3Y?<')O;7!T<R`]("1P<F]M<'1S.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!O;E-U8FUI="@F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@("1V87)N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@
M("1V86QU92`]("1V87)S+3YG970H)'9A<FYA;64I.PH*("`@("`@("!I9B`H
M)'9A;'5E6R<Q)UT@(3T@)'9A;'5E6R=O;&0G72D@>PH@("`@("`@("`@("`D
M=F%R+3YF;W)M+3YS9713=6)M:71T960H9F%L<V4I.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU
M92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(&EF("@D=F%R+3YI<U)E<75I
M<F5D*"D@)B8@*&5M<'1Y*"1V86QU95LG,2==*2!\?"!E;7!T>2@D=F%L=65;
M)S(G72DI*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7W9A;'5E<RD@
M?'P@:7-S970H)'1H:7,M/E]V86QU97-;)'9A;'5E6R<Q)UU=*2!\?`H@("`@
M("`@("`@("`H(65M<'1Y*"1T:&ES+3Y?<')O;7!T<RD@)B8@96UP='DH)'9A
M;'5E6R<Q)UTI*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B26YV86QI9"!D871A('-U8FUI
M='1E9"XB*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T5F%L=65S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]V86QU97,["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4')O;7!T<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')O;7!T<SL*("`@('T*"B`@
M("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@
M('L*("`@("`@("`D:6YF;R`]("1V87)S+3YG970H)'9A<BT^9V5T5F%R3F%M
M92@I*3L*("`@("`@("!R971U<FX@)&EN9F];)S(G73L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@
M/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S(BD["B`@("`@("`@)&%B;W5T6R=P87)A
M;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@G
M;&%B96PG(#T^(%\H(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=S=')I;F=L:7-T
M)RDL"B`@("`@("`@("`@("=P<F]M<'0G(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B4')O;7!T('1E>'0B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`]/B`G=&5X="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T
M.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VUU;'1I96YU;2!E
M>'1E;F1S($AO<F1E7T9O<FU?5'EP95]E;G5M('L*"B`@("!V87(@)'-I>F4@
M/2`U.PH*("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E<RP@)'-I>F4@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D<VEZ92DI('L*("`@("`@
M("`@("`@)'1H:7,M/G-I>F4@/2`H:6YT*21S:7IE.PH@("`@("`@('T*"B`@
M("`@("`@<&%R96YT.CII;FET*"1V86QU97,I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1V86PI('L*("`@("`@("`@("`@
M("`@(&EF("@A)'1H:7,M/FES5F%L:60H)'9A<BP@)'9A<G,L("1V86PL("1M
M97-S86=E*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=F%L
M=64I("8F("@H<W1R:6YG*2AI;G0I)'9A;'5E("$]/2`D=F%L=64I*2!["B`@
M("`@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"DI('L*("`@("`@("`@
M("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB
M*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]V
M86QU97,I(#T](#`@?'P@:7-S970H)'1H:7,M/E]V86QU97-;)'9A;'5E72DI
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("`D;65S<V%G92`](%\H(DEN=F%L:60@9&%T82!S=6)M:71T960N(BD["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@
M("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")-=6QT:7!L92!S96QE8W1I;VXB
M*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@
M("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T
M<FEN9VQI<W0G*2P*("`@("`@("`@("`@)W-I>F4G("`@/3X@87)R87DH)VQA
M8F5L)R`]/B!?*")3:7IE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)VEN="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T
M.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W)A9&EO(&5X=&5N
M9',@2&]R9&5?1F]R;5]4>7!E7V5N=6T@>PH*("`@("\J($5N=&ER96QY(&EM
M<&QE;65N=&5D(&)Y($AO<F1E7T9O<FU?5'EP95]E;G5M.R!J=7-T(&$@9&EF
M9F5R96YT"B`@("`@*B!V:65W+B`J+PH*("`@("\J*@H@("`@("H@4F5T=7)N
M(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@
M("`@)&%B;W5T6R=N86UE)UT@/2!?*")2861I;R!S96QE8W1I;VXB*3L*("`@
M("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=V
M86QU97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI
M<W0G*2D["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S
M($AO<F1E7T9O<FU?5'EP95]S970@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@
M>PH*("`@('9A<B`D7W9A;'5E<SL*("`@('9A<B`D7V-H96-K06QL(#T@9F%L
M<V4["@H@("`@9G5N8W1I;VX@:6YI="@F)'9A;'5E<RP@)&-H96-K06QL(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]V86QU97,@/2`D=F%L=65S
M.PH@("`@("`@("1T:&ES+3Y?8VAE8VM!;&P@/2`D8VAE8VM!;&P["B`@("!]
M"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L
M("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]V
M86QU97,I(#T](#`@?'P@8V]U;G0H)'9A;'5E*2`]/2`P*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D
M=F%L=64@87,@)&ET96TI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W9A;'5E<ULD:71E;5TI*2!["B`@("`@("`@("`@("`@("`D97)R;W(@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D97)R;W(I*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A
M9V4@/2!?*"));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(I.PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971686QU97,H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;'5E<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O
M=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B4V5T
M(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@
M("`@("`G=F%L=65S)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E9A;'5E<R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=S
M=')I;F=L:7-T)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]
M"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?9&%T92!E>'1E;F1S($AO<F1E7T9O
M<FU?5'EP92!["@H@("`@=F%R("1?9F]R;6%T.PH*("`@(&9U;F-T:6]N(&EN
M:70H)&9O<FUA="`]("<E82`E9"`E0B<I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]F;W)M870@/2`D9F]R;6%T.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L
M:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@
M("`@("`@)'9A;&ED(#T@=')U93L*"B`@("`@("`@:68@*"1V87(M/FES4F5Q
M=6ER960H*2D@>PH@("`@("`@("`@("`D=F%L:60@/2!S=')L96XH=')I;2@D
M=F%L=64I*2`^(#`["@H@("`@("`@("`@("!I9B`H(21V86QI9"D@>PH@("`@
M("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(B5S(&ES(')E<75I
M<F5D(BDL("1V87(M/F=E=$AU;6%N3F%M92@I*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V86QI9#L*("`@('T*"B`@("`O
M*BH*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06=O
M*"1T:6UE<W1A;7`I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=$871E
M+T-A;&,N<&AP)SL*("`@("`@("`D9&EF9F1A>7,@/2!$871E7T-A;&,Z.F1A
M=&5$:69F*&1A=&4H)VHG+"`D=&EM97-T86UP*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&1A=&4H)VXG+"`D=&EM97-T86UP
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1A
M=&4H)UDG+"`D=&EM97-T86UP*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&1A=&4H)VHG*2P@9&%T92@G;B<I+"!D871E*"=9
M)RDI.PH*("`@("`@("`O*B!!;B!E<G)O<B!O8V-U<F5D+B`J+PH@("`@("`@
M(&EF("@D9&EF9F1A>7,@/3T@+3$I('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@)&%G;R`]("1D:69F9&%Y<R`J($1A=&5?0V%L
M8SHZ8V]M<&%R941A=&5S*&1A=&4H)VHG+"`D=&EM97-T86UP*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9&%T92@G;B<L("1T:6UE<W1A;7`I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D871E*"=9)RP@)'1I;65S
M=&%M<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&1A=&4H)VHG*2P@9&%T92@G;B<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D871E
M*"=9)RDI.PH@("`@("`@(&EF("@D86=O(#P@+3$I('L*("`@("`@("`@("`@
M<F5T=7)N('-P<FEN=&8H7R@B("@E<R!D87ES(&%G;RDB*2P@)&1I9F9D87ES
M*3L*("`@("`@("!](&5L<V5I9B`H)&%G;R`]/2`M,2D@>PH@("`@("`@("`@
M("!R971U<FX@7R@B("AY97-T97)D87DI(BD["B`@("`@("`@?2!E;'-E:68@
M*"1A9V\@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@7R@B("AT;V1A>2DB
M*3L*("`@("`@("!](&5L<V5I9B`H)&%G;R`]/2`Q*2!["B`@("`@("`@("`@
M(')E='5R;B!?*"(@*'1O;6]R<F]W*2(I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!S<')I;G1F*%\H(B`H:6X@)7,@9&%Y<RDB*2P@
M)&1I9F9D87ES*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M1F]R;6%T=&5D5&EM92@D=&EM97-T86UP+"`D9F]R;6%T(#T@;G5L;"P@)'-H
M;W=A9V\@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D9F]R;6%T
M*2D@>PH@("`@("`@("`@("`D9F]R;6%T(#T@)'1H:7,M/E]F;W)M870["B`@
M("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'1I;65S=&%M<"DI('L*("`@
M("`@("`@("`@<F5T=7)N('-T<F9T:6UE*"1F;W)M870L("1T:6UE<W1A;7`I
M("X@*"1S:&]W86=O(#\@2&]R9&5?1F]R;5]4>7!E7V1A=&4Z.F=E=$%G;R@D
M=&EM97-T86UP*2`Z("<G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G;F%M
M92<@/3X@7R@B1&%T92(I*3L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?
M5'EP95]T:6UE(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC
M=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E
M*0H@("`@>PH@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"D@)B8@96UP
M='DH)'9A;'5E*2`F)B`H*'-T<FEN9RDH9&]U8FQE*21V86QU92`A/3T@)'9A
M;'5E*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=F%L=64I('Q\('!R96=?;6%T
M8V@H)R]>6S`M,ET_6S`M.5TZ6S`M-5U;,"TY720O)RP@)'9A;'5E*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M
M97-S86=E(#T@7R@B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BXB*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T
M>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")4:6UE(BDI.PH@("`@?0H*
M?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VAO=7)-:6YU=&5396-O;F0@97AT
M96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W-H;W=?<V5C;VYD
M<SL*"B`@("!F=6YC=&EO;B!I;FET*"1S:&]W7W-E8V]N9',@/2!F86QS92D*
M("`@('L*("`@("`@("`D=&AI<RT^7W-H;W=?<V5C;VYD<R`]("1S:&]W7W-E
M8V]N9',["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D=&EM92`]
M("1V87)S+3YG970H)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!I9B`H
M(21T:&ES+3Y?<VAO=U]S96-O;F1S("8F("%I<W-E="@D=&EM95LG<V5C;VYD
M)UTI*2!["B`@("`@("`@("`@("1T:6UE6R=S96-O;F0G72`](#`["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YE;7!T>51I;65!<G)A>2@D=&EM
M92D@)B8@(21T:&ES+3YC:&5C:W1I;64H)'1I;65;)VAO=7(G72P@)'1I;65;
M)VUI;G5T92==+"`D=&EM95LG<V5C;VYD)UTI*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@7R@B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("@D=&AI
M<RT^96UP='E4:6UE07)R87DH)'1I;64I("8F("1V87(M/FES4F5Q=6ER960H
M*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&-H96-K=&EM92@D:&]U<BP@)&UI;G5T92P@)'-E8V]N9"D*("`@('L*("`@
M("`@("!I9B`H(6ES<V5T*"1H;W5R*2!\?"`D:&]U<B`]/2`G)R!\?"`H)&AO
M=7(@/"`P('Q\("1H;W5R(#X@,C,I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D;6EN=71E*2!\
M?"`D;6EN=71E(#T]("<G('Q\("@D;6EN=71E(#P@,"!\?"`D;6EN=71E(#X@
M-C`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@:68@*"%I<W-E="@D<V5C;VYD*2!\?"`D<V5C;VYD(#T]/2`G)R!\
M?"`H)'-E8V]N9"`\(#`@?'P@)'-E8V]N9"`^(#8P*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@=&EM92!S=7!P
M;&EE9"!A<R!A($AO<F1E7T1A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1I;65?:6X@($1A=&4@:6X@;VYE(&]F('1H92!T:')E
M92!F;W)M871S('-U<'!O<G1E9"!B>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@2&]R9&5?1F]R;2!A;F0@2&]R9&5?1&%T92`H25-/(&9O<FUA
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@65E962U-32U$1"!(
M2#I-33I34RP@=&EM97-T86UP(%E965E-341$2$A-35-3(&%N9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@54Y)6"!E<&]C:"DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!$871E("!4:&4@=&EM92!O8FIE8W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%1I;65/8B@D=&EM95]I;BD*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+T1A=&4N<&AP)SL*"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1T:6UE7VEN*2D@>PH@("`@("`@("`@("!I9B`H(21T:&ES
M+3YE;7!T>51I;65!<G)A>2@D=&EM95]I;BDI('L*("`@("`@("`@("`@("`@
M("1T:6UE7VEN(#T@<W!R:6YT9B@G,3DW,"TP,2TP,2`E,#)D.B4P,F0Z)3`R
M9"<L("1T:6UE7VEN6R=H;W5R)UTL("1T:6UE7VEN6R=M:6YU=&4G72P@)'1I
M;65?:6Y;)W-E8V]N9"==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&YE=R!(;W)D95]$871E*"1T:6UE7VEN*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@=&EM92!S=7!P;&EE9"!S<&QI
M="!U<"!I;G1O(&%N(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1I;65?:6X@(%1I;64@:6X@;VYE(&]F('1H92!T:')E92!F;W)M871S
M('-U<'!O<G1E9"!B>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M2&]R9&5?1F]R;2!A;F0@2&]R9&5?1&%T92`H25-/(&9O<FUA=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@65E962U-32U$1"!(2#I-33I34RP@
M=&EM97-T86UP(%E965E-341$2$A-35-3(&%N9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@54Y)6"!E<&]C:"DN"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@07)R87D@=VET:"!T:')E92!E;&5M96YT<R`M(&AO=7(L
M(&UI;G5T92!A;F0@<V5C;VYD<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M5&EM95!A<G1S*"1T:6UE7VEN*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D=&EM95]I;BDI('L*("`@("`@("`@("`@+RH@5&AI<R!I<R!P<F]B86)L
M>2!A(&9A:6QE9"!I<U9A;&ED(&EN<'5T('-O(&IU<W0@<F5T=7)N('1H90H@
M("`@("`@("`@("`@*B!P87)T<R!A<R!T:&5Y(&%R92X@*B\*("`@("`@("`@
M("`@<F5T=7)N("1T:6UE7VEN.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D
M=&EM95]I;BDI('L*("`@("`@("`@("`@+RH@5&AI<R!I<R!J=7-T(&%N(&5M
M<'1Y(&9I96QD('-O(')E='5R;B!E;7!T>2!P87)T<RX@*B\*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=H;W5R)R`]/B`G)RP@)VUI;G5T92<@/3X@)R<L
M("=S96-O;F0G(#T^("<G*3L*("`@("`@("!]"B`@("`@("`@)'1I;64@/2`D
M=&AI<RT^9V5T5&EM94]B*"1T:6UE7VEN*3L*("`@("`@("!R971U<FX@87)R
M87DH)VAO=7(G(#T^("1T:6UE+3YH;W5R+`H@("`@("`@("`@("`@("`@("`@
M("`G;6EN=71E)R`]/B`D=&EM92T^;6EN+`H@("`@("`@("`@("`@("`@("`@
M("`G<V5C;VYD)R`]/B`D=&EM92T^<V5C*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!E;7!T>51I;65!<G)A>2@D=&EM92D*("`@('L*("`@("`@("!R971U<FX@
M*&ES7V%R<F%Y*"1T:6UE*2`F)B!E;7!T>2@D=&EM95LG:&]U<B==*2`F)B!E
M;7!T>2@D=&EM95LG;6EN=71E)UTI("8F(&5M<'1Y*"1T:6UE6R=S96-O;F0G
M72DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@
M9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@
M>PH@("`@("`@(')E='5R;B!A<G)A>2@G;F%M92<@/3X@7R@B5&EM92!S96QE
M8W1I;VXB*2D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?;6]N
M=&A996%R(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]S
M=&%R=%]Y96%R.PH@("`@=F%R("1?96YD7WEE87(["@H@("`@9G5N8W1I;VX@
M:6YI="@D<W1A<G1?>65A<B`](&YU;&PL("1E;F1?>65A<B`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1S=&%R=%]Y96%R*2D@>PH@("`@("`@
M("`@("`D<W1A<G1?>65A<B`](#$Y,C`["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D96YD7WEE87(I*2!["B`@("`@("`@("`@("1E;F1?>65A<B`]
M(&1A=&4H)UDG*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<W1A<G1?
M>65A<B`]("1S=&%R=%]Y96%R.PH@("`@("`@("1T:&ES+3Y?96YD7WEE87(@
M/2`D96YD7WEE87(["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A
M<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I
M9B`H(21V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'9A<G,M/F=E="@D=&AI
M<RT^9V5T36]N=&A687(H)'9A<BDI('Q\"B`@("`@("`@("`@("$D=F%R<RT^
M9V5T*"1T:&ES+3YG971996%R5F%R*"1V87(I*2D@>PH@("`@("`@("`@("`D
M;65S<V%G92`](%\H(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$UO;G1H
M5F%R*"1V87(I"B`@("!["B`@("`@("`@<F5T=7)N("1V87(M/F=E=%9A<DYA
M;64H*2`N("=;;6]N=&A=)SL*("`@('T*"B`@("!F=6YC=&EO;B!G971996%R
M5F%R*"1V87(I"B`@("!["B`@("`@("`@<F5T=7)N("1V87(M/F=E=%9A<DYA
M;64H*2`N("=;>65A<ETG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G;F%M92<@/3X@
M7R@B36]N=&@@86YD('EE87(B*2P*("`@("`@("`@("`@("`@("`@("`@)W!A
M<F%M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`G<W1A
M<G1?>65A<B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3=&%R="!Y96%R(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)V5N9%]Y96%R)R`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B
M16YD('EE87(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@(#T^("=S=')I;F=L:7-T)RDI*3L*("`@
M('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]M;VYT:$1A>5EE87(@97AT
M96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W-T87)T7WEE87([
M"B`@("!V87(@)%]E;F1?>65A<CL*("`@('9A<B`D7W!I8VME<CL*("`@('9A
M<B`D7V9O<FUA=%]I;B`](&YU;&P["B`@("!V87(@)%]F;W)M871?;W5T(#T@
M)R5X)SL*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@9&%T92!S=7!P;&EE
M9"!A<R!A($AO<F1E7T1A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1S=&%R=%]Y96%R("!4:&4@9FER<W0@879A:6QA8FQE('EE
M87(@9F]R(&EN<'5T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9%]Y96%R
M("`@(%1H92!L87-T(&%V86EL86)L92!Y96%R(&9O<B!I;G!U="X*("`@("`J
M($!P87)A;2!B;V]L96%N("1P:6-K97(@("`@("!$;R!W92!S:&]W('1H92!$
M2%1-3"!C86QE;F1A<C\*("`@("`J($!P87)A;2!I;G1E9V5R("1F;W)M871?
M:6X@("!4:&4@9F]R;6%T('1O('5S92!W:&5N('-E;F1I;F<@=&AE(&1A=&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@<W1O<F%G
M92X@1&5F875L=',@=&\@56YI>"!E<&]C:"X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!3:6UI;&%R('1O('1H92!S=')F=&EM92@I(&9U
M;F-T:6]N+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9O<FUA=%]O=70@(%1H
M92!F;W)M870@=&\@=7-E('=H96X@9&ES<&QA>6EN9R!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!D871E+B!3:6UI;&%R('1O('1H
M92!S=')F=&EM92@I(&9U;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!I
M;FET*"1S=&%R=%]Y96%R(#T@)R<L("1E;F1?>65A<B`]("<G+"`D<&EC:V5R
M(#T@=')U92P*("`@("`@("`@("`@("`@("`@)&9O<FUA=%]I;B`](&YU;&PL
M("1F;W)M871?;W5T(#T@)R5X)RD*("`@('L*("`@("`@("!I9B`H96UP='DH
M)'-T87)T7WEE87(I*2!["B`@("`@("`@("`@("1S=&%R=%]Y96%R(#T@9&%T
M92@G62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&5N9%]Y96%R
M*2D@>PH@("`@("`@("`@("`D96YD7WEE87(@/2!D871E*"=9)RD@*R`Q,#L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<W1A<G1?>65A<B`]("1S=&%R
M=%]Y96%R.PH@("`@("`@("1T:&ES+3Y?96YD7WEE87(@/2`D96YD7WEE87([
M"B`@("`@("`@)'1H:7,M/E]P:6-K97(@/2`D<&EC:V5R.PH@("`@("`@("1T
M:&ES+3Y?9F]R;6%T7VEN(#T@)&9O<FUA=%]I;CL*("`@("`@("`D=&AI<RT^
M7V9O<FUA=%]O=70@/2`D9F]R;6%T7V]U=#L*("`@('T*"B`@("!F=6YC=&EO
M;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@
M("`@>PH@("`@("`@("1D871E(#T@)'9A<G,M/F=E="@D=F%R+3YG971687).
M86UE*"DI.PH@("`@("`@("1E;7!T>2`]("1T:&ES+3YE;7!T>41A=&5!<G)A
M>2@D9&%T92D["@H@("`@("`@(&EF("@D96UP='D@/3T@,2`F)B`D=F%R+3YI
M<U)E<75I<F5D*"DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?2!E;'-E:68@*"1E;7!T>2`]/2`P("8F("%C:&5C:V1A
M=&4H)&1A=&5;)VUO;G1H)UTL("1D871E6R=D87DG72P@)&1A=&5;)WEE87(G
M72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?2!E;'-E:68@*"1E;7!T>2`]/2`M,2D@>PH@("`@("`@("`@("`D;65S<V%G
M92`](%\H(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(I.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!E;7!T>41A=&5!<G)A>2@D9&%T
M92D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871E*2D@>PH@("`@
M("`@("`@("!R971U<FX@96UP='DH)&1A=&4I.PH@("`@("`@('T*"B`@("`@
M("`@)&5M<'1Y(#T@,#L*("`@("`@("`O*B!#:&5C:R!E86-H(&1A=&4@87)R
M87D@8V]M<&]N96YT+B`J+PH@("`@("`@(&9O<F5A8V@@*"1D871E(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H96UP='DH)'9A;"DI('L*
M("`@("`@("`@("`@("`@("1E;7!T>2LK.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!S=&%T92!O9B!E;7!T>2X@*B\*("`@
M("`@("!I9B`H)&5M<'1Y(#T](#`I('L*("`@("`@("`@("`@+RH@268@;F\@
M96UP='D@<&%R=',@<F5T=7)N(#`N("HO"B`@("`@("`@("`@(')E='5R;B`P
M.PH@("`@("`@('T@96QS96EF("@D96UP='D@/3T@,RD@>PH@("`@("`@("`@
M("`O*B!)9B!A;&P@96UP='D@<&%R=',@<F5T=7)N(#$N("HO"B`@("`@("`@
M("`@(')E='5R;B`Q.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J
M($EF('-O;64@96UP='D@<&%R=',@<F5T=7)N("TQ+B`J+PH@("`@("`@("`@
M("!R971U<FX@+3$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!D871E('-U<'!L:65D('-P;&ET('5P(&EN=&\@86X@87)R
M87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T95]I;B`@1&%T
M92!I;B!O;F4@;V8@=&AE('1H<F5E(&9O<FUA=',@<W5P<&]R=&5D(&)Y"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]&;W)M(&%N9"!(
M;W)D95]$871E("A)4T\@9F]R;6%T"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!965E9+4U-+41$($A(.DU-.E-3+"!T:6UE<W1A;7`@65E964U-
M1$1(2$U-4U,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%N9"!5
M3DE8(&5P;V-H*2!P;'5S('1H92!F;W5R=&@@65E962U-32U$1"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!W:71H('1H<F5E(&5L96UE
M;G1S("T@>65A<BP@;6]N=&@@86YD(&1A>2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1&%T95!A<G1S*"1D871E7VEN*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D9&%T95]I;BDI('L*("`@("`@("`@("`@+RH@5&AI<R!I<R!P
M<F]B86)L>2!A(&9A:6QE9"!I<U9A;&ED(&EN<'5T('-O(&IU<W0@<F5T=7)N
M"B`@("`@("`@("`@("`J('1H92!P87)T<R!A<R!T:&5Y(&%R92X@*B\*("`@
M("`@("`@("`@<F5T=7)N("1D871E7VEN.PH@("`@("`@('T@96QS96EF("AE
M;7!T>2@D9&%T95]I;BDI('L*("`@("`@("`@("`@+RH@5&AI<R!I<R!J=7-T
M(&%N(&5M<'1Y(&9I96QD('-O(')E='5R;B!E;7!T>2!P87)T<RX@*B\*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"=Y96%R)R`]/B`G)RP@)VUO;G1H)R`]
M/B`G)RP@)V1A>2<@/3X@)R<I.PH@("`@("`@('T*"B`@("`@("`@)&1A=&4@
M/2`D=&AI<RT^9V5T1&%T94]B*"1D871E7VEN*3L*("`@("`@("!R971U<FX@
M87)R87DH)WEE87(G(#T^("1D871E+3YY96%R+`H@("`@("`@("`@("`@("`@
M("`@("`G;6]N=&@G(#T^("1D871E+3YM;VYT:"P*("`@("`@("`@("`@("`@
M("`@("`@)V1A>2<@/3X@)&1A=&4M/FUD87DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!D871E('-U<'!L:65D(&%S(&$@2&]R9&5?1&%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T95]I
M;B`@1&%T92!I;B!O;F4@;V8@=&AE('1H<F5E(&9O<FUA=',@<W5P<&]R=&5D
M(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]&;W)M
M(&%N9"!(;W)D95]$871E("A)4T\@9F]R;6%T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!965E9+4U-+41$($A(.DU-.E-3+"!T:6UE<W1A;7`@
M65E964U-1$1(2$U-4U,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&%N9"!53DE8(&5P;V-H*2!P;'5S('1H92!F;W5R=&@@65E962U-32U$1"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&4@(%1H92!D871E(&]B:F5C="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%T94]B*"1D871E7VEN*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1&%T92YP:'`G.PH*("`@
M("`@("!I9B`H:7-?87)R87DH)&1A=&5?:6XI*2!["B`@("`@("`@("`@("\J
M($EF('!A<W-E9"!A;B!A<G)A>2!C:&%N9V4@:70@=&\@=&AE($E33R!F;W)M
M870N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^96UP='E$871E07)R87DH
M)&1A=&5?:6XI(#T](#`I('L*("`@("`@("`@("`@("`@("1D871E7VEN(#T@
M<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@,#`Z,#`Z,#`G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D871E7VEN6R=Y96%R)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5?:6Y;)VUO
M;G1H)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&5?:6Y;)V1A>2==*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"<O7EQD>S1]+5QD>S)]+5QD>S)])"\G+"`D9&%T95]I
M;BDI('L*("`@("`@("`@("`@+RH@1FEX('1H92!D871E(&EF(&ET(&ES('1H
M92!S:&]R=&5N960@25-/+B`J+PH@("`@("`@("`@("`D9&%T95]I;B`]("1D
M871E7VEN("X@)R`P,#HP,#HP,"<["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@;F5W($AO<F1E7T1A=&4H)&1A=&5?:6XI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!D871E('-U<'!L:65D(&%S(&$@2&]R9&5?1&%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T92`@
M16ET:&5R(&%N(&%L<F5A9'D@<V5T('5P($AO<F1E7T1A=&4@;V)J96-T(&]R
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!D871E(&EN
M(&]N92!O9B!T:&4@=&AR964@9F]R;6%T<R!S=7!P;W)T960*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@(&)Y($AO<F1E7T9O<FT@86YD($AO<F1E7T1A
M=&4@*$E33R!F;W)M870*("`@("`J("`@("`@("`@("`@("`@("`@("`@(%E9
M65DM34TM1$0@2$@Z34TZ4U,L('1I;65S=&%M<"!965E934U$1$A(34U34R!A
M;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@(%5.25@@97!O8V@I('!L
M=7,@=&AE(&9O=7)T:"!965E9+4U-+41$+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@9&%T92!F;W)M871T960@86-C;W)D:6YG('1O('1H
M92`D9F]R;6%T7V]U=`H@("`@("H@("`@("`@("`@("`@("`@('!A<F%M971E
M<B!W:&5N('-E='1I;F<@=7`@=&AE(&UO;G1H9&%Y>65A<B!F:65L9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9F]R;6%T1&%T92@D9&%T92D*("`@('L*("`@
M("`@("!I9B`H(6ES7V$H)&1A=&4L("=$871E)RDI('L*("`@("`@("`@("`@
M)&1A=&4@/2`D=&AI<RT^9V5T1&%T94]B*"1D871E*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D9&%T92T^<W1R9G1I;64H)'1H:7,M/E]F;W)M871?
M;W5T*3L*("`@('T*"B`@("`O*BH*("`@("`J($EN<V5R="!T:&4@9&%T92!I
M;G!U="!T:')O=6=H('1H92!F;W)M(&EN=&\@)&EN9F\@87)R87DL(&EN('1H
M92!F;W)M870*("`@("`J('-P96-I9FEE9"!B>2!T:&4@)&9O<FUA=%]I;B!P
M87)A;65T97(@=VAE;B!S971T:6YG('5P(&UO;G1H9&%Y>65A<@H@("`@("H@
M9FEE;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F
M)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@("`@("1I;F9O(#T@)'1H:7,M/E]V
M86QI9&%T94%N9$9O<FUA="@D=F%R+3YG971686QU92@D=F%R<RDL("1V87(I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5F%L:61A=&4O9F]R;6%T(&$@9&%T
M92!S=6)M:7-S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&5!
M;F1&;W)M870H)'9A;'5E+"`F)'9A<BD*("`@('L*("`@("`@("`O*B!)9B!A
M;GD@8V]M<&]N96YT(&ES(&5M<'1Y(&-O;G-I9&5R(&ET(&$@8F%D(&1A=&4@
M86YD(')E='5R;B!T:&4*("`@("`@("`@*B!D969A=6QT+B`J+PH@("`@("`@
M(&EF("@D=&AI<RT^96UP='E$871E07)R87DH)'9A;'5E*2`]/2`Q*2!["B`@
M("`@("`@("`@(')E='5R;B`D=F%R+3YG971$969A=6QT*"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&1A=&4@/2`D=&AI<RT^9V5T1&%T94]B
M*"1V86QU92D["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V9O<FUA=%]I;B`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871E+3YT:6UE
M<W1A;7`H*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D9&%T92T^<W1R9G1I;64H)'1H:7,M/E]F;W)M871?:6XI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G;F%M
M92<@/3X@7R@B1&%T92!S96QE8W1I;VXB*2P*("`@("`@("`@("`@("`@("`@
M("`@)W!A<F%M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G<W1A<G1?>65A<B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3=&%R="!Y
M96%R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G96YD7WEE87(G("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")%
M;F0@>65A<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)W!I8VME<B<@("`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B4VAO=R!P:6-K97(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=B;V]L96%N)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`G9F]R;6%T7VEN)R`@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*")3=&]R86=E(&9O<FUA="(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@
M)W1E>'0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("=F;W)M871?;W5T
M)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D1I<W!L87D@9F]R;6%T(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G=&5X="<I*2D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&
M;W)M7U1Y<&5?8V]L;W)0:6-K97(@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@
M>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E
M+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER
M960H*2`F)B!E;7!T>2@D=F%L=64I*2!["B`@("`@("`@("`@("1M97-S86=E
M(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1V
M86QU92D@?'P@<')E9U]M871C:"@G+UXC*%LP+3EA+7I=*7LV?20O:2<L("1V
M86QU92DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*
M("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@;75S="!C;VYT86EN
M(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M
M<&QE("<C,3(S-&%F)RXB*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@
M)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H
M(D-O;&]U<B!S96QE8W1I;VXB*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@
M("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W-O<G1E<B!E>'1E;F1S
M($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?:6YS=&%N8V4["B`@("!V
M87(@)%]V86QU97,["B`@("!V87(@)%]S:7IE.PH@("`@=F%R("1?:&5A9&5R
M.PH*("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E<RP@)'-I>F4@/2`X+"`D:&5A
M9&5R(#T@)R<I"B`@("!["B`@("`@("`@<W1A=&EC("1H;W)D95]S;W)T97)?
M:6YS=&%N8V4@/2`P.PH*("`@("`@("`O*B!'970@=&AE(&YE>'0@<')O9W)E
M<W-I=F4@:6YS=&%N8V4@8V]U;G0@9F]R('1H92!H;W)D90H@("`@("`@("`J
M('-O<G1E<B!S;R!T:&%T(&UU;'1I<&QE('-O<G1E<G,@8V%N(&)E('5S960@
M;VX@;VYE('!A9V4N("HO"B`@("`@("`@)&AO<F1E7W-O<G1E<E]I;G-T86YC
M92LK.PH@("`@("`@("1T:&ES+3Y?:6YS=&%N8V4@/2`G:&]R9&5?<V]R=&5R
M7R<@+B`D:&]R9&5?<V]R=&5R7VEN<W1A;F-E.PH@("`@("`@("1T:&ES+3Y?
M=F%L=65S(#T@)'9A;'5E<SL*("`@("`@("`D=&AI<RT^7W-I>F4@("`]("1S
M:7IE.PH@("`@("`@("1T:&ES+3Y?:&5A9&5R(#T@)&AE861E<CL*("`@('T*
M"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@
M)B1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-I>F4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@
M("`@9G5N8W1I;VX@9V5T2&5A9&5R*"D*("`@('L*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?:&5A9&5R*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]H96%D97(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`G)SL*("`@
M('T*"B`@("!F=6YC=&EO;B!G971/<'1I;VYS*"1K97ES(#T@;G5L;"D*("`@
M('L*("`@("`@("`D:'1M;"`]("<G.PH@("`@("`@(&EF("@D=&AI<RT^7VAE
M861E<BD@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB
M(CXG("X@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7VAE861E<BD@+B`G/"]O
M<'1I;VX^)SL*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D:V5Y<RDI
M('L*("`@("`@("`@("`@)&ME>7,@/2!A<G)A>5]K97ES*"1T:&ES+3Y?=F%L
M=65S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:V5Y<R`](&5X
M<&QO9&4H(EQT(BP@)&ME>7-;)V%R<F%Y)UTI.PH@("`@("`@('T*("`@("`@
M("!F;W)E86-H("@D:V5Y<R!A<R`D<VQ?:V5Y*2!["B`@("`@("`@("`@("1H
M=&UL("X]("<\;W!T:6]N('9A;'5E/2(G("X@)'-L7VME>2`N("<B/B<@+B!H
M=&UL<W!E8VEA;&-H87)S*"1T:&ES+3Y?=F%L=65S6R1S;%]K97E=*2`N("<\
M+V]P=&EO;CXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I
M;F9O*0H@("`@>PH@("`@("`@("1V86QU92`]("1V87)S+3YG970H)'9A<BT^
M9V5T5F%R3F%M92@I*3L*("`@("`@("`D:6YF;R`](&5X<&QO9&4H(EQT(BP@
M)'9A;'5E6R=A<G)A>2==*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@
M("`@("1A8F]U=%LG;F%M92==(#T@7R@B4V]R="!O<F1E<B!S96QE8W1I;VXB
M*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@
M("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T
M<FEN9VQI<W0G*2P*("`@("`@("`@("`@)W-I>F4G("`@/3X@87)R87DH)VQA
M8F5L)R`]/B!?*")3:7IE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("`@("`G:&5A9&5R)R`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(DAE861E<B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI.PH@("`@("`@
M(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y
M<&5?<V5L96-T1FEL97,@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M("\J*@H@("`@("H@5&AE('1E>'0@=&\@=7-E(&EN('1H92!L:6YK+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VQI;FM?
M=&5X=#L*"B`@("`O*BH*("`@("`J(%1H92!S='EL92!T;R!U<V4@9F]R('1H
M92!L:6YK+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7VQI;FM?<W1Y;&4["@H@("`@+RHJ"B`@("`@*B`@0W)E871E('1H
M92!L:6YK('=I=&@@86X@:6-O;B!I;G-T96%D(&]F('1E>'0_"B`@("`@*@H@
M("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VEC;VX["@H@
M("`@+RHJ"B`@("`@*B!#;VYT86EN<R!G;VQL96T@<V5L96-T9FEL92!S96QE
M8W1I;VY)1`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7W-E;&5C=&ED.PH*("`@(&9U;F-T:6]N(&EN:70H)&QI;FM?=&5X
M="`](&YU;&PL("1L:6YK7W-T>6QE(#T@)R<L("1I8V]N(#T@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("1S96QE8W1I9"`]("<G*0H@("`@>PH@("`@("`@
M(&EF("AI<U]N=6QL*"1L:6YK7W1E>'0I*2!["B`@("`@("`@("`@("1L:6YK
M7W1E>'0@/2!?*")396QE8W0@1FEL97,B*3L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/E]L:6YK7W1E>'0@/2`D;&EN:U]T97AT.PH@("`@("`@("1T:&ES
M+3Y?;&EN:U]S='EL92`]("1L:6YK7W-T>6QE.PH@("`@("`@("1T:&ES+3Y?
M:6-O;B`]("1I8V]N.PH@("`@("`@("1T:&ES+3Y?<V5L96-T:60@/2`D<V5L
M96-T:60["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V
M87(L("8D:6YF;RD*("`@('L*("`@("`@("`D=F%L=64@/2`D=F%R+3YG9716
M86QU92@D=F%R<RD["B`@("`@("`@)&EN9F\@/2`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^8V%L;"@G9FEL97,O<V5L96-T;&ES=%)E<W5L=',G+"!A<G)A>2@D
M=F%L=64I("D["B`@("!]"@H@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@
M("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE
M)UT@/2!?*")&:6QE('-E;&5C=&EO;B(I.PH@("`@("`@(')E='5R;B`D86)O
M=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?87-S:6=N(&5X
M=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]L969T5F%L=65S
M.PH@("`@=F%R("1?<FEG:'1686QU97,["B`@("!V87(@)%]L969T2&5A9&5R
M.PH@("`@=F%R("1?<FEG:'1(96%D97(["B`@("!V87(@)%]S:7IE.PH@("`@
M=F%R("1?=VED=&@["@H@("`@9G5N8W1I;VX@:6YI="@D;&5F=%9A;'5E<RP@
M)')I9VAT5F%L=65S+"`D;&5F=$AE861E<B`]("<G+`H@("`@("`@("`@("`@
M("`@("`D<FEG:'1(96%D97(@/2`G)RP@)'-I>F4@/2`X+"`D=VED=&@@/2`G
M,C`P<'@G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&5F=%9A;'5E<R`]("1L
M969T5F%L=65S.PH@("`@("`@("1T:&ES+3Y?<FEG:'1686QU97,@/2`D<FEG
M:'1686QU97,["B`@("`@("`@)'1H:7,M/E]L969T2&5A9&5R(#T@)&QE9G1(
M96%D97(["B`@("`@("`@)'1H:7,M/E]R:6=H=$AE861E<B`]("1R:6=H=$AE
M861E<CL*("`@("`@("`D=&AI<RT^7W-I>F4@/2`D<VEZ93L*("`@("`@("`D
M=&AI<RT^7W=I9'1H(#T@)'=I9'1H.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES
M5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("![
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M5F%L=65S*"1S:61E*0H@("`@>PH@("`@("`@(')E='5R;B`D<VED92`_("1T
M:&ES+3Y?<FEG:'1686QU97,@.B`D=&AI<RT^7VQE9G1686QU97,["B`@("!]
M"@H@("`@9G5N8W1I;VX@<V5T5F%L=65S*"1S:61E+"`D=F%L=65S*0H@("`@
M>PH@("`@("`@(&EF("@D<VED92D@>PH@("`@("`@("`@("`D=&AI<RT^7W)I
M9VAT5F%L=65S(#T@)'9A;'5E<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7VQE9G1686QU97,@/2`D=F%L=65S.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!G971(96%D97(H)'-I9&4I"B`@("!["B`@
M("`@("`@<F5T=7)N("1S:61E(#\@)'1H:7,M/E]R:6=H=$AE861E<B`Z("1T
M:&ES+3Y?;&5F=$AE861E<CL*("`@('T*"B`@("!F=6YC=&EO;B!G9713:7IE
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S:7IE.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=%=I9'1H*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]W:61T:#L*("`@('T*"B`@("!F=6YC=&EO;B!G971/<'1I;VYS
M*"1S:61E+"`D9F]R;6YA;64I"B`@("!["B`@("`@("`@)&AT;6P@/2`G)SL*
M("`@("`@("`D:&5A9&5R(#T@9F%L<V4["B`@("`@("`@:68@*"1S:61E*2![
M"B`@("`@("`@("`@("1V86QU97,@/2`D=&AI<RT^7W)I9VAT5F%L=65S.PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<FEG:'1(96%D97(I*2![
M"B`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)R<@/3X@)'1H:7,M
M/E]R:6=H=$AE861E<BD@*R`D=F%L=65S.PH@("`@("`@("`@("`@("`@)&AE
M861E<G,@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'9A;'5E<R`]("1T:&ES+3Y?;&5F=%9A;'5E<SL*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VQE9G1(96%D97(I*2!["B`@
M("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)R<@/3X@)'1H:7,M/E]L
M969T2&5A9&5R*2`K("1V86QU97,["B`@("`@("`@("`@("`@("`D:&5A9&5R
M<R`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9F]R
M96%C:"`H)'9A;'5E<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@
M)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64](B<@+B`D:V5Y("X@)R(G.PH@("`@
M("`@("`@("!I9B`H)&AE861E<G,I('L*("`@("`@("`@("`@("`@("1H96%D
M97)S(#T@9F%L<V4["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`G(&]N9&)L8VQI8VL](DAO<F1E7T9O<FU?07-S:6=N
M+FUO=F4H7"<G("X@)&9O<FUN86UE("X*("`@("`@("`@("`@("=<)RP@)R`N
M("AI;G0I)'-I9&4@+B`G*3LB)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D:'1M;"`N/2`G/B<@+B`D=F%L("X@)SPO;W!T:6]N/B<["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@("!["B`@("`@("`@
M)'9A;'5E(#T@)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"D@+B`G7U]V
M86QU97,G*3L*("`@("`@("!I9B`H<W1R<&]S*"1V86QU92P@(EQT7'0B*2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&QE9G0@/2`D=F%L=64["B`@("`@
M("`@("`@("1R:6=H="`]("<G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&QI<W0H)&QE9G0L("1R:6=H="D@/2!E>'!L;V1E*")<=%QT(BP@)'9A
M;'5E*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1L969T*2D@>PH@
M("`@("`@("`@("`D:6YF;ULG;&5F="==(#T@87)R87DH*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D:6YF;ULG;&5F="==(#T@97AP;&]D92@B
M7'0B+"`D;&5F="D["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<FEG
M:'0I*2!["B`@("`@("`@("`@("1I;F9O6R=R:6=H="==(#T@87)R87DH*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:6YF;ULG<FEG:'0G72`]
M(&5X<&QO9&4H(EQT(BP@)')I9VAT*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T
M(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D%S<VEG
M;FUE;G0@8V]L=6UN<R(I.PH@("`@("`@("1A8F]U=%LG<&%R86US)UT@/2!A
M<G)A>2@*("`@("`@("`@("`@)VQE9G1686QU97,G(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B3&5F="!V86QU97,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@
M("`@("`@)W)I9VAT5F%L=65S)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E)I
M9VAT('9A;'5E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@("`@("`@)VQE
M9G1(96%D97(G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B3&5F="!H96%D97(B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G
M=&5X="<I+`H@("`@("`@("`@("`G<FEG:'1(96%D97(G(#T^(&%R<F%Y*"=L
M86)E;"<@/3X@7R@B4FEG:'0@:&5A9&5R(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@
M("`@("`G<VEZ92<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT
M)RDL"B`@("`@("`@("`@("=W:61T:"<@("`]/B!A<G)A>2@G;&%B96PG(#T^
M(%\H(E=I9'1H(&EN($-34R!U;FET<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I*3L*("`@("`@("!R971U
M<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V-R
M961I=&-A<F0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T
M:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@)B8@)'9A<BT^:7-2
M97%U:7)E9"@I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=F%L=64I*2!["B`@
M("`@("`@("`@("\J(&=E=$-A<F14>7!E*"D@=VEL;"!A;'-O('9E<FEF>2!T
M:&4@8VAE8VMS=6TN("HO"B`@("`@("`@("`@("1T>7!E(#T@)'1H:7,M/F=E
M=$-A<F14>7!E*"1V86QU92D["B`@("`@("`@("`@(&EF("@D='EP92`]/3T@
M9F%L<V4@?'P@)'1Y<&4@/3T@)W5N:VYO=VXG*2!["B`@("`@("`@("`@("`@
M("`D;65S<V%G92`](%\H(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+B(I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G971#:&5C:W-U;2@D8V-N=6TI
M"B`@("!["B`@("`@("`@)&QE;B`]('-T<FQE;B@D8V-N=6TI.PH@("`@("`@
M(&EF("@A:7-?;&]N9R@D;&5N("\@,BDI('L*("`@("`@("`@("`@)'=E:6=H
M="`](#(["B`@("`@("`@("`@("1D:6=I="`]("1C8VYU;5LP73L*("`@("`@
M("!](&5L<V5I9B`H:7-?;&]N9R@D;&5N("\@,BDI('L*("`@("`@("`@("`@
M)'=E:6=H="`](#$["B`@("`@("`@("`@("1D:6=I="`]("1C8VYU;5LP72`J
M(#(["B`@("`@("`@?0H@("`@("`@(&EF("@D9&EG:70@/B`Y*2!["B`@("`@
M("`@("`@("1D:6=I="`]("1D:6=I="`M(#D["B`@("`@("`@?0H@("`@("`@
M("1I(#T@,3L*("`@("`@("`D8VAE8VMS=6T@/2`D9&EG:70["B`@("`@("`@
M=VAI;&4@*"1I(#P@)&QE;BD@>PH@("`@("`@("`@("!I9B`H)&-C;G5M6R1I
M72`A/2`G("<I('L*("`@("`@("`@("`@("`@("1D:6=I="`]("1C8VYU;5LD
M:5T@*B`D=V5I9VAT.PH@("`@("`@("`@("`@("`@)'=E:6=H="`]("@D=V5I
M9VAT(#T](#$I(#\@,B`Z(#$["B`@("`@("`@("`@("`@("!I9B`H)&1I9VET
M(#X@.2D@>PH@("`@("`@("`@("`@("`@("`@("1D:6=I="`]("1D:6=I="`M
M(#D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8VAE8VMS
M=6T@*ST@)&1I9VET.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I*RL[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-H96-K<W5M.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$-A<F14>7!E*"1C8VYU;2D*("`@('L*("`@("`@
M("`D<W5M(#T@)'1H:7,M/F=E=$-H96-K<W5M*"1C8VYU;2D["B`@("`@("`@
M)&P@/2!S=')L96XH)&-C;G5M*3L*"B`@("`@("`@+R\@4V-R965N(&-H96-K
M<W5M+@H@("`@("`@(&EF("@H)'-U;2`E(#$P*2`A/2`P*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O($-H96-K
M(&9O<B!6:7-A+@H@("`@("`@(&EF("@H*"1L(#T](#$V*2!\?"`H)&P@/3T@
M,3,I*2`F)@H@("`@("`@("`@("`H)&-C;G5M6S!=(#T](#0I*2!["B`@("`@
M("`@("`@(')E='5R;B`G=FES82<["B`@("`@("`@?0H*("`@("`@("`O+R!#
M:&5C:R!F;W(@36%S=&5R0V%R9"X*("`@("`@("!I9B`H*"1L(#T](#$V*2`F
M)@H@("`@("`@("`@("`H)&-C;G5M6S!=(#T](#4I("8F"B`@("`@("`@("`@
M("@D8V-N=6U;,5T@/CT@,2D@)B8*("`@("`@("`@("`@*"1C8VYU;5LQ72`\
M/2`U*2D@>PH@("`@("`@("`@("!R971U<FX@)VUA<W1E<F-A<F0G.PH@("`@
M("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R($%M97@N"B`@("`@("`@:68@
M*"@D;"`]/2`Q-2D@)B8*("`@("`@("`@("`@*"1C8VYU;5LP72`]/2`S*2`F
M)@H@("`@("`@("`@("`H*"1C8VYU;5LQ72`]/2`T*2!\?"`H)&-C;G5M6S%=
M(#T](#<I*2D@>PH@("`@("`@("`@("!R971U<FX@)V%M97@G.PH@("`@("`@
M('T*"B`@("`@("`@+R\@0VAE8VL@9F]R($1I<V-O=F5R("A.;W9U<RDN"B`@
M("`@("`@:68@*'-T<FQE;B@D8V-N=6TI(#T](#$V("8F"B`@("`@("`@("`@
M('-U8G-T<B@D8V-N=6TL(#`L(#0I(#T]("<V,#$Q)RD@>PH@("`@("`@("`@
M("!R971U<FX@)V1I<V-O=F5R)SL*("`@("`@("!]"@H@("`@("`@("\O($EF
M('=E(&=O="!T:&ES(&9A<BP@=&AE;B!N;R!C87)D(&UA=&-H960N"B`@("`@
M("`@<F5T=7)N("=U;FMN;W=N)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@
M("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B0W)E9&ET(&-A<F0@;G5M8F5R
M(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO
M<F1E7T9O<FU?5'EP95]O8G)O=W-E<B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP
M92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L
M=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y
M<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@
M("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@
M7R@B4F5L871I;VYS:&EP($)R;W=S97(B*3L*("`@("`@("!R971U<FX@)&%B
M;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V1B;&]O:W5P
M(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E7V5N=6T@>PH*("`@(&9U;F-T:6]N
M(&EN:70H)&1S;BP@)'-Q;"P@)'!R;VUP="`](&YU;&PI"B`@("!["B`@("`@
M("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("`@("1V86QU97,@/2!A
M<G)A>2@I.PH@("`@("`@("1D8B`]("9$0CHZ8V]N;F5C="@D9'-N*3L*("`@
M("`@("!I9B`H(6ES7V$H)&1B+"`G4$5!4E]%<G)O<B<I*2!["@H@("`@("`@
M("`@("`O+R!3970@1$(@<&]R=&%B:6QI='D@;W!T:6]N<RX*("`@("`@("`@
M("`@<W=I=&-H("@D9&(M/G!H<'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G
M;7-S<6PG.@H@("`@("`@("`@("`@("`@)&1B+3YS971/<'1I;VXH)W!O<G1A
M8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"
M24Q)5%E?15)23U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("`D9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)4
M04))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D8V]L(#T@)B1D8BT^9V5T0V]L
M*"1S<6PI.PH@("`@("`@("`@("!I9B`H(6ES7V$H)&-O;"P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!
M<G)A>2YP:'`G.PH@("`@("`@("`@("`@("`@)'9A;'5E<R`]($AO<F1E7T%R
M<F%Y.CIC;VUB:6YE*"1C;VPL("1C;VPI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@('!A<F5N=#HZ:6YI="@D=F%L=65S+"`D<')O;7!T*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD
M('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@
M("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("=N86UE)R`]/B!?*")$
M871A8F%S92!,;V]K=7`B*2P*("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`G9'-N)R`]/B!A<G)A>2@G;&%B96PG(#T^
M(%\H(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A
M8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2P*("`@
M("`@("`@("`@("`@("=S<6PG(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B4U%,
M('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@
M("`@("`@("`@)W!R;VUP="<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")0<F]M
M<'0@=&5X="(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G=&5X="<I*0H@("`@("`@("`@("`I.PH@("`@?0H*?0H*
M8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V9I9VQE="!E>'1E;F1S($AO<F1E7T9O
M<FU?5'EP92!["@H@("`@=F%R("1?=&5X=#L*("`@('9A<B`D7V9O;G0["@H@
M("`@9G5N8W1I;VX@:6YI="@D=&5X="P@)&9O;G0I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]T97AT(#T@)'1E>'0["B`@("`@("`@)'1H:7,M/E]F;VYT(#T@
M)&9O;G0["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E<75I<F5D*"DI('L*("`@("`@("`@
M("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I
M9B`H4W1R:6YG.CIL;W=E<B@D=F%L=64I("$](%-T<FEN9SHZ;&]W97(H)'1H
M:7,M/E]T97AT*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H92!T
M97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE
M('-C<F5E;BXB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T1F]N="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9F]N=#L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971497AT*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@
M("`@("`@)VYA;64G(#T^(%\H(D9I9VQE="!#05!40TA!(BDL"B`@("`@("`@
M("`@("=P87)A;7,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1E>'0G
M(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5&5X="(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2P*("`@("`@
M("`@("`@("`@("=F;VYT)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D9I9VQE
M="!F;VYT(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B`G=&5X="<I*0H@("`@("`@("`@("`I.PH@("`@?0H*?0H*8VQA
M<W,@2&]R9&5?1F]R;5]4>7!E7VEN=F%L:60@97AT96YD<R!(;W)D95]&;W)M
M7U1Y<&4@>PH*("`@('9A<B`D;65S<V%G93L*"B`@("!F=6YC=&EO;B!I;FET
M*"1M97-S86=E*0H@("`@>PH@("`@("`@("1T:&ES+3YM97-S86=E(#T@)&UE
M<W-A9V4["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!R97!R97-E;G1S
M(&$@<VEN9VQE(&9O<FT@=F%R:6%B;&4@=&AA="!M87D@8F4@<F5N9&5R960@
M87,@;VYE(&]R"B`J(&UO<F4@9F]R;2!F:65L9',N"B`J"B`J($!A=71H;W(@
M(%)O8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@
M*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7U9A
M<FEA8FQE('L*"B`@("`O*BH*("`@("`J(%1H92!F;W)M(&EN<W1A;F-E('1H
M:7,@=F%R:6%B;&4@:7,@87-S:6=N960@=&\N"B`@("`@*@H@("`@("H@0'9A
M<B!(;W)D95]&;W)M"B`@("`@*B\*("`@('9A<B`D9F]R;3L*"B`@("`O*BH*
M("`@("`J($$@<VAO<G0@9&5S8W)I<'1I;VX@;V8@=&AI<R!V87)I86)L92=S
M('!U<G!O<V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1H=6UA;DYA;64["@H@("`@+RHJ"B`@("`@*B!4:&4@:6YT97)N
M86QL>2!U<V5D(&YA;64N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1V87).86UE.PH*("`@("\J*@H@("`@("H@02![0&QI
M;FL@2&]R9&5?1F]R;5]4>7!E?2!I;G-T86YC92X*("`@("`J"B`@("`@*B!`
M=F%R($AO<F1E7T9O<FU?5'EP90H@("`@("HO"B`@("!V87(@)'1Y<&4["@H@
M("`@+RHJ"B`@("`@*B!7:&5T:&5R('1H:7,@:7,@82!R97%U:7)E9"!V87)I
M86)L92X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1R97%U:7)E9#L*"B`@("`O*BH*("`@("`J(%=H971H97(@=&AI<R!I
M<R!A(')E861O;FQY('9A<FEA8FQE+@H@("`@("H*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)')E861O;FQY.PH*("`@("\J*@H@("`@
M("H@02!L;VYG(&1E<V-R:7!T:6]N(&]F('1H92!V87)I86)L92=S('!U<G!O
M<V4L('-P96-I86P@:6YS=')U8W1I;VYS+"!E=&,N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D97-C<FEP=&EO;CL*"B`@
M("`O*BH*("`@("`J(%1H92!V87)I86)L92!H96QP('1E>'0N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1H96QP.PH*("`@
M("\J*@H@("`@("H@5VAE=&AE<B!T:&ES(&ES(&%N(&%R<F%Y('9A<FEA8FQE
M+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)%]A<G)A>59A;#L*"B`@("`O*BH*("`@("`J(%1H92!D969A=6QT('9A;'5E
M+@H@("`@("H*("`@("`J($!V87(@;6EX960*("`@("`J+PH@("`@=F%R("1?
M9&5F5F%L=64@/2!N=6QL.PH*("`@("\J*@H@("`@("H@02![0&QI;FL@2&]R
M9&5?1F]R;5]!8W1I;VY](&EN<W1A;F-E+@H@("`@("H*("`@("`J($!V87(@
M2&]R9&5?1F]R;5]!8W1I;VX*("`@("`J+PH@("`@=F%R("1?86-T:6]N.PH*
M("`@("\J*@H@("`@("H@5VAE=&AE<B!T:&ES('9A<FEA8FQE(&ES(&1I<V%B
M;&5D+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V
M87(@)%]D:7-A8FQE9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5$]$3PH@
M("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]A
M=71O9FEL;&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1H
M:7,@:7,@82!H:61D96X@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VAI9&1E;B`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?;W!T:6]N<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!687)I86)L92!C;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1H=6UA;DYA;64@("`@("!!('-H;W)T(&1E<V-R:7!T:6]N
M(&]F('1H92!V87)I86)L92=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!P=7)P;W-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%R
M3F%M92`@("`@("`@5&AE(&EN=&5R;F%L;'D@=7-E9"!N86UE+@H@("`@("H@
M0'!A<F%M($AO<F1E7T9O<FU?5'EP92`D='EP92`@02![0&QI;FL@2&]R9&5?
M1F]R;5]4>7!E?2!I;G-T86YC92X*("`@("`J($!P87)A;2!B;V]L96%N("1R
M97%U:7)E9"`@("`@(%=H971H97(@=&AI<R!I<R!A(')E<75I<F5D('9A<FEA
M8FQE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E861O;FQY("`@("`@5VAE
M=&AE<B!T:&ES(&ES(&$@<F5A9&]N;'D@=F%R:6%B;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D97-C<FEP=&EO;B`@("!!(&QO;F<@9&5S8W)I<'1I;VX@
M;V8@=&AE('9A<FEA8FQE)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('!U<G!O<V4L('-P96-I86P@:6YS=')U8W1I;VYS+"!E=&,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T9O<FU?5F%R:6%B;&4H)&AU
M;6%N3F%M92P@)'9A<DYA;64L("8D='EP92P@)')E<75I<F5D+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5A9&]N;'D@/2!F86QS92P@
M)&1E<V-R:7!T:6]N(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^:'5M
M86Y.86UE("`@/2`D:'5M86Y.86UE.PH@("`@("`@("1T:&ES+3YV87).86UE
M("`@("`]("1V87).86UE.PH@("`@("`@("1T:&ES+3YT>7!E("`@("`@("`]
M("8D='EP93L*("`@("`@("`D=&AI<RT^<F5Q=6ER960@("`@/2`D<F5Q=6ER
M960["B`@("`@("`@)'1H:7,M/G)E861O;FQY("`@(#T@)')E861O;FQY.PH@
M("`@("`@("1T:&ES+3YD97-C<FEP=&EO;B`]("1D97-C<FEP=&EO;CL*("`@
M("`@("`D=&AI<RT^7V%R<F%Y5F%L("`@/2`H<W1R<&]S*"1V87).86UE+"`G
M6UTG*2`A/3T@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@07-S:6=N
M('1H:7,@=F%R:6%B;&4@=&\@=&AE('-P96-I9FEE9"!F;W)M+@H@("`@("H*
M("`@("`J($!P87)A;2!(;W)D95]&;W)M("1F;W)M("!4:&4@9F]R;2!I;G-T
M86YC92!T;R!A<W-I9VX@=&AI<R!V87)I86)L92!T;RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T1F]R;4]B*"8D9F]R;2D*("`@('L*("`@("`@("`D=&AI
M<RT^9F]R;2`]("8D9F]R;3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M82!D969A=6QT('9A;'5E(&9O<B!T:&ES('9A<FEA8FQE+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D=F%L=64@($$@=F%R:6%B;&4@=F%L=64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U;'0H)'9A;'5E*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?9&5F5F%L=64@/2`D=F%L=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H:7,@=F%R:6%B;&4G<R!D969A=6QT('9A
M;'5E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H:7,@=F%R:6%B
M;&4G<R!D969A=6QT('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$
M969A=6QT*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D969686QU
M93L*("`@('T*"B`@("`O*BH*("`@("`J($%S<VEG;G,@86X@86-T:6]N('1O
M('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@17AA;7!L93H*("`@("`J
M(#QC;V1E/@H@("`@("H@)'8@/2`F)&9O<FTM/F%D9%9A<FEA8FQE*"=->2!6
M87)I86)L92<L("=V87(Q)RP@)W1E>'0G+"!F86QS92D["B`@("`@*B`D86-T
M:6]N(#T@)DAO<F1E7T9O<FU?06-T:6]N.CIF86-T;W)Y*"=S=6)M:70G*3L*
M("`@("`J("1V+3YS971!8W1I;VXH)&%C=&EO;BD["B`@("`@*B`\+V-O9&4^
M"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T9O<FU?06-T:6]N("1A8W1I
M;VX@($$@>T!L:6YK($AO<F1E7T9O<FU?06-T:6]N?2!I;G-T86YC92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T06-T:6]N*"1A8W1I;VXI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]A8W1I;VX@/2`D86-T:6]N.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@=F%R:6%B;&4@:&%S(&%N
M(&%T=&%C:&5D(&%C=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@=&AI<R!V87)I86)L92!H87,@86X@871T86-H960@86-T
M:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-!8W1I;VXH*0H@("`@>PH@
M("`@("`@(')E='5R;B`A:7-?;G5L;"@D=&AI<RT^7V%C=&EO;BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!-86ME<R!T:&ES(&$@:&ED9&5N('9A<FEA8FQE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!H:61E*"D*("`@('L*("`@("`@("`D
M=&AI<RT^7VAI9&1E;B`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('=H971H97(@=&AI<R!I<R!A(&AI9&1E;B!V87)I86)L92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AI<R!A(&AI
M9&1E;B!V87)I86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-(:61D96XH
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VAI9&1E;CL*("`@('T*
M"B`@("`O*BH*("`@("`J($1I<V%B;&5S('1H:7,@=F%R:6%B;&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1I<V%B;&4H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?9&ES86)L960@/2!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!W:&5T:&5R('1H:7,@=F%R:6%B;&4@:7,@9&ES86)L960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H:7,@=F%R:6%B
M;&4@:7,@9&ES86)L960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES1&ES86)L
M960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1I<V%B;&5D.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!S:&]R="!D97-C<FEP
M=&EO;B!O9B!T:&ES('9A<FEA8FQE+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!!('-H;W)T(&1E<V-R:7!T:6]N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$AU;6%N3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YH=6UA;DYA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!I;G1E<FYA;&QY('5S960@=F%R:6%B;&4@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AI<R!V87)I86)L92=S(&EN=&5R;F%L(&YA
M;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%9A<DYA;64H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^=F%R3F%M93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AI<R!V87)I86)L92=S('1Y<&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!(;W)D95]&;W)M7U1Y<&4@(%1H:7,@=F%R:6%B;&4G
M<R![0&QI;FL@2&]R9&5?1F]R;5]4>7!E?0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT>7!E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F%M92!O9B!T:&ES
M('9A<FEA8FQE)W,@='EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AI<R!V87)I86)L92=S("![0&QI;FL@2&]R9&5?1F]R;5]4>7!E?2!N
M86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E3F%M92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YT>7!E+3YG9714>7!E3F%M92@I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@:7,@
M82!R97%U:7)E9"!V87)I86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=&AI<R!I<R!A(')E<75I<F5D('9A<FEA8FQE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<U)E<75I<F5D*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G)E<75I<F5D.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@:7,@82!R96%D;VYL>2!V87)I86)L
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AI
M<R!A(')E861O;FQY('9A<FEA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!I
M<U)E861O;FQY*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)E861O
M;FQY.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&]S<VEB
M;&4@=F%L=65S(&]F('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@5&AE('!O<W-I8FQE('9A;'5E<R!O9B!T:&ES('9A<FEA
M8FQE(&]R(&YU;&PN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT>7!E+3YG971686QU97,H
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&ES
M('9A<FEA8FQE(&AA<R!A(&QO;F<@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H:7,@=F%R:6%B;&4@:&%S
M(&$@;&]N9R!D97-C<FEP=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S
M1&5S8W)I<'1I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH)'1H
M:7,M/F1E<V-R:7!T:6]N*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AI<R!V87)I86)L92=S(&QO;F<@9&5S8W)I<'1I;VXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H:7,@=F%R:6%B;&4G<R!L;VYG(&1E
M<V-R:7!T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$97-C<FEP=&EO
M;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD97-C<FEP=&EO;CL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&ES(&ES
M(&%N(&%R<F%Y('9A<FEA8FQE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!T:&ES(&%N(&%R<F%Y('9A<FEA8FQE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<T%R<F%Y5F%L*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]A<G)A>59A;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=VAE=&AE<B!T:&ES('9A<FEA8FQE(&ES('1O('5P;&]A9"!A(&9I
M;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('9A
M<FEA8FQE(&ES('1O('5P;&]A9"!A(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES57!L;V%D*"D*("`@('L*("`@("`@("!R971U<FX@*"1T:&ES+3YT
M>7!E+3YG9714>7!E3F%M92@I(#T]("=F:6QE)RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!<W-I9VYS(&$@:&5L<"!T97AT('1O('1H:7,@=F%R:6%B;&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5L<"`@5&AE('9A<FEA
M8FQE(&AE;'`@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2&5L<"@D
M:&5L<"D*("`@('L*("`@("`@("`D=&AI<RT^9F]R;2T^7VAE;'`@/2!T<G5E
M.PH@("`@("`@("1T:&ES+3YH96QP(#T@)&AE;'`["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('=H971H97(@=&AI<R!V87)I86)L92!H87,@<V]M
M92!H96QP('1E>'0@87-S:6=N960N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF('1H:7,@=F%R:6%B;&4@:&%S(&$@:&5L<"!T97AT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-(96QP*"D*("`@('L*("`@("`@
M("!R971U<FX@(65M<'1Y*"1T:&ES+3YH96QP*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&AE;'`@=&5X="!O9B!T:&ES('9A<FEA8FQE
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&ES('9A<FEA8FQE
M)W,@:&5L<"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(96QP*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FAE;'`["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3971S(&$@=F%R:6%B;&4@;W!T:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&]P=&EO;B`@5&AE(&]P=&EO;B!N86UE+@H@
M("`@("H@0'!A<F%M(&UI>&5D("1V86P@("`@("!4:&4@;W!T:6]N)W,@=F%L
M=64N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P=&EO;B@D;W!T:6]N+"`D
M=F%L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!T:6]N<ULD;W!T:6]N72`]
M("1V86P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@=F%R:6%B
M;&4@;W!T:6]N)W,@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;W!T:6]N("!4:&4@;W!T:6]N(&YA;64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@("`@("`@("!4:&4@;W!T:6]N)W,@=F%L=64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$]P=&EO;B@D;W!T:6]N*0H@("`@>PH@("`@
M("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V]P=&EO;G-;)&]P=&EO;ETI(#\@
M)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=(#H@;G5L;#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%!R;V-E<W-E<R!T:&4@<W5B;6ET=&5D('9A;'5E(&]F('1H
M:7,@=F%R:6%B;&4@86-C;W)D:6YG('1O('1H92!R=6QE<R!O9@H@("`@("H@
M=&AE('9A<FEA8FQE('1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M(%9A<FEA
M8FQE<R`D=F%R<R`@5&AE('M`;&EN:R!687)I86)L97-](&EN<W1A;F-E(&]F
M('1H92!S=6)M:71T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<FTN"B`@("`@*B!`<&%R86T@;6EX960@)&EN9F\@("`@("!!('9A<FEA
M8FQE('!A<W-E9"!B>2!R969E<F5N8V4@=&AA="!W:6QL(&)E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!A<W-I9VYE9"!T:&4@<')O8V5S<V5D
M('9A;'5E(&]F('1H92!S=6)M:71T960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('9A<FEA8FQE('9A;'5E+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($1E<&5N9&EN9R!O;B!T:&4@=F%R:6%B;&4@='EP92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;R@F)'9A<G,L("8D:6YF;RD*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/G1Y<&4M/F=E=$EN9F\H)'9A<G,L
M("1T:&ES+"`D:6YF;RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('=H971H97(@=&AI<R!V87)I86)L92!I9B!I="!H860@=&AE(")T<F%C:V-H
M86YG92(@;W!T:6]N('-E=`H@("`@("H@:&%S(&%C='5A;&QY(&)E96X@8VAA
M;F=E9"X*("`@("`J"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("1V87)S("!4
M:&4@>T!L:6YK(%9A<FEA8FQE<WT@:6YS=&%N8V4@;V8@=&AE('-U8FUI='1E
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($YU;&P@:68@=&AI<R!V87)I86)L
M92!D;V5S;B=T(&AA=F4@=&AE(")T<F%C:V-H86YG92(*("`@("`J("`@("`@
M("`@("`@("`@("`@;W!T:6]N('-E="!O<B!T:&4@9F]R;2!W87-N)W0@<W5B
M;6ET=&5D('EE="X@02!B;V]L96%N"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&EN9&EC871I;F<@=VAE=&AE<B!T:&4@=F%R:6%B;&4@=V%S(&-H86YG960@
M;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W87-#:&%N9V5D*"8D
M=F%R<RD*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YG971/<'1I;VXH)W1R
M86-K8VAA;F=E)RDI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H@("`@("`@("1O;&0@/2`D=F%R<RT^9V5T*"=?7V]L9%\G("X@)'1H
M:7,M/F=E=%9A<DYA;64H*2D["B`@("`@("`@:68@*&ES7VYU;&PH)&]L9"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D;VQD("$]("1V87)S+3YG970H)'1H:7,M/F=E=%9A<DYA;64H
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!686QI9&%T97,@=&AI<R!V87)I
M86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("1V87)S("!4
M:&4@>T!L:6YK(%9A<FEA8FQE<WT@:6YS=&%N8V4@;V8@=&AE('-U8FUI='1E
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&UE<W-A9V4@($$@=F%R:6%B;&4@<&%S<V5D(&)Y
M(')E9F5R96YC92!T:&%T('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&%S<VEG;F5D(&$@9&5S8W)I<'1I=F4@97)R;W(@;65S<V%G
M92!I9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=F%L:61A=&EO
M;B!F86EL960N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF('1H92!V87)I86)L92!V86QI9&%T960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('9A;&ED871E*"8D=F%R<RP@)B1M97-S86=E*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^7V%R<F%Y5F%L*2!["B`@("`@("`@("`@("1V86QS(#T@
M)'1H:7,M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D=F%L<RDI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^<F5Q
M=6ER960I('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D=F%L<R!A<R`D
M:2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@D=F%L=64@/3T]
M(&YU;&P@)B8@)'1H:7,M/G)E<75I<F5D*2!["B`@("`@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^
M='EP92T^:7-686QI9"@D=&AI<RP@)'9A<G,L("1V86QU92P@)&UE<W-A9V4I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L=64@/2`D
M=&AI<RT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G1Y<&4M/FES5F%L:60H)'1H:7,L("1V87)S+"`D=F%L=64L("1M97-S
M86=E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<W5B;6ET=&5D(&]R(&1E9F%U
M;'0@=F%L=64@;V8@=&AI<R!V87)I86)L92X*("`@("`J($EF(&%N(&%C=&EO
M;B!I<R!A='1A8VAE9"!T;R!T:&ES('9A<FEA8FQE+"!T:&4@=F%L=64@=VEL
M;"!G970@<&%S<V5D('1O"B`@("`@*B!T:&4@86-T:6]N(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("1V87)S("!4:&4@>T!L:6YK
M(%9A<FEA8FQE<WT@:6YS=&%N8V4@;V8@=&AE('-U8FUI='1E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1I;F1E>"`@($EF('1H92!V87)I86)L92!I<R!A;B!A<G)A>2!V
M87)I86)L92P@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M<W!E8VEF:65S('1H92!A<G)A>2!E;&5M96YT('1O(')E='5R;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=F%R:6%B;&4@;W(@96QE;65N
M="!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5F%L=64H)B1V87)S
M+"`D:6YD97@@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V%R
M<F%Y5F%L*2!["B`@("`@("`@("`@("1N86UE(#T@<W1R7W)E<&QA8V4H)UM=
M)RP@)R<L("1T:&ES+3YV87).86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;F%M92`]("1T:&ES+3YV87).86UE.PH@("`@("`@('T*("`@
M("`@("`D=F%L=64@/2`D=F%R<RT^9V5T17AI<W1S*"1N86UE+"`D=V%S<V5T
M*3L*"B`@("`@("`@:68@*"$D=V%S<V5T*2!["B`@("`@("`@("`@("1V86QU
M92`]("1T:&ES+3YG971$969A=6QT*"D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'1H:7,M/E]A<G)A>59A;"`F)B`A:7-?;G5L;"@D:6YD97@I*2!["B`@
M("`@("`@("`@(&EF("@A)'=A<W-E="`F)B`A:7-?87)R87DH)'9A;'5E*2D@
M>PH@("`@("`@("`@("`@("`@)')E='5R;B`]("1V86QU93L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R971U<FX@/2!I<W-E="@D
M=F%L=65;)&EN9&5X72D@/R`D=F%L=65;)&EN9&5X72`Z(&YU;&P["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5T=7)N
M(#T@)'9A;'5E.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YH87-!
M8W1I;VXH*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;BT^<V5T5F%L
M=65S*"1V87)S+"`D<F5T=7)N+"`D=&AI<RT^7V%R<F%Y5F%L*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+G!H
M<```````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#,Q
M,``Q,#0Q-S,V,C<W,P`P,C`P,#4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D92!G<F%P
M:&EN9R!S=6ET92X*("H*("H@4')O=FED97,@82!S970@;V8@9W)A<&@@8F%C
M:V5N9',@86YD(&UE=&AO9',@9F]R(&-R96%T:6YG(&=R87!H<R!A<PH@*B!(
M5$U,('1A8FQE<RP@4U9'(&EM86=E<RP@971C+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]'<F%P:"]'<F%P:"YP:'`L=B`Q+C(W+C$P+C<@,C`P-B\P,2\P
M,2`R,3HR.#HQ."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?1W)A<&@*("HO"F-L87-S($AO<F1E7T=R87!H('L*"B`@("`O*BH*("`@
M("`J(%1H92!(;W)D95]);6%G92!I;G-T86YC92!T:&%T('=E(&%R92!D<F%W
M:6YG('1H92!G<F%P:"!T;RX*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("H@0'9A<B!(;W)D95]);6%G90H@("`@("HO"B`@("!V87(@
M)&EM9SL*"B`@("!V87(@)%]G<F%P:',@/2!A<G)A>2@I.PH*("`@('9A<B`D
M7VAE:6=H=#L*("`@('9A<B`D7W=I9'1H.PH*("`@('9A<B`D7W1I=&QE(#T@
M)R<["@H@("`@=F%R("1?8F%C:V=R;W5N9"`]("=L:6=H=&=R87DG.PH@("`@
M=F%R("1?=&ET;&5&;VYT(#T@)W-A;G,M<V5R:68G.PH@("`@=F%R("1?;&%B
M96Q&;VYT(#T@)W-A;G,M<V5R:68G.PH@("`@=F%R("1?87AI<T9O;G0@/2`G
M;6]N;W-P86-E)SL*"B`@("!V87(@)%]P861D:6YG3&5F="`](#8P.PH@("`@
M=F%R("1?<&%D9&EN9T)O='1O;2`](#0P.PH@("`@=F%R("1?<&%D9&EN9U1O
M<"`](#,P.PH@("`@=F%R("1?<&%D9&EN9U)I9VAT(#T@,C`["@H@("`@=F%R
M("1?;V9F<V5T1W)I9%@@/2`P.PH*("`@('9A<B`D7VEM9U1Y<&4@/2`G9V0G
M.PH*("`@('9A<B`D7V1A=&$@/2!A<G)A>2@G>"<@/3X@87)R87DH*2P*("`@
M("`@("`@("`@("`@("`@("`@("`G>2<@/3X@87)R87DH*2D["@H@("`@=F%R
M("1?=&UP9&ER.PH*("`@('9A<B`D7W!L;W1S(#T@87)R87DH*3L*("`@('9A
M<B`D7V-H87)T<R`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@2&]R9&5?1W)A
M<&@H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;
M)W1E;7`G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]T;7!D:7(@/2`D<&%R
M86US6R=T96UP)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1P
M87)A;7-;)W=I9'1H)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=VED=&@@
M/2`D<&%R86US6R=W:61T:"==.PH@("`@("`@("`@("`D=&AI<RT^7VAE:6=H
M="`]("1P87)A;7-;)VAE:6=H="==.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%E;7!T>2@D<&%R86US6R=I;6=4>7!E)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?:6UG5'EP92`]("1P87)A;7-;)VEM9U1Y<&4G73L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@)F%D9%!L;W0H)'!L;W14>7!E+"`D<&QO
M=%!A<F%M<RD*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]C:&%R
M=',I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=-
M:7AI;F<@;V8@0VAA<G1S(&%N9"!0;&]T<R!I<R!N;W0@86QL;W=E9"XG*3L*
M("`@("`@("!]"@H@("`@("`@("1P;&]T5'EP92`](&)A<V5N86UE*"1P;&]T
M5'EP92D["B`@("`@("`@0&EN8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O1W)A<&@O4&QO="\G("X@)'!L;W14>7!E("X@)RYP:'`G.PH*("`@
M("`@("`D8VQA<W,@/2`G2&]R9&5?1W)A<&A?4&QO=%\G("X@)'!L;W14>7!E
M.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@
M("`@("`D<&QO="`]("9N97<@)&-L87-S*"1T:&ES+"`D<&QO=%!A<F%M<RD[
M"B`@("`@("`@("`@("1T:&ES+3Y?<&QO='-;72`]("8D<&QO=#L*("`@("`@
M("`@("`@<F5T=7)N("1P;&]T.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=0;&]T('1Y<&4@;F]T(&9O
M=6YD)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N("9A9&1#:&%R
M="@D8VAA<G14>7!E+"`D8VAA<G1087)A;7,I"B`@("!["B`@("`@("`@:68@
M*&-O=6YT*"1T:&ES+3Y?<&QO=',I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=-:7AI;F<@;V8@0VAA<G1S(&%N9"!0;&]T<R!I
M<R!N;W0@86QL;W=E9"XG*3L*("`@("`@("!]"@H@("`@("`@("1C:&%R=%1Y
M<&4@/2!B87-E;F%M92@D8VAA<G14>7!E*3L*("`@("`@("!`:6YC;'5D95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]'<F%P:"]#:&%R="\G("X@)&-H
M87)T5'EP92`N("<N<&AP)SL*"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7T=R
M87!H7T-H87)T7R<@+B`D8VAA<G14>7!E.PH@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D8VAA<G0@/2`F;F5W("1C
M;&%S<R@D=&AI<RP@)&-H87)T4&%R86US*3L*("`@("`@("`@("`@)'1H:7,M
M/E]C:&%R='-;72`]("8D8VAA<G0["B`@("`@("`@("`@(')E='5R;B`D8VAA
M<G0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T-H87)T('1Y<&4@;F]T(&9O=6YD)RD["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N(&%D9%A$871A*"1D871A*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?9&%T85LG>"==(#T@)&1A=&$["B`@("!]"@H@("`@
M9G5N8W1I;VX@861D641A=&$H)&1A=&$L("1N86UE(#T@)R<I"B`@("!["B`@
M("`@("`@:68@*&5M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M92`]
M(&UD-2AS97)I86QI>F4H)&1A=&$I*3L*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/E]D871A6R=Y)UU;)&YA;65=(#T@)&1A=&$["B`@("`@("`@<F5T=7)N
M("1N86UE.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E="@D<&%R86TI"B`@("![
M"B`@("`@("`@)&ME>2`]("=?)R`N("1P87)A;3L*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/B1K97DI(#\@)'1H:7,M/B1K97D@.B!N=6QL.PH@("`@
M?0H*("`@(&9U;F-T:6]N('-E="@D<&%R86TL("1V86QU92D*("`@('L*("`@
M("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("1T:&ES+3XD:V5Y
M(#T@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%C:&4@=&AE(&EM
M86=E(&%N9"!R971U<FX@82!L:6YK('1O('9I97<@:70@;W5T(&]F('1H92!C
M86-H92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES<&QA>2@I"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF+"`D<F5G:7-T<GD["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]#86-H92YP:'`G.PH@("`@("`@("1C86-H92`]("9(
M;W)D95]#86-H93HZ<VEN9VQE=&]N*"1C;VYF6R=C86-H92==6R=D<FEV97(G
M72P@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G8V%C:&4G+"`D8V]N9ELG8V%C
M:&4G75LG9')I=F5R)UTI*3L*"B`@("`@("`@)'1H:7,M/FEN:71I86QI>F4H
M*3L*"B`@("`@("`@)&-I9"`](&UD-2AS97)I86QI>F4H)'1H:7,I*3L*("`@
M("`@("`D8V%C:&4M/G-E="@D8VED+"!S97)I86QI>F4H87)R87DH)V1A=&$G
M(#T^("1T:&ES+3YD<F%W*&9A;'-E*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V-T>7!E)R`]/B`D=&AI<RT^:6UG+3YG
M971#;VYT96YT5'EP92@I*2DI.PH*("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R
M;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V
M:6-E<R]C86-H979I97<N<&AP)RD["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D=7)L+"`G8VED)RP@)&-I9"D["@H@("`@("`@(')E='5R
M;B`D=&AI<RT^:6UG+3YG971,:6YK*"1U<FPL("1T:&ES+3Y?=&ET;&4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S<R!A;&P@;V8@=&AE(&1A=&$@
M<V5T<R!A;F0@<V5T(&=R87!H('!R;W!E<G1I97,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&EN:71I86QI>F4H)&UI;ED@/2!F86QS92P@)'-T97!,86)E;'-9
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@3&]A9"!A($AO<F1E7TEM86=E
M(&-A;G9A<R!T;R!D<F%W(&]N+@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O26UA9V4N<&AP)SL*("`@("`@("`D=&AI<RT^:6UG(#T@)DAO<F1E7TEM
M86=E.CIF86-T;W)Y*"1T:&ES+3Y?:6UG5'EP92P@87)R87DH)VAE:6=H="<@
M/3X@)'1H:7,M/E]H96EG:'0L("=W:61T:"<@/3X@)'1H:7,M/E]W:61T:"P@
M)W1E;7`G(#T^("1T:&ES+3Y?=&UP9&ER*2D["@H@("`@("`@("\O(%1O=&%L
M(&EM86=E(&%N9"!G<F%P:"!A<F5A(&1I;65N<VEO;G,N"B`@("`@("`@)'=I
M9'1H(#T@)'1H:7,M/E]W:61T:"`M(#$["B`@("`@("`@)&AE:6=H="`]("1T
M:&ES+3Y?:&5I9VAT("T@,3L*"B`@("`@("`@)'1H:7,M/E]G<F%P:%1O<"`]
M("1T:&ES+3Y?<&%D9&EN9U1O<#L*("`@("`@("`D=&AI<RT^7V=R87!H0F]T
M=&]M(#T@)'1H:7,M/E]H96EG:'0@+2`Q("T@*"1T:&ES+3Y?<&%D9&EN9U1O
M<"`K("1T:&ES+3Y?<&%D9&EN9T)O='1O;2D["B`@("`@("`@)'1H:7,M/E]G
M<F%P:$QE9G0@/2`D=&AI<RT^7W!A9&1I;F=,969T.PH@("`@("`@("1T:&ES
M+3Y?9W)A<&A2:6=H="`]("1T:&ES+3Y?=VED=&@@+2`D=&AI<RT^7W!A9&1I
M;F=2:6=H="`M(#$["B`@("`@("`@)'1H:7,M/E]G<F%P:$AE:6=H="`]("1T
M:&ES+3Y?9W)A<&A";W1T;VT@+2`D=&AI<RT^7V=R87!H5&]P.PH@("`@("`@
M("1T:&ES+3Y?9W)A<&A7:61T:"`]("1T:&ES+3Y?9W)A<&A2:6=H="`M("1T
M:&ES+3Y?9W)A<&A,969T.PH*("`@("`@("`D=&AI<RT^7V=R:618(#T@;6EN
M*&-O=6YT*"1T:&ES+3Y?9&%T85LG>"==*2P@<F]U;F0H)'1H:7,M/E]G<F%P
M:%=I9'1H("\@-#`I*3L*("`@("`@("!I9B`H(21T:&ES+3Y?9W)I9%@I('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;R!D871A+B<I.PH@("`@
M("`@('T*"B`@("`@("`@+R\@1FEN9"!T:&4@<F%N9V4@;V8@86QL('D@=F%L
M=65S+@H@("`@("`@("1Y9&%T82`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M
M/E]G<FED62`](#`["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]D871A6R=Y
M)UT@87,@)&1A=&$I('L*("`@("`@("`@("`@)'1H:7,M/E]G<FED62`](&UA
M>"@D=&AI<RT^7V=R:619+"!C;W5N="@D9&%T82DI.PH@("`@("`@("`@("`D
M>61A=&$@/2!A<G)A>5]M97)G92@D>61A=&$L("1D871A*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?;6%X6"`](&-O=6YT*"1T:&ES+3Y?9&%T85LG
M>"==*3L*("`@("`@("!L:7-T*"1T:&ES+3Y?;6EN62P@)'1H:7,M/E]M87A9
M*2`]("1T:&ES+3Y?9FEN9%)A;F=E*"1Y9&%T82D["B`@("`@("`@:68@*"1M
M:6Y9("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^7VUI;ED@/2`D
M;6EN63L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9&EF9ED@/2`D=&AI
M<RT^7VUA>%D@+2`D=&AI<RT^7VUI;ED["@H@("`@("`@("\O($-A;&-U;&%T
M92!T:&4@;G5M8F5R(&]F(%D@9W)I9&QI;F5S("AA;F0@=&AU<RP@;&%B96QS
M*2!T;PH@("`@("`@("\O('-H;W<N(%1R>2!T;R!M86ME('-U<F4@=V4@9&]N
M)W0@96YD('5P('=I=&@@=&]O(&1E;G-E(&$*("`@("`@("`O+R!G<FED+"!B
M=70@86QS;R!M86ME('-U<F4@=&AA="!W92!H879E(&$@9F5W(&=R:60@;&EN
M97,@=&\*("`@("`@("`O+R!B<F5A:R!U<"!S;6%L;"!D871A<V5T<RX*("`@
M("`@("!I9B`H)'-T97!,86)E;'-9(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V=R:619(#T@;6%X*&UI;B@D=&AI<RT^7V=R:619+"!F;&]O
M<B@D=&AI<RT^7V=R87!H2&5I9VAT("\@,S`I*2P@9FQO;W(H)'1H:7,M/E]G
M<F%P:$AE:6=H="`O(#8P*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]G<FED62`](&9L;V]R*"@D=&AI<RT^7VUA>%D@+2`D=&AI
M<RT^7VUI;EDI("\@)'-T97!,86)E;'-9*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@H)'1H:7,M/E]M87A9("T@)'1H:7,M/E]M:6Y9*2`]/2`P*2!["B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@<F%N9V4@=&\@9W)A<&@N
M($-H96-K(&1A=&$N)RD["B`@("`@("`@?0H*("`@("`@("`O+R!&;W)M870@
M=&5X="!F;W(@;&%B96QI;F<@=&AE(%D@87AI<RX*("`@("`@("!I9B`H)'-T
M97!,86)E;'-9(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D9&5L=&%,86)E
M;'-9(#T@*"1T:&ES+3Y?;6%X62`M("1T:&ES+3Y?;6EN62D@+R`H)'1H:7,M
M/E]G<FED62D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1E;'1A
M3&%B96QS62`]("1S=&5P3&%B96QS63L*("`@("`@("!]"@H@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\/2`D=&AI<RT^7V=R:619.R`D:2LK*2!["B`@("`@
M("`@("`@("1T97AT(#T@)'1H:7,M/E]M:6Y9("L@*"1D96QT84QA8F5L<UD@
M*B`D:2D["B`@("`@("`@("`@("1T:&ES+3Y?;&%B96QS65LD:5T@/2!N=6UB
M97)?9F]R;6%T*"1T97AT+"`R*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3Y?;&%B96QS62DI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=.;R!9(&%X:7,@9&%T82XG*3L*("`@("`@("!]"@H@("`@("`@
M("\O($-A;&-U;&%T92!T:&4@<W!A8VEN9R!F;W(@=&EC:W,@86YD(&=R:60@
M;&EN97,N"B`@("`@("`@)&1E;F]M:6YA=&]R(#T@)'1H:7,M/E]M87A8("T@
M,2`K("@R("H@)'1H:7,M/E]O9F9S971'<FED6"D["B`@("`@("`@:68@*"1D
M96YO;6EN871O<B`]/2`P*2!["B`@("`@("`@("`@("1D96YO;6EN871O<B`]
M(#$["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?9F%C=&]R6"`]("1T:&ES
M+3Y?9W)A<&A7:61T:"`O("1D96YO;6EN871O<CL*("`@("`@("`D=&AI<RT^
M7V9A8W1O<ED@/2`D=&AI<RT^7V=R87!H2&5I9VAT("\@)'1H:7,M/E]D:69F
M63L*"B`@("`@("`@)&1E;F]M:6YA=&]R(#T@)'1H:7,M/E]G<FED6"`M(#$@
M*R`R("H@)'1H:7,M/E]O9F9S971'<FED6#L*("`@("`@("!I9B`H)&1E;F]M
M:6YA=&]R(#T](#`I('L*("`@("`@("`@("`@)&1E;F]M:6YA=&]R(#T@,3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]D96QT851I8VMS6"`]("@D=&AI
M<RT^7V=R87!H5VED=&@@+R`D9&5N;VUI;F%T;W(I("\@)'1H:7,M/E]F86-T
M;W)8.PH@("`@("`@(&EF("@D<W1E<$QA8F5L<UD@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?9&5L=&%4:6-K<UD@/2`H)'1H:7,M/E]G<F%P
M:$AE:6=H="`O("1T:&ES+3Y?9W)I9%DI("\@)'1H:7,M/E]F86-T;W)9.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?9&5L=&%4:6-K
M<UD@/2`D<W1E<$QA8F5L<UD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!D<F%W*"1D:7-P;&%Y(#T@=')U
M92P@)&UI;ED@/2!F86QS92P@)&1E;'1A3&%B96QS62`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^:6YI=&EA;&EZ92@D;6EN62P@
M)&1E;'1A3&%B96QS62D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@("1P;&]T<R`](&-O=6YT*"1T:&ES+3Y?<&QO=',I
M.PH@("`@("`@("1C:&%R=',@/2!C;W5N="@D=&AI<RT^7V-H87)T<RD["@H@
M("`@("`@(&EF("@D<&QO=',I('L*("`@("`@("`@("`@)'1H:7,M/F1R87="
M86-K9W)O=6YD*"D["B`@("`@("`@("`@("1T:&ES+3YD<F%W5&ET;&4H*3L*
M("`@("`@("`@("`@)'1H:7,M/F1R87='<FED6"@I.PH@("`@("`@("`@("`D
M=&AI<RT^9')A=T=R:619*"D["B`@("`@("`@("`@("1T:&ES+3YD<F%W4&QO
M=$)O>"@I.PH@("`@("`@("`@("`D=&AI<RT^9')A=TQA8F5L<U@H*3L*("`@
M("`@("`@("`@)'1H:7,M/F1R87=,86)E;'-9*"D["@H@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D<&QO=',[("1I*RLI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&QO='-;)&E=+3YD<F%W*"1T:&ES+3Y?;6EN62D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)&-H87)T<RD@>PH@("`@
M("`@("`@("`D=&AI<RT^9')A=U1I=&QE*"D["@H@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D8VAA<G1S.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H87)T<ULD:5TM/F1R87<H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D:7-P;&%Y(#\@)'1H:7,M/FEM
M9RT^9&ES<&QA>2@I(#H@)'1H:7,M/FEM9RT^<F%W*"D["B`@("!]"@H@("`@
M9G5N8W1I;VX@9')A=T)A8VMG<F]U;F0H*0H@("`@>PH@("`@("`@("1T:&ES
M+3YI;6<M/G)E8W1A;F=L92@P+"`P+"`D=&AI<RT^7W=I9'1H("T@,2P@)'1H
M:7,M/E]H96EG:'0@+2`Q+"`G8FQA8VLG+"`D=&AI<RT^7V)A8VMG<F]U;F0I
M.PH@("`@("`@("1T:&ES+3YI;6<M/G)E8W1A;F=L92@D=&AI<RT^7V=R87!H
M3&5F="P@)'1H:7,M/E]G<F%P:%1O<"P@)'1H:7,M/E]G<F%P:%=I9'1H+"`D
M=&AI<RT^7V=R87!H2&5I9VAT+"`G8FQA8VLG+"`G=VAI=&4G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1R87<@82!B;W@@87)O=6YD('1H92!P;&]T(&%R
M96$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R87=0;&]T0F]X*"D*("`@('L*
M("`@("`@("`D=&AI<RT^:6UG+3YR96-T86YG;&4H)'1H:7,M/E]G<F%P:$QE
M9G0L("1T:&ES+3Y?9W)A<&A4;W`L("1T:&ES+3Y?9W)A<&A7:61T:"P@)'1H
M:7,M/E]G<F%P:$AE:6=H="P@)V)L86-K)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$<F%W<R!G<FED(&QI;F5S(&9R;VT@=&]P('1O(&)O='1O;2!O;B!T
M:&4@:6UA9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R87='<FED6"@I"B`@
M("!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'1H:7,M/E]G<FED6#L@
M)&DK*RD@>PH@("`@("`@("`@("`D>"`]("1T:&ES+3YT<F%N<VQA=&58*"1T
M:&ES+3Y?9&5L=&%4:6-K<U@@*B`D:2D["B`@("`@("`@("`@("1T:&ES+3YI
M;6<M/F1A<VAE9$QI;F4H)'@L("1T:&ES+3Y?9W)A<&A4;W`L("1X+"`D=&AI
M<RT^7V=R87!H0F]T=&]M+"`G9W)A>2<I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($1R87=S(&=R:60@;&EN97,@9G)O;2!L969T('1O(')I
M9VAT(&]N('1H92!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9')A=T=R
M:619*"D*("`@('L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/#T@)'1H:7,M
M/E]G<FED63L@)&DK*RD@>PH@("`@("`@("`@("`D>2`]("1T:&ES+3YT<F%N
M<VQA=&59*"1T:&ES+3Y?;6EN62`K("1T:&ES+3Y?9&5L=&%4:6-K<UD@*B`D
M:2D["B`@("`@("`@("`@("1T:&ES+3YI;6<M/F1A<VAE9$QI;F4H)'1H:7,M
M/E]G<F%P:$QE9G0L("1Y+"`D=&AI<RT^7V=R87!H4FEG:'0L("1Y+"`G9W)A
M>2<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@=&AE
M('1I=&QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!D<F%W5&ET;&4H*0H@("`@
M>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]T:71L92DI('L*("`@("`@
M("`@("`@)'1H:7,M/FEM9RT^=&5X="@D=&AI<RT^7W1I=&QE+"`D=&AI<RT^
M7V=R87!H3&5F="`K("@D=&AI<RT^7V=R87!H5VED=&@@+R`R*2`M("@H<W1R
M;&5N*"1T:&ES+3Y?=&ET;&4I("\@,BD@*B`W*2P@)'1H:7,M/E]G<F%P:%1O
M<"`M(#(P+"`D=&AI<RT^7W1I=&QE1F]N="D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1')A=W,@=&AE(&%X:7,@=&%G('1E>'0@;W5T<VED
M92!T:&4@<&QO='1I;F<@87)E82!O;B!T:&4@>`H@("`@("H@87AI<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9')A=TQA8F5L<U@H*0H@("`@>PH@("`@("`@
M("\O($1R87<@6"!A>&ES(&QA8F5L+@H@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]X;&%B96PI*2!["B`@("`@("`@("`@("1X(#T@)'1H:7,M/E]G<F%P
M:$QE9G0@*R`H)'1H:7,M/E]G<F%P:%=I9'1H("\@,BD@+2`H<W1R;&5N*"1T
M:&ES+3Y?>&QA8F5L*2`J(#,I.PH@("`@("`@("`@("`D>2`]("1T:&ES+3Y?
M9W)A<&A";W1T;VT@*R`U,#L*("`@("`@("`@("`@)'1H:7,M/FEM9RT^=&5X
M="@D=&AI<RT^7WAL86)E;"P@)'@L("1Y+"`D=&AI<RT^7VQA8F5L1F]N="D[
M"B`@("`@("`@?0H*("`@("`@("`D;&%S=%@@/2`P.PH@("`@("`@("1M:6Y$
M:69F(#T@,C`["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]D871A6R=X)UT@
M87,@)&D@/3X@)'1E>'0I('L*("`@("`@("`@("`@)'@@/2`D=&AI<RT^=')A
M;G-L871E6"@D:2D["B`@("`@("`@("`@(&EF("@D>"`M("1L87-T6"`^/2`D
M;6EN1&EF9BD@>PH@("`@("`@("`@("`@("`@)&QA<W18(#T@)'@["B`@("`@
M("`@("`@("`@("`D=&AI<RT^:6UG+3YT97AT*"1T97AT+"`D>"`M(#4L("1T
M:&ES+3Y?9W)A<&A";W1T;VT@*R`H<W1R;&5N*"1T97AT*2`J(#<I+"`D=&AI
M<RT^7V%X:7-&;VYT+"`G8FQA8VLG+"`M.3`I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FEM9RT^;&EN92@D>"P@)'1H:7,M/E]G<F%P:$)O='1O;2`K(#(L
M("1X+"`D=&AI<RT^7V=R87!H0F]T=&]M("T@,BD["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!T:&4@87AI
M<R!T86<@=&5X="!O=71S:61E('1H92!P;&]T=&EN9R!A<F5A(&]N('1H92!Y
M"B`@("`@*B!A>&ES+@H@("`@("HO"B`@("!F=6YC=&EO;B!D<F%W3&%B96QS
M62@I"B`@("!["B`@("`@("`@+R\@1')A=R!9(&%X:7,@;&%B96PN"B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^7WEL86)E;"DI('L*("`@("`@("`@("`@
M)'D@/2`D=&AI<RT^7V=R87!H5&]P("L@*"1T:&ES+3Y?9W)A<&A(96EG:'0@
M+R`R*2`K("@H<W1R;&5N*"1T:&ES+3Y?>6QA8F5L*2`O(#(I("H@-2D["B`@
M("`@("`@("`@("1T:&ES+3YI;6<M/G1E>'0H)'1H:7,M/E]Y;&%B96PL(#4L
M("1Y+"`D=&AI<RT^7VQA8F5L1F]N="P@)V)L86-K)RP@+3DP*3L*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&%B96QS62!A<R`D:2`]
M/B`D;&%B96PI('L*("`@("`@("`@("`@)'D@/2`D=&AI<RT^=')A;G-L871E
M62@D=&AI<RT^7VUI;ED@*R`D:2`J("1T:&ES+3Y?9&5L=&%4:6-K<UDI.PH@
M("`@("`@("`@("`D=&AI<RT^:6UG+3YT97AT*"1L86)E;"P@)'1H:7,M/E]G
M<F%P:$QE9G0@+2`H<W1R;&5N*"1L86)E;"D@*B`W*2P@)'D@+2`U+"`D=&AI
M<RT^7V%X:7-&;VYT*3L*("`@("`@("`@("`@)'1H:7,M/FEM9RT^;&EN92@D
M=&AI<RT^7V=R87!H3&5F="`M(#(L("1Y+"`D=&AI<RT^7V=R87!H3&5F="`K
M(#(L("1Y*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME
M(&$@<&%I<B!O9B`H>"QY*2!G<F%P:"!C;V]R9&EN871E<R!A;F0@<F5T=7)N
M('1H90H@("`@("H@<V-R965N+7!I>&5L(&-O;W)D:6YA=&5S(&9O<B!T:&5M
M+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`F)'@@("`@(%1H92!X('!O
M<VET:6]N(&EN('=O<FQD(&-O;W)D:6YA=&5S+@H@("`@("H@0'!A<F%M(&9L
M;V%T("8D>2`@("`@5&AE('D@<&]S:71I;VX@:6X@=V]R;&0@8V]O<F1I;F%T
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('1R86YS;&%T92@F)'@L("8D>2D*
M("`@('L*("`@("`@("`D>"`]("1T:&ES+3YT<F%N<VQA=&58*"1X*3L*("`@
M("`@("`D>2`]("1T:&ES+3YT<F%N<VQA=&59*"1Y*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1R86YS;&%T92!T:&4@>"!C;V]R9&EN871E(&]F(&$@<&]I
M;G0@;VX@=&AE('!L;W0@=&\@<V-R965N"B`@("`@*B!C;V]R9&EN871E<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'@@(%1H92!X('=O<FQD("AP
M;&]T*2!C;V]R9&EN871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<VQA
M=&58*"1X*0H@("`@>PH@("`@("`@(')E='5R;B`H*"1X("L@)'1H:7,M/E]O
M9F9S971'<FED6"D@*B`D=&AI<RT^7V9A8W1O<E@I("L@)'1H:7,M/E]G<F%P
M:$QE9G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4<F%N<VQA=&4@=&AE('D@
M8V]O<F1I;F%T92!O9B!A('!O:6YT(&]N('1H92!P;&]T('1O('-C<F5E;@H@
M("`@("H@8V]O<F1I;F%T97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T
M("1Y("!4:&4@>2!W;W)L9"`H<&QO="D@8V]O<F1I;F%T92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=')A;G-L871E62@D>2D*("`@('L*("`@("`@("!I9B`H
M)'DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)A<&A";W1T;VT@
M+2`H*"1Y("T@)'1H:7,M/E]M:6Y9*2`J("1T:&ES+3Y?9F%C=&]R62D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)A
M<&A";W1T;VT["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1FEN
M9"!T:&4@;6EN:6UU;2!A;F0@;6%X:6UU;2!V86QU97,@9F]R(&$@<V5T(&]F
M(&1A=&$N"B`@("`@*@H@("`@("H@5&AE("1R97-O;'5T:6]N('9A<FEA8FQE
M(&ES('5S960@9F]R(')O=6YD:6YG(&UA>&EM=6T@86YD"B`@("`@*B!M:6YI
M;75M('9A;'5E<RX@268@;6%X:6UU;2!V86QU92!I<R`X-C0U('1H96XZ"B`@
M("`@*@H@("`@("H@268@)')E<V]L=71I;VX@:7,@,"P@=&AE;B!M87AI;75M
M('9A;'5E(&)E8V]M97,@.3`P,"X*("`@("`J($EF("1R97-O;'5T:6]N(&ES
M(#$L('1H96X@;6%X:6UU;2!V86QU92!B96-O;65S(#@W,#`N"B`@("`@*B!)
M9B`D<F5S;VQU=&EO;B!I<R`R+"!T:&5N(&UA>&EM=6T@=F%L=64@8F5C;VUE
M<R`X-C4P+@H@("`@("H@268@)')E<V]L=71I;VX@:7,@,RP@=&AE;B!M87AI
M;75M('9A;'5E(&)E8V]M97,@.#8T-2X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@("1D871A("`@("`@("`@5&AE($1A=&%S970@=&\@9FEN9"!T:&4@
M<F%N9V4@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UI;B`@("`@("`@
M($UI;FEM=6T@=F%L=64@=&\@<W1A<G0@870N(%1H92!L;W=E<W0@;G5M8F5R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&1A
M=&%S970@:7,@=7-E9"!I9B!I="=S(&QO=V5R+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&UA>"`@("`@("`@($UA>&EM=6T@=F%L=64@=&\@<W1A<G0@870N
M(%1H92!H:6=H97-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;G5M8F5R(&EN('1H92!D871A<V5T(&ES('5S960@:68@:70G<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AI9VAE<BX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1R97-O;'5T:6]N("!4:&4@<F5S;VQU=&EO;B!T
M;R!U<V4@9F]R('1H92!R86YG92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@;6EN:6UU;2!A;F0@;6%X:6UU;2!V86QU97,@9F]R('1H92!R
M86YG92X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9FEN9%)A;F=E*"1D871A+"`D;6EN(#T@,"P@)&UA>"`](#`L("1R
M97-O;'5T:6]N(#T@,"D*("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1D871A
M*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)VUI;B<@/3X@,"P@)VUA
M>"<@/3X@,"D["B`@("`@("`@?0H*("`@("`@("`D9&%T85M=(#T@)&UA>#L*
M("`@("`@("`D9&%T85M=(#T@)&UI;CL*("`@("`@("`D;6%X(#T@;6%X*"1D
M871A*3L*("`@("`@("`D;6EN(#T@;6EN*"1D871A*3L*"B`@("`@("`@:68@
M*"1M87@@/3T@,"D@>PH@("`@("`@("`@("`D9F%C=&]R(#T@,3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)&UA>"`\(#`I('L*("`@("`@
M("`@("`@("`@("1F86-T;W(@/2`M<&]W*#$P+"`H9FQO;W(H;&]G,3`H86)S
M*"1M87@I*2D@*R`D<F5S;VQU=&EO;BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&9A8W1O<B`]('!O=R@Q,"P@*&9L;V]R*&QO
M9S$P*&%B<R@D;6%X*2DI("T@)')E<V]L=71I;VXI*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)&UA>"`]("1F86-T;W(@*B!`8V5I;"@D
M;6%X("\@)&9A8W1O<BD["B`@("`@("`@)&UI;B`]("1F86-T;W(@*B!`9FQO
M;W(H)&UI;B`O("1F86-T;W(I.PH*("`@("`@("!R971U<FX@87)R87DH)&UI
M;BP@)&UA>"D["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T=R;W5P+G!H<```````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`U,#`V-0`Q,#0Q-S,V,C<W,P`P,C`P-#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G2&]R9&4O1&%T851R964N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92](:7-T;W)Y+G!H<"<["@HO*BH*("H@5&AE($=R;W5P.CH@8VQA<W,@
M<')O=FED97,@=&AE($AO<F1E(&=R;W5P<R!S>7-T96TN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<"QV(#$N-C<N,BXQ,"`R,#`V
M+S`Q+S`Q(#(Q.C(X.C$X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*
M("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%-T97!H
M86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95]'<F]U<`H@*B\*8VQA<W,@
M1W)O=7`@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!A($1A=&%4<F5E
M(&EN<W1A;F-E('1O(&UA;F%G92!T:&4@9&EF9F5R96YT(&=R;W5P<RX*("`@
M("`J"B`@("`@*B!`=F%R($1A=&%4<F5E"B`@("`@*B\*("`@('9A<B`D7V1A
M=&%T<F5E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J+PH@
M("`@9G5N8W1I;VX@1W)O=7`H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@:68@*&5M<'1Y*"1C;VYF6R=D871A=')E92==6R=D<FEV
M97(G72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"=9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!'<F]U<',N)RP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1D<FEV
M97(@/2`D8V]N9ELG9&%T871R964G75LG9')I=F5R)UT["B`@("`@("`@)'1H
M:7,M/E]D871A=')E92`]("9$871A5')E93HZ<VEN9VQE=&]N*"1D<FEV97(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y7VUE<F=E*$AO<F1E.CIG971$<FEV97)#;VYF:6<H)V1A=&%T
M<F5E)RP@)&1R:79E<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=G<F]U<"<@
M/3X@)VAO<F1E+F=R;W5P<R<I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@82!N97<@9W)O=7`@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("`@5&AE(&=R;W5P)W,@;F%M92X*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A<F5N="`@5&AE(&=R;W5P)W,@<&%R96YT)W,@;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7T=R;W5P
M("!!(&YE=R!G<F]U<"!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9N
M97='<F]U<"@D;F%M92P@)'!A<F5N="`]($1!5$%44D5%7U)/3U0I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<&%R96YT("$]
M($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@)&YA;64@/2`D=&AI<RT^
M9V5T1W)O=7!.86UE*"1P87)E;G0I("X@)SHG("X@1&%T851R964Z.F5N8V]D
M94YA;64H)&YA;64I.PH@("`@("`@('T*"B`@("`@("`@)&=R;W5P(#T@)FYE
M=R!$871A5')E94]B:F5C=%]'<F]U<"@D;F%M92D["B`@("`@("`@)&=R;W5P
M+3YS971'<F]U<$]B*"1T:&ES*3L*("`@("`@("!R971U<FX@)&=R;W5P.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@1&%T851R965/8FIE8W1?
M1W)O=7`@;V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&YA;65D"B`@("`@
M*B!G<F]U<"P@=VET:"!T:&4@=7-E<G,@86YD(&]T:&5R(&1A=&$@<F5T<FEE
M=F5D(&%P<')O<')I871E;'DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92!4:&4@;F%M92!O9B!T:&4@9W)O=7`@=&\@<F5T<FEE=F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G971'<F]U<"@D;F%M92D*("`@('L*("`@
M("`@("`O*B!C86-H92!O9B!P<F5V:6]U<R!R971R:65V960@9W)O=7!S("HO
M"B`@("`@("`@<W1A=&EC("1G<F]U<$-A8VAE.PH*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1G<F]U<$-A8VAE*2D@>PH@("`@("`@("`@("`D9W)O=7!#86-H
M92`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1G
M<F]U<$-A8VAE6R1N86UE72DI('L*("`@("`@("`@("`@)&=R;W5P0V%C:&5;
M)&YA;65=(#T@)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T*"1N86UE+"`G
M1&%T851R965/8FIE8W1?1W)O=7`G*3L*("`@("`@("`@("`@:68@*"%I<U]A
M*"1G<F]U<$-A8VAE6R1N86UE72P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@)&=R;W5P0V%C:&5;)&YA;65=+3YS971'<F]U<$]B*"1T:&ES
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G
M<F]U<$-A8VAE6R1N86UE73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!A($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C="!C;W)R97-P;VYD:6YG
M('1O('1H92!G:79E;@H@("`@("H@=6YI<75E($E$+"!W:71H('1H92!U<V5R
M<R!A;F0@;W1H97(@9&%T82!R971R:65V960*("`@("`J(&%P<')O<')I871E
M;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@5&AE('5N
M:7%U92!)1"!O9B!T:&4@9W)O=7`@=&\@<F5T<FEE=F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9G971'<F]U<$)Y260H)&-I9"D*("`@('L*("`@("`@("`D
M9W)O=7`@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W1">4ED*"1C:60L
M("=$871A5')E94]B:F5C=%]'<F]U<"<I.PH@("`@("`@(&EF("@A:7-?82@D
M9W)O=7`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&=R;W5P+3YS
M971'<F]U<$]B*"1T:&ES*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1G
M<F]U<#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&=L;V)A;&QY('5N
M:7%U92!)1"!F;W(@82!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T
M851R965/8FIE8W1?1W)O=7`@)&=R;W5P("!4:&4@9W)O=7`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@($$@1U5)1"!R969E<G)I;F<@=&\@)&=R
M;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'54E$*"1G<F]U<"D*("`@
M('L*("`@("`@("!R971U<FX@)VAO<F1E.F=R;W5P.B<@+B`D=&AI<RT^9V5T
M1W)O=7!)9"@D9W)O=7`I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@
M9W)O=7`@=&\@=&AE(&=R;W5P<R!S>7-T96TN(%1H92!G<F]U<"!M=7-T(&9I
M<G-T(&)E"B`@("`@*B!C<F5A=&5D('=I=&@@1W)O=7`Z.FYE=T=R;W5P*"DL
M(&%N9"!H879E(&%N>2!I;FET:6%L('5S97)S"B`@("`@*B!A9&1E9"!T;R!I
M="P@8F5F;W)E('1H:7,@9G5N8W1I;VX@:7,@8V%L;&5D+@H@("`@("H*("`@
M("`J($!P87)A;2!$871A5')E94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H92!N
M97<@9W)O=7`@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1'<F]U
M<"@D9W)O=7`I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A
M=&%4<F5E3V)J96-T7T=R;W5P)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T=R;W5P<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T
M7T=R;W5P(&]B:F5C=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@
M("`@?0H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H
M)&=R;W5P*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3&]G('1H92!A9&1I=&EO;B!O9B!T:&4@9W)O=7`@:6X@
M=&AE(&AI<W1O<GD@;&]G+B`J+PH@("`@("`@("1H:7-T;W)Y(#T@)DAO<F1E
M7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@("`@("1L;V<@/2`D:&ES=&]R
M>2T^;&]G*"1T:&ES+3YG971'54E$*"1G<F]U<"DL(&%R<F%Y*"=A8W1I;VXG
M(#T^("=A9&0G*2P@=')U92D["B`@("`@("`@:68@*&ES7V$H)&QO9RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&QO9SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4W1O<F4@=7!D871E9"!D871A("T@=7-E<G,L(&5T8RX@+2!O9B!A
M(&=R;W5P('1O('1H92!B86-K96YD('-Y<W1E;2X*("`@("`J"B`@("`@*B!`
M<&%R86T@1&%T851R965/8FIE8W1?1W)O=7`@)&=R;W5P("!4:&4@9W)O=7`@
M=&\@=7!D871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5'<F]U<"@D
M9W)O=7`I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A=&%4
M<F5E3V)J96-T7T=R;W5P)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T=R;W5P<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7T=R
M;W5P(&]B:F5C=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@
M?0H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1A=&%T<F5E+3YU<&1A=&5$
M871A*"1G<F]U<"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\J($QO9R!T:&4@=7!D871E(&]F('1H92!G<F]U<"!U
M<V5R<R!O;B!T:&4@:&ES=&]R>2!L;V<N("HO"B`@("`@("`@)&AI<W1O<GD@
M/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@)&=U:60@
M/2`D=&AI<RT^9V5T1U5)1"@D9W)O=7`I.PH@("`@("`@(&9O<F5A8V@@*"1G
M<F]U<"T^9V5T075D:71,;V<H*2!A<R`D=7-E<DED(#T^("1A8W1I;VXI('L*
M("`@("`@("`@("`@)&AI<W1O<GDM/FQO9R@D9W5I9"P@87)R87DH)V%C=&EO
M;B<@/3X@)&%C=&EO;BP@)W5S97(G(#T^("1U<V5R260I+"!T<G5E*3L*("`@
M("`@("!]"B`@("`@("`@)&=R;W5P+3YC;&5A<D%U9&ET3&]G*"D["@H@("`@
M("`@("\J($QO9R!T:&4@9W)O=7`@;6]D:69I8V%T:6]N+B`J+PH@("`@("`@
M("1H:7-T;W)Y+3YL;V<H)&=U:60L(&%R<F%Y*"=A8W1I;VXG(#T^("=M;V1I
M9GDG*2P@=')U92D["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE(&YA;64@;V8@82!G<F]U<"!W:71H
M;W5T(&-H86YG:6YG(&ET<R!C;VYT96YT<R!O<@H@("`@("H@=VAE<F4@:70@
M:7,@:6X@=&AE(&=R;W5P<R!H:65R87)C:'DN"B`@("`@*@H@("`@("H@0'!A
M<F%M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G<F]U<"`@5&AE(&=R;W5P('1O
M(')E;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=TYA;64@("`@("`@
M("`@("`@(%1H92!G<F]U<"=S(&YE=R!N86UE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YA;65'<F]U<"@D9W)O=7`L("1N97=.86UE*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"='<F]U
M<',@;75S="!B92!$871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X
M=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]D871A=')E92T^<F5N86UE*"1G<F]U<"P@)&YE=TYA;64I
M.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@
M("`O*B!(:7-T;W)Y($QO9R!T:&4@;F%M92!C:&%N9V4@;V8@=&AE(&=R;W5P
M+B`J+PH@("`@("`@("1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L
M971O;B@I.PH@("`@("`@("1H:7-T;W)Y+3YL;V<H)'1H:7,M/F=E=$=5240H
M)&=R;W5P*2P@87)R87DH)V%C=&EO;B<@/3X@)W)E;F%M92<I+"!T<G5E*3L*
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V92!A(&=R;W5P(&9R;VT@=&AE(&=R;W5P<R!S>7-T96T@<&5R;6%N
M96YT;'DN"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7T=R
M;W5P("1G<F]U<"`@5&AE(&=R;W5P('1O(')E;6]V92X*("`@("`J($!P87)A
M;2!B;V]L96%N("1F;W)C92`@("`@("`@("`@("`@($9O<F-E('1O(')E;6]V
M92!E=F5R>2!C:&EL9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E1W)O
M=7`H)&=R;W5P+"`D9F]R8V4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M(6ES7V$H)&=R;W5P+"`G1&%T851R965/8FIE8W1?1W)O=7`G*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1W)O=7!S(&UU<W0@
M8F4@1&%T851R965/8FIE8W1?1W)O=7`@;V)J96-T<R!O<B!E>'1E;F0@=&AA
M="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@("1H:7-T;W)Y(#T@)DAO
M<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@("`@("1H:7-T;W)Y+3YL
M;V<H)'1H:7,M/F=E=$=5240H)&=R;W5P*2P@87)R87DH)V%C=&EO;B<@/3X@
M)V1E;&5T92<I+"!T<G5E*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T
M871R964M/G)E;6]V92@D9W)O=7`L("1F;W)C92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971R:65V92!T:&4@;F%M92!O9B!A(&=R;W5P+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1G:60@(%1H92!I9"!O9B!T:&4@9W)O
M=7`@=&\@<F5T<FEE=F4@=&AE(&YA;64@9F]R+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@9W)O=7`G<R!N86UE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971'<F]U<$YA;64H)&=I9"D*("`@('L*("`@("`@("!I9B`H
M:7-?82@D9VED+"`G1&%T851R965/8FIE8W1?1W)O=7`G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T3F%M92@D9VED+3YG
M971)9"@I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]D871A=')E92T^9V5T3F%M92@D9VED*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3=')I<',@86QL('!A<F5N="!R969E<F5N
M8V5S(&]F9B!O9B!T:&4@9VEV96X@9W)O=7`@;F%M92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@3F%M92!O9B!T:&4@9W)O=7`N"B`@
M("`@*@H@("`@("H@0')E='5R;B!4:&4@;F%M92!O9B!T:&4@9W)O=7`@=VET
M:&]U="!P87)E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<%-H
M;W)T3F%M92@D9W)O=7`I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&%T871R964M/F=E=%-H;W)T3F%M92@D9W)O=7`I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T<FEE=F4@=&AE($E$(&]F(&$@9W)O=7`N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@(%1H92!G<F]U<"!T;R!R971R
M:65V92!T:&4@240@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&=R;W5P)W,@240N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R
M;W5P260H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1G<F]U<"P@
M)T1A=&%4<F5E3V)J96-T7T=R;W5P)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&%T871R964M/F=E=$ED*"1G<F]U<"T^9V5T3F%M92@I*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D
M871A=')E92T^9V5T260H)&=R;W5P*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:R!I9B!A(&=R;W5P(&5X:7-T<R!I;B!T:&4@<WES
M=&5M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!4:&4@
M9W)O=7`@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('1H92!G<F]U<"!E>&ES=',L(&9A;'-E(&]T:&5R=VES92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1G<F]U<"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^97AI<W1S*"1G<F]U<"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H92!P87)E
M;G1S(&]F(&$@8VAI;&0@9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&=I9"!4:&4@:60@;V8@=&AE(&-H:6QD(&=R;W5P+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1W)O=7!087)E;G1S*"1G:60I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&%T871R964M/F=E=%!A<F5N=',H)&=I9"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@=&AE('-I;F=L92!P87)E;G0@;V8@=&AE(&=I=F5N
M(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1G:60@(%1H
M92!$871A5')E92!)1"!O9B!T:&4@8VAI;&0@9W)O=7`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!T:&4@<&%R96YT(&]F('1H92!G:79E;B!G<F]U<"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!087)E;G0H)&=I9"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T4&%R96YT0GE)
M9"@D9VED*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@
M<&%R96YT<R!A;&P@=&AE('=A>2!U<"!T;R!T:&4@<F]O="!O8FIE8W0@9F]R
M("1G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9VED("!4
M:&4@:60@;V8@=&AE(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($$@9FQA="!L:7-T(&]F(&%L;"!O9B!T:&4@<&%R96YT<R!O9B`D9W)O
M=7`L"B`@("`@*B`@("`@("`@("`@("`@("!H87-H960@:6X@)&ED(#T^("1N
M86UE(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!087)E
M;G1,:7-T*"1G:60I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T
M871R964M/F=E=%!A<F5N=$QI<W0H)&=I9"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P+"!I;B!T:&4@9F]R;6%T
M(&-I9"`]/B!G<F]U<&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)')E9G)E<V@@($EF('1R=64L('1H92!C86-H960@=F%L=64@:7,@:6=N
M;W)E9"!A;F0@=&AE(&=R;W5P"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@;&ES="!I<R!R969R97-H960@9G)O;2!T:&4@9W)O=7`@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!#240@/3X@9W)O=7!N
M86UE(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1'<F]U<',H)')E
M9G)E<V@@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)&=R;W5P<SL*
M"B`@("`@("`@:68@*"1R969R97-H('Q\(&ES7VYU;&PH)&=R;W5P<RDI('L*
M("`@("`@("`@("`@)&=R;W5P<R`]("1T:&ES+3Y?9&%T871R964M/F=E="A$
M051!5%)%15]&3U)-051?1DQ!5"P@1$%40512145?4D]/5"P@=')U92D["B`@
M("`@("`@("`@('5N<V5T*"1G<F]U<'-;1$%40512145?4D]/5%TI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1G<F]U<',["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I<R!A('!A
M<G0@;V8@=&AI<R!G<F]U<"!/3DQ9+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1G:60@(%1H92!)1"!O9B!T:&4@9W)O=7`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE('5S97(@;&ES="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&ES=%5S97)S*"1G:60I"B`@("!["B`@("`@("`@)&=R;W5P
M3V(@/2`F)'1H:7,M/F=E=$=R;W5P0GE)9"@D9VED*3L*("`@("`@("!I9B`H
M:7-?82@D9W)O=7!/8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&=R;W5P3V(["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T
M*"1G<F]U<$]B+3YD871A6R=U<V5R<R==*2!\?`H@("`@("`@("`@("`A:7-?
M87)R87DH)&=R;W5P3V(M/F1A=&%;)W5S97)S)UTI*2!["B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y7VME>7,H)&=R;W5P3V(M/F1A=&%;)W5S97)S)UTI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!U<V5R('1H870@:7,@
M<&%R="!O9B!T:&4@<W!E8VEF:65D(&=R;W5P"B`@("`@*B!A;F0@86YY(&]F
M(&ET<R!S=6)G<F]U<',N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&=R;W5P("!4:&4@240@;V8@=&AE('!A<F5N="!G<F]U<"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]M<&QE=&4@=7-E<B!L:7-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T06QL57-E<G,H)&=I9"D*("`@('L*
M("`@("`@("`O+R!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P('1H870@:7,@
M82!S=6(M9W)O=7`@;V8@)&=R;W5P+@H@("`@("`@("1G<F]U<',@/2`D=&AI
M<RT^7V1A=&%T<F5E+3YG971">4ED*$1!5$%44D5%7T9/4DU!5%]&3$%4+"`D
M9VED+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D9W)O=7!S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9W)O=7!S.PH@("`@("`@
M('T*"B`@("`@("`@)&=R;W5P<R`](&%R<F%Y7VME>7,H)&=R;W5P<RD["B`@
M("`@("`@)'5S97)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9W)O
M=7!S(&%S("1G<F]U<$ED*2!["B`@("`@("`@("`@("1U<V5R<R`](&%R<F%Y
M7VUE<F=E*"1U<V5R<RP@)'1H:7,M/FQI<W15<V5R<R@D9W)O=7!)9"DI.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@87)R87E?=F%L=65S*&%R<F%Y7V9L
M:7`H87)R87E?9FQI<"@D=7-E<G,I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P('1H870@)'5S97(@:7,@:6XN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5S97(@("`@("`@("`@
M5&AE('5S97(@=&\@9V5T(&=R;W5P<R!F;W(N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<&%R96YT1W)O=7!S("!!;'-O(')E='5R;B!T:&4@<&%R96YT<R!O
M9B!A;GD@9W)O=7!S/PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N
M(&%R<F%Y(&]F(&%L;"!G<F]U<',@=&AE('5S97(@:7,@:6XN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$=R;W5P365M8F5R<VAI<',H)'5S97(L("1P87)E
M;G1'<F]U<',@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)&-A8VAE
M.PH*("`@("`@("!I9B`H96UP='DH)&-A8VAE6R1U<V5R72DI('L*("`@("`@
M("`@("`@)&-R:71E<FEA(#T@87)R87DH"B`@("`@("`@("`@("`@("`G04Y$
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G
M(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`G=7-E<B<I+`H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VME>2<L("=O
M<"<@/3X@)STG+"`G=&5S="<@/3X@)'5S97(I*2D["B`@("`@("`@("`@("1G
M<F]U<',@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971">4%T=')I8G5T97,H)&-R
M:71E<FEA*3L*"B`@("`@("`@("`@(&EF("AI<U]A*"1G<F]U<',L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9W)O=7!S.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'!A<F5N=$=R;W5P<RD@
M>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P<R!A<R`D:60@/3X@
M)&<I('L*("`@("`@("`@("`@("`@("`@("`D<&%R96YT<R`]("1T:&ES+3Y?
M9&%T871R964M/F=E=%!A<F5N=$QI<W0H)&ED*3L*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<&%R96YT<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!A<F5N=',["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1G<F]U<',@*ST@
M)'!A<F5N=',["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1C86-H95LD=7-E<ET@/2`D9W)O=7!S.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1C86-H95LD=7-E<ET["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!387D@:68@82!U<V5R(&ES(&$@;65M8F5R(&]F(&$@9W)O=7`@
M;W(@;F]T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@
M("`@(%1H92!N86UE(&]F('1H92!U<V5R+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&=I9"`@("`@("`@5&AE($E$(&]F('1H92!G<F]U<"X*("`@("`J($!P
M87)A;2!B;V]L96%N("1S=6)G<F]U<',@(%)E='5R;B!T<G5E(&EF('1H92!U
M<V5R(&ES(&EN(&%N>2!S=6)G<F]U<',*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&]F(&=R;W5P('=I=&@@240@)&=I9"P@86QS;RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=7-E<DES26Y'<F]U<"@D=7-E<BP@)&=I9"P@)'-U8F=R;W5P<R`]('1R
M=64I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^97AI<W1S*"1T:&ES+3YG
M971'<F]U<$YA;64H)&=I9"DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!](&5L<V5I9B`H)'-U8F=R;W5P<RD@>PH@("`@("`@("`@
M("`D9W)O=7!S(#T@)'1H:7,M/F=E=$=R;W5P365M8F5R<VAI<',H)'5S97(L
M('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D9W)O=7!S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&=R;W5P<SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("%E;7!T>2@D9W)O=7!S
M6R1G:61=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7-E<G,@
M/2`D=&AI<RT^;&ES=%5S97)S*"1G:60I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D=7-E<G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=7-E<G,["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M(&EN7V%R<F%Y*"1U<V5R+"`D=7-E<G,I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE($1A=&%4<F5E(&QE=F5L(&]F('1H
M92!G:79E;B!G<F]U<"X@,"!I<R!R971U<FYE9"!F;W(*("`@("`J(&%N9"!O
M8FIE8W0@9&ER96-T;'D@8F5L;W<@1$%40512145?4D]/5"X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D9VED("!4:&4@1&%T851R964@240@;V8@
M=&AE(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@5&AE($1A=&%4<F5E
M(&QE=F5L(&]F('1H92!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3&5V96PH)&=I9"D*("`@('L*("`@("`@("`D;F%M92`]("1T:&ES+3Y?9&%T
M871R964M/F=E=$YA;64H)&=I9"D["B`@("`@("`@<F5T=7)N('-U8G-T<E]C
M;W5N="@D;F%M92P@)SHG*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M
M<'1S('1O(')E='5R;B!A(&-O;F-R971E($=R;W5P(&EN<W1A;F-E(&)A<V5D
M(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV
M97(@(%1H92!T>7!E(&]F(&-O;F-R971E($=R;W5P('-U8F-L87-S('1O(')E
M='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S
M(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($=R;W5P("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!'<F]U<"!I;G-T
M86YC92P@;W(@80H@("`@("H@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T
M;W)Y*"1D<FEV97(@/2`G)RP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@
M("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH*("`@("`@("!I9B`H
M0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]'<F]U<"\G("X@
M)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R]'<F]U<"\G("X@)&1R:79E<B`N("<N
M<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O
M;F-E("=(;W)D92]'<F]U<"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("!]"B`@("`@("`@)&-L87-S(#T@)T=R;W5P7R<@+B`D9')I=F5R.PH@("`@
M("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D
M9W)O=7`@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D9W)O=7`@/2!014%2.CIR86ES945R<F]R*"=#;&%S
M<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9W)O=7`["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@
M82!C;VYC<F5T92!'<F]U<"!I;G-T86YC92X*("`@("`J($ET('=I;&P@;VYL
M>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@1W)O=7`@:6YS=&%N8V4*
M("`@("`J(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)D=R;W5P.CIS:6YG
M;&5T;VXH*0H@("`@("H*("`@("`J($!R971U<FX@1W)O=7`@(%1H92!C;VYC
M<F5T92!'<F]U<"!R969E<F5N8V4L(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"D*("`@('L*("`@("`@
M("!S=&%T:6,@)&=R;W5P.PH*("`@("`@("!I9B`H(6ES<V5T*"1G<F]U<"DI
M('L*("`@("`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]!=71H+G!H<"<["B`@("`@("`@("`@("1A=71H
M(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D[
M"B`@("`@("`@("`@(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G9W)O=7!S
M)RDI('L*("`@("`@("`@("`@("`@("1G<F]U<"`]("9'<F]U<#HZ9F%C=&]R
M>2@D875T:"T^9V5T1')I=F5R*"DL("1A=71H*3L*("`@("`@("`@("`@?2!E
M;'-E:68@*"%E;7!T>2@D8V]N9ELG9W)O=7`G75LG9')I=F5R)UTI("8F("1C
M;VYF6R=G<F]U<"==6R=D<FEV97(G72`A/2`G9&%T871R964G*2!["B`@("`@
M("`@("`@("`@("`D9W)O=7`@/2`F1W)O=7`Z.F9A8W1O<GDH)&-O;F9;)V=R
M;W5P)UU;)V1R:79E<B==*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1G<F]U<"`](&YE=R!'<F]U<"@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&=R;W5P.PH@("`@?0H*?0H*
M+RHJ"B`J($5X=&5N<VEO;B!O9B!T:&4@1&%T851R965/8FIE8W0@8VQA<W,@
M9F]R('-T;W)I;F<@1W)O=7`@:6YF;W)M871I;VX*("H@:6X@=&AE($-A=&5G
M;W)I97,@9')I=F5R+B!)9B!Y;W4@=V%N="!T;R!S=&]R92!S<&5C:6%L:7IE
M9"!'<F]U<`H@*B!I;F9O<FUA=&EO;BP@>6]U('-H;W5L9"!E>'1E;F0@=&AI
M<R!C;&%S<R!I;G-T96%D(&]F(&5X=&5N9&EN9PH@*B!$871A5')E94]B:F5C
M="!D:7)E8W1L>2X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C
M:V%G92!(;W)D95]'<F]U<`H@*B\*8VQA<W,@1&%T851R965/8FIE8W1?1W)O
M=7`@97AT96YD<R!$871A5')E94]B:F5C="!["@H@("`@+RHJ"B`@("`@*B!4
M:&4@1W)O=7`@;V)J96-T('=H:6-H('1H:7,@9W)O=7`@:7,@87-S;V-I871E
M9"!W:71H("T@;F5E9&5D"B`@("`@*B!F;W(@=7!D871I;F<@9&%T82!I;B!T
M:&4@8F%C:V5N9"!T;R!M86ME(&-H86YG97,@<W1I8VLL(&5T8RX*("`@("`J
M"B`@("`@*B!`=F%R($=R;W5P"B`@("`@*B\*("`@('9A<B`D7V=R;W5P3V([
M"@H@("`@+RHJ"B`@("`@*B!4:&ES('9A<FEA8FQE(&-A8VAE<R!T:&4@=7-E
M<G,@861D960@;W(@<F5M;W9E9"!F<F]M('1H92!G<F]U<`H@("`@("H@9F]R
M($AI<W1O<GD@;&]G9VEN9R!O9B!U<V5R+6=R;W5P<R!R96QA=&EO;G-H:7`N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A
M=61I=$QO9R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@1&%T851R
M965/8FIE8W1?1W)O=7`@8V]N<W1R=6-T;W(N($IU<W0@;6%K97,@<W5R92!T
M;R!C86QL"B`@("`@*B!T:&4@<&%R96YT(&-O;G-T<G5C=&]R('-O('1H870@
M=&AE(&=R;W5P)W,@;F%M92!I<R!S970*("`@("`J('!R;W!E<FQY+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H
M92!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T851R965/8FIE8W1?
M1W)O=7`H)&YA;64I"B`@("!["B`@("`@("`@<&%R96YT.CI$871A5')E94]B
M:F5C="@D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-O8VEA=&5S
M(&$@1W)O=7`@;V)J96-T('=I=&@@=&AI<R!G<F]U<"X*("`@("`J"B`@("`@
M*B!`<&%R86T@1W)O=7`@)&=R;W5P3V(@(%1H92!'<F]U<"!O8FIE8W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$=R;W5P3V(H)B1G<F]U<$]B*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9W)O=7!/8B`]("8D9W)O=7!/8CL*("`@('T*
M"B`@("`O*BH*("`@("`J($9E=&-H('1H92!)1"!O9B!T:&ES(&=R;W5P"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(&=R;W5P)W,@240*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T260H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V=R;W5P3V(M/F=E=$=R;W5P260H)'1H:7,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V%V92!A;GD@8VAA;F=E<R!T;R!T:&ES(&]B:F5C
M="!T;R!T:&4@8F%C:V5N9"!P97)M86YE;G1L>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V%V92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)O
M=7!/8BT^=7!D871E1W)O=7`H)'1H:7,I.PH*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9',@82!U<V5R('1O('1H:7,@9W)O=7`L(&%N9"!M86ME<R!S=7)E
M('1H870@=&AE(&)A8VME;F0@:7,*("`@("`J('5P9&%T960@87,@=V5L;"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92!4:&4@=7-E
M<B!T;R!A9&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S97)N
M86UE+"`D=7!D871E(#T@=')U92D*("`@('L*("`@("`@("`D=&AI<RT^9&%T
M85LG=7-E<G,G75LD=7-E<FYA;65=(#T@,3L*("`@("`@("`D=&AI<RT^7V%U
M9&ET3&]G6R1U<V5R;F%M95T@/2`G861D57-E<B<["B`@("`@("`@:68@*"1U
M<&1A=&4@)B8@)'1H:7,M/E]G<F]U<$]B+3YE>&ES=',H)'1H:7,M/F=E=$YA
M;64H*2DI('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YS879E*"D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A('5S
M97(@9G)O;2!T:&ES(&=R;W5P+"!A;F0@;6%K97,@<W5R92!T:&%T('1H92!B
M86-K96YD"B`@("`@*B!I<R!U<&1A=&5D(&%S('=E;&PN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@5&AE('5S97(@=&\@<F5M;W9E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R;F%M92P@
M)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@=6YS970H)'1H:7,M/F1A
M=&%;)W5S97)S)UU;)'5S97)N86UE72D["B`@("`@("`@)'1H:7,M/E]A=61I
M=$QO9ULD=7-E<FYA;65=(#T@)V1E;&5T955S97(G.PH@("`@("`@(&EF("@D
M=7!D871E*2!["B`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!U
M<V5R('1H870@:7,@82!P87)T(&]F('1H:7,@9W)O=7`*("`@("`J("AA;F0@
M;VYL>2!T:&ES(&=R;W5P*0H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!U<V5R(&QI<W0*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G<F]U<$]B+3YL:7-T
M57-E<G,H)'1H:7,M/F=E=$ED*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T(&$@;&ES="!O9B!E=F5R>2!U<V5R('1H870@:7,@82!P87)T(&]F('1H
M:7,@9W)O=7`@86YD"B`@("`@*B!A;GD@;V8@:70G<R!S=6)G<F]U<',*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]M<&QE=&4@=7-E<B!L
M:7-T"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1!;&Q5<V5R<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)O=7!/8BT^;&ES=$%L;%5S97)S
M*"1T:&ES+3YG971)9"@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M;&P@=&AE('5S97)S(')E8V5N=&QY(&%D9&5D(&]R(')E;6]V960@9G)O;2!T
M:&4@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%U9&ET3&]G*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]A=61I=$QO9SL*("`@('T*
M"B`@("`O*BH*("`@("`J($-L96%R<R!T:&4@875D:70@;&]G+B!4;R!B92!C
M86QL960@869T97(@9W)O=7`@=7!D871E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;&5A<D%U9&ET3&]G*"D*("`@('L*("`@("`@("`D=&AI<RT^7V%U9&ET
M3&]G(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($UA<"!T:&ES
M(&]B:F5C="=S(&%T=')I8G5T97,@9G)O;2!T:&4@9&%T82!A<G)A>2!I;G1O
M(&$@9F]R;6%T"B`@("`@*B!T:&%T('=E(&-A;B!S=&]R92!I;B!T:&4@871T
M<FEB=71E<R!S=&]R86=E(&)A8VME;F0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@5&AE(&%T=')I8G5T97,@87)R87DN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]T;T%T=')I8G5T97,H*0H@("`@>PH@("`@("`@("\O($1E9F%U
M;'0@=&\@;F\@871T<FEB=71E<RX*("`@("`@("`D871T<FEB=71E<R`](&%R
M<F%Y*"D["@H@("`@("`@("\O($QO;W`@=&AR;W5G:"!A;&P@=7-E<G,L(&EF
M(&%N>2X*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F1A=&%;)W5S97)S)UTI
M("8F(&ES7V%R<F%Y*"1T:&ES+3YD871A6R=U<V5R<R==*2`F)B!C;W5N="@D
M=&AI<RT^9&%T85LG=7-E<G,G72DI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/F1A=&%;)W5S97)S)UT@87,@)'5S97(@/3X@)&%C=&EV92D@>PH@
M("`@("`@("`@("`@("`@)&%T=')I8G5T97-;72`](&%R<F%Y*"=N86UE)R`]
M/B`G=7-E<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VME>2<@/3X@)'5S97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W9A;'5E)R`]/B`D86-T:79E*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`D871T<FEB=71E<UM=(#T@87)R87DH)VYA
M;64G(#T^("=E;6%I;"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=K97DG(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%L=64G(#T^("1T:&ES+3YG970H)V5M86EL)RDI.PH*("`@("`@("!R971U
M<FX@)&%T=')I8G5T97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&EN
M(&$@;&ES="!O9B!A='1R:6)U=&5S(&9R;VT@=&AE(&)A8VME;F0@86YD(&UA
M<"!I="!T;R!O=7(*("`@("`J(&EN=&5R;F%L(&1A=&$@87)R87DN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R:6)U=&5S("!4:&4@;&ES="!O
M9B!A='1R:6)U=&5S(&9R;VT@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)A8VME;F0@*&%T=')I8G5T92!N86UE+"!K97DL(&%N9"!V
M86QU92DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F<F]M071T<FEB=71E<R@D
M871T<FEB=71E<RD*("`@('L*("`@("`@("`O+R!);FET:6%L:7IE(&1A=&$@
M87)R87DN"B`@("`@("`@)'1H:7,M/F1A=&%;)W5S97)S)UT@/2!A<G)A>2@I
M.PH*("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D871T<BD@>PH@
M("`@("`@("`@("!I9B`H)&%T=');)VYA;64G72`]/2`G=7-E<B<I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YD871A6R=U<V5R<R==6R1A='1R6R=K97DG
M75T@/2`D871T<ELG=F%L=64G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YD871A6R1A='1R6R=N86UE)UU=(#T@)&%T
M=');)W9A;'5E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="\`
M````````````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-0`P,34W,C0`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O3F5T+TE-4U`O````````````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<U`#`Q-C0W
M-``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U34"]!=71H+P``
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-S4`,#$W,S<U`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TYE="])35-0+T%U=&@O<&QA:6YT97AT+G!H<```````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-S0R,0`Q,#0Q-S,V,C<W-0`P,C(Q,3<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!.971?24U34%]!=71H7W!L86EN=&5X="!C;&%S<R!F;W(@24U34"!A
M=71H96YT:6-A=&EO;BX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E
M/@H@*B`@("=U<V5R;F%M92<@(%5S97)N86UE('1O(&QO9V]N('1O($E-4U`@
M<V5R=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@(%!A<W-W;W)D(&9O<B!C=7)R
M96YT('5S97(N"B`J("`@)W-E<G9E<B<@("`@5&AE(&AO<W1N86UE(&]F('1H
M92!)35-0('-E<G9E<BX*("H@("`G<&]R="<@("`@("!4:&4@<&]R="!O9B!T
M:&4@24U34"!S97)V97(N/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`O075T:"]P;&%I;G1E>'0N<&AP+'8@,2XW+C$P+C$Q
M(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I
M;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.971?24U3
M4`H@*B\*8VQA<W,@3F5T7TE-4U!?075T:%]P;&%I;G1E>'0@97AT96YD<R!.
M971?24U34%]!=71H('L*"B`@("`O*BH*("`@("`J(%!R:79A=&4@875T:&5N
M=&EC871I;VX@9G5N8W1I;VXN("!0<F]V:61E<R!A8W1U86P*("`@("`J(&%U
M=&AE;G1I8V%T:6]N(&-O9&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B!`<&%R86T@(&UI>&5D("`D<&%R86US($AA<V@@;V8@24U3
M4"!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($YE
M=%])35-0(&]B:F5C="!C;VYN96-T960@=&\@<V5R=F5R(&EF('-U8V-E<W-F
M=6PL"B`@("`@*B`@("`@("`@("`@("`@("!014%27T5R<F]R(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?875T:&5N=&EC871E*"1P87)A
M;7,I"B`@("!["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O
M;B@G;F]N92<L("1P87)A;7,I.PH@("`@("`@("1R97-U;'0@/2`D:6US<"T^
M:6YI="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("`@)'5S97))9"`]("1P87)A;7-;)W5S97)N86UE)UT["B`@("`@
M("`@("1C<F5D96YT:6%L<R`]("1P87)A;7-;)W!A<W-W;W)D)UT["@H@("`@
M("`@("\J(%-T87)T('1H92!C;VUM86YD+B`J+PH@("`@("`@("1R97-U;'0@
M/2`D:6US<"T^:6US<%-E;F0H)TQ/1TE.("<L('1R=64L(&9A;'-E*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@
M57-E<FYA;64@87,@82![?3\@*B\*("`@("`@("!I9B`H<')E9U]M871C:"A)
M35-07TU54U1?55-%7TQ)5$5204PL("1U<V5R260I*2!["B`@("`@("`@("`@
M("1B:55S97(@/2!S<')I;G1F*"=[)61])RP@<W1R;&5N*"1U<V5R260I*3L*
M("`@("`@("`@("`@)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@D8FE5<V5R
M+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T
M8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;7-P
M+3YI;7-P4F5C96EV92@I*2D@>PH*("`@("`@("`@("`@("`@(')E='5R;B`D
M:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M
M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@D=7-E<DED("X@)R`G
M+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`O*B!$;VXG="!W86YT('1O(&QO9R!T:&4@<&%S
M<W=O<F0A("HO"B`@("`@("`@)&QO9U9A;'5E(#T@)&EM<W`M/FQO9T5N86)L
M960["B`@("`@("`@)&EM<W`M/FQO9T5N86)L960@/2!F86QS93L*"B`@("`@
M("`@+RH@4&%S<R!A<R![?3\@*B\*("`@("`@("!I9B`H<')E9U]M871C:"A)
M35-07TU54U1?55-%7TQ)5$5204PL("1C<F5D96YT:6%L<RDI('L*("`@("`@
M("`@("`@)&)I4&%S<R`]('-P<FEN=&8H)WLE9'TG+"!S=')L96XH)&-R961E
M;G1I86QS*2D["B`@("`@("`@("`@("1R97-U;'0@/2`D:6US<"T^:6US<%-E
M;F0H)&)I4&%S<RP@9F%L<V4L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP
M96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0
M('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@D8W)E
M9&5N=&EA;',L(&9A;'-E+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5S=&]R92!T:&4@;&]G9VEN
M9R!B;V]L96%N+B`J+PH@("`@("`@("1I;7-P+3YL;V=%;F%B;&5D(#T@)&QO
M9U9A;'5E.PH*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)&EM<W`M/FEM
M<W!296-E:79E*"D["B`@("`@("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E<G9E
M<E]R97-P;VYS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D<V5R=F5R7W)E
M<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@<F5T=7)N("1I;7-P+3YI
M;7-P17)R;W(H)TQO9VEN('1O($E-4U`@:&]S="!F86EL960N)RP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6US
M<#L*("`@('T*"B`@("`O*BH*("`@("`J($9O<F-E(&$@;&]G;W5T(&-O;6UA
M;F0@=&\@=&AE(&EM<W`@<W1R96%M+@H@("`@("H*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&]G;W5T*"D*("`@('L*("`@("`@("`D=&AI<RT^7VEM<W`M/FQO
M9V]U="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!D<FEV
M97(@='EP90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG('1H92!T>7!E
M(&]F('1H:7,@24U34%]!=71H(&1R:79E<@H@("`@("HO"B`@("`@9G5N8W1I
M;VX@9V5T1')I=F5R5'EP92@I"B`@("`@>PH@("`@("`@("!R971U<FX@)W!L
M86EN=&5X="<["B`@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0+T%U=&@O8W)A;5]M9#4N<&AP
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S(P,@`Q,#0Q-S,V,C<W
M-0`P,C$U-S,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!.971?24U34%]!=71H7V-R86U?;60U
M(&-L87-S(&9O<B!)35-0(&%U=&AE;G1I8V%T:6]N+@H@*@H@*B!297%U:7)E
M9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W5S97)N86UE)R`@57-E<FYA;64@
M=&\@;&]G;VX@=&\@24U34"!S97)V97(@87,N"B`J("`@)W!A<W-W;W)D)R`@
M4&%S<W=O<F0@9F]R(&-U<G)E;G0@=7-E<BX*("H@("`G<V5R=F5R)R`@("!4
M:&4@:&]S=&YA;64@;V8@=&AE($E-4U`@<V5R=F5R+@H@*B`@("=P;W)T)R`@
M("`@(%1H92!P;W)T(&]F('1H92!)35-0('-E<G9E<BX\+W!R93X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+V-R86U?;60U
M+G!H<"QV(#$N-BXQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!2=6)I;G-K>2`\
M;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*B!`
M<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?075T:%]C<F%M
M7VUD-2!E>'1E;F1S($YE=%])35-07T%U=&@@>PH*("`@("\J*@H@("`@("H@
M4')I=F%T92!A=71H96YT:6-A=&EO;B!F=6YC=&EO;BX@(%!R;W9I9&5S(&%C
M='5A;`H@("`@("H@875T:&5N=&EC871I;VX@8V]D92X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;6EX960@)'!A<F%M
M<R!(87-H(&]F($E-4U`@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D($YE=%])35-0(&]B:F5C="!C;VYN96-T960@=&\@<V5R=F5R
M(&EF('-U8V-E<W-F=6PL"B`@("`@*B`@("`@("`@("`@("`@(%!%05)?17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]A=71H96YT
M:6-A=&4H)'!A<F%M<RD*("`@('L*("`@("`@("`D:6US<"`]("9.971?24U3
M4#HZ<VEN9VQE=&]N*"=N;VYE)RP@)'!A<F%M<RD["B`@("`@("`@)')E<W5L
M="`]("1I;7-P+3YI;FET*"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("1U<V5R260@/2`D<&%R86US6R=U<V5R;F%M
M92==.PH@("`@("`@("1C<F5D96YT:6%L<R`]("1P87)A;7-;)W!A<W-W;W)D
M)UT["B`@("`@("`@)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@G05542$5.
M5$E#051%($-204TM340U)RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("\J($=E="!R97-P;VYS92!A;F0@9&5C;V1E
M(&ET+B!.;W1E('1H870@=V4@<F5M;W9E('1H92`Q<W0@,@H@("`@("`@("`J
M(&-H87)A8W1E<G,@9G)O;2!T:&4@<F5S<&]N<V4@=&\@9V5T(')I9"!O9B!T
M:&4@)RLG"B`@("`@("`@("H@8V]N=&EN=6%T:6]N(&-H87)A8W1E<B!A;F0@
M=&AE('-P86-E('1H870@:7,@<V5N="!A<R!P87)T"B`@("`@("`@("H@;V8@
M=&AE($-204TM340U(')E<W!O;G-E("AA="!L96%S="!O;B!C>7)U<RUI;7-P
M9"DN("HO"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1I;7-P+3YI;7-P
M4F5C96EV92@I.PH@("`@("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?
M<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E
M(#T@8F%S938T7V1E8V]D92AT<FEM*'-U8G-T<B@D<V5R=F5R7W)E<W!O;G-E
M+"`R*2DI.PH*("`@("`@("`O*B!"=6EL9"!A;F0@8F%S938T(&5N8V]D92!T
M:&4@<F5S<&]N<V4@=&\@=&AE(&-H86QL86YG92X@*B\*("`@("`@("`D<F5S
M<&]N<V5?=&]?<V5N9"`]("1U<V5R260@+B`G("<@+B`D=&AI<RT^7VAM86,H
M)&-R961E;G1I86QS+"`D<V5R=F5R7W)E<W!O;G-E*3L*("`@("`@("`D8V]M
M;6%N9%]S=')I;F<@/2!B87-E-C1?96YC;V1E*"1R97-P;VYS95]T;U]S96YD
M*3L*"B`@("`@("`@+RH@4V5N9"!T:&4@<F5S<&]N<V4N("HO"B`@("`@("`@
M)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]S=')I;F<L(&9A
M;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]("1I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H)')E
M<W5L="`A/2`G3TLG*2!["B`@("`@("`@("`@(')E='5R;B`D:6US<"T^:6US
M<$5R<F]R*"=,;V=I;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("1I;7-P.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)&
M0R`R,3`T($A-04,@:6UP;&5M96YT871I;VXN($5L:6UI;F%T97,@=&AE(')E
M;&EA;F-E(&]N(&UH87-H+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'!A<F%M("!S=')I;F<@("1K97D@("`@5&AE($A-04,@:V5Y
M+@H@("`@("H@0'!A<F%M("!S=')I;F<@("1D871A("`@5&AE(&1A=&$@=&\@
M:&%S:"!W:71H('1H92!K97DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!-1#4@2$U!0RX*("`@("`J+PH@("`@9G5N8W1I;VX@7VAM86,H
M)&ME>2P@)&1A=&$I"B`@("!["B`@("`@("`@+RH@0GET92!L96YG=&@@9F]R
M(&UD-2X@*B\*("`@("`@("`D8B`](#8T.PH*("`@("`@("!I9B`H<W1R;&5N
M*"1K97DI(#X@)&(I('L*("`@("`@("`@("`@)&ME>2`]('!A8VLH)T@J)RP@
M;60U*"1K97DI*3L*("`@("`@("!]"@H@("`@("`@("1K97D@/2!S=')?<&%D
M*"1K97DL("1B+"!C:'(H,'@P,"DI.PH@("`@("`@("1I<&%D(#T@<W1R7W!A
M9"@G)RP@)&(L(&-H<B@P>#,V*2D["B`@("`@("`@)&]P860@/2!S=')?<&%D
M*"<G+"`D8BP@8VAR*#!X-6,I*3L*("`@("`@("`D:U]I<&%D(#T@)&ME>2!>
M("1I<&%D.PH@("`@("`@("1K7V]P860@/2`D:V5Y(%X@)&]P860["B`@("`@
M("`@<F5T=7)N(&UD-2@D:U]O<&%D("X@<&%C:R@G2"HG+"!M9#4H)&M?:7!A
M9"`N("1D871A*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1F]R8V4@82!L
M;V=O=70@8V]M;6%N9"!T;R!T:&4@:6US<"!S=')E86TN"B`@("`@*@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L;V=O=70H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?:6US<"T^;&]G;W5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@=&AE(&1R:79E<B!T>7!E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@=&AE('1Y<&4@;V8@=&AI<R!)35-07T%U=&@@9')I=F5R"B`@("`@*B\*
M("`@("!F=6YC=&EO;B!G971$<FEV97)4>7!E*"D*("`@("!["B`@("`@("`@
M(')E='5R;B`G8W)A;5]M9#4G.PH@("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0
M+T%U=&@O:6UT97-T+G!H<```````````````````````````````````````
M```````````````````````P,3`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-C8R-0`Q,#0Q-S,V,C<W-0`P,C$T,C0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!.971?
M24U34%]!=71H7VEM=&5S="!C;&%S<R!F;W(@24U34"!A=71H96YT:6-A=&EO
M;BX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=U<V5R
M;F%M92<@("`@("`@(%5S97)N86UE('1O(&QO9V]N('1O($E-4U`@<V5R=F5R
M(&%S+@H@*B`@("=P87-S=V]R9"<@("`@("`@(%!A<W-W;W)D(&9O<B!C=7)R
M96YT('5S97(N"B`J("`@)W-E<G9E<B<@("`@("`@("`@5&AE(&AO<W1N86UE
M(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G<&]R="<@("`@("`@("`@("!4
M:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N"B`J("`@)W-O8VME="<@("`@
M("`@("`@5&AE(&YA;65D('-O8VME="!T;R!U<V4@9F]R(&-O;FYE8W1I;VX*
M("H@("`G8V]M;6%N9"<@("`@("`@("!0871H('1O('1H92!I;71E<W0@8V]M
M;6%N9"!O;B!L;V-A;&AO<W0*("H@("`G875T:%]M96-H86YI<VTG("!!=71H
M96YT:6-A=&EO;B!M971H;V0@=&\@=7-E('=I=&@@:6UT97-T/"]P<F4^"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"]I;71E
M<W0N<&AP+'8@,2XQ,BXR+C0@,C`P-B\P,2\P,2`R,3HR.#HR."!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B`@("`@($QI86T@2&]E:V5N
M9V$@/&QI86UR0'5M:6-H+F5D=3X*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-
M:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!,:6%M($AO96ME;F=A(#QL:6%M<D!U;6EC
M:"YE9'4^"B`J($!A=71H;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K
M0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L87-S($YE
M=%])35-07T%U=&A?:6UT97-T(&5X=&5N9',@3F5T7TE-4U!?075T:"!["@H@
M("`@+RHJ"B`@("`@*B!0<FEV871E(&%U=&AE;G1I8V%T:6]N(&9U;F-T:6]N
M+B`@4')O=FED97,@86-T=6%L"B`@("`@*B!A=71H96YT:6-A=&EO;B!C;V1E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M
M("!M:7AE9"`@)'!A<F%M<R!(87-H(&]F($E-4U`@<&%R86UE=&5R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!.971?24U34"!O8FIE8W0@8V]N
M;F5C=&5D('1O('-E<G9E<B!I9B!S=6-C97-S9G5L+`H@("`@("H@("`@("`@
M("`@("`@("`@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F7V%U=&AE;G1I8V%T92@D<&%R86US*0H@("`@>PH@("`@("`@
M("1I;7-P(#T@)DYE=%])35-0.CIS:6YG;&5T;VXH)VYO;F4G+"`D<&%R86US
M*3L*("`@("`@("`D8V]M;6%N9"`]("<G.PH@("`@("`@("1E<G)O<E]R971U
M<FX@/2`G)SL*"B`@("`@("`@:68@*'-T<G1O;&]W97(H)'!A<F%M<ULG875T
M:%]M96-H86YI<VTG72D@/3T@)V=S<V%P:2<@)B8*("`@("`@("`@("`@:7-S
M970H)%]315)615);)TM20C5#0TY!344G72DI('L*("`@("`@("`@("`@("`@
M("1C;VUM86YD("X]("=+4D(U0T-.04U%/2<@+B`D7U-%4E9%4ELG2U)"-4-#
M3D%-12==.PH@("`@("`@('T*"B`@("`@("`@)&-O;6UA;F0@+CT@)R`G("`@
M("X@)'!A<F%M<ULG8V]M;6%N9"==+@H@("`@("`@("`@("`@("`@("`@("<@
M+6T@)R`N("1P87)A;7-;)V%U=&A?;65C:&%N:7-M)UT@+@H@("`@("`@("`@
M("`@("`@("`@("<@+74@)R`N(&5S8V%P97-H96QL87)G*"1P87)A;7-;)W5S
M97)N86UE)UTI("X*("`@("`@("`@("`@("`@("`@("`G("UA("<@+B!E<V-A
M<&5S:&5L;&%R9R@D<&%R86US6R=U<V5R;F%M92==*2`N"B`@("`@("`@("`@
M("`@("`@("`@)R`M=R`G("X@97-C87!E<VAE;&QA<F<H)'!A<F%M<ULG<&%S
M<W=O<F0G72DN"B`@("`@("`@("`@("`@("`@("`@)R`M<"`G("X@)'!A<F%M
M<ULG<&]R="==("X*("`@("`@("`@("`@("`@("`@("`G("U8("<@+B`D<&%R
M86US6R=S;V-K970G72`N"B`@("`@("`@("`@("`@("`@("`@)R`G("`@("X@
M)'!A<F%M<ULG<V5R=F5R)UT["@H@("`@("`@("1C;VYN7V%T=&5M<'1S(#T@
M,#L*("`@("`@("!W:&EL92`H)&-O;FY?871T96UP=',K*R`\(#0I('L*("`@
M("`@("`@("`@)&%T=&5M<'1S(#T@,#L*("`@("`@("`@("`@:68@*"%F:6QE
M7V5X:7-T<R@D<&%R86US6R=S;V-K970G72DI('L*("`@("`@("`@("`@("`@
M(&5X96,H)&-O;6UA;F0@+B`G(#X@+V1E=B]N=6QL(#(^)C$G*3L*("`@("`@
M("`@("`@("`@('-L965P*#$I.PH@("`@("`@("`@("`@("`@=VAI;&4@*"%F
M:6QE7V5X:7-T<R@D<&%R86US6R=S;V-K970G72DI('L*("`@("`@("`@("`@
M("`@("`@("!U<VQE97`H,C`P,#`P*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&%T=&5M<'1S*RL@/B`U*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1E<G)O<E]R971U<FX@/2`G.B!.;R!S;V-K970@869T97(@,3`@<V5C;VYD
M<R!O9B!T<GEI;F<A)SL*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64@,CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D
M<&%R86US6R=S;V-K970G72P@,"P@)&5R<F]R7VYU;6)E<BP@)&5R<F]R7W-T
M<FEN9RP@,S`I.PH@("`@("`@("`@("`D97)R;W)?<F5T=7)N(#T@)&5R<F]R
M7W-T<FEN9SL*("`@("`@("`@("`@:68@*"1F<"D@8G)E86L["B`@("`@("`@
M("`@('5N;&EN:R@D<&%R86US6R=S;V-K970G72D["@H@("`@("`@('T*("`@
M("`@("`O+T9A:6QU<F4_"B`@("`@("`@:68@*"%E;7!T>2@D97)R;W)?<F5T
M=7)N*2D@>PH@("`@("`@("`@("!R971U<FX@)&EM<W`M/FEM<W!%<G)O<B@G
M0V]N;F5C=&EO;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<@+B`G.B`G("X@)&5R
M<F]R7W)E='5R;BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@
M("`@("`@+R]3=6-C97-S"B`@("`@("`@)&EM<W`M/E]S=')E86T@/2`D9G`[
M"B`@("`@("`@<F5T=7)N("1I;7-P.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1F]R8V4@82!L;V=O=70@8V]M;6%N9"!T;R!T:&4@:6US<"!S=')E86TN"B`@
M("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V=O=70H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?:6US<"T^;&]G;W5T*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!D<FEV97(@='EP92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('1Y<&4@;V8@=&AI<R!)35-07T%U=&@@9')I
M=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$<FEV97)4>7!E*"D*("`@
M('L*("`@("`@("!R971U<FX@)VEM=&5S="<["B`@("!]"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U3
M4"]!=71H+G!H<```````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3$P-3<`,3`T,3<S-C(W-S4`,#(P,3`W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M)TYE="])35-0+G!H<"<["@HO*BH*("H@5&AE($YE=%])35-07T%U=&@@8VQA
M<W,@86)S=')A8W0@8VQA<W,@9F]R($E-4U`@875T:&5N=&EC871I;VXN"B`J
M"B`J(%)E<75I<F5D(%!A<F%M971E<G,Z/'!R93X*("H@("`G=7-E<FYA;64G
M("!5<V5R;F%M92!T;R!L;V=O;B!T;R!)35-0('-E<G9E<B!A<RX*("H@("`G
M<&%S<W=O<F0G("!087-S=V]R9"!F;W(@8W5R<F5N="!U<V5R+@H@*B`@("=S
M97)V97(G("`@(%1H92!H;W-T;F%M92!O9B!T:&4@24U34"!S97)V97(N"B`J
M("`@)W!O<G0G("`@("`@5&AE('!O<G0@;V8@=&AE($E-4U`@<V5R=F5R+CPO
M<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?24U34"])35-0+T%U
M=&@N<&AP+'8@,2XX+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z,C@Z,C<@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!2=6)I;G-K
M>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@
M*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?075T:"![
M"B`@("`O*BH*("`@("`J($-L87-S('9A<FEA8FQE('1O(&AO;&0@=&AE(')E
M<W5L=&EN9R!.971?24U34"!O8FIE8W0*("`@("`J"B`@("`@*B!`=F%R($YE
M=%])35-0"B`@("`@*B\*("`@('9A<B`D7VEM<W`["@H@("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@;&]G:6X@=&\@24U34"!S97)V97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("!087)A;65T97)S
M(&9O<B!.971?24U34`H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO9VEN("`@
M("`@("!3:&]U;&0@=V4@<F5M86EN(&QO9V=E9"!I;B!A9G1E<B!A=71H/PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@("`@("`@("`@("`@4F5T
M=7)N<R!A($YE=%])35-0(&]B:F5C="!C;VYN96-T960@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE($E-4U`@<V5R=F5R(&EF
M(&QO9VEN(&ES('1R=64@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-U8V-E<W-F=6PN("!2971U<FYS(&)O;VQE86X@=')U92!I
M9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=6-C97-S
M9G5L(&%N9"!L;V=I;B!I<R!F86QS92X@4F5T=7)N<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9A=71H96YT:6-A=&4H)'!A<F%M<RP@
M)&QO9VEN(#T@=')U92D*("`@('L*("`@("`@("`D=&AI<RT^7VEM<W`@/2`F
M)'1H:7,M/E]A=71H96YT:6-A=&4H)'!A<F%M<RD["@H@("`@("`@(&EF("AI
M<U]A*"1T:&ES+3Y?:6US<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"$D;&]G:6XI('L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YL;V=O=70H
M*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4')I=F%T92!A=71H96YT:6-A=&EO;B!F=6YC=&EO;BX@4')O=FED97,@86-T
M=6%L(&%U=&AE;G1I8V%T:6]N"B`@("`@*B!C;V1E+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!A<G)A>2`@("1P87)A
M;7,@("`@("!087)A;65T97)S(&9O<B!.971?24U34%]!=71H(&1R:79E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@("`@("`@(%)E
M='5R;G,@3F5T7TE-4U`@;V)J96-T(&-O;FYE8W1E9"!T;R!S97)V97(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@<W5C8V5S<V9U
M;"P@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("H@0&%B<W1R86-T"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9?875T:&5N=&EC871E*"1P87)A;7,I"B`@
M("!["@H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@='EP92!O
M9B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M($!R971U<FX@<W1R:6YG(%1Y<&4@;V8@24U34%]!=71H(&1R:79E<B!I;G-T
M86YC90H@("`@("HO"B`@("!F=6YC=&EO;B!G971$<FEV97)4>7!E*"D*("`@
M('L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)C92!A(&QO9V]U="!F<F]M
M('1H92!U;F1E<FQY:6YG($E-4U`@<W1R96%M+@H@("`@("H*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&]G;W5T*"D*("`@('L*"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!.971?24U34%]!
M=71H(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(*("`@("`J($UU<W0@8F4@
M8V%L;&5D(&%S("9.971?24U34%]!=71H.CIF86-T;W)Y*"D*("`@("`J"B`@
M("`@*B!`<&%R86T@('-T<FEN9R`D9')I=F5R(%1Y<&4@;V8@3F5T7TE-4U!?
M075T:"!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&-R96%T960@3F5T7TE-4U!?075T:"!S=6)C;&%S<R!O
M<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D
M9')I=F5R*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I
M=F5R*3L*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I('Q\("AS=')C;7`H
M)&1R:79E<BP@)VYO;F4G*2`]/2`P*2D@>PH@("`@("`@("`@("`D875T:"`]
M("9N97<@24U34%]!=71H*"D["B`@("`@("`@("`@(')E='5R;B`D875T:#L*
M("`@("`@("!]"@H@("`@("`@(&EF("AF:6QE7V5X:7-T<RAD:7)N86UE*%]?
M1DE,15]?*2`N("<O075T:"\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]!
M=71H+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@
M)&-L87-S(#T@)TYE=%])35-07T%U=&A?)R`N("1D<FEV97(["@H@("`@("`@
M(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D875T
M:"`]("9N97<@)&-L87-S*"D["B`@("`@("`@("`@(')E='5R;B`D875T:#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+B(I+"`D8VQA<W,I*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T
M<R!T;R!R971U<FX@82!C;VYC<F5T92!.971?24U34%]!=71H(&EN<W1A;F-E
M(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*B!7:6QL(&]N;'D@8W)E871E(&$@
M;F5W(&]B:F5C="!I9B!O;F4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&%L
M<F5A9'D*("`@("`J(&1O97,@;F]T(&5X:7-T+@H@("`@("H@375S="!B92!C
M86QL960@;&EK93H@)'9A<B`]("9.971?24U34%]!=71H.CIS:6YG;&5T;VXH
M)V1R:79E<E]T>7!E)RD["B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@
M)&1R:79E<B!4>7!E(&]F($E-4U!?075T:"!S=6)C;&%S<R!T;R!R971U<FXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@4F5F97)E;F-E('1O($E-
M4U!?075T:"!S=6)C;&%S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L
M971O;B@D9')I=F5R*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S
M.PH@("`@("`@("\J($-H96-K(&9O<B!A;GD@:6UT97-T(&1R:79E<B!I;G-T
M86YC97,@86YD(&MI;&P@=&AE;2X*("`@("`@("`@("!/=&AE<G=I<V4L('1H
M92!S;V-K970@=VEL;"!H86YG(&)E='=E96X@<F5Q=65S=',@9G)O;0H@("`@
M("`@("`@('-E<&5R871E(&1R:79E<G,@*&%N($%U=&@@<F5Q=65S="!A;F0@
M86X@3W!T:6]N<R!R97%U97-T*2XJ+PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D:6YS=&%N8V5S
M(&%S("1O8FHI('L*("`@("`@("`@("`@("`@(&EF("@D;V)J+3YG971$<FEV
M97)4>7!E*"D@/3T@)VEM=&5S="<I('L*("`@("`@("`@("`@("`@("`@("`D
M;V)J+3YL;V=O=70H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2![
M"B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*
M"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R
M*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=
M*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DYE
M=%])35-07T%U=&@Z.F9A8W1O<GDH)&1R:79E<BD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M3F5T+TE-4U`O0F]O:RYP:'``````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,34R,#,U`#$P-#$W,S8R-S<U`#`R,#$P,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E("=.970O24U34"]!=71H+G!H<"<["@HO*BH*("H@4W1R:6YG(&]F
M('-U<'!O<G1E9"!!0TP@<FEG:'1S+@H@*B\*9&5F:6YE*"=)35-07T%#3%]2
M24=(5%,G+"`G;')W8V1A)RD["@HO*BH*("H@3F5T7TE-4U!?0F]O:R!#;&%S
M<R`M('!R;W9I9&5S(&%P:2!F;W(@9&5A;&EN9R!W:71H($E-4U`*("H@861D
M<F5S<R!B;V]K<RX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@
M*B`@("=U<V5R;F%M92<@("`@(%5S97)N86UE('1O(&QO9V]N('1O($E-4U`@
M<V5R=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@("`@(%!A<W-W;W)D(&9O<B!C
M=7)R96YT('5S97(N"B`J("`@)V%U=&A?;65T:&]D)R`@5&AE(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"!T;R!U<V4@=&\@;&]G:6XN"B`J("`@)W-E<G9E<B<@
M("`@("`@5&AE(&AO<W1N86UE(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G
M<&]R="<@("`@("`@("!4:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N/"]P
M<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O
M:RYP:'`L=B`Q+C$V+C(N,C(@,C`P-B\P,2\P,2`R,3HR.#HR."!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%)U8FEN<VMY
M(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J
M($!P86-K86=E($YE=%])35-0"B`J+PIC;&%S<R!.971?24U34%]";V]K('L*
M"B`@("`O*BH*("`@("`J(%-O<G0@;W)D97(N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1S;W)T(#T@)V%S8V5N9"<["@H@
M("`@+RHJ"B`@("`@*B!.971?24U34"!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'9A<B!.971?24U34`H@("`@("HO"B`@("!V87(@)%]I;7-P.PH*("`@("\J
M*@H@("`@("H@4&%R86UE=&5R(&QI<W0N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R!(87-H(&-O;G1A:6YI;F<@24U34"!P87)A;65T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!.971?24U34%]";V]K*"1P87)A;7,I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@
M?0H*("`@("\J*@H@("`@("H@26YI=&EA;&EZ871I;VX@9G5N8W1I;VX@=&\@
M8F4@8V%L;&5D(&%F=&5R(&]B:F5C="!I<R!R971U<FYE9"X*("`@("`J(%1H
M:7,@86QL;W=S(&5R<F]R<R!T;R!O8V-U<B!A;F0@;F]T(&)R96%K('1H92!S
M8W)I<'0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:6YI="@I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7VEM<W`I*2!["B`@("`@("`@("`@("1A=71H(#T@)DYE=%])35-07T%U=&@Z
M.G-I;F=L971O;B@D=&AI<RT^7W!A<F%M<ULG875T:%]M971H;V0G72D["B`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"`]("1A=71H+3YA=71H96YT:6-A=&4H
M)'1H:7,M/E]P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H
M)'1H:7,M/E]I;7-P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM<W`["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?
M:6US<"T^=W)I=&54;TQO9R@G3F5T7TE-4U!?0F]O:R!I;FET:6%L:7IE9"XG
M+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&-O
M;G1A:6YI;F<@=&AE(&YA;65S(&]F(&%L;"!T:&4@861D<F5S<R!B;V]K<PH@
M("`@("H@879A:6QA8FQE('1O('1H92!L;V=G960@:6X@=7-E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D($%R<F%Y(&]F(&%D9')E<W,@8F]O:R!N
M86UE<R!O<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!
M9&1R97-S0F]O:TQI<W0H*0H@("`@>PH@("`@("`@("1C;VUM86YD7W-T<FEN
M9R`]("=!1$1215-30D]/2R`J)SL*"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)&-O;6UA;F1?<W1R:6YG*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"=014%27T5R<F]R)RDI('L*("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@
M24U34"!H;W-T(&9A:6QE9"XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@271E<F%T92!T:')O=6=H('1H92!R97-P;VYS92!A
M;F0@<&]P=6QA=&4@86X@87)R87D@;V8*("`@("`@("`@*B!A9&1R97-S(&)O
M;VL@;F%M97,N("HO"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES
M+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!I9B`H:7-?82@D<V5R
M=F5R7W)E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@('T*("`@("`@("`D86)O
M;VMS(#T@87)R87DH*3L*"B`@("`@("`@=VAI;&4@*'!R96=?;6%T8V@H(B]>
M7"H@041$4D534T)/3TLO(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@
M("`@("`@+RH@268@=&AI<R!I<R!A;B!!1$1215-30D]/2R!R97-P;VYS92P@
M=&AE;B!T:&ES('=I;&P@97AP;&]D92!A<R!S;SH*("`@("`@("`@("`@("H@
M6S!=(&%N9"!;,5T@8V%N(&)E(&1I<V-A<F1E9`H@("`@("`@("`@("`@*B!;
M,ET@/2!A='1R:6)U=&5S"B`@("`@("`@("`@("`J(%LS72`](&1E;&EM:71E
M<@H@("`@("`@("`@("`@*B!;-%T@/2!A9&1R97-S(&)O;VL@;F%M90H@("`@
M("`@("`@("`@*B\*"B`@("`@("`@("`@("\J($9I<G-T+"!C:&5C:R!F;W(@
M82![?2`J+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"A)35-07T]#5$54
M7T-/54Y4+"`D<V5R=F5R7W)E<W!O;G-E+"`D=&5M<$%R<F%Y*2D@>PH@("`@
M("`@("`@("`@("`@)&%B;V]K<UM=(#T@)'1H:7,M/E]I;7-P+3YR96-E:79E
M4W1R:6YG3&ET97)A;"@D=&5M<$%R<F%Y6S)=*3L*("`@("`@("`@("`@("`@
M("\J($=E="!T:&4@0U),1B!A="!E;F0@;V8@041$4D534T)/3TL@<F5S<&]N
M<V4*("`@("`@("`@("`@("`@("`J('1H870@=&AE('M](&1O97,@;F]T(&EN
M8VQU9&4N("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G)E8V5I
M=F53=')I;F=,:71E<F%L*#(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G("<L("1S97)V97)?<F5S
M<&]N<V4I.PH@("`@("`@("`@("`@("`@)&YU;5!A<G1S(#T@8V]U;G0H)'!A
M<G1S*3L*("`@("`@("`@("`@("`@("1N86UE(#T@)'!A<G1S6S1=.PH@("`@
M("`@("`@("`@("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92P@,"P@,2D[
M"B`@("`@("`@("`@("`@("!I9B`H)&9I<G-T0VAA<B`]/2)<(B(I('L*("`@
M("`@("`@("`@("`@("`@("`D;F%M92`](&QT<FEM*"1N86UE+"`B7"(B*3L*
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@-3L@)&D@/"`D;G5M4&%R
M=',[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@+CT@
M)R`G("X@)'!A<G1S6R1I73L*("`@("`@("`@("`@("`@("`@("`@("`@)&QA
M<W1#:&%R(#T@<W5B<W1R*"1P87)T<ULD:5TL('-T<FQE;B@D<&%R='-;)&E=
M*2`M(#$L(#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&QA<W1#
M:&%R(#T](")<(B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M86UE(#T@<G1R:6TH)&YA;64L(")<(B(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D86)O;VMS6UT@/2`D;F%M93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4F5C96EV92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S97)V97)?<F5S
M<&]N<V4@(3T@)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@
M<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G
M*"=!1$1215-30D]/2R!C;VUM86YD($]++B<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'
M7TE.1D\I.PH@("`@("`@(')E='5R;B`D86)O;VMS.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!C;VYT86EN:6YG('1H92!N86UE
M<R!T:&%T(&UA=&-H("1S96%R8V@*("`@("`J(&-R:71E<F$@:6X@=&AE(&%D
M9')E<W,@8F]O:R!N86UE9"`D86)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D86)O;VL@($%D9')E<W,@8F]O:R!N86UE('1O('-E87)C:"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<V5A<F-H("!396%R8V@@8W)I=&5R:6$@
M:6X@=&AE(&9O<FT@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=F
M:65L9$YA;64G(#T^("=S96%R8VA497)M)R`H;6%Y(&EN8VQU9&4@*B!W:6QD
M(&-A<F0I+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@07)R87D@;V8@
M;F%M97,@;V8@=&AE(&5N=')I97,@=&AA="!M871C:"!O<B!014%27T5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S96%R8V@H)&%B;V]K+"`D<V5A<F-H
M*0H@("`@>PH@("`@("`@("\O268@;F\@9FEE;&0@/3X@=F%L=64@<&%I<G,L
M(&%S<W5M92!W92!A<F4@<V5A<F-H:6YG(&YA;64N"B`@("`@("`@)&-R:71E
M<FEA(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1S96%R8V@I
M*2!["B`@("`@("`@("`@("1C<FET97)I85LG;F%M92==(#T@)'-E87)C:#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8W)I=&5R:6$@/2`D<V5A
M<F-H.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)U-%05)#2$%$1%)%4U,@)RP@=')U92P@9F%L<V4I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O
M+R!$;R!W92!N965D('1O('-E;F0@=&AE(&%B;V]K(&YA;64@87,@>WT@/PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@
M)&%B;V]K*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D
M?2(L('-T<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!2
M96-E:79E*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<
M*R\B+"`D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@
M8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E
M<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+R]3=&%R="!P87)S:6YG('1H92!S96%R8V@@87)R
M87DN"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M(B1A8F]O:R(L(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@("1C;W5N="`](&-O=6YT*"1C<FET
M97)I82D["B`@("`@("`@)&-U<G)E;G0@/2`Q.PH@("`@("`@(&9O<F5A8V@@
M*"1C<FET97)I82!A<R`D<V5A<F-H7V9I96QD(#T^("1S96%R8V@I('L*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B`D
M<V5A<F-H7V9I96QD("(L(&9A;'-E+"!F86QS92D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!(;W<@86)O=70@=&AE('-E87)C:"!T97)M(&%S(&$@>WTN"B`@("`@
M("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@
M)'-E87)C:"DI('L*("`@("`@("`@("`@("`@("1B:5-E87)C:"`]('-P<FEN
M=&8H(GLE9'TB+"!S=')L96XH)'-E87)C:"DI.PH*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:5-E87)C:"P@
M9F%L<V4L('1R=64I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<
M*R\B+"`D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C
M=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S
M97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I
M;7-P+3YI;7-P4V5N9"@D<V5A<F-H+"!F86QS92P@)&-U<G)E;G0@/3T@)&-O
M=6YT*3L*("`@("`@("`@("`@("`@("1C=7)R96YT*RL["B`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!/
M;FQY('-E;F0@=&AE($-R3&8@:68@=&AI<R!I<R!T:&4@;&%S="!F:65L9"]S
M96%R8V@@871O;2X*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"<B)R`N("1S96%R8V@@+B`G(B<L(&9A;'-E+"`D
M8W5R<F5N="`]/2`D8V]U;G0I.PH@("`@("`@("`@("`@("`@)&-U<G)E;G0K
M*SL*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@1V5T('1H92!R97-P;VYS92X*("`@("`@("`D<V5R=F5R7W)E
M<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@
M("1A8F]O:TYA;65S(#T@07)R87DH*3L*"B`@("`@("`@=VAI;&4@*'!R96=?
M;6%T8V@H(B]>7"H@4T5!4D-(041$4D534R\B+"`D<V5R=F5R7W)E<W!O;G-E
M*2D@>PH@("`@("`@("`@("`D8VAO<'!E9%]R97-P;VYS92`]"B`@("`@("`@
M("`@("`@("!P<F5G7W)E<&QA8V4H(B]>7"H@4T5!4D-(041$4D534R\B+"`G
M)RP@)'-E<G9E<E]R97-P;VYS92D["@H@("`@("`@("`@("`O+R!'970@<FED
M(&]F(&%N>2!L:6YG97)I;F<@<75O=&5S+@H@("`@("`@("`@("`D8VAO<'!E
M9%]R97-P;VYS92`]('!R96=?<F5P;&%C92@B+UPB+R(L("<G+"`D8VAO<'!E
M9%]R97-P;VYS92D["@H@("`@("`@("`@("`O+R!296UO=F4@86YY(&QI;F=E
M<FEN9R!W:&ET92!S<&%C92!I;B!F<F]N="!O;FQY+@H@("`@("`@("`@("`D
M=&5M<"`](&QT<FEM*"1C:&]P<&5D7W)E<W!O;G-E*3L*"B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"(O*'LI*%LP+3E=>S$L?2DH7'TD*2\B+"`D=&5M
M<"P@)'1E;7!!<G)A>2DI('L*("`@("`@("`@("`@("`@("1D871A4VEZ92`]
M("1T96UP07)R87E;,ET["B`@("`@("`@("`@("`@("`D=&5M<"`]("1T:&ES
M+3Y?:6US<"T^<F5C96EV95-T<FEN9TQI=&5R86PH)&1A=&%3:7IE*3L*"B`@
M("`@("`@("`@("`@("`O*B!'970@=&AE($-23$8@<VEN8V4@>WT@9&]E<R!N
M;W0@:6YC;'5D92!I="X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^<F5C96EV95-T<FEN9TQI=&5R86PH,BD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1A8F]O:TYA;65S6UT@/2`D=&5M<#L*"B`@("`@("`@("`@
M("\O($=E="!T:&4@;F5X="!R97-P;VYS92!L:6YE(&9R;VT@=&AE('-E<G9E
M<BX*("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!]"@H@("`@("`@("\O(%-H;W5L
M9"!C:&5C:R!F;W(@3TL@;W(@0D%$(&AE<F4@:G5S="!T;R!B92!C97)T86EN
M+@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@
M(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N
M9"!Y;W5R(')E<75E<W0N)R`N("`B.B`D8V]M;6%N9%]T97AT(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I
M<R!U;F%B;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)R`N("(Z("(@+B`D
M=&AI<RT^7VEM<W`M/FQA<W1287=%<G)O<BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!4:&ES(&%L;&]W<R!F;W(@;F\@<F5S
M=6QT<R`J+PH@("`@("`@(&EF("AC;W5N="@D86)O;VM.86UE<RD@/"`Q*2![
M"B`@("`@("`@("`@(')E='5R;B`D86)O;VM.86UE<SL*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G4T5!4D-(041$4D53
M4R!C;VUM86YD($]+)RP@7U]&24Q%7U\L(%]?3$E.15]?+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U])3D9/*3L*"B`@("`@
M("`@+R\@1&5T97)M:6YE('1H92!S;W)T(&1I<F5C=&EO;B!A;F0@<&5R9F]R
M;2!T:&4@<V]R="X*("`@("`@("!S=VET8V@@*"1T:&ES+3YS;W)T*2!["B`@
M("`@("`@8V%S92`G87-C96YD)SH*("`@("`@("`@("`@<V]R="@D86)O;VM.
M86UE<RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=D97-C
M96YD)SH*("`@("`@("`@("`@<G-O<G0H)&%B;V]K3F%M97,I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D86)O;VM.
M86UE<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87-S;V-I
M871I=F4@87)R87D@;V8@82!S:6YG;&4@861D<F5S<R!B;V]K(&5N=')Y+@H@
M("`@("H@3F]T92!T:&%T('1H97)E('=I;&P@86QW87ES(&)E(&$@)VYA;64G
M(&9I96QD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K("`@
M("`@($YA;64@;V8@=&AE(&%D9')E<W,@8F]O:R!T;R!S96%R8V@N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1E;G1R>4YA;64@("=N86UE)R!A='1R:6)U=&4@
M;V8@=&AE(&5N=')Y('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!!<G)A>2!C;VYT86EN:6YG(&5N=')Y(&]R(%!%05)?17)R;W(@
M;VX@9F%I;'5R92`O(&YO(&UA=&-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971%;G1R>2@D86)O;VLL("1E;G1R>4YA;64I"B`@("!["B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)T9%5$-(041$4D534R`G
M+"!T<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?
M3$E415)!3"P@)&%B;V]K*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R
M:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E
M+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<
M*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P
M+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T
M960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E
M<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H24U34%]-55-47U5315],251%4D%,+"`D96YT<GE.86UE*2D@>PH@("`@
M("`@("`@("`D8FE.86UE(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D96YT
M<GE.86UE*2D["@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P
M+3YI;7-P4V5N9"@D8FE.86UE+"!F86QS92P@=')U92D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O
M<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T
M:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D96YT<GE.86UE+"!F86QS92P@
M=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(EPB)&5N=')Y3F%M95PB(BP@
M9F%L<V4L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R
M97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@
M("`@<W=I=&-H("@D<V5R=F5R7W)E<W!O;G-E*2!["B`@("`@("`@8V%S92`G
M0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@
M<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@(&-A<V4@
M)TY/)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=.;R!E;G1R>2!I;B!T:&ES(&%D9')E<W,@8F]O:R!M871C:&5S('EO
M=7(@<75E<GDN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@("\O($=E="!T:&4@9&%T82!I;B!A;B!A<W-O8VEA=&EV92!A<G)A
M>2X*("`@("`@("`D96YT<GD@/2`D=&AI<RT^7W!A<G-E1F5T8VA!9&1R97-S
M4F5S<&]N<V4H)'-E<G9E<E]R97-P;VYS92D["@H@("`@("`@("\O1V5T('1H
M92!N97AT('-E<G9E<B!R97-P;VYS92`M+2!T:&ES("IS:&]U;&0J(&)E('1H
M92!/2R!R97-P;VYS92X*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!I9B`H)'-E<G9E
M<E]R97-P;VYS92`A/2`G3TLG*2!["B`@("`@("`@("`@("\O(%5N97AP96-T
M960@<F5S<&]N<V4@=&AR;W<@97)R;W(@8G5T('-T:6QL(&-O;G1I;G5E(&]N
M+@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO
M="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V
M97(N)RQ?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*"=&151#2$%$1%)%4U,@8V]M<&QE
M=&5D($]+)RP@7U]&24Q%7U\L(%]?3$E.15]?+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@4$5!4E],3T=?24Y&3RD["B`@("`@("`@<F5T
M=7)N("1E;G1R>3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N
M97<@861D<F5S<R!B;V]K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%B;V]K3F%M92!&54Q,62!154%,249)140@;F%M92!S=6-H("=J9&]E+F-L
M:65N=',G(&5T8RXN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@5')U
M92!O;B!S=6-C97-S("\@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C<F5A=&5!9&1R97-S0F]O:R@D86)O;VM.86UE*0H@
M("`@>PH@("`@("`@("1C;VUM86YD7W1E>'0@/2`G0U)%051%041$4D534T)/
M3TL@)SL*"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],
M251%4D%,+"`D86)O;VM.86UE*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@
M<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VM.86UE*2D["@H@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8V]M;6%N
M9%]T97AT("X@)&)I0F]O:RP@=')U92P@=')U92D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H
M)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO
M;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1A8F]O:TYA;64L
M(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1C;VUM86YD7W1E>'0@+B`D86)O;VM.86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M<G5E+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S97)V97)?<F5S
M<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@
M:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*("`@("`@("!]
M"@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@
M(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O
M3&]G*"=#4D5!5$5!1$1215-30D]/2R!C;VUP;&5T960@3TLG+"!?7T9)3$5?
M7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.
M15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"@H@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@+R\@0V]U;&0@;F]T
M(&-R96%T92!A8F]O:RX*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R
M;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@
M("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T
M86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`O+R!3;VUE=&AI;F<@=6YE>'!E
M8W1E9"X*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@=&AE('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%N(&%D9')E<W,@8F]O
M:R!C;VUP;&5T96QY(0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B
M;V]K3F%M92!.86UE(&]F(&%D9')E<W,@8F]O:R!T;R!D96QE=&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@+R!014%2
M7T5R<F]R(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E
M061D<F5S<T)O;VLH)&%B;V]K3F%M92D*("`@('L*("`@("`@("`D8V]M;6%N
M9%]T97AT(#T@)T1%3$5414%$1%)%4U-"3T]+("<["@H@("`@("`@("\O($-H
M96-K(&YE960@9F]R('M]+@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?
M35535%]54T5?3$E415)!3"P@)&%B;V]K3F%M92DI('L*("`@("`@("`@("`@
M)&)I0F]O:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K3F%M92DI
M.PH*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E
M;F0H)&-O;6UA;F1?=&5X="`N("1B:4)O;VLL('1R=64L('1R=64I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E
M*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O
M;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1A
M8F]O:TYA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]T97AT("X@)&%B
M;V]K3F%M92P@=')U92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I
M.PH@("`@("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N<V4[
M"B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N<V4I
M('L*("`@("`@("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^=W)I=&54;TQO9R@G1$5,151%041$4D534T)/3TL@8V]M<&QE=&5D($]+
M)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH*("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@("`@("\O
M($-O=6QD(&YO="!$14Q%5$4@86)O;VLN"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE
M('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N
M;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@+R\@4V]M971H
M:6YG('5N97AP96-T960N"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM
M<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R
M97-P;VYS92!F<F]M('1H92!S97)V97(N)RP@7U]&24Q%7U\L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE<R!A;B!A
M9&1R97-S(&)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O
M;VM/;&1.86UE($]L9"!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O
M;VM.97=.86UE($YE=R!A9&1R97-S(&)O;VL@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%1R=64@+R!014%27T5R<F]R"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F%M94%D9')E<W-";V]K*"1A8F]O:T]L9$YA;64L("1A
M8F]O:TYE=TYA;64I"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H)U)%3D%-14%$1%)%4U-"3T]+("<L('1R=64L(&9A
M;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D
M86)O;VM/;&1.86UE*2D@>PH@("`@("`@("`@("`D8FE/;&1.86UE(#T@<W!R
M:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VM/;&1.86UE*2D["@H@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE/;&1.
M86UE+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&%B;V]K3VQD3F%M92`B+"!F
M86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)
M5$5204PL("1A8F]O:TYE=TYA;64I*2!["B`@("`@("`@("`@("1B:4YE=TYA
M;64@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1A8F]O:TYE=TYA;64I*3L*
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD
M*"1B:4YE=TYA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H
M:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@0U),1B!S:6YC92!L87-T('!A<G0N"B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H)&%B;V]K3F5W3F%M92P@9F%L<V4L('1R
M=64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@
M("`@("`O+R!'970@<V5R=F5R(')E<W!O;G-E+@H@("`@("`@("1S97)V97)?
M<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@
M("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@(&-A<V4@
M)TY/)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y;W5R(')E
M<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G
M0D%$)SH*("`@("`@("`@("`@+R\@4WEN=&%X('!R;V)L96TN"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@
M<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RD["@H@
M("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW
M<FET951O3&]G*")!9&1R97-S(&)O;VL@)&%B;V]K3VQD3F%M92!S=6-C97-S
M9G5L;'D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M:&%N9V5D('1O("1A8F]O:TYE=TYA;64B+"!?7T9)3$5?7RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],
M3T=?24Y&3RD["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@
M9G)O;2!T:&4@<V5R=F5R+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@86X@861D<F5S<R!B;V]K
M(&5N=')Y('1O(&%N(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A8F]O:R`@("`@3F%M92!O9B!A9&1R97-S(&)O;VL@=&\@
M861D(&5N=')Y('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;G1R>4EN9F\@
M($%D9')E<W,@8F]O:R!E;G1R>2!I;F9O<FUA=&EO;B`M"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE<F4@35535"!B92!A(&9I96QD("=N
M86UE)R!C;VYT86EN:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5N=')Y(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!4<G5E(&]N('-U8V-E<W,@+R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9$5N=')Y*"1A8F]O:RP@)&5N=')Y26YF
M;RD*("`@('L*("`@("`@("`D8V]M;6%N9%]T97AT(#T@)R<["@H@("`@("`@
M(&EF("AG9714>7!E*"1E;G1R>4EN9F\I("$]("=A<G)A>2<I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*$E-4U!?0D%$
M7T%21U5-14Y4+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@3&]C:R!T:&4@96YT<GD@:68@:70@86QR96%D>2!E>&ES=',N
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YL;V-K16YT<GDH)&%B;V]K+"`D
M96YT<GE);F9O6R=N86UE)UTI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@G4U1/4D5!1$1215-3("<L('1R=64L(&9A;'-E*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@5&%K
M92!C87)E(&]F('1H92!N86UE+@H@("`@("`@("1E;G1R>4YA;64@/2`D96YT
M<GE);F9O6R=N86UE)UT["@H@("`@("`@("\O('M](&9O<B!B;V]K(&YA;64_
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,
M+"`D86)O;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[
M)61](BP@<W1R;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B
M)&%B;V]K("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O($1O('=E(&YE
M960@>WT@9F]R(&5N=')Y(&YA;64@87,@=V5L;#\*("`@("`@("!I9B`H<')E
M9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1E;G1R>4YA;64I*2![
M"B`@("`@("`@("`@("1B:6YA;64@/2!S<')I;G1F*")[)61](BP@<W1R;&5N
M*"1E;G1R>4YA;64I*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@D8FEN86UE+"!F86QS92P@=')U92D["B`@("`@("`@("`@("1T:&ES
M+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4V5N9"@D96YT<GE.86UE+"!F86QS92P@9F%L<V4I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E
M;F0H(EPB)&5N=')Y3F%M95PB("(L(&9A;'-E+"!F86QS92D["B`@("`@("`@
M?0H*("`@("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L=64I(#T@96%C:"@D
M96YT<GE);F9O*2D@>PH@("`@("`@("`@("`O+R!$;R!N;W0@<V5N="!T:&4@
M:V5Y(&YA;64@)VYA;64G+@H@("`@("`@("`@("!I9B`H)&ME>2`A/2`G;F%M
M92<I('L*("`@("`@("`@("`@("`@("\O(%!R;W1E8W0@9G)O;2!E>'1R86YE
M;W5S('=H:71E('-P86-E"B`@("`@("`@("`@("`@("`D=F%L=64@/2!T<FEM
M*"1V86QU92D["@H@("`@("`@("`@("`@("`@+R\@1F]R('-O;64@<F5A<V]N
M+"!T86)S('-E96T@=&\@8G)E86L@=&AI<RX*("`@("`@("`@("`@("`@("1V
M86QU92`]('!R96=?<F5P;&%C92@B+UQT+R(L(")<;EQR(BP@)'9A;'5E*3L*
M"B`@("`@("`@("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@=V4@;F5E9"![
M?0H@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U53
M15],251%4D%,+"`D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@)&-O
M;6UA;F1?=&5X="`N/2`D:V5Y("X@<W!R:6YT9B@B('LE9'TB+"!S=')L96XH
M)'9A;'5E*2D["@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H)&-O;6UA;F1?=&5X="P@9F%L<V4L('1R=64I.PH@("`@("`@
M("`@("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M
M/FEM<W!296-E:79E*"D["B`@("`@("`@("`@("`@("`@("`@)&-O;6UA;F1?
M=&5X="`]("<G.R`O+T-L96%R('1H92!C;VUM86YD7W1E>'0@8G5F9F5R"@H@
M("`@("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5R=F5R7W)E
M<W!O;G-E*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP
M96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`@("`@+R\@4V5N9"!T:&4@<W1R:6YG(&]F(&]C=&5T
M<R!A;F0@8F4@<W5R92!.3U0@=&\*("`@("`@("`@("`@("`@("`@("`O+R!E
M;F0@=VET:"!#4DQ&+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)'9A;'5E+"!F86QS92P@9F%L<V4I.PH*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@268@=V4@
M87)E(&AE<F4L('1H96X@=V4@9&\@;F]T(&YE960@=&\@<V5N9"!A"B`@("`@
M("`@("`@("`@("`@("`@+R\@>WTN"B`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@(EPB(B`N("1V86QU92`N(")<(B(["B`@("`@("`@("`@("`@("`@
M("`@)&-O;6UA;F1?=&5X="`N/2`D:V5Y("X@)R`G("X@)'9A;'5E("X@)R`G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!396YD(&%N>71H:6YG('1H870@:7,@;&5F="!O9B!T:&4@
M8V]M;6%N9"X*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1C;VUM
M86YD7W1E>'0L(&9A;'-E+"!T<G5E*3L*("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!S
M=VET8V@@*"1S97)V97)?<F5S<&]N<V4I('L*("`@("`@("!C87-E("=.3R<Z
M"B`@("`@("`@("`@("\O4V]R<GDN+BYC86YN;W0@9&\@:70N"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V
M97(@:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@
M("`@("\O4V]R<GDN+BYD:60@;F]T('5N9&5R<W1A;F0@>6]U"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@
M<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&
M24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-E<G9E
M<E]R97-P;VYS92`A/2`G3TLG*2!["B`@("`@("`@("`@("\O($-Y<G5S+4E-
M4U`@<V5R=F5R('-E;F1S(&$@1D540TA!1$1215-3(%)E<W!O;G-E(&AE<F4N
M"B`@("`@("`@("`@("\O($1O(&]T:&5R<S\@("`@(%1H:7,@=V%S(&YO="!I
M;B!T:&4@4D9#+@H@("`@("`@("`@("`D9'5M;7E?87)R87D@/0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)S949E=&-H061D<F5S<U)E<W!O;G-E*"1S
M97)V97)?<F5S<&]N<V4I.PH*("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS
M92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@("`@
M('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@("`@("!C87-E
M("=.3R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)TE-4U`@<V5R=F5R(&ES('5N86)L92!T;R!P97)F;W)M('EO
M=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@
M("!C87-E("="040G.@H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E
M<G-T86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:6US<"T^=W)I=&54;TQO9R@G4U1/4D5!1$1215-3($-O;7!L971E9"!S
M=6-C97-S9G5L;'DN)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I
M.PH*("`@("`@("`@("`@("`@("\O=V4@=V5R92!S=6-C97-S9G5L+BXN<V\@
M<F5L96%S92!T:&4@;&]C:R!O;B!T:&4@96YT<GD*("`@("`@("`@("`@("`@
M(&EF("@A)'1H:7,M/G5N;&]C:T5N=')Y*"1A8F]O:RP@)&5N=')Y26YF;ULG
M;F%M92==*2D@>PH@("`@("`@("`@("`@("`@("`@("\O8V]U;&0@;F]T(')E
M;&5A<V4@;&]C:PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G5&AA="!A9&1R97-S(&)O;VL@96YT<GD@:7,@
M;&]C:V5D(&]R(')E860@;VYL>2!F;W(@=&AE(&-U<G)E;G0@=7-E<BXG+"!?
M7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!A8F]O
M:R!E;G1R>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8F]O:R`@
M("`@3F%M92!O9B!A9&1R97-S(&)O;VL@8V]N=&%I;FEN9R!E;G1R>2X*("`@
M("`J($!P87)A;2!S=')I;F<@)&)O;VM%;G1R>2!.86UE(&]F(&5N=')Y('1O
M(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R=64@;VX@
M<W5C8V5S<R`O(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&5L971E16YT<GDH)&%B;V]K+"`D8F]O:T5N=')Y*0H@("`@
M>PH@("`@("`@("\O(%-T87)T('1H92!C;VUM86YD+@H@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"=$14Q%5$5!1$1215-3("<L
M('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@+R\@3F5E9"![?2!F;W(@8F]O:R!N86UE/PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B
M;V]K*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L
M('-T<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@
M:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["@H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$
M:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@
M<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*
M"B`@("`@("`@+R](;W<@8F]U="!F;W(@=&AE(&5N=')Y(&YA;64_"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D8F]O
M:T5N=')Y*2D@>PH@("`@("`@("`@("`D8FE%;G1R>2`]('-P<FEN=&8H(GLE
M9'TB+"!S=')L96XH)&)O;VM%;G1R>2DI.PH*("`@("`@("`@("`@)'1H:7,M
M/E]I;7-P+3YI;7-P4V5N9"@D8FE%;G1R>2P@9F%L<V4L('1R=64I.PH*("`@
M("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I
M;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D8F]O:T5N=')Y(#T@)'1H:7,M/E]I;7-P+3YQ=6]T
M95-P86-E9%-T<FEN9R@D8F]O:T5N=')Y*3L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)O;VM%;G1R>2P@9F%L<V4L('1R
M=64I.PH@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M
M/FEM<W!296-E:79E*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P
M;VYS92D@>PH@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@+R]3;W)R
M>2XN8V%N;F]T(&1O(&ET"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM
M<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE('1O('!E<F9O
M<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@+R]$;R!N;W0@:VYO=R!W:&%T
M('EO=7(@=&%L:VEN9R!A8F]U=`H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N
M9&5R<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@
M("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW
M<FET951O3&]G*"=$14Q%5$4@0V]M<&QE=&5D('-U8V-E<W-F=6QL>2XG+"!?
M7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@86-Q=6ER92!A('-E;6%P:&]R92!O;B!T:&4@861D<F5S<R!B;V]K
M(&5N=')Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K("`@
M("!!9&1R97-S(&)O;VL@;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]O
M:T5N=')Y($YA;64@;V8@96YT<GD@=&\@;&]C:PH@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@=')U92!O<B!A<G)A>2!O;B!S=6-C97-S(&%N9"!014%2
M7T5R<F]R(&]N(&9A:6QU<F4*("`@("`J("`@("`@("`@("`@("`@*'-E<G9E
M<B!D97!E;F1I;F<I"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO8VM%;G1R>2@D
M86)O;VLL("1B;V]K16YT<GDI"B`@("!["B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H)TQ/0TL@041$4D534T)/3TL@)RP@=')U
M92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`O+R!$;R!W92!N965D(&$@<W1R:6YG(&QI=&5R86P_"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D
M86)O;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61]
M(BP@<W1R;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P
M+3YI;7-P4V5N9"@D8FE";V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G
M1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N
M(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*
M"B`@("`@("`@+R\@5VAA="!A8F]U="!T:&4@96YT<GD@;F%M93\*("`@("`@
M("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1B;V]K
M16YT<GDI*2!["B`@("`@("`@("`@("1B:45N=')Y(#T@<W!R:6YT9B@B>R5D
M?2(L('-T<FQE;B@D8F]O:T5N=')Y*2D["@H@("`@("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1B:45N=')Y+"!F86QS92P@=')U92D["@H@("`@
M("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%
M<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN
M=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"1B;V]K16YT<GDL(&9A;'-E+"!T<G5E*3L*
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)O;VM%;G1R>2`]("1T
M:&ES+3Y?:6US<"T^<75O=&53<&%C9613=')I;F<H)&)O;VM%;G1R>2D["B`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1B;V]K16YT<GDB
M+"!F86QS92P@=')U92D["B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R7W)E
M<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@
M("!D;R!["@H@("`@("`@("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N<V4I
M('L*"B`@("`@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AA="!A9&1R97-S(&)O
M;VL@96YT<GD@:7,@;&]C:V5D(&]R(')E860@;VYL>2!F;W(@=&AE(&-U<G)E
M;G0@=7-E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@
M(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R
M<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R]#:&5C:R!T;R!S964@:68@
M=&AI<R!I<R!A($9%5$-(041$4D534R!R97-O;G-E"B`@("`@("`@("`@("1D
M=6UM>2`]("1T:&ES+3Y?<&%R<V5&971C:$%D9')E<W-297-P;VYS92@D<V5R
M=F5R7W)E<W!O;G-E*3L*"B`@("`@("`@("`@(&EF("@D9'5M;7DI('L*("`@
M("`@("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M
M/FEM<W!296-E:79E*"D["B`@("`@("`@("`@('T*"B`@("`@("`@?2!W:&EL
M92`H)'-E<G9E<E]R97-P;VYS92`A/2`G3TLG*3L*"B`@("`@("`@)'1H:7,M
M/E]I;7-P+3YW<FET951O3&]G*"),3T-+($%$1%)%4U-"3T]+(&]N("1A8F]O
M:R`D8F]O:T5N=')Y($]+(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*"B`@
M("`@("`@+R\@4F5T=7)N(&5I=&AE<B!T<G5E(&]R('1H92!&151#2$%$1%)%
M4U,@<F5S<&]N<V4@:68@:70@97AI<W1S+@H@("`@("`@(&EF("@A)&1U;6UY
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D9'5M;7D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@56YL;V-K<R!A('!R979I;W5S;'D@;&]C:V5D(&%D
M9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8F]O
M:R`@("`@3F%M92!O9B!A9&1R97-S(&)O;VL@8V]N=&%I;FEN9R!L;V-K960@
M96YT<GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V]K16YT<GD@3F%M92!O
M9B!E;G1R>2!T;R!U;FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=6YL;V-K16YT<GDH)&%B;V]K+"`D8F]O:T5N
M=')Y*0H@("`@>PH@("`@("`@("\O(%-T87)T('-E;F1I;F<@8V]M;6%N9"X*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G54Y,
M3T-+($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@>WT@9F]R(&)O
M;VL@;F%M93\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%
M7TQ)5$5204PL("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I0F]O:R`]('-P
M<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K*2D["@H@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*
M"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV
M92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C
M;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L
M<V4L(&9A;'-E*3L*"B`@("`@("`@+R](;W<@8F]U="!F;W(@96YT<GD@;F%M
M93\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$52
M04PL("1B;V]K16YT<GDI*2!["B`@("`@("`@("`@("1B:45N=')Y/7-P<FEN
M=&8H(GLE9'TB+"!S=')L96XH)&)O;VM%;G1R>2DI.PH@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:45N=')Y+"!F86QS92P@=')U92D[
M"@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I
M=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@
M8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B;V]K16YT<GDL(&9A;'-E+"!T
M<G5E*3L*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)O;VM%;G1R
M>2`]("1T:&ES+3Y?:6US<"T^<75O=&53<&%C9613=')I;F<H)&)O;VM%;G1R
M>2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1B;V]K
M16YT<GDB+"!F86QS92P@=')U92D["B`@("`@("`@?0H*("`@("`@("`D<F5S
M<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@
M('-W:71C:"`H)')E<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)TE-4U`@
M<V5R=F5R(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@<F5Q=65S="XG+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!C87-E("="040G.@H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)
M35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U<B!R97%U97-T+B<L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T]+)SH*("`@
M("`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*")53DQ/0TL@041$
M4D534T)/3TL@;VX@)&%B;V]K("1B;V]K16YT<GD@3TLB+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@06-C97-S($-O;G1R;VP@
M3&ES="`H04-,*2`@365T:&]D<RX*("`@("`J"B`@("`@*B!4:&4@9F]L;&]W
M:6YG(&-H87)A8W1E<G,@87)E(')E8V]G;FEZ960@04-,(&-H87)A8W1E<G,Z
M(&QR=V-D80H@("`@("H@;"`M(")L;V]K=7`B("`H<V5E('1H92!N86UE(&%N
M9"!E>&ES=&5N8V4@;V8@=&AE(&%D9')E<W,@8F]O:RD*("`@("`J('(@+2`B
M<F5A9"(@("`@*'-E87)C:"!A;F0@<F5T<FEE=F4@861D<F5S<V5S(&9R;VT@
M861D<F5S<R!B;V]K*0H@("`@("H@=R`M(")W<FET92(@("`H8W)E871E+V5D
M:70@;F5W(&%D9')E<W,@8F]O:R!E;G1R:65S("T@;F]T(&1E;&5T92D*("`@
M("`J(&,@+2`B8W)E871E(B`@*&-R96%T92!N97<@861D<F5S<R!B;V]K<R!U
M;F1E<B!T:&4@8W5R<F5N="!A9&1R97-S(&)O;VLI"B`@("`@*B!D("T@(F1E
M;&5T92(@("AD96QE=&4@96YT<FEE<R!O<B!E;G1I<F4@8F]O:RD*("`@("`J
M(&$@+2`B861M:6XB("`@*'-E="!!0TP@;&ES=',@9F]R('1H:7,@861D<F5S
M<R!B;V]K("T@=7-U86QL>2!O;FQY"B`@("`@*B`@("`@("`@("`@("`@(&%L
M;&]W960@9F]R('1H92!O=VYE<B!O9B!T:&4@861D<F5S<R!B;V]K*0H@("`@
M("H*("`@("`J(&5X86UP;&5S.@H@("`@("H@(")L<B(@=V]U;&0@8F4@<F5A
M9"!O;FQY(&9O<B!T:&%T('5S97(*("`@("`J("`B;')W(B!W;W5L9"!B92!R
M96%D+W=R:71E"B`@("`@*B\*"B`@("`O*BH*("`@("`J(%-E=',@86X@06-C
M97-S($-O;G1R;VP@3&ES="!F;W(@86X@86)O;VLN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D86)O;VL@3F%M92!O9B!A9&1R97-S(&)O;VLN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="!.86UE(&]F('5S97(@9F]R('1H
M:7,@86-L+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-L("`@86-L(&9O<B!T
M:&ES('5S97(O8F]O:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R
M=64@;VX@<W5C8V5S<R`O(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T04-,*"1A8F]O:RP@)&ED96YT+"`D86-L*0H@
M("`@>PH@("`@("`@("\O(%9E<FEF>2!T:&%T("1A8VP@;&]O:W,@9V]O9"X*
M("`@("`@("!I9B`H<')E9U]M871C:"@B+UM>(B`N($E-4U!?04-,7U))1TA4
M4R`N(")=+R(L("1A8VPI*2!["B`@("`@("`@("`@("\O97)R;W(N+BYA8VP@
M;&ES="!C;VYT86EN960@=6YR96-O9VEN>F5D(&]P=&EO;G,*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*$E-4U!?0D%$7T%2
M1U5-14Y4+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@0F5G:6X@<V5N9&EN9R!C;VUM86YD+@H@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"=3151!0TP@041$4D534T)/3TL@
M)RP@=')U92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`O+R![?2!F;W(@8F]O:R!N86UE/PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B;V]K
M*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T
M<FQE;B@D86)O;VLI*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@D8FE";V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I9B`H
M(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO
M="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O
M;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4V5N9"@B)&%B;V]K("(L(&9A;'-E+"!F86QS92D["@H@("`@
M("`@("\O('M](&9O<B!I9&5N=#\*("`@("`@("!I9B`H<')E9U]M871C:"A)
M35-07TU54U1?55-%7TQ)5$5204PL("1I9&5N="DI('L*("`@("`@("`@("`@
M)&)I261E;G0@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1I9&5N="DI.PH@
M("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4ED96YT+"!F
M86QS92P@=')U92D["@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>
M7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C
M=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S
M97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]
M"@H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B
M)&ED96YT("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O($YO=R!F:6YI
M<V@@=7`@=VET:"!T:&4@86-T=6%L($%#3"X*("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"1A8VPL(&9A;'-E+"!T<G5E*3L*("`@("`@("`D<F5S
M<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@
M('-W:71C:"`H)')E<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@("`@
M("`@("`@("`O+R!#;W5L9"!N;W0@<V5T($%#3"X*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U
M;F%B;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)RQ?7T9)3$5?7RP@7U],
M24Y%7U\I.PH*("`@("`@("!C87-E("="040G.@H@("`@("`@("`@("`O+R!"
M860@<WEN=&%X+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@
M>6]U<B!R97%U97-T+B<L7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@
M8V%S92`G3TLG.@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],
M;V<H(D%#3"!S970@9F]R("1I9&5N="!O;B`D86)O;VLB+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!R971U<FX@=')U93L*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@+R\@1&\@;F]T(&MN;W<@
M=VAY('=E('=O=6QD(&UA:V4@:70@9&]W;B!H97)E+@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV
M92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=')I979E<R!A;B!A9&1R97-S(&)O;VLG<R!!0TPN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VL@3F%M92!O9B!A9&1R97-S(&)O
M;VL@=&\@<F5T<FEE=F4@86-L(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(&%R<F%Y(&-O;G1A:6YI;F<@86-L(&9O<B!E=F5R>2!U<V5R('=I
M=&@@86-C97-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&%D9')E
M<W,@8F]O:R!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$%#3"@D86)O;VLI"B`@("!["B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)T=%5$%#3"!!1$1215-30D]/
M2R`G+"!T<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("\O('M](&9O<B!B;V]K(&YA;64_"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O
M;VLI*2!["B`@("`@("`@("`@("1B:4YA;64@/2!S<')I;G1F*")[)61](BP@
M<W1R;&5N*"1A8F]O:RDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!396YD*"1B:4YA;64L(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF
M("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@
M;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S
M<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H)&%B;V]K+"!F86QS92P@=')U92D["@H@("`@("`@
M("\O($=E="!R97-U;'1S+@H@("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?
M:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@<W=I=&-H("@D<F5S<&]N
M<V4I('L*("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@("`@("\O($-O=6QD
M(&YO="!C;VUP;&5T93\*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R
M;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@
M("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@+R\@1&\@;F]T(&MN;W<@=VAA
M="!Y;W4@<V%I9"$*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD
M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@268@=V4@87)E(&AE<F4L('=E(&YE960@=&\@<F5C
M96EV92!T:&4@*B!!0TP@4F5S<&]N<V5S+@H@("`@("`@(&1O('L*("`@("`@
M("`@("`@+RH@1V5T(&%N(&%R<F%Y(&]F(')E<W!O;G-E<RX*("`@("`@("`@
M("`@("H@5&AE(%LS72!E;&5M96YT('-H;W5L9"!B92!T:&4@861D<F5S<R!B
M;V]K(&YA;64*("`@("`@("`@("`@("H@6S1=(&%N9"!;-5T@=VEL;"!B92!U
M<V5R+V=R;W5P(&YA;64@86YD('!E<FUI<W-I;VYS("HO"@H@("`@("`@("`@
M("`O+W1H92!B;V]K(&YA;64@;6EG:'0@8F4@82!L:71E<F%L"B`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?3T-4151?0T]53E0L("1R97-P;VYS
M92P@)'1E;7!!<G)A>2DI('L*("`@("`@("`@("`@("`@("1D871A(#T@)'1H
M:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET97)A;"@D=&5M<$%R<F%Y6S)=
M*3L*("`@("`@("`@("`@("`@("\O1V5T('1H92!R97-T"B`@("`@("`@("`@
M("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H
M)R`G+"`D<F5S<&]N<V4I.PH*("`@("`@("`@("`@+R\@4'5S:"!T:&4@87)R
M87D@:68@8F]O:R!W87,@82!L:71E<F%L"B`@("`@("`@("`@(&EF("@D9&%T
M82D@>PH@("`@("`@("`@("`@("`@87)R87E?=6YS:&EF="@D<&%R=',L("<@
M)RP@)R`G+"`G("<L("<@)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M+R\@061D<F5S<R!B;V]K(&YA;64@<75O=&5D/PH@("`@("`@("`@("`D;G5M
M4&%R=',@/2!C;W5N="@D<&%R=',I.PH@("`@("`@("`@("`D;F%M92`]("1P
M87)T<ULS73L*("`@("`@("`@("`@)&9I<G-T04-,261X(#T@-#L*("`@("`@
M("`@("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92P@,"P@,2D["B`@("`@
M("`@("`@(&EF("@D9FER<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@
M("`@(&9O<B`H)&D@/2`T.R`D:2`\("1N=6U087)T<SL@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D<&%R='-;)&E=
M+"!S=')L96XH)'!A<G1S6R1I72D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@
M("`@("`D9FER<W1!0TQ)9'@K*SL*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&QA<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W(@*"1I(#T@)&9I<G-T
M04-,261X.R`D:2`\(&-O=6YT*"1P87)T<RD[("1I("L](#(I('L*("`@("`@
M("`@("`@("`@("1R97-U;'1S6R1P87)T<ULD:5U=(#T@)'!A<G1S6R1I*S%=
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI
M<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@('T@=VAI;&4@*'!R
M96=?;6%T8V@H(B]>7"H@04-,($%$1%)%4U-"3T]++R(L("1R97-P;VYS92DI
M.PH*("`@("`@("`O+R!(;W!E9G5L;'D@=V4@8V%N(')E8V5I=F4@86X@3TL@
M<F5S<&]N<V4@:&5R90H@("`@("`@(&EF("@D<F5S<&]N<V4@(3T@)T]+)RD@
M>PH@("`@("`@("`@("`O+R!3;VUE('=E:7)D('!R;V)L96T*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E
M8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?:6US<"T^=W)I=&54;TQO9R@B1T5404-,(&]N("1A8F]O:R!C;VUP;&5T
M960N(BP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("!R971U<FX@
M)')E<W5L=',["@H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!!
M0TP@96YT<GD@9F]R(&%N(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A8F]O:R!.86UE(&]F('1H92!A9&1R97-S(&)O;VLN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="!.86UE(&]F(&5N=')Y('1O
M(')E;6]V92!A8VP@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M=')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1E;&5T94%#3"@D86)O;VLL("1I9&5N="D*("`@
M('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G
M1$5,151%04-,($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@1&\@
M=V4@;F5E9"!L:71E<F%L(&9O<B!A9&1R97-S(&)O;VL@;F%M93\*("`@("`@
M("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1A8F]O
M:RDI('L*("`@("`@("`@("`@)&)I0F]O:R`]('-P<FEN=&8H(GLE9'TB+"!S
M=')L96XH)&%B;V]K*2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US
M<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@
M*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N
M;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P
M;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H(B1A8F]O:R`B+"!F86QS92P@9F%L<V4I.PH*("`@
M("`@("`O+R!,:71E<F%L(&9O<B!I9&5N="!N86UE/PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&ED96YT*2D@>PH@
M("`@("`@("`@("`D8FE)9&5N="`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH
M)&ED96YT*2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M)&)I261E;G0L(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("@A<')E
M9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E
M8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@
M9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E
M;F0H)&ED96YT+"!F86QS92P@=')U92D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B7"(D:61E;G1<(B(L
M(&9A;'-E+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("\O($=E="!R97-U
M;'1S+@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M
M/FEM<W!296-E:79E*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P
M;VYS92D@>PH@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B
M;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*"B`@("`@("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED
M(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH*("`@("`@("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T:&ES
M+3Y?:6US<"T^=W)I=&54;TQO9R@B1$5,151%1"!!0TP@9F]R("1I9&5N="!O
M;B`D86)O;VLB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@
M<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R
M+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@04-,('-T<FEN9R!C;VYT86EN:6YG('1H
M92!R:6=H=',@9F]R('1H92!C=7)R96YT('5S97(*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A8F]O:R!.86UE(&]F(&%D9')E<W,@8F]O:R!T;R!R
M971R:65V92!A8VPN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!A8VP@
M;V8@8W5R<F5N="!U<V5R(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;7E2:6=H=',H)&%B;V]K*0H@("`@>PH@("`@
M("`@("1D871A(#T@)R<["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)TU94DE'2%13($%$1%)%4U-"3T]+("<L('1R=64L(&9A
M;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D
M86)O;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61]
M(BP@<W1R;&5N*"1A8F]O:RDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M
M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@
M(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$
M:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@
M<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"1A8F]O:RP@9F%L<V4L('1R=64I.PH@("`@
M("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E
M:79E*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@
M("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R
M9F]R;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@
M("`@("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E
M<G-T86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPJ($U94DE'
M2%13($%$1%)%4U-"3T]++R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO
M="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V
M97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O
M+R![?2!F;W(@=&AE(&%B;V]K(&YA;64_"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H24U34%]/0U1%5%]#3U5.5"P@)'-E<G9E<E]R97-P;VYS92P@)'1E;7!!
M<G)A>2DI('L*("`@("`@("`@("`@)&1A=&$@/2`D=&AI<RT^7VEM<W`M/G)E
M8V5I=F53=')I;F=,:71E<F%L*"1T96UP07)R87E;,ETI.PH@("`@("`@("`@
M("`O+R!'970@=&AE(')E<W0N"B`@("`@("`@("`@("1S97)V97)?<F5S<&]N
M<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@?0H*
M("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<@)RP@)'-E<G9E<E]R97-P;VYS
M92D["@H@("`@("`@("\O(%!U<V@@=&AE(&%R<F%Y(&EF('=E(&AA9"!A('M]
M"B`@("`@("`@:68@*"1D871A*2!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI
M9G0H)'!A<G1S+"`G("<L("<@)RP@)R`G+"`G("<I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@475O=&5D(&%D9')E<W,@8F]O:R!N86UE/PH@("`@("`@("1N
M=6U087)T<R`](&-O=6YT*"1P87)T<RD["B`@("`@("`@)&YA;64@/2`D<&%R
M='-;,UT["B`@("`@("`@)&9I<G-T04-,261X(#T@-#L*("`@("`@("`D9FER
M<W1#:&%R(#T@<W5B<W1R*"1N86UE+"`P+"`Q*3L*("`@("`@("!I9B`H)&9I
M<G-T0VAA<B`]/2`B7"(B*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`T.R`D
M:2`\("1N=6U087)T<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&QA<W1#
M:&%R(#T@<W5B<W1R*"1P87)T<ULD:5TL('-T<FQE;B@D<&%R='-;)&E=*2`M
M(#$L(#$I.PH@("`@("`@("`@("`@("`@)&9I<G-T04-,261X*RL["B`@("`@
M("`@("`@("`@("!I9B`H)&QA<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&%C;"`]("1P87)T<ULD9FER<W1!
M0TQ)9'A=.PH@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM
M<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@(&EF("@D<V5R=F5R7W)E<W!O
M;G-E("$]("=/2R<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R
M:71E5&],;V<H(DU94DE'2%13(&]N("1A8F]O:R!C;VUP;&5T960N(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U<FX@
M)&%C;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M92!L;V<@:6YF;W)M871I;VX@:6X@=&AE($YE=%])35-0(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@(&%R<F%Y("!,;V<@<&%R86UE=&5R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@4$5!
M4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,
M;V=G97(H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]I;7-P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YS
M971,;V=G97(H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB*2D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4&%R<V5S(&$@24U34"!F971C:&%D9')E<W,@<F5S
M<&]N<V4@=&5X="!S=')I;F<@:6YT;PH@("`@("H@:V5Y+79A;'5E('!A:7)S
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@
M('-T<FEN9R`@)'-E<G9E<E]R97-P;VYS92!4:&4@<F%W(&9E=&-H861D<F5S
M<R!R97-P;VYS92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@061D
M<F5S<R!B;V]K(&5N=')Y(&EN9F]R;6%T:6]N(&%S(&ME>3T^=F%L=64@<&%I
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S949E=&-H061D<F5S<U)E
M<W!O;G-E*"1S97)V97)?<F5S<&]N<V4I"B`@("!["B`@("`@("`@)&%B;V]K
M(#T@)R<["@H@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*B!&151#2$%$
M1%)%4U,@+R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G6T524D]272!$:60@;F]T(')E8V5I
M=F4@82!&151#2$%$1%)%4U,@<F5S<&]N<V4@9G)O;2!S97)V97(N)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*"B`@("`@("`@("`@("1T:&ES+3Y?
M:6US<"T^97AI=$-O9&4@/2`G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E
M9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)SL*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@3D]415,*("`@("`@
M("`@*B!087)S92!O=70@=&AE('-E<G9E<B!R97-P;VYS92!S=')I;F<*("`@
M("`@("`@*@H@("`@("`@("`J($%F=&5R(&-H;W!I;F<@;V9F('1H92!S97)V
M97(@8V]M;6%N9"!R97-P;VYS92!T86=S(&%N9`H@("`@("`@("`J(&5X<&QO
M9&4H*2=I;F<@=&AE('-E<G9E<E]R97-P;VYS92!S=')I;F<*("`@("`@("`@
M*B!T:&4@)'!A<G1S(&%R<F%Y(&-O;G1A:6YS('1H92!C:'5N:W,@;V8@=&AE
M('-E<G9E<B!R971U<FYE9"!D871A+@H@("`@("`@("`J"B`@("`@("`@("H@
M5&AE('!R961I9FEN960@)VYA;64G(&9I96QD('-T87)T<R!I;B`D<&%R='-;
M,5TN"B`@("`@("`@("H@5&AE('-E<G9E<B!S:&]U;&0@<F5T=7)N(&%N>2!S
M:6YG;&4@:71E;2!O9B!D871A"B`@("`@("`@("H@=&AA="!C;VYT86EN<R!S
M<&%C97,@=VET:&EN(&ET(&%S(&$@9&]U8FQE('%U;W1E9"!S=')I;F<N"B`@
M("`@("`@("H@4V\@=V4@8V%N(&EN=&5R<')E="!T:&4@97AI<W1E;F-E(&]F
M(&$@9&]U8FQE('%U;W1E(&%T('1H92!B96=I;FYI;F<*("`@("`@("`@*B!O
M9B!A(&-H=6YK('1O(&UE86X@=&AA="!T:&4@;F5X="!C:'5N:RAS*2!A<F4@
M<&%R="!O9@H@("`@("`@("`J('1H92!S86UE('9A;'5E+B`@02!D;W5B;&4@
M<75O=&4@870@=&AE(&5N9"!O9B!A(&-H=6YK('-I9VYI9FEE<R!T:&4*("`@
M("`@("`@*B!E;F0@;V8@=&AA="!V86QU92!A;F0@=&AE(&-H=6YK(&9O;&QO
M=VEN9R!T:&%T(&-A;B!B92!I;G1E<G!R971E9`H@("`@("`@("`J(&%S(&$@
M:V5Y(&YA;64N"B`@("`@("`@("H*("`@("`@("`@*B!792!A;'-O(&YE960@
M=&\@=V%T8V@@9F]R('1H92!S97)V97(@<F5T=7)N:6YG(&$@>WT@<F5S<&]N
M<V4@9F]R('1H90H@("`@("`@("`J('9A;'5E(&]F('1H92!K97D@87,@=V5L
M;"X@*B\*"B`@("`@("`@+R\@5V%S('1H92!A9&1R97-S(&)O;VL@;F%M92!A
M("![?3\*("`@("`@("!I9B`H<')E9U]M871C:"@B+RA>7"H@1D540TA!1$12
M15-3("DH>RDH6S`M.5U[,2Q]*2A<?20I+R(L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'-E<G9E<E]R97-P;VYS92P@)'1E;7!!<G)A>2DI('L*("`@("`@
M("`@("`@)&%B;V]K(#T@)'1H:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET
M97)A;"@D=&5M<$%R<F%Y6S-=*3L*("`@("`@("`@("`@)&-H;W!P961?<F5S
M<&]N<V4@/2!T<FEM*"1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@5&%K92!O9F8@=&AE('-T
M=69F(&9R;VT@=&AE(&)E9VEN;FEN9R!O9B!T:&4@<F5S<&]N<V4*("`@("`@
M("`@("`@)&-H;W!P961?<F5S<&]N<V4@/2!T<FEM*'!R96=?<F5P;&%C92@B
M+UY<*B!&151#2$%$1%)%4U,@+R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L("1S97)V97)?<F5S<&]N
M<V4I*3L*("`@("`@("!]"@H@("`@("`@("1P87)T<R`](&5X<&QO9&4H)R`G
M+"`D8VAO<'!E9%]R97-P;VYS92D["B`@("`@("`@+RH@268@861D<F5S(&)O
M;VL@=V%S('-E;G0@87,@82![?2!T:&5N('=E(&UU<W0@)W!U<V@G(&$@8FQA
M;FL*("`@("`@("`@*B!V86QU92!T;R!T:&4@<W1A<G0@;V8@=&AI<R!A<G)A
M>2!S;R!T:&4@<F5S="!O9B!T:&4@<F]U=&EN90H@("`@("`@("`J('=I;&P@
M=V]R:R!W:71H('1H92!C;W)R96-T(&EN9&5X97,N("HO"B`@("`@("`@(&EF
M("@A96UP='DH)&%B;V]K*2D@>PH@("`@("`@("`@("!A<G)A>5]U;G-H:69T
M*"1P87)T<RP@)R`G*3L*("`@("`@("!]"@H@("`@("`@("\O(%=A<R!T:&4@
M861D<F5S<R!B;V]K(&YA;64@<75O=&5D/PH@("`@("`@("1N=6U/9E!A<G1S
M(#T@8V]U;G0H)'!A<G1S*3L*("`@("`@("`D;F%M92`]("1P87)T<ULP73L*
M("`@("`@("`D9FER<W1.86UE261X(#T@,3L*("`@("`@("`D9FER<W1#:&%R
M(#T@<W5B<W1R*"1N86UE+"`P+"`Q*3L*("`@("`@("!I9B`H)&9I<G-T0VAA
M<B`]/2)<(B(I('L*("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P@)&YU
M;4]F4&%R=',[("1I*RLI('L*("`@("`@("`@("`@("`@("1L87-T0VAA<B`]
M('-U8G-T<B@D<&%R='-;)&E=+"!S=')L96XH)'!A<G1S6R1I72D@+2`Q+"`Q
M*3L*("`@("`@("`@("`@("`@("1F:7)S=$YA;65)9'@K*SL*("`@("`@("`@
M("`@("`@(&EF("@D;&%S=$-H87(@/3T@(EPB(BD@>PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!.;W<@<W1A<G0@=V]R:VEN9R!O;B!T
M:&4@96YT<GD@;F%M90H@("`@("`@("1N86UE(#T@)'!A<G1S6R1F:7)S=$YA
M;65)9'A=.PH@("`@("`@("1F:7)S=$-H87(@/2!S=6)S='(H)&YA;64L,"PQ
M*3L*"B`@("`@("`@+R\@0VAE8VL@=&\@<V5E(&EF('1H92!F:7)S="!C:&%R
M(&]F('1H92!N86UE('-T<FEN9R!I<R!A(&1O=6)L92!Q=6]T90H@("`@("`@
M("\O('-O('=E(&MN;W<@:68@=V4@:&%V92!T;R!E>'1R86-T(&UO<F4@;V8@
M=&AE(&YA;64N"B`@("`@("`@:68@*"1F:7)S=$-H87(@/3T@(EPB(BD@>PH@
M("`@("`@("`@("`D;F%M92`](&QT<FEM*"1N86UE+"`B7"(B*3L*("`@("`@
M("`@("`@9F]R("@D:2`]("1F:7)S=$YA;65)9'@@*R`Q.R`D:2`\("1N=6U/
M9E!A<G1S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D;F%M92`N/2`@)R`G
M("X@)'!A<G1S6R1I73L*("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U
M8G-T<B@D<&%R='-;)&E=+"!S=')L96XH)'!A<G1S6R1I72D@+2`Q+#$I.PH@
M("`@("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`B7"(B*2!["B`@("`@
M("`@("`@("`@("`@("`@)&YA;64@/2!R=')I;2@D;F%M92P@(EPB(BD["B`@
M("`@("`@("`@("`@("`@("`@)&YE>'1+97D@/2`D:2`K(#$["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R('M]"B`@("`@("`@?2!E;'-E
M:68@*'!R96=?;6%T8V@H)R]<>RA<9"LI7'TO)RP@)&YA;64L("1M871C:&5S
M*2D@>PH@("`@("`@("`@("`D;F%M92`]("1T:&ES+3Y?:6US<"T^<F5C96EV
M95-T<FEN9TQI=&5R86PH)&UA=&-H97-;,5TI.PH@("`@("`@("`@("`D<F5S
M<&]N<V4])'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@
M("`D<&%R=',@/2!E>'!L;V1E*"<@)RP@)')E<W!O;G-E*3L*("`@("`@("`@
M("`@)&YU;4]F4&%R=',@/2!C;W5N="@D<&%R=',I.PH@("`@("`@("`@("`D
M;F5X=$ME>2`](#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M268@;VYL>2!O;F4@8VAU;FL@9F]R("=N86UE)R!T:&5N('=E(&IU<W0@:&%V
M92!T;R!P;VEN=`H@("`@("`@("`@("`O+R!T;R!T:&4@;F5X="!C:'5N:R!I
M;B!T:&4@87)R87DN+BYW:&EC:"!W:6QL(&AO<&5F=6QL>0H@("`@("`@("`@
M("`O+R!B92`G,B<*("`@("`@("`@("`@)&YE>'1+97D@/2`D9FER<W1.86UE
M261X("L@,3L*("`@("`@("!]"@H@("`@("`@("1L87-T0VAA<B`]("<G.PH@
M("`@("`@("1E;G1R>5LG;F%M92==(#T@)&YA;64["@H@("`@("`@("\O(%-T
M87)T('!A<G-I;F<@=&AE(')E<W0@;V8@=&AE(')E<W!O;G-E+@H@("`@("`@
M(&9O<B`H)&D@/2`D;F5X=$ME>3L@)&D@/"`D;G5M3V9087)T<SL@)&D@*ST@
M,BD@>PH@("`@("`@("`@("`D:V5Y(#T@)'!A<G1S6R1I73L*("`@("`@("`@
M("`@+RH@0VAE8VL@9F]R('M]("HO"B`@("`@("`@("`@(&EF("A`<')E9U]M
M871C:"A)35-07T]#5$547T-/54Y4+"`D<&%R='-;)&DK,5TL("1T96UP07)R
M87DI*2!["B`@("`@("`@("`@("`@("`D<V5R=F5R7V1A=&$@/2`D=&AI<RT^
M7VEM<W`M/G)E8V5I=F53=')I;F=,:71E<F%L*"1T96UP07)R87E;,ETI.PH@
M("`@("`@("`@("`@("`@)&5N=')Y6R1K97E=(#T@)'-E<G9E<E]D871A.PH*
M("`@("`@("`@("`@("`@("\J(%)E860@86YY(')E;6%I;FEN9R!D871A(&9R
M;VT@=&AE('-T<F5A;2!A;F0@<F5S970*("`@("`@("`@("`@("`@("`J('1H
M92!C;W5N=&5R('9A<FEA8FQE<R!S;R!T:&4@;&]O<"!W:6QL(&-O;G1I;G5E
M"B`@("`@("`@("`@("`@("`@*B!C;W)R96-T;'DN($YO=&4@=V4@<V5T("1I
M("!T;R`M,B!B96-A=7-E(&ET('=I;&P*("`@("`@("`@("`@("`@("`J(&)E
M(&EN8W)E;65N=&5D(&)Y(#(@8F5F;W)E('1H92!L;V]P('=I;&P@<G5N(&%G
M86EN("HO"B`@("`@("`@("`@("`@("`D<&%R=',@/2`D=&AI<RT^7VEM<W`M
M/F=E=%-E<G9E<E)E<W!O;G-E0VAU;FMS*"D["B`@("`@("`@("`@("`@("`D
M:2`]("TR.PH@("`@("`@("`@("`@("`@)&YU;4]F4&%R=',@/2!C;W5N="@D
M<&%R=',I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M+R\@3F]T(&$@<W1R:6YG(&QI=&5R86P@<F5S<&]N<V4*("`@("`@("`@("`@
M("`@($`D96YT<GE;)&ME>5T@/2`D<&%R='-;)&D@*R`Q73L*("`@("`@("`@
M("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@=&AE('9A;'5E('-T87)T960@
M=VET:"!A(&1O=6)L90H@("`@("`@("`@("`@("`@("\O('%U;W1E+B`@5V4@
M86QS;R!N965D('1O(&-H96-K(&EF('1H92!L87-T(&-H87(@:7,@80H@("`@
M("`@("`@("`@("`@("\O('%U;W1E('1O(&UA:V4@<W5R92!W92!214%,3%D@
M:&%V92!T;R!C:&5C:R!T:&4@;F5X=`H@("`@("`@("`@("`@("`@("\O(&5L
M96UE;G1S(&9O<B!A(&-L;W-I;F<@<75O=&4N"B`@("`@("`@("`@("`@("!I
M9B`H*$!S=6)S='(H)'!A<G1S6R1I("L@,5TL(#`L(#$I(#T]("<B)RD@)B8*
M("`@("`@("`@("`@("`@("`@("`H<W5B<W1R*"1P87)T<ULD:2`K(#%=+`H@
M("`@("`@("`@("`@("`@("`@("!S=')L96XH)'!A<G1S6R1I("L@,5TI("T@
M,2P@,2D@(3T@)R(G*2D@>PH*("`@("`@("`@("`@("`@("`@("!D;R!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1N97AT16QE;65N="`]("1P87)T<ULD
M:2LR73L*"B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=A<R!T:&ES(&5L
M96UE;G0@=&AE(&QA<W0@;VYE/PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;&%S=$-H87(@/2!S=6)S='(H)&YE>'1%;&5M96YT+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1N97AT16QE
M;65N="D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y
M6R1K97E=("X]("<@)R`N("1N97AT16QE;65N=#L*"B`@("`@("`@("`@("`@
M("`@("`@("`@("\O($Y/5RP@=V4@8V%N(&-H96-K('1H92!L87-T0VAA<BX*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`G(B<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D;VYE(#T@=')U93L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!#:&5C:R!T;R!S964@:68@=&AE(&YE>'0@96QE;65N="!I<R!T
M:&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&QA<W0@;VYE+B!)
M9B!S;RP@=&AE(&1O(&QO;W`@=VEL;"!T97)M:6YA=&4N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&]N92`](&9A;'-E.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&QA<W1#:&%R(#T@<W5B<W1R*"1P87)T<ULD:2LS
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')L96XH)'!A<G1S6R1I*S-=*2`M(#$L,2D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?2!W:&EL92`H)&QA<W1#:&%R("$]
M("<B)RD["@H@("`@("`@("`@("`@("`@("`@("\O($1O('=E(&YE960@=&\@
M861D('1H92!F:6YA;"!E;&5M96YT+"!O<B!W97)E"B`@("`@("`@("`@("`@
M("`@("`@+R\@=&AE<F4@;VYL>2!T=V\@=&]T86P_"B`@("`@("`@("`@("`@
M("`@("`@:68@*"$D9&]N92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;F5X=$5L96UE;G0@/2`D<&%R='-;)&DK,ET["B`@("`@("`@("`@("`@("`@
M("`@("`@("1E;G1R>5LD:V5Y72`N/2`G("<@+B`D;F5X=$5L96UE;G0["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("`@("`O+R!296UO=F4@=&AE('%U;W1E
M<R!S96YT(&)A8VL@=&\@=7,@9G)O;2!T:&4@<V5R=F5R+@H@("`@("`@("`@
M("`@("`@("`@(&EF("AS=6)S='(H)&5N=')Y6R1K97E=+"`P+"`Q*2`]/2`G
M(B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R1K97E=(#T@
M<W5B<W1R*"1E;G1R>5LD:V5Y72P@,2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-T<FQE;B@D96YT<GE;)&ME>5TI
M("T@,BD["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1E;G1R>5LD:V5Y72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-T<FQE;B@D96YT<GE;)&ME>5TI("T@,2P@,2D@
M/3T@)R(G*2!["@H@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE;)&ME
M>5T@/2!S=6)S='(H)&5N=')Y6R1K97E=+"`P+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1E;G1R>5LD
M:V5Y72D@+2`R*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1E;G1R>3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O
M3W!T:6]N<RYP:'``````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$U-38R`#$P-#$W,S8R-S<U`#`R,#8T-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=.
M970O24U34"]!=71H+G!H<"<["@HO*BH*("H@3F5T7TE-4U!?3W!T:6]N<R!#
M;&%S<R`M('!R;W9I9&5S(&%N(&EN=&5R9F%C92!T;R!)35-0('-E<G9E<BUB
M87-E9`H@*B!O<'1I;VYS('-T;W)A9V4N"B`J"B`J(%)E<75I<F5D('!A<F%M
M971E<G,Z/'!R93X*("H@("`G=7-E<FYA;64G("`@("!5<V5R;F%M92!T;R!L
M;V=O;B!T;R!)35-0('-E<G9E<B!A<RX*("H@("`G<&%S<W=O<F0G("`@("!0
M87-S=V]R9"!F;W(@8W5R<F5N="!U<V5R+@H@*B`@("=A=71H7VUE=&AO9"<@
M(%1H92!A=71H96YT:6-A=&EO;B!M971H;V0@=&\@=7-E('1O(&QO9VEN+@H@
M*B`@("=S97)V97(G("`@("`@(%1H92!H;W-T;F%M92!O9B!T:&4@24U34"!S
M97)V97(N"B`J("`@)W!O<G0G("`@("`@("`@5&AE('!O<G0@;V8@=&AE($E-
M4U`@<V5R=F5R+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?
M24U34"])35-0+T]P=&EO;G,N<&AP+'8@,2XS+C(N,38@,C`P-B\P,2\P,2`R
M,3HR.#HR."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-
M:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS
M:T!H;W)D92YO<F<^"B`J($!P86-K86=E($YE=%])35-0"B`J+PIC;&%S<R!.
M971?24U34%]/<'1I;VYS('L*"B`@("`O*BH*("`@("`J($YE=%])35-0(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`=F%R($YE=%])35-0"B`@("`@*B\*("`@
M('9A<B`D7VEM<W`["@H@("`@+RHJ"B`@("`@*B!087)A;65T97(@;&ES="X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A
M<F%M<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R(&9U;F-T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!(87-H(&-O;G1A
M:6YI;F<@24U34"!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!.
M971?24U34%]/<'1I;VYS*"1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI
M=&EA;&EZ871I;VX@9G5N8W1I;VX@=&\@8F4@8V%L;&5D(&%F=&5R(&]B:F5C
M="!I<R!R971U<FYE9"X*("`@("`J(%1H:7,@86QL;W=S(&5R<F]R<R!T;R!O
M8V-U<B!A;F0@;F]T(&)R96%K('1H92!S8W)I<'0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(%!%05)?17)R;W(@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VEM<W`I*2!["B`@("`@("`@("`@
M("1A=71H(#T@)DYE=%])35-07T%U=&@Z.G-I;F=L971O;B@D=&AI<RT^7W!A
M<F%M<ULG875T:%]M971H;V0G72D["B`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"`]("1A=71H+3YA=71H96YT:6-A=&4H)'1H:7,M/E]P87)A;7,I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]I;7-P+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G3F5T
M7TE-4U!?3W!T:6]N<R!I;FET:6%L:7IE9"XG+"!?7T9)3$5?7RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($9U;F-T:6]N('-E;F1S(&$@1T54(&-O;6UA;F0@=&\@24U34"!S
M97)V97(@86YD(')E=')I979E<R!V86QU97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M("!S=')I;F<@)&]P=&EO;DYA;64@3F%M92!O9B!O<'1I;VX@=&\@<F5T
M<FEE=F4N($%C8V5P=',@)RHG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<R!W:6QD(&-A<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@07-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!O<'1I;VX]/G9A
M;'5E('!A:7)S(&]R"B`@("`@*B`@("`@("`@("`@("`@("!014%27T5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)&]P=&EO;DYA;64I"B`@("![
M"B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@I.PH@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*")'150@)&]P=&EO;DYA;64B+"!T
M<G5E+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^
M:6US<%)E8V5I=F4H*3L*("`@("`@("!I9B`H:7-?82@D<V5R=F5R7W)E<W!O
M;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<V5R
M=F5R7W)E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*'!R96=?
M;6%T8V@H(B]>7"H@3U!424].+R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@
M("`@("`@("`@("\J($9I<G-T+"!C:&5C:R!F;W(@82![?2X@*B\*("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H24U34%]/0U1%5%]#3U5.5"P@)'-E<G9E
M<E]R97-P;VYS92P@)'1E;7!!<G)A>2DI('L*("`@("`@("`@("`@("`@("1T
M96UP(#T@97AP;&]D92@G("<L("1S97)V97)?<F5S<&]N<V4I.PH@("`@("`@
M("`@("`@("`@)&]P=&EO;G-;)'1E;7!;,EU=(#T@)'1H:7,M/E]I;7-P+3YR
M96-E:79E4W1R:6YG3&ET97)A;"@D=&5M<$%R<F%Y6S)=*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T96UP(#T@97AP;&]D92@G
M("<L("1S97)V97)?<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@)&]P=&EO
M;G-;)'1E;7!;,EU=(#T@=')I;2@D=&5M<%LS72D["B`@("`@("`@("`@("`@
M("`D:2`](#,["B`@("`@("`@("`@("`@("`D;&%S=$-H87(@/2`B(CL*("`@
M("`@("`@("`@("`@("1N97AT16QE;65N="`]('1R:6TH)'1E;7!;,UTI.PH*
M("`@("`@("`@("`@("`@("\J(%=A<R!T:&4@=F%L=64@<75O=&5D(&%N9"!S
M<&%C960_("HO"B`@("`@("`@("`@("`@("!I9B`H*'-U8G-T<B@D;F5X=$5L
M96UE;G0L,"PQ*2`]/2`G(B<I("8F"B`@("`@("`@("`@("`@("`@("`@*'-U
M8G-T<B@D;F5X=$5L96UE;G0L<W1R;&5N*"1N97AT16QE;65N="D@+2`Q+"`Q
M*2`A/2`G(B<I*2!["B`@("`@("`@("`@("`@("`@("`@9&\@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;F5X=$5L96UE;G0@/2`D=&5M<%LD:2LQ73L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&QA<W1#:&%R(#T@<W5B<W1R*"1N
M97AT16QE;65N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T<FQE;B@D;F5X=$5L96UE;G0I("T@,2P@,2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1O<'1I;VYS6R1T96UP6S)=72`N/2`G("<@
M+B`D;F5X=$5L96UE;G0["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M;&%S=$-H87(@/3T@)R(G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&]N92`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&]N92`](&9A;'-E
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QA<W1#:&%R(#T@<W5B
M<W1R*"1T96UP6R1I*S)=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<FQE;B@D=&5M<%LD:2LR72D@+2`Q+"`Q
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@?2!W:&EL
M92`H)&QA<W1#:&%R("$]("<B)RD["@H@("`@("`@("`@("`@("`@("`@(&EF
M("@A)&1O;F4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE>'1%;&5M
M96YT(#T@)'1E;7!;)&DK,5T["B`@("`@("`@("`@("`@("`@("`@("`@("1O
M<'1I;VYS6R1T96UP6S)=72`N/2`G("<@+B`D;F5X=$5L96UE;G0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM
M<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1S97)V
M97)?<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'-E<G9E<E]R97-P;VYS92`A/2`G3TLG*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G
M1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H
M92!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H)T=%5"!C;VUM86YD($]+
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@(')E='5R;B`D;W!T:6]N<SL*("`@('T*"B`@("`O*BH*("`@("`J($9U
M;F-T:6]N('-E=',@86X@;W!T:6]N('9A;'5E(&]N('1H92!)35-0('-E<G9E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VY.86UE("!.
M86UE(&]F(&]P=&EO;B!T;R!S970N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O
M<'1I;VY686QU92!686QU92!T;R!A<W-I9VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!4<G5E(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E="@D;W!T:6]N3F%M92P@)&]P=&EO;E9A;'5E*0H@("`@>PH@
M("`@("`@("\J(%-E;F0@=&AE(&)E9VEN;FEN9R!O9B!T:&4@8V]M;6%N9"X@
M*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B
M4T54("1O<'1I;VY.86UE("(L('1R=64L(&9A;'-E*3L*"B`@("`@("`@+RH@
M4V5N9"`D;W!T:6]N5F%L=64@87,@82!L:71E<F%L('M]/R`J+PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&]P=&EO
M;E9A;'5E*2D@>PH@("`@("`@("`@("`D8FE686QU92`]('-P<FEN=&8H(GLE
M9'TB+"!S=')L96XH)&]P=&EO;E9A;'5E*2D["B`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:59A;'5E+"!F86QS92P@
M=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D
M(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V
M97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!.;W<@<V5N9"!T:&4@<F5S="!O9B!T:&4@
M8V]M;6%N9"X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D;W!T:6]N5F%L=64L(&9A;'-E+"!T<G5E*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R
M97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@
M("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*("`@("`@
M("!](&5L<V5I9B`H)'-E<G9E<E]R97-P;VYS92`A/2`G3TLG*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE(&]P
M=&EO;B!C;W5L9"!N;W0@8F4@<V5T(&]N('1H92!)35-0('-E<G9E<BXG+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]I;7-P+3YW<FET951O3&]G*"=3150@8V]M;6%N9"!/2RXG+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&QO9R!I;F9O
M<FUA=&EO;B!I;B!T:&4@3F5T7TE-4U`@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@;&]G('!A<F%M971E<G,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M3&]G9V5R*"1P87)A;7,I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?:6US<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M<V5T3&]G9V5R*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@
M;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XG*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@;&]G;W5T*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7VEM<W`M/FQO9V]U="@I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O571I;',N<&AP````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-C$Q`#$P-#$W,S8R
M-S<U`#`R,#,P,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@3F5T7TE-4U!?571I;',Z.@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R].971?24U34"])35-0+U5T:6QS+G!H<"QV(#$N
M,RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E
M;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.
M971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?571I;',@>PH*("`@("\J*@H@
M("`@("H@571I;&ET>2!F=6YC=&EO;B!T;R!R971R:65V92!T:&4@;F%M97,@
M;V8@86QL('1H92!A9&1R97-S(&)O;VMS"B`@("`@*B!T:&%T('1H92!U<V5R
M(&AA<R!A8V-E<W,@=&\L(&%L;VYG('=I=&@@=&AE(&%C;"!F;W(@=&AO<V4*
M("`@("`J(&)O;VMS+B`@1F]R(&EN9F]R;6%T:6]N(&%B;W5T('1H92`D<V5R
M=F5R26YF;R!A<G)A>2!S964*("`@("`J('1U<F)A+V-O;F9I9R]S;W5R8V5S
M+G!H<"!A<R!T:&ES(&ES('1H92!C9F=3;W5R8V5S6UT@96YT<GD@9F]R"B`@
M("`@*B!T:&4@861D<F5S<R!B;V]K<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'-E<G9E<DEN9F\@($EN9F]R;6%T:6]N(&%B;W5T('1H92!S97)V
M97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@86YD('1H92!C
M=7)R96YT('5S97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@26YF
M;W)M871I;VX@86)O=70@86QL('1H92!A9&1R97-S(&)O;VMS(&]R(%!%05)?
M17)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%L;$)O;VMS*"1S97)V
M97));F9O*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G3F5T+TE-4U`N
M<&AP)SL*("`@("`@("`D9F]U;F1$969A=6QT(#T@9F%L<V4["B`@("`@("`@
M)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@("1I;7-P(#T@)DYE=%])35-0
M.CIS:6YG;&5T;VXH)T)O;VLG+"`D<V5R=F5R26YF;ULG<&%R86US)UTI.PH@
M("`@("`@("1R97-U;'0@/2`D:6US<"T^:6YI="@I.PH*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)&)O;VMS(#T@)&EM
M<W`M/F=E=$%D9')E<W-";V]K3&ES="@I.PH@("`@("`@(&EF("AI<U]A*"1B
M;V]K<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&)O
M;VMS.PH@("`@("`@('T*"B`@("`@("`@)&)#;W5N="`](&-O=6YT*"1B;V]K
M<RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)#;W5N=#L@)&DK*RD@
M>PH@("`@("`@("`@("`D;F5W0F]O:R`]("1S97)V97));F9O.PH@("`@("`@
M("`@("!I9B`H)&)O;VMS6R1I72`A/2`D<V5R=F5R26YF;ULG<&%R86US)UU;
M)W5S97)N86UE)UTI('L*("`@("`@("`@("`@("`@("1N97=";V]K6R=T:71L
M92==(#T@)TE-4U!?)R`N("1B;V]K<ULD:5T["B`@("`@("`@("`@("`@("`D
M;F5W0F]O:ULG<&%R86US)UU;)VYA;64G72`]("1B;V]K<ULD:5T["B`@("`@
M("`@("`@("`@("`D;F5W0F]O:ULG<&%R86US)UU;)VES7W)O;W0G72`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@)&YE=T)O;VM;)W!A<F%M<R==6R=M>5]R
M:6=H=',G72`]("1I;7-P+3YM>5)I9VAT<R@D8F]O:W-;)&E=*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F;W5N9$1E9F%U;'0@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@)&YE=T)O;VM;)W!A<F%M<R==6R=M
M>5]R:6=H=',G72`]("1I;7-P+3YM>5)I9VAT<R@D8F]O:W-;)&E=*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT<UM=(#T@)&YE=T)O;VL[
M"B`@("`@("`@?0H@("`@("`@("\J($EF('1H97)E(&ES(&YO(&1E9F%U;'0@
M861D<F5S<R!B;V]K("AN86UE9"!U<V5R;F%M92D@=&AE;B!W92!S:&]U;&0@
M8W)E871E(&]N92X@*B\*("`@("`@("!I9B`H(21F;W5N9$1E9F%U;'0I('L*
M("`@("`@("`@("`@)')E<W5L="`]("1I;7-P+3YC<F5A=&5!9&1R97-S0F]O
M:R@D<V5R=F5R26YF;ULG<&%R86US)UU;)W5S97)N86UE)UTI.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3&]G:6X@=&\@
M24U34"!H;W-T(&9A:6QE9"XG("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<Z($1E9F%U;'0@861D<F5S<R!B;V]K(&ES(&UI
M<W-I;F<@86YD(&-O=6QD(&YO="!B92!C<F5A=&5D+B<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%5T:6QI='D@9G5N8W1I;VX@=&\@;6%K92!I="!E
M87-I97(@9F]R(&-L:65N="!A<'!L:6-A=&EO;G,@=&\@9&5L971E"B`@("`@
M*B!A9&1R97-S(&)O;VMS('=I=&AO=70@:&%V:6YG('1O(&-R96%T92!I;7-P
M(&1R:79E<G,N("!4:&4@)'-O=7)C92!A<G)A>0H@("`@("H@:7,@82!H;W)D
M92]T=7)B82!S='EL92`D8V9G4V]U<F-E<R!E;G1R>2!F;W(@=&AE(&%D9')E
M<W,@8F]O:R!B96EN9PH@("`@("H@9&5L971E9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'-O=7)C92`@26YF;W)M871I;VX@86)O=70@=&AE(&%D
M9')E<W,@8F]O:R!B96EN9R!D96QE=&5D+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T94)O;VLH)'-O=7)C
M92D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TYE="])35-0+G!H<"<[
M"B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O;B@G0F]O:R<L
M("1S;W5R8V5;)W!A<F%M<R==*3L*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M
M/FEN:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/F1E;&5T94%D9')E<W-";V]K*"1S
M;W5R8V5;)W!A<F%M<R==6R=N86UE)UTI.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@571I;&ET>2!F=6YC=&EO;B!T;R!H96QP(&-L:65N
M=',@8W)E871E(&YE=R!A9&1R97-S(&)O;VMS('=I=&AO=70@:&%V:6YG"B`@
M("`@*B!T;R!C<F5A=&4@86X@:6US<"!D<FEV97(@:6YS=&%N8V4@9FER<W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W5R8V4@("`@26YF;W)M
M871I;VX@86)O=70@=&AE('5S97(G<R!D969A=6QT($E-4U`*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&%D9')E<W,@8F]O:RX*("`@("`J($!P
M87)A;2!S=')I;F<@)&YE=TYA;64@(%1H92!N86UE(&]F('1H92!N97<@861D
M<F5S<R!B;V]K+B`@3F]T92!T:&%T('1H:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&ES(&%U=&]M871I8V%L;'D@<75A;&EF:65D('=I=&@@
M=&AE('5S97(G<R!N86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!S;R!S:&]U;&0@;F]T(&)E('!A<W-E9"!A<R!A(&9U;&QY('%U86QI9FEE
M9"!)35-0"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1R97-S
M(&)O;VL@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!T<G5E
M(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("`@9G5N8W1I;VX@8W)E871E0F]O:R@D<V]U<F-E+"`D;F5W3F%M92D*
M("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TYE="])35-0+G!H<"<["B`@
M("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O;B@G0F]O:R<L("1S
M;W5R8V5;)W!A<F%M<R==*3L*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/FEN
M:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@
M("`@("`D;F%M92`]("1S;W5R8V5;)W!A<F%M<R==6R=U<V5R;F%M92==("X@
M)RXG("X@)&YE=TYA;64["B`@("`@("`@)')E<W5L="`]("1I;7-P+3YC<F5A
M=&5!9&1R97-S0F]O:R@D;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B].970O4TU3+P``````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S4`,#$V,S8V
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<```````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,3$R-@`Q
M,#0Q-S,V,C<W-0`P,C(R-#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($YE=%]335-?8VQI8VMA=&5L
M;%]H='1P($-L87-S(&EM<&QE;65N=',@=&AE($A45%`@05!)(&9O<B!A8V-E
M<W-I;F<@=&AE"B`J($-L:6-K871E;&P@*'=W=RYC;&EC:V%T96QL+F-O;2D@
M4TU3(&=A=&5W87DN"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@
M1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`L=B`Q+C$S+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HR.2!J86X@17AP("0*
M("H*("H@0&%U=&AO<B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@
M*B!`<&%C:V%G92!.971?4TU3"B`J+PIC;&%S<R!.971?4TU37V-L:6-K871E
M;&Q?:'1T<"!E>'1E;F1S($YE=%]335,@>PH*("`@('9A<B`D7W-E<W-I;VY?
M:60@/2!N=6QL.PH@("`@=F%R("1?8F%S95]U<FP@/2`G:'1T<#HO+V%P:2YC
M;&EC:V%T96QL+F-O;2]H='1P+R<["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A
M>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P
M;W)T('=H:6-H(&]P97)A=&EO;G,*("`@("`J(&ET('-U<'!O<G1S(&%N9"!W
M:&EC:"!I="!D;V5S;B=T+B!0;W-S:6)L92!V86QU97,@87)E.CQP<F4^"B`@
M("`@*B`@(&%U=&@@("`@("`@("T@5&AE(&=A=&5W87D@<F5Q=6ER92!A=71H
M96YT:6-A=&EO;B!B969O<F4@<V5N9&EN9SL*("`@("`J("`@8F%T8V@@("`@
M("`@+2!"871C:"!S96YD:6YG(&ES('-U<'!O<G1E9#L*("`@("`J("`@;75L
M=&D@("`@("`@+2!396YD:6YG(&]F(&UE<W-A9V5S('1O(&UU;'1I<&QE(')E
M8VEP:65N=',@:7,@<W5P<&]R=&5D.PH@("`@("H@("!R96-E:79E("`@("`M
M(%=H971H97(@=&AI<R!D<FEV97(@:7,@8V%P86)L92!O9B!R96-E:79I;F<@
M4TU3.PH@("`@("H@("!C<F5D:70@("`@("`M($ES('5S92!O9B!T:&4@9V%T
M97=A>2!B87-E9"!O;B!C<F5D:71S.PH@("`@("H@("!A9&1R97-S8F]O:R`M
M($%R92!G871E=V%Y(&%D9')E<W-B;V]K<R!S=7!P;W)T960["B`@("`@*B`@
M(&QI<W1S("`@("`@("T@1V%T97=A>2!S=7!P;W)T(&9O<B!D:7-T<FEB=71I
M;VX@;&ES=',N"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%U
M=&@G("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8F%T8V@G("`@("`@(#T^(#$P,"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VUU;'1I)R`@("`@("`]/B!T<G5E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5C96EV92<@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8W)E9&ET)R`@("`@(#T^
M('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A9&1R97-S
M8F]O:R<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=L:7-T<R<@("`@("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@075T
M:&5N=&EC871E(&%T('1H92!G871E=V%Y(&%N9"!S970@82!S97-S:6]N(&ED
M(&EF('-U8V-E<W-F=6PN($-A8VAI;F<*("`@("`J(&ES('5S960@=&\@;6EN
M:6UI<V4@=&AE(&AT='`@8V%L;',@9F]R('-U8G-E<75E;G0@;65S<V%G97,N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T
M92@I"B`@("!["B`@("`@("`@+RH@5V4@:&%V92!A;')E861Y(&%U=&AE;G1I
M8V%T960@<V\@<F5T=7)N('1R=64N("HO"B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W-E<W-I;VY?:60I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T('5P('1H92!H='1P(&%U=&AE
M;G1I8V%T:6]N('5R;"X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G875T
M:#]U<V5R/25S)G!A<W-W;W)D/25S)F%P:5]I9#TE<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)V%P:5]I9"==*3L*"B`@("`@("`@+RH@1&\@=&AE($A4
M5%`@875T:&5N=&EC871I;VX@86YD(&=E="!T:&4@<F5S<&]N<V4N("HO"B`@
M("`@("`@)')E<W!O;G-E(#T@3F5T7U--4U]C;&EC:V%T96QL7VAT='`Z.E]C
M86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B*2P@
M)')E<W!O;G-E+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@
M("\J(%-P;&ET('5P('1H92!R97-P;VYS92X@*B\*("`@("`@("`D<F5S<&]N
M<V4@/2!E>'!L;V1E*"<Z)RP@)')E<W!O;G-E*3L*("`@("`@("!I9B`H)')E
M<W!O;G-E6S!=(#T]("=/2R<I('L*("`@("`@("`@("`@)'1H:7,M/E]S97-S
M:6]N7VED(#T@=')I;2@D<F5S<&]N<V5;,5TI.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F=E=$5R<F]R*"1R97-P;VYS95LQ72P@7R@B075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<R(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!4:&ES(&9U;F-T:6]N(&1O97,@=&AE(&%C='5A;"!S96YD:6YG(&]F
M('1H92!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@5&AE(&%R<F%Y
M(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@86YD(&ET<R!S96YD"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T;R`@("`@(%1H92!D97-T:6YA=&EO;B!S=')I;F<N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@=VET:"!T:&4@
M<W5C8V5S<R!S=&%T=7,@86YD(&%D9&ET:6]N86P*("`@("`J("`@("`@("`@
M("`@("`@(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5N
M9"@F)&UE<W-A9V4L("1T;RD*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE
M(&AT='`@<V5N9&EN9R!U<FPN("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H
M)W-E;F1M<V<_<V5S<VEO;E]I9#TE<R9T97AT/25S)RP*("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E<W-I;VY?:60L"B`@("`@("`@("`@("`@
M("`@("`@("`@=7)L96YC;V1E*"1M97-S86=E6R=T97AT)UTI*3L*"B`@("`@
M("`@)')E<5]F96%T(#T@,#L*("`@("`@("!I9B`H(65M<'1Y*"1M97-S86=E
M6R=S96YD7W!A<F%M<R==6R=F<F]M)UTI*2!["B`@("`@("`@("`@("\J($EF
M('-O=7)C92!F<F]M(&ES('-E="P@<F5Q=6ER92!I="!F;W(@=')A;G-I="!G
M871E=V%Y<R!A;F0@87!P96YD"B`@("`@("`@("`@("`@('1O('5R;"X@*B\*
M("`@("`@("`@("`@)')E<5]F96%T(#TK(#$V.PH@("`@("`@("`@("`D=7)L
M("X]("<F9G)O;3TG("X@=7)L96YC;V1E*"1M97-S86=E6R=S96YD7W!A<F%M
M<R==6R=F<F]M)UTI.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1M
M97-S86=E6R=S96YD7W!A<F%M<R==6R=M<V=?='EP92==*2`F)@H@("`@("`@
M("`@("`D;65S<V%G95LG<V5N9%]P87)A;7,G75LG;7-G7W1Y<&4G72`]/2`G
M4TU37T9,05-()RD@>PH@("`@("`@("`@("`O*B!)9B!M97-S86=E('1Y<&4@
M:7,@9FQA<V@L(')E<75I<F4@:70@9F]R('1R86YS:70@9V%T97=A>7,N("HO
M"B`@("`@("`@("`@("1R97%?9F5A="`]*R`U,3(["B`@("`@("`@("`@("1U
M<FP@+CT@)R9M<V=?='EP93TG("X@)&UE<W-A9V5;)W-E;F1?<&%R86US)UU;
M)VUS9U]T>7!E)UT["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)')E
M<5]F96%T*2D@>PH@("`@("`@("`@("`O*B!)9B!F96%T=7)E<R!H879E(&)E
M96X@<F5Q=6ER960L(&%D9"!T;R!U<FPN("HO"B`@("`@("`@("`@("1U<FP@
M+CT@)R9R97%?9F5A=#TG("X@)')E<5]F96%T.PH@("`@("`@('T*"B`@("`@
M("`@+RH@07!P96YD('1H92!R96-I<&EE;G1S(&]F('1H:7,@;65S<V%G92!A
M;F0@8V%L;"!T:&4@=7)L+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T;R!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>
M+BH_/#]<*S\H7&1[-RQ]*2@^?"0I+R<L("1V86PL("1M871C:&5S*2D@>PH@
M("`@("`@("`@("`@("`@)'1O6R1K97E=(#T@)&UA=&-H97-;,5T["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!&25A-13H@4VEL
M96YT;'D@9')O<"!B860@<F5C:7!I96YT<RX@5&AI<R!S:&]U;&0@8F4@;&]G
M9V5D"B`@("`@("`@("`@("`@("`@*B!A;F0O;W(@<F5P;W)T960N("HO"B`@
M("`@("`@("`@("`@("!U;G-E="@D=&];)&ME>5TI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@("1T;R`](&EM<&QO9&4H)RPG+"`D=&\I.PH@
M("`@("`@("1U<FP@+CT@)R9T;STG("X@)'1O.PH@("`@("`@("1R97-P;VYS
M92`]('1R:6TH)'1H:7,M/E]C86QL55),*"1U<FPI*3L*"B`@("`@("`@+RH@
M56=L>2!P87)S:6YG(&]F('1H92!R97-P;VYS92P@8G5T('1H870G<R!H;W<@
M:70@8V]M97,@8F%C:RX@*B\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<
M;B(L("1R97-P;VYS92D["B`@("`@("`@)')E<W!O;G-E(#T@87)R87DH*3L*
M"B`@("`@("`@:68@*&-O=6YT*"1L:6YE<RD@/B`Q*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@
M)'!A<G1S(#T@97AP;&]D92@G5&\Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@
M("`@)')E8VEP:65N="`]('1R:6TH)'!A<G1S6S%=*3L*("`@("`@("`@("`@
M("`@("1O=71C;VUE(#T@97AP;&]D92@G.B<L("1P87)T<ULP72D["B`@("`@
M("`@("`@("`@("`D<F5S<&]N<V5;)')E8VEP:65N=%T@/2!A<G)A>2@H)&]U
M=&-O;65;,%T@/3T@)TE$)R`_(#$@.B`P*2P@)&]U=&-O;65;,5TI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@4VEN
M9VQE(')E8VEP:65N="X@*B\*("`@("`@("`@("`@)&]U=&-O;64@/2!E>'!L
M;V1E*"<Z)RP@)&QI;F5S6S!=*3L*("`@("`@("`@("`@)')E<W!O;G-E6R1T
M;UT@/2!A<G)A>2@H)&]U=&-O;65;,%T@/3T@)TE$)R`_(#$@.B`P*2P@)&]U
M=&-O;65;,5TI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-P;VYS
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@
M8W)E9&ET(&)A;&%N8V4@;VX@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R
M("!4:&4@8W)E9&ET(&)A;&%N8V4@879A:6QA8FQE(&]N('1H92!G871E=V%Y
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T0F%L86YC92@I"B`@("!["B`@
M("`@("`@+RH@4V5T('5P('1H92!U<FP@86YD(&-A;&P@:70N("HO"B`@("`@
M("`@)'5R;"`]('-P<FEN=&8H)V=E=&)A;&%N8V4_<V5S<VEO;E]I9#TE<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S97-S:6]N7VED*3L*
M("`@("`@("`D<F5S<&]N<V4@/2!T<FEM*"1T:&ES+3Y?8V%L;%523"@D=7)L
M*2D["@H@("`@("`@("\J(%1R>2!S<&QI='1I;F<@=7`@=&AE(')E<W!O;G-E
M+B`J+PH@("`@("`@("1L:6YE<R`](&5X<&QO9&4H)STG+"`D<F5S<&]N<V4I
M.PH*("`@("`@("`O*B!3<&QI="!U<"!T:&4@<F5S<&]N<V4N("HO"B`@("`@
M("`@)')E<W!O;G-E(#T@97AP;&]D92@G.B<L("1R97-P;VYS92D["B`@("`@
M("`@:68@*"1R97-P;VYS95LP72`]/2`G0W)E9&ET)RD@>PH@("`@("`@("`@
M("!R971U<FX@=')I;2@D<F5S<&]N<V5;,5TI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E
M6S%=+"!?*")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B*2D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@261E;G1I9FEE<R!T:&ES(&=A
M=&5W87D@9')I=F5R(&%N9"!R971U<FYS(&$@8G)I968@9&5S8W)I<'1I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@9')I=F5R
M(&EN9F\N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN9F\H*0H@("`@>PH@
M("`@("`@("1I;F9O6R=N86UE)UT@/2!?*")#;&EC:V%T96QL('9I82!(5%10
M(BD["B`@("`@("`@)&EN9F];)V1E<V,G72`](%\H(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(BD["@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M971E<G,@
M9F]R('1H:7,@9V%T97=A>2!D<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@07)R87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&%R86US*"D*("`@('L*("`@("`@("`D<&%R
M86US(#T@87)R87DH*3L*("`@("`@("`D<&%R86US6R=U<V5R)UT@("`@(#T@
M87)R87DH)VQA8F5L)R`]/B!?*")5<V5R;F%M92(I+"`G='EP92<@/3X@)W1E
M>'0G*3L*("`@("`@("`D<&%R86US6R=P87-S=V]R9"==(#T@87)R87DH)VQA
M8F5L)R`]/B!?*")087-S=V]R9"(I+"`G='EP92<@/3X@)W1E>'0G*3L*("`@
M("`@("`D<&%R86US6R=A<&E?:60G72`@(#T@87)R87DH)VQA8F5L)R`]/B!?
M*")!4$D@240B*2P@)W1Y<&4G(#T^("=T97AT)RD["@H@("`@("`@(')E='5R
M;B`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<&%R86UE=&5R<R!T:&%T(&-A;B!B92!S970@87,@9&5F875L="!F;W(@<V5N
M9&EN9R!M97-S86=E<PH@("`@("H@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E
M<B!A;F0@9&ES<&QA>65D('=H96X@<V5N9&EN9R!M97-S86=E<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!P87)A;65T97)S('1H
M870@8V%N(&)E('-E="!A<R!D969A=6QT+@H@("`@("H@0'1O9&\@(%-E="!U
M<"!B871C:"!F:65L9',O<&%R86US+"!W;W5L9"!B92!N:6-E('1O(&AA=F4@
M<FEN9W1O;F4O;&]G;PH@("`@("H@("`@("`@('-U<'!O<G0@=&]O+"!Q=65U
M92!C:&]I8V4L('5N:6-O9&4@8VAO:6-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$969A=6QT4V5N9%!A<F%M<R@I"B`@("!["B`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"D["B`@("`@("`@)'!A<F%M<ULG9G)O;2==(#T@87)R87DH
M"B`@("`@("`@("`@("=L86)E;"<@/3X@7R@B4V]U<F-E(&%D9')E<W,B*2P*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RD["@H@("`@("`@("1P87)A
M;7-;)V1E;&EV7W1I;64G72`](&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG
M(#T^(%\H(D1E;&EV97)Y('1I;64B*2P*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=E;G5M)RP*("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH87)R87DH
M)VYO=R<@/3X@7R@B:6UM961I871E(BDL("=U<V5R)R`]/B!?*")U<V5R('-E
M;&5C="(I*2DI.PH*("`@("`@("`D='EP97,@/2!A<G)A>2@G4TU37U1%6%0G
M(#T^("=335-?5$585"<L("=335-?1DQ!4T@G(#T^("=335-?1DQ!4T@G*3L*
M("`@("`@("`D<&%R86US6R=M<V=?='EP92==(#T@87)R87DH"B`@("`@("`@
M("`@("=L86)E;"<@/3X@7R@B365S<V%G92!T>7!E(BDL"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G;75L=&EE;G5M)RP*("`@("`@("`@("`@)W!A<F%M<R<@
M/3X@87)R87DH)'1Y<&5S*2D["@H@("`@("`@(')E='5R;B`D<&%R86US.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!F
M;W(@<V5N9&EN9R!M97-S86=E<R!U<VEN9R!T:&ES(&=A=&5W87D@9')I=F5R
M+`H@("`@("H@9&ES<&QA>65D('=H96X@<V5N9&EN9R!M97-S86=E<RX@5&AE
M<V4@87)E(&9I;'1E<F5D(&]U="!U<VEN9R!T:&4*("`@("`J(&1E9F%U;'0@
M=F%L=65S('-E="!F;W(@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@07)R87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@
M("`J($!T;V1O("!7;W5L9"!B92!N:6-E('1O('5S92!A('1I;64O9&%T92!S
M971U<"!R871H97(@=&AA;B!M:6YU=&5S(&9R;VT*("`@("`J("`@("`@("!N
M;W<@9F]R('1H92!D96QI=F5R>2!T:6UE+B!5<&QO860@9FEE;&0@9F]R(')I
M;F=T;VYE<R]L;V=O<S\*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5N9%!A
M<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US
M6R=F<F]M)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)V9R;VTG72`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")3;W5R8V4@861D
M<F5S<R(I+`H@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RD["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'!A<F%M<ULG9&5L:79?=&EM92==(#T]
M("=U<V5R)RD@>PH@("`@("`@("`@("`D<&%R86US6R=D96QI=E]T:6UE)UT@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@("=L86)E;"<@/3X@7R@B1&5L:79E
M<GD@=&EM92(I+`H@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@
M("`@("`@("`@("`@("`@)V1E<V,G(#T^(%\H(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&-O=6YT*"1P
M87)A;7-;)VUS9U]T>7!E)UTI(#X@,2D@>PH@("`@("`@("`@("`D<&%R86US
M6R=M<V=?='EP92==(#T@87)R87DH"B`@("`@("`@("`@("`@("`G;&%B96PG
M(#T^(%\H(DUE<W-A9V4@='EP92(I+`H@("`@("`@("`@("`@("`@)W1Y<&4G
M(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y
M*"1P87)A;7-;)VUS9U]T>7!E)UTI*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<&%R86US6R=M<V=?='EP92==(#T@)'!A<F%M<ULG;7-G7W1Y
M<&4G75LP73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%R86US.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!R97!R97-E
M;G1A=&EO;B!O9B!A;B!E<G)O<B!C;V1E+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1E<G)O<B`@5&AE(&5R<F]R(&-O9&4@=&\@;&]O:R!U<"X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@06X@97AI<W1I;F<@97)R
M;W(@=&5X="!T;R!U<V4@=&\@<F%I<V4@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!014%2($5R<F]R+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@($$@=&5X='5A;"!M97-S86=E(&-O<G)E<W!O;F1I;F<@=&\@=&AE
M(&5R<F]R(&-O9&4@;W(@80H@("`@("H@("`@("`@("`@("`@("`@4$5!4B!%
M<G)O<B!I9B!P87-S960@86X@97AI<W1I;F<@97)R;W(@=&5X="X*("`@("`J
M"B`@("`@*B!`=&]D;R`@0VAE8VL@=VAI8V@@;V8@=&AE<V4@87)E(&%C='5A
M;&QY(')E<75I<F5D(&%N9"!T<FEM(&1O=VX@=&AE"B`@("`@*B`@("`@("`@
M;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T17)R;W(H)&5R<F]R+"`D
M97)R;W)?=&5X="`]("<G*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W
M92!G970@;VYL>2!T:&4@;G5M8F5R(&%T('1H92!S=&%R="!O9B!A;B!E<G)O
M<BX@*B\*("`@("`@("!L:7-T*"1E<G)O<BD@/2!E>'!L;V1E*"<L)RP@)&5R
M<F]R*3L*("`@("`@("`D97)R;W(@/2!T<FEM*"1E<G)O<BD["@H@("`@("`@
M("\J($%N(&%R<F%Y(&]F(&5R<F]R(&-O9&5S(')E='5R;F5D(&)Y('1H92!G
M871E=V%Y+B`J+PH@("`@("`@("1E<G)O<G,@/2!A<G)A>2@G,#`Q)R`]/B!?
M*")!=71H96YT:6-A=&EO;B!F86EL960B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@)S`P,B<@/3X@7R@B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R
M9"XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S`P,R<@/3X@7R@B4V5S
M<VEO;B!)1"!E>'!I<F5D+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M,#`T)R`]/B!?*")!8V-O=6YT(&9R;WIE;BXB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)S`P-2<@/3X@7R@B36ES<VEN9R!S97-S:6]N($E$+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G,#`W)R`]/B!?*"))4"!L;V-K9&]W
M;B!V:6]L871I;VXN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,#$G
M(#T^(%\H(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G,3`R)R`]/B!?*"));G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G,3`S)R`]/B!?*")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,#0G(#T^(%\H(E5N
M:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)S$P-2<@/3X@7R@B26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,3`V
M)R`]/B!?*"));G9A;&ED('-O=7)C92!A9&1R97-S+B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G,3`W)R`]/B!?*")%;7!T>2!M97-S86=E+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G,3`X)R`]/B!?*"));G9A;&ED(&]R
M(&UI<W-I;F<@87!I7VED+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M,3`Y)R`]/B!?*")-:7-S:6YG(&UE<W-A9V4@240N(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("<Q,3`G(#T^(%\H(D5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$Q,2<@/3X@7R@B
M26YV86QI9"!P<F]T;V-O;"XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)S$Q,B<@/3X@7R@B26YV86QI9"!M<V=?='EP92XB*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@)S$Q,R<@/3X@7R@B36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,30G(#T^(%\H
M(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,34G(#T^(%\H(DUE<W-A9V4@
M97AP:7)E9"XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$Q-B<@/3X@
M7R@B26YV86QI9"!U;FEC;V1E(&1A=&$N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("<R,#$G(#T^(%\H(DEN=F%L:60@8F%T8V@@240N(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("<R,#(G(#T^(%\H(DYO(&)A=&-H('1E;7!L
M871E+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,S`Q)R`]/B!?*").
M;R!C<F5D:70@;&5F="XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S,P
M,B<@/3X@7R@B36%X(&%L;&]W960@8W)E9&ET+B(I*3L*"B`@("`@("`@:68@
M*&5M<'1Y*"1E<G)O<E]T97AT*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R<ULD97)R;W)=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H)&5R<F]R7W1E>'0L("1E
M<G)O<G-;)&5R<F]R72DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($1O('1H92!H='1P(&-A;&P@=7-I;F<@82!U<FP@<&%S<V5D('1O('1H
M92!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H92!U<FP@=&\@8V%L
M;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5S<&]N<V4@
M;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C86QL55),*"1U<FPI"B`@("!["B`@("`@("`@)&]P
M=&EO;G-;)VUE=&AO9"==(#T@)U!/4U0G.PH@("`@("`@("1O<'1I;VYS6R=T
M:6UE;W5T)UT@/2`U.PH@("`@("`@("1O<'1I;VYS6R=A;&QO=U)E9&ER96-T
M<R==(#T@=')U93L*"B`@("`@("`@:68@*"%`:6YC;'5D95]O;F-E("=(5%10
M+U)E<75E<W0N<&AP)RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M(BDI.PH@("`@("`@('T*("`@("`@("`D:'1T<"`]("9N97<@2%144%]297%U
M97-T*"1T:&ES+3Y?8F%S95]U<FP@+B`D=7)L+"`D;W!T:6]N<RD["B`@("`@
M("`@0"1H='1P+3YS96YD4F5Q=65S="@I.PH@("`@("`@(&EF("@D:'1T<"T^
M9V5T4F5S<&]N<V5#;V1E*"D@(3T@,C`P*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P96X@
M)7,N(BDL("1U<FPI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1T
M<"T^9V5T4F5S<&]N<V5";V1Y*"D["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O
M9V5N97)I8U]S;71P+G!H<```````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,C,R,@`Q,#0Q-S,V,C<W-0`P,C$U-3,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($=E;F5R:6,@
M92UM86EL(&)A<V5D(%--4R!D<FEV97(*("H*("H@0V]P>7)I9VAT(#(P,#4M
M,C`P-B!796)3<')O8VME=',L($Q,0PH@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@5&AI
M<R!D<FEV97(@:6YT97)F86-E<R!W:71H('1H92!E;6%I;"UT;RUS;7,@9V%T
M97=A>7,@<')O=FED960@8GD@;6%N>0H@*B!C87)R:65R<RP@<&%R=&EC=6QA
M<FQY('1H;W-E(&)A<V5D(&EN('1H92!5+E,N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`L=B`Q+C@N,BXS
M(#(P,#8O,#$O,#$@,C$Z,C@Z,CD@:F%N($5X<"`D"B`J"B`J($!C871E9V]R
M>2`@($YE='=O<FMI;F<*("H@0'!A8VMA9V4@("`@3F5T7U--4PH@*B!`875T
M:&]R("`@("!)86X@175R92`\:65U<F5`<&AP+FYE=#X*("H@0'-I;F-E("`@
M("`@2&]R9&4@,RXQ"B`J($!S:6YC92`@("`@($YE=%]335,@,"XP+C(*("HO
M"F-L87-S($YE=%]335-?9V5N97)I8U]S;71P(&5X=&5N9',@3F5T7U--4R![
M"@H@("`@+RHJ"B`@("`@*B!#87!A8FEL:71I97,@;V8@=&AI<R!D<FEV97(N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A
M<&%B:6QI=&EE<R`](&%R<F%Y*`H@("`@("`@("=A=71H)R`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@)V)A=&-H)R`@("`@("`]/B!F86QS92P*("`@("`@
M("`G;75L=&DG("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=R96-E:79E)R`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)V-R961I="<@("`@("`]/B!F86QS92P*
M("`@("`@("`G861D<F5S<V)O;VLG(#T^(&9A;'-E+`H@("`@("`@("=L:7-T
M<R<@("`@("`@/3X@9F%L<V4*("`@("D["@H@("`@+RHJ"B`@("`@*B!$<FEV
M97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W!A
M<F%M<R`](&%R<F%Y*`H@("`@("`@("=C87)R:65R)R`@("`@/3X@;G5L;"P*
M("`@("`@("`G;6%I;$)A8VME;F0G(#T^("=M86EL)RP*("`@("`@("`G;6%I
M;%!A<F%M<R<@(#T^(&%R<F%Y*"DL"B`@("`@("`@)VUA:6Q(96%D97)S)R`]
M/B!A<G)A>2@I"B`@("`I.PH*("`@("\J*@H@("`@("H@0V%R<FEE<B!E;6%I
M;"!M87`N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C87)R:65R<R`]
M(&%R<F%Y*`H@("`@("`@("\J(%4N4RX@8V%R<FEE<G,N("HO"B`@("`@("`@
M)V%T="<@("`@("`@("`@/3X@)R5S0&UM;V1E+F-O;2<L"B`@("`@("`@)V-I
M;F=U;&%R)R`@("`@/3X@)R5S0&UM;V1E+F-O;2<L"B`@("`@("`@)W9E<FEZ
M;VXG("`@("`@/3X@)R5S0'9T97AT+F-O;2<L"B`@("`@("`@)V)O;W-T)R`@
M("`@("`@/3X@)R5S0&UY8F]O<W1M;V)I;&4N8V]M)RP*("`@("`@("`G8V5L
M;'5L87)O;F4G("`]/B`G)7-`;7EC96QL;VYE+FYE="<L"B`@("`@("`@)V-I
M;F-Y8F5L;"<@("`@/3X@)R5S0&=O8V)W+F-O;2<L"B`@("`@("`@)W-P<FEN
M="<@("`@("`@/3X@)R5S0&UE<W-A9VEN9RYS<')I;G1P8W,N8V]M)RP*("`@
M("`@("`G=&UO8FEL95]U<R<@("`]/B`G)7-`=&UO;6%I;"YC;VTG+`H@("`@
M("`@("=S=6YC;VTG("`@("`@(#T^("<E<T!T;7,N<W5N8V]M+F-O;2<L"B`@
M("`@("`@)V%I<F-E;"<@("`@("`@/3X@)R5S0&%I<G-M<RYC;VTG+`H@("`@
M("`@("=A:7)T96PG("`@("`@(#T^("<E<T!A:7)T96QM86EL+F-O;2<L"B`@
M("`@("`@)V)P;&UO8FEL92<@("`@/3X@)R5S0&)P;&UO8FEL92YC;VTG+`H@
M("`@("`@("=B96QL;6]B:6QI='DG(#T^("<E<T!T>'0N8F5L;&UO8FEL:71Y
M+F-A)RP*("`@("`@("`G8FQU96=R87-S)R`@("`]/B`G)7-`<VUS+F)L=65C
M96QL+F-O;2<L"B`@("`@("`@)V-E;&QF;W)C92<@("`@/3X@)R5S0&-E;&9O
M<F-E+F-O;2<L"B`@("`@("`@)V-E;&QU;&%R;VYE)R`@/3X@)R5S0&UY8V5L
M;&]N92YN970G+`H@("`@("`@("\J($=E<FUA;B!C87)R:65R<RX@*B\*("`@
M("`@("`G97!L=7,G("`@("`@(#T^("<E<T!S;7-M86EL+F5P;'5S+F1E)RP*
M("`@("`@("`G=&UO8FEL95]D92<@(#T^("<E<T!T+6UO8FEL92US;7,N9&4G
M+`H@("`@("`@("=V;V1A9F]N95]D92<@/3X@)R5S0'9O9&%F;VYE+7-M<RYD
M92<L"B`@("`I.PH*("`@("\J*@H@("`@("H@261E;G1I9FEE<R!T:&ES(&1R
M:79E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!$<FEV97(@:6YF
M;RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;R@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`G;F%M92<@/3X@7R@B16UA
M:6PM=&\M4TU3($=A=&5W87DB*2P*("`@("`@("`@("`@)V1E<V,G(#T^(%\H
M(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H
M:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(I"B`@("`@("`@*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@<F5Q=6ER960@<&%R86UE=&5R<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E
M9"!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;7,H
M*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@)V-A
M<G)I97(G("`@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D-A<G)I97(B*2P@
M)W1Y<&4G(#T^("=T97AT)RDL"B`@("`@("`@("`@("=M86EL0F%C:V5N9"<@
M/3X@87)R87DH)VQA8F5L)R`]/B!?*")014%2.CI-86EL(&)A8VME;F0B*2P@
M)W1Y<&4G(#T^("=T97AT)RD*("`@("`@("`I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5N9',@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@66]U(&UA
M>2!A;'-O('-P96-I9GD@=&AE(&-A<G)I97(@=VET:"!T:&4@)V-A<G)I97(G
M(&ME>2!O9B!T:&4@;65S<V%G90H@("`@("H@=&\@879O:60@8W)E871I;F<@
M82!N97<@:6YS=&%N8V4@9F]R(&5A8V@@8V%R<FEE<BP@;W(@9FED9&QI;F<@
M=VET:"!T:&4*("`@("`J('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S
M86=E("!-97-S86=E('1O('-E;F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M;R`@("`@($1E<W1I;F%T:6]N('!H;VYE(&YU;6)E<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H('1H92!S=6-C97-S('-T
M871U<R!A;F0@861D:71I;VYA;`H@("`@("H@("`@("`@("`@("`@("`@:6YF
M;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96YD*"8D;65S<V%G
M92P@)'1O*0H@("`@>PH@("`@("`@("1R97-P;VYS92`](&%R<F%Y*"D["B`@
M("`@("`@)&1E<W1E;6%I;"`]("1T:&ES+3Y?9V5T1&5S="@D=&\I.PH@("`@
M("`@(')E<75I<F5?;VYC92`G36%I;"YP:'`G.PH@("`@("`@("1M(#T@36%I
M;#HZ9F%C=&]R>2@D=&AI<RT^7W!A<F%M<ULG;6%I;$)A8VME;F0G72P@)'1H
M:7,M/E]P87)A;7-;)VUA:6Q087)A;7,G72D["@H@("`@("`@(&EF("AI<W-E
M="@D;65S<V%G95LG8V%R<FEE<B==*2D@>PH@("`@("`@("`@("`D9&5S="`]
M("1T:&ES+3Y?9V5T1&5S="@D=&\L("1M97-S86=E6R=C87)R:65R)UTI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D97-T(#T@)'1H:7,M/E]G
M971$97-T*"1T;RD["B`@("`@("`@?0H*("`@("`@("`D<F5S(#TF("1M+3YS
M96YD*"1D97-T+"`D=&AI<RT^7W!A<F%M<ULG;6%I;$AE861E<G,G72P@)&UE
M<W-A9V5;)W1E>'0G72D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E
M<RDI('L*("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@/2!A<G)A>2@P+"`D
M<F5S+3YG971-97-S86=E*"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1R97-P;VYS95LD=&]=(#T@87)R87DH,2P@;G5L;"D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!D97-T:6YA=&EO;B!E+6UA:6P@861D<F5S<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P:&]N92`@4&AO;F4@;G5M8F5R
M('1O('-E;F0@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($1E
M<W1I;F%T:6]N(&%D9')E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971$
M97-T*"1P:&]N92P@)&-A<G)I97(@/2!N=6QL*0H@("`@>PH@("`@("`@("1C
M87)R:65R(#T@:7-?;G5L;"@D8V%R<FEE<BD@/R`D=&AI<RT^7W!A<F%M<ULG
M8V%R<FEE<B==(#H@)&-A<G)I97(["B`@("`@("`@<F5T=7)N('-P<FEN=&8H
M)'1H:7,M/E]C87)R:65R<ULD8V%R<FEE<ETL"B`@("`@("`@("`@("`@("`@
M("`@("`@<')E9U]R97!L86-E*"<O6UXP+3E=+R<L("<G+"`D<&AO;F4I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%D9')E<W,@=&5M
M<&QA=&4@9F]R(&$@8V%R<FEE<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C87)R:65R("!#87)R:65R(&YA;64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@061D<F5S<R!T96UP;&%T92!O<B!F86QS92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T061D<F5S<U1E;7!L871E*"1C87)R:65R*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C87)R:65R<ULD8V%R
M<FEE<ETI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%R<FEE<G-;)&-A<G)I97)=.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&-A<G)I97(@=&\@=&AE(&QI
M<W0N"B`@("`@*@H@("`@("H@061D<F5S<R!T96UP;&%T97,@;F5E9"!T;R!B
M92!I;B!T:&4@9F]R;2!O9B!A;B!E;6%I;"!A9&1R97-S+"!W:71H(&$*("`@
M("`J("<E<R<@<F5P<F5S96YT:6YG('1H92!P;&%C92!W:&5R92!T:&4@9&5S
M=&EN871I;VX@<&AO;F4@;G5M8F5R(&=O97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@0V%R<FEE<B!N86UE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D861D<B`@061D<F5S<R!T96UP;&%T92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D0V%R<FEE<B@D;F%M92P@)&%D9'(I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]C87)R:65R<ULD;F%M95T@/2`D861D<CL*("`@('T*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,C4S,0`Q,#0Q-S,V,C<W-0`P
M,C(P,S8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($YE=%]335-?<VUS,F5M86EL7VAT='`@0VQA<W,@
M:6UP;&5M96YT<R!T:&4@2%144"!!4$D@9F]R(&%C8V5S<VEN9R!T:&4*("H@
M<VUS,F5M86EL("AW=W<N<VUS,F5M86EL+F-O;2D@4TU3(&=A=&5W87DN"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O
M8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<"QV(#$N,C,N,3`N,3`@
M,C`P-B\P,2\P,2`R,3HR.#HR.2!J86X@17AP("0*("H*("H@0&%U=&AO<B!-
M87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!.971?
M4TU3"B`J+PIC;&%S<R!.971?4TU37W-M<S)E;6%I;%]H='1P(&5X=&5N9',@
M3F5T7U--4R!["@H@("`@=F%R("1?8F%S95]U<FP@/2`G:&]R9&4N<VUS,F5M
M86EL+F-O;2]H;W)D92\G.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@
M8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W
M:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@
M:70@9&]E<VXG="X@4&]S<VEB;&4@=F%L=65S(&%R93H\<')E/@H@("`@("H@
M("!A=71H("`@("`@("`M(%1H92!G871E=V%Y(')E<75I<F5S(&%U=&AE;G1I
M8V%T:6]N(&)E9F]R92!S96YD:6YG.PH@("`@("H@("!B871C:"`@("`@("`M
M($)A=&-H('-E;F1I;F<@:7,@<W5P<&]R=&5D.PH@("`@("H@("!M=6QT:2`@
M("`@("`M(%-E;F1I;F<@;V8@;65S<V%G97,@=&\@;75L=&EP;&4@<F5C:7!I
M96YT<R!I<R!S=7!P;W)T960["B`@("`@*B`@(')E8V5I=F4@("`@("T@5VAE
M=&AE<B!T:&ES(&1R:79E<B!I<R!C87!A8FQE(&]F(')E8V5I=FEN9R!335,[
M"B`@("`@*B`@(&-R961I="`@("`@("T@27,@=7-E(&]F('1H92!G871E=V%Y
M(&)A<V5D(&]N(&-R961I=',["B`@("`@*B`@(&%D9')E<W-B;V]K("T@07)E
M(&=A=&5W87D@861D<F5S<V)O;VMS('-U<'!O<G1E9#L*("`@("`J("`@;&ES
M=',@("`@("`@+2!'871E=V%Y('-U<'!O<G0@9F]R(&1I<W1R:6)U=&EO;B!L
M:7-T<RX*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G875T:"<@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8F%T8V@G("`@("`@(#T^(#$P,"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VUU;'1I)R`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5C96EV92<@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G8W)E9&ET)R`@("`@(#T^('1R
M=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A9&1R97-S8F]O
M:R<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI
M<W1S)R`@("`@("`]/B!T<G5E*3L*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N
M8W1I;VX@9&]E<R!T:&4@86-T=6%L('-E;F1I;F<@;V8@=&AE(&UE<W-A9V4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1M97-S86=E("!4:&4@87)R87D@8V]N=&%I;FEN9R!T
M:&4@;65S<V%G92!A;F0@:71S('-E;F0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!S=')I;F<@)'1O
M("`@("`@5&AE(&1E<W1I;F%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H('1H92!S=6-C97-S('-T871U
M<R!A;F0@861D:71I;VYA;`H@("`@("H@("`@("`@("`@("`@("`@:6YF;W)M
M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96YD*"8D;65S<V%G92P@
M)'1O*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@<V5N9&EN9R!U<FPN
M("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1M<V<N<&AP/W5S97)N
M86UE/25S)G!A<W-W;W)D/25S)FUE<W-A9V4])7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*
M("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A
M;7-;)W!A<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N
M8V]D92@D;65S<V%G95LG=&5X="==*2D["@H@("`@("`@("\J($-H96-K(&EF
M('-O=7)C92!F<F]M(&ES('-E="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1M
M97-S86=E6R=S96YD7W!A<F%M<R==6R=F<F]M)UTI*2!["B`@("`@("`@("`@
M("1U<FP@+CT@)R9O<FEG/2<@+B!U<FQE;F-O9&4H)&UE<W-A9V5;)W-E;F1?
M<&%R86US)UU;)V9R;VTG72D["B`@("`@("`@?0H@("`@("`@("\J($-H96-K
M(&EF(&UE<W-A9V4@='EP92!I<R!F;&%S:"X@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M<R==6R=M<V=?='EP92==*2`F)@H@
M("`@("`@("`@("`D;65S<V%G95LG<V5N9%]P87)A;7,G75LG;7-G7W1Y<&4G
M72`]/2`G4TU37T9,05-()RD@>PH@("`@("`@("`@("`D=7)L("X]("<F9FQA
M<V@],2<["B`@("`@("`@?0H@("`@("`@("\J($-H96-K(&EF(&1E;&EV97)Y
M(')E<&]R="!U<FP@:&%S(&)E96X@<V5T+B`J+PH@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]P87)A;7-;)V1E;&EV97)Y7W)E<&]R="==*2D@>PH@("`@
M("`@("`@("`D=7)L("X]("<F9&QU<FP])R`N('5R;&5N8V]D92@D=&AI<RT^
M7W!A<F%M<ULG9&5L:79E<GE?<F5P;W)T)UTI("X*("`@("`@("`@("`@("`@
M("`@("`G<F5P;W)T8V]D93TE8V]D929D97-T:6YA=&EO;FYU;6)E<CTE9&5S
M="<["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@<F5C:7!I
M96YT<R!A;F0@9&\@<V]M92!M:6YI;6%L('9A;&ED:71Y(&-H96-K:6YG+B`J
M+PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&\I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1T;R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_7"L_*%QD>S<L?2DH/GPD*2\G+"`D
M=F%L+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`D=&];)&ME
M>5T@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@+RH@1DE8344Z(%-I;&5N=&QY(&1R;W`@8F%D
M(')E8VEP:65N=',N(%1H:7,@<VAO=6QD(&)E"B`@("`@("`@("`@("`@("`@
M("`@("H@;&]G9V5D(&%N9"]O<B!R97!O<G1E9"X@*B\*("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D=&];)&ME>5TI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T;R`](&EM<&QO9&4H)RPG+"`D
M=&\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O7BXJ/SP_7"L_*%QD>S<L?2DH/GPD*2\G+"`D=&\L("1M871C:&5S
M*2D@>PH@("`@("`@("`@("`@("`@)'1O(#T@)&UA=&-H97-;,5T["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M,"P@<W!R:6YT9BA?*"));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(BDL("1T
M;RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!!<'!E
M;F0@=&AE(')E8VEP:65N=',@;V8@=&AI<R!M97-S86=E(&%N9"!C86QL('1H
M92!U<FPN("HO"B`@("`@("`@)'5R;"`N/2`G)G1O7VYU;3TG("X@)'1O.PH@
M("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*#`L("1R97-P;VYS92T^9V5T365S<V%G
M92@I*3L*("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H92!R97-P;VYS
M92P@8VAE8VL@9F]R(&YE=R!L:6YE<R!I;B!C87-E(&]F(&UU;'1I<&QE"B`@
M("`@("`@("H@<F5C:7!I96YT<RX@*B\*("`@("`@("`D;&EN97,@/2!E>'!L
M;V1E*")<;B(L("1R97-P;VYS92D["B`@("`@("`@)')E<W!O;G-E(#T@87)R
M87DH*3L*"B`@("`@("`@:68@*&-O=6YT*"1L:6YE<RD@/B`Q*2!["B`@("`@
M("`@("`@("\J($UU;'1I<&QE(')E8VEP:65N=',N("HO"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@
M)'!A<G1S(#T@97AP;&]D92@G5&\Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@
M("`@)')E8VEP:65N="`]('1R:6TH)'!A<G1S6S%=*3L*("`@("`@("`@("`@
M("`@(&EF("@D;&EN97-;,%T@/3T@)T%14TU3+4]+)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1R97-P;VYS95LD<F5C:7!I96YT72`](&%R<F%Y*#$L(&YU
M;&PI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D<F5S<&]N<V5;)')E8VEP:65N=%T@/2!A<G)A>2@P+"`D;&EN97-;
M,%TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@4VEN9VQE(')E8VEP:65N="X@*B\*
M("`@("`@("`@("`@:68@*"1L:6YE<ULP72`]/2`G05%335,M3TLG*2!["B`@
M("`@("`@("`@("`@("`D<F5S<&]N<V5;)'1O72`](&%R<F%Y*#$L(&YU;&PI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W!O
M;G-E6R1T;UT@/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!C<F5D:70@8F%L
M86YC92!O;B!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C<F5D
M:70@8F%L86YC92!A=F%I;&%B;&4@;VX@=&AE(&=A=&5W87DN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971"86QA;F-E*"D*("`@('L*("`@("`@("`O*B!3
M970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@
M<W!R:6YT9B@G<&]S=&US9RYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0])7,F
M8VUD/6-R961I="<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E
M*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@
M("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI.PH@
M("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@("`@("!]"@H@("`@("`@
M("\J(%1R>2!S<&QI='1I;F<@=7`@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@
M("1L:6YE<R`](&5X<&QO9&4H)STG+"`D<F5S<&]N<V4I.PH*("`@("`@("!I
M9B`H)&QI;F5S6S!=(#T]("=!45--4RU#4D5$250G*2!["B`@("`@("`@("`@
M(')E='5R;B`D;&EN97-;,5T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D;&EN97-;,%TL(%\H(D-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<R(I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&1S(&$@8V]N=&%C="!T;R!T:&4@9V%T97=A>2=S
M(&%D9')E<W-B;V]K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@("`@(%1H92!N86UE(&9O<B!T:&ES(&-O;G1A8W0*("`@("`J($!P87)A
M;2!I;G1E9V5R("1N=6UB97(@(%1H92!C;VYT86-T)W,@<&AO;F4@;G5M8F5R
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!R96UO=&4@8V]N
M=&%C="!)1"!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX*("`@("`J("`@
M("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9$-O;G1A8W0H)&YA;64L("1N=6UB97(I"B`@("!["B`@("`@("`@+RH@4V5T
M('5P('1H92!U<FP@86YD(&-A;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P
M<FEN=&8H)W!O<W1C;VYT86-T<RYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0]
M)7,F8VUD/4%$1$-/3E1!0U0F;F%M93TE<R9N=6UB97(])7,G+`H@("`@("`@
M("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E
M<B==*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M
M/E]P87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@("`@
M('5R;&5N8V]D92@D;F%M92DL"B`@("`@("`@("`@("`@("`@("`@("`@)&YU
M;6)E<BD["B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL55),*"1U
M<FPI.PH@("`@("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0VAE8VL@:68@=&AE<F4@=V%S(&%N(&5R<F]R(')E<W!O
M;G-E+B`J+PH@("`@("`@(&EF("AS=6)S='(H)')E<W!O;G-E+"`P+"`Q-RD@
M(3T@)T%14TU3+4-/3E1!0U1)1$]+)RD@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F=E=$5R<F]R*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<R(I*3L*("`@("`@("!]"@H@("`@("`@("\J(%-P;&ET('5P
M('1H92!R97-P;VYS92X@*B\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*"<L
M/2<L("1R97-P;VYS92D["B`@("`@("`@<F5T=7)N("1L:6YE<ULQ73L*("`@
M('T*"B`@("`O*BH*("`@("`J(%5P9&%T97,@82!C;VYT86-T(&EN('1H92!G
M871E=V%Y)W,@861D<F5S<V)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&ED("`@("`@5&AE(&-O;G1A8W0G<R!)1"!O;B!T:&4@9V%T97=A
M>2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!N86UE(&9O
M<B!T:&ES(&-O;G1A8W0*("`@("`J($!P87)A;2!I;G1E9V5R("1N=6UB97(@
M(%1H92!C;VYT86-T)W,@<&AO;F4@;G5M8F5R+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T94-O;G1A8W0H
M)&ED+"`D;F%M92P@)&YU;6)E<BD*("`@('L*("`@("`@("`O*B!3970@=7`@
M=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT
M9B@G<&]S=&-O;G1A8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C
M;60]55!$051%0T].5$%#5"9I9#TE<R9N86UE/25S)FYU;6)E<CTE<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US
M6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@
M("`@("`@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D
M;F%M92DL"B`@("`@("`@("`@("`@("`@("`@("`@)&YU;6)E<BD["B`@("`@
M("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@
M(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M4&%R<V4@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@(&EF("@D<F5S<&]N<V4@
M/3T@)T%14TU3+4]+)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5R
M<F]R*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E
M<R(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S
M(&$@8V]N=&%C="!I;B!T:&4@9V%T97=A>2=S(&%D9')E<W-B;V]K+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9"`@5&AE(&-O;G1A8W0G<R!)
M1"!O;B!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5#;VYT86-T*"1I9"D*("`@('L*
M("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@
M("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&-O;G1A8W1S+G!H<#]U<V5R;F%M
M93TE<R9P87-S=V]R9#TE<R9C;60]1$5,151%0T].5$%#5"9I9#TE<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US
M6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@
M("`@("`@)&ED*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q5
M4DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@
M("`@?0H*("`@("`@("`O*B!087)S92!T:&4@<F5S<&]N<V4N("HO"B`@("`@
M("`@:68@*"1R97-P;VYS92`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E+"!?*")#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S(BDI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($9E=&-H97,@=&AE(&5N=&ER92!A9&1R97-S(&)O;VL@9G)O
M;2!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!
M<G)A>2!O9B!C;VYT86-T<R!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX@
M9F%I;'5R92X*("`@("`J("`@("`@("`@("`@("`@($9O<FUA="!O9B!T:&4@
M<F5T=7)N960@8V]N=&%C=',@:7,@9F]R(&5X86UP;&4Z/&-O9&4^"B`@("`@
M*B`@("`@("`@("`@("`@("`@("!A<G)A>2@\=6YI<75E:60^(#T^(&%R<F%Y
M*"=N86UE)R`@(#T^(#QN86UE/BP*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYU;6)E<B<@/3X@/&YU;6)E
M<CXI+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@/'5N:7%U96ED
M/B`]/B!A<G)A>2@G;F%M92<@("`]/B`\;F%M93XL"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N=6UB97(G
M(#T^(#QN=6UB97(^*2D["B`@("`@*B`\+V-O9&4^"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$%D9')E<W-";V]K*"D*("`@('L*("`@("`@("`O*B!3970@
M=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R
M:6YT9B@G<&]S=&-O;G1A8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE
M<R9C;60]1T54041$4D534T)/3TLG+`H@("`@("`@("`@("`@("`@("`@("`@
M('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@
M("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W
M;W)D)UTI*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH
M)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S
M<&]N<V4N("HO"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#$Y
M*2`A/2`G05%335,M041$4D534T)/3TM/2R<I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S(BDI.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E(&%N9"!C;VYS=')U8W0@=&AE(&%R
M<F%Y+B`J+PH@("`@("`@(&QI<W0H)')E<W!O;G-E+"`D8V]N=&%C='-?<W1R
M*2`](&5X<&QO9&4H)RPG+"`D<F5S<&]N<V4L(#(I.PH*("`@("`@("`O*B!#
M:&5C:R!T:&%T('1H92!F=6QL(&%D9')E<W,@8F]O:R!L:7-T(&AA<R!B965N
M(')E8V5I=F5D+B`J+PH@("`@("`@("1L96YG=&@@/2!S=6)S='(H)')E<W!O
M;G-E+"`Q.2D["B`@("`@("`@:68@*'-T<FQE;B@D8V]N=&%C='-?<W1R*2`A
M/2`D;&5N9W1H*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN
M(BDI.PH@("`@("`@('T*("`@("`@("`D8V]N=&%C='-?;&EN97,@/2!E>'!L
M;V1E*")<;B(L("1C;VYT86-T<U]S='(I.PH@("`@("`@("1C;VYT86-T<R`]
M(&%R<F%Y*"D["B`@("`@("`@+RH@3&]O<"!T:')O=6=H(&QI;F5S(&%N9"!P
M:6-K(&]U="!T:&4@9FEE;&1S+"!M86ME('-U<F4@=&AA="!T:&4@(B(*("`@
M("`@("`@*B!A<F4@;F]T(&EN8VQU9&5D(&EN('1H92!V86QU97,L('-O(&=E
M="!T:&4@;&EN92!L97-S(#$@8VAA<B!O;B!E86-H"B`@("`@("`@("H@96YD
M(&%N9"!S<&QI="!F;W(@(BPB+B`J+PH@("`@("`@(&9O<F5A8V@@*"1C;VYT
M86-T<U]L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("!L:7-T*"1I9"P@
M)&YA;64L("1N=6UB97(I(#T@97AP;&]D92@G(BPB)RP@<W5B<W1R*"1L:6YE
M+"`Q+"`M,2DI.PH@("`@("`@("`@("`D8V]N=&%C='-;)&ED72`](&%R<F%Y
M*"=N86UE)R`]/B`D;F%M92P@)VYU;6)E<B<@/3X@)&YU;6)E<BD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&-O;G1A8W1S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A(&YE=R!D:7-T<FEB=71I;VX@;&ES="!O;B!T
M:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@($%N(&%R8FET<F%R>2!N86UE(&9O<B!T:&4@;F5W(&QI<W0N"B`@("`@
M*B!`<&%R86T@87)R87D@)&YU;6)E<G,@($$@<VEM<&QE(&%R<F%Y(&]F(&YU
M;6)E<G,@=&\@861D('1O('1H92!L:7-T+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($=A=&5W87D@240@9F]R('1H92!C<F5A=&5D(&QI<W0@;VX@
M<W5C8V5S<R!O<B!014%2($5R<F]R"B`@("`@*B`@("`@("`@("`@("`@("!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T0W)E871E*"1N
M86UE+"`D;G5M8F5R<RD*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R
M;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S
M=&1I<W1R:6)U=&EO;BYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0])7,F8VUD
M/4%$1$1)4U1,25-4)FYA;64])7,F;G5M;&ES=#TE<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@=7)L
M96YC;V1E*"1N86UE*2P*("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E
M*"<L)RP@)&YU;6)E<G,I*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^
M7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@
M97)R;W(@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N
M<V4L(#`L(#$V*2`A/2`G05%335,M1$E35$E414U)1"<I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(BDI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E(&%N9"!G970@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T($E$+B`J+PH@("`@("`@(&QI<W0H)')E<W!O
M;G-E+"`D:60I(#T@97AP;&]D92@G/2<L("1R97-P;VYS92D["@H@("`@("`@
M("\J(%1/1$\Z(&1O('=E(&YE960@=&\@8VAE8VL@=&AE(&QE;F=T:"!O9B!T
M:&4@:60@<W1R:6YG/R`J+PH*("`@("`@("!R971U<FX@)&ED.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5L971E<R!A(&1I<W1R:6)U=&EO;B!L:7-T(&9R
M;VT@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:60@(%1H92!G871E=V%Y($E$(&9O<B!T:&4@;&ES="!T;R!D96QE=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&ES=$1E;&5T92@D:60I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H92!U
M<FP@86YD(&-A;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O
M<W1D:7-T<FEB=71I;VXN<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S)F-M
M9#U$14Q%5$5$25-43$E35"9D:7-T:60])7,G+`H@("`@("`@("`@("`@("`@
M("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@
M("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;
M)W!A<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("1I9"D["B`@
M("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@
M("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@
M+RH@0VAE8VL@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*"1R97-P;VYS92`]
M/2`G05%335,M3TLG*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T17)R
M;W(H)')E<W!O;G-E+"!?*")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!5<&1A=&5S(&$@9&ES=')I8G5T:6]N(&QI<W0@;VX@=&AE(&=A=&5W87DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@5&AE(&=A
M=&5W87D@240@9F]R('1H92!L:7-T('1O('5P9&%T92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("`@(%1H92!A<F)I=')A<GD@;F%M92!O9B!T:&4@
M;&ES="X@268@9&EF9F5R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!F<F]M('1H92!O<FEG:6YA;"!N86UE('1H870@=&AE(&QI<W0@=V%S
M(&-R96%T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('5N9&5R
M+"!T:&4@;&ES="!W:6QL(&)E(')E;F%M960N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N=6UB97)S("!4:&4@;F5W(&QI<W0@;V8@;G5M8F5R<R!I;B!T:&4@
M;&ES="X@268@;&5F=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M96UP='DL('1H92!R97-U;'0@=VEL;"!B92!T:&4@<V%M92!A<R!C86QL:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;&ES=%)E;F%M
M92@I(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QI<W15<&1A=&4H)&ED+"`D;F%M92P@)&YU;6)E
M<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L
M(&%N9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=P;W-T
M9&ES=')I8G5T:6]N+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]
M55!$051%3$E35$Y!344F9&ES=&ED/25S)FYA;64])7,G+`H@("`@("`@("`@
M("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==
M*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("1I
M9"P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)&YA;64I*3L*
M"B`@("`@("`@+RH@0VAE8VL@:68@=&AE(&QI<W0@;G5M8F5R<R!N965D('5P
M9&%T:6YG+B`J+PH@("`@("`@(&EF("@A96UP='DH)&YU;6)E<G,I*2!["B`@
M("`@("`@("`@("1U<FP@+CT@)R9N=6UB97)S/2<@+B!I;7!L;V1E*"<L)RP@
M)&YU;6)E<G,I.PH@("`@("`@('T*"B`@("`@("`@)')E<W!O;G-E(#T@)'1H
M:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R97-P;VYS
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W!O
M;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@<F5S<&]N<V4N("HO
M"B`@("`@("`@:68@*"1R97-P;VYS92`]/2`G05%335,M3TLG*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E+"!?*")#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(I*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;65S(&$@9&ES=')I8G5T
M:6]N(&QI<W0@;VX@=&AE(&=A=&5W87DN($1O97,@;F]T:&EN9R!O=&AE<B!T
M:&%N"B`@("`@*B!C86QL:6YG('1H92!L:7-T57!D871E*"D@9G5N8W1I;VX@
M=VET:"!J=7-T('1H92`D:60@86YD("1N86UE"B`@("`@*B!V87)I86)L97,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@5&AE(&=A=&5W
M87D@240@9F]R('1H92!L:7-T('1O('5P9&%T92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!N97<@87)B:71R87)Y(&YA;64@9F]R('1H92!L
M:7-T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI<W1296YA;64H)&ED+"`D;F%M92D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/FQI<W15<&1A=&4H)&ED+"`D;F%M92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&971C:&5S(&$@;&ES=&EN9R!O9B!A=F%I;&%B;&4@
M9&ES=')I8G5T:6]N(&QI<W1S(&]N('1H92!S97)V97(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@06X@87)R87D@;V8@;&ES=',@;VX@<W5C8V5S
M<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B`@("`@("`@("`@
M("`@("!&;W)M870@;V8@=&AE(')E='5R;F5D(&QI<W1S(&ES(&9O<B!E>&%M
M<&QE.CQC;V1E/@H@("`@("H@("`@("`@("`@("`@("`@("`@87)R87DH/'5N
M:7%U96ED/B`]/B!A<G)A>2@G;F%M92<@("`]/B`\;F%M93XI+`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@/'5N:7%U96ED/B`]/B!A<G)A>2@G
M;F%M92<@("`]/B`\;F%M93XI*3L*("`@("`J(#PO8V]D93X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T3&ES=',H*0H@("`@>PH@("`@("`@("\J(%-E="!U
M<"!T:&4@=7)L(&%N9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I
M;G1F*"=P;W-T9&ES=')I8G5T:6]N+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R
M9#TE<R9C;60]1T540T]-4$%#5$Q)4U0G+`H@("`@("`@("`@("`@("`@("`@
M("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@
M("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A
M<W-W;W)D)UTI*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q5
M4DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R;W(@
M<F5S<&]N<V4N("HO"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L
M(#(R*2`A/2`G05%335,M1$E35%))0E5424].3$E35"<I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(BDI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E(&%N9"!C;VYS
M=')U8W0@=&AE(&%R<F%Y+B`J+PH@("`@("`@(&QI<W0H)')E<W!O;G-E+"`D
M;&ES='-?<W1R*2`](&5X<&QO9&4H)RPG+"`D<F5S<&]N<V4L(#(I.PH*("`@
M("`@("`O*B!#:&5C:R!T:&%T('1H92!F=6QL(&QI<W0@;V8@9&ES=')I8G5T
M:6]N(&QI<W1S(&AA<R!B965N(')E8V5I=F5D+B`J+PH@("`@("`@("1L96YG
M=&@@/2!S=6)S='(H)')E<W!O;G-E+"`R,BD["B`@("`@("`@:68@*'-T<FQE
M;B@D;&ES='-?<W1R*2`A/2`D;&5N9W1H*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(BDI.PH@("`@("`@
M('T*("`@("`@("`D;&ES='-?;&EN97,@/2!E>'!L;V1E*")<;B(L("1L:7-T
M<U]S='(I.PH@("`@("`@("1L:7-T<R`](&%R<F%Y*"D["B`@("`@("`@+RH@
M3&]O<"!T:')O=6=H(&QI;F5S(&%N9"!P:6-K(&]U="!T:&4@9FEE;&1S+"!M
M86ME('-U<F4@=&AA="!T:&4@(B(*("`@("`@("`@*B!A<F4@;F]T(&EN8VQU
M9&5D(&EN('1H92!V86QU97,L('-O(&=E="!T:&4@;&EN92!L97-S(#$@8VAA
M<B!O;B!E86-H"B`@("`@("`@("H@96YD(&%N9"!S<&QI="!F;W(@(BPB+B`J
M+PH@("`@("`@(&9O<F5A8V@@*"1L:7-T<U]L:6YE<R!A<R`D;&EN92D@>PH@
M("`@("`@("`@("!L:7-T*"1I9"P@)&YA;64L("1C;W5N="D@/2!E>'!L;V1E
M*"<B+"(G+"!S=6)S='(H)&QI;F4L(#$L("TQ*2D["B`@("`@("`@("`@("1L
M:7-T<ULD:61=(#T@87)R87DH)VYA;64G("`]/B`D;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G8V]U;G0G(#T^("1C;W5N="D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&QI<W1S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1F5T8VAE<R!A('-P96-I9FEC(&1I<W1R:6)U=&EO;B!L:7-T
M(&9R;VT@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@5&AE($E$(&]F('1H92!D:7-T<FEB=71I;VX@;&ES="!T;R!F971C:"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!;B!A<G)A>2!O9B!N=6UB
M97)S(&EN('1H92!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<@H@("`@
M("H@("`@("`@("`@("`@("`@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T3&ES="@D:60I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H
M92!U<FP@86YD(&-A;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H
M)W!O<W1D:7-T<FEB=71I;VXN<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S
M)F-M9#U'151.54U"15)35TE42$E$)F1I<W1I9#TE<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@)&ED
M*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@
M("`@("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N<V4N
M("HO"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#(R*2`A/2`G
M05%335,M1$E35%))0E5424].3$E35"<I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B*2D["B`@("`@("`@?0H*("`@
M("`@("`O*B!087)S92!T:&4@<F5S<&]N<V4@86YD(&-O;G-T<G5C="!T:&4@
M87)R87DN("HO"B`@("`@("`@;&ES="@D<F5S<&]N<V4L("1L:7-T7W-T<BD@
M/2!E>'!L;V1E*"<L)RP@)')E<W!O;G-E+"`R*3L*"B`@("`@("`@+RH@0VAE
M8VL@=&AA="!T:&4@9G5L;"!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<R!H
M87,@8F5E;B!R96-E:79E9"X@*B\*("`@("`@("`D;&5N9W1H(#T@<W5B<W1R
M*"1R97-P;VYS92P@,C(I.PH@("`@("`@(&EF("AS=')L96XH)&QI<W1?<W1R
M*2`A/2`D;&5N9W1H*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="XB*2D["B`@("`@("`@?0H@("`@("`@("1L:7-T7W-T<B`]('1R
M:6TH)&QI<W1?<W1R*3L*("`@("`@("!L:7-T*"1C;W5N="P@)&YU;6)E<G,I
M(#T@97AP;&]D92@G(BPB)RP@)&QI<W1?<W1R*3L*"B`@("`@("`@+RH@5$]$
M3SH@06YY=&AI;F<@=7-E9G5L('1H870@8V%N(&)E(&1O;F4@=VET:"!T:&4@
M8V]U;G0@;V8@;G5M8F5R<R!A=`H@("`@("`@("`J('1H92!S=&%R=#\@*B\*
M("`@("`@("`D8V]U;G0@/2!S=6)S='(H)&-O=6YT+"`Q*3L*"B`@("`@("`@
M+RH@17AP;&]D92!T:&4@;&ES="!O9B!N=6UB97)S(&EN=&\@86X@87)R87D@
M86YD(')E='5R;BX@*B\*("`@("`@("`D;G5M8F5R<R`]('-U8G-T<B@D;G5M
M8F5R<RP@,"P@+3$I.PH@("`@("`@(')E='5R;B!E>'!L;V1E*"<L)RP@)&YU
M;6)E<G,I.PH@("`@?0H*("`@("\J*@H@("`@("H@261E;G1I9FEE<R!T:&ES
M(&=A=&5W87D@9')I=F5R(&%N9"!R971U<FYS(&$@8G)I968@9&5S8W)I<'1I
M;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@9')I
M=F5R(&EN9F\N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN9F\H*0H@("`@
M>PH@("`@("`@("1I;F9O6R=N86UE)UT@/2!?*")S;7,R96UA:6P@=FEA($A4
M5%`B*3L*("`@("`@("`D:6YF;ULG9&5S8R==(#T@7R@B5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(BD["@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M971E<G,@
M9F]R('1H:7,@9V%T97=A>2!D<FEV97(N(%1H92!S971T86)L90H@("`@("H@
M<&%R86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y(&%R93H\<')E/@H@("`@("H@
M("`M('5S97(@("`@("`@("`@("`M(%1H92!U<V5R;F%M92!F;W(@875T:&5N
M=&EC871I;VX@;VX@=&AE(&=A=&5W87D["B`@("`@*B`@("T@<&%S<W=O<F0@
M("`@("`@("T@5&AE('!A<W-W;W)D(&9O<B!A=71H96YT:6-A=&EO;B!O;B!T
M:&4@9V%T97=A>3L*("`@("`J("`@+2!S<VP@("`@("`@("`@("`@+2!7:&5T
M:&5R(&]R(&YO="!T;R!U<V4@4U-,(&9O<B!C;VUM=6YI8V%T:6]N('=I=&@*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V%T97=A>2X*("`@
M("`J("`@+2!D96QI=F5R>5]R97!O<G0@+2!!(%523"!F;W(@82!S8W)I<'0@
M=VAI8V@@=V]U;&0@86-C97!T(&1E;&EV97)Y"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<F5P;W)T(&9R;VT@=&AE(&=A=&5W87DN"B`@("`@*B`\
M+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R
M97%U:7)E9"!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710
M87)A;7,H*0H@("`@>PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@
M("`@("1P87)A;7-;)W5S97(G72`@("`@/2!A<G)A>2@G;&%B96PG(#T^(%\H
M(E5S97)N86UE(BDL("=T>7!E)R`]/B`G=&5X="<I.PH@("`@("`@("1P87)A
M;7-;)W!A<W-W;W)D)UT@/2!A<G)A>2@G;&%B96PG(#T^(%\H(E!A<W-W;W)D
M(BDL("=T>7!E)R`]/B`G=&5X="<I.PH@("`@("`@("1P87)A;7-;)W-S;"==
M("`@("`@/2!A<G)A>2@G;&%B96PG("`@(#T^(%\H(E5S92!34TPB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`@("`]
M/B`G8F]O;&5A;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R97%U:7)E9"<@/3X@9F%L<V4I.PH@("`@("`@("1P87)A;7-;)V1E
M;&EV97)Y7W)E<&]R="==(#T@87)R87DH)VQA8F5L)R`@("`]/B!?*")54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E
M)R`@("`@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS92D["@H*("`@("`@
M("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('!A<F%M971E<G,@=&AA="!C86X@8F4@<V5T(&%S(&1E9F%U;'0@
M9F]R('-E;F1I;F<@;65S<V%G97,*("`@("`J('5S:6YG('1H:7,@9V%T97=A
M>2!D<FEV97(@86YD(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@;65S<V%G97,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@<&%R86UE
M=&5R<R!T:&%T(&-A;B!B92!S970@87,@9&5F875L="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1&5F875L=%-E;F1087)A;7,H*0H@("`@>PH@("`@("`@
M("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("1P87)A;7-;)V9R;VTG72`]
M(&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R
M97-S(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I.PH*("`@("`@
M("`D<&%R86US6R=D96QI=E]T:6UE)UT@/2!A<G)A>2@*("`@("`@("`@("`@
M)VQA8F5L)R`]/B!?*")$96QI=F5R>2!T:6UE(BDL"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y
M*&%R<F%Y*"=N;W<G(#T^(%\H(FEM;65D:6%T92(I+"`G=7-E<B<@/3X@7R@B
M=7-E<B!S96QE8W0B*2DI*3L*"B`@("`@("`@)'1Y<&5S(#T@87)R87DH)U--
M4U]415A4)R`]/B`G4TU37U1%6%0G+"`G4TU37T9,05-()R`]/B`G4TU37T9,
M05-()RD["B`@("`@("`@)'!A<F%M<ULG;7-G7W1Y<&4G72`](&%R<F%Y*`H@
M("`@("`@("`@("`G;&%B96PG(#T^(%\H(DUE<W-A9V4@='EP92(I+`H@("`@
M("`@("`@("`G='EP92<@/3X@)VUU;'1I96YU;2<L"B`@("`@("`@("`@("=P
M87)A;7,G(#T^(&%R<F%Y*"1T>7!E<RDI.PH*("`@("`@("!R971U<FX@)'!A
M<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M
M971E<G,@9F]R('-E;F1I;F<@;65S<V%G97,@=7-I;F<@=&AI<R!G871E=V%Y
M(&1R:79E<BP*("`@("`J(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@;65S<V%G
M97,N(%1H97-E(&%R92!F:6QT97)E9"!O=70@=7-I;F<@=&AE"B`@("`@*B!D
M969A=6QT('9A;'5E<R!S970@=7`@=VAE;B!C<F5A=&EN9R!T:&4@9V%T97=A
M>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U
M:7)E9"!P87)A;65T97)S+@H@("`@("H@0'1O9&\@(%=O=6QD(&)E(&YI8V4@
M=&\@=7-E(&$@=&EM92]D871E('-E='5P(')A=&AE<B!T:&%N(&UI;G5T97,@
M9G)O;0H@("`@("H@("`@("`@(&YO=R!F;W(@=&AE(&1E;&EV97)Y('1I;64N
M(%5P;&]A9"!F:65L9"!F;W(@<FEN9W1O;F5S+VQO9V]S/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971396YD4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1P87)A;7-;)V9R;VTG72DI('L*("`@("`@("`@("`@
M)'!A<F%M<ULG9G)O;2==(#T@87)R87DH"B`@("`@("`@("`@("`@("`G;&%B
M96PG(#T^(%\H(E-O=7)C92!A9&1R97-S(BDL"B`@("`@("`@("`@("`@("`G
M='EP92<@/3X@)W1E>'0G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<&%R
M86US6R=D96QI=E]T:6UE)UT@/3T@)W5S97(G*2!["B`@("`@("`@("`@("1P
M87)A;7-;)V1E;&EV7W1I;64G72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M)VQA8F5L)R`]/B!?*")$96QI=F5R>2!T:6UE(BDL"B`@("`@("`@("`@("`@
M("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("`@("`G9&5S8R<@/3X@
M7R@B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB*2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H8V]U;G0H)'!A<F%M<ULG;7-G7W1Y<&4G72D@/B`Q*2![
M"B`@("`@("`@("`@("1P87)A;7-;)VUS9U]T>7!E)UT@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("=L86)E;"<@/3X@7R@B365S<V%G92!T>7!E(BDL"B`@
M("`@("`@("`@("`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@
M("`@)W!A<F%M<R<@/3X@87)R87DH)'!A<F%M<ULG;7-G7W1Y<&4G72DI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)A;7-;)VUS9U]T>7!E
M)UT@/2`D<&%R86US6R=M<V=?='EP92==6S!=.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R(&-O9&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4:&4@97)R
M;W(@8V]D92!T;R!L;V]K('5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="`@("!!;B!E>&ES=&EN9R!E<G)O<B!T97AT('1O('5S92!T;R!R86ES92!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(@17)R;W(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!T97AT=6%L(&UE<W-A9V4@
M8V]R<F5S<&]N9&EN9R!T;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@("`@*B`@
M("`@("`@("`@("`@("!014%2($5R<F]R(&EF('!A<W-E9"!A;B!E>&ES=&EN
M9R!E<G)O<B!T97AT+@H@("`@("H*("`@("`J($!T;V1O("!#:&5C:R!W:&EC
M:"!O9B!T:&5S92!A<F4@86-T=6%L;'D@<F5Q=6ER960@86YD('1R:6T@9&]W
M;B!T:&4*("`@("`J("`@("`@("!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971%<G)O<B@D97)R;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@("!["B`@
M("`@("`@)&5R<F]R(#T@=')I;2@D97)R;W(I.PH*("`@("`@("`O*B!!;B!A
M<G)A>2!O9B!E<G)O<B!C;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T97=A>2X@
M*B\*("`@("`@("`D97)R;W)S(#T@87)R87DH"B`@("`@("`@("`@("=!45--
M4RU.3T%55$A$151!24Q3)R`@("`@("`@/3X@7R@B3F\@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D('-E;G0N(BDL"B`@("`@("`@("`@("=!45--4RU!551(
M15)23U(G("`@("`@("`@("`@/3X@7R@B26YC;W)R96-T('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"XB*2P*("`@("`@("`@("`@)T%14TU3+4Y/35-')R`@
M("`@("`@("`@("`@("`]/B!?*").;R!M97-S86=E('-U<'!L:65D+B(I+`H@
M("`@("`@("`@("`G05%335,M3D]$15-4)R`@("`@("`@("`@("`@(#T^(%\H
M(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(I+`H@("`@("`@("`@("`G05%3
M35,M3D]#4D5$250G("`@("`@("`@("`@(#T^(%\H(DEN<W5F9FEC:65N="!C
M<F5D:70N(BDL"B`@("`@("`@("`@("=!45--4RU.3TY!345355!03$E%1"<@
M("`@("`@/3X@7R@B3F\@;F%M92!S<&5C:69I960N(BDL"B`@("`@("`@("`@
M("=!45--4RU.3TY534)%4E-54%!,245$)R`@("`@/3X@7R@B3F\@;G5M8F5R
M('-P96-I9FEE9"XB*2P*("`@("`@("`@("`@)T%14TU3+4%$1%)%4U-"3T]+
M15)23U(G("`@("`]/B!?*")4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN
M9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB*2P*("`@("`@("`@("`@)T%14TU3+4-/3E1!
M0U1)1$524D]2)R`@("`@("`]/B!?*")4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N(BDL"B`@("`@("`@("`@("=!45--4RU#3TY4
M04-455!$051%15)23U(G("`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(BDL"B`@("`@("`@("`@("=!45--4RU$25-4241%4E)/4B<@("`@
M("`@("`@/3X@7R@B5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H
M97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@
M=&AE(&1A=&%B87-E+B(I+`H@("`@("`@("`@("`G05%335,M3D]$25-43$E3
M5%-54%!,245$)R`@(#T^(%\H(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"XB*2P*("`@("`@("`@("`@)T%14TU3+4E.4U5&1DE#
M245.5$-2141)5%,G("`]/B!?*"));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(I+`H@("`@("`@("`@("`G
M05%335,M3D].54U"15),25-44U504$Q)140G(#T^(%\H(DYU;6)E<G,@;F]T
M('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N
M(BDL"B`@("`@("`@("`@("=!45--4RU$25-43$E35%501$%414524D]2)R`@
M/3X@7R@B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB*2D["@H@("`@
M("`@(&EF("AE;7!T>2@D97)R;W)?=&5X="DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<G-;)&5R<F]R73L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"1E<G)O<E]T
M97AT+"`D97)R;W)S6R1E<G)O<ETI*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$;R!T:&4@:'1T<"!C86QL('5S:6YG(&$@=7)L('!A<W-E
M9"!T;R!T:&4@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("!4:&4@=7)L
M('1O(&-A;&PN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E
M<W!O;G-E(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V%L;%523"@D=7)L*0H@("`@>PH@("`@
M("`@("1O<'1I;VYS6R=M971H;V0G72`]("=03U-4)SL*("`@("`@("`D;W!T
M:6]N<ULG=&EM96]U="==(#T@-3L*("`@("`@("`D;W!T:6]N<ULG86QL;W=2
M961I<F5C=',G72`]('1R=64["@H@("`@("`@("1U<FP@/2`H96UP='DH)'1H
M:7,M/E]P87)A;7-;)W-S;"==*2`_("=H='1P.B\O)R`Z("=H='1P<SHO+R<I
M("X@)'1H:7,M/E]B87-E7W5R;"`N("1U<FP["@H@("`@("`@(&EF("@A0&EN
M8VQU9&5?;VYC92`G2%144"]297%U97-T+G!H<"<I('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+B(I*3L*("`@("`@("!]"B`@("`@("`@)&AT='`@
M/2`F;F5W($A45%!?4F5Q=65S="@D=7)L+"`D;W!T:6]N<RD["B`@("`@("`@
M0"1H='1P+3YS96YD4F5Q=65S="@I.PH@("`@("`@(&EF("@D:'1T<"T^9V5T
M4F5S<&]N<V5#;V1E*"D@(3T@,C`P*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P96X@)7,N
M(BDL("1U<FPI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1T<"T^
M9V5T4F5S<&]N<V5";V1Y*"D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$R,3,P`#$P-#$W,S8R-S<U`#`R,S`P,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M3F5T7U--4U]V;V1A9F]N96ET86QY7W-M='`@0VQA<W,@:6UP;&5M96YT<R!T
M:&4@4TU44"!!4$D@9F]R(&%C8V5S<VEN9R!T:&4*("H@5F]D869O;F4@271A
M;'D@4TU3(&=A=&5W87DN(%5S92!O9B!T:&ES(&=A=&5W87D@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N=`H@*B!W:71H(%9O9&%F;VYE($ET86QY("AW=W<N
M,3DP+FET*2X*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K
M:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA
M='1E;R!:86UB96QL:2`\;6UZ86UB94!H;W1M86EL+F-O;3X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`L=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR
M.#HR.2!J86X@17AP("0*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K:6,@/&UA
M<FMO0&]B;&\N8V]M/@H@*B!`875T:&]R($UA='1E;R!:86UB96QL:2`\;6UZ
M86UB94!H;W1M86EL+F-O;3X*("H@0'!A8VMA9V4@3F5T7U--4PH@*B\*8VQA
M<W,@3F5T7U--4U]V;V1A9F]N96ET86QY7W-M='`@97AT96YD<R!.971?4TU3
M('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@
M<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@@;W!E<F%T:6]N
M<PH@("`@("H@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N(%!O
M<W-I8FQE('9A;'5E<R!A<F4Z/'!R93X*("`@("`J("`@875T:"`@("`@("`@
M+2!4:&4@9V%T97=A>2!R97%U:7)E(&%U=&AE;G1I8V%T:6]N(&)E9F]R92!S
M96YD:6YG.PH@("`@("H@("!B871C:"`@("`@("`M($)A=&-H('-E;F1I;F<@
M:7,@<W5P<&]R=&5D.PH@("`@("H@("!M=6QT:2`@("`@("`M(%-E;F1I;F<@
M;V8@;65S<V%G97,@=&\@;75L=&EP;&4@<F5C:7!I96YT<R!I<R!S=7!P;W)T
M960["B`@("`@*B`@(')E8V5I=F4@("`@("T@5VAE=&AE<B!T:&ES(&1R:79E
M<B!I<R!C87!A8FQE(&]F(')E8V5I=FEN9R!335,["B`@("`@*B`@(&-R961I
M="`@("`@("T@27,@=7-E(&]F('1H92!G871E=V%Y(&)A<V5D(&]N(&-R961I
M=',["B`@("`@*B`@(&%D9')E<W-B;V]K("T@07)E(&=A=&5W87D@861D<F5S
M<V)O;VMS('-U<'!O<G1E9#L*("`@("`J("`@;&ES=',@("`@("`@+2!'871E
M=V%Y('-U<'!O<G0@9F]R(&1I<W1R:6)U=&EO;B!L:7-T<RX*("`@("`J(#PO
M<')E/@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1C87!A8FEL:71I97,@/2!A<G)A>2@G875T:"<@("`@("`@(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F%T8V@G("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;75L
M=&DG("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<F5C96EV92<@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8W)E9&ET)R`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G861D<F5S<V)O;VLG(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES=',G("`@("`@
M(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@9&]E
M<R!T:&4@86-T=6%L('-E;F1I;F<@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1M97-S86=E("!4:&4@87)R87D@8V]N=&%I;FEN9R!T:&4@;65S<V%G
M92!A;F0@:71S('-E;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@("`@5&AE
M(&1E<W1I;F%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;B!A<G)A>2!W:71H('1H92!S=6-C97-S('-T871U<R!A;F0@861D
M:71I;VYA;`H@("`@("H@("`@("`@("`@("`@("`@:6YF;W)M871I;VXN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]S96YD*"8D;65S<V%G92P@)'1O*0H@("`@
M>PH@("`@("`@(&EF("@A0&EN8VQU9&5?;VYC92`G36%I;"YP:'`G*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DUI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(BDI.PH@("`@("`@('T*("`@
M("`@("`D;6%I;&5R(#T@36%I;#HZ9F%C=&]R>2@G;6%I;"<I.PH*("`@("`@
M("`O*B!3:6YC92!T:&ES(&]N;'D@=V]R:W,@9F]R($ET86QI86X@;G5M8F5R
M<RP@=&AI<R!I<R!H87)D8V]D960N("HO"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R]>+BH_/#\H7"L_,SDI/RA<9'LQ,'TI/C\O)RP@)'1O+"`D;6%T8VAE
M<RDI('L*("`@("`@("`@("`@)&AE861E<G-;)T9R;VTG72`]("1T:&ES+3Y?
M<&%R86US6R=U<V5R)UT["B`@("`@("`@("`@("1T;R`]("1M871C:&5S6S)=
M("X@)T!S;7,N=F]D869O;F4N:70G.PH@("`@("`@("`@("`D<F5S=6QT(#T@
M)&UA:6QE<BT^<V5N9"@D=&\L("1H96%D97)S+"`D;65S<V%G95LG=&5X="==
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*#`L("1R97-U;'0M
M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!R971U<FX@87)R87DH,2P@;G5L;"D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH,"P@
M7R@B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<B(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)9&5N=&EF
M:65S('1H:7,@9V%T97=A>2!D<FEV97(@86YD(')E='5R;G,@82!B<FEE9B!D
M97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A
M>2!O9B!D<FEV97(@:6YF;RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YF
M;R@I"B`@("!["B`@("`@("`@)&EN9F];)VYA;64G72`](%\H(E9O9&%F;VYE
M($ET86QY('9I82!33510(BD["B`@("`@("`@)&EN9F];)V1E<V,G72`](%\H
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!3
M3510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@
M=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C
M;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN
M(BD["@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M971E<G,@9F]R('1H:7,@
M9V%T97=A>2!D<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M07)R87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R
M87DH*3L*("`@("`@("`D<&%R86US6R=U<V5R)UT@("`@("`@/2!A<G)A>2@G
M;&%B96PG("`]/B!?*")5<V5R;F%M92(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`@(#T^("=T97AT)RD["@H@("`@
M("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@<&%R86UE=&5R<R!T:&%T(&-A;B!B92!S970@87,@9&5F875L
M="!F;W(@<V5N9&EN9R!M97-S86=E<PH@("`@("H@=7-I;F<@=&AI<R!G871E
M=V%Y(&1R:79E<B!A;F0@9&ES<&QA>65D('=H96X@<V5N9&EN9R!M97-S86=E
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!P87)A
M;65T97)S('1H870@8V%N(&)E('-E="!A<R!D969A=6QT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971$969A=6QT4V5N9%!A<F%M<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!P87)A;65T97)S(&9O<B!S96YD:6YG(&UE<W-A9V5S('5S:6YG
M('1H:7,@9V%T97=A>2!D<FEV97(L"B`@("`@*B!D:7-P;&%Y960@=VAE;B!S
M96YD:6YG(&UE<W-A9V5S+B!4:&5S92!A<F4@9FEL=&5R960@;W5T('5S:6YG
M('1H90H@("`@("H@9&5F875L="!V86QU97,@<V5T('5P('=H96X@8W)E871I
M;F<@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M07)R87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J($!T;V1O("!7
M;W5L9"!B92!N:6-E('1O('5S92!A('1I;64O9&%T92!S971U<"!R871H97(@
M=&AA;B!M:6YU=&5S(&9R;VT*("`@("`J("`@("`@("!N;W<@9F]R('1H92!D
M96QI=F5R>2!T:6UE+B!5<&QO860@9FEE;&0@9F]R(')I;F=T;VYE<R]L;V=O
M<S\*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5N9%!A<F%M<R@D<&%R86US
M*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!A
M;B!E<G)O<B!C;V1E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1E
M<G)O<B`@5&AE(&5R<F]R(&-O9&4@=&\@;&]O:R!U<"X*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@("`@06X@97AI<W1I;F<@97)R;W(@=&5X="!T;R!U
M<V4@=&\@<F%I<V4@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!0
M14%2($5R<F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($$@=&5X
M='5A;"!M97-S86=E(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&5R<F]R(&-O9&4@
M;W(@80H@("`@("H@("`@("`@("`@("`@("`@4$5!4B!%<G)O<B!I9B!P87-S
M960@86X@97AI<W1I;F<@97)R;W(@=&5X="X*("`@("`J"B`@("`@*B!`=&]D
M;R`@0VAE8VL@=VAI8V@@;V8@=&AE<V4@87)E(&%C='5A;&QY(')E<75I<F5D
M(&%N9"!T<FEM(&1O=VX@=&AE"B`@("`@*B`@("`@("`@;&ES="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T17)R;W(H)&5R<F]R+"`D97)R;W)?=&5X="`]
M("<G*0H@("`@>PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'``
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R,S$W`#$P-#$W
M,S8R-S<U`#`R,#<S-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@3F5T7U--4U]W:6Y?:'1T<"!#;&%S
M<R!I;7!L96UE;G1S('1H92!(5%10($%022!F;W(@86-C97-S:6YG('1H92!7
M24X*("H@*'=W=RYW:6YP;&,N8V]M*2!335,@9V%T97=A>2X*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP+'8@,2XY+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(X
M.C(Y(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R($UA<FMO($1J=6MI8R`\;6%R
M:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($YE=%]335,*("HO"F-L87-S($YE
M=%]335-?=VEN7VAT='`@97AT96YD<R!.971?4TU3('L*"B`@("!V87(@)%]B
M87-E7W5R;"`]("=G871E=V%Y,RYG;S)M;V)I;&4N;F5T.C$P,#,P+V=A=&5W
M87DO=C,O9V%T97=A>2YA<W!X)SL*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y
M(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O
M<G0@=VAI8V@@;W!E<F%T:6]N<PH@("`@("H@:70@<W5P<&]R=',@86YD('=H
M:6-H(&ET(&1O97-N)W0N(%!O<W-I8FQE('9A;'5E<R!A<F4Z/'!R93X*("`@
M("`J("`@875T:"`@("`@("`@+2!4:&4@9V%T97=A>2!R97%U:7)E<R!A=71H
M96YT:6-A=&EO;B!B969O<F4@<V5N9&EN9SL*("`@("`J("`@8F%T8V@@("`@
M("`@+2!"871C:"!S96YD:6YG(&ES('-U<'!O<G1E9#L*("`@("`J("`@;75L
M=&D@("`@("`@+2!396YD:6YG(&]F(&UE<W-A9V5S('1O(&UU;'1I<&QE(')E
M8VEP:65N=',@:7,@<W5P<&]R=&5D.PH@("`@("H@("!R96-E:79E("`@("`M
M(%=H971H97(@=&AI<R!D<FEV97(@:7,@8V%P86)L92!O9B!R96-E:79I;F<@
M4TU3.PH@("`@("H@("!C<F5D:70@("`@("`M($ES('5S92!O9B!T:&4@9V%T
M97=A>2!B87-E9"!O;B!C<F5D:71S.PH@("`@("H@("!A9&1R97-S8F]O:R`M
M($%R92!G871E=V%Y(&%D9')E<W-B;V]K<R!S=7!P;W)T960["B`@("`@*B`@
M(&QI<W1S("`@("`@("T@1V%T97=A>2!S=7!P;W)T(&9O<B!D:7-T<FEB=71I
M;VX@;&ES=',N"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%U
M=&@G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V)A=&-H)R`@("`@("`]/B`Q,#`L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=M=6QT:2<@("`@("`@/3X@=')U92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E8V5I=F4G("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-R961I="<@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%D9')E
M<W-B;V]K)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VQI<W1S)R`@("`@("`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!4
M:&ES(&9U;F-T:6]N(&1O97,@=&AE(&%C='5A;"!S96YD:6YG(&]F('1H92!M
M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@5&AE(&%R<F%Y(&-O;G1A
M:6YI;F<@=&AE(&UE<W-A9V4@86YD(&ET<R!S96YD"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@('!A<F%M971E<G,N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T;R`@("`@(%1H92!D97-T:6YA=&EO;B!S=')I;F<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@=VET:"!T:&4@<W5C8V5S
M<R!S=&%T=7,@86YD(&%D9&ET:6]N86P*("`@("`J("`@("`@("`@("`@("`@
M(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5N9"@F)&UE
M<W-A9V4L("1T;RD*("`@('L*("`@("`@("`O*B!3=&%R="!T:&4@6$U,+B`J
M+PH@("`@("`@("1X;6P@/2`G/%--4TU%4U-!1T4^/%1%6%0^)R`N("1M97-S
M86=E6R=T97AT)UT@+B`G/"]415A4/B<["@H@("`@("`@("\J($-H96-K(&EF
M('-O=7)C92!F<F]M(&ES('-E="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1M
M97-S86=E6R=S96YD7W!A<F%M<R==6R=F<F]M)UTI*2!["B`@("`@("`@("`@
M("1X;6P@+CT@)SQ33U520T5?041$4CXG("X@)&UE<W-A9V5;)W-E;F1?<&%R
M86US)UU;)V9R;VTG72`N("<\+U-/55)#15]!1$12/B<["B`@("`@("`@?0H*
M("`@("`@("`O*B!,;V]P('1H<F]U9V@@<F5C:7!I96YT<R!A;F0@9&\@<V]M
M92!M:6YI;6%L('9A;&ED:71Y(&-H96-K:6YG+B`J+PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D=&\I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T;R!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O7BXJ/SP_*%PK/UQD>S<L?2DH/GPD*2\G+"`D=F%L+"`D;6%T8VAE<RDI
M('L*("`@("`@("`@("`@("`@("`@("`D=&];)&ME>5T@/2`D;6%T8VAE<ULQ
M73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@+RH@268@82!R96-I<&EE;G0@:7,@:6YV86QI9"!S=&]P(&%L;"!F=7)T
M:&5R('-E;F1I;F<N("HO"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*#`L('-P<FEN=&8H7R@B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(I
M+"`D=F%L*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1T;R`](&EM<&QO9&4H)SPO1$535$E.051)3TY?041$4CX\
M1$535$E.051)3TY?041$4CXG+"`D=&\I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_*%PK/UQD>S<L?2DH
M/GPD*2\G+"`D=&\L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'1O
M(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!R971U<FX@87)R87DH,"P@<W!R:6YT9BA?*"));G9A;&ED(')E
M8VEP:65N=#H@7"(E<UPB(BDL("1T;RDI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@("1X;6P@+CT@)SQ$15-424Y!5$E/3E]!1$12/B<@+B`D
M=&\@+B`G/"]$15-424Y!5$E/3E]!1$12/B<["@H@("`@("`@("\J(%1/1$\Z
M(%-H;W5L9"!W92!H879E('-O;65T:&EN9R!M;W)E(&EN=&5L;&EG96YT/R!#
M;W5L9"!A8W1U86QL>0H@("`@("`@("`J(&)E('!A<G0@;V8@<V5N9"!P87)A
M;65T97)S+B`J+PH@("`@("`@("1X;6P@+CT@)SQ44D%.4T%#5$E/3DE$/B<@
M+B!T:6UE*"D@+B`G/"]44D%.4T%#5$E/3DE$/B<["@H@("`@("`@("\J(%1/
M1$\Z($%D9"!S;VUE(&5X=')A('1A9W,L(&IU<W0@=&%C:V5D(&]N(&9O<B!N
M;W<N("HO"B`@("`@("`@)'AM;"`N/2`G/%194$5)1#XR/"]465!%240^/%-%
M4E9)0T5)1#XQ/"]315)624-%240^/"]335--15-304=%/B<["@H@("`@("`@
M("\J(%-E;F0@=&AI<R!M97-S86=E+B`J+PH@("`@("`@("1R97-P;VYS92`]
M("1T:&ES+3Y?<&]S="@D>&UL*3L*("`@("`@("!I9B`H:7-?82@D<F5S<&]N
M<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*#`L("1R97-P;VYS92T^9V5T365S<V%G92@I*3L*("`@("`@("!]"@H@("`@
M("`@("\J(%!A<G-E('1H92!R97-P;VYS92P@8VAE8VL@9F]R(&YE=R!L:6YE
M<R!I;B!C87-E(&]F(&UU;'1I<&QE"B`@("`@("`@("H@<F5C:7!I96YT<RX@
M*B\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<;B(L("1R97-P;VYS92D[
M"B`@("`@("`@)')E<W!O;G-E(#T@87)R87DH*3L*"B`@("`@("`@:68@*&-O
M=6YT*"1L:6YE<RD@/B`Q*2!["B`@("`@("`@("`@("\J($UU;'1I<&QE(')E
M8VEP:65N=',N("HO"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D
M;&EN92D@>PH@("`@("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G5&\Z
M)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@)')E8VEP:65N="`]('1R:6TH
M)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D;&EN97-;,%T@/3T@
M)T%14TU3+4]+)RD@>PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS95LD
M<F5C:7!I96YT72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V5;)')E8VEP
M:65N=%T@/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+RH@4VEN9VQE(')E8VEP:65N="X@*B\*("`@("`@("`@("`@:68@*"1L:6YE
M<ULP72`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@("`@("`D<F5S<&]N
M<V5;)'1O72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@/2!A<G)A>2@P+"`D
M;&EN97-;,%TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@261E;G1I
M9FEE<R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!R971U<FYS(&$@8G)I968@
M9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R
M87D@;V8@9')I=F5R(&EN9F\N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN
M9F\H*0H@("`@>PH@("`@("`@("1I;F9O6R=N86UE)UT@/2!?*")724X@=FEA
M($A45%`B*3L*("`@("`@("`D:6YF;ULG9&5S8R==(#T@7R@B5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.
M("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(BD["@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M971E<G,@9F]R('1H
M:7,@9V%T97=A>2!D<FEV97(N(%1H92!S971T86)L90H@("`@("H@<&%R86UE
M=&5R<R!F;W(@=&AI<R!G871E=V%Y(&%R93H*("`@("`J("`@+2!U<V5R("`@
M("`@("`@("`@+2!4:&4@=7-E<FYA;64@9F]R(&%U=&AE;G1I8V%T:6]N(&]N
M('1H92!G871E=V%Y.PH@("`@("H@("`M('!A<W-W;W)D("`@("`@("`M(%1H
M92!P87-S=V]R9"!F;W(@875T:&5N=&EC871I;VX@;VX@=&AE(&=A=&5W87D[
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@<F5Q=6ER
M960@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86US
M*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`D
M<&%R86US6R=U<V5R)UT@("`@(#T@87)R87DH)VQA8F5L)R`]/B!?*")5<V5R
M;F%M92(I+"`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@("`D<&%R86US6R=P
M87-S=V]R9"==(#T@87)R87DH)VQA8F5L)R`]/B!?*")087-S=V]R9"(I+"`G
M='EP92<@/3X@)W1E>'0G*3L*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A;65T97)S('1H
M870@8V%N(&)E('-E="!A<R!D969A=6QT(&9O<B!S96YD:6YG(&UE<W-A9V5S
M"B`@("`@*B!U<VEN9R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!D:7-P;&%Y
M960@=VAE;B!S96YD:6YG(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($%R<F%Y(&]F('!A<F%M971E<G,@=&AA="!C86X@8F4@<V5T
M(&%S(&1E9F%U;'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'13
M96YD4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*
M("`@("`@("`D<&%R86US6R=F<F]M)UT@/2!A<G)A>2@*("`@("`@("`@("`@
M)VQA8F5L)R`]/B!?*")3;W5R8V4@861D<F5S<R(I+`H@("`@("`@("`@("`G
M='EP92<@/3X@)W1E>'0G*3L*"B`@("`@("`@)'!A<F%M<ULG8V]S=%]I9"==
M(#T@87)R87DH"B`@("`@("`@("`@("=L86)E;"<@/3X@7R@B0V]S="!)1"(I
M+`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<I.PH*("`@("`@("!R971U
M<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('!A<F%M971E<G,@9F]R('-E;F1I;F<@;65S<V%G97,@=7-I;F<@=&AI<R!G
M871E=V%Y(&1R:79E<BP*("`@("`J(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@
M;65S<V%G97,N(%1H97-E(&%R92!F:6QT97)E9"!O=70@=7-I;F<@=&AE"B`@
M("`@*B!D969A=6QT('9A;'5E<R!S970@=7`@=VAE;B!C<F5A=&EN9R!T:&4@
M9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O
M9B!R97%U:7)E9"!P87)A;65T97)S+@H@("`@("H@0'1O9&\@(%=O=6QD(&)E
M(&YI8V4@=&\@=7-E(&$@=&EM92]D871E('-E='5P(')A=&AE<B!T:&%N(&UI
M;G5T97,@9G)O;0H@("`@("H@("`@("`@(&YO=R!F;W(@=&AE(&1E;&EV97)Y
M('1I;64N(%5P;&]A9"!F:65L9"!F;W(@<FEN9W1O;F5S+VQO9V]S/PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G971396YD4&%R86US*"1P87)A;7,I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)V9R;VTG72DI('L*("`@("`@
M("`@("`@)'!A<F%M<ULG9G)O;2==(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`G;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R97-S(BDL"B`@("`@("`@("`@
M("`@("`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AE;7!T>2@D<&%R86US6R=C;W-T7VED)UTI*2!["B`@("`@("`@("`@("1P
M87)A;7-;)V1E;&EV7W1I;64G72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M)VQA8F5L)R`]/B!?*")#;W-T($E$(BDL"B`@("`@("`@("`@("`@("`G='EP
M92<@/3X@)VEN="<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG(')E
M<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R(&-O9&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4:&4@97)R;W(@8V]D92!T;R!L;V]K
M('5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("!!;B!E>&ES=&EN
M9R!E<G)O<B!T97AT('1O('5S92!T;R!R86ES92!A"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(%!%05(@17)R;W(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@02!T97AT=6%L(&UE<W-A9V4@8V]R<F5S<&]N9&EN9R!T
M;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("!0
M14%2($5R<F]R(&EF('!A<W-E9"!A;B!E>&ES=&EN9R!E<G)O<B!T97AT+@H@
M("`@("H*("`@("`J($!T;V1O("!#:&5C:R!W:&EC:"!O9B!T:&5S92!A<F4@
M86-T=6%L;'D@<F5Q=6ER960@86YD('1R:6T@9&]W;B!T:&4*("`@("`J("`@
M("`@("!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%<G)O<B@D97)R
M;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@("!["B`@("`@("`@)&5R<F]R(#T@
M=')I;2@D97)R;W(I.PH*("`@("`@("`O*B!!;B!A<G)A>2!O9B!E<G)O<B!C
M;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T97=A>2X@*B\*("`@("`@("`D97)R
M;W)S(#T@87)R87DH"B`@("`@("`@("`@("=!45--4RU.3T%55$A$151!24Q3
M)R`@("`@("`@/3X@7R@B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N(BDL"B`@("`@("`@("`@("=!45--4RU$25-43$E35%501$%414524D]2
M)R`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB*2D["@H@
M("`@("`@(&EF("AE;7!T>2@D97)R;W)?=&5X="DI('L*("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<G-;)&5R<F]R73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"1E<G)O
M<E]T97AT+"`D97)R;W)S6R1E<G)O<ETI*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$;R!T:&4@:'1T<"!C86QL('5S:6YG(&$@=7)L('!A
M<W-E9"!T;R!T:&4@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D>&UL("!4:&4@
M6$U,(&EN9F]R;6%T:6]N('!A<W-E9"!T;R!T:&4@9V%T97=A>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5S<&]N<V4@;VX@<W5C8V5S
M<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]P;W-T*"1X;6PI"B`@("!["B`@("`@("`@)&]P=&EO;G-;)VUE=&AO
M9"==(#T@)U!/4U0G.PH@("`@("`@("1O<'1I;VYS6R=T:6UE;W5T)UT@/2`U
M.PH@("`@("`@("1O<'1I;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@=')U93L*
M"B`@("`@("`@+RH@5W)A<"!T:&4@>&UL('=I=&@@=&AE('-T86YD87)D('1A
M9W,N("HO"B`@("`@("`@)'AM;"`]("<\/WAM;"!V97)S:6]N/2(Q+C`B('-T
M86YD86QO;F4](FYO(C\^/"%$3T-465!%(%=)3E]$14Q)5D5265\R7U--4R!3
M65-414T@(G=I;F)O=6YD7VUE<W-A9V5S7W8Q+F1T9"(^/%=)3E]$14Q)5D52
M65\R7U--4SXG("X@)'AM;"`N("<\+U=)3E]$14Q)5D5265\R7U--4SXG.PH*
M("`@("`@("!I9B`H(4!I;F-L=61E7V]N8V4@)TA45%`O4F5Q=65S="YP:'`G
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DUI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB*2D["B`@("`@("`@
M?0H@("`@("`@("1H='1P(#T@)FYE=R!(5%107U)E<75E<W0H)'1H:7,M/E]B
M87-E7W5R;"P@)&]P=&EO;G,I.PH*("`@("`@("`O*B!!9&0@=&AE(&%U=&AE
M;G1I8V%T:6]N('9A;'5E<R!T;R!03U-4+B`J+PH@("`@("`@("1H='1P+3YA
M9&10;W-T1&%T82@G57-E<B<L("1T:&ES+3Y?<&%R86US6R=U<V5R)UTI.PH@
M("`@("`@("1H='1P+3YA9&10;W-T1&%T82@G4&%S<W=O<F0G+"`D=&AI<RT^
M7W!A<F%M<ULG<&%S<W=O<F0G72D["@H@("`@("`@("\J($%D9"!T:&4@6$U,
M(&%N9"!S96YD('1H92!R97%U97-T+B`J+PH@("`@("`@("1H='1P+3YA9&10
M;W-T1&%T82@G5TE.7UA-3"<L("1X;6PI.PH@("`@("`@($`D:'1T<"T^<V5N
M9%)E<75E<W0H*3L*("`@("`@("!I9B`H)&AT='`M/F=E=%)E<W!O;G-E0V]D
M92@I("$](#(P,"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!O<&5N("5S+B(I+"`D=&AI<RT^
M7V)A<V5?=7)L*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT='`M
M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TYE="])35-0+G!H<```````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`S-3$T-P`Q,#0Q-S,V,C<W-0`P,3<R,30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"FEN
M8VQU9&5?;VYC92`G3&]G+G!H<"<["@HO+R!#;VYS=&%N="!$969I;FET:6]N
M<PID969I;F4H)TE-4U!?3T-4151?0T]53E0G+"`B+RA[*2A;,"TY77LQ+'TI
M*%Q])"DO(BD["F1E9FEN92@G24U34%]-55-47U5315],251%4D%,)RP@(B];
M7%==+VDB*3L*"B\J*@H@*B!4:&4@3F5T7TE-4U`@8VQA<W,@<')O=FED97,@
M82!C;VUM;VX@:6YT97)F86-E('1O(&%N($E-4U`@<V5R=F5R("X*("H*("H@
M4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=S97)V97(G("!(;W-T
M;F%M92!O9B!)35-0('-E<G9E<BX*("H@("`G<&]R="<@("`@4&]R="!O9B!)
M35-0('-E<G9E<BX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"YP:'`L=B`Q+C$S+C$P+C$Y(#(P,#8O,#(O,3`@,#0Z-3@Z
M,C8@<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC
M:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`
M:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T
M7TE-4U`@>PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@;F%M
M92])4"!A9&1R97-S(&]F($E-4U`@:&]S="X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)&EM<W!?<V5R=F5R("`@("`@("`@
M("`@("`@(#T@)VQO8V%L:&]S="<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@
M8V]N=&%I;FEN9R!P;W)T(&9O<B!)35-0('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&EM<W!?<&]R="`@("`@
M("`@("`@("`@("`@(#T@)S0P-B<["@H@("`@+RHJ"B`@("`@*B!";V]L96%N
M('1O('-E="!I9B!W92!S:&]U;&0@=W)I=&4@=&\@82!L;V<L(&EF(&]N92!I
M<R!S970@=7`N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D;&]G16YA8FQE9"`@("`@("`@("`@("`@("`@/2!T<G5E.PH*
M("`@("\J*@H@("`@("H@4W1R:6YG(&)U9F9E<B!C;VYT86EN:6YG('1H92!L
M87-T(')A=R!.3R!O<B!"040@<F5S<&]N<V4@9G)O;2!T:&4*("`@("`J('-E
M<G9E<BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)&QA<W1287=%<G)O<B`@("`@("`@("`@("`@/2`G)SL*"B`@("`O+R!0
M<FEV871E($1E8VQA<F%T:6]N<PH@("`@=F%R("1?8V]M;6%N9%!R969I>"`@
M("`@("`@("`@("`]("=!)SL*("`@('9A<B`D7V-O;6UA;F1#;W5N="`@("`@
M("`@("`@("`@/2`Q.PH@("`@=F%R("1?=&%G("`@("`@("`@("`@("`@("`@
M("`@("`]("<G.PH@("`@=F%R("1?<W1R96%M("`@("`@("`@("`@("`@("`@
M("`](&YU;&P["B`@("!V87(@)%]L87-T0V]M;6%N9%1A9R`@("`@("`@("`@
M(#T@)W5N9&5F:6YE9"<["B`@("!V87(@)%]L;V=G97(@("`@("`@("`@("`@
M("`@("`@(#T@;G5L;#L*("`@('9A<B`D7VQO9U-E="`@("`@("`@("`@("`@
M("`@("`@/2!N=6QL.PH@("`@=F%R("1?;&]G3&5V96P@("`@("`@("`@("`@
M("`@("`](%!%05)?3$]'7TE.1D\["B`@("!V87(@)%]L;V="=69F97(@("`@
M("`@("`@("`@("`@("`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R!(87-H(&-O;G1A:6YI;F<@<V5R=F5R('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($YE=%])35-0*"1P87)A;7,I"B`@("!["B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;7,I("8F("%E;7!T>2@D<&%R86US
M6R=S97)V97(G72DI('L*("`@("`@("`@("`@)'1H:7,M/FEM<W!?<V5R=F5R
M(#T@)'!A<F%M<ULG<V5R=F5R)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?87)R87DH)'!A<F%M<RD@)B8@(65M<'1Y*"1P87)A;7-;)W!O<G0G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/FEM<W!?<&]R="`]("1P87)A;7-;)W!O
M<G0G73L*("`@("`@("!]"@H@("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA
M;&EZ871I;VX@9G5N8W1I;VX@=&\@8F4@8V%L;&5D(&%F=&5R(&]B:F5C="!I
M<R!R971U<FYE9"X@(%1H:7,*("`@("`J(&%L;&]W<R!E<G)O<G,@=&\@;V-C
M=7(@86YD(&YO="!B<F5A:R!T:&4@<V-R:7!T+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!014%27T5R<F]R(&]N(&-O
M;FYE8W1I;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@I
M"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YI;7-P3W!E;B@I.PH*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^=W)I=&54;TQO9R@G26YI=&EA;&EZ:6YG($YE=%])35-0(&]B:F5C
M="XG+"!?7T9)3$5?7RP@7U],24Y%7U\L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4E],3T=?24Y&3RD["B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!,;V=S(&]U="!O9B!T:&4@<V5R=F5R(&%N
M9"!C;&]S97,@=&AE($E-4U`@<W1R96%M"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QO9V]U="@I"B`@("!["B`@("`@("`@)'1H:7,M/G=R:71E5&],;V<H)T-L
M;W-I;F<@24U34"!#;VYN96-T:6]N+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U])3D9/*3L*("`@
M("`@("`D8V]M;6%N9%]S=')I;F<@/2`G3$]'3U54)SL*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/FEM<W!396YD*"1C;VUM86YD7W-T<FEN9RD["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!F8VQO<V4H)'1H:7,M/E]S=')E86TI.PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F8VQO
M<V4H)'1H:7,M/E]S=')E86TI.PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!R
M87<@8V%P86)I;&ET>2!R97-P;VYS92!F<F]M('1H92!S97)V97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R87<@8V%P86)I;&ET>2!R
M97-P;VYS92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V%P86)I;&ET>2@I"B`@
M("!["B`@("`@("`@)&-O;6UA;F1?<W1R:6YG(#T@)T-!4$%"24Q)5%DG.PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^:6US<%-E;F0H)&-O;6UA;F1?<W1R
M:6YG*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^:6US
M<%)E8V5I=F4H*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>7"H@
M0T%004))3$E462\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@("`@("`@
M("`@("`@)&-A<&%B:6QI='D@/2!P<F5G7W)E<&QA8V4H(B]>7"H@0T%004))
M3$E462\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R<L("1S97)V97)?<F5S<&]N<V4I.PH*("`@("`@("`@("`@("`@
M("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^:6US<%)E8V5I=F4H*3L@+R]/
M2PH*("`@("`@("`@("`@("`@(&EF("@A)'-E<G9E<E]R97-P;VYS92`]/2`G
M3TLG*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI;7-P
M17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@
M9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G=R:71E5&],;V<H)T-!4$%"24Q)5%D@8V]M<&QE=&5D($]+)RP@7U]&24Q%
M7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],
M24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D8V%P86)I;&ET>3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(&]P96X@86X@24U34"!S;V-K970@=VET:"!T:&4@<V5R=F5R+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!014%2
M7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM<W!/
M<&5N*"D*("`@('L*("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1T:&ES+3YI
M;7-P7W-E<G9E<BP@)'1H:7,M/FEM<W!?<&]R="D["B`@("`@("`@:68@*"$D
M9G`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI;7-P17)R;W(H)T-O
M;FYE8W1I;VX@=&\@24U34"!H;W-T(&9A:6QE9"XG+"!?7T9)3$5?7RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@
M("`@("`@('T*("`@("`@("`D=&AI<RT^7W-T<F5A;2`]("1F<#L*("`@("`@
M("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/FEM<W!296-E:79E*"D["B`@
M("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPJ($]++R(L("1S97)V97)?<F5S
M<&]N<V4I*2!["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H
M92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!S96YD(&$@8V]M
M;6%N9"!T;R!T:&4@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("1C;VUM86YD5&5X="!497AT('1O('-E;F0@=&\@=&AE('-E<G9E<BX*
M("`@("`J($!P87)A;2!B;V]L96%N("1I;F-L=61E5&%G("!$971E<FUI;F5S
M(&EF(&-O;6UA;F0@=&%G(&ES('!R97!E;F1E9"X*("`@("`J($!P87)A;2!B
M;V]L96%N("`D<V5N9$-23$8@("!$971E<FUI;F5S(&EF($-23$8@:7,@87!P
M96YD960N"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@5')U92!O;B!S=6-C97-S
M(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M:6US<%-E;F0H)&-O;6UA;F1497AT+"`D:6YC;'5D951A9SUT<G5E+"`D<V5N
M9$-23$8]=')U92D*("`@('L*("`@("`@("`D8V]M;6%N9%]T97AT(#T@)R<[
M"@H@("`@("`@(&EF("@A)'1H:7,M/E]S=')E86TI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@24U34"!H
M;W-T(&9A:6QE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1I;F-L=61E5&%G*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?=&%G(#T@)'1H:7,M/E]G971.97AT0V]M;6%N9%1A9R@I.PH@("`@("`@
M("`@("`D8V]M;6%N9%]T97AT(#T@(B1T:&ES+3Y?=&%G("(["B`@("`@("`@
M?0H*("`@("`@("`D8V]M;6%N9%]T97AT("X]("1C;VUM86YD5&5X=#L*"B`@
M("`@("`@:68@*"1S96YD0U),1BD@>PH@("`@("`@("`@("`D8V]M;6%N9%]T
M97AT("X](")<<EQN(CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YW<FET
M951O3&]G*"=4;SH@)R`N("1C;VUM86YD7W1E>'0L(%]?1DE,15]?+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@(&EF("@A9G!U=',H)'1H:7,M/E]S=')E86TL("1C;VUM
M86YD7W1E>'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6US<$5R
M<F]R*"=#;VYN96-T:6]N('1O($E-4U`@:&]S="!F86EL960N)RP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96-E:79E<R!A('-I;F=L92!#4DQ&('1E<FUI;F%T960@<V5R=F5R(')E<W!O
M;G-E('-T<FEN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@)TY/)RP@
M)T)!1"<L("=/2R<L(')A=R!R97-P;VYS92!O<B!014%27T5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I;7-P4F5C96EV92@I"B`@("!["B`@("`@("`@
M:68@*"$D=&AI<RT^7W-T<F5A;2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/FEM<W!%<G)O<B@G0V]N;F5C=&EO;B!T;R!)35-0(&AO<W0@9F%I;&5D
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("1R
M97-U;'0@/2!F9V5T<R@D=&AI<RT^7W-T<F5A;2P@-3$R*3L*("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI;7-P
M17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@
M9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@
M("`@("1M971A(#T@<W1R96%M7V=E=%]M971A7V1A=&$H)'1H:7,M/E]S=')E
M86TI.PH@("`@("`@(&EF("@D;65T85LG=&EM961?;W5T)UTI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@
M24U34"!H;W-T(&9A:6QE9"XG("X@)SH@0V]N;F5C=&EO;B!T:6UE9"!O=70A
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1S97)V97)?<F5S
M<&]N<V4@/2!T<FEM*"1R97-U;'0I.PH@("`@("`@("1T:&ES+3YW<FET951O
M3&]G*"=&<F]M.B`G("X@)'-E<G9E<E]R97-P;VYS92P@7U]&24Q%7U\L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*"B`@("`@("`@+RH@4&%R<V4@;W5T('1H92!R97-P;VYS93H*("`@
M("`@("`@*B!&:7)S="!M86ME('-U<F4@=&AA="!T:&ES(&ES(&YO="!F;W(@
M82!P<F5V:6]U<R!C;VUM86YD+@H@("`@("`@("`J($EF(&ET(&ES+"!I="!M
M96%N<R!W92!D:60@;F]T(')E860@86QL('1H92!S97)V97(@<F5S<&]N<V5S
M(&9R;VT*("`@("`@("`@*B!T:&4@;&%S="!C;VUM86YD+BXN<F5A9"!T:&5M
M(&YO=RP@8G5T('1H<F]W(&%N(&5R<F]R+B`J+PH@("`@("`@('=H:6QE("AP
M<F5G7VUA=&-H*"(O7B(@+B`D=&AI<RT^7VQA<W1#;VUM86YD5&%G"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B(O(BP@)'-E<G9E<E]R97-P;VYS92DI
M('L*("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]"B`@("`@("`@("`@
M("`@("!T<FEM*&9G971S*"1T:&ES+3Y?<W1R96%M+"`U,3(I*3L*("`@("`@
M("`@("`@)'1H:7,M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E
M>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)R`N("(Z("1S97)V
M97)?<F5S<&]N<V4B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D8W5R<F5N
M=%1A9R`]("1T:&ES+3Y?=&%G.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O
M7B(@+B`D8W5R<F5N=%1A9R`N("(@3D\O(BP@)'-E<G9E<E]R97-P;VYS92DI
M('L*("`@("`@("`@("`@)'1H:7,M/FQA<W1287=%<G)O<B`]("1S97)V97)?
M<F5S<&]N<V4["B`@("`@("`@("`@(')E='5R;B`G3D\G.PH@("`@("`@('T*
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>(B`N("1C=7)R96YT5&%G("X@
M(B!"040O(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@)'1H
M:7,M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD97)S
M=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@)'1H:7,M/FQA<W1287=%<G)O<B`]("1S97)V97)?<F5S<&]N
M<V4["B`@("`@("`@("`@(')E='5R;B`G0D%$)SL*("`@("`@("!]"@H@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"(O7B(@+B`D8W5R<F5N=%1A9R`N("(@3TLO
M(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@<F5T=7)N("=/
M2R<["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!I="!W87,@;F]T(&$@)TY/
M)RP@)T)!1"<@;W(@)T]+)R!R97-P;VYS92P*("`@("`@("`@*B!T:&5N(&ET
M)W,@=7`@=&\@=&AE(&-A;&QI;F<@9G5N8W1I;VX@=&\@9&5C:61E"B`@("`@
M("`@("H@=VAA="!T;R!D;R!W:71H(&ET+B`J+PH@("`@("`@(')E='5R;B`D
M<V5R=F5R7W)E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE
M=F5S($-23$8@=&5R;6EN871E9"!R97-P;VYS92!F<F]M('-E<G9E<B!A;F0@
M<W!L:71S(&ET(&EN=&\*("`@("`J(&%N(&%R<F%Y(&1E;&EM:71E9"!B>2!A
M(#QS<&%C93XN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!R97-U;'0@
M9G)O;2!E>'!L;V1E*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<G9E
M<E)E<W!O;G-E0VAU;FMS*"D*("`@('L*("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T*("`@("`@("`@("`@=')I;2AF9V5T<R@D=&AI<RT^7W-T<F5A;2P@
M-3$R*2D["B`@("`@("`@)&-H=6YK<R`](&5X<&QO9&4H)R`G+"`D<V5R=F5R
M7W)E<W!O;G-E*3L*("`@("`@("!R971U<FX@)&-H=6YK<SL*("`@('T*"B`@
M("`O*@H@("`@("H@4F5C96EV97,@9FEX960@;G5M8F5R(&]F(&)Y=&5S(&9R
M;VT@24U34"!S;V-K970N(%5S960@=VAE;@H@("`@("H@<V5R=F5R(')E='5R
M;G,@82!S=')I;F<@;&ET97)A;"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D;&5N9W1H("!.=6UB97(@;V8@8GET97,@=&\@<F5A9"!F<F]M('-O
M8VME="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&5X="!O9B!S
M=')I;F<@;&ET97)A;"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5C96EV95-T
M<FEN9TQI=&5R86PH)&QE;F=T:"D*("`@('L*("`@("`@("`D=&5M<"`]('1R
M:6TH9G)E860H)'1H:7,M/E]S=')E86TL("1L96YG=&@I*3L*("`@("`@("`D
M=&AI<RT^=W)I=&54;TQO9R@G1G)O;7M].B`G("X@)'1E;7`L(%]?1DE,15]?
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["B`@("`@("`@<F5T=7)N("1T96UP.PH@("`@?0H*("`@("\J
M*@H@("`@("H@26YC<F5M96YT<R!T:&4@24U34"!C;VUM86YD('1A9R!T;VME
M;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!R971U
M<FX@<W1R:6YG($YE>'0@8V]M;6%N9"!T86<N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G971.97AT0V]M;6%N9%1A9R@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]L87-T0V]M;6%N9%1A9R`]("1T:&ES+3Y?=&%G(#\@)'1H:7,M/E]T86<@
M.B`G=6YD969I;F5D)SL*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VUM86YD
M4')E9FEX("X@<W!R:6YT9B@G)3`T9"<L("1T:&ES+3Y?8V]M;6%N9$-O=6YT
M*RLI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!A('-T
M<FEN9R!N965D<R!T;R!B92!Q=6]T960@8F5F;W)E('-E;F1I;F<@=&\@=&AE
M('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@
M(%-T<FEN9R!T;R!B92!T97-T960N"B`@("`@*B!`<F5T=7)N('-T<FEN9R!/
M<FEG:6YA;"!S=')I;F<@<75O=&5D(&EF(&YE961E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<75O=&53<&%C9613=')I;F<H)'-T<FEN9RD*("`@('L*("`@
M("`@("!I9B`H<W1R<&]S*"1S=')I;F<L("<@)RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B`G(B<@+B`D<W1R:6YG("X@)R(G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)A:7-E<R!A;B!)35-0(&5R<F]R
M+B`@0F%S:6-A;&QY+"!O;FQY('=R:71E<PH@("`@("H@97)R;W(@;W5T('1O
M('1H92!H;W)D92!L;V=F:6QE(&%N9"!R971U<FYS(%!%05)?17)R;W(*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G(@("`@16ET:&5R(%!%05)?
M17)R;W(@;V)J96-T(&]R('1E>'0@=&\@=W)I=&4@=&\@;&]G+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9FEL92`@($9I;&4@;F%M92!W:&5R92!E<G)O<B!O
M8V-U<F5D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;F4@($QI;F4@;G5M
M8F5R('=H97)E(&5R<F]R(&]C8W5R960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&EM<W!%<G)O<B@D97)R(#T@)R<L("1F:6QE/5]?1DE,15]?+"`D;&EN93U?
M7TQ)3D5?7RD*("`@('L*("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1L;V=?=&5X="`]("1E<G(M/F=E=$UE
M<W-A9V4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&]G7W1E
M>'0@/2`D97)R.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G=R:71E5&],
M;V<H)&QO9U]T97AT+"`D9FEL92P@)&QI;F4L(%!%05)?3$]'7T524BD["B`@
M("`@("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&5R<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!7<FET97,@82!M97-S86=E('1O('1H92!)
M35-0(&QO9V9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S
M<V%G92`@5&5X="!T;R!W<FET92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I
M=&54;TQO9R@D;65S<V%G92P@)&9I;&4@/2!?7T9)3$5?7RP*("`@("`@("`@
M("`@("`@("`@("`@("`@)&QI;F4@/2!?7TQ)3D5?7RP@)'!R:6]R:71Y(#T@
M4$5!4E],3T=?24Y&3RD*("`@('L*("`@("`@("!I9B`H*"1T:&ES+3YL;V=%
M;F%B;&5D*2`F)B`H)'1H:7,M/E]L;V=3970I*2!["B`@("`@("`@("`@(&EF
M("@D<')I;W)I='D@/B`D=&AI<RT^7VQO9TQE=F5L*2!["B`@("`@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1L;V=-
M97-S86=E(#T@)UMI;7-P72`G("X@)&UE<W-A9V4@+B`G(%MO;B!L:6YE("<@
M+B`D;&EN92`N("<@;V8@(B<@+B`D9FEL92`N("<B72<["B`@("`@("`@("`@
M("1T:&ES+3Y?;&]G9V5R+3YL;V<H)&QO9TUE<W-A9V4L("1P<FEO<FET>2D[
M"B`@("`@("`@?2!E;'-E:68@*"@A)'1H:7,M/E]L;V=3970I("8F("@D=&AI
M<RT^;&]G16YA8FQE9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]L;V="=69F
M97);72`](&%R<F%Y*"=M97-S86=E)R`@/3X@)&UE<W-A9V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<')I;W)I='DG(#T^
M("1P<FEO<FET>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=F:6QE)R`@("`@/3X@)&9I;&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;&EN92<@("`@(#T^("1L:6YE"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@3&]G
M(&]B:F5C="!B87-E9"!O;B`D<&%R86US"B`@("`@*@H@("`@("H@0'!A<F%M
M("!A<G)A>2`@)'!A<F%M<R!,;V<@;V)J96-T('!A<F%M971E<G,N"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V=G97(H
M)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7VQO9TQE=F5L(#T@)'!A
M<F%M<ULG<')I;W)I='DG73L*("`@("`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN
M9VQE=&]N*"1P87)A;7-;)W1Y<&4G72P@)'!A<F%M<ULG;F%M92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULG:61E;G0G
M72P@)'!A<F%M<ULG<&%R86US)UTI.PH@("`@("`@("1T:&ES+3Y?;&]G4V5T
M(#T@=')U93L*"B`@("`@("`@:68@*&ES7V$H)&QO9V=E<BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G16YA8FQE9"`](&9A;'-E
M.PH@("`@("`@("`@("!R971U<FX@)&QO9V=E<CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G9V5R.PH@("`@
M("`@("`@("`D=&AI<RT^;&]G16YA8FQE9"`]('1R=64["B`@("`@("`@("`@
M("1T:&ES+3Y?=W)I=&5,;V="=69F97(H*3L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&5S
M(&]U="!C;VYT96YT<R!O9B`D7VQO9T)U9F9E<B!T;R!L;V<@9FEL92X@($%L
M;&]W<R!M97-S86=E<PH@("`@("H@=&\@8F4@;&]G9V5D(&1U<FEN9R!I;FET
M:6%L:7IA=&EO;B!O9B!O8FIE8W0@8F5F;W)E($QO9R!O8FIE8W0@:7,*("`@
M("`J(&EN<W1A;G1I871E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W=R:71E3&]G0G5F9F5R*"D*("`@
M('L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7VQO
M9T)U9F9E<BD[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M/G=R:71E5&],
M;V<H)'1H:7,M/E]L;V="=69F97);)&E=6R=M97-S86=E)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]G0G5F9F5R6R1I75LG
M9FEL92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQO9T)U9F9E<ELD:5U;)VQI;F4G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]L;V="=69F97);)&E=6R=P<FEO<FET>2==*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!C
M<F5A=&4@82!.971?24U34"!O8FIE8W0@8F%S960@;VX@)&1R:79E<BX*("`@
M("`J($UU<W0@8F4@8V%L;&5D(&%S("1I;7-P(#T@)DYE=%])35-0.CIF86-T
M;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("H*("`@("`J($!P87)A;2`@
M<W1R:6YG("1D<FEV97(@5'EP92!O9B!.971?24U34"!O8FIE8W0@=&\@<F5T
M=7)N+@H@("`@("H@0'!A<F%M("!M:7AE9"`@)'!A<F%M<R`@06YY('!A<F%M
M971E<G,@;F5E9&5D(&)Y('1H92!.971?24U34"!O8FIE8W0N"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@<F5Q=65S=&5D($YE=%])35-0(&]B:F5C="!O
M<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,I"B`@("!["B`@("`@("`@)&1R
M:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH@("`@("`@(&EF("AE;7!T>2@D
M9')I=F5R*2!\?"`D9')I=F5R(#T]("=N;VYE)RD@>PH@("`@("`@("`@("`D
M:6US<"`]("9N97<@3F5T7TE-4U`H)'!A<F%M<RD["B`@("`@("`@("`@(')E
M='5R;B`D:6US<#L*("`@("`@("!]"@H@("`@("`@(&EN8VQU9&5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O24U34"\G("X@)&1R:79E<B`N("<N<&AP
M)SL*("`@("`@("`D8VQA<W,@/2`G3F5T7TE-4U!?)R`N("1D<FEV97(["B`@
M("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@
M("1I;7-P(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@("`@(')E
M='5R;B`D:6US<#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D
M93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(I+"`D8VQA<W,I*2P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!.971?24U34"!O8FIE8W0@8F%S
M960@;VX@)&1R:79E<BX@($]N;'D*("`@("`J(&-R96%T97,@82!N97<@;V)J
M96-T(&EF(&]N92!W:71H('1H92!S86UE('!A<F%M971E<G,@86QR96%D>0H@
M("`@("H@9&]E<VXG="!E>&ES="X*("`@("`J($UU<W0@8F4@8V%L;&5D(&%S
M("1I;7-P(#T@)DYE=%])35-0.CIS:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M
M<RD["B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&1R:79E<B!4>7!E
M(&]F($YE=%])35-0(&]B:F5C="!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@
M(&UI>&5D("`D<&%R86US($%N>2!P87)A;65T97)S(&YE961E9"!B>2!T:&4@
M3F5T7TE-4U`@;V)J96-T+@H@("`@("H@0')E='5R;B!M:7AE9"`@4F5F97)E
M;F-E('1O('1H92!.971?24U34"!O8FIE8W0@;W(@4$5!4E]%<G)O<B!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV
M97(L("1P87)A;7,I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,[
M"B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@
M("`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S
M:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI
M.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI
M('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9.971?
M24U34#HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+U--4RYP
M:'``````````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#(U,C$T`#$P-#$W,S8R-S<U`#`Q-S$P,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["@HO*BH*("H@3F5T7U--4R!#;&%S<PH@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?4TU3+U--
M4RYP:'`L=B`Q+C$P+C$P+C$P(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X
M<"`D"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J($!P86-K86=E($YE=%]335,*("HO"F-L87-S($YE=%]335,@>PH*
M("`@("\J*@H@("`@("H@02!H87-H(&-O;G1A:6YI;F<@86YY('!A<F%M971E
M<G,@9F]R('1H92!C=7)R96YT(&=A=&5W87D@9')I=F5R+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R
M87DH*3L*"B`@("!V87(@)%]A=71H(#T@;G5L;#L*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($%N>2!P87)A;65T97)S(&YE961E9"!F;W(@=&AI<R!G871E=V%Y(&1R
M:79E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@3F5T7U--4R@D<&%R86US(#T@
M;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!A=F%I
M;&%B;&4@9V%T97=A>2!D<FEV97)S+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(&%R<F%Y(&]F(&%V86EL86)L92!D<FEV97)S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971$<FEV97)S*"D*("`@('L*("`@("`@("!S=&%T
M:6,@)&1R:79E<G,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A96UP='DH)&1R
M:79E<G,I*2!["B`@("`@("`@("`@(')E='5R;B`D9')I=F5R<SL*("`@("`@
M("!]"@H@("`@("`@("1D<FEV97)S(#T@87)R87DH*3L*"B`@("`@("`@:68@
M*"1D<FEV97)?9&ER(#T@;W!E;F1I<BAD:7)N86UE*%]?1DE,15]?*2`N("<O
M4TU3+R<I*2!["B`@("`@("`@("`@('=H:6QE("AF86QS92`A/3T@*"1F:6QE
M(#T@<F5A9&1I<B@D9')I=F5R7V1I<BDI*2!["B`@("`@("`@("`@("`@("`O
M*B!(:61E(&1O="!F:6QE<R!A;F0@;F]N("YP:'`@9FEL97,N("HO"B`@("`@
M("`@("`@("`@("!I9B`H<W5B<W1R*"1F:6QE+"`P+"`Q*2`A/2`G+B<@)B8@
M<W5B<W1R*"1F:6QE+"`M-"D@/3T@)RYP:'`G*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1R:79E<B`]('-U8G-T<B@D9FEL92P@,"P@+30I.PH@("`@("`@
M("`@("`@("`@("`@("1D<FEV97)?:6YF;R`]($YE=%]335,Z.F=E=$=A=&5W
M87E);F9O*"1D<FEV97(I.PH@("`@("`@("`@("`@("`@("`@("1D<FEV97)S
M6R1D<FEV97)=(#T@)&1R:79E<E]I;F9O6R=N86UE)UT["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V5D:7(H)&1R
M:79E<E]D:7(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D<FEV97)S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!O
M;B!A(&=A=&5W87DL('-U8V@@87,@;F%M92!A;F0@82!B<FEE9B!D97-C<FEP
M=&EO;BP*("`@("`J(&9R;VT@=&AE(&1R:79E<B!S=6)C;&%S<R!G971);F9O
M*"D@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@;V8@97AT<F$@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$=A=&5W87E);F9O*"1G871E=V%Y*0H@("`@>PH@("`@("`@('-T
M871I8R`D:6YF;R`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES<V5T*"1I;F9O
M6R1G871E=V%Y72DI('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O6R1G871E
M=V%Y73L*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G3F5T+U--
M4R\G("X@)&=A=&5W87D@+B`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)TYE
M=%]335-?)R`N("1G871E=V%Y.PH@("`@("`@("1I;F9O6R1G871E=V%Y72`]
M(&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1C;&%S<RP@)V=E=$EN9F\G*2D["@H@
M("`@("`@(')E='5R;B`D:6YF;ULD9V%T97=A>5T["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('!A<F%M971E<G,@9F]R(&$@9V%T97=A>2!F<F]M
M('1H92!D<FEV97(@<W5B8VQA<W,@9V5T4&%R86US*"D*("`@("`J(&9U;F-T
M:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@(%1H92!N86UE(&]F
M('1H92!G871E=V%Y(&1R:79E<B!F;W(@=VAI8V@@=&\@<F5T=7)N('1H90H@
M("`@("H@("`@("`@("`@("`@("`@<&%R86UE=&5R<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!E>'1R82!I;F9O<FUA=&EO
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1V%T97=A>5!A<F%M<R@D9V%T
M97=A>2D*("`@('L*("`@("`@("!S=&%T:6,@)'!A<F%M<R`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)&=A=&5W87E=*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'!A<F%M<ULD9V%T97=A>5T["B`@("`@("`@?0H*
M("`@("`@("!R97%U:7)E7V]N8V4@)TYE="]335,O)R`N("1G871E=V%Y("X@
M)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=.971?4TU37R<@+B`D9V%T97=A
M>3L*("`@("`@("`D<&%R86US6R1G871E=V%Y72`](&-A;&Q?=7-E<E]F=6YC
M*&%R<F%Y*"1C;&%S<RP@)V=E=%!A<F%M<R<I*3L*"B`@("`@("`@<F5T=7)N
M("1P87)A;7-;)&=A=&5W87E=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!S96YD('!A<F%M971E<G,@9F]R(&$@9V%T97=A>2!F<F]M('1H92!D
M<FEV97(@<W5B8VQA<W,*("`@("`J(&=E=$1E9F%U;'1396YD4&%R86US*"EF
M=6YC=&EO;BX@5&AE<V4@87)E('!A<F%M971E<G,@=VAI8V@@87)E(&%V86EL
M86)L90H@("`@("H@=&\@=&AE('5S97(@9'5R:6YG('-E;F1I;F<L('-U8V@@
M87,@<V5T=&EN9R!A('1I;64@9F]R(&1E;&EV97)Y+"!O<B!T>7!E"B`@("`@
M*B!O9B!335,@*&YO<FUA;"!T97AT(&]R(&9L87-H*2P@;W(@<V]U<F-E(&%D
M9')E<W,L(&5T8RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!4:&4@
M;F%M92!O9B!T:&4@9V%T97=A>2!D<FEV97(@9F]R('=H:6-H('1O(')E='5R
M;B!T:&4*("`@("`J("`@("`@("`@("`@("`@('-E;F0@<&%R86UE=&5R<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I
M;&%B;&4@<V5N9"!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971$969A=6QT4V5N9%!A<F%M<R@D9V%T97=A>2D*("`@('L*("`@("`@("!S
M=&%T:6,@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)&=A=&5W87E=*2D@>PH@("`@("`@("`@("!R971U<FX@)'!A<F%M
M<ULD9V%T97=A>5T["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@
M)TYE="]335,O)R`N("1G871E=V%Y("X@)RYP:'`G.PH@("`@("`@("1C;&%S
M<R`]("=.971?4TU37R<@+B`D9V%T97=A>3L*("`@("`@("`D<&%R86US6R1G
M871E=V%Y72`](&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1C;&%S<RP@)V=E=$1E
M9F%U;'1396YD4&%R86US)RDI.PH*("`@("`@("!R971U<FX@)'!A<F%M<ULD
M9V%T97=A>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=65R>2!T:&4@8W5R
M<F5N="!'871E=V%Y(&]B:F5C="!T;R!F:6YD(&]U="!I9B!I="!S=7!P;W)T
M<R!T:&4@9VEV96X*("`@("`J(&-A<&%B:6QI='DN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V%P86)I;&ET>2`@5&AE(&-A<&%B:6QI='D@=&\@
M=&5S="!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5VAE=&AE
M<B!O<B!N;W0@=&AE(&-A<&%B:6QI='D@:7,@<W5P<&]R=&5D(&]R(&%N>2!O
M=&AE<@H@("`@("H@("`@("`@("`@("`@("`@=F%L=64@=&AA="!T:&4@8V%P
M86)I;&ET>2!W:7-H97,@=&\@<F5P;W)T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!H87-#87!A8FEL:71Y*"1C87!A8FEL:71Y*0H@("`@>PH@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/F-A<&%B:6QI=&EE<ULD8V%P86)I;&ET>5TI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8V%P86)I;&ET:65S6R1C87!A
M8FEL:71Y73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@075T:&5N=&EC871E<R!A9V%I;G-T('1H92!G
M871E=V%Y(&EF(')E<75I<F5D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&AE;G1I8V%T92@I"B`@("!["B`@
M("`@("`@+RH@1&\@875T:&5N=&EC871I;VX@9F]R('1H:7,@9V%T97=A>2!I
M9B!D<FEV97(@<F5Q=6ER97,@:70N("HO"B`@("`@("`@:68@*"1T:&ES+3YH
M87-#87!A8FEL:71Y*"=A=71H)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]A
M=71H(#T@)'1H:7,M/E]A=71H96YT:6-A=&4H*3L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?875T:#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD<R!A(&UE<W-A9V4@=&\@
M;VYE(&]R(&UO<F4@<F5C:7!I96YT<RX@2&%N9',@;V9F('1H92!A8W1U86P@
M<V5N9&EN9PH@("`@("H@=&\@=&AE(&=A=&5W87D@9')I=F5R+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@5&AE(&UE<W-A9V4@=&\@
M8F4@<V5N="P@=VAI8V@@:7,@8V]M<&]S960@;V8Z"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(#QP<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@:60@("`M($$@=6YI<75E($E$(&9O<B!T:&4@;65S<V%G93L*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T;R`@("T@06X@87)R
M87D@;V8@<F5C:7!I96YT<SL*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!T97AT("T@5&AE('1E>'0@;V8@=&AE(&UE<W-A9V4["B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO<')E/@H@("`@("H*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!4B!%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S96YD*"8D
M;65S<V%G92D*("`@('L*("`@("`@("`O*B!!=71H96YT:6-A=&4N("HO"B`@
M("`@("`@:68@*&ES7V$H)'1H:7,M/F%U=&AE;G1I8V%T92@I+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%U=&@["B`@
M("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=&AE(')E8VEP:65N=',@
M87)E(&EN(&%N(&%R<F%Y+B`J+PH@("`@("`@(&EF("@A:7-?87)R87DH)&UE
M<W-A9V5;)W1O)UTI*2!["B`@("`@("`@("`@("1M97-S86=E6R=T;R==(#T@
M87)R87DH)&UE<W-A9V5;)W1O)UTI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M07)R87D@=&\@<W1O<F4@96%C:"!S96YD+B`J+PH@("`@("`@("1S96YD<R`]
M(&%R<F%Y*"D["@H@("`@("`@("\J($EF(&=A=&5W87D@<W5P<&]R=',@8F%T
M8V@@<V5N9&EN9RP@<')E9F5R96YC92!I<R!G:79E;B!T;R!T:&ES"B`@("`@
M("`@("H@;65T:&]D+B`J+PH@("`@("`@(&EF("@D;6%X7W!E<E]B871C:"`]
M("1T:&ES+3YH87-#87!A8FEL:71Y*"=B871C:"<I*2!["B`@("`@("`@("`@
M("\J(%-P;&ET('5P('1H92!R96-I<&EE;G1S(&EN('1H92!M87@@<F5C:7!I
M96YT<R!P97(@8F%T8V@@87,*("`@("`@("`@("`@("H@<W5P<&]R=&5D(&)Y
M(&=A=&5W87DN("HO"B`@("`@("`@("`@("1I36%X(#T@8V]U;G0H)&UE<W-A
M9V5;)W1O)UTI.PH@("`@("`@("`@("`D8F%T8VAE<R`](&-E:6PH)&E-87@@
M+R`D;6%X7W!E<E]B871C:"D["@H@("`@("`@("`@("`O*B!,;V]P('1H<F]U
M9V@@=&AE(&)A=&-H97,@86YD(&-O;7!O<V4@;65S<V%G97,@=&\@8F4@<V5N
M="X@*B\*("`@("`@("`@("`@9F]R("@D8B`](#`[("1B(#P@)&)A=&-H97,[
M("1B*RLI('L*("`@("`@("`@("`@("`@("1R96-I<&EE;G1S(#T@87)R87E?
M<VQI8V4H)&UE<W-A9V5;)W1O)UTL("@D8B`J("1M87A?<&5R7V)A=&-H*2P@
M)&UA>%]P97)?8F%T8V@I.PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@
M)'1H:7,M/E]S96YD*"1M97-S86=E+"`D<F5C:7!I96YT<RD["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D<F5C:7!I96YT<R!A<R`D<F5C:7!I96YT*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1R97-P;VYS95LD<F5C:7!I96YT
M75LP72`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J($UE<W-A
M9V4@=V%S('-E;G0L('-T;W)E(')E;6]T92!I9"X@*B\*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E;6]T95]I9"`]("1R97-P;VYS95LD<F5C:7!I96YT
M75LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R(#T@;G5L;#L*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`O*B!-97-S86=E(&9A:6QE9"P@<W1O<F4@97)R;W(@8V]D92X@
M*B\*("`@("`@("`@("`@("`@("`@("`@("`@)')E;6]T95]I9"`](&YU;&P[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<B`]("1R97-P;VYS95LD
M<F5C:7!I96YT75LQ73L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("\J(%-T;W)E('1H92!S96YD<RX@*B\*("`@("`@("`@
M("`@("`@("`@("`D<V5N9'-;72`](&%R<F%Y*"=M97-S86=E7VED)R`]/B`D
M;65S<V%G95LG:60G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R96UO=&5?:60G("`]/B`D<F5M;W1E7VED+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E8VEP:65N="<@(#T^("1R
M96-I<&EE;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G97)R;W(G("`@("`@/3X@)&5R<F]R*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J
M($YO(&)A=&-H('-E;F1I;F<@879A:6QA8FQE+"!J=7-T(&QO;W`@=&AR;W5G
M:"!A;&P@<F5C:7!I96YT<PH@("`@("`@("`@("`@*B!A;F0@<V5N9"!A(&UE
M<W-A9V4@9F]R(&5A8V@@;VYE+B`J+PH@("`@("`@("`@("!F;W)E86-H("@D
M;65S<V%G95LG=&\G72!A<R`D<F5C:7!I96YT*2!["B`@("`@("`@("`@("`@
M("`D<F5S<&]N<V4@/2`D=&AI<RT^7W-E;F0H)&UE<W-A9V4L("1R96-I<&EE
M;G0I.PH@("`@("`@("`@("`@("`@:68@*"1R97-P;VYS95LP72`]/2`Q*2![
M"B`@("`@("`@("`@("`@("`@("`@+RH@365S<V%G92!W87,@<V5N="P@<W1O
M<F4@<F5M;W1E(&ED(&EF(&%N>2X@*B\*("`@("`@("`@("`@("`@("`@("`D
M<F5M;W1E7VED(#T@*&ES<V5T*"1R97-P;VYS95LQ72D@/R`D<F5S<&]N<V5;
M,5T@.B!N=6QL*3L*("`@("`@("`@("`@("`@("`@("`D97)R;W(@/2!N=6QL
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`O*B!-97-S86=E(&9A:6QE9"P@<W1O<F4@97)R;W(@8V]D92X@*B\*("`@
M("`@("`@("`@("`@("`@("`D<F5M;W1E7VED(#T@;G5L;#L*("`@("`@("`@
M("`@("`@("`@("`D97)R;W(@/2`D<F5S<&]N<V5;,5T["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@+RH@4W1O<F4@=&AE('-E;F1S+B`J
M+PH@("`@("`@("`@("`@("`@)'-E;F1S6UT@/2!A<G)A>2@G;65S<V%G95]I
M9"<@/3X@)&UE<W-A9V5;)VED)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=R96UO=&5?:60G("`]/B`D<F5M;W1E7VED+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5C:7!I96YT)R`@/3X@)')E
M8VEP:65N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5R
M<F]R)R`@("`@(#T^("1E<G)O<BD["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<V5N9',["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!)9B!T:&4@8W5R<F5N="!D<FEV97(@:&%S(&$@8W)E9&ET(&-A<&%B:6QI
M='DL('%U97)I97,@=&AE(&=A=&5W87D@9F]R"B`@("`@*B!A(&-R961I="!B
M86QA;F-E(&%N9"!R971U<FYS('1H92!V86QU92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@(%9A;'5E(&EN9&EC871I;F<@879A:6QA8FQE(&-R
M961I="!O<B!N=6QL(&EF(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("!S
M=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)A;&%N8V4H*0H@
M("`@>PH@("`@("`@("\J($%U=&AE;G1I8V%T92X@*B\*("`@("`@("!I9B`H
M:7-?82@D=&AI<RT^875T:&5N=&EC871E*"DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?875T:#L*("`@("`@("!]"@H@
M("`@("`@("\J($-H96-K(&)A;&%N8V4N("HO"B`@("`@("`@:68@*"1T:&ES
M+3YH87-#87!A8FEL:71Y*"=C<F5D:70G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]G971"86QA;F-E*"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@1V%T97=A
M>2!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@1V%T
M97=A>2!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(%1H:7,@:7,@8F%S960@;VX@=&AE(&=A=&5W87D@9')I=F5R
M("@D9')I=F5R*2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@5&AE
M(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@
M;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($YE=%]335,@(%1H92!N97=L
M>2!C<F5A=&5D(&-O;F-R971E($=A=&5W87D@:6YS=&%N8V4@;W(@9F%L<V4@
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@86X@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`G3F5T+U--4R\G("X@
M)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G3F5T7U--4U\G
M("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI
M('L*("`@("`@("`@("`@)'-M<R`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S;7,@/2!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N(BDL("1D<FEV97(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<VUS.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@3F5T7U--4R!I;G-T86YC
M92!B87-E9"!O;@H@("`@("H@)&1R:79E<BX*("`@("`J"B`@("`@*B!)="!W
M:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($YE=%]335,@
M:6YS=&%N8V4@=VET:"!T:&4@<V%M90H@("`@("H@<&%R86UE=&5R<R!C=7)R
M96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@
M8F4@:6YV;VME9"!A<SH@)'9A<B`]("9.971?4TU3.CIS:6YG;&5T;VXH*0H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@
M;V8@8V]N8W)E=&4@3F5T7U--4R!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(%1H92!I<R!B87-E9"!O;B!T:&4@
M9V%T97=A>2!D<FEV97(@*"1D<FEV97(I+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!4:&4@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O
M;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&-R96%T960@8V]N8W)E=&4@3F5T7U--4R!I;G-T86YC
M92P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S
M:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@<W1A=&EC("1I;G-T86YC97,["B`@("`@("`@:68@*"%I<W-E="@D
M:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H
M87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A
M;F-E<ULD<VEG;F%T=7)E72`]("9.971?4TU3.CIF86-T;W)Y*"1D<FEV97(L
M("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC
M97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K+P``````````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W-0`P,38R,S``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O0FQO8VLO
M86-C;W5N="YP:'``````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#0S-S$U`#$P-#$W,S8R-S<U`#`R,#0P-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*)&)L;V-K7VYA;64@
M/2!?*")!8V-O=6YT($EN9F]R;6%T:6]N(BD["@HO*BH*("H@)$AO<F1E.B!H
M;W)D92]L:6(O0FQO8VLO86-C;W5N="YP:'`L=B`Q+C<N,BXT(#(P,#8O,#,O
M,3`@,3<Z,C@Z-#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P
M,#8@17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E
M>&%S+F5D=3X*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'-I;F-E("`@
M2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(
M;W)D95]";&]C:U](;W)D95]A8V-O=6YT(&5X=&5N9',@2&]R9&5?0FQO8VL@
M>PH*("`@('9A<B`D7V%P<"`]("=H;W)D92<["@H@("`@+RHJ"B`@("`@*B!4
M:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")->2!!
M8V-O=6YT($EN9F]R;6%T:6]N(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:&4@8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GDL("1C;VYF.PH*("`@("`@("!S=VET8V@@*"1C;VYF6R=A8V-O=6YT<R==
M6R=D<FEV97(G72D@>PH@("`@("`@(&-A<V4@)VYU;&PG.@H@("`@("`@("`@
M("`D;7ED<FEV97(@/2`F;F5W($%C8V]U;G1S7T1R:79E<B@I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!C87-E("=L;V-A;&AO<W0G.@H@("`@("`@
M(&-A<V4@)VQD87`G.@H@("`@("`@("`@("`D8VQA<W,@/2`G06-C;W5N='-?
M1')I=F5R7R<@+B`D8V]N9ELG86-C;W5N=',G75LG9')I=F5R)UT["B`@("`@
M("`@("`@("1M>61R:79E<B`]("9N97<@)&-L87-S*"1C;VYF6R=A8V-O=6YT
M<R==6R=P87)A;7,G72D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@
M("`@("\O($-H96-K(&9O<B!P87-S=V]R9"!S=&%T=7,N"B`@("`@("`@:68@
M*&ES7V$H)'-T871U<R`]("1M>61R:79E<BT^8VAE8VM087-S=V]R9%-T871U
M<R@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1S=&%T=7,@/2`D
M<W1A='5S+3YG971-97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?82@D=7-E<FYA;64@/2`D;7ED<FEV97(M/F=E=%5S97)N86UE*"DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1U<V5R;F%M92T^
M9V5T365S<V%G92@I.PH@("`@("`@('T*("`@("`@("`D=&%B;&4@/2!A<G)A
M>2A?*"),;V=I;B(I(#T^("1U<V5R;F%M92D["B`@("`@("`@:68@*&ES7V$H
M)&9U;&QN86UE(#T@)&UY9')I=F5R+3YG971&=6QL;F%M92@I+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9G5L;&YA;64M/F=E=$UE
M<W-A9V4H*3L*("`@("`@("!](&5L<V5I9B`H)&9U;&QN86UE*2!["B`@("`@
M("`@("`@("1T86)L95M?*")&=6QL($YA;64B*5T@/2`D9G5L;&YA;64["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1H;VUE(#T@)&UY9')I=F5R+3YG
M971(;VUE*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1H;VUE+3YG971-97-S86=E*"D["B`@("`@("`@?2!E;'-E:68@*"1H;VUE
M*2!["B`@("`@("`@("`@("1T86)L95M?*")(;VUE($1I<F5C=&]R>2(I72`]
M("1H;VUE.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<VAE;&P@/2`D
M;7ED<FEV97(M/F=E=%-H96QL*"DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1S:&5L;"T^9V5T365S<V%G92@I.PH@("`@("`@('T@
M96QS96EF("@D<VAE;&PI('L*("`@("`@("`@("`@)'1A8FQE6U\H(D1E9F%U
M;'0@4VAE;&PB*5T@/2`D<VAE;&P["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<U]A*"1Q=6]T82`]("1M>61R:79E<BT^9V5T475O=&$H*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'%U;W1A+3YG971-97-S86=E
M*"D["B`@("`@("`@?2!E;'-E:68@*"1Q=6]T82D@>PH@("`@("`@("`@("`D
M=&%B;&5;7R@B475O=&$B*5T@/2!S<')I;G1F*%\H(B4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'%U;W1A6R=U<V5D)UT@+R`H(#$P
M,C0@*B`Q,#(T+C`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1Q=6]T85LG;&EM:70G72`O("@@,3`R-"`J(#$P,C0N,"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1Q
M=6]T85LG=7-E9"==("H@,3`P+C`I("\@)'%U;W1A6R=L:6UI="==*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES7V$H)&QA<W1C:&%N9V4@/2`D;7ED<FEV
M97(M/F=E=%!A<W-W;W)D0VAA;F=E*"DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1L87-T8VAA;F=E+3YG971-97-S86=E*"D["B`@
M("`@("`@?2!E;'-E:68@*"1L87-T8VAA;F=E*2!["B`@("`@("`@("`@("1T
M86)L95M?*"),87-T(%!A<W-W;W)D($-H86YG92(I72`]("1L87-T8VAA;F=E
M.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U="`]("<\=&%B;&4@8VQA<W,]
M(FET96TB('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,2(^)SL*"B`@("`@
M("`@:68@*"%E;7!T>2@D<W1A='5S*2D@>PH@("`@("`@("`@("`D;W5T<'5T
M("X]("<\='(^/'1D(&-O;'-P86X](C(B/CQP(&-L87-S/2)N;W1I8V4B/B<@
M+@H@("`@("`@("`@("`@("`@2&]R9&4Z.FEM9R@G86QE<G1S+W=A<FYI;F<N
M<&YG)RP@7R@B5V%R;FEN9R(I*2`N"B`@("`@("`@("`@("`@("`G)FYB<W`[
M)FYB<W`[)R`N("1S=&%T=7,@+B`G/"]P/CPO=&0^/"]T<CXG.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)'1A8FQE(&%S("1K97D@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("1O=71P=70@+CT@(CQT<B!C;&%S<SU<(G1E>'1<
M(CX\=&0^)&ME>3PO=&0^/'1D/B1V86QU93PO=&0^/"]T<CY<;B(["B`@("`@
M("`@?0H@("`@("`@("1O=71P=70@+CT@(CPO=&%B;&4^7&XB.PH*("`@("`@
M("!I9B`H)')E9VES=')Y+3YG970H)W-T871U<R<L("=F;W)W87)D<R<I("$]
M("=I;F%C=&EV92<@)B8*("`@("`@("`@("`@)')E9VES=')Y+3YH87--971H
M;V0H)W-U;6UA<GDG+"`G9F]R=V%R9',G*2D@>PH@("`@("`@("`@("`D<W5M
M;6%R>2`]("1R96=I<W1R>2T^8V%L;$)Y4&%C:V%G92@G9F]R=V%R9',G+"`G
M<W5M;6%R>2<I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)'-U;6UA<GDL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)SQB
M<B`O/B<@+B`D<W5M;6%R>2`N(")<;B(["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*"1R96=I<W1R>2T^9V5T*"=S=&%T=7,G+"`G=F%C
M871I;VXG*2`A/2`G:6YA8W1I=F4G("8F"B`@("`@("`@("`@("1R96=I<W1R
M>2T^:&%S365T:&]D*"=S=6UM87)Y)RP@)W9A8V%T:6]N)RDI('L*("`@("`@
M("`@("`@)'-U;6UA<GD@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)W9A
M8V%T:6]N)RP@)W-U;6UA<GDG*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1S
M=6UM87)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]("<\8G(@+SXG("X@)'-U;6UA<GD@+B`B7&XB.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*
M"GT*"B\J*@H@*B!!8V-O=6YT<U]$<FEV97(Z.B!D969I;F5S(&%N($%022!F
M;W(@9V5T=&EN9R]D:7-P;&%Y:6YG(&%C8V]U;G0@:6YF;W)M871I;VX*("H@
M9F]R(&$@=7-E<B!F;W(@=&AE(&%C8V]U;G1S(&UO9'5L92X*("H*("H@0V]P
M>7)I9VAT(#(P,#$M,C`P-B!%<FEC(%)O<W1E='1E<B`\97)I8RYR;W-T971T
M97)`<&AY<VEC<RYU=&5X87,N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N
M=71E>&%S+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E
M($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!!8V-O=6YT<U]$<FEV97(@>PH*("`@
M("\J*@H@("`@("H@17)R;W(@<W1R:6YG(')E='5R;F5D('1O('5S97(@:68@
M86X@97)R;W(@;V-C=7)S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D97)R7W-T<CL*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('5S97)N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;&]W97)C87-E9"!U<V5R;F%M92X*("`@("`J"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%5S97)N86UE*"D*("`@('L*("`@("`@("`D875T:"`]
M(&5X<&QO9&4H)T`G+"!!=71H.CIG971!=71H*"DI.PH@("`@("`@(')E='5R
M;B!3=')I;F<Z.FQO=V5R*"1A=71H6S!=*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('5S97(@<F5A;&TN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!U<V5R(')E86QM+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971296%L;2@I"B`@("!["B`@("`@("`@)&%U=&@@/2!E>'!L;V1E
M*"=`)RP@075T:#HZ9V5T075T:"@I*3L*("`@("`@("!R971U<FX@:7-S970H
M)&%U=&A;,5TI(#\@)&%U=&A;,5T@.B`G)SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('5S97(G<R!Q=6]T82!I9B!A=F%I;&%B;&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!Q=6]T82!A<G)A>2P@96QE
M;65N=',@87)E('5S960@8GET97,@86YD(&QI;6ET(&)Y=&5S(&]N"B`@("`@
M*B`@("`@("`@("`@("`@("!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9711=6]T82@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@=7-E<B=S(&9U;&P@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@=7-E<B=S(&9U;&P@;F%M92`H<W1R:6YG*2P@;W(@9F%L<V4@
M*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G5L;&YA;64H*0H@
M("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('5S97(G<R!H;VUE("AL;V=I;BD@9&ER96-T;W)Y
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!U<V5R)W,@9&ER
M96-T;W)Y("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971(;VUE*"D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@
M9&5F875L="!S:&5L;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M:&4@=7-E<B=S('-H96QL("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9713:&5L;"@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@9&%T92!O9B!T:&4@=7-E<B=S(&QA<W0@<&%S<W=O<F0@8VAA;F=E+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($1A=&4@<W1R:6YG("AS=')I
M;F<I(&]R(&9A;'-E("AE<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A<W-W;W)D0VAA;F=E*"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S=&%T=7,@;V8@
M=&AE(&-U<G)E;G0@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@02!S=')I;F<@=VET:"!A('=A<FYI;F<@;65S<V%G92!I9B!T:&4@
M<&%S<W=O<F0@:7,@86)O=70*("`@("`J("`@("`@("`@("`@("`@('1O(&5X
M<&ER92P@4$5!4E]%<G)O<B!O;B!E<G)O<B!A;F0@9F%L<V4@;W1H97)W:7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&5C:U!A<W-W;W)D4W1A='5S*"D*
M("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@I]"@HO*BH*("H@
M26UP;&5M96YT<R!T:&4@06-C;W5N=',@05!)(&9O<B!S97)V97)S('=I=&@@
M=6YI>"!A8V-O=6YT<R!O;B!T:&4@;&]C86QH;W-T"B`J(&UA8VAI;F4@*'-A
M;64@;6%C:&EN92!A<R!T:&4@=V5B('-E<G9E<BDN("!3:&]U;&0@=V]R:R!F
M;W(@;&]C86P@=6YI>`H@*B!A8V-O=6YT<RP@;FES+VYI<RL@86-C;W5N=',L
M(&]R(&%N>2!004T@;W)I96YT960@86-C;W5N=',@=&AA="!A<'!E87(@87,*
M("H@;&]C86P@86-C;W5N=',@;VX@=&AE(&QO8V%L(&UA8VAI;F4N("!4:&4@
M97AC97!T:6]N(&ES('1H92!Q=6]T82!S=7!P;W)T+@H@*B!3964@=&AA="!R
M;W5T:6YE(&9O<B!A9&1I=&EO;F%L(&-O;6UE;G1S+@H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($5R:6,@2F]N(%)O<W1E='1E<B`\97)I8RYR;W-T971T
M97)`<&AY<VEC<RYU=&5X87,N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@17)I8R!2;W-T971T97(@/&5R:6,N<F]S='1T97)`<&AY<VEC<RYU
M=&5X87,N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@0'!A8VMA9V4@
M2&]R9&5?0FQO8VL*("HO"F-L87-S($%C8V]U;G1S7T1R:79E<E]L;V-A;&AO
M<W0@97AT96YD<R!!8V-O=6YT<U]$<FEV97(@>PH*("`@("\J*@H@("`@("H@
M2&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<&%R86US(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!(87-H(&-O;G1A:6YI;F<@
M8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!
M8V-O=6YT<U]$<FEV97)?;&]C86QH;W-T*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("1T:&ES+3YP87)A;7,@/2`D<&%R86US.PH@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/G!A<F%M<ULG<75O=&%?<&%T:"==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<&%R86US6R=Q=6]T85]P871H)UT@/2`G<75O
M=&$G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YP87)A
M;7-;)V=R97!?<&%T:"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^<&%R86US
M6R=G<F5P7W!A=&@G72`]("=G<F5P)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R(&%C8V]U;G0@9G)O;2!T:&4@
M<&]S:7@@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@02!H87-H('=I=&@@8V]M<&QE=&4@86-C;W5N="!D971A:6QS+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5T06-C;W5N="@I"B`@("!["B`@("`@("`@
M<W1A=&EC("1I;F9O<FUA=&EO;CL*"B`@("`@("`@:68@*"%I<W-E="@D:6YF
M;W)M871I;VXI*2!["B`@("`@("`@("`@("\O('1H:7,@=V]N)W0@=V]R:R!I
M9B!W92!D;VXG="!H879E('!O<VEX(&5X=&5N<VEO;G,*("`@("`@("`@("`@
M:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)W!O<VEX)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E!/4TE8(&5X
M=&5N<VEO;B!I<R!M:7-S:6YG(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=7-E<B`](%-T<FEN9SHZ;&]W97(H)'1H:7,M/F=E=%5S97)N86UE
M*"DI.PH@("`@("`@("`@("`D:6YF;W)M871I;VX@/2!P;W-I>%]G971P=VYA
M;2@D=7-E<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN9F]R;6%T
M:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP;&5M96YT('1H92!1=6]T
M82!!4$D@9F]R($E-05`@<V5R=F5R<R!W:71H(&$@=6YI>"!Q=6]T82!C;VUM
M86YD+@H@("`@("H@5&AI<R!M87D@<F5Q=6ER92!A(&UO9&EF:65D(")Q=6]T
M82(@8V]M;6%N9"!T:&%T(&%L;&]W<R!T:&4@:'1T<&0*("`@("`J('-E<G9E
M<B!A8V-O=6YT('1O(&=E="!Q=6]T87,@9F]R(&]T:&5R('5S97)S+BXN("!)
M="!R97%U:7)E<R!T:&%T('EO=7(*("`@("`J('=E8B!S97)V97(@86YD('5S
M97(@<V5R=F5R(&)E('1H92!S86UE('-E<G9E<B!O<B!A="!L96%S="!H879E
M('-H87)E9`H@("`@("H@875T:&5N=&EC871I;VX@86YD(&9I;&4@<V5R=F5R
M<R`H92YG+B!V:6$@3DE3+TY&4RDN("!!;F0@;&%S="P@:70@*&%S"B`@("`@
M*B!W<FET=&5N*2!R97%U:7)E<R!T:&4@<&]S:7@@<&AP(&5X=&5N<VEO;G,N
M"B`@("`@*@H@("`@("H@268@>6]U<B!Q=6]T82!C;VUM86YD('=R87!S('1H
M92!O=71P=70@;VYT;R!T=V\@;&EN97,L('1H96X@=&AI<R!M;V1U;&4*("`@
M("`J('=I;&P@;VYL>2!W;W)K(&EF('EO=2!H879E(&$@9W)E<"!W:&EC:"!S
M=7!P;W)T<R!T:&4@+4$@<W=I=&-H+"!A;F0@>6]U"B`@("`@*B!A<'!E;F0@
M86X@+4$Q('-W:71C:"!T;R!Y;W5R(&=R97!?<&%T:"`H92YG+B`G+V)I;B]G
M<F5P("U!,2<I+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!Q
M=6]T82!H87-H("AB>71E<R!U<V5D+"!L:6UI="D@;W(@9F%L<V4@9F]R(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9711=6]T82@I"B`@("!["B`@
M("`@("`@)&EN9F]R;6%T:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@
M("`@("`@:68@*&ES7V$H)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*
M("`@("`@("`D:&]M961I<B`]("1I;F9O<FUA=&EO;ELG9&ER)UT["@H@("`@
M("`@("\O($EF('=E('=A;G0@;6]U;G0@<&]I;G0@=')A;G-L871I;VYS+"!T
M:&5N('1R86YS;&%T92!T:&4@;&]G:6X@9&ER"B`@("`@("`@+R\@;F%M92!T
M;R!A(&UO=6YT('!O:6YT+B`@268@;F]T+"!T:&5N('-I;7!L>2!P87)S92!O
M=70@=&AE(&1E=FEC90H@("`@("`@("\O(&YA;64@9G)O;2!T:&4@;&]G:6X@
M9&ER96-T;W)Y+"!A;F0@=7-E('1H870@:6YS=&5A9"X*("`@("`@("!I9B`H
M)'1H:7,M/G!A<F%M<ULG=')A;G-L871E36]U;G10;VEN="==("8F"B`@("`@
M("`@("`@(&9I;&5?97AI<W1S*"1T:&ES+3YP87)A;7-;)W1R86YS;&%T:6]N
M5&%B;&4G72DI"B`@("`@("`@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)T9I;&4O1G-T86(N<&AP)SL*("`@("`@("`@("`@)'-Y<U1A8B`]($9I;&5?
M1G-T86(Z.G-I;F=L971O;B@D=&AI<RT^<&%R86US6R=T<F%N<VQA=&EO;E1A
M8FQE)UTI.PH@("`@("`@("`@("!D;R!["B`@("`@("`@("`@("`@("1E;G1R
M>2`]("8D<WES5&%B+3YG971%;G1R>49O<E!A=&@H)&AO;65D:7(I.PH@("`@
M("`@("`@("`@("`D:&]M961I<B`](&1I<FYA;64H)&AO;65D:7(I.PH@("`@
M("`@("`@("`@("!I9B`H)&AO;65D:7(@/3T@)RXG('Q\(&5M<'1Y*"1H;VUE
M9&ER*2D@>PH@("`@("`@("`@("`@("`@("`@)&AO;65D:7(@/2`G+R<["B`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!W:&EL92`H:7-?82@D96YT
M<GDL("=014%27T5R<F]R)RDI.PH@("`@("`@("`@("`D;6]U;G10;VEN="`]
M("1E;G1R>2T^9&5V:6-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M)&AO;65D:7(@/2!E>'!L;V1E*"<O)RP@)&AO;65D:7(I.PH@("`@("`@("`@
M("1M;W5N=%!O:6YT(#T@)R\G("X@)&AO;65D:7);,5T["B`@("`@("`@?0H*
M("`@("`@("`D8VUD;&EN92`]('-P<FEN=&8H)R5S("UU("5S(#(^)C$@?"`E
M<R`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP87)A
M;7-;)W%U;W1A7W!A=&@G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F=E=%5S97).86UE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YP87)A;7-;)V=R97!?<&%T:"==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;6]U;G10;VEN="D["B`@("`@("`@)&IU;FL@/2!E
M>&5C*"1C;61L:6YE+"`D<75O=&%?9&%T82P@)')E='5R;E]C;V1E*3L*("`@
M("`@("!I9B`H)')E='5R;E]C;V1E(#T](#`@)B8@(65M<'1Y*"1Q=6]T85]D
M871A6S!=*2D@>PH@("`@("`@("`@("\O($EN(&-A<V4@;V8@<75O=&$@;W5T
M<'5T('=R87!P:6YG(&]N('1W;R!L:6YE<RP@=V4@8V]N8V%T('1H90H@("`@
M("`@("`@("\O('-E8V]N9"!L:6YE(&]F(')E<W5L=',L(&EF(&%N>2P@:&5R
M92X*("`@("`@("`@("!I9B`H(65M<'1Y*"1Q=6]T85]D871A6S%=*2D@>PH@
M("`@("`@("`@("`@("`D<75O=&%?9&%T85LP72`N/2`D<75O=&%?9&%T85LQ
M73L*("`@("`@("`@("!]"B`@("`@("`@("`@+R\@3F]W('!A<G-E(&]U="!T
M:&4@<75O=&$@:6YF;R!A;F0@<F5T=7)N(&ET+@H@("`@("`@("`@("1Q=6]T
M82`]('!R96=?<W!L:70H)R]<<RLO)RP@=')I;2@D<75O=&%?9&%T85LP72DI
M.PH@("`@("`@("`@(')E='5R;B!A<G)A>2@G=7-E9"<@/3X@)'%U;W1A6S%=
M("H@,3`R-"P@)VQI;6ET)R`]/B`D<75O=&%;,ET@*B`Q,#(T*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=7-E<B=S(&9U;&P@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S(&9U;&P@;F%M92`H<W1R:6YG
M*2P@;W(@9F%L<V4@*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1G5L;&YA;64H*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES
M+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R
M;6%T:6]N.PH@("`@("`@('T*("`@("`@("`D9V5C;W-?87)R87D@/2!E>'!L
M;V1E*"<L)RP@)&EN9F]R;6%T:6]N6R=G96-O<R==*3L*("`@("`@("!R971U
M<FX@)&=E8V]S7V%R<F%Y6S!=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@=7-E<B=S(&AO;64@*&QO9VEN*2!D:7)E8W1O<GDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(G<R!D:7)E8W1O<GD@
M*'-T<FEN9RDL(&]R(&9A;'-E("AE<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$AO;64H*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T
M:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA
M=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN
M9F]R;6%T:6]N.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&EN9F]R;6%T
M:6]N6R=D:7(G73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('5S97(G<R!D969A=6QT('-H96QL+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!U<V5R)W,@<VAE;&P@*'-T<FEN9RDL(&]R(&9A;'-E("AE
M<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-H96QL*"D*("`@('L*
M("`@("`@("`D:6YF;W)M871I;VX@/2`D=&AI<RT^7V=E=$%C8V]U;G0H*3L*
M("`@("`@("!I9B`H:7-?82@D:6YF;W)M871I;VXL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;CL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;ELG<VAE;&PG73L*("`@('T*
M"GT*"B\J*@H@*B!4:&4@;&1A<"!C;&%S<R!A='1E;7!T<R!T;R!R971U<FX@
M=7-E<B!I;F9O<FUA=&EO;B!S=&]R960@:6X@86X@;&1A<`H@*B!D:7)E8W1O
M<GD@<V5R=FEC92X*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!%<FEC(%)O
M<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@17)I8R!*;VX@4F]S=&5T=&5R
M(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^"B`J($!S:6YC
M92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA
M<W,@06-C;W5N='-?1')I=F5R7VQD87`@97AT96YD<R!!8V-O=6YT<U]$<FEV
M97(@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!T:&4@;&1A<"!C;VYN
M96-T:6]N+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@
M("`@=F%R("1?9',["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@
M8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<&%R86US.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!!8V-O=6YT<U]$<FEV97)?;&1A<"!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@06-C;W5N='-?1')I=F5R7VQD87`H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M97)G
M92@*("`@("`@("`@("`@87)R87DH)VAO<W0G(#T^("=L;V-A;&AO<W0G+`H@
M("`@("`@("`@("`@("`@("`G<&]R="<@/3X@,S@Y+`H@("`@("`@("`@("`@
M("`@("`G8F%S961N)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@)V%T='(G
M(#T^("=U:60G+`H@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)S,G
M*2P*("`@("`@("`@("`@)'!A<F%M<RD["B`@("!]"@H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=7-E<B!A8V-O=6YT(&9R;VT@=&AE(&QD87`@<V]U
M<F-E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!W:71H
M(&-O;7!L971E(&%C8V]U;G0@9&5T86EL<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$%C8V]U;G0H*0H@("`@>PH@("`@("`@('-T871I8R`D:6YF;W)M
M871I;VX["@H@("`@("`@(&EF("@A:7-S970H)&EN9F]R;6%T:6]N*2D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@(#T@)'1H:7,M/F=E=%5S97)N86UE*"D[
M"@H@("`@("`@("`@("`O+R!C;VYN96-T('1O('1H92!L9&%P('-E<G9E<@H@
M("`@("`@("`@("`D=&AI<RT^7V1S(#T@;&1A<%]C;VYN96-T*"1T:&ES+3Y?
M<&%R86US6R=H;W-T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72D["B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]D<RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"%L9&%P7W-E=%]O<'1I;VXH)'1H:7,M/E]D<RP@3$1!4%]/4%1?
M4%)/5$]#3TQ?5D524TE/3BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4V5T
M($Q$05`@<')O=&]C;VP@=F5R<VEO;B!T;R`E9"!F86EL960Z(%LE9%T@)7,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)&-O
M;FXI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;&1A<%]E<G)O<B@D8V]N;BDI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@8FEN9"!A<R!A;F]N>6UO=7,*("`@("`@("`@("`@)')E<W5L="`]
M($!L9&%P7V)I;F0H)'1H:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(BDI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!'970@=&AE(&9U;&QN86UE"B`@
M("`@("`@("`@("1S96%R8VA297-U;'0@/2!L9&%P7W-E87)C:"@D=&AI<RT^
M7V1S+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T
M<B==("X@)STG("X@)'5S97)N86UE*3L*("`@("`@("`@("`@)&EN9F]R;6%T
M:6]N(#T@;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H4F5S
M=6QT*3L*"B`@("`@("`@("`@("\O(&1I<V-O;FYE8W0@9G)O;2!T:&4@;&1A
M<"!S97)V97(*("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD[
M"@H@("`@("`@("`@("!I9B`H)&EN9F]R;6%T:6]N6R=C;W5N="==(#T](#`I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5S97(@86-C;W5N="!N;W0@9F]U;F0B*2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@9G5L;"!N86UE+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!U<V5R)W,@9G5L;"!N
M86UE("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971&=6QL;F%M92@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T
M:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H
M)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)&EN9F]R;6%T:6]N6S!=6R=C;CML86YG+65S)UU;,%TI("8F"B`@("`@
M("`@("`@("1I;F9O<FUA=&EO;ELP75LG8VX[;&%N9RUE<R==6S!=("$]("<G
M*2!["B`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T:6]N6S!=6R=C;CML
M86YG+65S)UU;,%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YA
M;64@/2`D:6YF;W)M871I;VY;,%U;)V-N)UU;,%T["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@*&5M<'1Y*"1N86UE*2`_(&9A;'-E(#H@)&YA;64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B=S(&AO;64@
M*&QO9VEN*2!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE('5S97(G<R!D:7)E8W1O<GD@*'-T<FEN9RDL(&]R(&9A;'-E("AE
M<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$AO;64H*0H@("`@>PH@
M("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@
M("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*
M("`@("`@("`D:&]M961I<B`]("1I;F9O<FUA=&EO;ELP75LG:&]M961I<F5C
M=&]R>2==6S!=.PH@("`@("`@(')E='5R;B`H96UP='DH)&AO;65D:7(I(#\@
M9F%L<V4@.B`D:&]M961I<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!U<V5R)W,@9&5F875L="!S:&5L;"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S('-H96QL("AS=')I;F<I+"!O<B!F
M86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&5L;"@I
M"B`@("!["B`@("`@("`@)&EN9F]R;6%T:6]N(#T@)'1H:7,M/E]G971!8V-O
M=6YT*"D["B`@("`@("`@:68@*&ES7V$H)&EN9F]R;6%T:6]N+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX["B`@
M("`@("`@?0H@("`@("`@("1S:&5L;"`]("1I;F9O<FUA=&EO;ELP75LG;&]G
M:6YS:&5L;"==6S!=.PH@("`@("`@(')E='5R;B`H96UP='DH)'-H96QL*2`_
M(&9A;'-E(#H@)'-H96QL*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&1A=&4@;V8@=&AE('5S97(G<R!L87-T('!A<W-W;W)D(&-H86YG
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$871E('-T<FEN9R`H
M<W1R:6YG*2!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971087-S=V]R9$-H86YG92@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T
M:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H
M)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%TI*2![
M"B`@("`@("`@("`@("1L87-T8VAA;F=E(#T@<W1R9G1I;64H)R5X)RP@)&EN
M9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%T@*B`X-C0P,"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*&5M<'1Y*"1L87-T8VAA;F=E
M*2`_(&9A;'-E(#H@)&QA<W1C:&%N9V4I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<W1A='5S(&]F('1H92!C=7)R96YT('!A<W-W;W)D
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($$@<W1R:6YG('=I=&@@
M82!W87)N:6YG(&UE<W-A9V4@:68@=&AE('!A<W-W;W)D(&ES(&%B;W5T"B`@
M("`@*B`@("`@("`@("`@("`@("!T;R!E>'!I<F4L(%!%05)?17)R;W(@;VX@
M97)R;W(@86YD(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VAE8VM087-S=V]R9%-T871U<R@I"B`@("!["B`@("`@("`@)&EN9F]R
M;6%T:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES
M7V$H)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=M87@G75LP72D@)B8*("`@
M("`@("`@("`@:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA
M;F=E)UU;,%TI("8F"B`@("`@("`@("`@(&ES<V5T*"1I;F9O<FUA=&EO;ELP
M75LG<VAA9&]W=V%R;FEN9R==6S!=*2D@>PH@("`@("`@("`@("`D=&]D87D@
M/2!F;&]O<BAT:6UE*"D@+R`X-C0P,"D["B`@("`@("`@("`@("1W87)N9&%Y
M(#T@)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%T@*PH@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W
M;6%X)UU;,%T@+2`D:6YF;W)M871I;VY;,%U;)W-H861O=W=A<FYI;F<G75LP
M73L*("`@("`@("`@("`@)'1O97AP:7)E(#T@)&EN9F]R;6%T:6]N6S!=6R=S
M:&%D;W=L87-T8VAA;F=E)UU;,%T@*R`D:6YF;W)M871I;VY;,%U;)W-H861O
M=VUA>"==6S!=("T@)'1O9&%Y.PH*("`@("`@("`@("`@:68@*"1T;V1A>2`^
M/2`D=V%R;F1A>2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H
M7R@B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(BDL("1T
M;V5X<&ER92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]C
M;VQO<BYP:'``````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$V-C4`,3`T,3<S-C(W-S4`,#(P,#8T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO+R!4:&ES(&)L;V-K
M(&ES(&%N(&5X86UP;&4@86YD('!R;V)A8FQY(&YO="!U<V5F=6P@=&\@=7-E
M<G,N"B\O("1B;&]C:U]N86UE(#T@7R@B0V]L;W(B*3L*"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+VQI8B]";&]C:R]C;VQO<BYP:'`L=B`Q+C$R(#(P,#0O,#8O
M,#$@,3`Z,#4Z,S$@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L
M;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]C;VQO<B!E>'1E;F1S
M($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:&]R9&4G.PH*("`@
M(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A
M>2@G='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M
M92<@/3X@7R@B0V]L;W(B*2P*("`@("`@("`@("`@("`@("`@("`@)V1E9F%U
M;'0G(#T^("<C9F8P,#`P)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@
M=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")#;VQO<B(I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@
M=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H
M92!C;VYT96YT"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@
M('L*("`@("`@("`D:'1M;"`@/2`G/'1A8FQE('=I9'1H/2(Q,#`B(&AE:6=H
M=#TB,3`P(B!B9V-O;&]R/2(E<R(^)SL*("`@("`@("`D:'1M;"`N/2`G/'1R
M/CQT9#XF;F)S<#L\+W1D/CPO='(^)SL*("`@("`@("`D:'1M;"`N/2`G/"]T
M86)L93XG.PH*("`@("`@("!R971U<FX@<W!R:6YT9B@D:'1M;"P@)'1H:7,M
M/E]P87)A;7-;)V-O;&]R)UTI.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]"
M;&]C:R]F;W)T=6YE+G!H<```````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3$Q,3<`,3`T,3<S-C(W-S4`,#(P-#(Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@HD8FQO8VM?
M;F%M92`](%\H(E)A;F1O;2!&;W)T=6YE(BD["@HO*BH*("H@)$AO<F1E.B!H
M;W)D92]L:6(O0FQO8VLO9F]R='5N92YP:'`L=B`Q+C$T+C$P+C(@,C`P-2\Q
M,"\Q."`Q,3HS,SHS.2!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?
M0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7V9O<G1U;F4@97AT
M96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P(#T@)VAO<F1E)SL*
M"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I;B!T:&ES(&)L;V-K
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE('1I=&QE('1E
M>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@
M("`@<F5T=7)N(%\H(D9O<G1U;F4B*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<&%R86US*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M("1D97-C<FEP=&EO;G,@/2!A<G)A>2@G87)T)R`]/B!?*")!<G0B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%S8VEI+6%R="<@/3X@7R@B
M07-C:6D@07)T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=B
M;V9H+65X8W5S97,G(#T^(%\H(D)/1D@@17AC=7-E<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8V]M<'5T97)S)R`]/B!?*")#;VUP=71E
M<G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;VMI92<@
M/3X@7R@B0V]O:VEE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D969I;FET:6]N<R<@/3X@7R@B1&5F:6YI=&EO;G,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1R=6=S)R`]/B!?*")$<G5G<R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G961U8V%T:6]N)R`]/B!?
M*")%9'5C871I;VXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V5T:&YI8R<@/3X@7R@B171H;FEC(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=F;V]D)R`]/B!?*")&;V]D(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=F;W)T=6YE<R<@/3X@7R@B1F]R='5N97,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9O<G1U;F5S,B<@/3X@
M7R@B1F]R='5N97,@,B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9V]E9&5L)R`]/B!?*")';V5D96PB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VAU;6]R:7-T<R<@/3X@7R@B2'5M;W)I<W1S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K97)N96QN97=B:65S)R`]
M/B!?*")+97)N96P@3F5W8FEE<R(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:VED<R<@/3X@7R@B2VED<R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&%W)R`]/B!?*"),87<B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VQI;65R:6-K)R`]/B!?*"),:6UE<FEC:R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&EN=7AC;V]K:64G
M(#T^(%\H(DQI;G5X($-O;VMI92(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;&ET97)A='5R92<@/3X@7R@B3&ET97)A='5R92(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;&]V92<@/3X@7R@B3&]V92(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6%G:6,G(#T^(%\H
M(DUA9VEC(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M961I
M8VEN92<@/3X@7R@B365D:6-I;F4B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VUI<V-E;&QA;F5O=7,G(#T^(%\H(DUI<V-E;&QA;F5O=7,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYE=W,G(#T^(%\H
M(DYE=W,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]S9F]R
M='5N92<@/3X@7R@B3W!E<F%T:6YG(%-Y<W1E;2(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<&5O<&QE)R`]/B!?*")096]P;&4B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!E=',G(#T^(%\H(E!E=',B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!L871I='5D97,G
M(#T^(%\H(E!L871I='5D97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W!O;&ET:6-S)R`]/B!?*")0;VQI=&EC<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<FED9&QE<R<@/3X@7R@B4FED9&QE<R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V-I96YC92<@/3X@
M7R@B4V-I96YC92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<V]N9W,M<&]E;7,G(#T^(%\H(E-O;F=S("8@4&]E;7,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W-P;W)T<R<@/3X@7R@B4W!O<G1S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=&%R=')E:R<@/3X@
M7R@B4W1A<B!4<F5K(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T<F%N<VQA=&4M;64G(#T^(%\H(E1R86YS;&%T:6]N<R(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=VES9&]M)R`]/B!?*")7:7-D;VTB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=O<FLG(#T^(%\H
M(E=O<FLB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WII<'!Y
M)R`]/B!?*")::7!P>2(I*3L*"B`@("`@("`@)'9A;'5E<R`](&YU;&P["B`@
M("`@("`@:68@*&ES<V5T*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T:"==
M*2`F)@H@("`@("`@("`@("!I<U]E>&5C=71A8FQE*"1C;VYF6R=F;W)T=6YE
M)UU;)V5X96-?<&%T:"==*2D@>PH@("`@("`@("`@("!E>&5C*"1C;VYF6R=F
M;W)T=6YE)UU;)V5X96-?<&%T:"==("X@)R`M9B`R/B8Q)RP@)&]U='!U="P@
M)'-T871U<RD["B`@("`@("`@("`@(&EF("@A)'-T871U<RD@>PH@("`@("`@
M("`@("`@("`@9F]R("@D:2`](#$[("1I(#P@8V]U;G0H)&]U='!U="D[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`D9F]R='5N92`]('-U8G-T<B@D
M;W5T<'5T6R1I72P@<W1R<G!O<R@D;W5T<'5T6R1I72P@)R`G*2`K(#$I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5S8W)I<'1I;VYS6R1F
M;W)T=6YE72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<ULD
M9F]R='5N95T@/2`D9&5S8W)I<'1I;VYS6R1F;W)T=6YE73L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=65S6R1F;W)T=6YE72`]("1F;W)T=6YE.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H:7-?;G5L;"@D=F%L=65S*2D@>PH@("`@("`@("`@
M("`D=F%L=65S(#T@)&1E<V-R:7!T:6]N<SL*("`@("`@("!]"B`@("`@("`@
M87-O<G0H)'9A;'5E<RD["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y7VUE<F=E
M*&%R<F%Y*"<G(#T^(%\H(D%L;"(I*2P@)'9A;'5E<RD["@H@("`@("`@(')E
M='5R;B!A<G)A>2@*("`@("`@("`@("`@)V]F9F5N9"<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@
M("`@)VYA;64G(#T^(%\H(D]F9F5N<V4@9FEL=&5R(BDL"B`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)R<L"B`@("`@("`@("`@("`@("`G=F%L=65S
M)R`]/B!A<G)A>2@G)R`]/B!?*").;R!O9F9E;G-I=F4@9F]R='5N97,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R`M;R<@/3X@7R@B
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R`M82<@/3X@7R@B0F]T:"(I*2DL"B`@("`@("`@
M("`@("=F;W)T=6YE)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=T>7!E
M)R`]/B`G;75L=&EE;G5M)RP*("`@("`@("`@("`@("`@("=N86UE)R`]/B!?
M*")&;W)T=6YE('1Y<&4B*2P*("`@("`@("`@("`@("`@("=D969A=6QT)R`]
M/B!A<G)A>2@G)RDL"B`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B`D=F%L
M=65S*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G
M;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T:"==*2`F)@H@("`@("`@
M("`@("!I<U]E>&5C=71A8FQE*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T
M:"==*2D@>PH@("`@("`@("`@("`D8VUD3&EN92`]("1C;VYF6R=F;W)T=6YE
M)UU;)V5X96-?<&%T:"==.PH@("`@("`@("`@("`D8VUD3&EN92`N/2`D=&AI
M<RT^7W!A<F%M<ULG;V9F96YD)UT["B`@("`@("`@("`@("1C;61,:6YE("X]
M("<@)R`N(&EM<&QO9&4H)R`G+"`D=&AI<RT^7W!A<F%M<ULG9F]R='5N92==
M*3L*("`@("`@("`@("`@<F5T=7)N(&YL,F)R*&AT;6QS<&5C:6%L8VAA<G,H
M<VAE;&Q?97AE8R@D8VUD3&EN92DI*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O0FQO8VLO9V]O9VQE+G!H<```````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S-C$S`#$P-#$W,S8R-S<U`#`R,#(Q-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M)&)L;V-K7VYA;64@/2!?*")';V]G;&4@4V5A<F-H(BD["@HO*BH*("H@)$AO
M<F1E.B!H;W)D92]L:6(O0FQO8VLO9V]O9VQE+G!H<"QV(#$N,3`N,3`N,2`R
M,#`U+S$P+S$X(#$Q.C,S.C,Y(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(
M;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2&]R9&5?9V]O9VQE
M(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=H;W)D
M92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L
M92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!?*")';V]G;&4@4V5A<F-H(BD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@("1H
M=&UL("`]("<\9F]R;2!N86UE/2)G;V]G;&4B(&]N<W5B;6ET/2)O<&5N7V=O
M;V=L95]W:6XH*3L@<F5T=7)N(&9A;'-E.R(^)SL*("`@("`@("`D:'1M;"`N
M/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!H96EG:'0](C$P,"4B/B<["B`@("`@
M("`@)&AT;6P@+CT@)SQT<CX\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP
M="(@<W)C/2(G("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O
M="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]J879A<V-R:7!T+G!H<#]F:6QE
M/6]P96Y?9V]O9VQE7W=I;BYJ<R9A;7`[87!P/6AO<F1E(CX\+W-C<FEP=#XG
M.PH@("`@("`@("1H=&UL("X]("<\=&0^)R`N($AO<F1E.CII;6<H)V=O;V=L
M92YP;F<G+"`G1V]O9VQE)RD@+B`G/"]T9#X\+W1R/B<["B`@("`@("`@)&AT
M;6P@+CT@)SQT<CX\=&0^/&EN<'5T(&UA>$QE;F=T:#TB,C4V(B!S:7IE/2(T
M,"(@;F%M93TB<2(@=VED=&@](C$P,"4B("\^/"]T9#X\+W1R/B<["B`@("`@
M("`@)&AT;6P@+CT@)SQT<CX\=&0^/'1A8FQE('=I9'1H/2(Q,#`E(CX\='(^
M/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)R861I;R(@;F%M93TB
M87)E82(@=F%L=64](G=E8B(@=VED=&@](C(P)2(@8VAE8VME9#TB8VAE8VME
M9"(@+SXG("X@7R@B5V5B(BD@+B`G/"]T9#XG.PH@("`@("`@("1H=&UL("X]
M("<\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](G)A9&EO(B!N86UE
M/2)A<F5A(B!V86QU93TB:6UA9V5S(B!W:61T:#TB,C`E(B`O/B<@+B!?*"))
M;6%G97,B*2`N("<\+W1D/B<["B`@("`@("`@)&AT;6P@+CT@)SQT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB<F%D:6\B(&YA;64](F%R96$B('9A
M;'5E/2)G<F]U<',B('=I9'1H/2(R,"4B("\^)R`N(%\H(D=R;W5P<R(I("X@
M)SPO=&0^)SL*("`@("`@("`D:'1M;"`N/2`G/'1D(&%L:6=N/2)C96YT97(B
M/CQI;G!U="!T>7!E/2)R861I;R(@;F%M93TB87)E82(@=F%L=64](F1I<F5C
M=&]R>2(@=VED=&@](C(P)2(@+SXG("X@7R@B1&ER96-T;W)Y(BD@+B`G/"]T
M9#XG.PH@("`@("`@("1H=&UL("X]("<\=&0@86QI9VX](F-E;G1E<B(^/&EN
M<'5T('1Y<&4](G)A9&EO(B!N86UE/2)A<F5A(B!V86QU93TB;F5W<R(@=VED
M=&@](C(P)2(@+SXG("X@7R@B3F5W<R(I("X@)SPO=&0^/"]T<CX\+W1A8FQE
M/CPO=&0^/"]T<CXG.PH@("`@("`@("1H=&UL("X]("<\='(^/'1D/CQI;G!U
M="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(G("X@7R@B
M1V]O9VQE(%-E87)C:"(I("X@)R(@+SX\+W1D/CPO='(^)SL*("`@("`@("`D
M:'1M;"`N/2`G/"]T86)L93XG.PH@("`@("`@("1H=&UL("X]("<\+V9O<FT^
M)SL*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+T)L;V-K+VEF<F%M92YP:'``````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-#$Q,``Q,#0Q-S,V,C<W-0`P,C`Q-S4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B1B;&]C
M:U]N86UE(#T@7R@B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(I.PH*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+VEF<F%M92YP:'`L=B`Q+C$X
M+C@N-"`R,#`V+S`R+S(Q(#$P.C4S.C0U(&IA;B!%>'`@)`H@*@H@*B!`<&%C
M:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2&]R9&5?
M:69R86UE(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]
M("=H;W)D92<["@H@("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=I9G)A;64G(#T^(&%R<F%Y*"=T>7!E)R`]/B`G
M=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=N86UE)R`]/B!?*")54DPB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<G*2P*("`@("`@("`@("`@
M("`@("`@("`@)W1I=&QE)R`@/3X@87)R87DH)W1Y<&4G(#T^("=T97AT)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^(%\H(E1I=&QE(BDI+`H@("`@("`@("`@("`@("`@("`@("`G:&5I9VAT
M)R`]/B!A<G)A>2@G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")(96EG:'0B*2DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE('1I=&QE('1O(&=O(&EN('1H
M:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@
M=&ET;&4@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D=&ET;&4@
M/2!I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&ET;&4G72D*("`@("`@("`@("`@
M/R`D=&AI<RT^7W!A<F%M<ULG=&ET;&4G70H@("`@("`@("`@("`Z("1T:&ES
M+3Y?<&%R86US6R=I9G)A;64G73L*"B`@("`@("`@)&AT;6P@/2!(;W)D93HZ
M;&EN:R@D=&AI<RT^7W!A<F%M<ULG:69R86UE)UTI("X@)'1I=&QE("X*("`@
M("`@("`@("`@)SPO83X@.CH@/'-M86QL/B<@+@H@("`@("`@("`@("!(;W)D
M93HZ;&EN:R@D=&AI<RT^7W!A<F%M<ULG:69R86UE)UTL("<G+"`G)RP@)U]B
M;&%N:R<I("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G=V5B<VET92YP;F<G
M+"!?*")/<&5N(&EN(&$@;F5W('=I;F1O=R(I*2`N("<@)R`N"B`@("`@("`@
M("`@(%\H(D]P96X@:6X@82!N97<@=VEN9&]W(BD@+B`G/"]A/CPO<VUA;&P^
M)SL*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!C;VYT96YT"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@('L*("`@("`@("!G;&]B86P@)&)R
M;W=S97(["@H@("`@("`@(&EF("@A)&)R;W=S97(M/FAA<T9E871U<F4H)VEF
M<F%M97,G*2D@>PH@("`@("`@("`@("!R971U<FX@7R@B66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=H96EG:'0G72DI
M('L*("`@("`@("`@("`@:68@*"1B<F]W<V5R+3YI<T)R;W=S97(H)VUS:64G
M*2!\?"`D8G)O=W-E<BT^:7-"<F]W<V5R*"=K;VYQ=65R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@)&AE:6=H="`]("<G.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&AE:6=H="`]("<@:&5I9VAT/2(Q,#`E(B<[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M:&5I9VAT(#T@)R!H96EG:'0](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1T:&ES
M+3Y?<&%R86US6R=H96EG:'0G72D@+B`G(B<["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`G/&EF<F%M92!S<F,](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1T
M:&ES+3Y?<&%R86US6R=I9G)A;64G72D@+B`G(B!W:61T:#TB,3`P)2(G("X@
M)&AE:6=H="`N("<@;6%R9VEN:&5I9VAT/2(P(B!S8W)O;&QI;F<](F%U=&\B
M(&9R86UE8F]R9&5R/2(P(CX\+VEF<F%M93XG.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+T)L;V-K+VUE=&%R+G!H<```````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-S4S-P`Q,#0Q-S,V,C<W-0`P,C`P
M-C8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B365T87(@5V5A=&AE<B(I.PH*+RHJ
M"B`J(%1H92!(;W)D95]";&]C:U]M971A<B!C;&%S<R!P<F]V:61E<R!A;B!A
M<'!L970@9F]R('1H92!P;W)T86P*("H@<V-R965N('1O(&1I<W!L87D@3454
M05(@=V5A=&AE<B!D871A(&9O<B!A('-P96-I9FEE9"!L;V-A=&EO;@H@*B`H
M8W5R<F5N=&QY(&%I<G!O<G1S*2X*("H*("H@)$AO<F1E.B!H;W)D92]L:6(O
M0FQO8VLO;65T87(N<&AP+'8@,2XR,BXQ,"XU(#(P,#8O,#$O,3@@,3DZ-3<Z
M,#8@8F5N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC
M;&%S<R!(;W)D95]";&]C:U](;W)D95]M971A<B!E>'1E;F1S($AO<F1E7T)L
M;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:&]R9&4G.PH*("`@("\J*@H@("`@
M("H@5&AE('1I=&QE('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@("!4:&4@=&ET;&4@=&5X="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*("`@("`@("!R971U<FX@7R@B
M0W5R<F5N="!796%T:&5R(BD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<F%M
M<R@I"B`@("!["B`@("`@("`@:68@*"%`:6YC;'5D95]O;F-E("=397)V:6-E
M<R]796%T:&5R+G!H<"<I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U1H92!M971A<B!B;&]C:R!W:6QL(&YO="!W;W)K('=I=&AO=70@4V5R
M=FEC97-?5V5A=&AE<B!F<F]M(%!%05(N(%)U;B!P96%R(&EN<W1A;&P@4V5R
M=FEC97-?5V5A=&AE<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=E<G)O<B<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E<G)O<B<L
M"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(D5R<F]R(BDL"B`@
M("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%\H(DUE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N(BD*("`@("`@("`@("`@("`@("D*("`@("`@("`@
M("`@*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!G;&]B86P@)&-O
M;F8["@H@("`@("`@("`@("`O+R!'970@;&]C871I;VYS(&9R;VT@=&AE(&1A
M=&%B87-E+@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@
M("`@("`@("`@("1D8B`]("9$0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTI.PH@
M("`@("`@("`@("!I9B`H:7-?82@D9&(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D9&(["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\O(%-E="!$0B!P;W)T86)I;&ET>2!O<'1I;VYS+@H@("`@("`@
M("`@("!S=VET8V@@*"1D8BT^<&AP='EP92D@>PH@("`@("`@("`@("!C87-E
M("=M<W-Q;"<Z"B`@("`@("`@("`@("`@("`D9&(M/G-E=$]P=&EO;B@G<&]R
M=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)4
M04))3$E465]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@("1D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/
M4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2`D9&(M/G%U
M97)Y*"=314Q%0U0@:6-A;RP@;F%M92P@8V]U;G1R>2!&4D]-(&UE=&%R06ER
M<&]R=',@3U)$15(@0ED@8V]U;G1R>2<I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&QO
M8V%T:6]N<R`](&%R<F%Y*"D["B`@("`@("`@("`@('=H:6QE("@D<F]W(#T@
M)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*2D@>PH@("`@
M("`@("`@("`@("`@)&QO8V%T:6]N<ULD<F]W6R=C;W5N=')Y)UU=6R1R;W=;
M)VEC86\G75T@/2`D<F]W6R=N86UE)UT["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=L;V-A=&EO
M;B<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=M
M;&5N=6TG+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*"),;V-A
M=&EO;B(I+`H@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G2U-&
M0B<L"B`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@)&QO8V%T:6]N
M<RP*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G=6YI=',G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU
M;2<L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E5N:71S(BDL
M"B`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("=S)RP*("`@("`@
M("`@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@)W,G(#T^(%\H(E-T86YD87)D(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("=M)R`]/B!?*")-971R:6,B*0H@("`@("`@("`@("`@
M("`@("`@("D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G
M:VYO=',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]
M/B`G8VAE8VMB;W@G+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?
M*")7:6YD('-P965D(&EN(&MN;W1S(BDL"B`@("`@("`@("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^(#`*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@
M("`@("`G=&%F)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G='EP
M92<@/3X@)V-H96-K8F]X)RP*("`@("`@("`@("`@("`@("`@("`G;F%M92<@
M/3X@7R@B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(I+`H@("`@("`@("`@("`@
M("`@("`@("=D969A=6QT)R`]/B`P"B`@("`@("`@("`@("`@("`I"B`@("`@
M("`@("`@("D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R;W<H
M)&QA8F5L+"`D8V]N=&5N="D*("`@('L*("`@("`@("!R971U<FX@)SQB<B`O
M/CQS=')O;F<^)R`N("1L86)E;"`N("<Z/"]S=')O;F<^("<@+B`D8V]N=&5N
M=#L*("`@('T*"B`@("!F=6YC=&EO;B!?<V%M95)O=R@D;&%B96PL("1C;VYT
M96YT*0H@("`@>PH@("`@("`@(')E='5R;B`G(#QS=')O;F<^)R`N("1L86)E
M;"`N("<Z/"]S=')O;F<^("<@+B`D8V]N=&5N=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@:68@*"%`
M:6YC;'5D95]O;F-E("=397)V:6-E<R]796%T:&5R+G!H<"<I('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U1H92!M971A<B!B;&]C:R!W:6QL
M(&YO="!W;W)K('=I=&AO=70@4V5R=FEC97-?5V5A=&AE<B!F<F]M(%!%05(N
M(%)U;B!P96%R(&EN<W1A;&P@4V5R=FEC97-?5V5A=&AE<BXG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!?*")-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(I.PH@("`@("`@('T*"B`@("`@("`@9VQO
M8F%L("1C;VYF.PH@("`@("`@('-T871I8R`D;65T87),;V-S.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1C;VYF6R=S<6PG72DI('L*("`@("`@("`@("`@<F5T
M=7)N(%\H(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RXB*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7W!A<F%M<ULG;&]C871I;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N
M(%\H(DYO(&QO8V%T:6]N(&ES('-E="XB*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-?87)R87DH)&UE=&%R3&]C<RDI('L*("`@("`@("`@("`@)&UE
M=&%R3&]C<R`]("1T:&ES+3YG971087)A;7,H*3L*("`@("`@("!]"@H@("`@
M("`@(')E<75I<F5?;VYC92`G4V5R=FEC97,O5V5A=&AE<BYP:'`G.PH@("`@
M("`@("1M971A<B`]("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E*"=-151!
M4B<L(&%R<F%Y*"=D96)U9R<@/3X@,"DI.PH@("`@("`@("1D8E-T<FEN9R`]
M("1C;VYF6R=S<6PG75LG<&AP='EP92==("X@)SHO+R<["B`@("`@("`@)&1B
M4W1R:6YG("X]("1C;VYF6R=S<6PG75LG=7-E<FYA;64G72`N("<Z)SL*("`@
M("`@("`D9&)3=')I;F<@+CT@)&-O;F9;)W-Q;"==6R=P87-S=V]R9"==("X@
M)T`G.PH@("`@("`@("1D8E-T<FEN9R`N/2`D8V]N9ELG<W%L)UU;)VAO<W1S
M<&5C)UT@+B`G+R<["B`@("`@("`@)&1B4W1R:6YG("X]("1C;VYF6R=S<6PG
M75LG9&%T86)A<V4G73L*("`@("`@("`D;65T87(M/G-E=$UE=&%R1$(H)&1B
M4W1R:6YG*3L*("`@("`@("`D;65T87(M/G-E=%5N:71S1F]R;6%T*"1T:&ES
M+3Y?<&%R86US6R=U;FET<R==*3L*("`@("`@("`D;65T87(M/G-E=$1A=&54
M:6UE1F]R;6%T*"=-(&HL(%DG+"`G2#II)RD["B`@("`@("`@)&UE=&%R+3YS
M971-971A<E-O=7)C92@G:'1T<"<I.PH*("`@("`@("`D=6YI=',@/2`D;65T
M87(M/F=E=%5N:71S1F]R;6%T*"1T:&ES+3Y?<&%R86US6R=U;FET<R==*3L*
M("`@("`@("`D=V5A=&AE<B`]("1M971A<BT^9V5T5V5A=&AE<B@D=&AI<RT^
M7W!A<F%M<ULG;&]C871I;VXG72D["@H@("`@("`@("1H=&UL(#T@)SQT86)L
M92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/B<@+@H@("`@("`@("`@
M("`G/'1R/CQT9"!C;&%S<STB8V]N=')O;"(^/'-T<F]N9SXG("X*("`@("`@
M("`@("`@<W!R:6YT9B@G)7,L("5S("@E<RDG+`H@("`@("`@("`@("`@("`@
M("`@("1M971A<DQO8W-;)VQO8V%T:6]N)UU;)W9A;'5E<R==6R1T:&ES+3Y?
M<&%R86US6R=?7VQO8V%T:6]N)UU=6R1T:&ES+3Y?<&%R86US6R=L;V-A=&EO
M;B==72P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG7U]L
M;V-A=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=L;V-A=&EO;B==*2`N"B`@("`@("`@("`@("<\+W-T<F]N9SX\+W1D/CPO
M='(^/"]T86)L93X\<W1R;VYG/B<@+B!?*"),87-T(%5P9&%T960Z(BD@+B`G
M/"]S=')O;F<^("<@+@H@("`@("`@("`@("`D=V5A=&AE<ELG=7!D871E)UT@
M+B`G/&)R("\^/&)R("\^)SL*"B`@("`@("`@+R\@5VEN9"X*("`@("`@("!I
M9B`H:7-S970H)'=E871H97);)W=I;F0G72DI('L*("`@("`@("`@("`@)&AT
M;6P@+CT@)SQS=')O;F<^)R`N(%\H(E=I;F0Z(BD@+B`G/"]S=')O;F<^("<[
M"B`@("`@("`@("`@(&EF("@D=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==(#T]
M("=687)I86)L92<I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]P87)A;7-;)VMN;W1S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@<W!R:6YT9BA?*"(E<R!A="`E<R`E<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`D=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("!R;W5N9"@D;65T87(M/F-O;G9E<G13<&5E
M9"@D=V5A=&AE<ELG=VEN9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'5N:71S6R=W:6YD)UTL("=K="<I*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@)VMT)RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B)7,@870@)7,@)7,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97);)W=I;F1$:7)E
M8W1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)'=E871H
M97);)W=I;F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("1U;FET<ULG
M=VEN9"==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M:68@*"@D=V5A=&AE<ELG=VEN9$1E9W)E97,G72`]/2`G,#`P)RD@)B8*("`@
M("`@("`@("`@("`@("`@("`@("`@*"1W96%T:&5R6R=W:6YD)UT@/3T@)S`G
M*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9BA?*")C86QM
M(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@<W!R:6YT9BA?*")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R6R=W
M:6YD1&ER96-T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1W96%T:&5R6R=W:6YD1&5G<F5E<R==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG:VYO=',G
M72D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D
M=V5A=&AE<ELG=VEN9"==*2`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')O=6YD*"1M971A<BT^8V]N=F5R=%-P965D*"1W96%T:&5R6R=W
M:6YD)UTL("1U;FET<ULG=VEN9"==+"`G:W0G*2DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=K;F]T
M<R==*2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;FET
M<ULG=VEN9"==(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VMT)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1W96%T:&5R6R=W:6YD1W5S="==*2D@>PH@("`@("`@("`@("!I9B`H
M)'=E871H97);)W=I;F1'=7-T)UTI('L*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]P87)A;7-;)VMN;W1S)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9BA?*"(L(&=U<W1I;F<@)7,@)7,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&UE=&%R+3YC;VYV
M97)T4W!E960H)'=E871H97);)W=I;F1'=7-T)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("1U;FET<ULG=VEN9"==+"`G:W0G*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("=K="<I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*%\H(BP@9W5S
M=&EN9R`E<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D
M=V5A=&AE<ELG=VEN9$=U<W0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("1U;FET<ULG=VEN9"==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'=E871H97);)W=I
M;F1687)I86)I;&ET>2==*2D@>PH@("`@("`@("`@("!I9B`H)'=E871H97);
M)W=I;F1687)I86)I;&ET>2==6R=F<F]M)UTI('L*("`@("`@("`@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H7R@B+"!V87)I86)L92!F<F]M("5S('1O("5S
M(BDL"B`@("`@("`@("`@("`@("`@("`@)'=E871H97);)W=I;F1687)I86)I
M;&ET>2==6R=F<F]M)UTL"B`@("`@("`@("`@("`@("`@("`@)'=E871H97);
M)W=I;F1687)I86)I;&ET>2==6R=T;R==*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+R\@5FES:6)I;&ET>2X*("`@("`@("!I9B`H:7-S
M970H)'=E871H97);)W9I<VEB:6QI='DG72DI('L*("`@("`@("`@("`@)&AT
M;6P@+CT@)'1H:7,M/E]S86UE4F]W*%\H(E9I<VEB:6QI='DB*2P@)'=E871H
M97);)W9I<VEB:6QI='DG72`N("<@)R`N("1U;FET<ULG=FES)UTI.PH@("`@
M("`@('T*"B`@("`@("`@+R\@5&5M<&5R871U<F4O1&5W4&]I;G0N"B`@("`@
M("`@:68@*&ES<V5T*"1W96%T:&5R6R=T96UP97)A='5R92==*2D@>PH@("`@
M("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")496UP97)A='5R92(I
M+"!R;W5N9"@D=V5A=&AE<ELG=&5M<&5R871U<F4G72D@+B`G)F1E9SLG("X@
M4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72DI.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-S970H)'=E871H97);)V1E=U!O:6YT)UTI*2!["B`@("`@
M("`@("`@("1H=&UL("X]("1T:&ES+3Y?<V%M95)O=RA?*")$97<@4&]I;G0B
M*2P@<F]U;F0H)'=E871H97);)V1E=U!O:6YT)UTI("X@)R9D96<[)R`N(%-T
M<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES<V5T*"1W96%T:&5R6R=F96QT5&5M<&5R871U<F4G72DI('L*
M("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]S86UE4F]W*%\H(D9E96QS
M($QI:V4B*2P@<F]U;F0H)'=E871H97);)V9E;'1496UP97)A='5R92==*2`N
M("<F9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*2D["B`@
M("`@("`@?0H*("`@("`@("`O+R!0<F5S<W5R92X*("`@("`@("!I9B`H:7-S
M970H)'=E871H97);)W!R97-S=7)E)UTI*2!["B`@("`@("`@("`@("1H=&UL
M("X]("1T:&ES+3Y?<F]W*%\H(E!R97-S=7)E(BDL("1W96%T:&5R6R=P<F5S
M<W5R92==("X@)R`G("X@)'5N:71S6R=P<F5S)UTI.PH@("`@("`@('T*"B`@
M("`@("`@+R\@2'5M:61I='DN"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R
M6R=H=6UI9&ET>2==*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^
M7W-A;652;W<H7R@B2'5M:61I='DB*2P@<F]U;F0H)'=E871H97);)VAU;6ED
M:71Y)UTI("X@)R4G*3L*("`@("`@("!]"@H@("`@("`@("\O($-L;W5D<RX*
M("`@("`@("!I9B`H:7-S970H)'=E871H97);)V-L;W5D<R==*2D@>PH@("`@
M("`@("`@("`D8VQO=61S(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1W
M96%T:&5R6R=C;&]U9',G72!A<R`D8VQO=60I('L*("`@("`@("`@("`@("`@
M("1C;&]U9',@+CT@)SQB<B`O/B<["B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&-L;W5D6R=H96EG:'0G72DI('L*("`@("`@("`@("`@("`@("`@("`D
M8VQO=61S("X]('-P<FEN=&8H7R@B)7,@870@)7,@)7,B*2P@)&-L;W5D6R=A
M;6]U;G0G72P@)&-L;W5D6R=H96EG:'0G72P@)'5N:71S6R=H96EG:'0G72D[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1C;&]U9',@+CT@)&-L;W5D6R=A;6]U;G0G73L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^
M7W)O=RA?*")#;&]U9',B*2P@)&-L;W5D<RD["B`@("`@("`@?0H*("`@("`@
M("`O+R!#;VYD:71I;VYS+@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG
M8V]N9&ET:6]N)UTI*2!["B`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?
M<F]W*%\H(D-O;F1I=&EO;G,B*2P@)'=E871H97);)V-O;F1I=&EO;B==*3L*
M("`@("`@("!]"@H@("`@("`@("\O(%)E;6%R:W,N"B`@("`@("`@:68@*&ES
M<V5T*"1W96%T:&5R6R=R96UA<FLG72DI('L*("`@("`@("`@("`@)')E;6%R
M:W,@/2`G)SL*("`@("`@("`@("`@)&]T:&5R(#T@)R<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1W96%T:&5R6R=R96UA<FLG72!A<R`D<F5M87)K(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`@("`@<W=I=&-H("@D<F5M87)K*2!["B`@
M("`@("`@("`@("`@("!C87-E("=S96%P<F5S<W5R92<Z"B`@("`@("`@("`@
M("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+B!?*")0<F5S<W5R92!A
M="!S96$@;&5V96PZ("(I("X@)'9A;'5E("X@)R`G("X@)'5N:71S6R=P<F5S
M)UT["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@8V%S92`G<')E8VEP:71A=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'9A;'5E(&%S("1P<F5C:7`I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7VYU;65R:6,H)'!R96-I<%LG86UO=6YT)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R
M("\^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT
M9BA?*")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R96-I
M<%LG:&]U<G,G72D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P<F5C:7!;)V%M;W5N="==("X@)R`G("X@)'5N:71S6R=R86EN)UT["B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")0<F5C:7!I=&%T
M:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!R96-I<%LG:&]U<G,G72D@+B`D
M<')E8VEP6R=A;6]U;G0G73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("=S;F]W9&5P=&@G.@H@("`@("`@
M("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B4VYO=R!D
M97!T:#H@(BD@+B`D=F%L=64@+B`G("<@+B`D=6YI='-;)W)A:6XG73L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E
M("=S;F]W97%U:78G.@H@("`@("`@("`@("`@("`@("`@("1R96UA<FMS("X]
M("<\8G(@+SXG("X@7R@B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B*2`N
M("1V86QU92`N("<@)R`N("1U;FET<ULG<F%I;B==.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W-U;F1U<F%T
M:6]N)SH*("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^
M)R`N('-P<FEN=&8H7R@B)7,@;6EN=71E<R(I+"`D=F%L=64I.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)S%H
M=&5M<"<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O
M/B<@+B!?*")496UP(&9O<B!L87-T(&AO=7(Z("(I("X@<F]U;F0H)'9A;'5E
M*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("<Q:&1E=R<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@
M)SQB<B`O/B<@+B!?*")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(BD@+B!R
M;W5N9"@D=F%L=64I("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S
M6R=T96UP)UTI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&-A<V4@)S9H;6%X=&5M<"<Z"B`@("`@("`@("`@("`@("`@
M("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+B!?*")-87@@=&5M<"!L87-T(#8@
M:&]U<G,Z("(I("X@<F]U;F0H)'9A;'5E*2`N("<F9&5G.R<@+B!3=')I;F<Z
M.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("<V:&UI;G1E;7`G.@H@("`@
M("`@("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B36EN
M('1E;7`@;&%S="`V(&AO=7)S.B`B*2`N(')O=6YD*"1V86QU92D@+B`G)F1E
M9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72D["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G,C1H
M;6%X=&5M<"<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB
M<B`O/B<@+B!?*")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B*2`N(')O=6YD
M*"1V86QU92D@+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E
M;7`G72D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G,C1H;6EN=&5M<"<Z"B`@("`@("`@("`@("`@("`@("`@
M)')E;6%R:W,@+CT@)SQB<B`O/B<@+B!?*")-:6X@=&5M<"!L87-T(#(T(&AO
M=7)S.B`B*2`N(')O=6YD*"1V86QU92D@+B`G)F1E9SLG("X@4W1R:6YG.CIU
M<'!E<B@D=6YI='-;)W1E;7`G72D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G<V5N<V]R<R<Z"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1S96YS;W(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7R@B4V5N<V]R.B`B*2`N("1S
M96YS;W(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("`@("`@)&]T:&5R("X]("<\8G(@+SXG("X@)'9A;'5E.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?
M*")296UA<FMS(BDL("1R96UA<FMS("X@)&]T:&5R*3L*("`@("`@("!]"@H@
M("`@("`@("\O(%1!1@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A
M;7-;)W1A9B==*2D@>PH@("`@("`@("`@("`D=&%F(#T@)&UE=&%R+3YG971&
M;W)E8V%S="@D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG72D["B`@("`@("`@
M("`@(&EF("@A:7-?82@D=&%F+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL
M<W!A8VEN9STB,"(^)SL*("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G
M/'1R/CQT9"!C;&%S<STB8V]N=')O;"(@8V]L<W!A;CTB,B(^/&-E;G1E<CX\
M<W1R;VYG/B<@+B!?*")&;W)E8V%S="`H5$%&*2(I("X@)SPO<W1R;VYG/CPO
M=&0^/"]T<CX\+W1A8FQE/B<["B`@("`@("`@("`@("`@("`D9F]R96-A<W0@
M+CT@)SQS=')O;F<^5F%L:60Z(#PO<W1R;VYG/B<@+B`D=&%F6R=V86QI9$9R
M;VTG72`N("<@+2`G("X@)'1A9ELG=F%L:614;R==("X@)SQB<B`O/CQB<B`O
M/B<["B`@("`@("`@("`@("`@("`D:71E;2`](#`["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=&%F6R=T:6UE)UT@87,@)'1I;64@/3X@)&5N=')Y*2![
M"B`@("`@("`@("`@("`@("`@("`@)&ET96TK*SL*("`@("`@("`@("`@("`@
M("`@("`D9F]R96-A<W0@+CT@)SQT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P
M86-I;F<](C`B/B<["B`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]
M("<\='(@8VQA<W,](FET96TG("X@*"1I=&5M("4@,BD@+B`G(CXG.PH@("`@
M("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1D(&%L:6=N/2)C96YT
M97(B('=I9'1H/2(U,"(^)R`N("1T:6UE("X@)SPO=&0^/'1D/CQS=')O;F<^
M5VEN9#H\+W-T<F]N9SX@)SL*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&5N=')Y6R=W:6YD)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D96YT<GE;)W=I;F1$:7)E8W1I;VXG72`]/2`G5F%R:6%B;&4G*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?<&%R86US6R=K;F]T<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F;W)E8V%S="`N/2!S<')I;G1F*%\H(B5S(&%T("5S("5S
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<G1O
M;&]W97(H)&5N=')Y6R=W:6YD1&ER96-T:6]N)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D;65T87(M/F-O;G9E<G13
M<&5E9"@D96YT<GE;)W=I;F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1U;FET<ULG=VEN9"==+"`G:W0G*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K="<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@<W!R:6YT9BA?*"(E<R!A
M="`E<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D96YT<GE;)W=I;F1$:7)E8W1I;VXG72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F]U;F0H)&5N=')Y6R=W:6YD)UTI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=6YI='-;)W=I;F0G
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("@H)&5N=')Y6R=W:6YD1&5G<F5E<R==
M(#T]("<P,#`G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`H)&5N=')Y6R=W:6YD)UT@/3T@)S`G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<F5C87-T("X]('-P<FEN=&8H7R@B8V%L;2(I
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2!S<')I;G1F*%\H(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R=W:6YD1&ER96-T
M:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E;G1R>5LG=VEN9$1E9W)E97,G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P
M87)A;7-;)VMN;W1S)UTI(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F]U;F0H)&5N=')Y6R=W:6YD)UTI(#H*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F]U
M;F0H)&UE=&%R+3YC;VYV97)T4W!E960H)&5N=')Y6R=W:6YD)UTL("1U;FET
M<ULG=VEN9"==+"`G:W0G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=K;F]T
M<R==*2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1U;FET<ULG=VEN9"==(#H*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VMT)RD["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T
M("X]("<\8G(@+SXG.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y6R=T96UP97)A='5R94QO=R==
M*2!\?"!I<W-E="@D96YT<GE;)W1E;7!E<F%T=7)E2&EG:"==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O;F<^5&5M
M<&5R871U<F4\+W-T<F]N9SXG.PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&5N=')Y6R=T96UP97)A='5R94QO=R==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG/B!,
M;W<Z/"]S=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`D96YT<GE;)W1E;7!E<F%T=7)E3&]W)UT["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1E;G1R>5LG=&5M<&5R871U<F5(:6=H)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O;F<^($AI
M9V@Z/"]S=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`D96YT<GE;)W1E;7!E<F%T=7)E2&EG:"==.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`G/&)R("\^)SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R>5LG=VEN9'-H96%R
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G
M/'-T<F]N9SY7:6YD<VAE87(Z/"]S=')O;F<^)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O<F5C87-T("X]('-P<FEN=&8H7R@B9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5N=')Y6R=W:6YD<VAE87)$:7)E8W1I;VXG72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5LG
M=VEN9'-H96%R1&5G<F5E<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&5N=')Y6R=W:6YD<VAE87)(96EG:'0G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;FET<ULG
M:&5I9VAT)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@
M+CT@)SQB<B`O/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;)W9I<VEB:6QI='DG72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG
M/E9I<VEB:6QI='DZ/"]S=')O;F<^("<["B`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S="`N/2!S=')T;VQO=V5R*"1E;G1R>5LG=FES475A;&EF
M:65R)UTI("X@)R`G("X@)&5N=')Y6R=V:7-I8FEL:71Y)UT@+B`G("<@+B`D
M=6YI='-;)W9I<R==.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@)SQB<B`O/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;)V-O;F1I=&EO;B==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O
M;F<^0V]N9&ET:6]N<SH\+W-T<F]N9SX@)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@)&9O<F5C87-T("X]("1E;G1R>5LG8V]N9&ET:6]N)UT["B`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/&)R("\^)SL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&9O<F5C
M87-T("X]("<\<W1R;VYG/D-L;W5D<SH\+W-T<F]N9SX@)SL*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D96YT<GE;)V-L;W5D<R==(&%S("1C;&]U
M9',I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;&]U
M9'-;)W1Y<&4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`G("<@+B`D8VQO=61S6R=T>7!E)UT["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C
M87-T("X]("<@)R`N("1C;&]U9'-;)V%M;W5N="==.PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&-L;W5D<ULG:&5I9VAT)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)R!A="`G
M("X@)&-L;W5D<ULG:&5I9VAT)UT@+B`G("<@+B`D=6YI='-;)VAE:6=H="==
M.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<@)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SPO=&0^/"]T<CXG.PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;)V9M8R==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D:71E;2LK.PH@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D96YT<GE;)V9M8R==(&%S("1F;6-%;G1R
M>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]
M("<\='(@8VQA<W,](FET96TG("X@*"1I=&5M("4@,BD@+B`G(CXG.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\=&0@86QI
M9VX](F-E;G1E<B(@=VED=&@](C4P(CXG.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O<F5C87-T("X]("<J("<@+B`D9FUC16YT<GE;)V9R;VTG
M72`N("<\8G(@+SX@+2`G("X@)&9M8T5N=')Y6R=T;R==("X@)SPO=&0^)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1D
M/B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M)SQS=')O;F<^5'EP93H@/"]S=')O;F<^)R`N("1F;6-%;G1R>5LG='EP92==
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F;6-%
M;G1R>5LG<')O8F%B:6QI='DG72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F]R96-A<W0@+CT@)R`\<W1R;VYG/B!0<F]B.B`\+W-T
M<F]N9SXG("X@)&9M8T5N=')Y6R=P<F]B86)I;&ET>2==("X@)R4G.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1F;6-%;G1R>5LG8V]N9&ET:6]N)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]
M("<@/'-T<F]N9SX@0V]N9&ET:6]N<SH@/"]S=')O;F<^)R`N("1F;6-%;G1R
M>5LG8V]N9&ET:6]N)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9M8T5N
M=')Y6R=C;&]U9',G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R96-A<W0@+CT@)R`\<W1R;VYG/D-L;W5D<SH\+W-T<F]N9SXG
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F
M;6-%;G1R>5LG8VQO=61S)UT@87,@)&9M8T-L;W5D<RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9M8T-L;W5D
M<ULG='EP92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O<F5C87-T("X]("<@)R`N("1F;6-#;&]U9'-;)W1Y<&4G
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9M
M8T-L;W5D<ULG:&5I9VAT)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)R`G("X@)&9M8T-L;W5D
M<ULG86UO=6YT)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)R`G("X@)&9M8T-L;W5D<ULG:&5I9VAT
M)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R96-A<W0@+CT@)R`G("X@)'5N:71S6R=H96EG:'0G73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G
M("<@+B`D9FUC0VQO=61S6R=A;6]U;G0G73L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FUC16YT<GE;)W9I
M<U%U86QI9FEE<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S="`N/2`G(#QS=')O;F<^5FES:6)I;&ET>3H\+W-T<F]N
M9SX@)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@<W1R=&]L;W=E<B@D9FUC16YT<GE;)W9I<U%U86QI9FEE<B==*2`N
M("<@)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@)&9M8T5N=')Y6R=V:7-I8FEL:71Y)UT@+B`G("<@+B`D=6YI='-;
M)W9I<R==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\+W1D/CPO='(^
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9F]R
M96-A<W0@+CT@)SPO=&%B;&4^)SL*"B`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`D9F]R96-A<W0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D:'1M;#L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]M;V]N
M+G!H<```````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3<P,C4`,3`T,3<S-C(W-S4`,#$W-S$S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HD8FQO8VM?;F%M92`](%\H
M(DUO;VX@4&AA<V5S(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO
M8VLO;6]O;BYP:'`L=B`Q+C$V+C$P+C0@,C`P-2\Q,"\Q."`Q,3HS,SHS.2!J
M86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S
M($AO<F1E7T)L;V-K7TAO<F1E7VUO;VX@97AT96YD<R!(;W)D95]";&]C:R![
M"@H@("`@=F%R("1?87!P(#T@)VAO<F1E)SL*"B`@("!F=6YC=&EO;B!?=&ET
M;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")-;V]N(%!H87-E<R(I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2@*("`@("`@("`@("`@)W!H87-E)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")7:&EC:"!P:&%S97,B*2P*("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@
M("`G9&5F875L="<@/3X@)V-U<G)E;G0G+`H@("`@("`@("`@("`@("`@)W9A
M;'5E<R<@/3X@87)R87DH)V-U<G)E;G0G(#T^(%\H(D-U<G)E;G0@-"!0:&%S
M97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N97AT
M)R`]/B!?*").97AT(#0@4&AA<V5S(BDI*2P*("`@("`@("`@("`@)VAE;6ES
M<&AE<F4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H
M(DAE;6ES<&AE<F4B*2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU
M;2<L"B`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)VYO<G1H97)N)RP*
M("`@("`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=N;W)T:&5R;B<@
M/3X@7R@B3F]R=&AE<FX@2&5M:7-P:&5R92(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-O=71H97)N)R`]/B!?*")3;W5T:&5R;B!(
M96UI<W!H97)E(BDI*2P*("`@("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@)'!H87-E<R`]("1T:&ES
M+3Y?8V%L8W5L871E36]O;E!H87-E<RAD871E*"=9)RDI.PH@("`@("`@("1N
M;W<@/2!T:6UE*"D["@H@("`@("`@("1L87-T3F5W(#T@,#L*("`@("`@("`D
M;&%S=$YE=U-T86UP(#T@,#L*("`@("`@("`D;V9F<V5T(#T@,#L*("`@("`@
M("!F;W)E86-H("@D<&AA<V5S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("!I9B`H)&ME>2`\("1N;W<@)B8@)&ME>2`^("1L87-T3F5W4W1A;7`@
M)B8@)'9A;"`]/2!?*").97<@36]O;B(I*2!["B`@("`@("`@("`@("`@("`D
M;&%S=$YE=R`]("1O9F9S970["B`@("`@("`@("`@("`@("`D;&%S=$YE=U-T
M86UP(#T@)&ME>3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;V9F<V5T
M*RL["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A
M;7-;)W!H87-E)UTI("8F("1T:&ES+3Y?<&%R86US6R=P:&%S92==(#T]("=N
M97AT)RD@>PH@("`@("`@("`@("`D9&%T97,@/2!A<G)A>5]S;&EC92AA<G)A
M>5]K97ES*"1P:&%S97,I+"`D;&%S=$YE=R`K(#0L(#0I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1D871E<R`](&%R<F%Y7W-L:6-E*&%R<F%Y
M7VME>7,H)'!H87-E<RDL("1L87-T3F5W+"`T*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG:&5M:7-P:&5R92==*2`F
M)B`D=&AI<RT^7W!A<F%M<ULG:&5M:7-P:&5R92==(#T]("=N;W)T:&5R;B<I
M('L*("`@("`@("`@("`@)&QO8V%T:6]N(#T@7R@B3F]R=&AE<FX@2&5M:7-P
M:&5R92(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1L;V-A=&EO
M;B`](%\H(E-O=71H97)N($AE;6ES<&AE<F4B*3L*("`@("`@("!]"@H@("`@
M("`@("1H=&UL(#T@)SQT86)L92!W:61T:#TB,3`P)2(@:&5I9VAT/2(Q,#`E
M(B!C96QL<W!A8VEN9STB,"(^)R`N"B`@("`@("`@("`@("<\='(^/'1D(&-O
M;'-P86X](C0B(&-L87-S/2)C;VYT<F]L(CX\<W1R;VYG/B<@+B`D;&]C871I
M;VX@+B`G/"]S=')O;F<^/"]T9#X\+W1R/B<@+@H@("`@("`@("`@("`G/'1R
M(&AE:6=H=#TB,3`P)2(^/'1D('=I9'1H/2(R-24B(&%L:6=N/2)C96YT97(B
M/B<@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+VYE=VUO
M;VXN<&YG)RP@7R@B3F5W($UO;VXB*2D@+@H@("`@("`@("`@("`G/&)R("\^
M)R`N('-T<F9T:6UE*"<E9"`E8B<L("1D871E<ULP72D@+@H@("`@("`@("`@
M("`G/"]T9#XG.PH*("`@("`@("`D:'1M;"`N/2`G/'1D('=I9'1H/2(R-24B
M(&%L:6=N/2)C96YT97(B/B<["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%R86US6R=H96UI<W!H97)E)UTI("8F("1T:&ES+3Y?<&%R86US6R=H96UI
M<W!H97)E)UT@/3T@)VYO<G1H97)N)RD@>PH@("`@("`@("`@("`D:'1M;"`N
M/2!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+VQA<W1Q=6%R=&5R+G!N9R<L(%\H
M(D9I<G-T(%%U87)T97(B*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&AT;6P@+CT@2&]R9&4Z.FEM9R@G8FQO8VLO;6]O;B]F:7)S='%U87)T
M97(N<&YG)RP@7R@B1FER<W0@475A<G1E<B(I*3L*("`@("`@("!]"B`@("`@
M("`@)&AT;6P@+CT@)SQB<B`O/B<@+B!S=')F=&EM92@G)60@)6(G+"`D9&%T
M97-;,5TI("X@)SPO=&0^)SL*"B`@("`@("`@)&AT;6P@+CT@)SQT9"!W:61T
M:#TB,C4E(B!A;&EG;CTB8V5N=&5R(CXG("X*("`@("`@("`@("`@2&]R9&4Z
M.FEM9R@G8FQO8VLO;6]O;B]F=6QL;6]O;BYP;F<G+"!?*")&=6QL($UO;VXB
M*2D@+@H@("`@("`@("`@("`G/&)R("\^)R`N('-T<F9T:6UE*"<E9"`E8B<L
M("1D871E<ULR72D@+B`G/"]T9#XG.PH*("`@("`@("`D:'1M;"`N/2`G/'1D
M('=I9'1H/2(R-24B(&%L:6=N/2)C96YT97(B/B<["B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=H96UI<W!H97)E)UTI("8F("1T:&ES+3Y?
M<&%R86US6R=H96UI<W!H97)E)UT@/3T@)VYO<G1H97)N)RD@>PH@("`@("`@
M("`@("`D:'1M;"`N/2!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+V9I<G-T<75A
M<G1E<BYP;F<G+"!?*"),87-T(%%U87)T97(B*2D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FEM9R@G8FQO8VLO;6]O
M;B]L87-T<75A<G1E<BYP;F<G+"!?*"),87-T(%%U87)T97(B*2D["B`@("`@
M("`@?0H@("`@("`@("1H=&UL("X]("<\8G(@+SXG("X@<W1R9G1I;64H)R5D
M("5B)RP@)&1A=&5S6S-=*2`N("<\+W1D/CPO='(^/"]T86)L93XG.PH*("`@
M("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&%N(&%R<F%Y('=I=&@@86QL('1H92!P:&%S97,@;V8@=&AE(&UO;VX@
M9F]R(&$@=VAO;&4*("`@("`J('EE87(N"B`@("`@*@H@("`@("H@0F%S960@
M;VX@8V]D92!F<F]M"B`@("`@*B!H='1P.B\O=W=W+GIE;F0N8V]M+V-O9&5X
M+G!H<#]I9#TX,S`F<VEN9VQE/3$@8GD@07)E(%!E9&5R<V5N+@H@("`@("H*
M("`@("`J($-O;G9E<G1E9"!F<F]M($)A<VEC(&)Y(%)O9V5R(%<N(%-I;FYO
M="P@4VMY("8@5&5L97-C;W!E+"!-87)C:"`Q.3@U+@H@("`@("H@0V]N=F5R
M=&5D(&9R;VT@:F%V87-C<FEP="!B>2!!<F4@4&5D97)S96X@,C`P,@H@("`@
M("H@2F%V87-C<FEP="!F;W5N9"!A="!H='1P.B\O=W=W+G-T96QL869A;F4N
M8V]M+VUO;VY?<&AA<V4O;6]O;E]P:&%S92YH=&T*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`@("1Y96%R("`@5&AE(&9O=7(@9&EG:70@>65A<B!T
M;R!R971U<FX@=&AE(&UO;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!P:&%S97,@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M("`@5&AE(&UO;VX@<&AA<V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L
M8W5L871E36]O;E!H87-E<R@D62D*("`@('L*("`@("`@("`D4C$@/2`S+C$T
M,34Y,C8U("\@,3@P.PH@("`@("`@("15("`](&9A;'-E.PH@("`@("`@("1+
M,"`](&EN='9A;"@H)%D@+2`Q.3`P*2`J(#$R+C,V.#4I.PH@("`@("`@("14
M("`]("@D62`M(#$X.3DN-2D@+R`Q,#`["B`@("`@("`@)%0R(#T@)%0@*B`D
M5#L*("`@("`@("`D5#,@/2`D5"`J("14("H@)%0["B`@("`@("`@)$HP(#T@
M,C0Q-3`R,"`K(#(Y("H@)$LP.PH@("`@("`@("1&,"`](#`N,#`P,3$W."`J
M("14,B`M(#`N,#`P,#`P,34U("H@)%0S.PH@("`@("`@("1&,"`K/2`H,"XW
M-3DS,R`K(#`N-3,P-3@X-C@J)$LP*3L*("`@("`@("`D1C`@+3T@*#`N,#`P
M.#,W("H@)%0@*R`P+C`P,#,S-2`J("14,BD["B`@("`@("`@)$TP("`]("1+
M,"`J(#`N,#@P.#0X,C$Q,S,["B`@("`@("`@)$TP("`](#,V,"`J("@D33`@
M+2!I;G1V86PH)$TP*2D@*R`S-3DN,C(T,CL*("`@("`@("`D33`@+3T@,"XP
M,#`P,S,S("H@)%0R.PH@("`@("`@("1-,"`M/2`P+C`P,#`P,S0W("H@)%0S
M.PH@("`@("`@("1-,2`@/2`D2S`@*B`P+C`W,3<Q,S8V,3(X.PH@("`@("`@
M("1-,2`@/2`S-C`@*B`H)$TQ("T@:6YT=F%L*"1-,2DI("L@,S`V+C`R-3,[
M"B`@("`@("`@)$TQ("L](#`N,#$P-S,P-B`J("14,CL*("`@("`@("`D33$@
M*ST@,"XP,#`P,3(S-B`J("14,SL*("`@("`@("`D0C$@(#T@)$LP("H@,"XP
M.#4Q.34X-3$R.#L*("`@("`@("`D0C$@(#T@,S8P("H@*"1",2`M(&EN='9A
M;"@D0C$I*2`K(#(Q+C(Y-C0["B`@("`@("`@)$(Q("T](#`N,#`Q-C4R."`J
M("14,CL*("`@("`@("`D0C$@+3T@,"XP,#`P,#(S.2`J("14,SL*("`@("`@
M("!F;W(@*"1+.2`](#`[("1+.2`\/2`R.#L@)$LY(#T@)$LY("L@,"XU*2![
M"B`@("`@("`@("`@("1*(#T@)$HP("L@,30@*B`D2SD["B`@("`@("`@("`@
M("1&(#T@)$8P("L@,"XW-C4R.30@*B`D2SD["B`@("`@("`@("`@("1+(#T@
M)$LY("\@,CL*("`@("`@("`@("`@)$TU(#T@*"1-,"`K("1+("H@,CDN,3`U
M,S4V,#@I("H@)%(Q.PH@("`@("`@("`@("`D338@/2`H)$TQ("L@)$L@*B`S
M.#4N.#$V.3$X,#8I("H@)%(Q.PH@("`@("`@("`@("`D0C8@/2`H)$(Q("L@
M)$L@*B`S.3`N-C<P-3`V-#8I("H@)%(Q.PH@("`@("`@("`@("`D1B`M/2`P
M+C0P-C@@*B!S:6XH)$TV*3L*("`@("`@("`@("`@)$8@*ST@*#`N,3<S-"`M
M(#`N,#`P,SDS("H@)%0I("H@<VEN*"1--2D["B`@("`@("`@("`@("1&("L]
M(#`N,#$V,2`J('-I;B@R("H@)$TV*3L*("`@("`@("`@("`@)$8@*ST@,"XP
M,3`T("H@<VEN*#(@*B`D0C8I.PH@("`@("`@("`@("`D1B`M/2`P+C`P-S0@
M*B!S:6XH)$TU("T@)$TV*3L*("`@("`@("`@("`@)$8@+3T@,"XP,#4Q("H@
M<VEN*"1--2`K("1--BD["B`@("`@("`@("`@("1&("L](#`N,#`R,2`J('-I
M;B@R("H@)$TU*3L*("`@("`@("`@("`@)$8@*ST@,"XP,#$P("H@<VEN*#(@
M*B`D0C8@+2`D338I.PH*("`@("`@("`@("`@+RH@061D(#$O,B!M:6YU=&4@
M9F]R('!R;W!E<B!R;W5N9&EN9R!T;R!M:6YU=&5S('!E<B!3:WD@)@H@("`@
M("`@("`@("`@*B!496P@87)T:6-L92X@*B\*("`@("`@("`@("`@)$8@*ST@
M,"XU("\@,30T,#L*("`@("`@("`@("`@)$H@*ST@:6YT=F%L*"1&*3L*("`@
M("`@("`@("`@)$8@+3T@:6YT=F%L*"1&*3L*"B`@("`@("`@("`@("\J($-O
M;G9E<G0@9G)O;2!*1"!T;R!#86QE;F1A<B!$871E+B`J+PH@("`@("`@("`@
M("`D:G5L:6%N(#T@)$H@*R!R;W5N9"@D1BD["B`@("`@("`@("`@("1P87)T
M<R`@/2!E>'!L;V1E*"<O)RP@)'1H:7,M/E]J9'1O9W)E9V]R:6%N*"1J=6QI
M86XI*3L*("`@("`@("`@("`@)'-T86UP("`](&=M;6MT:6UE*#`L(#`L(#`L
M("1P87)T<ULP72P@)'!A<G1S6S%=+"`D<&%R='-;,ETI.PH*("`@("`@("`@
M("`@+RH@:&%L9B!++B`J+PH@("`@("`@("`@("!I9B`H*"1+.2`M(&9L;V]R
M*"1+.2DI(#X@,"D@>PH@("`@("`@("`@("`@("`@:68@*"15*2!["B`@("`@
M("`@("`@("`@("`@("`@+RH@3F5W(&AA;&8N("HO"B`@("`@("`@("`@("`@
M("`@("`@)'!H87-E<ULD<W1A;7!=(#T@7R@B1FER<W0@2&%L9B(I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!&
M=6QL(&AA;&8N("HO"B`@("`@("`@("`@("`@("`@("`@)'!H87-E<ULD<W1A
M;7!=(#T@7R@B3&%S="!(86QF(BD["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!F=6QL($LN("HO
M"B`@("`@("`@("`@("`@("!I9B`H(215*2!["B`@("`@("`@("`@("`@("`@
M("`@)'!H87-E<ULD<W1A;7!=(#T@7R@B3F5W($UO;VXB*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!H87-E<ULD
M<W1A;7!=(#T@7R@B1G5L;"!-;V]N(BD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D52`]("$D53L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1P:&%S97,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@:68@=&AE(&ID=&]G<F5G;W)I86X@9G5N8W1I;VX@97AI
M<W1S+"!A;F0@:68@;F]T"B`@("`@*B!C86QC=6QA=&5S('1H92!G<F5G;W)I
M86X@9&%T92!M86YU86QL>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1J
M=6QI86X@5&AE(&IU;&EA;B!D871E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@;2]D+UD*("`@("`J+PH@("`@9G5N8W1I;VX@7VID=&]G<F5G;W)I
M86XH)&IU;&EA;BD*("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"=J9'1O9W)E9V]R:6%N)RDI('L*("`@("`@("`@("`@<F5T=7)N(&ID=&]G
M<F5G;W)I86XH)&IU;&EA;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+R\@1G)O;2!H='1P.B\O<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN
M:F1T;V=R96=O<FEA;BYP:'`*("`@("`@("`@("`@)&IU;&EA;B`]("1J=6QI
M86X@+2`Q-S(Q,3$Y.PH@("`@("`@("`@("`D8V%L8S$@/2`T("H@)&IU;&EA
M;B`M(#$["B`@("`@("`@("`@("1Y96%R(#T@9FQO;W(H)&-A;&,Q("\@,30V
M,#DW*3L*("`@("`@("`@("`@)&IU;&EA;B`](&9L;V]R*"1C86QC,2`M(#$T
M-C`Y-R`J("1Y96%R*3L*("`@("`@("`@("`@)&1A>2`](&9L;V]R*"1J=6QI
M86X@+R`T*3L*("`@("`@("`@("`@)&-A;&,R(#T@-"`J("1D87D@*R`S.PH@
M("`@("`@("`@("`D:G5L:6%N(#T@9FQO;W(H)&-A;&,R("\@,30V,2D["B`@
M("`@("`@("`@("1D87D@/2`D8V%L8S(@+2`Q-#8Q("H@)&IU;&EA;CL*("`@
M("`@("`@("`@)&1A>2`](&9L;V]R*"@D9&%Y("L@-"D@+R`T*3L*("`@("`@
M("`@("`@)&-A;&,S(#T@-2`J("1D87D@+2`S.PH@("`@("`@("`@("`D;6]N
M=&@@/2!F;&]O<B@D8V%L8S,@+R`Q-3,I.PH@("`@("`@("`@("`D9&%Y(#T@
M)&-A;&,S("T@,34S("H@)&UO;G1H.PH@("`@("`@("`@("`D9&%Y(#T@9FQO
M;W(H*"1D87D@*R`U*2`O(#4I.PH@("`@("`@("`@("`D>65A<B`](#$P,"`J
M("1Y96%R("L@)&IU;&EA;CL*"B`@("`@("`@("`@(&EF("@D;6]N=&@@/"`Q
M,"D@>PH@("`@("`@("`@("`@("`@)&UO;G1H(#T@)&UO;G1H("L@,SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M;VYT:"`]("1M
M;VYT:"`M(#D["B`@("`@("`@("`@("`@("`D>65A<B`]("1Y96%R("L@,3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@(B1M;VYT:"\D9&%Y
M+R1Y96%R(CL*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O0FQO8VLO<W5N<FES92YP:'``````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-C4U`#$P-#$W,S8R-S<U`#`R,#0S-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*)&)L;V-K7VYA;64@/2!?*")3=6YR:7-E+U-U;G-E="(I.PH*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+W-U;G)I<V4N<&AP+'8@,2XQ-"XQ
M,"XS(#(P,#4O,3`O,3@@,3$Z,S,Z,SD@:F%N($5X<"`D"B`J"B`J($!P86-K
M86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]S
M=6YR:7-E(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]
M("=H;W)D92<["@H@("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*("`@("`@
M("!R971U<FX@7R@B4W5N<FES92]3=6YS970B*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH
M)VQO8V%T:6]N)R`]/B!A<G)A>2@G='EP92<@/3X@)VUL96YU;2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^(%\H(DQO8V%T:6]N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<U,2XU,3<Z+3`N,3$W
M)RDI.PH*("`@("`@("!G;&]B86P@)&-O;W)D:6YA=&5S.PH@("`@("`@(&EF
M("@A:7-?87)R87DH)&-O;W)D:6YA=&5S*2D@>PH@("`@("`@("`@("!`:6YC
M;'5D92`G2&]R9&4O3DQ3+V-O;W)D:6YA=&5S+G!H<"<["B`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)&-O;W)D:6YA=&5S*2D@>PH@("`@("`@("`@("`@
M("`@)&-O;W)D:6YA=&5S(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`D<&%R86US6R=L;V-A=&EO;B==6R=V86QU97,G72`]
M("1C;V]R9&EN871E<SL*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@("!]
M"@H@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG72DI('L*("`@("`@("`@
M("`@<F5T=7)N(%\H(DYO(&QO8V%T:6]N(&ES('-E="XB*3L*("`@("`@("!]
M"@H@("`@("`@("\O(%-E="!T:&4@=&EM97IO;F4@=F%R:6%B;&4L(&EF(&%V
M86EL86)L92X*("`@("`@("!.3%,Z.G-E=%1I;65:;VYE*"D["@H@("`@("`@
M(&QI<W0H)&QA="P@)&QO;F<I(#T@97AP;&]D92@G.B<L("1T:&ES+3Y?<&%R
M86US6R=L;V-A=&EO;B==*3L*("`@("`@("`D<FES92`]("1T:&ES+3Y?8V%L
M8W5L871E4W5N<V5T*'1I;64H*2P@)&QA="P@)&QO;F<L(&9A;'-E+"!F;&]O
M<BAD871E*"=:)RD@+R`S-C`P*2D["B`@("`@("`@)'-E="`]("1T:&ES+3Y?
M8V%L8W5L871E4W5N<V5T*'1I;64H*2P@)&QA="P@)&QO;F<L('1R=64L(&9L
M;V]R*&1A=&4H)UHG*2`O(#,V,#`I*3L*"B`@("`@("`@)&QO8V%T:6]N(#T@
M)R<["B`@("`@("`@9VQO8F%L("1C;V]R9&EN871E<SL*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1C;V]R9&EN871E<RDI('L*("`@("`@("`@("`@<F5Q=6ER
M92`G2&]R9&4O3DQ3+V-O;W)D:6YA=&5S+G!H<"<["B`@("`@("`@?0H@("`@
M("`@(&9O<F5A8V@@*"1C;V]R9&EN871E<R!A<R`D8V]U;G1R>2D@>PH@("`@
M("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D=&AI<RT^7W!A<F%M<ULG
M;&]C871I;VXG72P@)&-O=6YT<GDI*2!["B`@("`@("`@("`@("`@("`D;&]C
M871I;VX@/2`D8V]U;G1R>5LD=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG75T[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("<\=&%B;&4@=VED=&@](C$P,"4B(&AE:6=H
M=#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/CQT<CXG("X*("`@("`@("`@("`@
M)SQT9"!C;VQS<&%N/2(R(B!C;&%S<STB8V]N=')O;"(^/'-T<F]N9SXG("X@
M)&QO8V%T:6]N("X@)SPO<W1R;VYG/CPO=&0^/"]T<CX\='(@:&5I9VAT/2(Q
M,#`E(CXG("X*("`@("`@("`@("`@)SQT9"!W:61T:#TB-3`E(B!A;&EG;CTB
M8V5N=&5R(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO<W5N
M<FES92]S=6YR:7-E+G!N9R<L(%\H(E-U;B!2:7-E(BDI("X*("`@("`@("`@
M("`@)SQB<B`O/B<@+B`D<FES92`N("<\+W1D/B<@+@H@("`@("`@("`@("`G
M/'1D('=I9'1H/2(U,"4B(&%L:6=N/2)C96YT97(B/B<@+@H@("`@("`@("`@
M("!(;W)D93HZ:6UG*"=B;&]C:R]S=6YR:7-E+W-U;G-E="YP;F<G+"!?*")3
M=6X@4V5T(BDI("X*("`@("`@("`@("`@)SQB<B`O/B<@+B`D<V5T("X@)SPO
M=&0^)R`N("<\+W1R/CPO=&%B;&4^)SL*("`@('T*"B`@("`O*BH*("`@("`J
M(&AT='`Z+R]W=W<N>F5N9"YC;VTO8V]D97@N<&AP/VED/3$S-29S:6YG;&4]
M,0H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L8W5L871E4W5N<V5T*"1D871E
M+"`D;&%T:71U9&4L("1L;VYG:71U9&4L("1S=6YS970@/2!T<G5E+"`D=&EM
M97IO;F4I"B`@("!["B`@("`@("`@)'ED87D@/2!D871E*"=Z)RP@)&1A=&4I
M.PH@("`@("`@("1M;VX@/2!D871E*"=N)RP@)&1A=&4I.PH@("`@("`@("1M
M9&%Y(#T@9&%T92@G:B<L("1D871E*3L*("`@("`@("`D>65A<B`](&1A=&4H
M)UDG+"`D9&%T92D["@H@("`@("`@(&EF("@D=&EM97IO;F4@/3T@)S$S)RD@
M>PH@("`@("`@("`@("`D=&EM97IO;F4@/2`G+3$Q)SL*("`@("`@("`@("`@
M)&UD87DK*SL*("`@("`@("`@("`@)'ED87DK*SL*("`@("`@("!]"@H@("`@
M("`@("1!(#T@,2XU-S`X.PH@("`@("`@("1"(#T@,RXQ-#$U.3L*("`@("`@
M("`D0R`](#0N-S$R,SD["B`@("`@("`@)$0@/2`V+C(X,S$Y.PH@("`@("`@
M("1%(#T@,"XP,3<T-3,S("H@)&QA=&ET=61E.PH@("`@("`@("1&(#T@,"XP
M,3<T-3,S("H@)&QO;F=I='5D93L*("`@("`@("`D1R`](#`N,C8Q-SDY("`J
M("1T:6UE>F]N93L*"B`@("`@("`@+R\@1F]R(&%S=')O;F]M:6-A;"!T=VEL
M:6=H="P@=7-E(%(@/2`M+C,P.3`Q-PH@("`@("`@("\O($9O<B!N875T:6-A
M;"!T=VEL:6=H="P@=7-E(%(@/2`M+C(P-SDQ,@H@("`@("`@("\O($9O<B!C
M:79I;"!T=VEL:6=H="P@=7-E(%(@/2`M+C$P-#4R.`H@("`@("`@("\O($9O
M<B!S=6YR:7-E(&]R('-U;G-E="P@=7-E(%(@/2`M+C`Q-#4T,SD*("`@("`@
M("`D4B`]("TN,#$T-30S.3L*"B`@("`@("`@:68@*"1S=6YS970I('L*("`@
M("`@("`@("`@)$H@/2`D0SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D2B`]("1!.PH@("`@("`@('T*"B`@("`@("`@)$L@/2`D>61A>2`K("@H
M)$H@+2`D1BD@+R`D1"D["B`@("`@("`@)$P@/2`H)$L@*B`N,#$W,C`R*2`M
M("XP-3<T,#,Y.R`@("`@("`@("`@("`@+R\@4V]L87(@365A;B!!;F]M;VQY
M"B`@("`@("`@)$T@/2`D3"`K("XP,S,T-#`U("H@<VEN*"1,*3L@("`@("`@
M("`@("`@("`@+R\@4V]L87(@5')U92!,;VYG:71U9&4*("`@("`@("`D32`K
M/2`T+CDS,C@Y("L@*#,N-#DP-C9%+3`T*2`J('-I;B@R("H@)$PI.R`O+R!1
M=6%D<F%N="!$971E<FUI;F%T:6]N"B`@("`@("`@=VAI;&4@*"1-(#P@,"D@
M>PH@("`@("`@("`@("`D32`]("@D32`K("1$*3L*("`@("`@("!]"B`@("`@
M("`@=VAI;&4@*"1-(#X]("1$*2!["B`@("`@("`@("`@("1-(#T@*"1-("T@
M)$0I.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D32`O("1!*2`M(&EN='9A
M;"@D32`O("1!*2`]/2`P*2!["B`@("`@("`@("`@("1-("L](#0N.#0X,31%
M+3`V.PH@("`@("`@('T*"B`@("`@("`@)%`@/2!S:6XH)$TI("\@8V]S*"1-
M*3L@("`@("`@("`@("`@("`@("`@+R\@4V]L87(@4FEG:'0@07-C96YS:6]N
M"B`@("`@("`@)%`@/2!A=&%N,B@N.3$W-#8@*B`D4"P@,2D["@H@("`@("`@
M("\O(%%U861R86YT($%D:G5S=&UE;G0*("`@("`@("!I9B`H)$T@/B`D0RD@
M>PH@("`@("`@("`@("`D4"`K/2`D1#L*("`@("`@("!](&5L<V5I9B`H)$T@
M/B`D02D@>PH@("`@("`@("`@("`D4"`K/2`D0CL*("`@("`@("!]"@H@("`@
M("`@("11(#T@+C,Y-S@R("H@<VEN*"1-*3L@("`@("`@("`@("`O+R!3;VQA
M<B!$96-L:6YA=&EO;@H@("`@("`@("11(#T@)%$@+R!S<7)T*"TD42`J("11
M("L@,2D[("`@("`O+R!4:&ES(&ES(&AO=R!T:&4@;W)I9VEN86P@875T:&]R
M('=R;W1E(&ET(0H@("`@("`@("11(#T@871A;C(H)%$L(#$I.PH*("`@("`@
M("`D4R`]("12("T@*'-I;B@D42D@*B!S:6XH)$4I*3L*("`@("`@("`D4R`]
M("13("\@*&-O<R@D42D@*B!C;W,H)$4I*3L*"B`@("`@("`@:68@*&%B<R@D
M4RD@/B`Q*2!["B`@("`@("`@("`@(')E='5R;B`G;F]N92<[("`@("`@("`@
M("`@("`@("\O($YU;&P@<&AE;F]M96YO;@H@("`@("`@('T*"B`@("`@("`@
M)%,@/2`D4R`O('-Q<G0H+213("H@)%,@*R`Q*3L*("`@("`@("`D4R`]("1!
M("T@871A;C(H)%,L(#$I.PH*("`@("`@("!I9B`H(21S=6YS970I('L*("`@
M("`@("`@("`@)%,@/2`D1"`M("13(#L*("`@("`@("!]"@H@("`@("`@("14
M(#T@)%,@*R`D4"`M(#`N,#$W,C`R."`J("1+("T@,2XW,S,V-#L@+R\@3&]C
M86P@87!P87)E;G0@=&EM90H@("`@("`@("15(#T@)%0@+2`D1CL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@56YI=F5R<V%L('1I;65R"B`@("`@
M("`@)%8@/2`D52`K("1'.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!786QL(&-L;V-K('1I;64*"B`@("`@("`@+R\@475A9')A;G0@1&5T97)M
M:6YA=&EO;@H@("`@("`@('=H:6QE("@D5B`\(#`I('L*("`@("`@("`@("`@
M)%8@/2`H)%8@*R`D1"D["B`@("`@("`@?0H@("`@("`@('=H:6QE("@D5B`^
M/2`D1"D@>PH@("`@("`@("`@("`D5B`]("@D5B`M("1$*3L*("`@("`@("!]
M"B`@("`@("`@)%8@/2`D5B`J(#,N.#$Y-S(["@H@("`@("`@("1H;W5R(#T@
M:6YT=F%L*"16*3L*("`@("`@("`D5B`@("T]("1H;W5R.PH@("`@("`@("1M
M:6X@(#T@:6YT=F%L*"16("H@-C`I.PH@("`@("`@("16("`@+3T@)&UI;B`O
M(#8P.PH@("`@("`@("1S96,@(#T@:6YT=F%L*"16("H@,S8P,"D["@H@("`@
M("`@(')E='5R;B!S=')F=&EM92@G)5@G+"!M:W1I;64H)&AO=7(L("1M:6XL
M("1S96,L("1M;VXL("1M9&%Y+"`D>65A<BDI.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+T)L;V-K+W1I;64N<&AP````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`T-P`Q,#0Q-S,V,C<W-0`P
M,3<W,#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B0W5R<F5N="!4:6UE(BD["@HO
M*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO=&EM92YP:'`L=B`Q+C$V
M(#(P,#0O,3$O,C,@,34Z,3<Z-3,@8VAU8VL@17AP("0*("H*("H@0'!A8VMA
M9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7W1I
M;64@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P(#T@)VAO
M<F1E)SL*"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("!R
M971U<FX@)'!A<F%M<R`](&%R<F%Y*"=T:6UE)R`]/B!A<G)A>2@G='EP92<@
M/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")4:6UE(&9O<FUA="(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M969A=6QT)R`]/B`G,C0M:&]U<B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH)S(T
M+6AO=7(G(#T^(%\H(C(T($AO=7(@1F]R;6%T(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)S$R+6AO=7(G(#T^(%\H(C$R($AO=7(@1F]R;6%T(BDI*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L
M92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!?*")#=7)R96YT(%1I;64B*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=T:6UE)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T:6UE)UT@/2`G,C0M:&]U<B<["B`@("`@("`@
M?0H*("`@("`@("`O+R!3970@=&AE('1I;65Z;VYE('9A<FEA8FQE+"!I9B!A
M=F%I;&%B;&4N"B`@("`@("`@3DQ3.CIS9714:6UE6F]N92@I.PH*("`@("`@
M("`D:'1M;"`]("<\=&%B;&4@=VED=&@](C$P,"4B(&AE:6=H=#TB,3`P)2(^
M/'1R/CQT9"!S='EL93TB9F]N="UF86UI;'DZ=F5R9&%N83MF;VYT+7-I>F4Z
M,3AP>#LB(&%L:6=N/2)C96YT97(B('9A;&EG;CTB;6ED9&QE(CXG.PH@("`@
M("`@("1H=&UL("X]('-T<F9T:6UE*"<E02P@)4(@)60L("59("<I.PH@("`@
M("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG=&EM92==(#T]("<R-"UH;W5R)RD@
M>PH@("`@("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G)4@Z)4TG*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G
M)4DZ)4T@)7`G*3L*("`@("`@("!]"B`@("`@("`@)&AT;6P@+CT@)SPO=&0^
M/"]T<CX\+W1A8FQE/B<["@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<```````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#,V-30`,3`T,3<S-C(W-S4`,#(Q-C$W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*B!$:7-A8FQE(&)L;V-K(&EF(&YO="!C;VYF:6=U<F5D+B`J+PII
M9B`H(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)W=E871H97)D;W1C;VTG75LG
M<&%R=&YE<E]I9"==*2`F)@H@("`@(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;
M)W=E871H97)D;W1C;VTG75LG;&EC96YS95]K97DG72DI('L*("`@("1B;&]C
M:U]N86UE(#T@7R@B=V5A=&AE<BYC;VTB*3L*?0H*+RHJ"B`J(%1H92!(;W)D
M95]";&]C:U]W96%T:&5R9&]T8V]M(&-L87-S('!R;W9I9&5S(&%N(&%P<&QE
M="!F;W(@=&AE"B`J('!O<G1A;"!S8W)E96X@=&\@9&ES<&QA>2!W96%T:&5R
M(&%N9"!F;W)E8V%S="!D871A(&9R;VT@=V5A=&AE<BYC;VT*("H@9F]R(&$@
M<W!E8VEF:65D(&QO8V%T:6]N+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<"QV(#$N,S<N-"XQ,R`R,#`U+S$R+S`U
M(#`S.C0Q.C`P(&-H=6-K($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L
M;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]W96%T:&5R9&]T8V]M
M(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=H;W)D
M92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L
M92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!?*")796%T:&5R($9O<F5C87-T(BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4:&4@<&%R86UE=&5R<R!T;R!G;R!W:71H('1H:7,@
M8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M8V]N=&%I;FEN9R!T:&4@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W!A<F%M<R@I"B`@("!["B`@("`@("`@:68@*"$H0&EN8VQU9&5?;VYC
M92`G4V5R=FEC97,O5V5A=&AE<BYP:'`G*2!\?`H@("`@("`@("`@("`A*$!I
M;F-L=61E7V]N8V4@)T-A8VAE+G!H<"<I('Q\"B`@("`@("`@("`@("$H0&EN
M8VQU9&5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)RD@?'P*("`@("`@("`@
M("`@(6EN:5]G970H)V%L;&]W7W5R;%]F;W!E;B<I*2!["B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=4:&4@=V5A=&AE<BYC;VT@8FQO8VL@=VEL
M;"!N;W0@=V]R:R!W:71H;W5T(%!%05)<)W,@4V5R=FEC97-?5V5A=&AE<BP@
M0V%C:&4L(&%N9"!834Q?(%-E<FEA;&EZ97(@<&%C:V%G97,L(&%N9"!A;&QO
M=U]U<FQ?9F]P96X@96YA8FQE9"X@4G5N(&!P96%R(&EN<W1A;&P@4V5R=FEC
M97-?5V5A=&AE<B!#86-H92!834Q?4V5R:6%L:7IE<K0@86YD(&5N<W5R92!T
M:&%T(&%L;&]W7W5R;%]F;W!E;B!I<R!E;F%B;&5D(&EN('!H<"YI;FDN)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`D<&%R86US(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G97)R;W(G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G97)R;W(G+`H@("`@("`@("`@("`@
M("`@("`@("=N86UE)R`]/B!?*")%<G)O<B(I+`H@("`@("`@("`@("`@("`@
M("`@("=D969A=6QT)R`]/B!?*")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@
M;F]T(&%V86EL86)L92XB*0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@
M("`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)A;7,@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("=L;V-A=&EO;B<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@+R\@)W1Y<&4G(#T^("=W96%T:&5R9&]T8V]M
M)RP*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*"),;V-A=&EO;B(I+`H@("`@
M("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G0F]S=&]N+"!-02<*("`@
M("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G=6YI=',G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E5N:71S(BDL"B`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("=S=&%N9&%R9"<L"B`@("`@
M("`@("`@("`@("`@("`@)S`G(#T^("=N;VYE)RP*("`@("`@("`@("`@("`@
M("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@)W-T86YD87)D)R`]/B!?*")3=&%N9&%R9"(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G;65T<FEC)R`]/B!?*")-971R:6,B*0H@("`@("`@("`@
M("`@("`@("`@("D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@
M("`G9&%Y<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(I+`H@("`@("`@
M("`@("`@("`@("`@("=D969A=6QT)R`]/B`G,R<L"B`@("`@("`@("`@("`@
M("`@("`@)W9A;'5E<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("<Q)R`]/B`G,2<L"B`@("`@("`@("`@("`@("`@("`@("`@("<R)R`]
M/B`G,B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<S)R`]/B`G,R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<T)R`]/B`G-"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("<U)R`]/B`G-2<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("<V)R`]/B`G-B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<W)R`]
M/B`G-R<L"B`@("`@("`@("`@("`@("`@("`@("`@("<X)R`]/B`G."<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<Y)R`]/B`G.2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("<Q,"<@/3X@)S$P)PH@("`@("`@("`@("`@("`@("`@
M("D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G9&5T86EL
M961&;W)E8V%S="<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G(#T^("=C:&5C:V)O>"<L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^(%\H(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B*2P*("`@("`@("`@
M("`@("`@("`@("`G9&5F875L="<@/3X@,`H@("`@("`@("`@("`@("`@*0H@
M("`@("`@("`@("`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@
M5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@
M("`@>PH@("`@("`@(&EF("@A*$!I;F-L=61E7V]N8V4@)U-E<G9I8V5S+U=E
M871H97(N<&AP)RD@?'P*("`@("`@("`@("`@(2A`:6YC;'5D95]O;F-E("=#
M86-H92YP:'`G*2!\?`H@("`@("`@("`@("`A:6YI7V=E="@G86QL;W=?=7)L
M7V9O<&5N)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U1H
M92!W96%T:&5R+F-O;2!B;&]C:R!W:6QL(&YO="!W;W)K('=I=&AO=70@=&AE
M(%!%05)397)V:6-E<U]796%T:&5R(&%N9"!#86-H92!P86-K86=E<RP@86YD
M(&%L;&]W7W5R;%]F;W!E;B!E;F%B;&5D+B!2=6X@<&5A<B!I;G-T86QL(%-E
M<G9I8V5S7U=E871H97(@0V%C:&4L(&%N9"!E;G-U<F4@=&AA="!A;&QO=U]U
M<FQ?9F]P96Y?=W)A<'!E<G,@:7,@96YA8FQE9"!I;B!P:'`N:6YI+B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%\H(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(I.PH@("`@("`@
M('T*"B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E
M='5R;B!?*").;R!L;V-A=&EO;B!I<R!S970N(BD["B`@("`@("`@?0H*("`@
M("`@("`D=V5A=&AE<D1O=$-O;2`]("9397)V:6-E<U]796%T:&5R.CIS97)V
M:6-E*"=796%T:&5R1&]T0V]M)RD["B`@("`@("`@)'=E871H97)$;W1#;VTM
M/G-E=$%C8V]U;G1$871A*`H@("`@("`@("`@("`H:7-S970H)&-O;F9;)W=E
M871H97)D;W1C;VTG75LG<&%R=&YE<E]I9"==*2`_("1C;VYF6R=W96%T:&5R
M9&]T8V]M)UU;)W!A<G1N97)?:60G72`Z("<G*2P*("`@("`@("`@("`@*&ES
M<V5T*"1C;VYF6R=W96%T:&5R9&]T8V]M)UU;)VQI8V5N<V5?:V5Y)UTI(#\@
M)&-O;F9;)W=E871H97)D;W1C;VTG75LG;&EC96YS95]K97DG72`Z("<G*2D[
M"@H@("`@("`@("1C86-H941I<B`]($AO<F1E.CIG971496UP1&ER*"D["B`@
M("`@("`@:68@*"$D8V%C:&5$:7(I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I
M;&%B;&4@9F]R(&-A8VAE+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=V5A=&AE<D1O=$-O;2T^<V5T0V%C:&4H
M)V9I;&4G+"!A<G)A>2@G8V%C:&5?9&ER)R`]/B`H)&-A8VAE1&ER("X@)R\G
M*2DI.PH@("`@("`@('T*("`@("`@("`D=V5A=&AE<D1O=$-O;2T^<V5T1&%T
M951I;65&;W)M870H)VTN9"Y9)RP@)T@Z:2<I.PH@("`@("`@("1W96%T:&5R
M1&]T0V]M+3YS9715;FET<T9O<FUA="@D=&AI<RT^7W!A<F%M<ULG=6YI=',G
M72D["B`@("`@("`@)'5N:71S(#T@)'=E871H97)$;W1#;VTM/F=E=%5N:71S
M1F]R;6%T*"D["@H@("`@("`@("\O($EF('1H92!U<V5R(&5N=&5R960@82!Z
M:7`@8V]D92!F;W(@=&AE(&QO8V%T:6]N+"!N;R!N965D('1O"B`@("`@("`@
M+R\@<V5A<F-H("AW96%T:&5R+F-O;2!A8V-E<'1S('II<"!C;V1E<R!A<R!L
M;V-A=&EO;B!)1',I+@H@("`@("`@("\O(%1H92!L;V-A=&EO;B!)1"!S:&]U
M;&0@86QR96%D>2!H879E(&)E96X@=F%L:61A=&5D(&EN"B`@("`@("`@+R\@
M9V5T4&%R86US+@H@("`@("`@("1S96%R8V@@/2`H<')E9U]M871C:"@G+UQB
M*#\Z7%QD>S5]*"U<7&1[-7TI/RE\*#\Z6T$M6EU[-'U<7&1[-'TI7&(O)RP*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTL("1M871C
M:&5S*2`_"B`@("`@("`@("`@("1M871C:&5S6S!=(#H*("`@("`@("`@("`@
M)'=E871H97)$;W1#;VTM/G-E87)C:$QO8V%T:6]N*"1T:&ES+3Y?<&%R86US
M6R=L;V-A=&EO;B==*2D["B`@("`@("`@:68@*&ES7V$H)'-E87)C:"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!S=VET8V@@*"1S96%R8V@M/F=E
M=$-O9&4H*2D@>PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?
M15)23U)?4T525DE#15].3U1?1D]53D0Z"B`@("`@("`@("`@("`@("!R971U
M<FX@7R@B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(I
M.PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?54Y+
M3D]73E],3T-!5$E/3CH*("`@("`@("`@("`@("`@(')E='5R;B!?*")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(I.PH@("`@("`@("`@("!C87-E(%-%
M4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$Z"B`@("`@
M("`@("`@("`@("!R971U<FX@7R@B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92XB*3L*("`@("`@("`@("`@8V%S92!315)624-%4U]714%4
M2$527T524D]27T-!0TA%7TE.251?1D%)3$5$.@H@("`@("`@("`@("`@("`@
M<F5T=7)N(%\H(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(BD["B`@
M("`@("`@("`@(&-A<V4@4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?
M0T].3D5#5$5$.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DUE=&%R1$(@
M:7,@;F]T(&-O;FYE8W1E9"XB*3L*("`@("`@("`@("`@8V%S92!315)624-%
M4U]714%42$527T524D]27U5.2TY/5TY?15)23U(Z"B`@("`@("`@("`@("`@
M("!R971U<FX@7R@B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB*3L*
M("`@("`@("`@("`@8V%S92!315)624-%4U]714%42$527T524D]27TY/7TQ/
M0T%424]..@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DYO(&QO8V%T:6]N
M('!R;W9I9&5D+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(
M15)?15)23U)?24Y604Q)1%],3T-!5$E/3CH*("`@("`@("`@("`@("`@(')E
M='5R;B!?*"));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(I.PH@("`@("`@
M("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%]005)4
M3D527TE$.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DEN=F%L:60@<&%R
M=&YE<B!I9"XB*3L*("`@("`@("`@("`@8V%S92!315)624-%4U]714%42$52
M7T524D]27TE.5D%,241?4%)/1%5#5%]#3T1%.@H@("`@("`@("`@("`@("`@
M<F5T=7)N(%\H(DEN=F%L:60@<')O9'5C="!C;V1E+B(I.PH@("`@("`@("`@
M("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],24-%3E-%
M7TM%63H*("`@("`@("`@("`@("`@(')E='5R;B!?*"));G9A;&ED(&QI8V5N
M<V4@:V5Y+B(I.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@<F5T=7)N("1S96%R8V@M/F=E=&UE<W-A9V4H*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)&AT;6P@/2`G)SL*("`@("`@("!I9B`H
M:7-?87)R87DH)'-E87)C:"DI('L*("`@("`@("`@("`@+R\@4V5V97)A;"!L
M;V-A=&EO;G,@<F5T=7)N960@9'5E('1O(&EM<')E8VES92!L;V-A=&EO;@H@
M("`@("`@("`@("`O+R!P87)A;65T97(N"B`@("`@("`@("`@("1H=&UL(#T@
M7R@B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B*2`N"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG;&]C
M871I;VXG72`N"B`@("`@("`@("`@("`@("`G/&)R("\^/'5L/B<["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1S96%R8V@@87,@)&ED7W=E871H97(]/B1R96%L
M7VQO8V%T:6]N*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`B/&QI/B1R
M96%L7VQO8V%T:6]N("@D:61?=V5A=&AE<BD\+VQI/EQN(CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]U;#XG.PH@("`@("`@("`@
M("!R971U<FX@)&AT;6P["B`@("`@("`@?0H*("`@("`@("`D;&]C871I;VX@
M/2`D=V5A=&AE<D1O=$-O;2T^9V5T3&]C871I;VXH)'-E87)C:"D["B`@("`@
M("`@:68@*&ES7V$H)&QO8V%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D;&]C871I;VXM/F=E=&UE<W-A9V4H*3L*("`@("`@
M("!]"B`@("`@("`@)'=E871H97(@/2`D=V5A=&AE<D1O=$-O;2T^9V5T5V5A
M=&AE<B@D<V5A<F-H*3L*("`@("`@("!I9B`H:7-?82@D=V5A=&AE<BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'=E871H97(M/F=E
M=&UE<W-A9V4H*3L*("`@("`@("!]"B`@("`@("`@)&9O<F5C87-T(#T@)'=E
M871H97)$;W1#;VTM/F=E=$9O<F5C87-T*"1S96%R8V@L("1T:&ES+3Y?<&%R
M86US6R=D87ES)UTI.PH@("`@("`@(&EF("AI<U]A*"1F;W)E8V%S="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9O<F5C87-T+3YG
M971M97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("`O+R!,;V-A=&EO;B!A
M;F0@;&]C86P@=&EM92X*("`@("`@("`D:'1M;"`N/2`G/&1I=B!C;&%S<STB
M8V]N=')O;"(^)R`N"B`@("`@("`@("`@("<\<W1R;VYG/B<@+B`D;&]C871I
M;VY;)VYA;64G72`N("<\+W-T<F]N9SX@)R`N(%\H(DQO8V%L('1I;64Z("(I
M("X@)&QO8V%T:6]N6R=T:6UE)UT@+@H@("`@("`@("`@("`G/"]D:78^)SL*
M"B`@("`@("`@+R\@4W5N<FES92]S=6YS970N"B`@("`@("`@)&AT;6P@+CT@
M)SQS=')O;F<^)R`N(%\H(E-U;G)I<V4Z("(I("X@)SPO<W1R;VYG/B<@+@H@
M("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]S=6YR:7-E+W-U;G)I<V4N
M<&YG)RP@7R@B4W5N<FES92(I*2`N"B`@("`@("`@("`@("1L;V-A=&EO;ELG
M<W5N<FES92==.PH@("`@("`@("1H=&UL("X]("<@/'-T<F]N9SXG("X@7R@B
M4W5N<V5T.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@("`@("`@2&]R9&4Z
M.FEM9R@G8FQO8VLO<W5N<FES92]S=6YS970N<&YG)RP@7R@B4W5N<V5T(BDI
M("X*("`@("`@("`@("`@)&QO8V%T:6]N6R=S=6YS970G73L*"B`@("`@("`@
M+R\@5&5M<&5R871U<F4N"B`@("`@("`@)&AT;6P@+CT@)SQB<B`O/CQS=')O
M;F<^)R`N(%\H(E1E;7!E<F%T=7)E.B`B*2`N("<\+W-T<F]N9SXG("X*("`@
M("`@("`@("`@<F]U;F0H)'=E871H97);)W1E;7!E<F%T=7)E)UTI("X@)R9D
M96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI.PH*("`@("`@
M("`O+R!$97<@<&]I;G0N"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B<@
M+B!?*")$97<@<&]I;G0Z("(I("X@)SPO<W1R;VYG/B<@+@H@("`@("`@("`@
M("!R;W5N9"@D=V5A=&AE<ELG9&5W4&]I;G0G72D@+B`G)F1E9SLG("X@4W1R
M:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72D["@H@("`@("`@("\O($9E96QS
M(&QI:V4@=&5M<&5R871U<F4N"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG
M/B<@+B!?*")&965L<R!L:6ME.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@
M("`@("`@<F]U;F0H)'=E871H97);)V9E;'1496UP97)A='5R92==*2`N("<F
M9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*"B`@("`@
M("`@+R\@4')E<W-U<F4@86YD('1R96YD+@H@("`@("`@("1H=&UL("X]("<\
M8G(@+SX\<W1R;VYG/B<@+B!?*")0<F5S<W5R93H@(BD@+B`G/"]S=')O;F<^
M)SL*("`@("`@("`D=')E;F0@/2`D=V5A=&AE<ELG<')E<W-U<F54<F5N9"==
M.PH@("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B)60@)7,@86YD("5S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D=V5A=&AE<ELG<')E
M<W-U<F4G72DL("1U;FET<ULG<')E<R==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@7R@D=')E;F0I*3L*"B`@("`@("`@+R\@5VEN9"X*("`@("`@("`D
M:'1M;"`N/2`G/&)R("\^/'-T<F]N9SXG("X@7R@B5VEN9#H@(BD@+B`G/"]S
M=')O;F<^)SL*("`@("`@("!I9B`H)'=E871H97);)W=I;F1$:7)E8W1I;VXG
M72`]/2`G5D%2)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!?*")687)I86)L
M92(I.PH@("`@("`@('T@96QS96EF("@D=V5A=&AE<ELG=VEN9$1I<F5C=&EO
M;B==(#T]("=#04Q-)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!?*")#86QM
M(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&AT;6P@+CT@7R@B
M1G)O;2!T:&4@(BD@+B`D=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==.PH@("`@
M("`@(&EF("AI<W-E="@D=V5A=&AE<ELG=VEN9$=U<W0G72D@)B8@)'=E871H
M97);)W=I;F1'=7-T)UT@/B`P*2!["B`@("`@("`@("`@("1H=&UL("X]("<L
M("<@+B!?*")G=7-T:6YG(BD@+B`G("<@+B`D=V5A=&AE<ELG=VEN9$=U<W0G
M72`N"B`@("`@("`@("`@("`@("`G("<@+B`D=6YI='-;)W=I;F0G73L*("`@
M("`@("!]"@H@("`@("`@("`@("`D:'1M;"`N/2`G("@G("X@)'=E871H97);
M)W=I;F1$96=R965S)UT@+B`G*2<["B`@("`@("`@?0H@("`@("`@("1H=&UL
M("X](%\H(B!A="`B*2`N(')O=6YD*"1W96%T:&5R6R=W:6YD)UTI("X@)R`G
M("X@)'5N:71S6R=W:6YD)UT["@H@("`@("`@("\O($AU;6ED:71Y+@H@("`@
M("`@("1H=&UL("X]("<\8G(@+SX\<W1R;VYG/B<@+B!?*")(=6UI9&ET>3H@
M(BD@+B`G/"]S=')O;F<^)R`N"B`@("`@("`@("`@("1W96%T:&5R6R=H=6UI
M9&ET>2==("X@)R4G.PH*("`@("`@("`O+R!6:7-I8FEL:71Y+@H@("`@("`@
M("1H=&UL("X]("<@/'-T<F]N9SXG("X@7R@B5FES:6)I;&ET>3H@(BD@+B`G
M/"]S=')O;F<^)R`N"B`@("`@("`@("`@("AI<U]N=6UE<FEC*"1W96%T:&5R
M6R=V:7-I8FEL:71Y)UTI"B`@("`@("`@("`@("`_(')O=6YD*"1W96%T:&5R
M6R=V:7-I8FEL:71Y)UTI("X@)R`G("X@)'5N:71S6R=V:7,G70H@("`@("`@
M("`@("`@.B`D=V5A=&AE<ELG=FES:6)I;&ET>2==*3L*"B`@("`@("`@+R\@
M558@:6YD97@N"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B<@+B!?*")5
M+E8N(&EN9&5X.B`B*2`N("<\+W-T<F]N9SXG.PH@("`@("`@("1U=B`]("1W
M96%T:&5R6R=U=E1E>'0G73L*("`@("`@("`D:'1M;"`N/2`D=V5A=&AE<ELG
M=79);F1E>"==("X@)R`M("<@+B!?*"1U=BD["@H@("`@("`@("\O($-U<G)E
M;G0@8V]N9&ET:6]N+@H@("`@("`@("1C;VYD:71I;VX@/2!I;7!L;V1E*"<@
M+R`G+"!A<G)A>5]M87`H)U\G+"!E>'!L;V1E*"<@+R`G+"`D=V5A=&AE<ELG
M8V]N9&ET:6]N)UTI*2D["B`@("`@("`@)&AT;6P@+CT@)SQB<B`O/CQS=')O
M;F<^)R`N(%\H(D-U<G)E;G0@8V]N9&ET:6]N.B`B*2`N("<\+W-T<F]N9SXG
M("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\G("X*("`@("`@("`@("`@("`@("`@("`@("`H)'=E871H97);
M)V-O;F1I=&EO;DEC;VXG72`]/2`G+2<@/R`G;F$G(#H@)'=E871H97);)V-O
M;F1I=&EO;DEC;VXG72D@+B`G+G!N9R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@)&-O;F1I=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`G86QI9VX]
M(FUI9&1L92(G*3L*("`@("`@("`D:'1M;"`N/2`G("<@+B`D8V]N9&ET:6]N
M.PH*("`@("`@("`O+R!$;R!T:&4@9F]R96-A<W0@;F]W("AI9B!R97%U97-T
M960I+@H@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG9&%Y<R==(#X@,"D@
M>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&1I=B!C;&%S<STB8V]N=')O;"(@
M<W1Y;&4](G1E>'0M86QI9VXZ8V5N=&5R(CX\<W1R;VYG/B<@+@H@("`@("`@
M("`@("`@("`@<W!R:6YT9BA?*"(E9"UD87D@9F]R96-A<W0B*2P@)'1H:7,M
M/E]P87)A;7-;)V1A>7,G72D@+@H@("`@("`@("`@("`@("`@)SPO<W1R;VYG
M/CPO9&EV/B<["@H@("`@("`@("`@("`D9G5T=7)E1&%Y<R`](#`["B`@("`@
M("`@("`@("1H=&UL("X]("<\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C
M:6YG/2(S(CXG.PH@("`@("`@("`@("`O+R!(96%D97)S+@H@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1R/B<["B`@("`@("`@("`@("1H=&UL("X]("<\=&@^
M)R`N(%\H(D1A>2(I("X@)SPO=&@^/'1H/B9N8G-P.SPO=&@^/'1H/B<@+@H@
M("`@("`@("`@("`@("`@<W!R:6YT9BA?*")496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("<\<W!A;B!S='EL93TB8V]L;W(Z<F5D(CXG+"`G/"]S<&%N/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<\<W!A;B!S='EL93TB8V]L;W(Z8FQU
M92(^)RP@)SPO<W!A;CXG+`H@("`@("`@("`@("`@("`@("`@("`@("!3=')I
M;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*2D@+@H@("`@("`@("`@("`@("`@
M)SPO=&@^/'1H/B<@+B!?*")#;VYD:71I;VXB*2`N("<\+W1H/B<@+@H@("`@
M("`@("`@("`@("`@)SQT:#XG("X@7R@B4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC92(I("X@)SPO=&@^)SL*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%R86US6R=D971A:6QE9$9O<F5C87-T)UTI*2!["B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`G/'1H/B<@+B!?*")(=6UI9&ET>2(I("X@)SPO=&@^
M/'1H/B<@+B!?*")7:6YD(BD@+B`G/"]T:#XG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1H=&UL("X]("<\+W1R/B<["@H@("`@("`@("`@("!F;W)E
M86-H("@D9F]R96-A<W1;)V1A>7,G72!A<R`D=VAI8V@@/3X@)&1A>2D@>PH@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT<B!C;&%S<STB:71E;3`B/B<[
M"@H@("`@("`@("`@("`@("`@+R\@1&%Y(&YA;64N"B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1D(')O=W-P86X](C(B('-T>6QE/2)B;W)D97(Z,7!X
M('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@
M("`@("`@("`@("`@("`@)SQS=')O;F<^)SL*("`@("`@("`@("`@("`@(&EF
M("@D=VAI8V@@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]
M(%\H(E1O9&%Y(BD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'=H:6-H
M(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!?*")4;VUO
M<G)O=R(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G)4$G+"!M:W1I;64H,"P@,"P@
M,"P@9&%T92@G;2<I+"!D871E*"=D)RD@*R`D9G5T=7)E1&%Y<RP@9&%T92@G
M62<I*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`G/"]S=')O;F<^/&)R("\^)R`N"B`@("`@("`@("`@("`@("`@("`@
M<W1R9G1I;64H)R5B("5D)RP@;6MT:6UE*#`L(#`L(#`L(&1A=&4H)VTG*2P@
M9&%T92@G9"<I("L@)&9U='5R941A>7,L(&1A=&4H)UDG*2DI("X*("`@("`@
M("`@("`@("`@("`@("`G/"]T9#XG("X*("`@("`@("`@("`@("`@("`@("`G
M/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ
M8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`G/'-P86X@<W1Y;&4]
M(F-O;&]R.F]R86YG92(^)R`N"B`@("`@("`@("`@("`@("`@("`@7R@B1&%Y
M(BD@+B`G/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@("`O+R!4:&4@
M9&%Y('!O<G1I;VX@;V8@=&AE(&9O<F5C87-T(&ES(&YO(&QO;F=E<B!A=F%I
M;&%B;&4@869T97(@,CHP,"!P+FTN(&QO8V%L('1O9&%Y+@H@("`@("`@("`@
M("`@("`@:68@*"1W:&EC:"`]/2`P("8F("AS=')T;W1I;64H)&QO8V%T:6]N
M6R=T:6UE)UTI(#X]('-T<G1O=&EM92@G,30Z,#`G*2DI('L*("`@("`@("`@
M("`@("`@("`@("`O+R!"86QA;F-E('1H92!G<FED+@H@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("<\=&0@8V]L<W!A;CTB)R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`H*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D971A
M:6QE9$9O<F5C87-T)UTI(#\@)S4G(#H@)S,G*2`N("<B)RD@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R!S='EL93TB8F]R9&5R.C%P>"!S;VQI
M9"`C9&1D.R!T97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G)FYB<W`[/&)R("\^)R`N(%\H(DEN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N(BD@+B`G/&)R("\^)FYB<W`[)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G/"]T9#XG.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!&;W)E8V%S
M="!C;VYD:71I;VXN"B`@("`@("`@("`@("`@("`@("`@)&-O;F1I=&EO;B`]
M(&EM<&QO9&4H)R`O("<L(&%R<F%Y7VUA<"@G7R<L(&5X<&QO9&4H)R`O("<L
M("1D87E;)V1A>2==6R=C;VYD:71I;VXG72DI*3L*"B`@("`@("`@("`@("`@
M("`@("`@+R\@2&EG:"!T96UP97)A='5R92X*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[
M('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`@
M("`@)SQS<&%N('-T>6QE/2)C;VQO<CIR960B/B<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("!R;W5N9"@D9&%Y6R=T96UP97)A='5R94AI9V@G72D@+B`G
M/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@("`@("`@+R\@0V]N9&ET
M:6]N+@H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4]
M(F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+R<@+B`H)&1A>5LG9&%Y)UU;)V-O;F1I=&EO
M;DEC;VXG72`]/2`G+2<@/R`G;F$G(#H@)&1A>5LG9&%Y)UU;)V-O;F1I=&EO
M;DEC;VXG72D@+B`G+G!N9R<L("1C;VYD:71I;VXI("X*("`@("`@("`@("`@
M("`@("`@("`@("`@)SQB<B`O/B<@+B`D8V]N9&ET:6]N("X@)SPO=&0^)SL*
M"B`@("`@("`@("`@("`@("`@("`@+R\@4')E8VEP:71A=&EO;B!C:&%N8V4N
M"B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!S='EL93TB8F]R
M9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("1D87E;)V1A>2==6R=P<F5C:7!I=&%T
M:6]N)UT@+B`G)2<@+B`G/"]T9#XG.PH*("`@("`@("`@("`@("`@("`@("`O
M+R!)9B!A(&1E=&%I;&5D(&9O<F5C87-T('=A<R!R97%U97-T960L('-H;W<@
M:'5M:61I='D@86YD"B`@("`@("`@("`@("`@("`@("`@+R\@=VEN9',N"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D
M971A:6QE9$9O<F5C87-T)UTI*2!["@H@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!(=6UI9&ET>2X*("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@
M+CT@)SQT9"!S='EL93TB8F]R9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L
M:6=N.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&%Y6R=D87DG75LG:'5M:61I='DG72`N("<E/"]T9#XG.PH*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@5VEN9',N"B`@("`@("`@("`@("`@("`@("`@
M("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D
M9"(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*")&<F]M('1H
M92`B*2`N("1D87E;)V1A>2==6R=W:6YD1&ER96-T:6]N)UT@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7R@B(&%T("(I("X@)&1A>5LG9&%Y)UU;
M)W=I;F0G72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G("<@+B`D
M=6YI='-;)W=I;F0G73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D87E;)V1A>2==6R=W:6YD1W5S="==*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A>5LG9&%Y)UU;)W=I;F1'=7-T)UT@/B`P*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!?*"(L(&=U
M<W1I;F<@(BD@+B`D9&%Y6R=D87DG75LG=VEN9$=U<W0G72`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R`G("X@)'5N:71S6R=W:6YD)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W1R/B<["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@3FEG:'0@9F]R
M96-A<W0*("`@("`@("`@("`@("`@("1N:6=H="`](&EM<&QO9&4H)R`O("<L
M(&%R<F%Y7VUA<"@G7R<L(&5X<&QO9&4H)R`O("<L("1D87E;)VYI9VAT)UU;
M)V-O;F1I=&EO;B==*2DI.PH*("`@("`@("`@("`@("`@("\O(%-H861E(&ET
M(&9O<B!V:7-U86P@<V5P87)A=&EO;BX*("`@("`@("`@("`@("`@("1H=&UL
M("X]("<\='(@8VQA<W,](FET96TQ(CXG.PH*("`@("`@("`@("`@("`@("1H
M=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X
M="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@("`@("`@("`@(%\H(DYI
M9VAT(BD@+B`G/"]T9#XG.PH*("`@("`@("`@("`@("`@("\O($QO=R!T96UP
M97)A='5R92X*("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4]
M(F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@
M+@H@("`@("`@("`@("`@("`@("`@("<\<W!A;B!S='EL93TB8V]L;W(Z8FQU
M92(^)R`N"B`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&1A>5LG=&5M<&5R
M871U<F5,;W<G72D@+B`G/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@
M("`O+R!#;VYD:71I;VXN"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D
M('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N
M=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+R<@+B`H)&1A>5LG;FEG:'0G75LG8V]N
M9&ET:6]N26-O;B==(#T]("<M)R`_("=N82<@.B`D9&%Y6R=N:6=H="==6R=C
M;VYD:71I;VY)8V]N)UTI("X@)RYP;F<G+"`D;FEG:'0I("X*("`@("`@("`@
M("`@("`@("`@("`G/&)R("\^)R`N("1N:6=H="`N("<\+W1D/B<["@H@("`@
M("`@("`@("`@("`@+R\@4')E8VEP:71A=&EO;B!C:&%N8V4N"B`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED
M("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@
M("`@("`D9&%Y6R=N:6=H="==6R=P<F5C:7!I=&%T:6]N)UT@+B`G)3PO=&0^
M)SL*"B`@("`@("`@("`@("`@("`O+R!)9B!A(&1E=&%I;&5D(&9O<F5C87-T
M('=A<R!R97%U97-T960L(&1I<W!L87D@:'5M:61I='D@86YD"B`@("`@("`@
M("`@("`@("`O+R!W:6YD<RX*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A<F%M<ULG9&5T86EL961&;W)E8V%S="==*2D@>PH*("`@("`@
M("`@("`@("`@("`@("`O+R!(=6UI9&ET>2X*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[
M('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A>5LG;FEG:'0G75LG:'5M:61I='DG72`N("<E/"]T9#XG.PH*("`@
M("`@("`@("`@("`@("`@("`O+R!7:6YD<RX*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0B
M/B<@+@H@("`@("`@("`@("`@("`@("`@("`@("!?*")&<F]M('1H92`B*2`N
M("1D87E;)VYI9VAT)UU;)W=I;F1$:7)E8W1I;VXG72`N"B`@("`@("`@("`@
M("`@("`@("`@("`@(%\H(B!A="`B*2`N("1D87E;)VYI9VAT)UU;)W=I;F0G
M72`N"B`@("`@("`@("`@("`@("`@("`@("`@("<@)R`N("1U;FET<ULG=VEN
M9"==.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%Y6R=N:6=H
M="==6R=W:6YD1W5S="==*2`F)B`D9&%Y6R=N:6=H="==6R=W:6YD1W5S="==
M(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!?*"(L
M(&=U<W1I;F<@(BD@+B`D9&%Y6R=N:6=H="==6R=W:6YD1W5S="==("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<@)R`N("1U;FET<ULG=VEN9"==
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G/"]T<CXG.PH*("`@("`@("`@("`@
M("`@("\O(%!R97!A<F4@9F]R(&YE>'0@9&%Y+@H@("`@("`@("`@("`@("`@
M)&9U='5R941A>7,K*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M
M;"`N/2`G/"]T86)L93XG.PH@("`@("`@('T*"B`@("`@("`@+R\@1&ES<&QA
M>2!A(&)A<B!A="!T:&4@8F]T=&]M(&]F('1H92!B;&]C:R!W:71H('1H92!R
M97%U:7)E9`H@("`@("`@("\O(&%T=')I8G5T:6]N('1O('=E871H97(N8V]M
M(&%N9"!T:&4@;&]G;RP@8F]T:"!L:6YK960@=&\*("`@("`@("`O+R!W96%T
M:&5R+F-O;2!W:71H('1H92!P87)T;F5R($E$+@H@("`@("`@(')E='5R;B`D
M:'1M;"`N("<\9&EV(&-L87-S/2)R:6=H=$%L:6=N(&QI;F5D4F]W(CXG("X*
M("`@("`@("`@("`@7R@B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(BD@+B`G
M("<@+@H@("`@("`@("`@("!(;W)D93HZ;&EN:RA(;W)D93HZ97AT97)N86Q5
M<FPH)VAT='`Z+R]W=W<N=V5A=&AE<BYC;VTO/W!R;V0]>&]A<"9A;7`[<&%R
M/2<@+@H@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1O=$-O;2T^
M7W!A<G1N97))1"DL"B`@("`@("`@("`@("`@("`@("`@("`@("=W96%T:&5R
M+F-O;2<L("<G+"`G7V)L86YK)RP@)R<L("=W96%T:&5R+F-O;2<I("X*("`@
M("`@("`@("`@)SQE;3YW96%T:&5R+F-O;3PO96T^)G)E9SL@)R`N"B`@("`@
M("`@("`@($AO<F1E.CII;6<H)V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M5%=#;&]G;U\S,G!X+G!N9R<L("=W96%T:&5R+F-O;2!L;V=O)RD@+@H@("`@
M("`@("`@("`G/"]A/CPO9&EV/B<["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'``````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8P,0`Q,#0Q-S,V,C<W-0`P,C,S-3,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%!O<W-I8FQE('-T<FEN9W,@9G)O;2!W96%T:&5R+F-O;2P@
M:G5S="!T;R!H879E('1H96T@:6X@=&AE('-O=7)C92!F;W(*("H@;&]C86QI
M>F%T:6]N(')E87-O;G,N"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`L=B`Q+C$N,BXU(#(P,#8O,#(O
M,C$@,3`Z-3`Z-#<@:F%N($5X<"`D"B`J+PH*7R@B04T@0VQO=61S(BD["E\H
M(D%-($QI9VAT(%)A:6XB*3L*7R@B04T@4F%I;B(I.PI?*")!32!3:&]W97)S
M(BD["E\H(D%-(%-N;W<@4VAO=V5R<R(I.PI?*")#;&5A<B(I.PI?*")#;&5A
M<FEN9R!,871E(BD["E\H(D-L;W5D<R!%87)L>2(I.PI?*")#;&]U9'DB*3L*
M7R@B1F%I<B(I.PI?*")&97<@4VAO=V5R<R(I.PI?*")&97<@4VYO=R!3:&]W
M97)S(BD["E\H(D9O9R(I.PI?*")(87IE(BD["E\H(DAE879Y(%0M4W1O<FTB
M*3L*7R@B27-O;&%T960@5"U3=&]R;7,B*3L*7R@B3&EG:'0@1')I>GIL92(I
M.PI?*"),:6=H="!286EN(BD["E\H(DQI9VAT(%)A:6X@16%R;'DB*3L*7R@B
M3&EG:'0@4F%I;B!,871E(BD["E\H(DQI9VAT(%)A:6X@4VAO=V5R(BD["E\H
M(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(BD["E\H(DQI9VAT(%-N;W<B*3L*
M7R@B3&EG:'0@4VYO=R!3:&]W97(B*3L*7R@B36]S=&QY($-L96%R(BD["E\H
M(DUO<W1L>2!#;&]U9'DB*3L*7R@B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB
M*3L*7R@B36]S=&QY(%-U;FYY(BD["E\H(E!A<G1L>2!#;&]U9'DB*3L*7R@B
M4$T@3&EG:'0@4F%I;B(I.PI?*")032!286EN(BD["E\H(E!-(%-H;W=E<G,B
M*3L*7R@B4$T@4VYO=R(I.PI?*")032!3;F]W(%-H;W=E<G,B*3L*7R@B4$T@
M4W5N(BD["E\H(E!-(%0M4W1O<FUS(BD["E\H(E)A:6XB*3L*7R@B4F%I;B!%
M87)L>2(I.PI?*")286EN($QA=&4B*3L*7R@B4F%I;B!3:&]W97(B*3L*7R@B
M4F%I;B!A;F0@4VYO=R(I.PI?*")286EN('1O(%-N;W<B*3L*7R@B4V-A='1E
M<F5D(%0M4W1O<FUS(BD["E\H(E-H;W=E<G,B*3L*7R@B4VAO=V5R<R!%87)L
M>2(I.PI?*")3:&]W97)S($QA=&4B*3L*7R@B4VAO=V5R<R!I;B!T:&4@5FEC
M:6YI='DB*3L*7R@B4VYO=R(I.PI?*")3;F]W(%-H;W=E<B(I.PI?*")3;F]W
M(%-H;W=E<G,B*3L*7R@B4VYO=R!3:&]W97)S($5A<FQY(BD["E\H(E-N;W<@
M4VAO=V5R<R!,871E(BD["E\H(E-U;FYY(BD["E\H(E0M4W1O<FTB*3L*7R@B
M5"U3=&]R;2!A;F0@5VEN9'DB*3L*7R@B5"U3=&]R;7,B*3L*7R@B5"U3=&]R
M;7,@16%R;'DB*3L*7R@B5&AU;F1E<B(I.PI?*")7:6YD(BD["E\H(E=I;F0@
M16%R;'DB*3L*7R@B3&]W(BD["E\H(DUO9&5R871E(BD["E\H(DAI9V@B*3L*
M7R@B5F5R>2!(:6=H(BD["E\H(F9A;&QI;F<B*3L*7R@B<W1E861Y(BD["E\H
M(G)I<VEN9R(I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+P``````````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S<U`#`Q-38S-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]834PO5T)834PO````````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S4`,#$V-3(W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0O````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W-0`P,3<Q-#(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="
M6$U,+T141"]3>6YC34PN<&AP````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`W,3,S`#$P-#$W,S8R-S<U`#`R,3`R,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*:6YC;'5D95]O;F-E
M("=834PO5T)834PO1%1$+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O
M<FLO6$U,7U="6$U,+U="6$U,+T141"]3>6YC34PN<&AP+'8@,2XV+C$R+C4@
M,C`P-B\P,R\Q,2`P.3HU-3HQ,B!J86X@17AP("0*("H*("H@1G)O;2!":6YA
M<GD@6$U,($-O;G1E;G0@1F]R;6%T(%-P96-I9FEC871I;VX@5F5R<VEO;B`Q
M+C,L(#(U($IU;'D@,C`P,0H@*B!F;W5N9"!A="!H='1P.B\O=W=W+G=A<&9O
M<G5M+F]R9PH@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL
M;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?5T)834Q?1%1$7U-Y
M;F--3"!E>'1E;F1S(%A-3%]70EA-3%]$5$0@>PH*("`@(&9U;F-T:6]N(&EN
M:70H*0H@("`@>PH@("`@("`@("\J('1H:7,@8V]D92!T86)L92!H87,@8F5E
M;B!E>'1R86-T960@9G)O;2!L:6)W8GAM;`H@("`@("`@("`J("AS964@:'1T
M<#HO+VQI8G=B>&UL+F%Y;65R:6-K+F-O;2\I(&)Y('5S:6YG"B`@("`@("`@
M("H*("`@("`@("`@*B!G<F5P("=<(EM>7")=*EPB+"`J,'@N+BP@,'@N+B!]
M+"<@=V)X;6Q?=&%B;&5S+F,*("`@("`@("`@*B!\('-E9"`M92`G<R->+BI<
M(EPH6UY<(ETJ7"E<(BP@*EPH,'@N+EPI+"!<*#!X+BY<*2!]+"XJ)",@("`@
M("`@(%PD=&AI<RT^<V5T5&%G7"A<,RP@7")<,5PB7"D[("\O(%PR(V<G"B`@
M("`@("`@("HO"@H@("`@("`@("1T:&ES+3YS971486<H,'@P-2P@(D%D9"(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`V+"`B06QE<G0B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P-RP@(D%R8VAI
M=F4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P."P@(D%T
M;VUI8R(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`Y+"`B
M0VAA;"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!A+"`B
M0VUD(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&(L(")#
M;61)1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!C+"`B
M0VUD4F5F(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&0L
M(")#;W!Y(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&4L
M(")#<F5D(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&8L
M(")$871A(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3`L
M(")$96QE=&4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q
M,2P@(D5X96,B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q
M,BP@(D9I;F%L(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,3,L(")'970B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q
M-"P@(DET96TB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q
M-2P@(DQA;F<B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q
M-BP@(DQO8TYA;64B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@Q-RP@(DQO8U5222(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#$X+"`B36%P(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G
M*#!X,3DL(")-87!)=&5M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,6$L(")-971A(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,6(L(")-<V=)1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#%C+"`B37-G4F5F(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,60L(").;U)E<W`B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES
M+3YS971486<H,'@Q92P@(DYO4F5S=6QT<R(I.R`O+R`P>#`P"B`@("`@("`@
M)'1H:7,M/G-E=%1A9R@P>#%F+"`B4'5T(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,C`L(")297!L86-E(BD[("\O(#!X,#`*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,C$L(")297-P55))(BD[("\O(#!X,#`*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,C(L(")297-U;'1S(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C,L(")396%R8V@B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@R-"P@(E-E<75E;F-E(BD[("\O
M(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C4L(")397-S:6]N240B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R-BP@(E-F=$1E
M;"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(W+"`B4V]U
M<F-E(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C@L(")3
M;W5R8V52968B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R
M.2P@(E-T871U<R(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P
M>#)A+"`B4WEN8R(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P
M>#)B+"`B4WEN8T)O9'DB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@R8RP@(E-Y;F-(9'(B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS
M971486<H,'@R9"P@(E-Y;F--3"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#)E+"`B5&%R9V5T(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,F8L(")487)G9712968B*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@S,"P@(E)E<V5R=F5D(&9O<B!F=71U<F4@=7-E
M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,S$L(")697)$
M5$0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@S,BP@(E9E
M<E!R;W1O(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,S,L
M(").=6UB97)/9D-H86YG960B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS
M971486<H,'@S-"P@(DUO<F5$871A(BD[("\O(#!X,#`*"B`@("`@("`@:68@
M*"1T:&ES+3YV97)S:6]N(#T](#`I('L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$-O9&5086=E*#`L("<M+R]364Y#34PO+T141"!3>6YC34P@,2XP+R]%3B<L
M("=S>6YC;6PZ<WEN8VUL,2XP)RD["B`@("`@("`@("`@("1T:&ES+3YS971#
M;V1E4&%G92@Q+"`G+2\O4UE.0TU,+R]$5$0@365T26YF(#$N,"\O14XG+"`G
M<WEN8VUL.FUE=&EN9C$N,"<I.PH@("`@("`@("`@("`D=&AI<RT^<V5T55))
M*"=S>6YC;6PZ<WEN8VUL,2XP)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#`L("<M+R]364Y#34PO+T141"!3
M>6YC34P@,2XQ+R]%3B<L("=S>6YC;6PZ<WEN8VUL,2XQ)RD["B`@("`@("`@
M("`@("1T:&ES+3YS971#;V1E4&%G92@Q+"`G+2\O4UE.0TU,+R]$5$0@365T
M26YF(#$N,2\O14XG+"`G<WEN8VUL.FUE=&EN9C$N,2<I.PH@("`@("`@("`@
M("`D=&AI<RT^<V5T55))*"=S>6YC;6PZ<WEN8VUL,2XQ)RD["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O6$U,+U="6$U,+T141"]3>6YC34Q$979);F8N<&AP````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S0P`#$P-#$W,S8R-S<U`#`R,C$Q
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*:6YC;'5D95]O;F-E("=834PO5T)834PO1%1$+G!H<"<["@HO*BH*
M("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T141"]3>6YC
M34Q$979);F8N<&AP+'8@,2XT+C$R+C4@,C`P-B\P,R\Q,2`P.3HU-3HR,R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI
M;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!&<F]M($)I;F%R>2!8
M34P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N(#$N,RP@
M,C4@2G5L>2`R,#`Q"B`J(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P9F]R=6TN
M;W)G"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J
M+PIC;&%S<R!834Q?5T)834Q?1%1$7U-Y;F--3$1E=DEN9B!E>'1E;F1S(%A-
M3%]70EA-3%]$5$0@>PH*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@("`@
M("`@("\J('1H:7,@8V]D92!T86)L92!H87,@8F5E;B!E>'1R86-T960@9G)O
M;2!L:6)W8GAM;`H@("`@("`@("`J("AS964@:'1T<#HO+VQI8G=B>&UL+F%Y
M;65R:6-K+F-O;2\I(&)Y('5S:6YG"B`@("`@("`@("H*("`@("`@("`@*B!G
M<F5P("=<(EM>7")=*EPB+"`J,'@N+BP@,'@N+B!]+"<@=V)X;6Q?=&%B;&5S
M+F,*("`@("`@("`@*B!\('-E9"`M92`G<R->+BI<(EPH6UY<(ETJ7"E<(BP@
M*EPH,'@N+EPI+"!<*#!X+BY<*2!]+"XJ)",@("`@("`@(%PD=&AI<RT^<V5T
M5&%G7"A<,RP@7")<,5PB7"D[("\O(%PR(V<G"B`@("`@("`@("HO"@H@("`@
M("`@("1T:&ES+3YS971486<H,'@P-2P@(D-40V%P(BD[("\O(#!X,#`*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,#8L(")#5%1Y<&4B*3L@+R\@,'@P,`H@
M("`@("`@("1T:&ES+3YS971486<H,'@P-RP@(D1A=&%3=&]R92(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`X+"`B1&%T851Y<&4B*3L@
M+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P.2P@(D1E=DE$(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&$L(")$979);F8B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P8BP@(D1E=E1Y
M<"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!C+"`B1&ES
M<&QA>4YA;64B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P
M9"P@(D13365M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,&4L(")%>'0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P
M9BP@(D9W5B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$P
M+"`B2'=6(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3$L
M(")-86XB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q,BP@
M(DUA>$=52413:7IE(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G
M*#!X,3,L(")-87A)1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#$T+"`B36%X365M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,34L(")-;V0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@Q-BP@(D]%32(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#$W+"`B4&%R86U.86UE(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,3@L(")0<F]P3F%M92(I.R`O+R`P>#`P"B`@("`@("`@)'1H
M:7,M/G-E=%1A9R@P>#$Y+"`B4G@B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES
M+3YS971486<H,'@Q82P@(E)X+5!R968B*3L@+R\@,'@P,`H@("`@("`@("1T
M:&ES+3YS971486<H,'@Q8BP@(E-H87)E9$UE;2(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#%C+"`B4VEZ92(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#%D+"`B4V]U<F-E4F5F(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,64L(")3=U8B*3L@+R\@,'@P,`H@
M("`@("`@("1T:&ES+3YS971486<H,'@Q9BP@(E-Y;F-#87`B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@R,"P@(E-Y;F-4>7!E(BD[("\O
M(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C$L(")4>"(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(R+"`B5'@M4')E9B(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(S+"`B5F%L16YU;2(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(T+"`B5F5R0U0B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R-2P@(E9E<D14
M1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(V+"`B6$YA
M;2(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(W+"`B6%9A
M;"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(X+"`B551#
M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,CDL(")3=7!P
M;W)T3G5M8F5R3V9#:&%N9V5S(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,F$L(")3=7!P;W)T3&%R9V5/8FIS(BD[("\O(#!X,#`*"B`@
M("`@("`@:68@*"1T:&ES+3YV97)S:6]N(#T](#`I('L*("`@("`@("`@("`@
M)'1H:7,M/G-E=$-O9&5086=E*#`L("<M+R]364Y#34PO+T141"!$979);F8@
M,2XP+R]%3B<L("=S>6YC;6PZ9&5V:6YF,2XP)RD["B`@("`@("`@("`@("1T
M:&ES+3YS97154DDH)W-Y;F-M;#ID979I;F8Q+C`G*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@)RTO+U-9
M3D--3"\O1%1$($1E=DEN9B`Q+C$O+T5.)RP@)W-Y;F-M;#ID979I;F8Q+C$G
M*3L*("`@("`@("`@("`@)'1H:7,M/G-E=%5222@G<WEN8VUL.F1E=FEN9C$N
M,2<I.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO
M5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP:'``````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#0T,C,`,3`T,3<S-C(W-S4`,#(R,3(S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@II;F-L=61E7V]N
M8V4@)UA-3"]70EA-3"]$5$0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]834Q?5T)834PO5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP:'`L=B`Q
M+C0N,3(N-2`R,#`V+S`S+S$Q(#`Y.C4U.C,S(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A
M;6ED-BYC;VT^"B`J"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA
M="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY(#(P,#$*("H@
M9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-
M3%]$5$1?4WEN8TU,365T26YF(&5X=&5N9',@6$U,7U="6$U,7T141"!["@H@
M("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@("`@+RH@=&AI<R!C;V1E
M('1A8FQE(&AA<R!B965N(&5X=')A8W1E9"!F<F]M(&QI8G=B>&UL"B`@("`@
M("`@("H@*'-E92!H='1P.B\O;&EB=V)X;6PN87EM97)I8VLN8V]M+RD@8GD@
M=7-I;F<*("`@("`@("`@*@H@("`@("`@("`J(&=R97`@)UPB6UY<(ETJ7"(L
M("HP>"XN+"`P>"XN('TL)R!W8GAM;%]T86)L97,N8PH@("`@("`@("`J('P@
M<V5D("UE("=S(UXN*EPB7"A;7EPB72I<*5PB+"`J7"@P>"XN7"DL(%PH,'@N
M+EPI('TL+BHD(R`@("`@("`@7"1T:&ES+3YS971486=<*%PS+"!<(EPQ7")<
M*3L@+R\@7#(C9R<*("`@("`@("`@*B\*"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#`U+"`B06YC:&]R(BD[("\O(#!X,#$*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,#8L(")%34DB*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS9714
M86<H,'@P-RP@(D9O<FUA="(I.R`O+R`P>#`Q"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#`X+"`B1G)E94E$(BD[("\O(#!X,#$*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,#DL(")&<F5E365M(BD[("\O(#!X,#$*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,&$L("),87-T(BD[("\O(#!X,#$*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,&(L(")-87)K(BD[("\O(#!X,#$*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,&,L(")-87A-<V=3:7IE(BD[("\O(#!X,#$*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,34L(")-87A/8FI3:7IE(BD[("\O(#!X,#$*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&0L(")-96TB*3L@+R\@,'@P,0H@
M("`@("`@("1T:&ES+3YS971486<H,'@P92P@(DUE=$EN9B(I.R`O+R`P>#`Q
M"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!F+"`B3F5X="(I.R`O+R`P>#`Q
M"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$P+"`B3F5X=$YO;F-E(BD[("\O
M(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3$L(")3:&%R961-96TB
M*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q,BP@(E-I>F4B
M*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q,RP@(E1Y<&4B
M*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q-"P@(E9E<G-I
M;VXB*3L@+R\@,'@P,0H*("`@("`@("!I9B`H)'1H:7,M/G9E<G-I;VX@/3T@
M,"D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@)RTO+U-9
M3D--3"\O1%1$(%-Y;F--3"`Q+C`O+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ+C`G
M*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#$L("<M+R]364Y#
M34PO+T141"!-971);F8@,2XP+R]%3B<L("=S>6YC;6PZ;65T:6YF,2XP)RD[
M"B`@("`@("`@("`@("1T:&ES+3YS97154DDH)W-Y;F-M;#IM971I;F8Q+C`G
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D
M95!A9V4H,"P@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C$O+T5.)RP@)W-Y
M;F-M;#IS>6YC;6PQ+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O9&50
M86=E*#$L("<M+R]364Y#34PO+T141"!-971);F8@,2XQ+R]%3B<L("=S>6YC
M;6PZ;65T:6YF,2XQ)RD["B`@("`@("`@("`@("1T:&ES+3YS97154DDH)W-Y
M;F-M;#IM971I;F8Q+C$G*3L*("`@("`@("`@("`@+R\D=&AI<RT^<V5T55))
M*"=S>6YC;6PZ;65T:6YF)RD[("\O(&9O<B!S;VUE(&9U;FYY(')E87-O;BP@
M;&EB=V)X;6P@<')O9'5C97,@;F\@.FUE=&EN9C$N,2!H97)E"B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]834PO5T)834PO0V]N=&5N=$AA;F1L97(N<&AP````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#8P,34`,3`T,3<S-C(W-S4`,#(R,30W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO0V]N
M=&5N=$AA;F1L97(N<&AP+'8@,2XY+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HT
M-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY
M($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN("!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T
M:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY(#(P,#$*("H@9F]U;F0@870@:'1T
M<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,
M"B`J+PIC;&%S<R!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(@>PH*("`@('9A
M<B`D7V-U<G)E;G15<FD["B`@("!V87(@)%]O=71P=70@/2`G)SL*"B`@("!V
M87(@)%]O<&%Q=65(86YD;&5R.PH*("`@("\J*@H@("`@("H@0VAA<G-E="X*
M("`@("`J+PH@("`@=F%R("1?8VAA<G-E="`]("=55$8M."<["@H@("`@+RHJ
M"B`@("`@*B!70EA-3"!697)S:6]N+@H@("`@("H@,2P@,BP@;W(@,R!S=7!P
M;W)T960*("`@("`J+PH@("`@=F%R("1?=V)X;6Q697)S:6]N(#T@,CL*"B`@
M("!F=6YC=&EO;B!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?8W5R<F5N=%5R:2`]("9N97<@6$U,7U="6$U,7TQI
M9F]1=65U92@I.PH@("`@?0H*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&5R
M<F]R*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)O<BD["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T0VAA<G-E=%-T<B@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?8VAA<G-E=#L*("`@('T*"B`@("!F=6YC=&EO;B!S
M971#:&%R<V5T*"1C<RD*("`@('L*("`@("`@("`D=&AI<RT^7V-H87)S970@
M/2`D8W,["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=V)X;6Q697)S:6]N.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-E=%9E<G-I;VXH)'8I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]W8GAM;%9E<G-I;VX@/2`R.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=$]U='!U="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T<'5T
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]U='!U=%-I>F4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!S=')L96XH)'1H:7,M/E]O=71P=70I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T
M=')S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("<\)R`N("1E
M;&5M96YT.PH*("`@("`@("`D8W5R<F5N=%5R:2`]("1T:&ES+3Y?8W5R<F5N
M=%5R:2T^=&]P*"D["@H@("`@("`@(&EF("@H*"$D8W5R<F5N=%5R:2D@?'P@
M*"1C=7)R96YT57)I("$]("1U<FDI*2`F)B`D=7)I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?;W5T<'5T("X]("<@>&UL;G,](B<@+B`D=7)I("X@)R(G.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C=7)R96YT57)I+3YP=7-H*"1U
M<FDI.PH*("`@("`@("!F;W)E86-H("@D871T<G,@87,@)&%T='(I('L*("`@
M("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)R`G("X@)&%T=');)V%T=')I
M8G5T92==("X@)STB)R`N("1A='1R6R=V86QU92==("X@)R(G.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)SXG.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@)SPO)R`N("1E;&5M96YT("X@)SXG
M.PH*("`@("`@("`D=&AI<RT^7V-U<G)E;G15<FDM/G!O<"@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&-H87)A8W1E<G,H)'-T<BD*("`@('L*("`@("`@("`D
M=&AI<RT^7V]U='!U="`N/2`D<W1R.PH@("`@?0H*("`@(&9U;F-T:6]N(&]P
M87%U92@D;RD*("`@('L*("`@("`@("`O+R!)(&-A;B!C:&5C:R!T:&4@9FER
M<W0@8VAA;G)A8W1E<B!A;F0@<V5E(&EF(&ET(&ES(%="6$U,+@H@("`@("`@
M(&EF("AO<F0H)&];,%TI(#P@,3`I('L*("`@("`@("`@("`@+R\@4VAO=6QD
M(&1E8V]D92!T:&ES+"!)(')E86QL>2!N965D(&$@8V%L;"!B86-K(&9U;F-T
M:6]N+@H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T("X]("1O.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S971/
M<&%Q=65(86YD;&5R*"1O<&%Q=65(86YD;&5R*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;W!A<75E2&%N9&QE<B`]("1O<&%Q=65(86YD;&5R.PH@("`@?0H*
M("`@(&9U;F-T:6]N(')E;6]V94]P87%U94AA;F1L97(H*0H@("`@>PH@("`@
M("`@('5N<V5T*"1T:&ES+3Y?;W!A<75E2&%N9&QE<BD["B`@("!]"@I]"@IC
M;&%S<R!834Q?5T)834Q?3&EF;U%U975E('L*"B`@("!V87(@)%]Q=65U92`]
M(&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@6$U,7U="6$U,7TQI9F]1=65U92@I
M"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@<'5S:"@D;V)J*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<75E=65;72`]("1O8FH["B`@("!]"@H@("`@9G5N
M8W1I;VX@<&]P*"D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]Q
M=65U92DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7W!O<"@D=&AI<RT^
M7W%U975E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=&]P*"D*("`@
M('L*("`@("`@("!I9B`H)&-O=6YT(#T@8V]U;G0H)'1H:7,M/E]Q=65U92DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<75E=65;)&-O=6YT("T@
M,5T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O6$U,+U="6$U,+T141"YP:'``````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-C0W`#$P-#$W,S8R-S<U`#`Q-S8V-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T14
M1"YP:'`L=B`Q+C8N,3(N-2`R,#`V+S`S+S$Q(#`Y.C4U.C`Q(&IA;B!%>'`@
M)`H@*@H@*B!&<F]M($)I;F%R>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF
M:6-A=&EO;B!697)S:6]N(#$N,RP@,C4@2G5L>2`R,#`Q"B`J(&9O=6YD(&%T
M(&AT='`Z+R]W=W<N=V%P9F]R=6TN;W)G"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S
M(%A-3%]70EA-3%]$5$0@>PH*("`@('9A<B`D=F5R<VEO;CL*("`@('9A<B`D
M:6YT5&%G<SL*("`@('9A<B`D:6YT071T<FEB=71E<SL*("`@('9A<B`D<W1R
M5&%G<SL*("`@('9A<B`D<W1R071T<FEB=71E<SL*("`@('9A<B`D:6YT0V]D
M95!A9V5S.PH@("`@=F%R("1S=')#;V1E4&%G97,["B`@("!V87(@)'-T<D-O
M9&5086=E<U5223L*("`@('9A<B`D55)).PH@("`@=F%R("1834Q.4SL*("`@
M('9A<B`D1%!).PH*("`@(&9U;F-T:6]N(%A-3%]70EA-3%]$5$0H)'8I"B`@
M("!["B`@("`@("`@)'1H:7,M/G9E<G-I;VX@/2`D=CL*("`@("`@("`D=&AI
M<RT^:6YI="@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@
M("`@?0H*("`@(&9U;F-T:6]N('-E=$%T=')I8G5T92@D:6YT071T<FEB=71E
M+"`D<W1R071T<FEB=71E*0H@("`@>PH@("`@("`@("1T:&ES+3YS=')!='1R
M:6)U=&5S6R1S=')!='1R:6)U=&5=(#T@)&EN=$%T=')I8G5T93L*("`@("`@
M("`D=&AI<RT^:6YT071T<FEB=71E<ULD:6YT071T<FEB=71E72`]("1S=')!
M='1R:6)U=&4["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T5&%G*"1I;G1486<L
M("1S=')486<I"B`@("!["B`@("`@("`@)'1H:7,M/G-T<E1A9W-;)'-T<E1A
M9UT@/2`D:6YT5&%G.PH@("`@("`@("1T:&ES+3YI;G1486=S6R1I;G1486==
M(#T@)'-T<E1A9SL*("`@('T*"B`@("!F=6YC=&EO;B!S971#;V1E4&%G92@D
M:6YT0V]D95!A9V4L("1S=')#;V1E4&%G92P@)'-T<D-O9&5086=E55))*0H@
M("`@>PH@("`@("`@("1T:&ES+3YS=')#;V1E4&%G97-54DE;)'-T<D-O9&50
M86=E55))72`]("1I;G1#;V1E4&%G93L*("`@("`@("`D=&AI<RT^<W1R0V]D
M95!A9V5S6R1S=')#;V1E4&%G95T@/2`D:6YT0V]D95!A9V4["B`@("`@("`@
M)'1H:7,M/FEN=$-O9&5086=E<ULD:6YT0V]D95!A9V5=(#T@)'-T<D-O9&50
M86=E.PH@("`@?0H*("`@(&9U;F-T:6]N('1O5&%G4W1R*"1T86<I"B`@("![
M"B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3YI;G1486=S6R1T86==*2`_
M("1T:&ES+3YI;G1486=S6R1T86==(#H@9F%L<V4["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&]!='1R:6)U=&53='(H)&%T=')I8G5T92D*("`@('L*("`@("`@
M("!R971U<FX@:7-S970H)'1H:7,M/FEN=%1A9W-;)&%T=')I8G5T95TI(#\@
M)'1H:7,M/FEN=%1A9W-;)&%T=')I8G5T95T@.B!F86QS93L*("`@('T*"B`@
M("!F=6YC=&EO;B!T;T-O9&5086=E4W1R*"1C;V1E4&%G92D*("`@('L*("`@
M("`@("!R971U<FX@:7-S970H)'1H:7,M/FEN=$-O9&5086=E<ULD8V]D95!A
M9V5=*2`_("1T:&ES+3YI;G1#;V1E4&%G97-;)&-O9&5086=E72`Z(&9A;'-E
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1O5&%G26YT*"1T86<I"B`@("!["B`@
M("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3YS=')486=S6R1T86==*2`_("1T
M:&ES+3YS=')486=S6R1T86==(#H@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I
M;VX@=&]!='1R:6)U=&5);G0H)&%T=')I8G5T92D*("`@('L*("`@("`@("!R
M971U<FX@:7-S970H)'1H:7,M/G-T<D%T=')I8G5T97-;)&%T=')I8G5T95TI
M(#\@)'1H:7,M/G-T<D%T=')I8G5T97-;)&%T=')I8G5T95T@.B!F86QS93L*
M("`@('T*"B`@("!F=6YC=&EO;B!T;T-O9&5086=E26YT*"1C;V1E4&%G92D*
M("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/G-T<D-O9&5086=E
M<ULD8V]D95!A9V5=*2`_("1T:&ES+3YS=')#;V1E4&%G97-;)&-O9&5086=E
M72`Z(&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N('1O0V]D95!A9V554DDH
M)'5R:2D*("`@('L*("`@("`@("`D=7)I(#T@<W1R=&]L;W=E<B@D=7)I*3L*
M("`@("`@("!I9B@A:7-S970H)'1H:7,M/G-T<D-O9&5086=E<U5225LD=7)I
M72DI('L*("`@("`@("`@("`@9&EE*")U;F%B;&4@=&\@9FEN9"!C;V1E<&%G
M92!F;W(@)'5R:2%<;B(I.PH@("`@("`@('T*"B`@("`@("`@)')E="`](&ES
M<V5T*"1T:&ES+3YS=')#;V1E4&%G97-54DE;)'5R:5TI(#\@)'1H:7,M/G-T
M<D-O9&5086=E<U5225LD=7)I72`Z(&9A;'-E.PH*("`@("`@("!R971U<FX@
M)')E=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E='1E<B!F;W(@<')O<&5R
M='D@=F5R<VEO;BX*("`@("`J($!R971U<FX@5F%L=64@;V8@<')O<&5R='D@
M=F5R<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YV97)S:6]N.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!V97)S:6]N+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'8@($YE=R!V86QU92!O9B!P<F]P97)T>2!V
M97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971697)S:6]N*"1V*0H@
M("`@>PH@("`@("`@("1T:&ES+3YV97)S:6]N(#T@)'8["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'971T97(@9F]R('!R;W!E<G1Y(%5222X*("`@("`J($!R
M971U<FX@5F%L=64@;V8@<')O<&5R='D@55))+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G97154DDH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^55))
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!5
M4DDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1U("!.97<@=F%L=64@;V8@<')O
M<&5R='D@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!S97154DDH)'4I"B`@
M("!["B`@("`@("`@)'1H:7,M/E5222`]("1U.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T=&5R(&9O<B!P<F]P97)T>2!$4$DN"B`@("`@*B!`<F5T=7)N
M(%9A;'5E(&]F('!R;W!E<G1Y($1022X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1%!)*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/D1023L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@1%!)+@H@
M("`@("H@0'!A<F%M($1022!.97<@=F%L=64@;V8@<')O<&5R='D@1%!)+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971$4$DH)&0I"B`@("!["B`@("`@("`@
M)'1H:7,M/D1022`]("1D.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$1-86YA9V5R+G!H<```````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<Q-0`Q,#0Q-S,V,C<W-0`P,C$Q-3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"FEN8VQU9&5?;VYC92`G6$U,+U="6$U,+T141"]3>6YC34PN<&AP)SL*
M:6YC;'5D95]O;F-E("=834PO5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP:'`G
M.PII;F-L=61E7V]N8V4@)UA-3"]70EA-3"]$5$0O4WEN8TU,1&5V26YF+G!H
M<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,
M+T141$UA;F%G97(N<&AP+'8@,2XS+C$R+C@@,C`P-B\P,R\Q,R`Q-3HU,#HR
M,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY
M($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T
M:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY"B`J(#(P,#$@9F]U;F0@870@:'1T
M<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,
M"B`J+PIC;&%S<R!834Q?5T)834Q?1%1$36%N86=E<B!["@H@("`@=F%R("1?
M<W1R1%1$(#T@87)R87DH*3L*("`@('9A<B`D7W-T<D141%5222`](&%R<F%Y
M*"D["@H@("`@9G5N8W1I;VX@6$U,7U="6$U,7T141$UA;F%G97(H*0H@("`@
M>PH@("`@("`@("1T:&ES+3YR96=I<W1E<D141"@G+2\O4UE.0TU,+R]$5$0@
M4WEN8TU,(#$N,"\O14XG+"`G<WEN8VUL.G-Y;F-M;#$N,"<L(&YE=R!834Q?
M5T)834Q?1%1$7U-Y;F--3"@P*2D["B`@("`@("`@)'1H:7,M/G)E9VES=&5R
M1%1$*"<M+R]364Y#34PO+T141"!3>6YC34P@,2XQ+R]%3B<L("=S>6YC;6PZ
M<WEN8VUL,2XQ)RP@;F5W(%A-3%]70EA-3%]$5$1?4WEN8TU,*#$I*3L*"B`@
M("`@("`@)'1H:7,M/G)E9VES=&5R1%1$*"<M+R]364Y#34PO+T141"!-971)
M;F8@,2XP+R]%3B<L("=S>6YC;6PZ;65T:6YF,2XP)RP@;F5W(%A-3%]70EA-
M3%]$5$1?4WEN8TU,365T26YF*#`I*3L*("`@("`@("`D=&AI<RT^<F5G:7-T
M97)$5$0H)RTO+U-93D--3"\O1%1$($UE=$EN9B`Q+C$O+T5.)RP@)W-Y;F-M
M;#IM971I;F8Q+C$G+"!N97<@6$U,7U="6$U,7T141%]3>6YC34Q-971);F8H
M,2DI.PH*("`@("`@("`D=&AI<RT^<F5G:7-T97)$5$0H)RTO+U-93D--3"\O
M1%1$($1E=DEN9B`Q+C`O+T5.)RP@)W-Y;F-M;#ID979I;F8Q+C`G+"!N97<@
M6$U,7U="6$U,7T141%]3>6YC34Q$979);F8H,"DI.PH@("`@("`@("1T:&ES
M+3YR96=I<W1E<D141"@G+2\O4UE.0TU,+R]$5$0@1&5V26YF(#$N,2\O14XG
M+"`G<WEN8VUL.F1E=FEN9C$N,2<L(&YE=R!834Q?5T)834Q?1%1$7U-Y;F--
M3$1E=DEN9B@Q*2D["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$EN<W1A;F-E
M*"1P=6)L:6-)9&5N=&EF:65R*0H@("`@>PH@("`@("`@("1D=&0@/2!I<W-E
M="@D=&AI<RT^7W-T<D141%LD<'5B;&EC261E;G1I9FEE<ETI(#\@)B1T:&ES
M+3Y?<W1R1%1$6R1P=6)L:6-)9&5N=&EF:65R72`Z(&YU;&P["B`@("`@("`@
M<F5T=7)N("1D=&0["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$EN<W1A;F-E
M55))*"1U<FDI"B`@("!["B`@("`@("`@)'5R:2`]('-T<G1O;&]W97(H)'5R
M:2D["B`@("`@("`@)&1T9"`](&ES<V5T*"1T:&ES+3Y?<W1R1%1$55))6R1U
M<FE=*2`_("8D=&AI<RT^7W-T<D141%5225LD=7)I72`Z(&YU;&P["B`@("`@
M("`@<F5T=7)N("1D=&0["B`@("!]"@H@("`@9G5N8W1I;VX@<F5G:7-T97)$
M5$0H)'!U8FQI8TED96YT:69I97(L("1U<FDL("8D9'1D*0H@("`@>PH@("`@
M("`@("1D=&0M/G-E=$1022@D<'5B;&EC261E;G1I9FEE<BD["@H@("`@("`@
M("1T:&ES+3Y?<W1R1%1$6R1P=6)L:6-)9&5N=&EF:65R72`]("1D=&0["B`@
M("`@("`@)'1H:7,M/E]S=')$5$154DE;<W1R=&]L;W=E<B@D=7)I*5T@/2`D
M9'1D.PH@("`@?0H*?0H`````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]834PO5T)834PO1&5C;V1E<BYP:'``````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-#<W,3<`,3`T,3<S-C(W-S4`,#(P-C(R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@II
M;F-L=61E7V]N8V4@)UA-3"]70EA-3"YP:'`G.PII;F-L=61E7V]N8V4@)UA-
M3"]70EA-3"]$5$1-86YA9V5R+G!H<"<["FEN8VQU9&5?;VYC92`G6$U,+U="
M6$U,+T-O;G1E;G1(86YD;&5R+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M
M97=O<FLO6$U,7U="6$U,+U="6$U,+T1E8V]D97(N<&AP+'8@,2XR,BXQ,"XX
M(#(P,#8O,#$O,#$@,C$Z,C@Z-#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O
M;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!&<F]M($)I;F%R>2!834P@0V]N=&5N
M="!&;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N(#$N,RP@,C4@2G5L>0H@
M*B`R,#`Q(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P9F]R=6TN;W)G"B`J"B`J
M($!P86-K86=E(%A-3%]70EA-3`H@*B\*8VQA<W,@6$U,7U="6$U,7T1E8V]D
M97(@97AT96YD<R!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(@>PH*("`@("\J
M*@H@("`@("H@1&]C=6UE;G0@4'5B;&EC($ED96YT:69I97(@='EP90H@("`@
M("H@,2!M8E]U7VEN=#,R('=E;&P@:VYO=VX@='EP90H@("`@("H@,B!S=')I
M;F<@=&%B;&4*("`@("`J(&9R;VT@<W!E8R!B=70@8V]N=F5R=&5D(&EN=&\@
M82!S=')I;F<N"B`@("`@*@H@("`@("H@1&]C=6UE;G0@4'5B;&EC($ED96YT
M:69I97(*("`@("`J(%5S960@=VET:"!D<&E4>7!E+@H@("`@("HO"B`@("!V
M87(@)%]D<&D["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@=&%B;&4@87,@9&5F
M:6YE9"!I;B`U+C<*("`@("`J+PH@("`@=F%R("1?<W1R:6YG5&%B;&4@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N=&5N="!H86YD;&5R+@H@("`@
M("H@0W5R<F5N=&QY(&IU<W0@;W5T<'5T<R!R87<@6$U,+@H@("`@("HO"B`@
M("!V87(@)%]C:#L*"B`@("!V87(@)%]T86=$5$0["@H@("`@=F%R("1?<')E
M=D%T=')I8G5T94141#L*"B`@("!V87(@)%]A='1R:6)U=&5$5$0["@H@("`@
M+RHJ"B`@("`@*B!3=&%T92!V87)I86)L97,N"B`@("`@*B\*("`@('9A<B`D
M7W1A9U-T86-K(#T@87)R87DH*3L*("`@('9A<B`D7VES071T<FEB=71E.PH@
M("`@=F%R("1?:7-$871A(#T@9F%L<V4["@H@("`@=F%R("1?97)R;W(@/2!F
M86QS93L*"B`@("`O*BH*("`@("`J(%1H92!$5$0@36%N86=E<BX*("`@("`J
M"B`@("`@*B!`=F%R(%A-3%]70EA-3%]$5$1-86YA9V5R"B`@("`@*B\*("`@
M('9A<B`D7V1T9$UA;F%G97(["@H@("`@+RHJ"B`@("`@*B!4:&4@<W1R:6YG
M('!O<VET:6]N+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO
M"B`@("!V87(@)%]S=')P;W,["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@6$U,7U="6$U,7T1E8V]D97(H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?9'1D36%N86=E<B`]("9N97<@6$U,7U="
M6$U,7T141$UA;F%G97(H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE(&-O;G1E;G1(86YD;&5R('1H870@=VEL;"!R96-E:79E('1H92!O=71P
M=70@;V8@=&AE"B`@("`@*B!D96-O9&EN9RX*("`@("`J"B`@("`@*B!`<&%R
M86T@6$U,7U="6$U,7T-O;G1E;G1(86YD;&5R("1C:"!4:&4@8V]N=&5N=$AA
M;F1L97(*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V]N=&5N=$AA;F1L97(H
M)B1C:"D*("`@('L*("`@("`@("`D=&AI<RT^7V-H(#T@)B1C:#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!O;F4@8GET92!F<F]M('1H92!I;G!U
M="!S=')E86TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@
M(%1H92!70EA-3"!I;G!U="!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$)Y=&4H)&EN<'5T*0H@("`@>PH@("`@("`@(')E='5R;B!O<F0H)&EN
M<'5T>R1T:&ES+3Y?<W1R<&]S*RM]*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%1A:V5S(&$@5T)834P@:6YP=70@9&]C=6UE;G0@86YD(')E='5R;G,@9&5C
M;V1E9"!834PN"B`@("`@*B!(;W=E=F5R('1H92!P<F5F97)R960@86YD(&UO
M<F4@969F96-I96YT(&UE=&AO9"!I<R!T;PH@("`@("H@=7-E(&1E8V]D92@I
M(')A=&AE<B!T:&%N(&1E8V]D951O4W1R:6YG*"D@86YD(&AA=F4@86X*("`@
M("`J(&%P<')O<')I871E(&-O;G1E;G1(86YD;&5R(&1E86P@=VET:"!T:&4@
M9&5C;V1E9"!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'=B
M>&UL("!4:&4@5T)834P@9&]C=6UE;G0@=&\@9&5C;V1E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C;V1E9"!834P@9&]C=6UE;G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D951O4W1R:6YG*"1W8GAM;"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V-H(#T@)FYE=R!834Q?5T)834Q?0V]N
M=&5N=$AA;F1L97(H*3L*"B`@("`@("`@)'(@/2`D=&AI<RT^9&5C;V1E*"1W
M8GAM;"D["B`@("`@("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'1H:7,M/E]C:"T^9V5T3W5T<'5T*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!486ME<R!A(%="6$U,(&EN<'5T(&1O8W5M96YT(&%N9"!D96-O9&5S
M(&ET+@H@("`@("H@1&5C;V1I;F<@<F5S=6QT(&ES(&1I<F5C=&QY('!A<W-E
M9"!T;R!T:&4@8V]N=&5N=$AA;F1L97(N"B`@("`@*B!!(&-O;G1E;G1H86YD
M;&5R(&UU<W0@8F4@<V5T('5S:6YG('-E=$-O;G1E;G1(86YD;&5R"B`@("`@
M*B!P<FEO<B!T;R!I;G9O8V%T:6]N(&]F('1H:7,@;65T:&]D"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=V)X;6P@(%1H92!70EA-3"!D;V-U;65N
M="!T;R!D96-O9&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E8V]D92@D=V)X;6PI"B`@("!["B`@("`@("`@)'1H:7,M/E]E<G)O
M<B`](&9A;'-E.R`O+R!R97-E="!S=&%T90H*("`@("`@("`D=&AI<RT^7W-T
M<G!O<R`](#`["@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V-H*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)TYO($-O;G1E
M;G1H86YD;&5R(&1E9FEN960N)RD["B`@("`@("`@?0H*("`@("`@("`O+R!'
M970@5F5R<VEO;B!.=6UB97(@9G)O;2!396-T:6]N(#4N-`H@("`@("`@("\O
M('9E<G-I;VX@/2!U7VEN=#@*("`@("`@("`O+R!C=7)R96YT;'D@,2P@,B!O
M<B`S"B`@("`@("`@)'1H:7,M/E]W8GAM;%9E<G-I;VX@/2`D=&AI<RT^9V5T
M5F5R<VEO;DYU;6)E<B@D=V)X;6PI.PH*("`@("`@("`O+R!'970@1&]C=6UE
M;G0@4'5B;&EC($ED971I9FEE<B!F<F]M(%-E8W1I;VX@-2XU"B`@("`@("`@
M+R\@<'5B;&EC:60@/2!M8E]U7VEN=#,R('P@*'IE<F\@:6YD97@I"B`@("`@
M("`@+R\@>F5R;R`]('5?:6YT.`H@("`@("`@("\O($-O;G1A:6YI;F<@=&AE
M('9A;'5E('IE<F\@*#`I"B`@("`@("`@+R\@5&AE(&%C='5A;"!$4$D@:7,@
M9&5T97)M:6YE9"!A9G1E<B!T:&4@4W1R:6YG(%1A8FQE(&ES(')E860N"B`@
M("`@("`@)&1P:5-T<G5C="`]("1T:&ES+3YG971$;V-U;65N=%!U8FQI8TED
M96YT:69I97(H)'=B>&UL*3L*"B`@("`@("`@+R\@1V5T($-H87)S970@9G)O
M;2`U+C8*("`@("`@("`O+R!C:&%R<V5T(#T@;6)?=5]I;G0S,@H@("`@("`@
M("1T:&ES+3Y?8VAA<G-E="`]("1T:&ES+3YG971#:&%R<V5T*"1W8GAM;"D[
M"@H@("`@("`@("\O($=E="!3=')I;F<@5&%B;&4@9G)O;2`U+C<*("`@("`@
M("`O+R!S=')B,2`](&QE;F=T:"`J8GET90H@("`@("`@("1T:&ES+3YR971R
M:65V95-T<FEN9U1A8FQE*"1W8GAM;"D["@H@("`@("`@("\O($=E="!$;V-U
M;65N="!0=6)L:6,@261E=&EF:65R(&9R;VT@4V5C=&EO;B`U+C4N"B`@("`@
M("`@)'1H:7,M/E]D<&D@/2`D=&AI<RT^9V5T1&]C=6UE;G10=6)L:6-)9&5N
M=&EF:65R26UP;"@D9'!I4W1R=6-T6R=D<&E4>7!E)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9'!I4W1R=6-T6R=D<&E.=6UB97(G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<W1R:6YG5&%B;&4I.PH*("`@("`@("`O+R!.;W<@=&AE(')E
M86P@9G5N(&)E9VEN<RX*("`@("`@("`O+R!&<F]M(%-E8W1I;VYS(#4N,B!A
M;F0@-2XX"@H*("`@("`@("`O+R!$969A=6QT(&-O;G1E;G0@:&%N9&QE<BX*
M("`@("`@("`D=&AI<RT^7V1T9$UA;F%G97(@/2`F;F5W(%A-3%]70EA-3%]$
M5$1-86YA9V5R*"D["@H@("`@("`@("\O($=E="!T:&4@<W1A<G1I;F<@1%1$
M+@H@("`@("`@("1T:&ES+3Y?=&%G1%1$(#T@)'1H:7,M/E]D=&1-86YA9V5R
M+3YG971);G-T86YC92@D=&AI<RT^7V1P:2D["@H@("`@("`@(&EF("@A)'1H
M:7,M/E]T86=$5$0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"=.;R!$5$0@9F]U;F0@9F]R("<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("1T:&ES+3Y?9'!I("X@)R\G"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`D9'!I4W1R=6-T6R=D<&E.=6UB97(G72D["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7V%T=')I8G5T94141"`]("1T:&ES
M+3Y?=&%G1%1$.PH*("`@("`@("!W:&EL92`H96UP='DH)'1H:7,M/E]E<G)O
M<BD@)B8@)'1H:7,M/E]S=')P;W,@/"!S=')L96XH)'=B>&UL*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V1E8V]D92@D=V)X;6PI.PH@("`@("`@('T*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?97)R;W(I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V5R<F]R.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G971697)S:6]N3G5M8F5R
M*"1I;G!U="D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$)Y=&4H
M)&EN<'5T*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971$;V-U;65N=%!U8FQI
M8TED96YT:69I97(H)&EN<'5T*0H@("`@>PH@("`@("`@("1I(#T@6$U,7U="
M6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I.PH@
M("`@("`@(&EF("@D:2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@G9'!I5'EP92<@/3X@,BP*("`@("`@("`@("`@("`@("`@("`@("`@("=D
M<&E.=6UB97(G(#T^("1T:&ES+3YG971">71E*"1I;G!U="DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G9'!I5'EP92<@
M/3X@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("=D<&E.=6UB97(G(#T^
M("1I*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&]C=6UE
M;G10=6)L:6-)9&5N=&EF:65R26UP;"@D9'!I5'EP92P@)&1P:4YU;6)E<BD*
M("`@('L*("`@("`@("!I9B`H)&1P:51Y<&4@/3T@,2D@>PH@("`@("`@("`@
M("!R971U<FX@6$U,7U="6$U,.CIG971$4$E3=')I;F<H)&1P:4YU;6)E<BD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG
M9713=')I;F=486)L945N=')Y*"1D<&E.=6UB97(I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)A8W1E<B!E;F-O
M9&EN9RX@3VYL>2!D969A=6QT(&-H87)A8W1E<@H@("`@("H@96YC;V1I;F=S
M(&9R;VT@2C)312!A<F4@<W5P<&]R=&5D+B`@1G)O;0H@("`@("H@:'1T<#HO
M+W=W=RYI86YA+F]R9R]A<W-I9VYM96YT<R]C:&%R86-T97(M<V5T<R!A;F0*
M("`@("`J(&AT='`Z+R]J879A+G-U;BYC;VTO:C)S92\Q+C0N,B]D;V-S+V%P
M:2]J879A+VYI;R]C:&%R<V5T+T-H87)S970N:'1M;`H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971#:&%R<V5T*"1I;G!U="D*("`@('L*("`@("`@("`D8W,@
M/2!834Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T
M<G!O<RD["B`@("`@("`@<F5T=7)N(%A-3%]70EA-3#HZ9V5T0VAA<G-E=%-T
M<FEN9R@D8W,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H
M92!S=')I;F<@=&%B;&4N"B`@("`@*B!4:&4@<W1R:6YG('1A8FQE(&-O;G-I
M<W1S(&]F(&%N(&UB7W5?:6YT,S(@;&5N9W1H"B`@("`@*B!A;F0@=&AE;B!L
M96YG=&@@8GET97,@9F]R;6EN9R!T:&4@=&%B;&4N"B`@("`@*B!2969E<F5N
M8V5S('1O('1H92!S=')I;F<@=&%B;&4@<F5F97(@=&\@=&AE"B`@("`@*B!S
M=&%R=&EN9R!P;W-I=&EO;B!O9B!T:&4@*&YU;&P@=&5R;6EN871E9"D*("`@
M("`J('-T<FEN9R!I;B!T:&ES('1A8FQE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R971R:65V95-T<FEN9U1A8FQE*"1I;G!U="D*("`@('L*("`@("`@("`D
M<VEZ92`](%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES
M+3Y?<W1R<&]S*3L*("`@("`@("`D=&AI<RT^7W-T<FEN9U1A8FQE(#T@<W5B
M<W1R*"1I;G!U="P@)'1H:7,M/E]S=')P;W,L("1S:7IE*3L*("`@("`@("`D
M=&AI<RT^7W-T<G!O<R`K/2`D<VEZ93L*("`@("`@("`O+R!P<FEN="`B<W1R
M:6YG=&%B;&4H)'-I>F4I.B(@+B`D=&AI<RT^7W-T<FEN9U1A8FQE("XB7&XB
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-T<FEN9U1A8FQE16YT<GDH)&EN
M9&5X*0H@("`@>PH@("`@("`@(&EF("@D:6YD97@@/CT@<W1R;&5N*"1T:&ES
M+3Y?<W1R:6YG5&%B;&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(@
M/0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C:"T^<F%I<V5%<G)O<B@G26YV
M86QI9"!O9F9S970@)R`N("1I;F1E>`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G('9A;'5E(&5N8V]U;G1E<F5D(&%R;W5N9"!P
M;W-I=&EO;B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("1T:&ES+3Y?<W1R<&]S"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("<N($)R;VME;B!W8GAM;#\G*3L*("`@("`@("`@("`@
M<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@+R\@8V]P>2!O9B!M971H
M;V0@=&5R;7-T<B!B=70@=VET:&]U="!M;V1I9FEC871I;VX@;V8@=&AI<RT^
M7W-T<G!O<PH*("`@("`@("`D<W1R(#T@)R,G.R`O+R!M=7-T('-T87)T('=I
M=&@@;F]N96UP='D@<W1R:6YG('1O(&%L;&]W(&%R<F%Y(&%C8V5S<PH*("`@
M("`@("`D:2`](#`["B`@("`@("`@)&-H(#T@)'1H:7,M/E]S=')I;F=486)L
M95LD:6YD97@K*UT["B`@("`@("`@:68@*&]R9"@D8V@I(#T](#`I('L*("`@
M("`@("`@("`@<F5T=7)N("<G.R`O+R!D;VXG="!R971U<FX@)R,G"B`@("`@
M("`@?0H*("`@("`@("!W:&EL92`H;W)D*"1C:"D@(3T@,"D@>PH@("`@("`@
M("`@("`D<W1R6R1I*RM=(#T@)&-H.PH@("`@("`@("`@("!I9B`H)&EN9&5X
M(#X]('-T<FQE;B@D=&AI<RT^7W-T<FEN9U1A8FQE*2D@>PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-H(#T@
M)'1H:7,M/E]S=')I;F=486)L95LD:6YD97@K*UT["B`@("`@("`@?0H@("`@
M("`@("\O('!R:6YT(")S=')I;F<@=&%B;&4@96YT<GDZ("1S=')<;B(["B`@
M("`@("`@<F5T=7)N("1S='(["@H@("`@?0H*("`@(&9U;F-T:6]N(%]D96-O
M9&4H)&EN<'5T*0H@("`@>PH@("`@("`@("1T;VME;B`]("1T:&ES+3YG971"
M>71E*"1I;G!U="D["B`@("`@("`@)'-T<B`]("<G.PH*("`@("`@("`O+R!P
M<FEN="`B<&]S:71I;VXZ("(@+B`D=&AI<RT^7W-T<G!O<R`N("(@=&]K96XZ
M("(@+B`D=&]K96X@+B`B('-T<C$P.B`B("X@<W5B<W1R*"1I;G!U="P@)'1H
M:7,M/E]S=')P;W,L(#$P*2`N(")<;B([("\O($!T;V1O.B!R96UO=F4@9&5B
M=6<@;W5T<'5T"@H@("`@("`@('-W:71C:"`H)'1O:V5N*2!["B`@("`@("`@
M8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]).@H@("`@("`@("`@
M("`O+R!396-T:6]N(#4N."XT+C$*("`@("`@("`@("`@)'-T<B`]("1T:&ES
M+3YT97)M<W1R*"1I;G!U="D["B`@("`@("`@("`@("1T:&ES+3Y?8V@M/F-H
M87)A8W1E<G,H)'-T<BD["B`@("`@("`@("`@("\O('!R:6YT(")S='(Z)'-T
M<EQN(CL@+R\@0%1/1$\@4F5M;W9E(&1E8G5G(&-O9&4*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]3
M5%)?5#H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XQ"B`@("`@("`@
M("`@("1X(#T@6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H
M:7,M/E]S=')P;W,I.PH@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T
M<FEN9U1A8FQE16YT<GDH)'@I.PH@("`@("`@("`@("`D=&AI<RT^7V-H+3YC
M:&%R86-T97)S*"1S='(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S`Z"B`@("`@("`@
M8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S$Z"B`@("`@("`@
M8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S(Z"B`@("`@("`@
M("`@("\O(%-E8W1I;VX@-2XX+C0N,@H@("`@("`@("`@("`D<W1R(#T@)'1H
M:7,M/G1E<FUS='(H)&EN<'5T*3L*("`@("`@("`@("`@)'1H:7,M/E]C:"T^
M8VAA<F%C=&5R<R@D<W1R*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\P.@H@("`@("`@
M(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\Q.@H@("`@("`@
M(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\R.@H@("`@("`@
M("`@("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@)'-T<B`]("1T
M:&ES+3YG9713=')I;F=486)L945N='DH6$U,7U="6$U,.CI-0E5);G0S,E1O
M26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H
M:7,M/E]C:"T^8VAA<F%C=&5R<R@D<W1R*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,#H*
M("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47S$Z"B`@
M("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%\R.@H@("`@
M("`@("`@("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@)&5X=&5N
M<VEO;B`]("1T:&ES+3YG971">71E*"1I;G!U="D["B`@("`@("`@("`@("1T
M:&ES+3Y?8V@M/F-H87)A8W1E<G,H)&5X=&5N<VEO;BD["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?
M14Y42519.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C,*("`@("`@
M("`@("`@+R\@54-3+30@8VAR86-T97(@96YC;V1I;F<_"B`@("`@("`@("`@
M("1E;G1I='D@/2`D=&AI<RT^96YT:71Y*%A-3%]70EA-3#HZ34)526YT,S)4
M;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["@H@("`@("`@("`@("`D
M=&AI<RT^7V-H+3YC:&%R86-T97)S*"<F(R<@+B`D96YT:71Y("X@)SLG*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,
M3T)!3%]43TM%3E]023H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XT
M"B`@("`@("`@("`@("\O('1H<F]W(&YE=R!)3T5X8V5P=&EO;@H@("`@("`@
M("`@("`O+R!D:64H(E="6$U,(&=L;V)A;"!T;VME;B!P<F]C97-S:6YG(&EN
M<W1R=6-T:6]N*%!)+"`B("L@=&]K96X@*R`B*2!I<R!U;G-U<'!O<G1E9"%<
M;B(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)8
M34Q?1TQ/0D%,7U1/2T5.7TQ)5$5204PZ"B`@("`@("`@("`@("\O(%-E8W1I
M;VX@-2XX+C0N-0H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN
M9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@
M)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M/G!A<G-E5&%G
M*"1I;G!U="P@)'-T<BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%
M4D%,7T$Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N-0H@("`@("`@
M("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="
M6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*
M("`@("`@("`@("`@)'1H:7,M/G!A<G-E5&%G*"1I;G!U="P@)'-T<BP@=')U
M92P@9F%L<V4I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!8
M34Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204Q?04,Z"B`@("`@("`@("`@
M("\O(%-E8W1I;VX@-2XX+C0N-0H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M
M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT
M*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M
M/G!A<G-E5&%G*"1I;G!U="P@)'-T<FEN9RP@=')U92P@=')U92D["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?3$E415)!3%]#.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT
M+C4*("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YG9713=')I;F=486)L945N
M=')Y*%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?
M<W1R<&]S*2D["B`@("`@("`@("`@("1T:&ES+3YP87)S951A9R@D:6YP=70L
M("1S='(L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]/4$%1544Z"B`@("`@
M("`@("`@("\O(%-E8W1I;VX@-2XX+C0N-@H@("`@("`@("`@("`D<VEZ92`]
M(%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R
M<&]S*3L*("`@("`@("`@("`@+R\@<')I;G0@(F]P87%U92!O9B!S:7IE("1S
M:7IE7&XB.R`O+R!`=&]D;R!R96UO=F4@9&5B=6<*("`@("`@("`@("`@)&(@
M/2!S=6)S='(H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RP@)'-I>F4I.PH@("`@
M("`@("`@("`D=&AI<RT^7W-T<G!O<R`K/2`D<VEZ93L*"B`@("`@("`@("`@
M("\O(&]P87%U92!D871A(&EN<VED92!A(#QD871A/B!E;&5M96YT(&UA>2!O
M<B!M87D@;F]T(&)E"B`@("`@("`@("`@("\O(&$@;F5S=&5D('=B>&UL(&1O
M8W5M96YT("AF;W(@97AA;7!L92!D979I;F8@9&%T82DN"B`@("`@("`@("`@
M("\O(%=E(&9I;F0@;W5T(&)Y(&-H96-K:6YG('1H92!F:7)S="!B>71E(&]F
M('1H92!D871A.B!I9B!I="=S"B`@("`@("`@("`@("\O(#$L(#(@;W(@,R!W
M92!E>'!E8W0@:70@=&\@8F4@=&AE('9E<G-I;VX@;G5M8F5R(&]F(&$@=V)X
M;6P*("`@("`@("`@("`@+R\@9&]C=6UE;G0@86YD('1H=7,@<W1A<G0@82!N
M97<@=V)X;6P@9&5C;V1E<B!I;G-T86YC92!O;B!I="X*"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7VES1&%T82`F)B!O<F0H)&(I(#P](#$P*2!["B`@("`@
M("`@("`@("`@("`D9&5C;V1E<B`]("9N97<@6$U,7U="6$U,7T1E8V]D97(H
M=')U92D["B`@("`@("`@("`@("`@("`D9&5C;V1E<BT^<V5T0V]N=&5N=$AA
M;F1L97(H)'1H:7,M/E]C:"D["B`@("`@("`@("`@("`@("`D<R`]("1D96-O
M9&5R+3YD96-O9&4H)&(I.PH@("`@("`@("\O("`@("`@("`@("`@("`@("\J
M("\O($!T;V1O.B!&25A-12!C=7)R96YT;'D@=V4@8V%N)W0@9&5C;V1E($YO
M:VEA"B`@("`@("`@("`@("`@("`O+R!$979);F8@9&%T82X@4V\@:6=N;W)E
M(&5R<F]R(&9O<B!T:&4@=&EM92!B965I;F<N"B`@("`@("`@:68@*&ES7V$H
M)',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V5R<F]R(#T@)',["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@*B\*("`@("`@
M("`@("`@("`@("\O("1T:&ES+3Y?8V@M/F-H87)A8W1E<G,H)',I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@;F]R;6%L(&]P
M87%U92!B96AA=FEO=7(Z(&IU<W0@8V]P>2!T:&4@<F%W(&1A=&$Z("HO"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-H+3YC:&%R86-T97)S*"`D8BD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\O(&]L9"!A<'!R;V%C:"!T;R!D
M96%L('=I=&@@;W!A<75E(&1A=&$@:6YS:61E($-O;G1E;G1(86YD;&5R.@H@
M("`@("`@("`@("`O+R!&25A-12!/<&%Q=64@:7,@=7-E9"!B>2!364Y#34PN
M("!/<&%Q=64@9&%T82!T:&%T(&1E<&5N9',@;VX@=&AE(&-O;G1E>'0*("`@
M("`@("`@("`@+R\@:68@*&-O;G1E;G1(86YD;&5R(&EN<W1A;F-E;V8@3W!A
M<75E0V]N=&5N=$AA;F1L97(I('L*("`@("`@("`@("`@+R\@("`@("@H3W!A
M<75E0V]N=&5N=$AA;F1L97(I8V]N=&5N=$AA;F1L97(I+F]P87%U92AB*3L*
M("`@("`@("`@("`@+R\@?2!E;'-E('L*("`@("`@("`@("`@+R\@("`@(%-T
M<FEN9R!S='(@/2!N97<@4W1R:6YG*&(L(#`L('-I>F4L(&-H87)S970I.PH@
M("`@("`@("`@("`O+R`@("`@8VAA<EM=(&-H87)S(#T@<W1R+G1O0VAA<D%R
M<F%Y*"D["@H@("`@("`@("`@("`O+R`@("`@8V]N=&5N=$AA;F1L97(N8VAA
M<F%C=&5R<RAC:&%R<RP@,"P@8VAA<G,N;&5N9W1H*3L*("`@("`@("`@("`@
M+R\@?0H*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="
M6$U,7T=,3T)!3%]43TM%3E]%3D0Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@
M-2XX+C0N-RXQ"B`@("`@("`@("`@("1S='(@/2`D=&AI<RT^96YD5&%G*"D[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'
M3$]"04Q?5$]+14Y?4U=)5$-(7U!!1T4Z"B`@("`@("`@("`@("\O(%-E8W1I
M;VX@-2XX+C0N-RXR"B`@("`@("`@("`@("1C;V1E4&%G92`]("1T:&ES+3YG
M971">71E*"1I;G!U="D["B`@("`@("`@("`@("\O('!R:6YT(")S=VET8V@@
M=&\@8V]D97!A9V4@)&-O9&5086=E7&XB.R`O+R!`=&]D;SH@<F5M;W9E(&1E
M8G5G(&-O9&4*("`@("`@("`@("`@)'1H:7,M/G-W:71C:$5L96UE;G1#;V1E
M4&%G92@D8V]D95!A9V4I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N,@H@("`@("`@
M("`@("`O+R!396-T:6]N(#4N."XS"B`@("`@("`@("`@("1H87-!='1R:6)U
M=&5S(#T@*"@D=&]K96X@)B`P>#@P*2`A/2`P*3L*("`@("`@("`@("`@)&AA
M<T-O;G1E;G0@/2`H*"1T;VME;B`F(#!X-#`I("$](#`I.PH@("`@("`@("`@
M("`D<F5A;%1O:V5N(#T@)'1O:V5N("8@,'@S1CL*("`@("`@("`@("`@)'-T
M<B`]("1T:&ES+3YG971486<H)')E86Q4;VME;BD["@H@("`@("`@("`@("`O
M+R!P<FEN="`B96QE;65N=#HD<W1R7&XB.R`O+R!`5$]$3R!296UO=F4@9&5B
M=6<@8V]D90H@("`@("`@("`@("`D=&AI<RT^<&%R<V5486<H)&EN<'5T+"`D
M<W1R+"`D:&%S071T<FEB=71E<RP@)&AA<T-O;G1E;G0I.PH*("`@("`@("`@
M("`@:68@*"1R96%L5&]K96X@/3T@,'@P9BD@>PH@("`@("`@("`@("`@("`@
M+R\@<W1O<F4@:68@=V4G<F4@:6YS:61E(&$@1&%T82!T86<N(%1H:7,@;6%Y
M(&-O;G1A:6X*("`@("`@("`@("`@("`@("\O(&%N(&%D9&ET:6]N86P@96YC
M;&]S960@=V)X;6P@9&]C=6UE;G0@;VX@=VAI8V@@=V4@:&%V90H@("`@("`@
M("`@("`@("`@+R\@=&\@<G5N(&$@<V5P97)A=&4@96YC;V1E<@H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]I<T1A=&$@/2!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I<T1A=&$@/2!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V5486<H)&EN<'5T+"`D=&%G+"`D
M:&%S071T<FEB=71E<RP@)&AA<T-O;G1E;G0I"B`@("!["B`@("`@("`@)&%T
M=')S(#T@87)R87DH*3L*("`@("`@("!I9B`H)&AA<T%T=')I8G5T97,I('L*
M("`@("`@("`@("`@)&%T=')S(#T@)'1H:7,M/F=E=$%T=')I8G5T97,H)&EN
M<'5T*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V@M/G-T87)T16QE
M;65N="@D=&AI<RT^9V5T0W5R<F5N=%5222@I+"`D=&%G+"`D871T<G,I.PH*
M("`@("`@("!I9B`H)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@+R\@1DE8
M344@22!F;W)G;W0@=VAA="!D;V5S('1H:7,@9&]E<RX@3F]T('-U<F4@:68@
M=&AI<R!I<PH@("`@("`@("`@("`O+R!R:6=H=#\*("`@("`@("`@("`@)'1H
M:7,M/E]T86=3=&%C:UM=(#T@)'1A9SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7V-H+3YE;F1%;&5M96YT*"1T:&ES+3YG971#=7)R
M96YT55))*"DL("1T86<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!E;F1486<H*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W1A
M9U-T86-K*2D@>PH@("`@("`@("`@("`D=&%G(#T@87)R87E?<&]P*"1T:&ES
M+3Y?=&%G4W1A8VLI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M86<@/2`G56YK;F]W;B<["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H
M+3YE;F1%;&5M96YT*"1T:&ES+3YG971#=7)R96YT55))*"DL("1T86<I.PH*
M("`@("`@("!R971U<FX@)'1A9SL*("`@('T*"B`@("!F=6YC=&EO;B!G971!
M='1R:6)U=&5S*"1I;G!U="D*("`@('L*("`@("`@("`D=&AI<RT^<W1A<G1'
M971!='1R:6)U=&5S*"D["B`@("`@("`@)&AA<TUO<F5!='1R:6)U=&5S(#T@
M=')U93L*"B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*("`@("`@("`D871T
M<B`](&YU;&P["B`@("`@("`@)'9A;'5E(#T@;G5L;#L*("`@("`@("`D=&]K
M96X@/2!N=6QL.PH*("`@("`@("!W:&EL92`H)&AA<TUO<F5!='1R:6)U=&5S
M*2!["B`@("`@("`@("`@("1T;VME;B`]("1T:&ES+3YG971">71E*"1I;G!U
M="D["@H@("`@("`@("`@("!S=VET8V@@*"1T;VME;BD@>PH@("`@("`@("`@
M("`O+R!!='1R:6)U=&4@<W!E8VEF:65D+@H@("`@("`@("`@("!C87-E(%A-
M3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3#H*("`@("`@("`@("`@("`@
M("\O(%-E8W1I;VX@-2XX+C0N-0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1A='1R*2D@>PH@("`@("`@("`@("`@("`@("`@("1A='1R<UM=(#T@87)R
M87DH)V%T=')I8G5T92<@/3X@)&%T='(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1V86QU92D["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&%T='(@/2`D=&AI<RT^9V5T
M4W1R:6YG5&%B;&5%;G1R>2A834Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN
M<'5T+"`D=&AI<RT^7W-T<G!O<RDI.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`O+R!686QU92!S<&5C:69I960N"B`@("`@("`@("`@
M(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\P.@H@("`@("`@
M("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?,3H*("`@
M("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S(Z
M"B`@("`@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@
M("`@("`@("1V86QU92`N/2`D=&AI<RT^=&5R;7-T<B@D:6YP=70I.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(%A-3%]70EA-
M3%]'3$]"04Q?5$]+14Y?15A47U1?,#H*("`@("`@("`@("`@8V%S92!834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T585%]47S$Z"B`@("`@("`@("`@(&-A<V4@
M6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\R.@H@("`@("`@("`@("`@
M("`@+R\@4V5C=&EO;B`U+C@N-"XR"B`@("`@("`@("`@("`@("`D=F%L=64@
M+CT@)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5)
M;G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/
M0D%,7U1/2T5.7T585%\P.@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'
M3$]"04Q?5$]+14Y?15A47S$Z"B`@("`@("`@("`@(&-A<V4@6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E]%6%1?,CH*("`@("`@("`@("`@("`@("\O(%-E8W1I
M;VX@-2XX+C0N,@H@("`@("`@("`@("`@("`@)'9A;'5E("X]("1I;G!U=%LD
M=&AI<RT^7W-T<G!O<RLK73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.5$E463H*
M("`@("`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,PH@("`@("`@("`@
M("`@("`@)'9A;'5E("X]("1T:&ES+3YE;G1I='DH6$U,7U="6$U,.CI-0E5)
M;G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/
M0D%,7U1/2T5.7U-44E]).@H@("`@("`@("`@("`@("`@+R\@4V5C=&EO;B`U
M+C@N-"XQ"B`@("`@("`@("`@("`@("`D=F%L=64@+CT@)'1H:7,M/G1E<FUS
M='(H)&EN<'5T*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]4.@H@("`@("`@
M("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XQ"B`@("`@("`@("`@("`@("`D
M=F%L=64@+CT@)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,
M.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)8
M34Q?1TQ/0D%,7U1/2T5.7T]005%513H*("`@("`@("`@("`@("`@("\O(%-E
M8W1I;VX@-2XX+C0N-@H@("`@("`@("`@("`@("`@)'-I>F4@/2!834Q?5T)8
M34PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RD["B`@
M("`@("`@("`@("`@("`D8B`]('-U8G-T<B@D:6YP=70L("1T:&ES+3Y?<W1R
M<&]S+"`D=&AI<RT^7W-T<G!O<R`K("1S:7IE*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<W1R<&]S("L]("1S:7IE.PH*("`@("`@("`@("`@("`@("1V
M86QU92`N/2`D8CL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.1#H*("`@("`@("`@
M("`@("`@("\O(%-E8W1I;VX@-2XX+C0N-RXQ"B`@("`@("`@("`@("`@("`D
M:&%S36]R94%T=')I8G5T97,@/2!F86QS93L*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D871T<BDI('L*("`@("`@("`@("`@("`@("`@("`D871T<G-;
M72`](&%R<F%Y*"=A='1R:6)U=&4G(#T^("1A='1R+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D=F%L=64I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U=)5$-(7U!!
M1T4Z"B`@("`@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C<N,@H@("`@
M("`@("`@("`@("`@)&-O9&5086=E(#T@)'1H:7,M/F=E=$)Y=&4H)&EN<'5T
M*3L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]P<F5V071T<FEB=71E
M1%1$*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5V071T<FEB
M=71E1%1$(#T@)'1H:7,M/E]A='1R:6)U=&5$5$0["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)'1H:7,M/G-W:71C:$%T=')I8G5T94-O
M9&5086=E*"1C;V1E4&%G92D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!I9B`H)'1O:V5N
M(#X@,3(X*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D871T<G-;72`](&%R<F%Y
M*"=A='1R:6)U=&4G(#T^("1A='1R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&%T='(@/2`D
M=&AI<RT^7V%T=')I8G5T94141"T^=&]!='1R:6)U=&4H)'1O:V5N*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@
M5F%L=64N"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E("X]("1T:&ES+3Y?
M871T<FEB=71E1%1$+3YT;T%T=')I8G5T92@D=&]K96XI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/E]P<F5V071T<FEB=71E
M1%1$*2!["B`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E1%1$(#T@)'1H
M:7,M/E]P<F5V071T<FEB=71E1%1$.PH@("`@("`@("`@("`D=&AI<RT^7W!R
M979!='1R:6)U=&5$5$0@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3YS=&]P1V5T071T<FEB=71E<R@I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('-T87)T1V5T071T<FEB=71E<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I
M<T%T=')I8G5T92`]('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@<W1O<$=E
M=$%T=')I8G5T97,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:7-!='1R:6)U
M=&4@/2!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971#=7)R96YT55))
M*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I<T%T=')I8G5T92D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T86=$5$0M/F=E=%5222@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%T
M=')I8G5T94141"T^9V5T55))*"D["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N('=R:71E4W1R:6YG*"1S='(I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]C:"T^8VAA<F%C=&5R<R@D<W1R*3L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971486<H)'1A9RD*("`@('L*("`@("`@("`O+R!3:&]U;&0@:VYO=R!W:&EC
M:"!S=&%T92!I="!I<R!I;BX*("`@("`@("!R971U<FX@)'1H:7,M/E]T86=$
M5$0M/G1O5&%G4W1R*"1T86<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$%T
M=')I8G5T92@D871T<FEB=71E*0H@("`@>PH@("`@("`@("\O(%-H;W5L9"!K
M;F]W('=H:6-H('-T871E(&ET(&ES(&EN+@H@("`@("`@("1T:&ES+3Y?871T
M<FEB=71E1%1$+3YT;T%T=')I8G5T94EN="@D871T<FEB=71E*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!S=VET8VA%;&5M96YT0V]D95!A9V4H)&-O9&5086=E
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&%G1%1$(#T@)B1T:&ES+3Y?9'1D
M36%N86=E<BT^9V5T26YS=&%N8V4H)'1H:7,M/E]T86=$5$0M/G1O0V]D95!A
M9V53='(H)&-O9&5086=E*2D["B`@("`@("`@)'1H:7,M/G-W:71C:$%T=')I
M8G5T94-O9&5086=E*"1C;V1E4&%G92D["B`@("!]"@H@("`@9G5N8W1I;VX@
M<W=I=&-H071T<FEB=71E0V]D95!A9V4H)&-O9&5086=E*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?871T<FEB=71E1%1$(#T@)B1T:&ES+3Y?9'1D36%N86=E
M<BT^9V5T26YS=&%N8V4H)'1H:7,M/E]A='1R:6)U=&5$5$0M/G1O0V]D95!A
M9V53='(H)&-O9&5086=E*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@=&AE(&AE>"!V97)S:6]N(&]F('1H92!B87-E(#$P("1E;G1I='DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5N=&ET>2@D96YT:71Y*0H@("`@>PH@("`@
M("`@(')E='5R;B!D96-H97@H)&5N=&ET>2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296%D<R!A(&YU;&P@=&5R;6EN871E9"!S=')I;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1E<FUS='(H)&EN<'5T*0H@("`@>PH@("`@("`@("1S
M='(@/2`G(R<[("\O(&UU<W0@<W1A<G0@=VET:"!N;VYE;7!T>2!S=')I;F<@
M=&\@86QL;W<@87)R87D@86-C97-S"B`@("`@("`@)&D@/2`P.PH@("`@("`@
M("1C:"`]("1I;G!U=%LD=&AI<RT^7W-T<G!O<RLK73L*("`@("`@("!I9B`H
M;W)D*"1C:"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<[("\O(&1O
M;B=T(')E='5R;B`G(R<*("`@("`@("!]"B`@("`@("`@=VAI;&4@*&]R9"@D
M8V@I("$](#`I('L*("`@("`@("`@("`@)'-T<ELD:2LK72`]("1C:#L*("`@
M("`@("`@("`@)&-H(#T@)&EN<'5T6R1T:&ES+3Y?<W1R<&]S*RM=.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1S='(["B`@("!]"@I]"@H`````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T5N8V]D97(N
M<&AP````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,P,#(P`#$P
M-#$W,S8R-S<U`#`R,#8P-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=834PO5T)834PN
M<&AP)SL*:6YC;'5D95]O;F-E("=834PO5T)834PO0V]N=&5N=$AA;F1L97(N
M<&AP)SL*:6YC;'5D95]O;F-E("=834PO5T)834PO1%1$36%N86=E<BYP:'`G
M.PII;F-L=61E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J("1(
M;W)D93H@9G)A;65W;W)K+UA-3%]70EA-3"]70EA-3"]%;F-O9&5R+G!H<"QV
M(#$N,C4N,3`N,3$@,C`P-B\P,R\Q,2`P.3HU-3HU-2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`
M<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($9R;VT@0FEN87)Y
M(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS
M+"`R-2!*=6QY"B`J(#(P,#$@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U
M;2YO<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?
M5T)834Q?16YC;V1E<B!E>'1E;F1S(%A-3%]70EA-3%]#;VYT96YT2&%N9&QE
M<B!["@H@("`@=F%R("1?<W1R:6YG<R`](&%R<F%Y*"D["@H@("`@=F%R("1?
M<W1R:6YG5&%B;&4["@H@("`@=F%R("1?:&%S5W)I='1E;DAE861E<B`](&9A
M;'-E.PH*("`@('9A<B`D7V1T9#L*"B`@("!V87(@)%]O=71P=70@/2`G)SL*
M"B`@("!V87(@)%]U<FES(#T@87)R87DH*3L*"B`@("!V87(@)%]U<FE.=6US
M(#T@87)R87DH*3L*"B`@("!V87(@)%]C=7)R96YT55)).PH*("`@('9A<B`D
M7W-U8E!A<G-E<B`](&YU;&P["B`@("!V87(@)%]S=6)087)S97)3=&%C:R`]
M(#`["@H@("`@+RHJ"B`@("`@*B!4:&4@6$U,('!A<G-E<BX*("`@("`J"B`@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7W!A<G-E<CL*
M"B`@("`O*BH*("`@("`J(%1H92!$5$0@36%N86=E<BX*("`@("`J"B`@("`@
M*B!`=F%R(%A-3%]70EA-3%]$5$1-86YA9V5R"B`@("`@*B\*("`@('9A<B`D
M7V1T9$UA;F%G97(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@6$U,7U="6$U,7T5N8V]D97(H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?9'1D36%N86=E<B`]("9N97<@6$U,7U="6$U,7T14
M1$UA;F%G97(H*3L*("`@("`@("`D=&AI<RT^7W-T<FEN9U1A8FQE(#T@)FYE
M=R!834Q?5T)834Q?2&%S:%1A8FQE*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!486ME('1H92!I;G!U="`D>&UL(&%N9"!T=7)N(&ET(&EN=&\@5T)834PN
M(%1H:7,@:7,@7VYO=%\@=&AE"B`@("`@*B!I;G1E;F1E9"!W87D@;V8@=7-I
M;F<@=&AI<R!C;&%S<RX@270@:7,@9&5R:79E9"!F<F]M"B`@("`@*B!#;VYT
M96YT:&%N9&QE<B!A;F0@;VYE('-H;W5L9"!U<V4@:70@87,@82!#;VYT96YT
M2&%N9&QE<B!A;F0*("`@("`J('!R;V1U8V4@=&AE(%A-3"US=')U8W1U<F4@
M=VET:"!S=&%R=$5L96UE;G0H*2P@96YD16QE;65N="@I+`H@("`@("H@86YD
M(&-H87)A8W1E<G,H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC;V1E*"1X
M;6PI"B`@("!["B`@("`@("`@+R\@0W)E871E('1H92!834P@<&%R<V5R(&%N
M9"!S970@;65T:&]D(')E9F5R96YC97,N"B`@("`@("`@)'1H:7,M/E]P87)S
M97(@/2!X;6Q?<&%R<V5R7V-R96%T95]N<R@D=&AI<RT^7V-H87)S970I.PH@
M("`@("`@('AM;%]S971?;V)J96-T*"1T:&ES+3Y?<&%R<V5R+"`D=&AI<RD[
M"B`@("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1T:&ES+3Y?<&%R<V5R
M+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@9F%L<V4I.PH@("`@("`@('AM
M;%]S971?96QE;65N=%]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G7W-T87)T
M16QE;65N="<L("=?96YD16QE;65N="<I.PH@("`@("`@('AM;%]S971?8VAA
M<F%C=&5R7V1A=&%?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]C:&%R86-T
M97)S)RD["B`@("`@("`@>&UL7W-E=%]P<F]C97-S:6YG7VEN<W1R=6-T:6]N
M7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("<G*3L*("`@("`@("!X;6Q?<V5T
M7V5X=&5R;F%L7V5N=&ET>5]R969?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@
M)R<I.PH*("`@("`@("!I9B`H(7AM;%]P87)S92@D=&AI<RT^7W!A<G-E<BP@
M)'AM;"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*'-P<FEN=&8H)UA-3"!E<G)O<CH@)7,@870@;&EN92`E9"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM;%]E<G)O
M<E]S=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E*"1T:&ES+3Y?<&%R<V5R*2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D=&AI<RT^7W!A<G-E<BDI
M*3L*("`@("`@("!]"@H@("`@("`@('AM;%]P87)S97)?9G)E92@D=&AI<RT^
M7W!A<G-E<BD["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V]U='!U=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!W<FET92!T:&4@8V]R<F5C
M="!H96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET94AE861E<B@D
M=7)I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9'1D(#T@)B1T:&ES+3Y?9'1D
M36%N86=E<BT^9V5T26YS=&%N8V554DDH)'5R:2D["B`@("`@("`@:68@*"$D
M=&AI<RT^7V1T9"D@>PH@("`@("`@("`@("`O+R!43T1/.B!P<F]P97(@97)R
M;W(@:&%N9&QI;F<*("`@("`@("`@("`@9&EE*"=5;F%B;&4@=&\@9FEN9"!D
M=&0@9F]R("<@+B`D=7)I*3L*("`@("`@("!]"B`@("`@("`@)&1P:5-T<FEN
M9R`]("1T:&ES+3Y?9'1D+3YG971$4$DH*3L*"B`@("`@("`@+R\@4V5T(%9E
M<G-I;VX@3G5M8F5R(&9R;VT@4V5C=&EO;B`U+C0*("`@("`@("`O+R!V97)S
M:6]N(#T@=5]I;G0X"B`@("`@("`@+R\@8W5R<F5N=&QY(#$L(#(@;W(@,PH@
M("`@("`@("1T:&ES+3YW<FET959E<G-I;VY.=6UB97(H)'1H:7,M/E]W8GAM
M;%9E<G-I;VXI.PH*("`@("`@("`O+R!3970@1&]C=6UE;G0@4'5B;&EC($ED
M971I9FEE<B!F<F]M(%-E8W1I;VX@-2XU"B`@("`@("`@+R\@<'5B;&EC:60@
M/2!M8E]U7VEN=#,R('P@*"!Z97)O(&EN9&5X("D*("`@("`@("`O+R!Z97)O
M(#T@=5]I;G0X"B`@("`@("`@+R\@8V]N=&%I;FEN9R!T:&4@=F%L=64@>F5R
M;R`H,"D*("`@("`@("`O+R!4:&4@86-T=6%L($1022!I<R!D971E<FUI;F5D
M(&%F=&5R('1H92!3=')I;F<@5&%B;&4@:7,@<F5A9"X*("`@("`@("`D=&AI
M<RT^=W)I=&5$;V-U;65N=%!U8FQI8TED96YT:69I97(H)&1P:5-T<FEN9RP@
M)'1H:7,M/E]S=')I;F=S*3L*"B`@("`@("`@+R\@4V5T($-H87)S970@9G)O
M;2`U+C8*("`@("`@("`O+R!C:&%R<V5T(#T@;6)?=5]I;G0S,@H@("`@("`@
M("1T:&ES+3YW<FET94-H87)S970H)'1H:7,M/E]C:&%R<V5T*3L*"B`@("`@
M("`@+R\@4V5T(%-T<FEN9R!486)L92!F<F]M(#4N-PH@("`@("`@("\O('-T
M<F(Q(#T@;&5N9W1H("IB>71E"B`@("`@("`@)'1H:7,M/G=R:71E4W1R:6YG
M5&%B;&4H)'1H:7,M/E]S=')I;F=S+"`D=&AI<RT^7V-H87)S970L("1T:&ES
M+3Y?<W1R:6YG5&%B;&4I.PH*("`@("`@("`D=&AI<RT^7V-U<G)E;G154DD@
M/2`D=7)I.PH*("`@("`@("`D=&AI<RT^7VAA<U=R:71T96Y(96%D97(@/2!T
M<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E5F5R<VEO;DYU;6)E<B@D
M=F5R<VEO;BD*("`@('L*("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H
M)'9E<G-I;VXI.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E1&]C=6UE;G10
M=6)L:6-)9&5N=&EF:65R*"1D<&E3=')I;F<L("8D<W1R:6YG<RD*("`@('L*
M("`@("`@("`D:2`](%A-3%]70EA-3#HZ9V5T1%!)26YT*"1D<&E3=')I;F<I
M.PH*("`@("`@("!I9B`H)&D@/3T@,"D@>PH@("`@("`@("`@("`D<W1R:6YG
M<ULP72`]("1D<&E3=')I;F<["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<B@P*3L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR
M*#`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(%A-3%]70EA-3#HZ
M:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U='!U="P@)&DI.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!W<FET94-H87)S970H)&-H87)S970I"B`@
M("!["B`@("`@("`@)&-S(#T@6$U,7U="6$U,.CIG971#:&%R<V5T26YT*"1C
M:&%R<V5T*3L*"B`@("`@("`@:68@*"1C<R`]/2`P*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YS=7!P;W)T960@0VAA<G-E
M=#H@)R`N("1C:&%R<V5T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!834Q?5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M/E]O=71P=70L("1C
M<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('=R:71E4W1R:6YG
M5&%B;&4H)'-T<FEN9W,L("1C:&%R<V5T+"`D<W1R:6YG5&%B;&4I"B`@("![
M"B`@("`@("`@)'-T<FEN9T)Y=&5S(#T@87)R87DH*3L*("`@("`@("`D8V]U
M;G0@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1S=')I;F=S(&%S("1S='(I('L*
M("`@("`@("`@("`@)&)Y=&5S(#T@)'1H:7,M/E]G971">71E<R@D<W1R+"`D
M8VAA<G-E="D["B`@("`@("`@("`@("1S=')I;F=">71E<R`](&%R<F%Y7VUE
M<F=E*"1S=')I;F=">71E<RP@)&)Y=&5S*3L*("`@("`@("`@("`@)&YU;&Q,
M96YG=&@@/2`D=&AI<RT^7V%D9$YU;&Q">71E*"1B>71E<RD["B`@("`@("`@
M("`@("1T:&ES+3Y?<W1R:6YG5&%B;&4M/G-E="@D<W1R+"`D8V]U;G0I.PH@
M("`@("`@("`@("`D8V]U;G0@*ST@8V]U;G0H)&)Y=&5S*2`K("1N=6QL3&5N
M9W1H.PH@("`@("`@('T*"B`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN
M=#,R*"1T:&ES+3Y?;W5T<'5T+"!C;W5N="@D<W1R:6YG0GET97,I*3L*("`@
M("`@("`D=&AI<RT^7V]U='!U="`N/2!I;7!L;V1E*"<G+"`D<W1R:6YG0GET
M97,I.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E4W1R:6YG*"1S='(L("1C
M<RD*("`@('L*("`@("`@("`D8GET97,@/2`D=&AI<RT^7V=E=$)Y=&5S*"1S
M='(L("1C<RD["B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@:6UP;&]D92@G
M)RP@)&)Y=&5S*3L*("`@("`@("`D=&AI<RT^=W)I=&5.=6QL*"1C<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@=W)I=&5.=6QL*"1C:&%R<V5T*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@P*3L*("`@("`@("!R971U
M<FX@,3L*("`@('T*"B`@("!F=6YC=&EO;B!?861D3G5L;$)Y=&4H)B1B>71E
M<RD*("`@('L*("`@("`@("`D8GET97-;72`](&-H<B@P*3L*("`@("`@("!R
M971U<FX@,3L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T0GET97,H)'-T<FEN
M9RP@)&-S*0H@("`@>PH@("`@("`@("1S=')I;F<@/2!3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*"1S=')I;F<L("1C<RP@)W5T9BTX)RD["B`@("`@("`@)&YB
M>71E<R`]('-T<FQE;B@D<W1R:6YG*3L*"B`@("`@("`@)&)Y=&5S(#T@87)R
M87DH*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;F)Y=&5S.R`D:2LK
M*2!["B`@("`@("`@("`@("1B>71E<UM=(#T@)'-T<FEN9WLD:7T["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&)Y=&5S.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]S<&QI=%5222@D=&%G*0H@("`@>PH@("`@("`@("1P87)T<R`](&5X
M<&QO9&4H)SHG+"`D=&%G*3L*("`@("`@("`D;F%M92`](&%R<F%Y7W!O<"@D
M<&%R=',I.PH@("`@("`@("1U<FD@/2!I;7!L;V1E*"<Z)RP@)'!A<G1S*3L*
M("`@("`@("!R971U<FX@87)R87DH)'5R:2P@)&YA;64I.PH@("`@?0H*("`@
M(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D;F%M92P@)&%T=')I8G5T
M97,I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<W5B4&%R<V5R(#T](&YU
M;&PI('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7VAA<U=R:71T96Y(96%D
M97(I('L*("`@("`@("`@("`@("`@("1T:&ES+3YW<FET94AE861E<B@D=7)I
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C=7)R
M96YT55))("$]("1U<FDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YC:&%N
M9V5C;V1E<&%G92@D=7)I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]S=6)087)S97(@/3T@;G5L;"D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G=R:71E5&%G*"1N86UE+"`D871T<FEB=71E<RP@=')U92P@
M)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R+3YS=&%R=$5L96UE;G0H)'5R
M:2PD;F%M92P@)&%T=')I8G5T97,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97)3=&%C:RLK
M.PH@("`@("`@("`@("`D=&AI<RT^7W-U8E!A<G-E<BT^<W1A<G1%;&5M96YT
M*"1U<FDL)&YA;64L)&%T=')I8G5T97,I.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!?<W1A<G1%;&5M96YT*"1P87)S97(L("1T86<L("1A='1R
M:6)U=&5S*0H@("`@>PH@("`@("`@(&QI<W0H)'5R:2P@)&YA;64I(#T@)'1H
M:7,M/E]S<&QI=%5222@D=&%G*3L*"B`@("`@("`@)'1H:7,M/G-T87)T16QE
M;65N="@D=7)I+"`D;F%M92P@)&%T=')I8G5T97,I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&]P87%U92@D8GET97,I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3Y?<W5B4&%R<V5R(#T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/E]O
M=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3U!!455%*3L*
M("`@("`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?
M;W5T<'5T+"!C;W5N="@D8GET97,I*3L*("`@("`@("`@("`@)'1H:7,M/E]O
M=71P=70@+CT@)&)Y=&5S.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!C:&%R86-T97)S*"1C:&%R<RD*("`@('L*("`@("`@("`D8VAA<G,@/2!T
M<FEM*"1C:&%R<RD["@H@("`@("`@(&EF("AS=')L96XH)&-H87)S*2D@>PH@
M("`@("`@("`@("`O*B!792!D969I;FET96QY(&1O;B=T('=A;G0@86YY('=H
M:71E<W!A8V4N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W-U8E!A<G-E
M<B`]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`D:2`]("1T:&ES+3Y?<W1R
M:6YG5&%B;&4M/F=E="@D8VAA<G,I.PH@("`@("`@("`@("`@("`@:68@*"1I
M("$](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U
M="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?5"D["B`@("`@
M("`@("`@("`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES
M+3Y?;W5T<'5T+"`D:2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA834Q?5T)8
M34Q?1TQ/0D%,7U1/2T5.7U-44E])*3L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W)I=&53=')I;F<H)&-H87)S+"`D=&AI<RT^7V-H87)S970I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S=6)087)S97(M/F-H87)A8W1E<G,H)&-H87)S
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!?8VAA<F%C=&5R<R@D<&%R<V5R+"`D8VAA<G,I"B`@("!["B`@("`@("`@
M)'1H:7,M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!W<FET951A9R@D;F%M92P@)&%T=')S+"`D:&%S0V]N=&5N="P@)&-S*0H@
M("`@>PH@("`@("`@(&EF("@D871T<G,@(3T@;G5L;"`F)B`A8V]U;G0H)&%T
M=')S*2D@>PH@("`@("`@("`@("`D871T<G,@/2!N=6QL.PH@("`@("`@('T*
M"B`@("`@("`@)'0@/2`D=&AI<RT^7V1T9"T^=&]486=);G0H)&YA;64I.PH@
M("`@("`@(&EF("@D="`]/2`M,2D@>PH@("`@("`@("`@("`D:2`]("1T:&ES
M+3Y?<W1R:6YG5&%B;&4M/F=E="@D;F%M92D["B`@("`@("`@("`@(&EF("@D
M:2`]/2!N=6QL*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)&YA;64@+B`G(&ES(&YO="!F;W5N9"!I;B!3=')I;F<@5&%B
M;&4@;W(@1%1$)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!I9B`H)&%T=')S(#T](&YU;&P@)B8@(21H87-#;VYT96YT*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]7
M0EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3"D["B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)&%T=')S(#T](&YU;&P@)B8@)&AA<T-O;G1E;G0I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="
M6$U,7T=,3T)!3%]43TM%3E],251%4D%,7T$I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1A='1R<R`A/2!N=6QL("8F("1H87-#;VYT96YT*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]7
M0EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3%]#*3L*("`@("`@("`@("`@("`@
M('T@96QS96EF("@D871T<G,@(3T@;G5L;"`F)B`A)&AA<T-O;G1E;G0I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,7T%#*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("!834Q?5T)834PZ.FEN=%1O34)526YT
M,S(H)'1H:7,M/E]O=71P=70L("1I*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("@D871T<G,@/3T@;G5L;"`F)B`A
M)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<B@D="D["B`@("`@("`@("`@('T@96QS96EF("@D871T<G,@/3T@
M;G5L;"`F)B`D:&%S0V]N=&5N="D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]O=71P=70@+CT@8VAR*"1T('P@-C0I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&%T=')S("$](&YU;&P@)B8@)&AA<T-O;G1E;G0I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@D="!\(#$R."D["B`@("`@
M("`@("`@('T@96QS96EF("@D871T<G,@(3T@;G5L;"`F)B`A)&AA<T-O;G1E
M;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@D
M="!\(#$Y,BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@D871T<G,@(3T@;G5L;"`F)B!I<U]A<G)A>2@D871T<G,I("8F(&-O=6YT
M*"1A='1R<RD@/B`P("D@>PH@("`@("`@("`@("`D=&AI<RT^=W)I=&5!='1R
M:6)U=&5S*"1A='1R<RP@)&-S*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@=W)I=&5!='1R:6)U=&5S*"1A='1R<RP@)&-S*0H@("`@>PH@("`@
M("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@)'1H:7,M/G=R:71E071T<FEB=71E*"1N86UE+"`D=F%L=64L
M("1C<RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C
M:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%3D0I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('=R:71E071T<FEB=71E*"1N86UE+"`D=F%L=64L("1C<RD*("`@
M('L*("`@("`@("`D82`]("1T:&ES+3Y?9'1D+3YT;T%T=')I8G5T92@D;F%M
M92D["B`@("`@("`@:68@*"1A(#T]("TQ*2!["B`@("`@("`@("`@("1I(#T@
M)'1H:7,M/E]S=')I;F=486)L92T^9V5T*"1N86UE*3L*("`@("`@("`@("`@
M:68@*"1I(#T](&YU;&PI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D;F%M92`N("<@:7,@;F]T(&9O=6YD(&EN(%-T<FEN
M9R!486)L92!O<B!$5$0G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/
M0D%,7U1/2T5.7TQ)5$5204PI.PH@("`@("`@("`@("`@("`@6$U,7U="6$U,
M.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T<'5T+"`D:2D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U="`N/2`D83L*("`@("`@("!]"@H@("`@("`@("1I(#T@)'1H:7,M/E]S
M=')I;F=486)L92T^9V5T*"1N86UE*3L*("`@("`@("!I9B`H)&D@(3T@;G5L
M;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="
M6$U,7T=,3T)!3%]43TM%3E]35%)?5"D["B`@("`@("`@("`@(%A-3%]70EA-
M3#HZ:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U='!U="P@)&DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA8
M34Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E])*3L*("`@("`@("`@("`@)'1H
M:7,M/G=R:71E4W1R:6YG*"1V86QU92P@)&-S*3L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I+"`D;F%M92D*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/E]S=6)087)S97(@/3T@;G5L;"D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E]%3D0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?<W5B4&%R<V5R+3YE;F1%;&5M96YT*"1U<FDL("1N86UE*3L*("`@
M("`@("`@("`@)'1H:7,M/E]S=6)087)S97)3=&%C:RTM.PH*("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?<W5B4&%R<V5R4W1A8VL@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"
M04Q?5$]+14Y?3U!!455%*3L*"B`@("`@("`@("`@("`@("!834Q?5T)834PZ
M.FEN=%1O34)526YT,S(H)'1H:7,M/E]O=71P=70L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1T:&ES+3Y?<W5B
M4&%R<V5R+3YG971/=71P=70H*2DI.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]O=71P=70@+CT@)'1H:7,M/E]S=6)087)S97(M/F=E=$]U='!U="@I.PH*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R(#T@;G5L;#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?96YD
M16QE;65N="@D<&%R<V5R+"`D=&%G*0H@("`@>PH@("`@("`@(&QI<W0H)'5R
M:2P@)&YA;64I(#T@)'1H:7,M/E]S<&QI=%5222@D=&%G*3L*("`@("`@("`D
M=&AI<RT^96YD16QE;65N="@D=7)I+"`D;F%M92D["B`@("!]"@H@("`@9G5N
M8W1I;VX@8VAA;F=E8V]D97!A9V4H)'5R:2D*("`@('L*("`@("`@("`O+R!`
M=&]D;SH@=&AI<R!I<R!A(&AA8VLA"B`@("`@("`@:68@*"1T:&ES+3Y?9'1D
M+3YG971697)S:6]N*"D@/3T@,2`F)B`A<')E9U]M871C:"@G+S%<+C$D+R<L
M("1U<FDI*2!["B`@("`@("`@("`@("1U<FD@+CT@)S$N,2<["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^7V1T9"T^9V5T5F5R<VEO;B@I(#T](#`@
M)B8@(7!R96=?;6%T8V@H)R\Q7"XP)"\G+"`D=7)I*2D@>PH@("`@("`@("`@
M("`D=7)I("X]("<Q+C`G.PH@("`@("`@('T*"B`@("`@("`@)&-P(#T@)'1H
M:7,M/E]D=&0M/G1O0V]D95!A9V554DDH)'5R:2D["B`@("`@("`@:68@*'-T
M<FQE;B@D8W`I*2!["B`@("`@("`@("`@("1T:&ES+3Y?9'1D(#T@)B1T:&ES
M+3Y?9'1D36%N86=E<BT^9V5T26YS=&%N8V554DDH)'5R:2D["@H@("`@("`@
M("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]4
M3TM%3E]35TE40TA?4$%'12D["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<B@D8W`I.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G154DD@
M/2`D=7)I.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-U8E!A<G-E<B`]("9N97<@6$U,7U="6$U,7T5N8V]D97(H=')U92D["B`@
M("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R4W1A8VL@/2`Q.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($=E='1E<B!F;W(@<')O<&5R='D@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971/=71P=70H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V]U='!U=#L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971/=71P=713:7IE*"D*("`@('L*("`@("`@("!R971U<FX@
M<W1R;&5N*"1T:&ES+3Y?;W5T<'5T*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]D;V-S+P``````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W
M-0`P,38U-C8`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+V1O8W,O
M97AA;7!L97,O````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S<U`#`R,#0P-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]834PO=&5S=',O````````````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S4`,#$W,#`P`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]35D<N<&AP````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U,S(Q-@`Q,#0Q
M-S,V,C<W-0`P,3<P,3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%A-3%]35D<*("H*("H@5W)A<'!E
M<B!C;&%S<R!T:&%T('!R;W9I9&5S('-O;64@97AA;7!L97,@86YD(&$@9F5W
M(&-O;G9E;FEE;F-E"B`J(&UE=&AO9',N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+UA-3%]35D<O4U9'+G!H<"QV(#$N,3<N,3`N-"`R,#`V+S`Q+S`Q(#(Q
M.C(X.C0T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61R!["@H@
M("`@9G5N8W1I;VX@97AA;7!L92@I"B`@("!["B`@("`@("`@+R\@0W)E871E
M(&%N(&EN<W1A;F-E(&]F(%A-3%]35D=?1&]C=6UE;G0N($%L;"!O=&AE<B!O
M8FIE8W1S"B`@("`@("`@+R\@=VEL;"!B92!A9&1E9"!T;R!T:&ES(&EN<W1A
M;F-E(&9O<B!P<FEN=&EN9RX@4V5T('1H92!H96EG:'0*("`@("`@("`O+R!A
M;F0@=VED=&@@;V8@=&AE('9I97=P;W)T+@H@("`@("`@("1S=F<@/2`F;F5W
M(%A-3%]35D=?1&]C=6UE;G0H87)R87DH)W=I9'1H)R`]/B`T,#`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&5I9VAT
M)R`]/B`R,#`I*3L*"B`@("`@("`@+R\@0W)E871E(&%N(&EN<W1A;F-E(&]F
M(%A-3%]35D=?1W)O=7`N(%-E="!T:&4@<W1Y;&4L"B`@("`@("`@+R\@=')A
M;G-F;W)M<R!F;W(@8VAI;&0@;V)J96-T<RX*("`@("`@("`D9R`]("9N97<@
M6$U,7U-61U]'<F]U<"AA<G)A>2@G<W1Y;&4G(#T^("=S=')O:V4Z8FQA8VLG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N
M<V9O<FTG(#T^("=T<F%N<VQA=&4H,C`P(#$P,"DG*2D["@H@("`@("`@("\O
M($%D9"!A('!A<F5N="!T;R!T:&4@9R!I;G-T86YC92X*("`@("`@("`D9RT^
M861D4&%R96YT*"1S=F<I.PH*("`@("`@("`O+R!4:&4@<V%M92!R97-U;'1S
M(&-A;B!B92!A8V-O;7!L:7-H960@8GD@;6%K:6YG(&<@82!C:&EL9"!O9B!T
M:&4@<W9G+@H@("`@("`@("\O("1S=F<M/F%D9$-H:6QD*"1G*3L*"B`@("`@
M("`@+R\@0W)E871E(&%N9"!A;FEM871E(&$@8VER8VQE+@H@("`@("`@("1C
M:7)C;&4@/2`F;F5W(%A-3%]35D=?0VER8VQE*&%R<F%Y*"=C>"<@/3X@,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C
M>2<@/3X@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R)R`]/B`Q,#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("=S=')O:V4M=VED=&@Z,R<I
M*3L*("`@("`@("`D8VER8VQE+3YA9&1#:&EL9"AN97<@6$U,7U-61U]!;FEM
M871E*&%R<F%Y*"=A='1R:6)U=&5.86UE)R`]/B`G<B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T
M<FEB=71E5'EP92<@/3X@)UA-3"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9G)O;2<@/3X@,"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T;R<@/3X@-S4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9'5R)R`]/B`G,W,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V9I;&PG(#T^("=F<F5E>F4G*2DI.PH@("`@("`@("1C:7)C;&4M/F%D9$-H
M:6QD*&YE=R!834Q?4U9'7T%N:6UA=&4H87)R87DH)V%T=')I8G5T94YA;64G
M(#T^("=F:6QL)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A='1R:6)U=&54>7!E)R`]/B`G0U-3)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=F<F]M)R`]/B`G9W)E96XG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O)R`]/B`G<F5D
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D=7(G(#T^("<S<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9FEL;"<@/3X@)V9R
M965Z92<I*2D["@H@("`@("`@("\O($UA:V4@=&AE(&-I<F-L92!A(&-H:6QD
M(&]F(&<N"B`@("`@("`@)&<M/F%D9$-H:6QD*"1C:7)C;&4I.PH*("`@("`@
M("`O+R!#<F5A=&4@86YD(&%N:6UA=&4@<V]M92!T97AT+@H@("`@("`@("1T
M97AT(#T@)FYE=R!834Q?4U9'7U1E>'0H87)R87DH)W1E>'0G(#T^("=35D<@
M8VAA<G0A)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W@G(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=Y)R`]/B`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<W1Y;&4G(#T^("=F;VYT+7-I>F4Z,C`[=&5X="UA;F-H
M;W(Z;6ED9&QE.R<I*3L*("`@("`@("`D=&5X="T^861D0VAI;&0H;F5W(%A-
M3%]35D=?06YI;6%T92AA<G)A>2@G871T<FEB=71E3F%M92<@/3X@)V9O;G0M
M<VEZ92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V%T=')I8G5T951Y<&4G(#T^("=A=71O)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9G)O;2<@/3X@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=&\G(#T^(#(P+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D=7(G(#T^("<S
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V9I;&PG(#T^("=F<F5E>F4G*2DI.PH*("`@("`@("`O+R!-
M86ME('1H92!T97AT(&$@8VAI;&0@;V8@9RX*("`@("`@("`D9RT^861D0VAI
M;&0H)'1E>'0I.PH*("`@("`@("`O+R!396YD(&$@;65S<V%G92!T;R!T:&4@
M<W9G(&EN<W1A;F-E('1O('-T87)T('!R:6YT:6YG+@H@("`@("`@("1S=F<M
M/G!R:6YT16QE;65N="@I.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?16QE
M;65N=`H@*@H@*B!4:&ES(&ES('1H92!B87-E(&-L87-S(&9O<B!T:&4@9&EF
M9F5R96YT(%-61R!%;&5M96YT"B`J($]B:F5C=',N($5X=&5N9"!T:&ES(&-L
M87-S('1O(&-R96%T92!A(&YE=R!35D<@16QE;65N="X*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]%;&5M96YT('L*"B`@("!V
M87(@)%]E;&5M96YT<R`](&YU;&P["B`@("!V87(@)%]S='EL92`](&YU;&P[
M"B`@("!V87(@)%]T<F%N<V9O<FT@/2!N=6QL.PH@("`@=F%R("1?:60@/2!N
M=6QL.PH*("`@(&9U;F-T:6]N(%A-3%]35D=?16QE;65N="@D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P
M(#T^("1V*2!["B`@("`@("`@("`@("1P87)A;2`]("=?)R`N("1P.PH@("`@
M("`@("`@("`D=&AI<RT^)'!A<F%M(#T@)'8["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@36]S="!35D<@96QE;65N=',@8V%N(&-O;G1A:6X@
M8VAI;&0@96QE;65N=',N(%1H:7,@;65T:&]D(&-A;&QS"B`@("`@*B!T:&4@
M<')I;G1%;&5M96YT(&UE=&AO9"!O9B!A;GD@8VAI;&0@96QE;65N="!A9&1E
M9"!T;R!T:&ES"B`@("`@*B!O8FIE8W0@8GD@=7-E(&]F('1H92!A9&1#:&EL
M9"!M971H;V0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I
M"B`@("!["B`@("`@("`@+R\@3&]O<"!A;F0@8V%L;"X*("`@("`@("!I9B`H
M:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]E;&5M96YT<R!A<R`D8VAI;&0I('L*("`@("`@("`@
M("`@("`@("1C:&EL9"T^<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO9"!A
M9&1S(&%N(&]B:F5C="!R969E<F5N8V4@*&]R('9A;'5E+"!I9B`D8V]P>2!I
M<PH@("`@("H@=')U92D@=&\@=&AE(%]E;&5M96YT<R!A<G)A>2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D0VAI;&0H)B1E;&5M96YT+"`D8V]P>2`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@D8V]P>2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V5L96UE;G1S6UT@/2`F)&5L96UE;G0M/F-O<'DH*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F
M)&5L96UE;G0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI
M<R!M971H;V0@<V5N9',@82!M97-S86=E('1O('1H92!P87-S960@96QE;65N
M="!R97%U97-T:6YG('1O"B`@("`@*B!B92!A9&1E9"!A<R!A(&-H:6QD+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1087)E;G0H)B1P87)E;G0I"B`@("![
M"B`@("`@("`@:68@*&ES7W-U8F-L87-S7V]F*"1P87)E;G0L("=834Q?4U9'
M7T5L96UE;G0G*2D@>PH@("`@("`@("`@("`D<&%R96YT+3YA9&1#:&EL9"@D
M=&AI<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&-O<'DH*0H@
M("`@>PH@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H>F5N9%]V97)S:6]N
M*"DL("<R)RP@)SXG*2D@>PH@("`@("`@("`@("!R971U<FX@8VQO;F4H)'1H
M:7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1X;6Q?<W9G(#T@
M)'1H:7,["B`@("`@("`@("`@(')E='5R;B`D>&UL7W-V9SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<FEN="!E86-H(&]F('1H92!P87-S
M960@<&%R86UE=&5R<RP@:68@=&AE>2!A<F4@<V5T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P<FEN=%!A<F%M<R@I"B`@("!["B`@("`@("`@9F]R96%C:"`H
M9G5N8U]G971?87)G<R@I(&%S("1P87)A;2D@>PH@("`@("`@("`@("`D7W!A
M<F%M(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/B1?<&%R86TI*2!["B`@("`@("`@("`@("`@("!S=VET8V@@*"1P87)A
M;2D@>PH@("`@("`@("`@("`@("`@8V%S92`G9FEL=&5R)SH*("`@("`@("`@
M("`@("`@("`@("!E8VAO("<@9FEL=&5R/2)U<FPH(R<@+B`D=&AI<RT^)%]P
M87)A;2`N("<I(B<["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("!E8VAO
M("<@)R`N('-T<E]R97!L86-E*"=?)RP@)RTG+"`D<&%R86TI("X@)STB)R`N
M("1T:&ES+3XD7W!A<F%M("X@)R(G.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\O(%-E="!A;GD@;F%M960@871T<FEB=71E(&]F(&%N
M(&5L96UE;G0@=&\@82!V86QU92X*("`@(&9U;F-T:6]N('-E=%!A<F%M*"1P
M87)A;2P@)'9A;'5E*0H@("`@>PH@("`@("`@("1A='1R(#T@)U\G("X@)'!A
M<F%M.PH@("`@("`@("1T:&ES+3XD871T<B`]("1V86QU93L*("`@('T*"B`@
M("`O+R!'970@86YY(&YA;65D(&%T=')I8G5T92!O9B!A;B!E;&5M96YT+@H@
M("`@9G5N8W1I;VX@9V5T4&%R86TH)'!A<F%M*0H@("`@>PH@("`@("`@("1A
M='1R(#T@)U\G("X@)'!A<F%M.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M)&%T='(I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^)&%T='(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H@("`@?0H*("`@("\O(%!R:6YT(&]U="!T:&4@;V)J96-T(&9O<B!D
M96)U9V=I;F<N"B`@("!F=6YC=&EO;B!D96)U9R@I"B`@("!["B`@("`@("`@
M96-H;R`G/'!R93XG.R!V87)?9'5M<"@D=&AI<RD[(&5C:&\@)SPO<')E/B<[
M"B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]&<F%G;65N=`H@*@H@*B!`<&%C
M:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T9R86=M96YT(&5X=&5N
M9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]W:61T:#L*("`@('9A
M<B`D7VAE:6=H=#L*("`@('9A<B`D7W9I97=";W@["B`@("!V87(@)%]X.PH@
M("`@=F%R("1?>3L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@
M>PH@("`@("`@(&5C:&\@)SQS=F<G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A
M<F%M<R@G:60G+"`G=VED=&@G+"`G:&5I9VAT)RP@)W@G+"`G>2<L("=V:65W
M0F]X)RP@)W-T>6QE)RD["B`@("`@("`@96-H;R`G('AM;&YS/2)H='1P.B\O
M=W=W+G<S+F]R9R\R,#`P+W-V9R(@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N
M=S,N;W)G+S$Y.3DO>&QI;FLB/B<@+B`B7&XB.PH@("`@("`@('!A<F5N=#HZ
M<')I;G1%;&5M96YT*"D["B`@("`@("`@96-H;R`B/"]S=F<^7&XB.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&)U9F9E<D]B:F5C="@I"B`@("!["B`@("`@("`@
M;V)?<W1A<G0H*3L*("`@("`@("`D=&AI<RT^<')I;G1%;&5M96YT*"D["B`@
M("`@("`@)&]U='!U="`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@(&]B
M7V5N9%]C;&5A;B@I.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*
M?0H*+RHJ"B`J(%A-3%]35D=?1&]C=6UE;G0*("H*("H@5&AI<R!E>'1E;F1S
M('1H92!834Q?4U9'7T9R86=M96YT(&-L87-S+B!)="!W<F%P<R!T:&4@6$U,
M7U-61U]&<F%M96YT(&]U='!U=`H@*B!W:71H(&$@8V]N=&5N="!H96%D97(L
M('AM;"!D969I;FET:6]N(&%N9"!D;V-T>7!E+@H@*@H@*B!`<&%C:V%G92!8
M34Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T1O8W5M96YT(&5X=&5N9',@6$U,
M7U-61U]&<F%G;65N="!["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*
M("`@('L*("`@("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@:6UA9V4O<W9G
M*WAM;"<I.PH*("`@("`@("!P<FEN="@G/#]X;6P@=F5R<VEO;CTB,2XP(B!E
M;F-O9&EN9STB:7-O+3@X-3DM,2(_/B<N(EQN(BD["B`@("`@("`@<')I;G0H
M)SPA1$]#5%E012!S=F<@4%5"3$E#("(M+R]7,T,O+T141"!35D<@,2XP+R]%
M3B(*"2`@("`@("`@(FAT='`Z+R]W=W<N=S,N;W)G+U12+S(P,#$O4D5#+5-6
M1RTR,#`Q,#DP-"]$5$0O<W9G,3`N9'1D(CXG("X@(EQN(BD["@H@("`@("`@
M('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("!]"@I]"@HO*BH*("H@6$U,
M7U-61U]'<F]U<`H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!8
M34Q?4U9'7T=R;W5P(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!F
M=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQG
M)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W-T>6QE)RP@
M)W1R86YS9F]R;2<L("=F:6QT97(G*3L*("`@("`@("!P<FEN="@B/EQN(BD[
M"B`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("!P<FEN
M="@B/"]G/EQN(BD["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]497AT<&%T
M:`H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7U1E
M>'1P871H(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]T
M97AT.PH@("`@=F%R("1?>#L*("`@('9A<B`D7WD["B`@("!V87(@)%]D>#L*
M("`@('9A<B`D7V1Y.PH@("`@=F%R("1?<F]T871E.PH@("`@=F%R("1?=&5X
M=$QE;F=T:#L*("`@('9A<B`D7VQE;F=T:$%D:G5S=#L*("`@('9A<B`D7V-H
M87)S970["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"1E;&5M96YT(#T@
M)W1E>'1P871H)RD*("`@('L*("`@("`@("!E8VAO("<\)R`N("1E;&5M96YT
M.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G>"<L("=Y)RP@
M)V1X)RP@)V1Y)RP@)W)O=&%T92<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T97AT3&5N9W1H)RP@)VQE;F=T:$%D:G5S="<L("=S='EL92<L("=T
M<F%N<V9O<FTG*3L*("`@("`@("!E8VAO("<^)SL*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]C:&%R<V5T*2D@>PH@("`@("`@("`@("!E8VAO($!H=&UL
M<W!E8VEA;&-H87)S*"1T:&ES+3Y?=&5X="P@14Y47T-/35!!5"P@)'1H:7,M
M/E]C:&%R<V5T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/E]T97AT*3L*("`@("`@("!]"B`@
M("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("!E8VAO("(\
M+R1E;&5M96YT/EQN(CL*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D
M>"P@)'DL("1T97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>"`]("1X.PH@
M("`@("`@("1T:&ES+3Y?>2`]("1Y.PH@("`@("`@("1T:&ES+3Y?=&5X="`]
M("1T97AT.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?5&5X=`H@*@H@*B!`
M<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7U1E>'0@97AT96YD
M<R!834Q?4U9'7U1E>'1P871H('L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE
M;G0H*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"=T97AT
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'@L("1Y+"`D=&5X
M="D*("`@('L*("`@("`@("`D=&AI<RT^7W@@/2`D>#L*("`@("`@("`D=&AI
M<RT^7WD@/2`D>3L*("`@("`@("`D=&AI<RT^7W1E>'0@/2`D=&5X=#L*("`@
M('T*"GT*"B\J*@H@*B!834Q?4U9'7U1S<&%N"B`J"B`J($!P86-K86=E(%A-
M3%]35D<*("HO"F-L87-S(%A-3%]35D=?5'-P86X@97AT96YD<R!834Q?4U9'
M7T5L96UE;G0@>PH*("`@('9A<B`D7W1E>'0["B`@("!V87(@)%]X.PH@("`@
M=F%R("1?>3L*("`@('9A<B`D7V1X.PH@("`@=F%R("1?9'D["B`@("!V87(@
M)%]R;W1A=&4["B`@("!V87(@)%]T97AT3&5N9W1H.PH@("`@=F%R("1?;&5N
M9W1H061J=7-T.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("![
M"B`@("`@("`@96-H;R`G/'1S<&%N)SL*("`@("`@("`D=&AI<RT^<')I;G10
M87)A;7,H)VED)RP@)W@G+"`G>2<L("=D>"<L("=D>2<L("=R;W1A=&4G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5X=$QE;F=T:"<L("=L96YG
M=&A!9&IU<W0G+"`G<W1Y;&4G+"`G=')A;G-F;W)M)RD["B`@("`@("`@96-H
M;R`G/B<@+B`D=&AI<RT^7W1E>'0["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%
M;&5M96YT*"D["B`@("`@("`@?0H@("`@("`@(&5C:&\@(CPO='-P86X^7&XB
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1X+"`D>2P@)'1E>'0I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]X(#T@)'@["B`@("`@("`@)'1H:7,M
M/E]Y(#T@)'D["B`@("`@("`@)'1H:7,M/E]T97AT("`]("1T97AT.PH@("`@
M?0H*?0H*+RHJ"B`J(%A-3%]35D=?0VER8VQE"B`J"B`J($!P86-K86=E(%A-
M3%]35D<*("HO"F-L87-S(%A-3%]35D=?0VER8VQE(&5X=&5N9',@6$U,7U-6
M1U]%;&5M96YT('L*"B`@("!V87(@)%]C>#L*("`@('9A<B`D7V-Y.PH@("`@
M=F%R("1?<CL*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@
M("`@("`@(&5C:&\@)SQC:7)C;&4G.PH*("`@("`@("`D=&AI<RT^<')I;G10
M87)A;7,H)VED)RP@)V-X)RP@)V-Y)RP@)W(G+"`G<W1Y;&4G+"`G=')A;G-F
M;W)M)RD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I
M*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@
M96YD('1A9RX*("`@("`@("`@("`@96-H;R`B/EQN(CL*("`@("`@("`@("`@
M<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@96-H;R`B/"]C
M:7)C;&4^7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%!R
M:6YT('-H;W)T('1A9RX*("`@("`@("`@("`@96-H;R`B+SY<;B(["B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1C>"P@)&-Y+"`D
M<BD*("`@('L*("`@("`@("`D=&AI<RT^7V-X(#T@)&-X.PH@("`@("`@("1T
M:&ES+3Y?8WD@/2`D8WD["B`@("`@("`@)'1H:7,M/E]R("`]("1R.PH@("`@
M?0H*?0H*+RHJ"B`J(%A-3%]35D=?3&EN90H@*@H@*B!`<&%C:V%G92!834Q?
M4U9'"B`J+PIC;&%S<R!834Q?4U9'7TQI;F4@97AT96YD<R!834Q?4U9'7T5L
M96UE;G0@>PH*("`@('9A<B`D7W@Q.PH@("`@=F%R("1?>3$["B`@("!V87(@
M)%]X,CL*("`@('9A<B`D7WDR.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N
M="@I"B`@("!["B`@("`@("`@96-H;R`G/&QI;F4G.PH@("`@("`@("1T:&ES
M+3YP<FEN=%!A<F%M<R@G:60G+"`G>#$G+"`G>3$G+"`G>#(G+"`G>3(G+"`G
M<W1Y;&4G*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT
M<RDI('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N
M9"!E;F0@=&%G+@H@("`@("`@("`@("!P<FEN="@B/EQN(BD["B`@("`@("`@
M("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@('!R:6YT
M*"(\+VQI;F4^7&XB*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!0<FEN="!S:&]R="!T86<N"B`@("`@("`@("`@('!R:6YT*"(O/EQN(BD[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1X,2P@
M)'DQ+"`D>#(L("1Y,BD*("`@('L*("`@("`@("`D=&AI<RT^7W@Q(#T@)'@Q
M.PH@("`@("`@("1T:&ES+3Y?>3$@/2`D>3$["B`@("`@("`@)'1H:7,M/E]X
M,B`@/2`D>#(["B`@("`@("`@)'1H:7,M/E]Y,B`@/2`D>3(["B`@("!]"@I]
M"@HO*BH*("H@6$U,7U-61U]296-T"B`J"B`J($!P86-K86=E(%A-3%]35D<*
M("HO"F-L87-S(%A-3%]35D=?4F5C="!E>'1E;F1S(%A-3%]35D=?16QE;65N
M="!["@H@("`@=F%R("1?>#L*("`@('9A<B`D7WD["B`@("!V87(@)%]W:61T
M:#L*("`@('9A<B`D7VAE:6=H=#L*("`@('9A<B`D7W)X.PH@("`@=F%R("1?
M<GD["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@
M("!E8VAO("<\<F5C="<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I
M9"<L("=X)RP@)WDG+"`G=VED=&@G+"`G:&5I9VAT)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W)X)RP@)W)Y)RP@)W-T>6QE)RD["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@
M("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@
M("`@("`@<')I;G0H(CY<;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT
M16QE;65N="@I.PH@("`@("`@("`@("!P<FEN="@B/"]R96-T/EQN(BD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@4')I;G0@<VAO<G0@=&%G
M+@H@("`@("`@("`@("!P<FEN="@B+SY<;B(I.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!S9713:&%P92@D>"P@)'DL("1W:61T:"P@)&AE:6=H
M="D*("`@('L*("`@("`@("`D=&AI<RT^7W@@/2`D>#L*("`@("`@("`D=&AI
M<RT^7WD@/2`D>3L*("`@("`@("`D=&AI<RT^7W=I9'1H("`]("1W:61T:#L*
M("`@("`@("`D=&AI<RT^7VAE:6=H="`@/2`D:&5I9VAT.PH@("`@?0H*?0H*
M+RHJ"B`J(%A-3%]35D=?16QL:7!S90H@*@H@*B!`<&%C:V%G92!834Q?4U9'
M"B`J+PIC;&%S<R!834Q?4U9'7T5L;&EP<V4@97AT96YD<R!834Q?4U9'7T5L
M96UE;G0@>PH*("`@('9A<B`D7V-X.PH@("`@=F%R("1?8WD["B`@("!V87(@
M)%]R>#L*("`@('9A<B`D7W)Y.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N
M="@I"B`@("!["B`@("`@("`@96-H;R`G/&5L;&EP<V4G.PH@("`@("`@("1T
M:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G8W@G+"`G8WDG+"`G<G@G+"`G<GDG
M+"`G<W1Y;&4G+"`G=')A;G-F;W)M)RD["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H
M:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@("`@<')I;G0H
M(CY<;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@
M("`@("`@("`@("!P<FEN="@B/"]E;&QI<'-E/EQN(BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@
M("`@("!P<FEN="@B("\^7&XB*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T4VAA<&4H)&-X+"`D8WDL("1R>"P@)')Y*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?8W@@/2`D8W@["B`@("`@("`@)'1H:7,M/E]C>2`]("1C
M>3L*("`@("`@("`D=&AI<RT^7W)X("`]("1R>#L*("`@("`@("`D=&AI<RT^
M7W)Y("`]("1R>3L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U!O;'EL:6YE
M"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?4&]L
M>6QI;F4@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W!O
M:6YT<SL*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@
M("`@(&5C:&\@)SQP;VQY;&EN92<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R
M86US*"=I9"<L("=P;VEN=',G+"`G<W1Y;&4G+"`G=')A;G-F;W)M)RD["@H@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@
M("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N
M"B`@("`@("`@("`@('!R:6YT*"(^7&XB*3L*("`@("`@("`@("`@<&%R96YT
M.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@<')I;G0H(CPO<&]L>6QI
M;F4^7&XB*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!0<FEN
M="!S:&]R="!T86<N"B`@("`@("`@("`@('!R:6YT*"(O/EQN(BD["B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1P;VEN=',I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]P;VEN=',@/2`D<&]I;G1S.PH@("`@?0H*
M?0H*+RHJ"B`J(%A-3%]35D=?4&]L>6=O;@H@*@H@*B!`<&%C:V%G92!834Q?
M4U9'"B`J+PIC;&%S<R!834Q?4U9'7U!O;'EG;VX@97AT96YD<R!834Q?4U9'
M7T5L96UE;G0@>PH*("`@('9A<B`D7W!O:6YT<SL*"B`@("!F=6YC=&EO;B!P
M<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQP;VQY9V]N)SL*
M("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W!O:6YT<R<L("=S
M='EL92<L("=T<F%N<V9O<FTG*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H
M:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R
M96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!P<FEN="@B/EQN
M(BD["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@
M("`@("`@('!R:6YT*"(\+W!O;'EG;VX^7&XB*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O+R!0<FEN="!S:&]R="!T86<N"B`@("`@("`@("`@
M('!R:6YT*"(O/EQN(BD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M('-E=%-H87!E*"1P;VEN=',I"B`@("!["B`@("`@("`@)'1H:7,M/E]P;VEN
M=',@/2`D<&]I;G1S.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?4&%T:`H@
M*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7U!A=&@@
M97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7V0["@H@("`@
M9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\
M<&%T:"<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=D)RP@
M)W-T>6QE)RP@)W1R86YS9F]R;2<I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL
M9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@("`@("`@('!R:6YT*"(^
M7&XB*3L*("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@
M("`@("`@("`@<')I;G0H(CPO<&%T:#Y<;B(I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O(%!R:6YT('-H;W)T('1A9RX*("`@("`@("`@("`@
M<')I;G0H(B\^7&XB*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T4VAA<&4H)&0I"B`@("!["B`@("`@("`@)'1H:7,M/E]D(#T@)&0["B`@
M("!]"@I]"@HO*BH*("H@6$U,7U-61U]);6%G90H@*@H@*B!`<&%C:V%G92!8
M34Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7TEM86=E(&5X=&5N9',@6$U,7U-6
M1U]%;&5M96YT('L*"B`@("!V87(@)%]X.PH@("`@=F%R("1?>3L*("`@('9A
M<B`D7W=I9'1H.PH@("`@=F%R("1?:&5I9VAT.PH@("`@=F%R("1?:')E9CL*
M"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C
M:&\@)SQI;6%G92<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L
M("=X)RP@)WDG+"`G=VED=&@G+"`G:&5I9VAT)RP@)W-T>6QE)RD["B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^7VAR968I*2!["B`@("`@("`@("`@(&5C
M:&\@)R!X;&EN:SIH<F5F/2(G("X@)'1H:7,M/E]H<F5F("X@)R(G.PH@("`@
M("`@('T*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI
M('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E
M;F0@=&%G+@H@("`@("`@("`@("!E8VAO("(^7&XB.PH@("`@("`@("`@("!P
M87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@("`@("!E8VAO("(\+VEM
M86=E/EQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!0<FEN
M="!S:&]R="!T86<N"B`@("`@("`@("`@(&5C:&\@(B`O/EQN(CL*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'@L("1Y+"`D=VED
M=&@L("1H96EG:'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]X(#T@)'@["B`@
M("`@("`@)'1H:7,M/E]Y(#T@)'D["B`@("`@("`@)'1H:7,M/E]W:61T:"`@
M/2`D=VED=&@["B`@("`@("`@)'1H:7,M/E]H96EG:'0@(#T@)&AE:6=H=#L*
M("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T%N:6UA=&4*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]!;FEM871E(&5X=&5N9',@
M6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]A='1R:6)U=&5.86UE.PH@
M("`@=F%R("1?871T<FEB=71E5'EP93L*("`@('9A<B`D7V9R;VT["B`@("!V
M87(@)%]T;SL*("`@('9A<B`D7V)E9VEN.PH@("`@=F%R("1?9'5R.PH@("`@
M=F%R("1?9FEL;#L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@
M>PH@("`@("`@(&5C:&\@)SQA;FEM871E)SL*("`@("`@("`D=&AI<RT^<')I
M;G1087)A;7,H)VED)RP@)V%T=')I8G5T94YA;64G+"`G871T<FEB=71E5'EP
M92<L("=F<F]M)RP@)W1O)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V)E9VEN)RP@)V1U<B<L("=F:6QL)RD["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H
M:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@("`@96-H;R`B
M/EQN(CL*("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@
M("`@("`@("`@96-H;R`B/"]A;FEM871E/EQN(CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!E8VAO("(@+SY<;B(["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N('-E=%-H87!E*"1A='1R:6)U=&5.86UE+"`D871T<FEB
M=71E5'EP92`]("<G+"`D9G)O;2`]("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@)'1O(#T@)R<L("1B96=I;B`]("<G+"`D9'5R(#T@)R<L("1F:6QL(#T@
M)R<I"B`@("!["B`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5.86UE(#T@)&%T
M=')I8G5T94YA;64["B`@("`@("`@)'1H:7,M/E]A='1R:6)U=&54>7!E(#T@
M)&%T=')I8G5T951Y<&4["B`@("`@("`@)'1H:7,M/E]F<F]M("`]("1F<F]M
M.PH@("`@("`@("1T:&ES+3Y?=&\@/2`D=&\["B`@("`@("`@)'1H:7,M/E]B
M96=I;B`]("1B96=I;CL*("`@("`@("`D=&AI<RT^7V1U<B`]("1D=7(["B`@
M("`@("`@)'1H:7,M/E]F:6QL(#T@)&9I;&P["B`@("!]"@I]"@HO*BH*("H@
M6$U,7U-61U]&:6QT97(*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA
M<W,@6$U,7U-61U]&:6QT97(@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*
M("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H
M;R`G/&9I;'1E<B<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<I
M.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@
M("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T
M86<N"B`@("`@("`@("`@(&5C:&\@(CY<;B(["B`@("`@("`@("`@('!A<F5N
M=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@(&5C:&\@(CPO9FEL=&5R
M/EQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("(@+SY<
M;B(["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&%D9%!R:6UI=&EV
M92@D<')I;6ET:79E+"`D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3YA
M9&1#:&EL9"AN97<@6$U,7U-61U]&:6QT97)0<FEM:71I=F4H)'!R:6UI=&EV
M92P@)'!A<F%M<RDI.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?1FEL=&5R
M4')I;6ET:79E"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-
M3%]35D=?1FEL=&5R4')I;6ET:79E(&5X=&5N9',@6$U,7U-61U]%;&5M96YT
M('L*"B`@("!V87(@)%]P<FEM:71I=F5S(#T@87)R87DH)T)L96YD)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G0V]L;W)-871R:7@G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=#;VUP;VYE;G14<F%N<V9E<B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T-O;7!O<VET92<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)T-O;G9O;'9E36%T<FEX)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1&EF9G5S94QI9VAT:6YG
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1&ES<&QA8V5M96YT
M36%P)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1FQO;V0G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("='875S<VEA;D)L=7(G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=);6%G92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)TUE<F=E)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G36]R<&AO;&]G>2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)T]F9G-E="<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)U-P96-U;&%R3&EG:'1I;F<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=4:6QE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G5'5R8G5L96YC92<I.PH*("`@('9A<B`D7W!R:6UI=&EV93L*"B`@("!V
M87(@)%]I;CL*("`@('9A<B`D7VEN,CL*("`@('9A<B`D7W)E<W5L=#L*("`@
M('9A<B`D7W@["B`@("!V87(@)%]Y.PH@("`@=F%R("1?9'@["B`@("!V87(@
M)%]D>3L*("`@('9A<B`D7W=I9'1H.PH@("`@=F%R("1?:&5I9VAT.PH@("`@
M=F%R("1?;6]D93L*("`@('9A<B`D7W1Y<&4["B`@("!V87(@)%]V86QU97,[
M"B`@("!V87(@)%]O<&5R871O<CL*("`@('9A<B`D7VLQ.PH@("`@=F%R("1?
M:S(["B`@("!V87(@)%]K,SL*("`@('9A<B`D7VLT.PH@("`@=F%R("1?<W5R
M9F%C95-C86QE.PH@("`@=F%R("1?9&EF9G5S94-O;G-T86YT.PH@("`@=F%R
M("1?:V5R;F5L56YI=$QE;F=T:#L*("`@('9A<B`D7V9L;V]R7V-O;&]R.PH@
M("`@=F%R("1?9FQO;V1?;W!A8VET>3L*"B`@("!F=6YC=&EO;B!834Q?4U9'
M7T9I;'1E<E!R:6UI=&EV92@D<')I;6ET:79E+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!P87)E;G0Z.EA-3%]35D=?16QE;65N="@D<&%R
M86US*3L*("`@("`@("`D=&AI<RT^7W!R:6UI=&EV92`]("1P<FEM:71I=F4[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@
M("`@("`D;F%M92`]("=F92<@+B`D=&AI<RT^7W!R:6UI=&EV93L*("`@("`@
M("!E8VAO("<\)R`N("1N86UE.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M
M<R@G:60G+"`G>"<L("=Y)RP@)V1X)RP@)V1Y)RP@)W=I9'1H)RP@)VAE:6=H
M="<L("=I;B<L("=I;C(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F5S=6QT)RP@)VUO9&4G+"`G='EP92<L("=V86QU97,G+"`G;W!E<F%T;W(G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G:S$G+"`G:S(G+"`G:S,G
M+"`G:S0G+"`G<W5R9F%C95-C86QE)RP@)W-T9$1E=FEA=&EO;B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=D:69F=7-E0V]N<W1A;G0G+"`G:V5R
M;F5L56YI=$QE;F=T:"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=F
M;&]O9%]C;VQO<B<L("=F;&]O9%]O<&%C:71Y)RD["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O(%!R
M:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@("`@
M96-H;R`B/EQN(CL*("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H
M*3L*("`@("`@("`@("`@96-H;R`G/"\G("X@)&YA;64@+B`G/B<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`G+SXG.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($9O<B!F94UE<F=E(&5L96UE;G1S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1-97)G94YO9&4H)&EN*0H@("`@>PH@
M("`@("`@("1T:&ES+3YA9&1#:&EL9"AN97<@6$U,7U-61U]&:6QT97)-97)G
M94YO9&4H87)R87DH)VEN)R`]/B`D:6XI*2D["B`@("!]"@I]"@HO*BH*("H@
M6$U,7U-61U]&:6QT97)-97)G94YO9&4*("H*("H@0'!A8VMA9V4@6$U,7U-6
M1PH@*B\*8VQA<W,@6$U,7U-61U]&:6QT97)-97)G94YO9&4@97AT96YD<R!8
M34Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7VEN.PH*("`@(&9U;F-T:6]N
M('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/&9E365R9V5.
M;V1E)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VEN)RD["B`@("`@
M("`@96-H;R`G+SXG.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?57-E"B`J
M"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?57-E(&5X
M=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]S>6UB;VP["@H@
M("`@9G5N8W1I;VX@6$U,7U-61U]5<V4H)'-Y;6)O;"P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@<&%R96YT.CI834Q?4U9'7T5L96UE;G0H
M)'!A<F%M<RD["B`@("`@("`@)'1H:7,M/E]S>6UB;VP@/2`D<WEM8F]L.PH@
M("`@?0H*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@
M("`@96-H;R`G/'5S92!X;&EN:SIH<F5F/2(C)R`N("1T:&ES+3Y?<WEM8F]L
M("X@)R(O/B<["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]$969S"B`J"B`J
M($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?1&5F<R!E>'1E
M;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M
M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\9&5F<R<["B`@("`@("`@)'1H
M:7,M/G!R:6YT4&%R86US*"=I9"<L("=S='EL92<L("=T<F%N<V9O<FTG*3L*
M("`@("`@("!E8VAO("(^7&XB.PH@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M
M96YT*"D["B`@("`@("`@96-H;R`B/"]D969S/EQN(CL*("`@('T*"GT*"B\J
M*@H@*B!834Q?4U9'7TUA<FME<@H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J
M+PIC;&%S<R!834Q?4U9'7TUA<FME<B!E>'1E;F1S(%A-3%]35D=?16QE;65N
M="!["@H@("`@=F%R("1?<F5F6#L*("`@('9A<B`D7W)E9ED["B`@("!V87(@
M)%]M87)K97)5;FET<SL*("`@('9A<B`D7VUA<FME<E=I9'1H.PH@("`@=F%R
M("1?;6%R:V5R2&5I9VAT.PH@("`@=F%R("1?;W)I96YT.PH*("`@(&9U;F-T
M:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/&UA<FME
M<B<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=R9698)RP@
M)W)E9EDG+"`G;6%R:V5R56YI=',G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;6%R:V5R5VED=&@G+"`G;6%R:V5R2&5I9VAT)RP@)V]R:65N="<I
M.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>R`O
M+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@("`@
M("`@('!R:6YT*"(^7&XB*3L*("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L
M96UE;G0H*3L*("`@("`@("`@("`@<')I;G0H(CPO;6%R:V5R/EQN(BD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0H(B\^7&XB*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)')E9E@@/2`G
M)RP@)')E9ED@/2`G)RP@)&UA<FME<E5N:71S(#T@)R<L"B`@("`@("`@("`@
M("`@("`@("`@("`D;6%R:V5R5VED=&@@/2`G)RP@)&UA<FME<DAE:6=H="`]
M("<G+"`D;W)I96YT(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/E]R9698
M(#T@)')E9E@["B`@("`@("`@)'1H:7,M/E]R9699("`]("1R9699.PH@("`@
M("`@("1T:&ES+3Y?;6%R:V5R56YI=',@/2`D;6%R:V5R56YI=',["B`@("`@
M("`@)'1H:7,M/E]M87)K97)7:61T:"`]("1M87)K97)7:61T:#L*("`@("`@
M("`D=&AI<RT^7VUA<FME<DAE:6=H="`]("1M87)K97)(96EG:'0["B`@("`@
M("`@)'1H:7,M/E]O<FEE;G0@/2`D;W)I96YT.PH@("`@?0H*?0H*+RHJ"B`J
M(%A-3%]35D=?5&ET;&4*("H*("H@0'!A8VMA9V4@6$U,7U-61PHJ+PIC;&%S
M<R!834Q?4U9'7U1I=&QE(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@
M("!V87(@)%]T:71L93L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@
M("`@>PH@("`@("`@(&5C:&\@)SQT:71L92<["B`@("`@("`@)'1H:7,M/G!R
M:6YT4&%R86US*"=I9"<L("=S='EL92<I.PH@("`@("`@('!R:6YT*"(^7&XB
M*3L*("`@("`@("!P<FEN="@D=&AI<RT^7W1I=&QE*3L*("`@("`@("!P87)E
M;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@('!R:6YT*"(\+W1I=&QE/EQN
M(BD["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]$97-C"B`J"B`J($!P86-K
M86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?1&5S8R!E>'1E;F1S(%A-
M3%]35D=?16QE;65N="!["@H@("`@=F%R("1?9&5S8SL*"B`@("!F=6YC=&EO
M;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQD97-C)SL*
M("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W-T>6QE)RD["B`@
M("`@("`@96-H;R`G/B<@+B`D=&AI<RT^7V1E<V,["B`@("`@("`@<&%R96YT
M.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("!E8VAO("(\+V1E<V,^7&XB.PH@
M("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?5')E9@H@*@H@*B!`<&%C:V%G92!8
M34Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7U1R968@97AT96YD<R!834Q?4U9'
M7T5L96UE;G0@>PH*("`@('9A<B`D7W1E>'0["B`@("!V87(@)%]X.PH@("`@
M=F%R("1?>3L*("`@('9A<B`D7V1X.PH@("`@=F%R("1?9'D["B`@("!V87(@
M)%]R;W1A=&4["B`@("!V87(@)%]T97AT3&5N9W1H.PH@("`@=F%R("1?;&5N
M9W1H061J=7-T.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("![
M"B`@("`@("`@96-H;R`G/'1R968G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A
M<F%M<R@G:60G+"`G>"<L("=Y)RP@)V1X)RP@)V1Y)RP@)W)O=&%T92<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T97AT3&5N9W1H)RP@)VQE;F=T
M:$%D:G5S="<L("=S='EL92<I.PH@("`@("`@(&5C:&\@)SXG("X@)'1H:7,M
M/E]T97AT.PH@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@
M("`@96-H;R`B/"]T<F5F/EQN(CL*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"YP:'``````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C(P-@`Q,#0Q
M-S,V,C<W-0`P,3<R,S<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*@H@*B!#;VYS=&%N=',@87)E(&9R;VT@
M0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I
M;VX*("H@,2XS+"`R-2!*=6QY(#(P,#$@9F]U;F0@870@:'1T<#HO+W=W=RYW
M87!F;W)U;2YO<F<*("HO"@HO*BH*("H@1G)O;2`W+C$@1VQO8F%L(%1O:V5N
M<RX*("HO"@ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U=)5$-(
M7U!!1T4G+"`P*3L@("\O(#!X,#`*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,
M7U1/2T5.7T5.1"<L(#$I.R`@("`@("`@("`O+R`P>#`Q"F1E9FEN92@G6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]%3E1)5%DG+"`R*3L@("`@("`@+R\@,'@P
M,@ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U127TDG+"`S*3L@
M("`@("`@("\O(#!X,#,*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.
M7TQ)5$5204PG+"`T*3L@("`@("`O+R`P>#`T"@ID969I;F4H)UA-3%]70EA-
M3%]'3$]"04Q?5$]+14Y?15A47TE?,"<L(#8T*3L@("`@("\O(#!X-#`*9&5F
M:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S$G+"`V-2D[("`@
M("`O+R`P>#0Q"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?
M25\R)RP@-C8I.R`@("`@+R\@,'@T,@ID969I;F4H)UA-3%]70EA-3%]'3$]"
M04Q?5$]+14Y?4$DG+"`V-RD[("`@("`@("`@("\O(#!X-#,*9&5F:6YE*"=8
M34Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204Q?0R<L(#8X*3L@("`O+R`P
M>#0T"@ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,"<L
M(#$R."D[("`@("\O(#!X.#`*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/
M2T5.7T585%]47S$G+"`Q,CDI.R`@("`O+R`P>#@Q"F1E9FEN92@G6$U,7U="
M6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\R)RP@,3,P*3L@("`@+R\@,'@X,@ID
M969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U127U0G+"`Q,S$I.R`@
M("`@("\O(#!X.#,*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)
M5$5204Q?02<L(#$S,BD[("`O+R`P>#@T"@ID969I;F4H)UA-3%]70EA-3%]'
M3$]"04Q?5$]+14Y?15A47S`G+"`Q.3(I.R`@("`@("\O(#!X0S`*9&5F:6YE
M*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%\Q)RP@,3DS*3L@("`@("`O
M+R`P>$,Q"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,B<L
M(#$Y-"D[("`@("`@+R\@,'A#,@ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?3U!!455%)RP@,3DU*3L@("`@("\O(#!X0S,*9&5F:6YE*"=834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204Q?04,G+"`Q.38I.R`O+R`P>$,T
M"@HO*BH*("H@3F]T('-U<F4@=VAE<F4@9&5F:6YE9"X*("H@041$($-(05!4
M15(*("HO"F1E9FEN92@G1%!)7T141%]734Q?,5\P)RP@)RTO+U=!4$9/4E5-
M+R]$5$0@5TU,(#$N,"\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7U=405\Q7S`G
M+"`G+2\O5T%01D]254TO+T141"!75$$@,2XP+R]%3B<I.PID969I;F4H)T10
M25]$5$1?5TU,7S%?,2<L("<M+R]705!&3U)532\O1%1$(%=-3"`Q+C$O+T5.
M)RD["F1E9FEN92@G1%!)7T141%]325\Q7S$G+"`G+2\O5T%01D]254TO+T14
M1"!322`Q+C$O+T5.)RD["F1E9FEN92@G1%!)7T141%]33%\Q7S`G+"`G+2\O
M5T%01D]254TO+T141"!33"`Q+C`O+T5.)RD["F1E9FEN92@G1%!)7T141%]#
M3U\Q7S`G+"`G+2\O5T%01D]254TO+T141"!#3R`Q+C`O+T5.)RD["F1E9FEN
M92@G1%!)7T141%]#2$%.3D5,7S%?,2<L("<M+R]705!&3U)532\O1%1$($-(
M04Y.14P@,2XQ+R]%3B<I.PID969I;F4H)T1025]$5$1?5TU,7S%?,B<L("<M
M+R]705!&3U)532\O1%1$(%=-3"`Q+C(O+T5.)RD["F1E9FEN92@G1%!)7T14
M1%]734Q?,5\S)RP@)RTO+U=!4$9/4E5-+R]$5$0@5TU,(#$N,R\O14XG*3L*
M9&5F:6YE*"=$4$E?1%1$7U!23U9?,5\P)RP@)RTO+U=!4$9/4E5-+R]$5$0@
M4%)/5B`Q+C`O+T5.)RD["F1E9FEN92@G1%!)7T141%]75$%?5TU,7S%?,B<L
M("<M+R]705!&3U)532\O1%1$(%=402U734P@,2XR+R]%3B<I.PID969I;F4H
M)T1025]$5$1?0TA!3DY%3%\Q7S(G+"`G+2\O5T%01D]254TO+T141"!#2$%.
M3D5,(#$N,B\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7U-93D--3%\Q7S`G+"`G
M+2\O4UE.0TU,+R]$5$0@4WEN8TU,(#$N,"\O14XG*3L*9&5F:6YE*"=$4$E?
M1%1$7T1%5DE.1E\Q7S`G+"`G+2\O4UE.0TU,+R]$5$0@1&5V26YF(#$N,"\O
M14XG*3L*9&5F:6YE*"=$4$E?1%1$7U-93D--3%\Q7S$G+"`G+2\O4UE.0TU,
M+R]$5$0@4WEN8TU,(#$N,2\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7T1%5DE.
M1E\Q7S$G+"`G+2\O4UE.0TU,+R]$5$0@1&5V26YF(#$N,2\O14XG*3L*"B\J
M*@H@*B!/;FQY(&1E9F%U;'0@8VAA<F%C=&5R(&5N8V]D:6YG<R!F<F]M($HR
M4T4@87)E(&-U<G)E;G1L>2!S=7!P;W)T960N"B`J+PID969I;F4H)T-(05)3
M151?55-?05-#24DG+"`G55,M05-#24DG*3L*9&5F:6YE*"=#2$%24T547TE3
M3U\X.#4Y7S$G+"`G25-/+3@X-3DM,2<I.PID969I;F4H)T-(05)3151?551&
M7S@G+"`G551&+3@G*3L*9&5F:6YE*"=#2$%24T547U541E\Q-D)%)RP@)U54
M1BTQ-D)%)RD["F1E9FEN92@G0TA!4E-%5%]55$9?,39,12<L("=55$8M,39,
M12<I.PID969I;F4H)T-(05)3151?551&7S$V)RP@)U541BTQ-B<I.PH*+RHJ
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS
M0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]834Q?5T)834PO5T)834PN<&AP+'8@,2XQ,RXQ,BXX(#(P,#8O
M,#,O,3,@,#DZ,38Z,C4@:F%N($5X<"`D"B`J"B`J($!P86-K86=E(%A-3%]7
M0EA-3`H@*B\*8VQA<W,@6$U,7U="6$U,('L*"B`@("`O*BH*("`@("`J($1E
M8V]D:6YG($UU;'1I+6)Y=&4@26YT96=E<G,@9G)O;2!396-T:6]N(#4N,0H@
M("`@("H*("`@("`J(%5S92!L;VYG(&)E8V%U<V4@:70@:7,@=6YS:6=N960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($U"54EN=#,R5&]);G0H)&EN+"`F)'!O
M<RD*("`@('L*("`@("`@("`D=F%L(#T@,#L*"B`@("`@("`@9&\@>PH@("`@
M("`@("`@("`D8B`](&]R9"@D:6Y;)'!O<RLK72D["B`@("`@("`@("`@("1V
M86P@/#P](#<[("\O($)I='-H:69T(&QE9G0@-R!B:71S+@H@("`@("`@("`@
M("`D=F%L("L]("@D8B`F(#$R-RD["B`@("`@("`@?2!W:&EL92`H*"1B("8@
M,3(X*2`A/2`P*3L*"B`@("`@("`@<F5T=7)N("1V86P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%;F-O9&EN9R!-=6QT:2UB>71E($EN=&5G97)S(&9R;VT@
M4V5C=&EO;B`U+C$*("`@("`J+PH@("`@9G5N8W1I;VX@:6YT5&]-0E5);G0S
M,B@F)&]U="P@)&DI"B`@("!["B`@("`@("`@:68@*"1I(#X@,C8X-#,U-#4U
M*2!["B`@("`@("`@("`@("1B>71E<S`@/2`P('P@6$U,7U="6$U,.CIG971"
M:71S*#`L("1I*3L*("`@("`@("`@("`@)&)Y=&5S,2`](#$R."!\(%A-3%]7
M0EA-3#HZ9V5T0FET<R@Q+"`D:2D["B`@("`@("`@("`@("1B>71E<S(@/2`Q
M,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,BP@)&DI.PH@("`@("`@("`@("`D
M8GET97,S(#T@,3(X('P@6$U,7U="6$U,.CIG971":71S*#,L("1I*3L*("`@
M("`@("`@("`@)&)Y=&5S-"`](#$R."!\(%A-3%]70EA-3#HZ9V5T0FET<R@T
M+"`D:2D["@H@("`@("`@("`@("`D;W5T("X](&-H<B@D8GET97,T*2`N(&-H
M<B@D8GET97,S*2`N(&-H<B@D8GET97,R*2`N(&-H<B@D8GET97,Q*2`N(&-H
M<B@D8GET97,P*3L*("`@("`@("!](&5L<V5I9B`H)&D@/B`R,#DW,34Q*2![
M"B`@("`@("`@("`@("1B>71E<S`@/2`P('P@6$U,7U="6$U,.CIG971":71S
M*#`L("1I*3L*("`@("`@("`@("`@)&)Y=&5S,2`](#$R."!\(%A-3%]70EA-
M3#HZ9V5T0FET<R@Q+"`D:2D["B`@("`@("`@("`@("1B>71E<S(@/2`Q,C@@
M?"!834Q?5T)834PZ.F=E=$)I=',H,BP@)&DI.PH@("`@("`@("`@("`D8GET
M97,S(#T@,3(X('P@6$U,7U="6$U,.CIG971":71S*#,L("1I*3L*"B`@("`@
M("`@("`@("1O=70@+CT@8VAR*"1B>71E<S,I("X@8VAR*"1B>71E<S(I("X@
M8VAR*"1B>71E<S$I("X@8VAR*"1B>71E<S`I.PH@("`@("`@('T@96QS96EF
M("@D:2`^(#$V,S@S*2!["B`@("`@("`@("`@("1B>71E<S`@/2`P('P@6$U,
M7U="6$U,.CIG971":71S*#`L("1I*3L*("`@("`@("`@("`@)&)Y=&5S,2`]
M(#$R."!\(%A-3%]70EA-3#HZ9V5T0FET<R@Q+"`D:2D["B`@("`@("`@("`@
M("1B>71E<S(@/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,BP@)&DI.PH*
M("`@("`@("`@("`@)&]U="`N/2!C:'(H)&)Y=&5S,BD@+B!C:'(H)&)Y=&5S
M,2D@+B!C:'(H)&)Y=&5S,"D["B`@("`@("`@?2!E;'-E:68@*"1I(#X@,3(W
M*2!["B`@("`@("`@("`@("1B>71E<S`@/2`P('P@6$U,7U="6$U,.CIG971"
M:71S*#`L("1I*3L*("`@("`@("`@("`@)&)Y=&5S,2`](#$R."!\(%A-3%]7
M0EA-3#HZ9V5T0FET<R@Q+"`D:2D["@H@("`@("`@("`@("`D;W5T("X](&-H
M<B@D8GET97,Q*2`N(&-H<B@D8GET97,P*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8GET97,P(#T@,"!\(%A-3%]70EA-3#HZ9V5T0FET<R@P
M+"`D:2D["@H@("`@("`@("`@("`D;W5T("X](&-H<B@D8GET97,P*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0FET<R@D;G5M+"`D;"D*
M("`@('L*("`@("`@("!S=VET8V@@*"1N=6TI('L*("`@("`@("!C87-E(#`Z
M"B`@("`@("`@("`@(')E='5R;B`D;"`F(#$R-SL@+R\@,'@W1@H*("`@("`@
M("!C87-E(#$Z"B`@("`@("`@("`@(')E='5R;B`H)&P@/CX@-RD@)B`Q,C<[
M("\O(#!X-T8*"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!R971U<FX@
M*"1L(#X^(#$T*2`F(#$R-SL@+R\@,'@W1@H*("`@("`@("!C87-E(#,Z"B`@
M("`@("`@("`@(')E='5R;B`H)&P@/CX@,C$I("8@,3(W.R`O+R`P>#=&"@H@
M("`@("`@(&-A<V4@-#H*("`@("`@("`@("`@<F5T=7)N("@D;"`^/B`R."D@
M)B`Q,C<[("\O(#!X-T8*("`@("`@("!]"@H@("`@("`@(')E='5R;B`P.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$1025-T<FEN9R@D:2D*("`@('L*("`@
M("`@("`O*BH*("`@("`@("`@*B!!1$0@0TA!4%1%4@H@("`@("`@("`J+PH@
M("`@("`@("1$4$E3=')I;F<@/2!A<G)A>2@R(#T^($1025]$5$1?5TU,7S%?
M,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@,R`]/B!$4$E?1%1$7U=4
M05\Q7S`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#0@/3X@1%!)7T14
M1%]734Q?,5\Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`U(#T^($10
M25]$5$1?4TE?,5\Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`V(#T^
M($1025]$5$1?4TQ?,5\P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`W
M(#T^($1025]$5$1?0T]?,5\P+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`X(#T^($1025]$5$1?0TA!3DY%3%\Q7S$L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#D@/3X@1%!)7T141%]734Q?,5\R+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Q,"`]/B!$4$E?1%1$7U=-3%\Q7S,L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#$Q(#T^($1025]$5$1?4%)/5E\Q7S`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#$R(#T^($1025]$5$1?5U1!7U=-
M3%\Q7S(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#$S(#T^($1025]$
M5$1?0TA!3DY%3%\Q7S(L"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!.;W0@86QL(%-Y;F--3"!C;&EE;G1S(&MN;W<@=&AI<RP@<V\@=V4*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@<VAO=6QD('5S92!T:&4@<W1R
M:6YG('1A8FQE+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R`P>$9$
M,2`]/B!$4$E?1%1$7U-93D--3%\Q7S$L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#0P-#D@/3X@1%!)7T141%]364Y#34Q?,5\P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`T,#4P(#T^($1025]$5$1?1$5624Y&7S%?,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@-#`U,2`]/B!$4$E?1%1$7U-9
M3D--3%\Q7S$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#0P-3(@/3X@
M1%!)7T141%]$159)3D9?,5\Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@(')E='5R;B!I<W-E="@D1%!)4W1R:6YG6R1I72D@/R`D
M1%!)4W1R:6YG6R1I72`Z(&YU;&P["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M1%!)26YT*"1D<&DI"B`@("!["B`@("`@("`@+RHJ"B`@("`@("`@("H@041$
M($-(05!415(*("`@("`@("`@*B\*("`@("`@("`D1%!)26YT(#T@87)R87DH
M1%!)7T141%]734Q?,5\P(#T^(#(L"B`@("`@("`@("`@("`@("`@("`@("`@
M($1025]$5$1?5U1!7S%?,"`]/B`S+`H@("`@("`@("`@("`@("`@("`@("`@
M("!$4$E?1%1$7U=-3%\Q7S$@/3X@-"P*("`@("`@("`@("`@("`@("`@("`@
M("`@1%!)7T141%]325\Q7S$@/3X@-2P*("`@("`@("`@("`@("`@("`@("`@
M("`@1%!)7T141%]33%\Q7S`@/3X@-BP*("`@("`@("`@("`@("`@("`@("`@
M("`@1%!)7T141%]#3U\Q7S`@/3X@-RP*("`@("`@("`@("`@("`@("`@("`@
M("`@1%!)7T141%]#2$%.3D5,7S%?,2`]/B`X+`H@("`@("`@("`@("`@("`@
M("`@("`@("!$4$E?1%1$7U=-3%\Q7S(@/3X@.2P*("`@("`@("`@("`@("`@
M("`@("`@("`@1%!)7T141%]734Q?,5\S(#T^(#$P+`H@("`@("`@("`@("`@
M("`@("`@("`@("!$4$E?1%1$7U!23U9?,5\P(#T^(#$Q+`H@("`@("`@("`@
M("`@("`@("`@("`@("!$4$E?1%1$7U=405]734Q?,5\R(#T^(#$R+`H@("`@
M("`@("`@("`@("`@("`@("`@("!$4$E?1%1$7T-(04Y.14Q?,5\R(#T^(#$S
M+`H*("`@("`@("`@("`@("`@("`@("`@("`@+R\@3F]T(&%L;"!3>6YC34P@
M8VQI96YT<R!K;F]W('1H:7,L('-O(&UA>6)E('=E"B`@("`@("`@("`@("`@
M("`@("`@("`@("\O('-H;W5L9"!U<V4@=&AE('-T<FEN9R!T86)L92X*("`@
M("`@("`@("`@("`@("`@("`@("`@1%!)7T141%]364Y#34Q?,5\P(#T^(#0P
M-#DL"B`@("`@("`@("`@("`@("`@("`@("`@($1025]$5$1?1$5624Y&7S%?
M,"`]/B`T,#4P+`H@("`@("`@("`@("`@("`@("`@("`@("!$4$E?1%1$7U-9
M3D--3%\Q7S$@/3X@-#`U,2P*("`@("`@("`@("`@("`@("`@("`@("`@1%!)
M7T141%]$159)3D9?,5\Q(#T^(#0P-3(*("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@1%!)7T141%]364Y#34Q?,5\Q(#T^(#!X1D0Q+`H@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!$4$E?1%1$7T1%5DE.1E\Q7S$@/3X@,'A&1#(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@(')E='5R;B!I
M<W-E="@D1%!)26YT6R1D<&E=*2`_("1$4$E);G1;)&1P:5T@.B`P.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<F%C=&5R(&5N8V]D
M:6YG+@H@("`@("H@;VYL>2!D969A=6QT(&-H87)A8W1E<B!E;F-O9&EN9W,@
M9G)O;2!*,E-%(&%R92!S=7!P;W)T960*("`@("`J(&9R;VT@:'1T<#HO+W=W
M=RYI86YA+F]R9R]A<W-I9VYM96YT<R]C:&%R86-T97(M<V5T<PH@("`@("H@
M86YD(&AT='`Z+R]J879A+G-U;BYC;VTO:C)S92\Q+C0N,B]D;V-S+V%P:2]J
M879A+VYI;R]C:&%R<V5T+T-H87)S970N:'1M;`H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971#:&%R<V5T4W1R:6YG*"1C<RD*("`@('L*("`@("`@("`O*BH*
M("`@("`@("`@*B!&<F]M(&AT='`Z+R]W=W<N:6%N82YO<F<O87-S:6=N;65N
M=',O8VAA<F%C=&5R+7-E=',*("`@("`@("`@*B\*("`@("`@("`D8VAA<G-E
M=%-T<FEN9R`](&%R<F%Y*#,@/3X@)U53+4%30TE))RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#0@/3X@)TE33RTX.#4Y+3$G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@,3`V(#T^("=55$8M."<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Q,#$S(#T^("=55$8M,39"12<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,#$T(#T^("=55$8M
M,39,12<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,#$U(#T^
M("=55$8M,38G*3L*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1C:&%R<V5T4W1R
M:6YG6R1C<UTI(#\@)&-H87)S9713=')I;F=;)&-S72`Z(&YU;&P["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R86-T97(@96YC;V1I
M;F<N"B`@("`@*@H@("`@("H@3VYL>2!D969A=6QT(&-H87)A8W1E<B!E;F-O
M9&EN9W,@9G)O;2!*,E-%(&%R92!S=7!P;W)T960N"B`@("`@*@H@("`@("H@
M1G)O;2!H='1P.B\O=W=W+FEA;F$N;W)G+V%S<VEG;FUE;G1S+V-H87)A8W1E
M<BUS971S(&%N9`H@("`@("H@:'1T<#HO+VIA=F$N<W5N+F-O;2]J,G-E+S$N
M-"XR+V1O8W,O87!I+VIA=F$O;FEO+V-H87)S970O0VAA<G-E="YH=&UL"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$-H87)S971);G0H)&-S*0H@("`@>PH@
M("`@("`@("\J*@H@("`@("`@("`J($9R;VT@:'1T<#HO+W=W=RYI86YA+F]R
M9R]A<W-I9VYM96YT<R]C:&%R86-T97(M<V5T<PH@("`@("`@("`J+PH@("`@
M("`@("1C:&%R<V5T26YT(#T@87)R87DH)U53+4%30TE))R`]/B`S+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)TE33RTX.#4Y+3$G(#T^(#0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G551&+3@G(#T^(#$P-BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=55$8M,39"12<@/3X@,3`Q,RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=55$8M,39,12<@/3X@,3`Q
M-"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=55$8M,38G(#T^(#$P
M,34I.PH*("`@("`@("!R971U<FX@:7-S970H)&-H87)S971);G1;)&-S72D@
M/R`D8VAA<G-E=$EN=%LD8W-=(#H@;G5L;#L*("`@('T*"GT*"B\J*@H@*B!`
M<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-3%](87-H5&%B
M;&4@>PH*("`@('9A<B`D7V@["@H@("`@9G5N8W1I;VX@<V5T*"1K+"`D=BD*
M("`@('L*("`@("`@("`D=&AI<RT^7VA;)&M=(#T@)'8["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T*"1K*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D
M=&AI<RT^7VA;)&M=*2`_("1T:&ES+3Y?:%LD:UT@.B!N=6QL.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]497AT+P``````````````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`,#$V,3(S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9B\`````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W-@`P,38W-S,`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]$
M:69F+U)E;F1E<F5R+P``````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S<V`#`R,#4T,0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]497AT+T1I9F8O4F5N9&5R97(O:6YL:6YE+G!H<```````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`R-C8`,3`T,3<S-C(W-S8`,#(R-3,R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)U1E>'0O1&EF9B]296YD97)E<BYP:'`G.PH*
M+RHJ"B`J("));FQI;F4B(&1I9F8@<F5N9&5R97(N"B`J"B`J(%1H:7,@8VQA
M<W,@<F5N9&5R<R!D:69F<R!I;B!T:&4@5VEK:2US='EL92`B:6YL:6YE(B!F
M;W)M870N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1&EF9B]$:69F
M+U)E;F1E<F5R+VEN;&EN92YP:'`L=B`Q+C0N,3`N,3`@,C`P-B\P,2\P."`P
M,3HS-SHR,"!J86X@17AP("0*("H*("H@0&%U=&AO<B`@0VEP<FEA;B!0;W!O
M=FEC:0H@*B!`<&%C:V%G92!497AT7T1I9F8*("HO"F-L87-S(%1E>'1?1&EF
M9E]296YD97)E<E]I;FQI;F4@97AT96YD<R!497AT7T1I9F9?4F5N9&5R97(@
M>PH*("`@("\J*@H@("`@("H@3G5M8F5R(&]F(&QE861I;F<@8V]N=&5X="`B
M;&EN97,B('1O('!R97-E<G9E+@H@("`@("HO"B`@("!V87(@)%]L96%D:6YG
M7V-O;G1E>'1?;&EN97,@/2`Q,#`P,#L*"B`@("`O*BH*("`@("`J($YU;6)E
M<B!O9B!T<F%I;&EN9R!C;VYT97AT(")L:6YE<R(@=&\@<')E<V5R=F4N"B`@
M("`@*B\*("`@('9A<B`D7W1R86EL:6YG7V-O;G1E>'1?;&EN97,@/2`Q,#`P
M,#L*"B`@("`O*BH*("`@("`J(%!R969I>"!F;W(@:6YS97)T960@=&5X="X*
M("`@("`J+PH@("`@=F%R("1?:6YS7W!R969I>"`]("<\:6YS/B<["@H@("`@
M+RHJ"B`@("`@*B!3=69F:7@@9F]R(&EN<V5R=&5D('1E>'0N"B`@("`@*B\*
M("`@('9A<B`D7VEN<U]S=69F:7@@/2`G/"]I;G,^)SL*"B`@("`O*BH*("`@
M("`J(%!R969I>"!F;W(@9&5L971E9"!T97AT+@H@("`@("HO"B`@("!V87(@
M)%]D96Q?<')E9FEX(#T@)SQD96P^)SL*"B`@("`O*BH*("`@("`J(%-U9F9I
M>"!F;W(@9&5L971E9"!T97AT+@H@("`@("HO"B`@("!V87(@)%]D96Q?<W5F
M9FEX(#T@)SPO9&5L/B<["@H@("`@+RHJ"B`@("`@*B!(96%D97(@9F]R(&5A
M8V@@8VAA;F=E(&)L;V-K+@H@("`@("HO"B`@("!V87(@)%]B;&]C:U]H96%D
M97(@/2`G)SL*"B`@("`O*BH*("`@("`J(%=H870@87)E('=E(&-U<G)E;G1L
M>2!S<&QI='1I;F<@;VX_(%5S960@=&\@<F5C=7)S92!T;R!S:&]W('=O<F0M
M;&5V96P*("`@("`J(&-H86YG97,N"B`@("`@*B\*("`@('9A<B`D7W-P;&ET
M7VQE=F5L(#T@)VQI;F5S)SL*"B`@("!F=6YC=&EO;B!?8FQO8VM(96%D97(H
M)'AB96<L("1X;&5N+"`D>6)E9RP@)'EL96XI"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8FQO8VM?:&5A9&5R.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]S=&%R=$)L;V-K*"1H96%D97(I"B`@("!["B`@("`@("`@<F5T=7)N("1H
M96%D97(["B`@("!]"@H@("`@9G5N8W1I;VX@7VQI;F5S*"1L:6YE<RP@)'!R
M969I>"`]("<@)RP@)&5N8V]D92`]('1R=64I"B`@("!["B`@("`@("`@:68@
M*"1E;F-O9&4I('L*("`@("`@("`@("`@87)R87E?=V%L:R@D;&EN97,L(&%R
M<F%Y*"8D=&AI<RP@)U]E;F-O9&4G*2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'1H:7,M/E]S<&QI=%]L979E;"`]/2`G=V]R9',G*2!["B`@("`@("`@
M("`@(')E='5R;B!I;7!L;V1E*"<G+"`D;&EN97,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!I;7!L;V1E*")<;B(L("1L:6YE<RD@
M+B`B7&XB.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?861D960H
M)&QI;F5S*0H@("`@>PH@("`@("`@(&%R<F%Y7W=A;&LH)&QI;F5S+"!A<G)A
M>2@F)'1H:7,L("=?96YC;V1E)RDI.PH@("`@("`@("1L:6YE<ULP72`]("1T
M:&ES+3Y?:6YS7W!R969I>"`N("1L:6YE<ULP73L*("`@("`@("`D;&EN97-;
M8V]U;G0H)&QI;F5S*2`M(#%=("X]("1T:&ES+3Y?:6YS7W-U9F9I>#L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]L:6YE<R@D;&EN97,L("<@)RP@9F%L<V4I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]D96QE=&5D*"1L:6YE<RP@)'=O<F1S
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@87)R87E?=V%L:R@D;&EN97,L(&%R
M<F%Y*"8D=&AI<RP@)U]E;F-O9&4G*2D["B`@("`@("`@)&QI;F5S6S!=(#T@
M)'1H:7,M/E]D96Q?<')E9FEX("X@)&QI;F5S6S!=.PH@("`@("`@("1L:6YE
M<UMC;W5N="@D;&EN97,I("T@,5T@+CT@)'1H:7,M/E]D96Q?<W5F9FEX.PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7VQI;F5S*"1L:6YE<RP@)R`G+"!F86QS
M92D["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H86YG960H)&]R:6<L("1F:6YA
M;"D*("`@('L*("`@("`@("`O*B!)9B!W92=V92!A;')E861Y('-P;&ET(&]N
M('=O<F1S+"!D;VXG="!T<GD@=&\@9&\@<V\@86=A:6X@+2!J=7-T"B`@("`@
M("`@("H@9&ES<&QA>2X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]S<&QI=%]L
M979E;"`]/2`G=V]R9',G*2!["B`@("`@("`@("`@("1P<F5F:7@@/2`G)SL*
M("`@("`@("`@("`@=VAI;&4@*"1O<FEG6S!=("$]/2!F86QS92`F)B`D9FEN
M86Q;,%T@(3T](&9A;'-E("8F"B`@("`@("`@("`@("`@("`@("!S=6)S='(H
M)&]R:6=;,%TL(#`L(#$I(#T]("<@)R`F)@H@("`@("`@("`@("`@("`@("`@
M<W5B<W1R*"1F:6YA;%LP72P@,"P@,2D@/3T@)R`G*2!["B`@("`@("`@("`@
M("`@("`D<')E9FEX("X]('-U8G-T<B@D;W)I9ULP72P@,"P@,2D["B`@("`@
M("`@("`@("`@("`D;W)I9ULP72`]('-U8G-T<B@D;W)I9ULP72P@,2D["B`@
M("`@("`@("`@("`@("`D9FEN86Q;,%T@/2!S=6)S='(H)&9I;F%L6S!=+"`Q
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'!R969I>"`N
M("1T:&ES+3Y?9&5L971E9"@D;W)I9RD@+B`D=&AI<RT^7V%D9&5D*"1F:6YA
M;"D["B`@("`@("`@?0H*("`@("`@("`D=&5X=#$@/2!I;7!L;V1E*")<;B(L
M("1O<FEG*3L*("`@("`@("`D=&5X=#(@/2!I;7!L;V1E*")<;B(L("1F:6YA
M;"D["@H@("`@("`@("\J($YO;BUP<FEN=&EN9R!N97=L:6YE(&UA<FME<BX@
M*B\*("`@("`@("`D;FP@/2`B7#`B.PH*("`@("`@("`O*B!792!W86YT('1O
M('-P;&ET(&]N('=O<F0@8F]U;F1A<FEE<RP@8G5T('=E(&YE960@=&\*("`@
M("`@("`@*B!P<F5S97)V92!W:&ET97-P86-E(&%S('=E;&PN(%1H97)E9F]R
M92!W92!S<&QI="!O;B!W;W)D<RP*("`@("`@("`@*B!B=70@:6YC;'5D92!A
M;&P@8FQO8VMS(&]F('=H:71E<W!A8V4@:6X@=&AE('=O<F1L:7-T+B`J+PH@
M("`@("`@("1D:69F(#T@)FYE=R!497AT7T1I9F8H)'1H:7,M/E]S<&QI=$]N
M5V]R9',H)'1E>'0Q+"`D;FPI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S<&QI=$]N5V]R9',H)'1E>'0R+"`D;FPI*3L*"B`@
M("`@("`@+RH@1V5T('1H92!D:69F(&EN(&EN;&EN92!F;W)M870N("HO"B`@
M("`@("`@)')E;F1E<F5R(#T@)FYE=R!497AT7T1I9F9?4F5N9&5R97)?:6YL
M:6YE*&%R<F%Y7VUE<F=E*"1T:&ES+3YG971087)A;7,H*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)W-P;&ET7VQE=F5L)R`]/B`G=V]R9',G*2DI.PH*
M("`@("`@("`O*B!2=6X@=&AE(&1I9F8@86YD(&=E="!T:&4@;W5T<'5T+B`J
M+PH@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@D;FPL(")<;B(L("1R96YD
M97)E<BT^<F5N9&5R*"1D:69F*2D@+B`B7&XB.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]S<&QI=$]N5V]R9',H)'-T<FEN9RP@)&YE=VQI;F5%<V-A<&4@/2`B
M7&XB*0H@("`@>PH@("`@("`@("1W;W)D<R`](&%R<F%Y*"D["B`@("`@("`@
M)&QE;F=T:"`]('-T<FQE;B@D<W1R:6YG*3L*("`@("`@("`D<&]S(#T@,#L*
M"B`@("`@("`@=VAI;&4@*"1P;W,@/"`D;&5N9W1H*2!["B`@("`@("`@("`@
M("\O($5A="!A('=O<F0@=VET:"!A;GD@<')E8V5D:6YG('=H:71E<W!A8V4N
M"B`@("`@("`@("`@("1S<&%C97,@/2!S=')S<&XH<W5B<W1R*"1S=')I;F<L
M("1P;W,I+"`B(%QN(BD["B`@("`@("`@("`@("1N97AT<&]S(#T@<W1R8W-P
M;BAS=6)S='(H)'-T<FEN9RP@)'!O<R`K("1S<&%C97,I+"`B(%QN(BD["B`@
M("`@("`@("`@("1W;W)D<UM=(#T@<W1R7W)E<&QA8V4H(EQN(BP@)&YE=VQI
M;F5%<V-A<&4L('-U8G-T<B@D<W1R:6YG+"`D<&]S+"`D<W!A8V5S("L@)&YE
M>'1P;W,I*3L*("`@("`@("`@("`@)'!O<R`K/2`D<W!A8V5S("L@)&YE>'1P
M;W,["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'=O<F1S.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]E;F-O9&4H)B1S=')I;F<I"B`@("!["B`@("`@("`@
M)'-T<FEN9R`](&AT;6QS<&5C:6%L8VAA<G,H)'-T<FEN9RD["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U1E>'0O1&EF9B]296YD97)E<B]U;FEF:65D+G!H<```````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C$P,``Q,#0Q-S,V,C<W-@`P,C(V-C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G5&5X="]$:69F+U)E;F1E<F5R+G!H<"<["@HO*BH*("H@(E5N
M:69I960B(&1I9F8@<F5N9&5R97(N"B`J"B`J(%1H:7,@8VQA<W,@<F5N9&5R
M<R!T:&4@9&EF9B!I;B!C;&%S<VEC(")U;FEF:65D(&1I9F8B(&9O<FUA="X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I9F8O4F5N9&5R
M97(O=6YI9FEE9"YP:'`L=B`Q+C,N,3`N,R`R,#`V+S`Q+S`X(#`Q.C,W.C(P
M(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("HO"F-L87-S
M(%1E>'1?1&EF9E]296YD97)E<E]U;FEF:65D(&5X=&5N9',@5&5X=%]$:69F
M7U)E;F1E<F5R('L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O9B!L96%D:6YG
M(&-O;G1E>'0@(FQI;F5S(B!T;R!P<F5S97)V92X*("`@("`J+PH@("`@=F%R
M("1?;&5A9&EN9U]C;VYT97AT7VQI;F5S(#T@-#L*"B`@("`O*BH*("`@("`J
M($YU;6)E<B!O9B!T<F%I;&EN9R!C;VYT97AT(")L:6YE<R(@=&\@<')E<V5R
M=F4N"B`@("`@*B\*("`@('9A<B`D7W1R86EL:6YG7V-O;G1E>'1?;&EN97,@
M/2`T.PH*("`@(&9U;F-T:6]N(%]B;&]C:TAE861E<B@D>&)E9RP@)'AL96XL
M("1Y8F5G+"`D>6QE;BD*("`@('L*("`@("`@("!I9B`H)'AL96X@(3T@,2D@
M>PH@("`@("`@("`@("`D>&)E9R`N/2`G+"<@+B`D>&QE;CL*("`@("`@("!]
M"B`@("`@("`@:68@*"1Y;&5N("$](#$I('L*("`@("`@("`@("`@)'EB96<@
M+CT@)RPG("X@)'EL96X["B`@("`@("`@?0H@("`@("`@(')E='5R;B`B0$`@
M+21X8F5G("LD>6)E9R!`0"(["B`@("!]"@H@("`@9G5N8W1I;VX@7V%D9&5D
M*"1L:6YE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L:6YE<R@D
M;&EN97,L("<K)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V1E;&5T960H)&QI
M;F5S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VQI;F5S*"1L:6YE
M<RP@)RTG*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8VAA;F=E9"@D;W)I9RP@
M)&9I;F%L*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1E;&5T960H
M)&]R:6<I("X@)'1H:7,M/E]A9&1E9"@D9FEN86PI.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]$:69F+U)E;F1E<F5R+G!H
M<```````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R-C,S`#$P-#$W
M,S8R-S<V`#`R,3(U-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@02!C;&%S<R!T;R!R96YD97(@1&EF
M9G,@:6X@9&EF9F5R96YT(&9O<FUA=',N"B`J"B`J(%1H:7,@8VQA<W,@<F5N
M9&5R<R!T:&4@9&EF9B!I;B!C;&%S<VEC(&1I9F8@9F]R;6%T+B!)="!I<R!I
M;G1E;F1E9"!T:&%T"B`J('1H:7,@8VQA<W,@8F4@8W5S=&]M:7IE9"!V:6$@
M:6YH97)I=&%N8V4L('1O(&]B=&%I;B!F86YC:65R(&]U='!U=',N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1&EF9B]$:69F+U)E;F1E<F5R+G!H
M<"QV(#$N-2XQ,"XW(#(P,#4O,3(O,38@,3$Z-#0Z,#`@:F%N($5X<"`D"B`J
M"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B\*8VQA<W,@5&5X=%]$:69F7U)E
M;F1E<F5R('L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O9B!L96%D:6YG(&-O
M;G1E>'0@(FQI;F5S(B!T;R!P<F5S97)V92X*("`@("`J"B`@("`@*B!4:&ES
M('-H;W5L9"!B92!L969T(&%T('IE<F\@9F]R('1H:7,@8VQA<W,L(&)U="!S
M=6)C;&%S<V5S(&UA>2!W86YT('1O"B`@("`@*B!S970@=&AI<R!T;R!O=&AE
M<B!V86QU97,N"B`@("`@*B\*("`@('9A<B`D7VQE861I;F=?8V]N=&5X=%]L
M:6YE<R`](#`["@H@("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@=')A:6QI;F<@
M8V]N=&5X="`B;&EN97,B('1O('!R97-E<G9E+@H@("`@("H*("`@("`J(%1H
M:7,@<VAO=6QD(&)E(&QE9G0@870@>F5R;R!F;W(@=&AI<R!C;&%S<RP@8G5T
M('-U8F-L87-S97,@;6%Y('=A;G0@=&\*("`@("`J('-E="!T:&ES('1O(&]T
M:&5R('9A;'5E<RX*("`@("`J+PH@("`@=F%R("1?=')A:6QI;F=?8V]N=&5X
M=%]L:6YE<R`](#`["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@5&5X=%]$:69F7U)E;F1E<F5R*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@
M)'!A<F%M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=B`]("=?)R`N("1P
M87)A;3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3XD=BDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3XD=B`]("1V86QU93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;GD@<F5N
M9&5R97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;&P@<&%R86UE=&5R<R!O9B!T:&ES(')E;F1E<F5R(&]B:F5C="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86US*"D*("`@('L*("`@("`@("`D
M<&%R86US(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("AG971?;V)J96-T
M7W9A<G,H)'1H:7,I(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@(&EF("@D
M:WLP?2`]/2`G7R<I('L*("`@("`@("`@("`@("`@("1P87)A;7-;<W5B<W1R
M*"1K+"`Q*5T@/2`D=CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD
M97)S(&$@9&EF9BX*("`@("`J"B`@("`@*B!`<&%R86T@5&5X=%]$:69F("1D
M:69F("!!(%1E>'1?1&EF9B!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!F;W)M871T960@;W5T<'5T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96YD97(H)&1I9F8I"B`@("!["B`@("`@("`@)'AI(#T@)'EI
M(#T@,3L*("`@("`@("`D8FQO8VL@/2!F86QS93L*("`@("`@("`D8V]N=&5X
M="`](&%R<F%Y*"D["@H@("`@("`@("1N;&5A9"`]("1T:&ES+3Y?;&5A9&EN
M9U]C;VYT97AT7VQI;F5S.PH@("`@("`@("1N=')A:6P@/2`D=&AI<RT^7W1R
M86EL:6YG7V-O;G1E>'1?;&EN97,["@H@("`@("`@("1O=71P=70@/2`D=&AI
M<RT^7W-T87)T1&EF9B@I.PH*("`@("`@("`D9&EF9G,@/2`D9&EF9BT^9V5T
M1&EF9B@I.PH@("`@("`@(&9O<F5A8V@@*"1D:69F<R!A<R`D:2`]/B`D961I
M="D@>PH@("`@("`@("`@("!I9B`H:7-?82@D961I="P@)U1E>'1?1&EF9E]/
M<%]C;W!Y)RDI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D8FQO
M8VLI*2!["B`@("`@("`@("`@("`@("`@("`@)&ME97`@/2`D:2`]/2!C;W5N
M="@D9&EF9G,I("T@,2`_("1N=')A:6P@.B`D;FQE860@*R`D;G1R86EL.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D961I="T^;W)I9RD@/#T@
M)&ME97`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&)L;V-K6UT@/2`D
M961I=#L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&YT<F%I;"D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;G1E>'0@/2!A<G)A>5]S;&EC92@D961I="T^;W)I
M9RP@,"P@)&YT<F%I;"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8FQO8VM;72`]("9N97<@5&5X=%]$:69F7T]P7V-O<'DH)&-O;G1E>'0I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("1O=71P=70@+CT@)'1H:7,M/E]B;&]C:R@D>#`L("1N=')A:6P@*R`D
M>&D@+2`D>#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D>3`L("1N=')A:6P@*R`D>6D@+2`D>3`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8FQO8VLI.PH@("`@("`@("`@("`@("`@("`@("`@("`D8FQO8VL@/2!F86QS
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D8V]N=&5X="`]("1E9&ET+3YO<FEG.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M8FQO8VLI*2!["B`@("`@("`@("`@("`@("`@("`@)&-O;G1E>'0@/2!A<G)A
M>5]S;&EC92@D8V]N=&5X="P@8V]U;G0H)&-O;G1E>'0I("T@)&YL96%D*3L*
M("`@("`@("`@("`@("`@("`@("`D>#`@/2`D>&D@+2!C;W5N="@D8V]N=&5X
M="D["B`@("`@("`@("`@("`@("`@("`@)'DP(#T@)'EI("T@8V]U;G0H)&-O
M;G1E>'0I.PH@("`@("`@("`@("`@("`@("`@("1B;&]C:R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1C;VYT97AT*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1B;&]C:UM=(#T@)FYE=R!497AT7T1I9F9?3W!?
M8V]P>2@D8V]N=&5X="D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&)L;V-K6UT@/2`D961I=#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1E9&ET+3YO<FEG*2![
M"B`@("`@("`@("`@("`@("`D>&D@*ST@8V]U;G0H)&5D:70M/F]R:6<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D961I="T^9FEN86PI('L*
M("`@("`@("`@("`@("`@("1Y:2`K/2!C;W5N="@D961I="T^9FEN86PI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH
M)&)L;V-K*2D@>PH@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?8FQO
M8VLH)'@P+"`D>&D@+2`D>#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D>3`L("1Y:2`M("1Y,"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1B;&]C:RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&]U='!U="`N("1T:&ES+3Y?96YD1&EF9B@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]B;&]C:R@D>&)E9RP@)'AL96XL("1Y8F5G+"`D>6QE
M;BP@)B1E9&ET<RD*("`@('L*("`@("`@("`D;W5T<'5T(#T@)'1H:7,M/E]S
M=&%R=$)L;V-K*"1T:&ES+3Y?8FQO8VM(96%D97(H)'AB96<L("1X;&5N+"`D
M>6)E9RP@)'EL96XI*3L*"B`@("`@("`@9F]R96%C:"`H)&5D:71S(&%S("1E
M9&ET*2!["B`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA
M<W,H)&5D:70I*2D@>PH@("`@("`@("`@("!C87-E("=T97AT7V1I9F9?;W!?
M8V]P>2<Z"B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?8V]N
M=&5X="@D961I="T^;W)I9RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)W1E>'1?9&EF9E]O<%]A9&0G.@H@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V%D9&5D*"1E9&ET+3YF:6YA;"D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W1E
M>'1?9&EF9E]O<%]D96QE=&4G.@H@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`D=&AI<RT^7V1E;&5T960H)&5D:70M/F]R:6<I.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=T97AT7V1I9F9?;W!?8VAA
M;F=E)SH*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]C:&%N
M9V5D*"1E9&ET+3YO<FEG+"`D961I="T^9FEN86PI.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;W5T<'5T("X@)'1H:7,M/E]E;F1";&]C:R@I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]S=&%R=$1I9F8H*0H@("`@>PH@("`@("`@(')E='5R;B`G
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!?96YD1&EF9B@I"B`@("!["B`@("`@
M("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N(%]B;&]C:TAE861E
M<B@D>&)E9RP@)'AL96XL("1Y8F5G+"`D>6QE;BD*("`@('L*("`@("`@("!I
M9B`H)'AL96X@/B`Q*2!["B`@("`@("`@("`@("1X8F5G("X]("<L)R`N("@D
M>&)E9R`K("1X;&5N("T@,2D["B`@("`@("`@?0H@("`@("`@(&EF("@D>6QE
M;B`^(#$I('L*("`@("`@("`@("`@)'EB96<@+CT@)RPG("X@*"1Y8F5G("L@
M)'EL96X@+2`Q*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D>&)E9R`N
M("@D>&QE;B`_("@D>6QE;B`_("=C)R`Z("=D)RD@.B`G82<I("X@)'EB96<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W-T87)T0FQO8VLH)&AE861E<BD*("`@
M('L*("`@("`@("!R971U<FX@)&AE861E<B`N(")<;B(["B`@("!]"@H@("`@
M9G5N8W1I;VX@7V5N9$)L;V-K*"D*("`@('L*("`@("`@("!R971U<FX@)R<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7VQI;F5S*"1L:6YE<RP@)'!R969I>"`]
M("<@)RD*("`@('L*("`@("`@("!R971U<FX@)'!R969I>"`N(&EM<&QO9&4H
M(EQN)'!R969I>"(L("1L:6YE<RD@+B`B7&XB.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]C;VYT97AT*"1L:6YE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]L:6YE<R@D;&EN97,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]A9&1E
M9"@D;&EN97,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&EN97,H
M)&QI;F5S+"`G/B<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]D96QE=&5D*"1L
M:6YE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L:6YE<R@D;&EN
M97,L("<\)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H86YG960H)&]R:6<L
M("1F:6YA;"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D96QE=&5D
M*"1O<FEG*2`N("(M+2U<;B(@+B`D=&AI<RT^7V%D9&5D*"1F:6YA;"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O5&5X="]R95-4+P``````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<V`#`Q-S`P,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O1F]R;6%T=&5R+P``````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-S8`,#(P-S0S`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O<F53
M5"]&;W)M871T97(O:'1M;"YP:'``````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-C$P,0`Q,#0Q-S,V,C<W-@`P,C(T,3,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXO1F]R;6%T=&5R+G!H<"<["@HO*BH*
M("H@5&AE(%1E>'1?<F535%]&;W)M871T97)?:'1M;#HZ(&-L87-S(&ES('1H
M92!(5$U,(&9O<FUA='1E<BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X
M=%]R95-4+W)E4U0O1F]R;6%T=&5R+VAT;6PN<&AP+'8@,2XV+C$R+C4@,C`P
M-B\P,2\P,2`R,3HR.#HS.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E
M(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@5&5X=%]R95-4
M"B`J+PIC;&%S<R!497AT7W)E4U1?1F]R;6%T=&5R7VAT;6P@97AT96YD<R!4
M97AT7W)E4U1?1F]R;6%T=&5R('L*"B`@("`O*BH*("`@("`J(%1H92!C=7)R
M96YT(&]U='!U="!C:&%R<V5T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7V-H87)S970@/2!N=6QL.PH*("`@(&9U;F-T
M:6]N(&9O<FUA="@F)&YO9&4L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H(6ES<V5T*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA
M<G-E="`]("1T:&ES+3Y?8VAA<G-E=#L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<U]S=')I;F<H)&YO9&4I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M8VAA<G-E="DI('L*("`@("`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I
M86QC:&%R<R@D;F]D92P@14Y47U%53U1%4RP@)&-H87)S970I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&AT;6QS<&5C
M:6%L8VAA<G,H)&YO9&4L($5.5%]154]415,I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*"1N;V1E+3Y?='EP92D@>PH@("`@
M("`@(&-A<V4@)T1O8W5M96YT)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8VAI;&1R96XH)&YO9&4I.PH*("`@("`@("!C87-E("=(96%D:6YG)SH*
M("`@("`@("`@("`@)&QE=F5L(#T@)&YO9&4M/F=E=%!R;W!E<G1Y*"=L979E
M;"<I.PH@("`@("`@("`@("!R971U<FX@)SQH)R`N("1L979E;"`N("<^)R`N
M("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I("X@)SPO:"<@+@H@("`@("`@("`@
M("`@("`@)&QE=F5L("X@)SXG.PH*("`@("`@("!C87-E("=,:6YK)SH*("`@
M("`@("`@("`@<F5T=7)N("<\82!H<F5F/2(G("X*("`@("`@("`@("`@("`@
M("AI<W-E="@D8VAA<G-E="D@/PH@("`@("`@("`@("`@("`@($!H=&UL<W!E
M8VEA;&-H87)S*"1N;V1E+3YG9710<F]P97)T>2@G:')E9B<I+"!%3E1?455/
M5$53+"`D8VAA<G-E="D@.@H@("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L
M8VAA<G,H)&YO9&4M/F=E=%!R;W!E<G1Y*"=H<F5F)RDL($5.5%]154]415,I
M*2`N"B`@("`@("`@("`@("`@("`G(CXG("X*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8VAI;&1R96XH)&YO9&4I("X@)SPO83XG.PH*("`@("`@("!C87-E
M("=,:71E<F%L+4)L;V-K)SH*("`@("`@("`@("`@;&ES="@D=&5X="D@/2`D
M;F]D92T^7V-H:6QD<F5N.PH@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N
M("AI<W-E="@D8VAA<G-E="D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!`:'1M;'-P96-I86QC:&%R<R@D=&5X="P@14Y47U%53U1%4RP@)&-H
M87)S970I(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P
M96-I86QC:&%R<R@D=&5X="P@14Y47U%53U1%4RDI("X@)SPO<')E/B<["@H@
M("`@("`@(&-A<V4@)U!A<F%G<F%P:"<Z"B`@("`@("`@("`@(')E='5R;B`B
M/'`^(B`N("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I("X@(CPO<#XB.PH*("`@
M("`@("!C87-E("=);G1E<G!R971E9"U497AT)SH*("`@("`@("`@("`@<W=I
M=&-H("@D;F]D92T^9V5T4')O<&5R='DH)W)O;&4G*2D@>PH@("`@("`@("`@
M("!C87-E("=E;7!H87-I<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)SQE
M;3XG("X@)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]E;3XG.PH*("`@
M("`@("`@("`@8V%S92`G;&ET97)A;"<Z"B`@("`@("`@("`@("`@("!R971U
M<FX@)SQT=#XG("X@)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]T=#XG
M.PH*("`@("`@("`@("`@8V%S92`G<W1R;VYG)SH*("`@("`@("`@("`@("`@
M(')E='5R;B`G/'-T<F]N9SXG("X@)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@
M+B`G/"]S=')O;F<^)SL*"B`@("`@("`@("`@(&-A<V4@)W-U<&5R<V-R:7!T
M)SH*("`@("`@("`@("`@("`@(')E='5R;B`G/'-U<#XG("X@)'1H:7,M/E]C
M:&EL9')E;B@D;F]D92D@+B`G/"]S=7`^)SL*"B`@("`@("`@("`@(&-A<V4@
M)W-U8G-C<FEP="<Z"B`@("`@("`@("`@("`@("!R971U<FX@)SQS=6(^)R`N
M("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I("X@)SPO<W5B/B<["@H@("`@("`@
M("`@("!C87-E("=T:71L92UR969E<F5N8V4G.@H@("`@("`@("`@("`@("`@
M<F5T=7)N("<\8VET93XG("X@)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G
M/"]C:71E/B<["@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@+R\@6%A8.B!)<W-U92!A('=A<FYI;F<N"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]C:&EL9')E;B@D;F]D92D["B`@("`@("`@("`@('T*
M"B`@("`@("`@8V%S92`G4V5C=&EO;B<Z"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-H:6QD<F5N*"1N;V1E*3L*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@7V-H:6QD<F5N*"8D;F]D92D*("`@('L*("`@("`@("`D<F5S
M=6QT(#T@)R<["B`@("`@("`@9F]R96%C:"`H)&YO9&4M/E]C:&EL9')E;B!A
M<R`D8VAI;&0I('L*("`@("`@("`@("`@)')E<W5L="`N/2`D=&AI<RT^9F]R
M;6%T*"1C:&EL9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+W)E
M4U0O1F]R;6%T=&5R+G!H<```````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#,T,S0`,3`T,3<S-C(W-S8`,#(Q-#4U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@5&5X
M=%]R95-47T9O<FUA='1E<CHZ(&-L87-S(&ES('1H92!F<F%M97=O<FL@9F]R
M(')E;F1E<FEN9PH@*B!R95-T<G5C='5R961497AT(&1O8W5M96YT<R!T;R!D
M:69F97)E;G0@;65D:6$@*&4N9RX@2%1-3"DN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U1E>'1?<F535"]R95-4+T9O<FUA='1E<BYP:'`L=B`Q+C4N,3`N
M.2`R,#`V+S`Q+S`Q(#(Q.C(X.C,Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y
M<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*
M("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&
M96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!497AT
M7W)E4U0*("HO"F-L87-S(%1E>'1?<F535%]&;W)M871T97(@>PH*("`@("\J
M*@H@("`@("H@07)R87D@;V8@9')I=F5R+7-P96-I9FEC('!A<F%M971E<G,@
M9F]R(&9O<FUA='1I;F<N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]A<F=S.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M(&$@;F5W(&9O<FUA='1E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D87)G<R`@07)G=6UE
M;G1S('-P96-I9FEC('1O('1H:7,@9F]R;6%T=&5R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!497AT7W)E4U1?1F]R;6%T=&5R*"1A<F=S(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D=&AI<RT^7V%R9W,@/2`D87)G<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C="!A(&YE=R!F;W)M871T97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!.86UE(&]F('1H92!F
M;W)M871T:6YG(&1R:79E<B!T;R!C;VYS=')U8W0N"B`@("`@*B!`<&%R86T@
M87)R87D@)&%R9W,@("`@($%N(&%R<F%Y(&]F(&1R:79E<BUS<&5C:69I8R!P
M87)A;65T97)S+@H@("`@("H*("`@("`J($!R971U<FX@5&5X=%]R95-47T9O
M<FUA='1E<B`@5&AE(&9O<FUA='1E<@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9F%C=&]R>2@D9')I=F5R+"`D87)G<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@(&QI<W0H
M)'!A=&@L("1D<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<&%T:"`](&1I<FYA;64H7U]&24Q%7U\I("X@)R]&;W)M
M871T97(O)SL*("`@("`@("!]"B`@("`@("`@)&-L87-S(#T@)U1E>'1?<F53
M5%]&;W)M871T97)?)R`N("1D<FEV97(["B`@("`@("`@<F5Q=6ER95]O;F-E
M("1P871H("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D9F]R;6%T=&5R
M(#T@)FYE=R`D8VQA<W,H)&%R9W,I.PH@("`@("`@(')E='5R;B`D9F]R;6%T
M=&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R('1H92!D;V-U;65N
M="X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@5&5X=%]R95-4("1D;V-U;65N="`@5&AE(&1O8W5M96YT('=E('=I;&P@
M<F5N9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("`@(%1H
M92!O=71P=70@8VAA<G-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@9F]R;6%T
M*"8D9&]C=6UE;G0L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]R95-4+U!A
M<G-E<BYP:'``````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8Q
M-S0P`#$P-#$W,S8R-S<V`#`R,#<U,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE(%1E>'1?<F53
M5%]087)S97(Z.B!C;&%S<R!I;7!L96UE;G1S(&$@<&%R<V5R(&9O<B!R95-T
M<G5C='5R961497AT"B`J(&1O8W5M96YT<RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5&5X=%]R95-4+W)E4U0O4&%R<V5R+G!H<"QV(#$N."XR+C@@,C`P
M-B\P,2\P,2`R,3HR.#HS.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E
M(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@5&5X=%]R95-4
M"B`J+PIC;&%S<R!497AT7W)E4U1?4&%R<V5R('L*"B`@("`O*BH*("`@("`J
M(%1H92!P87)S92!T<F5E+@H@("`@("H*("`@("`J($!V87(@5&5X=%]R95-4
M"B`@("`@*B\*("`@('9A<B`D7V1O8W5M96YT.PH*("`@("\J*@H@("`@("H@
M02!H87-H(&]F(&%D;W)N;65N="!L979E;',N"B`@("`@*@H@("`@("H@5&AE
M(&ME>7,@87)E(&]N92UC:&%R86-T97(@;W(@='=O+6-H87)A8W1E<B!S=')I
M;F=S+B`@5&AE(&]N92UC:&%R86-T97(*("`@("`J('-T<FEN9W,@<F5P<F5S
M96YT('5N9&5R;&EN92!A9&]R;FUE;G1S(&]F('1H92!S<&5C:69I960@8VAA
M<F%C=&5R+"!A;F0*("`@("`J('1H92!D;W5B;&4M8VAA<F%C=&5R(&ME>7,@
M87)E('1H92!U;F1E<FQI;F4M86YD+6]V97)L:6YE('-T>6QE<RX@(%1H90H@
M("`@("H@=F%L=65S(&%S<V]C:6%T960@=VET:"!T:&4@:V5Y<R!A<F4@:6YT
M96=E<G,@<F5P<F5S96YT:6YG('1H90H@("`@("H@861O<FYM96YT)W,@:&5A
M9&EN9R!L979E;"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7V%D;W)N;65N=$QE=F5L<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X
M=%]R95-47U!A<G-E<B@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@<&%R<V4@=')E92!R97!R97-E;G1I;F<@82!D;V-U;65N="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&ES(&ES('1H
M92!T97AT(&]F('1H92!D;V-U;65N="!T;R!P87)S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(%1E>'1?<F535"`@5&AE('!A<G-E('1R964N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9P87)S92@D=&5X="D*("`@('L*("`@("`@("`D=&AI
M<RT^7W1E>'0@/2`D=&5X=#L*"B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B]R95-4+G!H<"<["@H@("`@("`@("1T:&ES
M+3Y?9&]C=6UE;G0@/2`F;F5W(%1E>'1?<F535"@G1&]C=6UE;G0G*3L*("`@
M("`@("`D=&AI<RT^7W!U<VA3=&%T92@D=&AI<RT^7V1O8W5M96YT+"`G4V5C
M=&EO;B<L(#`I.PH*("`@("`@("!W:&EL92`H)'1H:7,M/E]N97AT*"DI('L*
M"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O(%!A<G-E(&$@8"XN)R!D
M:7)E8W1I=F4N("!792!R97=R:71E(&%N(&!?7R<@9&ER96-T:79E('1O(&$*
M("`@("`@("`@("`@+R\@8"XN(%]?.B`G(&1I<F5C=&EV92!H97)E+@H@("`@
M("`@("`@("`O+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH7"Y<
M+GQ?7RE<<RLH+BH_*5QS*B0O)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]L:6YE0G5F9F5R6S!=+"`D;2DI('L*("`@("`@("`@("`@
M("`@(&EF("@D;5LQ72`]/2`G7U\G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1E>'0@/2`G7U\Z("<@+B`D;5LR73L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('=H:6QE("@D=&AI<RT^7V5N
M<W5R94QI;F5S*#(I("8F"B`@("`@("`@("`@("`@("`@("`@("`@<')E9U]M
M871C:"@G+UX@("A;7EQS72XJ/RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VQI;F5"=69F97);,5TL("1M*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T97AT("X]("<@)RXD;5LQ73L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VYE>'0H*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5$:7)E8W1I=F4H
M)'1E>'0I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O($QO;VL@9F]R(&]V
M97)L:6YE+6%N9"UU;F1E<FQI;F4@:&5A9&EN9W,N"B`@("`@("`@("`@("\O
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V5N<W5R94QI;F5S*#,I("8F"B`@
M("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O7B@N*S\I7',J)"\G+"`D=&AI
M<RT^7VQI;F5"=69F97);,5TL("1L:6YE36%T8V@I("8F"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-H96-K061O<FYM96YT*&%R<F%Y*#`L(#(I+"!S=')L
M96XH)&QI;F5-871C:%LQ72DI*2!["@H@("`@("`@("`@("`@("`@)&%D;W)N
M;65N=%1Y<&4@/2`D=&AI<RT^7VQI;F5"=69F97);,%U[,'T["B`@("`@("`@
M("`@("`@("`D861O<FYM96YT5'EP92`N/2`D861O<FYM96YT5'EP93L*"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VYE>'0H*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;F5X="@I.PH*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V%D;W)N;65N=$QE=F5L<ULD861O<FYM96YT5'EP95TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&YE=TQE=F5L(#T@)'1H:7,M/E]A9&]R;FUE
M;G1,979E;'-;)&%D;W)N;65N=%1Y<&5=.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&]P5&],979E;"@G4V5C=&EO;B<L("1N97=,979E;"`M(#$I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D;F5W3&5V96P@/2`D=&AI<RT^7V=E=%-T871E3&5V96PH)U-E8W1I;VXG
M*2`K(#$["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&]R;FUE;G1,
M979E;'-;)&%D;W)N;65N=%1Y<&5=(#T@)&YE=TQE=F5L.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&YO9&4@/2`F)'1H:7,M/E]M86ME
M3F]D92@D=&AI<RT^7V-U<G)E;G1.;V1E+"`G4V5C=&EO;B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=L979E
M;"<@/3X@)&YE=TQE=F5L*2D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!U
M<VA3=&%T92@D;F]D92P@)U-E8W1I;VXG+"`D;F5W3&5V96PI.PH@("`@("`@
M("`@("`@("`@<')E9U]M871C:"@G+UY<<RHH+BH_*5QS*B0O)RP@)&QI;F5-
M871C:%LQ72P@)&QI;F5-871C:"D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VUA:V5.;V1E*"1T:&ES+3Y?8W5R<F5N=$YO9&4L("=(96%D:6YG)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VQE=F5L)R`]
M/B`D;F5W3&5V96PI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;&EN94UA=&-H6S%=*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+PH@("`@("`@("`@("`O+R!,
M;V]K(&9O<B!U;F1E<FQI;F4@:&5A9&EN9W,N"B`@("`@("`@("`@("\O"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7V5N<W5R94QI;F5S*#(I("8F"B`@("`@
M("`@("`@("`@("!P<F5G7VUA=&-H*"<O7BA;7EQS72XJ/RE<<RHD+R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&EN94)U9F9E<ELP
M72P@)&QI;F5-871C:"D@)B8*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAE
M8VM!9&]R;FUE;G0H87)R87DH,2DL('-T<FQE;B@D;&EN94UA=&-H6S%=*2DI
M('L*"B`@("`@("`@("`@("`@("`D861O<FYM96YT5'EP92`]("1T:&ES+3Y?
M;&EN94)U9F9E<ELQ77LP?3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F5X
M="@I.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?861O<FYM
M96YT3&5V96QS6R1A9&]R;FUE;G14>7!E72DI('L*("`@("`@("`@("`@("`@
M("`@("`D;F5W3&5V96P@/2`D=&AI<RT^7V%D;W)N;65N=$QE=F5L<ULD861O
M<FYM96YT5'EP95T["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P;W!4
M;TQE=F5L*"=396-T:6]N)RP@)&YE=TQE=F5L("T@,2D["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1N97=,979E;"`]
M("1T:&ES+3Y?9V5T4W1A=&5,979E;"@G4V5C=&EO;B<I("L@,3L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%D;W)N;65N=$QE=F5L<ULD861O<FYM
M96YT5'EP95T@/2`D;F5W3&5V96P["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D;F]D92`]("8D=&AI<RT^7VUA:V5.;V1E*"1T:&ES+3Y?
M8W5R<F5N=$YO9&4L("=396-T:6]N)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)VQE=F5L)R`]/B`D;F5W3&5V
M96PI*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<'5S:%-T871E*"1N;V1E
M+"`G4V5C=&EO;B<L("1N97=,979E;"D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VUA:V5.;V1E*"1T:&ES+3Y?8W5R<F5N=$YO9&4L("=(96%D:6YG)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VQE=F5L
M)R`]/B`D;F5W3&5V96PI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;&EN94UA=&-H6S%=*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+PH@("`@("`@("`@("`O
M+R!087)S92!A(&`Z.B<@<&%R86=R87!H+@H@("`@("`@("`@("`O+PH@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<<RHZ.EQS*B0O)RP@)'1H:7,M
M/E]L:6YE0G5F9F5R6S!=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]N
M97AT*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&ET97)A;$)L
M;V-K*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+R\*("`@("`@("`@("`@+R\@4&%R<V4@82!P87)A
M9W)A<&@N("!792!E;F0@=&AE('!A<F%G<F%P:"!W:&5N('=E(')E='5R;B!T
M;PH@("`@("`@("`@("`O+R!A(&QO=V5R(&EN9&5N=&%T:6]N(&QE=F5L(&]R
M(&5N8V]U;G1E<B!A(&)L86YK(&QI;F4N"B`@("`@("`@("`@("\O"B`@("`@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BA<<RHI*%M>7'-=+BH_*5QS*B0O
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L:6YE0G5F
M9F5R6S!=+"`D;2DI('L*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,ET[
M"B`@("`@("`@("`@("`@("`D;&5V96P@/2!S=')L96XH)&U;,5TI.PH@("`@
M("`@("`@("`@("`@=VAI;&4@*"1T:&ES+3Y?96YS=7)E3&EN97,H,BD@)B8*
M("`@("`@("`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O7BA<<RHI*%M>
M7'-=+BH_*5QS*B0O)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;&EN94)U9F9E<ELQ72P@)&TI*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*'-T<FQE;B@D;5LQ72D@/"`D;&5V96PI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1T97AT("X]("<@)R`N("1M6S)=.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;F5X="@I.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1T<F%I;&EN9TQI=&5R86P@/2!F
M86QS93L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7B@N*EM>
M7'-=.BDZ7',J)"\G+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1E>'0@/2`D;5LQ73L*("`@("`@("`@("`@("`@("`@("`D=')A:6QI
M;F=,:71E<F%L(#T@=')U93L*("`@("`@("`@("`@("`@('T@96QS96EF("AP
M<F5G7VUA=&-H*"<O7B@N*C\I7',J.CI<<RHD+R<L("1T97AT+"`D;2DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&5X="`]("1M6S%=.PH@("`@("`@("`@
M("`@("`@("`@("1T<F%I;&EN9TQI=&5R86P@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%K94YO9&4H)'1H
M:7,M/E]C=7)R96YT3F]D92P@)U!A<F%G<F%P:"<L(&%R<F%Y*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97AT*3L*"B`@("`@("`@
M("`@("`@("!I9B`H)'1R86EL:6YG3&ET97)A;"D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;F5X="@I.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R<V5,:71E<F%L0FQO8VLH*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R!86%@Z($AA;F1L92!G87)B86=E(&QI;F4N"@H@("`@("`@
M('T["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1O8W5M96YT.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9?;6%K94YO9&4H)B1P87)E;G0L("1T>7!E+"`D<')O
M<',@/2!A<G)A>2@I+"`D8VAI;&1497AT(#T@;G5L;"D*("`@('L*("`@("`@
M("`D;F]D92`]("9N97<@5&5X=%]R95-4*"1T>7!E*3L*("`@("`@("!F;W)E
M86-H("@D<')O<',@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("1N;V1E+3YS9710<F]P97)T>2@D;F%M92P@)'9A;'5E*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"%I<U]N=6QL*"1P87)E;G0I*2!["B`@("`@("`@("`@
M("1P87)E;G0M/F%P<&5N9$-H:6QD*"1N;V1E*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"%I<U]N=6QL*"1C:&EL9%1E>'0I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<&%R<V5);FQI;F4H)&YO9&4L("1C:&EL9%1E>'0I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&YO9&4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@;75L=&EP;&4@861O<FYE;6YT(&QI;F5S(&EN('1H92!L:6YE
M(&)U9F9E<B!A;F0@;6%K97,@<W5R92!T:&5Y"B`@("`@*B!A<F4@861O<FYM
M96YT<R!A;F0@=&AA="!A;&P@87)E(&ED96YT:6-A;"!A9&]R;FUE;G1S+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D;&EN97,@("`@("`@($%N(&%R<F%Y(&]F(&QI;F4@;G5M
M8F5R<R!T;R!C:&5C:R!I9B!T:&5Y(&%R90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@861O<FYM96YT<RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1M:6Y,96YG=&@@(%1H92!M:6YI;75M(&QE;F=T:"!F;W(@=&AI<R!A
M9&]R;FUE;G0N("!4:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&1E9F%U;'0@:7,@,2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%=H971H97(@=&AI<R!L:6YE(&ES(&%N(&%D;W)N;65N="!W:&EC:"!M
M871C:&5S('1H90H@("`@("H@("`@("`@("`@("`@("`@("!A8F]V92!C<FET
M97)I82X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K061O<FYM96YT*"1L
M:6YE<R`](&%R<F%Y*#`I+"`D;6EN3&5N9W1H(#T@,2D*("`@('L*("`@("`@
M("`D8VAR(#T@;G5L;#L*("`@("`@("!F;W)E86-H("@D;&EN97,@87,@)&DI
M('L*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7BA;7F$M>D$M6C`M
M.5QX-V8M7'AF9EQS72LI7',J)"\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L:6YE0G5F9F5R6R1I72P@)&TI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&ES7VYU;&PH)&-H<BDI('L*("`@("`@("`@("`@("`@(&EF("AS
M=')L96XH)&U;,5TI(#P@)&UI;DQE;F=T:"D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1C:'(@/2`D;5LQ77LP?3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&U;,5TI("$]("1M:6Y,96YG
M=&@I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&UI;DQE
M;F=T:"`]('-T<FQE;B@D;5LQ72D["B`@("`@("`@("`@(&9O<B`H)&H@/2`P
M.R`D:B`\('-T<FQE;B@D;5LQ72D[("1J*RLI('L*("`@("`@("`@("`@("`@
M(&EF("@D;5LQ77LD:GT@(3T@)&-H<BD@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F
M=6YC=&EO;B`F7W!A<G-E26YL:6YE*"8D;F]D92P@)'1E>'0I"B`@("!["B`@
M("`@("`@<W1A=&EC("1A;&EA<V5S(#T@87)R87DH)W-U<"<@/3X@)W-U<&5R
M<V-R:7!T)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W5B
M)R`]/B`G<W5B<V-R:7!T)RD["B`@("`@("`@<W1A=&EC("1S8VAE;6%S(#T@
M87)R87DH)VAT='`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=H='1P<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9T
M<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VER8R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1E;&YE="<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYE=W,G*3L*"B`@("`@("`@
M=VAI;&4@*'-T<FQE;B@D=&5X="D@/B`P*2!["B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7EPJ7"HH*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE<*EPJ*"XJ
M*20O)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M
M86ME3F]D92@D;F]D92P@)TEN=&5R<')E=&5D+51E>'0G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<F]L92<@/3X@)W-T<F]N
M9R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;5LQ72D[
M"B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H<')E9U]M871C:"@G+UY<*B@H/SI<7%Q<+GQ;7EQ<7%Q=*2H_
M*5PJ*"XJ*20O)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]M86ME3F]D92@D;F]D92P@)TEN=&5R<')E=&5D+51E>'0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<F]L92<@/3X@
M)V5M<&AA<VES)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1M6S%=*3L*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@
M("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7F!@*"XJ/RE@8"@N*BDD
M+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1S=6(@/2`F)'1H
M:7,M/E]M86ME3F]D92@D;F]D92P@)TEN=&5R<')E=&5D+51E>'0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=R
M;VQE)R`]/B`G;&ET97)A;"<I*3L*("`@("`@("`@("`@("`@("1S=6(M/F%P
M<&5N9$-H:6QD*"1M6S%=*3L*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;
M,ET["B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7CHH6V$M
M>BU=*RDZ8"@H/SI<7%Q<+GQ;7EQ<7%Q=*2H_*6`H+BHI)"\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5X="P@)&TI*2!["B`@("`@
M("`@("`@("`@("`D<F]L92`]("1M6S%=.PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1A;&EA<V5S6R1M6S%=72DI('L*("`@("`@("`@("`@("`@("`@
M("`D<F]L92`]("1A;&EA<V5S6R1M6S%=73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1S=6(@/2`F)'1H:7,M/E]M86ME3F]D92@D;F]D
M92P@)TEN=&5R<')E=&5D+51E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=R;VQE)R`]/B`D<F]L92DI.PH@
M("`@("`@("`@("`@("`@:68@*"1R;VQE(#T]("=L:71E<F%L)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1S=6(M/F%P<&5N9$-H:6QD*"1M6S)=*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)S94EN;&EN92@D<W5B+"`D;5LR72D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S-=.PH@("`@("`@("`@
M("!](&5L<V5I9B`H<')E9U]M871C:"@G+UY@*"@_.EQ<7%PN?%M>7%Q<7%TI
M*C\I8#HH6V$M>BU=*RDZ*"XJ*20O)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)')O
M;&4@/2`D;5LR73L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D86QI87-E
M<ULD;5LR75TI*2!["B`@("`@("`@("`@("`@("`@("`@)')O;&4@/2`D86QI
M87-E<ULD;5LR75T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D<W5B(#T@)B1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L("=);G1E<G!R971E
M9"U497AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<F]L92<@/3X@)')O;&4I*3L*("`@("`@("`@("`@("`@
M(&EF("@D<F]L92`]/2`G;&ET97)A;"<I('L*("`@("`@("`@("`@("`@("`@
M("`D<W5B+3YA<'!E;F1#:&EL9"@D;5LQ72D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5);FQI
M;F4H)'-U8BP@)&U;,5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'1E>'0@/2`D;5LS73L*("`@("`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R]>8"@H/SI<7%Q<+GQ;7EQ<7%Q=*2H_*6!?7R@N*BDD+R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97AT+"`D;2DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,:6YK*"1N;V1E+"`D
M;5LQ72P@=')U92D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@
M("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UY@*"@_.EQ<7%PN
M?%M>7%Q<7%TI*C\I8%\H+BHI)"\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<G-E3&EN:R@D;F]D92P@)&U;,5TL(&9A;'-E*3L*("`@("`@("`@
M("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS96EF("AP
M<F5G7VUA=&-H*"<O7F`H*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE@*"XJ*20O)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0L("1M*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M86ME3F]D92@D;F]D92P@)TEN
M=&5R<')E=&5D+51E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<F]L92<@/3X@)W1I=&QE+7)E9F5R96YC92<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;5LQ72D["B`@("`@("`@
M("`@("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@("`@("!](&5L<V5I9B`H
M<')E9U]M871C:"@G+UXH*#\Z)R`N(&IO:6XH)WPG+"`D<V-H96UA<RD@+B`@
M)RDZ7"]<+ULM,"TY82UZ(R4F*RY<+SH[/U]<7'Y=*ULM,"TY82UZ(R4F*UPO
M7UQ<?ETI*"XJ*20O:2<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@
M("1S=6(@/2`F)'1H:7,M/E]M86ME3F]D92@D;F]D92P@)TQI;FLG+"!A<G)A
M>2@G:')E9B<@/3X@)&U;,5TI*3L*("`@("`@("`@("`@("`@("1S=6(M/F%P
M<&5N9$-H:6QD*"1M6S%=*3L*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;
M,ET["B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7BA;82UZ
M,"TY+5TK0%MA+7HP+3DM7"Y=*UPN6V$M>C`M.2U=*RDH+BHI)"]I)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0L("1M*2D@>PH@
M("`@("`@("`@("`@("`@)'-U8B`]("8D=&AI<RT^7VUA:V5.;V1E*"1N;V1E
M+"`G3&EN:R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)VAR968G(#T^("=M86EL=&\Z)R`N("1M6S%=*2D["B`@
M("`@("`@("`@("`@("`D<W5B+3YA<'!E;F1#:&EL9"@D;5LQ72D["B`@("`@
M("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@("`@("!](&5L<V5I
M9B`H<')E9U]M871C:"@G+UXH7'<K*5]<8B@N*BDD+R<L("1T97AT+"`D;2DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,:6YK*"1N;V1E+"`D
M;5LQ72P@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*
M("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>7%Q<7%QS*"XJ
M*20O)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@+R\@0F%C:W-L
M87-H+65S8V%P960@=VAI=&5S<&%C92!C:&%R86-T97)S(&%R92!R96UO=F5D
M(&9R;VT*("`@("`@("`@("`@("`@("\O('1H92!D;V-U;65N="X*("`@("`@
M("`@("`@("`@("1T97AT(#T@)&U;,5T["B`@("`@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"<O7EQ<7%PH+BDH+BHI)"\G+"`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D8R`]("1M6S%=.PH@("`@("`@("`@("`@("`@
M)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@("`@("1N;V1E+3YA<'!E;F1#
M:&EL9"@D8RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`O+R!86%@Z(%=E('-H;W5L9"!T<GD@=&\@=7-E(&$@<F5G97AP('1O(&=R
M86(@87,@;75C:"!T97AT(&%S"B`@("`@("`@("`@("`@("`O+R!P;W-S:6)L
M92P@=&AE;B!F86QL('1H<F]U9V@@=&\@=&AE('-I;F=L92UC:&%R86-T97(@
M8V%S90H@("`@("`@("`@("`@("`@+R\@:68@=V4@8V%N)W0@9V5T(&%N>71H
M:6YG+@H*("`@("`@("`@("`@("`@("1C(#T@<W5B<W1R*"1T97AT+"`P+"`Q
M*3L*("`@("`@("`@("`@("`@("1T97AT(#T@<W5B<W1R*"1T97AT+"`Q*3L*
M("`@("`@("`@("`@("`@("1N;V1E+3YA<'!E;F1#:&EL9"@D8RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8F]D>3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A;B!A;F]N>6UO=7,@;W(@;F%M
M960@;&EN:RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@5&5X=%]R95-4("`@("`@("`@("!4:&4@<&%R96YT
M(&YO9&4@9F]R('1H92!L:6YK+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="`@("`@("`@5&AE('1E>'0@=&\@<&%R<V4N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D86YO;GEM;W5S("!7:&5T:&5R('1H:7,@:7,@86X@86YO;GEM;W5S
M(&QI;FLN"B`@("`@*@H@("`@("H@0')E='5R;B!497AT7W)E4U0@(%1H92!N
M97<@;&EN:R!N;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F7W!A<G-E3&EN
M:R@F)&YO9&4L("1T97AT+"`D86YO;GEM;W5S(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)&QI;FL@/2`F)'1H:7,M/E]M86ME3F]D92@D;F]D92P@)TQI;FLG
M*3L*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\\*"XJ*3XO)RP@)'1E>'0L
M("1M*2D@>PH@("`@("`@("`@("`D;&EN:RT^<V5T4')O<&5R='DH)VAR968G
M+"`D;5LQ72D["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BA;7CQ=
M*S\I7',J/"\G+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D;&EN
M:RT^87!P96YD0VAI;&0H)&U;,5TI.PH@("`@("`@("`@("`@("`@:68@*"$D
M86YO;GEM;W5S*2!["B`@("`@("`@("`@("`@("`@("`@)&QI;FLM/G-E=%!R
M;W!E<G1Y*"=N86UE)RP@)'1H:7,M/E]N;W)M86QI>F5.86UE*"1M6S%=*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H(21A;F]N>6UO=7,I('L*("`@("`@("`@
M("`@("`@("1L:6YK+3YS9710<F]P97)T>2@G;F%M92<L("1T:&ES+3Y?;F]R
M;6%L:7IE3F%M92@D=&5X="DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1L:6YK+3YA<'!E;F1#:&EL9"@D=&5X="D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&%N;VYY;6]U<R`F)B!I<U]N=6QL*"1L:6YK+3YG9710<F]P97)T
M>2@G:')E9B<I*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W%U975E06YO;GEM
M;W5S4F5F97)E;F-E*"1L:6YK+"`G;&EN:R<I.PH@("`@("`@('T@96QS96EF
M("@A)&%N;VYY;6]U<R`F)B`A:7-?;G5L;"@D;&EN:RT^9V5T4')O<&5R='DH
M)VYA;64G*2DI('L*("`@("`@("`@("`@)'1H:7,M/E]P=71.86UE9%)E9F5R
M96YC92@D;&EN:RP@)VQI;FLG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D;&EN:SL*("`@('T*"B`@("`O*BH*("`@("`J($YO<FUA;&EZ97,@86X@
M;V)J96-T(&YA;64N"B`@("`@*B!4:&ES(&UE86YS('1H870@=V4@;&]W97)C
M87-E(&ET(&%N9"!N;W)M86QI>F4@86YY('=H:71E<W!A8V4@:6X@:70N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@02!N86UE('1O(&YO
M<FUA;&EZ92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&YO
M<FUA;&EZ960@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VYO<FUA;&EZ
M94YA;64H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C
M92@G+UQS*R\G+"`G("<L('-T<G1O;&]W97(H)&YA;64I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%!A<G-E<R!A;F0@97AE8W5T97,@82!@+BXG(&1I<F5C
M=&EV92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!!(&1I<F5C=&EV92!T;R!E>&5C
M=71E+"!L97-S('1H92!L96%D:6YG(&`N+B`G+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&%R<V5$:7)E8W1I=F4H)'1E>'0I"B`@("!["B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]>7U\Z7',J*"XJ/RE<<RHD+R<L("1T97AT+"`D;2DI
M('L*("`@("`@("`@("`@+R\*("`@("`@("`@("`@+R\@06YO;GEM;W5S(&QI
M;FL@9&5F:6YI=&EO;@H@("`@("`@("`@("`O+PH@("`@("`@("`@("`D9&5F
M;B`]("9N97<@5&5X=%]R95-4*"=,:6YK)RD["B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7EMA+7HP+3DM72M`6V$M>C`M.2U<+ETK7"Y;82UZ,"TY
M+5TK)"]I)RP@)&U;,5TI*2!["B`@("`@("`@("`@("`@("`D;5LQ72`]("=M
M86EL=&\Z)R`N("1M6S%=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D
M969N+3YS9710<F]P97)T>2@G:')E9B<L("1M6S%=*3L*("`@("`@("`@("`@
M)'1H:7,M/E]Q=65U94%N;VYY;6]U<T1E9FEN:71I;VXH)&1E9FXL("=L:6YK
M)RD["B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>7',J7R@N*C\I
M.EQS*B@N*C\I7',J)"\G+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("\O
M"B`@("`@("`@("`@("\O($YA;65D(&QI;FL@9&5F:6YI=&EO;@H@("`@("`@
M("`@("`O+PH@("`@("`@("`@("`D9&5F;B`]("9N97<@5&5X=%]R95-4*"=,
M:6YK)RD["B`@("`@("`@("`@("1D969N+3YS9710<F]P97)T>2@G;F%M92<L
M("1T:&ES+3Y?;F]R;6%L:7IE3F%M92@D;5LQ72DI.PH@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@G+UY;82UZ,"TY+5TK0%MA+7HP+3DM7"Y=*UPN6V$M
M>C`M.2U=*R0O:2<L("1M6S)=*2D@>PH@("`@("`@("`@("`@("`@)&U;,ET@
M/2`G;6%I;'1O.B<@+B`D;5LR73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D9&5F;BT^<V5T4')O<&5R='DH)VAR968G+"`D;5LR72D["B`@("`@("`@
M("`@("1T:&ES+3Y?<'5T3F%M961$969I;FET:6]N*"1D969N+"`G;&EN:R<I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-K:7!S(&)L86YK
M(&QI;F5S('5N=&EL('=E(&9I;F0@;VYE('=E(&-A;B!G970@=&AE(&EN9&5N
M=&%T:6]N(&QE=F5L"B`@("`@*B!F<F]M+"!T:&5N+"!G871H97)S(&QI;F5S
M('5N=&EL('=E(&AA=F4@82!D:69F97)E;G0@;&5V96PN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]P87)S94QI=&5R86Q";&]C:R@I"B`@("!["B`@("`@("`@
M:68@*"$D=&AI<RT^7V5N<W5R94QI;F5S*#$I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@('=H:6QE("AP<F5G7VUA
M=&-H*"<O7EQS*B0O)RP@)'1H:7,M/E]L:6YE0G5F9F5R6S!=*2D@>PH@("`@
M("`@("`@("!I9B`H(21T:&ES+3Y?;F5X="@I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@A<')E9U]M871C:"@G+UXH7',K*2@N*C\I7',J)"\G+"`D=&AI
M<RT^7VQI;F5"=69F97);,%TL("1M*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@("1L979E;"`]('-T<FQE;B@D;5LQ
M72D["B`@("`@("`@)'1E>'0@/2`D;5LR73L*"B`@("`@("`@:68@*"1T:&ES
M+3Y?;F5X="@I*2!["B`@("`@("`@("`@("1R92`]("<O7B@_.B![)R`N("1L
M979E;"`N("=]*"XJ/RE\*"DI7',J)"\G.PH@("`@("`@("`@("!W:&EL92`H
M<')E9U]M871C:"@D<F4L("1T:&ES+3Y?;&EN94)U9F9E<ELP72P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D=&5X="`N/2`B7&XB("X@)&U;,5T["B`@("`@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?;F5X="@I*2!["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1L(#T@)B1T:&ES+3Y?;6%K94YO9&4H
M)'1H:7,M/E]C=7)R96YT3F]D92P@)TQI=&5R86PM0FQO8VLG+"!A<G)A>2@I
M*3L*("`@("`@("`D;"T^87!P96YD0VAI;&0H<')E9U]R97!L86-E*"<O7',K
M)"]S)RP@)R<L("1T97AT*2D["@H@("`@("`@("\O(%A86#H@1&ER='D@:&%C
M:R$*("`@("`@("!A<G)A>5]U;G-H:69T*"1T:&ES+3Y?;&EN94)U9F9E<BP@
M)R<I.PH@("`@?0H*("`@("\O+2TM+0H@("`@+R\@3&EN92UR96%D:6YG(&UE
M;6)E<G,*("`@("\O+2TM+0H*("`@("\J*@H@("`@("H@5&AE(')E;6%I;F1E
M<B!O9B!T:&4@=&5X="!W92!A<F4@<&%R<VEN9RP@8F5I;F<@;6]D:69I960@
M8GD@7V=E=$QI;F4H*0H@("`@("H@86YD(%]N97AT*"DN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]T97AT.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@
M=&AE(&QI;F5S('=E(&AA=F4@<&5E:V5D(&%T+@H@("`@("H*("`@("`J(%1H
M92!F:7)S="!E;&5M96YT(&ES('1H92!L:6YE('=E(&%R92!C=7)R96YT;'D@
M=V]R:VEN9R!W:71H(&%N9"!S;R!O;BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M;&EN94)U9F9E<B`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!2971R:65V
M97,@=&AE(&YE>'0@;&EN92!F<F]M(&$@8FQO8VL@;V8@=&5X="X*("`@("`J
M"B`@("`@*B!792!R97!L86-E('1A8G,@=VET:"`X('-P86-E<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$QI;F4H*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)'1H:7,M/E]T
M97AT*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@
M('T*("`@("`@("`D:2`]('-T<G!O<R@D=&AI<RT^7W1E>'0L(")<;B(I.PH@
M("`@("`@(&EF("@D:2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)&QI;F4@
M/2!S=6)S='(H)'1H:7,M/E]T97AT+"`P+"`D:2D["B`@("`@("`@("`@("1T
M:&ES+3Y?=&5X="`]('-U8G-T<B@D=&AI<RT^7W1E>'0L("1I("L@,2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&QI;F4@/2`D=&AI<RT^7W1E
M>'0["B`@("`@("`@("`@("1T:&ES+3Y?=&5X="`]("<G.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<O7'0O)RP@)R`@("`@("`@
M)RP@)&QI;F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5M<',@=&\@=&AE
M(&YE>'0@;&EN92!I;B!T:&4@:6YP=70N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]N97AT*"D*("`@('L*
M("`@("`@("`O+R!3<&5C:6%L(&-A<V4@=&AE(&9I<G-T('1I;64@)W)O=6YD
M+@H@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7VQI;F5"=69F97(I(#T](#`I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YS=7)E3&EN97,H,2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?96YS=7)E3&EN97,H
M,BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M("`@("!A<G)A>5]S:&EF="@D=&AI<RT^7VQI;F5"=69F97(I.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@<W5R
M92!T:&5R92!I<R!A(&-E<G1A:6X@;G5M8F5R(&]F(&QI;F5S(&%T(&UI;FEM
M=6T@:6X@=&AE(&QI;F4*("`@("`J(&)U9F9E<BX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]U;G0@(%1H:7,@:7,@=&AE(&YU;6)E<B!O9B!L:6YE<R!W:&EC:"!M=7-T
M(&)E(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!B=69F
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R
M(&YO="!W92!S=6-C965D960N("!792!C86X@9F%I;"!A=`H@("`@("H@("`@
M("`@("`@("`@("`@("!E;F0M;V8M9FEL92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V5N<W5R94QI;F5S*"1C;W5N="`](#$I"B`@("!["B`@("`@("`@=VAI
M;&4@*&-O=6YT*"1T:&ES+3Y?;&EN94)U9F9E<BD@/"`D8V]U;G0I('L*("`@
M("`@("`@("`@)&QI;F4@/2`D=&AI<RT^7V=E=$QI;F4H*3L*("`@("`@("`@
M("`@:68@*&ES7VYU;&PH)&QI;F4I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L
M:6YE0G5F9F5R6UT@/2`D;&EN93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+R\M+2TM"B`@("`O+R!!;F]N>6UO=7,@<F5F
M97)E;F-E<R!A;F0@9&5F:6YI=&EO;G,*("`@("\O+2TM+0H*("`@('9A<B`D
M7V%N;VYY;6]U<U)E9F5R96YC97,@/2!A<G)A>2@I.PH@("`@=F%R("1?86YO
M;GEM;W5S1&5F:6YI=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M4VEN8V4@86YO;GEM;W5S(')E9F5R96YC97,@86YD(&1E9FEN:71I;VYS("AE
M+F<N(&9O;W1N;W1E<RP@;&EN:W,I(&1O"B`@("`@*B!N;W0@;F5E9"!T;R!B
M92!D969I;F5D(")I;B!L;V-K<W1E<"(@86-C;W)D:6YG('1O('1H92!S<&5C
M+"!W92!C<F5A=&4*("`@("`J('1H92!P87)T:6%L('!A<G-E(&YO9&4@:6X@
M8F]T:"!P;&%C97,@86YD('5S92!T:&ES(&YI9G1Y('-Y<W1E;2!T;PH@("`@
M("H@<75E=64@;W(@;65R9V4@:6X@96%C:"!P;&%C92X@($YO=&4@=&AA="!T
M:&4@<F5F97)E;F-E(&ES('1H92`B;6%S=&5R(@H@("`@("H@;F]D92X@(%1H
M92!D969I;FET:6]N(&=E=',@=&AR;W=N(&%W87D@<VEN8V4@:70@<F5A;&QY
M(&ES;B=T(&EN('1H90H@("`@("H@<&%R<V4@=')E92!A;GEW87DN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&]B:F5C="`F)&YO9&4@(%1H92!N;V1E('1O('%U975E(&]R(&UE<F=E('1O
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@(%1H92!T>7!E(&]F(&%N
M;VYY;6]U<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]Q=65U94%N
M;VYY;6]U<U)E9F5R96YC92@F)&YO9&4L("1T>7!E*0H@("`@>PH@("`@("`@
M(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D='EP92P@)'1H:7,M/E]A;F]N>6UO
M=7-$969I;FET:6]N<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]A;F]N>6UO
M=7-$969I;FET:6]N<ULD='EP95T@/2!A<G)A>2@I.PH@("`@("`@('T*("`@
M("`@("!I9B`H8V]U;G0H)'1H:7,M/E]A;F]N>6UO=7-$969I;FET:6]N<ULD
M='EP95TI(#X@,"D@>PH@("`@("`@("`@("`D9&5F;B`]("8D=&AI<RT^7V%N
M;VYY;6]U<T1E9FEN:71I;VYS6R1T>7!E75LP73L*("`@("`@("`@("`@87)R
M87E?<VAI9G0H)'1H:7,M/E]A;F]N>6UO=7-$969I;FET:6]N<ULD='EP95TI
M.PH@("`@("`@("`@("`D=&AI<RT^7VUE<F=E3F]D95!R;W!E<G1I97,H)&YO
M9&4L("1D969N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^7V%N;VYY;6]U<U)E9F5R96YC97-;)'1Y<&5=6UT@/2`F)&YO9&4["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@2&%N9&QE<R!A;B!A;F]N
M>6UO=7,@9&5F:6YI=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("8D;F]D92`@5&AE(&YO
M9&4@=&\@<75E=64@;W(@;65R9V4@9G)O;2X*("`@("`J($!P87)A;2!S=')I
M;F<@)'1Y<&4@("!4:&4@='EP92!O9B!A;F]N>6UO=7,@;V)J96-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<75E=65!;F]N>6UO=7-$969I;FET:6]N*"8D
M;F]D92P@)'1Y<&4I"B`@("!["B`@("`@("`@:68@*"%A<G)A>5]K97E?97AI
M<W1S*"1T>7!E+"`D=&AI<RT^7V%N;VYY;6]U<U)E9F5R96YC97,I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?86YO;GEM;W5S4F5F97)E;F-E<ULD='EP95T@
M/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M
M/E]A;F]N>6UO=7-2969E<F5N8V5S6R1T>7!E72D@/B`P*2!["B`@("`@("`@
M("`@("1R968@/2`F)'1H:7,M/E]A;F]N>6UO=7-2969E<F5N8V5S6R1T>7!E
M75LP73L*("`@("`@("`@("`@87)R87E?<VAI9G0H)'1H:7,M/E]A;F]N>6UO
M=7-2969E<F5N8V5S6R1T>7!E72D["B`@("`@("`@("`@("1T:&ES+3Y?;65R
M9V5.;V1E4')O<&5R=&EE<R@D<F5F+"`D;F]D92D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/E]A;F]N>6UO=7-$969I;FET:6]N<ULD
M='EP95U;72`]("8D;F]D93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!-97)G97,@=&AE('!R;W!E<G1I97,@9G)O;2!E86-H(&YO9&4@:6YT
M;R!T:&4@;W1H97(@;F]D92X*("`@("`J"B`@("`@*B!4:&4@;F]D92!T>7!E
M(&ES(&YO="!C:&%N9V5D("AF;W(@=&AE(&-A<V4@=VAE<F4@=V4@:&%V92!A
M(&9O;W1N;W1E"B`@("`@*B!R969E<F5N8V4@86YD(&$@9F]O=&YO=&4@9&5F
M:6YI=&EO;BDL(&)U="!B;W1H(&YO9&5S('=I;&P@:&%V92!A;&P*("`@("`J
M('!R;W!E<G1I97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)&YO9&4@(%1H92!R969E<F5N
M8V4@;F]D92X*("`@("`J($!P87)A;2!O8FIE8W0@)B1D969N("!4:&4@9&5F
M:6YI=&EO;B!N;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;65R9V5.;V1E
M4')O<&5R=&EE<R@F)&YO9&4L("8D9&5F;BD*("`@('L*("`@("`@("`O+R!8
M6%@Z(%=E('-H;W5L9"!M86ME('-U<F4@=&AE<F4@:7,@;F\@8V]L;&ES:6]N
M+@H@("`@("`@(&9O<F5A8V@@*"1D969N+3Y?<')O<&5R=&EE<R!A<R`D;F%M
M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&YO9&4M/G-E=%!R;W!E<G1Y
M*"1N86UE+"`D=F%L=64I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D
M;F]D92T^7W!R;W!E<G1I97,@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("1D969N+3YS9710<F]P97)T>2@D;F%M92P@)'9A;'5E*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+R\M+2TM"B`@("`O+R!.86UE9"!R969E<F5N
M8V5S(&%N9"!D969I;FET:6]N<PH@("`@+R\M+2TM"@H@("`@=F%R("1?;F%M
M9612969E<F5N8V5S(#T@87)R87DH*3L*("`@('9A<B`D7VYA;65D1&5F:6YI
M=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4W1O<F5S(&$@;F%M
M960@<F5F97)E;F-E('!A<G-E(&YO9&4@:6X@82!H87-H('-O('=E(&-A;B!L
M871E<B!M97)G90H@("`@("H@<')O<&5R=&EE<R!W:71H(&$@9&5F:6YI=&EO
M;BX@($EF('=E(&%L<F5A9'D@:&%V92!A(&1E9FEN:71I;VXL(&1O"B`@("`@
M*B!T:&4@;65R9V4@;F]W+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!497AT7W)E4U0@)B1N;V1E("!4:&4@
M<&%R<V4@=')E92!N;V1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M("`@(%1H92!T>7!E(&]F(&YA;65D(')E9F5R96YC92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('=E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T:&4@<F5F97)E;F-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<'5T3F%M9612969E<F5N8V4H)B1N;V1E+"`D='EP92D*("`@('L*("`@
M("`@("`D;F%M92`]("1N;V1E+3YG9710<F]P97)T>2@G;F%M92<I.PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65D4F5F97)E;F-E<ULD='EP95U;
M)&YA;65=*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?;F%M9612969E<F5N8V5S6R1T>7!E75LD;F%M
M95T@/2`F)&YO9&4["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F%M961$
M969I;FET:6]N<ULD='EP95U;)&YA;65=*2D@>PH@("`@("`@("`@("`D9&5F
M;B`]("8D=&AI<RT^7VYA;65D1&5F:6YI=&EO;G-;)'1Y<&5=6R1N86UE73L*
M("`@("`@("`@("`@)'1H:7,M/E]M97)G94YO9&50<F]P97)T:65S*"1N;V1E
M+"`D9&5F;BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&AE(&EN=F5R<V4@;V8@>T!L:6YK(%]P=71.
M86UE9%)E9F5R96YC92@I?2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!U=$YA;65D1&5F:6YI=&EO;B@F
M)&YO9&4L("1T>7!E*0H@("`@>PH@("`@("`@("1N86UE(#T@)&YO9&4M/F=E
M=%!R;W!E<G1Y*"=N86UE)RD["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M;F%M961$969I;FET:6]N<ULD='EP95U;)&YA;65=*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;F%M
M961$969I;FET:6]N<ULD='EP95U;)&YA;65=(#T@)B1N;V1E.PH@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VYA;65D4F5F97)E;F-E<ULD='EP95U;)&YA
M;65=*2D@>PH@("`@("`@("`@("`D<F5F(#T@)B1T:&ES+3Y?;F%M9612969E
M<F5N8V5S6R1T>7!E75LD;F%M95T["B`@("`@("`@("`@("1T:&ES+3Y?;65R
M9V5.;V1E4')O<&5R=&EE<R@D<F5F+"`D;F]D92D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O+2TM+0H@("`@+R\@4W1A
M=&4@<W1A8VL@;6%N86=E;65N=`H@("`@+R\M+2TM"@H@("`@+RHJ"B`@("`@
M*B!4:&4@<W1A=&4@<W1A8VLN"B`@("`@*@H@("`@("H@270@:7,@=7-E9"!T
M;R!K965P('1R86-K(&]F(&YE<W1E9"!B;V1Y+6QE=F5L(&5L96UE;G1S(&%N
M9"!H;W<@=&AE>0H@("`@("H@;6EG:'0@96YD+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<W1A=&53=&%C:R`](&%R<F%Y
M*"D["@H@("`@=F%R("1?8W5R<F5N=$YO9&4["@H@("`@9G5N8W1I;VX@7W!U
M<VA3=&%T92@F)&YO9&4L("1S=&%T951Y<&4L("1L979E;"D*("`@('L*("`@
M("`@("`D<W1A=&4@/2`F;F5W(%1E>'1?<F535%]087)S97)?<W1A=&4H)&YO
M9&4L("1S=&%T951Y<&4L("1L979E;"D["B`@("`@("`@)'1H:7,M/E]S=&%T
M95-T86-K6UT@/2`F)'-T871E.PH@("`@("`@("1T:&ES+3Y?8W5R<F5N=$YO
M9&4@/2`F)&YO9&4["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E=%-T871E3&5V
M96PH)'-T871E5'EP92D*("`@('L*("`@("`@("!F;W(@*"1I(#T@8V]U;G0H
M)'1H:7,M/E]S=&%T95-T86-K*2`M(#$[("1I(#X](#`[("1I+2TI('L*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&53=&%C:ULD:5TM/G-T871E5'EP
M92`]/2`D<W1A=&54>7!E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]S=&%T95-T86-K6R1I72T^;&5V96P["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N(#`["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W!O<%1O3&5V96PH)'-T871E5'EP92P@)&QE=F5L*0H@("`@>PH@("`@("`@
M('=H:6QE("@D=&AI<RT^7V=E=%-T871E3&5V96PH)'-T871E5'EP92D@/B`D
M;&5V96PI('L*("`@("`@("`@("`@)'1H:7,M/E]P;W`H*3L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W!O<"@I"B`@("!["B`@("`@("`@87)R
M87E?<&]P*"1T:&ES+3Y?<W1A=&53=&%C:RD["B`@("`@("`@:68@*&-O=6YT
M*"1T:&ES+3Y?<W1A=&53=&%C:RDI('L*("`@("`@("`@("`@)'-T871E(#T@
M)B1T:&ES+3Y?<W1A=&53=&%C:UMC;W5N="@D=&AI<RT^7W-T871E4W1A8VLI
M("T@,5T["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$YO9&4@/2`F)'-T
M871E+3YN;V1E.PH@("`@("`@('T*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L
M87-S(')E<')E<V5N=',@82!N;V1E(&]N('1H92!P87)S97(G<R!S=&%T92!S
M=&%C:RX*("H*("H@0'!A8VMA9V4@5&5X=%]R95-4"B`J+PIC;&%S<R!497AT
M7W)E4U1?4&%R<V5R7W-T871E('L*"B`@("!V87(@)&YO9&4["B`@("!V87(@
M)'-T871E5'EP93L*("`@('9A<B`D;&5V96P["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("8D;F]D
M92`@("`@(%1H:7,@:7,@=&AE('!A<G-E(&YO9&4@87-S;V-I871E9"!W:71H
M('1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A=&4N
M("!";&]C:RUL979E;"!E;&5M96YT<R!P87)S960@:6X@=&AI<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%T92!W:6QL(&)E(&-H:6QD
M<F5N(&]F('1H:7,@;F]D92X*("`@("`J($!P87)A;2!S=')I;F<@)'-T871E
M5'EP92`@0W5R<F5N=&QY(&]N;'D@)U-E8W1I;VXG+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1L979E;"`@("`@("!4:&ES(&ES('1H92!N97-T:6YG(&QE=F5L
M(&]F('1H:7,@<W1A=&4@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X
M=%]R95-47U!A<G-E<E]S=&%T92@F)&YO9&4L("1S=&%T951Y<&4L("1L979E
M;"D*("`@('L*("`@("`@("`D=&AI<RT^;F]D92`]("8D;F]D93L*("`@("`@
M("`D=&AI<RT^<W1A=&54>7!E(#T@)'-T871E5'EP93L*("`@("`@("`D=&AI
M<RT^;&5V96P@/2`D;&5V96P["B`@("!]"@I]"@``````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M5&5X="]D;V-S+P``````````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<V`#`Q-S`U,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]497AT+V1O8W,O97AA;7!L97,O````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`
M,#(P-C<Q`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O=&5S=',O
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,C<W-@`P,3<R-C4`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O5&5X="]$:69F+G!H<```````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#8S-34T`#$P-#$W,S8R-S<V`#`Q-S4Q-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&5X=%]$:69F"B`J"B`J($=E;F5R86P@05!)(&9O<B!G96YE<F%T
M:6YG(&%N9"!F;W)M871T:6YG(&1I9F9S("T@=&AE(&1I9F9E<F5N8V5S(&)E
M='=E96X*("H@='=O('-E<75E;F-E<R!O9B!S=')I;F=S+@H@*@H@*B!4:&4@
M4$A0(&1I9F8@8V]D92!U<V5D(&EN('1H:7,@<&%C:V%G92!W87,@;W)I9VEN
M86QL>2!W<FET=&5N(&)Y($=E;V9F<F5Y"B`J(%0N($1A:7)I:VD@86YD(&ES
M('5S960@=VET:"!H:7,@<&5R;6ES<VEO;BX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5&5X=%]$:69F+T1I9F8N<&AP+'8@,2XQ,2XR+C<@,C`P-B\P,B\P
M-B`P,#HR-3HU,B!J86X@17AP("0*("H*("H@0'!A8VMA9V4@5&5X=%]$:69F
M"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I
M<FEK:2YO<F<^"B`J+PIC;&%S<R!497AT7T1I9F8@>PH*("`@("\J*@H@("`@
M("H@07)R87D@;V8@8VAA;F=E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V5D:71S.PH*("`@("\J*@H@("`@("H@0V]M
M<'5T97,@9&EF9G,@8F5T=V5E;B!S97%U96YC97,@;V8@<W1R:6YG<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&9R;VU?;&EN97,@($%N(&%R<F%Y
M(&]F('-T<FEN9W,N("!4>7!I8V%L;'D@=&AE<V4@87)E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&QI;F5S(&9R;VT@82!F:6QE+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1T;U]L:6YE<R`@("!!;B!A<G)A>2!O9B!S=')I
M;F=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7T1I9F8H)&9R;VU?;&EN
M97,L("1T;U]L:6YE<RD*("`@('L*("`@("`@("!A<G)A>5]W86QK*"1F<F]M
M7VQI;F5S+"!A<G)A>2@D=&AI<RP@)U]T<FEM3F5W;&EN97,G*2D["B`@("`@
M("`@87)R87E?=V%L:R@D=&]?;&EN97,L(&%R<F%Y*"1T:&ES+"`G7W1R:6U.
M97=L:6YE<R<I*3L*"B`@("`@("`@:68@*&5X=&5N<VEO;E]L;V%D960H)WAD
M:69F)RDI('L*("`@("`@("`@("`@)&5N9VEN92`]("9N97<@5&5X=%]$:69F
M7T5N9VEN95]X9&EF9B@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1E;F=I;F4@/2`F;F5W(%1E>'1?1&EF9E]%;F=I;F5?;F%T:79E*"D["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7V5D:71S(#T@)&5N9VEN92T^9&EF
M9B@D9G)O;5]L:6YE<RP@)'1O7VQI;F5S*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&%R<F%Y(&]F(&1I9F9E<F5N8V5S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971$:69F*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]E9&ET<SL*("`@('T*"B`@("`O*BH*("`@("`J($-O;7!U=&5S
M(&$@<F5V97)S960@9&EF9BX*("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@
M("H@/&-O9&4^"B`@("`@*B`D9&EF9B`]("9N97<@5&5X=%]$:69F*"1L:6YE
M<S$L("1L:6YE<S(I.PH@("`@("H@)')E=B`]("1D:69F+3YR979E<G-E*"D[
M"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0')E='5R;B!497AT7T1I
M9F8@($$@1&EF9B!O8FIE8W0@<F5P<F5S96YT:6YG('1H92!I;G9E<G-E(&]F
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@(&]R:6=I;F%L(&1I9F8N
M("!.;W1E('1H870@=V4@<'5R<&]S96QY(&1O;B=T(')E='5R;B!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@<F5F97)E;F-E(&AE<F4L('-I;F-E('1H
M:7,@97-S96YT:6%L;'D@:7,@82!C;&]N92@I"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@;65T:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R979E<G-E
M*"D*("`@('L*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R
M<VEO;B@I+"`G,B<L("<^)RDI('L*("`@("`@("`@("`@)')E=B`](&-L;VYE
M*"1T:&ES*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5V(#T@
M)'1H:7,["B`@("`@("`@?0H@("`@("`@("1R978M/E]E9&ET<R`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]E9&ET<R!A<R`D961I="D@
M>PH@("`@("`@("`@("`D<F5V+3Y?961I='-;72`]("1E9&ET+3YR979E<G-E
M*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5V.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VAE8VMS(&9O<B!A;B!E;7!T>2!D:69F+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T=V\@<V5Q=65N8V5S
M('=E<F4@:61E;G1I8V%L+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5M<'1Y
M*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5D:71S(&%S("1E
M9&ET*2!["B`@("`@("`@("`@(&EF("@A:7-?82@D961I="P@)U1E>'1?1&EF
M9E]/<%]C;W!Y)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;7!U=&5S('1H92!L96YG=&@@;V8@
M=&AE($QO;F=E<W0@0V]M;6]N(%-U8G-E<75E;F-E("A,0U,I+@H@("`@("H*
M("`@("`J(%1H:7,@:7,@;6]S=&QY(&9O<B!D:6%G;F]S=&EC('!U<G!O<V5S
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&QE;F=T:"!O
M9B!T:&4@3$-3+@H@("`@("HO"B`@("!F=6YC=&EO;B!L8W,H*0H@("`@>PH@
M("`@("`@("1L8W,@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?961I
M=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@*&ES7V$H)&5D:70L("=4
M97AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@("`@("`@("`D;&-S("L]
M(&-O=6YT*"1E9&ET+3YO<FEG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!R971U<FX@)&QC<SL*("`@('T*"B`@("`O*BH*("`@("`J($=E
M=',@=&AE(&]R:6=I;F%L('-E="!O9B!L:6YE<RX*("`@("`J"B`@("`@*B!4
M:&ES(')E8V]N<W1R=6-T<R!T:&4@)&9R;VU?;&EN97,@<&%R86UE=&5R('!A
M<W-E9"!T;R!T:&4@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@5&AE(&]R:6=I;F%L('-E<75E;F-E(&]F('-T<FEN9W,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$]R:6=I;F%L*"D*("`@('L*("`@("`@
M("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@*"1E9&ET+3YO<FEG
M*2!["B`@("`@("`@("`@("`@("!A<G)A>5]S<&QI8V4H)&QI;F5S+"!C;W5N
M="@D;&EN97,I+"`P+"`D961I="T^;W)I9RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@('T*"B`@("`O*BH*
M("`@("`J($=E=',@=&AE(&9I;F%L('-E="!O9B!L:6YE<RX*("`@("`J"B`@
M("`@*B!4:&ES(')E8V]N<W1R=6-T<R!T:&4@)'1O7VQI;F5S('!A<F%M971E
M<B!P87-S960@=&\@=&AE(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!S97%U96YC92!O9B!S=')I;F=S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971&:6YA;"@I"B`@("!["B`@("`@("`@)&QI;F5S
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5D:71S(&%S
M("1E9&ET*2!["B`@("`@("`@("`@(&EF("@D961I="T^9FEN86PI('L*("`@
M("`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D;&EN97,L(&-O=6YT*"1L:6YE
M<RDL(#`L("1E9&ET+3YF:6YA;"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V97,@=')A:6QI;F<@;F5W;&EN97,@9G)O;2!A(&QI;F4@;V8@=&5X
M="X@5&AI<R!I<R!M96%N="!T;R!B92!U<V5D"B`@("`@*B!W:71H(&%R<F%Y
M7W=A;&LH*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L:6YE("!4
M:&4@;&EN92!T;R!T<FEM+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ME>2`@
M5&AE(&EN9&5X(&]F('1H92!L:6YE(&EN('1H92!A<G)A>2X@3F]T('5S960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T<FEM3F5W;&EN97,H)B1L:6YE+"`D
M:V5Y*0H@("`@>PH@("`@("`@("1L:6YE(#T@<W1R7W)E<&QA8V4H87)R87DH
M(EQN(BP@(EQR(BDL("<G+"`D;&EN92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@82!D:69F(&9O<B!V86QI9&ET>2X*("`@("`J"B`@("`@*B!4
M:&ES(&ES(&AE<F4@;VYL>2!F;W(@9&5B=6=G:6YG('!U<G!O<V5S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8VAE8VLH)&9R;VU?;&EN97,L("1T;U]L:6YE
M<RD*("`@('L*("`@("`@("!I9B`H<V5R:6%L:7IE*"1F<F]M7VQI;F5S*2`A
M/2!S97)I86QI>F4H)'1H:7,M/F=E=$]R:6=I;F%L*"DI*2!["B`@("`@("`@
M("`@('1R:6=G97)?97)R;W(H(E)E8V]N<W1R=6-T960@;W)I9VEN86P@9&]E
M<VXG="!M871C:"(L($5?55-%4E]%4E)/4BD["B`@("`@("`@?0H@("`@("`@
M(&EF("AS97)I86QI>F4H)'1O7VQI;F5S*2`A/2!S97)I86QI>F4H)'1H:7,M
M/F=E=$9I;F%L*"DI*2!["B`@("`@("`@("`@('1R:6=G97)?97)R;W(H(E)E
M8V]N<W1R=6-T960@9FEN86P@9&]E<VXG="!M871C:"(L($5?55-%4E]%4E)/
M4BD["B`@("`@("`@?0H*("`@("`@("`D<F5V(#T@)'1H:7,M/G)E=F5R<V4H
M*3L*("`@("`@("!I9B`H<V5R:6%L:7IE*"1T;U]L:6YE<RD@(3T@<V5R:6%L
M:7IE*"1R978M/F=E=$]R:6=I;F%L*"DI*2!["B`@("`@("`@("`@('1R:6=G
M97)?97)R;W(H(E)E=F5R<V5D(&]R:6=I;F%L(&1O97-N)W0@;6%T8V@B+"!%
M7U5315)?15)23U(I.PH@("`@("`@('T*("`@("`@("!I9B`H<V5R:6%L:7IE
M*"1F<F]M7VQI;F5S*2`A/2!S97)I86QI>F4H)')E=BT^9V5T1FEN86PH*2DI
M('L*("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B4F5V97)S960@9FEN86P@
M9&]E<VXG="!M871C:"(L($5?55-%4E]%4E)/4BD["B`@("`@("`@?0H*("`@
M("`@("`D<')E=G1Y<&4@/2!N=6QL.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@*"1P<F5V='EP
M92`]/2!G971?8VQA<W,H)&5D:70I*2!["B`@("`@("`@("`@("`@("!T<FEG
M9V5R7V5R<F]R*")%9&ET('-E<75E;F-E(&ES(&YO;BUO<'1I;6%L(BP@15]5
M4T527T524D]2*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<')E=G1Y
M<&4@/2!G971?8VQA<W,H)&5D:70I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@I]"@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO
M5&5X=%]$:69F+T1I9F8N<&AP+'8@,2XQ,2XR+C<@,C`P-B\P,B\P-B`P,#HR
M-3HU,B!J86X@17AP("0*("H*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A
M=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO
M<F<^"B`J+PIC;&%S<R!497AT7TUA<'!E9$1I9F8@97AT96YD<R!497AT7T1I
M9F8@>PH*("`@("\J*@H@("`@("H@0V]M<'5T97,@82!D:69F(&)E='=E96X@
M<V5Q=65N8V5S(&]F('-T<FEN9W,N"B`@("`@*@H@("`@("H@5&AI<R!C86X@
M8F4@=7-E9"!T;R!C;VUP=71E('1H:6YG<R!L:6ME(&-A<V4M:6YS96YS:71V
M92!D:69F<RP@;W(@9&EF9G,*("`@("`J('=H:6-H(&EG;F]R92!C:&%N9V5S
M(&EN('=H:71E+7-P86-E+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M9G)O;5]L:6YE<R`@("`@("`@($%N(&%R<F%Y(&]F('-T<FEN9W,N"B`@("`@
M*B!`<&%R86T@87)R87D@)'1O7VQI;F5S("`@("`@("`@("!!;B!A<G)A>2!O
M9B!S=')I;F=S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1M87!P961?9G)O;5]L
M:6YE<R`@5&AI<R!A<G)A>2!S:&]U;&0@:&%V92!T:&4@<V%M92!S:7IE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6UB97(@
M;V8@96QE;65N=',@87,@)&9R;VU?;&EN97,N("!4:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5L96UE;G1S(&EN("1M87!P
M961?9G)O;5]L:6YE<R!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1M87!P961?=&]?;&EN97,@87)E('=H870@:7,@86-T
M=6%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;7!A<F5D('=H96X@8V]M<'5T:6YG('1H92!D:69F+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1M87!P961?=&]?;&EN97,@("`@5&AI<R!A<G)A>2!S:&]U
M;&0@:&%V92!T:&4@<V%M92!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]F(&5L96UE;G1S(&%S("1T;U]L:6YE<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]-87!P961$:69F*"1F<F]M7VQI
M;F5S+"`D=&]?;&EN97,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&UA<'!E9%]F<F]M7VQI;F5S+"`D;6%P<&5D7W1O7VQI;F5S*0H@("`@>PH@
M("`@("`@(&%S<V5R="AC;W5N="@D9G)O;5]L:6YE<RD@/3T@8V]U;G0H)&UA
M<'!E9%]F<F]M7VQI;F5S*2D["B`@("`@("`@87-S97)T*&-O=6YT*"1T;U]L
M:6YE<RD@/3T@8V]U;G0H)&UA<'!E9%]T;U]L:6YE<RDI.PH*("`@("`@("!P
M87)E;G0Z.E1E>'1?1&EF9B@D;6%P<&5D7V9R;VU?;&EN97,L("1M87!P961?
M=&]?;&EN97,I.PH*("`@("`@("`D>&D@/2`D>6D@/2`P.PH@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?961I=',I.R`D:2LK*2![
M"B`@("`@("`@("`@("1O<FEG(#T@)B1T:&ES+3Y?961I='-;)&E=+3YO<FEG
M.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)&]R:6<I*2!["B`@("`@("`@
M("`@("`@("`D;W)I9R`](&%R<F%Y7W-L:6-E*"1F<F]M7VQI;F5S+"`D>&DL
M(&-O=6YT*"1O<FEG*2D["B`@("`@("`@("`@("`@("`D>&D@*ST@8V]U;G0H
M)&]R:6<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEN86P@/2`F
M)'1H:7,M/E]E9&ET<ULD:5TM/F9I;F%L.PH@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)&9I;F%L*2D@>PH@("`@("`@("`@("`@("`@)&9I;F%L(#T@87)R
M87E?<VQI8V4H)'1O7VQI;F5S+"`D>6DL(&-O=6YT*"1F:6YA;"DI.PH@("`@
M("`@("`@("`@("`@)'EI("L](&-O=6YT*"1F:6YA;"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@0VQA<W,@=7-E9"!I;G1E
M<FYA;&QY(&)Y($1I9F8@=&\@86-T=6%L;'D@8V]M<'5T92!T:&4@9&EF9G,N
M("!4:&ES(&-L87-S"B`J('5S97,@=&AE('AD:69F(%!%0TP@<&%C:V%G92`H
M:'1T<#HO+W!E8VPN<&AP+FYE="]P86-K86=E+WAD:69F*2!T;R!C;VUP=71E
M"B`J('1H92!D:69F97)E;F-E<R!B971W965N('1H92!T=V\@:6YP=70@87)R
M87ES+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G
M/@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H*("H@0&%C8V5S<R!P<FEV871E
M"B`J+PIC;&%S<R!497AT7T1I9F9?16YG:6YE7WAD:69F('L*"B`@("!F=6YC
M=&EO;B!D:69F*"1F<F]M7VQI;F5S+"`D=&]?;&EN97,I"B`@("!["B`@("`@
M("`@+RH@0V]N=F5R="!T:&4@='=O(&EN<'5T(&%R<F%Y<R!I;G1O('-T<FEN
M9W,@9F]R('AD:69F('!R;V-E<W-I;F<N("HO"B`@("`@("`@)&9R;VU?<W1R
M:6YG(#T@:6UP;&]D92@B7&XB+"`D9G)O;5]L:6YE<RD["B`@("`@("`@)'1O
M7W-T<FEN9R`](&EM<&QO9&4H(EQN(BP@)'1O7VQI;F5S*3L*"B`@("`@("`@
M+RH@1&EF9B!T:&4@='=O('-T<FEN9W,@86YD(&-O;G9E<G0@=&AE(')E<W5L
M="!T;R!A;B!A<G)A>2X@*B\*("`@("`@("`D9&EF9B`]('AD:69F7W-T<FEN
M9U]D:69F*"1F<F]M7W-T<FEN9RP@)'1O7W-T<FEN9RP@8V]U;G0H)'1O7VQI
M;F5S*2D["B`@("`@("`@)&1I9F8@/2!E>'!L;V1E*")<;B(L("1D:69F*3L*
M"B`@("`@("`@+RH@5V%L:R!T:')O=6=H('1H92!D:69F(&]N92!L:6YE(&%T
M(&$@=&EM92X@(%=E(&)U:6QD('1H92`D961I=',*("`@("`@("`@*B!A<G)A
M>2!O9B!D:69F(&]P97)A=&EO;G,@8GD@<F5A9&EN9R!T:&4@9FER<W0@8VAA
M<F%C=&5R(&]F('1H90H@("`@("`@("`J('AD:69F(&]U='!U="`H=VAI8V@@
M:7,@:6X@=&AE(")U;FEF:65D(&1I9F8B(&9O<FUA="DN"B`@("`@("`@("H*
M("`@("`@("`@*B!.;W1E('1H870@=V4@9&]N)W0@:&%V92!E;F]U9V@@:6YF
M;W)M871I;VX@=&\@9&5T96-T(")C:&%N9V5D(@H@("`@("`@("`J(&QI;F5S
M('5S:6YG('1H:7,@87!P<F]A8V@L('-O('=E(&-A;B=T(&%D9"!497AT7T1I
M9F9?3W!?8VAA;F=E9`H@("`@("`@("`J(&EN<W1A;F-E<R!T;R!T:&4@)&5D
M:71S(&%R<F%Y+B`@5&AE(')E<W5L="!I<R!S=&EL;"!P97)F96-T;'D*("`@
M("`@("`@*B!V86QI9"P@86QB96ET(&$@;&ET=&QE(&QE<W,@9&5S8W)I<'1I
M=F4@86YD(&5F9FEC:65N="X@*B\*("`@("`@("`D961I=',@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1D:69F(&%S("1L:6YE*2!["B`@("`@("`@
M("`@('-W:71C:"`H)&QI;F5;,%TI('L*("`@("`@("`@("`@8V%S92`G("<Z
M"B`@("`@("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$:69F7T]P
M7V-O<'DH87)R87DH<W5B<W1R*"1L:6YE+"`Q*2DI.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("<K)SH*("`@("`@("`@("`@
M("`@("1E9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?3W!?861D*&%R<F%Y*'-U
M8G-T<B@D;&EN92P@,2DI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G+2<Z"B`@("`@("`@("`@("`@("`D961I='-;72`]
M("9N97<@5&5X=%]$:69F7T]P7V1E;&5T92AA<G)A>2AS=6)S='(H)&QI;F4L
M(#$I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E9&ET<SL*("`@('T*"GT*"B\J
M*@H@*B!#;&%S<R!U<V5D(&EN=&5R;F%L;'D@8GD@1&EF9B!T;R!A8W1U86QL
M>2!C;VUP=71E('1H92!D:69F<RX@(%1H:7,@8VQA<W,@:7,*("H@:6UP;&5M
M96YT960@=7-I;F<@;F%T:79E(%!(4"!C;V1E+@H@*@H@*B!4:&4@86QG;W)I
M=&AM('5S960@:&5R92!I<R!M;W-T;'D@;&EF=&5D(&9R;VT@=&AE('!E<FP@
M;6]D=6QE"B`J($%L9V]R:71H;3HZ1&EF9B`H=F5R<VEO;B`Q+C`V*2!B>2!.
M960@2V]N>BP@=VAI8V@@:7,@879A:6QA8FQE(&%T.@H@*B!H='1P.B\O=W=W
M+G!E<FPN8V]M+T-004XO875T:&]R<R]I9"].+TY%+TY%1$M/3EHO06QG;W)I
M=&AM+41I9F8M,2XP-BYZ:7`*("H*("H@36]R92!I9&5A<R!A<F4@=&%K96X@
M9G)O;3H*("H@:'1T<#HO+W=W=RYI8W,N=6-I+F5D=2]^97!P<W1E:6XO,38Q
M+SDV,#(R.2YH=&UL"B`J"B`J(%-O;64@:61E87,@*&%N9"!A(&)I="!O9B!C
M;V1E*2!A<F4@=&%K96X@9G)O;2!A;F%L>7IE+F,L(&]F($=.50H@*B!D:69F
M=71I;',M,BXW+"!W:&EC:"!C86X@8F4@9F]U;F0@870Z"B`J(&9T<#HO+V=N
M=61I<W0N9VYU+F]R9R]P=6(O9VYU+V1I9F9U=&EL<R]D:69F=71I;',M,BXW
M+G1A<BYG>@H@*@H@*B!3;VUE(&ED96%S("AS=6)D:79I<VEO;B!B>2!.0TA5
M3DM3(#X@,BP@86YD('-O;64@;W!T:6UI>F%T:6]N<RD@87)E(&9R;VT*("H@
M1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SXN(%1H
M92!O<FEG:6YA;"!02%`@=F5R<VEO;B!O9B!T:&ES"B`J(&-O9&4@=V%S('=R
M:71T96X@8GD@:&EM+"!A;F0@:7,@=7-E9"]A9&%P=&5D('=I=&@@:&ES('!E
M<FUI<W-I;VXN"B`J"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@
M/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J($!P86-K86=E(%1E>'1?1&EF9@H@
M*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9E]%;F=I
M;F5?;F%T:79E('L*"B`@("!F=6YC=&EO;B!D:69F*"1F<F]M7VQI;F5S+"`D
M=&]?;&EN97,I"B`@("!["B`@("`@("`@)&Y?9G)O;2`](&-O=6YT*"1F<F]M
M7VQI;F5S*3L*("`@("`@("`D;E]T;R`](&-O=6YT*"1T;U]L:6YE<RD["@H@
M("`@("`@("1T:&ES+3YX8VAA;F=E9"`]("1T:&ES+3YY8VAA;F=E9"`](&%R
M<F%Y*"D["B`@("`@("`@)'1H:7,M/GAV(#T@)'1H:7,M/GEV(#T@87)R87DH
M*3L*("`@("`@("`D=&AI<RT^>&EN9"`]("1T:&ES+3YY:6YD(#T@87)R87DH
M*3L*("`@("`@("!U;G-E="@D=&AI<RT^<V5Q*3L*("`@("`@("!U;G-E="@D
M=&AI<RT^:6Y?<V5Q*3L*("`@("`@("!U;G-E="@D=&AI<RT^;&-S*3L*"B`@
M("`@("`@+R\@4VMI<"!L96%D:6YG(&-O;6UO;B!L:6YE<RX*("`@("`@("!F
M;W(@*"1S:VEP(#T@,#L@)'-K:7`@/"`D;E]F<F]M("8F("1S:VEP(#P@)&Y?
M=&\[("1S:VEP*RLI('L*("`@("`@("`@("`@:68@*"1F<F]M7VQI;F5S6R1S
M:VEP72`A/3T@)'1O7VQI;F5S6R1S:VEP72D@>PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/GAC:&%N
M9V5D6R1S:VEP72`]("1T:&ES+3YY8VAA;F=E9%LD<VMI<%T@/2!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("\O(%-K:7`@=')A:6QI;F<@8V]M;6]N(&QI
M;F5S+@H@("`@("`@("1X:2`]("1N7V9R;VT[("1Y:2`]("1N7W1O.PH@("`@
M("`@(&9O<B`H)&5N9'-K:7`@/2`P.R`M+21X:2`^("1S:VEP("8F("TM)'EI
M(#X@)'-K:7`[("1E;F1S:VEP*RLI('L*("`@("`@("`@("`@:68@*"1F<F]M
M7VQI;F5S6R1X:5T@(3T]("1T;U]L:6YE<ULD>6E=*2!["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M>&-H86YG961;)'AI72`]("1T:&ES+3YY8VAA;F=E9%LD>6E=(#T@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O+R!)9VYO<F4@;&EN97,@=VAI8V@@9&\@
M;F]T(&5X:7-T(&EN(&)O=&@@9FEL97,N"B`@("`@("`@9F]R("@D>&D@/2`D
M<VMI<#L@)'AI(#P@)&Y?9G)O;2`M("1E;F1S:VEP.R`D>&DK*RD@>PH@("`@
M("`@("`@("`D>&AA<VA;)&9R;VU?;&EN97-;)'AI75T@/2`Q.PH@("`@("`@
M('T*("`@("`@("!F;W(@*"1Y:2`]("1S:VEP.R`D>6D@/"`D;E]T;R`M("1E
M;F1S:VEP.R`D>6DK*RD@>PH@("`@("`@("`@("`D;&EN92`]("1T;U]L:6YE
M<ULD>6E=.PH@("`@("`@("`@("!I9B`H*"1T:&ES+3YY8VAA;F=E9%LD>6E=
M(#T@96UP='DH)'AH87-H6R1L:6YE72DI*2!["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D>6AA<VA;)&QI
M;F5=(#T@,3L*("`@("`@("`@("`@)'1H:7,M/GEV6UT@/2`D;&EN93L*("`@
M("`@("`@("`@)'1H:7,M/GEI;F1;72`]("1Y:3L*("`@("`@("!]"B`@("`@
M("`@9F]R("@D>&D@/2`D<VMI<#L@)'AI(#P@)&Y?9G)O;2`M("1E;F1S:VEP
M.R`D>&DK*RD@>PH@("`@("`@("`@("`D;&EN92`]("1F<F]M7VQI;F5S6R1X
M:5T["B`@("`@("`@("`@(&EF("@H)'1H:7,M/GAC:&%N9V5D6R1X:5T@/2!E
M;7!T>2@D>6AA<VA;)&QI;F5=*2DI('L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YX=EM=(#T@
M)&QI;F4["B`@("`@("`@("`@("1T:&ES+3YX:6YD6UT@/2`D>&D["B`@("`@
M("`@?0H*("`@("`@("`O+R!&:6YD('1H92!,0U,N"B`@("`@("`@)'1H:7,M
M/E]C;VUP87)E<V5Q*#`L(&-O=6YT*"1T:&ES+3YX=BDL(#`L(&-O=6YT*"1T
M:&ES+3YY=BDI.PH*("`@("`@("`O+R!-97)G92!E9&ET<R!W:&5N('!O<W-I
M8FQE+@H@("`@("`@("1T:&ES+3Y?<VAI9G1";W5N9&%R:65S*"1F<F]M7VQI
M;F5S+"`D=&AI<RT^>&-H86YG960L("1T:&ES+3YY8VAA;F=E9"D["B`@("`@
M("`@)'1H:7,M/E]S:&EF=$)O=6YD87)I97,H)'1O7VQI;F5S+"`D=&AI<RT^
M>6-H86YG960L("1T:&ES+3YX8VAA;F=E9"D["@H@("`@("`@("\O($-O;7!U
M=&4@=&AE(&5D:70@;W!E<F%T:6]N<RX*("`@("`@("`D961I=',@/2!A<G)A
M>2@I.PH@("`@("`@("1X:2`]("1Y:2`](#`["B`@("`@("`@=VAI;&4@*"1X
M:2`\("1N7V9R;VT@?'P@)'EI(#P@)&Y?=&\I('L*("`@("`@("`@("`@87-S
M97)T*"1Y:2`\("1N7W1O('Q\("1T:&ES+3YX8VAA;F=E9%LD>&E=*3L*("`@
M("`@("`@("`@87-S97)T*"1X:2`\("1N7V9R;VT@?'P@)'1H:7,M/GEC:&%N
M9V5D6R1Y:5TI.PH*("`@("`@("`@("`@+R\@4VMI<"!M871C:&EN9R`B<VYA
M:V4B+@H@("`@("`@("`@("`D8V]P>2`](&%R<F%Y*"D["B`@("`@("`@("`@
M('=H:6QE("@D>&D@/"`D;E]F<F]M("8F("1Y:2`\("1N7W1O"B`@("`@("`@
M("`@("`@("`@("`F)B`A)'1H:7,M/GAC:&%N9V5D6R1X:5T@)B8@(21T:&ES
M+3YY8VAA;F=E9%LD>6E=*2!["B`@("`@("`@("`@("`@("`D8V]P>5M=(#T@
M)&9R;VU?;&EN97-;)'AI*RM=.PH@("`@("`@("`@("`@("`@*RLD>6D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1C;W!Y*2!["B`@("`@("`@
M("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$:69F7T]P7V-O<'DH)&-O
M<'DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!&:6YD(&1E;&5T
M97,@)B!A9&1S+@H@("`@("`@("`@("`D9&5L971E(#T@87)R87DH*3L*("`@
M("`@("`@("`@=VAI;&4@*"1X:2`\("1N7V9R;VT@)B8@)'1H:7,M/GAC:&%N
M9V5D6R1X:5TI('L*("`@("`@("`@("`@("`@("1D96QE=&5;72`]("1F<F]M
M7VQI;F5S6R1X:2LK73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&%D
M9"`](&%R<F%Y*"D["B`@("`@("`@("`@('=H:6QE("@D>6D@/"`D;E]T;R`F
M)B`D=&AI<RT^>6-H86YG961;)'EI72D@>PH@("`@("`@("`@("`@("`@)&%D
M9%M=(#T@)'1O7VQI;F5S6R1Y:2LK73L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*"1D96QE=&4@)B8@)&%D9"D@>PH@("`@("`@("`@("`@("`@
M)&5D:71S6UT@/2`F;F5W(%1E>'1?1&EF9E]/<%]C:&%N9V4H)&1E;&5T92P@
M)&%D9"D["B`@("`@("`@("`@('T@96QS96EF("@D9&5L971E*2!["B`@("`@
M("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$:69F7T]P7V1E;&5T
M92@D9&5L971E*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1A9&0I('L*("`@
M("`@("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?3W!?861D
M*"1A9&0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&5D:71S.PH@("`@?0H*("`@("\J*@H@("`@("H@1&EV:61E<R!T:&4@
M3&%R9V5S="!#;VUM;VX@4W5B<V5Q=65N8V4@*$Q#4RD@;V8@=&AE('-E<75E
M;F-E<R`H6$]&1BP*("`@("`J(%A,24TI(&%N9"`H64]&1BP@64Q)32D@:6YT
M;R!.0TA53DM3(&%P<')O>&EM871E;'D@97%U86QL>2!S:7IE9`H@("`@("H@
M<V5G;65N=',N"B`@("`@*@H@("`@("H@4F5T=7)N<R`H3$-3+"!05%,I+B`@
M3$-3(&ES('1H92!L96YG=&@@;V8@=&AE($Q#4RX@4%13(&ES(&%N(&%R<F%Y
M(&]F"B`@("`@*B!.0TA53DM3*S$@*%@L(%DI(&EN9&5X97,@9VEV:6YG('1H
M92!D:79I;F<@<&]I;G1S(&)E='=E96X@<W5B"B`@("`@*B!S97%U96YC97,N
M("!4:&4@9FER<W0@<W5B+7-E<75E;F-E(&ES(&-O;G1A:6YE9"!I;B`H6#`L
M(%@Q*2P@*%DP+"!9,2DL"B`@("`@*B!T:&4@<V5C;VYD(&EN("A8,2P@6#(I
M+"`H63$L(%DR*2!A;F0@<V\@;VXN("!.;W1E('1H870@*%@P+"!9,"D@/3T*
M("`@("`J("A83T9&+"!93T9&*2!A;F0@*%A;3D-(54Y+4UTL(%E;3D-(54Y+
M4UTI(#T]("A83$E-+"!93$E-*2X*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T
M:6]N(&%S<W5M97,@=&AA="!T:&4@9FER<W0@;&EN97,@;V8@=&AE('-P96-I
M9FEE9"!P;W)T:6]N<R!O9@H@("`@("H@=&AE('1W;R!F:6QE<R!D;R!N;W0@
M;6%T8V@L(&%N9"!L:6ME=VES92!T:&%T('1H92!L87-T(&QI;F5S(&1O(&YO
M=`H@("`@("H@;6%T8V@N("!4:&4@8V%L;&5R(&UU<W0@=')I;2!M871C:&EN
M9R!L:6YE<R!F<F]M('1H92!B96=I;FYI;F<@86YD(&5N9`H@("`@("H@;V8@
M=&AE('!O<G1I;VYS(&ET(&ES(&=O:6YG('1O('-P96-I9GDN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]D:6%G("@D>&]F9BP@)'AL:6TL("1Y;V9F+"`D>6QI
M;2P@)&YC:'5N:W,I"B`@("!["B`@("`@("`@)&9L:7`@/2!F86QS93L*"B`@
M("`@("`@:68@*"1X;&EM("T@)'AO9F8@/B`D>6QI;2`M("1Y;V9F*2!["B`@
M("`@("`@("`@("\J(%1H:6YG<R!S965M<R!F87-T97(@*$DG;2!N;W0@<W5R
M92!)('5N9&5R<W1A;F0@=VAY*2!W:&5N('1H90H@("`@("`@("`@("`@*B!S
M:&]R=&5S="!S97%U96YC92!I<R!I;B!8+B`J+PH@("`@("`@("`@("`D9FQI
M<"`]('1R=64["B`@("`@("`@("`@(&QI<W0@*"1X;V9F+"`D>&QI;2P@)'EO
M9F8L("1Y;&EM*0H@("`@("`@("`@("`@("`@/2!A<G)A>2@D>6]F9BP@)'EL
M:6TL("1X;V9F+"`D>&QI;2D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&9L
M:7`I('L*("`@("`@("`@("`@9F]R("@D:2`]("1Y;&EM("T@,3L@)&D@/CT@
M)'EO9F8[("1I+2TI('L*("`@("`@("`@("`@("`@("1Y;6%T8VAE<ULD=&AI
M<RT^>'9;)&E=75M=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@)'EL:6T@+2`Q.R`D:2`^/2`D
M>6]F9CL@)&DM+2D@>PH@("`@("`@("`@("`@("`@)'EM871C:&5S6R1T:&ES
M+3YY=ELD:5U=6UT@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/FQC<R`](#`["B`@("`@("`@)'1H:7,M/G-E<5LP73T@
M)'EO9F8@+2`Q.PH@("`@("`@("1T:&ES+3YI;E]S97$@/2!A<G)A>2@I.PH@
M("`@("`@("1Y;6ED<ULP72`](&%R<F%Y*"D["@H@("`@("`@("1N=6UE<B`]
M("1X;&EM("T@)'AO9F8@*R`D;F-H=6YK<R`M(#$["B`@("`@("`@)'@@/2`D
M>&]F9CL*("`@("`@("!F;W(@*"1C:'5N:R`](#`[("1C:'5N:R`\("1N8VAU
M;FMS.R`D8VAU;FLK*RD@>PH@("`@("`@("`@("!I9B`H)&-H=6YK(#X@,"D@
M>PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P]("1T:&ES+3YL
M8W,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D>6UI9'-;)&E=6R1C
M:'5N:R`M(#%=(#T@)'1H:7,M/G-E<5LD:5T["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1X,2`]("1X;V9F("L@*&EN
M="DH*"1N=6UE<B`K("@D>&QI;2TD>&]F9BDJ)&-H=6YK*2`O("1N8VAU;FMS
M*3L*("`@("`@("`@("`@9F]R("@[("1X(#P@)'@Q.R`D>"LK*2!["B`@("`@
M("`@("`@("`@("`D;&EN92`]("1F;&EP(#\@)'1H:7,M/GEV6R1X72`Z("1T
M:&ES+3YX=ELD>%T["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)'EM871C
M:&5S6R1L:6YE72DI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1M871C:&5S(#T@
M)'EM871C:&5S6R1L:6YE73L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1M
M871C:&5S(&%S("1Y*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3YI;E]S97%;)'E=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D:R`]("1T:&ES+3Y?;&-S4&]S*"1Y*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@87-S97)T*"1K(#X@,"D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1Y;6ED<ULD:UT@/2`D>6UI9'-;)&L@+2`Q73L*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@('=H:6QE("AL:7-T*"1J=6YK
M+"`D>2D@/2!E86-H*"1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D>2`^("1T:&ES+3YS97%;)&L@+2`Q72D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!A<W-E<G0H)'D@/"`D=&AI<RT^<V5Q6R1K72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("\J($]P=&EM:7IA=&EO;CH@=&AI<R!I<R!A
M(&-O;6UO;B!C87-E.B!N97AT(&UA=&-H(&ES"B`@("`@("`@("`@("`@("`@
M("`@("`@("`J(&IU<W0@<F5P;&%C:6YG('!R979I;W5S(&UA=&-H+B`J+PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:6Y?<V5Q6R1T:&ES+3YS
M97%;)&M=72`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5Q6R1K72`]("1Y.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^:6Y?<V5Q6R1Y72`](#$["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*&5M<'1Y*"1T:&ES+3YI;E]S97%;)'E=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:R`]("1T:&ES+3Y?;&-S4&]S*"1Y*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@87-S97)T*"1K(#X@,"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1Y;6ED<ULD:UT@/2`D>6UI9'-;)&L@+2`Q73L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1S97!S6UT@/2`D9FQI<"`_(&%R<F%Y
M*"1Y;V9F+"`D>&]F9BD@.B!A<G)A>2@D>&]F9BP@)'EO9F8I.PH@("`@("`@
M("1Y;6ED(#T@)'EM:61S6R1T:&ES+3YL8W-=.PH@("`@("`@(&9O<B`H)&X@
M/2`P.R`D;B`\("1N8VAU;FMS("T@,3L@)&XK*RD@>PH@("`@("`@("`@("`D
M>#$@/2`D>&]F9B`K("AI;G0I*"@D;G5M97(@*R`H)'AL:6T@+2`D>&]F9BD@
M*B`D;BD@+R`D;F-H=6YK<RD["B`@("`@("`@("`@("1Y,2`]("1Y;6ED6R1N
M72`K(#$["B`@("`@("`@("`@("1S97!S6UT@/2`D9FQI<"`_(&%R<F%Y*"1Y
M,2P@)'@Q*2`Z(&%R<F%Y*"1X,2P@)'DQ*3L*("`@("`@("!]"B`@("`@("`@
M)'-E<'-;72`]("1F;&EP(#\@87)R87DH)'EL:6TL("1X;&EM*2`Z(&%R<F%Y
M*"1X;&EM+"`D>6QI;2D["@H@("`@("`@(')E='5R;B!A<G)A>2@D=&AI<RT^
M;&-S+"`D<V5P<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7VQC<U!O<R@D>7!O
M<RD*("`@('L*("`@("`@("`D96YD(#T@)'1H:7,M/FQC<SL*("`@("`@("!I
M9B`H)&5N9"`]/2`P('Q\("1Y<&]S(#X@)'1H:7,M/G-E<5LD96YD72D@>PH@
M("`@("`@("`@("`D=&AI<RT^<V5Q6RLK)'1H:7,M/FQC<UT@/2`D>7!O<SL*
M("`@("`@("`@("`@)'1H:7,M/FEN7W-E<5LD>7!O<UT@/2`Q.PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FQC<SL*("`@("`@("!]"@H@("`@("`@("1B
M96<@/2`Q.PH@("`@("`@('=H:6QE("@D8F5G(#P@)&5N9"D@>PH@("`@("`@
M("`@("`D;6ED(#T@*&EN="DH*"1B96<@*R`D96YD*2`O(#(I.PH@("`@("`@
M("`@("!I9B`H)'EP;W,@/B`D=&AI<RT^<V5Q6R1M:61=*2!["B`@("`@("`@
M("`@("`@("`D8F5G(#T@)&UI9"`K(#$["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D96YD(#T@)&UI9#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@87-S97)T*"1Y<&]S("$]("1T:&ES+3YS97%;
M)&5N9%TI.PH*("`@("`@("`D=&AI<RT^:6Y?<V5Q6R1T:&ES+3YS97%;)&5N
M9%U=(#T@9F%L<V4["B`@("`@("`@)'1H:7,M/G-E<5LD96YD72`]("1Y<&]S
M.PH@("`@("`@("1T:&ES+3YI;E]S97%;)'EP;W-=(#T@,3L*("`@("`@("!R
M971U<FX@)&5N9#L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S($Q#4R!O
M9B!T=V\@<V5Q=65N8V5S+@H@("`@("H*("`@("`J(%1H92!R97-U;'1S(&%R
M92!R96-O<F1E9"!I;B!T:&4@=F5C=&]R<R`D=&AI<RT^>W@L>7UC:&%N9V5D
M6UTL(&)Y"B`@("`@*B!S=&]R:6YG(&$@,2!I;B!T:&4@96QE;65N="!F;W(@
M96%C:"!L:6YE('1H870@:7,@86X@:6YS97)T:6]N(&]R"B`@("`@*B!D96QE
M=&EO;B`H:64N(&ES(&YO="!I;B!T:&4@3$-3*2X*("`@("`J"B`@("`@*B!4
M:&4@<W5B<V5Q=65N8V4@;V8@9FEL92`P(&ES("A83T9&+"!83$E-*2!A;F0@
M;&EK97=I<V4@9F]R(&9I;&4@,2X*("`@("`J"B`@("`@*B!.;W1E('1H870@
M6$Q)32P@64Q)32!A<F4@97AC;'5S:79E(&)O=6YD<RX@($%L;"!L:6YE(&YU
M;6)E<G,@87)E"B`@("`@*B!O<FEG:6XM,"!A;F0@9&ES8V%R9&5D(&QI;F5S
M(&%R92!N;W0@8V]U;G1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;7!A
M<F5S97$@*"1X;V9F+"`D>&QI;2P@)'EO9F8L("1Y;&EM*0H@("`@>PH@("`@
M("`@("\J(%-L:61E(&1O=VX@=&AE(&)O='1O;2!I;FET:6%L(&1I86=O;F%L
M+B`J+PH@("`@("`@('=H:6QE("@D>&]F9B`\("1X;&EM("8F("1Y;V9F(#P@
M)'EL:6T*("`@("`@("`@("`@("`@)B8@)'1H:7,M/GAV6R1X;V9F72`]/2`D
M=&AI<RT^>79;)'EO9F9=*2!["B`@("`@("`@("`@("LK)'AO9F8["B`@("`@
M("`@("`@("LK)'EO9F8["B`@("`@("`@?0H*("`@("`@("`O*B!3;&ED92!U
M<"!T:&4@=&]P(&EN:71I86P@9&EA9V]N86PN("HO"B`@("`@("`@=VAI;&4@
M*"1X;&EM(#X@)'AO9F8@)B8@)'EL:6T@/B`D>6]F9@H@("`@("`@("`@("`@
M("`F)B`D=&AI<RT^>'9;)'AL:6T@+2`Q72`]/2`D=&AI<RT^>79;)'EL:6T@
M+2`Q72D@>PH@("`@("`@("`@("`M+21X;&EM.PH@("`@("`@("`@("`M+21Y
M;&EM.PH@("`@("`@('T*"B`@("`@("`@:68@*"1X;V9F(#T]("1X;&EM('Q\
M("1Y;V9F(#T]("1Y;&EM*2!["B`@("`@("`@("`@("1L8W,@/2`P.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\J(%1H:7,@:7,@860@:&]C(&)U
M="!S965M<R!T;R!W;W)K('=E;&PN("`D;F-H=6YK<R`]"B`@("`@("`@("`@
M("`J('-Q<G0H;6EN*"1X;&EM("T@)'AO9F8L("1Y;&EM("T@)'EO9F8I("\@
M,BXU*3L@)&YC:'5N:W,@/0H@("`@("`@("`@("`@*B!M87@H,BQM:6XH."PH
M:6YT*21N8VAU;FMS*2D[("HO"B`@("`@("`@("`@("1N8VAU;FMS(#T@;6EN
M*#<L("1X;&EM("T@)'AO9F8L("1Y;&EM("T@)'EO9F8I("L@,3L*("`@("`@
M("`@("`@;&ES="@D;&-S+"`D<V5P<RD*("`@("`@("`@("`@("`@(#T@)'1H
M:7,M/E]D:6%G*"1X;V9F+"`D>&QI;2P@)'EO9F8L("1Y;&EM+"`D;F-H=6YK
M<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&QC<R`]/2`P*2!["B`@("`@
M("`@("`@("\J(%@@86YD(%D@<V5Q=65N8V5S(&AA=F4@;F\@8V]M;6]N('-U
M8G-E<75E;F-E.B!M87)K(&%L;`H@("`@("`@("`@("`@*B!C:&%N9V5D+B`J
M+PH@("`@("`@("`@("!W:&EL92`H)'EO9F8@/"`D>6QI;2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/GEC:&%N9V5D6R1T:&ES+3YY:6YD6R1Y;V9F*RM=
M72`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@=VAI;&4@*"1X;V9F
M(#P@)'AL:6TI('L*("`@("`@("`@("`@("`@("1T:&ES+3YX8VAA;F=E9%LD
M=&AI<RT^>&EN9%LD>&]F9BLK75T@/2`Q.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@57-E('1H92!P87)T:71I;VYS
M('1O('-P;&ET('1H:7,@<')O8FQE;2!I;G1O('-U8G!R;V)L96US+B`J+PH@
M("`@("`@("`@("!R97-E="@D<V5P<RD["B`@("`@("`@("`@("1P=#$@/2`D
M<V5P<ULP73L*("`@("`@("`@("`@=VAI;&4@*"1P=#(@/2!N97AT*"1S97!S
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP87)E<V5Q("@D<'0Q
M6S!=+"`D<'0R6S!=+"`D<'0Q6S%=+"`D<'0R6S%=*3L*("`@("`@("`@("`@
M("`@("1P=#$@/2`D<'0R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@061J=7-T<R!I;G-E<G1S+V1E;&5T97,@;V8@
M:61E;G1I8V%L(&QI;F5S('1O(&IO:6X@8VAA;F=E<R!A<R!M=6-H(&%S"B`@
M("`@*B!P;W-S:6)L92X*("`@("`J"B`@("`@*B!792!D;R!S;VUE=&AI;F<@
M=VAE;B!A(')U;B!O9B!C:&%N9V5D(&QI;F5S(&EN8VQU9&4@82!L:6YE(&%T
M(&]N92!E;F0*("`@("`J(&%N9"!H87,@86X@97AC;'5D960L(&ED96YT:6-A
M;"!L:6YE(&%T('1H92!O=&AE<BX@(%=E(&%R92!F<F5E('1O"B`@("`@*B!C
M:&]O<V4@=VAI8V@@:61E;G1I8V%L(&QI;F4@:7,@:6YC;'5D960N("!@8V]M
M<&%R97-E<2<@=7-U86QL>2!C:&]O<V5S"B`@("`@*B!T:&4@;VYE(&%T('1H
M92!B96=I;FYI;F<L(&)U="!U<W5A;&QY(&ET(&ES(&-L96%N97(@=&\@8V]N
M<VED97(@=&AE"B`@("`@*B!F;VQL;W=I;F<@:61E;G1I8V%L(&QI;F4@=&\@
M8F4@=&AE(")C:&%N9V4B+@H@("`@("H*("`@("`J(%1H:7,@:7,@97AT<F%C
M=&5D('9E<F)A=&EM(&9R;VT@86YA;'EZ92YC("A'3E4@9&EF9G5T:6QS+3(N
M-RDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:&EF=$)O=6YD87)I97,H)&QI
M;F5S+"`F)&-H86YG960L("1O=&AE<E]C:&%N9V5D*0H@("`@>PH@("`@("`@
M("1I(#T@,#L*("`@("`@("`D:B`](#`["@H@("`@("`@(&%S<V5R="@G8V]U
M;G0H)&QI;F5S*2`]/2!C;W5N="@D8VAA;F=E9"DG*3L*("`@("`@("`D;&5N
M(#T@8V]U;G0H)&QI;F5S*3L*("`@("`@("`D;W1H97)?;&5N(#T@8V]U;G0H
M)&]T:&5R7V-H86YG960I.PH*("`@("`@("!W:&EL92`H,2D@>PH@("`@("`@
M("`@("`O*B!38V%N(&9O<G=A<F0@=&\@9FEN9"!T:&4@8F5G:6YN:6YG(&]F
M(&%N;W1H97(@<G5N(&]F"B`@("`@("`@("`@("`J(&-H86YG97,N($%L<V\@
M:V5E<"!T<F%C:R!O9B!T:&4@8V]R<F5S<&]N9&EN9R!P;VEN="!I;B!T:&4*
M("`@("`@("`@("`@("H@;W1H97(@9FEL92X*("`@("`@("`@("`@("H*("`@
M("`@("`@("`@("H@5&AR;W5G:&]U="!T:&ES(&-O9&4L("1I(&%N9"`D:B!A
M<F4@861J=7-T960@=&]G971H97(@<V\@=&AA=`H@("`@("`@("`@("`@*B!T
M:&4@9FER<W0@)&D@96QE;65N=',@;V8@)&-H86YG960@86YD('1H92!F:7)S
M="`D:B!E;&5M96YT<R!O9@H@("`@("`@("`@("`@*B`D;W1H97)?8VAA;F=E
M9"!B;W1H(&-O;G1A:6X@=&AE('-A;64@;G5M8F5R(&]F('IE<F]S("AU;F-H
M86YG960*("`@("`@("`@("`@("H@;&EN97,I+@H@("`@("`@("`@("`@*@H@
M("`@("`@("`@("`@*B!&=7)T:&5R;6]R92P@)&H@:7,@86QW87ES(&ME<'0@
M<V\@=&AA="`D:B`]/2`D;W1H97)?;&5N(&]R"B`@("`@("`@("`@("`J("1O
M=&AE<E]C:&%N9V5D6R1J72`]/2!F86QS92X@*B\*("`@("`@("`@("`@=VAI
M;&4@*"1J(#P@)&]T:&5R7VQE;B`F)B`D;W1H97)?8VAA;F=E9%LD:ETI('L*
M("`@("`@("`@("`@("`@("1J*RL["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@('=H:6QE("@D:2`\("1L96X@)B8@(2`D8VAA;F=E9%LD:5TI('L*("`@
M("`@("`@("`@("`@(&%S<V5R="@G)&H@/"`D;W1H97)?;&5N("8F("$@)&]T
M:&5R7V-H86YG961;)&I=)RD["B`@("`@("`@("`@("`@("`D:2LK.R`D:BLK
M.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1J(#P@)&]T:&5R7VQE;B`F)B`D
M;W1H97)?8VAA;F=E9%LD:ETI('L*("`@("`@("`@("`@("`@("`@("`D:BLK
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H)&D@/3T@)&QE;BD@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%R="`]("1I.PH*("`@("`@
M("`@("`@+RH@1FEN9"!T:&4@96YD(&]F('1H:7,@<G5N(&]F(&-H86YG97,N
M("HO"B`@("`@("`@("`@('=H:6QE("@K*R1I(#P@)&QE;B`F)B`D8VAA;F=E
M9%LD:5TI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!D;R!["B`@("`@("`@("`@("`@("`O*B!296-O
M<F0@=&AE(&QE;F=T:"!O9B!T:&ES(')U;B!O9B!C:&%N9V5S+"!S;R!T:&%T
M('=E(&-A;@H@("`@("`@("`@("`@("`@("H@;&%T97(@9&5T97)M:6YE('=H
M971H97(@=&AE(')U;B!H87,@9W)O=VXN("HO"B`@("`@("`@("`@("`@("`D
M<G5N;&5N9W1H(#T@)&D@+2`D<W1A<G0["@H@("`@("`@("`@("`@("`@+RH@
M36]V92!T:&4@8VAA;F=E9"!R96=I;VX@8F%C:RP@<V\@;&]N9R!A<R!T:&4@
M<')E=FEO=7,*("`@("`@("`@("`@("`@("`J('5N8VAA;F=E9"!L:6YE(&UA
M=&-H97,@=&AE(&QA<W0@8VAA;F=E9"!O;F4N("!4:&ES(&UE<F=E<PH@("`@
M("`@("`@("`@("`@("H@=VET:"!P<F5V:6]U<R!C:&%N9V5D(')E9VEO;G,N
M("HO"B`@("`@("`@("`@("`@("!W:&EL92`H)'-T87)T(#X@,"`F)B`D;&EN
M97-;)'-T87)T("T@,5T@/3T@)&QI;F5S6R1I("T@,5TI('L*("`@("`@("`@
M("`@("`@("`@("`D8VAA;F=E9%LM+21S=&%R=%T@/2`Q.PH@("`@("`@("`@
M("`@("`@("`@("1C:&%N9V5D6RTM)&E=(#T@9F%L<V4["B`@("`@("`@("`@
M("`@("`@("`@=VAI;&4@*"1S=&%R="`^(#`@)B8@)&-H86YG961;)'-T87)T
M("T@,5TI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-T87)T+2T["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&%S<V5R
M="@G)&H@/B`P)RD["B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1O=&AE
M<E]C:&%N9V5D6RTM)&I=*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!A<W-E<G0H)R1J(#X](#`@)B8@(21O=&AE<E]C:&%N9V5D6R1J72<I
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J(%-E="!#
M3U)215-03TY$24Y'('1O('1H92!E;F0@;V8@=&AE(&-H86YG960@<G5N+"!A
M="!T:&4*("`@("`@("`@("`@("`@("`J(&QA<W0@<&]I;G0@=VAE<F4@:70@
M8V]R<F5S<&]N9',@=&\@82!C:&%N9V5D(')U;B!I;B!T:&4*("`@("`@("`@
M("`@("`@("`J(&]T:&5R(&9I;&4N($-/4E)%4U!/3D1)3D<@/3T@3$5.(&UE
M86YS(&YO('-U8V@@<&]I;G0@:&%S"B`@("`@("`@("`@("`@("`@*B!B965N
M(&9O=6YD+B`J+PH@("`@("`@("`@("`@("`@)&-O<G)E<W!O;F1I;F<@/2`D
M:B`\("1O=&AE<E]L96X@/R`D:2`Z("1L96X["@H@("`@("`@("`@("`@("`@
M+RH@36]V92!T:&4@8VAA;F=E9"!R96=I;VX@9F]R=V%R9"P@<V\@;&]N9R!A
M<R!T:&4@9FER<W0*("`@("`@("`@("`@("`@("`J(&-H86YG960@;&EN92!M
M871C:&5S('1H92!F;VQL;W=I;F<@=6YC:&%N9V5D(&]N92X@(%1H:7,*("`@
M("`@("`@("`@("`@("`J(&UE<F=E<R!W:71H(&9O;&QO=VEN9R!C:&%N9V5D
M(')E9VEO;G,N("!$;R!T:&ES('-E8V]N9"P@<V\*("`@("`@("`@("`@("`@
M("`J('1H870@:68@=&AE<F4@87)E(&YO(&UE<F=E<RP@=&AE(&-H86YG960@
M<F5G:6]N(&ES(&UO=F5D"B`@("`@("`@("`@("`@("`@*B!F;W)W87)D(&%S
M(&9A<B!A<R!P;W-S:6)L92X@*B\*("`@("`@("`@("`@("`@('=H:6QE("@D
M:2`\("1L96X@)B8@)&QI;F5S6R1S=&%R=%T@/3T@)&QI;F5S6R1I72D@>PH@
M("`@("`@("`@("`@("`@("`@("1C:&%N9V5D6R1S=&%R="LK72`](&9A;'-E
M.PH@("`@("`@("`@("`@("`@("`@("1C:&%N9V5D6R1I*RM=(#T@,3L*("`@
M("`@("`@("`@("`@("`@("!W:&EL92`H)&D@/"`D;&5N("8F("1C:&%N9V5D
M6R1I72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@87-S97)T*"<D
M:B`\("1O=&AE<E]L96X@)B8@(2`D;W1H97)?8VAA;F=E9%LD:ETG*3L*("`@
M("`@("`@("`@("`@("`@("`D:BLK.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D:B`\("1O=&AE<E]L96X@)B8@)&]T:&5R7V-H86YG961;)&I=*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1C;W)R97-P;VYD:6YG(#T@)&D["B`@
M("`@("`@("`@("`@("`@("`@("`@('=H:6QE("@D:B`\("1O=&AE<E]L96X@
M)B8@)&]T:&5R7V-H86YG961;)&I=*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:BLK.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]('=H:6QE("@D<G5N;&5N9W1H("$]("1I("T@)'-T87)T*3L*"B`@("`@
M("`@("`@("\J($EF('!O<W-I8FQE+"!M;W9E('1H92!F=6QL>2UM97)G960@
M<G5N(&]F(&-H86YG97,@8F%C:R!T;R!A"B`@("`@("`@("`@("`J(&-O<G)E
M<W!O;F1I;F<@<G5N(&EN('1H92!O=&AE<B!F:6QE+B`J+PH@("`@("`@("`@
M("!W:&EL92`H)&-O<G)E<W!O;F1I;F<@/"`D:2D@>PH@("`@("`@("`@("`@
M("`@)&-H86YG961;+2TD<W1A<G1=(#T@,3L*("`@("`@("`@("`@("`@("1C
M:&%N9V5D6RTM)&E=(#T@,#L*("`@("`@("`@("`@("`@(&%S<V5R="@G)&H@
M/B`P)RD["B`@("`@("`@("`@("`@("!W:&EL92`H)&]T:&5R7V-H86YG961;
M+2TD:ETI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&%S<V5R="@G)&H@/CT@,"`F
M)B`A)&]T:&5R7V-H86YG961;)&I=)RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A
M=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO
M<F<^"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F
M7T]P('L*"B`@("!V87(@)&]R:6<["B`@("!V87(@)&9I;F%L.PH*("`@(&9U
M;F-T:6]N(')E=F5R<V4H*0H@("`@>PH@("`@("`@('1R:6=G97)?97)R;W(H
M)T%B<W1R86-T(&UE=&AO9"<L($5?55-%4E]%4E)/4BD["B`@("!]"@H@("`@
M9G5N8W1I;VX@;F]R:6<H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M;W)I9R`_(&-O=6YT*"1T:&ES+3YO<FEG*2`Z(#`["B`@("!]"@H@("`@9G5N
M8W1I;VX@;F9I;F%L*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F9I
M;F%L(#\@8V]U;G0H)'1H:7,M/F9I;F%L*2`Z(#`["B`@("!]"@I]"@HO*BH*
M("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N
M($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J"B`J($!A8V-E<W,@
M<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F7T]P7V-O<'D@97AT96YD<R!4
M97AT7T1I9F9?3W`@>PH*("`@(&9U;F-T:6]N(%1E>'1?1&EF9E]/<%]C;W!Y
M*"1O<FEG+"`D9FEN86P@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1F:6YA;"DI('L*("`@("`@("`@("`@)&9I;F%L(#T@)&]R:6<[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YO<FEG(#T@)&]R:6<["B`@("`@
M("`@)'1H:7,M/F9I;F%L(#T@)&9I;F%L.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9R979E<G-E*"D*("`@('L*("`@("`@("`D<F5V97)S92`]("9N97<@5&5X
M=%]$:69F7T]P7V-O<'DH)'1H:7,M/F9I;F%L+"`D=&AI<RT^;W)I9RD["B`@
M("`@("`@<F5T=7)N("1R979E<G-E.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K
M86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI
M(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*@H@*B!`86-C97-S('!R:79A=&4*
M("HO"F-L87-S(%1E>'1?1&EF9E]/<%]D96QE=&4@97AT96YD<R!497AT7T1I
M9F9?3W`@>PH*("`@(&9U;F-T:6]N(%1E>'1?1&EF9E]/<%]D96QE=&4H)&QI
M;F5S*0H@("`@>PH@("`@("`@("1T:&ES+3YO<FEG(#T@)&QI;F5S.PH@("`@
M("`@("1T:&ES+3YF:6YA;"`](&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9R979E<G-E*"D*("`@('L*("`@("`@("`D<F5V97)S92`]("9N97<@5&5X
M=%]$:69F7T]P7V%D9"@D=&AI<RT^;W)I9RD["B`@("`@("`@<F5T=7)N("1R
M979E<G-E.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%1E>'1?1&EF9@H@
M*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I
M:VDN;W)G/@H@*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?
M1&EF9E]/<%]A9&0@97AT96YD<R!497AT7T1I9F9?3W`@>PH*("`@(&9U;F-T
M:6]N(%1E>'1?1&EF9E]/<%]A9&0H)&QI;F5S*0H@("`@>PH@("`@("`@("1T
M:&ES+3YF:6YA;"`]("1L:6YE<SL*("`@("`@("`D=&AI<RT^;W)I9R`](&9A
M;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N("9R979E<G-E*"D*("`@('L*("`@
M("`@("`D<F5V97)S92`]("9N97<@5&5X=%]$:69F7T]P7V1E;&5T92@D=&AI
M<RT^9FEN86PI.PH@("`@("`@(')E='5R;B`D<F5V97)S93L*("`@('T*"GT*
M"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O9F9R
M97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@0&%C
M8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F9?3W!?8VAA;F=E(&5X
M=&5N9',@5&5X=%]$:69F7T]P('L*"B`@("!F=6YC=&EO;B!497AT7T1I9F9?
M3W!?8VAA;F=E*"1O<FEG+"`D9FEN86PI"B`@("!["B`@("`@("`@)'1H:7,M
M/F]R:6<@/2`D;W)I9SL*("`@("`@("`D=&AI<RT^9FEN86P@/2`D9FEN86P[
M"B`@("!]"@H@("`@9G5N8W1I;VX@)G)E=F5R<V4H*0H@("`@>PH@("`@("`@
M("1R979E<G-E(#T@)FYE=R!497AT7T1I9F9?3W!?8VAA;F=E*"1T:&ES+3YF
M:6YA;"P@)'1H:7,M/F]R:6<I.PH@("`@("`@(')E='5R;B`D<F5V97)S93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+U1E>'0O<F535"YP:'``````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-S$W,@`Q,#0Q-S,V,C<W-@`P,3<U,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!497AT7W)E4U0Z.B!C;&%S<R!R97!R97-E;G1S(&$@<&%R
M<V4@;F]D92!O9B!A(')E4W1R=6-T=7)E9%1E>'0*("H@9&]C=6UE;G0@86YD
M('!R;W9I9&5S(&%N($%022!F;W(@<&%R<VEN9R!R95-T<G5C='5R961497AT
M(&1O8W5M96YT<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]R95-4
M+W)E4U0N<&AP+'8@,2XU+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI
M8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O
M;3X*("H@0'!A8VMA9V4@5&5X=%]R95-4"B`J+PIC;&%S<R!497AT7W)E4U0@
M>PH*("`@("\J*@H@("`@("H@5&AE('!A<G-E(&YO9&4@='EP92X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W1Y<&4["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A
M>2!O9B!T:&4@<&%R<V4@;F]D92=S(&-H:6QD<F5N+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?8VAI;&1R96X@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M02!H87-H(&]F('!A<G-E(&YO9&4@<')O<&5R=&EE<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?<')O<&5R=&EE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("!4:&ES(&ES('1H92!N;V1E('1Y<&4N("!4:&4@9&5F875L="!I<R`G
M1&]C=6UE;G0G+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7W)E4U0H)'1Y
M<&4@/2`G1&]C=6UE;G0G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?='EP92`]
M("1T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@07!P96YD<R!A(&-H:6QD
M('!A<G-E(&YO9&4@=&\@=&AI<R!P87)S92!N;V1E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F=\5&5X=%]R95-4("8D8VAI;&0@(%1H:7,@:7,@=&AE
M('-T<FEN9R!O<B!O8FIE8W0@8VAI;&0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1O(&%P<&5N9"!T;R!T:&ES('!A<G-E(&YO
M9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<&5N9$-H:6QD*"8D8VAI;&0I
M"B`@("!["B`@("`@("`@)&X@/2!C;W5N="@D=&AI<RT^7V-H:6QD<F5N*3L*
M("`@("`@("!I9B`H:7-?<W1R:6YG*"1C:&EL9"D@)B8@)&X@/B`P("8F(&ES
M7W-T<FEN9R@D=&AI<RT^7V-H:6QD<F5N6R1N("T@,5TI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?8VAI;&1R96Y;)&X@+2`Q72`N/2`D8VAI;&0["B`@("`@
M("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D8VAI;&0I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?8VAI;&1R96Y;72`]("1C:&EL9#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7V-H:6QD<F5N6UT@/2`F)&-H:6QD.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE('9A;'5E
M(&]F(&$@<&%R<V4@;F]D92!P<F]P97)T>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@5&AE('!R;W!E<G1Y)W,@;F%M92X*("`@("`J
M($!P87)A;2!S=')I;F<@)'9A;'5E("!4:&4@<')O<&5R='DG<R!V86QU92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4')O<&5R='DH)&YA;64L("1V86QU
M92D*("`@('L*("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97-;)&YA;65=(#T@
M)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!V
M86QU92!O9B!A('!A<G-E(&YO9&4@<')O<&5R='DN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE('!R;W!E<G1Y)W,@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R;W!E<G1Y)W,@=F%L
M=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R;W!E<G1Y*"1N86UE*0H@
M("`@>PH@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D;F%M92P@)'1H
M:7,M/E]P<F]P97)T:65S*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')O<&5R=&EE<ULD
M;F%M95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$=6UP<R!T:&ES('!A<G-E
M(&YO9&4@86YD(&ET<R!C:&EL9')E;BX*("`@("`J(%1H:7,@;65T:&]D(&ES
M(&9O<B!D96)U9V=I;F<@<'5R<&]S97,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&QE=F5L("!4:&ES(&ES('1H92!I;F1E;G0@;&5V96P@;V8@
M=&AI<R!P87)S92!N;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D=6UP*"1L
M979E;"`](#`I"B`@("!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QE
M=F5L.R`D:2LK*2!["B`@("`@("`@("`@(&5C:&\@)R`@)SL*("`@("`@("!]
M"B`@("`@("`@96-H;R`D=&AI<RT^7W1Y<&4L("<Z.B<["B`@("`@("`@:W-O
M<G0H)'1H:7,M/E]P<F]P97)T:65S*3L*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7W!R;W!E<G1I97,@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@(&5C:&\@)R`G+"`D;F%M92P@)STB)RP@<')E9U]R97!L86-E*"<O6R)<
M7%Q<72\G+"`G7%PD,2<L("1V86QU92DL"B`@("`@("`@("`@("`@("`G(B<[
M"B`@("`@("`@?0H@("`@("`@(&5C:&\@(EQN(CL*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7V-H:6QD<F5N(&%S("1C:&EL9"D@>PH@("`@("`@("`@("!I
M9B`H:7-?<W1R:6YG*"1C:&EL9"DI('L*("`@("`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("@D;&5V96P@*R`Q*3L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@(&5C:&\@)R`@)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5C:&\@)R(G+"!P<F5G7W)E<&QA8V4H)R];(EQ<7%Q=+R<L
M("=<7"0Q)RP@)&-H:6QD*2P@(EPB7&XB.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&-H:6QD+3YD=6UP*"1L979E;"`K(#$I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4&%R<V5S(&$@<F53=')U8W1U<F5D5&5X="!D;V-U;65N="X*("`@("`J"B`@
M("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="`@5&AI<R!I<R!T:&4@=&5X="!O9B!T:&4@9&]C=6UE;G0@=V4@=V%N="!T
M;R!P87)S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1E>'1?<F535"`@5&AE
M('!A<G-E9"!D;V-U;65N="!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9P87)S92@D=&5X="D*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W)E4U0O4&%R
M<V5R+G!H<"<["B`@("`@("`@)'!A<G-E<B`]("9N97<@5&5X=%]R95-47U!A
M<G-E<B@I.PH@("`@("`@(')E='5R;B`D<&%R<V5R+3YP87)S92@D=&5X="D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9C,N<&AP````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-3(V,@`Q,#0Q
M-S,V,C<W-@`P,3<U-S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G5&5X="]$:69F+G!H
M<"<["@HO*BH*("H@02!C;&%S<R!F;W(@8V]M<'5T:6YG('1H<F5E('=A>2!D
M:69F<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I9F8S
M+G!H<"QV(#$N,BXQ,"XS(#(P,#4O,3`O,3@@,3$Z,#$Z,S$@:F%N($5X<"`D
M"B`J"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E
M>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*B\*8VQA<W,@
M5&5X=%]$:69F,R!E>'1E;F1S(%1E>'1?1&EF9B!["@H@("`@+RHJ"B`@("`@
M*B!#;VYF;&EC="!C;W5N=&5R+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]C;VYF;&EC=&EN9T)L;V-K<R`](#`["@H@
M("`@+RHJ"B`@("`@*B!#;VUP=71E<R!D:69F(&)E='=E96X@,R!S97%U96YC
M97,@;V8@<W1R:6YG<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&]R
M:6<@("`@5&AE(&]R:6=I;F%L(&QI;F5S('1O('5S92X*("`@("`J($!P87)A
M;2!A<G)A>2`D9FEN86PQ("!4:&4@9FER<W0@=F5R<VEO;B!T;R!C;VUP87)E
M('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:6YA;#(@(%1H92!S96-O;F0@
M=F5R<VEO;B!T;R!C;VUP87)E('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!4
M97AT7T1I9F8S*"1O<FEG+"`D9FEN86PQ+"`D9FEN86PR*0H@("`@>PH@("`@
M("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*"=X9&EF9B<I*2!["B`@("`@("`@
M("`@("1E;F=I;F4@/2`F;F5W(%1E>'1?1&EF9E]%;F=I;F5?>&1I9F8H*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D96YG:6YE(#T@)FYE=R!4
M97AT7T1I9F9?16YG:6YE7VYA=&EV92@I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]E9&ET<R`]("1T:&ES+3Y?9&EF9C,H)&5N9VEN92T^9&EF9B@D
M;W)I9RP@)&9I;F%L,2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N9VEN92T^9&EF9B@D;W)I9RP@)&9I;F%L,BDI.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&UE<F=E9$]U='!U="@D;&%B96PQ(#T@9F%L<V4L
M("1L86)E;#(@/2!F86QS92D*("`@('L*("`@("`@("`D;&EN97,@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?961I=',@87,@)&5D:70I
M('L*("`@("`@("`@("`@:68@*"1E9&ET+3YI<T-O;F9L:6-T*"DI('L*("`@
M("`@("`@("`@("`@("\J($9)6$U%.B!T:&ES('-H;W5L9"!P<F]B86)L>2!B
M92!M;W9E9"!S;VUE=VAE<F4@96QS92X@*B\*("`@("`@("`@("`@("`@("1L
M:6YE<R`](&%R<F%Y7VUE<F=E*"1L:6YE<RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"<\/#P\/#P\)R`N("@D;&%B96PQ
M(#\@)R`G("X@)&QA8F5L,2`Z("<G*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D961I="T^9FEN86PQ+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH(CT]/3T]/3TB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E9&ET+3YF:6YA
M;#(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G/CX^/CX^/B<@+B`H)&QA8F5L,B`_("<@)R`N("1L86)E;#(@.B`G)RDI
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N9FQI8W1I;F=";&]C:W,K
M*SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L:6YE
M<R`](&%R<F%Y7VUE<F=E*"1L:6YE<RP@)&5D:70M/FUE<F=E9"@I*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L:6YE<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9&EF9C,H)&5D:71S,2P@)&5D:71S,BD*("`@('L*
M("`@("`@("`D961I=',@/2!A<G)A>2@I.PH@("`@("`@("1B8B`]("9N97<@
M5&5X=%]$:69F,U]";&]C:T)U:6QD97(H*3L*"B`@("`@("`@)&4Q(#T@8W5R
M<F5N="@D961I=',Q*3L*("`@("`@("`D93(@/2!C=7)R96YT*"1E9&ET<S(I
M.PH@("`@("`@('=H:6QE("@D93$@?'P@)&4R*2!["B`@("`@("`@("`@(&EF
M("@D93$@)B8@)&4R("8F(&ES7V$H)&4Q+"`G5&5X=%]$:69F7T]P7V-O<'DG
M*2`F)B!I<U]A*"1E,BP@)U1E>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@
M("`@("`@("`@("\J(%=E(&AA=F4@8V]P>2!B;&]C:W,@9G)O;2!B;W1H(&1I
M9F9S+B!4:&ES(&ES('1H92`H;VYL>2D*("`@("`@("`@("`@("`@("`J('1I
M;64@=V4@=V%N="!T;R!E;6ET(&$@9&EF9C,@8V]P>2!B;&]C:RX@($9L=7-H
M(&-U<G)E;G0*("`@("`@("`@("`@("`@("`J(&1I9F8S(&1I9F8@8FQO8VLL
M(&EF(&%N>2X@*B\*("`@("`@("`@("`@("`@(&EF("@D961I="`]("1B8BT^
M9FEN:7-H*"DI('L*("`@("`@("`@("`@("`@("`@("`D961I='-;72`]("1E
M9&ET.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1N8V]P
M>2`](&UI;B@D93$M/FYO<FEG*"DL("1E,BT^;F]R:6<H*2D["B`@("`@("`@
M("`@("`@("!A<W-E<G0H)&YC;W!Y(#X@,"D["B`@("`@("`@("`@("`@("`D
M961I='-;72`]("9N97<@5&5X=%]$:69F,U]/<%]C;W!Y*&%R<F%Y7W-L:6-E
M*"1E,2T^;W)I9RP@,"P@)&YC;W!Y*2D["@H@("`@("`@("`@("`@("`@:68@
M*"1E,2T^;F]R:6<H*2`^("1N8V]P>2D@>PH@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y7W-P;&EC92@D93$M/F]R:6<L(#`L("1N8V]P>2D["B`@("`@("`@
M("`@("`@("`@("`@87)R87E?<W!L:6-E*"1E,2T^9FEN86PL(#`L("1N8V]P
M>2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1E,2`](&YE>'0H)&5D:71S,2D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@:68@*"1E,BT^;F]R:6<H*2`^("1N8V]P>2D@>PH@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D93(M/F]R:6<L(#`L
M("1N8V]P>2D["B`@("`@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E*"1E
M,BT^9FEN86PL(#`L("1N8V]P>2D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1E,B`](&YE>'0H)&5D:71S,BD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H)&4Q("8F("1E,BD@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D93$M/F]R:6<@)B8@)&4R+3YO<FEG*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1N;W)I9R`](&UI;B@D93$M/FYO<FEG*"DL("1E,BT^;F]R
M:6<H*2D["B`@("`@("`@("`@("`@("`@("`@("`@("1O<FEG(#T@87)R87E?
M<W!L:6-E*"1E,2T^;W)I9RP@,"P@)&YO<FEG*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87E?<W!L:6-E*"1E,BT^;W)I9RP@,"P@)&YO<FEG*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&)B+3YI;G!U="@D;W)I9RD["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D93$L("=497AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1B8BT^;W5T,2AA<G)A>5]S<&QI8V4H)&4Q+3YF:6YA
M;"P@,"P@)&YO<FEG*2D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?82@D93(L("=497AT7T1I9F9?3W!?8V]P
M>2<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1B8BT^;W5T,BAA<G)A
M>5]S<&QI8V4H)&4R+3YF:6YA;"P@,"P@)&YO<FEG*2D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M(&EF("@D93$@)B8@(2`D93$M/F]R:6<I('L*("`@("`@("`@("`@("`@("`@
M("`D8F(M/F]U=#$H)&4Q+3YF:6YA;"D["B`@("`@("`@("`@("`@("`@("`@
M)&4Q(#T@;F5X="@D961I=',Q*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("@D93(@)B8@(2`D93(M/F]R:6<I('L*("`@("`@("`@
M("`@("`@("`@("`D8F(M/F]U=#(H)&4R+3YF:6YA;"D["B`@("`@("`@("`@
M("`@("`@("`@)&4R(#T@;F5X="@D961I=',R*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1E9&ET
M(#T@)&)B+3YF:6YI<V@H*2D@>PH@("`@("`@("`@("`D961I='-;72`]("1E
M9&ET.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E9&ET<SL*("`@('T*
M"GT*"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O
M9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@
M0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F8S7T]P('L*"B`@
M("!F=6YC=&EO;B!497AT7T1I9F8S7T]P*"1O<FEG(#T@9F%L<V4L("1F:6YA
M;#$@/2!F86QS92P@)&9I;F%L,B`](&9A;'-E*0H@("`@>PH@("`@("`@("1T
M:&ES+3YO<FEG(#T@)&]R:6<@/R`D;W)I9R`Z(&%R<F%Y*"D["B`@("`@("`@
M)'1H:7,M/F9I;F%L,2`]("1F:6YA;#$@/R`D9FEN86PQ(#H@87)R87DH*3L*
M("`@("`@("`D=&AI<RT^9FEN86PR(#T@)&9I;F%L,B`_("1F:6YA;#(@.B!A
M<G)A>2@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&UE<F=E9"@I"B`@("!["B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VUE<F=E9"DI('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YF:6YA;#$@/3T]("1T:&ES+3YF:6YA;#(I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;65R9V5D(#T@)B1T:&ES+3YF:6YA;#$[
M"B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^9FEN86PQ(#T]/2`D=&AI
M<RT^;W)I9RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M97)G960@/2`F
M)'1H:7,M/F9I;F%L,CL*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YF
M:6YA;#(@/3T]("1T:&ES+3YO<FEG*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VUE<F=E9"`]("8D=&AI<RT^9FEN86PQ.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M97)G960@/2!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?;65R9V5D.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0V]N9FQI8W0H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;65R9V5D*"D@/3T](&9A;'-E
M.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T
M:&]R("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G
M/@H@*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9C-?
M3W!?8V]P>2!E>'1E;F1S(%1E>'1?1&EF9C-?3W`@>PH*("`@(&9U;F-T:6]N
M(%1E>'1?1&EF9C-?3W!?0V]P>2@D;&EN97,@/2!F86QS92D*("`@('L*("`@
M("`@("`D=&AI<RT^;W)I9R`]("1L:6YE<R`_("1L:6YE<R`Z(&%R<F%Y*"D[
M"B`@("`@("`@)'1H:7,M/F9I;F%L,2`]("8D=&AI<RT^;W)I9SL*("`@("`@
M("`D=&AI<RT^9FEN86PR(#T@)B1T:&ES+3YO<FEG.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&UE<F=E9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YO
M<FEG.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0V]N9FQI8W0H*0H@("`@>PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G
M92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\
M9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@0&%C8V5S<R!P<FEV871E"B`J
M+PIC;&%S<R!497AT7T1I9F8S7T)L;V-K0G5I;&1E<B!["@H@("`@9G5N8W1I
M;VX@5&5X=%]$:69F,U]";&]C:T)U:6QD97(H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?:6YI="@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&EN<'5T*"1L:6YE
M<RD*("`@('L*("`@("`@("!I9B`H)&QI;F5S*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?87!P96YD*"1T:&ES+3YO<FEG+"`D;&EN97,I.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!O=70Q*"1L:6YE<RD*("`@('L*("`@("`@
M("!I9B`H)&QI;F5S*2!["B`@("`@("`@("`@("1T:&ES+3Y?87!P96YD*"1T
M:&ES+3YF:6YA;#$L("1L:6YE<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(&]U=#(H)&QI;F5S*0H@("`@>PH@("`@("`@(&EF("@D;&EN97,I
M('L*("`@("`@("`@("`@)'1H:7,M/E]A<'!E;F0H)'1H:7,M/F9I;F%L,BP@
M)&QI;F5S*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-%;7!T
M>2@I"B`@("!["B`@("`@("`@<F5T=7)N("$D=&AI<RT^;W)I9R`F)B`A)'1H
M:7,M/F9I;F%L,2`F)B`A)'1H:7,M/F9I;F%L,CL*("`@('T*"B`@("!F=6YC
M=&EO;B!F:6YI<V@H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:7-%;7!T
M>2@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D961I="`]("9N97<@5&5X=%]$:69F,U]/<"@D
M=&AI<RT^;W)I9RP@)'1H:7,M/F9I;F%L,2P@)'1H:7,M/F9I;F%L,BD["B`@
M("`@("`@("`@("1T:&ES+3Y?:6YI="@I.PH@("`@("`@("`@("!R971U<FX@
M)&5D:70["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]I;FET*"D*
M("`@('L*("`@("`@("`D=&AI<RT^;W)I9R`]("1T:&ES+3YF:6YA;#$@/2`D
M=&AI<RT^9FEN86PR(#T@87)R87DH*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M87!P96YD*"8D87)R87DL("1L:6YE<RD*("`@('L*("`@("`@("!A<G)A>5]S
M<&QI8V4H)&%R<F%Y+"!S:7IE;V8H)&%R<F%Y*2P@,"P@)&QI;F5S*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+U1E>'0O1FQO=V5D+G!H<```````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R-C<R,0`Q,#0Q-S,V,C<W-@`P,C`P-C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!497AT7T9L;W=E9#HZ(&-L87-S('!R;W9I9&5S(&-O
M;6UO;B!M971H;V1S(&9O<B!M86YI<'5L871I;F<@=&5X=`H@*B!U<VEN9R!T
M:&4@96YC;V1I;F<@9&5S8W)I8F5D(&EN(%)&0R`S-C<V("@G9FQO=V5D)R!T
M97AT*2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&;&]W960O1FQO
M=V5D+G!H<"QV(#$N,30N,3`N,3<@,C`P-B\P,R\Q,2`P.3HU,#HR,B!J86X@
M17AP("0*("H*("H@5&AI<R!C;&%S<R!I<R!B87-E9"!O;B!T:&4@5&5X=#HZ
M1FQO=V5D('!E<FP@;6]D=6QE("A697)S:6]N(#`N,30I(&9O=6YD"B`J(&EN
M('1H92!#4$%.('!E<FP@<F5P;W-I=&]R>2X@(%1H:7,@;6]D=6QE(&ES(')E
M;&5A<V5D('5N9&5R('1H92!097)L"B`J(&QI8V5N<V4L('=H:6-H(&ES(&-O
M;7!A=&EB;&4@=VET:"!T:&4@3$=03"X*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P,R!0:&EL:7`@36%K"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&;&]W
M960@>PH*("`@("\J*@H@("`@("H@5&AE(&UA>&EM=6T@;&5N9W1H('1H870@
M82!L:6YE(&ES(&%L;&]W960@=&\@8F4@*'5N;&5S<R!F86-E9"!W:71H"B`@
M("`@*B!W:71H(&$@=V]R9"!T:&%T(&ES('5N<F5A<V]N86)L>2!L;VYG*2X@
M5&AI<R!C;&%S<R!W:6QL(')E+7=R87`@80H@("`@("H@;&EN92!I9B!I="!E
M>&-E961S('1H:7,@;&5N9W1H+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]M87AL96YG=&@@/2`W.#L*"B`@("`O*BH*
M("`@("`J(%=H96X@=&AI<R!C;&%S<R!W<F%P<R!A(&QI;F4L('1H92!N97=L
M>2!C<F5A=&5D(&QI;F5S('=I;&P@8F4@<W!L:70*("`@("`J(&%T('1H:7,@
M;&5N9W1H+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]O<'1L96YG=&@@/2`W,CL*"B`@("`O*BH*("`@("`J(%1H92!T
M97AT('1O(&)E(&9O<FUA='1E9"X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]T97AT.PH*("`@("\J*@H@("`@("H@5&AE
M(&-A8VAE9"!O=71P=70@;V8@=&AE(&9O<FUA='1I;F<N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O=71P=70@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@5&AE(&-H87)A8W1E<B!S970@;V8@=&AE('1E
M>'0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?8VAA<G-E=#L*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&5X="!U<VEN
M9R!$96Q3<#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?9&5L<W`@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@
M(%1H92!T97AT('1O('!R;V-E<W,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M:&%R<V5T("!4:&4@8VAA<F%C=&5R('-E="!O9B`D=&5X="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@5&5X=%]&;&]W960H)'1E>'0L("1C:&%R<V5T(#T@;G5L
M;"D*("`@('L*("`@("`@("`D=&AI<RT^7W1E>'0@/2`D=&5X=#L*("`@("`@
M("`D=&AI<RT^7V-H87)S970@/2`D8VAA<G-E=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!T:&4@;6%X:6UU;2!L96YG=&@@;V8@82!L:6YE(&]F('1E
M>'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>"`@02!N97<@
M=F%L=64@9F]R("1?;6%X;&5N9W1H+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971-87A,96YG=&@H)&UA>"D*("`@('L*("`@("`@("`D=&AI<RT^7VUA>&QE
M;F=T:"`]("1M87@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&]P
M=&EM86P@;&5N9W1H(&]F(&$@;&EN92!O9B!T97AT+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1M87@@($$@;F5W('9A;'5E(&9O<B`D7V]P=&QE
M;F=T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T3&5N9W1H*"1O<'0I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]O<'1L96YG=&@@/2`D;W!T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T('=H971H97(@=&\@9F]R;6%T('1E<W0@
M=7-I;F<@1&5L4W`N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@
M("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1D96QS<"`@57-E($1E;%-P
M/PH@("`@("HO"B`@("!F=6YC=&EO;B!S971$96Q3<"@D9&5L<W`I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]D96QS<"`]("AB;V]L*2`D9&5L<W`["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2969O<FUA=',@=&AE(&EN<'5T('-T<FEN9RP@
M=VAE<F4@=&AE('-T<FEN9R!I<R`G9F]R;6%T/69L;W=E9"<@<&QA:6X*("`@
M("`J('1E>'0@87,@9&5S8W)I8F5D(&EN(%)&0R`R-C0V+@H@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N("1Q=6]T92`@061D(&QE=F5L(&]F('%U;W1I
M;F<@=&\@96%C:"!L:6YE/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=&5X="!C;VYV97)T960@=&\@4D9#(#(V-#8@)V9I>&5D)R!F;W)M
M870N"B`@("`@*B\*("`@(&9U;F-T:6]N('1O1FEX960H)'%U;W1E(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)'1X="`]("<G.PH*("`@("`@("`D=&AI<RT^
M7W)E9F]R;6%T*&9A;'-E+"`D<75O=&4I.PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?;W5T<'5T(&%S("1V86PI('L*("`@("`@("`@("`@)'1X="`N/2`D
M=F%L6R=T97AT)UT@+B`B7&XB.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M<G1R:6TH)'1X="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2969O<FUA=',@
M=&AE(&EN<'5T('-T<FEN9RP@86YD(')E='5R;G,@=&AE(&]U='!U="!I;B!A
M;B!A<G)A>2!F;W)M870*("`@("`J('=I=&@@<75O=&4@;&5V96P@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'%U;W1E("!!
M9&0@;&5V96P@;V8@<75O=&EN9R!T;R!E86-H(&QI;F4_"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@87)R87ES('=I=&@@=&AE
M(&9O;&QO=VEN9R!E;&5M96YT<SH*("`@("`J(#QP<F4^"B`@("`@*B`G;&5V
M96PG("T@5&AE('%U;W1E(&QE=F5L(&]F('1H92!C=7)R96YT(&QI;F4N"B`@
M("`@*B`G=&5X="<@("T@5&AE('1E>'0@9F]R('1H92!C=7)R96YT(&QI;F4N
M"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@=&]&:7AE9$%R
M<F%Y*"1Q=6]T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5F
M;W)M870H9F%L<V4L("1Q=6]T92D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5F;W)M871S('1H92!I
M;G!U="!S=')I;F<L('=H97)E('1H92!S=')I;F<@:7,@)V9O<FUA=#UF:7AE
M9"<@<&QA:6X*("`@("`J('1E>'0@87,@9&5S8W)I8F5D(&EN(%)&0R`R-C0V
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1Q=6]T92`@061D(&QE
M=F5L(&]F('%U;W1I;F<@=&\@96%C:"!L:6YE/PH@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@=&5X="!C;VYV97)T960@=&\@4D9#(#(V-#8@
M)V9L;W=E9"<@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T9L;W=E
M9"@D<75O=&4@/2!F86QS92D*("`@('L*("`@("`@("`D='AT(#T@)R<["@H@
M("`@("`@("1T:&ES+3Y?<F5F;W)M870H=')U92P@)'%U;W1E*3L*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7V]U='!U="!A<R`D=F%L*2!["B`@("`@("`@
M("`@("1T>'0@+CT@)'9A;%LG=&5X="==("X@(EQN(CL*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1T>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2969O
M<FUA=',@=&AE(&EN<'5T('-T<FEN9RP@=VAE<F4@=&AE('-T<FEN9R!I<R`G
M9F]R;6%T/69L;W=E9"<@<&QA:6X*("`@("`J('1E>'0@87,@9&5S8W)I8F5D
M(&EN(%)&0R`R-C0V+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1T;V9L;W=E9"`@0V]N=F5R
M="!T;R!F;&]W960_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<75O=&4@("`@
M($%D9"!L979E;"!O9B!Q=6]T:6YG('1O(&5A8V@@;&EN93\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@87)R87ES+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<F5F;W)M870H)'1O9FQO=V5D+"`D<75O=&4I"B`@
M("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?;W5T<'5T*2D@>PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7V]U='!U="`](&%R<F%Y*"D["B`@("`@("`@)'1E>'0@/2!E>'!L;V1E*")<
M;B(L("1T:&ES+3Y?=&5X="D["@H@("`@("`@("\J(%-E="!V87)I86)L97,@
M=7-E9"!I;B!R96=E>'!S+B`J+PH@("`@("`@("1D96QS<"`]("@D=&]F;&]W
M960@)B8@)'1H:7,M/E]D96QS<"D@/R`Q(#H@,#L*("`@("`@("`D;W!T(#T@
M)'1H:7,M/E]O<'1L96YG=&@@+2`Q("T@)&1E;'-P.PH*("`@("`@("`O*B!0
M<F]C97-S(&UE<W-A9V4@;&EN92!B>2!L:6YE+B`J+PH@("`@("`@(&1O('L*
M("`@("`@("`@("`@)&QI;F4@/2!A<G)A>5]S:&EF="@D=&5X="D["@H@("`@
M("`@("`@("`O*B!097(@4D9#(#(V-#8@6S0N,UTL('1H92`G57-E;F5T(%-I
M9VYA='5R92!#;VYV96YT:6]N)R!L:6YE"B`@("`@("`@("`@("`J("A$05-(
M($1!4T@@4U`I(&ES(&YO="!C;VYS:61E<F5D(&9L;W=E9"X@(%=A=&-H(&9O
M<B!T:&ES('=H96X*("`@("`@("`@("`@("H@9&5A;&EN9R!W:71H('!O=&5N
M=&EA;&QY(&9L;W=E9"!L:6YE<RX@*B\*"B`@("`@("`@("`@("\J(%1H92!N
M97AT('1H<F5E('-T97!S(&-O;64@9G)O;2!21D,@,C8T-B!;-"XR72X@*B\*
M("`@("`@("`@("`@+RH@4U1%4"`Q.B!$971E<FUI;F4@<75O=&4@;&5V96P@
M9F]R(&QI;F4N("HO"B`@("`@("`@("`@(&EF("@H)&YU;5]Q=6]T97,@/2`D
M=&AI<RT^7VYU;7%U;W1E<R@D;&EN92DI*2!["B`@("`@("`@("`@("`@("`D
M;&EN92`]('-U8G-T<B@D;&EN92P@)&YU;5]Q=6]T97,I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!/;FQY(&-O;6)I;F4@;&EN97,@:68@=V4@
M87)E(&-O;G9E<G1I;F<@=&\@9FQO=V5D(&]R(&EF('1H90H@("`@("`@("`@
M("`@*B!C=7)R96YT(&QI;F4@:7,@<75O=&5D+B`J+PH@("`@("`@("`@("!I
M9B`H(21T;V9L;W=E9"!\?"`D;G5M7W%U;W1E<RD@>PH@("`@("`@("`@("`@
M("`@+RH@4U1%4"`R.B!296UO=F4@<W!A8V4@<W1U9F9I;F<@9G)O;2!L:6YE
M+B`J+PH@("`@("`@("`@("`@("`@)&QI;F4@/2`D=&AI<RT^7W5N<W1U9F8H
M)&QI;F4I.PH*("`@("`@("`@("`@("`@("\J(%-415`@,SH@4VAO=6QD('=E
M(&EN=&5R<')E="!T:&ES(&QI;F4@87,@9FQO=V5D/PH@("`@("`@("`@("`@
M("`@("H@5VAI;&4@;&EN92!I<R!F;&]W960@*&YO="!E;7!T>2!A;F0@=&AE
M<F4@:7,@82!S<&%C90H@("`@("`@("`@("`@("`@("H@870@=&AE(&5N9"!O
M9B!T:&4@;&EN92DL(&%N9"!T:&5R92!I<R!A(&YE>'0@;&EN92P@86YD('1H
M90H@("`@("`@("`@("`@("`@("H@;F5X="!L:6YE(&AA<R!T:&4@<V%M92!Q
M=6]T92!D97!T:"P@861D('1O('1H92!C=7)R96YT"B`@("`@("`@("`@("`@
M("`@*B!L:6YE+B!!(&QI;F4@:7,@;F]T(&9L;W=E9"!I9B!I="!I<R!A('-I
M9VYA='5R92!L:6YE+B`J+PH@("`@("`@("`@("`@("`@=VAI;&4@*"%E;7!T
M>2@D;&EN92D@)B8*("`@("`@("`@("`@("`@("`@("`@("`H)&QI;F4@(3T@
M)RTM("<I("8F"B`@("`@("`@("`@("`@("`@("`@("`@*"1L:6YE>W-T<FQE
M;B@D;&EN92DM,7T@/3T@)R`G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("%E;7!T>2@D=&5X="D@)B8*("`@("`@("`@("`@("`@("`@("`@("`H)'1H
M:7,M/E]N=6UQ=6]T97,H)'1E>'1;,%TI(#T]("1N=6U?<75O=&5S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("\J($EF($1E;%-P(&ES('EE<R!A;F0@=&AI
M<R!I<R!F;&]W960@:6YP=70L('=E(&YE960@=&\*("`@("`@("`@("`@("`@
M("`@("`@*B!R96UO=F4@=&AE('1R86EL:6YG('-P86-E+B`J+PH@("`@("`@
M("`@("`@("`@("`@(&EF("@A)'1O9FQO=V5D("8F("1T:&ES+3Y?9&5L<W`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2!S=6)S='(H)&QI
M;F4L(#`L("TQ*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)&QI;F4@+CT@)'1H:7,M/E]U;G-T=69F*'-U8G-T<BAA<G)A
M>5]S:&EF="@D=&5X="DL("1N=6U?<75O=&5S*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($5N<W5R92!L:6YE
M(&ES(&9I>&5D+"!S:6YC92!W92!A;')E861Y(&IO:6YE9"!A;&P@9FQO=V5D
M"B`@("`@("`@("`@("`J(&QI;F5S+B!296UO=F4@86QL('1R86EL:6YG("<@
M)R!F<F]M('1H92!L:6YE+B`J+PH@("`@("`@("`@("!I9B`H)&QI;F4@(3T@
M)RTM("<I('L*("`@("`@("`@("`@("`@("1L:6YE(#T@<G1R:6TH)&QI;F4I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!);F-R96UE;G0@<75O
M=&4@9&5P=&@@:68@=V4G<F4@<75O=&EN9RX@*B\*("`@("`@("`@("`@:68@
M*"1Q=6]T92D@>PH@("`@("`@("`@("`@("`@)&YU;5]Q=6]T97,K*SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@5&AE('%U;W1E('!R969I>"!F
M;W(@=&AE(&QI;F4N("HO"B`@("`@("`@("`@("1Q=6]T97-T<B`]('-T<E]R
M97!E870H)SXG+"`D;G5M7W%U;W1E<RD["@H@("`@("`@("`@("!I9B`H96UP
M='DH)&QI;F4I*2!["B`@("`@("`@("`@("`@("`O*B!,:6YE(&ES(&5M<'1Y
M+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=71;72`](&%R<F%Y
M*"=T97AT)R`]/B`D<75O=&5S='(L("=L979E;"<@/3X@)&YU;5]Q=6]T97,I
M.PH@("`@("`@("`@("!](&5L<V5I9B`H96UP='DH)'1H:7,M/E]M87AL96YG
M=&@I('Q\("@H4W1R:6YG.CIL96YG=&@H)&QI;F4L("1T:&ES+3Y?8VAA<G-E
M="D@*R`D;G5M7W%U;W1E<RD@/#T@)'1H:7,M/E]M87AL96YG=&@I*2!["B`@
M("`@("`@("`@("`@("`O*B!,:6YE(&1O97,@;F]T(')E<75I<F4@<F5W<F%P
M<&EN9RX@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T6UT@/2!A
M<G)A>2@G=&5X="<@/3X@)'%U;W1E<W1R("X@)'1H:7,M/E]S='5F9B@D;&EN
M92P@)&YU;5]Q=6]T97,L("1T;V9L;W=E9"DL("=L979E;"<@/3X@)&YU;5]Q
M=6]T97,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&UI;B`]("1N=6U?<75O=&5S("L@,3L*"B`@("`@("`@("`@("`@("`O*B!2
M97=R87`@=&AI<R!P87)A9W)A<&@N("HO"B`@("`@("`@("`@("`@("!W:&EL
M92`H)&QI;F4I('L*("`@("`@("`@("`@("`@("`@("`O*B!3='5F9B!A;F0@
M<F4M<75O=&4@=&AE(&QI;F4N("HO"B`@("`@("`@("`@("`@("`@("`@)&QI
M;F4@/2`D<75O=&5S='(@+B`D=&AI<RT^7W-T=69F*"1L:6YE+"`D;G5M7W%U
M;W1E<RP@)'1O9FQO=V5D*3L*("`@("`@("`@("`@("`@("`@("`D;&EN95]L
M96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D;&EN92P@)'1H:7,M/E]C:&%R<V5T
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&QI;F5?;&5N9W1H(#P]("1T
M:&ES+3Y?;W!T;&5N9W1H*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J
M(%)E;6%I;FEN9R!S96-T:6]N(&]F(&QI;F4@:7,@<VAO<G0@96YO=6=H+B`J
M+PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U=%M=(#T@
M87)R87DH)W1E>'0G(#T^("1L:6YE+"`G;&5V96PG(#T^("1N=6U?<75O=&5S
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1M(#T@4W1R:6YG.CIR96=E>$UA=&-H*"1L
M:6YE+"!A<G)A>2@G7B@N>R<@+B`D;6EN("X@)RPG("X@)&]P="`N("=]*2`H
M+BHI)RP@)UXH+GLG("X@)&UI;B`N("<L)R`N("1T:&ES+3Y?;6%X;&5N9W1H
M("X@)WTI("@N*BDG+"`G7B@N>R<@+B`D;6EN("X@)RQ]*3\@*"XJ*2<I+"`D
M=&AI<RT^7V-H87)S970I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J
M(%=E(&YE960@=&\@=W)A<"!T97AT(&%T(&$@8V5R=&%I;B!N=6UB97(@;V8*
M("`@("`@("`@("`@("`@("`@("`@("`@("H@*F-H87)A8W1E<G,J+"!N;W0@
M82!C97)T86EN(&YU;6)E<B!O9B`J8GET97,J.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@*B!T:'5S('1H92!N965D(&9O<B!A(&UU;'1I8GET92!C87!A
M8FQE(')E9V5X+@H@("`@("`@("`@("`@("`@("`@("`@("`@*B!)9B!A(&UU
M;'1I8GET92!R96=E>"!I<VXG="!A=F%I;&%B;&4L('=E(&%R92!S='5C:PH@
M("`@("`@("`@("`@("`@("`@("`@("`@*B!W:71H('!R96=?;6%T8V@H*2`H
M=&AE(&9U;F-T:6]N('=I;&P@<W1I;&P@=V]R:R`M"B`@("`@("`@("`@("`@
M("`@("`@("`@("`J('=E('=I;&P@:G5S="!B92!L969T('=I=&@@<VAO<G1E
M<B!R;W=S('1H86X@97AP96-T960*("`@("`@("`@("`@("`@("`@("`@("`@
M("H@:68@;75L=&EB>71E(&-H87)A8W1E<G,@97AI<W0@:6X@=&AE(')O=RDN
M"B`@("`@("`@("`@("`@("`@("`@("`@("`J"B`@("`@("`@("`@("`@("`@
M("`@("`@("`J($%L9V]R:71H:6TZ"B`@("`@("`@("`@("`@("`@("`@("`@
M("`J(#$N(%1R>2!T;R!F:6YD(&$@<W1R:6YG(&%S(&QO;F<@87,@7V]P=&QE
M;F=T:"X*("`@("`@("`@("`@("`@("`@("`@("`@("H@,BX@5')Y('1O(&9I
M;F0@82!S=')I;F<@87,@;&]N9R!A<R!?;6%X;&5N9W1H+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@*B`S+B!486ME('1H92!F:7)S="!W;W)D+B`J+PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)&U;,5TI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;5LQ72`]("1M6S)=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&U;,ET@/2`G)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V]U='!U=%M=(#T@87)R87DH)W1E>'0G(#T^("1M6S%=("X@)R`G("X@
M*"@D9&5L<W`I(#\@)R`G(#H@)R<I+"`G;&5V96PG(#T^("1N=6U?<75O=&5S
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2`D;5LR73L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`O*B!/;F4@97AC97-S:79E;'D@;&]N9R!W;W)D(&QE9G0@;VX@;&EN
M92X@($)E"B`@("`@("`@("`@("`@("`@("`@("`@("`J(&%B<V]L=71E;'D@
M<W5R92!I="!D;V5S(&YO="!E>&-E960@.3DX(&-H87)A8W1E<G,*("`@("`@
M("`@("`@("`@("`@("`@("`@("H@:6X@;&5N9W1H(&]R(&5L<V4@=V4@;75S
M="!T<G5N8V%T92X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1L
M:6YE7VQE;F=T:"`^(#DY."D@>R`*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;W5T<'5T6UT@/2!A<G)A>2@G=&5X="<@/3X@4W1R:6YG
M.CIS=6)S='(H)&QI;F4L(#`L(#DY."P@)'1H:7,M/E]C:&%R<V5T*2P@)VQE
M=F5L)R`]/B`D;G5M7W%U;W1E<RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;&EN92`](%-T<FEN9SHZ<W5B<W1R*"1L:6YE+"`Y.3@L(&YU;&PL
M("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U=%M=(#T@87)R87DH)W1E>'0G(#T^("1L:6YE+"`G;&5V96PG(#T^("1N
M=6U?<75O=&5S*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?2!W:&EL92`H(65M<'1Y*"1T97AT*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!N=6UB97(@;V8@;&5A9&EN9R`G/B<@8VAA<F%C=&5R
M<R!I;B!T:&4@=&5X="!I;G!U="X*("`@("`J("<^)R!C:&%R86-T97)S(&%R
M92!D969I;F5D(&)Y(%)&0R`R-C0V('1O(&EN9&EC871E(&$@<75O=&5D(&QI
M;F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@86YA;'EZ92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@
M;&5A9&EN9R!Q=6]T92!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?;G5M<75O=&5S*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B!S=')S
M<&XH)'1E>'0L("<^)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3<&%C92US
M='5F9G,@:68@:70@<W1A<G1S('=I=&@@)R`G(&]R("<^)R!O<B`G1G)O;2`G
M+"!O<B!I9@H@("`@("H@<75O=&4@9&5P=&@@:7,@;F]N+7IE<F\@*&9O<B!A
M97-T:&5T:6,@<F5A<V]N<R!S;R!T:&%T('1H97)E(&ES(&$*("`@("`J('-P
M86-E(&%F=&5R('1H92`G/B<I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@
M(%1H92!T97AT('1O('-T=69F+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;G5M
M7W%U;W1E<R`@5&AE('%U;W1E+6QE=F5L(&]F('1H:7,@;&EN92X*("`@("`J
M($!P87)A;2!B;V]L96%N("1T;V9L;W=E9"`@($%R92!W92!C;VYV97)T:6YG
M('1O(&9L;W=E9"!T97AT/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<W1U9F9E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<W1U
M9F8H)'1E>'0L("1N=6U?<75O=&5S+"`D=&]F;&]W960I"B`@("!["B`@("`@
M("`@:68@*"1T;V9L;W=E9"`F)@H@("`@("`@("`@("`H)&YU;5]Q=6]T97,@
M?'P@<')E9U]M871C:"@B+UXH/SH@?#Y\1G)O;2!\1G)O;20I+R(L("1T97AT
M*2DI('L*("`@("`@("`@("`@<F5T=7)N("<@)R`N("1T97AT.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!5;G-T=69F<R!A('-P86-E('-T=69F960@;&EN92X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("!4:&4@=&5X="!T;R!U;G-T=69F+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@=6YS='5F9F5D('1E>'0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]U;G-T=69F*"1T97AT*0H@("`@>PH@("`@("`@(&EF("@A
M96UP='DH)'1E>'0I("8F("@D=&5X='LP?2`]/2`G("<I*2!["B`@("`@("`@
M("`@("1T97AT(#T@<W5B<W1R*"1T97AT+"`Q*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T97AT.PH@("`@?0H*?0H`````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+G!H<```````````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$V,34V-``Q,#0Q-S,V,C<W-@`P,38W
M-C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"FEN8VQU9&5?;VYC92`G3&]G+G!H<"<["FEN8VQU9&5?;VYC92`G
M2&]R9&4O571I;"YP:'`G.PH*+RHJ"B`J(%1H92!(;W)D93HZ(&-L87-S('!R
M;W9I9&5S('1H92!F=6YC=&EO;F%L:71Y('-H87)E9"!B>2!A;&P@2&]R9&4*
M("H@87!P;&EC871I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`L=B`Q+C0X.2XR+C0T(#(P,#8O,#,O,C0@,#`Z-#`Z,S@@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]&<F%M97=O
M<FL*("HO"F-L87-S($AO<F1E('L*"B`@("`O*BH*("`@("`J($QO9W,@82!M
M97-S86=E('1O('1H92!G;&]B86P@2&]R9&4@;&]G(&)A8VME;F0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1M97-S86=E("`@("!%:71H97(@82!S
M=')I;F<@;W(@82!014%27T5R<F]R(&]B:F5C="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&9I;&4@("`@("`@5VAA="!F:6QE('=A<R!T:&4@;&]G(&9U;F-T
M:6]N(&-A;&QE9"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AE+F<N(%]?1DE,15]?*3\*("`@("`J($!P87)A;2!I;G1E9V5R("1L
M:6YE("`@("`@5VAA="!L:6YE('=A<R!T:&4@;&]G(&9U;F-T:6]N(&-A;&QE
M9"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("AE+F<N
M(%]?3$E.15]?*3\*("`@("`J($!P87)A;2!I;G1E9V5R("1P<FEO<FET>2`@
M5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B!/;F4@;V8Z"B`@("`@*B`\
M<')E/@H@("`@("H@4$5!4E],3T=?14U%4D<*("`@("`J(%!%05)?3$]'7T%,
M15)4"B`@("`@*B!014%27TQ/1U]#4DE4"B`@("`@*B!014%27TQ/1U]%4E(*
M("`@("`J(%!%05)?3$]'7U=!4DY)3D<*("`@("`J(%!%05)?3$]'7TY/5$E#
M10H@("`@("H@4$5!4E],3T=?24Y&3PH@("`@("H@4$5!4E],3T=?1$5"54<*
M("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V=-97-S86=E
M*"1M97-S86=E+"`D9FEL92P@)&QI;F4L("1P<FEO<FET>2`](%!%05)?3$]'
M7TE.1D\I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I
M9B`H(21C;VYF6R=L;V<G75LG96YA8FQE9"==*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D<')I;W)I='D@/B`D8V]N
M9ELG;&]G)UU;)W!R:6]R:71Y)UTI('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@)&QO9V=E<B`]("9(;W)D93HZ9V5T3&]G9V5R
M*"D["B`@("`@("`@:68@*"%I<U]A*"1L;V=G97(L("=,;V<G*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<B@G06X@97)R
M;W(@:&%S(&]C8W5R<F5D+B!&=7)T:&5R;6]R92P@2&]R9&4@96YC;W5N=&5R
M960@86X@97)R;W(@871T96UP=&EN9R!T;R!L;V<@=&AI<R!E<G)O<BX@4&QE
M87-E(&-H96-K('EO=7(@2&]R9&4@;&]G9VEN9R!C;VYF:6=U<F%T:6]N(&EN
M(&AO<F1E+V-O;F9I9R]C;VYF+G!H<"XG*2P@7U]&24Q%7U\L(%]?3$E.15]?
M+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D;65S<V%G
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=7-E<FEN9F\@/2`D
M;65S<V%G92T^9V5T57-E<DEN9F\H*3L*("`@("`@("`@("`@)&UE<W-A9V4@
M/2`D;65S<V%G92T^9V5T365S<V%G92@I.PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1U<V5R:6YF;RDI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=7-E<FEN9F\I*2!["B`@("`@("`@("`@("`@("`@("`@)'5S97)I;F9O
M(#T@0&EM<&QO9&4H)RP@)RP@)'5S97)I;F9O*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1M97-S86=E("X]("<Z("<@+B`D=7-E<FEN
M9F\["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-?8V%L;&%B
M;&4H87)R87DH)&UE<W-A9V4L("=G971-97-S86=E)RDI*2!["B`@("`@("`@
M("`@("1M97-S86=E(#T@)&UE<W-A9V4M/F=E=$UE<W-A9V4H*3L*("`@("`@
M("!]"@H@("`@("`@("1A<'`@/2!I<W-E="@D1TQ/0D%,4ULG<F5G:7-T<GDG
M72D@/R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T07!P*"D@.B`G:&]R9&4G
M.PH@("`@("`@("1M97-S86=E(#T@)ULG("X@)&%P<"`N("==("<@+B`D;65S
M<V%G92`N("<@6V]N(&QI;F4@)R`N("1L:6YE("X@)R!O9B`B)R`N("1F:6QE
M("X@)R)=)SL*"B`@("`@("`@+RH@36%K92!S=7)E('1O(&QO9R!I;B!T:&4@
M<WES=&5M)W,@;&]C86QE+B`J+PH@("`@("`@("1L;V-A;&4@/2!S971L;V-A
M;&4H3$-?5$E-12P@,"D["B`@("`@("`@<V5T;&]C86QE*$Q#7U1)344L("=#
M)RD["@H@("`@("`@("1L;V=G97(M/FQO9R@D;65S<V%G92P@)'!R:6]R:71Y
M*3L*"B`@("`@("`@+RH@4F5S=&]R92!O<FEG:6YA;"!L;V-A;&4N("HO"B`@
M("`@("`@<V5T;&]C86QE*$Q#7U1)344L("1L;V-A;&4I.PH*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F=E=$QO9V=E<B@I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*
M("`@("`@("!I9B`H96UP='DH)&-O;F9;)VQO9R==6R=E;F%B;&5D)UTI*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M('-T871I8R`D;&]G8VAE8VL["B`@("`@("`@:68@*"%I<W-E="@D;&]G8VAE
M8VLI*2!["B`@("`@("`@("`@("\O(%1R>2!T;R!M86ME('-U<F4@=&AA="!W
M92!C86X@;&]G(&UE<W-A9V5S('-O;65H;W<N"B`@("`@("`@("`@(&EF("AE
M;7!T>2@D8V]N9ELG;&]G)UTI('Q\"B`@("`@("`@("`@("`@("!E;7!T>2@D
M8V]N9ELG;&]G)UU;)W1Y<&4G72D@?'P*("`@("`@("`@("`@("`@(&5M<'1Y
M*"1C;VYF6R=L;V<G75LG;F%M92==*2!\?`H@("`@("`@("`@("`@("`@96UP
M='DH)&-O;F9;)VQO9R==6R=I9&5N="==*2!\?`H@("`@("`@("`@("`@("`@
M(6ES<V5T*"1C;VYF6R=L;V<G75LG<&%R86US)UTI*2!["B`@("`@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<B@G2&]R9&4@:7,@
M;F]T(&-O<G)E8W1L>2!C;VYF:6=U<F5D('1O(&QO9R!E<G)O<B!M97-S86=E
M<RX@66]U(&UU<W0@8V]N9FEG=7)E(&%T(&QE87-T(&$@=&5X="!F:6QE(&QO
M9R!I;B!H;W)D92]C;VYF:6<O8V]N9BYP:'`N)RDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L;V=C
M:&5C:R`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QO9V=E
M<B`]("9,;V<Z.G-I;F=L971O;B@D8V]N9ELG;&]G)UU;)W1Y<&4G72P@)&-O
M;F9;)VQO9R==6R=N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;F9;)VQO9R==6R=I9&5N="==+"`D8V]N9ELG
M;&]G)UU;)W!A<F%M<R==*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R
M;WES(&%N>2!E>&ES=&EN9R!S97-S:6]N(&]N(&QO9VEN(&%N9"!M86ME('-U
M<F4@=&\@=7-E(&$@;F5W"B`@("`@*B!S97-S:6]N($E$+"!T;R!A=F]I9"!S
M97-S:6]N(&9I>&%T:6]N(&ES<W5E<RX@4VAO=6QD(&)E(&-A;&QE9"!B969O
M<F4*("`@("`J(&-H96-K:6YG(&$@;&]G:6XN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$-L96%N4V5S<VEO;B@I"B`@("!["B`@("`@("`@+R\@36%K92!S
M=7)E('1O(&9O<F-E(&$@8V]M<&QE=&5L>2!N97<@<V5S<VEO;B!)1"!A;F0@
M8VQE87(*("`@("`@("`O+R!A;&P@<V5S<VEO;B!D871A+@H@("`@("`@(&EF
M("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-"XS+C,G*2`A/3T@
M+3$I('L*("`@("`@("`@("`@<V5S<VEO;E]R96=E;F5R871E7VED*"D["B`@
M("`@("`@("`@('-E<W-I;VY?=6YS970H*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!`<V5S<VEO;E]D97-T<F]Y*"D["B`@("`@("`@("`@(&EF
M("A5=&EL.CIE>'1E;G-I;VY%>&ES=',H)W!O<VEX)RDI('L*("`@("`@("`@
M("`@("`@("1N97=?<V5S<VEO;E]I9"`](&UD-2AM:6-R;W1I;64H*2`N('!O
M<VEX7V=E='!I9"@I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1N97=?<V5S<VEO;E]I9"`](&UD-2AU;FEQ:60H;71?<F%N9"@I
M+"!T<G5E*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<V5S<VEO;E]I
M9"@D;F5W7W-E<W-I;VY?:60I.PH*("`@("`@("`@("`@+R\@4F5S=&%R="!T
M:&4@<V5S<VEO;BP@:6YC;'5D:6YG('-E='1I;F<@=7`@=&AE('-E<W-I;VX*
M("`@("`@("`@("`@+R\@:&%N9&QE<BX*("`@("`@("`@("`@2&]R9&4Z.G-E
M='5P4V5S<VEO;DAA;F1L97(H*3L*("`@("`@("`@("`@0'-E<W-I;VY?<W1A
M<G0H*3L*("`@("`@("!]"@H@("`@("`@("\J(%)E<V5T(&-O;VMI92!T:6UE
M;W5T<RP@:68@;F5C97-S87)Y+B`J+PH@("`@("`@(&EF("@A96UP='DH)$=,
M3T)!3%-;)V-O;F8G75LG<V5S<VEO;B==6R=T:6UE;W5T)UTI*2!["B`@("`@
M("`@("`@("1A<'`@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T07!P*"D[
M"B`@("`@("`@("`@(&EF("A396-R970Z.F-L96%R2V5Y*"1A<'`I*2!["B`@
M("`@("`@("`@("`@("!396-R970Z.G-E=$ME>2@D87!P*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!396-R970Z.G-E=$ME>2@G875T:"<I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%B;W)T<R!W:71H(&$@9F%T
M86P@97)R;W(L(&1I<W!L87EI;F<@9&5B=6<@:6YF;W)M871I;VX@=&\@=&AE
M('5S97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1E<G)O<B`@($$@
M4$5!4E]%<G)O<B!O8FIE8W0@=VET:"!D96)U9R!I;F9O<FUA=&EO;B!O<B!A
M;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&5R<F]R(&UE<W-A9V4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9FEL92`@5&AE(&9I;&4@:6X@=VAI
M8V@@=&AE(&5R<F]R(&]C8W5R960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M;&EN92`@5&AE(&QI;F4@;VX@=VAI8V@@=&AE(&5R<F]R(&]C8W5R960N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D;&]G("`@3&]G('1H:7,@;65S<V%G92!V
M:6$@2&]R9&4Z.FQO9TUE<W-A9V4H*3\*("`@("`J+PH@("`@9G5N8W1I;VX@
M9F%T86PH)&5R<F]R+"`D9FEL92P@)&QI;F4L("1L;V<@/2!T<G5E*0H@("`@
M>PH@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T%U=&@N<&AP)SL*("`@
M("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]#3$DN<&AP)SL*"B`@("`@("`@
M)&%D;6EN(#T@8VQA<W-?97AI<W1S*"=!=71H)RD@)B8@075T:#HZ:7-!9&UI
M;B@I.PH@("`@("`@("1C;&D@/2!C;&%S<U]E>&ES=',H)TAO<F1E7T-,22<I
M("8F($AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH*3L*"B`@("`@("`@)&5R
M<F]R=&5X="`]("<\:#$^)R`N(%\H(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D(BD@+B`G/"]H,3XG.PH@("`@("`@(&EF("AI<U]A*"1E<G)O<BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D:6YF;R`](&%R<F%Y7VUE<F=E
M*&%R<F%Y*"=F:6QE)R`]/B`G8V]N9BYP:'`G+"`G=F%R:6%B;&4G(#T^("<D
M8V]N9B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"1E<G)O<BT^9V5T57-E<DEN9F\H*2DI.PH*("`@("`@("`@("`@<W=I=&-H
M("@D97)R;W(M/F=E=$-O9&4H*2D@>PH@("`@("`@("`@("!C87-E($A/4D1%
M7T524D]27T12259%4E]#3TY&24=?34E34TE.1SH*("`@("`@("`@("`@("`@
M("1M97-S86=E(#T@<W!R:6YT9BA?*").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(BDL("1I;F9O6R=N86UE)UTI("X@
M)SQB<B`O/B<@+@H@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG970H)V9I;&5R;V]T)RD@+B`G+V-O;F9I9R\G("X@)&EN9F];)V9I
M;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H(B5S
M6R<E<R==6R=P87)A;7,G72(L("1I;F9O6R=V87)I86)L92==+"`D:6YF;ULG
M9')I=F5R)UTI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92!(3U)$15]%4E)/4E]$4DE615)?0T].1DE'.@H@("`@("`@("`@
M("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(BDL("1I;F9O6R=F
M:65L9"==+"`D:6YF;ULG;F%M92==*2`N("<\8G(@+SXG("X*("`@("`@("`@
M("`@("`@("`@("!S<')I;G1F*%\H(E1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN(&$@)7,@<V5T=&EN9RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RD@+B`G
M+V-O;F9I9R\G("X@)&EN9F];)V9I;&4G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-P<FEN=&8H(B5S6R<E<R==6R=P87)A;7,G75LG)7,G72(L
M("1I;F9O6R=V87)I86)L92==+"`D:6YF;ULG9')I=F5R)UTL("1I;F9O6R=F
M:65L9"==*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1E<G)O<BT^
M9V5T365S<V%G92@I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1E<G)O<G1E>'0@+CT@)SQH,SXG("X@:'1M
M;'-P96-I86QC:&%R<R@D;65S<V%G92D@+B`G/"]H,SXG.PH@("`@("`@('T@
M96QS96EF("AI<U]O8FIE8W0H)&5R<F]R*2`F)B!M971H;V1?97AI<W1S*"1E
M<G)O<BP@)V=E=$UE<W-A9V4G*2D@>PH@("`@("`@("`@("`D97)R;W)T97AT
M("X]("<\:#,^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&5R<F]R+3YG971-97-S
M86=E*"DI("X@)SPO:#,^)SL*("`@("`@("!](&5L<V5I9B`H:7-?<W1R:6YG
M*"1E<G)O<BDI('L*("`@("`@("`@("`@)&5R<F]R=&5X="`N/2`G/&@S/B<@
M+B!H=&UL<W!E8VEA;&-H87)S*"1E<G)O<BD@+B`G/"]H,SXG.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1A9&UI;BD@>PH@("`@("`@("`@("`D97)R;W)T
M97AT("X]("<\<#X\8V]D93XG("X@<W!R:6YT9BA?*");;&EN92`E<R!O9B`E
M<UTB*2P@)&QI;F4L("1F:6QE*2`N("<\+V-O9&4^/"]P/B<["B`@("`@("`@
M("`@(&EF("AI<U]O8FIE8W0H)&5R<F]R*2D@>PH@("`@("`@("`@("`@("`@
M)&5R<F]R=&5X="`N/2`G/&@S/B<@+B!?*")$971A:6QS("AA;'-O(&EN($AO
M<F1E)W,@;&]G9FEL92DZ(BD@+B`G/"]H,SXG.PH@("`@("`@("`@("`@("`@
M)&5R<F]R=&5X="`N/2`G/'`^/'!R93XG("X@:'1M;'-P96-I86QC:&%R<RA5
M=&EL.CIB=69F97)/=71P=70H)W9A<E]D=6UP)RP@)&5R<F]R*2D@+B`G/"]P
M<F4^/"]P/B<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)&QO
M9RD@>PH@("`@("`@("`@("`D97)R;W)T97AT("X]("<\:#,^)R`N(%\H(D1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(BD@+B`G/"]H,SXG.PH@("`@("`@('T*"B`@("`@("`@+R\@3&]G('1H92!E
M<G)O<B!V:6$@2&]R9&4Z.FQO9TUE<W-A9V4H*2!I9B!R97%U97-T960N"B`@
M("`@("`@:68@*"1L;V<I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)&5R<F]R+"`D9FEL92P@)&QI;F4L(%!%05)?3$]'7T5-15)'*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D8VQI*2!["B`@("`@("`@("`@(&5C:&\@
M<W1R:7!?=&%G<RAS=')?<F5P;&%C92AA<G)A>2@G/&)R("\^)RP@)SQP/B<L
M("<\+W`^)RP@)SQH,3XG+"`G/"]H,3XG+"`G/&@S/B<L("<\+V@S/B<I+"`B
M7&XB+"`D97)R;W)T97AT*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@96-H;R`\/#P@2%1-3`H\:'1M;#X*/&AE860^/'1I=&QE/DAO<F1E(#HZ
M($9A=&%L($5R<F]R/"]T:71L93X\+VAE860^"CQB;V1Y('-T>6QE/2)B86-K
M9W)O=6YD.B-F9F8[(&-O;&]R.B,P,#`B/B1E<G)O<G1E>'0\+V)O9'D^"CPO
M:'1M;#X*2%1-3#L*("`@("`@("!]"B`@("`@("`@97AI=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9',@=&AE(&IA=F%S8W)I<'0@8V]D92!T;R!T:&4@
M;W5T<'5T("AI9B!O=71P=70@:&%S(&%L<F5A9'D@<W1A<G1E9"D*("`@("`J
M(&]R('1O('1H92!L:7-T(&]F('-C<FEP="!F:6QE<R!T;R!I;F-L=61E('9I
M82!I;F-L=61E4V-R:7!T1FEL97,H*2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F:6QE("`@("!4:&4@9G5L;"!J879A<V-R:7!T(&9I;&4@;F%M
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@("`@(%1H92!A<'!L:6-A
M=&EO;B!N86UE+B!$969A=6QT<R!T;R!T:&4@8W5R<F5N=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@87!P;&EC871I;VXN"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D9&ER96-T("!);F-L=61E('1H92!F:6QE(&1I<F5C=&QY
M('=I=&AO=70@<&%S<VEN9R!I=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AR;W5G:"!J879A<V-R:7!T+G!H<#\*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D4V-R:7!T1FEL92@D9FEL92P@)&%P<"`](&YU;&PL("1D:7)E
M8W0@/2!F86QS92D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@
M("`@("`@('-T871I8R`D:6YC;'5D960@/2!A<G)A>2@I.PH*("`@("`@("!I
M9B`H96UP='DH)&%P<"DI('L*("`@("`@("`@("`@)&%P<"`]("1R96=I<W1R
M>2T^9V5T07!P*"D["B`@("`@("`@?0H*("`@("`@("`O+R!3:VEP(&%N>2!J
M<R!F:6QE<R!T:&%T(&AA=F4@<VEN8V4@8F5E;B!D97!R96-A=&5D+@H@("`@
M("`@("1I9VYO<F5D7V9I;&5S(#T@87)R87DH)VAO<F1E)R`]/B!A<G)A>2@G
M=&]O;'1I<"YJ<R<@/3X@,2DI.PH@("`@("`@(&EF("@A96UP='DH)&EG;F]R
M961?9FEL97-;)&%P<%U;)&9I;&5=*2D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("`O+R!$;VXG="!I;F-L=61E('-C<FEP=',@
M;75L=&EP;&4@=&EM97,N"B`@("`@("`@:68@*"%E;7!T>2@D:6YC;'5D961;
M)&%P<%U;)&9I;&5=*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@("`@("1I;F-L=61E9%LD87!P75LD9FEL95T@/2!T<G5E.PH*("`@
M("`@("`O+R!%>'!L:6-I=&QY(&-H96-K(&9O<B!A(&YO;BU02%`@=F5R<VEO
M;B!O9B!T:&4@<V-R:7!T+@H@("`@("`@(&EF("@A)&1I<F5C="`F)B!F:6QE
M7V5X:7-T<R@D9FEL97LP?2`]/2`G+R<@/R`D<F5G:7-T<GDM/F=E="@G9FEL
M97)O;W0G+"`D87!P*2`N("1F:6QE(#H@)')E9VES=')Y+3YG970H)VIS9G,G
M+"`D87!P*2`N("<O)R`N("1F:6QE*2D@>PH@("`@("`@("`@("`D9&ER96-T
M(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("\O($EF(&AE861E<G,@:&%V
M92!A;')E861Y(&)E96X@<V5N="P@=V4@;F5E9"!T;R!O=71P=70@80H@("`@
M("`@("\O(#QS8W)I<'0^('1A9R!D:7)E8W1L>2X*("`@("`@("!I9B`H;V)?
M9V5T7VQE;F=T:"@I('Q\(&AE861E<G-?<V5N="@I*2!["B`@("`@("`@("`@
M(&EF("@D9&ER96-T*2!["B`@("`@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z
M.G5R;"@D9FEL97LP?2`]/2`G+R<@/R`D<F5G:7-T<GDM/F=E="@G=V5B<F]O
M="<L("1A<'`I("X@)&9I;&4@.B`D<F5G:7-T<GDM/F=E="@G:G-U<FDG+"`D
M87!P*2`N("<O)R`N("1F:6QE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T
M*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VIA=F%S8W)I<'0N
M<&AP)RD["B`@("`@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE
M=&5R*"1U<FPL(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%P
M<"<@(#T^("1A<'`I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO
M("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2(G("X@)'5R
M;"`N("<B/CPO<V-R:7!T/B<@+B`B7&XB.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&=L;V)A;"`D7VAO<F1E7W-C<FEP=%]F:6QE<SL*("`@("`@
M("`@("`@)%]H;W)D95]S8W)I<'1?9FEL97-;)&%P<%U;72`](&%R<F%Y*"1F
M:6QE+"`D9&ER96-T*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!);F-L=61E<R!J879A<V-R:7!T(&9I;&5S('1H870@=V5R92!N965D960@
M8F5F;W)E(&%N>2!H96%D97)S('=E<F4@<V5N="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:6YC;'5D95-C<FEP=$9I;&5S*"D*("`@('L*("`@("`@("!G;&]B
M86P@)%]H;W)D95]S8W)I<'1?9FEL97,L("1R96=I<W1R>3L*"B`@("`@("`@
M+RH@268@:70@:&%S(&)E96X@<F5Q=65S=&5D(&EN('1H92!S97-S:6]N('1O
M(&1I<V%B;&4@:F%V87-C<FEP="P*("`@("`@("`@*B!I;G-E<G0@=&AE('-C
M<FEP="!T;R!T97-T(&9O<B!I="!B96EN9R!E;F%B;&5D(&%G86EN+B`J+PH@
M("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)V-A;&QB86-K<R==6R=B<F]W
M<V5R+F1I<V%B;&5*879A<V-R:7!T)UTI*2!["B`@("`@("`@("`@($AO<F1E
M.CIA9&138W)I<'1&:6QE*"=T97-T7VIA=F%S8W)I<'0N:G,G+"`G:&]R9&4G
M*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('1H97)E(&ES(&YO(&IA=F%S
M8W)I<'0@879A:6QA8FQE+"!T:&5R92=S(&YO('!O:6YT(&EN(&EN8VQU9&EN
M9PH@("`@("`@("`J('1H92!R97-T(&]F('1H92!F:6QE<RX@*B\*("`@("`@
M("!I9B`H(21'3$]"04Q36R=B<F]W<V5R)UTM/FAA<T9E871U<F4H)VIA=F%S
M8W)I<'0G*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@
M("`@("`O*B!!9&0@9V5N97)A;"!522!J<R!L:6)R87)Y+B`J+PH@("`@("`@
M($AO<F1E.CIA9&138W)I<'1&:6QE*"=H;W)D92YJ<R<L("=H;W)D92<L('1R
M=64I.PH@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-1=6ER
M:R@G=VEN9&]W961?8V]N=')O;',G*2D@>PH@("`@("`@("`@("`O*B!&:7AE
M<R!F;W(@244@=&AA="!C86XG="!E87-I;'D@8F4@9&]N92!W:71H;W5T(&)R
M;W=S97(*("`@("`@("`@("`@("H@9&5T96-T:6]N+B`J+PH@("`@("`@("`@
M("!(;W)D93HZ861D4V-R:7!T1FEL92@G:&]R9&4N:64N:G,G+"`G:&]R9&4G
M+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)%]H;W)D
M95]S8W)I<'1?9FEL97,I*2!["B`@("`@("`@("`@("1B87-E7W5R;"`]($AO
M<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N
M("<O<V5R=FEC97,O:F%V87-C<FEP="YP:'`G*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)%]H;W)D95]S8W)I<'1?9FEL97,@87,@)&%P<"`]/B`D9FEL97,I
M('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&9I;&5;,5TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1U<FP@/2`D9FEL95LP77LP?2`]
M/2`G+R<@/R`D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("1A<'`I("X@)&9I
M;&5;,%T@.B`D<F5G:7-T<GDM/F=E="@G:G-U<FDG+"`D87!P*2`N("<O)R`N
M("1F:6QE6S!=.PH@("`@("`@("`@("`@("`@("`@("`@("!E8VAO("<\<V-R
M:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2(G("X@2&]R9&4Z.G5R
M;"@D=7)L*2`N(")<(CX\+W-C<FEP=#Y<;B(["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'5R;"`](%5T
M:6PZ.F%D9%!A<F%M971E<B@D8F%S95]U<FPL(&%R<F%Y*"=F:6QE)R`]/B`D
M9FEL95LP72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A<'`G("`]/B`D87!P
M*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)SQS8W)I<'0@='EP
M93TB=&5X="]J879A<V-R:7!T(B!S<F,](B<@+B`D=7)L("X@(EPB/CPO<V-R
M:7!T/EQN(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);F-L=61E<R!J879A<V-R:7!T(&9I;&5S('1H870@=V5R92!N965D
M960@8F5F;W)E(&%N>2!H96%D97)S('=E<F4@<V5N="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:6YL:6YE4V-R:7!T1FEL97,H*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D7VAO<F1E7W-C<FEP=%]F:6QE<RP@)')E9VES=')Y.PH*("`@("`@
M("!I9B`H(65M<'1Y*"1?:&]R9&5?<V-R:7!T7V9I;&5S*2D@>PH@("`@("`@
M("`@("`D:G-7<F%P<&5R(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@
M)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VIA=F%S8W)I<'0N<&AP)SL*("`@("`@
M("`@("`@9F]R96%C:"`H)%]H;W)D95]S8W)I<'1?9FEL97,@87,@)&%P<"`]
M/B`D9FEL97,I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A
M<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&9I
M;&5;,5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@($!R96%D9FEL92@D
M9FEL95LP77LP?2`]/2`G+R<@/R`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G
M+"`D87!P*2`N("1F:6QE6S!=(#H@)')E9VES=')Y+3YG970H)VIS9G,G+"`D
M87!P*2`N("<O)R`N("1F:6QE6S!=*3L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1F:6QE
M6S!=.PH@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E("1J<U=R87!P
M97(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS(&EF(&QI;FL@<VAO=6QD(&)E('-H;W=N(&%N9"!R971U<FX@=&AE
M(&YE<V-E<W-A<GD@8V]D92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D='EP92`@("`@(%1Y<&4@;V8@;&EN:R!T;R!D:7-P;&%Y"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D87!P("`@("`@(%1H92!N86UE(&]F('1H92!C=7)R
M96YT($AO<F1E(&%P<&QI8V%T:6]N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&]V97)R:61E("!/=F5R<FED92!(;W)D92!S971T:6YG<S\*("`@("`J($!P
M87)A;2!B;V]L96%N("1R969E<G)E<B`@26YC;'5D92!T:&4@8W5R<F5N="!P
M86=E(&%S('1H92!R969E<G)E<B`H=7)L/2D_"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!(5$U,('1O(&-R96%T92!T:&4@;&EN:RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4V5R=FEC94QI;FLH)'1Y<&4L("1A<'`L
M("1O=F5R<FED92`](&9A;'-E+"`D<F5F97)R97(@/2!T<G5E*0H@("`@>PH@
M("`@("`@(&EF("@A2&]R9&4Z.G-H;W=397)V:6-E*"1T>7!E*2`F)B`A)&]V
M97)R:61E*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("!C87-E("=H96QP
M)SH*("`@("`@("`@("`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<T9E
M871U<F4H)VIA=F%S8W)I<'0G*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z
M.F%D9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RP@)VAO<F1E)RP@=')U92D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@
M)R]S97)V:6-E<R]H96QP+R<L('1R=64I.PH@("`@("`@("`@("!R971U<FX@
M571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=M;V1U;&4G+"`D87!P*3L*"B`@
M("`@("`@8V%S92`G<')O8FQE;2<Z"B`@("`@("`@("`@(')E='5R;B!(;W)D
M93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*2`N("<O<V5R=FEC97,O<')O8FQE;2YP:'`_<F5T=7)N7W5R;#TG
M("X@=7)L96YC;V1E*$AO<F1E.CIS96QF57)L*'1R=64L('1R=64L('1R=64I
M*2D["@H@("`@("`@(&-A<V4@)VQO9V]U="<Z"B`@("`@("`@("`@(')E='5R
M;B!(;W)D93HZ=7)L*$%U=&@Z.F%D9$QO9V]U=%!A<F%M971E<G,H)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]L
M;V=I;BYP:'`G+"!!551(7U)%05-/3E],3T=/550I*3L*"B`@("`@("`@8V%S
M92`G;&]G:6XG.@H@("`@("`@("`@("!R971U<FX@075T:#HZ9V5T3&]G:6Y3
M8W)E96XH)R<L("1R969E<G)E<B`_($AO<F1E.CIS96QF57)L*'1R=64I(#H@
M;G5L;"D["@H@("`@("`@(&-A<V4@)V]P=&EO;G,G.@H@("`@("`@("`@("!G
M;&]B86P@)&-O;F8["B`@("`@("`@("`@(&EF("@H)&-O;F9;)W!R969S)UU;
M)V1R:79E<B==("$]("<G*2`F)B`H)&-O;F9;)W!R969S)UU;)V1R:79E<B==
M("$]("=N;VYE)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!(;W)D93HZ
M=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R
M9&4G*2`N("<O<V5R=FEC97,O<')E9G,N<&AP/V%P<#TG("X@)&%P<"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T>7!E("!4:&4@='EP92!O9B!L:6YK+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@;&EN:R!I<R!T;R!B
M92!S:&]W;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<VAO=U-E<G9I8V4H)'1Y
M<&4I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H
M96UP='DH)&-O;F9;)VUE;G4G75LG;&EN:W,G75LD='EP95TI*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@('-W:71C
M:"`H)&-O;F9;)VUE;G4G75LG;&EN:W,G75LD='EP95TI('L*("`@("`@("!C
M87-E("=A;&PG.@H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@("`@
M8V%S92`G;F5V97(G.@H@("`@("`@("`@("!R971U<FX@9F%L<V4["@H@("`@
M("`@(&-A<V4@)V%U=&AE;G1I8V%T960G.@H@("`@("`@("`@("!R971U<FX@
M*&)O;VPI075T:#HZ9V5T075T:"@I.PH*("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@9')I=F5R('!A<F%M971E<G,@9F]R('1H
M92!S<&5C:69I960@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&)A8VME;F0@(%1H92!B86-K96YD('-Y<W1E;2`H92YG+B`G<')E9G,G
M+"`G8V%T96=O<FEE<R<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("=C;VYT86-T<R<I(&)E:6YG('5S960N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(%1H92!U<V5D(&-O;F9I9W5R871I;VX@87)R87D@=VEL;"!B
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9ELD8F%C:V5N
M9%TN($EF(&%N(&%R<F%Y(&=E=',@<&%S<V5D+"!I="!W:6QL"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(&)E("1C;VYF6R1K97DQ75LD:V5Y,ETN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@(%1H92!T>7!E(&]F(&1R
M:79E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]N;F5C
M=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$<FEV
M97)#;VYF:6<H)&)A8VME;F0L("1T>7!E(#T@)W-Q;"<I"B`@("!["B`@("`@
M("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D8R`](&YU;&P["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1B86-K96YD*2D@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@("1C(#T@2&]R
M9&5?07)R87DZ.F=E=$5L96UE;G0H)&-O;F8L("1B86-K96YD*3L*("`@("`@
M("!](&5L<V5I9B`H:7-S970H)&-O;F9;)&)A8VME;F1=*2D@>PH@("`@("`@
M("`@("`D8R`]("1C;VYF6R1B86-K96YD73L*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<U]N=6QL*"1C*2`F)B!I<W-E="@D8ULG<&%R86US)UTI*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D8V]N9ELD='EP95TI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@87)R87E?;65R9V4H)&-O;F9;)'1Y<&5=+"`D8ULG
M<&%R86US)UTI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1C6R=P87)A;7,G73L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1C;VYF6R1T>7!E72D@/R`D8V]N
M9ELD='EP95T@.B!A<G)A>2@I.PH@("`@?0H*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(%9&4R!D<FEV97(@<&%R86UE=&5R<R!F;W(@=&AE('-P96-I
M9FEE9"!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!61E,@<WES=&5M(&YA;64@*&4N9RX@)VEM86=E<R<L("=D;V-U
M;65N=',G*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@8F5I;F<@=7-E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@=VET:"!T
M:&4@5D93('!A<F%M971E<G,[('1H92!61E,@9')I=F5R(&EN("=T>7!E)PH@
M("`@("H@("`@("`@("`@("`@("`@86YD('1H92!C;VYN96-T:6]N('!A<F%M
M971E<G,@:6X@)W!A<F%M<R<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%9&
M4T-O;F9I9R@D;F%M92D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@
M("`@("`@(&EF("@A:7-S970H)&-O;F9;)&YA;65=6R=T>7!E)UTI*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(EEO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(I*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D8V]N9ELD;F%M95U;)W1Y<&4G72`]/2`G:&]R9&4G*2!["B`@
M("`@("`@("`@("1V9G,@/2`D8V]N9ELG=F9S)UT["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'9F<R`]("1C;VYF6R1N86UE73L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D=F9S6R=T>7!E)UT@/3T@)W-Q;"<I('L*("`@("`@
M("`@("`@)'9F<ULG<&%R86US)UT@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG
M*"1N86UE+"`G<W%L)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'9F
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A;&P@;F5C97-S
M87)Y('!A<F%M971E<G,@9F]R(&$@9')I=F5R(&-O;F9I9W5R871I;VX*("`@
M("`J(&%R92!S970@86YD('1H<F]W<R!A(&9A=&%L(&5R<F]R('=I=&@@82!D
M971A:6QE9"!E>'!L86EN871I;VX*("`@("`J(&AO=R!T;R!F:7@@=&AI<RP@
M:68@<V]M971H:6YG(&ES(&UI<W-I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@("`@(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y('=I
M=&@@86QL('!A<F%M971E<G,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV
M97(@("`@5&AE(&ME>2!N86UE("AI;B!T:&4@8V]N9FEG=7)A=&EO;B!A<G)A
M>2D@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9')I
M=F5R+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:65L9',@("`@($%N(&%R<F%Y
M('=I=&@@;6%N9&%T;W)Y('!A<F%M971E<B!N86UE<R!F;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&ES(&1R:79E<BX*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@("!4:&4@8VQE87(@=&5X="!N86UE(&]F
M('1H92!D<FEV97(N($EF(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@('-P96-I9FEE9"P@=&AE(&%P<&QI8V%T:6]N(&YA;64@=VEL;"!B
M92!U<V5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@("`@(%1H92!C
M;VYF:6=U<F%T:6]N(&9I;&4@=&AA="!S:&]U;&0@8V]N=&%I;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@('1H97-E('-E='1I;F=S+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F%R:6%B;&4@(%1H92!N86UE(&]F('1H92!C
M;VYF:6=U<F%T:6]N('9A<FEA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M<W-E<G1$<FEV97)#;VYF:6<H)'!A<F%M<RP@)&1R:79E<BP@)&9I96QD<RP@
M)&YA;64@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1F:6QE(#T@)V-O;F8N<&AP)RP@)'9A<FEA8FQE(#T@)R1C;VYF)RD*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O+R!$;VXG
M="!G96YE<F%T92!A(&9A=&%L(&5R<F]R(&EF('=E(&9A:6P@9'5R:6YG(&]R
M(&)E9F]R90H@("`@("`@("\O(%)E9VES=')Y(&EN<W1A;G1I871I;VXN"B`@
M("`@("`@:68@*&ES7VYU;&PH)&YA;64I*2!["B`@("`@("`@("`@("1N86UE
M(#T@:7-S970H)')E9VES=')Y*2`_("1R96=I<W1R>2T^9V5T07!P*"D@.B`G
M6W5N:VYO=VY=)SL*("`@("`@("!]"B`@("`@("`@)&9I;&5R;V]T(#T@:7-S
M970H)')E9VES=')Y*2`_("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<I(#H@
M)R<["@H@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M<RD@?'P@(6-O=6YT
M*"1P87)A;7,I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR
M86ES945R<F]R*`H@("`@("`@("`@("`@("`@<W!R:6YT9BA?*").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(BDL("1N
M86UE*2`N(")<;EQN(B`N"B`@("`@("`@("`@("`@("!S<')I;G1F*%\H(E1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(BDL
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&5R;V]T("X@)R]C;VYF:6<O)R`N
M("1F:6QE+`H@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H(B5S6R<E<R==
M6R=P87)A;7,G72(L("1V87)I86)L92P@)&1R:79E<BDI*2P*("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D9FEE;&1S(&%S("1F:65L9"D@>PH@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1P87)A;7-;)&9I96QD72DI('L*("`@("`@("`@("`@("`@
M($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*`H@("`@("`@("`@("`@
M("`@("`@('-P<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB*2P@)&9I96QD+"`D;F%M92D@+B`B
M7&Y<;B(@+@H@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEL97)O;W0@+B`G+V-O;F9I9R\G("X@)&9I
M;&4L"B`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H(B5S6R<E<R==
M6R=P87)A;7,G75LG)7,G72(L("1V87)I86)L92P@)&1R:79E<BP@)&9I96QD
M*2DI+`H@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@<V5S<VEO;BUI9"UI9FEE9"!V97)S:6]N(&]F("1U<FDN
M"B`@("`@*B!)9B!A(&9U;&P@55),(&ES(')E<75E<W1E9"P@86QL('!A<F%M
M971E<B!S97!A<F%T;W)S(&=E="!C;VYV97)T960@=&\*("`@("`J("(F(BP@
M;W1H97)W:7-E('1O("(F86UP.R(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7)I("`@("`@("`@("`@("!4:&4@55))('1O(&)E(&UO9&EF:65D
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9U;&P@("`@("`@("`@("!'96YE
M<F%T92!A(&9U;&P@*&AT='`Z+R]S97)V97(O<&%T:"\I"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%523"X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1A<'!E;F1?<V5S<VEO;B`@,"`](&]N;'D@:68@;F5E9&5D
M+"`Q(#T@86QW87ES+"`M,2`]"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YE=F5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@55),('=I=&@@=&AE('-E<W-I;VX@:60@87!P96YD960@*&EF
M(&YE961E9"DN"B`@("`@*B\*("`@(&9U;F-T:6]N('5R;"@D=7)I+"`D9G5L
M;"`](&9A;'-E+"`D87!P96YD7W-E<W-I;VX@/2`P+"`D9F]R8V5?<W-L(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1F;W)C95]S<VPI('L*("`@("`@
M("`@("`@)&9U;&P@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@:68@*"1F
M=6QL*2!["B`@("`@("`@("`@(&=L;V)A;"`D8V]N9BP@)')E9VES=')Y+"`D
M8G)O=W-E<CL*"B`@("`@("`@("`@("\J(%-T;W)E(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<R!I;B!L;V-A;"!V87)I86)L97,N("HO"B`@("`@("`@("`@("1S
M97)V97)?;F%M92`]("1C;VYF6R=S97)V97(G75LG;F%M92==.PH@("`@("`@
M("`@("`D<V5R=F5R7W!O<G0@/2`D8V]N9ELG<V5R=F5R)UU;)W!O<G0G73L*
M"B`@("`@("`@("`@("1P<F]T;V-O;"`]("=H='1P)SL*("`@("`@("`@("`@
M:68@*"1C;VYF6R=U<V5?<W-L)UT@/3T@,2D@>PH@("`@("`@("`@("`@("`@
M)'!R;W1O8V]L(#T@)VAT='!S)SL*("`@("`@("`@("`@?2!E;'-E:68@*"1C
M;VYF6R=U<V5?<W-L)UT@/3T@,B`F)@H@("`@("`@("`@("`@("`@("`@("`@
M)&)R;W=S97(M/G5S:6YG4U-,0V]N;F5C=&EO;B@I*2!["B`@("`@("`@("`@
M("`@("`D<')O=&]C;VP@/2`G:'1T<',G.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&-O;F9;)W5S95]S<VPG72`]/2`S*2!["B`@("`@("`@("`@("`@("`D
M<V5R=F5R7W!O<G0@/2`G)SL*("`@("`@("`@("`@("`@(&EF("@D9F]R8V5?
M<W-L*2!["B`@("`@("`@("`@("`@("`@("`@)'!R;W1O8V]L(#T@)VAT='!S
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@268@=7-I;F<@;F]N+7-T86YD87)D('!O<G1S+"!A9&0@=&AE('!O
M<G0@=&\@=&AE(%523"X@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D<V5R
M=F5R7W!O<G0I("8F"B`@("`@("`@("`@("`@("`H*"@D<')O=&]C;VP@/3T@
M)VAT='`G*2`F)B`H)'-E<G9E<E]P;W)T("$](#@P*2D@?'P*("`@("`@("`@
M("`@("`@("`H*"1P<F]T;V-O;"`]/2`G:'1T<',G*2`F)B`H)'-E<G9E<E]P
M;W)T("$](#0T,RDI*2D@>PH@("`@("`@("`@("`@("`@)'-E<G9E<E]N86UE
M("X]("<Z)R`N("1S97)V97)?<&]R=#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@4W1O<F4@=&AE('=E8G)O;W0@:6X@82!L;V-A;"!V87)I86)L
M92X@*B\*("`@("`@("`@("`@)'=E8G)O;W0@/2`D<F5G:7-T<GDM/F=E="@G
M=V5B<F]O="<I.PH*("`@("`@("`@("`@)'5R;"`]("1P<F]T;V-O;"`N("<Z
M+R\G("X@)'-E<G9E<E]N86UE.PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1U
M<FDL(#`L(#$I("$]("<O)RD@>PH@("`@("`@("`@("`@("`@:68@*'-U8G-T
M<B@D=V5B<F]O="P@+3$I(#T]("<O)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1U<FP@+CT@)'=E8G)O;W0@+B`D=7)I.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D=7)L("X]("1W96)R;V]T("X@
M)R\G("X@)'5R:3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1U<FP@+CT@)'5R:3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1U<FP@/2`D=7)I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D87!P96YD7W-E<W-I;VX@/3T@
M,2D@?'P*("`@("`@("`@("`@*"@D87!P96YD7W-E<W-I;VX@/3T@,"D@)B8*
M("`@("`@("`@("`@("%I<W-E="@D7T-/3TM)15MS97-S:6]N7VYA;64H*5TI
M*2D@>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U
M<FPL('-E<W-I;VY?;F%M92@I+"!S97-S:6]N7VED*"DI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1F=6QL*2!["B`@("`@("`@("`@("\J(%=E(&YE960@
M=&\@<G5N('1H92!R97!L86-E('1W:6-E+"!B96-A=7-E('=E(&]N;'D@8V%T
M8V@@979E<GD*("`@("`@("`@("`@("H@<V5C;VYD(&UA=&-H+B`J+PH@("`@
M("`@("`@("!R971U<FX@<')E9U]R97!L86-E*&%R<F%Y*"<O*#T_+BH_*29A
M;7`[*"XJ/STI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R\H/3\N*C\I)F%M<#LH+BH_/2DO)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R0Q)B0R)RP@)'5R;"D["B`@("`@("`@?2!E
M;'-E:68@*'!R96=?;6%T8V@H)R\]+BHF86UP.RXJ/2\G+"`D=7)L*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'5R;#L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@:'1M;&5N=&ET:65S*"1U<FPI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S97-S:6]N+6ED+6EF
M:65D('9E<G-I;VX@;V8@)'5R:2P@=7-I;F<@=&AE(&-U<G)E;G0*("`@("`J
M(&%P<&QI8V%T:6]N)W,@=V5B<F]O="!S971T:6YG+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'5R:2`@("`@("`@("`@("`@5&AE(%5222!T;R!B
M92!M;V1I9FEE9"X*("`@("`J($!P87)A;2!B;V]L96%N("1F=6QL("`@("`@
M("`@("`@1V5N97)A=&4@82!F=6QL("AH='1P.B\O<V5R=F5R+W!A=&@O*0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!54DPN"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D87!P96YD7W-E<W-I;VX@(#`@/2!O;FQY
M(&EF(&YE961E9"P@,2`](&%L=V%Y<RP@+3$@/0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!N979E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('5R;"!W:71H('1H92!S97-S:6]N(&ED(&%P
M<&5N9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L:6-A=&EO;E5R;"@D
M=7)I+"`D9G5L;"`](&9A;'-E+"`D87!P96YD7W-E<W-I;VX@/2`P*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("\J(%-T;W)E
M('1H92!W96)R;V]T(&EN(&$@;&]C86P@=F%R:6%B;&4N("HO"B`@("`@("`@
M)'=E8G)O;W0@/2`D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<I.PH*("`@("`@
M("!I9B`H)&9U;&PI('L*("`@("`@("`@("`@<F5T=7)N($AO<F1E.CIU<FPH
M)'5R:2P@)&9U;&PL("1A<'!E;F1?<V5S<VEO;BD["B`@("`@("`@?2!E;'-E
M:68@*'-U8G-T<B@D=V5B<F]O="P@+3$I(#T]("<O)RD@>PH@("`@("`@("`@
M("!R971U<FX@2&]R9&4Z.G5R;"@D=V5B<F]O="`N("1U<FDL("1F=6QL+"`D
M87!P96YD7W-E<W-I;VXI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!(;W)D93HZ=7)L*"1W96)R;V]T("X@)R\G("X@)'5R:2P@)&9U
M;&PL("1A<'!E;F1?<V5S<VEO;BD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A;B!E>'1E<FYA;"!L:6YK('!A<W-E9"!T:')O
M=6=H('1H92!D97)E9F5R97(@=&\@<W1R:7`@<V5S<VEO;@H@("`@("H@241S
M(&9R;VT@=&AE(')E9F5R97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7)L("`@5&AE(&5X=&5R;F%L(%523"!T;R!L:6YK('1O+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'1A9R`@268@=')U92P@82!C;VUP;&5T92`\83X@
M=&%G(&ES(')E='5R;F5D+"!O;FQY('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@=7)L(&]T:&5R=VES92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&-O<G)E8W0@;&EN:R!T;R!T:&4@9&5R969E<F5R('-C
M<FEP="X*("`@("`J+PH@("`@9G5N8W1I;VX@97AT97)N86Q5<FPH)'5R;"P@
M)'1A9R`](&9A;'-E*0H@("`@>PH@("`@("`@("1E>'0@/2!(;W)D93HZ=7)L
M*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G
M*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@)R]S97)V:6-E<R]G;RYP
M:'`G+"!T<G5E+"`M,2D["@H@("`@("`@("\J(%=E(&UU<W0@;6%K92!S=7)E
M('1H97)E(&%R92!N;R`F86UP)W,@:6X@=&AE(%523"X@*B\*("`@("`@("`D
M=7)L(#T@<')E9U]R97!L86-E*&%R<F%Y*"<O*#T_+BH_*29A;7`[*"XJ/STI
M+R<L("<O*#T_+BH_*29A;7`[*"XJ/STI+R<I+"`G)#$F)#(G+"`D=7)L*3L*
M("`@("`@("`D97AT(#T@571I;#HZ861D4&%R86UE=&5R*"1E>'0L("=U<FPG
M+"`D=7)L*3L*("`@("`@("!I9B`H)'1A9RD@>PH@("`@("`@("`@("`D97AT
M(#T@2&]R9&4Z.FQI;FLH)&5X="P@)'5R;"P@)R<L("=?8FQA;FLG*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1E>'0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@55),('1O(&)E('5S960@9F]R(&1O=VYL;V%D:6YG
M+"!T:&%T('1A:V5S(&EN=&\@86-C;W5N="!A;GD*("`@("`J('-P96-I86P@
M8G)O=W-E<B!Q=6ER:W,@*&DN92X@244G<R!B<F]K96X@9FEL96YA;64@:&%N
M9&QI;F<I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE
M("!4:&4@9FEL96YA;64@;V8@=&AE(&1O=VYL;V%D(&1A=&$N"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@("`@06YY(&%D9&ET:6]N86P@<&%R86UE
M=&5R<R!N965D960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@("`@
M5&AE(%523"!T;R!A;'1E<BX@268@;F]N92!P87-S960@:6XL('=I;&P@=7-E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&9I;&4@)W9I
M97<N<&AP)R!L;V-A=&5D(&EN('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@;6]D=6QE)W,@8F%S92!D:7)E8W1O<GDN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D;W=N;&]A9"!54DPN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O=VYL;V%D57)L*"1F:6QE;F%M92P@
M)'!A<F%M<R`](&%R<F%Y*"DL("1U<FP@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D8G)O=W-E<CL*"B`@("`@("`@)&AO<F1E7W5R;"`](&9A;'-E
M.PH*("`@("`@("!I9B`H:7-?;G5L;"@D=7)L*2D@>PH@("`@("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D
M4&%R86UE=&5R*$AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G
M+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O9&]W;FQO860O)RDL("=M;V1U;&4G
M+"`D<F5G:7-T<GDM/F=E=$%P<"@I*3L*("`@("`@("`@("`@)&AO<F1E7W5R
M;"`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!!9&0@<&%R86UE=&5R
M<RX@*B\*("`@("`@("!I9B`H(6ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@
M("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`D<&%R86US
M*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E(&%R92!U<VEN9R!T:&4@
M9&5F875L="!(;W)D92!D;W=N;&]A9"!L:6YK+"!A9&0@=&AE"B`@("`@("`@
M("H@9FEL96YA;64@=&\@=&AE(&5N9"!O9B!T:&4@55),+B!!;'1H;W5G:"!N
M;W0@;F5C97-S87)Y(&9O<@H@("`@("`@("`J(&UA;GD@8G)O=W-E<G,L('1H
M:7,@<VAO=6QD(&%L;&]W(&5V97)Y(&)R;W=S97(@=&\@9&]W;FQO860*("`@
M("`@("`@*B!C;W)R96-T;'DN("HO"B`@("`@("`@:68@*"1H;W)D95]U<FPI
M('L*("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G9FXG+"`G+R<@+B!R87=U<FQE;F-O9&4H)&9I;&5N86UE*2D["B`@("`@
M("`@?2!E;'-E:68@*"1B<F]W<V5R+3YH87-1=6ER:R@G8G)E86M?9&ES<&]S
M:71I;VY?9FEL96YA;64G*2D@>PH@("`@("`@("`@("`O*B!3;VUE(&)R;W=S
M97)S('=I;&P@;VYL>2!O8G1A:6X@=&AE(&9I;&5N86UE(&-O<G)E8W1L>0H@
M("`@("`@("`@("`@*B!I9B!T:&4@97AT96YS:6]N(&ES('1H92!L87-T(&%R
M9W5M96YT(&EN('1H92!Q=65R>0H@("`@("`@("`@("`@*B!S=')I;F<@86YD
M(')E<W0@;V8@=&AE(&9I;&5N86UE(&%P<&5A<G,@:6X@=&AE"B`@("`@("`@
M("`@("`J(%!!5$A?24Y&3R!E;&5M96YT+B`J+PH@("`@("`@("`@("`D9FEL
M96YA;64@/2!R87=U<FQE;F-O9&4H)&9I;&5N86UE*3L*"B`@("`@("`@("`@
M("\J($=E="!T:&4@=V5B<V5R=F5R($E$+B`J+PH@("`@("`@("`@("`D<V5R
M=F5R(#T@2&]R9&4Z.G=E8E-E<G9E<DE$*"D["@H@("`@("`@("`@("`O*B!'
M970@=&AE(&YA;64@86YD(&5X=&5N<VEO;B!O9B!T:&4@9FEL92X@($%P86-H
M92`R(&1O97,*("`@("`@("`@("`@("H@3D]4('-U<'!O<G0@4$%42%])3D9/
M(&EN9F]R;6%T:6]N(&)E:6YG('!A<W-E9"!T;R!T:&4*("`@("`@("`@("`@
M("H@4$A0(&UO9'5L92!B>2!D969A=6QT+"!S;R!D:7-A8FQE('1H870*("`@
M("`@("`@("`@("H@9G5N8W1I;VYA;&ET>2X@*B\*("`@("`@("`@("`@:68@
M*"@D<V5R=F5R("$]("=A<&%C:&4R)RDI('L*("`@("`@("`@("`@("`@(&EF
M("@H)'!O<R`]('-T<G)P;W,H)&9I;&5N86UE+"`G+B<I*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1N86UE(#T@)R\G("X@<')E9U]R97!L86-E*"<O7"XO
M)RP@)R4R12<L('-U8G-T<B@D9FEL96YA;64L(#`L("1P;W,I*3L*("`@("`@
M("`@("`@("`@("`@("`D97AT(#T@<W5B<W1R*"1F:6QE;F%M92P@)'!O<RD[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1N86UE(#T@)R\G("X@)&9I;&5N86UE.PH@("`@("`@("`@("`@("`@("`@
M("1E>'0@/2`G)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`O*B!%;G1E<B!T:&4@4$%42%])3D9/(&EN9F]R;6%T:6]N+B`J+PH@("`@
M("`@("`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1U<FPL("<_)RDI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'5R;"`]('-U8G-T<B@D=7)L+"`P+"`D
M<&]S*2`N("1N86UE("X@<W5B<W1R*"1U<FPL("1P;W,I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=7)L("X]("1N
M86UE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!!<'!E;F0@=&AE(&5X=&5N<VEO;BP@:68@:70@97AI<W1S+B`J
M+PH@("`@("`@("`@("!I9B`H*"1S97)V97(@/3T@)V%P86-H93(G*2!\?"`A
M96UP='DH)&5X="DI('L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA
M9&1087)A;65T97(H)'5R;"P@)V9N7V5X="<L("<O)R`N("1F:6QE;F%M92D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7)L
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A;F-H;W(@=&%G
M('=I=&@@=&AE(')E;&5V86YT('!A<F%M971E<G,*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<FP@("`@("`@(%1H92!F=6QL(%523"!T;R!B92!L
M:6YK960@=&\N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T:71L92`@("`@(%1H
M92!L:6YK('1I=&QE+V1E<V-R:7!T:6]N+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8VQA<W,@("`@("!4:&4@0U-3(&-L87-S(&]F('1H92!L:6YK+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T("`@("!4:&4@=VEN9&]W('1A<F=E
M="!T;R!P;VEN="!T;RX*("`@("`J($!P87)A;2!S=')I;F<@)&]N8VQI8VL@
M("`@2F%V85-C<FEP="!A8W1I;VX@9F]R('1H92`G;VYC;&EC:R<@979E;G0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T:71L93(@("`@(%1H92!L:6YK('1I
M=&QE("AT;V]L=&EP*2`H9&5P<F5C871E9"`M(&IU<W0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=7-E("1T:71L92DN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A8V-E<W-K97D@(%1H92!A8V-E<W,@:V5Y('1O('5S92X*
M("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E<R`@06YY(&]T:&5R(&YA
M;64O=F%L=64@<&%I<G,@=&\@861D('1O('1H92`\83X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&%G+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&5S8V%P92`@("!7:&5T:&5R('1O(&5S8V%P92!S<&5C:6%L(&-H87)A
M8W1E<G,@:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1I=&QE(&%T=')I8G5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&9U;&P@/&$@:')E9CX@=&%G+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L:6YK*"1U<FPL("1T:71L92`]("<G+"`D8VQA<W,@/2`G)RP@)'1A<F=E
M="`]("<G+"`D;VYC;&EC:R`]("<G+`H@("`@("`@("`@("`@("`@("`D=&ET
M;&4R(#T@)R<L("1A8V-E<W-K97D@/2`G)RP@)&%T=')I8G5T97,@/2!A<G)A
M>2@I+`H@("`@("`@("`@("`@("`@("`D97-C87!E(#T@=')U92D*("`@('L*
M("`@("`@("!S=&%T:6,@)&-H87)S970["B`@("`@("`@:68@*"%I<W-E="@D
M8VAA<G-E="DI('L*("`@("`@("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H
M87)S970H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'1I=&QE
M,BDI('L*("`@("`@("`@("`@)'1I=&QE(#T@)'1I=&QE,CL*("`@("`@("!]
M"@H@("`@("`@("1R970@/2`B/&$@:')E9CU<(B1U<FQ<(B(["B`@("`@("`@
M:68@*"%E;7!T>2@D;VYC;&EC:RDI('L*("`@("`@("`@("`@)')E="`N/2`B
M(&]N8VQI8VL]7"(D;VYC;&EC:UPB(CL*("`@("`@("!]"B`@("`@("`@:68@
M*"%E;7!T>2@D8VQA<W,I*2!["B`@("`@("`@("`@("1R970@+CT@(B!C;&%S
M<SU<(B1C;&%S<UPB(CL*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D
M=&%R9V5T*2D@>PH@("`@("`@("`@("`D<F5T("X]("(@=&%R9V5T/5PB)'1A
M<F=E=%PB(CL*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D=&ET;&4I
M*2!["B`@("`@("`@("`@(&EF("@D97-C87!E*2!["B`@("`@("`@("`@("`@
M("`D=&ET;&4@/2!N;#)B<BA`:'1M;'-P96-I86QC:&%R<RA`:'1M;'-P96-I
M86QC:&%R<R@D=&ET;&4L($5.5%]154]415,L("1C:&%R<V5T*2P@14Y47U%5
M3U1%4RP@)&-H87)S970I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<F5T("X]("<@=&ET;&4](B<@+B`D=&ET;&4@+B`G(B<["B`@("`@("`@?0H@
M("`@("`@(&EF("@A96UP='DH)&%C8V5S<VME>2DI('L*("`@("`@("`@("`@
M)')E="`N/2`G(&%C8V5S<VME>3TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&%C
M8V5S<VME>2D@+B`G(B<["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D
M871T<FEB=71E<R!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@
M)')E="`N/2`G("<@+B!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2`N("<](B<@
M+B!H=&UL<W!E8VEA;&-H87)S*"1V86QU92D@+B`G(B<["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@(B1R970^(CL*("`@('T*"B`@("`O*BH*("`@("`J
M(%5S97,@1$]-(%1O;VQT:7!S('1O(&1I<W!L87D@=&AE("=T:71L92<@871T
M<FEB=71E(&9O<@H@("`@("H@2&]R9&4Z.FQI;FLH*2!C86QL<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@("`@(%1H92!F=6QL(%52
M3"!T;R!B92!L:6YK960@=&\*("`@("`J($!P87)A;2!S=')I;F<@)'-T871U
M<R`@("`@5&AE($IA=F%38W)I<'0@;6]U<V4M;W9E<B!S=')I;F<*("`@("`J
M($!P87)A;2!S=')I;F<@)&-L87-S("`@("`@5&AE($-34R!C;&%S<R!O9B!T
M:&4@;&EN:PH@("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T("`@("!4:&4@
M=VEN9&]W('1A<F=E="!T;R!P;VEN="!T;RX*("`@("`J($!P87)A;2!S=')I
M;F<@)&]N8VQI8VL@("`@2F%V85-C<FEP="!A8W1I;VX@9F]R('1H92`G;VYC
M;&EC:R<@979E;G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T:71L92`@("`@
M(%1H92!L:6YK('1I=&QE("AT;V]L=&EP*2X*("`@("`J($!P87)A;2!S=')I
M;F<@)&%C8V5S<VME>2`@5&AE(&%C8V5S<R!K97D@=&\@=7-E+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("`D871T<FEB=71E<R!!;GD@;W1H97(@;F%M92]V86QU
M92!P86ER<R!T;R!A9&0@=&\@=&AE(#QA/@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T86<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!F=6QL(#QA(&AR968^('1A9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&EN:U1O;VQT:7`H)'5R;"P@)'-T871U<R`]("<G+"`D8VQA<W,@/2`G
M)RP@)'1A<F=E="`]("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&]N
M8VQI8VL@/2`G)RP@)'1I=&QE(#T@)R<L("1A8V-E<W-K97D@/2`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!S=&%T:6,@)&-H87)S970["B`@("`@("`@:68@*"%I
M<W-E="@D8VAA<G-E="DI('L*("`@("`@("`@("`@)&-H87)S970@/2!.3%,Z
M.F=E=$-H87)S970H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH
M)'1I=&QE*2D@>PH@("`@("`@("`@("`D=&ET;&4@/2`G)FQT.W!R929G=#LG
M("X@<')E9U]R97!L86-E*&%R<F%Y*"<O7&XO)RP@)R\H*#\\(3QB<BE<<WLQ
M+'TH/SPA7"\^*2DO96TG+"`G+SQB<B!<+SX\8G(@7"\^+R<L("<O/&)R(%PO
M/B\G*2P@87)R87DH)R<L("=S=')?<F5P96%T*"(F;F)S<#LB+"!S=')L96XH
M(B0Q(BDI)RP@)R9L=#MB<B`O)F=T.R`F;'0[8G(@+R9G=#LG+"`G)FQT.V)R
M("\F9W0[)RDL(&YL,F)R*$!H=&UL<W!E8VEA;&-H87)S*$!H=&UL<W!E8VEA
M;&-H87)S*"1T:71L92P@14Y47U%53U1%4RP@)&-H87)S970I+"!%3E1?455/
M5$53+"`D8VAA<G-E="DI*2`N("<F;'0[+W!R929G=#LG.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@2&]R9&4Z.FQI;FLH)'5R;"P@)'1I=&QE+"`D8VQA
M<W,L("1T87)G970L("1O;F-L:6-K+"!N=6QL+"`D86-C97-S:V5Y+"`D871T
M<FEB=71E<RP@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A;B!A;F-H;W(@<V5Q=65N8V4@=VET:"!T:&4@<F5L979A;G0@<&%R86UE
M=&5R<R!F;W(@82!W:61G970*("`@("`J('=I=&@@86-C97-S:V5Y(&%N9"!T
M97AT+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'5R;"`@("`@(%1H92!F=6QL(%523"!T;R!B
M92!L:6YK960@=&\N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&ET;&4@("`@
M5&AE(&QI;FL@=&ET;&4O9&5S8W)I<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D8VQA<W,@("`@5&AE($-34R!C;&%S<R!O9B!T:&4@;&EN:PH@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'1A<F=E="`@(%1H92!W:6YD;W<@=&%R9V5T
M('1O('!O:6YT('1O+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&]N8VQI8VL@
M($IA=F%38W)I<'0@86-T:6]N(&9O<B!T:&4@)V]N8VQI8VLG(&5V96YT+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'1I=&QE,B`@(%1H92!L:6YK('1I=&QE
M("AT;V]L=&EP*2`H9&5P<F5C871E9"`M(&IU<W0@=7-E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1I=&QE*2X*("`@("`J($!P87)A;2!B
M;V]L96%N("1N;V-H96-K("!$;VXG="!C:&5C:R!I9B!T:&4@86-C97-S(&ME
M>2!A;')E861Y(&AA<R!B965N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@=7-E9"X@1&5F875L=',@=&\@9F%L<V4@*#T@8VAE8VLI+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"`\82!H<F5F/E1I
M=&QE/"]A/B!S97%U96YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@=VED9V5T
M*"1U<FPL("1T:71L92`]("<G+"`D8VQA<W,@/2`G=VED9V5T)RP@)'1A<F=E
M="`]("<G+`H@("`@("`@("`@("`@("`@("`@("1O;F-L:6-K(#T@)R<L("1T
M:71L93(@/2`G)RP@)&YO8VAE8VL@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H(65M<'1Y*"1T:71L93(I*2!["B`@("`@("`@("`@("1T:71L92`]("1T
M:71L93(["B`@("`@("`@?0H*("`@("`@("`D86L@/2!(;W)D93HZ9V5T06-C
M97-S2V5Y*"1T:71L92P@)&YO8VAE8VLI.PH*("`@("`@("!R971U<FX@2&]R
M9&4Z.FQI;FLH)'5R;"P@)R<L("1C;&%S<RP@)'1A<F=E="P@)&]N8VQI8VLL
M("<G+"`D86LI("X@2&]R9&4Z.FAI9VAL:6=H=$%C8V5S<TME>2@D=&ET;&4L
M("1A:RD@+B`G/"]A/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@<V5S<VEO;BUI9"UI9FEE9"!V97)S:6]N(&]F("130U))4%1?3D%-12!R
M97-P+B`D4$A07U-%3$8N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)'%U97)Y7W-T<FEN9R`@26YC;'5D92!A;GD@455%4EE?4U1224Y'/PH@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&YO8V%C:&4@("`@("`@26YC;'5D92!A(&YO
M8V%C:&4@<&%R86UE=&5R(&EN('1H92!54DP_"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D9G5L;"`@("`@("`@("!2971U<FX@82!F=6QL(%523#\*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E<75E<W1E9"!54DDN"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E;&95<FPH)'%U97)Y7W-T<FEN9R`](&9A
M;'-E+"`D;F]C86-H92`]('1R=64L("1F=6QL(#T@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("1F;W)C95]S<VP@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H<W5B<W1R*'!H<%]S87!I7VYA;64H*2P@,"P@,RD@/3T@)V-G:2<I
M('L*("`@("`@("`@("`@+R\@5VAE;B!U<VEN9R!#1TD@4$A0+"!30U))4%1?
M3D%-12!M87D@8V]N=&%I;B!T:&4@<&%T:"!T;PH@("`@("`@("`@("`O+R!T
M:&4@4$A0(&)I;F%R>2!I;G-T96%D(&]F('1H92!S8W)I<'0@8F5I;F<@<G5N
M.R!U<V4*("`@("`@("`@("`@+R\@4$A07U-%3$8@:6YS=&5A9"X*("`@("`@
M("`@("`@)'5R;"`]("1?4T525D526R=02%!?4T5,1B==.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1U<FP@/2!I<W-E="@D7U-%4E9%4ELG4T-2
M25!47TY!344G72D@/PH@("`@("`@("`@("`@("`@)%]315)615);)U-#4DE0
M5%].04U%)UT@.@H@("`@("`@("`@("`@("`@)%]315)615);)U!(4%]314Q&
M)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H)'%U97)Y7W-T<FEN9R`F)B`A
M96UP='DH)%]315)615);)U%515)97U-44DE.1R==*2D@>PH@("`@("`@("`@
M("`D=7)L("X]("<_)R`N("1?4T525D526R=1545265]35%))3D<G73L*("`@
M("`@("!]"@H@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1U<FPL("1F=6QL
M+"`P+"`D9F]R8V5?<W-L*3L*"B`@("`@("`@:68@*"1N;V-A8VAE*2!["B`@
M("`@("`@("`@(')E='5R;B!5=&EL.CIN;V-A8VAE57)L*"1U<FPI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=7)L.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!C;W)R96-T
M;'DM<&%T:&5D(&QI;FL@=&\@86X@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<W)C("`@5&AE(&EM86=E(&9I;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A;'0@("!497AT(&1E<V-R:6)I;F<@=&AE(&EM86=E+@H@
M("`@("H@0'!A<F%M(&UI>&5D("`D871T<B`@06YY(&%D9&ET:6]N86P@871T
M<FEB=71E<R!F;W(@=&AE(&EM86=E('1A9RX@0V%N(&)E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!A('!R92UB=6EL="!S=')I;F<@;W(@86X@87)R
M87D@;V8@:V5Y+W9A;'5E('!A:7)S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("!T:&%T('=I;&P@8F4@87-S96UB;&5D(&%N9"!H=&UL+65N8V]D960N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D:7(@("!4:&4@<F]O="!G<F%P:&EC
M<R!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!F=6QL(&EM86=E('1A9RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6UG*"1S
M<F,L("1A;'0@/2`G)RP@)&%T='(@/2`G)RP@)&1I<B`](&YU;&PI"B`@("![
M"B`@("`@("`@<W1A=&EC("1C:&%R<V5T.PH@("`@("`@(&EF("@A:7-S970H
M)&-H87)S970I*2!["B`@("`@("`@("`@("1C:&%R<V5T(#T@3DQ3.CIG971#
M:&%R<V5T*"D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@:6UA9V5S+"!S:6UP;'D@<F5T=7)N('1H92!!3%0@
M=&5X="X@*B\*("`@("`@("!I9B`H(21'3$]"04Q36R=B<F]W<V5R)UTM/FAA
M<T9E871U<F4H)VEM86=E<R<I*2!["B`@("`@("`@("`@(')E='5R;B!`:'1M
M;'-P96-I86QC:&%R<R@D86QT+"!%3E1?0T]-4$%4+"`D8VAA<G-E="D["B`@
M("`@("`@?0H*("`@("`@("`O*B!)9B!N;R!D:7)E8W1O<GD@:&%S(&)E96X@
M<W!E8VEF:65D+"!G970@:70@9G)O;2!T:&4@<F5G:7-T<GDN("HO"B`@("`@
M("`@:68@*"1D:7(@/3T](&YU;&PI('L*("`@("`@("`@("`@9VQO8F%L("1R
M96=I<W1R>3L*("`@("`@("`@("`@)&1I<B`]("1R96=I<W1R>2T^9V5T26UA
M9V5$:7(H*3L*("`@("`@("!]"@H@("`@("`@("\J($EF(&$@9&ER96-T;W)Y
M(&AA<R!B965N('!R;W9I9&5D+"!P<F5P96YD(&ET('1O('1H92!I;6%G92!S
M;W5R8V4N("HO"B`@("`@("`@:68@*"%E;7!T>2@D9&ER*2D@>PH@("`@("`@
M("`@("`D<W)C(#T@)&1I<B`N("<O)R`N("1S<F,["B`@("`@("`@?0H*("`@
M("`@("`O*B!"=6EL9"!A;&P@;V8@=&AE('1A9R!A='1R:6)U=&5S+B`J+PH@
M("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH)W-R8R<@/3X@)'-R8RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=A;'0G(#T^("1A;'0I.PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D871T<BDI('L*("`@("`@("`@("`@)&%T=')I
M8G5T97,@/2!A<G)A>5]M97)G92@D871T<FEB=71E<RP@)&%T='(I.PH@("`@
M("`@('T*"B`@("`@("`@)&EM9R`]("<\:6UG)SL*("`@("`@("!F;W)E86-H
M("@D871T<FEB=71E<R!A<R`D871T<FEB=71E(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`D:6UG("X]("<@)R`N("1A='1R:6)U=&4@+B`G/2(G("X@*"1A
M='1R:6)U=&4@/3T@)W-R8R<@/R`D=F%L=64@.B!`:'1M;'-P96-I86QC:&%R
M<R@D=F%L=64L($5.5%]#3TU0050L("1C:&%R<V5T*2D@+B`G(B<["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!T:&4@=7-E<B!S=7!P;&EE9"!A('!R92UB
M=6EL="!S=')I;F<@;V8@871T<FEB=71E<RP@861D('1H870N("HO"B`@("`@
M("`@:68@*&ES7W-T<FEN9R@D871T<BD@)B8@(65M<'1Y*"1A='1R*2D@>PH@
M("`@("`@("`@("`D:6UG("X]("<@)R`N("1A='1R.PH@("`@("`@('T*"B`@
M("`@("`@+RH@4F5T=7)N('1H92!C;&]S960@:6UA9V4@=&%G+B`J+PH@("`@
M("`@(')E='5R;B`D:6UG("X@)R`O/B<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F5S('1H92!L;V-A=&EO;B!O9B!T:&4@<WES=&5M('1E;7!O
M<F%R>2!D:7)E8W1O<GDN($EF(&$@<W!E8VEF:6,*("`@("`J('-E='1I;F<@
M8V%N;F]T(&)E(&9O=6YD+"!I="!D969A=6QT<R!T;R`O=&UP+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!!(&1I<F5C=&]R>2!N86UE('1H870@
M8V%N(&)E('5S960@9F]R('1E;7`@9FEL97,N"B`@("`@*B`@("`@("`@("`@
M("`@("`@4F5T=7)N<R!F86QS92!I9B!O;F4@8V]U;&0@;F]T(&)E(&9O=6YD
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971496UP1&ER*"D*("`@('L*("`@
M("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("\J($EF(&]N92!H87,@8F5E
M;B!S<&5C:69I8V%L;'D@<V5T+"!T:&5N('5S92!T:&%T("HO"B`@("`@("`@
M:68@*"%E;7!T>2@D8V]N9ELG=&UP9&ER)UTI*2!["B`@("`@("`@("`@("1T
M;7`@/2`D8V]N9ELG=&UP9&ER)UT["B`@("`@("`@?0H*("`@("`@("`O*B!.
M97AT+"!T<GD@571I;#HZ9V5T5&5M<$1I<B@I+B`J+PH@("`@("`@(&EF("AE
M;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`D=&UP(#T@571I;#HZ9V5T5&5M
M<$1I<B@I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@:70@:7,@<W1I;&P@
M96UP='DL('=E(&AA=F4@9F%I;&5D+"!S;R!R971U<FX@9F%L<V4["B`@("`@
M("`@("H@;W1H97)W:7-E(')E='5R;B!T:&4@9&ER96-T;W)Y(&1E=&5R;6EN
M960N("HO"B`@("`@("`@<F5T=7)N(&5M<'1Y*"1T;7`I(#\@9F%L<V4@.B`D
M=&UP.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A('1E;7!O<F%R
M>2!F:6QE;F%M92!F;W(@=&AE(&QI9F5T:6UE(&]F('1H92!S8W)I<'0L(&%N
M9`H@("`@("H@*&]P=&EO;F%L;'DI(')E9VES=&5R<R!I="!T;R!B92!D96QE
M=&5D(&%T(')E<75E<W0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<')E9FEX("`@4')E9FEX('1O(&UA:V4@=&AE('1E;7!O<F%R
M>2!N86UE(&UO<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(')E
M8V]G;FEZ86)L92X*("`@("`J($!P87)A;2!B;V]L96%N("1D96QE=&4@($1E
M;&5T92!T:&4@9FEL92!A="!T:&4@96YD(&]F('1H92!R97%U97-T/PH@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&ER("`@("`@1&ER96-T;W)Y('1O(&-R96%T
M92!T:&4@=&5M<&]R87)Y(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D<V5C=7)E("!)9B!D96QE=&EN9R!F:6QE+"!S:&]U;&0@=V4@<V5C=7)E
M;'D@9&5L971E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M9FEL93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%)E='5R;G,@
M=&AE(&9U;&P@<&%T:"UN86UE('1O('1H92!T96UP;W)A<GD@9FEL92!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("!F86QS92!I9B!A('1E;7!O<F%R>2!F
M:6QE(&-O=6QD(&YO="!B92!C<F5A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971496UP1FEL92@D<')E9FEX(#T@)TAO<F1E)RP@)&1E;&5T92`]('1R
M=64L("1D:7(@/2`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1S96-U
M<F4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1I<BD@?'P@
M(6ES7V1I<B@D9&ER*2D@>PH@("`@("`@("`@("`D9&ER(#T@2&]R9&4Z.F=E
M=%1E;7!$:7(H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!5=&EL.CIG
M971496UP1FEL92@D<')E9FEX+"`D9&5L971E+"`D9&ER+"`D<V5C=7)E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-T87)T<R!O=71P=70@8V]M<')E<W-I
M;VXL(&EF(')E<75E<W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<')E
M<W-/=71P=70H*0H@("`@>PH@("`@("`@('-T871I8R`D<W1A<G1E9#L*"B`@
M("`@("`@:68@*&ES<V5T*"1S=&%R=&5D*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`O*B!#;VUP<F5S<R!O=71P=70@:68@
M<F5Q=65S=&5D(&%N9"!P;W-S:6)L92X@*B\*("`@("`@("!I9B`H)$=,3T)!
M3%-;)V-O;F8G75LG8V]M<')E<W-?<&%G97,G72`F)@H@("`@("`@("`@("`A
M)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S475I<FLH)V)U9V=Y7V-O;7!R97-S
M:6]N)RD@)B8*("`@("`@("`@("`@:6YI7V=E="@G>FQI8BYO=71P=71?8V]M
M<')E<W-I;VXG*2`]/2`G)R`F)@H@("`@("`@("`@("!I;FE?9V5T*"=Z96YD
M7V%C8V5L97)A=&]R+F-O;7!R97-S7V%L;"<I(#T]("<G("8F"B`@("`@("`@
M("`@(&EN:5]G970H)V]U='!U=%]H86YD;&5R)RD@(3T@)V]B7V=Z:&%N9&QE
M<B<I('L*("`@("`@("`@("`@:68@*&]B7V=E=%]L979E;"@I*2!["B`@("`@
M("`@("`@("`@("!O8E]E;F1?8VQE86XH*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!O8E]S=&%R="@G;V)?9WIH86YD;&5R)RD["B`@("`@("`@?0H*
M("`@("`@("`D<W1A<G1E9"`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F5S(&EF(&]U='!U="!C;VUP<F5S<VEO;B!C86X@8F4@=7-E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@;W5T
M<'5T(&-O;7!R97-S:6]N(&-A;B!B92!U<V5D+"!F86QS92!I9B!N;W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%L;&]W3W5T<'5T0V]M<')E<W-I;VXH*0H@
M("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0G)O=W-E<BYP:'`G
M.PH@("`@("`@("1B<F]W<V5R(#T@)D)R;W=S97(Z.G-I;F=L971O;B@I.PH*
M("`@("`@("`O*B!4=7)N(&]F9B!C;VUP<F5S<VEO;B!F;W(@8G5G9WD@8G)O
M=W-E<G,N("HO"B`@("`@("`@:68@*"1B<F]W<V5R+3YH87-1=6ER:R@G8G5G
M9WE?8V]M<')E<W-I;VXG*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*&EN:5]G970H)WIL:6(N;W5T
M<'5T7V-O;7!R97-S:6]N)RD@/3T@)R<@)B8*("`@("`@("`@("`@("`@(&EN
M:5]G970H)WIE;F1?86-C96QE<F%T;W(N8V]M<')E<W-?86QL)RD@/3T@)R<@
M)B8*("`@("`@("`@("`@("`@(&EN:5]G970H)V]U='!U=%]H86YD;&5R)RD@
M(3T@)V]B7V=Z:&%N9&QE<B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@5V5B('-E<G9E<B!B96EN9R!U<V5D+@H@("`@("H@4$A0('-T
M<FEN9R!L:7-T(&)U:6QT(&9R;VT@=&AE(%!(4"`G8V]N9FEG=7)E)R!S8W)I
M<'0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@=V5B('-E<G9E
M<B!I9&5N=&EF:6-A=&EO;B!S=')I;F<N"B`@("`@*B`\<')E/@H@("`@("H@
M)V%O;'-E<G9E<B<@/2!!3TP@4V5R=F5R"B`@("`@*B`G87!A8VAE,2<@("`]
M($%P86-H92`Q+G@*("`@("`J("=A<&%C:&4R)R`@(#T@07!A8VAE(#(N>`H@
M("`@("H@)V-A=61I=6TG("`@/2!#875D:75M"B`@("`@*B`G8V=I)R`@("`@
M("`](%5N:VYO=VX@<V5R=F5R("T@4$A0(&)U:6QT(&%S($-'22!P<F]G<F%M
M"B`@("`@*B`G8VQI)R`@("`@("`]($-O;6UA;F0@3&EN92!);G1E<F9A8V4@
M8G5I;&0*("`@("`J("=E;6)E9"<@("`@(#T@16UB961D960@4$A0"B`@("`@
M*B`G:7-A<&DG("`@("`](%IE=7,@25-!4$D*("`@("`J("=M:6QT97(G("`@
M(#T@36EL=&5R"B`@("`@*B`G;G-A<&DG("`@("`]($Y305!)"B`@("`@*B`G
M<&AT='!D)R`@("`](%!(5%101`H@("`@("H@)W!I,W=E8B<@("`@/2!0:3-7
M96(*("`@("`J("=R;WAE;B<@("`@(#T@4F]X96XO4&EK90H@("`@("H@)W-E
M<G9L970G("`@/2!397)V;&5T"B`@("`@*B`G=&AT='!D)R`@("`]('1H='1P
M9`H@("`@("H@)W1U>"<@("`@("`@/2!4=7@*("`@("`J("=W96)J86UE<R<@
M(#T@5V5B:F%M97,*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO
M;B!W96)397)V97))1"@I"B`@("!["B`@("`@("`@)'-E<G9E<B`]('!H<%]S
M87!I7VYA;64H*3L*"B`@("`@("`@:68@*"1S97)V97(@/3T@)V%P86-H92<I
M('L*("`@("`@("`@("`@<F5T=7)N("=A<&%C:&4Q)SL*("`@("`@("!](&5L
M<V5I9B`H*"1S97)V97(@/3T@)V%P86-H93)F:6QT97(G*2!\?`H@("`@("`@
M("`@("`@("`@("`H)'-E<G9E<B`]/2`G87!A8VAE,FAA;F1L97(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)V%P86-H93(G.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D<V5R=F5R.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(#QL:6YK/B!T86=S(&9O<B!T
M:&4@0U-3('-T>6QE<VAE971S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F=\87)R87D@)&%P<"`@5&AE($AO<F1E(&%P<&QI8V%T:6]N*',I+@H@("`@
M("H@0'!A<F%M(&UI>&5D("1T:&5M92`@("`@("!4:&4@=&AE;64@=&\@=7-E
M.R!S<&5C:69Y(&%N(&5M<'1Y('9A;'5E('1O"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E=')I979E('1H92!T:&5M92!F<F]M('5S97(@
M<')E9F5R96YC97,L(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F86QS92!F;W(@;F\@=&AE;64N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D:6YH97)I="`@($EN:&5R:70@2&]R9&4M=VED92!#4U,_"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(#QL:6YK/B!T86=S(&9O<B!#4U,@<W1Y
M;&5S:&5E=',N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T>6QE<VAE971,:6YK
M*"1A<'!S(#T@;G5L;"P@)'1H96UE(#T@)R<L("1I;FAE<FET(#T@=')U92D*
M("`@('L*("`@("`@("!I9B`H)'1H96UE("$]/2!F86QS92`F)B!E;7!T>2@D
M=&AE;64I*2!["B`@("`@("`@("`@("1T:&5M92`]("1'3$]"04Q36R=P<F5F
M<R==+3YG971686QU92@G=&AE;64G*3L*("`@("`@("!]"@H@("`@("`@("1R
M=&P@/2!I<W-E="@D1TQ/0D%,4ULG;FQS)UU;)W)T;"==6R1'3$]"04Q36R=L
M86YG=6%G92==72D["B`@("`@("`@)&-S<R`](&%R<F%Y*"D["@H@("`@("`@
M("1T:&5M97-?9G,@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T:&5M
M97-F<R<L("=H;W)D92<I.PH@("`@("`@(&EF("@D:6YH97)I="D@>PH@("`@
M("`@("`@("`D=&AE;65S7W5R:2`]($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G=&AE;65S=7)I)RP@)VAO<F1E)RDL(&9A;'-E+"`M
M,2D["B`@("`@("`@("`@("1C<W-;72`]("1T:&5M97-?=7)I("X@)R]S8W)E
M96XN8W-S)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AE;64I("8F"B`@
M("`@("`@("`@("`@("!F:6QE7V5X:7-T<R@D=&AE;65S7V9S("X@)R\G("X@
M)'1H96UE("X@)R]S8W)E96XN8W-S)RDI('L*("`@("`@("`@("`@("`@("1C
M<W-;72`]("1T:&5M97-?=7)I("X@)R\G("X@)'1H96UE("X@)R]S8W)E96XN
M8W-S)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1R=&PI('L*
M("`@("`@("`@("`@("`@("1C<W-;72`]("1T:&5M97-?=7)I("X@)R]R=&PN
M8W-S)SL*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H96UE*2`F)@H@
M("`@("`@("`@("`@("`@("`@(&9I;&5?97AI<W1S*"1T:&5M97-?9G,@+B`G
M+R<@+B`D=&AE;64@+B`G+W)T;"YC<W,G*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1C<W-;72`]("1T:&5M97-?=7)I("X@)R\G("X@)'1H96UE("X@)R]R
M=&PN8W-S)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P<RDI('L*("`@("`@("`@
M("`@:68@*"%I<U]A<G)A>2@D87!P<RDI('L*("`@("`@("`@("`@("`@("1A
M<'!S(#T@87)R87DH)&%P<',I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!F;W)E86-H("@D87!P<R!A<R`D87!P*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&EN:&5R:70@)B8@)&%P<"`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@)'1H96UE<U]F<R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG
M970H)W1H96UE<V9S)RP@)&%P<"D["B`@("`@("`@("`@("`@("`D=&AE;65S
M7W5R:2`]($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M=&AE;65S=7)I)RP@)&%P<"DL(&9A;'-E+"`M,2D["B`@("`@("`@("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)'1H96UE<U]F<R`N("<O<V-R965N+F-S<R<I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-S<UM=(#T@)'1H96UE<U]U<FD@
M+B`G+W-C<F5E;BYC<W,G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AE;64I("8F"B`@("`@("`@("`@("`@("`@
M("`@9FEL95]E>&ES=',H)'1H96UE<U]F<R`N("<O)R`N("1T:&5M92`N("<O
M<V-R965N+F-S<R<I*2!["B`@("`@("`@("`@("`@("`@("`@)&-S<UM=(#T@
M)'1H96UE<U]U<FD@+B`G+R<@+B`D=&AE;64@+B`G+W-C<F5E;BYC<W,G.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@D<G1L*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1T:&5M97-?
M9G,@+B`G+W)T;"YC<W,G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O<G1L+F-S<R<["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H
M96UE*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("!F:6QE7V5X:7-T<R@D
M=&AE;65S7V9S("X@)R\G("X@)'1H96UE("X@)R]R=&PN8W-S)RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-S<UM=(#T@)'1H96UE<U]U<FD@+B`G
M+R<@+B`D=&AE;64@+B`G+W)T;"YC<W,G.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&AT;6P@/2`G)SL*("`@("`@("!F;W)E86-H("@D8W-S(&%S
M("1C<W-?;&EN:RD@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&QI;FL@:')E
M9CTB)R`N("1C<W-?;&EN:R`N("<B(')E;#TB<W1Y;&5S:&5E="(@='EP93TB
M=&5X="]C<W,B("\^)R`N(")<;B(["B`@("`@("`@?0H*("`@("`@("`O*B!,
M;V%D($E%(%!.1R!T<F%N<W!A<F5N8WD@8V]D92!I9B!N965D960N("HO"B`@
M("`@("`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<U%U:7)K*"=P;F=?
M=')A;G-P87)E;F-Y)RD@)B8*("`@("`@("`@("`@)$=,3T)!3%-;)W!R969S
M)UTM/F=E=%9A;'5E*"=A;'!H85]F:6QT97(G*2D@>PH@("`@("`@("`@("`D
M=7)L(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=J
M<W5R:2<L("=H;W)D92<I("X@)R]A;'!H84EM86=E3&]A9&5R+G!H<"<L('1R
M=64L("TQ*3L*("`@("`@("`@("`@)&AT;6P@+CT@)SQS='EL92!T>7!E/2)T
M97AT+V-S<R(^(&EM9R![(&)E:&%V:6]R.B!U<FPH(B<@+B`D=7)L("X@)R(I
M.R!](#PO<W1Y;&4^)SL*("`@("`@("!]"@H@("`@("`@("\J($QO860@8G)O
M=W-E<B!S<&5C:69I8R!S='EL97-H965T<R!I9B!N965D960N("HO"B`@("`@
M("`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FES0G)O=W-E<B@G;7-I92<I
M("8F("1'3$]"04Q36R=B<F]W<V5R)UTM/F=E=$UA:F]R*"D@/"`W*2!["B`@
M("`@("`@("`@("1H=&UL("X]("<\;&EN:R!H<F5F/2(G("X@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F=E="@G=&AE;65S=7)I)RP@)VAO<F1E)RD@+B`G+VEE
M-E]O<E]L97-S+F-S<R(@<F5L/2)S='EL97-H965T(B!T>7!E/2)T97AT+V-S
M<R(@+SXG("X@(EQN(CL*("`@("`@("`@("`@:68@*"1'3$]"04Q36R=B<F]W
M<V5R)UTM/F=E=%!L871F;W)M*"D@/3T@)VUA8R<I('L*("`@("`@("`@("`@
M("`@("1H=&UL("X]("<\;&EN:R!H<F5F/2(G("X@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G=&AE;65S=7)I)RP@)VAO<F1E)RD@+B`G+VEE-6UA8RYC
M<W,B(')E;#TB<W1Y;&5S:&5E="(@='EP93TB=&5X="]C<W,B("\^)R`N(")<
M;B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1'3$]"
M04Q36R=B<F]W<V5R)UTM/FES0G)O=W-E<B@G;W!E<F$G*2D@>PH@("`@("`@
M("`@("`D:'1M;"`N/2`G/&QI;FL@:')E9CTB)R`N("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG970H)W1H96UE<W5R:2<L("=H;W)D92<I("X@)R]O<&5R82YC
M<W,B(')E;#TB<W1Y;&5S:&5E="(@='EP93TB=&5X="]C<W,B("\^)R`N(")<
M;B(["B`@("`@("`@?0H@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==
M+3YI<T)R;W=S97(H)VUO>FEL;&$G*2`F)@H@("`@("`@("`@("`D1TQ/0D%,
M4ULG8G)O=W-E<B==+3YG971-86IO<B@I(#X](#4@)B8*("`@("`@("`@("`@
M<')E9U]M871C:"@G+W)V.B@N*BE<*2\G+"`D1TQ/0D%,4ULG8G)O=W-E<B==
M+3YG971!9V5N=%-T<FEN9R@I+"`D<F5V:7-I;VXI("8F"B`@("`@("`@("`@
M("1R979I<VEO;ELQ72`\/2`Q+C0I('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)SQL:6YK(&AR968](B<@+B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T
M:&5M97-U<FDG+"`G:&]R9&4G*2`N("<O;6]Z,30N8W-S(B!R96P](G-T>6QE
M<VAE970B('1Y<&4](G1E>'0O8W-S(B`O/B<@+B`B7&XB.PH@("`@("`@('T*
M("`@("`@("!I9B`H<W1R<&]S*'-T<G1O;&]W97(H)$=,3T)!3%-;)V)R;W=S
M97(G72T^9V5T06=E;G13=')I;F<H*2DL("=S869A<FDG*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQL:6YK(&AR968](B<@+B`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T:&5M97-U<FDG+"`G:&]R9&4G*2`N
M("<O<V%F87)I+F-S<R(@<F5L/2)S='EL97-H965T(B!T>7!E/2)T97AT+V-S
M<R(@+SXG("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M
M;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@82!C=7-T;VT@<V5S<VEO
M;B!H86YD;&5R('5P+"!I9B!T:&5R92!I<R!O;F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E='5P4V5S<VEO;DAA;F1L97(H*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D8V]N9CL*"B`@("`@("`@:6YI7W-E="@G=7)L7W)E=W)I=&5R+G1A
M9W,G+"`P*3L*("`@("`@("!S97-S:6]N7W-E=%]C;V]K:65?<&%R86US*"1C
M;VYF6R=S97-S:6]N)UU;)W1I;65O=70G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;VYF6R=C;V]K:64G75LG<&%T:"==+"`D8V]N
M9ELG8V]O:VEE)UU;)V1O;6%I;B==+"`D8V]N9ELG=7-E7W-S;"==(#T](#$@
M/R`Q(#H@,"D["B`@("`@("`@<V5S<VEO;E]C86-H95]L:6UI=&5R*"1C;VYF
M6R=S97-S:6]N)UU;)V-A8VAE7VQI;6ET97(G72D["B`@("`@("`@<V5S<VEO
M;E]N86UE*'5R;&5N8V]D92@D8V]N9ELG<V5S<VEO;B==6R=N86UE)UTI*3L*
M"B`@("`@("`@)'1Y<&4@/2`A96UP='DH)&-O;F9;)W-E<W-I;VYH86YD;&5R
M)UU;)W1Y<&4G72D@/R`D8V]N9ELG<V5S<VEO;FAA;F1L97(G75LG='EP92==
M(#H@)VYO;F4G.PH*("`@("`@("!I9B`H)'1Y<&4@/3T@)V5X=&5R;F%L)RD@
M>PH@("`@("`@("`@("`D8V%L;',@/2`D8V]N9ELG<V5S<VEO;FAA;F1L97(G
M75LG<&%R86US)UT["B`@("`@("`@("`@('-E<W-I;VY?<V5T7W-A=F5?:&%N
M9&QE<B@D8V%L;'-;)V]P96XG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C86QL<ULG8VQO<V4G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C86QL<ULG<F5A9"==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&QS6R=W<FET92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&QS
M6R=D97-T<F]Y)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V%L;'-;)V=C)UTI.PH@("`@("`@('T@96QS96EF("@D='EP92`A
M/2`G;F]N92<I('L*("`@("`@("`@("`@9VQO8F%L("1?<V5S<VEO;E]H86YD
M;&5R.PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY(
M86YD;&5R+G!H<"<["B`@("`@("`@("`@("1?<V5S<VEO;E]H86YD;&5R(#T@
M)E-E<W-I;VY(86YD;&5R.CIS:6YG;&5T;VXH)&-O;F9;)W-E<W-I;VYH86YD
M;&5R)UU;)W1Y<&4G72D["B`@("`@("`@("`@(&EF("@A96UP='DH)%]S97-S
M:6]N7VAA;F1L97(I("8F"B`@("`@("`@("`@("`@("`A:7-?82@D7W-E<W-I
M;VY?:&%N9&QE<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M:6YI7W-E="@G<V5S<VEO;BYS879E7VAA;F1L97(G+"`G=7-E<B<I.PH@("`@
M("`@("`@("`@("`@<V5S<VEO;E]S971?<V%V95]H86YD;&5R*&%R<F%Y*"8D
M7W-E<W-I;VY?:&%N9&QE<BP@)V]P96XG*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@F)%]S97-S:6]N7VAA;F1L
M97(L("=C;&]S92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?:&%N9&QE<BP@)W)E860G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@F)%]S97-S:6]N7VAA;F1L97(L("=W<FET92<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?
M:&%N9&QE<BP@)V1E<W1R;WDG*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@F)%]S97-S:6]N7VAA;F1L97(L("=G
M8R<I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@($AO
M<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*"=(;W)D92!I<R!U;F%B;&4@
M=&\@8V]R<F5C=&QY('-T87)T('1H92!C=7-T;VT@<V5S<VEO;B!H86YD;&5R
M+B<I+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I
M;VX@:7,@=')I9V=E<F5D('=H96X@=&AE('-E<W-I;VX@:7,@;&]A9&5D+B!)
M="!C:&5C:W,@9F]R"B`@("`@*B!A;GD@8V%L;&)A8VMS('-T;W)E9"!I;B!T
M:&4@<V5S<VEO;B!T:&%T(&YE960@=&\@8F4@<G5N(&EM;65D:6%T96QY"B`@
M("`@*B!T:&4@<V5S<VEO;B!I<R!L;V%D960N"B`@("`@*B!4:&4@=V%Y('1O
M('-T;W)E('1H92!C86QL8F%C:W,@:7,Z"B`@("`@*B`\<')E/@H@("`@("H@
M)%]315-324].6R=C86QL8F%C:W,G75LG/&-L87-S(&]B:F5C=#XN/&9U;F-T
M:6]N/B==(#T@=')U93L*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($%N
M>2!O8FIE8W1S('1H870@87)E(&YO="!A=F%I;&%B;&4@:6X@)$=,3T)!3%,@
M=VEL;"!B92!S:6QE;G1L>0H@("`@("H@:6=N;W)E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5S<VEO;D-A;&QB86-K<R@I"B`@("!["B`@("`@("`@:68@
M*&ES<V5T*"1?4T534TE/3ELG8V%L;&)A8VMS)UTI*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*&%R<F%Y7VME>7,H)%]315-324].6R=C86QL8F%C:W,G72D@
M87,@)&-A;&QB86-K*2!["B`@("`@("`@("`@("`@("!L:7-T*"1C;&%S<RP@
M)&9U;F-T:6]N*2`](&5X<&QO9&4H)RXG+"`D8V%L;&)A8VLI.PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R1C;&%S<UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H87)R87DH)B1'3$]"04Q3
M6R1C;&%S<UTL("1F=6YC=&EO;BDI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A;B!U;BUU<V5D(&%C8V5S<R!K97D@9G)O;2!T:&4@;&%B96P@9VEV
M96XN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@("`@(%1H
M92!L86)E;"!T;R!C:&]O<V4@86X@86-C97-S(&ME>2!F<F]M+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&YO8VAE8VL@($1O;B=T(&-H96-K(&EF('1H92!A
M8V-E<W,@:V5Y(&%L<F5A9'D@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!U<V5D/PH@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!!('-I;F=L92!L;W=E<B!C87-E(&-H87)A8W1E<B!A8V-E<W,@:V5Y
M(&]R(&5M<'1Y"B`@("`@*B`@("`@("`@("`@("`@("`@<W1R:6YG(&EF(&YO
M;F4@8V%N(&)E(&9O=6YD"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%C8V5S
M<TME>2@D;&%B96PL("1N;V-H96-K(#T@9F%L<V4L("1S:'5T9&]W;B`](&9A
M;'-E*0H@("`@>PH@("`@("`@("\J(%1H92!A8V-E<W,@:V5Y<R!A;')E861Y
M('5S960@:6X@=&AI<R!P86=E("HO"B`@("`@("`@<W1A=&EC("1?=7-E9"`]
M(&%R<F%Y*"D["@H@("`@("`@("\J(%1H92!L86)E;',@86QR96%D>2!U<V5D
M(&EN('1H:7,@<&%G92`J+PH@("`@("`@('-T871I8R`D7VQA8F5L<R`](&%R
M<F%Y*"D["@H@("`@("`@("\J(%-H=71D;W=N(&-A;&P@9F]R('1R86YS;&%T
M;W)S/R`J+PH@("`@("`@(&EF("@D<VAU=&1O=VXI('L*("`@("`@("`@("`@
M:68@*"%C;W5N="@D7VQA8F5L<RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<V-R:7!T(#T@8F%S96YA
M;64H)%]315)615);)U!(4%]314Q&)UTI.PH@("`@("`@("`@("`D;&%B96QS
M(#T@87)R87E?:V5Y<R@D7VQA8F5L<RD["B`@("`@("`@("`@('-O<G0H)&QA
M8F5L<RD["B`@("`@("`@("`@("1U<V5D(#T@87)R87E?:V5Y<R@D7W5S960I
M.PH@("`@("`@("`@("!S;W)T*"1U<V5D*3L*("`@("`@("`@("`@)')E;6%I
M;FEN9R`]('-T<E]R97!L86-E*"1U<V5D+"!A<G)A>2@I+"`G86)C9&5F9VAI
M:FML;6YO<'%R<W1U=G=X>7HG*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)T%C8V5S<R!K97D@:6YF;W)M871I;VX@9F]R("<@+B`D<V-R:7!T
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G57-E9"!L86)E;',Z("<@+B!I;7!L;V1E*"<L)RP@)&QA8F5L
M<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=5<V5D(&ME>7,Z("<@+B!I;7!L;V1E*"<G+"`D=7-E9"DL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=&<F5E(&ME>7,Z("<@+B`D<F5M86EN:6YG+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@
M("`@("`O*B!5<V4@86-C97-S(&ME>7,@870@86QL/R`J+PH@("`@("`@('-T
M871I8R`D;F]T<W5P<&]R=&5D.PH@("`@("`@(&EF("@A:7-S970H)&YO='-U
M<'!O<G1E9"DI('L*("`@("`@("`@("`@)&YO='-U<'!O<G1E9"`]("$D1TQ/
M0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=A8V-E<W-K97DG*2!\?`H@
M("`@("`@("`@("`@("`@(21'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G
M=VED9V5T7V%C8V5S<VME>2<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1N
M;W1S=7!P;W)T960@?'P@(7!R96=?;6%T8V@H)R]?*%M!+5IA+7I=*2\G+"`D
M;&%B96PL("1M871C:"DI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@('T*("`@("`@("`D:V5Y(#T@)&UA=&-H6S%=.PH*("`@("`@("`O*B!(
M87,@=&AI<R!K97D@86QR96%D>2!B965N('5S960_("HO"B`@("`@("`@:68@
M*&ES<V5T*"1?=7-E9%MS=')T;VQO=V5R*"1K97DI72D@)B8*("`@("`@("`@
M("`@(2@D;F]C:&5C:R`F)B!I<W-E="@D7VQA8F5L<ULD;&%B96Q=*2DI('L*
M("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@
M4V%V92!K97D@86YD(&QA8F5L+B`J+PH@("`@("`@("1?=7-E9%MS=')T;VQO
M=V5R*"1K97DI72`]('1R=64["B`@("`@("`@)%]L86)E;'-;)&QA8F5L72`]
M('1R=64["@H@("`@("`@(')E='5R;B`D:V5Y.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4W1R:7!S(&%N(&%C8V5S<R!K97D@9G)O;2!A(&QA8F5L+@H@("`@
M("H@1F]R(&UU;'1I8GET92!C:&%R<V5T('-T<FEN9W,@=&AE(&%C8V5S<R!K
M97D@9V5T<R!R96UO=F5D(&-O;7!L971E;'DL"B`@("`@*B!O=&AE<G=I<V4@
M;VYL>2!T:&4@=6YD97)S8V]R92!G971S(')E;6]V960N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!L86)E;"!C;VYT86EN:6YG
M(&%N(&%C8V5S<R!K97DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!L86)E;"!W:71H('1H92!A8V-E<W,@:V5Y(&)E:6YG('-T<FEP<&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=')I<$%C8V5S<TME>2@D;&%B96PI
M"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O
M;F9I9R]N;',N<&AP)SL*("`@("`@("`D;75L=&EB>71E(#T@:7-S970H)$=,
M3T)!3%-;)VYL<R==6R=M=6QT:6)Y=&4G75M.3%,Z.F=E=$-H87)S970H=')U
M92E=*3L*"B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G+U\H6T$M6F$M
M>ETI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;75L=&EB>71E
M("8F('!R96=?;6%T8V@H)R];7'@X,"U<>&9F72\G+"`D;&%B96PI(#\@)R<@
M.B`G7#$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QA8F5L*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($AI9VAL:6=H=',@86X@86-C97-S(&ME
M>2!I;B!A(&QA8F5L+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA
M8F5L("`@("`@5&AE(&QA8F5L('1O('1O(&AI9VAL:6=H="!T:&4@86-C97-S
M(&ME>2!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5S<TME>2`@5&AE
M(&%C8V5S<R!K97D@=&\@:&EG:&QI9VAT+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@2%1-3"!V97)S:6]N(&]F('1H92!L86)E;"!W:71H
M('1H92!A8V-E<W,@:V5Y"B`@("`@*B`@("`@("`@("`@("`@("`@:&EG:&QI
M9VAT960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AI9VAL:6=H=$%C8V5S<TME
M>2@D;&%B96PL("1A8V-E<W-+97DI"B`@("!["B`@("`@("`@)'-T<FEP<&5D
M7VQA8F5L(#T@2&]R9&4Z.G-T<FEP06-C97-S:V5Y*"1L86)E;"D["@H@("`@
M("`@(&EF("AE;7!T>2@D86-C97-S2V5Y*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'-T<FEP<&5D7VQA8F5L.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1'3$]"04Q36R=N;',G75LG;75L=&EB>71E)UU;3DQ3.CIG971#:&%R
M<V5T*'1R=64I72DI('L*("`@("`@("`@("`@<F5T=7)N("1S=')I<'!E9%]L
M86)E;"`N("<H)R`N("<\<W!A;B!C;&%S<STB86-C97-S2V5Y(CXG("X*("`@
M("`@("`@("`@("`@('-T<G1O=7!P97(H)&%C8V5S<TME>2D@+B`G/"]S<&%N
M/B<@+B`G*2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M('-T<E]R97!L86-E*"=?)R`N("1A8V-E<W-+97DL("<\<W!A;B!C;&%S<STB
M86-C97-S2V5Y(CXG("X@)&%C8V5S<TME>2`N("<\+W-P86X^)RP@)&QA8F5L
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!A<'!R;W!R:6%T92`B86-C97-S:V5Y(B!A;F0@(G1I=&QE(B!A='1R:6)U
M=&5S(&9O<B!A;B!(5$U,"B`@("`@*B!T86<@86YD('1H92!G:79E;B!L86)E
M;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@("`@5&AE
M('1I=&QE(&]F(&%N($A434P@96QE;65N=`H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&YO8VAE8VL@($1O;B=T(&-H96-K(&EF('1H92!A8V-E<W,@:V5Y(&%L
M<F5A9'D@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!U<V5D/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&ET
M;&4L(&%N9"!I9B!A<'!R;W!R:6%T92P@=&AE(&%C8V5S<VME>2!A='1R:6)U
M=&5S"B`@("`@*B`@("`@("`@("`@("`@("`@9F]R('1H92!E;&5M96YT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971!8V-E<W-+97E!;F14:71L92@D;&%B
M96PL("1N;V-H96-K(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&%K(#T@2&]R
M9&4Z.F=E=$%C8V5S<TME>2@D;&%B96PL("1N;V-H96-K*3L*("`@("`@("`D
M871T<FEB=71E<R`]("=T:71L93TB)R`N($AO<F1E.CIS=')I<$%C8V5S<TME
M>2@D;&%B96PI.PH@("`@("`@(&EF("@A96UP='DH)&%K*2D@>PH@("`@("`@
M("`@("`D871T<FEB=71E<R`N/2!S<')I;G1F*%\H(B`H06-C97-S:V5Y("5S
M*2(I+"`D86LI.PH@("`@("`@("`@("`D871T<FEB=71E<R`N/2`G(B!A8V-E
M<W-K97D](B<@+B`D86L["B`@("`@("`@?0H@("`@("`@("1A='1R:6)U=&5S
M("X]("<B)SL*("`@("`@("!R971U<FX@)&%T=')I8G5T97,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&%B96P@96QE;65N="!I;F-L=61I
M;F<@86X@86-C97-S(&ME>2!F;W(@=7-A9V4@:6X@8V]N:G5C=&EO;@H@("`@
M("H@=VET:"!A(&9O<FT@9FEE;&0N(%5S97(@<')E9F5R96YC97,@<F5G87)D
M:6YG(&%C8V5S<R!K97ES(&%R92!R97-P96-T960N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F]R("`@(%1H92!F;W)M(&9I96QD)W,@:60@871T
M<FEB=71E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!L86)E
M;"!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86L@("`@(%1H92!A8V-E
M<W,@:V5Y('1O('5S92X@268@;G5L;"!A(&YE=R!A8V-E<W,@:V5Y"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!B92!G96YE<F%T960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!H=&UL(&-O9&4@9F]R
M('1H92!L86)E;"!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!L86)E
M;"@D9F]R+"`D;&%B96PL("1A:R`](&YU;&PI"B`@("!["B`@("`@("`@9VQO
M8F%L("1P<F5F<SL*"B`@("`@("`@:68@*&ES7VYU;&PH)&%K*2D@>PH@("`@
M("`@("`@("`D86L@/2!(;W)D93HZ9V5T06-C97-S:V5Y*"1L86)E;"P@,2D[
M"B`@("`@("`@?0H@("`@("`@("1L86)E;"`]($AO<F1E.CIH:6=H;&EG:'1!
M8V-E<W-+97DH)&QA8F5L+"`D86LI.PH*("`@("`@("!R971U<FX@<W!R:6YT
M9B@G/&QA8F5L(&9O<CTB)7,B)7,^)7,\+VQA8F5L/B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<BP*("`@("`@("`@("`@("`@("`@("`@("`A96UP
M='DH)&%K*2`_("<@86-C97-S:V5Y/2(G("X@)&%K("X@)R(G(#H@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@)&QA8F5L*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E9&ER96-T<R!T;R!T:&4@;6%I;B!(;W)D92!L;V=I;B!P86=E
M(&]N(&%U=&AE;G1I8V%T:6]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D*("`@('L*("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH@("`@("`@(&EF
M("A(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@("`@("`@("`@
M)&-L:2`]("9(;W)D95]#3$DZ.G-I;F=L971O;B@I.PH@("`@("`@("`@("`D
M8VQI+3YF871A;"A?*")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(I*3L*
M("`@("`@("!]"@H@("`@("`@("1U<FP@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+VQO9VEN+G!H<"<["B`@
M("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!A<G)A>2@G
M=7)L)R`]/B!(;W)D93HZ<V5L9E5R;"AT<G5E*2P@)VYO<VED96)A<B<@/3X@
M,2DL(&YU;&PL(&9A;'-E*3L*("`@("`@("`D=7)L(#T@075T:#HZ861D3&]G
M;W5T4&%R86UE=&5R<R@D=7)L*3L*("`@("`@("!H96%D97(H)TQO8V%T:6]N
M.B`G("X@2&]R9&4Z.G5R;"@D=7)L+"!T<G5E*2D["B`@("`@("`@97AI=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%!R;W9I9&5S(&$@<W1A;F1A<F1I<V5D
M(&9U;F-T:6]N('1O(&-A;&P@82!(;W)D92!H;V]K+"!C:&5C:VEN9R!W:&5T
M:&5R"B`@("`@*B!A(&AO;VL@8V]N9FEG(&9I;&4@97AI<W1S(&%N9"!W:&5T
M:&5R('1H92!F=6YC=&EO;B!I='-E;&8@97AI<W1S+B!)9@H@("`@("H@=&AE
M<V4@='=O(&-O;F1I=&EO;G,@87)E(&YO="!S871I<V9I960@:70@=VEL;"!R
M971U<FX@=&AE('-P96-I9FEE9`H@("`@("H@=F%L=64@*&)Y(&1E9F%U;'0@
M82!014%2(&5R<F]R*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H
M;V]K("!4:&4@9G5N8W1I;VX@=&\@8V%L;"X*("`@("`J($!P87)A;2!A<G)A
M>2`@)&%R9W,@($%N(&%R<F%Y(&]F(&%N>2!A<F=U;65N=',@=&\@<&%S<R!T
M;R!T:&4@:&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@9G5N8W1I
M;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("!)9B!S<&5C:69I960@
M;&]O:R!F;W(@:&]O:W,@:6X@=&AE(&-O;F9I9R!D:7)E8W1O<GD*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@(&]F('1H:7,@87!P+@H@("`@("H@0'!A
M<F%M(&UI>&5D("1E<G)O<B`@5VAA="!T;R!R971U<FX@:68@)&%P<"]C;VYF
M:6<O:&]O:W,N<&AP(&]R("1H;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("!D;V5S(&YO="!E>&ES="X@268@=&AI<R!I<R!T:&4@<W1R:6YG("=0
M14%27T5R<F]R)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@82!014%2
M(&5R<F]R(&]B:F5C="!I<R!R971U<FYE9"!I;G-T96%D+"!D971A:6QI;F<*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@('1H92!F86EL=7)E+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!T:&4@<F5S=6QT<R!O
M9B!T:&4@:&]O:R!O<B!014%2(&5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-A;&Q(;V]K*"1H;V]K+"`D87)G<R`](&%R<F%Y*"DL
M("1A<'`@/2`G:&]R9&4G+"`D97)R;W(@/2`G4$5!4E]%<G)O<B<I"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("!S=&%T:6,@)&AO
M;VMS7VQO861E9#L*"B`@("`@("`@:68@*"%I<W-E="@D:&]O:W-?;&]A9&5D
M*2D@>PH@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)')E9VES=')Y+3YG
M970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I9R]H;V]K<RYP:'`G*2D@
M>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1R96=I<W1R>2T^9V5T
M*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@
M("`@("`@("`@("`@("1H;V]K<U]L;V%D960@/2!T<G5E.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&AO;VMS7VQO861E9"`](&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D:&]O
M:W-?;&]A9&5D("8F(&9U;F-T:6]N7V5X:7-T<R@D:&]O:RDI('L*("`@("`@
M("`@("`@<F5T=7)N(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1H;V]K+"`D87)G
M<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?<W1R:6YG*"1E<G)O<BD@
M)B8@<W1R8VUP*"1E<G)O<BP@)U!%05)?17)R;W(G*2`]/2`P*2!["B`@("`@
M("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G2&]O
M:R`E<R!I;B!A<'!L:6-A=&EO;B`E<R!N;W0@8V%L;&5D+B<L("1H;V]K+"`D
M87!P*2D["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1E<G)O<BP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!I;FET:6%L('!A9V4@=&\@;&]A9"!W:&5N(&%C8V5S
M<VEN9R!(;W)D92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(%523"!O9B!T:&4@:6YI=&EA;"!P86=E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I;FET:6%L4&%G92@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<RP@
M)')E9VES=')Y+"`D<&5R;7,["@H@("`@("`@("1I;FET:6%L7V%P<"`]("1P
M<F5F<RT^9V5T5F%L=64H)VEN:71I86Q?87!P;&EC871I;VXG*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1I;FET:6%L7V%P<"D@)B8@)')E9VES=')Y+3YH87-0
M97)M:7-S:6]N*"1I;FET:6%L7V%P<"DI('L*("`@("`@("`@("`@<F5T=7)N
M($AO<F1E.CIU<FPH)')E9VES=')Y+3YG971);FET:6%L4&%G92@D:6YI=&EA
M;%]A<'`I+"!T<G5E*3L*("`@("`@("!](&5L<V5I9B`H:7-S970H)')E9VES
M=')Y+3YA<'!L:6-A=&EO;G-;)VAO<F1E)UU;)VEN:71I86Q?<&%G92==*2D@
M>PH@("`@("`@("`@("!R971U<FX@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1R
M96=I<W1R>2T^87!P;&EC871I;VYS6R=H;W)D92==6R=I;FET:6%L7W!A9V4G
M72P@=')U92D["B`@("`@("`@?2!E;'-E:68@*$%U=&@Z.F=E=$%U=&@H*2D@
M>PH@("`@("`@("`@("!R971U<FX@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S
M97)V:6-E<R]P;W)T86PO)RP@=')U92D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G;&]G:6XN
M<&AP)RP@=')U92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VX@9F]R('1H92!C=7)R
M96YT('5S97(N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@($$@<&5R;6ES
M<VEO;BP@8W5R<F5N=&QY(&]N;'D@)VUA>%]B;&]C:W,G+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!V86QU92!O9B!T:&4@<W!E8VEF:65D
M('!E<FUI<W-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I
M;VXH)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@9VQO8F%L("1P97)M<SL*
M"B`@("`@("`@:68@*"$D<&5R;7,M/F5X:7-T<R@G:&]R9&4Z)R`N("1P97)M
M:7-S:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1A;&QO=V5D(#T@)'!E<FUS+3YG971097)M:7-S:6]N<R@G
M:&]R9&4Z)R`N("1P97)M:7-S:6]N*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)&%L;&]W960I*2!["B`@("`@("`@("`@('-W:71C:"`H)'!E<FUI<W-I;VXI
M('L*("`@("`@("`@("`@8V%S92`G;6%X7V)L;V-K<R<Z"B`@("`@("`@("`@
M("`@("`D86QL;W=E9"`](&%R<F%Y7W)E9'5C92@D86QL;W=E9"P@8W)E871E
M7V9U;F-T:6]N*"<D82P@)&(G+"`G<F5T=7)N(&UA>"@D82P@)&(I.R<I+"`P
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&%L;&]W960["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&%V86EL86)L92!M96YU(&ET
M96US('=H96X@:6X@82!(;W)D92!S8W)I<'0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@079A:6QA8FQE(&UE;G4@:71E;7,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$AO<F1E365N=2@I"B`@("!["B`@("`@("`@9VQO8F%L
M("1R96=I<W1R>2P@)'!R969S.PH*("`@("`@("`D;65N=2`](&%R<F%Y*"D[
M"@H@("`@("`@("\J(%1H92!H;VUE('!A9V4@8G5T=&]N+B!)9B!A;B!I;FET
M:6%L(&%P<&QI8V%T:6]N(&AA<R!B965N('-E="!I;B!T:&4*("`@("`@("`@
M*B!P<F5F<R!T:&ES('=I;&P@9&5F875L="!T;R!T:&%T(&%P<&QI8V%T:6]N
M+B!/=&AE<G=I<V4@:70@=VEL;"!G;PH@("`@("`@("`J('1O('1H92!P;W)T
M86P@<V-R965N+B`J+PH@("`@("`@("1I;FET:6%L7V%P<"`]("1P<F5F<RT^
M9V5T5F%L=64H)VEN:71I86Q?87!P;&EC871I;VXG*3L*("`@("`@("!I9B`H
M(65M<'1Y*"1I;FET:6%L7V%P<"DI('L*("`@("`@("`@("`@)'5R;"`]($AO
M<F1E.CIU<FPH)')E9VES=')Y+3YG971);FET:6%L4&%G92@D:6YI=&EA;%]A
M<'`I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7)L(#T@2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P;W)T86PO)RD["B`@("`@
M("`@?0H@("`@("`@("1M96YU6UT@/2!A<G)A>2@G=7)L)R`]/B`D=7)L+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G=&5X="<@/3X@(%\H(DAO;64B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=H;W)D92YP;F<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;E]P871H)R`]/B`D<F5G
M:7-T<GDM/F=E=$EM86=E1&ER*"DI.PH*("`@("`@("!I9B`H075T:#HZ:7-!
M9&UI;B@I*2!["B`@("`@("`@("`@("1M96YU6UT@/2!A<G)A>2@G=7)L)R`]
M/B!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+R<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1E>'0G(#T^("!?*")?061M:6YI<W1R871I
M;VXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G
M861M:6YI<W1R871I;VXN<&YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=I8V]N7W!A=&@G(#T^("1R96=I<W1R>2T^9V5T26UA9V5$:7(H*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&UE;G4["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O+FAT86-C97-S````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#$V`#$P-#$W,S8R-S<V`#`Q-C<V-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!$96YY(&9R;VT@86QL"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+W9E<G-I;VXN<&AP````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`U,@`Q,#0Q-S,V
M,C<W-@`P,3<S-C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`@9&5F:6YE*"=(3U)$15]615)324].)RP@)S,N,2XQ
M)RD@/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]3>6YC34PN<&AP````````````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#$V-S(`,3`T,3<S-C(W-S8`,#$W,#8T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<["FEN8VQU
M9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0O4W1A='5S+G!H<"<["FEN8VQU9&5?
M;VYC92`G4WEN8TU,+T-O;6UA;F0O06QE<G0N<&AP)SL*:6YC;'5D95]O;F-E
M("=3>6YC34PO0V]M;6%N9"]3>6YC+G!H<"<["FEN8VQU9&5?;VYC92`G4WEN
M8TU,+T-O;6UA;F0O1FEN86PN<&AP)SL*:6YC;'5D95]O;F-E("=3>6YC34PO
M4WEN8RYP:'`G.PII;F-L=61E7V]N8V4@)U-Y;F--3"]"86-K96YD+G!H<"<[
M"@HO*BH*("H@5&AE(%-Y;F--3%]3>6YC2&1R(&%N9"!3>6YC34Q?4WEN8T)O
M9'D@8VQA<W-E<R!P<F]V:61E<PH@*B!A(%-Y;F-(9'(@86YD(%-Y;F-";V1Y
M(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO;@H@
M*B`Q+C$@-2XR+C(@86YD(#4N,BXS+B`@36]S="!O9B!T:&4@=V]R:R!I<R!P
M87-S960@;VX@=&\*("H@4WEN8TU,7T-O;6UA;F1?06QE<G0@86YD(%-Y;F--
M3%]#;VUM86YD7U-Y;F,N"B`J"B`J(%1H97)E(&%R92!T=V\@9VQO8F%L(&]B
M:F5C=',@=&AA="!A<F4@=7-E9"!B>2!3>6YC34PZ"B`J(#$I("1?4T534TE/
M3ELG4WEN8TU,+G-T871E)UTZ"B`J("`@('-E<W-I;VX@;V)J96-T('5S960@
M=&\@;6%I;G1A:6X@=&AE('-T871E(&)E='=E96X@=&AE(&EN9&EV:61U86P*
M("H@("`@4WEN8TU,(&UE<W-A9V5S+@H@*@H@*B`R*2`D1TQ/0D%,4ULG8F%C
M:V5N9"=="B`J("`@($)A8VME;F0@=&\@:&%N9&QE('1H92!C;VUM=6YI8V%T
M:6]N('=I=&@@=&AE(&1A=&%S=&]R92X@0W5R<F5N=&QY('1H90H@*B`@("!H
M;W)D92!B86-K96YD(&ES('1H92!O;FQY(&)A8VME;F0@<')O=FED960N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PN<&AP+'8@,2XR
M,2XQ,"XQ,"`R,#`V+S`Q+S`Q(#(Q.C(X.C,U(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A
M;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;G1H;VYY
M($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*B!`875T:&]R("!+87)S
M=&5N($9O=7)M;VYT(#QF;W5R;6]N=$!G;7@N9&4^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#
M;VYT96YT2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@*B!/=71P=70@0V]N=&5N
M=$AA;F1L97(@=7-E9"!T;R!O=71P=70@6$U,(&5V96YT<RX*("`@("`J"B`@
M("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)%]O=71P=70["@H@
M("`@+RHJ"B`@("`@*B!3=&%C:R!F;W(@:&]L9&EN9R!T:&4@>&UL(&5L96UE
M;G1S(&1U<FEN9R!C<F5A=&EO;B!O9B!T:&4@;V)J96-T(&9R;VT*("`@("`J
M('1H92!X;6P@979E;G0@9FQO=RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7U-T86-K(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-H87)S.PH*
M("`@(&9U;F-T:6]N('-E=$]U='!U="@F)&]U='!U="D*("`@('L*("`@("`@
M("`D=&AI<RT^7V]U='!U="`]("8D;W5T<'5T.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?4W1A8VM;72`]("1E;&5M96YT.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA<G,I*2!["B`@("`@("`@
M("`@('5N<V5T*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@('T*"B`@("`@("`@
M87)R87E?<&]P*"1T:&ES+3Y?4W1A8VLI.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&-H87)A8W1E<G,H)'-T<BD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]C:&%R<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]C:&%R<R`]("1T
M:&ES+3Y?8VAA<G,@+B`D<W1R.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?8VAA<G,@/2`D<W1R.PH@("`@("`@('T*("`@('T*"GT*
M"@HO*BH*("H@1&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O
M=&]C;VPL('9E<G-I;VX@,2XQ(#4N,BXR"B`J"B`J($!P86-K86=E(%-Y;F--
M3`H@*B\*8VQA<W,@4WEN8TU,7U-Y;F--3$AD<B!E>'1E;F1S(%-Y;F--3%]#
M;VYT96YT2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@*B!$969I;F5D(&EN(%-Y
M;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO;B`Q+C$@-2XQ
M+CDN(%5S97(@;F%M92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]L;V-.86UE.PH*("`@("\J*@H@("`@("H@1&5F:6YE
M9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@
M,2XQ(#4N,2XQ.`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7W-E<W-I;VY)1#L*"B`@("`O*BH*("`@("`J($1E9FEN960@
M:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N
M,2X@($UU<W0@8F4@,2XP("@P*0H@("`@("H@;W(@,2XQ("@Q*2X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]V97)S:6]N
M.PH*("`@("\J*@H@("`@("H@1&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT
M871I;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ(#4N,2XQ,@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUS9TE$.PH*("`@
M("\J*@H@("`@("H@1&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@
M4')O=&]C;VPL('9E<G-I;VX@,2XQ(#4N,2XQ,`H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=%5223L*"B`@("`O
M*BH*("`@("`J($1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R
M;W1O8V]L+"!V97)S:6]N(#$N,2`U+C$N,3`L(#4N,2XR,`H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O=7)C955223L*
M"B`@("!V87(@)%]C<F5D1&%T83L*"B`@("!V87(@)%]C<F5D1F]R;6%T.PH*
M("`@('9A<B`D7V-R9614>7!E.PH*("`@('9A<B`D7VUA>$US9U-I>F4["@H@
M("`@9G5N8W1I;VX@9V5T4W1A=&5&<F]M4V5S<VEO;B@D<V]U<F-E55))+"`D
M;&]C3F%M92P@)'-E<W-I;VY)1"D*("`@('L*("`@("`@("`D1TQ/0D%,4ULG
M8F%C:V5N9"==(#T@)FYE=R!3>6YC34Q?0F%C:V5N9%](;W)D92@I.PH*("`@
M("`@("`O+R!296QO860@=&AE($AO<F1E(%-E<W-I;VY(86YD;&5R(&EF(&YE
M8V5S<V%R>2X*("`@("`@("!(;W)D93HZ<V5T=7!397-S:6]N2&%N9&QE<B@I
M.PH*("`@("`@("`O+R!3>6YC34P@<')O=&]C;VP@9&]E<R!N;W0@<F5Q=6ER
M92!T:&4@8VQI96YT('1O('-E;F0@=&AE"B`@("`@("`@+R\@=7-E<FYA;64@
M;VX@86YY(&UE<W-A9V5S(&)U="!T:&4@9FER<W0N("!3;R!U;F9O<G1U;F%T
M96QY"B`@("`@("`@+R\@=V4@8V%N)W0@=7-E(&ET('1O(&UA:V4@82!U;FEQ
M=64@<V5S<VEO;B!I9"X*("`@("`@("!S97-S:6]N7VED*"=S>6YC;6PG("X@
M<')E9U]R97!L86-E*"<O6UYA+7I!+5HP+3E=+R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP@)'-O=7)C955222`N
M("1S97-S:6]N240I*3L*("`@("`@("!S97-S:6]N7W-T87)T*"D["@H@("`@
M("`@("\O($ET('=O=6QD('-E96T@;75L=&ES>6YC(&1O97,@;F]T('-E;F0@
M=&AE('5S97(@;F%M92!O;F-E(&ET"B`@("`@("`@+R\@:&%S(&)E96X@875T
M:&]R:7IE9"X@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!S97-S:6]N(&ED
M+@H@("`@("`@('-E<W-I;VY?:60H)W-Y;F-M;"<@+B!P<F5G7W)E<&QA8V4H
M)R];7F$M>D$M6C`M.5TO)RP@)R<L("1S;W5R8V554DD@+B`D<V5S<VEO;DE$
M*2D["B`@("`@("`@0'-E<W-I;VY?<W1A<G0H*3L*"B`@("`@("`@:68@*"%I
M<W-E="@D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==*2D@>PH@("`@("`@("`@
M("`O+R!#<F5A=&4@82!N97<@<W1A=&4@:68@;VYE(&1O97,@;F]T(&%L<F5A
M9'D@97AI<W0N"B`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO
M9TUE<W-A9V4H)TYE=R!S97-S:6]N(&-R96%T960Z("<*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B!S97-S:6]N7VED*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH*("`@("`@("`@("`@)%]315-324].6R=3>6YC34PN<W1A
M=&4G72`]("9N97<@4WEN8TU,7U-T871E*"1S;W5R8V554DDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;&]C3F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S97-S:6]N240I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM
M/FQO9TUE<W-A9V4H)T5X:7-T:6YG('-E<W-I;VX@8V]N=&EN=65D.B`G"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@<V5S<VEO;E]I9"@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@
M>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT
M+"`D871T<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI
M<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@+R\@
M/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`O+R!&:6YD('1H92!S
M=&%T92X*("`@("`@("`@("`@)'-T871E(#T@)'1H:7,M/F=E=%-T871E1G)O
M;5-E<W-I;VXH)'1H:7,M/E]S;W5R8V554DDL("1T:&ES+3Y?;&]C3F%M92P@
M)'1H:7,M/E]S97-S:6]N240I.PH*("`@("`@("`@("`@)'-T871E+3YS9716
M97)S:6]N*"1T:&ES+3Y?=F5R<VEO;BD["B`@("`@("`@("`@("1S=&%T92T^
M<V5T37-G240H)'1H:7,M/E]M<V=)1"D["B`@("`@("`@("`@("1S=&%T92T^
M<V5T5&%R9V5T55))*"1T:&ES+3Y?=&%R9V5T55))*3L*("`@("`@("`@("`@
M)'-T871E+3YS971087-S=V]R9"@D=&AI<RT^7V-R961$871A*3L*("`@("`@
M("`@("`@)'-T871E+3YS97170EA-3"AI<U]A*"1T:&ES+3Y?;W5T<'5T+"`G
M6$U,7U="6$U,7T5N8V]D97(G*2D["@H@("`@("`@("`@("`O+R!3=&]R92!L
M;V=I;B!N86UE(&EN('-T871E(&EF(&YO="!A;')E861Y('-E=`H@("`@("`@
M("`@("!I9B`H96UP='DH)'-T871E+3Y?;&]C3F%M92D@)B8@(65M<'1Y*"1T
M:&ES+3Y?;&]C3F%M92DI('L*("`@("`@("`@("`@("`@("1S=&%T92T^<V5T
M3&]C3F%M92@D=&AI<RT^7VQO8TYA;64I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]M87A-<V=3:7IE*2D@>PH@("`@
M("`@("`@("`@("`@)'-T871E+3YS971-87A-<V=3:7IE*"1T:&ES+3Y?;6%X
M37-G4VEZ92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S='(@/2`G
M875T:&]R:7IE9#TG("X@)'-T871E+3YI<T%U=&AO<FEZ960H*2`N"B`@("`@
M("`@("`@("`@("`G('9E<G-I;VX])R`N("1S=&%T92T^9V5T5F5R<VEO;B@I
M("X*("`@("`@("`@("`@("`@("<@;7-G:60])R`N("1S=&%T92T^9V5T37-G
M240H*2`N"B`@("`@("`@("`@("`@("`G('-O=7)C93TG("X@)'-T871E+3YG
M9713;W5R8V554DDH*2`N"B`@("`@("`@("`@("`@("`G('1A<F=E=#TG("X@
M)'-T871E+3YG971487)G97154DDH*2`N"B`@("`@("`@("`@("`@("`G('5S
M97(])R`N("1S=&%T92T^9V5T3&]C3F%M92@I("X*("`@("`@("`@("`@("`@
M("<@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D@+@H@("`@("`@("`@
M("`@("`@)R!W8GAM;#TG("X@)'-T871E+3YI<U="6$U,*"D*"B`@("`@("`@
M("`@("`@("`["@H@("`@("`@("`@("`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==(#T@)'-T871E.PH*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G
M72T^;&]G365S<V%G92@D<W1R+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("\O($=O="!T:&4@<W1A=&4[(&YO
M=R!W<FET92!O=7(@4WEN8TAD<B!H96%D97(N"B`@("`@("`@("`@("1T:&ES
M+3YO=71P=713>6YC2&1R*"1T:&ES+3Y?;W5T<'5T*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@*"1E;&5M
M96YT(#T]("=697)0<F]T;R<I('L*("`@("`@("`@("`@("`@("\O(#PO5F5R
M4')O=&\^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`@("`@:68@
M*'1R:6TH)'1H:7,M/E]C:&%R<RD@/3T@)U-Y;F--3"\Q+C$G*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V97)S:6]N(#T@,3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M97)S:6]N(#T@,#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E:68@*"1E;&5M96YT(#T]("=397-S:6]N240G*2!["B`@("`@("`@("`@
M("`@("`O+R`\+U-E<W-I;VY)1#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E<W-I;VY)1"`]('1R:6TH)'1H:7,M/E]C
M:&%R<RD["B`@("`@("`@("`@('T@96QS96EF("@D96QE;65N="`]/2`G37-G
M240G*2!["B`@("`@("`@("`@("`@("`O+R`\+TUS9TE$/CPO4WEN8TAD<CX\
M+U-Y;F--3#X*("`@("`@("`@("`@("`@("1T:&ES+3Y?;7-G240@/2!I;G1V
M86PH=')I;2@D=&AI<RT^7V-H87)S*2D["B`@("`@("`@("`@('T@96QS96EF
M("@D96QE;65N="`]/2`G0W)E9"<I('L*("`@("`@("`@("`@("`@("\O(#PO
M0W)E9#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-R961$871A(#T@8F%S938T7V1E8V]D92@D=&AI<RT^7V-R961$871A
M*3L*"B`@("`@("`@("`@("`@("`D=&UP(#T@97AP;&]D92@G.B<L("1T:&ES
M+3Y?8W)E9$1A=&$I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V-.86UE
M(#T@)'1M<%LP73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W)E9$1A=&$@
M/2`D=&UP6S%=.PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-Y;F--3#H@<F5C96EV960@8W)E9&5N=&EA;',@9F]R('5S97(])PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N
M("1T:&ES+3Y?;&]C3F%M92`L("=C<F5D/2<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7V-R961$
M871A+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@,SH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=,;V-54DDG*2![
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C:ULQ72`]/2`G4V]U
M<F-E)RD@>PH@("`@("`@("`@("`@("`@("`@("\O(#PO3&]C55))/CPO4V]U
M<F-E/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-O=7)C955222`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]3=&%C:ULQ72`]/2`G5&%R
M9V5T)RD@>PH@("`@("`@("`@("`@("`@("`@("\O(#PO3&]C55))/CPO5&%R
M9V5T/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W1A<F=E=%5222`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D96QE;65N="`]
M/2`G3&]C3F%M92<I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T
M86-K6S%=(#T]("=3;W5R8V4G*2!["B`@("`@("`@("`@("`@("`@("`@+R\@
M/"],;V-.86UE/CPO4V]U<F-E/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VQO8TYA;64@/2!T<FEM*"1T:&ES+3Y?
M8VAA<G,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I
M9B`H)&5L96UE;G0@/3T@)T1A=&$G*2!["B`@("`@("`@("`@("`@("`@("`@
M+R\@/"]$871A/CPO0W)E9#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]3=&%C:ULQ72`]/2`G0W)E9"<I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V-R961$871A(#T@=')I;2@D=&AI
M<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E:68@*"1E;&5M96YT(#T]("=-87A-<V=3:7IE)RD@>PH@("`@("`@("`@
M("`@("`@+R\@/"]-87A-<V=3:7IE/CPO365T83X\+U-Y;F-(9'(^/"]3>6YC
M34P^"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUA>$US9U-I>F4@/2!I;G1V
M86PH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@-#H*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?4W1A8VM;,5T@/3T@)T-R960G*2!["B`@("`@("`@("`@("`@("!I9B`H
M)&5L96UE;G0@/3T@)T9O<FUA="<I('L*("`@("`@("`@("`@("`@("`@("`O
M+R`\+T9O<FUA=#X\+TUE=&$^/"]#<F5D/CPO4WEN8TAD<CX\+U-Y;F--3#X*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-R961&;W)M870@/2!T<FEM
M*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1E
M;&5M96YT(#T]("=4>7!E)RD@>PH@("`@("`@("`@("`@("`@("`@("\O(#PO
M5'EP93X\+TUE=&$^/"]#<F5D/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-R9614>7!E(#T@=')I;2@D=&AI<RT^
M7V-H87)S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ96YD
M16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I;VX@
M;W5T<'5T4WEN8TAD<B@F)&]U='!U="D*("`@('L*("`@("`@("`D871T<G,@
M/2!A<G)A>2@I.PH*("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC
M34PN<W1A=&4G73L*"B`@("`@("`@)'5R:2`]("1S=&%T92T^9V5T55))*"D[
M"B`@("`@("`@)'5R:4UE=&$@/2`D<W1A=&4M/F=E=%5224UE=&$H*3L*"B`@
M("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=3>6YC2&1R)RP@
M)&%T=')S*3L*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL
M("=697)$5$0G+"`D871T<G,I.PH@("`@("`@("1C:&%R<R`]("@D=&AI<RT^
M7W9E<G-I;VX@/3T@,2D@/R`G,2XQ)R`Z("<Q+C`G.PH@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1U<FDL("=697)$5$0G*3L*"B`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1U<FDL("=697)0<F]T;R<L("1A='1R<RD["B`@("`@("`@
M)&-H87)S(#T@*"1T:&ES+3Y?=F5R<VEO;B`]/2`Q*2`_("=3>6YC34PO,2XQ
M)R`Z("=3>6YC34PO,2XP)SL*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1C:&%R<RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G
M5F5R4')O=&\G*3L*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U
M<FDL("=397-S:6]N240G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H
M87)A8W1E<G,H)'1H:7,M/E]S97-S:6]N240I.PH@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'5R:2P@)U-E<W-I;VY)1"<I.PH*("`@("`@("`D;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)TUS9TE$)RP@)&%T=')S*3L*("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES+3Y?;7-G240I.PH@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)TUS9TE$)RD["@H@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G5&%R9V5T)RP@)&%T
M=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)TQO
M8U5222<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D
M=&AI<RT^7W-O=7)C955222D["B`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D=7)I+"`G3&]C55)))RD["B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M
M96YT*"1U<FDL("=,;V-.86UE)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T
M+3YC:&%R86-T97)S*"1S=&%T92T^9V5T3&]C3F%M92@I*3L*("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=,;V-.86UE)RD["B`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G5&%R9V5T)RD["@H@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G4V]U<F-E)RP@)&%T=')S
M*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)TQO8U52
M22<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D=&AI
M<RT^7W1A<F=E=%5222D["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D
M=7)I+"`G3&]C55)))RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D
M=7)I+"`G4V]U<F-E)RD["@H@("`@("`@("\J"B`@("`@("`@1&\@;F]T('-E
M;F0@4F5S<%5222!%;&5M96YT+B!)="=S(&]P=&EO;F%L(&%N9"!M87D@8F4@
M;6ES;&5A9&EN9SH*("`@("`@("`D=&AI<RT^7W1A<F=E=%5222!I<R!D871A
M(&9R;VT@=&AE(&-L:65N="!A;F0@;F]T(&=U87)A;G1E960@=&\@8F4*("`@
M("`@("!T:&4@8V]R<F5C="!54DP@9F]R(&%C8V5S<RX@3&5T('1H92!C;&EE
M;G0@:G5S="!S=&%Y('=I=&@@=&AE('-A;64*("`@("`@("!54DP@:70@:&%S
M('5S960@9F]R('1H92!P<F5V:6]U<R!R97%U97-T*',I+@H@("`@("`@("HO
M"B`@("`@("`@+R\D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)U)E<W!5
M4DDG+"`D871T<G,I.PH@("`@("`@("\O)&]U='!U="T^8VAA<F%C=&5R<R@D
M=&AI<RT^7W1A<F=E=%5222D["B`@("`@("`@+R\D;W5T<'5T+3YE;F1%;&5M
M96YT*"1U<FDL("=297-P55)))RD["@H@("`@("`@("\J"B`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=-971A)RP@)&%T=')S*3L*"B`@
M("`@("`@+R\@1'5M;7D@36%X($US<5-I>F4L('1H:7,@:7,@:G5S="!P=70@
M:6X@=&\@;6%K92!T:&4@<&%C:V5T"B`@("`@("`@+R\@=V]R:RP@:70@:7,@
M;F]T(&$@<F5A;"!V86QU92X*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'5R:4UE=&$L("=-87A-<V=3:7IE)RP@)&%T=')S*3L*("`@("`@("`D
M8VAA<G,@/2`G-3`P,#`G.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H
M)&-H87)S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FE-971A
M+"`G36%X37-G4VEZ92<I.PH*("`@("`@("`O+R!$=6UM>2!-87A/8FI3:7IE
M+"!T:&ES(&ES(&IU<W0@<'5T(&EN('1O(&UA:V4@=&AE('!A8VME=`H@("`@
M("`@("\O('=O<FLL(&ET(&ES(&YO="!A(')E86P@=F%L=64N"B`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FE-971A+"`G36%X3V)J4VEZ92<L
M("1A='1R<RD["B`@("`@("`@)&-H87)S(#T@)S0P,#`P,#`G.PH@("`@("`@
M("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1U<FE-971A+"`G36%X3V)J4VEZ92<I.PH*("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=-971A)RD["B`@("`@("`@
M*B\*"B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G4WEN8TAD
M<B<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-O=7)C955222@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V]U<F-E55)).PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$QO8TYA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7VQO8TYA;64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4V5S<VEO
M;DE$*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S97-S:6]N240[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=F5R<VEO;CL*("`@('T*"B`@("!F=6YC=&EO
M;B!G971-<V=)1"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;7-G
M240["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5&%R9V5T55))*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]T87)G97154DD["B`@("!]"@H@("`@
M9G5N8W1I;VX@;W!A<75E*"1O*0H@("`@>PH@("`@?0H*?0H*+RHJ"B`J($1E
M9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S
M:6]N(#$N,2`U+C(N,PH@*@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S
M(%-Y;F--3%]3>6YC34Q";V1Y(&5X=&5N9',@4WEN8TU,7T-O;G1E;G1(86YD
M;&5R('L*"B`@("!V87(@)%]C=7)R96YT0VUD240@/2`Q.PH*("`@('9A<B`D
M7V-U<G)E;G1#;VUM86YD.PH*("`@('9A<B`D7V%C=&EO;D-O;6UA;F1S(#T@
M9F%L<V4["@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M
M96YT+"`D871T<G,I"B`@("!["B`@("`@("`@<&%R96YT.CIS=&%R=$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["@H@("`@("`@('-W:71C:"`H
M8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#$Z"B`@("`@
M("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*
M("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY#;VUM86YD<R`](&9A;'-E.R`O
M+R!S;R!F87(L('=E(&AA=F4@;F]T('-E96X@8V]M;6%N9',@=&AA="!R97%U
M:7)E(&%C=&EO;B!F<F]M(&]U<B!S:61E"@H@("`@("`@("`@("`O+R`\4WEN
M8TU,/CQ3>6YC0F]D>3X*("`@("`@("`@("`@)'5R:2`]("1S=&%T92T^9V5T
M55))*"D["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["@H@("`@("`@("`@("`O+R!2
M:6=H="!O=7(@<W1A='5S(&%B;W5T('1H92!H96%D97(N"B`@("`@("`@("`@
M("1S=&%T=7,@/2`F;F5W(%-Y;F--3%]#;VUM86YD7U-T871U<R@H)'-T871E
M+3YI<T%U=&AO<FEZ960H*2D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@4D534$].4T5?05542$5.5$E#051)
M3TY?04-#15!4140@.B!215-03TY315])3E9!3$E$7T-2141%3E1)04Q3+"`G
M4WEN8TAD<B<I.PH@("`@("`@("`@("`D<W1A='5S+3YS9713;W5R8V52968H
M)'-T871E+3YG9713;W5R8V554DDH*2D["B`@("`@("`@("`@("1S=&%T=7,M
M/G-E=%1A<F=E=%)E9B@D<W1A=&4M/F=E=%1A<F=E=%5222@I*3L*("`@("`@
M("`@("`@)'-T871U<RT^<V5T0VUD4F5F*#`I.PH*("`@("`@("`@("`@)'1H
M:7,M/E]C=7)R96YT0VUD240@/2`D<W1A='5S+3YO=71P=70H)'1H:7,M/E]C
M=7)R96YT0VUD240L("1T:&ES+3Y?;W5T<'5T*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@+R\@/%-Y;F--3#X\
M4WEN8T)O9'D^/%M#;VUM86YD73X*("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M96YT0V]M;6%N9"`](%-Y;F--3%]#;VUM86YD.CIF86-T;W)Y*"1E;&5M96YT
M*3L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT0V]M;6%N9"T^<W1A<G1%
M;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH*("`@("`@("`@("`@
M:68@*"1E;&5M96YT("$]("=3=&%T=7,G("8F("1E;&5M96YT("$]("=-87`G
M("8F("1E;&5M96YT("$]("=&:6YA;"<I('L*("`@("`@("`@("`@("`@("\O
M(%=E)W9E(&=O="!T;R!D;R!S;VUE=&AI;F<A(%1H:7,@8V%N)W0@8F4@=&AE
M(&QA<W0*("`@("`@("`@("`@("`@("\O('!A8VME="X*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?86-T:6]N0V]M;6%N9',@/2!T<G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("`O+R`\4WEN8TU,/CQ3>6YC0F]D>3X\0V]M;6%N9#X\+BXN/@H@
M("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1#;VUM86YD+3YS=&%R=$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!E;F1%;&5M96YT*"1U
M<FDL("1E;&5M96YT*0H@("`@>PH@("`@("`@('-W:71C:"`H8V]U;G0H)'1H
M:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("\O
M(#PO4WEN8T)O9'D^/"]3>6YC34P^"B`@("`@("`@("`@("1S=&%T92`]("8D
M7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`@("`@:68@*"1S
M=&%T92T^:&%S4&5N9&EN9T5L96UE;G1S*"DI('L*("`@("`@("`@("`@("`@
M("\J('-T:6QL('-O;65T:&EN9R!T;R!D;SH@9&]N)W0@8VQO<V4@<V5S<VEO
M;B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A8W1I;VY#;VUM86YD<R`]
M('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M96YT0VUD240@/2!3>6YC34Q?0V]M;6%N9%]&:6YA;#HZ;W5T<'5T1FEN86PH
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-U<G)E;G1#;61)1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T*3L*("`@("`@("`@("`@)'1H
M:7,M/E]O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7V%C=&EO;D-O;6UA;F1S*2!["B`@("`@
M("`@("`@("`@("`O+R!4:&ES('!A8VME="!D:60@;F]T(&-O;G1A:6X@86YY
M(')E86P@86-T:6]N<RP@:G5S=`H@("`@("`@("`@("`@("`@+R\@<W1A='5S
M(&%N9"!M87`N(%1H:7,@;65A;G,@=V4G<F4@9&]N92X@5&AE('-E<W-I;VX*
M("`@("`@("`@("`@("`@("\O(&-A;B!B92!C;&]S960@86YD('1H92!A;F-H
M;W)S('-A=F5D(&9O<B!T:&4@;F5X=`H@("`@("`@("`@("`@("`@+R\@<WEN
M8RX*("`@("`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE
M<W-A9V4H)W-Y;F,G("X@<V5S<VEO;E]I9"@I("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!C;VUP;&5T960@
M<W5C8V5S<V9U;&QY(2<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G(%-T;W)I;F<@0VQI96YT+513("<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<W1A=&4M/E]C;&EE;G1!;F-H;W).97AT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("`@("`@)$=,3T)!
M3%-;)V)A8VME;F0G72T^=W)I=&53>6YC4W5M;6%R>2@*("`@("`@("`@("`@
M("`@("`@("`D<W1A=&4M/F=E=%-Y;F-)9&5N=&EF:65R*"DL"B`@("`@("`@
M("`@("`@("`@("`@)'-T871E+3Y?8VQI96YT06YC:&]R3F5X="P*("`@("`@
M("`@("`@("`@("`@("`D<W1A=&4M/E]S97)V97)!;F-H;W).97AT*3L*("`@
M("`@("`@("`@("`@("1L;V<@/2`D<W1A=&4M/F=E=$QO9R@I.PH@("`@("`@
M("`@("`@("`@)',@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L
M;V<@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`D<R`N/2`B
M("1K/21V(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1'
M3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)U-U;6UA<GDZ)R`N("1S
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH*("`@("`@
M("`@("`@("`@("\O(%-E<W-I;VX@8V%N(&)E(&-L;W-E9"!H97)E+@H@("`@
M("`@("`@("`@("`@<V5S<VEO;E]U;G-E="@I.PH@("`@("`@("`@("`@("`@
M<V5S<VEO;E]D97-T<F]Y*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S86=E*"=3
M>6YC34PZ(')E='5R;B!M97-S86=E(&-O;7!L971E9"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@
M("\O(#PO6T-O;6UA;F1=/CPO4WEN8T)O9'D^/"]3>6YC34P^"B`@("`@("`@
M("`@("1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0M/F5N9$5L96UE;G0H)'5R:2P@
M)&5L96UE;G0I.PH*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT0VUD240@
M/2`D=&AI<RT^7V-U<G)E;G1#;VUM86YD+3YO=71P=70H)'1H:7,M/E]C=7)R
M96YT0VUD240L("1T:&ES+3Y?;W5T<'5T*3L*"B`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@+R\@/"\N+BX^/"];0V]M
M;6%N9%T^/"]3>6YC0F]D>3X\+U-Y;F--3#X*("`@("`@("`@("`@)'1H:7,M
M/E]C=7)R96YT0V]M;6%N9"T^96YD16QE;65N="@D=7)I+"`D96QE;65N="D[
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT
M.CIE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!C:&%R86-T97)S*"1S='(I"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=$-O;6UA;F0M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O<')E9G,N<&AP````````````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-#,P`#$P-#$W,S8R
M-S<V`#`Q-S`R,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O<')E9G,N
M<&AP+'8@,2XQ.2XT+C$P(#(P,#8O,#$O,#$@,C$Z,CDZ,#4@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*
M;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M9G5N8W1I;VX@:&%N9&QE7W-H;W=S=6UM87)Y<V5L96-T*"1U<&1A=&5D*0I[
M"B`@("!G;&]B86P@)'!R969S.PH*("`@("1S:&]W7W-U;6UA<FEE<R`](%5T
M:6PZ.F=E=$9O<FU$871A*"=S:&]W7W-U;6UA<FEE<R<I.PH@("`@:68@*"%I
M<U]N=6QL*"1S:&]W7W-U;6UA<FEE<RDI('L*("`@("`@("`D<')E9G,M/G-E
M=%9A;'5E*"=S:&]W7W-U;6UA<FEE<R<L("1S:&]W7W-U;6UA<FEE<RD["B`@
M("`@("`@)'5P9&%T960@/2!T<G5E.PH@("`@?0H*("`@(')E='5R;B`D=7!D
M871E9#L*?0H*9G5N8W1I;VX@:&%N9&QE7W1H96UE<V5L96-T*"1U<&1A=&5D
M*0I["B`@("!G;&]B86P@)'!R969S.PH*("`@("1T:&5M92`](%5T:6PZ.F=E
M=$9O<FU$871A*"=T:&5M92<I.PH@("`@:68@*"%I<U]N=6QL*"1T:&5M92DI
M('L*("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=T:&5M92<L("1T:&5M92D[
M"B`@("`@("`@)'5P9&%T960@/2!T<G5E.PH@("`@?0H*("`@(')E='5R;B`D
M=7!D871E9#L*?0H*9G5N8W1I;VX@:&%N9&QE7V-A=&5G;W)Y;6%N86=E;65N
M="@D=7!D871E9"D*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP)SL*("`@("1C36%N86=E<B`]("9N97<@4')E
M9G-?0V%T96=O<GE-86YA9V5R*"D["@H@("`@+RH@06QW87ES('-A=F4@8V]L
M;W)S(&]F(&%L;"!C871E9V]R:65S+B`J+PH@("`@)&-O;&]R<R`](&%R<F%Y
M*"D["B`@("`D8V%T96=O<FEE<R`]("1C36%N86=E<BT^9V5T*"D["B`@("!F
M;W)E86-H("@D8V%T96=O<FEE<R!A<R`D8V%T96=O<GDI('L*("`@("`@("!I
M9B`H)&-O;&]R(#T@571I;#HZ9V5T1F]R;41A=&$H)V-O;&]R7R<@+B!B87-E
M-C1?96YC;V1E*"1C871E9V]R>2DI*2!["B`@("`@("`@("`@("1C;VQO<G-;
M)&-A=&5G;W)Y72`]("1C;VQO<CL*("`@("`@("!]"B`@("!]"B`@("!I9B`H
M)&-O;&]R(#T@571I;#HZ9V5T1F]R;41A=&$H)V-O;&]R7R<@+B!B87-E-C1?
M96YC;V1E*"=?9&5F875L=%\G*2DI('L*("`@("`@("`D8V]L;W)S6R=?9&5F
M875L=%\G72`]("1C;VQO<CL*("`@('T*("`@(&EF("@D8V]L;W(@/2!5=&EL
M.CIG971&;W)M1&%T82@G8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H)U]U;F9I
M;&5D7R<I*2D@>PH@("`@("`@("1C;VQO<G-;)U]U;F9I;&5D7R==(#T@)&-O
M;&]R.PH@("`@?0H@("`@)&--86YA9V5R+3YS971#;VQO<G,H)&-O;&]R<RD[
M"@H@("`@)&%C=&EO;B`](%5T:6PZ.F=E=$9O<FU$871A*"=C06-T:6]N)RD[
M"B`@("`D8V%T96=O<GD@/2!5=&EL.CIG971&;W)M1&%T82@G8V%T96=O<GDG
M*3L*"B`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@(&-A<V4@)V%D9"<Z"B`@
M("`@("`@)&--86YA9V5R+3YA9&0H)&-A=&5G;W)Y*3L*("`@("`@("!B<F5A
M:SL*"B`@("!C87-E("=R96UO=F4G.@H@("`@("`@("1C36%N86=E<BT^<F5M
M;W9E*"1C871E9V]R>2D["B`@("`@("`@8G)E86L["@H@("`@9&5F875L=#H*
M("`@("`@("`O*B!3879E(&)U='1O;BX@*B\*("`@("`@("`D=7!D871E9"`]
M('1R=64["B`@("!]"@H@("`@<F5T=7)N("1U<&1A=&5D.PI]"@HO*BH*("H@
M1&\@86YY=&AI;F<@=&AA="!W92!N965D('1O(&1O(&%S(&$@<F5S=6QT(&]F
M(&-E<G1A:6X@<')E9F5R96YC97,*("H@8VAA;F=I;F<N"B`J+PIF=6YC=&EO
M;B!P<F5F<U]C86QL8F%C:R@I"GL*("`@(&=L;V)A;"`D<')E9G,L("1R96=I
M<W1R>2P@)&YO=&EF:6-A=&EO;BP@)&YL<SL*"B`@("!I9B`H)'!R969S+3YI
M<T1I<G1Y*"=L86YG=6%G92<I('Q\"B`@("`@("`@)'!R969S+3YI<T1I<G1Y
M*"=S:&]W7W-I9&5B87(G*2D@>PH@("`@("`@(&EF("@D<')E9G,M/FES1&ER
M='DH)VQA;F=U86=E)RDI('L*("`@("`@("`@("`@3DQ3.CIS971,86YG*"1P
M<F5F<RT^9V5T5F%L=64H)VQA;F=U86=E)RDI.PH@("`@("`@("`@("!.3%,Z
M.G-E=%1E>'1D;VUA:6XH)')E9VES=')Y+3YG971!<'`H*2P@)')E9VES=')Y
M+3YG970H)V9I;&5R;V]T)RD@+B`G+VQO8V%L92<L($Y,4SHZ9V5T0VAA<G-E
M="@I*3L*("`@("`@("`@("`@4W1R:6YG.CIS971$969A=6QT0VAA<G-E="A.
M3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@?0H*("`@("`@("`D=7)L(#T@
M)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*3L*("`@("`@("!I
M9B`H<W5B<W1R*"1U<FPL("TQ*2`A/2`G+R<I('L*("`@("`@("`@("`@)'5R
M;"`N/2`G+R<["B`@("`@("`@?0H@("`@("`@("1U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H)'5R;"`N("=I;F1E>"YP:'`G+"`G=7)L)RP@2&]R9&4Z.G-E
M;&95<FPH=')U92DI.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)VEF
M("AW:6YD;W<N<&%R96YT+F9R86UE<RD@=VEN9&]W+G!A<F5N="YF<F%M97,N
M;&]C871I;VX@/2!<)R<@+B!A9&1S;&%S:&5S*$AO<F1E.CIU<FPH)'5R;"P@
M=')U92DI("X@)UPG.R<L("=J879A<V-R:7!T)RD["B`@("!]"@H@("`@:68@
M*"1P<F5F<RT^:7-$:7)T>2@G<VED96)A<E]W:61T:"<I*2!["B`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"@G:68@*'=I;F1O=RYP87)E;G0@)B8@=VEN
M9&]W+G!A<F5N="YD;V-U;65N="YG971%;&5M96YT0GE)9"A<)VAF7"<I("8F
M('=I;F1O=RYP87)E;G0N:&]R9&5?;65N=2`F)B!W:6YD;W<N<&%R96YT+FAO
M<F1E7VUE;G4N97AP86YD9613:61E8F%R+G-H;W=N*"DI('=I;F1O=RYP87)E
M;G0N9&]C=6UE;G0N9V5T16QE;65N=$)Y260H7"=H9EPG*2YC;VQS(#T@=VEN
M9&]W+G!A<F5N="YH;W)D95]M96YU+G)T;"`_(%PG*BPG("X@)'!R969S+3YG
M971686QU92@G<VED96)A<E]W:61T:"<I("X@)UPG(#H@7"<G("X@)'!R969S
M+3YG971686QU92@G<VED96)A<E]W:61T:"<I("X@)RPJ7"<[)RP@)VIA=F%S
M8W)I<'0G*3L*("`@('T*"B`@("!I9B`H)'!R969S+3YI<T1I<G1Y*"=T:&5M
M92<I('Q\"B`@("`@("`@)'!R969S+3YI<T1I<G1Y*"=M96YU7W9I97<G*2!\
M?`H@("`@("`@("1P<F5F<RT^:7-$:7)T>2@G;65N=5]R969R97-H7W1I;64G
M*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)VEF("AW:6YD;W<N
M<&%R96YT+F9R86UE<RYH;W)D95]M96YU*2!W:6YD;W<N<&%R96YT+F9R86UE
M<RYH;W)D95]M96YU+FQO8V%T:6]N+G)E;&]A9"@I.R<L("=J879A<V-R:7!T
M)RD["B`@("!]"GT*"B\J($%S<VEG;B!V87)I86)L97,@9F]R('-E;&5C="!L
M:7-T<RX@*B\*:68@*"$D<')E9G,M/FES3&]C:V5D*"=T:6UE>F]N92<I*2![
M"B`@("`D=&EM97IO;F5?;W!T:6]N<R`]("1T>CL*("`@(&%R<F%Y7W5N<VAI
M9G0H)'1I;65Z;VYE7V]P=&EO;G,L(%\H(D1E9F%U;'0B*2D["GT*:68@*"$D
M<')E9G,M/FES3&]C:V5D*"=I;FET:6%L7V%P<&QI8V%T:6]N)RDI('L*("`@
M(&=L;V)A;"`D<&5R;7,["@H@("`@)&EN:71I86Q?87!P;&EC871I;VY?;W!T
M:6]N<R`](&%R<F%Y*"D["B`@("`D87!P<R`]("1R96=I<W1R>2T^;&ES=$%P
M<',H87)R87DH)V%C=&EV92<I*3L*("`@(&9O<F5A8V@@*"1A<'!S(&%S("1A
M*2!["B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1R96=I<W1R>2T^9V5T*"=F
M:6QE<F]O="<L("1A*2D@)B8*("`@("`@("`@("`@*"@D<&5R;7,M/F5X:7-T
M<R@D82D@)B8@*"1P97)M<RT^:&%S4&5R;6ES<VEO;B@D82P@075T:#HZ9V5T
M075T:"@I+"!015)-4U]214%$*2!\?"!!=71H.CII<T%D;6EN*"DI*2!\?`H@
M("`@("`@("`@("`@(21P97)M<RT^97AI<W1S*"1A*2DI('L*("`@("`@("`@
M("`@)&EN:71I86Q?87!P;&EC871I;VY?;W!T:6]N<ULD85T@/2`D<F5G:7-T
M<GDM/F=E="@G;F%M92<L("1A*3L*("`@("`@("!]"B`@("!]"B`@("!A<V]R
M="@D:6YI=&EA;%]A<'!L:6-A=&EO;E]O<'1I;VYS*3L*?0II9B`H(21P<F5F
M<RT^:7-,;V-K960H)W1H96UE)RDI('L*("`@("1T:&5M95]O<'1I;VYS(#T@
M87)R87DH*3L*("`@("1T:&5M95]B87-E(#T@)')E9VES=')Y+3YG970H)W1H
M96UE<V9S)RP@)VAO<F1E)RD["B`@("`D9&@@/2!`;W!E;F1I<B@D=&AE;65?
M8F%S92D["B`@("!I9B`H(21D:"D@>PH@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H(E1H96UE(&1I<F5C=&]R>2!C86XG="!B92!O<&5N960B+"`G:&]R
M9&4N97)R;W(G*3L*("`@('T@96QS92!["B`@("`@("`@=VAI;&4@*"@D9&ER
M(#T@<F5A9&1I<B@D9&@I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@:68@
M*"1D:7(@/3T@)RXG('Q\("1D:7(@/3T@)RXN)R!\?"`A(&ES7V1I<B@D=&AE
M;65?8F%S92XG+R<N)&1I<BDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AE;65?;F%M92`](&YU
M;&P["B`@("`@("`@("`@($!I;F-L=61E("1T:&5M95]B87-E("X@)R\G("X@
M)&1I<B`N("<O:6YF;RYP:'`G.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T
M:&5M95]N86UE*2D@>PH@("`@("`@("`@("`@("`@)'1H96UE7V]P=&EO;G-;
M)&1I<ET@/2`D=&AE;65?;F%M93L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("!A<V]R="@D=&AE;65?;W!T:6]N<RD["GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+V-O<F4N<&AP````````````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R-@`Q
M,#0Q-S,V,C<W-@`P,38V-#$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($AO<F1E($%P<&QI8V%T:6]N
M($9R86UE=V]R:R!C;W)E('-E<G9I8V5S(&9I;&4N"B`J"B`J(%1H:7,@9FEL
M92!S971S('5P(&%N>2!N96-E<W-A<GD@:6YC;'5D92!P871H('9A<FEA8FQE
M<R!A;F0@:6YC;'5D97,*("H@=&AE(&UI;FEM=6T@<F5Q=6ER960@2&]R9&4@
M;&EB<F%R:65S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]C;W)E+G!H<"QV
M(#$N,C8N-BXW(#(P,#8O,#$O,#<@,38Z-#`Z,C@@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*+RH@5'5R;B!02%`@<W1U
M9F8@;V9F('1H870@8V%N(')E86QL>2!S8W)E=R!T:&EN9W,@=7`N("HO"FEN
M:5]S970H)VUA9VEC7W%U;W1E<U]S>6)A<V4G+"`P*3L*:6YI7W-E="@G;6%G
M:6-?<75O=&5S7W)U;G1I;64G+"`P*3L*"B\J(%5N<V5T(&%L;"!V87)I86)L
M97,@<&]P=6QA=&5D('1H<F]U9V@@<F5G:7-T97)?9VQO8F%L<RX@*B\*:68@
M*&EN:5]G970H)W)E9VES=&5R7V=L;V)A;',G*2D@>PH@("`@9F]R96%C:"`H
M87)R87E?:V5Y<R@D7T=%5"D@87,@)&ME>2D@>PH@("`@("`@('5N<V5T*"0D
M:V5Y*3L*("`@('T*("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)%]03U-4*2!A
M<R`D:V5Y*2!["B`@("`@("`@=6YS970H)"1K97DI.PH@("`@?0H@("`@9F]R
M96%C:"`H87)R87E?:V5Y<R@D7T-/3TM)12D@87,@)&ME>2D@>PH@("`@("`@
M('5N<V5T*"0D:V5Y*3L*("`@('T*("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H
M)%]%3E8I(&%S("1K97DI('L*("`@("`@("!U;G-E="@D)&ME>2D["B`@("!]
M"B`@("!F;W)E86-H("AA<G)A>5]K97ES*"1?4T525D52*2!A<R`D:V5Y*2![
M"B`@("`@("`@=6YS970H)"1K97DI.PH@("`@?0I]"@HO*B!)9B!T:&4@2&]R
M9&4@1G)A;65W;W)K('!A8VMA9V5S(&%R92!N;W0@:6YS=&%L;&5D(&EN(%!(
M4"=S(&=L;V)A;`H@*B!I;F-L=61E7W!A=&@L('EO=2!M=7-T(&%D9"!A;B!I
M;FE?<V5T*"D@8V%L;"!H97)E('1O(&%D9"!T:&5I<B!L;V-A=&EO;B!T;PH@
M*B!T:&4@:6YC;'5D95]P871H+B`J+PII;FE?<V5T*"=I;F-L=61E7W!A=&@G
M+"!D:7)N86UE*%]?1DE,15]?*2`N(%!!5$A?4T5005)!5$]2("X@:6YI7V=E
M="@G:6YC;'5D95]P871H)RDI.PH*+RH@4$5!4B!B87-E(&-L87-S+B`J+PII
M;F-L=61E7V]N8V4@)U!%05(N<&AP)SL*"B\J($AO<F1E(&-O<F4@8VQA<W-E
M<RX@*B\*:6YC;'5D95]O;F-E("=(;W)D92YP:'`G.PII;F-L=61E7V]N8V4@
M)TAO<F1E+U)E9VES=')Y+G!H<"<["FEN8VQU9&5?;VYC92`G2&]R9&4O4W1R
M:6YG+G!H<"<["FEN8VQU9&5?;VYC92`G2&]R9&4O3DQ3+G!H<"<["FEN8VQU
M9&5?;VYC92`G2&]R9&4O3F]T:69I8V%T:6]N+G!H<"<["FEN8VQU9&5?;VYC
M92`G2&]R9&4O075T:"YP:'`G.PII;F-L=61E7V]N8V4@)TAO<F1E+T)R;W=S
M97(N<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D92]097)M<RYP:'`G.PH*+RH@
M0G)O=W-E<B!D971E8W1I;VX@;V)J96-T+B`J+PII9B`H8VQA<W-?97AI<W1S
M*"="<F]W<V5R)RDI('L*("`@("1B<F]W<V5R(#T@)D)R;W=S97(Z.G-I;F=L
M971O;B@I.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]B87-E+G!H<```````````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,T-C0`,3`T,3<S
M-C(W-S8`,#$V-C(V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!(;W)D92!B87-E(&EN8VQU<VEO;B!F
M:6QE+@H@*@H@*B!4:&ES(&9I;&4@8G)I;F=S(&EN(&%L;"!O9B!T:&4@9&5P
M96YD96YC:65S('1H870@2&]R9&4*("H@9G)A;65W;W)K+6QE=F5L('-C<FEP
M=',@=VEL;"!N965D+"!A;F0@<V5T<R!U<"!O8FIE8W1S('1H870@86QL"B`J
M('-C<FEP=',@=7-E+@H@*@H@*B!.;W1E.B!4:&ES(&)A<V4@9FEL92!D;V5S
M(%]N;W1?(&-H96-K(&%U=&AE;G1I8V%T:6]N+"!S;R!A<R!T;PH@*B!A=F]I
M9"!A;B!I;F9I;FET92!L;V]P(&]N('1H92!(;W)D92!L;V=I;B!P86=E+B!9
M;W4G;&P@;F5E9"!T;R!D;PH@*B!I="!Y;W5R<V5L9B!I;B!F<F%M97=O<FLM
M;&5V96P@<&%G97,N"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB+V)A<V4N<&AP
M+'8@,2XT,"XQ,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,#4@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\O($-H96-K(&9O<B!A
M('!R:6]R(&1E9FEN:71I;VX@;V8@2$]21$5?0D%312`H<&5R:&%P<R!B>2!A
M;@HO+R!A=71O7W!R97!E;F1?9FEL92!D969I;FET:6]N(&9O<B!S:71E(&-U
M<W1O;6EZ871I;VXI+@II9B`H(61E9FEN960H)TA/4D1%7T)!4T4G*2D@>PH@
M("`@0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PI]"@HO+R!,;V%D('1H92!(;W)D92!&<F%M97=O<FL@8V]R92P@
M86YD('-E="!U<"!I;F-L=7-I;VX@<&%T:',N"G)E<75I<F5?;VYC92!(3U)$
M15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*+R\@4F5G:7-T<GDN"B1S97-S
M:6]N7V-O;G1R;VP@/2!5=&EL.CIN;VY);G!U=%9A<B@G<V5S<VEO;E]C;VYT
M<F]L)RD["FEF("@D<V5S<VEO;E]C;VYT<F]L(#T]("=N;VYE)RD@>PH@("`@
M)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH2$]21$5?4T534TE/
M3E].3TY%*3L*?2!E;'-E:68@*"1S97-S:6]N7V-O;G1R;VP@/3T@)W)E861O
M;FQY)RD@>PH@("`@)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH
M2$]21$5?4T534TE/3E]214%$3TY,62D["GT@96QS92!["B`@("`D<F5G:7-T
M<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;B@I.PI]"FEF("AI<U]A*"@D<'5S
M:&5D(#T@)')E9VES=')Y+3YP=7-H07!P*"=H;W)D92<L("%D969I;F5D*"=!
M551(7TA!3D1,15(G*2DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("!I9B`H)'!U
M<VAE9"T^9V5T0V]D92@I(#T]("=P97)M:7-S:6]N7V1E;FEE9"<I('L*("`@
M("`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*
M("`@('T*("`@($AO<F1E.CIF871A;"@D<'5S:&5D+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(&9A;'-E*3L*?0HD8V]N9B`]("8D1TQ/0D%,4ULG8V]N9B==.PI`
M9&5F:6YE*"=(3U)$15]414U03$%415,G+"`D<F5G:7-T<GDM/F=E="@G=&5M
M<&QA=&5S)RDI.PH*+R\@3F]T:69I8V%T:6]N(%-Y<W1E;2X*)&YO=&EF:6-A
M=&EO;B`]("9.;W1I9FEC871I;VXZ.G-I;F=L971O;B@I.PHD;F]T:69I8V%T
M:6]N+3YA='1A8V@H)W-T871U<R<I.PH*+RH@4V5T('5P('1H92!M96YU+B`J
M+PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*)&UE;G4@/2`F;F5W
M($UE;G4H*3L*"B\O($-O;7!R97-S(&]U='!U=`I(;W)D93HZ8V]M<')E<W-/
M=71P=70H*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O5D93+G!H<```````````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8W,C`Q`#$P-#$W,S8R-S<V
M`#`Q-C,U,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["G)E<75I<F5?
M;VYC92`G3&]G+G!H<"<["@ID969I;F4H)U9&4U]154]405]-151224-?0EE4
M12<L(#$I.PID969I;F4H)U9&4U]154]405]-151224-?2T(G+"`R*3L*9&5F
M:6YE*"=61E-?455/5$%?34544DE#7TU")RP@,RD["F1E9FEN92@G5D937U%5
M3U1!7TU%5%))0U]'0B<L(#0I.PH*+RHJ"B`J(%9&4R!!4$D@9F]R(&%B<W1R
M86-T960@9FEL92!S=&]R86=E(&%N9"!A8V-E<W,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U9&4R]61E,N<&AP+'8@,2XV.2XT+C$S(#(P,#8O,#,O,3<@
M,3<Z-#,Z,#,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'!A8VMA9V4@5D93"B`J($!S:6YC92`@($AO<F1E(#(N,@H@
M*B\*8VQA<W,@5D93('L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN
M9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@3&ES="!O9B!A9&1I=&EO;F%L(&-R961E;G1I86QS(')E
M<75I<F5D(&9O<B!T:&ES(%9&4R!B86-K96YD("AE>&%M<&QE.@H@("`@("H@
M1F]R($944"P@=V4@;F5E9"!A('5S97)N86UE(&%N9"!P87-S=V]R9"!T;R!L
M;V<@:6X@=&\@=&AE('-E<G9E<B!W:71H*2X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-R961E;G1I86QS(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@<&5R;6ES<VEO;G,@86YD(&EF
M('1H97D@8V%N(&)E(&-H86YG960@:6X@=&AI<R!61E,@8F%C:V5N9"X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E<FUI
M<W-I;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R)R`]/B!A<G)A>2@G<F5A
M9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F
M86QS92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L
M<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DL"B`@
M("`@("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET
M92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DI.PH*("`@("\J*@H@
M("`@("H@02!014%2($QO9R!O8FIE8W0N($EF('!R97-E;G0L('=I;&P@8F4@
M=7-E9"!T;R!L;V<@97)R;W)S(&%N9`H@("`@("H@:6YF;W)M871I;VYA;"!M
M97-S86=E<R!A8F]U="!61E,@86-T:79I='DN"B`@("`@*@H@("`@("H@0'9A
M<B!,;V<*("`@("`J+PH@("`@=F%R("1?;&]G9V5R(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J(%1H92!L;V<@;&5V96P@=&\@=7-E("T@;65S<V%G97,@=VET
M:"!A(&AI9VAE<B!L;V<@;&5V96P@=&AA;B!C;VYF:6=U<F5D"B`@("`@*B!H
M97)E('=I;&P@;F]T(&)E(&QO9V=E9"X@1&5F875L=',@=&\@;VYL>2!L;V=G
M:6YG(&5R<F]R<R!O<B!H:6=H97(N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D7VQO9TQE=F5L(#T@4$5!4E],3T=?15)2
M.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@<VEZ92P@:6X@8GET97,L
M(&]F('1H92!61E,@:71E;2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1?=F9S4VEZ92`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!61E,H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W5S97(G72DI
M('L*("`@("`@("`@("`@)'!A<F%M<ULG=7-E<B==(#T@)R<["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=V9G-?<75O=&%L:6UI="==
M*2D@>PH@("`@("`@("`@("`D<&%R86US6R=V9G-?<75O=&%L:6UI="==(#T@
M+3$["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=V9G-?
M<75O=&%R;V]T)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)W9F<U]Q=6]T
M87)O;W0G72`]("<O)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]P87)A
M;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H
M92!C<F5D96YT:6%L<R!T:&%T('=E(&AA=F4@8GD@8V%L;&EN9R!?8V]N;F5C
M="@I+"!T;R!S964@:68*("`@("`J('1H97)E(&ES(&$@=F%L:60@;&]G:6XN
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M+"!014%27T5R<F]R(&1E<V-R:6)I;F<@=&AE('!R;V)L96T@:68@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("!C<F5D96YT:6%L<R!A<F4@:6YV86QI9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM#<F5D96YT:6%L<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!C;VYF:6=U<F%T:6]N('!A<F%M971E<G,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%S<V]C:6%T
M:79E(&%R<F%Y('=I=&@@<&%R86UE=&5R(&YA;65S(&%S(&ME>7,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=%!A<F%M<R@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1N86UE(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULD;F%M95T@/2`D
M=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!C;VYF:6=U<F%T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@5&AE('!A<F%M971E<B!T;R!R971U<FXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('!A<F%M971E<B!V86QU
M92!O<B!N=6QL(&EF(&ET(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%!A<F%M*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!I
M<W-E="@D=&AI<RT^7W!A<F%M<ULD;F%M95TI(#\@)'1H:7,M/E]P87)A;7-;
M)&YA;65=(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J($QO9W,@82!M
M97-S86=E(&EF(&$@4$5!4B!,;V<@;V)J96-T(&ES(&%V86EL86)L92P@86YD
M('1H92!M97-S86=E)W,*("`@("`J('!R:6]R:71Y(&ES(&QO=V5R('1H86X@
M;W(@97%U86P@=&\@=&AE(&-O;F9I9W5R960@;&]G(&QE=F5L+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`@("1M97-S86=E("`@5&AE(&UE<W-A9V4@
M=&\@8F4@;&]G9V5D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!R:6]R:71Y
M("!4:&4@;65S<V%G92=S('!R:6]R:71Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](%!%05)?3$]'7T524BD*("`@
M('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;&]G9V5R*2!\?"`D<')I
M;W)I='D@/B`D=&AI<RT^7VQO9TQE=F5L*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1M97-S86=E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1U<V5R:6YF;R`]("1M97-S86=E
M+3YG9715<V5R26YF;R@I.PH@("`@("`@("`@("`D;65S<V%G92`]("1M97-S
M86=E+3YG971-97-S86=E*"D["B`@("`@("`@("`@(&EF("@D=7-E<FEN9F\I
M('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=7-E<FEN9F\I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'5S97)I;F9O(#T@:6UP;&]D92@G+"`G
M+"`D=7-E<FEN9F\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@+CT@)SH@)R`N("1U<V5R:6YF;SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('1O(&QO9R!I;B!T
M:&4@<WES=&5M)W,@;&]C86QE+B`J+PH@("`@("`@("1L;V-A;&4@/2!S971L
M;V-A;&4H3$-?5$E-12P@,"D["B`@("`@("`@<V5T;&]C86QE*$Q#7U1)344L
M("=#)RD["@H@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H)&UE<W-A9V4L
M("1P<FEO<FET>2D["@H@("`@("`@("\J(%)E<W1O<F4@;W)I9VEN86P@;&]C
M86QE+B`J+PH@("`@("`@('-E=&QO8V%L92A,0U]424U%+"`D;&]C86QE*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(%!%05(@3&]G(&]B:F5C
M="!U<V5D('1O(&QO9R!I;F9O<FUA=&EO;F%L(&]R(&5R<F]R(&UE<W-A9V5S
M+@H@("`@("H*("`@("`J($!P87)A;2!,;V<@)B1L;V=G97(@(%1H92!,;V<@
M;V)J96-T('1O('5S92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3&]G9V5R
M*"8D;&]G9V5R+"`D;&]G3&5V96P@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?82@D;&]G9V5R+"`G3&]G)RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]L;V=G97(@/2`F
M)&QO9V=E<CL*("`@("`@("!I9B`H(6ES7VYU;&PH)&QO9TQE=F5L*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQO9TQE=F5L(#T@)&QO9TQE=F5L.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@<VEZ
M92!O9B!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@5&AE(&9I;&4@<VEZ92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<VEZ92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@82!F:6QE(&9R;VT@=&AE(%9&
M4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T
M<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(&9I;&4@
M9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D<&%T:"P@)&YA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T
M('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M97,@82!P87)T(&]F(&$@9FEL92!F<F]M('1H92!61E,N(%!A<G1I8W5L87)L
M>2!U<V5F=6P@=VAE;@H@("`@("H@<F5A9&EN9R!L87)G92!F:6QE<R!W:&EC
M:"!W;W5L9"!E>&-E960@=&AE(%!(4"!M96UO<GD@;&EM:71S(&EF('1H97D*
M("`@("`J('=E<F4@<W1O<F5D(&EN(&$@<W1R:6YG+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1P871H
M("`@("`@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A
M;2!S=')I;F<@("1N86UE("`@("`@(%1H92!F:6QE;F%M92!T;R!R971R:65V
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1O9F9S970@("`@(%1H92!O9F9S
M970@;V8@=&AE('!A<G0N("A4:&4@;F5W(&]F9G-E="!W:6QL"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B92!S=&]R960@:6X@:&5R92DN
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&5N9W1H("`@("!4:&4@;&5N9W1H
M(&]F('1H92!P87)T+B!)9B!T:&4@;&5N9W1H(#T@+3$L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@=VAO;&4@<&%R="!A9G1E<B!T
M:&4@;V9F<V5T(&ES(')E=')I979E9"X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($EF(&UO<F4@8GET97,@87)E(&=I=F5N(&%S(&5X:7-T
M<R!A9G1E<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&=I=F5N(&]F9G-E="X@3VYL>2!T:&4@879A:6QA8FQE(&)Y=&5S(&%R90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5A9"X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1R96UA:6YI;F<@(%1H92!B>71E<R!T:&%T(&%R
M92!L969T+"!A9G1E<B!T:&4@<&%R="!T:&%T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I<R!R971R:65V960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@5&AE(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5A9$)Y=&5286YG92@D<&%T:"P@)&YA;64L("8D;V9F<V5T+"`D
M;&5N9W1H(#T@+3$L("8D<F5M86EN:6YG*0H@("`@>PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93+@H@
M("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL
M92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@
M9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&UP1FEL
M92`@("`@(%1H92!T96UP;W)A<GD@9FEL92!C;VYT86EN:6YG('1H92!D871A
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F4@<W1O
M<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M
M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E
M*"1P871H+"`D;F%M92P@)'1M<$9I;&4L("1A=71O8W)E871E(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T
M('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@
M82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@("`@
M*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O
M('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@("!4:&4@
M9FEL92!D871A+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@
M($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('=R:71E1&%T82@D<&%T:"P@)&YA;64L("1D871A+"`D875T;V-R96%T92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M36]V97,@82!F:6QE('1H<F]U9V@@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE('!A=&@@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@;W)I9VEN86P@9FEL
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!D97-T:6YA=&EO
M;B!F:6QE(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V92@D<&%T:"P@)&YA;64L("1D
M97-T*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]P
M:65S(&$@9FEL92!T:')O=6=H('1H92!B86-K96YD+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M(%1H92!P871H(&]F('1H92!O<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&]R:6=I;F%L(&9I;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D97-T("!4:&4@;F%M92!O9B!T:&4@
M9&5S=&EN871I;VX@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O<'DH)'!A=&@L
M("1N86UE+"`D9&5S="D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E;&5T97,@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("!4:&4@<&%T:"!T;R!D96QE=&4@=&AE(&9I;&4@9G)O;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!D96QE=&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&5L971E1FEL92@D<&%T:"P@)&YA;64I"B`@("!["B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E
M9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;65S(&$@9FEL92!I
M;B!T:&4@5D93+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@<&%T:"!T;R!T
M:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&]L9&YA;64@(%1H92!O
M;&0@9FEL96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P871H("!4
M:&4@;F5W('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N97=N86UE("!4:&4@;F5W(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M
M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92D*("`@
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P
M<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:68@
M82!G:79E;B!F:6QE(&]R(&9O;&1E<B!E>&ES=',@:6X@82!F;VQD97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@
M=&AE(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F
M:6QE(&]R(&9O;&1E<B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!I="!E>&ES=',L(&9A;'-E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1P871H+"`D;F%M92D*("`@('L*
M("`@("`@("`D;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H*3L*("`@
M("`@("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&ES<V5T*"1L:7-T6R1N86UE72D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&9O;&1E<B!I;B!T:&4@5D93
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@(%1H92!P87)E;G0@9F]L9&5R+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8W)E871E1F]L9&5R*"1P871H+"`D;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R
M=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($%U=&]M871I8V%L;'D@
M8W)E871E<R!A;GD@;F5C97-S87)Y('!A<F5N="!D:7)E8W1O<FEE<R!I;B!T
M:&4@<W!E8VEF:65D"B`@("`@*B`D<&%T:"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!4:&4@5D93('!A=&@@=&\@875T;V-R96%T92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@875T;V-R96%T95!A=&@H)'!A=&@I"B`@
M("!["B`@("`@("`@)&1I<G,@/2!E>'!L;V1E*"<O)RP@)'!A=&@I.PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D9&ER<RDI('L*("`@("`@("`@("`@)&-U<B`]
M("<O)SL*("`@("`@("`@("`@9F]R96%C:"`H)&1I<G,@87,@)&1I<BD@>PH@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9&ER*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@A)'1H:7,M/FES1F]L9&5R*"1C=7(L("1D:7(I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E
M871E1F]L9&5R*"1C=7(L("1D:7(I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&-U<B`A/2`G+R<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-U<B`N/2`G+R<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1C=7(@+CT@)&1I<CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!G
M:79E;B!I=&5M(&ES(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@(%1H92!P87)E;G0@9F]L9&5R+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&ET96T@;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@:70@:7,@82!F;VQD97(L(&9A;'-E
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-&;VQD97(H)'!A
M=&@L("1N86UE*0H@("`@>PH@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M
M/FQI<W1&;VQD97(H)'!A=&@L(&YU;&PL('1R=64L('1R=64I.PH@("`@("`@
M(')E='5R;B!I<W-E="@D9F]L9&5R3&ES=%LD;F%M95TI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A(&9O;&1E<B!F<F]M('1H92!61E,N"B`@
M("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@("`@("`@5&AE('!A<F5N="!F;VQD97(N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@;F%M92!O9B!T:&4@9F]L
M9&5R('1O(&1E;&5T92X*("`@("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I
M=F4@($9O<F-E(&$@<F5C=7)S:79E(&1E;&5T93\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE
M=&5&;VQD97(H)'!A=&@L("1N86UE+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U
M<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(')E
M8W5R<VEV96QY(&%L;"!F:6QE<R!A;F0@<W5B9F]L9&5R<R!F<F]M('1H92!G
M:79E;B!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE('!A=&@@;V8@=&AE(&9O;&1E<B!T;R!E;7!T>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E;7!T>49O;&1E<B@D<&%T:"D*("`@('L*("`@("`@("`O+R!'970@86YD
M(&1E;&5T92!T:&4@<W5B9F]L9&5R<RX*("`@("`@("`D;&ES="`]("1T:&ES
M+3YL:7-T1F]L9&5R*"1P871H+"!N=6QL+"!T<G5E+"!T<G5E*3L*("`@("`@
M("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&QI<W0["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1L
M:7-T(&%S("1F;VQD97(I('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YD96QE=&5&;VQD97(H)'!A=&@L("1F;VQD97);)VYA;64G72P@=')U92D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@("\O($]N;'D@9FEL97,@87)E(&QE9G0L
M(&=E="!A;F0@9&5L971E('1H96TN"B`@("`@("`@)&QI<W0@/2`D=&AI<RT^
M;&ES=$9O;&1E<B@D<&%T:"D["B`@("`@("`@:68@*&ES7V$H)&QI<W0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@
M("`@('T*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D9FEL92D@>PH@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T949I;&4H)'!A=&@L("1F
M:6QE6R=N86UE)UTI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!F:6QE(&QI<W0@;V8@=&AE(&1I<F5C=&]R>2!P87-S
M960@:6XN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@
M("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2!M
M:7AE9"`D9FEL=&5R("`@("`@(%-T<FEN9R]H87-H('1O(&9I;'1E<B!F:6QE
M+V1I<FYA;64@;VXN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@
M("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<F]N
M;'D@("`@4VAO=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H@0'!A<F%M(&)O
M;VQE86X@)')E8W5R<VEV92`@4F5T=7)N(&%L;"!D:7)E8W1O<GD@;&5V96QS
M(')E8W5R<VEV96QY/PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@($9I
M;&4@;&ES="!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<B@D<&%T:"P@)&9I;'1E
M<B`](&YU;&PL("1D;W1F:6QE<R`]('1R=64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("1D:7)O;FQY(#T@9F%L<V4L("1R96-U<G-I=F4@/2!F86QS92D*
M("`@('L*("`@("`@("`D;&ES="`]("1T:&ES+3Y?;&ES=$9O;&1E<B@D<&%T
M:"P@)&9I;'1E<BP@)&1O=&9I;&5S+"`D9&ER;VYL>2D["B`@("`@("`@:68@
M*"$D<F5C=7)S:79E('Q\(&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@("`@('T*"B`@("`@("`@
M9F]R96%C:"`H)&QI<W0@87,@)&YA;64@/3X@)'9A;'5E<RD@>PH@("`@("`@
M("`@("!I9B`H)'9A;'5E<ULG='EP92==(#T]("<J*F1I<B<I('L*("`@("`@
M("`@("`@("`@("1L:7-T6R1N86UE75LG<W5B9&ER<R==(#T@)'1H:7,M/FQI
M<W1&;VQD97(H)'!A=&@@+B`G+R<@+B`D;F%M92P@)&9I;'1E<BP@)&1O=&9I
M;&5S+"`D9&ER;VYL>2P@)')E8W5R<VEV92D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;&ES=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@86X@86X@=6YS;W)T960@9FEL92!L:7-T(&]F('1H
M92!S<&5C:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@5&AE
M('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2!M:7AE9"`D
M9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@=&\@9FEL=&5R(&9I;&4O9&ER;F%M
M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@4VAO=R!D
M;W1F:6QE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@4VAO
M=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($9I;&4@;&ES="!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQI<W1&;VQD97(H)'!A=&@L
M("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL97,@/2!T<G5E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1I<F]N;'D@/2!F86QS92D*("`@('L*("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@
M=V]R:VEN9R!D:7)E8W1O<GD@;V8@=&AE(%9&4R!B86-K96YD+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R<F5N="!W;W)K:6YG(&1I
M<F5C=&]R>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5R<F5N=$1I<F5C
M=&]R>2@I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R(&]R(&YO="!A(&9I;&5N86UE(&UA
M=&-H97,@86YY(&9I;'1E<B!E;&5M96YT+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R
M("`@("!3=')I;F<O:&%S:"!T;R!B=6EL9"!T:&4@<F5G=6QA<B!E>'!R97-S
M:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O;2X*("`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!3=')I;F<@8V]N=&%I;FEN
M9R!T:&4@9FEL96YA;64@=&\@;6%T8V@N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N(&UA=&-H+"!F86QS92!O;B!N;R!M871C:"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F
M:6QE;F%M92D*("`@('L*("`@("`@("`D;F%M969I;'1E<B`](&YU;&P["@H@
M("`@("`@("\O($)U:6QD(&$@<F5G97AP(&)A<V5D(&]N("1F:6QT97(N"B`@
M("`@("`@:68@*"1F:6QT97(@(3T](&YU;&PI('L*("`@("`@("`@("`@)&YA
M;65F:6QT97(@/2`G+R<["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D9FEL
M=&5R*2D@>PH@("`@("`@("`@("`@("`@)&]N8V4@/2!F86QS93L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1F:6QT97(@87,@)&ET96TI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&]N8V4@(3T]('1R=64I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&YA;65F:6QT97(@+CT@)R@G.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;VYC92`]('1R=64["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;65F:6QT
M97(@+CT@)WPH)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)&YA;65F:6QT97(@+CT@)&ET96T@+B`G*2<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;F%M969I;'1E<B`N/2`G*"<@+B`D9FEL=&5R("X@)RDG.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1N86UE9FEL=&5R("X]("<O)SL*("`@("`@
M("!]"@H@("`@("`@("1M871C:"`](&9A;'-E.PH@("`@("`@(&EF("@D;F%M
M969I;'1E<B`A/3T@;G5L;"D@>PH@("`@("`@("`@("`D;6%T8V@@/2!P<F5G
M7VUA=&-H*"1N86UE9FEL=&5R+"`D9FEL96YA;64I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1M871C:#L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M86YG97,@<&5R;6ES<VEO;G,@9F]R(&%N(&ET96T@;VX@=&AE(%9&4RX*("`@
M("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("`@("`@("!4:&4@<&%R96YT(&9O;&1E<B!O9B!T:&4@:71E
M;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H92!N86UE
M(&]F('1H92!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&5R;6ES<VEO
M;B`@5&AE('!E<FUI<W-I;VX@=&\@<V5T+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H86YG95!E
M<FUI<W-I;VYS*"1P871H+"`D;F%M92P@)'!E<FUI<W-I;VXI"B`@("!["B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E
M9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R=&5D
M(&QI<W0@;V8@9F]L9&5R<R!I;B!T:&4@<W!E8VEF:65D(&1I<F5C=&]R>2X*
M("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R
M>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@0'!A<F%M(&UI>&5D("1F
M:6QT97(@("`@("`@($AA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A<V5D(&]N
M(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9F]L9&5R
M<R`@26YC;'5D92!D;W1F;VQD97)S/PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T
M1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9O;&1E
M<G,@/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@;&ES="!O9B!A9&1I=&EO;F%L(&-R961E;G1I86QS
M(')E<75I<F5D+"!I9B!A;GDN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@0W)E9&5N=&EA;"!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9712
M97%U:7)E9$-R961E;G1I86QS*"D*("`@('L*("`@("`@("!R971U<FX@87)R
M87E?9&EF9B@D=&AI<RT^7V-R961E;G1I86QS+"!A<G)A>5]K97ES*"1T:&ES
M+3Y?<&%R86US*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N
M(&%R<F%Y('-P96-I9GEI;F<@=VAA="!P97)M:7-S:6]N<R!A<F4@8VAA;F=E
M86)L92!F;W(@=&AI<PH@("`@("H@5D93(&EM<&QE;65N=&%T:6]N+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($-H86YG96%B;&4@<&5R;6ES:6]N
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36]D:69I86)L95!E<FUI<W-I
M;VYS*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P97)M:7-S:6]N
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@<W1R:6YG('1O
M(&%L;"!L;W=E<F-A<V4@8VAA<F%C=&5R<R!I9VYO<FEN9R!T:&4@8W5R<F5N
M=`H@("`@("H@;&]C86QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'-T<FEN9R`@5&AE('-T<FEN9R!T;R!B92!L;W=E<F-A<V5D"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=')I;F<@=VET:"!L;W=E<F-A
M<V4@8VAA<F%C=&5R<PH@("`@("HO"B`@("!F=6YC=&EO;B!S=')T;VQO=V5R
M*"1S=')I;F<I"B`@("!["B`@("`@("`@)&QA;F=U86=E(#T@<V5T;&]C86QE
M*$Q#7T-465!%+"`P*3L*("`@("`@("!S971L;V-A;&4H3$-?0U194$4L("=E
M;B<I.PH@("`@("`@("1S=')I;F<@/2!S=')T;VQO=V5R*"1S=')I;F<I.PH@
M("`@("`@('-E=&QO8V%L92A,0U]#5%E012P@)&QA;F=U86=E*3L*("`@("`@
M("!R971U<FX@)'-T<FEN9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&-H87)A8W1E<B`H;F]T(&)Y=&4I(&QE;F=T:"!O9B!A('-T<FEN
M9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@("!4:&4@
M<W1R:6YG('1O(')E='5R;B!T:&4@;&5N9W1H(&]F+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E('=H96X@8V%L
M8W5L871I;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!S
M=')I;F<G<R!L96YG=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!S=')I;F<G<R!L96YG=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T
M<FQE;B@D<W1R:6YG+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*&5X=&5N<VEO;E]L;V%D960H)VUB<W1R:6YG)RDI('L*("`@("`@("`@
M("`@:68@*&ES7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`D
M8VAA<G-E="`]("=)4T\M.#@U.2TQ)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<F5T(#T@0&UB7W-T<FQE;B@D<W1R:6YG+"`D8VAA<G-E="D["B`@
M("`@("`@("`@(&EF("@A96UP='DH)')E="DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5T.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!S=')L96XH)'-T<FEN9RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!S:7IE(&]F(&$@9FEL92X*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!T:&4@9FEL92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!F
M:6QE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('-I>F4@
M;V8@=&AE(&9I;&4L(&EN(&)Y=&5S+"!O<B!014%27T5R<F]R(&]N"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$9I;&53:7IE*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-I>F4@;V8@82!F
M;VQD97(*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@=&AE(&9O
M;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F
M('1H92!F;VQD97(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@<VEZ92!O9B!T:&4@9F]L9&5R+"!I;B!B>71E<RP@;W(@4$5!4E]%<G)O
M<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971&;VQD97)3:7IE*"1P871H(#T@;G5L;"P@)&YA
M;64@/2!N=6QL*0H@("`@>PH@("`@("`@("1S:7IE(#T@,#L*("`@("`@("`D
M<F]O="`]("@H(6ES7VYU;&PH)'!A=&@I*2`_("1P871H("X@)R\G(#H@)R<I
M("X@)&YA;64["B`@("`@("`@)&]B:F5C=%]L:7-T(#T@)'1H:7,M/FQI<W1&
M;VQD97(H)')O;W0L(&YU;&PL('1R=64L(&9A;'-E+"!T<G5E*3L*("`@("`@
M("!F;W)E86-H("@D;V)J96-T7VQI<W0@87,@)&ME>2`]/B`D=F%L*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D=F%L6R=S=6)D:7)S)UTI*2!["B`@("`@
M("`@("`@("`@("`D<VEZ92`K/2`D=&AI<RT^9V5T1F]L9&5R4VEZ92@D<F]O
M="P@)&ME>2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<VEZ92`K/2!`)'1H:7,M/F=E=$9I;&53:7IE*"1R;V]T+"`D:V5Y*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S:7IE
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ92!O9B!T
M:&4@5D93(&ET96TN"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@
M("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('-I>F4L(&EN(&)Y
M=&5S+"!O9B!T:&4@5D93(&ET96TN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%9&4U-I>F4H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?
M=F9S4VEZ92DI('L*("`@("`@("`@("`@)'1H:7,M/E]V9G-3:7IE(#T@)'1H
M:7,M/F=E=$9O;&1E<E-I>F4H)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T87)O
M;W0G72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<U-I
M>F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!61E,@<75O=&$@
M;&EM:70N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1Q=6]T82`@(%1H92!L:6UI="!T;R!A
M<'!L>2X*("`@("`J($!P87)A;2!I;G1E9V5R("1M971R:6,@(%1H92!M971R
M:6,@=&\@;75L=&EP;'D@=&AE('%U;W1A(&EN=&\N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%%U;W1A*"1Q=6]T82P@)&UE=')I8R`](%9&4U]154]405]-
M151224-?0EE412D*("`@('L*("`@("`@("!S=VET8V@@*"1M971R:6,I('L*
M("`@("`@("!C87-E(%9&4U]154]405]-151224-?2T(Z"B`@("`@("`@("`@
M("1Q=6]T82`J/2!P;W<H,BP@,3`I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92!61E-?455/5$%?34544DE#7TU".@H@("`@("`@("`@("`D
M<75O=&$@*CT@<&]W*#(L(#(P*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@5D937U%53U1!7TU%5%))0U]'0CH*("`@("`@("`@("`@)'%U
M;W1A("H]('!O=R@R+"`S,"D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T86QI;6ET)UT@
M/2`D<75O=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!61E,@
M<75O=&$@<F]O="X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER("!4:&4@<F]O="!D:7)E
M8W1O<GD@9F]R('1H92!Q=6]T82!D971E<FUI;F%T:6]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S9711=6]T85)O;W0H)&1I<BD*("`@('L*("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=F9S7W%U;W1A<F]O="==(#T@)&1I<CL*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!Q=6]T82!I;F9O<FUA=&EO;B`H=7-E9"]A
M;&QO8V%T960I+"!I;B!B>71E<RX*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R
M9&4@,RXQ"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@06X@87-S;V-I
M871I=F4@87)R87DN"B`@("`@*B`@("`@("`@("`@("`@("`G;&EM:70G(#T@
M36%X:6UU;2!Q=6]T82!A;&QO=V5D"B`@("`@*B`@("`@("`@("`@("`@("`G
M=7-A9V4G(#T@0W5R<F5N=&QY('5S960@<&]R=&EO;B!O9B!Q=6]T82`H:6X@
M8GET97,I"B`@("`@*B`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T475O=&$H
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG=F9S
M7W%U;W1A;&EM:70G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B3F\@<75O=&$@<V5T+B(I*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=7-A9V4@/2`D=&AI<RT^9V5T5D934VEZ92@I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D=7-A9V4L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("!R971U<FX@)'5S86=E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=U<V%G92<@
M/3X@)'1H:7,M/F=E=%9&4U-I>F4H*2P@)VQI;6ET)R`]/B`D=&AI<RT^7W!A
M<F%M<ULG=F9S7W%U;W1A;&EM:70G72D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!L;V-A
M=&EO;B!O9B!T:&4@<WES=&5M('1E;7!O<F%R>2!D:7)E8W1O<GDN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@02!D:7)E8W1O<GD@;F%M92!W:&EC:"!C86X@8F4@=7-E
M9"!F;W(@=&5M<"!F:6QE<RX*("`@("`J("`@("`@("`@("`@("`@("!2971U
M<FYS(&9A;'-E(&EF(&]N92!C;W5L9"!N;W0@8F4@9F]U;F0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971496UP1&ER*"D*("`@('L*("`@("`@("`D=&UP
M7VQO8V%T:6]N<R`](&%R<F%Y*"<O=&UP)RP@)R]V87(O=&UP)RP@)V,Z7%=5
M5&5M<"<L("=C.EQT96UP)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=C.EQW:6YD;W=S7'1E;7`G+"`G8SI<=VEN;G1<=&5M<"<I.PH*("`@
M("`@("`O*B!4<GD@4$A0)W,@=7!L;V%D7W1M<%]D:7(@9&ER96-T:79E+B`J
M+PH@("`@("`@("1T;7`@/2!I;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I.PH*
M("`@("`@("`O*B!/=&AE<G=I<V4L('1R>2!T;R!D971E<FUI;F4@=&AE(%1-
M4$1)4B!E;G9I<F]N;65N="!V87)I86)L92X@*B\*("`@("`@("!I9B`H96UP
M='DH)'1M<"DI('L*("`@("`@("`@("`@)'1M<"`](&=E=&5N=B@G5$U01$E2
M)RD["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!S=&EL;"!C86YN;W0@
M9&5T97)M:6YE(&$@=F%L=64L('1H96X@8WEC;&4@=&AR;W5G:"!A(&QI<W0@
M;V8*("`@("`@("`@*B!P<F5S970@<&]S<VEB:6QI=&EE<RX@*B\*("`@("`@
M("!W:&EL92`H96UP='DH)'1M<"D@)B8@<VEZ96]F*"1T;7!?;&]C871I;VYS
M*2D@>PH@("`@("`@("`@("`D=&UP7V-H96-K(#T@87)R87E?<VAI9G0H)'1M
M<%]L;V-A=&EO;G,I.PH@("`@("`@("`@("!I9B`H0&ES7V1I<B@D=&UP7V-H
M96-K*2D@>PH@("`@("`@("`@("`@("`@)'1M<"`]("1T;7!?8VAE8VL["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF(&ET(&ES('-T
M:6QL(&5M<'1Y+"!W92!H879E(&9A:6QE9"P@<V\@<F5T=7)N(&9A;'-E.R!O
M=&AE<G=I<V4*("`@("`@("`@*B!R971U<FX@=&AE(&1I<F5C=&]R>2!D971E
M<FUI;F5D+B`J+PH@("`@("`@(')E='5R;B!E;7!T>2@D=&UP*2`_(&9A;'-E
M(#H@)'1M<#L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!T96UP
M;W)A<GD@9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@4F5T=7)N<R!T:&4@9G5L
M;"!P871H+6YA;64@=&\@=&AE('1E;7!O<F%R>2!F:6QE(&]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@(&9A;'-E(&EF(&$@=&5M<&]R87)Y(&9I;&4@8V]U
M;&0@;F]T(&)E(&-R96%T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9714
M96UP1FEL92@I"B`@("!["B`@("`@("`@)'1M<%]D:7(@/2`D=&AI<RT^7V=E
M=%1E;7!$:7(H*3L*("`@("`@("!I9B`H96UP='DH)'1M<%]D:7(I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T
M;7!?9FEL92`]('1E;7!N86TH)'1M<%]D:7(L("=V9G,G*3L*"B`@("`@("`@
M+RH@268@=&AE(&9I;&4@=V%S(&-R96%T960L('1H96X@<F5G:7-T97(@:70@
M9F]R(&1E;&5T:6]N(&%N9`H@("`@("`@("`J(')E='5R;BX@*B\*("`@("`@
M("!I9B`H96UP='DH)'1M<%]F:6QE*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T
M;7!?9FEL93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:W,@=&AE('%U;W1A('=H96X@<')E<&%R:6YG('1O('=R:71E(&1A=&$N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;6]D92`@($5I=&AE<B`G<W1R:6YG)R!O<B`G9FEL92<N
M("!)9B`G<W1R:6YG)RP@)&1A=&$@:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@9&%T82!T;R!B92!W<FET=&5N+B`@268@)V9I;&4G+"`D
M9&%T82!I<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F:6QE
M;F%M92!C;VYT86EN:6YG('1H92!D871A('1O(&)E('=R:71T96XN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("8D9&%T82`@16ET:&5R('1H92!D871A(&]R('1H
M92!F:6QE;F%M92!T;R!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!014%27T5R<F]R(&]N(&5R<F]R+"!T<G5E(&]N('-U8V-E<W,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:U%U;W1A5W)I=&4H)&UO9&4L
M("8D9&%T82D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)W9F
M<U]Q=6]T86QI;6ET)UT@(3T@+3$I('L*("`@("`@("`@("`@:68@*"1M;V1E
M(#T]("=F:6QE)RD@>PH@("`@("`@("`@("`@("`@)&9I;&5S:7IE(#T@0&9I
M;&5S:7IE*"1D871A*3L*("`@("`@("`@("`@("`@(&EF("@D9FEL97-I>F4@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S
M:7IE*"D@9F%I;&5D*2XB*2D["B`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F:6QE<VEZ92`]('-T<FQE
M;B@D9&%T82D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"@D=&AI
M<RT^9V5T5D934VEZ92@I("L@)&9I;&5S:7IE*2`^("1T:&ES+3Y?<&%R86US
M6R=V9G-?<75O=&%L:6UI="==*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L
M('%U;W1A('=I;&P@8F4@97AC965D960N(BDI.PH@("`@("`@("`@("!](&5L
M<V5I9B`H)'1H:7,M/E]V9G-3:7IE("$]/2`P*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9F<U-I>F4@*ST@)&9I;&5S:7IE.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K<R!T:&4@<75O=&$@=VAE;B!P<F5P87)I;F<@=&\@
M9&5L971E(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&AE
M(&9I;&4@:7,@;&]C871E9"!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!014%27T5R<F]R(&]N(&5R<F]R+"!T<G5E(&]N('-U8V-E<W,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C:&5C:U%U;W1A1&5L971E*"1P871H+"`D;F%M
M92D*("`@('L*("`@("`@("!I9B`H*"1T:&ES+3Y?<&%R86US6R=V9G-?<75O
M=&%L:6UI="==("$]("TQ*2`F)@H@("`@("`@("`@("`A96UP='DH)'1H:7,M
M/E]V9G-3:7IE*2D@>PH@("`@("`@("`@("`D9FEL97-I>F4@/2`D=&AI<RT^
M9V5T1FEL95-I>F4H)'!A=&@L("1N86UE*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)&9I;&5S:7IE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(I*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^7W9F<U-I>F4@+3T@)&9I;&5S:7IE
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!61E,@
M:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@5D93('-U
M8F-L87-S('1O(')E='5R;BX@5&AI<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E<B`H)&1R:79E
M<BDN(%1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O9&4@:7,@
M9'EN86UI8V%L;'D@:6YC;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG
M=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE
M8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!61E,@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R
M971E(%9&4R!I;G-T86YC92P@;W(@82!014%27T5R<F]R"B`@("`@*B`@("`@
M("`@("`@("`@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A
M8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:6YC;'5D95]O;F-E("=61E,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@)&-L87-S(#T@)U9&4U\G("X@)&1R:79E<CL*("`@("`@("!I9B`H
M8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)'9F<R`]("9N
M97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1V9G,@/2!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(BDL("1C;&%S<RDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1V9G,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC
M<F5T92!61E,@:6YS=&%N8V4@8F%S960@;VX*("`@("`J("1D<FEV97(N($ET
M('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@5D93(&EN
M<W1A;F-E('=I=&@@=&AE"B`@("`@*B!S86UE('!A<F%M971E<G,@8W5R<F5N
M=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D
M(&EF(&UU;'1I<&QE('1Y<&5S(&]F(&9I;&4@8F%C:V5N9',@*&%N9"P@=&AU
M<RP*("`@("`J(&UU;'1I<&QE(%9&4R!I;G-T86YC97,I(&%R92!R97%U:7)E
M9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@
M87,Z("1V87(@/2`F5D93.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!61E,@
M<W5B8VQA<W,@=&\@<F5T=7)N+B!4:&ES"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@:7,@8F%S960@;VX@=&AE('-T;W)A9V4@9')I=F5R("@D9')I
M=F5R*2X@5&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]D92!I
M<R!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF
M:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N
M;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(%9&4R`@5&AE(&-O;F-R971E(%9&4R!R969E
M<F5N8V4L(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@("`@("`@
M(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A
M;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E
M(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@
M("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@
M("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F5D93.CIF86-T;W)Y
M*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O87!I
M+G!H<```````````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$R-S8U`#$P-#$W,S8R-S<V`#`Q-C0W,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@2&]R
M9&4@97AT97)N86P@05!)(&EN=&5R9F%C92X*("H*("H@5&AI<R!F:6QE(&1E
M9FEN97,@2&]R9&4G<R!E>'1E<FYA;"!!4$D@:6YT97)F86-E+B!/=&AE<@H@
M*B!A<'!L:6-A=&EO;G,@8V%N(&EN=&5R86-T('=I=&@@2&]R9&4@=&AR;W5G
M:"!T:&ES($%022X*("H*("H@)$AO<F1E.B!H;W)D92]L:6(O87!I+G!H<"QV
M(#$N-#,N,BXS(#(P,#4O,3`O,3@@,3$Z,S,Z,SD@:F%N($5X<"`D"B`J"B`J
M($!P86-K86=E($AO<F1E"B`J+PH*)%]S97)V:6-E<ULG<&5R;7,G72`](&%R
M<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@("`G='EP92<@/3X@)WMU
M<FXZ:&]R9&5]<W1R:6YG07)R87DG*3L*"B1?='EP97,@/2!A<G)A>2@*("`@
M("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)R`]/B!A<G)A>2AA<G)A>2@G:71E
M;2<@/3X@)W-T<FEN9R<I*2P*("`@("=H87-H271E;2<@/3X@87)R87DH)VME
M>2<@/3X@)W-T<FEN9R<L("=V86QU92<@/3X@)W-T<FEN9R<I+`H@("`@)VAA
M<V@G(#T^(&%R<F%Y*&%R<F%Y*"=I=&5M)R`]/B`G>W5R;CIH;W)D97UH87-H
M271E;2<I*2P*("`@("=H87-H2&%S:$ET96TG(#T^(&%R<F%Y*"=K97DG(#T^
M("=S=')I;F<G+"`G=F%L=64G(#T^("=[=7)N.FAO<F1E?6AA<V@G*2P*("`@
M("=H87-H2&%S:"<@/3X@87)R87DH87)R87DH)VET96TG(#T^("=[=7)N.FAO
M<F1E?6AA<VA(87-H271E;2<I*2D["@HD7W-E<G9I8V5S6R=A9&UI;E]L:7-T
M)UT@/2!A<G)A>2AT<G5E*3L*"B1?<V5R=FEC97-;)W)E;6]V955S97)$871A
M)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G=7-E<B<@/3X@)W-T
M<FEN9R<I"BD["@HD7W-E<G9I8V5S6R=L:7-T07!P<R==(#T@87)R87DH"B`@
M("`G87)G<R<@/3X@87)R87DH)V9I;'1E<B<@/3X@)WMU<FXZ:&]R9&5]<W1R
M:6YG07)R87DG*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!
M<G)A>2<**3L*"B1?<V5R=FEC97-;)VQI<W1!4$ES)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E
M?7-T<FEN9T%R<F%Y)PHI.PH*)%]S97)V:6-E<ULG8FQO8VM4:71L92==(#T@
M87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)V%P<"<@/3X@)W-T<FEN9R<L
M("=N86UE)R`]/B`G<W1R:6YG)RP@)W!A<F%M<R<@/3X@)WMU<FXZ:&]R9&5]
M:&%S:"<I+`H@("`@)W1Y<&4G(#T^("=S=')I;F<G"BD["@HD7W-E<G9I8V5S
M6R=B;&]C:T-O;G1E;G0G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y
M*"=A<'`G(#T^("=S=')I;F<G+"`G;F%M92<@/3X@)W-T<FEN9R<L("=P87)A
M;7,G(#T^("=[=7)N.FAO<F1E?6AA<V@G*2P*("`@("=T>7!E)R`]/B`G<W1R
M:6YG)PHI.PH*)%]S97)V:6-E<ULG9V5T4')E9F5R96YC92==(#T@87)R87DH
M"B`@("`G87)G<R<@/3X@87)R87DH)V%P<"<@/3X@)W-T<FEN9R<L("=P<F5F
M)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)W-T<FEN9R<**3L*"B1?
M<V5R=FEC97-;)W-E=%!R969E<F5N8V4G72`](&%R<F%Y*`H@("`@)V%R9W,G
M(#T^(&%R<F%Y*"=A<'`G(#T^("=S=')I;F<G+"`G<')E9B<@/3X@)W-T<FEN
M9R<L("=V86QU92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L
M96%N)PHI.PH*)%]S97)V:6-E<ULG8FQO8VMS)UT@/2!A<G)A>2@*("`@("=A
M<F=S)R`]/B!A<G)A>2@I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?6AA
M<V@G"BD["@H*9G5N8W1I;VX@)E]H;W)D95]B;&]C:R@D87!P+"`D;F%M92P@
M)'!A<F%M<R`](&%R<F%Y*"DI"GL*("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:RYP:'`G.PH@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<"<["@H@("`@)')E
M<W5L="`]("1R96=I<W1R>2T^<'5S:$%P<"@D87!P*3L*("`@(&EF("@A:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)')E<W5L="`]
M($AO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K*"1A<'`L("1N86UE
M+"`D<&%R86US*3L*("`@("`@("`D<F5G:7-T<GDM/G!O<$%P<"@D87!P*3L*
M("`@('T*("`@(')E='5R;B`D<F5S=6QT.PI]"@IF=6YC=&EO;B!?:&]R9&5?
M<&5R;7,H*0I["B`@("`D<&5R;7,@/2!A<G)A>2@I.PH*("`@("1P97)M<ULG
M=')E92==6R=H;W)D92==6R=M87A?8FQO8VMS)UT@/2!F86QS93L*("`@("1P
M97)M<ULG=&ET;&4G75LG:&]R9&4Z;6%X7V)L;V-K<R==(#T@7R@B36%X:6UU
M;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(I.PH@("`@)'!E<FUS6R=T>7!E
M)UU;)VAO<F1E.FUA>%]B;&]C:W,G72`]("=I;G0G.PH*("`@(')E='5R;B`D
M<&5R;7,["GT*"F9U;F-T:6]N(%]H;W)D95]B;&]C:U1I=&QE*"1A<'`L("1N
M86UE+"`D<&%R86US(#T@87)R87DH*2D*>PH@("`@)&)L;V-K(#T@)E]H;W)D
M95]B;&]C:R@D87!P+"`D;F%M92P@)'!A<F%M<RD["B`@("!I9B`H:7-?82@D
M8FQO8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)&)L;V-K
M+3YG971-97-S86=E*"D["B`@("!]"B`@("!R971U<FX@)&)L;V-K+3YG9714
M:71L92@I.PI]"@IF=6YC=&EO;B!?:&]R9&5?8FQO8VM#;VYT96YT*"1A<'`L
M("1N86UE+"`D<&%R86US(#T@87)R87DH*2D*>PH@("`@)&)L;V-K(#T@)E]H
M;W)D95]B;&]C:R@D87!P+"`D;F%M92P@)'!A<F%M<RD["B`@("!I9B`H:7-?
M82@D8FQO8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)&)L
M;V-K+3YG971-97-S86=E*"D["B`@("!]"B`@("!R971U<FX@)&)L;V-K+3YG
M971#;VYT96YT*"D["GT*"F9U;F-T:6]N(%]H;W)D95]B;&]C:W,H*0I["B`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*
M("`@("1C;VQL96-T:6]N(#T@)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.G-I
M;F=L971O;B@I.PH@("`@:68@*&ES7V$H)&-O;&QE8W1I;VXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("!R971U<FX@)&-O;&QE8W1I;VX["B`@("!](&5L
M<V4@>PH@("`@("`@(')E='5R;B`D8V]L;&5C=&EO;BT^9V5T0FQO8VMS3&ES
M="@I.PH@("`@?0I]"@IF=6YC=&EO;B!?:&]R9&5?861M:6Y?;&ES="@I"GL*
M("`@(')E='5R;B!A<G)A>2@G8V]N9FEG=7)A=&EO;B<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B`G)6%P<&QI8V%T:6]N)2]A
M9&UI;B]S971U<"\G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@
M7R@B7U-E='5P(BDL"B`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G
M8V]N9FEG+G!N9R<I+`H@("`@("`@("`@("`@("`@("=U<V5R<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B`G)6%P<&QI8V%T
M:6]N)2]A9&UI;B]U<V5R+G!H<"<L"B`@("`@("`@("`@("`@("`@("`@("=N
M86UE)R`]/B!?*")?57-E<G,B*2P*("`@("`@("`@("`@("`@("`@("`@)VEC
M;VXG(#T^("=U<V5R+G!N9R<I+`H@("`@("`@("`@("`@("`@("=G<F]U<',G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A
M<'!L:6-A=&EO;B4O861M:6XO9W)O=7!S+G!H<"<L"B`@("`@("`@("`@("`@
M("`@("`@("=N86UE)R`]/B!?*")?1W)O=7!S(BDL"B`@("`@("`@("`@("`@
M("`@("`@("=I8V]N)R`]/B`G9W)O=7`N<&YG)RDL"B`@("`@("`@("`@("`@
M("`@)W!E<FUS)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@)VQI
M;FLG(#T^("<E87!P;&EC871I;VXE+V%D;6EN+W!E<FUS+VEN9&5X+G!H<"<L
M"B`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")?4&5R;6ES<VEO
M;G,B*2P*("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=P97)M<RYP
M;F<G*2P*("`@("`@("`@("`@("`@("`G9&%T871R964G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O
M861M:6XO9&%T871R964N<&AP)RP*("`@("`@("`@("`@("`@("`@("`@)VYA
M;64G(#T^(%\H(E]$871A5')E92(I+`H@("`@("`@("`@("`@("`@("`@("`G
M:6-O;B<@/3X@)V1A=&%T<F5E+G!N9R<I+`H@("`@("`@("`@("`@("`@("=S
M97-S:6]N<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("=L:6YK
M)R`]/B`G)6%P<&QI8V%T:6]N)2]A9&UI;B]S97-S:6]N<RYP:'`G+`H@("`@
M("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B4V5S<VEO;G,B*2P*("`@
M("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=U<V5R+G!N9R<I+`H@("`@
M("`@("`@("`@("`@("=P:'!S:&5L;"<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("=L:6YK)R`]/B`G)6%P<&QI8V%T:6]N)2]A9&UI;B]P:'!S
M:&5L;"YP:'`G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B
M4%](4"!3:&5L;"(I+`H@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@
M)VUI;64O<&AP+G!N9R<I+`H@("`@("`@("`@("`@("`@("=S<6QS:&5L;"<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B`G)6%P
M<&QI8V%T:6]N)2]A9&UI;B]S<6QS:&5L;"YP:'`G+`H@("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@/3X@7R@B4U]13"!3:&5L;"(I+`H@("`@("`@("`@
M("`@("`@("`@("`G:6-O;B<@/3X@)W-Q;"YP;F<G*2P*("`@("`@("`@("`@
M("`@("`G8VUD<VAE;&PG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO8VUD<VAE;&PN<&AP
M)RP*("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E]#3$DB*2P*
M("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=S:&5L;"YP;F<G*2P*
M("`@("`@("`@("`@("`@("`I.PI]"@IF=6YC=&EO;B!?:&]R9&5?<F5M;W9E
M57-E<D1A=&$H)'5S97(I"GL*("`@(&=L;V)A;"`D8V]N9CL*"B`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U!R969S+G!H<"<["B`@("`D<')E9G,@/2`F4')E
M9G,Z.G-I;F=L971O;B@D8V]N9ELG<')E9G,G75LG9')I=F5R)UTL(&YU;&PL
M("1U<V5R*3L*("`@(&EF("AI<U]A*"1R97-U;'0@/2`D<')E9G,M/F-L96%R
M*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@('T*?0H*9G5N8W1I;VX@7VAO<F1E7VQI<W1!<'!S*"1F:6QT97(@/2!N
M=6QL*0I["B`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1!
M<'!S*"1F:6QT97(I.PI]"@IF=6YC=&EO;B!?:&]R9&5?;&ES=$%027,H*0I[
M"B`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1!4$ES*"D[
M"GT*"F9U;F-T:6]N(%]H;W)D95]G9710<F5F97)E;F-E*"1A<'`L("1P<F5F
M*0I["B`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^;&]A9%!R969S*"1A<'`I
M.PH@("`@<F5T=7)N("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@D<')E
M9BD["GT*"F9U;F-T:6]N(%]H;W)D95]S9710<F5F97)E;F-E*"1A<'`L("1P
M<F5F+"`D=F%L=64I"GL*("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YL;V%D
M4')E9G,H)&%P<"D["B`@("!R971U<FX@)$=,3T)!3%-;)W!R969S)UTM/G-E
M=%9A;'5E*"1P<F5F+"`D=F%L=64I.PI]"@``````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O5&5S="YP:'``````````````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4T-S,R`#$P-#$W,S8R
M-S<V`#`Q-C8S-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*+RHJ"B`J($1E9FEN92!(3U)$15]"05-%+"!I9B!I
M="!I<R!N;W0@86QR96%D>2!S970L(&%N9"!I;F-L=61E('1H92!M86EN"B`J
M($AO<F1E(&QI8G)A<GDL('-I;F-E('=E(')E<75I<F4@:70@9F]R('1H:7,@
M<&%C:V%G92!T;R!F=6YC=&EO;BX*("HO"FEF("@A9&5F:6YE9"@G2$]21$5?
M0D%312<I*2!["B`@("!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXG*3L*?0IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O;&EB+V-O<F4N<&AP)SL*"B\J*@H@*B!3970@=&AE('!A=&@@=&\@=&AE
M('1E;7!L871E<R!N965D960@9F]R('1E<W1I;F<@;W5T<'5T+@H@*B\*9&5F
M:6YE*"=415-47U1%35!,051%4R<L($A/4D1%7T)!4T4@+B`G+W1E;7!L871E
M<R]T97-T+R<I.PH*+RH@268@9V5T=&5X="!I<R!N;W0@;&]A9&5D+"!D969I
M;F4@82!D=6UM>2!?*"D@9G5N8W1I;VX@<V\@=&AA=`H@*B!I;F-L=61I;F<@
M86YY(&9I;&4@=VET:"!G971T97AT('-T<FEN9W,@=V]N)W0@8V%U<V4@82!F
M871A;"!E<G)O<BP*("H@8V%U<VEN9R!T97-T+G!H<"!T;R!R971U<FX@82!B
M;&%N:R!P86=E+B`J+PII9B`H(69U;F-T:6]N7V5X:7-T<R@G7R<I*2!["B`@
M("!F=6YC=&EO;B!?*"1S*2![(')E='5R;B`D<SL@?0I]"@HO*BH*("H@5&AE
M($AO<F1E7U1E<W0Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;G,@=7-E9"!I
M;B!T:&4@=&5S="!S8W)I<'1S"B`J('5S960@:6X@=&AE('9A<FEO=7,@87!P
M;&EC871I;VYS("AT97-T+G!H<"DN"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB
M+U1E<W0N<&AP+'8@,2XS,2XT+C$Y(#(P,#8O,#,O,C@@,3(Z,S$Z,3,@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($)R96YT($HN($YO<F1Q=6ES="`\8FIN0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!A=71H
M;W(@($)R96YT($HN($YO<F1Q=6ES="`\8FIN0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?5&5S=`H@*B\*8VQA<W,@2&]R9&5?5&5S="!["@H@("`@+RHJ"B`@("`@
M*B!!<G)A>2!T:&%T(&AO;&1S('1H92!L:7-T(&]F($AO<F1E(&%P<&QI8V%T
M:6]N<RX*("`@("`J("A,;V%D960@9G)O;2!C;VYF:6<O<F5G:7-T<GDN<&AP
M*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1A
M<'!L:6-A=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V%C:&5D
M(')E<W5L=',@;V8@9V5T07!P;&EC871I;VYS*"DN"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<'!O=71P=70@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5&AE(%!(4"!V97)S:6]N(&]F('1H92!S
M>7-T96TN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]P:'!V97(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5&5S="@I"B`@("!["B`@("`@("`@
M:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP
M:'`G.PH@("`@("`@(&MS;W)T*"1T:&ES+3YA<'!L:6-A=&EO;G,I.PH*("`@
M("`@("`O*B!3=&]R92!T:&4@4$A0('9E<G-I;VX@:6YF;W)M871I;VXN("HO
M"B`@("`@("`@)'1H:7,M/E]P:'!V97(@/2`D=&AI<RT^<W!L:7102%!697)S
M:6]N*'!H<'9E<G-I;VXH*2D["@H@("`@("`@("\J(%=E('=A;G0@=&\@8F4@
M87,@=F5R8F]S92!A<R!P;W-S:6)L92!H97)E+B`J+PH@("`@("`@(&5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@("`@("\J(%-E="!C:&%R86-T97(@
M96YC;V1I;F<N("HO"B`@("`@("`@:&5A9&5R*"=#;VYT96YT+71Y<&4Z('1E
M>'0O:'1M;#L@8VAA<G-E=#UU=&8M."<I.PH@("`@("`@(&AE861E<B@G5F%R
M>3H@06-C97!T+4QA;F=U86=E)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S92!02%`@=F5R<VEO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1V97)S:6]N("!!(%!(4"US='EL92!V97)S:6]N('-T<FEN9R`H6"Y8+E@I
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@5&AE('!A<G-E9"!S=')I
M;F<N"B`@("`@*B`@("`@("`@("`@("`@($ME>7,Z("=M86IO<B<L("=M:6YO
M<B<L("=S=6)M:6YO<B<L("=C;&%S<R<*("`@("`J+PH@("`@9G5N8W1I;VX@
M<W!L:7102%!697)S:6]N*"1V97)S:6]N*0H@("`@>PH@("`@("`@("\J($9I
M<G-T('!I8VL@;V9F(&UA:F]R('9E<G-I;VXL(&%N9"!L;W=E<BUC87-E('1H
M92!R97-T+B`J+PH@("`@("`@(&EF("@H<W1R;&5N*"1V97)S:6]N*2`^/2`S
M*2`F)B`H)'9E<G-I;VY;,5T@/3T@)RXG*2D@>PH@("`@("`@("`@("`D<&AP
M=F5R6R=M86IO<B==(#T@<W5B<W1R*"1V97)S:6]N+"`P+"`S*3L*("`@("`@
M("`@("`@)'9E<G-I;VX@/2!S=6)S='(H<W1R=&]L;W=E<B@D=F5R<VEO;BDL
M(#,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P:'!V97);)VUA
M:F]R)UT@/2`D=F5R<VEO;CL*("`@("`@("`@("`@)'!H<'9E<ELG8VQA<W,G
M72`]("=U;FMN;W=N)SL*("`@("`@("`@("`@<F5T=7)N("1P:'!V97(["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'9E<G-I;VY;,%T@/3T@)RXG*2!["B`@
M("`@("`@("`@("1V97)S:6]N(#T@<W5B<W1R*"1V97)S:6]N+"`Q*3L*("`@
M("`@("!]"@H@("`@("`@("\J($YE>'0L(&1E=&5R;6EN92!I9B!T:&ES(&ES
M(#0N,&(@;W(@-"XP<F,[(&EF('-O+"!T:&5R92!I<R!N;PH@("`@("`@("`@
M(&UI;F]R+"!T:&4@<F5S="!I<R!T:&4@<W5B;6EN;W(L(&%N9"!C;&%S<R!I
M<R!S970@=&\@8F5T82X@*B\*("`@("`@("`D<R`]('-T<G-P;B@D=F5R<VEO
M;BP@)S`Q,C,T-38W.#DG*3L*("`@("`@("!I9B`H)',@/3T@,"D@>PH@("`@
M("`@("`@("`D<&AP=F5R6R=S=6)M:6YO<B==(#T@)'9E<G-I;VX["B`@("`@
M("`@("`@("1P:'!V97);)V-L87-S)UT@/2`G8F5T82<["B`@("`@("`@("`@
M(')E='5R;B`D<&AP=F5R.PH@("`@("`@('T*"B`@("`@("`@+RH@3W1H97)W
M:7-E+"!T:&ES(&ES(&YO;BUB971A.R`@=&AE(&YU;65R:6,@<&%R="!I<R!T
M:&4@;6EN;W(L"B`@("`@("`@("`@=&AE(')E<W0@:7,@96ET:&5R(&$@8VQA
M<W-I9FEC871I;VX@*&1E=BP@8W9S*2!O<B!A('-U8FUI;F]R"B`@("`@("`@
M("`@=F5R<VEO;B`H<F,\>#XL('!L/'@^*2X@*B\*("`@("`@("`D<&AP=F5R
M6R=M:6YO<B==(#T@<W5B<W1R*"1V97)S:6]N+"`P+"`D<RD["B`@("`@("`@
M:68@*"AS=')L96XH)'9E<G-I;VXI(#X@)',I("8F"B`@("`@("`@("`@("@H
M)'9E<G-I;VY;)'-=(#T]("<N)RD@?'P@*"1V97)S:6]N6R1S72`]/2`G+2<I
M*2D@>PH@("`@("`@("`@("`D<RLK.PH@("`@("`@('T*("`@("`@("`D<&AP
M=F5R6R=S=6)M:6YO<B==(#T@<W5B<W1R*"1V97)S:6]N+"`D<RD["B`@("`@
M("`@:68@*"@D<&AP=F5R6R=S=6)M:6YO<B==(#T]("=C=G,G*2!\?`H@("`@
M("`@("`@("`H)'!H<'9E<ELG<W5B;6EN;W(G72`]/2`G9&5V)RD@?'P*("`@
M("`@("`@("`@*'-U8G-T<B@D<&AP=F5R6R=S=6)M:6YO<B==+"`P+"`R*2`]
M/2`G<F,G*2D@>PH@("`@("`@("`@("!U;G-E="@D<&AP=F5R6R=S=6)M:6YO
M<B==*3L*("`@("`@("`@("`@)'!H<'9E<ELG8VQA<W,G72`]("=D978G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A)'!H<'9E<ELG<W5B
M;6EN;W(G72D@>PH@("`@("`@("`@("`@("`@=6YS970H)'!H<'9E<ELG<W5B
M;6EN;W(G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!H<'9E<ELG
M8VQA<W,G72`]("=R96QE87-E)SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<&AP=F5R.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@=&AE(&QI
M<W0@;V8@4$A0(&UO9'5L97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1M;V1L:7-T("!4:&4@;6]D=6QE(&QI<W0N"B`@("`@*B`\<')E/@H@("`@
M("H@2T59.B`@(&UO9'5L92!N86UE"B`@("`@*B!604Q513H@16ET:&5R('1H
M92!D97-C<FEP=&EO;B!O<B!A;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@
M96YT<FEE<SH*("`@("`J("`@("`@("`G9&5S8W)I<"<@("TM("!-;V1U;&4@
M1&5S8W)I<'1I;VX*("`@("`J("`@("`@("`G97)R;W(G("`@("TM("!%<G)O
M<B!-97-S86=E"B`@("`@*B`@("`@("`@)W!H<'9E<B<@("`M+2`@5&AE(%!(
M4"!V97)S:6]N(&%B;W9E('=H:6-H('1O(&1O('1H92!T97-T"B`@("`@*B`\
M+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!P:'!-;V1U;&5#:&5C:R@D
M;6]D;&ES="D*("`@('L*("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@
M)&]U='!U=%]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1M
M;V1L:7-T(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D97)R;W)?
M;7-G(#T@)&UO9%]T97-T(#T@)'-T871U<U]O=70@/2`D9F%T86P@/2!N=6QL
M.PH@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH*("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@("`@("`@("`D9&5S8W)I
M<"`]("1V86Q;)V1E<V-R:7`G73L*("`@("`@("`@("`@("`@("1F871A;"`]
M("%E;7!T>2@D=F%L6R=F871A;"==*3L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=F%L6R=P:'!V97(G72D@)B8*("`@("`@("`@("`@("`@("`@("`H
M=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)'9A;%LG<&AP=F5R)UTI
M(#T]("TQ*2D@>PH@("`@("`@("`@("`@("`@("`@("1M;V1?=&5S="`]('1R
M=64["B`@("`@("`@("`@("`@("`@("`@)'-T871U<U]O=70@/2`G3B]!)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=F%L6R=E<G)O<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("1E<G)O<E]M
M<V<@/2`D=F%L6R=E<G)O<B==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1E<V-R:7`@/2`D=F%L
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-?;G5L;"@D<W1A
M='5S7V]U="DI('L*("`@("`@("`@("`@("`@("1M;V1?=&5S="`](&5X=&5N
M<VEO;E]L;V%D960H)&ME>2D["B`@("`@("`@("`@("`@("`D<W1A='5S7V]U
M="`]("1T:&ES+3Y?<W1A='5S*"1M;V1?=&5S="P@)&9A=&%L*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&5N=')Y6UT@/2`D9&5S8W)I<#L*("`@
M("`@("`@("`@)&5N=')Y6UT@/2`D<W1A='5S7V]U=#L*"B`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D97)R;W)?;7-G*2`F)B`A)&UO9%]T97-T*2!["B`@
M("`@("`@("`@("`@("`D96YT<GE;72`]("1E<G)O<E]M<V<["B`@("`@("`@
M("`@("`@("!I9B`H(21F871A;"D@>PH@("`@("`@("`@("`@("`@("`@("1E
M;G1R>5M=(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N
M=')Y*3L*"B`@("`@("`@("`@(&EF("@D9F%T86P@)B8@(21M;V1?=&5S="D@
M>PH@("`@("`@("`@("`@("`@96-H;R`D;W5T<'5T.PH@("`@("`@("`@("`@
M("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&AE
M(&QI<W0@;V8@4$A0('-E='1I;F=S+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D;6]D;&ES="`@5&AE('-E='1I;F=S(&QI<W0N"B`@("`@*B`\8V]D
M93X*("`@("`J($M%63H@("!S971T:6YG(&YA;64*("`@("`J(%9!3%5%.B!!
M;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("`@
M("`@("`G97)R;W(G("`@("TM("!%<G)O<B!-97-S86=E"B`@("`@*B`@("`@
M("`@)W-E='1I;F<G("`M+2`@0F]O;&5A;B`M('-H;W5L9"!T:&4@<V5T=&EN
M9R!B92!O;B!O<B!O9F8*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE($A434P@;W5T<'5T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P:'!3971T:6YG0VAE8VLH)'-E='1I;F=S7VQI<W0I"B`@("![
M"B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("!F;W)E86-H("@D<V5T
M=&EN9W-?;&ES="!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&5N
M=')Y(#T@87)R87DH*3L*("`@("`@("`@("`@)')E<W5L="`]("AI;FE?9V5T
M*"1K97DI(#T]("1V86Q;)W-E='1I;F<G72D["@H@("`@("`@("`@("`D96YT
M<GE;72`]("1K97D@+B`G("<@+B`H*"1V86Q;)W-E='1I;F<G72`]/3T@=')U
M92D@/R`G96YA8FQE9"<@.B`G9&ES86)L960G*3L*("`@("`@("`@("`@)&5N
M=')Y6UT@/2`D=&AI<RT^7W-T871U<R@D<F5S=6QT*3L*"B`@("`@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D
M=F%L6R=E<G)O<B==.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;W5T
M<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:R!T:&4@;&ES="!O9B!014%2(&UO9'5L97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P96%R7VQI<W0@(%1H92!014%2(&UO9'5L92!L
M:7-T+@H@("`@("H@/'!R93X*("`@("`J($M%63H@("!014%2(&-L87-S(&YA
M;64*("`@("`J(%9!3%5%.B!!;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@
M96YT<FEE<SH*("`@("`J("`@("`@("`G9&5P96YD<R<@("`M+2`@5&AI<R!M
M;V1U;&4@9&5P96YD<R!O;B!A;F]T:&5R(&UO9'5L90H@("`@("H@("`@("`@
M("=E<G)O<B<@("`@("TM("!%<G)O<B!-97-S86=E"B`@("`@*B`@("`@("`@
M)V9U;F-T:6]N)R`@+2T@(%)E9F5R96YC92!T;R!F=6YC=&EO;B!T;R!R=6X@
M:68@;6]D=6QE(&ES(&9O=6YD"B`@("`@*B`@("`@("`@)W!A=&@G("`@("`@
M+2T@(%1H92!P871H('1O('1H92!014%2(&UO9'5L90H@("`@("H@("`@("`@
M("=R97%U:7)E9"<@("TM("!)<R!T:&ES(%!%05(@;6]D=6QE(')E<75I<F5D
M/R`H8F]O;&5A;BD*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%!%05)-;V1U;&5#:&5C:R@D<&5A<E]L:7-T*0H@("`@>PH@("`@("`@
M("1O=71P=70@/2`G)SL*"B`@("`@("`@+RH@5'5R;B!T<F%C:VEN9R!O9B!E
M<G)O<G,@;VXN("HO"B`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@
M,2D["@H@("`@("`@("\J(%!R:6YT('1H92!I;F-L=61E7W!A=&@N("HO"B`@
M("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H87)R87DH(CQS
M=')O;F<^4$5!4B!396%R8V@@4&%T:"`H4$A0)W,@:6YC;'5D95]P871H*3PO
M<W1R;VYG/B(L("<F;F)S<#L\='0^)R`N(&EN:5]G970H)VEN8VQU9&5?<&%T
M:"<I("X@)SPO='0^)RDI.PH*("`@("`@("`O*B!#:&5C:R!F;W(@4$5!4B!I
M;B!G96YE<F%L+B`J+PH@("`@("`@('L*("`@("`@("`@("`@)&5N=')Y(#T@
M87)R87DH*3L*("`@("`@("`@("`@)&5N=')Y6UT@/2`G4$5!4B<["B`@("`@
M("`@("`@($!I;F-L=61E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@
M)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<R@A:7-S970H)'!H<%]E<G)O<FUS
M9RDI.PH@("`@("`@("`@("!I9B`H:7-S970H)'!H<%]E<G)O<FUS9RDI('L*
M("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)T-H96-K('EO=7(@4$A0(&EN
M8VQU9&5?<&%T:"!S971T:6YG('1O(&UA:V4@<W5R92!I="!H87,@=&AE(%!%
M05(@;&EB<F%R>2!D:7)E8W1O<GDN)SL*("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@)'1H:7,M/E]O=71P=71,:6YE*"1E;G1R>2D["B`@("`@("`@("`@
M("`@("!I;FE?<F5S=&]R92@G=')A8VM?97)R;W)S)RD["B`@("`@("`@("`@
M("`@("!R971U<FX@)&]U='!U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D;W5T<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R(&$@<F5C96YT(%!%05(@=F5R
M<VEO;BX@*B\*("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH@("`@("`@("1N
M97=P96%R(#T@)'1H:7,M/FES4F5C96YT4$5!4B@I.PH@("`@("`@("1E;G1R
M>5M=(#T@)U)E8V5N="!014%2)SL*("`@("`@("`D96YT<GE;72`]("1T:&ES
M+3Y?<W1A='5S*"1N97=P96%R*3L*("`@("`@("!I9B`H(21N97=P96%R*2![
M"B`@("`@("`@("`@("1E;G1R>5M=(#T@)U1H:7,@=F5R<VEO;B!O9B!014%2
M(&ES(&YO="!R96-E;G0@96YO=6=H+B!3964@=&AE(#QA(&AR968](FAT='`Z
M+R]W=W<N:&]R9&4N;W)G+W!E87(O(CY(;W)D92!014%2('!A9V4\+V$^(&9O
M<B!D971A:6QS+B<["B`@("`@("`@?0H@("`@("`@("1O=71P=70@+CT@)'1H
M:7,M/E]O=71P=71,:6YE*"1E;G1R>2D["@H@("`@("`@("\J($=O('1H<F]U
M9V@@;6]D=6QE(&QI<W0N("HO"B`@("`@("`@)'-U8V-E961E9"`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H)'!E87)?;&ES="!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*"B`@("`@("`@
M("`@("\J($EF('1H:7,@;6]D=6QE(&1E<&5N9',@;VX@86YO=&AE<B!M;V1U
M;&4@=&AA="!W90H@("`@("`@("`@("`@*B!H879E;B=T('-U8V-E<V9U;&QY
M(&9O=6YD+"!F86EL('1H92!T97-T+B`J+PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1V86Q;)V1E<&5N9',G72D@)B8@96UP='DH)'-U8V-E961E9%LD=F%L
M6R=D97!E;F1S)UU=*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`](&9A
M;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E
M<W5L="`]($!I;F-L=61E7V]N8V4@)'9A;%LG<&%T:"==.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1E<G)O<E]M<V<@/2`D=F%L6R=E<G)O<B==.PH@
M("`@("`@("`@("!I9B`H)')E<W5L="`F)B!I<W-E="@D=F%L6R=F=6YC=&EO
M;B==*2D@>PH@("`@("`@("`@("`@("`@)&9U;F-?;W5T<'5T(#T@8V%L;%]U
M<V5R7V9U;F,H)'9A;%LG9G5N8W1I;VXG72D["B`@("`@("`@("`@("`@("!I
M9B`H)&9U;F-?;W5T<'5T*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L
M="`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("1E<G)O<E]M<V<@/2`D
M9G5N8U]O=71P=70["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&5N=')Y6UT@/2`D:V5Y.PH@("`@("`@("`@("`D96YT
M<GE;72`]("1T:&ES+3Y?<W1A='5S*"1R97-U;'0L("%E;7!T>2@D=F%L6R=R
M97%U:7)E9"==*2D["@H@("`@("`@("`@("!I9B`H)')E<W5L="D@>PH@("`@
M("`@("`@("`@("`@)'-U8V-E961E9%LD:V5Y72`]('1R=64["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86Q;
M)W)E<75I<F5D)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R7VUS
M9R`N/2`G(%1(25,@25,@02!215%525)%1"!-3T153$4A)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)&5R<F]R7VUS
M9SL*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=F%L6R=R97%U:7)E9"==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@,3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]U='!U
M="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E<W1O<F4@<')E=FEO=7,@=F%L=64@;V8@)W1R86-K7V5R
M<F]R<R<N("HO"B`@("`@("`@:6YI7W)E<W1O<F4H)W1R86-K7V5R<F]R<R<I
M.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H96-K('1H92!L:7-T(&]F(')E<75I<F5D(&9I;&5S"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1F:6QE7VQI<W0@(%1H92!F:6QE(&QI<W0N
M"B`@("`@*B`\<')E/@H@("`@("H@2T59.B`@(&9I;&4@<&%T:`H@("`@("H@
M5D%,544Z(%1H92!E<G)O<B!M97-S86=E('1O('5S92`H;G5L;"!T;R!U<V4@
M9&5F875L="!M97-S86=E*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&]U='!U="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5Q=6ER961&:6QE0VAE8VLH)&9I;&5?;&ES="D*("`@('L*
M("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@(&9O<F5A8V@@*"1F:6QE
M7VQI<W0@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1E;G1R>2`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("1R97-U;'0@/2!F:6QE7V5X:7-T<R@G
M+B\G("X@)&ME>2D["@H@("`@("`@("`@("`D96YT<GE;72`]("1K97D["B`@
M("`@("`@("`@("1E;G1R>5M=(#T@)'1H:7,M/E]S=&%T=7,H)')E<W5L="D[
M"@H@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@
M(&EF("AE;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R
M>5M=(#T@)U1H92!F:6QE(#QC;V1E/B<@+B`D:V5Y("X@)SPO8V]D93X@87!P
M96%R<R!T;R!B92!M:7-S:6YG+B!9;W4@<')O8F%B;'D@:G5S="!F;W)G;W0@
M=&\@8V]P>2`\8V]D93XG("X@)&ME>2`N("<N9&ES=#PO8V]D93X@;W9E<BX@
M5VAI;&4@>6]U(&1O('1H870L('1A:V4@82!L;V]K(&%T('1H92!S971T:6YG
M<R!A;F0@;6%K92!S=7)E('1H97D@87)E(&%P<')O<')I871E(&9O<B!Y;W5R
M('-I=&4N)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&5N=')Y6UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?
M;W5T<'5T3&EN92@D96YT<GDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-P;&%Y<R!A;B!E
M<G)O<B!S8W)E96X@=VET:"!A(&QI<W0@;V8@86QL(&-O;F9I9W5R871I;VX@
M9FEL97,@=&AA=`H@("`@("H@87)E(&UI<W-I;F<L('1O9V5T:&5R('=I=&@@
M82!D97-C<FEP=&EO;B!W:&%T('1H97D@9&\@86YD(&AO=R!T:&5Y(&%R90H@
M("`@("H@8W)E871E9"X@268@82!F:6QE(&-A;B!B92!A=71O;6%T:6-A;&QY
M(&-R96%T960@9G)O;2!T:&4@9&5F875L=',L('1H96X*("`@("`J('=E(&1O
M('1H870@:6YS=&5A9"!A;F0@9&]N)W0@9&ES<&QA>2!A;B!E<G)O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@("`@(%1H92!A<'!L
M:6-A=&EO;B!N86UE"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'!"87-E("`@
M(%1H92!P871H('1O('1H92!A<'!L:6-A=&EO;@H@("`@("H@0'!A<F%M(&%R
M<F%Y("`D9FEL97,@("`@("!!;B!A<G)A>2!W:71H('1H92`B<W1A;F1A<F0B
M(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9FEL97,@=&AA="!S:&]U;&0@8F4@8VAE8VME9"X@0W5R<F5N=&QY"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-U<'!O<G1E9#H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!C;VYF+G!H<`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`M('!R969S+G!H<`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`M(&UI;65?9')I=F5R<RYP
M:'`*("`@("`J($!P87)A;2!A<G)A>2`D861D:71I;VYA;"`@06X@87-S;V-I
M871I=F4@87)R87D@8V]N=&%I;FEN9R!M;W)E(&9I;&5S("AA<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!K97ES*2!A;F0@97)R;W(@;65S
M<V%G92`H87,@=F%L=65S*2!I9B!T:&5Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&1O;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VYF:6=&:6QE<TUI<W-I;F<H)&%P<"P@)&%P<$)A<V4L("1F:6QE<RP@
M)&%D9&ET:6]N86P@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J(%1R>2!T
M;R!L;V%D(&$@8F%S:6,@9G)A;65W;W)K(&EF('=E)W)E('1E<W1I;F<@86X@
M87!P(&]T:&5R('1H86X*("`@("`@("`@*B!T:&4@2&]R9&4@8F%S92!F:6QE
M<RX@*B\*("`@("`@("!I9B`H)&%P<"`A/2`G2&]R9&4G*2!["B`@("`@("`@
M("`@("1'3$]"04Q36R=R96=I<W1R>2==(#T@)E)E9VES=')Y.CIS:6YG;&5T
M;VXH*3L*("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/G!U<VA!
M<'`H)VAO<F1E)RP@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D9FEL97,I*2!["B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y
M*"1F:6QE<RD["B`@("`@("`@?0H@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE
M<F=E*"1F:6QE<RP@87)R87E?:V5Y<R@D861D:71I;VYA;"DI.PH*("`@("`@
M("`O*B!4<GD@=&\@875T;RUC<F5A=&4@;6ES<VEN9R`N9&ES="!F:6QE<RX@
M*B\*("`@("`@("`D:6YD:6-E<R`](&%R<F%Y7VME>7,H)&9I;&5S*3L*("`@
M("`@("!F;W)E86-H("@D:6YD:6-E<R!A<R`D:6YD97@I('L*("`@("`@("`@
M("`@:68@*&ES7W)E861A8FQE*"1A<'!"87-E("X@)R]C;VYF:6<O)R`N("1F
M:6QE<ULD:6YD97A=*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&5S
M6R1I;F1E>%TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@:68@*$!F:6QE7V5X:7-T<R@D87!P0F%S92`N("<O8V]N9FEG+R<@+B`D
M9FEL97-;)&EN9&5X72`N("<N9&ES="<I("8F"B`@("`@("`@("`@("`@("`@
M("`@0&-O<'DH)&%P<$)A<V4@+B`G+V-O;F9I9R\G("X@)&9I;&5S6R1I;F1E
M>%T@+B`G+F1I<W0G+"`D87!P0F%S92`N("<O8V]N9FEG+R<@+B`D9FEL97-;
M)&EN9&5X72DI('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D9FEL97-;
M)&EN9&5X72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\J(%)E='5R;B!I9B!W92!H879E(&YO(&UI<W-I
M;F<@9FEL97,@;&5F="X@*B\*("`@("`@("!I9B`H(6-O=6YT*"1F:6QE<RDI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&1E
M<V-R:7!T:6]N<R`](&%R<F%Y7VUE<F=E*&%R<F%Y*`H@("`@("`@("`@("`G
M8V]N9BYP:'`G(#T^('-P<FEN=&8H)U1H:7,@:7,@=&AE(&UA:6X@)7,@8V]N
M9FEG=7)A=&EO;B!F:6QE+B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=)="!C;VYT86EN<R!P871H<R!A;F0@;W!T:6]N<R!F;W(@
M=&AE("5S("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W-C<FEP=',N(%EO=2!N965D('1O(&QO9VEN(&%S(&%N("<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%D;6EN:7-T<F%T;W(@86YD
M(&-R96%T92!T:&4@9FEL92!W:71H("<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1H92!W96(@9G)O;G1E;F0@=6YD97(@(D%D;6EN
M:7-T<F%T:6]N(#T^("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)U-E='5P(BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&%P<"P@)&%P<"P@)&%P<$)A<V4@+B`G+V-O;F9I9R<I+`H@("`@
M("`@("`@("`G<')E9G,N<&AP)R`]/B!S<')I;G1F*"=4:&ES(&9I;&4@8V]N
M=')O;',@=&AE(&1E9F%U;'0@<')E9F5R96YC97,@)R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V9O<B`E<RP@86YD(&%L<V\@8V]N
M=')O;',@=VAI8V@@<')E9F5R96YC97,@)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5S97)S(&-A;B!A;'1E<BXG+"`D87!P*2P*
M("`@("`@("`@("`@)VUI;65?9')I=F5R<RYP:'`G(#T^('-P<FEN=&8H)U1H
M:7,@9FEL92!C;VYT<F]L<R!L;V-A;"!-24U%("<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9')I=F5R<R!F;W(@)7,L
M('-P96-I9FEC86QL>2!W:&%T("<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:VEN9',@;V8@9FEL97,@87)E('9I97=A
M8FQE(&%N9"]O<B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1O=VYL;V%D86)L92XG+"`D87!P*2P*("`@("`@("`@
M("`@)V)A8VME;F1S+G!H<"<@/3X@<W!R:6YT9B@G5&AI<R!F:6QE(&-O;G1R
M;VQS('=H870@8F%C:V5N9',@87)E("<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A=F%I;&%B;&4@9G)O;2`E<RXG+"`D87!P
M*2P*("`@("`@("`@("`@)W-O=7)C97,N<&AP)R`]/B!S<')I;G1F*"=4:&ES
M(&9I;&4@9&5F:6YE<R!T:&4@;&ES="!O9B!A=F%I;&%B;&4@)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V]U<F-E<R!F;W(@
M)7,N)RP@)&%P<"D*("`@("`@("`I+"`D861D:71I;VYA;"D["@H@("`@("`@
M("\J($EF('=E(&MN;W<@=&AE('5S97(@:7,@86X@861M:6XL(&=I=F4@=&AE
M;2!A(&1I<F5C="!L:6YK('1O"B`@("`@("`@("H@9V5N97)A=&4@8V]N9BYP
M:'`N($EN('1H92!F=71U<F4L('-H;W5L9"!W92!T<GD@9V5N97)A=&EN9PH@
M("`@("`@("`J(&$@8F%S:6,@8V]N9BYP:'`@875T;VUA9VEC86QL>2!H97)E
M/R`J+PH@("`@("`@(&EF("A!=71H.CII<T%D;6EN*"DI('L*("`@("`@("`@
M("`@)'-E='5P7W5R;"`]($AO<F1E.CIL:6YK*$AO<F1E.CIU<FPH)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R]A9&UI;B]S971U<"]C;VYF:6<N<&AP/V%P<#TG("X@4W1R:6YG.CIL;W=E
M<B@D87!P*2DI("X*("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T:6]N(%=E
M8B!);G1E<F9A8V4G("X@)SPO83XG.PH@("`@("`@("`@("`D9&5S8W)I<'1I
M;VYS6R=C;VYF+G!H<"==(#T*("`@("`@("`@("`@("`@('-P<FEN=&8H)U1H
M:7,@:7,@=&AE(&UA:6X@)7,@8V]N9FEG=7)A=&EO;B!F:6QE+B`G("X*("`@
M("`@("`@("`@("`@("`@("`@("`@)T=E;F5R871E(&ET(&)Y(&=O:6YG('1O
M('1H92`E<RXG+`H@("`@("`@("`@("`@("`@("`@("`@("`D87!P+"`D<V5T
M=7!?=7)L*3L*("`@("`@("!]"@H@("`@("`@("1T:71L92`]('-P<FEN=&8H
M)R5S(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D)RP@)&%P<"D["B`@("`@
M("`@)&AE861E<B`]('-P<FEN=&8H)U-O;64@;V8@)7-<)W,@8V]N9FEG=7)A
M=&EO;B!F:6QE<R!A<F4@;6ES<VEN9R!O<B!U;G)E861A8FQE)RP@)&%P<"D[
M"B`@("`@("`@)&9O;W1E<B`]('-P<FEN=&8H)T-R96%T92!T:&5S92!F:6QE
M<R!F<F]M('1H96ER("YD:7-T('9E<G-I;VYS(&EN("5S(&%N9"!C:&%N9V4@
M=&AE;2!A8V-O<F1I;F<@=&\@>6]U<B!N965D<RXG+"`D87!P0F%S92`N("<O
M8V]N9FEG)RD["@H@("`@("`@(&5C:&\@/#P\($A%041%4@H\:'1M;#X*/&AE
M860^/'1I=&QE/B1T:71L93PO=&ET;&4^/"]H96%D/@H\8F]D>2!S='EL93TB
M8F%C:V=R;W5N9"UC;VQO<CH@=VAI=&4[(&-O;&]R.B!B;&%C:SLB/@H\:#$^
M)&AE861E<CPO:#$^"DA%041%4CL*"B`@("`@("`@9F]R96%C:"`H)&9I;&5S
M(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D9&5S8W)I<'1I
M;VYS6R1F:6QE72DI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1D97-C<FEP=&EO;B`]("1D97-C<FEP
M=&EO;G-;)&9I;&5=.PH@("`@("`@("`@("!E8VAO(#P\/"!&24Q%"B`@("`\
M:#,^)&9I;&4\+V@S/CQP/B1D97-C<FEP=&EO;CPO<#X*1DE,13L*("`@("`@
M("!]"@H@("`@("`@(&5C:&\@/#P\($9/3U1%4@H*/&@R/B1F;V]T97(\+V@R
M/@H\+V)O9'D^"CPO:'1M;#X*1D]/5$52.PH@("`@("`@(&5X:70["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@;&ES="!O9B!R97%U:7)E9"!(
M;W)D92!A<'!L:6-A=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A<'!?;&ES="`@5&AE(&%P<&QI8V%T:6]N(&QI<W0N"B`@("`@*B`\<')E
M/@H@("`@("H@2T59.B`@(&%P<&QI8V%T:6]N(&YA;64*("`@("`J(%9!3%5%
M.B!!;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J
M("`@("`@("`G97)R;W(G("`@("TM("!%<G)O<B!-97-S86=E"B`@("`@*B`@
M("`@("`@)W9E<G-I;VXG("`M+2`@5&AE(&UI;FEM=6T@=F5R<VEO;B!R97%U
M:7)E9`H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!(5$U,(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5Q
M=6ER961!<'!#:&5C:R@D87!P7VQI<W0I"B`@("!["B`@("`@("`@)&]U='!U
M="`]("<G.PH*("`@("`@("`D87!P<R`]("1T:&ES+3YA<'!L:6-A=&EO;DQI
M<W0H*3L*"B`@("`@("`@9F]R96%C:"`H)&%P<%]L:7-T(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D96YT<GE;72`]("1K97D["@H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1A<'!S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D
M=&AI<RT^7W-T871U<RAF86QS92D["B`@("`@("`@("`@("`@("`D96YT<GE;
M72`]("1V86Q;)V5R<F]R)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`O*B!3=')I<"`G+6-V<R<@86YD($@S("AV97(I(&9R;VT@
M=F5R<VEO;B!S=')I;F<N("HO"B`@("`@("`@("`@("`@("`D87!P=F5R(#T@
M<W1R7W)E<&QA8V4H)RUC=G,G+"`G)RP@)&%P<'-;)&ME>5TM/G9E<G-I;VXI
M.PH@("`@("`@("`@("`@("`@)&%P<'9E<B`]('!R96=?<F5P;&%C92@G+T@S
M(%PH*"XJ*5PI+R<L("<D,2<L("1A<'!V97(I.PH@("`@("`@("`@("`@("`@
M:68@*'9E<G-I;VY?8V]M<&%R92@D=F%L6R=V97)S:6]N)UTL("1A<'!V97(I
M(#T]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D=&AI
M<RT^7W-T871U<RAF86QS92D@+B`G("A(879E('9E<G-I;VXZ("<@+B`D87!P
M<ULD:V5Y72T^=F5R<VEO;B`N("<[($YE960@=F5R<VEO;CH@)R`N("1V86Q;
M)W9E<G-I;VXG72`N("<I)SL*("`@("`@("`@("`@("`@("`@("`D96YT<GE;
M72`]("1V86Q;)V5R<F]R)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)'1H:7,M/E]S=&%T=7,H
M=')U92D@+B`G("A697)S:6]N.B`G("X@)&%P<'-;)&ME>5TM/G9E<G-I;VX@
M+B`G*2<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@27,@=&AI<R!A("=R96-E;G0G('9E<G-I;VX@;V8@4$5!
M4C\*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@5')U92!I9B!A(')E
M8V5N="!V97)S:6]N(&]F(%!%05(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M4F5C96YT4$5!4B@I"B`@("!["B`@("`@("`@0&EN8VQU9&5?;VYC92`G4$5!
M4BYP:'`G.PH@("`@("`@("1P96%R7VUE=&AO9',@/2!G971?8VQA<W-?;65T
M:&]D<R@G4$5!4B<I.PH@("`@("`@(')E='5R;B`H:7-?87)R87DH)'!E87)?
M;65T:&]D<RD@)B8*("`@("`@("`@("`@("`@("AI;E]A<G)A>2@G<F5G:7-T
M97)S:'5T9&]W;F9U;F,G+"`D<&5A<E]M971H;V1S*2!\?`H@("`@("`@("`@
M("`@("`@(&EN7V%R<F%Y*"=R96=I<W1E<E-H=71D;W=N1G5N8R<L("1P96%R
M7VUE=&AO9',I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/8G1A:6X@:6YF
M;W)M871I;VX@;VX@=&AE(%!(4"!V97)S:6]N+@H@("`@("H*("`@("`J($!R
M971U<FX@;V)J96-T('-T9$-L87-S("!43T1/"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%!H<%9E<G-I;VY);F9O<FUA=&EO;B@I"B`@("!["B`@("`@("`@
M)&]U='!U="`]("9N97<@<W1D0VQA<W,["B`@("`@("`@)'5R;"`]('5R;&5N
M8V]D92@D7U-%4E9%4ELG4$A07U-%3$8G72D["B`@("`@("`@)'9E<G-?8VAE
M8VL@/2!T<G5E.PH*("`@("`@("`D=&5S='-C<FEP="`]("1T:&ES+3YA<'!L
M:6-A=&EO;G-;)VAO<F1E)UU;)W=E8G)O;W0G72`N("<O=&5S="YP:'`G.PH@
M("`@("`@("1O=71P=70M/G!H<&EN9F\@/2`D=&5S='-C<FEP="`N("<_;6]D
M93UP:'!I;F9O)G5R;#TG("X@)'5R;#L*("`@("`@("`D;W5T<'5T+3YE>'1E
M;G-I;VYS(#T@)'1E<W1S8W)I<'0@+B`G/VUO9&4]97AT96YS:6]N<R9U<FP]
M)R`N("1U<FP["B`@("`@("`@)&]U='!U="T^=F5R<VEO;B`]('!H<'9E<G-I
M;VXH*3L*("`@("`@("`D;W5T<'5T+3YM86IO<B`]("1T:&ES+3Y?<&AP=F5R
M6R=M86IO<B==.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!H<'9E<ELG
M;6EN;W(G72DI('L*("`@("`@("`@("`@)&]U='!U="T^;6EN;W(@/2`D=&AI
M<RT^7W!H<'9E<ELG;6EN;W(G73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&AP=F5R6R=S=6)M:6YO<B==*2D@>PH@("`@("`@("`@
M("`D;W5T<'5T+3YS=6)M:6YO<B`]("1T:&ES+3Y?<&AP=F5R6R=S=6)M:6YO
M<B==.PH@("`@("`@('T*("`@("`@("`D;W5T<'5T+3YC;&%S<R`]("1T:&ES
M+3Y?<&AP=F5R6R=C;&%S<R==.PH*("`@("`@("`D;W5T<'5T+3YS=&%T=7-?
M8V]L;W(@/2`G<F5D)SL*("`@("`@("!I9B`H)&]U='!U="T^;6%J;W(@/"`G
M-"XS)RD@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%T=7,@/2`G5&AI<R!V
M97)S:6]N(&]F(%!(4"!I<R!N;W0@<W5P<&]R=&5D+B!9;W4@;F5E9"!T;R!U
M<&=R861E('1O(&$@;6]R92!R96-E;G0@=F5R<VEO;BXG.PH@("`@("`@("`@
M("`D=F5R<U]C:&5C:R`](&9A;'-E.PH@("`@("`@('T@96QS96EF("@H)&]U
M='!U="T^;6%J;W(@/3T@)S0N,R<I('Q\"B`@("`@("`@("`@("`@("`@("@D
M;W5T<'5T+3YM86IO<B`]/2`G-"XT)RD@?'P*("`@("`@("`@("`@("`@("`@
M*"1O=71P=70M/FUA:F]R(#T]("<U+C`G*2!\?`H@("`@("`@("`@("`@("`@
M("`H)&]U='!U="T^;6%J;W(@/3T@)S4N,2<I*2!["B`@("`@("`@("`@("1O
M=71P=70M/G-T871U<R`]("=9;W4@87)E(')U;FYI;F<@82!S=7!P;W)T960@
M=F5R<VEO;B!O9B!02%`N)SL*("`@("`@("`@("`@)&]U='!U="T^<W1A='5S
M7V-O;&]R(#T@)V=R965N)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;W5T<'5T+3YS=&%T=7,@/2`G5V]W+"!A(&UY<W1I8V%L('9E<G-I;VX@
M;V8@4$A0(&9R;VT@=&AE(&9U='5R92X@3&5T(#QA(&AR968](FUA:6QT;SID
M979`;&ES=',N:&]R9&4N;W)G(CYD979`;&ES=',N:&]R9&4N;W)G/"]A/B!K
M;F]W('=H870@=F5R<VEO;B!Y;W4@:&%V92!S;R!W92!C86X@9FEX('1H:7,@
M<V-R:7!T+B<["B`@("`@("`@("`@("1O=71P=70M/G-T871U<U]C;VQO<B`]
M("=O<F%N9V4G.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=F5R<U]C:&5C
M:RD@>PH@("`@("`@("`@("`D;W5T<'5T+3YV97)S:6]N7V-H96-K(#T@)TAO
M<F1E(')E<75I<F5S(%!(4"`T+C,N,"!O<B!G<F5A=&5R+B<["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!T:&4@87!P;&EC871I;VX@;&ES="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!,:7-T(&]F('-T9$-L87-S(&]B:F5C=',N"B`@("`@
M*B`@("`@("`@("`@("`@("!+15DZ(&%P<&QI8V%T:6]N(&YA;64*("`@("`J
M("`@("`@("`@("`@("`@($5,14U%3E0@)W9E<G-I;VXG.B!697)S:6]N(&]F
M(&%P<&QI8V%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("!%3$5-14Y4("=T
M97-T)SH@5&AE(&QO8V%T:6]N(&]F('1H92!T97-T('-C<FEP="`H:68@86YY
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L:6-A=&EO;DQI<W0H*0H@("`@
M>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]A<'!O=71P=70I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%P<&]U='!U=#L*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YA<'!L:6-A=&EO;G,@87,@)&UO
M9"`]/B`D9&5T*2!["B`@("`@("`@("`@(&EF("@H)&1E=%LG<W1A='5S)UT@
M(3T@)VAE861I;F<G*2`F)@H@("`@("`@("`@("`@("`@*"1D971;)W-T871U
M<R==("$]("=B;&]C:R<I("8F"B`@("`@("`@("`@("`@("!I<U]R96%D86)L
M92@D9&5T6R=F:6QE<F]O="==("X@)R]L:6(O=F5R<VEO;BYP:'`G*2D@>PH@
M("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1D971;)V9I;&5R;V]T)UT@
M+B`G+VQI8B]V97)S:6]N+G!H<"<["B`@("`@("`@("`@("`@("`D=F5R<VEO
M;E]C;VYS=&%N="`](%-T<FEN9SHZ=7!P97(H)&UO9"D@+B`G7U9%4E-)3TXG
M.PH@("`@("`@("`@("`@("`@:68@*&1E9FEN960H)'9E<G-I;VY?8V]N<W1A
M;G0I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A<'!O=71P=71;
M)&UO9%T@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?87!P;W5T<'5T6R1M;V1=+3YV97)S:6]N(#T@8V]N<W1A;G0H)'9E
M<G-I;VY?8V]N<W1A;G0I.PH@("`@("`@("`@("`@("`@("`@(&EF("@H)&UO
M9"`A/2`G:&]R9&4G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("!`:7-?
M<F5A9&%B;&4H)&1E=%LG9FEL97)O;W0G72`N("<O=&5S="YP:'`G*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%P<&]U='!U=%LD;6]D
M72T^=&5S="`]("1D971;)W=E8G)O;W0G72`N("<O=&5S="YP:'`G.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?87!P;W5T
M<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T('1H92!R97-U;'1S
M(&]F(&$@<W1A='5S(&-H96-K+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("`@("`@
M5&AE(')E<W5L="!O9B!T:&4@<W1A='5S(&-H96-K+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)')E<75I<F5D("!7:&5T:&5R('1H92!C:&5C:V5D(&ET96T@
M:7,@<F5Q=6ER960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!(5$U,(&]F('1H92!R97-U;'0@;V8@=&AE('-T871U<R!C:&5C:RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-T871U<R@D8F]O;"P@)')E<75I<F5D(#T@
M=')U92D*("`@('L*("`@("`@("!I9B`H)&)O;VPI('L*("`@("`@("`@("`@
M<F5T=7)N("<\9F]N="!C;VQO<CTB9W)E96XB/CQS=')O;F<^665S/"]S=')O
M;F<^/"]F;VYT/B<["B`@("`@("`@?2!E;'-E:68@*"1R97%U:7)E9"D@>PH@
M("`@("`@("`@("!R971U<FX@)SQF;VYT(&-O;&]R/2)R960B/CQS=')O;F<^
M3F\\+W-T<F]N9SX\+V9O;G0^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)SQF;VYT(&-O;&]R/2)O<F%N9V4B/CQS=')O;F<^3F\\
M+W-T<F]N9SX\+V9O;G0^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);G1E<FYA;"!O=71P=70@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E
M;G1R>2`@,R!E;&5M96YT(&%R<F%Y+@H@("`@("H@/'!R93X*("`@("`J(#%S
M="!V86QU93H@2&5A9&5R"B`@("`@*B`R;F0@=F%L=64Z(%1E<W0@4F5S=6QT
M"B`@("`@*B`S<F0@=F%L=64Z($5R<F]R(&UE<W-A9V4@*&EF('!R97-E;G0I
M"B`@("`@*B`T=&@@=F%L=64Z($5R<F]R(&QE=F5L("AI9B!P<F5S96YT*3H@
M,"`](&5R<F]R+"`Q(#T@=V%R;FEN9PH@("`@("H@/"]P<F4^"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@($A434P@;W5T<'5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;W5T<'5T3&EN92@D96YT<GDI"B`@("!["B`@("`@("`@
M)&]U='!U="`]("<\;&D^)R`N(&%R<F%Y7W-H:69T*"1E;G1R>2D@+B`G.B`G
M("X@87)R87E?<VAI9G0H)&5N=')Y*3L*("`@("`@("!I9B`H(65M<'1Y*"1E
M;G1R>2DI('L*("`@("`@("`@("`@)&US9R`](&%R<F%Y7W-H:69T*"1E;G1R
M>2D["B`@("`@("`@("`@("1O=71P=70@+CT@)SQB<B`O/CQF;VYT(&-O;&]R
M/2(G("X@*&5M<'1Y*"1E;G1R>2D@?'P@(6%R<F%Y7W-H:69T*"1E;G1R>2D@
M/R`G<F5D)R`Z("=O<F%N9V4G*2`N("<B/CQS=')O;F<^)R`N("1M<V<@+B`G
M/"]S=')O;F<^/"]F;VYT/B<@+B`B7&XB.PH@("`@("`@('T*("`@("`@("`D
M;W5T<'5T("X]("<\+VQI/B<@+B`B7&XB.PH*("`@("`@("!R971U<FX@)&]U
M='!U=#L*("`@('T*"GT*````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92\`````
M````````````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,#$`,#$U-C0V`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V%R7U-9+P``````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-@`P,38W,#4`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O87)?4UDO3$-?34534T%'
M15,O````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S<V`#`R,#0W,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]A<E]362],0U]-15-304=%4R]H;W)D92YM;P``````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,38T,30`,3`T,3<S-C(W-S8`,#(R,3,S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````>P```!P`
M``#T`P``IP```,P'````````:`H```@```!I"@``!0```'(*```(````>`H`
M``<```"!"@``#````(D*```?````E@H``#D```"V"@``*0```/`*```1````
M&@L``!8````L"P``%@```$,+```(````6@L```@```!C"P``%0```&P+```*
M````@@L```P```"-"P``!@```)H+```'````H0L``"D```"I"P```@```-,+
M```%````U@L``!````#<"P``%````.T+```O`````@P```\````R#```)@``
M`$(,```%````:0P```T```!O#```!0```'T,```0````@PP``!````"4#```
M#P```*4,```+````M0P```\```#!#```#````-$,```/````W@P``!X```#N
M#```(0````T-```@````+PT```,```!0#0``!````%0-```$````60T```P`
M``!>#0``"@```&L-```%````=@T```H```!\#0``#P```(<-```2````EPT`
M`!````"J#0``*````+L-```(````Y`T``!````#M#0``!@```/X-```'````
M!0X```(````-#@``!````!`.```/````%0X```H````E#@``!P```#`.```'
M````.`X```0```!`#@``!0```$4.```"````2PX``#,```!.#@``,P```((.
M```X````M@X``#$```#O#@``+````"$/```%````3@\```(```!4#P``!P``
M`%</```1````7P\```@```!Q#P``'@```'H/```%````F0\``"@```"?#P``
M*0```,@/```3````\@\```L````&$```$0```!(0```$````)!````P````I
M$```&@```#80```7````41```!<```!I$```&P```($0```?````G1```!,`
M``"]$```$````-$0```7````XA````<```#Z$```!0````(1```)````"!$`
M`"$````2$0``'````#01```%````41$```,```!7$0``+P```%L1```@````
MBQ$``"4```"L$0``(````-(1```F````\Q$```P````:$@``#````"<2```(
M````-!(```<````]$@``!@```$42```-````3!(```L```!:$@``#````&82
M```*````<Q(```(```!^$@``!@```($2```#````B!(``$4```",$@``,```
M`-(2```0`````Q,``!\````4$P``$````#03```/````11,```0```!5$P``
M!0```%H3``!H`0``8!,```<```#)%```#````-$4```)````WA0```<```#H
M%```"P```/`4```8````_!0``"8````5%0``+0```#P5```0````:A4``!\`
M``![%0``(0```)L5```+````O14```4```#)%0``%0```,\5```-````Y14`
M``T```#S%0``!@````$6```&````"!8``"H````/%@``"P```#H6```$````
M1A8``!````!+%@``"P```%P6```<````:!8```P```"%%@``*0```)(6```1
M````O!8```T```#.%@```P```-P6```+````X!8```L```#L%@``"@```/@6
M```'`````Q<```L````+%P``"````!<7```0````(!<``!\````Q%P``'P``
M`%$7```>````<1<```0```"0%P``"````)47```'````GA<```P```"F%P``
M"P```+,7```%````OQ<```L```#%%P``#P```-$7```4````X1<``!$```#V
M%P``)0````@8```%````+A@``!4````T&```!````$H8```$````3Q@```L`
M``!4&```!@```&`8```-````9Q@```T```!U&```!0```(,8```&````B1@`
M``4```"0&```!0```)88```"````G!@``"<```"?&```)P```,<8```I````
M[Q@``"`````9&0``'````#H9```'````5QD```4```!?&0``!@```&49```,
M````;!D```L```!Y&0``%````(49```$````FAD``!P```"?&0``*````+P9
M```+````Y1D```P```#Q&0``$0```/X9```%````$!H```P````6&@``%0``
M`",:```3````.1H``!$```!-&@``%````%\:```2````=!H``!@```"'&@``
M#````*`:```/````K1H```@```"]&@``!P```,8:```&````SAH``",```#5
M&@``&P```/D:```%````%1L```\````;&P``*P```"L;```=````5QL``!\`
M``!U&P``+@```)4;```B````Q!L``!(```#G&P``#P```/H;```,````"AP`
M``4````7'```"````!T<```/````)AP```T````V'```"P```$0<```*````
M4!P```@```!;'```!@```&0<```#````:QP``"8```!O'```+0```)8<```(
M````Q!P``!$```#-'```#P```-\<```0````[QP```4`````'0``!0````8=
M```!````;````'0```!'````"0```#``````````20`````````I````:```
M`%P```!E````8@```"<```!7````!````"\`````````00```%4```!>````
M`````$`````K````````````````````-@```&H```!9````,0```$H```!/
M````4@``````````````0@```!H````*`````````"````!F````-P``````
M````````4P```&0```!N````!0```%8```!&````=P```!D`````````2P``
M``\`````````&P```%0``````````````',```!M````#0`````````?````
M$P````(`````````;P```$,`````````(@````L```!P````%````!8```!C
M````+@```&D```!A````&````$@````L``````````````!Y````!@```&``
M``!V````.@```'@```!=````/P```#L```!.````<0```!$```!,````,@``
M`!(```!:````#@```#,````=````9P````````````````````````!K````
M6````````````````````",````0````4```````````````-0```!P`````
M````1`````@``````````````#@````#`````````!<```!Z````#````#P`
M```^`````````"@`````````6P```"T````D````````````````````30``
M```````E`````````!X```!%````!P```"$```!?````%0```#0```!U````
M`````'L````]````40````````!R````.0```"8````J```````````R-"!H
M;W5R<P!!32]030!!9&0@<&%I<@!!9&1R97-S`$%D9')E<W,@0F]O:P!!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=F%I;&%B
M;&4@9FEE;&1S.@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O
M<R!U<V5R;F%M92X`0FER=&AD87D`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;6EC<P!#;VUP86YY
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$
M`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N`$9A>`!(96QP`$AO;64`2&]M92!!9&1R97-S
M`$AO;64@4&AO;F4`2&]R9&4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`2V5R8F5R;W,@
M<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!,86YG=6%G90!,:7-T
M($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@
M9FEE;&1S`$UE;G4@;6]D93H`365S<V%G90!-;VYT:&QY`$YA;64`3F5V97(`
M3F\`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO=&5S`$]+`$]P
M=&EO;G,`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0`4')O8FQE;2!$97-C<FEP=&EO;@!296UO=F4@
M<&%I<@!2971U<FX@=&\@3W!T:6]N<P!2;VQE`%-A=F4@3W!T:6]N<P!396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RX`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD
M(%!R;V)L96T@4F5P;W)T`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W5C8V5S<P!487-K<P!497AT($]N;'D`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BX`5&ET;&4`55),`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S
M97(@3W!T:6]N<P!5<V5R;F%M90!787)N:6YG`%=E96ML>0!796QC;VUE('1O
M("5S`%=E;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE
M87)L>0!997,`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN
M9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`6U!R
M;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`;F%M90!V0V%R9`!0<F]J
M96-T+4ED+59E<G-I;VXZ($A/4D1%('8R+C`N,`I297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@
M,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M
M,#0M,S`@,3(Z,#`K,#(P,`I,87-T+51R86YS;&%T;W(Z(%!L871I;G5M($1E
M=F5L;W!M96YT(%1E86T@/&1E=G1E86U`<&QA=&EN=6TM<WDN;F5T/@I,86YG
M=6%G92U496%M.B!!<F%B:6,@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%
M+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O:'1M;#L@8VAA<G-E
M=#U#4#$R-38*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`,C0@
MT\?:R0#DY<?1Q_`OX>WAQ_``P];=(,ODQ\;M`,?AVN3FQ^0`S]W*T2#:Y,?F
M[>0`RN,@RLW/[<\@WNWCR2#;[=$@X][(YN')`,K#W^W/(,?AV.'((-[(X2#'
MX<C/P2#(VN/A[<?*(,?AU>W'Y,F_`,KC(-'=UB#'X<K-WMX@X^0@Q^'EYNW)
M(./D(-[(X2#'X>/.S^,@T<?/[>;3+@#'X<W>YN$@Q^'CRN;=T<DZ`-_AX\D@
MX]'FT2#;R-$@X][(YN')("C?[='([='FTRD`Q]/C(,?AX]/*SL_C(-O(T2#C
MWLCFX2`HW^W1R.W1YM,I`.WFXR#'X>/MX<?/`,/,Y,_)`,7AV\?!(,?AR.''
MVR#:Y"#CU-_AR0#'X>7'RMT@Q^',YL?A`,7;X<?>(,?AY,?=T,D`T=/FX\?*
M`,?AU-'?R0#AQ\7CW\?D[<D@X=W*S2!-86EN=&5N86YC95]487-K(.'AR-'M
MX\P@)7,`[>;C("T@T=[C[>0`[>;C[0#'X<K-WMX@Q^''W<K1Q];M`-31S2#'
MX>/4W^')`,KC(,W=V2#'X<K=Q]7MX2#AX\_MT2#'X>39Q^,`SNW'T<?*(,?A
MVM'6`.''(,K/SN$@X\C'U-')\"#%X>P@Q^'CX=T@;6%I;G1E;F%N8V4N<&AP
M`,?AR-'MSR#'X<7AW\K1YN3M`.''RN;,SR#DRL?&S"X`SMC#`-_A(#$U(,_>
M[=[)`-_A(#,P(,_>[=[)`-_A(#4@S][MWLD`W^$@S\[FX0#?X2#DU=T@T\?:
MR0#?X2#/WNW>R0##X\OAR2#:X>P@Q^'>[>,Z`.''Q>/?Q^3MR2#AX=K+YM$@
MVN'L(,?ARMW6[>''RBX`X<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!,1$%0
M+@#AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C(%--0BX`W<??TP#'X>/3Q]K/
MR0#'X<C/Q^W)`-KDYL?D(,?AX^32X0#EQ\K=(,?AX^32X0#EYM'/[0##[=[F
MY,?*(-W>V`##[=[FY,?*(./:(.35YM4`Q^'-WN;A(,?AX]/*YM'/R3H@)7,`
MQ^'-WN;A(,?AX]/*YM'/R3H`Q^'CSL_C(-_MT<CMT>;3(-'=UB#'X<K-WMX@
MX^0@Q^'EYNW)+@#'X>';R0#>Q\;CR2#:Y,?F[>0@Q^'CT\?:S\D`S\[FX0#.
MT>;,`-3ET2`M(-'>X^WD`,?AR-'MSP#CV,?(WLD@Q^'-WN;A`.;6VB#'X>/0
MW]''RCH`T=/'X<D`U.71[<?P`,?AQ]/C`,/(S\?P`.''`.''RN;,SR#CVN'F
MX\?*(,WFX2#%VL_'S\?*(,?AW"!&5%`@5D93+@#AQ\KFS,\@X]KAYN/'RB#-
MYN$@Q=K/Q\_'RB#'X=P@4U%,(%9&4RX`X<?*YLS/(./:X>;CQ\H@S>;A(,7:
MS\?/Q\H@X^'=Q\H@4U%,(%9&4RX`X<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@
MW^W1R.W1YM,`X<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@4TU"/@#CX<?-V<?*
M`./FQ]W>`,[MQ]''R@#CVN'FX\?*(,+.T>P`W^'CR2#'X>/1YM$`RN3=[=`@
MVN/A[<?*(,?AU>W'Y,D`Y<?*W0#'X=',Q\$@RM+F[<_DQR#CX<[5(,?AX]3?
MX<DN`,?AT<S'P2#*TN;MS^3'(,C'T^,@Q^'CT\K.S^,@YM_AX\D@Q^'3T2X`
MU-'-(,?AX]3?X<D`Q=+AR2#'X<ODQ\;M`-KFS\D@Q>'L(,?ASNW'T<?*`,?A
MS^;1`,W=V2#'X<[MQ]''R@#'SLK1(,?AW>;'U>$@X>'*Q]'MSCH`Q\[*T2#*
MY-/MWB#'X<K'T>W..@#'SLK1(,KDT^W>(,?AYM[*.@#%SLK1(,W>X>WD(./*
MX\?+X>WD+@#%SLK1(.';RM\@Q^'CW=;AR3H`P]'3X2#*WM'MT<?P(,CCU-_A
MR2#-U>'*`,7EX^$@Q^'5[<?DR0#%S\['T2#-T>;=(,['U<D`RN,@R.3,Q\T`
MQ^'CY>/'R@#DU2#=WM@`[<S((,/D(.W?YN0@Y=#'(,?AT=[C(,/?R-$@X^0@
MQ^'5W=$`[<S((,/D(,K?YN0@Y=#E(,?AWNWCR2#1WN,N`,?AX=[(`-KDYL?D
M(,?AQ>3*T>3MR@#AQR#%X]_'Y.W)(.'*V^WMT2#'X=/CQ\WMQ\H@X>/AW2!6
M1E,@)7,O)7,N`.''(,7CW\?D[<D@X>'%RM7'X2#(X\[/XR!344PN`.''(,7C
MW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="X`X<<@RN;,SR#%X]_'Y.W)(.'*
MV^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+@#;[=$@WL?/T2#:X>P@RM',
MX\D@X]/*Y,\@Q^'FT<\@Y=#'`,K1Q\S:(-KD(,?ARMOM[=''R@#.[<?1Q\H@
MQ^'CT\K.S^,`Q]/C(,?AX]/*SL_C`,KDR.WE`,/3R.;:[<?P`,/EX<<@R-_C
M(,7A["`E<P##Y>''(.;3Y>''("5S`-KDYL?D(,?AVN/A`.7'RMT@Q^':X^$`
MT^3)("T@U]<`T^3F[<?P`.3:XP#MS,@@U-'-(,?AX]3?X<D@WLCA(,?1T\?A
M(,K>T>W1Q_`@R.7'+@#'Y,KERB#5X<?-[<D@Q^''RM7'X2`E<RX@Q^'1S,?!
M(,7:Q\_)(,?AS\[FX2X`R.W'Y,?*WSH`RN,@RLW/[<L@Q^'.[<?1Q\H`6\K>
MT>W1(,?AX]3?X<E=`%O'X=/8T2`E<R#CY"`E<UT`Q^''T^,`=D-A<F0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+WIH7U17+P``````````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-@`P,38W,C,`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?5%<O3$-?34534T%'15,O````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<V
M`#`R,#4Q,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]Z:%]45R],
M0U]-15-304=%4R]H;W)D92YM;P``````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S
M-#$P-C,`,3`T,3<S-C(W-S8`,#(R,34R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-X2!)4`````30<``!P```"$.@``QPD`
M`.QT````````")P```X````)G```#P```!B<```-````*)P```@````VG```
M"P```#^<```,````2YP```0```!8G```&````%V<```;````=IP``"T```"2
MG```'0```,"<```D````WIP``"D````#G0``&0```"V=```F````1YT```P`
M``!NG0``)````'N=```/````H)T```L```"PG0``#@```+R=```%````RYT`
M`"@```#1G0``"````/J=```*`````YX``!4````.G@``$@```"2>```+````
M-YX``(4```!#G@``#@```,F>```*````V)X```T```#CG@``#@```/&>```1
M`````)\```T````2GP``#````""?```-````+9\```8````[GP``E````$*?
M```*````UY\```\```#BGP``&````/*?```,````"Z````X````8H```#@``
M`">@```(````-J````D````_H```+@```$F@```:````>*```#(```"3H```
M.````,:@``!4````_Z```%$```!4H0``6@```*:A``!7`````:(``#0```!9
MH@``"0```(ZB```-````F*(```<```"FH@``"@```*ZB```/````N:(```4`
M``#)H@``!@```,^B```1````UJ(```@```#HH@``"0```/&B```)````^Z(`
M`"4````%HP``(````"NC```3````3*,``!````!@HP``#P```'&C```*````
M@:,```,```",HP``#P```)"C```4````H*,```D```"UHP``#0```+^C```2
M````S:,``!D```#@HP``'@```/JC```/````&:0```H````II```#P```#2D
M```(````1*0``"0```!-I```%````'*D```6````AZ0```@```">I```3@``
M`*>D```M````]J0``!D````DI0``!P```#ZE```,````1J4``"P```!3I0``
M#@```("E```#````CZ4```L```"3I0``!P```)^E```'````IZ4```4```"O
MI0``!0```+6E```*````NZ4```,```#&I0``%P```,JE```*````XJ4```\`
M``#MI0``#@```/VE```8````#*8``",````EI@``#@```$FF```4````6*8`
M`!<```!MI@``%P```(6F```7````G:8``!,```"UI@``#P```,FF```.````
MV:8``!\```#HI@``'0````BG```'````)J<```8````NIP``"````#6G```/
M````/J<```8```!.IP``"@```%6G```3````8*<```L```!TIP``$````("G
M```5````D:<``!4```"GIP``!P```+VG```0````Q:<```4```#6IP``%0``
M`-RG```1````\J<```P````$J```.P```!&H```X````3:@```D```"&J```
M!P```)"H```4````F*@```,```"MJ```!0```+&H```0````MZ@```D```#(
MJ```$P```-*H```Y````YJ@``!(````@J0``)P```#.I```L````6ZD``"H`
M``"(J0``)0```+.I```*````V:D```8```#DJ0``"0```.NI```'````]:D`
M`"\```#]J0``-P```"VJ```N````9:H``%4```"4J@``+0```.JJ```M````
M&*L``#T```!&JP``/P```(2K```M````Q*L``$````#RJP``(P```#.L```C
M````5ZP``$````![K```+0```+RL```S````ZJP``"4````>K0``%0```$2M
M```9````6JT``"D```!TK0``)````)ZM```H````PZT``!$```#LK0``"@``
M`/ZM```*````":X``!`````4K@``%@```"6N```6````/*X```<```!3K@``
M!P```%NN```4````8ZX```H```!XK@``"````(.N```G````C*X```@```"T
MK@``!P```+VN```'````Q:X```8```#-K@``!0```-2N```'````VJX```8`
M``#BK@``"````.FN```I````\JX```X````<KP``"@```"NO```$````-J\`
M``<````[KP``"0```$.O```&````3:\``!$```!4KP``!P```&:O```6````
M;J\```0```"%KP``"````(JO```&````DZ\```T```":KP``!@```*BO```>
M````KZ\``!$```#.KP``"````."O```-````Z:\```P```#WKP``!P````2P
M```#````#+````,````0L```%P```!2P```3````++```!T```!`L```"```
M`%ZP```$````9[````@```!LL```"````'6P``!!````?K```!H```#`L```
M(````-NP```5````_+````8````2L0``!@```!FQ```5````(+$``!@````V
ML0``(@```$^Q```N````<K$``!T```"AL0``(0```+^Q``!4````X;$``"D`
M```VL@``"@```&"R```'````:[(``!4```!SL@``#@```(FR```*````F+(`
M``\```"CL@``#0```+.R```/````P;(```T```#1L@``"0```-^R```4````
MZ;(```8```#^L@``&`````6S```=````'K,``!,````\LP``$0```%"S```4
M````8K,```0```!WLP``!@```'RS```4````@[,``%0```"8LP``9````.VS
M```$````4K0```X```!7M```!0```&:T```%````;+0``!L```!RM```&@``
M`(ZT```3````J;0``!$```"]M```$0```,^T```<````X;0``"H```#^M```
M$````"FU```A````.K4```4```!<M0``$P```&*U```+````=K4``!(```""
MM0``"@```)6U```/````H+4```T```"PM0``$0```+ZU```3````T+4```P`
M``#DM0``!@```/&U```,````^+4```8````%M@``%P````RV```0````)+8`
M`!$````UM@``"````$>V```%````4+8```P```!6M@``$````&.V```%````
M=+8```T```!ZM@``!@```(BV```'````C[8```T```"7M@``!P```*6V```+
M````K;8```<```"YM@``!P```,&V```)````R;8```D```#3M@``"@```-VV
M```9````Z+8``#T````"MP``'0```$"W```,````7K<``!````!KMP``!0``
M`'RW```E````@K<``!(```"HMP``$P```+NW```K````S[<``#L```#[MP``
M(````#>X```(````6+@``#8```!AN```(0```)BX```0````NK@```@```#+
MN```#````-2X```$````X;@```\```#FN```#@```/:X```*````!;D```T`
M```0N0``'P```!ZY```<````/KD``"$```!;N0``'@```'VY```9````G+D`
M`!X```"VN0``'0```-6Y```;````\[D``"`````/N@``+@```#"Z```F````
M7[H``!P```"&N@``'@```*.Z```<````PKH``"8```#?N@``*P````:[```S
M````,KL``"8```!FNP``*P```(V[```X````N;L``!T```#RNP``%0```!"\
M```O````)KP``"````!6O```$@```'>\```I````BKP``!X```"TO```(```
M`-.\```2````]+P``*(````'O0``%@```*J]```C````P;T``"@```#EO0``
M*0````Z^```H````.+X``!\```!AO@``%0```(&^```@````E[X``"4```"X
MO@``*````-Z^```M````![\``#`````UOP``D@```&:_```A````^;\``!8`
M```;P```'````#+````F````3\```"H```!VP```00```*'```!$````X\``
M``P````HP0``!P```#7!```'````/<$```8```!%P0``#0```$S!```0````
M6L$``!(```!KP0``$P```'[!```2````DL$```<```"EP0``!````*W!```0
M````LL$```P```##P0``#@```-#!```-````W\$```\```#MP0``$P```/W!
M```-````$<(``"@````?P@```P```$C"```-````3,(```8```!:P@``$0``
M`&'"```7````<\(``!L```"+P@``#@```*?"```"````ML(``$D```"YP@``
M!0````/#```0````"<,```\````:PP``!````"K#```-````+\,```X````]
MPP```P```$S#```.````4,,```@```!?PP``#P```&C#```/````>,,```<`
M``"(PP``#0```)##```0````GL,```T```"OPP``"P```+W#```&````R<,`
M``L```#0PP``#````-S#```*````Z<,``!$```#TPP``&0````;$```+````
M(,0```T````LQ```(@```#K$```;````7<0``#0```!YQ```"@```*[$```8
M````N<0``!D```#2Q```%@```.S$```B`````\4```T````FQ0``!P```#3%
M```4````/,4```L```!1Q0``(@```%W%```O````@,4```L```"PQ0``"0``
M`+S%```9````QL4```L```#@Q0``%P```.S%```7````!,8```D````<Q@``
M%@```";&```/````/<8``!D```!-Q@``%@```&?&```.````?L8``!@```"-
MQ@``"````*;&```-````K\8``"8```"]Q@``0P```.3&```(````*,<``!(`
M```QQP``'P```$3'```(````9,<```L```!MQP``+P```'G'```.````J<<`
M``4```"XQP``!@```+['```#````Q<<```<```#)QP``!````-''```*````
MUL<```H```#AQP``#P```.S'```0````_,<``!<````-R```$0```"7(```9
M````-\@``!<```!1R```"0```&G(```%````<\@```L```!YR```"@```(7(
M```%````D,@```T```"6R```&P```*3(```7````P,@``!0```#8R```"0``
M`.W(```.````]\@```T````&R0``$@```!3)```X````)\D``"````!@R0``
M"````(')```.````BLD``'L```"9R0``&````!7*```1````+LH```<```!`
MR@``!0```$C*```8````3LH``!X```!GR@``&P```(;*```9````HLH``!L`
M``"\R@``$P```-C*```'````[,H```@```#TR@``!@```/W*```&````!,L`
M`!`````+RP``#P```!S+```0````+,L```\````]RP``"P```$W+```/````
M6<L```P```!IRP``#P```';+```'````ALL```8```".RP``#@```)7+```,
M````I,L```\```"QRP``"````,'+```(````RLL``!,```#3RP``'@```.?+
M```A````!LP``"`````HS```&0```$G,```7````8\P``"4```![S```%P``
M`*',```6````N<P```0```#0S```&P```-7,```-````\<P```P```#_S```
M`P````S-```%````$,T```@````6S0``"@```!_-```,````*LT```L````W
MS0``$````$/-```,````5,T```0```!AS0``$P```&;-```4````>LT```P`
M``"/S0``"0```)S-```.````ILT```L```"US0``&P```,'-```'````W<T`
M``<```#ES0``"@```.W-```-````^,T```D````&S@``!````!#.```%````
M%<X```,````;S@``&````!_.```*````.,X```0```!#S@``)@```$C.```.
M````;\X``'P```!^S@``%0```/O.```%````$<\```<````7SP``#````!_/
M```(````+,\```H````USP``!@```$#/```(````1\\```(```!0SP``!@``
M`%//```&````6L\``!0```!ASP``#0```';/```0````A,\``!L```"5SP``
M!````+'/```)````ML\``!````#`SP``"0```-'/```)````V\\```4```#E
MSP``"````.O/```&````],\``!D```#[SP``#@```!70```'````)-````<`
M```LT```!0```#30```)````.M````H```!$T````@```$_0```&````4M``
M``L```!9T```#0```&70```)````<]````8```!]T```$@```(30```)````
ME]````<```"AT```%````*G0```=````OM```$(```#<T```)0```!_1```E
M````1=$```8```!KT0``"@```'+1```$````?=$```D```""T0``"````(S1
M```1````E=$```D```"GT0``!@```+'1```-````N-$```8```#&T0``!```
M`,W1```>````TM$```4```#QT0``#@```/?1```$````!M(```8````+T@``
M!P```!+2```A````&M(```T````\T@``%0```$K2```&````8-(```0```!G
MT@``$0```&S2```&````?M(```H```"%T@``(@```)#2```$````L](```4`
M``"XT@``'0```+[2```$````W-(```P```#AT@``#@```.[2```*````_=(`
M``@````(TP``"0```!'3```%````&],``#H````ATP``,````%S3```U````
MC=,``"D```##TP``1P```.W3```X````-=0``"D```!NU```/P```)C4```N
M````V-0``"T````'U0``'P```#75```/````5=4``!(```!EU0``"P```'C5
M```F````A-4``"D```"KU0``)````-75```F````^M4```@````AU@``"@``
M`"K6```)````-=8```<````_U@``(````$?6```@````:-8``"8```")U@``
M"@```+#6```9````N]8``"D```#5U@``$@```/_6```'````$M<```H````:
MUP``#````"77```/````,M<``!````!"UP``0````%/7``!P````E-<``&8`
M```%V```#@```&S8```)````>]@```H```"%V```$@```)#8```3````H]@`
M``P```"WV```!@```,38```/````R]@``!(```#;V```$````.[8```1````
M_]@``!P````1V0``(P```"[9``!J````4MD```\```"]V0``!0```,W9```0
M````T]D```D```#DV0``!````.[9```+````\]D``"````#_V0``%````"#:
M```,````-=H```P```!"V@``#P```$_:```5````7]H``"D```!UV@``*@``
M`)_:```F````RMH``"<```#QV@``*0```!G;```J````0]L``!D```!NVP``
M0@```(C;```1````R]L``!(```#=VP``$P```/#;```4````!-P```\````9
MW```%@```"G<```7````0-P``!````!8W```$0```&G<```T````>]P``!,`
M``"PW```$@```,3<```U````U]P``!0````-W0``!P```"+=```,````*MT`
M`"`````WW0``$````%C=```4````:=T``!$```!^W0``%P```)#=```<````
MJ-T``!,```#%W0``%````-G=```:````[MT``!$````)W@``&@```!O>```>
M````-MX``!H```!5W@``$P```'#>```5````A-X``!$```":W@``%P```*S>
M```4````Q-X``!<```#9W@``%0```/'>```)````!]\``!`````1WP``&0``
M`"+?```$````/-\```<```!!WP``"P```$G?```1````5=\```8```!GWP``
M!@```&[?```&````==\```4```!\WP``!P```(+?```'````BM\```4```"2
MWP``%@```)C?```&````K]\```8```"VWP``!````+W?```$````PM\```<`
M``#'WP``#@```,_?```,````WM\```P```#KWP``#0```/C?```*````!N``
M``X````1X```!0```"#@```H````)N````X```!/X```#````%[@```/````
M:^````H```![X```"````(;@```)````C^```"L```"9X```!````,7@```(
M````RN```"8```#3X```$@```/K@```/````#>$```8````=X0``"@```"3A
M```'````+^$```@````WX0``(````$#A```)````8>$``!0```!KX0``#```
M`(#A```-````C>$```X```";X0``%@```*KA```1````P>$```8```#3X0``
M`P```-KA```&````WN$```<```#EX0``!````.WA```+````\N$```L```#^
MX0``!P````KB```'````$N(``!8````:X@``#0```#'B```-````/^(```H`
M``!-X@``$````%CB```/````:>(``!$```!YX@``%P```(OB```*````H^(`
M`!$```"NX@``"````,#B```$````R>(```\```#.X@``.@```-[B```%````
M&>,``!X````?XP``#@```#[C```0````3>,```L```!>XP``#````&KC```)
M````=^,```<```"!XP``"@```(GC```)````E.,```X```">XP``$````*WC
M```;````ON,``!@```#:XP``&@```//C```*````#N0```D````9Y```"@``
M`"/D```,````+N0```\````[Y```"````$OD```&````5.0```<```!;Y```
M!0```&/D```+````:>0``$<```!UY```#0```+WD```)````R^0```0```#5
MY````P```-KD```3````WN0``!,```#RY```$P````;E```*````&N4```(`
M```EY0``!````"CE```E````+>4```,```!3Y0``!0```%?E```J````7>4`
M``H```"(Y0``!0```)/E```$````F>4```H```">Y0``#0```*GE```&````
MM^4```@```"^Y0``"````,?E```$````T.4```4```#5Y0``:````-OE```)
M````1.8```P```!.Y@``!0```%OF```&````8>8``!L```!HY@``+P```(3F
M```0````M.8```H```#%Y@``#P```-#F```*````X.8```D```#KY@``$P``
M`/7F```;````"><``!@````EYP``%P```#[G```?````5N<```X```!VYP``
M`P```(7G```'````B><```@```"1YP``!P```)KG```*````HN<```L```"M
MYP``!P```+GG``!1````P><``!`````3Z```#````"3H```:````,>@``$H`
M``!,Z```&0```)?H```&````L>@``!H```"XZ```)0```-/H```&````^>@`
M``8`````Z0``'P````?I```&````)^D```D````NZ0``&````#CI```7````
M4>D``"@```!IZ0``!@```)+I```-````F>D``"(```"GZ0``5P```,KI```3
M````(NH``",````VZ@``$P```%KJ```"````;NH```L```!QZ@``"````'WJ
M```-````ANH```H```"4Z@``!P```)_J```4````I^H```8```"\Z@``"```
M`,/J```.````S.H```<```#;Z@``"@```./J```+````[NH``#(```#ZZ@``
M!P```"WK```,````->L```T```!"ZP``#````%#K```)````7>L```D```!G
MZP``"@```''K```'````?.L```D```"$ZP``!P```([K```*````ENL``!L`
M``"AZP``$@```+WK```*````T.L``!8```#;ZP``"0```/+K```0````_.L`
M``<````-[```$@```!7L```$````*.P```<````M[```!0```#7L```%````
M.^P```L```!![```%````$WL```1````8NP``!H```!T[```%@```(_L```4
M````INP``!<```"[[```&````-/L```<````[.P``!D````)[0``!P```"/M
M```%````*^T```T````Q[0``#````#_M```1````3.T```@```!>[0``%P``
M`&?M```+````?^T```P```"+[0``'P```)CM```:````N.T``!,```#3[0``
M!````.?M```*````[.T```0```#W[0``#````/SM```%````">X```D````/
M[@``!0```!GN```'````'^X```4````G[@``!````"WN```"````,NX``#@`
M```U[@``+````&[N```2````F^X``"D```"N[@``,@```-CN```*````"^\`
M`"P````6[P``+@```$/O```S````<N\``#,```"F[P``.````-KO```/````
M$_```!@````C\```$````#SP```/````3?```!,```!=\```%0```''P```4
M````A_```!(```"<\```%````*_P```M````Q/```"T```#R\```,0```"#Q
M```N````4O$``"\```"!\0``+````+'Q``!B````WO$``!,```!!\@``#0``
M`%7R```(````8_(``!<```!L\@``"````(3R```,````C?(``"L```":\@``
M(0```,;R```:````Z/(```D````#\P``10````WS``!!````4_,```0```"5
M\P``$P```)KS```4````KO,```X```##\P``$P```-+S```8````YO,```8`
M``#_\P``"0````;T```*````$/0```\````;]```$````"OT```'````//0`
M``X```!$]```!0```%/T```;````6?0```@```!U]```!@```'[T```4````
MA?0``!$```":]```#@```*ST```X````N_0```(```#T]```!@```/?T```.
M````_O0```4````-]0``!P```!/U```&````&_4``"@````B]0``#````$OU
M```<````6/4```0```!U]0``*0```'KU```?````I/4``%P```#$]0``%```
M`"'V```^````-O8``!\```!U]@``$````)7V```'````IO8```X```"N]@``
M#````+WV```,````RO8``!,```#7]@``"@```.OV```=````]O8``!D````4
M]P``!0```"[W```1````-/<``!$```!&]P``)````%CW```2````??<``!4`
M``"0]P``$@```*;W```.````N?<``!D```#(]P``"````.+W```)````Z_<`
M``T```#U]P``"@````/X```'````#O@```\````6^```!@```";X```+````
M+?@``!H````Y^```"@```%3X```'````7_@```@```!G^```!0```'#X```?
M````=O@```8```"6^```$````)WX```(````KO@```T```"W^```"````,7X
M```>````SO@``!(```#M^```+`````#Y```:````+?D```D```!(^0``"@``
M`%+Y```5````7?D```4```!S^0``%````'GY```$````COD``!````"3^0``
M!@```*3Y```'````J_D``!X```"S^0``*````-+Y```*````^_D``!P````&
M^@``$0```"/Z```+````-?H``!H```!!^@``%````%SZ```$````<?H```0`
M``!V^@``"P```'OZ```%````A_H```8```"-^@``"````)3Z```&````G?H`
M`!L```"D^@``-````,#Z```T````]?H``"`````J^P``*0```$O[```@````
M=?L``$$```"6^P``&@```-C[```H````\_L``"D````<_```4````$;\```B
M````E_P```8```"Z_```"````,'\```%````ROP```@```#0_```&0```-G\
M```9````\_P``"H````-_0``(P```#C]```9````7/T``"X```!V_0``-```
M`*7]```(````VOT``!<```#C_0``"@```/O]```'````!OX``"$````._@``
M$````##^```.````0?X```L```!0_@``!P```%S^```3````9/X```@```!X
M_@``"P```('^```*````C?X``!0```"8_@``#P```*W^```R````O?X```L`
M``#P_@``!0```/S^```%`````O\```4````(_P``%P````[_```/````)O\`
M``0````V_P``"@```#O_```)````1O\```L```!0_P``#0```%S_```,````
M:O\```X```!W_P``!0```(;_```$````C/\```T```"1_P``,@```)__``!%
M````TO\``!<````8``$`!P```#```0`>````.``!`!0```!7``$`!0```&P`
M`0`4````<@`!``8```"'``$`!P```(X``0`.````E@`!`"H```"E``$`!@``
M`-```0`,````UP`!``T```#D``$`$0```/(``0`+````!`$!`#8````0`0$`
M"@```$<!`0`B````4@$!``L```!U`0$`#P```($!`0`R````D0$!`"4```#$
M`0$`,````.H!`0`Q````&P(!`"T```!-`@$`#@```'L"`0`%````B@(!``X`
M``"0`@$`$P```)\"`0`2````LP(!``<```#&`@$`$0```,X"`0`3````X`(!
M``<```#T`@$`%````/P"`0`8````$0,!``<````J`P$`!0```#(#`0`,````
M.`,!``P```!%`P$`$@```%(#`0`$````90,!``<```!J`P$`"@```'(#`0`+
M````?0,!``P```")`P$`#@```)8#`0`.````I0,!``4```"T`P$`!0```+H#
M`0`N````P`,!`"8```#O`P$`(P```!8$`0`#````.@0!`!(````^!`$`!@``
M`%$$`0`>````6`0!`!@```!W!`$`)0```)`$`0`-````M@0!``D```#$!`$`
M`P```,X$`0`'````T@0!``H```#:!`$``@```.4$`0`,````Z`0!`!4```#U
M!`$`"P````L%`0`9````%P4!`"`````Q!0$`$@```%(%`0`%````904!``H`
M``!K!0$`%0```'8%`0`2````C`4!``P```"?!0$`!````*P%`0`)````L04!
M``<```"[!0$`#````,,%`0!2````T`4!`!<````C!@$`)````#L&`0`2````
M8`8!``<```!S!@$`!@```'L&`0`.````@@8!``P```"1!@$`#0```)X&`0`5
M````K`8!`!(```#"!@$`#P```-4&`0`4````Y08!``H```#Z!@$`&P````4'
M`0`0````(0<!``L````R!P$`:0```#X'`0`:````J`<!`!<```##!P$`)P``
M`-L'`0`:`````P@!`!<````>"`$`&P```#8(`0`9````4@@!`!\```!L"`$`
M$P```(P(`0`(````H`@!``<```"I"`$`"````+$(`0`)````N@@!`!4```#$
M"`$`#0```-H(`0`C````Z`@!``T````,"0$`$P```!H)`0`(````+@D!``,`
M```W"0$`1@```#L)`0`_````@@D!`#<```#""0$`5P```/H)`0`%````4@H!
M`!\```!8"@$`+P```'@*`0`*````J`H!``@```"S"@$`#0```+P*`0`M````
MR@H!``0```#X"@$`3P```/T*`0`E````30L!``L```!S"P$`'P```'\+`0`=
M````GPL!`"4```"]"P$`(````.,+`0`D````!`P!`"`````I#`$`"P```$H,
M`0`'````5@P!``T```!>#`$`#````&P,`0`7````>0P!``8```"1#`$`#```
M`)@,`0`'````I0P!``D```"M#`$`$P```+<,`0`)````RPP!``0```#5#`$`
M$````-H,`0`(````ZPP!``@```#T#`$`!````/T,`0`+`````@T!``P````.
M#0$`$@```!L-`0`1````+@T!``P```!`#0$`#P```$T-`0`'````70T!``T`
M``!E#0$`%````',-`0`.````B`T!``P```"7#0$`&P```*0-`0`L````P`T!
M`!,```#M#0$`!@````$.`0`'````"`X!`!,````0#@$`!0```"0.`0`$````
M*@X!`!<````O#@$`"@```$<.`0`,````4@X!``D```!?#@$`!@```&D.`0`)
M````<`X!``@```!Z#@$`"0```(,.`0`*````C0X!`!$```"8#@$`!@```*H.
M`0`.````L0X!``X```#`#@$`#0```,\.`0`+````W0X!`!T```#I#@$`"P``
M``</`0`"````$P\!`!P````6#P$`!P```#,/`0`&````.P\!`&0```!"#P$`
M"0```*</`0`'````L0\!`"8```"Y#P$`.````.`/`0`:````&1`!`"H````T
M$`$`.P```%\0`0`H````FQ`!`#0```#$$`$`&0```/D0`0`5````$Q$!``4`
M```I$0$`!P```"\1`0`(````-Q$!``<```!`$0$`!0```$@1`0`'````3A$!
M``X```!6$0$`"0```&41`0`&````;Q$!``@```!V$0$`"P```'\1`0`'````
MBQ$!``@```"3$0$`!P```)P1`0`6````I!$!``D```"[$0$`!@```,41`0`+
M````S!$!`!````#8$0$`!@```.D1`0`<````\!$!`!0````-$@$`!P```"(2
M`0`1````*A(!``@````\$@$`#@```$42`0`(````5!(!``4```!=$@$`$```
M`&,2`0`0````=!(!``8```"%$@$`&0```(P2`0`*````IA(!`!P```"Q$@$`
M!P```,X2`0`%````UA(!`!````#<$@$`%````.T2`0`+`````A,!``T````.
M$P$`*````!P3`0`8````11,!`!<```!>$P$`!````'83`0`)````>Q,!``H`
M``"%$P$`!P```)`3`0`"````F!,!``X```";$P$`"````*H3`0`C````LQ,!
M`#@```#7$P$`)@```!`4`0`Q````-Q0!`"<```!I%`$`9````)$4`0`4````
M]A0!`%4````+%0$`.````&$5`0!*````FA4!`%L```#E%0$`*````$$6`0`X
M````:A8!`"@```"C%@$`+````,P6`0`F````^18!`!L````@%P$`/@```#P7
M`0`C````>Q<!`!<```"?%P$`2````+<7`0"%`````!@!`#````"&&`$`)0``
M`+<8`0!!````W1@!`%L````?&0$`20```'L9`0`Q````Q1D!`!T```#W&0$`
M&````!4:`0`K````+AH!`"$```!:&@$`'P```'P:`0`K````G!H!`"$```#(
M&@$`)P```.H:`0`Z````$AL!`!T```!-&P$`$0```&L;`0`S````?1L!`"4`
M``"Q&P$`)P```-<;`0`@````_QL!`!\````@'`$`,````$`<`0!I````<1P!
M`#$```#;'`$`00````T=`0`S````3QT!`"4```"#'0$`/0```*D=`0!E````
MYQT!`$T```!-'@$`+P```)L>`0`N````RQX!`#````#Z'@$`5````"L?`0!:
M````@!\!`$@```#;'P$`2@```"0@`0`R````;R`!`"\```"B(`$`+````-(@
M`0`M````_R`!`!<````M(0$`)0```$4A`0`R````:R$!`"D```">(0$`/@``
M`,@A`0`B````!R(!`%(````J(@$`)0```'TB`0`+````HR(!`+$```"O(@$`
M10```&$C`0`A````IR,!`#````#)(P$`)0```/HC`0`<````("0!`#$````]
M)`$`!P```&\D`0`'````=R0!``0```!_)`$`#0```(0D`0`+````DB0!``X`
M``">)`$`"P```*TD`0`%````N20!`!````"_)`$``@```-`D`0!9````TR0!
M``4````M)0$`$@```#,E`0`$````1B4!``<```!+)0$`"````%,E`0`%````
M7"4!``,```!B)0$`$````&8E`0`3````=R4!``T```"+)0$``@```)DE`0`'
M````G"4!``8```"D)0$`%````*LE`0`,````P"4!`!@```#-)0$`!@```.8E
M`0`2````[24!``P`````)@$``P````TF`0`$````$28!``8````6)@$`!P``
M`!TF`0`?````)28!`#4```!%)@$`+@```'LF`0`O````JB8!`!<```#:)@$`
M(@```/(F`0`E````%2<!`"`````[)P$`&P```%PG`0`8````>"<!`"0```"1
M)P$`'P```+8G`0`:````UB<!`"$```#Q)P$`(````!,H`0`:````-"@!`#(`
M``!/*`$`&@```((H`0`O````G2@!`"L```#-*`$`'P```/DH`0`C````&2D!
M`!\````]*0$`&@```%TI`0`A````>"D!`"4```":*0$`)@```,`I`0`E````
MYRD!`"0````-*@$`&````#(J`0`=````2RH!`"0```!I*@$`&````(XJ`0`B
M````IRH!`"P```#**@$`+P```/<J`0`5````)RL!`"4````]*P$`/````&,K
M`0`?````H"L!`",```#`*P$`'P```.0K`0`@````!"P!`!H````E+`$`&```
M`$`L`0`F````62P!`!X```"`+`$`*0```)\L`0`>````R2P!`#$```#H+`$`
M"0```!HM`0`,````)"T!`!<````Q+0$`+P```$DM`0`D````>2T!``<```">
M+0$`#P```*8M`0`4````MBT!``X```#++0$`#0```-HM`0`D````Z"T!``4`
M```-+@$`!P```!,N`0`B````&RX!`"4````^+@$`&@```&0N`0`=````?RX!
M`!H```"=+@$`!P```+@N`0#'````P"X!``L```"(+P$`%0```)0O`0`&````
MJB\!``D```"Q+P$`"P```+LO`0`-````QR\!`!<```#5+P$`!@```.TO`0`S
M````]"\!`!,````H,`$`$P```#PP`0`'````4#`!``\```!8,`$`!P```&@P
M`0`R````<#`!``0```"C,`$`(0```*@P`0`3````RC`!``P```#>,`$`$0``
M`.LP`0`R````_3`!`!8````P,0$`"````$<Q`0`=````4#$!``D```!N,0$`
M"@```'@Q`0`4````@S$!``H```"8,0$`'0```*,Q`0`(````P3$!`!\```#*
M,0$`"````.HQ`0`:````\S$!``8````.,@$`%0```!4R`0`'````*S(!``@`
M```S,@$`"0```#PR`0`_````1C(!``<```"&,@$`#P```(XR`0`.````GC(!
M`!````"M,@$`"0```+XR`0`)````R#(!``@```#2,@$`$P```-LR`0`'````
M[S(!`!D```#W,@$`"@```!$S`0`7````'#,!`!0````T,P$`"@```$DS`0`,
M````5#,!`!<```!A,P$`!````'DS`0`J````?C,!``P```"I,P$`$0```+8S
M`0`'````R#,!``(```#0,P$`$````-,S`0`8````Y#,!``L```#],P$``P``
M``DT`0`(````#30!``8````6-`$`!P```!TT`0`-````)30!``L````S-`$`
M%````#\T`0`5````5#0!``X```!J-`$`+P```'DT`0`@````J30!`!P```#*
M-`$`%0```.<T`0`,````_30!`#$````*-0$`!0```#PU`0`2````0C4!`#\`
M``!5-0$`$@```)4U`0`*````J#4!``8```"S-0$`!````+HU`0`$````OS4!
M``H```#$-0$`$P```,\U`0`%````XS4!``8```#I-0$`!@```/`U`0`(````
M]S4!``0`````-@$`#`````4V`0`*````$C8!`#D````=-@$`+@```%<V`0`9
M````AC8!`!\```"@-@$`'0```,`V`0`1````WC8!``(```#P-@$`!````/,V
M`0`*````^#8!``8````#-P$`!0````HW`0`#````$#<!``P````4-P$`10``
M`"$W`0`R````9S<!`!H```":-P$`-````+4W`0`H````ZC<!`%,````3.`$`
M&0```&<X`0!R````@3@!`"````#T.`$`-0```!4Y`0`A````2SD!`$4```!M
M.0$`,````+,Y`0`H````Y#D!`"D````-.@$`)@```#<Z`0`E````7CH!`"@`
M``"$.@$`*````*TZ`0`B````UCH!`"L```#Y.@$`,````"4[`0`2````5CL!
M`!,```!I.P$`$````'T[`0!Y````CCL!``D````(/`$`H0```!(\`0!S````
MM#P!`'P````H/0$`*P```*4]`0!4````T3T!`!<````F/@$`)P```#X^`0`6
M````9CX!``\```!]/@$`%P```(T^`0`?````I3X!`$````#%/@$`'P````8_
M`0`<````)C\!`%$```!#/P$`&@```)4_`0`4````L#\!``H```#%/P$`!0``
M`-`_`0`&````UC\!``@```#=/P$`$@```.8_`0`0````^3\!`!,````*0`$`
M'0```!Y``0`/````/$`!``\```!,0`$`!````%Q``0`)````84`!``L```!K
M0`$`!P```'=``0`%````?T`!`!0```"%0`$`!P```)I``0`(````HD`!``\`
M``"K0`$`"````+M``0`,````Q$`!``\```#10`$`!@```.%``0`4````Z$`!
M``8```#]0`$`#`````1!`0`(````$4$!`!D````:00$`$0```#1!`0`*````
M1D$!`!@```!100$`$P```&I!`0`<````?D$!`!$```";00$`#P```*U!`0`$
M````O4$!`!D```#"00$`!P```-Q!`0`"````Y$$!``(```#G00$`$0```.I!
M`0`)````_$$!``8````&0@$`$@````U"`0`7````($(!``8````X0@$``@``
M`#]"`0`$````0D(!``\```!'0@$`$P```%="`0`'````:T(!``<```!S0@$`
M$0```'M"`0`&````C4(!`!@```"40@$`!@```*U"`0`3````M$(!`!````#(
M0@$`$@```-E"`0`"````[$(!``8```#O0@$`#````/9"`0`)`````T,!`!$`
M```-0P$`(@```!]#`0`'````0D,!``<```!*0P$`"P```%)#`0`%````7D,!
M``(```!D0P$`"P```&=#`0!A`0``<T,!``H```#51`$`#````.!$`0`*````
M[40!``<```#X1`$`!P````!%`0`'````"$4!``(````010$`$0```!-%`0`8
M````)44!`"L````^10$`&@```&I%`0`=````A44!`!,```"C10$`$0```+=%
M`0`I````R44!``T```#S10$`&P````%&`0`2````'48!``L````P1@$`!P``
M`#Q&`0`%````1$8!`!(```!*1@$`!P```%U&`0`'````948!``L```!M1@$`
M"0```'E&`0`+````@T8!`#P```"/1@$`"0```,Q&`0`%````UD8!``H```#<
M1@$`#P```.=&`0`*````]T8!``H````"1P$`"@````U'`0`*````&$<!``8`
M```C1P$`60```"I'`0`'````A$<!``P```",1P$`$@```)E'`0`*````K$<!
M``D```"W1P$`"0```,%'`0`)````RT<!``8```#51P$`'0```-Q'`0`4````
M^D<!`"4````/2`$`+0```#5(`0!`````8T@!`$0```"D2`$`1````.E(`0!*
M````+DD!`"<```!Y20$`"````*%)`0`(````JDD!``@```"S20$`"````+Q)
M`0`(````Q4D!``D```#.20$`"````-A)`0`.````X4D!``<```#P20$`!@``
M`/A)`0`&````_TD!`!L````&2@$`&P```")*`0`(````/DH!``H```!'2@$`
M"P```%)*`0`$````7DH!``0```!C2@$`"@```&A*`0`*````<TH!``D```!^
M2@$`"````(A*`0`(````D4H!`!$```":2@$`$````*Q*`0`/````O4H!``@`
M``#-2@$`#0```-9*`0`&````Y$H!`!D```#K2@$`#P````5+`0`0````%4L!
M``H````F2P$`,P```#%+`0`K````94L!`!L```"12P$`!````*U+`0`&````
MLDL!`"$```"Y2P$`!````-M+`0`$````X$L!`!0```#E2P$`%````/I+`0`4
M````#TP!``@````D3`$`!````"U,`0`)````,DP!``0````\3`$`$@```$%,
M`0`(````5$P!``@```!=3`$`!@```&9,`0`6````;4P!`!<```"$3`$`!@``
M`)Q,`0`.````HTP!``X```"R3`$`$````,%,`0`0````TDP!``@```#C3`$`
M"````.Q,`0`=````]4P!`!,````330$`%0```"=-`0`0````/4T!``\```!.
M30$`$P```%Y-`0`,````<DT!``0```!_30$`%0```(1-`0`J````FDT!``@`
M``#%30$`#````,Y-`0`.````VTT!`!(```#J30$`!````/U-`0`(`````DX!
M``0````+3@$`%P```!!.`0`*````*$X!``H````S3@$`&@```#Y.`0`D````
M64X!`!(```!^3@$`$@```)%.`0`6````I$X!``0```"[3@$`$````,!.`0`0
M````T4X!``@```#B3@$`#P```.M.`0`;````^TX!``@````73P$`&0```"!/
M`0`9````.D\!`!D```!43P$`&0```&Y/`0`$````B$\!``0```"-3P$`%```
M`))/`0`0````IT\!`"H```"X3P$`(P```.-/`0`I````!U`!`&L````Q4`$`
M*````)U0`0`H````QE`!`#$```#O4`$`,0```"%1`0`H````4U$!`"D```!\
M40$`'````*91`0`<````PU$!`#$```#@40$`*````!)2`0`N````.U(!`!0`
M``!J4@$`"0```']2`0`,````B5(!`!````"64@$`#0```*=2`0`-````M5(!
M``L```##4@$`%0```,]2`0`$````Y5(!``@```#J4@$`$@```/-2`0`8````
M!E,!`!`````?4P$`#@```#!3`0`8````/U,!`!,```!84P$`$0```&Q3`0`4
M````?E,!``0```"34P$`!P```)A3`0`0````H%,!``\```"Q4P$`#````,%3
M`0`0````SE,!``T```#?4P$`!````.U3`0`A````\E,!``@````45`$`"```
M`!U4`0`$````)E0!`!(````K5`$`!````#Y4`0`$````0U0!``@```!(5`$`
M!````%%4`0`M````5E0!``0```"$5`$`$0```(E4`0`$````FU0!``T```"@
M5`$`#0```*Y4`0`>````O%0!`!@```#;5`$`$P```/14`0`(````"%4!`!D`
M```150$`$````"M5`0`(````/%4!``,```!%50$`"@```$E5`0`/````5%4!
M`!,```!D50$`!@```'A5`0`&````?U4!`!$```"&50$`$0```)A5`0`F````
MJE4!`!$```#150$`&@```.-5`0`2````_E4!``\````15@$`!````"%6`0`,
M````)E8!`!(````S5@$`#P```$96`0`C````5E8!`!(```!Z5@$`&@```(U6
M`0`Q````J%8!`!D```#:5@$`$P```/16`0`(````"%<!``H````15P$`&0``
M`!Q7`0`(````-E<!``H````_5P$`"P```$I7`0`*````5E<!``L```!A5P$`
M"````&U7`0`6````=E<!``0```"-5P$`)0```))7`0`1````N%<!``@```#*
M5P$`"@```--7`0`(````WE<!``L```#G5P$`!````/-7`0`,````^%<!`!L`
M```%6`$`+0```"%8`0`$````3U@!``T```!46`$`#````&)8`0`,````;U@!
M`!$```!\6`$`#P```(Y8`0`-````GE@!``@```"L6`$`$@```+58`0`-````
MR%@!`!(```#66`$`&0```.E8`0`5`````UD!``(````960$`%````!Q9`0`(
M````,5D!``X````Z60$`"@```$E9`0`0````5%D!``8```!E60$`#@```&Q9
M`0`4````>UD!``@```"060$`!````)E9`0`&````GED!``(```"E60$`%P``
M`*A9`0`*````P%D!``@```#+60$`$P```-19`0`$````Z%D!``8```#M60$`
M#@```/19`0`#`````UH!``@````'6@$`!````!!:`0`$````%5H!``@````:
M6@$`!````"-:`0`$````*%H!`!`````M6@$`!````#Y:`0`$````0UH!``0`
M``!(6@$`!````$U:`0`$````4EH!`#0```!76@$`#0```(Q:`0`'````FEH!
M``@```"B6@$`#````*M:`0`R````N%H!``D```#K6@$`"@```/5:`0`;````
M`%L!`"D````<6P$`&@```$9;`0`&````85L!`!\```!H6P$`%````(A;`0`-
M````G5L!``0```"K6P$`%P```+!;`0`$````R%L!``P```#-6P$`!````-I;
M`0`7````WUL!`!@```#W6P$`%0```!!<`0`9````)EP!`!<```!`7`$`%P``
M`%A<`0`2````<%P!`!0```"#7`$`%````)A<`0`0````K5P!`!8```"^7`$`
M(@```-5<`0`4````^%P!`!,````-70$`%0```"%=`0`2````-UT!`!0```!*
M70$`%@```%]=`0`=````=ET!`!4```"470$`%P```*I=`0`9````PET!`!(`
M``#<70$`$@```.]=`0`=`````EX!`!4````@7@$`#````#9>`0`7````0UX!
M`!(```!;7@$`%@```&Y>`0`,````A5X!`$L```"27@$`)P```-Y>`0`2````
M!E\!`!0````97P$`%````"Y?`0`8````0U\!``T```!<7P$`$@```&I?`0`3
M````?5\!`!$```"17P$`%0```*-?`0`9````N5\!`!0```#37P$`3````.A?
M`0`6````-6`!``X```!,8`$`$@```%M@`0`4````;F`!`!D```"#8`$`*@``
M`)U@`0`M````R&`!``8```#V8`$`!````/U@`0`$`````F$!``0````'80$`
M#`````QA`0`,````&6$!``P````F80$`#````#-A`0`*````0&$!`!(```!+
M80$`"P```%YA`0`(````:F$!``@```!S80$`"````'QA`0`,````A6$!``@`
M``"280$`#````)MA`0`*````J&$!`!\```"S80$`!````--A`0`$````V&$!
M`!$```#=80$`$0```.]A`0`7`````6(!`!H````98@$`&P```#1B`0`"````
M4&(!`%4```!38@$`!````*EB`0`,````KF(!``H```"[8@$`!````,9B`0`(
M````RV(!``@```#48@$`!````-UB`0`*````XF(!``8```#M8@$`"@```/1B
M`0`(````_V(!``0````(8P$`"`````UC`0`.````%F,!`!4````E8P$`!```
M`#MC`0`$````0&,!``H```!%8P$`"````%!C`0`(````66,!``@```!B8P$`
M#@```&MC`0`*````>F,!``@```"%8P$`$@```(YC`0`.````H6,!`"````"P
M8P$`!@```-%C`0`8````V&,!``X```#Q8P$`#`````!D`0`5````#60!``@`
M```C9`$`#@```"QD`0`(````.V0!``0```!$9`$`'0```$ED`0`7````9V0!
M``0```!_9`$`"````(1D`0`6````C60!``H```"D9`$`"````*]D`0`(````
MN&0!``0```#!9`$`$0```,9D`0`(````V&0!``X```#A9`$`#@```/!D`0`(
M````_V0!``@````(90$`$0```!%E`0`&````(V4!`!P````J90$`*0```$=E
M`0`3````<64!`",```"%90$`$P```*EE`0`$````O64!``<```#"90$`'```
M`,IE`0`*````YV4!``0```#R90$`"````/=E`0`$`````&8!`!(````%9@$`
M!````!AF`0`(````'68!``@````F9@$`"````"]F`0`(````.&8!``P```!!
M9@$`"````$YF`0`.````5V8!``P```!F9@$`!````'-F`0`,````>&8!`!8`
M``"%9@$`!P```)QF`0`(````I&8!``P```"M9@$`%0```+IF`0`,````T&8!
M`!,```#=9@$`"````/%F`0`)````^F8!``D````$9P$`#`````YG`0`J````
M&V<!`!,```!&9P$`"````%IG`0`*````8V<!`#P```!N9P$`$@```*MG`0`>
M````OF<!`!0```#=9P$`!````/)G`0`4````]V<!`!L````,:`$`&P```"AH
M`0`6````1&@!`!<```!;:`$`%0```'-H`0`2````B6@!`!,```"<:`$`!```
M`+!H`0`-````M6@!``H```##:`$`"0```,YH`0`*````V&@!``D```#C:`$`
M"````.UH`0`*````]F@!``D````!:0$`!P````MI`0`$````$VD!``0````8
M:0$`"@```!UI`0`(````*&D!``8````Q:0$`!@```#AI`0`(````/VD!``T`
M``!(:0$`$````%9I`0`7````9VD!`!8```!_:0$`$````)9I`0`0````IVD!
M`!L```"X:0$`$````-1I`0`,````Y6D!``0```#R:0$`+@```/=I`0`-````
M)FH!``D````T:@$`!````#YJ`0`$````0VH!``0```!(:@$`!````$UJ`0`&
M````4FH!``8```!9:@$`"````&!J`0`(````:6H!``L```!R:@$`$P```'YJ
M`0`1````DFH!``@```"D:@$`"````*UJ`0`(````MFH!``@```"_:@$`%0``
M`,AJ`0`&````WFH!``X```#E:@$`!@```/1J`0`$````^VH!``@`````:P$`
M"`````EK`0`$````$FL!``(````7:P$`#@```!IK`0`(````*6L!``0````R
M:P$`&P```#=K`0`.````4VL!`$X```!B:P$`"@```+%K`0`$````O&L!``0`
M``#!:P$`"````,9K`0`$````SVL!``8```#4:P$`!````-MK`0`(````X&L!
M``8```#I:P$`!````/!K`0`-````]6L!`!0````#;`$`&@```!AL`0`A````
M,VP!`!L```!5;`$`!@```'%L`0`"````>&P!``@```![;`$`!````(1L`0`$
M````B6P!``P```".;`$`!0```)ML`0`/````H6P!`!(```"Q;`$`$````,1L
M`0`6````U6P!``X```#L;`$`#````/ML`0`4````"&T!``0````=;0$`!```
M`")M`0`&````)VT!``L````N;0$`"P```#IM`0`$````1FT!``T```!+;0$`
M$P```%EM`0`4````;6T!`!(```"";0$`"````)5M`0`0````GFT!`"D```"O
M;0$`&P```-EM`0`;````]6T!``0````1;@$`%0```!9N`0`+````+&X!`!0`
M```X;@$`"````$UN`0`(````5FX!``@```!?;@$`#P```&AN`0`@````>&X!
M``\```"9;@$`#````*EN`0`1````MFX!``P```#(;@$`"0```-5N`0`"````
MWVX!``0```#B;@$`!````.=N`0`A````[&X!``8````.;P$`%P```!5O`0`$
M````+6\!``0````R;P$`#@```#=O`0`$````1F\!``0```!+;P$`$0```%!O
M`0`"````8F\!``0```!E;P$`$0```&IO`0`"````?&\!``@```!_;P$`!@``
M`(AO`0`(````CV\!`!,```"8;P$`$````*QO`0`%````O6\!`#````##;P$`
M'@```/1O`0`L````$W`!`"$```!`<`$`+@```&)P`0`F````D7`!`"$```"X
M<`$`,0```-IP`0`A````#'$!`!T````N<0$`'````$QQ`0`&````:7$!``@`
M``!P<0$`!0```'EQ`0`6````?W$!`!4```"6<0$`#0```*QQ`0`1````NG$!
M``0```#,<0$`!@```-%Q`0`(````V'$!`!````#A<0$`%0```/)Q`0`5````
M"'(!`!T````><@$`!P```#QR`0`0````1'(!`"````!5<@$`#@```'9R`0`.
M````A7(!``8```"4<@$`"````)MR`0`*````I'(!``\```"O<@$`,````+]R
M`0!I````\'(!`#X```!:<P$`"0```)ES`0`(````HW,!``D```"L<P$`#```
M`+9S`0`-````PW,!``@```#1<P$`!````-IS`0`-````WW,!``P```#M<P$`
M"0```/IS`0`.````!'0!`!,````3=`$`&@```"=T`0!&````0G0!``@```")
M=`$`#````))T`0`*````GW0!`!````"J=`$`!````+MT`0`$````P'0!``T`
M``#%=`$`$````--T`0`(````Y'0!``@```#M=`$`#````/9T`0`0`````W4!
M`!P````4=0$`'````#%U`0`8````3G4!`!@```!G=0$`&@```(!U`0`:````
MFW4!``X```"V=0$`&P```,5U`0`0````X74!`!````#R=0$`#@````-V`0`.
M````$G8!``@````A=@$`#@```"IV`0`.````.78!``P```!(=@$`#````%5V
M`0`/````8G8!``T```!R=@$`$0```(!V`0`A````DG8!``D```"T=@$`!```
M`+YV`0`&````PW8!`!L```#*=@$`$````.9V`0`/````]W8!``\````'=P$`
M#P```!=W`0`.````)W<!``X````V=P$`#0```$5W`0`+````4W<!`!````!?
M=P$`%@```'!W`0`3````AW<!``T```";=P$`$0```*EW`0`-````NW<!``\`
M``#)=P$`$0```-EW`0`/````ZW<!``\```#[=P$`$0````MX`0`$````'7@!
M``@````B>`$`(````"MX`0`-````3'@!`!````!:>`$`$@```&MX`0`(````
M?G@!``\```"'>`$`!@```)=X`0`$````GG@!``X```"C>`$`$````+)X`0`$
M````PW@!``P```#(>`$`$@```-5X`0`&````Z'@!``T```#O>`$`!````/UX
M`0`$`````GD!``0````'>0$`!`````QY`0`(````$7D!``@````:>0$`"```
M`"-Y`0`*````+'D!``H````W>0$`#````$)Y`0`2````3WD!``@```!B>0$`
M"````&MY`0`(````='D!``@```!]>0$`"````(9Y`0`(````CWD!`"@```"8
M>0$`!````,%Y`0`3````QGD!`"T```#:>0$`&0````AZ`0`-````(GH!``\`
M```P>@$`"@```$!Z`0`*````2WH!``0```!6>@$`)P```%MZ`0`&````@WH!
M`!(```"*>@$`!@```)UZ`0`)````I'H!``X```"N>@$`%````+UZ`0`6````
MTGH!`!$```#I>@$`!````/MZ`0`(`````'L!`!`````)>P$`!````!I[`0`(
M````'WL!``8````H>P$`$````"][`0`2````0'L!`!\```!3>P$`&@```'-[
M`0`$````CGL!``0```"3>P$`"````)A[`0`(````H7L!``8```"J>P$`"```
M`+%[`0`$````NGL!``8```"_>P$`!@```,9[`0`$````S7L!``D```#2>P$`
M(````-Q[`0`$````_7L!`!\````"?`$`"@```")\`0`,````+7P!``@````Z
M?`$`#P```$-\`0`-````4WP!`!$```!A?`$`#P```'-\`0`/````@WP!``T`
M``"3?`$`$0```*%\`0`0````LWP!`!(```#$?`$`%@```-=\`0`$````[GP!
M`!(```#S?`$`"0````9]`0`*````$'T!``H````;?0$`!````"9]`0`$````
M*WT!``0````P?0$`!````#5]`0`(````.GT!`"T```!#?0$`"0```'%]`0`$
M````>WT!``0```"`?0$``@```(5]`0`,````B'T!``P```"5?0$`#````*)]
M`0`3````KWT!``(```##?0$`"````,9]`0`;````SWT!``,```#K?0$`#```
M`.]]`0`Y````_'T!`!<````V?@$`!````$Y^`0`$````4WX!``@```!8?@$`
M#0```&%^`0`/````;WX!`!,```!_?@$`$P```)-^`0`+````IWX!``X```"S
M?@$`(````,)^`0`*````XWX!``T```#N?@$`!````/Q^`0`$`````7\!`!(`
M```&?P$`)````!E_`0`=````/G\!`!<```!<?P$`"@```'1_`0`7````?W\!
M`!0```"7?P$`#P```*Q_`0`7````O'\!`!@```#4?P$`%P```.U_`0`,````
M!8`!``P````2@`$`!````!^``0`2````)(`!``0````W@`$`!````#R``0`)
M````08`!``H```!+@`$`!````%:``0`N````6X`!``L```"*@`$`"````):`
M`0`3````GX`!`"L```"S@`$`$0```-^``0`$````\8`!`!(```#V@`$`&@``
M``F!`0`$````)($!``\````I@0$`+@```#F!`0`$````:($!``D```!M@0$`
M&````'>!`0`7````D($!`!0```"H@0$`!````+V!`0`$````PH$!`!X```#'
M@0$`-0```.:!`0`0````'((!`!P````M@@$`$````$J"`0`&````6X(!``@`
M``!B@@$`!````&N"`0`(````<((!``@```!Y@@$`!````(*"`0`?````AX(!
M``\```"G@@$`#P```+>"`0`&````QX(!``0```#.@@$`"````-."`0`$````
MW((!`",```#A@@$`!@````6#`0`(````#(,!``@````5@P$`"````!Z#`0`$
M````)X,!``0````L@P$`!````#&#`0`$````-H,!``0````[@P$`!````$"#
M`0`5````18,!`!````!;@P$`!````&R#`0`(````<8,!``P```!Z@P$`"```
M`(>#`0`0````D(,!``X```"A@P$`"P```+"#`0`$````O(,!`!(```#!@P$`
M#````-2#`0`.````X8,!`!(```#P@P$`(P````.$`0`5````)X0!`!4````]
MA`$`%0```%.$`0`1````:80!`!$```![A`$`%P```(V$`0`3````I80!`!$`
M``"YA`$`"````,N$`0`$````U(0!`!P```#9A`$`"````/:$`0`)````_X0!
M``0````)A0$`%0````Z%`0`4````)(4!``8````YA0$`$0```$"%`0`-````
M4H4!``\```!@A0$`!````'"%`0`(````=84!``8```!^A0$`"@```(6%`0`&
M````D(4!`!0```"7A0$`#````*R%`0`2````N84!``0```#,A0$`#0```-&%
M`0`"````WX4!`!D```#BA0$`&@```/R%`0`-````%X8!`!H````EA@$`(0``
M`$"&`0`)````8H8!`!L```!LA@$`%P```(B&`0`<````H(8!`!L```"]A@$`
M(````-F&`0`+````^H8!``L````&AP$`"@```!*'`0`+````'8<!`!`````I
MAP$`$0```#J'`0`+````3(<!``L```!8AP$`"P```&2'`0`;````<(<!`!L`
M``",AP$`'P```*B'`0`<````R(<!`!T```#EAP$`&@````.(`0!(````'H@!
M`!,```!GB`$`#@```'N(`0`&````BH@!`!4```"1B`$`!@```*>(`0`(````
MKH@!`!,```"WB`$`%P```,N(`0`7````XX@!``8```#[B`$`*P````*)`0`M
M````+HD!``(```!<B0$`$0```%^)`0`6````<8D!`!D```"(B0$`!@```**)
M`0`8````J8D!``T```#"B0$`!@```-")`0`&````UXD!``P```#>B0$`#0``
M`.N)`0`&````^8D!``@`````B@$`!@````F*`0`2````$(H!``8````CB@$`
M!````"J*`0`&````+XH!``@````VB@$`!````#^*`0`9````1(H!``(```!>
MB@$`!````&&*`0`*````9HH!``8```!QB@$`!````'B*`0`&````?8H!`!<`
M``"$B@$`!@```)R*`0`,````HXH!``L```"PB@$`(P```+R*`0`3````X(H!
M`"8```#TB@$`#@```!N+`0`M````*HL!`!(```!8BP$`"````&N+`0`$````
M=(L!``8```!YBP$`"````("+`0`$````B8L!``@```".BP$`!````)>+`0`0
M````G(L!`!0```"MBP$`!````,*+`0`(````QXL!``H```#0BP$`#0```-N+
M`0`0````Z8L!``P```#ZBP$`#`````>,`0`,````%(P!`!8````AC`$`"@``
M`#B,`0`(````0XP!``@```!,C`$`"````%6,`0`(````7HP!``@```!GC`$`
M!@```'",`0`(````=XP!`!0```"`C`$`"@```)6,`0`$````H(P!`!,```"E
MC`$`#````+F,`0`P````QHP!``\```#WC`$`(0````>-`0`1````*8T!``0`
M```[C0$`!````$"-`0`-````18T!``H```!3C0$`'0```%Z-`0`(````?(T!
M``4```"%C0$`!@```(N-`0`-````DHT!``0```"@C0$`!````*6-`0`$````
MJHT!``H```"OC0$`!````+J-`0`&````OXT!``P```#&C0$`$P```-.-`0`$
M````YXT!`!,```#LC0$`"`````".`0`$````"8X!``@````.C@$`!````!>.
M`0`+````'(X!``0````HC@$`%````"V.`0`$````0HX!``0```!'C@$`"```
M`$R.`0`$````58X!`!````!:C@$`$P```&N.`0`;````?XX!`!4```";C@$`
M%0```+&.`0`8````QXX!`"8```#@C@$`%0````>/`0`1````'8\!`!H````O
MCP$`+@```$J/`0`3````>8\!``T```"-CP$`!````)N/`0`$````H(\!`!$`
M``"ECP$`"````+>/`0`(````P(\!`"L```#)CP$`%@```/6/`0`.````#)`!
M`"D````;D`$`+P```$60`0`$````=9`!``P```!ZD`$`!@```(>0`0`$````
MCI`!`!(```"3D`$`"@```*:0`0`(````L9`!``@```"ZD`$`!````,.0`0`(
M````R)`!``0```#1D`$`"````-:0`0`(````WY`!``P```#HD`$`#````/60
M`0`:`````I$!`!8````=D0$`#````#21`0`$````09$!``@```!&D0$`%@``
M`$^1`0`&````9I$!``(```!MD0$`!@```'"1`0`&````=Y$!``0```!^D0$`
M!@```(.1`0`&````BI$!``@```"1D0$`!````)J1`0`$````GY$!``@```"D
MD0$`)0```*V1`0`R````TY$!``@````&D@$`"`````^2`0`5````&)(!`!4`
M```ND@$`"@```$22`0`*````3Y(!``0```!:D@$`!````%^2`0`*````9)(!
M`"@```!OD@$`!````)B2`0`(````G9(!``@```"FD@$`"````*^2`0`&````
MN)(!`"<```"_D@$`!````.>2`0`4````[)(!``H````!DP$`#@````R3`0`7
M````&Y,!`!$````SDP$`&@```$63`0`7````8),!`!4```!XDP$`"````(Z3
M`0`$````EY,!``@```"<DP$`#0```*63`0`0````LY,!``0```#$DP$`"```
M`,F3`0`.````TI,!`!(```#ADP$`"````/23`0`.````_9,!``0````,E`$`
M!````!&4`0`(````%I0!``8````?E`$`"P```":4`0`$````,I0!`!(````W
ME`$`"P```$J4`0`0````5I0!`!````!GE`$`!@```'B4`0`&````?Y0!``(`
M``"&E`$`!````(F4`0`,````CI0!``@```";E`$`!@```*24`0`$````JY0!
M`!L```"PE`$`#P```,R4`0`/````W)0!`!8```#LE`$`#@````.5`0`$````
M$I4!``H````7E0$`"@```"*5`0`$````+94!``P````RE0$`!@```#^5`0`7
M````1I4!`"P```!>E0$`%@```(N5`0`9````HI4!`#,```"\E0$`$@```/"5
M`0`2`````Y8!`!4````6E@$`*````"R6`0`*````598!`!L```!@E@$`!```
M`'R6`0`)````@98!``<```"+E@$`"````).6`0`X````G)8!``\```#5E@$`
M%P```.66`0`(````_98!``0````&EP$`!`````N7`0`(````$)<!``@````9
MEP$`#````"*7`0`4````+Y<!`!(```!$EP$`#@```%>7`0`6````9I<!``@`
M``!]EP$`$0```(:7`0`,````F)<!``8```"EEP$`0P```*R7`0`-````\)<!
M`!$```#^EP$`%0```!"8`0`-````)I@!`!$````TF`$`%P```$:8`0`0````
M7I@!``T```!OF`$`#````'V8`0`(````BI@!`!(```"3F`$`"````*:8`0`$
M````KY@!`"P```"TF`$`!````.&8`0`;````YI@!``@````"F0$`#P````N9
M`0`$````&YD!``@````@F0$`*````"F9`0`A````4ID!`",```!TF0$`.@``
M`)B9`0`$````TYD!``P```#8F0$`'````.69`0`3`````IH!``0````6F@$`
M"````!N:`0`A````))H!``0```!&F@$`'P```$N:`0`@````:YH!``H```",
MF@$`%````)>:`0`5````K)H!`!8```#"F@$`%````-F:`0`2````[IH!`!0`
M```!FP$`"````!:;`0`(````'YL!``@````HFP$`"````#&;`0`*````.IL!
M``0```!%FP$`%P```$J;`0`$````8IL!``0```!GFP$`"````&R;`0`2````
M=9L!``0```"(FP$`"````(V;`0`3````EIL!`!4```"JFP$``@```,";`0`$
M````PYL!``0```#(FP$`"````,V;`0`(````UIL!``H```#?FP$`'````.J;
M`0`2````!YP!``8````:G`$`#````"&<`0`(````+IP!`!,````WG`$`$0``
M`$N<`0`L````79P!``8```"*G`$`!@```)&<`0`$````F)P!``H```"=G`$`
M#@```*B<`0`(````MYP!``P```#`G`$`"````,V<`0`(````UIP!``8```#?
MG`$`!````.:<`0`4````ZYP!``0`````G0$`"@````6=`0`(````$)T!``(`
M```9G0$`!````!R=`0`(````(9T!``0````JG0$`!@```"^=`0`&````-IT!
M`!@````]G0$`"@```%:=`0`&````89T!`!$```!HG0$`!````'J=`0`$````
M?YT!`#\```"$G0$`!````,2=`0`$````R9T!`!D```#.G0$`)0```.B=`0`/
M````#IX!`!@````>G@$`)0```#>>`0`5````79X!`!@```!SG@$`#P```(R>
M`0`/````G)X!``P```"LG@$`!````+F>`0`$````OIX!``0```##G@$``@``
M`,B>`0`$````RYX!``D```#0G@$`!@```-J>`0`$````X9X!``8```#FG@$`
M!````.V>`0`$````\IX!`!$```#WG@$`!`````F?`0`6````#I\!`!0````E
MGP$`#0```#J?`0`2````2)\!``X```!;GP$`#````&J?`0`4````=Y\!`!T`
M``",GP$`!````*J?`0`(````KY\!``0```"XGP$`#````+V?`0`0````RI\!
M``0```#;GP$`"````."?`0`(````Z9\!``0```#RGP$`!````/>?`0`5````
M_)\!`"<````2H`$`!0```#J@`0`(````0*`!``@```!)H`$`$@```%*@`0`$
M````9:`!``8```!JH`$`(0```'&@`0`0````DZ`!``@```"DH`$`!````*V@
M`0`&````LJ`!``@```"YH`$`#````,*@`0`&````SZ`!``X```#6H`$`#P``
M`.6@`0`8````]:`!`"$````.H0$`%````#"A`0`<````1:$!`!8```!BH0$`
M.P```'FA`0`&````M:$!`"8```"\H0$`'P```..A`0`H`````Z(!`#H````L
MH@$`#P```&>B`0`;````=Z(!`!T```"3H@$`'0```+&B`0`3````SZ(!`!$`
M``#CH@$`&0```/6B`0`5````#Z,!``8````EHP$`,````"RC`0!E````7:,!
M`!X```##HP$`#P```.*C`0`O````\J,!`#$````BI`$`+P```%2D`0`5````
MA*0!``@```":I`$`!@```*.D`0`9````JJ0!`!<```#$I`$`%P```-RD`0`6
M````]*0!`!,````+I0$`$P```!^E`0`=````,Z4!``@```!1I0$`!@```%JE
M`0`?````8:4!`!,```"!I0$`&0```)6E`0`8````KZ4!``T```#(I0$`$0``
M`-:E`0!"````Z*4!`"0````KI@$`)0```%"F`0`?````=J8!`!P```"6I@$`
M)````+.F`0`Y````V*8!`"\````2IP$`%P```$*G`0`;````6J<!`"(```!V
MIP$`.````)FG`0`Q````TJ<!`"L````$J`$`*0```#"H`0`E````6J@!`!X`
M``"`J`$`'@```)^H`0`;````OJ@!`!$```#:J`$`&0```.RH`0`;````!JD!
M`!L````BJ0$`)````#ZI`0`/````8ZD!`#T```!SJ0$`$P```+&I`0`(````
MQ:D!`&H```#.J0$`,P```#FJ`0`3````;:H!`"T```"!J@$`%P```*^J`0`/
M````QZH!`"0```#7J@$``@```/RJ`0`(````_ZH!``0````(JP$`"`````VK
M`0`(````%JL!``@````?JP$`"P```"BK`0`$````-*L!``\````YJP$`!@``
M`$FK`0!+````4*L!``0```"<JP$`"P```*&K`0`+````K:L!``<```"YJP$`
M!````,&K`0`,````QJL!``0```#3JP$`$0```-BK`0`.````ZJL!``8```#Y
MJP$`!@````"L`0`2````!ZP!``\````:K`$`%0```"JL`0`,````0*P!`!@`
M``!-K`$`#P```&:L`0`.````=JP!``P```"%K`$`!````)*L`0`%````EZP!
M``\```"=K`$`$````*VL`0`2````OJP!`!\```#1K`$`'@```/&L`0`?````
M$*T!``X````PK0$`%@```#^M`0`9````5JT!`!0```!PK0$`$@```(6M`0`2
M````F*T!`!<```"KK0$`$@```,.M`0`2````UJT!`!<```#IK0$`&`````&N
M`0`1````&JX!`!T````LK@$`$0```$JN`0`:````7*X!`!$```!WK@$`$@``
M`(FN`0`6````G*X!`!<```"SK@$`$@```,NN`0`7````WJX!`!4```#VK@$`
M$P````RO`0`0````(*\!`!$````QKP$`$@```$.O`0`7````5J\!`!(```!N
MKP$`$@```(&O`0`/````E*\!`"8```"DKP$`*0```,NO`0`.````]:\!`!8`
M```$L`$`)P```!NP`0`8````0[`!`!8```!<L`$`'@```'.P`0`?````DK`!
M`!@```"RL`$`$P```,NP`0`2````W[`!`!<```#RL`$`(@````JQ`0`6````
M+;$!`"````!$L0$`!````&6Q`0`(````:K$!``0```!SL0$`'@```'BQ`0`;
M````E[$!``8```"SL0$`#@```+JQ`0`G````R;$!`!4```#QL0$`%`````>R
M`0`D````'+(!``0```!!L@$`!@```$:R`0`E````3;(!`"0```!SL@$`#P``
M`)BR`0`7````J+(!`!(```#`L@$`!@```-.R`0"-````VK(!``@```!HLP$`
M#@```'&S`0`$````@+,!``<```"%LP$`"@```(VS`0`+````F+,!``\```"D
MLP$`!````+2S`0`C````N;,!``P```#=LP$`#````.JS`0`0````][,!``X`
M```(M`$`"````!>T`0`U````(+0!``8```!6M`$`'P```%VT`0`*````?;0!
M``H```"(M`$`"@```).T`0`=````GK0!`!````"\M`$`"@```,VT`0`7````
MV+0!``L```#PM`$`"````/RT`0`/````!;4!`!4````5M0$`$0```"NU`0`$
M````/;4!`!(```!"M0$`!@```%6U`0`8````7+4!``(```!UM0$`"````'BU
M`0`2````@;4!``0```"4M0$`%````)FU`0`D````KK4!``0```#3M0$`"```
M`-BU`0`(````X;4!``@```#JM0$`!0```/.U`0`&````^;4!``\`````M@$`
M#P```!"V`0`'````(+8!``P````HM@$`"@```#6V`0`F````0+8!`",```!G
MM@$`!@```(NV`0`(````DK8!`!T```";M@$`!````+FV`0`;````OK8!``T`
M``#:M@$`$0```.BV`0`$````^K8!``8```#_M@$`"`````:W`0`,````#[<!
M`!`````<MP$`!````"VW`0`$````,K<!``0````WMP$`!````#RW`0`)````
M0;<!``@```!+MP$`$0```%2W`0`2````9K<!`!D```!YMP$`(P```).W`0`/
M````M[<!``\```#'MP$`%@```->W`0`(````[K<!`"(```#WMP$`!````!JX
M`0`3````'[@!`",````SN`$`"````%>X`0`(````8+@!``4```!IN`$`"```
M`&^X`0`"````>+@!``8```![N`$`"````(*X`0`%````B[@!``8```"1N`$`
M!````)BX`0`(````G;@!``0```"FN`$`"@```*NX`0`*````MK@!`#@```#!
MN`$`,````/JX`0`3````*[D!`!,````_N0$`%0```%.Y`0`-````:;D!``(`
M``!WN0$``@```'JY`0`,````?;D!``0```"*N0$`#````(^Y`0`"````G+D!
M``L```"?N0$`/0```*NY`0`9````Z;D!``L````#N@$`(0````^Z`0`A````
M,;H!`"4```!3N@$`"P```'FZ`0!3````A;H!`!<```#9N@$`00```/&Z`0`H
M````,[L!`"$```!<NP$`'````'Z[`0`5````F[L!`!4```"QNP$`%0```,>[
M`0`5````W;L!`!4```#SNP$`$P````F\`0`7````';P!`"(````UO`$`'@``
M`%B\`0`0````=[P!`!<```"(O`$`"````*"\`0!3````J;P!``@```#]O`$`
M5@````:]`0`M````7;T!`%$```"+O0$`&P```-V]`0`V````^;T!`!,````P
MO@$`&0```$2^`0`3````7KX!``D```!RO@$`#P```'R^`0`8````C+X!`!L`
M``"EO@$`#P```,&^`0`2````T;X!`#H```#DO@$`#P```!^_`0`/````+[\!
M`!4````_OP$`#````%6_`0`/````8K\!`!$```!ROP$`"@```(2_`0`*````
MC[\!``L```":OP$`$@```*:_`0`4````N;\!``8```#.OP$`"````-6_`0`*
M````WK\!``@```#IOP$`!@```/*_`0`&````^;\!``T`````P`$`!@````[`
M`0`&````%<`!``T````<P`$`!@```"K``0`&````,<`!``\````XP`$`!@``
M`$C``0`-````3\`!``@```!=P`$`!@```&;``0`&````;<`!`!````!TP`$`
M#````(7``0`$````DL`!``X```"7P`$`"````*;``0`2````K\`!``P```#"
MP`$`"@```,_``0`$````VL`!`!,```#?P`$`!````//``0`#````^,`!``(`
M``#\P`$`$@```/_``0`$````$L$!`!`````7P0$`#0```"C!`0`,````-L$!
M``,```!#P0$``@```$?!`0`$````2L$!``D```!/P0$`"0```%G!`0`&````
M8\$!``8```!JP0$`"````''!`0`$````>L$!`!````!_P0$`!````)#!`0`,
M````E<$!``@```"BP0$`$P```*O!`0`"````O\$!``0```#"P0$`"````,?!
M`0`&````T,$!``P```#7P0$`&@```.3!`0`$````_\$!``8````$P@$`"@``
M``O"`0`%````%L(!``4````<P@$`$````"+"`0`!````304```````#P!@``
M@04``$T$```[!@``P@```)8"``"D!```R`4``#4$``"6`0```````#8`````
M````````````````````L`$``'T#```5!```8P(``)L`````````[0$``*\$
M``#-````N`8```````#@`0``;P0``/$`````````U0``````````````Y`$`
M``````"C!0``7`$``&\&````````20<``%,&``#_`@```````*0%```4`0``
M`````.\!``!,````A@4```````````````<````$``#W!```=`$``",&``";
M!@``@@4```````"F!@``0@0``*X#```_`@``=0$```,%``#]!@``QP``````
M``#E!```1P,``"<#``"4`0``/P4``"$'```^`@``N08``((&``!V!```>`8`
M`$P"```!`P``90```(,```#R`P``<P(``&H"````````V`8```8#``")!@``
M``````L```#D!@```````'D%````````^P(``"$#``#G!@``"````*@#````
M````;P```%X%``````````````````!(!@```````*`"````````)P4``+8&
M```L!```3`,``!("````````\@0````````>!```KP4``!L'``#5`0``+P(`
M`%0%``#,`0```````&`"````````]`8``)P#``!J!@`````````````%!0``
M``````````#H!0``)P8`````````````&```````````````M`,``.4%``"1
M`@````````````!1`0``J@$``*\&``!Z````$`0``-T$```<!```!P8``'L#
M``!$`@``B@0``#<$``!9!0``M0(``$4%``#)`````````/H$```"!P``C0$`
M`&\#``#0!```-0$``&8````2!@```````+\%``"M!@```````)4&``#/`0``
M^08``*P!``#<`P``2`<``),"``#\`@``V@0``-H#```6!0```````$`"``!O
M!0``-P4``&<&``"0````5@,``,@$``#X!0```````!($````````!0(`````
M``"B`@``-`,``&P`````````@@,``/X!````````600``(0#```$````````
M`&,&````````R@````````"3!```?`4``'P````!`@``V`4``#$`````````
M%0<``"$&````````R@0``````````````````$(`````````/`0``&P%``#_
M!@``D`4``#`%````````R0(``&$%`````@``GP8``#<#````````400``"T%
M``",`0``,`````````"%!0``0P8```X%``"1`P``Q@8``,8%``!D`0``F@4`
M````````````L08```H$``!B!@``X@0````````F`0````````````#]````
M_@4``)H#``#G````:P```*$`````````:P8``!4&``"$`0``(@````````#P
M`P``[`0``&T#``!0`P````````````"4!@````````````#"!@``Q08``#4#
M``"D!@``#P4``!@!```N!P````````(!``#H!````````$P!``"2`P``:P0`
M``X$`````````````(T$```9````-`$``.L#``"7`P``"0,``+0!``!(!```
M!P0``%<"```&`@``>`4``.0"``!)````M`4``&4&``````````````,```"-
M`@````````````!$`P``)0,``"\%`````````````#$'``"/!````P<``-<`
M``!T!```508```````#$!```10```/4&``!J````"@,``%(#``#`!@``T0``
M`#0%````````80,``.H"``#N````7P```%<&````````1P(``#\'```P`@``
M```````````D`P``C`4``'`````7!0```````-@$```0`0``-@8``$L#```2
M!0``@0,``%P`````````^0$``!,&```?!@```````````````````````'X#
M``#(`@``/@,```````"#`@``W`$``,0!```>`P``O0```%8```"/`@``I@(`
M`!,#``"7!@```````$H'``#9!0```````$(#````````MP4``'@!````````
MS@(``$8#``"4````/P```"\&``":`0``T00``#P%`````````````-X#```&
M!@``>````(4#```V!```[0,`````````````$P```+\#````````'0(`````
M`````````````!4!``"$!@``"P0```````!]!```TP4```````#R!0``*0<`
M`&P&``!!!```^P,``-\#``#J!```004``*D"```-!P``XP$````````J!0``
MQP,``!D#``"]!0``WP8``+D%````````,@(``.("```U!P``_`8```````#\
M`0``'`(```````!Z`0```````'H#```>`@```````&(%``!I!@```````*L%
M````````S04`````````````R0,```T%````````G`(```````",`P``=@,`
M`.(!``"F`0```````-,!````````A0(```````"M!0``"04`````````````
M_@````````!Q`0``#P```.4&````````^@,``+@$````````O08`````````
M````KP,``(X&``#F!```GP0``(<"````````(`<````````"!0``@@0`````
M````````D`$``-0&``#A!@``D@8`````````````&@,``-($``#@````!0``
M`"`!``!)!@``.0,``/(&``"S!@```````"(!``!F!0``,`<``($&```4!P``
M`````/<%```V!0``3`4``'\"``"5`0``1P0```D````=`````````'<````>
M!@```````/T!``"C`@```````$T!```4`P```````$X!````````````````
M```@`P```````'$$``#R`@``%`4``",!````````=08``"H"````````XP0`
M````````````Y`4``!`#``"9!0```````'$%````````Z0$```````"=`0``
M``````<#``!2!@``"00``(L"````````N`(`````````````4@````@"``!E
M`@```````!D&```N`@``7P8````````P`0``@P8``#$%````````BP0`````
M`````````````+0```"-!0``$0$``)P%``"=`P``KP$``'X!```D!@``/@``
M`',%``""`@``50,```````!F`P``7`8``(H&``!1````H`0``*$!````````
M=@```+4$````````'0<````````L`0```````*<#`````````````+$%``!#
M`0```````!\```#%`0``%`0``-8$```0```````````````5!0``0@8`````
M``"&`@``]@````````#F````\P````````!`!```(`(```````#"!0``BP8`
M`-\$````````S`,``.8&``"K`P``(0(```````!F`@```````,T&``!%!```
MW@0``&4$``![`0```P$``(D!``#S`0````````````"V!0```````$P$``"Y
M````_@0``%X&````````/0<`````````````&@$``#<`````````N````#`$
M``"T`@```````.\#`````````````*T"`````````````'D`````````QP8`
M`,D&```U!@``O`$```````#Z!@``+`,``.H%``#(`P``]`0``)`$``!U!```
M`````!\#``#&`@``Q0,``(X```#7!```+00`````````````SP```/@&```H
M!0``/0(``#0$````````,P```/`!``#B`````````(D$````````T`4``*($
M``"0`P``H08``+L$```H!P``3@,``'<&````````M@(``&`#``#T````````
M``````#$`@``S@,```0'``"1!```'`8``"P"``!@!0``'`4``,````!+!```
M'@```)@```"K`````````+4&``````````````````"*`0```````,L!````
M````"@```+X!````````^0,``*H"``#3!@```````%D```#+````X@8`````
M``#G`0```````%X!``#9````2@$``+`$``"I!@```````"8#````````````
M``````"#`P```````(`%``##``````````````"@!0``7P,``(@$````````
M/`8``/8!``#U`0```````$X$``!*````B04``.<%```0!0```````%`%````
M````_`4``#X%``#,`````````$$"````````AP```%@%``!A````7P$``&H%
M````````_0,``"D!``![````4@0``````````````````/L$```L!@``````
M`*\```!Z!```T0,```````#N`0``.`8``!8&``#S!@``SP4``,($``#W`0``
M]P8```````#L`P``/`````````#H`0``%P8``(`"````````5`$``'`&````
M````6@0``-T"``"P`P``J`8``!`"``"U`P``U@```"D```!I`0``B`,`````
M``"F`P``````````````````L00``*X&````````&@0```T```!;`P``2@0`
M`,P$``!7`P``A00``.\$``"3`0``6`(``)P!```C`P```````/`"``!8`0``
M`````,<$```X!0``P`,``)$&```F!@``U@4``)\%````````*@8``&0%``!!
M`````````!P#````````H`$```<'```D!0``````````````````V0(``&,%
M``#E`@``+P,``/,#``#B`P``0P```*P&``!Q`@``7P(``&4#````````T0$`
M`#(!`````````````,,$``#(`0```````%,%````````W````"(#```H````
M`````-0"````````^@$```D'``!W`0``:`````````````````````````"W
M`@```````$`&``"K!```NP8``#($```#!`````4``*X```````````````,"
M``"-`P```````.L"````````!08``&,!```H`0```````%<$````````````
M`&@!````````3@````@#``!5!0```````"@&```,!```L`4```````!F!```
M`````#,#``#9!@```````$X"````````.P0``'0"``"7````<P```%D!``#@
M!0``0@(``%$#``!%`P``0````-T`````````;@$``'P$```+`P``$00``,P"
M``"!!```'P$``%,!``"5!0````````````"I````,0,``'\$``!N!```````
M`*L!``".`P``*P```#L#``!/`P``EP$``$4"````````'P4```````#;`@``
M````````````````30(``,H&``#!`0``G@,``'\```">````IP8``%(%````
M````X`,``%H```!"`0``,@4``,H!``"9````^@4``+@!``"/````80$```P"
M``"E`P``&0<```````#S`@``$@<``.D%``!@`````````"$```!F`0``````
M`!8#````````````````````````&P,``'($``!X`@``K00```````!-!@``
M!@4``#T%````````:P,``.4```#:!@``&0$``+,"``#_`P``G`0``+@%````
M````!`,``&($```E!@```````'T!```F!```)@4``#`#```C!P``P04```@'
M```````````````````8!0``*`(``"H'``!(!0```````/$&``!9`P``50$`
M`*,!```;!0``BP$``*4%`````````````+<```````````````L%````````
M<08``+@#``"R!0```````-(!``"_`0```````(P&``#7!0```````!0```"#
M!```2@(``"(&``!4!@``+0$``#H&``#A!0``8`8``-@!```,!0``E@4``/``
M````````DP4```````!N`P``F0$``)`"``".!``````````````$`@``````
M`!\'````````EP(```````!&!```^0```'4%````````#P$``+L```!J`0``
MO`4``.<#``!!`P``O`8```````!B````^P```.$"``!G!0``(P0``%$"```;
M`@`````````````7!P```08``%H"``!<`@```````)0"````````6P4``!,"
M```J````N@0``&0"```Y!```?0````\$``"G`@``,0$``!,!````````````
M`*T````.`P```````'\&````````/P8``"`%```]`P``0`4``"D$``"H!```
MJ`$``$\!``#/!@```````%,```"/`0``````````````````HP0``*H$````
M`````````$(%```'`0``2`(````````<````GP(``,X%```9`@``<@$`````
M````````+P```%8!```8!```*0,``%X"```M`@``D`8``-P"``#.!@``````
M```````/`P```````*(&``!=!@``5`(``"H#````````=@4``&0```#6`@``
M`````-L````.!@```````&P!``!J!```O00``-0!````````J0$``'D$```X
M`P``6`0``'H&``#\!```Z0```-8&``!&`@``Z````+D$````````]`(```$'
M```6!P```````"T`````````)`$``'(````D````E@```$D!````````G04`
M`(@"``!/````B`8``+,#``#X````N@$``.\````S!0``%0(``.,%````````
M:`,``(<#``#0`@``P`4``&P"```(!```$P4``!T&``#Q`@``W0,``-,"``!;
M`0``*`,``#@!``!>````2P8``%L&````````D@````````#&````500``.H#
M``"H`@``)`(```````#R`0``3@8````````8!@``*P0`````````````````
M`*D#``"C````]@4````````=!```/08```H&``#^`P```04``+4```#F!0``
MR`8``$,%``!C!```A`4``.L!``#N`P``V@```(H#```P!@``!`8```````!'
M!P````````P'``#Q!```OP8```H%``#:!0``-P<``(8`````````9`8`````
M``!5````WP$```0$`````````````.4#```\!P```````-T&````````;`0`
M`+H"``!\!@````````````#G`@``````````````````204``,0%``"?`0``
M`````'L%```K!0``0P(``/4"``!!!@``6@,`````````````U00``#@"```O
M!```D@0```````!Z`@``[P(``.D#```;`0``P@(``+``````````&P0`````
M``#L!@```````#@'``#U!```F`8```P```";!````````*H#``#/`@``W@``
M`-(&```7!```5P4``"$$````````%P,```````!P!````````),```"2`@``
M`````-D#````````$@,``+,%```Q!@``70(``"\'``!P`@``IP$``*<%```/
M!@````````````#8`@``K`,``/\````;!@``YP0``/\$``"]`0```````(`!
M``!9!@``:P$``(X%``#Z`@``6P```%0#``#W`P``1````+D!```[`@``I`,`
M`'`!````````904``!D$``#H`P```````/0%``#!!```)P0``/L!``"O`@``
M\P4``(X"``"=````8@(``*$"``#L`0``&`<``!X'``!R!0``[00``#X&````
M````>08``%T```"[`0``3`8``.\&```3!P```````.8!````````;04``#$$
M``!C`P```@8````````T!P``*P,`````````````K@(`````````````O@(`
M`-$&``!+`0``BP````````!$!````````$D#``"9`P``H@```#<&``#2`P``
MO0,``*(#```'````VP$````````R!@``)04````````&`````````-("``"Y
M`P``VP,``!4```"H!0``(P(```T!````````1P4```````!H!```C`0``(`$
M``````````````L'``!&````.@<``"T&``!0!@```````#L%``#0!@``[P4`
M`.L```"[`@``/@0``&@%``!%`0``6P0``$8&``"T!@``=0,```````"H````
MR@(``%T%````````%P```.H!``!6!```:04``-H"``",`@``8P``````````
M````#`8``+T"````````U0(``/@$````````[`4``#4```!M`0```````',#
M``#.`0``(@0``'`#```Z`````````+X`````````<P$``-0```!!`0``````
M`!H"``!G!```H@4```(```!*!@```````)(!``#K!````````*````"E````
M"P8````````_`0``=P,``%\%``#!`@```````%H&``#*!0``B`4``#P"```=
M!0``AP0``%<`````````FP$``,D$``#>`@```````&H#`````````````'$#
M``"9!@``80(``&T"```@````[@4````````S!P```````*T#``#E`0``.0<`
M`#8#```(!0``Q````%("``"V`P``\0$``,T$````````4`$``#8'````````
M)`0``-D!``#!`P``Y`,``"$!``!0!```DP,``-4&``!8!@``Z08``,T#```D
M!P``````````````````1`<``'$`````````,0(``-(%```^`0``F@0``#H%
M```%!P```````-8#``"Z!@``1`4``"X&``#,!0``FP4```````"@`P``=P4`
M``````!9`@``;00`````````````,P$```````#!`````````&<#``""````
M50(``*X$``"#!0``HP,``)P````I!0``Z0(``*4"``"D`@``30<``"L!``#`
M!```H04`````````````G0(```\'``!#!P``2````'(#``#(````9P$``/@#
M``"F!```*08```````#Q`P```````)<$````````!P4``)@%````````W@8`
M``````!%!@``#@$```````">!0``0`$`````````````FP,``!$"```U!0``
MB0````8!```N`P```@(``$<```"4!```)P$```````##`P``L`8```````#J
M!@``V````+$!```J`0```````#(```!D!```J04``!`'``#*`P``7@,`````
M`````````````*(!````````+0,``#@$``"1``````````````#'`0``L@,`
M`*T!``#M!0```````%`"``!)`@``K@4``.`&``"&`0``5@(`````````````
M(P4``*,&``"D`0``2@4``-L$``"@!@``5`0``(8#``"'!0``GP,``,\$````
M`````````#<"``#J`````````)X"``#)!0```````%H!`````````````,L&
M``"E!@`````````````_`P``(@4``)H```"%!@``?P$`````````````````
M````````````1P$```````!\`0``F`(````````@!```Y``````````6!```
M&`(``!8````4`@``%P(``(4!``#3!```_`,``/X&`````````````.P"````
M``````````````!N````$@$```````#4`P``FP(````#````````WP4``/`%
M`````````````($`````````/`$``$L```"W!```A@0``+X%``"U`0``7`4`
M`&\"```<`0``V00````````&!P``\04``&L"``"V`0```````-$"```)!@``
M/@<```````"/!0```````$@!``"R`@``C0````````#D!````````.@"``!D
M`P``^`(```````"K`@``B@(```````#P!```>P8```````"^`P````````$$
M``"=!```I0$``(<!``#5!0``]@(``&(#``!0````I@```/8#``#+`@``PP(`
M`+<#``#T`0``W`4``,L#``!M!@```````!X%```K!P``+@0`````````````
M1`8``````````````````%\$``#$!@``X`(```````#L`````````"<```!&
M!P```````.$````L!P``(`8``$('``!/!0``?P4``,4$``"5`P```````$4'
M``!,!P``K`4``/X"``"A`P``Y@,``'X"``#Y!```UP$``%0```"P`@``````
M``````#%!0``,P8``*0```"^!@``J@8``'0````-!@``>0(```L"``!H`@``
MPP8``%$&``#\````C@$``%,"``"7!0``&@4``)\````C````-`(``'H%```]
M`0``A`0``#@```#>`0```````&\!```N`````````/L&``!=`P````````P#
M``"[!0``:0```%T!`````````````"4$``"A!```UP(``+L#``#]!```L0(`
M``T#``#]`@``[@(``-X%````````#00```````"9`@````````@!``!<!```
M`````'D#``",```````````````*!P````````````!\`@``AP8``&D$``!N
M!0``P@$`````````````]P(``&X"``!R`@``G`8``-P$``!`!P````````H"
M``!&`0````````````"/`P``````````````````+````#4"``#K!@``J00`
M`#<!``#A!```:0(``%,#``"8!````````.,```#!!@``(@(``%$%```1!0``
MZ`8``!$'``"V````F`,```````!!!P``M`0```````"*````BP4``,X$``"F
M!0```````&$&```1````Q`,``/D"``"$`@``)@```+(``````````````%P#
M```V`0``PP4```````#U`P````````````#A`P``F@8``$,$````````=`,`
M`'0&```V`@```````(`#``!;`@```````!4#````````T``````````0!@``
MIP```"<"```#!@``N@4```$!``#1!0``G@8```D"``#;!@``,P0`````````
M!@``LP$``',&``!A!````````"X%````````.@,``$,#``!G`@``3P0```X"
M``#C`@``[@0``,\#```E`@``.P$`````````````T@````````#=`0``?@8`
M`-P&``"Q````'P(``*L&``#%`@``Z00``.(%```7`0``IP0``!(```#U````
M7@0`````````````N@````````![!````````&X&``"_````]04```4!``!*
M`P``K``````````]````)@<``,<%``#&!```B````',$```O`0``U`4`````
M``"=!@````````````#C`P```@,``!$#````````N@,``"<'``"V!```````
M`+\$```H!```B`$``'<"````````2P<``$`#``"&!@``700```X'``#M````
M-`````,#``":`@``Q@$``'\#````````2P4``-H!``!]`@``^@``````````
M`````````"8"``!T!0``@0(``/8$```<!P``\@```!\$``!X`P``I00`````
M```\`P``B0,``($!````````K`(``.X&``"U!0``.@$``*X!````````_P$`
M``````!@!```````````````````(@<``+($```_!```A0```$D$``"5!```
MD04``/T%``"`!@``RP0``+<&``"R`0``90$``$X%````````#0(``(T&``#4
M!```5@4``!0&``!]!@``J@4``)X$```[!P``.@0``)@!``!K!0``!0,``(,!
M``!B`0``.0(``+<!```1!@``=@8```````````````````\"``"$````UP8`
M``````````````````X```!'!@``B@4``$0!````````^`$``.T"```E!P``
MQP(```L!```Y`0``BP,``/D%``"6`P``:0,``)$!````````E`,``)D$````
M````CP8```````!X!````@0``"H$````````>0$``.$!````````?04``,T"
M``![`@```````#L```#F`@``.0`````````,`0``$P0``(D"````````````
M`&T`````````&`,``+D"``#``0``````````````````O`(``+$#``#S!```
M`````#T$```=`0````````0!``#6`0```````,T!``#0`P```````#0&``"2
M!0``O`0``,(#``!^`````````-<#``!2`0``"0$```8$``!7`0``9P```*P$
M````````=0(``'8!``!P!0``^P4``"P%``#%````+0<``$L"``"`````````
M````````````U0,``%,$``#0`0``3P8``!H&```$!0``O`,``.T&```E`0``
M````````````````*0(``%8&```R!P``'0,``,8#```%!```P`(```<"```A
M!0``6`,``.L%``#?`@``'@$``/<`````````O@0``.`$``!(`P``,@,``$\"
M`````````````'X$````````8`$```````#8`P``,P(`````````````E@8`
M``````#,!@```````)8$````````E`4```````"3!@```````-\```!H!@``
M?@4``$T````9!0```````.,&``"\````&@```&P#``#)`0```````'8"```E
M````=0`````````N`0``W04```H!````````&P```"L"``">`0``6````!H'
M``!-`P``TP```#H"````````1@4````!````````?`,``/8&````````.04`
M`)4`````````L@8``/\%````````PP$``,L%``"S!`````````````"5`@``
M%@$````````6`@``9@8```````!:!0``J@````@&``#.`````````#D&````
M````TP,``'(&`````````````"L&``"S````@@$``'<$``#;!0```````/0#
M``"_`@```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S
M(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@
M`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED
M(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E
M9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E
M871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F
M)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@
M97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E
M<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E
M96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS
M*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q
M=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S
M`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D
M`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E
M;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG
M(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM
M('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H
M;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D
M(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A
M('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G
M92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-
M(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T
M:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O
M=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!
M9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z
M`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD
M(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B
M`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!
M9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`
M061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!
M9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N
M;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D
M960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`
M061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`
M061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I
M80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E
M9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S
M:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E
M($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E
M($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N
M871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R
M<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N
M>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R
M8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N
M(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R
M;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H
M:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B
M+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM
M."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O
M4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O
M:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN
M<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!
M=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N
M9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B
M-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD
M87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P
M9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@
M9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I
M;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)A8VMG<F]U;F0`0F%C:V=R;W5N
M9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U
M<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I
M`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI
M>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O
M9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`
M0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D
M97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`
M0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I
M=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M
M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`
M0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T
M:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL
M92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@
M3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T
M:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN
M9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#
M97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!0
M87-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P
M;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL
M<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W
M;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E
M<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D
M871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L
M;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#
M;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A
M<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K
M97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC
M<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#
M;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS
M`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@
M<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#
M;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N
M9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P
M=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A
M:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C
M;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O
M;VL@27-L86YD<P!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO
M;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R
M>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&)I;F0@
M=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O
M=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R
M96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P
M9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L
M9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E
M<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`
M0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C
M:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N
M;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N
M(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#
M;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V
M92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T
M:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU
M86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@
M9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F
M;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#
M<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S
M=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I
M;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H
M97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE
M8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!2
M97!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY
M`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!2
M96-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C
M96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT
M`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL
M`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``
M1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@
M8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B
M+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F
M;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T
M`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B
M;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`
M1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$52
M4@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R
M;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E
M<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L
M(%-A;'9A9&]R`$5L96UE;G0N+BX`16UA:6P`16UA:6P@061D<F5S<P!%;6%I
M;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I
M;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A
M9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I
M;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E
M>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R
M`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17%U871O<FEA;"!'=6EN
M96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P
M9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F
M<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@
M(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&
M87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W
M(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&
M:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@
M36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&
M:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`
M1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A
M<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE
M9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&
M;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y
M<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A
M;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA
M`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U
M;&P@3F%M90!'86)O;@!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA
M;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!-87!S
M`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X
M-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`
M1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`
M1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M
M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA
M`$A434P`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA
M<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE
M`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E
M+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(
M;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S
M<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@
M(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U
M:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P
M87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@
M(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ
M;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I
M`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET
M>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E
M<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W
M:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)7VYS97)T(%)O=R!"969O<F4`
M26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E
M>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O
M<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO
M=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R
M+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T
M(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T
M(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z
M`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G
M92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3
M=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN
M7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`
M26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T
M('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R
M<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L
M;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A
M=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV
M86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN
M`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N
M`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A
M;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED
M('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H
M87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N
M:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`
M27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`
M2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E
M<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z
M86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#
M<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+
M97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$55
M0RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!0
M87-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96)A;F]N`$QE9G0`3&5F="!H
M96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B
M($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT
M(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@
M4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO
M=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S
M('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI
M<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T
M+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R
M:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A
M='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE
M(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN
M(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@
M<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE
M9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W
M97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U
M<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`
M36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-
M86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA
M<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W
M:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R
M<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R
M:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S
M86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R
M=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN
M90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I
M<F5D+@!-97-S86=E('1Y<&4`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`
M365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`
M365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE
M`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@
M;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-
M;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@
M4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU
M;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`
M37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!-
M>2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA
M;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD
M<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O
M8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E
M;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-3
M3"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE
M='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L
M961O;FEA`$YE=R!#871E9V]R>0!.97<@365S<V%G92!T;R`E<P!.97<@36]O
M;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S
M<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S
M<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`
M3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`
M3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A
M=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO
M8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A
M9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E
M8VEF:65D+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I
M9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO
M('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/
M+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T
M($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@
M<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G
M;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`
M3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`
M3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F:6-E
M`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD
M('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@
M=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@
M9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@
M9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N
M86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF
M;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG
M:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@
M2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H
M96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@
M4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE
M=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S
M=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T
M`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R
M9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L
M:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI
M<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`
M4&ET8V%I<FX`4&EX96QS`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A
M<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G
M;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I
M=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I
M`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET
M871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E
M(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN
M="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@
M2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I
M8V\`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`
M4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I
M;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O
M<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R
M96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R
M97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O
M<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`
M4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO
M=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V
M92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E
M<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@
M4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O
M($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#
M;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S
M`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T
M:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O
M=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S
M.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O
M;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2
M=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-1
M3"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N
M80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE
M<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@
M5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R
M86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O
M;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@
M9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V
M97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N
M90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD
M(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E
M9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3
M:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E
M;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D
M`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I
M;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-I97)R82!,96]N90!3:6=N('5P`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H
M;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO
M=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI
M80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A
M9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C97(`4W!A8VEN9P!3<&%C:6YG
M(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP
M=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3
M<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@
M;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R
M97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C
M<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S
M(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N
M`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O
M('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3
M=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3
M=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@
M`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE
M`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E
M9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`
M5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%
M87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R
M;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J
M:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`
M5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!4
M96UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S
M2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N
M`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@
M86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@
M1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4
M:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T
M(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F
M;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E
M;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@
M97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R
M86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F
M;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S
M:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A
M=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H
M92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X
M="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S
M8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@
M<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA
M8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA
M;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D
M("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M
M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M
M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@
M<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD
M+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&9I96QD(&ES(')E<75I
M<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N
M`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G
M+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@
M:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V
M:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT
M('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N
M($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I
M="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@
M9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE
M("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W
M:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`
M5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4
M<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4
M=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@
M`%4N5BX@:6YD97@Z(`!54DP`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T
M;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R
M96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I
M;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE
M*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53
M:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD
M;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N
M:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`
M57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T
M:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U
M<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF
M9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P
M=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S
M(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO
M="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S
M+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5
M>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T
M:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`
M5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S
M96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@
M86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I
M970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X
M=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R
M:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL
M:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10
M`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S
M=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E
M8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I
M`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I
M;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES
M=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O
M9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT
M97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8
M-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE
M;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B
M;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@
M:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED
M;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@
M=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N
M(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H
M;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@
M9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@
M82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C
M;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T
M960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@
M8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N
M('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O
M;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO
M=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N
M=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B
M86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E
M<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S
M(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X
M<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`
M6F%M8FEA`%II;6)A8G=E`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!2
M97!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@
M+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?
M0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G
M92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK
M+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E
M='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`
M8V%L96YD87(`8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E
M;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C
M;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<`9&%T82!F;W)M870@97)R;W(`96YT<GD@;F]T(&9O=6YD`&9I;&4`9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M
M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R
M`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M;0!N86UE`&YO="!I
M;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N
M=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R
M;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R
M96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R
M;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L
M96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,2TP-2`Q-3HP
M-"LP.#`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#$M,3(M,C`@,3(Z,#`K,#@P
M,`I,87-T+51R86YS;&%T;W(Z($1A=FED($-H86YG(#QD879I9$!T;78N9V]V
M+G1W/@I,86YG=6%G92U496%M.B!4<F%D:71I;VYA;"!#:&EN97-E(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4))1S4*0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@."UB:70*`"`H)7,@I-&K92D`("BGUK&VP>0@)7,I`"`H
M)7,@I-&DNBD`("BDM:31*0`@**GZI-$I`"`HK%&DT2D`J?,`(B5S(B"DHZQ/
MI$"MTZ78O_T`(B5S(B"DHZQ/I$"MTZ:SKL2JNK_OOMPN`"(E<R(@J7REO*9B
M($A/4D1%(*JZM?FE5<#)*%)E9VES=')Y*:2DLUVI=RX`I^2DHZCL("(E<R(@
M=')E92!R96YD97)E<BX`(B5S(J1WIJBE7*JZI5ND2JCLN'.RU:ATLLZDI"X`
M(B5S(J1WI5ND2L5VK:VH=++.+@`B)7,BJ,.EO*O8I=\Z("5S+@"D=ZC/I<X@
M)2XR9DU"("RN9;9Q("4N,F9-0B`LL]&^;"`H)2XR9B4E*0`E9"`E<R"E2*3.
M("5S`+/,JO&D0*:XL4N]6,7<I_.I\R`E9""DT:ME+@"SS*KQ("5D(*31KO"V
M2+EWL_@`)7,@+2"SQJ?1O_T`)7,@J_ROO@`E<R!+0@`E<R"Z^\5`OMZG0"`M
M(+U4NWL`)7,@LUVI=P`E<R"U^:55`"5S(*90MTZVM:78`"5S(*1WIG.F8@`E
M<R"F8B`E<R`E<P`E<R"D=[1.I%6F0ZC&MK6JNKK[Q4"^WJ=`M$ZZ_"X@O="I
M\Z:YKLFDQ+_OIT&W4:UNOMZG0*JZMK6EV"X`I;*[W:UN("5S`"5S(*3``*?D
MI*.H["`E<RX`("5S(*CL("5S(*9`("5S`"5SJKJS<;!4O_T`)7.JNJ;FJ,:^
MY``E<ZJZL\:GT;_]`"5SJKJKW;_LPZ\`)7,Z("5S`"5S.B"S;ZO*JTBE\Z2C
MI$"I=Z]UI=&K2*2DJKJQ2*7SI$BITK%(M6\N(+W0JF"W3J15ID.ITJ:SJKJZ
M]+CTLW.ULJ:SI6FOX*RJNGRG0:JZK=.D2+CJKL8N`"P@L'VMMR``+""P?:VW
M("5S("5S`"S%W*3&MG&Q<2`E<R"H["`E<P`M+2"_[[[<("TM`#$R(*1PKLFH
M[@`R-""D<*[)J.X`,C0@I'"NR:CN`*17I$"MM@"FN;#/MO2ELK:WK6ZK_*EW
MN.JNQJYWIOBJ0;K=+@"U;Z7-I$:D0*W3Q%FMJZJZO_F[?@"Q_:5;L4NV;*7S
M+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N`+']Q>?#TJ1WP[&SN:JZMFRE
M\RS!V;O=K6ZFLZ1`K=,@4$=0(*2]MGVJ]\9?+@"Q_;C1L4NV;*7S+,'9N]VM
M;J:SI$"MTZ2]MGT@4$=0(*KWQE\LJ'"Q2R!01U`@JO?&7RRE2*3.LW'#]J1F
MI4\N`+']L/6FYK9LI?/#L;.Y+,'9N]VM;J:SI$"MTZ2]MGT@4$=0(*KWQE\L
MJ'"Q2R!01U`@JO?&7RRE2*3.LW'#]J1FI4\N`+']N-&Q2[9LI?,LP=F[W:UN
MIK.D0*W3I+VV?2!334E-12"J]\9?+*APL4L@4TU)344@JO?&7RRE2*3.LW'#
M]J1FI4\N`+']L/6FYK9LI?/#L;.Y+,'9N]VM;J:SI$"MTZ2]MGT@4R]-24U%
M(*KWQE\LJ'"Q2R!3+TU)344@JO?&7RRE2*3.LW'#]J1FI4\N`+']I5NQ2[9L
MI?,LP=F[W:UNIK.D0*W3(%--24U%(*2]MGVJ]\9?+@"DR*MEIK.VLP"DR*ME
MI'"K0@"DR*MEIK.K0@"DR*MEL'VK0@"DR*MEL'VSMP"DR*ME+Z3(J^$`05!)
M(+USN+D`P_:I\[-OK=.]<[_HOKD`P_:I\RXN+@"EOZ15I.@`I;^DI*6A`,5V
MK:VDHZBL++5,JFNKV*7?(%9&4R"EV+_]+@#%=JVMI*.HK"RU3*IKJ]BEWR!6
M1E,@P,FNURX`L6*XN;CJL%0`L6*XN;M0L4N]6`"Q8KBYI'>MX;6R+@"ULK%B
M`+=SO%<`MW.\5Z:XN'.RU0"W<[Q7I&S%=JVM`*9BIKFW<[Q7.@"W<[Q7N'.R
MU0"W<[Q7Q7:MK0"W<[Q7IKBX<[+5J.P@(B5S(@"W<[Q7IKC%=JVMIMPB)7,B
M`+=SO%>D0*W3J,^ESJK,.@"W<[Q7Q.:F[`"W<[Q7I$"MTZ:HK?LZ`+=SO%>Y
M[P"W<[Q7("5S(*RP($UO>FEL;&$@JKJDP*VV`+=SO%>H[*JZLW&P5+_].@"W
M<[Q7J.RGVJJZLW&P5+_]`+=SO%>HSZ7.JLP`I'>W<[Q7("(E<R(@J.RH=++.
MI*0N(*;]M4RJ:[=SO%?#0J5^JKJU^:55N.JP5#H@)7,N`*1WMW.\5R`B)7,B
M(*CLJ'2RSJ2D+B"G0;)[IF*E::5(MFFFYK5NI$JD1BX`MW.\5ZC/I<ZJS*JZ
MI5ROX*78JV6S4</VLZPN`*9AIWT`LW&P5+_]`*:HK+"ZWK)ZK?L@+2"LL*CD
MI4RHSZ7.JLRS7:EWQ7:MK0"ZWK)Z`+QSIVD`069G:&%N:7-T86X@**K\M$FF
MO2D`06QB86YI82`HJORZN*3:I:>HR"D`06QG97)I82`HJORZN*3.IU&HR"D`
MMFRE\Z=/IE<`N>^[]`"Y[[OTI.BFH3H`J=*FLP"ITJ:SI'?%Y\/2JKJHSZ7.
MJLP`J=*FL[ASLM4`J=*FL\5VK:T`I7ZNV+UU`*2YLURF;K18K=.Y<:1LMFRE
M\Z9AIWT`I+FS7,7<I_.VM:78O7.XN:JZJZRZ03\`I'>F<Z9B`,7<I_,@24U3
M4""U;J1*`,7<I_,@24U34""Q2[U8`,7<I_,@24U34""HSZ7.JLP`Q=RG\[EQ
MI&RV;*7SINVG?0#%W*?SO,NJ3P"TP*5.I.6F<@!!;65R:6-A;B!386UO82`H
MK/S$4K#MPL2\KZC(*0"D0*W3M4RNQ*JZK<BS4:C/I<XN`+5OI<VD1J1`K=.E
MO*J^JKJ_^;M^+@!!;F1O<G)A("BF=[E$IM4I`$%N9V]L82`HIG>M]*G4*0!!
M;F=U:6QL82`HIG>F8ZG4KG$I`+#.IE>E3K)ZIG.H^@"UJJ[7`$%N=&%R8W1I
M8V$@**MNMZ6D:K.P*0!!;G1I9W5A(&%N9"!"87)B=61A("BF=[2CI<JN<:3.
MI-JZN*6LN4:N<2D`P+.ESK5[IJ$`P+.ESK5[IJ&R3;/F`,"SI<ZU>Z:AI'>T
M3KK\`*Y-I<ZH[*G2IK.JNJ:XID"HR0"GY:WC`+EWIO2D:J1P`*5\I.L`JORI
MU*="I.4@*%=I;F1O=W,M,3(U-BD`P*/!6<#)I&JD<`#`H\%9P,FF5[K9`*=!
MO52I=ZUNIU*PHR`E<R"JNK7YI56VW"`_`*=!O52I=ZUNIU*PHR`B)7,B(*5(
MI,ZE]*;SJKJFN+ASLM4@/P!!<F=E;G1I;F$@**K\KMJGRBD`07)M96YI82`H
MJ,BL_*6GJ,@I`*C(K/REIZC(I.4@*$%235-#24DM."D`P\"S3@!!<G5B82`H
MJOR^?*3:KG$I`$%S8V5N<VEO;B!)<VQA;F0`I.6F<L/`LTX`J,BL=R^DTZ6M
MK':F8;#/`+#UIN:^WJ=`NOO%0*MEQ>.EW+U4NWNY[[C</P"DP+!TQ.:F[`#`
M?+C5IU*PHZ1`K=.DHZ9SIF*JNKASLM4N`,!\N-6G4K"CI$"MTZ2CIG.F8JJZ
MQ7:MK2X`P'RXU;USO^BD0*W3I*.F<Z9BJKJX<[+5+@#`?+C5O7._Z*1`K=.D
MHZ9SIF*JNJ9`J,DN`,3=J<H`I$NDZP!!=7-T<F%L:6$@*+]$I&JG4:C(*0!!
M=7-T<FEA("BV^*9AIU$I`$%U=&A?8W)Y<W%L.B"GY*2CJ.RITKO=K6ZJNB!I
M;6%P(*FUIOFN3:7S+@!!=71H7V-Y<G5S.B"F^*I!NMVHPZ6\M*.HT;C3MK6D
MY+2I+@!!=71H7V-R>75S.B"GY*2CJ.RITKO=K6ZJNB!I;6%P(*FUIOFN3:7S
M+@!!=71H7V9T<#H@I^2DHZCLJ=*[W:UNJKH@1E10(*FUIOFN3:7S+KW0K:NW
M<[USQ+8@4$A0(*C#I4*E6Z1*("TM96YA8FQE+69T<""_[[:U+*C2IG`@8V]N
M9FEG=7)E("TM96YA8FQE+69T<`!!=71H7VEM87`Z(*?DI*.H[*G2N]VM;JJZ
M($E-05`@J;6F^:Y-I?,N`$%U=&A?:W)B-3H@I^2DHZCLJ=*[W:UNJKH@:W)B
M-2"IM:;YKDVE\RX`075T:%]L9&%P.B"W<[Q7J,^ESJK,LV^VM:5<K^"EV*ME
MJ,.DHZ3DM*FEV+_]JD&PR`!!=71H7VQD87`Z(*=2L*.HSZ7.JLRS;[:UI5RO
MX*78JV6HPZ2CI.2TJ:78O_VJ0;#(`$%U=&A?;&1A<#H@I^2DHZCLJ=*[W:UN
MJKH@3$1!4""IM:;YKDVE\RX`075T:%]L9&%P.B"U3*IKMW.\5ZC/I<ZJS"`E
M<RX@IOBJ0;ZYIE[`LSH`075T:%]L9&%P.B"U3*IKLKZPHZC/I<ZJS"`E<P!!
M=71H7VQD87`Z(+5,JFNG\[=SJ,^ESJK,("5S`$%U=&A?;&1A<#H@I_.W<ZC/
MI<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!L,@`075T:%]M8V%L.B"G
MY*2CJ.RITKO=K6ZJNB!-0T%,(*FUIOFN3:7S+@!!=71H7W-M8F%U=&@Z(*?D
MI*.H[*G2N]VM;JJZ('-M8F%U=&@@J;6F^:Y-I?,N`$E-05`@IOBJ0;ZYQ>?#
MTK_YNWXN`,7GP]*EHK'1+@#%Y\/2I:*QT2X@)7,`4D%$2553(,7GP]*_^;M^
M+@!&5%`@Q>?#TK_YNWXN`%--0B#%Y\/2O_F[?BX`I6FESJJZQ.:F[#H`07IE
M<F)A:6IA;B`HJ,BVZZOTM4TI`*U)M+H`K4FTNL-#IN(`:V5R8F5R;W,@L4N]
M6+_YNWXN`&ME<F)E<F]S(*C/I<ZJS*97NMF_^;M^+@!"86AA;6%S("BDVJNB
ML*@I`$)A:')A:6X@**3:JDPI`*IIP[FJNJ[\I.4@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H("BI<Z5;J=0I`$)A<F)A9&]S("BDVJBIIF@I`*?DI*.H[+G/
MI=REV+_]("(E<R(N`+#RO74`0F5L87)U<P!"96QG:75M("BD\:=1KLDI`$)E
M;&EZ92`HJ*FHO;2U*0!"96YI;B`HJ*FYYRD`0F5R;75D82`HILJ\?;E&*0!"
M:'5T86X@**2CI*8I`*7-I.D`I^2DHZCLP+.ESK5[IJ$B)3(D<R*JNK#/MO0B
M)3$D<R(N`+#/MO2S7:EW`+#/MO2KK+I!`++*Q>D`0F]L:79I82`HK,&G4;K[
MJ,@I`*[1Q=(`KMB]=0"NV+UUI&JD<`"NV+UU`$)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$@**III&BEIZC(I,ZVPL')K?2Z^ZBZ*0"E_K.A`$)O='-W86YA("BJ
M::6^J+HI`*FSLZ$`0F]U=F5T($ES;&%N9`!"<F%Z:6P@**3:IN@I`$)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;2`H
MJ%JUW"D`0G5L9V%R:6$@**M/I5NG4:C(*0"VM:78LL6XN0!"=7)K:6YA($9A
M<V\@**6LM%BOQZIKK\$I`$)U<G5N9&D@*+M:MJFF82D`JJFML;K>LGH`0U)#
M`$-23""DP+.APDD`P'BF<Z[FI+JN92XN+E]E`*?6J/JJ[*ELI,:I?*6\I[FF
MJ"X`IN:HQK[D`+ESK\6MMP!#86UB;V1I82`HK%JN2+GK*0!#86UE<F]O;B`H
ML]BSP;:I*0"U3*IKIMNPRJVKN&VQ2[U8++W0P7"UN*=!JKJH=++.NMZR>JW[
M+@"U3*IKO&>D2L#)KM<@(B5S(@"U3*IKLW.]=:;<($E-05`@IOBJ0;ZY.B`E
M<P"U3*IKMGVQTL#)KM<@(B5S(BX`0V%N861A("BE6ZZSI&HI`*CZKO@`J/JN
M^+#=PT2F7K/X`+5,JFNG4K"CP,FNUR`B)7,B+@"GY*2CJ.R\R*9SI=B__2X`
MK\JDUB`G=&%R9V5T1FEL92<@L-&\QK5,JFO$?L3RLT*R>BX`M4RJ:[*^L*.E
MV+_]("(E<R(N`+5,JFNROK"C.R`E9""MTZ1LMK"D=Z9SIF(N`+5,JFNMJ[+5
MH4.ITK2CJ-&JNK!/O_V\QJ78NU"E_:MEJ=+`>*9SJKJXZJ[&I*.RQ2X`M4RJ
M:[;'L&7"LK!4J.RK_*EWJKJXN;U8+@!#87!E(%9E<F1E("BZ^[QWJ*0I`+NA
MJ?JDY:9R`*3`P_Z[4+S0Q=(`0V%Y;6%N($ES;&%N9',@*+9]L-*X<ZYQ*0"F
MYK#*N7&XW`#`>*9SKN:DNJYE`,!XIG.NYKG4I5(Z`,!XIG.NYJ2ZKF4`P'BF
M<Z[FMJ&V6CH`IN:PRKEQN-P`MNNZN*]3I.4@*$E33RTX.#4Y+3$T*0"X;:2D
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8R`HI*2K1*9`J4VPZBD`I*2\VB`H
M25-/+3@X-3DM,C``OLS#TK+3N&``OLS#TK[6IK.JS`"^S,/2K$:UI@!#:&%D
M("BL9+QW*0"G\Z?O`*?SI^^G0:JZL4N]6`"G\Z?OIT&JNJJZI?ZF5Z5(I,ZF
M7K9LIF&G?2X`I=BK9:JZLUVI=ZC#I;RDY+2IL4N]6,7<I_,N(+W0P7"UN*=!
MJKJZWK)ZK?LN`*9RI+@`P,NL9+-SM;(N+BY?:P!#:&EL92`HM+RG42D`0VAI
M;F$@**2DL.HI`,*RQ>FDI*3E("A'0C(S,3(I`*6_Q>FDI*3E("A":6<U*0"_
M[[[<P+.ESK5[IJ$Z`+_OOMRQ2[U8`+_OOMRD0*W3J,^ESJK,IE>ZV0"DZ;3!
MQ>.EW*3HIJ$Z`+_OOMRVM:78JZRZ0:JZK;>NY@!#:')I<W1M87,@27-L86YD
M("BX=+W/KG$I`*?DI*.H["`E<R"JNL/^IT^I=[AQ+@"TN`"R3;"CMTRS;B!/
M9F9I8V4@O-#%T@"R3;"CK&2XWP"R3;"CJ,^ESJK,.B`E<P"R3;"CJ,^ESJK,
M`+)-L*.HSZ7.JLRJNKCJKL8`L=_"X+2X`*OVM\:YJ\'DI4C$?L3R`$-L:6-K
M871E;&P@LWJY3"!(5%10`,/VLZRU^+6A`+:SMG$`IJVF:+:S`+.Q`$-O8V]S
M("A+965L:6YG*2!)<VQA;F1S`*?IQ7RXZJ[&IZ@`I^G%?,/DK,D`0V]L;VUB
M:6$@**WTK=ND\:C(*0##0Z;B`+W5IN*]3``Q-K9IINS#0Z;BI4Z]6`#$YCH`
MQ.:F[+S0PT0`I62S<0"I4J5/`*?EIKBI4J5/`+7[O=<`NMFI20!#;VUO<F]S
M("BL[+ROP[DI`*2]I7$`N7&XHP#`]+G2`+'XI?,`KG2RIP"[4"!01$$@M'BD
M5ZNLN7&XHRRTO+QZJZRDXK[WI4BDSB!/=71L;V]K(*JZIE"H0K-=J7<N`+-=
MJ7>XZJ[&N4RTP2X`LUVI=R`E<P"]5+M[L4N]6`!#;VYG;R`HK>BJ1RD`0V]N
M9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92`HK>BJ1Z9`J4VP
MZBD`LW.ULJ6BL=$N`+-SM;*EHK'1.B``LW.ULJ;<I+VV?:KWQE^F^*I!OKFN
MR;Y$J=HN`+-SM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^1*G:+B"M[*9=.B`E<R`H
M)7,I`+-SM;*FW"!&5%`@P,FNUZ;XJD&^N:6BL=$N`+-SM;BD2`"P3[_]I'>F
MJ*5<IF&W<[Q7IMRG0:JZLW&P5+_]I*0N`,"CP5G`R:[7JKJDNJYEJZRZ03H@
M`"(E<R(@P,FNUZ2ZKF4`Q'[$\@!#;V]K($ES;&%N9',@**SLITJX<ZYQ*0"]
MQKMS`+W&NW.EHK'1.B`E<P"]QKMS`$-O<W1A(%)I8V$@**WTM+6D:KZDI5LI
M`$-O=&4@9"=)=F]I<F4@*+9(I/JN_*FD*0"U3*IKI4@@4$=0(*5;L4NV;*7S
M.B``M4RJ:Z5((%!'4""P]:;FMFRE\\.QL[DZ(`"U3*IKI4@@4R]-24U%(*5;
ML4NV;*7S+@"U3*IKK+`@4R]-24U%(+9LI?/#L;.Y+@"U3*IKMW.\5[-SM;BD
M2"X@)7,`M4RJ:\.TM;(@3$1!4""F^*I!OKD`M4RJ:\.TM;(@;&1A<""F^*I!
MOKD`M4RJ:\#+K&2W;*]Q+B`E<P"U3*IKLW.ULJ;<(&QD87`@IOBJ0;ZY`+5,
MJFNS<[6RIMRF^*I!OKD@(B5S(B"HSZ7.($944#H@)7,`M4RJ:ZO8I=^P=+AM
MN'.RU2X@)7,`M4RJ:[C1L4L@4$=0(+CJKL8Z(`"U3*IKN-&Q2R!3+TU)344@
MN.JNQBX`M4RJ:Z=2L*.S<[6XI$@N("5S`+5,JFNG4K"CL'2X;;)-L^8N("5S
M`+5,JFNG4K"CI_.W<[5[IJ$@(B5S(BX`M4RJ:ZA-J7>FK*7SI$BJNKEQI&RV
M;*7SINRG?2X`M4RJ:\#RJ/JGN;[CJKJS<;!4O_TN`+5,JFO`\JCZI[F^XZJZ
ML'2X;;)-L^8N`+5,JFO`\JCZL'2X;;)-L^:DI*JZN'.RU2X`M4RJ:[C\I$JU
MIK*D("(E<R(N`+5,JFNKV*7?I=B__2`B)7,B+@"U3*IKIMNJ]\9?IOBJ0;ZY
MJ/JQ;Z2]MGVJ]\9?+@"U3*IKMGVQTB`B)7,B(*5(O&>D2BX`M4RJ:[9]L=(@
M)7,N`+5,JFNV?;'2NOO%0*1UIT"\TK+5("5S`+5,JFNV?;'2I=B__2`B)7,B
M+@"U3*IKLW.QM2!,1$%0(""F^*I!OKDN`+5,JFO%JJCZ("5S+@"U3*IKK:NW
M<[-=J7>HSZ7.JLRJNK%+O5@N(+.AI,"JNK+3N&"DHZ6_O50N(+W0P7"UN*=!
MJKJH=++.NMZR>JW[I4BH\Z=5LT*R>BX`M4RJ:\6JJ/JF<ZCZL;&H[JKM*$%C
M8V5S<R!#;VYT<F]L($QI<W0I`+5,JFO%JJCZLW&P5+_]+B`E<P"U3*IKQ:JH
M^K!TN&VR3:55+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E<P"U3*IKQ:JH^J;X
MJD&^N:JZK-O#]J]3J<H`M4RJ:Z9>M%^S7:EW+@"U3*IKIU*PHZ78O_T@(B5S
M(BX`M4RJ:\!XIG,@)7,@JKJS7:EW+@"U3*IKP'BF<[/&I?>S7:EW+@"U3*IK
MP'BF<[/&I?>S7:EW.B`E<RX`M4RJ:\!XIG.G\[=SM7NFH:CL.B`B)7,B+@"U
M3*IKP'BF<[/&I?>S7:EW("5S+@"U3*IKP'BF<[-=J7?`R25S+B"G0:5II4BH
MSZ7.)7.DI*JZJ.2E3*5<K^#`>*9SLUVI=ZG.I.*PRKW&NW.D5:VQM7NFH;U8
MJ.P@)7,N`+5,JFNW:K1-($Q$05`@(*;XJD&^N2X`M4RJ:Z=2L*,@(B5S(BX`
MM4RJ:Z?SMW.S<[6XI$@N("5S`+5,JFNG\[=SL'2X;;)-I54N("5S`+5,JFO"
MT+QG("(E<R(Z("5S(*JZLUVI=RX`I^2DHZCL($UO>FEL;&$@JKJDP*VV+B"]
MT+U4NWNDP*VVK$^G7[9]L=(N`+5,JFN]X:2IJ,^ESJK,("(E<R(@I%6F0\5V
MK:VH[*M(I?.G6"`B)7,B.B`E<P"GWK-.I7D`L.JN80"]TJKM`*O8I=\`J]BE
MWZ1`K=.S<[6R`*O8I=^D0*W3MW.JN@"KV*7?IKBK2*7SIU@`J]BEWZK,JKK%
M=JVM`*M(I<ZE9+BYO5@`0W)O871I82`HITK#N:;HJ,@I`$-U8F$@**5JI-HI
M`*78JV6W?+3!`*78JV6NR;:A`*78JV6Z]*=]`*78JV6JNJC/I<ZJS`"EV*ME
MI-&N\`"EV*MEJKJJK*IP.B``I=BK9:JZK;>NY@"FVZUQI$"HQ[5NI$HE<ZOA
MJ=*M;K#UIN:JNJ1UIT`N`+#%I%4`L,6D50!#>7!R=7,@*,')M+:PQ[2U*0"F
MZ*B]NKBDY2`H2T])."U2*0"FZ*B]NKBDY2`H5VEN9&]W<RTQ,C4Q*0"FZ*B]
MNKBDY2^O4:=*Q/6DY2`H2T])."U5*0!#>F5C:"!297!U8FQI8R`HL;:G2J9`
MJ4VPZBD`I.D`N.JNQJC3M[VF5[K9("B]T+#1IM(@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0"H0Z3I`+[PJJRXZJ[&PG/$_0"XZJ[&KG>W:K1-`*3IM,$`IJRH[*3I
MM,$`O^^^W*3IM,$`I=6DT0"G4K"CQ.:F[%]L`*11I$>DZP"D4;9IINR\QJ9R
M`+3NI-;!6;'&`+EWLUT`N7>S7<-#IN(`N7>S7:JZJ*VE]\/1IT\`N7>S7:E2
MI4^XT:I2OKDH4VAE;&PI`*EWN'$`IU*PHP"G4K"CP'BF<Z[F`*=2L*.X<[+5
M`*=2L*.L]K_]`*=2L*/%=JVM`*=2L*.A0K)-JL6V;*7S`*=2L*/`>*9SKN8`
MIU*PH\3FINP`IU*PH[)[IG.JNK3`I4Z\RZI/`*=2L*,B)7,BJKK%=JVM`+U4
MJ7>M;J=2L*,B)7,BJKK%=JVMI4BDSJ:XQ7:MK2`_`*=2L*.F0P"G4K"CJ=*_
M[[[<JKJHK:7WP]&G3[CJKL8`IU*PHZ78JV6JNL3FINP`IU*PHZ78JV6JNJ9#
M`*?SMW.U>Z:A("(E<R(@I'>G4K"C+@"[O+!EKLFVH0!$96YM87)K("BDIK/!
M*0"PW<-$M'FM>@"T>:UZ`++3N&`@*+W0L-&FTB!(;W)D92"P3[_]P,FNURDZ
M`++3N&"]T+#1IM*H=++.NMZR>K5NO_TN`*SCM6\`Q5/"2;?%J]<`L\RKX:1`
MI'"NR:JZQ5/"2;?%J]<Z(`#%4\))M\6KUSH@`+%QI:JFW*5K`+%QI6NFW*6J
M`*78O_T`I4@@,C0@I'"NR:CNQ>.EW#\`Q>.EW+_OMK4`Q>.EW+C4LM.JNKEW
ML_@`Q>.EW+EWL_@@*%1!1BD`Q>.EW*[FIJ$`ML>P9:9>L?@`1&II8F]U=&D@
M**9.I:RF82D`I*.G4K"C`*2CK6ZJO;&UIG.H^B!M86EN=&5N86YC92YP:'``
MLL2D0+6GL$^__:Q/IU^E7:=TQ.:F[*97NMD_(*9PJD>L3[W0I,2_[RX`1&]M
M:6YI8V$@**9HJ?JEIZ5;*0!$;VUI;FEC86X@4F5P=6)L:6,@**9HJ?JEIZ5;
MID"I3;#J*0#!V:A3IK.Q8KBYMMP_(+7YI54N`*15N/P`I%6X_"`E<P"D5;C\
MLUVI=\#)KM>E=*9SK+`@4$A0(+5[IJ$N`*15J=2E7*_@JNT`P\2K?@"Y<:1L
MMFRE\P"_^;M^`$5C=6%D;W(@**3,I<JF:+JX*0"]<[_H`+USO^BPS[;T`+US
MO^BX<[+5`+USO^C%=JVM`+USO^C%=JVM`+USO^@E<ZJZQ7:MK0"]<[_HO^^V
MM0"]<[_H(B5S(JJZQ7:MK0"]<[_H)7.JNL5VK:T`L="H?`!%9WEP="`HKDJD
MSBD`16P@4V%L=F%D;W(@*,+$NKBERZ9H*0"DN*7S+BXN`+EQI&RV;*7S`+EQ
MI&RV;*7SINVG?0"Y<:1LMFRE\Z;MIWVELK:WIVNF6"X`N7&D;+9LI?.]5+M[
M`$5M86EL+71O+5--4R"Y:+E$OKD`JNVQH;+%N+D`JL6EU:M(I?,N`*K%I=6U
MLJI'+@"JQ:75MVJT3;:UI=@`I+FS7*;;P\"T6;2AI$JWTZ3YJ.RK2*7SI*0H
MNO2MMKUSO&>\TJ:A*2`_`+'2L,JWQKFKI6O!Y*5<K^"J[3\`M;*G]*9^I?<`
MJ?&D:KUSO^B^N0"F<*I'IT&[W:UNK:NS7;%+O5@LO="_Z:1*I$"MTZ9WI?ZP
MW:5Y+*C2IG`@)Z=!PV2JJZJZIE>ZV2`_)SH`IF*FN;_II$J\=KFSJKJZ]*=]
M`$5Q=6%T;W)I86P@1W5I;F5A("BHJKE$M%BDNJC(*0!%<FET<F5A("BDS*7?
MKU.HO:9W*0"_^;M^`*O8I=^PS[;T)7.NR;5OI<V_^;M^`*=2L*.F4*A"P>/"
M23H@)7,@KLFU;Z7-O_F[?@"G4K"CIE"H0K!/O_TZ("5S(*[)M6^ES;_YNWX`
MQ:JH^J2ZKF4Z)7,@KLFU;Z7-O_F[?@"G\[=SL4N]6#H@)7,@KLFU;Z7-O_F[
M?@"\9Z1*("(E<R(@KLFU;Z7-O_F[?BX`17-T;VYI82`HMU*H1J6GJ,@I`$5T
M:&EO<&EA("BFYZ_!I/&HR"D`NMBQV@!%=7)O<&4@*+S:K'<I`*A#(#$U(*3`
MQ,$`J$,@,B"DP,3!`*A#(#,P(*SMQ,$`J$,@-2"DP,3!`*A#IKBU;J1*`*A#
M(#,P(*3`Q,$`J$,@,2"DP,3!`+UDJ-*MR#H`L/6FY@"N:;9]`*YIMGVXZJ[&
MIZ@`K6ZH1"`G*2<`J.RTP:3I`+C1NZ&M^P"K9;2ZPT.FX@!&5%`@I%>VQ[-=
MJ7<N`,6JJ/JPOJ9NLUVI=Z6BL=$`M4RJ:[-SO76FW"!,1$%0(*;XJD&^N2X`
MM4RJ:[-SO76FW"!334(@IOBJ0;ZY+@"]QKMSI:*QT:;;("(E<R(N`+W&NW.E
MHK'1J.P@(B5S(BX`M4RJ:ZO8I=^D0*W3MW.JNB!305-,(+-SL;4N`+=HLKZE
MHK'1J.P@(B5S(BX`PEZH^J6BL=$Z("5S`+2VLW$`1F%L:VQA;F0@27-L86YD
M<R"J:\3UITJZUKASKG$@*+"HNKBZ^Z_'M+6X<ZYQ*0!&87)O92!)<VQA;F1S
M`,19K:N_^;M^.@"VQZ]U`+;'KW4`I$>DZP"W4,2Q`+=0Q+$Z(`"D\J3RJT(`
MM76\R+!]L[<`Q.:F[+!]ID,`1FEJ:2`HM+3`V2D`P,FNU[S&I=@Z("5S(*W3
MP,FNUP#`R:[7O,:EV#H@)7,@P,FNUP#`R:[7P6"ZW@#`R:[7IE>ZV0#`R:[7
MO^^^W`#`R:[7I%>VQP#`R:[7I%>VQZ5<K^"EO+-1I.2TJ2X`N4S";[ZY`$9I
M;FQA;F0@**KBQ/4I`*17I6*DZP"D5ZFV`*E4J7>D\:C2`*17I%7$0:W+`*]"
ML,H`P_H`I=B__2`E<R"DHZ9SIF(`IG*KK,-#IN(`K;FJJP"F7:RPPG/$_;ZY
MJ,.EO*3DM*F\=KFSI5ROX"X`KO"V2+EWL_@@*%1!1BD`N7>S^*31O,8@*+EW
ML_BDT;S&I5VL0:75I-&E2*3.J5VVH:JZN.JNQCNF<*I'N7>S^*31O,:X^ZKX
ML4ZF^Z7.I/&X^[QEM%2JNJJIK;$I`*?1L$^Q2[U8(#\`JNVSY@"D<+MY`*1P
MNWG#_JNL`*1PNWD`I'"[>2`R`+W7OL(`IMNPRL+@JT@`K%"TP:2M`*[8K%L`
M1G)A;F-E("BJ:[#J*0!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I
M86YA("BJ:\3=NURHR*BZ*0!&<F5N8V@@4&]L>6YE<VEA("BJ:\3=K,&G4:6G
MINBHR"D`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`+%(I?.D2`"Q<0"G
MN;[CM'FM>@"ZH:3K`*7^IE<`1V%B;VX@**5;M%XI`,/`M%DZ`$=A;6)I82`H
MI<RD\:C(*0"RHZ7-("5S(*W3J'2RSK-=J7<`I'>RHZ7-JKJS7:EWN.JNQ@!'
M96]R9VEA("BS[*IVJ,BF0*E-L.HI`$=E<FUA;GD@*+QWL.HI`$=H86YA("BM
M>Z_'*0!':6)R86QT87(@**J]I:S#N:K[*0"F5[K9`*MEJ;D`K?2\=[JX`$=O
M;V=L92"F8;G/`$=O;V=L92"W:K1-`*;'MJ4`1W)E96-E("BGQL.^*0"GQL.^
MI.4@*$E33RTX.#4Y+3<I`$=R965N;&%N9"`HKN:SKL3UKG$I`&=R96YA9&$@
M**[FM^>OQ[E&*0"X<[+5NMZR>@"X<[+5IE>ZV:2CL6^JQ:75`$=R;W5P7VQD
M87`Z(+5,JFNW<[Q7N'.RU2`E<RX@IOBJ0;ZYIE[`LSH@`$=R;W5P7VQD87`Z
M(+5,JFNG4K"CN'.RU2`E<P!'<F]U<%]L9&%P.B"U3*IKI_.W<[ASLM4@)7,`
MN'.RU0!'=6%D96QO=7!E("BM]+QWK*6TMBD`1W5A;2`HP_:N<2D`1W5A=&5M
M86QA("BERJ9AL*BIU"D`KN:NIJ;HKG$`J-.[J\5VK:T`LUBKR*]DJ*4`1W5I
M;F5A("BT6*2ZJ,@I`$=U:6YE82U":7-S874@*+18I+JHR*3QK\&F0*E-L.HI
M`$=U>6%N82`HNURHR*BZ*0"V5Z3ELW.ULKMYJ*4`I^2DHZCL($A45%`@Q>?#
MTBX`2&%I=&D@**[\IF$I`,+XM.HMNG2ZX@#&1P"J[<!9`*KMP%D`2&5A<F0@
M27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`*1JN7"K0@"GQJ="J-.DY2`H
M25-/+3@X-3DM."U)*0"PJJO7`+NAJ?H`O7._Z+ZYJ,^ESKNAJ?H`NZ&I^@"E
M8K)Y`+-ON,RL3\#)KM>JNK9]J6PZ`+"J`*YA7VT`2&]L>2!3964@*+'KO\VI
MHRD`KF$`INVN8:9AIWT`KF&EV+_]`*;MKF&Y<;C<`$AO;F1U<F%S("BGN[.C
MJ=2TM2D`2&]N9R!+;VYG("BMN[3D*0!(;W)D90!(;W)D92]+;VQA8CH@MFRE
M\R`E,B1S(*2DN4JH[+5,KL2JNB`E,21S(%A-3+CJKL8`2&]R9&4O2V]L86(Z
M(+5,MFRE\[Y!IEBJJZ7S("5S`$AO<F1E+TMO;&%B.B"V;*7S("4R)',@I*2G
MY*2CJ.RJJZ7SJZRZ02`E,21S`$AO<F1E+TMO;&%B.B"D=Z:HI5RJNK*^L*,@
M)7,@(B5S(@!(;W)D92]+;VQA8CH@ON.F6*1UM7N[W:UN("=D;VUX;6PG(*JZ
M(%!(4""IM:;Y`$AO<F1E+TMO;&%B.B"U3*IKJ]BEWR`E<R"JJZ7SJKH@6$U,
M(+[P`$AO<F1E+TMO;&%B.B"U3*IKLKZPHR`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@M4RJ:\#RJ/JSH:7W("5S(*NLND&JNB!-24U%(,/1IT^XN;U8`$AO
M<F1E+TMO;&%B.B"U3*IKIE"H0B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
MM4RJ:Z90J$*DP*C).B`E<P!(;W)D92]+;VQA8CH@I;RJOJJZI,"HR2`B)7,B
M`*3TI:V]=0"D]*6MN=2E4@"D]*6M.@"G0:9PIO.H[*:Y(#\@*+W0L=2M>B$I
M`*=!K6ZF6*C6IFBDUJW3Q.:F[*E//P#$YJ;LO,:EV*9`K7`_`*=!K6ZF6*C6
MIFBDUJ9#J4\_`+?#J]<`M\.KUSH@`+?&O5VD:JYV`$AU;F=A<GD@**9)I/JG
M42D`24U!4""V;+UCJ]BEWZ6BL=$Z("5S`$E-05`@MFR]8Z=2L*.EHK'1.B`E
M<P!)34%0(+9LO6.ZS[K0L'2X;:O8I=^EHK'1.B`E<P!)4""F[*=]`$E0(*;L
MIWVU3*IKJ,^ESBX`25`@INRG?:C#I*.F8B!#2412(*JZI+FS7+#/MO2DI"X`
MIF*KX:VQM*&D2J9#7VX`26-E;&%N9"`HID*N<2D`K\*YSZ7<`"5SJKJYSZ7<
M`+G/I=RDSJ3EIG(`J*VE]\/1IT^JNJ97NMDZ`*9PJD>U3*IKI;^]5*9AQ>.E
MW"P@)7,@I4BE=+9]L=*V;*7SJ?.W<[7XM:&W[:2D+@"HSZ7.($EN=&5R;F5T
M($5X<&QO<F5R(,)SQ/V^N:[)IG"J1ZA3IK.LW:CLI?2F\ZJZI'"YSZ7<+""G
M0:5IK^"[W:UNI,2_[[-OK=.VM:78I4C#]K.L(%!.1R"\=KFSJKK!],+#KL2J
M1RX`IG"J1ZS=J.RS;ZMHJ%.FL[QVN;.JNK!4KJ<LLV^J[:7<IT&JNL)SQ/V^
MN;5,JFO%XZ7<I%>VQZJZO':YLRX`O':YL[EWQ/TZ`+QVN;.Z]*=]`+QVN;.Z
M]*=].@"\=KFSJ-.FV\/`M%D`O':YLZC3IMO#P+19.@"D5[;'O':YLP"\=KFS
M`+;7I$HL(*A"QDH@)60`MM>D2L3FINPZ("5S`+;7I$K$YJ;L.@"F8JOAK;&T
MH:1*ID-?<P"_Z:1*I*.EO[U4JKJG0*7.O5@N`+W0P,NL9*=!JKJHSZ7.JLRF
M5[K9I,ZQ2[U8`*C/I<ZJS*97NMFDHZ6_O52ISJK,N7&D;+9LI?.F[:=]I'?%
MW*?S+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BX`O%>E6\%9L<8`
M26YD:6$@**9,J]<I`*W3IT^HSZ7.JLP`26YD;VYE<VEA("BF3*6G*0"XZK!4
M`+CJL%0`M4RE::7.JKJXZK!4+@"F8JOAK;&TH:1*Q.:F[%]O`+2AI$JYSZ3Y
M`+2AI$JJ[:[F`+2AI$JZ]+CTLW.UL@"F8JMEK;&TH:1*Q.:F[%]#`*9BI=BK
M9<3FINRKX:VQM*&D2J1`K=.W<\3FINP`IF*EV*MEQ.:F[*MEK;&TH:1*I$"M
MT[=SQ.:F[`"F8J78JV6F0ZOAK;&TH:1*I$"MT[=SID,`IF*EV*MEID.K9:VQ
MM*&D2J1`K=.W<Z9#`*9BI=BK9;A@PDFKX:VQM*&D2J1`K=.L<;BH`*9BI=BK
M9;A@PDFK9:VQM*&D2J1`K=.L<;BH`+2AI$JE:;3`I4Z\RZI/`+=SL4N]6+%.
ML4BU;ZCLLV^MT[9LI?.F8:=].@"F8JOAK;&TH:1*P'BF<Z[F`*9BJV6ML;2A
MI$K`>*9SKN8`IF*KX:VQM*&D2L3FINP`IF*K9:VQM*&D2L3FINP`M*&D2K9L
MI?,`IF*KX:VQM*&D2JQQN*@`IF*K9:VQM*&D2JQQN*@`IF*KX:VQM*&D2J9#
M`*9BJV6ML;2AI$JF0P"F=Z7^L-VE>:JZM:JNUSH`M*&D2B_%W*?SO':YLP"T
MH:1*+\7<I_.Z]+CTLW.UL@#"2;S&I*.HK*5(IMRI\[5,JFNVQ[!EM;FP=+AM
MN'.RU2X`PDF\QJ2CJ*PN`+[CO,8`ON.\QJ9#`+5,KL2JNB!51$@HJ,^ESJK,
MN.JNQJKMP%DI+@"U3*[$JKH@6DE0(+CJKL8N`+5,KL2JNL"SI<ZU>Z:A+@"U
M3*[$JKJGY::XN+F]6"X`L&6E6*JZN.JNQK5,KL0N`+5,KL2JNJ78O-"F[:=]
M`+5,KL2JNL#)KM>NYJ:A`+5,KL2JNK'"Q7:]6"X`M4RNQ*JZIF&PSRX`M4RN
MQ*JZ(&US9U]T>7!E+@"U3*[$JKJISJ?DI*.H["!A<&E?:60N`+5,KL2JNJG.
MI^2DHZCLL-&\QBX`M4RNQ*JZI/?%=JVM+@"U3*[$JKJYV:;QP]&G3[U8+@"U
M3*[$JKJRHZM^O5@N`+5,KL2JNK-QL%2H\ZEW+@"U3*[$JKJFK*7SI$@Z(B5S
M(@"U3*[$JKJDP*C)JJNE\RX`M4RNQ*JZJ-.WO:;MIWTN`+5,KL2JNKA5L.J]
M6+CJKL8N`+CJLJ,`IEZT7[_OOMP`27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B`HI>RNU"D`27)A<2`HI>RIU*=**0!)<F5L86YD("BW4KJXQ/4I`$ES;&4@
M;V8@36%N("BPTJYQ*0"GO;.AN7"K0@!)<W)A96P@**5(IN*F0RD`P[&U;ZK,
M`+'7Q>D`271A;'D@*+AQI&JG42D`2F%M86EC82`HI/JV4J5;*0"D0*3K`$IA
M<&%N("BDZ:6[*0"DZ:3E("A)4T\M,C`R,BU*4"D`OT&FZ*YQ`$IO<F1A;B`H
MK/FEN2D`I$.DZP"DNZ3K`+GON_0`N&VDI`"EJJ5KN>^[]`"^8:6JN>^[]`"^
M8:5KN>^[]`!+87IA:VAS=&%N`*M/KV2M[+S+(#\`2V5N>6$@**K6J,@I`$ME
M<F)E<F]S(+M[P]*_^;M^+@"NUJ3?MW.DX@"J]\9?J]BEWP"J]\9?KU.\>`"J
M]\9?JOBKUP"J]\9?JZRZ00"J]\9?NWFJ:P"EV*MEJKJDO;9]JO?&7Z;XJD&^
MN:2D+*1WN&>F<Z9BIT&JNJKWQE\N`*C@M:,`2VER:6)A=&D@*+#RJ+VDVK2U
M*0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B`HI5_!
M^BD`2V]R96$L(%)E<'5B;&EC(&]F("BK;L'Z*0#!^J3E("A%54,M2U(I`$MU
M=V%I="`HK.RKPJ]3*0!+>7)G>7IS=&%N`*JIK;&P=+AM7WD`NWFHI0!,86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R`HO&2PZBD`I%6E8J3K`+/,
MJO&D0*:XL4N]6,7<I_.I\P"D5:FVI.L`I%>FN*?SMW,Z`*17I$"FN+5NI$HZ
M("5S`*17I$"FN+5NI$HZ("5S(*;;("5S`*17I$"FN+5NI$HZ(++$I$"FN+5N
MI$H`3&%T=FEA("BIU++FNONHR"D`JFNKWP"JJ:VQL'2X;0!,96)A;F]N("B^
MI*3:N>`I`*6JP^0`I:K#Y*KMP%D`I:K#Y*W(`$QE<V]T:&\@*+_@K\&FJRD`
M3&EB97)I82`HO^"D\;?GJ,@I`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$@**=1
MI/&HR"D`3&EE8VAT96YS=&5I;B`HID.DY+2PM+6U;BD`MTRK0@"D<*M"`*:M
MIK.D<*M"`+'?IK.D<*M"`*1PL'VK0@"D<*M"IK.Y<`"D<+.W`*1PL'VSMP"E
MM*ION-8`LW.UL@"S<[6RPDFH[#H`Q>.EW*[)LW.ULK9LI?.F[:=]J.R]<[QG
MMFRE\ZVVK;$`LW.UL@"F0Z58("T@J,^ESJK,I6FE2*S=J.RS;ZW3JTBE\Z=8
M`*9#I5BXZJ[&KG<`ID.E6+NAJ?J\T,-$`*9#I5BJ[:[F`+!1O=>X<[+5+<#)
MKM?"9`"P4;W7N'.RU2VH1*=5`+!1O=>X<[+5+</1IT^XN;U8`+!1O=>X<[+5
M+;[6IK.JS`"P4;W7N'.RU2VQ2*7SI$@`L%&]U[ASLM4MK7&^7`"P4;W7N'.R
MU2VH^J[XK7&^7`"F0Z58MWRTP:6BL=$Z("5S`*9#I5BHSZ7.JLREHK'1.B`E
M<P"F0Z58J,^ESJK,JKJE7*_@LU'#]K.L`*3EOL<`3&ET:'5A;FEA("BEW[.S
MJ7LI`+C\I$JDI"XN+@"W[:9AKLFVH3H@`*9AL,^[4*[)MJ$`IF&PSP"U;J1*
M`+5NI5@`M6ZD2@"U;J1*I'6G0`"U;J1*I:*QT2P@O=#`RZQDN]6D5:JZI<ZD
MX:97J4VQ2[U8+""U3:OAK:NXU2X`M6ZD2J6BL=$N`*KXI7D`MU*QH0"G0P"D
M<+QGI\;#OKS&IG(`I'"\9ZG4I$*\QJ9R`*1PO&?#N;"HO,:F<@!,=7AE;6)O
M=7)G("B_8[3+L_DI`*3K`*A#I.FP5*ZG`$U3+51.148@JOZE6\#)KM>DI*A3
MIK.XZJ[&+@!-4T<`36%C86\@*+]$JODI`$UA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9B`HL*BHY+EYID"I3;#J*0!-861A9V%S
M8V%R("BPJ+E&I5NTM:5;*0#%7;-.`+9LI?,`MFRE\[K>LGH`J]BEW[-SM;)?
M:RXN+@!-86QA=VD@*+"HJ=2KPBD`36%L87ES:6$@*+"HJ-.FZ*C(*0!-86QD
M:79E<R`HL*BZN*9AI-(I`$UA;&D@*+"HIU$I`$UA;'1A("BPJ+JXI4PI`+K>
MLGJG0:JZI,##_BRHPZ5"K+"DP,/^LUVI=\-#IN(N`$UA<#(T(*9AN<\`36%P
M475E<W0@IF&YSP"D5*3K`,/DK,D`O-"P3Z:H(*S=N4POI;RLW;E,`+S0L$^F
MJ*CDI4RJNL/1IT\@**C2IG`N(*VKK6XOI'>F7L+0*0!-87)S:&%L;"!)<VQA
M;F1S("BPJ*Y,NKBX<ZYQ*0!-87)T:6YI<75E("BPJ+2CI:>G2JYQ*0"DQ[!T
MQ.:F[*2D`$UA=7)I=&%N:6$@**U4IU&V\*6GJ,@I`$UA=7)I=&EU<R`HO*^H
MO:;HM+4I`*2YLURJNK/,I&K"2;S&+@"J_J7SO,:EV*1WME>E6*2YLURD5ZVM
M+@"SS*KQ(#(T(*1PKLFJNK/,L*JWQ:O7.B``L\RJ\2`V(*1PKLFJNK/,L*JW
MQ:O7.B``L,^V]*17K:V\QJ78`*2YLURSS*1JJOBKUP"DK:3K`$UA>6]T=&4@
M*+"HK/FO4ZYQ*0#"Y;['`*:HK?L`O^^SYKS2IJ$Z`*98J-;`>*9SKN8`MFRE
M\P"V;*7SQ>?#TJ1WI[FFJ"RF_:Q/J,^ESJK,JKK#L;.YJV^U3*IKLW&Y3,7G
MP](N`,*RL%2D=[E,M,$N`,*RL%2KK+I!`$UE=&%R(+#/MO2U3*IKJ,^ESBX`
M365T87(@L,^V]+5,JFNHSZ7.+B"RT[A@O="PT:;2J'2RSKK>LGJU;K_]+@!-
M971A<D1"(*E\I;RS<[&U+@"DZ*IK`*3HJFL@(B5S(B"EO+-1J7>X<0"DZ*IK
MI;RI=[AQ+B"E2*E)I7.DZ*IK.B`E<P"DO:CN`$UE>&EC;R`HOJ6FZ*WT*0!-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F("BQ2Z=*P[FEIZ;HJ,@I
M`*2DMJ$`36EM92"KK+I!`+/,JO$@,C0@I'"NR:JZL\RG0[?%J]<Z(`"SS*KQ
M(#8@I'"NR:JZL\RPJK?%J]<Z(`"SS+5UL4N]6*[$M,&I?*6\J.RTP0"L3:YG
M`,+XMK4`I^2DHZCL(%!%05(@I5VXRR!(5%107U)E<75E<W0N`+-=J7?`R;_R
MI:(N(*9PJD>M;JC/I<ZS;ZW3P+.ESK5[IJ&G0:6RMK>R>Z9BM$ZRHZ7-I4PN
M`*?DI*.H[,*RL%2JNB!)1"X`I^2DHZCLI;*VMZJZ(%!%05(@I5VXRR!-86EL
M+@"GY*2CJ.RW?+3!JKH@240N`*Q0M,&D0`"FYK#*MFRE\P"WQ:E-`*?SMW.D
MZ;3!`*W7I^^Z]*=]`+S2LM4`36]L9&]V82P@4F5P=6)L:6,@;V8@*+RONKBF
M:*7+*0!-;VYA8V\@*+ROK\>M]"D`36]N9V]L:6$@*+M8I6HI`*3KI,ZF?@"H
M0Z3K`+M8MNNIU*]3`*3KK-L`IF*RQ"5DIN:GY*CLJKK$YJ;LO,:EV*1WME>E
M6+EWM,$E9"X`O*^LI:WT`*9HMK.NR;2X`*9HMK.NR;.Q`+2XKLFF:+:S`*15
MLKX`I:JRO@"E:[*^`*17LKX`I%6RO@"D5[*^`$UO>F%M8FEQ=64@*++VI%2D
M\:=**0"]QK_OIJ&D5:G4I5ROX*KM`+W&O^\`I]JJNK%BN+D`I]JJNK%BN+FX
MZK!4`*W3I$BON*5X`*W3I$BON*5XK;:ML;!TN&T`37EA;FUA<B`HO7&H;"D`
MI*,LI]JDHZ90MTX`IE>ZV0!.86UI8FEA("BHNJ;,I/&HR"D`3F%U<G4@*+_5
MOGPI`$YE<&%L("BEIZIYNK@I`$YE=&AE<FQA;F1S("BR_,3U*0!.971H97)L
M86YD<R!!;G1I;&QE<R`HLOS$W:9WIF&F0[2U*0!.971S8V%P92"LL+#RPJ:J
MNKKTIWT`3F5T<V-A<&4@OLS#TJ=`O&^Z]*=]`$YE='-C87!E(+[,P]*L1K6F
MNO2G?0!.971S8V%P92"G\[=SNO2G?0!.971S8V%P92"G0+QONO2G?0!.971S
M8V%P92!34TP@IOBJ0;ZYIE>ZV0!.971S8V%P92"^S,/2JKJU^;C1`$YE='-C
M87!E(+[,P]*KK+I!`+KTN/2D=:CC`+%QI;P`3F5W($-A;&5D;VYI82`HMW.S
MV*B]IFBEIZC(*0"W<[Q7I,##_@"\9ZM(M;D@)7,`MW.DZP"W<ZC/I<ZJS*97
MNMD@**M$I;*M;BD`3F5W(%IE86QA;F0@**_#INC$]2D`MW.Q2[U8`+=SL4N]
M6+%.J?,E>*CLM,$N`+=SL4N]6*2CLL6F6"X`MW.U^+6A("A?8FQA;FLI`+=S
MNT0`MW.[1+ASLM4`I%6D0*A"`*15I$"MT[_OMK4`I%6D0*VV`$YI8V%R86=U
M82`HI:>E6ZG4I<HI`$YI9V5R("BEIZ3I*0!.:6=E<FEA("BI8*3.IU&HR"D`
ML=^D5P!.:75E("BOPZY*KG$I`*=?`+5,I6FHT<7CI=RN=+*GJKJS7:EWN.JN
MQBX`M4RE::7.JKJUIK*DJ]BS>2!)4T\@O':YLRX`J%.FLZ?EIKB\RZ:A+@"I
MTJO\J7>JNJ;LN&VD5ZA3IK.PS[;TIG.F8@"H4Z:SM*.HT:;FJ,:^Y*97NMFE
M2*C1($U#04P@Q>?#TBX`J%.FL\7<I_,N`+5,JFNF8J78JV7%=JVMI*2\5Z5;
MIKC%=JVM+@"H4Z:SJ_RI=ZJZ("5S(+-=J7>XZK!4+@"H4Z:SJ_RI=ZJZ($94
M4"!61E,@LUVI=[CJL%0N`*A3IK.K_*EWJKH@4U%,(%9&4[-=J7>XZK!4+@"H
M4Z:SJ_RI=ZJZ(%-13"U&:6QE(%9&4[-=J7>XZK!4+@"U3+/1OFS"2;S&+@"E
MO+2CJ-&EV*JZ+@#`R:[7I;RD5[;'`*?DI*.H[+G/I=PN`*;LN&VXZK!4J7RE
MO+-=J7<`J7REO+2CJ-&F[+AMN.JP5"X`I;RTHZC1PK*P5"X`I;RK_*EWIE>Z
MV2X`I;RK_*EWN+F]6"X`J%.FLZO\J7>Q2[U8I4BHT2!(5%10(,7GP](N`*A3
MIK.K_*EWL4N]6*5(J-$@24U!4"#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1($ME
M<F)E<F]S(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@3&]G:6X@Q>?#TBX`J%.F
MLZO\J7>Q2[U8I4BHT2!005-35T0@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!3
M34(@Q>?#TBX`I;R_Z:1*($]P96Y34TP@I$>DN+#UIN;`R:JZI?ZX]*Y\+B!0
M2T-3(#$R(+-7KN:JNJ5;L4NXZJ[&N]VM;J7.J.RXT[5[IJ$N`*A3IK.KW;QF
MJKJU^:55I=.]T"X`NL^ZT+!TPT*EO+-=J7<`M4RNYKUU`*E\I;RK_*EWQ.:F
M[*3`N6JF<J2X+@"U3*[8O74`M4RFN<#)KM<`M4R\R*9SI=B__:5IJ-&GUJCZ
M+@"EO+;'L&6HSZ7.JLRF5[K9J<ZQ2[U8+@"U3*5II<ZJNB!834P@N.JNQK-1
MML>F7@"JQ:75K<@`K>RI;+-=J7?`R:2DI^2DHZCLJJFEN[CJL%0N(*VKMW.R
MHZ7-LUVI=\#)+@"F8J=!JKJS7:EWP,FDI*?DI*.H[*JII;NXZK!4+B"MJ[=S
MLJ.ES;-=J7?`R2X`M4P`M4P@*'5S92!I;7!L:6-I="D`I.FFU;#2I.4@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9"`HO]6ZUJ=*KG$I`*5?I6*R>0!.
M;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y("BNOZO"*0"K1*2GJ^$`
MJT2DIZME`*2CK$^D0*W3I=B__0"U>Z:AJ7REO*>YIJ@N`*2CLUVI=P"EO+-1
MI.2TJ0"SQJ?1O_T`J%.FLZ5IPG/$_:JZ+*9>I6@N`*11I$"DZP"\QJ9R`*9R
MI+B\Q@"F<J2XO&6KUP"FYKS&`*?SMW.P=+AMN'.RU:[)I;RK_*EWO,:EV"X`
M3TL`JJNE\P"JJZ7SJ]BEWZK,`*1+MFFF[`"D4:3K`+_LI+VKQP"W<[%+O5BE
MLK:WNU#"PK%+O5BDHZ90+@#"PK%+O5@`PL*Q2[U8I*.EO[U4`$]M86X@**K\
ML-(I`*5UIK,@24U!4""F^*I!OKFDY+2IJTBE\Z=8I,"HR:5<K^`N`*5UI+FS
M7*1`K=.V;*7SINVG?2X`I76FL[[6IK.JS+M0J'2RSKK>LGJM^Z5II4C%W*?S
MID"HR<5VK:T`IF*W<ZJZM?BUH;9]L=(`3W!E;E-33""_^;M^.B"U3*IKL7$@
M4R]-24U%(,.QL[FJ_J7SN-&V?;CJKL8N`*9BMW.JNK7XM:&V?;'2LW.UL@"G
M0+=^J'2RS@"_[[:U`"5SO^^VM0"VM:78O7.XN0"RU<*T`++5PK2SYJ;L`++5
MPK0`K>RI;,"SI<ZU>Z:AO,NJ3P"F8B`E<SH@I*2JNJWLJ6R\RZI/+@"HY*5,
M`*CDI4RXZK!4`+[6IK.JS,5VK:T`4$%-(,7GP]*U3*[$+@!014%2.CJV;*7S
MIOBJ0;K=`%!'4""\QJ;LP[&SN0!01U`@I5NQ2[CJKL8`4$=0(*2]MGVJ]\9?
M`%!'4""D=\.QL[DOI'>E6[%+(+CJKL8`4$A0(+5[IJ&]6`!02%`@K_.]6@"D
MR*OAI'"K0@"DR*OAL'VK0@"DR*OAIK.SMP"DR*OAL'VSMP"DR*OAM+@`I,BK
MX;EPJT(`4$]325@@97AT96YS:6]N(+_RI:(`4$A0(*_SO5I?2`"YU*52`%!A
M:VES=&%N("BDVK#RM+6I6BD`4&%L874@**FMKULI`%!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960@**3:L,>TM:E:ION[XK#/*0!086YA;6$@**3:
MKK.PJ"D`4&%P=6$@3F5W($=U:6YE82`HI-JEK*C(MW.T6*2ZJ,@I`%!A<F%G
M=6%Y("BDVJG4IF,I`*9HMK,`L4N]6`"Q2[U8Q=RG\Z>YIJ@N`+%+O5BDHZ6_
MO50`J%.FLZO\J7>Q2[U8I4BHT2!2041)55,@Q>?#TBX`L4N]6+U4NWL`L4N]
M6#H`L4N]6#H@`+%+O5BELK:WIVNF6"X`MDND5P"V2Z17`+CTKGP`J]V\9K5N
MO_VA1P"FJ*W[`*;*I,"D\0"P]:;FNOO%0+[>IT``M6ZD2JOAL/6FYKK[Q4"^
MWJ=`/P#%=JVM`"(E<R*JNL5VK:VEO+-1IU*PHRX`IG.H^KY$J=H`Q7:MK0#%
M=JVMNMZR>@"GVJJZ`%!E<G4@**^UOGPI`,-DJJL`4&AI;&EP<&EN97,@*+7A
MJ]^[JRD`N7&XW`##P+19`%!I=&-A:7)N`+FSK\``O="V::1*P'BF<Z[FPDF_
M[P"]T+U4J7>M;K*^L*.FN:2XI?,Z`+W0O52I=Z=!K6ZDI,)?IKFDN*7SJKJS
M<[6R+@"]T+_II$JD0*W3I.NE]Z3.IGZE]RX`O="_Z:1*MW.\5Z3`P_ZJNJ97
MNMDZ`+W0O^FD2J1`K=.FLZ[$JKH@25`@INRG?0"]T+_II$JD0*W3IK.NQ*JZ
MI.FTP3NDQ+_OIKFDZZ7WJKJDZ;3!+@"]T+_II$JD0*W3IK.NQ*JZKLFVH2X`
MO="THZC1L-W#1*JZNDNM;BX`O="_Z:1*IT&JNJC/I<ZJS*97NMFDSK%+O5@`
MO="^7,6JI%6F0Z2ZKF4NIT&ELK:WIE"W3K-OJ,>HQK:UI'ZOX*C/I<ZH=++.
M+@"]T+_II$JW<ZJZI,##_J97NMDZ`%!O;&%N9"`HJFG$]2D`K$:J=@"GZ[*\
M`%!O<G1U9V%L("BXLK7EI/HI`+QVN;.F[+AM`*KMKN:F[+AM`+N\L&6V;*7S
MJ.RS;ZW3JTBE\Z=8("AN;W0@96YF;W)C960@8GD@24U!4"D`L\RJ\2`E<R"D
M<*[)JKJML*M"MG$Z(`"ML*M"/&)R("\^OO>R=@!0<F5F<U]L9&%P.B"GY*2C
MJ.RITKO=K6ZJNB!,1$%0(*FUIOFN3:7S+@!0<F5F<U]S97-S:6]N.B"GY*2C
MJ.RITKO=K6ZJNB!S97-S:6]N(*FUIOFN3:7S+@"N\,"C`*[\I:VML:[PP*,Z
M(`"N\,"C.B``N7?$_0"F8K=SJKJU^+6AN7?$_;QVN;,`I%>D0*W3O^^VM0"F
M0Z9,I.6E\P"H<+%+JO?&7P"PW<-$`+#=PT2T>:UZ`+%-KM<`M*.EW*2ZKF4`
MI+VV?:KWQE\`I+VV?:KWQE^Z=+KB`*2]MGVJ]\9?N.JP5`"DO;9]+ZAPL4NJ
M]\9?N>^HPZ6\LU&RHZ7-+@!0=65R=&\@4FEC;R`HJFFF:+ZDIE4I`%%A=&%R
M("BE9+E&*0"L9+C?`+K/NM"P=+AM`%)302"DO;9]JO?&7R`H)60@INRDN"D`
MO^^^W+9S`*M"`*:MIK.K0@"QWZ:SJT(`L'VK0@"K0J:SL[<`JT+"X+.W`,!(
MOO>D<+MY`*3QLG8`Q:JH^@#%JJCZMFRE\P"O=:JZK6ZG4K"C("5S(+;</R"S
M;[:UOMZG0+%.M4RJ:ZOLM%\N`*]UJKJM;K)-L*.HSZ7.JLP@)7,@JKJXZJ[&
MMMP@/R"S;[:UOMZG0+%.M4RJ:ZOLM%\N`*CZKOBT7ZWL`*VKMW.^X[)Z`*VK
MMW.^X[)ZL,JZ0:78O_VDN*7S.@"MJ[=SON.R>JW3I$BON*5XI+JN93H`L6"S
M5ZKMI=RFH0##]L%PPG/$_;ZY`*VKQ:H`M?N]UP"[M[K=IOBJ0;ZY`+NWNMVZ
M]*=]("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`LKZPHP"ROK"C
ML,^V]`"ROK"CQ.:F[`"E:+"CKN:FH0"ROK"CN>\`IMNF^*I!OKF\R*9SI=B_
M_:2DLKZPHZ1WP'BF<ZJZLUVI=[5[IJ$N`+*^L*,`IMNDY:7SI*2ROK"CIKFD
M0+A@PDD`LKZPHZC/I<ZJS`"ROK"CJ,^ESJK,.B`E<P"[W:A$I;RS4:9>P+,Z
M(+_YNWZXN;U8.@"GY*2CJ.RITKO=JKJJ0;#(+@`E,B1S(*JZLUVI=Z6RMK>K
M_*EW("(E,21S(@!61E,@JKJS7:EWI;*VMZO\J7<@(B5S(@"S7:EWN.JNQJ6R
MMK>K_*EW("(E<R(`I;*VM\3FINP`K:NS70"MJ[-=L4N]6`"MJ[-=IT&JNK%+
MO5@Z`*9>IG.SS*OAI$"MTZQDN-\`M;*J1P"J\*9>O^^VM0"F0::XO^FD2K=S
ML4N]6`!2975N:6]N("BO9*6GJ?2N<2D`IEZT7[-=J7<`NO2MMKUSO^B^N;_O
MMK4`P;R[>0"E:\/D`*5KP^2J[<!9`*5KP^2MR`"F0Z2ZKF5?=RXN+@"HI*;B
M`%)O;6%N:6$@*,.YL*BEIZC(*0"QV\+@(#$X,""KUP"P9J[)L'<@.3`@J]>Q
MV\+@`+:VKLFP=R`Y,""KU[';PN``ID.DNJYE`*9#I+JN90"F0P"NYKUU`,3F
MINR[4*9#KN:]=0#$YJ;LKN:]=0"F0Z[FO74`L/6FY@!2=7-S:6%N($9E9&5R
M871I;VX@**M8P[FTM2D`4G=A;F1A("B_8Z9WN48I`%,O34E-12"E6[%+P[&S
MN0"V;*7SI'>HSZ7.(%,O34E-12"E6[%+`%-!4TP@Q>?#TK5,KL0N`,*RL%0`
MN.JNQJYWK_.]6@"E6[%+LM>ZW;[W`*:HI5P`N.JNQJYWK_.]6E]1`*Q0M,&D
MNP!386EN="!(96QE;F$@*+ATNZZPQZ_'*0!386EN="!+:71T<R!A;F0@3F5V
M:7,@*+ATITJHO;2UIFBZUJ3.I:>Z^[2U*0!386EN="!,=6-I82`HN'3%4Z;H
MJ,@I`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,@*+ATI.6TRZ3.KN:WYZBZI$(I`*90I$"MT[7X
MM:$@*%]S96QF*0!386UO82`HPL2\KZC(N'.N<2D`4V%N($UA<FEN;R`HN'2P
MJ*=1O]4I`%-A;R!4;VUE(&%N9"!0<FEN8VEP92`HN'2F:*S\I,ZTMJI,INBD
M\2D`O<.L4+2CJ-&JS`!3875D:2!!<F%B:6$@**A&KU&F8:K\J=2G0BD`P'BF
M<P#`>*9S("(E<R(`P'BF<R`E<P#`>*9SO^^VM0"Q3K*CI<VJNK-=J7?`R:5(
M(%!(4""[>:BEKN:FH<!XIG.H[*=!JKJF^*I!OKF\R*9SI=B__:2D+@"S7:EW
M("5S(*1WP'BF<RX`I_.W<[5[IJ&D=\!XIG.H[#H@(B5S(BX`N7.L4+EPJT(`
MK.R^QP"W:K1-`+=JM$VDWL"Z`+_OOMS`R:[7`+_OOMRD0*W3I.FTP0"_[[[<
MI$"MT[ASLM6ESJ5(MW.\5P"_[[[<I$"F[+=SJKJ^UJ:SJLP`O^^^W*1`LZ&F
M^*I!OKD`O^^^W*1`INRHSZ7.JLRESJ5(MW.\5P"_[[[<J=*FLP"_[[[<J=*F
MLZ3IM,&DN*7S+@"_[[[<I$"MTZJKI?,`I*._[[[<`*GSI4BD5:JZM?BUH:2D
MO^^H^J=!K6ZJNJ9RI+@NI4BWQKFKO<:[<ZG2O^^DY:9R++5-J^&V2Z17I.6E
M\[USO^BPSRX`O^^^W*3IM,&DP+EJ.@"_[[[<I.FTP:3IM,&NYJ:A.@"_[[[<
ML?W%W*?SJKJHK:7WP]&G3SH`O^^^W*[)MJ&DP+EJ.@"_[[[<I.FTP:[)MJ&N
MYJ:A.@"_[[[<K-NDK*3'L'2JNJ1'K=/$YJ;L+@"_[[[<IT&JNL-#IN*P=+AM
M`+_OOMRPOJ9NNWFHI3H`ML>P9;#=PT2DS\"S`+;'L&7"LK!4`%-E;F5G86P@
M*+;KI+JE6[JX*0"W4+3ZOKDZ(`"D1:3K`%-E<F)I82!A;F0@36]N=&5N96=R
M;R`HMNNZN+K[J,B[4+M8KU.EIZWTP[DI`*?'N+D`IOBJ0;ZYN.JNQK_YNWZI
MSJK,M4RJ:ZC/I<XN`+=\M,&ZWK)Z`+=\M,$@240@I'>Y3+3!+@"W?+3!`*[6
MJ/JDZ+;T`*2YLURG0:GSI]&P3[%+O5BJNJ[)K=0LI6FE2*;;IN:MJ[-=L4N]
M6"X`LUVI=[NWNMVF^*I!OKFD5\3=J?.G0:JZK=.D2*^XI7@N`+-=J7>G0:JZ
ML+ZF;KMYJ*4L(*[)L,^E2*3.I.FTP:[FIJ$N`+-=J7>G0:JZL=*I;,"SI<ZU
M>Z:A+,-#IN*P=+AM+*VVK;&G\[=SP%>R=BRDSJCDI4S%XZ7<O^^VM2X`LUVI
M=P"G\[=SM7NFH;1.NOP`IK.F;K18K=.F8<))J4VS;ZW3L-&\QJ:SP_8Z(`!3
M97EC:&5L;&5S("BVZZGUNK@I`,'*JJL`PK*U=;I+K6X`K$^G7ZRPI&JSH:7W
MJKJS<[6RJ7>X<:?6L;:E7*_@P>0_`,7CI=P`Q>.EW+=SLJ.ES;M0K>S`>*9S
MLUVI=\#)JKJN=+*G+@"H0Z:XM6ZD2JOAQ>.EW*17I$"FN*JZM6ZD2J[)MJ$@
M/P#%XZ7<PDF_[[ZY`,7CI=RJ[:[FOMZG0*5<K^"J[2`_`*GSI:K#Y,7CI=P@
M)7,@I5ROX*KM/P#%XZ7<P'BF<Z[FI+JN9;GON-RDZ+;T`,7CI=RJ[:[FI+JN
M9;GON-RDZ+;T`,7CI=RF0Z2ZKF6Y[[C<I.BV]`#%XZ7<O':YLZ2ZKF6Y[[C<
MI.BV]`#%XZ7<I%>VQP"K^<3RL'VK0@"FK::SL'VK0@"QWZ:SL'VK0@"[MZ3H
MIK.P?:M"`*:LP5D`4VEE<G)A($QE;VYE("BWX*1LI'.PZBD`M?FE50##L;.Y
M`,.QL[FZ=+KB`%-I;F=A<&]R92`HMW.E6ZE9*0"D:J1P`+*DN4RZ^\5``%-L
M;W9A:VEA("BTM:REI>^G2BD`4VQO=F5N:6$@*+2UK*6E[Z6GJ,@I`+.W`+!]
ML[<`L'VSMP"FK::SL'VSMP"QWZ:SL'VSMP"_;K.WLF"KUSH@`%-O;&]M;VX@
M27-L86YD<R`HK\'#N:KYN'.N<2D`4V]M86QI82`HK\&PJ*=1J,@I`+IQNU"X
MU@"QQJ9#I.BF5K_OOMP`J-.WO:9AIWT`4V]U=&@@069R:6-A("BK;JM$*0"K
M;KS:("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@
M4V%N9'=I8V@@27-L86YD<P"K;J5BLGD`JL6EU:;F`+:AMEH`MJ&V6KM0N=2E
M4@!3<&%I;B`HINBO6J3Z*0"I5:>CMFRE\P"O4Z[MIG*DN+_II$H`I,"SSL!X
MIG,`I,"SSL3FINP`I,"SSJ9#`+E"L,H`4W)I($QA;FMA("BTM:B]Q/6E9"D`
MO-"WQP"L4+O:JJ?%4;[4`+'2J6RF?J7W`*S9`*JLND$`P'BF<Z[FIJ$`M?.Y
M1`"G4K"CO74`IG*FZJ9#`*;;MFRE\Z9AIWVDI*5HL*.Z]+#LIE>ZV0"\RZ:A
M(%M#4U-=`*Q0M,&DT0"GY*2CJ.RFN*78O_T@(B5S(@"E1*:N`+!EI5@`O%>E
M6R`B)7,B(*CLJ'2RSJJZI=.]T*1WL&6E6"X@IT&ELK:WM:6H[+C3I=.]T+-1
MKM:MXZOAI'ZOX+5NI$HN`*15O-``IJBE7`"FJ*5<JKJE6Z1*("(E<R(@J.RH
M=++.I*0N`*:HI5RJNJ;;J'2RSJ2DLDVPHZC/I<ZJS"`B)7,B(*JZN.JNQBX`
M(B5S(J1WIU*PHZ>YIJ@N`*:HI5RJNJ;;J'2RSJ2DLKZPHR`B)7,B+@"D=Z:H
MI5RJNJ9>M%^S7:EW+B"]T*VKMW.X_*1*P,NU^*YTLJ<N`*1WIJBE7*JZL\:E
M][-=J7>XZJ[&+@"D=Z:HI5RJNK/&I?>S7:EWN.JNQB`E<RX`IJBE7*JZI_.W
M<R`B)7,B`*1WIJBE7*JZPM"\9R`E<P!3=61A;B`HQ*RDIBD`NDNM;@"DZ:58
M`*3IN*@`M+@`I.FE6`"DZ:58+Z3IN*@`I.FE6#H@`*3IN*@`I.FXJ#H@`*17
MO-``I.2TJ0!3=7)I;F%M92`HQ*RG4:MN*0"Z[[BY`%-V86QB87)D(&%N9"!*
M86X@36%Y96X`4W=A>FEL86YD("BE=J7+P-G$]2D`4W=E9&5N("BWYZCE*0!3
M=VET>F5R;&%N9"`HM^>D:"D`IE"H0K!/O_VD=Z=2L*,`IE"H0J;FL,JXR[AM
M`+=JM$VVM:78I*2JNKMYJFN_^;M^`%-Y<FEA;B!!<F%B(%)E<'5B;&EC("BQ
MU*=1J,@I`+EPJT(`N7"K0J:SK;<`N7"K0@"FK::SJ_G$\KEPJT(`5$%"(*3`
MN6JNYJ:AP,FNUP"J[;/F`*KMKN:DNJYE`*KMKN:DNJYE`*5XQE<`I7C&5P!4
M86II:VES=&%N("BV\*9.M+6I6BD`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9B`HJ5JI?*6GJ,@I`*78O-`Z`*O=O^RHQK:U`+EQN-RXN;U8`+/,JO&D
M0*1PKLFJNK?%J]<Z(`"WQ:O7`+?%J]<Z(`"WQ:O7/&)R("\^*"5SL*HE<R\E
M<Z=#)7,I("9D96<[)7,`I^2DHZCLO,NJ3R`B)7,B+@"\RZI/NMZR>@"DNJYE
M`*_"I.6F<@"Y[[OTI.6F<@"Y[[OTI.6F<K.[NMT`K%"TP:5\`*[UI.4@*%1)
M4RTV,C`I`%1H86EL86YD("BN];#J*0!&5%`@J;6F^2AE>'1E;G-I;VXIM4RN
MQ"X`2&]R9&4O2V]L86(@ON.F6*1UM7NHPZ6\I.2TJ2`B)7,B`$E-4U`@K/:_
M_;5,JFNS4:KLJ6PN`$UA:6YT96YA;F-E(,/^IT^HPZ6\IJBE7+C\I$H`O^^V
MM;7XM:&E2,/VLZPNPO>V?:2D+@"G0:JZJ'2RSKK>LGJM^Z6RMK>E_;-=J7>F
M;J1`K=/%=JVMJ^&ZW:1^K^#%_:=!J,^ESL5VK:VH=++.+@"ILZ[8O74`P7"U
MN+BYO5BEO*O\J7<LJL6EU:G.IF*XZJ[&KG>DI*?DI*.H["X`I'>FJ*5<JKJQ
M3L%PM;BD2+=SO%>FW+-QL%2__:2D+@#%Y\/2MFRE\\.QL[F[W:UNIK.D0*W3
MI'>XT;9]JKH@4$=0(+#/MO0N`+!TN&VX<[+5JKK#T:=/N+F]6"A)1"FDHZQ/
MI;RK_*EW++1.K$^JQ:75J<ZJS*2CIF*XZJ[&KG>DI"X`L'2X;;ASLM6EO*O\
MJ7<N`+O=K6ZD0*W3N&>Y3*5;L4NJNKKTN/2S<[6R+@#`R:[7("5S(,"SN-.E
M7:=TI$"MTR`E<R"S7:EW+@#`R:[7("5S(,"SN-.E7:=TI$"HQR`E<R"S7:EW
M+@"U3*IKO<:[<ZCLIMNHK<#)KM<N`*:YP,FNUZ2DJ%.FL[CJKL8N`*5(I%6L
M3R!R9F,X,C(@MFRE\ZJZJNW`62X`J*VE]\/1IT\@)7,@I'>S4:=2L*,N`*6J
MKMB]=0!';G501R"D1Z2XP,FJNKCTKGRELK:WJ7>X<:9B($-R>7!T7W!G<#HZ
M(,/^IT^DI"X`IT&TOZGS("5S(+%(M;D@)7,@I$"KRJ5$IJZLL"`B)7,B(*JZ
MJTBE\Z1WLU&V?;'2+@JF_;-OJ,.DHZ_@JT_#TKC3JTBE\ZJZI+JN9:1WI[FE
M_K-1IJRE\Z1(K-VGN:G.I$:XT2X`LW.ULJCLO7.\9[9LI?.MMJVQJ=*HSZ7.
MJKJF5[K9`*6RMK>L3Z1`K=.\QJ9R+@!(;W)D95]#<GEP=%]S;6EM93HZ(,/^
MIT\LI;*[W:UNIK,@;W!E;G-S;""\TK+5+@"FN;"^IFX@(B5S(B"XZJ[&IEVL
ML+97N4RSS*1JI+FS7*W(+*G2I4BU3*IKLU'`>*9S`*7.I4C`R[7XIKFXZJ[&
MP_ZKK"`H)7,I(*JZM7NFH:C#I*.F<Z9BJ?.H=++.I%<N`*3>K7JF<J6RMK>L
ML+/FI$"F<J2X+@"EJJ5KKMB]=0"E:Z[8O74`Q.:F[*3`N6JF<J6RMK>LL+/F
MI$"F<J2X+@"FN:;XJD&^N2`B)7,B(*1WLU&G4K"C+@"FN:;XJD&^N2`B)7,B
M(*1WLU'`>*9S+@`E<R"JNK7YI56[W:A$I'>S4;*^L*,N`*O\J7>JNK!/O_VH
MPZ2CIG.F8BX`O,BF<\#)KM<B)7,BI*.F<Z9B+@"G0:G2O^FD2JJZN.JNQKM0
MM66ML;CJKL:DH[+%+@"D5Z15KMB]=0"D5Z[8O74`L7&D5Z1`K=.H0L9*I*>K
MX:17ML>JNKCJKL:_\J6B+@"D5[;'P,FNUZC#I;RS4<!XIG,N`'=E871H97(N
M8V]M(+#/MO2U3*IKJ,^ESBX`I^2DHZCLO,NFH;!TN&VEV+_]("(E<R(N`+5,
MI6FESJJZO^^VM2X`M4RJ_J7SI6FJO;&UMGVQTBX`IKG$YJ;LI*2E7:=TI-.F
M:*JZIG*\QBZG0:1WO^FD2B`E<R"MTZ9RO,8[IT&_Z:1*JKJF<KS&I;*VMZ1P
MJ?,@)7,N`+=SO%<@(B5S(B"H[*ATLLXZ("5S(*[)M6^ES:1`K=.PW<-$+@"F
MVZATLLZR3;"C("(E<R(@JKJXZJ[&KLFU;Z7-I$"MT[#=PT0Z`*;;J'2RSK*^
ML*,@(B5S(B"NR;5OI<VD0*W3L-W#1#H`I_.W<R`B)7,B.B`E<R"NR;5OI<VD
M0*W3L-W#1`"D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E<R"EO+-1I%>VQRX`
MI%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@)7,@I&JD<+97N4RDN;-<L\RD:JW(
M("@E9"!B>71E<RDN`*17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z(+;(LZ&DP*JZ
M("5S(,#)KM>S4:17ML<N`,#+M?BV;*7SKLFU;Z7-I$"MT[_YNWXN`+;7I$JF
MN;-QL%2__;CJKL:NR;5OI<V_^;M^+@"VUZ1*(&E#86QE;F1A<B"XZJ[&KLFU
M;Z7-I$"MT[_YNWXN`*9BLUVI=ZKML^:DI+5OI<VD1J1`K=._^;M^+J:SI6FO
MX*=!O_*Z?*1&I;*VM[;QO&>JNL3FINPN`+#UIN:S<;!4O_VK_*EWI5ROX*[)
MM6^ES:1`K=._^;M^+B"]T+5YJ^&F0;C5I$"FN"X`I_.W<\%PM;BD2+CJKL:N
MR;5OI<VD1J1`K=._^;M^+B"]T+5YJ^&F0;C5+@"G\[=SL'2X;;ASLM6NR;5O
MI<VD1J1`K=._^;M^+B"]T+5YJ^&F0;C5+@"FN2!)34%0(*;XJD&^N:C#I;RD
MY+2IJTBE\Z=8I,"HR:5<K^`N`+-OIORE1Z2CK$^EO[U4JKH@<F%R(,"CP5G`
MR:[7+@"S;Z;\I4>DHZQ/I;^]5*JZ('II<"#`H\%9P,FNURX`LV^F_*5'I*.L
M3Z6_O52JNJM(I<ZE9+BYO5@N`*:YQ.:F[*Q/I;*[W:UNJKHN`*:YQ.:F[*2Z
MKF6E=:2YLUR^X[S&O,:F<BX`IKG$YJ;LI+JN9:5UI+FS7+S&IG*DSJM?N+DN
M`*:YQ.:F[*2ZKF6E=:2YLURD2[9IINR\QJW(+@"FN<3FINRDNJYEI;*VMZRP
MLW*XN:G.JL6EU:3`N6JJNKS&IG(`I;*VMZQ/I$"MT[S&IG(N`*:YQ.:F[*2Z
MKF6ELK:WI5VG=*1`LM6D4:2[MFFF[*JZ(%)'0B##0Z;BI4Z]6"RHTJ9P("<C
M,3(S-&%F)RX`LV^MTZKML^:D=[-1LT*R>KE,+@"S;ZQ/("5S+@"S;ZQ/($MO
M;&%B(+ASLM6JNJ1`K=.JJZ7S+B"Q_<#+M?BFN:JKI?.[W:UNK^"DY+2I2V]L
M86(@N'.RU:[FIJ&JNKEQI&RV;*7SLV[%Z2Z]T+#1IM(@)7,@I4BD1KC1LV^H
MQ[9LI?.S;L7I`+-OJ\JV;*7SJ,.K1*5(IT&Z1*7.JKJF<J2XMK"FTZQ/J,^E
MSB`H)7,I(*[1O&>FTZ:H+@"FN;S&K<BSS*36I;*VMZQ/(#$N`*:YIOBJ0;ZY
MM4RJ:[GO('II<""DSB!G>FEP(*[FIJ'`R:[7MFFFYKC1P*/!60"FN:ATLLZE
MV*MEK$^PL:7.JKJJK+I!+@"ELK:WK$^D0*W3O,:F<BX`IKFU^+6AI;*VMZUN
MI=&_[[:UM?BUH2A/<'1I;VXIJ=*I2:5S`+EP`+#=PT2P;,+<`*[)MJ$`KLFV
MH:O\JVX`KLFVH:[FIJ$`KLFPS[_OOMP`5&EM;W(M3&5S=&4`O-##1`"\T,-$
M("AT;V]L=&EP*3H`IJRE\Z1(`*9PJD>M;KW&O^\LO="F8L))O^^WQKFKJKJF
M4*[)J_8@0V]N=')O;,'D**W3I$BY<;BC*2"ISB!#;VUM86YDP>0HQ*NJ1[EQ
MN*,I+@"DM:31`$A434P@K>RI;,#)`%1O9V\@**9HK?0I`%1O:V5L874`J?JD
MT0!4;VYG82`HJD:E6RD`L[NSH0"SS*17O&BNV*Q;("A?=&]P*0"D9*B]N4:D
MSJ:KJ*FM]`"O=:G.L+``K%"TP:1'`%1U;FES:6$@**SPI:>FZ*C(*0!4=7)K
M97D@**1GIM6HY"D`I&>FU:CDI.4@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A
M;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU("BD9Z7+OGPI`+_I
MI$JG0:JZO^^^W#H@`+6UI7Z]=:O\O,8Z(`"Z]*=]`+KTIWTZ`%5G86YD82`H
MKU&D>KE&*0!5:W)A:6YE("BO4:=*Q/4I`+5,JFNF<ZCZ(%9&4R"EV+_]+@"U
M^:55KLFU3*IKO%>E6\-"I7ZJNJC/I<ZJS+CJL%0N`+5,JFNG[\7<(%9&4R#`
MR:[7("(E<R(@JKK%=JVM+@"U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNL5V
MK:TN`+5,JFO%W*?SK+`@)7,N`+5,JFO`RZQDP,FNUZ1JI'`@(B5S(BX`M4RJ
M:\#+K&3`R:[7I&JD<"`B)7,O)7,B+@"U3*IKLW.ULB!344P@IOBJ0;ZY+@"U
M3*IKJ,^ESB!34TP@LW.ULBX`M4RJ:[W&NW,@5D93(,#)KM<N`+5,JFNKV*7?
M(%9&4R"EV+_]("(E<R(N`+5,JFNKV*7?(%9&4R"EV+_]+@"U3*IKJ]BEWR!6
M1E,@P,FNURX`M4RJ:ZO8I=\@5D93(*78O_T@(B5S(BX`M4RJ:ZO8I=^JQ:75
MJKH@5D93(,#)KM<N`+5,JFNQ3KCJKL:XT<"CP5DN`+5,JFNG4K"C("(E<R(L
MIKFEV+_]J,.K1*K%I=4N`+5,JFNG4K"C("(E<R(Z("5S`+5,JFNG4K"C("5S
M+*:YI=B__:C#JT2JQ:75`+5,JFN[O+!JIU*PHZ78O_TN`+5,JFNG4K"C(%9&
M4R"EV+_]+@"U3*IKIU*PHR!61E,@I=B__3H@)7,N`+5,JFNG4K"C(%9&4R#`
MR:[7("(E<R(N`+5,JFNG4K"C(%9&4R#`R:[7+@"U3*IKIU*PHR!61E,@I=B_
M_2`B)7,B+@"U3*IKN[RP:J=2L*,@5D93.B`E<RX`M4RJ:Z=0PE^EV*MEJKJE
MV+_]+@"U3*IKN-&V?;[,P]*RT[A@`+5,JFNX_*1*)7.JNJEWN'$N`+5,JFNW
M:+*^(%9&4R#`R:[7+@"U3*IKMGVQTB!61E,@P,FNUR`B)7,B+@"U3*IKO&>D
M2B!61E,@P,FNURX`M4RJ:[9]L=(@5D93(,#)KM<N`+5,JFNV?;'2P*/!6<#)
M+@"U3*IKQ:JH^B!61E,@P,FNUR`H9FEL97-I>F4H*2!F86EL960I+@"U3*IK
MQ:JH^B!61E,@P,FNUR`H9V5T1FEL95-I>F4H*2!F86EL960I+@"U3*IKQ:JH
M^L#)KM<Z(`"U3*IKQ:JH^B!V9G-R;V]T(*78O_TN`+5,JFNG\Z97("5S(*RP
M("5S.B"F7:RPI=B\T*M(I?.G6*1WIG.F8@"U3*IKQ=RG\R!61E,@I=B__:JZ
MIE>ZV2X`M4RJ:[*^L*,@5D93(*78O_TZ("5S+@"U3*IKQ=RG\R!61E,@P,FN
MUR`B)7,B(*JZIE>ZV2X`M4RJ:\7<I_,@5D93(,#)KM<@)7,O)7,@JKJF5[K9
M+@"U3*IKQ=RG\R!61E,@P,FNUZJZIE>ZV2X`M4RJ:[#UIN8@)VUK:7-O9G,G
M+@"U3*IKPN"TJR!7;W)D(*3EI?,`M4RJ:[QGI$H@5D93("(E<R(@P,FNURX`
MM4RJ:[QGI$H@5D93(,#)KM<@*&-O<'DH*2!F86EL960I+@"U3*IKO&>D2B!6
M1E,@P,FNU[CJKL8N`+5,JFN\9Z1*(%9&4R#`R:[7+""ZS[K0L'3#0J1WNJ$N
M`*FSO74`J/JN^*?SI^\`M%^M[`"F^*I!OKFS<[6RKLFU;Z7-I;RY=[3!JKJF
M7L"S.B``M6^ES:6\N7>TP:JZIE[`LRRET:;XJD&^N3H@`*6\I,##_@"X5;#J
MO5@@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<R`HJORIU*="P7"F6*1J
MI+VPZBD`56YI=&5D($MI;F=D;VT@**U>L.HI`%5N:71E9"!3=&%T97,@**S\
ML.HI`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P"SYJ;L
M`*6\JKZJN@"EO*J^JKH@05!)(+!4KJ>]<[BY("A!4$D@365S<V%G92!)1"DN
M`*6\JKZJNJO(I.&P5*ZGO7.XN2`H05!)($UE<W-A9V4@240I+@"EO*J^JKJF
M[+AMN.JP5"X`I;RJOJJZJ,^ESJK,IE>ZV:G.L4N]6"X`I*3"7Z78JV6DN*7S
MJKJS<[6R`*6\J5*F5P"F7:9WI?[%5;Q[I*.DN;-<I;RQPL5VJKJU>Z:AL/6F
MYK#%I%4OO<:[<R^V2Z17+B#"2;_OO52I=Z5(P,NU^"!M;WII;&QA+F]R9R"I
MTK2CJ-&JNJS;P_:GWK-.I.6E\RS%_:=!I6FE2+C1L*.FN:1`K:VH[JC#IMNF
MYK9]J?&U>Z:AIG.H^K#%MDO#KRX`J/JN^,-#IN(`I;RDY+2IJKJPQL#)IE<`
MQ=RG\P"G\[=S("5S`*?SMW.HSZ7.JLP`(B5S(J1WI_.W<RX`I_.W<[5[IJ&D
M=Z=2L*,N`*17ML<`I'>D5[;'J=*FL\"SI<ZU>Z:AJKJS7:EWP,FH[*;XJD&^
MN2X`I&J\9ZG4I$*\QJ9R`*1JO&?#N;"HO,:F<@!5<G5G=6%Y("BO4:G4IF,I
M`*C/I<ZEV*MEJKHZ("5S`*C/I<X@4U-,`*9PJD>G0:JZJ,^ESJK,IE>ZV2^Q
M2[U8NU`@24U34""F^*I!OKFDHZ90+*5IIF*FN;-=J7<N`*C/I<ZJS`"HSZ7.
MJLP@)7,@I;RS<;E,("5S(*JZL<+%=L7GP](N`*C/I<ZJS+K>LGH`J,^ESJK,
MO^^VM0"HSZ7.JLRU^:55`*:YK[BE>*JZJ,^ESJK,M?FE5:ATLLZD=["QI<XN
M`*?DI*.H[*C/I<ZJS+%BN+D`J,^ESJK,IE>ZV0"HSZ7.JLRF5[K9("(E<R(@
MI'>F<Z9B+@"HSZ7.JLRF5[K9.@"HSZ7.JLPZ(`"H=++.I*2JNJC/I<ZJS#H`
M57IB96MI<W1A;B`HKU&O]Z=/ITHI`%9&4R"EV+_]J,.DHZ9SIF(N`+"RM,$`
MI'>GY*CLIK.NQ*JZIF'"23H@`*:SKL2IR@"E2*3`Q,&LL+/FINPHL7&R>Z9B
ML%^ZXBD`K<@`O^^H^JW(IML`5F%N=6%T=2`HI<NEHZK\N<\I`,7<I,8`5F5N
M97IU96QA("BI9:2ZM^>IU"D`Q>?#TJ6BL=$@+2"FN;9LI?.E::_@I'>^1*1(
MOM6FV[]YI^\N`*JII;L`JJFEN[&QJ.X`JZNJO;GON_0`JZNJO;G4I5(`JZNJ
MO3H`JT2Q8+"J`%9I970@3F%M("BV5JMN*0"V5JMNI.4@*%9)4T-)22D`P,NU
M^"`E<P"F8K=SM?BUH;9]L=(`I4@@)7,@P,NU^`!6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"`HK5[$W;K[J,JX<ZYQ*0!6:7)G:6X@27-L86YD<RP@52Y3+B`H
MK/S$W;K[J,JX<ZYQ*0"OX*BCJ]<`K^"HHZO7.B``N'&D:J=1I?&\=ZVWN7&K
M2*2]I7&S>KE,(%--5%``Q+6G:0#$M:=I(2$A(+%Q("5S(*3BL,JROK"CM7NF
MH2X`5TE.(+AGI=$@2%144`!786QL:7,@86YD($9U='5N80#$M:=I`*Q0M,&D
M5`"DT:[PN7>T^@"N\+9(N.JNQK2CJ-$`=V5A=&AE<BYC;VT@NO2ON`"Z]*^X
M`+KTK[@`J$.V9P#%=ZKO`,5WJN^H["`E<P#%=ZKO+"`E<P"FZ+S:("A)4T\M
M.#@U.2TQ*0"FZ+S:("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$@**;H
MO+NKHJG4*0"U;J1*J^'`L[C3I?W%XZ7<("5S(*W^I$"MT\"SI<ZU>Z:A/P#$
MYJ;LJKJDP+EJIG*DN#\`I-ZM>JJZJV6X;:9RI+@_`%=H97)E:7,@075S=')A
M;&EA(*9AN<\`K?ZMTZ3KK-L`NO2MMKUSO^B^N:JZM*&E\RAP;'5G:6YS*;'2
ML,JQL:CN+@"\9:O7`*5(($-34R"LL+/FINRJNKQEJ]<`I:K#Y"5SI5ROX*KM
MJKJ\9:O7**15IKBU;J1*J6RES:[$*3H`JNVNYKQEJ]<`O&6KU[/FINP`O&6K
MUSH`MK#%Z;/0IT``K;<`IJVFLZVW`*VWLW0HN&`I`*VWLW0Z`*VWLW0Z(`"T
MO+QZ`+3!J]W"IZJK`*1UIT``O^RDO:O'IF&G?0"_[*2]J\>Y<;C<`++$)62F
MYJJZQ.:F[+S&I=BDHZ6_O50N(,"SN-.M;J:S)62MT\3FINPLI76GY*CL)62M
MT\3FINPN`,3FINR\QJ78I*.EO[U4+B#`L[C3K6ZFLR5DK=/$YJ;L+*5UI^2H
M["5DK=/$YJ;L+@!8-3`Y=C,@J;6F^:KWQE^[>:IK`%@U,#EV,R"E1*:NM,"E
M3J97NMD`6#4P.78S(*5$IJZJ]\9?P]&G3ZK,`%@U,#EV,R"PQL#)IE<`IGX`
MIGX`66%H;V\@(2"F8;G/`*A#IGX`665M96X@*+BMJODI`*Q/`*Q/JKHLI]JF
M4+=.`*=!I=BK9:C/I<ZOPJ3EIG*]<[QGO-*FH2X@J,^ESB!;/#Y=(*OVMG.E
M::3!M*NLL+KTK;:]<[QGO-*FH2X`I*.DN;-<IT&KV*7?)62E2*17JKJPS[;T
M+@"G0:6\LU&QPL5V+@"G0:JZI?ZF5Z2DI*.E:::S("=<)R"S;[S+JKJF<J2X
M+B``IT&HPZ6\O^FD2J1`K=.FLZ[$JKJY<:1LMFRE\Z;LIWTN`*=!J,.EO*71
MMM>D2JJZP,FNUZ2DN>^L3:7TIO/$YJ;LJ.P@)7,`IT&D=[AGM6ZE6"X`O="_
MZ:1*I$"MTZ:SKL2JNKEQN-RXN;U8++#JN]JY<;C<N+F]6+;(I76DN;-<O,:F
M<KBYO5@LJ,.U^+&AJG"E::GSJV6ML:9!I5ND0*W3("<K)RX`IT&ELK:WO^FD
M2J1`K=.FLZ[$JKJMR"X`IT&ELK:WI?VS5[FZIFZ^\*JLN.JNQBA$871A5')E
M92FF^*I!NMVD?J_@Q'[$\JC/I<ZW<Z7.I.&U^:55JD&PR"X`IT&ELK:WI?VS
M5[FZI$"MT[7JP,#`R:[7J'2RSBA61E,IIOBJ0;K=+@"]T+1YK7JPW<-$H4&F
M8J=!ML>P9;#=PT2S^*=II*>K92X`IT&ELK:WO^FD2J:YLW.ULJG2J_RF5JJZ
MNO2G?0"]T*O\J7>M;J=2L*.JNJ;XJD&^N2X`O="K_*EWK6ZR3;"CJKJHSZ7.
MJLPN`+W0J_RI=ZUNLKZPHZJZJ,^ESJK,+@"]T*O\J7>M;K=SO%>JNJC/I<ZJ
MS"X`O="K_*EWK6ZG\[=SJKJHSZ7.JLPN`+W0J_RI=ZUNL/6FYJJZIT"ESBX`
MIT&ELK:WO^FD2K=SI,##_JJZIE>ZV2X`IT&ELK:WM*.HT:1`K=.X<:1JIU&Y
MTJ2ZJKJY<;C<N+F]6`"G0:JZ("5S(+=\M,&D=[E,KLDNO="MJ[=SM6ZD2BX`
MIT&JNKEQI&RV;*7SINVG?0"G0:JZL4BE\Z1(N7&D;+9LI?.F[:=].@"G0:JZ
MN.JP5`"FV[%QIT&JNB`E<R"W?+3!MGVI;*5(J-.G0:JZNO2[VKKTN/2F[*=]
MI'?%W*?S+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!I;*VMZVKMW.U;J1*+@"G
M0:JZIE>ZV0"G0:JZQ>?#TJ;XJD&ZW:C#I*.DY+2IMW.\5ZC/I<ZJS"X@IG"J
M1Z=!I\:QYKK>LGJHSZ7.JLRQ8KBY+*=!I;*VMZ5TO^^HY*5,JKK%Y\/2IOBJ
M0;K=+@"G0:JZQ>?#TKK=J,.EO*3DM*FF0Z58J,^ESJK,J<ZXTZ5<K^"D=[-1
MP_:SK"X`IMNQ<:=!JKH@)7,@MWRTP;9]J6RE2*C3IT&JNL)SQ/V^N:;\I4>D
M=\7<I_,N(*RPJT_%0*=!JKJF=Z7^L%^HHZ%!IT&ELK:WK:NW<[5NI$HN`*=!
MJKK"<\3]OKFHPZ6\I.2TJ;-OK=.E7*_@+@"G0:JZPG/$_;ZYJ,.EO*3DM*FF
M0Z9,O^^VM2Z]T*OV($-44DPO0V]M;6%N9"`K(%`@ID.F3"X`IT&EV*MEJ=*S
M7:EWJKJNR;#/.@"[U:15N7>S7:JZJ*VE]\/1IT^D=\7<I_,N`+O5I%6Y=[-=
MJKJHK:7WP]&G3SH`IT&JNJ7^IE<Z`*=!JKJU;J1*I'>H[+3!+@"G0:9B("5S
M(*2DJKJW<[%+O5BL3SH@)7,`IT&F8K5NI$JTP;:AJKJ_[[:UI'>S4:?SMW,N
M`*=!JKJ_[[:UI'>G\[=S+@"G0:JZL4N]6*1WK:NW<[-=J7<`L4N]6*1WLU&M
MJ[=SLUVI=RRW<ZJZL4N]6*1WLWJY3+EQI&RV;*7SL4BU;[W0I4BXT[%+O5BU
M;J1*+@"G0:JZL4N]6*1WJ.RTP2X`IT&JNKNWNMVF^*I!OKDZ`%EU9V]S;&%V
M:6$@**MNM+6IU*32*0!:86ER92`HPL2E["D`6F%M8FEA("BI?*3QJ,@I`%II
M;6)A8G=E("BHKZ3:J\(I`%O!],+#I-ZM>ET`6[#=PT2DSZQ-70!;Q>.EW*3>
MK7H@+0!;Q>.EW*3>K7H@+2`E<R"FYET`6Z;LJ?.FYB`E<R"F0"`E<R"FYET`
MNMZR>E]!`*E2I4^F0U]#`+[PJJRXZJ[&7T0`IU*PHZ9#7T0`N'.RU5]'`+NA
MJ?I?2`"\=KFSI+JN95])+BXN`+5NI$I?3`"U;J587TP`K=>G[[-SM;)?32XN
M+@"_[[:U7T\`Q7:MK5]0`+*^L*.Y[[-SM;)?4BXN+@"S7:EW7U,`JNVNYJ2Z
MKF5?5"XN+@"HSZ7.JLQ?50"S<;!4O_T`IN:HQK[D`+5,JFNKV*7?O^FE6,#)
MKM<`M4RJ:[9]L=*_Z:1*`*OVIKD`L4NE3Z9#NWFJ:[_YNWX`LUVI=[_YNWX`
MO_*EHJVKK6ZJNJATLL[`R:[7`+CJKL:NYJ:AO_F[?@"GY*2CJ.RP3[_]`,#)
MKM<`L7$@)7,@*"5S*2"I\R`E<R`E<P"P?:VW`*[).@"NR0"EO*J^JKJV;*7S
MI42^]Z97NMD`I=^G60"JO;&UQ>.EW*GSI;NDY;#/`+_II$HOO^FE6+_YNWX`
MI+JSH;-NQ>F_^;M^`*;F70"DP`"F5[K9`*E\I;RYZJ=`+@"I?*6\N>JG0"X`
ML\:GT;_]`*;*I,"D\0"F<ZCZOD2IV@"YLZ_``+-QJTBH\ZEWN[>ZW;_YNWX`
MI%>DR0"U3*5II<ZJNJI!L,@`Q>.EW*YTLJ<`<VUS,F5M86EL(+AGI=$@2%14
M4`"L[0##K:EW`*ATLLZ_^;M^`*O=O^S#KP"\R*[)J<JJNJ6BL=$`ID&FN+_I
MI$JG0:JZL4N]6*5(O52[>[5,NWX`ON.F6`"EO*E2IE<`J,^ESJK,O^^^W`!V
M0V%R9`"L4+3!.@!W96%T:&5R+F-O;2"Z]*^X````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?5%<O:&5L<"YX;6P`````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-30P`#$P-#$W
M,S8R-S<V`#`R,#,W,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)"24<U
M(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O>FA?5%<O:&5L<"YX;6PL
M=B`Q+C,N,3`N,2`R,#`V+S`R+S$P(#$T.C`Q.C(S(&IA;B!%>'`@)"`M+3X*
M/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!M9#4](C8X8V$S,V8W9C!C
M.6%A931C,3`S96(T-S0Y,F-D8S$U(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET
M;&4^I$JD9JVVK;$\+W1I=&QE/@H@/'!A<F$^"B`@LV^MTZVVK;&THZC1J=*F
ML\/VJ?.G0:JZK:O"2;I+K6ZXZK!4H4.HTJ9PH4&EIJ5II4C%XZ7<I5BF8J=!
MJKJFK*7SO6.DI*78JV6FL[18J\JW<[9LI?.A0Z;FJ,:^Y*2DIUFQ3JC3J.RJ
MNJC&L:&A0:5.O^S#KZ2DJKJFLZW^J,>KW;_LJ,:VM:%!MW.[1*I!L,BJNK/,
MMW.N^*ZGM:6UI:%#IM.S;ZC'NDNM;J90KLFD7:5=IW2D1J?6L;:E7*_@H4'$
MM*9PMFRE\[QGIT"A0:O8I=^W<ZJZIN:HQK[DJ,:E\[6EM:6A0PH@/"]P87)A
M/@H@/'!A<F$^"B"FT[-OJ,>Z2ZUNJKJDNJYEI6FE2,7]IT&X9Z71JJFML;!T
MN&VK]K9SIMNFYJ9WL<:A0ZC2IG"A0:=!I6FE2+_OOMRM;J5;I$JM_J1`J,>V
MM:78J.RD2J1FK;:ML:2DJ,.QQJ9#J.2VMJ?'H4,*(#PO<&%R83X*("`\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!M9#4](F(X8V8P864Q.64U-V1F
M83!C,F(Y-C)E-3$V-S@R9C0W(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^
MP+.ESK5[IJ&^R<3]ID,\+W1I=&QE/@H@/'!A<F$^"B`@IF*MMJVQL\REJL/D
MJKJD0+'&N<^NU[K9K+#`LZ7.M7NFH;[)Q/VF0Z%#PDF_[Z17K;&JNJ7TI$"M
MTZ1PN<^EW+%.I6F[M*GVI]:S=*JZI,&TJZGSI*.F4*JZP+.ESK5[IJ&A0PH@
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN
M=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4](F1D.35D9C`W83`S,#,Q
M,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT:71L93ZPOJ9NLUVI=SH@NOO%
M0#H@L/6FYKK[Q4`\+W1I=&QE/@H@("`@/'!A<F$^"B`@(""DQ+_OIKFD0+:U
MI=BA0:9PJD>G0:?&L>:F8K5NI$JJNJ90KLFP]:;FNOO%0*1UIT"A0PH@("`@
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M
M7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB83(Q,38R8V1F
M9C-B,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I=&QE/K"^IFZS7:EW
M.B"Z^\5`.B"]5+M[L/6FYKK[Q4`\+W1I=&QE/@H@("`@/'!A<F$^"B`@(""D
MQ+_OIKFD0+:UI=BA0:9PJD>G0:?&L>:F8K#UIN:Z^\5`I'6G0*MEN]VF0::X
MO'BH1*=!JKJF4+=.H4.G7ZMHJ=*FL[K[Q4"D=:=`L4ZI\[5NI$JKX:;;L,JP
M]:;FH4,*("`@(#PO<&%R83X*("`\+V5N=')Y/@H\+VAE;'`^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]B9U]"1R\`````````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`,#$V-C,P`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+V)G7T)'+TQ#7TU%4U-!1T53+P``````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W
M-@`P,C`T,34`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8F=?0D<O
M3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#0R-C$Q`#$P-#$W,S8R-S<V`#`R,C`U-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````/H````<````[`<``%$!
M``"\#P`````````5```.`````14```@````0%0``#````!D5```+````)A4`
M`"@````R%0``%0```%L5```.````<14```@```"`%0``,@```(D5```X````
MO!4``%0```#U%0``40```$H6```T````G!8```4```#1%@``#0```-<6```2
M````Y18```\```#X%@``&0````@7```'````(A<```P````J%P``#@```#<7
M```#````1A<```4```!*%P``"@```%`7```/````6Q<``!\```!K%P``$0``
M`(L7```,````G1<``#D```"J%P``)P```.07```L````#!@``"H````Y&```
M"@```&08```5````;Q@``"D```"%&```$0```*\8```6````P1@``!8```#8
M&```"````.\8```$````^!@```D```#]&````P````<9```#````"QD```@`
M```/&0``(````!@9```&````.1D```H```!`&0``#````$L9```&````6!D`
M``<```!?&0``$````&<9```K````>!D```0```"D&0``'@```*D9```;````
MR!D``!L```#D&0``,P`````:```O````-!H``"D```!D&@```P```(X:```"
M````DAH```4```"5&@``$````)L:```&````K!H``"\```"S&@``#P```.,:
M```$````\QH```4```#X&@``#0```/X:```;````#!L```T````H&P``!0``
M`#8;```0````/!L``!````!-&P``#P```%X;```+````;AL```\```!Z&P``
M#````(H;```/````EQL``!X```"G&P``(0```,8;```@````Z!L```,````)
M'```$P````T<```4````(1P```P````V'```"0```$,<```;````31P```<`
M``!I'```!@```'$<```)````>!P``!0```""'```!@```)<<```1````GAP`
M`!X```"P'```!````,\<```$````U!P```P```#9'```"@```.8<```%````
M\1P``"````#W'```(````!@=```F````.1T``"D```!@'0``"@```(H=```/
M````E1T``!(```"E'0``$````+@=```7````R1T```8```#A'0``#````.@=
M```,````]1T```T````"'@``*````!`>```K````.1X```@```!E'@``$```
M`&X>```:````?QX```8```":'@``!P```*$>```"````J1X``"4```"L'@``
M!````-(>```/````UQX```<```#G'@``"@```.\>```'````^AX```8````"
M'P``"0````D?```-````$Q\```<````A'P``"@```"D?```$````-!\```<`
M```Y'P``!0```$$?```7````1Q\```(```!?'P``,P```&(?```S````EA\`
M`#@```#*'P``+0````,@```Q````,2```"P```!C(```&@```)`@```)````
MJR````4```"U(````@```+L@```'````OB````P```#&(```$0```-,@```1
M````Y2````D```#W(```"`````$A```)````"B$```H````4(0``%0```!\A
M```%````-2$``"@````[(0``"P```&0A```:````<"$```4```"+(0``(```
M`)$A```R````LB$```4```#E(0``!````.LA```R````\"$``"H````C(@``
M!@```$XB```/````52(```0```!E(@``"0```&HB```#````="(``!4```!X
M(@``$@```(XB```/````H2(``!0```"Q(@``&@```,8B```7````X2(``!<`
M``#Y(@``&P```!$C```9````+2,``!\```!'(P``5P```&<C```$````OR,`
M``0```#$(P``%P```,DC```&````X2,```<```#H(P``!0```/`C```)````
M]B,``$H`````)```.````$LD``!(````A"0``$D```#-)```,````!<E``!I
M````2"4``#T```"R)0``90```/`E``!-````5B8``"X```"D)@``+P```-,F
M```L`````R<``!<````P)P``)0```$@G```R````;B<``#X```"A)P``)0``
M`.`G```A````!B@``#`````H*```'````%DH```-````=B@```4```"$*```
M`P```(HH```@````CB@``"(```"O*```)0```-(H```F````^"@```D````?
M*0``!@```"DI```)````,"D``!,````Z*0``"````$XI```)````5RD```H`
M``!A*0``%````&PI```(````@2D``#\```"**0``!P```,HI```&````TBD`
M``T```#9*0``"P```.<I```O````\RD```P````C*@``"@```#`J```"````
M.RH```8````^*@```P```$4J```H````22H``"8```!R*@``)0```)DJ```H
M````ORH``!````#H*@``<P```/DJ```?````;2L``!0```"-*P``#P```*(K
M```$````LBL```<```"W*P``!0```+\K``!2`0``Q2L```\````8+0``!P``
M`"@M```(````,"T```X````Y+0``)0```$@M```<````;BT```P```"++0``
M!P```)@M```U````H"T``#4```#6+0``4@````PN``!/````7RX``#<```"O
M+@``!0```.<N```6````[2X``!8````$+P``%@```!LO```F````,B\```4`
M``!9+P``$````%\O```.````<"\```<```!_+P``"0```(<O```,````D2\`
M``P```">+P``(P```*LO```7````SR\```T```#G+P``-P```/4O```M````
M+3```"T```!;,```+P```(DP```(````N3```!@```#",```,@```-LP```/
M````#C$``!L````>,0``)0```#HQ```*````8#$```D```!K,0``!P```'4Q
M```#````?3$```,```"!,0``"````(4Q```F````CC$```8```"U,0``#P``
M`+PQ```0````S#$```<```#=,0``"````.4Q```3````[C$``"D````",@``
M!P```"PR```E````-#(``"4```!:,@``)P```(`R```E````J#(``#H```#.
M,@``-0````DS```&````/S,```(```!&,P``"0```$DS```;````4S,```8`
M``!O,P``+@```'8S```-````I3,```@```"S,P``!0```+PS```+````PC,`
M`"(```#.,P``$````/$S```&`````C0```\````)-```$````!DT```.````
M*C0```T````Y-```%````$<T```,````7#0``!,```!I-```*0```'TT```R
M````IS0``"0```#:-```!````/\T```5````!#4``!8````:-0``#````#$U
M```+````/C4``"8```!*-0``!@```'$U```&````>#4```L```!_-0``%P``
M`(LU```%````HS4```X```"I-0``(0```+@U```%````VC4```8```#@-0``
M#0```.<U```/````]34```4````%-@``+P````LV```O````.S8``#P```!K
M-@``)@```*@V```*````SS8```T```#:-@``%````.@V```3````_38``!\`
M```1-P``"0```#$W```2````.S<``!$```!.-P``$@```&`W```J````<S<`
M`"T```">-P``!````,PW```*````T3<``"$```#<-P``!````/XW```%````
M`S@```(````).```+0````PX```$````.C@``!`````_.```!P```%`X```.
M````6#@```4```!G.```!0```&TX```(````<S@``!$```!\.```!P```(XX
M```*````EC@```,```"A.```!0```*4X```&````JS@``",```"R.````@``
M`-8X```F````V3@``"8`````.0``*P```"<Y```K````4SD``"\```!_.0``
M-0```*\Y```9````Y3D```X```#_.0``!P````XZ```"````%CH```4````9
M.@``#P```!\Z```0````+SH``!0```!`.@``"0```%4Z```&````7SH```<`
M``!F.@``"````&XZ```2````=SH```8```"*.@``,@```)$Z```%````Q#H`
M`!D```#*.@``!P```.0Z```>````[#H``#<````+.P``"@```$,[```&````
M3CL``$(```!5.P``*0```)@[```(````PCL``!<```#+.P``!````.,[```)
M````Z#L```,```#R.P``&@```/8[```@````$3P```\````R/```'0```$(\
M```9````8#P``!H```!Z/```&````)4\```>````KCP``",```#-/```)```
M`/$\``!H````%CT```D```!_/0``!@```(D]```>````D#T```<```"O/0``
M!0```+<]```&````O3T```H```#$/0``1P```,\]```K````%SX``$D```!#
M/@``5P```(T^```O````Y3X``%\````5/P``-0```'4_``!A````JS\``#\`
M```-0```)P```$U````<````=4```!L```"20```%P```*Y````J````QD``
M`#$```#Q0```10```"-!```@````:4$``"0```"*00``-P```*]!```@````
MYT$``!4````(0@``"````!Y"```#````)T(``"0````K0@``*P```%!"```E
M````?$(``"@```"B0@``"@```,M"```'````UD(```H```#>0@``'P```.E"
M```#````"4,```0````-0P``!0```!)#```8````&$,```@````Q0P``/0``
M`#I#```(````>$,```@```"!0P``$````(I#```/````FT,``#0```"K0P``
M#````.!#```.````[4,```(```#\0P``!P```/]#```"````!T0``"$````*
M1```*P```"Q$```J````6$0``"T```"#1```$0```+%$``!E````PT0``"L`
M```I10``#P```%5%```0````944```0```!V10``!P```'M%```%````@T4`
M``$`````````MP```)H````\````Y0```*<```!T````````````````````
MB@````````"6````4````'<`````````40```(X```!G````$@```',`````
M`````````"@```"O````D````!T````)````#P```'\``````````````#\`
M``!N````&P```$L```!F`````````/8`````````*@```"T`````````6P``
M``````!4````]0````````")````20```'T`````````J@```$4```"L````
M>P```/,`````````S@```&T````U````[P````````"N````YP```(8````S
M````DP```*T```!:`````````/(```!@````0P```'8`````````3```````
M````````1P`````````@````.@```#D```#:`````````#@````:````,@``
M`(L```!-``````````````!C````;P```*L```#N````X````&$`````````
M``````````!D`````````,P```!>````T````"X```!R````Z```````````
M````-@```-T```"C````VP```(P``````````````-,```!7````%````,D`
M``#4`````@```)D````$````$````!X```#>````M0``````````````H@``
M`$H```#/````(0```)4`````````6````"8````*````+P```"4````^````
MN0```($`````````&0```&@```#Z````:@```-4```"T`````````+$````7
M````Y@````````"2`````````%,```!&````WP```*4`````````7```````
M``!9````G````,L``````````````*D```#(````[````"(`````````90``
M`+(```#M````?@```&P`````````X@```,0````3````````````````````
M``````````"V`````````((```#J````\0```.L```"1````<0```)T`````
M`````````-P```"P````%0```*````#2````%@```,T`````````O@```+@`
M``#T````AP```)X```#%`````````$$`````````EP`````````Q````C0``
M`'@```"_`````````.,`````````#@```%T```#1````0@`````````[````
MX0```'4``````````````$@```!2````3P```(\``````````````'`````(
M````#0```#0```!6````(P```````````````````%4```#9````^0```/@`
M``#8`````````)\````1````UP```+P```#'````U@```*$````]````*P``
M`*@````<````!0````,````+````Q@```+,`````````O0````````#!````
M`````,H`````````\````(`````8````F````+H`````````:P``````````
M`````````'P```!Y````0`````````!Z````)````.0```"#````Z0``````
M``"%````8@```#`````?````]P``````````````#````(@````I````NP``
M`)L`````````1`````````##````A````#<```"D````P````"<`````````
ME````&D````&````!P```$X``````````````"P```#"````I@```%\`````
M("@E<R!D87ES(&%G;RD`("AT;V1A>2D`("AY97-T97)D87DI`"5S("T@3F]T
M:6-E`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`
M)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&ES(')E<75I<F5D`#(T(&AO=7)S
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S
M<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!32]030!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R
M;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=')A=&EO;@!!9',`
M06QI87,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E
M($YA;64`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T<FEB=71E<P!!=71H96YT:6-A=&EO;B!F86EL960`
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`079A
M:6QA8FQE(&9I96QD<SH`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R
M8F5R;W,@=7-E<FYA;64N`$)I<G1H9&%Y`$)O;&0`0F]O:VUA<FMS`$--4P!#
M4D,`0V%L96YD87(`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`
M0V%N8V5L`$-E;&P@4&AO;F4`0V]L;W(@4&EC:V5R`$-O;6EC<P!#;VUP86YY
M`$-O;F9I<FT@4&%S<W=O<F0`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!#;W!Y`$-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@;V)T86EN('!U
M8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B!-
M86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#=70`1$0`1&%I;'D`1&5F875L
M="!)9&5N=&ET>0!$96QE=&4`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`1&ES<&QA>2!/<'1I;VYS`$5D:70`16UA
M:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`
M16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P
M('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA
M;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`
M1F%X`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`
M1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R<P!&;W)U;7,`1G5L;"!.86UE`$=R;W5P($%D;6EN:7-T
M<F%T:6]N`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"X`2&5L<`!(;VUE`$AO;64@061D<F5S<P!(;VUE
M(%!H;VYE`$AO<F1E`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$EC;VYS($]N;'D`26-O;G,@=VET
M:"!T97AT`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN
M=F%L:60@9&%T82!S=6)M:71T960N`$ET86QI8P!*=7-T:69Y($9U;&P`2G5S
M=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N`$QA;F=U86=E`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]G(&EN`$QO9R!O=70`34T`
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-86EL`$UA
M=&-H:6YG(&9I96QD<P!-96UB97)S`$UE;G4@;6]D93H`365S<V%G90!-971H
M;V0`36EM92!4>7!E`$UO9&EF:65D($1A=&4`36]N=&AL>0!->2!!8V-O=6YT
M`$YA;64`3F5T=V]R:P!.979E<@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.
M;P!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;W1E<P!/2P!/<'1I;VYS`$]R
M9&5R960@3&ES=`!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N
M<P!02%`@4VAE;&P`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VX`4&AO;F4`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2X`4F%T:6\`4F5A9`!296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!U
M<V5R.B`E<P!2;VQE`%-13"!3:&5L;`!34T@`4V5L96-T(&$@9W)O=7`@=&\@
M861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T
M(&$@=7-E<B!T;R!A9&0`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3970@
M>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@
M<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4VAO=P!3
M:7IE`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8FUI=`!3=6-C97-S`%1A
M<VMS`%1E>'0@3VYL>0!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4
M:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+@!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE('!R
M;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO
M="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY
M(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E
M<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"X`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I;64@5')A8VMI;F<`
M5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E
M860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N=`!5;F1E<FQI;F4`57!D871E`%5P9&%T92`E
M<P!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97)N86UE`%5S97)N86UE.@!5<V5R
M;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%9A8V%T:6]N`%9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+@!787)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T
M97(@;&]G:6X_`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9
M97,`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U<B!);F9O<FUA=&EO;@!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`6VQI;F4@)7,@;V8@
M)7-=`&9I;&4`=6YN86UE9`!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO
M<F1E(#,N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3$Q+3$Y(#(P.C0T+3`U,#`*
M3&%S="U4<F%N<VQA=&]R.B!-:7)O<VQA=B!096YD978@/&UI<F]`8WEB97)S
M:&%D92YU<SX*3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*
M34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/4-0,3(U,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M"@`@*"5S(.3MZ"#MX.?@Y"D`("CD[>7Q*0`@*.+WY?#@*0`E<R`M(,?@X>7K
MY>;JX``E<R#.X?'K\^;BX/GH(.[OY?#@]NCH("T@S^[RXOKPYN3E[>CE`"5S
M(-/QZ^[BZ/\@[^X@T>_N\.#G\^SE[>CE\NX`)7,@[>7NX?7NY.CL`#(T(/?@
M\>``Q^`@Y.`@ZO#H[_+H\.#RY2#OZ/'L[B#E(.WE[N'U[N3H["#O\^'KZ/?E
M[2!01U`@ZNO^]RX`Q^`@Y.`@[_#NXN7PZ/+E(._NY._H\>#M[B#OZ/'L[B#E
M(.WE[N'U[N3H["!01U`@ZNO^]RX`Q^`@Y.`@Y.7J\.CO\NCPX/+E(._H\>SN
M(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(.KK_O<L(.OH]^7M(.KK_O<@Z"#J
MZ_[W[N+@(/3PX.?@+@#'X"#DX"#O[N3OZ/CE\N4@[^CQ[.X@\>`@[>7NX?7N
MY.CLZ#H@[_/AZ^CWY>T@ZNO^]RP@Z^CWY>T@ZNO^]R#H(.KK_O?NXN`@]/#@
MY^`N`,?@(.3@(.KPZ._RZ/#@\N4@[^CQ[.X@Y2#MY>[A]>[DZ.P@[_/AZ^CW
MY>T@4TU)344@ZNO^]RX`04TO4$T`Q.[AX.+_[>4@[>`@[>[BX"#C\//OX`#$
M[N'@XO_MY2#MX"#M[N+H(._PX.+@`,3NX>#BZ"#M[N(@[^[R\.7AZ/+EZSH`
MQ.[AX.+_[>7R[B#MX"#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M[BX`P.3PY?$`
MP.3PY?'E[2#AY>OEYNWHZ@#`Y.SH[>CQ\O#H\.#MY0#$[N'@XNKH`,_QY>+D
M[NWH[`#"\>CWZN@@X_#S[^@`PO'H]^KH(._PX.+@`,+ZXN7DY>W@\N`@\?+N
MZ>WN\?(@[>4@Y2#D[N_S\?+H[.`N`-#@Y^SE\"#MX"#@\/7HXNWH_R#TX.GK
M`,CLY2#MX"#@\/7HXN``Q.`@\>4@Z/'JX"#KZ"#O[O+B^O#FY.7MZ.4@[_#E
MY.@@[N'QZ_/FXN#YZ/+E(.[OY?#@]NCH/P##\.7XZN`@[_#H(.CG\O#HXN#M
MY2#MX"#MY?'Z^>7Q\N+SXN#YX"#C\//OX"X`P_#E^.K@(._PZ"#HY_+PZ.+@
M[>4@[>4@[>7Q^OGE\?+B\^+@^>@@[_#@XN`N`,/PY?CJX"#O\.@@\.7DX.KR
MZ/#@[>4@[>`@[>7Q^OGE\?+B\^+@^>@@[_#@XN`N`,#R\.CA\_+H`,/PY?CJ
MX"#O\.@@Z.3E[?+H].CJX/;H_P#(Y.7M\NCTZ.K@]NC_\N`@X>7XY2#N\O7B
M^O#KY>W@(.[R(%)!1$E54R#Q^O#B^O#@+@#-X.OH]^WH(._NZ^7RX#H`S>7B
MX.OHY.W@(&ME<F)E<F]S("#OX/#NZ^`N`,WEXN#KZ.3M[B!K97)B97)O<R#O
M[O+PY>'H\N7K\>KN(.CLY2X`T.[FY.7M(.3E[0#3Y.7AY>OE[>@`SO+LY?+J
MZ`!#35,`0U)#`,K@Z^7MY.#P`,/PY?CJX"#O\.@@\>+Z\.?BX.WE(/$@[.7I
MZR#Q^O#B^O`Z("5S`,[RZN#FZ`#,[N'HZ^7M(/+EZ^7T[NT`R.?AZ/#@[>4@
M[>`@]N+_\@#*[NSHZO'H`,KN[._@[>C_`,_N\N+Z\.3E\N4@[^#P[NO@\N``
MQ.[Q\OKOX"#D[B#O\^'KZ/?MZ/\@\?KPXOKP(.'E^.4@[O+JX.?@[2X`RN[O
MZ/#@Z0##\.7XZN`@[_#H(%!'4"#J\.CO\NCPX.WE\NX@[>`@[^CQ[.XN`,/P
MY?CJX"#O\.@@4$=0(._NY._H\>+@[>7R[B#MX"#OZ/'L[BX`P_#E^.K@(._P
MZ"#DY>KPZ._RZ/#@[>7R[B#MX"!01U`@Y.#M[>@N`,WEZN[PY>KRY>T@96UA
M:6P@X.3PY?$@[>`@[^[K\_?@\N7K_RX`P_#E^.K@(._PZ"#O[NOS]^#BX.WE
M\NX@[>`@[_/AZ^CW[>C_(.KK_O<@[O(@ZNO^]RWQ^O#B^O#@+@#-Y>+ZY^SN
MYNWN\?(@Y.`@\>4@[O+B[O#H(,[A\>OSYN+@^>A?Y^#DX/?H(.SNY//K("5S
M(`#HY_#EYN@`Q,0`Q>;EY.WEXNWN`,CDY>WRZ/?M[O'R(._N(._NY/#@Y^'H
M\.#MY0#(Y_+PZ.D`Q.7RX.GKZ/+E(.'_]>`@\.7CZ/'R\.CPX.WH(.?@(.#D
M[.CMZ/'R\.#R[O#@+@#$Z/'OZ^7I(,[O]NCH`-#EY.#J]NC_`,_H\>SN`,5M
M86EL(.#D\.7Q`$5M86EL(.#D\.7QZ/+E(/+P_^'BX"#DX"#Q^N+OX.3@\BX`
MS_#@Y^7M(/#EY_/K\N#R+@##\.7XZN``PO'EZN@@,34@[.CM\_+H`,+QY>KH
M(#,P(/'EZO/MY.@`PO'EZN@@-2#LZ.WS\N@`PO'_ZNX@Z^[CXN#MY0#-X"#B
M\>7JZ"#O[NONXNCM(/?@\0#"\?_JX"#LZ.WS\N``S_#H[.7P[>@@\?+NZ>WN
M\?+H.@#-Y>+ZY^SNYNWN\?(@Y.`@\>4@Y^#PY>3_\B#O\.7TY?#E[?;HZ/+E
M+@#-Y>+ZY^SNYNWN\?(@Y.`@\>4@[O'Z^>7Q\N+H(.+P^N?JX"#Q($Q$05`@
M\?KPXOKP+@##\.7XZN`@[_#H(/'B^O#GXN#MY2#Q^O$@4TU"(/'Z\.+Z\"X`
MU.#J\0#!\.[I(/3@Z>ONXN4Z("5S(/3@Z>L`P?#NZ2#TX.GK[N+E.B`E<R#T
MX.GKX`#4X.GK(.SE[>#FY?``R.SE(.W@(/3@Z>L`R.?O\.#YX.WE\NX@[>`@
M].#IZ^[BY2#MY2#QY2#O[N3D^O#FX"X`U.CK\OKP`-3N\//LZ`#([.4@[>`@
M].#IZP#`Y.SH[>CQ\O#H\.#MY2#MX"#C\//OZ`##\//OZ`#/\.#BX"#GX"#C
M[O'RZ`!(5%10(.CDY>WRZ/3HZN#VZ/\@[>4@Y2#MX.SE\.7MX"X`S^[L[OD`
MS>#WX.ON`,3N[.#XY>T@X.3PY?$`Q.[LX/CE[2#RY>OE].[M`$AO<F1E`,/P
MY?CJX"#O\.@@\?KGY.#BX.WE(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S
M`,/PY?CJX"#O\.@@Z.?R\.CBX.WE(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z
M("5S`,/PY?CJX"#O[O#@Y.@@ZN+N\N`@[_#H(/'ZY^3@XN#MY2#MX"!)34%0
M(._N^>7M\>K@(.KS\NC_.B`E<P!)4"#@Y/#E\>`@[>4@Y2#B(._NY^+NZ^7M
MZ/\@0TE$4B#AZ^[J+@#1X.SN(.CJ[NWH`,CJ[NWH(/$@\N7J\?(`R.SO[O#R
MZ/#@[>X@[^[KY3H@)7,`R.SO[O#RZ/#@[>@@[^[KY?+@.@#(Y^_PX/+E[>CR
MY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N`,W@ZNON[>7MZ`#O^NOM[B#O[N3PX.+M
M_^+@[>4`Z__B[B#O[N3PX.+M_^+@[>4`Y/_Q[>X@[^[D\.#B[?_BX.WE`$ME
M<F)E<F]S(/'Z\.+Z\.`@[O+UXOKPZ^@@Z.3E[?+H].CJX/;H__+@+@#*Z_[W
MX"#BY??E(/'Z^>7Q\N+SXN`@XB#O\^'KZ/?MZ/\@ZNO^]_'Z\.+Z\"X`Q>?H
MZ@#/[NSN^2#RY>SH`-'OZ/'ZZN`@\2#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M
M+@#"]>[D`,CG]>[D`,S,`$U3+51.148@[_#HZO#E[^7MZ/_R(/3@Z>L@[>4@
M\?KD^O#FX/CE(.3@[>WH+@#/[OG@`-'ZXN_@Y.#YZ"#O[NOE\N``U^OE[>[B
MY0#"Z.0@[>`@[.7M_O+N.@#/Z/'L[@#,Y?+NY`!-:6UE(/+H[P#$X/+@(.W@
M(._P[NSE[?_MY0#,Y?'E]^WN`,SN__+@(,_N^>``R.SE`,SPY>;@`,WHZN[C
MX`#-[N+N(._N\O#EX>CRY>OQZNX@Z.SE("CN[_;H[NW@Z^WN*0#-Y0#-_^S@
M(.?@Y.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!&5%`@5D93+@#-_^S@(.?@Y.#D
MY>W@(.KN[?3HX_/PX/;H_R#GX"!344P@5D93+@#-_^S@(.?@Y.#DY>W@(.KN
M[?3HX_/PX/;H_R#GX"!344PM1FEL92!61E,N`,W_[.`@Y^#DX.3E[>`@[^#P
M[NO@(.?@($E-05`@Z.3E[?+H].CJX/;H_RX`S?_LX"#GX.3@Y.7MX"#OX/#N
MZ^`@Y^`@2V5R8F5R;W,@Z.3E[?+H].CJX/;H_RX`S?_LX"#J[NWTZ./S\.#V
MZ.[M[>`@Z.WT[O#LX/;H_R#GX"!334(@Z.3E[?+H].CJX/;H_RX`POKP[>#R
MZ/+E(.3@[>WH(.WE(/'@(%A-3`#-_^S@(/'R[NGM[O'RZ`#!Y>OEYNKH`,[*
M`,[O]NCH`,_NY/#EY.7M(/'OZ/'ZZ@#$\//CX"#H[?3N\.S@]NC_`,_PX.+@
M(.W@(._PZ/+EYN#RY>O_`%!'4"!3:&5L;`#/X/#NZ^``S^#P[NO@.@#/X/#N
MZ^`Z(`#-Y>KN\.7J\NW@(._@\.[KX"X`PNSZZNWH`,3@(/'E(.CGXOKP^.+@
M\B#KZ"#NX?'K\^;BX/GH\N4@[N_E\.#VZ.@@[_#H(,+U[N0_`,_PX.+@`,#D
M[.CMZ/'R\.CPX.WE(.W@(._PX.+@\N``TN7KY?3N[0#,[NO_+"#B^N+EY.7R
MY2#LY?'E]B#H(./NY.CMX"X`RNO^]^[BX"#DXN[IZN`@[_/AZ^CWY>TO]^#Q
M\N7M(.KK_O<@[>4@X>7XY2#CY>WE\.CPX.W@+@#*[N7TZ/;HY>WR`-?E\N7M
MY0#(\>K@\N4@Y.`@Z.?R\.CE\N4@)7,@Z^@_(-+@Y^@@[N_E\.#VZ/\@[>4@
M[.[FY2#DX"#QY2#B^O#MY2#MX.?@Y"X`P.3PY?$@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`S_#E[.#U[>@`S_#E[.#U[>@@[^[R\.7A
MZ/+EZSH@)7,`T.[K_P!344P@4VAE;&P`4U-(`,CGX>7PY?+E(./P\^_@(.?@
M(.3NX>#B_^WE`,CGX>7PY?+E(.WNXB#O\.CRY>;@\N7K(.W@(./P\^_@`,CG
MX>7PY?+E(/'Z\.+Z\`#(Y^'E\.@@[^[R\.7AZ/+EZR#GX"#D[N'@XO_MY0#(
MY^'E\.7RY2#$X/+@(/#@Y^3EZ^CRY>LZ`,CGX>7PY?+E(/3N\.S@\B#GX"#$
MX/+@\N`Z`,CGX>7PY?+E(/3N\.S@\B#GX"#7X/'@.@#(Y^'E\.7RY2#DXN4@
M\?KB[^#DX/GH(._NZ^7RX#H`R.?AY?#E\N4@XN#XX/+@(/'UY>S@(.?@(/;B
MY?+NXN7RY2X`R.?AY?#E\N4@[_#EY._N]^CRX.WH__(@[O(@PN#Q(.7GZ.HZ
M`,?@Y.#I\N4@PN#XY?+N(.W@]^#K[>X@[_#HZ^[FY>WHY2P@\?7E[.`@Y^`@
M]N+E\N[BY2P@[N_PY?'M_^+@[>4@[>`@\?+PX.WH]N#RX"#H(.3P\^/H(.[O
M]NCH(.?@(.3H\>_KY?\N`,_NZN#GXN#MY0#0X.?LY?``POKBY>;DX.WE(.W@
M(/'OY?;HX.OMZ"#QZ.SB[NOH`,CG[_#@\N@`T_'OY?4`Q^#DX/?H`-'@[.X@
M\N7J\?(`S_#HZO#E[^7MZ/_R(%!'4"#O[N3OZ/$@Y2#MY>[A]>[DZ.P@Y^`@
MY.`@\>4@[_#NXN7PZ"#O[N3OZ/'@[>[R[B#OZ/'L[BX`RO#H[_+H\.#MY?+N
M(.CGZ/'JXN`@ZO#H[_+H\.#MX"!W96(@XO#ZY^K@+@#,Y?'R[N_NZ^[FY>WH
MY?+N(.W@($=N=5!'(/3@Z>O@(/+P_^'BX"#DX"#A^N3E(.3@Y.7M;R#MX"!#
M<GEP=%]P9W`Z.B!C;&%S`,_P[N/PX.S@\N`L(.KN__+N(/'K\^;H(.?@(._N
MZN#GXN#MY2#MX"#R[N?H(/+H[R#DX.WMZ"`H)7,I(.WE(.'E^.4@[O+J\.CR
MX"#B(/'H\?+E[.#RX`#-_^S@(.3B[NGJZ"P@ZN[H\NX@Y.`@X?KDX/(@[^[J
MX.?@[>@@XB#KZ.WH__+@+@#([.`@\N+Z\.3E(.SM[N/N(/'H[.+NZ^@@XB#R
M[N+@(._NZ^4N(,+ZXN7KZ"#Q\N4@)7,@\>CLXN[KX#L@\O#_X>+@(.3@(.+Z
MXN7DY?+E(._N+>S@Z^KN(.[R("5S+@##\.7XZN`@[_#H(.CG[_#@^>#MY?+N
M(.W@(/3@Z>O@.B`E<R#MY2#AY?CE(.CG[_#@\N7M+@#([.#XY2#O\.[AZ^7L
M(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX"X@)7,@Y2#O[BWC[NO_["#N\B#L
MX.KQZ.S@Z^WN(.3N[_/Q\NCLZ/\@\.#G[.7P("@E9"#AX.GRX"DN`,/PY?CJ
MX"#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`N("5S(.'E^.4@\>#L[B#N\O?@
M\?+H(.CG[_#@\N7M+@##\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J
M[NWRX.KRZ"X`TN[BX"#MY2#E(.+@Z^CDY>T@<F%R(.#P]>CB+@#2[N+@(.WE
M(.4@XN#KZ.3E[2!Z:7`@].#IZRX`TN[BX"#O[NOE(.4@[>7NX?7NY.CL[BX`
MTN[BX"#O[NOE(.SNYN4@Y.`@\?KD^O#FX"#QX.SN(/;EZ^@@]^CQZ^`N`-+N
MXN`@[^[KY2#L[N;E(.3@(/'ZY/KPYN`@\>#L[B#WZ/'KX"#H(.3B[N7R[O?H
MY2X`TN[BX"#O[NOE(/+P_^'BX"#DX"#E(.?@[^7RX/\@Z.OH(.CM\N7PXN#K
M(/#@Y^3EZ^7M(/'OZ/'ZZB#O\.[LY>WKZ.+H`-+@Y^@@].[P[.`@XN7WY2#A
MY?CE(.[A\.#A[O+E[>`N`-+NXN`@]^CQZ^X@\O#_X>+@(.3@(.4@[^[MY2#E
MY.CMZ/;@+@#2[N?H(/'Z\.+Z\"#MY2#L[N;E(.3@(.3EZN[L[_#E\>CPX"!Z
M:7`@Z"!G>FEP(/3@Z>ONXN4N`-+@Y^@@\?+NZ>WN\?(@\O#_X>+@(.3@(.4@
M]^CQZ^XN`,_P[O'KY>3_XN#MY2#MY2#B\.7LY0#$Z_KF[>[Q\@!54DP`S>7B
M^N?L[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N`,/PY?CJX"#O\.@@
M[O+BX/#_[>7R[B#MX"#J[NSO\.7QZ/#@[2#@\/7HXBX`P_#E^.K@(._PZ"#W
MY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+@##\.7XZN`@[_#H(._PY>+NY.`@
M[>`@\N[GZ"!7;W)D(.3NZO/LY>WR`,_NY/?E\/+@[>@`SN_PY?'MZ`#.[_#E
M\>WH("5S`,#D[.CMZ/'R\.CPX.WE(.W@(._N\O#EX>CRY>OH\N4`R.SE`,CL
MY3H`R.SE.B``S^[R\.7AZ/+EZ^@@XB#QZ/'RY>S@\N`Z`,+@ZN#M]NC_`,/P
MY?CJX"#O\.@@[_#NXN7PZN#RX"`M(/+NXN`@[^CQ[.X@[.[FY2#DX"#E(.'H
MZ^X@[^[D[_#@XN7M[BX`PNWH[.#MZ.4`T>7D[.CW[>X`Q.[A\.4@Q.[XZ^@@
MXB`E<P#$[N'PY2#D[OCKZ"P@)7,`R.?AY?#E\N4@[_#HZ^[FY>WHY?+N+"#J
M[N7R[B`E<R#DX"#O[NK@YN4@\>OEY"#B]>[D+@#!Z.?MY?$@X.3PY?$`P>CG
M[>7Q(/+EZ^7T[NT`P\,`P^[DZ/CM[@#$X`#-Y2#B^N+EY.[U\N4@XN#KZ.3E
M[2!E;6%I;"#@Y/#E\2X`TO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@
MY^`@Z.?R\.CBX.WE+@#2\/_AXN`@Y.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#G
MX"#D[N'@XO_MY2X`TO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@
M[N_PY?'M_^+@[>4N`,CM].[P[.#VZ/\@Y^`@PN#Q`,+@^.C_\B#HY.7M\NCT
MZ.K@]NCN[>7M(.3PX.GBY?`@[>4@[^[DY/KPYN`@\>_H\?KJ(.W@(._N\O#E
MX>CRY>OH\N4L(.CKZ"#RX.?H(.+ZY^SNYNWN\?(@Y2#GX.'PX.WE[>`N`,+@
M^.CRY2#J[NWTZ./S\.#VZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"X`PN#X
MZ/+E(/'Z\.+Z\.@Z`%OKZ.WH_R`E<R#N\B`E<UT`].#IZP#AY><@Z.SE`'9#
M87)D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O8F=?0D<O:&5L<"YX;6P`````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-#$W,S8R-S<V
M`#`R,#(W-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E
M+VQO8V%L92]B9U]"1R]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R
M.C$V(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y
M(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^
M"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@
M<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@
M1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I
M;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG
M(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O
M"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E
M<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL
M(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L
M('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A
M=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A
M<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G
M92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&
M;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC
M;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC
M:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P
M;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@
M=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P
M;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS
M(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY
M('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N
M"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN
M=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA
M:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L
M;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C
M:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC
M92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F
M;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@
M;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V)S7T)!+P``````````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-@`P,38V
M,S8`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8G-?0D$O3$-?3453
M4T%'15,O````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8R-S<V`#`R,#0R,P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]B<U]"02],0U]-15-304=%4R]H;W)D92YM;P``````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-34T,S<`,3`T,3<S-C(W-S8`,#(R,#<T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-X2!)4`````C0$`
M`!P```"$#```'0(``.P8````````8"$```X```!A(0``#0```'`A```(````
M?B$```L```"'(0``#````),A```$````H"$```P```"E(0``"P```+(A```%
M````OB$``"@```#$(0``"````.TA```*````]B$``!4````!(@``$@```!<B
M```+````*B(```H````V(@``#0```$$B```.````3R(``!$```!>(@``#0``
M`'`B```,````?B(```T```"+(@``!@```)DB```,````H"(```X```"M(@``
M#@```+PB```(````RR(``!H```#4(@``!0```.\B```1````]2(```@````'
M(P``$````!`C```/````(2,```H````Q(P```P```#PC```)````0",```\`
M``!*(P``"@```%HC```D````92,``!0```"*(P``#````)\C```L````K",`
M``L```#9(P``!P```.4C```'````[2,```,```#U(P``(P```/DC```4````
M'20``!<````R)```%P```$HD```?````8B0```4```"")```.0```(@D```&
M````PB0``!0```#))```"@```-XD```$````Z20```<```#N)```"0```/8D
M```&`````"4``!$````')0``!P```!DE```6````(24```0````X)0``"```
M`#TE```&````1B4```T```!-)0``!@```%LE```>````8B4``!$```"!)0``
M"````),E```-````G"4```P```"J)0``!P```+<E```#````OR4```,```##
M)0``$P```,<E```(````VR4```@```#D)0``"````.TE```@````]B4```8`
M```7)@``!@```!XF```5````)28``!4````[)@``%````%$F```8````9B8`
M`!T```!_)@``!@```)TF``!4````I"8```4```#Y)@``!0```/\F```;````
M!2<``!H````A)P``$0```#PG```1````3B<``!P```!@)P``*@```'TG```0
M````J"<```4```"Y)P``$P```+\G```0````TR<```<```#D)P``!P```.PG
M```$````]"<```X```#Y)P``!@````@H```-````#R@``!`````=*```$@``
M`"XH```H````02@```4```!J*```!````'`H```(````=2@```<```!^*```
M#0```(8H```0````E"@```L```"E*```!@```+$H```9````N"@``!@```#2
M*```%````.LH```+`````"D```D````,*0``%@```!8I```/````+2D``!8`
M```]*0``"````%0I```+````72D```0```!I*0``#P```&XI```0````?BD`
M`!<```"/*0``$0```*<I```-````N2D```D```#'*0``(````-$I```1````
M\BD```<````$*@``!0````PJ```'````$BH```@````:*@``!@```",J```&
M````*BH``!`````Q*@``#P```$(J```0````4BH```\```!C*@``"P```',J
M```/````?RH```P```"/*@``#P```)PJ```(````K"H```<```"U*@``!```
M`+TJ```0````PBH```(```#3*@``#0```-8J```2````Y"H``!4```#W*@``
M!`````TK```%````$BL```0````8*P``#````!TK```*````*BL```@````U
M*P``"0```#XK```%````2"L```H```!.*P``&0```%DK```I````<RL```<`
M``"=*P``"@```*4K```,````L"L```\```"]*P``$````,TK```/````WBL`
M``<```#N*P``%@```/8K```$````#2P```0````2+```!P```!<L```(````
M'RP``"`````H+```#0```$DL```.````5RP``!8```!F+```$0```'TL```&
M````CRP```,```"6+```!@```)HL```'````H2P```<```"I+```!P```+$L
M```6````N2P```T```#0+```!0```-XL```>````Y"P```D````#+0``"@``
M``TM```,````&"T```\````E+0``"````#4M```&````/BT```<```!%+0``
M"P```$TM``!'````62T```T```"A+0``"0```*\M```*````N2T``&@```#$
M+0``!0```"TN```;````,RX``"\```!/+@``$````'\N```*````D"X```\`
M``";+@``"@```*LN```)````MBX```,```#`+@``!P```,0N```*````S"X`
M``L```#7+@``!P```.,N```)````ZRX```<```#U+@``$````/TN```$````
M#B\```<````3+P``!0```!LO```-````(2\```P````O+P``"````#PO```7
M````12\```L```!=+P``$P```&DO```$````?2\```H```""+P``!````(TO
M```,````DB\```D```"?+P``!0```*DO```'````KR\```4```"W+P``!```
M`+TO```"````PB\``"$```#%+P``!````.<O```4````["\```@````!,```
M!P````HP```0````$C````<````C,```#@```"LP```%````.C```!$```!`
M,```"````%(P```&````6S````<```!B,```'@```&HP```H````B3````H`
M``"R,```&@```+TP```4````V#```"@```#M,```*@```!8Q```0````03$`
M``<```!2,0``$P```%HQ```-````;C$``!X```!\,0``%````)LQ```.````
ML#$``"H```"_,0``!0```.HQ```1````\#$```<````",@``%`````HR```8
M````'S(```P````X,@``!@```$4R```/````3#(``"<```!<,@``&0```(0R
M```?````GC(``!,```"^,@``"````-(R```'````VS(```@```#C,@``"0``
M`.PR```5````]C(```T````,,P``$P```!HS```#````+C,``$8````R,P``
M/P```'DS```W````N3,``%<```#Q,P``!0```$DT```*````3S0```T```!:
M-```+0```&@T```$````EC0``"4```";-```'P```,$T```=````X30```0`
M``#_-```$`````0U```;````%34```<````Q-0``!P```#DU```$````034`
M`!\```!&-0``)P```&8U```C````CC4``!\```"R-0``+P```-(U```A````
M`C8``!P````D-@``,0```$$V```"````<S8``!0```!V-@``#````(LV```'
M````F#8```\```"@-@``%````+`V```=````Q38```<```#C-@``,@```.LV
M```A````'C<```P```!`-P``$0```$TW```(````7S<```<```!H-P``!P``
M`'`W```&````>#<```<```!_-P``#0```(<W```+````E3<``!0```"A-P``
M%0```+8W```.````S#<``"\```#;-P``,0````LX```_````/3@```8```!]
M.````P```(0X```U````B#@``!D```"^.```,````-@X```2````"3D``!,`
M```<.0``$````#`Y``!Y````03D```D```"[.0``*P```,4Y```7````\3D`
M`!8````).@``#P```"`Z```?````,#H``$````!0.@``'P```)$Z```<````
ML3H``%$```#..@``%````"`[```*````-3L```4```!`.P``!@```$8[```(
M````33L```4```!6.P``$@```%P[```0````;SL``!,```"`.P``'0```)0[
M```/````LCL```\```#".P``!````-([```)````USL```L```#A.P``!P``
M`.T[```%````]3L``!0```#[.P``!P```!`\```(````&#P```\````A/```
M"````#$\```,````.CP```\```!'/```!@```%<\```4````7CP```8```!S
M/```#````'H\```)````ASP```<```"1/```!0```)D\```+````GSP``'4!
M``"K/```$````"$^```-````,CX```@```!`/@``"````$D^```'````4CX`
M``,```!:/@``"@```%X^```-````:3X```4```!W/@``'P```'T^```.````
MG3X```H```"L/@``$0```+<^```/````R3X```H```#9/@``"0```.0^```1
M````[CX```X`````/P``"@````\_```+````&C\```T````F/P``"0```#0_
M```&````/C\```\```!%/P``#P```%4_```/````93\```<```!U/P``&@``
M`'T_```%````F#\```X```">/P``#0```*T_```8````NS\``!(```#4/P``
M#0```.<_```%````]3\```P```#[/P``%@````A````,````'T```!\````L
M0```$````$Q````&````74```#8```!D0```"@```)M````(````ID````4`
M``"O0````P```+5````E````N4```!<```#?0```%P```/=````@````#T$`
M`!\````P00``!0```%!!```K````5D$```8```""00``%@```(E!```+````
MH$$```4```"L00``"````+)!```*````NT$```,```#&00``$````,I!```&
M````VT$``!,```#B00```P```/9!```'````^D$```,````"0@``#0````9"
M```&````%$(``"8````;0@``$0```$)"```(````5$(``!````!=0@``#```
M`&Y"```'````>T(```,```"#0@```P```(="```2````BT(```@```">0@``
M!P```*="```'````KT(``"4```"W0@``!@```-U"```(````Y$(``!P```#M
M0@``$P````I#```5````'D,``!L````T0P``'P```%!#```(````<$,``%$`
M``!Y0P``!````,M#```$````T$,``"$```#50P``'````/=#```/````%$0`
M`!@````D1```(@```#U$```K````8$0```\```",1```!@```)Q$```6````
MHT0```H```"Z1```!@```,5$```)````S$0```<```#61```$````-Y$```'
M````[T0```P```#W1```#`````1%```6````$44``#L````H10``!@```&1%
M```%````:T4```@```!Q10``"@```'I%```/````A44``!$```"510``"@``
M`*=%```&````LD4``!T```"Y10``&0```-=%```D````\44```0````61@``
M"@```!M&```D````)D8```X```!+1@``%@```%I&```(````<48```L```!Z
M1@``"````(9&```0````CT8``!````"@1@``%@```+%&```5````R$8```P`
M``#>1@``"````.M&```H````]$8``!4````=1P``"````#-'```&````/$<`
M``@```!#1P``"````$Q'```'````54<```8```!=1P``$````&1'```/````
M=4<``!$```"%1P``#P```)='```1````IT<``!````"Y1P``"P```,I'```5
M````UD<```<```#L1P``!P```/1'```"````_$<```T```#_1P``!0````U(
M```/````$T@``!(````C2```&````#9(```%````3T@```@```!52```!P``
M`%Y(```-````9D@```X```!T2```"````(-(```)````C$@```4```"62```
M"0```)Q(```8````ID@``"P```"_2```!@```.Q(```*````\T@```L```#^
M2```$`````I)```/````&TD``!`````K20``!@```#Q)```6````0TD```0`
M``!:20``!````%])```)````9$D```4```!N20``(0```'1)```/````EDD`
M`!(```"F20``(````+E)```5````VDD```<```#P20``!0```/A)```(````
M_DD```4````'2@``!@````U*```(````%$H``!P````=2@``"P```#I*```'
M````1DH``"<```!.2@``!0```'9*```+````?$H``!$```"(2@``&@```)I*
M```(````M4H```H```"^2@``!0```,E*```.````STH``%(```#>2@``%0``
M`#%+```*````1TL```H```!22P``2@```%U+```$````J$L``"4```"M2P``
M-P```--+```0````"TP```@````<3```$@```"5,```+````.$P```H```!$
M3````P```$],```'````4TP```T```!;3```"P```&E,```&````=4P```@`
M``!\3```"````(5,```4````CDP```,```"C3```!0```*=,```&````K4P`
M``\```"T3```#P```,1,```+````U$P``",```#@3```"P````1-```5````
M$$T```<````F30``"@```"Y-```%````.4T```\````_30``"0```$]-```%
M````64T```@```!?30```P```&A-```$````;$T```(```!Q30``*````'1-
M```'````G4T``!<```"E30``"````+U-```'````QDT``!$```#.30``!@``
M`.!-```,````YTT```8```#T30``$@```/M-```%````#DX```4````43@``
M"````!I.```9````(TX``"T````]3@``!P```&M.```D````<TX``!$```"8
M3@``-0```*I.```U````X$X``!`````63P``"````"=/```-````,$\```X`
M```^3P``(P```$U/```:````<4\``!````",3P``+````)U/```'````RD\`
M``\```#23P``!P```.)/```9````ZD\``!4````$4```#@```!I0```%````
M*5```!`````O4```+````$!0```4````;5```!@```""4```&````)M0```+
M````M%````<```#`4```"````,A0```)````T5```!(```#;4```#0```.Y0
M```5````_%````<````240``2````!I1``!'````8U$``#P```"K40``8@``
M`.A1```(````2U(```<```!44@``"P```%Q2```L````:%(```<```"54@``
M+P```)U2```F````S5(``!<```#T4@``"`````Q3```/````%5,``!L````E
M4P``!````$%3```(````1E,```4```!/4P``)P```%53```F````?5,``!H`
M``"D4P``%@```+]3```Q````UE,``"\````(5```'@```#A4```T````5U0`
M``(```",5```$P```(]4```/````HU0```X```"S5```#@```,)4```:````
MT50``",```#L5```"````!!5```X````&54``!\```!250``$0```')5```6
M````A%4```X```";50``"0```*I5```*````M%4```@```"_50``"P```,A5
M```1````U%4```\```#F50``%````/95```5````"U8```X````A5@``+```
M`#!6``!$````758``$H```"B5@``"````.U6```"````]E8``#,```#Y5@``
M(P```"U7```U````45<``!(```"'5P``$@```)I7```0````K5<``(````"^
M5P``"````#]8```F````2%@``!@```!O6```%@```(A8```3````GU@``!P`
M``"S6```,@```-!8```3`````UD``!<````760``3@```"]9```6````?ED`
M``L```"560``!````*%9```'````IED```@```"N60``!0```+=9```7````
MO5D``!(```#560``&0```.A9```D`````EH```X````G6@``#P```#9:```$
M````1EH```D```!+6@``"P```%5:```&````85H```8```!H6@``$0```&]:
M```+````@5H```8```"-6@``$0```)1:```'````IEH```@```"N6@``#P``
M`+=:```'````QUH``!(```#/6@``"@```.):```&````[5H```X```#T6@``
M"0````-;```%````#5L```L````36P```0```,<```!B`0``````````````
M````B@```$$!```7````8P````T```!I````'P```(\`````````%P$`````
M````````]P```%(````I`0``M````(D!``````````````H!``"F````@P``
M`+\````?`0``9@```(T!``"D``````````````!M`0``_````&@!``"?````
M`````+L```"R``````````````"G````BP````````!"`0``1P```!(!````
M`````````%D```!\`0``;@$``/L``````````````/````!U````W@```-L`
M``#X````?P``````````````E````"X````"`0``<`$``'X`````````=@$`
M`$P```"H````+````#0!``#5`````````#8```!8`0```````"\```!0`0``
M7@$`````````````J@```$L!``!Y````!```````````````2@```&<!``#+
M````(P$``%L!``!@`0``1`$`````````````(`$``*$`````````+0$`````
M```R````EP```#<!``#6````)`$```,`````````Z0```!P```!5````````
M`(4````1`0```````*X```````````````,!```U````[P```($```"2````
M6````&H!``"K`````````,T````_`0`````````````(````'`$``),```!N
M````B```````````````^@````D```"E`````````(P!``!9`0```````$,!
M```S`````````"T`````````@@$``%8!``!\``````````H```##````````
M`((```!)`0``G@````````````````````````!<`0```````!8```!W````
MK````-<```!6````F@```&H````/`0```````,````#*````.````-0```#F
M`````````-H```"'````C@````L`````````C````'(````1````3P$``#$!
M```O`0``)0$``,0``````````````!T`````````50$`````````````!@$`
M`"X!````````ZP```-@`````````M0```````````````````!0`````````
M1@$``)$````S`0``G``````````]````SP```'H`````````B0```'0````Q
M`````````$(````J````'@$``#L```!K`0``5P````X!``"\````-@$`````
M``"=````P0```$L```#R````&0```#4!`````````````%(!````````````
M`+X```"I````(@```#X!``#D````)P$```````!0`````````/$```!=`0``
M?@$````````$`0``%@$``,(````E`````````(````!V``````````````#M
M````&0$``&@```"!`0``^0````````#3````#@```'`````5````N0```(8`
M``!_`0```````.X```#G````!0````````"&`0``2``````````^````%0$`
M`&\!``#=````@P$``.``````````3@$``"8```";````B`$`````````````
MO0```!H!````````*P$``(`!``!S`0``T0```+H```"9````<P```!@````W
M`````````-\```!*`0``L0```#H`````````_P```#\`````````H```````
M```Y````2`$``#````#A````.0$``&P```#<````4P$```@!``#J````-```
M`$T````I````10```'<!``#,`````````$D``````````````'D!``!:`0``
MV0`````````R`0``/`$```````"-````A`$```<```![````Z````(4!```4
M`0``AP$``'@!``!A`0```````````````````````-`````0`0```````"L`
M```,`0```````!H`````````40```'T`````````&P`````````H`0``/```
M``````!:````.P$``/,```!G`````````"(!````````!0$`````````````
M!@```!X```"*`0```````*,````````````````````L`0``(0$``%P```!`
M`0``8````'0!````````*@$``+@```#L````,`$``$````#]````7P$``&(`
M``!Z`0``&`$``)4``````````````&$````]`0``:P```%L`````````;P``
M```````G````"P$``+8```!=````7P`````````X`0``]0```!(````"````
ML````+<````3``````````````!,`0``T@```$X```#^````:0$``$T!``"8
M````<@$``$$```!E````H@```,4````=`0```````*\```!$````(P```.4`
M``!#````#P```&P!````````8P$``)````!&`````````+,````'`0``R0``
M`/8`````````9```````````````1P$```````````````````P`````````
MX@````````!F`0``K0```'T!``!U`0```````#H!``#.````10$``%0`````
M````4P```"0```!X````>P$``'$`````````Q@`````!```;`0``5P$``(0`
M```-`0``40$```````#T`````````!````#(````5`$``$\````H````XP``
M```````F`0``E@`````````A`````````"````!E`0````````D!``!>````
M`0$``&0!````````<0$``!,!``!M````BP$````@*"5S(&1A>7,@86=O*0`@
M*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y
M*0`@870@`"5D("5S(&%N9"`E<P`E<R`M($YO=&EC90`E<R!+0@`E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S
M(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI
M<W1S+@`E<R!A="`E<R`E<P`E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@
M=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E
M<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+2T@<V5L96-T("TM
M`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D`$%-+U!-`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C
M8V]U;G1I;F<`061D`$%D9"!(97)E.@!!9&0@82!N97<@=7-E<CH`061D(&-O
M;'5M;@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D
M('1O(&%D9')E<W,@8F]O:SH`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%F9VAA;FES=&%N`$%L
M8F%N:6$`06QG97)I80!!;&P`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@
M4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!<')I;`!!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`075G=7-T
M`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA
M`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!"
M;W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O
M=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I
M=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T
M`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U]E;&P@4')O<&5R=&EE
M<RXN+@!#86QE;F1A<@!#86UB;V1I80!#86UE<F]O;@!#86XG="!C;VYN96-T
M('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#871E9V]R:65S(&%N9"!,86)E;',`0V5L=&EC("A)4T\M
M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R
M;W!E86X@*$E33RTX.#4Y+3(I`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP
M;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H
M;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQE87(`0VQE87(@
M35-/9F9I8V4@=&%G<P!#;VQO=7(@<V5L96-T:6]N`$-O;6]R;W,`0V]M<&%N
M>0!#;W!Y`$-O<'D@<V5L96-T:6]N`$-R96%T90!#<F5A=&4@82!L:6YK`$-R
M96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-U<W1O;6EZ92!T
M87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`1&%I;'D`1&%T90!$96-E
M;6)E<@!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$
M969I;FET:6]N<P!$96QE=&4`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`
M1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&]W;FQO
M860`1&]W;FQO860@)7,`161I=`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M
M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@
M9F]R.@!%;6%I;"!!9&1R97-S`$5M;W1I8V]N<P!%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M
M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!&96)R=6%R>0!&:6QT97)S`$9R;VT`
M1G5L;"!$97-C<FEP=&EO;@!';P!';V]G;&4@4V5A<F-H`$=R965K("A)4T\M
M.#@U.2TW*0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5L<`!(;U]M90!(;VUE
M`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(
M;W)D90!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`26-E;&%N
M9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E
M;G1I='DG<R!N86UE.@!);G-E<G0@;65S<V%G97,`2F%N=6%R>0!*87!A;F5S
M92`H25-/+3(P,C(M2E`I`$IU;'D`2G5N90!,85]Y;W5T`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@57!D871E9#H`
M3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO
M9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96)A;F]N`$QE<V]T:&\`
M3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`
M3&EN:W,`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI=&AU86YI
M80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C
M871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3'5X96UB
M;W5R9P!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+@!-87)C:`!-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H
M:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87D`365M8F5R<P!-
M96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`36EM92!4>7!E`$UO;G1H
M;'D`37D@4&]R=&%L($QA>6]U=`!.86UE`$YE='=O<FL`3F5V97(`3F5W($-A
M;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO
M<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S
M`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="X`3F]N90!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W9E;6)E
M<@!/8W1O8F5R`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O
M<B`E<P!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!096]P;&4`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T
M:6]N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R
M979I;W5S(&]P=&EO;G,`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%)E
M860@;65S<V%G97,`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E
M9G)E<V@@4&]R=&%L(%9I97<Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!297-E=`!2971U<FX@
M=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<P!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C
M="!A('-E<G9E<@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!3
M35,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT
M96YE9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@
M;W!T:6]N<RX`4V5T=7``4V5Y8VAE;&QE<P!3:&]R="!3=6UM87)Y`%-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W
M`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/P!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I`%-U8FIE8W0`4W5C8V5S<P!497AT`%1H86YK('EO
M=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($]P=&EO;G,@=VEN9&]W(&AA
M<R!C;&]S960N($5X:71I;F<N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4;P!4=7)K:7-H("A)4T\M.#@U.2TY
M*0!5;F1O($-H86YG97,`56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D
M($%R86(@16UI<F%T97,`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`
M56YN86UE9`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E
M<RX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N86UE`%9I
M97<@)7,`5V%R;FEN9P!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E
M;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX
M.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!996%R;'D`665S`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!H879E(&)E96X@;&]G9V5D
M(&]U="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R($YA;64`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W
M;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L
M96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?
M26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@
M3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN
M`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B
M;V]K`'1A<VL@;&ES=`!U;FYA;65D`'9#87)D`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@:&]R9&4M8G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`W+3`Q
M(#$S.C,Q*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!6961R86X@3&IU8F]V:6,@
M/'9L:G5B;W9I8T!S;6%R=&YE="YB83X*3&%N9W5A9V4M5&5A;3H@0F]S;FEA
M;B`\;&]K86Q`;&EN=7@N;W)G+F)A/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,@I#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E@M1V5N97)A=&]R.B!+0F%B
M96P@,2XQ,`H`("AP<FEJ92`E<R!D86YA*0`@*'IA("5S(&1A;F$I`"`H9&%N
M87,I`"`H<W5T<F$I`"`H:G7H92D`('4@`"5D("5S(&D@)7,`)7,@+2!.87!O
M;65N80`E<R!+0@`E<R!397)V:7-N92!O<&5R86-I:F4@+2!P;W1V<F1A`"5S
M('!O9&6Y879A;FIE`"5S('!R:6IA=F$`)7,@=7-L;W9I('5G;W9O<F$`)7,@
M=F7F('!O<W1O:FDN`"5S('4@)7,@)7,`)7,@;6EN=71A`"5S(&YI:F4@<')O
M;F'P96XN`"5S('IA("5S(&]D("5S`"5S(&%D<F5S87(`)7,@:V%L96YD87(`
M)7,@8FEL:F6^;FEC80`E<R!Z861A8VD`)7,Z("5S`"TM(&EZ86)E<FET92`M
M+0`Q,BUS871N:2!F;W)M870`,C0M<V%T;FD@9F]R;6%T`#(T('-A=&$`1&^Y
M;&\@:F4@9&\@9F%T86QN92!G<F6Y:V4`04TO4$T`3R!O=F]M(&5D:71O<G4`
M3R!P<F]G<F%M=2XN+@"I:69R82!K;W)I<VYIZ&MO9R!N86QO9V$`3F%L;V<@
M:F4@>F%M<GIN=70N`%)AZ'5N;W9O9'-T=F\`1&]D86H`1&]D86H@;W9D:F4Z
M`$1O9&%J(&YO=F]G(&MO<FES;FEK83H`1&]D86H@:V]L;VYU`$1O9&%J("5S
M(&UE;FD@=2!-;WII;&QA(%-I9&5B87(`1&]D86H@=2!A9')E<V%R.@!);65N
M:6L`061M:6YI<W1R:7)A;FIE("T@<&]D9;EA=F%N:F4@9&]Z=F]L82!D<G5G
M:6@@:V]R:7-N:6MA`$%F9V%N:7-T86X`06QB86YI:F$`06R^:7(`4W9E`$1O
M>G9O;&D@<')A=FQJ96YJ92!N=6UE<FES86YI:"!L:7-T:3\`06QT97)N871I
M=FYI($E-4U`@;&]G:6X`06QT97)N871I=FYA($E-4U`@N6EF<F$`06QT97)N
M871I=FYO($E-4U`@:V]R:7-N:>AK;R!I;64`56YEN65N82!J92!I;&5G86QN
M82!V<FEJ961N;W-T+@!!<')I;`!0:71A:B!P<FEJ92!O8F%V;&IA;FIA('-E
M<G9I<VYI:"!O<&5R86-I:F$_`$%U9W5S=`!"86QT:>AK:2`H25-/+3@X-3DM
M,3,I`%9R<W1A(&)L;VMA`$UA<VYO`$)O;&EV:6IA`%IA8FEL:F6Y:V4`4G5B
M`$1E8FQJ:6YA(')U8F]V83H`4G5B;W9I`$)O<VYA(&D@2&5R8V5G;W9I;F$`
M3V)A`$)O8W9A;F$`1&YO`$)O=79E="!O<W1R=F\`0G)A>FEL`$)R:71A;G-K
M82!);F1I:G-K;RU/:V5A;G-K82!497)I=&]R:6IA`$)R=6YE:2!$87)U<W-A
M;&%M`$)U9V%R<VMA`$QI<W1A('-A('1AZ&MA;6$`0G5R:VEN82!&87-O`$)U
M<G5N9&D`0TU3`$-20P!/<V]B:6YE(.9?96QI:F4N+BX`2V%L96YD87(`2V%M
M8F_P80!+86UE<G5N`$YE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E
M<CH@)7,`2V%N861A`$]D=7-T86YI`$]D=7-T86YI(&]D('!R:6IA=F4@<')O
M8FQE;6$`2V%T96=O<FEJ92!I(&]Z;F%K90!+96QT<VMI("A)4T\M.#@U.2TQ
M-"D`0V5N=')A;&YO+4%F<FGH:V$@4F5P=6)L:6MA`$-E;G1R86QN;RUE=G)O
M<'-K:2`H25-/+3@X-3DM,BD`4')O;6IE;FD`4')O;6EJ96YI=&4@:6UE(&D@
M861R97-U(&MO:F4@=FED92!D<G5G:2!K861A(.AI=&%J=2!I(&]D9V]V87)A
M:G4@;F$@=F&Y92!P;W)U:V4N`,AI;&4`2VEN80!+:6YE<VMI('!O:F5D;F]S
M=&%V;&IE;FD@*$=",C,Q,BD`2VEN97-K:2!T<F%D:6-I;VYA;&YI("A":6<U
M*0!)>F%B97)I=&4@N6EF<G4`27IA8F5R:71E(&MO<FES;FGH:V\@:6UE`$EZ
M86)E<FET92!K86MO('-E('!R:6MA>G5J92!D871U;3H`27IA8F5R:71E('9R
M<W1U('-T:6QA("AZ82!N=6UE<FES86YE(&QI<W1E*0!5<VMRN6YJ92!O<W1R
M=F\`3^AI<W1I`$_H:7-T:2!-4T]F9FEC92!T86=O=F4`27IB;W(@8F]J90!+
M;VUO<FD`2V]M<&%N:6IA`$MO<&ER86H`2V]P:7)A:B!I>F%B<F%N;P!+<F5I
M<F%J`$YA<')A=FD@;&EN:P!.87!R879I(&YO=FD`4')A=FQJ96YJ92!P;V0M
M9F]L9&5R80!0;V1E<VET92!Z861A=&ME(&MO:FD@YF4@<V4@:7IV<KEA=F%T
M:2!N86MO;B!P<FEJ879E(&YA("5S+@!$;F5V;F\`1&%T=6T`1&5C96UB87(`
M4W1A;F1A<F1N;P!3=&%N9&%R9&YA(&)O:F$`1&5F875L="!I9&5N=&ET970`
M1&5F:6YI8VEJ90!/8G)IN6D`0G)I<V%N:F4@:2!I>F)A8VEV86YJ92!P;W)U
M:V$`3V)R:;EI(&EZ86)R86YI(&ED96YT:71E=`!/<&FY:71E('!R;V)L96UE
M('4@<F%D=2!S82!W96)M86EL;VT`3W!I<P!$:7)E:W1O<FEJ`%!R:6MAOFD@
M=G)I:F5M92!U(#(T+7-A=&YO;2!F;W)M871U/P!/<&-I:F4@<')I:V%Z80!0
M<FEK8;YI('!R;V=N;WIU("A4048I`$1O=VYL;V%D`$1O=VYL;V%D("5S`$EZ
M;6EJ96YI`$EZ;6EJ96YI(&1O>G9O;'4`27IM:6IE;FD@9&]Z=F]L90!)>FUI
M:F5N:2!D;WIV;VQE('IA("5S`$EZ;6EJ96YI=&4@;W!C:6IE('IA.@!%;6%I
M;"!A9')E<V$`4VUA:FQI:FD`06MT:79I<F%J(&MO;G1E:W-T(&UE;FD@;F$@
M9&5S;F]M(&ML:6MU/P!%:W9A=&]R:6IA;&YA($=V:6YE:F$`17)I=')E:F$`
M1W)EN6MA`$5S=&]N:6IA`$5T:6]P:6IA`$5T;FGH:VD`179R;W!A`%-V86MI
M:"`Q-2!M:6YU=&$`4W9A:VEH(#(@;6EN=71E`%-V86MI:"`S,"!S96MU;F1I
M`%-V86MI:"`U(&UI;G5T80!+;V0@<W9A:V4@<')I:F%V90!3=F%K:6@@<&]L
M82!S871A`%-V86MI(&UI;G5T`%9R:6IE9&YO<W1I('!R:6UJ97)I.@!&96)R
M=6%R`$9I;'1E<FD`3V0`1&5T86QJ86X@;W!I<P!+<F5N:0!';V]G;&4@<')E
M=')A9V$`1W+H:VD@*$E33RTX.#4Y+3<I`$AE8G)E:G-K:2`H25-/+3@X-3DM
M."U)*0!0;VUOY@!0;^A?971A:P!0;^AE=&%K`$%D<F5S82`H:W7F:2D`5&5L
M969O;B`H:W7F:2D`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$E0(&%D<F5S
M80!)4"!A9')E<V$@;FEJ92!D;W-T=7!N82X`25`@861R97-A(&YI:F4@9&]Z
M=F]L:F5N82!U;G5T87(@0TE$4B!B;&]K82X`27-L86YD`%-A;6\@:6MO;F4`
M26MO;F4@>F$@)7,`26MO;F4@<V$@=&5K<W1O;0!);64@:61E;G1I=&5T83H`
M1&]D879A;FIE('!O<G5K80!*86YU87(`2F%P86YS:VD@*$E33RTR,#(R+4I0
M*0!*=6QI`$IU;FD`4F%?<W!O<F5D`$IE>FEK`$QA;R!.87)O9&YA($1E;6]K
M<F%T<VMA(%)E<'5B;&EK80!:861N:F$@:7IM:F5N83H`6F%D;FIA('!R:6IA
M=F$Z("5S`%IA9&YJ82!P<FEJ879A.B`E<R!S82!A9')E<V4Z("5S`%IA9&YJ
M82!P<FEJ879A.B!.:6MA9`!,871V:6IA`%IA:V]N`%)A<W!O<F5D`$QI8F%N
M`$QE<V]T;P!,:6)E<FEJ80!,:6)I:G-K82!!<F%P<VMA($2^86UA:&ER:6IA
M`$QI:'1E;KET86IN`$QI;FMO=FD`3&ES=&%N:F4@+2!K;W)I<VYI:R!M;[YE
M('9I9&IE=&D@9F]L9&5R`$QI='9A`%7H:71A=F%M+BXN`$QO:V%L;F\@=G)I
M:F5M93H@`$QO:V%L;F4@<&]S=&%V:V4@:2!V<FEJ96UE`$QO:V%C:6IA`%!R
M:6IA=FD@<V4`27IL87H`6F%D86-I('!R:6IA=F4`4')I:F%V82!N:6IE('5S
M<&IE;&$N($YA:G9E<F]V871N:6IE(&IE('!O9W)EN6YO('5N97-E;F\@:V]R
M:7-N:>AK;R!I;64@:6QI(+EI9G)A+@!0<FEJ879A(&YI:F4@=7-P:F5L82X`
M1'5G:2!T96MS=`!,=6MS96UB=7)G`$YA<')A=FET92!K871E9V]R:6IE('-T
M879K:2!I('IA('-V86MU(&]D(&YJ:6@@;V1R961I=&4@;V1G;W9A<F%J=>9U
M(&)O:G4N`$UA<G0`3WIN8>AA=F%N:F4@:V%O('!R;^AI=&%N;R]N97!R;^AI
M=&%N;P!/>FYAZ&%V86YJ92!D<G5G:6T@;WIN86MA;6$@*&YP<BX@=F&^;F\@
M:6QI(&]D9V]V;W)E;F\I`$UA<KEA;&]V82!O<W1R=F$`36%R=&EN:6L`3V1G
M;W9A<F%J=>9A('!O;&IA`$UA=7)I=&%N:6IA`$UA=7)I8VEJ=7,`36%J`,AL
M86YO=FD`5G)S=&$@;65N:6IA.@!3<&]J:2!P;VQJ80!0;W)U:V$`36EM92!T
M:7``36IE<V7H;F\`4F%S<&]R960@;6]G('!O<G1A;&$`26UE`$UR9;YA`$YI
M:V%D80!.;W9A($MA;&5D;VYI:F$`3F]V82!K871E9V]R:6IA`$YO=FD@;6IE
M<V5C`$YO=F\@:V]R:7-N:>AK;R!I;64@*&YI:F4@;V)A=F5Z;F\I`$YO=FD@
M6F5L86YD`$YO=FD@<')O>F]R("A?<')A>F%N*0!.;W9O<W1I`$YE=W,M9W)U
M<&4`1&%L:F4`4VQJ961EYF4@;W!C:6IE`$YI:V%R86=V80!.:6=E<@!.:6=E
M<FEJ80!.;^8`3FEU90!.90!.:6IE('!O<VQA;F\@:V]R:7-N:>AK;R!I;64@
M:2]I;&D@N6EF<F$N`$YI:F5D86X`3F]R9&EJ<VMI("A)4T\M.#@U.2TQ,"D`
M3F]V96UB87(`3VMT;V)A<@!/<&5R871I=FYI('-I<W1E;0!/<&-I:F4`3W!C
M:6IE('IA("5S`$]S=&%L;P!/<W1A;&4@:6YF;W)M86-I:F4`J6EF<F$`3&IU
M9&D`4')O8V5N870`27IV<KEI('-E<G9I<VYE(&]P97)A8VEJ90!)>G9RN6D@
M<V5R=FES;F4@;W!E<F%C:6IE('!R:6QI:V]M(&QO9VER86YJ83\`1&]Z=F]L
M90!!9&UI;FES=')A8VEJ82!D;WIV;VQA("AP<FEV:6QE9VEJ82D`3&GH;F4@
M:6YF;W)M86-I:F4`36]L:6UO(&1A:G1E(&MR871A:R!O<&ES('9AN65G('!R
M;V)L96UA('-A('=E8FUA:6QO;2X`4VQA;FIE('4@;W9A:B!F;VQD97(@*&YI
M:F4@<')I;G7P96YO(&]D('-T<F%N92!)34%082D`4')E=&AO9&YE(&]P8VEJ
M90!0<F]B;&5M/P!/<&ES('!R;V)L96UA`,AI=&%N:F4@<&]R=6MA`$&^=7)I
M<F%J(&1I;F%M:>AK92!E;&5M96YT92!M96YI:F$Z`$&^=7)I<F%J('!OZ&5T
M;G4@<W1R86YI8W4Z`%5D86QJ96YI('-E<G9E<FD`561A;&IE;FD@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4&]N:;ET:0!.87IA9"!N
M82!O<&-I:F4`4F5U;FEO;@!6<F%T:2!S=&%R=2!K;VYF:6=U<F%C:6IU`$]P
M8VEJ92!E9&ET;W)A('1E:W-T80!38>AU=F%J(&]P8VEJ90!4<F&^:0!)>F%B
M97)I=&4@<V5R=F5R`$EZ86)E<FET92!I9&5N=&ET970@:V]J:2"^96QI=&4@
M<')O;6EJ96YI=&DZ`$EZ86)E<FET92"Y96UU(&)O:F$N`$EZ86)E<FET92"^
M96QJ96YI(&IE>FEK.@!0;[EA;&II('!R:6IA=G4@<')O8FQE;6$`4&^Y86QJ
M:2!335,`4V5N96=A;`!396YZ;W(Z(`!397!T96UB87(`4W)B:6IA(&D@0W)N
M82!';W)A`%-E<FEJ<VMI(&)R;VH`240@<V5S:6IE(&IE(&ES=&5K86\N`$]D
M86)E<FD`4&]D97-I=&4@;W!C:6IE(&MO:F4@=F%M(&]M;V=UYG5J=2!D82!P
M;VYIN71I=&4@N6EF<G4@86MO(&IE('IA8F]R879I=&4N`%!O9&5S:71E('5D
M86QJ96YE('-E<G9E<F4@:V]J:6UA(+YE;&ET92!P<FES='5P:71I('!U=&5M
M('9AN65G('!O<G1A;&$N`$]D86)E<FET92"^96QJ96YI(&IE>FEK+"!V<F5M
M96YS:W4@>F]N=2!I('!O<W1A=FME('IA(&1A='5M+@!0;V1E<VET92!S=&%R
M=&YU(&MO;7!O;F5N='4L(+EE;74@8F]J82P@;W-V:F6^879A;FIE('-T<F%N
M:6-E(&D@9')U9V4@;W!C:6IE(&MO:F4@<V4@=&GH=2!P<FEK87IA+@!0;W-T
M879K90!396JY96QI`$MR871A:R!O<&ES`$1A(&QI(&1E9FEN:7-A=&D@<')I
M<W1U<&YE('1I<&ME('IA(&QI;FMO=F4_`%!R:6MAOFD`4')I:V&^:2!V<FEJ
M96UE('IA9&YJ92!P<FEJ879E(&YA:V]N(&QO9VER86YJ83\`4')I:V&^:2!M
M96YI('IA(&UA;FEP=6QA8VEJ92!T86)E;&%M83\`4')I:V&^:2`E<R!M96YI
M(&QI:F5V;S\`5F5L:>AI;F$`4')E<VMOZ&D@<V5R=FES`$IUOFYO+65V<F]P
M<VMI("A)4T\M.#@U.2TS*0!496UA`%5S<&IEN6YO`%1E:W-T`$AV86QA(+ET
M;R!K;W)I<W1I=&4@16YE<F=O9&%T82!W96)M86EL+@!0<F]Z;W(@>F$@;W!C
M:6IE('-E('IA='9O<FEO+B!)>FQA>FEM+@!)9&5N=&ET970@(B5S(B!J92!O
M8G)I<V%N+@!.96UA(&1O<W1U<&YI:"!O<&-I:F$N`$1E<VEL82!S92!G<F6Y
M:V$@=&]K;VT@<')I:V%Z82!O=F]G(&1I:F5L82!P;W)U:V4`5G)I:F5D;F]S
M="!O=F]G(&)R;VIA(&UO<F$@;F%J;6%N:F4@:7IN;W-I=&D@,2X`3W9A('9R
M:6IE9&YO<W0@;6]R82!B:71I(&)R;VHN`$]V86H@<')O>F]R('-E('-M:6IE
M('!O>FEV871I('-A;6\@:7H@<')O>F]R82!/<&-I:F4`6F$`5'5R<VMI("A)
M4T\M.#@U.2TY*0!0;VYIN71I(&EZ;6IE;F4`3F5K871E9V]R:7-A;F\`56YI
M:V]D("A55$8M."D`56IE9&EN:F5N:2!!<F%P<VMI($5M:7)A=&D`3F5P;WIN
M871O(&MO<FES;FGH:V\@:6UE(&EL:2"Y:69R82X`0F5Z:6UE;FD`2V]R:7-T
M:71E(&]V;R!A:V\@<V4@:6UE+[EI9G)A(')A>FQI:W5J=2!Z82!)35-0('-E
M<G9E<BX`2V]R:7-N:6L@)7,@;F5M82!D;WIV;VQU('IA("5S+@!+;W)I<VYI
MZ&ME(&]P8VEJ90!296=I<W1R86-I:F$@:V]R:7-N:6MA`$MO<FES;FGH:V\@
M:6UE`%!R:6MA>B`E<P!5<&]Z;W)E;FIE`%-E9&UIZ&YO`$1O8G)O(&1ON6QI
M`$1O8G)O(&1ON6QI(&YA("5S`$1O8G)O(&1ON6QI+"`E<P!:87!A9&YI("A)
M4T\M.#@U.2TQ*0!:87!A9&YI("A)4T\M.#@U.2TQ-2D`6F%P861N82!386AA
M<F$`2V]J=2!K;VUP;VYE;G1U(.9E("5S('!R:6MA>F%T:2!N86MO;B!U;&%Z
M83\`2V]J92!D;V1A=&ME(+YE;&ET92!A:W1I=FER871I('IA(&5D:71O<B!F
M;W)M871I<F%N;V<@*')I8V@I('1E:W-T82X`J6ER:6YA("5S(&UE;FEJ82!S
M82!L:6IE=F4@<W1R86YI8V4@*'-T=7!A(&YA('-N86=U(&MO9"!S;&IE9&7F
M92!P<FEJ879E*3H`1V]D:;EN:F4`1&$`3F4@;6^^92!S861ROF%V871I("=<
M)R!K87)A:W1E<B!U('1V;VT@<'5N;VT@:6UE;G4N`$]D:F%V;&II=F%N:F4@
M:F4@=7-P:F6Y;F\@:7IV<KEE;F\N`"`E<R!S97-I:F$@:F4@:7-T96ML82X@
M36]L:6UO(&1A('-E('!O;F]V;R!P<FEJ879I=&4N`%9AN6$@92UM86EL(&%D
M<F5S80!68;EA($9R;VTZ(&%D<F5S83H`5F&Y92!I;F9O<FUA8VEJ90!68;EA
M($EN=&5R;F5T(&%D<F5S82!J92!P<F]M:6IE;FIE;F$@;F%K;VX@<')I:F%V
M;&II=F%N:F$@;F$@)7,N($1A(&)I('9AN6$@<VEG=7)N;W-T(&)I;&$@<V'H
M=79A;F$L(&UO<F%T92!S92!P;VYO=F\@<')I:F%V:71I+@!68;EE(&EM90!6
M8;D@8G)O=W-E<B!N92!P;V1ROF%V82!O=G4@;6]G=>9N;W-T+@!4<F5N=71N
M82!V<F5M96YS:V$@>F]N83H`5F&Y(&1E9F%U;'0@:61E;G1I=&5T.@!68;EE
M(&EM92!I('!R97II;64Z`%9AN6$@;F]V82"Y:69R82!Z82`E<R!J93H@)7,`
M5F&Y92!O<&-I:F4@<W4@<V'H=79A;F4@=&]K;VT@=')A:F%N:F$@;W9E('-E
M<VEJ92X`3W!C:6IE('-U('-AZ'5V86YE+@!68;EA(+EI9G)A(&IE('!O;FFY
M=&5N80!68;EA(+EI9G)A(&IE('!O;FFY=&5N82P@<')O=FIE<FET92!V8;D@
M92UM86EL(&D@<')I:F%V:71E('-E('-A(&YO=F]M(+EI9G)O;2X`5F&Y:2!U
M9&%L:F5N:2!S97)V97)I.@!*=6=O<VQA=FEJ80!:86ER`%IA;6)I:F$`6FEM
M8F%B=F4`6FEP<'D`6U-A:W)I:B!C:71I<F%N:2!T96MS=%T`6U!R:6IA=F$@
M<')O8FQE;6%=`%M0<FEK8;YI(&-I=&ER86YI('1E:W-T("T`6U!R:6MAOFD@
M8VET:7)A;FD@=&5K<W0@+2`E<R!R961O=F%=`%MR960@)7,@;V0@)7-=`%]!
M9&UI;FES=')A8VEJ80!?0TQ)`%]$871A5')E90!?3V)R:;EI(')E9`!?1W)U
M<&4`7U!O;6_F`%]/<V]B:6YE('-L:6ME+BXN`%]0<FEJ879I('-E`%])>FQA
M>@!?27IM:6IE;FD@;&EN:RXN+@!?3W!C:6IE`%]$;WIV;VQE`%]5:VQO;FD@
M;&EN:RXN+@!?4&]D97-I`$]S;V)I;F4@7W1A8F5L92XN+@!?2V]R:7-N:6-I
M`&EM96YI:P!L:7-T82!Z861A=&%K80!B97H@:6UE;F$`=D-A<F0`=V5A=&AE
M<BYC;VT`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8V%?15,O
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S<V`#`Q-C8T,@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]C85]%4R],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`,#(P-#(W`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V-A7T53+TQ#7TU%4U-!1T53
M+VAO<F1E+FUO````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#`Q,@`Q,#0Q
M-S,V,C<W-@`P,C(P-C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````WA($E0````!D````'````#P#``")````7`8```````"`
M"```*````($(```(````J@@```4```"S"```"````+D(```'````P@@```4`
M``#*"```'P```-`(```1````\`@```@````""0``"`````L)```5````%`D`
M``H````J"0``#````#4)```'````0@D``"D```!*"0```@```'0)```%````
M=PD``!````!]"0``%````(X)```O````HPD```\```#3"0``)@```.,)```%
M````"@H```T````0"@``!0```!X*```0````)`H``!`````U"@``#P```$8*
M```+````5@H```\```!B"@``#````'(*```/````?PH``!X```"/"@``(0``
M`*X*```#````T`H```0```#4"@``#````-D*```*````Y@H```4```#Q"@``
M$@```/<*```0````"@L```@````;"P``$````"0+```&````-0L```<````\
M"P```@```$0+```$````1PL```\```!,"P``!P```%P+```'````9`L```0`
M``!L"P``!0```'$+```%````=PL```<```!]"P``$0```(4+```(````EPL`
M`!X```"@"P``!0```+\+```H````Q0L``"D```#N"P``$P```!@,```+````
M+`P``!$````X#```!````$H,```,````3PP``!H```!<#```%P```'<,```7
M````CPP``!L```"G#```'P```,,,```3````XPP``!````#W#```%P````@-
M```'````(`T```4````H#0``(0```"X-```<````4`T```4```!M#0```P``
M`',-```@````=PT``"8```"8#0``#````+\-```,````S`T```@```#9#0``
M!P```.(-```&````Z@T```T```#Q#0``"P```/\-```,````"PX```H````8
M#@```@```",.```&````)@X``$4````M#@``,````',.```0````I`X``!\`
M``"U#@``$````-4.```/````Y@X```4```#V#@``70$``/P.```J````6A``
M``@```"%$```!0```(X0```-````E!````8```"B$```!0```*D0```C````
MKQ```!(```#3$```"@```.80```)````\1```!(```#[$```$0````X1```/
M````(!$```D````P$0``,````#H1```"````:Q$```H```!N$0``&````'D1
M```7````DA$``#<```"J$0``%P```.(1```H````^A$```4````C$@``#@``
M`"D2```%````.!(```X````^$@``#@```$T2```-````7!(``!0```!J$@``
M#P```'\2```*````CQ(``!(```":$@``)0```*T2```I````TQ(```,```#]
M$@``!0````$3```1````!Q,``!(````9$P``!0```"P3```1````,A,``!``
M``!$$P``!@```%43```5````7!,```8```!R$P``$````'D3```"````BA,`
M``8```"-$P``$P```)03```(````J!,```L```"Q$P```P```+T3```#````
MP1,```4```#%$P``!P```,L3```0````TQ,```L```#D$P``(P```/`3```'
M````%!0``"\````<%```/0```$P4```7````BA0```T```"B%```$````+`4
M```&````P10```T```#(%```)@```-84```A````_10``"`````?%0``)P``
M`$`5```F````:!4```X```"/%0``$@```)X5```>````L14```0```#0%0``
M!@```-45```I````W!4``"$````&%@``!0```"@6```#````+A8``"H````R
M%@``+@```%T6```-````C!8``!````":%@``!@```*L6```$````LA8```P`
M``"W%@``#P```,06```-````U!8``!(```#B%@``$P```/46```"````"1<`
M``D````,%P``0P```!87``!'````6A<``!0```"B%P``)````+<7```6````
MW!<``!````#S%P``!0````08```!````)`````````!.````'0```$\````7
M````10````<````B`````````$T````A`````````$L```!B````"@```!$`
M````````#````#(```!3````,0`````````E````1@```%T`````````4@``
M`$(```!5`````````$<````L````+P```%8```!1````-0```!`````(````
M/@```$$```!?````*P````\````Y````2@```",````8````,P```$`````H
M````8`````L``````````````%0``````````````#T````)`````````"X`
M``!(````7````#H`````````#@````````!9`````````#8`````````&P``
M`#\````<````&@````T````[``````````0````%`````````!(`````````
M$P````````!7````+0`````````F```````````````5````!@````````!;
M````-P```!D`````````7@`````````X````-`````````!)````'P```%H`
M``!$`````````!X``````````````&,`````````6````"D`````````,```
M````````````/````&0```!0`````````!8````@``````````,```!A````
M0P```"H````G````3`````(`````````%``````E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N`#(T(&AO=7)S`$%-+U!-`$%D9"!P
M86ER`$%D9')E<W,`06QI87,`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+@!!=F%I;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!#86QE;F1A<@!#86YC
M96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`0V]M
M<&%N>0!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<P!$1`!$86EL>0!$969A=6QT($ED96YT:71Y`$1E<V-R:6)E('1H92!0<F]B
M;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R`$5V
M97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T
M97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%
M>&%M<&QE('9A;'5E<SH`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`2&5L<`!(
M;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!,86YG=6%G90!,:7-T($AE;'`@5&]P:6-S
M`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE<W-A
M9V4`36]N=&AL>0!.86UE`$YE=F5R`$YO=&5S`$]P=&EO;G,`3W1H97(@26YF
M;W)M871I;VX`4&%S<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O
M8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O
M<F0`4')O8FQE;2!$97-C<FEP=&EO;@!296UO=F4@<&%I<@!2971U<FX@=&\@
M3W!T:6]N<P!2;VQE`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I
M;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T
M`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5C
M8V5S<P!487-K<P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`
M5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:71L90!54DP`56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S97(@3W!T:6]N
M<P!5<V5R;F%M90!787)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@26YF;W)M871I;VX`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=
M`%ML:6YE("5S(&]F("5S70!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO
M<F1E(#(N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P
M"E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#(M,3@@,#DZ,SDK,#$P,`I,87-T
M+51R86YS;&%T;W(Z($%N9V5L<R!'=6EM97+@(#Q!;F=E;',N1W5I;65R84!U
M86(N97,^"DQA;F=U86=E+51E86TZ($-A=&%L86X@/&1E=D!L:7-T<RYH;W)D
M92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:70*`$]P97)A8VEO;G,@9&4@36%N=&5N:6UE;G0@)7,@+2!#
M;VYF:7)M86-I\P`R-"!H;W)E<P!!32]030!!9F5G:7(@<&%R96QL`$%D<F7G
M80!!;&EE<P!3)VAA(&5S<&5C:69I8V%T('5N('9A;&]R(&ELMVQE9V%L+@!#
M86UP<R!D:7-P;VYI8FQE<SH`06YI=F5R<V%R:0!#86QE;F1A<FD`0V%N8V5L
MMVQA<B!);F9O<FUE`%1E;.AF;VX@0V5LMVQU;&%R`%1A;F-A<B!&:6YE<W1R
M80!#;VUP86YY:6$`3F\@<R=H82!P;V=U="!O8G)I<B!E;"!M\F1U;"`E<R!-
M86EN=&5N86YC95]487-K`$1$`$1IX')I86UE;G0`261E;G1I=&%T(%!R961E
M=&5R;6EN861A`$1E<V-R:7!C:?,@9&5L(%!R;V)L96UA`$5L<R!D971A;&QS
M(&AA;B!E<W1A="!R96=I<W1R871S('!E<B!A(&PG861M:6YI<W1R861O<BX`
M3W!C:6]N<R!D92!6:7-U86QI>F%C:?,`3F\@86-C961I=2!D:7)E8W1A;65N
M="!A(&UA:6YT96YA;F-E+G!H<`!%;6%I;`!297-U;'1A="!B=6ET+@!%<G)O
M<@!#861A(#$U(&UI;G5T<P!#861A(#,P('-E9V]N<P!#861A(#4@;6EN=71S
M`$-A9&$@26YI8VD@9&4@4V5S<VGS`$-A9&$@;6ET:F$@:&]R80!#861A(&UI
M;G5T`$5X96UP;&4@9&4@=F%L;W)S.@!%<G)A9&$@86P@<F5C=7!E<F%R(&QE
M<R!P<F5F97+H;F-I97,N`$5R<F%D82!A;"!C;VYN96-T87(@86UB(&5L('-E
M<G9I9&]R($Q$05`N`$9A>`!!:G5D80!!9')EYV$@4&%R=&EC=6QA<@!496SH
M9F]N(%!A<G1I8W5L87(`2&]R9&4`0V%M<"!I;7!O<G1A=#H@)7,`0V%M<',@
M:6UP;W)T871S.@!)9&EO;6$`3&QI<W1A<B!496UE<R!D)T%J=61A`$5N=')A
M<@!3;W)T:7(@9&4@<V5S<VGS`$U-`$-O<G)E=0!#86UP<R!#;W)R97-P;VYE
M;G1S`$UI<W-A=&=E`$UE;G-U86QM96YT`$YO;0!-86D`3F]T97,`3W!C:6]N
M<P!!;'1R82!);F9O<FUA8VGS`$-O;G1R87-E;GEA`%)E86QI='IA<B!/<&5R
M86-I;VYS(&1E($UA;G1E;FEM96YT`%1E;.AF;VX`4VD@=7,@<&QA=2P@<')O
M<&]R8VEO;F5U('5N(')E<W5M(&1E;"!P<F]B;&5M82X`4VD@=7,@<&QA=2P@
M<')O<&]R8VEO;F5U(&5L('9O<W1R92!N;VT@9"=U<W5A<FD@:2!C;VYT<F%S
M96YY80!$97-C<FEP8VGS(&1E;"!0<F]B;&5M80!4<F5U<F4@<&%R96QL`%1O
M<FYA<B!A($]P8VEO;G,`1G5N8VGS`$1E<V%R($]P8VEO;G,`4V5L96-C:6]N
M974@96P@9&5L:6UI=&%D;W(@9&4@;&$@9&%T83H`4V5L96-C:6]N974@96P@
M9F]R;6%T(&1E(&QA(&1A=&$Z`%-E;&5C8VEO;F5U(&5L(&9O<FUA="!D92!L
M)VAO<F$Z`%-E;&5C8VEO;F5U(&1O<R!C86UP<R!Q=64@8V]I;F-I9&5I>&EN
M+@!396QE8V-I;VYE=2!E;"!V;W-T<F4@:61I;VUA('!R969E<FET.@!%;G9I
M87(@26YF;W)M90!/;6ET:7(@36%N=&5N:6UE;G0`16YT<F%D82!D92!#87+@
M8W1E<G,@17-P96-I86QS`,AX:70`1F5I;F5S`$%Q=65S="!N^FUE<F\@:&$@
M9&4@<V5R(&-O;2!A(&WM;FEM('5N(#$N`$%Q=65S="!V86QO<B!H82!D92!S
M97(@=6X@;OIM97)O+@!4[71O;`!54DP`26YC87!AYR!D92!C;VYN96-T87)S
M92!A;"!S97)V:61O<B!D92!344PN`$YO(.ES('!O<W-I8FQE('1R861U:7(@
M87%U97-T(&1O8W5M96YT(&1E(%=O<F0`1&5S9F5R($-A;G9I<P!/<&-I;VYS
M(&0G57-U87)I`%5S=6%R:0!!=NUS`%-E=&UA;F%L;65N=`!"96YV:6YG=71S
M(&$@)7,`0F5N=FEN9W5T+"`E<P!!9')EYV$@9&4@;&$@1F5I;F$`5&5LZ&9O
M;B!D92!L82!&96EN80!!00!!;G5A;&UE;G0`2&5U(&1E(&1E<V-R:75R92!E
M;"!P<F]B;&5M82!A8F%N<R!D)V5N=FEA<B!L)VEN9F]R;64@9&5L('!R;V)L
M96UA+@!,82!V;W-T<F$@<V5S<VGS(&5N("5S(&AA(&5X<&ER870N(%-I('5S
M('!L874L(&EN:6-I974@=6YA(&YO=F$@<V5S<VGS+@!,82!V;W-T<F$@26YF
M;W)M86-I\P!,97,@;W!C:6]N<R!H86X@97-T870@86-T=6%L:71Z861E<RX`
M6TEN9F]R;64@9&5L(%!R;V)L96UA70!;;.UN:6$@)7,@9&4@)7-=`'9#87)D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]C<U]#
M6B\`````````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-S8`,#$V-C<Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V-S7T-:+TQ#7TU%4U-!1T53+P``````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-@`P,C`T-38`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8W-?0UHO3$-?34534T%'
M15,O:&]R9&4N;6\`````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S,V,#,U`#$P
M-#$W,S8R-S<V`#`R,C$R,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#>$@25`````)@&```<````W#0``,L(``"<:0``````
M`,B,```.````R8P```\```#8C```#0```.B,```(````]HP```L```#_C```
M#`````N-```$````&(T```P````=C0``#P```"J-```+````.HT```X```!&
MC0``!0```%6-```H````6XT```@```"$C0``"@```(V-```5````F(T``!(`
M``"NC0``"P```,&-```.````S8T```H```#<C0``#0```.>-```.````]8T`
M`!$````$C@``#0```!:.```,````)(X```T````QC@``!@```#^.```/````
M1HX``!@```!6C@``#````&^.```.````?(X```X```"+C@``"````)J.```N
M````HXX``!H```#2C@``,@```.V.```X````((\``%0```!9CP``40```*Z/
M``!:`````)```%<```!;D```-````+.0```'````Z)````H```#PD```#P``
M`/N0```%````"Y$```8````1D0``$0```!B1```(````*I$```D````SD0``
M"0```#V1```E````1Y$``"````!MD0``$````(Z1```/````GY$```H```"O
MD0```P```+J1```/````OI$``!0```#.D0``"0```..1```-````[9$``!(`
M``#[D0``#P````Z2```*````'I(```\````ID@``"````#F2```D````0I(`
M`!0```!GD@``%@```'R2```(````DY(``!D```"<D@``!P```+:2```,````
MOI(``"P```#+D@``#@```/B2```#````!Y,```L````+DP``!P```!>3```'
M````'Y,```4````GDP``!0```"V3```*````,Y,```,````^DP``%P```$*3
M```*````6I,```\```!EDP``#@```'63```8````A),``",```"=DP``#@``
M`,&3```4````T),``!<```#EDP``%P```/V3```7````%90``!,````ME```
M#P```$&4```.````490``!\```!@E```!P```("4```&````B)0```@```"/
ME```#P```)B4```&````J)0```H```"OE```$P```+J4```+````SI0``!``
M``#:E```%0```.N4```5`````94```<````7E0``$````!^5```%````,)4`
M`!4````VE0``$0```$R5```,````7I4``#L```!KE0``"0```*>5```'````
ML94``!0```"YE0```P```,Z5```%````TI4``!````#8E0``"0```.F5```3
M````\Y4``#D````'E@``$@```$&6```G````5)8``"P```!\E@``*@```*F6
M```E````U)8```H```#ZE@``!@````67```)````#)<```<````6EP``+P``
M`!Z7```W````3I<``"X```"&EP``50```+67```M````"Y@``"T````YF```
M+0```&>8``!`````E9@``",```#6F```(P```/J8```M````'ID``#,```!,
MF0``%0```("9```9````EID``"D```"PF0``)````-J9```1````_YD```H`
M```1F@``#````!R:```*````*9H``!`````TF@``%@```$6:```6````7)H`
M``<```!SF@``!P```'N:```4````@YH```H```"8F@``"````*.:```(````
MK)H```<```"UF@``!P```+V:```&````Q9H```4```#,F@``!P```-*:```&
M````VIH```@```#AF@``*0```.J:```.````%)L```H````CFP``!````"Z;
M```'````,YL```D````[FP``!@```$6;```1````3)L```<```!>FP``%@``
M`&:;```$````?9L```@```""FP``!@```(N;```-````DIL```8```"@FP``
M'@```*>;```1````QIL```@```#8FP``#0```.&;```,````[YL```<```#\
MFP```P````2<```#````")P``!<````,G```$P```"2<```(````.)P```0`
M``!!G```"````$:<```(````3YP``$$```!8G```(````)J<```&````NYP`
M``8```#"G```%0```,F<```8````WYP``"(```#XG```+@```!N=```=````
M2IT``"$```!HG0``5````(J=```I````WYT```H````)G@``!P```!2>```5
M````')X```X````RG@``"@```$&>```/````3)X```T```!<G@``#P```&J>
M```-````>IX```D```"(G@``%````)*>```&````IYX``!@```"NG@``'0``
M`,>>```3````Y9X``!0```#YG@``!`````Z?```&````$Y\``%0````:GP``
M!````&^?```.````=)\```4```"#GP``!0```(F?```;````CY\``!H```"K
MGP``$0```,:?```1````V)\``!P```#JGP``*@````>@```0````,J```"$`
M``!#H```!0```&6@```3````:Z```!(```!_H```"@```)*@```/````G:``
M`!$```"MH```$P```+^@```,````TZ````8```#@H```!@```.>@```7````
M[J```!`````&H0``$0```!>A```(````*:$```4````RH0``#````#BA```0
M````1:$```4```!6H0``#0```%RA```&````:J$```<```!QH0``#0```'FA
M```'````AZ$```L```"/H0``!P```)NA```'````HZ$```D```"KH0``"@``
M`+6A```9````P*$```P```#:H0``$````.>A```%````^*$``"4```#^H0``
M$@```"2B```3````-Z(``"L```!+H@``.P```'>B```@````LZ(``#8```#4
MH@``"`````NC```,````%*,```8````AHP``!````"BC```.````+:,```H`
M```\HP``#0```$>C```>````5:,``!L```!THP``(0```)"C```>````LJ,`
M`!D```#1HP``'@```.NC```;````"J0``"8````FI```&P```$VD```>````
M::0``!P```"(I```)@```*6D```S````S*0``"8`````I0``*P```">E```X
M````4Z4``"\```",I0``$@```+RE```I````SZ4``!(```#YI0``H@````RF
M```6````KZ8``",```#&I@``*````.JF```I````$Z<``"@````]IP``'P``
M`&:G```@````AJ<``"4```"GIP``,````,VG```A````_J<``!P````@J```
M)@```#VH``!!````9*@```P```"FJ```!P```+.H```'````NZ@```8```##
MJ```#0```,JH```0````V*@``!(```#IJ```$P```/RH```2````$*D```<`
M```CJ0``!````"NI```,````,*D```X````]J0``#P```$RI```3````7*D`
M``T```!PJ0``*````'ZI```#````IZD```T```"KJ0``!@```+FI```1````
MP*D``!<```#2J0``&P```.JI```.````!JH```(````5J@``!0```!BJ```0
M````'JH```0````OJ@``#0```#2J```.````0JH```,```!1J@``#@```%6J
M```(````9*H```\```!MJ@``#P```'VJ```'````C:H```T```"5J@``$```
M`*.J```+````M*H```8```#`J@``#````,>J```1````U*H``!D```#FJ@``
M"P````"K```-````#*L``"(````:JP``"@```#VK```8````2*L``!D```!A
MJP``%@```'NK```-````DJL```<```"@JP``%````*BK```+````O:L``"(`
M``#)JP``+P```.RK```+````'*P```D````HK```&0```#*L```+````3*P`
M`!<```!8K```%P```'"L```)````B*P``!8```"2K```#P```*FL```6````
MN:P```X```#0K```&````-^L```(````^*P```T````!K0``)@````^M``!#
M````-JT```@```!ZK0``$@```(.M```(````EJT```L```"?K0``+P```*NM
M```.````VZT```4```#JK0``!@```/"M```#````]ZT```<```#[K0``!```
M``.N```*````"*X```H````3K@``#P```!ZN```0````+JX``!<````_K@``
M$0```%>N```7````::X```D```"!K@``!0```(NN```+````D:X```H```"=
MK@```@```*BN```%````JZX```T```"QK@``&P```+^N```7````VZX```D`
M``#SK@``#@```/VN```-````#*\``!(````:KP``.````"VO```@````9J\`
M``@```"'KP``#@```)"O``![````GZ\``!@````;L```$0```#2P```'````
M1K````4```!.L```&0```%2P```'````;K````@```!VL```!@```'^P```&
M````AK```!````"-L```#P```)ZP```0````KK````\```"_L```"P```,^P
M```/````V[````P```#KL```#P```/BP```'````"+$```8````0L0``#@``
M`!>Q```,````)K$``"@````SL0``#P```%RQ```(````;+$```@```!UL0``
M$P```'ZQ```>````DK$``"$```"QL0``(````-.Q```9````]+$``!<````.
ML@``)0```":R```7````3+(```0```!DL@``&P```&FR```-````A;(```P`
M``"3L@```P```*"R```(````I+(```H```"ML@``#````+BR```+````Q;(`
M`!````#1L@``#````.*R```$````[[(``!,```#TL@``%`````BS```,````
M';,```D````JLP``#@```#2S```+````0[,``!L```!/LP``!P```&NS```'
M````<[,```H```![LP``#0```(:S```)````E+,```0```">LP``!0```*.S
M```#````J;,``!@```"MLP``"@```,:S```$````T;,``"8```#6LP``#@``
M`/VS``!\````#+0``!4```")M```!0```)^T```'````I;0```P```"MM```
M"````+JT```*````P[0```8```#.M```"````-6T```"````WK0```8```#A
MM```!@```.BT```4````[[0```T````$M0``$````!*U```;````([4```0`
M```_M0``"0```$2U```0````3K4```D```!?M0``"0```&FU```%````<[4`
M`!H```!YM0``"````)2U```&````G;4``!D```"DM0``#@```+ZU```'````
MS;4```<```#5M0``!0```-VU```)````X[4```H```#MM0```@```/BU```&
M````^[4```T````"M@``"0```!"V```&````&K8``!(````AM@``"0```#2V
M```'````/K8``!0```!&M@``'0```%NV```&````>;8```H```"`M@``!```
M`(NV```)````D+8```@```":M@``$0```*.V```)````M;8```8```"_M@``
M#0```,:V```&````U+8```0```#;M@``.0```."V```]````&K<``#H```!8
MMP``'@```).W```%````LK<```X```"XMP``!````,>W```&````S+<``"$`
M``#3MP``%0```/6W```&````"[@```0````2N```$0```!>X```&````*;@`
M``H````PN```(@```#NX```$````7K@```4```!CN```'0```&FX```$````
MA[@```P```",N```"@```)FX```(````I+@```D```"MN```!0```+>X```Z
M````O;@``#````#XN```-0```"FY```I````7[D``$<```")N0``.````-&Y
M```I````"KH``#\````TN@``+@```'2Z```M````H[H``!\```#1N@``#P``
M`/&Z```2`````;L```L````4NP``)@```""[```I````1[L``"0```!QNP``
M)@```):[```(````O;L```H```#&NP``"0```-&[```'````V[L``"````#C
MNP``(`````2\```F````);P```H```!,O```&0```%>\```I````<;P``!8`
M``";O```$@```+*\```'````Q;P```H```#-O```#````-B\```/````Y;P`
M`!````#UO```0`````:]``!P````1[T``&8```"XO0``#@```!^^```)````
M+KX```H````XO@``$@```$.^```3````5KX```P```!JO@``!@```'>^```/
M````?KX``!(```".O@``$````*&^```1````LKX``!P```#$O@``(P```.&^
M``!J````!;\```\```!POP``!0```("_```0````AK\```D```"7OP``!```
M`*&_```+````IK\``!0```"ROP``#````,>_```,````U+\```\```#AOP``
M%0```/&_```I````!\```"H````QP```)@```%S````G````@\```"D```"K
MP```*@```-7````9`````,$``$(````:P0``$0```%W!```2````;\$``!,`
M``""P0``%````);!```/````J\$``!8```"[P0``%P```-+!```0````ZL$`
M`!$```#[P0``-`````W"```3````0L(``!(```!6P@``-0```&G"```4````
MG\(```<```"TP@``#````+S"```@````R<(``!0```#JP@``$0```/_"```7
M````$<,``!P````IPP``$P```$;#```1````6L,``!H```!LPP``'@```(?#
M```:````IL,``!$```#!PP``%````-/#```7````Z,,``!4`````Q```"0``
M`!;$```9````(,0```0````ZQ```!P```#_$```+````1\0``!$```!3Q```
M!@```&7$```&````;,0```8```!SQ```!0```'K$```'````@,0```<```"(
MQ```!0```)#$```6````EL0```8```"MQ```!@```+3$```$````N\0```0`
M``#`Q```!P```,7$```.````S<0```P```#<Q```#````.G$```-````]L0`
M``H````$Q0``#@````_%```%````'L4``"@````DQ0``#@```$W%```,````
M7,4```\```!IQ0``"@```'G%```(````A,4```D```"-Q0``*P```)?%```$
M````P\4```@```#(Q0``)@```-'%```2````^,4```\````+Q@``!@```!O&
M```*````(L8```<````MQ@``"````#7&```@````/L8```D```!?Q@``#```
M`&G&```-````=L8```X```"$Q@``%@```)/&```1````JL8```8```"\Q@``
M`P```,/&```&````Q\8``!D```#.Q@``!P```.C&```$````\,8```L```#U
MQ@``"P````''```'````#<<```<````5QP``%@```!W'```-````-,<```T`
M``!"QP``"@```%#'```0````6\<```\```!LQP``$0```'S'```7````CL<`
M``H```"FQP``$0```+''```(````P\<```0```#,QP``#P```-''```Z````
MX<<```4````<R```#````"+(```>````+\@```X```!.R```$````%W(```+
M````;L@```P```!ZR```"0```(?(```'````D<@```H```"9R```"0```*3(
M```.````KL@``!````"]R```&@```,[(```*````Z<@```D```#TR```"@``
M`/[(```,````"<D```\````6R0``"````";)```&````+\D```<````VR0``
M"P```#[)``!'````2LD```T```"2R0``"0```*#)```$````JLD```,```"O
MR0``$P```+/)```3````Q\D``!,```#;R0``"@```._)```"````^LD```0`
M``#]R0``)0````+*```#````*,H```4````LR@``*@```#+*```*````7<H`
M``4```!HR@``!````&[*```*````<\H```T```!^R@``!@```(S*```(````
MD\H```@```"<R@``!````*7*```%````JLH``&@```"PR@``"0```!G+```,
M````(\L```4````PRP``!@```#;+```;````/<L``"\```!9RP``$````(G+
M```*````FLL```\```"ERP``"@```+7+```)````P,L``!,```#*RP``&P``
M`-[+```8````^LL``!<````3S```#@```"O,```#````.LP```<````^S```
M"````$;,```'````3\P```H```!7S```"P```&+,```'````;LP``%$```!V
MS```$````,C,```,````V<P```T```#FS```&@```/3,``!*````#\T```8`
M``!:S0``!@```&'-```&````:,T``!\```!OS0``!@```(_-```)````ELT`
M`!@```"@S0``%P```+G-```&````T<T```T```#8S0``(@```.;-``!7````
M"<X``!,```!AS@``(P```'7.```3````F<X```(```"MS@``"P```+#.```(
M````O,X```T```#%S@``"@```-/.```'````WLX``!0```#FS@``!@```/O.
M```(`````L\```X````+SP``!P```!K/```*````(L\```L````MSP``!P``
M`#G/```,````0<\```T```!.SP``#````%S/```)````:<\```D```!SSP``
M"@```'W/```'````B,\```D```"0SP``!P```)K/```*````HL\``!L```"M
MSP``$@```,G/```*````W,\```D```#GSP``$````/'/```'`````M```!(`
M```*T```!````!W0```'````(M````4````JT```!0```##0```+````-M``
M`!0```!"T```$0```%?0```:````:=```!8```"$T```%````)O0```7````
ML-```!@```#(T```'````.'0```9````_M````<````8T0``!0```"#1```-
M````)M$```P````TT0``"````$'1```7````2M$```L```!BT0``$P```&[1
M```$````@M$```H```"'T0``!````)+1```,````E]$```D```"DT0``!0``
M`*[1```'````M-$```4```"\T0``!````,+1```"````Q]$``#@```#*T0``
M+`````/2```2````,-(``"D```!#T@``,@```&W2```*````H-(``"P```"K
MT@``+@```-C2```S````!],``#,````[TP``.````&_3```/````J-,``!@`
M``"XTP``$````-'3```/````XM,``!,```#RTP``%`````;4```2````&]0`
M`!0````NU```%0```$/4```M````6=0``"T```"'U```,0```+74```N````
MY]0``"\````6U0``+````$;5``!B````<]4``!,```#6U0``"````.K5```(
M````\]4``"L```#\U0``(0```"C6```:````2M8```D```!EU@``10```&_6
M``!!````M=8```0```#WU@``$P```/S6```4````$-<```X````EUP``$P``
M`#37```8````2-<```8```!AUP``"0```&C7```*````<M<```\```!]UP``
M$````(W7```'````GM<```X```"FUP``!0```+77```;````N]<```@```#7
MUP``!@```.#7```4````Y]<``!$```#\UP``#@````[8```X````'=@```(`
M``!6V```!@```%G8```.````8-@```4```!OV```!P```'78```.````?=@`
M``8```",V```!````)/8```I````F-@``!<```#"V```'P```-K8``!<````
M^M@``!0```!7V0``/@```&S9```?````J]D``!````#+V0``!P```-S9```.
M````Y-D```P```#SV0``#`````#:```3````#=H```H````AV@``'0```"S:
M```9````2MH```4```!DV@``$0```&K:```1````?-H``"0```".V@``%0``
M`+/:```2````R=H```X```#<V@``&0```.O:```(````!=L```D````.VP``
M#0```!C;```*````)ML```<````QVP``#P```#G;```+````2=L```H```!5
MVP``!P```&#;```(````:-L```4```!QVP``'P```'?;```&````E]L``!``
M``">VP``"````*_;```-````N-L```@```#&VP``$@```,_;```L````XML`
M`!H````/W```"0```"K<```*````--P``!4````_W```!0```%7<```4````
M6]P```0```!PW```$````'7<```&````AMP```<```"-W```'@```)7<```H
M````M-P```H```#=W```&@```.C<```4`````]T```0````8W0``!````!W=
M```+````(MT```4````NW0``!@```#3=```(````.]T```8```!$W0``"@``
M`$O=```;````5MT``#0```!RW0``-````*?=```@````W-T``"D```#]W0``
M(````"?>``!!````2-X``!H```"*W@``*````*7>```I````SMX``"(```#X
MW@``!@```!O?```(````(M\```4````KWP``"````#'?```9````.M\``!D`
M``!4WP``*@```&[?```C````F=\``"X```"]WP``-````.S?```(````(>``
M`!<````JX```"@```$+@```'````3>```"$```!5X```$````'?@```.````
MB.````L```"7X```!P```*/@```3````J^````@```"_X```"P```,C@```*
M````U.```!0```#?X```,@```/3@```+````)^$```4````SX0``!0```#GA
M```7````/^$```\```!7X0``!````&?A```*````;.$```D```!WX0``"P``
M`('A```-````C>$```P```";X0``#@```*CA```%````M^$```0```"]X0``
M#0```,+A```R````T.$``$4````#X@``%P```$GB```>````8>(``!0```"`
MX@``!0```)7B```4````F^(```<```"PX@``#@```+CB```J````Q^(```8`
M``#RX@``#````/GB```-````!N,``!$````4XP``"P```";C```V````,N,`
M``H```!IXP``(@```'3C```+````E^,```\```"CXP``,@```+/C```.````
MYN,```4```#UXP``#@```/OC```3````"N0```<````>Y```$0```";D```'
M````..0``!0```!`Y```&````%7D```'````;N0```4```!VY```#````'SD
M```,````B>0``!(```"6Y```!````*GD```'````KN0```H```"VY```"P``
M`,'D```,````S>0```X```#:Y```#@```.GD```%````^.0```4```#^Y```
M+@````3E```F````,^4``",```!:Y0```P```'[E```2````@N4```8```"5
MY0``'@```)SE```8````N^4``"4```#4Y0``#0```/KE```)````".8```,`
M```2Y@``!P```!;F```*````'N8```(````IY@``#````"SF```5````.>8`
M``L```!/Y@``&0```%OF```@````=>8``!(```"6Y@``!0```*GF```*````
MK^8``!4```"ZY@``$@```-#F```,````X^8```0```#PY@``!P```/7F```,
M````_>8``%(````*YP``%P```%WG```'````=><```8```!]YP``#@```(3G
M```,````D^<```T```"@YP``%0```*[G```2````Q.<```\```#7YP``%```
M`.?G```;````_.<``!`````8Z```:0```"GH```:````D^@``!<```"NZ```
M)P```,;H```:````[N@``!<````)Z0``&P```"'I```9````/>D``!\```!7
MZ0``$P```'?I```(````B^D```<```"4Z0``"````)SI```)````I>D``!4`
M``"OZ0``#0```,7I```3````T^D```,```#GZ0``1@```.OI```_````,NH`
M`#<```!RZ@``5P```*KJ```%`````NL``!\````(ZP``+P```"CK```*````
M6.L```@```!CZP``#0```&SK```M````>NL```0```"HZP``3P```*WK```E
M````_>L``!P````C[```"P```$#L```?````3.P``!T```!L[```)0```(KL
M```@````L.P``"0```#1[```(````/;L```+````%^T```<````C[0``#0``
M`"OM```,````.>T``!<```!&[0``!@```%[M```Y````9>T```P```"?[0``
M!P```*SM```)````M.T``!,```"^[0``"0```-+M```$````W.T``!````#A
M[0``"````/+M```(````^^T```0````$[@``"P````GN```,````%>X``!(`
M```B[@``$0```#7N```,````1^X``!H```!4[@``#P```&_N```'````?^X`
M``T```"'[@``%````)7N```.````JNX```P```"Y[@``&P```,;N```L````
MXNX``!,````/[P``'````"/O```H````0.\```8```!I[P``!P```'#O```3
M````>.\```4```",[P``!````)+O```7````E^\```H```"O[P``#````+KO
M```)````Q^\```8```#1[P``"0```-CO```(````XN\```D```#K[P``"@``
M`/7O```1`````/````8````2\```#@```!GP```.````*/````T````W\```
M"P```$7P```=````4?````L```!O\````@```'OP```'````?O````8```"&
M\```"0```(WP```'````E_```#L```"?\```*````-OP```T````!/$``!4`
M```Y\0``!0```$_Q```'````5?$```@```!=\0``!P```&;Q```%````;O$`
M``<```!T\0``#@```'SQ```)````B_$```8```"5\0``"````)SQ```+````
MI?$```<```"Q\0``"````+GQ```'````PO$``!8```#*\0``"0```.'Q```&
M````Z_$```L```#R\0``'````/[Q```4````&_(```<````P\@``"````#CR
M```(````0?(```4```!*\@``$````%#R```0````8?(```8```!R\@``&0``
M`'GR```*````D_(``!P```">\@``!P```+OR```%````P_(``!````#)\@``
M%````-KR```+````[_(```T```#[\@``%P````GS```$````(?,```D````F
M\P``"@```##S```'````._,```(```!#\P``#@```$;S```(````5?,``!\`
M``!>\P``(P```'[S```X````HO,``#$```#;\P``)P````WT``!D````-?0`
M`!0```":]```50```*_T```X````!?4``$H````^]0``6P```(GU```H````
MY?4``#@````.]@``*````$?V```L````</8``"<```"=]@``&P```,7V```^
M````X?8``*D!```@]P``(P```,KX```7````[O@``$@````&^0``A0```$_Y
M```P````U?D``$$````&^@``6P```$CZ``!)````I/H``!T```#N^@``&```
M``S[```A````)?L``!\```!'^P``*P```&?[```A````D_L``"<```"U^P``
M'0```-W[```1````^_L``#,````-_```)0```$'\```G````9_P``!\```"/
M_```,````*_\``!I````X/P``#T```!*_0``90```(C]``!-````[OT``"\`
M```\_@``+@```&S^```P````F_X``%0```#,_@``6@```"'_``!(````?/\`
M`$H```#%_P``,@```!```0`O````0P`!`"P```!S``$`+0```*```0!Q````
MS@`!`&\```!``0$`LP```+`!`0`7````9`(!`"4```!\`@$`,@```*("`0`I
M````U0(!`#X```#_`@$`(@```#X#`0!2````80,!`"4```"T`P$`"P```-H#
M`0"Q````Y@,!`$4```"8!`$`(0```-X$`0`P``````4!`"4````Q!0$`'```
M`%<%`0`Q````=`4!``<```"F!0$`!P```*X%`0`$````M@4!``T```"[!0$`
M"P```,D%`0`.````U04!``L```#D!0$`!0```/`%`0`0````]@4!``(````'
M!@$`60````H&`0`%````9`8!`!(```!J!@$`!````'T&`0`'````@@8!``@`
M``"*!@$`!0```),&`0`#````F08!`!````"=!@$`#````*X&`0`3````NP8!
M``T```#/!@$``@```-T&`0`'````X`8!``8```#H!@$`%````.\&`0`,````
M!`<!`!@````1!P$`!@```"H'`0`2````,0<!``P```!$!P$``P```%$'`0`J
M````50<!``0```"`!P$`!@```(4'`0`'````C`<!`!\```"4!P$`-0```+0'
M`0`N````Z@<!`"\````9"`$`%P```$D(`0`@````80@!`!L```"""`$`&```
M`)X(`0`D````MP@!`!\```#<"`$`&@```/P(`0`@````%PD!`!H````X"0$`
M,@```%,)`0`O````A@D!`"L```"V"0$`'P```.()`0`C`````@H!`!\````F
M"@$`&@```$8*`0`E````80H!`"8```"'"@$`)0```*X*`0`D````U`H!`!@`
M``#Y"@$`'0```!(+`0`D````,`L!`!@```!5"P$`(@```&X+`0`E````D0L!
M`#P```"W"P$`'P```/0+`0`C````%`P!`!\````X#`$`(````%@,`0`:````
M>0P!`!@```"4#`$`)@```*T,`0`>````U`P!`"D```#S#`$`'@```!T-`0`)
M````/`T!``P```!&#0$`%P```%,-`0`O````:PT!`"0```";#0$`!P```,`-
M`0`/````R`T!`!0```#8#0$`#@```.T-`0`-````_`T!`"0````*#@$`!0``
M`"\.`0`'````-0X!`"(````]#@$`)0```&`.`0`=````A@X!`!H```"D#@$`
M!P```+\.`0#'````QPX!``L```"/#P$`%0```)L/`0`&````L0\!``D```"X
M#P$`"P```,(/`0`7````S@\!``8```#F#P$`,P```.T/`0`3````(1`!`!,`
M```U$`$`!P```$D0`0`/````41`!``<```!A$`$`,@```&D0`0`A````G!`!
M`!,```"^$`$`#````-(0`0`1````WQ`!`#(```#Q$`$`"````"01`0`)````
M+1$!``H````W$0$`%````$(1`0`*````5Q$!`!T```!B$0$`"````(`1`0`?
M````B1$!``@```"I$0$`&@```+(1`0`&````S1$!`!4```#4$0$`!P```.H1
M`0`(````\A$!``D```#[$0$`/P````42`0`'````11(!``\```!-$@$`#@``
M`%T2`0`0````;!(!``D```!]$@$`"0```(<2`0`(````D1(!`!,```":$@$`
M!P```*X2`0`9````MA(!``H```#0$@$`%P```-L2`0`4````\Q(!``H````(
M$P$`#````!,3`0`7````(!,!``0````X$P$`*@```#T3`0`1````:!,!``<`
M``!Z$P$``@```((3`0`0````A1,!`!@```"6$P$`"P```*\3`0`#````NQ,!
M``@```"_$P$`!@```,@3`0`'````SQ,!``T```#7$P$`"P```.43`0`4````
M\1,!`!4````&%`$`#@```!P4`0`O````*Q0!`"````!;%`$`'````'P4`0`,
M````F10!`#$```"F%`$`!0```-@4`0`2````WA0!`#\```#Q%`$`$@```#$5
M`0`*````1!4!``8```!/%0$`!````%85`0`$````6Q4!``H```!@%0$`$P``
M`&L5`0`%````?Q4!``8```"%%0$`!@```(P5`0`$````DQ4!``P```"8%0$`
M"@```*45`0`%````L!4!`!@```"V%0$`&0```,\5`0`?````Z14!`!T````)
M%@$`$0```"<6`0`"````.18!``0````\%@$`"@```$$6`0`&````3!8!``4`
M``!3%@$``P```%D6`0`,````718!`$4```!J%@$`&@```+`6`0`U````RQ8!
M`"@````!%P$`4P```"H7`0`9````?A<!`'(```"8%P$`(`````L8`0`U````
M+!@!`"$```!B&`$`10```(08`0`P````RA@!`"@```#[&`$`*0```"09`0`F
M````3AD!`"4```!U&0$`*````)L9`0`H````Q!D!`"(```#M&0$`,````!`:
M`0`2````01H!`!,```!4&@$`$````&@:`0!Y````>1H!``D```#S&@$`<P``
M`/T:`0!\````<1L!`"L```#N&P$`%P```!H<`0`6````,AP!``\```!)'`$`
M'P```%D<`0!`````>1P!`!\```"Z'`$`'````-H<`0!1````]QP!`!0```!)
M'0$`"@```%X=`0`%````:1T!``8```!O'0$`"````'8=`0`%````?QT!`!(`
M``"%'0$`$````)@=`0`3````J1T!`!T```"]'0$`#P```-L=`0`/````ZQT!
M``0```#['0$`"0`````>`0`+````"AX!``<````6'@$`!0```!X>`0`4````
M)!X!``<````Y'@$`"````$$>`0`/````2AX!``@```!:'@$`#````&,>`0`/
M````<!X!``8```"`'@$`%````(<>`0`&````G!X!``P```"C'@$`"````+`>
M`0`$````N1X!``H```"^'@$`!P```,D>`0`$````T1X!`!D```#6'@$``@``
M`/`>`0`)````\QX!``8```#]'@$`!@````0?`0`G````"Q\!``0````S'P$`
M#P```#@?`0`3````2!\!``<```!<'P$`!P```&0?`0`&````;!\!``8```!S
M'P$`$````'H?`0`2````BQ\!``8```">'P$`"0```*4?`0`B````KQ\!``<`
M``#2'P$`!P```-H?`0`+````XA\!``4```#N'P$``@```/0?`0`+````]Q\!
M`,<!```#(`$`#@```,LA`0`5````VB$!``T```#P(0$`!P```/XA`0`(````
M!B(!``@````/(@$`"@```!@B`0`*````(R(!`!(````N(@$`#0```$$B`0`(
M````3R(!``4```!8(@$`'0```%XB`0`,````?"(!``T```")(@$`%0```)<B
M`0`0````K2(!``L```"^(@$`$````,HB`0`(````VR(!`!,```#D(@$`#0``
M`/@B`0`*````!B,!``L````1(P$`"P```!TC`0`/````*2,!``8````Y(P$`
M$````$`C`0`6````42,!``L```!H(P$`$@```'0C`0`2````AR,!``@```":
M(P$`+0```*,C`0`9````T2,!`#@```#K(P$`00```"0D`0!3````9B0!`%$`
M``"Z)`$`60````PE`0!7````9B4!`#L```"^)0$`"@```/HE`0`.````!28!
M`!8````4)@$`!0```"LF`0`&````,28!`!D````X)@$`#````%(F`0`4````
M7R8!`!<```!T)@$`)P```(PF`0`F````M"8!`!$```#;)@$`'P```.TF`0`/
M````#2<!``0````=)P$`$0```"(G`0`0````-"<!``<```!%)P$`%````$TG
M`0`1````8B<!`!@```!T)P$`#@```(TG`0`1````G"<!``H```"N)P$`*0``
M`+DG`0`3````XR<!`!<```#W)P$`$`````\H`0`C````("@!``8```!$*`$`
M!P```$LH`0!*````4R@!``P```">*`$`"````*LH`0`+````M"@!``<```#`
M*`$`"````,@H`0`/````T2@!``@```#A*`$`"@```.HH`0`#````]2@!`!D`
M``#Y*`$`#P```!,I`0`9````(RD!`!0````]*0$`$@```%(I`0`H````92D!
M``P```".*0$`)P```)LI`0`7````PRD!`",```#;*0$`'0```/\I`0`2````
M'2H!`!(````P*@$`#@```$,J`0`?````4BH!``8```!R*@$`!@```'DJ`0`(
M````@"H!``X```")*@$`!P```)@J`0`*````H"H!`!$```"K*@$`"````+TJ
M`0`/````QBH!`!8```#6*@$`&@```.TJ`0`(````""L!`!(````1*P$`!0``
M`"0K`0`6````*BL!`!X```!!*P$`#0```&`K`0`P````;BL!``D```"?*P$`
M!P```*DK`0`4````L2L!``4```#&*P$`!0```,PK`0`0````TBL!``L```#C
M*P$`&@```.\K`0`S````"BP!``\````^+`$`)@```$XL`0`S````=2P!`#$`
M``"I+`$`,````-LL`0`(````#"T!``4````5+0$`"0```!LM`0`(````)2T!
M`#D````N+0$`+0```&@M`0`X````EBT!`%,```#/+0$`-P```",N`0`W````
M6RX!`#8```"3+@$`-P```,HN`0`E`````B\!`"H````H+P$`-P```%,O`0`]
M````BR\!``\```#)+P$`$P```-DO`0`G````[2\!`!P````5,`$`#@```#(P
M`0`+````03`!``P```!-,`$`!@```%HP`0`,````83`!`!H```!N,`$`)@``
M`(DP`0`&````L#`!``<```"W,`$`%@```+\P`0`)````UC`!``@```#@,`$`
M!@```.DP`0`)````\#`!``8```#Z,`$`!0````$Q`0`%````!S$!``<````-
M,0$`!@```!4Q`0`*````'#$!`"4````G,0$`#P```$TQ`0`)````73$!``4`
M``!G,0$`!P```&TQ`0`'````=3$!``4```!],0$`#0```(,Q`0`&````D3$!
M`!,```"8,0$``P```*PQ`0`(````L#$!``H```"Y,0$`#0```,0Q`0`(````
MTC$!`",```#;,0$`$0```/\Q`0`)````$3(!`!(````;,@$`#````"XR`0`'
M````.S(!``,```!#,@$``P```$<R`0`4````2S(!`!0```!@,@$`"````'4R
M`0`(````?C(!``@```"',@$`!P```)`R`0!7````F#(!`"0```#P,@$`!@``
M`!4S`0`&````'#,!`!<````C,P$`&@```#LS`0`<````5C,!`"P```!S,P$`
M&P```*`S`0`N````O#,!`'(```#K,P$`)0```%XT`0`*````A#0!``<```"/
M-`$`$@```)<T`0`1````JC0!``\```"\-`$`#@```,PT`0`4````VS0!`!``
M``#P-`$`%`````$U`0`/````%C4!`!4````F-0$`!0```#PU`0`7````0C4!
M`!L```!:-0$`%P```'8U`0`4````CC4!``,```"C-0$`!@```*<U`0!H````
MKC4!``0````7-@$`%@```!PV`0`%````,S8!``0````Y-@$`'@```#XV`0`8
M````738!``P```!V-@$`&````(,V`0`8````G#8!`"T```"U-@$`#@```.,V
M`0`B````\C8!``@````5-P$`&@```!XW`0`8````.3<!`!,```!2-P$`'```
M`&8W`0`8````@S<!`!0```"<-P$`"P```+$W`0`(````O3<!``<```#&-P$`
M$````,XW`0`5````WS<!`!````#U-P$`"`````8X`0`%````#S@!``L````5
M.`$`#````"$X`0`(````+C@!``T````W.`$`!P```$4X`0`&````33@!`!$`
M``!4.`$`"````&8X`0`,````;S@!``<```!\.`$`!0```(0X`0`(````BC@!
M``@```"3.`$`$P```)PX`0`+````L#@!``X```"\.`$`!0```,LX`0`=````
MT3@!`!````#O.`$`$0`````Y`0`T````$CD!`$0```!'.0$`'P```(PY`0`Q
M````K#D!``H```#>.0$`#P```.DY`0`'````^3D!``D````!.@$`#P````LZ
M`0`)````&SH!`!$````E.@$`(0```#<Z`0`A````63H!`"0```![.@$`)```
M`*`Z`0`8````Q3H!`"$```#>.@$`&P`````[`0`E````'#L!`!H```!".P$`
M'0```%T[`0`8````>SL!`",```"4.P$`*0```+@[`0`;````XCL!`"8```#^
M.P$`,````"4\`0`N````5CP!`!$```"%/`$`*0```)<\`0`.````P3P!`+``
M``#0/`$`$````($]`0`8````DCT!`",```"K/0$`)````,\]`0`?````]#T!
M`!L````4/@$`(````#`^`0`A````43X!`"X```!S/@$`'````*(^`0`>````
MOSX!`"D```#>/@$`2P````@_`0`/````5#\!``0```!D/P$`$@```&D_`0`(
M````?#\!``X```"%/P$`#@```)0_`0`2````HS\!``L```"V/P$`%````,(_
M`0`*````US\!``0```#B/P$`#````.<_`0`/````]#\!``\````$0`$`$P``
M`!1``0`,````*$`!`#$````U0`$`"P```&=``0`1````<T`!``0```"%0`$`
M#P```(I``0`5````FD`!`!@```"P0`$`#P```,E``0`"````V4`!``4```#<
M0`$`$@```.)``0`%````]4`!``L```#[0`$`#`````=!`0`#````%$$!``\`
M```800$`"````"A!`0`8````,4$!`!````!*00$`"@```%M!`0`0````9D$!
M`!,```!W00$`"````(M!`0`&````E$$!``X```";00$`#````*I!`0`8````
MMT$!``P```#000$`#@```-U!`0`C````[$$!``P````00@$`'@```!U"`0`7
M````/$(!`!4```!40@$`#````&I"`0`&````=T(!``X```!^0@$`!0```(U"
M`0`G````DT(!`#\```"[0@$`!0```/M"`0`)`````4,!`!X````+0P$`"P``
M`"I#`0`3````-D,!`!,```!*0P$`!P```%Y#`0`9````9D,!`!(```"`0P$`
M&````)-#`0`0````K$,!`!4```"]0P$`"````--#`0`(````W$,!`"8```#E
M0P$`2`````Q$`0`(````540!`!8```!>1`$`!P```'5$`0`*````?40!`#$`
M``"(1`$`#P```+I$`0`%````RD0!``8```#01`$``P```-=$`0`'````VT0!
M``<```#C1`$`#````.M$`0`/````^$0!``T````(10$`#0```!9%`0`4````
M)$4!`!4````Y10$`%````$]%`0`%````9$4!``4```!J10$`"P```'!%`0`(
M````?$4!``(```"%10$`!0```(A%`0`/````CD4!`"$```">10$`$@```,!%
M`0`0````TT4!``\```#D10$`$0```/1%`0`>````!D8!`#$````E1@$`+0``
M`%=&`0`*````A48!``X```"01@$`BP```)]&`0`6````*T<!`!````!"1P$`
M!P```%-'`0`%````6T<!`"$```!A1P$`"````(-'`0`'````C$<!``<```"4
M1P$`!@```)Q'`0`0````HT<!``X```"T1P$`$0```,-'`0`/````U4<!`!L`
M``#E1P$`$0````%(`0`-````$T@!`!<````A2`$`!P```#E(`0`)````04@!
M`!0```!+2`$`#0```&!(`0`[````;D@!`!D```"J2`$`"````,1(`0`-````
MS4@!`!T```#;2`$`&0```/E(`0`A````$TD!`"`````U20$`&@```%9)`0`;
M````<4D!`"4```"-20$`&@```+-)`0`%````SDD!`!T```#420$`$````/))
M`0`.`````TH!``,````22@$`!````!9*`0`-````&TH!``X````I2@$`#P``
M`#A*`0`7````2$H!``L```!@2@$`!````&Q*`0`8````<4H!`!D```"*2@$`
M#P```*1*`0`-````M$H!``T```#"2@$`#@```-!*`0`?````WTH!``8```#_
M2@$`!@````9+`0`.````#4L!``X````<2P$`#0```"M+`0`(````.4L!``@`
M``!"2P$`!````$M+`0`4````4$L!``L```!E2P$`!0```'%+`0`D````=TL!
M``\```"<2P$`:P```*Q+`0`:````&$P!``D````S3`$`!@```#U,`0`*````
M1$P!``8```!/3`$`"````%9,`0`$````7TP!``H```!D3`$``@```&],`0`$
M````<DP!``<```!W3`$`%0```'],`0`2````E4P!`!0```"H3`$`&@```+U,
M`0`"````V$P!``(```#;3`$`#@```-Y,`0`&````[4P!``H```#T3`$`!0``
M`/],`0`9````!4T!``@````?30$`!@```"A-`0`7````+TT!`!````!'30$`
M"0```%A-`0`'````8DT!``4```!J30$`"0```'!-`0`-````>DT!``8```"(
M30$`!@```(]-`0`9````EDT!``L```"P30$`!0```+Q-`0`2````PDT!``<`
M``#530$`!P```-U-`0`8````Y4T!`!T```#^30$`!P```!Q.`0`*````)$X!
M``0````O3@$`"0```#1.`0`(````/DX!``L```!'3@$`"P```%-.`0`&````
M7TX!``T```!F3@$`!@```'1.`0`$````>TX!`#<```"`3@$`00```+A.`0`X
M````^DX!`"8````S3P$`!0```%I/`0`/````8$\!``8```!P3P$`"````'=/
M`0`?````@$\!`!H```"@3P$`!0```+M/`0`(````P4\!`!,```#*3P$`"```
M`-Y/`0`)````YT\!`!<```#Q3P$`!@````E0`0`&````$%`!`!4````74`$`
M!0```"U0`0`+````,U`!``P````_4`$`"````$Q0`0`)````55`!``4```!?
M4`$`+@```&50`0`T````E%`!`#P```#)4`$`)P````91`0`^````+E$!`#@`
M``!M40$`*````*91`0`R````SU$!`"T````"4@$`-0```#!2`0`H````9E(!
M`!(```"/4@$`$P```*)2`0`-````ME(!`#$```#$4@$`'````/92`0`<````
M$U,!`!H````P4P$`!P```$M3`0`(````4U,!``<```!<4P$`"````&13`0`F
M````;5,!`"0```"44P$`,0```+E3`0`)````ZU,!`!@```#U4P$`*`````Y4
M`0`6````-U0!`!(```!.5`$`!@```&%4`0`+````:%0!``P```!T5`$`#@``
M`(%4`0`/````D%0!`#@```"@5`$`@````-E4`0!F````6E4!``\```#!50$`
M"P```-%5`0`,````W54!`!$```#J50$`$@```/Q5`0`.````#U8!``<````>
M5@$`#P```"96`0`4````-E8!`!$```!+5@$`#P```%U6`0`>````;58!`#``
M``",5@$`?0```+U6`0`0````.U<!``4```!,5P$`%````%)7`0`)````9U<!
M``D```!Q5P$`"0```'M7`0`2````A5<!``X```"85P$`#@```*=7`0`3````
MME<!`!4```#*5P$`'P```.!7`0`A`````%@!`!T````B6`$`'P```$!8`0`@
M````8%@!`"(```"!6`$`&````*18`0`W````O5@!``\```#U6`$`$0````59
M`0`1````%UD!`!,````I60$`#0```#U9`0`2````2UD!`!0```!>60$`#P``
M`'-9`0`1````@UD!`#(```"560$`%@```,A9`0`4````WUD!`#P```#T60$`
M%````#%:`0`*````1EH!`!,```!16@$`(@```&5:`0`2````B%H!`"@```";
M6@$`&0```,1:`0`9````WEH!`!<```#X6@$`$@```!!;`0`?````(UL!`"(`
M``!#6P$`&@```&9;`0`2````@5L!`!<```"46P$`'````*Q;`0`6````R5L!
M``@```#@6P$`&````.E;`0`$`````EP!``4````'7`$`"P````U<`0`0````
M&5P!``8````J7`$`#````#%<`0`'````/EP!``8```!&7`$`!P```$U<`0`%
M````55P!``@```!;7`$`&````&1<`0`&````?5P!``D```"$7`$`"````(Y<
M`0`&````EUP!``@```">7`$`$0```*=<`0`2````N5P!``\```#,7`$`$```
M`-Q<`0`*````[5P!`!$```#X7`$`!`````I=`0`A````#UT!``\````Q70$`
M#P```$%=`0`6````45T!``L```!H70$`"0```'1=`0`+````?ET!`"\```"*
M70$`!````+I=`0`(````OUT!``0```#(70$`!0```,U=`0`1````TUT!``8`
M``#E70$`"@```.Q=`0`*````]UT!``4````"7@$`(P````A>`0`.````+%X!
M`!$````[7@$`%0```$U>`0`7````8UX!`!P```![7@$`&@```)A>`0`%````
MLUX!``4```"Y7@$`"0```+]>`0`9````R5X!``<```#C7@$`!@```.M>`0`-
M````\EX!``X`````7P$`!P````]?`0`'````%U\!``4````?7P$`#P```"5?
M`0`.````-5\!``H```!$7P$`$````$]?`0`2````8%\!`!0```!S7P$`%```
M`(A?`0`-````G5\!`!8```"K7P$`"````,)?`0`%````RU\!`!(```#17P$`
M2````.1?`0`&````+6`!``\````T8`$`(P```$1@`0`/````:&`!`!4```!X
M8`$`#@```(Y@`0`-````G6`!``\```"K8`$`"0```+M@`0`/````Q6`!``\`
M``#58`$`$0```.5@`0`0````]V`!`!X````(80$`"@```"=A`0`(````,F$!
M``P````[80$`#````$AA`0`,````56$!``4```!B80$`#````&AA`0`)````
M=6$!`!X```!_80$`9P```)YA`0`3````!F(!``L````:8@$`!0```"9B`0`%
M````+&(!`!(````R8@$`%````$5B`0`3````6F(!``L```!N8@$``@```'IB
M`0`*````?6(!`"\```"(8@$``P```+AB`0`%````O&(!`"8```#"8@$`"@``
M`.EB`0`%````]&(!``4```#Z8@$`$P````!C`0`2````%&,!``8````G8P$`
M"````"YC`0`'````-V,!``0````_8P$`!0```$1C`0!N````2F,!``H```"Y
M8P$`#0```,1C`0`&````TF,!``4```#98P$`*0```-]C`0`R````"60!`!$`
M```\9`$`"@```$YD`0`1````660!``H```!K9`$`"0```'9D`0`9````@&0!
M`"<```":9`$`*0```,)D`0`H````[&0!``\````590$`!@```"5E`0`'````
M+&4!``@````T90$`!P```#UE`0`.````164!``P```!490$`!@```&%E`0!%
M````:&4!`!````"N90$`"@```+]E`0`&````RF4!`!P```#190$`80```.YE
M`0`&````4&8!``@```!79@$`!@```&!F`0`4````9V8!``D```!\9@$`"```
M`(9F`0`I````CV8!`"@```"Y9@$`"0```.)F`0`%````[&8!`"L```#R9@$`
M9P```!YG`0`I````AF<!`"X```"P9P$`&````-]G`0`"````^&<!``T```#[
M9P$`!0````EH`0`4````#V@!``H````D:`$`!0```"]H`0`(````-6@!``8`
M```^:`$`"0```$5H`0`+````3V@!``<```!;:`$`"````&-H`0`+````;&@!
M``8```!X:`$`#@```']H`0`0````CF@!`!$```"?:`$`#0```+%H`0`/````
MOV@!`!````#/:`$`#P```.!H`0`-````\&@!``\```#^:`$`"`````YI`0`>
M````%VD!`!,````V:0$`"````$II`0`*````4VD!`!8```!>:0$`!P```'5I
M`0`/````?6D!``4```"-:0$`!P```)-I`0`%````FVD!``4```"A:0$`"```
M`*=I`0`1````L&D!`!$```#":0$`&@```-1I`0`6````[VD!`!0````&:@$`
M%P```!MJ`0`:````,VH!`!\```!.:@$`&````&YJ`0`#````AVH!``4```"+
M:@$`#@```)%J`0`.````H&H!`!8```"O:@$`(@```,9J`0`+````Z6H!`!0`
M``#U:@$`!P````IK`0`*````$FL!``4````=:P$`#@```"-K`0`)````,FL!
M``4````\:P$`!P```$)K`0`#````2FL!``0```!.:P$``@```%-K`0`^````
M5FL!`#0```"5:P$`%````,IK`0`J````WVL!`$4````*;`$`"@```%!L`0`L
M````6VP!`#,```"(;`$`.````+QL`0`X````]6P!`#T````N;0$`%````&QM
M`0`:````@6T!`!L```"<;0$`'````+AM`0`;````U6T!`!\```#Q;0$`&P``
M`!%N`0`;````+6X!``X```!);@$`,````%AN`0`P````B6X!`#0```"Z;@$`
M/0```.]N`0`R````+6\!`"\```!@;P$`<@```)!O`0`F`````W`!``P````J
M<`$`"@```#=P`0`S````0G`!`#4```!V<`$`)P```*QP`0`-````U'`!`$0`
M``#B<`$`/P```"=Q`0`%````9W$!`!L```!M<0$`%@```(EQ`0`2````H'$!
M`!$```"S<0$`&0```,5Q`0`&````WW$!``<```#F<0$`"0```.YQ`0`.````
M^'$!`!0````'<@$`#@```!QR`0`1````*W(!``@````]<@$`'@```$9R`0`(
M````97(!``4```!N<@$`"P```'1R`0`-````@'(!``L```".<@$`.@```)IR
M`0`"````U7(!``8```#8<@$`#@```-]R`0`)````[G(!``4```#X<@$`$@``
M`/YR`0`(````$7,!``0````:<P$`,P```!]S`0`.````4W,!`"D```!B<P$`
M4````(QS`0`5````W7,!`#H```#S<P$`(````"YT`0`/````3W0!``@```!?
M=`$`#P```&AT`0`/````>'0!``H```"(=`$`%````)-T`0`,````J'0!`!H`
M``"U=`$`%0```-!T`0`'````YG0!`!$```#N=`$`$0````!U`0`A````$G4!
M`!0````T=0$`$@```$EU`0`0````7'4!`",```!M=0$`!P```)%U`0`+````
MF74!`!0```"E=0$`$@```+IU`0`1````S74!`!H```#?=0$`$````/IU`0`,
M````"W8!``<````8=@$`"````"!V`0`%````*78!`"$````O=@$`!@```%%V
M`0`1````6'8!``@```!J=@$`#@```'-V`0`%````@G8!``\```"(=@$`+P``
M`)AV`0`2````R'8!``8```#;=@$`!P```.)V`0`7````ZG8!``8````"=P$`
M$@````EW`0`%````''<!`!4````B=P$`!````#AW`0`'````/7<!`!8```!%
M=P$`,0```%QW`0`%````CG<!`!,```"4=P$`$````*AW`0`$````N7<!``X`
M``"^=P$`"````,UW`0`'````UG<!``H```#>=P$`"````.EW`0`&````\G<!
M``4```#Y=P$`(````/]W`0`U````('@!`#4```!6>`$`&P```(QX`0`D````
MJ'@!`",```#->`$`/P```/%X`0`;````,7D!`"8```!->0$`+0```'1Y`0`D
M````HGD!``8```#'>0$`"````,YY`0`)````UWD!``L```#A>0$`%P```.UY
M`0`0````!7H!`"X````6>@$`)````$5Z`0`T````:GH!`#@```"?>@$`$0``
M`-AZ`0`B````ZGH!`!(````->P$`!@```"![`0`;````)WL!`!(```!#>P$`
M$0```%9[`0`-````:'L!``<```!V>P$`#@```'Y[`0`(````C7L!``L```"6
M>P$`#````*)[`0`;````KWL!`#0```#+>P$`"0````!\`0`%````"GP!``D`
M```0?`$`&@```!I\`0`1````-7P!``0```!'?`$`"@```$Q\`0`+````5WP!
M`!````!C?`$`#@```'1\`0`,````@WP!`!8```"0?`$`!0```*=\`0`%````
MK7P!``\```"S?`$`+````,-\`0!+````\'P!`!8````\?0$`'0```%-]`0`:
M````<7T!``4```",?0$`$````))]`0`'````HWT!`!$```"K?0$`+````+U]
M`0`)````ZGT!``X```#T?0$`$0````-^`0`5````%7X!``T````K?@$`.0``
M`#E^`0`)````<WX!`!T```!]?@$`$P```)M^`0`7````KWX!`"\```#'?@$`
M#P```/=^`0`1````!W\!`!<````9?P$`'@```#%_`0`(````4'\!`!(```!9
M?P$`!P```&Q_`0`4````='\!`!H```")?P$`!P```*1_`0`'````K'\!`!``
M``"T?P$`#P```,5_`0`1````U7\!``4```#G?P$`"````.U_`0`-````]G\!
M``T````$@`$`#@```!*``0`0````(8`!`!`````R@`$`!@```$.``0`(````
M2H`!`"X```!3@`$`)@```(*``0`D````J8`!``<```#.@`$`#@```-:``0`&
M````Y8`!`!<```#L@`$`%P````2!`0`B````'($!``H````_@0$`"P```$J!
M`0`#````5H$!``8```!:@0$`#````&&!`0`"````;H$!``P```!Q@0$`$P``
M`'Z!`0`+````DH$!`!D```">@0$`(````+B!`0`2````V8$!``4```#L@0$`
M"@```/*!`0`5````_8$!`!$````3@@$`#@```"6"`0`&````-((!``D````[
M@@$`$````$6"`0!*````5H(!`!<```"A@@$`!````+F"`0`(````OH(!`!0`
M``#'@@$`#@```-R"`0`,````ZX(!`"(```#X@@$`%P```!N#`0`-````,X,!
M`",```!!@P$`'````&6#`0`-````@H,!`&(```"0@P$`(@```/.#`0`6````
M%H0!`"L````MA`$`(````%F$`0`4````>H0!`!X```"/A`$`%@```*Z$`0`?
M````Q80!`!@```#EA`$`"@```/Z$`0`'````"84!``<````1A0$`!````!F%
M`0`3````'H4!``T````RA0$`$0```$"%`0`(````4H4!`$$```!;A0$`/```
M`)V%`0!"````VH4!`&`````=A@$`"0```'Z&`0`^````B(8!`"\```#'A@$`
M"@```/>&`0`*`````H<!``X````-AP$`.P```!R'`0`(````6(<!`#@```!A
MAP$`+@```)J'`0`B````R8<!``\```#LAP$`*0```/R'`0`8````)H@!`#``
M```_B`$`(@```'"(`0`H````DX@!`"(```"\B`$`#P```-^(`0`(````[X@!
M``X```#XB`$`#P````>)`0`0````%XD!``<````HB0$`/0```#")`0`,````
M;HD!``X```![B0$`!@```(J)`0`5````D8D!``@```"GB0$`"````+")`0`/
M````N8D!``D```#)B0$`"0```-.)`0`'````W8D!`!````#EB0$`$````/:)
M`0`6````!XH!`!<````>B@$`$0```#:*`0`;````2(H!`!,```!DB@$`"```
M`'B*`0`-````@8H!``P```"/B@$`#P```)R*`0`,````K(H!`!D```"YB@$`
M+````-.*`0`/`````(L!`!\````0BP$`*````#"+`0`(````68L!``8```!B
MBP$`$````&F+`0`)````>HL!``0```"$BP$`&````(F+`0`.````HHL!`!``
M``"QBP$`#@```,*+`0`%````T8L!``D```#7BP$`"````.&+`0`)````ZHL!
M``L```#TBP$`$0````",`0`$````$HP!``X````7C`$`!0```":,`0`+````
M+(P!``X````XC`$`(0```$>,`0`*````:8P!``(```!TC`$`!P```'>,`0`%
M````?XP!``L```"%C`$`!P```)&,`0`R````F8P!`"0```#,C`$`,0```/&,
M`0`7````(XT!``4````[C0$`!P```$&-`0`'````28T!``P```!1C0$`"```
M`%Z-`0`-````9XT!`!,```!UC0$`#P```(F-`0`,````F8T!``X```"FC0$`
M"P```+6-`0`'````P8T!``@```#)C0$`"````-*-`0`6````VXT!``D```#R
MC0$`!P```/R-`0`)````!(X!`"`````.C@$`!0```"^.`0`&````-8X!``8`
M```\C@$`"@```$..`0`'````3HX!`!(```!6C@$`$@```&F.`0`&````?(X!
M`!8```"#C@$`"P```)J.`0`;````IHX!``0```#"C@$`!0```,>.`0`/````
MS8X!`!P```#=C@$`!P```/J.`0`)`````H\!`!4````,CP$`!````"*/`0`*
M````)X\!``\````RCP$`"@```$*/`0`"````38\!`!$```!0CP$`!P```&*/
M`0`>````:H\!`!X```")CP$`,P```*B/`0`E````W(\!`"D````"D`$`70``
M`"R0`0`3````BI`!`%0```">D`$`+@```/.0`0!!````(I$!`%X```!DD0$`
M(````,.1`0!*````Y)$!`"@````OD@$`,@```%B2`0`C````BY(!`!T```"O
MD@$`+````,V2`0#N`0``^I(!`!L```#IE`$`%`````65`0!&````&I4!`(4`
M``!AE0$`/P```.>5`0`Q````)Y8!`$L```!9E@$`.````*66`0`<````WI8!
M`!4```#[E@$`&````!&7`0`7````*I<!`"L```!"EP$`'````&Z7`0`?````
MBY<!`!,```"KEP$`#````+^7`0`O````S)<!`!X```#\EP$`'P```!N8`0`A
M````.Y@!`$(```!=F`$`4````*"8`0`U````\9@!`&$````GF0$`1@```(F9
M`0`O````T)D!`"<`````F@$`+````"B:`0!'````59H!`%````"=F@$`00``
M`.Z:`0!.````,)L!`"T```!_FP$`)0```*V;`0`E````TYL!`"8```#YFP$`
M:@```""<`0!H````BYP!`*X```#TG`$`&P```*.=`0`J````OYT!`#8```#J
MG0$`+P```"&>`0!%````49X!`"````"7G@$`40```+B>`0`A````"I\!``L`
M```LGP$`M0```#B?`0`\````[I\!`"(````KH`$`*@```$Z@`0`K````>:`!
M`!P```"EH`$`+P```,*@`0`&````\J`!``8```#YH`$``P````"A`0`.````
M!*$!``L````3H0$`"@```!^A`0`+````*J$!``4````VH0$`#````#RA`0`$
M````2:$!`&X```!.H0$`!````+VA`0`6````PJ$!``0```#9H0$`!P```-ZA
M`0`%````YJ$!``4```#LH0$`!````/*A`0`0````]Z$!``@````(H@$`$0``
M`!&B`0`3````(Z(!``(````WH@$`!P```#JB`0`'````0J(!`!0```!*H@$`
M#````%^B`0`6````;*(!``8```"#H@$`$P```(JB`0`,````GJ(!``,```"K
MH@$`*````*^B`0`$````V*(!``8```#=H@$`"````.2B`0`;````[:(!`#0`
M```)HP$`)P```#ZC`0`H````9J,!`!,```"/HP$`(````*.C`0`=````Q*,!
M`!L```#BHP$`(````/ZC`0`;````'Z0!`!H````[I`$`(@```%:D`0`4````
M>:0!`#$```".I`$`+P```,"D`0`F````\*0!`!H````7I0$`'@```#*E`0`>
M````4:4!`!D```!PI0$`(P```(JE`0`=````KJ4!`"@```#,I0$`&@```/6E
M`0`;````$*8!`"`````LI@$`(P```$VF`0`9````<:8!`"$```"+I@$`'@``
M`*VF`0`V````S*8!`!X````#IP$`(@```"*G`0`B````1:<!`",```!HIP$`
M'0```(RG`0`8````JJ<!`"(```##IP$`(0```.:G`0`R````"*@!`"`````[
MJ`$`"@```%RH`0`+````9Z@!`!8```!SJ`$`*````(JH`0`=````LZ@!``H`
M``#1J`$`#P```-RH`0`7````[*@!``X````$J0$`%@```!.I`0`A````*JD!
M``@```!,J0$`!P```%6I`0`B````7:D!`"4```"`J0$`)0```*:I`0`6````
MS*D!``H```#CJ0$`W````.ZI`0`1````RZH!`!4```#=J@$`#````/.J`0`/
M`````*L!`!8````0JP$`(P```">K`0`&````2ZL!`$````!2JP$`%0```).K
M`0`4````J:L!``<```"^JP$`$P```,:K`0`*````VJL!`#<```#EJP$`*0``
M`!VL`0`6````1ZP!`!0```!>K`$`%````'.L`0`Q````B*P!`!$```"ZK`$`
M$@```,RL`0`3````WZP!`!$```#SK`$`"@````6M`0`7````$*T!``@````H
MK0$`(````#&M`0`(````4JT!`!,```!;K0$`!P```&^M`0`1````=ZT!``<`
M``")K0$`"````)&M`0`)````FJT!`#8```"DK0$`!0```-NM`0`/````X:T!
M`!0```#QK0$`$0````:N`0`+````&*X!``P````DK@$`!P```#&N`0`3````
M.:X!``L```!-K@$`&P```%FN`0`0````=:X!`!H```"&K@$`%P```*&N`0`+
M````N:X!``P```#%K@$`&````-*N`0`)````ZZX!`"H```#UK@$`$0```""O
M`0`*````,J\!``(````]KP$`$````$"O`0`7````4:\!``L```!IKP$``P``
M`'6O`0`*````>:\!``4```"$KP$`!P```(JO`0`,````DJ\!``L```"?KP$`
M%````*NO`0`5````P*\!``X```#6KP$`.````.6O`0`8````'K`!`!@````W
ML`$`"@```%"P`0`E````6[`!``4```"!L`$`%@```(>P`0`\````GK`!``T`
M``#;L`$`#@```.FP`0`&````^+`!``0```#_L`$`!`````2Q`0`*````";$!
M`!<````4L0$`!0```"RQ`0`&````,K$!``@````YL0$`!0```$*Q`0`4````
M2+$!`!4```!=L0$`!0```'.Q`0`7````>;$!`!X```"1L0$`'P```+"Q`0`:
M````T+$!`!````#KL0$``@```/RQ`0`$````_[$!``L````$L@$`!0```!"R
M`0`%````%K(!``,````<L@$`#@```""R`0!,````+[(!`!P```!\L@$`*@``
M`)FR`0`F````Q+(!`$X```#KL@$`'P```#JS`0!=````6K,!`!T```"XLP$`
M1P```-:S`0`@````'K0!`#$````_M`$`,P```'&T`0`H````I;0!`#0```#.
MM`$`-@````.U`0`T````.K4!`#````!OM0$`*````*"U`0`B````R;4!`#@`
M``#LM0$`%````"6V`0`5````.K8!``X```!0M@$`80```%^V`0`*````P;8!
M`&,```#,M@$`:0```#"W`0`G````FK<!`!L```#"MP$`&````-ZW`0`1````
M][<!`!T````)N`$`.0```">X`0`B````8;@!`!L```"$N`$`:@```*"X`0`6
M````"[D!``H````BN0$`!````"VY`0`&````,KD!``@````YN0$`!0```$*Y
M`0`5````2+D!`!(```!>N0$`&0```'&Y`0`C````B[D!``\```"ON0$`#0``
M`+^Y`0`$````S;D!``D```#2N0$`#0```-RY`0`(````ZKD!``D```#SN0$`
M%@```/VY`0`+````%+H!``H````@N@$`%0```"NZ`0`)````0;H!``8```!+
MN@$`$P```%*Z`0`*````9KH!`!8```!QN@$`"@```(BZ`0`'````D[H!``@`
M``";N@$`"````*2Z`0`,````K;H!``8```"ZN@$`!@```,&Z`0`9````R+H!
M``(```#BN@$`"````.6Z`0`&````[KH!``8```#UN@$`*0```/RZ`0`%````
M)KL!`!,````LNP$`&0```$"[`0`(````6KL!``<```!CNP$`!@```&N[`0`*
M````<KL!`!````!]NP$`&0```(Z[`0`(````J+L!``P```"QNP$`(P```+Z[
M`0`*````XKL!``D```#MNP$`$````/>[`0`%````"+P!``(````.O`$`"P``
M`!&\`0`!````+@$``!`%``"(!@``SP0``.(%``#_````%0(````````T!0``
M'0$``#\#````````2`0````````%`P``)````'4&`````````````"(!``#5
M`P``:`$``)X!```A`P``;`0``,X!``!`!@``20,``$``````````GP,`````
M````````X`,``"D%``"7`0```````+D#``"5!````````"D`````````````
M`!P$``!'!@```````*\#`````````````#H!``!M`0``UP0``#T#``#V`P``
M-@,````````)!````````"T!```C!```\@4``%P!`````````````%<#````
M````L0,``)T"``"6`P``70$``'@$``#^`@```````-T"``#Z````E0$`````
M```N!@``T@```!0&```'!````````+P#``#D!0``D@0```P#``!R!@``H@,`
M`$$!````````ZP0``````````````````%4````Y`@``O````!<&``#@````
M-P0``&$````#``````````,!``#3`@``EP0``$H#``#2`0``"0(```````"&
M`0``R00``!\"``#A`````````)X#```-!```3@,``'8#``"W`P``SP``````
M``#'`0``10$````````@!0``?@4``"4&``#F````\`0``#@#``!M!```````
M```````9`@``[@(``)@&``!W!```HP$``,P$``#<````ZP(``$T!```0`@``
MQP````T#``!3`P``&`8``$`%```(`0```````&X$``!&`0```````/\"``!Y
M!0``UP$``*X$``!F`````````"H$``````````````````#T`@``1@8``)@$
M``#F!```5P8``.(#```F!@``_0,``,L%``#=`P``````````````````)@(`
M```````>````X`4``,X"``````````````````")!0``D`,``#,"``#R`P``
MN0$``.0"``!_!```2@4```````#:!0``C@8``*4#``!U````X`$``)X%```D
M`@```````'(%``#`!```6P(``$<!```4!`````````````#&`P``C04``)L#
M`````````````&`!``"*````+04``'T#``"$!0``?`4``+X#```(````!`8`
M`.<$``#8!```V@0````````'`0``/````#@"``!&````[00``#L"````````
M-@````````"0!````````-L`````````A`0``(@$````````IP,``%,!```]
M`@``Y0,``!(!````````FP(```````"D`P``I`(``&P#``!8`P``YP(`````
M````!0``U`(``/@!```_````K@$```````"(!0``80(``,4%``!%`@``,P4`
M`*4!``!T`P``C08``)(```"Z!0``0P$``+X$````````````````````````
MD@8``/$!``"&!```DP$``$0"````````=P8```````!8````40$``*@$``",
M`@```````&8#``"E`@```````*@````T`0```````*$```![`0``V`4``%8&
M``!2!@``8`,``$D&`````````````'`!``"]!`````````````!-!0``@P,`
M``````!,!```_00``!<"``!)````XP$``-,#````````J@$``'@```!K`P``
M[`(``+0$`````````````'`%``"<````P@4``#H````E`@``+00``%X"````
M````\P,```H"````````<`(``/\$``"$````R0```!8&`````````````$T`
M```S````Y00```````"F`0``7@,``"L!``!W`P``IP4````````^`P``3`$`
M```````/````D08``%<"``#P`````````,$%```/`@``A`(``&T#``!T!```
M"P,``"@```"=!```CP,``($#```Q`P``>@0``*$!``"Z`P``F`,``"X%``!3
M!@````(``#L#``#2`P```````',$``!*!```C@$``+T%``"R!0``K`(``"`"
M`````````````-P%``#&`@````````$"```5`0``S`(````````0````70``
M````````````0`$``*L%``#L`P``/`(```D&````````C0$``(X%````````
MQ@4``&0!``#S`@```````"````#C````$P4````````E!```````````````
M````=`8``-4"``!R````&`0`````````````-`0``-P"````````GP```-8"
M```#!@```````)$#```/!0``8@(``#H%`````````````&X%``"N!0``&08`
M`%0&``"O`@``G0$``(\`````````J04```````#W`0``%@```!(#``#!````
M<`,```X"```C!0```````&\$`````````````#`&``!4````6`$``+\!``"!
M!```@P(```````"I`@``AP8``!P```!5`@```````"<!````````0P4``/D"
M``#X`@``P`4``$8%``"9!``````````````V!```!P,``&,%``",`0``````
M``````````````````````!@!`````````````!V`0```````'D"````````
M``````````"S`0```````'4!````````Z00``/0%``#!`0``````````````
M````-P```(($```C````0@$``-,`````````P@````````!.````````````
M``!G!```>P0``-\```!.!0``\`,`````````````P`$``!T"````````&04`
M``L&``"U!0``B````.8%``#U`@``R`(``#0#````````7@8``&(```!9`0``
MH0(``(P&``#A!```H`0``````````````````(X```#H`@``*`,``(`%``!G
M!@``)P(``!L"``":`@``PP```%(%```$`@``700``,P#``"0`0``M@(``'D`
M``"#!0``$`8```("``!K!0``@P$``","```0`P``?`$``.<!```<`0``````
M`%,```"Y!```\`4``.T"``#H!0``90```,D"``!Z!@````````````!:````
MNP```.P```"M`@``5`$````````I`0``J@```(@!```G!@``(0(``!@%```H
M!@`````````````R`@``708```````!#`P``F@4````````.!0``=00``)8&
M```!!0``&00``#D!````````,`0``%(#`````````````+\#````````N`4`
M````````````5@(````````Y!@``R04``&4#``#O!0``LP4``&<#``#M`0``
M]@0``````````````````.4%``"H!0``1````,4!````````1P4``#,$```5
M!0``(P8``*@!``!_`0``#0(``)(!``#9````6@$``-X%``!_!0``$@(``&\"
M``!Y!```W04```,"``!$`P``6P4``'X"``![````4P0``)<"``",!0``````
M`(`!``#(`0``6`0``+0%````````X@````````">`@``GP4``$$"````````
ML@,```````!R`@```````$X&``!2`0``]P,```8#````````\@$``*,%````
M``````````````"/`0``6`(``&D"``!N````+@0````````6`@``U00`````
M``#6`P``<P,``$("```?!```90$``%8#````````,0(``$`$``!V`@``BP4`
M`-\%````````9@(``!$&```@!@``_P4``!@#``""`P``:`4``/4$````````
MJ00``#@$``"Z`@``>P4``!H!``!L````GP(``````````````````$L````U
M!0```````,\"```#`P``.00``!T&``!5!@``JP0``/D$``"L!```]`$```X!
M``#8`P``!P(```````!@````*P4``)H#``"J!`````````````#9!0``P0(`
M``````##!0``L`,``$0&``";````````````````````[P(``(D&``!+!@``
M`````-X!````````N````$8"````````4`(``'4"```J`0```````#L&```8
M`@``0P0``+8%````````L@0``.\#````````M@0``!$```"D!0``DP8``),"
M``!2`@``I`$``(4$````````*P```-P!``!C`@``````````````````V@,`
M`(@"``!6`0``QP,``$@!``!.!```'`(``#\!```"`P``+P0```````#Y`0``
M`````$D"````````=P(``"H#``#+`0``/P8```````!X!0``7`(``*(%``#(
M`````````%<```",!```XP,``$L$``")````D0```)(%``"<`0``'`4``',!
M``#4!0``+0,``*L!`````````````*(```"]`P``X@(```````"6`@``MP4`
M````````````<0$``$\#``#]`@``S@0``$H```!^````*P8``!<#``"$`P``
M]P(```````#*!0``*`$``,0"```F`P``QP4```(%``#;!0`````````````>
M`0``(@(``*,$````````%P4```````#U`````0$``($!``"@!0``P````#H$
M```]`0```````-8!`````````````/0`````````X0$`````````````9@0`
M`)`````>`@```````!X$``"I````LP(``#`#``#>````P@$`````````````
M4`8``%P#````````>@,`````````````\0,``"0!````````/P4``$4%```^
M````B`,`````````````00````````#+`````````&$&``!D````````````
M``"5!@``B@4``/L#```R!0```````!,&``"4!@``Z0(`````````````=```
M`/@#``!V!@``40,```8&```]!0```````+8#``"X`0``QP(```````"%!0``
M`````"`#```2!0``EP,```````!X!@``IP0``(H&`````````````*,"``"P
M`@``%@$``"$!```^!```40(``!@!``!'````1`$``/H"````````(00`````
M```\!```9`(``/,````X````60```,X```!C!```9`0``*\$````````B00`
M`.\$`````````````&X"`````````````(H#``"P!```@@4``"<#``!(`@``
MA0(``````````````````!T#``#?`0````````````#A!0``%@4``#<&```U
M````A0,```````"P!0``:@``````````````Q0,````#``#I`0```````-L$
M```/!@``S`4``!,$````````L0```!<!``#-`0``5`(``"8$````````;@,`
M```&``".`@``;P,```P%``"%`0``+08``$,`````````K@,``%($``"M````
MFP4``+("```"!```V@$``&8&``"4`0``Q`````````"W!```?P```)L$``!`
M`@``;P$``'H%``"G````!`,``"8```"'`P````$```````#\`P``_@4``&0&
M````````B0$``-0$````````PP$``&(!``#E````>`,``&\%````````I`0`
M`'T&```[`0```````$\````O````3P(`````````````T0(``.@```#0````
M8`(```0$```%````K@(```X$```/`0``OP````````"\`@``@P8`````````
M`````````+`!``":!```_04``*T$``#(!````````%`%````````U@```)4"
M``!(!@```````/X#``!;````%0```"P!``"M!0```````'P&``#/`P``````
M````````````+P,``$<"````````U`,``&D$``!B!0``50$``"\!````````
M]0$```````#D!```XP(```H%``#]`0``)0```!0```````````````````!@
M!@`````````````````````````````4!0``````````````````UP``````
M``!4`P``(08``(`$`````````````!(`````````S0```%0%``#2!0``)0$`
M`(\$```Y`P``U04``!P&``#_`0``Q`$```````!?!@``O@(``'$&``#>`P``
M9@$``',&``````````````````"1`0``3P4``%X%``!O````+@````H!````
M`````````-$!``#9!```!@$```````"O```````````````+`0``"@0``-T$
M````````#0$```````!9!@```````)0```#X!0``*@(``*8"``#7!0``H@$`
M`!$#``!P````D0(``````````````````*<"``!/!````````%`#``#,`0``
M)P0```````#C!```9`4`````````````&@(```````"6!0``^@$``$L!```L
M``````````````!:`@````````````!]`0````````````"S`````````!$"
M```]````3`(``-L"``!"!@```````$P```"8`@``^P$``"`!``"J`P``````
M``````"F````S@,``)<%``#I`P``Y`````````#T!```*0,`````````````
M[0,``.0#``#J`P``)0,`````````````4`0``+4$``#7`@``V0,``#D%```X
M!@``[@0``)T%``"[!```E`0``)D"```:````,08``"(%``"6`0``904`````
M```H!0```````/@$````````9P(``&(&``#\!0``/P(````````W`@``````
M``````"T````#P,``.$"````!```#@,````````N`P```````#0"``#8````
M`````%L&```D`P``O0$``"4%``#Z`P```````-\"``!1!0``^0```(0&```F
M!0``7@```-@"``"V````<P4````````I!@``$@8``/$```!\`@``;P8```8"
M```V`@``PP,``-H"``#7`P```````$L#````````#P0``)`"``"<!0``C`,`
M`.8#``!R!```<@$```````!9!```F0``````````````6@,``%4%``#[````
M_@$```````!J`0``&P8````````:!0````````````!%`P``<P```)H`````
M````\P0``$$#``"$`0``'0```*4```!Z`0``7P,``+X!`````````````(8#
M`````````````#4"``#B!```70,``"P&``!^!`````````````"3`P``P@,`
M`#0`````````CP4```8`````````H`(``,4```#R!````````#`"``!1````
MPP0``",!``#(!0``200``/X```!K`0``K``````````;````X`(```````#K
M!0````````````!%!```%`,``*$$``"-!```20$````````,`@``7P(`````
M``"_!0```````-\$````````7P$```H&``":`0``F0$``&$$``"/!@``8`4`
M``(```!U`P``<P(````````9`````````$($``!A`0``<@,```8%``#J!```
MQ@$``%@&``!K!@``Z@```(<"``#)`0```````)P$````````I@4````````A
M````F`4``&X&``!H`@``_`$``,P```"'`0``JP,````````,`0``60,``$\!
M```-!@```````#X!``"6````8P8``'0"```K`@```````.L```"8`0``@08`
M`(````#K`P``-@4``*L```"=`P````````````"8`````````!X#```:!@``
M4@```.P$```,````+0```'L#````````2@$```````"U`P``MP(``/<%``!Y
M`0``.@(``'\"```Q````3@(``&4&``#G````-08```@&``#G`P``T@0``%@%
M``!'`P``7@0``'L"````````Q`4``!($````````N`,````````!!@``'P,`
M`/$"````````I00````````_!```(@,```````!L`0``=`$``/D#````````
M#0```.D%```R!````````$@#``#!`P```````#8!```A!0``C0```-,!``#F
M`0``G@0`````````````;`(``&T&```:!```]P```$D%``"!````VP,``(4`
M``!^`P``_`0``,0#````````RP0``&$%``"Z`0``^P(``'L&``#B`0``1@,`
M`+,$``"-`P``L@$``"($``"M`0``&````+P$``"5`P``+0(```````#5`0``
M0P8``'P#````````%00``%<%``!4!``````````````0!```P@0```````"U
M````M0$``'P```!?!0```````#`%```R`0``GP0```P&````````H`$``$4&
M``#<`P``;`8``)P"``!]!0``[P$``&<!`````````````*H"``!'!```````
M``,%``"X!```N0```$P%``#X````?@8```````!(!0```````-`#``!C````
MA@```),```!3!0``I`````````#L!0```````#4$``"\!0``\00````````[
M!0```````,L"```.!@``/@4``-D"``"A!0``N@0``'@!``#6!```[@```)T`
M``!F!0``(`0```````#1`````````*X```!*!@``@04``%P$````````````
M`&<```"F`P``````````````````TP0``-\#``"6!````````$8$```R````
M_@0``)L!``!I!@````````````"4`P``U@4``.T`````````,`$```H```!P
M!```]@(``&4$```L`P``(@````(!```9`0```````&H$``"3!```Z@$``$L"
M``"Z````!0$``+L%``!L!0```````,4"``"B`@``R`,``,T#``!B!```:`,`
M`+T"````````]P0``*`````'````%0,``-D!``#S`0```````,8```"^!0``
M`````!$%``""!@``4`$```````"0!0``7`4``(`#``")`@``$P(``'@"````
M````U`$``/P```#S!0``6P$``/P"``#N`P``0@4``/T`````````AP0`````
M``#H!````````````````````````"L$``!/!@````````````"+`@``````
M`"\&``""````70(``+0"``"I`0``A08``-T```"+````:@,```0!````````
M2P4``&L"``!0`````````+4"````````008``#4!````````[@$``&T"```+
M!```'P4``"0%``#-`@``````````````````7````#L$``#*````K`,``+,#
M``#/`0````````````#K`0``0`,``/`"````````L````%,"````````,P8`
M`-@!```(`P``Y0(``,H!``!W````J`,``-("``!I`0````````````!%````
M6@8``-X$``"Y`@``@P0``&H%``"W`````````#P!`````````````*$#``#J
M`@```````(H"``"@`P````````````#1`P``B0,``"\"``#Y!0``@P```"H`
M````````JP(```````"9`P``C0(``%L$```I!```@`(``+(`````````````
M``````"_!```+`0``#(&``"Q!````````)<```#H`P``=04````````)````
M`````-`"``!\!```S@4````````(!```.`4```````#Q!0``U0```#P&```)
M`0```@8``*\!`````````````'0%``"W`0````````D%`````````````&D`
M``#:````E`(``)("```D!@``?0````````".`P``O0```)(#````````R0,`
M`-,%``!A`P``XP4````````4`0```````,("```L!0`````````````(`@``
M```````````=!0``3`,``'<!``"[`P```````+8!```Q!0``2``````````Q
M!```Y0$````````O!0``3`8``+X```">````$P```*P%```#!```5P$``+0!
M``#U`P``/00``(8%````````PP(``!$$``#H`0``:`````````!-!@``````
M`%X!``!?!```>@(``$(#``!C`P``"P4```````#``P``]@```$,"```(!0``
M!````%D"````````!`4``#H#``"4!0```````!L#```>!@``F04``"0$``"5
M!0``400``+D%``!_`P``YP4```````"7!@``9P4``'T$``#[!```<04``"H&
M``"T`P```````%4$``"/`@``000```````!Y`P``5@```'8$```J!0``,P,`
M``<&``#'!```&P$```P$``"C`P```````-P$``#0!```@@(``,H$```F`0``
MBP$```````!H!@``L0$``"<````+`````````,0$``#-!0``"@,`````````
M````^@4``#<#``"'````.@8``&H"````````[`$``/4%``!;`P``408``#``
M````````HP```),%```S`0```````#X"``!!!0```````#$!````````D`8`
M`(8"````````@@$```````!K````J0,``/8%```.````[P```'$#```H`@``
MBP,``'8%```W!0``>@````````#P`0```````&T%````````]@$```````"?
M`0``R@(``#T&````````Q@0````````1`0``5@4``````````````````($"
M``!-`P``<`8``$H"``"*`0```00``"@$````````5P0``,$$```N`@``VP$`
M`"<%```+`@```````!,!```W`0``7`8`````````````^@0``*@"```T!@``
M``````T%``!V````1`4``%H$````````?0(``&X!``#N!0``6@4``%4#````
M````/`,`````````````(P,``````````````````!8$```&!````````.$#
M```K`P``:04``$0$``#R`````````&0#```?!@``R@,``!8#``!Q`@``D04`
M`.`$`````````````,\%``#+`P``A@8``&T`````````%P```-0```!"````
M%08``!0"``#_`P``T`$``&L$``!-!```[04``%\```#R`@``30(```````"Q
M`@```````'D&````````]`,``!D#```V!@```````,4$``#1!```C````(L$
M````````&@,````````R`P``@`8``#D````7!```+`(``!P#````````````
M`(L&```;!0``Y`$``#@!```%`@``3@$```````````````````````"B!```
M604```````"[`@``NP$``%T%``#0!0``8@,```4&``!^`0``IP$````````\
M!0``W@(``'<%````````OP(``+@"```%!0```````.D`````````90(``(X$
M``!_!@``(@8``"D"```?```````````````3`P``I04``*\%```U`P``"0,`
M`&H&``!Q````!00``'$$``"5````L04``!T$``#[!0```````*P!```0`0``
MP`(``*T#``"\`0``'@4```<%``#F`@``B@0````````^!@``T04```````!C
M`0``I@0```$#````````G`,```````"J!0``Z@4``#L`````````5@0``&@$
M``!I`P```````!L$`````````````(<%````````W0$```````"1!```````
M`!\!``#-!````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN
M("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@
M870@`"5D("5S(&%N9"`E<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`
M)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS
M(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`
M)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O
M("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G
M<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@9W5S=&EN9R`E<R`E
M<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@4F%I;@!!32!3:&]W
M97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z
M96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@
M4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E
M<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES
M=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L
M;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M
M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D
M>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@
M4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M
M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X
M=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`
M06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A
M=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE
M`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N
M:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)
M<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N
M`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A
M:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H
M`$)A<F)A9&]S`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N
M:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L
M:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@
M5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI
M8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!"
M;W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A
M<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-2
M0P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN
M`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E
M="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N
M861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T
M92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S
M(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R
M;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S
M<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M
M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A
M<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R
M`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL
M('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE
M8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY
M`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC
M97,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT:6YU
M90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]S
M=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG
M;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC
M92X@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!
M0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U
M<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R
M+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT
M`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@
M82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I
M;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4
M:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O
M;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`
M0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A
M:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@
M<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L
M(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO
M<@!$969A=6QT($ED96YT:71Y`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@
M1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S
M86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(')O=P!$96QE=&4@<V5L96-T
M960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB
M92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO
M<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@
M4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L
M969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R
M>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P
M;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D
M`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%
M4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E
M<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%
M;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S
M<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE
M(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@
M=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE
M87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@
M<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<75A=&]R:6%L($=U
M:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`
M17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M
M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU
M=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E
M8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D
M('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO
M<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@
M9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O
M("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E
M($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&965L<R!,:6ME
M`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I
M96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI
M=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N
M80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE(%-E87)C
M:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA
M;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E
M;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I
M;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T
M:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D
M97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H
M25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(
M96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE
M(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@
M96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO
M(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L
M86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX
M;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A
M=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z
M("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A
M;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU
M;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`
M2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O
M=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@
M;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@
M0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O
M=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N
M<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES
M<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD
M;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T
M($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@
M='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E
M(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L
M;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`
M26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I
M9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);G-E<G0@
M0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R
M="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@
M8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O
M<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@
M<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T
M+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN
M=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N
M`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T>7!E
M+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV
M86QI9"!P<F]T;V-O;"X`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S
M;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R
M>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE
M(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI
M8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR
M,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I
M9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2
M:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I
M97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME
M>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO
M<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U
M86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L
M9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I
M80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO
M;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&EB97)I
M80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@
M1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I
M;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN
M:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T
M:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#
M;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T
M86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H
M:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI
M<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,
M;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,
M;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L
M9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P
M475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@
M9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!
M;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG
M(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D
M:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!L
M96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z
M`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S
M9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@
M8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE
M=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=')I8P!-97AI8V\`
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4
M>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C
M:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)
M1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I
M9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO
M;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N
M(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO
M<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V
M92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N
M=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O
M($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N
M9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%52
M3`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%52
M3`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`
M3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W
M(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H
M7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC
M87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E
M;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD
M+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO
M(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E
M;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN
M9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.
M;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E
M`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO
M="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T
M('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@
M9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S
M`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T
M('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N
M`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N
M<V4@9FEL=&5R`$]F9FEC90!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N
M;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE
M=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T
M82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N
M<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I
M;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!)
M;F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'
M4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN
M`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@5"U3=&]R
M;7,`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN
M96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I
M;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E
M(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T
M:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I
M<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C
M96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS
M`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI
M;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF
M;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R
M*',I.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E
M;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0
M<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C
M=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H
M;0!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME
M>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A
M:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO
M=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A
M;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H
M(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296UA
M<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C
M;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=6ER960@
M1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R
M9`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4F5V97)T($-O
M;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`
M4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I
M97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T
M871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z
M`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD
M(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U
M<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,
M(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA
M`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R
M<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4
M;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A
M8FEA`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+@!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`
M4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@
M;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D
M9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C
M=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD
M(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E
M=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA
M>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO
M=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N
M9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@
M:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S
M($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E
M($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L
M;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S
M`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E
M<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA
M;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO
M;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I
M;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C
M96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3
M=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC
M90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME
M=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D
M<F5S<P!3='EL92!;0U-370!3=0!3=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`
M4W5C8V5S<P!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C
M:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('=R;W1E
M("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR
M:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``
M4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D
M(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B
M;&EC`%0M4W1O<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O
M<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I
M;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F
M;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP
M;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U
M(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I
M;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N
M965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C
M:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T
M;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D
M871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U
M<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S
M<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A
M=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I
M960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I
M='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W
M:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M
M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S
M92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@
M;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A
M<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y
M(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N
M($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O
M('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4
M:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N
M('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O
M;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y
M960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL
M>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E
M<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@
M;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E
M>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S
M:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B
M;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E
M(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H
M879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S
M<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R
M96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T
M97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A
M;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W
M=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@
M9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE
M>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES
M(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C
M="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A
M;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F
M('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S
M86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R
M('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII
M<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4
M:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E
M;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O
M`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N
M`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R
M;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R
M:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U
M<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``
M52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y
M('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@
M86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S
M(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L
M971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@
M=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T
M:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N
M9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL
M960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E
M9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/
M=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W
M<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI
M<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D
M871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R
M($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO
M;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I
M;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L
M=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E
M;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O
M;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A
M;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE
M=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER
M9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES
M:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``
M5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C
M87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`
M5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ
M-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P
M:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E
M>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H
M.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I
M;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A
M8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R
M('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N
M93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I
M;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:
M86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=
M`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN
M:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`
M7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?
M36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@
M3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D
M9')E<W,@8F]O:P!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`9F%L;&EN9P!F
M:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`:6UM961I871E`&EN
M;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT
M960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E
M;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W1E861Y`'1A<VL@;&ES=`!T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE
M9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED
M+59E<G-I;VXZ($AO<F1E(#,N,`I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#<M,C(@,3$Z
M-#DM,#<P,`I,87-T+51R86YS;&%T;W(Z($UI;&]S(%=I;6UE<B`\=VEM;65R
M0'IC=2YC>CX*3&%N9W5A9V4M5&5A;3H@0WIE8V@@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU<F%L
M/2AN)3$P/3TQ("8F(&XE,3`P(3TQ,2`_(#`@.B!N)3$P/CTR("8F(&XE,3`\
M/30@)B8@*&XE,3`P/#$P('Q\(&XE,3`P/CTR,"D@/R`Q(#H@,BD["@`@*'#X
M960@)7,@9&YY*0`@*%#X[7-T=7!O=OT@:VSMZ"`E<RD`("AV("5S(&1N96-H
M*0`@*&1N97,I`"`H>NUT<F$I`"`H=NAE<F$I`"!R>6-H;&]S="``)60@)7,@
M82`E<P`E9"UD96YN[2!P^&5D<&]V[.\`)7,@+2!O>F[A;65N[0`E<R!O=&ES
M:P`E<R!+0@`E<R!O<&5R86-E(/ID<KYB>2`M('!O='9R>F5N[0`E<R!N87-T
M879E;NT`)7,@<F5G:7-T<F%C90`E<R!P;V1M[6YK>2!P;W6^[7;A;NT`)7,@
M:FF^(&5X:7-T=6IE+@`E<R!N82`E<R`E<P`E<R!J92!P;[YA9&]VX6YO`"5S
M(&UI;G5T`"5S(&YE8GEL;R!N86QE>F5N;RX`)7,@8;X@)7,@>B`E<P`E<R!A
M9')E<^'X`"5S(&MA;&5N9.'X`"5S('KA<&ES;NUK`"5S('-E>FYA;2#Z:V]L
M^0`E<SH@)7,`+"!NX7)A>F]V_2`E<R`E<P`L('!R;VWL;F[A(&]D("5S(&1O
M("5S`"TM(';]8NQR("TM`#$R(&AO9&EN;W;](&9O<FWA=``R-"!H;V1I;F]V
M_2!F;W)MX70`,C0@:&]D:6X`4')O('1E;G1O(&)L;VL@:F4@=GF^861O=N%N
M(&1A=&%BX7IO=OT@>F1R;VHN`%9Y<VMY=&QA('-E('KA=F&^;N$@8VAY8F$`
M4')O('IAN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN
M_2!01U`@:VSMZ"X`4')O('9E<FEF:6MA8VD@<&]D97!S86[I('IP<N%V>2!J
M92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"X`4')O(&1EN6EF<F]V
MX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"P@
M<')I=N%T;NT@4$=0(&ML[>@@82!H97-L;RX`4')O('!O9&5P<^%N[2!Z<'+A
M=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M
M(%!'4"!K;.WH(&$@:&5S;&\N`%!R;R!D9;EI9G)O=N%N[2!Z<'+A=GD@:F4@
M;G5T;F\@<&]UONUT('9E^&5J;OT@4R]-24U%(&ML[>@L('!R:7;A=&[M(%,O
M34E-12!K;.WH(&$@:&5S;&\N`%!R;R!P;V1E<'/A;NT@>G!RX79Y(&IE(&YU
M=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEVX71N[2!3+TU)
M344@:VSMZ"!A(&AE<VQO+@!0<F\@>F&Y:69R;W;A;NT@>G!RX79Y(&IE(&YU
M=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+@!286YN[2!DZ;F[`%)A
M;F[M('#X96CA\FMY`%)A;F[M('-N[&AO=ND@</AE:.'R:WD`04TO4$T`05!)
M($E$`$EN9F]R;6%C92!O('1O;71O(&5D:71O<G4`26YF;W)M86-E+BXN`%1E
M>'0@9&]L^2!D;R!O8G+A>FMU`%1E>'0@9&]P<F]S=/AE9"!O8G+A>FMU`%9Y
M='9O^&5N[2!61E,@861R87/A^&4@;F5B>6QO('!O=F]L96YO+@!6>71V;_AE
M;NT@5D93('-O=6)O<G4@;F5B>6QO('!O=F]L96YO+@!5OFEV871E;'-KZ2!H
M97-L;P!5OFEV871E;&O](/KH970@8GEL('IA8FQO:V]VX6XN`%6^:79A=&5L
M:^D@^NAT>0!6;&^^`%#X:61A="!P;V1S:W5P:6YU`%#X:61A="!P;V0M<'+A
M=F$`4/AI9&%T.@!0^&ED870@;F]V;W4@<VMU<&EN=0!0^&ED870@;F]VX2!P
M<N%V80!0^&ED870@;F]VZ6AO('6^:79A=&5L93H`4/AI9&%T('-L;W5P96,`
M4/AI9&%T(&YO=ND@Z&QE;GD`4/AI9&%T('#A<@!0^&ED870@)7,@;65N=2!J
M86MO(&)OZ&[M('-L;W5P96,@36]Z:6QL>0!0^&ED870@9&\@861R97/A^&4Z
M`%#X:61A="!D;R!MZ6AO(&%D<F5SX?AE`%#X:61A="!UOFEV871E;&4`4/AI
M9.%VX6[M('6^:79A=&5L^2!J92!Z86)L;VMO=N%N;RX`061R97-A`$%D<F5S
MX?@`5GEK;V[A=F%T(&%D;6EN:7-T<F%C:2`M(&YA<W1A=F5N[2!P^.US='5P
M;W;]8V@@<'+A=B!P<F\@;W-T871N[2!UOFEV871E;&4`061M:6YI<W1R86-E
M`$EN>F5RX71Y`$%F9VCA;FES=.%N`$%L8N%N:64`06R^[7)S:V\`4/AE>F3M
M=FMA+T%L:6%S`%IA<F]V;F%T`%IA<F]V;N%N[3H`5KEE`%:Y:6-H;FD@;W;L
M^&5N[2!UOFEV871E;.D`5KEE8VAN>2!S:W5P:6YY`%:Y96-H;F$@=;YI=F%T
M96QS:^$@<'+A=F$`5KEE8VAN>2#H='GX:2!S=')A;GD`4&]V;VQI="!V[6-E
M(&%D<F5S`%!O=F]L:70@;F%S=&%V96[M('1Y<'4@<V5T^.UD[&[]('-E>FYA
M;3\`2FF^(&5X:7-T=6IE`$%L=&5R;F%T:79N[2!)35-0('#X:6ALX;EE;NT@
M9&\@<WES=.EM=0!!;'1E<FYA=&EV;NT@24U34"!H97-L;P!!;'1E<FYA=&EV
M;NT@24U34"!UOFEV871E;'-KZ2!J;>EN;P!!;'1E<FYA=&EV;NT@92UM86EL
M;W;A(&%D<F5S80!!;'1E<FYA=&EV;NT@=GIO<GD`06QT97)N871I=F[M('1E
M>'0Z`$%M97)I8VOA(%-A;6]A`$)Y;&$@>F%DX6YA(&YE<&]V;VQE;N$@:&]D
M;F]T82X`06YD;W)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UN[2!P<F]X>0!/
M9'!O=NSO`$%N=&%R:W1I:V$`06YT:6=U82!A($)A<F)U9&$`07!L:6MA8V4`
M4V5Z;F%M(&%P;&EK86/M`$%P;&EK86-E(&IE('#X:7!R879E;F$`4&]UONUT
M('!R;R!D[&1IZ&[I('-D[6QE;NT`4V-H=N%L:70`4/AI8FQIOF[A('9E;&EK
M;W-T`$1U8F5N`$%R86)S:WD@*%=I;F1O=W,M,3(U-BD`5F5L:6MO<W0@87)C
M:&EV;W9A;NEH;R!S;W5B;W)U`$IMZ6YO(&%R8VAI=G4`57+H:73L(&-H8V5T
M92!V>6UA>F%T(+[A9&]S="!O('#X:6ALX;EE;NT@9&\@)7,_`$%R9V5N=&EN
M80!!<FWI;FEE`$%R;>EN<VO]("A!4DU30TE)+3@I`%5M[&[M`$%R=6)A`$%S
M8V5N<VEO;B!)<VQA;F0`07-C:6D@=6WL;NT`07-I92]R96=I;VX@5&EC:.EH
M;R!O8V7A;G4`4&^^X61A="!O('!O='9R>F5N[2!P^&5D('!R;W9E9&5N[6T@
M;W!E<F%C[2#Z9'*^8GD_`%-L;W5P8V4@<R#Z:V]L>0!0;VMU<R!O('9Y;6%Z
MX6[M(&YE97AI<W1U:NUC[2!S:W5P:6YY+@!0;VMU<R!O('9Y;6%ZX6[M(&YE
M97AI<W1U:NUC[6-H('6^:79A=&5L<VO]8V@@<'+A=BX`4&]K=7,@;R#Z<')A
M=G4@;F5E>&ES='5J[6/M8V@@=;YI=F%T96QS:_UC:"!P<N%V+@!0;VMU<R!O
M(/IP<F%V=2!N965X:7-T=6KM8^UH;R!S9.UL96[I:&\@;V)J96MT=2X`071R
M:6)U='D`4W)P96X`075S='+A;&EE`%)A:V]U<VMO`$%U=&A?8WER<W%L.B!.
M96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!I;6%P+@!!
M=71H7V-Y<G5S.B!:9')O:B!N96WA('!OOF%D;W9A;ND@<V-H;W!N;W-T:2X`
M075T:%]C>7)U<SH@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N
M82!P<F\@:6UA<"X`075T:%]F='`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V
M86[A('#X[7!O;F$@<')O(&9T<"X@2V]M<&EL=6IT92!02%`@<R`M+65N86)L
M92UF='``075T:%]I;6%P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P
M^.UP;VYA('!R;R!)34%0+@!!=71H7VMR8C4Z($YE8GEL82!N86QE>F5N82!P
M;[YA9&]V86[A('#X[7!O;F$@<')O(&MR8C4N`$%U=&A?;&1A<#H@3F5B>6QA
M(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@3$1!4`!!=71H7VQD
M87`Z($YE;'IE('#X:61A="!UOFEV871E;&4@)7,N($ALX;EE;NT@<V5R=F5R
M=3H@`$%U=&A?;&1A<#H@3F5L>F4@=GEM87IA="!UOFEV871E;&4@)7,`075T
M:%]L9&%P.B!.96QZ92!A:W1U86QI>F]V870@=;YI=F%T96QE("5S`$%U=&A?
M;6-A;#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@
M34-!3"X`075T:%]S;6)A=71H.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%N
MX2!P^.UP;VYA('!R;R!S;6)A=71H+@!/=NSX96[M('-E;&AA;&\`3W;L^&5N
M[2!S96QH86QO+B`E<P!/=NSX96[M(&)Y;&\@>F%M[71N=71O(%)!1$E54R!S
M97)V97)E;2X`4V5L:&%L;R!O=NSX96[M($944"!S979E<F5M+@!$;W-T=7!N
MX2!P;VQE.@!!>F5R8F%J9+[A;@!"3T9((';];6QU=GD`4&]Z863M`$)A<G9A
M('!O>F%D[0"I<&%T;ND@:&5S;&\@<')O(&ME<F)E<F]S+@"I<&%T;ND@=;YI
M=F%T96QS:^D@:FWI;F\@<')O(&ME<F)E<F]S+@!"86AA;7D`0F%H<F%I;@!"
M86QT:6-KZ2`H25-/+3@X-3DM,3,I`$)A;F=L863IN0!"87)B861O<P!:X6ML
M860`0NQL;W)U<VMO`$)E;&=I90!"96QI>@!"96YI;@!"97)M=61Y`$)H^G3A
M;@!.87)O>F5N:6YY`$YE;'IE(&YA;.EZ="#HX7-T("(E<R(@87!L:6MA8V4@
M(B5S(BX`3F%S=&%V96[M(&)L;VMU`%1Y<"!B;&]K=0!4=>AN[`!";VSM=FEE
M`%KA;&^^:WD`3VMR86H`J>WX:V$@;VMR86IE.@!/:W)A:F4`0F]S;F$@82!(
M97)C96=O=FEN80!/8F$`0F]T<W=A;F$`1&]L;NT@Z.%S=`!";W5V970@27-L
M86YD`$)R87KM;&EE`$)R:71S:^$@=&5R:71O<FEA('8@26YD:6-KZ6T@;V-E
MX6[L`$)R=6YE:2!$87)U<W-A;&%M`$)U;&AA<G-K;P!397IN86T@<R!O9'+A
MOFMA;6D`0G5R:VEN82!&87-O`$)U<G5N9&$`0TU3`$-20P!#4DP@9&ES=')I
M8G7H;NT@8F]D>0!6;&%S=&YO<W1I(&)?=?)K>2XN+@!+86QE;F3A^`!"97IV
M['3X[0!+86UB;V2^80!+86UE<G5N`$AE<VQO(&YE;'IE(&YA<W1A=FET(&%U
M=&]M871I8VMY+"!P<F]S[6T@:V]N=&%K='5J=&4@5F&Y96AO('-Y<W3I;6]V
MZ6AO(&%D;6EN:7-T<N%T;W)A+@!.96QZ92!S92!P^&EP;VII="!K($E-05`@
M<V5R=F5R=3H@)7,`2V%N861A`%-T;W)N;P!3=&]R;F\@:&SAN65N[2!P<F]B
M;.EM=0!.96QZ92!V>6UA>F%T('-O=6)O<B`B)7,B+@!.96QZ92!N86KM="!D
M;^AA<V[](&%D<F5SX?@N`$YE;'IE('!O:W)AZ&]V870@8F5Z('!A<F%M971R
M=2`G=&%R9V5T1FEL92<N`$YE;'IE('9Y;6%Z870@861R97/A^"`B)7,B+@!.
M96QZ92!V>6UA>F%T+"!P<F]T;[YE(&5X:7-T=6KM('!O9'-K=7!I;GD@)60N
M`$YE;'IE('!R;W;I<W0@>FWL;G4@=7-P;_CA9.%N[2P@<&_H970@<&]S:WET
M;G5T_6-H('!O;&^^96L@<')O(&YO=ND@=7-P;_CA9.%N[2!N96]D<&]V[63A
M('!OZ'1U('5L;[YE;OUC:"!P;VQOOF5K+@!.96QZ92!Z87-L870@>G!RX79U
M(&YA('IA9&%NZ2#H[7-L;RX@`$-A<&4@5F5R9&4`5&ET=6QK>0!+871E9V]R
M:64@82!Z;F'H:WD`2V%J;6%N<VOI(&]S=')O=GD`36]B:6QN[2!T96QE9F]N
M`$UOOFYO<W1I(&)U\FMY`$]D<W1U<"!M97II(&)U\FMA;6DZ`%9L87-T;F]S
M=&D@8G7R:WD`365Z97)Y(&UE>FD@8G7R:V%M:3H`36]B:6QN[2!T96QE9F]N
M`$ME;'1S:_T@*$E33RTX.#4Y+3$T*0!3=/AE9`!3=/AE9&]A9G)I8VOA(')E
M<'5B;&EK80!3=/AE9&]E=G)O<'-K_2`H25-/+3@X-3DM,BD`4&]D<F]B;F]S
M=&D@8V5R=&EF:6OA='4`4&]D;>UN:WD@8V5R=&EF:6OA='4`R&%D`%IM[&YI
M=`!.87-T879E;NT@:FWI;F$@82!E;6%I;&]VZ2!A9')E<WDN(%1Y=&\@<&]L
M;[YK>2!L:63I('5V:63M+"!K9'F^('-I(.AT;W4@;F5B;R!O9'!O=NUD86KM
M(&YA(%9AN64@>G!RX79Y+@!:;F%K`%IK;VYT7W)O;&]V870@;V1K87HN+BX`
M0VAI;&4`R.UN80#([6ZY=&EN82!Z:F5D;F]D=;EE;N$@*$=",C,Q,BD`5')A
M9&GH;NT@Z.UNN71I;F$@*$)I9S4I`%IV;VQT92!H97-L;P!:=F]L=&4@=;YI
M=F%T96QS:^D@:FWI;F\`5GEB<F%T('IO8G)A>F5N[2!D871U;74Z`%9Y8G)A
M="!T>7`@<W1Y;'4@<V5Z;F%M=2`H<')O(/AA>F5NZ2!S97IN86UY*0!6X6YO
MZ&[M(&]S=')O=@!.96)Y;&$@;F%L97IE;F$@9&5F:6YI8V4@=/CM9'D@)7,N
M`%9YZ&ES=&ET`%9YZ&ES=&ET('IN8>AK>2!Z($U33V9F:6-E`$]D<W1R86[L
M;NT@=;YI=F%T96QE.B`E<P!/9'-T<F%N:70@=;YI=F%T96QE`$]D<W1R86[L
M;NT@^F1A:OD@;R!UOFEV871E;&D`2VQI:V[L=&4@<')O('!O:W)AZ&]VX6[M
M`$-L:6-K871E;&P@</AE<R!(5%10`%IA=OCM="!O:VYO`%IA=&&^96YO`$]B
M;&'H;F\`2V]K;W-O=ND@;W-T<F]V>0!3:VQA<&YO=70@8F_H;NT@;&FY='4`
M4VML87!N;W5T(&]K<F%J90!+;VQU;6)I90!"87)V80!6_6+L<B!B87)E=@!0
M86QE=&$@8F%R978`4VQO=7!C93H`3N%Z=GD@<VQO=7!C90!+;VUI:W-Y`%#X
M[6MA>@!0^.UK87IO=N$@:V]N>F]L80!0;WINX6UK80!/8F5C;ND@:FWI;F\`
M2V]M;W)O<P!&:7)M80!0;^CM=&'H90!0;V1M[6YK>0!2;WID[6QY('8@;F%S
M=&%V96[M`$YA<W1A=FET("5S`%!O='9R9&ET(&AE<VQO`$MO;F=O`$MO;F=O
M+"!$96UO:W)A=&EC:^$@<F5P=6)L:6MA`%-P;VIE;NT@<V5L:&%L;RX`4W!O
M:F5N[2!S96QH86QO.B``0GEL;R!Z86WM=&YU=&\@<W!O:F5N[2!S('9E^&5J
M;OUM(&ML[>AO=OUM('-E<G9E<F5M+@!">6QO('IA;>UT;G5T;R!S<&]J96[M
M(',@=F7X96IN_6T@:VSMZ&]V_6T@<V5R=F5R96TN($3Y=F]D(#H@)7,@*"5S
M*0!396QH86QO('-P;VIE;NT@<R!&5%`@<V5R=F5R96TN`$MO;G1A:W1Y(&)Y
M;'D@^G-P[+EN["!P^&EDX6YY(&1O(%9AN65H;R!A9')E<^'X92X`4&]K<F'H
M;W9A=`!#;V]K;W9Y(&]S=')O=GD`2V]LX>AE:P!+;W#M<F]V870`2V]P[7)O
M=F%T(';]8NQR`$MO<W1A<FEK80!0;V+X9;[M('-L;VYO=FEN>0!:<'+A=G4@
M;F5L>F4@N6EF<F]V870@<&]M;V/M(%!'4"X`6G!RX79U(&YE;'IE('!O9&5P
M<V%T('!O;6]C[2!01U`N`%IP<N%V=2!N96QZ92"Y:69R;W9A="!P;VUO8^T@
M4R]-24U%+@!:<'+A=G4@;F5L>F4@<&]D97!S870@<&]M;V/M(%,O34E-12X`
M3F5L>F4@</AI9&%T(&MO;G1A:W0N("5S`$YE;'IE('-E('#X:7!O:FET(&L@
M3$1!4"!S97)V97)U+@!.96QZ92!Z:V]N=')O;&]V870@^NAE="X@)7,`3F5L
M>F4@=GET=F_X:70@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!D9;EI
M9G)O=F%T(%!'4"!D871A+@!.96QZ92!D9;EI9G)O=F%T(%,O34E-12!D871A
M+@!.96QZ92!S;6%Z870@:V]N=&%K="X@)7,`3F5L>F4@<VUA>F%T(&1I<W1R
M:6)UZ&[M('-E>FYA;2X@)7,`3F5L>F4@>FII<W1I="!E+6UA:6QO=F]U(&%D
M<F5S=2!P^.UJ96UC92X`3F5L>F4@>NUS:V%T(/IP;&[](&%D<F5SX?@N`$YE
M;'IE('KM<VMA="#Z<&QN_2!D:7-T<FEB=>AN[2!S97IN86TN`$YE;'IE('KM
M<VMA="#Z<&QN_2!S97IN86T@9&ES=')I8G7H;NUC:"!S97IN86WY+@!.96QZ
M92!Z[7-K870@=F7X96IN_2!K;.WH('H@:VSMZ&]VZ6AO('-E<G9E<G4N`$YE
M;'IE(&]T97;X[70@)7,N`$YE;'IE('!R;W;I<W0@;W!E<F%C92#Z9'*^8GD@
M<')O(&UO9'5L("5S`$YE;'IE(.CM<W0@)7,N`$YE;'IE(')E<V5T;W9A="!H
M97-L;R!P<F\@9&%NZ6AO('6^:79A=&5L92X@5KEE8VAN>2!N96)O(&[L:W1E
M<ND@>B!P;V1R;V)N;W-T[2!N96)Y;'D@<W!RX79N["!Z863A;GDN(%IK=7-T
M92!T;R!Z;F]V=2!N96)O('!O:W5D('!O=/AE8G5J971E('!O;6]C+"!K;VYT
M86MT=6IT92!S<'+A=F-E('-Y<W3I;74N`$YE;'IE('KM<VMA="!!0TP`3F5L
M>F4@>NUS:V%T(&%D<F5SX?@N("5S`$YE;'IE('KM<VMA="!D:7-T<FEB=>AN
M[2!S97IN86TN("5S`$YE;'IE('KM<VMA="!D:7-T<FEB=>AN[2!S97IN86UY
M+B`E<P!.96QZ92!Z[7-K870@<V-H;W!N;W-T:2!S97)V97)U`$YE;'IE('#X
M97!N;W5T(&MO;F9I9W5R86-I+@!.96QZ92!U;&^^:70@:V]N9FEG=7)A8VD@
M<')O("5S+@!.96QZ92!U;&^^:70@>N%L;[YN[2!K;VYF:6=U<F%C:2X`3F5L
M>F4@=6QOOFET('KA;&]H=2!K;VYF:6=U<F'H;NUH;R!S;W5B;W)U("5S+@!.
M96QZ92!H;&5D870@=B!,1$%0('-E<G9E<G4N`$YE;'IE(&%K='5A;&EZ;W9A
M="!K;VYT86MT+B`E<P!.96QZ92!A:W1U86QI>F]V870@9&ES=')I8G7H;NT@
M<V5Z;F%M+B`E<P!.96QZ92!N86SI>G0@8F_H;NT@;&FY='4@<')O($UO>FEL
M;'4N(%!R;W/M;2!P^&5S=NQDZ'1E('-E+""^92!J92!O=&5V^&5NX2X`3V1P
M;^CM=&%N_2!T97AT`%IE;>P`5GEUZ&]V86/M('#X961M['1Y`%9Y='9O^&ET
M`%9Y='9O^&ET(&]D:V%Z`%9Y='9O^&ET(&YO=F]U`%9Y='9O^&ET('!O9'-L
M;[YK>0!4=OER8V4@<'+A=@#([7-L;R!K<F5D:71N[2!K87)T>0!#:&]R=F%T
M<VMO`$MU8F$`06MT=>%L;NT@Z&%S`$%K='7A;&[M(%523"!J90!!:W1UX6QN
M[2!P;^AA<^T`06MT=>%L;NT@<&]D;>UN:WDZ(`!.>6[L:KGM('-T>6P`3F%S
M=&%V96[M(/IK;VSY('!R;W;A9.QN_6-H('#X:2!P^&EH;.&Y96[M(&1O("5S
M+@!6>7-T^&EH;F]U=`!6>7-T^&EH;F]U="!V_6+L<@!+>7!R`$%Z8G5K82`H
M2T])."U2*0!!>F)U:V$@*%=I;F1O=W,M,3(U,2D`07IB=6MA+U5K<F%J:6YA
M("A+3TDX+54I`,AE<VOA(')E<'5B;&EK80!$1`!$96YN[`!$871A5')E92!P
M<F]H;.V^9>@`1&%T=6T`4/AI:F%T;R!D;F4`5OUB['(@9&%T=6UU`$1E;@!3
M;6%?>F%T('-L;W5P96,`4')O<VEN96,`R.US;&$@9&5S[71K;W;I('-O=7-T
M879Y`%IM96ZY:70@;V1S87IE;NT`26UP;&EC:71N[0!);7!L:6-I=&[M(&)A
M<G9A`$EM<&QI8VET;NT@:61E;G1I=&$`1&5F:6YI8V4`4VUA>F%T`%-M87IA
M="!S:W5P:6YU`%-M87IA="!P<N%V80!3;6%Z870@82!V>>AI<W1I="!Z<'+A
M=GD`4VUA>F%T(&)U\FMU`%-M87IA="!S;&]U<&5C`%-M87IA="!E>&ES='5J
M[6/M(&%L=&5R;F%T:79N[2!V>F]R`%-M87IA="#XX61E:P!3;6%Z870@=GEB
M<F%N;W4HZ2D@:61E;G1I='4H>2D`4VUA>F%T('-O=>AA<V[]('-L;W5P96,`
M4VUA>F%T('-O=>AA<V[](/CA9&5K`,AA<R!D;W)UZ&5N[0!$X6YS:V\`4&]P
M<V%T('!R;V)LZ6T`4&]P:7,`4&]D<F]B;F]S=&D@*'1A:^D@=B!L;V<@<V]U
M8F]R=2!(;W)D92DZ`%!O9')O8FYO<W1I(&)Y;'D@>F%Z;F%M96[A;GD@9&\@
M;&]G('-O=6)O<G4@<')O(&%D;6EN:7-T<N%T;W)A+@!6_79O:@!2;W-N_2!B
M;V0`4F]S;OT@8F]D('IA('!O<VQE9&[M(&AO9&EN=3H@`%)O<V[](&)O9#H@
M`%-M['(@>B!L979A(&1O<')A=F$`4VWL<B!Z('!R879A(&1O;&5V80!!9')E
M<^'X`%IO8G)A>FET(#(T+6AO9&EN;W;](.AA<S\`36^^;F]S=&D@>F]B<F%Z
M96[M`%IO8G)A>FET('#X961P;W;L[R`H5$%&*0!&;W)MX70@>F]B<F%Z96[M
M`$1I<W!O>FGH;NT@=7!O>F]R;NQN[0!$:FEB;W5T:0!.97-M87IA=`!.97#X
M:7-T=7!O=F%T('#X[6UO(&1O(&UA:6YT96YA;F-E+G!H<`!/8G-A:'5J92!P
M<G9N[2#XX61E:R!NX7IE=B!S;&]U<&/Y/R!0;VMU9"!A;F\L('IAN6MR=&[L
M=&4@=&5N=&\@<N%M9>AE:SH`1&]M:6YI:V$`1&]M:6YI:^%N<VOA(')E<'5B
M;&EK80!3=&&^96[M`%-T8;YE;NT@)7,`4W1A:&YO=70@9V5N97)O=F%N;W4@
M:V]N9FEG=7)A8VD@:F%K;R!02%`@<VMR:7!T+@!2;VQE=&]V_2!S97IN86T`
M1')O9WD`12UM86EL`$524@!%:W;A9&]R`%5P<F%V:70`57!R879I="!B;&]K
M`%5P<F%V:70@<VMU<&EN=0!5<')A=FET('!RX79A`%5P<F%V:70@<'+A=F$`
M57!R879I="!P<N%V82!P<F\@)7,`57!R879I="!M;[YN;W-T:2!P<F\Z`%5P
M<F%V:70@<'+A=F$@<')O("5S`%;]=6MA`$5G>7!T`$5L(%-A;'9A9&]R`%!R
M=F5K+BXN`$5M`$5M86EL`$5M86EL;W;A(&%D<F5S80!%;6%I;&]VZ2!A9')E
M<WD@<V4@;75S[2!S:&]D;W9A="X`16UA:6P@<R!P;W1V<GIE;NUM`$EK;VYK
M>2!S(&5M;V-E;6D`4'+A>F1NX2!Z<'+A=F$N`%!RX7ID;OT@=OUS;&5D96LN
M`%!RX7ID;OT@=&5R;>UN('!R;R!V>6AL963A=N%N[0!0;W9O;&ET('9K;.%D
MX6[M(&]B<F%Z:_D@>B!F;W1O(&=A;&5R:>T@9&\@=&5X='4_`$%K=&EV;W9A
M="!P<F%VZ2!K;&EK;G5T[2!P<F\@:V]N=&5X=&]VZ2!M96YU/P!+;VYE8R!R
M;VMU`%IV['2Y:70@961I=&]R`%IA9&5J=&4@8F5Z<&7H;F]S=&[M(&]TX7IK
M=2P@;F$@:W1E<F]U(&)U9&5T92!M=7-E="!O9'!O=NQD['0@<&]K=60@<VD@
M8G5D971E(&-H=.UT(')E<V5T;W9A="!S=ND@:&5S;&\L(&YA</@N("=*86OI
M(&IE(&IMZ6YO(%9AN65H;R!P<V$_)SH`6F1E('9L;[YI="!54DP@;V)RX7IK
M=0!2;W9N[6MO=N$@1W5I;F5A`$5R:71R96$`0VAY8F$`3F%S=&%L82!C:'EB
M82!S('!ON71O=F[M('IP<N%V;W4N`$5S=&]N<VMO`$5T:6]P:64`171N:6-K
MZ0!%=G)O<&$`2V&^9/UC:"`Q-2!M:6YU=`!+8;YDZ2`R(&UI;G5T>0!+8;YD
M_6-H(#,P('-E:W5N9`!+8;YD_6-H(#4@;6EN=70`2V&^9.D@</AI:&SAN65N
M[2!D;R!S>7-TZ6UU`$MAOF1O=2!P^6P@:&]D:6YU`$MAOF1O=2!M:6YU='4`
M5GIO<F]V_2!P^.UK;&%D(&AO9&YO=#H`4')O=NES=`!2;WIV:6YO=70`4F]Z
M8F%L:70@8F_H;NT@;&FY='4`3^AE:^%VX6YA("<I)P!/Z&5KX7;A;F\@<V%M
M;W-T871NZ2!S;&]V;R!N96)O(&AL961A;OT@=&5R;>UN('8@=79O>F]V:^%C
M:`!$871U;2!P<F\@:V]N96,@<&QA=&YO<W1I`$5X<&]N96YT`$)A<G9A('!O
M</AE9.T`4/AE;F]S(&MO;F9I9W5R86-E('!O;6]C[2!&5%``4V5L:&%L;R!Z
M[7-KX6[M(&UOOFYO<W3M+@!.96QZ92!S92!P^&EP;VII="!K($Q$05`@<V5R
M=F5R=2X`3F5L>F4@<V4@</AI<&]J:70@:R!334(@<V5R=F5R=2X`4V5L:&%L
M;R!K;W#M<F]VX6[M('H@(B5S(BX`4V5L:&%L;R!K;W#M<F]VX6[M(&1O("(E
M<R(N`%-E;&AA;&\@>F%L;[YE;NT@;F]VZ6AO(%-!4TP@<W!O:F5N[2X`4V5L
M:&%L;R!P^&5S=6YU=.T@9&\@(B5S(BX`1&]B<ND`1F%L:VQA;F1S:^D@;W-T
M<F]V>2`H36%L=FEN>2D`1F%R:6IS:^D@;W-T<F]V>0!:X79AOF[A(&-H>6)A
M.@!&87@`VFYO<@!#[71I="!S92!J86MO`$/M=&ET('-E(&IA:V\Z`$1R;V)N
MZ2!P^&5HX?)K>0!$<F]B;ND@<V[L:&]VZ2!P^&5HX?)K>0!-871I8V4@<&]L
M90!&:6II`%!OZ&5T('-O=6)O<ODZ("5S('-O=6)O<@!0;^AE="!S;W5B;W+Y
M.B`E<R!S;W5B;W+Y`%-P<N%V8V4@<V]U8F]R^0!.X7IE=B!S;W5B;W)U`%;]
M8NQR('-O=6)O<G4`4/AE;NES="!S;W5B;W(`4/AE;F]S('-O=6)O<OD@;F5N
M[2!P;V1P;W)O=N%N+@!&:6QT<GD`1FEN<VMO`%!R=F[M('!O;&]V:6YA`%!R
M=F[M(.AT=G)T:6YA`%!E=F[I(&WL^.UT:V\`4/AE:&]D:70`4&QO=F]U8^T`
M36QH80!3;&^^:V$@)7,@;F5E>&ES='5J90!"87)V82!P[7-M80!*[61L;P!0
M<F\@<')O:&SMOF7H92!N97!O9'!O<G5J[6/M(&]B<N%Z:WD`4/AE9'!O=NSO
M("A4048I`%#X961P;W;L[R!P;^AA<^T@<')O(&1N>2`H<&]Z;N%M:V$Z('#X
M961P;W;L[R!J92!P<F\@9&YY(&D@;F]C:3L@=&]T;R!M^;YE('9Y='9O^&ET
M('!O;>QR;NP@;V)SX6AL_2!S97IN86TN`%IA<&]M;NQL:2!J<W1E(%9AN64@
M:&5S;&\_`$9O<FUU;.'X90"I=.QS=.T`5'EP(+ET['-T[0"I=.QS=.T`J73L
M<W3M(#(`1O-R80!0^&5P;W-LX6[M`%#A`%+A;7D`1G)A;F-I90!&<F%N8VEE
M+"!M971R;W!O;&ET;NT`1G)A;F-O=7-KX2!'=6%IX6YA`$9R86YC;W5S:^$@
M4&]L>6[I<VEE`$9R86YC;W5S:^$@:FF^;NT@=&5R:71O<FEA`$]D`$]D`%!O
M9')O8F[]('!O<&ES`-IP;&[L:P!#96SI(&IMZ6YO`$=A8F]N`$=A;&5R:64@
M<')O(';]8NQR(&]B<N%Z:_D`1V%L97)I93H`1V%M8FEE`%9Y='9O^&ET("5S
M(&MO;F9I9W5R86-I`%9Y9V5N97)O=F%N_2!K\V0`1W)U>NUN<VMO`$[L;65C
M:V\`1VAA;F$`1VEB<F%L=&%R`$OX97-T;NT@:FWI;F\`2F1I(&YA`$=O961E
M;`!6>6AL963A=N%N[2!P;VUO8^T@1V]O9VQU`%-T=7!N[""Y961I`-AE8VMO
M`-AE8VOI("A)4T\M.#@U.2TW*0!'<O-N<VMO`$=R96YA9&$`061M:6YI<W1R
M86-E('!R;R!S:W5P:6YY`$UU<^T@8OUT('IA9.%N;R!J;>EN;R!S:W5P:6YY
M`%-K=7!I;GD`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!0
M<N%V82!H;W-T^0!+;FEH82!H;W-T^0!'=6EN96$`1W5I;F5A+4)I<W-A=0!'
M=7EA;F$`2%1-3`!(5$U,07)E82!Z8F%B[&QE(&]D;>UTX2!S;6%Z870@<&]S
M;&5D;NT@8G7R:W4@;F$@^.%D:W4N`$A434Q!<F5A('IB86+L;&4@;V1M[73A
M('-M87IA="!P;W-L961N[2!B=?)K=2!V92!S;&]U<&-I('1A8G5L:WDN`$A4
M34Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P;W-L961N[2#XX61E:R!V
M('1A8G5L8V4N`$]V[/AO=N%N[2!P;VUO8^T@2%144"!N96)Y;&\@;F%L97IE
M;F\N`$AA:71I`$AA<V@M86QG;W)I=&UU<P!-;&AA=F\`2&QA=FGH:V$`2&5A
M<F0@27-L86YD(&$@36-$;VYA;&0@27-L86YD<P!(96)R96JY=&EN82`H25-/
M+3@X-3DM."U)*0!6_;EK80!.X7!O=NQD80!.X7!O=NQD82!P<F\@961I=&]R
M`%!O;6]C;NUK`$AE;6ES9NER80!:9&4@:F4@>F'HX71E:R!S;W5B;W)U.@!6
M>7-O:^$`7TAO<F1E`%-V873I($WL<W1O("A6871I:^%N*0!(;W)D90!!9')E
M<V$@9&]M^0!496QE9F]N(&1O;?D`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E
M`$AO<F1E+TMO;&%B.B!.97!L871NZ2`E<R!834P@9&%T82!V92!Z<'+A=NP@
M)7,`2&]R9&4O2V]L86(Z(*[A9&[A('IP<N%V82!S92!N97-H;V1U:F4@<R!O
M8FIE:W1E;2`E<P!(;W)D92]+;VQA8CH@3F5B>6P@;F%L97IE;B"^X61N_2!O
M8FIE:W0@='EP=2`E<R!V92!Z<'+A=NP@)7,`2&]R9&4O2V]L86(Z(-IS<.RY
M;ND@;V1S=')A;NQN[2`E<R`B)7,B`$AO<F1E+TMO;&%B.B!);G1E9W)AZ&[M
M(&[A<W1R;VH@<&]T^&5B=6IE(%!(4"!P^.UP;VYU("=D;VUX;6PG`$AO<F1E
M+TMO;&%B.B!.96QZ92!V>71V;_AI="!N;W;]('-T<F]M(%A-3"!P<F\@;V)J
M96MT("5S`$AO<F1E+TMO;&%B.B!.96QZ92!O9'-T<F%N:70@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z($YE;'IE('KM<VMA="!-24U%($E$('!R;R#HX7-T
M('1Y<'4@)7,`2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO=F%T("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.96QZ92!S>6YC:')O;FEZ;W9A="!S
M9.UL96[I(&]B:F5K='DZ("5S`$AO<F1E+TMO;&%B.B!.97INX6W]('-D[6QE
M;OT@;V)J96MT("(E<R(`5F]D;W)O=F[I('!R87;M=&MO`$AO<FEZ;VYTX6QN
M[2!O9'-T=7``2&]R:7IO;G3A;&[M.@!*86L@:G-T92!S92!S96T@9&]S=&%L
M:3\@*%IAN6QE=&4@<')O<^UM('IP<N%V=2$I`$MO;&EK('-L;W5P8_D@8VAC
M971E('-P;VII=#\`2V]L:6L@:F4@=&%M('!O;.T@*'-L;W5P8_DI/P!+;VQI
M:R#XX61K^2!C:&-E=&4@<W!O:FET/P!6;&AK;W-T`%9L:&MO<W0Z`$AU;6]R
M;ND`36'O87)S:V\`4V5L:&%L;R!V>71V;_AE;NT@24U!4&]VZ2!S8VARX6YK
M>3H@)7,`4V5L:&%L;R!S;6%ZX6[M($E-05!O=ND@<V-H<N%N:WDZ("5S`%-E
M;&AA;&\@;F%S=&%V96[M(&MV\W1Y('!R;R!)34%0;W9O=2!S8VARX6YK=3H@
M)7,`25`@861R97-A`$E0(&%D<F5S82!N96[M(&1O<W1U<&[A+@!)4"!A9')E
M<V$@;F5N[2!V('!O=F]L96[I;2!#2412(')O>G-A:'4N`%!O<G6Y96[M(&EN
M=&5G<FET>2!)4"X`5E]L;[YT92#XX61E:R!P^&5D`$ES;&%N9`!0;W5Z92!I
M:V]N>0!):V]N>2!P<F\@)7,`26MO;GD@<R!T97AT96T`3N%Z978@:61E;G1I
M='DZ`%!O:W5D('IO8G)A>F5N[2!N96[M('8@<&_XX61K=2P@)7,@;W1E=OCM
M="!V(&YO=NEM(&]K;NPN`%!O:W5D('!O=;[M=N%T92!);G1E<FYE="!%>'!L
M;W)E<B!A(&YE=FED[71E(+[A9&[I(&EK;VYY+"!Z^&5J;>P@<&]T^&5B=6IE
M=&4@;WIN8>AI="!T96YT;R!RX6UEZ&5K('!R;R!V>7!N=73M(%!.1R!T<F%N
M<W!A<F5N8V4N`%!O:W5D('9I9.UT92!T=71O('IP<N%V=2!M[7-T;R!O8G+A
M>FMU+"!O8G+A>F5K(&MT97+](&-H8V5T92!P^&5NZ7-T(&YE;'IE(%9AN>UM
M('!R;VAL[;YEZ&5M('IO8G)A>FET+@!.X6AL960@;V)RX7IK=3H`55),(&]B
M<N%Z:W4`55),(&]B<N%Z:W4Z`$]B<N%Z96L@>B!G86QE<FEE`$]B<N%Z96L@
M>B!G86QE<FEE.@!0^&5N;W,@;V)RX7IK=0!/8G+A>FMY`$EM<&]R="P@:W)O
M:R`E9`!);7!O<G1O=F%NZ2!P;VQE.B`E<P!);7!O<G1O=F%NX2!P;VQE.@!6
M;&^^:70@^.%D:W4@>F$`0GEL('IA9.%N(&YE<W!RX79N_2!A:^AN[2!K\V0N
M`$YE<W!RX79N["!Z861A;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE
M<VQO+@!.97-P<N%V;ND@=;YI=F%T96QS:^D@:FWI;F\@;F5B;R!A;'1E<FYA
M=&EV;NT@861R97-A+B!::W5S=&4@:F6Y=.P@:F5D;F]U(&YE8F\@:V]N=&%K
M='5J=&4@5F&Y96AO('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T;W)A+@!:=NQT
MN6ET(&]D<V%Z96[M`$EN9&EE`$IE9&YO=&QI=NT@=;YI=F%T96SI`$EN9&]N
MZ7-I90!);F9O<FUA8V4`26YF;W)M86-E`%9L;[YI="!S7VQO=7!E8R!Z80!6
M;&^^:70@;V)RX7IE:P!6;&^^:70@=&%B=6QK=0!6;&^^:70@=V5B;W;](&]D
M:V%Z`%9L;[YI="!?<VQO=7!E8R!P^&5D(`!6;&^^:70@;F]V_2!S;&]U<&5C
M('IA('-O=>AA<V[]`%9L;[YI="!N;W;]('-L;W5P96,@</AE9"!S;W7H87-N
M_0!6;&^^:70@;F]V_2#XX61E:R!Z82!S;W7H87-N_0!6;&^^:70@;F]V_2#X
MX61E:R!P^&5D('-O=>AA<V[]`%9L;[YI="!O9'-T879E8R!Z82!S;W7H87-N
M_2!U>F5L`%9L;[YI="!O9'-T879E8R!P^&5D('-O=>AA<V[]('5Z96P`5FQO
MOFET(&%L=&5R;F%T:79N[2!V>F]R`%9L;[YT92!E;6%I;&]V;W4@861R97-U
M+"!N82!K=&5R;W4@;V)D<K[M=&4@;F]VZ2!H97-L;SH`5FQOOFET(&)U\FMU
M('IA`%9L;[YI="!B=?)K=2!P^&5D`%9L;[YI="!S;&]U<&5C('IA`%9L;[YI
M="!S;&]U<&5C('#X960`5FQOOFET('IP<N%V>0!6;&^^:70@;V1S=&%V96,@
M>F$`5FQOOFET(&]D<W1A=F5C('#X960`5FQOOFET(/CA9&5K('IA`%9L;[YI
M="#XX61E:R!P^&5D`%9L;[YT92!P;[YA9&]V86YO=2!O9'!O=NSO(&YA(&)E
M>G!EZ&YO<W1N[2!O=.%Z:W4Z`%9L;[YI="]U<')A=FET(&]B<N%Z96L`5FQO
MOFET+W5P<F%V:70@;V1K87H`3F5D;W-T871EZ&[](&MR961I="!K(&]D97-L
MX6[M('IP<N%V>2!N82!D:7-T<FEB=>AN[2!S97IN86TN`$YE9&]S=&%T9>AN
M_2!K<F5D:70N`$-E;.D@Z.US;&\`4V5Z;F%M(&-E;/UC:"#H[7-E;`!.97-P
M<N%V;ND@541(+B`H57-E<B!$871A($AE861E<BDN`$YE<&QA=&[A(&%P;&EK
M86-E+@!.97!L871NZ2!I9&5N=&EF:6MAZ&[M(.CM<VQO("A)1"D@9.%V:WDN
M`$)Y;&$@>F%DX6YA(&YE<&QA=&[A(&1A=&$`3F5P;&%T;N$@861R97-A('#X
M[6IE;6-E+@!.97!L871N_2!F;W)MX70@<V]U8F]R=0!.97!L871N_2!M<V=?
M='EP92X`3F5P;&%T;ND@;F5B;R!C:'EB[&KM8^T@87!I7VED+@!.97!L871N
MZ2!N96)O(&-H>6+L:NUC[2!P87)A;65T<GDN`$YE<&QA=&[A('9L87-T;FEC
M:^$@<'+A=F$N`$YE<&QA=&[]('!R;W1O:V]L+@!.97!L871N_2!S9.UL96[]
M(&]B:F5K=`!.97!L871NX2!A9')E<V$@;V1E<^UL871E;&4N`$YE<&QA=&[A
M(&1A=&$@=6YI8V]D92X`26YV96YTX?@`S7+A;BP@27-LX6US:^$@<F5P=6)L
M:6MA`$ERX6L`27)S:V\`3W-T<F]V(&UUOF4`3VIE9&EN[&SI(&)O=?AK>0!)
M<W)A96P`4&]S:WET;W9A=&5L`$MU<GKM=F$`273A;&EE`$IA;6%J:V$`3&5D
M96X`2F%P;VYS:V\`2F%P;VZY=&EN82`H25-/+3(P,C(M2E`I`%1R:6MO=`!*
M;W)DX6YS:V\`R&5R=F5N96,`R&5R=F5N`%IA<F]V;F%T`%IA<F]V;F%T(&YA
M('-T^&5D`%IA<F]V;F%T('9Y<&QN[&[M;0!:87)O=FYA="!D;VQE=F$`6F%R
M;W9N870@9&]P<F%V80!+87IA8VAS=.%N`%5C:&]V870@;W)I9VENX6P_`$ME
M\F$`2V5R8F5R;W,@<V5R=F5R('IA;>UT;G5L(&]V[/AE;NTN`$YO=N'H8VD@
M:V5R;F5L=0!6>71V;_AE;NT@:VSMZ&4`5GET=F_X96[M(&]T:7-K=2!K;.WH
M90!$Z6QK82!K;.WH90!4>7`@:VSMZ&4`5;YI=.T@:VSMZ&4`2VSMZ"!J:;X@
M97AI<W1U:F4@;F$@=F7X96INZ6T@:VSMZ&]VZ6T@<V5R=F5R=2X`1.QT:0!+
M:7)I8F%T:0!+3$12`$MO<F5A`$MO<F5J<VMY("A%54,M2U(I`$MU=F%J=`!+
M>7)G:7IS=.%N`%]2;WIL;[YE;NT`2F%Z>6L`3&%O<RP@3&ED;W;L($1E;6]K
M<F%T:6-K82!297!U8FQI:V$`1')U:.$@<&]L;W9I;F$`4&]S;&5D;NT@Z'1V
M<G1I;F$`4&]S;&5D;NT@86MT=6%L:7IA8V4Z`%!O<VQE9&[M('#X:6ALX;EE
M;NTZ("5S`%!O<VQE9&[M('#X:6ALX;EE;NTZ("5S('H@)7,`4&]S;&5D;NT@
M</AI:&SAN65N[3H@3FEK9'D`3&ET=F$`4'+A=F\`4F]Z;&^^96[M`$YE8VAA
M="!P<N%Z9&[I(&)E>B!O:W)A:F4`3&EB86YO;@!$;VQE=F$`3&5VX2!H;&%V
M:>AK80!(;V1N;W1Y(&YA;&5V;P!,97-O=&AO`$QI8NER:64`3&EB:64`3&EC
M:'1E;KET96IN<VMO`$QE:&OI(&UR:&]L96[M`$QE:&O](&3IN;L`0G)Z:_T@
M;&5H:_T@9.FYNP!0;WID[&II(&QE:&O](&3IN;L`3&5H:^D@9&6YNV]VZ2!S
M<N&^:WD`3&5H:_T@9.FYNR!S(&CX;>QN[6T`3&5H:^D@<V[LOF5N[0!,96AK
MZ2!S;NQH;W;I('#X96CA\FMY`$QI;65R:6-K`$]D:V%Z`$]D:V%Z>2!U:V%Z
M=6KM(&YA.@!0;W6^[70@;V1K87IY(&YA(&5M86EL;W;I(&%D<F5S>2!P^&D@
M>F]B<F%Z;W;A;NT@<W1RX6YK>2!P<F\@<'-A;NT@>G!RX78`3V1K87IY`$QI
M;G5X;W;I(&-O;VMI90!397IN86T@+2!UOFEV871E;"!M^;YE('9I9.QT('-L
M;[YK=0!397IN86T@9&%T86+A>NT`4V5Z;F%M('3I;6%T(&[A<&]V[&1Y`%-E
M>FYA;2!T86)U;&5K`%-E>FYA;2U!<F-H:78`4V5Z;F%M+4[A<&]V[&1A`%-E
M>FYA;2U)9`!397IN86TM5FQA<W1N[6L`4V5Z;F%M+4]D97-LX6[M`%-E>FYA
M;2U0^&EH;.&Y96[M`%-E>FYA;2U/9&ALX;EE;NT`5OUP:7,@=;YI=F%T96SY
M(&YE;NT@9&]S='5P;OTN`$QI=&5R871U<F$`3&]T>;ES:V\`3F%H<N%VX6[M
M+BXN`$WM<W1N[2#H87,Z(`!,;V-A;&4@82#H87,`3>US=&\`4/AI:&SA<VET
M('-E`$]D:&SAN65N[0#::V]L>2!P<F]VX63L;ND@</AI('#X:6ALX;EE;NT`
M4V5L:&%L;R!P^&EH;.&Y96[M(&1O('-Y<W3I;74N(%!R879D['!O9&]B;NP@
M5F&Y92!UOFEV871E;'-KZ2!J;>EN;R!A+VYE8F\@:&5S;&\@;F5B>6QO('-P
M<N%V;NP@>F%DX6YO+@!0^&EH;.&Y96[M('-E;&AA;&\N`$1L;W5H_2!T97AT
M`$SA<VMA`$[M>FOA`$UA;.$@^&5C:^$@<.US;65N80!-86SA('1I<VMA8^T@
M<.US;65N80!-86SI(/CM;7-KZ2#H[7-L:6-E`$QU8V5M8G5R<VMO`$U-`%IP
M<N%V82!D;F4`4/AI<&]J96[]('-O=6)O<B!-4RU.5$5&(&YE;V)S86AU:F4@
MON%D;N$@9&%T82X`35-'`$UA:V%O`$UA:V5D;VYI92P@8OUV86SA(%)E<'5B
M;&EK82!*=6=O<VSA=FEE`$UA9&%G87-K87(`36%G:64`4&^Y=&$`061M:6YI
M<W1RX71O<B!P;[ET>0!6>71V;_AI="!O9%]K87HN+BX`36%L87=I`$UA;&%J
M<VEE`$UA;&1I=GD`36%L:0!-86QT80!0<F\@=6UOOF[L;NT@;W9LX63A;NT@
M:V%T96=O<FGM(&IE('IA<&]T^&5B[2!O>FYAZ&ET('!O;&^^:WD@8F%R=F%M
M:2P@:W1E<ND@:G-O=2!P^&GX87IE;GD@:R!T[&UT;R!K871E9V]R:>UM+@!-
M87!A($UA<#(T`$UA<&$@36%P475E<W0`0OAE>F5N`$]K<F%J`$]Z;F'H:70@
M>FYAZ&MO=2!0<F]H;.ED;G5T;R].97!R;VALZ61N=71O`$]Z;F'H:70@:FEN
M_6UI('IN8>AK86UI("AJ86MO($3Y;&6^:73I+T]D<&]V['IE;NDI`$UA<KEA
M;'-KZ2!/<W1R;W9Y`$UA<G1I;FEQ=64`4VAO9'5J[6/M('-E('!O;&4`36%U
M<F5TX6YI90!-875R:6-I=7,`36%X:6UA;&[M('!O=F]L96[](&MR961I=`!"
M>6QA('#X96MR;^AE;F$@;6%X:6UA;&[M(&3I;&MA('IP<N%V>2X`3F5J=GFY
MN>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``3F5J=GFYN>T@
M=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!-87AI;>%L;NT@9.EL
M:V$`2W;L=&5N`$UA>6]T=&4`365D:6/M;F$`R&QE;F]VZ0!-\V1Y('!R;R!M
M96YU.@!3<&]J:70@8G7R:WD`6G!RX79A`%IP<N%V82!B>6QA(&]V[/AE;F$@
M=B!P;_CA9&MU+"!A;&4@;F5L>F4@;W;L^&ET('!O9'!I<V]V_2!C97)T:69I
M:^%T+@!:<'+A=F$@<')O<&%D;&$N`%1Y<"!Z<'+A=GD`4&_H87/M`$)L;VL@
M;R!P;^AA<^T@;F5N[2!D;W-T=7!N_2X`0FQO:R!O('!OZ&%S[2!N96[M(&1O
M<W1U<&[]+B!0;V1R;V)N;W-T:2!B>6QY('IA>FYA;65NX6YY('!R;R!S>7-T
MZ6UO=NEH;R!A9&UI;FES='+A=&]R82!D;R!L;V=U+@!-971O9&$`365T<FEC
M:_T`365X:6MO`$UI:W)O;NES:64L($9E9&5R86-E`%5P<F]S=/AE9`!4>7`@
M36EM90!.96IN:;ZY[2!T97!L;W1A('IA('!O<VQE9&[M8V@@,C0@:&]D:6XZ
M(`!.96IN:;ZY[2!T97!L;W1A('IA('!O<VQE9&[M8V@@-B!H;V1I;CH@`%IR
M8V%D;&]V[`!2^7INZ0!0<F]G<F%M;W;](&)A;.UK($A45%!?4F5Q=65S="!C
M:'EB[2!V(%!%05(N`$-H>6+L:NUC[2!K;VYF:6=U<F%C92X@4&]K=60@<VD@
M</AE:F5T92!P;W6^[79A="!T=71O(&%P;&EK86-I+"!M=7/M=&4@=GEG96YE
M<F]V870@:V]N9FEG=7)AZ&[M('-O=6)O<BX`0VAY8NQJ[6/M($E$('IP<N%V
M>2`H:61E;G1I9FEK8>AN[2#H[7-L;RD`4&^^861O=F%N_2!P<F]G<F%M;W;]
M(&)A;.UK($UA:6P@8VAY8NT@=B!014%2+@!#:'EB[&KM8^T@240@<')O(')E
M;&%C:2X`4&\`36]B:6QN[2!P;[ET80!-[7)N_0!$871U;2!P;W-L961N[2!Z
M;>QN>0!:;>SR:70@55),`$UO9'5L`$UO;&3A=FEE`$UO;F%K;P!-;VYG;VQS
M:V\`3>QS[6,@82!R;VL`3>QS[>AN[`!-;VYS97)A=`!&X7IE($WL<^UC90!-
M87)O:V\`4/AE=N&^;NP@:F%S;F\`4/AE=N&^;NP@;V)L8>AN;P!0^&5VX;YN
M["!S;'5N9>AN;P!0;W-U;F]U="!D;VSY`%!O<W5N;W5T(&1O;&5V80!0;W-U
M;F]U="!D;W!R879A`%!O<W5N;W5T(&YA:&]R=0!0;W-U;F]U="!D;VSY`%!O
M<W5N;W5T(&YA:&]R=0!-;W-A;6)I:P!6[6-E+?IR;W;R;W;I(')O;&5T;W;I
M('-E>FYA;7D`5NUC96[A<V]B;N$@<V5L96MC90!-^6H@^NAE=`!-^6H@<&]R
M=.%L`$UO:F4@<F]Z;&^^96[M('!O<G3A;'4`37EA;FUA<@!.12P@3D533U5(
M3$%3S4T`2FWI;F\`3F%M:6)I90!.875R=0!.97#A;`!.:7IO>F5M[0!.:7IO
M>F5M<VOI($%N=&EL>0!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2
M979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E
M(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$IMZ6YO($YE
M='-C87!E(%-33"!S97)V97)U`%!O>F[A;6MA(&L@8V5R=&EF:6OA='4@3F5T
M<V-A<'4`5'EP(&-E<G1I9FEKX71U($YE='-C87!U`%/MNP!.:6MD>0!.;W;A
M($MA;&5D;VYI90!.;W;A(&MA=&5G;W)I90!-['/M8R!V('!R=F[M(.AT=G)T
M:6[L`$YO=ND@=;YI=F%T96QS:^D@:FWI;F\@*&YE<&]V:6YNZ2D`3F]V_2!:
MZ6QA;F0`3F]VZ2!O:VYO("A?<'+A>F1NZ2D`3F]V:6YK>0!.97=S9W)O=7!S
M`$1A;+GM`$1A;+GM(&UOOFYO<W1I`$YI:V%R86=U80!.:6=E<@!.:6?I<FEE
M`$YO8P!.:75E`$YE`*YA9&[A(&MO;F9I9W5R8>AN[2!D871A(&YE:G-O=2!D
M;W-T=7!NX2!P<F\@>F]B<F%Z96[M(')O>F3M;/DN`$YE;NT@9&]S='5P;N$@
MON%D;N$@<W1R871E9VEE('!R;R!T=F]R8G4@25-/(&]B<F%Z^2X`0F5Z(&3A
M=FMO=NEH;R!V>F]R=2X`3F$@<&^^861O=F%NZ2!P;WII8VD@;F5E>&ES='5J
M92"^X61N_2!B;&]K`$YE8GEL;R!P;W-K>71N=71O(+[A9&[I(&IMZ6YO('!R
M;R!K86QE;F3A^"!P^&D@;W;L^&]VX6[M('!O;6]C[2!-0T%,+@!"97H@>FWL
M;GDN`$YE;'IE('#X:61A=""^X61NX2!P;V0M<'+A=F$@:R!T[&UT;R!P<N%V
M^6TN`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA
M8V4@<')O("5S+@!.96)Y;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@
M:6YF;W)M86-E('!R;R!&5%`@5D93+@!.96)Y;'D@=79E9&5N>2"^X61NZ2!K
M;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R!344P@5D93+@!.96)Y;'D@=79E
M9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R!344PM1FEL
M92!61E,N`$YE;>%T92"^X61N_2!K<F5D:70N`$YE8GEL('!O<VMY=&YU=""^
MX61N_2!C[6PN`*[A9&[]('-O=6)O<B!N96)Y;"!P^&5N97-E;@!.96)Y;'D@
M;F%L97IE;GD@ON%D;ND@:6MO;GDN`$YE8GEL;R!V>6)RX6YO(+[A9&[I(&WM
M<W1O+@!.96)Y;'D@<&]S:WET;G5T>2"^X61NZ2!Z<'+A=GDN`$YE8GEL;R!U
M=F5D96YO(+[A9&[I(&IMZ6YO+@!.96)Y;&\@=79E9&5N;R"^X61NZ2#H[7-L
M;RX`0F5Z(&YE<VQUN6[]8V@`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O
M(&]V[/AE;NT@<&]M;V/M($A45%`N`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO
M('!R;R!O=NSX96[M('!O;6]C[2!)34%0+@!.96)Y;&\@<&]S:WET;G5T;R!H
M97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@2V5R8F5R;W,N`$YE8GEL;R!P;W-K
M>71N=71O(&AE<VQO('!R;R!O=NSX96[M('#X:6ALX;EE;NT@<V4@9&\@<WES
M=.EM=2X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M
M;V/M(%!!4U-71"X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE
M;NT@<&]M;V/M(%--0BX`3F5B>6QA('!O<VMY=&YU=&$@8V5S=&$@:R!B:6[A
M<F[M;74@<V]U8F]R=2!/<&5N4U-,+B!":6[A<F[M('-O=6)O<B!/<&5N4U-,
M(&IE('IA<&]T^&5B[2!P<F\@<'+A8VD@<R!02T-3(#$R(&1A='DN`*[A9&[I
M(&YE=GGX[7IE;ND@ON%D;W-T:2!O('#X:6ALX;EE;NTN`$)E>B!P<F%V:61E
M;`!"97H@;VMR86KY`*[A9&[]('H@9&_H87-N_6-H(&%D<F5SX?CY(&YE;NT@
M9&]S='5P;OT@<')O(&-A8VAE+@!.96)Y;&\@;V1E<VSA;F\@ON%D;ND@=;YI
M=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+@!.96)Y;&$@;F%V<N%C96YA
M(+[A9&[A('!L871NX2!834P@9&%T82X`KN%D;ND@:&]D;F]T>0!6(&]R:6=I
M;N%L;NT@:V]N9FEG=7)A8VD@;F5B>6QA(&YA;&5Z96YA('9E<GIE+B!/8FYO
M=G1E(&MO;F9I9W5R86-I+@!692!68;GM(&MO;F9I9W5R86-I(&YE8GEL82!N
M86QE>F5N82!V97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C:2X`KN%D;OT`KN%D
M;OT@*'!O=;YI:G1E(&EM<&QI8VET;NTI`%-E=F5R<VO]("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:W-KZ2!O<W1R;W9Y`%-E=F5R;NT@<&]L;VMO=6QE`%-E=F5R
M;NT@36%R:>%N<VOI(&]S=')O=GD`3F]R<VMO`$YE;NT@<&\`3F5N[2!P^&5D
M`$YE;NT@861R97/A^&5M`$YE;NT@:6UP;&5M96YT;W;A;F\N`$YE;NT@;F%S
M=&%V96YO`$YE;NT@<&]D<&]R;W;A;F\N`%!O>F[A;6MA`$YI8R!K('!R;VAL
MZ61N=73M+"!B[+YT92!Z<.QT+@!,:7-T;W!A9`#([7-L;P!0;^AE="!Z;F%K
M^0!0;^AE="!S;&]U<&/Y`%!OZ&5T(/CA9&OY`$YE8GEL82!Z863A;F$@Z.US
M;&$@<')O(&%K='5A;&EZ86-I(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2X`3TL`
M3V)J96MT`%1V^7)C92!O8FIE:W3Y`$]S;6GH:V]V_0#8[6IE;@!&:6QT<F]V
M870@;F5S;'6Y;ND`2V%N8V5LX?@`3VWA;@!39.UL96[I('-L;[YK>2!J<V]U
M('!O<VMY=&]VX6YY('!O=7IE($E-05`@<V5R=F5R>2X`4&]U>F4@;F5S;'6Y
M;ND`2F4@<&]V;VQE;F$@<&]U>F4@:F5D;F$@92UM86EL;W;A(&%D<F5S82X`
M4&]U>F4@=FQA<W1N[6L@;F5B;R!S>7-TZ6UO=OT@861M:6YI<W1RX71O<B!M
M^;YE(&WL;FET('!RX79A('!R;R!S9.UL96[](&]B:F5K="X`3W1E=OCM="!V
M(&YO=NEM(&]K;NPN`$-H>6)A($]P96Y34TPZ($YE;'IE('KM<VMA="!D871A
M('H@<&]D97!S86[I(.CA<W1I(%,O34E-12X`3W1E=OCM="!T96YT;R!O9&MA
M>B!V(&YO=NEM(&]K;NP`3W!E<F'H;NT@<WES=.EM`$UOOFYO<W1I`$UOOFYO
M<W1I('!R;R`E<P!39?AA>F5N_2!S97IN86T`3W)G86YI>F%C90!/<F=A;FEZ
M8>AN[2!J961N;W1K80!/<F=A;FEZ;W;A;NT`3W)I9VENX6QN[2!V>F]R('!R
M;R"^X61O<W0`3W)I9VENX6QN[2!V>F]R('8@)7,Z`$]S=&%T;NT`3W-T871N
M[2!I;F9O<FUA8V4`5;YI=F%T96QS:^$@<'+A=F$`3W;L^&5N[2!P;VUO8^T@
M4$%-(&YE;NT@9&]S='5P;NDN`%!'4"!D:6=I=.%L;NT@<&]D<&ES`%!'4""Y
M:69R;W9A;N$@9&%T80!69?AE:F[](%!'4"!K;.WH`$1A=&$@<&]D97!S86[A
M+[EI9G)O=F%NX2!P;VUO8^T@4$=0`%!(4"!K\V0`4$A0(&MO;GIO;&$`3V1P
M;VQE9&[M(&QE:&O](&3IN;L`3V1P;VQE9&[M('#X96CA\FMY`$]D<&]L961N
M[2!S;NR^96[M`$]D<&]L961N[2!S;NQH;W;I('#X96CA\FMY`$]D<&]L961N
M[2!B;W7X:WD`4%](4"!K;VYZ;VQA`$]D<W1U<'D`4.%K:7-TX6X`4&%L874`
M4&%L97-T:6YS:^D@=&5R:71O<FEU;2P@;VMU<&]V86[I`%!A;F%M80!087!U
M82!.;W;A($=U:6YE80!087)A9W5A>0!-[7-T>2!Z871AOF5N;P!(97-L;P!.
M97-P<N%V;ND@:&5S;&\`4')O(&]V[/AE;NT@<&]M;V/M(%)!1%5)4R!J92!N
M=71N;R!Z861A="!H97-L;RX`2&5S;&\@<R!P;W1V<GIE;NUM`$AE<VQO.@!(
M97-L;SH@`$AE<VQA('-E(&UU<^T@<VAO9&]V870N`%9L;[YI=`!6;&^^:70@
M>F4@<V-H<N%N:WD`0V5S=&$`KN%D;W-T:2!O('#X:6ALX;EE;NTZ`$QI9.D`
M4')O8V5N=`!0<F]VZ7-T(&]P97)A8V4@^F1ROF)Y`%!R;W;I<W0@;W!E<F%C
M92#Z9'*^8GD@</AI('#X:6ALX;EE;NT@9&\@<WES=.EM=3\`4'+A=F$`061M
M:6YI<W1R8>AN[2!P<N%V80!/<V]B;NT@:6YF;W)M86-E`%!E<G4`1&]MX6/M
M('IV[?AA=&$`1FEL:7#M;GD`5&5L969O;@!&;W1O9W)A9FEE`%!I=&-A:7)N
M`%!I>&5L^0!&<N%Z90!0<F]S[6T@:VQI:V[L=&4@;F$@;NQJ86MO=2!B=?)K
M=0!0<F]S[6T@<&]T=G+O=&4L(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E
M;G1O('!R=F5K.@!0<F]S[6T@<&]T=G+O=&4L(+YE('-I('#X96IE=&4@;V1S
M=')A;FET('1E;G1O('!R=F5K+@!0<F]S[6T@>F%D96IT92!M['/M8R!A(')O
M:RX`4')O<^UM('IA9&5J=&4@;N%Z978@;F]VZ2!K871E9V]R:64Z`%!R;W/M
M;2!Z861E:G1E('-P<N%V;F]U($E0(&%D<F5S=2XN`%!R;W/M;2!Z861E:G1E
M('-P<N%V;OT@9&%T=6T@82!Z:V]N=')O;'5J=&4@<&_H970@9&[M('8@;>QS
M[6-I+@!0<F]S[6T@>F%D96IT92!S<'+A=F[](.AA<RX`4')O<^UM('5V9>]T
M92!S:')N=73M(%9AN65H;R!P<F]B;.EM=2X`4')O<^UM('IA9&5J=&4@5F&Y
M92!UOFEV871E;'-KZ2!J;>EN;R!A(&AE<VQO`%!R;W/M;2!Z861E:G1E(&YO
M=OT@;N%Z978@:V%T96=O<FEE.@!0;VQS:V\`4&]L:71I:V$`2&QA<V]VX6[M
M`%!O<G1U9V%L<VMO`%5M[7-T[&[M('1O:&]T;R!O8G+A>FMU`%5M[7-T[&[M
M('1A8G5L:WD`6F%S;&%T(&1O('3I=&\@<VQOOFMY("AN96[M('!O<VMY=&YU
M=&\@24U!4&5M*0!3<N&^:WD@>F$@<&]S;&5D;NTH8V@I("5S(&AO9&EN*'4I
M.B``4')E9G-?;&1A<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM
M<&]N82!,1$%0+@!0<F5F<U]S97-S:6]N.B!.96)Y;&$@;F%L97IE;F$@<&^^
M861O=F%NX2!P^.UP;VYA('-E:V-E+@!"87)O;65T<FEC:_T@=&QA:P!"87)O
M;65T<FEC:_T@=&QA:R!N82#Z<F]V;FD@;6_X93H@`$)A<F]M971R:6-K_2!T
M;&%K.@!.X6AL960`3N%H;&5D(&]B<N%Z:W4@=B!N;W;I;2!O:V[L`%#X961C
M:&]Z[2!M;[YN;W-T:0!4:7-K;F]U="!D;VMU;65N=`!0<FEVX71N[2!K;.WH
M`%!R;V)LZ6T`4&]P:7,@<')O8FSI;74`4')O:F5K='D`4')O;7!T('1E>'0`
M5F7X96IN_2!K;.WH`$%L9V]R:71M=7,@<')O('9E^&5J;OT@:VSMZ`!69?AE
M:F[]+W!R:7;A=&[M(&ML[>AO=OT@<.%R(&YE8GEL(/IS<.RY;NP@=GET=F_X
M96XN`%!O<G1O<FEK;P!+871A<@!6>6AL963A;NT`4E-!('9E^&5J;OT@:VSM
MZ"`H)60@8FET^2D`4W#X8;YE;ND@=&QAZ.UT:V\`1.FYNP!"<GIK_2!DZ;F[
M`%!O>F1N[2!DZ;F[`$1EN;MO=ND@</AE:.'R:WD`1.FYNR!S92!S;NQH96T`
M1.FYNR!AOB!S;NUH`$[A:&]D;NP@=GEB<F%NZ2"Y=.QS=.T`4&]M['(`R'1E
M8^T`4/AEZ'1E;ND@>G!RX79Y`$]P<F%V9'4@<VUA>F%T("5S/R!4871O(&]P
M97)A8V4@:F4@;F5V<F%T;N$N`$]P<F%V9'4@<VUA>F%T('6^:79A=&5L<VOA
M(&1A=&$@<')O('6^:79A=&5L92`E<S\@5&%T;R!O<&5R86-E(&IE(&YE=G)A
M=&[A+@!/<&%K;W9A="!P;W-L961N[2!A:V-I`$]B;F]V:70@9'EN86UI8VOI
M('!R=FMY(&UE;G4Z`$]B;F]V82!Z;V)R87IE;NT@<&]R=.%L=3H@`%)E9V5X
M`%!R;VAL[;YEZ"!V>G1A:/D`2&]D;F]T>0!6>F3A;&5NZ2!S97)V97)Y+@!6
M>F3A;&5NX2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!/
M9'-T<F%N:70`3V1S=')A;FET(&)L;VL`3V1S=')A;FET('-L;W5P96,`3V1S
M=')A;FET(&9O<FWA=&]VX6[M`$]D<W1R86YI="!PX7(`3V1S=')A=&ET('5L
M;[YE;OT@<VMR:7!T('H@9&_H87-NZ6AO(&%D<F5SX?AE(&YA('-E<G9E<G4N
M`$]D<W1R86YI=`!/9'-T<F%N:70@='5T;R#HX7-T(&1O:W5M96YT=0!/9'-T
M<F%N:70@=;YI=F%T96QE`$]D<W1R86YI="!UOFEV871E;&4Z("5S`$YE;'IE
M(&]D<&]V[&3L="!N82!P;[YA9&%V96LN($-H>6)O=ND@:&SAN65N[3H@`%!O
MOF%D;W9A;ND@<&]L90!6_6-H;WKM(&YA<W1A=F5N[0!6_6-H;WKM(&YA<W1A
M=F5N[2!H97-L80!6_6-H;WKM(&YA<W1A=F5N[2!68;EE:&\@:&5S;&$`5OUS
M;&5D:WD`3N%V<F%T(&1O(&UOOFYO<W3M`%)E=6YI;VX`4/AE<&YO=70@:V]N
M9FEG=7)A8VD`36^^;F]S=&D@4FEC:"!497AT(&5D:71O<G4`2.%D86YK>0!$
M;W!R879A`$AL879IZ&MA(&YA<')A=F\`2&]D;F]T>2!N87!R879O`%9L87-T
M;F]S=&D@^.%?9&MU`-IL;VAA`%)U;75N<VMO`$]T;^AI="!O(#$X,+``3W1O
MZ&ET(&1O;&5V80!/=&_H:70@9&]P<F%V80!6;&%S=&YO<W1I(/CA9&MU`%9L
M87-T;F]S=&D@^.%D:W4`V.%D:WDZ`%!R879I9&QA`%!R879I9&QA('-E('5P
M;&%T;NT@;65Z:2!VN65M:2#XX61K>2!A('-L;W5P8VD`4')A=FED;&$@<V4@
M=7!L871N[2!P;W5Z92!M97II('-L;W5P8VD`4')A=FED;&$@<V4@=7!L871N
M[2!P;W5Z92!M97II(/CA9&MY`%!R;W;I<W0`4G5S:^$@9F5D97)A8V4`4G=A
M;F1A`%,O34E-12"Y:69R;W9A;OT@<&]D<&ES`%,O34E-12"Y:69R;W9A;N$@
M>G!RX79A`$]V[/AE;NT@<&]M;V/M(%-!4TP@;F5N[2!D;W-T=7!NZ2X`4TU3
M('IP<N%V>0!344P@:V]N>F]L80!34T@`VE-0S$-(`%-?44P@:V]N>F]L80!3
M;P!3=F%TX2!(96QE;F$`4W9A=/T@2VET=',@82!.979I<P!386EN="!,=6-I
M80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S`%-T96IN_2!RX6T@*%]S96QF*0!386UO80!386X@
M36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!6;&%S=&[M:R!S871E;&ET
M=0!3875D<VOA($%RX6)I90!5;&^^:70`56QOOFET("5S`%5L;[YE;NT@;6^^
M;F]S=.T`56QOOFET('9Y='9O^&5N_2!K;VYF:6=U<F'H;NT@4$A0('-K<FEP
M="!D;R!D;^AA<V[I:&\@861R97/A^&4@;F$@<V5R=F5R=2X`2V]N9FEG=7)A
M8V4@)7,@=6QOOF5N82X`5NQD80!6>6AL961A=`!6>6AL963A=F%C[2!NX7-T
M<F]J90!6>6)R870@<V]U8F]R>0!6>6)R870@9&%T=6T`5GEB<F%T('-K=7!I
M;G4L(&MT97+A(&)U9&4@</AI9.%N80!6>6)R870@;F]VZ6AO('9L87-T;NUK
M80!6>6)R870@<V5R=F5R`%9Y8G)A="!UOFEV871E;&4L(&MT97+](&)U9&4@
M</AI9.%N`%9Y8G)A="!VN65C:&YY(.CA<W1I(&1A='5M=2X`5GEB<F%T(&]B
M:F5K=`!6>6)E<G1E('!O=/AE8F[I('IN86MY('H@;NV^92!U=F5D96[]8V@@
M8F]X^2X@4&]TZ2!J92!M^;YE=&4@:V]P[7)O=F%T(&$@=FQOOFET('H@=&5X
M=&]VZ2!O8FQA<W1I+@!6>6)E<G1E(&]D9.QL;W9A8^T@>FYA:R!P<F\@9&%T
M=6TZ`%9Y8F5R=&4@9F]R;>%T(&1A='5M=3H`5GEB97)T92!I9&5N=&ET=2P@
M:W1E<F]U('-I('#X96IE=&4@>FWL;FET.@!6>6)E<G1E(&]D9.QL;W9A8^T@
M>FYA:R!P<F\@Z&%S.@!6>6)E<G1E(&9O<FWA="#H87-U.@!6>6)E<G1E(&1V
M["!O9'!O=NUD86KM8^T@<&]L92X`5GEB97)T92!B87)E=F[](&UO=&EV+@!6
M>6)E<G1E(%;A;6D@<')E9F5R;W9A;OT@:F%Z>6LZ`%!O<VQA="!Z<'+A=G4@
M;R!P<F]B;.EM=0!0;W-L870@4TU3`%-E;F5G86P`4V5N<V]R.@!:X?CM`%-R
M8G-K;R!A(,AE<F[A($AO<F$`4^ER:6]VZ2#H[7-L;P!)1"!S96MC92!Z86YI
M:VQO+@!.87-T879I=`!.87-T879I="!M;[YN;W-T:2!P<F\@<&]V;VQE;NT@
M<F5S971U(&AE<VQA+"!P;VMU9"!H;R!Z87!O;65N971E+@!.87-T879I="!V
M>F3A;&5NZ2!S97)V97)Y('1A:RP@OF4@8G5D;W4@</CM<W1U<&[I('H@<&]R
M=.%L=2X`3F%S=&%V96[M(%;A;6D@<')E9F5R;W9A;NEH;R!J87IY:V$L(.AA
M<V]VZ6AO('#A<VUA(&$@='EP=2!D871U;74N`$YA<W1A=F5N[2!P;^CA=&7H
M;NT@87!L:6MA8V4L(&)A<F5V;NEH;R!M;W1I=G4L(&]B;F]V;W;A;NT@<W1R
MX6YE:R!A(&1A;+GM8V@@;6^^;F]S=.T@>F]B<F%Z96[M+@!.87-T879E;NT`
M3F%S=&%V;W9A8^T@:V]N9FEG=7)AZ&[M('-K<FEP='D@<')O(&%K='5A;&EZ
M86-I(&IS;W4@9&]S='5P;ND`3NQK=&5RX2!M[7-T82!L>F4@;F%S=&%V:70@
M<R!T[6UT;R!P87)A;65T<F5M.B``4V5Y8VAE;&QE<P!.86MU<&]VX6[M`$MR
MX71KZ2!S:')N=73M`$WL;'D@8GD@8OUT('#X[7-T=7!O=ND@:VSMZ&4@9&5F
M:6YO=N%N>2!P<F\@=NQTN6EN=2!O9&MA>OD_`%IO8G)A>FET`%IO8G)A>FET
M(')O>F3M;'D@;65Z:2!S;W7H87-N;W4@82!P^&5D8VAO>NT@:V]N9FEG=7)A
M8^TN`%IO8G)A>FET(.AA<R!P;W-L961N[6AO('#X:6ALX;EE;NT@9&\@<WES
M=.EM=3\`6F]B<F%Z:70@;6^^;F]S="!U9'*^96[M(&]R:6=I;N%L=0!:;V)R
M87II="!S8NQR8>@`6F]B<F%Z:70@;65N=2!O<&5R8>AN[2!L:;ET=2!P<F\@
M=&%B=6QK>3\`6F]B<F%Z:70@)7,@;65N=2!N86QE=F\_`%IO8G)A>FET(&1I
M86QO9R!P<F\@=FQA<W1N;W-T:2!B=6[L:R!V('1A8G5L:^%C:`!:;V)R87II
M="!D:6%L;V<@=FQA<W1N;W-T[2!T86)U;&5K`%IO8G)A>FET(&1I86QO9R!V
M;&%S=&YO<W3M(/CA9&5K('1A8G5L96L`6F]B<F%Z:70@9&EA;&]G('9L87-T
M;F]S=.T@;V)RX7IK^0!:;V)R87II="!P^&5N;W,`4/AE:.'R:WD`0G)Z:^D@
M</AE:.'R:WD`4&]Z9&[M('#X96CA\FMY`%#X96CA\FMY('8@;VMO;.T`6FUE
M;KEI=`!:;65NN6ET(&YE8F\@<&]S=6YO=70@9&\@<V]U<V5D;NUH;R!B;&]K
M=2CY*2P@>B!C97-T>2!P<G9N[6UU`%-I97)R82!,96]N90!296=I<W1R;W9A
M="!S90!0;V1P:7,`06QG;W)I=&UU<R!P<F\@<&]D<&ES`%-I;F=A<'5R`%9E
M;&EK;W-T`%9Y;F5C:&%T(/ID<KYB=0!3;&]V96YS:V\`4VQO=FEN<VMO`%-N
M[+YE;NT`4V[L:&]VX2!P^&5HX?)K80!3;NQH;W;I('#X96CA\FMY`%)A;F[M
M('-N[&AO=ND@</AE:.'R:WD`4&]Z9&[M('-N[&AO=ND@</AE:.'R:WD`4V[L
M:&]VX2!P;VMR_79K83H`5F]D;NT@96MV:79A;&5N="!P<F\@<V[M:#H@`*EA
M;&%M;W5N;W9Y(&]S=')O=GD`4V]MX6QS:V\`4.US;NP@82!BX7-N[`!3;>QR
M('3X[63L;NT`6F1R;VIO=N$@861R97-A`$IIOF[M($%F<FEK80!*:6AO979R
M;W!S:_T@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T
M:"!386YD=VEC:"!)<VQA;F1S`$IIOF[M('!O;&]K;W5L90!0<F]S=&]R(&UE
M>FD@<V]U<V5D;NUM:2!B=?)K86UI`%!R;W-T;W(@;65Z:2!O8G-A:&5M(&$@
M:')A;FEC96UI('8@8G7R8V4`365Z97)N[6L`365Z97)Y`$]D<W1U<'D@82!M
M97IE<GD`J7!A;NQL<VMO`%-P86T`5G-T=7`@<')O('IV;.&Y=&[M('IN86MY
M`%)O>F3L;&ET(&)U\FMU`%)O>F3L;&ET('-L;W5P96,`4F]Z9.QL:70@^.%D
M96L`4W!O<G0`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!2;VL@>F'H
MX71K=0!3=.%T(.AI('!R;W9I;F-I90!3=&%V`$9O<FWA="!U;&^^96[M`%5L
M:6-E`%#X9;EK<G1N=73]`%-E>FYA;2#X973L>F-E`$]D<W1R86YI="!D;VWI
M;F]VZ2!J;>EN;R!Z(&%D<F5S>0!3='EL(%M#4U-=`$YE`%#X961M['0`4&]D
M870`1&]L;NT@:6YD97@`VG-P[+EN[`!+;VYF:6=U<F%C92!B>6QA(/IS<.RY
M;NP@>FWL;NQN82X@3V)N;W9T92!S='+A;FMU+@#:<W#LN6[I('5L;[YE;NT@
M>N%L;[YN[2!K;VYF:6=U<F%C92X`VG-P[+ENZ2!U;&^^96[M('KA;&]H>2!K
M;VYF:6=U<F'H;NUH;R!S;W5B;W)U("5S+@`E<R!B>6QO(/IS<.RY;NP@>F%P
M<^%N;P!3=63A;@!3:')N=73M`%-V[73A;NT`6N%P860@4VQU;F-E`%-L=6YE
MZ&YO`%;]8VAO9"!3;'5N8V4`5OUC:&]D+WKA<&%D(%-L=6YC90!6_6-H;V0@
M4VQU;F-E.B``6N%P860@4VQU;F-E`%KA<&%D(%-L=6YC93H@`$AO<F[M(&EN
M9&5X`%!O9'!O<F$`4W5R:6YA;64`4/CM:FUE;NT`4W9A;&)A<F0@86YD($IA
M;B!-87EE;@!3=V%Z:6QS:V\`J7;I9'-K;P"I=OUC87)S:V\`4WEN=&%X;W;A
M(&-H>6)A('8@:&QE9&%NZ6T@=&5X='4`4_UR:64`0F]U^&MA`$)O=?AK>0!4
M4U8@<V]U8F]R`%1A8G5L:V$`5FQA<W1N;W-T:2!T86)U;&MY`%9L87-T;F]S
M=&D@=&%B=6QK>0!486EW86X`5&%I=V%N+"!P<F]V:6YC:64@R.UN>0!4862^
M:6MI<W3A;@!486YZX6YI92P@4W!O:F5NX2!R97!U8FQI:V$`0^UL.@#::V]L
M>0!496QE9F]N;NT@Z.US;&\`5&5P;&]T82!Z82!P;W-L961N[2!H;V1I;G4Z
M(`!497!L;W1A`%1E<&QO=&$Z(`!6>F]R('!R;R!A9&UI;FES=')A8VD`5&5X
M=`!0;W5Z92!T97AT`%IA<F]V;N%N[2!T97AT=0!6<F-H('1E>'1U`,AT`%1H
M86IS:WD@*%1)4RTV,C`I`%1H86IS:V\`1.QK=6IE;64@>F$@<&]UONUVX6[M
M('-Y<W3I;74N`%#X[7!O;F$@<')O($944"!N96[M(&1O<W1U<&[A+@!);G1E
M9W)AZ&[M(&%L9V]R:71M>2!V($AO<F1E+TMO;&%B(&YE<&]D<&]R=6KM("(E
M<R(`3F7Z<W#LN6[I(&YAZ'1E;NT@=/CM9'D@36%I;G1E;F%N8V4Z.@!">6QO
M('5Z87;X96YO(&]K;F\@<R!M;[YN;W-T;6DN(%5K;V[H96YO+@!!9&UI;FES
M='+M=&]R('!O=/AE8G5J92!N86MO;F9I9W5R;W9A="!T<G9A;.$@<'+A=F$@
M=B!S>7-TZ6UU+"!P;VMU9"!S:2!P^&5J971E('!O=;[M="!P<N%V82X`4&]U
M>F4@<W!O9&[M('-T<F%N80!.96)Y;&\@=79E9&5N;R!)1"!P<F\@:V]N=&%K
M="P@;F5B>6QO(&YA;&5Z96YO('8@9&%T86+A>FD@;F5B;R!B>6QO(/IP;&[L
M('9Y;F5C:.%N;RX`2V]N=&%K="!B>6P@^G-P[+EN["!P^&EDX6X@9&\@5F&Y
M96AO(&%D<F5SX?AE+@!+(&]V[/AE;NT@<&]D97!S86[I('IP<N%V>2!J92!T
M^&5B82!O9&3L;&5N_2!B;&]K(',@4$=0('!O9'!I<V5M+@!.96)Y;&\@=79E
M9&5N;R!)1"!D:7-T<FEB=>AN[6AO('-E>FYA;74L(&YE8GEL;R!N86QE>F5N
M;R!V(&1A=&%BX7II(&YE8F\@8GEL;R#Z<&QN["!V>6YE8VCA;F\N`$YE8GEL
M('5V961E;B!D:7-T<FEB=>AN[2!S97IN86TN`*EI9G)O=F%C[2!M;[YN;W-T
M:2!L>F4@=GEUONUT('!O=7IE('#X:2!B97IP9>ANZ6T@<W!O:F5N[2!S('=E
M8F5M("AH='1P<RDN`%-O=6)O<B`E<R!B>2!M[&P@;V)S86AO=F%T(&YA<W1A
M=F5N[2`E<RX`4V]U8F]R("5S(&)Y(&WL;"!O8G-A:&]V870@;NQK=&5RX2!Z
M(&YA<W1A=F5N[2`E<RX`4V]U8F]R(&YE;'IE(&MO<.UR;W9A="!SX6T@9&\@
M<V5B92X`4V]U8F]R(&YE;V)S86AU:F4@ON%D;N$@9&%T82X`3N%S;&5D=6KM
M(&AL879IZ&MY('!R;R!M97-S86=E+W)F8S@R,B!Z<'+A=G4`2F4@>F[A;>DL
M(+YE(&WS9"!P^&5S(&-E;&]U(&]B<F%Z;W9K=2!V($EN=&5R;F5T($5X<&QO
M<F5R=2!P^7-O8NT@<')O8FSI;7DL('!R;W1OOF4@<V4@=B!N[&T@=GES:WET
M=6IE(&-H>6)A+"!K=&5RZ2!S92!N96QZ92!V>6AN;W5T+B!*86MO(&[A<VQE
M9&5K(&WYOF4@8OUT(&[A:&]D;ND@>FAR;W5C96[M('1O:&]T;R!P<F]G<F%M
M=2P@8VAY8NQJ[6/M(&9U;FMC92!E9&ET;W)U(&YE8F\@;F5S<'+A=F[I('IO
M8G)A>F]VX6[M+B!0;VMU9"!J92!6X;D@<WES=&5MZ6T@5VEN;V1W<R`Y>"P@
M:F4@=F5L;6D@<')A=F3L<&]D;V)NZ2P@OF4@<V4@;V)J97;M(&-H>6)O=ND@
M:&SAN65N[2`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A(&)U9&5T92!M
M=7-E="!R97-T87)T;W9A="!P;^CM=&'H+EQN7&Y">6QI(&IS=&4@=F%R;W;A
M;FDN(%!R;W/M;2!S=&ES:V[L=&4@3TL@<&]K=60@<VD@</AE:F5T92!P;VMR
M8>AO=F%T('8@;?-D=2!P^&5S(&-E;&]U(&]B<F%Z;W9K=2X`261E;G1I=&$@
M(B5S(B!B>6QA('-M87KA;F$N`%!O=7IE(&YA(&QE=ND@<W1R86[L`%5M[7-T
M[&[M(&)I;N%R;NUH;R!S;W5B;W)U($=N=5!'(&UU<^T@8OUT('IA9.%N;R!D
M;R!T^.UD>2!#<GEP=%]P9W`Z.BX`6G!RX79A('IA<VQA;N$@=B`E<R!K("5S
M(',@</AE9&WL=&5M("(E<R(@8GEL82!Z;V)R87IE;F$N"E1O=&\@;F5Z87)U
MZ'5J92P@OF4@>G!RX79A(&)Y;&$@</AEZ'1E;F$@;F5B;R"^92!J[2!A9')E
M<^%T*&MA*2!R;WIU;>QL*&$I+@!.X7IE=BP@:W1E<OT@8G5D92!P;W6^:70@
M</AI(&]D:V%Z;W;A;NT@;F$@<W1RX6YC92!T=F]R8GD@>G!RX78`5/CM9&$@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!V>;YA9'5J92!M;V1U;"!O<&5N<W-L+@!.
M96QZ92!U;&^^:70@;F%S=&%V96[M("(E<R(L('!R;W1OOF4@:F5H;R!V96QI
M:V]S="!P^&5SX6AL82!P;W9O;&5N_2!L:6UI="X`3F5B>6QA(&YA;&5Z96YA
M(&%P;&EK86-E('!R;R#H=&5N[2!T;VAO=&\@='EP=2!D870@*"5S*2X`4&]U
M>F4@;F$@<')A=ND@82!L97;I('-T<F%N[`!0;W5Z92!N82!P<F%VZ2!S=')A
M;NP`4V5R=F5R("(E<R(@8GEL('9Y;6%ZX6XN`%-E<G9E<B`B)7,B(&)Y;"!U
M;&^^96XN`$)Y;&$@;V1S=')A;NQN82"^X61O<W0@;R!P^&EH;.&Y96[M('!R
M;R`E<RX`4&^^861O=F%N_2#XX61E:R!N965X:7-T=6IE+@!$;^AA<V[]('-O
M=6)O<B`B)7,B(&YE97AI<W1U:F4N`%!O=7IE(&YA:&_X92!A(&1O;&4`4&]U
M>F4@;F%H;_AE`%IT<F%T:6QA('-E('#X96YE<V5NX2!D871A('H@</AE9&-H
M;WKM:&\@:W)O:W4N`%#X96YE<V5N_2!S;W5B;W(@;F5L>F4@=6QOOFET+@!"
M;&]K('=E871H97(N8V]M(&YE;NT@9&]S='5P;OTN`*[A9&[I('H@;6^^;F]S
M=.T@;F5J<V]U(&1O<W1U<&[I+@!.96)Y;'D@;F%L97IE;GD@ON%D;ND@Z.%S
M=&DL(&MT97+I(&)Y(&)Y;&\@;6^^;F\@>F]B<F%Z:70@=B#XX61K=2X`4/CM
M;&FY(&UN;VAO('IN86OY('8@<&]L:2X@6F%D86QI(&IS=&4@)7,@>FYA:_D[
M(&UU<^UT92!Z861A="!MZ6[L(&YEOB`E<R!Z;F%K^2X`3F%S=&%L82!C:'EB
M82!P^&D@</AE;F]S=2!S;W5B;W)U.B`E<R!N96)Y;"!P^&5N97-E;BX`3F%S
M=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U+B`E<R!N96WYOF4@8OUT
M(';L=+GM(&YEOB!M87AI;>%L;NT@<&]V;VQE;N$@=F5L:6MO<W0@*"5D(&)Y
M=/DI+@!.87-T86QA(&-H>6)A('#X:2!P^&5N;W-U('-O=6)O<G4Z(&)Y;&$@
M</AE;F5S96YA(&IE;B#HX7-T('-O=6)O<G4@)7,N`$1ON6QO(&L@8VAY8NP@
M</AI('IO8G)A>F]VX6[M('3I=&\@Z.%S=&D@>G!RX79Y`$YA<W1A;&$@8VAY
M8F$@</AI(&EM<&]R=&]VX6[M(&MO;G1A:W1U+@!0^&D@:6UP;W)T;W;A;NT@
M:4-A;&5N9&%R(&1A="!D;[EL;R!K(&-H>6+L+@!#:'EB82!V(&MO;F9I9W5R
M8>AN[6T@9F]R;75LX?AI+B!:^&5J;>P@:G-T92!V>6YE8VAA;&D@<&^^861O
M=F%NZ2!P;VQE+@!.87-T86QA(&-H>6)A('#X:2!P<F]VX63L;NT@>F%D86[I
M(&]P97)A8V4@=B!A9')E<^'X:2X@4')O<^UM('IK=7-T92!T;R!P;WID[&II
M+@!.87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!K;VYT86MT=2X@4')O
M<^UM('IK=7-T92!T;R!P;WID[&II+@!.87-T86QA(&-H>6)A('#X:2!A:W1U
M86QI>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA;74N(%!R;W/M;2!Z:W5S=&4@
M=&\@<&]Z9.QJ:2X`5&5N=&\@24U!4"!S97)V97(@;F5P;V1P;W)U:F4@<V3M
M;&5N[2!S;&^^96LN`%1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T;OT@<F%R(&%R
M8VAI=BX`5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!Z:7`@<V]U8F]R+@!4
M;W1O(&YE=GEP863A(&IA:V\@<&QA=&[I(.CM<VQO(&MA<G1Y+@!496YT;R!O
M=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP<N%V('!O;6]C[2!#;&EC:V%T
M96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&)RX6YY('#X:2!P;W6^:73M
M($A45%`@05!)`%1E;G1O(&]V;&%D8>@@=6UOOO)U:F4@<&]S[6SA;NT@>G!R
MX78@<&]M;V/M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&)R
MX6YY('#X:2!P;W6^:73M($A45%`@05!)`%1E;G1O(&]V;&%D8>@@=6UOOO)U
M:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M(%--5%`@9&\@5F]D869O;F4@271A
M;'D@8G+A;GD@<&]U>F4@<')O(.CM<VQA('!O<VMY=&YU=.D@5F]D869O;F5M
M+B!-=7/M=&4@;>UT(&5M86EL;W;](/KH970@=2!6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!4;W1O('!O;&4@:F4@;G5T;ND@=GEP;&YI
M="X`5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&-E;.$@Z.US;&$N
M`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!C96SA(.CM<VQA(&$@
M9'9O:G1EZ&MU+@!4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@;W-M
M:>AK;W;I(.CM<VQA+@!4;W1O('!O;&4@;75S[2!B_70@<V5Z;F%M(&-E;/UC
M:"#H[7-E;"!O9&3L;&5N_6-H(.CA<FMO=2!N96)O(&UE>F5R;W4`5&]T;R!P
M;VQE(&UU<^T@8OUT('!L871NZ2#H[7-L;RX`5&]T;R!P;VQE(&UU<^T@<&)S
M86AO=F%T(&)A<F5V;OT@:_-D('8@N65S=&[A8VMO=NEM(%)'0B!F;W)MX71U
M+"!N87#X+B`G(S$R,S1A9B<N`%1E;G1O(&9O<FUU;.'X(&IIOB!B>6P@>G!R
M86-O=N%N+@!4;W1O(&IE("5S+@!4;W1O(&IE(&]B:F5K="!+;VQA8B!'<F]U
M<'=A<G4N($L@>FALZ61N=73M('1O:&]T;R!O8FIE:W1U(&IE('IA<&]T^&5B
M[2!M[70@<&^Y=&]V;NUH;R!K;&EE;G1A+"!K=&5R_2!R;WIU;>T@9F]R;>%T
M=2!+;VQA8B!'<F]U<'=A<G4N(%!R;R!S97IN86T@=&%K;W;]8V@@:VQI96YT
M^2!P<F]S[6T@;F%VN71I=G1E("5S`%1A=&\@>G!RX79A(&)Y;&$@;F%P<^%N
M82!V(&II;ND@>FYA:V]VZ2!S863L("@E<RD@;F6^(%9AN>TN(`!4;W1O(.CM
M<VQO(&UU<^T@8OUT(&YE:FWI;NP@:F5D;F$N`%-E<G9E<B!N96WYOF4@<F]Z
M8F%L:70@>FEP(&$@9WII<"!S;W5B;W)Y+@!496YT;R!S>7-TZ6T@:F4@=B!S
M;W7H87-N;W-T:2!D96%K=&EV;W9A;OTN`%1A=&\@:&]D;F]T82!M=7/M(&+]
M="#H[7-L;RX`5&]T;R!O:VYO(&UUOF4@8OUT('9O;.%N;R!P;W5Z92!Z(&]K
M;F$@;6^^;F]S=.T`2/AM[&[M`$SM<W1K>0#(87,`4VQE9&]VX6[M(.AA<W4`
M1F]R;>%T(.AA<W4`5OUB['(@Z&%S=0!4:6UO<BU,97-T90!4:71U;`!4:71U
M;"`H=&EP*3H`2V]M=0!0;VMU9"!S:2!P^&5J971E('9Y8G)A="!V[6-E('!O
M;&^^96LL('IMX>AK;NQT92!K;.%V97-U($-O;G1R;VP@*%!#*2!N96)O($-O
M;6UA;F0@*$UA8RD@82!K;&EK;NQT92!N82!P;VQOOFMU+@!$;F5S`%#X97!N
M;W5T(&YA($A434P@>F1R;VH`5&]G;P!4;VME;&%U`%KM=')A`%1O;F=A`%9R
M8V@`2&]R;NT@<N%M("A?=&]P*0!0^&5K;&%D>0!4<FEN:61A9"!A(%1O8F%G
M;P!3<'+A=F[L(&YE8F\@N7!A=&[L`-IT`%1U;FES:V\`5'5R96-K;P!4=7)E
M8VMY("A)4T\M.#@U.2TY*0!4=7)K;65N:7-TX6X`5'5R:W,@82!#86EC;W,@
M;W-T<F]V>0!4=79A;'4`3F%P:;ET92!68;EI('9O;&)U.@!5+E8N(&EN9&5X
M.B``55),`%523"!P<F\@>G!RX79U(&\@<W1A=G4@>F%S;&%NZ6AO('-K<FEP
M='4`55),.@!59V%N9&$`56MR86II;F$`5D93(&%D<F5SX?@@:F4@;F5P^.US
M='5P;OTN`%#X:2!R96=I<W1R86-I(&YE;'IE('#X:61A="!E>'1R82!UOFEV
M871E;'-KZ2#Z9&%J92X`3F5L>F4@>FWL;FET('!RX79A('!R;R!61E,@<V]U
M8F]R("(E<R(N`$YE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O<B`E
M<R\E<RX`3F5L>F4@>FWL;FET(&YA("5S+@!.96QZ92!S92!P^&EP;VII="!K
M(%-13"!S97)V97)U+@!.96QZ92!S92!P^&EP;VII="!P;VUO8^T@4U-,+@!.
M96QZ92!K;W#M<F]V870@5D93('-O=6)O<BX`3F5L>F4@=GET=F_X:70@5D93
M(&%D<F5SX?@@(B5S(BX`3F5L>F4@=GET=F_X:70@5D93(&%D<F5SX?@N`$YE
M;'IE('9Y='9O^&ET(%9&4R!S;W5B;W(N`$YE;'IE('9Y='9O^&ET('!RX7ID
M;OT@5D93('-O=6)O<BX`3F5L>F4@<F]Z8F%L:70@9&%T82X`3F5L>F4@=GEM
M87IA="`B)7,B+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P<N%Z9&[]+@!.96QZ
M92!V>6UA>F%T("5S+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P<N%Z9&[]+@!.
M96QZ92!R96MU<GII=NP@;V1S=')A;FET(%9&4R!A9')E<^'X+@!.96QZ92!V
M>6UA>F%T(%9&4R!A9')E<^'X+@!.96QZ92!V>6UA>F%T(%9&4R!A9')E<^'X
M.B`E<RX`3F5L>F4@=GEM87IA="!61E,@<V]U8F]R("(E<R(N`$YE;'IE('9Y
M;6%Z870@5D93('-O=6)O<BX`3F5L>F4@<F5K=7)Z:79N["!O9'-T<F%N:70@
M5D93.B`E<RX`3F5L>F4@=7+H:70@86MT=>%L;NT@861R97/A^"X`3F5L>F4@
M>FII<W1I="!P;V1R;V)N;W-T:2!O(&-E<G1I9FEKX71U+@!$969I;FEC92`E
M<R!N96[M(&1O<W1U<&[A+@!.96QZ92!P^&5S=6YO=70@5D93('-O=6)O<BX`
M3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(@(B5S(BX`5D93('-O=6)O<B!N
M96QZ92!O=&5V^.UT('!R;R!ZX7!I<RX`3F5L>F4@;W1E=OCM="!61E,@<V]U
M8F]R+@!.96QZ92!O=&5V^.UT(&%R8VAI=F]V86[]('-O=6)O<BX`3F5L>F4@
MZ.US="!Z('9F<W)O;W0@861R97/A^&4N`$YE;'IE('#X96IM96YO=F%T("5S
M(&YA("5S.B!C[6QO=N$@<VQOOFMA(&IIOB!E>&ES='5J90!61E,@861R97/A
M^"!N96QZ92!P^&5J;65N;W9A="X`5D93(&%D<F5SX?@@;F5L>F4@</AE:FUE
M;F]V870Z("5S+@!.96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R("(E<R(N
M`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(@)7,O)7,N`$YE;'IE('#X
M96IM96YO=F%T(%9&4R!S;W5B;W(N`$YE;'IE('!R;W;I<W0@)VUK:7-O9G,G
M+@!496YT;R!D;VMU;65N="!7;W)D(&YE;'IE('#X96QOOFET`$YE;'IE('IA
M<'-A="!D;R!61E,@<V]U8F]R=2`B)7,B+@!.96QZ92!Z87!S870@9&%T82!D
M;R!61E,@<V]U8F]R=2`H<V5L:&%L;R!C;W!Y*"DI+@!.96QZ92!Z87!S870@
M9&%T82!D;R!61E,@<V]U8F]R=0!0;V1T<FAN=73I`%-T;W)N;R!Z;>QN`%-T
M;W)N;W9A="!P;W-L96[M(&%K8VD`3F5OZ&5KX79A;N$@;V1P;W;L[R!S97)V
M97)U(&YA('-P;VIE;NTZ(`!.96_H96OA=F%NX2!O9'!O=NSO('-E<G9E<G4Z
M(`!.979Y<&QN[&YO`%5N:6-O9&4@*%541BTX*0!3<&]J96[I($%R86)S:^D@
M16UI<N%T>0!696QKX2!"<FETX6YI90!3<&]J96[I(%-TX71Y($%M97)I8VOI
M`%-P;VIE;ND@4W3A='D@365NN6EN;W;]8V@@;W-T<F]V^0!*961N;W1K>0!.
M97INX6WI`$YE>F[A;>D@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`3F5Z
M;N%MZ2!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!.97INX6WI('6^
M:79A=&5L<VOI(&IMZ6YO(&YE8F\@:&5S;&\N`$]D<&]J:70@<V]UZ&%S;OT@
M<')V96L`0F5Z92!J;>EN80!.97!R:79I;&5G;W9A;ND@<VMR:7!T>2!N96UO
M:&]U('9Y=;[M=F%T(&9U;FMC82!6>6IM;W5T+TMO<.UR;W9A="]6;&^^('H@
M8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y+B!+;&EK;NQT92!N82!/2R!A8GES=&4@
M=FED[&QI('1E8VAN:6-K;W4@>G!RX79U('H@;6]Z:6QL82YO<F<L(&MT97+A
M('9Y<W;L=&QU:F4L(&IA:R!N87-T879I="!S:W)I<'0@<')O('#X[7-T=7`@
M:V4@<V-H<N%N8V4N`$YE;F%S=&%V96[A(&)A<G9A`$YE<&]D<&]R;W9A;N$@
M</CM<&]N80!!:W1U86QI>F]V870`06MT=6%L:7IO=F%T("5S`$%K='5A;&EZ
M;W9A="!UOFEV871E;&4`4VMR:7!T('!R;R!A:W1U86QI>F%C:2!B>6P@=GEM
M87KA;BX`4/AE;F]S`%:Y96-H;GD@<V]U8F]R>2!P<F\@;F%S=&%V96[M(&%P
M;&EK86/M(&)Y;'D@</AE;F5S96YY(&YA('-E<G9E<BX`5F5L:^$@=&ES:V%C
M[2!P[7-M96YA`%9E;&OI(/CM;7-KZ2#H[7-L:6-E`%5R=6=U87D`4&]UONUT
M(&%K='7A;&[M.B`E<P!0;W6^[70@4U-,`%!O=;[M="!P;VMU9"!J;>EN;R]H
M97-L;R!J<V]U(&II;ND@;F6^('!R;R!)35-0('-E<G9E<BX`5;YI=F%T96P@
M)7,@;F5N[2!O<'+A=F[L;B!K('!O=;[M=N%N[2`E<RX`061M:6YI<W1R86-E
M('6^:79A=&5L^0!5OFEV871E;'-KZ2!M;[YN;W-T:0!296=I<W1R86-E('6^
M:79A=&5L^0!.82!T;VUT;R!S97)V97)U(&YE;NT@;6^^;N$@<F5G:7-T<F%C
M92!UOFEV871E;/DN`%6^:79A=&5L<VOI(&IMZ6YO`%6^:79A=&5L<VOI(&IM
MZ6YO.@!5OFEV871E;'-KZ2!J;>EN;SH@`%-E>FYA;2!UOFEV871E;/DZ`%5Z
M8F5K:7-TX6X`5D93(&%D<F5SX?@@;F5E>&ES='5J92X`1&]V;VQE;N$`3F%L
M97IE;N$@<&QA=&[A(&WM<W1A('IA:')N=6KM.B``4&QA=&YO<W0`2&]D;F]T
M82!V(&UI;G5TX6-H+@!(;V1N;W1Y`%9Y8G)A;ND@:&]D;F]T>2!Z`%9A;G5A
M='4`4')O;>QN;ND`5F5N97IU96QA`%-E;&AA;&$@=F5R:69I:V%C92`M('1A
M=&\@>G!RX79A(&UO:&QA(&+]="!Z9F%LN6]VX6YA+@!697)Z90!697)S:6]N
M($-O;G1R;VP`5F5R=&EKX6QN[2!Z87)O=F[A;NT`5F5R=&EKX6QN[2!O9'-T
M=7``5F5R=&EKX6QN[3H`5F5L;6D@=GES;VOA`%9I971N86T`5FEE=&YA;7-K
M>2`H5DE30TE)*0!:;V)R87II="`E<P!:;V)R87II="!E>'1E<F[M('=E8G-T
M<N%N:W4`6F]B<F%Z:70@:F%K;R`E<P!086YN96YS:^D@3W-T<F]V>2P@0G)I
M='-KZ0!086YN96YS:^D@3W-T<F]V>2P@52Y3+@!6:61I=&5L;F]S=`!6:61I
M=&5L;F]S=#H`5F]D869O;F4@271A;'D@</AE<R!33510`%503UI/4DY)5`!5
M4$]:3U).S$[-(2$A($]$4U120=)412!32U))4%0@4E7(3LP@6B`E<RX`5V%L
M;&ES(&%N9"!&=71U;F$`57!O>F]R;NQN[0!3=`!0^&5D<&]V[.\@<&_H87/M
M`$1A=&$@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H97(N8V]M`%=E8@!796(@
M<V5R=F5R`%3]9&[L`%;M=&5J=&4`5NUT96IT92!V("5S`%;M=&5J=&4L("5S
M`%KA<&%D;NT@*$E33RTX.#4Y+3$I`%KA<&%D;NT@*$E33RTX.#4Y+3$U*0!:
MX7!A9&[M(%-A:&%R80!+=&5R;W4@87!L:6MA8VD@;>$@)7,@>F]B<F%Z:70@
M<&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!*86O](&IE(&]D9.QL;W9A8^T@
M>FYA:S\`2F%K_2!J92!Z;F%K('!R;R!C:71A8VD_`$MT97+I(&;A>F4`5F]L
M8F$@<F]ZN>WX96[M('!R;R!2:6-H(%1E>'0@961I=&]R+@"I[?AK80"I[?AK
M82!V($-34R!J961N;W1KX6-H`*GM^&MA("5S(&UE;G4@=FQE=F\@*'IM[&YA
M('-E(&]B:F5V[2!P^&D@9&%LN>UM('#X:6ALX;EE;NTI.@"I[?AK82!T86)U
M;&MY`$IE9&YO=&MA(+GM^&MY`*GM^&MA.@!7:6MI`%;M='(`4F%N;NT@=NUT
M<@!2>6-H;&]S="!V['1R=2!V('5Z;&5C:`!6[71R.@!6[71R.B``36]U9')O
M<W0`4'+A8V4`061R97-A(&1O('IA;>QS=&[A;NT`5&5L969O;B!D;R!Z86WL
M<W1NX6[M`%@M4F5F`%@U,#EV,R!ZX6ML861N[2!O;65Z96[M`%@U,#EV,R!R
M;WJY[?AE;ND@<&]UOFET[2!K;.WH90!8-3`Y=C,@86QT97)N871I=F[M(&IM
MZ6YO(&]S;V)Y`%@U,#EV,R!I9&5N=&EF:6OA=&]R(&ML[>AE`%@U,#EV,R!R
M;WJY[?AE;NT`4E(`4E)24@!-87!A(%EA:&]O(0!2;^AN[`!*96UE;@!!;F\`
M06YO+"!S;W5H;&%S[6T`2G-T92!V(%1%6%1/5LE-($W31%4N(%!O=;YI:G1E
M(%L\/ET@=&QAZ.UT:V$@:R!Z<.QT;NEM=2!P^&5P;G5T[2!D;R!765-)5UE'
M+@!.96)Y;&D@:G-T92!S<'+A=F[L(&]V[/AE;FDN`%IN86L@)UPG(&YE;?F^
M92!B_70@<V]UZ.%S=.T@5F&Y96AO(&IMZ6YA+@!">6QA('IA9.%N82!N97!L
M871NX2!E+6UA:6QO=N$@861R97-A+@!.96UA<&]V86QI(&IS=&4@ON%D;N$@
M<&]L92!Z(&EM<&]R=&]V86[I:&\@<V]U8F]R=2!K(&]D<&]V[61A:NUC[6T@
M<&]L[6T@=B`E<RX`0GEL:2!J<W1E(&]D:&SAN65N:2!Z92!S>7-TZ6UU+@!6
M;&^^=&4@Z.US;&\@;6]B:6QN[6AO('1E;&5F;VYU+"!P;W6^:6IT92!J96X@
MZ.US;&EC(&YE8F\@</CM<&%D;NP@)RLG('!R;R!M97II;N%R;V1N[2#H:7-L
M82X`375S[71E('IA9&%T('!L871N;W4@:&]D;F]T=2X`375S[71E(&MO;F9I
M9W5R;W9A="!D871A8N%Z:2!D870L('!O:W5D('-I('#X96IE=&4@<&]UONUV
M870@4F5G:7-T<F%C92X`375S[71E(&MO;F9I9W5R;W9A="!61E,@8F%C:V5N
M9"X`375S[71E(&YE:F3X[79E('!O<'-A="!P<F]B;.EM(&$@<&]TZ2!H;R!O
M9&5S;&%T+@!-=7/M=&4@>F%D870@55),(&YA(&MT97+I(&)U9&4@=&5N=&\@
M;V1K87H@=6MA>F]V870`375S[71E('9Y8G)A="!S97)V97(L(&MT97+](&)U
M9&4@<VUA>N%N+@!-=7/M=&4@=GEB<F%T('6^:79A=&5L<VOI(&IMZ6YO+"!K
M=&5RZ2!B=61E('-M87KA;F\N`$UU<^UT92!Z861A="!UOFEV871E;'-KZ2!J
M;>EN;RP@:W1E<ND@8G5D92!O9'-T<F%N[&YO+@!.975V961L:2!J<W1E('6^
M:79A=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B=61E('#X:63A;F\N`$YE=79E9&QI
M(&IS=&4@=;YI=F%T96QS:^D@:FWI;F\@<')O(&%K='5A;&EZ86-I+@!-=7/M
M=&4@>F%D870@86MC:2P@:W1E<N$@8G5D92!P<F]V961E;F$N`$UU<^UT92!Z
M861A="!J;>EN;R!N;W;I(&MA=&5G;W)I92X`5F&Y92`E<R!R96QA8V4@8GEL
M82!U:V]NZ&5N82X@3W#L="!S92!P^&EH;&&Y=&4L('!R;W/M;2X`5F&Y92!E
M;6%I;&]VX2!A9')E<V$`5F&Y92!/9"UK;VAO.B!A9')E<V$Z`%9AN64@:6YF
M;W)M86-E`%8@<F5L86-I("5S('-E('IM[&YI;&$@5F&Y92!I;G1E<FYE=&]V
MX2!A9')E<V$N(%H@8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y('-E(&UU<^UT92!O
M<.QT('#X:6ALX7-I="X`5F&Y92!J;>EN;P!6X;D@;W;L^&]V86/M('-Y<W3I
M;2!N97!O9'!O<G5J92!V_7!I<R!UOFEV871E;/D@86YE8F\@=&%T;R!M;[YN
M;W-T(&YE;NT@</CM<W1U<&[A('H@:FEN_6-H(&3Y=F]D^2X`6F3A('-E+""^
M92!V('!R^6+L:'4@<F5L86-E("5S('-E('IM[&YI;"!6X;D@<')O:&SMOF7H
M+B!:(&)E>G!EZ&YO<W1N[6-H(&3Y=F]D^2!S92!M=7/M=&4@;W#L="!P^&EH
M;.%S:70N`%;AN2!P<F]H;.V^9>@@;F5P;V1P;W)U:F4@='5T;R!M;[YN;W-T
M+@!68;EE('-O=>AA<V[I(.AA<V]VZ2!PX7-M;SH`5F&Y92!I;7!L:6-I=&[M
M(&ED96YT:71A`%9AN64@^G!L;ND@:FWI;F\Z`%9AN64@;F]VZ2!H97-L;R!P
M<F\@)7,@:F4Z("5S`%9AN64@;F%S=&%V96[M(&)Y;&\@86MT=6%L:7IO=N%N
M;R!P<F\@=')VX6[M('3I=&\@<F5L86-E+@!68;EE(&YA<W1A=F5N[2!B>6QO
M(&%K='5A;&EZ;W;A;F\N`%9AN64@:&5S;&\@8GEL;R!R97-E=&]VX6YO+@!6
M8;EE(&AE<VQO(&)Y;&\@<F5S971O=N%N;RP@>FMO;G1R;VQU:G1E('-I('IP
M<N%V>2!E;&5K=')O;FEC:^D@<&^Y='D@82!P^&EH;&&Y=&4@<V4@<R!68;GM
M;2!N;W;];2!H97-L96TN`%9AN64@=GIDX6QE;ND@<V5R=F5R>3H`2G5G;W-L
MX79I90!:86ER`%IA;6)I90!::6UB86)V90!::7!P>0!;56MR_70@8VET;W9A
M;OT@=&5X=%T`6TALX;EE;NT@<')O8FSI;75=`%M:;V)R87II="!C:71O=F%N
M_2!T97AT("T`6UIO8G)A>FET(&-I=&]V86[]('1E>'0@+2`E<R#XX61K^5T`
M6_CA9&5K("5S('H@)7-=`%]!9&UI;FES=')A8V4`7T-,20!?1&%T851R964`
M7U-M87IA="#XX61E:P!?4VMU<&EN>0!?3N%P;W;L9&$`7U9L87-T;F]S=&D@
M;V)RX7IK=2XN+@!?4/AI:&SAN65N[0!?3V1H;.&Y96[M`%]-;V1I9FEK;W9A
M="!O9&MA>BXN+@!?36^^;F]S=&D`7U!RX79A`%]/9'-T<F%N:70@;V1K87HN
M+BX`7TYA<W1A=F5N[0!?5FQA<W1N;W-T:2!T86)U;&MY+BXN`%]5OFEV871E
M;.D`861R97/A^`!K86QE;F3A^`!B97IV['3X[0!K;&EK;F]U="!Z9&4`<W+A
MOFMY`'-O=6)O<@!Z("5S("@E<RD@<GEC:&QO<W3M("5S("5S`&@Z`&]K86V^
M:73L`'8@^&%D[`#XX61K^5T`8VAY8F]V_2!K\V0@;6MI<V]F<R`E9"!P^&D@
M=GET=N'X96[M($E33RX`:FWI;F\`;F5N[2!I;7!L96UE;G1O=N%N;P!N96[M
M(&1O<W5D(&EM<&QE;65N=&]VX6YO`'KA<&ES;NUK`'!R;V-E;G0`<&EX96SY
M`'-T;W5P86KM8^T`>F]B<F%Z:70@<F]Z9.UL>0!S;7,R96UA:6P@>F$@<&]U
MOFET[2!(5%10`'9Y=')V86SI`'-E>FYA;2#Z:V]L^0!P<F\@<&]T=G)Z96[M
M(&YA<&FY=&4@:&5S;&\@9'9A:W+A=`!S:F5D;F]C96[]`&)E>B!NX7IV=0!V
M>6)R870@=;YI=F%T96QE`'9#87)D`'<Z`'=E871H97(N8V]M````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V-S7T-:+VAE;'`N>&UL````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(V,0`Q,#0Q-S,V,C<W-@`P,C`S-#(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,B(_/@H\(2TM
M("1(;W)D93H@:&]R9&4O;&]C86QE+V-S7T-:+VAE;'`N>&UL+'8@,2XV(#(P
M,#0O,#@O,3@@,#@Z-#(Z-3$@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](G-U;6UA<GDB('-T871E/2)U<'1O9&%T92(@;60U/2(V.&-A,S-F
M-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q-2(^"CQT:71L93Y0;W)TX6P\+W1I
M=&QE/@H@/'!A<F$^"B`@4W1RX6YK82!0;W)TX6QU('!O<VMY='5J92!S=')U
MZ&[]('#X96AL960@=KEE8V@@9/EL9;YI=/UC:"!I;F9O<FUA8^TN"B`@3F%P
M^.UK;&%D(&WYOF4@>F]B<F%Z;W9A="!P;^AE="!E;6%I;/DL(&EN9F]R;6%C
M:2!O('-C:/EZ:^%C:"!V92!68>QE;2!K86QE;F3A^&DL"B`@^FMO;&5C:"P@
M871D+B!6['2Y:6YA('3L8VAT;R!I;F9O<FUC[2!P;W-K>71U:NT@;&EN:WD@
M:R!B[+YN_6T@9G5N:V/M;2P@"B`@:F%K;R!N87#X[6ML860@=GET=F_X96[M
M(&YO=ND@96UA:6QO=ND@>G!RX79Y+"!V>71V;_AE;FWM(&YO=ND@<V-H^7IK
M>2P@871D+@H@/"]P87)A/@H@/'!A<F$^"B`@4F]Z=G*^96[M('3I=&\@<W1R
MX6YK>2!P;W)TX6QU(&QZ92!N87-T879I="!P;VUO8^T@=&QAZ.UT:V$@4F]Z
M;&^^96[M+@H@($YA</CM:VQA9"P@;?F^971E('-I('9Y8G)A="P@:W1E<ND@
M<')V:WD@<VD@</AE:F5T92!Z;V)R87II="!A('1A:^D@=B!J86OI;0H@('!O
M^&%D[2X@"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B
M('-T871E/2)U<'1O9&%T92(@;60U/2)B.&-F,&%E,3EE-3=D9F$P8S)B.38R
M934Q-C<X,F8T-R(^"CQT:71L93Y.879I9V'H;NT@3&FY=&$@<')O($%P;&EK
M86-E/"]T:71L93X*(#QP87)A/@H@($YA=FEG8>AN[2!L:;ET82!J92!U;>US
M=&[L;F$@=FQE=F\@;F$@=V5B<W1RX6YC92X@2VQI:V[L=&4@;F$@:6MO;FMY
M"B`@=.ET;R!L:;ET>2!P;W-K>71U:NUC[2!P^&5H;&5D;NQJN>T@82!R>6-H
M;&5JN>T@</AE<.UNX6[M(&UE>FD@87!L:6MA8V5M:2X*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X
M8C)D,#`B/@H@("`@/'1I=&QE/DYA<W1A=F5N[3H@VF1ROF)A.B!0<F]VZ7-T
M(-ID<KYB=3PO=&ET;&4^"B`@("`\<&%R83X*("`@($]Z;F'H=&4@=&5N=&\@
M<N%M9>AE:RP@<&]K=60@<VD@</AE:F5T92!P<F]VZ7-T(&]P97)A8V4@^F1R
MOF)Y('#X:0H@("`@</AI:&SAN65N[2!D;R!S>73I;74N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA
M;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB83(Q,38R8V1F9C-B,60X9F%E
M861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I=&QE/DYA<W1A=F5N[3H@VF1ROF)A
M.B!0;W1V<F1I="#:9'*^8G4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!/>FYA
MZ'1E('1E;G1O('+A;67H96LL('!O:W5D('-I('#X96IE=&4@<&]T=G)D:70@
M=KEE8VAN>2!O<&5R86-E(/ID<KYB>0H@("`@;F6^('-E('!R;W9E9&]U+B!0
M;VMU9"!T96YT;R!RX6UEZ&5K('KY<W1A;F4@;F5O>FYAZ&5N_2P@<&]T^&5B
M;ND@;W!E<F%C92`*("`@('-E('!R;W9E9&]U(&%U=&]M871I8VMY(&)E>B!M
M;[YN;W-T:2!S=&]R;F$N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]D85]$2R\`````````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`,#$V-C,R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V1A7T1++TQ#7TU%4U-!1T53+P``
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W-@`P,C`T,3<`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9&%?
M1$LO3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P-#`U,#`Q`#$P-#$W,S8R-S<V`#`R,C`U,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25`````(L'```<````=#P`
M`!,*``#,>````````!BA```.````&:$```\````HH0``#0```#BA```(````
M1J$```L```!/H0``#````%NA```$````:*$``!@```!MH0``&P```(:A```M
M````HJ$``!T```#0H0``)````.ZA```I````$Z(``!D````]H@``)@```%>B
M```,````?J(``"0```"+H@``#P```+"B```+````P*(```X```#,H@``!0``
M`-NB```H````X:(```@````*HP``"@```!.C```5````'J,``!(````THP``
M"P```$>C``"%````4Z,```X```#9HP``"@```.BC```-````\Z,```X````!
MI```$0```!"D```-````(J0```P````PI```#0```#VD```&````2Z0``)0`
M``!2I```"@```.>D```/````\J0``!@````"I0``#````!NE```.````**4`
M``X````WI0``"````$:E```)````3Z4``"X```!9I0``&@```(BE```R````
MHZ4``#@```#6I0``5`````^F``!1````9*8``%H```"VI@``5P```!&G```T
M````::<```D```">IP``#0```*BG```'````MJ<```H```"^IP``#P```,FG
M```%````V:<```8```#?IP``$0```.:G```(````^*<```D````!J```"0``
M``NH```E````%:@``"`````[J```$P```%RH```0````<*@```\```"!J```
M"@```)&H```#````G*@```\```"@J```%````+"H```)````Q:@```T```#/
MJ```$@```-VH```9````\*@``!X````*J0``#P```"FI```*````.:D```\`
M``!$J0``"````%2I```D````7:D``!0```""J0``%@```)>I```(````KJD`
M`$X```"WJ0``+0````:J```9````-*H```<```!.J@``#````%:J```L````
M8ZH```X```"0J@```P```)^J```+````HZH```<```"OJ@``!P```+>J```%
M````OZH```4```#%J@``"@```,NJ```#````UJH``!<```#:J@``"@```/*J
M```/````_:H```X````-JP``&````!RK```C````-:L```X```!9JP``%```
M`&BK```7````?:L``!<```"5JP``%P```*VK```3````Q:L```\```#9JP``
M#@```.FK```?````^*L``!T````8K```!P```#:L```&````/JP```@```!%
MK```#P```$ZL```&````7JP```H```!EK```$P```'"L```+````A*P``!``
M``"0K```%0```*&L```5````MZP```<```#-K```$````-6L```%````YJP`
M`!4```#LK```$0````*M```,````%*T``#L````AK0``.````%VM```)````
MEJT```<```"@K0``%````*BM```#````O:T```4```#!K0``$````,>M```)
M````V*T``!,```#BK0``.0```/:M```2````,*X``"<```!#K@``+````&NN
M```J````F*X``"4```##K@``"@```.FN```&````]*X```D```#[K@``!P``
M``6O```O````#:\``#<````]KP``+@```'6O``!5````I*\``"T```#ZKP``
M+0```"BP```]````5K```#\```"4L```+0```-2P``!``````K$``",```!#
ML0``(P```&>Q``!`````B[$``"T```#,L0``,P```/JQ```E````+K(``!4`
M``!4L@``&0```&JR```I````A+(``"0```"NL@``*````-.R```1````_+(`
M``H````.LP``#````!FS```*````)K,``!`````QLP``%@```$*S```6````
M6;,```<```!PLP``!P```'BS```4````@+,```H```"5LP``"````*"S```G
M````J;,```@```#1LP``!P```-JS```'````XK,```8```#JLP``!0```/&S
M```'````][,```8```#_LP``"`````:T```I````#[0```X````YM```"@``
M`$BT```$````4[0```<```!8M```"0```&"T```&````:K0``!$```!QM```
M!P```(.T```6````B[0```0```"BM```"````*>T```&````L+0```T```"W
MM```!@```,6T```>````S+0``!$```#KM```"````/VT```-````!K4```P`
M```4M0``!P```"&U```#````*;4```,````MM0``%P```#&U```3````2;4`
M`!T```!=M0``"````'NU```$````A+4```@```")M0``"````)*U``!!````
MF[4``!H```#=M0``*P```/BU```@````)+8``!4```!%M@``!@```%NV```&
M````8K8``!4```!IM@``&````'^V```B````F+8``"X```"[M@``'0```.JV
M```A````"+<``%0````JMP``*0```'^W```*````J;<```<```"TMP``!P``
M`+RW```5````Q+<```X```#:MP``"@```.FW```/````]+<```T````$N```
M#P```!*X```-````(K@```D````PN```%````#JX```&````3[@``!@```!6
MN```'0```&^X```3````C;@``!$```"AN```%````+.X```$````R+@```8`
M``#-N```%````-2X``!4````Z;@``&0````^N0``!````*.Y```.````J+D`
M``4```"WN0``!0```+VY```;````P[D``!H```#?N0``$P```/JY```1````
M#KH``!$````@N@``'````#*Z```J````3[H``!````!ZN@``(0```(NZ```%
M````K;H``!,```"SN@``"P```,>Z```2````T[H```H```#FN@``#P```/&Z
M```-`````;L``!$````/NP``$P```"&[```,````-;L```8```!"NP``#```
M`$F[```&````5KL``!<```!=NP``$````'6[```1````AKL```@```"8NP``
M!0```*&[```,````I[L``!````"TNP``!0```,6[```-````R[L```8```#9
MNP``!P```."[```-````Z+L```<```#VNP``"P```/Z[```'````"KP```<`
M```2O```"0```!J\```)````)+P```H````NO```&0```#F\```]````4[P`
M`!T```"1O```#````*^\```0````O+P```4```#-O```)0```-.\```2````
M^;P``!,````,O0``*P```""]```[````3+T``"````"(O0``"````*F]```V
M````LKT``"$```#IO0``$`````N^```(````'+X```P````EO@``!@```#*^
M```$````.;X```\````^O@``#@```$Z^```'````7;X```H```!EO@``#0``
M`'"^```?````?KX``!P```">O@``(0```+N^```>````W;X``!D```#\O@``
M'@```!:_```;````-;\``"$```!1OP``+@```'._```F````HK\``!P```#)
MOP``'@```.:_```<````!<```"8````BP```*P```$G````S````=<```"8`
M``"IP```*P```-#````X````_,```!T````UP0``%0```%/!```O````:<$`
M`"````"9P0``$@```+K!```I````S<$``!X```#WP0``(````!;"```2````
M-\(``*(```!*P@``%@```.W"```C````!,,``"@````HPP``*0```%'#```H
M````>\,``!\```"DPP``%0```,3#```@````VL,``"4```#[PP``*````"'$
M```M````2L0``#````!XQ```D@```*G$```A````/,4``!8```!>Q0``'```
M`'7%```F````DL4``"H```"YQ0``00```.3%``!$````)L8```P```!KQ@``
M!P```'C&```'````@,8```8```"(Q@``#0```(_&```0````G<8``!(```"N
MQ@``$P```,'&```2````U<8```<```#HQ@``!````/#&```0````]<8``!``
M```&QP``#````!?'```.````),<```T````SQP``#P```$''```3````4<<`
M``T```!EQP``*````'/'```#````G,<```T```"@QP``!@```*['```1````
MM<<``!<```#'QP``&P```-_'```.````^\<```(````*R```20````W(```%
M````5\@``!````!=R```#P```&[(```$````?L@```T```"#R```#@```)'(
M```#````H,@```X```"DR```"````+/(```/````O,@```\```#,R```!P``
M`-S(```-````Y,@``!````#RR```#0````/)```+````$<D```8````=R0``
M"P```"3)```,````,,D```H````]R0``$0```$C)```9````6LD```L```!T
MR0``#0```(#)```B````CLD```\```"QR0``&P```,')```T````W<D```H`
M```2R@``&````!W*```2````-LH``!D```!)R@``%@```&/*```B````>LH`
M``T```"=R@``!P```*O*```4````L\H```L```#(R@``(@```-3*```O````
M]\H```L````GRP``"0```#/+```9````/<L```L```!7RP``%P```&/+```7
M````>\L```D```"3RP``%@```)W+```/````M,L``!D```#$RP``%@```-[+
M```.````]<L``!@````$S```"````!W,```-````)LP``"8````TS```0P``
M`%O,```(````G\P``!(```"HS```'P```+O,```(````V\P```L```#DS```
M+P```/#,```.````(,T```4````OS0``!@```#7-``!%````/,T```,```""
MS0``!P```(;-```$````CLT```H```"3S0``"@```)[-```/````J<T``!``
M``"YS0``%P```,K-```1````XLT``!D```#TS0``%P````[.```)````)LX`
M``4````PS@``"P```#;.```*````0LX```(```!-S@``!0```%#.```-````
M5LX``!L```!DS@``%P```(#.```4````F,X```D```"MS@``#@```+?.```-
M````QLX``!(```#4S@``.````.?.```@````(,\```@```!!SP``#@```$K/
M``![````6<\``!@```#5SP``&````.[/```1````!]````<````9T```!0``
M`"'0```8````)]```!X```!`T```&P```%_0```9````>]```!L```"5T```
M&0```+'0```3````R]````<```#?T```"````.?0```&````\-````8```#W
MT```$````/[0```/````#]$``!`````?T0``#P```##1```+````0-$```\`
M``!,T0``#````%S1```/````:=$```<```!YT0``!@```('1```.````B-$`
M``P```"7T0``*````*31```/````S=$```@```#=T0``"````.;1```3````
M[]$``!X````#T@``(0```"+2```@````1-(``!D```!ET@``%P```'_2```E
M````E](``!<```"]T@``%@```-72```$````[-(``!L```#QT@``#0````W3
M```,````&],```,````HTP``!0```"S3```(````,M,```H````[TP``#```
M`$;3```+````4],``!````!?TP``#````'#3```.````?=,```L```",TP``
M!````)C3```$````G=,``!,```"BTP``%````+;3```,````R],```D```#8
MTP``#@```.+3```+````\=,``!L```#]TP``!P```!G4```'````(=0```H`
M```IU```#0```#34```)````0M0```0```!,U```!0```%'4```#````5]0`
M`!@```!;U```"@```'34```$````?]0``"8```"$U```#@```*O4``!\````
MNM0``!4````WU0``!0```$W5```'````4]4```P```!;U0``"````&C5```*
M````<=4```8```!\U0``"````(/5```"````C-4```8```"/U0``!@```);5
M```4````G=4```T```"RU0``$````,#5```;````T=4```0```#MU0``"0``
M`/+5```0````_-4```D````-U@``"0```!?6```%````(=8``!H````GU@``
M"````$+6```&````2]8``!D```!2U@``#@```&S6```'````>]8```<```"#
MU@``!0```(O6```)````D=8```H```";U@``#@```*;6```"````M=8```8`
M``"XU@``"P```+_6```-````R]8```D```#9U@``!@```./6```2````ZM8`
M``D```#]U@``!P````?7```4````#]<``!T````DUP``0@```$+7```E````
MA=<``"4```"KUP``!@```-'7```*````V-<```0```#CUP``"0```.C7```(
M````\M<``!$```#[UP``"0````W8```&````%]@```T````>V```!@```"S8
M```$````,]@``#D````XV```/0```'+8```Z````L-@``!X```#KV```!0``
M``K9```.````$-D```0````?V0``!@```"39```'````*]D``"$````SV0``
M#0```%79```5````8]D```8```!YV0``!````(#9```1````A=D```8```"7
MV0``"@```)[9```B````J=D```0```#,V0``!0```-'9```=````U]D```0`
M``#UV0``#````/K9```.````!]H```H````6V@``"````"':```)````*MH`
M``4````TV@``.@```#K:```P````==H``#4```"FV@``*0```-S:``!'````
M!ML``#@```!.VP``*0```(?;```_````L=L``"X```#QVP``+0```"#<```?
M````3MP```\```!NW```$@```'[<```+````D=P``"8```"=W```*0```,3<
M```D````[MP``"8````3W0``"````#K=```*````0]T```D```!.W0``!P``
M`%C=```@````8-T``"````"!W0``)@```*+=```*````R=T``!D```#4W0``
M*0```.[=```6````&-X``!(````OW@``!P```$+>```*````2MX```P```!5
MW@``#P```&+>```0````<MX``$````"#W@``<````,3>``!F````-=\```X`
M``"<WP``"0```*O?```*````M=\``!(```#`WP``$P```-/?```,````Y]\`
M``8```#TWP``#P```/O?```2````"^```!`````>X```$0```"_@```<````
M0>```",```!>X```:@```(+@```/````[>````4```#]X```$`````/A```)
M````%.$```0````>X0``"P```"/A```@````+^$``!0```!0X0``#````&7A
M```,````<N$```\```!_X0``%0```(_A```I````I>$``"H```#/X0``)@``
M`/KA```G````(>(``"D```!)X@``*@```'/B```9````GN(``$(```"XX@``
M$0```/OB```2````#>,``!,````@XP``%````#3C```/````2>,``!8```!9
MXP``%P```'#C```0````B.,``!$```"9XP``-````*OC```3````X.,``!(`
M``#TXP``-0````?D```4````/>0```<```!2Y```#````%KD```@````9^0`
M`!````"(Y```%````)GD```1````KN0``!<```#`Y```'````-CD```3````
M]>0``!0````)Y0``&@```![E```1````.>4``!H```!+Y0``'@```&;E```:
M````A>4``!,```"@Y0``%0```+3E```1````RN4``!<```#<Y0``%````/3E
M```7````">8``!4````AY@``"0```#?F```0````0>8``!D```!2Y@``!```
M`&SF```'````<>8```L```!YY@``$0```(7F```&````E^8```8```">Y@``
M!@```*7F```%````K.8```<```"RY@``!P```+KF```%````PN8``!8```#(
MY@``!@```-_F```&````YN8```0```#MY@``!````/+F```'````]^8```X`
M``#_Y@``#`````[G```,````&^<```T````HYP``"@```#;G```.````0><`
M``4```!0YP``*````%;G```.````?^<```P```".YP``#P```)OG```*````
MJ^<```@```"VYP``"0```+_G```K````R><```0```#UYP``"````/KG```F
M`````^@``!(````JZ```#P```#WH```&````3>@```H```!4Z```!P```%_H
M```(````9^@``"````!PZ```"0```)'H```4````F^@```P```"PZ```#0``
M`+WH```.````R^@``!8```#:Z```$0```/'H```&`````^D```,````*Z0``
M!@````[I```9````%>D```<````OZ0``!````#?I```+````/.D```L```!(
MZ0``!P```%3I```%````7.D```<```!BZ0``%@```&KI```-````@>D```T`
M``"/Z0``"@```)WI```0````J.D```\```"YZ0``$0```,GI```7````V^D`
M``H```#SZ0``$0```/[I```(````$.H```0````9Z@``#P```![J```Z````
M+NH```4```!IZ@``#````&_J```>````?.H```X```";Z@``$````*KJ```+
M````N^H```P```#'Z@``"0```-3J```'````WNH```H```#FZ@``"0```/'J
M```.````^^H``!`````*ZP``&P```!OK```8````-^L``!H```!0ZP``"@``
M`&OK```)````=NL```H```"`ZP``#````(OK```/````F.L```@```"HZP``
M!@```+'K```<````N.L```<```#5ZP``!0```-WK```+````X^L``$<```#O
MZP``#0```#?L```)````1>P```0```!/[````P```%3L```3````6.P``!,`
M``!L[```$P```(#L```*````E.P```(```"?[```!````*+L```E````I^P`
M``,```#-[```!0```-'L```J````U^P```H````"[0``!0````WM```$````
M$^T```H````8[0``#0```"/M```&````,>T```@````X[0``"````$'M```$
M````2NT```4```!/[0``:````%7M```)````ONT```P```#([0``$````-7M
M```%````YNT```8```#L[0``&P```//M```O````#^X``!`````_[@``"@``
M`%#N```/````6^X```H```!K[@``"0```';N```3````@.X``!L```"4[@``
M&````+#N```7````R>X``!\```#A[@``#@````'O```#````$.\```<````4
M[P``"````!SO```'````)>\```H````M[P``"P```#CO```'````1.\``%$`
M``!,[P``$````)[O```,````K^\```T```"\[P``&@```,KO``!*````Y>\`
M`!D````P\```!@```$KP```:````4?```"4```!L\```!@```)+P```&````
MF?```!\```"@\```!@```,#P```)````Q_```!@```#1\```%P```.KP```H
M`````O$```8````K\0``#0```#+Q```B````0/$``%<```!C\0``$P```+OQ
M```C````S_$``!,```#S\0```@````?R```+````"O(```@````6\@``#0``
M`!_R```*````+?(```<````X\@``%````$#R```&````5?(```@```!<\@``
M#@```&7R```'````=/(```H```!\\@``"P```(?R```R````D_(```<```#&
M\@``#````,[R```-````V_(``!<```#I\@``#`````'S```)````#O,```D`
M```8\P``"@```"+S```'````+?,```D````U\P``!P```#_S```*````1_,`
M`!L```!2\P``#P```&[S```2````?O,```H```"1\P``%@```)SS```)````
ML_,``!````"]\P``!P```,[S```2````UO,```0```#I\P``!P```.[S```%
M````]O,```4```#\\P``"P````+T```4````#O0``!$````C]```&@```#7T
M```6````4/0``!0```!G]```%P```'ST```8````E/0``!P```"M]```&0``
M`,KT```'````Y/0```4```#L]```#0```/+T```,`````/4```@````-]0``
M%P```!;U```+````+O4```P````Z]0``'P```$?U```:````9_4``!,```""
M]0``!````);U```*````F_4```0```"F]0``#0```*OU```,````N?4```4`
M``#&]0``"0```,SU```%````UO4```<```#<]0``!0```.3U```$````ZO4`
M``(```#O]0``.````/+U```L````*_8``!(```!8]@``*0```&OV```R````
ME?8```H```#(]@``+````-/V```N`````/<``#,````O]P``,P```&/W```X
M````E_<```\```#0]P``&````.#W```0````^?<```\````*^```$P```!KX
M```5````+O@``!0```!$^```$@```%GX```4````;/@``!4```"!^```+0``
M`)?X```M````Q?@``#$```#S^```+@```"7Y```O````5/D``"P```"$^0``
M8@```+'Y```3````%/H```T````H^@``"````#;Z```7````/_H```@```!7
M^@``#````&#Z```K````;?H``"$```"9^@``&@```+OZ```)````UOH``$4`
M``#@^@``00```";[```$````:/L``!,```!M^P``%````('[```.````EOL`
M`!,```"E^P``&````+G[```&````TOL```D```#9^P``"@```./[```/````
M[OL``!````#^^P``!P````_\```.````%_P```4````F_```&P```"S\```(
M````2/P```8```!1_```%````%C\```1````;?P```X```!__```.````([\
M```"````Q_P```8```#*_```#@```-'\```%````X/P```<```#F_```#@``
M`.[\```&````_?P``"@````$_0``#````"W]```<````.OT```0```!7_0``
M*0```%S]```7````AOT``!\```">_0``7````+[]```4````&_X``#X````P
M_@``'P```&_^```0````C_X```<```"@_@``#@```*C^```,````M_X```P`
M``#$_@``$P```-'^```*````Y?X``!T```#P_@``&0````[_```%````*/\`
M`!$````N_P``$0```$#_```D````4O\``!(```!W_P``%0```(K_```2````
MH/\```X```"S_P``&0```,+_```(````W/\```D```#E_P``#0```.__```'
M````_?\```H````%``$`!P```!```0`/````&``!``8````H``$`"P```"\`
M`0`:````.P`!``H```!6``$`!P```&$``0`(````:0`!``4```!R``$`'P``
M`'@``0`&````F``!`!````"?``$`"````+```0`-````N0`!``@```#'``$`
M'@```-```0`2````[P`!`"P````"`0$`&@```"\!`0`)````2@$!``H```!4
M`0$`%0```%\!`0`%````=0$!`!0```![`0$`!````)`!`0`0````E0$!``8`
M``"F`0$`!P```*T!`0`>````M0$!`"@```#4`0$`"@```/T!`0`<````"`(!
M`!$````E`@$`"P```#<"`0`:````0P(!`!0```!>`@$`!````',"`0`$````
M>`(!``L```!]`@$`!0```(D"`0`&````CP(!``@```"6`@$`!@```)\"`0`*
M````I@(!`!L```"Q`@$`-````,T"`0`T`````@,!`"`````W`P$`*0```%@#
M`0`@````@@,!`$$```"C`P$`&@```.4#`0`H``````0!`"D````I!`$`4```
M`%,$`0`B````I`0!``8```#'!`$`"````,X$`0`%````UP0!``@```#=!`$`
M&0```.8$`0`9``````4!`"H````:!0$`(P```$4%`0`9````:04!`"X```"#
M!0$`-````+(%`0`(````YP4!`!<```#P!0$`"@````@&`0`'````$P8!`"$`
M```;!@$`$````#T&`0`.````3@8!``L```!=!@$`!P```&D&`0`3````<08!
M``@```"%!@$`"P```(X&`0`*````F@8!`!0```"E!@$`#P```+H&`0`R````
MR@8!``L```#]!@$`#@````D'`0`%````&`<!``4````>!P$`!0```"0'`0`7
M````*@<!``\```!"!P$`!````%('`0`*````5P<!``D```!B!P$`"P```&P'
M`0`-````>`<!``P```"&!P$`#@```),'`0`%````H@<!``0```"H!P$`#0``
M`*T'`0`R````NP<!`$4```#N!P$`%P```#0(`0`'````3`@!`!X```!4"`$`
M%````',(`0`%````B`@!`!0```"."`$`!@```*,(`0`'````J@@!``X```"R
M"`$`*@```,$(`0`&````[`@!``P```#S"`$`#0`````)`0`1````#@D!``L`
M```@"0$`-@```"P)`0`*````8PD!`"(```!N"0$`"P```)$)`0`/````G0D!
M`#(```"M"0$`)0```.`)`0`P````!@H!`#$````W"@$`+0```&D*`0`.````
MEPH!``4```"F"@$`#@```*P*`0`3````NPH!`!(```#/"@$`!P```.(*`0`1
M````Z@H!`!,```#\"@$`!P```!`+`0`4````&`L!`!@````M"P$`!P```$8+
M`0`%````3@L!``P```!4"P$`#````&$+`0`2````;@L!``0```"!"P$`!P``
M`(8+`0`*````C@L!``L```"9"P$`#````*4+`0`.````L@L!``X```#!"P$`
M!0```-`+`0`%````U@L!`"X```#<"P$`)@````L,`0`C````,@P!``,```!6
M#`$`$@```%H,`0`&````;0P!`!X```!T#`$`&````),,`0`E````K`P!``T`
M``#2#`$`"0```.`,`0`?````Z@P!``,````*#0$`!P````X-`0`*````%@T!
M``(````A#0$`#````"0-`0`5````,0T!``L```!'#0$`&0```%,-`0`@````
M;0T!`!(```".#0$`!0```*$-`0`*````IPT!`!4```"R#0$`$@```,@-`0`,
M````VPT!``0```#H#0$`"0```.T-`0`'````]PT!``P```#_#0$`4@````P.
M`0`7````7PX!`"0```!W#@$`$@```)P.`0`'````KPX!``8```"W#@$`#@``
M`+X.`0`,````S0X!``T```#:#@$`%0```.@.`0`2````_@X!``\````1#P$`
M%````"$/`0`*````-@\!`!L```!!#P$`$````%T/`0`+````;@\!`&D```!Z
M#P$`&@```.0/`0`7````_P\!`"<````7$`$`&@```#\0`0`7````6A`!`!L`
M``!R$`$`&0```(X0`0`?````J!`!`!,```#($`$`"````-P0`0`'````Y1`!
M``@```#M$`$`"0```/80`0`5`````!$!``T````6$0$`(P```"01`0`-````
M2!$!`!,```!6$0$`"````&H1`0`#````<Q$!`$8```!W$0$`/P```+X1`0`W
M````_A$!`%<````V$@$`!0```(X2`0`?````E!(!`"\```"T$@$`"@```.02
M`0`(````[Q(!``T```#X$@$`+0````83`0`$````-!,!`$\````Y$P$`)0``
M`(D3`0`<````KQ,!``L```#,$P$`'P```-@3`0`=````^!,!`"4````6%`$`
M(````#P4`0`D````710!`"````""%`$`"P```*,4`0`'````KQ0!``T```"W
M%`$`#````,44`0`7````TA0!``8```#J%`$`.0```/$4`0`,````*Q4!``<`
M```X%0$`"0```$`5`0`3````2A4!``D```!>%0$`!````&@5`0`0````;14!
M``@```!^%0$`"````(<5`0`$````D!4!``L```"5%0$`#````*$5`0`2````
MKA4!`!$```#!%0$`#````-,5`0`:````X!4!``\```#[%0$`!P````L6`0`-
M````$Q8!`!0````A%@$`#@```#86`0`,````118!`!L```!2%@$`+````&X6
M`0`3````FQ8!`!P```"O%@$`*````,P6`0`&````]18!``<```#\%@$`$P``
M``07`0`%````&!<!``0````>%P$`%P```",7`0`*````.Q<!``P```!&%P$`
M"0```%,7`0`&````71<!``D```!D%P$`"````&X7`0`)````=Q<!``H```"!
M%P$`$0```(P7`0`&````GA<!``X```"E%P$`#@```+07`0`-````PQ<!``L`
M``#1%P$`'0```-T7`0`+````^Q<!``(````'&`$`'`````H8`0`'````)Q@!
M``8````O&`$`9````#88`0`)````FQ@!``<```"E&`$`)@```*T8`0`X````
MU!@!`!H````-&0$`*@```"@9`0`[````4QD!`"@```"/&0$`-````+@9`0`9
M````[1D!`!4````'&@$`!0```!T:`0`'````(QH!``@````K&@$`!P```#0:
M`0`%````/!H!``<```!"&@$`#@```$H:`0`)````61H!``8```!C&@$`"```
M`&H:`0`+````<QH!``<```!_&@$`"````(<:`0`'````D!H!`!8```"8&@$`
M"0```*\:`0`&````N1H!``L```#`&@$`$````,P:`0`&````W1H!`!P```#D
M&@$`%`````$;`0`'````%AL!`!$````>&P$`"````#`;`0`.````.1L!``@`
M``!(&P$`!0```%$;`0`0````5QL!``D```!H&P$`$````'(;`0`&````@QL!
M`!D```"*&P$`"@```*0;`0`<````KQL!``<```#,&P$`!0```-0;`0`0````
MVAL!`!0```#K&P$`"P`````<`0`-````#!P!`"@````:'`$`&````$,<`0`7
M````7!P!``0```!T'`$`"0```'D<`0`*````@QP!``<```".'`$``@```)8<
M`0`.````F1P!``@```"H'`$`(P```+$<`0`?````U1P!`#@```#U'`$`)@``
M`"X=`0`Q````51T!`"<```"''0$`9````*\=`0`4````%!X!`%4````I'@$`
M.````'\>`0!*````N!X!`%L````#'P$`*````%\?`0`X````B!\!`"@```#!
M'P$`+````.H?`0`F````%R`!`!L````^(`$`/@```%H@`0"I`0``F2`!`",`
M``!#(@$`%P```&<B`0!(````?R(!`(4```#((@$`,````$XC`0`E````?R,!
M`$$```"E(P$`6P```.<C`0!)````0R0!`#$```"-)`$`'0```+\D`0`8````
MW20!`"L```#V)`$`(0```"(E`0`?````1"4!`"L```!D)0$`)@```)`E`0`A
M````MR4!`"<```#9)0$`.@````$F`0`=````/"8!`!$```!:)@$`,P```&PF
M`0`E````H"8!`"<```#&)@$`(````.XF`0`?````#R<!`#`````O)P$`:0``
M`&`G`0`Q````RB<!`$$```#\)P$`,P```#XH`0`E````<B@!`#T```"8*`$`
M90```-8H`0!-````/"D!`"\```"**0$`+@```+HI`0`P````Z2D!`%0````:
M*@$`6@```&\J`0!(````RBH!`$H````3*P$`,@```%XK`0`O````D2L!`"P`
M``#!*P$`+0```.XK`0!Q````'"P!`&8```".+`$`;P```/4L`0"S````92T!
M`!<````9+@$`)0```#$N`0`R````5RX!`"D```"*+@$`/@```+0N`0`B````
M\RX!`%(````6+P$`)0```&DO`0`+````CR\!`+$```";+P$`10```$TP`0`A
M````DS`!`#````"U,`$`)0```.8P`0`<````##$!`#$````I,0$`!P```%LQ
M`0`'````8S$!``0```!K,0$`#0```'`Q`0`+````?C$!``X```"*,0$`"P``
M`)DQ`0`%````I3$!`!````"K,0$``@```+PQ`0!9````OS$!``4````9,@$`
M$@```!\R`0`$````,C(!``<````W,@$`"````#\R`0`%````2#(!`#````!.
M,@$``P```'\R`0`0````@S(!``P```"4,@$`$P```*$R`0`-````M3(!``(`
M``##,@$`!P```,8R`0`&````SC(!`!0```#5,@$`#````.HR`0`8````]S(!
M``8````0,P$`$@```!<S`0`,````*C,!``,````W,P$`*@```#LS`0`$````
M9C,!``8```!K,P$`!P```'(S`0`?````>C,!`#4```":,P$`+@```-`S`0`O
M````_S,!`!<````O-`$`(@```$<T`0`E````:C0!`"````"0-`$`&P```+$T
M`0`8````S30!`"0```#F-`$`'P````LU`0`:````*S4!`"$```!&-0$`(```
M`&@U`0`:````B34!`#(```"D-0$`&@```-<U`0`O````\C4!`"L````B-@$`
M'P```$XV`0`C````;C8!`!\```"2-@$`&@```+(V`0`A````S38!`"4```#O
M-@$`)@```!4W`0`E````/#<!`"0```!B-P$`&````(<W`0`=````H#<!`"0`
M``"^-P$`&````.,W`0`B````_#<!`"P````?.`$`+P```$PX`0`5````?#@!
M`"4```"2.`$`/````+@X`0`?````]3@!`",````5.0$`'P```#DY`0`@````
M63D!`!H```!Z.0$`&````)4Y`0`F````KCD!`!X```#5.0$`*0```/0Y`0`>
M````'CH!`#$````].@$`"0```&\Z`0`,````>3H!`!<```"&.@$`+P```)XZ
M`0`D````SCH!``<```#S.@$`#P```/LZ`0`4````"SL!``X````@.P$`#0``
M`"\[`0`D````/3L!``4```!B.P$`!P```&@[`0`B````<#L!`"4```"3.P$`
M&@```+D[`0`=````U#L!`!H```#R.P$`!P````T\`0#'````%3P!``L```#=
M/`$`%0```.D\`0`&````_SP!``D````&/0$`"P```!`]`0`-````'#T!`!<`
M```J/0$`!@```$(]`0`S````23T!`!,```!]/0$`$P```)$]`0`'````I3T!
M``\```"M/0$`!P```+T]`0`R````Q3T!``0```#X/0$`(0```/T]`0`3````
M'SX!``P````S/@$`$0```$`^`0`R````4CX!`!8```"%/@$`"````)P^`0`=
M````I3X!``D```##/@$`"@```,T^`0`4````V#X!``H```#M/@$`'0```/@^
M`0`(````%C\!`!\````?/P$`"````#\_`0`:````2#\!`"<```!C/P$`!@``
M`(L_`0`5````DC\!``<```"H/P$`"````+`_`0`)````N3\!`#\```##/P$`
M!P````-``0`/````"T`!``X````;0`$`$````"I``0`)````.T`!``D```!%
M0`$`"````$]``0`3````6$`!``<```!L0`$`&0```'1``0`*````CD`!`!<`
M``"90`$`%````+%``0`*````QD`!``P```#10`$`%P```-Y``0`$````]D`!
M`"H```#[0`$`#````"9!`0`1````,T$!``<```!%00$``@```$U!`0`0````
M4$$!`!@```!A00$`"P```'I!`0`#````AD$!``@```"*00$`!@```)-!`0`'
M````FD$!``T```"B00$`"P```+!!`0`4````O$$!`!4```#100$`#@```.=!
M`0`O````]D$!`"`````F0@$`'````$="`0`5````9$(!``P```!Z0@$`,0``
M`(="`0`%````N4(!`!(```"_0@$`/P```-)"`0`2````$D,!``H````E0P$`
M!@```#!#`0`$````-T,!``0````\0P$`"@```$%#`0`3````3$,!``4```!@
M0P$`!@```&9#`0`&````;4,!``@```!T0P$`!````'U#`0`,````@D,!``H`
M``"/0P$`.0```)I#`0`N````U$,!`"D````#1`$`!0```"U$`0`8````,T0!
M`!D```!,1`$`'P```&9$`0`=````AD0!`!$```"D1`$``@```+9$`0`$````
MN40!``H```"^1`$`!@```,E$`0`%````T$0!``,```#61`$`#````-I$`0!%
M````YT0!`#(````M10$`&@```&!%`0`T````>T4!`"@```"P10$`4P```-E%
M`0`9````+48!`'(```!'1@$`(````+I&`0`U````VT8!`"$````11P$`10``
M`#-'`0`P````>4<!`"@```"J1P$`*0```--'`0`F````_4<!`"4````D2`$`
M*````$I(`0`H````<T@!`"(```"<2`$`*P```+](`0`P````ZT@!`!(````<
M20$`$P```"])`0`0````0TD!`'D```!420$`"0```,Y)`0"A````V$D!`',`
M``!Z2@$`?````.Y*`0`K````:TL!`%0```"72P$`%P```.Q+`0`G````!$P!
M`!8````L3`$`#P```$-,`0`7````4TP!`!\```!K3`$`0````(M,`0`?````
MS$P!`!P```#L3`$`40````E-`0`:````6TT!`!0```!V30$`"@```(M-`0`%
M````EDT!``8```"<30$`"````*--`0`%````K$T!`!(```"R30$`$````,5-
M`0`3````UDT!`!T```#J30$`#P````A.`0`/````&$X!``0````H3@$`"0``
M`"U.`0`+````-TX!``<```!#3@$`!0```$M.`0`4````44X!``<```!F3@$`
M"````&Y.`0`/````=TX!``@```"'3@$`#````)!.`0`/````G4X!``8```"M
M3@$`%````+1.`0`&````R4X!``P```#03@$`$0```-U.`0`(````[TX!``0`
M``#X3@$`&0```/U.`0`1````%T\!``H````I3P$`&````#1/`0`3````34\!
M`!P```!A3P$`$0```'Y/`0`$````D$\!``\```"53P$`!P```*5/`0`$````
MK4\!`!D```"R3P$`!P```,Q/`0`"````U$\!``(```#73P$`$0```-I/`0`)
M````[$\!``8```#V3P$`$@```/U/`0`7````$%`!``8````H4`$`)P```"]0
M`0`"````5U`!``0```!:4`$`#P```%]0`0`3````;U`!``<```"#4`$`!P``
M`(M0`0`1````DU`!``8```"E4`$`&````*Q0`0`&````Q5`!`!,```#,4`$`
M$````.!0`0`2````\5`!``(````$40$`!@````=1`0`,````#E$!``D````;
M40$`$0```"51`0`B````-U$!``<```!:40$`!P```&)1`0`+````:E$!``4`
M``!V40$``@```'Q1`0`+````?U$!`)0!``"+40$`$````"!3`0`/````,5,!
M``T```!!4P$`"````$]3`0`+````6%,!``@```!D4P$`!0```&U3`0`8````
M<U,!`!L```",4P$`+P```*A3`0`>````V%,!`"4```#W4P$`*````!U4`0`:
M````1E0!`"H```!A5`$`"P```(Q4`0`@````F%0!``X```"Y5`$`"P```,A4
M`0`/````U%0!``4```#D5`$`(````.I4`0`,````"U4!``X````850$`$P``
M`"=5`0`7````.U4!``P```!350$`B@```&!5`0`)````ZU4!``L```#U50$`
M#P````%6`0`/````$58!`!,````A5@$`#````#56`0`-````0E8!``L```!0
M5@$`!@```%Q6`0"J````8U8!``@````.5P$`$````!=7`0`:````*%<!``H`
M``!#5P$`$````$Y7`0`0````7U<!``@```!P5P$`#P```'E7`0`M````B5<!
M`"$```"W5P$`.P```-E7`0!&````%5@!`%L```!<6`$`60```+A8`0!B````
M$ED!`%X```!U60$`/@```-19`0`/````$UH!`!(````C6@$`#@```#9:`0`/
M````15H!`!(```!56@$`!0```&A:`0`&````;EH!`!$```!U6@$`!0```(=:
M`0`)````C5H!``D```"76@$`*@```*%:`0`F````S%H!`!$```#S6@$`$```
M``5;`0`2````%EL!``H````I6P$`!@```#1;`0`2````.UL!`!X```!.6P$`
M"P```&U;`0`0````>5L!`!,```"*6P$`&P```)Y;`0`A````NEL!`!4```#<
M6P$`#@```/);`0`4`````5P!``D````67`$`)P```"!<`0`;````2%P!`!X`
M``!D7`$`#````(-<`0!:````D%P!`#````#K7`$`(@```!Q=`0`'````/UT!
M``\```!'70$`,P```%==`0`.````BUT!``@```":70$`"P```*-=`0`(````
MKUT!``@```"X70$`"0```,%=`0`*````RUT!``H```#670$`!````.%=`0`3
M````YET!``P```#Z70$`$`````=>`0`/````&%X!`!@````H7@$`)0```$%>
M`0`3````9UX!`!4```![7@$`%P```)%>`0`:````J5X!`!(```#$7@$`%@``
M`-=>`0`1````[EX!`!``````7P$`+0```!%?`0`>````/U\!``<```!>7P$`
M!@```&9?`0`(````;5\!`!0```!V7P$`!@```(M?`0`(````DE\!`!,```";
M7P$`"P```*]?`0`1````NU\!`!4```#-7P$`$P```.-?`0`'````]U\!``X`
M``#_7P$`!0````Y@`0`6````%&`!`!(````K8`$`"0```#Y@`0!"````2&`!
M`$````"+8`$`"0```,Q@`0`(````UF`!`!,```#?8`$`!0```/-@`0`%````
M^6`!``P```#_8`$`"0````QA`0`9````%F$!`$0````P80$`#P```'5A`0`P
M````A6$!`#0```"V80$`,P```.MA`0`O````'V(!``L```!/8@$`!@```%MB
M`0`*````8F(!``8```!M8@$`,````'1B`0`Q````I6(!`"\```#78@$`40``
M``=C`0`N````66,!`"X```"(8P$`1P```+=C`0!(````_V,!`"X```!(9`$`
M.0```'=D`0`D````L60!`"8```#69`$`2P```/UD`0`N````264!`#0```!X
M90$`(````*UE`0`/````SF4!`!,```#>90$`(````/)E`0`C````$V8!`",`
M```W9@$`%````%MF`0`+````<&8!`!,```!\9@$`"@```)!F`0`.````FV8!
M`!D```"J9@$`'````,1F`0`&````X68!``<```#H9@$`%@```/!F`0`*````
M!V<!``@````29P$`)0```!MG`0`*````06<!``P```!,9P$`!P```%EG`0`&
M````86<!``4```!H9P$`!P```&YG`0`&````=F<!``H```!]9P$`*@```(AG
M`0`/````LV<!``@```##9P$``P```,QG`0`(````T&<!``D```#99P$`!```
M`.-G`0`.````Z&<!``4```#W9P$`%@```/UG`0`%````%&@!``@````::`$`
M!````"-H`0`)````*&@!``D````R:`$`&@```#QH`0`1````5V@!``D```!I
M:`$`"@```'-H`0`,````?F@!``<```"+:`$``P```)-H`0`#````EV@!`!<`
M``";:`$`$P```+-H`0`V````QV@!``@```#^:`$`"@````=I`0`(````$FD!
M``@````;:0$`00```"1I`0`<````9FD!`"L```"#:0$`)0```*]I`0`7````
MU6D!``8```#M:0$`"````/1I`0`=````_6D!`!D````;:@$`)P```#5J`0`P
M````76H!`!T```".:@$`)````*QJ`0!E````T6H!`"P````W:P$`"0```&1K
M`0`+````;FL!``<```!Z:P$`%````()K`0`+````EVL!``4```"C:P$`$```
M`*EK`0`-````NFL!`!````#(:P$`$````-EK`0`,````ZFL!`!4```#W:P$`
M!P````UL`0`>````%6P!`!X````T;`$`$P```%-L`0`/````9VP!`!4```!W
M;`$`!0```(UL`0`%````DVP!`!$```"9;`$`7P```*ML`0!<````"VT!``0`
M``!H;0$`#@```&UM`0`%````?&T!``0```"";0$`'P```(=M`0`<````IVT!
M`!$```#$;0$`#P```-9M`0`2````YFT!`!\```#Y;0$`)````!EN`0`'````
M/FX!`",```!&;@$`!0```&IN`0`;````<&X!`!0```",;@$`$@```*%N`0`.
M````M&X!`!(```##;@$`#0```-9N`0`5````Y&X!`!,```#Z;@$`"@````YO
M`0`%````&6\!``T````?;P$`!0```"UO`0`5````,V\!`!4```!);P$`$P``
M`%]O`0`)````<V\!``4```!];P$`"P```(-O`0`)````CV\!``4```"9;P$`
M#0```)]O`0`+````K6\!``@```"Y;P$`#0```,)O`0`)````T&\!``L```#:
M;P$`"0```.9O`0`%````\&\!``D```#V;P$`!P````!P`0`+````"'`!`!<`
M```4<`$`0P```"QP`0`<````<'`!``T```"-<`$`#P```)MP`0`%````JW`!
M`"````"Q<`$`&````-)P`0`9````ZW`!`"T````%<0$`/````#-Q`0`G````
M<'$!``D```"8<0$`,0```*)Q`0`A````U'$!``\```#V<0$`!P````9R`0`,
M````#G(!``<````;<@$`!@```"-R`0`9````*G(!`!````!$<@$`"````%5R
M`0`*````7G(!``\```!I<@$`(````'ER`0`?````FG(!`"(```"Z<@$`(0``
M`-UR`0`>````_W(!`"$````><P$`(0```$!S`0`D````8G,!`#<```"'<P$`
M*0```+]S`0`@````Z7,!`"(````*=`$`'0```"UT`0`H````2W0!`$0```!T
M=`$`+P```+ET`0`F````Z70!`"D````0=0$`0@```#IU`0`?````?74!`!8`
M``"==0$`,0```+1U`0`C````YG4!`!,````*=@$`+````!YV`0`=````2W8!
M`!P```!I=@$`$P```(9V`0"S````FG8!`!0```!.=P$`)@```&-W`0`G````
MBG<!`"@```"R=P$`'@```-MW`0`B````^G<!`!8````=>`$`(0```#1X`0`I
M````5G@!`"P```"`>`$`/P```*UX`0`O````[7@!`)X````=>0$`'@```+QY
M`0`@````VWD!`!\```#\>0$`*@```!QZ`0`L````1WH!`$4```!T>@$`1```
M`+IZ`0`,````_WH!``0````,>P$`!@```!%[`0`%````&'L!`!,````>>P$`
M"P```#)[`0`0````/GL!`!,```!/>P$`$0```&-[`0`(````=7L!``0```!^
M>P$`$0```(-[`0`3````E7L!``H```"I>P$`$````+1[`0`1````Q7L!``P`
M``#7>P$`$````.1[`0`+````]7L!`#H````!?`$`!````#Q\`0`)````07P!
M``8```!+?`$`$@```%)\`0`8````97P!`!L```!^?`$`"````)I\`0`"````
MHWP!`$D```"F?`$`!@```/!\`0`2````]WP!``\````*?0$`!````!I]`0`/
M````'WT!``@````O?0$``P```#A]`0`,````/'T!``@```!)?0$`"@```%)]
M`0`1````77T!``@```!O?0$`#0```'A]`0`2````AGT!``T```"9?0$`#```
M`*=]`0`$````M'T!``H```"Y?0$`"P```,1]`0`+````T'T!`!````#<?0$`
M&````.U]`0`*````!GX!``P````1?@$`)P```!Y^`0`-````1GX!`!D```!4
M?@$`.P```&Y^`0`*````JGX!`!4```"U?@$`$````,M^`0`9````W'X!`!<`
M``#V?@$`(`````Y_`0`2````+W\!``<```!"?P$`$0```$I_`0`+````7'\!
M`"$```!H?P$`/P```(I_`0`)````RG\!``@```#4?P$`&@```-U_`0`*````
M^'\!`!D````#@`$`&0```!V``0`'````-X`!`!4````_@`$`&0```%6``0`8
M````;X`!`!0```"(@`$`#@```)V``0`3````K(`!``@```#`@`$`$````,F`
M`0`H````VH`!`$(````#@0$`&0```$:!`0`9````8($!`"8```!Z@0$`!```
M`*&!`0`'````IH$!`#````"N@0$`$0```-^!`0`,````\8$!``8```#^@0$`
M2`````6"`0`#````3H(!``<```!2@@$`!P```%J"`0`*````8H(!``P```!M
M@@$`$````'J"`0`1````BX(!`!@```"=@@$`#P```+:"`0`:````QH(!`!@`
M``#A@@$`"@```/J"`0`'````!8,!``L````-@P$`"@```!F#`0`"````)(,!
M``4````G@P$`#@```"V#`0`;````/(,!`!8```!8@P$`%````&^#`0`'````
MA(,!``L```",@P$`#P```)B#`0`+````J(,!`#H```"T@P$`(````.^#`0`'
M````$(0!`!D````8A`$`@P```#*$`0`:````MH0!`!L```#1A`$`$0```.V$
M`0`'````_X0!``0````'A0$`'0````R%`0`E````*H4!`",```!0A0$`(@``
M`'2%`0`D````EX4!`"$```"\A0$`'0```-Z%`0`'````_(4!``@````$A@$`
M!@````V&`0`&````%(8!``P````;A@$`#@```"B&`0`0````-X8!``T```!(
MA@$`#P```%:&`0`/````9H8!``H```!VA@$`$````(&&`0`%````DH8!``4`
M``"8A@$`$0```)Z&`0`.````L(8!`"H```"_A@$`#P```.J&`0`)````^H8!
M``@````$AP$`&`````V'`0`A````)H<!`"P```!(AP$`(P```'6'`0`>````
MF8<!`!P```"XAP$`*````-6'`0`;````_H<!`!0````:B`$`!0```"^(`0`9
M````-8@!``@```!/B`$`#0```%B(`0`#````9H@!``H```!JB`$`!P```'6(
M`0`%````?8@!``<```"#B`$`"````(N(`0`+````E(@!``L```"@B`$`#@``
M`*R(`0`7````NX@!``0```#3B`$``P```-B(`0`3````W(@!`!4```#PB`$`
M#0````:)`0`'````%(D!``<````<B0$`"@```"2)`0`=````+XD!``8```!-
MB0$`!P```%2)`0`.````7(D!``X```!KB0$`&````'J)`0`$````DXD!``@`
M``"8B0$`!````*&)`0`8````IHD!``X```"_B0$``P```,Z)`0`Q````THD!
M`!`````$B@$`@````!6*`0`2````EHH!``H```"IB@$`"````+2*`0`+````
MO8H!``H```#)B@$`#````-2*`0`$````X8H!``X```#FB@$``P```/6*`0`&
M````^8H!``@`````BP$`%@````F+`0`-````((L!`!$````NBP$`&P```$"+
M`0`#````7(L!``,```!@BP$`$````&2+`0`(````=8L!``H```!^BP$`!0``
M`(F+`0`F````CXL!``@```"VBP$`!@```+^+`0`8````QHL!``X```#?BP$`
M"````.Z+`0`(````]XL!``4`````C`$`"0````:,`0`'````$(P!`!L````8
MC`$`!0```#2,`0`%````.HP!``L```!`C`$`#@```$R,`0`(````6XP!``H`
M``!DC`$`$@```&^,`0`(````@HP!``<```"+C`$`%0```).,`0`>````J8P!
M`#D```#(C`$`)0````*-`0`G````*(T!``<```!0C0$`"@```%B-`0`$````
M8XT!``D```!HC0$`"````'*-`0`0````>XT!``@```",C0$`!@```)6-`0`-
M````G(T!``8```"JC0$`!````+&-`0`^````MHT!`$````#UC0$`/@```#:.
M`0`9````=8X!``4```"/C@$`#@```)6.`0`#````I(X!``@```"HC@$`#```
M`+&.`0`A````OHX!``X```#@C@$`%P```.^.`0`%````!X\!``4````-CP$`
M'````!./`0`'````,(\!``D````XCP$`&````$*/`0`#````6X\!``0```!?
MCP$`&````&2/`0`$````?8\!``X```""CP$`#0```)&/`0`.````GX\!``@`
M``"NCP$`"0```+>/`0`%````P8\!`#8```#'CP$`+@```/Z/`0`W````+9`!
M`!T```!ED`$`0````(.0`0`U````Q)`!`"@```#ZD`$`.P```".1`0`N````
M7Y$!`"\```".D0$`'P```+Z1`0`-````WI$!``L```#LD0$`"````/B1`0`W
M`````9(!`"T````YD@$`)````&>2`0`K````C)(!``D```"XD@$`"P```,*2
M`0`*````SI(!``8```#9D@$`)````."2`0`B````!9,!`"X````HDP$`"@``
M`%>3`0`=````8I,!`",```"`DP$`%@```*23`0`0````NY,!``8```#,DP$`
M"@```-.3`0`-````WI,!`!````#LDP$`#P```/V3`0`_````#90!`'T```!-
ME`$`;@```,N4`0`7````.I4!``H```!2E0$`"P```%V5`0`3````:94!`!0`
M``!]E0$`$````)*5`0`(````HY4!`!0```"LE0$`%@```,&5`0`3````V)4!
M`!(```#LE0$`(````/^5`0`E````()8!`'\```!&E@$`$````,:6`0`&````
MUY8!`!0```#>E@$`"@```/.6`0`$````_I8!``L````#EP$`)`````^7`0`4
M````-)<!``X```!)EP$`#````%B7`0`5````99<!`!(```![EP$`)P```(Z7
M`0`E````MI<!`"4```#<EP$`(P````*8`0`K````)I@!`"D```!2F`$`&@``
M`'R8`0!"````EY@!`!(```#:F`$`$````.V8`0`4````_I@!`!(````3F0$`
M#P```":9`0`5````-ID!`!4```!,F0$`$@```&*9`0`0````=9D!`#,```"&
MF0$`%````+J9`0`7````SYD!`#L```#GF0$`%P```".:`0`&````.YH!``P`
M``!"F@$`(````$^:`0`1````<)H!`!4```""F@$`$P```)B:`0`6````K)H!
M`!0```##F@$`$@```-B:`0`4````ZYH!`!H`````FP$`$0```!N;`0`=````
M+9L!`",```!+FP$`'@```&^;`0`3````CIL!`!4```"BFP$`$0```+B;`0`6
M````RIL!`!8```#AFP$`&P```/B;`0`5````%)P!``4````JG`$`$@```#"<
M`0`;````0YP!``0```!?G`$`!@```&2<`0`#````:YP!``X```!OG`$`!@``
M`'Z<`0`(````A9P!``D```".G`$`!P```)B<`0`'````H)P!``8```"HG`$`
M!0```*^<`0`5````M9P!``8```#+G`$`!@```-*<`0`$````V9P!``0```#>
MG`$`!@```..<`0`'````ZIP!``T```#RG`$`#P````"=`0`-````$)T!``H`
M```>G0$`#P```"F=`0`%````.9T!`#$````_G0$`%@```'&=`0`.````B)T!
M`!(```"7G0$`"P```*J=`0`)````MIT!``\```#`G0$`.````-"=`0`$````
M"9X!``@````.G@$`"````!>>`0`)````()X!`!$````JG@$`!@```#R>`0`+
M````0YX!``H```!/G@$`!0```%J>`0`$````8)X!``X```!EG@$`%@```'2>
M`0`.````BYX!`!````":G@$`$````*N>`0`<````O)X!`!0```#9G@$`!P``
M`.Z>`0`#````]IX!``8```#ZG@$`%`````&?`0`'````%I\!``<````>GP$`
M$````":?`0`/````-Y\!``8```!'GP$`!@```$Z?`0`(````59\!``8```!>
MGP$`#0```&6?`0`(````<Y\!``@```!\GP$`$````(6?`0`-````EI\!``@`
M``"DGP$`$P```*V?`0`'````P9\!``P```#)GP$`"0```-:?`0`*````X)\!
M`!0```#KGP$`/@````"@`0`,````/Z`!``H```!,H`$`'````%>@`0`.````
M=*`!`!D```"#H`$`#0```)V@`0`-````JZ`!``D```"YH`$`!P```,.@`0`*
M````RZ`!``D```#6H`$`#@```."@`0`0````[Z`!`"``````H0$`'P```"&A
M`0`@````0:$!``H```!BH0$`!P```&VA`0`)````=:$!``H```!_H0$`$P``
M`(JA`0`$````GJ$!``<```"CH0$`*0```*NA`0`&````U:$!``<```#<H0$`
M#0```.2A`0!(````\J$!`!,````[H@$`"@```$^B`0`)````6J(!``,```!D
MH@$`#P```&BB`0`1````>*(!``P```"*H@$`"0```)>B`0`"````H:(!``0`
M``"DH@$`(@```*FB`0`#````S*(!``4```#0H@$`+P```-:B`0`*````!J,!
M``0````1HP$`!@```!:C`0`4````':,!`!$````RHP$`!@```$2C`0`(````
M2Z,!``H```!4HP$`!````%^C`0`%````9*,!`'````!JHP$`"@```-NC`0`-
M````YJ,!`!$```#THP$`!0````:D`0`&````#*0!`!@````3I`$`*@```"RD
M`0`-````5Z0!``H```!EI`$`%@```'"D`0`+````AZ0!``D```"3I`$`$P``
M`)VD`0`A````L:0!`!P```#3I`$`'````/"D`0`>````#:4!``X````LI0$`
M`P```#NE`0`'````/Z4!``<```!'I0$`"0```$^E`0`.````6:4!``P```!H
MI0$`!@```'6E`0!5````?*4!``\```#2I0$`"@```.*E`0`-````[:4!`!L`
M``#[I0$`5````!>F`0`:````;*8!``8```"'I@$`'0```(ZF`0`E````K*8!
M``D```#2I@$`!@```-RF`0`+````XZ8!``0```#OI@$`"0```/2F`0`<````
M_J8!`!L````;IP$`*P```#>G`0`&````8Z<!``L```!JIP$`(````':G`0!H
M````EZ<!`!(`````J`$`'P```!.H`0`3````,Z@!``,```!'J`$`#````$NH
M`0`$````6*@!``P```!=J`$`"0```&JH`0`'````=*@!``<```!\J`$`!@``
M`(2H`0`)````BZ@!``L```"5J`$`"````*&H`0`*````JJ@!``D```"UJ`$`
M-0```+^H`0`'````]:@!``P```#]J`$`"@````JI`0`6````%:D!``@````L
MJ0$`"````#6I`0`0````/JD!``D```!/J0$`!P```%FI`0`(````8:D!``<`
M``!JJ0$`"@```'*I`0`?````?:D!`!````"=J0$`#0```*ZI`0`)````O*D!
M`!@```#&J0$`"@```-^I`0`5````ZJD!``<`````J@$`%0````BJ`0`$````
M'JH!``<````CJ@$`!0```"NJ`0`%````,:H!``P````WJ@$`$P```$2J`0`1
M````6*H!`!H```!JJ@$`%@```(6J`0`4````G*H!`!<```"QJ@$`&````,FJ
M`0`<````XJH!`!@```#_J@$`!P```!BK`0`&````(*L!``T````GJP$`"P``
M`#6K`0`&````0:L!`!D```!(JP$`"P```&*K`0`+````;JL!`!X```!ZJP$`
M&````)FK`0`3````LJL!``<```#&JP$`#0```,ZK`0`%````W*L!``T```#B
MJP$`#0```/"K`0`&````_JL!``D````%K`$`!0````^L`0`'````%:P!``,`
M```=K`$`!````"&L`0`#````)JP!`#L````JK`$`-````&:L`0`6````FZP!
M`#H```"RK`$`*````.VL`0`.````%JT!`#`````EK0$`+P```%:M`0`T````
MAJT!`#0```"[K0$`.0```/"M`0`.````*JX!`!\````YK@$`#P```%FN`0`3
M````::X!`!8```!]K@$`$P```)2N`0`5````J*X!`!,```"^K@$`%0```-*N
M`0`<````Z*X!`#`````%KP$`,````#:O`0`T````9Z\!`"D```"<KP$`*@``
M`,:O`0`F````\:\!`&0````8L`$`'0```'VP`0`6````F[`!``T```"RL`$`
M&0```,"P`0`+````VK`!``\```#FL`$`-````/:P`0`H````*[$!`"$```!4
ML0$`#0```':Q`0!'````A+$!`$(```#,L0$`!0````^R`0`5````%;(!`!4`
M```KL@$`!P```$&R`0`2````2;(!`!,```!<L@$`!0```'"R`0`/````=K(!
M``@```"&L@$`$@```(^R`0`3````HK(!``\```"VL@$`$@```,:R`0`%````
MV;(!`!X```#?L@$`"````/ZR`0`#````![,!``H````+LP$`#@```!:S`0`,
M````);,!`#4````RLP$``@```&BS`0`&````:[,!``P```!RLP$`!0```'^S
M`0`'````A;,!`!$```"-LP$`!@```)^S`0`M````IK,!``\```#4LP$`(```
M`.2S`0`$````!;0!`"X````*M`$`&@```#FT`0`>````5+0!`%\```!SM`$`
M%````-.T`0`_````Z+0!`"4````HM0$`#@```$ZU`0`-````7;4!`!0```!K
MM0$`#````("U`0`,````C;4!`!0```":M0$`#````*^U`0`?````O+4!`!P`
M``#<M0$`!0```/FU`0`1````_[4!``\````1M@$`(0```"&V`0`0````0[8!
M`!0```!4M@$`$@```&FV`0`3````?+8!`!L```"0M@$`"````*RV`0`(````
MM;8!``X```"^M@$`"@```,VV`0`+````V+8!``D```#DM@$`#@```.ZV`0`)
M````_;8!``L````'MP$`&````!.W`0`(````++<!``<````UMP$`"````#VW
M`0`%````1K<!``D```!,MP$`!@```%:W`0`/````7;<!``@```!MMP$`#0``
M`':W`0`'````A+<!``\```",MP$`#P```)RW`0`B````K+<!`!<```#/MP$`
M"````.>W`0`)````\+<!`!D```#ZMP$`!@```!2X`0`8````&[@!``,````T
MN`$`%P```#BX`0`$````4+@!``<```!5N`$`%0```%VX`0`B````<[@!``L`
M``"6N`$`'0```**X`0`1````P+@!``L```#2N`$`&@```-ZX`0`(````^;@!
M``0````"N0$`!P````>Y`0`,````#[D!``<````<N0$`!0```"2Y`0`(````
M*KD!``<````SN0$`"P```#NY`0`/````1[D!`"T```!7N0$`+@```(6Y`0`>
M````M+D!`"4```#3N0$`'0```/FY`0`X````%[H!`"````!0N@$`.@```'&Z
M`0`F````K+H!`$P```#3N@$`'0```""[`0`%````/KL!``<```!$NP$`#P``
M`$R[`0`(````7+L!`!4```!ENP$`&````'N[`0`Q````E+L!`!\```#&NP$`
M$@```.:[`0`M````^;L!`#4````GO`$`!````%V\`0`5````8KP!``8```!X
MO`$`!0```'^\`0`@````A;P!``\```"FO`$`$````+:\`0`,````Q[P!``<`
M``#4O`$`$@```-R\`0`)````[[P!``T```#YO`$`$`````>]`0`9````&+T!
M`!L````RO0$`,0```$Z]`0`+````@+T!``\```",O0$`!0```)R]`0`,````
MHKT!``4```"OO0$`'````+6]`0`.````TKT!``0```#AO0$`#````.:]`0`)
M````\[T!``D```#]O0$`"P````>^`0`$````$[X!`!(````8O@$`!P```"N^
M`0`#````,[X!``P````WO@$`.P```$2^`0!+````@+X!`!D```#,O@$`!P``
M`.:^`0`A````[KX!`!D````0OP$`#P```"J_`0`.````.K\!``H```!)OP$`
M!0```%2_`0`.````6K\!`"D```!IOP$`!````)._`0`)````F+\!``T```"B
MOP$`$````+"_`0`(````P;\!`#4```#*OP$`!0````#``0`@````!L`!``L`
M```GP`$`#P```#/``0`T````0\`!`",```!XP`$`,````)S``0`P````S<`!
M`"\```#^P`$`"P```"[!`0`'````.L$!``\```!"P0$`$P```%+!`0`;````
M9L$!``H```""P0$`&P```(W!`0`3````J<$!``<```"]P0$`%````,7!`0`F
M````VL$!``4````!P@$`!0````?"`0`.````#<(!``T````<P@$`$P```"K"
M`0`%````/L(!``@```!$P@$`"0```$W"`0`-````5\(!``L```!EP@$`$```
M`''"`0`0````@L(!``<```"3P@$`!P```)O"`0`M````H\(!`"<```#1P@$`
M)0```/G"`0`%````'\,!``<````EPP$`!@```"W#`0`=````-,,!`!8```!2
MPP$`(0```&G#`0`#````B\,!``T```"/PP$`(````)W#`0`#````OL,!``8`
M``#"PP$`#0```,G#`0`#````U\,!``L```#;PP$`$P```.?#`0`*````^\,!
M`!<````&Q`$`'````![$`0`3````.\0!``4```!/Q`$`"@```%7$`0`4````
M8,0!``X```!UQ`$`#````(3$`0`#````D<0!``@```"5Q`$`"````)[$`0`3
M````I\0!`$X```"[Q`$`%@````K%`0`T````(<4!``T```!6Q0$`"0```&3%
M`0`#````;L4!``P```!RQ0$`"@```'_%`0`,````BL4!`!D```"7Q0$`#P``
M`+'%`0`.````P<4!`!D```#0Q0$`"0```.K%`0`;````],4!``X````0Q@$`
M"@```!_&`0!A````*L8!`!8```",Q@$`$````*/&`0`E````M,8!`!8```#:
MQ@$`$````/'&`0`H`````L<!`!P````KQP$`&@```$C'`0`7````8\<!``@`
M``![QP$`!P```(3'`0`'````C,<!``D```"4QP$`%0```)['`0`+````M,<!
M`"L```#`QP$`%0```.S'`0`3`````L@!``D````6R`$`!@```"#(`0!>````
M)\@!`#X```"&R`$`-0```,7(`0!@````^\@!``L```!<R0$`,0```&C)`0`D
M````FLD!``P```"_R0$`"````,S)`0`0````U<D!`#P```#FR0$``P```"/*
M`0!(````)\H!`#````!PR@$`)@```*'*`0`+````R,H!`"8```#4R@$`&@``
M`/O*`0`O````%LL!`"P```!&RP$`+P```'/+`0`L````H\L!``P```#0RP$`
M!0```-W+`0`-````X\L!``H```#QRP$`$````/S+`0`&````#<P!`"L````4
MS`$`#````$#,`0`)````3<P!``L```!7S`$`$0```&/,`0`)````=<P!``D`
M``!_S`$`&P```(G,`0`)````I<P!``D```"OS`$``P```+G,`0`'````O<P!
M``@```#%S`$`$````,[,`0`-````W\P!``H```#MS`$`%@```/C,`0`,````
M#\T!``<````<S0$`#@```"3-`0`.````,\T!``\```!"S0$`"0```%+-`0`9
M````7,T!`"4```!VS0$`$0```)S-`0`6````KLT!`"0```#%S0$`$````.K-
M`0`)````^\T!``\````%S@$`!P```!7.`0`)````'<X!`!\````GS@$`"0``
M`$?.`0`+````4<X!``D```!=S@$`!0```&?.`0`)````;<X!``@```!WS@$`
M"0```(#.`0`-````BLX!`!4```"8S@$`!@```*[.`0`.````M<X!``,```#$
MS@$`#P```,C.`0`0````V,X!`!D```#IS@$`"@````//`0`#````#L\!`!X`
M```2SP$`!````#'/`0`'````-L\!`&T````^SP$`"@```*S/`0`&````M\\!
M`"````"^SP$`+P```-_/`0`-````#]`!`!H````=T`$`.P```#C0`0`:````
M=-`!`"````"/T`$`#P```+#0`0`-````P-`!``4```#.T`$`!P```-30`0`)
M````W-`!``H```#FT`$`!P```/'0`0`)````^=`!`!0````#T0$`"P```!C1
M`0`*````)-$!``P````OT0$`#````#S1`0`%````2=$!``<```!/T0$`"0``
M`%?1`0`5````8=$!``D```!WT0$`!P```('1`0`'````B=$!`!````"1T0$`
M!@```*+1`0`5````J=$!``8```"_T0$`!@```,;1`0`.````S=$!``8```#<
MT0$`#@```./1`0`'````\M$!``4```#ZT0$`$`````#2`0`+````$=(!`!``
M```=T@$`!@```"[2`0`=````-=(!``L```!3T@$`"````%_2`0`$````:-(!
M``<```!MT@$`#0```'72`0`3````@](!``H```"7T@$`#````*+2`0`I````
MK](!`!H```#9T@$`%P```/32`0`%````#-,!``D````2TP$`#P```!S3`0`)
M````+-,!``,````VTP$`#@```#K3`0`(````2=,!`"0```!2TP$`'P```'?3
M`0`V````E],!`"$```#.TP$`)P```/#3`0`L````&-0!`'$```!%U`$`#@``
M`+?4`0!9````QM0!`#(````@U0$`5P```%/5`0!0````J]4!`"$```#\U0$`
M.@```![6`0`I````6=8!`"X```"#U@$`)P```++6`0`;````VM8!`#8```#V
MU@$`QP$``"W7`0`<````]=@!`!$````2V0$`0P```"39`0"7````:-D!`#@`
M````V@$`)````#G:`0`Y````7MH!`%\```"8V@$`6P```/C:`0`I````5-L!
M`!D```!^VP$`$P```)C;`0`L````K-L!`!D```#9VP$`%@```//;`0`J````
M"MP!`"<````UW`$`(@```%W<`0`F````@-P!`$$```"GW`$`#P```.G<`0`'
M````^=P!`#,````!W0$`)````#7=`0`H````6MT!`"````"#W0$`&P```*3=
M`0`S````P-T!`%T```#TW0$`0````%+>`0!,````D]X!`#L```#@W@$`,@``
M`!S?`0!#````3]\!`&H```"3WP$`20```/[?`0`S````2.`!`#T```!\X`$`
M.0```+K@`0!6````].`!`%D```!+X0$`10```*7A`0!&````Z^$!`#4````R
MX@$`,0```&CB`0`N````FN(!`#(```#)X@$`>P```/SB`0!P````>.,!`'D`
M``#IXP$`O@```&/D`0`5````(N4!`",````XY0$`*P```%SE`0`K````B.4!
M`$<```"TY0$`)P```/SE`0!&````).8!`"<```!KY@$`#````)/F`0"E````
MH.8!`#\```!&YP$`&````(;G`0`V````G^<!`!P```#6YP$`'0```//G`0`N
M````$>@!``8```!`Z`$`!0```$?H`0`#````3>@!``T```!1Z`$`"@```%_H
M`0`(````:N@!``L```!SZ`$`!0```'_H`0`0````A>@!``,```"6Z`$`:0``
M`)KH`0`%````!.D!`!`````*Z0$`!````!OI`0`'````(.D!``@````HZ0$`
M!0```#'I`0`_````-^D!``,```!WZ0$`$````'OI`0`-````C.D!`!(```":
MZ0$`$````*WI`0`#````OND!``@```#"Z0$`!P```,OI`0`4````T^D!``P`
M``#HZ0$`%0```/7I`0`&````"^H!`!`````2Z@$`#0```"/J`0`#````,>H!
M`#$````UZ@$`!````&?J`0`&````;.H!``<```!SZ@$`'0```'OJ`0`]````
MF>H!`"P```#7Z@$`+0````3K`0`7````,NL!`"8```!*ZP$`*0```''K`0`K
M````F^L!`"````#'ZP$`&0```.CK`0`@`````NP!`!L````C[`$`%@```#_L
M`0`@````5NP!`!H```!W[`$`&P```)+L`0`M````KNP!`!D```#<[`$`*@``
M`/;L`0`H````(>T!`!P```!*[0$`(````&?M`0`=````B.T!`!@```"F[0$`
M'P```+_M`0`B````W^T!`"(````"[@$`)````"7N`0`D````2NX!`!@```!O
M[@$`&P```(CN`0`D````I.X!`!8```#)[@$`(````.#N`0`K`````>\!`"X`
M```M[P$`$P```%SO`0`@````<.\!`#0```"1[P$`'````,;O`0`@````X^\!
M`!T````$\`$`'@```"+P`0`8````0?`!`!L```!:\`$`*````';P`0`=````
MG_`!`"D```"]\`$`'````.?P`0`V````!/$!``T````[\0$`$0```$GQ`0`9
M````6_$!`"T```!U\0$`(````*/Q`0`,````Q/$!``\```#1\0$`&@```.'Q
M`0`.````_/$!``,````+\@$`%0````_R`0`'````)?(!``8````M\@$`(0``
M`#3R`0`D````5O(!`!0```![\@$`(````)#R`0`8````L?(!``X```#*\@$`
MW````-GR`0`5````MO,!`!P```#,\P$`!P```.GS`0`*````\?,!``X```#\
M\P$`#P````OT`0`@````&_0!``8````\]`$`.0```$/T`0`8````??0!``X`
M``"6]`$`!P```*7T`0`4````K?0!``@```#"]`$`-0```,OT`0`&`````?4!
M`"$````(]0$`%0```"KU`0`3````0/4!`!,```!4]0$`.0```&CU`0`7````
MHO4!``H```"Z]0$`(````,7U`0`+````YO4!``P```#R]0$`$P```/_U`0`*
M````$_8!`!P````>]@$`!0```#OV`0`A````0?8!``D```!C]@$`&0```&WV
M`0`M````A_8!``<```"U]@$`'P```+WV`0`'````W?8!``D```#E]@$`"0``
M`._V`0`^````^?8!``<````X]P$`#P```$#W`0`1````4/<!``X```!B]P$`
M!P```''W`0`)````>?<!``<```"#]P$`%0```(OW`0`&````H?<!`!4```"H
M]P$`"@```+[W`0`3````R?<!`!8```#=]P$`"0```/3W`0`+````_O<!`!D`
M```*^`$`!````"3X`0`H````*?@!``P```!2^`$`$````%_X`0`(````</@!
M``,```!Y^`$`"@```'WX`0`F````B/@!``L```"O^`$``P```+OX`0`'````
MO_@!``@```#'^`$`"0```-#X`0`0````VO@!``T```#K^`$`%````/GX`0`5
M````#OD!``H````D^0$`+@```"_Y`0`8````7OD!`!@```!W^0$`%P```)#Y
M`0`,````J/D!`#8```"U^0$`!@```.SY`0`4````\_D!`$0````(^@$`$@``
M`$WZ`0`,````8/H!``<```!M^@$`!````'7Z`0`$````>OH!``T```!_^@$`
M%````(WZ`0`%````HOH!``8```"H^@$`!@```*_Z`0`*````MOH!``<```#!
M^@$`$0```,GZ`0`1````V_H!`#D```#M^@$`+@```"?[`0`V````5OL!``4`
M``"-^P$`&````)/[`0`9````K/L!`!\```#&^P$`'0```.;[`0`2````!/P!
M``(````7_`$`!````!K\`0`+````'_P!``4````K_`$`!0```#'\`0`"````
M-_P!``\````Z_`$`5````$K\`0`Y````G_P!`!$```#9_`$`+0```.O\`0`L
M````&?T!`&(```!&_0$`%P```*G]`0!L````P?T!`"$````N_@$`2P```%#^
M`0`D````G/X!`$H```#!_@$`.0````S_`0`K````1O\!`"\```!R_P$`+P``
M`*+_`0`P````TO\!`#$````#``(`+@```#4``@`C````9``"`#@```"(``(`
M,0```,$``@`2````\P`"`!(````&`0(`$@```!D!`@"(````+`$"``@```"U
M`0(`M````+X!`@"#````<P("`'T```#W`@(`,P```'4#`@!8````J0,"`!8`
M```"!`(`(@```!D$`@`7````/`0"``\```!4!`(`%@```&0$`@`=````>P0"
M`$$```"9!`(`&@```-L$`@`@````]@0"`%@````7!0(`%P```'`%`@`4````
MB`4"``L```"=!0(`!0```*D%`@`&````KP4"``@```"V!0(`!0```+\%`@`5
M````Q04"`!0```#;!0(`%````/`%`@`?````!08"`!,````E!@(`#@```#D&
M`@`#````2`8"``@```!,!@(`"@```%4&`@`'````8`8"``4```!H!@(`%```
M`&X&`@`'````@P8"``8```"+!@(`%0```)(&`@`-````J`8"``L```"V!@(`
M$@```,(&`@`)````U08"`!,```#?!@(`!P```/,&`@`/````^P8"`!`````+
M!P(`"````!P'`@`*````)0<"`!D````P!P(`%0```$H'`@`(````8`<"`"4`
M``!I!P(`$@```(\'`@`9````H@<"`!$```"\!P(`!P```,X'`@`3````U@<"
M``@```#J!P(``P```/,'`@`5````]P<"``D````-"`(``@```!<(`@`"````
M&@@"`!$````="`(`#0```"\(`@`)````/0@"`!,```!'"`(`%````%L(`@`'
M````<`@"`"H```!X"`(``@```*,(`@`$````I@@"`!(```"K"`(`&````+X(
M`@`)````UP@"``<```#A"`(`$0```.D(`@`'````^P@"`!X````#"0(`"```
M`"()`@`5````*PD"``T```!!"0(`$@```$\)`@`"````8@D"``<```!E"0(`
M"@```&T)`@`+````>`D"`!@```"$"0(`*@```)T)`@`-````R`D"``H```#6
M"0(`"@```.$)`@`%````[`D"``(```#R"0(`"P```/4)`@`!````TP0``!P$
M```Q!0``7P,```````"<`0``;0(``*`$````````E`,``,<!``#]!@``?```
M````````````A@(``"L'```+`0```````(,'``#!````=P4``!4$``#Q!0``
M+````-L#``##!@``)0<```@"```!!```O`4```0'```Q`P```````*8"``#P
M!0``9`(``+("```/!```@0,```````````````````````#6!```404``(4$
M`````````````/8!``!P`@````````````!_`@``+@0````````C`0``I`4`
M``````!D!P``Y`4``)$&```E`0``<@8``/4$``!N`@``<`$``#4'``#"`0``
MT0(``"\$``!O`P``4`<``%H```"B`0``,P$``(L'````````>P$``.L```"8
M!@``P`4``%X'``!*!0``S@8```````"4!```8@(``/(````I`@``9@(`````
M``#;!```A@8``-X%`````````````*4```````````````````"8`P``````
M`$````#F!@```````,T!````````G00``$@"``"_!0```````/T"``"*!P``
M``````P%````````3P0``,P%``#L`@``)@4``!<`````````-````%@```"\
M`0````````````"U`@``6@0``&4#``!J`P``7P$``(0'````````````````
M``#Z`0``9`,``&\```#6`0```````'\&````````"@<``)``````````30,`
M`)L"````````'`,``%\&``#T`0``WP```"@#``#<`0``T`$``+8#``!'`P``
M`````!T'```3!P``)0,``/$```"P!0``T@0`````````````JP,``*0`````
M````RP4``&$#``!Y`P``E00```H$````````C`8``,`!````````X00``'H'
M``#9`P``YP$```````#_!0``3`<``*D!``!8!```Y`$```````!/````O@$`
M`````````````````"\#``!N!P```````+(`````````F`4``&<$``"F!@``
MX@$``$@&````````*@```/L!``!H`0``5@<``-H#```J!@``HP0``%8&``!6
M!```L08```````"=`@``6P```)0&``"+`P``J0````````"L!0``TP```*`#
M``!Z`0``9P(``,(#```J!P``>P,``"L`````````-@``````````````,0(`
M`(,```#D!````````/8$``!Y!```1@<```````#W``````````````"3`@``
MN@4````````7!0``J@,``"L"``!\!P```````'0$```[`@````````````"0
M`@``C@$``(H$``#<````?@<``%<%``":`P```P(``#T'``!>`P``!@$`````
M``!%!````````"\'``"?`P``I0$`````````````9P4``'$!````````````
M`$0&``#;````/P<``$H``````````@(````````I`0```````%8#````````
MG`0```````#,`0``800``!8#````````)P0``&$``````````````"4$``!W
M````[@,``&@&````````G@8````&``![`````````!H&``"Q!````P````4'
M``#=!0``N08``,D#``!\`@``&`<``.P``````````````&,!````````[@(`
M`)H```"2````G@,```````";`0``*P4``'$"``#S`P``1@,``+X"``"Z`0``
MW00``-@&``"T`P``XP0``,H$``"J!````````!H'```7`@``OP0``!@!``"Q
M`@````````````#B`P``CP(```````!^`0``_@4``&D!```8!@``^`$``"H#
M``!+`P``<@,``$<$``"6`0``1P```,@!``!Q`P``4`8``#H```!B!@``4P``
M`-<&``!V`@```````"X%```F`@``=08``.T````,!@``!````.0"``!^`P``
M@P4``(D!``"3!```_@(``&8'``#G!0``%P$```````"?`0``#P<``'L"``!^
M````!00```L'```O!@``-@8```````!2`@``OP````````!W`P``_P,`````
M```+````,P4`````````````:`<``"D&``#=`````````/0"``!!!P``````
M`-@#``#:!`````````````!H````#0(``'0&````````U08``,<&``!Q````
MH````/X&``!"`@```````)L$``"Y`P``P`````0$```0!@``3`$``)0"``"Y
M!0``H`$``,$!````````!0````````!.!P``U@(``&,`````````Q```````
M`````````````/($````````0`4``'$'````````SP8````````7`P``@P8`
M````````````4@4`````````````\P0``'<$``"E!@``;P0```@```!>````
M2@<``+H#``!V!0``W@```(0#```D!```.P4``/D&``"<`P``=P(```````!J
M`0``/@(``,`&``#N!0``O@0```````!Q!@```````(D```"E`@```````#4&
M````````'@<```````!5`0``(@0``#@!````````;00```````"'`@``>04`
M`(`%``#6`````````"$"``!1!@``-P0``#,"`````````````)<#``#_!```
M`@<```<#``!K!@```````/$!``#&````\`,``(\```!=!P````````````#I
M!@``A0,`````````````W0(``"X#``!7`0``]@8```````#E`0``_@```$T`
M``#-!```$`4````````V`0``D`,``'T!``"7````600``'\$``!S````IP4`
M`%@"``""`@```````$,&``!V`0``_@$```````#G!````````"0`````````
M^`0``&L$``#&!```60$``"$$```&````GP(``%X"``````````````0&``"4
M!0```````.,&``".`P``/@```"L!```4`@``UP,``),&``!"!P```````&P#
M````````C@0``*,`````````Q0,``%$```"]`@``+`0``"`$``#I!```````
M`"X&``#V`@``,`8``%@%``````````````````"I`@``)`,`````````````
MLP$```````!]````)P,```````!T!P```````)$$````````S@$``/(&```(
M`0````````````````````$``$P%```Z!@```````,D%```1`0``7P0``/H#
M``"<````L`,``,0!````````=00``'$$``#7`@``R@4``'P!``",`0``````
M````````````_04``#4$````````0`<``*<&``#0`P``J@8``.T!``"F````
M`````.\"``````````````````"M!```ZP$``/D$``#?`P``*`0```````!F
M!```GP```!$&``"Y!```Z@,```````#)!```6P(``(P$````````Q`(``+X%
M``!"!0``=@<``-8%``"5!@```````&4'`````````````!L$````````]`,`
M`%0```#9`````````$@```"6`````````%8"```W````(08``#P"``!S`@``
M`````/,"````````"`0``+<"``"E!```>0<```````#<!@``%0````````#9
M!````````/P`````````'P4``(L%``#W`0``]P4``'P#``#:!@``M`4``)4%
M```#!0```````````````````````(,$``"_`@``S@(```X'``"9`P``_P(`
M``````#T!```/P(``%,!````````Q00``#(!````````RP(``(P`````````
M`````$L!`````````````+P&```)`0``W@$``"8$``"D`P``S04``',!```S
M!```$@8``(L$``!B`````````"\```"B!@``.`(``%D"``"!!P``20<``(T%
M```9`````````*T```#O`P``TP8``'P%```R````O04``,H"````````^`8`
M`+@&``!;!0``1`$`````````````'0(``"`'``#=!@````````X%````````
M8`$``#D"``!#`@``NP$``(`#````````*@$``$8```#0`@``%08```````!_
M````0@,``#<'```M`0``,00``.$!````````T@4``+0"``#H`0``5`,``/@#
M``!]!````````*(#``#4`@``8@,``.L%`````````````%\````?`@``,@,`
M`/P"````````<P0```````""!@``-P4``#H%```8!````````'8```"C`P``
M`````)<%``!B!0``$@(``&P!```B`0```````(X`````````:@4```````#%
M!0``&@$``.`!````````DP,``)@`````````A04``!@`````````+`4``(8$
M````````'````)L&``!J!@``^P(``(4!````````3`,``&H'``!Z!```$`0`
M`&4```!4!0``Q@8``'0"``#@``````````````"W`P``=0,`````````````
M````````````````7`$````````Z!P``?@(``&P``````````````(@"````
M````T`8```L"```/!0``;0$``"T"``#@!0``YP(``$\#```-`0``8````&<`
M````````P08``-D"``"[!@``````````````````Z@```+($```H````````
M`#$'````````\P```*H%``#]`0``U00``!H```````````````````!B!```
M`````,H&``!A!@``3@`````````3`@````````````!*!```%P8``",````_
M````@@4``*@$``"X`@``D04``.0```!"!````````+@%``!!!0``'P$``+@!
M````````FP4```````"U`````P<``"T'`````````````+`$````````:P<`
M`'L%``!F````````````````````S@0```<!``!9!@````````````#A!@``
M8@<``#L!```[!```=0(``.T&```Y!```(0<``/\&``!S!@``#`$```````!)
M!@``GP8``+P$``!G!@``"04``$<'``````````````````!S`P``BP```'L'
M``#2`P```0(``*,!```L`P```````+,$````````)@<```$#``#K`@``<```
M`&\&``#8````$P8``$4#``!?!P``\P4``.H&``#1!```/P,```````#[!0``
M9P<``*$&``#2`@```````&L!``#1````BP8``#````#(`@``H00``.P!``#B
M````:@(``*8!``!<`@```````#@#````````708``"L$``!@`P``X04`````
M``#/````E@4``-D&``!%`@````````````"5`0`````````````(!@``1@4`
M```'````````20,``&P%``!5!P``TP$``(`!````````````````````````
M`````/T$``!L!```!@0``#X#```?!```WP0```````!<`P``?@0``!$"```M
M!@``RP0``!L#````````@`8``'4````%`P``D0$```````"L``````````0"
M``!Y`0``*00``#8'````````>@```'0``````````````&(!``!4`0``#0``
M`#\!``#>`P``M@8``#D'`````````````"8```````````````````"(!0``
MCP0```````!&!````08```````"S````4`$``)(&``"R`0``%@(``%`"``"'
M`P``<`<``/4"``"V````]`8``/$#``!1`0``X@0``.\$````````T08`````
M```O`@````````T'``!0`````````%0"````````308``($"````````'08`
M``````#U!@``C08``+L```!>!@```````/D!``"$````1P8```````!U`0``
M``````````!$`@``2`$``!4#````````)`$``%D#``#U````F@4``%,%``#>
M!@``.0$``!L'````````B`$``%P%``!7!```0P<``)H"```]`P``$0,``*X%
M``!)`0```````)\$````````/@$``&H```!^!0``IP,``*D&```@````````
M`*X```!+````$@```*8$```!`0``>@8```````#5`0``N@```.0#``"V`0``
M``````````!H!`````````````"^````N0```'($````````$0```%\%``#F
M!```(`,``*L!``#F````(@(``*`&``"]`0``\@$``#L&``"$!@```````($`
M```2!```NP(``#T$``!_`0``&P```+,"````````O0,``'4%``!E`@``A0``
M``````#-`@``Q08``'\%````````5P(``)\%``#P`0``K0,```````"*!0``
M<@$``+$```"!!````````/$&````````$@<``&\"````````[0,````````0
M`@``%`$``"T#``!$!````````-4#``#?`@```````'T&``!)!0```````-L%
M``"'!````````+,&``#W`@``KP0```4"````````(0```/P%``!W`0``/`,`
M``L&``#T!0``\`(``'$%``"X`P```````-0#``#H`@``6@8```````![!```
M00,````````J`@``G`4``,8%``#:!0``804``````````````0<``'H%``!'
M`@``/````+P```````````````\#`````````````!$'```X!@``%`0`````
M````````80(```D'```S`P```````$`!```]!0```````)P&````````````
M`(<!``#)````Z0,``.4&``"]````BP$``+T$````````-@,``#4"```=!0``
M`````(@&``"N!```!P(``.L$``"_`P``````````````````200``%(&``"U
M!```<P4``,0#````````:P,``-H!``"P`0```````),%````````RP8``*(%
M````````"0,``'T#```3````#00``,4!```+!````````$$"``!5````XP4`
M``````"L`P```P,``!D$```'!@````````````#J!```[`4```H#``"H!0``
MMP0``!8```!4!```-P$``%4%``"D`@``^0(```````"``@``(P4``/L#``!#
M`0``:@0`````````````/P4``!,!````````\@,``,<$``"_!@```````$@#
M````````S0,``%T%``!\!```/@8``/D````>!0``1@$```````"K````5@$`
M`.@$``"-`````````,X#```Y!@````````````#+````AP```-T#````````
M`````,P$````````4P<````````9!0```````.<#```Q````S`,``(D%```0
M`0``#@```&P'``"G````SP0``&,'```9!@``V@```"$!``"B`@``F`(``%X$
M```M!```)`<``&4!``!X`@``%0<``!T$``#9!0``G`(``%T`````````X`0`
M`&8%``!`!@``Y@(```````"R!0````````0#```>!```````````````````
M!`4```````"3`0``AP8``'0#``"O`P``^P8```````"2!```A0(``!\&````
M````W`,```````!;`0``7`<``!0#``#Q`@``-`<``'0%``"H`P``70$``"P&
M``````````````````"P!@``X`,``$X#``#\!```.P<``'@$````````+P4`
M`&D&``#4````H`(``/D#````````*`4``(<'``#M!0``<@(````````I````
M``````8"````````#`<``.4$````````4P8`````````````*`<```(&````
M````1@(``````````````````-<!``#-````-P,```0!````````+`<``','
M``!D!@```````($%``!N`0``KP(``,0$```N`@``500`````````````````
M`(0%```3!```D0(``%@&``#2````K@,``$H&```X!P``?0<```````#0!```
M&P4```````"Z!`````````````""`0`````````````C`@``6@$````````<
M!P``,P<``"`"``"H`@``)P<````````Z!```B0(``&L```#S!@``.04``#P!
M```1!0```````.4%``"*````'`$``*L$``")`P``!@4````````B!0``70(`
M``````#J`0```````/H$````````WP$``$<%````````%`8``(@```#I`@``
M-`0``.4#``"K!0``S@4``,<#````````/P0``````````````````.H"``"A
M`P``_@,``!@%```S````]@4``'@'````````<`8```````#+`P``;P$``!X#
M``!9!0```````(8```"#`0```````+0```"/`P``A`0``#`$``"W`0``F0(`
M`*`%``"V`@``Y0(````````R!```H0```"P"``#(`P``"P,```````",!0``
M`````!P&``"L!```````````````````:P4```````#8`0````````X$```)
M!@```````"4```#A`P``G@``````````````<@4``"`&````````%0$``#X%
M```=````S`(``)X%``"*!@``C@(``"$%``"6`@```````$$&``!"!@``H0$`
M`*$%```G`@`````````````M````2P<``)4"``!2!``````````````T`@``
M^`4``'0!``!=`P``-0$```````!.!```5@4``*($```)````PP4``(,#````
M````6`$``&D"``#L`P``&0(```````#"`@``6P<``$,#```\!```D`$``.8!
M``#C`P``400`````````````K`(```X"```<`@``3@$``$@$```*````````
M`$X&``#\`0``+@```(T!````````+@<``.T"``#I`0``SP$``&P"````````
M`````-H"``##`@``)P```+,#``"2!0```````&X````0`````````(T$```;
M`0``<`0``'<'`````P``WP4``%0'``"R`P``"`<``(T#````````C0(``&<!
M``""`P``OP$``'@&``!N!```J@```$X"``!D!0```````(P#```P!P``@@0`
M``````"\`P``/@0``!@"````````-P(``)(#``""``````0`````````````
M``````\"```5`@``P@```+L#````````T@8``#`%``#N````P04```````!(
M!0``%`<``%H'```"!```7@$`````````````V0$``$L&``#Q!```;@8``#@%
M```\!P``F@$``.$```"\`@``O@,``!8$`````````````)D%``#J!0``]0,`
M``````!$!P``&0,``.P$``"5`P```@,```H&``"/!@```````&T&``!A!P``
M+@$``"<&````````9@8``&D#````````8`8``+4#```*`@``20(``!\````-
M!@``9`$`````````````3P(`````````````I@4``#(&``"Q`0``#@8``-(!
M```U!0``A@$``%P`````````/`8``.8#```:!0``NP0``*T"````````@```
M`'H#``")!@``R`4``(4&``#=`0``-0,``.\!``````````````P```"6`P``
M8P(``)X"``#R!0``````````````````9`0`````````````Z0```+8%``"C
M!@```````!X!``#!`P``/08``'`%``"$`0``:P(```````!-!```Z`8`````
M``#(!@``CP$```````##````'P<```````!C!```=0<````````-!0``/0$`
M`%$'``!M`P``(P8``$0````7!P````````````#8`@``20```#L#```7!```
M`````.\```!L!@````````H%``!3`P``!P4``"0%``"W!@``J00```<$``!'
M`0``108``````````````````"`%````````L````*\````Q!@``\`8``.,`
M````````)`8``!(#``#!!```VP8`````````````?P,```P$```8`P``K`$`
M``````"Y`0``Y`8``,X`````````D@$``(`'``#%`@```@4````````T`0``
M`````*@````L`0``#@,```````"0!```&0$``*(```!0!0```````.L&``#5
M`@``````````````````"00``)D!``";`P``J@$```P"``#5!0``]04``/4!
M```-`P```````)T!``#%`````````,8"``!7````.````"@"````````````
M`/T#``"G!```NP4```````#"!0```````$\!```=`0``[@8``/H&``"6!```
M4`0```````"M`0````````````"D`0``J04``+`"``!E!@```````-8#```6
M!0``I@,````````:`@````4```````"(!P``@@<``-$%``#C`0``K@8``.,"
M``#"!@``JP(``'`#``"0!0``KP$```````#3!0``I`8```````"U!0``````
M`,\%``!M!0```````/@"````````WP8`````````````'P,``'\'``"T!```
MJ`8```````#$!0``IP$``$,```"=`P``&P(```````!,!`````````(!``"7
M`@``3P4``$`#``![!@``W`(```````!(!P``8P4``($&``!$`P``Y0```$T%
M``#$!@```````````````````````-````!;`P``MP```'D"``!#!0``````
M`%0&``#7!0``2@(``#T````M!0```````'P&``#@`@``8`0``!H#````````
M``````````##!````````-,#``#B`@``>`,``)0```")!P``&@0`````````
M``````````````!!!```&P8`````````````4@<````````I`P``_0```%<#
M`````````````",'``!1`P``.@(``),```#S`0``50(`````````````#P8`
M``````"9!````````$(!``!?`@``2P0``$T'``!N!0``L0,```````"$`@``
M3P8````````F`0```````-L!````````L04``'('``#<!```:04``+4&```G
M!0``/@<``$4'``!*`P``:00``,\#````````:`(``*\%``"`!```=@,``-$#
M``!0`P``F`$``.$"``!,`@``P@0```````"(!```;0<``'(`````````````
M``````#Z`@```````#(%``!H`P``!P<``",#``!^!@```````.@#``"7!```
MM0$``,P&``#/`@``*`$``)<!``#+`0```````%@'``!3`@``6@,``(8%````
M````,`(``/@```"9`````````,P```"N`@``-`4```````#7`````````*4%
M```````````````````F!@``F@8``.X!```A`P``.P```)D&``!!`0``Q@,`
M`(P"```&!P``%04``&4%```````````````````B`P``B@(``!X```"%!P``
M5P<``*T%``!%````=P8``#@$``##`0``U`$``$(```!E!```*0<``&\%``#W
M!@``5@````X!``#Z!0``30(``/X$``!:`@``HP4```8&``#I!0``(@```$4%
M````````3`8``)@$``"=!@``P0(```,$`````````````+X&``!N`P``%@8`
M`.\&````````?04``.@````T`P``6@4``!(%```/`0``'@(```````!H!0``
M`````"\!```]`@``30$``#`!```E`@``U0`````````E!0``9@,``/8```!Z
M`@``D`8`````````````HP(```````"N`0``_`,``&$!``"X````D0``````
M`````````````)4````F`P``#P``````````````B@,```````!]`@``QP4`
M`,8!````````A@,``"('``">`0```````-L"``#)`0``"@$``%4#``!Y````
MU`0``,,#````````R@$``!,#``````````````````!O!P``\`0``'8$```(
M`P```````#\&``#8!````````*$"``!M````CP4``!D'````````60<``"H$
M```"````8`(``!P%````````^04``$X%````````R`````P#``"+`@``````
M`*4#```(!0```````#D#``#_`0``$`<``%T$```)`@```````$P```":!```
MT0$``"D%``#H!0```````'@`````````9@$``/````#O!0``2P(``+<%```%
M!0```````%(```#K`P``2P4``-8&```Y````R`0``)T%``#``@``8`<```,!
M``!Y!@``1`4``.`&``````````````<````V!0``*P,``/H```#)!@``%@<`
M``,&``#*````>`$``!(!``#W`P``Y@4``*P&``!3!```4@$````````&`P``
MN0(``$\'```4````D0,``*H"``!<!```UP0``#H#```P`P``]````$`$````
M````W@(``+(&````````!08``-P%``!C!@``P`,``,H#``#M!```6P0``)0!
M``"(`P``:0<``(8'`````````````!,%``".!@``I`0``#('``"*`0``0P0`
M`)L````B!@``\@(``'8&`````````````+8$````````$`,``.P&``!@!0``
M`````/L$``"6!@``X@4``"L&`````````````/<$````````N@(```````"T
M`0``1@8```````"O!@``5P8``#P%````````00```#8$````````,@(`````
M```!!0```````(X%```=`P``IP(`````````````4@,``"@&``#4!0``_`8`
M``````"H`0``8P,``!$$`````````````%4&```G`0``LP4```````#G!@``
MTP(```````"'!0``@P(``+H&``!8`P``@0$```````#N!```)`(``-0&````
M````-0```+T&``#)`@``J0,``%D`````````,0$```````#B!@``M`8```L%
M``!%`0``7`8``+@$```W!@```````%L&````````9````"4&``#'`@``````
M`)T```#_````!0$``$`"``")!```:0```-@%```@`0``G@0```````"2`@``
M%`4````````Z`0``T`4````````6`0```````'@%``#'````S08`````````
M````7@4``",$``#V`P``*@4``.<```#`!```JP8``!X&``!*`0``,P8````"
M``!G`P``W@0``#8"`````````````/L```"M!@``EP8``%$"````````-`8`
M```@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES
M*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B
M(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I
M8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES
M=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z
M("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E
M9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER
M97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN
M=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T
M:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT
M`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D
M`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S
M($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S
M(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@
M=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G
M=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE
M8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`
M/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@
M=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W
M97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!0
M87-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H
M:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@
M3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U
M<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@
M82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A
M:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T
M;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S
M97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E
M<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN
M:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN
M:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI
M87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E
M<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D
M97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0
M($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0
M(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T
M96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H
M87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S
M(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`
M07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R
M96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA
M=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&
M:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U
M<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R
M=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF
M:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M
M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T
M`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E
M<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q
M=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E
M<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!
M9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O
M(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE
M9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE
M;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE
M(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"
M86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME
M<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M
M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I
M<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"96QG
M:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C
M:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3
M971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R
M9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z
M96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R
M87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A
M<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`
M0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL
M(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`
M0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T
M('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI
M;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#
M86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L
M971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A
M;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R
M96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M
M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@
M;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@
M<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`
M0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO
M;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T
M:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM
M,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T
M:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG
M90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D
M9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L
M>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N
M;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@
M($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK
M+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#
M:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ
M`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H
M;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F
M:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E
M('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S
M97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N
M=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S
M`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`
M0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#
M;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU
M;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N
M=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I
M=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N
M9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S
M(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#
M;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE
M($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D
M+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O
M;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B
M)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A
M:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O
M=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@
M96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G
M92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T
M;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O
M=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N
M;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O
M=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A
M9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U
M;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@
M)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A
M8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`
M0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P
M=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N
M=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@
M=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD
M(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I
M;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED
M96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T
M(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`
M0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@
M<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N
M=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!3
M97-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5
M<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R
M96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX
M+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA
M;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@
M3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`
M1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E
M87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N
M=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@
M0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO
M;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T
M92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$
M96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L
M971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L
M971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R
M:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@
M4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@
M;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@
M9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O
M(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P
M;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E
M=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA
M>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O
M(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC
M86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$
M;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%
M+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE
M<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D
M:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET
M(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T
M:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M
M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L
M96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM
M=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y
M(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@
M161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I
M;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E
M<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z
M`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I
M;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%
M<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT
M96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`
M171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y
M(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E
M8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P
M;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C
M;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S
M(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&
M86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H
M36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE
M<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R
M<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(
M00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I
M;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R
M=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_
M`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S
M(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-
M971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL
M($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E
M("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M
M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS
M`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L
M90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A
M`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA
M;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE
M80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO
M;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R
M`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE
M879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP
M`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE
M($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R
M:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K
M+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)
M8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X
M=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R
M<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`
M26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E
M(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T
M97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?
M<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!)
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S
M`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO
M;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!)
M;6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L
M=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT
M97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@
M8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A
M9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS
M97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!)
M;G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS
M97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`
M26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T
M80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A
M;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`
M26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L
M:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@
M<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA
M<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI
M8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)
M<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*
M86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*
M97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R
M`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA
M:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R
M96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME
M>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE
M)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#
M+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!0
M96]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A
M<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T
M(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ
M($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE
M<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI
M96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A
M:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3
M:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES
M="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M
M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I
M8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@
M9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T
M=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@
M86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC
M('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E
M`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`
M3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%
M1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G
M87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA
M<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W
M:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R
M<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R
M:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S
M86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R
M=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN
M90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I
M<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-
M971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I
M<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H
M;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D
M(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S
M`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S
M<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`
M36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-
M;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U
M8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL
M>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN
M(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY
M($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN9'D`
M36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-
M;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S
M96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY
M(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4
M($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.
M971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P
M92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE
M='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE
M='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E
M<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E
M<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W
M('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O
M;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P
M<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R
M86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE
M(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`
M3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R
M($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!6
M1E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`
M3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@
M;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E
M<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE
M($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`
M3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@
M<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE
M("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@
M27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)
M<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E
M8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N
M`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.
M=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`
M3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A
M=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#
M<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L
M9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A
M<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY
M($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F
M9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A
M('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y
M<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A
M;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I
M;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO
M;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z
M.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y
M<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I
M;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!0
M32!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H
M96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C
M8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N
M9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L
M971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`
M4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO
M=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U
M<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N
M86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI
M;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O
M<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C
M:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N
M/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S
M96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C
M=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N
M`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!
M;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U
M<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y
M("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I
M;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W
M`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L
M;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A
M8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`
M4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S
M97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@
M0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@
M<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R
M;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E
M<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!2
M97-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S
M`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO
M;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O
M7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A
M=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E
M<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y
M<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE
M<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O
M:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!3
M86EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M
M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I
M80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I
M9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B
M+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N
M9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O
M=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`
M4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@
M=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@
M=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--
M4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E
M;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@
M879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`
M4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E
M="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P
M(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@
M>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM
M97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L
M:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O
M=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R
M:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET
M:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3
M=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A
M<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I
M;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R
M90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I
M;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3
M;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,
M871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3
M;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D
M97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T
M:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN
M9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`
M4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E
M(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D
M<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B
M)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E
M<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@
M:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B
M+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`
M4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`
M4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z
M(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M
M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W
M961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC
M`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@
M16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3
M970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA
M<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U
M<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B
M(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT
M($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H
M86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H
M92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE
M($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!0
M1U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@
M<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I
M960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H
M879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E
M;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I
M9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E
M;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W
M86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W
M("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!S<&5C:69I960@<F]W(&1O97,@
M;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E
M>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@
M=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F
M;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A
M<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@
M=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN
M9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@
M=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@
M`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L
M;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY
M('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE
M(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R
M97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@
M=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L
M9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O
M<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME
M=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T
M:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D
M87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4
M;VYG80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@
M;6EN=71E<RX`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R
M:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U
M<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``
M52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y
M('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@
M86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B
M)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN
M96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`
M56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE
M*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S
M('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W
M<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI
M<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D
M871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A
M9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@
M;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E
M;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO
M;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F
M;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5
M<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E
M:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N
M`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L
M=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X
M:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R
M;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E
M<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6
M:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I
M<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O
M9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@
M86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7
M965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E
M<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N
M(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA
M(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R
M('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI
M=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F
M9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T
M:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D
M(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7
M;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O
M9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y
M=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`
M66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@
M87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I
M=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N
M=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA
M;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T
M;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M
M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T
M:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D
M;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R
M96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N
M+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U
M<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@
M;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R
M<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI
M9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D
M(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E
M<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE
M=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO
M9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI
M<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I
M97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C
M86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T
M(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M
M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD
M`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I
M;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I
M;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN
M97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M
M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO
M=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE
M`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D
M>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA
M;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXQ+C$M8W9S"E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`V+3`S+3$Q(#$R.C,Y*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP
M,RTQ,2`Q-CHU,BLP,3`P"DQA<W0M5')A;G-L871O<CH@0G)I86X@5')U96QS
M96X@/&AO<F1E*VDQ.&Y`8G)I86YT<G5E;'-E;BYD:SX*3&%N9W5A9V4M5&5A
M;3H@1&%N:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX
M.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM
M1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3L*`"`H)7,@9&%G
M92!S:61E;BD`("A!8V-E<W-K97D@)7,I`"`H;VT@)7,@9&%G92D`("AI(&1A
M9RD`("AI(&UO<F=E;BD`("AI(&?E<BD`(&UE9"``(B5S(B!E<B!I:VME(&5T
M(&MA=&%L;V<N`"(E<R(@97(@:6YT970@9WEL9&EG="!V86QG+@`B)7,B(&5R
M(&EK:V4@:V]N9FEG=7)E<F5T(&D@2&]R9&5S(&9O<G1E9VYE;'-E+@`B)7,B
M('1RYBUO<&)Y9V=E<B!I:VME(&9U;F1E="X`(B5S(B!B;&5V('1I;&;X:F5T
M(&D@9W)U<'!E+7-Y<W1E;65T+@`B)7,B(&)L978@=&EL9OAJ970@=&EL;&%D
M96QS97,M<WES=&5M970N`"(E<R(@8FQE=B!I:VME(&1A;FYE=#H@)7,N`"4N
M,F9-0B!B<G5G="!U9"!A9B`E+C)F34(@=&EL;&%D="`H)2XR9B4E*0`E9"`E
M<R!O9R`E<P`E9"!D86=E('1I;"!D:70@:V]D96]R9"!U9&SX8F5R+@`E9"UD
M86=S('5D<VEG=``E<R`M($YO=&ET<P`E<R!F:6YG97)A9G1R>6L`)7,@2T(`
M)7,@5F5D;&EG96AO;&1E;'-E("T@0F5K<N9F=&5L<V4`)7,@;W!SYG1N:6YG
M`"5S(&]P<VMR:79N:6YG`"5S(&)R=6=S8F5T:6YG96QS97(`)7,@96MS:7-T
M97)E<B!A;&QE<F5D92X`)7,@=F5D("5S("5S`"5S(&5R('!A<F%T('1I;"!A
M="!U9&;X<F4@9&4@=F5D;&EG96AO;&1E;'-E<VAA;F1L:6YG97(L('-O;2!E
M<B!M87)K97)E="!N961E;F9O<BX@(%/F="!H86L@=60@9F]R(&1E(&AA;F1L
M:6YG97(L('-O;2!D=2#X;G-K97(@=61F^')T(&YU+@`E<R!K<N9V970`)7,@
M;6EN=71T97(`)7,@:6MK92!F=6YD970N`"5S('1I;"`E<R!A9B`E<P`E<W,@
M861R97-S96MA<G1O=&5K`"5S<R!K86QE;F1E<@`E<W,@;F]T97-B;&]K`"5S
M<R!O<&=A=F5R`"5S.B`E<P`E<SH@1&5N;F4@8F5S:V5D(&5R(&UU;&EG=FES
M(&EK:V4@9G)A(&1E;B!P97)S;VXL('-O;2!D96X@:.9V9&5R(&%T(';F<F4@
M9G)A+B`@5N9R('9A<G-O;2!M960@870@9OAL9V4@:&5N=FES;FEN9V5R(&5L
M;&5R(&9O<G-Y;F4@869S96YD97)E;B!M960@<&5R<V]N;&EG92!I;F9O<FUA
M=&EO;F5R+@`L(&1I<V5T(``L(&)LYG-E;F1E("5S("5S`"P@<VMR:69T96YD
M92!F<F$@)7,@=&EL("5S`"TM(';F;&<@+2T`,3(M=&EM97)S(&9O<FUA=``R
M-"UT:6UE<G,@9F]R;6%T`#(T('1I;65R`#Q&;W)E9^5E;F1E(&1A9P!%;B!D
M871A8F%S92UB86-K96YD(&5R(&MRYG9E="!F;W(@9&5N;F4@8FQO:RX`1&5R
M(&5R(&]P<W3E970@96X@9W)A=F5R96YD92!F96IL`$5N(&]F9F5N=&QI9R!0
M1U`M;OAG;&4@97(@:W+F=F5T(&9O<B!A="!K<GEP=&5R92!E;B!B97-K960N
M`$5N(&]F9F5N=&QI9R!01U`M;OAG;&4@97(@:W+F=F5T(&9O<B!A="!V97)I
M9FEC97)E(&5N('-I9VYE<F5T(&)E<VME9"X`16X@;V9F96YT;&EG(%!'4"UN
M^&=L92P@<')I=F%T(%!'4"UN^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V970@
M9F]R(&%T(&1E:W)Y<'1E<F4@96X@8F5S:V5D+@!%;B!O9F9E;G1L:6<@4$=0
M+6[X9VQE+"!P<FEV870@4$=0+6[X9VQE(&]G(&5T(&SX<V5N(&5R(&MRYG9E
M="P@9F]R(&%T('-I9VYE<F4@96X@8F5S:V5D+@!%;B!O9F9E;G1L:6<@4R]-
M24U%+6[X9VQE+"!P<FEV870@4R]-24U%+6[X9VQE(&]G(&5T(&SX<V5N(&5R
M(&MRYG9E="P@9F]R(&%T(&1E:W)Y<'1E<F4@96X@8F5S:V5D+@!%;B!O9F9E
M;G1L:6<@4R]-24U%+6[X9VQE+"!P97)S;VYL:6<@4R]-24U%+6[X9VQE(&]G
M(&SX<V5N(&5R(&MRYG9E="!F;W(@870@<VEG;F5R92!E;B!B97-K960N`$5N
M(&]F9F5N=&QI9R!3+TU)344M;OAG;&4@97(@:W+F=F5T(&9O<B!A="!K<GEP
M=&5R92!E;B!B97-K960N`$9O<FUI9&1A9R!3:WEE=`!&;W)M:61D86<@3&5T
M(%)E9VX`1F]R;6ED9&%G(%)E9VX`1F]R;6ED9&%G($)Y9V5R`$9O<FUI9&1A
M9R!3;F5B>6=E<@!!32]030!!4$D@240`3VT@9&5N;F4@<VMR:6)E;G0`3VTN
M+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!9&=A;F<@;N9G=&5T('9E9"!D86YN
M96QS92!A9B!61E,M:V%T86QO9RX`061G86YG(&[F9W1E="!V960@9&%N;F5L
M<V4@868@5D93+69I;"X`2V]N=&\M:6YF;W)M871I;VX`2V]N=&]E;G,@:V]D
M96]R9`!+;VYT;R!I;F1E9G)O<W-E="X`2V]N=&5R:6YG+@!4:6QF^&H`5&EL
M9OAJ('5N9&5R9W)U<'!E`%1I;&;X:B!U;F1E<F]R9&YE9&4@=&EL;&%D96QS
M90!4:6QF^&H@:&5R.@!4:6QF^&H@;GD@9W)U<'!E`%1I;&;X:B!N>2!R971T
M:6=H960`5&EL9OAJ('5N9&5R9W)U<'!E('1I;"`B)7,B`%1I;&;X:B!E;B!U
M;F1E<G)E='1I9VAE9"!T:6P@(B5S(@!/<')E='1E(&5N(&YY(&)R=6=E<CH`
M5&EL9OAJ(&MO;&]N;F4`5&EL9OAJ(&YY92!M961L96UM97(`3W!R970@<&%R
M`%1I;&;X:B`E<RUM96YU96X@<V]M(&5N($UO>FEL;&$@4VED96)A<@!4:6QF
M^&H@=&EL(&%D<F5S<V5K87)T;W1E:SH`5&EL9OAJ('1I;"!M:70@861R97-S
M96MA<G1O=&5K`$]P<F5T(&)R=6=E<@!(87(@=&EL9OAJ970@(B5S(B!T:6P@
M<WES=&5M970L(&UE;B!K=6YN92!I:VME('1I;&;X:F4@96MS=')A(&]P<VMR
M:79N:6YG<VEN9F]R;6%T:6]N.B`E<RX`5&EL9OAJ970@(B5S(B!T:6P@<WES
M=&5M970N($1U(&MA;B!L;V=G92!I;F0@;G4N`$]P<F5T=&5L<V4@868@8G)U
M9V5R92!E<B!S;.5E="!F<F$`061R97-S90!!9')E<W-E:V%R=&]T96L`061M
M:6YI<W1RZ7(@+2!I;F1S=&EL('1I;&QA9&5L<V5R(&9O<B!A;F1R92!B<G5G
M97)E`$%D;6EN:7-T<F%T:6]N`%)E:VQA;65R`$%F9VAA;FES=&%N`$%L8F%N
M:65N`$%L9V5R:65T`$MA;&1E;F%V;@!/<'-T:6QL:6YG`$IU<W1E<FEN9SH`
M06QL90!!;&QE(.9G=&5D92!B<G5G97)E`$%L;&4@9W)U<'!E<@!!;&QE('1I
M;&QA9&5L<V5R`$%L;&4@9FER92!S:61E<@!4:6QL860@;75L=&EP;&4@861R
M97-S97(`5&EL;&%D(&%N9VEV96QS92!A9B!O<F1N970@;&ES=&5T>7!E/P!%
M:W-I<W1E<F5R(&%L;&5R961E`$%L=&5R;F%T:78@24U34"UL;V=I;@!!;'1E
M<FYA=&EV($E-4U`M:V]D96]R9`!!;'1E<FYA=&EV($E-4U`M8G)U9V5R;F%V
M;@!$:6X@92UM86EL+6%D<F5S<V4`06QT97)N871I=F4@<VMA8F5L;VYE<@!!
M;'1E<FYA=&EV('1E:W-T.@!!;65R:6MA;G-K(%-A;6]A`$1E;B!VYG)D:2P@
M9&5R(&)L978@86YG:79E="P@=F%R(&EK:V4@9WEL9&EG+@!$97(@97(@;W!S
M=.5E="!E;B!U:V5N9'0@9F5J;"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM:7-E<F5N9&4@<')O>'D`0F5S=F%R`%-Y9'!O;&5N`$%N=&EG=6$@
M86YD($)A<F)U9&$`07!P;&EK871I;VX`07!P;&EK871I;VYS;&ES=&4`07!P
M;&EK871I;VX@97(@<&%R870N`%#E9OAR('5N9&5R9&5L:6YG97(`1V]D:V5N
M9`!#:7)K87-T^')R96QS90!!<')I;`!!<F%B:7-K("A7:6YD;W=S+3$R-38I
M`$%R:VEV+69I;'-T^')R96QS90!!<FMI=FYA=FX`17(@9'4@<VEK:V5R('#E
M+"!A="!D=2!V:6P@<VQE='1E(&]P<VMR:79N:6YG<V%N;6]D;FEN9V5N(&9O
M<B`E<R`_`$5R(&1U('-I:VME<BP@870@9'4@^&YS:V5R(&%T('-L971T92`B
M)7,B(&]G(&5N:'9E<B!U;F1E<F=R=7!P93\`07)G96YT:6YA`$%R;65N:65N
M`$%R;65N<VL@*$%235-#24DM."D`2W5N<W0`07)U8F$`07-C96YS:6]N^&5N
M`$%30TE)($%R=`!!<VEA=&ES:R]S=&EL;&5H879S<F5G:6]N`%-P^')G(&5F
M=&5R(&)E:W+F9G1E;'-E(&;X<B!U9&;X<F5L<V4@868@=F5D;&EG96AO;&1E
M;'-E<VAA;F1L:6YG97(_`%1I;&1E;"!K;VQO;FYE<@!&;W)S^&<@<.4@870@
M<VQE='1E(&5N(&EK:V4M96MS:7-T97)E;F1E(&=R=7!P92X`1F]R<_AG('#E
M(&%T('-L971T92!E;B!I:VME+65K<VES=&5R96YD92!T:6QL861E;'-E+@!&
M;W)S^&<@<.4@870@YFYD<F4@96X@:6MK92UE:W-I<W1E<F5N9&4@=&EL;&%D
M96QS92X`1F]R<_AG('#E(&%T(.9N9')E(&5N(&EK:V4M96MS:7-T97)E;F1E
M(&1E;&EN9RX`071T<FEB=71T97(`075G=7-T`$%U<W1R86QI96X`V'-T<FEG
M`$%U=&A?8WER<W%L.B!+<N9V970@24U!4"UU9'9I9&1E;'-E(&EK:V4@9G5N
M9&5T+@!!=71H7V-Y<G5S.B!"86-K96YD(&AA<B!I:VME(&1E(&[X9'9E;F1I
M9V4@979N97(N`$%U=&A?8WER=7,Z($MRYG9E="!)34%0+75D=FED9&5L<V4@
M:6MK92!F=6YD970N`$%U=&A?9G1P.B!+<N9V970@1E10+75D=FED9&5L<V4@
M:6MK92!F=6YD970N($]V97)SYG0@4$A0(&UE9"`M+65N86)L92UF='`M9FQA
M9V5T+@!!=71H7VEM87`Z($MRYG9E="!)34%0+75D=FED9&5L<V4@:6MK92!F
M=6YD970N`$%U=&A?:W)B-3H@2W+F=F5T($M20C4M=61V:61D96QS92!I:VME
M(&9U;F1E="X`075T:%]L9&%P.B!4:6QF^&IE;'-E(&)R=6=E<F4@97(@:6MK
M92!U;F1E<G-T^'1T970@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!3;&5T;FEN9R!A9B!B<G5G97)E(&5R(&EK:V4@=6YD97)S=/AT=&5T('9E
M9"!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@2W+F=F5T($Q$05`M=61V
M:61D96QS92!I:VME(&9U;F1E="X`075T:%]L9&%P.B!+=6YN92!I:VME('1I
M;&;X:F4@8G)U9V5R("5S+B!397)V97)E;B!S86=D93H@`$%U=&A?;&1A<#H@
M2V%N(&EK:V4@<VQE='1E(&)R=6=E<B`E<P!!=71H7VQD87`Z($MA;B!I:VME
M(&]P9&%T97)E(&)R=6=E<B`E<P!!=71H7VQD87`Z($]P9&%T97)I;F<@868@
M8G)U9V5R92!E<B!I:VME('5N9&5R<W3X='1E="!V960@06-T:79E($1I<F5C
M=&]R>2X`075T:%]M8V%L.B!+<N9V970@34-!3"UU9'9I9&1E;'-E(&EK:V4@
M9G5N9&5T+@!!=71H7W-M8F%U=&@Z($MRYG9E="!334)!551(+75D=FED9&5L
M<V4@:6MK92!F=6YD970N`,9G=&YI;F<@=F5D($E-05`M<V5R=F5R(&9E:FQE
M9&4N`,9G=&YI;F<@9F5J;&5D90#&9W1N:6YG(&9E:FQE9&4N("5S`,9G=&YI
M;F<@869V:7-T(&%F(%)!1$E54RUS97)V97(N`,9G=&YI;F<@;W9E<F9O<B!&
M5%`M<V5R=F5R(&9E:FQE9&4N`,9G=&YI;F<@;W9E<F9O<B!334(M<V5R=F5R
M(&9E:FQE9&4N`$9E;'1E<B!T:6P@<N5D:6=H960Z`$%S97)B86ED:F%N`$)/
M1D@M=6YD<VMY;&1N:6YG97(`0F%C:V=R;W5N9`!"86=G<G5N9'-F87)V90!$
MY7)L:6=T(&ME<F)E<F]S+6MO9&5O<F0N`$3E<FQI9W0@:V5R8F5R;W,M8G)U
M9V5R;F%V;BX`0F%H86UA`$)A:')A:6X`0F%L=&EK=6T@*$E33RTX.#4Y+3$S
M*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<VES(&=R869I:VMA=&%L;V<@(B5S
M(B!I:VME(&9U;F1E="X`0F%S:7-L:6YI90!(=FED97)U<VQA;F0`0F5L9VEE
M;@!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`1OAD<V5L<V1A9P!";&]K
M("(E<R(@868@87!P;&EK871I;VX@(B5S(B!I:VME(&9U;F1E="X`0FQO:RUE
M9V5N<VMA8F5R`$)L;VMT>7!E`$9E9`!";VQI=FEE;@!";V=MYG)K97(`4F%N
M9`!286UM971Y:VME;'-E.@!286YD90!";W-N:65N(&]G($AE<GIE9V]V:6YA
M`$)E9V=E`$)O='-V86YA`$)U;F0`0F]U=F5T^&5N`$)R87-I;&EE;@!"<FET
M:7-K+4EN9&EE;B!/8V5A;F]M<N5D90!"<G5N96D@1&%R=7-S86QA;0!"=6QG
M87)I96X`4'5N:W1L:7-T90!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#
M`$-23"!D:7-T<FEB=71I;VYS<W1E9&5R`$-E;&QE+65G96YS:V%B97(N+BX`
M26YI=&EA;&ES97)I;F<@868@;6ED;&5R=&ED:6=T(&QA9V5R(&EK:V4@9N9R
M9&EG9VIO<G0N`$MA;&5N9&5R`%9I;F1S=&EL;&4`2V%M8F]D:6$`0V%M97)O
M=6X`2V%N(&EK:V4@;G5L<W1I;&QE(&MO9&5O<F0@875T;VUA=&ES:SL@:V]N
M=&%K="!D:6X@861M:6YI<W1R871O<BX`2V%N(&EK:V4@<VMR:79E('1I;"!F
M:6P@(B5S(@!+86X@:6MK92!HY6YD=&5R92!E:W-T97)N92!S97-S:6]N<VCE
M;F1T86<N`$MA;B!I:VME(&9O<F)I;F1E('1I;"!)34%0('-E<G9E<BX@)7,`
M2V%N(&EK:V4@Y6)N92!F:6P@(B5S(BX`0V%N861A`$%N;G5L;&5R`$%F8G)Y
M9"!R97!O<G1E<FEN9R!A9B!P<F]B;&5M`$MA;B!I:VME('-L971T92!F:6P@
M(B5S(BX`2V%N(&EK:V4@9FEN9&4@970@;6ED;&5R=&ED:6=T(&MA=&%L;V<N
M`$MA;B!I:VME(&9O<G1SYG1T92!U9&5N("=T87)G971&:6QE)RUP87)A;65T
M<F5N+@!+86X@:6MK92!F:F5R;F4@:V%T86QO9R`B)7,B+@!+86X@:6MK92!F
M:F5R;F4L("5D(&+X<FX@96MS:7-T97)E<BX`2V%N(&EK:V4@;VUF;W)D96QE
M.R!A;G1A;&QE="!A9B!P=6YK=&5R(&%N9VEV970@=&EL(&]M9F]R9&5L:6YG
M('-V87)E<B!I:VME('1I;"!D970@;W!B979A<F5D92!A;G1A;"X`2V%N(&EK
M:V4@9&ER:6=E<F4@8F5S:V5D('1I;"!A;F=I=FYE(&YU;6UE<BX`2V%P(%9E
M<F1E`$)I;&QE9'1E:W-T`%5D8GED97(`2V%T96=O<FEE<B!O9R!-YG)K97(`
M0V%Y;6%N^&5R;F4`36]B:6P`0V5L;&4M96=E;G-K86)E<@!#96QL969O<G)I
M;F<Z`$-E;&QE+65G96YS:V%B97(`0V5L;&4M;65L;&5M<G5M.@!-;V)I;'1E
M;&5F;VX`2V5L=&ES:R`H25-/+3@X-3DM,30I`$-E;G1RZ7(`1&5N(&-E;G1R
M86QA9G)I:V%N<VME(%)E<'5B;&EK`$-E;G1R86PM975R;W#F:7-K("A)4T\M
M.#@U.2TR*0!#97)T:69I:V%T+61E=&%L:F5R`$-E<G1I9FEK870M96IE<@!#
M97)T:69I:V%T+7!O;&ET:6MK97(`5&-H860`QFYD<F4`QFYD<F4@9&ET(&MO
M9&5O<F0`2&5R(&MA;B!D=2#F;F1R92!D970@;F%V;B!O9R!D96X@861R97-S
M92P@<V]M(&%N9')E('-E<BP@;N5R(&1E(&SF<V5R(&]G('-V87)E<B!PY2!D
M:6YE(&4M;6%I;"X`2V]D96]R9'/F;F1R:6YG(&5R(&EK:V4@=6YD97)S=/AT
M=&5T(&%F(&1E;B!N=7;F<F5N9&4@;W!SYG1N:6YG+B`@2V]N=&%K="!D:6X@
M861M:6YI<W1R871O<BX`5&5G;@!(86L@;&EN:R!A9BXN+@!#:&EL90!+:6YA
M`%-I;7!L:69I8V5R970@:VEN97-I<VL@*$=",C,Q,BD`5')A9&ET:6]N96QT
M(&MI;F5S:7-K("A":6<U*0!6YFQG(&%P<&QI:V%T:6]N.@!6YFQG(&5T(&MO
M9&5O<F0`5N9L9R!E="!B<G5G97)N879N`%;F;&<@:'9O<F1A;B!D871O97(@
M<VMA;"!V:7-E<SH`5N9L9R!L:7-T92US=&EL("AF;W(@;W)D;F5D92!L:7-T
M97(I`$IU;&7X96X`2VQA<W-E9&5F:6YI=&EO;B!A9B`E<R!I:VME(&9U;F1E
M="X`2VQA<G0`1FIE<FX@35-/9F9I8V4M;W!MYG)K;FEN9V5R`$YU;'-T:6P@
M9F]R97-P^')G<V5L`%)E;G,@8G)U9V5R('5D.B`E<P!.=6QS=&EL(&)R=6=E
M<@!6:7-K(&)R=6=E<F1A=&$@=60`4V5N(&]P:VQA<FEN9P!+;&EK(&9O<B!A
M="!F;W)T<^9T=&4`0VQI8VMA=&5L;"!V:6$@2%144`!,=6L@=FEN9'5E`%-K
M>65R`%-K>65R('1I9&QI9W0`4VMY970`0V]C;W,@*$ME96QI;F<I(-AE<FYE
M`$9O;&0@<VED97!A;F5L('-A;6UE;@!386UM96YF;VQD961E(')A;F1E`$MO
M;'5M8FEE;@!&87)V90!&87)V97;F;&=E<@!&87)V979A;&<`2V]L<SH`2V]L
M;VYN971I=&QE<@!496=N97-E<FEE<@!+;VUM86YD;P!+;VUM86YD;VQI;FEE
M`$MO;6UE;G1A<@!#;VUM;VX@3F%M90!#;VUO<F5R;F4`1FER;6$`0V]M<'5T
M97)E`$9O<FAO;&0`0F5T:6YG96QS97(`2V]N9FEG=7)A=&EO;G-F;W)S:V5L
M;&4`2V]N9FEG=7)A=&EO;B!T:6P@<WEN:W)O;FES97)I;F<@;65D(%!$065R
M+"!3;6%R='!H;VYE<R!O9R!/=71L;V]K+@!+;VYF:6=U<F%T:6]N96X@97(@
M9F]RYFQD970N`$MO;F9I9W5RZ7(@)7,`0F5K<N9F="!K;V1E;W)D`$MO;F=O
M`$MO;F=O+"!$96X@9&5M;VMR871I<VME(')E<'5B;&EK`$9O<F)I;F1E;'-E
M(&UI<VQY:VME9&5S+@!&;W)B:6YD96QS92!M:7-L>6MK961E<SH@`$9O<F)I
M;F1E;'-E('1I;"!O9F9E;G1L:6<@;OAG;&5S97)V97(@;N9G=&5T+@!&;W)B
M:6YD96QS92!T:6P@;V9F96YT;&EG(&[X9VQE<V5R=F5R(&[F9W1E="X@Q7)S
M86<Z("5S("@E<RD`1F]R8FEN9&5L<V4@=&EL($944"US97)V97(@;6ES;'EK
M:V5D97,N`$MO;G1A:W1E<@!+;VYT86MT97(@8FQE=B!T:6QF^&IE="!T:6P@
M9&ET(&%D<F5S<V5K87)T;W1E:V5T`$EN9&AO;&1S='EP92!A9B!K;VUP<FEM
M97)E="!F:6PZ(`!);F1H;VQD(&%F("(E<R(`1F]R='/F=`!#;V]K($ES;&%N
M9',`4VWE:V%G90!+;W!I97(`2V]P:65R:6YG(&UI<VQY:VME9&5S.B`E<P!+
M;W!IZ7(@;6%R:V5R:6YG`$=E8GER($E$`$-O<W1A(%)I8V$`16QF96YB96YS
M:WES=&5N`$MU;FYE(&EK:V4@4$=0+6MR>7!TZ7)E(&)E<VME9#H@`$MU;FYE
M(&EK:V4@4$=0+7-I9V[I<F4@8F5S:V5D.B``2W5N;F4@:6MK92!3+TU)344M
M:W)Y<'1E<F4@8F5S:V5D+@!+=6YN92!I:VME(%,O34E-12US:6=NZ7)E(&)E
M<VME9"X`2W5N;F4@:6MK92!T:6QF^&IE(&MO;G1A:W0N("5S`$MU;FYE(&EK
M:V4@:V]B;&4@=&EL($Q$05`M<V5R=F5R+@!+=6YN92!I:VME(&MO;G1R;VQL
M97(@8F%L86YC92X@)7,`2W5N;F4@:6MK92!F;W)B:6YD92!T:6P@3$1!4"US
M97)V97(N`$MU;FYE(&EK:V4@9F]R8FEN9&4@=&EL('-E<G9E<B`B)7,B('9E
M9"!B<G5G(&%F($944#H@)7,`2W5N;F4@:6MK92!O<')E='1E(&1I<W1R:6)U
M=&EO;G-L:7-T92X@)7,`2W5N;F4@:6MK92!D96MR>7!T97)E(%!'4"UD871A
M.B``2W5N;F4@:6MK92!D96MR>7!T97)E(%,O34E-12UD871A+@!+=6YN92!I
M:VME('-L971T92!K;VYT86MT+B`E<P!+=6YN92!I:VME('-L971T92!D:7-T
M<FEB=71I;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@<VQE='1E(#QE;3YS8W)I
M<'0\+V5M/B`B)7,B('1I;"!O<&=R861E<FEN9R!A9B!O<'/F=&YI;F<N`$MU
M;FYE(&EK:V4@8F5S=&5M;64@;6]D=&%G97)E;G,@92UM86EL+6%D<F5S<V4N
M`$MU;FYE(&EK:V4@:&5N=&4@:&5L92!A9')E<W-E:V%R=&]T96LN`$MU;FYE
M(&EK:V4@:&5N=&4@:&5L92!D:7-T<FEB=71I;VYS;&ES=&4N`$MU;FYE(&EK
M:V4@:&5N=&4@9G5L9'-TYFYD:6<@9F]R=&5G;F5L<V4@;W9E<B!D:7-T<FEB
M=71I;VYS;&ES=&5R+@!+=6YN92!I:VME(&AE;G1E('-T<F%T96=I("(E<R(N
M`$MU;FYE(&EK:V4@;6MD:7(@(B5S(BX`2W5N;F4@:6MK92!H96YT92!O9F9E
M;G1L:6<@;OAG;&4@9G)A(&[X9VQE<V5R=F5R+@!+=6YN92!I:VME(.5B;F4@
M(B5S(B!F;W(@<VMR:79N:6YG+@!+=6YN92!I:VME(.5B;F4@)7,N`$MU;FYE
M(&EK:V4@Y6)N92!M;V1U;"!T:6P@=F5D;&EG96AO;&1E;'-E("5S`$MU;FYE
M(&EK:V4@Y6)N92!K871A;&]G("(E<R(N`$MU;FYE(&EK:V4@;N4@3$1!4"US
M97)V97)E;BX`2W5N;F4@:6MK92!LYG-E("5S+@!+=6YN92!I:VME(&YU;'-T
M:6QL92!K;V1E;W)D970@9F]R(&1E;B!A;FUO9&5D92!B<G5G97(N("!.;V=L
M92!E;&QE<B!A;&QE(&1E=&%L:F5R(&5R('5K;W)R96MT92X@4'+X=B!I9V5N
M(&5L;&5R(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(L(&AV:7,@9'4@:&%R
M(&)E:&]V(&9O<B!Y9&5R;&EG97)E(&AJYFQP+@!+=6YN92!I:VME(&AE;G1E
M($%#3`!+=6YN92!I:VME(&AE;G1E(&%D<F5S<V5K87)T;W1E:V5T+B`E<P!+
M=6YN92!I:VME(&AE;G1E(&1I<W1R:6)U=&EO;G-L:7-T92X@)7,`2W5N;F4@
M:6MK92!H96YT92!D:7-T<FEB=71I;VYS;&ES=&5R+B`E<P!+=6YN92!I:VME
M(&AE;G1E('-E<G9E<G,@979N97(`2W5N;F4@:6MK92!G96YD86YN92!K;VYF
M:6=U<F%T:6]N+@!+=6YN92!I:VME(')M9&ER("(E<R(N`$MU;FYE(&EK:V4@
M9V5M;64@)7,M:V]N9FEG=7)A=&EO;@!+=6YN92!I:VME(&=E;6UE(&5N(&)A
M8VMU<"UK;VYF:6=U<F%T:6]N+@!+=6YN92!I:VME(&=E;6UE(&5N(&)A8VMU
M<"UK;VYF:6=U<F%T:6]N.B`E<P!+=6YN92!I:VME(&=E;6UE('-C<FEP="!T
M:6P@;W!G<F%D97)I;F<@868@;W!SYG1N:6YG('1I;#H@(B5S(BX`2W5N;F4@
M:6MK92!G96UM92!B86-K=7`M:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RX`2W5N
M;F4@:6MK92!G96UM92!K;VYF:6=U<F%T:6]N<V9I;&5N("5S+B!$=2!K86X@
M96YT96X@86YV96YD92!E;B!A9B!M=6QI9VAE9&5R;F4@9F]R(&%T(&=E;6UE
M(&MO9&5N('1I;&)A9V4@<.4@)7,@96QL97(@;6%N=65L="!K;W!I97)E(&MO
M9&5N(&YE9&5N9F]R('1I;"`E<RX`2W5N;F4@:6MK92!S^&=E($Q$05`M<V5R
M=F5R96XN`$MU;FYE(&EK:V4@/&5M/G5N;&EN:SPO96T^("(E<R(N`$MU;FYE
M(&EK:V4@;W!D871E<F4@:V]N=&%K="X@)7,`2W5N;F4@:6MK92!O<&1A=&5R
M92!D:7-T<FEB=71I;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@<VMR:79E(&MO
M;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$MU;FYE(&EK:V4@9FEN9&4@36]Z
M:6QL82!3:61E8F%R+B!&;W)V:7,@9&EG(&]M(&%T('-I9&5B87)E;B!E<B#E
M8F5N+@!+=6YN92!I:VME(&=I=F4@8G)U9V5R("(E<R(@9OAL9V5N9&4@<F5T
M=&EG:&5D97(@=&EL(&UA<'!E;B`B)7,B.B`E<P!/<'1A;'0@=&5K<W0`3&%N
M9`!+=7)S97(`3W!R970`3W!R970@96X@:&5N=FES;FEN9P!/<')E="!E;B!N
M>0!/<')E="!U;F1E<FUA<'!E`%-K86)E<G,@<F5T=&EG:&5D97(`2W)E9&ET
M:V]R="UN=6UM97(`2W)O871I96X`0W5B80!.=7;F<F5N9&4@-"!F87-E<@!)
M;F1E=N9R96YD92!S97-S:6]N`$%K='5E;"!T:60`3G5VYG)E;F1E(%523"!E
M<@!.=7;F<F5N9&4@8G)U9V5R90!!:W1U96QT('9E:G(`3G5VYG)E;F1E('9E
M:G(Z(`!!:W1U96P@<W1I;`!4:6QP87,@;W!G879E<BP@9&5R(&)L:79E<B!U
M9&;X<G0L(&[E<B!D=2!L;V=G97(@:6YD(&D@)7,N`$ML:7``2VQI<"!V86QG
M`$-Y<&5R;@!+>7)I;&QI<VL@*$M/23@M4BD`2WER:6QL:7-K("A7:6YD;W=S
M+3$R-3$I`$MY<FEL;&ES:R]5:W)A:6YS:R`H2T])."U5*0!4:F5K:VEE=`!$
M1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A9VQI9P!$871A5')E
M92!S=&EF:6YD97(`1&%T86)A<V4M;W!S;&%G`$1A=&\`36]D=&%G96QS97-D
M871O`$1A=&]V86QG`$1A9P!3;&5T(&MO;&]N;F4`1&5C96UB97(`1&5C:6UA
M;'1A;`!-:6YD<VL@:6YD<GEK;FEN9P!3=&%N9&%R9`!3=&%N9&%R9&9A<G9E
M`%-T86YD87)D+6ED96YT:71E=`!3=&%N9&%R9"US:V%L`$1E9FEN:71I;VYE
M<@!3;&5T`%-L970@8V5L;&4`4VQE="!G<G5P<&4`4VQE="!L;V=B;V<`4VQE
M="!T:6QL861E;'-E<@!&:F5R;B!O9R!U9'-L970@8F5S:V5D97(`4VQE="!C
M96QL90!3;&5T(&MO;&]N;F4`4VQE="!E:W-I<W1E<F5N9&4L(&%L=&5R;F%T
M:79E('-K86)E;&]N`%-L970@8F5S:V5D97(`4VQE="!T:6QL861E;'-E<B!F
M;W(@(B5S(@!3;&5T('1I;&QA9&5L<V5R(&9O<B`B)7,B(&]G(&%L;&4@=6YD
M97)O<F1N961E('1I;&QA9&5L<V5R/P!3;&5T('+F:VME`%-L970@=F%L9W1E
M(&ED96YT:71E=`!3;&5T('5N9&5R;6%P<&5R`%-L970@9&5N(&%K='5E;&QE
M(&MO;&]N;F4`4VQE="!D96X@86MT=65L;&4@<N9K:V4`3W!G<F%D97)I;F=S
M<V-R:7!T("(E<R(@<VQE='1E="X`3&5V97)I;F=S=&ED<W!U;FMT`$1A;FUA
M<FL`0F5S:W)I=B!P<F]B;&5M970`0F5S:W)I=F5L<V4`1&5T86QJ97(@*&]G
M<^4@:2!(;W)D92=S(&QO9V9I;"DZ`$1E=&%L:F5R(&5R('-K<F5V970@=&EL
M(&QO9V)O9V5N(&%F(&AE;G-Y;B!T:6P@861M:6YI<W1R871O<F5N+@!59'9I
M:VQI;F<`1'5G<'5N:W0`1'5G<'5N:W0@9F]R('-I9'-T92!T:6UE.B``1'5G
M<'5N:W0Z(`!2971N:6YG('9E;G-T<F4@=&EL(&CX:G)E`%)E=&YI;F<@:/AJ
M<F4@=&EL('9E;G-T<F4`2V%T86QO9P!6:7,@=&ED(&UE9"`R-"!T:6UE<C\`
M26YD<W1I;&QI;F=E<B!F;W(@=FES;FEN9P!6:7,@=61D>6)E;F1E('9E:G)U
M9'-I9W0`5FES('9E:G)U9'-I9W0@*%1!1BD`5FES;FEN9W-F;W)M870`3W9E
M<F1R86=E;'-E<VYO=&ET<P!$:FEB;W5T:0!&;W)T<GED('-L971N:6YG`$1U
M(&WE(&EK:V4@:V%L9&4@;6%I;G1E;F%N8V4N<&AP(&1I<F5K=&4`26YD96AO
M;&1E<B!D96X@9OAR<W1E('+F:VME(&9E;'1N879N93\@2'9I<R!J82P@;6%R
M:^ER(&1E;FYE(&)O:W,Z`$1E;B!D;VUI;FEK86YS:V4@4F5P=6)L:6L`1&5N
M(&1O;6EN:6MA;G-K92!297!U8FQI:P!(87(@9'4@:6MK92!N;V=E;B!K;VYT
M;S\@365L9"!D:6<@=&EL+@!(96YT`$AE;G0@)7,`2&5N="!G96YE<F5R970@
M:V]N9FEG=7)A=&EO;B!N960@<V]M(%!(4"US8W)I<'0N`%)U;&QE9V%R9&EN
M+6QI<W1E`$UE9&EK86UE;G1E<@!%+6UA:6P`14UA:6PM=&EL+5--4R!G871E
M=V%Y+61R:79E<BP@9F]R(&]P97)A=/AR97(L('-O;2!U9&)Y9&5R(&1E;FYE
M('-E<G9I8V4N`$524@!%<75A9&]R`%)E9&EG97(`QFYD<F4@8FQO:P#&;F1R
M92!G<G5P<&4`QFYD<F4@=&EL;&%D96QS90#&;F1R92!T:6QL861E;'-E<@#&
M;F1R92!T:6QL861E;'-E<B!F;W(@)7,`QFYD<F4@=F%L9R!F;W(Z`,9N9')E
M('1I;&QA9&5L<V5R(&9O<B`B)7,B`,9N9')E('1I;&QA9&5L<V5R(&9O<B`E
M<P!59&1A;FYE;'-E`,9G>7!T96X`16P@4V%L=F%D;W(`16QE;65N="XN+@!%
M;0!E36%I;`!E+6UA:6PM861R97-S90!%+6UA:6PM861R97-S97(@<VMA;"!P
M87-S92X`12UM86EL(&UE9"!B96MRYF9T96QS90!%;6%I;"UT;RU335,@1V%T
M97=A>0!3;6EL97ES`%1O;2!B97-K960N`$EN=&5T(')E<W5L=&%T+@!4;VUT
M('5D=')Y:P!!:W1I=NER(&EN9'/F='1E;'-E(&%F(&)I;&QE9&5R(&9R82!&
M;W1O9V%L;&5R:65R(&D@=&5K<W0_`$%K=&EVZ7(@:/AJ<F4M:VQI:R!C;VYT
M97AT+6UE;G4_`%-L=70MY7(`1F]R<W3X<B!E9&ET97)I;F=S=N9R:W3X:@!)
M;F1T87-T(&5T('-I:VME<FAE9'-S</AR9W-MY6PL('-O;2!D=2!V:6P@8FQI
M=F4@<W!U<F=T+"!NY7(@9'4@:&%R(&)R=6<@9F]R(&%T(.9N9')E(&1I="!K
M;V1E;W)D+"!F>"`G:'9A9"!E<B!D:70@:^9L961Y<G,@;F%V;C\G.@!);F1T
M87-T(%523"!T:6P@8FEL;&5D(&AE<@!);F1T87-T(&)O9W-T879E<B!N961E
M;F9O<CH`QFMV871O<FEA;"!'=6EN96$`QG)I=')E80!&96IL`$9E:FP@=F5D
M(&1A;FYE;'-E(&%F(&)L;VLZ("5S`$9E:FP@=6YD97(@<VQE=&YI;F<@868@
M<WEN8RUHYF=T93H@)7,`1F5J;"!U;F1E<B!S;&5T;FEN9R!A9B!S>6YC(&QO
M9SH@)7,`1F5J;"!U;F1E<B!H96YT;FEN9R!A9B!I;F1H;VQD.B`E<P!&96IL
M('5N9&5R(&]P9&%T97)I;F<@868@:V]D96]R9#H@)7,`1F5J;"!F;W)B=6YD
M970@;65D(&4M<&]S="!B97-K960N`$9E:FP@=6YD97(@<VMR:79N:6YG(&%F
M("(E<R(N`$5S=&QA;F0`QG1I;W!I96X`171N:7-K`$5U<F]P80!(=F5R(&MV
M87)T97(`2'9E<G0@,BX@;6EN=70`2'9E<B!H86QV92!M:6YU=`!(=F5R(#4N
M(&UI;G5T`$%L=&ED('9E9"!L;V=I;@!(=F5R(&AA;'9E('1I;64`2'9E<B!M
M:6YU=`!%:W-E;7!E;';F<F1I97(Z`%5D9OAR`%5D=FED`$9O;&0@<VED97!A
M;F5L('5D`$9O<G9E;G1E9&4@)RDG`$9O<G9E;G1E9&4@<F5N="!O<F0@96QL
M97(@8VET97)E="!S^&=E=&5R;0!&;W+F;&1E;'-E<V1A=&\`16MS<&]N96YT
M`$9'+69A<G9E`$944"UL86=R:6YG(&%F(&]P<^9T;FEN9P!+=6YN92!I:VME
M(.9N9')E(&EN9'-T:6QL:6YG97)N92X`2W5N;F4@:6MK92!FY2!F;W)B:6YD
M96QS92!T:6P@3$1!4"!S97)V97)E;BX`2W5N;F4@:6MK92!F;W)B:6YD92!T
M:6P@4TU"+7-E<G9E<BX`1F5J;"!U;F1E<B!K;W!I97)I;F<@9G)A("(E<R(N
M`$MU;FYE(&EK:V4@:V]P:65R92!T:6P@(B5S(BX`2W5N;F4@:6MK92!E=&%B
M;&5R92!N>2!305-,+69O<F)I;F1E;'-E+@!+=6YN92!I:VME(&9L>71T92!T
M:6P@(B5S(BX`2W5N;F4@:6MK92!H96YT93H@)7,`4VUU:W0`1F%L:VQA;F1S
M^&5R;F4@*$UA;'9I;F%S*0!&YG+X97)N90!$^&1E;&EG(&9E:FPZ`$9A>`!&
M86MS:6UI;&5R`$9E8G)U87(`1OAL97,`1OAL97,Z(`!&Y2!B>6=E<@!&Y2!S
M;F5B>6=E<@!&96QT;6%T<FEC90!&:6=L970@0T%05$-(00!&:6=L970@<VMR
M:69T<W1Y<&]G<F%F:0!&:6II`$9I;`!!;G1A;"!F:6QE<CH@)7,@9FEL`$%N
M=&%L(&9I;&5R.B`E<R!F:6QE<@!&:6QHY6YD=&5R:6YG`$9I;&YA=FX`1FEL
M=F%L9P!&:6QL86=R:6YG`$9I;&QA9W)I;F<@:6MK92!U;F1E<G-T^'1T970N
M`$9I;'1R90!&:6YL86YD`$;X<G-T92!H86QV9&5L`$;X<G-T92!K=F%R=&%L
M`$9I:W/I<B!S=/AR<F5L<V5S9F]R:&]L9`!&;&EP`$9L>61E;F1E`%3E9V4`
M36%P<&4@)7,@96MS:7-T97)E<B!I:VME`%1Y<&]G<F%F:69A<G9E`$UA9`!&
M;W(@=V5B<')O9W)A;6UE<BP@<V]M(&EK:V4@=6YD97)S=/AT=&5R(&)I;&QE
M9&5R`%9E:G)U9'-I9W0@*%1!1BD`561S:6=T<V1A9V4@*&)E;>9R:R!A="!D
M96X@<F5T=7)N97)E('9E:G)U9'-I9W0@=F5D<OAR97(@8N5D92!D86<@;V<@
M;F%T.R!E="!S=&]R="!A;G1A;"!H97(@:V%N(')E<W5L=&5R92!I(&5N(&UE
M9V5T(&)R960@8FQO:RD`1VQE;70@9&ET(&MO9&5O<F0_`$9O<FUU;&%R97(`
M3W)D<W!R;V<`17!I9W)A;71Y<&4`17!I9W)A;6UE<@!%<&EG<F%M;65R(#(`
M1F]R80!6:61E<F5S96YD96QS90!&<F4`4F%M;65R`$9R86YK<FEG`$9R86YK
M<FEG+"!-971R;W!O;&ET86X`1G)A;G-K($=U>6%N80!&<F%N<VL@4&]L>6YE
M<VEE;@!&<F%N<VME('-Y9&QI9V4@5&5R<FET;W)I97(`1G)A`$9R80!&=6QD
M(&)E<VMR:79E;'-E`$9U;&1MY6YE`$9U;&1T(&YA=FX`1V%B;VX`1V%L;&5R
M:2!H=F]R9G)A(&)I;&QE9&4@<VMA;"!T86=E<R!F<F$`1V%L;&5R:3H`1V%M
M8FEA`$=E;F5RZ7(@)7,M:V]N9FEG=7)A=&EO;@!'96YE<F5R970@:V]D90!'
M96]R9VEE;@!4>7-K;&%N9`!':&%N80!':6)R86QT87(`1F]R;F%V;@!'<G5N
M9&SF9V=E;F1E(&EN9'-T:6QL:6YG97(`561F^'(`1_9D96P`1V]O9VQE($UA
M<',`1V]O9VQE+7/X9VYI;F<`1W+E=&]N97(`1W+F:V5N;&%N9`!'<N9S:R`H
M25-/+3@X-3DM-RD`1W+X;FQA;F0`1W)E;F%D80!'<G5P<&4M861M:6YI<W1R
M871I;VX`1W)U<'!E;F%V;F4@;>4@:6MK92!VYG)E('1O;6UE`$=R;W5P7VQD
M87`Z($MA;B!I:VME('1I;&;X:F4@9W)U<'!E("5S+B!397)V97)E;B!M96QD
M97(Z(`!'<F]U<%]L9&%P.B!+86X@:6MK92!S;&5T=&4@9W)U<'!E("5S`$=R
M;W5P7VQD87`Z($MA;B!I:VME(&]P9&%T97)E(&=R=7!P92`E<P!'<G5P<&5R
M`$=U861E;&]U<&4`1W5A;0!'=6%T86UA;&$`1W5E<FYS97D`1^9S=&5T:6QL
M861E;'-E<@!'YG-T96)O9P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`
M2%1-3`!(5$U,07)E82!NYF=T97(@<.4@9F5J('9I<R!A="!S;&5T=&4@9&5N
M('-I9'-T92!C96QL92!I('+F:VME+@!(5$U,07)E82!NYF=T97(@<.4@9F5J
M('9I<R!A="!S;&5T=&4@9&5N('-I9'-T92!K;VQO;FYE(&D@=&%B96PN`$A4
M34Q!<F5A(&[F9W1E<B!PY2!F96H@=FES(&%T('-L971T92!D96X@<VED<W1E
M('+F:VME(&D@=&%B96PN`$A45%`MYF=T;FEN9R!I:VME(&9U;F1E="X`2&'O
M=&D`2&%S:"UA;&=O<FET;64`1&ES`%1O<'1E:W-T`$]V97)S:W)I9G1E<@!(
M96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2W)A9G1I9R!T;W)D
M96X`2&5B<F%I<VL@*$E33RTX.#4Y+3@M22D`2/AJ9&4`2&KF;'``2&KF;'`@
M=&EL(')E9&EG97)I;F=S=N9R:W3X:@!(:N9L<&5R`$AE;6ES9N9R90!(97(@
M97(@<W1A<G1E;B!A9B!F:6QE;CH`2/AJ`$AJ96T`2&5L;&EG<_@@*%9A=&EK
M86YS=&%T96XI`$AJ96T`4')I=F%T+6%D<F5S<V4`2&IE;6UE:V%T86QO9P!0
M<FEV870M=&5L969O;@!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O
M2V]L86(Z(%5G>6QD:6<@)7,@6$U,(&1A=&$@<.5T<G5F9F5T(&D@8F5S:V5D
M("5S`$AO<F1E+TMO;&%B.B!);F=E;B!B97-K960@<W9A<F5R('1I;"!O8FIE
M:W0@)7,`2&]R9&4O2V]L86(Z($EN=&5T(&]B:F5K="!A9B!T>7!E("5S(&9U
M;F1E="!I(&)E<VME9"`E<P!(;W)D92]+;VQA8CH@4VQE='1E9&4@)7,@(B5S
M(@!(;W)D92]+;VQA8CH@26YT96=R871I;VYS;6%S:VEN96X@:W+F=F5R(%!(
M4"UU9'9I9&1E;'-E("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!+86X@:6MK92!D
M86YN92!N>70@6$U,+71RYB!F;W(@;V)J96MT("5S`$AO<F1E+TMO;&%B.B!+
M86X@:6MK92!S;&5T=&4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($MA;B!I
M:VME(&EN9&AE;G1E($U)344M240@9F]R(&1E;&5N(&%F('1Y<&4@)7,`2&]R
M9&4O2V]L86(Z($MA;B!I:VME('-Y;FMR;VYI<V5R92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@2V%N(&EK:V4@<WEN:W)O;FES97)E(&1E;&EN9V5R.B`E
M<P!(;W)D92]+;VQA8CH@56ME;F1T(&1E;&EN9R`B)7,B`%9A;F1R970@<W1R
M96<`5F%N9')E="!F;W(`5F%N9')E=#H`2'9O<F1A;B!B87(@9'4@9&EG(&%D
M(&UE9"!A="!H879N92!H97(_("A);F1R87!P;W)TZ7(A*0!(=F]R(&UA;F=E
M(&MO;&]N;F5R(/AN<VME<B!D=2!A="!S86UM96YLYF=G93\`2'9O<B!M86YG
M92!F96QT97(@*&MO;&]N;F5R*2!E<B!D97(_`$AV;W(@;6%N9V4@<N9K:V5R
M(/AN<VME<B!D=2!A="!S86UM96YLYF=G93\`1G5G=&EG:&5D`$9U9W1I9VAE
M9#H@`$AU;6]R:7-T97(`56YG87)N`$]P<F5T=&5L<V4@868@24U!4"UM87!P
M92!F96IL961E.B`E<P!3;&5T;FEN9R!A9B!)34%0+6UA<'!E(&9E:FQE9&4Z
M("5S`$1E9FEN97)I;F<@868@:W9O=&4@9F]R($E-05`M;6%P<&4@9F5J;&5D
M93H@)7,`25`M861R97-S90!)4"UA9')E<W-E(&EK:V4@=&EL9^9N9V5L:6=E
M+@!)4"UA9')E<W-E(&EK:V4@:6YD96YF;W(@0TE$4BUB;&]K+@!)4"!L;V-K
M9&]W;B!V:6]L871I;VXN`$EN9'/F="!RYFMK92!F^'(`27-L86YD`$MU;B!I
M:V]N97(`26MO;F5R(&9O<B`E<P!):V]N97(@;65D('1E:W-T`$ED96YT:71E
M='-N879N.@!(=FES(&1E;B!I:VME('9I<W0@:V]R<F5K="P@)7,@9F]R(&%T
M(.5B;F4@9&5N(&D@970@;GET('9I;F1U92X`2'9I<R!D=2!I:VME('-E<B!N
M;V=E;B!I:V]N97(@=F5D(&)R=6<@868@26YT97)N970@17AP;&]R97(@<VMA
M;"!D=2!MY7-K92!H86MK92!D96YN92!B;VMS(&%F(&9O<B!A="!S;.4@4$Y'
M+71R86YS<&%R96YS(&9R82X`2'9I<R!D=2!S97(@9&5N;F4@8F5S:V5D(&D@
M<W1E9&5T(&9O<B!E="!B:6QL961E+"!SY2!V:6P@9'4@:6MK92!K=6YN92!S
M92!D970@:2!D:6X@;F5T+6SF<V5R(&5F=&5R(&]P;.9G;FEN9RX`0FEL;&5D
M+69O<FCE;F1S=FES;FEN9SH`0FEL;&5D+5523`!":6QL960M55),.@!":6QL
M961E(&9R82!G86QL97)I`$)I;&QE9&4@9G)A(&=A;&QE<FDZ`$)I;&QE9"UO
M<&SF9VYI;F<`0FEL;&5D97(`26UP;W)T97)I;F<L('1R:6X@)60`26UP;W)T
M97)E9&4@9F5L=&5R.B`E<P!);7!O<G1E<F5D92!F96QT97(Z`$EN9'/F="!R
MYFMK92!E9G1E<@!&96IL86=T:6<@:&%N9&QI;F=S:V]D92!A;F=I=F5T+@!5
M:V]R<F5K="!B<G5G97)N879N(&]G+V5L;&5R(&MO9&5O<F0N`%5K;W)R96MT
M(&)R=6=E<FYA=FX@96QL97(@86QT97)N871I=B!A9')E<W-E+B!0<OAV(&EG
M96X@96QL97(@:V]N=&%K="!D:6X@861M:6YI<W1R871O<BP@:'9I<R!D=2!H
M87(@8G)U9R!F;W(@>61E<FQI9V5R92!H:N9L<"X`1F]R^&<@:6YD<GEK;FEN
M9P!);F1I96X`26YD:79I9'5E;&QE(&)R=6=E<F4`26YD;VYE<VEE;@!);F9O
M`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&EK:V4@;.9N9V5R92!T:6QGYFYG
M96QI9P!);F1SYG0@:V]L;VYN92!E9G1E<@!);F1SYG0@8FEL;&5D90!);F1S
MYG0@=&%B96P`26YD<^9T('=E8BUH96YV:7-N:6YG`$EN9'/F="!K;VQO;FYE
M(&;X<@!);F1SYG0@96X@;GD@:V]L;VYN92!E9G1E<B!D96X@86MT=65L;&4`
M26YD<^9T(&5N(&YY(&MO;&]N;F4@9OAR(&1E;B!A:W1U96QL90!);F1SYG0@
M96X@;GD@<N9K:V4@969T97(@9&5N(&%K='5E;&QE`$EN9'/F="!E;B!N>2!R
MYFMK92!F^'(@9&5N(&%K='5E;&QE`$EN9'/F="!E;B!P87)A9W)A9B!E9G1E
M<B!D970@86MT=65L;&4@<'5N:W0`26YD<^9T(&5N('!A<F%G<F%F(&;X<B!D
M970@86MT=65L;&4@<'5N:W0`26YD<^9T(&%L=&5R;F%T:78@<VMA8F5L;VX`
M26YD=&%S="!E;B!E+6UA:6PM861R97-S92P@:'9O<G1I;"!D=2!K86X@;6]D
M=&%G92!D970@;GEE(&MO9&5O<F0Z`$EN9'/F="!C96QL92!E9G1E<@!);F1S
MYG0@8V5L;&4@9OAR`$EN9'/F="!K;VQO;FYE(&5F=&5R`$EN9'/F="!K;VQO
M;FYE(&;X<@!);F1SYG0@8F5S:V5D97(`26YD<^9T('!A<F%G<F%F(&5F=&5R
M`$EN9'/F="!P87)A9W)A9B!E9G1E<@!);F1SYG0@<N9K:V4@969T97(`26YD
M<^9T('+F:VME(&;X<@!);F1T87-T(&1E="!K<N9V961E('-V87(@=&EL('-I
M:VME<FAE9'-S</AR9W-MY6QE=#H`26YD<^9T+^9N9')E(&)I;&QE9&4`26YD
M<^9T+^9N9')E(&AE;G9I<VYI;F<`571I;'-T<N9K:V5L:6<@:W)E9&ET('1I
M;"!A="!S96YD92!T:6P@9&ES=')I8G5T:6]N<VQI<W1E;BX`571I;'-T<N9K
M:V5L:6=E(&MR961I="X`2&5L=&%L`$AE;'1A;'-L:7-T90!59WEL9&EG(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+@!59WEL9&EG92!:25`M9&%T80!59WEL
M9&EG="!A<'!L:6MA=&EO;BX`56=Y;&1I9W0@<VMR:7!T+4E$+@!59WEL9&EG
M92!D871A(&%F<V5N9'0N`%5G>6QD:6<@9&5S=&EN871I;VXN`%5G>6QD:6=T
M(&9I;&9O<FUA=`!59WEL9&EG(&QI8V5N<V[X9VQE+@!59WEL9&EG('!L86-E
M<FEN9R!A;F=I=F5T+@!59WEL9&EG(&US9U]T>7!E+@!59WEL9&EG(&5L;&5R
M(&UA;F=L96X@87!I7VED+@!59WEL9&EG92!E;&QE<B!M86YG;&5N9&4@<&%R
M86UE=')E+@!59WEL9&EG92!F;W+F;&1R92UT:6QL861E;'-E<BX`56=Y;&1I
M9R!P87)T;F5R+6ED+@!59WEL9&EG('!R;V1U:W0M:V]D92X`56=Y;&1I9R!P
M<F]T;VMO;"X`56=Y;&1I9R!M;V1T86=E<CH@(B5S(@!59WEL9&EG="!D96QI
M;F=S;V)J96MT`%5G>6QD:6<@;W!R:6YD96QS97-A9')E<W-E+@!59WEL9&EG
M('5N:6-O9&4M9&%T82X`26YD8F\`26YV97)TZ7(@;6%R:V5R:6YG`$ER86XL
M($1E;B!I<VQA;6ES:R!R97!U8FQI:P!)<F%K`$ER;&%N9`!-86X`4W1E9'9I
M<R!T;W)D96X`27-R865L`%5D<W1E9&5R`$ET86QI96YS:P!)=&%L:65N`$IA
M;6%I8V$`2F%N=6%R`$IA<&%N`$IA<&%N<VL@*$E33RTR,#(R+4I0*0!*97)S
M97D`2F]R9&5N`$IU;&D`2G5N:0!*=7-TZ7(`0V5N='+I<@!,:6=E(&UA<F=E
M;F5R`%9E;G-T<F5J=7-T97)E=`!(^&IR96IU<W1E<F5T`$MA<V%K:'-T86X`
M0F5V87(@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!A9G9I<W1E
M(&=O9&ME;F1E;'-E(&%F(&ED96YT:71E="X`2V5R;F4M/&5M/DYE=V)I97,\
M+V5M/@!.^&=L92US:V%B96QS90!.^&=L92UF:6YG97)A9G1R>6L`3OAG;&5L
MYFYG9&4`3OAG;&5T>7!E`$[X9VQE86YV96YD96QS90!.^&=L92!E:W-I<W1E
M<F5R(&%L;&5R961E('#E(&1E;B!O9F9E;G1L:6=E(&[X9VQE<V5R=F5R+@!"
M^')N`$MI<FEB871I`%-Y9&MO<F5A`$YO<F1K;W)E80!K;W)E86YS:R`H155#
M+4M2*0!+=7=A:70`2VER9VES:7-T86X`561F;W)M;FEN9P!3<')O9P!,86]S
M`%-I9'-T92!H86QV9&5L`%-I9'-T92!K;V1E;W)D<^9N9')I;F<`4VED<W1E
M(&MV87)T86P`4VED<W0@;W!D871E<F5T.@!3:61S=&4@;&]G:6XZ("5S`%-I
M9'-T92!I;F1L;V=N:6YG.B`E<R!F<F$@)7,`4VED<W1E(&QO9VEN.B!!;&1R
M:6<`3&5T;&%N9`!,;W8`3&%Y;W5T`%1O;2!V960@:6YG96X@<F%M;65R`$QI
M8F%N;VX`5F5N<W1R90!696YS=')E('1O<'1E:W-T`%9E;G-T<F4@=N9R9&EE
M<@!,97-O=&\`3FEV96%U`$QI8F5R:65N`$QI8GEE;@!,:65C:'1E;G-T96EN
M`%-T^'9R96=N`$QE="!R96=N`$QE="!R96=N('1I9&QI9W0`3&5T(')E9VX@
M<V5N=`!,970@8GEG90!,970@8GEG92!M960@=&]R9&5N`$QE="!S;F4`3&5T
M('-N92!B>6=E`%9I='1I9VAE9`!(96YV:7-N:6YG`$9O<F)I;F0@<'5N:W1E
M<B!T:6PZ`$9O<F)I;F0@92UM86EL+6%D<F5S<V5N(&UE9"!I;F1S:W)I=FYI
M;F=S<VED96X@=F5D(&9R96UV:7-N:6YG`$AE;G9I<VYI;F=E<@!,:6YU>"UK
M:6MS`$QI<W1E("T@8G)U9V5R(&MA;B!S92!M87!P96X`3&ES="!D871A8F%S
M97(`3W!L:7-T;FEN9R!A9B!H:N9L<&5E;6YE<@!,:7-T('1A8F5L;&5R`$QI
M<W1E+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T
M+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T;FEN
M9R!A9B!S97-S:6]N<R!F96IL961E.B`E<P!,:7-T;FEN9R!A9B!B<G5G97)E
M(&9E:FQE9&4Z("5S`%9I<VYI;F<@868@8G)U9V5R92!E<B!S;.5E="!F<F$N
M`$QI='1E<F%T=7(`3&ET875E;@!(96YT97(N+BX`3&]K86P@=&ED.@!296=I
M;VYA;&1A=&$@;V<@=&ED`%-T960`3&]G(&EN9`!,;V<@868@=&ED;&EG97)E
M('-Y;FMR;VYI<V5R:6YG<W-E<W-I;VYE<@!,;V<@=60`3&]G(&EN9`!,;V=I
M;BUO<&=A=F5R`$QO9R!I;F0@9F5J;&5D92!F;W)D:2!D:70@8G)U9V5R;F%V
M;B!E;&QE<B!K;V1E;W)D(&)L978@86YG:79E="!F;W)K97)T+@!,;V=I;F0@
M;6ES;'EK:V5D97,N`$QA;F<@=&5K<W0`2^9R;&EG:&5D`$QA=@!3;>4@9W+F
M<VME('1E9VX`4VWE(&QA=&EN<VME('1E9VX`4VWE(')O;65R=&%L`$QU>&5M
M8F]R9P!-30!-3U1$`$U3+51.148M8FEL86<@:6YD:&]L9'0@:6YG96X@9&%T
M82X`35-'`$UA8V%O`$UA:V5D;VYI96XL($1E;B!T:61L:6=E<F4@:G5G;W-L
M879I<VME(')E<'5B;&EK`$UA9&%G87-K87(`36%G:0!%+6UA:6P`12UM86EL
M+6%D;6EN:7-T<F%T;W(`1&%N(&AE;G9I<VYI;F<N+BX`36%L87=I`$UA;&%Y
M<VEA`$UA;&1I=F5R;F4`36%L:0!-86QT80!(Y6YD=.ER(&QI<W1E;B!A9B!K
M871E9V]R:65R+"!S;VT@9'4@<VMA;"!M87)K97)E(&5M;F5R(&UE9"P@;V<@
M9F%R=F5R;F4L(&1E<B!S:V%L(&MN>71T97,@=&EL(&1I<W-E(&MA=&5G;W)I
M97(N`$UA<#(T+6MO<G0`36%P475E<W0M:V]R=`!+;W)T;.9G;FEN9R!G96UT
M+@!-87)T<P!-87)G96X`36%R:^ER(&UE9"!3970O57-E="UF;&%G`$UA<FOI
M<B!M960@86YD<F4@9FQA9R`H9G@@5FEG=&EG+T)E<W9A<F5T*0!-87)S:&%L
M;/AE<FYE`$UA<G1I;FEQ=64`3W9E<F5N<W!A<W-E;F1E(&9E;'1E<@!-875R
M:71A;FEE;@!-875R:71I=7,`36%X('1I;&QA9'0@:W)E9&ET+@!-86MS:6UU
M;2!B97-K960M9&5L92!O=F5R<VMR961E="X`36%K<RX@=&5M<"X@<VED<W0@
M,C0@=&EM97(Z(`!-86MS+B!T96UP+B!S:61S=&4@-B!T:6UE<CH@`$UA:W-I
M;75M(&%N=&%L(&%F('!O<G1A;&)L;VMK90!-86MS:6UU;6SF;F=D90!-86H`
M36%Y;W1T90!-961I8VEN`$UE9&QE;6UE<@!-96YU+71I;'-T86YD.@!&;W+I
M;B!C96QL97(`0F5S:V5D`$)E<VME9"!S=6-C97-F=6QD="!V97)I9FEC97)E
M="!M960@=6YD97)S:W)I=F5R96YS(&-E<G1I9FEK870@:W5N;F4@:6MK92!V
M97)I9FEC97)E<RX`0F5S:V5D('5D;/AB970N`$)E<VME9'1Y<&4`365T87(@
M5V5A=&AE<@!-971A<F)L;VL@:6MK92!T:6QGYFYG96QI9RX`365T87)B;&]K
M(&EK:V4@=&EL9^9N9V5L:6<N($1E=&%L:F5R(&5R(&)L979E="!N;W1E<F5T
M('1I;"!B<G5G(&9O<B!A9&UI;FES=')A=&]R96XN`$UE=&%R1$(@97(@:6MK
M92!F;W)B=6YD970N`$UE=&]D90!-971O9&4@(B5S(B!E<B!I:VME(&1E9FEN
M97)E=`!-971O9&4@:6MK92!D969I;F5D+B!-971O9&4@:V%L9'0Z("5S`$WE
M;&5E;FAE9`!-97AI8V\`36EK<F]N97-I96X`36ED=`!-24U%+71Y<&4`36EN
M+B!T96UP+B!S:61S=&4@,C0@=&EM97(Z(`!-:6XN('1E;7`N('-I9'-T92`V
M('1I;65R.B``36EN:6UU;2!K;V1E;W)D<V%L9&5R(&5R(&5N9&YU(&EK:V4@
M=61S=.5E=`!3<&5J;&4`1F]R<VME;&QI9W0`36%N9VQE<B!014%2+7!A:VME
M($A45%!?4F5Q=65S="X`2V]N9FEG=7)A=&EO;B!M86YG;&5R+B!$=2!B;&EV
M97(@;OAD="!T:6P@870@9V5N97)E<F4@9&5N(&YU+"!H=FES(&1U(/AN<VME
M<B!A="!B<G5G92!D96YN92!A<'!L:6MA=&EO;BX`36%N9VQE<B!B97-K960M
M:60N`$UA;F=L97(@:W+F=F5T(%!%05(M<&%K:V4@36%I;"X`36%N9VQE<B!S
M97-S:6]N+4E$+@!-86X`36]B:6P@12UP;W-T`$KF=FX`QFYD<FEN9W-D871O
M`,9N9')E(%523`!-;V1U;'5S`$UO;&1O=F$`36]N86-O`$UO;F=O;&EE;@!-
MY6YE9"!O9R#E<@!-Y6YE9&QI9P!-;VYT<V5R<F%T`$WE;F5F87-E<@!&;&5R
M92!F96QT97(@9G5N9&5T(&D@;&EN:64@)60@96YD(&1E="!F;W)V96YT961E
M("5D+@!-87)O:VMO`$UE<W0@<VMY9G)I=`!-97-T('-K>65T`$UE<W0@<VMY
M970@;V<@8FSF<V5N9&4`365S="!S;VP`1FQY="!N960`1FQY="!T:6P@=F5N
M<W1R90!-;V0@:/AJ<F4`1FQY="!O<`!&;'ET(&YE9`!&;'ET(&]P`$UO8V%M
M8FEQ=64`375L=&DM;FEV96%U(')U;&QE9V%R9&EN<VQI<W1E<@!-=6QT:6UA
M<"!52R!K;W)T`$UU;'1I<&QE('9A;&<`36EN(&MO;G1O`$UI;F4@:V]N=&\M
M:6YF;W)M871I;VYE<@!-:6X@4&]R=&%L`$UI;B!0;W)T86PM=61F;W)M;FEN
M9P!->6%N;6%R`$Y%2BP@:F5G(&5R($E+2T4@96YI9P!.879N`$YA;6EB:6$`
M3F%U<G4`3F5P86P`3F5D97)L86YD96YE`$AO;&QA;F1S:V4@06YT:6QL97(`
M3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.
M971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA
M;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T
M:69I8W1E('1Y<&4`3F5T=N9R:P!!;&1R:6<`3GD@2V%L961O;FEE;@!.>2!K
M871E9V]R:0!.>6WE;F4`3GET(&)R=6=E<FYA=FX@*'9A;&=F<FET*0!.97<@
M6F5A;&%N9`!.>70@:V]D96]R9`!.>70@:V]D96]R9"!V:6P@=61L^&)E(&1E
M;B`E>"X`3GEE(&MO9&5O<F0@97(@:6MK92!E;G,N`$YY="!V:6YD=64@*%]B
M;&%N:RD`3GEH961E<@!.>6AE9'-G<G5P<&5R`$[F<W1E`$[F<W1E(#0@9F%S
M97(`3N9S=&4@=&EL=F%L9P!.YG-T93X`3FEC87)A9W5A`$YI9V5R`$YI9V5R
M:6$`3F%T`$YI=64`3F5J`$EN9V5N('1I;&?F;F=E;&EG92!K;VYF:6=U<F%T
M:6]N9&%T82!A="!V:7-E(&9O<G-K96QL92!F;W(N`$EN9V5N('1I;&?F;F=E
M;&EG('-T<F%T96=I('1I;"!A="!L879E($E33RUB:6QL961E<BX`26YG96X@
M<VMR:7!T+7-K86)E;&]N+@!$97(@96MS:7-T97)E<B!I:VME(&YO9V5N(&)L
M;VL@<.4@9&5N(&9O<F5S<'5R9W1E('!O<VET:6]N`$EN9V5N(&MA;&5N9&5R
M(&%N9VEV970@=&EL($U#04PMYF=T;FEN9RX`26YG96X@YFYD<FEN9RX`1&5R
M(&MA;B!I:VME('1I;&;X:F5S(&+X<FX@=&EL(&1E;FYE('1I;&QA9&5L<V4N
M`$EN9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E="!F;W(@
M)7,N`$EN9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E="!F
M;W(@1E10(%9&4RX`26YG96X@:V]N9FEG=7)A=&EO;BUI;F9O<FUA=&EO;B!A
M;F=I=F5T(&9O<B!344P@5D93+@!);F=E;B!K;VYF:6=U<F%T:6]N+6EN9F]R
M;6%T:6]N(&%N9VEV970@9F]R(%-13"U&:6QE(%9&4RX`2W)E9&ET('5D=/AM
M="X`26YT970@8F5S=&5M;65L<V5S<W1E9"!A;F=I=F5T+@!);F=E;B!F:6P@
M<V5N9'0`1F%N9'0@:6YG96X@:6MO;F5R+@!);G1E="!S=&5D(&EN9'-T:6QL
M970N`$EN=&5T('-T960@86YG:79E="X`26YG96X@8F5S:V5D(&%N9VEV970N
M`$EN=&5T(&YA=FX@86YG:79E="X`26YT970@;G5M;65R(&%N9VEV970N`$EN
M9V5N(&%N<W3X9&5L:6=E(&5P:6=R86UM97(`26YT970@:V]D96]R9"!A;F=I
M=F5T('1I;"!B<G5G(&9O<B!(5%10+>9G=&YI;F<N`$EN=&5T(&MO9&5O<F0@
M86YG:79E="!T:6P@8G)U9R!F;W(@24U!4"WF9W1N:6YG+@!);G1E="!K;V1E
M;W)D(&%N9VEV970@=&EL(&)R=6<@9F]R($ME<F)E<F]S+>9G=&YI;F<N`$EN
M=&5T(&MO9&5O<F0@86YG:79E="!F;W(@3&]G:6YD+>9G=&YI;F<N`$EN=&5T
M(&MO9&5O<F0@86YG:79E='0@=&EL(%!!4U-71"WF9W1N:6YG+@!);G1E="!K
M;V1E;W)D(&%N9VEV970@9F]R(%--0BWF9W1N:6YG+@!3=&D@=&EL($]P96Y3
M4TPM8FEB;&EO=&5K970@;6%N9VQE<BX@($]P96Y34TPM8FEB;&EO=&5K970@
M97(@;OAD=F5N9&EG="!F;W(@870@:.5N9'1E<F4@4$M#4S$R+61A=&$N`$EN
M9V5N('9E;G1E;F1E(&]P<VMR:79N:6YG97(N`$MV;W1E(&EK:V4@:6YD<W1I
M;&QE="X`26YG96X@<W1R96=E<@!);F=E;B!S:VEL;&5T96=N(&%N9VEV970N
M`$EN9V5N('-I9&5R`$EN9V5N('/E9&%N(&9I;`!$97(@;6%N9VQE<B!E="!M
M:61L97)T:61I9W0@:V%T86QO9R!T:6P@;65L;&5M;&%G97(N`$EN=&5T(&)R
M=6=E<FYA=FX@;V<O96QL97(@:V]D96]R9"!S96YD="X`26YG96X@9WEL9&EG
M92!834PM9&%T82!R971U<FYE<F5T`$EN9V5N(';F<F1I97(`3W)I9VEN86P@
M:V]N9FEG=7)A=&EO;B!M86YG;&5R('9E<G-I;VYS;G5M;65R+B!296=E;F5R
MZ7(@:V]N9FEG=7)A=&EO;BX`1&EN(&MO;F9I9W5R871I;VX@;6%N9VQE<B!V
M97)S:6]N<VYU;6UE<BX@4F5G96YE<NER(&MO;F9I9W5R871I;VXN`$EN9V5N
M`$EN9V5N("AB<G5G(&EM<&QI8VET*0!.;W)D:7-K("A)4T\M.#@U.2TQ,"D`
M3F]R9F]L:P!.;W)D;&EG92!H86QV:W5G;&4`3F]R9&QI9V4@36%R:6%N8?AE
M<@!.;W)G90!):VME('-E;F5R92!E;F0`26MK92!F^'(`26MK92!N;V=E="!K
M871A;&]G`$EK:V4@:6UP;&5M96YT97)E="X`26MK92!I;F1S=&EL;&5T`$EK
M:V4@=6YD97)S=/AT=&5T+@!.;W1E<@!);G1E="!A="!B<F]W<V4L('9E;F0@
M=&EL8F%G92X`3F]V96UB97(`5&%L`$%N=&%L('1E9VX`06YT86P@:V]L;VYN
M97(`06YT86P@<N9K:V5R`%1A;"!I:VME(&%N9VEV970@9F]R(&]P9&%T97)I
M;F<@:2!D:7-T<FEB=71I;VYS;&ES=&4N`$]+`$]B:F5K=`!/8FIE:W1D86YN
M97(`3VMT86P`3VMT;V)E<@!!;G-T^&1E;F1E(&9I;'1E<@!+;VYT;W(`1V%M
M;65L="!O9R!N>70@:V]D96]R9"!S:V%L(';F<F4@9F]R<VME;&QI9V4N`$=A
M;6UE;'0@:V]D96]R9`!'86UM96QT(&MO9&5O<F0@97(@:6MK92!K;W)R96MT
M+@!/;6%N`$1E;'1E(&UA<'!E<B!U;F1E<G-T^'1T97,@:W5N(&%F($E-05`M
M<V5R=F5R92X`2W5N(&%N<W3X9&5L:6=E(&5P:6=R86UM97(`2W5N(.EN(&4M
M<&]S="UA9')E<W-E('1I;&QA9'0N`$5N(&1E;&EN9W,@96IE<G-K86(@;V<@
M96IE<G1I;&QA9&5L<V5R(&WE(&MU;B#F;F1R92!A9B!E;B!S>7-T96UA9&UI
M;FES=')A=&]R(&5L;&5R(&5J97)E;B!S96QV`,5B96X@:2!E="!N>70@=FEN
M9'5E`$]P96Y34TPM9F5J;#H@1&%T82!K=6YN92!I:VME('5D9')A9V5S(&9R
M82!S:6=N97)E="!3+TU)344M9&5L+@#%8F5N(&1E;FYE(&AE;G9I<VYI;F<@
M:2!E="!N>70@=FEN9'5E`$]P97)A=&EV<WES=&5M`$EN9'-T:6QL:6YG97(`
M26YD<W1I;&QI;F=E<B!F;W(@)7,`3W)D;F5T(&QI<W1E`$]R9V%N:7-A=&EO
M;@!/<F=A;FES871O<FES:R!E;FAE9`!/<F=A;FES97)I;F<`3W!R:6YD96QI
M9R!A<'!L:6MA=&EO;G-S:V%B96QO;@!/<')I;F1E;&EG92!S:V%B96QO;F5R
M(&D@)7,Z`$%N9&5N`$%N9&5N(&EN9F]R;6%T:6]N`$5J97)R971T:6=H961E
M<@!004TMYF=T;FEN9R!E<B!I:VME('1I;&?F;F=E;&EG92X`4$5!4CHZ36%I
M;"UM;W1O<@!01U`@9&EG:71A;"!S:6=N871U<@!01U`M:W)Y<'1E<F5T(&1A
M=&$`3V9F96YT;&EG(%!'4"UN^&=L90!01U`M<VEG;F5R970O:W)Y<'1E<F5T
M(&1A=&$`4$A0+6MO9&4`4$A0+7-K86P`169T;2X@;&5T(')E9VX`169T;2X@
M<F5G;@!%9G1M+B!B>6=E<@!%9G1M+B!S;F4`169T;2X@<VYE8GEG97(`169T
M;2X@<V]L`$5F="X@=&]R9&5N`%!/4TE8+75D=FED9&5L<V4@;6%N9VQE<@!0
M2%`M<VMA;`!&;W)R:6YG`%!A:VES=&%N`%!A;&%U`%!A;.9S=&EN80!086YA
M;6$`4&%P=6$@3GD@1W5I;F5A`%!A<F%G=6%Y`$1E;'9I<W0@<VMY970`2V]D
M96]R9`!+;V1E;W)D(.9N9')E="X`2V]D96]R9"!F;W)K97)T`$MO9&5O<F0@
M:W+F=F5T('9E9"!2041)55,MYF=T;FEN9RX`2V]D96]R9"!M960@8F5K<N9F
M=&5L<V4`2V]D96]R9#H`2V]D96]R9#H@`$MO9&5O<F1E;F4@<VMA;"!VYG)E
M(&5N<RX`26YD<^9T`$EN9'/F="!F<F$@=61K;&EP<VAO;&1E<@!3=&D`5F5N
M=&5N9&4@;W!S:W)I=FYI;F=E<CH`1F]L:P!0<F]C96YT`%5D9OAR('9E9&QI
M9V5H;VQD96QS90!59&;X<B!V961L:6=E:&]L9&5L<V4@=F5D(&QO9R!I;F0_
M`%1I;&QA9&5L<V5R`%1I;&QA9&5L<V4@(B5S(B!I:VME('-L971T970N`%1I
M;&QA9&5L<V4@;N9G=&5T`%1I;&QA9&5L<V5R`%1I;&QA9&5L<V5S+6%D;6EN
M:7-T<F%T:6]N`%!R;V9I;&5R`%!E<G4`2^9L961Y<@!&:6QI<'!I;F5R;F4`
M5&5L969O;@!&;W1O<P!0:71C86ER;@!0<FEK:V5R`$)A;F%L:71E=&5R`$ML
M:6L@:2!E;B!C96QL90!"96MRYF9T(&%T(&1U(/AN<VME<B!A="!S;&5T=&4@
M9&5T=&4@96QE;65N=#H`0F5K<N9F="!A="!D=2#X;G-K97(@870@869LYFYK
M92!D971T92!E;&5M96YT+@!);F1T87-T(&5N(&WE;F5D(&]G(&5T(.5R<W1A
M;"X`26YD=&%S="!E="!N879N('1I;"!D96X@;GEE(&MA=&5G;W)I.@!);F1T
M87-T(&5N(&=Y;&1I9R!)4"UA9')E<W-E+@!);F1T87-T(&5N(&=Y;&1I9R!D
M871O+"!T:F5K(&%N=&%L;&5T(&%F(&1A9V4@:2!MY6YE9&5N+@!);F1T87-T
M(&5N(&=Y;&1I9R!T:61S86YG:79E;'-E+@!3:W)I=B!V96YL:6=S="P@:'9A
M9"!P<F]B;&5M970@9^5R('5D('#E(&]G(&AV860@9&5R('-K97(N`$EN9'1A
M<W0@=F5N;&EG<W0@8G)U9V5R;F%V;B!O9R!K;V1E;W)D`$SF<R!F^&QG96YD
M92!T96MS="X@1'4@4TM!3"!VYG)E(&5N:6<@:2!B971I;F=E;'-E<FYE(&9O
M<B!A="!B<G5G92!S>7-T96UE="X`26YD=&%S="!D970@;GEE(&MA=&5G;W)I
M;F%V;CH`4&]L96X`4&]L:71I:P!-96YI;F=S;>5L:6YG97(`4&]R='5G86P`
M4&QA8V5R:6YG(&%F(&)I;&QE9&5T`%!L86-E<FEN9R!A9B!D96YN92!T86)E
M;`!396YD('1I;"!D96YN92!M87!P92`H:6MK92!G96YN96UT=G5N9V5T(&%F
M($E-05`I`$YE9&+X<B!G96YN96T@<V5N97-T("5S('1I;65R.B``3F5D8OAR
M/&)R("\^8VAA;F-E`%!R969S7VQD87`Z($MRYG9E="!,1$%0+75D=FED9&5L
M(&EK:V4@9G5N9&5T+@!0<F5F<U]S97-S:6]N.B!+<N9V970@<V5S<VEO;BUU
M9'9I9&1E;'-E(&EK:V4@9G5N9&5T+@!4<GEK`%1R>6L@=F5D(&]V97)F;&%D
M96XZ(`!4<GEK.B``1VQI;70`0F5T<F%G="!B:6QL961E="!I(&5T(&YY="!V
M:6YD=64`1F]R<FEG92!T:6QV86QG`%5D<VMR:78@9&]K=6UE;G0`4')I=F%T
M(&[X9VQE`%!R;V)L96T`4')O8FQE;6)E<VMR:79E;'-E`%!R;VIE:W1E<@!3
M=&EK;W)D<W1E:W-T`$]F9F5N=&QI9V4@;OAG;&4`3V9F96YT;&EG+6[X9VQE
M+6%L9V]R:71M90!/9F9E;G1L:6<@;OAG;&4@:6YF;W)M871I;VX`3V9F96YT
M;&EG+W!R:79A="UN^&=L97/F="UG96YE<F5R:6YG(&UI<VQY:VME9&5S+@!0
M=65R=&\@4FEC;P!59')E;G,@8F5S:V5D97(`46%T87(`1F]R97-P^')G<V5L
M`$MV;W1E`$]F9F5N=&QI9R!24T$M;OAG;&4@*"5D(&)I="D`16YK96QT=FES
M('9A;&<`4F5G;@!296=N('1I9&QI9W0`4F5G;B!S96YT`%)E9VYB>6=E<@!2
M96=N(&]G('-N90!3;'5D`%1I;&;F;&1I9W0@97!I9W)A;0!&;W)H;VQD`$SF
M<P!,YG,@8F5S:V5D97(`5FER:V5L:6<@<VQE='1E("5S/R!$96YN92!O<&5R
M871I;VX@:V%N(&EK:V4@8FQI=F4@;VUG:F]R="X`5FER:V5L:6<@<VQE='1E
M(&1A=&$@9F]R(&)R=6=E<B`E<S\@1&5N;F4@;W!E<F%T:6]N(&MA;B!I:VME
M(&)L:79E(&]M9VIO<G0N`$]M9_AR(&1I;B!S:61S=&4@:&%N9&QI;F<`3W!D
M871E<@!/<&9R:7-K(&1Y;F%M:7-K92!M96YU+65L96UE;G1E<CH`1V5N;W!F
M<FES:R!P;W)T86QV:7-N:6YG.@!296=U;.9R="!U9'1R>6L`4F5L871I;VYS
M;.9S97(`1V5N;W!F<FES:P!.;W1E<@!&:F5R;F4@<V5R=F5R90!&:F5R;B!5
M4DP@*&AT='`Z+R]W=W<N96MS96UP96PN9&LO:&]R9&4I.@!3;&5T`%-L970@
M8FQO:P!&:F5R;B!K;VQO;FYE`%-L970@9F]R;6%T97)I;F<`4VQE="!P87(`
M1FIE<FX@;&%G<F5T('-K<FEP="!F<F$@<V5R=F5R<R!M:61L97)T:61I9V4@
M:V%T86QO9RX`1FIE<FX`1FIE<FX@9&5T=&4@<'5N:W0@9G)A(&1O:W5M96YT
M970`4VQE="!B<G5G97(`4VQE="!B<G5G97(Z("5S`$%N;6]D;FEN9R!K=6YN
M92!I:VME(&)E<W9A<F5S+B!2971U<FYE<F5T(&9E:FQK;V1E.B``06YM;V1E
M="!T:F5N97-T92!K=6YN92!I:VME(&9I;F1E<RX`2W+F=F5D92`G)7,G(&5R
M(&EK:V4@86YG:79E="!I("5S+6MO;F9I9W5R871I;VXN`$MRYG9E="`B)7,B
M(&5R(&EK:V4@86YG:79E="!I(%9&4R!K;VYF:6=U<F%T:6]N+@!+<N9V961E
M("(E<R(@97(@:6MK92!A;F=I=F5T(&D@:V]N9FEG=7)A=&EO;F5N+@!+<N9V
M970@9F5L=`!.=6QS=&EL`$YU;'-T:6P@:V]D96]R9`!.=6QS=&EL(&1I="!K
M;V1E;W)D`$=E;G-K86(@<VED<W1E(&9O<F5S</AR9W-E;`!297-U;'1A=&5R
M`%1I;&)A9V4@=&EL(&EN9'-T:6QL:6YG97)N90!'96YT87-T(&YY="!K;V1E
M;W)D`%)E=6YI;VX`1V5N9&%N(&MO;F9I9W5R871I;VX`26YD<W1I;&QI;F=E
M<B!F;W(@4FEC:"!497AT+7)E9&EG97)I;F<`1^5D97(`2/AJ<F4`2/AJ<F4@
M=&]P=&5K<W0`2/AJ<F4@=N9R9&EE<@!2YFMK92UE9V5N<VMA8F5R+BXN`%)E
M9V5L`%)U;>9N:65N`%)O=.ER(#$X,`!2;W3I<B!V96YS=')E`%)O=.ER(&CX
M:G)E`%+F:VME+65G96YS:V%B97(`4N9K:V4M96=E;G-K86)E<@!2YFMK97(Z
M`%-T<F5G97(`4W1R96=E<B!V:6P@;W!T<N9D92!M96QL96T@<N9K:V5R(&]G
M(&MO;&]N;F5R`%-T<F5G97(@=FEL(&MU;B!O<'1RYF1E(&UE;&QE;2!K;VQO
M;FYE<@!3=')E9V5R('9I;"!K=6X@;W!T<N9D92!M96QL96T@<N9K:V5R`%5D
M9OAR`%)U<VQA;F0`4G=A;F1A`$MR>7!T;V=R869I<VL@4R]-24U%+7-I9VYA
M='5R`%,O34E-12US:6=N97)E="!B97-K960`4T%33"WF9W1N:6YG(&5R(&EK
M:V4@=&EL9^9N9V5L:6<N`%--4P!344PM9F]R=&]L:V5R`%-13"UU9'1R>6L@
M9F]R(&]P<VQA9R!A9B!VYG)D:65R`%-32`!354-#15,`4U%,+69O<G1O;&ME
M<@!,^'(`4VMT+B!(96QE;F$`4VMT+B!+:71T<R!O9R!.979I<P!3:W0N($QU
M8VEA`%-K="X@4&EE<G)E(&]G($UI<75E;&]N`%-K="X@5FEN8V5N="!O9R!'
M<F5N861I;F5R;F4`4V%M;64@<F%M;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-O82!4;VUE(&]G(%!R:6YC:7!E`%-A=&5L:71U9&)Y9&5R`%-A=61I
M87)A8FEE;@!'96T`1V5M("(E<R(`1V5M("(E<R(`1V5M;64@26YD<W1I;&QI
M;F=E<@!'96T@9V5N97)E<F5T(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I
M<'0@:2!D:6X@<V5R=F5R<R!M:61L97)T:61I9V4@:V%T86QO9RX`1V5M="`E
M<RUK;VYF:6=U<F%T:6]N+@!'96UT92!S:W)I<'0@9F]R(&]P9W)A9&5R:6YG
M(&%F(&]P<^9T;FEN9R!T:6PZ("(E<R(N`%-P<F5D="!T;W)D96X`5FED96YS
M:V%B`%/X9P!3^&=E;6%S:VEN97(`5N9L9R!F:6QE<@!6YFQG(&5N(&1A=&\`
M5N9L9R!E;B!G<G5P<&4@870@=&EL9OAJ90!6YFQG(&5N(&YY(&5J97(`5N9L
M9R!E;B!S97)V97(`5N9L9R!E;B!B<G5G97(@870@=&EL9OAJ90!6YFQG(&%L
M;&4`5N9L9R!A;&QE(&1A=&\M:V]M<&]N96YT97(N`%;F;&<@970@;V)J96MT
M`%;F;&<@:6YG96X`5N9L9R!D92!T96=N(&1U(&AA<B!B<G5G(&9O<B!F<F$@
M:V%S<V5R;F4@;F5D96YF;W(N($1E(&MA;B!SY2!K;&EP<&5S(&]G(&MO<&EE
M<F5S(&9R82!T97AT9F5L=&5T+@!6YFQG(&1A=&\M861S:VEL;&5R96XZ`%;F
M;&<@9&%T;V9O<FUA=#H`5N9L9R!D96X@:61E;G1I=&5T+"!S;VT@9'4@=FEL
M(.9N9')E.@!6YFQG('1I9',M861S:VEL;&5R96XZ`%;F;&<@=&ED<V9O<FUA
M=#H`5N9L9R!T;R!F96QT97(L(&1E<B!S=F%R97(@=&EL(&AI;F%N9&5N+@!6
MYFQG(&1I;B!F87)V97-A;6UE;G/F=&YI;F<N`%;F;&<@9&ET(&9O<F5T<G5K
M;F4@<W!R;V<Z`%-E;F0@<')O8FQE;6)E<VMR:79E;'-E`%-E;F0@4TU3`%-E
M;F5G86P`1OAL97(Z(`!397!T96UB97(`4V5R8FEE;B!O9R!-;VYT96YE9W)O
M`%-E<FEE;G5M;65R`%-E<G9E<BUD871A(&9O<FME<G0@96QL97(@:6MK92!T
M:6QGYFYG96QI9RX`4V5S<VEO;G-A9&UI;FES=')A=&]R`%-E<W-I;VXM240@
M=61L^&)E="X`4V5S<VEO;F5R`$WF;F=D90!);F1S=&EL;&EN9V5R(&1E<B!T
M:6QL861E<B!D:6<@870@;G5L<W1I;&QE(&1I="!K;V1E;W)D+"!H=FES(&1U
M(&YO9V5N<VEN9&4@<VMU;&QE(&=L96UM92!D970N`$EN9'-T:6P@9FIE<FYE
M('-E<G9E<F4L('-O;2!D=2#X;G-K97(@870@=&EL9^4@9G)A(&1I;B!P;W)T
M86PN`$EN9'-T:6P@9&EN(&9O<F5T<G5K;F4@<W!R;V<M+"!T:61S>F]N92T@
M;V<@9&%T;W9A;&<N`$EN9'-T:6P@9&EN92!O<'-T87)T<V%P<&QI:V%T:6]N
M97(L(&9A<G9E<V%M;65N<^9T;FEN9RP@<VED96]P9G)I<VMN:6X@;V<@86YD
M<F4@=FES;FEN9W-T:6QV86QG+@!);F1S=&EL;&EN9P!3:W)I<'1S('1I;"!O
M<&=R861E<FEN9R!A9B!O<'/F=&YI;F<@=&EL9^9N9V5L:6=E`$9L97)E('-T
M961E<B!M=6QI9R!M960@<&%R86UE=&5R96XZ(`!397EC:&5L;&5R;F4`4VAO
M<'!I;F<`2V]R="!O<'-U;6UE<FEN9P!3:V%L(&AU<G1I9RUT87-T97(@9&5F
M:6YE<F5S(&9O<B!D92!F;&5S=&4@:&5N=FES;FEN9V5R/R`H]RD`5FES`%9I
M<R!F;W)S:V5L;&5N92!M96QL96T@9&5N(&=E;71E(&]G(&1E;B!N>6QI9W0@
M9V5N97)E<F5D92!K;VYF:6=U<F%T:6]N+@!6:7,@=&ED<W!U;FMT(&9O<B!S
M96YE<W1E('1I;&=A;F<@=F5D('#E;&]G;FEN9S\`5FES(&UU;&EG:&5D(&9O
M<B!A="!B96AO;&1E(&]P<FEN9&5L:6<`5FES('-N=7!P97(`5FES(%1A8F5L
M;W!E<F%T:6]N97(M:VYA<'!E;B!I(&UE;G5E;C\`5FES("5S+6UE;G5E;B!T
M:6P@=F5N<W1R93\`5FES(&1I86QO9W9I;F1U92!M960@96=E;G-K86)E<B!F
M;W(@=&%B96QC96QL96X`5FES(&1I86QO9W9I;F1U92!M960@96=E;G-K86)E
M<B!F;W(@=&%B96QL96X`5FES(&1I86QO9W9I;F1U92!M960@96=E;G-K86)E
M<B!F;W(@=&%B96QRYFMK96X`5FES(&1I86QO9W9I;F1U92!M960@96=E;G-K
M86)E<B!F;W(@8FEL;&5D970`5FES(&%F<V5N9'1E`$)Y9V5R`$)Y9V5R('1I
M9&QI9W0`0GEG97(@<V5N=`!">6=E<B!I(&[F<FAE9&5N`%-K<G5M<`!3:W)U
M;7`@96QL97(@9FQY="!N86)O8FQO:VME(&%F('9E:F5N(&;X<G-T`%-I97)R
M82!,96]N90!3:W)I=B!I;F0`56YD97)S:W)I9G0`4VEG;F%T=7)A;&=O<FET
M;64`4VEN9V%P;W)E`%-T^')R96QS90!3<')I;F<@=F5D;&EG96AO;&1E;'-E
M(&]V97(`4VQO=F%K:65T`%-L;W9E;FEE;@!3;F4`4VYE8GEG90!3;F5B>6=E
M<@!3;F5B>6=E<B!T:61L:6=T`%-N96)Y9V5R('-E;G0`4VYE9'EB9&4Z(`!3
M;F7F:W9I=F%L96YT(&D@=F%N9#H@`%-A;&]M;V[X97)N90!3;VUA;&EA`%-A
M;F=E(&]G('!O97-I`%-O<G1E<FEN9W-V86QG`$%F<V5N9&5R861R97-S90!3
M>61A9G)I:V$`4WED975R;W#F:7-K("A)4T\M.#@U.2TS*0!3>60@1V5O<F=I
M82!O9R!$92!S>61L:6=E(%-A;F1W:6-H^&5R`%-Y9&QI9V4@:&%L=FMU9VQE
M`$QU9G0@;65L;&5M(&YA8F]C96QL97(`3'5F="!M96QL96T@:6YD:&]L9"!O
M9R!R86UM92!I(&-E;&QE`$UE;&QE;7)U;7-T86YG970`365L;&5M<G5M`$QU
M9G0@;V<@9F]R<FEN9P!3<&%N:65N`%-K:61T<&]S=`!);F1T87-T;FEN9R!F
M;W(@<W!E8VEA;&MA<F%K=&5R`$1E;"!C96QL90!$96P@:V]L;VYN90!$96P@
M<N9K:V4`4W!O<G0`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!"96=Y
M;F1E;'-E<^5R`$1E;'-T870@96QL97(@<')O=FEN<P!3=&%T=7,`3&%G<FEN
M9W-F;W)M870`5F5J`$=E;FYE;7-T<F5G;FEN9P!,:7-T92!A9B!S=')E;F=E
M`$9J97)N(&1O;>9N92!F<F$@861R97-S96X`4W1I;"!;0U-370!3^&X`56YD
M97)K871A;&]G("(E<R(@:6MK92!F=6YD970N`$5M;F4`1V]D:V5N9`!!;FUO
M9&YI;F<@;VT@870@=&EL9OAJ92`B)7,B('1I;"!S>7-T96T@869S96YD="X@
M($1U(&MA;B!I:VME(&QO9V=E('#E(&;X<B!D:6X@86YM;V1N:6YG(&5R(&)L
M979E="!A;F5R:V5N9'0N`$QA=B!S:W)I9G0`561F^')T`"(E<R(@8FQE=B!T
M:6QF^&IE="!T:6P@<WES=&5M970N`$1A=&$@9F]R(&)R=6=E<B`B)7,B(&)L
M978@<VQE='1E="!F<F$@<WES=&5M970N`"(E<R(@<VQE='1E="X`(B5S(B!S
M;&5T=&5T(&9R82!S>7-T96UE="X`2V]N9FEG=7)A=&EO;B!T:6QB86=E9OAR
M="X@1V5N:6YD;.9S(&9O<B!A="!S92#F;F1R:6YG97)N92X`4F5S97)V96MO
M;F9I9W5R871I;VX@9V5M="X`4F5S97)V96MO;F9I9W5R871I;VYF:6P@)7,@
M9V5M="X`(B5S(B!O<&1A=&5R970N`"(E<R(@<VMR979E="X`4W5D86X`26YD
M:&]L9`!3;VQO<&=A;F<`4V]L;F5D9V%N9P!3;VQR:6=T`%-O;&]P9V%N9P!3
M;VQO<&=A;F<O<V]L;F5D9V%N9P!3;VQO<&=A;F<Z(`!3;VQN961G86YG`%-O
M;&YE9&=A;F<Z(`!(YG9E="!S:W)I9G0`2&KF;'``4W5R:6YA;0!%9G1E<FYA
M=FX`4W9A;&)A<F0@;V<@2F%N($UA>65N`%-W87II;&%N9`!3=F5R:6=E`%-C
M:'=E:7H`4WEN8R!L;V<@<VQE='1E=`!3>6YC34P`4WEN=&%K<V9E:FP@:2!S
M^&=E;&5D`%-Y<FEE;@!4;W)D96X`5&]R9&5N(&]G('9I;F0`5&]R9&5N`%1O
M<F1E;B!T:61L:6=T`%135BUF:6P`5&%B96P`5&%B96PM96=E;G-K86)E<@!4
M86)E;&WF;F=D90!486)E;"UE9V5N<VMA8F5R`%1A:7=A;@!486EW86XL($1E
M;B!K:6YE<VES:V4@<')O=FEN<P!4861J:6MI<W1A;@!486YZ86YI80!-Y6PZ
M`$]P9V%V97(`5&5L969O;FYU;6UE<@!496UP+B!S:61S=&4@=&EM93H@`%1E
M;7!E<F%T=7(`5&5M<&5R871U<CH@`%1E;7!E<F%T=7(\8G(@+SXH)7-(^&HE
M<R\E<TQA=B5S*2`F9&5G.R5S`%-K86)E;&]N("(E<R(@:6MK92!F=6YD970N
M`%-K86)E;&]N+6%D;6EN:7-T<F%T:6]N`%1E:W-T`%)E;B!T96MS=`!496MS
M="UJ=7-T97)I;F<`5&5K<W0M=&]P`%1O<@!4:&%I("A425,M-C(P*0!4:&%I
M;&%N9`!&5%`M=61V:61D96QS96X@97(@:6MK92!T:6QGYFYG96QI9RX`2&ES
M=&]R:6LM<WES=&5M970@97(@<VSE970@9G)A+@!(;W)D92]+;VQA8BUI;G1E
M9W)A=&EO;G-M;W1O<F5N('5N9&5R<W3X='1E<B!I:VME("(E<R(`24U34"UL
M;V=G96X@:W5N;F4@:6MK92!K;&%R9_AR97,N`$UA:6YT96YA;F-E.CHM:VQA
M<W-E;B!B;&5V(&EK:V4@:6YD;.9S=`!4:6QV86QG<W9I;F1U970@97(@8FQE
M=F5T(&QU:VME="X@069S;'5T=&5R+@!!9&UI;FES=')A=&]R96X@8FQI=F5R
M(&[X9'0@=&EL(&%T(&MO;F9I9W5R97)E(&5N('!E<FUA;F5N="!4:6QL861E
M;'-E<RUB86-K96YD+"!H=FES(&1U('9I;"!A;G9E;F1E(%1I;&QA9&5L<V5R
M+@!+=6X@=6YD97)S:61E;@!+;VYT86MT+4E$+6YU;6UE<F5T(&)L978@:6MK
M92!A;F=I=F5T+"!E9G1E<FQA9'0@=&]M="!E;&QE<B!B;&5V(&EK:V4@9G5N
M9&5T(&D@9&%T86)A<V5N+@!+;VYT86MT96X@8FQE=B!T:6QF^&IE="!T:6P@
M9&ET(&%D<F5S<V5K87)T;W1E:V5T+@!$96X@;/AS9VIO<G1E(%!'4"US:6=N
M871U<BUB;&]K(&5R(&MRYG9E="!F;W(@870@:W5N;F4@=F5R:69I8V5R92!D
M96X@<VEG;F5R961E(&)E<VME9"X`1&ES=')I8G5T:6]N<VQI<W1E+4E$(&5R
M(&5N=&5N(&EK:V4@86YG:79E="P@=&]M="!E;&QE<B!I:VME(&9U;F1E="!I
M(&1A=&%B87-E;BX`1&ES=')I8G5T:6]N<VQI<W1E;B!I:VME(&%N9VEV970N
M`$MR>7!T97)I;F=S9F%C:6QI=&5T97)N92!K<N9V97(@96X@<VEK:V5R('=E
M8BUF;W)B:6YD96QS92X`1FEL96X@)7,@8OAR(&EN9&5H;VQD92!E;B`E<RUI
M;F1S=&EL;&EN9RX`1FEL96X@)7,@8OAR(&EN9&5H;VQD92!N;V=L92`E<RUI
M;F1S=&EL;&EN9V5R+@!&:6QE;B!K86X@:6MK92!K;W!I97)E<R!O=F5N<.4@
M<VEG<V5L=BX`1FEL96X@:6YD96AO;&1T(&EN9V5N(&1A=&$N`$;X;&=E;F1E
M(&5R(&AO=F5D97)N92!F<F$@9&5N;F4@;65S<V%G92]R9F,X,C(M8F5S:V5D
M+@!&=6QD<VOF<FUS=&EL<W1A;F0@=FED97,@870@=F]L9&4@<')O8FQE;65R
M(&D@26YT97)N970@17AP;&]R97(@9W)U;F1E="!B<F]W<V5R+69E:FPL('-O
M;2!V:2!I:VME(&AA<B!K=6YN970@;VUGY2X@1'4@=FEL(&UU;&EG=FES(&]P
M;&5V92!F;W)V86YS:V5D92!V:7-N:6YG97(L(&UA;F=E;"!PY2!E9&ET97)I
M;F=S9G5N:W1I;VYE<B!O9R]E;&QE<B!T:6QFYFQD:6=E(&)R;W=S97(M;F5D
M8G)U9"X@2'9I<R!D:70@<WES=&5M(&5R(%=I;F1O=W,F;F)S<#LY>"!V:6P@
M9'4@;65D(&CX:B!S86YD<WEN;&EG:&5D(&]P;&5V92`G1V5N97)E;"!B97-K
M>71T96QS97-F96IL)R!O9R!V:6P@8FQI=F4@;OAD="!T:6P@870@9V5N<W1A
M<G1E(&UA<VMI;F5N+EQN7&Y$=2!E<B!N=2!A9'9A<F5T+B`@5')Y:R!/2R!H
M=FES(&1U('-T861I9R#X;G-K97(@870@<'+X=F5T(&9U;&1S:^9R;7-R961I
M9V5R:6YG+@!)9&5N=&ET971E;B`B)7,B(&5R('-L971T970N`$MU;B!V96YS
M=')E('-I9&4N`%!L86-E<FEN9V5N(&%F($=N=5!'+7!R;V=R86UM970@<VMA
M;"!G:79E<R!T:6P@0W)Y<'1?<&=P.CHM:VQA<W-E;BX`0F5S:V5D96XL('-O
M;2!E<B!S96YD="!D96X@)7,@=&EL("5S(&UE9"!E;6YE="`B)7,B(&5R(&)L
M979E="!V:7-T+@I$971T92!E<B!I;F=E;B!G87)A;G1I(&9O<BP@870@8F5S
M:V5D96X@<F5N="!F86MT:7-K(&5R(&)L979E="!LYG-T(&5L;&5R(&9O<G-T
MY65T+@!.879N970L(&1E<B!S:V%L(&)R=6=E+"!NY7(@9&5R(&AE;G9I<V5S
M('1I;"!S:W)I=F5S:61E;@!!;G1A;&QE="!A9B!F96QT97(@<VMA;"!VYG)E
M(&5T('1A;"X`;W!E;G-S;"UM;V1U;&5T(&5R(&MRYG9E="!A9B!(;W)D95]#
M<GEP=%]S;6EM93HZ+6ML87-S96XN`%!RYF9E<F5N8V5N("(E<R(@:W5N;F4@
M:6MK92!G96UM97,@9F]R9&D@9&5N<R!D871A(&]V97)S:W)I9&5R(&1E;B!M
M86MS:6UA;'0@=&EL;&%D=&4@<W3X<G)E;'-E`%!R;V=R86UM970L(&1E<B!B
M<G5G97,@=&EL(&%T(&)E=')A9W1E(&1E;FYE(&1A=&%T>7!E("@E<RDL(&)L
M979E="!I:VME(&9U;F1E="!PY2!S>7-T96UE="X`0VET871I;VYS=&5G;F5T
M('-K86P@=N9R92!E="!E;FME;'0@=&5G;BX`2W5N(&CX:G)E(&]G('9E;G-T
M<F4@<VED90!+=6X@<VED96X@=&EL(&CX:G)E`$%D<VMI;&QE;'-E<W1E9VYE
M="!S:V%L(';F<F4@970@96YK96QT('1E9VXN`%-E<G9E<F5N("(E<R(@97(@
M<VQE='1E="X`4V5R=F5R96X@(B5S(B!E<B!G96UT+@!/<'-K<FEV;FEN9W-A
M;FUO9&YI;F=E;B!F;W(@)7,@97(@<VQE='1E="X`1&5N(&%N9VEV;F4@<N9K
M:V4@*"5D*2!E:W-I<W1E<F5R(&EK:V4N`$1E;B!A;F=I=FYE('+F:VME(&5K
M<VES=&5R97(@:6MK92X`1&5N(&UI9&QE<G1I9&EG92!F:6P@(B5S(B!F:6YD
M97,@:6MK92X`1&5N('1E:W-T+"!S;VT@9'4@:6YD=&%S=&5D92P@<&%S<V5R
M(&EK:V4@=&EL('1E:W-T96X@<.4@<VOF<FUE;BX`2W5N('1O<"!O9R!B=6YD
M`$MU;B!T;W``1&5N(&%F<V5N9'1E(&EN9F]R;6%T:6]N(&5R('1A8G0@<VED
M96X@<VED<W1E('1R:6XN`$1E;B!O=F5R9OAR=&4@9FEL(&MU;FYE(&EK:V4@
M9V5M;65S+@!W96%T:&5R+F-O;2UB;&]K:V5N(&5R(&EK:V4@=&EL9^9N9V5L
M:6<N`%1E;6$M:V%T86QO9V5T("(E<R(@:6MK92!F=6YD970N`$EN9V5N('1I
M;'9A;&<@=&EL('+E9&EG:&5D+@!$97(@9F]R969I;F1E<R!I;F=E;B!D96QE
M+"!S;VT@:V%N('9I<V5S(&EN9&QE:G)E="X`1&5R(&5R(&9O<B!M86YG92!T
M96=N(&D@9&5T=&4@9F5L="X@1'4@:&%R(&EN9'1A<W1E="`E<R!T96=N.R!D
M=2!S:V%L(&EN9'1A<W1E(&UI;F1R92!E;F0@)7,N`$1E<B!O<'-T;V0@970@
M<')O8FQE;2!U;F1E<B!T:6QF^&IE;'-E;B!A9B`G)7,G('1I;"!S>7-T96UE
M=#H@)7,`1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9J97)N96QS92!A
M9B!D871A(&9O<B!B<G5G97(@(B5S(B!F<F$@<WES=&5M970Z(`!$97(@;W!S
M=&]D(&5T('!R;V)L96T@=6YD97(@<VQE=&YI;F<@868@(B5S(B!F<F$@<WES
M=&5M970Z(`!$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@;W!D871E<FEN
M9R!A9B`B)7,B.B`E<P!$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@9FEL
M;W9E<F;X<G-L96XZ($EN9V5N("5S(&)L978@;W9E<F;X<G0N`$1E<B!O<'-T
M;V0@970@<')O8FQE;2!U;F1E<B!F:6QO=F5R9OAR<VQE;CH@)7,@=F%R('-T
M^')R92!E;F0@9&5N(&UA:W-I;6%L="!T:6QL861T92!S=/AR<F5L<V4@*"5D
M(&)Y=&5S*2X`1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9I;&]V97)F
M^')S;&5N.B`E<R!B;&5V(&MU;B!D96QV:7-T(&]V97)F^')T+@!$97(@;W!S
M=&]D(&5N(&9E:FP@=6YD97(@=FES;FEN9R!A9B!D96YN92!B97-K961D96P`
M1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG96X@868@:V]N
M=&%K=&EN9F]R;6%T:6]N+@!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP
M;W)T97)I;F=E;B!A9B!I0V%L96YD87(@9&%T82X`1&5R(&]P<W1O9"!E;B!F
M96IL(&D@:V]N9FEG=7)A=&EO;G-F;W)M=6QA<F5N+B!.=6QI9W9I<R!H87(@
M9'4@=61E;&%D="!E="!K<N9V970@9F5L="X`1&5R(&]P<W1O9"!E="!P<F]B
M;&5M('5N9&5R('5D9OAR96QS92!A9B!D96X@86YG:79N92!A9')E<W-E:V%R
M=&]T96MS9G5N:W1I;VXN(%!R^'8@:6=E;BX`1&5R(&]P<W1O9"!E;B!F96IL
M('5N9&5R(&]P9&%T97)I;F<@868@:V]N=&%K="UD971A;&IE<FYE+B!0<OAV
M(&EG96XN`$1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!O<&1A=&5R:6YG(&%F
M(&1I<W1R:6)U=&EO;G-L:7-T96XN(%!R^'8@:6=E;BX`1&5N;F4@24U!4"US
M97)V97(@=6YD97)S=/AT=&5R(&EK:V4@9&5L:6YG(&%F(&UA<'!E<BX`1&5T
M=&4@='ED97(@:6MK92!PY2!A="!VYG)E(&5T(&=Y;&1I9W0@<F%R+6%R:VEV
M+@!$96YN92!T>61E<B!I:VME('#E(&%T(';F<F4@96X@9WEL9&EG('II<"UF
M:6PN`$1E='1E('1Y9&5R(&EK:V4@<.4@870@=N9R92!E="!G>6QD:6=T(&MO
M<G1N=6UM97(N`$1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E;F1E;'-E(&%F
M(&)E<VME9&5R(&EG96YN96T@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2!A9&=A;F=S<'5N:W1E="!V960@8G)U9R!A9B!(5%10($%020!$
M96YN92!D<FEV97(@=&EL;&%D97(@869S96YD96QS92!A9B!B97-K961E<B!I
M9V5N;F5M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&%D9V%N9W-P=6YK=&5T
M('9E9"!B<G5G(&%F($A45%`@05!)`$1E;FYE(&1R:79E<B!T:6QL861E<B!A
M9G-E;F1E;'-E(&%F(&)E<VME9&5R(&EG96YN96T@<VUS,F5M86EL("AH='1P
M.B\O<VUS,F5M86EL+F-O;2D@861G86YG<W!U;FMT970@=F5D(&)R=6<@868@
M2%144"!!4$D`1&5N;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@
M8F5S:V5D97(@=FEA(%--5%`@:6=E;FYE;2!6;V1A9F]N92!)=&%L:65N(&%D
M9V%N9W-P=6YK=&5T+"!D;V<@:W5N('1I;"!6;V1A9F]N92UN=6UR92X@1&5N
M(&MRYG9E<B!E;B!E+6UA:6QK;VYT;R!H;W,@5F]D869O;F4@271A;&EE;B`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!$971T92!F96QT(&5R(&MRYG9E="X`1&5T
M=&4@9F5L="!MY2!K=6X@:6YD96AO;&1E(&AE;'1A;"X`1&5T=&4@9F5L="!M
MY2!K=6X@:6YD96AO;&1E(&YU;7)E(&]G(&MO;&]N+@!$971T92!F96QT(&WE
M(&MU;B!I;F1E:&]L9&4@;VMT86QE(';F<F1I97(N`$1E='1E(&9E;'0@<VMA
M;"!VYG)E(&5N(&MO;6UA+2!E;&QE<B!M96QL96UR=6US861S:VEL9'0@;&ES
M=&4@868@:&5L=&%L`$1E='1E(&9E;'0@<VMA;"!VYG)E(&5T(&=Y;&1I9W0@
M;G5M;65R+@!$971T92!F96QT('-K86P@:6YD96AO;&1E(&5N(&9A<G9E:V]D
M92!I(%)'0B!H97@M9F]R;6%T+"!F>"`G(S$R,S1A9B<N`$1E;FYE(&9O<FUU
M;&%R(&5R(&%L;&5R961E('!R;V-E<W-E<F5T+@!$971T92!E<B`E<RX`1&5T
M=&4@97(@970@2V]L86(@1W)O=7!W87)E+6]B:F5K="X@1F]R(&%T('-E(&1E
M='1E(&]B:F5K="!H87(@9'4@8G)U9R!F;W(@96X@92UM86EL+6ML:65N="P@
M<V]M(&9O<G-TY7(@2V]L86(@1W)O=7!W87)E+69O<FUA=&5T+B!"97/X9R`E
M<R!F;W(@96X@;&ES=&4@868@:VQI96YT97(N`$1E;FYE(&)E<VME9"!E<B!S
M:W)E=F5T(&UE9"!E="!A;F1E="!T96=N<^9T("@E<RD@96YD(&1I="!E9V5T
M+@!486QL970@<VMA;"!VYG)E(&UI;BX@,2X`1&5N;F4@<V5R=F5R(&MA;B!I
M:VME(&1E:V]M<')I;65R92!Z:7`M(&]G(&=Z:7`M9FEL97(N`$1E='1E('-Y
M<W1E;2!E<B!D96%K=&EV97)E="X`1&5N;F4@=N9R9&D@<VMA;"!VYG)E(&5T
M('1A;"X`1&5T=&4@=FEN9'5E('-K86P@:V%L9&5S(&9R82!E="!4:6QV86QG
M<W9I;F1U90!4;W)D96X`4V%G97(`5&ED`%1I9'-O<&?X<F5L<V4`5&ED<V9O
M<FUA=`!4:61S=F%L9P!4:6UO<BU,97-T90!4:71E;`!4:71L92`H=&]O;'1I
M<"DZ`%1I;`!&;W(@870@=N9L9V4@;75L=&EP;&4@:6YD9V%N9V4@<VMA;"!#
M=')L+2`H4$,I(&5L;&5R($-O;6UA;F0@*$UA8RDM=&%S=&5N(&AO;&1E<R!N
M961E(&UE9&5N<R!D97(@:VQI:VME<RX`22!$86<`4VMI9G0@2%1-3"UK:6QD
M90!4;V=O`%1O:V5L874`22!M;W)G96X`5&]N9V$`1F]R(&UA;F=E('5G>6QD
M:6=E(&QO9VEN9"UF;W)S^&<@:2!L^&)E="!A9B!D92!S:61S=&4@;6EN=71T
M97(N`%1O<`!4;W`@9G)A;64@*%]T;W`I`$]V97)SYG1T96QS97(`5')I;FED
M860@;V<@5&]B86=O`%-A;F0@96QL97(@9F%L<VL`5&ER`%1U;F5S:65N`%1Y
M<FMI970`5'ER:VES:R`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS
M(&]G($-A:6-O<R#897)N90!4=79A;'4`4VMR:78@9&ET('9A;&<Z(`!5+E8N
M+6EN9&5K<SH@`%523`!54DP@9F]R('-K<FEP="!T:6P@;6]D=&%G96QS92!A
M9B!S=&%T=7,@<F%P<&]R=&5N`%523#H`56=A;F1A`%5K<F%I;F4`2W5N;F4@
M:6MK92!T:6QGY2!61E,M:V%T86QO9RX`2V%N(&EK:V4@=&EL9OAJ92!E:W-T
M<F$@8G)U9V5R(&EN9F]R;6%T:6]N('5N9&5R(&]P<VMR:79N:6YG+@!+86X@
M:6MK92#F;F1R92!T:6QL861E;'-E<B!F;W(@5D93+69I;"`B)7,B+@!+86X@
M:6MK92#F;F1R92!T:6QL861E;'-E<B!F;W(@5D93+69I;"`E<R\E<RX`2V%N
M(&EK:V4@<VMI9G1E('1I;"`E<RX`2V%N(&EK:V4@=&IE:VME(&9I;'-T^')R
M96QS96X@868@(B5S(BX`2V%N(&EK:V4@=&IE:VME(&9I;'-T^')R96QS96X@
M868@(B5S+R5S(BX`2W5N;F4@:6MK92!FY2!F;W)B:6YD96QS92!T:6P@4U%,
M('-E<G9E<F5N+@!+86X@:6MK92!FY2!F;W)B:6YD96QS92!M960@4U-,+@!+
M86X@:6MK92!K;W!I97)E(%9&4RUF:6PN`$MA;B!I:VME(&1A;FYE(%9&4RUK
M871A;&]G("(E<R(N`$MA;B!I:VME(&1A;FYE(%9&4RUK871A;&]G+@!+86X@
M:6MK92!L879E(%9&4RUF:6PN`$MA;B!I:VME(&]P<F5T=&4@5D93+6UA<'!E
M("(E<R(N`$MA;B!I:VME(&QA=F4@=&]M(%9&4RUF:6PN`$MA;B!I:VME(&1E
M:V]M<')I;65R92!D871A+@!+86X@:6MK92!S;&5T=&4@(B5S(CL@:V%T86QO
M9V5T(&5R(&EK:V4@=&]M="X`2V%N(&EK:V4@<VQE='1E("(E<R(Z("5S+@!+
M86X@:6MK92!S;&5T=&4@)7,[(&MA=&%L;V=E="!E<B!I:VME('1O;70`2V%N
M(&EK:V4@<VQE='1E(%9&4RUK871A;&]G970@<F5K=7)S:79T+@!+86X@:6MK
M92!S;&5T=&4@5D93+6MA=&%L;V<N`$MA;B!I:VME('-L971T92!61E,M:V%T
M86QO9SH@)7,N`$MA;B!I:VME('-L971T92!61E,M9FEL("(E<R(N`$MA;B!I
M:VME('-L971T92!61E,M9FEL+@!+86X@:6MK92!S;&5T=&4@5D93+6UA<'!E
M("(E<R(N`$MA;B!I:VME('-L971T92!61E,@<F5K=7)S:79T.B`E<RX`2V%N
M(&EK:V4@8F5S=&5M;64@86MT=65L="!K871A;&]G+@!+86X@:6MK92!U9&1R
M86=E(&-E<G1I9FEK870M9&5T86QJ97(`2V%N(&EK:V4@:6YD;.9S92!D969I
M;FET:6]N96X@868@)7,N`$MA;B!I:VME(&9L>71T92!61E,M9FEL+@!+86X@
M:6MK92#E8FYE(%9&4RUF:6P@(B5S(BX`2V%N(&EK:V4@Y6)N92!61E,M9FEL
M('1I;"!S:W)I=FYI;F<N`$MA;B!I:VME(.5B;F4@5D93+69I;"X`2V%N(&EK
M:V4@Y6)N92!K;VUP<FEM97)E="!A<FMI=BX`2V%N(&EK:V4@;.9S92!61E,M
M9FEL("AF:6QE<VEZ92@I(&9E:FQE9&4I+@!+86X@:6MK92!LYG-E(%9&4RUF
M:6P@*&=E=$9I;&53:7IE*"D@9F5J;&5D92DN`$MA;B!I:VME(&SF<V4@9FEL
M.B``2V%N(&EK:V4@;.9S92!V9G-R;V]T+6MA=&%L;V=E="X`2V%N(&EK:V4@
M;VUD^&)E("5S('1I;"`E<SH@;>5L;6%P<&5N(&9I;F1E<R!A;&QE<F5D90!+
M86X@:6MK92!O;63X8F4@5D93+6MA=&%L;V<N`$MA;B!I:VME(&]M9/AB92!6
M1E,M:V%T86QO9SH@)7,N`$MA;B!I:VME(&]M9/AB92!61E,M9FEL("(E<R(N
M`$MA;B!I:VME(&]M9/AB92!61E,M9FEL("5S+R5S+@!+86X@:6MK92!O;63X
M8F4@5D93+69I;"X`2V%N(&EK:V4@869V:6ML92`G;6MI<V]F<R<N`$MU;FYE
M(&EK:V4@;W9E<G/F='1E(&1E='1E(%=O<F0@9&]K=6UE;G0`2V%N(&EK:V4@
M<VMR:79E(%9&4RUF:6P@(B5S(BX`2V%N(&EK:V4@<VMR:79E(%9&4RUF:6P@
M*&-O<'DH*2!F96IL961E*2X`2V%N(&EK:V4@<VMR:79E(%9&4RUF:6QD871A
M+@!+86X@:6MK92!S:W)I=F4@5D93+69I;#L@:W9O=&5N('9I;"!B;&EV92!O
M=F5R<VMR961E="X`56YD97)L:6YI97)E=`!&;W)T<GED(.9N9')I;F=E<@!/
M;6?X<B!D:6X@<VED<W1E(&AA;F1L:6YG`%5V96YT970@<F5A:W1I;VX@9G)A
M('-E<G9E<B!PY2!F;W)B:6YD96QS96XZ(`!5=F5N=&5T(')E86MT:6]N(&9R
M82!S97)V97(@<.4Z(`!):VME(&%N8G)A9W0`56YI8V]D92`H551&+3@I`$9O
M<F5N961E($%R86)I<VME($5M:7)A=&5R`%-T;W)B<FET=&%N:65N`%5300!5
M4T%S('5N9&5R;W)D;F5D92#X97(`16YH961E<@!5:V5N9'0`56ME;F1T(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN`%5K96YD="!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5:V5N9'0@<W1E9"!A;F=I=F5T+@!5:V5N9'0@
M8G)U9V5R;F%V;B!E;&QE<B!K;V1E;W)D+@!(YF=T(&%K='5E;'0@96QE;65N
M="!A9BX`26MK92!N879N9VEV970`57!R:79I;&EG97)E9&4@<VMR:7!T97(@
M:V%N(&EK:V4@=&EL9^4@:VQI<'!E+VMO<&DO:6YD<^9T('!R;V=R86UMYG-S
M:6=T(&%F('-I:VME<FAE9'/E<G-A9V5R+B`@2VQI:R!/2R!F;W(@870@<V4@
M96X@=&5K;FES:R!N;W1E(&AO<R!M;WII;&QA+F]R9RP@<V]M('9I<V5R(&1I
M9RP@:'9O<F1A;B!D=2!K86X@=&EL;&%D92!E="!S:W)I<'0@870@=&EL9^4@
M=61K;&EP<VAO;&1E<F5N+@!&87)V92!I:VME(&EN9'-T:6QL970`561V:61D
M96QS92!I:VME('5N9&5R<W3X='1E=`!/<&1A=.ER`$]P9&%TZ7(@)7,`3W!D
M873I<B!B<G5G97(`(B5S(B!O<&1A=&5R970N`$]P9W)A9&5R:6YG<RUF;W)E
M<VMR:69T('-L971T970N`%5P;&]A9`!/<'/F=&YI;F=S9FEL97(@=&EL(&%L
M;&4@87!P;&EK871I;VYE<B!L86=T(&]P('#E('-E<G9E<BX`4W1O<F4@;&%T
M:6YS:V4@8F]G<W1A=F5R`%-T;W)E(')O;65R=&%L`%5R=6=U87D`06YV96YD
M(&YU=N9R96YD93H@)7,`0G)U9R!34TP`0G)U9R!H=FES(&YA=FXO:V]D96]R
M9"!E<B!F;W)S:V5L;&EG(&9O<B!)35-0+7-E<G9E<BX`0G)U9V5R`$)R=6=E
M<B`E<R!I:VME(&)E;7EN9&EG970@=&EL("5S+@!"<G5G97(M861M:6YI<W1R
M871I;VX`0G)U9V5R:6YD<W1I;&QI;F=E<@!"<G5G97(M<F5G:7-T<F5R:6YG
M`$)R=6=E<BUR96=I<W1R97)I;F<@97(@8FQE=F5T('-LY65T(&9R82!PY2!D
M971T92!W96)S=&5D+@!"<G5G97)K;VYT;R!I:VME(&9U;F1E=`!"<G5G97)N
M879N`$)R=6=E<FYA=FX@(B5S(B!F:6YD97,@86QL97)E9&4N`$)R=6=E<FYA
M=FXZ`$)R=6=E<FYA=FXZ(`!"<G5G97)E(&D@<WES=&5M970Z`%5S8F5K:7-T
M86X`5D93+6MA=&%L;V<@96MS:7-T97)E<B!I:VME+@!&97)I90!'>6QD:6=E
M(&9U;F1E="!S=&5D97(@:6YK;'5D97)E<CH`1WEL9&EG:&5D`%;F<F1I(&5R
M(&UI;G5T=&5R(&9R82!N=2X`5N9R9&D@97(@;65R92!E;F0@9&5N(&UA:W-I
M;6%L92!LYFYG9&4@868@)7,N`%;F<F1I97(`5N9R9&EE<BP@9&5R(&MA;B!V
MYFQG97,@:6)L86YD=`!686YU871U`%-K:69T96YD90!696YE>G5E;&$`169T
M97)P<OAV;FEN9R!F96IL961E("T@9&5R(&5R(&)L979E="!P:6QL970@=F5D
M(&1E;FYE(&)E<VME9"X`5F5R<VEO;@!697)S:6]N<VMO;G1R;VP`3&]D<F5T
M(&]P<W1I;&QI;F<`3&]D<F5T(&9O<G)I;F<`3&]D<F5T.@!-96=E="!H^&H`
M5FEE=&YA;0!6:65T;F%M97-I<VL@*%9)4T-)22D`5FES("5S`%-E('#E(&5K
M<W1E<FX@=V5B<VED90!6:7,@<V]M("5S`$IO;69R=?AE<BP@0G)I=&ES:V4`
M2F]M9G)U^&5R+"!!;65R:6MA;G-K90!3>6YL:6=H960`4WEN;&EG:&5D.B``
M5F]D869O;F4@271A;&EE;B!V:6$@4TU44`!705).`$%$5D%24T5,(2$A($9*
M15).(%-#4DE05"!-04Y514Q4($9202`E<RX`5TE.('9I82!(5%10`%=A;&QI
M<R!O9R!&=71U;F$`061V87)S96P`3VYS`%9E:G)U9'-I9W0`5F5J<FEN9F]R
M;6%T:6]N('-T:6QL970@=&EL<N5D:6=H960@868`5V5A=&AE<BYC;VT`5V5B
M`%=E8G-I=&4`56=E;G1L:6<`5F5L:V]M;65N`%9E;&MO;6UE;B!T:6P@)7,`
M5F5L:V]M;65N+"`E<P!697-T;&EG("A)4T\M.#@U.2TQ*0!697-T;&EG("A)
M4T\M.#@U.2TQ-2D`5F5S='-A:&%R80!(=FEL:V5N(&%P<&QI:V%T:6]N('-K
M86P@)7,@=FES92!E9G1E<B!L;V=I;F0_`$AV860@97(@<V5P87)A=&]R=&5G
M;F5T/P!(=F%D(&5R(&-I=&%T:6]N<W1E9VYE=#\`5VAE<F5I<R!!=7-T<F%L
M:65N+6MO<G0`2'9I;&ME(&9A<V5R`$AV:6QK92!P;'5G:6YS('-K86P@86MT
M:79E<F5S(&9O<B!2:6-H(%1E>'0M=N9R:W3X:F5T+@!"<F5D9&4`0G)E9&1E
M(&D@0U-3+65N:&5D97(`0G)E9&1E(&%F("5S+6UE;G5E;B!T:6P@=F5N<W1R
M92`H8FQI=F5R(&%K=&EV97)E="!V960@;N9S=&4@;&]G:6YD*3H`0G)E9&1E
M(&%F('1A8F5L;&5N`$)R961D92UE;FAE9`!"<F5D9&4Z`%=I:VD`5FEN9`!"
M;.9S="!T:61L:6=T`%9I;F1H87-T:6=H960@:2!K;F]B`%9I;F0Z`%9I;F0Z
M(`!6:7-D;VT`V&YS:V5L:7-T90!!<F)E:F1E`$%D<F5S<V4@*&%R8F5J9&4I
M`%1E;&5F;VX@*&%R8F5J9&4I`$9O<FME<G0@86YT86P@9F5L=&5R(&D@;&EN
M:64@)60N($9O<G9E;G1E9&4@)60L(&9A;F1T("5D+@!&;W)K97)T(&%N=&%L
M(&9E;'1E<BX@1F]R=F5N=&5D92`E9"P@9F%N9'0@)60N`$9O<FME<G0@9F]R
M<VMY9&YI;F<@)60@=6YD97(@:6YD;.9S;FEN9R!A9B!E;B!61E,M9FEL+@!8
M+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!U9'9I9&1E;'-E
M<@#%Q0#%Q<7%`%EA:&]O(2UK;W)T`,5R;&EG`%EE;65N`$IA`$IA+"!J96<@
M97(@96YI9P!$=2!B969I;F1E<B!D:6<@:2!414M35"!-3T154RX@($)R=6<@
M6SP^72UK;F%P<&5N('1I;"!A="!S:VEF=&4@=&EL8F%G92!T:6P@5UE325=9
M1RX`1'4@:&%R(&EK:V4@=&EL;&%D96QS92!T:6P@870@;W!R971T92!M97)E
M(&5N9"`E9"!B;&]K:V4N`$1U(&5R(&EK:V4@YF=T970N`$1U(&MA;B!I:VME
M(&AA=F4@)UPG+71E9VYE="!I(&1I="!F=6QD92!N879N+@!$=2!I;F1T87-T
M961E(&EK:V4@96X@9WEL9&EG(&4M<&]S="UA9')E<W-E+@!&;W(@870@:6UP
M;W)T97)E('-K86P@9'4@=&EL;W)D;F4@9F5L=&5R(&9R82!D96X@9FEL(&1U
M(&EM<&]R=&5R97(@=&EL(&1E('1I;'-V87)E;F1E(&9E;'1E<B!I("5S+@!$
M=2!E<B!B;&5V970@;&]G9V5T('5D+@!$=2!S:V%L(&EN9'1A<W1E(&5T(&9U
M;F=E<F5N9&4@;6]B:6QN=6UM97([(&MU;B!C:69R92!M960@970@=F%L9V9R
M:2`G*R<@9F]R(&1E;B!I;G1E<FYA=&EO;F%L(')E=&YI;F=S:V]D92X`1'4@
M<VMA;"!I;F1T87-T92!E;B!G>6QD:6<@=N9R9&DN`$1U('-K86P@:V]N9FEG
M=7)E<F4@96X@1&%T851R964M8F%C:V5N9"!F;W(@870@:W5N;F4@86YV96YD
M92!/<'-K<FEV;FEN9V5R+@!$=2!S:V%L(&MO;F9I9W5R97)E(&5N9"!61E,M
M8F%C:V5N9"X`1'4@8FQI=F5R(&[X9"!T:6P@870@;&%V92!E;B!P<F]B;&5M
M8F5S:W)I=F5L<V4L(&;X<B!D=2!K86X@<V5N9&4@9&5N(&EN9"X`1'4@<VMA
M;"!I;F1T87-T92!D96X@55),(&AV;W)T:6P@9&5N;F4@:.9G=&4@<VMA;"!H
M96YV:7-E`$1U('-K86P@=N9L9V4@9&5N('-E<G9E<BP@<V]M('-K86P@<VQE
M='1E<RX`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@9'4@=FEL
M(&9J97)N92X`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@9'4@
M=FEL(&9J97)N92X`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@
M9'4@=FEL('1I;&;X:F4N`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@
M<V]M(&1U('9I;"!O<&1A=&5R92X`1'4@<VMA;"!A;F=I=F4@9&5N(&AA;F1L
M:6YG+"!S;VT@<VMA;"!U9&;X<F5S+@!$=2!S:V%L(&%N9VEV92!E="!N>70@
M:V%T96=O<FEN879N+@!$=2!B;&EV97(@;OAD="!T:6P@870@86YG:79E(&5T
M(&ET86QI96YS:V4@=&5L969O;FYU;6UE<@!$:6X@)7,@<V5S<VEO;B!E<B!U
M9&SX8F5T+B!,;V<@=F5N;&EG<W0@:6YD(&EG96XN`$1I;B!E+7!O<W0M861R
M97-S90!$:6X@1G)O;3H@861R97-S93H`1&EN92!I;F9O<FUA=&EO;F5R`$1I
M;B!);G1E<FYE="UA9')E<W-E(&5R('-K:69T970@<VED96X@8F5G>6YD96QS
M96X@868@9&EN("5S+7-E<W-I;VXN($9O<B!A="!B97-K>71T92!D:6X@<VEK
M:V5R:&5D(&)L:79E<B!D=2!N^&1T('1I;"!A="!L;V=G92!I;F0@:6=E;BX`
M1&ET(&YA=FX`1&EN(.9G=&YI;F=S+6)A8VME;F0@=6YD97)S=/AT=&5R(&EK
M:V4@=&EL9OAJ96QS96X@868@8G)U9V5R92X@2'9I<R!D=2#X;G-K97(@870@
M8G)U9V4@2&]R9&4@=&EL(&%T(&%D;6EN:7-T<F5R92!B<G5G97)K;VYT:2P@
M8FQI=F5R(&1U(&[X9'0@=&EL(&%T(&)R=6=E(&5N(&%N9&5N(.9G=&YI;F=S
M+6)A8VME;F0N`$1I;B!A=71O<FES871I;VYS+6)A8VME;F0@=6YD97)S=/AT
M=&5R(&EK:V4@;W!L:7-T;FEN9V5N(&%F(&)R=6=E<F4@96QL97(@97(@9&5N
M(&9U;FMT:6]N(&%F(&5N(&5L;&5R(&%N9&5N(&=R=6YD(&)L979E="!S;.5E
M="!F<F$N`$1I;B!B<F]W<V5R('-Y;F5S(&%T(';F<F4@<VMI9G1E="!S:61E
M;B!B96=Y;F1E;'-E;B!A9B!D:6X@)7,M<V5S<VEO;BX@1F]R(&%T(&)E<VMY
M='1E(&1I;B!S:6MK97)H960L('-K86P@9'4@;&]G9V4@:6YD(&EG96XN`$1I
M;B!B<F]W<V5R('5N9&5R<W3X='1E<B!I:VME(&1E;FYE(&9U;FMT:6]N86QI
M=&5T+@!$:6X@8G)O=W-E<B!U;F1E<G-T^'1T97(@:6MK92!D96YN92!P<FEN
M="UM=6QI9VAE9"X@5')Y:R!#=')L+T-O;6UA;F0@*R!0(&9O<B!A="!P<FEN
M=&4N`$1I;B!A:W1U96QL92!T:61S>F]N93H`1&EN(&9O<G9A;&=T92!I9&5N
M=&ET970@97(@YFYD<F5T+@!$:6X@<W1A;F1A<F0M:61E;G1I=&5T.@!$:70@
M9G5L9&4@;F%V;CH`1&ET(&QO9VEN9"!E<B!U9&SX8F5T+@!$:70@;GEE(&MO
M9&5O<F0@9F]R("5S(&5R.B`E<P!$:6YE('1I;'9A;&<@97(@8FQE=F5T(&]P
M9&%T97)E="!F;W(@=F%R:6=H961E;B!A9B!D96YN92!S97-S:6]N+@!$:6YE
M('1I;'9A;&<@97(@;W!D871E<F5T+@!$:70@:V]D96]R9"!E<B!B;&5V970@
M;G5L<W1I;&QE=`!$:70@:V]D96]R9"!E<B!B;&5V970@;G5L<W1I;&QE.R!K
M;VYT<F]L;.ER(&1I;B!I;F1B86MK92!O9R!L;V<@:6YD(&UE9"!D:70@;GEE
M(&MO9&5O<F0N`$1I="!K;V1E;W)D(&5R('5D;/AB970N`$1I;F4@9FIE<FYE
M('-E<G9E<F4Z`$IU9V]S;&%V:65N`%IA[W)E`%IA;6)I80!::6UB86)W90!:
M:7!P>0!;4VMJ=6P@8VET97)E="!T96MS=%T`6U!R;V)L96UB97-K<FEV96QS
M95T`6U9I<R!C:71E<F5T('1E:W-T("T`6U9I<R!C:71E<F5T('1E:W-T("T@
M)7,@;&EN:65R70!;;&EN:64@)7,@=60@868@)7-=`$%D;6EN:7-T<F%T:6]N
M`$-,20!$871A5')E90!3;&5T('+F:VME`$=R=7!P97(`2&KF;'``0FEL;&5D
M+65G96YS:V%B97(N+BX`3&]G(&EN9`!,;V<@=60`QFYD<FEN9R!H96YV:7-N
M:6YG+BXN`$EN9'-T:6QL:6YG97(`5&EL;&%D96QS97(`4VQE="!H96YV:7-N
M:6YG+BXN`$]P<^9T;FEN9P!486)E;"UE9V5N<VMA8F5R+BXN`$)R=6=E<F4`
M861R97-S96MA<G1O=&5K`&%D<F5S<V5N="!U:V5N9'0`:V%L96YD97(`=FEN
M9'-T:6QL90!K86X@:6MK92!D86YN92!U9&1A=&$M9FEL`&MA;B!I:VME(.5B
M;F4@:6YD9&%T80!K;&EK(&AE<@!F96IL('9E9"!A;G9E;F1E;'-E(&%F(&MO
M;6UA;F1O+6QI;FEE`&MO;F9I9W5R871I;VYS9F5J;`!M86YG;&5R(&MR:71I
M<VL@<WES=&5M9FEL`&9E:FP@:2!D871A9F]R;6%T`')E9&EG97(`:6YD9V%N
M9R!I:VME(&9U;F1E=`!F86QD96YD90!F:6P`9G)A("5S("@E<RD@;65D("5S
M("5S`'-T;W)M9G5L9`!H.@!H:`!U:V5N9'0@;6%S:VEN;F%V;@#X:F5B;&EK
M:V5L:6=T`&EN9&QE:G)E=`!I;F1D871A+W5D9&%T82UF96IL`&EN=&5R;B!S
M;V9T=V%R92UF96IL`&QI;FEE<ET`;6MI<V]F<R!F96IL:V]D92`E9"!U;F1E
M<B!D86YN96QS92!A9B!)4T\N`&UM`&YA=FX`:6MK92!I;7!L96UE;G1E<F5T
M`&5N9&YU(&EK:V4@:6UP;&5M96YT97)E=`!N;W1E<V)L;VL`<')O8V5N=`!T
M:6QL861E;'-E(&[F9W1E=`!P<FEK:V5R`&9E:FP@:2!P<F]T;VMO;"!F<F$@
M9FIE<FX@<VED90!S=&EG96YD90!T:F5N97-T92!U=&EL9^9N9V5L:6<`=FES
M(&9O<G-K96QL90!S;7,R96UA:6P@=FEA($A45%``<W,`<W1A8FEL=`!S>7-T
M96UF96IL`&]P9V%V96QI<W1E`&UI9&QE<G1I9&EG(&9E:FQT:6QS=&%N9`!I
M;F1T87-T(&MO9&5O<F1E="!T;R!G86YG92!F;W(@870@8F5K<N9F=&4`<V%M
M;65N<VUE;'1E=`!U;F%V;F=I=F5N`&)R=6=E<G9A;&<`=D-A<F0`=SH`=V5A
M=&AE<BYC;VT`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V1A7T1++VAE;'`N>&UL````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#0Q-S,V,C<W-@`P,C`R-S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O
M9&%?1$LO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-B!J86X@
M17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4]
M(FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^
M"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@
M;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M
M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G
M97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@
M;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L
M(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S
M;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN
M('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S
M"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N
M97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A
M<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U
M<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP
M;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@
M=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@
M=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N
M($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T
M(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N
M(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES
M(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*
M("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC
M92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A
M/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E
M;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B
M;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U
M=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]D95]$12\`````````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`,#$V-C,P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V1E7T1%+TQ#7TU%4U-!1T53+P``
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W-@`P,C`T,34`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9&5?
M1$4O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P-#(U,C(V`#$P-#$W,S8R-S<V`#`R,C`V,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25`````(D'```<````9#P`
M`!,*``"L>````````/B@```.````^:````\````(H0``#0```!BA```(````
M)J$```L````OH0``#````#NA```$````2*$``!@```!-H0``&P```&:A```M
M````@J$``!T```"PH0``)````,ZA```I````\Z$``!D````=H@``)@```#>B
M```,````7J(``"0```!KH@``#P```)"B```+````H*(```X```"LH@``!0``
M`+NB```H````P:(```@```#JH@``"@```/.B```5````_J(``!(````4HP``
M"P```">C``"%````,Z,```X```"YHP``"@```,BC```-````TZ,```X```#A
MHP``$0```/"C```-`````J0```P````0I```#0```!VD```&````*Z0``)0`
M```RI```"@```,>D```/````TJ0``!@```#BI```#````/ND```.````"*4`
M``X````7I0``"````":E```)````+Z4``"X````YI0``&@```&BE```R````
M@Z4``#@```"VI0``5````.^E``!1````1*8``%H```"6I@``5P```/&F```T
M````2:<```D```!^IP``#0```(BG```'````EJ<```H```">IP``#P```*FG
M```%````N:<```8```"_IP``$0```,:G```(````V*<```D```#AIP``"0``
M`.NG```E````]:<``"`````;J```$P```#RH```0````4*@```\```!AJ```
M"@```'&H```#````?*@```\```"`J```%````)"H```)````I:@```T```"O
MJ```$@```+VH```9````T*@``!X```#JJ```#P````FI```*````&:D```\`
M```DJ0``"````#2I```D````/:D``!0```!BJ0``%@```'>I```(````CJD`
M`$X```"7J0``+0```.:I```9````%*H```<````NJ@``#````#:J```L````
M0ZH```X```!PJ@```P```'^J```+````@ZH```<```"/J@``!P```)>J```%
M````GZH```4```"EJ@``"@```*NJ```#````MJH``!<```"ZJ@``"@```-*J
M```/````W:H```X```#MJ@``&````/RJ```C````%:L```X````YJP``%```
M`$BK```7````7:L``!<```!UJP``%P```(VK```3````I:L```\```"YJP``
M#@```,FK```?````V*L``!T```#XJP``!P```!:L```&````'JP```@````E
MK```#P```"ZL```&````/JP```H```!%K```$P```%"L```+````9*P``!``
M``!PK```%0```(&L```5````EZP```<```"MK```$````+6L```%````QJP`
M`!4```#,K```$0```.*L```,````]*P``#L````!K0``.````#VM```)````
M=JT```<```"`K0``%````(BM```#````G:T```4```"AK0``$````*>M```)
M````N*T``!,```#"K0``.0```-:M```2````$*X``"<````CK@``+````$NN
M```J````>*X``"4```"CK@``"@```,FN```&````U*X```D```#;K@``!P``
M`.6N```O````[:X``#<````=KP``+@```%6O``!5````A*\``"T```#:KP``
M+0````BP```]````-K```#\```!TL```+0```+2P``!`````XK```",````C
ML0``(P```$>Q``!`````:[$``"T```"LL0``,P```-JQ```E````#K(``!4`
M```TL@``&0```$JR```I````9+(``"0```".L@``*````+.R```1````W+(`
M``H```#NL@``#````/FR```*````!K,``!`````1LP``%@```"*S```6````
M.;,```<```!0LP``!P```%BS```4````8+,```H```!ULP``"````("S```G
M````B;,```@```"QLP``!P```+JS```'````PK,```8```#*LP``!0```-&S
M```'````U[,```8```#?LP``"````.:S```I````[[,```X````9M```"@``
M`"BT```$````,[0```<````XM```"0```$"T```&````2K0``!$```!1M```
M!P```&.T```6````:[0```0```""M```"````(>T```&````D+0```T```"7
MM```!@```*6T```>````K+0``!$```#+M```"````-VT```-````YK0```P`
M``#TM```!P````&U```#````";4```,````-M0``%P```!&U```3````*;4`
M`!T````]M0``"````%NU```$````9+4```@```!IM0``"````'*U``!!````
M>[4``!H```"]M0``*P```-BU```@````!+8``!4````EM@``!@```#NV```&
M````0K8``!4```!)M@``&````%^V```B````>+8``"X```";M@``'0```,JV
M```A````Z+8``%0````*MP``*0```%^W```*````B;<```<```"4MP``!P``
M`)RW```5````I+<```X```"ZMP``"@```,FW```/````U+<```T```#DMP``
M#P```/*W```-`````K@```D````0N```%````!JX```&````+[@``!@````V
MN```'0```$^X```3````;;@``!$```"!N```%````).X```$````J+@```8`
M``"MN```%````+2X``!4````R;@``&0````>N0``!````(.Y```.````B+D`
M``4```"7N0``!0```)VY```;````H[D``!H```"_N0``$P```-JY```1````
M[KD``!$`````N@``'````!*Z```J````+[H``!````!:N@``(0```&NZ```%
M````C;H``!,```"3N@``"P```*>Z```2````L[H```H```#&N@``#P```-&Z
M```-````X;H``!$```#ON@``$P````&[```,````%;L```8````BNP``#```
M`"F[```&````-KL``!<````]NP``$````%6[```1````9KL```@```!XNP``
M!0```(&[```,````A[L``!````"4NP``!0```*6[```-````J[L```8```"Y
MNP``!P```,"[```-````R+L```<```#6NP``"P```-Z[```'````ZKL```<`
M``#RNP``"0```/J[```)````!+P```H````.O```&0```!F\```]````,[P`
M`!T```!QO```#````(^\```0````G+P```4```"MO```)0```+.\```2````
MV;P``!,```#LO```*P````"]```[````++T``"````!HO0``"````(F]```V
M````DKT``"$```#)O0``$````.N]```(````_+T```P````%O@``!@```!*^
M```$````&;X```\````>O@``#@```"Z^```'````/;X```H```!%O@``#0``
M`%"^```?````7KX``!P```!^O@``(0```)N^```>````O;X``!D```#<O@``
M'@```/:^```;````%;\``"$````QOP``+@```%._```F````@K\``!P```"I
MOP``'@```,:_```<````Y;\``"8````"P```*P```"G````S````5<```"8`
M``")P```*P```+#````X````W,```!T````5P0``%0```#/!```O````2<$`
M`"````!YP0``$@```)K!```I````K<$``!X```#7P0``(````/;!```2````
M%\(``*(````JP@``%@```,W"```C````Y,(``"@````(PP``*0```#'#```H
M````6\,``!\```"$PP``%0```*3#```@````NL,``"4```#;PP``*`````'$
M```M````*L0``#````!8Q```D@```(G$```A````',4``!8````^Q0``'```
M`%7%```F````<L4``"H```"9Q0``00```,3%``!$````!L8```P```!+Q@``
M!P```%C&```'````8,8```8```!HQ@``#0```&_&```0````?<8``!(```".
MQ@``$P```*'&```2````M<8```<```#(Q@``!````-#&```0````U<8``!``
M``#FQ@``#````/?&```.````!,<```T````3QP``#P```"''```3````,<<`
M``T```!%QP``*````%/'```#````?,<```T```"`QP``!@```(['```1````
ME<<``!<```"GQP``&P```+_'```.````V\<```(```#JQP``20```.W'```%
M````-\@``!`````]R```#P```$[(```$````7L@```T```!CR```#@```''(
M```#````@,@```X```"$R```"````)/(```/````G,@```\```"LR```!P``
M`+S(```-````Q,@``!````#2R```#0```./(```+````\<@```8```#]R```
M"P````3)```,````$,D```H````=R0``$0```"C)```9````.LD```L```!4
MR0``#0```&#)```B````;LD```\```"1R0``&P```*')```T````O<D```H`
M``#RR0``&````/W)```2````%LH``!D````IR@``%@```$/*```B````6LH`
M``T```!]R@``!P```(O*```4````D\H```L```"HR@``(@```+3*```O````
MU\H```L````'RP``"0```!/+```9````'<L```L````WRP``%P```$/+```7
M````6\L```D```!SRP``%@```'W+```/````E,L``!D```"DRP``%@```+[+
M```.````U<L``!@```#DRP``"````/W+```-````!LP``"8````4S```0P``
M`#O,```(````?\P``!(```"(S```'P```)O,```(````N\P```L```#$S```
M+P```-#,```.`````,T```4````/S0``!@```!7-``!%````',T```,```!B
MS0``!P```&;-```$````;LT```H```!SS0``"@```'[-```/````B<T``!``
M``"9S0``%P```*K-```1````PLT``!D```#4S0``%P```.[-```)````!LX`
M``4````0S@``"P```!;.```*````(LX```(````MS@``!0```##.```-````
M-LX``!L```!$S@``%P```&#.```4````>,X```D```"-S@``#@```)?.```-
M````ILX``!(```"TS@``.````,?.```@`````,\```@````ASP``#@```"K/
M``![````.<\``!@```"USP``&````,[/```1````Y\\```<```#YSP``!0``
M``'0```8````!]```!X````@T```&P```#_0```9````6]```!L```!UT```
M&0```)'0```3````J]````<```"_T```"````,?0```&````T-````8```#7
MT```$````-[0```/````[]```!````#_T```#P```!#1```+````(-$```\`
M```LT0``#````#S1```/````2=$```<```!9T0``!@```&'1```.````:-$`
M``P```!WT0``*````(31```/````K=$```@```"]T0``"````,;1```3````
MS]$``!X```#CT0``(0````+2```@````)-(``!D```!%T@``%P```%_2```E
M````=](``!<```"=T@``%@```+72```$````S-(``!L```#1T@``#0```.W2
M```,````^](```,````(TP``!0````S3```(````$M,```H````;TP``#```
M`";3```+````,],``!`````_TP``#````%#3```.````7=,```L```!LTP``
M!````'C3```$````?=,``!,```""TP``%````);3```,````J],```D```"X
MTP``#@```,+3```+````T=,``!L```#=TP``!P```/G3```'`````=0```H`
M```)U```#0```!34```)````(M0```0````LU```!0```#'4```#````-]0`
M`!@````[U```"@```%34```$````7]0``"8```!DU```#@```(O4``!\````
MFM0``!4````7U0``!0```"W5```'````,]4```P````[U0``"````$C5```*
M````4=4```8```!<U0``"````&/5```"````;-4```8```!OU0``!@```';5
M```4````?=4```T```"2U0``$````*#5```;````L=4```0```#-U0``"0``
M`-+5```0````W-4```D```#MU0``"0```/?5```%`````=8``!H````'U@``
M"````"+6```&````*]8``!D````RU@``#@```$S6```'````6]8```<```!C
MU@``!0```&O6```)````<=8```H```![U@``#@```(;6```"````E=8```8`
M``"8U@``"P```)_6```-````J]8```D```"YU@``!@```,/6```2````RM8`
M``D```#=U@``!P```.?6```4````[]8``!T````$UP``0@```"+7```E````
M9=<``"4```"+UP``!@```+'7```*````N-<```0```##UP``"0```,C7```(
M````TM<``!$```#;UP``"0```.W7```&````]]<```T```#^UP``!@````S8
M```$````$]@``#D````8V```/0```%+8```Z````D-@``!X```#+V```!0``
M`.K8```.````\-@```0```#_V```!@````39```'````"]D``"$````3V0``
M#0```#79```5````0]D```8```!9V0``!````&#9```1````9=D```8```!W
MV0``"@```'[9```B````B=D```0```"LV0``!0```+'9```=````M]D```0`
M``#5V0``#````-K9```.````Y]D```H```#VV0``"`````':```)````"MH`
M``4````4V@``.@```!K:```P````5=H``#4```"&V@``*0```+S:``!'````
MYMH``#@````NVP``*0```&?;```_````D=L``"X```#1VP``+0````#<```?
M````+MP```\```!.W```$@```%[<```+````<=P``"8```!]W```*0```*3<
M```D````SMP``"8```#SW```"````!K=```*````(]T```D````NW0``!P``
M`#C=```@````0-T``"````!AW0``)@```(+=```*````J=T``!D```"TW0``
M*0```,[=```6````^-T``!(````/W@``!P```"+>```*````*MX```P````U
MW@``#P```$+>```0````4MX``$````!CW@``<````*3>``!F````%=\```X`
M``!\WP``"0```(O?```*````E=\``!(```"@WP``$P```+/?```,````Q]\`
M``8```#4WP``#P```-O?```2````Z]\``!````#^WP``$0````_@```<````
M(>```",````^X```:@```&+@```/````S>````4```#=X```$````./@```)
M````].````0```#^X```"P````/A```@````#^$``!0````PX0``#````$7A
M```,````4N$```\```!?X0``%0```&_A```I````A>$``"H```"OX0``)@``
M`-KA```G`````>(``"D````IX@``*@```%/B```9````?N(``$(```"8X@``
M$0```-OB```2````[>(``!,`````XP``%````!3C```/````*>,``!8````Y
MXP``%P```%#C```0````:.,``!$```!YXP``-````(OC```3````P.,``!(`
M``#4XP``-0```.?C```4````'>0```<````RY```#````#KD```@````1^0`
M`!````!HY```%````'GD```1````CN0``!<```"@Y```'````+CD```3````
MU>0``!0```#IY```&@```/[D```1````&>4``!H````KY0``'@```$;E```:
M````9>4``!,```"`Y0``%0```)3E```1````JN4``!<```"\Y0``%````-3E
M```7````Z>4``!4````!Y@``"0```!?F```0````(>8``!D````RY@``!```
M`$SF```'````4>8```L```!9Y@``$0```&7F```&````=^8```8```!^Y@``
M!@```(7F```%````C.8```<```"2Y@``!P```)KF```%````HN8``!8```"H
MY@``!@```+_F```&````QN8```0```#-Y@``!````-+F```'````U^8```X`
M``#?Y@``#````.[F```,````^^8```T````(YP``"@```!;G```.````(><`
M``4````PYP``*````#;G```.````7^<```P```!NYP``#P```'OG```*````
MB^<```@```"6YP``"0```)_G```K````J><```0```#5YP``"````-KG```F
M````X^<``!(````*Z```#P```!WH```&````+>@```H````TZ```!P```#_H
M```(````1^@``"````!0Z```"0```''H```4````>^@```P```"0Z```#0``
M`)WH```.````J^@``!8```"ZZ```$0```-'H```&````X^@```,```#JZ```
M!@```.[H```9````]>@```<````/Z0``!````!?I```+````'.D```L````H
MZ0``!P```#3I```%````/.D```<```!"Z0``%@```$KI```-````8>D```T`
M``!OZ0``"@```'WI```0````B.D```\```"9Z0``$0```*GI```7````N^D`
M``H```#3Z0``$0```-[I```(````\.D```0```#YZ0``#P```/[I```Z````
M#NH```4```!)Z@``#````$_J```>````7.H```X```![Z@``$````(KJ```+
M````F^H```P```"GZ@``"0```+3J```'````ONH```H```#&Z@``"0```-'J
M```.````V^H``!````#JZ@``&P```/OJ```8````%^L``!H````PZP``"@``
M`$OK```)````5NL```H```!@ZP``#````&OK```/````>.L```@```"(ZP``
M!@```)'K```<````F.L```<```"UZP``!0```+WK```+````P^L``$<```#/
MZP``#0```!?L```)````)>P```0````O[````P```#3L```3````..P``!,`
M``!,[```$P```&#L```*````=.P```(```!_[```!````(+L```E````A^P`
M``,```"M[```!0```+'L```J````M^P```H```#B[```!0```.WL```$````
M\^P```H```#X[```#0````/M```&````$>T```@````8[0``"````"'M```$
M````*NT```4````O[0``:````#7M```)````GNT```P```"H[0``$````+7M
M```%````QNT```8```#,[0``&P```-/M```O````[^T``!`````?[@``"@``
M`##N```/````.^X```H```!+[@``"0```%;N```3````8.X``!L```!T[@``
M&````)#N```7````J>X``!\```#![@``#@```.'N```#````\.X```<```#T
M[@``"````/SN```'````!>\```H````-[P``"P```!CO```'````).\``%$`
M```L[P``$````'[O```,````C^\```T```"<[P``&@```*KO``!*````Q>\`
M`!D````0\```!@```"KP```:````,?```"4```!,\```!@```'+P```&````
M>?```!\```"`\```!@```*#P```)````I_```!@```"Q\```%P```,KP```H
M````XO````8````+\0``#0```!+Q```B````(/$``%<```!#\0``$P```)OQ
M```C````K_$``!,```#3\0```@```.?Q```+````ZO$```@```#V\0``#0``
M`/_Q```*````#?(```<````8\@``%````"#R```&````-?(```@````\\@``
M#@```$7R```'````5/(```H```!<\@``"P```&?R```R````<_(```<```"F
M\@``#````*[R```-````N_(``!<```#)\@``#````.'R```)````[O(```D`
M``#X\@``"@````+S```'````#?,```D````5\P``!P```!_S```*````)_,`
M`!L````R\P``#P```$[S```2````7O,```H```!Q\P``%@```'SS```)````
MD_,``!````"=\P``!P```*[S```2````MO,```0```#)\P``!P```,[S```%
M````UO,```4```#<\P``"P```.+S```4````[O,``!$````#]```&@```!7T
M```6````,/0``!0```!']```%P```%ST```8````=/0``!P```"-]```&0``
M`*KT```'````Q/0```4```#,]```#0```-+T```,````X/0```@```#M]```
M%P```/;T```+````#O4```P````:]0``'P```"?U```:````1_4``!,```!B
M]0``!````';U```*````>_4```0```"&]0``#0```(OU```,````F?4```4`
M``"F]0``"0```*SU```%````MO4```<```"\]0``!0```,3U```$````RO4`
M``(```#/]0``.````-+U```L````"_8``!(````X]@``*0```$OV```R````
M=?8```H```"H]@``+````+/V```N````X/8``#,````/]P``,P```$/W```X
M````=_<```\```"P]P``&````,#W```0````V?<```\```#J]P``$P```/KW
M```5````#O@``!0````D^```$@```#GX```4````3/@``!4```!A^```+0``
M`'?X```M````I?@``#$```#3^```+@````7Y```O````-/D``"P```!D^0``
M8@```)'Y```3````]/D```T````(^@``"````!;Z```7````'_H```@````W
M^@``#````$#Z```K````3?H``"$```!Y^@``&@```)OZ```)````MOH``$4`
M``#`^@``00````;[```$````2/L``!,```!-^P``%````&'[```.````=OL`
M`!,```"%^P``&````)G[```&````LOL```D```"Y^P``"@```,/[```/````
MSOL``!````#>^P``!P```._[```.````]_L```4````&_```&P````S\```(
M````*/P```8````Q_```%````#C\```1````3?P```X```!?_```.````&[\
M```"````I_P```8```"J_```#@```+'\```%````P/P```<```#&_```#@``
M`,[\```&````W?P``"@```#D_```#`````W]```<````&OT```0````W_0``
M*0```#S]```7````9OT``!\```!^_0``7````)[]```4````^_T``#X````0
M_@``'P```$_^```0````;_X```<```"`_@``#@```(C^```,````E_X```P`
M``"D_@``$P```+'^```*````Q?X``!T```#0_@``&0```.[^```%````"/\`
M`!$````._P``$0```"#_```D````,O\``!(```!7_P``%0```&K_```2````
M@/\```X```"3_P``&0```*+_```(````O/\```D```#%_P``#0```,__```'
M````W?\```H```#E_P``!P```/#_```/````^/\```8````(``$`"P````\`
M`0`:````&P`!``H````V``$`!P```$$``0`(````20`!``4```!2``$`'P``
M`%@``0`&````>``!`!````!_``$`"````)```0`-````F0`!``@```"G``$`
M'@```+```0`2````SP`!`"P```#B``$`&@````\!`0`)````*@$!``H````T
M`0$`%0```#\!`0`%````50$!`!0```!;`0$`!````'`!`0`0````=0$!``8`
M``"&`0$`!P```(T!`0`>````E0$!`"@```"T`0$`"@```-T!`0`<````Z`$!
M`!$````%`@$`"P```!<"`0`:````(P(!`!0````^`@$`!````%,"`0`$````
M6`(!``L```!=`@$`!0```&D"`0`&````;P(!``@```!V`@$`!@```'\"`0`*
M````A@(!`!L```"1`@$`-````*T"`0`T````X@(!`"`````7`P$`*0```#@#
M`0`@````8@,!`$$```"#`P$`&@```,4#`0`H````X`,!`"D````)!`$`4```
M`#,$`0`B````A`0!``8```"G!`$`"````*X$`0`%````MP0!``@```"]!`$`
M&0```,8$`0`9````X`0!`"H```#Z!`$`(P```"4%`0`9````204!`"X```!C
M!0$`-````)(%`0`(````QP4!`!<```#0!0$`"@```.@%`0`'````\P4!`"$`
M``#[!0$`$````!T&`0`.````+@8!``L````]!@$`!P```$D&`0`3````408!
M``@```!E!@$`"P```&X&`0`*````>@8!`!0```"%!@$`#P```)H&`0`R````
MJ@8!``L```#=!@$`#@```.D&`0`%````^`8!``4```#^!@$`!0````0'`0`7
M````"@<!``\````B!P$`!````#('`0`*````-P<!``D```!"!P$`"P```$P'
M`0`-````6`<!``P```!F!P$`#@```','`0`%````@@<!``0```"(!P$`#0``
M`(T'`0`R````FP<!`$4```#.!P$`%P```!0(`0`'````+`@!`!X````T"`$`
M%````%,(`0`%````:`@!`!0```!N"`$`!@```(,(`0`'````B@@!``X```"2
M"`$`*@```*$(`0`&````S`@!``P```#3"`$`#0```.`(`0`1````[@@!``L`
M````"0$`-@````P)`0`*````0PD!`"(```!."0$`"P```'$)`0`/````?0D!
M`#(```"-"0$`)0```,`)`0`P````Y@D!`#$````7"@$`+0```$D*`0`.````
M=PH!``4```"&"@$`#@```(P*`0`3````FPH!`!(```"O"@$`!P```,(*`0`1
M````R@H!`!,```#<"@$`!P```/`*`0`4````^`H!`!@````-"P$`!P```"8+
M`0`%````+@L!``P````T"P$`#````$$+`0`2````3@L!``0```!A"P$`!P``
M`&8+`0`*````;@L!``L```!Y"P$`#````(4+`0`.````D@L!``X```"A"P$`
M!0```+`+`0`%````M@L!`"X```"\"P$`)@```.L+`0`C````$@P!``,````V
M#`$`$@```#H,`0`&````30P!`!X```!4#`$`&````',,`0`E````C`P!``T`
M``"R#`$`"0```,`,`0`?````R@P!``,```#J#`$`!P```.X,`0`*````]@P!
M``(````!#0$`#`````0-`0`5````$0T!``L````G#0$`&0```#,-`0`@````
M30T!`!(```!N#0$`!0```($-`0`*````APT!`!4```"2#0$`$@```*@-`0`,
M````NPT!``0```#(#0$`"0```,T-`0`'````UPT!``P```#?#0$`4@```.P-
M`0`7````/PX!`"0```!7#@$`$@```'P.`0`'````CPX!``8```"7#@$`#@``
M`)X.`0`,````K0X!``T```"Z#@$`%0```,@.`0`2````W@X!``\```#Q#@$`
M%`````$/`0`*````%@\!`!L````A#P$`$````#T/`0`+````3@\!`&D```!:
M#P$`&@```,0/`0`7````WP\!`"<```#W#P$`&@```!\0`0`7````.A`!`!L`
M``!2$`$`&0```&X0`0`?````B!`!`!,```"H$`$`"````+P0`0`'````Q1`!
M``@```#-$`$`"0```-80`0`5````X!`!``T```#V$`$`(P````01`0`-````
M*!$!`!,````V$0$`"````$H1`0`#````4Q$!`$8```!7$0$`/P```)X1`0`W
M````WA$!`%<````6$@$`!0```&X2`0`?````=!(!`"\```"4$@$`"@```,02
M`0`(````SQ(!``T```#8$@$`+0```.82`0`$````%!,!`$\````9$P$`)0``
M`&D3`0`<````CQ,!``L```"L$P$`'P```+@3`0`=````V!,!`"4```#V$P$`
M(````!P4`0`D````/10!`"````!B%`$`"P```(,4`0`'````CQ0!``T```"7
M%`$`#````*44`0`7````LA0!``8```#*%`$`.0```-$4`0`,````"Q4!``<`
M```8%0$`"0```"`5`0`3````*A4!``D````^%0$`!````$@5`0`0````314!
M``@```!>%0$`"````&<5`0`$````<!4!``L```!U%0$`#````($5`0`2````
MCA4!`!$```"A%0$`#````+,5`0`:````P!4!``\```#;%0$`!P```.L5`0`-
M````\Q4!`!0````!%@$`#@```!86`0`,````)18!`!L````R%@$`+````$X6
M`0`3````>Q8!`!P```"/%@$`*````*P6`0`&````U18!``<```#<%@$`$P``
M`.06`0`%````^!8!``0```#^%@$`%P````,7`0`*````&Q<!``P````F%P$`
M"0```#,7`0`&````/1<!``D```!$%P$`"````$X7`0`)````5Q<!``H```!A
M%P$`$0```&P7`0`&````?A<!``X```"%%P$`#@```)07`0`-````HQ<!``L`
M``"Q%P$`'0```+T7`0`+````VQ<!``(```#G%P$`'````.H7`0`'````!Q@!
M``8````/&`$`9````!88`0`)````>Q@!``<```"%&`$`)@```(T8`0`X````
MM!@!`!H```#M&`$`*@````@9`0`[````,QD!`"@```!O&0$`-````)@9`0`9
M````S1D!`!4```#G&0$`!0```/T9`0`'`````QH!``@````+&@$`!P```!0:
M`0`%````'!H!``<````B&@$`#@```"H:`0`)````.1H!``8```!#&@$`"```
M`$H:`0`+````4QH!``<```!?&@$`"````&<:`0`'````<!H!`!8```!X&@$`
M"0```(\:`0`&````F1H!``L```"@&@$`$````*P:`0`&````O1H!`!P```#$
M&@$`%````.$:`0`'````]AH!`!$```#^&@$`"````!`;`0`.````&1L!``@`
M```H&P$`$````#$;`0`)````0AL!`!````!,&P$`!@```%T;`0`9````9!L!
M``H```!^&P$`'````(D;`0`'````IAL!``4```"N&P$`$````+0;`0`4````
MQ1L!``L```#:&P$`#0```.8;`0`H````]!L!`!@````='`$`%P```#8<`0`$
M````3AP!``D```!3'`$`"@```%T<`0`'````:!P!``(```!P'`$`#@```',<
M`0`(````@AP!`",```"+'`$`'P```*\<`0`X````SQP!`"8````('0$`,0``
M`"\=`0`G````81T!`&0```")'0$`%````.X=`0!5`````QX!`#@```!9'@$`
M2@```)(>`0!;````W1X!`"@````Y'P$`.````&(?`0`H````FQ\!`"P```#$
M'P$`)@```/$?`0`;````&"`!`#X````T(`$`J0$``',@`0`C````'2(!`!<`
M``!!(@$`2````%DB`0"%````HB(!`#`````H(P$`)0```%DC`0!!````?R,!
M`%L```#!(P$`20```!TD`0`Q````9R0!`!T```"9)`$`&````+<D`0`K````
MT"0!`"$```#\)`$`'P```!XE`0`K````/B4!`"8```!J)0$`)P```)$E`0`Z
M````N24!`!T```#T)0$`$0```!(F`0`S````)"8!`"4```!8)@$`)P```'XF
M`0`@````IB8!`!\```#')@$`,````.<F`0!I````&"<!`#$```"")P$`00``
M`+0G`0`S````]B<!`"4````J*`$`/0```%`H`0!E````CB@!`$T```#T*`$`
M+P```$(I`0`N````<BD!`#````"A*0$`5````-(I`0!:````)RH!`$@```""
M*@$`2@```,LJ`0`R````%BL!`"\```!)*P$`+````'DK`0`M````IBL!`'$`
M``#4*P$`9@```$8L`0!O````K2P!`+,````=+0$`%P```-$M`0`E````Z2T!
M`#(````/+@$`*0```$(N`0`^````;"X!`"(```"K+@$`4@```,XN`0`E````
M(2\!``L```!'+P$`L0```%,O`0!%````!3`!`"$```!+,`$`,````&TP`0`E
M````GC`!`!P```#$,`$`,0```.$P`0`'````$S$!``<````;,0$`!````",Q
M`0`-````*#$!``L````V,0$`#@```$(Q`0`+````43$!``4```!=,0$`$```
M`&,Q`0`"````=#$!`%D```!W,0$`!0```-$Q`0`2````US$!``0```#J,0$`
M!P```.\Q`0`(````]S$!``4`````,@$`,`````8R`0`#````-S(!`!`````[
M,@$`#````$PR`0`3````63(!``T```!M,@$``@```'LR`0`'````?C(!``8`
M``"&,@$`%````(TR`0`,````HC(!`!@```"O,@$`!@```,@R`0`2````SS(!
M``P```#B,@$``P```.\R`0`J````\S(!``0````>,P$`!@```",S`0`'````
M*C,!`!\````R,P$`-0```%(S`0`N````B#,!`"\```"W,P$`%P```.<S`0`B
M````_S,!`"4````B-`$`(````$@T`0`;````:30!`!@```"%-`$`)````)XT
M`0`?````PS0!`!H```#C-`$`(0```/XT`0`@````(#4!`!H```!!-0$`,@``
M`%PU`0`:````CS4!`"\```"J-0$`*P```-HU`0`?````!C8!`",````F-@$`
M'P```$HV`0`:````:C8!`"$```"%-@$`)0```*<V`0`F````S38!`"4```#T
M-@$`)````!HW`0`8````/S<!`!T```!8-P$`)````'8W`0`8````FS<!`"(`
M``"T-P$`+````-<W`0`O````!#@!`!4````T.`$`)0```$HX`0`\````<#@!
M`!\```"M.`$`(P```,TX`0`?````\3@!`"`````1.0$`&@```#(Y`0`8````
M33D!`"8```!F.0$`'@```(TY`0`I````K#D!`!X```#6.0$`,0```/4Y`0`)
M````)SH!``P````Q.@$`%P```#XZ`0`O````5CH!`"0```"&.@$`!P```*LZ
M`0`/````LSH!`!0```##.@$`#@```-@Z`0`-````YSH!`"0```#U.@$`!0``
M`!H[`0`'````(#L!`"(````H.P$`)0```$L[`0`:````<3L!`!T```",.P$`
M&@```*H[`0`'````Q3L!`,<```#-.P$`"P```)4\`0`5````H3P!``8```"W
M/`$`"0```+X\`0`+````R#P!``T```#4/`$`%P```.(\`0`&````^CP!`#,`
M```!/0$`$P```#4]`0`3````23T!``<```!=/0$`#P```&4]`0`'````=3T!
M`#(```!]/0$`!````+`]`0`A````M3T!`!,```#7/0$`#````.L]`0`1````
M^#T!`#(````*/@$`%@```#T^`0`(````5#X!`!T```!=/@$`"0```'L^`0`*
M````A3X!`!0```"0/@$`"@```*4^`0`=````L#X!``@```#./@$`'P```-<^
M`0`(````]SX!`!H`````/P$`)P```!L_`0`&````0S\!`!4```!*/P$`!P``
M`&`_`0`(````:#\!``D```!Q/P$`/P```'L_`0`'````NS\!``\```##/P$`
M#@```-,_`0`0````XC\!``D```#S/P$`"0```/T_`0`(````!T`!`!,````0
M0`$`!P```"1``0`9````+$`!``H```!&0`$`%P```%%``0`4````:4`!``H`
M``!^0`$`#````(E``0`7````ED`!``0```"N0`$`*@```+-``0`,````WD`!
M`!$```#K0`$`!P```/U``0`"````!4$!`!`````(00$`&````!E!`0`+````
M,D$!``,````^00$`"````$)!`0`&````2T$!``<```!200$`#0```%I!`0`+
M````:$$!`!0```!T00$`%0```(E!`0`.````GT$!`"\```"N00$`(````-Y!
M`0`<````_T$!`!4````<0@$`#````#)"`0`Q````/T(!``4```!Q0@$`$@``
M`'="`0`_````BD(!`!(```#*0@$`"@```-U"`0`&````Z$(!``0```#O0@$`
M!````/1"`0`*````^4(!`!,````$0P$`!0```!A#`0`&````'D,!``8````E
M0P$`"````"Q#`0`$````-4,!``P````Z0P$`"@```$=#`0`Y````4D,!`"X`
M``",0P$`*0```+M#`0`%````Y4,!`!@```#K0P$`&0````1$`0`?````'D0!
M`!T````^1`$`$0```%Q$`0`"````;D0!``0```!Q1`$`"@```'9$`0`&````
M@40!``4```"(1`$``P```(Y$`0`,````DD0!`$4```"?1`$`,@```.5$`0`:
M````&$4!`#0````S10$`*````&A%`0!3````D44!`!D```#E10$`<@```/]%
M`0`@````<D8!`#4```"31@$`(0```,E&`0!%````ZT8!`#`````Q1P$`*```
M`&)'`0`I````BT<!`"8```"U1P$`)0```-Q'`0`H`````D@!`"@````K2`$`
M(@```%1(`0`K````=T@!`#````"C2`$`$@```-1(`0`3````YT@!`!````#[
M2`$`>0````Q)`0`)````ADD!`*$```"020$`<P```#)*`0!\````IDH!`"L`
M```C2P$`5````$]+`0`7````I$L!`"<```"\2P$`%@```.1+`0`/````^TL!
M`!<````+3`$`'P```"-,`0!`````0TP!`!\```"$3`$`'````*1,`0!1````
MP4P!`!H````330$`%````"Y-`0`*````0TT!``4```!.30$`!@```%1-`0`(
M````6TT!``4```!D30$`$@```&I-`0`0````?4T!`!,```".30$`'0```*)-
M`0`/````P$T!``\```#030$`!````.!-`0`)````Y4T!``L```#O30$`!P``
M`/M-`0`%`````TX!`!0````)3@$`!P```!Y.`0`(````)DX!``\````O3@$`
M"````#].`0`,````2$X!``\```!53@$`!@```&5.`0`4````;$X!``8```"!
M3@$`#````(A.`0`1````E4X!``@```"G3@$`!````+!.`0`9````M4X!`!$`
M``#/3@$`"@```.%.`0`8````[$X!`!,````%3P$`'````!E/`0`1````-D\!
M``0```!(3P$`#P```$U/`0`'````74\!``0```!E3P$`&0```&I/`0`'````
MA$\!``(```",3P$``@```(]/`0`1````DD\!``D```"D3P$`!@```*Y/`0`2
M````M4\!`!<```#(3P$`!@```.!/`0`G````YT\!``(````/4`$`!````!)0
M`0`/````%U`!`!,````G4`$`!P```#M0`0`'````0U`!`!$```!+4`$`!@``
M`%U0`0`8````9%`!``8```!]4`$`$P```(10`0`0````F%`!`!(```"I4`$`
M`@```+Q0`0`&````OU`!``P```#&4`$`"0```--0`0`1````W5`!`"(```#O
M4`$`!P```!)1`0`'````&E$!``L````B40$`!0```"Y1`0`"````-%$!``L`
M```W40$`6`$``$-1`0`/````G%(!`!,```"L4@$`#@```,!2`0`(````SU(!
M``D```#84@$`"@```.)2`0`%````[5(!`!H```#S4@$`'P````Y3`0`R````
M+E,!`#````!A4P$`*0```))3`0`H````O%,!`!X```#E4P$`,P````14`0`,
M````.%0!`"<```!%5`$`$@```&U4`0`,````@%0!`!````"-5`$`!0```)Y4
M`0`A````I%0!`!````#&5`$`$````-=4`0`6````Z%0!`!4```#_5`$`#```
M`!55`0"%````(E4!`!````"H50$`"@```+E5`0`2````Q%4!`!````#750$`
M#@```.A5`0`,````]U4!``X````$5@$`$0```!-6`0`&````)58!`,$````L
M5@$`!P```.Y6`0`+````]E8!`!H````"5P$`#P```!U7`0`1````+5<!`!$`
M```_5P$`"@```%%7`0`'````7%<!`"P```!D5P$`)````)%7`0!5````ME<!
M`&$````,6`$`>0```&Y8`0!X````Z%@!`'P```!A60$`>P```-Y9`0!8````
M6EH!`!$```"S6@$`&0```,5:`0`0````WUH!`!(```#P6@$`&`````-;`0`%
M````'%L!``8````B6P$`$@```"E;`0`'````/%L!``T```!$6P$`#0```%);
M`0`W````8%L!`"X```"86P$`$@```,=;`0`-````VEL!`!(```#H6P$`"P``
M`/M;`0`*````!UP!`!L````27`$`&P```"Y<`0`0````2EP!`!8```!;7`$`
M%@```')<`0`>````B5P!`!X```"H7`$`)0```,=<`0`1````[5P!`!H```#_
M7`$`#P```!I=`0`J````*ET!`!H```!570$`'P```'!=`0`3````D%T!`'H`
M``"D70$`0@```!]>`0`O````8EX!``<```"27@$`"@```)I>`0`P````I5X!
M``X```#67@$`!P```.5>`0`+````[5X!``@```#Y7@$`"`````)?`0`)````
M"U\!``L````57P$`#````"%?`0`$````+E\!`!0````S7P$`#````$A?`0`+
M````55\!`!````!A7P$`&0```')?`0`F````C%\!`!$```"S7P$`&@```,5?
M`0`:````X%\!`!X```#[7P$`&````!I@`0`4````,V`!`!(```!(8`$`$@``
M`%M@`0`G````;F`!`"<```"68`$`!P```+Y@`0`&````QF`!``@```#-8`$`
M#@```-9@`0`'````Y6`!``D```#M8`$`$P```/=@`0`)````"V$!``\````5
M80$`%0```"5A`0`8````.V$!``H```!480$`#P```%]A`0`%````;V$!`!<`
M``!U80$`"P```(UA`0`*````F6$!`$L```"D80$`10```/!A`0`+````-F(!
M``@```!"8@$`%0```$MB`0`%````86(!``4```!G8@$`$````&UB`0`+````
M?F(!`!<```"*8@$`+@```*)B`0`0````T6(!`#T```#B8@$`/````"!C`0`_
M````76,!`#\```"=8P$`"0```-UC`0`&````YV,!``H```#N8P$`"@```/EC
M`0!!````!&0!`#T```!&9`$`0````(1D`0!Q````Q60!`#\````W90$`0P``
M`'=E`0!3````NV4!`%`````/9@$`/P```&!F`0!1````H&8!`#,```#R9@$`
M-P```"9G`0!7````7F<!`#\```"V9P$`0P```/9G`0`J````.F@!`"````!E
M:`$`'````(9H`0`]````HV@!`"D```#A:`$`*0````MI`0`2````-6D!``T`
M``!(:0$`#0```%9I`0`+````9&D!`!````!P:0$`&P```(%I`0`?````G6D!
M``<```"]:0$`!P```,5I`0`6````S6D!``L```#D:0$`"````/!I`0`M````
M^6D!``H````G:@$`"@```#)J`0`'````/6H!``8```!%:@$`!0```$QJ`0`(
M````4FH!``8```!;:@$`"@```&)J`0`M````;6H!`!(```";:@$`"````*YJ
M`0`$````MVH!``@```"\:@$`"P```,5J`0`$````T6H!``P```#6:@$`!@``
M`.-J`0`3````ZFH!``8```#^:@$`"`````5K`0`%````#FL!``L````4:P$`
M"0```"!K`0`I````*FL!`!$```!4:P$`"0```&9K`0`3````<&L!``P```"$
M:P$`!P```)%K`0`#````F6L!``,```"=:P$`%P```*%K`0`7````N6L!`#<`
M``#1:P$`"`````EL`0`)````$FP!``H````<;`$`!P```"=L`0!C````+VP!
M`"P```"3;`$`.@```,!L`0`\````^VP!`"H````X;0$`!@```&-M`0`)````
M:FT!`!@```!T;0$`+````(UM`0`E````NFT!`#8```#@;0$`,@```!=N`0`S
M````2FX!`)$```!^;@$`2````!!O`0`)````66\!``L```!C;P$`"````&]O
M`0`=````>&\!``T```"6;P$`#````*1O`0`3````L6\!``T```#%;P$`$P``
M`--O`0`.````YV\!``P```#V;P$`%@````-P`0`)````&G`!`!P````D<`$`
M'0```$%P`0`1````7W`!`!(```!Q<`$`%0```(1P`0`&````FG`!``8```"A
M<`$`%P```*AP`0"$````P'`!`'L```!%<0$`!P```,%Q`0`3````R7$!``4`
M``#=<0$`!0```.-Q`0`?````Z7$!`!X````)<@$`%````"AR`0`7````/7(!
M`!X```!5<@$`-````'1R`0`O````J7(!``\```#9<@$`*````.ER`0`&````
M$G,!`!@````9<P$`%````#)S`0`9````1W,!`!4```!A<P$`%0```'=S`0`1
M````C7,!``H```"?<P$`$P```*IS`0`1````OG,!``8```#0<P$`"P```-=S
M`0`'````XW,!``L```#K<P$`#@```/=S`0`7````!G0!``D````>=`$`!0``
M`"AT`0`+````+G0!``@````Z=`$`"````$-T`0`4````3'0!``8```!A=`$`
M!@```&AT`0`,````;W0!``D```!\=`$`$````(9T`0`'````EW0!``4```"?
M=`$`"````*5T`0`+````KG0!``L```"Z=`$`&@```,9T`0!$````X70!`"L`
M```F=0$`$````%)U`0`3````8W4!``4```!W=0$`'````'UU`0`:````FG4!
M`!L```"U=0$`/0```-%U`0!,````#W8!`"@```!<=@$`"````(5V`0`]````
MCG8!`"0```#,=@$`#P```/%V`0`&`````7<!``L````(=P$`!@```!1W`0`(
M````&W<!`!L````D=P$`$````$!W`0`)````47<!``H```!;=P$`#@```&9W
M`0`Y````=7<!`#D```"O=P$`.P```.EW`0`[````)7@!`"L```!A>`$`*@``
M`(UX`0`L````N'@!`"H```#E>`$`0@```!!Y`0`O````4WD!`"X```"#>0$`
M,````+)Y`0`H````XWD!`"\````,>@$`/````#QZ`0`^````>7H!`#0```"X
M>@$`,0```.UZ`0`Y````'WL!`"\```!9>P$`,@```(E[`0!&````O'L!`#``
M```#?`$`'P```#1\`0`Z````5'P!`"X```"/?`$`.P```+Y\`0`?````^GP!
M`-P````:?0$`'P```/=]`0`N````%WX!`#$```!&?@$`,@```'A^`0`U````
MJWX!`#````#A?@$`+@```!)_`0`Q````07\!`#D```!S?P$`/````*U_`0!$
M````ZG\!`#P````O@`$`Q0```&R``0`O````,H$!`"(```!B@0$`+P```(6!
M`0`S````M8$!`#X```#I@0$`9````"B"`0!=````C8(!``X```#K@@$`!```
M`/J"`0`%````_X(!``D````%@P$`#@````^#`0`6````'H,!`!4````U@P$`
M#P```$N#`0`2````6X,!``@```!N@P$`!````'>#`0`1````?(,!`!$```".
M@P$`#0```*"#`0`0````KH,!`!$```"_@P$`$````-&#`0`8````XH,!``X`
M``#[@P$`40````J$`0`,````7(0!`!0```!IA`$`!@```'Z$`0`3````A80!
M`!D```"9A`$`'@```+.$`0`5````TH0!``(```#HA`$`2P```.N$`0`'````
M-X4!`!`````_A0$`$````%"%`0`%````884!``T```!GA0$`#0```'6%`0`#
M````@X4!``\```"'A0$`"````)>%`0`&````H(4!`!$```"GA0$`"````+F%
M`0`-````PH4!`!$```#0A0$`#0```.*%`0`,````\(4!``<```#]A0$`#0``
M``6&`0`.````$X8!``L````BA@$`#@```"Z&`0`A````/88!``T```!?A@$`
M#@```&V&`0`F````?(8!`!,```"CA@$`%P```+>&`0`M````SX8!``T```#]
MA@$`'0````N'`0`3````*8<!`!L````]AP$`&@```%F'`0`N````=(<!`!$`
M``"CAP$`"````+6'`0`;````OH<!``P```#:AP$`(@```.>'`0`P````"H@!
M``L````[B`$`"````$>(`0`=````4(@!``H```!NB`$`%0```'F(`0`5````
MCX@!``L```"EB`$`(P```+&(`0`5````U8@!`!\```#KB`$`&0````N)`0`-
M````)8D!`!,````SB0$`"0```$>)`0`-````48D!`"\```!?B0$`40```(^)
M`0`(````X8D!`!<```#JB0$`(@````**`0`-````)8H!`!`````SB@$`-```
M`$2*`0`,````>8H!``8```"&B@$`!0```(V*`0!+````DXH!``8```#?B@$`
M!P```.:*`0`*````[HH!`!````#YB@$`$0````J+`0`1````'(L!`!$````N
MBP$`&@```$"+`0`=````6XL!`!H```!YBP$`&````)2+`0`'````K8L!``<`
M``"UBP$`"P```+V+`0`*````R8L!``(```#4BP$`!0```->+`0`,````W8L!
M`"4```#JBP$`%0```!",`0`6````)HP!``<````]C`$`$````$6,`0`0````
M5HP!`!0```!GC`$`.P```'R,`0`G````N(P!``<```#@C`$`$0```.B,`0"7
M````^HP!`!D```"2C0$`(P```*R-`0`1````T(T!``<```#BC0$`!@```.J-
M`0`F````\8T!`#(````8C@$`,````$N.`0`D````?(X!`"0```"AC@$`'0``
M`,:.`0`?````Y(X!``<````$CP$`"0````R/`0`)````%H\!``8````@CP$`
M#P```">/`0`.````-X\!`!````!&CP$`#@```%>/`0`3````9H\!`!$```!Z
MCP$`$````(R/`0`.````G8\!``D```"LCP$`"@```+:/`0`.````P8\!``P`
M``#0CP$`/0```-V/`0`-````&Y`!``@````ID`$`$````#*0`0`C````0Y`!
M`#,```!GD`$`)P```)N0`0`F````PY`!`"\```#JD`$`*0```!J1`0`V````
M1)$!`"P```![D0$`%0```*B1`0`&````OI$!``X```#%D0$`!@```-21`0`0
M````VY$!``,```#LD0$`!````/"1`0`'````]9$!`!,```#]D0$`%0```!&2
M`0`3````)Y(!`!D````[D@$`"@```%62`0`.````8)(!``L```!OD@$`!P``
M`'N2`0`%````@Y(!`!````")D@$`$@```)J2`0`,````K9(!``D```"ZD@$`
M#````,22`0`/````T9(!`#$```#AD@$`!@```!.3`0`(````&I,!``P````C
MDP$`#@```#"3`0`7````/Y,!``@```!7DP$`"````&"3`0`%````:9,!`"(`
M``!ODP$`#````)*3`0`%````GY,!`"H```"EDP$`$````-"3`0!Q````X9,!
M`!,```!3E`$`"0```&>4`0`*````<90!``T```!\E`$`"P```(J4`0`-````
MEI0!``4```"DE`$`#0```*J4`0`"````N)0!``8```"[E`$`"@```,*4`0`7
M````S90!`!,```#EE`$`%@```/F4`0`Q````$)4!``,```!"E0$`!````$:5
M`0`9````2Y4!``@```!EE0$`$@```&Z5`0`%````@94!`!D```"'E0$`"```
M`*&5`0`&````JI4!`!D```"QE0$`#@```,N5`0`(````VI4!``L```#CE0$`
M!0```.^5`0`)````]94!``<```#_E0$`&`````>6`0`#````()8!``8````D
ME@$`"P```"N6`0`,````-Y8!``H```!$E@$`#````$^6`0`7````7)8!``@`
M``!TE@$`!P```'V6`0`1````A98!`",```"7E@$`4````+N6`0`V````#)<!
M`#H```!#EP$`!P```'Z7`0`*````AI<!``0```"1EP$`"0```):7`0`(````
MH)<!``H```"IEP$`"0```+27`0`&````OI<!``T```#%EP$`!@```-.7`0`$
M````VI<!`#L```#?EP$`/@```!N8`0`]````6I@!`"8```"8F`$`!0```+^8
M`0`0````Q9@!``8```#6F`$`"P```-V8`0`,````Z9@!`!D```#VF`$`$```
M`!"9`0`8````(9D!``0````ZF0$`!0```#^9`0`+````19D!``4```!1F0$`
M"@```%>9`0`>````8ID!``0```"!F0$`"P```(:9`0`,````DID!``H```"?
MF0$`#@```*J9`0`/````N9D!``X```#)F0$`"````-B9`0`)````X9D!``4`
M``#KF0$`,P```/&9`0`S````)9H!`#P```!9F@$`+P```)::`0!.````QIH!
M`$@````5FP$`-0```%Z;`0!6````E)L!`#L```#KFP$`3````"><`0`P````
M=)P!`!$```"EG`$`&0```+><`0`+````T9P!`$,```#=G`$`+P```"&=`0`B
M````49T!`"X```!TG0$`$````*.=`0`2````M)T!``<```#'G0$`!@```,^=
M`0`Q````UIT!`#$````(G@$`.````#J>`0`*````<YX!`!L```!^G@$`*0``
M`)J>`0`?````Q)X!`!,```#DG@$`!@```/B>`0`*````_YX!``P````*GP$`
M#P```!>?`0`9````)Y\!`%\```!!GP$`?0```*&?`0!Z````'Z`!``T```":
MH`$`"````*B@`0`)````L:`!`!````"[H`$`$0```,R@`0`.````WJ`!``8`
M``#MH`$`%P```/2@`0`5````#*$!`!,````BH0$`%````#:A`0`;````2Z$!
M`"H```!GH0$`E0```)*A`0`1````**(!``8````ZH@$`$0```$&B`0`*````
M4Z(!``L```!>H@$`#0```&JB`0`C````>*(!`!8```"<H@$`#P```+.B`0`0
M````PZ(!``T```#4H@$`%P```.*B`0`L````^J(!`"L````GHP$`*P```%.C
M`0`J````?Z,!`#8```"JHP$`-0```.&C`0`<````%Z0!`$\````TI`$`%0``
M`(2D`0`4````FJ0!`!8```"OI`$`%0```,:D`0`6````W*0!`!8```#SI`$`
M%0````JE`0`5````(*4!`!0````VI0$`,P```$NE`0`8````?Z4!`!@```"8
MI0$`.P```+&E`0`2````[:4!``@`````I@$`%`````FF`0`C````'J8!`!0`
M``!"I@$`%````%>F`0`3````;*8!`!D```"`I@$`%@```)JF`0`6````L:8!
M`!L```#(I@$`&0```.2F`0`4````_J8!`!\````3IP$`(@```#.G`0`5````
M5J<!`!4```!LIP$`%P```(*G`0`5````FJ<!`!H```"PIP$`'0```,NG`0`;
M````Z:<!`!@````%J`$`"````!ZH`0`0````)Z@!`!@````XJ`$`!````%&H
M`0`&````5J@!``L```!=J`$`%````&FH`0`&````?J@!``H```"%J`$`!@``
M`)"H`0`'````EZ@!``<```"?J`$`!@```*>H`0`%````KJ@!`!<```"TJ`$`
M!@```,RH`0`)````TZ@!``0```#=J`$`!````.*H`0`)````YZ@!``H```#Q
MJ`$`"0```/RH`0`0````!JD!`!$````7J0$`"@```"FI`0`5````-*D!``4`
M``!*J0$`-0```%"I`0`/````AJD!`!(```"6J0$`'````*FI`0`.````QJD!
M``P```#5J0$`#@```.*I`0!)````\:D!``8````[J@$`"````$*J`0`A````
M2ZH!``X```!MJ@$`$P```'RJ`0`&````D*H!``L```"7J@$`"0```*.J`0`'
M````K:H!``0```"UJ@$`#0```+JJ`0`7````R*H!``\```#@J@$`%@```/"J
M`0`4````!ZL!`!L````<JP$`&@```#BK`0`(````4ZL!``8```!<JP$`!@``
M`&.K`0`=````:JL!``<```"(JP$`!0```)"K`0`1````EJL!``L```"HJP$`
M!P```+2K`0`%````O*L!``<```#"JP$`!@```,JK`0`-````T:L!``H```#?
MJP$`#@```.JK`0`3````^:L!`!4````-K`$`%````".L`0`;````.*P!`!,`
M``!4K`$`%0```&BL`0`(````?JP!``0```"'K`$`$@```(RL`0`7````GZP!
M``4```"WK`$`$0```+VL`0`E````SZP!`!0```#UK`$`%@````JM`0`1````
M(:T!``T````SK0$`#````$&M`0`)````3JT!``\```!8K0$`#@```&BM`0`0
M````=ZT!`!````"(K0$`,````)FM`0`P````RJT!`"P```#[K0$`"0```"BN
M`0`'````,JX!``<````ZK@$`$````$*N`0`0````4ZX!``,```!DK@$`"```
M`&BN`0`@````<:X!``@```"2K@$`"````)NN`0`/````I*X!`&D```"TK@$`
M&0```!ZO`0`+````.*\!``4```!$KP$`!P```$JO`0`:````4J\!`!H```!M
MKP$`$P```(BO`0`)````G*\!``(```"FKP$`!````*FO`0`D````KJ\!``<`
M``#3KP$`!0```-NO`0`O````X:\!``H````1L`$`!0```!RP`0`'````(K`!
M`!0````JL`$`$````#^P`0`&````4+`!``@```!7L`$`"0```&"P`0`$````
M:K`!``4```!OL`$`=````'6P`0`+````ZK`!``X```#VL`$`&`````6Q`0`$
M````'K$!``P````CL0$`)@```#"Q`0`U````5[$!``X```"-L0$`"@```)RQ
M`0`2````I[$!``L```"ZL0$`"0```,:Q`0`9````T+$!`"@```#JL0$`*0``
M`!.R`0`H````/;(!`"````!FL@$`#@```(>R`0`#````EK(!``X```":L@$`
M!P```*FR`0`*````L;(!``H```"\L@$`%````,>R`0`)````W+(!`%H```#F
ML@$`'````$&S`0`.````7K,!``P```!MLP$`&P```'JS`0!,````EK,!`!T`
M``#CLP$`!P````&T`0`D````";0!`#`````NM`$`"````%^T`0`&````:+0!
M`"(```!OM`$`!0```)*T`0`'````F+0!`"D```"@M`$`*````,JT`0`T````
M\[0!``@````HM0$`#0```#&U`0`>````/[4!`&(```!>M0$`&````,&U`0`6
M````VK4!`!4```#QM0$``@````>V`0`+````"K8!``4````6M@$`#@```!RV
M`0`.````*[8!``<````ZM@$`#P```$*V`0`&````4K8!``@```!9M@$`#@``
M`&*V`0`)````<;8!``H```![M@$`"@```(:V`0`W````D;8!``<```#)M@$`
M$@```-&V`0`3````Y+8!`!X```#XM@$`$@```!>W`0`*````*K<!``H````U
MMP$`"P```$"W`0`)````3+<!``H```!6MP$`"0```&&W`0`(````:[<!`!\`
M``!TMP$`$0```)2W`0`/````IK<!``H```"VMP$`"@```,&W`0`+````S+<!
M`!$```#8MP$`!0```.JW`0`9````\+<!``0````*N`$`!P````^X`0`%````
M%[@!``4````=N`$`"P```".X`0`8````+[@!`!(```!(N`$`&0```%NX`0`;
M````=;@!`"(```"1N`$`%@```+2X`0`7````R[@!`!(```#CN`$`%@```/:X
M`0`(````#;D!``,````6N0$`#0```!JY`0`.````*+D!``<````WN0$`'0``
M`#^Y`0`*````7;D!``X```!HN0$`)@```'>Y`0`K````GKD!`!8```#*N0$`
M"P```.&Y`0`+````[;D!``8```#YN0$`$`````"Z`0`5````$;H!``<````G
MN@$`"0```"^Z`0`%````.;H!``<````_N@$`!@```$>Z`0`$````3KH!``0`
M``!3N@$`0````%BZ`0`Z````F;H!`!0```#4N@$`,P```.FZ`0`[````';L!
M`!$```!9NP$`3````&N[`0`Z````N+L!`$L```#SNP$`2P```#^\`0!1````
MB[P!`!<```#=O`$`&0```/6\`0`7````#[T!`!4````GO0$`'0```#V]`0`3
M````6[T!`!H```!OO0$`%````(J]`0`7````G[T!`!P```"WO0$`-P```-2]
M`0`W````#+X!`#L```!$O@$`.````("^`0`Y````N;X!`#8```#SO@$`=0``
M`"J_`0`C````H+\!`"D```#$OP$`#````.Z_`0`<````^[\!``P````8P`$`
M%````"7``0`T````.L`!`"P```!OP`$`,````)S``0`+````S<`!`%P```#9
MP`$`5@```#;!`0`%````C<$!`!D```"3P0$`%@```*W!`0`,````Q,$!`!0`
M``#1P0$`$@```.;!`0`(````^<$!``H````"P@$`"0````W"`0`0````%\(!
M`!0````HP@$`$````#W"`0`2````3L(!``<```!AP@$`)0```&G"`0`(````
MC\(!``0```"8P@$`$@```)W"`0`2````L,(!`!$```##P@$`+P```-7"`0`"
M````!<,!``8````(PP$`#P````_#`0`)````'\,!``<````IPP$`'````#'#
M`0`$````3L,!`#L```!3PP$`#@```(_#`0`8````GL,!``0```"WPP$`+P``
M`+S#`0`9````[,,!`!\````&Q`$`7@```";$`0`7````A<0!`$<```"=Q`$`
M*0```.7$`0`-````#\4!``T````=Q0$`%````"O%`0`1````0,4!``P```!2
MQ0$`%@```%_%`0`,````=L4!`!T```"#Q0$`%@```*'%`0`(````N,4!`!0`
M``#!Q0$`#@```-;%`0`J````Y<4!`!(````0Q@$`&0```"/&`0`8````/<8!
M`!H```!6Q@$`*P```''&`0`(````G<8!``D```"FQ@$`&0```+#&`0`1````
MRL8!`!,```#<Q@$`$@```/#&`0`9`````\<!`!$````=QP$`%````"_'`0`;
M````1,<!``H```!@QP$`#````&O'`0`(````>,<!``4```"!QP$`(0```(?'
M`0`&````J<<!``\```"PQP$`"````,#'`0`1````R<<!``@```#;QP$`'@``
M`.3'`0`1`````\@!`#D````5R`$`&````$_(`0`)````:,@!``H```!RR`$`
M(@```'W(`0`(````H,@!`!\```"IR`$`!````,G(`0`<````SL@!``@```#K
MR`$`!P```/3(`0`<````_,@!`#`````9R0$`!@```$K)`0`@````4<D!`!(`
M``!RR0$`!@```(7)`0`0````C,D!`!,```"=R0$`!````+')`0`)````MLD!
M``L```#`R0$`!P```,S)`0`%````U,D!``@```#:R0$`!0```./)`0`+````
MZ<D!`!\```#UR0$`/@```!7*`0!,````5,H!`"<```"AR@$`-@```,G*`0`G
M`````,L!`%4````HRP$`)P```'[+`0`W````ILL!`#<```#>RP$`BP```!;,
M`0`H````HLP!``4```#+S`$`!P```-',`0`(````V<P!``@```#BS`$`&P``
M`.O,`0`=````!\T!`"H````ES0$`*@```%#-`0`F````>\T!`$````"BS0$`
M1@```./-`0`)````*LX!`!<````TS@$`"P```$S.`0`(````6,X!`#@```!A
MS@$`%@```)K.`0`0````L<X!`!(```#"S@$`"````-7.`0`3````WLX!``@`
M``#RS@$`#0```/O.`0`6````"<\!`"<````@SP$`*````$C/`0!#````<<\!
M``L```"USP$`'0```,'/`0`%````W\\!``<```#ESP$`&````.W/`0`C````
M!M`!``P````JT`$`!0```#?0`0`*````/=`!``P```!(T`$`#````%70`0`+
M````8M`!`!H```!NT`$`"@```(G0`0`*````E-`!``4```"?T`$`$0```*70
M`0!)````M]`!`%T````!T0$`'@```%_1`0`,````?M$!`"8```"+T0$`'```
M`++1`0`2````S]$!`!,```#BT0$`#0```/;1`0`+````!-(!`!`````0T@$`
M+0```"'2`0`)````3](!``T```!9T@$`#@```&?2`0`6````=M(!``P```"-
MT@$`/@```)K2`0`(````V=(!`"D```#BT@$`$`````S3`0`4````'=,!`$4`
M```RTP$`,P```'C3`0`W````K-,!`#0```#DTP$`,````!G4`0`0````2M0!
M``P```!;U`$`%0```&C4`0`>````?M0!`!<```"=U`$`"@```+74`0`7````
MP-0!`!X```#8U`$`!P```/?4`0`:````_]0!`!P````:U0$`!@```#?5`0`&
M````/M4!`!(```!%U0$`#````%C5`0`7````9=4!``4```!]U0$`"````(/5
M`0`.````C-4!`!$```";U0$`$@```*W5`0`3````P-4!`!,```#4U0$`!P``
M`.C5`0`&````\-4!`"@```#WU0$`&P```"#6`0`:````/-8!``<```!7U@$`
M%0```%_6`0`&````==8!`",```!\U@$`(P```*#6`0`K````Q-8!``L```#P
MU@$`"0```/S6`0`C````!M<!``,````JUP$`!@```"[7`0`*````-=<!``(`
M``!`UP$`#````$/7`0`5````4-<!``L```!FUP$`&0```'+7`0`@````C-<!
M`!<```"MUP$`!0```,77`0`*````R]<!`!4```#6UP$`$@```.S7`0`-````
M_]<!``D````-V`$`#@```!?8`0`,````)M@!`!<````SV`$`6````$O8`0`=
M````I-@!`#0```#"V`$`%````/?8`0`,````#-D!``4````9V0$`#0```!_9
M`0`1````+=D!``\````_V0$`(````$_9`0`8````<-D!`!````")V0$`(@``
M`)K9`0`.````O=D!`"8```#,V0$`$````//9`0`0````!-H!`)$````5V@$`
M(@```*?:`0`<````RMH!`#$```#GV@$`(````!G;`0`:````.ML!`"P```!5
MVP$`&@```(+;`0`C````G=L!`!D```#!VP$`#P```-O;`0`'````Z]L!``@`
M``#SVP$`"0```/S;`0`6````!MP!``P````=W`$`*@```"K<`0`2````5=P!
M`!8```!HW`$`"0```'_<`0`,````B=P!`'L```"6W`$`5````!+=`0!%````
M9]T!`'````"MW0$`#0```![>`0`E````+-X!`"P```!2W@$`"@```'_>`0`'
M````BMX!`!4```"2W@$`0@```*C>`0`&````Z]X!`%0```#RW@$`,````$??
M`0`B````>-\!`!(```";WP$`)0```*[?`0`J````U-\!`"\```#_WP$`*0``
M`"_@`0`O````6>`!`"4```")X`$`%0```*_@`0`'````Q>`!``P```#-X`$`
M#@```-K@`0`7````Z>`!``L````!X0$`/0````WA`0`,````2^$!``P```!8
MX0$`"````&7A`0`3````;N$!``@```""X0$`!0```(OA`0`=````D>$!``@`
M``"OX0$`"0```+CA`0`&````PN$!``T```#)X0$`#0```-?A`0`2````Y>$!
M`!0```#XX0$`#`````WB`0`8````&N(!``T````SX@$`"````$'B`0`1````
M2N(!`!X```!<X@$`$````'OB`0`)````C.(!`!H```"6X@$`+````+'B`0`3
M````WN(!`"T```#RX@$`+0```"#C`0`-````3N,!``<```!<XP$`"````&3C
M`0`'````;>,!``0```!UXP$`%0```'KC`0`,````D.,!``T```"=XP$`#```
M`*OC`0`%````N.,!``D```"^XP$`"````,CC`0`)````T>,!``D```#;XP$`
M&````.7C`0`&````_N,!``X````%Y`$`!@```!3D`0`/````&^0!``P````K
MY`$`(````#CD`0`*````6>0!``(```!DY`$`)0```&?D`0`'````C>0!``H`
M``"5Y`$`B@```*#D`0`,````*^4!``8````XY0$`(P```#_E`0`T````8^4!
M`"````"8Y0$`(````+GE`0!7````VN4!`#$````RY@$`-````&3F`0`C````
MF>8!`"````"]Y@$`!0```-[F`0`/````Y.8!``T```#TY@$`#P````+G`0`&
M````$N<!``T````9YP$`$P```"?G`0`/````.^<!``\```!+YP$`$0```%OG
M`0`,````;><!``<```!ZYP$`!P```(+G`0`(````BN<!`!8```"3YP$`"0``
M`*KG`0`(````M.<!``<```"]YP$`'````,7G`0`&````XN<!`!T```#IYP$`
M&0````?H`0`(````(>@!`!,````JZ`$`"````#[H`0`-````1^@!``D```!5
MZ`$`%0```%_H`0`'````=>@!`!4```!]Z`$`!@```)/H`0`;````FN@!``T`
M``"VZ`$`'````,3H`0`%````X>@!``@```#GZ`$`#0```/#H`0`?````_N@!
M``H````>Z0$`#````"GI`0`I````-ND!`!P```!@Z0$`$@```'WI`0`$````
MD.D!``@```"5Z0$`"P```)[I`0`)````JND!``(```"TZ0$`%@```+?I`0`(
M````SND!`"8```#7Z0$`)@```/[I`0`^````)>H!`"\```!DZ@$`-````)3J
M`0`Z````R>H!`&\````$ZP$`"0```'3K`0!L````?NL!`#L```#KZP$`4P``
M`"?L`0!R````>^P!`"D```#N[`$`1P```!CM`0`O````8.T!`#$```"0[0$`
M-````,+M`0`?````]^T!`#X````7[@$`Z`$``%;N`0`B````/_`!``D```!B
M\`$`20```&SP`0"H````MO`!`"L```!?\0$`-0```(OQ`0!#````P?$!`'8`
M```%\@$`2````'SR`0!"````Q?(!`!0````(\P$`"@```!WS`0`]````*/,!
M`!\```!F\P$`(@```(;S`0`P````J?,!`"H```#:\P$`*0````7T`0!0````
M+_0!`!(```"`]`$`"````)/T`0!(````G/0!`#<```#E]`$`*@```!WU`0`G
M````2/4!`"8```!P]0$`*P```)?U`0!H````P_4!`$,````L]@$`1@```'#V
M`0!"````M_8!`#L```#Z]@$`4````#;W`0!M````A_<!`%@```#U]P$`00``
M`$[X`0`]````D/@!`$````#.^`$`9@````_Y`0!X````=OD!`'````#O^0$`
M<````&#Z`0`X````T?H!`"X````*^P$`+@```#G[`0`P````:/L!`(,```"9
M^P$`>````!W\`0!_````EOP!`-,````6_0$`&@```.K]`0`L````!?X!`#8`
M```R_@$`*P```&G^`0!8````E?X!`"T```#N_@$`5P```!S_`0`J````=/\!
M``P```"?_P$`O@```*S_`0!=````:P`"`",```#)``(`.````.T``@`G````
M)@$"`"````!.`0(`0P```&\!`@`&````LP$"``<```"Z`0(`!````,(!`@`-
M````QP$"``H```#5`0(`"P```.`!`@`+````[`$"``4```#X`0(`$````/X!
M`@`"````#P("`%\````2`@(`!0```'("`@`<````>`("``0```"5`@(`!P``
M`)H"`@`&````H@("``4```"I`@(`.@```*\"`@`$````Z@("`!<```#O`@(`
M#0````<#`@`3````%0,"`!`````I`P(``@```#H#`@`(````/0,"``8```!&
M`P(`%0```$T#`@`,````8P,"`!<```!P`P(`!@```(@#`@`.````CP,"``H`
M``">`P(`"````*D#`@`N````L@,"``@```#A`P(`!@```.H#`@`'````\0,"
M`#@```#Y`P(`7````#($`@!(````CP0"`$D```#8!`(`,@```"(%`@`P````
M504"`#,```"&!0(`.````+H%`@`O````\P4"`"H````C!@(`-@```$X&`@`Q
M````A08"`"L```"W!@(`-@```.,&`@`M````&@<"`"T```!(!P(`0@```'8'
M`@`D````N0<"`#\```#>!P(`.@```!X(`@`Q````60@"`#4```"+"`(`,```
M`,$(`@`K````\@@"`#8````>"0(`,@```%4)`@`V````B`D"`#4```"_"0(`
M*P```/4)`@`M````(0H"`#````!/"@(`.P```(`*`@`K````O`H"`"@```#H
M"@(`1@```!$+`@!)````6`L"`"<```"B"P(`-````,H+`@!/````_PL"`#(`
M``!/#`(`-@```((,`@`Q````N0P"`#(```#K#`(`+````!X-`@`I````2PT"
M`"X```!U#0(`,P```*0-`@!&````V`T"`"\````?#@(`8````$\.`@`-````
ML`X"`!P```"^#@(`(@```-L.`@!!````_@X"`"4```!`#P(`$````&8/`@`/
M````=P\"`!P```"'#P(`%@```*0/`@`2````NP\"`"0```#.#P(`"0```/,/
M`@`)````_0\"`"4````'$`(`*````"T0`@`G````5A`"`"<```!^$`(`)```
M`*80`@`)````RQ`"``,!``#5$`(`$@```-D1`@`=````[!$"``X````*$@(`
M$````!D2`@`6````*A("`!@```!!$@(`'P```%H2`@`)````>A("`$X```"$
M$@(`&@```-,2`@`3````[A("``<````"$P(`%0````H3`@`,````(!,"`%D`
M```M$P(`"````(<3`@`I````D!,"`!(```"Z$P(`%0```,T3`@`5````XQ,"
M`#X```#Y$P(`'````#@4`@`,````510"`"@```!B%`(`#0```(L4`@`.````
MF10"`!4```"H%`(`"@```+X4`@`D````R10"``L```#N%`(`&0```/H4`@`*
M````%!4"`!T````?%0(`+0```#T5`@`%````:Q4"`"<```!Q%0(`!P```)D5
M`@`'````H14"``D```"I%0(`3````+,5`@`'`````!8"`!$````(%@(`"P``
M`!H6`@`7````)A8"``D````^%@(`"0```$@6`@`'````4A8"`!8```!:%@(`
M"P```'$6`@`>````?18"``\```"<%@(`&````*P6`@`<````Q18"``4```#B
M%@(`!P```.@6`@`9````\!8"``<````*%P(`,0```!(7`@`-````1!<"`!$`
M``!2%P(`!P```&07`@`"````;!<"`!````!O%P(`#P```(`7`@`+````D!<"
M``,```"<%P(`!P```*`7`@`+````J!<"``H```"T%P(`$0```+\7`@`.````
MT1<"`!L```#@%P(`'````/P7`@`*````&1@"`#8````D&`(`)````%L8`@`J
M````@!@"`!<```"K&`(`#0```,,8`@`^````T1@"``8````0&0(`%P```!<9
M`@!`````+QD"``X```!P&0(`!P```'\9`@`'````AQD"``0```"/&0(`!```
M`)09`@`)````F1D"`!X```"C&0(`!0```,(9`@`&````R!D"``@```#/&0(`
M#````-@9`@`&````Y1D"`!0```#L&0(`%`````$:`@!`````%AH"`#0```!7
M&@(`+@```(P:`@`,````NQH"`!X```#(&@(`(0```.<:`@`O````"1L"`"D`
M```Y&P(`%````&,;`@`"````>!L"``0```![&P(`#````(`;`@`(````C1L"
M``4```"6&P(``@```)P;`@`1````GQL"`&$```"Q&P(`+@```!,<`@`:````
M0AP"`#H```!='`(`+P```)@<`@!>````R!P"`!8````G'0(`?0```#X=`@`I
M````O!T"`%8```#F'0(`*0```#T>`@!`````9QX"`#X```"H'@(`-0```.<>
M`@!,````'1\"`#4```!J'P(`-P```*`?`@`Y````V!\"`!\````2(`(`+@``
M`#(@`@`R````82`"`$````"4(`(`$@```-4@`@`2````Z"`"``P```#[(`(`
MB0````@A`@`(````DB$"`,8```";(0(`<0```&(B`@"+````U"("`"T```!@
M(P(`90```(XC`@`7````]","`"8````,)`(`%P```#,D`@`7````2R0"`!H`
M``!C)`(`)````'XD`@!#````HR0"`"8```#G)`(`(`````XE`@!K````+R4"
M`!P```";)0(`#````+@E`@`+````Q24"``4```#1)0(`!@```-<E`@`(````
MWB4"``4```#G)0(`%@```.TE`@`0````!"8"`!4````5)@(`(````"LF`@`1
M````3"8"``\```!>)@(`#0```&XF`@`)````?"8"``X```"&)@(`"````)4F
M`@`&````GB8"`!4```"E)@(`"0```+LF`@`)````Q28"`!,```#/)@(`#@``
M`.,F`@`'````\B8"`!(```#Z)@(`#@````TG`@`9````'"<"``D````V)P(`
M"@```$`G`@`2````2R<"``@```!>)P(`"0```&<G`@`I````<2<"`"(```";
M)P(`$````+XG`@`E````SR<"`!0```#U)P(`&P````HH`@`1````)B@"``H`
M```X*`(`%@```$,H`@`'````6B@"``4```!B*`(`%0```&@H`@`$````?B@"
M``(```"#*`(``@```(8H`@`2````B2@"``8```"<*`(`!@```*,H`@`2````
MJB@"`!<```"]*`(`!P```-4H`@`Z````W2@"``(````8*0(`!````!LI`@`3
M````("D"`!@````T*0(`"@```$TI`@`'````6"D"`!(```!@*0(`!0```',I
M`@`9````>2D"``@```"3*0(`%P```)PI`@`5````M"D"`!,```#**0(``@``
M`-XI`@`.````X2D"``P```#P*0(`#0```/TI`@`6````"RH"`#H````B*@(`
M!P```%TJ`@`)````92H"`!$```!O*@(`!0```($J`@`"````ARH"``L```"*
M*@(``0```-,$```<!```,04``%\#````````G`$``&T"``"@!````````)0#
M``#'`0``^P8``'P``````````````(8"```I!P``"P$```````"!!P``P0``
M`'<%```5!```\`4``"P```#;`P``P08``",'```(`@```00``+P%```"!P``
M,0,```````"F`@``[P4``&0"``"R`@``#P0``($#````````````````````
M````U@0``%$%``"%!`````````````#V`0``<`(`````````````?P(``"X$
M````````(P$``*0%````````8@<``.,%``"/!@``)0$``'`&``#U!```;@(`
M`'`!```S!P``P@$``-$"```O!```;P,``$X'``!:````H@$``#,!``")!P``
M`````'L!``#K````E@8``,`%``!<!P``2@4``,P&````````E`0``&("``#R
M````*0(``&8"````````VP0``(0&``#=!0````````````"E````````````
M````````F`,```````!`````Y`8```````#-`0```````)T$``!(`@``OP4`
M``````#]`@``B`<````````,!0```````$\$``#+!0``[`(``"8%```7````
M`````#0```!8````O`$`````````````M0(``%H$``!E`P``:@,``%\!``""
M!P``````````````````^@$``&0#``!O````U@$```````!]!@````````@'
M``"0`````````$T#``";`@```````!P#``!=!@``]`$``-\````H`P``W`$`
M`-`!``"V`P``1P,````````;!P``$0<``"4#``#Q````L`4``-($````````
M`````*L#``"D`````````,H%``!A`P``>0,``)4$```*!````````(H&``#`
M`0```````.$$``!X!P``V0,``.<!````````_@4``$H'``"I`0``6`0``.0!
M````````3P```+X!```````````````````O`P``;`<```````"R````````
M`)@%``!G!```I`8``.(!``!&!@```````"H```#[`0``:`$``%0'``#:`P``
M*`8``*,$``!4!@``5@0``*\&````````G0(``%L```"2!@``BP,``*D`````
M````K`4``-,```"@`P``>@$``&<"``#"`P``*`<``'L#```K`````````#8`
M`````````````#$"``"#````Y`0```````#V!```>00``$0'````````]P``
M````````````DP(``+H%````````%P4``*H#```K`@``>@<```````!T!```
M.P(`````````````D`(``(X!``"*!```W````'P'``!7!0``F@,```,"```[
M!P``7@,```8!````````100````````M!P``GP,``*4!`````````````&<%
M``!Q`0````````````!"!@``VP```#T'``!*``````````("````````*0$`
M``````!6`P```````)P$````````S`$``&$$```6`P```````"<$``!A````
M```````````E!```=P```.X#``!F!@```````)P&``#_!0``>P`````````8
M!@``L00```,````#!P``W`4``+<&``#)`P``?`(``!8'``#L````````````
M``!C`0```````.X"``":````D@```)X#````````FP$``"L%``!Q`@``\P,`
M`$8#``"^`@``N@$``-T$``#6!@``M`,``.,$``#*!```J@0````````8!P``
M%P(``+\$```8`0``L0(`````````````X@,``(\"````````?@$``/T%``!I
M`0``%@8``/@!```J`P``2P,``'(#``!'!```E@$``$<```#(`0``<0,``$X&
M```Z````8`8``%,```#5!@``=@(````````N!0``)@(``',&``#M````"@8`
M``0```#D`@``?@,``(,%``")`0``DP0``/X"``!D!P``Y@4``!<!````````
MGP$```T'``![`@``?@````4$```)!P``+08``#0&````````4@(``+\`````
M````=P,``/\#````````"P```#,%`````````````&8'```G!@``W0``````
M``#T`@``/P<```````#8`P``V@0`````````````:`````T"``!R!@``````
M`-,&``#%!@``<0```*````#\!@``0@(```````";!```N0,``,`````$!```
M#@8``$P!``"4`@``N04``*`!``#!`0````````4`````````3`<``-8"``!C
M`````````,0```````````````````#R!````````$`%``!O!P```````,T&
M````````%P,``($&`````````````%(%`````````````/,$``!W!```HP8`
M`&\$```(````7@```$@'``"Z`P``=@4``-X```"$`P``)`0``#L%``#W!@``
MG`,``'<"````````:@$``#X"``"^!@``[04``+X$````````;P8```````")
M````I0(````````S!@```````!P'````````50$``"($```X`0```````&T$
M````````AP(``'D%``"`!0``U@`````````A`@``3P8``#<$```S`@``````
M``````"7`P``_P0````'```'`P``:08```````#Q`0``Q@```/`#``"/````
M6P<`````````````YP8``(4#`````````````-T"```N`P``5P$``/0&````
M````Y0$``/X```!-````S00``!`%````````-@$``)`#``!]`0``EP```%D$
M``!_!```<P```*<%``!8`@``@@(```````!!!@``=@$``/X!````````YP0`
M```````D`````````/@$``!K!```Q@0``%D!```A!```!@```)\"``!>`@``
M```````````#!@``E`4```````#A!@``C@,``#X````K`0``%`(``-<#``"1
M!@``0`<```````!L`P```````(X$``"C`````````,4#``!1````O0(``"P$
M```@!```Z00````````L!@``]@(``"X&``!8!0``````````````````J0(`
M`"0#`````````````+,!````````?0```"<#````````<@<```````"1!```
M`````,X!``#P!@``"`$````````````````````!``!,!0``.`8```````#(
M!0``$0$``%\$``#Z`P``G````+`#``#$`0```````'4$``!Q!```UP(``,D%
M``!\`0``C`$``````````````````/P%```U!````````#X'``"E!@``T`,`
M`*@&``#M`0``I@````````#O`@``````````````````K00``.L!``#Y!```
MWP,``"@$````````9@0``)\````/!@``N00``.H#````````R00``%L"``",
M!````````,0"``"^!0``0@4``'0'``#5!0``DP8```````!C!P``````````
M```;!````````/0#``!4````V0````````!(````E@````````!6`@``-P``
M`!\&```\`@``<P(```````#S`@````````@$``"W`@``I00``'<'````````
MV@8``!4`````````V00```````#\`````````!\%``"+!0``]P$``/8%``!\
M`P``V`8``+0%``"5!0```P4```````````````````````"#!```OP(``,X"
M```,!P``F0,``/\"````````]`0``#\"``!3`0```````,4$```R`0``````
M`,L"``",``````````````!+`0````````````"Z!@``"0$``-X!```F!```
MI`,``,P%``!S`0``,P0``!`&``"+!```8@`````````O````H`8``#@"``!9
M`@``?P<``$<'``"-!0``&0````````"M````[P,``-$&``!\!0``,@```+T%
M``#*`@```````/8&``"V!@``6P4``$0!`````````````!T"```>!P``VP8`
M```````.!0```````&`!```Y`@``0P(``+L!``"``P```````"H!``!&````
MT`(``!,&````````?P```$(#```U!P``+0$``#$$``#A`0```````-$%``"T
M`@``Z`$``%0#``#X`P``?00```````"B`P``U`(``&(#``#J!0``````````
M``!?````'P(``#(#``#\`@```````',$````````@`8``#<%```Z!0``&`0`
M``````!V````HP,```````"7!0``8@4``!("``!L`0``(@$```````".````
M`````&H%````````Q04``!H!``#@`0```````),#``"8`````````(4%```8
M`````````"P%``"&!````````!P```"9!@``:`8``/L"``"%`0```````$P#
M``!H!P``>@0``!`$``!E````5`4``,0&``!T`@``X```````````````MP,`
M`'4#`````````````````````````````%P!````````.`<``'X"``!L````
M``````````"(`@```````,X&```+`@``#P4``&T!```M`@``WP4``.<"``!/
M`P``#0$``&````!G`````````+\&``#9`@``N08``````````````````.H`
M``"R!```*``````````O!P```````/,```"J!0``_0$``-4$```:````````
M````````````8@0```````#(!@``7P8``$X`````````$P(`````````````
M2@0``!4&```C````/P```((%``"H!```N`(``)$%``#D````0@0```````"X
M!0``004``!\!``"X`0```````)L%````````M0````$'```K!P``````````
M``"P!````````&D'``![!0``9@```````````````````,X$```'`0``5P8`
M````````````WP8``&`'```[`0``.P0``'4"``#K!@``.00``!\'``#]!@``
M<08```P!````````1P8``)T&``"\!```908```D%``!%!P``````````````
M````<P,``(L```!Y!P``T@,```$"``"C`0``+`,```````"S!````````"0'
M```!`P``ZP(``'````!M!@``V````!$&``!%`P``70<``/(%``#H!@``T00`
M`#\#````````^@4``&4'``"?!@``T@(```````!K`0``T0```(D&```P````
MR`(``*$$``#L`0``X@```&H"``"F`0``7`(````````X`P```````%L&```K
M!```8`,``.`%````````SP```)8%``#7!@``10(`````````````E0$`````
M````````!@8``$8%``#^!@```````$D#``!L!0``4P<``-,!``"``0``````
M``````````````````````#]!```;`0```8$```^`P``'P0``-\$````````
M7`,``'X$```1`@``*P8``,L$```;`P```````'X&``!U````!0,``)$!````
M````K``````````$`@``>0$``"D$```T!P```````'H```!T````````````
M``!B`0``5`$```T````_`0``W@,``+0&```W!P`````````````F````````
M````````````B`4``(\$````````1@0````&````````LP```%`!``"0!@``
ML@$``!8"``!0`@``AP,``&X'``#U`@``M@```/(&``#Q`P``40$``.($``#O
M!````````,\&````````+P(````````+!P``4`````````!4`@```````$L&
M``"!`@```````!L&````````\P8``(L&``"[````7`8```````#Y`0``A```
M`$4&````````=0$`````````````1`(``$@!```5`P```````"0!``!9`P``
M]0```)H%``!3!0``W`8``#D!```9!P```````(@!``!<!0``5P0``$$'``":
M`@``/0,``!$#``"N!0``20$```````"?!````````#X!``!J````?@4``*<#
M``"G!@``(`````````"N````2P```!(```"F!````0$``'@&````````U0$`
M`+H```#D`P``M@$`````````````:`0`````````````O@```+D```!R!```
M`````!$```!?!0``Y@0``"`#``"K`0``Y@```"("``">!@``O0$``/(!```Y
M!@``@@8```````"!````$@0``+L"```]!```?P$``!L```"S`@```````+T#
M``!U!0``90(``(4`````````S0(``,,&``!_!0```````%<"``"?!0``\`$`
M`*T#````````B@4``'(!``"Q````@00```````#O!@```````!`'``!O`@``
M`````.T#````````$`(``!0!```M`P``1`0```````#5`P``WP(```````![
M!@``204```````#:!0``AP0```````"Q!@``]P(``*\$```%`@```````"$`
M``#[!0``=P$``#P#```)!@``\P4``/`"``!Q!0``N`,```````#4`P``Z`(`
M`%@&````````>P0``$$#````````*@(``)P%``#&!0``V04``&$%````````
M`````/\&``!Z!0``1P(``#P```"\```````````````/`P`````````````/
M!P``-@8``!0$`````````````&$"```'!P``,P,```````!``0``/04`````
M``":!@````````````"'`0``R0```.D#``#C!@``O0```(L!``"]!```````
M`#8#```U`@``'04```````"&!@``K@0```<"``#K!```OP,`````````````
M`````$D$``!0!@``M00``',%``#$`P```````&L#``#:`0``L`$```````"3
M!0```````,D&``"B!0````````D#``!]`P``$P````T$``#%`0``"P0`````
M``!!`@``50```.(%````````K`,```,#```9!```!08`````````````Z@0`
M`.L%```*`P``J`4``+<$```6````5`0``#<!``!5!0``I`(``/D"````````
M@`(``",%``#[`P``0P$``&H$`````````````#\%```3`0```````/(#``#'
M!```O08```````!(`P```````,T#``!=!0``?`0``#P&``#Y````'@4``$8!
M````````JP```%8!``#H!```C0````````#.`P``-P8`````````````RP``
M`(<```#=`P````````````#,!````````%$'````````&04```````#G`P``
M,0```,P#``")!0``$`$```X```!J!P``IP```,\$``!A!P``%P8``-H````A
M`0``H@(``)@"``!>!```+00``"('``!E`0``>`(``!,'```=!```V`4``)P"
M``!=`````````.`$``!F!0``/@8``.8"````````L@4````````$`P``'@0`
M``````````````````0%````````DP$``(4&``!T`P``KP,``/D&````````
MD@0``(4"```=!@```````-P#````````6P$``%H'```4`P``\0(``#('``!T
M!0``J`,``%T!```J!@``````````````````K@8``.`#``!.`P``_`0``#D'
M``!X!````````"\%``!G!@``U````*`"``#Y`P```````"@%``"%!P``[`4`
M`'("````````*0`````````&`@````````H'``#E!````````%$&````````
M`````"8'```!!@```````$8"``````````````````#7`0``S0```#<#```$
M`0```````"H'``!Q!P``8@8```````"!!0``;@$``*\"``#$!```+@(``%4$
M``````````````````"$!0``$P0``)$"``!6!@``T@```*X#``!(!@``-@<`
M`'L'````````T`0``!L%````````N@0`````````````@@$`````````````
M(P(``%H!````````&@<``#$'```@`@``J`(``"4'````````.@0``(D"``!K
M````\08``#D%```\`0``$04```````#D!0``B@```!P!``"K!```B0,```8%
M````````(@4``%T"````````Z@$```````#Z!````````-\!``!'!0``````
M`!(&``"(````Z0(``#0$``#E`P``JP4``,T%``#'`P```````#\$````````
M``````````#J`@``H0,``/X#```8!0``,P```/4%``!V!P```````&X&````
M````RP,``&\!```>`P``604```````"&````@P$```````"T````CP,``(0$
M```P!```MP$``)D"``"@!0``M@(``.4"````````,@0``*$````L`@``R`,`
M``L#````````C`4````````:!@``K`0``````````````````&L%````````
MV`$````````.!```!P8````````E````X0,``)X``````````````'(%```>
M!@```````!4!```^!0``'0```,P"``">!0``B`8``(X"```A!0``E@(`````
M```_!@``0`8``*$!``"A!0``)P(`````````````+0```$D'``"5`@``4@0`
M````````````-`(``/<%``!T`0``70,``#4!````````3@0``%8%``"B!```
M"0```,,%``"#`P```````%@!``!I`@``[`,``!D"````````P@(``%D'``!#
M`P``/`0``)`!``#F`0``XP,``%$$`````````````*P"```.`@``'`(``$X!
M``!(!```"@````````!,!@``_`$``"X```"-`0```````"P'``#M`@``Z0$`
M`,\!``!L`@````````````#:`@``PP(``"<```"S`P``D@4```````!N````
M$`````````"-!```&P$``'`$``!U!P````,``-X%``!2!P``L@,```8'``"-
M`P```````(T"``!G`0``@@,``+\!``!V!@``;@0``*H```!.`@``9`4`````
M``",`P``+@<``(($````````O`,``#X$```8`@```````#<"``"2`P``@@``
M```$```````````````````/`@``%0(``,(```"[`P```````-`&```P!0``
M[@```,$%````````2`4``!('``!8!P```@0``%X!`````````````-D!``!)
M!@``\00``&P&```X!0``.@<``)H!``#A````O`(``+X#```6!```````````
M``"9!0``Z04``/4#````````0@<``!D#``#L!```E0,```(#```(!@``C08`
M``````!K!@``7P<``"X!```E!@```````&0&``!I`P```````%X&``"U`P``
M"@(``$D"```?````"P8``&0!`````````````$\"`````````````*8%```P
M!@``L0$```P&``#2`0``-04``(8!``!<`````````#H&``#F`P``&@4``+L$
M``"M`@```````(````!Z`P``AP8```````"#!@``W0$``#4#``#O`0``````
M```````,````E@,``&,"``">`@``\04``````````````````&0$````````
M`````.D```"V!0``H08````````>`0``P0,``#L&``!P!0``A`$``&L"````
M````300``.8&````````Q@8``(\!````````PP```!T'````````8P0``','
M````````#04``#T!``!/!P``;0,``"$&``!$````%0<`````````````V`(`
M`$D````[`P``%P0```````#O````:@8````````*!0``4P,```<%```D!0``
MM08``*D$```'!```1P$``$,&```````````````````@!0```````+````"O
M````+P8``.X&``#C`````````"(&```2`P``P00``-D&`````````````'\#
M```,!```&`,``*P!````````N0$``.(&``#.`````````)(!``!^!P``Q0(`
M``(%````````-`$```````"H````+`$```X#````````D`0``!D!``"B````
M4`4```````#I!@``U0(```````````````````D$``"9`0``FP,``*H!```,
M`@``U`4``/0%``#U`0``#0,```````"=`0``Q0````````#&`@``5P```#@`
M```H`@````````````#]`P``IP0``+L%````````P@4```````!/`0``'0$`
M`.P&``#X!@``E@0``%`$````````K0$`````````````I`$``*D%``"P`@``
M8P8```````#6`P``%@4``*8#````````&@(````%````````A@<``(`'``#0
M!0``XP$``*P&``#C`@``P`8``*L"``!P`P``D`4``*\!````````T@4``*(&
M````````M04```````#.!0``;04```````#X`@```````-T&````````````
M`!\#``!]!P``M`0``*8&````````Q`4``*<!``!#````G0,``!L"````````
M3`0````````"`0``EP(``$\%``!``P``>08``-P"````````1@<``&,%``!_
M!@``1`,``.4```!-!0``P@8```````````````````````#0````6P,``+<`
M``!Y`@``0P4```````!2!@``U@4``$H"```]````+04```````!Z!@``X`(`
M`&`$```:`P``````````````````PP0```````#3`P``X@(``'@#``"4````
MAP<``!H$````````````````````````000``!D&`````````````%`'````
M````*0,``/T```!7`P`````````````A!P``40,``#H"``"3````\P$``%4"
M``````````````T&````````F00```````!"`0``7P(``$L$``!+!P``;@4`
M`+$#````````A`(``$T&````````)@$```````#;`0```````+$%``!P!P``
MW`0``&D%``"S!@``)P4``#P'``!#!P``2@,``&D$``#/`P```````&@"``"O
M!0``@`0``'8#``#1`P``4`,``)@!``#A`@``3`(``,($````````B`0``&L'
M``!R````````````````````^@(````````R!0``:`,```4'```C`P``?`8`
M``````#H`P``EP0``+4!``#*!@``SP(``"@!``"7`0``RP$```````!6!P``
M4P(``%H#``"&!0```````#`"``#X````F0````````#,````K@(``#0%````
M````UP````````"E!0``````````````````)`8``)@&``#N`0``(0,``#L`
M``"7!@``00$``,8#``",`@``!`<``!4%``!E!0``````````````````(@,`
M`(H"```>````@P<``%4'``"M!0``10```'4&```X!```PP$``-0!``!"````
M900``"<'``!O!0``]08``%8````.`0``^04``$T"``#^!```6@(``*,%```$
M!@``Z`4``"(```!%!0```````$H&``"8!```FP8``,$"```#!```````````
M``"\!@``;@,``!0&``#M!@```````'T%``#H````-`,``%H%```2!0``#P$`
M`!X"````````:`4````````O`0``/0(``$T!```P`0``)0(``-4`````````
M)04``&8#``#V````>@(``(X&`````````````*,"````````K@$``/P#``!A
M`0``N````)$```````````````````"5````)@,```\``````````````(H#
M````````?0(``,<%``#&`0```````(8#```@!P``G@$```````#;`@``R0$`
M``H!``!5`P``>0```-0$``##`P```````,H!```3`P``````````````````
M;0<``/`$``!V!```"`,````````]!@``V`0```````"A`@``;0```(\%```7
M!P```````%<'```J!````@```&`"```<!0```````/@%``!.!0```````,@`
M```,`P``BP(```````"E`P``"`4````````Y`P``_P$```X'``!=!```"0(`
M``````!,````F@0``-$!```I!0``YP4```````!X`````````&8!``#P````
M[@4``$L"``"W!0``!04```````!2````ZP,``$L%``#4!@``.0```,@$``"=
M!0``P`(``%X'```#`0``=P8``$0%``#>!@`````````````'````-@4``"L#
M``#Z````QP8``!0'```"!@``R@```'@!```2`0``]P,``.4%``"J!@``4P0`
M`%(!````````!@,``+D"``!-!P``%````)$#``"J`@``7`0``-<$```Z`P``
M,`,``/0```!`!````````-X"``"P!@````````````#;!0``808``,`#``#*
M`P``[00``%L$``"4`0``B`,``&<'``"$!P`````````````3!0``C`8``*0$
M```P!P``B@$``$,$``";````(`8``/("``!T!@````````````"V!```````
M`!`#``#J!@``8`4```````#[!```E`8``.$%```I!@````````````#W!```
M`````+H"````````M`$``$0&````````K08``%4&```\!0```````$$````V
M!````````#("`````````04```````".!0``'0,``*<"`````````````%(#
M```F!@``TP4``/H&````````J`$``&,#```1!`````````````!3!@``)P$`
M`+,%````````Y08``-,"````````AP4``(,"``"X!@``6`,``($!````````
M[@0``"0"``#2!@```````#4```"[!@``R0(``*D#``!9`````````#$!````
M````X`8``+(&```+!0``10$``%H&``"X!```-08```````!9!@```````&0`
M```C!@``QP(```````"=````_P````4!``!``@``B00``&D```#7!0``(`$`
M`)X$````````D@(``!0%````````.@$``,\%````````%@$```````!X!0``
MQP```,L&`````````````%X%```C!```]@,``"H%``#G````P`0``*D&```<
M!@``2@$``#$&`````@``9P,``-X$```V`@````````````#[````JP8``)4&
M``!1`@```````#(&````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I
M`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D
M87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S
M(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W
M960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`
M)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS
M(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E
M<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@
M)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S
M($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G
M92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R
M92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN
M9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L
M(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R
M;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-
M(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$
M`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D
M;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T
M:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I
M;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!
M9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D
M(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI
M80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H
M96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L
M;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!
M;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!
M;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S
M<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A
M;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I
M;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A
M(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P
M;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R
M;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R
M-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD
M(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H
M05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!
M<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N
M="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R
M:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD
M87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?
M;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0
M('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT
M:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL
M960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S
M`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S
M<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN
M`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE
M`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`
M0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F
M;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`
M0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O
M<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U
M=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET
M;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`
M0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`
M0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E
M<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S
M+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N
M(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O
M<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B
M)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P
M=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L
M86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z
M`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT
M:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E
M($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I
M97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@
M<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O
M;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA
M<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E
M($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R
M;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T
M('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L
M86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#
M;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R
M.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E
M`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@
M5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L
M:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E
M<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I
M;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD
M(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O
M;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I
M9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S
M+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O
M=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N
M9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN
M96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S
M`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``
M0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE
M`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`
M0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E
M<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E
M=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER
M("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O
M=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`
M0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E
M860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@
M<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B
M+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L
M9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN
M:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET
M92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I
M9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U
M;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE
M=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`
M0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA
M<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),
M(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N
M9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#
M>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.
M("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W
M<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S
M96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@
M;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R
M`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$
M96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L
M971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N
M>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D
M(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U
M<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`
M1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I
M;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E
M8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$
M:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO
M;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T
M("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN
M('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M
M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N
M(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E
M<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%
M4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E
M<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%
M;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER
M;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@
M>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N
M('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L
M971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R
M`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R
M(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z
M("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B
M)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD
M(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q
M=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'
M($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@
M8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO
M=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R
M<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME
M.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`
M1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U
M;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R
M`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA
M;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&
M*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y
M;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T
M=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A
M;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H
M(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&
M<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE
M`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A
M;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E
M`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!'
M;&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E
M87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E
M;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D
M(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E
M`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U
M97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL
M(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H
M;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)
M*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P
M:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`
M2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE
M($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(
M;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O
M2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D
M;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO
M;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L
M9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES
M=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E
M<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T
M(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)
M8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD
M:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN
M=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B
M871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L
M:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C
M;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S
M(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE
M8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)
M=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*
M=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I
M9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.
M97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T
M:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O
M9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,
M86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T
M($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,
M969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@
M4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!2
M86EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W
M`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@
M=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE
M;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``
M3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,
M:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@
M<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S
M:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,
M;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L
M871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-
M30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`
M35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U
M8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME
M(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A
M`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA
M8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H
M;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN
M9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN
M9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E
M9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@
M3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA
M>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS
M`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N
M`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`
M365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN
M:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`
M36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N
M+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA
M:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`
M36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N
M9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I
M96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-
M;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U
M9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T
M`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I
M<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M
M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!)
M;F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R
M`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`
M3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S
M92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@
M<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O
M8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E
M`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W
M($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W
M('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W
M('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.
M97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N
M<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO
M`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG
M($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES
M=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N
M`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@
M:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@
M<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF
M:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N
M97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.
M;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N
M`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU
M97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y
M+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H
M97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O
M<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.
M;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E
M<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B
M:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL
M=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F
M97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E
M8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M
M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E
M<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G
M86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W
M;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T
M=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG
M;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H
M="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO
M=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI
M<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S
M=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'
M=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@
M`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B
M;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N
M("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I
M;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R
M;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET
M8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A
M<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A
M>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U
M9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@
M=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@
M8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E
M<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`
M4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R
M979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I
M;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE
M;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y
M`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O
M4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0
M=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!2
M4T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!2
M86EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W
M`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@
M;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T
M:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S
M`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!2
M96UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA
M='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO
M=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T
M=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T
M(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN
M(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S
M970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@
M475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A
M<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT
M($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I
M9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O
M=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T
M:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N
M9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R
M>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@
M9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!3
M86EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA
M`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-
M87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E
M<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P
M=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A
M<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E
M`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L
M96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`
M4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@
M:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!2
M97!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R
M8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@
M=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N
M($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO
M<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G
M9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I
M8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE
M("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E
M<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@
M5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG
M;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`
M4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`
M4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3
M;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0
M;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T
M:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N
M($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C
M92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3
M<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI
M="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A
M<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M
M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3
M=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3
M=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U
M8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO
M=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A
M<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@
M=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM
M87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U
M;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U
M<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N
M`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E
M9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@
M07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O
M<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE(%!R;W!E<G1I97,`
M5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O
M=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP
M(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E
M;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA
M=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E
M>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M
M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA
M8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D
M92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B
M)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H
M92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L
M;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M
M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@
M;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N
M;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO
M="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES
M="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@
M8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@
M9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@
M;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@
M:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L
M;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L
M92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G
M92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A
M;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`
M5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@
M:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE
M(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E
M`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT
M+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF
M:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I
M;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@
M9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P
M(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@
M=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E
M<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I
M<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T
M:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B
M(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I
M;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F
M;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A
M<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C
M87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.
M("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A
M9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I
M<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N
M`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G
M+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@
M:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V
M:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT
M('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N
M($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I
M="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@
M9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE
M("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W
M:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`
M5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN
M<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P`%1O<"!F<F%M92`H7W1O
M<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F
M86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4
M=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4
M>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`
M56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P
M>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E
M<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R
M("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@
M(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F
M;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@
M9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5
M;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D
M92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M
M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)
M<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA
M;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N
M;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O
M;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII
M;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O
M<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5
M<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S
M`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES
M=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`
M57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B
M(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I
M;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L
M=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!6
M86QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E
M;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L
M`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E
M<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`
M5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)
M<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI
M='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`
M5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)
M3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H
M97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N
M8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S
M`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T
M:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H
M(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN
M9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D
M;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L
M(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&
M4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E
M>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S
M`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H
M92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D
M(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R
M97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@
M=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0
M('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U
M;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED
M96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E
M9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES
M('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`
M66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`
M6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E
M<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M
M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#
M3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E
M(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN
M+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T
M=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A
M9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@
M;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM
M86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET
M:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D
M:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`
M:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@
M<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@
M>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E
M;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S
M97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL
M('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E
M;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O
M;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E
M871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ+6-V<PI2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT-RLP,3`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z-3`K,#$P,`I,87-T+51R86YS;&%T
M;W(Z($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"DQA;F=U86=E+51E
M86TZ($=E<FUA;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX
M.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"`H=F]R
M("5S(%1A9V5N*0`@*%IU9W)I9F9S=&%S=&4@)7,I`"`H:6X@)7,@5&%G96XI
M`"`H:&5U=&4I`"`H;6]R9V5N*0`@*&=E<W1E<FXI`"!M:70@`"(E<R(@:7-T
M(&ME:6X@5F5R>F5I8VAN:7,N`"(E<R(@:7-T(&ME:6YE(&?\;'1I9V4@075S
M=V%H;"X`(B5S(B!I<W0@:6X@9&5R($AO<F1E(%)E9VES=')Y(&YI8VAT(&MO
M;F9I9W5R:65R="X`1&5R($)A=6TM4F5N9&5R97(@9OQR("(E<R(@=W5R9&4@
M;FEC:'0@9V5F=6YD96XN`"(E<R(@=W5R9&4@>G5M($=R=7!P96YS>7-T96T@
M:&EN>G5G96;\9W0N`"(E<R(@=W5R9&4@>G5M(%)E8VAT97-Y<W1E;2!H:6YZ
M=6=E9OQG="X`(B5S(B!W=7)D92!N:6-H="!E<G-T96QL=#H@)7,N`"4N,F9-
M0B`H)3,D+C)F)24I('9O;B`E,B0N,F9-0B!E<FQA=6)T96X@=F5R8G)A=6-H
M=``E9"`E<R!U;F0@)7,`26X@)60@5&%G96X@=VER9"!):'(@4&%S<W=O<G0@
M=6YG_&QT:6<N`"5D+51A9V4M5F]R:&5R<V%G90`E<R`M($AI;G=E:7,`)7,@
M1FEN9V5R86)D<G5C:P`E<R!+0@`E<R!787)T=6YG<V%R8F5I=&5N("T@0F5S
M=.1T:6=U;F<`)7,M2V]N9FEG=7)A=&EO;@`E<R!296=I<W1R:65R=6YG`"5S
M($YU='IU;F=S8F5D:6YG=6YG96X`)7,@97AI<W1I97)T(&)E<F5I=',N`"5S
M(&UI="`E<R`E<P`E<R!W:7)D(&1I92!787)T=6YG<V%R8F5I=&5N(&1U<F-H
M9OQH<F5N+"!D:64@=6YT96X@;6%R:VEE<G0@<VEN9"X@36%R:VEE<F5N(%-I
M92!A;&QE($%U9F=A8F5N+"!D:64@:F5T>G0@9'5R8VAG96;\:')T('=E<F1E
M;B!S;VQL96XN`"5S(&ES="!N;W1W96YD:6<`)7,@36EN=71E;@`E<R!N:6-H
M="!G969U;F1E;BX`)7,@8FES("5S('9O;B`E<P`E<W,@061R97-S8G5C:``E
M<W,@2V%L96YD97(`)7-S($YO=&EZ8FQO8VL`)7-S($%U9F=A8F5N;&ES=&4`
M)7,Z("5S`"5S.B!$:65S92!.86-H<FEC:'0@<W1A;6UT('5N=&5R(%5M<W3D
M;F1E;B!N:6-H="!V;VX@9&5M(&%N9V5G96)E;F5N($%B<V5N9&5R+B!&;VQG
M96X@4VEE(&ME:6YE;B!,:6YK<R!I;B!D:65S97(@3F%C:')I8VAT('5N9"!H
M_'1E;B!3:64@<VEC:"!D879O<BP@9&5M($%B<V5N9&5R('!E<G/V;FQI8VAE
M($1A=&5N('!R96ES>G5G96)E;BX`+"!B]FEG(``L(&)I9R`E<R`E<P`L('-C
M:'=A;FME;F0@=F]N("5S(&)I<R`E<P`M+2!!=7-WY&AL96X@+2T`,3(M4W1U
M;F1E;BU&;W)M870`,C0M4W1U;F1E;BU&;W)M870`,C0@4W1U;F1E;@`\6G5R
M_&-K`$9R(&1I97-E;B!";&]C:R!W:7)D(&5I;F4@1&%T96YB86YK(&)E;G1I
M9W0N`$5I;B!S8VAW97)E<B!&96AL97(@:7-T(&%U9F=E=')E=&5N.@!%:6X@
M]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P@=VER9"!F_'(@9&EE(%9E<G-C
M:&S\<W-E;'5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E
M;G1L:6-H97(@4$=0+5-C:&S\<W-E;"!W:7)D(&;\<B!D:64@W&)E<G!R_&9U
M;F<@96EN97(@=6YT97)Z96EC:&YE=&5N($YA8VAR:6-H="!B96[V=&EG="X`
M16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%!'4"U38VAL_'-S
M96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!%;G1S8VAL_'-S
M96QU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC
M:&5R('5N9"!E:6X@<')I=F%T97(@4$=0+5-C:&S\<W-E;"!S;W=I92!E:6X@
M4&%S<W=O<G0@=VER9"!F_'(@9&EE(%5N=&5R>F5I8VAN=6YG(&5I;F5R($YA
M8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R
M:79A=&5R(%,O34E-12U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I
M<F0@9OQR(&1I92!%;G1S8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT(&)E
M;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R('5N9"!E:6X@<')I=F%T97(@4R]-
M24U%+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O<G0@=VER9"!F_'(@9&EE
M(%5N=&5R>F5I8VAN=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN
M(/9F9F5N=&QI8VAE<B!3+TU)344M4V-H;/QS<V5L('=I<F0@9OQR(&1I92!6
M97)S8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+@!6;W)M
M:71T86=S(%=O;&ME;@!6;W)M:71T86=S(&QE:6-H=&5R(%)E9V5N`%9O<FUI
M='1A9W,@4F5G96X`5F]R;6ET=&%G<R!38VAA=65R`%9O<FUI='1A9W,@4V-H
M;F5E<V-H875E<@!!32]030!!4$D@240`W&)E<B!D:65S96X@161I=&]R`$EN
M9F\N+BX`06)S;VQU="!5;G1E;@!!8G-O;'5T($UI='1E`%IU9W)I9F8@=F5R
M=V5I9V5R="!B96EM($%N;&5G96X@9&5S(%9&4RU697)Z96EC:&YI<W-E<RX`
M6G5G<FEF9B!V97)W96EG97)T(&)E:6T@06YL96=E;B!D97(@5D93+41A=&5I
M+@!+;VYT;VEN9F]R;6%T:6]N96X`2V]N=&]P87-S=V]R=`!+;VYT;R!E:6YG
M969R;W)E;BX`0G5C:&AA;'1U;F<`2&EN>G5F_&=E;@!.975E(%5N=&5R9W)U
M<'!E(&AI;GIU9OQG96X`3F5U92!5;G1E<G)E8VAT92!H:6YZ=6;\9V5N`$AI
M97(@:&EN>G5F_&=E;CH`3F5U92!'<G5P<&4@:&EN>G5F_&=E;@!.975E(%)E
M8VAT92!H:6YZ=6;\9V5N`%5N=&5R9W)U<'!E('IU("(E<R(@:&EN>G5F_&=E
M;@!5;G1E<G)E8VAT92!Z=2`B)7,B(&AI;GIU9OQG96X`1OQG96X@4VEE(&5I
M;F5N(&YE=65N($)E;G5T>F5R(&AI;GIU.@!3<&%L=&4@:&EN>G5F_&=E;@!.
M975E($UI=&=L:65D97(@:&EN>G5F_&=E;@!086%R(&AI;GIU9OQG96X`1&%S
M("5S+4UE;OP@>G5R($UO>FEL;&$@4VED96)A<B!H:6YZ=6;\9V5N`%IU;2!!
M9')E<W-B=6-H(&AI;GIU9OQG96XZ`%IU(&UE:6YE;2!!9')E<W-B=6-H(&AI
M;GIU9OQG96X`0F5N=71Z97(@:&EN>G5F_&=E;@`B)7,B('=U<F1E('IU;2!3
M>7-T96T@:&EN>G5G96;\9W0L(&%B97(@9&EE('IU<^1T>FQI8VAE;B!296=I
M<W1R:65R=6YG<VEN9F]R;6%T:6]N96X@:V]N;G1E;B!N:6-H="!G97-P96EC
M:&5R="!W97)D96XZ("5S+@`B)7,B('=U<F1E('IU;2!3>7-T96T@:&EN>G5G
M96;\9W0N(%-I92!K]FYN96X@<VEC:"!J971Z="!A;FUE;&1E;BX`1&%S($AI
M;GIU9OQG96X@=F]N($)E;G5T>F5R;B!I<W0@;FEC:'0@;?9G;&EC:"X`061R
M97-S90!!9')E<W-B=6-H`%9E<G=A;'1E;B`M(%)E8VAT92!F_'(@86YD97)E
M($)E;G5T>F5R(&9E<W1L96=E;@!!9&UI;FES=')A=&EO;@!797)B=6YG`$%F
M9VAA;FES=&%N`$%L8F%N:65N`$%L9V5R:65N`%-P:71Z;F%M90!!=7-R:6-H
M='5N9P!!=7-R:6-H='5N9SH`06QL90!!;F=E;65L9&5T92!"96YU='IE<@!!
M;&QE($=R=7!P96X`06QL92!296-H=&4`06QL92!V:65R(%-E:71E;@!-96AR
M97)E($%D<F5S<V5N(&5R;&%U8F5N`$9O<FUA="!V;VX@;G5M;65R:65R=&5N
M($QI<W1E;B#D;F1E<FX_`$5X:7-T:65R="!B97)E:71S`$%L=&5R;F%T:79E
M($E-4U`M06YM96QD=6YG`$%L=&5R;F%T:79E<R!)35-0+5!A<W-W;W)T`$%L
M=&5R;F%T:79E<B!)35-0+4)E;G5T>F5R;F%M90!!;'1E<FYA=&EV92!%;6%I
M;&%D<F5S<V4`06QT97)N871I=F4@5F]R;&%G96X`06QT97)N871I=F5R(%1E
M>'0Z`$%M97)I:V%N:7-C:"U386UO80!%<R!W=7)D92!E:6X@=6YG_&QT:6=E
M<B!797)T(&%N9V5G96)E;BX`16EN('5N8F5K86YN=&5R($9E:&QE<B!I<W0@
M875F9V5T<F5T96XN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;65R
M(%!R;WAY`$%N='=O<G0`06YT87)K=&ES`$%N=&EG=6$@=6YD($)A<F)U9&$`
M06YW96YD=6YG`$%N=V5N9'5N9W-L:7-T90!!;G=E;F1U;F<@:7-T(&)E<F5I
M="X`075F(%5N=&5R<F5C:'1E(&%N=V5N9&5N`$)E<W3D=&EG96X`56YG96;D
M:')E($=R]M]E`$%P<FEL`$%R86)I<V-H("A7:6YD;W=S+3$R-38I`$%R8VAI
M=F=R]M]E`$%R8VAI=FYA;64`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D
M:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!L]G-C:&5N(&WV8VAT
M96X_`%-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@(B5S(B!U;F0@86QL92!5
M;G1E<F=R=7!P96X@;/9S8VAE;B!M]F-H=&5N/P!!<F=E;G1I;FEE;@!!<FUE
M;FEE;@!!<FUE;FES8V@@*$%235-#24DM."D`2W5N<W0`07)U8F$`07-C96YS
M:6]N+4EN<V5L;@!!4T-)22U+=6YS=`!!<VEE;B]087II9FES8VAE(%)E9VEO
M;@!!;G-T96AE;F1E(%=A<G1U;F=S87)B96ET96X@8F5S=.1T:6=E;B!L87-S
M96X_`%IU;W)D;G5N9W-F96QD97(`17,@=W5R9&4@=F5R<W5C:'0L(&5I;F4@
M;FEC:'0@97AI<W1I97)E;F1E($=R=7!P92!Z=2!L]G-C:&5N+@!%<R!W=7)D
M92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T:65R96YD97,@4F5C:'0@>G4@
M;/9S8VAE;BX`17,@=W5R9&4@=F5R<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE
M<F5N9&5S(%)E8VAT('IU(&)E87)B96ET96XN`$5S('=U<F1E('9E<G-U8VAT
M+"!E:6X@;FEC:'0@97AI<W1I97)E;F1E<R!296-H="!Z=2!B96%R8F5I=&5N
M+@!!='1R:6)U=&4`075G=7-T`$%U<W1R86QI96X`UG-T97)R96EC:`!!=71H
M7V-Y<G-Q;#H@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG('=U<F1E
M(&YI8VAT(&=E9G5N9&5N+@!!=71H7V-Y<G5S.B!$87,@0F%C:V5N9"!H870@
M;FEC:'0@9&EE(&)E;O9T:6=T96X@1N1H:6=K96ET96XN`$%U=&A?8WER=7,Z
M($1I92!B96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G
M969U;F1E;BX`075T:%]F='`Z($1I92!B96[V=&EG=&4@1E10+45R=V5I=&5R
M=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B!+;VUP:6QI97)E;B!3:64@4$A0
M(&UI="!D96T@+2UE;F%B;&4M9G1P(%!A<F%M971E<BX`075T:%]I;6%P.B!$
M:64@8F5N]G1I9W1E($E-05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F
M=6YD96XN`$%U=&A?:W)B-3H@1&EE(&)E;O9T:6=T92!+97)B97)O<RU%<G=E
M:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]L9&%P.B!$87,@
M2&EN>G5F_&=E;B!V;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV92!$:7)E
M8W1O<GD@;FEC:'0@=6YT97)S=/QT>G0`075T:%]L9&%P.B!$87,@3/9S8VAE
M;B!V;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV92!$:7)E8W1O<GD@;FEC
M:'0@=6YT97)S=/QT>G0`075T:%]L9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M
M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?;&1A<#H@
M1&5R($)E;G5T>F5R("5S(&MO;FYT92!N:6-H="!H:6YZ=6=E9OQG="!W97)D
M96XN($UE;&1U;F<@9&5S(%-E<G9E<G,Z(`!!=71H7VQD87`Z($)E;G5T>F5R
M("5S(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96X`075T:%]L9&%P.B!"
M96YU='IE<B`E<R!K;VYN=&4@;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;@!!
M=71H7VQD87`Z($1A<R!!:W1U86QI<VEE<F5N('9O;B!"96YU='IE<FX@=VER
M9"!F_'(@06-T:79E($1I<F5C=&]R>2!N:6-H="!U;G1E<G-T_'1Z="X`075T
M:%]M8V%L.B!$:64@8F5N]G1I9W1E($U#04PM17)W96ET97)U;F<@=W5R9&4@
M;FEC:'0@9V5F=6YD96XN`$%U=&A?<VUB875T:#H@1&EE(&)E;O9T:6=T92!3
M86UB82U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`06YM96QD
M=6YG(&)E:6T@24U!4"U397)V97(@9F5H;&=E<V-H;&%G96XN`$%U=&AE;G1I
M9FEZ:65R=6YG(&9E:&QG97-C:&QA9V5N`$%N;65L9'5N9R!F96AL9V5S8VAL
M86=E;BX@)7,`1&EE($%U=&AE;G1I9FEZ:65R=6YG('=U<F1E('9O;2!2041)
M55,M4V5R=F5R('IU<OQC:V=E=VEE<V5N+@!!;FUE;&1U;F<@8F5I;2!&5%`M
M4V5R=F5R(&9E:&QG97-C:&QA9V5N+@!!;FUE;&1U;F<@8F5I;2!334(M4V5R
M=F5R(&9E:&QG97-C:&QA9V5N+@!697)F_&=B87)E($9E;&1E<CH`07-E<F)A
M:61S8VAA;@!"3T9(+4%U<W)E9&5N`$AI;G1E<F=R=6YD`$AI;G1E<F=R=6YD
M9F%R8F4`1F%L<V-H97,@2V5R8F5R;W,M4&%S<W=O<G0N`$9A;'-C:&5R($ME
M<F)E<F]S+4)E;G5T>F5R;F%M92X`0F%H86UA<P!"86AR96EN`$)A;'1I<V-H
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S8V@`0F%R8F%D;W,`0F%S:7,M0FEL
M9&5R+59E<GIE:6-H;FES("(E<R(@;FEC:'0@9V5F=6YD96XN`$=R=6YD;&EN
M:64`5V5IWW)U;&%N9`!"96QG:65N`$)E;&EZ90!"96YI;@!"97)M=61A<P!"
M:'5T86X`1V5B=7)T<W1A9P!";&]C:R`B)7,B(&1E<B!!;G=E;F1U;F<@(B5S
M(B!N:6-H="!G969U;F1E;BX`0FQO8VME:6YS=&5L;'5N9V5N`$)L;V-K='EP
M`$9E='0`0F]L:79I96X`3&5S97IE:6-H96X`4F%N9`!286AM96YD:6-K93H`
M4N1N9&5R`$)O<VYI96XM2&5R>F5G;W=I;F$`0F5I9&5S`$)O='-W86YA`%5N
M=&5N`$)O=79E=&EN<V5L`$)R87-I;&EE;@!"<FET:7-C:&5S(%1E<G)I=&]R
M:75M(&EM($EN9&ES8VAE;B!/>F5A;@!"<G5N96D@1&%R=7-S86QA;0!"=6QG
M87)I96X`56YN=6UM97)I97)T92!,:7-T90!"=7)K:6YA($9A<V\`0G5R=6YD
M:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VYS<W1E;&QE`%]:96QL96YE:6=E
M;G-C:&%F=&5N+BXN`$1E<B!:=VES8VAE;G-P96EC:&5R(&MO;FYT92!N:6-H
M="!I;FET:6%L:7-I97)T('=E<F1E;BX`2V%L96YD97(`5VEN9'-T:6QL`$MA
M;6)O9'-C:&$`2V%M97)U;@!087-S=V]R="!K86YN(&YI8VAT(&%U=&]M871I
M<V-H('IU<OQC:V=E<V5T>G0@=V5R9&5N+"!B:71T92!W96YD96X@4VEE('-I
M8V@@86X@26AR96X@061M:6YI<W1R871O<BX`1&EE($1A=&5I("(E<R(@:V%N
M;B!N:6-H="!G97-P96EC:&5R="!W97)D96X`17AT97)N92!397-S:6]N+4AA
M;F1L97(@:_9N;F5N(&YI8VAT(&%D;6EN:7-T<FEE<G0@=V5R9&5N+@!697)B
M:6YD=6YG('IU;2!)34%0+5-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT
M('=E<F1E;CH@)7,`1&EE($1A=&5I("(E<R(@:V%N;B!N:6-H="!G9?9F9FYE
M="!W97)D96XN`$MA;F%D80!!8F)R96-H96X`4')O8FQE;6)E<FEC:'0@86)B
M<F5C:&5N`$1I92!$871E:2`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W
M97)D96XN`$ME:6X@=&5M<&]RY')E<R!697)Z96EC:&YI<R!G969U;F1E;BX`
M1F]R='-E='IU;F<@;VAN92`B=&%R9V5T1FEL92(M4&%R86UE=&5R(&YI8VAT
M(&WV9VQI8V@N`$1A<R!697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!E
M;G1F97)N="!W97)D96XN`$MO;FYT92!N:6-H="!E;G1F97)N="!W97)D96XL
M("5D($MI;F1E<B!E>&ES=&EE<F5N+@!5;7-O<G1I97)E;B!N:6-H="!M]F=L
M:6-H+B!$:64@06YZ86AL(&1E<B!%:6YT<N1G92P@9&EE('5M<V]R=&EE<G0@
M=V5R9&5N('-O;&QE;BP@<W1I;6UT(&YI8VAT(&UI="!D97(@06YZ86AL(&1E
M<B!G97-P96EC:&5R=&5N($5I;G1RY&=E(/QB97)E:6XN`$1I92!.86-H<FEC
M:'0@:V]N;G1E(&YI8VAT(&%N(&1I92!A;F=E9V5B92!.=6UM97(@=V5I=&5R
M9V5L96ET970@=V5R9&5N+@!+87`@5F5R9&4`W&)E<G-C:')I9G0`4')O=FED
M97(`2V%T96=O<FEE;B!U;F0@0F5S8VAR:69T=6YG96X`0V%Y;6%N+4EN<V5L
M;@!-;V)I;'1E;&5F;VX`6F5L;&5N96EG96YS8VAA9G1E;@!);FYE;F%B<W1A
M;F0Z`%IE;&QE;F5I9V5N<V-H869T96X`6F5L;&5N86)S=&%N9#H`36]B:6QT
M96QE9F]N`$ME;'1I<V-H("A)4T\M.#@U.2TQ-"D`6F5N=')I97)T`%IE;G1R
M86QA9G)I:V%N:7-C:&4@4F5P=6)L:6L`36ET=&5L975R;W#D:7-C:"`H25-/
M+3@X-3DM,BD`6F5R=&EF:6MA=&1E=&%I;',`6F5R=&EF:6MA=&)E<VET>F5R
M`%IE<G1I9FEK871R:6-H=&QI;FEE;@!4<V-H860`Q&YD97)N`,1N9&5R;B!3
M:64@26AR(%!A<W-W;W)T`,1N9&5R;B!3:64@9&5N($YA;65N(&]D97(@9&EE
M($5M86EL861R97-S92P@9&EE(&1I92!%;7!FY&YG97(@26AR97(@16UA:6QS
M('-E:&5N+"!W96YN(&1I97-E($EH<F4@16UA:6QS(&QE<V5N(&]D97(@9&%R
M875F(&%N=V]R=&5N+@!$87,@Q&YD97)N($EH<F5S(%!A<W-W;W)T<R!W:7)D
M('9O;B!D:65S96T@4WES=&5M('IU<B!:96ET(&YI8VAT('5N=&5R<W3\='IT
M+B!":71T92!W96YD96X@4VEE('-I8V@@86X@26AR96X@061M:6YI<W1R871O
M<BX`6F5I8VAE;@!,:6YK(/QB97)?<'+\9F5N+BXN`$-H:6QE`$-H:6YA`$-H
M:6YE<VES8V@@=F5R96EN9F%C:'0@*$=",C,Q,BD`0VAI;F5S:7-C:"!T<F%D
M:71I;VYE;&P@*$)I9S4I`$%N=V5N9'5N9R!A=7-WY&AL96XZ`%?D:&QE;B!3
M:64@96EN(%!A<W-W;W)T`%?D:&QE;B!3:64@96EN96X@0F5N=71Z97)N86UE
M;@!,96=E;B!3:64@9F5S="P@=VEE(&1A<R!$871U;2!A;F=E>F5I9W0@=V5R
M9&5N('-O;&PZ`$QI<W1E;F9O<FUA="!A=7-WY&AL96X@*&;\<B!N=6UM97)I
M97)T92!,:7-T96XI`%=E:6AN86-H='-I;G-E;`!+;&%S<V5N9&5F:6YI=&EO
M;B!F_'(@)7,@;FEC:'0@9V5F=6YD96XN`$AE:71E<@!-4RU/9F9I8V4M5&%G
M<R!E;G1F97)N96X`06)F<F%G92!Z=7+\8VMS971Z96X`0F5N=71Z97)D871E
M;B!L]G-C:&5N.B`E<P!"96YU='IE<F1A=&5N(&SV<V-H96X`0F5N=71Z97)D
M871E;B!L]G-C:&5N`%-PY'1E<B!!=69K;&%R96YD`$9O<G1F86AR96X`0VQI
M8VMA=&5L;"!P97(@2%144`!&96YS=&5R('-C:&QI9=]E;@!7;VQK96X`1G+\
M:"!7;VQK96X`0F5W]FQK=`!+;VMO<VEN<V5L;@!-96[\(&5I;F9A:')E;@!:
M=7-A;6UE;FCD;F=E;F1E(%)A:&UE;@!+;VQU;6)I96X`1F%R8F4`1F%R8F%U
M<W=A:&P`1F%R8G=A:&P`4W!A;'1E;CH`4W!A;'1E;OQB97)S8VAR:69T96X`
M0V]M:6-S`$)E9F5H;`!"969E:&QS>F5I;&4`2V]M;65N=&%R`$5I;F1E=71I
M9V5R($YA;64`2V]M;W)E;@!&:7)M80!#;VUP=71E<@!"961I;F=U;F=E;@!"
M961I;F=U;F=E;@!+;VYF:6=U<F%T:6]N<W5N=&5R<V-H:65D90!+;VYF:6=U
M<F%T:6]N(&1E<B!3>6YC:')O;FEZ871I;VX@;6ET(%!$07,L(%-M87)T<&AO
M;F5S('5N9"!/=71L;V]K+@!$:64@2V]N9FEG=7)A=&EO;B!M=7-S(&%K='5A
M;&ES:65R="!W97)D96XN`"5S(&MO;F9I9W5R:65R96X`4&%S<W=O<G0@8F5S
M=.1T:6=E;@!+;VYG;P!$96UO:W)A=&ES8VAE(%)E<'5B;&EC($MO;F=O`%9E
M<F)I;F1U;F<@9F5H;&=E<V-H;&%G96XN`%9E<F)I;F1U;F<@9F5H;&=E<V-H
M;&%G96XZ(`!697)B:6YD=6YG('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L
M<V5R=F5R('=U<F1E(&%B9V5W:65S96XN`%9E<F)I;F1U;F<@>G5M(/9F9F5N
M=&QI8VAE;B!38VAL_'-S96QS97)V97(@=W5R9&4@86)G97=I97-E;BX@1W)U
M;F0Z("5S("@E<RD`5F5R8FEN9'5N9R!Z=6T@1E10+5-E<G9E<B!F96AL9V5S
M8VAL86=E;@!+;VYT86MT90!$:64@2V]N=&%K=&4@=W5R9&5N(&5R9F]L9W)E
M:6-H($EH<F5M($%D<F5S<V)U8V@@:&EN>G5G96;\9W0N`$EN:&%L='-T>7`@
M9&5R(&MO;7!R:6UI97)T96X@1&%T96DZ(`!);FAA;'0@=F]N("(E<R(`5V5I
M=&5R`$-O;VLM26YS96QN`$-O;VMI90!+;W!I97)E;@!+;W!I97)E;B!F96AL
M9V5S8VAL86=E;CH@)7,`075S=V%H;"!K;W!I97)E;@!+;W-T96XM240`0V]S
M=&$@4FEC80!%;&9E;F)E:6YK_'-T90!$:64@3F%C:')I8VAT(&MO;FYT92!N
M:6-H="!M:70@4$=0('9E<G-C:&S\<W-E;'0@=V5R9&5N.B``1&EE($YA8VAR
M:6-H="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!U;G1E<GIE:6-H;F5T('=E<F1E
M;CH@`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!3+TU)344@=F5R
M<V-H;/QS<V5L="!W97)D96XN`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT
M(&UI="!3+TU)344@=6YT97)Z96EC:&YE="!W97)D96XN`$MO;G1A:W0@:V]N
M;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX@)7,`5F5R8FEN9'5N9R!Z
M=6T@3$1!4"U397)V97(@9F5H;&=E<V-H;&%G96XN`$MO;G1O<W1A;F0@:V]N
M;G1E(&YI8VAT(/QB97)P<OQF="!W97)D96XN("5S`%9E<F)I;F1U;F<@>G5M
M($Q$05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+@!&5%`M5F5R8FEN9'5N9R!Z
M=6T@4V5R=F5R("(E<R(@:V]N;G1E(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E
M;CH@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E
M<F1E;BX@)7,`4$=0+41A=&5N(&MO;FYT96X@;FEC:'0@96YT<V-H;/QS<V5L
M="!W97)D96XZ(`!3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E;G1S8VAL
M_'-S96QT('=E<F1E;BX`2V]N=&%K="!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@
M=V5R9&5N+B`E<P!697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@9V5L]G-C
M:'0@=V5R9&5N+B`E<P!$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T("(E<R(@
M:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`1&EE($5M86EL861R97-S
M92!D97,@16UP9N1N9V5R<R!K;VYN=&4@;FEC:'0@97)M:71T96QT('=E<F1E
M;BX`1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI8VAT(&MO;7!L971T(&=E;&5S
M96X@=V5R9&5N+@!697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@875S9V5L
M97-E;B!W97)D96XN("5S`$QI<W1E(&1E<B!697)T96EL97)L:7-T96X@:V]N
M;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+@!$:64@4W1R871E9VEE("(E
M<R(@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R9&5N+@!$87,@5F5R>F5I8VAN
M:7,@(B5S(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@#69F9E;G1L
M:6-H97(@4V-H;/QS<V5L(&MO;FYT92!N:6-H="!V;VT@4V-H;/QS<V5L<V5R
M=F5R(&=E:&]L="!W97)D96XN`"(E<R(@:V]N;G1E(&YI8VAT('IU;2!38VAR
M96EB96X@9V7V9F9N970@=V5R9&5N+@`E<R!K;VYN=&4@;FEC:'0@9V5L97-E
M;B!W97)D96XN`$1A<R!-86EN=&5N86YC95]487-K($UO9'5L("5S(&MO;FYT
M92!N:6-H="!G9?9F9FYE="!W97)D96X`5F5R>F5I8VAN:7,@(B5S(B!K;VYN
M=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!697)B:6YD=6YG('IU;2!,1$%0
M+5-E<G9E<B!K;VYN=&4@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N+@`E<R!K
M;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN`$1A<R!087-S=V]R="!F_'(@
M9&5N(&%N9V5G96)E;F5N($)E;G5T>F5R(&MO;FYT92!N:6-H="!Z=7+\8VMG
M97-E='IT('=E<F1E;BP@=V5I;"!E:6YI9V4@06YG86)E;B!N:6-H="!R:6-H
M=&EG('=A<F5N+B!697)S=6-H96X@4VEE(&5S(&5R;F5U="!O9&5R('=E;F1E
M;B!3:64@<VEC:"!A;B!):')E;B!!9&UI;FES=')A=&]R+"!W96YN(%-I92!W
M96ET97)E($AI;&9E(&)E;O9T:6=E;BX`04-,(&MO;FYT92!N:6-H="!G96QE
M<V5N('=E<F1E;@!$87,@061R97-S8G5C:"!K;VYN=&4@;FEC:'0@9V5L97-E
M;B!W97)D96XN("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A=7-G
M96QE<V5N('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&5N(&MO;FYT92!N:6-H
M="!A=7-G96QE<V5N('=E<F1E;BX@)7,`1&EE(%-E<G9E<F;D:&EG:V5I=&5N
M(&MO;FYT96X@;FEC:'0@875S9V5L97-E;B!W97)D96X`2V]N9FEG=7)A=&EO
M;B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S971Z="!W97)D96XN`%9E<GIE:6-H
M;FES("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`)7,M2V]N
M9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!"
M86-K=7`@9&5R($MO;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H
M97)T('=E<F1E;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N(&MO;FYT92!N
M:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S`$1A<R!!:W1U86QI<VEE<G5N
M9W-S:W)I<'0@:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!G97-P96EC:&5R="!W
M97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E<R!K;VYN=&4@;FEC
M:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$:64@2V]N9FEG=7)A=&EO;B`E<R!K
M;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B!3:64@:_9N;F5N(&5N
M='=E9&5R(&5I;F4@9&5R($WV9VQI8VAK96ET96X@=6YT97(@)7,@=F5R=V5N
M9&5N+"!U;2!D96X@0V]D92!Z=2!S<&5I8VAE<FXL(&]D97(@9&5N('5N=&5N
M<W1E:&5N9&5N($-O9&4@;6%N=65L;"!N86-H("5S(&MO<&EE<F5N+@!$97(@
M3$1!4"U397)V97(@:V]N;G1E(&YI8VAT(&1U<F-H<W5C:'0@=V5R9&5N+@`B
M)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1E<B!+;VYT86MT
M(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN("5S`%9E<G1E:6QE
M<FQI<W1E(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N+B`E<P!$
M:64@2V]N9FEG=7)A=&EO;B!F_'(@(B5S(B!K;VYN=&4@;FEC:'0@9V5S<&5I
M8VAE<G0@=V5R9&5N.B`E<P!$:64@36]Z:6QL82!3:61E8F%R(&MO;FYT92!N
M:6-H="!G969U;F1E;B!W97)D96XN(%-T96QL96X@4VEE('-I8VAE<BP@9&%S
M<R!D:64@4VED96)A<B!G9?9F9FYE="!I<W0N`$1E;2!"96YU='IE<B`B)7,B
M(&MO;FYT96X@9&EE(&9O;&=E;F1E(%)E8VAT92!F_'(@9&5N($]R9&YE<B`B
M)7,B(&YI8VAT('IU9V5W:65S96X@=V5R9&5N.B`E<P!'97KD:&QT97(@5&5X
M=`!,86YD`$MU<G-E`$5R<W1E;&QE;@!,:6YK(&5R<W1E;&QE;@!.975E($ED
M96YT:73D="!A;FQE9V5N`%5N=&5R;W)D;F5R(&5R<W1E;&QE;@!%<G-T96QL
M97)R96-H=&4`2W)E9&ET:V%R=&5N;G5M;65R`$MR;V%T:65N`$MU8F$`06MT
M=65L;&4@-"!0:&%S96X`06MT=65L;&4@4V5S<VEO;G,`06MT=65L;&4@6F5I
M=`!!:W1U96QL92!54DP@:7-T`$%K='5E;&QE($)E;G5T>F5R`$%K='5E;&QE
M<R!7971T97(`1&5R>F5I=&EG92!"961I;F=U;F=E;CH@`$%K='5E;&QE<B!3
M=&EL`$QE9V5N(%-I92!F97-T+"!W96QC:&4@075F9V%B96X@;F%C:"!D97(@
M06YM96QD=6YG(&)E:2`E<R!E<FQE9&EG="!W97)D96X@<V]L;&5N+@!!=7-S
M8VAN96ED96X`075S=V%H;"!A=7-S8VAN96ED96X`6GEP97)N`$MY<FEL;&ES
M8V@@*$M/23@M4BD`2WER:6QL:7-C:"`H5VEN9&]W<RTQ,C4Q*0!+>7)I;&QI
M<V-H+U5K<F%I;FES8V@@*$M/23@M52D`5'-C:&5C:&ES8VAE(%)E<'5B;&EK
M`%14`$133B`H<VEE:&4@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!4Y&=L:6-H`$1A
M=&%4<F5E($)R;W=S97(`1&%T96YB86YK86)F<F%G90!$871U;0!%;7!F86YG
M<V1A='5M`$1A='5M<V%U<W=A:&P`5&%G`%-P86QT92!?;/9S8VAE;@!$97IE
M;6)E<@!:86AL96X`16EN>G5G('9E<G)I;F=E<FX`4W1A;F1A<F0`4W1A;F1A
M<F1F87)B90!3=&%N9&%R9&ED96YT:73D=`!3=&%N9&%R9'-H96QL`$1E9FEN
M:71I;VYE;@!,]G-C:&5N`%IE;&QE(&SV<V-H96X`1W)U<'!E(&SV<V-H96X`
M3&]G(&SV<V-H96X`4F5C:'1E(&SV<V-H96X`3F%C:')I8VAT96X@;/9S8VAE
M;B!U;F0@96YT9F5R;F5N`%IE;&QE(&SV<V-H96X`4W!A;'1E(&SV<V-H96X`
M0F5S=&5H96YD92!A;'1E<FYA=&EV92!6;W)L86=E(&SV<V-H96X`3F%C:')I
M8VAT96X@;/9S8VAE;@!296-H=&4@9OQR("(E<R(@;/9S8VAE;@!296-H=&4@
M9OQR("(E<R(@=6YD(&%L;&4@56YT97)R96-H=&4@;/9S8VAE;C\`6F5I;&4@
M;/9S8VAE;@!!=7-G97?D:&QT92!)9&5N=&ETY'0@;/9S8VAE;@!5;G1E<F]R
M9&YE<B!L]G-C:&5N`$1I92!A:W1U96QL92!3<&%L=&4@;/9S8VAE;@!$:64@
M86MT=65L;&4@6F5I;&4@;/9S8VAE;@!$87,@06MT=6%L:7-I97)U;F=S<VMR
M:7!T("(E<R(@=W5R9&4@9V5L]G-C:'0N`$%U<VQI969E<G5N9W-Z96ET`$3D
M;F5M87)K`$)E<V-H<F5I8F5N(%-I92!D87,@4')O8FQE;0!"97-C:')E:6)U
M;F<`1&5T86EL<R`H875C:"!I;B!(;W)D97,@3&]G9&%T96DI.@!$971A:6QS
M('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET9V5L;V=G="X`16YT
M=VEC:VQU;F<`5&%U<'5N:W0`5&%U<'5N:W0@9&5R(&QE='IT96X@4W1U;F1E
M.B``5&%U<'5N:W0Z(`!6;VX@;&EN:W,@;F%C:"!R96-H=',`5F]N(')E8VAT
M<R!N86-H(&QI;FMS`%9E<GIE:6-H;FES`%IE:70@:6T@,C0M4W1U;F1E;BU&
M;W)M870@86YZ96EG96X_`$%N>F5I9V4M16EN<W1E;&QU;F=E;@!$971A:6QI
M97)T92!6;W)H97)S86=E(&%N>F5I9V5N`%9O<FAE<G-A9V4@*%1!1BD@86YZ
M96EG96X`06YZ96EG969O<FUA=`!%;7!F86YG<V)E<W3D=&EG=6YG`$1S8VAI
M8G5T:0!.:6-H="!L]G-C:&5N`$=R96EF96X@4VEE(&YI8VAT(&1I<F5K="!A
M=68@;6%I;G1E;F%N8V4N<&AP('IU`$5N=&CD;'0@9&EE(&5R<W1E(%IE:6QE
M(&1I92!&96QD;F%M96X_(%=E;FX@:F$L(&1I97-E<R!!=7-W86AL:^1S=&-H
M96X@;6%R:VEE<F5N.@!$;VUI;FEC80!$;VUI;FEK86YI<V-H92!297!U8FQI
M:P!.;V-H(&ME:6YE;B!:=6=A;F<_($AI97(@86YM96QD96XN`$AE<G5N=&5R
M;&%D96X`)7,@2&5R=6YT97)L861E;@!%<GIE=6=T92!+;VYF:6=U<F%T:6]N
M(&%L<R!02%`M4VMR:7!T(&AE<G5N=&5R;&%D96XN`$%U<W=A:&QL:7-T90!$
M<F]G96X`16UA:6P`16UA:6PM;F%C:"U335,M9V%T97=A>2!F_'(@4')O=FED
M97(L(&1I92!E:6YE;B!S;VQC:&5N($1I96YS="!U;G1E<G-T_'1Z96XN`$9%
M2$Q%4@!%8W5A9&]R`$)E87)B96ET96X`0FQO8VL@8F5A<F)E:71E;@!'<G5P
M<&4@8F5A<F)E:71E;@!296-H=&4@8F5A<F)E:71E;@!296-H=&4@8F5A<F)E
M:71E;@!296-H=&4@9OQR("<E<R<@8F5A<F)E:71E;@!%:6YS=&5L;'5N9V5N
M(&)E87)B96ET96X@9OQR.@!296-H=&4@9OQR("(E<R(@8F5A<F)E:71E;@!2
M96-H=&4@9OQR("5S(&)E87)B96ET96X`0FEL9'5N9P#$9WEP=&5N`$5L(%-A
M;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6QA9')E<W-E`$1I92!%
M;6%I;&%D<F5S<V5N(&W\<W-E;B!G;&5I8V@@<V5I;BX`16UA:6P@;6ET($)E
M<W3D=&EG=6YG`$5M86EL+6YA8V@M4TU3+4=A=&5W87D`4VUI;&5Y<P!,965R
M92!.86-H<FEC:'0N`$QE97)E<R!%<F=E8FYI<RX`4W5C:&)E9W)I9F9E(&SV
M<V-H96X`16EN9OQG96X@=F]N($)I;&1E<FX@875S($9O=&]G86QE<FEE;B!I
M;B!D96X@5&5X="!E<FQA=6)E;C\`2V]N=&5X=&UE;OP@8F5I(%)E8VAT<VML
M:6-K(&%K=&EV:65R96X_`$5N9&IA:'(`161I=&]R('9E<F=R]M]E<FX`1V5B
M96X@4VEE(&5I;F4@4VEC:&5R:&5I='-F<F%G92!E:6XL(&1I92!):&YE;B!G
M97-T96QL="!W:7)D+"!W96YN(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K<V5T
M>F5N(&WV8VAT96XL('HN($(N(")7:64@;&%U=&5T(&1E<B!.86UE($EH<F5S
M($AA=7-T:65R<S\B.@!(:65R(&1I92!":6QD+5523"!A;F=E8F5N`$=E8F5N
M('-I92!D:64@0G5C:'-T86)E;B!U;G1E;B!E:6XZ`,1Q=6%T;W)I86PM1W5I
M;F5A`$5R:71R96$`1F5H;&5R`$9E:&QE<B!B96EM($5R<W1E;&QE;B!E:6YE
M<R!";&]C:W,Z("5S`$9E:&QE<B!B96EM($SV<V-H96X@9&5S(%-Y;F-H<F]N
M:7-A=&EO;G-A;FME<G,Z("5S`$9E:&QE<B!B96EM($SV<V-H96X@9&5S(%-Y
M;F-H<F]N:7-A=&EO;G-L;V=S.B`E<P!&96AL97(@8F5I;2!%<GIE=6=E;B!D
M97,@26YH86QT<SH@)7,`1F5H;&5R(&)E:6T@Q&YD97)N(&1E<R!087-S=V]R
M=',Z("5S`$9E:&QE<B!I;B!D97(@16UA:6QN86-H<FEC:'0N`$9E:&QE<B!B
M96EM(%-C:')E:6)E;B!V;VX@(B5S(BX`17-T;&%N9`#$=&AI;W!I96X`171N
M:7-C:&5S`$5U<F]P80!!;&QE(#$U($UI;G5T96X`06QL92`R($UI;G5T96X`
M06QL92`S,"!396MU;F1E;@!!;&QE(#4@36EN=71E;@!"96D@:F5D97(@06YM
M96QD=6YG`$%L;&4@:&%L8F4@4W1U;F1E`$%L;&4@-C`@4V5K=6YD96X`0F5I
M<W!I96QW97)T93H`075S9OQH<F5N`%9E<F=R]M]E<FX`365N_"!A=7-F86AR
M96X`)RDG(&5R=V%R=&5T`$5I;GIE;&YE<R!7;W)T(&]D97(@4W5C:&)E9W)I
M9F8@:6X@06YF_&AR=6YG<WIE:6-H96X@97)W87)T970`5F5R9F%L;'-D871U
M;0!%>'!O;F5N=`!6;W)D97)G<G5N9&9A<F)E`$AO8VAL861E;B!D97(@2V]N
M9FEG=7)A=&EO;B!P97(@1E10`$)E;G5T>F5R96EN<W1E;&QU;F=E;B!K;VYN
M=&5N(&YI8VAT(&=E;&%D96X@=V5R9&5N+@!697)B:6YD=6YG('IU;2!,1$%0
M(%-E<G9E<B!G97-C:&5I=&5R="X`5F5R8FEN9'5N9R!Z=6T@4TU"+5-E<G9E
M<B!G97-C:&5I=&5R="X`17,@:V]N;G1E(&ME:6YE($MO<&EE('9O;B`B)7,B
M(&5R<W1E;&QT('=E<F1E;BX`17,@:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!K
M;W!I97)T('=E<F1E;BX`075F8F%U(&5I;F5N(&YE=65N(%-!4TPM5F5R8FEN
M9'5N9R!I<W0@9F5H;&=E<V-H;&%G96XN`$5S(&MO;FYT92!N:6-H="!N86-H
M("(E<R(@=F5R<V-H;V)E;B!W97)D96XN`$9E:&QE<B!B96EM($QE<V5N.B`E
M<P!(96ET97(`1F%L:VQA;F1I;G-E;&X`1F%R]F5R`%-C:'=E<F5R($9E:&QE
M<CH`1F%X`$9A>&4`1F5B<G5A<@!'96;\:&QT92!496UP97)A='5R`$=E9OQH
M;'1E(%1E;7!E<F%T=7(Z(`!697)E:6YZ96QT92!38VAA=65R`%9E<F5I;GIE
M;'1E(%-C:&YE97-C:&%U97(`1F5L9&UA=')I>`!&:6=L970@0T%05$-(00!&
M:6=L970M1F]N=`!&:61S8VAI`$1A=&5I`$%N>F%H;#H@)7,@1&%T96D`06YZ
M86AL.B`E<R!$871E:65N`$1A=&5I;6%N86=E<@!$871E:6YA;64`1&%T96EA
M=7-W86AL`$1A=&5I+4AO8VAL861E;@!$87,@2&]C:&QA9&5N('9O;B!$871E
M:65N('=I<F0@;FEC:'0@=6YT97)S=/QT>G0N`$9I;'1E<@!&:6YN;&%N9`!%
M<G-T92!(Y&QF=&4`17)S=&5S(%9I97)T96P`5F5R:.1L=&YI<R!Z=7+\8VMS
M971Z96X`56UD<F5H96X`5&5X=&9L==\`3F5B96P`1&%S(%9E<GIE:6-H;FES
M("5S(&5X:7-T:65R="!N:6-H=`!38VAR:69T9F%R8F4`17-S96X`1OQR($)R
M;W=S97(L(&1I92!K96EN92!":6QD97(@=6YT97)S=/QT>F5N`%9O<FAE<G-A
M9V4@*%1!1BD`5F]R:&5R9V5S86=T92!486=E("A6;W)H97)S86=E;B!E;G1H
M86QT96X@5&%G92!U;F0@3N1C:'1E+"!E:6X@:&]H97(@5V5R="!K86YN('IU
M(&5I;F5M('-E:'(@9W)OWV5N($)L;V-K(&;\:')E;BD`4&%S<W=O<G0@=F5R
M9V5S<V5N/P!&;W)M=6QA<F4`1VS\8VMS:V5K<P!';/QC:W-K96MS='EP`$=L
M_&-K<VME:W-E`$=L_&-K<VME:W-E(#(`1F]R96X`5V5I=&5R;&5I='5N9P!&
M<@!286AM96X`1G)A;FMR96EC:`!%=7)O<.1I<V-H97,@1G)A;FMR96EC:`!&
M<F%N>O9S:7-C:"U'=6%Y86YA`$9R86YZ]G-I<V-H+5!O;'EN97-I96X`1G)A
M;GKV<VES8VAE($=E8FEE=&4@:6T@<_QD;&EC:&5N($EN9&ES8VAE;B!/>F5A
M;@!6;VX`075S(`!6;VQL<W3D;F1I9V4@0F5S8VAR96EB=6YG`%9O;&QM;VYD
M`%9O;&QS=.1N9&EG97(@3F%M90!'86)U;@!":6QD97(@875S(&1I97-E<B!'
M86QE<FEE`$=A;&5R:64Z`$=A;6)I80`E<RU+;VYF:6=U<F%T:6]N(&5R>F5U
M9V5N`$5R>F5U9W1E<B!#;V1E`$=E;W)G:65N`$1E=71S8VAL86YD`$=H86YA
M`$=I8G)A;'1A<@!6;W)N86UE`$%L;&=E;65I;F4@16EN<W1E;&QU;F=E;@!,
M;W,`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!3=6-H90!'<F%U<W1U9F5N
M`$=R:65C:&5N;&%N9`!'<FEE8VAI<V-H("A)4T\M.#@U.2TW*0!'<O9N;&%N
M9`!'<F5N861A`$=R=7!P96YV97)W86QT=6YG`$=R=7!P96YN86UE;B!D_')F
M96X@;FEC:'0@;&5E<B!S96EN`$=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@
M:V]N;G1E(&YI8VAT(&AI;GIU9V5F_&=T('=E<F1E;BX@365L9'5N9R!D97,@
M4V5R=F5R<SH@`$=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@:V]N;G1E(&YI
M8VAT(&=E;/9S8VAT('=E<F1E;@!'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S
M(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N`$=R=7!P96X`1W5A
M9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'87-T<F5C:'1E`$?D
M<W1E8G5C:`!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!$97(@
M161I=&]R(&MA;FX@9&EE(&QE='IT92!:96QL92!E:6YE<B!:96EL92!N:6-H
M="!L]G-C:&5N+@!$97(@161I=&]R(&MA;FX@9&EE(&QE='IT92!3<&%L=&4@
M96EN97(@5&%B96QL92!N:6-H="!L]G-C:&5N+@!$97(@161I=&]R(&MA;FX@
M9&EE(&QE='IT92!:96EL92!E:6YE<B!486)E;&QE(&YI8VAT(&SV<V-H96XN
M`$A45%`M075T:&5N=&EF:7II97)U;F<@;FEC:'0@9V5F=6YD96XN`$AA:71I
M`$AA<V@M06QG;W)I=&AM=7,`1&EE<VEG`-QB97)S8VAR:69T`$MO<&9E:6YT
M<N1G90!(96%R9"T@=6YD($UC1&]N86QD:6YS96QN`%-C:'=E<F4@1V5W:71T
M97(`2&5B<N1I<V-H("A)4T\M.#@U.2TX+4DI`$CV:&4`2&EL9F4`161I=&]R
M:&EL9F4`2&EL9F4`2&5M:7-P:&5R90!$:65S(&ES="!D97(@0F5G:6YN(&1E
M<B!$871E:3H`2&]C:`!?4W1A<G1S96ET90!6871I:V%N<W1A9'0`4W1A<G1S
M96ET90!!9')E<W-E('!R:79A=`!(96EM=F5R>F5I8VAN:7,`5&5L969O;B!P
M<FEV870`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!5
M;F?\;'1I9V4@)7,M6$U,+41A=&5N(&EN($YA8VAR:6-H="`E<P!(;W)D92]+
M;VQA8CH@17,@<&%S<W0@:V5I;F4@3F%C:')I8VAT('IU;2!/8FIE:W0@)7,`
M2&]R9&4O2V]L86(Z($ME:6X@3V)J96MT('9O;2!4>7`@)7,@:6X@3F%C:')I
M8VAT("5S(&=E9G5N9&5N`$AO<F1E+TMO;&%B.B`E<R`B)7,B('=U<F1E(&5R
M9F]L9W)E:6-H(&5N=&9E<FYT`$AO<F1E+TMO;&%B.B!$:64@26YT96=R871I
M;VYS9G5N:W1I;VYE;B!B96[V=&EG96X@9&EE(")D;VUX;6PB(%!(4"U%<G=E
M:71E<G5N9P!(;W)D92]+;VQA8CH@1OQR(&1A<R!/8FIE:W0@)7,@:V]N;G1E
M(&ME:6X@;F5U97(@6$U,+4)A=6T@97)Z975G="!W97)D96X`2&]R9&4O2V]L
M86(Z("5S("(E<R(@:V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;CH@)7,`
M2&]R9&4O2V]L86(Z($1I92!-24U%+4E$(&1E<R!!8G-C:&YI='1S('9O;2!4
M>7`@)7,@:V]N;G1E(&YI8VAT(&AE<F%U<V=E9G5N9&5N('=E<F1E;BX`2&]R
M9&4O2V]L86(Z("5S("(E<R(@:V]N;G1E(&YI8VAT('-Y;F-H<F]N:7-I97)T
M('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z($1I92!G96UE:6YS86UE;B!/8FIE
M:W1E(&MO;FYT96X@;FEC:'0@<WEN8VAR;VYI<VEE<G0@=V5R9&5N.B`E<P!(
M;W)D92]+;VQA8CH@56YB96MA;FYT97,@9V5M96EN<V%M97,@3V)J96MT("(E
M<R(`2&]R:7IO;G1A;&4@3&EN:64`2&]R:7IO;G1A;&5R($EN;F5N86)S=&%N
M9`!(;W)I>F]N=&%L.@!7:64@<VEN9"!3:64@:&EE<FAE<F=E;&%N9W0_($)I
M='1E(&%N(&1I92!%;G1W:6-K;&5R('IU<OQC:VUE;&1E;B$I`%=I92!V:65L
M92!3<&%L=&5N('-O;&QE;B!Z=7-A;6UE;F=E9OQG="!W97)D96X_`%=I979I
M96QE($9E;&1E<B`H4W!A;'1E;BD@9VEB="!E<S\`5VEE('9I96QE(%IE:6QE
M;B!S;VQL96X@>G5S86UM96YG96;\9W0@=V5R9&5N/P!,=69T9F5U8VAT:6=K
M96ET`$QU9G1F975C:'1I9VME:70Z(`!+;VUI:V5R`%5N9V%R;@!!;FQE9V5N
M(&1E<R!)34%0+5!O<W1F86-H<R!I<W0@9F5H;&=E<V-H;&%G96XZ("5S`$SV
M<V-H96X@9&5S($E-05`M4&]S=&9A8VAS(&ES="!F96AL9V5S8VAL86=E;CH@
M)7,`1F5S=&QE9V5N(&1E<B!)34%0+5!O<W1F86-H+5%U;W1A(&ES="!F96AL
M9V5S8VAL86=E;CH@)7,`25`M061R97-S90!)4"U!9')E<W-E(&YI8VAT('9E
M<F;\9V)A<BX`25`M061R97-S92!N:6-H="!I;2!E<FQA=6)T96X@0TE$4BU"
M;&]C:RX`5F5R;&5T>G5N9R!D97(@9F5S=&=E;&5G=&5N($E0+@!:96EL92!E
M:6YF_&=E;B!?=F]R`$ES;&%N9`!.=7(@0FEL9&5R`$EC;VYS(&;\<B`E<P!"
M:6QD97(@=6YD(%1E>'0`0F5Z96EC:&YU;F<@9&5R($ED96YT:73D=`!796YN
M('-I92!N:6-H="!K;W)R96MT(&%N9V5Z96EG="!W:7)D+"`E<RP@=6T@<VEE
M(&EN(&5I;F5M(&YE=65N($9E;G-T97(@86YG97IE:6=T('IU(&)E:V]M;65N
M+@!796YN(%-I92!M:70@9&5M($EN=&5R;F5T($5X<&QO<F5R(&ME:6YE(%-Y
M;6)O;&4@<V5H96XL(&W\<W-E;B!3:64@9&EE<V5S($OD<W1C:&5N(&UA<FMI
M97)E;BP@=6T@4$Y'+51R86YP87)E;GH@875S>G5S=&5L;&5N+@!796YN(%-I
M92!D:65S92!.86-H<FEC:'0@86X@4W1E;&QE(&5I;F4@0FEL9&5S('-E:&5N
M+"!K86YN($EH<B!"<F]W<V5R(&1A<R!":6QD+"!D87,@4VEE(&AO8VAL861E
M;B!M]F-H=&5N(&YI8VAT(&%N>F5I9V5N+@!":6QD=F]R<V-H874Z`$)I;&0M
M55),`$)I;&0M55),.@!":6QD('9O;B!'86QE<FEE`$)I;&0@=F]N($=A;&5R
M:64Z`$)I;&0M2&]C:&QA9&5N`$)I;&1E<@!);7!O<G1I97)E;BP@4V-H<FET
M="`E9`!);7!O<G1I97)T97,@1F5L9#H@)7,`26UP;W)T:65R=&4@1F5L9&5R
M.@!:96EL92!E:6YF_&=E;B!?;F%C:`!5;F?\;'1I9V4@06MT:6]N(&%N9V5G
M96)E;BX`56YG_&QT:6=E<B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O
M<G0N`$9A;'-C:&5R($)E;G5T>F5R;F%M92!O9&5R($5M86EL861R97-S92X@
M5F5R<W5C:&5N(%-I92!E<R!E<FYE=70@;V1E<B!W96YD96X@4VEE('-I8V@@
M86X@26AR96X@4WES=&5M861M:6YI<W1R871O<BP@=V5N;B!3:64@=V5I=&5R
M92!(:6QF92!B96[V=&EG96XN`$5I;GIU9R!V97)G<O;?97)N`$EN9&EE;@!%
M:6YZ96QN92!"96YU='IE<@!);F1O;F5S:65N`$EN9F]R;6%T:6]N`$EN9F]R
M;6%T:6]N96X`26YF;W)M871I;VYE;B!N:6-H="!M96AR('9E<F;\9V)A<BX`
M7U-P86QT92!D879O<B!E:6YF_&=E;@!":6QD(&AI;GIU9OQG96X`5&%B96QL
M92!E:6YF_&=E;@!,:6YK(&5I;F;\9V5N`%-?<&%L=&4@9&%N86-H(&5I;F;\
M9V5N`$5I;F4@;F5U92!3<&%L=&4@;F%C:"!D97(@86MT=65L;&5N(&5I;F;\
M9V5N`$5I;F4@;F5U92!3<&%L=&4@=F]R(&1E<B!A:W1U96QL96X@96EN9OQG
M96X`16EN92!N975E(%IE:6QE(&YA8V@@9&5R(&%K='5E;&QE;B!E:6YF_&=E
M;@!%:6YE(&YE=64@6F5I;&4@=F]R(&1E<B!A:W1U96QL96X@96EN9OQG96X`
M16EN96X@;F5U96X@06)S871Z(&YA8V@@9&5M(&%K='5E;&QE;B!%;&5M96YT
M(&5I;F;\9V5N`$5I;F5N(&YE=65N($%B<V%T>B!V;W(@9&5M(&%K='5E;&QE
M;B!%;&5M96YT(&5I;F;\9V5N`$%L=&5R;F%T:79E(%9O<FQA9V4@96EN9OQG
M96X`1V5B96X@4VEE(&5I;F4@16UA:6QA9')E<W-E(&%N+"!A;B!D:64@9&%S
M(&YE=64@4&%S<W=O<G0@9V5S8VAI8VMT('=E<F1E;B!S;VQL.@!:96QL92!D
M86YA8V@@96EN9OQG96X`6F5L;&4@9&%V;W(@96EN9OQG96X`4W!A;'1E(&1A
M;F%C:"!E:6YF_&=E;@!3<&%L=&4@9&%V;W(@96EN9OQG96X`3F%C:')I8VAT
M96X@:&EN>G5F_&=E;@!!8G-A='H@9&%N86-H(&5I;F;\9V5N`$%B<V%T>B!D
M879O<B!E:6YF_&=E;@!:96EL92!D86YA8V@@96EN9OQG96X`6F5I;&4@9&%V
M;W(@96EN9OQG96X`1V5B96X@4VEE(&1I92!!;G1W;W)T(&%U9B!D:64@4VEC
M:&5R:&5I='-F<F%G92!E:6XZ`$)I;&0@96EN9OQG96XO8F5A<F)E:71E;@!,
M:6YK(&5I;F;\9V5N+V)E87)B96ET96X`6G4@=V5N:6<@1W5T:&%B96XL('5M
M(&%N(&1I92!697)T96EL97)L:7-T92!Z=2!V97)S8VAI8VME;BX`6G4@=V5N
M:6<@1W5T:&%B96XN`$=A;GIZ86AL`$QI<W1E('9O;B!'86YZ>F%H;&5N`%5N
M9_QL=&EG97(@541(+B`H57-E<B!$871A($AE861E<BDN`%5N9_QL=&EG92!:
M25`M1&%T96XN`%5N9_QL=&EG92!!;G=E;F1U;F<N`%5N9_QL=&EG92!"871C
M:"U)1"X`56YG_&QT:6=E($1A=&5N(&5I;F=E8F5N+@!5;F?\;'1I9V4@6FEE
M;&%D<F5S<V4N`%5N9_QL=&EG97,@1&%T96EF;W)M870`56YG_&QT:6=E<B!,
M:7IE;GIS8VAL_'-S96PN`%5N9_QL=&EG97(@3W)T(&%N9V5G96)E;BX`56YG
M_&QT:6=E<B!M<V=?='EP92X`56YG_&QT:6=E(&]D97(@9F5H;&5N9&4@87!I
M7VED+@!5;F?\;'1I9V4@;V1E<B!F96AL96YD92!087)A;65T97(N`%5N9_QL
M=&EG97,@W&)E<G)E8VAT+@!5;F?\;'1I9V4@4&%R=&YE<BU)1"X`56YG_&QT
M:6=E<B!0<F]D=6MT8V]D92X`56YG_&QT:6=E<R!0<F]T;VMO;&PN`%5N9_QL
M=&EG97(@16UP9N1N9V5R.B`B)7,B`%5N9_QL=&EG97,@9V5M96EN<V%M97,@
M3V)J96MT`%5N9_QL=&EG92!5<G-P<G5N9W-A9')E<W-E+@!5;F?\;'1I9V4@
M56YI8V]D92U$871E;BX`26YV96YT87(`075S=V%H;"!U;6ME:')E;@!)<VQA
M;6ES8VAE(%)E<'5B;&EK($ER86X`27)A:P!)<FQA;F0`27-L92!O9B!-86X`
M5F5R96EN>F5L=&4@1V5W:71T97(`27-R865L`$%U<W-T96QL97(`2W5R<VEV
M`$ET86QI96X`2F%M86EK80!*86YU87(`2F%P86X`2F%P86YI<V-H("A)4T\M
M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE;@!*=6QI`$IU;FD`0FQO8VMS871Z
M`%IE;G1R:65R96X`0FQO8VMS871Z`$QI;FMS(&%U<W)I8VAT96X`4F5C:'1S
M(&%U<W)I8VAT96X`2V%S86-H<W1A;@!/<FEG:6YA;"!B96EB96AA;'1E;C\`
M2V5N:6$`2V5R8F5R;W,M4V5R=F5R(&AA="!!=71H96YT:69I>FEE<G5N9R!Z
M=7+\8VMG97=I97-E;BX`2V5R;F5L+4YE=6QI;F=E`%-C:&S\<W-E;&5R>F5U
M9W5N9P!&:6YG97)A8F1R=6-K(&1E<R!38VAL_'-S96QS`%-C:&S\<W-E;&SD
M;F=E`%-C:&S\<W-E;'1Y<`!38VAL_'-S96QZ=V5C:P!$97(@4V-H;/QS<V5L
M(&)E9FEN9&5T('-I8V@@8F5R96ET<R!A=68@9&5M(/9F9F5N=&QI8VAE;B!3
M8VAL_'-S96QS97)V97(N`$MI;F1E<@!+:7)I8F%T:0!$96UO:W)A=&ES8VAE
M(%9O;&MS<F5P=6)L:6,@2V]R96$`4F5P=6)L:6L@2V]R96$`2V]R96%N:7-C
M:"`H155#+4M2*0!+=7=A:70`2VER9VES:7-T86X`06Y?<&%S<V5N`%-P<F%C
M:&4`3&%O<P!,971Z=&4@2.1L9G1E`$QE='IT92!087-S=V]R=.1N9&5R=6YG
M`$QE='IT97,@5FEE<G1E;`!,971Z=&4@06MT=6%L:7-I97)U;F<Z`$QE='IT
M92!!;FUE;&1U;F<Z("5S`$QE='IT92!!;FUE;&1U;F<Z("5S('9O;B`E<P!,
M971Z=&4@06YM96QD=6YG.B!.;V-H(&YI90!,971T;&%N9`!'97-E='H`1F]R
M;6%T`$QE97(@;&%S<V5N(&;\<B!K96EN96X@4F%H;65N`$QI8F%N;VX`3&EN
M:W,`3&EN:V4@W&)E<G-C:')I9G0`3&EN:V4@5V5R=&4`3&5S;W1H;P!%8F5N
M90!,:6)E<FEA`$QI8GEE;@!,:65C:'1E;G-T96EN`%-P<OQH<F5G96X`3&5I
M8VAT97(@4F5G96X`1G+\:"!L96EC:'1E<B!296=E;@!3<.1T97(@3&5I8VAT
M97(@4F5G96X`3&5I8VAT92!296=E;G-C:&%U97(`3&5I8VAT97(@4F5G96X@
M;6ET($=E=VET=&5R`$QE:6-H=&5R(%-C:&YE969A;&P`3&5I8VAT92!38VAN
M965S8VAA=65R`$QI;65R:6-K`$QI;FL`3&EN:R!V97)W96ES="!A=68Z`$5M
M86EL861R97-S92!V97)L:6YK96X_`$QI;FMS`$QI;G5X+4=L_&-K<VME:W-E
M`$QI<W0@+2!"96YU='IE<B!K86YN(&1E;B!/<F1N97(@<V5H96X`1&%T96YB
M86YK96X@86YZ96EG96X`2&EL9F5E:6YT<N1G92!A;GIE:6=E;@!486)E;&QE
M;B!A;GIE:6=E;@!,:7-T96XM07)C:&EV`$QI<W1E;BU(:6QF90!,:7-T96XM
M260`3&ES=&5N+4)E<VET>F5R`$QI<W1E;BU!9')E<W-E`$QI<W1E;BU!;FUE
M;&1U;F<`3&ES=&5N+4%B;65L9'5N9P!$87,@06YZ96EG96X@9&5R(%-E<W-I
M;VYS(&ES="!F96AL9V5S8VAL86=E;CH@)7,`1&%S($%N>F5I9V5N(&1E<B!"
M96YU='IE<B!I<W0@9F5H;&=E<V-H;&%G96XZ("5S`$1A<R!!;GIE:6=E;B!D
M97(@0F5N=71Z97(@:7-T(&YI8VAT(&WV9VQI8V@N`$QI=&5R871U<@!,:71A
M=65N`$QA9&4N+BX`3&]K86QE(%5H<GIE:70Z(`!3<')A8VAE('5N9"!:96ET
M`$]R=`!!;FUE;&1E;@!,;V<@9&5R(&QE='IT96X@4WEN8VAR;VYI<V%T:6]N
M+@!!8FUE;&1E;@!!;FUE;&1E;@!!;FUE;&1E875F9V%B96X`1&EE($%N;65L
M9'5N9R!I<W0@9F5H;&=E<V-H;&%G96XL('=E:6P@4VEE($EH<F5N($)E;G5T
M>F5R;F%M96X@;V1E<B!):'(@4&%S<W=O<G0@9F%L<V-H(&5I;F=E9V5B96X@
M:&%B96XN`$%N;65L9'5N9R!F96AL9V5S8VAL86=E;BX`3&%N9V5R(%1E>'0`
M3&EE8F4`3FEE9')I9P!+;"X@9W)I96-H:7-C:&4@0G5C:'-T86)E;@!+;"X@
M;&%T96EN:7-C:&4@0G5C:'-T86)E;@!+;"X@<O9M:7-C:&4@6F%H;&5N`$QU
M>&5M8G5R9P!-30!-3U1$`$U3+51.148M06YH86YG(&5N=&AI96QT(&ME:6YE
M($1A=&5N+@!(24Y714E3`$UA8V%O`$1I92!E:&5M86QI9V4@2G5G;W-L87=I
M<V-H92!297!U8FQI:R!-87IE9&]N:65N`$UA9&%G87-K87(`36%G:64`5V5B
M;6%I;`!%;6%I;"!!9&UI;FES=')A=&EO;@!,:6YK(%]A;FQE9V5N+BXN`$UA
M;&%W:0!-86QA>7-I80!-86QI9&EV96X`36%L:0!-86QT80!697)W86QT96X@
M4VEE(&1I92!+871E9V]R:65N+"!M:70@9&5N96X@4VEE($5L96UE;G1E('5N
M9"!%:6YT<N1G92!K96YN>F5I8VAN96X@:_9N;F5N+"!S;W=I92!D:64@>G5G
M96CV<FEG96X@1F%R8F5N+@!-87`R-"U+87)T90!-87!1=65S="U+87)T90!:
M=6]R9&YU;F=E;B!G97-P96EC:&5R="X`3>1R>@!!==]E;F%B<W1A;F0`36ET
M($=E;&5S96XM+U5N9V5L97-E;BU3=&%T=7,@=F5R<V5H96X`36ET(&%N9&5R
M96T@4W1A='5S('9E<G-E:&5N("AZ+D(N(%=I8VAT:6<O0F5A;G=O<G1E="D`
M36%R<VAA;&QI;G-E;&X`36%R=&EN:7%U90!:=6=E;W)D;F5T92!&96QD97(`
M36%U<F5T86YI96X`36%U<FET:75S`$UA>&EM86P@97)L875B=&5R($MR961I
M="X`36%X:6UA;&4@3F%C:'1I8VAT96YT96EL92#\8F5R<V-H<FET=&5N+@!(
M]F-H<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T=6YD96XZ(`!(]F-H
M<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#8@4W1U;F1E;CH@`$UA>&EM86QE
M($%N>F%H;"!A;B!0;W)T86QB;/9C:V5N`$UA>&EM86QE($SD;F=E`$UA:0!-
M87EO='1E($ES;&%N9`!-961I>FEN`$UI=&=L:65D97(`365N_&UO9'5S.@!:
M96QL96X@>G5S86UM96YF_&=E;@!.86-H<FEC:'0`1&EE($YA8VAR:6-H="!K
M;VYN=&4@97)F;VQG<F5I8V@@_&)E<G!R_&9T('=E<F1E;B!A8F5R(&YI8VAT
M(&1A<R!:97)T:69I:V%T(&1E<R!!8G-E;F1E<G,N`$YA8VAR:6-H="!N:6-H
M="!M96AR(&?\;'1I9RX`3F%C:')I8VAT96YT>7``365T87(@5V5T=&5R`$UE
M=&%R8FQO8VL@;FEC:'0@=F5R9OQG8F%R+@!-971A<F)L;V-K(&YI8VAT('9E
M<F;\9V)A<BX@1&5T86EL<R!W=7)D96X@9OQR(&1E;B!!9&UI;FES=')A=&]R
M(&UI=&=E;&]G9W0N`$ME:6YE(%9E<F)I;F1U;F<@>G5R($UE=&%R1$(N`$UE
M=&AO9&4`1&EE($UE=&AO9&4@(B5S(B!I<W0@;FEC:'0@9&5F:6YI97)T`$UE
M=&AO9&4@;FEC:'0@9&5F:6YI97)T+B!!=69G97)U9F5N92!-971H;V1E.B`E
M<P!-971R:7-C:`!-97AI:V\`1O9D97)I97)T92!3=&%A=&5N('9O;B!-:6MR
M;VYE<VEE;@!-:71T90!-:6UE='EP`%1I969S='1E;7!E<F%T=7(@9&5R(&QE
M='IT96X@,C0@4W1U;F1E;CH@`%1I969S='1E;7!E<F%T=7(@9&5R(&QE='IT
M96X@-B!3='5N9&5N.B``1&%S(&UI;FEM86QE(%!A<W-W;W)T86QT97(@:7-T
M(&YO8V@@;FEC:'0@86)G96QA=69E;@!3<&EE9V5L;@!697)S8VAI961E;F5S
M`%!%05(M4&%K970@2%144%]297%U97-T(&9E:&QT+@!&96AL96YD92!+;VYF
M:6=U<F%T:6]N+B!3:64@;?QS<V5N(&1I97-E(&IE='IT(&5R>F5U9V5N+"!W
M96YN(%-I92!D:64@06YW96YD=6YG('9E<G=E;F1E;B!M]F-H=&5N+@!&96AL
M96YD92!.86-H<FEC:'1E;BU)1"X`4$5!4BU086ME="!-86EL(&9E:&QT+@!&
M96AL96YD92!3:71Z=6YG<RU)1"X`36\`16UA:6P@36]B:6P`3>3?:6<`Q&YD
M97)U;F=S9&%T=6T`55),(&)E87)B96ET96X`36]D=6QU<P!297!U8FQI:R!-
M;VQD874`36]N86-O`$UO;F=O;&5I`$UO;F%T('5N9"!*86AR`$UO;F%T;&EC
M:`!-;VYT<V5R<F%T`$UO;F1P:&%S96X`365H<B!&96QD97(@:6X@6F5I;&4@
M)60@86QS(&1I92!E<G=A<G1E=&5N("5D(&=E9G5N9&5N+@!-87)O:VMO`-QB
M97)W:65G96YD(&AE:71E<@#<8F5R=VEE9V5N9"!"97?V;&MT`-QB97)W:65G
M96YD($)E=_9L:W0@=6YD(%=I;F1I9P#<8F5R=VEE9V5N9"!3;VYN:6<`3F%C
M:"!U;G1E;@!.86-H(&QI;FMS`$YA8V@@<F5C:'1S`$YA8V@@;V)E;@!.86-H
M('5N=&5N`$YA8V@@;V)E;@!-;W-A;6)I:P!!=7-W86AL;&ES=&4@:6X@;65H
M<F5R96X@16)E;F5N`$UU;'1I;6%P+55++4MA<G1E`$UE:')F86-H875S=V%H
M;`!-96EN($MO;G1O`$UE:6X@2V]N=&\`365I;B!0;W)T86P`365I;B!0;W)T
M86QL87EO=70`0G5R;6$`3D5)3BP@:6-H('-T:6UM92!.24-(5"!Z=0!.86UE
M`$YA;6EB:6$`3F%U<G4`3F5P86P`3FEE9&5R;&%N9&4`3FEE9&5R;.1N9&ES
M8VAE($%N=&EL;&5N`$YE='-C87!E+4)A<VES+5523`!.971S8V%P92U#02U3
M<&5R<G5N9W,M55),`$YE='-C87!E+4-!+5)I8VAT;&EN:65N+5523`!.971S
M8V%P92U:971I9FEK871S97)N975E<G5N9W,M55),`$YE='-C87!E+5-P97)R
M=6YG<RU54DP`3F5T<V-A<&4M4U-,+5-E<G9E<FYA;64`3F5T<V-A<&4M2V]M
M;65N=&%R`$YE='-C87!E+5IE<G1I9FEK871T>7``3F5T>G=E<FL`3FEE`$YE
M=6MA;&5D;VYI96X`3F5U92!+871E9V]R:64`3F5U;6]N9`!.975E<B!"96YU
M='IE<FYA;64@*&]P=&EO;F%L*0!.975S965L86YD`$YE=65S(%!A<W-W;W)T
M`$1A<R!N975E(%!A<W-W;W)D('=I<F0@86T@)7@@86)L875F96XN`$1I92!N
M975E;B!087-S=_9R=&5R('-T:6UM96X@;FEC:'0@_&)E<F5I;BX`3F5U97,@
M1F5N<W1E<B`H7V)L86YK*0!.86-H<FEC:'1E;@!.97=S9W)U<'!E;@!796ET
M97(`3N1C:'-T92`T(%!H87-E;@!.Y&-H<W1E($5I;G-T96QL=6YG96X`5V5I
M=&5R/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.86-H=',`3FEU90!.96EN
M`$ME:6YE($MO;F9I9W5R871I;VYS9&%T96X@=F5R9OQG8F%R+"!U;2!5;G1E
M<G-C:&EE9&4@86YZ=7IE:6=E;BX`2V5I;F4@4W1R871E9VEE('IU;2!%<G-T
M96QL96X@=F]N($E33RU!8F)I;&1E<FX@=F5R9OQG8F%R+@!+96EN92!"871C
M:"U6;W)L86=E+@!%<R!E>&ES=&EE<G0@:V5I;B!";&]C:R!A;B!D97(@86YG
M96=E8F5N96X@4&]S:71I;VX`2V5I;B!+86QE;F1E<FYA;64@9OQR(&1I92!-
M0T%,+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;F4@Q&YD97)U
M;F=E;BX`56YT97)H86QB(&1I97-E<B!%8F5N92!K]FYN96X@:V5I;F4@=V5I
M=&5R96X@56YT97)R96-H=&4@:&EN>G5G96;\9W0@=V5R9&5N+@!&_'(@)7,@
M=W5R9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E
M9V5B96XN`$;\<B!D96X@1E10+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+
M;VYF:6=U<F%T:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+@!&_'(@9&5N
M(%-13"U61E,M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I
M;F9O<FUA=&EO;F5N(&%N9V5G96)E;BX`1OQR(&1E;B!344PM1&%T96DM5D93
M+51R96EB97(@=W5R9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I
M;VYE;B!A;F=E9V5B96XN`$ME:6X@2W)E9&ET(&UE:'(@_&)R:6<N`$ME:6X@
M16UP9N1N9V5R(&%N9V5G96)E;BX`2V5I;F4@1&%T96D@:&]C:&=E;&%D96X`
M2V5I;F4@26-O;G,@9V5F=6YD96XN`$5S('=U<F1E(&ME:6X@3W)T(&9E<W1G
M96QE9W0N`$ME:6X@3W)T(&%N9V5G96)E;BX`2V5I;F4@3F%C:')I8VAT(&%N
M9V5G96)E;BX`2V5I;B!.86UE(&%N9V5G96)E;BX`2V5I;F4@3G5M;65R(&%N
M9V5G96)E;BX`2V5I;F4@86YS=/;?:6=E;B!';/QC:W-K96MS90!+96EN(%!A
M<W-W;W)T(&;\<B!D:64@2%144"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B
M96XN`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!)34%0+4%U=&AE;G1I9FEZ:65R
M=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R="!F_'(@9&EE($ME<F)E<F]S
M+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R="!F
M_'(@9&EE($QO9VEN+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I
M;B!087-S=V]R="!F_'(@9&EE(%!!4U-71"U!=71H96YT:69I>FEE<G5N9R!A
M;F=E9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!334(M075T:&5N=&EF
M:7II97)U;F<@86YG96=E8F5N+@!+96EN(%!F860@>G5M($]P96Y34TPM4')O
M9W)A;6T@86YG96=E8F5N+B!$87,@3W!E;E-33"U0<F]G<F%M;2!W:7)D(&)E
M;O9T:6=T+"!U;2!02T-3+3$R+41A=&5N('9E<F%R8F5I=&5N('IU(&OV;FYE
M;BX`2V5I;F4@875S<W1E:&5N9&5N(%)E9VES=')I97)U;F=E;BX`2V5I;B!3
M<&5I8VAE<G!L871Z+4MO;G1I;F=E;G0@9F5S=&=E;&5G="X`2V5I;F4@4F%H
M;65N`$ME:6X@5')E;FYZ96EC:&5N(&%N9V5G96)E;BX`2V5I;F4@4V5I=&5N
M`$1A=&5I(&YI8VAT(&=E9G5N9&5N`$ME:6YE('1E;7!O<N1R97,@5F5R>F5I
M8VAN:7,@9OQR(&1E;B!#86-H92!G969U;F1E;BX`2V5I;B!"96YU='IE<FYA
M;64@=6YD+V]D97(@4&%S<W=O<G0@86YG96)E;BX`17,@=W5R9&5N(&ME:6YE
M(&?\;'1I9V5N(%A-3"U$871E;B!Z=7+\8VMG96=E8F5N`$ME:6YE(%=E<G1E
M`$ME:6YE(%9E<G-I;VYS;G5M;65R(&EN(&1E<B!/<FEG:6YA;&MO;F9I9W5R
M871I;VX@9V5F=6YD96XN($5R;F5U97)N(%-I92!):')E($MO;F9I9W5R871I
M;VXN`$ME:6YE(%9E<G-I;VYS;G5M;65R(&EN($EH<F5R($MO;F9I9W5R871I
M;VX@9V5F=6YD96XN($5R;F5U97)N(%-I92!):')E($MO;F9I9W5R871I;VXN
M`$ME:6YE`$ME:6YS("A3=&%N9&%R9"!B96YU='IE;BD`3F]R9&ES8V@@*$E3
M3RTX.#4Y+3$P*0!.;W)F;VQK:6YS96P`3O9R9&QI8VAE($AE;6ES<&AE<F4`
M3O9R9&QI8VAE($UA<FEA;F5N`$YO<G=E9V5N`$?\;'1I9R!B:7,`1_QL=&EG
M(&%B`$ME:6X@5F5R>F5I8VAN:7,`3FEC:'0@:6UP;&5M96YT:65R="X`3FEC
M:'0@9F5S=&=E;&5G=`!.:6-H="!U;G1E<G-T_'1Z="X`3F]T:7IE;@!.:6-H
M=',@86YZ=7IE:6=E;BP@8FET=&4@>G5R_&-K9V5H96XN`$YO=F5M8F5R`%IA
M:&P`06YZ86AL(&1E<B!:96EC:&5N`$%N>F%H;"!D97(@4W!A;'1E;@!!;GIA
M:&P@9&5R(%IE:6QE;@!+96EN92!.=6UM97)N(&;\<B!D:64@5F5R=&5I;&5R
M;&ES=&4@86YG96=E8F5N+@!/2P!/8FIE:W0`3V)J96MT97)S=&5L;&5R`$]K
M=&%L>F%H;`!/:W1O8F5R`$9I;'1E<B!F_'(@86YS=/;?:6=E($EN:&%L=&4`
M0OQR;P!):'(@;F5U97,@4&%S<W=O<G0@;75S<R!S:6-H('9O;B!):')E;2!A
M;'1E;B!U;G1E<G-C:&5I9&5N+@!!;'1E<R!087-S=V]R=`!&86QS8VAE<R!A
M;'1E<R!087-S=V]R="X`3VUA;@!.=7(@24U!4"U397)V97(@=6YT97)S=/QT
M>F5N(&=E;65I;G-A;64@3W)D;F5R+@!.=7(@86YS=/;?:6=E($=L_&-K<VME
M:W-E`$YU<B!E:6YE($5M86EL+4%D<F5S<V4@97)L875B="X`3G5R(&1E<B!"
M97-I='IE<B!O9&5R(&1E<B!3>7-T96UA9&UI;FES=')A=&]R(&MA;FX@9&5N
M($)E<VET>F5R(&]D97(@9&EE($)E<VET>F5R<F5C:'1E(.1N9&5R;@!);B!N
M975E;2!&96YS=&5R(/9F9FYE;@!/<&5N4U-,+49E:&QE<CH@4VEG;FEE<G1E
M(%,O34E-12U$871E;B!K;VYN=&5N(&YI8VAT(&5X=')A:&EE<G0@=V5R9&5N
M+@!$:65S96X@3&EN:R!I;B!E:6YE;2!N975E;2!&96YS=&5R(/9F9FYE;@!"
M971R:65B<WES=&5M`$5I;G-T96QL=6YG96X`16EN<W1E;&QU;F=E;B!F_'(@
M)7,`3G5M;65R:65R=&4@3&ES=&4`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO
M;G-A8G1E:6QU;F<`3W)G86YI<VEE<F5N`$]R:6=I;F%L=F]R;&%G92!D97(@
M06YW96YD=6YG`$]R:6=I;F%L=F]R;&%G92!I;B`E<SH`4V]N<W1I9V4`06YD
M97)E($EN9F]R;6%T:6]N96X`0F5S:71Z97)R96-H=&4`4$%-+4%U=&AE;G1I
M9FEZ:65R=6YG(&ES="!N:6-H="!V97)F_&=B87(N`%!%05(Z.DUA:6PM0F%C
M:V5N9`!$:6=I=&%L92!01U`M56YT97)S8VAR:69T`%!'4"UV97)S8VAL_'-S
M96QT92!$871E;@#69F9E;G1L:6-H97(@4$=0+5-C:&S\<W-E;`!-:70@4$=0
M('5N=&5R>F5I8VAN971E+W9E<G-C:&S\<W-E;'1E($1A=&5N`%!(4"!#;V1E
M`%!(4"!3:&5L;`!6;W)M:71T86=S(&QE:6-H=&5R(%)E9V5N`$YA8VAM:71T
M86=S(%)E9V5N`$YA8VAM:71T86=S(%-C:&%U97(`3F%C:&UI='1A9W,@4V-H
M;F5E`$YA8VAM:71T86=S(%-C:&YE97-C:&%U97(`3F%C:&UI='1A9W,@4V]N
M;F4`3F%C:&UI='1A9W,@1V5W:71T97(`1&EE(%!/4TE8+45R=V5I=&5R=6YG
M(&9E:&QT`%]02%`@4VAE;&P`26YN96YA8G-T86YD`%!A:VES=&%N`%!A;&%U
M`$)E<V5T>G1E(%!A;.1S=&EN96YS:7-C:&4@1V5B:65T90!086YA;6$`4&%P
M=6$M3F5U9W5I;F5A`%!A<F%G=6%Y`%1E:6QW96ES92!"97?V;&MT`%!A<W-W
M;W)T`%!A<W-W;W)T(&5R9F]L9W)E:6-H(&=EY&YD97)T+@!&86QS8VAE<R!0
M87-S=V]R=`!+96EN(%!A<W-W;W)T(&;\<B!D:64@4D%$2553+4%U=&AE;G1I
M9FEZ:65R=6YG(&%N9V5G96)E;BX`4&%S<W=O<G0@;6ET($)E<W3D=&EG=6YG
M`%!A<W-W;W)T.@!087-S=V]R=#H@`$1I92!087-S=_9R=&5R(&W\<W-E;B!G
M;&5I8V@@<V5I;BX`16EN9OQG96X`5F]N(&1E<B!:=VES8VAE;F%B;&%G92!E
M:6YF_&=E;@!09F%D`$%U<W-T96AE;F1E(%)E9VES=')I97)U;F=E;CH`4&5R
M<V]N96X`4')O>F5N=`!787)T=6YG<V%R8F5I=&5N(&1U<F-H9OQH<F5N`%=A
M<G1U;F=S87)B96ET96X@;F%C:"!D97(@06YM96QD=6YG(&1U<F-H9OQH<F5N
M/P!296-H=&4`4F5C:'0@(B5S(B!W=7)D92!N:6-H="!G96SV<V-H="X`6G5G
M<FEF9B!V97)W96EG97)T`%)E8VAT90!296-H=&5V97)W86QT=6YG`%!E<G/V
M;FQI8VAE($%N9V%B96X`4&5R=0!(875S=&EE<F4`4&AI;&EP<&EN96X`5&5L
M969O;@!&;W1O<P!0:71C86ER;@!0:7AE;`!0;&%T=&AE:71E;@!":71T92!K
M;&EC:V5N(%-I92!I;B!E:6YE(%IE;&QE`$)I='1E(&)E<W3D=&EG96X@4VEE
M+"!D87-S(%-I92!D:65S97,@16QE;65N="!L]G-C:&5N(&WV8VAT96XZ`$)I
M='1E(&)E=.1T:6=E;B!3:64L(&1A<W,@4VEE(&1E;B!,:6YK('9O;B!D:65S
M96T@16QE;65N="!E;G1F97)N96X@;?9C:'1E;BX`0FET=&4@96EN96X@36]N
M870@=6YD(&5I;B!*86AR(&%N9V5B96XN`$)I='1E(&=E8F5N(%-I92!E:6YE
M;B!.86UE;B!F_'(@9&EE(&YE=64@2V%T96=O<FEE(&%N.@!":71T92!E:6YE
M(&?\;'1I9V4@25`M061R97-S92!E:6YG96)E;BX`0FET=&4@9V5B96X@4VEE
M(&5I;B!G_&QT:6=E<R!$871U;2!A;CL@_&)E<G!R_&9E;B!3:64@9&EE(%IA
M:&P@9&5R(%1A9V4@:6X@9&5M($UO;F%T+@!":71T92!E:6YE;B!G_&QT:6=E
M;B!:96ET=V5R="!E:6YG96)E;BX`0FET=&4@9V5B96X@4VEE(&5I;F4@6G5S
M86UM96YF87-S=6YG($EH<F5S(%!R;V)L96US(&%N+@!":71T92!G96)E;B!3
M:64@26AR96X@0F5N=71Z97)N86UE;B!U;F0@26AR(%!A<W-W;W)T(&%N`$)I
M='1E(&QE<V5N(%-I92!S:6-H(&1E;B!F;VQG96YD96X@5&5X="!S;W)G9N1L
M=&EG(&1U<F-H+B!3:64@3=Q34T5.(&1I97-E;B!"961I;F=U;F=E;B!Z=7-T
M:6UM96XL('=E;FX@4VEE(&1I97-E<R!3>7-T96T@8F5N=71Z96X@;?9C:'1E
M;BX`0FET=&4@9&5N(&YE=65N($MA=&5G;W)I96YA;65N(&5I;F=E8F5N.@!0
M;VQE;@!0;VQI=&EK`%5M9G)A9V5N`%!O<G1U9V%L`%!O<VET:6]N:65R=6YG
M(&1I97-E($)I;&1E<P!0;W-I=&EO;FEE<G5N9R!D:65S97(@5&%B96QL90!3
M96YD96X@86X@9&EE<V5N($]R9&YE<B`H;FEC:'0@9'5R8V@@24U!4"D`3FEE
M9&5R<V-H;&%G(&EN(&1E;B!L971Z=&5N("5S(%-T=6YD92AN*3H@`$YI961E
M<G-C:&QA9W,M/&)R("\^=V%H<G-C:&5I;FQI8VAK96ET`%!R969S7VQD87`Z
M($1I92!B96[V=&EG=&4@3$1!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G
M969U;F1E;BX`4')E9G-?<V5S<VEO;CH@1&EE(&)E;O9T:6=T92!397-S:6]N
M+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!,=69T9')U8VL`
M3'5F=&1R=6-K(&%U9B!3965H]FAE.B``3'5F=&1R=6-K.B``5F]R<V-H874`
M16EN92!6;W)S8VAA=2!D97,@0FEL9&5S(&EN(&5I;F5M(&YE=65M($9E;G-T
M97(@86YZ96EG96X`5F]H97)I9V4@16EN<W1E;&QU;F=E;@!$;VMU;65N="!D
M<G5C:V5N`%!R:79A=&5R(%-C:&S\<W-E;`!0<F]B;&5M90!0<F]B;&5M8F5S
M8VAR96EB=6YG`%!R;VIE:W1E`$YA8VAF<F%G971E>'0`UF9F96YT;&EC:&5R
M(%-C:&S\<W-E;`!!;&=O<FET:&UU<R!D97,@]F9F96YT;&EC:&5N(%-C:&S\
M<W-E;',`26YF;W)M871I;VYE;B!Z=6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E
M;`!$87,@]F9F96YT;&EC:&4O<')I=F%T92!38VAL_'-S96QP86%R(&MO;FYT
M92!N:6-H="!E<G-T96QL="!W97)D96XN`%!U97)T;R!2:6-O`$YA8VAR:6-H
M=&5N(&5N9&?\;'1I9R!L]G-C:&5N`$MA=&%R`$%B9G)A9V4`4W!E:6-H97)P
M;&%T>BU+;VYT:6YG96YT`-9F9F5N=&QI8VAE<B!24T$@4V-H;/QS<V5L("@E
M9"!":70I`$%U<W=A:&QK;F]P9@!296=E;@!&<OQH(%)E9V5N`%-PY'1E<B!2
M96=E;@!296=E;G-C:&%U97(`4V-H;F5E<F5G96X`4F5G96X@:6X@4V-H;F5E
M(/QB97)G96AE;F0`1VS\8VMS:V5K<P!697)HY&QT;FES`$QE<V5N`$YA8VAR
M:6-H=&5N(&QE<V5N`"5S('=I<FML:6-H(&SV<V-H96X_($1I97-E<B!6;W)G
M86YG(&MA;FX@;FEC:'0@<OQC:V?D;F=I9R!G96UA8VAT('=E<F1E;BX`1&%T
M96X@9&5S($)E;G5T>F5R<R`E<R!W:7)K;&EC:"!L]G-C:&5N/R!$:65S97(@
M5F]R9V%N9R!K86YN(&YI8VAT('+\8VMGY&YG:6<@9V5M86-H="!W97)D96XN
M`$;\:')T(&QE='IT92!!:W1I;VX@97)N975T(&%U<P!!:W1U86QI<VEE<F4`
M1'EN86UI<V-H92!-96[\96QE;65N=&4@86MT=6%L:7-I97)E;CH`4&]R=&%L
M86YS:6-H="!A:W1U86QI<VEE<F5N.@!296=U;.1R97(@075S9')U8VL`5F5R
M8FEN9'5N9W,M0G)O=W-E<@!!:W1U86QI<VEE<F5N`$)E;65R:W5N9V5N`$5N
M=&9E<FYT92!397)V97(`4V5R=F5R861R97-S92`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`$5N=&9E<FYE;@!";&]C:R!L]G-C:&5N`%-P86QT
M92!L]G-C:&5N`$9O<FUA=&EE<G5N9R!E;G1F97)N96X`4&%A<B!L]G-C:&5N
M`$=E<W!E:6-H97)T97,@4VMR:7!T(&%U<R!D96T@=&5M<&]RY')E;B!697)Z
M96EC:&YI<R!E;G1F97)N96XN`$5N=&9E<FYE`$1I97-E<R!%;&5M96YT(&%U
M<R!D96T@1&]K=6UE;G0@96YT9F5R;F5N`$)E;G5T>F5R(&SV<V-H96X`0F5N
M=71Z97(@;/9S8VAE;CH@)7,`06YF<F%G92!K;VYN=&4@;FEC:'0@8F5A;G1W
M;W)T970@=V5R9&5N+B!:=7+\8VMG96=E8F5N97(@1F5H;&5R8V]D93H@`$1E
M<B!G97?\;G-C:'1E($1I96YS="!K;VYN=&4@;FEC:'0@9V5F=6YD96X@=V5R
M9&5N+@`B)7,B('=U<F1E(&EN(&1E<B!+;VYF:6=U<F%T:6]N(&;\<B`E<R!N
M:6-H="!A;F=E9V5B96XN`"(E<R(@=W5R9&4@:6X@9&5R(%9&4RU+;VYF:6=U
M<F%T:6]N(&YI8VAT(&%N9V5G96)E;BX`(B5S(B!W=7)D92!I;B!D97(@2V]N
M9FEG=7)A=&EO;B!N:6-H="!A;F=E9V5B96XN`$YO='=E;F1I9V5S($9E;&0`
M6G5R_&-K<V5T>F5N`%!A<W-W;W)T('IU<OQC:W-E='IE;@!3971Z96X@4VEE
M($EH<B!087-S=V]R="!Z=7+\8VL`3&5T>G1E($%B9G)A9V4@96EN9OQG96X`
M17)G96)N:7-S90!:=7+\8VL@>G4@16EN<W1E;&QU;F=E;@!.975E<R!087-S
M=V]R="!E<FYE=70@96EN9V5B96X`4NEU;FEO;@!+;VYF:6=U<F%T:6]N('IU
M<OQC:W-E='IE;@!765-)5UE'+45D:71O<B!%:6YS=&5L;'5N9V5N`%+D='-E
M;`!296-H=',`4F5C:'1E(-QB97)S8VAR:69T`%)E8VAT92!797)T90!?6F5I
M;&5N96EG96YS8VAA9G1E;BXN+@!2;VQL90!2=6WD;FEE;@!5;2`Q.#"P(&1R
M96AE;@!.86-H(&QI;FMS(&1R96AE;@!.86-H(')E8VAT<R!D<F5H96X`6F5I
M;&5N96EG96YS8VAA9G1E;@!:96EL96YE:6=E;G-C:&%F=&5N`%IE:6QE;CH`
M4F5G96QN`%)A:&UE;B!Z=VES8VAE;B!A;&QE;B!:96EL96X@=6YD(%-P86QT
M96X`4F%H;65N(&YU<B!Z=VES8VAE;B!3<&%L=&5N`%)A:&UE;B!N=7(@>G=I
M<V-H96X@6F5I;&5N`%-T87)T96X`4G5S<VES8VAE($;V<F1E<F%T:6]N`%)U
M86YD80!3+TU)344@:W)Y=&]G<F%P:&ES8VAE(%5N=&5R<V-H<FEF=`!-:70@
M4R]-24U%('9E<G-C:&S\<W-E;'1E($YA8VAR:6-H=`!305-,+4%U=&AE;G1I
M9FEZ:65R=6YG(&ES="!N:6-H="!V97)F_&=B87(N`%--4RU697)S86YD`%-1
M3"!3:&5L;`!344PM06YW96ES=6YG('IU<B!!8F9R86=E(&1E<B!797)T90!3
M4T@`15)&3TQ'`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI
M='1S('5N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@=6YD($UI
M<75E;&]N`%-A:6YT(%9I;F-E;G0@=6YD(&1I92!'<F5N861I;F5N`$=L96EC
M:&5R(%)A:&UE;B`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@
M=6YD(%!R:6YC:7!E`%-A=&5L;&ET96YP<F]V:61E<@!3875D:2U!<F%B:65N
M`%-P96EC:&5R;@`B)7,B('-P96EC:&5R;@`E<R!S<&5I8VAE<FX`16EN<W1E
M;&QU;F=E;B!S<&5I8VAE<FX`17)Z975G=&4@2V]N9FEG=7)A=&EO;B!A;',@
M4$A0+5-K<FEP="!I;2!T96UP;W+D<F5N(%9E<GIE:6-H;FES($EH<F5S(%-E
M<G9E<G,@<W!E:6-H97)N+@`E<RU+;VYF:6=U<F%T:6]N(&=E<W!E:6-H97)T
M+@!$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T('=U<F1E(&EN("(E<R(@9V5S
M<&5I8VAE<G0N`%9E<F5I;GIE;'1E($=E=VET=&5R`%=I<W-E;G-C:&%F=`!3
M=6-H90!3=6-H;6%S8VAI;F5N`$1A=&5I96X@875S=^1H;&5N`$1A='5M(&%U
M<W?D:&QE;@!(:6YZ=7IU9OQG96YD92!'<G5P<&5N(&%U<W?D:&QE;@!.975E
M;B!"97-I='IE<B!A=7-WY&AL96X`4V5R=F5R(&%U<W?D:&QE;@!(:6YZ=7IU
M9OQG96YD96X@0F5N=71Z97(@875S=^1H;&5N`$%L;&4@875S=^1H;&5N`$QE
M9V5N(%-I92!A;&QE($1A='5M<VMO;7!O;F5N=&5N(&9E<W0N`$]B:F5K="!A
M=7-WY&AL96X`2V5I;F5N(&%U<W?D:&QE;@!7Y&AL96X@4VEE(&1I92!B96[V
M=&EG=&5N(%IE:6-H96X@875S(&1E;B!J97=E:6QI9V5N($9E;&1E<FX@875S
M+B!$86YN(&OV;FYE;B!3:64@9&EE<V4@875S(&1E;2!497AT9F5L9"!K;W!I
M97)E;B!U;F0@:6X@26AR92!.86-H<FEC:'0@96EN9OQG96XN`%?D:&QE;B!3
M:64@9&%S($1A='5M<W1R96YN>F5I8VAE;CH`5^1H;&5N(%-I92!D87,@1&%T
M=6US9F]R;6%T.@!7Y&AL96X@4VEE(&1I92!)9&5N=&ETY'0L(&1I92!3:64@
MY&YD97)N(&WV8VAT96XZ`%?D:&QE;B!3:64@9&%S(%IE:71T<F5N;GIE:6-H
M96XZ`%?D:&QE;B!3:64@9&%S(%IE:71F;W)M870Z`%?D:&QE;B!3:64@>G=E
M:2!Z=7-A;6UE;F=E:/9R:6=E($9E;&1E<B!A=7,N`%?D:&QE;B!3:64@96EN
M($9A<F)S8VAE;6$N`%?D:&QE;B!3:64@26AR92!B979O<GIU9W1E(%-P<F%C
M:&4Z`%!R;V)L96UB97)I8VAT(&%B<V-H:6-K96X`4TU3('9E<G-C:&EC:V5N
M`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I96X@=6YD($UO;G1E
M;F5G<F\`4V5R:65N;G5M;65R`%-E<G9E<F1A=&5N('5N9_QL=&EG(&]D97(@
M;FEC:'0@=F5R9OQG8F%R+@!397-S<VEO;G9E<G=A;'1U;F<`4V5S<VEO;BU)
M1"!A8F=E;&%U9F5N+@!3:71Z=6YG96X`075S=V%H;"U3871Z`$QE9V5N(%-I
M92!D:64@16EN<W1E;&QU;F=E;B!F97-T+"!D:64@97,@26AN96X@97)L875B
M96X@26AR(%!A<W-W;W)T('IU<OQC:WIU<V5T>F5N+"!F86QL<R!S:64@97,@
M96EN;6%L('9E<F=E<W-E;B!S;VQL=&5N+@!,96=E;B!3:64@96YT9F5R;G1E
M(%-E<G9E<B!F97-T+"!A=68@9&EE(%-I92!V;VX@26AR96T@4&]R=&%L(&%U
M<R!Z=6=R96EF96X@;?9C:'1E;BX`5^1H;&5N(%-I92!):')E(&)E=F]R>G5G
M=&4@4W!R86-H92P@6F5I='IO;F4@=6YD($1A='5M<V5I;G-T96QL=6YG96XN
M`$QE9V5N(%-I92!D87,@9&EE(%-T87)T86YW96YD=6YG+"!D87,@1F%R8G-C
M:&5M82P@9&EE(%-E:71E;F%K='5A;&ES:65R=6YG('5N9"!A;F1E<F4@06YZ
M96EG965I;G-T96QL=6YG96X@9F5S="X`2V]N9FEG=7)A=&EO;@!!:W1U86QI
M<VEE<G5N9W-S:W)I<'1E('-I;F0@=F5R9OQG8F%R`$UE:')E<F4@<&%S<V5N
M9&4@3W)T92!M:70@9&EE<V5M(%!A<F%M971E<CH@`%-E>6-H96QL96X`16EN
M:V%U9@!+=7)Z92!:=7-A;6UE;F9A<W-U;F<`4V]L;&5N(%1A<W1E;FMO;6)I
M;F%T:6]N96X@9OQR(&1I92!M96ES=&5N($QI;FMS(&%K=&EV:65R="!W97)D
M96X_`%IE:6=E;@!5;G1E<G-C:&EE9&4@>G=I<V-H96X@9&5R(&%K='5E;&QE
M;B!U;F0@9&5R(&=E<F%D92!E<GIE=6=T96X@2V]N9FEG=7)A=&EO;B!A;GIE
M:6=E;BX`06YZ96EG96XL('=A;FX@9&EE(&QE='IT92!!;FUE;&1U;F<@97)F
M;VQG="!I<W0_`$5R:&%L=&5N(&1E<R!/<FEG:6YA;',@97)M]F=L:6-H96X`
M075S=^1H;&5R(&%N>F5I9V5N`%=E<FMZ975G;&5I<W1E(&;\<B!486)E;&QE
M;B!A;GIE:6=E;C\`1&%S("5S+4UE;OP@875F(&1E<B!L:6YK96X@4V5I=&4@
M86YZ96EG96X_`$1I86QO9R!F_'(@5&%B96QL96YZ96QL96YE:6=E;G-C:&%F
M=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YE:6=E;G-C:&%F=&5N
M(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B96QL96YZ96EL96YE:6=E;G-C:&%F
M=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@0FEL9&5I9V5N<V-H869T96X@86YZ
M96EG96X`2&]C:&QA9&5N(&5R;?9G;&EC:&5N`%-C:&%U97(`1G+\:"!38VAA
M=65R`%-PY'1E<B!38VAA=65R`%-C:&%U97(@:6X@9&5R(%5M9V5B=6YG`%9E
M<FML96EN97)N`%9E<FML96EN97)N(&]D97(@=F5R<V-H:65B96X@4VEE(&5R
M<W0@9&EE(&)E;F%C:&)A<G1E;B!";/9C:V4`4VEE<G)A($QE;VYE`%)E9VES
M=')I97)E;@!3:6=N871U<@!3:6=N871U<F%L9V]R:71H;75S`%-I;F=A<'5R
M`$=R]M]E`%=A<G1U;F=S87)B96ET96X@_&)E<G-P<FEN9V5N`%-L;W=A:V5I
M`%-L;W=E;FEE;@!38VAN964`4V-H;F5E<V-H875E<@!38VAN965S8VAA=65R
M`$9R_&@@4V-H;F5E<V-H875E<@!3<.1T97(@4V-H;F5E<V-H875E<@!38VAN
M965H]FAE.B``4V-H;F5E;65N9V4@86QS(%=A<W-E<CH@`%-O;&]M;VYI;G-E
M;&X`4V]M86QI96X`3&EE9&5R("8@1V5D:6-H=&4`075S=V%H;"!D97(@4V]R
M=&EE<G)E:6AE;F9O;&=E`%5R<W!R=6YG<V%D<F5S<V4`4_QD869R:6MA`%/\
M9&5U<F]PY&ES8V@@*$E33RTX.#4Y+3,I`%/\9&=E;W)G:65N('5N9"!D:64@
M4_QD;&EC:&5N(%-A;F1W:6-H:6YS96QN`%/\9&QI8VAE($AE;6ES<&AE<F4`
M06)S=&%N9"!Z=VES8VAE;B!A=69E:6YA;F1E<B!F;VQG96YD96X@6F5L;&5N
M`$%B<W1A;F0@>G=I<V-H96X@26YH86QT('5N9"!286AM96X@=F]N(%IE;&QE
M;@!!8G-T86YD:&%L=&5R`$%B<W1A;F0`06)S=.1N9&4`4W!A;FEE;@!3<&%M
M`%-O;F1E<GIE:6-H96XM16EN9V%B90!:96QL92!T96EL96X`4W!A;'1E('1E
M:6QE;@!:96EL92!T96EL96X`4W!O<G0`4W)I($QA;FMA`%-T86YD87)D`%-T
M87(@5')E:P!3=&%R=&IA:'(`0G5N9&5S<W1A870@;V1E<B!0<F]V:6YZ`%-T
M871U<P!3<&5I8VAE<F9O<FUA=`!3=')AWV4`1'5R8VAG97-T<FEC:&5N`%IE
M:6-H96YL:7-T90!$;VUA:6X@875S(&1E<B!!9')E<W-E(&5N=&9E<FYE;@!3
M=&EL(%M#4U-=`%-O`%5N=&5R=F5R>F5I8VAN:7,@(B5S(B!N:6-H="!G969U
M;F1E;BX`0F5T<F5F9@!!8G-C:&EC:V5N`$1I92!296=I<W1R:65R=6YG<V%N
M9G)A9V4@9OQR("(E<R(@=W5R9&4@86)G97-C:&EC:W0N(%-I92!K]FYN96X@
M<VEC:"!N;V-H(&YI8VAT(&%N;65L9&5N+"!S;VQA;F=E(&1I92!!;F9R86=E
M(&YO8V@@;FEC:'0@8F5S=.1T:6=T('=U<F1E+@!4:65F9V5S=&5L;'0`17)F
M;VQG`"(E<R(@=W5R9&4@97)F;VQG<F5I8V@@:&EN>G5G96;\9W0N`$1A=&5N
M(&1E<R!"96YU='IE<G,@(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H
M="X`(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="X`(B5S(B!W=7)D
M92!E<F9O;&=R96EC:"!G96SV<V-H="X`2V]N9FEG=7)A=&EO;B!E<F9O;&=R
M96EC:"!Z=7+\8VMG97-E='IT+B!396ET92!N974@;&%D96XL('5M(&1I92#$
M;F1E<G5N9V5N(&%N>G5Z96EG96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO
M;B!E<F9O;&=R96EC:"!G97-P96EC:&5R="X`0F%C:W5P(&1E<B!+;VYF:6=U
M<F%T:6]N("5S(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+@`B)7,B('=U<F1E
M(&5R9F]L9W)E:6-H(&%K='5A;&ES:65R=``E<R!W=7)D92!E<F9O;&=R96EC
M:"!G97-P96EC:&5R=`!3=61A;@!:=7-A;6UE;F9A<W-U;F<`4V]N;F5N875F
M9V%N9P!3;VYN96YU;G1E<F=A;F<`4V]N;FEG`%-O;FYE;F%U9F=A;F<`4V]N
M;F5N875F+W5N=&5R9V%N9P!3;VYN96YA=69G86YG.B``4V]N;F5N=6YT97)G
M86YG`%-O;FYE;G5N=&5R9V%N9SH@`$AO8VAG97-T96QL=`!3=7!P;W)T`%-U
M<FEN86T`3F%C:&YA;64`4W9A;&)A<F0@=6YD($IA;B!-87EE;@!3=V%S:6QA
M;F0`4V-H=V5D96X`4V-H=V5I>@!3>6YC:')O;FEZ871I;VYS;&]G(&=E;/9S
M8VAT`%-Y;F--3`!&;W)M871F96AL97(@:6X@4W5C:&)E9W)I9F9E;@!!<F%B
M:7-C:&4@4F5P=6)L:6L@4WER:65N`$=E=VET=&5R`$=E=VET=&5R('5N9"!7
M:6YD:6<`1V5W:71T97(`1G+\:"!'97=I='1E<@!44U8M1&%T96D`5&%B96QL
M96YE:6=E;G-C:&%F=&5N`%1A8F5L;&4`5&%B96QL96YE:6=E;G-C:&%F=&5N
M`%1A:7=A;@!486EW86XL(&-H:6YE<VES8VAE(%!R;W9I;GH`5&%D<V-H:6MI
M<W1A;@!697)E:6YI9W1E(%)E<'5B;&EK(%1A;G-A;FEA`%II96PZ`$%U9F=A
M8F5N`%1E;&5F;VYN=6UM97(`5&5M<&5R871U<B!D97(@;&5T>G1E;B!3='5N
M9&4Z(`!496UP97)A='5R`%1E;7!E<F%T=7(Z(`!496UP97)A='5R/&)R("\^
M*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<P!6;W)L86=E("(E<R(@;FEC:'0@
M9V5F=6YD96XN`%9O<FQA9V5N=F5R=V%L='5N9P!497AT`$YU<B!497AT`$%U
M<W)I8VAT=6YG`%1E>'0@3V)E;@!$;P!4:&%I;.1N9&ES8V@@*%1)4RTV,C`I
M`%1H86EL86YD`$1I92!&5%`M17AT96YS:6]N(&ES="!N:6-H="!V97)F_&=B
M87(N`$1I92!#:')O;FEK('-T96AT(&YI8VAT('IU<B!697)F_&=U;F<N`$1I
M92!(;W)D92]+;VQA8B!);G1E9W)A=&EO;G-F=6YK=&EO;F5N('5N=&5R<W3\
M='IE;B`B)7,B(&YI8VAT`$1I92!)35-0+4QO9V1A=&5I(&MO;FYT92!N:6-H
M="!E<G-T96QL="!W97)D96XN`$1I92!-86EN=&5N86YC93HZ($ML87-S92!K
M;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96X`1&%S($5I;G-T96QL=6YG96XM
M1F5N<W1E<B!I<W0@9V5S8VAL;W-S96X@=V]R9&5N+B!!8F)R=6-H+@!$97(@
M061M:6YI<W1R871O<B!M=7-S(&5I;B!P97)M86YE;G1E<R!296-H=&4M0F%C
M:V5N9"!E:6YR:6-H=&5N+"!W96YN(%-I92!D:64@4F5C:'1E=F5R=V%L='5N
M9R!N=71Z96X@;?9C:'1E;BX`3G5R('5N=&5N`$1I92!)1"U.=6UM97(@9&5S
M($MO;G1A:W1S('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D97(@
M:V]N;G1E(&EN(&1E<B!$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@=V5R9&5N
M+@!$97(@2V]N=&%K="!W=7)D92!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B
M=6-H(&AI;GIU9V5F_&=T+@!$97(@4$=0+5-I9VYA='5R8FQO8VL@=VER9"!B
M96[V=&EG="P@=6T@9&EE('5N=&5R>F5I8VAN971E($YA8VAR:6-H="!Z=2#\
M8F5R<'+\9F5N+@!$:64@240M3G5M;65R(&1E<B!697)T96EL97)L:7-T92!W
M=7)D92!N:6-H="!A;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92!I;B!D
M97(@1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`1&EE(%9E<G1E
M:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5G96)E;BX`1&EE(%9E<G-C:&S\
M<W-E;'5N9W-F=6YK=&EO;F5N(&)E;O9T:6=E;B!E:6YE('-I8VAE<F4@4V5R
M=F5R=F5R8FEN9'5N9RX`1&EE($1A=&5I("5S('-O;&QT92!E:6YE;B`E<R!%
M:6YT<F%G(&5N=&AA;'1E;BX`1&EE($1A=&5I("5S('-O;&QT92!E:6YI9V4@
M)7,@16EN='+D9V4@96YT:&%L=&5N+@!$:64@1&%T96D@:V%N;B!N:6-H="!A
M=68@<VEC:"!S96QB<W0@:V]P:65R="!W97)D96XN`$1I92!$871E:2!E;G1H
M:65L="!K96EN92!$871E;BX`2&EE<B!S:6YD(&1I92!+;W!F96EN='+D9V4@
M9OQR(&1I97-E(&UE<W-A9V4O<F9C.#(R($YA8VAR:6-H="X`1&5R(%9O;&QB
M:6QD;6]D=7,@=F5R=7)S86-H="!A=68@1W)U;F0@=F]N($9E:&QE<FX@:6T@
M26YT97)N970@17AP;&]R97(@8F5K86YN=&5R;6'?96X@4')O8FQE;64@;6ET
M(&1I97-E;2!"<F]W<V5R+"!D:64@=VER(&YI8VAT('5M9V5H96X@:_9N;F5N
M+B!5;G1E<B!5;7-TY&YD96X@97)H86QT96X@4VEE(&5I;F4@9F5H;&5R:&%F
M=&4@06YZ96EG92P@9F5H;&5N($5D:71O<F9U;FMT:6]N96XL(&]D97(@9&5R
M($)R;W=S97(@<W3\<GIT(&%B+B!!=68@96EN96T@5VEN9&]W(#EX(%-Y<W1E
M;2!W97)D96X@4VEE('9E<FUU=&QI8V@@96EN92`G06QL9V5M96EN92!38VAU
M='IV97)L971Z=6YG)R!E<FAA;'1E;B!U;F0@;?QS<V5N(&1E;B!296-H;F5R
M(&YE=2!S=&%R=&5N+EQN7&Y3:64@=W5R9&5N(&=E=V%R;G0N($)I='1E(&1R
M_&-K96X@4VEE(&%U9B!/2RP@=V5N;B!3:64@;F]C:"!I;6UE<B!D96X@5F]L
M;&)I;&1M;V1U<R!V97)W96YD96X@;?9C:'1E;BX`1&EE($ED96YT:73D="`B
M)7,B('=U<F1E(&=E;/9S8VAT+@!.=7(@;&EN:W,`1&5R($]R="!D97,@1VYU
M4$<M4')O9W)A;6US(&UU<W,@9&5R($-R>7!T7W!G<#HZ($ML87-S92#\8F5R
M9V5B96X@=V5R9&5N+@!$:64@3F%C:')I8VAT(&UI="!D96T@0F5T<F5F9B`B
M)3,D<R(L(&1I92!A;2`E,21S(&%N("4R)',@9V5S8VAI8VMT('=U<F1E+"!I
M<W0@86YG97IE:6=T('=O<F1E;BX*1&%S(&AE:=]T(&YI8VAT+"!D87-S(&1I
M92!.86-H<FEC:'0@875C:"!G96QE<V5N(&]D97(@=F5R<W1A;F1E;B!W=7)D
M92X`3F%M92!F_'(@9&5N($QI;FL@>G5R($YA8VAR:6-H=&5N97)S=&5L;'5N
M9P!$:64@06YZ86AL(&1E<B!&96QD97(@;75S<R!A;',@6F%H;"!A;F=E9V5B
M96X@=V5R9&5N+@!$87,@3W!E;E-33"U-;V1U;"!W:7)D(&;\<B!D:64@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!+;&%S<V4@8F5N]G1I9W0N`$1I92!"96YU='IE
M<F5I;G-T96QL=6YG("(E<R(@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E
M<F1E;BP@=V5I;"!I:')E($1A=&5N(&1I92!M87AI;6%L(&5R;&%U8G1E($=R
M]M]E(/QB97)S8VAR96ET96X`1&%S(%!R;V=R86UM(&;\<B!D:64@06YZ96EG
M92!D:65S97,@1&%T96ET>7!S("@E<RD@=W5R9&4@;FEC:'0@9V5F=6YD96XN
M`$1A<R!!;F;\:')U;F=S>F5I8VAE;B!M=7-S(&%L<R!E:6YZ96QN97,@6F5I
M8VAE;B!A;F=E9V5B96X@=V5R9&5N+@!.=7(@;&EN:W,@=6YD(')E8VAT<P!.
M=7(@<F5C:'1S`$1A<R!4<F5N;GIE:6-H96X@;75S<R!A;',@96EN>F5L;F5S
M(%IE:6-H96X@86YG96=E8F5N('=E<F1E;BX`1&5R(%-E<G9E<B`B)7,B('=U
M<F1E(&5N=&9E<FYT+@!$97(@4V5R=F5R("(E<R(@=W5R9&4@9V5S<&5I8VAE
M<G0N`$1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@=F]N("5S('=U<F1E(&5N
M=&9E<FYT+@!$:64@86YG96=E8F5N92!:96EL92`H)60I(&5X:7-T:65R="!N
M:6-H="X`1&EE('1E;7!O<N1R92!$871E:2`B)7,B(&5X:7-T:65R="!N:6-H
M="X`1&5R(%1E>'0L(&1E;B!3:64@86YG96=E8F5N(&AA8F5N+"!E;G1S<')I
M8VAT(&YI8VAT(&1E;2!497AT(&%U9B!D96T@0FEL9'-C:&ER;2X`3G5R(&]B
M96X@=6YD('5N=&5N`$YU<B!O8F5N`$1I92!H;V-H9V5L861E;F5N($1A=&5N
M('-I;F0@;F%C:"!D96T@;&5T>G1E;B!38VAR:71T('9E<FQO<F5N(&=E9V%N
M9V5N+@!$:64@:&]C:&=E;&%D96YE($1A=&5I(&MO;FYT92!N:6-H="!G97-P
M96EC:&5R="!W97)D96XN`$1E<B!W96%T:&5R+F-O;2!";&]C:R!I<W0@;FEC
M:'0@=F5R9OQG8F%R+@!4:&5M96XM5F5R>F5I8VAN:7,@(B5S(B!N:6-H="!G
M969U;F1E;BX`17,@<VEN9"!K96EN92!%:6YS=&5L;'5N9V5N('9E<F;\9V)A
M<BX`17,@9VEB="!K96EN92!A;GIE:6=B87)E;B!.86-H<FEC:'1E;G1E:6QE
M+@!$:65S97,@1F5L9"!E;G1HY&QT('IU('9I96QE(%IE:6-H96XN(%-I92!H
M86)E;B`E<R!:96EC:&5N(&%N9V5G96)E;CL@4VEE(&W\<W-E;B!W96YI9V5R
M(&%L<R`E<R!A;F=E8F5N+@!"96EM($AI;GIU9OQG96X@=F]N("(E<R(@>G5M
M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ("5S`$)E:6T@
M3/9S8VAE;B!D97(@1&%T96X@=F]N($)E;G5T>F5R("(E<R(@:7-T(&5I;B!0
M<F]B;&5M(&%U9F=E=')E=&5N.B``0F5I;2!,]G-C:&5N('9O;B`B)7,B(&%U
M<R!D96T@4WES=&5M(&ES="!E:6X@4')O8FQE;2!A=69G971R971E;CH@`$)E
M:6T@06MT=6%L:7-I97)E;B!V;VX@(B5S(B!I<W0@96EN(%!R;V)L96T@875F
M9V5T<F5T96XZ("5S`$)E:6T@2&]C:&QA9&5N(&1E<B!$871E:2!I<W0@96EN
M($9E:&QE<B!A=69G971R971E;BX@)7,@=W5R9&4@;FEC:'0@:&]C:&=E;&%D
M96XN`$)E:6T@2&]C:&QA9&5N(&1E<B!$871E:2!I<W0@96EN($9E:&QE<B!A
M=69G971R971E;BX@)7,@=V%R(&=R]M]E<B!A;',@9&EE(&UA>&EM86P@97)L
M875B=&4@1W+VWV4@*"5D($)Y=&5S*2X`0F5I;2!(;V-H;&%D96X@9&5R($1A
M=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W=7)D92!N=7(@
M=&5I;'=E:7-E(&AO8VAG96QA9&5N+@!"96EM($%N>F5I9V5N(&1I97-E<R!.
M86-H<FEC:'1E;G1E:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+@!"
M96EM($EM<&]R=&EE<F5N(&1E<B!+;VYT86MT9&%T96X@:7-T(&5I;B!&96AL
M97(@875F9V5T<F5T96XN`$)E:6T@26UP;W)T:65R96X@9&5R(&E#86QE;F1A
M<B!$871E;B!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`1&%S($MO;F9I
M9W5R871I;VYS+49O<FUU;&%R(&5N=&AI96QT(&5I;F5N($9E:&QE<BX@5FEE
M;&QE:6-H="!H86)E;B!3:64@96EN(%!F;&EC:'1F96QD(&QE97(@9V5L87-S
M96XN`$)E:6T@075S9OQH<F5N(&1E<B!A;F=E9V5B96YE;B!!9')E<W-B=6-H
M9G5N:W1I;VX@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($)I='1E('9E
M<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+@!"96D@9&5R($%K
M='5A;&ES:65R=6YG(&1E<B!+;VYT86MT9&5T86EL<R!I<W0@96EN($9E:&QE
M<B!A=69G971R971E;BX@0FET=&4@=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@
M;F]C:"!E:6YM86PN`$)E:2!D97(@06MT=6%L:7-I97)U;F<@9&5R(%9E<G1E
M:6QE<FQI<W1E(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92!V
M97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`1&EE<V5R($E-
M05`M4V5R=F5R('5N=&5R<W3\='IT(&ME:6YE(&=E;65I;G-A;65N($]R9&YE
M<BX`1&EE<R!S8VAE:6YT(&ME:6X@9_QL=&EG97,@4D%2+4%R8VAI=B!Z=2!S
M96EN+@!$:65S('-C:&5I;G0@:V5I;B!G_&QT:6=E<R!:25`M07)C:&EV('IU
M('-E:6XN`$1I97,@<V-H96EN="!K96EN92!G_&QT:6=E($MA<G1E;FYU;6UE
M<B!Z=2!S96EN+@!$:65S97(@5')E:6)E<B!E<FQA=6)T(&1A<R!697)S8VAI
M8VME;B!V;VX@3F%C:')I8VAT96X@9'5R8V@@9&5N($-L:6-K871E;&PM1V%T
M97=A>2`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!M:70@2&EL9F4@9&5R($A4
M5%`M05!)+@!$:65S97(@5')E:6)E<B!E<FQA=6)T(&1A<R!697)S8VAI8VME
M;B!V;VX@3F%C:')I8VAT96X@9'5R8V@@9&5N(%=)3BU'871E=V%Y("AH='1P
M.B\O=VEN<&QC+F-O;2D@;6ET($AI;&9E(&1E<B!(5%10+4%022X`1&EE<V5R
M(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H
M=&5N(&1U<F-H(&1E;B!S;7,R;6%I;"U'871E=V%Y("AH='1P.B\O<VUS,FUA
M:6PN8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)+@!$:65S97(@5')E:6)E
M<B!E<FQA=6)T(&1A<R!697)S8VAI8VME;B!V;VX@3F%C:')I8VAT96X@<&5R
M(%--5%`@9'5R8V@@9&5N(%9O9&%F;VYE+4ET86QI96XM1V%T97=A>2!A=7-S
M8VAL:67?;&EC:"!A;B!6;V1A9F]N92U.=6UM97)N+B!$86;\<B!W:7)D(&5I
M;B!%;6%I;&MO;G1O(&)E:2!6;V1A9F]N92!)=&%L:65N("AH='1P.B\O=W=W
M+C$Y,"YI="D@8F5N]G1I9W0N`$1I97-E<R!&96QD(&ES="!N;W1W96YD:6<N
M`$1I97-E<R!&96QD(&1A<F8@;G5R(&=A;GIE(%IA:&QE;B!E;G1H86QT96XN
M`$1I97-E<R!&96QD(&1A<F8@;G5R(%IA:&QE;B!U;F0@96EN96X@4'5N:W0@
M96YT:&%L=&5N+@!$:65S97,@1F5L9"!D87)F(&YU<B!/:W1A;'IA:&QE;B!E
M;G1H86QT96XN`$1I97-E<R!&96QD(&UU<W,@96EN92!K;VUM82T@;V1E<B!L
M965R>F5I8VAE;F=E=')E;FYT92!,:7-T92!V;VX@9V%N>F5N(%IA:&QE;B!E
M;G1H86QT96X`1&EE<V5S($9E;&0@;75S<R!E:6YE(&?\;'1I9V4@6F%H;"!E
M;G1H86QT96XN`$1I97-E<R!&96QD(&UU<W,@96EN96X@1F%R8G=E<G0@:6T@
M:&5X861E>FEM86QE;B!21T(M1F]R;6%T(&5N=&AA;'1E;BP@>BX@0BX@)R,Q
M,C,T868G+@!$:65S97,@1F]R;75L87(@=W5R9&4@8F5R96ET<R!V97)A<F)E
M:71E="X`1&EE<R!I<W0@)7,N`$1I92!I<W0@96EN($MO;&%B+4=R;W5P=V%R
M92U/8FIE:W0N(%5M(&1I97-E<R!/8FIE:W0@86YZ=7IE:6=E;BP@8F5N]G1I
M9V5N(%-I92!E:6X@16UA:6QP<F]G<F%M;2P@9&%S(&1A<R!+;VQA8BU'<F]U
M<'=A<F4M1F]R;6%T('5N=&5R<W3\='IT+B!%:6YE($QI<W1E('-O;&-H97(@
M4')O9W)A;6UE(&9I;F1E;B!3:64@=6YT97(@)7,`1&EE<V4@3F%C:')I8VAT
M('=U<F1E(&EN(&5I;F5M(%IE:6-H96YS871Z("@E<RD@97)S=&5L;'0L(&1E
M<B!N:6-H="!):')E;2!E:6=E;F5N(&5N='-P<FEC:'0N`$1I97-E(%IA:&P@
M;75S<R`Q(&]D97(@9W+VWV5R('-E:6XN`$1I97-E<B!397)V97(@:V%N;B!:
M25`M('5N9"!'6DE0+41A=&5I;B!N:6-H="!E;G1P86-K96XN`$1I97-E<R!3
M>7-T96T@:7-T('IU<B!:96ET(&1E86MT:79I97)T+@!$:65S97(@5V5R="!M
M=7-S(&5I;F4@6F%H;"!S96EN+@!$:65S97,@1F5N<W1E<B!M=7-S('9O;B!E
M:6YE;2!%:6YS=&5L;'5N9V5N+49E;G-T97(@9V7V9F9N970@=V5R9&5N`$1O
M;FYE<@!4:6-K971S`%IE:70`6F5I=&5R9F%S<W5N9P!:96ET9F]R;6%T`%IE
M:71A=7-W86AL`%1I;6]R+4QE<W1E`%1I=&5L`%1I=&5L("A4;V]L=&EP*3H`
M06X`2&%L=&5N(%-I92!B96EM($ML:6-K96X@4W1R9R!B>G<N("A00RD@0V]M
M;6%N9"`H36%C*2!G961R_&-K="P@=6T@;65H<F5R92!%:6YT<N1G92!A=7-Z
M=7?D:&QE;BX`2&5U=&4`6G4@2%1-3"U1=65L;&-O9&4@=6US8VAA;'1E;@!4
M;V=O`%1O:V5L874`36]R9V5N`%1O;F=A`%IU('9I96QE('5N9_QL=&EG92!!
M;FUE;&1E=F5R<W5C:&4@:6X@9&5N(&QE='IT96X@36EN=71E;BX`3V)E;@#$
M==]E<G-T97(@4F%H;65N("A?=&]P*0#<8F5R<V5T>G5N9V5N`%1R:6YI9&%D
M('5N9"!4;V)A9V\`5V%H<B!O9&5R(&9A;'-C:`!$:0!4=6YE<VEE;@!4_')K
M96D`5/QR:VES8V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<RT@
M=6YD($-A:6-O<VEN<V5L;@!4=79A;'4`26AR92!!=7-W86AL.B``558M26YD
M97@Z(`!(;VUE<&%G90!54DP@26AR97,@4VMR:7!T<R!F_'(@9&5N(%9E<G-A
M;F1S=&%T=7-B97)I8VAT`$%D<F5S<V4Z`%5G86YD80!5:W)A:6YE`$%U9B!D
M87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!Z=6=E9W)I9F9E;B!W
M97)D96XN`$1I92!Z=7/D='IL:6-H96X@0F5N=71Z97)I;F9O<FUA=&EO;F5N
M(&MO;FYT96X@8F5I(&1E<B!296=I<W1R:65R=6YG(&YI8VAT(&AI;GIU9OQG
M="!W97)D96XN`$1I92!:=6=R:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E
M:2`B)7,B(&MO;FYT96X@;FEC:'0@9V7D;F1E<G0@=V5R9&5N+@!$:64@6G5G
M<FEF9G-R96-H=&4@9OQR(&1I92!61E,M1&%T96D@)7,O)7,@:V]N;G1E;B!N
M:6-H="!G9>1N9&5R="!W97)D96XN`$5S(&MA;FX@;FEC:'0@:6X@5F5R>F5I
M8VAN:7,@)7,@9V5W96-H<V5L="!W97)D96XN`$1I92!'<O;?92!V;VX@(B5S
M(B!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!$:64@1W+VWV4@=F]N
M("(E<R\E<R(@:V]N;G1E(&YI8VAT(&)E<W1I;6UT('=E<F1E;BX`5F5R8FEN
M9'5N9R!Z=6T@4U%,(%-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E
M<F1E;BX`4U-,+59E<F)I;F1U;F<@:V]N;G1E(&YI8VAT(&AE<F=E<W1E;&QT
M('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@:V]P:65R="!W
M97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@
M86YG96QE9W0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N
M:6-H="!A;F=E;&5G="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI
M8VAT(&%N9V5L96=T('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B
M(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$QE97)E(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@!$:64@1&%T96X@:V]N
M;G1E;B!N:6-H="!D96MO;7!R:6UI97)T('=E<F1E;BX`(B5S(B!K;VYN=&4@
M;FEC:'0@9V5L]G-C:'0@=V5R9&5N+"!D87,@5F5R>F5I8VAN:7,@:7-T(&YI
M8VAT(&QE97(N`"(E<R(@:V%N;B!N:6-H="!G96SV<V-H="!W97)D96XZ("5S
M+@`E<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+"!D87,@5F5R>F5I
M8VAN:7,@:7-T(&YI8VAT(&QE97(`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN
M=&4@;FEC:'0@<F5K=7)S:78@9V5L]G-C:'0@=V5R9&5N+@!$87,@5D93+59E
M<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1A<R!6
M1E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@
M)7,N`$1I92!61E,M1&%T96D@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@
M=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G96SV<V-H="!W
M97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N+@!$87,@5D93(&MO;FYT92!N:6-H="!R96MU<G-I
M=B!G96SV<V-H="!W97)D96XZ("5S+@!$87,@86MT=65L;&4@5F5R>F5I8VAN
M:7,@:V]N;G1E(&YI8VAT(&)E<W1I;6UT('=E<F1E;BX`1&EE(%IE<G1I9FEK
M871D971A:6QS(&MO;FYT96X@;FEC:'0@875S9V5L97-E;B!W97)D96X`1&5R
M("5S+51R96EB97(@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R9&5N+@!$:64@
M5D93+41A=&5I(&MO;FYT92!N:6-H="!V97)S8VAO8F5N('=E<F1E;BX`1&EE
M(%9&4RU$871E:2`B)7,B(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN
M`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT('IU;2!"97-C:')E:6)E;B!G
M9?9F9FYE="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E
M]F9F;F5T('=E<F1E;BX`1&%S($%R8VAI=B!K;VYN=&4@;FEC:'0@9V7V9F9N
M970@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G96QE<V5N
M('=E<F1E;B`H9FEL97-I>F4H*2!F96AL9V5S8VAL86=E;BDN`$1I92!61E,M
M1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N("AG971&:6QE4VEZ
M92@I(&9E:&QG97-C:&QA9V5N*2X`1&EE($1A=&5I(&MO;FYT92!N:6-H="!G
M96QE<V5N('=E<F1E;CH@`$1A<R!V9G-R;V]T+59E<GIE:6-H;FES(&MO;FYT
M92!N:6-H="!G96QE<V5N('=E<F1E;BX`)7,@:V]N;G1E(&YI8VAT(&YA8V@@
M)7,@=6UB96YA;FYT('=E<F1E;CH@1&%S(%II96QV97)Z96EC:&YI<R!E>&ES
M=&EE<G0@8F5R96ET<P!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H
M="!U;6)E;F%N;G0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT
M92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N.B`E<RX`1&EE(%9&4RU$871E:2`B
M)7,B(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N+@!$:64@5D93+41A
M=&5I("5S+R5S(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N+@!$:64@
M5D93+41A=&5I(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N+@`B;6MI
M<V]F<R(@:V]N;G1E(&YI8VAT(&%U<V=E9OQH<G0@=V5R9&5N+@!$:65S97,@
M5V]R9"U$;VMU;65N="!LY'-S="!S:6-H(&YI8VAT(&%N>F5I9V5N`$1I92!6
M1E,M1&%T96D@(B5S(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N
M+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G97-C:')I96)E;B!W97)D
M96X@*&-O<'DH*2!F96AL9V5S8VAL86=E;BDN`$1I92!61E,M1&%T96X@:V]N
M;G1E;B!N:6-H="!G97-C:')I96)E;B!W97)D96XN`$1I92!61E,M1&%T96D@
M:V]N;G1E(&YI8VAT(&=E<V-H<FEE8F5N('=E<F1E;BP@9&%S(%-P96EC:&5R
M<&QA='HM2V]N=&EN9V5N="!W_')D92#\8F5R<V-H<FET=&5N+@!5;G1E<G-T
M<FEC:&5N`,1N9&5R=6YG96X@<OQC:V?D;F=I9R!M86-H96X`36%C:'0@9&EE
M(&QE='IT92!!:W1I;VX@<OQC:V?D;F=I9P!5;F?\;'1I9V4@4OQC:VUE;&1U
M;F<@=F]M(%-E<G9E<B!B96EM($AE<G-T96QL96X@9&5R(%9E<F)I;F1U;F<Z
M(`!5;F5R=V%R=&5T92!!;G1W;W)T(&1E<R!397)V97)S(&%U9CH@`$YI8VAT
M('IU9V5O<F1N970`56YI8V]D92`H551&+3@I`%9E<F5I;FEG=&4@07)A8FES
M8VAE($5M:7)A=&4`5F5R96EN:6=T97,@2_9N:6=R96EC:`!697)E:6YI9W1E
M(%-T86%T96X`2VQE:6YE<F4@06UE<FEK86YI<V-H92#<8F5R<V5E:6YS96QN
M`$5I;FAE:71E;@!5;F)E:V%N;G0`56YB96MA;FYT92!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+@!5;F)E:V%N;G1E(&-L:6US9VED("A#;&EE;G0@365S
M<V%G92!)1"DN`$5S('=U<F1E(&5I;B!U;F)E:V%N;G1E<B!/<G0@86YG96=E
M8F5N+@!5;F)E:V%N;G1E<B!"96YU='IE<FYA;64@;V1E<B!087-S=V]R="X`
M3&EN:R!V;VT@86MT=65L;&5N($5L96UE;G0@96YT9F5R;F5N`%5N8F5N86YN
M=`!!=7,@4VEC:&5R:&5I='-G<OQN9&5N(&3\<F9E;B!U;F%U=&]R:7-I97)T
M92!3:W)I<'1E(&YI8VAT(&%U<V-H;F5I9&5N+"!K;W!I97)E;B!U;F0@96EN
M9OQG96XN($ML:6-K96X@4VEE(&%U9B!/2RP@=6T@96EN96X@2&EN=V5I<R!A
M=68@;6]Z:6QL82YO<F<@86YG97IE:6=T('IU(&)E:V]M;65N+"!D97(@8F5S
M8VAR96EB="P@=VEE(%-I92!E:6YE;2!3:W)I<'0@9&5N(%IU9W)I9F8@875F
M(&1I92!:=VES8VAE;F%B;&%G92!E<FQA=6)E;B!K]FYN96XN`$9A<F)E('IU
M<OQC:W-E='IE;@!%<G=E:71E<G5N9R!N:6-H="!U;G1E<G-T_'1Z=`!!:W1U
M86QI<VEE<G5N9P`E<R!A:W1U86QI<VEE<F5N`$)E;G5T>F5R(&%K='5A;&ES
M:65R96X`(B5S(B!W=7)D92!A:W1U86QI<VEE<G0N`$%K='5A;&ES:65R=6YG
M<W-K<FEP="!G96SV<V-H="X`2&]C:&QA9&5N`$1I92!+;VYF:6=U<F%T:6]N
M<V1A=&5I96X@86QL97(@06YW96YD=6YG96X@=W5R9&5N(&%U9B!D96X@4V5R
M=F5R(&AO8VAG96QA9&5N+@!'<BX@;&%T96EN:7-C:&4@0G5C:'-T86)E;@!'
M<BX@<O9M:7-C:&4@6F%H;&5N`%5R=6=U87D`06MT=65L;&4@8F5N=71Z96XZ
M("5S`%-33"!B96YU='IE;@!":71T92!A=7-F_&QL96XL('=E;FX@4VEE(&5I
M;F5N(&%N9&5R96X@0F5N=71Z97)N86UE;B]087-S=V]R="!F_'(@9&5N($E-
M4U`M4V5R=F5R(&AA8F5N+@!"96YU='IE<@!"96YU='IE<B`E<R!I<W0@9OQR
M("5S(&YI8VAT(&%U=&]R:7-I97)T+@!"96YU='IE<G9E<G=A;'1U;F<`0F5N
M=71Z97)E:6YS=&5L;'5N9V5N`$)E;G5T>F5R<F5G:7-T<FEE<G5N9P!$:64@
M0F5N=71Z97)R96=I<W1R:65R=6YG('=U<F1E(&%U9B!D:65S96T@4WES=&5M
M(&1E86MT:79I97)T+@!"96YU='IE<FMO;G1O(&YI8VAT(&=E9G5N9&5N`$)E
M;G5T>F5R;F%M90!$97(@0F5N=71Z97)N86UE("(E<R(@97AI<W1I97)T(&)E
M<F5I=',N`$)E;G5T>F5R;F%M93H`0F5N=71Z97)N86UE.B``0F5N=71Z97(@
M9&5S(%-Y<W1E;7,Z`%5S8F5K:7-T86X`1&%S(%9&4RU697)Z96EC:&YI<R!E
M>&ES=&EE<G0@;FEC:'0N`$%B=V5S96YH96ET`%!A<W-E;F1E(&=E9G5N9&5N
M92!/<G1E.B``1_QL=&EG:V5I=`!797)T(&EN($UI;G5T96X@=F]N(&IE='IT
M(&%N+@!$97(@5V5R="!I<W0@_&)E<B!D97(@;6%X:6UA;&5N($SD;F=E('9O
M;B`E<RX`5V5R=&4`5V5R=&4L(&%U<R!D96YE;B!A=7-G97?D:&QT('=E<F1E
M;B!K86YN`%9A;G5A='4`1')E:&5N9`!696YE>G5E;&$`W&)E<G!R_&9U;F<@
M9F5H;&=E<V-H;&%G96X@+2!D:65S92!.86-H<FEC:'0@:_9N;G1E(&UA;FEP
M=6QI97)T('=O<F1E;B!S96EN+@!697)S:6]N`%9E<G-I;VYS:V]N=')O;&QE
M`$%U<W)I8VAT=6YG`%9E<G1I:V%L97(@26YN96YA8G-T86YD`%9E<G1I:V%L
M.@!396AR($AO8V@`5FEE=&YA;0!6:65T;F%M97-I<V-H("A625-#24DI`"5S
M(&%N>F5I9V5N`$5I;F4@97AT97)N92!796)S96ET92!A;GIE:6=E;@!!;GIE
M:6=E;B!A;',@)7,`0G)I=&ES8VAE($IU;F=F97)N:6YS96QN`$%M97)I:V%N
M:7-C:&4@2G5N9V9E<FYI;G-E;&X`4VEC:'0`4VEC:'0Z(`!6;V1A9F]N92!)
M=&%L:65N('!E<B!33510`%=!4DY53D<`5T%23E5.1R$A(2!,UE-#2$5.(%-)
M12!$05,@4TM225!4($U!3E5%3$P@0553("5S+@!724X@_&)E<B!(5%10`%=A
M;&QI<R!U;F0@1G5T=6YA`%=A<FYU;F<`36D`5V5T=&5R=F]R:&5R<V%G90!7
M971T97)D871E;B!V;VX`5V5A=&AE<BYC;VT`5V5B`%=E8G-I=&4`5_9C:&5N
M=&QI8V@`5VEL;&MO;6UE;@!7:6QL:V]M;65N(&)E:2`E<P!7:6QL:V]M;65N
M+"`E<P!797-T975R;W#D:7-C:"`H25-/+3@X-3DM,2D`5V5S=&5U<F]PY&ES
M8V@@*$E33RTX.#4Y+3$U*0!797-T<V%H87)A`%=E;&-H92!!;G=E;F1U;F<@
M<V]L;"`E<R!N86-H(&1E;2!!;FUE;&1E;B!A;F=E>F5I9V5N/P!796QC:&5S
M(%1R96YN>F5I8VAE;B!W:7)D('9E<G=E;F1E=#\`5V5L8VAE($%N9OQH<G5N
M9W-Z96EC:&5N('=E<F1E;B!V97)W96YD970_`%=H97)E:7,M075S=')A;&EA
M+4MA<G1E`%=E;&-H92!0:&%S96X`5V5L8VAE(%!L=6=I;G,@9OQR(&1E;B!7
M65-)5UE'+45D:71O<B!S;VQL96X@86MT:79I97)T('=E<F1E;C\`0G)E:71E
M`$)R96ET92!I;B!#4U,M16EN:&5I=&5N`$)R96ET92!D97,@)7,M365N_',@
M;&EN:W,@*'=I<FMS86T@;F%C:"!D97(@;N1C:'-T96X@06YM96QD=6YG*3H`
M5&%B96QL96YB<F5I=&4`16EN:&5I=`!"<F5I=&4Z`%=I:VD`5VEN9`!&<OQH
M(%=I;F0`5VEN9&=E<V-H=VEN9&EG=&ME:70@:6X@2VYO=&5N`%=I;F0Z`%=I
M;F0Z(`!796ES:&5I=`!7=6YS8VAZ971T96P`07)B96ET`$%D<F5S<V4@9V5S
M8VCD9G1L:6-H`%1E;&5F;VX@9V5S8VCD9G1L:6-H`$9A;'-C:&4@06YZ86AL
M(&%N($9E;&1E<FX@:6X@6F5I;&4@)60N("5D(&5R=V%R=&5T+"`E9"!G969U
M;F1E;BX`1F%L<V-H92!!;GIA:&P@86X@1F5L9&5R;BX@)60@97)W87)T970L
M("5D(&=E9G5N9&5N+@!5;F?\;'1I9V5R($]F9G-E="`E9"!B96EM($QE<V5N
M(&1E<B!61E,M1&%T96DN`%%U97)V97)W96ES90!8-3`Y=C,@1V5N97)E;&QE
M($5I;G-C:'+D;FMU;F<`6#4P.78S($5R=V5I=&5R=&5R(%-C:&S\<W-E;'IW
M96-K`%@U,#EV,R!!;'1E<FYA=&EV97(@3F%M92!D97,@6F5R=&EF:6MA=&EN
M:&%B97)S`%@U,#EV,R!)9&5N=&ETY'0@9&5S(%IE<G1I9FEK871S8VAL_'-S
M96QS`%@U,#EV,R!%<G=E:71E<G5N9V5N`$I*`$I*2DH`66%H;V\A($MA<G1E
M`$KD:')L:6-H`$IE;65N`$IA`$IA+"!I8V@@<W1I;6UE('IU`%-I92!B969I
M;F1E;B!S:6-H(&EM(%1E>'1M;V1U<RX@0F5N=71Z96X@4VEE(&1E;B!;/#Y=
M($MN;W!F+"!U;2!I;B!D96X@5UE325=)1RU-;V1U<R!Z=2!W96-H<V5L;BX`
M4VEE(&3\<F9E;B!N:6-H="!M96AR(&%L<R`E9"!";/9C:V4@97)S=&5L;&5N
M+@!3:64@<VEN9"!N:6-H="!A;F=E;65L9&5T+@!3:64@9/QR9F5N(&1A<R!:
M96EC:&5N("=<)R!N:6-H="!I;B!):')E;2!.86UE;B!V97)W96YD96XN`%-I
M92!H86)E;B!K96EN92!G_&QT:6=E($5M86EL861R97-S92!A;F=E9V5B96XN
M`%-I92!H86)E;B!K96EN92!&96QD97(@875S(&1E;B!I;7!O<G1I97)T96X@
M1&%T96X@9&5N(&5N='-P<F5C:&5N9&5N($9E;&1E<FX@:6X@)7,@>G5G96]R
M9&YE="X`4VEE('=U<F1E;B!A8F=E;65L9&5T+@!3:64@;?QS<V5N(&5I;F4@
M9_QL=&EG92!-;V)I;'1E;&5F;VYN=6UM97(@86YG96)E;BP@;G5R(&%U<R!:
M86AL96X@=6YD(&=G9BX@96EN96T@(BLB(&;\<B!I;G1E<FYA=&EO;F%L92!6
M;W)W86AL96X@8F5S=&5H96YD+@!3:64@;?QS<V5N(&5I;F5N(&?\;'1I9V5N
M(%=E<G0@86YG96=E8F5N+@!3:64@;?QS<V5N(&5I;B!$871A5')E92U"86-K
M96YD(&MO;F9I9W5R:65R96XL('5M(%)E9VES=')I97)U;F=E;B!V97)W96YD
M96X@>G4@:_9N;F5N+@!3:64@;?QS<V5N(&5I;B!61E,M0F%C:V5N9"!K;VYF
M:6=U<FEE<F5N+@!3:64@;?QS<V5N(&1A<R!0<F]B;&5M(&)E<V-H<F5I8F5N
M+"!U;2!D96X@0F5R:6-H="!A8GIU<V-H:6-K96XN`%-I92!M_'-S96X@9&EE
M(%523"!A;F=E8F5N+"!A=68@9&EE(&1I97-E<B!,:6YK('9E<G=E:7-E;B!S
M;VQL`%-I92!M_'-S96X@97)S="!D96X@>G4@96YT9F5R;F5N9&5N(%-E<G9E
M<B!A=7-WY&AL96XN`%-I92!M_'-S96X@96EN96X@0F5N=71Z97)N86UE;B!A
M;F=E8F5N+"!D97-S96X@1&%T96X@9V5L]G-C:'0@=V5R9&5N('-O;&QE;BX`
M4VEE(&W\<W-E;B!E:6YE;B!Z=2!L]G-C:&5N9&5N($)E;G5T>F5R;F%M96X@
M86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE;B!H:6YZ=7IU9OQG96YD96X@0F5N
M=71Z97)N86UE;B!A;F=E8F5N+@!3:64@;?QS<V5N(&1E;B!Z=2!A:W1U86QI
M<VEE<F5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BX`4VEE(&W\<W-E;B!E
M:6YE($%K=&EO;B!A;F=E8F5N+@!3:64@;?QS<V5N(&5I;F5N(&YE=65N($MA
M=&5G;W)I96YA;65N(&%N9V5B96XN`%-I92!M_'-S96X@96EN92!)=&%L:65N
M:7-C:&4@5&5L969O;FYU;6UE<B!A;F=E8F5N`$EH<F4@)7,M4V5S<VEO;B!I
M<W0@86)G96QA=69E;BX@0FET=&4@;65L9&5N(%-I92!S:6-H(&5R;F5U="!A
M;BX`26AR92!%;6%I;"U!9')E<W-E`$EH<F4@5F]N.B!!9')E<W-E.@!):')E
M($%N9V%B96X`26AR92!);G1E<FYE=&%D<F5S<V4@:&%T('-I8V@@9V7D;F1E
M<G0L('-E:70@4VEE(&1I92`E<RU3:71Z=6YG(&)E9V]N;F5N(&AA8F5N+B!:
M=6T@4V-H=71Z($EH<F5R(%-I8VAE<FAE:70@;?QS<V5N(%-I92!S:6-H(&YE
M=2!A;FUE;&1E;BX`26AR($YA;64`26AR($%U=&AE;G1I9FEZ:65R=6YG<W-Y
M<W1E;2!E<FQA=6)T(&ME:6X@2&EN>G5F_&=E;B!V;VX@;F5U96X@0F5N=71Z
M97)N+B!796YN(%-I92!(;W)D92!B96YU='IE;B!M]F-H=&5N+"!U;2!):')E
M($)E;G5T>F5R('IU('9E<G=A;'1E;BP@;?QS<V5N(%-I92!E:6YE;B!A;F1E
M<F5N($%U=&AE;G1I9FEZ:65R=6YG<W1R96EB97(@8F5N=71Z96XN`$EH<B!!
M=71H96YT:69I>FEE<G5N9W-S>7-T96T@97)L875B="!D87,@06YZ96EG96X@
M9&5R($)E;G5T>F5R(&YI8VAT+"!O9&5R(&1I97-E($WV9VQI8VAK96ET('=U
M<F1E(&%U<V=E<V-H86QT970N`$EH<B!"<F]W<V5R(&AA="!S:6-H(&%N<V-H
M96EN96YD(&=EY&YD97)T('-E:70@4VEE(&1I92`E<RU3:71Z=6YG(&)E9V]N
M;F5N(&AA8F5N+B!:=6T@4V-H=71Z($EH<F5R(%-I8VAE<FAE:70@;?QS<V5N
M(%-I92!S:6-H(&YE=2!A;FUE;&1E;BX`26AR($)R;W=S97(@=6YT97)S=/QT
M>G0@9&EE<V4@1G5N:W1I;VX@;FEC:'0N`$EH<B!"<F]W<V5R('5N=&5R<W3\
M='IT(&1I97-E($1R=6-K9G5N:W1I;VX@;FEC:'0N($)I='1E(&1R_&-K96X@
M4VEE(%-T<F<O2V]M;6%N9&\@*R!0('5M('IU(&1R=6-K96XN`$EH<F4@86MT
M=65L;&4@6F5I='IO;F4Z`$EH<F4@4W1A;F1A<F1I9&5N=&ETY'0@=W5R9&4@
M9V7D;F1E<G0N`$EH<F4@4W1A;F1A<F1I9&5N=&ETY'0Z`$EH<B!V;VQL<W3D
M;F1I9V5R($YA;64Z`$EH<B!:=6=A;F<@:7-T(&%B9V5L875F96XN`$EH<B!N
M975E<R!087-S=V]R="!F_'(@)7,@;&%U=&5T.B`E<P!):')E($5I;G-T96QL
M=6YG96X@=W5R9&5N(&;\<B!D:64@1&%U97(@9&EE<V5R(%-I='IU;F<@9V5S
M<&5I8VAE<G0N`$EH<F4@16EN<W1E;&QU;F=E;B!W=7)D96X@9V5S<&5I8VAE
M<G0N`$EH<B!087-S=V]R="!W=7)D92!Z=7+\8VMG97-E='IT`$EH<B!087-S
M=V]R="!W=7)D92!Z=7+\8VMG97-E='IT+B!2=69E;B!3:64@26AR92!%;6%I
M;',@86(@=6YD(&UE;&1E;B!3:64@<VEC:"!M:70@26AR96T@;F5U96X@4&%S
M<W=O<G0@86XN`$EH<B!087-S=V]R="!I<W0@86)G96QA=69E;BX`26AR92!3
M97)V97(Z`$IU9V]S;&%W:65N`%IA:7)E`%-A;6)I80!3:6UB86)W90!::7!P
M>0!;6FET871T97AT('9E<G-T96-K96Y=`%M0<F]B;&5M8F5R:6-H=%T`6UII
M=&%T=&5X="!A;GIE:6=E;B`M`%M::71A='1E>'0@86YZ96EG96X@+2`E<R!:
M96EL96Y=`%M:96EL92`E<R!V;VX@)7-=`%]!9&UI;FES=')A=&EO;@!"95]F
M96AL<WIE:6QE`%]$871A5')E90!:96EL92!?;/9S8VAE;@!?1W)U<'!E;@!?
M2&EL9F4`7T)I;&1E:6=E;G-C:&%F=&5N+BXN`$%N7VUE;&1E;@!!8E]M96QD
M96X`3&EN:R!?8F5A<F)E:71E;BXN+@!?16EN<W1E;&QU;F=E;@!?4F5C:'1E
M`$QI;FL@7V5N=&9E<FYE;BXN+@!?2V]N9FEG=7)A=&EO;@!?5&%B96QL96YE
M:6=E;G-C:&%F=&5N+BXN`%]"96YU='IE<@!!9')E<W-B=6-H`$%D<F5S<V%T
M('5N8F5K86YN=`!+86QE;F1E<@!W:6YD<W1I;&P`075S9V%B961A=&5I(&MO
M;FYT92!N:6-H="!E<G-T96QL="!W97)D96X`16EN9V%B92!K86YN(&YI8VAT
M(&=E]F9F;F5T('=E<F1E;@!K;&EC:V5N(%-I92!H:65R`%5N9_QL=&EG92!"
M96YU='IU;F<@9&5R($MO;6UA;F1O>F5I;&4`2V]N9FEG=7)A=&EO;G-F96AL
M97(`2W)I=&ES8VAE(%-Y<W1E;61A=&5I(&9E:&QT`$1A=&5N9F]R;6%T9F5H
M;&5R`&)E87)B96ET96X`16EN=')A9R!N:6-H="!G969U;F1E;@!F86QL96YD
M`$1A=&5I`&%U<R`E<R`H)7,I(&UI="`E<R`E<P!B]FEG`&@Z`&AH`$AO<W1N
M86UE('5N8F5K86YN=`!S;V9O<G0`26YL:6YE`$5I;BTO075S9V%B969E:&QE
M<@!);G1E<FYE<B!3;V9T=V%R969E:&QE<@!:96EL96Y=`&UK:7-O9G,M1F5H
M;&5R8V]D92`E9"!B96D@9&5R($5R<W1E;&QU;F<@9&5S($E33RU!8F)I;&1E
M<RX`;6T`3F%M90!N:6-H="!I;7!L96UE;G1I97)T`$YO8V@@;FEC:'0@:6UP
M;&5M96YT:65R=`!.;W1I>F)L;V-K`%!R;WIE;G0`6G5G<FEF9B!V97)W96EG
M97)T`%!I>&5L`%)E;6]T969E:&QE<B!I;2!0<F]T;VMO;&P`<W1E:6=E;F0`
M4V5R=FEC92!N:6-H="!V97)F_&=B87(`56YT97)S8VAI961E(&%N>F5I9V5N
M`'-M<S)E;6%I;"#\8F5R($A45%``<W,`9VQE:6-H8FQE:6)E;F0`4WES=&5M
M9F5H;&5R`$%U9F=A8F5N;&ES=&4`5F]R_&)E<F=E:&5N9&5R($9E:&QE<@!G
M96)E;B!3:64@9&%S(%!A<W-W;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@0F5S
M=.1T:6=U;F<@96EN`'5N:69I960`=6YB96YA;FYT`&)E;G5T>F5R9&5F:6YI
M97)T`'9#87)D`&(Z`'=E871H97(N8V]M````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O9&5?1$4O:&5L<"YX;6P`````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-#$P`#$P-#$W,S8R-S<V`#`R,#(W
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA
M+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O9&5?1$4O:&5L<"YX;6PL=B`Q+C4@
M,C`P-"\Q,"\R,B`Q,SHS-SHQ.2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE
M;G1R>2!I9#TB<W5M;6%R>2(@;60U/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B
M-#<T.3)C9&,Q-2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y$:64@
M4&]R=&%L<V5I=&4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@($1I92!0;W)T
M86QS96ET92!E<FQA=6)T(&5I;F4@:W5R>F4@W&)E<G-I8VAT(/QB97(@86QL
M92!):')E('=I8VAT:6=E;@H@("`@("!);F9O<FUA=&EO;F5N+B!3:64@:V%N
M;B!Z=6T@0F5I<W!I96P@86YZ96EG96XL('=I92!V:65L92!N975E($5M86EL
M<R!3:64*("`@("`@:&%B96XL('=E;&-H92!497)M:6YE(&1E;6[D8VAS="!A
M;G-T96AE;BP@=V5L8VAE($%U9F=A8F5N(%-I92!N;V-H('IU"B`@("`@(&5R
M;&5D:6=E;B!H86)E;B!O9&5R(&%U8V@@9&EE(&YE=65S=&5N($YA8VAR:6-H
M=&5N+B!6:65L92!D:65S97(*("`@("`@W&)E<G-I8VAT96X@96YT:&%L=&5N
M('-C:&YE;&QE(%IU9W)I9F9E(&%U9B!HY'5F:6<@8F5N]G1I9W1E($9U;FMT
M:6]N96XL"B`@("`@('=I92!D87,@4V-H<F5I8F5N(&YE=65R($5M86EL<R!O
M9&5R(&1E;2!!;FQE9V5N(&YE=65R($MA;&5N9&5R96EN='+D9V4*("`@("`@
M;V1E<B!!=69G86)E;BX*("`@(#PO<&%R83X*("`@(#QP87)A/@H@("`@("!$
M97(@26YH86QT(&1I97-E<B!0;W)T86QS96ET92!K86YN(/QB97(@9&5N(")!
M;G!A<W-E;B(M3&EN:PH@("`@("!V97+D;F1E<G0@=V5R9&5N+B!3:64@:_9N
M;F5N('IU;2!"96ES<&EE;"!A=7-WY&AL96XL('=E;&-H92#<8F5R<VEC:'1E
M;@H@("`@("!I;B!D:64@4&]R=&%L<V5I=&4@875F9V5N;VUM96X@=V5R9&5N
M('-O;&QE;BP@=6YD(&9E<W1L96=E;BP@:6X@=V5L8VAE<@H@("`@("!296EH
M96YF;VQG92!S:64@86YG97IE:6=T('=E<F1E;BX*("`@(#PO<&%R83X*("`\
M+V5N=')Y/@H*("`\96YT<GD@:60](FYA=F)A<B(@;60U/2)B.&-F,&%E,3EE
M-3=D9F$P8S)B.38R934Q-C<X,F8T-R(@<W1A=&4](G5P=&]D871E(CX*("`@
M(#QT:71L93Y$:64@06YW96YD=6YG<RU.879I9V%T:6]N<VQE:7-T93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@("`@075F(&1E<B!L:6YK96X@4V5I=&4@9&5S
M($9E;G-T97)S(&)E9FEN9&5T('-I8V@@9&EE($YA=FEG871I;VYS;&5I<W1E
M"B`@("`@(&;\<B!D:64@06YW96YD=6YG96XN($ML:6-K96X@4VEE(&%U9B!D
M:64@4WEM8F]L92!O9&5R($YA;65N(&1E<@H@("`@("!!;G=E;F1U;F=E;BP@
M=6T@<V-H;F5L;"!U;F0@96EN9F%C:"!Z=VES8VAE;B!D:65S96X@:&EN+2!U
M;F0*("`@("`@:&5R>G5S8VAA;'1E;BX*("`@(#PO<&%R83X*("`\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U
M<'1O9&%T92(@;60U/2)D9#DU9&8P-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P
M,"(^"B`@("`\=&ET;&4^16EN<W1E;&QU;F=E;CH@06YM96QD96%U9F=A8F5N
M.B!787)T=6YG<V%R8F5I=&5N"B`@("`@(&1U<F-H9OQH<F5N/"]T:71L93X*
M("`@(#QP87)A/@H@("`@("!796YN(%-I92!M]F-H=&5N+"!D87-S(&YA8V@@
M9&5R($%N;65L9'5N9R!787)T=6YG<V%R8F5I=&5N(&1U<F-H9V5F_&AR=`H@
M("`@("!W97)D96XL(&UA<FMI97)E;B!3:64@9&EE<V5S($%U<W=A:&QF96QD
M+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC
M;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB83(Q
M,38R8V1F9C-B,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I=&QE/D5I
M;G-T96QL=6YG96XZ($%N;65L9&5A=69G86)E;CH@5V%R='5N9W-A<F)E:71E
M;B!B97-TY'1I9V5N/"]T:71L93X*("`@(#QP87)A/@H@("`@("!796YN(%-I
M92!A;&QE(%=A<G1U;F=S87)B96ET96X@8F5S=.1T:6=E;B!M]F-H=&5N+"!B
M979O<B!D:65S90H@("`@("!A=7-G96;\:')T('=E<F1E;BP@;6%R:VEE<F5N
M(%-I92!D:65S97,@075S=V%H;&9E;&0N(%=E;FX@4VEE(&1A<R!&96QD"B`@
M("`@(&1E86MT:79I97)T(&QA<W-E;BP@=V5R9&5N(&%L;&4@5V%R='5N9W-A
M<F)E:71E;B!A=71O;6%T:7-C:`H@("`@("!D=7)C:&=E9OQH<G0L(&]H;F4@
M9&%S<R!3:64@8F5I(&1E<B!!;FUE;&1U;F<@9&EE($=E;&5G96YH96ET(&AA
M8F5N+`H@("`@("!D:65S92!A8GIU8G)E8VAE;BX*("`@(#PO<&%R83X*("`\
M+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O96Q?1U(O````````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8R-S<V`#`Q-C8V,``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E
M;%]'4B],0U]-15-304=%4R\`````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`,#(P-#0U`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V5L7T=2+TQ#7TU%4U-!1T53+VAO<F1E+FUO````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,U-S<Q,0`Q,#0Q-S,V,C<W-@`P,C(Q
M,38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MWA($E0`````+!@``'````'0P```/"```S&`````````(@0``)0````F!``!(
M````+X$```X```!X@0``#P```(>!```-````EX$```@```"E@0``"P```*Z!
M```,````NH$```0```#'@0``#````,R!```/````V8$```L```#I@0``$0``
M`/6!```.````!X(``"@````6@@``"````#^"```*````2((``!4```!3@@``
M$@```&F"```+````?((``!0```"(@@``)@```)V"```G````Q((``"8```#L
M@@``#@```!.#```*````(H,``"<````M@P``(````%6#```.````=H,``!<`
M``"%@P``(@```)V#```U````P(,``!$```#V@P``#0````B$```,````%H0`
M``T````CA```&P```#&$```M````380``!T```![A```)````)F$```I````
MOH0``!D```#HA```#P````*%```8````$H4```P````KA0``#@```#B%```.
M````1X4```@```!6A0``(@```%^%```:````@H4``#(```"=A0``.````-"%
M``!4````"88``%$```!>A@``6@```+"&``!7````"X<``#0```!CAP``!0``
M`)B'```1````GH<```@```"PAP``"0```+F'```)````PX<```X```#-AP``
M"````-R'```E````Y8<``"`````+B```$````"R(```/````/8@```H```!-
MB```!P```%B(```#````8(@```\```!DB```%````'2(```)````B8@```T`
M``"3B```$@```*&(```9````M(@``!X```#.B```#P```.V(```*````_8@`
M``\````(B0``"````!B)```D````(8D``!<```!&B0``%````%Z)```6````
M<XD```@```"*B0``3@```).)```M````XHD``!D````0B@``!P```"J*```,
M````,HH``"P````_B@``#@```&R*```.````>XH``!8```"*B@``!0```*&*
M```%````IXH```H```"MB@```P```+B*```7````O(H```H```#4B@``#P``
M`-^*```.````[XH``!@```#^B@``(P```!>+```.````.XL``!0```!*BP``
M%P```%^+```7````=XL``!<```"/BP``$P```*>+```/````NXL``!\```#+
MBP``$0```.N+```1````_8L```\````/C```!@```!^,```+````)HP``!``
M```RC```%0```$.,```5````68P```<```!OC```!0```'>,```.````?8P`
M`!$```",C```#````)Z,```[````JXP``#@```#GC````P```""-```)````
M)(T``#D````NC0``$@```&B-```/````>XT``#D```"+C0``)P```,6-```L
M````[8T``"H````:C@``)0```$6.```)````:XX```H```!UC@``!@```(".
M```5````AXX``!D```"=C@``*0```+>.```D````X8X``!$````&CP``$0``
M`!B/```*````*H\``!`````UCP``%@```$:/```6````78\```0```!TCP``
M)P```'F/```(````H8\```@```"JCP``*0```+./```.````W8\```H```#L
MCP``!````/>/```'````_(\```0````$D```!@````F0```-````$)```!<`
M```>D````P```#:0```3````.I````@```!.D```$````%>0```)````:)``
M``0```!RD```00```'>0```@````N9````8```#:D```%0```.&0```8````
M]Y```"(````0D0``+@```#.1```=````8I$``"$```"`D0``5````**1```I
M````]Y$```<````AD@``%0```"F2```*````/Y(```\```!*D@``#0```%J2
M```/````:)(```T```!XD@``"0```(:2```&````D)(``!,```"7D@``%```
M`*N2```,````P)(```8```#-D@``#P```-22``!4````Y)(```0````YDP``
M#@```#Z3``!$````39,```T```"2DP``$P```*"3```1````M),``!$```#&
MDP``$0```-B3```<````ZI,``"H````'E```$P```#*4```A````1I0```4`
M``!HE```$P```&Z4```2````@I0```H```"5E```#P```*"4```1````L)0`
M``H```#"E```$0```,V4```,````WY0``!````#LE```$0```/V4```%````
M#Y4```P````5E0``$````"*5```%````,Y4```T````YE0``!@```$>5```'
M````3I4```T```!6E0``!P```&25```+````;)4```<```!XE0``"0```("5
M```4````BI4```D```"?E0``"@```*F5```9````M)4``#T```#.E0``'0``
M``R6```=````*I8```P```!(E@``$````%66```2````9I8``!,```!YE@``
M*P```(V6```[````N98``"````#UE@``#@```!:7```V````)9<``!````!<
MEP``&P```&V7```(````B9<```0```"2EP``#@```)>7```>````II<``!L`
M``#%EP``(0```.&7```>`````Y@``!D````BF```'@```#R8```;````6Y@`
M`"X```!WF```)@```*:8```;````S9@``!X```#IF```'`````B9```F````
M)9D``"L```!,F0``,P```'B9```F````K)D``"L```#3F0``.````/^9```=
M````.)H``!4```!6F@``+P```&R:```2````G)H``"````"OF@``*0```-":
M```>````^IH``!(````9FP``H@```"R;```6````SYL``",```#FFP``*```
M``J<```I````,YP``"@```!=G```'P```(:<```5````IIP``"````"\G```
M)0```-V<```H`````YT``"T````LG0``,````%J=``"2````BYT``"$````>
MG@``%@```$">```<````5YX``"8```!TG@``*@```)N>``!!````QIX``$0`
M```(GP``#````$V?```'````6I\```<```!BGP``!@```&J?```-````<9\`
M`!````!_GP``$@```)"?```3````HY\``!(```"WGP``!P```,J?```-````
MTI\```P```#@GP``#@```.V?```/````_)\``!,````,H```#0```""@```H
M````+J````,```!7H```#0```%N@```"````::````4```!LH```!````'*@
M```0````=Z```!8```"(H```!````)^@```-````I*````X```"RH````P``
M`,&@```.````Q:````@```#4H```#P```-V@```(````[:````\```#VH```
M!P````:A```-````#J$``!`````<H0``$P```"VA```3````0:$```L```!5
MH0``$0```&&A```)````<Z$```8```!]H0``#````(2A```1````D:$``!D`
M``"CH0``"P```+VA```-````R:$``"(```#7H0``&P```/JA```T````%J(`
M``H```!+H@``&````%:B```9````;Z(``!8```")H@``+P```*"B```B````
MT*(```T```#SH@``#`````&C```F````#J,``!0````UHP``"P```$JC```B
M````5J,``"\```!YHP``"P```*FC```)````M:,``!D```"_HP``"P```-FC
M```7````Y:,``!<```#]HP``"0```!6D```6````'Z0```\````VI```%@``
M`$:D```.````7:0``!@```!LI```#0```(6D```F````DZ0``$,```"ZI```
M"````/ZD```+````!Z4``"\````3I0``#@```$.E```%````4J4```0```!8
MI0``"@```%VE```*````:*4```\```!SI0``$````(.E```7````E*4``!$`
M``"LI0``%P```+ZE```9````UJ4```\```#PI0``"@````"F```%````"Z8`
M``T````1I@``&P```!^F```7````.Z8```D```!3I@``#@```%VF```-````
M;*8``!(```!ZI@``.````(VF```@````QJ8```,```#GI@``"````.NF```.
M````]*8``'L````#IP``&````'^G```%````F*<``!@```">IP``&0```+>G
M```3````T:<```8```#EIP``!@```.RG```0````\Z<```\````$J```$```
M`!2H```/````):@```L````UJ```#P```$&H```,````4:@```\```!>J```
M!P```&ZH```&````=J@```X```!]J```(````(RH```=````K:@```P```#+
MJ```*````-BH```/`````:D```@````1J0``"````!JI```3````(ZD``!X`
M```WJ0``(0```%:I```@````>*D``!D```"9J0``%P```+.I```E````RZD`
M`!<```#QJ0``0@````FJ```$````3*H```P```!1J@```P```%ZJ```(````
M8JH```H```!KJ@``#````':J```+````@ZH``!````"/J@``#````*"J```3
M````K:H``!0```#!J@``#````-:J```)````XZH```X```#MJ@``"P```/RJ
M```;````"*L```<````DJP``"@```"RK```-````-ZL```D```!%JP``!```
M`$^K```%````5*L```,```!:JP``&````%ZK```*````=ZL```0```""JP``
M)@```(>K```5````KJL```4```#$JP``!P```,JK```,````TJL```@```#?
MJP``"@```.BK```&````\ZL```@```#ZJP```@````.L```&````!JP``!4`
M```-K```#P```".L```1````,ZP``!H```!%K```!````&"L```)````9:P`
M`!````!OK```$0```("L```)````DJP```D```"<K```&@```*:L```(````
MP:P```H```#*K```#@```-6L```"````Y*P```8```#GK```$@```.ZL```4
M`````:T``!T````6K0``$0```#2M```&````1JT``!$```!-K0``$0```%^M
M```)````<:T``!X```![K0``!@```)JM```$````H:T``!$```"FK0``!@``
M`+BM```*````OZT``!$```#*K0``(@```-RM```$````_ZT``"4````$K@``
M!0```"JN```$````,*X```P````UK@``"@```$*N```%````3:X```L```!3
MK@``#````%^N```.````;*X``"````![K@``#P```)RN```2````K*X```L`
M``"_K@``)@```,NN```I````\JX``"0````<KP``)@```$&O```(````:*\`
M``H```!QKP``"0```'RO```@````AJ\``"````"GKP``)@```,BO```%````
M[Z\```H```#UKP``&0````"P```I````&K```!8```!$L```!@```%NP```2
M````8K````H```!UL```#````("P```/````C;```!````"=L```0````*ZP
M``!P````[[```&8```!@L0``#@```,>Q```)````UK$``!(```#@L0``$P``
M`/.Q```,````![(```8````4L@``!@```!NR```.````(K(```\````QL@``
M$@```$&R```0````5+(```H```!EL@``$0```'"R```<````@K(``",```"?
ML@``:@```,.R```/````+K,``!`````^LP``!````$^S```+````5+,``!0`
M``!@LP``#````'6S```,````@K,```\```"/LP``%0```)^S```I````M;,`
M`"H```#?LP``)@````JT```G````,;0``"D```!9M```*@```(.T```9````
MKK0``$(```#(M```$0````NU```2````';4``!,````PM0``%````$2U```/
M````6;4``!8```!IM0``%P```("U```0````F+4``!$```"IM0``-````+NU
M```3````\+4``!(````$M@``-0```!>V```4````3;8```<```!BM@``#```
M`&JV```K````=[8``"````"CM@``%````,2V```1````V;8``!<```#KM@``
M'`````.W```3````(+<``!$````TMP``&@```$:W```>````8;<``!H```"`
MMP``$0```)NW```7````K;<``!0```#%MP``%P```-JW```5````\K<```D`
M```(N```!@```!*X```'````&;@```0````AN```!````":X```'````*[@`
M``X````SN```#````$*X```,````3[@```T```!<N```$````&JX```1````
M>[@``!````"-N```#@```)ZX```1````K;@``"@```"_N```#P```.BX```.
M````^+@```P````'N0``#P```!2Y```*````)+D```@````ON0``"0```#BY
M```K````0KD```0```!NN0``"P```'.Y```.````?[D```<```".N0``#@``
M`):Y```)````I;D```P```"ON0``#0```+RY```.````RKD``!8```#9N0``
M$0```/"Y```#`````KH```8````&N@``&0````VZ```$````)[H```L````L
MN@``"P```#BZ```(````1+H```X```!-N@``!````%RZ```/````8;H``#H`
M``!QN@``!0```*RZ```,````LKH``!X```"_N@``#@```-ZZ```0````[;H`
M``L```#^N@``&@````J[```*````);L```P````PNP``#P```#V[```(````
M3;L```8```!6NP``!P```%V[```+````9;L``%P```!QNP``#0```,Z[```&
M````W+L```D```#CNP``!````.V[```#````\KL``!,```#VNP``$P````J\
M```3````'KP```(````RO```!0```#6\```$````.[P```H```!`O```#0``
M`$N\``!H````6;P```8```#"O```&````,F\```1````XKP```4```#TO```
M!@```/J\```;`````;T``"\````=O0``#P```$V]```3````7;T``!L```!Q
MO0``&````(V]```7````IKT```X```"^O0```P```,V]```4````T;T``!,`
M``#FO0``$````/J]```-````"[X```X````9O@``%@```"B^```'````/[X`
M``4```!'O@``"@```$V^```+````6+X```<```!DO@``40```&R^```0````
MOKX```P```#/O@``#0```-R^```:````ZKX``$H````%OP``!@```%"_```:
M````5[\```8```!ROP``!@```'F_```)````@+\``!@```"*OP``%P```*._
M```&````N[\```T```#"OP``(@```-"_``!7````\[\``!,```!+P```(P``
M`%_````3````@\````(```"7P```"P```)K````(````IL````T```"OP```
M"@```+W````*````R,````X```#3P```!P```.+````3````ZL````L```#^
MP```"0````K!```)````%,$```H````>P0``!P```"G!```)````,<$```<`
M```[P0``&P```$/!```2````7\$```H```!RP0``"0```'W!```0````A\$`
M``H```"8P0``$````*/!```2````M,$```0```#'P0``#````,S!```'````
MV<$```4```#AP0``#````.?!```(````],$```P```#]P0``%`````K"```7
M````'\(``!,````WP@``!````$O"```*````4,(```0```!;P@``"0```&#"
M```*````:L(```P```!UP@```@```(+"```X````A<(``"P```"^P@``$@``
M`.O"```I````_L(``#(````HPP``"@```%O#```V````9L,``"P```"=PP``
M+@```,K#```S````^<,``#P````MQ```.@```&K$```[````I<0``#,```#A
MQ```/@```!7%```X````5,4```\```"-Q0``&````)W%```0````ML4```\`
M``#'Q0``$P```-?%```4````Z\4``!(`````Q@``%````!/&```5````*,8`
M`!,````^Q@``'0```%+&```(````<,8```@```!YQ@``*P```(+&```A````
MKL8``!H```#0Q@``"0```.O&``!%````]<8``$$````[QP``#P```'W'```$
M````C<<``!,```"2QP``$P```*;'```)````NL<```H```#$QP``#P```,_'
M```0````W\<```<```#PQP``#@```/C'```%````!\@```T````-R```!P$`
M`!O(```&````(\D``!L````JR0``!@```$;)```C````3<D```@```!QR0``
M!@```'K)```4````@<D``!$```"6R0``)@```*C)```.````S\D``#@```#>
MR0``!@```!?*```.````'LH``!H````MR@``!0```$C*```'````3LH```X`
M``!6R@``!@```&7*```,````;,H``"D```!YR@``%P```*/*```?````N\H`
M`%P```#;R@``%````#C+```^````3<L``!\```",RP``$````*S+```4````
MO<L```<```#2RP``"P```-K+```.````YLL```P```#URP``#`````+,```3
M````#\P```H````CS```'0```"[,```9````3,P```4```!FS```$0```&S,
M```1````?LP``"0```"0S```%0```+7,```2````R\P```X```#>S```&0``
M`.W,```(````!\T```D````0S0``"@```!K-```'````)<T```@````MS0``
M*P```#;-```2````8LT``"P```!US0``&@```*+-```)````O<T```H```#'
MS0``%0```-+-```0````Z,T```4```#YS0``%````/_-```$````%,X``!``
M```9S@``!@```"K.```'````,<X``!X````YS@``*````%C.```*````@<X`
M`!P```",S@``&@```*G.```/````Q,X``!0```#4S@``!````.G.```%````
M[LX```8```#TS@``!@```/O.```*`````L\``!L````-SP``-````"G/```T
M````7L\``"````"3SP``*0```+3/```@````WL\``$$```#_SP``&@```$'0
M```=````7-```"@```!ZT```'````*/0```<````P-```"D```#=T```*0``
M``?1``!1````,=$``%<```"#T0``+````-O1```B````"-(``!\````KT@``
M&0```$O2```9````9=(``"H```!_T@``*P```*K2```C````UM(``"X```#Z
MT@``-````"G3```-````7M,```@```!LTP``%P```'73```*````C=,```<`
M``"8TP``(0```*#3```-````PM,``!````#0TP``#@```.'3```+````\-,`
M``<```#\TP``$P````34```(````&-0```L````AU```"@```"W4```4````
M.-0``#(```!-U```!0```(#4```7````AM0```\```">U```#@```*[4```%
M````O=0```0```##U```#0```,C4```R````UM0``$4````)U0``%P```$_5
M```>````9]4``!0```"&U0``%0```)O5```%````L=4``!0```"WU0``!P``
M`,S5```C````U-4```X```#XU0``*@````?6```&````,M8```P````YU@``
M#0```$;6```1````5-8``!<```!FU@``"P```'[6```V````BM8```H```#!
MU@``(@```,S6```+````[]8```\```#[U@``"P````O7```@````%]<``"<`
M```XUP``*P```&#7```)````C-<``#(```"6UP``,````,G7```Q````^M<`
M`"T````LV```0````%K8```]````F]@``$(```#9V```/@```!S9```_````
M6]D``$(```";V0``/@```-[9```_````'=H``$(```!=V@``/@```*#:```_
M````W]H``$$````?VP``/0```&';```^````G]L``#\```#>VP``.P```![<
M```\````6MP``#T```"7W```.@```-7<``!"````$-T``#X```!3W0``/P``
M`)+=```.````TMT``!0```#AW0``!0```/;=```.````_-T``!,````+W@``
M!P```!_>```1````)]X```X````YW@``!P```$C>```4````4-X```X```!E
MW@``&````'3>```'````C=X```4```"5W@``#````)O>```,````J-X``!(`
M``"UW@``!````,C>```*````S=X```L```#8W@``#````.3>```.````\=X`
M``X`````WP``!0````_?```%````%=\``"X````;WP``)@```$K?```C````
M<=\```,```"5WP``'@```)G?```8````N-\``"4```#1WP``#0```/??```)
M````!>````<````/X```"@```!?@```"````(N```!(````EX```#0```#C@
M```2````1N````0```!9X```!P```%[@```)````9N````P```!PX```4@``
M`'W@```7````T.```"0```#HX```!P````WA```&````%>$```X````<X0``
M"P```"OA```.````-^$```P```!&X0``#0```%/A```5````8>$``!(```!W
MX0``#P```(KA```4````FN$``!L```"OX0``$````,OA``!H````W.$``!H`
M``!%X@``%P```&#B```G````>.(``!H```"@X@``%P```+OB```;````T^(`
M`!D```#OX@``'P````GC```7````*>,``!,```!!XP``"````%7C```(````
M7N,```D```!GXP``#0```''C```3````?^,```,```"3XP``1@```)?C```_
M````WN,``#0````>Y```)````%/D```W````>.0``%<```"PY```!0````CE
M```?````#N4``"\````NY0``"````%[E```-````9^4```X```!UY0``+0``
M`(3E```$````LN4``$\```"WY0``)0````?F```<````+>8```L```!*Y@``
M'P```%;F```=````=N8``"4```"4Y@``(````+KF```D````V^8``"``````
MYP``"P```"'G```&````+><``#D````TYP``!P```&[G```9````=N<```D`
M``"0YP``$P```)KG```$````KN<``!````"SYP``,````,3G```4````]><`
M``T````*Z```#@```!CH```3````)^@``!P````[Z```*````%CH```&````
M@>@```<```"(Z```$P```)#H```$````I.@``!<```"IZ```"@```,'H```,
M````S.@```D```#9Z```!@```./H```%````ZN@```H```#PZ```$0```/OH
M```&````#>D```X````4Z0``#@```"/I```-````,ND```L```!`Z0``'0``
M`$SI```+````:ND```(```!VZ0``'````'GI```'````END``!<```">Z0``
M!@```+;I``!E````O>D```D````CZ@``!P```"WJ```F````->H``#@```!<
MZ@``&@```)7J```J````L.H``#L```#;Z@``*````!?K```T````0.L``!D`
M``!UZP``%0```(_K```'````I>L```@```"MZP``!P```+;K```'````ONL`
M``X```#&ZP``"0```-7K```&````W^L```@```#FZP``"P```._K```'````
M^^L```<````#[```$`````OL```&````'.P``!P````C[```!0```$#L```0
M````1NP``!````!7[```#P```&CL```'````>.P```4```"`[```#0```(;L
M```0````E.P``!0```"E[```"P```+KL```-````QNP``!@```#4[```%P``
M`.WL```:````!>T``!0````@[0``!````#7M```)````.NT```H```!$[0``
M!P```$_M```"````5^T``!\```!:[0``(P```'KM```X````GNT``#$```#7
M[0``)P````GN``!D````,>X``!0```"6[@``'````*ON``!5````R.X``#@`
M```>[P``2@```%?O``!;````HN\``"@```#^[P``.````"?P```J````8/``
M`"@```"+\```+````+3P```G````X?```!L````)\0``/@```"7Q``"I`0``
M9/$``",````.\P``%P```#+S``!(````2O,``",```"3\P``A0```+?S```P
M````/?0``$$```!N]```6P```+#T``!,````#/4``(\```!9]0``'0```.GU
M```8````!_8``"$````@]@``'P```$+V```K````8O8``"$```".]@``*0``
M`+#V```G````VO8``!T````"]P``$0```"#W```S````,O<``"4```!F]P``
M.````(SW```@````Q?<``!\```#F]P``,`````;X``!I````-_@``#(```"A
M^```,0```-3X``!!````!OD``#,```!(^0``)0```'SY```]````HOD``&4`
M``#@^0``30```$;Z```O````E/H``"X```#$^@``*P```//Z```P````'_L`
M`"H```!0^P``/@```'O[``!4````NOL``%H````/_```2````&K\``!*````
ML_P``!0```#^_```,@```!/]```=````1OT``",```!D_0``+P```(C]```L
M````N/T``"T```#E_0``<0```!/^``!O````A?X``+,```#U_@``%P```*G_
M```E````P?\``#(```#G_P``*0```!H``0`^````1``!`"(```"#``$`4@``
M`*8``0#-````^0`!`)L```#'`0$`I@```&,"`0`E````"@,!``L````P`P$`
ML0```#P#`0")````[@,!`$4```!X!`$`(0```+X$`0"7````X`0!`#````!X
M!0$`)0```*D%`0`<````SP4!``<```#L!0$`!````/0%`0`-````^04!``L`
M```'!@$`#@```!,&`0`%````(@8!`!`````H!@$``@```#D&`0!9````/`8!
M``4```"6!@$`$@```)P&`0`(````KP8!``,```"X!@$`$````+P&`0`,````
MS08!`!````#:!@$`#0```.L&`0`"````^08!``X```#\!@$`$@````L'`0`#
M````'@<!`"H````B!P$`!````$T'`0`?````4@<!`#4```!R!P$`+@```*@'
M`0`O````UP<!`!<````'"`$`(````!\(`0`;````0`@!`!@```!<"`$`)```
M`'4(`0`?````F@@!`!H```"Z"`$`(````-4(`0`:````]@@!`#(````1"0$`
M+P```$0)`0`:````=`D!`"L```"/"0$`'P```+L)`0`C````VPD!`!\```#_
M"0$`&@```!\*`0`E````.@H!`"8```!@"@$`)0```(<*`0`D````K0H!`!@`
M``#2"@$`'0```.L*`0`D````"0L!`!@````N"P$`(@```$<+`0`E````:@L!
M`"H```"0"P$`/````+L+`0`?````^`L!`",````8#`$`'P```#P,`0`@````
M7`P!`!H```!]#`$`&````)@,`0`F````L0P!`!X```#8#`$`*0```/<,`0`>
M````(0T!``D```!`#0$`#````$H-`0`7````5PT!`!<```!O#0$`+P```(<-
M`0`D````MPT!``<```#<#0$`'P```.0-`0`%````!`X!``<````*#@$`(@``
M`!(.`0`E````-0X!`!T```!;#@$`&@```'D.`0`'````E`X!`,<```"<#@$`
M"P```&0/`0`5````<`\!``8```"&#P$`"0```(T/`0`8````EP\!``L```"P
M#P$`#0```+P/`0`7````R@\!``8```#B#P$`,P```.D/`0`3````'1`!`!,`
M```Q$`$`#P```$40`0`1````51`!``<```!G$`$`,@```&\0`0`A````HA`!
M`!,```#$$`$`#````-@0`0`1````Y1`!`#(```#W$`$`%````"H1`0`0````
M/Q$!``@```!0$0$`'0```%D1`0`)````=Q$!``H```"!$0$`!0```(P1`0`4
M````DA$!`!T```"G$0$`"````,41`0`?````SA$!``@```#N$0$`&@```/<1
M`0`&````$A(!`!4````9$@$`"````"\2`0`_````.!(!``<```!X$@$`#P``
M`(`2`0`.````D!(!`!````"?$@$`"0```+`2`0`)````NA(!``<```#$$@$`
M&0```,P2`0`*````YA(!``H```#Q$@$`"0```/P2`0`*````!A,!``P````1
M$P$`%P```!X3`0`$````-A,!`"H````[$P$`!P```&83`0`"````;A,!``8`
M``!Q$P$`!P```'@3`0`-````@!,!``L```".$P$`+P```)H3`0`R````RA,!
M`"````#]$P$`'````!X4`0`,````.Q0!`#$```!(%`$`!0```'H4`0`2````
M@!0!`#\```"3%`$`$@```-,4`0`*````YA0!``8```#Q%`$`$P```/@4`0`%
M````#!4!``8````2%0$`!@```!D5`0`)````(!4!``0````J%0$`#````"\5
M`0`*````/!4!``4```!'%0$`&````$T5`0`9````9A4!`!\```"`%0$`'0``
M`*`5`0`1````OA4!``(```#0%0$`!````-,5`0`&````V!4!``,```#?%0$`
M#````.,5`0!%````\!4!`!H````V%@$`-0```%$6`0`H````AQ8!`%,```"P
M%@$`&0````07`0`^````'A<!`"````!=%P$`-0```'X7`0`A````M!<!`$4`
M``#6%P$`,````!P8`0`H````31@!`"D```!V&`$`)@```*`8`0`E````QQ@!
M`"@```#M&`$`*````!89`0`B````/QD!`#````!B&0$`$@```),9`0`3````
MIAD!`!,```"Z&0$`$````,X9`0!Y````WQD!``D```!9&@$`<@```&,:`0!S
M````UAH!`'P```!*&P$`*P```,<;`0!3````\QL!`!<```!''`$`%@```%\<
M`0`/````=AP!`!\```"&'`$`0````*8<`0`?````YQP!`!P````''0$`40``
M`"0=`0`;````=AT!`!0```"2'0$`$@```*<=`0`0````NAT!`!,```#+'0$`
M'0```-\=`0`/````_1T!``\````-'@$`"P```!T>`0`'````*1X!``4````Q
M'@$`%````#<>`0`'````3!X!``@```!4'@$`#P```%T>`0`(````;1X!``P`
M``!V'@$`#P```(,>`0`&````DQX!`!0```":'@$`!@```*\>`0`,````MAX!
M``@```##'@$`!````,P>`0`*````T1X!``0```#<'@$`&0```.$>`0`"````
M^QX!``D```#^'@$`!@````@?`0`&````#Q\!`"<````6'P$`!````#X?`0`/
M````0Q\!`!,```!3'P$`!P```&<?`0`'````;Q\!``8```!W'P$`$````'X?
M`0`2````CQ\!``8```"B'P$`"0```*D?`0`%````LQ\!`"(```"Y'P$`!P``
M`-P?`0`'````Y!\!``L```#L'P$`!0```/@?`0!G`0``_A\!`"L```!F(0$`
M70```)(A`0`5````\"$!`!8````&(@$`#P```!TB`0`)````+2(!``@````W
M(@$`!P```$`B`0`&````2"(!``P```!/(@$`$````%PB`0`-````;2(!``T`
M``![(@$`%@```(DB`0`G````H"(!`!(```#((@$`"@```-LB`0`.````YB(!
M``\```#U(@$`"P````4C`0`0````$2,!`"8````B(P$`(@```$DC`0`J````
M;",!`!0```"7(P$`"````*PC`0`I````M2,!`",```#?(P$`#P````,D`0`@
M````$R0!`"4````T)`$`-P```%HD`0`5````DB0!``\```"H)`$`$0```+@D
M`0`2````RB0!`!X```#=)`$`.````/PD`0`M````-24!`"<```!C)0$`*P``
M`(LE`0`;````MR4!``\```#3)0$`&````.,E`0`-````_"4!``L````*)@$`
M"P```!8F`0`'````(B8!`"8````J)@$`&P```%$F`0!#````;28!`$P```"Q
M)@$`7P```/XF`0!?````7B<!`&(```"^)P$`8@```"$H`0!&````A"@!``4`
M``#+*`$`'````-$H`0`'````[B@!``T```#V*`$`#`````0I`0`1````$2D!
M``X````C*0$`.````#(I`0`V````:RD!`!,```"B*0$`%0```+8I`0`)````
MS"D!``D```#6*0$`"````.`I`0`2````Z2D!`"P```#\*0$`#0```"DJ`0`4
M````-RH!`!0```!,*@$`&P```&$J`0`O````?2H!`!4```"M*@$`#P```,,J
M`0`4````TRH!`!````#H*@$`)0```/DJ`0`A````'RL!`!T```!!*P$`(```
M`%\K`0`/````@"L!`%4```"0*P$`.0```.8K`0`H````("P!``D```!)+`$`
M$````%,L`0`O````9"P!``H```"4+`$`$@```)\L`0`9````LBP!``D```#,
M+`$`#````-8L`0`-````XRP!``,```#Q+`$`%P```/4L`0`.````#2T!`!$`
M```<+0$`&P```"XM`0`E````2BT!`"\```!P+0$`"P```*`M`0`8````K"T!
M`!D```#%+0$`'0```-\M`0`;````_2T!`!,````9+@$`%````"TN`0`B````
M0BX!`!4```!E+@$`%P```'LN`0`@````DRX!``@```"T+@$`"````+TN`0`/
M````QBX!`!@```#6+@$`)P```.\N`0`'````%R\!``@````?+P$`$@```"@O
M`0`=````.R\!`!H```!9+P$`/````'0O`0!$````L2\!``4```#V+P$`"P``
M`/PO`0`Z````"#`!``X```!#,`$`$@```%(P`0!#````93`!`"@```"I,`$`
M+0```-(P`0`P`````#$!`#,````Q,0$`#P```&4Q`0`)````=3$!``D```!_
M,0$`&0```(DQ`0`=````HS$!`#0```#!,0$`*@```/8Q`0`0````(3(!`!0`
M```R,@$`"````$<R`0`/````4#(!`!<```!@,@$`'````'@R`0`%````E3(!
M`"T```";,@$`#0```,DR`0`(````US(!`"T```#@,@$`$@````XS`0`.````
M(3,!``8````P,P$`!````#<S`0`*````/#,!``@```!',P$`$````%`S`0`3
M````83,!`"@```!U,P$`$P```)XS`0`*````LC,!`!0```"],P$`"P```-(S
M`0`&````WC,!`$P```#E,P$`*````#(T`0`'````6S0!`!P```!C-`$`)```
M`(`T`0`F````I30!`#0```#,-`$`)`````$U`0`I````)C4!`(````!0-0$`
M-P```-$U`0`+````"38!`!<````5-@$`#P```"TV`0`0````/38!``\```!.
M-@$`$````%XV`0`/````;S8!``\```!_-@$`!@```(\V`0`;````EC8!`!<`
M``"R-@$`"````,HV`0`&````TS8!``X```#:-@$`6@```.DV`0`*````1#<!
M`!,```!/-P$`6P```&,W`0`0````OS<!`!(```#0-P$`#P```.,W`0`5````
M\S<!`!8````).`$`+````"`X`0`O````33@!`!<```!].`$`(@```)4X`0`(
M````N#@!`"0```#!.`$`%0```.8X`0`1````_#@!`!L````..0$`%P```"HY
M`0`1````0CD!`!L```!4.0$`$@```'`Y`0`;````@SD!`!8```"?.0$`!0``
M`+8Y`0`2````O#D!`!````#/.0$`!P```.`Y`0`-````Z#D!``8```#V.0$`
M!@```/TY`0`/````!#H!``8````4.@$`"P```!LZ`0`(````)SH!``P````P
M.@$`%@```#TZ`0`+````5#H!``@```!@.@$`&0```&DZ`0`^````@SH!`"L`
M``#".@$`)P```.XZ`0`2````%CL!`!,````I.P$`$@```#T[`0`3````4#L!
M`#0```!D.P$`1````)D[`0`C````WCL!`!`````"/`$`-P```!,\`0`4````
M2SP!`!L```!@/`$`"````'P\`0`)````A3P!`!(```"//`$`+0```*(\`0`H
M````T#P!`#````#Y/`$`*P```"H]`0`E````5CT!`"0```!\/0$`'P```*$]
M`0`^````P3T!`"@`````/@$`*0```"D^`0`L````4SX!`!T```"`/@$`)@``
M`)X^`0`N````Q3X!`#,```#T/@$`+P```"@_`0`N````6#\!`#4```"'/P$`
M)````+T_`0`B````XC\!`$8````%0`$`%@```$Q``0`D````8T`!`"P```"(
M0`$`(P```+5``0`8````V4`!`,````#R0`$`,0```+-!`0`G````Y4$!`"8`
M```-0@$`)@```#1"`0`P````6T(!`!X```",0@$`*````*M"`0`D````U$(!
M`#(```#Y0@$`-0```"Q#`0`U````8D,!`#0```"80P$`M0```,U#`0`J````
M@T0!`!P```"N1`$`(P```,M$`0`K````[T0!`"L````;10$`3@```$=%`0!+
M````ED4!`!$```#B10$`!````/1%`0`'````^44!``H````!1@$`&0````Q&
M`0`4````)D8!`!4````[1@$`&@```%%&`0`9````;$8!``L```"&1@$`#0``
M`))&`0`,````H$8!`!,```"M1@$`#0```,%&`0`2````ST8!``L```#B1@$`
M/P```.Y&`0`'````+D<!`!`````V1P$``@```$='`0`(````2D<!``@```!3
M1P$`&P```%Q'`0`G````>$<!``H```"@1P$`%````*M'`0`3````P$<!``4`
M``#41P$`#P```-I'`0`*````ZD<!`!$```#U1P$`#0````=(`0`1````%4@!
M``X````G2`$`$P```#9(`0`7````2D@!`!\```!B2`$`'P```()(`0`'````
MHD@!`!$```"J2`$`#P```+Q(`0`(````S$@!``\```#52`$`%P```.5(`0`?
M````_4@!``\````=20$`#P```"U)`0`I````/4D!`"$```!G20$`/0```(E)
M`0`/````QTD!`!<```#720$`&0```.])`0`:````"4H!`#X````D2@$`*```
M`&-*`0`*````C$H!`!````"72@$`+P```*A*`0`9````V$H!``D```#R2@$`
M.@```/Q*`0`U````-TL!``@```!M2P$`#@```'9+`0`F````A4L!`!````"L
M2P$`)0```+U+`0`H````XTL!``D````,3`$`'0```!9,`0`2````-$P!`!D`
M``!'3`$`#P```&%,`0`2````<4P!``T```"$3`$`0````)),`0`^````TTP!
M``D````230$`#````!Q-`0`P````*4T!`!````!:30$`$0```&M-`0`+````
M?4T!`!$```")30$`$@```)M-`0`:````KDT!`!L```#)30$`(@```.5-`0`9
M````"$X!`"(````B3@$`)````$5.`0`5````:DX!``L```"`3@$`#````(Q.
M`0`/````F4X!`"8```"I3@$`$P```-!.`0`)````Y$X!``P```#N3@$`'@``
M`/M.`0`:````&D\!`#\````U3P$`)P```'5/`0`%````G4\!``L```"C3P$`
M%P```*]/`0".````QT\!`"````!64`$`!0```'=0`0`@````?5`!`!8```">
M4`$`%0```+50`0`&````RU`!``8```#24`$`#0```-E0`0`,````YU`!`!0`
M``#T4`$`#`````E1`0`D````%E$!``T````[40$`"@```$E1`0`6````5%$!
M``@```!K40$`"````'11`0`9````?5$!`"(```"740$`(P```+I1`0`/````
MWE$!`#@```#N40$`$````"=2`0`'````.%(!`!````!`4@$`&````%%2`0`W
M````:E(!`"P```"B4@$`(@```,]2`0`=````\E(!`!P````04P$`(P```"U3
M`0`;````45,!`$T```!M4P$`!P```+M3`0`2````PU,!``,```#64P$`"P``
M`-I3`0`+````YE,!``T```#R4P$`#`````!4`0`2````#50!``X````@5`$`
M&@```"]4`0`:````2E0!`!0```!E5`$`#0```'I4`0`/````B%0!`!(```"8
M5`$`)0```*M4`0`&````T50!``H```#85`$`#0```.-4`0`.````\50!``0`
M````50$`!0````55`0`&````"U4!`!@````250$`#P```"M5`0`%````.U4!
M`"H```!!50$`&````&Q5`0`&````A54!``@```",50$`#P```)55`0`*````
MI54!``P```"P50$`!@```+U5`0`*````Q%4!``(```#/50$`!P```-)5`0`:
M````VE4!`!<```#U50$`%0````U6`0`A````(U8!``,```!%5@$`!P```$E6
M`0`3````458!`!0```!E5@$`#0```'I6`0`,````B%8!`"X```"55@$`"```
M`,16`0`+````S58!`!````#95@$`"````.I6`0`&````\U8!`!4```#Z5@$`
M$0```!!7`0`N````(E<!`!8```!15P$`!@```&A7`0`/````;U<!``\```!_
M5P$`"0```(]7`0`L````F5<!``0```#&5P$`!P```,M7`0`F````TU<!``8`
M``#Z5P$`"@````%8`0`5````#%@!`!T````B6`$`!````$!8`0`L````15@!
M``T```!R6`$`#0```(!8`0`1````CE@!`!````"@6`$`#0```+%8`0`O````
MOU@!``\```#O6`$`$````/]8`0`M````$%D!`!(````^60$`$P```%%9`0`*
M````95D!`#P```!P60$`(P```*U9`0`?````T5D!`"0```#Q60$`!P```!9:
M`0`(````'EH!``P````G6@$`+0```#1:`0`K````8EH!`$$```".6@$`"P``
M`-!:`0`,````W%H!`"$```#I6@$`+0````M;`0`6````.5L!``L```!06P$`
M%0```%Q;`0`.````<EL!`!````"!6P$`%0```));`0`1````J%L!`#P```"Z
M6P$`C````/=;`0!V````A%P!`!8```#[7`$`"P```!)=`0`2````'ET!`!,`
M```Q70$`$````$5=`0`'````5ET!``@```!>70$`&0```&==`0`1````@5T!
M`!4```"370$`%0```*E=`0`.````OUT!`!4```#.70$`'P```.1=`0`A````
M!%X!`'(````F7@$`$0```)E>`0`2````JUX!``L```"^7@$`"P```,I>`0`4
M````UEX!`!````#K7@$`#P```/Q>`0`5````#%\!`!0````B7P$`)@```#=?
M`0`J````7E\!`"<```")7P$`)P```+%?`0`J````V5\!`"L````$8`$`'@``
M`#!@`0!,````3V`!`!0```"<8`$`%````+%@`0`4````QF`!`!0```#;8`$`
M$@```/!@`0`8`````V$!`!@````<80$`%0```#5A`0`5````2V$!`#L```!A
M80$`&0```)UA`0`:````MV$!`#0```#280$`%`````=B`0`(````'&(!``X`
M```E8@$`+P```#1B`0`>````9&(!`!,```"#8@$`#P```)=B`0`9````IV(!
M`!L```#!8@$`%P```-UB`0`3````]6(!`!H````)8P$`(0```"1C`0`:````
M1F,!`!4```!A8P$`&P```'=C`0`A````DV,!`!L```"U8P$`&P```-%C`0`4
M````[6,!``8````"9`$`"@````ED`0`'````%&0!``<````<9`$`#````"1D
M`0`7````,60!`!,```!)9`$`%0```%UD`0`2````<V0!`!4```"&9`$`%```
M`)QD`0`5````L60!`!@```#'9`$`%@```.!D`0`M````]V0!`!0````E90$`
M#@```#IE`0`3````264!`!(```!=90$`#@```'!E`0`.````?V4!``X```".
M90$`.0```)UE`0`&````UV4!``X```#>90$`$P```.UE`0`'`````68!`!,`
M```)9@$`#@```!UF`0`1````+&8!`!0````^9@$`(P```%-F`0`J````=V8!
M`"4```"B9@$`!0```,AF`0`'````SF8!`"D```#69@$`"`````!G`0`4````
M"6<!``\````>9P$`"@```"YG`0`2````.6<!``<```!,9P$`%P```%1G`0`U
M````;&<!``D```"B9P$`#````*QG`0`H````N6<!`!8```#B9P$`%@```/EG
M`0`-````$&@!`#$````>:`$`"@```%!H`0`,````6V@!``T```!H:`$`"0``
M`'9H`0`'````@&@!``8```"(:`$`$@```(]H`0!'````HF@!`!````#J:`$`
M!@```/MH`0`.`````FD!``4````1:0$`!@```!=I`0`7````'FD!`!<````V
M:0$`%@```$YI`0`"````96D!``8```!H:0$`#````&]I`0`0````?&D!`!8`
M``"-:0$`/0```*1I`0`*````XFD!`!H```#M:0$`#P````AJ`0`'````&&H!
M``0````@:@$`,@```"5J`0`V````6&H!`!0```"/:@$`&@```*1J`0`9````
MOVH!`"@```#9:@$`)P````)K`0`-````*FL!``4````X:P$`$@```#YK`0`6
M````46L!`!4```!H:P$`%@```'YK`0`7````E6L!`!\```"M:P$`!````,UK
M`0`*````TFL!`!````#=:P$`$0```.YK`0`&`````&P!`&(````';`$`$```
M`&IL`0`/````>VP!`!````"+;`$`&@```)QL`0!*````MVP!``<````";0$`
M&P````IM`0`'````)FT!``8````N;0$`"0```#5M`0`J````/VT!`"D```!J
M;0$`"0```)1M`0`'````GFT!`"(```"F;0$`9````,EM`0`;````+FX!`",`
M``!*;@$`&@```&YN`0`"````B6X!`!@```",;@$`!P```*5N`0`7````K6X!
M``\```#%;@$`#0```-5N`0`.````XVX!``<```#R;@$`%P```/IN`0`.````
M$F\!``L````A;P$`#P```"UO`0`,````/6\!``L```!*;P$`"P```%9O`0`+
M````8F\!`"<```!N;P$`$````)9O`0`1````IV\!`!@```"Y;P$`)0```-)O
M`0`/````^&\!`!4````(<`$`#P```!YP`0`%````+G`!`!,````T<`$`!@``
M`$AP`0`$````3W`!``T```!4<`$`"@```&)P`0`,````;7`!`!,```!Z<`$`
M'@```(YP`0`3````K7`!``,```#!<`$`&P```,5P`0`'````X7`!``X```#I
M<`$`#````/AP`0`1````!7$!``,````7<0$`.@```!MQ`0`[````5G$!`!X`
M``"2<0$`)0```+%Q`0`I````UW$!`!4````!<@$`0@```!=R`0!"````6G(!
M`"L```"=<@$`,````,ER`0`^````^G(!`#X````Y<P$`/P```'AS`0`O````
MN',!`$0```#H<P$`-````"UT`0`3````8G0!`!0```!V=`$`%````(MT`0`6
M````H'0!`!<```"W=`$`$0```,]T`0`3````X70!`!4```#U=`$`(@````MU
M`0`6````+G4!`"0```!%=0$`%````&IU`0`4````?W4!`"T```"4=0$`)@``
M`,)U`0`D````Z74!`!(````.=@$`0````"%V`0!$````8G8!`!(```"G=@$`
M!@```+IV`0`>````P78!`!$```#@=@$`"````/)V`0`(````^W8!`!,````$
M=P$`%0```!AW`0`.````+G<!`!$````]=P$`"@```$]W`0`5````6G<!`$\!
M``!P=P$`"P```,!X`0`?````S'@!``P```#L>`$`/P```/EX`0`)````.7D!
M``<```!#>0$`$@```$MY`0`.````7GD!`"L```!M>0$`#P```)EY`0`W````
MJ7D!``L```#A>0$`%P```.UY`0`G````!7H!``D````M>@$`"0```#=Z`0`0
M````07H!``<```!2>@$`#@```%IZ`0`W````:7H!`!H```"A>@$`)0```+QZ
M`0"#````XGH!`!<```!F>P$`2@```'Y[`0`J````R7L!`!,```#T>P$`%P``
M``A\`0`(````('P!``P````I?`$`#P```#9\`0`2````1GP!``H```!9?`$`
M$````&1\`0`(````=7P!`!L```!^?`$`&````)I\`0`$````LWP!`!$```"X
M?`$`&0```,I\`0`J````Y'P!`!0````/?0$`'````"1]`0`2````07T!`"H`
M``!4?0$`"P```']]`0`+````BWT!``L```"7?0$`!P```*-]`0`'````JWT!
M`#,```"S?0$`#0```.=]`0`N````]7T!`!8````D?@$`"````#M^`0`)````
M1'X!`!X```!.?@$`&@```&U^`0`*````B'X!`!L```"3?@$`"````*]^`0`6
M````N'X!``@```#/?@$`!P```-A^`0`?````X'X!`#``````?P$`#0```#%_
M`0`E````/W\!`!H```!E?P$`$P```(!_`0`6````E'\!``H```"K?P$`"```
M`+9_`0`+````OW\!``X```#+?P$`"P```-I_`0`B````YG\!`$`````)@`$`
M0@```$J``0`=````C8`!`"X```"K@`$`)P```-J``0!,`````H$!`!H```!/
M@0$`(````&J!`0`L````BX$!`!T```"X@0$`'@```-:!`0`J````]8$!`#4`
M```@@@$`<0```%:"`0!9````R((!`#4````B@P$`+````%B#`0`G````A8,!
M`!8```"M@P$`'````,2#`0`Z````X8,!`#@````<A`$`+````%6$`0`S````
M@H0!`#L```"VA`$`#````/*$`0`%````_X0!`"`````%A0$`!P```":%`0`-
M````+H4!`"H````\A0$`$@```&>%`0`5````>H4!`!$```"0A0$`$````**%
M`0`(````LX4!`!4```"\A0$`#@```-*%`0`1````X84!``X```#SA0$`'```
M``*&`0!!````'X8!``<```!AA@$`&P```&F&`0`,````A88!``\```"2A@$`
M!0```**&`0`(````J(8!`!(```"QA@$`/P```,2&`0!9````!(<!`"@```!>
MAP$`*P```(>'`0`B````LX<!`"````#6AP$`!0```/>'`0`0````_8<!``8`
M```.B`$`*0```!6(`0`;````/X@!`#<```!;B`$`"````).(`0`.````G(@!
M``\```"KB`$`%0```+N(`0`>````T8@!`!````#PB`$`20````&)`0`,````
M2XD!`"@```!8B0$`#P```(&)`0`3````D8D!`!(```"EB0$`)0```+B)`0!$
M````WHD!`#8````CB@$`#````%J*`0!!````9XH!`#D```"IB@$`.@```..*
M`0`V````'HL!`$P```!5BP$`2P```**+`0!.````[HL!`$@````]C`$`30``
M`(:,`0!.````U(P!`$@````CC0$`30```&R-`0!.````NHT!`$@````)C@$`
M30```%*.`0!-````H(X!`$<```#NC@$`3````#:/`0!+````@X\!`$4```#/
MCP$`2@```!60`0!)````8)`!`$@```"JD`$`3@```/.0`0!(````0I$!`$T`
M``"+D0$`$0```-F1`0`7````ZY$!``D````#D@$`#@````V2`0`6````')(!
M``P````SD@$`%P```$"2`0`;````6)(!``D```!TD@$`%P```'Z2`0`1````
MEI(!`"P```"HD@$`"0```-62`0`%````WY(!`!$```#ED@$`#````/>2`0`4
M````!),!``4````9DP$`#P```!^3`0`3````+Y,!`!````!#DP$`$0```%23
M`0`1````9I,!``@```!XDP$`!P```(&3`0!!````B9,!`#$```#+DP$`,@``
M`/V3`0`(````,)0!`!X````YE`$`'0```%B4`0`K````=I0!``P```"BE`$`
M"P```*^4`0`(````NY0!``P```#$E`$``@```-&4`0`4````U)0!`!$```#I
ME`$`$0```/N4`0`*````#94!``T````8E0$`#P```":5`0`3````-I4!`&8`
M``!*E0$`'@```+&5`0`U````T)4!``@````&E@$`"0````^6`0`2````&98!
M`!,````LE@$`%P```$"6`0`/````6)8!`!<```!HE@$`&P```("6`0`6````
MG)8!`!0```"SE@$`'````,B6`0`=````Y98!`!D````#EP$`A0```!V7`0`C
M````HY<!`"P```#'EP$`+0```/27`0`<````(I@!`"0````_F`$`(@```&28
M`0`>````AY@!`!<```"FF`$`)@```+Z8`0`=````Y9@!``P````#F0$`#```
M`!"9`0`+````'9D!`!$````IF0$`&0```#N9`0`$````59D!`&````!:F0$`
M0````+N9`0!(````_)D!`"(```!%F@$`0@```&B:`0!X````JYH!``<````D
MFP$`+````"R;`0`V````69L!``8```"0FP$`$````)>;`0`1````J)L!`$$`
M``"ZFP$`"````/R;`0!1````!9P!`$````!7G`$`+P```)B<`0`1````R)P!
M`"L```#:G`$`(P````:=`0`M````*IT!`"8```!8G0$`+@```'^=`0`G````
MKIT!`!H```#6G0$`"@```/&=`0`Q````_)T!`!`````NG@$`*````#^>`0`(
M````:)X!`!0```!QG@$`!P```(:>`0`2````CIX!`#<```"AG@$`'P```-F>
M`0`2````^9X!``\````,GP$`$````!R?`0`A````+9\!`"\```!/GP$`$P``
M`'^?`0`'````DY\!`!,```";GP$`!````*^?`0`;````M)\!``\```#0GP$`
M#P```."?`0`0````\)\!``@````!H`$`!@````J@`0`,````$:`!`!(````>
MH`$`"0```#&@`0`1````.Z`!``X```!-H`$`#@```%R@`0`,````:Z`!`"0`
M``!XH`$`"@```)V@`0`"````J*`!`!T```"KH`$`!````,F@`0`D````SJ`!
M``@```#SH`$`;````/R@`0`*````::$!``@```!TH0$`(P```'VA`0!`````
MH:$!`!<```#BH0$`)@```/JA`0!1````(:(!`"P```!SH@$`.P```*"B`0`7
M````W*(!`!,```#TH@$`$0````BC`0`'````&J,!``0````BHP$`!P```">C
M`0`,````+Z,!``D````\HP$`!````$:C`0`&````2Z,!``L```!2HP$`"@``
M`%ZC`0`'````::,!`"P```!QHP$`!@```)ZC`0`E````I:,!``<```#+HP$`
M$````-.C`0`0````Y*,!`!0```#UHP$`!P````JD`0`(````$J0!`!,````;
MI`$`$0```"^D`0`?````0:0!``L```!AI`$`#0```&VD`0`;````>Z0!`!,`
M``"7I`$`&P```*ND`0`2````QZ0!``<```#:I`$`#````.*D`0`1````[Z0!
M``\````!I0$``@```!&E`0`P````%*4!`"D```!%I0$`*P```&^E`0`J````
MFZ4!`"4```#&I0$`>0```.RE`0`2````9J8!`"@```!YI@$`3````**F`0`T
M````[Z8!`%<````DIP$`4@```'RG`0`A````SZ<!`#H```#QIP$`*0```"RH
M`0`O````5J@!`#4```"&J`$`,0```+RH`0`@````[J@!`$`````/J0$`\`$`
M`%"I`0`<````0:L!`!8```!>JP$`1P```'6K`0`I````O:L!`(````#GJP$`
M0P```&BL`0`^````K*P!`&H```#KK`$`:0```%:M`0":````P*T!`"$```!;
MK@$`$P```'VN`0`>````D:X!`!\```"PK@$`)````-"N`0`A````]:X!`"P`
M```7KP$`)0```$2O`0`<````:J\!`!(```"'KP$`.0```)JO`0`K````U*\!
M`#4`````L`$`)````#:P`0`A````6[`!`$````!]L`$`:P```+ZP`0`P````
M*K$!`#````!;L0$`1````(RQ`0`O````T;$!`"0````!L@$`-````":R`0!\
M````6[(!`%4```#8L@$`2````"ZS`0!"````=[,!`#D```"ZLP$`/0```/2S
M`0`X````,K0!`$8```!KM`$`50```+*T`0!R````"+4!`'````![M0$`60``
M`.RU`0`8````1K8!`#L```!?M@$`(@```)NV`0`M````OK8!`"P```#LM@$`
M+````!FW`0`Q````1K<!`&@```!XMP$`90```.&W`0"S````1[@!`!D```#[
MN`$`+````!6Y`0!(````0KD!`#8```"+N0$`70```,*Y`0`S````(+H!`%H`
M``!4N@$`R````*^Z`0#=````>+L!`(,```!6O`$`(P```-J\`0`.````_KP!
M`,`````-O0$`KP```,Z]`0!)````?KX!`#````#(O@$`F@```/F^`0!#````
ME+\!`"4```#8OP$`)````/Z_`0`)````(\`!``,````MP`$`%````#'``0`*
M````1L`!``P```!1P`$`!@```%[``0`1````9<`!``0```!WP`$`=0```'S`
M`0`&````\L`!`!<```#YP`$`!0```!'!`0`&````%\$!`!,````>P0$`"P``
M`#+!`0`4````/L$!``\```!3P0$``@```&/!`0`<````9L$!`"````"#P0$`
M%0```*3!`0!,````NL$!`!8````'P@$`)0```!["`0!#````1,(!`#@```"(
MP@$`.0```,'"`0`8````^\(!`"X````4PP$`(@```$/#`0`@````9L,!`"@`
M``"'PP$`(P```+##`0`A````U,,!`"<```#VPP$`(````![$`0`S````/\0!
M`#````!SQ`$`'````*3$`0`_````P<0!`"$````!Q0$`-0```"/%`0`H````
M6<4!`",```""Q0$`.@```*;%`0`N````X<4!`"P````0Q@$`(0```#W&`0`D
M````7\8!`"@```"$Q@$`+P```*W&`0`C````W<8!`"D````!QP$`-0```"O'
M`0!&````8<<!`#H```"HQP$`*````./'`0`L````#,@!`"L````YR`$`+```
M`&7(`0`F````DL@!`"$```"YR`$`+P```-O(`0`F````"\D!`#(````RR0$`
M*P```&7)`0`.````D<D!``\```"@R0$`(@```+#)`0`A````T\D!`#D```#U
MR0$`,0```"_*`0`1````8<H!`"$```!SR@$`!P```)7*`0`'````G<H!`"(`
M``"ER@$`)0```,C*`0`?````[LH!`!X````.RP$`!P```"W+`0`'`0``-<L!
M`!$````]S`$`&@```$_,`0`)````:LP!``P```!TS`$`(````(',`0`0````
MHLP!`!$```"SS`$`)````,7,`0`(````ZLP!`#4```#SS`$`&@```"G-`0`9
M````1,T!`!,```!>S0$`)@```'+-`0`)````F<T!`#8```"CS0$`+P```-K-
M`0`2````"LX!``\````=S@$`#@```"W.`0`W````/,X!`!4```!TS@$`%@``
M`(K.`0`,````H<X!`"$```"NS@$`#0```-#.`0`.````WLX!``<```#MS@$`
M%````/7.`0`<````"L\!``@````GSP$`-````##/`0`*````9<\!`!<```!P
MSP$`!0```(C/`0`:````CL\!``D```"ISP$`.P```+//`0`&````[\\!``\`
M``#VSP$`$P````;0`0`.````&M`!``<````IT`$`"0```#'0`0`+````.]`!
M`!\```!'T`$`#P```&?0`0`2````=]`!`!$```"*T`$`"0```)S0`0`*````
MIM`!`!H```"QT`$`!P```,S0`0`S````U-`!``T````(T0$``@```!;1`0`+
M````&=$!``L````ET0$`$@```#'1`0`/````1-$!`#\```!4T0$`.P```)31
M`0`G````T-$!`"4```#XT0$`#````![2`0!3````*](!``8```!_T@$`%0``
M`(;2`0!%````G-(!`!$```#BT@$`#@```/32`0`'`````],!`!@````+TP$`
M!P```"33`0`(````+-,!``4````UTP$`#P```#O3`0`'````2],!`!(```!3
MTP$`$0```&;3`0`%````>-,!`!H```!^TP$`(0```)G3`0`?````N],!`",`
M``#;TP$`$0```/_3`0`"````$=0!``0````4U`$`!@```!G4`0`#````(-0!
M``P````DU`$`90```#'4`0`;````E]0!`#@```"SU`$`(0```.S4`0!3````
M#M4!`!(```!BU0$`1@```'75`0`A````O-4!`#X```#>U0$`(P```!W6`0!!
M````0=8!`#@```"#U@$`,0```+S6`0`P````[M8!`#`````?UP$`,````%#7
M`0`Q````@=<!`"P```"SUP$`,````.#7`0!!````$=@!`!L```!3V`$`'```
M`&_8`0`1````C-@!`!(```">V`$`?0```+'8`0`,````+]D!`'<````\V0$`
M=````+39`0"(````*=H!`#$```"RV@$`8@```.3:`0`5````1]L!`!\```!=
MVP$`%````'W;`0`C````DML!`$0```"VVP$`(0```/O;`0`4````'=P!`%0`
M```RW`$`'@```(?<`0`C````IMP!`"$```#*W`$`%0```.S<`0`B`````MT!
M`"X````EW0$`$@```%3=`0`*````9]T!`!````!RW0$`!@```(/=`0`'````
MBMT!`!0```"2W0$`!P```*?=`0`&````K]T!`!@```"VW0$`"````,_=`0`/
M````V-T!`!4```#HW0$`"0```/[=`0`3````"-X!``<````<W@$`$````"3>
M`0`*````-=X!``8```!`W@$`"P```$?>`0`&````4]X!`!D```!:W@$``@``
M`'3>`0`%````=]X!``P```!]W@$`"````(K>`0`Q````D]X!``4```#%W@$`
M%0```,O>`0`;````X=X!``T```#]W@$`"@````O?`0`.````%M\!`!$````E
MWP$`%@```#??`0`(````3M\!``X```!7WP$`!0```&;?`0`K````;-\!``L`
M``"8WP$`!P```*3?`0`.````K-\!``T```"[WP$``0```-H$``"#`@``2P(`
M`*H!``!.`@``KP4`````````````@@0``#<`````````=`,``(,```!N`@``
M%P4```````!H`@``?@4``-8%``#S!```F@```((%````````D````*D!``".
M!```Z````&P%```6`P``I0(``)X$```````````````````@!0``2`0``.`#
M``#C````E`$``/@%`````````````$<```"G````X0,``(4#``#O````F`4`
M`'4%``#^!0``RP$``#("``"'`0``)P$````````_`P``T`(``*D%``![````
M:P$``"\$```5`P``.0```)X!``!5!0```````*T!```O`P``6P`````#```2
M`0``J@(``.(!`````````````*<!``#7!0``NP```*@``````````````.H`
M````````R`$``*L$```)!@``Y0$``/`!```W!0```````.T$```7`P``````
M``````"X`P``Y````"`#````````@P$``"0#```*!0``3P$``"L%````````
M.P,``+L"``":!0````````````"V`0````````````#$!0```````(X!``#J
M!0``Q0(``(8!````````R`(``,D$`````````````.\#```^!````````'4!
M``";`0``HP,``'P%``#-`0```````!L`````````/0$```````#G!0``````
M`!T$``"[!```.P0``*D"`````````````+8#````````W`4``#H````V!```
M)00``,8$``"Z`@``7`$``.H!``!0````]04``/(%``".!0``G`4``(L!```B
M!````````-L"```@`@```````#,$``"X`0``<@4``.X%``!Y!0``:0,``.($
M``#^`````````.@#````````R@,``!$#````````K00``+$!``"@`@```P0`
M``X!``!4`P``-@(```````!W`0``I@(``%,$``"4!```BP0``,L```#6`P``
MI````/@!``"\`@```````!H"``#/`P``<@,````````-`P```````)4!``!'
M`0``(0(`````````````H@4``!L!``"5`P```````.@%``!I`@``````````
M``!2!```]@0``$P"```Q!0```````&X`````````L`(``$`#``!R!```B`0`
M`'H"```\`@```````&<#``#'!0``(P,``,(```"1`P``W@```-0$``#?!0``
M``````\%``!%!0``400```````#A````Q@$````````]!```4P,`````````
M````S0```.L#````````KP$``.\%``"F````U0(``*H#````````A@(``$4`
M```%`0```````&4%``#)`@```````$X$``!>!0```````,H`````````90(`
M`-L#``"7`P``5`0``,P#``"/`P``(@````````#W`@```````'@```#.`@``
MU@(``,H%```?!```K`$`````````````X0$``)\!``````````````````!B
M````RP(``*`%```.`````````)4"```5````)@,``(T%``!S!```)0``````
M````````2@(```````#T`````````%,!``!O`0``Q`$``/L```"1`0``<```
M`!,````I!```K@$```````!G!```N`0````````/`P```````%T```"+`P``
M^@(``%$```#F`P``Q`(``,`#````````^04``!4%``"5!0```````+D#````
M````"@$``-L%``#(`P``?@,```````"Q`P``804``.L$``!A````K`,`````
M``#3!```U`(``'L!``!>!`````````````"K`P``H@````````"?`@``8@,`
M``````!#````A@,``#4$``!J!0``"0```)($``#!````30(```````#3````
M`````#<!`````````````%`%```F!````````&H```!&`@``/@4```@%``"9
M`P``8P```+D$``#X!```*`0```````!H`0``;04``,8"``#T`@``Q@```),$
M``"9!```2P4``'`"``!;`@``<P,``.D!```/`@````````````!'!```````
M`&,"``!)`P``N04``%L%``#L!````````+4"``":`0``E``````````*!@``
M3`````````#.!0``[0(``"H%``#R`0``\04``&<````N!0``(@$``$T%``#E
M`@``CP$``+\$```D`0``J@0```````#8`0```````%,"````````W@4```@!
M````````:@,``+\%```W`@``=`(``%<#```M!````````.,%``!M`@``V@4`
M`$D````<!0`````````````C`@```````'0$``#^!```9P4```````#>`0``
M3P,```````!N!0``M`$```P#``!<`@``$P0```8%``"W!```"`8``#H%``"R
M`P``G`0``!($``#!!```V0,``'<"````````U@```$L```#N`0``\P$`````
M```E`0``*`$``%`#``"Y`0``P`0``&@$```-````0`$``,4#``"+`@``W@,`
M`-0%``!9`0``9@,```<#```M`0```````(4`````````Q0$``+H#```[````
M-0$````````M`P``#0(``$D!```+!```1@0``'`#``````````````````#0
M`0``MP4``-4%```:`0``L`$``-X"``!_!0``C0(``)(#``#_!```K0,``!(`
M`````````````/P#``#/`0``(0,``'T````%`P``T@4``+\```"9!0``8P0`
M``````",`0``LP$``#(#``!7`0``B0(``'8"``#-`@``0P,```````#I!```
M3@```*T"``!P!````````(("``!U`@``*0,```````!L`0``%@$``-(```#F
M!0``@00``(X"````````@0$``&L#````````Q0```!4!``#4````A`(``,P$
M```````````````````>`0``/@(```````!,!```,`$``.(```#3`0``````
M`'L$``"=`@``]@$```````##!```80$```````"A!0``.00```4%````````
M@04``*4```!Y!```Y`,````````X`@`````````````-!0``JP```+L!``!+
M!```1````+("```E`P``!`8``*,$``"P!```_P``````````````C`0``!`#
M``#7````+`,```````!4!0```````/,#```!!@``4P4``,("``"<`@``R@$`
M`,$!``#L`0``,@4``!L#````````Z`$```````#_`0``M``````````*!```
M6@0``$D"``#+!0``>0(````````H`@``H@(````````#`@``O0,``*X"``#_
M`@```````````````0``O`````````#0!```X@,``"L"```O!0``J@4`````
M``#9`@```````'L#``"``P``+@```$@"``"G`@``\P```)(%````````_04`
M`,P%``"`!0``````````````````_`4``'@#````````\`0``%8$``!T!0``
M-`0```````"9`@```````&@```")`0``````````````````=@$``*<%``#Y
M````#@(``.T```"]!0``^P,``*4%``#.`P```````(4!``#=`0``;`(``'T#
M``"Q!```-`(``"<#`````````````.4```"4`@``'`0``"0"``#"`0```@``
M`,0#``#@!0``F0$```````#J`@``,P$``"0$``!]`0``2@4`````````````
M`````%P$````````40,``+($````````]00```````!!````K@4``)$"```/
M`````````-4#`````````````/`%```0!0``*P0```````!C`0```````*P"
M``!X!````````-T#``""`0```@8```````"X````PP```*(!````````?P``
M`````````````````%H"``!4`0```````/0#``"=!```J@```!X#```]````
M^P$``$<#```!!0``LP,``%<%``#=`````````.<!````````-`$``'@"``"?
M!```B`(```````#Z!0``2`,```$!``"<`0```````.L%``#S`@``VP$``$H#
M```O`@```````-4$``#<`P````````````"$`P``>@0```````#)`P``$P,`
M`"H!``!7`@```````#`"``#C`0``'0```-\"````````R0```)L"````````
M^0$``"@#````````*0````\$````!0``_@$``+8$```.!0``MP,``!@!``"A
M`0``>`$```````!$`@``N0(``.L"````````]P```,4%````````%P```-P"
M``!D`@``=P```'H```#\!````````+X`````````GP``````````````$0``
M`.4#```9!0``````````````!@``,`0``(H```#]!```/`4``%@%``!R`@``
M,00`````````````K0```.(%````````7@```%(%````````Y@0``)X#```)
M`P``A`4``%L$``!?`@``*P$```8```"B!```Y@(```D$````````B@4``(,#
M``!\`@``N@````````#5``````````````````````````````#D`0``4@``
M``````!>`@``'`$``)H$``#0!0```````-\```!J!```60(``'$#````````
M]0``````````````Z0,``$L#```R!```]@,``#8%````````&00``/8"``"?
M!0```````'L%``#_!0``UP0``%$!````````J00``&@%``![`@``(`0``$,"
M``"?`P``EP$````````]!0``3P0``.T%``!C`P``60,``%@#``!;`P``@0``
M`&L````L````)@$```L%``!M`0```````&L%````````E@$````````U`P``
M`````&T#``#$````XP,``+P$````````_@,````````J!```(````"X"````
M````*0(``"<"````````?@$``+<!``#D!0```````#`%````````G`,`````
M``!L`````````#D%``##`@``704```````!Y`P``=@,``'P```!]`@``X```
M`/D#````````3`4``+$%``"S!```I`,`````````````;@$``-L$```*````
M\0```+H%````````T0,`````````````]`0```````"'````J`0```8$````
M````)@(``,,!``!4````%@(``!8$``!?!0``)P```%0"``"^`0``A`0``&0%
M```+!@``!@(``%\!``!?!`````````````!S````$@4``)H#``"(!0``$@(`
M`$8```"S`@``*P,``````````````````&8```!1!0``N@0``,($````````
M'@```&D%``!6`P``AP(``.D```!\`0``O@4``.$%``"V`````````(H!``#'
M`@``?P(``#P#``#P````B@0``*0$```9`P``[@```%D%```?`@```````*,!
M``"]!```]@````````"2``````````````!@!```8P4`````````````````
M``````#U`P``?P$``",```!D`P``A`````````"O`````````%("``!6````
M`00```````!.`P``204``````````````````$`````X`P``#`(``#0#````
M`````````)<````E!0````````0%```M````.P4``#\```";!0``=@```",%
M```_`@``H`,``(4"`````````````.,"``#,`0```````,X!``#6!```V00`
M``````!%`0```````,D!``!2`P```````($#``#F``````````4&``#?!```
MZP```*`$`````````@0``!@#```````````````````H````'@4``.@"````
M````Z04``#H!``"^!```90,``$$!```V`0```````#P!``#<`0```````,4$
M```X!```\00``#\!```(`@``!P8``.T#```Y`P``$`$``!<!```W`P``\@``
M`#$!``!0!````P$``#H#`````````````&\%``"]`````````.P%``"H`P``
M`````/<$``";`P``-@,```````"\!0``?P,``(````".`P``_````)`$``#Q
M`0```````/H!````````0@0```````#=!0``.`4``%8"``"R`0```````*@%
M``#:````D00``*$"``"'!`````````D"````````Z@,``&@#``#1`@``<0$`
M`!T#````````P0,``'$%```#`P``&@4``,<#`````````````)X```#>!```
M=0```/T"``!2`0``HP4``-\!````````#@,``/$"```'``````````````"+
M`````````%H#``"U``````````````#O`0````````````!8`@``6@4``.,$
M```_!```$`0``)D```#/````.0(``!,%```I!0```````*$$```&!@``````
M`'P#``"W````%`$``'0!``!W!`````````````!&!0``,````!X"````````
MJ0,``.<#```+`@````````````!D`0````````0"`````````````!D!``#W
M`P``A@4``'$"```<`@``N@$``&(%``!"````<`$``-@%```Z!````````.X#
M``#R`@``_0$``',%``"N````:0$``"\!``!,`P``I0$``*@"````````Y`0`
M``L```!5`````````-@$```(`P``,P(```````!@!0``M@(```````")!0``
MM`0``!L$``!]!```3P```"$!```<````(@4``*L%````````/@```)T!``!Z
M`P``[`(``)@#```+`P``<P(``)("``#Y`@```````*<#```B`P``:0````,&
M``#@`@```````"P%```A`````````!``````````;P(``,P"```"!0``````
M``````"(`P``!P(```````"\`P``V`````8!```Q`````````&4!````````
MT@0``'P$``!I!```G@(``(\$``"&!```4`$```````#5`0````````````!B
M!````````%X!``"F`0``L`4````````````````````````Q`P``S```````
M``#7`P``=@4``-@"````````M00``/8%```<`P``7@,`````````````#`4`
M`",!```8`@``JP$``$0%``!A`@``O0(``)8#```M!0```````',!```R````
M+`$``#@````4!```6P$`````````````,@$``,L#``"Q``````````4$```4
M!0``````````````````$00```````#4`P``%00``&\#````````0@$``(,$
M``##!0``KP,``)4```"3`````````"0`````````@`(``&8$``!M!```````
M`"("``"A````/P4``-$%``"G!```"04``*P$``"(````5P```/,%````````
M8@$```8#``!?`P``#``````````;!0``;P```"X!``!^````/0(```````#`
M````^@````````#X`P``^00````````-`0``.`$``)T`````````L````(L%
M```L!```6@$``,0$``"[!0```````,T$``!*!```;`,``$@%````````%`(`
M`#0```!G`@``K@,```````"1!0``J`$```````#1`0``YP(``+D```"C`@``
M_0```(T!``!<`P```````-P$``"3!0``EP(``(4%``":`@``&`0``-,"````
M````UP(``$<%```J````PP,``-$$``#!`@``9P$``"\`````````.0$``(`$
M``"T`@``QP```-<!``#/!0``C``````````\!````````,`"``!D````!`$`
M``("``#]`P``+`(``%4#```$!```C@```-$```"F!0`````````````4`P``
MG````&`#``!<````#00``$$#````````>@4``````````````````(P#``!P
M!0``&@0``!\```#<````;P0``/`"````````9@$```````"=`P``%P0``$P!
M``!-````YP```)4$````````#P$`````````````=`````H"``"C````V04`
M``````!Q``````0``+4#```J`@```````)`%``"/`````````(\"```=`0``
M'P4```````"W`@```````$H!``"T`P``TP,``#L!``#T`0```````&`!``"D
M`0``$@,``#0%``"!`@``000``*4#``#E!0``5@$``*````!F!0```````"0%
M``#Q`P``NP,`````````````KP(```````!/`@``V@(``.<$`````@``````
M`"X#```(!```1@,``",$````````Z@0```````"$`0``X00``/P!````````
M30,``#T#``!^!```10,```<!``!%`@``"P$``%8%```.!```^`(````````#
M!0``\@,``%T$``#P`P``I@,``$\%``!=`P``&@,``$T$``"=!0``"@,``'4#
M```#````RP0```````#!!0``7P`````````=`@``P@,````````;`@``````
M`+(%``#(!0``T@$```````"3`0``KP0````````U````9`0``)8`````````
M`````+\!``!A`P``[P0````````S````[P(``%D$``"3`@``/@,``,8#``#Z
M`P``]P$``+(`````````50(``,@````4````H@,``'(`````````0P4``%H`
M`````````````+,%``!1`@``%P(```````""`P``5P0``$("````````EP0`
M`-L``````````0(``'$$``#=`@`````````````G!0``]P4``&L"```'!```
MT@,``)L```!E!`````````````#@`0```````,`%``!Z`0``QP$``$`"````
M`````````(<%`````````````$<"````````#`0``````````````````,X`
M````````8```````````````M0$``/($``"_`P``````````````````=P,`
M`%@!```^`0```````,T#`````````````!$!``"X`@``QP0``,T%````````
M`````-,%````````2`$``$4$``"0`@``@P4``*4$``!3````E`4``"X$```U
M!0``500``/L"````````X@(``+X#````````Z0(``,8%``",!0``,P,``/X"
M``!$`0```````-````"8`0``M04``(H#````````'@0``)8$````````M`4`
M`"$$``#=!````````)@"``````````````````!L!```Y00``(8```"-!```
M`````$$"```[`@``200``,H"``!A!```-0(``$T!```8````9@(```````"7
M!0``70(``,(%``#K`0```````.X"```%````O`$``,\"``"8````2````$H`
M```6!0``C`(```````"A`P```````!@%``"``0```0,`````````````````
M``````#*!```Y`(```(!``````````````````!V!```>0$``#<$``#.!```
MB@(``*T%````````1`0``,\$```1`@```````%4!``!]!0``=00``"<$``!<
M!0```````#$"````````B0````````!=`0``)0(``!\!``#:`P````````@`
M``````````````````"/!0```````&H!````````*P````````!Y````#`$`
M`$0#```"`P```````!T%``!`!````````*0"```P`P``F`0``%@```";!```
M`````/4"``!`!0``3@4``"8```"F!```8@(``"`!```Z`@```````+`#``!@
M`@```````(@!``#@!`````````````#\`@``0@,``!4"`````````````.X$
M``!M````!`,```````#?`P``N`4``$X!``#8`P``O0$````````1!0``JP(`
M`)0#``"I`````````-H!````````M@4``*`!````````````````````````
M<@$``"$%````````D`$````````I`0``K`4``!,"```)`0``A00``"8%``"'
M`P`````````````:````^P4``*P```"0`P``,P4``)X%```?`P``[`,``&4`
M``````````````````````````````````!N`P``[````(D#``!#!```````
M`+$"``"2`0``^@0```````#_`P```````-D````M`@```````+,```#A`@``
MO@(````````0`@``[0$```````#T!0```````&X$```\````OP(```0```#X
M````R04``'X"`````````````"H#`````````````(T#``!9````@@```-("
M``!0`@``:P0``)$```"6`@``004``$(%``#H!`````````````#``0``U`$`
M`(T```!X!0``I`4``&H"```%`@``E@4``%@$``#[!```$P$``'<%```9````
MY@$```````")!```]0$``#8````6````?P0```````#6`0```````-`#````
M````0P$``$L!```H!0``!P4``$8!``#9`0``&0(``),#````````R`0``*X$
M````("!4:&4@;6%I;&)O>"!T<F%S:"!I<R!A;')E861Y(&5M<'1Y+@`@)B,Q
M-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E
M<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`
M("AY97-T97)D87DI`"!A="``)60@)7,@86YD("5S`"5D+61A>2!F;W)E8V%S
M=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG97)P<FEN
M=``E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S
M(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L
M<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!H87,@8V%N8V5L;&5D("5S
M+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E<R!H
M87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S('-E
M;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:7,@<F5Q=6ER960`
M)7,@;6EN=71E<P`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RX`)7,@=&\@
M)7,@;V8@)7,`)7,@=VES:&5S('1O(&%D9"!T;R`E<RX`)7,@=VES:&5S('1O
M(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E<R!W:7-H97,@=&\@<F5C96EV92!T
M:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+@`E<R=S($%D9')E<W,@
M0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T
M`"<E<R<@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`G)7,G(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`)R5S)R!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"X`)R5S)R!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN`"<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN`"<E<R<@=V%S(&YO="!C<F5A=&5D.B`E<RX`+"!G=7-T:6YG("5S("5S
M`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U
M<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/&(^02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960Z/"]B/@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!32]030!!8F]U="!T:&ES(&5D:71O<@!!8F]U
M="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P="!R97%U97-T`$%C8V5P
M=&5D`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R
M9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@
M0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D
M9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R
M;W5P('1O("<E<R<`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G`$%D
M9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@
M<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D
M('1H:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`061D
M('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`G)7,G('1O('1H
M92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P
M(&EN9F]R;6%T:6]N.B`E<RX`061D960@)R5S)R!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`06MT:6]N($%I
M<G!O<G0`06QE>&%N9')O=7!O;&D@06ER<&]R=`!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E
M<FYA=&4@=&5X=#H`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M;F-H:6%L;W,@06ER<&]R=`!!;F1R879I9&$@06ER<&]R=`!!;F]N>6UO=7,@
M4')O>'D`06YS=V5R`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P
M;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R
M;W9E`$%P<FEL`$%R87AO<R!!:7)P;W)T`$%R8VAI=F4@1FEL92!3:7IE`$%R
M8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@9&5L971E("<E<R<@86YD(&%N>2!S=6(M9W)O=7!S/P!!<G0`07-C
M:6D@07)T`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN
M=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071H:6YA
M:2!!:7)P;W)T`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY
M('1O(&$@<F5Q=65S="!Y;W4@<V5N=`!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T96YD965S`$%T=')I8G5T97,`075G=7-T`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S
M.@!!=V%I=&EN9R!297-P;VYS90!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L
M;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA
M;64N`$)A<F4`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U
M;F0N`$)A<V5L:6YE`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I
M;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`
M0F]L9`!";W)D97)S`$)O=&@`0F]T=&]M`$)U;&QE=&5D($QI<W0`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`0U93`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L
M96YD87(`0V%L96YD87(@4W5M;6%R>0!#86QE;F1A<CH`0V%L;0!#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<P!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+@!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#
M96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@
M<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96YT97(`0V5R
M=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%I<B!0
M97)S;VX`0VAA;F=E`$-H86YG92!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&EO<R!!:7)P;W)T`$-H;V]S92!!
M<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA
M;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VAR>7-O=7!O;&D@06ER<&]R=`!#;&%S<R!D969I;FET:6]N(&]F("5S
M(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O
M=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@
M=&\@0V]N=&EN=64`0VQO<V4@2&5L<`!#;&]S92!(96QP(%=I;F1O=P!#;&]S
M92!7:6YD;W<`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#
M;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU
M;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N
M=`!#;VUM;VX@3F%M90!#;VUP86YY`$-O;7!L971E9`!#;VUP;W-E($UE<W-A
M9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I
M9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S
M+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O
M=70@;V8@9&%T92X`0V]N9FEG=7)A=&EO;B!N965D<R!U<&1A=&EN9RX`0V]N
M9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N;F5C=&EO;B!F86EL960N
M`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T(%-E87)C:`!#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`0V]N=&5N=',@;V8@)R5S)P!#;VYT96YT<R!O9B!T:&4@4D%2(&%R8VAI
M=F4`0V]N=&EN=64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H
M96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`G
M)7,G('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD
M(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S
M)RX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL
M(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R
M:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S)RX`
M0V]U;&0@;F]T(&UK9&ER("<E<R<N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC
M(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#
M;W5L9"!N;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E
M;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D
M:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E
M<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!R;61I<B`G)7,G+@!#;W5L9"!N;W0@<V%V92`E
M<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M("<E<R<N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS
M('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY
M('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`G)7,G+@!#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B`G)7,G.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E
M('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E
M<B`G)7,G.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T
M90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F
M;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R
M`$-R961I=',`0W5R<F5N="!0:&%S90!#=7)R96YT(%1I;64`0W5R<F5N="!5
M4DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R
M<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$1$`$1A:6QY`$1A=&$`1&%T851R
M964@0G)O=W-E<@!$871A8F%S92!Q=65R>2!F86EL960N`$1A=&4`1&%T92!2
M96-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C
M96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN9&5N
M=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A
M=6QT(%!E<FUI<W-I;VYS`$1E9F%U;'0@<&5R;6ES<VEO;G,`1&5F:6YI=&EO
M;G,`1&5L96=A=&4@<&]S:71I;VX`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@
M1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S
M86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G
M)7,G`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I
M='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W`$1E;&5T92!T:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`
M1&5L:79E<GD@=&EM90!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S
M8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO
M=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E
M8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R
M('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&\@
M;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M
M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O=VYL;V%D`$1O=VYL;V%D
M("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$5D:70`161I="!";&]C:P!%
M9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<`
M16QE9G-I<R!!:7)P;W)T`$5L96UE;G0N+BX`16UA:6P`16UA:6P@061D<F5S
M<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF
M:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L
M="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H
M="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9`!%;F0@>65A<@!%;FQA<F=E($5D
M:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@
M=&AE(&EM86=E(%523"!H97)E`$5R<F]R`$5R<F]R('-E;F1I;F<@<F5P;'DZ
M("5S+@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@
M)R5S)RX`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E
M9"`B0D5'24XB(&EN('1H92!L:6YE("5D+@!%>'!E8W1E9"`B14Y$.B5S(B!I
M;B!L:6YE("5D+@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`
M1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T
M;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@
M;6]V92!T;R`B)7,B+@!&86EL=7)E(&EN(&-H86YG:6YG('!A<W-W;W)D(&9O
M<B!U<V5R("5S(&9R;VT@8VQI96YT("5S+"!R96%S;VX@)7,`1F%I<@!&871A
M;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@
M`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I
M;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-
M86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&
M:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:7)S="!(86QF
M`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O
M<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F5E+T)U<WD@
M26YF;W)M871I;VX`1G)E92]"=7-Y(%)E<&QY`$9R964O0G5S>2!297%U97-T
M`$9R964O0G5S>2!297%U97-T(%)E<W!O;G-E`$9R;VT`1G)O;2!T:&4@`$9U
M;&P@1&5S8W)I<'1I;VX`1G5L;"!$97-C<FEP=&EO;CH`1G5L;"!-;V]N`$9U
M;&P@3F%M90!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'
M:79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=R965C90!'<F5E:R`H25-/
M+3@X-3DM-RD`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S
M="!B92!N;VXM96UP='D`1W)O=7`@<&5R;6ES<VEO;G,`1W)O=7!S`$=U97-T
M(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T8F]O:P!(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&5I9VAT`$AE;'``2&5L<"!U
M<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R86ML:6]N($%I<G!O
M<G0`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AI
M<W1O<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM96UP='D`2&]?;64`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!(;W)D92!,;V=I;@!(
M;W)D92!3>7-T96T`2&]R9&4@5VER96QE<W,`2&]R9&4@:7,@;F]T('!R;W!E
M<FQY(&-O;F9I9W5R960`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D
M9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I
M='D`2'5M:61I='DZ(`!(=6UO<FES=',`24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`24Y"3U@`
M25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N
M('9I;VQA=&EO;BX`25]N8F]X`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N<R!/
M;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G
M92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO
M860`26UA9V5S`$EM<&]R=`!);7!O<G0@17)R;W(Z(`!);7!O<G0L(%-T97`@
M)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26X@4')O
M8V5S<P!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@
M9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EV:61U86P@57-E
M<G,`26YF;P!);F9O<FUA=&EO;@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E
M<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@
M7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T
M(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS
M97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU
M;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S
M`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O
M<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@
M=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ
M`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T
M`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI
M='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A
M;&ED(')E8VEP:65N=#H@)R5S)P!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A
M;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV
M96YT;W)Y`$ET86QI8P!*86YU87)Y`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I
M9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2
M:6=H=`!+86QA;6%T82!!:7)P;W)T`$MA<G!A=&AO<R!!:7)P;W)T`$MA<W1O
M<FEA($%I<G!O<G0`2V5E<"!O<FEG:6YA;#\`2V5F86QH;FEA($%I<G!O<G0`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)K
M>7)A($%I<G!O<G0`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&
M:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`
M2V]S($%I<G!O<G0`2V]Z86YI($%I<G!O<G0`3&%?>6]U=`!,87)I<V$@06ER
M<&]R=`!,87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`
M3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,:6UE<FEC:P!,:6UN;W,@
M06ER<&]R=`!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI
M;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD
M97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE
M<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V%D:6YG+BXN`$QO8V%L
M('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O
M=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&9O<B!S;VUE(')E87-O;BX@
M36]S="!L:6ME;'D@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;V=O=70`3&]N9R!T
M97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@
M;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$U-`$UA9VEC`$UA:6P`36%I
M;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA;G5A;`!-
M87`@1&%T92!A;F0@5&EM92!&:65L9',`36%P($EM<&]R="!&:65L9',`36%R
M8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I
M=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-871C
M:&EN9R!F:65L9',`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-965T:6YG
M($-A;F-E;&QA=&EO;@!-965T:6YG($EN9F]R;6%T:6]N`$UE971I;F<@4')O
M<&]S86P`365E=&EN9R!297!L>0!-965T:6YG(%5P9&%T90!-965T:6YG(%5P
M9&%T92!297%U97-T`$UE;6)E<G,`365M;W,`365N=2!M;V1E.@!-97)G92!C
M96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF
M:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T
M:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971H;V0@)R5S)R!I<R!N;W0@9&5F
M:6YE9`!-971R:6,`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E
M;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-
M:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET
M(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES
M<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G
M92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO
M9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;VYT:"!6:65W`$UO
M;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N=&AL>2!%=F5N=',@3&ES=`!-;V]N
M(%!H87-E<P!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY
M(%!O<G1A;"!,87EO=70`37D@4W5M;6%R>0!->71I;&EN:2!!:7)P;W)T`$Y/
M+"!)($1O($Y/5"!!9W)E90!.86UE`$YE961S($%C=&EO;@!.971W;W)K`$YE
M=F5R`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@4&%S<W=O<F0`3F5W(%!A
M<W-W;W)D("AA9V%I;BD`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W('=I
M;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(%!A9V4`
M3F5X="!0:&%S90!.97AT(&]P=&EO;G,`3F\`3F\@879A:6QA8FQE(&-O;F9I
M9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T
M8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D
M('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&0@<&5R;6ES<VEO
M;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN`$YO(&-H:6QD
M<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!,
M1$%0(%!R969E<F5N8V5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,($-A=&5G;W)I97,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@4')E9F5R96YC97,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D
M:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L
M;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E
M<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P96YD:6YG
M('-I9VYU<',N`$YO('!R969E<F5N8V5S(&%R92!A=F%I;&%B;&4N`$YO(')U
M;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N(%!A
M<G1I8VEP86YT`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)T:&5R;B!(
M96UI<W!H97)E`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R
M>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T
M97,`3F]T97,@4W5M;6%R>0!.;W1E<R!I<R!A;B!A<'!L:6-A=&EO;B!W:&EC
M:"!A;&QO=W,@>6]U('1O(&-R96%T92!T:&4@8V]M<'5T97(@97%U:79A;&5N
M="!O9B!S=&EC:WD@;F]T97,N($YO=&5S(&-A;B!B92!C<F5A=&5D+"!M;V1I
M9FEE9"P@9&5L971E9"P@86YD('!R:6YT960N(%EO=2!C86X@86QS;R!S96%R
M8V@@;VX@>6]U<B!N;W1E<R!T;R!L;V-A=&4@:6YF;W)M871I;VXN(%-U<'!O
M<G0@9F]R(&EM<&]R=&EN9R!A;F0@97AP;W)T:6YG(&YO=&5S(&ES(&%L<V\@
M879A:6QA8FQE+@!.;W1E<SH`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M`$YO=&EC90!.;W1I9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+@!.
M;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F
M(&-O;'5M;G,`3G5M8F5R(&]F(&-O;'5M;G,@:6X@=&AE('-U;6UA<GD@=FEE
M=SH`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3V)J96-T`$]B:F5C="!#
M<F5A=&]R`$]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS`$]C=&%L`$]C=&]B
M97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!087-S=V]R9`!/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C
M:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E
M;0!/<'1I;VYA;"!087)T:6-I<&%N=`!/<'1I;VYS`$]P=&EO;G,@9F]R`$]P
M=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI
M<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N
M('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H
M97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4%](4"!3:&5L
M;`!0861D:6YG`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@9F]R('5S97(@
M)7,@9G)O;2!C;&EE;G0@)7,`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W
M;W)D<R!M=7-T(&UA=&-H+@!087-T($5V96YT<R!,:7-T`%!A<W1E`%!A<W1E
M(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M`%!E<FUI<W-I;VX@)R5S)R!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VX`4&5R;6ES<VEO;G,@9F]R`%!E<G-O;F%L($EN9F]R;6%T
M:6]N`%!E=',`4&AO;F4`4&AO=&]S`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E
M(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@
M25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R
M(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!N97<@<&%S<W=O<F0`
M4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A
M<V4@<')O=FED92!Y;W5R('!A<W-W;W)D`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!W:71H($!D;VUA
M:6X`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S
M92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@
M<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@
M<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@
M='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!L96%S92!V97)I9GD@>6]U
M<B!N97<@<&%S<W=O<F0`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C961E('EO=7(@<VEG;F%T=7)E('=I
M=&@@9&%S:&5S("@G+2T@)RD_`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S96YT871I;VYS`%!R97-S=7)E`%!R
M97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@4&%G90!0
M<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R
M;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X
M=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%%U97)Y
M`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286YD
M;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A
M;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A
M;"!6:65W.@!2969R97-H(%-U;6UA<GD@5FEE=SH`4F5G97@`4F5L871I;VYS
M:&EP($)R;W=S97(`4F5M87)K<P!296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!2
M96UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M(&UY
M(&-A;&5N9&%R`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`
M4F5M;W9E('5S97(Z("5S`%)E<&QY(%-E;G0N`%)E<&QY('=I=&@@3F]T(%-U
M<'!O<G1E9"!-97-S86=E`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT
M(#(@;6]N=&AS+@!297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN`%)E<&QY.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"`G)7,G(&YO="!S
M<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)R5S)R!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M)7,G(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G8F%S961N)R!N;W0@<W!E8VEF:65D(&EN
M('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D871A8F%S
M92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`G9&%T86)A<V4G(&YO="!S<&5C:69I960@:6X@8V%T
M96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G9&%T86)A<V4G(&YO
M="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T
M:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=H;W-T<W!E8R<@;F]T('-P
M96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=H;W-T<W!E8R<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I960@
M:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A
M<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN('!R
M969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N
M;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I
M97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C
M:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!C
M871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=T86)L92<@;F]T
M('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G=6ED)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("=U:60G(&YO="!S<&5C:69I960@:6X@
M<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S97)N86UE
M)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE9"!I;B!C871E
M9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U<V5R;F%M92<@;F]T
M('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"!&:65L9`!297%U:7)E9"!087)T:6-I<&%N=`!297-E=`!297-E="!0
M87-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O
M($]P=&EO;G,`4F5T=7)N('1O(&UA:6P`4F5U;FEO;@!2979E<G0@0V]N9FEG
M=7)A=&EO;@!2:&]D97,@06ER<&]R=`!2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O
M7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O=&%T92`Q.#``4F]T871E($QE9G0`
M4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O
M=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS
M(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N
M`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!354-#15-3`%-?44P@4VAE
M;&P`4V$`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]S($%I<G!O<G0`4V%T96QL
M:71E(%!R;W9I9&5R`%-A=F4`4V%V92`E<P!3879E("<E<R<`4V%V92!/<'1I
M;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z("<E<R<N`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E
M87)C:"!-86EL`%-E87)C:"!297-U;'1S`%-E;&5C="!&:6QE<P!396QE8W0@
M82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N
M97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X=&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@
M=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E;F0@4')O
M8FQE;2!297!O<G0`4V5N9"!335,`4V5N<V]R.B``4V5P=&5M8F5R`%-E<FEA
M;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@
M=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V
M97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3970@
M>6]U<B!P<F5F97)R960@9&ES<&QA>2!L86YG=6%G92X`4V5T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T
M=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!3:&]P<&EN
M9P!3:&]R="!3=6UM87)Y`%-H;W)T(%-U;6UA<GDZ`%-H;W5L9"!A8V-E<W,@
M:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U
M<&QO860`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:6=N('5P`%-I9VX@=7`@:68@
M;F]T(')E9VES=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`
M4VEZ90!3:VEP($UA:6YT96YA;F-E`%-O;64@;V8@2&]R9&4G<R!C;VYF:6=U
M<F%T:6]N(&9I;&5S(&%R92!M:7-S:6YG.@!3;W)T(&]R9&5R('-E;&5C=&EO
M;@!3;W5D82!!:7)P;W)T`%-O=7)C92!A9&1R97-S`%-O=71H97)N($AE;6ES
M<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W
M965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG
M`%-P86-I;F<@86YD('!A9&1I;F<`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S
M`%-T87)T`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T
M;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R
M:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@
M6T-34UT`4W4`4W5B9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!3=6)J96-T
M`%-U8FIE8W0@4'5B;&EC($ME>2!);F9O`%-U8FUI=`!3=6)M:71T960@<F5Q
M=65S="!T;R!A9&0@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L
M;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3
M=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@)R5S)R!T;R!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`G
M)7,G+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`G)7,G(&9R;VT@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("<E
M<R<`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U;6UA<GD`4W5N(%)I<V4`4W5N
M(%-E=`!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`
M4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)N86UE`%-Y;F,@;&]G
M(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`
M5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A;F%G
M<F$@06ER<&]R=`!487)G970Z`%1A<VMS`%1A=&]I($%I<G!O<G0`5&5L97!H
M;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!4
M96UP97)A='5R93H@`%1E;7!L871E("<E<R<@;F]T(&9O=6YD+@!496UP;&%T
M92!!9&UI;FES=')A=&EO;@!496YT871I=F5L>2!!8V-E<'0@<F5Q=65S=`!4
M96YT871I=F5L>2!!8V-E<'1E9`!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S
M(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S
M<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C86QE;F1A
M<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE
M<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T
M:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P
M96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&5V96YT(&AA<R!B965N(&%D9&5D
M('1O('EO=7(@8V%L96YD87(N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L
M;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R
M,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C
M875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@
M8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U
M;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V
M97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T
M:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E
M96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL
M>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I
M=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UA:6QB;W@@=')A
M<V@@:7,@86QR96%D>2!E;7!T>2X`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H
M:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@
M<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES
M(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`
M5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S
M92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!M97-S86=E('1Y<&4@
M*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R96=I<W1R
M>2!I<R!H;W<@2&]R9&4@87!P;&EC871I;VYS(&9I;F0@;W5T(&AO=R!T;R!T
M86QK('1O(&5A8V@@;W1H97(N(%EO=2!S:&]U;&0@;&ES="!A;GD@:6YS=&%L
M;&5D($AO<F1E(&%P<&QI8V%T:6]N<R!T:&%T('EO=2!H879E(&AE<F4N`%1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I
M9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W
M(&1O97,@;F]T(&5X:7-T+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y
M;W5R('1A<VML:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO
M="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O
M<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"X`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@
M=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE;65S(&1I<F5C=&]R>2`G)7,G
M(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4
M:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L
M9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E
M;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG
M("<E<R<@=&\@=&AE('-Y<W1E;2X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG("<E<R<@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES
M=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@)R5S
M)SH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+@!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S
M+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R
M97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5S<V%L;VYI:VD@06ER<&]R=`!4:&ES($E-05`@<V5R
M=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&%C
M=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C=&EO;B!I<R!N;W0@>65T
M(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET
M86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH
M='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F
M:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@
M;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE
M(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@
M9FEL92!C;VYT<F]L<R!T:&4@9VQO8F%L('-E="!O9B!-24U%(&1R:79E<G,@
M9F]R('1H92!(;W)D92!F<F%M97=O<FLL(&%L;&]W:6YG(&%P<&QI8V%T:6]N
M<R!T;R!M86ME('5S92!O9B!P<F]G<F%M<R!S=6-H(&%S(&5N<V-R:7!T(&]R
M(&US=V]R9'9I97<@=&\@<F5N9&5R(&-O;G1E;G0@:6YT;R!(5$U,(&9O<B!V
M:65W:6YG(&EN(&$@8G)O=W-E<BX`5&AI<R!F:6QE(&-O;G1R;VQS('1H92!S
M='EL97-H965T('1H870@:7,@=7-E9"!T;R!S970@8V]L;W)S(&%N9"!F;VYT
M<R!F;W(@=&AE($AO<F1E(&9R86UE=V]R:R!A;F0@86QL(&%P<&QI8V%T:6]N
M<R!T:&%T(&1O(&YO="!P<F]V:61E('1H96ER(&]W;B!S971T:6YG<RX`5&AI
M<R!F:6QE(&UA<',@9FEL92!E>'1E;G-I;VYS('1O(&QO9VEC86P@34E-12!T
M>7!E<RP@96YA8FQI;F<@2&]R9&4@87!P;&EC871I;VYS('1O(&9I9W5R92!O
M=70@:&]W('1O(&AA;F1L92!S;VUE(&-O;G1E;G0@<W5C:"!A<R!E;6%I;"!A
M='1A8VAM96YT<R!O<B!#5E,@8VAE8VMO=71S+@!4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&ES('1H92!M
M86EN($AO<F1E(&-O;F9I9W5R871I;VX@9FEL92X@270@8V]N=&%I;G,@<&%T
M:',@86YD(&)A<VEC(&ET96US('1H870@87!P;'D@=&\@=&AE(&-O<F4@9G)A
M;65W;W)K(&%N9"!A;&P@2&]R9&4@87!P;&EC871I;VYS+@!4:&ES(&UE<W-A
M9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@
M=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N`%1H:7,@<')O8FQE;2!R97!O<G0@=V%S(')E8V5I=F5D(&9R;VT@)7,N
M(%1H92!U<V5R(&-L:6-K960@=&AE('!R;V)L96T@<F5P;W)T(&QI;FL@9G)O
M;2!T:&4@9F]L;&]W:6YG(&QO8V%T:6]N.B5S(&%N9"!I<R!U<VEN9R!T:&4@
M9F]L;&]W:6YG(&)R;W=S97(Z)7,`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE
M('-E;&5C=&EO;@!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O
M9V=L92!(5$U,(%-O=7)C90!4;VUO<G)O=P!4;W``5&]P(&9R86UE("A?=&]P
M*0!4<F%N<VQA=&EO;G,`5')I<&]L:7,@06ER<&]R=`!4<G5E(&]R(&9A;'-E
M`%1U`%1Y<&4@;6ES;6%T8V@N`%1Y<&4@>6]U<B!C:&]I8V4Z(`!54DP`55),
M(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='D`56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RX`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E9VES=&5R('!R969E<F5N8V5S(&EN('-E<W-I
M;VXN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O
M;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`
M56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(&5N9"!O9B!F:6QE+@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B``56YF:6QE9`!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z
M("5S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R
M<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N
M;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R
M('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC
M86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O
M(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E
M="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E
M<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D871E('5S97(`57!D871E
M9"`G)7,G+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D
M960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N
M`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<V4@
M0W5R<F5N=#H@)7,`57-E($1E9F%U;'0@5F%L=64`57-E(%-33`!5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES
M=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`
M57-E<B!P87-S=V]R9"!C:&%N9V4`57-E<B!P97)M:7-S:6]N<P!5<V5R;F%M
M90!5<V5R;F%M92`G)7,G(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E
M<FYA;64Z(`!5<V5R<P!5<V5R<R!I;B!T:&4@<WES=&5M.@!61E,@9&ER96-T
M;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%R:6%B;&4`
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E
M<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@
M2&EG:`!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A
M<R`E<P!6:65W(&5V96YT`%9I97<@=&%S:P!6:7-I8FEL:71Y`%9I<VEB:6QI
M='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!787)N:6YG`%=E`%=E
M96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!A<'!L:6-A=&EO;B!S:&]U;&0@2&]R9&4@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN
M<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7
M:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE
M(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F
M('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6YD('-P965D(&EN(&MN
M;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W1S`%=O<FL`5V]R:R!!
M9&1R97-S`%=O<FL@4&AO;F4`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I
M;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@
M06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE
M<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EE87)L>0!997,`665S+"!)
M($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A
M=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+CQB<B`O/E1H86YK('EO=2!F;W(@=7-I;F<@
M=&AE('-Y<W1E;2X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),
M('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N
M('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T
M92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M
M86EL($%D9')E<W,`66]U<B!%;6%I;"!!9&1R97-S.@!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO;B`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO
M=7(@<&%S<W=O<F1S(&1O(&YO="!M871C:`!9;W5R(')E;6]T92!S97)V97)S
M.@!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1
M=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML
M:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T1E;&5T92!2;W<`7T=R
M;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@
M;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E
M;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E
M<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!F:6QE
M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`:6UM961I871E`&EN;&EN
M90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)
M4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`
M;F]T97!A9`!P97)C96YT`'!I>&5L<P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E
M;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S:R!L:7-T`'1R87-H`'1Y<&4@=&AE
M('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S
M97(@<V5L96-T`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4Z(#,N
M,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#(M,3$M,#<@,3(Z,#8K,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`U+3`T+3(V(#$Q.C$S*S`R,#`*3&%S="U4
M<F%N<VQA=&]R.B!+;VYS=&%N=&EN;W,@0RX@36EL;W-I<R`\:VUI;&]S:7-`
M>6%H;V\N8V]M/@I,86YG=6%G92U496%M.B!'<F5E:R`\9&5V0&QI<W1S+FAO
M<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3<*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@."UB:70*`"`@QR#C\>'L[.'T[^CU\=_DX2`GZMSD[_(G(.7?
M[>'I(-[DYR#<Y.7IX2X`("8C,34Q.R`E<R#%W^WAZ2#G(//TZ>/LWB#MX2#C
MW^WO]>T@[^D@Z^7I]._U\>/?Y?(@\_7M]-[QY_/G\B#P[_4@Y=_MX>D@Y?#I
MZ^7C[-WMY?(@\.'QX>K<]/DN`"`H\/'I[2#A\/P@)7,@Y^S=\>7R*0`@*,KK
MY>GDWR#P\?SSXN'SY_(@)7,I`"`H\^4@)7,@Y^S=\>7R*0`@*//>[.7QX2D`
M("CA_?'I[RD`("CWZ.7R*0`@\_3I\B``)60@)7,@ZN'I("5S`"5D+>SE\><@
M\/'\XNOE^.<`)7,@+2#3Y^SEW_GSYP`E<RW$Z>'WY=_QZ?/G`"5S(,3AZO3U
MZ^GJ_"#A\._T_?#Y[.$`)7,@R^7I]._U\>/?Y?(@T_7M]-[QY_/G\B`M(,7P
MZ>+EXN'?^?/G`"5S+=#A\>'LY?3Q[_#OW^?SYP`E<R#%X^/QX?;>`"5S(,_Q
M[^D@]_'>\^?R`"5S(-[DYR#U\-SQ]^7I+@`E<R#SY2`E<R`E<P`E<R#AZO7Q
M_NCGZN4@)7,N`"5S(.'PW.WTY_/E(//E(.7Q_O3G[.$@Y.GAZ.7SZ>S\].?T
MX?(N`"5S(.'PW.WTY_/E(//TY^T@\/'\\^KKY_/G(./IX2`E<RX`)7,@\^'R
M(-WS].7IZ^4@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(N`"5S(.7?[>'I
M(.'PX>GT[_WLY>WO`"5S(.OE\/3<`"5S(//A\B#FWO3G\^4@\.OG\>_V[_'?
MY?(@Y.GAZ.7SZ>S\].?TX?(N`"5S(.;>].?SY2#TY^T@\.'Q[_7SW^$@\^'R
M(//TZ?(@)7,N`"5S(/GR("5S(.'P_"`E<P`E<R#E\.GH]>SEWR#TY^T@\/'O
M\^C>ZN<@\_3O("5S+@`E<R#E\.GH]>SEWR#MX2#SX?(@Y>WG[.7Q_O/EZ2#C
MZ>$@)7,N`"5S(.7PZ>CU[.7?(.WA(.O<XN7I(/3I\B#TY>OE]?3AW^7R(/#K
MY_'O]N_QW^7R(./IX2`E<RX`)7,G<R#$Z>7UZ/7M\^GOX_'<]N_R`"5S)W,@
MQ^SE\>_K_./I[P`E<W,@T^?LY>GY[.'TW/'I[P`E<W,@R]_S].$@Q?'CX?/I
M_NT`)R5S)R#DY>T@Y=_MX>D@W>/J]?'G(.7PZ>OOX]XN`"<E<R<@Y.7M(-WW
MY>D@\?7H[.GS].7?(//T[R!R96=I<W1R>2#TY_(@Y?;A\>SOX][R($AO<F1E
M`"5S(.'MX?#A\>'S]-STY_(@Y.7MY/'IZM[R(.3O[-[R(.3E[2#B\=WHY^KE
M+@`G)7,G(/#Q[_/TW>CGZN4@\_3I\B#O[-SDY?(@\_7S]-[LX?3O\BX`)R5S
M)R#P\>_S]-WHY^KE(//TZ?(@W.3EZ>7R(/3O]2#S]?/TWNSA]._R+@`G)7,G
M(.3E[2#DY^SI[_7QX][HY^KE.B`E<RX`+"!G=7-T:6YG("5S("5S`"P@[.7T
MX>+KY_3>(.'P_"`E<R#SY2`E<P`M+2#E\.GK[^/>("TM`#$R^?'G(.SO\?;>
M`#(T^?'G(.SO\?;>`#(T(/[QY?(`/&(^T.'Q[_7SZ=SS].?JY2#=[>$@\^_B
MX?'\(.O<Z._R.CPO8CX`T.'Q[_7SZ=SSZ.?JY2#J\=_SZ>SO(.O<Z._R`,'P
MX>GTY=_TX>D@Y.?L_//I[R#JZ^7IY-\@4$=0(./IX2#TY^T@ZO'U\/3OX_'<
M]N?SYR#E[?SR(.SG[?WLX?3O\BX`P?#AZ?3EW_3AZ2#DY^S\\^GO(.KKY>GD
MWR!01U`@X^GA(.7PZ>+EXN'?^?/G(.7M_/(@]?#OX^7C\>'L[-WM[_4@[.?M
M_>SA]._R+@#!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!01U`@ZNOE
MZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA(.'P[^KQ]?#T[^/QX?;>\^7T
MY2#=[>$@[-[M]>SA+@#!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!0
M1U`@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA(/7P[^/QW/CE].4@
M^.?VZ>'JW"#=[>$@[-[M]>SA+@#!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y
M\.GJ_"!3+TU)344@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA(.'P
M[^KQ]?#T[^/QX?;>\^7TY2#=[>$@[-[M]>SA+@#!\.'I].7?].'I(.3G[/SS
MZ>\L(/#Q[_/Y\.GJ_"!3+TU)344@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@
MX^GA(.WA(/7P[^/QW/CE].4@^.?VZ>'JW"#=[>$@[-[M]>SA+@#!\.'I].7?
M].'I(.3G[/SSZ>\@ZNOEZ>3?(%,O34E-12#CZ>$@].?M(.KQ]?#T[^/QW/;G
M\^<@Y>W\\B#LY^W][.'T[_(N`/#L+^SL`-#E\=\@X?7T[_T@]._U(,KEZ>SE
M[>_C\=SV[_4`T.7QWRXN+@#!\/SK]?3O(/3=Z^_R`,'P_.OU].<@S-WSYP#!
M\._D[_?>(.'I]-[LX?3O\@#%X^GMY2#A\._DY>KT_`#'(/#Q_//BX?/G(.'P
M[_'QW_;HY^KE(.KA]-P@].<@Y.?LZ>_U\>/?X2!61E,@ZN'TX>O\X^_U+@#'
M(/#Q_//BX?/G(.'P[_'QW_;HY^KE(.KA]-P@].<@Y.?LZ>_U\>/?X2!61E,@
MX?'WY=_O]2X`ROGDZ>K\\B#+[^/A\>GA\^SO_0#/(.OOX^'QZ>'S[/SR(/#<
MX_GSY2X`RN'TX>/QX?;>`,7MW?'CY>GE\@#0\>_SZ-[JYP#0\>_SZ-[JYR#U
M\._O[-SDX?(`T/'O\^C>ZN<@W.3EZ>'R(/7P[^_LW.3A\B`H8VAI;&0@<&5R
M;6ES<VEO;BD`T/'O\^C>ZN<@Y>3^.@#0\>_SZ-[JYR#-W>'R(,_LW.3A\@#0
M\>_SZ-[JYR#MW>'R(-SDY>GA\@#0\>_SZ-[JYR#U\._O[-SDX?(@\_3O("<E
M<R<`T/'O\^C>ZN<@W.3EZ>'R("AP97)M:7-S:6]N*2#U\._O[-SDX?(@\_3O
M("<E<R<`T/'O\^C>ZN<@[=WO]2#W\=[S].<Z`-#Q[_/HWNKG(//TWNOG\@#0
M\>_SZ-[JYR#MW>_U(.S=Z^_U\@#0\>_SZ-[JYR#FY?WC[_7R`-#Q[_/HWNKG
M(/3O]2`E<R#S].\@[.7M[_T@]._U($UO>FEL;&$`T/'O\^C>ZN<@X?7T[_T@
M\_3O(.?LY?'OZ_SCZ?P@[._U`-#Q[_/HWNKG(//T[R#$Z>7UZ/7M\^GOX_'<
M]N\Z`-#Q[_/HWNKG(//T[R#$Z>7UZ/7M\^GOX_'<]N\@[._U`-#Q[_/HWNKG
M(/?QWO/TYP#0\>_S]-WHY^KE("<E<R<@\_3O(//]\_3G[.$L(.'KZ]P@Y.7M
M(.SP_/'E\^$@[>$@\/'O\^C=\_D@\_7L\.OG\?GLX?3IZMWR(/#KY_'O]N_Q
MW^7R`-#Q[_/TW>CGZN4@)R5S)R#S].\@\_WS].?LX2X@S/#O\>7?].4@[>$@
M\_7MY.7HY=_TY2#T_O'A+@#'(/#Q[_/HWNKG(/?QY_/T_NT@W??EZ2#A\.7M
MY?'C[_#OZ>?HY=\N`,3IY?WH]>WSYP#$Z>7UZ/7M\^GOX_'<]N_R`,3IX??E
MW_'I\^<@+2#$_O/TY2#DZ>KAZ?[LX?3A(//E(-SKZ^_U\B#W\=[S].7R`,3I
MX??EW_'I\^<`P>7Q[^OI[-WMX?(@P>KTW^_U`,'E\>_KZ>S>[2#!Z^7NX>WD
M\>_]\._KY_(`V.7UY/[M]>SO`,7UZ/7C\=SL[.GSY0#%]>CUX_'<[.SI\^<Z
M`,_KX0#/Z^_I(._I(-WCZO7Q[^D@]_'>\_3E\@#/Z^7R(._I(,_LW.3E\@#/
MZ^$@].$@Y.GJX>G^[.'TX0#*X>D@[^D@]-WS\^7QZ?(@*#0I(/#KY?7QW?(`
MS>$@Y?#I]/'=\._M].'I(/#OZ^OA\.O=\B#DZ>7UZ/WM\^7I\@#-X2#E\.GT
M\=WP[^WTX>D@\?7H[-_SY>GR(/3A[NGM[^SI[-WM^>T@Z^GS]/[M.P#'Y.<@
M]?#<\??EZ0#%[>'KZ^'J].GJWB!)35-0(,7?\^_D[_(`Q>WAZ^OAZO3IZOSR
M($E-4U`@ROGDZ>K\\@#%[>'KZ^'J].GJ_"!)35-0(+SM[^SA(-?QWO/TYP#%
M[>'KZ^'J].GJWB#DZ>7]Z/7M\^<@96UA:6P`Q>WAZ^OAZO3IZMP@\/'\]/7P
MX0#%[>'KZ^'J].GJ_"#JY=_LY>WO.@#/\=_S].?JY2#LW^$@[.<@Y?#I]/'E
M\/SLY>WG(/3I[-XN`,'E\>_KZ>S=[>'R(,'C]]_AZ^_U+@#!Y?'OZ^GLW>WA
M\B#![>3QX>+?Y.'R+@#![?[M]>SO\B#$Z>'L[.7S[^OAXN?TWO(@*%!R;WAY
M*0#!\-SM].?SYP#%]N'Q[._CW@#+W_/TX2#%]N'Q[._CWO(`QR#E]N'Q[._C
MWB#EW^WAZ2#=]._I[.<N`,7VX?'L[^/>(.KAZ2#S].$@Y>[A\?3^[.7MX2#J
M[^GM_/?QY_/TX0#%X^KQW^WY`,'P\=_KZ>_R`,'E\>_KZ>S=[>'R(,'QW.[O
M]0#,W>/EZ._R(.'Q]^7?[_4@X?'WY>GOZ-WTY_/G\@#/[>_LX2#A\??EW^_U
M(.'Q]^7IZ-WTY_/G\@#%W_/TY2#SW^/O]?'G(./IX2#TYR#DZ>'C\>'VWB#T
MY_(@X=_TY_/G\B#U\._C\>'VWO(@X^GA("5S(#\`Q=_S].4@\]_C[_7Q[^D@
M_/3I(.C=Z^7TY2#MX2#DZ>'C\=SXY?3E("<E<R<@ZN'I(/SKY?(@].GR(/7P
M[^_LW.3E\C\`U-WW[><`05-#24D@U-WW[><`S>$@YN?TY=_TY2#E\.GBY>+A
MW_GSYR#P\=_M(.'P_"#JW.CE(.7MW?'CY>GA(.3IX??EW_'I\^?R.P#![=SH
MY?/G(//TY^O^[0#!Y?'OZ^GLW>WA\B#!Z.?M_NT`U.\@\_7MY^SLW>WO(.7?
M[>'I(-WMX2#A\??EW^\@Y^SE\>_K[^/?[_4@\^4@X?#<[?3G\^<@X>GTWNSA
M]/SR(//A\@#0\>_S\-SHY>GA(.3IX>/QX?;>\B#LYR#U\.'QZO3>\B#O[-SD
MX?(N`-#Q[_/PW.CEZ>$@Y.GAX_'A]M[R(.SG(/7PX?'J]._](.3IZN'I_NSA
M]._R+@#0\>_S\-SHY>GA(.7PY>[E\>/A\]_A\B#LYR#U\.'QZO3O_2#DZ>KA
MZ?[LX?3O\BX`T/'O\_#<Z.7IX2#E\.7NY?'CX?/?X?(@[.<@]?#A\>KT[_T@
MY.GA[._I\>'S[-WM[_4N`-#A\>7U\>GSZOSLY>WOZ0#)Y.G\].?TY?(`P?WC
M[_7S]._R`,<@X?7HY>WTZ>KO\._?Y_/G(.'PW?3U]^4`QR#A]>CE[?3IZN_P
M[]_G\^<@X?#=]/7WY2X@)7,`QR#A]>CE[?3IZN_P[]_G\^<@X?#O\?'?]NCG
MZN4@X?#\(/3O[2!2041)55,@<V5R=F5R+@#'(.'UZ.7M].GJ[_#OW^?SYR#S
M]._M($944"U397)V97(@X?#=]/7WY2X`Q.GAZ-WSZ>SA(-#EY-_A.@#![>'L
MW>WO[?3A\B#A\-SM].?SYP#5\/SBX>CQ[P#7\?[LX2#U\/SBX>CQ[_4`R]SH
M[_(@2V5R8F5R;W,MZOGDZ>K\\BX`R]SH[_(@2V5R8F5R;W,MO.WO[.$@U_'>
M\_3G+@#!Y.7I[P#/(.K]\>GO\B#JX?3<Z^_C[_(@X_'A]NGJ_NT@)R5S)R#D
MY>T@XO'=Z.?JY2X`PN'SZ>K>(./QX>SLW@##Y>W=Z.OIX0#4[R#T[-[LX2`B
M)7,B(/3G\B#E]N'Q[._CWO(@(B5S(B#DY>T@XO'=Z.?JY2X`T?7H[-_SY>GR
M(/3LWNSA]._R`-3]\._R(/3LWNSA]._R`+CM]._MX0"\\>GA`,KAZ2#TX2#D
M_>\`RN'T_O3A].\`R]_S].$@[.4@].7KY=_E\@#3Y^SEW^$@Y.GA[>_LWO(@
M0U),`,'Q]^7?[R#JY>GLW>WO]2#W^?'I\^S=[>\@[.4@ZOSL[.$@*$-64RD`
MR>3I_/3G].7R(,KEZ^G^[2XN+@#'[.7Q[^O\X^GO`-#E\=_KY_CG(,?LY?'O
MZ_SCZ>_U`,?LY?'OZ_SCZ>\Z`,?QY>S?X0#!Y/WMX?3G(.<@X?'WZ>KO\._?
MY_/G(/3O]2#J^>3IZN_](.'U]/SLX?3A+"#E\.GJ[^GM^>W>\_3E(.SE(/3O
M(.3IX??EZ?'I\_3>`,'D_>WA].<@YR#S_>WDY?/G(.SE(/3O[2!)34%0+5-E
M<G9E<CH@)7,`P>K]\?GSYP#!ZOWQ^?/G(,'MX?;O\=SR(-#Q[^+KWNSA]._R
M`,'D_>WA].<@YR#DZ>'C\>'VWB#T[_4@X?'WY=_O]2`B)7,B+@#$Y2#B\=_S
MZOD@\/'O\_GQZ>W\(/;<ZN7K[R`H=&5M<"!D:7(I+@#!Y/WMX?3G(.<@\_7M
MW??EZ>$@]_GQW_(@].?M(/#A\=SLY?3Q[R`B=&%R9V5T1FEL92(N`,'D_>WA
M].<@YR#DZ>'C\>'VWB#T[_4@]N'JW>OO]2`B)7,B+@#!Y/WMX?3G(.<@Y.GA
MX_'A]MXL("5D(/7P]MSJY>OO\B#U\-SQ]^7I+@#!Y/WMX?3G(.<@Y?#A[>'T
MX>[I[?SLY_/G+"#O(.'QZ>CL_/(@]/GM(.7CX_'A]O[M(/#O]2#D_O/A].4@
MX^GA(.7PX>WA].'NZ>W\[.?SYRP@Y.7M(/3AZ?'IW.;EZ2#LY2#T[^T@X?'I
MZ.S\(/3Y[2#A\._HY^KE]>S=[?GM+@#$Y2#L\._Q_B#MX2#D\>_L[^OOX][S
M^2#LWNWU[.$@\_3O[2#A\>GH[/P@\._U(._QW_/A].4N`,7PZ>KE]N'KW^3A
M`,KA].?C[_'?Y?(@ZN'I(,7TZ>K=].7R`,KI[>?T_"#4Y^O=]OGM[P#)Y.G\
M].?TY?(@RN7KZ>_]`,/=[.GS[.$@RN7KZ>_].@#)Y.G\].?TY?(@RN7KZ>_]
M`,3IW.KE[>\@RN7KZ?[M.@#*Z>WG]/P@U.?KW?;Y[>\`RMWM]/'O`,OE\/3O
M[-WQY>GE\B#0Z?/T[_#OZ>?TZ>KO_0#0[^OI].GJWB#0Z?/T[_#OZ>?TZ>KO
M_0#0\?SEY/'O\@#!Z^OAX]X`P>OKX>/>(.KYY.GJ[_T`P>OKW.[TY2#T[R#\
M[>_LX2#JX>D@].<@Y.GE_>CU[?/G(/#O]2#HX2#BZ]WP[_7M(/STX>T@Y.GA
MXMSF[_7M(-X@X?#A[?3O_>T@\^4@[.?M_>SA]-P@\^'R`-?A\>'J]-[QX?(`
MN.OEX_?O\B#S_>WDY?/G\BXN+@#3Y^SEZ?[S].4@].\@].7T\>'C^>W?Y.GO
M(./IX2#O\._IX>3>\._TY2#E\>/A\]_A*.7R*2#HW>OE].4@[>$@Y>KTY>OE
M\_3O_>T@X?7TWB#TYR#S].GC[-XN`,'E\>_KZ>S=[>'R(-??[_4`Q?#IZ]WN
M].4@Q?;A\>SOX]XZ`,7PZ>O=[O3E(.KYY.GJ_`#%\.GKW>[TY2#\[>_LX2#W
M\=[S].<`Q?#IZ]WN].4@[.GA(.7MW?'CY>GA.@#%\.GKW>[TY2#P^?(@Z.$@
MY>SVX>W?YN_M].'I(._I(.?LY?'O[.?MW^7R.@#%\.GKW>[TY2#T_?#O(.O?
M\_3A\B`HX^GA(/3A[NGM[^SG[-WMY?(@Z]_S].7R*0#!Y?'OZ^GLW>WA\B#7
M\?7S[_WP[^OG\@#$Y>T@XO'=Z.?JY2#O\>GS[/SR(.KKW//G\B#T[_4@)7,N
M`,KAZ-SQZ?/E`,KAZ.'QZ?/L_/(@Y?3IZN7T_NT@*'1A9W,I($U3+4]F9FEC
M90`GP>3EZ>'S[.$G(-?QWO/TYSH@)7,`RN'HX?'I\^S\\B#7\=[S].<`RN'H
MX?'I\^S\\B#DY>3O[-WM^>T@]_'>\_3G`,K<[?3E(.KKZ>H@X^GA(//U[=WW
MY>GA`,KKY=_SZ>SO(,+OWNCEZ>'R`,KKY=_SZ>SO(-#A\=SH]?'O]2#"[][H
MY>GA\@#*Z^7?\^GL[R#0X?'<Z/7Q[_4`P>WAY-_PZ_GSYR#0Z^7U\>GJWO(@
MS/#<\>'R`,'MX>3I\.OY[-WMX2#0Y?'IZ/[QZ>$`U_'^[.$`Q?#IZ]WJ].?R
M(-?Q_NSA]._R`,7PZ>OOX]X@U_'^[.'T[_(`T_3>Z^7R.@#4W_3K[^D@T_3G
MZ_[M`$-O;6EC<P#%[?3OZ]X`RMWK]?;O\B#%[?3OZ_[M`-/W_.OI[P#*[^GM
M_""\[>_LX0#%].'I\>7?X0#/Z^_JZ^?Q_NCGZN4`T_WMZ.7SYR#,Y^W][.'T
M[_(@*"5S*0#5\._K[^/I\_3=\@#3]>WHWNKE\@#$Z>'V[_'=\B#0X?'A[.7T
M\>_P[]_G\^?R`,7PZ>OOX]WR(./IX2#S]>/W\>_MZ?/L_"#LY2!01$%S+"#=
M[O7P[>$@U.?KW?;Y[>$@ZN'I($]U=&QO;VLN`$1I92!+;VYF:6=U<F%T:6]N
M(&UU<W,@86MT=6%L:7-I97)T('=E<F1E;BX`QR#PX?'A[.7T\>_P[]_G\^<@
M]_'EZ=SFY?3AZ2#E[>?LW?'Y\^<N`-#A\>'LY?3Q[_#OW^?SYR`E<P#%\.GB
MY>+AW_GSYR#*^>3IZN_]`,<@\_WMY.7SYR#A\-WT]??E+@#'(//][>3E\^<@
MX?#=]/7WY3H@`,'Q[>?SYR#S_>WDY?/G\B#A\/P@].\@Y.?L_//I[R#E[O7P
MY_'E].?TWB#JZ^7IY.G^[2X`P?'MY_/G(//][>3E\^?R(.'P_"#T[R#DY^S\
M\^GO(.7N]?#G\>7TY_3>(.KKY>GDZ?[M+B#+_./O\B`Z("5S("@E<RD`QR#S
M_>WDY?/G(.SE(/3O($944"U397)V97(@X?#=]/7WY2X`P>WAYM[TY_/G(,7P
MX?;>\@#/Z2#E\.'VW?(@\/'O\_3=Z.?JX>T@Y?#I]/7W_O(@\_3O(,3IY?7H
M]>WSZ>_C\=SV[R#SX?(N`-#E\>GE]_SLY>WA(/3O]2`G)7,G`-#E\>GE]_SL
MY>WA(/3Y[2#A\??EW_GM(%)!4@#3]>W=]^7IX0#![?3IX_'A]MX`P>WTZ>/Q
MX?;>(,7PZ>OOX][R`,'D_>WA].<@YR#J\?7P]._C\=SVY_/G(/3O]2#LY^W]
M[.'T[_(@[.4@4$=0+@#!Y/WMX?3G(.<@]?#OX_'A]MX@]._U(.SG[?WLX?3O
M\B#LY2!01U`N`,'D_>WA].<@YR#J\?7P]._C\=SVY_/G(/3O]2#LY^W][.'T
M[_(@[.4@4R]-24U%+@#!Y/WMX?3G(.<@]?#OX_'A]MX@]._U(.SG[?WLX?3O
M\B#LY2!3+TU)344N`,3E[2#L\/SQY?/A(.WA(/#Q[_/HW?/Y(/3G[2#E\.'V
MWBX@)7,`P>3][>'TYR#G(//][>3E\^<@[.4@].\@3$1!4"U397)V97(N`,'D
M_>WA]._R(.\@W>OEX^_R(/7P[^OOW_#O]2X@)7,`P>3][>'TYR#G(//][>3E
M\^<@\_3O[2#E[O7PY_'E].?TWB`G)7,G(/?QY_/I[/#OZ?[M].'R($944#H@
M)7,`P>3][>'TYR#G(.3G[.GO]?'CW^$@Z]_S].'S(.3IX>WO[-[R+B`E<P#!
MY/WMX?3G(.<@X?#OZO'U\/3OX_'<]N?SYR!01U`@Y.7D[^S=[?GM+@#!Y/WM
MX?3G(.<@X?#OZO'U\/3OX_'<]N?SYR!3+TU)344@Y.7D[^S=[?GM+@#!Y/WM
MX?3G(.<@Y.GAX_'A]MX@Y?#A]M[R+B`E<P#!Y/WMX?3G(.<@Y.GAX_'A]MX@
MZ]_S].'R(.3IX>WO[-[R+B`E<P#!Y/WMX?3G(.<@Y.GAX_'A]MX@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@)R5S)R`N`,3E(.SP[_'^(.WA(.3IY?7J\>GMWO/Y
M(/3G(.3IY?WH]>WSYR#T[_4@\.'QX>O>\/3G+@#!Y/WMX?3G(.<@\.O>\>?R
M(/#Q_//BX?/G(/3O]2#$Z>7UZ/7M\^GOX_'<]N_U+@#!Y/WMX?3G(.<@\.O>
M\>?R(/#Q_//BX?/G(/3G\B#KW_/TX?(@Y.GA[>_LWO(N`,'D_>WA].<@YR#P
MZ][QY_(@\/'\\^+A\^<@Z]_S].'R(.'P_"#KW_/TY?(@Y.GA[>_LWO(N`,'D
M_>WA].\@].\@]OSQ]/GLX2#S]/'A].?CZ>K>\B`B)7,B+@#!Y/WMX?3G(.<@
MY.?LZ>_U\>/?X2#VX>K=Z^_U("(E<R(N`,'D_>WA].<@YR#A[=SJ].?SYR#D
MY^S\\^GO]2#JZ^7IY.GO_2#A\/P@]._M(.7N]?#G\>7TY_3>(,3G["[*Z^7I
MY.G^[2X`P>3][>'T[R#T[R#<[>_IX^SA("5S+@#!Y/WMX?3O(/3O(-SM[^GC
M[.$@(B5S(B#CZ>$@Y>/C\>'VWBX`P>3][>'T[R#T[R#<[>_IX^SA(/3O]2#L
MW?'O]?(@Q.GA]^7?\>GSY_(@)7,`Q.7M(.SP[_'^(.WA(.'M[]_N^2#T[R#V
MW.KEZ^\@(B5S(BX`Q.7M(.SP[_'^(.WA(.3IX>+<\_D@)7,N`,'D_>WA].<@
MYR#A\??IZN_P[]_G\^<@]._U(.KYY.GJ[_T@X^GA(/3O[2#AZ?3O_>SE[>\@
M]_'>\_3G+B#*W/#OZ>$@WB#\Z^7R(._I(.OE\/3O[-WQY>GE\B#DY>T@Y=_M
MX>D@\_GS]-WR+B#.X>WAY._JZ>S<\_3E(-X@Y?#IZN_I[?GMWO/TY2#LY2#T
M[R#DZ>'WY>DM\>GS]-X@X>T@]_'EZ=SSY?/HY2#PY?'I\_/\].7QYR#B[][H
MY>GA+@#!Y/WMX?3G(.<@X>W<ZO3G\^<@R]_S].'R(,KA[?SM^>T@T/'\\^+A
M\^?R("A!0TPI`,'D_>WA].<@YR#A[=SJ].?SYR#$Z>7UZ/7M\^GOX_'<]N_U
M+B`E<P#!Y/WMX?3G(.<@X>W<ZO3G\^<@R]_S].'R(,3IX>WO[-[R+B`E<P#!
MY/WMX?3G(.<@X>W<ZO3G\^<@R^GS]/[M(,3IX>WO[-[R+B`E<P#!Y/WMX?3G
M(.<@X>W<ZO3G\^<@]/GM(.GDZ>_TWO3Y[2#T[_4@Y>[U\.?QY?3G]-X`P>3]
M[>'TYR#G(.7PX>WA]N_QW"#Q]>CLW_/E^>TN`,'D_>WA].<@YR#DZ>'C\>'V
MWB#VX>K=Z^_U("AR;61I<BD@(B5S(BX`Q.4@[/#O\?X@[>$@X?#OZ.?JY?WS
M^2`E<R#Q]>CLW_/EZ?(N`,3E(.SP[_'^(.WA(.K<[?D@Y?;EY/'IZOP@X>WT
MW^/QX?;O(/3Y[2#Q]>CLW_/E^>TN`,3E(.SP[_'^(.WA(.K<[?D@Y?;EY/'I
MZOP@X>WTW^/QX?;O(/3Y[2#Q]>CLW_/E^>TZ("5S`,3E(.SP[_'^(.WA(.'P
M[^CGZN7]\_D@\/'\X_'A[.SA(.7MY^S=\?GSY_(@\_3O("<E<R<N`,3E(.SP
M[_'^(.WA(.'P[^CGZN7]\_D@Y?;EY/'IZOP@X?'WY=_O(/'UZ.S?\^7Y[2`E
M<RX`Q.4@[/#O\?X@[>$@X?#OZ.?JY?WS^2#T[R#A\??EW^\@\?7H[-_SY?GM
M("5S+B#,\._QY=_TY2#EW_3E(.WA(/?QY_/I[._P[^G>+?/E].4@[.GA(.'P
M_"#TZ?(@Y?#IZ^_CW?(@X^GA(.WA(.'P[^CGZN7]\^7TY2#PW_/Y(//T[R`E
M<R#>(.'M].GC\=SX].4@[.4@].\@]]WQZ2#T[^T@ZO[DZ>KA(/#?\_D@\_3O
M("5S+@#!Y/WMX?3G(.<@X>WAYM[TY_/G(//T[^T@Y>[U\.?QY?3G]-X@3$1!
M4"X`Q.4@[/#O\?X@[>$@X?#O\_7MY-WS^2`B)7,B+@#$Y2#L\._Q_B#MX2#E
M[>?LY?'^\_D@].?M(.7PX?;>+B`E<P#$Y2#L\._Q_B#MX2#E[>?LY?'^\_D@
M].<@R]_S].$@Q.GA[>_LWO(N("5S`,3E(.SP[_'^(.WA(./QW/CY(/3I\B#Q
M]>S?\^7I\B#CZ>$@)R5S)SH@)7,`Q.4@[/#O\?X@[>$@XO'^(/3G(/#KY?7Q
MZ>K>(.SPW/'A(/3O]2!-;WII;&QA+B#"Y>+AZ?GHY=_TX>D@_/3I(.7?[>'I
M(.'M[^GJ]-XN`,3E(.SP[_'^(.WA(.3^\_D@\_3O(/?QWO/TYR`G)7,G(/3A
M(/#A\>'JW/3Y(.3IZN'I_NSA].$@\_3O(/;<ZN7K[R`G)7,G.B`E<P#,Y?3Q
MY^S=[>\@ZN7?[.7M[P#7_O'A`-#O\>7?Y?(`Q.?LZ>_U\>/?X0#$Y^SI[_7Q
MX]_A(.7M_/(@\_7MY-WS[._U`,3G[.GO]?'CW^$@[.GA\B#MW>'R`,3G[.GO
M]?'CW^$@]?#O]N'JW>OY[0#%[N_U\^GOY._TWO/EZ?(@Q.?LZ>_U\>/O_0#!
M\>GH[/SR(-#I\_3Y].GJWO(@RMSQ].'R`,7U]^'QZ?/TW^7R`-3QW??O]?/A
M(-;<\^<`U/'=]^_U\^$@_O'A`-3O(/3QW??O[2!54DP@Y=_MX>D`U/'=]^_M
M(,KAZ?'\\@#4\=WW[_7SX2#S]>WHWNKG.B``U/'=]_GM(//T_>L`T.'QX>SE
M]/'O\._?Y_/G(.3IX>3IZN'SZ?[M(/#O]2#EZO3EZ^_][?3AZ2#JX?3<(/3G
M[2#EW_/OY.\@)7,N`,'P[^KO\-X`P?#OZN_PWB#E\.GK[^/>\@#,S`#'[.7Q
MWO/IX0#$Y>3O[-WMX0#%[/;<[>GSYR`H0G)O=W-E<BD@1&%T851R964`QR#A
M[>'FWO3G\^<@\_3G(,+<\^<@Q.7D[^S=[?GM(.'PW?3U]^4N`,?LY?'O[.?M
MW^$`Q^SE\>_LY^W?X2#PX?'AZ^'BWO(`Q?#IZ^_CWB#'[.7Q[^SG[=_A\@#'
M[-WQX0#$Z>'C\>'VWB#3]-[KY_(`Q.7JW>SB\>GO\@#$Y>KAY.GJ[]\@X?'I
MZ.SOWP"X]^_U[2#A\>WGZ.7?`,SEW_GSYR#0Y?'IZ/GQW^_U`-#Q[^KAZ._Q
MZ?/LW>WO`-#Q[^7PZ>OEX^S=[>\@U_'^[.$`T/'OY?#IZ^7C[-WMYR#4X?7T
M_/3G].$`T/'OZN'H[_'I\^S=[>7R(,7N[_7SZ>_D[_3>\^7I\@#0\>_JX>CO
M\>GS[-WMY?(@Q>[O]?/I[^3O]-[SY>GR`,_QZ?/L[]\`R-WSYR#A[?3I\/'O
M\_[P[_4`P>WTZ?#Q[_/Y\.?LW>WO`,3IX>/QX?;>`,3IX>/QX?;>(,_LW.3A
M\@#$Z>'C\>'VWB#%[N_U\^GOY/STY_/G\@#$Z>'C\>'VWB#JX>D@Y>KJW>WY
M\^<@[.?M]>S<]/GM`,3IX>/QX?;>(.KEZ^GO_0#$Z>'C\>'VWB#3]-[KY_(`
MQ.GAX_'A]MX@]?#<\??O[?3O\B#E[>'KZ^'J].GJ[_T@\/'O]/WP[_4`Q.GA
MX_'A]MX@Y>[O]?/I[^3O]-[SY?GM(./IX2`G)7,G`,3IX>/QX?;>(.7N[_7S
MZ>_D[_3>\^7Y[2#CZ>$@)R5S)R#JX>D@ZMSHY2#U\.\MY>[O]?/I[^3\].?S
MYSL`Q.GAX_'A]MX@\_3>Z^?R`-#Q[^7PZ>OEX^S=[><@U.'U]/STY_3A`,3I
MX>/QX?;>(/3QW??O]?/A\B#S]-[KY_(`Q.GAX_'A]MX@]/'=]^_U\^'R(./Q
MX>SLWO(`Q.GAX_'A]MX@X?7TWO(@].?R(.7N[_7SZ>_D_/3G\^?R(.KAZ2#J
MW.CE(/7P[RWE[N_U\^GOY/STY_/G\CL`Q.GAX_'<]N?JY2#T[R!S971U<"!U
M<&=R861E('-C<FEP="`G)7,G+@"_\>$@W/;I[N?R`,'Q[>?SYR#AZ?3>[.'T
M[_(`P?'MY_/G(.'I]-[LX?3O\B#CZ>$@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\
M].?TX?(`T.7QZ>/QX?;>(/3O]2#0\>_BZ][LX?3O\@#0Y?'IX_'A]MX`R^7P
M]._LW?'EZ>7R("CE\-_SY_(@ZN'I(//T[R#A\??EW^\@ZN'TX>/QX?;>\B#T
M[_4@2&]R9&4I.@#/Z2#KY?#T[^S=\>7IY?(@W??O]>T@ZN'TX>/QX?;EWR#C
MZ>$@]._M(.3IX??EZ?'I\_3>+@#![=SP]/7NYP#3Y^SEW^\@Q/'O\^G<\@#3
MY^SEW^\@Q/'O\^G<\B#CZ>$@].?M(/3EZ^7U].'?X2#^\>$Z(`#3Y^SEW^\@
MQ/'O\^G<\CH@`,KA].7]Z/7M\^<@X?#\(.'QZ?/TY?'<(/#Q[_(@].$@Y.7N
MZ=P`RN'TY?WH]>WSYR#A\/P@].$@Y.7NZ=P@\/'O\B#TX2#A\>GS].7QW`#*
MX?3<Z^_C[_(`Q>SVW.WI\^<@_O'A\B#SY2`R-/GQYR#L[_'VWCL`Q?#IZ^_C
MW?(@Q>SVW.WI\^?R`,7L]MSMZ?/G(/#Q[^+KW?CE^>T@*%1!1BD`S._Q]MX@
MQ>SVW.WI\^?R`,7MY^S=\?GSYR#$Z=STX>[G\@#,YR#DZ>'C\=SVY>GR`,SG
M[2#E\.GWY>GQWO/E].4@[>$@X>WOW^[E].4@X?#E]>CEW^'R(/3O(.'Q]^7?
M[R!M86EN=&5N86YC92YP:'``T.7QZ=WWY>D@YR#P\?[TYR#C\>'L[-X@[^W\
M[.'TX2#PY>3?^>T[(,'M(.WAZ2#T\^7JW/'E].4@X?7T_#H`RN'TW>+A\^SA
M`,KA]-WBX?/LX2`E<P#*X?3=XN'S[.$@]._U(.'Q]^7?[_4@\.'QX>S=]/'Y
M[2#SX>T@4$A0+7-C<FEP="X`R]_S].$@RN'TX?'<ZO3G\@#6W/'LX>KA+>WA
M\>KY].GJW`#%\.7NY?'CX?/?X0#%\.7NY?'CX?/?X2!";&]C:P#%\.7NY?'C
MX?/?X2#/[-SDX?(`Q?#E[N7QX^'SW^$@Q>[O]?/I[^3\].?SY_(`Q?#E[N7Q
MX^'SW^$@Q>[O]?/I[^3O]-[SY?GM`,7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>
M\^7Y[2#CZ>$@)7,`Q?#E[N7QX^'SW^$@Y?#IZ^_C_NT@X^GA.@#%\.7NY?'C
MX?/?X2#%[N_U\^GOY._TWO/E^>T@X^GA("5S`,7PY>[E\>/A\]_A(,7N[_7S
MZ>_D[_3>\^7Y[2#CZ>$@)R5S)P#!Y?'OZ^GLW>WA\B#%Z^7U\]_MX?(`T_3O
MZ??EW^\N+BX`P>OKY^OOX_'A]M_A`,3IY?WH]>WSYR!%;6%I;`#'(.3IY?WH
M]>WSYR!%;6%I;"#P\=WPY>D@[>$@].'I\>G<YN7I+@#,WNWU[.$@[.4@\?7H
M[-_SY>GR`,'I\^C>[.'TX0#*Y>W\(.S>[?7LX2X`Q.7M(.7PZ?/T\=SVY^KA
M[2#!\._TY>O=\^SA].$N`,'DY>GE\B#S]>WHWNKE\B#A[>'FWO3G\^?R`,7M
MY?'C[_#OW^?SYR#EZ?/AX_GCWO(@Y>GJ_.WY[2#A\.\@4&AO=&\@0V%L;&5R
M:65W(//T[R#JY=_LY>WO.P#-X2#E[>7QX^_P[^GGZ.7?(/3O(.SE[>_](.SE
M(.3E[M\@ZNOIZCL`U-WK[_(`N/3O\B#4W>OO]?(`S.7CW>WH]?/G(,KEZ>SE
M[>_C\=SV[_4`Q/[S].4@[.GA(.7Q_O3G\^<@X?/VX>OEW^'R+"#G(._P[]_A
M(.CA(//A\B#FY_3GZ.7?(.'M(/?QY>GA\^CEWR#MX2#AZ^O<[N4M].4@]._M
M(.KYY.GJ_"#SX?(L(/`N]RX@)]#OZ?P@Y=_MX>D@].\@_.WO[.$@]._U(.KA
M]._IZNGDW^_U(//A\CLG.@#$_O/TY2#TYR#S_>WDY?/G(/3G\B#EZ>K\[>'R
M(.7D_@#+W.CO\@#+W.CO\B#A\._S]-WKZ^_M].'R(.'PW.WTY_/G.B`E<P#+
MW.CO\B#LY2#LWNWU[.$@96UA:6PN`,O<Z._R(./QW/;O[?3A\B`B)7,B+@#%
MZ.WIZOP`Q?7Q_O#G`,K<Z.4@,34@Z^7P]-P`RMSHY2`R(,OE\/3<`,K<Z.4@
M,S`@Y.7U].7Q_.OE\/3A`,K<Z.4@-2#KY?#TW`#*W.CE(/;O\=P@\._U(.SP
MX=_MY?3E(//TY^T@]?#G\>7SW^$`RMSHY2#LZ?/>(/[QX0#*W.CE(.OE\/3\
M`-#A\>'DY>GC[.'TZ>K=\B#TZ>S=\CH`Q>KTW>OE\^<`Q?#=ZO3A\^<`Q?#=
MZO3A\^<@T.OE]?'IZM[R(,SPW/'A\@#![>'LY>W\[.7M[R`B0D5'24XB(//T
MYR#C\>'L[-X@)60N`,'MX>SE[?SLY>WO(")%3D0Z)7,B(//TYR#C\>'L[-X@
M)60N`,'MX>S=[>_M].'M("<I)P#![>'LW>WO[?3A[2#A\.O>(.O=[N<@WB#S
M]>WHWNKG(.'MX>;>].?SY_(@\^4@Y>GSX>/YX^GJW`#'[.7Q[^SG[=_A(,O>
M[N?R`,7JZ-WTY_(`U_'^[.$@\/'O\^K>[>GO]0#1]>CLW_/EZ?(@X^GA($94
M4"!U<&QO860`P?#O]/7WW^$@ZN'TW"#TY^T@\/'O\_#<Z.7IX2#A[=SJ].?S
MY_(@]/GM(/#Q[_3I[-[SY?GM+@#!\._T]???X2#S_>WDY?/G\B#S]._M(.3I
MX>KO[.GS]-X@RN'TX>O\X^_U+@#!\._T]???X2#S_>WDY?/G\B#S]._M(%--
M0BU397)V97(N`,'P[_3U]]_A(.'M].GC\>'VWO(@X?#\("(E<R(N`,'P[_3U
M]]_A(.'M].GC\>'VWO(@\^4@(B5S(BX`P?#O]/7WW^$@Y.?LZ>_U\>/?X?(@
M\_WMY.7SY_(@4T%33"X`P?#O]/7WW^$@[.7TX?;O\=SR(//E("(E<R(N`,'P
M[_3U]]_A(.KA]-P@].?M(.'KZ^'CWB#J^>3IZN_](./IX2#T[^T@]_'>\_3G
M("5S(.'P_"#T[R#S].'H[/P@)7,L(.O\X^_R("5S`,'?Z/'I[_(`T._K_2#S
M[^+A\?P@R]SH[_(Z`-;!S@#6Y>+Q[_7<\>GO\@#$Z=SHY?/G(./IX0#$Z=SH
MY?/G(./IX3H@`,O?X^7R(.+Q[_?=\@#+W^/E\B#WZ>_M[_#T_O/EZ?(`T-_M
MX>KA\B#0Y>3?[_4`P?'IZ.S\\B#A\??EW^_U.B`E<R#A\??EW^\`P?'IZ.S\
M\B#A\??EW^_U.B`E<R#A\??EW^$`Q.GA]^7I\>GS]-[R(,'Q]^7?^>T`O.WO
M[.$@P?'WY=_O]0#%\.GK[^/>(,'Q]^7?[_4`)\'MW>+A\^SA)R#!\??EW^_U
M`"?![=WBX?/LX2<@P?'WY=_O]2#DY>T@]?#O\_3G\=_FY?3AZ2X`UM_K]/'A
M`-#Q_O3O(,SI\_P`T/'^].\@U-WTX?'T[P#3].'HY?'\\B#K_./O\@!&;&EP
M`$9L;V%T`,_LW_?KYP#/(/;<ZN7K[_(@)7,@Y.7M(/7PW/'WY>D`U_'^[.$@
MX_'<[.SA]._R`-3Q[_;>`,/IX2!"<F]W<V5R<RP@\._U(.3E[2#U\._S].?Q
MW^;O]>T@Y>GJ_.WE\@#.Y??<\^'TY2#T[^T@ZOGDZ>K\(//A\CL`UOSQ[.7R
M`-#Q_.+KY?CG`-3]\._R(-#Q_.+KY?CG\@#0\>_BZ]WXY>GR`-#Q[^+KW?CE
MZ?(@,@!&;W)U;7,`T/'O^>C>\^7I\@#0X0#0Z^'?\^GA`-#KY_'O]N_QW^7R
M(,3IX>CE\^GL_/3G].'R`,'PW.WTY_/G(,3IX>CE\^GL_/3G].'R`,'?].?L
MX2#$Z>'HY?/I[/STY_3A\@#!\-SM].?SYR#SY2#AW_3G[.$@Q.GAZ.7SZ>S\
M].?TX?(`P?#\`,'P_"#T[R``P>WAZ_7TZ>K>(-#E\>GC\>'VW@#![>'K]?3I
MZMX@T.7QZ>/QX?;>.@#0Z][QY_(@T^7KWNWG`-#KWO'E\B"\[>_LX0!'86QL
M97)Y(.'P_"#TY^T@[_#OW^$@Z.$@\.'?\>WO[?3AZ2#OZ2#EZ>K\[>7R`$=A
M;&QE<GDZ`,SIZO'\(+SM[^SA`,/E[>GJW?(@Q?#IZ^_CW?(`S.7TW.+A\^<`
MQ>OKW.3A`,7KZ^?MZ>K<("A)4T\M.#@U.2TW*0#$Z>'WY=_QZ?/G(,_LW.3Y
M[0#4X2#O[?SLX?3A(/3Y[2#O[-SD^>T@Y.7M(/#QW?#EZ2#MX2#EW^WAZ2#J
MY>W<`,7N[_7SZ>_D[_3>\^7I\B#/[-SD^>T`S^S<Y.7R`,GDZ?STY_3E\B!'
M=65S=`#)Y.G\].?TY?(@1W5E<W0`1W5E<W1B;V]K`-3O(//]\_3G[.$@X?7H
MY>WTZ>KO\._?Y_/G\B!(5%10(.3E(.+QW>CGZN4N`+[X[_(`PN_>Z.7IX0#"
M[][HY>GA(./IX2#TYR#W\=[SYR#T[_4@ZN7I[.7M[^/QW/;O]0#"[^?H_/(`
MQ^SI\_;AW_'I[P#!Y?'OZ^GLW>WA\B#'\>'JZ^7?[_4`Q>3^(.7?[>'I(.<@
MX?'WWB#T[_4@X?'WY=_O]3H`V.?KW`#'(.7CX_'A]MX@Z?/T[_'IZN_](.3E
M[2#P\=WPY>D@[>$@Y=_MX>D@ZN7MW@#!\??IZMX@T^7KW^3A`,'Q]^GJWB#3
MY>O?Y.$`Q.GE_>CU[?/G(-/PZ?3I[_T`U.?KW?;Y[>\@T_#I].GO_0#!\??I
MZMX@T^7KW^3A`,7?\^_D[_(@\_3G[2#5\.?QY?/?X2#'R^7J]/'O[>GJ[_T@
MU.'W]>3Q[^SEW^_U`-/]\_3G[.$@)TAO<F1E)P`G2&]R9&4G(,'S_?'LX?3G
M`-3O(/#Q_./QX>SLX2`G2&]R9&4G(.3E[2#=]^7I(/'UZ.SI\_3EWR#S^?/T
MW`#/\>GF_.WTZ>_R(,KA[?SMX?(`S_'IYOSM].GO("?CW>SI\^SA)P#/\>GF
M_.WTZ>\Z`-#Y\B#VZ-SSX?3E(.7D_CL@*/#A\>'JX>O^(.WA(/3O(.'MX?;=
M\>7TY2#S].\@Y.GA]^7I\>GS]-XA*0#0_//E\B#S]-[KY?(@Z-WKY?3E(.WA
M(.7M[_#OZ=[SY?3E.P#0_//A(/#EY-_A("CS]-[KY?(I(.7?[>'I(.7JY=\[
M`-#\\^7R(./QX>SLW?(@Z-WKY?3E(.WA(.7M[_#OZ=[SY?3E.P#5X_'A\]_A
M`-7C\>'SW^$Z`-?I[_7L[_'?\_3A\@#'(,3G[.GO]?'CW^$@X_'A[.SA]._H
M]?'?Y.'R($E-05`@X?#=]/7WY3H@)7,`QR#DZ>'C\>'VWB#C\>'L[.'T[^CU
M\=_DX?(@24U!4"#A\-WT]??E.B`E<P#'(,3G[.GO]?'CW^$@\.7I\>_QZ?/L
M_NT@*'%U;W1A*2#C\>'L[.'T[^CU\=_DX?(@24U!4"#A\-WT]??E.B`E<P#%
MZ?/E\??\[.7MX0!)4"W$Z>7]Z/7M\^<`25`MQ.GE_>CU[?/G(.3E[2#EW^WA
MZ2#DZ>'HW?/I[.<N`$E0+<3IY?WH]>WSYR#LYR#E\.GT\>7P]-X@[-WSX2#S
MY2!#2412+4)L;V-K+@#*Z^7?Y/GLX2W0X?'AXM_A\^<@25`N`,7I\^7Q]_SL
MY>WA`,7I\^'C^>/>(,/QX>SLWO(@T/'I[0#,_.WO(,7IZN_MW^3IX0#%Z>KO
M[=_DZ>$@X^GA("5S`,7IZN_MW^3IX2#JX>D@RN7?[.7M[P#/[>_LX2#TX?7T
M_/3G].'R.@#![2#DY>T@Y>SVX>W?YN7TX>D@\_GS]-PL("5S(./IX2#MX2#A
M[>_?[N7I(//E(.W=[R#PX?'<Z/7Q[RX`P>T@Y.4@XNO=\.7TY2#JX>W=[>$@
MY>GJ[^W?Y.GO(/?QY_/I[._P[^G^[?3A\B#T[^T@26YT97)N970@17AP;&]R
M97(L(-_S^?(@\/'=\.7I(.WA(/3SY>K<\>7TY2#EY/X@X^GA(.WA(.'PY>WE
M\>/O\._IWO/E].4@].<@Y.GA]MSMY>GA(%!.1RX`P>T@XNO=\.7TY2#A]?3\
M(/3O(.S>[?7LX2#W^?'?\B#EZ>K\[>$L(.<@Y>GJ_.WA(/#O]2#HW>OE].4@
M[>$@ZN'TY>+<\^7TY2#DY2#L\._QY=\@[>$@Y>SVX>WI\^CEWR#A\/P@]._M
M(&)R;W=S97(@\^'R+@#0\>_E\.GSZOSPZ?/G(,7IZOSMX?(Z`%523"#%Z>K\
M[>'R`,7IZOSMX2#A\/P@1V%L;&5R>0#%Z>K\[>$@X?#\($=A;&QE<GDZ`,'P
M[_/T[^O>(,7IZOSMX?(`Q>GJ_.WE\@#%Z?/AX_GCW@#+W.CO\B#JX?3<(/3G
M[2#%Z?/AX_GCWCH@`,7I\^'C^>/>+"#"WNSA("5D`-#EY-_O(/#O]2#EZ?/>
M]^CG.B`E<P#0Y>3?X2#P[_4@Y>GSWO?HY_/A[3H`T^4@Q?#E[N7QX^'SW^$`
MQ>GSX>/YX]X@P_'A[.S>\B#,Y?3<`,3\Z.?JY2#KW.CO\B#J^>3IZOSR(.7M
MW?'CY>GA\BX`R]SH[_(@_.WO[.$@]_'>\_3G(-XOZN'I(.KYY.GJ_/(N`,O<
MZ._R(/SM[^SA(/?QWO/TYR#>(.7MX>OKX>KTZ>K>(.3IY?WH]>WSYRX@SN'M
MX>3OZNGLW//TY2#>(.7PZ>KOZ>WY[=[S].4@[.4@].\@Y.GA]^7I\>GS]-X@
MX^GA(/#E\>'I]-WQ^2#B[][HY>GA+@#!_>[G\^<@T.7QZ>CY\=_O]0#)Y.GA
MW_3E\>_I(-?QWO/TY?(`T.OG\>_V[_'?Y?(`T.OG\>_V[_'?Y?(`Q>GSX>/Y
MX]X@T_3>Z^?R(,SE]-P`Q>GSX>/YX]X@Q>GJ_.WA\@#%Z?/AX_GCWB#0W^WA
MZN$`Q>GSX>/YX]X@\_WMY.7SY_(@5V5B`,7I\^'C^>/>(-/TWNOG\B#0\>GM
M`,7I\^'C^>/>(.W=X?(@\_3>Z^?R(.SE]-P@].?M(/3QW??O]?/A`,7I\^'C
M^>/>(.W=X?(@\_3>Z^?R(/#QZ>T@X?#\(/3G[2#T\=WW[_7SX0#%Z?/AX_GC
MWB#MW>'R(./QX>SLWO(@[.7TW"#TY^T@]/'=]^_U\^$`Q>GSX>/YX]X@[=WA
M\B#C\>'L[-[R(.SE]-P@].?M(/3QW??O]?/A`,7IX>/YX]X@\.'QX>/QW/;O
M]2#LY?3<(/3O[2#T\=WW[^WTX2#J_.SB[P#%Z?/AX_GCWB#PX?'AX_'<]N_U
M(/#QZ>T@]._M(/3QW??O[?3A(.K\[.+O`,7I\^'C^>/>(.7MX>OKX>KTZ>KO
M_2#P\>_T_?#O]0#$_O/TY2!E;6%I;"#DZ>7]Z/7M\^<@\_3G[2#O\._?X2#E
M\.GH]>SEW_3E(.WA(/#A\>'KW.+E].4@].\@[=WO(//A\B#J^>3IZOPZ`,7I
M\^'C^>/>(.KEZ^GO_2#LY?3<`,7I\^'C^>/>(.KEZ^GO_2#P\>GM`,7I\^'C
M^>/>(//TWNOG\B#LY?3<`,7I\^'C^>/>(//TWNOG\B#P\>GM`,7I\^'C^>/>
M(.SG[?WLX?3O\@#%Z?/AX_GCWB#PX?'AX_'<]N_U(.SE]-P`Q>GSX>/YX]X@
M\.'QX>/QW/;O]2#P\>GM`,7I\^'C^>/>(./QX>SLWO(@[.7TW`#%Z?/AX_GC
MWB#C\>'L[-[R(/#QZ>T`Q>GSX>/YX]X@].?R(.'PX>GT[_WLY>WG\B#A\-SM
M].?SY_(@\_3G[2#E\?[TY_/G(.'S]N'KY=_A\CH`Q>GSX>/YX]XOQ.G\\>CY
M\^<@Q>GJ_.WA\@#%Z?/AX_GCWB_$Z?SQZ/GSYR#3_>WDY?/G\@#,YR#E\.'Q
MZMWR(/7P_.OOZ?#O(./IX2#A\._S]._KWB#S].<@Z]_S].$@Y.GA[>_LWO(N
M`,SG(.7PX?'JW?(@]?#\Z^_I\.\N`,'JW?'AZ>_R`,O?\_3A(,'JY?'AW_GM
M`,7PZ>O=[N'TY2#+W.CO\B#%[=WQX^7IX2#CZ2<@X?7T_"#T[R#S]?/TX?3I
MZOPN`,'J]?'O(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@#,YR#=X^KU\><@
MY?;A\>SOX]XN`,'J]?'O($)A=&-H+4E$+@#3]-SKZ.?JX>T@Z]SH[_(@Y.7D
M[^S=[>$N`,'J]?'G(.3IY?WH]>WSYR#P\>_O\>GS[._]+@#,YR#=X^KU\><@
M[._Q]MX@X?'WY=_O]0#,YR#=X^KU\>\@;7-G7W1Y<&4N`,SG(-WCZO7Q[R#>
M(.OEW_#EZ2!A<&E?:60N`,SG(-WCZO7QY?(@WB#EZ^OI\.7?\B#PX?'<[.7T
M\>_I+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@#,YR#=X^KU\>\@\/'Y
M]/SJ[^OK[RX`S.<@W>/J]?'O\B#PX?'AZ][P].?R.B`G)7,G`,SG(-WCZO7Q
M[R#J[^GM_/?QY_/T[R#A[?3IZN7?[.7M[P#,YR#=X^KU\><@X?'WZ>K>(.3I
MY?WH]>WSYRX`S.<@W>/J]?'A(.3EY._LW>WA(%5N:6-O9&4N`,KA]-SK[^/O
M\B#5\.'Q]_SM]/GM`-#KX>/IX0#)X>WO]=SQZ>_R`,GO_>OI[_(`R>_][>GO
M\@#%]>CUX_'<[.SI\^<`Q?7H]>/QW.SLZ?/G(//T[R#*W>WT\>\`T.O>\>?R
M(,7UZ/7C\=SL[.GSYP#%]>CUX_'<[.SI\^<@P?'I\_3E\=P`Q?7H]>/QW.SL
MZ?/G(,3E[NG<`,'E\>_KZ>S=[>'R(,KAZ^'LW/3A\@#!Y?'OZ^GLW>WA\B#*
MX?'PW.CO]0#!Y?'OZ^GLW>WA\B#*X?/T[_'IW/(`S>$@ZO'A]-[S^2#T[R#A
M]>CE[?3IZOP[`,'E\>_KZ>S=[>'R(,KE]N'K[^WIW/(`2V5R8F5R;W,M4V5R
M=F5R(.'Q[=[HY^KE(/3G[2#A]>CE[?3IZN_P[]_G\^<N`,'E\>_KZ>S=[>'R
M(,K=\>KU\>'R`,W=X2#A\/P@2V5R;F5L`,3G[.GO]?'CW^$@RNOEZ>3I[_T`
MP?#O]/WP^>SA(,KKY>GDZ>_]`,S>ZN_R(,KKY>GDZ>_]`-3]\._R(,KKY>GD
MZ>_]`-?QWO/G(,KKY>GDZ>_]`-3O(.KKY>GDWR#U\-SQ]^7I(-[DYR#S]._M
M(.7N]?#G\>7TY_3>(.3G[/SSZ?GM(.KKY>GDZ?[M+@#0X>GDZ=P`P>7Q[^OI
M[-WMX?(@ROD`P>7Q[^OI[-WMX?(@RN_FW.WG\@#$Z=STX>[G`,'E\>_KZ>S=
M[>'R(,O<\>GSX?(`U.7KY?7TX=_O(,SI\_P`U.7KY?7TX=_O(-3=].'Q].\`
MU.7KY?7TX=_A(,7MY^S=\?GSYSH`U.7KY?7TX=_A(,7?\^_D[_(@\_3G[2#U
M\.?QY?/?X3H@)7,`U.7KY?7TX=_A(,7?\^_D[_(@\_3G[2#U\.?QY?/?X3H@
M)7,@X?#\("5S`-3EZ^7U].'?X2#%W_/OY._R(//TY^T@]?#G\>7SW^$Z(-#O
M]-T`S?SL[_(`Q.G<].'NYP#!]M[S].4@ZN7M_"#CZ>$@[>$@[.?M(/7PW/'W
M[_7M(/#E\>GH_O'IX0#!\>GS].7QW`#!\>GS].7QWB#%\.GJY?;AZ]_DX0#!
M\>GS].7QW?(@U.GLW?(`T.7M]-SS].GW[P#!Y?'OZ^GLW>WA\B#+WNSM[_4`
MT_WMY.7SYP#3_>WDY?/G(/#O]2#DY=_W[>7I(//E.@#3_>WDY?/G(/3G\B#D
MZ>7]Z/7M\^<@X^GA(-SM[^GC[.$@\.'QX>C]\>_U(//][>CE\^?R.P#3]>WD
MW?/EZ?(`3&EN=7@M0V]O:VEE`$QI<W0@+2#/(/?QWO/TY_(@[/#O\>7?(.WA
M(.3EWR#T[R#VW.KEZ^\`R]_S].$@PMSSY?GM(,3EY._LW>WY[0#+W_/TX2#H
MY>S<]/GM(,+OWNCEZ>'R`,O?\_3A(-#I[=SJ^>T`QR#DY^SI[_7QX]_A(.O?
M\_3A\B#W\>?S]/[M(-WWY>D@X?#E[>7QX^_P[^GGZ.7?+@#6_/'T^?/G+BXN
M`-3O\.GJWB"_\>$Z(`#4_/#O\B#JX>D@_O'A`-3\\._HY?/?X0#%W_/OY._R
M`+CN[^3O\@#$Z>7QX^'SW^7R(.7I\_SD[_4`QR#EW_/OY._R(,'PW?3U]^4N
M(-#IZ.'M_/3A].$@Y/SHY^KE(.O<Z._R(/3O(+SM[^SA(-?QWO/TYR#>(.\@
MROGDZ>K\\BX`Q=_S[^3O\B#!\-WT]??E+@"X[N_D[_(`S.7CW.OO(,KEW^SE
M[>\`P>/<\.<`U^'LY^O\`,SIZO'<(,7KZ^?MZ>K<(./QW.SLX?3A`,SIZO'<
M(.OA].GMZ>K<(./QW.SLX?3A`,SIZO'<(-'Y[.'ZZMX@P?'?Z.SG\^<`S,P`
MS.'CZ>K\`,'KZ^?K[^/QX?;?X0#$Z>'WY=_QZ?/G($5M86EL`,3G[.GO]?'C
MW^$@T_WMY.7SY_(N+BX`Q.GA]^7?\>GSYR#JX?3GX^_QZ?[M(.KAZ2#W\?GL
MW/3Y[2#P[_4@Z.$@Y>SVX>W?YN_M].'I(.'U]-WR+@#%X_?EZ?'?Y.GO`-#E
MY-_A(,?LY?'O[.?MW^'R(.KAZ2"_\>'R`-#EY-_A(.7I\^'C^>/>\@#,W/'T
MZ>_R`+SQZ>\`S.'QZMSQZ?/LX2#LY2#=[>3EZ>[G(,'MX>/M^?/LW>WO]2_,
MYR#A[>'C[?GS[-WM[_4`S.'QZMSQZ?/LX2#LY2#<Z^OG(-WMY.7I[N<@*/`N
M]RX@T^?LX>WTZ>K\+\'PX>WTY^S=[>\I`-#EY-_A(/#O]2#TX>GQZ=SF[_7M
M`,S=X^GS].<@Y?#I]/'E\/3>(/#?\_3Y\^<N`-7PW?'BX?/G(._QW^_U(.SG
M[?WLX?3O\BX`S-WCZ?/TYR#HY?'L[^KQX?/?X2#TY>OE]?3AW_GM(#(T(/GQ
M_NTZ(`#,W>/I\_3G(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@-B#Y\?[M.B``
MS-WCZ?/T[R#LWNKO\@#,W.GO\@#!ZOWQ^?/G(-/U[=SM].?SY_(`T.OG\>_V
M[_'?Y?(@T_7MW.WTY_/G\@#0\?STX?/G(./IX2#3]>W<[?3G\^<`P?#<[?3G
M\^<@X^GA(-/U[=SM].?SYP#%[>?LW?'Y\^<@X^GA(-/U[=SM].?SYP#!W_3G
M[.$@Y>WG[-WQ^?/G\B#CZ>$@T_7MW.WTY_/G`,S=Z^<`T^?LY>G^\^7I\@#*
MX?3<\_3A\^<@S.7M[_TZ`-/UX_?^[>7U\^<@ZN7KZ?[M`,S>[?7LX0#4[R#L
MWNWU[.$@Y?#IXN7BX>G^Z.?JY2#E\.GT]??^\BP@X>OKW"#T[R#PZ?/T[_#O
MZ>?TZ>K\(/3O]2#U\._C\=SV[^WTX2#DY2#L\._QY=\@[>$@Y?#IXN7BX>GY
MZ.7?+@#4[R#LWNWU[.$@W>OG[N4N`-3]\._R(.SG[?WLX?3O\@#*X>GQ_/(@
MX?#\($UE=&%R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N`,S=Z._D[_(`QR#,W>COY._R("<E<R<@
MY.7M(._QW_/HY^KE`,SE]/'IZOP`S.7SX=_O`$UI;64@5'EP90#,Z>KQ_/3E
M\><@Z.7Q[._J\>'SW^$@].7KY?7TX=_Y[2`R-"#Y\?[M.B``S.GJ\?STY?'G
M(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@-B#Y\?[M.B``RN'H\=WP].?R`,3I
MW/;O\>$`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@#+Y=_P
MY>D@].\@8V]N9FEG=7)A=&EO;BX@T/'=\.7I(.WA(/3O(.3G[.GO]?'CWO/E
M].4@X>T@Z-WKY?3E(.WA(/?QY_/I+>SO\._IWO/E].4@X?7TWB#TY^T@Y?;A
M\>SOX]XN`,OEW_#EZ2#T[R!)1"#T[_4@[.?M_>SA]._R+@!-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@#+Y=_PY>D@].\@240@].?R(//]
M[>3E\^?R+@#$Y0!%;6%I;"#*Z>WG]-[R(-3GZ^7V^>W?X?(`S-WT\>GO\@#'
M[.7Q[^SG[=_A(/3Q[_#O\._?Y_/G\@#4\>_P[_#OW^?SYR!54DP`Q>SVW.WI
M\^<@S-[MX0#,WNWA\B#JX>D@W?3O\@#,Y^WIX=_A`,SG[>GAW^$@R]_S].$@
MP^7C[^W\]/GM`-;<\^7I\B#3Y>O>[>?R`,K?[>?SYR#JW/3Y`,K?[>?SYR#A
M\>GS].7QW`#*W^WG\^<@Y.7NZ=P`RM_MY_/G(/#<[?D`RM_MY_/G(.K<]/D`
MRM_MY_/G(/#<[?D`T._KZ^'PZ]WR(.O?\_3E\B#E\.GK[^/>\B`HZN'TX?'Q
MW.KTY?(I`-#OZ^OA\.O>(.7PZ>OOX]X`SR#+[^/A\>GA\^S\\B#L[_4`SR#I
M\_3\]._P_/(@[._U("AP;W)T86PI`,<@Y>SVW.WI\^<@]._U(.GS]/ST[_#O
M_2#L[_4@*'!O<G1A;"D`QR#0Y?'?Z^?XYR#L[_4Z`,'E\>_KZ>S=[>'R(,SU
M].?KWNWG\@#/U\DL(,3%(//U[/;Y[?X`O.WO[.$`P?#AZ?3EW_3AZ2#E[=WQ
MX^7IX0#$W^KT]>\`T._TW0#-W>$@RN'TY^/O\=_A`,W=X2#3Y>O>[><`S=WO
M\B#*^>3IZOSR`,W=[_(@ROGDZ>K\\B`H[N'MW"D`S=WO(/SM[^SA(-?QWO/T
MYR`H\/'OX>GQY?3IZOPI`,W=[R#PX?'<Z/7Q[R`HZN7M_"D`S=WA`,_LW.3E
M\B#CZ>$@[=WA("AN97=S9W)O=7!S*0#%\/SLY>WO`,7P_.SE[><@T^7KW^3A
M`,7P_.SE[><@UMSSYP#%\/SLY>WE\B#%\.GK[^/=\@#/]^D`Q.7M(/7PW/'W
MY>D@Y.GAZ-WSZ>SO(&-O;F9I9W5R871I;VX@X^GA(.WA(.3EW^[Y(.3IX?;O
M\=WR+@#$Y>T@]?#<\??EZ2#DZ>'HW?/I[.<@\_3QX?3GX^GJWB#CZ>$@Y.?L
MZ>_U\>/?X2!)4T\@:6UA9V5S+@#$Y>T@]?#<\??EZ2#P\?ST]?#O(./IX2!"
M871C:"X`Q.7M(/7PW/'WY>D@0FQO8VL@\_3G[2#AZ?3O_>SE[><@Z-WSYP#$
MY2#D_.CGZN4@_.WO[.$@X^GA(.'UZ.7M].GJ[_#OW^?SYR!-0T%,+@#$Y>T@
M]?#<\??O]>T@X>OKX>/=\BX`Q.4@[/#O\>_][2#MX2#P\>_S].7H[_WM(.7N
M[_7SZ>_D[_3>\^7I\B#JW/3Y(.'P)R#A]?3\(/3O(.7PW_#EY.\N`,3E[2#L
M\._Q[_WM(.WA(/#Q[_/TY>CO_>T@]?#OZN'TY^/O\=_E\B#SY2#A]?3>(/3G
M[2#E[N_U\^GOY/STY_/G+@#$Y>T@[_'?\^CGZN'M(/#KY_'O]N_QW^7R(/'U
MZ.S?\^7Y[2#CZ>$@)7,N`,3E[2#O\=_SZ.?JX>T@\.OG\>_V[_'?Y?(@\?7H
M[-_SY?GM(./IX2!&5%`@5D93+@#$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#K
MY_'O]N_QW^7R(./IX2#TY^T@]?#G\>7SW^$@RN'TX>O\X^_U+@#$Y>T@W??O
M]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2#TZ?(@ZN'TY^/O\=_E
M\B#TY_(@4U%,+@#$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R
M(./IX2#TZ?(@\/'O].GLWO/EZ?(@].?R(%-13"X`Q.7M(-WW[_7M(/'UZ.SI
M\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@4U%,(%9&4RX`Q.7M(-WW[_7M(/'U
MZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@].?M(.'UZ.7M].GJ[_#OW^?S
MYR#S].?M(%-13"X`Q.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E
M\B#CZ>$@4U%,+49I;&4@5D93+@#$Y>T@W>SEZ>WE(/#?\_3Y\^<N`,3E(.3^
M\^'TY2#P\>_O\>GS[/PN`,3E(/;O\?3^Z.?JX>T@X?'WY=_A`,3E(.+QW>CG
MZN'M(.7IZN_MW^3IX2X`Q.7M(._QW_/HY^KE(/3O\._HY?/?X2X`Q.4@Y/[S
MX?3E(.S>[?7LX2X`Q.7M(._QW_/HY^KE(/SM[^SA+@#$Y>T@[_'?\^CGZN4@
MX?'IZ.S\\BX`Q.7M(/7PW/'W[_7M(.3U\]SQY?/TY?(@\/'OXNO=^.7I\@#$
MY>T@Y>KJ\>7L[_WM(.7?\^_D[^DN`,_I(/#Q[_3I[-[SY>GR(.3E[2#EW^WA
MZ2#DZ>'HW?/I[.7R+@#$Y>T@]?#<\??O]>T@ZN'M_.WE\@#$Y>T@]?#<\??O
M]>T@\.OE]?'=\@#$Y>T@]?#<\??EZ2#P\>_S^?'I[?SR(/?^\>_R(./IX2#L
M[=[LYR!C86-H92X`Q.7M(.3\Z.?JY2#\[>_LX2#W\=[S].<@WB_JX>D@ZOGD
MZ>K\\BX`Q.7M(.7PZ?/T\=SVY^KA[2#=X^/U\>$@6$U,(.3EY._LW>WA`,3E
M[2#U\-SQ]^_U[2#TZ>S=\@#$Y2#B\=WHY^KE(-WJY._SYR#S].\@X?'WZ>K\
M(&-O;F9I9W5R871I;VXN(,[A[>'DY^SI[_7QX][S].4@].\N`,3E(.+QW>CG
MZN4@W>KD[_/G(//T[R#A\??IZOP@\^'R(&-O;F9I9W5R871I;VXN(,[A[>'D
MY^SI[_7QX][S].4@].\N`,KA[=WMX?(@T_7L[.7TW??Y[0#*X>SLW^$`RN'M
MW>WA("C7\=[SYR#P\>_JX>CO\>GS[-WM[_4I`,+\\>7I[R#'[.GS]N'?\>GO
M`+SWZ2#,Y?3<`+SWZ2#0\>GM`,3E[2#EW^WAZ2#JX?3<Z^_C[_(`Q.7M(-WW
MY>D@[^OOZNOG\?GHY=\N`,3E[2#=]^GE(/3EZ.7?`,3E[2#U\._S].?QW^;E
M].4N`-/G[.7I_O/EZ?(`T^?LY>G^\^7I\B`M(-#E\=_KY_CG`,_I(//G[.7I
M_O/EZ?(@Y=_MX>D@[.GA(.7VX?'L[^/>(/#O]2#SX?(@Y?#I]/'=\.7I(.WA
M(.3G[.GO]?'CWO/E].4@].\@X>WTW_/T[^GW[R#T^>T@ZM_T\>GM^>T@[.GJ
M\?[M(/?A\?3I_NT@\_3O[2#U\._K[^/I\_3>+B#,\._QY=_TY2#MX2#DY^SI
M[_7QX][SY?3E+"#MX2#T\>_P[_#OZ=[SY?3E+"#MX2#DZ>'C\=SXY?3E(.KA
MZ2#MX2#T]?#^\^7TY2X@S/#O\>7?].4@Y?#?\^?R(.WA(/C<[N7TY2#S].GR
M(//G[.7?^?/EZ?(@\^'R(./IX2#MX2#E[?3O\-_SY?3E(.SIX2#PZ^?Q[_;O
M\=_A+B#5\._S].?QW^;E].'I(.KAZ2#EZ?/AX_GCWB`M(.7NX>/YX]X@]/GM
M(//G[.7I_O/E^>TN`-/G[.7I_O/EZ?(Z`-3?\._TX2#CZ>$@Y>SVW.WI\^<L
M(.7PZ?/T\>_VWBX`P>WAZN_I[?[SY>GR`-3O(/#Q_./QX>SLX2#P[_4@Y.GA
M]^7I\=_FY?3AZ2#TZ?(@Y>GD[_#OZ=[SY>GR("5S(.3E[2#B\=WHY^KE+@#-
M[]WLXO'I[_(`P?'IZ.S\\@#!\>GH[/SR(/?A\>'J]-[Q^>T`P?'IZ.S\\B#S
M].?K_NT`P?'IZ.S\\B#S].?K_NT@\_3G[2#E[/;<[>GSYR#TY_(@\.7QW^OG
M^.?R.@#!\>GH[/SR(./QX>SL_NT`Q.7M(._QW_/HY^KE(.'QZ>CL_/(@X^GA
M(.7MY^S=\?GSYR#T^>T@Z^GS]/[M(.3IX>WO[-[R+@#![?3IZN7?[.7M[P#$
MY^SI[_7QX_SR(,'M].GJY>GLW>WO]0#%[N_U\^GOY._TWO/EZ?(@Q.?LZ>_U
M\>/O_2#![?3IZN7I[-WM[_4`S^KTX>3IZOSR`,_J]/[B\>GO\@#6W^OT\>\@
M\/'O\^+OZ_[M`,/QX?;EW^\`T.'KZ?SR(,KYY.GJ_/(`S/SM[R!)34%0+5-E
M<G9E<G,@]?#O\_3G\=_F[_7M(.KO]>W\]_'G\_3O]?(@]N'JW>OK[_7R+@#,
M_.WO(.3U\]SQY?/TY?(@\/'OXNO=^.7I\@#,_.WO(.SIX2!%;6%I;"#DZ>7]
MZ/7M\^<@Y?#I]/'=\.7TX>DN`,S\[>\@[R#IY.GOZO3>].?R(-X@[R#DZ>'W
MY>GQZ?/TWO(@\_7S]-[LX?3O\B#L\._QY=\@[>$@X>OKW.[EZ2#TY^T@Z>3I
M[^KTY_/?X2#>(/3I\B#E[N_U\^GOY._TWO/EZ?(@]._U(.GDZ>_J]-[TYR#C
MZ>$@ZN_I[=X@]_'>\^<N`,'M[^GC[.$@\^4@[=WO(/#A\=SH]?'O`$]P96Y3
M4TPMR]SH[_(Z(,3E[2#L\._Q_B#MX2#BX]SK^2#DY>3O[-WMX2#A\/P@4R]-
M24U%(/7P[^/EX_'A[.S=[>\@[-WQ[_(N`,'M[^GC[.$@X?7TWO(@].?R(//]
M[>3E\^?R(//E(.W=[R#PX?'<Z/7Q[P#+Y>GT[_7QX^GJ_"#3_?/TY^SA`-#Q
M[^7QX>GTZ>K\\B#3]>SLY?3=]_GM`,7PZ>OOX]WR`,7PZ>OOX]WR(./IX0#%
M\.GK[^/=\B#CZ>$@)7,`U.'NZ>WO[.?LW>WG(,O?\_3A`,_QX^'MZ?/L_/(`
MU.S>[.$@S_'CX>WI\^SO_0#/\>/<[?GSYP#!]>CE[?3IZOP@\/'\]/7P[R#E
M]N'Q[._CWO(`P?7HY>WTZ>K<(/#Q_/3U\.$@\V4@)7,Z`,'KZ^\`P>OKY?(@
MT.OG\>_V[_'?Y?(`Q>[O]?/I[^3O]-[SY>GR(,GDZ>_J]-[TYP#'(,'UZ.7M
M].GJ[_#OW^?SYR!004T@Y.7M(.7?[>'I(.3IX>C=\^GLYRX`V.?VZ>'JWB#5
M\._C\>'VWB!01U``RO'U\/3OX_'A]N?LW>WA(.3EY._LW>WA(%!'4`#$Y^S\
M\^GO(,KKY>GDWR!01U``U?#OX^7C\>'L[-WMX2_*\?7P]._C\>'VY^S=[>$@
M4$=0(.3EY._LW>WA`%!(4"#*_N3IZN'R`%!(4"#*W>OU]N_R`%!(4"#*W>OU
M]N_R`,/=[.GS[.$`ROGDZ>K\\@#/(.KYY.GJ_/(@W.OKX>[E(./IX2#T[^T@
M]_'>\_3G("5S(.'P_"#T[R#S].'H[/P@)7,`R]SH[_(@ZOGDZ>K\\@#!\.'I
M].7?].'I(.KYY.GJ_/(@X^GA(.'UZ.7M].GJ[_#OW^?SYR!2041)55,N`,KY
MY.GJ_/(@[.4@Y?#IXN7BX=_Y\^<`ROGDZ>K\\CH`ROGDZ>K\\CH@`,\@ZOGD
MZ>K\\B#P\=WPY>D@[>$@].'I\>G<YN7I+@#+W_/TX2#0Y?'A\^S=[?GM(./E
MX^_M_/3Y[0#%\.GJ_.OKY_/G`,7PZ>K\Z^OG\^<@X?#\(/3O(&-L:7!B;V%R
M9`#$Z>'D\>_LW@#%W_/OY._I(/#O]2#EZNKQY>SO_>TZ`,'MZ/'Y\._I`-#O
M\^_S]/P`Q>KTW>OE\^<@R^7I]._U\>/I_NT@T_7M]-[QY_/G\@#%ZO3=Z^7S
MYR#+Y>GT[_7QX^G^[2#3]>WTWO'G\^?R(.KA]-P@].?M(.7?\^_D[SL`Q>[O
M]?/I[^3\].?SYP#%[N_U\^GOY/STY_/G(./IX2`G)7,G(.3E(.3IX>/QW/;G
MZN4N`,3IX??EW_'I\^<@Q>[O]?/I[^3O]-[SY?GM`,7N[_7SZ>_D[_3>\^7I
M\B#CZ>$`T/'O\_GPZ>K=\B#PZ^?Q[_;O\=_E\@#*X?3OZ>K?Y.GA`-3GZ]WV
M^>WO`-;Y]._C\>'VW^7R`,7IZN_M[_/T[^GWY=_A`,KOZ>WO]/7PW^7R`-#A
M\>'JX>O^(.K<[?3E(.KKZ>H@\^4@ZMSP[^GO(.KEZ]\`T.'QX>KAZ_X@Y?#I
MXN7BX>G^\_3E(/STZ2#HW>OE].4@[>$@Y.GAX_'<^.7TY2#A]?3\(/3O(//T
M[^GWY=_O.@#0X?'AZN'K_B#E\.GBY>+AZ?[S].4@_/3I(.C=Z^7TY2#MX2#A
M\._S]>WDW?/E].4@X?7T_"#T[R#S]._I]^7?[RX`T.'QX>KAZ_X@Y/[S].4@
M[-[MX2#JX>D@W?3O\BX`T.'QX>KAZ_X@Y/[S].4@W>WA(/SM[^SA(./IX2#T
MYR#MW>$@ZN'TY^/O\=_A.@#0X?'AZN'K_B#D_O/TY2#LZ>$@W>/J]?'G($E0
M(.3IY?WH]>WSYRX`T.'QX>KAZ_X@Y/[S].4@[.GA(-WCZO7QYR#G[.7Q[^SG
M[=_A+"#EZ]WN].4@]._M(.'QZ>CL_"#T^>T@Y^SE\?[M(/3O]2#LWNWA+@#0
MX?'AZN'K_B#D_O/TY2#=X^KU\><@_O'A+@#0X?'AZN'K_B#D_O/TY2#T[R#M
MW>\@ZOGDZ>K\(//A\@#0X?'AZN'K_B#D_O/TY2#LZ>$@\.7QW^OG^.<@]._U
M(/#Q[^+KWNSA]._R+@#0X?'AZN'K_B#D_O/TY2#T[^T@ZOGDZ>K\(//A\@#0
MX?'AZN'K_B#D_O/TY2#T[R"\[>_LX2#7\=[S].<`T.'QX>KAZ_X@Y/[S].4@
M].\@_.WO[.$@ZN'I(/3O[2#J^>3IZOP@\^'R`-/U[/#KY_'^\_3E(/3O(/SM
M[^SA(/?QWO/TYR#LY2#T[^T@]._LW>$@*$!E<FUI<RYY9'0I`-#A\>'JX>O^
M(.3IX>+<\_3E(/3O(.'J_.OO]>CO(.KEW^SE[^TN(-#QW?#EZ2#MX2#S]>SV
M^>WEW_3E(.SE(/3O]?(@_/'O]?(@X^GA(.WA(/?QY_/I[._P[^G>\^7TY2#A
M]?3\(/3O(//]\_3G[.$N`-#A\>'JX>O^(.3EW_3E(/3I\B#AZOSK[_7HY?(@
M\.OG\>_V[_'?Y?(@ZN'I(.7PZ>O=[O3E(.SIX2#E[=WQX^7IX2#A\/P@].\@
M\.'QX>K<]/D@[.7M[_TN`-#A\>'JX>O^(.7PZ>O=[O3E(.SIX2#E[=WQX^7I
MX2#A\/P@].\@\.'QX>K<]/D@[.7M[_TN`-#A\>'JX>O^(.3^\_3E(/3O(/SM
M[^SA(/3G\B#MW>'R(.KA].?C[_'?X?(Z`-#A\>'JX>O^(.7PZ>+EXN'I_O/T
MY2#T[R#MW>\@ZOGDZ>K\(//A\@#(W?/G(.'U]-[R(/3G\B#EZ>K\[>'R`-3O
M\._HY?3^[?3A\B#A]?3\(/3O[2#PW^WAZN$`P?#O\_3OZ]X@\^4@X?7T_"#T
M[R#VW.KEZ^\@*.3E[2#U\._S].?QW^;E].'I(.'P_"#T[R!)34%0*0#-X2#P
M\>_TW//S[^WTX>D@Y/WO(/#A_>OE\B#P\=_M(/3G[2#U\._C\>'VWB#SX?(@
M*"<M+2<I.P#*X?3AZO'>[.WI\^<@X^GA(/3I\B#TY>OE]?3AW^7R("5S(/[Q
MX2CE\BDZ(`!0<F5F<U]L9&%P.B#$Y2#B\=WHY^KE(.<@X?#AZ?3O_>SE[><@
MY?#=ZO3A\^<@3$1!4"X`4')E9G-?<V5S<VEO;CH@Q.4@XO'=Z.?JY2#G(.'P
MX>GT[_WLY>WG(.7PW>KTX?/G(//U[>7D\=_A\BX`T.'Q[_7SZ=SSY>GR`-#?
MY?/G`-#?Y?/G(//T[R#E\-_PY>3O(/3G\B#HW.OA\_/A\CH@`-#?Y?/G.B``
MT/'OY?#I\^K\\.GSYP#0\>_E\.GSZOSPZ?/G(/3G\B#EZ>K\[>_A\B#SY2#M
MW>\@\.'QW.CU\>\`T/'OY^/O_>SE[><@T^7KW^3A`-#Q[^?C[_WLY>WE\B#%
M\.GK[^/=\@#%ZO3]\/GSYR#EX^/QW/;O]0#0\>_S^?#IZOP@RNOEZ>3?`-#Q
M_.+KY^SA`-#E\>GC\>'VWB#0\>_BZ][LX?3O\@"X\>/O("AP<F]J96-T*0#*
MY=_LY>WO(/#Q[_3Q[_#>\@#$Y^S\\^GO(,KKY>GDWP#!Z^/\\>GH[._R(,3G
M[/SSZ>_U(,KKY>GDZ>_]`-3O(.;E_>/O\B#$Y^S\\^GO]2_0\>_S^?#IZN_]
M(.KKY>GDZ>_](.3E(.3G[.GO]?'CWNCGZN4@Y?#I]/7W_O(N`,7Q_O3G\^<`
MQ.?L_//I[R#*Z^7IY-\@4E-!("@E9"!":70I`,7PZ>OOX]\@Y>W\\@#4]??A
MW^$@T/'\XNOE^.<`R_SC[_(`P>W<X^WY\^<`P>W<X^WY\^<@[.?M_>SA]._R
M`,7?\_3E(.+=XN'I[_(@X^GA(/3G(.3IX>/QX?;>("5S.R#!]?3\(.3E[2#L
M\._QY=\@[>$@Y?#A[=WKZ.7I+@#%W_/TY2#SW^/O]?'O\B#CZ>$@].<@Y.GA
MX_'A]MX@]/GM(.3EY._LW>WY[2#T[_4@]_'>\_3G("5S.R#!]?3\(.3E[2#L
M\._QY=\@[>$@Y?#A[=WKZ.7I+@#%\.'MY>KTW>OE\^<@].?R(/3EZ^7U].'?
MX?(@Y?'CX?/?X?(@\^'R`,'MX>W=^?/G(/3Y[2#D]>WA[.GJ_NT@\_3OZ??E
MW_GM(/3O]2#,Y>WO_3H`P>WA[=WY\^<@].?R(.7L]MSMZ?/G\B#T[_4@4&]R
M=&%L.@#![>'MW?GSYR#TY_(@T/'OXN_KWO(@T.7QW^OG^.?R.@!296=E>`#%
M[/;<[>GSYR#3]]WSY?GM`-/W_.OIX0#!\._L[>?L_.WE]?/G(/#KY_'O]N_Q
MZ?[M(.3IX>CE\^GL_/3G].'R+@#!\._LX>KQ]?/LW>WOZ2#%[O7PY_'E].?T
MW?(`P?#O[.'J\?7S[-WMYR#DZ>7]Z/7M\^<@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.@#!]N'?\>7SYP#!]N'?\>7SYR#,\.O\Z@#!]N'?\>7S
MYR#3]-[KY_(`P?;AW_'E\^<@[._Q]N_P[]_G\^?R`,'VX=_QY?/G(.'P_"#T
M[R#G[.7Q[^O\X^G\(.SO]0#!]N'?\>7SYR#FY?WC[_7R`,'VX=_QY?/G(.'P
M[^CGZN7U[-WM[_4@<V-R:7!T(.'P_"#T[^T@\/'O\_GQZ>W\(.KA]-SK[^/O
M(/3O]2#E[O7PY_'E].?TWBX`P?;AW_'E\^<@]._U`,'VX=_QY?/G(.'U]._]
M(/3O]2#J_.SB[_4@X?#\(/3O(-WCX_'A]N\`Q.GAX_'A]MX@]_'>\_3G`,3I
MX>/QX?;>(-?QWO/TYSH@)7,`T_3<Z^CGZN4@P?#<[?3G\^<N`,'PW.WTY_/G
M(.SE(,S'(/7P[_/TY_'IYOSLY>WO(.S>[?7LX2X`P?#<[?3G\^<@[.4@\.OG
M\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(@X^GA(/3O]?(@Y?#\[.7M[_7R(.3]
M[R#LWNWE\BX`P?#<[?3G\^<@[.4@].GR(.;G]._][.7MY?(@\.OG\>_V[_'?
MY?(@Y.GAZ.7SZ>S\].?TX?(N`,'PW.WTY_/G.B`E<P#4[R#AW_3G[.$@Y.4@
M[/#O\>7?(.WA(.'PX>WTY^CEWRX@Q?#I\_3QY?;\[.7M[_(@ZOGDZ>K\\B#K
MW.CO]?(Z(`#4[R#A\.'I]._][.7M[R`G)7,G(.3E[2#JX>CO\=_SZ.?JY2#S
M].\@)7,@8V]N9FEG=7)A=&EO;BX`U.\@X?#AZ?3O_>SE[>\@)R5S)R#DY>T@
MZN'H[_'?\^CGZN4@\_3O(%9&4R!C;VYF:6=U<F%T:6]N+@#4[R#A\.'I]._]
M[.7M[R`G)7,G(.3E[2#JX>CO\=_SZ.?JY2#S].\@8V]N9FEG=7)A=&EO;BX`
MU.\@X?#AZ?3O_>SE[>\@)V)A<V5D;B<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S
M].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+@#4[R#A\.'I]._][.7M
M[R`G8F%S961N)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR
M(/3Y[2#P\>_TZ>S>\^7Y[2X`U.\@X?#AZ?3O_>SE[>\@)V1A=&%B87-E)R#D
MY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#O
MW^?SY_(N`-3O(.'PX>GT[_WLY>WO("=D871A8F%S92<@Y.7M(-WWY>D@ZN'H
M[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+@#4[R#A\.'I]._]
M[.7M[R`G9&%T86)A<V4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CL
MW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+@#4[R#A\.'I]._][.7M[R`G:&]S='-P
M96,G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WT
MZ>KO\._?Y_/G\BX`U.\@X?#AZ?3O_>SE[>\@)VAO<W1S<&5C)R#DY>T@W??E
MZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN`-3O(.'P
MX>GT[_WLY>WO("=H;W-T<W!E8R<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR
M(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN`-3O(.'PX>GT[_WLY>WO("=P
M87-S=V]R9"<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A
M]>CE[?3IZN_P[]_G\^?R+@#4[R#A\.'I]._][.7M[R`G<&%S<W=O<F0G(.3E
M[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2X`
MU.\@X?#AZ?3O_>SE[>\@)W!A<W-W;W)D)R#DY>T@W??EZ2#JX>CO\>GS].7?
M(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2X`U.\@X?#AZ?3O_>SE
M[>\@)W!H<'1Y<&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/E
MZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`U.\@X?#AZ?3O_>SE[>\@)W!H<'1Y<&4G
M(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^
M[2X`U.\@X?#AZ?3O_>SE[>\@)W!H<'1Y<&4G(.3E[2#=]^7I(.KAZ._QZ?/T
MY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+@#4[R#A\.'I]._]
M[.7M[R`G=&%B;&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/E
MZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`U.\@X?#AZ?3O_>SE[>\@)W1A8FQE)R#D
MY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN
M`-3O(.'PX>GT[_WLY>WO("=T86)L92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S
M].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN`-3O(.'PX>GT[_WLY>WO
M("=U:60G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7H
MY>WTZ>KO\._?Y_/G\BX`U.\@X?#AZ?3O_>SE[>\@)W5I9"<@Y.7M(-WWY>D@
MZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN`-3O
M(.'PX>GT[_WLY>WO("=U<V5R;F%M92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S
M].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+@#4[R#A\.'I]._][.7M
M[R`G=7-E<FYA;64G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/E
MZ?(@ZN'TY^/O\>G^[2X`U.\@X?#AZ?3O_>SE[>\@)W5S97)N86UE)R#DY>T@
MW??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y
M[2X`P?#AZ?3O_>SE[>\@T.7DW^\`P?#AZ?3O_>SE[>_R(-/U[.SE]-WW^>T`
MQ?#A[>'V[_'<`,'KZ^'CWB#*^>3IZN_]`,'KZ]SN].4@]._M(,KYY.GJ_"#S
MX?(`P?#O].7KW?/LX?3A`,7PZ?/T\>_VWB#S].GR(,7PZ>OOX]WR`,7PZ?/T
M\>_VWB#S].?M(.'KZ^?K[^/QX?;?X0#%\.'MW>WY\^<`Q?#A[>'V[_'<($-O
M;F9I9W5R871I;VX`P>7Q[^OI[-WMX?(@T?SD[_4`Q?#IZ^_CW?(@Y?#E[N7Q
MX^'S]-X@Y>SPZ^_U].GS[-WM[_4@ZN7I[-WM[_4`P>GMW^/LX?3A`,3E[NG<
M`,3E[NG<(.7PZ>KE]N'KW^3A`,3E[NG=\B#TZ>S=\@#)Y.G\].?TY?(@X_'A
M[.S>\BXN+@#1_.OO\@#0Y?'I\_3Q[_;>(#$X,+``T.7QZ?/T\>_VWB#!\>GS
M].7QW`#0Y?'I\_3Q[_;>(,3E[NG<`,GDZ?STY_3E\B##\>'L[-[R`,GDZ?ST
MY_3E\B##\>'L[-[R`,/QX>SLW?(Z`,KA[?SMY?(`S^D@ZN'M_.WE\B#HX2#E
M[/;A[=_F[^WTX>D@[.7TX>[](/SK^>T@]/GM(./QX>SL_NT@ZN'I(/3Y[2#S
M].?K_NT`S^D@ZN'M_.WE\B#HX2#E[/;A[=_F[^WTX>D@[.7TX>[](/3Y[2#S
M].?K_NT@[/SM[P#/Z2#JX>W\[>7R(.CA(.7L]N'MW^;O[?3AZ2#LY?3A[OT@
M]/GM(./QX>SL_NT@[/SM[P#%ZO3=Z^7SYP#5\._C\>'VWB#*\?7P]._C\=SV
MY_/G\B!3+TU)344`RO'U\/3OX_'A]N?LW>WO(.S>[?7LX2!3+TU)344`QR#A
M]>CE[?3IZN_P[]_G\^<@4T%33"#DY>T@Y=_MX>D@Y.GAZ-WSZ>SG+@#,Y^W]
M[.'TX2!335,`4U%,(,K=Z_7V[_(`Q=#)U-77V=,`4U]13"#*W>OU]N_R`-/A
M`+KDZ>\@\.OAW_/I[R`H7W-E;&8I`,'E\>_KZ>S=[>'R(-/<[._U`-#<\>_W
M[_(@Q._Q]?;\\>_U`,'P[^C>ZN7U\^<`P?#OZ-[JY?7SYR`E<P#!\._HWNKE
M]?/G("<E<R<`P?#OZ-[JY?7SYR#%\.GK[^/^[0#!\._HWNKE]?/G(/3O]2!C
M;VYF:6=U<F%T:6]N(/#O]2#DY^SI[_7QX][HY^KE(//A[2!02%`@4V-R:7!T
M(//T[^T@\/'O\_GQZ>W\(.KA]-SK[^/O(/3O]2#E[O7PY_'E].?TWBX`P?#O
MZ.?JY?7LW>WO("5S(&-O;F9I9W5R871I;VXN`-3O('-C<FEP="#E[>?LW?'Y
M\^?R(/3O('-E='5P(.'P[^CGZN7]Z.?JY2#S].\Z("<E<R<N`,7PZ?/TWNSG
M`,'MX>;>].?SYP#,Y_?A[=WR(,'MX>;>].?SY_(`P>WAYM[TY_/G(,SG[?7L
MW/3Y[0#!\._TY>O=\^SA].$@P>WAYM[TY_/G\@#%\.GK[^/>(,'Q]^7?^>T`
MQ?#IZ]WN].4@[.GA(.?LY?'O[.?MW^$`Q?#IZ]WN].4@[^S<Y.$@X^GA(/#Q
M[_/HWNKG`,7PZ>O=[O3E(.W=[R#)Y.GOZO3>].<`Q?#IZ]WN].4@Y>[U\.?Q
MY?3G]-X`Q?#IZ]WN].4@]_'>\_3G(./IX2#P\>_SZ-[JYP#%\.GK[^/>(/SK
M^>T@]/GM(.?LY?'O[.?MZ?[M+@#%\.GK[^/>(.7M_/(@X>WTZ>KEZ>S=[>_U
M`,7PZ>O=[O3E(/3O]?(@]^'QX>KTWO'E\B#P[_4@Z-WKY?3E(.'P_"#TZ?(@
M\.'QX>K<]/D@Z]_S].7R+B#*X?3\\.GM[/#O\>7?].4@[>$@].$@X>WTZ>/Q
MW/CE].4@ZN'I(.WA(/3A(.7PZ>KOZ^O>\^7TY2#S].\@[-[M]>SA(//A\BX`
MQ?#IZ^_CWB#T[_4@Y.GA]_GQZ?/TWB#G[.7Q[^SG[=_A\CH`Q?#IZ^_CWB#T
MY_(@[._Q]M[R(/#O]2#HX2#=]^7I(.<@Y^SE\>_LY^W?X3H`Q?#IZ]WN].4@
M].<@].'U]/STY_3A(/#O]2#HW>OE].4@[>$@X>OKW.[E].4Z`,7PZ>O=[O3E
M(/3O(.3IX??Y\>GS]-X@_O'A\CH`Q?#IZ]WN].4@].<@[._Q]MX@\._U(.CA
M(-WWY>D@YR#^\>$Z`,7PZ>O=[O3E(.3][R#PY>3?X2#P[_4@].'I\>G<YN_U
M[2X`Q?#IZ]WN].4@].\@]_'Y[.'TZ>K\("?S]][LX2<N`,7PZ>O=[O3E(/3G
M(./K_O/SX2#SX?(Z`,'P[_/T[^O>(/3Y[2#PZ>\@\/'\\_;A]/GM(/#KY_'O
M]N_QZ?[M`,'P[_/T[^O>(,'MX?;O\=SR(-#Q[^+KWNSA]._R`,'P[_/T[^O>
M(%--4P#!Z?/HY_3>\>'R.B``T^7P]-WLXO'I[_(`T^7I\>GAZOSR(,'QZ>CL
M_/(`U.\@240@].?R(//][>3E\^?R(-WKY^[E+@#(W?/E`,C=\_3E(.7PZ>OO
MX]WR(/#O]2#HX2#SX?(@Y?#I]/'=\._U[2#MX2#AZ^O<YN7TY2#T[^T@ZOGD
MZ>K\(//A\BP@X>K\[.<@ZN'I(.'M(/3O[2#=]^7TY2#NY??<\^7I+@#0X?'A
M[.7T\>_P[]_G\^<@X?#O[.'J\?7S[-WM^>T@Y>[U\.?QY?3G]/[M(/#O]2#H
MW>OE].4@\/'\\^+A\^<N`-'UZ.S?\_3E(.3IW/;O\>7R(.7PZ>OOX]WR(.7L
M]MSMZ?/G\B#JX>D@].\@]_'\[>\@X>WA[=WY\^?R(/3Y[2#SY>O?Y/GM+@#%
M\.GK[^/>(/3G\B#P\>_TZ>SO_>SE[>?R(./K_O/SX?(N`,KAZ._QW_/TY2#T
MY^T@\/'O].GL_NSE[><@X^O^\_/A+"#F_NWG(/[QX?(@ZN'I(.SO\?;>(.?L
MY?'O[.?MW^'R+@#*X>CO\=_S].4@].?M(.7VX?'L[^/>(.7JZM_MY_/G\BP@
M].$@\/'O].GL_NSE[>$@]_'^[.'TX2P@].<@\.7QW^_D[R#A[>'MW?GSY_(@
M].?R(//EZ]_DX?(@ZN'I(-SKZ^7R(.7PZ>OOX]WR(.7L]MSMZ?/G\BX`T?WH
M[.GSYP#%W^WAZ2#DZ>'HW?/I[.$@4V-R:7!T<R#E[>?LW?'Y\^?R(/'UZ.S?
M\^7Y[0#0[^OKW?(@]._P[^CE\]_E\B#EW^WAZ2#PZ>CA[=WR(.SE(.'U]-X@
M].<@\.'QW.SE]/'O.B``P>/O\=WR`-/][?3O[.<@T.7QW^OG^.<`T_WM]._L
MYR#0Y?'?Z^?XYSH`T/'=\.7I(/3O(.KKY>GDWR#P\?SSXN'SY_(@[>$@[_'I
M\^CEWR#CZ>$@\.7QZ?/S_/3E\>7R(//U[>3=\^7I\CL`Q>SVW.WI\^<`Q>SV
MW.WI\^<@Y.GA]N_Q_NT@[.7TX>[](/3O]2#A\._HY^KE]>S=[>_U(.KAZ2#T
M[_4@Y.?LZ>_U\>/GZ-WM]._R(&-O;F9I9W5R871I;VXN`,7L]MSMZ?/G(/3G
M\B#^\>'R(/3EZ^7U].'?X?(@Y>GS_.3O]2#\].'M(.SPX=_M[_7LY2#S].\@
M\_WS].?LX3L`Q>SVW.WI\^<@Y?#IZ^_CWO(@X^GA(.'P[^C>ZN7U\^<@]._U
M(.'UZ.7M].GJ[_T`Q>SVW.WI\^<@\_7KZ]WJ].<`S>$@Y>SVX>W?YN7TX>D@
M].\@[.7M[_T@[.4@Y?'CX?/?Y?(@\-_MX>KA.P#%[/;<[>GSYR#T[_4@)7,@
MS.7M[_T@\_3A(.'QZ?/TY?'<.P#%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I
M[_3>]/GM(,KEZ^G^[2#0W^WAZN$`Q>SVW.WI\^<@]._U(.3IX>O\X^_U(,GD
MZ>_TWO3Y[2#0W^WAZN$`Q>SVW.WI\^<@]._U(.3IX>O\X^_U(,GDZ>_TWO3Y
M[2##\>'L[/[M(-#?[>'JX0#%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>
M]/GM(,7IZOSMX?(`Q>SVW.WI\^<@]OSQ]/GSY_(@*'5P;&]A9"D`T_7Q\=_J
M[?GSYP#0\?[TX2#S]?'QW^KM^?/G(-X@[.7TX>K?[>?SYR#CY>GT[^WIZO[M
M(/3LY^S<]/GM`,7?\^_D[_(MU?#OX_'A]MX`QR#%W_/OY._R+=7P[^/QX?;>
M(.3E[2#=]^7I(.KA].'W^?'GZ.7?+@#5\._C\>'VW@#!Z^/\\>GH[._R(-7P
M[^/QX?;>\@#,W>/EZ._R`,'J_?'Y\^<@T_7M]-[QY_/G\@#,Y?'IZMP@X?#\
M(/3A(.'Q]^7?X2#DZ>'WY=_QZ?/G\B#T[_4@2&]R9&4@W??O]>T@]^'HY=\Z
M`,7PZ>OOX]X@ZN'TY?WH]>WSY_(@].'NZ>W\[.?SY_(`P>7Q[^OI[-WMX?(@
MT^_]Y.'R`,3IY?WH]>WSYR#0Y^/>\@#-_/3I[R#'[.GS]N'?\>GO`,3IW//T
MY^SA(.SE].'N_2#CY>GT[^WIZO[M(.KEZ^G^[0#$Z=SS].?LX2#LY?3A[OT@
M\.7QZ>7W[^S=[>_U(.KAZ2#C\>'L[-[R(.KEZ^G^[0#0Z][J]/'O(,3IX?/T
MWNSA]._R`,'QX=_Y\^<`P?'AW_GSYR#JX>D@X]WLZ?/LX0!3<&%M`,7I\^'C
M^>/>(,7IY.GJ_NT@U^'QX>KTWO'Y[0#$Z>'?\>7SYR#JY>OI[_T`Q.GAW_'E
M\^<@\_3>Z^?R`,3IX=_QY?/G(./QX>SLWO(`P>CKWNSA].$`N.WA\>[G`+CT
M[_(@N.WA\>[G\@#0[^OI].7?X2#>(,7PX?'WW^$`RN'TW//TX?/G`,SO\?;>
M(.'P[^C>ZN7U\^?R`,3IY?WH]>WSYRW/Y/SR`,3IX>/QX>SLZ?/LW>WA`,O?
M\_3A(.O=[N7Y[0#!]N'?\>7SYR#T[_4@9&]M86EN(.'P_"#TYR#DZ>7]Z/7M
M\^<`T_3]ZR!;0U-370#*]0#/(/7P[_;<ZN7K[_(@)R5S)R#DY2#B\=WHY^KE
M+@#(W>SA`,C=[.$@)]#KY_'O]N_QW^7R(,3G[/SSZ>_U(,KKY>GDZ>_])P#!
M\._S]._KW@#4[R#AW_3G[.$@X^GA(/#Q[_/HWNKG("<E<R<@\_3O(//]\_3G
M[.$@X?#E\_3<Z^<N(,3E(.SP[_'EW_3E(.WA(.[A[>'L\.7?].4@[-WW\>D@
M[>$@Y>/J\>GHY=\@].\@X=_TY^S<(//A\BX`U?#OY.7?ZO3G\@#%\.GT]???
MX0#%\.GT]??>\B#P\>_SZ-[JYR`G)7,G(//T[R#S_?/TY^SA+@#4X2#DY>3O
M[-WMX2#T[_4@]_'>\_3G("<E<R<@Y.GAX_'<]N?JX>T@Y?#I]/7W_O(@X?#\
M(/3O(//]\_3G[.$N`,7PZ?3U]][R(.3IX>/QX?;>("<E<R<N`,7PZ?3U]][R
M(.3IX>/QX?;>("<E<R<@X?#\(/3O(//]\_3G[.$N`,_I(/'UZ.S?\^7I\B#E
M\.'MX?;=\>CGZN'M(.7PZ?3U]_[R+B#*W.WTY2#E\.'MX?;\\?3Y\^<@X^GA
M(.WA(.3EW_3E(/3I\B#AZ^OAX]WR+@#%\.GT]??>\B#E\._HWNKE]?/G(.7V
MY>3QZ>KO_2!C;VYF:6=U<F%T:6]N+@#%\.GT]??>\B#A\._HWNKE]?/G(/3O
M]2#E]N7D\>GJ[_T@X?'WY=_O]2!C;VYF:6=U<F%T:6]N("5S+@#%\.GT]??>
M\B#E[>?LW?'Y\^<@)R5S)P#%\.GT]??>\B#EX^/QX?;>("5S`-/][>_XYR`M
M(-#E\=_KY_CG`,'MX?3OZ]X`Q/WSYP#![>'T[^O>`,'MX?3OZ]XOQ/WSYP#!
M[>'T[^O>.B``Q/WSYP#$_?/G.B``U?#E\>3EW^KTY?(`U?#O\_3>\>GNYP#%
M\-_HY?3O`-3O(.'Q]^7?[R#JX?3AX_'A]M[R(//UX_?Q[^WI\^SO_2#DZ>'C
M\=SVY^KE`%-Y;F--3`#+W.CO\B#S_>WTX>[G\B#S]._U\B#\\>_U\B#A[>'F
MWO3G\^?R`-#?[>'JX?(`R>3I_/3G].7R(-#?[>'JX0#)Y.G\].?TY?(@T-_M
MX>KA`,'E\>_KZ>S=[>'R(-3A[=SC\>'R`-/T_/?O\CH`Q?'CX?/?Y?(`P>7Q
M[^OI[-WMX?(@U.'T[_KO]0#!\>GH[/SR(-3GZ^7V_NWO]0#(Y?'L[^KQX?/?
MX2#TY^T@].7KY?7TX=_A(/[QX3H@`,CE\>SOZO'A\]_A`,CE\>SOZO'A\]_A
M.B``U.\@\/'\]/7P[R`G)7,G(.3E(.+QW>CGZN4N`,3IX??EW_'I\^<@T/'O
M]/WP[_4`T/'O\_GQZ>W>(,'P[^3O]]X@X>GTWNSA]._R`-#Q[_/Y\>GMW"#!
M\._DY>KT_`#*Y=_LY>WO`,S\[>\@RN7?[.7M[P#3]._?]^?SYR#JY>GLW>WO
M]0#*[_'U]MX@ZN7I[-WM[_4`U.4`Q?7WX?'I\_3O_>SE(/#O]2#W\>?SZ>SO
M\._IWO/A].4@].\@T_WS].?LW"#LX?(N`,<@Y?#=ZO3A\^<@1E10(.3E[2#E
MW^WAZ2#AZOSLYR#DZ>'HW?/I[.<N`-3O(//]\_3G[.$@2&]R9&4O2V]L86(@
MY.7M(/7P[_/TY_'?YN7I("(E<R(`Q.GA]^7?\>GSYSHZ(,<@ZNO<\^<@Y.4@
M]N_Q]/[HY^KE(.7PZ?3U]_[R`-3O(/#A\=SH]?'O(.7PZ>OOX_[M(-WJZ^7I
M\^4N(+CN[^3O\BX`SR#DZ>'WY>GQZ?/TWO(@\/'=\.7I(.WA(/'UZ.S?\^7I
M(-WMX2#L_.WI[.\@\.OAW_/I[R#%[N_U\^GOY._TWO/E^>TL(./IX2#MX2#L
M\._QY=_TY2#MX2#W\>?SZ>SO\._IWO/E].4@Y>[O]?/I[^3O]-[SY>GR+@#'
M(.K<]/D@\.OE]?'<(.S\[>\`U.$@Y.7D[^S=[>$@Y^SE\>_K[^/?[_4@Y.7M
M(.7?[>'I(-WCZO7QX0#4[R!)1"#TY_(@Y?#A]M[R(.3E[2#JX>CO\=_SZ.?J
MY2P@WO3A[2#JY>W\(-X@Y.4@XO'=Z.?JY2#S].<@XMSSYR#DY>3O[-WM^>TN
M`,<@Y?#A]MX@\/'O\_3=Z.?JY2#E\.GT]??^\B#S].\@Q.GE]>CU[?/I[^/Q
MW/;O(//A\BX`U.\@].S>[.$@4$=0(/#O]2#A\._S\-SSZ.?JY2#A\.'I].7?
M].\@X^GA(/3G[2#E\.'KWNCE]?/G(/3O]2#U\._CY>/QX>SLW>WO]2#LY^W>
M[.'T[_(N`-3O($E$(/3G\B#KW_/TX?(@Y.GA[>_LWO(@Y.7M(._QW_/HY^KE
M+"#>].'M(.KE[?P@WB#DY2#B\=WHY^KE(//TYR#BW//G(.3EY._LW>WY[2X`
MQR#KW_/TX2#DZ>'M[^S>\B#DY>T@ZN'H[_'?\^CGZN4N`,_I(.3U[>'T_/3G
M].7R(.KQ]?#T[^/QW/;G\^?R(.'PX>GT[_WM(.'S]N'KWB#S_>WDY?/G(%=%
M0BX`U.\@X^7C[^W\\B#P\>_S]-WHY^KE(//T[R#G[.7Q[^O\X^G\(//A\BX`
MU.\@X?'WY=_O("5S(/#QW?#EZ2#MX2#PY?'IW??EZ2#LZ>$@)7,@\?WH[.GS
MYRX`U.\@X?'WY=_O("5S(/#QW?#EZ2#MX2#PY?'IW??EZ2#JW/#OZ>7R("5S
M(/'UZ.S?\^7I\BX`U.\@X?'WY=_O(.3E(.SP[_'EWR#MX2#A[?3IX_'A]N7?
M(//T[^T@Y>'U]/P@]._U+@#4[R#A\??EW^\@Y.7M(/#E\>G=]^7I(.3EY._L
MW>WA+@#4X2#PX?'AZMST^2#EW^WAZ2#E\.GJY?;AZ]_DY?(@X^GA(.'U]/P@
M].\@[-[M]>SA+W)F8S@R,B#LWNWU[.$N`,<@ZN'TW//TX?/G(/#KWO'O]?(@
M[^C\[>?R(.7?[>'I(./M^?/T_"#\].D@Y.?LZ>_U\>/EWR#P\?SBZ^?LX2#L
MY2#T[^T@26YT97)N970@17AP;&]R97(L(.7NX>GTW^'R(/#Q[^+KY^S<]/GM
M("AB=6=S*2#T[_4@8G)O=W-E<BP@].$@[_#OW^$@Y.7M(.7?X>D@Y/7MX?3\
M(.WA(.[E\.7QX?/H[_WM+B#,\._QY=\@[>$@Y.7?].4@)_/J[_7PW^3IX2<@
M\_3G[2#OZ/SMYRP@\/'OXNO>[.'TX2#S].<@Z^7I]._U\>/?X2#T[_4@8G)O
M=W-E<B#>(.KAZ2#J_.OG[-P@]._U+B#![2#T[R#S_?/TY^S<(//A\B#EW^WA
MZ2!7:6YD;W<@.7@@Y=_MX>D@\._K_2#PZ>CA[?P@[>$@Y.7?].4@)\/E[>GJ
MWB#!\._T]???X2#0\>_S].'SW^'R)R#JX>D@[>$@\/'=\.7I(.WA(.7PX>WE
MZNKI[=[SY?3E("AR96)O;W0I+EQN7,'U]-X@Y=_MX>D@\/'OY>GD[_#OW^?S
MYRX@T.'TWO/TY2#/RB#A[2#HW>OE].4@X>K\[.<@[>$@Y._UZ]WXY?3E(//E
M(.KA]-SS].'SYR#PZ][Q[_7R(._H_.WG\BX`QR#TX?7T_/3G].$@(B5S(B#D
MZ>'C\=SVY^KE+@#'(.'QZ?/TY?'>(/#KY?7QW"#L_.WO`,<@Z-WSYR#T[_4@
M\/'OX_'<[.SA]._R($=N=5!'(/#QW?#EZ2#MX2#D[^CEWR#CZ>$@].<@0W)Y
M<'1?<&=P.CH@ZNO<\^<N`,<@X_'A[.SA]._H]?'?Y.$@)^K<Y._R)R#EW^WA
MZ2#>Y.<@W.3EZ>$N`-3O(.S>[?7LX2#P[_4@\_3<Z^CGZN4@\_3I\B`E<R#S
M]._M("5S(.SE(.C=[.$@)7,@Y>SVX>W?\^CGZN4N"L'U]/P@Y.7M(.'P[_3E
MZ^7?(.7PZ>+EXN'?^?/G(/STZ2#DZ>'BW//HY^KE(.KAZ2#=X^GMY2#JX?3A
M[>_G]/PN`-3O(/SM[^SA(/#O]2#HX2#W\>?SZ>SO\._IY=_TX>D@_/3A[2#S
M]>WDW>7S].4@\_3G(//EZ]_DX2#S_>WHY?/G\BX`QR#BZ>+KZ>_HWNKG($]P
M96Y34TP@X?#AZ?3EW_3AZ2#CZ>$@2&]R9&5?0W)Y<'1?<VUI;64Z.B#JZ]SS
MYRX`QR#P\>_TW^SG\^<@(B5S(B#DY>T@[/#\\>7SY2#MX2#A\._HY^KE]>CE
MWR#CZ>'TWR#TX2#DY>3O[-WMX2#TY_(@]?#E\>+AW^WO]>T@].\@[-WCZ?/T
M[R#E\.GT\>7P]/P@[-WCY>CO\@#4[R#P\?SC\>'L[.$@\._U(/?QY_/I[._P
M[^GEW_3E(./IX2#TY^T@Y>SVW.WI\^<@X?7T[_T@]._U(.7?Y._U\B#LY^WU
M[-ST^>T@*"5S*2#DY>T@XO'=Z.?JY2#S].\@\_WS].?LX2X`QR!R96=I<W1R
M>2#EW^WAZ2#O(/3Q_/#O\B#LY2#T[^T@[_#OW^\@[^D@Y?;A\>SOX]WR(/3O
M]2!(;W)D92#E\.GJ[^GM^>WO_>TN(.SE].'N_2#T[_7R+B#%Y/X@\/'=\.7I
M(.WA(./QW/CE].4@_/3I(.7VX?'L[^/=\B#T[_4@2&]R9&4@W??E].4@Y>/J
MX?3A\_3>\^7I+@#'(.'QZ?/TY?'>(.KAZ2#DY>[IW"#PZ^7U\=WR(.S\[>\`
MQR#DY>[IW"#PZ^7U\=P@[/SM[P#/(.7N]?#G\>7TY_3>\B`B)7,B(.3IX>/Q
MW.?JY2X`SR#E[O7PY_'E]-[R("(E<R(@X?#OZ.?JY?WHY^KE+@#4[R#AW_3G
M[.$@Y>GS_.3O]2#CZ>$@)7,@Y.GAX_'<]N?JY2X`QR#C\>'L[-X@\._U(._Q
MW_/A].4@Y.7M(/7PW/'WY>DN`,<@Y?'CX?/?X2#P\>_S]-WHY^KE(//TYR#K
MW_/TX2#E\>/A\^G^[2#SX?(N`-3O(/#Q[_/Y\>GM_"#A\??EW^\@(B5S(B#D
MY>T@]?#<\??EZ2X`QR#PW.WY(.KAZ2#JW/3Y(/#KY?7QW?(@[/SM[P#'(/#<
M[?D@\.OE]?'<(.S\[>\`U.$@Y.7D[^S=[>$@\._U(//TW>OMX?3E(/?<Z.?J
MX>T@X?#\(/3O(/#Q[^?C[_WLY>WO(.+>[.$N`-3O(.'Q]^7?[R#P[_4@\_3E
MW^OA].4@Y.4@[/#\\>7SY2#MX2#S^>CEWRX`S^D@\.OG\>_V[_'?Y?(@Y.GA
MZ.7SZ>S\].?TX?(@X?#OZ.?JY?WHY^KA[2#E\.GT]??^\BX`SR#JX?3<Z^_C
M[_(@Z.7LW/3Y[2`G)7,G(.3E(.+QW>CGZN4N`,3E[2#U\-SQ]^_U[2#%\.GK
M[^/=\B#DZ>'HW?/I[.7R+@#$Y>T@]?#<\??O]>T@].S>[.'TX2#P[_4@Y.4@
M[/#O\>_][2#MX2#E[/;A[>GSZ._][2#E[?/Y[.'T^>S=[>$N`-7PW/'W[_7M
M(/#OZ^OOWR#WX?'AZO3>\>7R(//E(.'U]/P@].\@\.7DW^\N(,7I\^'CW./A
M].4@)7,@]^'QX>KTWO'E\BP@\/'=\.7I(.WA(/7PW/'W[_7M(.OIX_STY?'O
MZ2#A\/P@)7,N`-#Q_.+KY^SA(.KA]-P@].?M(/#Q[_/HWNKG("<E<R<@\_3O
M(//]\_3G[.$N("5S+@#0\?SBZ^?LX2#JX?3<(/3G[2#P\>_SZ-[JYR`G)7,G
M(//T[R#S_?/TY^SA.B`E<RX`T/'\XNOG[.$@ZN'TW"#TYR#DZ>'C\>'VWB#D
MY>3O[-WM^>T@]._U(/?QWO/TYR`G)7,G(.'P_"#T[R#S_?/TY^SA.B``T/'\
MXNOG[.$@ZN'TW"#TYR#DZ>'C\>'VWB`G)7,G(.'P_"#T[R#S_?/TY^SA.B``
MT/'\XNOG[.$@ZN'TW"#TY^T@Y>WG[-WQ^?/G("<E<R<Z("5S`-#Q_.+KY^SA
M(.KA]-P@].?M(.'P[_/T[^O>(.'Q]^7?[_4Z(,3E[2#S]-SKZ.?JY2`E<RX`
MT.'Q[_7SZ=SSZ.?JY2#P\?SBZ^?LX2#JX?3<(/3G[2#A\._S]._KWB#T[_4@
MX?'WY=_O]3H@U.\@)7,@Y=_MX>D@[.7CX>O]].7Q[R#A\/P@].\@[-WCZ?/T
M[R#E\.GT\>7P_.SE[>\@[-WCY>CO\B`H)60@0GET97,I+@#0X?'O]?/IW//H
MY^KE(/#Q_.+KY^SA(.KA]-P@].?M(.'P[_/T[^O>(/3O]2#A\??EW^_U.B#3
M]-SKZ.?JY2#L_.WO(-WMX2#T[-[LX2#T[_4@)7,N`-#A\>_U\^G<\^CGZN4@
M\_;<Z^SA(.KA]-P@].?M(.7L]MSMZ?/G(.'U]._](/3O]2#T[-[LX?3O\B#T
M[_4@[.?M_>SA]._R+@#0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#E
MZ?/AX_GCWB#DY>3O[-WM^>T@Q.GE]>CU[?/I[^/QW/;O]2X`T.'Q[_7SZ=SS
MZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@]._U(./EX^_M[_3O\CH@
M)7,N`-#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(.3E
MY._LW>WY[2#G[.7Q[^OOX]_O]2X`T.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'T
MW"#TY^T@Y>GSX>/YX]X@].?R(.7QX^'SW^'R.B`E<RX`T.'Q[_7SZ=SSZ.?J
MY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@\.OG\>_V[_'I_NT@Y.GAZ.7S
MZ>S\].?TX?(Z("5S+@#0X?'O]?/IW//HY^KE(//VW.OLX2#S].<@]OSQ[.$@
M\?7H[-_SY?GM+B"Z\_GR(.'VWO/A].4@ZN7M_"#JW/#OZ>\@X?#AZ?3O_>SE
M[>\@\.7DW^\N`-#A\>_U\^G<\^CGZN4@\_;<Z^SA(//TY^T@Y>KTW>OE\^<@
M].?R(.KAZ._QZ?/LW>WG\B#KY>GT[_7QX]_A\B#T[_4@Q.GE]>CU[?/I[^/Q
MW/;O]2X@T.'QX>KAZ_X@Y._JZ>S<\_3E(.'QX_STY?'A+@!"96D@9&5R($%K
M='5A;&ES:65R=6YG(&1E<B!+;VYT86MT9&5T86EL<R!I<W0@96EN($9E:&QE
M<B!A=69G971R971E;BX@0FET=&4@=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@
M;F]C:"!E:6YM86PN`-#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7M
MY^S=\?GSYR#TY_(@Z]_S].'R(.3IX>WO[-[R+B#0X?'AZN'K_B#D[^KI[-SS
M].4@X?'C_/3E\>$N`,'E\>_KZ>S=[>'R(,CE\_/AZ^_MW^KG\@#/(.7N]?#G
M\>7TY_3>\B!)34%0(.3E[2#U\._S].?QW^;EZ2#J[^GM_/?QY_/T[_7R(/;A
MZMWK[_7R+@#!]?3>(.<@Y>W=\>/EZ>$@Y.7M(/7P[_/TY_'?YN7TX>DN`,'U
M]-X@YR#KY>GT[_7QX]_A(.3E[2#=]^7I(._K[^KKY_'YZ.7?(.'J_.SG+@#!
M]?3\(.3E(/;AW^WE].'I(.WA(.7?[>'I(-WCZO7Q[R#A\??EW^\@<F%R+@#!
M]?3\(.3E(/;AW^WE].'I(.WA(.7?[>'I(-WCZO7Q[R#A\??EW^\@>FEP+@#!
M]?3\(.3E(/;AW^WE].'I(.WA(.7?[>'I(-WCZO7Q[_(@X?'IZ.S\\B#JW/'T
MX?(N`,'U]/SR(.\@[^3GX_SR(//A\B#E\.GT\=WPY>D@[>$@\_3=Z^WE].4@
M[.?M_>SA].$@[-WS^2!#;&EC:V%T96QL+2AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(.S=\_D@2%144"U!4$DN`,'U]/SR(.\@[^3GX_SR(//A\B#E\.GT\=WP
MY>D@[>$@\_3=Z^WE].4@[.?M_>SA].$@[-WS^2!S;7,R96UA:6PM*&AT='`Z
M+R]S;7,R;6%I;"YC;VTI(.S=\_D@2%144"U!4$DN`,'U]/SR(.\@[^3GX_SR
M(//A\B#E\.GT\=WPY>D@[>$@\_3=Z^WE].4@[.?M_>SA].$@[-WS^2!33510
M("#JX>D@].?R(%9O9&%F;VYE+4ET86QY(.S\[>\@\^4@X?'IZ.SO_?(@5F]D
M869O;F4N(,'PX>GTY=\@W>WA(.OOX^'QZ>'S[/P@96UA:6P@\_3G(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`-3O(/#EY-_O(.'U]/P@
MX?#AZ?3EW_3AZ2X`U.\@\.7DW^\@X?7T_"#L\._QY=\@[>$@W??EZ2#L_.WO
M(.'JW?'AZ>_U\BX`P?7T_"#T[R#PY>3?[_4@[/#O\>7?(.WA(/#E\>G=]^7I
M(.S\[>\@X?'IZ.SO_?(@ZN'I(-SM^2#JW/3Y(/3EZ^7?X2`H.BDN`,'U]/P@
M].\@\.7DW^\@[/#O\>7?(.WA(/#E\>G=]^7I(.S\[>\@[^KTX>3IZMWR(/3I
M[-WR+@#!]?3\(/3O(/#EY-_O(.SP[_'EWR#MX2#PY?'IW??EZ2#L_.WO(.O?
M\_3A(.'QZ>CL_NT@]_GQZ?/LW>WY[2#LY2#JY>W\(-X@Y>OKY^WIZOP@Y?'Y
M].?LX?3IZOP`P?7T_"#T[R#PY>3?[R#P\=WPY>D@[>$@Y=_MX>D@W>WA\B#=
MX^KU\>_R(.'QZ>CL_/(N`,'U]/P@].\@\.7DW^\@\/'=\.7I(.WA(/#E\>G=
M]^7I(.KYY.GJ_"#W\?[LX?3O\B#SY2!21T(@Y.7JX>7NX>3IZMX@[._Q]MXL
M(/`N]RX@)R,Q,C,T868G+@#!]?3\(/3O(.'Q]^7?[R#PY?'IW??EZ2#T[_7R
M($U)344@9')I=F5R<R#P[_4@]_'G\^GL[_#OZ>_][?3AZ2#A\/P@].?M(/7P
MY_'E\]_A(.7PZ?3QW?#O[?3A\B#DZ=SV[_'A(/#Q[^/QW.SLX?3A(.WA(.3I
MX??EZ?'?YN_M].'I(/3A(/#E\>GE]_SLY>WA(/3Y[2!E;6%I;"#JX>D@[>$@
M].$@Y>SVX>W?YN_U[2#LY2#T[^T@ZN'TW.OKY^OO(/3Q_/#O+@#!]?3\(/3O
M(.'Q]^7?[R#EZ]WC]^7I(/3I\B#Q]>CLW_/EZ?(@]/GM(/?Q^>S<]/GM(.KA
MZ2#T^>T@X_'A[.SA]._SY>GQ_NT@X^GA(/SKX2#T[R#P\?SC\>'L[.$@]._U
M($AO<F1E+"#JX>D@X^GA(/3I\B#E]N'Q[._CW?(@\._U(.7?[>'I(.7CZN'T
MY?/TY^S=[>7R(//E(.'U]/P@ZN'I(.3E[2#PX?'=]^_U[2#DZ>K=\B#T[_7R
M(.7PZ>OOX]WR(./IX2#A]?3=\B#TZ?(@\?7H[-_SY>GR+@#!]?3\(/3O(.'Q
M]^7?[R#JX?3AX_'<]N7I(/3I\B#E\.7J]-SSY>GR(/3Y[2#T_?#Y[2#,R<S%
M+"#^\_3E(/3A(/#E\>GE]_SLY>WA(._QZ?/LW>WY[2!M86EL(.WA(.7L]N'M
MW^;O[?3AZ2#LY2#T[^T@ZN'TW.OKY^OO(/3Q_/#O+@#!]?3>(.<@]OSQ[.$@
MW??EZ2#>Y.<@Y?#E[N7QX^'SZ.7?+@#!]?3\(.7?[>'I("5S+@#!]?3\(.7?
M[>'I($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(,/IX2#MX2#DY=_TY2#T[R#A
M[?3IZN7?[.7M[R#A]?3\(/?QY>G<YN7SZ.4@W>WA(/#Q_./QX>SLX2!E;6%I
M;"#P[_4@ZN'TX>OAXN'?[>7I(.'U]-X@].<@[._Q]MXN(,/IX2#KW_/TX2#T
MW?3OZ?GM(/#Q[^/QX>SLW/3Y[2#L\._QY=_TY2#MX2#E\.GSZN7UZ.7?].4@
M].\@)7,`P?7T_"#EW^WAZ2#T[R#BX?/IZOP@X?'WY=_O(/'UZ.S?\^7Y[2#T
M[_4@\/'OX_'<[.SA]._R("=(;W)D92<N(-#E\>G=]^7I(/3A(.SO[>_PW/3I
MX2#JX>D@].$@XN'SZ>K<(.S=\><@\._U(/?QY_/I[._P[^GO_>WTX>D@X?#\
M(/3O[2#P]?'>[>$@ZN'I(/3I\B#E]N'Q[._CW?(@]._U(//U\_3>[.'T[_(N
M(`#4[R#LWNWU[.$@X?7T_"#C\=SVZ.?JY2#LY2#J^>3IZN_SY>O?Y.$@*"5S
M*2#DZ>'V[_'E].GJWB#A\/P@].<@Y.GJWB#SX?(N`,'U]/SR(.\@X?'IZ.S\
M\B#P\=WPY>D@[>$@Y=_MX>D@]._UZ]SWZ?/T[^T@W>WA+@#4[R#P\?SBZ^?L
MX2#A]?3\(.'MX?;=\>CGZN4@X?#\("5S+B#/(/?QWO/TY_(@ZMSKY?/E(/3G
M[3QB<B\^X>WA]N_QW"#P\>_BZ][LX?3O\B#A\/P@].\@\.'QX>K<]/D@55),
M.CQB<B\^)7,@ZN'I(/?QY_/I[._P[^GEWR#T[^T@X>K\Z^_UZ.\@8G)O=W-E
M<CH\8G(O/B5S`,'U]/SR(.\@Y>[U\.?QY?3G]-[R(.3E(.SP[_'EWR#MX2#A
M\._S]>SPZ=WSY>D@>FEP(.KAZ2!G>FEP(.'Q]^7?X2X`U.\@\_WS].?LX2#A
M]?3\(-WWY>D@X?#E[>7QX^_P[^GGZ.7?+@#!]?3>(.<@].GLWB#P\=WPY>D@
M[>$@Y=_MX>D@X?'IZ.S\\BX`Q>GSZ?3>\>GA`-GQX0#)]^WGZ^'T_NWTX?(@
M].?M(/[QX0#,[_'VWB#^\>'R`,7PZ>OOX]X@_O'A\@#4W_3K[_(`U-_TZ^_R
M("A4;V]L=&EP*3H`T/'\\@##Z>$@[>$@ZO'A]-[SY?3E(/#OZ^OA\.O<(.'M
M].GJY=_LY>WA+"#J\>'TWO/TY2#PX?3G[-SM[R#T[R!#;VYT<F]L("A00RD@
MWB#T[R!#;VUM86YD("A-86,I(/#KWNKT\>\L(.7M_B#JW.WE].4@ZNOIZBX`
MT][LY?'A`,7MX>OKX>/>(//E(/#GX^'?[R!(5$U,`,']\>GO`,KO\?7VW@#0
MW.WY(/#KX=_SZ>\@*%]T;W`I`,SE].'V\=SSY>GR`,'E\>_KZ>S=[>'R(-3Q
MW_#OZ^?R`,'KY^C=\B#>(/CE]>3=\@#4\0#+X>WHX?/LW>WO\B#T_?#O\B#D
MY>3O[-WM^>TN`-#KY^KT\>_K[^/>\_3E(/3G[2#E\.GK[^/>(//A\CH@`,?K
MY>KT\>_MZ>K>(,3IY?WH]>WSYP#'Z^7J]/'O[>GJWB#$Z>7]Z/7M\^<@X^GA
M(.7PZ?/T\>_VWB#A[>'V[_'<\B#JX?3<\_3A\^?R(/3O]2#P\>_C\=SL[.'T
M_/(@\^'R`,?KY>KT\>_MZ>K>(,3IY?WH]>WSYSH`P>3][>'TYR#G(/#Q_//B
MX?/G(//T[^T@5D93(.KA]-SK[^/O+@#!Y/WMX?3G(.<@\/'O\^C>ZN4@Y?#I
M\.O=[^T@\.OG\>_V[_'I_NT@ZN'TW"#TY^T@Y=_S[^3O(/3O]2#W\=[S].<N
M`,'D_>WA].<@YR#AZ^OAX]X@Y>[O]?/I[^3O]-[SY?GM(./IX2#T[R!61E,@
MX?'WY=_O("(E<R(N`,'D_>WA].<@YR#AZ^OAX]X@Y>[O]?/I[^3O]-[SY?GM
M(./IX2#T[R!61E,@X?'WY=_O("5S+R5S+@#!Y/WMX?3G(.<@X>OKX>/>(/3O
M]2`E<RX`Q.7M(.7?[>'I(.3U[>'TWB#G(//][>3E\^<@\_3O(.3IX>KO[.GS
M]-X@4U%,+@#$Y>T@Y=_MX>D@Y/7MX?3>(.<@\_WMY.7SYR#LY2!34TPN`,'D
M_>WA].<@YR#A[?3IX_'A]MX@5D93(.'Q]^7?[_4N`,'D_>WA].<@YR#DY^SI
M[_7QX]_A(.KA].'K_./O]2!61E,@(B5S(BX`P>3][>'TYR#G(.3G[.GO]?'C
MW^$@ZN'TX>O\X^_U(%9&4RX`P>3][>'TYR#G(.3G[.GO]?'CW^$@5D93(.'Q
M]^7?[_4N`,'D_>WA].<@YR#DY^SI[_7QX]_A(.KE[>_](%9&4R#A\??EW^_U
M+@#!Y/WMX?3G(.<@X?#O\_7L\-_E\^<@Y.7D[^S=[?GM+@#!Y/WMX?3G(.<@
MY.GAX_'A]MX@(B5S(BP@[R#VW.KEZ^_R(.3E[2#EW^WAZ2#JY>W\\BX`P>3]
M[>'TYR#G(.3IX>/QX?;>("5S+"#O(/;<ZN7K[_(@Y.7M(.7?[>'I(.KE[?SR
M`,'D_>WA].<@YR#DZ>'C\>'VWB`G)7,G.B`E<RX`P>3][>'TYR#G(.3IX>/Q
MX?;>(.KA].'K_./O]2!61E,@Y?#A[>'K[.+A[?SLY>WA("AR96-U<G-I=F5L
M>2DN`,'D_>WA].<@YR#DZ>'C\>'VWB#JX?3AZ_SC[_4@5D93+@!$87,@5D93
M+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XZ("5S
M+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@]._U(%9&4R#A\??EW^_U("(E<R(N`,'D
M_>WA].<@YR#DZ>'C\>'VWB#T[_4@5D93(.'Q]^7?[_4N`,'D_>WA].<@YR#D
MZ>'C\>'VWB!61E,@Y?#A[>'KX>SBX>W\[.7MX2`H<F5C=7)S:79E;'DI.B`E
M<RX`Q.4@[/#O\?X@[>$@\/'O\^3I[_'?\_D@]._M(/3QW??O[?3A(.KA]-SK
M[^/O+@#$Y2#L\._Q_B#MX2#E[MSC^2#PZ^?Q[_;O\=_E\B#PZ?/T[_#OZ>?T
MZ>KO_0#!Y/WMX?3G(.<@]OSQ]/GSYR#O\>GS[._](/3O]2`E<RX`P>3][>'T
MYR#G(.SE].'JW^WG\^<@]._U(%9&4R#A\???[_4N`,'D_>WA].\@].\@W.WO
MZ>/LX2#T[_4@5D93(.'Q]^7?[_4@(B5S(BX`P>3][>'T[R#T[R#<[>_IX^SA
M(/3O]2!61E,@X?'WY=_O]2#CZ>$@X_'<^.GL[RX`P>3][>'T[R#T[R#<[>_I
MX^SA(/3O]2!61E,@X?'WY=_O]2X`Q.4@[/#O\?X@[>$@X>WOW^[Y(/3O(//U
M[/#IY?/LW>WO(.'Q]^7?[RX`Q.4@[/#O\?X@[>$@Y.GAXMSS^2#T[^T@ZOWQ
MZ>\@ZN'TW.OOX^\@5D93("AV9G-R;V]T*2X`Q.7M(.7?[>'I(.3U[>'T_.T@
M[>$@ZN'TX??Y\>?H[_WM(._I(/#Q[_3I[-[SY>GR(./IX2#A]?3>(/3G[2#S
M_>WDY?/G+@#!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U("5S(//E("5S.B#O
M(/;<ZN7KZ^_R(/7PW/'WY>D@WN3G`,'D_>WA].<@YR#LY?3O[>_LX?/?X2#T
M[_4@5D93(.KA].'K_./O]2X`P>3][>'TYR#G(.SE]._M[^SA\]_A(/3O]2!6
M1E,@ZN'TX>O\X^_U.B`E<RX`P>3][>'TYR#G(.SE]._M[^SA\]_A(/3O]2!6
M1E,@X?'WY=_O]2`B)7,B+@#!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&
M4R#A\??EW^_U("5S+R5S+@#!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&
M4R#A\??EW^_U+@#!Y/WMX?3G(.<@Y>KTW>OE\^<@]._U(")M:VES;V9S(BX`
MQ.7M(.SP_/'E\^4@[>$@[.7TX?;QX?/TY=\@X?7T_"#T[R#=X^/QX?;O(%=O
M<F0`Q.4@[/#O\?X@[>$@X_'<^/D@\_3O(%9&4R#A\??EW^\@(B5S(BX`Q.4@
M[/#O\?X@[>$@X_'<^.<@\_3O(%9&4R#A\??EW^\@*&-O<'DH*2#A\-WT]??E
M*2X`Q.4@[/#O\?X@[>$@X_'<^/D@Y.7D[^S=[>$@]._U(%9&4R#A\??EW^_U
M+@#5\._C\>'L[.GS[-WMX0#!ZOWQ^?/G(,'KZ^'C_NT`P>KU\?[MY>D@].<@
M].7KY?7TX=_A(//A\B#E[=WQX^7IX0#,YR#A[>'LY>W\[.7M[R#TW>OO\B#T
M[_4@X?'WY=_O]2X`S.<@X>WA[.7M_.SE[><@X?#<[?3G\^<@X?#\(/3O[2#E
M[O7PY_'E].?TWB#S].<@\_WMY.7SYSH@`,SG(.'MX>SE[?SLY>WG(.'PW.WT
MY_/G(.'P_"#T[^T@Y>[U\.?QY?3G]-X@\_3O.B``S.<@P?'WY>GOZ.7TY^S=
M[>\`S.<@]^7I\>GF_.SE[>\@\_3OZ??EW^\@]/WP[_4Z("5S`,SO[=SDY?(`
MP>/M^?/T[P!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N
M:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`P>/M^?/T[R#\
M[>_LX2#W\=[S].<@WB#J^>3IZOSR+@#!\._S_>WDY?/G(/3QW??O[?3O\B#S
M]._I]^7?[_4`P>W^[?7L[P#,YR#E[N_U\^GOY._TY^S=[>$@\/'OX_'<[.SA
M].$@Y.4@[/#O\>_][2#MX2#=]^_U[2#P\?SSXN'SYR#SY2#KY>GT[_7QX]_E
M\B#A\._J[_#>\B_A[?3IX_'A]M[R+^7PZ>K\Z^?SY_(@X^GA(.O\X^_U\B#A
M\_;AZ^7?X?(N(-#A]-[S].4@S\H@X^GA(.WA(.3EW_3E(/3E]^WIZMWR(//G
M[.7I_O/EZ?(@\_3O(&UO>FEL;&$N;W)G(/#O]2#SX?(@Y.7?]^WO]>T@\/GR
M(.WA(.7PZ?3QW?CE].4@\^4@\/'OX_'<[.SA].$@].<@\/'\\^+A\^<@\_3O
M(&-L:7!B;V%R9`#,YR#O\>GS[-WM[R#W\?[LX0#,YR#U\._S].?QZ>;\[.7M
MYR#E\-WJ].'SYP#%[>?LW?'Y\^<`Q>WG[-WQ^?/G("5S`,7MY^S=\?GSYR#J
MX?3<\_3A\^?R(.'PX>WTY^S=[>_U`,7MY^S=\?GSYR#W\=[S].<`)R5S)R#%
M[>?LY?'^Z.?JY2X`U.\@\/'\X_'A[.SA(.'MX>+<Z.SI\^?R(.3IX>/QW/;G
MZN4N`,'P[_/T[^O>`,'P[_/T[^O>(/SK^>T@]/GM(.'Q]^7?^>T@\?7H[-_S
MY?GM(//T[^T@Y>[U\.?QY?3G]-XN`,KE]N'KX=_A(.OA].GMZ>K<(./QW.SL
MX?3A`-'Y[.'ZZN_?(.'QZ>CL[]\MRN7VX>OAW^$`U_'>\^<@]/'=]^_M]._R
M.B`E<P#-X2#W\>?SZ>SO\._IY^CEWR#G(/#Q[^7PZ>OEX^S=[><@].GLW@#7
M\=[SYR!34TP`U_'G\^GL[_#OZ>7?].'I(.'M(/3O(/SM[^SA+^KYY.GJ_/(@
MY=_MX>D@Y.GA]N_QY?3IZMPN`,\@]_'>\_3G\B`E<R#DY>T@Y=_MX>D@Y>[O
M]?/I[^3O].?LW>WO\B#CZ>$@)7,N`,3IX??EW_'I\^<@U_'G\_3^[0#%\.GK
M[^/=\B#7\=[S].<`Q>/C\>'VWB#7\=[S].<`QR#EX^/QX?;>(/?QWO/TYR#=
M]^7I(.'PY>WE\>/O\._IY^CEWR#CZ2<@X?7T_"#T[R!S:71E+@#!Z^OAX]X@
MZOGDZ>KO_2#W\=[S].<`Q>[O]?/I[^3O]-[SY>GR(-?QWO/TYP"\[>_LX2#7
M\=[S].<`U.\@_.WO[.$@]_'>\_3G("<E<R<@]?#<\??EZ2#>Y.<N`+SM[^SA
M(-?QWO/TYSH`O.WO[.$@U_'>\_3G.B``U_'>\_3E\@#7\=[S].7R(//T[R#3
M_?/TY^SA.@#/(.KA]-SK[^/O\B!61E,@Y.7M(/7PW/'WY>DN`,3IX>KO\-WR
M`+CCZO7QY?(@]._P[^CE\]_E\B#P[_4@XO'=Z.?JX>T@\_7L\.7QZ>OA[.+<
M[>_M].'I.B``Q>/J]?'\].?TX0#4Z>S>(//E(.OE\/3<(.'P_"#T_O'A+@#4
MZ>S=\@#$_O/TY2#TZ>S=\B#CZ>$@[>$@Y?#IZ]WN^0#,Y?3AXNOG]-X`QR#E
M\.GBY>+AW_GSYR#A\-WT]??E("T@X?7T_"#T[R#LWNWU[.$@[/#O\>7?(.WA
M(-SKZ^'NY2#LY2X`N.KD[_/G`+CKY>/W[_(@N.KD[_/G\@#*W.CE].<@Q?7H
M]>/QW.SLZ?/G`,K<Z.7T[R#CW>SI\^SA`,K<Z.7TX3H`T._K_2#XY^O>`,7L
M]MSMZ?/G("5S`,7L]MSMZ?/G(.7N^?3E\>GJWO(@Z?/T[_/EZ]_DX?(`Q>SV
MW.WI\^<@\^'M("5S`,7L]MSMZ?/G(./EX^_M_/3O\@#%[/;<[>GSYR#E\>/A
M\]_A\@#/\>'T_/3G].$`S_'A]/STY_3A.@!6;V1A9F]N92#)].'KW^'R(.S=
M\_D@4TU44`#0T<_3S]?'`-#1S]//U\<A(2$@P=;!R='%T]3%(-3/(-#1S\/1
MP<S,P2#,S\W/R2#3P=,@P=#/("5S+@#0\>_EZ>3O\._?Y_/G`-3E`,7BY._L
MX>3IX=_A`,KAZ_GSWNOHX?3E`,KAZ_GSWNOHX?3E(//T[R`E<P#*X>OY\][K
MZ.'TY2P@)7,`T._IW"#E]N'Q[._CWB#HX2#E[/;A[-_FY>D@].\@)7,@X?;O
M_2#S]>WDY>CEW_3E(//TY^T@]?#G\>7SW^$[`-#OZ>$@Y?;A\>SOX]X@[>$@
MY>SVX>W?YN7TX>D@X?;O_2#S]>WDY>CEW_3E(//TY^T@]?#G\>7SW^$[`-#O
MZ?SR(.7?[>'I(.\@Y.GA]_GQZ?/TZ>K\\B#WX?'AZO3>\>'R.P#0[^G\\B#E
MW^WAZ2#O(/?A\>'J]-[QX?(@Y>GSX>/YX^GJ_NT[`-#OZ=WR(-;<\^7I\@#*
MX>CO\=_S].4@\._IW"#P\?SSZ.7TX2#HX2#E[>7QX^_P[^GGZ._][2#S]._M
M(.7PY>[E\>/A\_3>(.7L\.OO]?3I\^S=[>_U(.KEZ>S=[>_U+@#0Z]ST[_(`
MT.O<]._R(//E(.SO[=SDY?(@0U-3`-#KW/3O\B#T[_4@)7,@[.7M[_T@\_3A
M(.'QZ?/TY?'<("CHX2#E]N'Q[._SZ.7?(//TY^T@Y?#\[.7MYR#EW_/OY.\I
M.@#0Z]ST[_(@]._U(/#?[>'JX0#,[^W<Y.$@\.O<]._U\@#0Z]ST[_(Z`+CM
M].'SYR#A[=WL[_4@\^4@ZOSLXN_U\@#![>7L[_(Z`,'MY>SO\CH@`-/O]M_A
M`,O?\_3A(.7PZ>CU[.G^[0#%\>/A\]_A`,3IY?WH]>WSYR#%\>/A\]_A\@#4
MY^O=]OGM[R#%\>/A\]_A\@!8+5)E9@!8-3`Y=C,@PN'SZ>KOWR#0Y?'I[_'I
M\^SOWP!8-3`Y=C,@U_'>\^<@Y?#EZO3A[-WM[_4@ZNOEZ>3I[_T`6#4P.78S
M(,7MX>OAZO3IZOP@O.WO[.$@R-WLX?3O\@!8-3`Y=C,@P>WAX^WY\>GS].GJ
M_"#*Z^7IY-\@R-WLX?3O\@!8-3`Y=C,@Q?#EZO3<\^7I\@#%Q0#%Q<7%`,7T
MWO/IX0#-X=\`S>'I+"#3]>SV^>W^`,7?\_3E(//E(.KA]-SS].'SYR#*Q<G,
MQ<W/U2X@U_'G\^GL[_#OZ>7?\_3E(/3O(%L\/ET@\.O>ZO3Q[R#CZ>$@[>$@
MY?#I\_3QW?CE].4@\^4@ZN'TW//TX?/G(%=94TE724<N`,3E[2#=]^7TY2#A
M]>CE[?3IZN_P[^GGZ.7?+@#$Y>T@Y?#I]/'=\.7TX>D@[>$@W??E].4@].\@
M]^'QX>KTWO'A("=<)R#S].\@O.WO[-P@\^'R+@#$Y2#D_O/A].4@W>/C]?'G
M(.3IY?WH]>WSYR!E;6%I;"X`Q.7M(.'M].GS]._I]]_SX?3E(.KA[=WMX2#P
MY>3?[R#A\/P@].\@X?'WY=_O(.7I\^'C^>/>\B#SY2#A[?3?\_3OZ??A(/#E
MY-_A(//T[R`E<RX`N/?E].4@X?#O\_7MY.7HY=\N`+CWY?3E(.'P[_/U[>3E
MZ.7?+CQB<B`O/L7U]^'QZ?/T[_WLY2#P[_4@]_'G\^GL[_#OZ=[SX?3E(/3G
M[2#U\.?QY?/?X2X`T/'=\.7I(.WA(.3^\^7TY2#LZ>$@W>/J]?'G(/3I[-XN
M`-#QW?#EZ2#MX2#Q]>CLW_/E].4@].\@1&%T851R964@X^GA(.WA(/?QY_/I
M[._P[^GEW_3E(%-I9VYU<',N`-#QW?#EZ2#MX2#Q]>CLW_/E].4@].\@5D93
M+4)A8VME;F0N`-#QW?#EZ2#MX2#PY?'IX_'<^.7TY2#T[R#P\?SBZ^?LX2#P
M\>GM(//TY=_KY?3E(.'MX?;O\=P@X^GA(.'U]/PN`-#QW?#EZ2#MX2#S]>SP
MZ^?Q_O/E].4@].\@55),(/#O]2#DY=_W[>7I(.'U]-X@YR#S_>WDY?/G`-#Q
MW?#EZ2#MX2#E\.GKW>[E].4@]._M(.7N]?#G\>7TY_3>(./IX2#DZ>'C\>'V
MWBX`T/'=\.7I(.WA(._QW_/E].4@W>WA(/SM[^SA(/?QWO/TYR#CZ>$@Y.GA
MX_'A]MXN`-#QW?#EZ2#MX2#O\=_SY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA
M(.3IX>/QX?;>+@#0\=WPY>D@[>$@[_'?\^7TY2#=[>$@_.WO[.$@]_'>\_3G
M(./IX2#P\>_SZ-[JYRX`T/'=\.7I(.WA(._QW_/E].4@W>WA(/SM[^SA(/?Q
MWO/TYR#CZ>$@Y>WG[-WQ^?/G+@#0\=WPY>D@[>$@[_'?\^7TY2#LZ>$@Y>W=
M\>/EZ>$@X^GA(.7J]-WKY?/G+@#0\=WPY>D@[>$@Y/[SY?3E(-WMX2#\[>_L
MX2#CZ>$@].<@[=WA(.KA].?C[_'?X2X`QR#S_>WDY?/G(//A\B`E<R#DZ>'J
M_/#GZN4N(-#A\>'JX>O^(.3OZNGLW//TY2#MX2#NX>WA\_7MY.7HY=_TY2X`
MQR#'Z^7J]/'O[>GJWB#SX?(@Q.GE_>CU[?/G`,<@Q^OEZO3Q[^WIZMX@\^'R
M(,3IY?WH]>WSYSH`QR#!\/PZ(,3IY?WH]>WSYSH`S^D@T.OG\>_V[_'?Y?(@
M\^'R`,<@26YT97)N970@Y.GE_>CU[?/>(//A\B#<Z^OA[N4@X?#\(/3G[2#=
M[>'Q[N<@].?R("5S(//][>3E\][R(//A\BX@P^GA(/3G[2#P\>_S].'SW^$@
M].?R(.'S]MSKY>GA\B#P\=WPY>D@[>$@[N'MX?/U[>3EZ.7?].4N`-3O(/SM
M[^S<(//A\@#4[R#S_?/TY^SA(.'UZ.7M].GJ[_#OW^?SY_(@Y.7M(/7P[_/T
MY_'?YN7I(/#Q[_/HWNKG(/?QY_/T_NTL(-X@YR#KY>GT[_7QX]_A(.'U]-X@
MW??EZ2#A\.7MY?'C[_#OZ>?HY=\@X^GA(.K<\._I[R#K_./O+@#4[R#S_?/T
MY^SA(.'UZ.7M].GJ[_#OW^?SY_(@Y.7M(/7P[_/TY_'?YN7I(.O?\_3A(/?Q
MY_/T_NTL(-X@YR#KY>GT[_7QX]_A(.'U]-X@W??EZ2#A\.7MY?'C[_#OZ>?H
MY=\@X^GA(.K<\._I[R#K_./O+@#/($)R;W=S97(@\^'R(/;AW^WE].'I(.WA
M(-WWY>D@X>OKW.[EZ2#A\/P@].?M(-WMX?'NYR#TY_(@)7,@\_WMY.7SWO(@
M\^'R+B##Z>$@].?M(/#Q[_/TX?/?X2#TY_(@X?/VW.OEZ>'R+"#HX2#P\=WP
MY>D@[>$@[N'MX?/U[>3EZ.7?].4N`,\@0G)O=W-E<B#SX?(@Y.7M(/7P[_/T
MY_'?YN7I(.'U]-X@].<@Z^7I]._U\>/?X2X`SR!"<F]W<V5R(//A\B#DY>T@
M]?#O\_3G\=_FY>D@X?7TWB#TY^T@Y?#IZ^_CWB#EZO3]\/GSY_(N(-#A]-[S
M].4@0V]N=')O;"]/<'1I;VX@*R!0(./IX2#EZO3]\/GSYRX`QR#T\=WW[_7S
MX2#F_NWG(/[QX?(Z`,<@\/'OZN'H[_'I\^S=[><@\^'R(/3A]?3\].?TX3H`
MU.\@\.O>\>7R(/SM[^S<(//A\CH`SR#MW>_R(//A\B#J^>3IZOSR(./IX2`E
M<R#EW^WAZ3H@)7,`S^D@Y?#IZ^_CW?(@\^'R(-WW[_7M(.7MY^SE\?GHY=\@
MX^GA(/3G(.3IW/'JY>GA(.'U]-[R(/3G\B#S_>WDY?/G\BX`S^D@Y?#IZ^_C
MW?(@\^'R(-WW[_7M(.7MY^SE\?GHY=\N`,\@ZOGDZ>K\\B#SX?(@W.OKX>[E
M`,\@ZOGDZ>K\\B#SX?(@W.OKX>[E+"#EZ]WC[O3E(/3A(.SG[?WLX?3<(//A
M\B#JX>D@ZMSM].4@Y=_S[^3O(.SE(/3O(.W=[R#SX?(@ZOGDZ>K\+@#/Z2#M
MW>_I(.KYY.GJ[]\@Y.7M(/3AZ?'IW.;O]>T`S^D@X?#O[.'J\?7S[-WM[^D@
M\^'R(.7N]?#G\>7TY_3=\CH`6\'P_.KQ]?CG(.KEZ>S=[>_U(//E(.7I\^'C
M^>/IZMQ=`%O![>'V[_'<(-#Q[^+KWNSA]._R70!;Q>SVW.WI\^<@ZN7I[-WM
M[_4@\^4@Y>GSX>/YX^GJW"`M`%O%[/;<[>GSYR#JY>GLW>WO]2#SY2#EZ?/A
MX_GCZ>K<("T@)7,@X_'A[.S=\ET`6^/QX>SLWB`E<R#A\/P@)7-=`,3IX??E
MW_'I\^<`Q.GAX_'A]MX@P_'A[.S>\@#/[-SDY?(`PN_>Z.7IX0#)Y.G\].?T
MY?(@Q>GJ_.WA\BXN+@#%W_/OY._R`,7N[^3O\@#4\>_P[_#OW^?SYR#3_>WD
MY?/L[_4N+BX`Q?#IZ^_CW?(`Q>[O]?/I[^3O]-[SY>GR`,3IX>/QX?;>(-/U
M[>3=\^SO]2XN+@#1]>CLW_/EZ?(`R>3I_/3G].7R(-#?[>'JX2XN+@#7\=[S
M].7R`,3IY?7H]>WSZ>_C\=SV[_(`Q^SE\>_K_./I[P#G\>7LW^$`\.'TWO/T
MY2#EY/X`X?'WY=_O`.'P_"#T[R`E<R`H)7,I(//TZ?(@)7,@)7,`:#H`W.SE
M\^$`Y>WS^>SA]/GLW>WO`./QX>SLW?)=`&UK:7-O9G,MZOGDZ>K\\B#KW.CO
M]?(@)60@ZN'TW"#TYR#DY^SI[_7QX]_A($E33RX`_.WO[.$`Y.7M(-WWY>D@
MY>/JX?3A\_3AZ.7?`.3E[2#=]^7I(.7CZN'TX?/TX>CEWR#AZOSLYP#SY^SE
MZ?GLX?3<\>GO`/3OZ?(@Y>KA]/P`Y>GJ[^WO\_3OZ??EW^$`Y>SVW.WI\^<@
MY.GA]N_Q_NT`<VUS(//E(&5M86EL(.S=\_D@2%144`#S].'HY?'\\@#KW_/T
MX2#E\>/A\^G^[0#JW.3O\@##\=SX].4@]._M(.KYY.GJ_"#D_>\@]N_QW?(@
MX^GA(.7PZ>+EXN'?^?/G`.7M[_#OZ>?LW>WA`.'M_NWU[.$`Y?#IZ^_CWB#W
M\=[S].<`V.?VZ>'JWB#*W/'TX0``````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O96Q?1U(O:&5L<"YX;6P`````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-#$W,S8R-S<V`#`R
M,#,R-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO
M8V%L92]E;%]'4B]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$V
M(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S
M=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\
M<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M
M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R
M(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M
M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V
M96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@
M;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@
M86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O
M;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U
M8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN
M9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^
M"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A
M<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@
M97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D
M92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O
M<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC
M871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE
M(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC
M871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N
M('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W
M:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N
M86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA
M:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT
M96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M
M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T
M:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O
M<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M
M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@
M;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V5N7U53+P``````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-@`P,38W,#$`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O96Y?55,O:&5L<"YX;6P`
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,3$T`#$P
M-#$W,S8R-S<V`#`R,#,T-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/&AE;'`^"@H\
M96YT<GD@:60](G-U;6UA<GDB/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T
M:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q
M=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T
M:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@
M92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C
M;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@
M=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E
M<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S
M('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T
M:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L
M(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*
M(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A
M;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N
M+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T
M;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN
M('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y
M/@H*/&5N=')Y(&ED/2)N879B87(B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N
M($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T
M(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N
M(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES
M(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*
M("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A
M/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN
M=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L
M:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\96YT
M<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC
M93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O
M(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R
M92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W
M:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E
M('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V5S7T53+P``````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W-@`P,38V-C8`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O97-?
M15,O3$-?34534T%'15,O````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8R-S<V`#`R,#0U,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]E<U]%4R],0U]-15-304=%4R]H;W)D92YM;P``````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`T,C$R,#,`,3`T,3<S-C(W-S8`,#(R,3$P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````-X2
M!)4`````B0<``!P```!D/```$PH``*QX````````^*````X```#YH```#P``
M``BA```-````&*$```@````FH0``"P```"^A```,````.Z$```0```!(H0``
M&````$VA```;````9J$``"T```""H0``'0```+"A```D````SJ$``"D```#S
MH0``&0```!VB```F````-Z(```P```!>H@``)````&NB```/````D*(```L`
M``"@H@``#@```*RB```%````NZ(``"@```#!H@``"````.JB```*````\Z(`
M`!4```#^H@``$@```!2C```+````)Z,``(4````SHP``#@```+FC```*````
MR*,```T```#3HP``#@```.&C```1````\*,```T````"I```#````!"D```-
M````':0```8````KI```E````#*D```*````QZ0```\```#2I```&````.*D
M```,````^Z0```X````(I0``#@```!>E```(````)J4```D````OI0``+@``
M`#FE```:````:*4``#(```"#I0``.````+:E``!4````[Z4``%$```!$I@``
M6@```):F``!7````\:8``#0```!)IP``"0```'ZG```-````B*<```<```"6
MIP``"@```)ZG```/````J:<```4```"YIP``!@```+^G```1````QJ<```@`
M``#8IP``"0```.&G```)````ZZ<``"4```#UIP``(````!NH```3````/*@`
M`!````!0J```#P```&&H```*````<:@```,```!\J```#P```("H```4````
MD*@```D```"EJ```#0```*^H```2````O:@``!D```#0J```'@```.JH```/
M````":D```H````9J0``#P```"2I```(````-*D``"0````]J0``%````&*I
M```6````=ZD```@```".J0``3@```)>I```M````YJD``!D````4J@``!P``
M`"ZJ```,````-JH``"P```!#J@``#@```'"J```#````?ZH```L```"#J@``
M!P```(^J```'````EZH```4```"?J@``!0```*6J```*````JZH```,```"V
MJ@``%P```+JJ```*````TJH```\```#=J@``#@```.VJ```8````_*H``",`
M```5JP``#@```#FK```4````2*L``!<```!=JP``%P```'6K```7````C:L`
M`!,```"EJP``#P```+FK```.````R:L``!\```#8JP``'0```/BK```'````
M%JP```8````>K```"````"6L```/````+JP```8````^K```"@```$6L```3
M````4*P```L```!DK```$````'"L```5````@:P``!4```"7K```!P```*VL
M```0````M:P```4```#&K```%0```,RL```1````XJP```P```#TK```.P``
M``&M```X````/:T```D```!VK0``!P```("M```4````B*T```,```"=K0``
M!0```*&M```0````IZT```D```"XK0``$P```,*M```Y````UJT``!(````0
MK@``)P```".N```L````2ZX``"H```!XK@``)0```*.N```*````R:X```8`
M``#4K@``"0```-NN```'````Y:X``"\```#MK@``-P```!VO```N````5:\`
M`%4```"$KP``+0```-JO```M````"+```#T````VL```/P```'2P```M````
MM+```$````#BL```(P```".Q```C````1[$``$````!KL0``+0```*RQ```S
M````VK$``"4````.L@``%0```#2R```9````2K(``"D```!DL@``)````(ZR
M```H````L[(``!$```#<L@``"@```.ZR```,````^;(```H````&LP``$```
M`!&S```6````(K,``!8````YLP``!P```%"S```'````6+,``!0```!@LP``
M"@```'6S```(````@+,``"<```")LP``"````+&S```'````NK,```<```#"
MLP``!@```,JS```%````T;,```<```#7LP``!@```-^S```(````YK,``"D`
M``#OLP``#@```!FT```*````*+0```0````SM```!P```#BT```)````0+0`
M``8```!*M```$0```%&T```'````8[0``!8```!KM```!````(*T```(````
MA[0```8```"0M```#0```)>T```&````I;0``!X```"LM```$0```,NT```(
M````W;0```T```#FM```#````/2T```'`````;4```,````)M0```P````VU
M```7````$;4``!,````IM0``'0```#VU```(````6[4```0```!DM0``"```
M`&FU```(````<K4``$$```![M0``&@```+VU```K````V+4``"`````$M@``
M%0```"6V```&````.[8```8```!"M@``%0```$FV```8````7[8``"(```!X
MM@``+@```)NV```=````RK8``"$```#HM@``5`````JW```I````7[<```H`
M``")MP``!P```)2W```'````G+<``!4```"DMP``#@```+JW```*````R;<`
M``\```#4MP``#0```.2W```/````\K<```T````"N```"0```!"X```4````
M&K@```8````ON```&````#:X```=````3[@``!,```!MN```$0```(&X```4
M````D[@```0```"HN```!@```*VX```4````M+@``%0```#)N```9````!ZY
M```$````@[D```X```"(N0``!0```)>Y```%````G;D``!L```"CN0``&@``
M`+^Y```3````VKD``!$```#NN0``$0````"Z```<````$KH``"H````ON@``
M$````%JZ```A````:[H```4```"-N@``$P```).Z```+````I[H``!(```"S
MN@``"@```,:Z```/````T;H```T```#AN@``$0```.^Z```3`````;L```P`
M```5NP``!@```"*[```,````*;L```8````VNP``%P```#V[```0````5;L`
M`!$```!FNP``"````'B[```%````@;L```P```"'NP``$````)2[```%````
MI;L```T```"KNP``!@```+F[```'````P+L```T```#(NP``!P```-:[```+
M````WKL```<```#JNP``!P```/*[```)````^KL```D````$O```"@````Z\
M```9````&;P``#T````SO```'0```'&\```,````C[P``!````"<O```!0``
M`*V\```E````L[P``!(```#9O```$P```.R\```K`````+T``#L````LO0``
M(````&B]```(````B;T``#8```"2O0``(0```,F]```0````Z[T```@```#\
MO0``#`````6^```&````$KX```0````9O@``#P```!Z^```.````+KX```<`
M```]O@``"@```$6^```-````4+X``!\```!>O@``'````'Z^```A````F[X`
M`!X```"]O@``&0```-R^```>````]KX``!L````5OP``(0```#&_```N````
M4[\``"8```""OP``'````*F_```>````QK\``!P```#EOP``)@````+````K
M````*<```#,```!5P```)@```(G````K````L,```#@```#<P```'0```!7!
M```5````,\$``"\```!)P0``(````'G!```2````FL$``"D```"MP0``'@``
M`-?!```@````]L$``!(````7P@``H@```"K"```6````S<(``",```#DP@``
M*`````C#```I````,<,``"@```!;PP``'P```(3#```5````I,,``"````"Z
MPP``)0```-O#```H`````<0``"T````JQ```,````%C$``"2````B<0``"$`
M```<Q0``%@```#[%```<````5<4``"8```!RQ0``*@```)G%``!!````Q,4`
M`$0````&Q@``#````$O&```'````6,8```<```!@Q@``!@```&C&```-````
M;\8``!````!]Q@``$@```([&```3````H<8``!(```"UQ@``!P```,C&```$
M````T,8``!````#5Q@``$````.;&```,````]\8```X````$QP``#0```!/'
M```/````(<<``!,````QQP``#0```$7'```H````4\<```,```!\QP``#0``
M`(#'```&````CL<``!$```"5QP``%P```*?'```;````O\<```X```#;QP``
M`@```.K'``!)````[<<```4````WR```$````#W(```/````3L@```0```!>
MR```#0```&/(```.````<<@```,```"`R```#@```(3(```(````D\@```\`
M``"<R```#P```*S(```'````O,@```T```#$R```$````-+(```-````X\@`
M``L```#QR```!@```/W(```+````!,D```P````0R0``"@```!W)```1````
M*,D``!D````ZR0``"P```%3)```-````8,D``"(```!NR0``#P```)')```;
M````H<D``#0```"]R0``"@```/+)```8````_<D``!(````6R@``&0```"G*
M```6````0\H``"(```!:R@``#0```'W*```'````B\H``!0```"3R@``"P``
M`*C*```B````M,H``"\```#7R@``"P````?+```)````$\L``!D````=RP``
M"P```#?+```7````0\L``!<```!;RP``"0```'/+```6````?<L```\```"4
MRP``&0```*3+```6````OLL```X```#5RP``&````.3+```(````_<L```T`
M```&S```)@```!3,``!#````.\P```@```!_S```$@```(C,```?````F\P`
M``@```"[S```"P```,3,```O````T,P```X`````S0``!0````_-```&````
M%<T``$4````<S0```P```&+-```'````9LT```0```!NS0``"@```'/-```*
M````?LT```\```")S0``$````)G-```7````JLT``!$```#"S0``&0```-3-
M```7````[LT```D````&S@``!0```!#.```+````%LX```H````BS@```@``
M`"W.```%````,,X```T````VS@``&P```$3.```7````8,X``!0```!XS@``
M"0```(W.```.````E\X```T```"FS@``$@```+3.```X````Q\X``"``````
MSP``"````"'/```.````*L\``'L````YSP``&````+7/```8````SL\``!$`
M``#GSP``!P```/G/```%`````=```!@````'T```'@```"#0```;````/]``
M`!D```!;T```&P```'70```9````D=```!,```"KT```!P```+_0```(````
MQ]````8```#0T```!@```-?0```0````WM````\```#OT```$````/_0```/
M````$-$```L````@T0``#P```"S1```,````/-$```\```!)T0``!P```%G1
M```&````8=$```X```!HT0``#````'?1```H````A-$```\```"MT0``"```
M`+W1```(````QM$``!,```#/T0``'@```./1```A`````M(``"`````DT@``
M&0```$72```7````7](``"4```!WT@``%P```)W2```6````M=(```0```#,
MT@``&P```-'2```-````[=(```P```#[T@```P````C3```%````#-,```@`
M```2TP``"@```!O3```,````)M,```L````STP``$````#_3```,````4-,`
M``X```!=TP``"P```&S3```$````>-,```0```!]TP``$P```(+3```4````
MEM,```P```"KTP``"0```+C3```.````PM,```L```#1TP``&P```-W3```'
M````^=,```<````!U```"@````G4```-````%-0```D````BU```!````"S4
M```%````,=0```,````WU```&````#O4```*````5-0```0```!?U```)@``
M`&34```.````B]0``'P```":U```%0```!?5```%````+=4```<````SU0``
M#````#O5```(````2-4```H```!1U0``!@```%S5```(````8]4```(```!L
MU0``!@```&_5```&````=M4``!0```!]U0``#0```)+5```0````H-4``!L`
M``"QU0``!````,W5```)````TM4``!````#<U0``"0```.W5```)````]]4`
M``4````!U@``&@````?6```(````(M8```8````KU@``&0```#+6```.````
M3-8```<```!;U@``!P```&/6```%````:]8```D```!QU@``"@```'O6```.
M````AM8```(```"5U@``!@```)C6```+````G]8```T```"KU@``"0```+G6
M```&````P]8``!(```#*U@``"0```-W6```'````Y]8``!0```#OU@``'0``
M``37``!"````(M<``"4```!EUP``)0```(O7```&````L=<```H```"XUP``
M!````,/7```)````R-<```@```#2UP``$0```-O7```)````[=<```8```#W
MUP``#0```/[7```&````#-@```0````3V```.0```!C8```]````4M@``#H`
M``"0V```'@```,O8```%````ZM@```X```#PV```!````/_8```&````!-D`
M``<````+V0``(0```!/9```-````-=D``!4```!#V0``!@```%G9```$````
M8-D``!$```!EV0``!@```'?9```*````?MD``"(```")V0``!````*S9```%
M````L=D``!T```"WV0``!````-79```,````VMD```X```#GV0``"@```/;9
M```(`````=H```D````*V@``!0```!3:```Z````&MH``#````!5V@``-0``
M`(;:```I````O-H``$<```#FV@``.````"[;```I````9]L``#\```"1VP``
M+@```-';```M`````-P``!\````NW```#P```$[<```2````7MP```L```!Q
MW```)@```'W<```I````I-P``"0```#.W```)@```//<```(````&MT```H`
M```CW0``"0```"[=```'````.-T``"````!`W0``(````&'=```F````@MT`
M``H```"IW0``&0```+3=```I````SMT``!8```#XW0``$@````_>```'````
M(MX```H````JW@``#````#7>```/````0MX``!````!2W@``0````&/>``!P
M````I-X``&8````5WP``#@```'S?```)````B]\```H```"5WP``$@```*#?
M```3````L]\```P```#'WP``!@```-3?```/````V]\``!(```#KWP``$```
M`/[?```1````#^```!P````AX```(P```#[@``!J````8N````\```#-X```
M!0```-W@```0````X^````D```#TX```!````/[@```+`````^$``"`````/
MX0``%````##A```,````1>$```P```!2X0``#P```%_A```5````;^$``"D`
M``"%X0``*@```*_A```F````VN$``"<````!X@``*0```"GB```J````4^(`
M`!D```!^X@``0@```)CB```1````V^(``!(```#MX@``$P````#C```4````
M%.,```\````IXP``%@```#GC```7````4.,``!````!HXP``$0```'GC```T
M````B^,``!,```#`XP``$@```-3C```U````Y^,``!0````=Y```!P```#+D
M```,````.N0``"````!'Y```$````&CD```4````>>0``!$```".Y```%P``
M`*#D```<````N.0``!,```#5Y```%````.GD```:````_N0``!$````9Y0``
M&@```"OE```>````1N4``!H```!EY0``$P```(#E```5````E.4``!$```"J
MY0``%P```+SE```4````U.4``!<```#IY0``%0````'F```)````%^8``!``
M```AY@``&0```#+F```$````3.8```<```!1Y@``"P```%GF```1````9>8`
M``8```!WY@``!@```'[F```&````A>8```4```",Y@``!P```)+F```'````
MFN8```4```"BY@``%@```*CF```&````O^8```8```#&Y@``!````,WF```$
M````TN8```<```#7Y@``#@```-_F```,````[N8```P```#[Y@``#0````CG
M```*````%N<```X````AYP``!0```##G```H````-N<```X```!?YP``#```
M`&[G```/````>^<```H```"+YP``"````);G```)````G^<``"L```"IYP``
M!````-7G```(````VN<``"8```#CYP``$@````KH```/````'>@```8````M
MZ```"@```#3H```'````/^@```@```!'Z```(````%#H```)````<>@``!0`
M``![Z```#````)#H```-````G>@```X```"KZ```%@```+KH```1````T>@`
M``8```#CZ````P```.KH```&````[N@``!D```#UZ```!P````_I```$````
M%^D```L````<Z0``"P```"CI```'````-.D```4````\Z0``!P```$+I```6
M````2ND```T```!AZ0``#0```&_I```*````?>D``!````"(Z0``#P```)GI
M```1````J>D``!<```"[Z0``"@```-/I```1````WND```@```#PZ0``!```
M`/GI```/````_ND``#H````.Z@``!0```$GJ```,````3^H``!X```!<Z@``
M#@```'OJ```0````BNH```L```";Z@``#````*?J```)````M.H```<```"^
MZ@``"@```,;J```)````T>H```X```#;Z@``$````.KJ```;````^^H``!@`
M```7ZP``&@```##K```*````2^L```D```!6ZP``"@```&#K```,````:^L`
M``\```!XZP``"````(CK```&````D>L``!P```"8ZP``!P```+7K```%````
MO>L```L```##ZP``1P```,_K```-````%^P```D````E[```!````"_L```#
M````-.P``!,````X[```$P```$SL```3````8.P```H```!T[````@```'_L
M```$````@NP``"4```"'[````P```*WL```%````L>P``"H```"W[```"@``
M`.+L```%````[>P```0```#S[```"@```/CL```-`````^T```8````1[0``
M"````!CM```(````(>T```0````J[0``!0```"_M``!H````->T```D```">
M[0``#````*CM```0````M>T```4```#&[0``!@```,SM```;````T^T``"\`
M``#O[0``$````!_N```*````,.X```\````[[@``"@```$ON```)````5NX`
M`!,```!@[@``&P```'3N```8````D.X``!<```"I[@``'P```,'N```.````
MX>X```,```#P[@``!P```/3N```(````_.X```<````%[P``"@````WO```+
M````&.\```<````D[P``40```"SO```0````?N\```P```"/[P``#0```)SO
M```:````JN\``$H```#%[P``&0```!#P```&````*O```!H````Q\```)0``
M`$SP```&````<O````8```!Y\```'P```(#P```&````H/````D```"G\```
M&````+'P```7````RO```"@```#B\```!@````OQ```-````$O$``"(````@
M\0``5P```$/Q```3````F_$``",```"O\0``$P```-/Q```"````Y_$```L`
M``#J\0``"````/;Q```-````__$```H````-\@``!P```!CR```4````(/(`
M``8````U\@``"````#SR```.````1?(```<```!4\@``"@```%SR```+````
M9_(``#(```!S\@``!P```*;R```,````KO(```T```"[\@``#````,GR```)
M````UO(```D```#@\@``"@```.KR```'````]?(```D```#]\@``!P````?S
M```*````#_,``!L````:\P``#P```#;S```2````1O,```H```!9\P``%@``
M`&3S```)````>_,``!````"%\P``!P```);S```2````GO,```0```"Q\P``
M!P```+;S```%````OO,```4```#$\P``"P```,KS```4````UO,``!$```#K
M\P``&@```/WS```6````&/0``!0````O]```%P```$3T```8````7/0``!P`
M``!U]```&0```)+T```'````K/0```4```"T]```#0```+KT```,````R/0`
M`!$```#5]```"````.?T```7````\/0```L````(]0``#````!3U```?````
M(?4``!H```!!]0``$P```%SU```$````</4```H```!U]0``!````(#U```-
M````A?4```P```"3]0``!0```*#U```)````IO4```4```"P]0``!P```+;U
M```%````OO4```0```#$]0```@```,GU```X````S/4``"P````%]@``$@``
M`#+V```I````1?8``#(```!O]@``"@```*+V```L````K?8``"X```#:]@``
M,P````GW```S````/?<``#@```!Q]P``#P```*KW```8````NO<``!````#3
M]P``#P```.3W```3````]/<``!4````(^```%````![X```2````,_@``!0`
M``!&^```%0```%OX```M````<?@``"T```"?^```,0```,WX```N````__@`
M`"\````N^0``+````%[Y``!B````B_D``!,```#N^0``#0````+Z```(````
M$/H``!<````9^@``"````#'Z```,````.OH``"L```!'^@``(0```'/Z```:
M````E?H```D```"P^@``10```+KZ``!!`````/L```0```!"^P``$P```$?[
M```4````6_L```X```!P^P``$P```'_[```8````D_L```8```"L^P``"0``
M`+/[```*````O?L```\```#(^P``$````-C[```'````Z?L```X```#Q^P``
M!0````#\```;````!OP```@````B_```!@```"O\```4````,OP``!$```!'
M_```#@```%G\```X````:/P```(```"A_```!@```*3\```.````J_P```4`
M``"Z_```!P```,#\```.````R/P```8```#7_```*````-[\```,````!_T`
M`!P````4_0``!````#']```I````-OT``!<```!@_0``'P```'C]``!<````
MF/T``!0```#U_0``/@````K^```?````2?X``!````!I_@``!P```'K^```.
M````@OX```P```"1_@``#````)[^```3````J_X```H```"__@``'0```,K^
M```9````Z/X```4````"_P``$0````C_```1````&O\``"0````L_P``$@``
M`%'_```5````9/\``!(```!Z_P``#@```(W_```9````G/\```@```"V_P``
M"0```+__```-````R?\```<```#7_P``"@```-__```'````ZO\```\```#R
M_P``!@````(``0`+````"0`!`!H````5``$`"@```#```0`'````.P`!``@`
M``!#``$`!0```$P``0`?````4@`!``8```!R``$`$````'D``0`(````B@`!
M``T```"3``$`"````*$``0`>````J@`!`!(```#)``$`+````-P``0`:````
M"0$!``D````D`0$`"@```"X!`0`5````.0$!``4```!/`0$`%````%4!`0`$
M````:@$!`!````!O`0$`!@```(`!`0`'````AP$!`!X```"/`0$`*````*X!
M`0`*````UP$!`!P```#B`0$`$0```/\!`0`+````$0(!`!H````=`@$`%```
M`#@"`0`$````30(!``0```!2`@$`"P```%<"`0`%````8P(!``8```!I`@$`
M"````'`"`0`&````>0(!``H```"``@$`&P```(L"`0`T````IP(!`#0```#<
M`@$`(````!$#`0`I````,@,!`"````!<`P$`00```'T#`0`:````OP,!`"@`
M``#:`P$`*0````,$`0!0````+00!`"(```!^!`$`!@```*$$`0`(````J`0!
M``4```"Q!`$`"````+<$`0`9````P`0!`!D```#:!`$`*@```/0$`0`C````
M'P4!`!D```!#!0$`+@```%T%`0`T````C`4!``@```#!!0$`%P```,H%`0`*
M````X@4!``<```#M!0$`(0```/4%`0`0````%P8!``X````H!@$`"P```#<&
M`0`'````0P8!`!,```!+!@$`"````%\&`0`+````:`8!``H```!T!@$`%```
M`'\&`0`/````E`8!`#(```"D!@$`"P```-<&`0`.````XP8!``4```#R!@$`
M!0```/@&`0`%````_@8!`!<````$!P$`#P```!P'`0`$````+`<!``H````Q
M!P$`"0```#P'`0`+````1@<!``T```!2!P$`#````&`'`0`.````;0<!``4`
M``!\!P$`!````(('`0`-````AP<!`#(```"5!P$`10```,@'`0`7````#@@!
M``<````F"`$`'@```"X(`0`4````30@!``4```!B"`$`%````&@(`0`&````
M?0@!``<```"$"`$`#@```(P(`0`J````FP@!``8```#&"`$`#````,T(`0`-
M````V@@!`!$```#H"`$`"P```/H(`0`V````!@D!``H````]"0$`(@```$@)
M`0`+````:PD!``\```!W"0$`,@```(<)`0`E````N@D!`#````#@"0$`,0``
M`!$*`0`M````0PH!``X```!Q"@$`!0```(`*`0`.````A@H!`!,```"5"@$`
M$@```*D*`0`'````O`H!`!$```#$"@$`$P```-8*`0`'````Z@H!`!0```#R
M"@$`&`````<+`0`'````(`L!``4````H"P$`#````"X+`0`,````.PL!`!(`
M``!("P$`!````%L+`0`'````8`L!``H```!H"P$`"P```',+`0`,````?PL!
M``X```","P$`#@```)L+`0`%````J@L!``4```"P"P$`+@```+8+`0`F````
MY0L!`",````,#`$``P```#`,`0`2````-`P!``8```!'#`$`'@```$X,`0`8
M````;0P!`"4```"&#`$`#0```*P,`0`)````N@P!`!\```#$#`$``P```.0,
M`0`'````Z`P!``H```#P#`$``@```/L,`0`,````_@P!`!4````+#0$`"P``
M`"$-`0`9````+0T!`"````!'#0$`$@```&@-`0`%````>PT!``H```"!#0$`
M%0```(P-`0`2````H@T!``P```"U#0$`!````,(-`0`)````QPT!``<```#1
M#0$`#````-D-`0!2````Y@T!`!<````Y#@$`)````%$.`0`2````=@X!``<`
M``")#@$`!@```)$.`0`.````F`X!``P```"G#@$`#0```+0.`0`5````P@X!
M`!(```#8#@$`#P```.L.`0`4````^PX!``H````0#P$`&P```!L/`0`0````
M-P\!``L```!(#P$`:0```%0/`0`:````O@\!`!<```#9#P$`)P```/$/`0`:
M````&1`!`!<````T$`$`&P```$P0`0`9````:!`!`!\```""$`$`$P```*(0
M`0`(````MA`!``<```"_$`$`"````,<0`0`)````T!`!`!4```#:$`$`#0``
M`/`0`0`C````_A`!``T````B$0$`$P```#`1`0`(````1!$!``,```!-$0$`
M1@```%$1`0`_````F!$!`#<```#8$0$`5P```!`2`0`%````:!(!`!\```!N
M$@$`+P```(X2`0`*````OA(!``@```#)$@$`#0```-(2`0`M````X!(!``0`
M```.$P$`3P```!,3`0`E````8Q,!`!P```")$P$`"P```*83`0`?````LA,!
M`!T```#2$P$`)0```/`3`0`@````%A0!`"0````W%`$`(````%P4`0`+````
M?10!``<```")%`$`#0```)$4`0`,````GQ0!`!<```"L%`$`!@```,04`0`Y
M````RQ0!``P````%%0$`!P```!(5`0`)````&A4!`!,````D%0$`"0```#@5
M`0`$````0A4!`!````!'%0$`"````%@5`0`(````814!``0```!J%0$`"P``
M`&\5`0`,````>Q4!`!(```"(%0$`$0```)L5`0`,````K14!`!H```"Z%0$`
M#P```-45`0`'````Y14!``T```#M%0$`%````/L5`0`.````$!8!``P````?
M%@$`&P```"P6`0`L````2!8!`!,```!U%@$`'````(D6`0`H````IA8!``8`
M``#/%@$`!P```-86`0`3````WA8!``4```#R%@$`!````/@6`0`7````_18!
M``H````5%P$`#````"`7`0`)````+1<!``8````W%P$`"0```#X7`0`(````
M2!<!``D```!1%P$`"@```%L7`0`1````9A<!``8```!X%P$`#@```'\7`0`.
M````CA<!``T```"=%P$`"P```*L7`0`=````MQ<!``L```#5%P$``@```.$7
M`0`<````Y!<!``<````!&`$`!@````D8`0!D````$!@!``D```!U&`$`!P``
M`'\8`0`F````AQ@!`#@```"N&`$`&@```.<8`0`J`````AD!`#L````M&0$`
M*````&D9`0`T````DAD!`!D```#'&0$`%0```.$9`0`%````]QD!``<```#]
M&0$`"`````4:`0`'````#AH!``4````6&@$`!P```!P:`0`.````)!H!``D`
M```S&@$`!@```#T:`0`(````1!H!``L```!-&@$`!P```%D:`0`(````81H!
M``<```!J&@$`%@```'(:`0`)````B1H!``8```"3&@$`"P```)H:`0`0````
MIAH!``8```"W&@$`'````+X:`0`4````VQH!``<```#P&@$`$0```/@:`0`(
M````"AL!``X````3&P$`"````"(;`0`%````*QL!`!`````Q&P$`"0```$(;
M`0`0````3!L!``8```!=&P$`&0```&0;`0`*````?AL!`!P```")&P$`!P``
M`*8;`0`%````KAL!`!````"T&P$`%````,4;`0`+````VAL!``T```#F&P$`
M*````/0;`0`8````'1P!`!<````V'`$`!````$X<`0`)````4QP!``H```!=
M'`$`!P```&@<`0`"````<!P!``X```!S'`$`"````((<`0`C````BQP!`!\`
M``"O'`$`.````,\<`0`F````"!T!`#$````O'0$`)P```&$=`0!D````B1T!
M`!0```#N'0$`50````,>`0`X````61X!`$H```"2'@$`6P```-T>`0`H````
M.1\!`#@```!B'P$`*````)L?`0`L````Q!\!`"8```#Q'P$`&P```!@@`0`^
M````-"`!`*D!``!S(`$`(P```!TB`0`7````02(!`$@```!9(@$`A0```*(B
M`0`P````*",!`"4```!9(P$`00```'\C`0!;````P2,!`$D````=)`$`,0``
M`&<D`0`=````F20!`!@```"W)`$`*P```-`D`0`A````_"0!`!\````>)0$`
M*P```#XE`0`F````:B4!`"<```"1)0$`.@```+DE`0`=````]"4!`!$````2
M)@$`,P```"0F`0`E````6"8!`"<```!^)@$`(````*8F`0`?````QR8!`#``
M``#G)@$`:0```!@G`0`Q````@B<!`$$```"T)P$`,P```/8G`0`E````*B@!
M`#T```!0*`$`90```(XH`0!-````]"@!`"\```!"*0$`+@```'(I`0`P````
MH2D!`%0```#2*0$`6@```"<J`0!(````@BH!`$H```#+*@$`,@```!8K`0`O
M````22L!`"P```!Y*P$`+0```*8K`0!Q````U"L!`&8```!&+`$`;P```*TL
M`0"S````'2T!`!<```#1+0$`)0```.DM`0`R````#RX!`"D```!"+@$`/@``
M`&PN`0`B````JRX!`%(```#.+@$`)0```"$O`0`+````1R\!`+$```!3+P$`
M10````4P`0`A````2S`!`#````!M,`$`)0```)XP`0`<````Q#`!`#$```#A
M,`$`!P```!,Q`0`'````&S$!``0````C,0$`#0```"@Q`0`+````-C$!``X`
M``!",0$`"P```%$Q`0`%````73$!`!````!C,0$``@```'0Q`0!9````=S$!
M``4```#1,0$`$@```-<Q`0`$````ZC$!``<```#O,0$`"````/<Q`0`%````
M`#(!``,````&,@$`$`````HR`0`,````&S(!`!,````H,@$`#0```#PR`0`"
M````2C(!``<```!-,@$`!@```%4R`0`4````7#(!``P```!Q,@$`&````'XR
M`0`&````ES(!`!(```">,@$`#````+$R`0`#````OC(!`"H```#",@$`!```
M`.TR`0`&````\C(!``<```#Y,@$`'P````$S`0`U````(3,!`"X```!7,P$`
M+P```(8S`0`7````MC,!`"(```#.,P$`)0```/$S`0`@````%S0!`!L````X
M-`$`&````%0T`0`D````;30!`!\```"2-`$`&@```+(T`0`A````S30!`"``
M``#O-`$`&@```!`U`0`R````*S4!`!H```!>-0$`+P```'DU`0`K````J34!
M`!\```#5-0$`(P```/4U`0`?````&38!`!H````Y-@$`(0```%0V`0`E````
M=C8!`"8```"<-@$`)0```,,V`0`D````Z38!`!@````.-P$`'0```"<W`0`D
M````13<!`!@```!J-P$`(@```(,W`0`L````IC<!`"\```#3-P$`%0````,X
M`0`E````&3@!`#P````_.`$`'P```'PX`0`C````G#@!`!\```#`.`$`(```
M`.`X`0`:`````3D!`!@````<.0$`)@```#4Y`0`>````7#D!`"D```![.0$`
M'@```*4Y`0`Q````Q#D!``D```#V.0$`#``````Z`0`7````#3H!`"\````E
M.@$`)````%4Z`0`'````>CH!``\```"".@$`%````)(Z`0`.````ISH!``T`
M``"V.@$`)````,0Z`0`%````Z3H!``<```#O.@$`(@```/<Z`0`E````&CL!
M`!H```!`.P$`'0```%L[`0`:````>3L!``<```"4.P$`QP```)P[`0`+````
M9#P!`!4```!P/`$`!@```(8\`0`)````C3P!``L```"7/`$`#0```*,\`0`7
M````L3P!``8```#)/`$`,P```-`\`0`3````!#T!`!,````8/0$`!P```"P]
M`0`/````-#T!``<```!$/0$`,@```$P]`0`$````?ST!`"$```"$/0$`$P``
M`*8]`0`,````NCT!`!$```#'/0$`,@```-D]`0`6````##X!``@````C/@$`
M'0```"P^`0`)````2CX!``H```!4/@$`%````%\^`0`*````=#X!`!T```!_
M/@$`"````)T^`0`?````ICX!``@```#&/@$`&@```,\^`0`G````ZCX!``8`
M```2/P$`%0```!D_`0`'````+S\!``@````W/P$`"0```$`_`0`_````2C\!
M``<```"*/P$`#P```)(_`0`.````HC\!`!````"Q/P$`"0```,(_`0`)````
MS#\!``@```#6/P$`$P```-\_`0`'````\S\!`!D```#[/P$`"@```!5``0`7
M````($`!`!0````X0`$`"@```$U``0`,````6$`!`!<```!E0`$`!````'U`
M`0`J````@D`!``P```"M0`$`$0```+I``0`'````S$`!``(```#40`$`$```
M`-=``0`8````Z$`!``L````!00$``P````U!`0`(````$4$!``8````:00$`
M!P```"%!`0`-````*4$!``L````W00$`%````$-!`0`5````6$$!``X```!N
M00$`+P```'U!`0`@````K4$!`!P```#.00$`%0```.M!`0`,`````4(!`#$`
M```.0@$`!0```$!"`0`2````1D(!`#\```!90@$`$@```)E"`0`*````K$(!
M``8```"W0@$`!````+Y"`0`$````PT(!``H```#(0@$`$P```--"`0`%````
MYT(!``8```#M0@$`!@```/1"`0`(````^T(!``0````$0P$`#`````E#`0`*
M````%D,!`#D````A0P$`+@```%M#`0`I````BD,!``4```"T0P$`&````+I#
M`0`9````TT,!`!\```#M0P$`'0````U$`0`1````*T0!``(````]1`$`!```
M`$!$`0`*````140!``8```!01`$`!0```%=$`0`#````740!``P```!A1`$`
M10```&Y$`0`R````M$0!`!H```#G1`$`-`````)%`0`H````-T4!`%,```!@
M10$`&0```+1%`0!R````SD4!`"````!!1@$`-0```&)&`0`A````F$8!`$4`
M``"Z1@$`,`````!'`0`H````,4<!`"D```!:1P$`)@```(1'`0`E````JT<!
M`"@```#11P$`*````/I'`0`B````(T@!`"L```!&2`$`,````')(`0`2````
MHT@!`!,```"V2`$`$````,I(`0!Y````VT@!``D```!520$`H0```%])`0!S
M`````4H!`'P```!U2@$`*P```/)*`0!4````'DL!`!<```!S2P$`)P```(M+
M`0`6````LTL!``\```#*2P$`%P```-I+`0`?````\DL!`$`````23`$`'P``
M`%-,`0`<````<TP!`%$```"03`$`&@```.),`0`4````_4P!``H````230$`
M!0```!U-`0`&````(TT!``@````J30$`!0```#--`0`2````.4T!`!````!,
M30$`$P```%U-`0`=````<4T!``\```"/30$`#P```)]-`0`$````KTT!``D`
M``"T30$`"P```+Y-`0`'````RDT!``4```#230$`%````-A-`0`'````[4T!
M``@```#U30$`#P```/Y-`0`(````#DX!``P````73@$`#P```"1.`0`&````
M-$X!`!0````[3@$`!@```%!.`0`,````5TX!`!$```!D3@$`"````'9.`0`$
M````?TX!`!D```"$3@$`$0```)Y.`0`*````L$X!`!@```"[3@$`$P```-1.
M`0`<````Z$X!`!$````%3P$`!````!=/`0`/````'$\!``<````L3P$`!```
M`#1/`0`9````.4\!``<```!33P$``@```%M/`0`"````7D\!`!$```!A3P$`
M"0```'-/`0`&````?4\!`!(```"$3P$`%P```)=/`0`&````KT\!`"<```"V
M3P$``@```-Y/`0`$````X4\!``\```#F3P$`$P```/9/`0`'````"E`!``<`
M```24`$`$0```!I0`0`&````+%`!`!@````S4`$`!@```$Q0`0`3````4U`!
M`!````!G4`$`$@```'A0`0`"````BU`!``8```".4`$`#````)50`0`)````
MHE`!`!$```"L4`$`(@```+Y0`0`'````X5`!``<```#I4`$`"P```/%0`0`%
M````_5`!``(````#40$`"P````91`0!]`0``$E$!``\```"04@$`$@```*!2
M`0`-````LU(!``8```#!4@$`"0```,A2`0`'````TE(!``,```#:4@$`&0``
M`-Y2`0`?````^%(!`#(````84P$`+P```$M3`0`H````>U,!`"T```"D4P$`
M&0```-)3`0`K````[%,!``H````85`$`+@```"-4`0`6````4E0!``H```!I
M5`$`%````'14`0`%````B50!`"X```"/5`$`$P```+Y4`0`+````TE0!`!H`
M``#>5`$`#0```/E4`0`.````!U4!`)D````650$`#0```+!5`0`*````OE4!
M`!<```#)50$`#@```.%5`0`1````\%4!``P````"5@$`%@````]6`0`,````
M)E8!``8````S5@$`G0```#I6`0`*````V%8!``\```#C5@$`%0```/-6`0`1
M````"5<!`!,````;5P$`$P```"]7`0`(````0U<!``D```!,5P$`-@```%97
M`0`D````C5<!`#@```"R5P$`0P```.M7`0!E````+U@!`&(```"56`$`:P``
M`/A8`0!H````9%D!`#H```#-60$`#P````A:`0`5````&%H!``X````N6@$`
M$P```#U:`0`9````45H!``4```!K6@$`"0```'%:`0`1````>UH!``P```"-
M6@$`#0```)I:`0`-````J%H!`#0```"V6@$`,0```.M:`0`)````'5L!`!0`
M```G6P$`%````#Q;`0`,````45L!``8```!>6P$`&0```&5;`0`>````?UL!
M``P```">6P$`#````*M;`0`1````N%L!`",```#*6P$`*````.Y;`0`2````
M%UP!``X````J7`$`#P```#E<`0`*````25P!`"\```!47`$`&0```(1<`0`9
M````GEP!``X```"X7`$`7````,=<`0`Z````)%T!`"H```!?70$`"0```(I=
M`0`+````E%T!`#0```"@70$`#@```-5=`0`(````Y%T!``H```#M70$`!P``
M`/A=`0`'`````%X!``4````(7@$`!P````Y>`0`+````%EX!``4````B7@$`
M(0```"A>`0`0````2EX!`!4```!;7@$`#P```'%>`0`;````@5X!`#0```"=
M7@$`"0```-)>`0`7````W%X!`!8```#T7@$`&`````M?`0`A````)%\!`!<`
M``!&7P$`$0```%Y?`0`/````<%\!`!\```"`7P$`)0```*!?`0`'````QE\!
M``8```#.7P$`!P```-5?`0`-````W5\!``D```#K7P$`"0```/5?`0`2````
M_U\!``H````28`$`%0```!U@`0`9````,V`!`"P```!-8`$`!P```'I@`0`1
M````@F`!``4```"48`$`%@```)I@`0`2````L6`!`!(```#$8`$`/@```-=@
M`0`^````%F$!``D```!580$`!P```%]A`0`3````9V$!``0```![80$`!0``
M`(!A`0`.````AF$!``X```"580$`%P```*1A`0!'````O&$!`!8````$8@$`
M)@```!MB`0`K````0F(!`"P```!N8@$`-````)MB`0`)````T&(!``8```#:
M8@$`"0```.%B`0`'````ZV(!`#@```#S8@$`.@```"QC`0`W````9V,!`%P`
M``"?8P$`-@```/QC`0`V````,V0!`$<```!J9`$`2P```+)D`0`V````_F0!
M`$X````U90$`+````(1E`0`N````L64!`$T```#@90$`-@```"YF`0`\````
M968!`"X```"B9@$`&````-%F`0`<````ZF8!`#,````'9P$`+0```#MG`0`M
M````:6<!`!,```"79P$`"@```*MG`0`,````MF<!``4```##9P$`#@```,EG
M`0`?````V&<!`"8```#X9P$`!P```!]H`0`'````)V@!`!4````O:`$`"@``
M`$5H`0`(````4&@!`#,```!9:`$`"@```(UH`0`'````F&@!``<```"@:`$`
M!@```*AH`0`%````KV@!``@```"U:`$`!@```+YH`0`*````Q6@!`#0```#0
M:`$`$@````5I`0`.````&&D!``<````G:0$`!P```"]I`0`*````-VD!``4`
M``!":0$`$0```$AI`0`&````6FD!`!(```!A:0$`!0```'1I`0`(````>FD!
M``@```"#:0$`#@```(QI`0`&````FVD!`"D```"B:0$`$0```,QI`0`(````
MWFD!`!$```#G:0$`#````/EI`0`'````!FH!``,````.:@$``P```!)J`0`:
M````%FH!`!@````Q:@$`*@```$IJ`0`&````=6H!``4```!\:@$`!P```()J
M`0`'````BFH!`&4```"2:@$`)P```/AJ`0`X````(&L!`"D```!9:P$`(@``
M`(-K`0`&````IFL!``@```"M:P$`'0```+9K`0`E````U&L!`"<```#Z:P$`
M-````")L`0`H````5VP!`"T```"`;`$`8@```*YL`0`V````$6T!``H```!(
M;0$`"0```%-M`0`)````76T!`!8```!G;0$`#````'YM`0`.````BVT!`!0`
M``":;0$`$````*]M`0`4````P&T!`!,```#5;0$`#@```.EM`0`5````^&T!
M``<````.;@$`&````!9N`0`;````+VX!`!@```!+;@$`&P```&1N`0`9````
M@&X!``0```":;@$`!P```)]N`0`4````IVX!`%@```"\;@$`<@```!5O`0`'
M````B&\!`!4```"0;P$`!0```*9O`0`%````K&\!`!L```"R;P$`&````,YO
M`0`+````YV\!`!0```#S;P$`&@````AP`0`>````(W`!`#L```!"<`$`#@``
M`'YP`0`L````C7`!``<```"Z<`$`&P```,)P`0`/````WG`!`!(```#N<`$`
M#@````%Q`0`8````$'$!`!`````I<0$`%@```#IQ`0`3````47$!``X```!E
M<0$`!0```'1Q`0`/````>G$!``8```"*<0$`&````)%Q`0`5````JG$!``\`
M``#`<0$`"````-!Q`0`%````V7$!`!$```#?<0$`$@```/%Q`0`)````!'(!
M`!<````.<@$`!@```"9R`0`'````+7(!`!$````U<@$`"@```$=R`0`,````
M4G(!``<```!?<@$`"````&=R`0`+````<'(!``D```!\<@$`"P```(9R`0`?
M````DG(!`$D```"R<@$`)0```/QR`0`-````(G,!`!0````P<P$`!0```$5S
M`0`@````2W,!`!(```!L<P$`$P```']S`0`Z````DW,!`$H```#.<P$`)P``
M`!ET`0`)````070!`#P```!+=`$`*@```(AT`0`1````LW0!``D```#%=`$`
M"@```,]T`0`&````VG0!``8```#A=`$`$@```.AT`0`0````^W0!``L````,
M=0$`"@```!AU`0`/````(W4!`"P````S=0$`+````&!U`0`M````C74!`"X`
M``"[=0$`(@```.IU`0`E````#78!`"(````S=@$`)@```%9V`0`V````?78!
M`"X```"T=@$`)@```.-V`0`H````"G<!`"0````S=P$`,0```%AW`0!%````
MBG<!`$````#0=P$`-0```!%X`0`T````1W@!`#X```!\>`$`)@```+MX`0`E
M````XG@!`#P````(>0$`)0```$5Y`0`5````:WD!`#D```"!>0$`)0```+MY
M`0`G````X7D!`!0````)>@$`R@```!YZ`0`;````Z7H!`#$````%>P$`,```
M`#=[`0`S````:'L!`#$```"<>P$`)P```,Y[`0`H````]GL!`"L````??`$`
M,@```$M\`0`U````?GP!`$L```"T?`$`-`````!]`0"D````-7T!`"<```#:
M?0$`'0````)^`0`F````('X!`#,```!'?@$`,0```'M^`0!.````K7X!`%4`
M``#\?@$`#0```%)_`0`$````8'\!``8```!E?P$`!0```&Q_`0`/````<G\!
M``4```""?P$`$0```(A_`0`6````FG\!`!P```"Q?P$`!P```,Y_`0`$````
MUG\!`!````#;?P$`$0```.Q_`0`+````_G\!``H````*@`$`$0```!6``0`-
M````)X`!`!(````U@`$`#0```$B``0`Z````5H`!``8```"1@`$`$````)B`
M`0`&````J8`!`!$```"P@`$`%P```,*``0`;````VH`!``\```#V@`$``@``
M``:!`0!)````"8$!``L```!3@0$`#````%^!`0`<````;($!``4```")@0$`
M%P```(^!`0`2````IX$!``,```"Z@0$`$0```+Z!`0`)````T($!`!$```#:
M@0$`$````.R!`0`+````_8$!`!$````)@@$`%0```!N"`0`1````,8(!``P`
M``!#@@$`%````%""`0`.````98(!``X```!T@@$`$0```(."`0`3````E8(!
M`!H```"I@@$`#@```,2"`0`0````TX(!`"L```#D@@$`$0```!"#`0`<````
M(H,!`$0````_@P$`#0```(2#`0`?````DH,!`!0```"R@P$`&0```,>#`0`6
M````X8,!`$,```#X@P$`$````#R$`0`)````380!`!0```!7A`$`"P```&R$
M`0`V````>(0!`#4```"OA`$`"@```.6$`0`5````\(0!`"D````&A0$`%P``
M`#"%`0`6````2(4!`!8```!?A0$`"@```':%`0`@````@84!`!D```"BA0$`
M'````+R%`0`8````V84!`!D```#RA0$`&`````R&`0`(````)88!``L````N
MA@$`*0```#J&`0!8````9(8!``@```"]A@$`%````,:&`0`B````VX8!``D`
M``#^A@$`#`````B'`0`V````%8<!`!$```!,AP$`!@```%Z'`0`&````98<!
M`%4```!LAP$``P```,*'`0`'````QH<!`!4```#.AP$`$````.2'`0`/````
M]8<!`!0````%B`$`%0```!J(`0`;````,(@!`!8```!,B`$`'0```&.(`0`;
M````@8@!``D```"=B`$`!@```*>(`0`+````KH@!``L```"ZB`$``@```,:(
M`0`&````R8@!`!,```#0B`$`+P```.2(`0`7````%(D!`!4````LB0$`"@``
M`$*)`0`1````38D!`!0```!?B0$`'````'2)`0`Y````D8D!`#<```#+B0$`
M$@````.*`0`/````%HH!`(8````FB@$`(P```*V*`0`@````T8H!`!$```#R
MB@$`!P````2+`0`%````#(L!`!P````2BP$`+0```"^+`0`S````78L!`!\`
M``"1BP$`)0```+&+`0`?````UXL!`!<```#WBP$`!P````^,`0`'````%XP!
M``8````?C`$`!@```":,`0`/````+8P!``X````]C`$`$````$R,`0`.````
M78P!`!4```!LC`$`#P```(*,`0`+````DHP!`!,```">C`$`"````+*,`0`(
M````NXP!`!4```#$C`$`#P```-J,`0!%````ZHP!`!0````PC0$`"0```$6-
M`0`.````3XT!`!\```!>C0$`(````'Z-`0`G````GXT!`"8```#'C0$`&```
M`.Z-`0`7````!XX!`"`````?C@$`&````$".`0`6````68X!``D```!PC@$`
M&0```'J.`0`+````E(X!`!0```"@C@$``P```+6.`0`%````N8X!``<```"_
MC@$`#@```,>.`0`0````UHX!``T```#GC@$`&````/6.`0`0````#H\!`!$`
M```?CP$`#P```#&/`0`$````08\!``<```!&CP$`&@```$Z/`0`;````:8\!
M``@```"%CP$`$0```(Z/`0`4````H(\!``X```"UCP$`)P```,2/`0`'````
M[(\!``D```#TCP$`$````/Z/`0`0````#Y`!``H````@D`$`!P```"N0`0`+
M````,Y`!``8````_D`$`&````$:0`0`.````7Y`!``8```!ND`$`*````'60
M`0`0````GI`!`)L```"OD`$`&P```$N1`0`+````9Y$!``<```!SD0$`#P``
M`'N1`0`(````BY$!``H```"4D0$`!0```)^1`0`(````I9$!``,```"ND0$`
M!@```+*1`0`'````N9$!`!8```#!D0$`$````-B1`0`2````Z9$!`!T```#\
MD0$``@```!J2`0`$````'9(!`!0````BD@$`"@```#>2`0`/````0I(!``4`
M``!2D@$`(P```%B2`0`(````?)(!``8```"%D@$`&P```(R2`0`/````J)(!
M``<```"XD@$`"````,"2`0`%````R9(!``D```#/D@$`#P```-F2`0`1````
MZ9(!``(```#[D@$`!@```/Z2`0`/````!9,!`!(````5DP$`$````"B3`0`&
M````.9,!`!,```!`DP$`"P```%23`0`'````8),!`!@```!HDP$`,````(&3
M`0!-````LI,!`"L`````E`$`+0```"R4`0`&````6I0!``D```!AE`$`!```
M`&N4`0`)````<)0!``D```!ZE`$`%P```(24`0`,````G)0!``8```"IE`$`
M#0```+"4`0`'````OI0!``0```#&E`$`00```,N4`0!(````#94!`$$```!6
ME0$`)P```)B5`0`%````P)4!``T```#&E0$`!P```-25`0`(````W)4!``D`
M``#EE0$`&P```.^5`0`9````"Y8!`!4````EE@$`!@```#N6`0`%````0I8!
M`!````!(E@$`"````%F6`0`*````8I8!`",```!ME@$`!````)&6`0`'````
MEI8!`"<```">E@$`!@```,:6`0`)````S98!`!,```#7E@$`$P```.N6`0`(
M````_Y8!``D````(EP$`!0```!*7`0!'````&)<!`#0```!@EP$`00```)67
M`0`R````UY<!`$D````*F`$`.P```%28`0`L````D)@!`#X```"]F`$`+P``
M`/R8`0`]````+)D!`#$```!JF0$`$````)R9`0`1````K9D!``L```"_F0$`
M,@```,N9`0`A````_ID!`!\````@F@$`'@```$":`0`'````7YH!``D```!G
MF@$`"@```'&:`0`'````?)H!`"D```"$F@$`+````*Z:`0`]````VYH!``P`
M```9FP$`(P```":;`0`V````2IL!`!8```"!FP$`%0```)B;`0`(````KIL!
M``L```"WFP$`#````,.;`0`0````T)L!`!<```#AFP$`10```/F;`0!\````
M/YP!`&<```"\G`$`#0```"2=`0`0````,IT!`!$```!#G0$`%````%6=`0`5
M````:IT!`!<```"`G0$`"````)B=`0`1````H9T!`!,```"SG0$`$@```,>=
M`0`5````VIT!`"X```#PG0$`+0```!^>`0"7````39X!`!$```#EG@$`!0``
M`/>>`0`5````_9X!``D````3GP$`"P```!V?`0`+````*9\!`"4````UGP$`
M&````%N?`0`/````=)\!``X```"$GP$`%````).?`0`9````J)\!`"T```#"
MGP$`+@```/"?`0`J````'Z`!`"H```!*H`$`)@```'6@`0`H````G*`!`!X`
M``#%H`$`00```.2@`0`5````)J$!`!0````\H0$`%P```%&A`0`6````::$!
M`!$```"`H0$`%P```)*A`0`6````JJ$!`!0```#!H0$`%````-:A`0`[````
MZZ$!`!D````GH@$`&@```$&B`0`Z````7*(!`!,```"7H@$`!@```*NB`0`0
M````LJ(!`"T```##H@$`%````/&B`0`5````!J,!`!4````<HP$`(````#*C
M`0`>````4Z,!`!P```!RHP$`'````(^C`0`G````K*,!`!,```#4HP$`(```
M`.BC`0`F````":0!`"`````PI`$`&0```%&D`0`=````:Z0!`!0```")I`$`
M'````)ZD`0`<````NZ0!`"$```#8I`$`&0```/JD`0`*````%*4!`!(````?
MI0$`&P```#*E`0`$````3J4!``<```!3I0$`"P```%NE`0`2````9Z4!``8`
M``!ZI0$`!@```(&E`0`'````B*4!``8```"0I0$`!P```)>E`0`%````GZ4!
M``4```"EI0$`%0```*NE`0`&````P:4!``8```#(I0$`!0```,^E`0`%````
MU:4!``H```#;I0$`$0```.:E`0`*````^*4!`!8````#I@$`%````!JF`0`*
M````+Z8!`!<````ZI@$`!0```%*F`0`U````6*8!`!(```".I@$`$0```*&F
M`0`:````LZ8!``\```#.I@$`#0```-ZF`0`0````[*8!`#0```#]I@$`!0``
M`#*G`0`(````.*<!`"<```!!IP$`$P```&FG`0`0````?:<!``8```".IP$`
M"@```)6G`0`-````H*<!``8```"NIP$`(@```+6G`0`0````V*<!`!L```#I
MIP$`$`````6H`0`5````%J@!`!$````LJ`$`&@```#ZH`0`4````6:@!``8`
M``!NJ`$`!0```'6H`0`,````>Z@!`"8```"(J`$`!P```*^H`0`)````MZ@!
M`!(```#!J`$`%P```-2H`0`'````[*@!``4```#TJ`$`!P```/JH`0`6````
M`JD!``T````9J0$`#P```">I`0`-````-ZD!`!8```!%J0$`&````%RI`0`/
M````=:D!`!$```"%J0$`#````)>I`0`8````I*D!``P```"]J0$`!P```,JI
M`0`4````TJD!`$(```#GJ0$`"````"JJ`0`,````,ZH!`"T```!`J@$`%0``
M`&ZJ`0`5````A*H!``T```":J@$`#````*BJ`0`)````M:H!``<```"_J@$`
M"@```,>J`0`)````TJH!``X```#<J@$`$````.NJ`0`I````_*H!`"4````F
MJP$`*@```$RK`0`*````=ZL!``@```""JP$`"@```(NK`0`,````EJL!``T`
M``"CJP$`"0```+&K`0`.````NZL!`#4```#*JP$`!0````"L`0`.````!JP!
M`!H````5K`$`70```#"L`0`:````CJP!``X```"IK`$`!````+BL`0`$````
MO:P!`!H```#"K`$`&@```-VL`0`:````^*P!``H````3K0$``@```!ZM`0`$
M````(:T!`"4````FK0$``P```$RM`0`%````4*T!`"D```!6K0$`"@```("M
M`0`%````BZT!``8```"1K0$`"P```)BM`0`1````I*T!``8```"VK0$`!P``
M`+VM`0`(````Q:T!``0```#.K0$`!0```-.M`0!K````V:T!``H```!%K@$`
M#0```%"N`0`=````7JX!``4```!\K@$`!@```(*N`0`I````B:X!`#8```"S
MK@$`#@```.JN`0`)````^:X!`!,````#KP$`"@```!>O`0`(````(J\!`!<`
M```KKP$`.````$.O`0`?````?*\!`!X```"<KP$`(P```+NO`0`/````WZ\!
M``0```#OKP$`!P```/2O`0`(````_*\!``@````%L`$`$0````ZP`0`/````
M(+`!``<````PL`$`80```#BP`0`1````FK`!``\```"LL`$`#P```+RP`0`;
M````S+`!`%$```#HL`$`'````#JQ`0`&````5[$!`!\```!>L0$`)@```'ZQ
M`0`'````I;$!``8```"ML0$`(````+2Q`0`(````U;$!``D```#>L0$`(0``
M`.BQ`0`@````"K(!`#P````KL@$`"````&BR`0`*````<;(!`"<```!\L@$`
M5````*2R`0`;````^;(!`!\````5LP$`&@```#6S`0`#````4+,!``P```!4
MLP$`"````&&S`0`9````:K,!``T```"$LP$`!@```)*S`0`6````F;,!``8`
M``"PLP$`"````+>S`0`)````P+,!``P```#*LP$`"@```->S`0`0````XK,!
M`$$```#SLP$`"0```#6T`0`:````/[0!`!<```!:M`$`&````'*T`0`5````
MB[0!`!@```"AM`$`%@```+JT`0`6````T;0!`!4```#HM`$`%@```/ZT`0`*
M````%;4!`!\````@M0$`$````$"U`0`2````4;4!``D```!DM0$`#````&ZU
M`0`)````>[4!`!D```"%M0$`!P```)^U`0`7````I[4!``8```"_M0$`!P``
M`,:U`0`%````SK4!``4```#4M0$`!P```-JU`0`3````XK4!`!0```#VM0$`
M(@````NV`0`B````+K8!`!T```!1M@$`'````&^V`0`B````C+8!`"8```"O
MM@$`'P```-:V`0`#````]K8!``4```#ZM@$`#P````"W`0`/````$+<!`!,`
M```@MP$`"@```#2W`0`B````/[<!``T```!BMP$`$````'"W`0`C````@;<!
M`!T```"EMP$`%@```,.W`0`(````VK<!``X```#CMP$`"0```/*W`0`0````
M_+<!`!,````-N`$`"@```"&X`0`)````++@!``4````VN`$`!P```#RX`0`%
M````1+@!``0```!*N`$``@```$^X`0`W````4K@!`#L```"*N`$`&0```,:X
M`0`F````X+@!`$8````'N0$`#````$ZY`0`T````6[D!`#L```"0N0$`1```
M`,RY`0!$````$;H!`$P```!6N@$`#P```*.Z`0`@````L[H!`!\```#4N@$`
M'````/2Z`0`?````$;L!`!\````QNP$`(````%&[`0`@````<KL!`"````"3
MNP$`#````+2[`0!!````P;L!`$$````#O`$`10```$6\`0!&````B[P!`$,`
M``#2O`$`0````!:]`0!Y````5[T!`!4```#1O0$`$````.>]`0`)````^+T!
M`",````"O@$`!P```":^`0`4````+KX!`#H```!#O@$`.````'Z^`0`D````
MM[X!``L```#<O@$`4P```.B^`0!*````/+\!``<```"'OP$`%P```(^_`0`5
M````I[\!``\```"]OP$`$````,V_`0`8````WK\!``<```#WOP$`"@```/^_
M`0`(````"L`!`!,````3P`$`$````"?``0`.````.,`!`!(```!'P`$`!0``
M`%K``0`D````8,`!``D```"%P`$`!@```(_``0`4````EL`!`!(```"KP`$`
M#P```+[``0!(````SL`!``<````7P0$`!@```!_!`0`2````)L$!``4````Y
MP0$`!P```#_!`0`/````1\$!``<```!7P0$`-0```%_!`0`2````E<$!`"4`
M``"HP0$`!````,[!`0`[````T\$!``X````/P@$`*````!["`0"'````1\(!
M`!H```#/P@$`10```.K"`0`G````,,,!`!$```!8PP$`"````&K#`0`.````
M<\,!``X```""PP$`#````)'#`0`3````GL,!``P```"RPP$`(````+_#`0`<
M````X,,!``0```#]PP$`$`````+$`0`;````$\0!`"H````OQ`$`%0```%K$
M`0`1````<,0!`!8```""Q`$`$0```)G$`0`?````J\0!``H```#+Q`$`#```
M`-;$`0`3````X\0!`!$```#WQ`$`%P````G%`0`0````(<4!`!P````RQ0$`
M#@```$_%`0`5````7L4!`"(```!TQ0$`#0```)?%`0`&````I<4!``@```"L
MQ0$`!0```+7%`0`@````N\4!``8```#<Q0$`$@```./%`0`(````]L4!`!,`
M``#_Q0$`"@```!/&`0`H````'L8!`!4```!'Q@$`00```%W&`0`;````G\8!
M``L```"[Q@$`#````,?&`0`E````U,8!``4```#ZQ@$`%@````#'`0`#````
M%\<!`!$````;QP$`!0```"W'`0`*````,\<!`"4````^QP$`.0```&3'`0`*
M````GL<!`"8```"IQP$`$P```-#'`0`+````Y,<!`!T```#PQP$`%`````[(
M`0`$````(\@!``@````HR`$`"0```#'(`0`(````.\@!``L```!$R`$`"```
M`%#(`0`'````6<@!``<```!AR`$`$@```&G(`0`J````?,@!`#<```"GR`$`
M&P```-_(`0`K````^\@!`",````GR0$`00```$O)`0`;````C<D!`"0```"I
MR0$`+0```,[)`0!,````_,D!`"@```!)R@$`!P```'+*`0`(````>LH!``D`
M``"#R@$`"````(W*`0`5````ELH!`!0```"LR@$`+````,'*`0`O````[LH!
M`"(````>RP$`-P```$'+`0`_````><L!``<```"YRP$`&@```,'+`0`)````
MW,L!``P```#FRP$`+@```//+`0`3````(LP!`!(````VS`$`#0```$G,`0`+
M````5\P!`!@```!CS`$`"0```'S,`0`2````ALP!`!$```"9S`$`&@```*O,
M`0`<````QLP!`#D```#CS`$`"P```!W-`0`0````*<T!``4````ZS0$`"```
M`$#-`0`%````2<T!`!H```!/S0$`#P```&K-`0`&````>LT!``\```"!S0$`
M$0```)'-`0`(````H\T!``X```"LS0$`#@```+O-`0`3````RLT!``4```#>
MS0$`$````.3-`0`-````]<T!`#P````#S@$`4@```$#.`0`B````D\X!``H`
M``"VS@$`)P```,'.`0`;````Z<X!``4````%SP$`%P````O/`0`)````(\\!
M``T````MSP$`$@```#O/`0`J````3L\!``8```!YSP$`#0```(#/`0`.````
MCL\!`!````"=SP$`"@```*[/`0`]````N<\!``D```#WSP$`(`````'0`0`0
M````(M`!`!0````ST`$`0````$C0`0`F````B=`!`$(```"PT`$`0P```//0
M`0`\````-]$!``\```!TT0$`!P```(31`0`2````C-$!`!(```"?T0$`&0``
M`++1`0`*````S-$!`!,```#7T0$`&P```.O1`0`'````!](!`!<````/T@$`
M*````"?2`0`&````4-(!``<```!7T@$`$````%_2`0`5````<-(!`!<```"&
MT@$`!P```)[2`0`'````IM(!``D```"NT@$`%````+C2`0`2````S=(!`!,`
M``#@T@$`$P```/32`0`&````"-,!``4````/TP$`,0```!73`0`H````1],!
M`"4```!PTP$`"````);3`0`/````G],!``8```"OTP$`&@```+;3`0`9````
MT=,!`"L```#KTP$`"0```!?4`0`,````(=0!`"<````NU`$``P```%;4`0`%
M````6M0!``T```!@U`$``P```&[4`0`,````<M0!`!,```!_U`$`"P```)/4
M`0`7````G]0!`!@```"WU`$`$P```-#4`0`%````Y-0!``H```#JU`$`%@``
M`/74`0`5````#-4!``X````BU0$`!P```#'5`0`,````.=4!``H```!&U0$`
M$````%'5`0!=````8M4!`"8```#`U0$`/````.?5`0`2````)-8!``<````W
MU@$`!@```#_6`0`+````1M8!`!0```!2U@$`%````&?6`0`<````?-8!`!\`
M``"9U@$`%@```+G6`0`>````T-8!`!````#OU@$`+0````#7`0`5````+M<!
M``T```!$UP$`;@```%+7`0`D````P=<!`"````#FUP$`*P````?8`0`C````
M,]@!`!\```!7V`$`(P```'?8`0`E````F]@!`!\```#!V`$`&P```.'8`0`*
M````_=@!``<````(V0$`"````!#9`0`*````&=D!`!,````DV0$`#P```#C9
M`0`M````2-D!`!@```!VV0$`'````(_9`0`(````K-D!``H```"UV0$`4@``
M`,#9`0!%````$]H!`$````!9V@$`>````)K:`0`-````$]L!`#`````AVP$`
M,0```%+;`0`*````A-L!``<```"/VP$`#0```)?;`0`Z````I=L!`!,```#@
MVP$`1````/3;`0`M````.=P!`"<```!GW`$`$````(_<`0`R````H-P!`",`
M``#3W`$`,P```/?<`0`J````*]T!`#(```!6W0$`*P```(G=`0`-````M=T!
M``D```##W0$`$0```,W=`0`3````W]T!`!@```#SW0$`!P````S>`0`W````
M%-X!``P```!,W@$`!````%G>`0`%````7MX!`!(```!DW@$`"````'?>`0`&
M````@-X!`!0```"'W@$`"@```)S>`0`)````I]X!``4```"QW@$`$0```+?>
M`0`1````R=X!`!H```#;W@$`'````/;>`0`5````$]\!`"$````IWP$`#0``
M`$O?`0`'````6=\!`!(```!AWP$`*0```'3?`0`)````GM\!``D```"HWP$`
M&P```++?`0`H````SM\!``X```#WWP$`(0````;@`0`T````*.`!``D```!=
MX`$`"0```&?@`0`2````<>`!``8```"$X`$`!````(O@`0`B````D.`!``T`
M``"SX`$`#P```,'@`0`,````T>`!``@```#>X`$`"0```.?@`0`(````\>`!
M``D```#ZX`$`#0````3A`0`2````$N$!``8````EX0$`&0```"SA`0`5````
M1N$!``<```!<X0$`$````&3A`0`@````=>$!``P```"6X0$``P```*/A`0`E
M````I^$!``8```#-X0$`!@```-3A`0![````V^$!``D```!7X@$`!0```&'B
M`0`L````9^(!`$8```"4X@$`(P```-OB`0`O````_^(!`%`````OXP$`.@``
M`(#C`0`]````N^,!`"0```#YXP$`(````![D`0`%````/^0!``<```!%Y`$`
M"````$WD`0`)````5N0!``<```!@Y`$`"````&CD`0`2````<>0!``H```"$
MY`$`"0```(_D`0`+````F>0!``L```"EY`$`!P```+'D`0`'````N>0!``@`
M``#!Y`$`%````,KD`0`+````W^0!``8```#KY`$`!0```/+D`0`D````^.0!
M``8````=Y0$`+0```"3E`0`8````4N4!``@```!KY0$`%````'3E`0`)````
MB>4!`!,```"3Y0$`"P```*?E`0`%````L^4!`!0```"YY0$`!0```,[E`0`4
M````U.4!``8```#IY0$`&@```/#E`0`*````"^8!`!P````6Y@$`"````#/F
M`0`&````/.8!`!(```!#Y@$`)````%;F`0`+````>^8!``T```"'Y@$`*@``
M`)7F`0`A````P.8!`!P```#BY@$`!0```/_F`0`*````!><!`!,````0YP$`
M&````"3G`0`#````/><!`!,```!!YP$`"0```%7G`0`D````7^<!`"@```"$
MYP$`,P```*WG`0`H````X><!`#4````*Z`$`+P```$#H`0!D````<.@!`!8`
M``#5Z`$`7````.SH`0`Z````2>D!`$D```"$Z0$`:P```,[I`0`J````.NH!
M`$$```!EZ@$`,0```*?J`0`W````V>H!`"T````1ZP$`'0```#_K`0!"````
M7>L!`-,!``"@ZP$`(@```'3M`0`7````E^T!`$P```"O[0$`@````/SM`0`W
M````?>X!`"P```"U[@$`/P```.+N`0!>````(N\!`$H```"![P$`*@```,SO
M`0`B````]^\!`!0````:\`$`'P```"_P`0`A````3_`!`"````!Q\`$`*P``
M`)+P`0`D````OO`!`",```#C\`$`/@````?Q`0`B````1O$!`!4```!I\0$`
M-P```'_Q`0`F````M_$!`"P```#>\0$`*P````OR`0`:````-_(!`"T```!2
M\@$`:0```(#R`0`V````ZO(!`$D````A\P$`-P```&OS`0`M````H_,!`$``
M``#1\P$`<````!+T`0!2````@_0!`#4```#6]`$`-P````SU`0`T````1/4!
M`&L```!Y]0$`<P```.7U`0!:````6?8!`%D```"T]@$`-P````[W`0`I````
M1O<!`"D```!P]P$`+P```)KW`0!Y````RO<!`&X```!$^`$`=P```+/X`0#$
M````*_D!`!8```#P^0$`)P````?Z`0`X````+_H!`"\```!H^@$`30```)CZ
M`0`J````YOH!`&,````1^P$`(P```'7[`0`+````F?L!`*@```"E^P$`2@``
M`$[\`0`I````F?P!`#@```##_`$`*@```/S\`0`C````)_T!`#T```!+_0$`
M!@```(G]`0`+````D/T!``0```"<_0$`"@```*']`0`/````K/T!`!$```"\
M_0$`"P```,[]`0`&````VOT!`!$```#A_0$`!````//]`0!F````^/T!``,`
M``!?_@$`%````&/^`0`$````>/X!``<```!]_@$`!@```(7^`0`%````C/X!
M``@```"2_@$`%0```)O^`0`,````L?X!`!$```"^_@$`$0```-#^`0`#````
MXOX!``4```#F_@$`!P```.S^`0`2````]/X!``P````'_P$`%````!3_`0`&
M````*?\!`!4````P_P$`#0```$;_`0`#````5/\!`"X```!8_P$`!````(?_
M`0`&````C/\!``<```"3_P$`)0```)O_`0!'````P?\!`#@````)``(`.0``
M`$(``@`8````?``"`"<```"5``(`*@```+T``@`F````Z``"`!P````/`0(`
M(0```"P!`@`H````3@$"`",```!W`0(`(````)L!`@`D````O`$"`"8```#A
M`0(`(@````@"`@`V````*P("`!T```!B`@(`,P```(`"`@`Y````M`("`"8`
M``#N`@(`*@```!4#`@`H````0`,"`",```!I`P(`*````(T#`@`R````M@,"
M`"L```#I`P(`,````!4$`@`F````1@0"`"0```!M!`(`)0```)($`@`N````
MN`0"`"````#G!`(`)P````@%`@`W````,`4"`#H```!H!0(`'````*,%`@`F
M````P`4"`#T```#G!0(`)P```"4&`@`K````308"`"@```!Y!@(`*@```*(&
M`@`D````S08"`!X```#R!@(`*P```!$'`@`H````/0<"`#<```!F!P(`+@``
M`)X'`@`Y````S0<"``D````'"`(`$````!$(`@`8````(@@"`#(````["`(`
M)0```&X(`@`-````E`@"``\```"B"`(`%@```+((`@`*````R0@"``X```#4
M"`(`*@```.,(`@`(````#@D"``L````7"0(`+P```",)`@`Q````4PD"`"D`
M``"%"0(`(@```*\)`@`D````T@D"``H```#W"0(`[`````(*`@`,````[PH"
M`!8```#\"@(`"@```!,+`@`-````'@L"`!(````L"P(`%P```#\+`@`J````
M5PL"``8```"""P(`4@```(D+`@`:````W`L"`!H```#W"P(`!P```!(,`@`/
M````&@P"``@````J#`(`0@```#,,`@`'````=@P"`"T```!^#`(`&@```*P,
M`@`3````QPP"`!0```#;#`(`-````/`,`@`@````)0T"``<```!&#0(`)```
M`$X-`@`(````<PT"``D```!\#0(`%P```(8-`@`*````G@T"`!P```"I#0(`
M"````,8-`@`N````SPT"``<```#^#0(`(P````8.`@`G````*@X"``<```!2
M#@(`%0```%H.`@`'````<`X"``@```!X#@(`"0```($.`@!`````BPX"``<`
M``#,#@(`#````-0.`@`3````X0X"``\```#U#@(`"0````4/`@`(````#P\"
M``<````8#P(`$P```"`/`@`&````-`\"`!H````[#P(`"P```%8/`@`:````
M8@\"`!0```!]#P(`"P```)(/`@`-````G@\"`"````"L#P(`!0```,T/`@`U
M````TP\"``P````)$`(`#P```!80`@`+````)A`"``,````R$`(`%````#80
M`@`B````2Q`"``L```!N$`(``P```'H0`@`(````?A`"``P```"'$`(`"@``
M`)00`@`0````GQ`"``X```"P$`(`$@```+\0`@`3````TA`"`!$```#F$`(`
M.````/@0`@`A````,1$"`!\```!3$0(`(0```',1`@`)````E1$"`#0```"?
M$0(`!P```-01`@`7````W!$"`$````#T$0(`$P```#42`@`3````21("``@`
M``!=$@(`!````&82`@`&````:Q("``\```!R$@(`'0```((2`@`'````H!("
M``@```"H$@(`"0```+$2`@`&````NQ("``8```#"$@(`%0```,D2`@`4````
MWQ("`$(```#T$@(`,P```#<3`@`I````:Q,"``4```"5$P(`&P```)L3`@`=
M````MQ,"`",```#5$P(`)P```/D3`@`2````(10"``(````T%`(`!````#<4
M`@`/````/!0"``H```!,%`(`!0```%<4`@`"````710"``T```!@%`(`2```
M`&X4`@`W````MQ0"`!8```#O%`(`-P````85`@`L````/A4"`%H```!K%0(`
M%P```,85`@"#````WA4"`"4```!B%@(`.@```(@6`@`B````PQ8"`#8```#F
M%@(`.````!T7`@`M````5A<"`"P```"$%P(`+````+$7`@`J````WA<"`"X`
M```)&`(`+@```#@8`@`R````9Q@"`#,```":&`(`,@```,X8`@`6`````1D"
M``T````8&0(`#@```"89`@"&````-1D"``D```"\&0(`K0```,89`@!Q````
M=!H"`(4```#F&@(`*P```&P;`@!<````F!L"`!0```#U&P(`*`````H<`@`6
M````,QP"`!````!*'`(`)````%L<`@`B````@!P"`$(```"C'`(`(````.8<
M`@`>````!QT"`%P````F'0(`&@```(,=`@`3````GAT"``H```"R'0(`!0``
M`+T=`@`&````PQT"``@```#*'0(`!0```-,=`@`6````V1T"`!4```#P'0(`
M%P````8>`@`B````'AX"`!````!!'@(`#P```%(>`@`$````8AX"``P```!G
M'@(`#@```'0>`@`'````@QX"``8```"+'@(`&0```)(>`@`/````K!X"``8`
M``"\'@(`%0```,,>`@`)````V1X"``P```#C'@(`%````/`>`@`,````!1\"
M`!@````2'P(`"0```"L?`@`+````-1\"`!@```!!'P(`!@```%H?`@`%````
M81\"`"<```!G'P(`&P```(\?`@`*````JQ\"`!D```"V'P(`%@```-`?`@`D
M````YQ\"`!D````,(`(`"0```"8@`@`5````,"`"``@```!&(`(`!P```$\@
M`@`7````5R`"``<```!O(`(``@```'<@`@`"````>B`"`!\```!](`(`#@``
M`)T@`@`(````K"`"`!<```"U(`(`&0```,T@`@`'````YR`"`"L```#O(`(`
M`@```!LA`@`&````'B$"``\````E(0(`&0```#4A`@`%````3R$"``H```!5
M(0(`$P```&`A`@`'````="$"`!D```!\(0(`"@```)8A`@`7````H2$"`!,`
M``"Y(0(`$@```,TA`@`"````X"$"``<```#C(0(`$0```.LA`@`&````_2$"
M``X````$(@(`,````!,B`@`)````1"("``H```!.(@(`%````%DB`@`%````
M;B("``(```!T(@(`"P```'<B`@`!````TP0``!P$```Q!0``7P,```````"<
M`0``;0(``*`$````````E`,``,<!``#[!@``?```````````````A@(``"D'
M```+`0```````($'``#!````=P4``!4$``#Q!0``+````-H#``#!!@``(P<`
M``@"```!!```O`4```('```Q`P```````*8"``#P!0``9`(``+("```/!```
M@0,```````````````````````#6!```404``(4$`````````````/8!``!P
M`@````````````!_`@``+@0````````C`0``I`4```````!B!P``Y`4``(\&
M```E`0``<`8``/4$``!N`@``<`$``#,'``#"`0``T0(``"\$``!O`P``3@<`
M`%H```"B`0``,P$``(D'````````>P$``.L```"6!@``P`4``%P'``!*!0``
MS`8```````"4!```8@(``/(````I`@``9@(```````#;!```A`8``-X%````
M`````````*4```````````````````"8`P```````$````#D!@```````,T!
M````````G00``$@"``"_!0```````/T"``"(!P````````P%````````3P0`
M`,P%``#L`@``)@4``!<`````````-````%@```"\`0````````````"U`@``
M6@0``&4#``!J`P``7P$```````````````````````#Z`0``9`,``&\```#6
M`0```````'T&````````"`<``)``````````30,``)L"````````'`,``%T&
M``#T`0``WP```"@#``#<`0``T`$``+8#``!'`P```````!L'```1!P``)0,`
M`/$```"P!0``T@0`````````````JP,``*0`````````RP4``&$#``!Y`P``
ME00```H$````````B@8``,`!````````X00``'@'``#8`P``YP$```````#_
M!0``2@<``*D!``!8!```Y`$```````!/````O@$``````````````````"\#
M``!L!P```````+(`````````F`4``&<$``"D!@``X@$``+$&````````*@``
M`/L!``!H`0``5`<``-D#```I!@``HP0``%0&``!6!```KP8```````"=`@``
M6P```)(&``"+`P``J0````````"L!0``TP```*`#``!Z`0``9P(``,(#```H
M!P``>P,``"L`````````-@``````````````,0(``(,```#D!````````/8$
M``!Y!```1`<```````#W``````````````"3`@``N@4````````7!0``J@,`
M`"L"``!Z!P```````'0$```[`@````````````"0`@``C@$``(H$``#<````
M?`<``%<%``":`P```P(``#L'``!>`P``!@$```````!%!````````"T'``"?
M`P``I0$`````````````9P4``'$!`````````````$,&``#;````/0<``$H`
M`````````@(````````I`0```````%8#````````G`0```````#,`0``800`
M`!8#````````)P0``&$``````````````"4$``!W````[0,``&8&````````
MG`8````&``![`````````!D&``"Q!````P````,'``#=!0``MP8``,D#``!\
M`@``%@<``.P``````````````&,!````````[@(``)H```"2````G@,`````
M``";`0``*P4``'$"``#R`P``1@,``+X"``"Z`0``W00``-8&``"T`P``XP0`
M`,H$``"J!````````!@'```7`@``OP0``!@!``"Q`@````````````#A`P``
MCP(```````!^`0``_@4``&D!```7!@``^`$``"H#``!+`P``<@,``$<$``"6
M`0``1P```,@!``!Q`P``3@8``#H```!@!@``4P```-4&``!V`@```````"X%
M```F`@``<P8``.T````+!@``!````.0"``!^`P``@P4``(D!``"3!```_@(`
M`&0'``#G!0``%P$```````"?`0``#0<``'L"``!^````!00```D'```N!@``
M-08```````!2`@``OP````````!W`P``_P,````````+````,P4`````````
M````9@<``"@&``#=`````````/0"```_!P```````-<#``#:!```````````
M``!H````#0(``'(&````````TP8``,4&``!Q````H````/P&``!"`@``````
M`)L$``"Y`P``P`````0$```/!@``3`$``)0"``"Y!0``H`$``,$!````````
M!0````````!,!P``U@(``&,`````````Q````````````````````/($````
M````0`4``&\'````````S08````````7`P``@08`````````````4@4`````
M````````\P0``'<$``"C!@``;P0```@```!>````2`<``+H#``!V!0``W@``
M`(0#```D!```.P4``/<&``"<`P``=P(```````!J`0``/@(``+X&``#N!0``
MO@0```````!O!@```````(D```"E`@```````#0&````````'`<```````!5
M`0``(@0``#@!````````;00```````"'`@``>04``(`%``#6`````````"$"
M``!/!@``-P0``#,"`````````````)<#``#_!`````<```<#``!I!@``````
M`/$!``#&````[P,``(\```!;!P````````````#G!@``A0,`````````````
MW0(``"X#``!7`0``]`8```````#E`0``_@```$T```#-!```$`4````````V
M`0``D`,``'T!``"7````600``'\$``!S````IP4``%@"``""`@```````$(&
M``!V`0``_@$```````#G!````````"0`````````^`0``&L$``#&!```60$`
M`"$$```&````GP(``%X"``````````````0&``"4!0```````.$&``".`P``
M/@```"L!```4`@``U@,``)$&``!`!P```````&P#````````C@0``*,`````
M````Q0,``%$```"]`@``+`0``"`$``#I!````````"T&``#V`@``+P8``%@%
M``````````````````"I`@``)`,`````````````LP$```````!]````)P,`
M``````!R!P```````)$$````````S@$``/`&```(`0``````````````````
M``$``$P%```Y!@```````,D%```1`0``7P0``/H#``"<````L`,``,0!````
M````=00``'$$``#7`@``R@4``'P!``",`0``````````````````_04``#4$
M````````/@<``*4&``#0`P``J`8``.T!``"F`````````.\"````````````
M``````"M!```ZP$``/D$``#>`P``*`0```````!F!```GP```!`&``"Y!```
MZ0,```````#)!```6P(``(P$````````Q`(``+X%``!"!0``=`<``-8%``"3
M!@```````&,'`````````````!L$````````\P,``%0```#9`````````$@`
M``"6`````````%8"```W````(`8``#P"``!S`@```````/,"````````"`0`
M`+<"``"E!```=P<```````#:!@``%0````````#9!````````/P`````````
M'P4``(L%``#W`0``]P4``'P#``#8!@``M`4``)4%```#!0``````````````
M`````````(,$``"_`@``S@(```P'``"9`P``_P(```````#T!```/P(``%,!
M````````Q00``#(!````````RP(``(P``````````````$L!````````````
M`+H&```)`0``W@$``"8$``"D`P``S04``',!```S!```$08``(L$``!B````
M`````"\```"@!@``.`(``%D"``!_!P``1P<``(T%```9`````````*T```#N
M`P``T08``'P%```R````O04``,H"````````]@8``+8&``!;!0``1`$`````
M````````'0(``!X'``#;!@````````X%````````8`$``#D"``!#`@``NP$`
M`(`#````````*@$``$8```#0`@``%`8```````!_````0@,``#4'```M`0``
M,00``.$!````````T@4``+0"``#H`0``5`,``/<#``!]!````````*(#``#4
M`@``8@,``.L%`````````````%\````?`@``,@,``/P"````````<P0`````
M``"`!@``-P4``#H%```8!````````'8```"C`P```````)<%``!B!0``$@(`
M`&P!```B`0```````(X`````````:@4```````#%!0``&@$``.`!````````
MDP,``)@`````````A04``!@`````````+`4``(8$````````'````)D&``!H
M!@``^P(``(4!````````3`,``&@'``!Z!```$`0``&4```!4!0``Q`8``'0"
M``#@``````````````"W`P``=0,`````````````````````````````7`$`
M```````X!P``?@(``&P``````````````(@"````````S@8```L"```/!0``
M;0$``"T"``#@!0``YP(``$\#```-`0``8````&<`````````OP8``-D"``"Y
M!@``````````````````Z@```+($```H`````````"\'````````\P```*H%
M``#]`0``U00``!H```````````````````!B!````````,@&``!?!@``3@``
M```````3`@````````````!*!```%@8``",````_````@@4``*@$``"X`@``
MD04``.0```!"!````````+@%``!!!0``'P$``+@!````````FP4```````"U
M`````0<``"L'`````````````+`$````````:0<``'L%``!F````````````
M````````S@0```<!``!7!@````````````#?!@``8`<``#L!```[!```=0(`
M`.L&```Y!```'P<``/T&``!Q!@``#`$```````!'!@``G08``+P$``!E!@``
M"04``$4'``````````````````!S`P``BP```'D'``#2`P```0(``*,!```L
M`P```````+,$````````)`<```$#``#K`@``<````&T&``#8````$@8``$4#
M``!=!P``\P4``.@&``#1!```/P,```````#[!0``90<``)\&``#2`@``````
M`&L!``#1````B08``#````#(`@``H00``.P!``#B````:@(``*8!``!<`@``
M`````#@#````````6P8``"L$``!@`P``X04```````#/````E@4``-<&``!%
M`@````````````"5`0`````````````'!@``1@4``/X&````````20,``&P%
M``!3!P``TP$``(`!`````````````````````````````/T$``!L!```!@0`
M`#X#```?!```WP0```````!<`P``?@0``!$"```L!@``RP0``!L#````````
M?@8``'4````%`P``D0$```````"L``````````0"``!Y`0``*00``#0'````
M````>@```'0``````````````&(!``!4`0``#0```#\!``#=`P``M`8``#<'
M`````````````"8```````````````````"(!0``CP0```````!&!````08`
M``````"S````4`$``)`&``"R`0``%@(``%`"``"'`P``;@<``/4"``"V````
M\@8``/`#``!1`0``X@0``.\$````````SP8````````O`@````````L'``!0
M`````````%0"````````2P8``($"````````'`8```````#S!@``BP8``+L`
M``!<!@```````/D!``"$````1@8```````!U`0````````````!$`@``2`$`
M`!4#````````)`$``%D#``#U````F@4``%,%``#<!@``.0$``!D'````````
MB`$``%P%``!7!```00<``)H"```]`P``$0,``*X%``!)`0```````)\$````
M````/@$``&H```!^!0``IP,``*<&```@`````````*X```!+````$@```*8$
M```!`0``>`8```````#5`0``N@```.,#``"V`0````````````!H!```````
M``````"^````N0```'($````````$0```%\%``#F!```(`,``*L!``#F````
M(@(``)X&``"]`0``\@$``#H&``""!@```````($````2!```NP(``#T$``!_
M`0``&P```+,"````````O0,``'4%``!E`@``A0````````#-`@``PP8``'\%
M````````5P(``)\%``#P`0``K0,```````"*!0``<@$``+$```"!!```````
M`.\&````````$`<``&\"````````[`,````````0`@``%`$``"T#``!$!```
M`````(('``#?`@```````'L&``!)!0```````-L%``"'!````````%X'``#W
M`@``KP0```4"````````(0```/P%``!W`0``/`,```H&``#T!0``\`(``'$%
M``"X`P```````-0#``#H`@``6`8```````![!```00,````````J`@``G`4`
M`,8%``#:!0``804`````````````_P8``'H%``!'`@``/````+P`````````
M``````\#``````````````\'```W!@``%`0`````````````80(```<'```S
M`P```````$`!```]!0```````)H&`````````````(<!``#)````Z`,``.,&
M``"]````BP$``+T$````````-@,``#4"```=!0```````(8&``"N!```!P(`
M`.L$``"_`P``````````````````200``%`&``"U!```<P4``,0#````````
M:P,``-H!``"P`0```````),%````````R08``*(%````````"0,``'T#```3
M````#00``,4!```+!````````$$"``!5````XP4```````"L`P```P,``!D$
M```&!@````````````#J!```[`4```H#``"H!0``MP0``!8```!4!```-P$`
M`%4%``"D`@``^0(```````"``@``(P4``/L#``!#`0``:@0`````````````
M/P4``!,!````````\0,``,<$``"]!@```````$@#````````S0,``%T%``!\
M!```/08``/D````>!0``1@$```````"K````5@$``.@$``"-`````````,X#
M```X!@````````````#+````AP```-P#`````````````,P$````````40<`
M```````9!0```````.8#```Q````S`,``(D%```0`0``#@```&H'``"G````
MSP0``&$'```8!@``V@```"$!``"B`@``F`(``%X$```M!```(@<``&4!``!X
M`@``$P<``!T$``#9!0``G`(``%T`````````X`0``&8%```_!@``Y@(`````
M``"R!0````````0#```>!```````````````````!`4```````"3`0``A08`
M`'0#``"O`P``^08```````"2!```A0(``!X&````````VP,```````!;`0``
M6@<``!0#``#Q`@``,@<``'0%``"H`P``70$``"L&``````````````````"N
M!@``WP,``$X#``#\!```.0<``'@$````````+P4``&<&``#4````H`(``/D#
M````````*`4``(4'``#M!0``<@(````````I``````````8"````````"@<`
M`.4$````````408`````````````)@<```(&````````1@(`````````````
M`````-<!``#-````-P,```0!````````*@<``'$'``!B!@```````($%``!N
M`0``KP(``,0$```N`@``500``````````````````(0%```3!```D0(``%8&
M``#2````K@,``$@&```V!P``>P<```````#0!```&P4```````"Z!```````
M``````""`0`````````````C`@``6@$````````:!P``,0<``"`"``"H`@``
M)0<````````Z!```B0(``&L```#Q!@``.04``#P!```1!0```````.4%``"*
M````'`$``*L$``")`P``!@4````````B!0``70(```````#J`0```````/H$
M````````WP$``$<%````````$P8``(@```#I`@``-`0``.0#``"K!0``S@4`
M`,<#````````/P0``````````````````.H"``"A`P``_@,``!@%```S````
M]@4``'8'````````;@8```````#+`P``;P$``!X#``!9!0```````(8```"#
M`0```````+0```"/`P``A`0``#`$``"W`0``F0(``*`%``"V`@``Y0(`````
M```R!```H0```"P"``#(`P``"P,```````",!0```````!L&``"L!```````
M````````````:P4```````#8`0````````X$```(!@```````"4```#@`P``
MG@``````````````<@4``!\&````````%0$``#X%```=````S`(``)X%``"(
M!@``C@(``"$%``"6`@```````$`&``!!!@``H0$``*$%```G`@``````````
M```M````20<``)4"``!2!``````````````T`@``^`4``'0!``!=`P``-0$`
M``````!.!```5@4``*($```)````PP4``(,#````````6`$``&D"``#K`P``
M&0(```````#"`@``60<``$,#```\!```D`$``.8!``#B`P``400`````````
M````K`(```X"```<`@``3@$``$@$```*`````````$P&``#\`0``+@```(T!
M````````+`<``.T"``#I`0``SP$``&P"`````````````-H"``##`@``)P``
M`+,#``"2!0```````&X````0`````````(T$```;`0``<`0``'4'`````P``
MWP4``%('``"R`P``!@<``(T#````````C0(``&<!``""`P``OP$``'8&``!N
M!```J@```$X"``!D!0```````(P#```N!P``@@0```````"\`P``/@0``!@"
M````````-P(``)(#``""``````0```````````````````\"```5`@``P@``
M`+L#````````T`8``#`%``#N````P04```````!(!0``$@<``%@'```"!```
M7@$`````````````V0$``$D&``#Q!```;`8``#@%```Z!P``F@$``.$```"\
M`@``O@,``!8$`````````````)D%``#J!0``]`,```````!"!P``&0,``.P$
M``"5`P```@,```D&``"-!@```````&L&``!?!P``+@$``"8&````````9`8`
M`&D#````````7@8``+4#```*`@``20(``!\````,!@``9`$`````````````
M3P(`````````````I@4``#$&``"Q`0``#08``-(!```U!0``A@$``%P`````
M````.P8``.4#```:!0``NP0``*T"````````@````'H#``"'!@``R`4``(,&
M``#=`0``-0,``.\!``````````````P```"6`P``8P(``)X"``#R!0``````
M````````````9`0`````````````Z0```+8%``"A!@```````!X!``#!`P``
M/`8``'`%``"$`0``:P(```````!-!```Y@8```````#&!@``CP$```````##
M````'0<```````!C!```<P<````````-!0``/0$``$\'``!M`P``(@8``$0`
M```5!P````````````#8`@``20```#L#```7!````````.\```!J!@``````
M``H%``!3`P``!P4``"0%``"U!@``J00```<$``!'`0``1`8`````````````
M`````"`%````````L````*\````P!@``[@8``.,`````````(P8``!(#``#!
M!```V08`````````````?P,```P$```8`P``K`$```````"Y`0``X@8``,X`
M````````D@$``'X'``#%`@```@4````````T`0```````*@````L`0``#@,`
M``````"0!```&0$``*(```!0!0```````.D&``#5`@``````````````````
M"00``)D!``";`P``J@$```P"``#5!0``]04``/4!```-`P```````)T!``#%
M`````````,8"``!7````.````"@"`````````````/T#``"G!```NP4`````
M``#"!0```````$\!```=`0``[`8``/@&``"6!```4`0```````"M`0``````
M``````"D`0``J04``+`"``!C!@```````-4#```6!0``I@,````````:`@``
M``4```````"&!P``@`<``-$%``#C`0``K`8``.,"``#`!@``JP(``'`#``"0
M!0``KP$```````#3!0``H@8```````"U!0```````,\%``!M!0```````/@"
M````````W08`````````````'P,``'T'``"T!```I@8```````#$!0``IP$`
M`$,```"=`P``&P(```````!,!`````````(!``"7`@``3P4``$`#``!Y!@``
MW`(```````!&!P``8P4``'\&``!$`P``Y0```$T%``#"!@``````````````
M`````````-````!;`P``MP```'D"``!#!0```````%(&``#7!0``2@(``#T`
M```M!0```````'H&``#@`@``8`0``!H#``````````````````##!```````
M`-,#``#B`@``>`,``)0```"'!P``&@0```````````````````````!!!```
M&@8`````````````4`<````````I`P``_0```%<#`````````````"$'``!1
M`P``.@(``),```#S`0``50(```````#X`P``#@8```````"9!````````$(!
M``!?`@``2P0``$L'``!N!0``L0,```````"$`@``308````````F`0``````
M`-L!````````L04``'`'``#<!```:04``+,&```G!0``/`<``$,'``!*`P``
M:00``,\#````````:`(``*\%``"`!```=@,``-$#``!0`P``F`$``.$"``!,
M`@``P@0```````"(!```:P<``'(```````````````````#Z`@```````#(%
M``!H`P``!0<``",#``!\!@```````.<#``"7!```M0$``,H&``#/`@``*`$`
M`)<!``#+`0```````%8'``!3`@``6@,``(8%````````,`(``/@```"9````
M`````,P```"N`@``-`4```````#7`````````*4%```````````````````E
M!@``F`8``.X!```A`P``.P```)<&``!!`0``Q@,``(P"```$!P``%04``&4%
M```````````````````B`P``B@(``!X```"#!P``50<``*T%``!%````=08`
M`#@$``##`0``U`$``$(```!E!```)P<``&\%``#U!@``5@````X!``#Z!0``
M30(``/X$``!:`@``HP4```4&``#I!0``(@```$4%````````2@8``)@$``";
M!@``P0(```,$`````````````+P&``!N`P``%08``.T&````````?04``.@`
M```T`P``6@4``!(%```/`0``'@(```````!H!0```````"\!```]`@``30$`
M`#`!```E`@``U0`````````E!0``9@,``/8```!Z`@``C@8`````````````
MHP(```````"N`0``_`,``&$!``"X````D0```````````````````)4````F
M`P``#P``````````````B@,```````!]`@``QP4``,8!````````A@,``"`'
M``">`0```````-L"``#)`0``"@$``%4#``!Y````U`0``,,#````````R@$`
M`!,#``````````````````!M!P``\`0``'8$```(`P```````#X&``#8!```
M`````*$"``!M````CP4``!<'````````5P<``"H$```"````8`(``!P%````
M````^04``$X%````````R`````P#``"+`@```````*4#```(!0```````#D#
M``#_`0``#@<``%T$```)`@```````$P```":!```T0$``"D%``#H!0``````
M`'@`````````9@$``/````#O!0``2P(``+<%```%!0```````%(```#J`P``
M2P4``-0&```Y````R`0``)T%``#``@````````,!``!W!@``1`4``-X&````
M``````````<````V!0``*P,``/H```#'!@``%`<```,&``#*````>`$``!(!
M``#V`P``Y@4``*H&``!3!```4@$````````&`P``N0(``$T'```4````D0,`
M`*H"``!<!```UP0``#H#```P`P``]````$`$````````W@(``+`&````````
M`````-P%``!A!@``P`,``,H#``#M!```6P0``)0!``"(`P``9P<``(0'````
M`````````!,%``",!@``I`0``#`'``"*`0``0P0``)L````A!@``\@(``'0&
M`````````````+8$````````$`,``.H&``!@!0```````/L$``"4!@``X@4`
M`"H&`````````````/<$````````N@(```````"T`0``108```````"M!@``
M508``#P%````````00```#8$````````,@(````````!!0```````(X%```=
M`P``IP(`````````````4@,``"<&``#4!0``^@8```````"H`0``8P,``!$$
M`````````````%,&```G`0``LP4```````#E!@``TP(```````"'!0``@P(`
M`+@&``!8`P``@0$```````#N!```)`(``-(&````````-0```+L&``#)`@``
MJ0,``%D`````````,0$```````#@!@``L@8```L%``!%`0``6@8``+@$```V
M!@```````%D&````````9````"0&``#'`@```````)T```#_````!0$``$`"
M``")!```:0```-@%```@`0``G@0```````"2`@``%`4````````Z`0``T`4`
M```````6`0```````'@%``#'````RP8`````````````7@4``",$``#U`P``
M*@4``.<```#`!```J08``!T&``!*`0``,@8````"``!G`P``W@0``#8"````
M`````````/L```"K!@``E08``%$"````````,P8````@*"5S(&1A>7,@86=O
M*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O
M;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C
M=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@
M<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS
M('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@
M9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E
M8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S
M(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI
M<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@
M;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E
M<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E
M<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L
M86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@
M:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N
M86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&
M;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F
M871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S
M`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO
M=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`
M06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT
M(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#
M:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.
M97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A
M(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D
M(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ
M`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T
M;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I
M9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!
M9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM
M96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!
M;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_
M`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T
M92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R
M;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N
M871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD
M;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!
M;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P
M;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@
M0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!
M<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV
M92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!
M<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I
M;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T
M<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E
M<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H
M.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE
M;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I
M;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H
M92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A
M:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO
M="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI
M;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI
M8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4
M>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC
M:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O
M='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN
M9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R
M:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#
M`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`
M0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#
M86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T
M('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A
M;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O
M8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD
M<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@
M<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T
M;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@
M3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T
M:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN
M9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#
M97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!0
M87-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P
M;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL
M<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W
M;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E
M<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D
M871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L
M;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#
M;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A
M<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K
M97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC
M<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#
M;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS
M`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@
M<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#
M;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N
M9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P
M=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A
M:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C
M;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O
M;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S
M96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E
M+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D
M9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@
M(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B
M)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@
M8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B
M+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L
M:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S
M(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N
M(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P
M87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O
M9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U
M;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S
M`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B
M('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S
M`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A
M(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E
M871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#
M=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT
M(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E
M871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S
M96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C
M:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A
M:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T
M92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`
M1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A
M=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H
M96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O
M=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`
M1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O
M=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S
M`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT
M(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV
M97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP
M=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E
M=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@
M`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO
M;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T
M`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N
M)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A
M9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@
M<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M
M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED
M92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%
M9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`
M161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA
M:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`
M16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`
M16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@
M<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@
M4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C
M;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I
M<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I
M;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R
M<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U
M<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC
M`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C
M=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N
M($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&
M86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S
M97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O
M<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE
M=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E
M($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L
M<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W
M97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&
M:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I
M;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S
M`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&
M;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#
M;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED
M92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`
M1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A
M<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E
M;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U
M;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I
M;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A
M;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G
M;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@
M*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T
M<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD
M87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R
M;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`
M1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E
M<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U
M`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O
M=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA
M:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@
M27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B
M<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I
M=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O
M9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y
M(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE
M(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@
M:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V
M960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG
M`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E
M<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(
M=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0
M($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V
M:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N
M;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA
M;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O
M<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@
M:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T
M;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y
M('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E
M(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`
M26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@
M9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E
M($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O
M`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N
M`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B
M;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E
M`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C
M96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E
M<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L
M=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A
M9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R
M`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R
M('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G
M90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S
M96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R
M961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R
M($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI
M8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET
M=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL
M92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO
M;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN
M=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`
M26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L
M:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L
M:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E
M;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M
M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`
M2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU
M;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*
M=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I
M9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG
M97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER
M:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`
M2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER
M9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A
M=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,
M87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T
M(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,
M87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,
M969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB
M97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG
M:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@
M4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4
M:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`
M3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T
M;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU
M>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,
M;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I
M;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U
M=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I
M;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-
M87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU
M<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E
M9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V
M(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI
M;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@
M;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y
M<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C
M;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-
M97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`
M36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN
M9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N
M($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO
M9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`
M36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO
M;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#
M;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2
M:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L
M=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT
M:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T
M:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@
M1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L
M86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.
M971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@
M55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@
M55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I
M8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R
M:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@365S<V%G
M92!T;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@
M6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W
M("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`
M3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI
M9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R
M961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U
M<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.
M;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@
M;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N
M<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG
M('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R
M('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R
M;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I
M8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES
M<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T
M97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D
M+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O
M=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A
M8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R
M<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@
M;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`
M3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M
M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I
M<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@
M=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@
M9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@
M9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N
M86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF
M;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG
M:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@
M2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H
M96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`
M4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`
M4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`
M4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W
M;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I
M;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E
M(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`
M4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI
M960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R
M<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE
M`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E
M<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R
M('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D
M9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N
M=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A
M;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O
M8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O
M<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A
M9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`
M4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S
M(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?
M<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@
M`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R
M979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O
M8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT
M`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!)
M;F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C
M97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U
M97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C
M=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A
M:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO
M`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@
M9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`
M4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M
M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!2
M96UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E
M('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V
M92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC
M92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I
M9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S
M<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L
M9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E
M<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E
M='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO
M;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H
M="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE
M`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`
M4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E
M<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,
M('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,
M(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`
M4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6
M:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`
M4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL
M:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E
M("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`
M4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E
M;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE
M=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`
M4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T
M(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N
M9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E
M<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D
M;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y
M8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@
M:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U
M<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W
M97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I
M9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R
M82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM
M`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO
M=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W
M97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W
M(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI
M80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A
M9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3
M<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@
M8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T
M87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3
M=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T
M<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE
M(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C
M=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T
M(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S
M9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D
M(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S
M<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L
M;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U
M8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S
M`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E
M`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P
M97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N
M9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC
M(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@
M5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`
M5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!4
M86EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE
M<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E
M`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E
M<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@
M061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT
M=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D
M:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B
M92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L
M;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N
M9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U
M('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL
M>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H
M92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES
M(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D
M:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC
M<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T
M:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N
M`%1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@
M9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W
M:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H
M870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@
M97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U
M;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO
M=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T
M('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE
M87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L
M;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W
M:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O
M('1H92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B
M92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC
M92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M
M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U
M;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E
M(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N
M`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H
M92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T
M;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E
M('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O
M(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E
M<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E
M<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES
M=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B
M;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE
M("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P
M87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@
M9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I
M96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF
M:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@
M<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E
M;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL
M("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510
M('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@
M5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N
M="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@
M;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L
M9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N
M=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@
M97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N
M('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@
M1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L
M:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V
M97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I
M;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M
M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@
M2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4
M;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B
M86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H
M25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L
M86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!5
M4DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@
M9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5
M;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N
M86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I
M;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH
M*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5
M;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5
M;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@
M8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`
M57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N
M86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R
M:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E
M<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG
M`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE3
M0TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A
M<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@
M52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V
M:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R
M;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E
M9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ
M*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA
M<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT
M(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`
M5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD
M.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O
M<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T
M<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE
M8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A
M<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C
M86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)
M=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO
M=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@
M86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A
M=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N
M93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO
M=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G
M:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@
M:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`
M6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT
M70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI
M;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S
M`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`
M7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E
M($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A
M9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L
M:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I
M;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O
M<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@
M;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R
M<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R
M<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@:6UP
M;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`
M<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N
M8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R
M`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R
M9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C
M=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO
M<F1E(#,N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,34@,3<Z,C0K
M,#$P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$U(#$W.C(T*S`Q,#`*
M3&%S="U4<F%N<VQA=&]R.B!-86YU96P@4"X@07EA;&$@/&UA>6%L84!U;F5X
M+F5S/@I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%
M+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN("$](#$I.PH`
M("AH86-E("5S(&3M87,I`"`H06-C961I96YD;R!A("5S*0`@*&5N("5S(&3M
M87,I`"`H:&]Y*0`@*&UA\6%N82D`("AA>65R*0!E;B``(B5S(B!N;R!E<R!U
M;B!D:7)E8W1O<FEO+@`B)7,B(&YO(&5S('5N82!E;&5C8VGS;B!VX6QI9&$N
M`$YO('-E(&AA(&-O;F9I9W5R861O("(E<R(@96X@96P@<F5G:7-T<F\@9&4@
M2&]R9&4N`$YO('-E(&5N8V]N='+S(&5L(&=E;F5R861O<B!D92#A<F)O;&5S
M(&1E("(E<R(N`%-E(&AA(&'Q861I9&\@(B5S(B!A;"!S:7-T96UA(&1E(&=R
M=7!O<RX`4V4@:&$@8?%A9&ED;R`B)7,B(&%L('-I<W1E;6$@9&4@<')I=FEL
M96=I;W,N`$YO('-E(&AA(&-R96%D;R`B)7,B.B`E<RX`57-A9&]S("4N,F9-
M0B!D92`E+C)F34(@<&5R;6ET:61O<R`H)2XR9B4E*0`E9"`E<R!Y("5S`%%U
M961A;B`E9"!D[6%S(&AA<W1A('%U92!E>'!I<F4@;&$@8V]N=')A<V7Q82X`
M)60@<')O;O-S=&EC;W,@9&EA<FEO<P`E<R`M($%V:7-O`$AU96QL82!D:6=I
M=&%L(&1E("5S`"5S($M"`"5S(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM:65N
M=&\@+2!#;VYF:7)M86-I\VX`0V]N9FEG=7)A8VGS;B!D92`E<P!&:7)M82!D
M92`E<P!!8W5E<F1O<R!D92!L:6-E;F-I82!D92`E<P!982!E>&ES=&4@)7,N
M`"5S(&$@;&%S("5S("5S`"5S(&5S=.$@<')E<&%R861O('!A<F$@<F5A;&EZ
M87(@;&%S(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\@<V5L96-C:6]N
M861A<RY!8W1I=F4@;&%S(&-A<VEL;&%S(&1E(&QA<R!O<&5R86-I;VYE<R!Q
M=64@9&5S96$@96IE8W5T87(@96X@97-T82!O8V%S:?-N+@!(86-E(&9A;'1A
M("5S`"5S(&UI;G5T;W,`3F\@<V4@:&$@96YC;VYT<F%D;R`E<RX`)7,@86P@
M)7,@9&4@)7,`1&ER96-C:6]N97,@9&4@)7,`06=E;F1A(&1E("5S`$QI8G)E
M=&$@9&4@;F]T87,@9&4@)7,`5&%R96%S(&1E("5S`"5S.B`E<P`E<SH@17-T
M92!M96YS86IE('!U961E('%U92!N;R!P<F]C961A(&1E('%U:65N('!A<F5C
M92!S97(N($5V:71E('-E9W5I<B!C=6%L<75I97(@=NUN8W5L;R!I;F-L=>UD
M;R!O('-U;6EN:7-T<F%R(&-U86QQ=6EE<B!I;F9O<FUA8VGS;B!P97)S;VYA
M;"!A;"!R96UI=&5N=&4N`"P@=F5N=&]S;R``+"!V96YT;W-O("5S("5S`"P@
M=F%R:6%B;&4@9&4@)7,@82`E<P`M+2!S96QE8V-I;VYA<B`M+0!&;W)M871O
M(&1E(#$R(&AO<F%S`$9O<FUA=&\@9&4@,C0@:&]R87,`,C0@:&]R87,`/$%N
M=&5R:6]R`%!A<F$@97-T92!B;&]Q=64@:&%C92!F86QT82!U;B!M;W1O<B!D
M92!B87-E(&1E(&1A=&]S+@!392!H82!P<F]D=6-I9&\@=6X@97)R;W(@:7)R
M97!A<F%B;&4`2&%C92!F86QT82!U;F$@8VQA=F4@4$=0('#Z8FQI8V$@<&%R
M82!C:69R87(@=6X@;65N<V%J92X`2&%C92!F86QT82!U;F$@8VQA=F4@4$=0
M('#Z8FQI8V$@<&%R82!C;VUP<F]B87(@=6X@;65N<V%J92!F:7)M861O+@!(
M86-E;B!F86QT82!U;F$@8VQA=F4@4$=0('#Z8FQI8V$L('5N82!C;&%V92!0
M1U`@<')I=F%D82!Y('5N82!F<F%S92!C;&%V92!P87)A(&1E<V-I9G)A<B!U
M;B!M96YS86IE+@!(86-E;B!F86QT82!U;F$@8VQA=F4@4$=0('#Z8FQI8V$L
M('5N82!C;&%V92!01U`@<')I=F%D82!Y('5N82!F<F%S92!C;&%V92!P87)A
M(&9I<FUA<B!U;B!M96YS86IE+@!(86-E;B!F86QT82!U;F$@8VQA=F4@4R]-
M24U%('#Z8FQI8V$L('5N82!C;&%V92!3+TU)344@<')I=F%D82!Y('5N82!F
M<F%S92!C;&%V92!P87)A(&1E<V-I9G)A<B!U;B!M96YS86IE+@!(86-E;B!F
M86QT82!U;F$@8VQA=F4@4R]-24U%('#Z8FQI8V$L('5N82!C;&%V92!3+TU)
M344@<')I=F%D82!Y('5N82!F<F%S92!C;&%V92!P87)A(&9I<FUA<B!U;B!M
M96YS86IE+@!(86-E(&9A;'1A('5N82!C;&%V92!334E-12!P^F)L:6-A('!A
M<F$@8VEF<F%R('5N(&UE;G-A:F4N`$YU8F5S(&UA=&EN86QE<P!,:6=E<F$@
M;&QU=FEA(&UA=&EN86P`3&QU=FEA(&UA=&EN86P`06=U86-E<F]S(&UA=&EN
M86QE<P!!9W5A8V5R;R!M871I;F%L(&1E(&YI979E`$%-+U!-`$E$(&1E($%0
M20!!8V5R8V$@9&5L(&5D:71O<@!!8V5R8V$@9&4N+BX`26YF97)I;W(@06)S
M+@!%;B!M961I;R!!8G,N`%-E(&AA(&1E;F5G861O(&5L(&%C8V5S;R!A;"!C
M<F5A<B!E;"!D:7)E8W1O<FEO(%9&4RX`4V4@:&$@9&5N96=A9&\@96P@86-C
M97-O(&%L(&-R96%R(&5L(&%R8VAI=F\@5D93+@!)9&5N=&ED860`0V]N=')A
M<V7Q82!D92!A8V-E<V\`261E;G1I9&%D(&)L;W%U96%D82X`0V]N=&%B:6QI
M9&%D`$'Q861I<@!!\6%D:7(@9W)U<&\@9&5S8V5N9&EE;G1E`$'Q861I<B!P
M<FEV:6QE9VEO(&1E<V-E;F1I96YT90!!\6%D:7(@87%U[3H`0?%A9&ER(&=R
M=7!O`$'Q861I<B!P<FEV:6QE9VEO`$'Q861I<B!A("(E<R(@=6X@9W)U<&\@
M9&5S8V5N9&EE;G1E`$'Q861I<B!A("(E<R(@=6X@<')I=FEL96=I;R!D97-C
M96YD:65N=&4`0?%A9&ER('5N('5S=6%R:6\Z`$'Q861I<B!C;VQU;6YA`$'Q
M861I<B!M:65M8G)O<P!!\6%D:7(@<&%R`$'Q861I<B!E;"!M96[Z("5S(&-O
M;6\@<&%N96P@;&%T97)A;"!D92!-;WII;&QA`$'Q861I<B!A(&QA<R!D:7)E
M8V-I;VYE<SH`0?%A9&ER(&$@;&%S(&1I<F5C8VEO;F5S.@!!\6%D:7(@=7-U
M87)I;P!392!H82!A\6%D:61O("(E<R(@86P@<VES=&5M82P@<&5R;R!N;R!S
M92!P=65D92!A\6%D:7(@;&$@:6YF;W)M86-I\VX@861I8VEO;F%L(&1E(&%L
M=&$Z("5S+@!392!H82!A\6%D:61O("(E<R(@86P@<VES=&5M82X@66$@<'5E
M9&4@:6YI8VEA<B!L82!S97-I\VXN`$QA(&%D:6-I\VX@9&4@=7-U87)I;W,@
M97-TX2!D97-H86)I;&ET861A+@!$:7)E8V-I\VX`1&ER96-C:6]N97,`061M
M:6YI<W1R861O<B`M(&1E9FEN92!P<FEV:6QE9VEO<R!D92!O=')O<R!U<W5A
M<FEO<P!!9&UI;FES=')A8VGS;@!!;G5N8VEO<P!!9F=A;FES=.%N`$%L8F%N
M:6$`07)G96QI80!!;&EA<P!!;&EN96%R`$%L:6YE86-I\VXZ`%1O9&]S`%1O
M9&]S(&QO<R!U<W5A<FEO<R!A=71E;G1I9FEC861O<P!4;V1O<R!L;W,@9W)U
M<&]S`%1O9&]S(&QO<R!P<FEV:6QE9VEO<P!4;V1O<R!L;W,@;&%D;W,`4&5R
M;6ET:7(@=F%R:6%S(&1I<F5C8VEO;F5S`+]097)M:71I<B!C;VYF:6=U<F%C
M:?-N(&1E('1I<&\@9&4@;&ES=&%S(&]R9&5N861A<S\`66$@97AI<W1E`$%C
M8V5S;R!)35-0(&%L=&5R;F%T:79O`$-L879E($E-4U`@86QT97)N871I=F$`
M57-U87)I;R!)35!3(&%L=&5R;F%T:79O`$1I<F5C8VGS;B!E;&5C='+S;FEC
M82!A;'1E<FYA=&EV80!0;&%N=&EL;&%S(&%L=&5R;F%T:79A<P!497AT;R!A
M;'1E<FYA=&EV;P!386UO82!!;65R:6-A;F$`4V4@:&$@:6YD:6-A9&\@=6X@
M=F%L;W(@:6QE9V%L+@!392!H82!P<F]D=6-I9&\@=6X@97)R;W(@9&5S8V]N
M;V-I9&\N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&$`4')O>'D@86[S;FEM;P!2
M97-P=65S=&$`06YTX7)T:61A`$%N=&EG=6$@>2!"87)B861O<P!!<&QI8V%C
M:?-N`$QI<W1A(&1E(&%P;&EC86-I;VYE<P!,82!A<&QI8V%C:?-N(&5S=.$@
M;&ES=&$N`$%P;&EC87(@82!R96-U<G-O<R!C;VUP87)T:61O<R!D97-C96YD
M:65N=&5S`$%P<F]B87(`5&%M8?%O(&%P<F]X:6UA9&\`06)R:6P`07+A8FEG
M;R`H5VEN9&]W<RTQ,C4V*0!486UA\6\@9&5L(&%R8VAI=F\`3F]M8G)E(&1E
M;"!A<F-H:79O`+]%<W1A('-E9W5R;R!D92!Q=64@9&5S96$@96QI;6EN87(@
M;&$@<V]L:6-I='5D(&1E(&%L=&$@9&4@)7,_`+]%<W3A('-E9W5R;R!D92!Q
M=64@9&5S96$@96QI;6EN87(@(B5S(B!Y('1O9&]S('-U<R!S=6)G<G5P;W,_
M`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6\@*$%235-#24DM."D`07)T90!!
M<G5B80!)<VQA($%S8V5N<VGS;@!'<N%F:6-O<R!!<V-I:0!296=I\VX@9&4@
M07-I82]086/M9FEC;P"_4V]L:6-I=&%R(&-O;F9I<FUA8VGS;B!A;G1E<R!D
M92!R96%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O/P!#;VQU
M;6YA<R!D92!A<VEG;F%C:?-N`$EN=&5N=&$@96QI;6EN87(@=6X@9W)U<&\@
M:6YE>&ES=&5N=&4N`$EN=&5N=&$@96QI;6EN87(@=6X@<')I=FEL96=I;R!I
M;F5X:7-T96YT92X`26YT96YT82!M;V1I9FEC87(@=6X@<')I=FEL96=I;R!I
M;F5X:7-T96YT92X`26YT96YT82!M;V1I9FEC87(@=6X@<F5C=7)S;R!C;VUP
M87)T:61O(&EN97AI<W1E;G1E+@!!=')I8G5T;W,`06=O<W1O`$%U<W1R86QI
M80!!=7-T<FEA`$%U=&A?8WER<W%L.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E
M;G-I\VX@:6UA<"!N96-E<V%R:6$N`$%U=&A?8WER=7,Z($5L(&UO=&]R(&-A
M<F5C92!D92!L87,@8V%P86-I9&%D97,@;F5C97-A<FEA<RX`075T:%]C>7)U
M<SH@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&EM87`@;F5C97-A<FEA
M+@!!=71H7V9T<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N($944"!N
M96-E<V%R:6$N($-O;7!I;&4@4$A0(&-O;B!L82!O<&-I\VX@+2UE;F%B;&4M
M9G1P+@!!=71H7VEM87`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!)
M34%0(&YE8V5S87)I82X`075T:%]K<F(U.B!.;R!S92!E;F-O;G1R\R!L82!E
M>'1E;G-I\VX@:W)B-2!N96-E<V%R:6$N`$%U=&A?;&1A<#H@3F\@97-TX2!S
M;W!O<G1A9&$@;&$@861I8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@1&ER
M96-T;W)Y`$%U=&A?;&1A<#H@3F\@97-TX2!S;W!O<G1A9&$@;&$@96QI;6EN
M86-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!,1$%0(&YE8V5S87)I
M82X`075T:%]L9&%P.B!.;R!S92!P=65D92!A\6%D:7(@96P@=7-U87)I;R`E
M<RX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<CH@`$%U=&A?;&1A
M<#H@26YC87!A>B!D92!E;&EM:6YA<B!E;"!U<W5A<FEO("5S`$%U=&A?;&1A
M<#H@26YC87!A>B!D92!A8W1U86QI>F%R(&5L('5S=6%R:6\@)7,`075T:%]L
M9&%P.B!.;R!E<W3A('-O<&]R=&%D82!L82!A8W1U86QI>F%C:?-N(&1E('5S
M=6%R:6]S(&1E($%C=&EV92!$:7)E8W1O<GD`075T:%]M8V%L.B!.;R!S92!E
M;F-O;G1R\R!L82!E>'1E;G-I\VX@34-!3"!N96-E<V%R:6$N`$%U=&A?<VUB
M875T:#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N('-M8F%U=&@@;F5C
M97-A<FEA+@!&86QL\R!L82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I
M9&]R($E-05`N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;@!&86QL\R!L82!A
M=71E;G1I9FEC86-I\VXN("5S`$5L('-E<G9I9&]R(%)!1$E54R!H82!R96-H
M87IA9&\@;&$@875T96YT:69I8V%C:?-N+@!&86QL\R!L82!A=71E;G1I9FEC
M86-I\VX@8V]N(&5L('-E<G9I9&]R($944"X`1F%L;/,@;&$@875T96YT:69I
M8V%C:?-N(&-O;B!E;"!S97)V:61O<B!334(N`$-A;7!O<R!D:7-P;VYI8FQE
M<SH`07IE<F)A:6IA;@!%>&-U<V%S($)/1D@`1F]N9&\`0V]L;W(@9&4@9F]N
M9&\`0V]N=')A<V7Q82!K97)B97)O<R!I;F-O<G)E8W1A+@!.;VUB<F4@9&4@
M=7-U87)I;R!K97)B97)O<R!I;F-O<G)E8W1O+@!"86AA;6%S`$)A:')A:6X`
M0N%L=&EC;R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`3F\@
M<V4@96YC;VYT<O,@96P@9&ER96-T;W)I;R!B87-E(&1E(&EMX6=E;F5S("(E
M<R(N`$SM;F5A(&)A<V4`0F5L87)U<P!"Z6QG:6-A`$)E;&EZ90!"96YI;@!"
M97)M=61A<P!":'5T86X`0W5M<&QE8?%O<P!.;R!S92!E;F-O;G1R\R!E;"!B
M;&]Q=64@(B5S(B!D92!L82!A<&QI8V%C:?-N("(E<R(N`$]P8VEO;F5S(&1E
M(&)L;W%U90!4:7!O(&1E(&)L;W%U90!.96=R:71A`$)O;&EV:6$`36%R8V%D
M;W)E<P!";W)D90!'<F]S;W(@9&5L(&)O<F1E.@!";W)D97,`0F]S;FEA($AE
M<GIE9V]V:6YA`$%M8F]S`$)O='-W86YA`$EN9F5R:6]R`$ES;&$@9&4@0F]U
M=F5T`$)R87-I;`!497)R:71O<FEO(&]C9>%N:6-O(&1E(&QA($EN9&EA(&)R
M:73A;FEC80!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!,:7-T82!D97-O
M<F1E;F%D80!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`%!U;G1O<R!D
M92!D:7-T<FEB=6-I\VX@0U)#`%!R;W!I961A9&5S(&1E(%]C96QD82XN+@!.
M;R!S92!H82!F:6YA;&EZ861O(&5L(&EN:6-I;R!D92!L82!C86-HZ2X`06=E
M;F1A`$-A;&UA`$-A;6)O>6$`0V%M97+Z;@!.;R!S92!P=65D92!R96%J=7-T
M87(@;&$@8VQA=F4@875T;VWA=&EC86UE;G1E+"!P\VYG87-E(&5N(&-O;G1A
M8W1O(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA+@!.;R!S92!P
M=65D92!E<V-R:6)I<B!E;B!E;"!A<F-H:79O("(E<R(`3F\@<V4@<'5E9&5N
M(&%D;6EN:7-T<F%R(&UA;F5J861O<F5S(&1E('-E<VGS;B!E>'1E<FYO<RX`
M3F\@<V4@<'5E9&4@8V]N96-T87(@86P@<V5R=FED;W(@24U!4#H@)7,`3F\@
M<V4@<'5E9&4@86)R:7(@96P@87)C:&EV;R`B)7,B+@!#86YA9.$`0V%N8V5L
M87(`0V%N8V5L87(@:6YF;W)M92!D92!P<F]B;&5M87,`3F\@<V4@<'5E9&4@
M96QI;6EN87(@96P@87)C:&EV;R`B)7,B+@!.;R!S92!E;F-U96YT<F$@=6X@
M9&ER96-T;W)I;R!T96UP;W)A;"X`3F\@<V4@<'5E9&4@8V]N=&EN=6%R('-I
M;B!E;"!P87+A;65T<F\@)W1A<F=E=$9I;&4G+@!.;R!S92!P=65D92!E;&EM
M:6YA<B!E;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&5L:6UI;F%R
M+"!T:65N92`E9"!D97-C96YD:65N=&5S+@!.;R!S92!P=65D92!R96]R9&5N
M87(L(&5L(&[Z;65R;R!D92!E;G1R861A<R!Q=64@<V4@9&5S96$@;W)D96YA
M<B!N;R!C;VEN8VED92!C;VX@;&%S(&%L;6%C96YA9&%S+@!.;R!S92!P=65D
M92!D:7)I9VER(&5L(&UE;G-A:F4@86P@;OIM97)O(&5S<&5C:69I8V%D;RX`
M0V%B;R!697)D90!3=6)T[71U;&\`4')O=F5E9&]R`$-A=&5G;W+M87,@>2!E
M=&EQ=65T87,`27-L87,@0V%I;>%N`%1E;.EF;VYO(&WS=FEL`%!R;W!I961A
M9&5S(&1E(&-E;&1A`$UA<F=E;B!D92!C96QD83H`4')O<&EE9&%D97,@9&4@
M8V5L9&$`17-P86-I861O(&1E(&-E;&1A.@!496SI9F]N;R!M\W9I;`!#Z6QT
M:6-O("A)4T\M.#@U.2TQ-"D`0V5N=')A<@!297#Z8FQI8V$@0V5N=')O869R
M:6-A;F$`175R;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I`$1E=&%L;&5S(&1E
M;"!C97)T:69I8V%D;P!0<F]P:65T87)I;R!D96P@8V5R=&EF:6-A9&\`4&]L
M[71I8V%S(&1E;"!C97)T:69I8V%D;P!#:&%D`$-A;6)I87(`0V%M8FEE(&QA
M(&-O;G1R87-E\6$`0V%M8FEA(&5L(&YO;6)R92!Y(&QA(&1I<F5C8VGS;B!E
M;&5C='+S;FEC82!V:7-I8FQE<R!A;"!L965R(&\@<F5S<&]N9&5R(&$@<W5S
M(&UE;G-A:F5S+@!,82!C;VYF:6=U<F%C:?-N(&%C='5A;"!N;R!S;W!O<G1A
M(&5L(&-A;6)I;R!D92!C;VYT<F%S9?%A<RX@4/-N9V%S92!E;B!C;VYT86-T
M;R!C;VX@96P@861M:6YI<W1R861O<B!D96P@<VES=&5M82X`1W+A9FEC;P!6
M97)I9FEC87(@7W;M;F-U;&\N+BX`0VAI;&4`0VAI;F$`0VAI;F\@<VEM<&QI
M9FEC861O("A'0C(S,3(I`$-H:6YO('1R861I8VEO;F%L("A":6<U*0!!<&QI
M8V%C:?-N.@!%;&EJ82!U;F$@8V]N=')A<V7Q80!%;&EJ82!U;B!N;VUB<F4@
M9&4@=7-U87)I;P!%;&EJ82!C\VUO(&UO<W1R87(@;&%S(&9E8VAA<SH`4V5L
M96-C:6]N87(@=&EP;R!D92!E<W1I;&\@9&4@;&ES=&$@*'!A<F$@;&ES=&%S
M(&]R9&5N861A<RD`27-L82!D92!087-C=6$`3F\@<V4@96YC;VYT<O,@;&$@
M9&5F:6YI8VGS;B!D92!C;&%S92!D92`E<RX`3&EM<&EA<@!%;&EM:6YA<B!E
M=&EQ=65T87,@35-/9F9I8V4`0F]R<F%R(&-O;G-U;'1A`$)O<G)A<B!U<W5A
M<FEO.B`E<P!";W)R87(@=7-U87)I;P!";W)R87(@9&%T;W,@9&5L('5S=6%R
M:6\`1&5S<&5J861O('1A<F3M;P!(86=A(&-L:6-K('!A<F$@<V5G=6ER`$-L
M:6-K871E;&P@<&]R($A45%``0V5R<F%R('9E;G1A;F$`3G5B97,`3G5B97,@
M=&5M<')A;F%S`&YU8F]S;P!)<VQA<R!D92!C;V-O<R`H2V5E;&EN9RD`3V-U
M;'1A<B!B87)R82!L871E<F%L`$-O;&%P<V%R(&)O<F1E<P!#;VQO;6)I80!#
M;VQO<@!396QE8W1O<B!D92!C;VQO<@!396QE8V-I\VX@9&4@8V]L;W(`0V]L
M=6UN87,Z`%3M='5L;W,@9&4@;&%S(&-O;'5M;F%S`$/S;6EC<P!#;VUA;F1O
M`$EN=.ER<'(N(&-O;6%N9&]S`$-O;65N=&%R:6\`3F]M8G)E(&-O;?IN`$-O
M;6]R;W,`0V]M<&'Q[6$`3W)D96YA9&]R97,`0V]N9&EC:?-N`$-O;F1I8VEO
M;F5S`$1I9F5R96YC:6%S(&1E(&QA(&-O;F9I9W5R86-I\VX`0V]N9FEG=7)A
M8VGS;B!P87)A('-I;F-R;VYI>F%C:?-N(&-O;B!01$%S+"!-\W9I;&5S(&-O
M;B!A9V5N9&$@>2!/=71L;V]K+@!,82!C;VYF:6=U<F%C:?-N(&5S=.$@9&5S
M86-T=6%L:7IA9&$N`$-O;F9I9W5R87(@)7,`0V]N9FER;6%R(&-O;G1R87-E
M\6$`0V]N9V\`0V]N9V\L(%)E</IB;&EC82!$96UO8W+A=&EC82!D96P`1F%L
M;/,@;&$@8V]N97AI\VXN`$9A;&SS(&QA(&-O;F5X:?-N.B``4V4@:&$@<F5C
M:&%Z861O(&QA(&-O;F5X:?-N(&%L('-E<G9I9&]R(&1E(&-L879E<R!P^F)L
M:6-O+@!392!H82!R96-H87IA9&\@;&$@8V]N97AI\VX@86P@<V5R=FED;W(@
M9&4@8VQA=F5S('#Z8FQI8V\N($UO=&EV;SH@)7,@*"5S*0!(82!F86QL861O
M(&QA(&-O;F5X:?-N(&%L('-E<G9I9&]R($944"X`0V]N=&%C=&]S`%-E(&AA
M;B!A\6%D:61O(&-O<G)E8W1A;65N=&4@;&]S(&-O;G1A8W1O<R!A('-U<R!D
M:7)E8V-I;VYE<P!4:7!O(&1E(&-O;G1E;FED;R!D96P@87)C:&EV;R!C;VUP
M<FEM:61O.B``0V]N=&5N:61O(&1E("(E<R(`0V]N=&EN=6%R`$ES;&%S($-O
M;VL`0V]O:VEE`$-O<&EA<@!&86QL\R!L82!C;W!I83H@)7,`0V]P:6%R('-E
M;&5C8VGS;@!)1"!D92!C;W-T90!#;W-T82!2:6-A`$-O<W1A(&1E($UA<F9I
M;`!.;R!S92!P=65D92!C:69R87(@96P@;65N<V%J92!M961I86YT92!01U`Z
M(`!.;R!S92!P=65D92!F:7)M87(@96P@;65N<V%J92!M961I86YT92!01U`Z
M(`!.;R!S92!P=65D92!C:69R87(@96P@;65N<V%J92!M961I86YT92!3+TU)
M344`3F\@<V4@<'5E9&4@9FER;6%R(&5L(&UE;G-A:F4@;65D:6%N=&4@(%,O
M34E-10!.;R!S92!P=65D92!A\6%D:7(@96P@8V]N=&%C=&\N("5S`$YO('-E
M('!U961E(&5N;&%Z87(@86P@<V5R=FED;W(@3$1!4"X`3F\@<V4@<'5E9&4@
M8V]M<')O8F%R(&5L('-A;&1O+B`E<P!.;R!S92!P=65D92!C;VYE8W1A<B!A
M;"!S97)V:61O<B!,1$%0+@!.;R!S92!P=65D92!C;VYE8W1A<B!A;"!S97)V
M:61O<B`B)7,B(&UE9&EA;G1E($944#H@)7,`3F\@<V4@<'5E9&4@8W)E87(@
M;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P=65D96X@9&5S
M8VEF<F%R(&QO<R!D871O<R!01U`Z(`!.;R!S92!P=65D96X@9&5S8VEF<F%R
M(&QO<R!D871O<R!3+TU)344N`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&-O
M;G1A8W1O+B`E<P!.;R!S92!P=65D92!E;&EM:6YA<B!L82!L:7-T82!D92!D
M:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&=U:?-N
M(&1E(&%C='5A;&EZ86-I\VX@9&4@8V]N9FEG=7)A8VGS;B`B)7,B+@!.;R!S
M92!P=65D92!D971E<FUI;F%R82!L82!D:7)E8V-I\VX@9&4@8V]R<F5O(&1E
M;"!D97-T:6YA=&%R:6\N`$YO('-E('!U961E('1R865R(&QA(&QI8G)E=&$@
M9&4@9&ER96-C:6]N97,@8V]M<&QE=&$N`$YO('-E('!U961E('1R865R(&QA
M(&QI<W1A(&1E(&1I<W1R:6)U8VGS;B!C;VUP;&5T82X`3F\@<V4@<'5E9&4@
M=')A97(@;&$@;&ES=&$@8V]M<&QE=&$@9&4@;&ES=&%S(&1E(&1I<W1R:6)U
M8VGS;BX`3F\@<V4@<'5E9&4@8V%R9V%R(&QA(&5S=')A=&5G:6$@(B5S(BX`
M3F\@<V4@<'5E9&4@8W)E87(@96P@9&ER96-T;W)I;R`B)7,B+@!.;R!S92!P
M=65D92!O8G1E;F5R(&QA(&-L879E('#Z8FQI8V$@9&5L('-E<G9I9&]R(&1E
M(&-L879E<RX`3F\@<V4@<'5E9&4@86)R:7(@(B5S(B!P87)A(&5S8W)I8FER
M+@!.;R!S92!P=65D92!A8G)I<B`E<RX`3F\@<V4@<'5E9&4@86)R:7(@96P@
M;?-D=6QO(&1E('1A<F5A<R!D92!M86YT96YI;6EE;G1O("5S`$YO('-E('!U
M961E(&%B<FER(&5L(&1I<F5C=&]R:6\@(B5S(BX`3F\@<V4@<'5E9&4@;&]C
M86QI>F%R(&5L('-E<G9I9&]R($Q$05`N`$YO('-E('!U961E(&QE97(@)7,N
M`$YO('-E('!U961E(')E<W1A8FQE8V5R(&QA(&-O;G1R87-E\6$@9&5L('5S
M=6%R:6\@<V]L:6-I=&%D;RX@4&%R=&4@9&4@;&]S(&1E=&%L;&5S(&\@=&]D
M;W,L('-O;B!I;F-O<G)E8W1O<RX@4')U96)E(&]T<F$@=F5Z(&\@</-N9V%S
M92!E;B!C;VYT86-T;R!C;VX@96P@861M:6YI<W1R861O<B!D96P@<VES=&5M
M82!P87)A(&WA<R!I;F9O<FUA8VGS;BX`3F\@<V4@<'5E9&4@;V)T96YE<B!L
M82!!0TPN`$YO('-E('!U961E(&]B=&5N97(@;&$@;&EB<F5T82!D92!D:7)E
M8V-I;VYE<RX@)7,`3F\@<V4@<'5E9&4@;V)T96YE<B!L82!L:7-T82!D92!D
M:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E;B!O8G1E;F5R(&QA<R!L:7-T
M87,@9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P=65D96X@;V)T96YE<B!L
M87,@8V%P86-I9&%D97,@9&5L('-E<G9I9&]R`$YO('-E('!U961E(')E<W1A
M=7)A<B!L82!C;VYF:6=U<F%C:?-N+@!.;R!S92!P=65D92!E;&EM:6YA<B!E
M;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&=U87)D87(@;&$@8V]N
M9FEG=7)A8VGS;B!D92`E<RX`3F\@<V4@<'5E9&4@9W5A<F1A<B!U;F$@8V]P
M:6$@9&4@;&$@8V]N9FEG=7)A8VGS;BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!U
M;F$@8V]P:6$@9&4@;&$@8V]N9FEG=7)A8VGS;CH@)7,`3F\@<V4@<'5E9&4@
M9W5A<F1A<B!E;"!G=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I
M9W5R86-I\VX@96XZ("(E<R(N`$YO('-E('!U961E(&=U87)D87(@;&$@8V]P
M:6$@)7,@9&4@;&$@8V]N9FEG=7)A8VGS;BX`3F\@<V4@<'5E9&4@9W5A<F1A
M<B!E;"!A<F-H:79O("5S(&1E(&-O;F9I9W5R86-I\VXN(%!U961E('5T:6QI
M>F%R('5N82!D92!L87,@;W!C:6]N97,@<&%R82!R97-T875R87(@96P@8_-D
M:6=O(&1E("5S(&\@8V]P:6%R(&UA;G5A;&UE;G1E(&$@)7,@96P@8_-D:6=O
M('-I9W5I96YT92X`3F\@<V4@<'5E9&4@8G5S8V%R(&5N(&5L('-E<G9I9&]R
M($Q$05`N`$YO('-E('!U961E(&1E<W9I;F-U;&%R("(E<R(N`$YO('-E('!U
M961E(&%C='5A;&EZ87(@96P@8V]N=&%C=&\N("5S`$YO('-E('!U961E(&%C
M='5A;&EZ87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P
M=65D92!E<V-R:6)I<B!L82!C;VYF:6=U<F%C:?-N(&1E("(E<R(Z("5S`$YO
M('-E('!U961E(&QO8V%L:7IA<B!E;"!P86YE;"!L871E<F%L(&1E($UO>FEL
M;&$N($-O;7!R=65B92!Q=64@97-TZ2!A8FEE<G1O+@!.;R!S92!P=65D96X@
M;W1O<F=A<B!A;"!U<W5A<FEO("(E<R(@;&]S('-I9W5I96YT97,@9&5R96-H
M;W,@<&%R82!L82!C87)P971A("(E<R(Z("5S`%1E>'1O(&-O;G1A9&\`4&'M
M<P!#=7)S;W,`0W)E87(`0W)E82!U;B!V[6YC=6QO`$-R96%R`$-R96%R('-U
M8F-A<G!E=&%S`%!R:79I;&5G:6]S(&1E(&-R96%D;W(`3OIM97)O(&1E('1A
M<FIE=&$@9&4@8W+I9&ET;P!#<F]A8VEA`$-U8F$`-"!&87-E<R!A8W1U86QE
M<P!397-I;VYE<R!A8W1U86QE<P!(;W)A(&%C='5A;`!54DP@86-T=6%L`%5S
M=6%R:6]S(&%C='5A;&5S`%1I96UP;R!A8W1U86P`0V]N9&EC:?-N(&%C='5A
M;#H@`$5S=&EL;R!A8W1U86P`4&5R<V]N86QI>F$@;&%S('1A<F5A<R!A(&5J
M96-U=&%R(&%L(&EN:6-I87(@<V5S:?-N(&5N("5S+@!#;W)T87(`0V]R=&%R
M('-E;&5C8VGS;@!#:&EP<F4`0VER[6QI8V\@*$M/23@M4BD`0VER[6QI8V\@
M*%=I;F1O=W,M,3(U,2D`0VER[6QI8V\O56-R86YI86YO("A+3TDX+54I`%)E
M</IB;&EC82!#:&5C80!$1`!$4TX@*'9E82!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E<R]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M`$1I87)I86UE;G1E`,%R7V)O;"!D871O<P!#;VYS=6QT82!D92!L82!B87-E
M(&1E(&1A=&]S`$9E8VAA`%-E(&AA(')E8VEB:61O(&QA(&9E8VAA`%-E;&5C
M8VGS;B!D92!F96-H80!$[6$`15]L:6UI;F%R(&-O;'5M;F$`1&EC:65M8G)E
M`$[Z;65R;W,@9&5C:6UA;&5S`%)E9'5C:7(@<V%N9W)A9&\`4&]R(&]M:7-I
M\VX`0V]L;W(@<&]R(&]M:7-I\VX`261E;G1I9&%D('!O<B!O;6ES:?-N`%-H
M96QL('!O<B!O;6ES:?-N`$1E9FEN:6-I;VYE<P`F;F)S<#M%;&EM:6YA<B9N
M8G-P.P!%;&EM:6YA<B!C96QD80!%;&EM:6YA<B!G<G5P;P!%;&EM:6YA<B!R
M96=I<W1R;P!%;&EM:6YA<B!P<FEV:6QE9VEO`$5L:6UI;F%R('D@=F%C:6%R
M(&UE;G-A:F5S`$5L:6UI;F%R(&-E;&1A`$5L:6UI;F%R(&-O;'5M;F$`16QI
M;6EN87(@<&QA;G1I;&QA<R!A;'1E<FYA=&EV87,@97AI<W1E;G1E<P!%;&EM
M:6YA<B!M96YS86IE<P!%;&EM:6YA<B!P<FEV:6QE9VEO<R!D92`B)7,B`+]%
M;&EM:6YA<B!P<FEV:6QE9VEO<R!P87)A("(E<R(@>2!C=6%L<75I97(@<')I
M=FEL96=I;R!D97-C96YD:65N=&4_`$5L:6UI;F%R(&9I;&$`16QI;6EN87(@
M:61E;G1I9&%D('-E;&5C8VEO;F%D80!%;&EM:6YA<B!S=6)C87)P971A<P!%
M;&EM:6YA(&QA(&-O;'5M;F$@86-T=6%L`$5L:6UI;F$@;&$@9FEL82!A8W1U
M86P`4V4@:&$@96QI;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@
M9&4@;&$@8V]N9FEG=7)A8VGS;B`B)7,B+@!(;W)A(&1E(&5N=')E9V$Z`$1I
M;F%M87)C80!$97-C<FEB82!E;"!P<F]B;&5M80!$97-C<FEP8VGS;@!$971A
M;&QE<R`H=&%M8FGI;B!E;B!E;"!A<F-H:79O(&1E(')E9VES=')O(&1E($AO
M<F1E*3H`4V4@:&%N(')E9VES=')A9&\@;&]S(&1E=&%L;&5S('!A<F$@96P@
M861M:6YI<W1R861O<BX`1&5S87)R;VQL;P!0=6YT;R!D92!C;VYD96YS86-I
M\VX`4'5N=&\@9&4@8V]N9&5N<V%C:?-N(&1E(&QA(/IL=&EM82!H;W)A.B``
M4'5N=&\@9&4@8V]N9&5N<V%C:?-N.B``1&4@:7IQ=6EE<F1A(&$@9&5R96-H
M80!$92!D97)E8VAA(&$@:7IQ=6EE<F1A`$1I<F5C=&]R:6\`OTUO<W1R87(@
M96X@9F]R;6%T;R!D92`R-"UH;W)A<S\`3W!C:6]N97,@9&4@5FES=6%L:7IA
M8VGS;@!-;W-T<F%R('!R;V[S<W1I8V\@9&5T86QL861O`$UO<W1R87(@<')O
M;O-S=&EC;R`H5$%&*0!&;W)M871O(&1E('9I<W5Z86QI>F%C:?-N`$YO=&EF
M:6-A8VGS;B!D92!C;VYS=6QT80!$:FEB;W5T:0!.;R!E;&EM:6YA<@!.;R!A
M8V-E9&5R(&1I<F5C=&%M96YT92!A(&UA:6YT96YA;F-E+G!H<`"_0V]N=&EE
M;F4@;&$@<')I;65R82!F:6QA(&QO<R!N;VUB<F5S(&1E(&QO<R!C86UP;W,_
M(%-I(&5S(&%S[2P@<V5L96-C:6]N92!E<W1A(&-A<VEL;&$Z`$1O;6EN:6-A
M`%)E</IB;&EC82!$;VUI;FEC86YA`+].;R!D:7-P;VYE(&1E(&-U96YT83\@
M4V]L:6/M=&5L82X`1&5S8V%R9V%R`$1E<V-A<F=A<B`E<P!$97-C87)G87(@
M;&$@8V]N9FEG=7)A8VGS;B!G96YE<F%D82!C;VUO('5N(&=U:?-N(%!(4"X`
M3&ES=&$@9&5S<&QE9V%B;&4`1')O9V%S`$-O<G)E;P!#;VYT<F]L861O<B!D
M92!P87-A<F5L82!#;W)R96\M82U335,@<&%R82!P<F]V965D;W)E<R!Q=64@
M<')O<&]R8VEO;F5N(&5S=&4@<V5R=FEC:6\N`$524@!%8W5A9&]R`"9N8G-P
M.TUO9&EF:6-A<B9N8G-P.P!-;V1I9FEC87(@8FQO<75E`$UO9&EF:6-A<B!G
M<G5P;P!-;V1I9FEC87(@<')I=FEL96=I;P!-;V1I9FEC87(@<')I=FEL96=I
M;W,`36]D:69I8V%R('!R:79I;&5G:6]S(&1E("5S`$UO9&EF:6-A<B!O<&-I
M;VYE<R!D93H`36]D:69I8V%R('!R:79I;&5G:6]S(&1E("(E<R(`36]D:69I
M8V%R('!R:79I;&5G:6]S(&1E("5S`$5D=6-A8VGS;@!%9VEP=&\`16P@4V%L
M=F%D;W(`16QE;65N=&\N+BX`16T`0V]R<F5O`$1I<F5C8VGS;B!D92!C;W)R
M96\`3&%S(&1I<F5C8VEO;F5S(&1E(&-O<G)E;R!T:65N96X@<75E(&-O:6YC
M:61I<BX`0V]R<F5O(&-O;B!C;VYF:7)M86-I\VX`4&%S87)E;&$@0V]R<F5O
M+6$M4TU3`$5M;W1I8V]N97,`365N<V%J92!E;B!B;&%N8V\`4F5S=6QT861O
M(&5N(&)L86YC;RX`3&EM<&EA<B!TZ7)M:6YO<R!D92!B^G-Q=65D80"_4&5R
M;6ET:7(@:6YS97)C:?-N(&1E(&EMX6=E;F5S(&1E(&QA<R!'86QE<NUA<R!D
M92!F;W1O<S\`OU!E<FUI=&ER(&UE;OH@9&4@8V]N=&5X=&\@9&5L(&)O=/-N
M(&1E<F5C:&\@9&5L(')A=/-N/P!!\6\@9&4@=&5R;6EN86-I\VX`06=R86YD
M87(@961I=&]R`$EN=')O9'5Z8V$@=6YA('!R96=U;G1A(&1E('-E9W5R:61A
M9"!Q=64@<V4@;&4@9F]R;75L87+A('-I('!R96-I<V$@<F5A:G5S=&%R(&QA
M(&-O;G1R87-E\6$L('`N92X@)[]#=>%L(&5S(&5L(&YO;6)R92!D92!S=2!M
M87-C;W1A/R<Z`$EN=')O9'5Z8V$@87%U[2!L82!54DP@9&4@;&$@:6UA9V5N
M`$EN=')O9'5Z8V$@;&%S(&QE=')A<R!D92!D96)A:F\Z`$=U:6YE82!%8W5A
M=&]R:6%L`$5R:71R96$`17)R;W(`17)R;W(@86P@8W)E87(@96P@8FQO<75E
M.B`E<P!%<G)O<B!A;"!E;&EM:6YA<B!A;F-L82!D92!S:6YC<F]N:7IA8VGS
M;CH@)7,`17)R;W(@86P@96QI;6EN87(@96P@<F5G:7-T<F\@9&4@<VEN8W)O
M;FEZ86-I\VXZ("5S`$5R<F]R(&%L(&]B=&5N97(@8V]N=&5N:61O<SH@)7,`
M17)R;W(@86P@86-T=6%L:7IA<B!L82!C;VYT<F%S9?%A.B`E<P!%<G)O<B!C
M;VX@96P@;65N<V%J92!D92!C;W)R96\N`$5R<F]R(&%L(&5S8W)I8FER("(E
M<R(N`$5S=&]N:6$`171I;W#M80#)=&YI8V\`175R;W!A`$-A9&$@,34@;6EN
M=71O<P!#861A(#(@;6EN=71O<P!#861A(#,P('-E9W5N9&]S`$-A9&$@-2!M
M:6YU=&]S`$-A9&$@:6YI8VEO(&1E('-E<VGS;@!#861A(&UE9&EA(&AO<F$`
M0V%D82!M:6YU=&\`5F%L;W)E<R!D92!E:F5M<&QO.@!%:F5C=71A<@!%>'!A
M;F1I<@!-;W-T<F%R(&)A<G)A(&QA=&5R86P`<V4@97-P97)A8F$@)RDG`%-E
M(&5S<&5R86)A('5N82#Z;FEC82!P86QA8G)A(&\@=6X@=.ER;6EN;R!D92!B
M^G-Q=65D82!E;G1R96-O;6EL;&%D;P!&96-H82!D92!V96YC:6UI96YT;P!%
M>'!O;F5N=&4`0V]L;W(@9&4@;&5T<F$`0V%R9V%R(&QA(&-O;F9I9W5R86-I
M\VX@<&]R($944`!&86QL;R!A;"!T<F%E<B!L87,@<')E9F5R96YC:6%S+@!)
M;F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@<V5R=FED;W(@3$1!4"X`26YC87!A
M>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R(%--0BX`1F%L;&\@86P@8V]P
M:6%R(&1E("(E<R(N`$9A;&QO(&%L(&-O<&EA<B!A("(E<R(N`$9A;&QO(&%L
M(&-R96%R('5N82!C;VYE>&GS;B!305-,`$9A;&QO(&%L('1R87-L861A<B`B
M)7,B+@!&86QL;R!A;"!R96-U<&5R87(Z("5S`$1E<W!E:F%D;P!)<VQA<R!-
M86QV:6YA<R`H1F%L:VQA;F0I`$ES;&%S($9A<F]E`$5R<F]R(&ER<F5C=7!E
M<F%B;&4Z`$9A>`!&87AE<P!&96)R97)O`%-E('-I96YT92!C;VUO`%-E('-I
M96YT92!C;VUO.B``4&]C87,@;&QU=FEA<P!%<V-A<V\@86=U86-E<F\@9&4@
M;FEE=F4`36%T<FEZ(&1E(&-A;7!O<P!#05!40TA!(&1E($9I9VQE=`!,971R
M82!D92!&:6=L970`1FEJ:0!!<F-H:79O`$ZZ(&1E(&%R8VAI=F]S.B`E<R!A
M<F-H:79O`$ZZ(&1E(&%R8VAI=F]S.B`E<R!A<F-H:79O<P!!<F-H:79O<P!.
M;VUB<F4@9&4@87)C:&EV;P!396QE8V-I\VX@9&4@87)C:&EV;P!#87)G87(@
M87)C:&EV;P!,82!C87)G82!D92!A<F-H:79O<R!N;R!E<W3A('-O<&]R=&%D
M82X`1FEL=')O<P!&:6YL86YD:6$`0W5A<G1O(&-R96-I96YT90!#=6%R=&\@
M8W)E8VEE;G1E`%)A>O-N(&9I:F$`5F]L=&5A<@!$:7-P;W-I8VGS;@!.:65B
M;&$`3&$@8V%R<&5T82`E<R!N;R!E>&ES=&4N`$-O;&]R(&1E(&QE=')A`$-O
M;6ED80!087)A(&YA=F5G861O<F5S('%U92!N;R!A9&UI=&%N(&EMX6=E;F5S
M`%!R;V[S<W1I8V\@*%1!1BD`1.UA<R!D96P@<')O;O-S=&EC;R`H=&5N9V$@
M96X@8W5E;G1A('%U92!E;"!P<F]N\W-T:6-O(&9A8VEL:71A9&\@:6YC;'5Y
M92!T86YT;R!E;"!D[6$@8V]M;R!L82!N;V-H93L@=6X@;OIM97)O(&=R86YD
M92!S92!T<F%D=6-I<N$@96X@=6X@8FQO<75E(&UU>2!A;F-H;RD`OTAA(&]L
M=FED861O(&QA(&-O;G1R87-E\6$_`$9O<FUU;&%R:6]S`$9O<G1U;F$`5&EP
M;R!D92!F;W)T=6YA`$9O<G1U;F%S`$9O<G1U;F%S(#(`1F]R;W,`4F5E;G;M
M;W,`5FEE`$9R86UE<P!&<F%N8VEA`$9R86YC:6$L($UE=')O<&]L:71A;F$`
M1W5A>6%N82!F<F%N8V5S80!0;VQI;F5S:6$@9G)A;F-E<V$`5&5R<FET;W)I
M;W,@9G)A;F-E<V5S(&1E;"!S=7(`1&4`1&5L(`!$97-C<FEP8VGS;B!C;VUP
M;&5T80!,=6YA(&QL96YA`$YO;6)R92!C;VUP;&5T;P!'86+S;@!'86QE<NUA
M(&1E(&QA('%U92!O8G1E;F5R(&QA(&EM86=E;@!'86QE<NUA.@!'86UB:6$`
M1V5N97)A<B!C;VYF:6=U<F%C:?-N(&1E("5S`$/S9&EG;R!G96YE<F%D;P!'
M96]R9VEA`$%L96UA;FEA`$=H86YA`$=I8G)A;'1A<@!.;VUB<F4@:6YD:6-A
M9&\`3W!C:6]N97,@9VQO8F%L97,`27(`1V]E9&5L`$UA<&%S(&1E($=O;V=L
M90!"^G-Q=65D82!E;B!';V]G;&4`17-C86QA(&1E(&=R:7-E<P!'<F5C:6$`
M1W)I96=O("A)4T\M.#@U.2TW*0!'<F]E;FQA;F1I80!'<F%N861A`$%D;6EN
M:7-T<F%C:?-N(&1E(&=R=7!O<P!,;W,@;F]M8G)E<R!D92!G<G5P;R!N;R!P
M=65D96X@9&5J87)S92!E;B!B;&%N8V\`1W)O=7!?;&1A<#H@3F\@<V4@<'5E
M9&4@8?%A9&ER(&5L(&=R=7!O("5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L
M('-E<G9I9&]R.B``1W)O=7!?;&1A<#H@26YC87!A>B!D92!E;&EM:6YA<B!E
M;"!G<G5P;R`E<P!'<F]U<%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A;&EZ87(@
M96P@9W)U<&\@)7,`1W)U<&]S`$=U861A;'5P90!'=6%M`$=U871E;6%L80!'
M=65R;F5S97D`4')I=FEL96=I;W,@9&4@:6YV:71A9&\`3"X@:6YV:71A9&]S
M`$=U:6YE80!'=6EN96$M0FES<V%U`$=U87EA;F$`2%1-3`!(5$U,('-E(&YI
M96=A(&-O8F%R9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM82!C96QD82!D
M92!L82!F:6QA+@!(5$U,07)E82!S92!N:65G82!C;V)A<F1E;65N=&4@82!E
M;&EM:6YA<B!L82#Z;'1I;6$@8V]L=6UN82!D92!L82!T86)L82X`2%1-3"!S
M92!N:65G82!C;V)A<F1E;65N=&4@82!E;&EM:6YA<B!L82#Z;'1I;6$@9FEL
M82!D92!L82!T86)L82X`3F\@<V4@96YC;VYT<O,@;&$@875T96YT:69I8V%C
M:?-N($A45%`N`$AA:73M`$%L9V]R:6UO($AA<V@`3F5B;&EN80!#86)E8V5R
M80!#86)E8V5R87,`27-L82!(96%R9"!E($ES;&%S($UC1&]N86QD`%1O<FUE
M;G1A('1R;W!I8V%L(&EN=&5N<V$`2&5B<F5O("A)4T\M.#@U.2TX+4DI`$%L
M='5R80!!>75D80!!>75D82!D96P@961I=&]R`$%Y=61A;G1E`$AE;6ES9F5R
M:6\`07%U[2!T:65N92!E;"!C;VUI96YZ;R!D96P@87)C:&EV;SH`06QT80!?
M26YI8VEO`%-A;G1A(%-E9&4@*$-I=61A9"U%<W1A9&\@9&5L(%9A=&EC86YO
M*0!);FEC:6\`1&]M:6-I;&EO`$1I<F5C=&]R:6\@<&5R<V]N86P`5&5LZ69O
M;F\@<&%R=&EC=6QA<@!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O
M2V]L86(Z(%-E(&AA;B!E;F-O;G1R861O(&1A=&]S(%A-3"`E<R!N;R!VX6QI
M9&]S(&5N(&5L(&UE;G-A:F4@)7,`2&]R9&4O2V]L86(Z($YI;F?Z;B!M96YS
M86IE(&-O<G)E<W!O;F1E(&%L(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@3F\@
M<V4@96YC;VYT<O,@=6X@;V)J971O(&1E('1I<&\@)7,@96X@96P@;65N<V%J
M92`E<P!(;W)D92]+;VQA8CH@4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N
M=&4@)7,@(B5S(@!(;W)D92]+;VQA8CH@16P@;6]T;W(@9&4@:6YT96=R86-I
M\VX@<')E8VES82!D92!L82!E>'1E;G-I\VX@4$A0("=D;VUX;6PG`$AO<F1E
M+TMO;&%B.B!);F-A<&%Z(&1E(&-R96%R(&YU979O(.%R8F]L(%A-3"!D96P@
M;V)J971O("5S`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E(&5L:6UI;F%R("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!);F-A<&%Z(&1E(&]B=&5N97(@240@
M34E-12!D92!L82!P87)T92!D92!T:7!O("5S`$AO<F1E+TMO;&%B.B!);F-A
M<&%Z(&1E('-I;F-R;VYI>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!)
M;F-A<&%Z(&1E('-I;F-R;VYI>F%R(&5L96UE;G1O<R!C;VUP87)T:61O<SH@
M)7,`2&]R9&4O2V]L86(Z($5L96UE;G1O(&-O;7!A<G1I9&\@9&5S8V]N;V-I
M9&\@(B5S(@!,[6YE82!H;W)I>F]N=&%L`$UA<F=E;B!H;W)I>F]N=&%L`$AO
M<FEZ;VYT86PZ`+]#\VUO(&QL96?S(&AA<W1A(&%Q=>T_("BA0V]M=6[M<75E
M;&\L('!O<B!F879O<B$I`+]#=6%N=&%S(&-O;'5M;F%S(&1E<V5A(&-O;6)I
M;F%R/P"_0W7A;G1O<R!C86UP;W,@*&-O;'5M;F%S*2!H87D_`+]#=6%N=&%S
M(&9I;&%S(&1E<V5A(&-O;6)I;F%R/P!(=6UE9&%D`$AU;65D860Z(`!(=6UO
M<FES=&%S`$AU;F=R[6$`2&$@9F%L;&%D;R!L82!C<F5A8VGS;B!D96P@8G5Z
M\VX@24U!4#H@)7,`2&$@9F%L;&%D;R!L82!E;&EM:6YA8VGS;B!D96P@8G5Z
M\VX@24U!4#H@)7,`2&$@9F%L;&%D;R!L82!C<F5A8VGS;B!D92!E<W!A8VEO
M(&%S:6=N861O(&1E;"!B=7KS;B!)34%0.B`E<P!$:7)E8V-I\VX@25``3&$@
M9&ER96-C:?-N($E0(&YO(&5S=.$@9&ES<&]N:6)L92X`3&$@9&ER96-C:?-N
M($E0(&YO(&5S=.$@96YT<F4@8FQO<75E<R!#2412('!E<FUI=&ED;W,N`%9I
M;VQA8VGS;B!L;V-K9&]W;B!)4"X`25]N<V5R=&%R(&9I;&$@96YC:6UA`$ES
M;&%N9&EA`%/S;&\@:6-O;F]S`$EC;VYO<R!D92`E<P!)8V]N;W,@8V]N('1E
M>'1O`$YO;6)R92!D92!L82!I9&5N=&ED860Z`%-I(&YO('-E(&UU97-T<F$@
M8V]R<F5C=&%M96YT92P@)7,@<&%R82!A8G)I<FQO(&5N('5N82!V96YT86YA
M(&YU979A+@!3:2!N;R!V92!N:6YG^FX@:6-O;F\@;65D:6%N=&4@26YT97)N
M970@17AP;&]R97(L('!U961E('1E;F5R('%U92!A8W1I=F%R(&5S=&$@8V%S
M:6QL82!P87)A(&1E<V%C=&EV87(@;&$@=')A;G-P87)E;F-I82!03D<N`%-I
M('9E(&5S=&4@;65N<V%J92!S:6X@;FEN9W5N82!I;6%G96XL(&QA(&EM86=E
M;B!Q=64@<75I97)E(&-A<F=A<B!N;R!S92!P=65D92!M;W-T<F%R(&5N('-U
M(&YA=F5G861O<BX`5FES=&$@<')E=FEA.@!54DP@9&4@;&$@:6UA9V5N`%52
M3"!D92!L82!I;6%G96XZ`$EM86=E;B!D92!L82!G86QE<NUA`$EM86=E;B!D
M92!L82!G86QE<NUA.@!392!H82!C87)G861O(&QA(&EM86=E;@!);>%G96YE
M<P!);7!O<G1A<BP@<&%S;R`E9`!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O
M<R!I;7!O<G1A9&]S.@!);E]S97)T87(@9FEL82!D96)A:F\`4V4@:&$@:6YD
M:6-A9&\@=6X@8_-D:6=O(&1E(&%C8VGS;B!I;F-O<G)E8W1O+@!.;VUB<F4@
M9&4@=7-U87)I;R!Y+V\@8V]N=')A<V7Q82!I;F-O<G)E8W1O<RX`3F]M8G)E
M(&1E('5S=6%R:6\@;R!D:7)E8V-I\VX@86QT97)N871I=F$@:6YC;W)R96-T
M;W,N(%9U96QV82!A(&EN=&5N=&%R;&\@;R!P\VYG87-E(&5N(&-O;G1A8W1O
M(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('!A<F$@;>%S(&EN
M9F]R;6%C:?-N+@!!=6UE;G1A<B!S86YG<F%D;P!);F1I80!5<W5A<FEO<R!I
M;F1I=FED=6%L97,`26YD;VYE<VEA`$EN9F]R;6%C:?-N`$EN9F]R;6%C:?-N
M`$QA(&EN9F]R;6%C:?-N('EA(&YO(&5S=.$@9&ES<&]N:6)L92X`26YS97)T
M87(@8U]O;'5M;F$@9&5T<N%S`$EN<V5R=&%R(&EM86=E;@!);G-E<G1A<B!T
M86)L80!);G-E<G1A<B!V[6YC=6QO(%=E8@!);G-E<G1A<B!?8V]L=6UN82!D
M96QA;G1E`$EN<V5R=&$@=6YA(&YU979A(&-O;'5M;F$@9&5T<N%S(&1E(&QA
M(&%C='5A;`!);G-E<G1A('5N82!N=65V82!C;VQU;6YA(&1E;&%N=&4@9&4@
M;&$@86-T=6%L`$EN<V5R=&$@=6YA(&9I;&$@;G5E=F$@9&5B86IO(&1E(&QA
M(&%C='5A;`!);G-E<G1A('5N82!F:6QA(&YU979A(&5N8VEM82!D92!L82!A
M8W1U86P`26YS97)T82!U;B!PX7)R869O('1R87,@96P@;F]D;R!A8W1U86P`
M26YS97)T82!U;B!PX7)R869O(&%N=&5S(&1E;"!N;V1O(&%C='5A;`!);G-E
M<G1A<B!P;&%N=&EL;&$@86QT97)N871I=F$`26YS97)T87(@=6YA(&1I<F5C
M8VGS;B!D92!C;W)R96\@96X@;&$@<75E(')E8VEB:7(@;&$@8V]N=')A<V7Q
M83H`26YS97)T87(@8V5L9&$@9&5T<N%S`$EN<V5R=&%R(&-E;&1A(&%N=&5S
M`$EN<V5R=&%R(&-O;'5M;F$@9&5T<N%S`$EN<V5R=&%R(&-O;'5M;F$@86YT
M97,`26YS97)T87(@;65N<V%J97,`26YS97)T87(@<.%R<F%F;R!D971RX7,`
M26YS97)T87(@<.%R<F%F;R!A;G1E<P!);G-E<G1A<B!F:6QA(&1E8F%J;P!)
M;G-E<G1A<B!F:6QA(&5N8VEM80!);G-E<G1A<B!L82!R97-P=65S=&$@;F5C
M97-A<FEA(&$@;&$@<')E9W5N=&$@9&4@<V5G=7)I9&%D.@!);G-E<G1A<B]-
M;V1I9FEC87(@:6UA9V5N`$EN<V5R=&%R+TUO9&EF:6-A<B!V[6YC=6QO`%-A
M;&1O(&EN<W5F:6-I96YT92!P87)A(&5N=FEA<B!A(&QA(&QI<W1A(&1E(&1I
M<W1R:6)U8VGS;BX`4V%L9&\@:6YS=69I8VEE;G1E+@!%;G1E<F\`3&ES=&$@
M9&4@96YT97)O<P!51$@@*$-A8F5C97)A(&1E($1A=&]S(&1E(%5S=6%R:6\I
M(&YO(';A;&ED82X`1&%T;W,@6DE0(&YO(';A;&ED;W,`07!L:6-A8VGS;B!N
M;R!VX6QI9&$N`$E$(&1E(&QO=&4@;F\@=N%L:61O+@!392!H86X@96YV:6%D
M;R!D871O<R!N;R!VX6QI9&]S+@!$:7)E8V-I\VX@9&4@8V]R<F5O(&YO(';A
M;&ED82X`1F]R;6%T;R!D92!A<F-H:79O(&YO(';A;&ED;P!#;&%V92!D92!L
M:6-E;F-I82!N;R!VX6QI9&$N`%-E(&AA(&EN9&EC861O('5N82!U8FEC86-I
M\VX@;F\@=N%L:61A+@!M<V=?='EP92!N;R!VX6QI9&\N`&%P:5]I9"!N;R!V
MX6QI9&\@;R!D97-A<&%R96-I9&\N`%!A<N%M971R;W,@;F\@=N%L:61O<R!O
M(&1E<V%P87)E8VED;W,N`%!R:79I;&5G:6\@9&5L('!A9')E(&YO(';A;&ED
M;W,N`$E$(&1E(&%S;V-I861O(&YO(';A;&ED;RX`0_-D:6=O(&1E('!R;V1U
M8W1O(&YO(';A;&ED;RX`4')O=&]C;VQO(&YO(';A;&ED;RX`1&5S=&EN871A
M<FEO(&YO(';A;&ED;SH@(B5S(@!/8FIE=&\@8V]M<&%R=&ED;R!N;R!VX6QI
M9&\N`$1I<F5C8VGS;B!D96P@<F5M:71E;G1E(&YO(';A;&ED80!$871O<R!U
M;FEC;V1E(&YO(';A;&ED;W,N`$EN=F5N=&%R:6\`26YV97)T:7(@<V5L96-C
M:?-N`$ERX6XL(%)E</IB;&EC82!)<VSA;6EC82!D90!)<F%Q`$ER;&%N9&$`
M27-L82!D92!-86X`0F]R<F%S8V%S(&%I<VQA9&%S`$ES<F%E;`!%;6ES;W(`
M0W5R<VEV80!)=&%L:6$`2F%M86EC80!%;F5R;P!*87#S;@!*87!O;NES("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F3A;@!*=6QI;P!*=6YI;P!*=7-T:69I
M8V%R`$%L:6YE87(@86P@8V5N=')O`$IU<W1I9FEC87(`06QI;F5A<B!A(&QA
M(&EZ<75I97)D80!!;&EN96%R(&$@;&$@9&5R96-H80!+87IA:VAS=&%N`+]#
M;VYS97)V87(@96P@;W)I9VEN86P_`$ME;GEA`$5L('-E<G9I9&]R($ME<F)E
M<F]S(&AA(')E8VAA>F%D;R!L82!A=71E;G1I9FEC86-I\VXN`$YO=F%T;W,@
M9&5L($ME<FYE;`!#<F5A8VGS;B!D92!C;&%V90!(=65L;&$@9&EG:71A;"!D
M92!L82!C;&%V90!486UA\6\@9&4@8VQA=F4`5&EP;R!D92!C;&%V90!5<V\@
M9&4@;&$@8VQA=F4Z`$QA(&-L879E('EA(&5X:7-T92!E;B!E;"!S97)V:61O
M<B!D92!C;&%V97,@</IB;&EC;RX`3FGQ;W,`2VER:6)A=&D`0V]R96$L(%)E
M</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A(&1E`$-O<F5A+"!297#Z8FQI
M8V$@9&4`0V]R96%N;R`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!?1&ES
M=')I8G5C:?-N`$ED:6]M80!,86\L(%)E</IB;&EC82!$96UO8W+A=&EC82!0
M;W!U;&%R`$-U87)T;R!M96YG=6%N=&4`VFQT:6UO(&-A;6)I;R!D92!C;VYT
M<F%S9?%A`$-U87)T;R!M96YG=6%N=&4`VFQT:6UA(&%C='5A;&EZ86-I\VXZ
M`-IL=&EM82!S97-I\VXZ("5S`-IL=&EM82!S97-I\VXZ("5S(&1E<V1E("5S
M`-IL=&EM82!S97-I\VXZ($YU;F-A`$QA='9I80!,97EE<P!$:7-T<FEB=6-I
M\VX`1&5J87(@96X@8FQA;F-O('!A<F$@96QI;6EN87(@96P@8F]R9&4`3&5B
M86YO;@!)>G%U:65R9&$`0V%B96-E<F$@:7IQ=6EE<F1A`%9A;&]R97,@9&4@
M;&$@:7IQ=6EE<F1A`$QE<V]T:&\`3FEV96P`3&EB97)I80!,:6)Y86X@07)A
M8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG97)A(&QL;W9I>FYA`$QL
M=79I82!L:6=E<F$`3&QU=FEA(&QI9V5R82!M871U=&EN80!,;'5V:6$@;&EG
M97)A('9E<W!E<G1I;F$`06=U86-E<F\@;&EG97)O`$QL=79I87,@>2!T<G5E
M;F]S`$YE=F%D82!S=6%V90!,:6=E<F\@86=U86-E<F\@9&4@;FEE=F4`0VAA
M<V-A<G)I;&QO`%;M;F-U;&\`16P@=NUN8W5L;R!A<'5N=&$@83H`5FEN8W5L
M87(@9&ER96-C:?-N(&1E(&-O<G)E;R!A(&QA('#A9VEN82!D92!C;VUP;W-I
M8VGS;B!A;"!M;W-T<F%R`%;M;F-U;&]S`$-O;VMI92!,:6YU>`!,:7-T87(@
M+2!E;"!U<W5A<FEO('!U961E(&5X86UI;F%R(&QA(&-A<G!E=&$`3&ES=&%R
M(&)A<V5S(&1E(&1A=&]S`$QI<W1A<B!T96UA<R!D92!A>75D80!,:7-T87(@
M=&%B;&%S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W
M;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E
M`$AA(&9A;&QA9&\@96P@;&ES=&%D;R!D92!L87,@<V5S:6]N97,Z("5S`$AA
M(&9A;&QA9&\@96P@;&ES=&%D;R!D92!U<W5A<FEO<SH@)7,`16P@;&ES=&%D
M;R!D92!U<W5A<FEO<R!E<W3A(&1E<VAA8FEL:71A9&\N`$QI=&5R871U<F$`
M3&ET=6%N:6$`3&5Y96YD;RXN+@!(;W)A(&QO8V%L.B``261I;VUA('D@:&]R
M80!58FEC86-I\VX`26YI8VEA<B!S97-I\VX`4F5G:7-T<F\@9&4@;&%S('-E
M<VEO;F5S(&1E('-I;F-R;VYI>F%C:?-N(&%N=&5R:6]R97,`4V%L:7(`26YI
M8VEA<B!S97-I\VX`5&%R96%S(&1E(&EN:6-I;R!D92!S97-I\VX`1F%L;/,@
M96P@:6YI8VEO(&1E('-E<VGS;B!P;W)Q=64@:6YT<F]D=6IO(&EN8V]R<F5C
M=&%M96YT92!S=2!N;VUB<F4@9&4@=7-U87)I;R!O(&-O;G1R87-E\6$N`$9A
M;&SS(&5L(&EN:6-I;R!D92!S97-I\VXN`%1E>'1O(&-O;7!L971O`$%M;W(`
M0F%J80!!;&9A8F5T;R!G<FEE9V\@96X@;6EN^G-C+@!!;&9A8F5T;R!L871I
M;F\@96X@;6EN^G-C+@!.^FUE<F]S(')O;6%N;W,@96X@;6EN^G-C+@!,=7AE
M;6)U<F=O`$U-`$U/5$0`16P@861J=6YT;R!-4RU43D5&(&YO(&-O;G1E;NUA
M(&1A=&]S+@!-4T<`36%C86\`36%C961O;FEA+"!!;G1I9W5A(%)E</IB;&EC
M82!9=6=O<VQA=F$@9&4`36%D86=A<V-A<@!-86=I80!#;W)R96\`061M+B!C
M;W)R96\`0W)E87(@7W;M;F-U;&\N+BX`36%L87=I`$UA;&%S:6$`36%L9&EV
M87,`36%L:0!-86QT80!'97-T:6]N82!L82!L:7-T82!D92!C871E9V]R[6%S
M(&-O;B!L82!Q=64@971I<75E=&%R(&5L96UE;G1O<R!Y(&QO<R!C;VQO<F5S
M(&%S;V-I861O<R!A(&1I8VAA<R!C871E9V]R[6%S+@!-87!A(&UA<#(T`$UA
M<&$@;6%P<75E<W0`0V]R<F5S<&]N9&5N8VEA<R!A;&UA8V5N861A<RX`36%R
M>F\`36%R9V5N`$UA<F-A<B!C;VX@;&%S(&)A;F1E<F%S(&1E($QE[61O+U-I
M;B!L965R`$UA<F-A<B!C;VX@;W1R87(@8F%N9&5R87,@*'`N92X@26UP;W)T
M86YT92]297-P;VYD:61O*0!)<VQA<R!-87)S:&%L;`!-87)T:6YI8V$`0V%M
M<&]S(&-O:6YC:61E;G1E<P!-875R:71A;FEA`$UA=7)I8VEO`%-A;&1O(&WA
M>&EM;R!P97)M:71I9&\N`%-E(&AA('-O8G)E<&%S861O(&5L(&[Z;65R;R!M
MX7AI;6\@9&4@<&%R=&5S(&1E(&UE;G-A:F4N`%1E;7`N(&WA>&EM82#Z;'1I
M;6%S(#(T(&AO<F%S.B``5&5M<"X@;>%X:6UA(/IL=&EM87,@-B!H;W)A<SH@
M`$[Z;65R;R!MX7AI;6\@9&4@8FQO<75E<R!D96P@<&]R=&%L`$QO;F=I='5D
M(&WA>&EM80!-87EO`$UA>6]T=&4`365D:6-I;F$`36EE;6)R;W,`1F]R;6%T
M;R!D96P@;65N^CH`0V]M8FEN87(@8V5L9&%S`$UE;G-A:F4`4V4@:&$@8V]M
M<')O8F%D;R!C;W)R96-T86UE;G1E(&5L(&UE;G-A:F4@<&5R;R!N;R!S92!P
M=65D92!V97)I9FEC87(@96P@8V5R=&EF:6-A9&\@9&5L(&9I<FUA;G1E+@!-
M96YS86IE(&-A9'5C861O+@!4:7!O(&1E(&UE;G-A:F4`5&EE;7!O(&1E($UE
M=&%R`$)L;W%U92!-971A<B!N;R!D:7-P;VYI8FQE+@!";&]Q=64@365T87(@
M;F\@9&ES<&]N:6)L92X@4V4@:&%N(')E9VES=')A9&\@;&]S(&1E=&%L;&5S
M('!A<F$@96P@861M:6YI<W1R861O<BX`3F\@97-TX2!C;VYE8W1A9&$@;&$@
M365T87)$0@!-Z71O9&\`16P@;>ET;V1O("(E<R(@;F\@97-TX2!D969I;FED
M;P!-Z71O9&\@;F\@9&5F:6YI9&\N($WI=&]D;R!L;&%M861O.B`E<P!-Z71R
M:6-O`$WI:FEC;P!-:6-R;VYE<VEA+"!%<W1A9&]S($9E9&5R861O<R!D90!%
M;B!M961I;P!4:7!O($UI;64`5&5M<"X@;>UN+B!L87,@^FQT:6UA<R`R-"!H
M;W)A<SH@`%1E;7`N(&WM;BX@;&%S(/IL=&EM87,@-B!H;W)A<SH@`%1O9&%V
M[6$@;F\@:&$@97AP:7)A9&\@;&$@86YT:6?\961A9"!M[6YI;6$@9&4@;&$@
M8V]N=')A<V7Q80!2969L96IA<@!-:7-C96SA;F5A`%!A<75E=&4@4$5!4B!(
M5%107U)E<75E<W0@9&5S87!A<F5C:61O+@!&86QT82!L82!C;VYF:6=U<F%C
M:?-N+B!4:65N92!Q=64@9V5N97)A<FQA(&%H;W)A('-I(&1E<V5A('5T:6QI
M>F%R(&5S=&$@87!L:6-A8VGS;BX`240@9&4@;65N<V%J92!D97-A<&%R96-I
M9&\N`%!A<75E=&4@4$5!4B!-86EL(&1E<V%P87)E8VED;RX`240@9&4@<V5S
M:?-N(&1E<V%P87)E8VED;RX`3'5N`$-O<G)E;R!M\W9I;`!-;V1E<F%D;P!3
M92!H82!M;V1I9FEC861O(&QA(&9E8VAA`$UO9&EF:6-A<B!54DP`3?-D=6QO
M`$UO;&1A=FEA+"!297#Z8FQI8V$@9&4`3?-N86-O`$UO;F=O;&EA`$UE<R!Y
M(&'Q;P!-96YS=6%L;65N=&4`36]N='-E<G)A=`!&87-E<R!D92!L82!L=6YA
M`%-E(&AA;B!E;F-O;G1R861O(&WA<R!C86UP;W,@96X@;&$@;.UN96$@)60@
M<75E(&QO<R`E9"!E<W!E<F%D;W,N`$UA<G)U96-O<P!&=6YD86UE;G1A;&UE
M;G1E(&1E<W!E:F%D;P!&=6YD86UE;G1A;&UE;G1E(&YU8F]S;P!&=6YD86UE
M;G1A;&UE;G1E('-O;&5A9&\`1&5S<&QA>F%R(&AA8VEA(&%B86IO`$1E<W!L
M87IA<B!A(&QA(&EZ<75I97)D80!$97-P;&%Z87(@82!L82!D97)E8VAA`$1E
M<W!L87IA<B!H86-I82!A<G)I8F$`1&5S<&QA>F%R(&AA8VEA(&%B86IO`$1E
M<W!L87IA<B!H86-I82!A<G)I8F$`36]Z86UB:7%U90!,:7-T87,@9&5S<&QE
M9V%B;&5S(&UU;'1I+6YI=F5L`$UA<&$@54L@;?IL=&EP;&4`4V5L96-C:?-N
M(&WZ;'1I<&QE`$ED96YT:61A9`!-:2!I9&5N=&ED860`36D@<&]R=&%L`$1I
M<W1R:6)U8VGS;B!D92!M:2!P;W)T86P`37EA;FUA<@!.3RP@3D\@97-T;WD@
M9&4@86-U97)D;P!.;VUB<F4`3F%M:6)I80!.875R=0!.97!A;`!(;VQA;F1A
M`$%N=&EL;&%S($AO;&%N9&5S87,`55),(&)A<V4@9&4@3F5T<V-A<&4`55),
M(&1E(&%N=6QA8VGS;B!D92!#02!D92!.971S8V%P90!54DP@9&4@<&]L[71I
M8V%S(&1E($-!(&1E($YE='-C87!E`%523"!D92!R96YO=F%C:?-N(&1E($YE
M='-C87!E`%523"!D92!A;G5L86-I\VX@9&4@3F5T<V-A<&4`3F]M8G)E(&1E
M('-E<G9I9&]R(%-33"!D92!.971S8V%P90!#;VUE;G1A<FEO(&1E;"!C97)T
M:69I8V%D;R!D92!.971S8V%P90!4:7!O(&1E(&-E<G1I9FEC861O(&1E($YE
M='-C87!E`%)E9`!.=6YC80!.=65V82!#86QE9&]N:6$`3G5E=F$@8V%T96=O
M<NUA`$5N=FEA<B!M96YS86IE(&$@)7,`3'5N82!N=65V80!.=65V;R!N;VUB
M<F4@9&4@=7-U87)I;R`H;W!C:6]N86PI`$YU979A(%IE;&%N9&$`0V]N=')A
M<V7Q82!N=65V80!,82!N=65V82!C;VYT<F%S9?%A(&5X<&ER87+A(&5L("5X
M+@!,87,@8V]N=')A<V7Q87,@;F\@8V]I;F-I9&5N+@!.=65V82!V96YT86YA
M("A?8FQA;FLI`$YO=&EC:6%S`$<N(&1E(&YO=&EC:6%S`%-I9W5I96YT90!0
M<O-X:6UA<R`T(&9A<V5S`$]P8VEO;F5S('-I9W5I96YT97,`4VEG=6EE;G1E
M/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.;V-H90!.:75E`$YO`$YO(&AA
M>2!D871O<R!D92!C;VYF:6=U<F%C:?-N('!A<F$@;6]S=')A<B!D:69E<F5N
M8VEA<RX`3F\@<V4@9&ES<&]N92!D92!E<W1R871E9VEA(&1E(&5L86)O<F%C
M:?-N(&1E(&EMX6=E;F5S($E33RX`3F\@:&%Y('!L86YT:6QL82!D92!L;W1E
M<P!.;R!H87D@8FQO<75E<R!E;B!L82!P;W-I8VGS;B!I;F1I8V%D80!.;R!S
M92!H82!I;G1R;V1U8VED;R!U;B!N;VUB<F4@9&4@86=E;F1A('!A<F$@;&$@
M875T96YT:69I8V%C:?-N($U#04PN`%-I;B!C86UB:6]S+@!.;R!S92!P=65D
M96X@8?%A9&ER(&1E<V-E;F1I96YT97,@82!E<W1E('!R:79I;&5G:6\N`$YO
M('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C
M:?-N('!A<F$@)7,N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS
M;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!&5%`N`$YO('-E(&AA
M(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A
M<F$@5D93('!O<B!344PN`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA
M8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!A<F-H:79O(%-1
M3"X`3F\@<75E9&$@<V%L9&\N`$YO('-E(&AA(&EN=')O9'5C:61O(&5L(&1E
M<W1I;F\N`$YO('-E(&AA(&-A<F=A9&\@;FEN9_IN(&%R8VAI=F\`3F\@<V4@
M:&%N(&5N8V]N=')A9&\@:6-O;F]S+@!.;R!S92!H82!D969I;FED;R!L82!U
M8FEC86-I\VXN`$YO('-E(&AA(&1E9FEN:61O(&QA('5B:6-A8VGS;BX`3F\@
M<V4@:&$@:6YT<F]D=6-I9&\@=6X@;65N<V%J92X`3F\@<V4@:&$@97-P96-I
M9FEC861O('5N(&YO;6)R92X`3F\@<V4@:&$@97-P96-I9FEC861O('5N(&[Z
M;65R;RX`3F\@;V9E;G-I=F%S`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C
M;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N($A45%`N`$YO('-E
M(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT
M:69I8V%C:?-N($E-05`N`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT
M<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N($ME<F)E<F]S+@!.;R!S
M92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N
M=&EF:6-A8VGS;B!D92!I;FEC:6\N`$YO('-E(&AA(&EN=')O9'5C:61O('5N
M82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N(%!!4U-71"X`
M3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A
M=71E;G1I9FEC86-I\VX@4TU"+@!.;R!S92!H82!I;F1I8V%D;R!V[6$@9&4@
M86-C97-O(&$@;&]S(&)I;F%R:6]S($]P96Y34TPN(%!A<F$@=')A8F%J87(@
M8V]N(&1A=&]S(%!+0U,@,3(@:&%C96X@9F%L=&$@;&]S(&)I;F%R:6]S($]P
M96Y34TPN`%-I;B!A;'1A<R!P96YD:65N=&5S+@!#87)E8V4@9&4@<75O=&$N
M`%-I;B!R87EA<P!.;R!S92!H82!E<W!E8VEF:6-A9&\@=6X@<V5P87)A9&]R
M+@!.:6YG=6YO`$YO(&5X:7-T92!E;"!A<F-H:79O`$YO('-E(&1I<W!O;F4@
M9&4@=6X@9&ER96-T;W)I;R!D92!A;&UA8V5N86UI96YT;R!T96UP;W)A;"X`
M3F\@<V4@:&$@96YV:6%D;R!E;"!N;VUB<F4@9&4@=7-U87)I;R!Y+V\@;&$@
M8V]N=')A<V7Q82X`3F\@<V4@:&%N(&1E=G5E;'1O(&1A=&]S(%A-3"!VX6QI
M9&]S`%-I;B!V86QO<F5S`$YO('-E(&5N8V]N='+S(&QA('9E<G-I\VX@96X@
M;&$@8V]N9FEG=7)A8VGS;B!O<FEG:6YA;"X@4F5G96YE<F%R(&QA(&-O;F9I
M9W5R86-I\VXN`$YO('-E(&5N8V]N='+S(&QA('9E<G-I\VX@96X@;&$@8V]N
M9FEG=7)A8VGS;BX@4F5G96YE<F%R(&QA(&-O;F9I9W5R86-I\VXN`$YI;F=U
M;F$`3FEN9W5N;R`H=7-O(&EM<&SM8VET;RD`3O-R9&EC;R`H25-/+3@X-3DM
M,3`I`$ES;&$@9&4@3F]R9F]L:P!(96UI<V9E<FEO(&YO<G1E`$ES;&%S($UA
M<FEA;F%S(&1E;"!.;W)T90!.;W)U96=A`$YO(&1E<W!UZ7,`3F\@86YT97,`
M3F\@97,@=6X@9&ER96-T;W)I;P!3:6X@9&5S87)R;VQL87(N`%-I;B!E<W1A
M8FQE8V5R`$YO(&5S=.$@<V]P;W)T861O+@!.;W1A<P!.;R!H87D@;F%D82!V
M:7-U86QI>F%B;&4L(')E=')O8V5D82X`3F]V:65M8G)E`$[Z;65R;P!.^FUE
M<F\@9&4@8V%R86-T97)E<P!.^FUE<F\@9&4@8V]L=6UN87,`3OIM97)O(&1E
M(&9I;&%S`$YO('-E(&AA;B!E<W!E8VEF:6-A9&\@;OIM97)O<R!A(&%C='5A
M;&EZ87(@96X@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+@!!8V5P=&%R`$]B
M:F5T;P!#<F5A9&]R(&1E(&]B:F5T;W,`3V-T86P`3V-T=6)R90!&:6QT<F%R
M(&]F96YS87,`3V9I8VEN80!,82!C;VYT<F%S9?%A(&%N=&EG=6$@>2!L82!N
M=65V82!D96)E;B!S97(@9&ES=&EN=&%S+@!#;VYT<F%S9?%A(&%N=&EG=6$`
M3&$@8V]N=')A<V7Q82!A;G1I9W5A(&YO(&5S(&-O<G)E8W1A+@!/;>%N`%/S
M;&\@;&]S('-E<G9I9&]R97,@24U!4"!S;W!O<G1A;B!L87,@8V%R<&5T87,@
M8V]M<&%R=&ED87,N`%/S;&\@;V9E;G-I=F%S`%/S;&\@<V4@<&5R;6ET92!U
M;F$@9&ER96-C:?-N(&1E(&-O<G)E;RX`4_-L;R!E;"!P<F]P:65T87)I;R!O
M('5N(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<'5E9&4@8V%M8FEA<B!L
M82!P<F]P:65D860@;R!L;W,@<')I=FEL96=I;W,@9&4@<')O<&EE=&%R:6\@
M9&4@=6X@<F5C=7)S;R!C;VUP87)T:61O`$%B<FER(&5N('5N82!N=65V82!V
M96YT86YA`$5R<F]R($]P96Y34TPZ($YO('-E('!U961E;B!E>'1R865R(&1A
M=&]S(&1E(&QA('!A<G1E(%,O34E-12!F:7)M861A+@!!8G)I<B!E<W1E(';M
M;F-U;&\@96X@=6YA('9E;G1A;F$@;G5E=F$`4VES=&5M82!O<&5R871I=F\`
M3W!C:6]N97,`3W!C:6]N97,@9&4@)7,`3&ES=&$@;W)D96YA9&$`3W)G86YI
M>F%C:?-N`%5N:61A9"!O<F=A;FEZ871I=F$`3W)G86YI>F%C:?-N`%!L86YT
M:6QL82!D92!A<&QI8V%C:?-N(&]R:6=I;F%L`%!L86YT:6QL87,@;W)I9VEN
M86QE<R!E;B`E<SH`3W1R;P!/=')A(&EN9F]R;6%C:?-N`%!R:79I;&5G:6]S
M(&1E;"!P<F]P:65T87)I;P!,82!A=71E;G1I9FEC86-I\VX@4$%-(&YO(&5S
M=.$@9&ES<&]N:6)L92X`4$5!4CHZ36]T;W(@9&4@8V]R<F5O`$9I<FUA(&1I
M9VET86P@4$=0`$1A=&]S(&-I9G)A9&]S(&-O;B!01U``0VQA=F4@4$=0('#Z
M8FQI8V$`1&%T;W,@9FER;6%D;W,O8VEF<F%D;W,@8V]N(%!'4`!#\V1I9V\@
M4$A0`$EN=.ER<'(N(%!(4`!,;&]V:7IN82!V97-P97)T:6YA`$QL=79I82!V
M97-P97)T:6YA`$-H87!A<G)O;F5S('9E<W!E<G1I;F]S`$YI979E('9E<W!E
M<G1I;F$`06=U86-E<F\@9&4@;FEE=F4@=F5S<&5R=&EN;P!3;VP@=F5S<&5R
M=&EN;P!";W)R87-C87,@=F5S<&5R=&EN87,`3F\@<V4@96YC=65N=')A(&QA
M(&5X=&5N<VGS;B!03U-)6`!);G3I<G!R+B!07TA0`$UA<F=E;@!086MI<W3A
M;@!086QA=0!086QE<W1I;F]S+"!497)R:71O<FEO<R!/8W5P861O<P!086YA
M;>$`4&%P^F$@3G5E=F$@1W5I;F5A`%!A<F%G=6%Y`%!A<F-I86QM96YT92!N
M=6)O<V\`0V]N=')A<V7Q80!,82!C;VYT<F%S9?%A('-E(&-A;6)I861O(&-O
M<G)E8W1A;65N=&4N`$-O;G1R87-E\6$@:6YC;W)R96-T80!(87D@<75E(&EN
M=')O9'5C:7(@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I
M\VX@4D%$2553+@!#;VYT<F%S9?%A(&-O;B!C;VYF:7)M86-I\VX`0V]N=')A
M<V7Q83H`0V]N=')A<V7Q83H@`$QA<R!C;VYT<F%S9?%A<R!T:65N96X@<75E
M(&-O:6YC:61I<BX`4&5G87(`4&5G87(@9&5L('!O<G1A<&%P96QE<P!6[6$`
M06QT87,@<&5N9&EE;G1E<SH`1V5N=&4`4&]R8V5N=&%J90!296%L:7IA<B!O
M<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O`+]296%L:7IA<B!O<&5R86-I
M;VYE<R!D92!M86YT96YI;6EE;G1O(&%L(&EN:6-I87(@<V5S:?-N/P!0<FEV
M:6QE9VEO`$YO('-E(&AA(&5L:6UI;F%D;R!E;"!P<FEV:6QE9VEO("(E<R(N
M`%!R:79I;&5G:6\@9&5N96=A9&\`4')I=FEL96=I;W,`061M:6YI<W1R86-I
M\VX@9&4@<')I=FEL96=I;W,`26YF;W)M86-I\VX@<&5R<V]N86P`4&5R^@!-
M87-C;W1A<P!&:6QI<&EN87,`5&5LZ69O;F\`1F]T;V=R86;M87,`4&ET8V%I
M<FX`4.UX96QE<P!4\W!I8V]S`%!U;'-E(&5N('5N82!C96QD80!#;VYF:7)M
M92!Q=64@9&5S96$@96QI;6EN87(@97-T92!E;&5M96YT;SH`0V]N9FER;64@
M<75E(&1E<V5A(&5L:6UI;F%R(&5L(';M;F-U;&\@82!E<W1E(&5L96UE;G1O
M+@!);G1R;V1U>F-A('5N(&UE<R!Y('5N(&'Q;RX`26YT<F]D=7IC82!E;"!N
M;VUB<F4@9&4@;&$@;G5E=F$@8V%T96=O<NUA.@!);G1R;V1U>F-A('5N82!D
M:7)E8V-I\VX@25`@=N%L:61A+@!);G1R;V1U>F-A('5N82!F96-H82!VX6QI
M9&$L(&-O;7!R=65B92!E;"!N^FUE<F\@9&4@9.UA<R!D96P@;65S+@!);G1R
M;V1U>F-A('5N82!H;W)A(';A;&ED82X`4')O<&]R8VEO;F4@=6X@<F5S=6UE
M;B!D96P@<')O8FQE;6$N`$EN=')O9'5Z8V$@<W4@;F]M8G)E(&1E('5S=6%R
M:6\@>2!C;VYT<F%S9?%A+@!,96$@96P@=&5X=&\@<VEG=6EE;G1E+B!$14)%
M(&%C97!T87(@;&]S('3I<FUI;F]S('-I('%U:65R92!U<V%R(&5L('-I<W1E
M;6$N`$EN=')O9'5Z8V$@96P@;G5E=F\@;F]M8G)E(&1E(&-A=&5G;W+M83H`
M4&]L;VYI80!0;VSM=&EC80!%;F-U97-T87,`4&]R='5G86P`4&]S:6-I\VX@
M9&4@;&$@:6UA9V5N`%!O<VEC:?-N(&1E(&QA('1A8FQA`$5N=FEA<B!A(&5S
M=&$@8V%R<&5T82`H;F\@;V)L:6=A9&\@<&]R($E-05`I`%!R96-I<&ET86-I
M;VYE<R!D92!L82AS*2#Z;'1I;6$H<RD@)7,@:&]R82AS*3H@`%!R;V)A8FEL
M:61A9#QB<B`O/F1E('!R96-I<&ET86-I\VX`4')E9G-?;&1A<#H@;F\@<V4@
M96YC;VYT<O,@;&$@97AT96YS:?-N($Q$05`@<F5Q=65R:61A+@!0<F5F<U]S
M97-S:6]N.B!N;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@9&4@<V5S:?-N
M(')E<75E<FED82X`4')E<VGS;@!0<F5S:?-N(&%L(&YI=F5L(&1E;"!M87(Z
M(`!0<F5S:?-N.B``5FES=&$@<')E=FEA`%9I<W1A('!R979I82!D92!L82!I
M;6%G96X@96X@=6YA(&YU979A('9E;G1A;F$`3W!C:6]N97,@86YT97)I;W)E
M<P!);7!R:6UI<B!D;V-U;65N=&\`0VQA=F4@<')I=F%D80"_4')O8FQE;6%S
M/P!$97-C<FEP8VGS;B!D96P@<')O8FQE;6$`4')O>65C=&]S`%1E>'1O(&1E
M;"!I;F1U8W1O<@!#;&%V92!01U`@</IB;&EC80!!;&=O<FET;6\@9&4@8VQA
M=F4@</IB;&EC80!);F9O<FUA8VGS;B!D92!C;&%V92!P^F)L:6-A`$YO('-E
M(&=E;F5R87)O;B!C;W)R96-T86UE;G1E(&QA<R!C;&%V97,@4/IB;&EC82]0
M<FEV861A+@!0=65R=&\@4FEC;P!,:6UP:6%R(&UE;G-A:F5S`%%A=&%R`$-O
M;G-U;'1A`%%U;W1A`$-L879E(%)302!P^F)L:6-A("@E9"!B:70I`$)O=/-N
M(&1E(&]P8VGS;@!,;'5V:6$`3&QU=FEA(&UA='5T:6YA`$QL=79I82!V97-P
M97)T:6YA`$%G=6%C97)O`$QL=79I82!Y($YI979E`$QL=79I82!A($YI979E
M`%)U961A(&1E(&QA(&9O<G1U;F$`4F%Z\VX`)FYB<W`[3&5E<B9N8G-P.P!,
M965R(&UE;G-A:F5S`+]%;&EM:6YA<B!R96%L;65N=&4@)7,_($5S=&$@;W!E
M<F%C:?-N(&YO('-E('!U961E(&1E<VAA8V5R+@"_16QI;6EN87(@<F5A;&UE
M;G1E(&QO<R!D871O<R!D96P@=7-U87)I;R`E<S\@17-T82!O<&5R86-I\VX@
M;F\@<V4@<'5E9&4@9&5S:&%C97(N`%9U96QV92!A(')E86QI>F%R(&QA(/IL
M=&EM82!A8V-I\VX`06-T=6%L:7IA<@!!8W1U86QI>F%R(&5L96UE;G1O<R!D
M92!M96[Z(&1I;N%M:6-O<SH`06-T=6%L:7IA<B!V:7-T82!D96P@<&]R=&%L
M`%)E9V5X`$YA=F5G861O<B!D92!R96QA8VEO;F5S`%)E9G)E<V-A<@!/8G-E
M<G9A8VEO;F5S`%-E<G9I9&]R97,@<F5M;W1O<P!54DP@<F5M;W1A("AH='1P
M.B\O=W=W+F5J96UP;&\N8V]M+VAO<F1E*3H`475I=&%R`%%U:71A<B!B;&]Q
M=64`475I=&%R(&-O;'5M;F$`16QI;6EN87(@9F]R;6%T;P!1=6ET87(@<&%R
M`$5L:6UI;F%R(&=U:?-N(&=U87)D861O(&1E;"!D:7)E8W1O<FEO('1E;7!O
M<F%L(&1E;"!S97)V:61O<BX`16QI;6EN87(@`$5L:6UI;F%R(&5S=&4@;F]D
M;R!D96P@9&]C=6UE;G1O`$5L:6UI;F%R('5S=6%R:6\`16QI;6EN87(@=7-U
M87)I;SH@)7,`3F\@<V4@<'5E9&4@<F5S<&]N9&5R(&$@;&$@<V]L:6-I='5D
M+B!#\V1I9V\@9&4@97)R;W(@9&5V=65L=&\Z(`!.;R!S92!E;F-O;G1R\R!E
M;"!S97)V:6-I;R!S;VQI8VET861O+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@
M96P@(B5S(B!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A8VGS;B!D92`E<RX`
M3F\@<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA
M(&-O;F9I9W5R86-I\VX@9&4@5D93+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@
M96P@(B5S(B!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A8VGS;BX`0V%M<&\@
M;F5C97-A<FEO`$QI;7!I87(`3&EM<&EA<B!C;VYT<F%S9?%A`$QI;7!I87(@
M8V]N=')A<V7Q80!297-T875R87(@^FQT:6UA(&-O;G-U;'1A`%)E<W5L=&%D
M;W,`4F5G<F5S87(@82!O<&-I;VYE<P!2965S8W)I8FER(&-O;G1R87-E\6$@
M;G5E=F$`4F5U;FGS;@!297-T875R87(@8V]N9FEG=7)A8VGS;@!/<&-I;VYE
M<R!D92!E9&EC:?-N(&1E('1E>'1O(&5N<FEQ=65C:61O`$-R:6)A<P!$97)E
M8VAA`$-A8F5C97)A(&1E<F5C:&$`5F%L;W)E<R!D92!L82!D97)E8VAA`%!R
M;W!I961A9&5S(&1E(%]F:6QA+BXN`$9U;F-I\VX`4G5M86[M80!':7)A<B`Q
M.#``1VER87(@82!L82!I>G%U:65R9&$`1VER87(@82!L82!D97)E8VAA`%!R
M;W!I961A9&5S(&1E(&9I;&$`4')O<&EE9&%D97,@9&4@9FEL80!&:6QA<SH`
M4F%Y87,`07!A<F5C97+A;B!R87EA<R!E;G1R92!T;V1A<R!L87,@9FEL87,@
M>2!C;VQU;6YA<P!!<&%R96-E<N%N(')A>6%S('/S;&\@96YT<F4@;&%S(&-O
M;'5M;F%S`$%P87)E8V5RX6X@<F%Y87,@<_-L;R!E;G1R92!L87,@9FEL87,`
M16IE8W5T87(`1F5D97)A8VGS;B!2=7-A`%)U86YD80!&:7)M82!C<FEP=&]G
M<N%F:6-A(%,O34E-10!-96YS86IE(&-I9G)A9&\@96X@4R]-24U%`$YO(&5S
M=.$@9&ES<&]N:6)L92!L82!A=71E;G1I9FEC86-I\VX@4T%33"X`365N<RX@
M4TU3`$EN=.ER<'(N(%-13`!396YT96YC:6$@4U%,('!A<F$@8V]N<W5L=&%S
M(&1E('9A;&]R97,`4U-(`,E8251/`$EN=.ER<'(N(%-?44P`4V%B`%-A;G1A
M($AE;&5N80!386EN="!+:71T<R!Y($YE=FES`%-A;G1A($QU8^UA`%-A:6YT
M(%!I97)R92!Y($UI<75E;&]N`%-A;B!6:6-E;G1E('D@1W)A;F%D:6YA<P!-
M:7-M;R!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%N=&\@5&]M
MX7,@>2!0<NUN8VEP90!0<F]V965D;W(@9&4@<V%TZ6QI=&4`07)A8FEA(%-A
M=61I=&$`1W5A<F1A<@!'=6%R9&%R("(E<R(`1W5A<F1A<B`E<P!'=6%R9&%R
M(&]P8VEO;F5S`$=U87)D87(@;&$@8V]N9FEG=7)A8VGS;B!G96YE<F%D82!C
M;VUO('5N(&=U:?-N(%!(4"!E;B!E;"!D:7)E8W1O<FEO('1E;7!O<F%L(&1E
M('-U('-E<G9I9&]R+@!392!H82!G=6%R9&%D;R!L82!C;VYF:6=U<F%C:?-N
M(&1E("5S+@!'=6%R9&%R(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@
M8V]N9FEG=7)A8VGS;B!E;CH@(B5S(BX`0F]R<F%S8V%S(&%I<VQA9&%S`$-I
M96YC:6$`0G5S8V%R`$TN(&+Z<W%U961A`%-E;&5C8VEO;F%R(&%R8VAI=F]S
M`%-E;&5C8VEO;F4@=6YA(&9E8VAA`%-E;&5C8VEO;F4@96P@9W)U<&\@82!A
M\6%D:7(`4V5L96-C:6]N92!U;B!N=65V;R!P<F]P:65T87)I;P!396QE8V-I
M;VYE('5N('-E<G9I9&]R`%-E;&5C8VEO;F4@96P@=7-U87)I;R!A(&'Q861I
M<@!396QE8V-I;VYA<B!T;V1O`%-E;&5C8VEO;F4@=&]D;W,@;&]S(&-O;7!O
M;F5N=&5S(&1E(&QA(&9E8VAA+@!396QE8V-I;VYA<B!U;B!O8FIE=&\`4VEN
M('-E;&5C8VGS;@!396QE8V-I;VYE(&QO<R!C87+A8W1E<F5S('%U92!N96-E
M<VET92!D92!L87,@8V%S:6QL87,@9&4@86)A:F\N(%!U961E(&-O<&EA<FQO
M<R!Y('!E9V%R;&]S(&1E;"#A<F5A(&1E('1E>'1O+@!396QE8V-I;VYE(&5L
M(&1E;&EM:71A9&]R(&1E(&9E8VAA<SH`4V5L96-C:6]N92!E;"!F;W)M871O
M(&1E(&9E8VAA<SH`4V5L96-C:6]N92!L82!I9&5N=&ED860@<75E('%U:65R
M82!C86UB:6%R.@!396QE8V-I;VYE(&5L(&1E;&EM:71A9&]R(&1E(&AO<F%S
M.@!396QE8V-I;VYE(&5L(&9O<FUA=&\@9&4@:&]R87,Z`%-E;&5C8VEO;F4@
M9&]S(&-A;7!O<R!C;VEN8VED96YT97,N`%-E;&5C8VEO;F4@<W4@8V]M8FEN
M86-I\VX@9&4@8V]L;W)E<RX`4V5L96-C:6]N92!S=2!I9&EO;6$@<')E9F5R
M:61O.@!%;G9I87(@:6YF;W)M92!D92!P<F]B;&5M87,`16YV:6%R(%--4P!3
M96YE9V%L`%-E;G-O<CH@`%-E<'1I96UB<F4`4V5R8FEA('D@36]N=&5N96=R
M;P!.^FUE<F\@9&4@<V5R:64`1&%T;W,@9&5L('-E<G9I9&]R(&5R<O-N96]S
M(&\@;F\@9&ES<&]N:6)L97,N`$%D;6EN:7-T<F%C:?-N(&1E('-E<VGS;@!(
M82!C861U8V%D;R!E;"!)1"!D92!S97-I\VXN`%-E<VEO;F5S`$5S=&%B;&5C
M97(`17-T86)L96-E(&]P8VEO;F5S('%U92!L92!P97)M:71E;B!R96%J=7-T
M87(@<W4@8V]N=')A<V7Q82!S:2!L;&5G87)A(&$@;VQV:61A<FQA+@!#;VYF
M:6=U<F$@<V5R=FED;W)E<R!R96UO=&]S(&$@;&]S('%U92!D97-E92!A8V-E
M9&5R(&1E<V1E(&5L('!O<G1A;"X`1&5F:6YE(&QA<R!O<&-I;VYE<R!P<F5F
M97)I9&%S(&1E(&ED:6]M82P@>F]N82!H;W)A<FEA('D@9F5C:&%S+@!$969I
M;F4@;&$@87!L:6-A8VGS;B!D92!I;FEC:6\L(&QA(&-O;6)I;F%C:?-N(&1E
M(&-O;&]R97,L(&QA(&%C='5A;&EZ86-I\VX@9&4@<.%G:6YA('D@;W1R87,@
M;W!C:6]N97,@9&4@=FES=6%L:7IA8VGS;BX`0V]N9FEG=7)A8VGS;@!(87D@
M9W5I;VYE<R!D92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX`
M5F%R:6%S('5B:6-A8VEO;F5S(&1I<W!O;FEB;&5S(&-O;B!E;"!P87+A;65T
M<F\Z(`!397EC:&5L;&5S`$-O;7!R87,`4F5S=6UE;B!C;W)T;P"_1&5F:6YI
M<B!C;&%V97,@9&4@86-C97-O('!A<F$@;&$@;6%Y;W+M82!D92!L;W,@=NUN
M8W5L;W,_`"9N8G-P.TUO<W1R87(F;F)S<#L`375E<W1R82!L87,@9&EF97)E
M;F-I87,@96YT<F4@;&$@;G5E=F$@8V]N9FEG=7)A8VGS;B!Y(&QA(&%L;6%C
M96YA9&$`OTUO<W1R87(@:&]R82!D92!L82#Z;'1I;6$@<V5S:?-N(&%L(&EN
M:6-I87(_`$UO<W1R87(@;W!C:?-N(&1E(&-O;G-E<G9A<B!E;"!O<FEG:6YA
M;`!-;W-T<F%R('-E;&5C=&]R`+]-;W-T<F%R(&QA(&)A<G)A(&1E(&UE;OH@
M9&4@;W!E<F%C:6]N97,@9&4@=&%B;&$_`+]-;W-T<F%R(&5L(&UE;OH@)7,@
M82!L82!I>G%U:65R9&$_`$UU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P:65D
M861E<R!D92!C96QD82!D92!T86)L80!-=65S=')A(&5L(&1IX6QO9V\@9&4@
M<')O<&EE9&%D97,@9&4@=&%B;&$`375E<W1R82!E;"!D:>%L;V=O(&1E('!R
M;W!I961A9&5S(&1E(&9I;&$@9&4@=&%B;&$`375E<W1R82!E;"!D:>%L;V=O
M(&1E('!R;W!I961A9&5S(&1E(&EM86=E;@!-;W-T<F%R(&-A<F=A`$%G=6%C
M97)O<P!,;'5V:6%S(&UA='5T:6YA<P!,;'5V:6%S('9E<W!E<G1I;F%S`$%G
M=6%C97)O<R!E;B!L82!V96-I;F1A9`!2961U8VER`%!R:6UE<F\@<F5D=7IC
M82!O('%U:71E(&1E(&5N;65D:6\@;&]S(&)L;W%U97,@8V5R8V%N;W,`4VEE
M<G)A($QE;VYA`$%L=&$`1FER;6$`06QG;W)I=&UO(&1E(&9I<FUA`%-I;F=A
M<'5R`%1A;6'Q;P!/;6ET:7(@;6%N=&5N:6UI96YT;P!%<VQO=F%Q=6EA`$5S
M;&]V96YI80!.:65V90!!9W5A8V5R;R!D92!N:65V90!!9W5A8V5R;R!D92!N
M:65V90!!9W5A8V5R;R!D92!N:65V92!M871U=&EN;P!!9W5A8V5R;R!D92!N
M:65V92!V97-P97)T:6YO`$5S<&5S;W(@9&4@;&$@;FEE=F4Z(`!%<75I=F%L
M96YT92!D92!L82!N:65V92!E;B!A9W5A.B``27-L87,@4V%L;VWS;@!3;VUA
M;&EA`$-A;F-I;VYE<R`F(%!O96UA<P!396QE8V-I\VX@9&5L('-E;G1I9&\@
M9&4@;&$@8VQA<VEF:6-A8VGS;@!296UI=&5N=&4`4W5DX69R:6-A`$5U<F]P
M82!D96P@<W5R("A)4T\M.#@U.2TS*0!'96]R9VEA(&1E;"!3=7(@92!)<VQA
M<R!386YD=VEC:"!D96P@4W5R`$AE;6ES9F5R:6\@<W5R`$5S<&%C:6%D;R!E
M;G1R92!C96QD87,@861Y86-E;G1E<P!%<W!A8VEA9&\@96YT<F4@96P@8V]N
M=&5N:61O('D@96P@8F]R9&4@9&4@=6YA(&-E;&1A`%-E<&%R861O<@!%<W!A
M8VEA9&\`17-P86-I861O('D@;6%R9V5N`$5S<&'Q80!3<&%M`$5S8W)I='5R
M82!D92!C87)A8W1E<F5S(&5S<&5C:6%L97,`1&EV:61I<B!C96QD80!$:79I
M9&ER(&-O;'5M;F$`1&EV:61I<B!F:6QA`$1E<&]R=&5S`%-R:2!,86YK80!%
M<W3A;F1A<@!3=&%R(%1R96L`0?%O(&1E(&EN:6-I;P!%<W1A9&\@;R!P<F]V
M:6YC:6$`17-T861O`$9O<FUA=&\@9&4@86QM86-E;F%M:65N=&\`1&ER96-C
M:?-N(&1E(&QA(&-A;&QE`%1A8VAA9&$`3&ES=&$@9&4@8V%D96YA<P!%;&EM
M:6YA<B!D;VUI;FEO(&1E(&QA(&1I<F5C8VGS;@!%<W1I;&\@6T-34UT`1&]M
M`$YO('-E(&5N8V]N='+S(&5L('-U8F1I<F5C=&]R:6\@(B5S(BX`07-U;G1O
M`$5N=FEA<@!392!H82!E;G9I861O('5N82!S;VQI8VET=60@9&4@86QT82!D
M92`B)7,B(&5N(&5L('-I<W1E;6$N($YO('!O9'+A(&EN:6-I87(@<V5S:?-N
M(&AA<W1A('%U92!S92!H87EA(&%P<F]B861O(&QA('-O;&EC:71U9"X`4W5B
M[6YD:6-E`,EX:71O`%-E(&AA(&'Q861I9&\@8V]R<F5C=&%M96YT92`B)7,B
M(&%L('-I<W1E;6$N`%-E(&AA;B!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92!L
M;W,@9&%T;W,@9&5L('5S=6%R:6\@(B5S(B!D96P@<VES=&5M82X`4V4@:&$@
M96QI;6EN861O(&-O<G)E8W1A;65N=&4@(B5S(BX`4V4@:&$@96QI;6EN861O
M(&-O<G)E8W1A;65N=&4@(B5S(B!D96P@<VES=&5M82X`4V4@:&$@<F5S=&%U
M<F%D;R!C;W)R96-T86UE;G1E(&QA(&-O;F9I9W5R86-I\VXN(%)E9G)E<W%U
M92!P87)A('9E<B!L;W,@8V%M8FEO<RX`4V4@:&$@9W5A<F1A9&\@8V]R<F5C
M=&%M96YT82!L82!C;W!I82!D92!L82!C;VYF:6=U<F%C:?-N+@!392!H82!G
M=6%R9&%D;R!C;W)R96-T86UE;G1E(&QA(&-O<&EA("5S(&1E(&QA(&-O;F9I
M9W5R86-I\VXN`%-E(&AA(&%C='5A;&EZ861O(&-O<G)E8W1A;65N=&4@(B5S
M(@!392!H82!E<V-R:71O(&-O<G)E8W1A;65N=&4@)R5S)P!3=63A;@!297-U
M;65N`$%M86YE8V5R`$%T87)D96-E<@!3;VQE861O`$%M86YE8V5R`$%M86YE
M8V5R+T%T87)D96-E<@!!;6%N96-E<CH@`$%T87)D96-E<@!!=&%R9&5C97(Z
M(`!3=7!E<NUN9&EC90!3;W!O<G1E`%-U<FEN86T`07!E;&QI9&\`4W9A;&)A
M<F0@>2!*86X@36%Y96X`4W=A>FEL86YD:6$`4W5E8VEA`%-U:7IA`%)E9VES
M=')O(&1E('-I;F-R;VYI>F%C:?-N(&5L:6UI;F%D;P!3>6YC34P`17)R;W(@
M9&4@<VEN=&%X:7,@96X@;&]S('3I<FUI;F]S(&1E(&+Z<W%U961A`%)E</IB
M;&EC82#!<F%B92!D92!3:7)I80!#:'5B87-C;P!";W)R87-C;W-O('D@=F5N
M=&]S;P!";W)R87-C87,`0F]R<F%S8V%S(&UA='5T:6YA<P!!<F-H:79O(%13
M5@!486)L80!0<F]P:65D861E<R!D92!T86)L80!486)L80!0<F]P:65D861E
M<R!D92!T86)L80!486EWX6X`5&%I=^%N+"!0<F]V:6YC:6$@9&4@0VAI;F$`
M5&%Y:6MI<W3A;@!486YZ86YI82P@4F5P^F)L:6-A(%5N:61A(&1E`$1E<W1I
M;F\Z`%1A<F5A<P!.^FUE<F\@9&4@=&5LZ69O;F\`5&5M<&5R871U<F$@9'5R
M86YT92!L82#Z;'1I;6$@:&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A
M.B``5&5M<&5R871U<F$\8G(@+SXH)7--X7@E<R\E<TWM;B5S*2`F9&5G.R5S
M`$YO('-E(&5N8V]N='+S(&QA('!L86YT:6QL82`B)7,B+@!!9&UI;FES=')A
M8VGS;B!D92!P;&%N=&EL;&%S`%1E>'1O`%/S;&\@=&5X=&\`06QI;F5A8VGS
M;B!D92!T97AT;P!";W)D92!S=7!E<FEO<B!D96P@=&5X=&\`2G5E`%1A:6QA
M;F3I<R`H5$E3+38R,"D`5&%I;&%N9&EA`$YO(&5S=.$@9&ES<&]N:6)L92!L
M82!E>'1E;G-I\VX@1E10+@!%;"!S:7-T96UA(&AI<W3S<FEC;R!E<W3A(&1E
M<VAA8FEL:71A9&\N`$5L(&UO=&]R(&1E(&EN=&5G<F%C:?-N($AO<F1E+TMO
M;&%B(&YO('-O<&]R=&$@(B5S(@!.;R!S92!P=65D92!I;FEC:6%R(&5L(')E
M9VES=')O(&1E($E-4U`N`$YO('-E(&AA(&-A<F=A9&\@8V]R<F5C=&%M96YT
M92!L82!C;&%S92!-86EN=&5N86YC93HZ`%-E(&AA(&-E<G)A9&\@;&$@=F5N
M=&%N82!D92!O<&-I;VYE<RX@4V%L:65N9&\N`%-I(&1E<V5A('5T:6QI>F%R
M('!E<FUI<V]S+"!E;"!A9&UI;FES=')A9&]R('1I96YE('%U92!C;VYF:6=U
M<F%R('5N('-O<&]R=&4@9&4@<&5R;6ES;W,@<&5R;6%N96YT92X`4_-L;R!E
M;"!B;W)D92!I;F9E<FEO<@!%;"!)1"!D96P@8V]N=&%C=&\@;F\@<V4@97-P
M96-I9FEC\RP@<V4@9&5J\R!E;B!B;&%N8V\@;R!N;R!S92!E;F-O;G1R\R!E
M;B!L82!B87-E(&1E(&1A=&]S+@!392!H82!A\6%D:61O(&-O<G)E8W1A;65N
M=&4@96P@8V]N=&%C=&\@82!S=7,@9&ER96-C:6]N97,N`%!A<F$@8V]M<')O
M8F%R(&5L(&UE;G-A:F4@9FER;6%D;R!H86-E(&9A;'1A(&5L(&)L;W%U92!D
M92!F:7)M82!S97!A<F%D;RX`16P@240@9&4@;&$@;&ES=&$@9&4@9&ES=')I
M8G5C:?-N(&YO('-E(&5S<&5C:69I8_,L('-E(&1E:O,@96X@8FQA;F-O(&\@
M;F\@<V4@96YC;VYT<O,@96X@;&$@8F%S92!D92!D871O<RX`3F\@<V4@97-P
M96-I9FEC\R!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN`$QA<R!C87)A8W1E
M<NUS=&EC87,@9&4@8VEF<F%D;R!N96-E<VET86X@=6YA(&-O;F5X:?-N('=E
M8B!S96=U<F$N`$5L(&%R8VAI=F\@)7,@=&5N9'+M82!Q=64@8V]N=&5N97(@
M=6YA(&]P8VGS;B`E<RX`16P@87)C:&EV;R`E<R!T96YD<NUA('%U92!C;VYT
M96YE<B!A;&=U;F%S(&]P8VEO;F5S("5S+@!.;R!S92!P=65D92!C;W!I87(@
M96P@87)C:&EV;R!S;V)R92!S[2!M:7-M;RX`16P@87)C:&EV;R!N;R!C;VYT
M:65N92!D871O<RX`02!C;VYT:6YU86-I\VX@=&EE;F4@;&%S(&-A8F5C97)A
M<R!D92!E<W1E(&UE;G-A:F4@;65S<V%G92]R9F,X,C(N`%-E('-A8F4@<75E
M(&5L(&UO9&\@9&4@<&%N=&%L;&$@8V]M<&QE=&$@9&$@<')O8FQE;6%S(&-O
M;B!);G1E<FYE="!%>'!L;W)E<B!D96)I9&\@82!F86QL;W,@9&5L(&YA=F5G
M861O<B!Q=64@;F\@:&5M;W,@<&]D:61O('-O<VQA>6%R+B!0=65D92!S=69R
M:7(@=FES=6%L:7IA8VGS;B!D92!B87-U<F$L('#I<F1I9&$@9&4@9G5N8VEO
M;F5S(&1E;"!E9&ET;W(@>2]O(&-U96QG=65S(&%L96%T;W)I;W,@9&5L(&YA
M=F5G861O<BX@4VD@<W4@<VES=&5M82!O<&5R871I=F\@97,@5VEN9&]W<R`Y
M>"P@97,@;75Y('!R;V)A8FQE('%U92!S=69R82!U;B!F86QL;R!D92!P<F]T
M96-C:?-N(&=E;F5R86P@>2!T96YG82!Q=64@<F5I;FEC:6%R(&5L(&5Q=6EP
M;RY<;EQN66$@97-TX2!A=FES861O+B!0=6QS92!!8V5P=&%R('-I(&'Z;B!D
M97-E82!P<F]B87(@96P@961I=&]R(&5N(&UO9&\@9&4@<&%N=&%L;&$@8V]M
M<&QE=&$N`%-E(&AA(&5L:6UI;F%D;R!L82!I9&5N=&ED860@(B5S(BX`4_-L
M;R!E;"!B;W)D92!I>G%U:65R9&\`2&%Y('%U92!I;F1I8V%R;&4@82!L82!C
M;&%S92!#<GEP=%]P9W`Z.B!L82!U8FEC86-I\VX@9&4@;&]S(&)I;F%R:6]S
M($=N=5!'+@!392!H82!M;W-T<F%D;R!E;"!M96YS86IE(&5N=FEA9&\@96P@
M)7,@82`E<R!C;VX@96P@87-U;G1O("(E<R(N"LES=&\@;F\@9V%R86YT:7IA
M('%U92!E;"!M96YS86IE(&AA>6$@<VED;R!L96ED;R!O(&-O;7!R96YD:61O
M+@!.;VUB<F4@=71I;&EZ861O(&%L('9I;F-U;&%R(&$@;&$@<.%G:6YA(&1E
M(&-O;7!O<VEC:?-N`$5L(&[Z;65R;R!D92!C86UP;W,@=&EE;F4@<75E('-E
M<B!U;B!N^FUE<F\N`$AA8V4@9F%L=&$@96P@;?-D=6QO(&]P96YS<VP@<&%R
M82!L82!C;&%S92!(;W)D95]#<GEP=%]S;6EM93HZ+@!.;R!S92!P=65D92!G
M=6%R9&%R(&QA('!R969E<F5N8VEA("(E<R(@<&]R<75E('-U<R!D871O<R!S
M;V)R97!A<V%N(&5L('1A;6'Q;R!MX7AI;6\@<&5R;6ET:61O`$YO('-E(&5N
M8V]N='+S(&5N(&5L('-I<W1E;6$@96P@<')O9W)A;6$@<&%R82!V97(@97-T
M92!T:7!O(&1E(&1A=&]S("@E<RDN`$5L(&-A<N%C=&5R(&1E(&-I=&$@9&5B
M92!S97(@<V5R('/S;&\@=6YO+@!3\VQO(&QO<R!L861O<R!I>G%U:65R9&\@
M>2!D97)E8VAO`%/S;&\@96P@;&%D;R!D97)E8VAO`$5L('-E<&%R861O<B!D
M96)E('-E<B!S\VQO('5N;RX`4V4@:&$@96QI;6EN861O(&5L('-E<G9I9&]R
M("(E<R(N`%-E(&AA(&=U87)D861O(&5L('-E<G9I9&]R("(E<R(N`%-E(&AA
M(&5L:6UI;F%D;R!L82!S;VQI8VET=60@9&4@86QT82!D92`E<RX`3&$@9FEL
M82!E<W!E8VEF:6-A9&$@*"5D*2!N;R!E>&ES=&4N`$5L(&%R8VAI=F\@=&5M
M<&]R86P@(B5S(B!N;R!E>&ES=&4N`$5L('1E>'1O('%U92!H82!I;G1R;V1U
M8VED;R!N;R!C;VEN8VED92!C;VX@96P@9&4@;&$@<&%N=&%L;&$N`%/S;&\@
M;&]S(&QA9&]S('-U<&5R:6]R(&4@:6YF97)I;W(`4_-L;R!E;"!L861O('-U
M<&5R:6]R`%-E('!E<F1I97)O;B!L;W,@9&%T;W,@8V%R9V%D;W,@9&5S9&4@
M96P@<&%S;R!A;G1E<FEO<BX`3F\@<V4@<'5D;R!G=6%R9&%R(&5L(&%R8VAI
M=F\@8V%R9V%D;RX`3F\@97-TX2!D:7-P;VYI8FQE(&5L(&)L;W%U92!D92!W
M96%T:&5R+F-O;2X`3F\@<V4@96YC;VYT<O,@96P@9&ER96-T;W)I;R!D92!4
M96UA<R`B)7,B+@!.;R!S92!D:7-P;VYE(&1E(&]P8VEO;F5S+@!.;R!H87D@
M<&%R=&5S('%U92!S92!P=65D86X@;6]S=')A<B!E;B!L[6YE82X`16X@97-T
M92!C86UP;R!H87D@9&5M87-I861O<R!C87)A8W1E<F5S+B!(82!I;G1R;V1U
M8VED;R`E<R!C87)A8W1E<F5S('D@=&EE;F4@<75E(&EN=')O9'5C:7(@;65N
M;W,@9&4@)7,N`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A9&ER(&$@
M(B5S(B!A;"!S:7-T96UA.B`E<P!392!P<F]D=6IO('5N('!R;V)L96UA(&%L
M(&)O<G)A<B!L;W,@9&%T;W,@9&5L('5S=6%R:6\@(B5S(B!D96P@<VES=&5M
M83H@`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@96QI;6EN87(@82`B)7,B
M(&1E;"!S:7-T96UA.B``4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A8W1U
M86QI>F%R("(E<R(Z("5S`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@8V]N(&QA
M(&-A<F=A(&1E;"!A<F-H:79O.B!.;R!S92!C87)G\R`E<RX`4V4@<')O9'5J
M;R!U;B!P<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N($5L("5S
M(&5R82!MX7,@9W)A;F1E('%U92!E;"!T86UA\6\@;>%X:6UO('!E<FUI=&ED
M;R`H)60@8GET97,I+@!392!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L82!C
M87)G82!D96P@87)C:&EV;RX@4_-L;R!S92!C87)G\R!P87)C:6%L;65N=&4@
M96P@)7,N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@;6]S=')A<B!E<W1A('!A
M<G1E(&1E;"!M96YS86IE`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T
M87(@;&]S(&1A=&]S(&1E;"!C;VYT86-T;RX`4V4@<')O9'5J;R!U;B!E<G)O
M<B!A;"!I;7!O<G1A<B!L;W,@9&%T;W,@:4-A;&5N9&%R+@!392!P<F]D=6IO
M('5N(&5R<F]R(&5N(&5L(&9O<FUU;&%R:6\@9&4@8V]N9FEG=7)A8VGS;BX@
M4'5E9&4@<75E(&AA>6$@;VQV:61A9&\@<F5L;&5N87(@=6X@8V%M<&\@;F5C
M97-A<FEO+@!392!P<F]D=6IO('5N(&5R<F]R(&%L(&5J96-U=&%R(&QA(&9U
M;F-I\VX@97-P96-I9FEC861A(&1E(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N
M97,N(%9U96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N`%-E('!R;V1U:F\@
M=6X@97)R;W(@86P@86-T=6%L:7IA<B!L;W,@9&5T86QL97,@9&5L(&-O;G1A
M8W1O+B!6=65L=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+@!392!P<F]D=6IO
M('5N(&5R<F]R(&%L(&%C='5A;&EZ87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C
M:?-N+B!6=65L=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+@!%<W1E('-E<G9I
M9&]R($E-05`@;F\@<V]P;W)T82!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N
M`,ES=&4@;F\@<&%R96-E('-E<B!U;B!A<F-H:79O(')A<B!VX6QI9&\N`,ES
M=&4@;F\@<&%R96-E('-E<B!U;B!A<F-H:79O('II<"!VX6QI9&\N`,ES=&4@
M;F\@<&%R96-E('-E<B!U;B!N^FUE<F\@9&4@=&%R:F5T82!VX6QI9&\N`$5S
M=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I87(@;65N<V%J97,@82!T<F%V
MZ7,@9&4@;&$@<&%S87)E;&$@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2P@;65D:6%N=&4@;&$@05!)($A45%``17-T92!C;VYT<F]L861O
M<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!A('1R87;I<R!D92!L82!P87-A
M<F5L82!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2P@;65D:6%N=&4@;&$@05!)
M($A45%``17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE
M<R!A('1R87;I<R!D92!L82!P87-A<F5L82!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PN8V]M*2P@;65D:6%N=&4@;&$@05!)($A45%``17-T92!C;VYT
M<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!V:6$@4TU44"!A('1R
M87;I<R!D92!L82!P87-A<F5L82!D92!6;V1A9F]N92!D92!)=&%L:6$L('/S
M;&\@82!N^FUE<F]S(%9O9&%F;VYE+B!(86-E(&9A;'1A('5N82!C=65N=&$@
M9&4@8V]R<F5O(&1E(%9O9&%F;VYE(&1E($ET86QI82`H:'1T<#HO+W=W=RXQ
M.3`N:70I+@!(86-E(&9A;'1A(&5S=&4@8V%M<&\N`$5S=&4@8V%M<&\@<_-L
M;R!P=65D92!C;VYT96YE<B!E;G1E<F]S+@!%<W1E(&-A;7!O('/S;&\@<'5E
M9&4@8V]N=&5N97(@;OIM97)O<R!Y(&QO<R!D;W,@<'5N=&]S+@!%<W1E(&-A
M;7!O('/S;&\@<'5E9&4@8V]N=&5N97(@=F%L;W)E<R!O8W1A;&5S+@!%<W1E
M(&-A;7!O('1I96YE('%U92!S97(@=6YA(&QI<W1A(&1E(&5N=&5R;W,@<V5P
M87)A9&]S('!O<B!C;VUA<R!O(&5S<&%C:6]S+@!%<W1E(&-A;7!O('1I96YE
M('%U92!S97(@=6X@;OIM97)O(';A;&ED;RX`17-T92!C86UP;R!T:65N92!Q
M=64@8V]N=&5N97(@=6X@8_-D:69O(&1E(&-O;&]R(&5N(&9O<FUA=&\@4D="
M($AE>&%D96-I;6%L+"!P;W(@96IE;7!L;R`G(S$R,S1A9B<N`%EA('-E(&AA
M('!R;V-E<V%D;R!E<W1E(&9O<FUU;&%R:6\N`$5S=&\@97,@)7,N`,ES=&\@
M97,@=6X@;V)J971O(&1E($MO;&%B($=R;W5P=V%R92X@4&%R82!V97)L;R!N
M96-E<VET82!U;B!C;&EE;G1E(&1E(&-O<G)E;R`@<75E(&5N=&EE;F1A(&5L
M(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!U;F$@;&ES=&$@
M9&4@9&EC:&]S(&-L:65N=&5S('9I<VET92`E<P!%<W1E(&UE;G-A:F4@<V4@
M97-C<FEB:?,@8V]N('5N(&IU96=O(&1E(&-A<F%C=&5R97,@*"5S*2!D:7-T
M:6YT;R!A;"!S=7EO+@!%<W1E(&[Z;65R;R!D96)E('-E<B!P;W(@;&\@;65N
M;W,@=6X@=6YO+@!%<W1E('-E<G9I9&]R(&YO('!U961E(&1E<V-O;7!R:6UI
M<B!A<F-H:79O<R!Z:7`@>2!G>FEP+@!%<W1E('-I<W1E;6$@86-T=6%L;65N
M=&4@97-TX2!D97-A8W1I=F%D;RX`17-T92!V86QO<B!T:65N92!Q=64@<V5R
M('5N(&[Z;65R;RX`17-T82!V96YT86YA('/S;&\@<'5E9&4@86)R:7)S92!D
M97-D92!U;F$@=F5N=&%N82!D92!O<&-I;VYE<P!4<G5E;F\`26YC:61E;F-I
M87,`2&]R80!#+B!T:65M<&]S`$9O<FUA=&\@:&]R87)I;P!396QE8V-I\VX@
M9&4@:&]R80!4:6UO<BU,97-T90!4[71U;&\`5.UT=6QO("AC;VYS96IO*3H`
M4&%R80!087)A('-E;&5C8VEO;F%R('9A<FEO<R!C86UP;W,L(&UA;G1E;F=A
M('!U;'-A9&$@;&$@=&5C;&$@0V]N=')O;"`H4$,I(&\@0V]M86YD;R`H36%C
M*2!A;"!H86-E<B!C;&EC:RX`2&]Y`$-O;FUU=&%R(&]R:6=E;B!(5$U,`%1O
M9V\`5&]K96QA=0!-8?%A;F$`5&]N9V$`4W5P97)I;W(`1G)A;64@<W5P97)I
M;W(@*%]T;W`I`%1R861U8V-I;VYE<P!4<FEN:61A9"!Y(%1O8F%G;P!697)D
M861E<F\@;R!F86QS;P!-87(`5/IN97H`5'5R<77M80!4=7)C;R`H25-/+3@X
M-3DM.2D`5'5R:VUE;FES=.%N`$ES;&%S(%1U<FMS('D@0V%I8V]S`%1U=F%L
M=0!%<V-R:6)A('-U(&5L96-C:?-N.B``S6YD:6-E(%4N5BXZ(`!54DP`55),
M(&1E('-U(&EN9F]R;64@9&4@97-T861O(&1E(&5N=NUO(&1E;"!G=6GS;@!5
M4DPZ`%5G86YD80!58W)A;FEA`$EN8V%P87H@9&4@86-C961E<B!A;"!D:7)E
M8W1O<FEO(%9&4RX`26YC87!A>B!D92!A\6%D:7(@:6YF;W)M86-I\VX@9&4@
M=7-U87)I;R!A9&EC:6]N86P@86P@<F5A;&EZ87(@96P@86QT82X`26YC87!A
M>B!D92!C86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C:&EV;R!61E,@
M(B5S(BX`26YC87!A>B!D92!C86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@
M87)C:&EV;R!61E,@)7,O)7,N`$EN8V%P87H@9&4@8V%M8FEA<B!A("5S+@!)
M;F-A<&%Z(&1E(&-O;7!R;V)A<B!E;"!T86UA\6\@9&4@(B5S(BX`26YC87!A
M>B!D92!C;VUP<F]B87(@96P@=&%M8?%O(&1E("(E<R\E<R(N`$EN8V%P87H@
M9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!344PN`$EN8V%P87H@9&4@8V]N
M96-T87(@8V]N(%-33"X`26YC87!A>B!D92!C;W!I87(@96P@87)C:&EV;R!6
M1E,N`$EN8V%P87H@9&4@8W)E87(@96P@9&ER96-T;W)I;R!61E,@(B5S(BX`
M26YC87!A>B!D92!C<F5A<B!E;"!D:7)E8W1O<FEO(%9&4RX`26YC87!A>B!D
M92!C<F5A<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!C<F5A<B!L82!C
M87)P971A(%9&4R`B)7,B`$EN8V%P87H@9&4@8W)E87(@=6X@87)C:&EV;R!6
M1E,@=F%C[6\N`$EN8V%P87H@9&4@9&5S8V]M<')I;6ER(&QO<R!D871O<RX`
M26YC87!A>B!D92!E;&EM:6YA<B`B)7,B+"!E;"!D:7)E8W1O<FEO(&YO(&5S
M=.$@=F%C[6\N`$EN8V%P87H@9&4@96QI;6EN87(@(B5S(CH@)7,N`$EN8V%P
M87H@9&4@96QI;6EN87(@)7,L(&5L(&1I<F5C=&]R:6\@;F\@97-TX2!V86/M
M;P!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93(&1E(&9O
M<FUA(')E8W5R<VEV82X`26YC87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E8W1O
M<FEO(%9&4RX`26YC87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%9&
M4SH@)7,N`$EN8V%P87H@9&4@96QI;6EN87(@96P@87)C:&EV;R!61E,@(B5S
M(BX`26YC87!A>B!D92!E;&EM:6YA<B!E;"!A<F-H:79O(%9&4RX`26YC87!A
M>B!D92!E;&EM:6YA<B!L82!C87)P971A(%9&4R`B)7,B+@!);F-A<&%Z(&1E
M(&5L:6UI;F%R(&5L(%9&4R!D92!F;W)M82!R96-U<G-I=F$Z("5S+@!);F-A
M<&%Z(&1E(&1E=&5R;6EN87(@96P@9&ER96-T;W)I;R!A8W1U86PN`$EN8V%P
M87H@9&4@97AT<F%E<B!L;W,@9&5T86QL97,@9&5L(&-E<G1I9FEC861O+@!)
M;F-A<&%Z(&1E(&-A<F=A<B!L82!D969I;FEC:?-N(&1E("5S+@!);F-A<&%Z
M(&1E('1R87-L861A<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!A8G)I
M<B!E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&%B<FER(&5L(&%R
M8VAI=F\@5D93('!A<F$@97-C<FEB:7(N`$EN8V%P87H@9&4@86)R:7(@96P@
M87)C:&EV;R!61E,N`$EN8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!C;VUP
M<FEM:61O+@!);F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV;R!61E,@*&AA(&9A
M;&QA9&\@9FEL97-I>F4H*2DN`$EN8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O
M(%9&4R`H:&$@9F%L;&%D;R!G971&:6QE4VEZ92@I*2X`26YC87!A>B!D92!L
M965R('5N(&%R8VAI=F\Z(`!);F-A<&%Z(&1E(&QE97(@96P@9&ER96-T;W)I
M;R!V9G-R;V]T+@!);F-A<&%Z(&1E(')E;F]M8G)A<B`E<R!C;VUO("5S.B!L
M82!C87)P971A(&1E<W1I;F\@>6$@97AI<W1E`$EN8V%P87H@9&4@<F5N;VUB
M<F%R(&5L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E
M;"!D:7)E8W1O<FEO(%9&4SH@)7,N`$EN8V%P87H@9&4@<F5N;VUB<F%R(&5L
M(&%R8VAI=F\@5D93("(E<R(`26YC87!A>B!D92!R96YO;6)R87(@96P@87)C
M:&EV;R!61E,@)7,O)7,N`$EN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&%R8VAI
M=F\@5D93+@!);F-A<&%Z(&1E(&5J96-U=&%R("=M:VES;V9S)RX`3F\@<V4@
M<'5E9&4@=')A9'5C:7(@97-T92!D;V-U;65N=&\@9&4@5V]R9`!);F-A<&%Z
M(&1E(&5S8W)I8FER(&5L(&%R8VAI=F\@5D93("(E<R(N`$EN8V%P87H@9&4@
M97-C<FEB:7(@=6X@87)C:&EV;R!61E,@*&AA(&9A;&QA9&\@8V]P>2@I*2X`
M26YC87!A>B!D92!E<V-R:6)I<B!L;W,@9&%T;W,@9&5L(&%R8VAI=F\@5D93
M+@!);F-A<&%Z(&1E(&5S8W)I8FER('5N(&%R8VAI=F\@5D93+"!S92!S=7!E
M<F%RX2!L82!Q=6]T82X`4W5B<F%Y861A`$1E<VAA8V5R(&-A;6)I;W,`1&5S
M:&%C92!L82#Z;'1I;6$@86-C:?-N`%)E<W!U97-T82!I;F5S<&5R861A(&1E
M;"!S97)V:61O<B!E;B!L82!C;VYE>&GS;CH@`%)E<W!U97-T82!I;F5S<&5R
M861A(&1E;"!S97)V:61O<B!A.B``4VEN(&-A=&5G;W+M80!5;FEC;V1E("A5
M5$8M."D`16UI<F%T;W,@P7)A8F5S(%5N:61O<P!);F=L871E<G)A`$5S=&%D
M;W,@56YI9&]S`$5S=&%D;W,@56YI9&]S(&UE;F]S(&QA<R!I<VQA<R!P97)I
M9NER:6-A<P!5;FED861E<P!$97-C;VYO8VED;P!!<&EM<V=I9"!D97-C;VYO
M8VED;R`H240@9&4@;65N<V%J92!D92!L82!!4$DI+@!#;&EM<V=I9"!D97-C
M;VYO8VED;R`H240@9&4@;65N<V%J92!D96P@8VQI96YT92DN`%-E(&AA(&1E
M9FEN:61O('5N82!U8FEC86-I\VX@9&5S8V]N;V-I9&$N`%5S=6%R:6\@;R!C
M;VYT<F%S9?%A(&1E<V-O;F]C:61O<RX`16QI;6EN87(@=NUN8W5L;R!D96P@
M96QE;65N=&\@86-T=6%L`%-I;B!N;VUB<F4`3&]S(&=U:6]N97,@<VEN('!R
M:79I;&5G:6]S(&YO('!U961E;B!A8V-E9&5R(&1E(&9O<FUA('!R;V=R86WA
M=&EC82!A($-O<G1A<B]#;W!I87(O4&5G87(@<&]R(')A>F]N97,@9&4@<V5G
M=7)I9&%D+B!0=6QS92!!8V5P=&%R('!A<F$@=F5R(&5N(&UO>FEL;&$N;W)G
M('5N82!N;W1A('3I8VYI8V$@<75E(&QE(&UU97-T<F4@8_-M;R!P97)M:71I
M<B!Q=64@=6X@9W5I\VX@86-C961A(&%L('!O<G1A<&%P96QE<RX`06YU;&%R
M(&-O;&]R`$5X=&5N<VGS;B!N;R!S;W!O<G1A9&$`06-T=6%L:7IA<@!!8W1U
M86QI>F%R("5S`$%C='5A;&EZ87(@=7-U87)I;P!392!H82!A8W1U86QI>F%D
M;R`B)7,B+@!392!H82!E;&EM:6YA9&\@96P@9W5I\VX@9&4@86-T=6%L:7IA
M8VGS;BX`0V%R9V%R`%-E(&AA;B!C87)G861O(&5N(&5L('-E<G9I9&]R('1O
M9&]S(&QO<R!A<F-H:79O<R!D92!C;VYF:6=U<F%C:?-N(&1E(&%P;&EC86-I
M;VYE<RX`06QF86)E=&\@;&%T:6YO(&5N(&UA>?IS8RX`3OIM97)O<R!R;VUA
M;F]S(&5N(&UA>?IS8RX`57)U9W5A>0!5<V%R(&%C='5A;#H@)7,`57-A<B!3
M4TP`4V4@=7-A('-I(&5L('5S=6%R:6\O8V]N=')A<V7Q82!S;VX@9&ES=&EN
M=&]S(&5N(&5L('-E<G9I9&]R($E-4U`N`%5S=6%R:6\`16P@=7-U87)I;R`E
M<R!C87)E8V4@9&4@875T;W)I>F%C:?-N('!A<F$@)7,N`$%D;6EN:7-T<F%C
M:?-N(&1E('5S=6%R:6]S`$]P8VEO;F5S(&1E('5S=6%R:6\`4F5G:7-T<F\@
M9&4@=7-U87)I;W,`17-T82!S961E('1I96YE(&1E<V%C=&EV861O(&5L(')E
M9VES=')O(&1E('5S=6%R:6]S+@!.;R!S92!H82!E;F-O;G1R861O(&QA(&ED
M96YT:61A9`!5<W5A<FEO`%EA(&5X:7-T92!E;"!N;VUB<F4@9&4@=7-U87)I
M;R`B)7,B+@!5<W5A<FEO.@!5<W5A<FEO.B``57-U87)I;W,@96X@96P@<VES
M=&5M83H`57IB96MI<W3A;@!.;R!E>&ES=&4@96P@9&ER96-T;W)I;R!61E,N
M`$%U<V5N8VEA`$QA<R!U8FEC86-I;VYE<R!VX6QI9&%S(&5N8V]N=')A9&%S
M(&EN8VQU>65N.B``5F%L:61E>@!686QO<B!E;B!M:6YU=&]S(&$@<&%R=&ER
M(&1E(&%H;W)A+@!%;"!V86QO<B!E>&-E9&4@96P@=&%M8?%O(&WA>&EM;R!D
M92`E<RX`5F%L;W)E<P!686QO<F5S(&$@<V5L96-C:6]N87(`5F%N=6%T=0!6
M87)I86)L90!696YE>G5E;&$`2&$@9F%L;&%D;R!L82!C;VUP<F]B86-I\VX@
M+2!E<W1E(&UE;G-A:F4@<'5E9&4@:&%B97)S92!F;W)Z861O+@!697)S:?-N
M`$,N('9E<G-I;VYE<P!!;&EN96%C:?-N('9E<G1I8V%L`$UA<F=E;B!V97)T
M:6-A;`!697)T:6-A;#H`375Y(&%L=&$`5FEE=&YA;0!6:65T;F%M:71A("A6
M25-#24DI`%9E<B`E<P!697(@=6YA('#A9VEN82!W96(@97AT97)N80!697(@
M8V]M;R`E<P!)<VQA<R!6[7)G96YE<RP@0G)I=.%N:6-A<P!)<VQA<R!6[7)G
M96YE<RP@52Y3+@!6:7-I8FEL:61A9`!6:7-I8FEL:61A9#H@`%9O9&%F;VYE
M(&1E($ET86QI82!M961I86YT92!33510`$%625-/`*&AH4%$5D525$5.0TE!
M(2$A($5,24U)3D4@34%.54%,345.5$4@14P@1U5)TTX@1$4@)7,N`%=)3B!P
M;W(@2%144`!786QL:7,@>2!&=71U;F$`061V97)T96YC:6$`36EE`%!R979I
M<VGS;B!D96P@=&EE;7!O`$1A=&]S(&1E;"!T:65M<&\@<W5M:6YI<W1R861O
M<R!P;W(`5V5A=&AE<BYC;VT`5V5B`%-E9&4@5V5B`%-E;6%N86QM96YT90!"
M:65N=F5N:61O`$)I96YV96YI9&]S(&$@)7,`0FEE;G9E;FED;RP@)7,`3V5S
M=&4@*$E33RTX.#4Y+3$I`$]E<W1E("A)4T\M.#@U.2TQ-2D`4^%H87)A($]C
M8VED96YT86P`OU%UZ2!A<&QI8V%C:?-N(&1E8F5R[6$@;6]S=')A<B`E<R!A
M;"!I;FEC:6%R(&QA('-E<VGS;C\`OT-UX6P@97,@96P@8V%RX6-T97(@9&5L
M:6UI=&%D;W(_`+]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E(&-I=&%D;S\`36%P
M82!D92!L;V-A;&EZ86-I\VX@9&4@075S=')A;&EA`%%UZ2!F87-E<P!0;'5G
M:6YS(&AA8FEL:71A9&]S(&1E;"!E9&ET;W(@9&4@=&5X=&\@96YR:7%U96-I
M9&\N`$%N8VAU<F$`06YC:'5R82!E;B!U;FED861E<R!#4U,`06YC:'5R82!D
M96P@;65N^B`E<R!I>G%U:65R9&\@*&1I<W!O;FEB;&4@96X@;&$@<'+S>&EM
M82!S97-I\VXI.@!!;F-H=7)A(&1E(&QA('1A8FQA`%5N:61A9&5S(&1E(&%N
M8VAU<F$`06YC:'5R83H`5VEK:0!6:65N=&\`5FEE;G1O(&UA='5T:6YA`%9E
M;&]C:61A9"!D96P@=FEE;G1O(&5N(&YU9&]S`%9I96YT;SH`5FEE;G1O.B``
M4V%B:61U<NUA`$1E<V5O<P!%;7!L96\`1&ER96-C:?-N(&1E;"!T<F%B86IO
M`%1E;.EF;VYO(&1E;"!T<F%B86IO`$[Z;65R;R!E<G+S;F5O(&1E(&-A;7!O
M<R!E;B!L82!L[6YE82`E9"X@4V4@97-P97)A8F%N("5D('D@:&%Y("5D+@!.
M^FUE<F\@97)R\VYE;R!D92!C86UP;W,N(%-E(&5S<&5R86)A;B`E9"!Y(&AA
M>2`E9"X`3V9F<V5T("5D(&5R<O-N96\@86P@;&5E<B!U;B!A<F-H:79O(%9&
M4RX`6"U2968`3&EM:71A8VEO;F5S(&+A<VEC87,@6#4P.78S`%5S;R!D92!C
M;&%V92!E>'1E;F1I9&$@6#4P.78S`$YO;6)R92!A;'1E<FYA=&EV;R!D92!A
M<W5N=&\@6#4P.78S`$ED96YT:69I8V%D;W(@9&4@8VQA=F4@9&4@87-U;G1O
M(%@U,#EV,P!%>'1E;G-I;VYE<R!8-3`Y=C,`04$`04%!00"A36%P82!D92!9
M86AO;R$`06YU86QM96YT90!996UE;@!3[0!3[2P@;&\@86-E<'1O`$5S=.$@
M96X@34]$3R!415A43RX@571I;&EC92!E;"!B;W3S;B!;/#Y=('!A<F$@<F5G
M<F5S87(@86P@;6]D;R!765-)5UE'+@!.;R!D:7-P;VYE(&1E('!R:79I;&5G
M:6]S('!A<F$@8W)E87(@;>%S(&1E("5D(&)L;W%U97,N`$YO(&5S=.$@875T
M96YT:69I8V%D;RX`3F\@<'5E9&4@:6YC;'5I<B!E;"!C87+A8W1E<B`B7"(@
M96X@96P@;F]M8G)E(&-O;7!L971O+@!.;R!I;G1R;V1U:F\@=6YA(&1I<F5C
M8VGS;B!D92!C;W)R96\@=N%L:61A+@!.;R!A<V]C:?,@;FEN9W5N;R!D92!L
M;W,@8V%M<&]S(&1E;"!A<F-H:79O(&EM<&]R=&%D;R!A(&QO<R!C86UP;W,@
M8V]R<F5S<&]N9&EE;G1E<R!D92`E<RX`2&$@<V%L:61O(&1E(&QA('-E<VGS
M;BX`5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@;OIM97)O(&1E('1E;.EF;VYO
M(&WS=FEL(';A;&ED;RP@<_-L;R!D[6=I=&]S(&-O;B!U;B`G*R<@;W!C:6]N
M86P@<&%R82!E;"!P<F5F:6IO(&1E(&QL86UA9&$@:6YT97)N86-I;VYA;"X`
M5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@=F%L;W(@=N%L:61O+@!087)A('5S
M87(@06QT87,@=&EE;F4@<75E(&-O;F9I9W5R87(@=6X@;6]T;W(@9&4@1&%T
M851R964N`%1I96YE('%U92!C;VYF:6=U<F%R('5N(&UO=&]R(%9&4RX`1&5B
M92!D97-C<FEB:7(@96P@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&5L(&EN
M9F]R;64N`%1I96YE('%U92!I;G1R;V1U8VER(&QA(%523"!A(&QA('%U92!A
M<'5N=&$@97-T92!V[6YC=6QO`%1I96YE('%U92!S96QE8V-I;VYA<B!U;B!S
M97)V:61O<B!A(&5L:6UI;F%R+@!4:65N92!Q=64@97-P96-I9FEC87(@=6X@
M=7-U87)I;R!A(&5L:6UI;F%R+@!4:65N92!Q=64@97-P96-I9FEC87(@=6X@
M=7-U87)I;R!A(&5L:6UI;F%R+@!4:65N92!Q=64@97-P96-I9FEC87(@96P@
M=7-U87)I;R!A(&'Q861I<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S
M=6%R:6\@82!A8W1U86QI>F%R+@!4:65N92!Q=64@97-P96-I9FEC87(@<77I
M(&%C8VGS;B!S92!E:F5C=71A<N$N`%1I96YE('%U92!I;G1R;V1U8VER('5N
M(&YU979O(&YO;6)R92!D92!C871E9V]R[6$N`%1I96YE('%U92!I;G1R;V1U
M8VER('5N(&[Z;65R;R!D92!T96SI9F]N;R!I=&%L:6%N;P!(82!E>'!I<F%D
M;R!S=2!S97-I\VX@)7,N(%9U96QV82!A(&EN:6-I87(@<V5S:?-N+@!3=2!D
M:7)E8V-I\VX@9&4@8V]R<F5O`$1I<F5C8VGS;B!$93H`4W4@:6YF;W)M86-I
M\VX`2&$@8V%M8FEA9&\@<W4@9&ER96-C:?-N(&1E($EN=&5R;F5T(&1E<V1E
M(&5L(&-O;6EE;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R(')A>F]N97,@9&4@
M<V5G=7)I9&%D('1I96YE('%U92!V;VQV97(@82!I;FEC:6%R(&QA('-E<VGS
M;BX`4W4@;F]M8G)E`%-U(&UO=&]R(&1E(&%U=&5N=&EF:6-A8VGS;B!N;R!P
M97)M:71E(&'Q861I<B!U<W5A<FEO<RX@4VD@<75I<VEE<F$@=7-A<B!(;W)D
M92!P87)A(&%D;6EN:7-T<F%R(&-U96YT87,@9&4@=7-U87)I;RP@=&5N9'+A
M('%U92!U=&EL:7IA<B!U;B!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@9&ES
M=&EN=&\N`%-U(&UO=&]R(&1E(&%U=&5N=&EF:6-A8VGS;B!N;R!P97)M:71E
M(&QI<W1A<B!U<W5A<FEO<RP@;R!S92!H82!D97-H86)I;&ET861O(&QA(&-A
M<F%C=&5R[7-T:6-A('!O<B!A;&?Z;B!M;W1I=F\N`%!A<F5C92!Q=64@:&$@
M8V%M8FEA9&\@<W4@;F%V96=A9&]R(&1E<V1E(&5L(&-O;6EE;GIO(&1E('-U
M('-E<VGS;B`E<RX@4&]R(')A>F]N97,@9&4@<V5G=7)I9&%D('1I96YE('%U
M92!V;VQV97(@82!I;FEC:6%R(&QA('-E<VGS;BX`4W4@;F%V96=A9&]R(&YO
M(&%D;6ET92!E<W1A(&-A<F%C=&5R[7-T:6-A+@!%;"!N879E9V%D;W(@;F\@
M861M:71E(&5S=&$@;W!C:?-N(&1E(&EM<')E<VGS;BX@4')E<VEO;F4@0V]N
M=')O;"]#;VUA;F1O("L@4"!P87)A(&EM<')I;6ER+@!:;VYA(&AO<F%R:6$@
M86-T=6%L.@!392!H82!C86UB:6%D;R!S=2!I9&5N=&ED860@<&]R(&]M:7-I
M\VXN`$ED96YT:61A9"!P;W(@;VUI<VGS;CH`3F]M8G)E(&-O;7!L971O.@!3
M92!H82!A9V]T861O('-U('1I96UP;R!D92!C;VYE>&GS;BX`3&$@;G5E=F$@
M8V]N=')A<V7Q82!P87)A("5S(&5S.B`E<P!392!H86X@86-T=6%L:7IA9&\@
M<W5S(&]P8VEO;F5S('/S;&\@<&]R(&QA(&1U<F%C:?-N(&1E(&QA('-E<VGS
M;BX`4V4@:&%N(&%C='5A;&EZ861O('-U<R!O<&-I;VYE<RX`4V4@:&$@<F5A
M:G5S=&%D;R!S=2!C;VYT<F%S9?%A`%-E(&AA(')E86IU<W1A9&\@<W4@8V]N
M=')A<V7Q82P@8V]M<')U96)E(&5L(&-O<G)E;R!E(&EN:6-I92!S97-I\VX@
M8V]N('-U(&YU979A(&-O;G1R87-E\6$N`$QA(&-O;G1R87-E\6$@:&$@97AP
M:7)A9&\N`%-E<G9I9&]R97,@<F5M;W1O<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6FEP<'D`6T]C=6QT87(@=&5X=&\@8VET861O70!;
M26YF;W)M92!D92!P<F]B;&5M85T`6TUO<W1R87(@=&5X=&\@8VET861O("T`
M6TUO<W1R87(@=&5X=&\@8VET861O("T@)7,@;.UN96%S70!;;.UN96$@)7,@
M9&4@)7-=`%]!9&UI;FES=')A8VGS;@!?0TQ)`,%R7V)O;"!D871O<P!%7VQI
M;6EN87(@9FEL80!?1W)U<&]S`$%?>75D80!0<F]P:65D861E<R!D92!?:6UA
M9V5N+BXN`%]);FEC:6%R('-E<VGS;@!?4V%L:7(`36]D:69I8V%R(%]V[6YC
M=6QO+BXN`%]/<&-I;VYE<P!?4')I=FEL96=I;W,`7T5L:6UI;F%R(';M;F-U
M;&\N+BX`0V]N7V9I9W5R86,N`%!R;W!I961A9&5S(&1E(%]T86)L82XN+@!?
M57-U87)I;W,`9&ER96-C:6]N97,`9&5S=&EN871A<FEO(&1E<V-O;F]C:61O
M`&%G96YD80!C86QM80!N;R!S92!P=65D92!C<F5A<B!E;"!A<F-H:79O(&1E
M(&1E<W1I;F\`;F\@<V4@<'5E9&4@86)R:7(@96P@;W)I9V5N`'!U;'-E(&%Q
M=>T`97)R;W(@9&4@;.UN96$@9&4@8V]M86YD;P!E<G)O<B!D92!C;VYF:6=U
M<F%C:?-N`&9A;'1A('5N(&%R8VAI=F\@8W+M=&EC;R!D96P@<VES=&5M80!E
M<G)O<B!D92!F;W)M871O(&1E(&1A=&]S`&UO9&EF:6-A<@!E;G1R861A(&YO
M(&5N8V]N=')A9&$`9&5S8V5N<V\`87)C:&EV;P!D96P@)7,@*"5S*2!A(&QA
M<R`E<R`E<P!V96YT;W-O`&@Z`&AH`&YO;6)R92!D92!A;F9I=')I\VX@9&5S
M8V]N;V-I9&\`:6YM961I871A;65N=&4`96X@;.UN96$`97)R;W(@9&4@96YT
M<F%D82]S86QI9&$`97)R;W(@9&4@<V]F='=A<F4@:6YT97)N;P!L[6YE87-=
M`&/S9&EG;R!D92!E<G)O<B!M:VES;V9S("5D(&%L(')E86QI>F%R($E33RX`
M;6T`;F]M8G)E`'-I;B!D97-A<G)O;&QA<@!A^FX@;F\@<V4@:&$@9&5S87)R
M;VQL861O`&YO=&%S`'!O<F-E;G1A:F4`<')I=FEL96=I;R!D96YE9V%D;P!P
M[7AE;&5S`&5R<F]R(')E;6]T;R!D92!P<F]T;V-O;&\`96X@875M96YT;P!S
M97)V:6-I;R!N;R!D:7-P;VYI8FQE+@!M;W-T<F%R(&1I9F5R96YC:6%S`'-M
M<S)E;6%I;"!P;W(@2%144`!S<P!E<W1A8FQE`&5R<F]R(&1E;"!S:7-T96UA
M`'1A<F5A<P!F86QL;R!T96UP;W)A;`!E<V-R:6)A(&1O<R!V96-E<R!L82!C
M;VYT<F%S9?%A('!A<F$@8V]N9FER;6%R;&$`=6YI9FEC861O`'-I;B!N;VUB
M<F4`=7-U87)I;R!S96QE8V-I;VYA9&\`=D-A<F0`=SH`=V5A=&AE<BYC;VT`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O97-?15,O:&5L<"YX;6P`````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`T,S(S`#$P-#$W,S8R-S<V`#`R,#,S-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/WAM;"!V
M97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]E<U]%
M4R]H96QP+GAM;"QV(#$N,R`R,#`T+S$R+S$P(#$V.C$W.C,W(&IA;B!%>'`@
M)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B
M/@H\=&ET;&4^3&$@<"8C>$4Q.V=I;F$@9&5L('!O<G1A;#PO=&ET;&4^"B`\
M<&%R83X*("!%<W1A('`F(WA%,3MG:6YA(&1E;"!P;W)T86P@<')O<&]R8VEO
M;F$@=6X@<B8C>$4Q.W!I9&\@<F5S=6UE;B!D92!T;V1A('-U(&EN9F]R;6%C
M:28C>$8S.VX*("!I;7!O<G1A;G1E+B!0;W(@96IE;7!L;RP@<'5E9&4@;6]S
M=')A<B!C=28C>$4Q.VYT;W,@;65N<V%J97,@;G5E=F]S('1I96YE(&5N(&5L
M"B`@8G5Z)B-X1C,[;B!D92!%;G1R861A+"!A8V]N=&5C:6UI96YT;W,@:6YM
M:6YE;G1E<R!D92!L82!A9V5N9&$L('1A<F5A<R!P96YD:65N=&5S"B`@9&4@
M;&$@;&ES=&$@9&4@=&%R96%S+"!T:71U;&%R97,@9&4@<V5R=FEC:6]S(&1E
M(&YO=&EC:6%S('-E;&5C8VEO;F%D;W,L(&5T8RX*("!-=6-H;W,@9&4@97-T
M;W,@<F5S)B-X1D$[;65N97,@<&]D<B8C>$4Q.VX@8V]N=&5N97(@871A:F]S
M(&$@86-T:79I9&%D97,@=7-U86QE<R!T86QE<PH@(&-O;6\@;&$@<F5D86-C
M:28C>$8S.VX@9&4@;G5E=F]S(&UE;G-A:F5S+"!L82!C<F5A8VDF(WA&,SMN
M(&1E(&%C;VYT96-I;6EE;G1O<R!D92!L80H@(&%G96YD82!O('1A<F5A<R!N
M=65V87,L(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@($QO<R!C;VYT96YI9&]S
M(&1E(&5S=&$@<"8C>$4Q.V=I;F$@9&5L('!O<G1A;"!S92!P=65D96X@<&5R
M<V]N86QI>F%R(&UE9&EA;G1E(&5L"B`@8F]T)B-X1C,[;B!$:7-T<FEB=6-I
M)B-X1C,[;BX@4&]R(&5J96UP;&\L('!U961E(&5L96=I<B!Q=28C>$4Y.R!E
M;&5M96YT;W,@:6YC;'5I<B!E;B!E<W1A"B`@<"8C>$4Q.V=I;F$@9&5L('!O
M<G1A;"!A<R8C>$5$.R!C;VUO(&5L(&]R9&5N(&5N(&5L('%U92!S92!M;W-T
M<F%R)B-X13$[;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA
M=F)A<B(@<W1A=&4](G5P=&]D871E(B!M9#4](F(X8V8P864Q.64U-V1F83!C
M,F(Y-C)E-3$V-S@R9C0W(CX*/'1I=&QE/DQA(&)A<G)A(&1E(&YA=F5G86-I
M)B-X1C,[;B!D92!A<&QI8V%C:6]N97,\+W1I=&QE/@H@/'!A<F$^"B`@16X@
M96P@;&%D;R!I>G%U:65R9&\@9&4@;&$@<"8C>$4Q.V=I;F$@=V5B('-E(&5N
M8W5E;G1R82!L82!B87)R82!D92!N879E9V%C:28C>$8S.VX@9&4*("!A<&QI
M8V%C:6]N97,N(%!U;'-E(&QO<R!I8V]N;W,@9&4@9&EC:&$@8F%R<F$@<&%R
M82!C86UB:6%R('(F(WA%,3MP:61A('D@9B8C>$4Q.V-I;&UE;G1E"B`@96YT
M<F4@;&%S(&%P;&EC86-I;VYE<R!D:7-P;VYI8FQE<RX*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X
M8C)D,#`B/@H@("`@/'1I=&QE/E!R969E<F5N8VEA<SH@36%N=&5N:6UI96YT
M;SH@4F5A;&EZ87(@;6%N=&5N:6UI96YT;SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@(%-I(&1E<V5A(')E86QI>F%R(&QA<R!O<&5R86-I;VYE<R!D92!M86YT
M96YI;6EE;G1O(&%L(&EN:6-I87(@;&$@<V5S:28C>$8S.VXL"B`@("!S96QE
M8V-I;VYE(&5S=&$@8V%S:6QL82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U
M<'1O9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V
M92(^"B`@("`\=&ET;&4^4')E9F5R96YC:6%S.B!-86YT96YI;6EE;G1O.B!#
M;VYF:7)M87(@;6%N=&5N:6UI96YT;SPO=&ET;&4^"B`@("`\<&%R83X*("`@
M(%-I('%U:7-I97)A(&-O;F9I<FUA<B!L87,@=&%R96%S(&1E(&UA;G1E;FEM
M:65N=&\@86YT97,@9&4@<75E('-E(&5J96-U=&5N+`H@("`@<V5L96-C:6]N
M92!E<W1A(&-A<VEL;&$N(%-I('-E(&1E:F$@<VEN('-E;&5C8VEO;F%R+"!S
M92!E:F5C=71A<B8C>$4Q.VX*("`@(&%U=&]M)B-X13$[=&EC86UE;G1E(&%L
M(&EN:6-I87(@;&$@<V5S:28C>$8S.VX@=&]D87,@;&%S('1A<F5A<R!D92!M
M86YT96YI;6EE;G1O"B`@("!P96YD:65N=&5S('-I;B!L82!P;W-I8FEL:61A
M9"!D92!C86YC96QA<FQA<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O971?144O````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<V
M`#`Q-C8U,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E=%]%12],
M0U]-15-304=%4R\`````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C(W-S8`,#(P-#,V`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+V5T7T5%+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q-S`Q,``Q,#0Q-S,V,C<W-@`P,C(P-S``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````WA($E0``
M``"`````'````!P$``"M````'`@```````#0"@``*````-$*```(````^@H`
M``4````#"P```P````D+```/````#0L```@````="P``"````"8+```9````
M+PL```<```!)"P``#@```%$+```%````8`L``!\```!F"P``)P```(8+```L
M````K@L``"H```#;"P``$0````8,```(````&`P```@````A#```!@```"H,
M```5````,0P```H```!'#```#````%(,```'````7PP``!````!G#```*0``
M`'@,```"````H@P```4```"E#```$````*L,```&````O`P``!0```###```
M+P```-@,```/````"`T``"8````8#0``!````#\-```%````1`T```T```!*
M#0``!0```%@-```0````7@T``!````!O#0``#P```(`-```+````D`T```\`
M``"<#0``#````*P-```/````N0T``"$```#)#0```P```.L-```,````[PT`
M`!0```#\#0``!@```!$.```$````&`X```P````=#@``"@```"H.```%````
M-0X``!(````[#@``$````$X.```(````7PX``!````!H#@``&@```'D.```&
M````E`X```<```";#@```@```*,.```$````I@X```\```"K#@``!P```+L.
M```'````PPX```<```#+#@``!````-,.```'````V`X```4```#@#@``&@``
M`.8.```%`````0\```<````'#P``$0````\/```(````(0\``!4````J#P``
M'@```$`/```+````7P\``!H```!K#P``!0```(8/```H````C`\``"D```"U
M#P``$P```-\/```$````\P\```8```#X#P``"P```/\/```1````"Q````0`
M```=$```#````"(0```:````+Q```!<```!*$```%P```&(0```;````>A``
M`!D```"6$```'P```+`0```3````T!````0```#D$```$````.D0```7````
M^A````<````2$0``!0```!H1```A````(!$``!P```!"$0``!0```%\1```@
M````91$``"8```"&$0``#````*T1```3````NA$```P```#.$0``"````-L1
M```4````Y!$```<```#Y$0``!@````$2```-````"!(```L````6$@``#```
M`"(2```*````+Q(```(````Z$@``!@```#T2``!%````1!(``"8```"*$@``
M)0```+$2```P````UQ(``!`````($P``<P```!D3```?````C1,``!````"M
M$P``#P```+X3``!<`0``SA,``!D````K%0``"````$45```%````3A4```0`
M``!4%0``$@```%D5```)````;!4```T```!V%0``(0```(05```'````IA4`
M``8```"N%0``!0```+45```;````NQ4``"````#7%0``'@```/@5```:````
M%Q8``!(````R%@``"0```$46```(````3Q8```4```!8%@``!0```%X6```-
M````9!8```D```!R%@``!0```'P6```0````@A8``"D```"3%@```@```+T6
M```(````P!8```\```#)%@``!P```-D6```2````X18``"@```#T%@``#@``
M`!T7```N````+!<```4```!;%P``!@```&$7```0````:!<```0```!Y%P``
M%````'X7```5````DQ<``!,```"I%P``$P```+T7```6````T1<```P```#H
M%P``#P```/47```B````!1@```0````H&```"P```"T8```/````.1@```8`
M``!)&````P```%`8```.````5!@```X```!C&```!0```'(8```3````>!@`
M`!(```",&```!````)\8```8````I!@``"<```"]&```"@```.48```*````
M\!@```(```#[&````P```/X8```.`````AD```<````1&0``!0```!D9```)
M````'QD```0````I&0``!````"X9```,````,QD``"4```!`&0``!P```&89
M```)````;AD```@```!X&0``"````($9```:````BAD``!,```"E&0``!```
M`+D9```-````OAD```<```#,&0``$P```-09```D````Z!D``!,````-&@``
M`P```"$:```'````)1H```P````M&@``$@```#H:```$````31H``!(```!2
M&@``%P```&4:```6````?1H``!8```"4&@``&````*L:```0````Q!H``!0`
M``#5&@``&0```.H:```%````!!L``!,````*&P``$P```!X;```*````,AL`
M``0````]&P``(````$(;```?````8QL```@```"#&P``'@```(P;```J````
MJQL``!````#6&P``#@```.<;```2````]AL```P````)'```%````!8<```'
M````*QP```P````S'```$@```$`<```1````4QP```\```!E'```"@```'4<
M```"````@!P```L```"#'```+@```(\<```I````OAP``"8```#H'```-0``
M``\=```)````11T``'<```!/'0``'P```,<=```0````YQT```\```#X'0``
M`0`````````%`````````",```!`````7``````````J````'0```$4`````
M````8P`````````P````7@```%\````_````8```````````````;```````
M```7````4P```#4````Z````20````````!(````9@```'0```!H````6@``
M``@`````````<0`````````.````)``````````R````1P```"\````#````
M`````"P````)````6P```#@`````````@````"4````K````(@`````````9
M````50``````````````5P```"8```!.````6````&0````/````%```````
M```8````0@````P```!-`````````'(````G````=@``````````````!P``
M``````!4````70```%(````<````8@`````````1````40```#<```!U````
M``````````!Z````````````````````>````'<````^````/````&\````"
M````,0```!4```!9````'P```'T```!!````?````',```!0``````````8`
M```@````$P```'L`````````$````!L```!N````(0``````````````````
M`&4```!Y````"@```!(```!K````-````!X```!6````?P`````````:````
M2P```#,`````````-@```&D```````````````0````[````:@```$\`````
M`````````#D```!,```````````````-````"P```&<`````````/0``````
M```I````+0```'X````6````<````$8````H````1````"X`````````2@``
M`$,```!A````;0``````````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`R-"!H;W5R<P!!32]030!!9&0`061D(&$@;F5W('5S
M97(Z`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`061D<F5S<P!!9&UI;FES=')A=&EO;@!!;&EA<P!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`079A:6QA8FQE(&9I96QD<SH`0FER=&AD87D`0V%L96YD
M87(`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L
M;W-E(%=I;F1O=P!#;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&5F
M875L="!)9&5N=&ET>0!$96QE=&4`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$5D:70`16UA:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S
M`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA
M;7!L92!V86QU97,Z`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!&87@`1FEL92!-86YA9V5R`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M<P!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI<W0@2&5L
M<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]G(&EN`$QO
M9R!O=70`34T`36%I;`!-871C:&EN9R!F:65L9',`365M8F5R<P!-97-S86=E
M`$UO;G1H;'D`3F%M90!.971W;W)K`$YE=F5R`$YO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D`$YO=&5S`$]P=&EO;G,`3W1H97(@26YF;W)M871I;VX`4&%S
M<W=O<F0`4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;@!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5A9`!296UO=F4`4F5M;W9E
M('!A:7(`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA
M=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-H
M;W<`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M=6-C97-S`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R($%D;6EN:7-T
M<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5<V5R<R!I;B!T:&4@<WES
M=&5M.@!787)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@
M4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R
M*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TP-BTP,B`Q,#HT.2LP,C`P
M"DQA<W0M5')A;G-L871O<CH@5&]O;6%S($%A<R`\=&]O;6%S+F%A<T!M86EL
M+F5E/@I,86YG=6%G92U496%M.B!%<W1O;FEA;B`\9&5V0&QI<W1S+FAO<F1E
M+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$S"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:70*`"5S($AO;VQD=7-T]O9D("T@:VEN;FET=7,`,C0@='5N
M9&D`14PO4$P`3&ES80!,:7-A('5U<R!K87-U=&%J83H`3&ES82!P86%R`$QI
M<V$@:V%S=71A:F$`2V%S=71A:F%T92!L:7-A;6EN92!P;VQE(&QU8F%T=60N
M`$%A9')E<W,`2&%L9'5S`$%L:6%S`%-I<V5S=&%T:2!L=6)A;6%T=2!VY.1R
M='5S+@!+871S92!K=7-T=71A9&$@;VQE;6%T=70@9W)U<'!I+@!+871S92!K
M=7-T=71A9&$@;VQE;6%T=70@;'5B82X`2V%T<V4@;75U=&$@;VQE;6%T=70@
M;'5B82X`2V%S=71A=&%V860@=N1L:F%D`%/\;FYI<.1E=@!+86QE;F1E<@!,
M;V]B=0!,;V]B=0!-;V)I:6QT96QE9F]N`%-U;&4@86ME;@!&:7)M80!+:6YN
M:71A('-A;&%S]6YA`$5I('-U=61A(&OD:79I=&%D82!H;V]L9'5S=/;V(&UO
M;V1U;&ET("5S`%!0`$EG82!PY&5V`%9A:6ME:61E;G1I=&5E=`!+=7-T=71A
M`$MI<FIE;&1A('!R;V)L965M:0#<:W-I:V%S:F%D(&QO9VET:2!A9&UI;FES
M=')A871O<FD@:F%O:W,N`$5K<F%A;FD@<V5A9&5D`,1R82#\<FET82!M86EN
M=&5N86YC92YP:'`@9F%I;&D@;W1S92!KY&EV:71A9&$`375U9&$`12UM86EL
M`%1U;&5M=7,@;VX@=/QH:2X`5FEG80!)9V$@,34@;6EN=71I('1A9V%N=`!)
M9V$@,S`@<V5K=6YD:2!T86=A;G0`26=A(#4@;6EN=71I('1A9V%N=`!)9V%L
M('-I<W-E;&]G:6UI<V5L`$EG82!P;V]L92!T=6YN:2!T86=A;G0`2V]R9"!M
M:6YU=&ES`$[D:61I<W;DY')T=7-E9`!%:2!S86%N=60@_&AE;F1U<W0@3$1!
M4"!S97)V97)I9V$N`$9A:W,`1F%I;&EH86QD=7(`1W)U<'!I9&4@:&%L9'5S
M`$=R=7!I9`!!8FD`2V]D=6YE(&%A9')E<W,`2V]D=6YE('1E;&5F;VX`2&]R
M9&4`26UP;W)D:71U9"!VY&QI.B`E<P!);7!O<F1I='5D(';D;&IA9#H`2V5E
M;`!!8FEI;F9O('1E96UA9&4@;FEM96MI<FD`2V%S=71A:F%T92!N:6UE:VER
M:F$@<&]L92!L=6)A='5D(&[D:&$N`$QO9VD@<VES<V4`3&]G:2!VY&QJ80!+
M2P!)35``4V]B:79A9"!VY&QJ860`3&EI:VUE9`!496%D90!+;W)D(&MU=7,`
M3FEM:0!6]7)K`$UI='1E(&MU;F%G:0!%:2!T86=A<W1A='5D(&MO<G)E:W1S
M96ED(%A-3"!A;F1M96ED`$WD<FMM960`2.3D;&5S='5S`$UU=2!I;F9O`%-A
M;&%S]6YA`%-A;&%S]6YA9"!P96%V860@:VQA<'!I;6$N`$OD:79I=&$@:&]O
M;&1U<W3V]F0`3&]A9`!,=6)A9&4@:&%L9'5S`%1E;&5F;VX`2VER:F5L9&$@
M<')O8FQE96UI+@!3:7-E<W1A(&]M82!K87-U=&%J86YI;6D@:F$@<V%L87/U
M;F$`4')O8FQE96UI(&MI<FIE;&1U<P!,;V4`165M86QD80!%96UA;&1A('!A
M87(`5&%G87-I(&CDY&QE<W1U<W-E`%)O;&P`4V%L=F5S=&$@:.3D;&5S='5S
M`%9A;&D@:W5U<.1E=F$@97)A;&1A:F$Z`%9A;&D@:W5U<.1E=F$@9F]R;6%A
M=#H`5F%L:2!K96QL86%J82!F;W)M86%T.@!686QI(&MA:W,@<V]B:79A="!V
MY&QJ82X`5F%L:2!VY')V:7-K965M+@!686QI(&]M82!L96UM:6MK965L.@!3
M86%D82!P<F]B;&5E;6D@:VER:F5L9'5S`$[D:71A`$KD=&$@:&]O;&1U<R!V
M86AE;&4`17)I;>1R:VED92!S:7-E<W1U<P!,Y&MS(&MO<F1A`%3V]F0`4V5E
M(&%R=B!P96%B(&]L96UA(';D:&5M86QT(/QK<RX`4V5L;&4@:V]H82!P96%L
M('!E86(@;VQE;6$@87)V+@!096%L:VER:0!%:2!S86$@_&AE;F1U<W0@4U%,
M('-E<G9E<FEG82X`4V5D82!7;W)D:2!D;VMU;65N=&D@;VX@=O5I;6%T=2!T
M]6QG96YD861A`%3\:&ES=&$@;75U='5S960`2V%S=71A:F%H86QD=7,`2V%S
M=71A:F$@:.3D;&5S='5S`$MA<W5T86IA;FEM:0!+87-U=&%J860@<_QS=&5E
M;6ES.@!(;VEA='5S`$MO<F0@;N1D86QA<P!497)E('1U;&5M87-T("5S+6D`
M5&5R92!T=6QE;6%S="P@)7,`5/;V:V]H82!A861R97-S`%3V]G1E;&5F;VX`
M04$`2V]R9"!A87-T87,`16YN92!S86%T;6ES="!O;&5K<R!T87)K('!R;V)L
M965M:2!K:7)J96QD861A+@!096%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI
M9&$@965M86QD861A+@!096%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@
M;&ES861A+@!3:6YU("5S('-E<W-I;V]N(&]N(&%E9W5N=60N(%!A;'5N(&QO
M9VD@=75E<W1I('-I<W-E+@!3:6YU(&EN9F\`4VEN=2!A=71E;G1I;6ES<_QS
M=&5E;2!E:2!V]6EM86QD82!K87-U=&%J871E(&YI;65K:7)J82!NY&AA+"!V
M]6D@;VX@<V5E(';U:6UA;'5S(&UI;F=I;"!M=75L('#U:&IU<V5L(';D;&IA
M(&S\;&ET871U9"X`4VEN=2!M=75D871U<V5D(&]N('-A;'9E<W1A='5D+@!;
M2&]R9&4@<')O8FQE96U=`%MR:61A("5S("5S+7-T70``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E=%]%12]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`T
M,3<S-C(W-S8`,#(P,S$V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D
M93H@:&]R9&4O;&]C86QE+V5T7T5%+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O
M,C<@,C`Z,C(Z,34@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60]
M(G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E
M/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@
M82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R
M;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N
M97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@
M=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO
M=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S
M('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R
M:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U
M;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A
M9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T
M8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O
M<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T
M=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M
M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S
M(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE
M/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R
M83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES
M('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T
M:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N
M9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI
M8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F
M97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*
M("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O
M>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O
M;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O
M;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R
M=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL
M(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O
M(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9F%?25(O````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R
M-S<V`#`Q-C8U,``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F85])
M4B],0U]-15-304=%4R\`````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-S8`,#(P-#,U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V9A7TE2+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#,U-S<Q-P`Q,#0Q-S,V,C<W-@`P,C(Q,30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````"G!0``'````%0M``"+!P``C%H```````"X>```#@```+EX```/````
MR'@```T```#8>```"````.9X```+````[W@```P```#[>```!`````AY```D
M````#7D``"D````R>0``&0```%QY```F````=GD```P```"=>0``)````*IY
M```/````SWD```L```#?>0``#@```.MY```%````^GD``"@`````>@``"```
M`"EZ```*````,GH``!4````]>@``$@```%-Z```+````9GH``(4```!R>@``
M#@```/AZ```*````!WL```T````2>P``#@```"![```1````+WL```T```!!
M>P``#````$][```-````7'L```8```!J>P``"@```'%[```/````?'L``!@`
M``",>P``#````*5[```.````LGL```X```#!>P``"````-![```N````V7L`
M`!H````(?```,@```"-\```X````5GP``%0```"/?```40```.1\``!:````
M-GT``%<```"1?0``-````.E]```-````'GX```<````L?@``"@```#1^```/
M````/WX```4```!/?@``$0```%5^```(````9WX```D```!P?@``"0```'I^
M```E````A'X``"````"J?@``$P```,M^```0````WWX```\```#P?@``"@``
M``!_```#````"W\```\````/?P``%````!]_```)````-'\```T````^?P``
M$@```$Q_```>````7W\```\```!^?P``"@```(Y_```/````F7\```@```"I
M?P``)````+)_```4````UW\``!8```#L?P``"`````.````9````#(````<`
M```F@```#````"Z````L````.X````X```!H@````P```'>````%````>X``
M``4```"!@```"@```(>````#````DH```!<```"6@```"@```*Z````/````
MN8````X```#)@```&````-B````C````\8````X````5@0``%````"2!```7
M````.8$``!<```!1@0``%P```&F!```3````@8$```\```"5@0``'P```*6!
M```/````Q8$```8```#5@0``"P```-R!```0````Z($``!4```#Y@0``%0``
M``^"```'````)8(``!`````M@@``!0```#Z"```5````1((``!$```!:@@``
M#````&R"```[````>8(``!0```"U@@```P```,J"```Y````SH(``!(````(
M@P``)P```!N#```L````0X,``"H```!P@P``)0```)N#```*````P8,```8`
M``#,@P``+P```-.#```W`````X0``"X````[A```50```&J$```M````P(0`
M`"T```#NA```+0```!R%``!`````2H4``",```"+A0``(P```*^%```M````
MTX4``#,````!A@``%0```#6&```9````2X8``"D```!EA@``)````(^&```1
M````M(8```H```#&A@``$````-&&```6````XH8``!8```#YA@``%````!"'
M```(````)8<``"D````NAP``#@```%B'```*````9X<```0```!RAP``"0``
M`'>'```&````@8<``!$```"(AP``!P```)J'```$````HH<```8```"GAP``
M#0```*Z'```#````O(<```,```#`AP``%P```,2'```3````W(<```@```#P
MAP``!````/F'``!!````_H<``!H```!`B```(````%N(```5````?(@```8`
M``"2B```%0```)F(```8````KX@``"(```#(B```+@```.N(```=````&HD`
M`"$````XB0``5````%J)```I````KXD```<```#9B0``!P```.&)```5````
MZ8D```H```#_B0``#P````J*```-````&HH```\````HB@``#0```#B*```)
M````1HH``!0```!0B@``!@```&6*```=````;(H``!,```"*B@``%````)Z*
M```&````LXH``!0```"ZB@``5````,^*``!D````)(L```0```")BP``#@``
M`(Z+```%````G8L``!L```"CBP``&@```+^+```1````VHL``!$```#LBP``
M'````/Z+```J````&XP``"$```!&C```!0```&B,```3````;HP``!(```""
MC```"@```)6,```/````H(P``!$```"PC```$P```,*,```,````UHP```8`
M``#CC```!@```.J,```0````\8P``!$````"C0``!0```!2-```,````&HT`
M`!`````GC0``!0```#B-```-````/HT```8```!,C0``!P```%.-```-````
M6XT```<```!IC0``"P```'&-```'````?8T```D```"%C0``"0```(^-```*
M````F8T``!D```"DC0``#````+Z-```0````RXT``!(```#<C0``$P```.^-
M```K`````XX``#L````OC@``(````&N.```(````C(X``#8```"5C@``"```
M`,R.```&````U8X```0```#<C@``#@```.&.```>````\(X``!L````/CP``
M(0```"N/```>````38\``!D```!LCP``'@```(:/```=````I8\``!L```##
MCP``(````-^/```F`````)```!L````GD```'@```$.0```<````8I```"8`
M``!_D```,P```*:0```F````VI```"L````!D0``.````"V1```O````9I$`
M`!(```"6D0``*0```*F1```2````TY$``*(```#FD0``%@```(F2```C````
MH)(``"@```#$D@``*0```.V2```H````%Y,``!\```!`DP``(````&"3```E
M````@9,``"@```"GDP``,````-"3``"2`````90``"$```"4E```'````+:4
M```F````TY0``$$```#ZE```#````#R5```'````294```<```!1E0``!@``
M`%F5```-````8)4``!````!NE0``$@```'^5```3````DI4``!(```"FE0``
M#````+F5```.````QI4```\```#5E0``$P```.65```-````^94``"@````'
ME@```P```#"6```-````-)8``!$```!"E@``%P```%26```;````;)8```(`
M``"(E@``!0```(N6```0````D98```0```"BE@``#0```*>6```.````M98`
M``,```#$E@``#@```,B6```(````UY8```\```#@E@``#P```/"6```'````
M`)<```T````(EP``$````!:7```-````)Y<```L````UEP``!@```$&7```,
M````2)<``!$```!5EP``&0```&>7```+````@9<```T```"-EP``(@```)N7
M```;````OI<``#0```#:EP``"@````^8```8````&I@``!D````SF```%@``
M`$V8```-````9)@``!0```!RF```"P```(>8```B````DY@``"\```"VF```
M"P```.:8```)````\I@``!D```#\F```"P```!:9```7````(ID``!<````Z
MF0``"0```%*9```6````7)D```\```!SF0``&0```(.9```6````G9D```X`
M``"TF0``&````,.9```-````W)D``"8```#JF0``0P```!&:```(````59H`
M``L```!>F@``+P```&J:```.````FIH```4```"IF@``!@```*^:```#````
MMIH```0```"ZF@``"@```+^:```*````RIH```\```#5F@``$````.6:```7
M````]IH``!$````.FP``&0```"";```7````.IL```D```!2FP``"@```%R;
M```"````9YL```4```!JFP``#0```'";```;````?IL``!<```":FP``"0``
M`+*;```.````O)L```T```#+FP``$@```-F;```X````[)L``"`````EG```
M"````$:<```.````3YP``'L```!>G```&````-J<```%````\YP``!@```#Y
MG```&0```!*=```;````+)T``!D```!(G0``!@```&*=```&````:9T``!``
M``!PG0``#P```(&=```0````D9T```\```"BG0``"P```+*=```/````OIT`
M``P```#.G0``#P```-N=```'````ZYT```8```#SG0``#@```/J=```,````
M"9X```\````6G@``"````":>```(````+YX``!,````XG@``'@```$R>```A
M````:YX``"````"-G@``&0```*Z>```7````R)X``"4```#@G@``%P````:?
M```$````'I\```P````CGP```P```#"?```(````-)\```L````]GP``$```
M`$F?```3````6I\``!0```!NGP``#````(.?```)````D)\```X```":GP``
M"P```*F?```;````M9\```<```#1GP``"@```-F?```-````Y)\```D```#R
MGP``!0```/R?```#`````J```!@````&H```"@```!^@```$````*J```"8`
M```OH```#@```%:@```5````9:````4```![H```!P```(&@```,````B:``
M``@```"6H```"@```)^@```&````JJ````@```"QH````@```+J@```&````
MO:````0```#$H```"0```,F@```0````TZ````D```#DH```"0```.Z@```:
M````^*````@````3H0``&0```!RA```.````-J$```H```!%H0```@```%"A
M```-````4Z$```D```!AH0``$@```&NA```4````?J$``!T```"3H0``!@``
M`+&A```1````N*$```D```#*H0``!````-2A```Y````V:$``#T````3H@``
M.@```%&B```>````C*(```X```"KH@``!````+JB```&````OZ(``!4```#&
MH@``!@```-RB```$````XZ(``!$```#HH@``!@```/JB```*`````:,``"(`
M```,HP``!````"^C```%````-*,```0````ZHP``#````#^C```.````3*,`
M``H```!;HP``!0```&:C```Z````;*,``#````"GHP``-0```-BC```I````
M#J0``#@````XI```*0```'&D```_````FZ0``"X```#;I```+0````JE```?
M````.*4```\```!8I0``$@```&BE```+````>Z4``"8```"'I0``*0```*ZE
M```D````V*4``"8```#]I0``"````"2F```*````+:8``"`````XI@``(```
M`%FF```F````>J8```H```"AI@``&0```*RF```I````QJ8``!(```#PI@``
M"@````.G```,````#J<```\````;IP``$````"NG``!`````/*<``'````!]
MIP``9@```.ZG```.````5:@```D```!DJ```"@```&ZH```2````>:@``!,`
M``",J```#````*"H```&````K:@```\```"TJ```$@```,2H```0````UZ@`
M`!$```#HJ```'````/JH```C````%ZD``&H````[J0``#P```*:I```0````
MMJD```0```#'J0``"P```,RI```@````V*D``!0```#YJ0``#`````ZJ```,
M````&ZH```\````HJ@``%0```#BJ```I````3JH``"H```!XJ@``)@```*.J
M```G````RJH``"D```#RJ@``*@```!RK```9````1ZL``$(```!AJP``$0``
M`*2K```2````MJL``!,```#)JP``%````-VK```/````\JL``!8````"K```
M%P```!FL```0````,:P``!$```!"K```-````%2L```3````B:P``!(```"=
MK```-0```+"L```4````YJP```<```#[K```#`````.M```@````$*T``!0`
M```QK0``$0```$:M```7````6*T``!P```!PK0``$P```(VM```1````H:T`
M`!H```"SK0``'@```,ZM```:````[:T``!$````(K@``%P```!JN```4````
M,JX``!<```!'K@``%0```%^N```)````=:X``!````!_K@``$0```)"N```&
M````HJX```8```"IK@``!P```+"N```6````N*X```8```#/K@``!````-:N
M```$````VZX```<```#@K@``#@```.BN```,````]ZX```P````$KP``#0``
M`!&O```.````'Z\``"@````NKP``#````%>O```/````9*\```H```!TKP``
M"````'^O```)````B*\``"L```"2KP``!````+ZO```/````PZ\```<```#3
MKP``"````-NO```)````Y*\``!0```#NKP``#`````.P```-````$+````X`
M```>L```%@```"VP```1````1+````,```!6L```!@```%JP```$````8;``
M``L```!FL```"P```'*P```-````?K````H```",L```$````)>P```/````
MJ+```!$```"XL```%P```,JP```*````XK```!$```#ML```!````/^P```/
M````!+$``#H````4L0``!0```$^Q```,````5;$``!X```!BL0``#@```(&Q
M```0````D+$```L```"AL0``#````*VQ```)````NK$```<```#$L0``"@``
M`,RQ```)````U[$```X```#AL0``$````/"Q```:`````;(```H````<L@``
M"@```">R```,````,K(```\````_L@``"````$^R```&````6+(```<```!?
ML@``!0```&>R```+````;;(``$<```!YL@``#0```,&R```)````S[(```0`
M``#9L@```P```-ZR```3````XK(``!,```#VL@``$P````JS```"````'K,`
M``0````ALP``)0```":S```#````3+,```4```!0LP``!````%:S```*````
M6[,```T```!FLP``:````'2S```)````W;,```P```#GLP``!0```/2S```&
M````^K,``!L````!M```+P```!VT```/````3;0``!,```!=M```&P```'&T
M```8````C;0``!<```"FM```#@```+ZT```#````S;0```@```#1M```!P``
M`-JT```*````XK0```L```#MM```!P```/FT``!1`````;4``!````!3M0``
M#````&2U```-````<;4``!H```!_M0``2@```)JU```&````Y;4```8```#L
MM0``!@```/.U```)````^K4``!@````$M@``%P```!VV```&````-;8```T`
M```\M@``5P```$JV```3````HK8``!,```"VM@```@```,JV```+````S;8`
M``@```#9M@``#0```.*V```*````\+8```X```#[M@``!P````JW```+````
M$K<```P````>MP``#0```"NW```,````.;<```D```!&MP``"0```%"W```*
M````6K<```<```!EMP``"0```&VW```'````=[<``!L```!_MP``$@```)NW
M```*````KK<``!8```"YMP``"0```-"W```0````VK<``!(```#KMP``!```
M`/ZW```1`````[@``!H````5N```%@```#"X```4````1[@``!<```!<N```
M'````'2X```9````D;@```<```"KN```!0```+.X```,````N;@```@```#&
MN```%P```,^X```,````Y[@``!\```#TN```&@```!2Y```3````+[D```0`
M``!#N0``"@```$BY```$````4[D```P```!8N0``!0```&6Y```"````:[D`
M`#@```!NN0``+````*>Y```2````U+D``"D```#GN0``,@```!&Z```*````
M1+H``"P```!/N@``+@```'RZ```S````J[H``#,```#?N@``.````!.[```/
M````3+L``!@```!<NP``$````'6[```/````AKL``!,```"6NP``%````*J[
M```2````O[L``!0```#2NP``%0```.>[```M````_;L``"T````KO```,0``
M`%F\```N````B[P``"\```"ZO```+````.J\```3````%[T```@````KO0``
M%P```#2]```(````3+T``"L```!5O0``(0```(&]```:````H[T```D```"^
MO0``10```,B]``!!````#KX```0```!0O@``$P```%6^```4````:;X``!,`
M``!^O@``"0```)*^```*````G+X```\```"GO@``$````+>^```'````R+X`
M``X```#0O@``!0```-^^```;````Y;X```@````!OP``!@````J_```4````
M$;\``!$````FOP``#@```#B_```X````1[\```(```"`OP``!@```(._```.
M````BK\```4```"9OP``!P```)^_```.````I[\```8```"VOP``*````+V_
M```,````YK\``!P```#SOP``*0```!#````7````.L```!\```!2P```7```
M`'+````4````S\```!\```#DP```$`````3!```'````%<$```X````=P0``
M#````"S!```,````.<$``!,```!&P0``"@```%K!```=````9<$``!D```"#
MP0``!0```)W!```1````H\$``!$```"UP0``)````,?!```5````[,$``!(`
M```"P@``#@```!7"```9````),(```@````^P@``"0```$?"```-````4<(`
M``H```!?P@``!P```&K"```/````<L(```L```""P@``&@```(["```*````
MJ<(```<```"TP@``#0```+S"```(````RL(``!X```#3P@``$@```/+"```L
M````!<,``!H````RPP``"0```$W#```*````5\,``!4```!BPP``!0```'C#
M```4````?L,```0```"3PP``$````)C#```&````J<,```<```"PPP``'@``
M`+C#```H````U\,```H`````Q```'`````O$```+````*,0``!H````TQ```
M%````$_$```$````9,0```4```!IQ```!@```&_$```&````=L0``!L```!]
MQ```-````)G$```T````SL0``"`````#Q0``*0```"3%```@````3L4``$$`
M``!OQ0``&@```+'%```H````S,4``"D```#UQ0``4````!_&```B````<,8`
M``@```"3Q@``!0```)S&```9````HL8``!D```"\Q@``*@```-;&```C````
M`<<``"X````EQP``-````%3'```(````B<<``!<```"2QP``"@```*K'```'
M````M<<``"$```"]QP``$````-_'```.````\,<```L```#_QP``!P````O(
M```3````$\@```@````GR```"P```##(```*````/,@``!0```!'R```,@``
M`%S(```%````C\@```4```"5R```%P```)O(```/````L\@```0```##R```
M"@```,C(```)````T\@```L```#=R```#0```.G(```,````]\@```X````$
MR0``!0```!/)```$````&<D```T````>R0``,@```"S)``!%````7\D``!<`
M``"ER0``'@```+W)```4````W,D``!0```#QR0``!P````;*```.````#LH`
M`"H````=R@``!@```$C*```,````3\H```T```!<R@``$0```&K*```+````
M?,H``#8```"(R@``"@```+_*```B````RLH```L```#MR@``#P```/G*```R
M````"<L```X````\RP``!0```$O+```.````4<L``!,```!@RP``!P```'3+
M```1````?,L``!,```".RP``!P```*++```4````JLL``!@```"_RP``!P``
M`-C+```%````X,L```P```#FRP``#````//+```2`````,P```0````3S```
M"@```!C,```+````(\P```P````OS```#@```#S,```.````2\P```4```!:
MS```!0```&#,```N````9LP``"8```"5S```(P```+S,```#````X,P``!@`
M``#DS```)0```/W,```-````(\T```D````QS0```P```#O-```'````/\T`
M``H```!'S0```@```%+-```2````5<T```0```!HS0``!P```&W-```,````
M=<T``%(```""S0``%P```-7-```'````[<T```8```#US0``#@```/S-```,
M````"\X```T````8S@``%0```";.```2````/,X```\```!/S@``%````%_.
M```*````=,X``!L```!_S@``$````)O.```+````K,X``&D```"XS@``&@``
M`"+/```7````/<\``"<```!5SP``&@```'W/```7````F,\``!L```"PSP``
M&0```,S/```?````YL\``!,````&T```"````!K0```(````(]````D````L
MT```#0```#;0```3````1-````,```!8T```1@```%S0```_````H]```#<`
M``#CT```5P```!O1```%````<]$``!\```!YT0``+P```)G1```(````R=$`
M``T```#2T0``+0```.#1```$````#M(``$\````3T@``)0```&/2```<````
MB=(```L```"FT@``'P```++2```=````TM(``"4```#PT@``(````!;3```D
M````-],``"````!<TP``"P```'W3```'````B=,```T```"1TP``#````)_3
M```&````K-,``#D```"STP``!P```.W3```)````]=,``!,```#_TP``!```
M`!/4```0````&-0```0````IU```"P```"[4```,````.M0``!(```!'U```
M$0```%K4```,````;-0``!H```!YU```#0```)34```4````HM0```X```"W
MU```&P```,;4```3````XM0``!P```#VU```*````!/5```&````/-4```<`
M``!#U0``$P```$O5```$````7]4``!<```!DU0``"@```'S5```,````A]4`
M``D```"4U0``!@```)[5```(````I=4```D```"NU0``"@```+C5```1````
MP]4```8```#5U0``#@```-S5```.````Z]4```L```#ZU0``"P````;6```"
M````$M8```<````5U@``!@```!W6```)````)-8```<````NU@``&@```#;6
M```[````4=8``"@```"-U@``-````+;6```5````Z]8```<````!UP``"```
M``G7```'````$M<```4````:UP``!P```"#7```.````*-<```D````WUP``
M!@```$'7```(````2-<```L```!1UP``!P```%W7```'````9=<``!P```!M
MUP``!P```(K7```(````DM<```@```";UP``!0```*37```0````JM<``!``
M``"[UP``!P```,S7```%````U-<``!````#:UP``%````.O7```+`````-@`
M``T````,V```%P```!K8```$````,M@```D````WV```"@```$'8```'````
M3-@```(```!4V```#@```%?8```?````9M@``",```"&V```,0```*K8```G
M````W-@``&0````$V0``%````&G9``!5````?MD``#@```#4V0``2@````W:
M``!;````6-H``"@```"TV@``.````-W:```H````%ML``"P````_VP``)P``
M`&S;```;````E-L``*D!``"PVP``(P```%K=```7````?MT``(4```"6W0``
M,````!S>```E````3=X``%L```!SW@``20```,_>```=````&=\``!@````W
MWP``*P```%#?```A````?-\``!\```">WP``*P```+[?```A````ZM\``"<`
M```,X```'0```#3@```1````4N```#,```!DX```)0```)C@```G````ON``
M`!\```#FX```,`````;A``!I````-^$``#T```"AX0``90```-_A``!-````
M1>(``"\```"3X@``+@```,/B```P````\N(``%0````CXP``6@```'CC``!(
M````T^,``$H````<Y```,@```&?D```O````FN0``"P```#*Y```+0```/?D
M```7````)>4``"4````]Y0``,@```&/E```I````EN4``#X```#`Y0``(@``
M`/_E```+````(N8``$4````NY@``(0```'3F```P````EN8``"4```#'Y@``
M'````.WF```Q````"N<```<````\YP``!P```$3G```$````3.<```T```!1
MYP``"P```%_G```.````:^<```4```!ZYP``$````(#G```"````D><``%D`
M``"4YP``!0```.[G```(````].<```,```#]YP``$`````'H```,````$N@`
M``T````?Z````@```"WH```4````,.@``!(```!%Z```#````%CH```#````
M9>@```0```!IZ```'P```&[H```U````CN@``"X```#$Z```+P```//H```7
M````(^D``"`````[Z0``&P```%SI```8````>.D``"0```"1Z0``'P```+;I
M```:````UND``"````#QZ0``&@```!+J```R````+>H``!H```!@Z@``+P``
M`'OJ```K````J^H``!\```#7Z@``(P```/?J```?````&^L``!H````[ZP``
M)0```%;K```F````?.L``"4```"CZP``)````,GK```8````[NL``!T````'
M[```)````"7L```8````2NP``"(```!C[```)0```(;L```\````K.P``!\`
M``#I[```(P````GM```?````+>T``"````!-[0``&@```&[M```8````B>T`
M`"8```"B[0``'@```,GM```I````Z.T``!X````2[@``"0```#'N```,````
M.^X``!<```!([@``+P```&#N```D````D.X```<```"U[@``#P```+WN```%
M````S>X```<```#3[@``'0```-ON```:````^>X```<````4[P``QP```!SO
M```+````Y.\``!4```#P[P``!@````;P```)````#?````L````7\```#0``
M`"/P```7````,?````8```!)\```,P```%#P```3````A/```!,```"8\```
M#P```*SP```'````O/```#(```#$\```(0```/?P```3````&?$```P````M
M\0``$0```#KQ```R````3/$``!8```!_\0``"````);Q```)````G_$```H`
M``"I\0``%````+3Q```=````R?$```@```#G\0``'P```/#Q```(````$/(`
M`!H````9\@``)P```#3R```&````7/(``!4```!C\@``"````'GR```'````
M@O(```\```"*\@``#@```)KR```0````J?(```D```"Z\@``"0```,3R```3
M````SO(```<```#B\@``&0```.KR```*````!/,```H````/\P``#````!KS
M```J````)_,```<```!2\P```@```%KS```0````7?,``!@```!N\P``"P``
M`(?S```#````D_,```@```"7\P``!@```*#S```'````I_,```T```"O\P``
M"P```+WS```4````R?,``!4```#>\P``+P```/3S```@````)/0``!P```!%
M]```#````&+T```Q````;_0```4```"A]```$@```*?T```_````NO0``!(`
M``#Z]```"@````WU```&````&/4```0````?]0``!````"3U```*````*?4`
M`!,````T]0``!0```$CU```&````3O4```8```!5]0``!````%SU```,````
M8?4```H```!N]0```@```'GU```$````?/4```8```"!]0```P```(CU```,
M````C/4``$4```"9]0``&@```-_U```U````^O4``"@````P]@``4P```%GV
M```9````K?8``'(```#']@``(````#KW```U````6_<``"$```"1]P``10``
M`+/W```P````^?<``"@````J^```*0```%/X```F````??@``"4```"D^```
M*````,KX```H````\_@``"(````<^0``,````#_Y```2````</D``!,```"#
M^0``$````)?Y``!Y````J/D```D````B^@``<P```"SZ``!\````H/H``"L`
M```=^P``%P```$G[```6````8?L```\```!X^P``%P```(C[```?````H/L`
M`$````#`^P``'P````'\```<````(?P``%$````^_```&@```)#\```4````
MJ_P``!(```#`_```$````-/\```3````Y/P``!T```#X_```#P```!;]```/
M````)OT```0````V_0``"0```#O]```+````1?T```<```!1_0``!0```%G]
M```4````7_T```<```!T_0``"````'S]```/````A?T```@```"5_0``#```
M`)[]```/````J_T```8```"[_0``%````,+]```&````U_T```P```#>_0``
M"````.O]```$````]/T```H```#Y_0``!`````3^```9````"?X```<````C
M_@```@```"O^```)````+OX```8````X_@``!@```#_^```$````1OX```\`
M``!+_@``$P```%O^```'````;_X```<```!W_@``!@```'_^```&````AOX`
M`!````"-_@``!@```)[^```)````I?X``"(```"O_@``!P```-+^```'````
MVOX```L```#B_@``!0```.[^```"````]/X```L```#W_@``<0$```/_```3
M````=0`!`!H```")``$`$````*0``0`-````M0`!``L```##``$`#0```,\`
M`0`&````W0`!`#@```#D``$`-@```!T!`0`D````5`$!`#H```!Y`0$`"P``
M`+0!`0`Z````P`$!`!P```#[`0$`#0```!@"`0`4````)@(!`!,````[`@$`
M*P```$\"`0`?````>P(!`!````";`@$`%@```*P"`0`@````PP(!``T```#D
M`@$`PP```/("`0`;````M@,!``T```#2`P$`$@```.`#`0`2````\P,!`!H`
M```&!`$`#0```"$$`0`,````+P0!`!@````\!`$`!@```%4$`0`)````7`0!
M``\```!F!`$`'P```'8$`0`.````E@0!`!@```"E!`$`&````+X$`0`/````
MUP0!`%(```#G!`$`*0```#H%`0!=````9`4!`&\```#"!0$`E````#(&`0".
M````QP8!`)(```!6!P$`D0```.D'`0!;````>P@!`"````#7"`$`&0```/@(
M`0`9````$@D!`!<````L"0$`#0```$0)`0`D````4@D!``\```!W"0$`$P``
M`(<)`0`/````FPD!`#@```"K"0$`/````.0)`0`7````(0H!`!8````Y"@$`
M$P```%`*`0`0````9`H!`!,```!U"@$`)0```(D*`0`H````KPH!`!L```#8
M"@$`)0```/0*`0`E````&@L!`#0```!`"P$`+0```'4+`0`<````HPL!`"<`
M``#`"P$`&@```.@+`0!4`````PP!`#$```!8#`$`-0```(H,`0`>````P`P!
M`#0```#?#`$`"````!0-`0`8````'0T!`$P````V#0$`#@```(,-`0`.````
MD@T!``H```"A#0$`$0```*P-`0`)````O@T!``8```#(#0$`.````,\-`0`6
M````"`X!`!8````?#@$`&````#8.`0`<````3PX!`$D```!L#@$`'0```+8.
M`0`<````U`X!`"$```#Q#@$`)P```!,/`0`Q````.P\!`"````!M#P$`%@``
M`(X/`0`U````I0\!``P```#;#P$`"````.@/`0`@````\0\!`"\````2$`$`
M'@```$(0`0`R````81`!``H```"4$`$`&0```)\0`0`*````N1`!`!4```#$
M$`$`)````-H0`0`1````_Q`!`'0````1$0$`%````(81`0`&````FQ$!`%P`
M``"B$0$`&0```/\1`0!$````&1(!`$0```!>$@$`2@```*,2`0!.````[A(!
M`!$````]$P$`"@```$\3`0`Z````6A,!`%T```"5$P$`-@```/,3`0`V````
M*A0!`#<```!A%`$`.````)D4`0`X````TA0!`'<````+%0$`,0```(,5`0`\
M````M14!`#@```#R%0$`/@```"L6`0`K````:A8!`"\```"6%@$`2````,86
M`0!"````#Q<!`"4```!2%P$`$0```'@7`0`8````BA<!`",```"C%P$`)P``
M`,<7`0`4````[Q<!``T````$&`$`10```!(8`0`7````6!@!``\```!P&`$`
M"````(`8`0`-````B1@!``8```"7&`$`$@```)X8`0`-````L1@!``D```"_
M&`$`"@```,D8`0`:````U!@!``,```#O&`$``P```/,8`0`7````]Q@!`!H`
M```/&0$`"@```"H9`0`(````-1D!`)8````^&0$`,0```-49`0!/````!QH!
M`#8```!7&@$`#````(X:`0`G````FQH!`#@```##&@$`.````/P:`0!3````
M-1L!`#(```")&P$`0P```+P;`0#!`````!P!`%$```#"'`$`"@```!0=`0`(
M````'QT!`"$````H'0$`#````$H=`0`7````5QT!`!,```!O'0$`%P```(,=
M`0`@````FQT!``P```"\'0$`%````,D=`0`(````WAT!`!T```#G'0$`&```
M``4>`0`;````'AX!``L````Z'@$`+0```$8>`0"0````=!X!`*0````%'P$`
M"@```*H?`0`8````M1\!``,```#.'P$`&P```-(?`0`:````[A\!`!\````)
M(`$`)0```"D@`0`P````3R`!`$H```"`(`$`)@```,L@`0`&````\B`!`",`
M``#Y(`$`'P```!TA`0`:````/2$!`"4```!8(0$`)P```'XA`0`=````IB$!
M`!,```#$(0$`"@```-@A`0`(````XR$!`"$```#L(0$`&P````XB`0`&````
M*B(!`!X````Q(@$`$P```%`B`0`-````9"(!`!D```!R(@$`"````(PB`0`*
M````E2(!`!4```"@(@$`"@```+8B`0`1````P2(!``@```#3(@$`$P```-PB
M`0`&````\"(!``H```#W(@$`(0````(C`0`3````)",!`!@````X(P$`(```
M`%$C`0`@````<B,!`#H```"3(P$`30```,XC`0`V````'"0!``P```!3)`$`
M7P```&`D`0`*````P"0!``@```#+)`$`#````-0D`0`V````X20!`#T````8
M)0$`.0```%8E`0!`````D"4!`#P```#1)0$`.`````XF`0`T````1R8!`#,`
M``!\)@$`,@```+`F`0`V````XR8!`#\````:)P$`/@```%HG`0!!````F2<!
M`#,```#;)P$`0@````\H`0!>````4B@!`$<```"Q*`$`1P```/DH`0!6````
M02D!`%<```"8*0$`)P```/`I`0!,````&"H!`"0```!E*@$`*`$``(HJ`0`Y
M````LRL!`%$```#M*P$`40```#\L`0!1````D2P!`%4```#C+`$`.@```#DM
M`0`\````="T!`$0```"Q+0$`20```/8M`0!4````0"X!`"(!``"5+@$`.@``
M`+@O`0`^````\R\!`$P````R,`$`@P```'\P`0`8`````S$!``@````<,0$`
M#P```"4Q`0`*````-3$!`!H```!`,0$`&@```%LQ`0`@````=C$!`"0```"7
M,0$`(@```+PQ`0`1````WS$!`!,```#Q,0$`&0````4R`0`5````'S(!``\`
M```U,@$`/````$4R`0`*````@C(!`!<```"-,@$`$0```*4R`0`7````MS(!
M`!L```#/,@$``@```.LR`0`,````[C(!`!X```#[,@$`"@```!HS`0`>````
M)3,!`!<```!$,P$`!@```%PS`0`/````8S,!``P```!S,P$`%0```(`S`0`<
M````EC,!``T```"S,P$`%````,$S`0`8````UC,!`!H```#O,P$`#`````HT
M`0`&````%S0!``\````>-`$`#P```"XT`0`G````/C0!``\```!F-`$`#P``
M`'8T`0`K````AC0!`"(```"R-`$`1P```-4T`0`-````'34!`"4````K-0$`
M&````%$U`0`6````:C4!`!,```"!-0$`#P```)4U`0`*````I34!``\```"P
M-0$`10```,`U`0`*````!C8!`!$````1-@$`,````",V`0`3````5#8!`!X`
M``!H-@$`'@```(<V`0`(````IC8!`#H```"O-@$`'@```.HV`0`H````"3<!
M`!L````R-P$`$P```$XW`0`1````8C<!``\```!T-P$`0````(0W`0"$````
MQ3<!``X```!*.`$`$0```%DX`0!2````:S@!`!P```"^.`$`#````-LX`0`=
M````Z#@!``,````&.0$`#`````HY`0`5````%SD!`!4````M.0$`%0```$,Y
M`0`9````63D!`"4```!S.0$`(0```)DY`0`J````NSD!`"@```#F.0$`#@``
M``\Z`0`+````'CH!``(````J.@$`'0```"TZ`0`H````2SH!`%(```!T.@$`
M+P```,<Z`0`.````]SH!`!T````&.P$`'````"0[`0`G````03L!`%4```!I
M.P$`2P```+\[`0`3````"SP!`"(````?/`$`NP```$(\`0`P````_CP!``8`
M```O/0$`'@```#8]`0`@````53T!`#$```!V/0$`-@```*@]`0`*````WST!
M``H```#J/0$`'````/4]`0`4````$CX!`!0````G/@$`%@```#P^`0`2````
M4SX!`!0```!F/@$`#P```'L^`0`6````BSX!``@```"B/@$`#P```*L^`0`B
M````NSX!`!D```#>/@$`%P```/@^`0`.````$#\!`!H````?/P$`$P```#H_
M`0`R````3C\!`#@```"!/P$`.````+H_`0`V````\S\!`#<````J0`$`/P``
M`&)``0`M````HD`!``@```#00`$`$0```-E``0`&````ZT`!``H```#R0`$`
M$P```/U``0`/````$4$!`"@````A00$`*````$I!`0`5````<T$!`!,```")
M00$`&0```)U!`0`7````MT$!`#H```#/00$`#@````I"`0`/````&4(!``T`
M```I0@$`$0```#="`0`,````24(!``\```!60@$`(````&9"`0`-````AT(!
M``8```"50@$`5P```)Q"`0`0````]$(!`#T````%0P$`"@```$-#`0`(````
M3D,!``\```!70P$`#````&=#`0`/````=$,!``X```"$0P$`#@```)-#`0`(
M````HD,!`!````"K0P$`!````+Q#`0`%````P4,!``\```#'0P$`#P```-=#
M`0`/````YT,!`"P```#W0P$`"P```"1$`0`>````,$0!`!8```!/1`$`%@``
M`&9$`0`&````?40!`!4```"$1`$`%P```)I$`0`2````LD0!`!<```#%1`$`
M+````-U$`0`4````"D4!`!D````?10$`&P```#E%`0`$````544!`$D```!:
M10$`20```*1%`0!)````[D4!`"P````X1@$`%0```&5&`0`/````>T8!``H`
M``"+1@$`%0```)9&`0`*````K$8!``P```"W1@$`,P```,1&`0`1````^$8!
M``\````*1P$`.````!I'`0`(````4T<!``@```!<1P$`"````&5'`0`1````
M;D<!`!,```"`1P$`'````)1'`0`(````L4<!`%H```"Z1P$`1P```!5(`0!.
M````74@!`#8```"L2`$`6@```.-(`0`R````/DD!`%P```!Q20$`0@```,Y)
M`0!+````$4H!`"\```!=2@$`$P```(U*`0`@````H4H!``D```#"2@$`4```
M`,Q*`0`^````'4L!`"X```!<2P$`/````(M+`0`*````R$L!``P```#32P$`
M/````.!+`0`X````'4P!`$T```!63`$`"P```*1,`0`J````L$P!`$L```#;
M3`$`*````"=-`0`5````4$T!`!H```!F30$`&@```(%-`0`2````G$T!`'@`
M``"O30$`F````"A.`0#@````P4X!`!T```"B3P$`#@```,!/`0`/````ST\!
M`!H```#?3P$`&P```/I/`0`5````%E`!``P````L4`$`'0```#E0`0`E````
M5U`!`"L```!]4`$`*````*E0`0`U````TE`!`#4````(40$`W0```#Y1`0`;
M````'%(!`!4````X4@$`#@```$Y2`0`.````75(!`#````!L4@$`&P```)U2
M`0`1````N5(!``\```#+4@$`%@```-M2`0`H````\E(!`$0````;4P$`1```
M`&!3`0!`````I5,!`$````#F4P$`00```"=4`0!!````:50!`"````"K5`$`
M9@```,Q4`0`6````,U4!`!8```!*50$`%@```&%5`0`6````>%4!`!$```"/
M50$`'@```*%5`0`>````P%4!`!4```#?50$`%````/55`0!1````"E8!`!P`
M``!<5@$`'````'E6`0!*````EE8!`!D```#A5@$`#P```/M6`0`:````"U<!
M`!(````F5P$`+````#E7`0`:````9E<!`"L```"!5P$`(````*U7`0`F````
MSE<!`"````#U5P$`0````!98`0`Z````5U@!`!X```"26`$`&P```+%8`0`C
M````S5@!`#T```#Q6`$`)````"]9`0`E````5%D!``P```!Z60$`'P```(=9
M`0`(````IUD!`!4```"P60$`#0```,99`0`,````U%D!`!8```#A60$`%```
M`/A9`0`*````#5H!``@````86@$`&````"%:`0`8````.EH!`!H```!36@$`
M%@```&Y:`0`;````A5H!`",```"A6@$`/0```,5:`0`3`````UL!`!H````7
M6P$`#P```#);`0`/````0EL!`!4```!26P$`2P```&A;`0`0````M%L!``\`
M``#%6P$`#@```-5;`0`(````Y%L!`!$```#M6P$`(P```/];`0`-````(UP!
M`!X````Q7`$`%P```%!<`0`@````:%P!`!T```")7`$`"````*=<`0`.````
ML%P!``0```"_7`$`#P```,1<`0`1````U%P!`!8```#F7`$`%0```/U<`0`F
M````$UT!`"8````Z70$`(P```&%=`0`H````A5T!``T```"N70$`&P```+Q=
M`0`*````V%T!`!D```#C70$`@````/U=`0`1````?EX!`!4```"07@$`0@``
M`*9>`0`>````Z5X!`"0````(7P$`%0```"U?`0`5````0U\!`!<```!97P$`
M#0```'%?`0`3````?U\!`!,```"37P$`%P```*=?`0`>````OU\!`#0```#>
M7P$`#````!-@`0`1````(&`!`!,````R8`$`&````$9@`0`,````7V`!``@`
M``!L8`$`"````'5@`0`(````?F`!`!,```"'8`$`=````)M@`0`?````$&$!
M``\````P80$`!@```$!A`0`*````1V$!`!X```!280$`'````'%A`0`@````
MCF$!``(```"O80$`$0```+)A`0!`````Q&$!``,````%8@$`"`````EB`0`=
M````$F(!`!4````P8@$`&````$9B`0"#````7V(!``D```#C8@$`#````.UB
M`0`(````^F(!``H````#8P$`3@````YC`0!<````76,!`!X```"Z8P$`(@``
M`-EC`0`T````_&,!`#,````Q9`$`,0```&5D`0`3````EV0!``0```"K9`$`
M"@```+!D`0`*````NV0!`!8```#&9`$`%P```-UD`0`*````]60!`(8`````
M90$`&@```(=E`0`1````HF4!`!8```"T90$`*P```,ME`0!Q````]V4!``8`
M``!I9@$`$P```'!F`0`&````A&8!``L```"+9@$`+P```)=F`0`M````QV8!
M``@```#U9@$`#````/YF`0"O````"V<!`"(```"[9P$`(0```-YG`0`,````
M`&@!`!$````-:`$`$P```!]H`0`@````,V@!``X```!4:`$`$````&-H`0`,
M````=&@!`!,```"!:`$`$0```)5H`0`3````IV@!`!<```"[:`$`'````--H
M`0`:````\&@!`!H````+:0$`&@```"9I`0`<````06D!`!H```!>:0$`+```
M`'EI`0`5````IFD!``T```"\:0$`'````,II`0`/````YVD!`!X```#W:0$`
M(0```!9J`0`&````.&H!`!4````_:@$`&@```%5J`0`6````<&H!`!0```"'
M:@$`%P```)QJ`0`>````M&H!`!H```#3:@$`"````.YJ`0`(````]VH!`!$`
M````:P$`"P```!)K`0`M````'FL!`!8```!,:P$`+0```&-K`0`R````D6L!
M`!X```#$:P$`"@```.-K`0`:````[FL!``@````);`$`'````!)L`0`$````
M+VP!``0````T;`$`:0```#EL`0!/````HVP!`"4```#S;`$`1@```!EM`0!9
M````8&T!`!,```"Z;0$`6@```,YM`0!"````*6X!`$<```!L;@$`1P```+1N
M`0!,````_&X!`"D```!);P$`(P```'-O`0`N````EV\!`"8```#&;P$`)0``
M`.UO`0`E````$W`!`!\````Y<`$`+0```%EP`0`D````AW`!`$X```"L<`$`
M3@```/MP`0!2````2G$!`%(```"=<0$`4````/!Q`0!-````07(!`$(```"/
M<@$`$P```-)R`0`S````YG(!``\````:<P$`.0```"IS`0!$````9',!`$4`
M``"I<P$`$P```.]S`0!R`````W0!`'D```!V=`$`$0```/!T`0`T`````G4!
M`!0````W=0$`&````$QU`0`+````974!``L```!Q=0$`%@```'UU`0`>````
ME'4!`!,```"S=0$`&0```,=U`0`2````X74!`#P```#T=0$`#````#%V`0`&
M````/G8!`!P```!%=@$`%P```&)V`0`5````>G8!`%(```"0=@$`"@```.-V
M`0`&````[G8!`!P```#U=@$`#````!)W`0`*````'W<!`!P````J=P$`#P``
M`$=W`0!1````5W<!`!@```"I=P$`+0```,)W`0!C````\'<!`"````!4>`$`
M0@```'5X`0">````N'@!`"L```!7>0$`/0```(-Y`0`3````P7D!`!8```#5
M>0$`%@```.QY`0`8`````WH!``P````<>@$`%P```"EZ`0`2````07H!`#$`
M``!4>@$`(````(9Z`0`(````IWH!`!<```"P>@$`&@```,AZ`0`X````XWH!
M`"(````<>P$`)@```#][`0`8````9GL!`#8```!_>P$`"````+9[`0`.````
MOWL!`"0```#.>P$`&0```/-[`0`5````#7P!`!<````C?`$`"````#M\`0`K
M````1'P!``X```!P?`$`%P```']\`0`3````EWP!``X```"K?`$`.````+I\
M`0`B````\WP!`$(````6?0$`'@```%E]`0`/````>'T!`!````"(?0$`,P``
M`)E]`0`.````S7T!`",```#<?0$`"`````!^`0`B````"7X!``@````L?@$`
M"````#5^`0`F````/GX!`$L```!E?@$`"````+%^`0`<````NGX!``P```#7
M?@$`&P```.1^`0`7`````'\!`!D````8?P$`"````#)_`0`*````.W\!``X`
M``!&?P$`-0```%5_`0!=````BW\!`&L```#I?P$`.````%6``0!!````CH`!
M`#4```#0@`$`=`````:!`0`U````>X$!`$,```"Q@0$`3@```/6!`0"'````
M1((!`#L```#,@@$`#@````B#`0`(````%X,!`"L````@@P$`*0```$R#`0`;
M````=H,!`"P```"2@P$`.0```+^#`0`_````^8,!``@````YA`$`'P```$*$
M`0`*````8H0!`!,```!MA`$`/0```(&$`0`<````OX0!``T```#<A`$`$0``
M`.J$`0`(````_(0!`!,````%A0$`$0```!F%`0`1````*X4!`!,````]A0$`
M)````%&%`0!-````=H4!``\```#$A0$`"@```-2%`0`D````WX4!`!<````$
MA@$`"@```!R&`0`;````)X8!`!L```!#A@$`&````%^&`0`4````>(8!`!8`
M``"-A@$`%0```*2&`0`(````NH8!``P```##A@$`'````-"&`0!*````[88!
M`'8````XAP$`+0```*^'`0`Z````W8<!`",````8B`$`(P```#R(`0`.````
M8(@!`"(```!OB`$``P```)*(`0`&````EH@!``\```"=B`$`#P```*V(`0`8
M````O8@!``T```#6B`$`40```.2(`0`&````-HD!`"`````]B0$`$0```%Z)
M`0`5````<(D!`%<```"&B0$`(````-Z)`0`0````_XD!`!X````0B@$`,P``
M`"^*`0`*````8XH!`",```!NB@$`+@```)**`0`0````P8H!`"4```#2B@$`
M*P```/B*`0`,````)(L!``@````QBP$`$P```#J+`0`5````3HL!`!@```!D
MBP$`!@```'V+`0`8````A(L!`!(```"=BP$`%@```+"+`0`5````QXL!`!4`
M``#=BP$`"P```/.+`0`*````_XL!`%(````*C`$`2P```%V,`0!)````J8P!
M``@```#SC`$`*P```/R,`0`Y````*(T!``X```!BC0$`#@```'&-`0`#````
M@(T!`!````"$C0$`#@```)6-`0`(````I(T!`"````"MC0$`#P```,Z-`0`2
M````WHT!`!@```#QC0$`@0````J.`0`?````C(X!``8```"LC@$`#P```+..
M`0`0````PXX!`"````#4C@$`'````/6.`0`W````$H\!`",```!*CP$`'@``
M`&Z/`0`Y````C8\!`!,```#'CP$`-````-N/`0`6````$)`!`!X````GD`$`
M\````$:0`0`E````-Y$!`"$```!=D0$`1P```'^1`0`E````QY$!`!\```#M
MD0$`)0````V2`0`A````,Y(!`"T```!5D@$`%0```(.2`0`.````F9(!``H`
M``"HD@$`#@```+.2`0`7````PI(!`"0```#:D@$`"@```/^2`0"2````"I,!
M`)$```"=DP$`4@```"^4`0"`````@I0!`!H````#E0$`4P```!Z5`0`^````
M<I4!``@```"QE0$`%0```+J5`0!D````T)4!``H````UE@$`:P```$"6`0!7
M````K)8!`#L````$EP$`(@```$"7`0!4````8Y<!`$,```"XEP$`/0```/R7
M`0`O````.I@!`#8```!JF`$`,0```*&8`0`5````TY@!``@```#IF`$`&P``
M`/*8`0`;````#ID!``T````JF0$`.0```#B9`0`-````<ID!``H```"`F0$`
M&P```(N9`0`,````IYD!`"````"TF0$`!@```-69`0`(````W)D!``@```#E
MF0$`&P```.Z9`0`;````"IH!``\````FF@$`'0```#::`0`:````5)H!`"4`
M``!OF@$`%0```)6:`0`;````JYH!`!@```#'F@$`+0```.":`0`V````#IL!
M`!4```!%FP$`"@```%N;`0`K````9IL!``X```"2FP$`(P```*&;`0`3````
MQ9L!`!,```#9FP$`$0```.V;`0`*````_YL!`!(````*G`$`"@```!V<`0`/
M````*)P!`!H````XG`$`#0```%.<`0`<````89P!`!4```!^G`$`$P```)2<
M`0`.````J)P!``P```"WG`$`"@```,2<`0`*````SYP!``X```#:G`$`$```
M`.F<`0`F````^IP!`)`````AG0$`00```+*=`0!1````])T!`"@```!&G@$`
M"@```&^>`0`3````>IX!`!,```".G@$`#````**>`0`(````KYX!`!$```"X
MG@$`"@```,J>`0`(````U9X!``H```#>G@$`$````.F>`0`0````^IX!`!<`
M```+GP$`+````".?`0`(````4)\!``@```!9GP$`$````&*?`0`(````<Y\!
M`!<```!\GP$`%P```)2?`0`'````K)\!``H```"TGP$`$P```+^?`0`<````
MTY\!`!,```#PGP$`%0````2@`0`9````&J`!``8````TH`$`#0```#N@`0`/
M````2:`!`!$```!9H`$`#@```&N@`0`.````>J`!`$D```")H`$`)P```-.@
M`0`]````^Z`!`#8````YH0$`GP```'"A`0`:````$*(!`&4````KH@$`5```
M`)&B`0!O````YJ(!`&$```!6HP$`,````+BC`0!D````Z:,!`#H```!.I`$`
M/````(FD`0!)````QJ0!`#0````0I0$`#@$``$6E`0`D````5*8!`!0```!Y
MI@$`O````(ZF`0!M````2Z<!`#@```"YIP$`?````/*G`0"S````;Z@!`"``
M```CJ0$`&````$2I`0`S````7:D!`"8```"1J0$`)@```+BI`0!%````WZD!
M`"P````EJ@$`,````%*J`0`F````@ZH!`!@```"JJ@$`30```,.J`0!`````
M$:L!`#$```!2JP$`,@```(2K`0!2````MZL!`,H````*K`$`4@```-6L`0"+
M````**T!`((```"TK0$`2````#>N`0!1````@*X!`%4```#2K@$`B````"BO
M`0"4````L:\!`'8```!&L`$`>````+VP`0!4````-K$!`$8```"+L0$`2```
M`-*Q`0!*````&[(!`"@```!FL@$`10```(^R`0!,````U;(!`$X````BLP$`
MB````'&S`0`X````^K,!`!D````SM`$`CP```$VT`0`O````W;0!`%$````-
MM0$`/P```%^U`0`J````G[4!`%D```#*M0$`!@```"2V`0`,````*[8!``@`
M```XM@$`%0```$&V`0`1````5[8!`!<```!IM@$`"@```(&V`0`C````C+8!
M``0```"PM@$`CP```+6V`0`*````1;<!``@```!0MP$`"````%FW`0`@````
M8K<!`!$```"#MP$`'0```)6W`0`-````L[<!`!0```#!MP$`*P```-:W`0`0
M`````K@!``,````3N`$`!````!>X`0`R````'+@!`&H```!/N`$`4````+JX
M`0!6````"[D!`"L```!BN0$`-````(ZY`0`H````P[D!`$8```#LN0$`/```
M`#.Z`0`W````<+H!`#L```"HN@$`0````.2Z`0`N````);L!`#H```!4NP$`
M+@```(^[`0`X````OKL!`%````#WNP$`,P```$B\`0`X````?+P!`#P```"U
MO`$`-P```/*\`0!,````*KT!`#P```!WO0$`1@```+2]`0`U````^[T!`#L`
M```QO@$`/````&V^`0!)````JKX!`#<```#TO@$`.@```"R_`0`R````9[\!
M`&P```":OP$`/`````?``0!!````1,`!`$4```"&P`$`1@```,S``0!`````
M$\$!`#(```!4P0$`/0```(?!`0`W````Q<$!`#(```#]P0$`.P```##"`0`3
M````;,(!`"$```"`P@$`*P```*+"`0!&````SL(!`#0````5PP$`#P```$K#
M`0`/````6L,!``P```!JPP$`&0```'?#`0`X````D<,!`",```#*PP$`"P``
M`.[#`0"3`0``^L,!`!H```".Q0$`(````*G%`0`2````RL4!`!4```#=Q0$`
M'0```//%`0`<````$<8!`#0````NQ@$`$P```&/&`0!S````=\8!`!P```#K
MQ@$`(`````C'`0`<````*<<!`!<```!&QP$`9````%['`0!`````P\<!`!D`
M```$R`$`'@```![(`0`8````/<@!`$P```!6R`$`(P```*/(`0`1````Q\@!
M`!(```#9R`$`$P```.S(`0`<`````,D!`"`````=R0$`#@```#[)`0!$````
M3<D!``P```"2R0$`*````)_)`0!!````R,D!``P````*R@$`)P```!?*`0`,
M````/\H!``@```!,R@$`$P```%7*`0`3````:<H!`"(```!]R@$`"P```*#*
M`0`1````K,H!`!,```"^R@$`"P```-+*`0`F````WLH!`!H````%RP$`&0``
M`"#+`0`;````.LL!`$\```!6RP$`#````*;+`0`0````L\L!`!@```#$RP$`
M/0```-W+`0`+````&\P!``0````GS`$`#0```"S,`0`*````.LP!`!$```!%
MS`$`&0```%?,`0`6````<<P!`!0```"(S`$`%0```)W,`0!:````L\P!`",`
M```.S0$`*````#+-`0`/````6\T!`&P```!KS0$`!@```-C-`0`<````W\T!
M`%T```#\S0$`$P```%K.`0`1````;LX!``D```"`S@$`!````(K.`0`'````
MC\X!`!D```"7S@$`+P```+'.`0`'````X<X!``@```#IS@$`!@```/+.`0`&
M````^<X!`!8`````SP$`%@```!?/`0`%````+L\!``0````TSP$`#````#G/
M`0`&````1L\!`!4```!-SP$`<@```&//`0`G````UL\!`&(```#^SP$`4P``
M`&'0`0",````M=`!`!@```!"T0$`L0```%O1`0!)````#=(!`'H```!7T@$`
M4P```-+2`0!*````)M,!`&@```!QTP$`4@```-K3`0!3````+=0!`%$```"!
MU`$`5P```-/4`0!>````*]4!`%$```"*U0$`/P```-S5`0!6````'-8!`"0`
M``!SU@$`(````)C6`0`5````N=8!`+T```#/U@$`#0```(W7`0#:````F]<!
M`+D```!VV`$`3````##9`0`W````?=D!`"````"UV0$`%P```-;9`0`H````
M[MD!`#4````7V@$`7````$W:`0`[````JMH!`#0```#FV@$`H0```!O;`0`N
M````O=L!`"T```#LVP$`,0```!K<`0`6````3-P!`"D```!CW`$`,@```(W<
M`0`3````P-P!``X```#4W`$``P```./<`0`1````Y]P!``T```#YW`$`%```
M``?=`0`,````'-T!`!P````IW0$`"````$;=`0`(````3]T!`!@```!8W0$`
M$0```''=`0`,````@]T!`!0```"0W0$`&@```*7=`0`:````P-T!``X```#;
MW0$`&````.K=`0`*`````]X!``@````.W@$`(0```!?>`0`,````.=X!`!<`
M``!&W@$`!@```%[>`0`"````9=X!``H```!HW@$`"````'/>`0`)````?-X!
M``8```"&W@$`'````(W>`0`L````JMX!``<```#7W@$`"````-_>`0`.````
MZ-X!``@```#WW@$`&0````#?`0`/````&M\!`!4````JWP$`0P```$#?`0`1
M````A-\!``L```"6WP$`%P```*+?`0`%````NM\!``(```#`WP$`"P```,/?
M`0`!````+@```#X```#<!```P@````````#0!````````.T"````````````
M```````K`0```````$4%``",!0``XP(``&0%```-````L````$@!````````
M``````````"9`0``#P0``*`$````````W00``!<%````````F0(``'D```#D
M`0```````)$#````````B00```````"B!```PP,``/($````````-0(``.H$
M``#3`@````````````!F`0``&@,``!`#````````^`0``%L#```'`0``LP$`
M`-,#````````````````````````10,``!0"``"=!0``<`0``'\#``![`P``
M`````(4"``````````````X```"8`@```````(H#````````?@$``/T$```O
M`@```````!H"``!\!```GP4``)($``"I`0``NP,``+,```"S`P``[@$`````
M``!]`P```````#8```"8!```K0$``.H"```Z`P````````````"F!0``5P(`
M`"<%``#[````C`,``)(`````````L`0``.<"``#8`@```````)P"``#?````
M`````'@%``!7`P``.`,````````X`@``"@```'P#```5!0````,``/<#````
M````9P$``#P!``!%!```/04``)\!``!^`````````!\```!V````OP$`````
M````````&0,````````O`P``T`````````#6`P``B`$``#4#```#`0``^`$`
M`*,!````````]00``/$"``"N!```P````!L```!(`P```````,`#``":`@``
M_`0```````"N````80```&D!````````T@,``%<%```?!0```````$0"``#L
M```````````````D!```````````````````R@(``%@$```5`````````#,`
M``"_`@``DP```%0#``#K`P``F04``#$$``!X`@``?@(``%T```"X!```H```
M````````````!P0```````#T`@```````/,#``!?`@``6`,````````,`0``
M6P$``'(#```)`0```````(8"``````````````````#\`@``BP,```````#:
M!```2P$``-H!````````=@$``*\$```V`0``*`,````````Y`P``K@$``.<!
M``"E`@``00$``/,!```4!0``:04``'H!```Q``````````X%``#-!```>0$`
M`(@```"W````@@(``!@$````````D00``&4#```````````````````G````
MW@0``&8%``"!!```%P,``,`!``#_`0```````!\#```D````,@$`````````
M````G@$```L```#T`P```````+0#`````````````'(%`````````````($"
M```@`0````````,```#O`0``O@$``(<```#I!```Y@```!P"````````EP4`
M`,@$``"F`0``3P,```````!5!```(@,``-<````M!0``M`````````"X`0``
MX@,``+\#```5`0``-@,```$#``#Q`0``%P```*<$``##`0``60```"H`````
M````#04``"8$```6!0```````.`$```K`@```````+4"``"&!0``60,``$T%
M``"0!0``````````````````<`$```8"``!5`@```````(D#````````````
M`+P$```1!0``D`$``$D!``#X`@``*0`````````/`P``<@(```````#G!```
MB0```-@!``#Q````Q00``(\!``!G`@``G00````````_!0``C0```',!````
M`````````(4$``!K`P``I0,````````Y````;P$``,<$``#6`````````'0`
M````````/@4``%@!`````````````",%```H!0``&04``'P!```,`@``)`(`
M`)T```!X`````````*$```#I````X0(``'H$```B!```H@$``(H!````````
M@@```(\%``"^````"0(``(8$``````````````H$``#<`@``Y@$``*,```![
M!```904``#P````D`0``,@4``!X#``!P```````````````D`P``B`(``%(%
M```4`P``,P0``+@#``!3!0``'`4`````````````9`,``%8%``!+!```L@$`
M`!$`````````CP0``)8$``!/`@``````````````````;00``),"``#[!```
M^P$``)X"``!Z!0``]`````````"9````V0,`````````````Y@,``(H$````
M````X@(``-X!``!.`P``C0$`````````````JP0```````!;!0```````*\!
M``````````````\"``!7!```Q@```/T```"A!0``I04```````#7`P``@P``
M`&X"```Z`0``[P,``$D%``!>`P``D@4``(L%``"S!```"0,``!,"````````
M``````````#(`@``T0```#T!``!Y`P``V0$``)0%`````````````+T!````
M`````````'4#``"$````X0$``)8```!.````D`(``&\#``"7````IP(``#T#
M````````ZP```&<`````````+`$``*T#````````@@0``%4`````````MP,`
M`$@$``"!!0``&@````````!H`0``A@,``(0%`````````````*H!``#D`@``
M]@````````````````````````"(`P``%@(``*0!``#N`P``R0(``/("```!
M!```50$``$X!````````R@0``*@`````````OP0``,X"``"6`P``M`0``&(#
M``!*!```'04````````?!```Y0,``#X"````````<00``%D"````````8`0`
M`-\"```X!0``I`4````````'`@``4@$``%`$````````$P```,8#``"P`@``
M[`(````````4`0``-P```-P```"C!0```````.L!```.`P``*P0`````````
M`````````/X!``!2`@``=`(``+L!````````=0(```````!3`0``704``(X!
M``"J````?P```,H!```9!```D0$``+4```"$`@``7`,`````````````2P,`
M`,D$``#C`0``#0(``-X"```.!````````-D$```&!```:`(``/D!``#A!```
M``````P`````````,@(``.T!``!<`@``T`,``*@"``!?!0``ZP(``,0"```=
M`0``&`$``-,!``#R`P``3@4``)(!````````HP0``!L$``"X````8@$```@%
M```*`@````(``!$!``````````````````#H`P``#`0``$8#``#J````$@4`
M`"`"```A!0``O@(``&H````M!````````"H$``#2!```F`4````````L````
M6@$``*$!``"F`P``X`$``*\"``";!0``.P(``"L%``!*!0``)P0``!P!``"5
M`P```````+H```"O`P```````)("```W!0``"`0`````````````"`$`````
M```>````?@,``)@```!%````S0$``/,```#Z!```CP```(D"``":`P``````
M`$D#``"8`0``BP0``/P!```/````-P$``#X#``#!`@``.P`````%``"Q`0``
MP@$``"4%``!T!```O`,``$P"```3!0``C0(``%$"`````````````/P#```"
M`P``VP(``+H$````````EP$``&L%````````5`(````````'`P``400``'D%
M````````F0,``$<```!=`@```````#$%``#)``````````````!.!```GP(`
M`#P%``"'!```"04``,,`````````3P```(,#``#%`P``'00``.D"``!:`P``
M`````'P```#C!```/P```"X"````````,0,``"$```"#!```E@(``+4!````
M````%P(````````[`0```````&,"```-`P``<P,``)T#```F````N@$``"D"
M``#J`0``&`(```````"K`0```````*P"``#'`P``W`,``*(#````````?0$`
M`-X`````````%0(``+4$``!!!0````````````!<`0``:`4``!\"```(`@``
M-`,``/H"````````@0,``,T"``!'!````````-H"``"1`````````,P#``#Y
M`P``80$````````:`0```````)0$````````Y0```!,#```6`0``0@,``%D!
M``"I````EP0``!8#```]`@``<@0```````"L`P``9@```!<!``!6`P``:`,`
M```````>!0``LP(``%T#```B`@```````$P#```M````D````,0#``#C`P``
MT00``'0!``!T`P``;@`````````B````L@```.8$``";`P```````%8"``#-
M`P``[`$```T$``!^!0``U`````````"'`0``FP$``$T````7!```CP,``%@"
M````````(00``&,```#5`P``@`````````#^`P``<P4``"4!```5`P``3P$`
M`%($````````X0```/0$```X!```````````````````_P,``#4!``!@`@``
M`````,8"``#H!```:@0`````````````,`$``)$"``",````(````!(!``"-
M`P```````$<#``#Q!```/00``)T!```N!0````````````#_````<P0``.@`
M```Q`0``@@4``&`#``!K````?04```````#:`P``)0,``&($```N`P``$@0`
M`'L%``"#`@``A0$``-T!``"0`P```````/,$````````[0```),!```T`0``
MK0``````````````9P0``$@````%!0````````````"(!````````&,#````
M````````````````````7@4``%@%`````````````(0!````````U0(`````
M``#7`@``S````*<#``#.`P```````/H#``!:`@```````#H%````````G`0`
M`+D"``#6`@``4`4````````3!```0@````,#````````$00``/`#``#>`P``
M!0(```````"L`0``V````.\$``!F!```C@0```````#/````5@```"@$``"M
M`@``#`,``#@```#2`@``$`$``.L$````````N0$`````````````I@```*H$
M`````````@0``+X$```?`0``^0```-(````T!0``RP```.P#``"V`0``````
M`*`%```*!0``J@(```````!M`P```````*T$````````PP(``%$```!B````
M`````,8$```+!0``9````'X$``#,!````````)8!```&`0``X@0``.$#``#+
M`@``?00``%,"``"E`0```````)$%```A`0``;P```'`"``#Y`@``!````*$"
M``"W!```!0$```````#1`0``%00``%`````8!0``IP$````````[!```F00`
M``````!Z`@```````%X"``"O````00,````````F`P```@(```````"D`P``
M'@(```````#L!```;`$```````````````````````"0!```10(``.@!``!<
M!0````````````"7`@``BP$``)H%``"/`@```````,L#``!D`@```````+("
M`````````````)0"``!;!````````+$"`````0``\`(``*(`````````U@$`
M`',"````````1`4``&\%``!M````2P4``%H```"\`0``9P,``/X$``"``0``
M`````%P```"L!```Q@$``!(````%!```N@,``'T"```C````.P,```````"`
M`@``B0$```````#8`P``P`(``/\$`````````````&T!``#]`0``"0```"`#
M```````````````````"````&@4``$P```!$!```;P(```````!4!```E04`
M``````!(!0``-P0``$P!``!"!0``;@4``+X#``!A`P``@P4`````````````
M&@0``-4```#E`@``O`````\!```K````%@````$%``!3````,P$``-0#``!J
M`P``,````,L$``#I`0``B@```&8#```D!0````````````!J!0``U`(``$8%
M``!3!```>`,``.T#``"5`````````!$#``!_`@``.00```L"```G`@``?P0`
M``````#V`P``.P4```````#/`0``-00``&,$`````````````&,%``"%````
MNP0```T!``!U!0``Z`(``%T$``!<!````````%\`````````=P```&`!```N
M!```900``.D#```H`0```````*0"``#X`P````````````#Y!```=P$``&4`
M``#9`@````````````#)`P````````````"[`````````'$%``!Q`P``P@(`
M``````!L`P``U@0``-P!````````+0,``"(!```#!```Q`$``'$`````````
M6@4``$T!``"6!0``G@0``&X$``#2`0``6P```",$`````````````!T```"Y
M`P``S@0``,H```#?`0``U0$`````````````NP(`````````````@0``````
M``#4!```DP,``'4```#4`0``G````'`%``#(````J0(``"P"``"&````X```
M`(P$``#%````WP0``/````":````K@,``.X$``#.`0``I`0``"P%```J`@``
M!@```%0!```$`P``[@(``'P%``!J`@``Q0(```````!:!````````"8%``#X
M`````````-<!``"Q````>`0``&<%``!``P``P0,``#\$```C`@``(0,`````
M``!M!0``Y`````L#``".````H`(``"8!``!4!0``-P,``/0!``!)````````
M`&4"``!Y!````````#0$````````+`,```````!Z`P``-04```````!?`0``
M;````.8"````````B04``$8"````````A@$``#,%````````J0,``"\!```I
M!0``C`(``,4!``#/`@``/@$``,P"``".`@``=0$``.`#````````"@,``!`$
M````````H00`````````````200```````!(`@``&````%`"``#O````I@(`
M````````````2@(``!`%`````````@4``#P"````````=@(``$<"````````
M`````````````````````$(!```P!```O0(``&X#```R````"`````````!-
M`P``"P$``$\$``#B`````````'$!```A`@``)@(``/4```#\````1````+($
M``!2`````````,0```#'`@``"`,``+4#``"H`0``>P(`````````````````
M``````"?````$0(``&@$```L!```+P```#($``!`!0``X@$```0"````````
M$@(``*,#``!]````!`0``",!``````````````<%```9`@```````+T```#V
M!```(`4```````!1!0``90$```````#9````I````,`$``"T`0``G@4``*L#
M``#:````>0(```````";!```B`4``$$$````````J@,``&D$````````K@(`
M``````#1`@``C00``)L```"V!```B@(```````````````````0%``!L!```
M`````$("`````````````$L"``#[`P``BP(```,"``#W`0``M@,``%(#``"4
M`P``G@```%`#``!\`@``@`0`````````````&P,````````.`@``````````
M``"$`P``QP```-,``````````````#,"`````````````"H%``"*!0``=P(`
M`#P$````````"@$``!`"````````]0,``'@!``!>`0``;0(``"\$```2`P``
M``````````"7`P``[00```````!D!```P00``'L```#P!```!@4````````B
M!0``'`0``$8$`````````````*8$``#!`0```````!X!``!>!```O00``#$"
M``!>````8@(``-@$``"@`P``I0````````!!`@```````$P$``!7`0``_0(`
M`&`%``#P`0```````),$`````````````$,#``!O!`````````````#O`@``
MVP$```````#;````\P(``#0```"Y````A0,``%\$``#+`0``/P(``&D"``!-
M`@``-`(``/(```"<`P``6P(``-L#``"Z`@````0``+T#``"!`0```````#\#
M``!_!0``4`$``"\%``!-!```TP0``)X#```$`0```````,T````Z````GP,`
M`&L"```I`0``N00``"`$``!`!````````+$$````````]P```$P%````````
M=P,``+P"```^!```<`,``#@!```"`0```````#`%```<````2@`````````E
M`@``0P$``"X!```K`P``0P(``)\$``"G!0``E0$``-<$````````VP0``,$`
M````````````````````````(P,```````!#!0``0@0``%4%````````_0,`
M`!@#````````$P$````````````````````````H`````````.0#````````
ME00``'<$``""`P``)P$``!T"``"+````,`,``(<%``````````````````!I
M`P``C04``#D%``"X`@```````+<!`````````````+8`````````804``,,$
M``!L`@``;`4```````!K!```'@0```````````````````````!`````D@,`
M``````#J`P```````&L!````````Y0$``!8$```V`@```````%D$```%`P``
ME0(``#,#```]```````````````P`@```````!L!```+!```XP```*@$````
M````7P,``$D"``"8`P``.0$``!D```"<`0``2@$```<```!R`0``_@```$X"
M```!`0``,@,``#4```!/!0``*`(``"H!``".!0``'0,`````````````.0(`
M``````"3!0``4P,``'$"````````1`,``%0`````````9`$```````#W`@``
M9@(``(P!``#'`0``=P4``%<```````````````4``````````````$8!``"4
M`0``:@$``````````````````%8!``!1`0``@`,```````!V`P``````````
M``":!```JP```!0$````````I00```````"L````604``$H#``!T!0``````
M`&@```````````````````"'`P``]0$``*@#``":`0``8P$``#H$```0````
M<@```$8`````````T0,``,@#```.`0``;@$``#P#``"_````W0```'4$````
M````A`0``/8!```W`@``E````"T!``!Z`````````*<```"I!````````/L"
M````````HP(```\%``!V!```+0(``!L%``"`!0``1`$``*$#``#D!```/P$`
M`+(#``#0`0``M@(``,@!````````A04``#H"``!1`P```````!D!``!+````
M8@4``&D``````````````.`"``!8````50,```````#?`P``_P(``#8$``"P
M`P``*00``$<!``#^`@``?P$```8#``#N````U00``-T#```!`@``M`(``$,$
M``";`@``H`$`````````````0P```-T"``"=`@``1P4``"D#``!%`0``"00`
M`$`!````````]0(``%8$``#)`0``G`4``"H#```<`P``8````,\$````````
M00```+$#``".`P``80(``',````;`@```````,\#``"'`@``@@$``+<"````
M````>P$```,%``#G`P````````````!``@``L`$``#8%````````\@$``/<$
M````````\0,``"<#`````````````/8"``"#`0```````%T!````````Q`0`
M````````````^@$``,P!``#G`````````,H#``"K`@``P@0``&$$```,!0``
M%```````````````=@4``*(%`````````````-`"````````S@```/H```"B
M`@````````````#"`P```````.4$```E````)00````@*"5S(&1A>7,@86=O
M*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O
M;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F
M34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@
M)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A
M>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E
M='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A
M9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M
M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H
M96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@
M0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T
M`"5S.B`E<P`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T
M($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H
M;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O
M<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'
M<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'
M<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@
M;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E
M<W,@8F]O:P!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D
M9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO
M;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!;&EA<P!!
M;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!
M;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G
M:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E
M<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L
M871E<P!!;'1E<FYA=&4@=&5X=#H`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%P<&QI8V%T:6]N`$%P
M<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`
M07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI
M=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<FUE;FEA;B`H05)-4T-)22TX*0!!
M<G0`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075T:%]C
M>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B
M:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO
M="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W
M:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H
M96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!"86-K9W)O=6YD`$)A8VMG
M<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R
M;W,@=7-E<FYA;64N`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A<V5L:6YE`$)L
M;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K
M(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";V]K;6%R:W,`0F]R9&5R`$)O
M<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T960@
M3&ES=`!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R
M;W!E<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86X@;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S
M(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BX`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#
M96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@
M<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E3
M3RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#
M:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@
M3&EN:RXN+@!#:&EL90!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO
M;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U3
M3V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE
M87(@=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA
M($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]L;&%P<V4@4VED
M96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO<@!#;VQO<B!0:6-K97(`0V]L
M;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM
M86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUP86YY
M`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O
M;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C
M=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN`$-O;G1I;G5E`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T
M:6]N`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N
M;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@
M8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S
M97)V97(`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!
M0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO
M="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L
M9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N
M(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O
M9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W
M('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N
M=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK
M`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@
M4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-U<G)E;G0@5&EM90!#
M=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I
M;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O
M;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WER:6QL:6,@*$M/
M23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN
M:6%N("A+3TDX+54I`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T90!$
M871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M
M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E
M9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@
M4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@
M4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C
M96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$
M96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E
M<GD@=&EM90!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A
M:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT
M`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN
M=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T
M;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L
M87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@
M9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@
M=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;W=N
M;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA
M:6P`15)2`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES
M<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S
M`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`
M161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5L96UE;G0N+BX`
M16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y
M(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N
M86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S
M(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N
M9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y
M;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17)R;W(`17)R
M;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@
M)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92X`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F
M<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@
M(B5S(BX`1F%I<@!&871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E=R!3:&]W
M97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE
M($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@
M<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+@!&:6QT97)S`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T
M:6\`1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O
M;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,`1F]R96-A<W0@*%1!1BD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS
M`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R
M=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E
M<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VT`1V%L;&5R>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;@!'96YE<F%T960@0V]D90!':79E;B!.86UE`$=O`$=O;V=L92!396%R8V@`
M1W)A>7-C86QE`$=R965K("A)4T\M.#@U.2TW*0!'<F]U<"!!9&UI;FES=')A
M=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5E
M<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$A434P`2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T
M:6]N(&YO="!F;W5N9"X`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5B
M<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I
M=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O
M9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE
M($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R`B)7,B`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M
M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I
M>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D
M<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T
M('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E?;G-E<G0@4F]W($)E9F]R
M90!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E
M;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R
M86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E
M(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M
M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@
M4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+@!);F-R96%S92!);F1E;G0`26YD:79I9'5A;"!5<V5R<P!);F9O`$EN9F]R
M;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R
M="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS
M97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N
M97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O
M=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T
M:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R
M="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T
M:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L
M;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E
M9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!)
M;G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R
M="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H
M92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E
M<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O
M('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`
M26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)
M1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y
M<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES
M<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!)
M;G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A
M;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A
M;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`
M27-O;&%T960@5"U3=&]R;7,`27-S=65R`$ET86QI8P!*86YU87)Y`$IA<&%N
M97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+965P(&]R:6=I;F%L/P!+97)B97)O<R!S97)V97(@<F5J96-T
M960@875T:&5N=&EC871I;VXN`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I
M;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MO<F5A;B`H
M155#+4M2*0!,85]Y;W5T`$QA;F=U86=E`$QA<W0@2&%L9@!,87-T(%!A<W-W
M;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO
M9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE
M=F5R`$QA=P!,87EO=70`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,
M:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H
M="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6YK`$QI
M;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C
M;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI
M90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S
M97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`
M3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3
M=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!,:71E<F%T=7)E`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,
M;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F
M86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S
M`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!-30!-
M3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'
M`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G
M;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA
M<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-871C:&EN9R!F:65L9',`
M36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-961I8VEN90!-96UB97)S`$UE
M;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D
M(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O
M=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E
M('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC
M`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI
M<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@
M;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S
M:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE
M($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]O;B!0:&%S97,`36]S=&QY($-L96%R`$UO
M<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`
M36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UU;'1I+6QE
M=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C
M;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T
M86P@3&%Y;W5T`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YE='-C87!E($)A
M<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!
M('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S
M8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A=&5G
M;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!P87-S
M=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S
M=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.
M97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I;VYS`$YI9VAT`$YO`$YO(&%V86EL
M86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F
M;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G
M97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE
M(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D
M(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD
M<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U
M;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`
M3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F
M9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%14
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S
M`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP
M;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<G1H97)N($AE;6ES<&AE
M<F4`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I
M;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H
M:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E
M<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R
M;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES
M=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A
M;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P
M87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@
M<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S
M`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A
M(&YE=R!W:6YD;W<`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/
M<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E
M9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N
M:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@
M4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@5"U3=&]R;7,`4$]325@@97AT96YS
M:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A<G1L>2!#;&]U
M9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A
M<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!0
M87-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S
M:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O
M<FUA=&EO;@!0971S`%!H;VYE`%!H;W1O<P!0:7AE;',`4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@
M82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T
M>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L:71I8W,`4&]L;',`4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z
M(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0
M<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R
M;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X
M=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%%U97)Y
M`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO
M;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@
M86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E
M860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;&%T:6]N<VAI
M<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@
M0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@
M<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R
M;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z(`!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E
M="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T
M>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N
M`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT
M(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`
M4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E
M<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(')O=W,@;VYL>0!2=6X`4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3
M($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!3
M80!386UE(&9R86UE("A?<V5L9BD`4V%V90!3879E("5S`%-A=F4@3W!T:6]N
M<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D
M("5S(&-O;F9I9W5R871I;VXN`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I
M;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P
M('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E
M;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E
M>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE
M>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I
M<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z(`!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W
M`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO
M=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@
M3&%T90!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I9VX@=7``4VEG;F%T=7)E`%-I
M9VYA='5R92!!;&=O<FET:&T`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-N;W<`
M4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3
M;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B``4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO
M;@!3;W5R8V4@861D<F5S<P!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`
M4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E
M;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`
M4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%M`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P
M;&ET(')O=P!3<&]R=',`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`
M4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E
M="!!9&1R97-S`%-T<FEN9R!L:7-T`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`
M4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!D96QE=&5D
M("(E<R(N`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K
M=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=W)O=&4@
M)7,`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N
M<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C
M<FEP=`!3=7!P;W)T`%-U<FYA;64`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T
M97)M<P!4+5-T;W)M`%0M4W1O<FUS`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R
M;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!487)G970Z`%1A<VMS`%1E;&5P
M:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`
M5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`
M5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E
M;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9G5L;"!S8W)E
M96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R
M;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A
M;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M
M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G
M970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R
M96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4
M:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;65S<V%G92!S96YT(&]N("5S
M('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*
M5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E
M;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI
M;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD
M<R!M=7-T(&)E(&YU;65R:6,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@
M;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA
M>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W
M('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M
M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I
M960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S
M(B!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N
M;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES
M(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F
M;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I
M;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&9I96QD(&ES(')E<75I<F5D
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BX`5&AI<R!I<R`E<RX`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T
M96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4
M<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O;6]R<F]W`%1O<`!4;W`@9G)A;64@
M*%]T;W`I`%1R86YS;&%T:6]N<P!4<G5E(&]R(&9A;'-E`%1U`%1U<FMI<V@@
M*$E33RTX.#4Y+3DI`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``
M55),`%523#H`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG
M('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E
M;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE
M(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I
M8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E
M;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P
M>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5
M;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I
M;&5D`%5N:6-O9&4@*%541BTX*0!5;FET<P!5;FMN;W=N`%5N:VYO=VX@=7-E
M<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U
M<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E
M<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A
M9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB
M97)S`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S
M97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO
M;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U
M;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S
M97)S(&EN('1H92!S>7-T96TZ`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI
M<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``
M5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@
M=&\@<V5L96-T(&9R;VT`5F%R:6%B;&4`5F5R<VEO;@!697)S:6]N($-O;G1R
M;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`
M5F5R>2!(:6=H`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FES:6)I;&ET>0!6:7-I
M8FEL:71Y.B``5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A
M=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML
M>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H
M25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H
M87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3
M('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME
M<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`
M5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S
M<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!
M9&1R97-S`%=O<FL@4&AO;F4`65D`65E960!996%R;'D`665S`%EE<RP@22!!
M9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N
M;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L
M(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O
M('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E
M<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO
M=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF
M;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R
M($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`
M66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L
M;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`6TAI9&4@475O
M=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@
M+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E
M<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W
M`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?
M3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS
M`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`
M7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`
M9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:6UM
M961I871E`&EN;&EN90!L:6YE<UT`;F%M90!N;W0@:6UP;&5M96YT960`;F]T
M('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&EX96QS`')I<VEN
M9P!S:&]W(&1I9F9E<F5N8V5S`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E
M<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S(`I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ
M,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#<M,#@@,34Z,C<K,#(P
M,`I,87-T+51R86YS;&%T;W(Z06UI<FMA8FER($UE=&%N971W;W)K:6YG(&QT
M9"X@/'!E<G-I86XM:&]R9&5`;65T86YE='=O<FMI;F<N8V]M/@I,86YG=6%G
M92U496%M.B!097)S:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U6
M97)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/5541BTX"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`HV+'9
MB-BR(-F"V*C9A"`E<RD`*-JIV83;C-BO(-BOV+/8JMBQV+/;C"`E<RD`*-BO
MV+$@)7,@V+'9B-BR*0`@*-BGV878L=F(V+(I`"`HV8'8L=BOV*<I`"`HV*_;
MC-BQV8C8LBD`(-BOV+$@`"(E<R(@V*C9AR#:K]BQV8C9A^*`C-F'V*?;C"#8
ML]BGV878I]F&V8<@V*?8MMBGV8'9AR#8M-BO`"(E<R(@V*C9AR#8L]BGV878
MI]F&V8<@V878K-F(V++B@(S9A]BG(-BGV+;8I]F!V8<@V+38KP`B)7,B(-BG
MVXS8K-BGV*\@V8;8M-BOV8<@V*C9B-BO.B`E<RX`)2XR9DU"(-BGV+/8JMF!
MV*?8K]F'(-BTV*_9AR#8I]BR("4N,F9-0B#9A=BLV*?8LB`H)2XR9DU"*0`E
M9"`E<R#9B"`E<P#8I]BSV84@V+'9A=BR(-BTV878IR`E9"#8L=F(V+(@V*_;
MC-JOV+$@V878N=BJV*C8L2#8I]BSV*HN`-F^VXS8M,*MV*C;C-F&VXP@)60M
MV+'9B-BRV8<`)7,@+2#8JMF(V*S9AP#8I]BKV+$@V*?9AMJOV+38JB`E<P#:
MJ=N,V839B-BHV*?;C-BJ("5S`"5S(-BYV879A-N,V*?8JB#9AMJOV8?8K]BG
MV+';C"`M(-BJV*/;C-N,V*\`(-BQV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,
M("5S(``E<R#8J]BHV*H@V8;8I]F%`-BTV+'9B-BW(-BJV8C8I]F!V8(@)7,`
M)7,@V*?8LB#9@MBHV80@V879B-BLV8C8KR#8I]BSV*H`)7,@V*_8L2`E<R`E
M<P`E<R#8HMF%V*?8K]F'(-BGV*S8L=BGVXP@V+G9A=F$VXS8I]BJ(-F&VJ_9
MA]BOV*?8L=N,(-BGV8;8JMBNV*?8J"#8M-BOV8<@V*?8L]BJ+B#8K-BYV*C9
MAR#9A]BQ(-BYV879A-N,V*?8JMN,(-BQV*<@VJG9AR#9A]F%(-BGVJG9AMF(
MV88@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BLV+'8IR#:J=F&VXS8KR#8N=F$
MV*?9A=BJ(-BHV++9AMN,V*\`)7,@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ
M`"5S(-BOV8+;C-F"V8<`)7,@V;[;C-BOV*<@V8;8M-BO`"5S(-BHV8<@)7,@
MV*?8LB`E<P#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR`E<P#8JMF"V8C;C-F%
M("5S`"5S)W,@3F]T97!A9`#9@=F'V+'8L]BJ(-F(V+C8I]N,V8$@)7,`)7,Z
M("5S`-B,(-BHV*?8KP#8C"#8J-BGV*\@)7,@)7,`V(P@V878JMBZVXS;C-BQ
M(-BGV+(@)7,@V*C9AR`E<P`@V*?9AMBJV*[8I]BH(`#9@MBGV838J"#;L=NR
M(-BSV*?8N=BJVXP`V8+8I]F$V*@@V[+;M"#8L]BGV+G8JMN,`-NRV[0@V+/8
MI]BYV*K9AP#;C-JI(-F^V+38JMN,V*C8I]F&(-BOV*?8K]JOV*?9AB#8J-BQ
MV*?;C"#8I]N,V88@V*C9A-BGVJD@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ
M`-N,VJD@V*[8M]BGVXP@V*S8K]N,(-BQV*X@V*_8I]BOV8<@V*?8L]BJ`-N,
MVJD@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@V*C8L=BGVXP@V+'9A=BRV*C9
MAMBOVXP@VXS:J2#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8
MJ@#;C-JI(-JIV83;C-BO(-BYV879B-F%VXP@4$=0(-BHV+'8I]N,(-BHV*?8
MLMBHVXS9AMN,(-N,VJD@V;[;C-BZV*?9A2#8I]F%V+;8I]BA(-BTV*_9AR#9
MA=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9
MA=N,V(P@VXS:J2#:J=F$VXS8KR#8KMBUV8C8M=N,(%!'4"#9B"#;C-JI(-BY
MV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-BQV878LMJOV+38I]N,VXP@VXS:
MJ2#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JI
MV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@
M4$=0(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V*?9A=BV
MV*?8H2#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ
M`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@VJG9A-N,V*\@V*[8
MM=F(V+7;C"!3+TU)344@V8@@VXS:J2#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQ
MV*?;C"#8L=F%V++:K]BTV*?;C-N,(-F^VXS8NMBGV84@V879B-BQV*\@V8;;
MC-BGV+(@V*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@
MVJG9A-N,V*\@V*[8M=F(V+7;C"!3+TU)344@V8@@VXS:J2#8N=BHV*?8L=BJ
M(-JOV+#8L2#8J-BQV*?;C"#8I]F%V+;8I]BA(-N,VJD@V;[;C-BZV*?9A2#9
MA=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9
MA=N,(%,O34E-12#8J-BQV*?;C"#8L=F%V++8J-F&V*_;C"#9OMN,V+K8I]F%
M(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#8J-BGV+'8I]F&(-BSV*C:J2#8
MM=BHV*W:K]BGV8?;C`#8J-BGV+'8I]F&(-BUV*C8K=JOV*?9A]N,`-BQVJ_8
MJ-BGV+$@V+78J-BMVJ_8I]F'VXP`V*K:K]BQVJ\@V+78J-BMVJ_8I]F'VXP`
MV+78J-BM+]BYV+78L0#8K]BQV*C8I]BQV8<@V*?;C-F&(-F(VXS8L=BGV+/8
MJMBGV+$`V*_8L=BHV*?8L=F'+BXN`-F^V*?;C-N,V88@V878M]F$V8(`V8C8
ML]BW(-F%V+?9A-F"`-BGVXS8K-BGV*\@V+38I]BNV8<@5D93(-F%V*S9B-BR
M(-BOV+/8JMBQV+/;C"#9AMBOV*?8L=BO`-BGVXS8K-BGV*\@V;[8L=F(V8;8
MK]F'(%9&4R#9A=BLV8C8LB#8K]BSV*K8L=BSVXP@V8;8K]BGV+'8KP#8I]BW
MV838I]BYV*?8JB#8K=BSV*?8J`#8I]BSV84@V+'9A=BR(-BMV+/8I]BH`-BM
MV+/8I]BH(-F%V+/8K]F(V*\`V*W8L]BGV*C8K]BGV+';C`#8I]BVV*?9@=F'
M(-JIV+'8K]F&`-BGV+;8I]F!V8<@VJG8L=BOV88@VJ_8L=F(V8<@V8'8L=BY
MVXP`V*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BLV8C8LB#9@=BQV+G;C.*`C`#8
MI]N,V8;8K-BG(-BGV+;8I]F!V8<@VJG9ACH`V*?8MMBGV8'9AR#:J=BQV*_9
MAB#:K]BQV8C9AR#8K-BOVXS8KP#8I]BVV*?9@=F'(-JIV+'8K]F&(-F%V*S9
MB-BR(-BLV*_;C-BO`-BGV+;8I]F!V8<@VJG8L=BOV88@VXS:J2#9A=BLV8C8
MLB#9@=BQV+G;C"#8J-F'("(E<R(`V*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI
M(-JIV*?8L=BHV+$@V*S8K]N,V*\Z`-BGV+;8I]F!V8<@VJG8L=BOV88@V+/8
MJMF(V88`V*?8MMBGV8'9AR#:J=BQV*_9AB#8I]BYV+;8I]N,(-BLV*_;C-BO
M`-BGV+;8I]F!V8<@VJG8L=BOV88@V++9B-BL`"#8I]BVV*?9@=F'(-JIV+'8
MK]F&(-JOV++;C-F&VJ_8I]F&("5S(-BHV+G9AMF(V*?9AB#9AMF(V*?8L2#8
MK-BGV8;8J-N,(-F%V8C8LMN,V838IP#8I]BVV*?9@=F'(-JIV+'8K]F&(-BH
MV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,Z`-BGV+;8I]F!V8<@VJG8L=BO
MV88@V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#9A=F&`-BGV+;8I]F!
MV8<@V8/8L=BOV88@VJG8I]BQV*C8L0#8I]BVV*?9@=F'(-JIV+'8K]F&(-JI
MV*?8L=BHV+'8I]F&(-F!V+G8I]F$(-F&VXS8L]BJ`-BBV*_8L=BS`-JIV*K8
MI]BHVH;9A]F4(-BBV*_8L=BS(`#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'
M+2#8JMBYVXS;C-F&(-F%V*S9B-BRV8?8I]N,(-JIV*?8L=BHV+'8I]F&(-BO
MVXS:K]BQ`-BSV+'9OMBQV+/8JMN,`-BJV*C9A-N,V+K8I]BJ`-F%V+G8I]BO
MV80`V*K8L=BGV+(@VJG8L=BOV88`V*K8L=BGV+(Z`-F'V879AP#8JMF%V*?9
MA=N,(-JIV*?8L=BHV+'8I]F&(-BJV*/;C-N,V*\@V+79A-BGV*W;C-BJ(-BT
MV*_9AP#9A]F%V8<@VJ_8L=F(V8?B@(S9A]BG`-F'V879AR#9A=BLV8C8LN*`
MC-F'V*<`V8?9A=F'V90@VH;9A]BGV+$@V+/9A=BJ`-BGV*S8I]BRV8<@VH;9
MAMBO(-BBV*_8L=BSVXP`V*+;C-BG(-BGV*S8I]BRV8<@V*K9AMBXVXS9A2#9
MAMF(V+D@V8'9A]BQV+/8JB#9A=BQV*K8J"#8K]BGV*_9AR#8M-F(V*_8GP#8
MI]BR(-F"V*C9A"#9A=F(V*S9B-BO(-BGV+/8J@#9B-BQV8C8KR!)35-0(-BL
MV*?;C-JOV++;C-F&`-BGV+/9A2#8L=F%V+(@24U34"#8K-BGVXS:K]BRVXS9
MA@#9AMBGV84@VJG8I]BQV*C8L=N,($E-4U`@V*S8I]N,VJ_8LMN,V88`V*+8
MK]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8K-BGVXS:K]BRVXS9
MA@#8I]F$VJ_9B.*`C-F'V*?;C"#8K-BGVXS:K]BRVXS9A@#9A=BJV88@V*S8
MI]N,VJ_8LMN,V88Z`-N,VJD@V879@MBOV*?8L2#9AMBGV*_8L=BSV*H@V*K8
MN=N,VXS9AB#8M-BOV8<@V*C9B-BO`-F^VXS8M-JIV*?8L0#9OMBGV+/8K@#8
MJ-BQV8;8I]F%V8?9E.*`C"#:J=BGV+'8J-BQV*_;C`#9@=F'V+'8L]BJ(-BH
MV+'9AMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C`#8J-BQV8;8I]F%
MV8<@V*+9A=BGV*_9AR#8I]BSV*H`V*?8N=F%V*?9A"#8J-BQ(-BQV8C;C"#8
MI]BTV*K8L=BGVJG9A]BGVXP@V8'8L=BYVXP`V*K8M=F(VXS8J`#8I]F&V*_8
MI]BRV8<@V*K9@MBQVXS8J-N,`-BBV8C8L=N,V80`07)A8FEC("A7:6YD;W=S
M+3$R-38I`-BGV8;8K]BGV++9AR#9OMBQV8C9AMBOV8<@V*+8L=BTVXS9B`#9
MAMBGV84@V*+8L=BTVXS9B`#8HMN,V*<@V+39A=BG(-F%V+?9A=BFV8;;C-BO
M(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BWV838I]BYV*?8JB#8I]F!
MV*K8JMBGV*T@V*W8L]BGV*@@)7,@V+'8IR#9OMBGVJD@VJG9AMN,V*_8GP!!
M<FUE;FEA;B`H05)-4T-)22TX*0#9A]F&V+$`V*+;C-BG(-F"V*C9A"#8I]BR
M(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C"#8J-BQV*?;C"#8JMBCVXS;
MC-BO(-BBV88@V+/8IMF(V*?9A"#8M-F(V*_8GR``V*?9AMBJV+/8I]BH(-BS
MV*K9B-F&V8?8IP#8L]BYVXP@V*_8L2#8K=BPV8$@VJ_8L=F(V8?;C"#8M-BO
MV8<@V*?8L]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8J@#8L]BYVXP@V*_8
ML2#8K=BPV8$@V878K-F(V++;C"#8M-BOV8<@V*?8L]BJ(-JIV8<@V879B-BL
MV8C8KR#9AMN,V+/8J@#8L]BYVXP@V*_8L2#9B-N,V+'8I]N,V+0@V878K-F(
MV++;C"#8M-BOV8<@V*?8L]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8J@#8
ML]BYVXP@V*_8L2#9B-N,V+'8I]N,V+0@V*?8M-BJV+'8I]JIVXP@V+38K]F'
M(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`XH",V8C;C-J8VJ_;
MC-F'V*<`V*+:K]F(V+/8J@!!=71H7V-Y<G-Q;#H@V*C8L]BW(-F%V8C8L=BO
M(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?8WER<W%L.B#8
ML]BGV878I]F&V8<@V;[8M-BJVXS8J-BGV88@V8+8I]BHV83;C-BJV8?8I]N,
M(-F%V8C8L=BO(-F&VXS8I]BR(-BQV*<@V8;8K]BGV+'8KP!!=71H:6UP.B#8
MJ-BSV+<@V879B-BQV*\@V8;;C-BGV+(@24U!4"#9OMN,V*_8IR#9AMBTV*\`
M075T:%]F='`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!&5%`@V;[;C-BO
MV*<@V8;8M-BO`$%U=&A?:6UP.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@
M24U!4"#9OMN,V*_8IR#9AMBTV*\`075T:%]K<F(U.B#8J-BSV+<@V879B-BQ
MV*\@V8;;C-BGV+(@:W)B-2#9OMN,V*_8IR#9AMBTV*\`075T:%]L9&%P.B#8
MJ-BSV+<@V879B-BQV*\@V8;;C-BGV+(@3$1!4"#9OMN,V*_8IR#9AMBTV*\`
M075T:%]L9&%P.MBGV+;8I]F!V8<@VJG8L=BOV88@VJG8I]BQV*C8L2`E<R#9
MA=F%VJG9AB#9AMN,V+/8JBX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'
M(-JIV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*H`075T:%]L9&%P.MBMV+#9
M@2#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ(`!!=71H7VQD87`Z
MV*C8L=F(V++8L=BSV*?9AMN,(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;
MC-BSV*H`075T:%]M8V%L.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@34-!
M3"#9OMN,V*_8IR#9AMBTV*\`075T:%]S;6)A=71H.B#8J-BSV+<@V879B-BQ
MV*\@V8;;C-BGV+(@<VUB875T:"#9OMN,V*_8IR#9AMBTV*\`V*K8M=BOVXS9
M@B#9A]F(VXS9D=BJ(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP#8JMBUV*_;C-F"
M(-F'V8C;C-F1V*H@V8;8I]F%V8C9@=F1V8(@V*C9B-BO+B`E<P#8JMBUV*_;
MC-F"(-F'V8C;C-F1V*H@V*?8LB#8M]BQV8$@VJG8I]BQV+/8I]BR(%)!1$E5
M4R#8L=BO(-BTV*_9AR#8I]BSV*H`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BO
MV+$@VJG8I]BQV+/8I]BR($944"#9AMBGV879B-F!V9'9@B#8J-F(V*\@`-F!
MVXS9A-BOV8?8I]N,(-F"V*?8J-F$(-BOV+/8JMBQV+/;C#H`V;[8L^*`C-BR
MV87;C-F&V8<`V+'9AMJO(-F^V+/B@(S8LMF%VXS9AMF'`-BGV+/9A2#8L=F%
MV+(@V8;8I]BOV+'8L]BJ(&ME<F)E<F]S`-F&V*?9A2#:J=BGV+'8J-BQ(-F&
MV*?8K]BQV+/8JB!K97)B97)O<P!"86QT:6,@*$E33RTX.#4Y+3$S*0#8KMBW
M(-F%V*C9AMBG`-BHV839B-JI("(E<R(@V*?8LB#8J-BQV8;8I]F%V8?9E"#:
MJ=BGV+'8J-BQV*_;C"`B)7,B(-N,V*?9@=BJ(-F&V+38KP#8JMF&V+C;C-F%
MV*?8JB#8J-F$V8C:J0#9AMF(V+D@V*C9A-F(VJD`V+/;C-BGV8<`VH;9B-BH
M(-BGV839@0#9A-BHV8<`V;[9A]F&V*?;C"#9A-BHV8<Z`-F$V*C9A^*`C-F'
MV*<`V8?8L2#8K]F(`-F^V*?;C-N,V88`V83;C-BSV*H@V*C9B-F$V*KB@(S8
MK]BGV+$`0TU3`$-20P#9AMF"V*?8MR#8JMF(V++;C-BY($-23`#8KMBUV8C8
MM=N,V*?8JB#8L]F$V8C9A"XN+@#8JMF"V8C;C-F%`-BBV+'8I]F%`-F&V87;
MC.*`C-BJV8C8I]F&(-BGV+/9A2#8L=F%V+(@V+'8IR#8J-BWV8C8L2#8KMF(
MV*_:J=BGV+$@V*_9B-BHV*?8L=F'(-BHV*?8LMF&V+38I]F&V*_8C"#8J-BG
M(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO(-BJV878I]BS(-BH
MVJ_;C-BQVXS8KP#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9
MAR`B)7,B(-F&V8C8M-BJ`-F&V87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQ
MV+/8I]BR(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V878JMBUV80@V+38
MKSH@)7,`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'("(E<R(@V+'8
MIR#8J-BGV+(@VJG8L=BO`-BGV8;8M=BQV*?9@0#8I]F&V+78L=BGV8$@V*?8
MLB#8I]BQV+/8I]F$(-JOV++8I]BQV+0`V8;9A=N,XH",V*K9B-BGV88@V;[8
ML=F(V8;8K]F'("(E<R(@V+'8IR#8K=BPV8$@VJG8L=BO("``V8;9A=N,XH",
MV*K9B-BGV88@VXS:J2#8M-BGV*[9AR#9A=F(V8+8JB#9OMN,V*_8IR#:J=BQ
MV*\`V8;9A=N,XH",V*K9B-BGV88@V*C8K]F(V88@V;[8I]BQV*?9A=BJV+$@
M)]F^V+'9B-F&V*_9AR#9A=F"V+78KR<@V*?8K]BGV879AR#8K]BGV*\`V8;9
MA=N,XH",V*K9B-BGV88@V+38I]BNV8<@(B5S(MBQV*<@V*W8L-F!(-JIV+'8
MKR``V8;9A=N,XH",V*K9B-BGV88@V*W8L-F!(-F&V879B-BOV(P@)60@V8'8
ML=BRV8;8KR#9A=F(V*S9B-BO(-BGV+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#8
MK]F(V*C8I]BQV8<@V878L=BJV*@@V8;9A=F(V*_8C"#8J-BQV*[;C"#8I]BR
M(-F(V+'9B-BOVXS9A]BGVXP@V8'8L=BGV8?9A2#8M-BOV8<@V*C8L=BGVXP@
MV878L=BJV*@@V+/8I]BRVXP@V*C8IR#8M-F%V*?8L=F'XH",V8?8I]N,(-BP
MV*[;C-BQV8<@V+38K]F'V(P@V+/8I]BRVJ_8I]BQ(-F&VXS8L]BJ`-F&V87;
MC.*`C-BJV8C8I]F&(-F^VXS8NMBGV84@V+'8IR#8J-F'(-BTV878I]BQV8<@
MV*K8N=N,VXS9AB#8M-BOV8<@VJ_8L-BQ(-BOV*?8KP#8N=F&V8C8I]F&`-BM
MV*?9A=F$`-JOV+'9B-F'XH",V8?8IR#9B"#8J-BQVH;8L]BHV8?8IP#9A=F(
MV*C8I]N,V80`V*[8M=F(V+7;C-BGV*H@V+/9A-F(V80`V8'8I]BUV839AR#8
ML]F$V8C9A`#8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A`#9@=BGV+79A-F'XH",
MVJ_8L-BGV+';C"#8L]F$V8C9A`#9A=F(V*C8I]N,V80`0V5L=&EC("A)4T\M
M.#@U.2TQ-"D`V878L=JIV+(`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BD`V*S8LMBFVXS8I]BJ(-JOV8C8I]F'VXP@`-BSVXS8I]BSV*K9A]BGVXP@
MVJ_9B-BGV8?;C`#8JMBZVXS;C-BQ(`#8I]BSV84@V+'9A=BR(-BNV8C8KR#8
ML=BG(-BJV+K;C-N,V+$@V*_9A]N,V*\`V*K8NMN,VXS8L=BOV*?8K]F&(-F&
MV*?9A2#9B"#8HMBOV+'8L]N,(-JIV8<@V*?9@=BQV*?8KR#9A]F&VJ_8I]F%
M(-BNV8C8I]F&V*_9AB#9B"#9OMBGV+/8KB#8K]BGV*_9AB#8J-F'(-F&V*?9
MA=F'V90@V+39A=BG(-BNV8C8I]F'V8;8KR#8K]N,V*\@`-BJV+K;C-N,V+'8
MK]BGV*_9AB#8I]BSV84@V+'9A=BR(-BTV878IR#8K]BQ(-F^VXS:J=BQV*C9
MAMBOVXP@V8'8N=F$VXP@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S8M-F(
MV*\N(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8KMF(V*\@V*K9
MA=BGV+,@V*C:K]N,V+';C-BO`-F&V8C;C-BSV8<`V*C8L=BQV+/;C"#9OMN,
MV8C9AMBO+BXN`.*`C`!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`V*?9AMBJV*[8I]BH(-N,VJD@V*?8
ML]F%(-BQV878L@#8I]F&V*K8KMBGV*@@VXS:J2#9AMBGV84@VJG8I]BQV*C8
ML=N,`-BGV8;8JMBNV*?8J"#:AMJOV8C9AMJOVXP@V8;9A=BGVXS8M"#8JMBG
MV+';C-BN.@#8I]F&V*K8KMBGV*@@V8;9B-BY(-BSV*C:J2#9@=F'V+'8L]BJ
M("C8J-BQV*?;C"#9@=F'V+'8L]BJV8?8I]N,(-F%V+'8JMBH*0#8JMBYV+';
MC-F!(-JIV838I]BS("5S(-N,V*?9@=BJ(-F&V+38KP#8M=BGV8$`V;[8I]JI
M(-JIV+'8K]F&(-BJVJ_9A]BGVXP@35-/9F9I8V4`V;[8I]JI(-JIV+'8K]F&
M(-JIV*?8L=BHV+$@.B`E<P#9OMBGVJD@VJG8L=BOV88@VJG8I]BQV*C8L0#9
MOMBGVJD@VJG8L=BOV88@V*_8I]BOV8?9E"#:J=BGV+'8J-BQ`-BHV+'8I]N,
M(-BGV*_8I]F%V8?8C"#:J=F$VXS:J2#:J=F&VXS8KP!#;&EC:V%T96QL(-BG
MV+(@V+?8L=N,V8(@2%144`#8J-BSV*K9AB#9OMF&V*S8L=F'`-BGV*C8L=F'
MV*<`V*?8J-BQVXP`V*S9A=BY(-BTV*_9AB#9AMF(V*?8L2#:J=F&V*?8L=N,
M`-J&V878N2#8M-BOV88@V838J-F'XH",V8?8IP#8L=F&VJ\`V*?9AMBJV*[8
MI]BH(-JIV8;9AMBOV8<@V+'9AMJO`-BGV8;8JMBNV*?8J"#8L=F&VJ\`V+/8
MJMF(V8;9A]BG.@#8N=F&V*?9B-N,V88@V+/8JMF(V8;9A]BG`-F%V+;8K=JI
M`-F!V+'9A=BGV88`V;[9B-BSV*K9AR#9@=BQV878I]F&`-BJV8C8MMN,V*T`
MV8;8I]F%(-BYV879B-F%VXP`V+38L=JIV*H`V+'8I]N,V*?9AMF'XH",V8?8
MIP#8M-BQV+<`V+38L=BGVXS8MP#8JMF!V*?9B-BJV8?8I]N,(-F^VXS:J=BQ
MV*C9AMBOVXP`V;[;C-JIV+'8J-F&V*_;C"`E<P#8JMBCVXS;C-BO(-BGV+/9
MA2#8L=F%V+(`V*?8JMBUV*?9A"#9AMBGV879B-F!V9'9@B#8J-F(V*\`V*?8
MJMBUV*?9A"#9AMBGV879B-F!V9'9@B#8J-F(V*\`V*?8JMBUV*?9A"#8J-F'
M(-JIV*?8L=BSV*?8LB#:J=F$VXS8KR#8N=F%V8C9A=N,(-BQV*\@V+38KP#8
MI]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR(-JIV83;C-BO(-BYV879B-F%
MVXP@V+'8KR#8M-BO+B#8K]F$VXS9A#H@)7,@*"5S*0#8I]BJV+78I]F$(-BH
MV8<@VJG8I]BQV+/8I]BR($944"#9AMBGV879B-F!V9'9@B#8J-F(V*\`V8;9
MA=BGV+/9A]BG`-BJV878I]BSV8?8IR#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@
MV*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8M-F%V*<@V*?8MMBGV8'9
MAR#8M-BOV8<@V*C9B-BO`-BGV*_8I]F%V8<`VJG9B-JIVXP`V+'9B-F&V8C8
MM-BJ`-BQV8C9AMF(V+38JB#8J-BQV*_8I]BTV*K9AB#8I]BR(-BHV*[8M"#8
MI]F&V*K8KMBGV*C;C`#9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@
MV+'8IR#8L=F%V++8J-F&V*_;C"#:J=F&V*\@4$=0`-F&V87;C.*`C-BJV8C8
MI]F&V*\@V;[;C-BZV*?9A2#8L=BG(-BGV878MMBGV*$@VJG9AMBO(%!'4`#9
MAMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8L=F%V++8J-F&
MV*_;C"#:J=F&V*\@4R]-24U%`-F&V87;C.*`C-BJV8C8I]F&V*\@V;[;C-BZ
MV*?9A2#8L=BG(-BGV878MMBGV*$@VJG9AMBO(%,O34E-10#9AMF%VXSB@(S8
MJMF(V*?9AB#8JMF%V*?8L]F'V*<@V+'8IR#8I]BVV*?9@=F'(-JIV+'8KR`E
M<P#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!,1$%0(-F^
MVXS9B-BSV*H@`-F&V87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR
M(&QD87`@V;[;C-F(V+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#8J-BGV838I]F&
MV+,@V+'8IR#:AMJI(-JIV+'8KR`E<P#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'
M(-JIV*?8L=BSV*?8LB!L9&%P(-F%V*K8M=F$(-BTV*\`V8;9A=N,XH",V*K9
MB-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V*?;C-BLV*?8KR#:J=BQ
MV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-BOV*?8K]F'(%!'4"#8L=BG(-BQ
MV878LMJOV+38I]N,VXP@V8;9A=F(V*\@`-F&V87;C.*`C-BJV8C8I]F&(-BO
MV*?8K]F'(%,O34E-12#8L=BG(-BQV878LMJOV+38I]N,VXP@V8;9A=F(V*\@
M`-F&V87;C.*`C-BJV8C8I]F&(-BJV878I]BS(-BQV*<@V*W8L-F!(-F&V879
MB-BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,
MV+G;C"#8L=BG(-BMV+#9@2#9AMF%V8C8KRX@)7,`V8;9A=N,XH",V*K9B-BG
MV88@V*+8K]BQV+,@VJ_;C-BQV8;8K]F'(-F&V*?9A=F'V90@V*?9A-JIV*K8
ML=F(V8;;C-JIVXP@V+'8IR#8JMBTV*[;C-BU(-BOV*?8KP#9AMF%VXSB@(S8
MJMF(V*?9AB#:J=F$(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BQV*<@V8C8
MI]JIV+3;C"#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=F$(-F!V8?8
ML=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V8C8I]JIV+3;C"#9AMF%V8C8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-JIV*?9A=F$(-F!V8?8L=BS
MV*H@V*K9B-BRVXS8N=N,(-BQV*<@V8C8I]JIV+3;C"#9AMF%V8C8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#:J=F$VXS8KR#8N=F%V8C9A=N,(-BQV*<@V*?8LB#:
MJ=BGV+'8L]BGV+(@VJG9A-N,V*\@V*C8K]BSV*H@V*+9B-BQV*\`V8;9A=N,
MXH",V*K9B-BGV88@)7,@V+'8IR#8J-BGV+(@VJG8L=BO`-F&V87;C.*`C-BJ
MV8C8I]F&(-F%V*_9B-F$(-F(V+C8I]N,V8$@V8;:K]F'V*_8I]BQVXP@)7,@
MV+'8IR#8J-BGV+(@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@)7,@V+'8
MIR#8KMF(V*?9AMBO`-F&V87;C.*`C-BJV8C8I]F&(-BGV+/9A2#8L=F%V+(@
MV+'8IR#8J-BQV*?;C"#:J=BGV+'8J-BQ(-F%V8C8L=BO(-F&V+C8L2#8J-BG
MV++9AMBTV*?9AMBO+B#8J-BYV+;;C"#;C-BG(-F'V879AR#8K-BRV*;;C-BG
MV*H@V878L=BHV8C8MR#8J-F'(-BBV88@V8;8I]BOV+'8L]BJ(-F%VXSB@(S8
MJ-BGV+38KRX@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KR#;C-BG(-BH
MV+'8I]N,(-JIV87:J2#8J-N,V+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ(-BS
MV*?9A=BGV8;9AR#8KMF(V*\@V*K9A=BGV+,@V*C:K]N,V+';C-BO`-F&V87;
MC.*`C-BJV8C8I]F&($%#3"#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8
MHMF(V+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=BJV*?8J-J&V8?9E"#8HMBO
MV+'8LR#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,`
MV8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8
MIR#8K]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\N("5S`-F&V87;C.*`
MC-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*_9B-BH
MV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9
MAB#9@MBGV*C9A-N,V*K9A]BGVXP@VJG8I]BQV+/8I]BR(-BQV*<@V*_9B-BH
MV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^
MVXS:J=BQV*C9AMBOVXP@V+'8IR#8J-BGV++:K]BQV*_8I]F&V*\`V8;9A=N,
MXH",V*K9B-BGV88@V;[;C-JIV+'8J-F&V*_;C"`E<R#8L=BG(-BOV*[;C-BQ
MV8<@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@
MV;[8M-BJVXS8J-BGV88@V+'8IR#8K=F!V+@@VJG8L=BO`-F&V87;C.*`C-BJ
MV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@V;[8M-BJVXS8J-BGV88@V+'8IR#8
MK=F!V+@@VJG8L=BO.B`E<R``V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8
MK]F'(-F^V+38JMN,V*C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8IR#8
MK=F!V+@@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#9
MOMN,VJG8L=BHV8;8K]N,("5S(-BQV*<@V*W9@=BX(-F&V879B-BO+B#8M-F%
MV*<@V87;C"#8JMF(V*?9AMN,V*\@V*?8LB#;C-JIVXP@V*?8LB#:K]BRVXS9
MAMF'XH",V8?8IR#8J-BQV*?;C"#8K=F!V+@@VJG8KR#8J-BQ(-BQV8C;C"`E
M<R#8I]BSV*K9@=BGV*_9AR#9AMF%V*?;C-N,V*\@V8@@VXS8IR#8I]N,V8;:
MJ=F'(-BGV+(@VJG8KR#8J-F'(-BUV8C8L=BJ(-BOV+/8JMN,(-BOV+$E<R#8
ML=F(V8;9B-BTV*H@V*K9A]N,V8<@V8;9A=BGVXS;C-BO`-F&V87;C.*`C-BJ
MV8C8I]F&(-JIV*?8L=BSV*?8LB!,1$%0(-BQV*<@V*S8L]BJV*S9B"#:J=BQ
MV*\`V8;9A=N,XH",V*K9B-BGV88@V*K9A=BGV+,@(-BQV*<@V*C8L=F(V++8
ML=BSV*?9AMN,(-JIV+'8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V8'9A]BQ
MV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8J-BQV8C8LMBQV+/8I]F&VXP@VJG8
ML=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9AMF(V*?8L2#8K-BGV8;8J-N,
M(-F%V8C8LMN,V838IR#8L=BG(-F^VXS8K]BG(-JIV+'8KRX@V878M]F%V*;9
MAB#8M-F(VXS8KR#:J=F'(-F&V8C8I]BQ(-BLV*?9AMBHVXP@V*C8I]BR(-BG
MV+/8J@#9A=BJV88@V+39A=BGV+'8M"#8M-BOV8<`VJG8M-F(V+$`V*_9B-BQ
MV8?B@(S9A]BG`-BGVXS8K-BGV*\`V*?;C-BLV*?8KR#;C-JI(-F^VXS9B-F&
MV*\`V*?;C-BLV*?8KR#;C-JIVXP@V*S8K]N,V*\`V*?;C-BLV*?8KR#8LMN,
MV+'9OMF(V+39A^*`C-F'V*<`V878K-F(V++9A]BGVXP@V*?;C-BLV*?8KR#:
MJ=F&V8;8K]F'`-BTV878I]BQV8<@VJG8I]BQV*H@V*?8N=BJV*C8I]BQVXP`
MV+/8I]BYV*H@V8'8N=F$VXP`55),(-F!V+G9A-N,(-F'V+/8J@#8HMBH(-F(
M(-F'V8C8I]N,(-F!V+G9A-N,`-BTV+'8I]N,V+<@V8'8N=F$VXPZ(`#8L]BH
MVJD@V8'8N=F$VXP`V+/9@=BGV+'8M-N,(-JIV+'8K]F&(-F(V+C8I]N,V8$@
MV8?9AMJOV*?9A2#9B-BQV8C8KR#8J-F'("5S`-BHV+';C-BOV88`V*C8L=N,
MV*_9AB#8I]F&V*K8KMBGV*@`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@
M*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$
M`-BQV8C8LMBGV8;9AP#9A=BQV8C8L=JOV+$@V*_8L=BNV*H@V*_8I]BOV8<`
MV*K8I]BQVXS8K@#8JMBGV+';C-BN(-BOV+';C-BGV8'8JB#8M-BOV8<`V*K8
MI]BQVXS8KB#8I]F&V*K8KMBGV*@`V+'9B-BR`-BMV+#9@2#8L]BJV8C9A@#8
MK]BSV*?9A=BHV+$`V*?8N=BOV*?8KR#8K]F'V*_9A]N,`-JIV84@VJG8L=BO
MV88@V*K9B-BQV8'8JMJOVXP`V;[;C-BT(-F!V+'8M@#8L=F&VJ\@V;[;C-BT
M(-F!V+'8M@#9A]F(VXS9D=BJ(-F^VXS8M"#9@=BQV+8`V;[9B-BSV*K9A]F4
M(-F^VXS8M"#9@=BQV+8`V*K8N=BGV+';C-F!`-BMV+#9@0#8K=BPV8$@VJ_8
ML=F(V8<`V*W8L-F!(-F%V*S9B-BR`-BMV+#9@2#9B"#9OMBGVJG8L]BGV++;
MC"#9OMN,V+K8I]F%V8?8IP#8K=BPV8$@V+/9A-F(V80`V*W8L-F!(-BSV*K9
MB-F&`-BMV+#9@2#8I]F$VJ_9B-N,(-BLV*?;C-JOV++;C-F&(-F%V8C8K-F(
MV*\`V*W8L-F!(-F%V*S9B-BRV8?8IR#8J-BQV*?;C"`@(B5S(@#8HMN,V*<@
MV878K-F(V++9A]BG(-F((-BRVXS8L=F%V*S9B-BRV8?8IR#8J-BQV*?;C"`B
M)7,B(-BMV+#9@2#8M-F(V*_8GP#8K=BPV8$@V+/8M]BQ`-BMV+#9@2#9A]F(
MVXS9D=BJ(-BGV8;8JMBNV*?8J"#8M-BOV8<`V*W8L-F!(-BSV*K9B-F&(-F!
MV+G9A-N,`-BMV+#9@2#8L]BWV+$@V8'8N=F$VXP`V++9A=BGV88@V*?8L=BS
MV*?9A`#8M-BQV*T@V878M-JIV80`V*K9B-BVVXS8K0#8K-BRV9#8IMN,V*?8
MJCH`(-BLV++8IMN,V*?8JB#8J-BQV*?;C"#8L]BQV;[8L=BSV*H@V+/8I]F%
MV*?9AMF'(-BKV*C8JB#8M-BOV8<@V*?8L]BJ`-JOV+/8JMBQV+0`V8;9@MBW
MV8<@V+38J-F&V84`V8;9@MBWV8<@V+38J-F&V84@V*C8L=BGVXP@V+/8I]BY
MV*H@VJ_8L-BTV*K9ASH@`-F&V8+8M]F'(-BTV*C9AMF%.B``V*S9A]BJ(-BG
MV+(@VH;9OB#8J-F'(-BQV*?8L]BJ`-BLV8?8JB#8I]BR(-BQV*?8L]BJ(-BH
MV8<@VH;9O@#8M-BGV*[9AP#8HMN,V*<@V++9A=BGV88@,C0@V+/8I]BYV*K9
MAR#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?`-JOV++;C-F&V8?B@(S9
MA]BGVXP@V8;9A=BGVXS8M`#9AMF%V*?;C-BT(-BLV++8IMN,V*?8JB#9OMN,
MV+3"K=BHVXS9AMN,`-F&V878I]N,V+0@V;[;C-BTPJW8J-N,V8;;C`#9AMF%
MV*?;C-BT(-F"V*?9A-BH`-BMV*?9A-BJ(-BJV+#:J=BQ`-BMV+#9@2#9AMBT
MV8C8KP#8K]BSV*K8L=BSVXP@V878L]BJV8+;C-F%(-BHV8<@;6%I;G1E;F%N
M8V4N<&AP(-F%V87:J=F&(-F&VXS8L]BJ`-BBVXS8IR#8L]BWV+$@V*?9B-F$
M(-BTV*?9A=F$(-F!VXS9A-BO(-F&V*?9A2#9A=N,XH",V*C8I]BTV*_8GR#8
MI]JOV+$@VH;9AMN,V88@V*?8L]BJV(P@V*?;C-F&(-BLV+G8J-F'(-BQV*<@
MV+G9A-BGV878JB#8J-BRV8;;C-BO.@#8I]BSV*K9@MBQV*?8L0#8I]BSV*K9
M@MBQV*?8L2`E<P#8I]BSV*K9@MBQV*?8L2#9OMN,VJG8L=BHV8;8K]N,(-BJ
MV8C9A-N,V*\@V+38K]F'(-BHV+G9AMF(V*?9AB#8K]BSV*H@V8;9B-N,V+,@
M4$A0`-F!V8?8L=BSV*H@V;[8I]N,VXS9AN*`C-F^V+$`V*_8I]BQV8C9A]BG
M`-F&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:J=N,`$524@#9B-N,V+'8I]N,
MV+0`V8C;C-BQV*?;C-BT(-BHV839B-JI`-F(VXS8L=BGVXS8M"#:K]BQV8C9
MAP#9B-N,V+'8I]N,V+0@V878K-F(V+(`V8C;C-BQV*?;C-BT(-F%V*S9B-BR
MV8?8IP#9B-N,V+'8I]N,V+0@V878K-F(V++9A]BG(-BHV+'8I]N,("5S`-JO
MV++;C-F&V8?B@(S9A]BGVXP@V8C;C-BQV*?;C-BT.@#9B-N,V+'8I]N,V+0@
MV878K-F(V++B@(S9A]BG(-BHV+'8I]N,("(E<R(`V8C;C-BQV*?;C-BT(-F%
MV*S9B-BRXH",V8?8IR#8J-BQV*?;C"`E<P#8JMBMV+7;C-F$V*?8J@#8N=F&
MV+78L2XN+@!%;0#9AMBGV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C`#8HMBO
MV+'8LR#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,`-BBV*_8L=BS
MV8?8I]N,(-F&V*?9A=F'XH",V8?8I]N,(-BGV83:J=BJV+'9B-F&VXS:J=N,
M(-BHV*?;C-BO(-F%V8;8M]BHV8(@V*C8I]BTV*\`V8;8I]F%V8?9E"#8I]F$
MVJG8JMBQV8C9AMN,VJG;C"#8J-BG(-BJV*/;C-N,V*\`V*?8K=BSV*?8L]BG
MV*H`V*[8I]F$VXP@VJG8L=BOV88@V;[;C-BZV*?9A2``V*[8I]F$VXP@VJG8
ML=BOV88@V8;8JMN,V*S9AP#8KMBGV83;C"#:J=BQV*_9AB#9A=F(V*?8L=BO
M(-BLV+/8JMBLV8@`V*+;C-BG(-BOV+'8K"#8JMBUV*?9B-N,V+$@V*?8LB#:
MK]BGV838L=N,V8?8I]N,(-BYVJG8LR#8K]BQ(-F%V*K9AB#9@=BYV*?9A"#8
MM-F(V*_8GP#8HMN,V*<@VJ_8LMN,V8;:K]BGV88@V++9A=N,V8;9AR#8L=F(
MVXP@VJG9A-N,VJD@V+'8I]BSV*H@V8'8N=BGV80@V+39B-BOV)\`V*?9AMBJ
MV8?8I]N,(-BSV*?9A`#8J-BRV+':KR#:J=BQV*_9AB#9B-N,V+'8I]BSV*K8
MI]BQ`-N,VJD@V+/8IMF(V*?9A"#8I]F%V8;;C-BJVXP@V*C8L=BGVXP@V;[8
ML=BSV+0@V*?8LB#8M-F%V*<@V*C9AR#9A]F&VJ_8I]F%(-BHV*?8LMF&V+38
MI]F&V*_9AB#8I]BSV84@V+'9A=BR(-F(V*?8L=BO(-JIV8;;C-BOV(P@V878
MJ]F$V*?9DB`GV8;8I]F%(-BMVXS9B-BGV88@V*[8I]F&VJ_;C"#8M-F%V*<@
MVH;;C-BSV*K8GR<`55),(-BJV+79B-N,V+$@V+'8IR#8I]N,V8;8K-BG(-F(
MV*?8L=BO(-JIV8;;C-BO`-BNV+?8IP#8J-F$V8C:J2#8I]N,V*S8I]BO(-BN
MV+?8ISH@)7,`V*[8M]BG(-BOV+$@VJG8L]BH(-F%V*W8JMF(V*<Z)7,`V*[8
MM]BG(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-BGV+/9A2#8L=F%V+(@.B`E
M<P#8KMBWV*<@V*C8IR#9OMN,V+K8I]F%(-F&V*?9A=F'V90@V*?9A-JIV*K8
ML=F(V8;;C-JIVXP`V+G8JMN,V8+9AP#8I]BQV8C9OMBG`-F'V+$@V;[8I]F&
MV++8K]F'(-BOV8+;C-F"V8<`V8?8L2#8K]F((-BOV8+;C-F"V8<`V8?8L2#8
ML]N,(-BOV8+;C-F"V8<`V8?8L2#9OMF&V*P@V*_9@MN,V8+9AP#8K]BQ(-F'
MV+$@V8C8L=F(V*\`V8?8L2#9AMN,V84@V+/8I]BYV*H`V8?8L2#8K]F"VXS9
M@MF'`-F%V8+8I]BOVXS8L2#9A=BKV*?9A#H`V*?8K-BQV*<`V*C8I]BR(-JI
MV+'8K]F&`-BHV*?8LMJIV+'8K]F&(-F&V8C8I]BQ(-JIV8;8I]BQVXP`V*?9
MAMBJV+C8I]BQ(-BHV+'8I]N,("<H)P#8JMBGV+';C-BN(-BGV8;9@MBVV*?8
MH0#9AMF%V*?;C-F&V*_9AP#8L=F&VJ\@V;[;C-BTXH",V++9A=N,V8;9AP!&
M5%`@=7!L;V%D(&]F('-E='5P`"#8J-BGV++;C-BGV*C;C"#8JMF"V*_9A=BG
MV*H@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`"#8I]BJV+78I]F$(-BHV8<@VJG8
MI]BQV+/8I]BR($Q$05`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`"#8I]BJV+78
MI]F$(-BHV8<@VJG8I]BQV+/8I]BR(%--0B#9AMBGV879B-F!V9'9@B#8J-F(
MV*\@`"#8JMF'VXS9AR#8L=F(V8;9B-BTV*H@V*?8LB`B)7,B(-F&V*?9A=F(
MV8'9D=F"(-BHV8C8KP#8I]N,V*S8I]BO(-BQV8C9AMF(V+38JB#8K]BQ("(E
M<R(@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`"#8I]N,V*S8I]BO(-N,VJD@V*?8
MJMBUV*?9A"#8K-BOVXS8KR!305-,(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP`@
MV*?9AMBJV8+8I]F$(-BHV8<@(B5S(B#9AMBGV879B-F!V9'9@B#8J-F(V*\`
MV838M]N,V8$`V*[8M]BGVXP@V*S8K]N,.B``V8':J=BS`-F!V8C8L=N,V8<`
MV+':K]BHV*?8L2#8KMF!VXS9@0#:J=F%VXP@V*K:K]BQVJ\`V+39A=BGV+'8
MM"#9OMBQV8C9AMBOV8<Z("5S(-F^V+'9B-F&V*_9AP#8M-F%V*?8L=BT(-F^
MV+'9B-F&V*_9ASH@)7,@V;[8L=F(V8;8K]F'`-F%V*_;C-BQ(-F^V+'9B-F&
MV*_9AP#9AMBGV84@V;[8L=F(V8;8K]F'`-BGV8;8JMBNV*?8J"#9OMBQV8C9
MAMBOV8<`V*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<`V*?8L=BSV*?9A"#9OMBQ
MV8C9AMBOV8<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S8M-F(V*\N+@#9
M@=N,V838JMBQV8?8IP#9AMN,V879AR#8I]F(V80`V+'8J-BY(-BGV8C9A`#9
MAMBSV*C8JB#8J]BGV*C8J@#8I]BYV+38I]BQVXP`V879A^*`C-BBV839B-BO
M`-F^V8C8M-F'("5S(-F%V8C8K-F(V*\@V8;;C-BSV*H@`-BQV8;:KR#9@MF$
MV84`V+K8L-BG`-BHV+'8I]N,(-F%V+'9B-BQVJ_8L=F'V*?;C-N,(-JIV8<@
MV*K8M=BGV8C;C-BQ(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:
MJ=F&V8;8KP#9OMN,V+3"K=BHVXS9AMN,`-BGV+/9A2#8L=F%V+(@V*[9B-BO
M(-BQV*<@V8'8L=BGV879B-BT(-JIV+'8K]F'XH",V*?B@(S;C-BOV)\`V8'8
ML=F%V8?8IP#8M]BGV838N0#9AMF(V+D@V+?8I]F$V+D`V+?8I]F$V+G9A]BG
M`-BWV*?9A-BYV8?8IR#;L@#8I]F&V*S9A=F&V8?8IP#8I]BQV*S8I]BYV8?8
MIP#8K-F%V+G9AP#:AMBGV+':AMF(V*C9A]BG`-BGV+(`V*?8LB``V+38L=BM
M(-JIV*?9A=F$`-F%V*?9AR#:J=BGV879A`#9AMBGV84@VJG8I]F%V80`VJ_8
MI]F$V+';C"#8J-BQV*?;C"#8K]BQVXS8I]F!V*H@V*K8M=F(VXS8L2``VJ_8
MI]F$V+';C#H`V*K9B-F$VXS8KR#9OMN,VJG8L=BHV8;8K]N,("5S`-JIV*\@
MV*K9B-F$VXS8KR#8M-BOV8<`V8;8I]F%(-BOV*?8K]F'(-BTV*_9AP#8J-BQ
MV8@`V*S8L]F&V*S9B-N,(-JOV8C:K]F$`-BOV+'8K-F'(-BNV*?:J=BSV*K8
ML=N,`$=R965K("A)4T\M.#@U.2TW*0#8L]BQV;[8L=BSV*K;C"#:K]BQV8C9
MAP#9AMBGV84@VJ_8L=F(V8<@V8;8J-BGVXS8KR#8KMBGV83;C"#8J-BGV+38
MKP#:K]BQV8C9AR8C>#(P,&,[V8?8IP#9A=BLV8C8LMF'V*?;C"#9A=F'V878
MI]F&`-JIV*K8I]BHVH;9A]F4(-N,V*?8K]BHV8C8KP!(5$U,`$A434Q!<F5A
M(-BMV+#9@2#8HMBNV+';C-F&(-BSV839B-F$(-BQV*<@V*_8L2#8L=BOVXS9
M@2#8L=BO(-F%VXSB@(S:J=F&V*\`2%1-3$%R96$@V*W8L-F!(-BBV*[8L=N,
MV88@V+/8JMF(V88@V+'8IR#8K]BQ(-BLV*_9B-F$(-BQV*\@V87;C.*`C-JI
MV8;8KP!(5$U,07)E82#8K=BPV8$@V*+8KMBQVXS9AB#8L=BOVXS9@2#8L=BG
M(-BOV+$@V*S8K]F(V80@V+'8KR#9A=N,XH",VJG9AMBO`-BJV+78K]N,V8(@
MV8?9B-N,V9'8JB!(5%10(-N,V*?9@=BJV8<@V8;8M-BO`-BGV83:K]F(V+';
MC-BJV84@2&%S:`#9A=F'XH",V*+9A-F(V*\`V+/8L=BBV878KP!(96)R97<@
M*$E33RTX.#4Y+3@M22D`V*C9A-F&V*_;C`#8L=BGV8?9AMF%V*<`V+'8I]F'
MV8;9A=BGVXP@V*?8L]BJV8'8I]BOV8<@V*?8LB#9B-N,V+'8I]N,V+3:K]BQ
M`-JIV87:J2#:J=F&V8;8K]F'`-F&VXS9A>*`C-JIV+'9AP#8I]N,V8;8K-BG
M(-BGV*C8JMBOV*?;C"#9OMBQV8C9AMBOV8?B@(P@V87;C.*`C-BHV*?8M-BO
M.@#8J-BGV838IP#8KMBGV8;9AP#8KMBGV8;9AP#8HMBOV+'8LR#8KMBGV8;9
MAP#8M-BGV*[9A]F4(-BGV+79A-N,`-BTV878I]BQV8<@V*K9A-F!V88@V879
MAMBRV80`V8?9B-BQV*\`2&]R9&4O2V]L86(Z("5S(-BHV*<@V*_8I]BOV8<@
MV8;8I]BOV+'8L]BJ(%A-3"#8K]BQ(-F^VXS8NMBGV84@)7,@V879B-BGV*S9
MAR#8M-BOV8<@V*?8L]BJ`$AO<F1E+TMO;&%B.B#9A]N,VH8@V;[;C-BZV*?9
MA=N,(-F%V+?8I]BHV8+8JB#8J-BG(-BTVXS8H2`E<R#9AMBOV*?8L=BO`$AO
M<F1E+TMO;&%B.B#9A]N,VH8@V+3;C-BFVXP@V*?8LB#9AMF(V+D@)7,@V*_8
ML2#9OMN,V+K8I]F%("5S(-N,V*?9@=BJ(-F&V+38KP!(;W)D92]+;VQA8CH@
MV*C8IR#9A=F(V8'9D=F"VXS9D=BJ("5S("(E<R(@V*W8L-F!(-BTV*\`2&]R
M9&4O2V]L86(Z(-BJV8C9A-N,V*\@VXS:J2#8K]BQV*[8JB#8K-BOVXS8KR!8
M34P@V*C8L=BGVXP@V+3;C-BA("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@`$AO
M<F1E+TMO;&%B.B#8K=BPV8$@)7,@(B5S(CHE<R#9A=F"V*_9B-BQ(-F&VXS8
ML]BJ`$AO<F1E+TMO;&%B.B#8J-BGV++;C-BGV*C;C"`@34E-12!)1"#8J-BQ
MV*?;C"#9@MBSV878JMN,(-BGV+(@V8;9B-BY("5S(-F%V8+8K]F(V+$@V8;;
MC-BSV*H@`$AO<F1E+TMO;&%B.B#8L]F&VJG8L=F(V88@VJG8L=BOV88@)7,@
M(B5S(CH@)7,@V879@MBOV8C8L2#9AMN,V+/8J@!(;W)D92]+;VQA8CH@V+/9
MAMJIV+'9B-F&(-JIV+'8K]F&(-BGV+38JMBQV*?:J=F'V*<@V879@MBOV8C8
ML2#9AMN,V+/8JCH@)7,`2&]R9&4O2V]L86(Z(-BGV+38JMBQV*?:J2#9AMBG
MV+39AMBGV*[8JMF'("(E<R(`V8+8I]F&V8C9AB#8I]F!V8+;C`#9@=BGV+79
MA-F'XH",VJ_8L-BGV+';C"#8I]F!V8+;C``ZV*?9@=F"VXP`VH;:K]F(V8;9
MAR#8J-BG(-BGVXS9AMBLV*<@V*+8M-F&V*<@V+38K]N,V*_8GR`HV838M]F!
MV*?9BR#:K]BRV*?8L=BT(-BOV8?;C-BO*2$`VH;9AMBO(-BSV*K9B-F&(-BQ
MV*<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BOV+K8I]F%(-JIV8;;C-BOV)\`
MVH;9AMBO(-F!VXS9A-BO("C8L]BJV8C9ABD@V8C8K-F(V*\@V*_8I]BQV*_8
MGP#:AMF&V*\@V+/8M]BQ(-BQV*<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BO
MV+K8I]F%(-JIV8;;C-BOV)\`V+'8M]F(V*C8J@#8L=BWV8C8J-BJ.B``V*?;
MC-BLV*?8KR#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"
M(-BHV8C8KSH@("5S`-BMV+#9@2#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&
MV*?9A=F(V8'9D=F"(-BHV8C8KR`Z("5S`-BGVXS8K-BGV*\@V878K=BOV8C8
MK]N,V9'8JB#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"
M(-BHV8C8KR`Z("5S`-BBV*_8L=BS($E0`-BBV*_8L=BS($E0(-F"V*?8J-F$
M(-BOV+/8JMBQV+/;C"#9AMN,V+/8J@#8HMBOV+'8LR!)4"#8K]BQ(-BOV*?8
MKMF$(-BHV839B-JI($-)1%(@V*?8K-BGV++9AR#8K]BGV*_9AR#9AMF%VXSB
M@(S8M-F(V*\`V*?8J-BJV*_8IR#8L]BWV+$@V+'8IR#9B-BGV+'8KR#:J=F&
MVXS8KP#9@=F"V+<@V*+;C-JIV8C9AMF'V*<`V*+;C-JIV8C9AMF'V*<@V*C8
ML=BGVXP@)7,`V*+;C-JIV8C9AMF'V*<@V*C8IR#9A=BJV88`V8;8I]F%(-F'
MV8C;C-F1V*HZ`-BGVJ_8L2#8HMF&(-BHV8<@V*_8L=BSV*K;C"#9AMF%V*?;
MC-BT(-BOV*?8K]F'(-F&V+38K]B,("5S("#8J-BQV*?;C"#8J-BGV+(@VJG8
ML=BOV88@V*+9AB#8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8KP#8I]JO
MV+$@V+39A=BG(-F'VXS:AB#8HMN,VJG9B-F&VXP@V+'8IR#8K]BQ(-F%V+'9
MB-BQVJ_8L2#9AMBHVXS9AMN,V*_8C"#9A=F%VJG9AB#8I]BSV*H@V838I]BR
MV84@V*C8I]BTV*\@VJG9AR!03D<@5')A;G-P87)E;F-Y(-BQV*<@V*[8I]F%
MV8C8M"#:J=F&VXS8KP#8I]JOV+$@V+39A=BG(-BGVXS9AB#9OMN,V+K8I]F%
M(-BQV*<@V878M-BGV8?8K]F'(-JIV8;;C-BO(-BGV878IR#8JMBUV8C;C-BQ
MVXP@V+'8IR#9A=BTV*?9A]BOV8<@V8;:J=F&VXS8K]B,(-BGVXS9AB#8J-F'
M(-BGVXS9AB#8N=F$V*H@V*[9B-BGV8?8KR#8J-F(V*\@VJG9AR#9A=BQV8C8
ML=JOV+$@V+39A=BG(-F!V*?8K]BQ(-BHV8<@V8;9A=BGVXS8M"#8JMBUV8C;
MC-BQ(-F&VXS8L]BJ(`#9OMN,V+3B@(S9AMF%V*?;C"#8JMBUV8C;C-BQ.@!5
M4DP@V*K8M=F(VXS8L0!54DP@V*K8M=F(VXS8L3H`V*K8M=F(VXS8L2#8I]BR
M(-JOV*?9A-BQVXP`V*K8M=F(VXS8L2#8I]BR(-JOV*?9A-BQVXPZ`-BGV+'8
ML]BGV80@V*K8M=F(VXS8L0#8JMBUV*?9B-N,V+$`V*_8L=F(V8;B@(S8J-BQ
MV*_8C"#:K]BGV84@)60`V8';C-F$V*\@V*_8L=F(V8;B@(S8J-BQV*\@V+38
MK]F'.B`E<P#9@=N,V838K^*`C-F'V*?;C"#8K]BQV8C9AN*`C-BHV+'8KR#8
MM-BOV8<Z`-BHV+G8K]BGV8L@V+/8M]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMN,
MV*\`VJG8KR#8N=F%V83:J=BQV*\@V8;8I]BOV+'8L]BJ(-BOV*?8K]F'(-BT
MV*_9AR#8I]BSV*H`(-F&V*?9A2#:J=BGV+'8J-BQ+]BGV+/9A2#8L=F%V+(@
M(-F&V*?8K]BQV+/8JB#8I]BSV*H`V8;8I]F%(-JIV*?8L=BHV+$@VXS8IR#8
MHMBOV+'8LR#8K-BGVXS:K]BRVXS9AB#9AMBGV*_8L=BSV*H@V87;C.*`C-BH
MV*?8M-BO+B#9A-BWV8'8IR#9A=BLV*_8K]BGV9(@V+/8N=N,(-JIV8;;C-BO
M(-F((-N,V*<@V*_8L2#8M=F(V+'8JB#9AMN,V*?8LB#8J-F'(-JIV87:J2#8
MJ-N,V+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8JMF%
MV*?8LR#8J-JOVXS8L=N,V*\`V*?9@=BRV*?;C-BT(-BJV8C8L=F!V*K:K]N,
M`-JIV*?8L=BHV+'8I]F&(-BNV*?8M0#8I]BWV838I]BYV*?8J@#8I]BWV838
MI]BYV*?8J@#8I]BWV838I]BYV*?8JB#8K]N,VJ_8L2#8K]BQ(-BOV+/8JMBQ
MV+,@V8;;C-BSV*H`V*_8L=BL(-BSV*K9B-F&(-BHV+G8KR#8I]BR`-BOV+'8
MK"#8JMBUV8C;C-BQ`-BOV+'8K"#8K-BOV8C9A`#8K]BQV*P@V;[;C-F(V8;8
MKR#9B-BH`-BGV*C8JMBOV*<@V+/8JMF(V88@V+'8IR#8K]BQV*P@VJG9AMN,
MV*\`VXS:J2#8L]BJV8C9AB#8K-BOVXS8KR#8J-BYV*\@V*?8LB#8L]BJV8C9
MAB#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\`VXS:J2#8L]BJV8C9AB#8K-BO
MVXS8KR#9@MBHV80@V*?8LB#8L]BJV8C9AB#9@=BYV83;C"#8K]BQV*P@VJG9
MAMN,V*\`VXS:J2#8L]BWV+$@V*S8K]N,V*\@V*C8N=BO(-BGV+(@V+/8M]BQ
M(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KP#;C-JI(-BSV+?8L2#8K-BOVXS8
MKR#9@MBHV80@V*?8LB#8L]BWV+$@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO
M`-N,VJD@V;[8I]BQV*?:K]BQV*?9@2#8J-BYV*\@V*?8LB#:K]BQV8<@V8'8
MN=F$VXP@V*_8L=BL(-JIV8;;C-BO`-N,VJD@V;[8I]BQV*?:K]BQV*?9@2#9
M@MBHV80@V*?8LB#:K]BQV8<@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO`-BO
MV+'8K"#8I]F$VJ_9B-N,(-BLV*?;C-JOV++;C-F&`-N,VJD@V*+8K]BQV+,@
MV;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8J-BQV*?;C"#8K]BQVXS8I]F!
MV*H@V*?8L]F%(-BQV878LB`@V*S8K]N,V*\@V*_8L=BL(-JIV8;;C-BO(`#8
MK]BQV*P@V+/9A-F(V80@V*C8N=BO`-BOV+'8K"#8L]F$V8C9A"#9@MBHV80`
MV*_8L=BL(-BSV*K9B-F&(-BHV+G8KP#8K]BQV*P@V+/8JMF(V88@V8+8J-F$
M`-BOV+'8K"#9OMN,V+K8I]F%`-BOV+'8K"#9OMBGV+'8I]JOV+'8I]F!(-BH
MV+G8KP#8K]BQV*P@V;[8I]BQV*?:K]BQV*?9@2#9@MBHV80`V*_8L=BL(-BS
MV+?8L2#8J-BYV*\@`-BOV+'8K"#8L]BWV+$@V8+8J-F$`-F^V*?8L]BN(-F%
MV8C8L=BO(-F&VXS8I]BR(-BQV*<@V*C8L=BGVXP@V+/8IMF(V*?9A"#8I]F%
MV8;;C-BJVXP@V*_8L=BL(-JIV8;;C-BO.@#8K]BQV*POV*K8NMN,VXS8L2#8
MJMBUV8C;C-BQ`-BOV+'8K"_8JMBZVXS;C-BQ(-F^VXS9B-F&V*\`V*?8N=BJ
MV*C8I]BQ(-F&V*?:J=BGV8';C"#8J-BQV*?;C"#8I]BQV+/8I]F$(-BHV8<@
MV8'9A]BQV+/8JB#8JMF(V++;C-BYVXP`V*?8N=BJV*C8I]BQ(-F&V*?:J=BG
MV8';C`#8N=BOV*\@V+78K=N,V*T`V8'9A]BQV+/8JB#8N=BOV*\@V+78K=N,
MV*T`541((-F&V*?9A=BYV*K8J-BQ`-BHV+'9AMBGV879A]F4(-JIV*?8L=BH
MV+'8K]N,(-F&V*?9A=BYV*K8J-BQ`-BOV+/8JMF'($E$(-F&V*?9A=BYV*K8
MJ-BQ`-BOV*?8K]F'V90@V8;8I]F%V+G8JMBHV+$@V*?8L=BGV*;9AR#8M-BO
MV8<`V*+8K]BQV+,@V879@MBUV*\@V8;8I]F%V+G8JMBHV+$`V8+8I]F$V*@@
MV;[8L=F(V8;8K]F'V90@V8;8I]F%V+G8JMBHV+$`V8;9B-BY(-F^VXS8NMBG
MV84@V8;8I]F%V+G8JMBHV+$`87!I7VED(-F&V*?9A=BYV*K8J-BQ(-BGV+/8
MJB#9B"#;C-BG(-BGV+(@V*C;C-F&(-BQV8'8JMF'(-BGV+/8J@#9OMBGV+'8
MI]F%V*K8L2#9AMBGV878N=BJV*C8L2#9B"#;C-BG(-BGV+(@V*C;C-F&(-BQ
MV8'8JMF'`-F%V*S9B-BR(-F^V*_8L2#9AMBGV878N=BJV*C8L0#9OMBQV8C8
MJMJIV80@V8;8I]F%V+G8JMBHV+$`VJ_;C-BQV8;8K]F'V90@V8;8I]F%V+G8
MJMBHV+$Z("(E<R(`V+3;C-BA(-BHV8<@V*?8M-BJV+'8I]JI(-JOV+#8I]BT
MV*K9AR#8M-BOV8?9E"#9AMBGV878N=BJV*C8L0#8HMBOV+'8LR#8L]BQVH;8
MM-F%V8<@V8;8I]F%V+G8JMBHV+$`V*_8I]BOV8<@VXS9B-F&VXS:J=BO(-F&
MV*?9A=BYV*K8J-BQ(`#9A=F(V*S9B-BOVXP`V*C8L=JOV+'8K]BGV8;8K]F&
M(-BGV8;8JMBNV*?8J`!4+5-T;W)M<P#9A=F&V*K8M-BQ(-JIV8;9AMBOV8<`
MV*W8L=F(V8$@VJG8K`#:F-BGV8;9B-N,V8<`2F%P86YE<V4@*$E33RTR,#(R
M+4I0*0#8LMN,V+'9OMN,V+'8I]F'V8;;C`#:F-F(V*;;C-F'`-J8V8C8IMF&
M`-F'V87B@(S8JMBQV*?8LB#:J=BQV*_9A@#9A]F%XH",V*K8L=BGV++;C"#9
MB-BSV+<`V8?9A>*`C-BJV+'8I]BRVXP@VJG8I]F%V80`V8?9A>*`C-BJV+'8
MI]BRVXP@VH;9O@#9A]F%XH",V*K8L=BGV++;C"#8L=BGV+/8JB``V*?8M=F$
MVXP@V8;:K]F'(-BOV*?8M-BJV8<@V+39B-BOV)\`VJG8I]BQV+/8I]BR(&ME
M<F)E<F]S92#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V+'8IR#8L=BO(-JIV+'8
MKP#8I]N,V*S8I]BO(-JIV83;C-BO`-BGV*O8L2#8I]F&VJ_8M-BJ(-JIV83;
MC-BO`-BWV8C9A"#:J=F$VXS8KP#9AMF(V+D@VJG9A-N,V*\`VJG8I]BQV*C8
ML=BO(-JIV83;C-BO`-JIV83;C-BO(-F"V*C9A-BGV8L@V*_8L2#:J=BGV+'8
ML]BGV+(@V+G9A=F(V87;C"#:J=F$VXS8KR#9A=F(V*S9B-BO(-BGV+/8J@#B
M@(S8J-J&V8?B@(S9A]BG`$MO<F5A;B`H155#+4M2*0#8K-BGV8;9A=BGVXS;
MC`#8LMBHV*?9A@#9AMN,V879A]F4(-BBV*[8L0#8JMBZVXS;C-BQ(-BBV*[8
ML=N,V88@V*?8L]F%(-BQV878L@#8L=BHV+D@V*+8KMBQ`-BBV*[8L=N,V88@
MV*C8L=F(V++8L=BSV*?9AMN,.@#8HMBNV+';C-F&(-F(V+'9B-BO.B`E<P#8
MHMBNV+';C-F&(-F(V+'9B-BO(#H@)7,@V*?8LB`E<P#8HMBNV+';C-F&(-F(
MV+'9B-BO.B#9A]BQVJ_8L@#8K=F"V8C9@@#8K-BGV8;9A=BGVXS;C`#:AMF^
M`-BSV+'8HMF%V*\@VH;9O@#9A=F"V*?8K]N,V+$@VH;9O@#9AMF%XH",V8;9
MA2#8J-BGV+'8I]F&`-BHV*?8L=F&V*_:K]N,(-BSV*C:J0#8J-BGV+'9AMBO
MVJ_;C"#8L]BHVJD@V++9B-BOV8?9AMJOV*?9A0#8J-BGV+'9AMBOVJ_;C"#8
ML]BHVJD@V*_;C-BQV8?9AMJOV*?9A0#8J-BGV+'9AMBOVJ_;C"#9B"#8L=JO
MV*C8I]BQ(-BSV*C:J0#8J-BGV+'8I]F&(-BSV*C:J2#8J-F'(-F'V878L=BG
MV8<@V+'8N=BO`-BHV+'9@2#8L]BHVJD`V*C8L=F!(-F((-BQVJ_8J-BGV+$@
MV+/8J-JI`-F^VXS9B-F&V*\`V8;9@MBGV+<@V;[;C-F(V8;8KR#8J-F'.@#8
MHMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BQV*<@V*C9AR#8
MM=F!V*W9AR#8I]N,V*S8I]BO(-F^VXS8NMBGV878C"#8J-F'(-F'V8;:K]BG
MV84@V878M-BGV8?8K]F'V(P@V;[;C-F(V8;8KR#8K]F'VXS8KP#9OMN,V8C9
MAMBOXH",V8?8IP#:J=F(VJG;C"#9A-N,V8;9B-JIV+,`V8'9A]BQV+/8JB`M
M(-JIV*?8L=BHV+$@V87;C.*`C-BJV8C8I]F&V*\@V;[9B-BTV8<@V+'8IR#8
MJ-BHVXS9AMBO`-F!V8?8L=BSV*H@V*_8I]BOVJ_8I]F&V8?8I^*`C`#9@=F'
MV+'8L]BJ(-BYV8;8I]F(VXS9AB#8L=BGV8?9AMF%V*<`V8'9A]BQV+/8JB#8
MK-BOV*?9B-F$`-F!V8?8L=BSV*H@V*+8L=BTVXS9B`#9@=F'V+'8L]BJ(-BQ
MV*?9A]F&V878IP#9@=F'V+'8L]BJ($ED`-F!V8?8L=BSV*H@V878I]F$VJD`
MV8'9A]BQV+/8JB#9OMBSV*K;C`#9@=F'V+'8L]BJ(-BYV+;9B-N,V9'8J@#9
M@=F'V+'8L]BJ(-BYV*_9A2#8N=BVV8C;C-F1V*H`V8'9A]BQV+/8JB#:J=BG
MV+'8J-BQV*?9AB#9@=BYV*?9A"#9AMF%VXSB@(S8J-BGV+38KP#8I]BOV*C;
MC-BGV*H`V*C8I]BQVJG8L=BOV88N+BX`V+/8I]BYV*H@V878K=F$VXPZ(`#9
MA=BMV83;C-F1V*H@V8@@V+/8I]BYV*H`V879B-F"V+G;C-BJ`-F(V+'9B-BO
M`-BNV+'9B-BL`-F(V+'9B-BO`-F(V+C8I]N,V8$@V8C8L=F(V*\`V8C8L=F(
MV*\@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(-BRVXS8L=BG(-F&V*?9A2#:J=BG
MV+'8J-BQ(-F((-N,V*<@V*?8L]F%(-BQV878LB#9B-BGV+'8KR#8M-BOV8<@
MV*?8M-BJV*C8I]F'(-BHV8C8KR``V8C8L=F(V*\@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO+@#9A=BJV88@V*C9A-F&V*\`V+G8M-F"`-F^V*?;C-N,V88`V*W8
ML=F(V8$@VJG9B-J&VJD@VXS9B-F&V*?9AMN,`-BMV+'9B-F!(-JIV8C:AMJI
M(-F$V*?8JMN,V88`V*?8N=BOV*?8KR#:J=F(VH;:J2#;C-F(V8;8I]F&VXP`
M34T`V;[;C-BZV*?9A2#8L=F(V+(`V;[;C-F(V+/8JB!-4RU43D5&(-BTV*?9
MA=F$(-F'VXS:AB#8K]BGV*_9A^*`C-BGXH",VXS;C"#9AMN,V+/8J@!-4T<`
MV*S8I]BOV8@`V8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;C-JIVXP`V+/8L=F^
MV+'8L]BJ(-F&V*?9A=F'`-BSV*?8KMBJV88@V;[;C-F(V8;8KRXN+@#9A=BO
MVXS8L=N,V*H@V8@@V*K8N=N,VXS9AB#8L=F&VJ\@V*_8L]BJV8?B@(S9A]BG
MVXS;C"#:J=F'(-BTV878IR#9A=F(V*?8L=BO(-BQV*<@V*C8IR#8HMF&V8?8
MIR#9AMBGV87B@(S:K]BPV*?8L=N,(-F%VXSB@(S:J=F&VXS8KP!-87`R-"!M
M87``36%P475E<W0@;6%P`-F%V*?8L=BS`-BMV*?8M-N,V8<`V+G9A-BGV878
MJB#:K]BPV*?8L=N,(-BHV*<@V;[8L=J&V84@V878M-BGV8?8K]F'(-BTV*_9
MAR\@V878M-BGV8?8K]F'(-F&V+38K]F'`"#8N=F$V*?9A=BJ(-JOV+#8I]BQ
MVXP@V*C8IR#8N=F$V*?8IMF%(-BOVXS:K]BQ("C9A=BGV8;9AMBO(-F%V8?9
MA2_9OMBGV+/8KB#8K]BGV*_9AR#8M-BOV8<I`-F!VXS9A-BOXH",V8?8I]N,
M(-BGV8;8M]BHV*?9@@#8J-N,V+3;C-F&V8<@V*?8N=BJV*C8I]BQ(-F%V*S8
MI]BR`-BJV*[8M]N,(-BGV+(@V*C;C-BTVXS9AMF'(-F"V+/9A=BJV8?8I]N,
M(-F^VXS8NMBGV84`V*C;C-BTVXS9AMF'(-BOV878IR#8K]BQ(-NRV[0@V+/8
MI]BYV*H@VJ_8L-BTV*K9ASH@`-BHVXS8M-N,V8;9AR#8K]F%V*<@V*_8L2#;
MMB#8L]BGV+G8JB#:K]BPV+38JMF'.B``V*C;C-BTVXS9AMF'(-BWV8C9A`#9
MA=N,`-F^V++8M-JIVXP`V*?8N=BVV*?8H0#9A=BO(-JOV++;C-F&VJ_8I]F&
MVXPZ`-BGV*_8NMBGV84@V+/9A-F(V839A]BG`-F^VXS8NMBGV84`V;[;C-BZ
MV*?9A2#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C8I]BRV*C;C-F&VXP@V+38
MKR#8I]F%V*<@VJ_9B-BGV8?;C"#8I]F%V+;8I]BA(-JIV8;9AMBOV8<@V8;9
MA=N,XH",V*K9B-BGV8;8KR#8J-BGV++8J-N,V8;;C"#8M-F(V*\`V;[;C-BZ
MV*?9A2#9A=F&V8+8MMN,(-BTV*\`V8;9B-BY(-F^VXS8NMBGV84`V*+8J"#9
MB"#9A]F(V*?;C"!-971A<@#8J-F$V8C:J2!-971A<B#9@MBGV*C9A"#8K]BS
MV*K8L=BS(-F&VXS8L]BJ`-BHV839B-JI($UE=&%R(-F"V*?8J-F$(-BOV+/8
MJMBQV+,@V8;;C-BSV*HN(-BLV++8IMN,V*?8JB#8J-BQV*?;C"#8L]BQV;[8
ML=BSV*H@V+/8I]F%V*?9AMF'(-BKV*C8JB#8M-BOV8<@V*?8L]BJ`-BQV8C8
MM`#8I]F&V*_8I]BRV8?B@(S8I]N,`-F(V+/8MP#9AMF(V+D@36EM90`@VJG9
MA=N,V8;9AR#8K]F%V*?;C"#;LMNT(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z(``@
MVJG9A=N,V8;9AR#8K]F%V*?;C"#;MB#8L]BGV+G8JB#:K]BPV+38JMF'.B``
MV*+;C-F&V8<`V878JMF!V+'9@MF'`-F^VXS:J=BQV*C9AMBOVXP@V879B-BL
MV8C8KR#9AMN,V+/8JBX@V+39A=BG(-BGVJ_8L2#9A=N,XH",V*[9B-BGV8?;
MC-BO(-BGV+(@V*?;C-F&(-BHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,
M(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO(-BHV*?;C-BO(-BBV8;8L=BG(-BJ
MV8C9A-N,V*\@VJG9AMN,V*\`V*?8LB#8J-N,V88@V+'9@=BJV88@240@V;[;
MC-BZV*?9A0#8I]BR(-BHVXS9AB#8L=F!V*K9AB!)1"#9AMBTV+/8JB``V*_9
MB-BTV8;8J-F'`-F^V+/8JB#8L]F$V8C9A-N,`-F%V+G8JMBOV80@VJG8L=BO
MV88`V*K8I]BQVXS8KB#8JMBZVXS;C-BQ(-N,V*?9@=BJV8<`V*K8NMN,VXS8
ML2!54DP`V878I]F'(-F((-BSV*?9A`#9A=BGV8?8I]F&V8<`V8'8I]BRV8?8
MI]N,(-F%V*?9AP#8J-N,V+38JMBQ(-BUV*?9@0#8J-N,V+38JMBQ(-BGV*C8
ML=N,`-BHVXS8M-BJV+$@V*+9@=BJV*?8J-N,`-BGV8;8JMF"V*?9A"#8J-F'
M(-F^V*?;C-N,V88`V*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<`V*?9AMBJ
MV8+8I]F$(-BHV8<@V+'8I]BSV*H`V*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$
MV*<`V*?9AMBJV8+8I]F$(-BHV8<@V;[8I]N,VXS9A@#8I]F&V*K9@MBGV80@
MV*C9AR#8J-BGV838IP#9@=F'V+'8L]BJ(-F^V*?;C-N,V8;B@(S9OMBQ(-J&
MV8;8KR#8L]BWV*W;C`#:AMF&V*\@V*?9AMBJV*[8I]BHVXP`V*W8L]BGV*@@
MV879A@#8I]BWV838I]BYV*?8JB#8K=BSV*?8J"#9A=F&`-BOV+':K]BGV8<@
MV879A@#8K-BGV8;9A=BGVXS;C"#8K]BQVJ_8I]F'(-F%V88`V8;9A]B,(-F%
MV88@V879B-BGV8'9@B#9AMN,V+/8JMF%`-F&V*?9A0!54DP@V;[8I]N,V8<@
M3F5T<V-A<&4`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2
M979O8V%T:6]N(%523`#8JMF(V+;;C-BM(-JOV8C8I]F'VXP@3F5T<V-A<&4`
MV8;9B-BY(-JOV8C8I]F'VXP@3F5T<V-A<&4`V+38J-JIV8<`V8?8L=JOV+(`
MV*_8L]BJV8<@V*S8K]N,V*\`V878I]F'(-F&V8@`V8;8I]F%(-JIV*?8L=BH
MV+';C"#8K-BOVXS8KR`HV*?8KMBJVXS8I]BQVXPI`-BGV+/9A2#8L=F%V+(@
MV*S8K]N,V*\`V*?8L]F%(-BQV878LB#9A-BZV8@@V*[9B-BGV8?8KR#8M-BO
M(-BOV+$@)7@@`-BGV+/9A2#8L=F%V++9A]BGVXP@V*S8K]N,V*\@V*K8M]BG
MV*C9@B#9AMBOV*?8L=BO`-F^V8;8K-BQV8<@V*S8K]N,V*\@*-BNV*?9A-N,
M*0#8I]BNV*C8I]BQ`-JOV+'9B-F'XH",V8?8I]N,(-BNV*C8L=N,`-BHV+G8
MK]N,`-JOV++;C-F&V8?B@(S9A]BGVXP@V*C8N=BOVXP`V+38J`#9AMF'`-BO
MV*?8K]F'(-F^VXS:J=BQV*C9AMBOVXP@V*_8L2#8K]BSV*K8L=BSVXP@V*C8
ML=BGVXP@V8;8M-BGV88@V*_8I]BOV88@V*K9@=BGV8C8JMF'V*<@V8C8K-F(
MV*\@V8;8K]BGV+'8KP!)4T\@V8;;C-BSV*H@V*?8L]BJV+'8I]BJVIC;C"#8
MK]BQ(-BOV+/8JMBQV+/;C"#8J-BQV*?;C"#8L]BGV*[8JMF&(-BJV+79B-N,
MV+$@`-BGV83:K]F(VXP@V*_8L]BJV8?B@(S8I]N,VXP@V8;;C-BSV*H`V*C9
MA-BGVJG;C"#8K]BQ(-F%V8C9@MBYVXS8JB#8K]BQV*[9B-BGV+/8JB#8M-BO
MV8<@V879B-BLV8C8KR#9AMN,V+/8J@#9A]N,VH8@V8;8I]F%(-BJV8+9B-N,
MV87;C"#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@34-!3"#9@=BQ
MV*?9A]F%(-F&V+38K]F'(-BGV+/8J@#8J-BOV8C9AB#8JMBZVXS;C-BQ`-F'
MVXS:AB#9A=BLV8C8LB#9@=BQV+G;C.*`C-BGVXP@V8;9A=N,XH",V*K9B-BG
MV8;8KR#8J-F'(-BGVXS9AB#9A=BLV8C8LB#8I]BVV*?9@=F'(-BTV8C8KP#9
MA]N,VH8@V*?8M]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;
MC"`E<R#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^
MVXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@1E10(%9&4R#9A=BTV*[8M2#9AMBT
MV*\`V8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8
ML=BGVXP@4U%,(%9&4R#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BGV+?9A-BG
MV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@4U%,+49I;&4@5D93
M(-F%V+38KMBU(-F&V+38KP#9A]N,VH8@V*?8N=BJV*C8I]BQVXP@V*C8I]F"
MVXP@V8;9A=BGV8;8KP#9A]N,VH8@V879@MBUV*_;C"#9@=BQV*?9A]F%(-F&
MV+38KP#9A]N,VH8@V;[8L=F(V8;8K]F'XH",V*?;C-N,(-BGV+'8L]BGV80@
MV8;8M-BO`-F'VXS:AB#8HMN,VJG9B-F&VXSB@(P@V;[;C-BOV*<@V8;8M-BO
M`-F'VXS:AB#9A=JIV*?9AMN,(-BJV8;8N-N,V84@V8;8M-BOV8<`V8?;C-J&
M(-F^VXS8NMBGV87;C"#9@=BQV*?9A]F%(-F&V+38KP#9A]N,VH8@V8;8I]F%
MVXP@V878M-BNV+4@V8;8M-BO`-F'VXS:AB#8M-F%V*?8L=F'XH",V*?B@(S;
MC-N,(-F%V+38KMBU(-F&V+38KP#8HMN,V8;8K]F'(-F&V*?9A=BWV*C9B-BY
MVXP@V8;;C-BSV*H`V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($A4
M5%`@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ
M`-BHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!)34%0(-BGV+/9A2#8
ML=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8
MJMBUV*_;C-F"(-F'V8C;C-F1V*H@2V5R8F5R;W,@V*?8L]F%(-BQV878LMN,
M(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8I]N,(-BJV+78K]N,
MV8(@V8?9B-N,V9'8JB#9B-BQV8C8KR#8I]BSV84@V+'9A=BRVXP@V8'8L=BG
MV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(
MVXS9D=BJ(%!!4U-71"#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBT
MV*_9AR#8I]BSV*H`V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%--
M0B#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`
MV*K9@MBGV+;8I]N,(-BKV*C8JB#9AMBGV87;C"#8K]BQ(-BGV8;8JMBXV*?8
ML2#8JMBCVXS;C-BO(-F&VXS8L]BJ`-BHV*_9B-F&(-F"V8C8I]BYV*\`V8?;
MC-J&(-BLV*_8I]JIV8;9AMBOV8?B@(S8I^*`C-N,VXP@V878M-BNV+4@V8;8
MM-BO`-BHV*_9B-F&(-BSV878J@#8M-BGV*[9AR#9A=F(V8+8JMN,(-BHV+'8
MI]N,(-JIV*?8M-F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`V8?;C-J&(-F&V*?9
MA2#:J=BGV+'8J-BQVXP@V8@@VXS8IR#8I]BSV84@V+'9A=BRVXP@V*?8L=BS
MV*?9A"#9AMBTV*\`V8?;C-J&(-BOV*?8K]F'(%A-3"#9A=BYV*K8J-BQVXP@
MV*C8I]BRVJ_8L=BOV*?9AMBOV8<@V8;8M-BOV8<@V*?8L]BJ`-BHV*_9B-F&
M(-F%V8+8K]BGV+$`V8;8L]BNV8?B@(P@V*_8L2#9OMN,VJG8L=BHV8;8K]N,
M(-BGV+79A-N,(-F^VXS8K]BG(-F&V+38KRX@V;[;C-JIV+'8J-F&V*_;C"#8
ML=BG(-BOV8C8J-BGV+'9AR#8JMF(V83;C-BO(-JIV8;;C-BO`-F&V+/8KMF'
MXH",(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#8M-F%V*<@V;[;C-BOV*<@V8;8
MM-BOV8<@V*?8L]BJ+B#9OMN,VJG8L=BHV8;8K]N,(-BQV*<@V*_9B-BHV*?8
ML=F'(-BJV8C9A-N,V*\@VJG9AMN,V*\`V8?;C-J&XH",VJG8K]BGV84`V8?;
MC-J&XH",VJG8K]BGV84@*-BVV879AMN,(-BGV+/8JMF!V*?8K]F'(-JIV8;;
MC-BO*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0#9AMN,V84@VJG8L=F'(-BTV878
MI]F$VXP`V8;9AR#8J-BYV*\`V8;9AR#9@MBHV80`VXS:J2#8M-BGV*[9AR#9
MAMN,V+/8J@#9OMN,V*?8K]F'XH",V+/8I]BRVXP@V8;8M-BOV8<`V*K9AMBX
MVXS9A2#9AMBTV*_9AP#9OMBTV*K;C-BHV*?9AMN,(-F&V+38K]F'`-N,V*?8
MK]BOV*?8M-BJV8?8IP#:AMN,V++;C"#8J-BQV*?;C"#9A=BQV8C8L2#9AMN,
MV+/8JMB,(-BHV8<@V+G9@MBH(-BHV+':K]BQV*\`V8;9B-BGV878J-BQ`-BY
MV*_8KP#8JMBYV*_8I]BO(-F&V8C;C-BSV8?B@(S9A]BG`-BJV+G8K]BGV*\@
MV+/8JMF(V8;9A]BG`-BJV+G8K]BGV*\@V+/8M]BQV8?8IP#8I]BYV*_8I]BO
M(-BHV+'8I]N,(-BHV+'9B-BRV+'8L]BGV8;;C"#9@=F'V+'8L]BJ(-BJV8C8
MLMN,V+G;C"#9A=BTV*[8M2#9AMBTV*_9AMBO`-BJV*/;C-N,V*\`V+3;C-BA
M`-BGVXS8K-BGV*\@VJG9AMF&V*_9AR#8M-N,V*$`V8?8M-BJV*?;C-N,`-BG
MVJG8JMBHV+$`V8';C-F$V*K8L2#8J-N,XH",V*W8L=F%V*K;C`#8K]F!V*K8
ML2#:J=BGV+$`V*?8L]F%(-BQV878LB#8K-BOVXS8KR#9B"#8I]BSV84@V+'9
MA=BR(-F!V+G9A-N,(-BHV*?;C-BO(-F%V*K9@=BGV8C8JB#8J-BGV+39AMBO
M`-BGV+/9A2#8L=F%V+(@V8+8K]N,V87;C`#8I]BSV84@V+'9A=BR("#9@MBO
MVXS9A=N,(-F&V*?8K]BQV+/8JB#8I]BSV*H`V*K9AMF'V*<@VJG8I]BQV+/8
MI]BRV8?8I]N,($E-05#9OMF(V+39A^*`C-F'V*?;C"#9A=BTV*K8L=JI(-BQ
MV*<@V;[8M-BJVXS8J-BGV8;;C"#9A=N,XH",VJG9AMF&V*\@`-F!V8+8MR#8
MHMN,V8;8K]F'(-F&V*?9A=BWV*C9B-BY`-BJV8;9A]BG(-N,VJD@V*+8K]BQ
MV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J=N,(-F%V*S8I]BR(-BGV+/8
MJ@#8JMF&V8?8IR#9A=BGV83:J2#;C-BG(-BSV+'9OMBQV+/8JB#8L]BGV878
MI]F&V8<@V87;C.*`C-BJV8C8I]F&V*\@V878I]F$VJG;C-BJ(-N,V*<@V878
MK-F(V++9A]BGVXP@V878I]F$VJD@V+'8IR#8J-BQV*?;C"#;C-JI(-BGV+38
MJMBQV*?:J2#8JMBZVXS;C-BQ(-BOV8?8KP#8K]BQ(-N,VJD@V;[9AMBLV+'9
MAR#8K-BOVXS8KR#8J-BGV+(@V+39B-BO`-BGVXS9AB#9OMN,V8C9AMBO(-BO
MV+$@VXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO(-BHV*?8LB#8M-F(V*\`V+/;
MC-BSV*K9A2#8N=BGV879A`#:K]BRVXS9AMF')B-X,C`P8SO9A]BG`-JOV++;
MC-F&V8?B@(S9A]BGVXP@)7,`V83;C-BSV*H@V878L=BJV*@@V+38K]F'`-BS
MV*?8LMF%V*?9A@#9B-BGV*W8KR#8L]BGV++9A=BGV8;;C`#8L]BGV++9A=BG
MV8;8K]F'VXP`V*?9A-JOV8C;C"#8I]BUV83;C"#8J-BQV8;8I]F%V8?9E"#:
MJ=BGV+'8J-BQV*_;C`#8I]F$VJ_9B-F'V*?;C"#8I]BUV83;C"#8K]BQ("5S
M.@#8K]N,VJ_8L0#8I]BWV838I]BYV*?8JB#8K]N,VJ_8L0#9A=BLV8C8LN*`
MC-F'V*?;C"#9A=BGV83:J0#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@4$%-(-F"
MV*?8J-F$(-BOV+/8JMBQV+/;C"#9AMN,V+/8J@#8I]F%V+;8I]BAXH",(-BO
MVXS8K-N,V*K8I]F$VXP@4$=0`-F^VXS8NMBGV84@V+'9A=BRV*C9AMBOVXP@
MV+38K]F'V90@4$=0`"#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'4`#9OMN,V+K8
MI]F%(-BQV878LMBHV8;8K]N,(-BTV*_9AR_8I]F%V+;8I]BA(-BTV*_9AR!0
M1U``VJG8KR!02%``V;[9B-BSV*K9AR!02%``V*C8I]BQV8;8K]JOVXP@V+/8
MJ-JI(-BYV+78L=JOV*?9A]N,`-BQVJ_8J-BGV+$@V+G8M=BQVJ_8I]F'VXP`
MV*C8L=F!(-BYV+78L=JOV*?9A]N,`-BJVJ_8L=JO(-BYV+78L=JOV*?9A]N,
M`%0M4W1O<FUS`-BHV+/8MR!03U-)6"#8I]BR(-BHVXS9AB#8L=F!V*K9AR#B
M@(S8I]BSV*H`V;[9B-BSV*K9AR!02%``V8'8I]BUV839A^*`C-JOV+#8I]BQ
MVXP`V8+8L]F%V*K;C"#8I]BHV+';C`#8I]BSV84@V+'9A=BR(`#8I]BSV84@
MV+'9A=BR(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8JMBZVXS;C-BQ(-N,V*?9
M@=BJ+@#8I]BSV84@V+'9A=BR("#9AMBGV*_8L=BSV*H@V*?8L]BJ`-BGV+/9
MA2#8L=F%V+(@(-BHV8<@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%)!1$E54R#9
MAMN,V*?8LB#8K]BGV+'8KP#8I]BSV84@V+'9A=BR("#8J-BG(-BJV*/;C-N,
MV*\`V*?8L]F%(-BQV878LB`Z`-BGV+/9A2#8L=F%V+(@.B``V*?8L]F%(-BQ
MV878LN*`C-F'V*<@V*C8I]N,V*\@V879AMBWV*C9@B#8J-BGV+39AMBO`-J&
MV+/8J-BGV8;8K]F&`-J&V+/8J-BGV8;8K]F&(-BGV+(@V*K8KMBJV8<@V+'8
ML]F%`-F%V+/;C-BQ`-BKV*C8JB#9AMBGV879A]BGVXP@V8;8I]F%V+G9A-F(
MV84`V878L=BOV84`V*_8L=BUV*\`V*?8K-BQV*?;C"#8N=F%V83;C-BGV*H@
MV8;:K]F'V*_8I]BQVXP`V*+;C-BG(-BYV879A-N,V*?8JB#9AMJOV8?8K]BG
MV+';C"#8K]BQ(-F$V*W8N-F'(-F(V+'9B-BO(-BGV*S8L=BG(-BTV8C8K]B?
M`-F%V*S9B-BR`-F%V*S9B-BR("`B)7,B(-BMV+#9@2#9AMBTV*\`V878K-F(
MV++9A]BG`-BSV+'9OMBQV+/8JMN,(-F%V*S9B-BRV8?8IP#8I]BWV838I]BY
MV*?8JB#8M-BNV+7;C`#8K=N,V8C8I]F&V*?8JB#8KMBGV8;:K]N,`-BJV839
M@=F&`-BYVJG8L]F'V*<`V;[;C-JIV+/9A-F'V*<`V838M]F!V*?9BR#8K]BG
MV*[9A"#:AMF&V*\@V+/9A-F(V80@VJG9A-N,VJD@VJG9AMN,V*\`V838M]F!
MV*?9BR#8JMBCVXS;C-BO(-JIV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8I]F'
MVXS8KR#8I]N,V88@V+G9AMBUV+$@V+'8IR#8K=BPV8$@VJG9AMN,V*\Z`-F$
MV+?9@=BGV8L@V*K8H]N,VXS8KR#:J=F&VXS8KR#:J=F'(-F%VXSB@(S8KMF(
MV*?9A]N,V*\@V;[;C-F(V8;8KR#8I]N,V88@V+G9AMBUV+'9A]BG(-BQV*<@
MV8+8M]BY(-JIV8;;C-BO`-F$V+?9@=BGV8L@VXS:J2#9A=BGV8<@V8@@VXS:
MJ2#8L]BGV80@V8C8I]BQV*\@VJG9AMN,V*\N`-F$V+?9@=BGV8L@V8;8I]F%
MVXP@V*C8L=BGVXP@V*_8L]BJV8<@V*S8K]N,V*\@V8C8I]BQV*\@VJG9AMN,
MV*\Z`-F$V+?9@=BGV8L@V*+8K]BQV+,@25`@V878N=BJV*C8L=N,(-F(V*?8
ML=BO(-JIV8;;C-BO`-F$V+?9@=BGV8L@VXS:J2#8JMBGV+';C-BN(-F%V+G8
MJMBHV+$@V8C8I]BQV*\@VJG9AMN,V*_8C"#8JMBYV*_8I]BO(-BQV8C8LMF'
MV*<@V*_8L2#9A=BGV8<@V+'8IR#:J=F&V*K8L=F$(-JIV8;;C-BO`-F$V+?9
M@=BGV8L@VXS:J2#8LMF%V*?9AB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;
MC-BO`-F$V+?9@=BGV8L@V*[9A-BGV+79A^*`C-BGXH",VXS;C"#8I]BR(-F%
MV+3:J=F$(-BQV*<@V*C9AMF(VXS8L]N,V*\`V838M]F!V*?9BR#9AMBGV84@
MVJG8I]BQV*C8L2#9B"#8I]BSV84@V+'9A=BR("#8KMF(V*\@V+'8IR#8HMF%
MV*?8K]F'(-JIV8;;C-BO`-F$V+?9@=BGV8L@V878JMF&(-BRVXS8L2#8L=BG
M(-BHV*[9B-BGV8;;C-BO+B#8M-F%V*<@V*C8L=BGVXP@V*?8L]BJV8'8I]BO
MV8<@V*?8LB#8L]BGV878I]F&V8<@V*C8I]N,V*\@V+38L=F(V+<@V+'8IR#9
M@MBHV8C9A"#:J=F&VXS8KP#9A-BWV8'8I]F+(-F&V*?9A2#8K]BSV*K9AR#8
MK-BOVXS8KR#8L=BG(-F(V*?8L=BO(-JIV8;;C-BO.@#8L]N,V*?8L]BJV8?8
MIP#8HMBQV*?8H0#9A=BMV80@V8+8L=BGV+':K]BQV8'8JMF&(-BGVXS9AB#8
MJMBUV8C;C-BQ`-F%V*W9A"#9@MBQV*?8L=JOV+'9@=BJV88@V*?;C-F&(-BL
MV*_9B-F$`-F^V+/8JB#8J-F'(-BGVXS9AB#9OMF(V+39AP#8K]BQV+78KR#8
ML=BWV8C8J-BJ(-BOV+$@)7,@V+/8I]BYV*H@V8+8J-F$.@!0<F5F<U]L9&%P
M.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@3$1!4"#9OMN,V*_8IR#9AMBT
MV*\`4')E9G-?<V5S<VEO;CH@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR('-E
M<W-I;VX@V;[;C-BOV*<@V8;8M-BO`-F!V+38I]BQ`-F!V+38I]BQ(-BOV+$@
MV+/8M]BM(-BOV+';C-BG.B``V8'8M-BGV+$Z(`#9OMN,V+3B@(S9AMF%V*?;
MC-BT`-F^VXS8M.*`C-F&V878I]N,V+0@V*K8M=F(VXS8L2#8K]BQ(-N,VJD@
MV;[9AMBLV+'9AR#8K-BOVXS8KR``VJ_8LMN,V8;9A^*`C-F'V*?;C"#9@MBH
MV83;C`#:AMBGV;X@V+/9AMBO`-JIV83;C-BO(-BTV*[8M=N,`-F%V+3:J=F$
M`-BJV8C8MMN,V*T@V878M-JIV80`V;[8L=F(VIC9A^*`C-F'V*<`V878JMF&
M(-BGV+G9A-BGV88`VJG9A-N,V*\@V+G9A=F(V87;C`#8I]F$VJ_9B-BQVXS8
MJMF%(-JIV83;C-BO(-BYV879B-F%VXP`V*S9@=BJ(-JIV83;C-BO(-BYV879
MB-F%VXPOV*[8M=F(V+7;C"#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*K9B-F$
MVXS8KR#9AMBTV*\`V;[8L=BSXH",V8C8K-F(`-BSV8?9A=N,V8<`(-JIV83;
MC-BO(-BYV879B-F%VXP@4E-!("@E9"#8J-N,V*HI`-BGV8;8JMBNV*?8J"#8
ML=BGV*_;C-F(`-BHV*?8L=BGV88`V*C8I]BQV*?9AB#8LMF(V*_9A]F&VJ_8
MI]F%`-BHV*?8L=BGV88@V*_;C-BQV8?9AMJOV*?9A0#8J-BGV+'8I]F&(-F(
M(-BQVJ_8J-BGV+$`V*C8I]BQV*?9AB#9B"#8J-BQV8$`V*C8I]BQV*?9AB#8
MJ-F'(-BHV+'9@0#8M]BGV838N2#8JMBUV*?8K]F!VXP`V8;8L]BHV*H`V*[9
MB-BGV8;8K]F&`-BNV8C8I]F&V*_9AB#9OMN,V+K8I]F%V8?8IR``V8C8I]F"
MV+G8I]F2("5S(-BMV+#9@2#8M-F(V*_8GR#8I]N,V88@V+G9A=F$(-F"V*?8
MJ-F$(-F(V*?:K]BQV*\@V8;;C-BSV*H`V8C8I]F"V+G8I]F+(-BOV*?8K]F'
MV90@VJG8I]BQV*C8L=N,(-BHV+'8I]N,(-JIV*?8L=BHV+$@)7,@V*W8L-F!
M(-BTV8C8K]B?(-BGVXS9AB#8N=F%V80@V8+8I]BHV80@V8C8I]JOV+'8KR#9
MAMN,V+/8J@#8I]F&V*S8I]F%(-BBV*[8L=N,V88@V+G9A=F$(-BTV878IR#8
MI]BR(-F&V8@`V*C8I]BRV*+9B-BQVXP@V+G9AMBGV+78L2#:K]BRVXS9AMJO
MV*?9AB#8K]N,V8;8I]F%VXS:J=N,.@#8J-BGV++8HMF(V+';C"#9AMF%V*?;
MC"#8K]BQVJ_8I]F'.@#9A=BQV8C8L=JOV+$@V+'8I]BHV+?9A^*`C-BGXH",
MVXS;C`#8JMF(V+;;C-BMV*?8J@#:J=BGV+'8L]BGV++9A]BGVXP@V+'8I]F'
MXH",V*_9B-BQ`%523`#8K=BPV8$`V*W8L-F!(-BHV839B-JI`-BMV+#9@2#8
ML]BJV8C9A@#8K=BPV8$@V8+8I]F$V*@@V*C9AMBOVXP`V*W8L-F!(-BRV8C8
MK`#8K=BPV8$@V*_8L]BJ(.*`C-F&V8C;C-BSV8?8I]N,(-BMV8'8N"#8M-BO
MV8<@V*_8L2#8M-BGV*[9AR#9A=F(V8+8JB#:J=BGV+'8L]BGV+(`V*W8L-F!
M`-BMV+#9@2#8I]N,V88@VJ_8L=F'(-BGV+(@V+/9AMBO`-BMV+#9@2#:J=BG
MV+'8J-BQ`-BMV+#9@2#:J=BGV+'8J-BQ.B`E<P#8JMF"V*?8MMBG(-F"V*?8
MJ-F$(-F^V*?8L]BNVJ_9B-N,VXP@V8;;C-BSV*HN(-JIV*\@V*[8M]BGVXP@
MV*C8L=JOV+'8K]BGV8;8K]F'(-BTV*_9ASH`V8';C-F$V*_9A]BGVXP@V879
MB-BQV*\@V8;;C-BGV+(`V*C8I]BRV8;8M-BGV8;;C`#8J-BGV++9AMBTV*?9
MAMN,(-BGV+/9A2#8L=F%V+(`V*?8L]F%(-BQV878LB#8KMF(V*\@V+'8IR#8
MJ-BGV++9AMBTV*?9AMN,(-JIV8;;C-BO`-F&V*K8I]N,V*P`V*C8I]BRVJ_8
MM-BJ(-BHV8<@VJ_8LMN,V8;9A^*`C-F'V*<`V*K8I]N,V;X@V*_9B-BHV*?8
ML=F'(-BGV+/9A2#8L=F%V+(@(-BLV*_;C-BO(`#:K]BQV*_9A]F%V*?;C-N,
M`-BHV*?8LMJOV+'8K]BGV8;8K]F&(-F^VXS:J=BQV*C9AMBOVXP`VJ_8LMN,
MV8;9A^*`C-F'V*?;C"#9B-N,V+'8I]N,V+3:K]BQ(-F%V*K9A@#9A=BYV878
MI]F'V*<`V+'8I]BSV*H`V+/8L=BBV878KR#8L=BGV+/8J@#9A=F"V*?8K]N,
MV+$@V+'8I]BSV*H`V*[8M=F(V+7;C-BGV*H@V+/8M]BQ+BXN`-F&V8+8M`#:
MAMBQV*[8M"#;L=NXV[`@V*_8L=BLV8<`VH;8L=BNV+0@V*C9AR#:AMF^`-J&
MV+'8KMBT(-BHV8<@V+'8I]BSV*H`V*[8M=F(V+7;C-BGV*H@V+/8M]BQ`-BN
MV+79B-BUVXS8I]BJ(-BSV+?8L0#8L]BWV+'9A]BG.@#9@MF(V*?8N=BO`-F"
MV8C8I]BYV*\@V*C;C-F&(-BJV878I]F%(-BSV+?8L=F'V*<@V8@@V+/8JMF(
MV8;9A]BG(-F&V878I]N,V*?9AB#8KMF(V*?9A]BO(-BTV*\`V8+9B-BGV+G8
MKR#9@=F"V+<@V*C;C-F&(-BJV878I]F%(-BSV*K9B-F&V8?8IR#9AMF%V*?;
MC-BGV88@V*[9B-BGV8?8KR#8M-BO`-F"V8C8I]BYV*\@V8'9@MBW(-BHVXS9
MAB#8JMF%V*?9A2#8L]BWV+'9A]BG(-F&V878I]N,V*?9AB#8KMF(V*?9A]BO
M(-BTV*\`V*?8K-BQV*<`V;[;C-BZV*?9A2#8L=F%V++8J-F&V*_;C"`@V+38
MK]F'V90@4R]-24U%(`#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@4T%33"#9@MBG
MV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*H`V;[;C-BZV*?9A2!335,`V;[9
MB-BSV*K9AR!344P`4U-(`-F%V8C9@=F1V8+;C-F1V*H`V;[9B-BSV*K9AR!3
M44P`V+39AMBHV8<`V8?9A=BGV88@VH;8I]BQVH;9B-BH("C8KMF(V*_8M"D`
MV*W9@=BX(-JIV+'8K]F&`-BMV8'8N"#:J=BQV*_9AB`E<P#8K=F!V+@@VJ_8
MLMN,V8;9A^*`C-F'V*<`V;[;C-JIV+'8J-F&V*_;C"#8JMF(V83;C-BO(-BT
MV*_9AR#8J-BYV8;9B-BGV88@V*_8L]BJ(.*`C-F&V8C;C-BS(%!(4"#8K]BQ
M(-BTV*?8KMF'V90@V879B-F"V*H@VJG8I]BQV+/8I]BR(-BTV878IR#8K=F!
MV+@@V+39B-BO`-F^VXS:J=BQV*C9AMBOVXP@)7,@V*W9@=BX(-BTV*\`V+G9
MA-F%`-BLV+/8JN*`C-F(V*S9B`#8K-F(VXS8M-JOV+'9A]BG`-BGV8;8JMBN
MV*?8J"#9OMBQV8C9AMBOV8?B@(S9A]BG`-BGV8;8JMBNV*?8J"#;C-JI(-BJ
MV*?8L=N,V*X`V*?9AMBJV*[8I]BH(-N,VJD@VJ_8L=F(V8<@V*C8L=BGVXP@
MV*?8MMBGV8'9AR#:J=BQV*_9A@#8I]F&V*K8KMBGV*@@VXS:J2#9A=BGV83:
MJ2#8K-BOVXS8KP#8I]F&V*K8KMBGV*@@VXS:J2#:J=BGV+'8L]BGV+(`V*?9
MAMBJV*[8I]BH(-N,VJD@VJG8I]BQV*C8L2#8J-BQV*?;C"#8I]BVV*?9@=F'
M(-JIV+'8K]F&`-BGV8;8JMBNV*?8J"#9A]F%V8<`V*?9AMBJV*[8I]BH(-BJ
MV878I]F%(-F%V*39A-F!V8?B@(S9A]BGVXP@V*K8I]BQVXS8K@#8I]F&V*K8
MKMBGV*@@VXS:J2#8M-BF`-BGV8;8JMBNV*?8J"#9A]N,VH;B@(S:J=BOV*?9
MA0#9AMF(VXS8L]F'XH",V8?8I]N,VXP@VJG9AR#9A-BGV++9A2#8K]BGV+';
MC-BO(-BQV*<@V*?8LB#8K-BYV*C9AR#8LMN,V+$@V*?9AMBJV*[8I]BH(-JI
MV8;;C-BO+B#8L]F^V+,@V+39A=BG(-F%VXSB@(S8JMF(V*?9AMN,V*\@V*?8
MLB#8HMF&V8?8IR#8K]BQ(-F%V8;8M]F"V8<@V878JMF&(-F&V+/8KMF'XH",
MV*C8L=BOV*?8L=N,(-JIV+'8K]F'(-F((-BOV+$@V878K=F$(-BOVXS:K]BQ
M(-BHVH;8L]BHV*?9AMN,V*\`V*?9AMBJV*[8I]BH(-F%V*W8K]F(V*_9AR#8
MJMBGV+';C-BN.@#8I]F&V*K8KMBGV*@@V8+8I]F$V*@@V*K8I]BQVXS8KCH`
MV*?9AMBJV*[8I]BH(-F'V8C;C-F1V*K;C"#:J=F'(-F%VXSB@(S8KMF(V*?9
MA]N,V*\@V*K8NMN,VXS8L2#8K]F'VXS8KSH`V*?9AMBJV*[8I]BH(-F%V*W8
MK]F(V*_9A]F4(-BRV878I]F&.@#8I]F&V*K8KMBGV*@@V8+8I]F$V*@@V++9
MA=BGV88Z`-BGV8;8JMBNV*?8J"#8K]F((-F!VXS9A-BO(-F%V8;8M]BHV8(`
MV*?9AMBJV*[8I]BH(-BWV+'8K2#8L=F&VJ\@V+39A=BG`-BGV8;8JMBNV*?8
MJ"#8LMBHV*?9AB#9A=F(V+'8KR#9AMBXV+$@V+39A=BG.@#8I]BQV+/8I]F$
M(-JOV++8I]BQV+0`V*?8L=BSV*?9A"!335,`V*W8L]JOV+$Z(`#8L]F^V*K8
MI]F%V*C8L0#8I]BYV*_8I]BO(-BJV+'8JMN,V*C;C`!)1"#9AMBTV+/8JB#9
MA=F&V8+8MMN,(-BTV*_9AR#8I]BSV*H`V*K9AMBXVXS9A0#8JMF&V+C;C-F%
M(-JOV++;C-F&V8?B@(S9A]BG(-BHV+'8I]N,(-BGV*S8I]BRV8<@V*_8I]BO
MV88@V*C9AR#8M-F%V*<@V*C8L=BGVXP@V*C8I]BRV8;8M-BGV8;;C"#8I]BS
MV84@V+'9A=BR(-BHV8<@V8?9AMJOV*?9A2#9@=BQV*?9A=F(V+3;C"#8HMF&
M(`#8JMF&V+C;C-F%(-JIV*?8L=BSV*?8LMF'V*?;C"#8L=BGV8<@V*_9B-BQ
MVXP@VJG9AR#8M-F%V*<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BR(-BOV+':
MK]BGV8<@V*[9B-BO(-BHV8<@V*+9AB#8K]BSV*K8L=BSVXP@V*_8I]BTV*K9
MAR#8J-BGV+3;C-BO`-BGV8;8JMBNV*?8J"#8LMBHV*?9AB#9A=F(V+'8KR#9
MAMBXV+'8C"#8L]BGV+G8JB#9B"#:K]BRVXS9AMF'XH",V8?8I]N,(-BJV*?8
ML=N,V*X`V*?9AMBJV*[8I]BH(-BHV+'9AMBGV879AR#8LMF%V*?9AB#8M-BQ
MV8C8N=B,(-BWV+'8K2#8L=F&VJ_8C"#8J-BGV++8HMF(V+';C"#8M=F!V*W9
MAR#9B"#8J-F"VXS9AR#:K]BRVXS9AMF'XH",V8?8I]N,(-F&V878I]N,V+0`
MV+'8I]F')B-X,C`P8SO8I]F&V*_8I]BRVXP`V*_8L]BJ(.*`C-F&V8C;C-BS
M("#8J-BQV8C8LMBQV+/8I]F&VXP@V+'8I]F'XH",V*?9AMBOV*?8LMN,(-BO
MV+$@V*_8L]BJV+'8LR#8I]BSV*H`VH;9AMBOVXS9AB#9A=F(V8+8N=N,V9'8
MJB#8J-BG(-F^V*?8L=BGV878JMBQ(-F%V87:J=F&(-BGV+/8JCH`V*[8L=N,
MV*\`V*[9A-BGV+79AR#:J=F(V*K8I]F'`-BBVXS8IR#:J=F$VXS8K]F'V*?;
MC"#8K]BSV*K8L=BSVXP@V*C8I]N,V*\@V*C8L=BGVXP@V*C;C-BTV*K8L2#9
MOMN,V8C9AMBOV8?8IR#8JMBYV+';C-F!(-BTV8C9AMBOV)\`V8;9A=BGVXS8
MM``@V8;9A=BGVXS8M"#8JMF!V*?9B-BJV8?8I]N,(-F%VXS8I]F&(-F^VXS:
MJ=BQV*C9AMBOVXP@V*W9@=BX(-BTV*_9AR#9@=BYV83;C"#9B"#8JMF(V83;
MC-BO(-BTV*_9AR#8K-BOVXS8KP#8HMN,V*<@V++9A=BGV88@V*+8KMBQVXS9
MAB#9B-BQV8C8KR#8J-F'(-F'V8;:K]BGV84@V8C8L=F(V*\@V8;8M-BGV88@
MV*_8I]BOV8<@V+39B-BOV)\`V8;9A=BGVXS8M"#:K]BRVXS9AMF'XH",V8?8
MIR#8J-BQV*?;C"#9AMJOV8?8K]BGV+';C"#8I]BUV80`V*?9AMBJV*[8I]BH
M(-F#V8;9AMBOV8<@V8;9A=BGVXS8M`#8HMN,V*<@V87;C-F$V8<@VJ_8LMN,
MV8;:K]BGV88@V+G9A=F$VXS8I]BJ(-BLV*_9B-F$XH",(-F&V878I]N,V+0@
MV*_8I]BOV8<@V+39B-BOV)\`V*+;C-BG(-JOV++;C-F&VJ_8I]F&("5S(-BS
MV878JB#8L=BGV+/8JB#9AMBTV*?9AB#8K]BGV*_9AR#8M-F(V*_8GP#9AMF%
MV*?;C-BT(-JOV8'8JN*`C-F(VJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BSV839
MB-F$(-BLV*_9B-F$`-F&V878I]N,V+0@VJ_9@=BJVJ_9B-N,(-BNV+79B-BU
MVXS8I]BJ(-BLV*_9B-F$`-F&V878I]N,V+0@VJ_9@=BJVJ_9B-N,(-BNV+79
MB-BUVXS8I]BJ(-BSV+?8L2#8K-BOV8C9A`#9AMF%V*?;C-BT(-JOV8'8JMJO
MV8C;C"#8KMBUV8C8M=N,V*?8JB#8JMBUV8C;C-BQ`-F&V878I]N,V+0@V*?8
ML=BSV*?9A`#8JMJOV+':KP#8L=JOV*C8I]BQ(-BRV8C8K]F'V8;:K]BGV84`
MV+':K]BHV*?8L2#8K]N,V+'9A]F&VJ_8I]F%`-BLV878N2#8M-BOV88`V*S9
MA=BY(-BTV*_9AB#;C-BG(-BGV8;8JMF"V*?9A"#8J-F$V8C:J=F'V*?;C"#9
MA=BLV*?9B-BQ`-BKV*C8JB#9AMBGV84`V*?9A=BVV*?8H0#8I]F$VJ_9B-BQ
MVXS8JMF%(-BGV878MMBGV*$`V*?9AMBOV*?8LMF'`-BUV+'9@=F&V+C8L2#8
MI]BR(-F&VJ_9A]BOV*?8L=N,`-BHV+'9@0#8JMJOV+':KP#8JMJOV+':KP#8
ML=JOV*C8I]BQ(-BRV8C8K]F'V8;:K]BGV84`V+':K]BHV*?8L2#8K]N,V+'9
MA]F&VJ_8I]F%`-BYV879@B#8J-BQV8$Z(`#9A=BYV*?8K]F$(-BHV+'9@2#8
MK]BQ(-BBV*@Z(`#8M-BYV+'9A]BG(-F((-BBV8C8I]BRV8?8IP#8I]F&V*K8
MKMBGV*@@V*S9A]BJ(-F%V+'8JMBH(-BSV*?8LMN,`-BBV*_8L=BS(-BSV+':
MAMBTV879AP!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`V8;;C-F%(-JI
MV+'9AR#8K-F&V8C8J-N,`-F!V*?8M=F$V8?9E"#8J-N,V88@V+/9A-F(V839
MA]BGVXP@V878K-BGV8C8L0#9@=BGV+79A-F'V90@V*C;C-F&(-F%V*W8JMF(
MV*<@V8@@V838J-F'(-BOV+$@V+/9A-F(V80`V8'8I]BUV839A^*`C-JOV+#8
MI]BQ`-F!V*?8M=F$V8<`V8'8I]BUV839A^*`C-JOV+#8I]BQVXP@V8@@V*_8
ML=BRVJ_8L-BGV+';C`#9A]BQV++9AMBGV879AP#:J=BGV+'8I]JIV*K8L2#8
MKMBGV+4@V8C8I]BQV*\@V+38KP#8JMF"V+/;C-F%(-BSV839B-F$`-BJV8+8
ML]N,V84@V+/8JMF(V88`V*K9@MBSVXS9A2#8L]BWV+$`V8C8L=BRV+3;C`#8
MI]BSV*K8I]F&V*_8I]BQV*\`V+/8JMBGV+'9AP#8L]BGV80@V+38L=F(V+D`
MV8C8MMBYVXS8JB#8K=F(V++9A^*`C-F'V*<`V8C8MMBYVXS8JN*`C`#9@MBG
MV838J"#8L-BNVXS8L=F'(-BSV*?8LMN,`-BBV*_8L=BS(-BNVXS8I]BHV*?9
MA@#9@=F'V+'8L]BJ(-BQV+38JMF'`-BTVXS9B-F'(%M#4U-=`-N,VJG8M-F&
MV*C9AP#8N=F&V8C8I]F&`-BGV+'8L]BGV80`V++;C-BQV8;9B-N,V+,`V879
MB-F!V9'9@MN,V9'8J@`B)7,B(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=BP
MV8$@V+38KP#9OMN,VJG8L=BHV8;8K]N,(-BHV*<@V879B-F!V9'9@MN,V9'8
MJB#8J-BGV++:K]BQV*_8I]F&V*_9AR#8M-BO+B#8J-BQV*?;C"#9A=BTV*?9
MA]BOV8<@V*K8NMN,VXS8L=BGV*H@V878K-BOV*_8I]F2(-BBV8;8L=BG(-BH
MV*?8L2#9AMF%V*?;C-N,V*\`V;[;C-JIV+'8J-F&V*_;C"#9OMBTV*K;C-BH
MV*?9AB#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W9@=BX(-BTV*\`V;[8L=F(
MV8;8K]F'(-F^V+38JMN,V*C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@V*C8
MIR#9A=F(V8'9D=F"VXS9D=BJ(-BMV8'8N"#8M-BO`"5S(-BHV*<@V879B-F!
MV9'9@MN,V9'8JB#9AMF(V+38JMF'(-BTV*\`V*[9A-BGV+79AP#8M]F$V8C8
MN2#8HMF!V*K8I]BH`-BZV+'9B-BH(-BBV8'8JMBGV*@`V*+9@=BJV*?8J-N,
M`-BWV839B-BY`-BWV839B-BY+]BZV+'9B-BH`-BWV839B-BY.B``V+K8L=F(
MV*@`V+K8L=F(V*@Z(`#8J-BGV838I]F&V8C;C-BS`-F^V+38JMN,V*C8I]F&
MVXP`V8;8I]F%(-BNV*?9AMF(V*?8K]JOVXP`V*[8M]BGVXP@V8;8K=F(VXP@
MV*_8L2#9A=F(V*?8L=BO(-BLV+/8JMBLV8@`5"U3=&]R;7,`5"U3=&]R;7,`
MV;[8L=F(V8;8K]F'(%135@#8K-BOV8C9A`#8KMBUV8C8M=N,V*?8JB#8K-BO
MV8C9A`#8KMBUV8C8M=N,V*?8JB#8K-BOV8C9A`#9A]BOV8$Z`-F(V+C8I]N,
MV8$`V+39A=BGV+'9AR#8JMF$V8'9A@#8K]F%V*?;C"#8L]BGV+G8JB#8I]BN
MVXS8L3H@`-BOV+'8K-F'(-BMV+'8I]BQV*H`V*_8L=BLV8<@V*W8L=BGV+'8
MJCH@`-BGV83:K]F(VXP@V+/8L=F^V+'8L]BJVXP`V878JMF&`-F!V8+8MR#9
MA=BJV88`V*K8L=BGV+(@V878JMF&`-BHV*?9A-BGVXP@V878JMF&`-F^V8;8
MK-BTV8;8J-F'`%1H86D@*%1)4RTV,C`I`-BGV+(@V+39A=BG(-BHV8<@V*[8
MI]BWV+$@V*?8L]BJV8'8I]BOV8<@V*?8LB#8L]BGV878I]F&V8<@V878JMBT
MVJG8L=N,V84`V*C8L]BW($944"#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8
ML]BJ`-F&VJ_9A]BOV*?8L=N,.CH@VJG9A-BGV+,@V*C8IR#9A=F(V8'9D=F"
MVXS9D=BJ(-BHV*?8L2#9AMBTV*\`V;[9AMBLV+'9A]F4(-JOV++;C-F&V8?B
M@(S9A]BG(-BHV+/8JMF'(-BTV*\N(-BNV+'9B-BL`-BSV+'9OMBQV+/8JB#8
MJ-BGVXS8KR#;C-JI(-F^V+38JMN,V*C8I]F&(-F%V*S9B-BRV8?8IR#8L=BG
MV(P@(-BOV+$@V+79B-BQV*H@V*K9A=BGVXS9A"#8M-F%V*<@V*C9AR#8I]BS
MV*K9@=BGV*_9AR#8I]BR(-F%V*S9B-BRV8?8I]B,(-F^VXS:J=BQV*C9AMBO
MVXP@VJG9AMBO+@#8JMF&V8?8IR#8L]F%V*H@V;[8I]N,VXS9A@#8M-F%V*?8
ML=F'($E$(-BJV878I]BS(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JMB,(-BG
MVXS9AB#8M-F%V*?8L=F'(-BOV+$@V*_8I]BOVJ_8I]F&(-N,V*?9@=BJ(-F&
MV+38KP#8JMF%V*?8LR`@)7,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@
MVJG8JMBGV*C:AMF'(-BBV*_8L=BS(-BTV878IR#8I]BVV*?9@=F'(-BTV*\`
MVXS:J2#8J-F$V8C:J2#8I]F%V+;8I]N,(%!'4"#8J-BQV*?;C"#8J-BGV++8
MJ-N,V8;;C"#;C-JI(-F^VXS8NMBGV84@V*?9A=BVV*?8H2#8M-BOV8<@V879
MB-BQV*\@V8;;C-BGV+(@V*?8L]BJ`$E$(-F!V8?8L=BSV*H@V*K9B-BRVXS8
MN=N,(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JB#9B"#;C-BG(-BOV+$@V*_8
MI]BOVJ_8I]F&(-F%V8C8K-F(V*\@V8;;C-BSV*H`V8'9A]BQV+/8JB#8JMF(
MV++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ`-F%V+38KMBUV8?B
M@(SB@(S9A]BGVXP@V+'9A=BRV*C9AMBOVXP@V8;;C-BGV++9A=F&V*\@VXS:
MJ2#8I]BQV*K8M=BGV80@V*?9A=F&(-F(V*@@V87;C.*`C-BHV*?8M-F&V*\`
MV;[8L=F(V8;8K]F'("5S(-BHV*?;C-BO(-BOV*?8L=BGVXP@V*K9AMBXVXS9
MA2`E<R#8J-BGV+38KP#9OMBQV8C9AMBOV8<@)7,@V*C8I]N,V*\@V*W8I]F(
MVXP@V*K9AMBXVXS9A=BGV*H@)7,@V*C8I]BTV*\`V;[8L=F(V8;8K]F'(-BH
MV+$@V+'9B-N,(-BNV8C8K]BT(-F&V87;C.*`C-BJV8C8I]F&V*\@V+'9B-F&
MV8C8M-BJ(-BTV8C8KP#9OMBQV8C9AMBOV8<@V*W8I]F(VXP@V*_8I]BOV8?B
M@(S8I^*`C-N,VXP@V8;;C-BSV*H@`-F%V*\@V*K9A=BGV84@V+79@=BMV8<@
MV*C8IR!)12#9A=BTVJG9A"#8K]BGV+'8KR#9B"#8I]N,V88@V*?8LB#9A=BT
MVJG9A-BGV*H@V878L=F(V+':K]BQ(-F%VXSB@(S8J-BGV+38KRX@V*?:K]BQ
M(-F'V8;9B-BR(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*W8I]F$V*H@V8C;C-BQ
MV*?;C-BTVJ_8L2#8JMF%V*?9A2#8M=F!V*W9AR#8L=BG(-BGV878JMBMV*?9
MAB#:J=F&VXS8K]B,(-F$V+?9@=BGV8L@VJG9A-N,V*\@V*K8H]N,VXS8KR#8
ML=BG(-F!V+38I]BQ(-BOV8?;C-BO(`#9A]F(VXS9D=BJ("(E<R(@V*W8L-F!
M(-BTV*_9AR#8I]BSV*H`V*K9AMF'V*<@V+/9A=BJ(-J&V;X`V;[;C-BZV*?9
MA2#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V+'9B-N,("5S(-BHV8<@)7,@V*C8
MIR#9A=F(V+;9B-BY("(E<R(@V8;9A=BGVXS8M"#8K]BGV*_9AR#8M-BOV8<@
MV*?8L]BJ+@K8JMBVV87;C-F&VXP@V*C8L=BGVXP@V*[9B-BGV8;8K]F'(-BT
MV*_9AB#9B"#;C-BG(-BOV+':J2#8HMF&(-F(V*S9B-BO(-F&V*_8I]BQV*\`
MV8;8I]F%VXP@VJG9AR#8J-F'(-F'V8;:K]BGV84@V;[;C-F(V8;8K]BOV8?;
MC"#8J-F'(-BUV8'8K=F'(-BGVXS8K-BGV*\@V8;8I]F%V8<@V*?8L]BJV8'8
MI]BOV8<@V87;C.*`C-BTV8C8KP#8JMBYV*_8I]BO(-F!VXS9A-BOXH",V8?8
MIR#8J-BGVXS8KR#;C-JI(-BYV*_8KR#8J-BGV+38KP#8I]F(V839B-N,V*H@
M(B5S(B#9AMF%VXSB@(S8JMF(V*?9AMBO(-BMV8'8N"#:K]BQV*_8KR#8LMN,
MV+'8IR#9A=F"V*_8I]BQ(-BOV*?8K]F'(-BBV88@V*?8LB#8K=BO(-F%V*S8
MI]BR(-BHVXS8M-BJV+$@V*?8L]BJ`-BHV+'9AMBGV879A^*`C-BGXH",VXS;
MC"#:J=F'(-BHV+'8I]N,(-F%V+38I]F'V*_9AR#8I]N,V88@V8;9B-BY(-BO
MV*?8K]F'("@E<RD@V8+8J-F$V*?9BR#9A=F(V+'8KR#8I]BSV*K9@=BGV*_9
MAR#9@MBQV*?8L2#9A=N,XH",VJ_8L=F!V*K8C"#8K]BQ(-BSV*?9A=BGV8;9
MAR#9A=F(V*S9B-BO(-F&VXS8L]BJ`-BJV8;9A]BG(-BSV878JB#8L=BGV+/8
MJB#9B"#:AMF^`-BJV8;9A]BG(-BSV878JB#8L=BGV+/8J@#8K-BOV*<@VJG9
MAMF&V*_9AR#8J-BGVXS8KR#;C-JI(-F&V8C;C-BSV8<@V*C8I]BTV*\`VJG8
MI]BQV+/8I]BR("(E<R(@V*W8L-F!(-BTV*_9AR#8I]BSV*H`VJG8I]BQV+/8
MI]BR("(E<R(@V*W9@=BX(-BTV*_9AR#8I]BSV*H`V*_8L=BNV8C8I]BSV*H@
MV*?9@=BJV*K8I]BM(-BMV+/8I]BH(-BHV+'8I]N,("5S(-BMV+#9@2#8M-BO
MV8<@V*?8L]BJ`-BQV*_;C-F!(-F%V+38KMBU(-BTV*_9AR#9B-BLV8C8KR#9
MAMBOV*?8L=BO`-F^V+'9B-F&V*_9AR#9A=F(V8+8JMN,("`B)7,BV879B-BL
MV8C8KR#9AMN,V+/8J@#8JMF&V8?8IR#8L]F%V*H@V*C8I]F$V*<@V8@@V;[8
MI]N,VXS9A@#8JMF&V8?8IR#8L]F%V*H@V*C8I]F$V*<`V*_8I]BOV8?9E"#8
MI]BQV+/8I]F$(-BTV*_9AR#8I]BR(-JOV*?9A2#9@MBHV83;C"#8I]BR(-BO
MV+/8JB#8L=F!V*K9AR#8I]BSV*H`V;[8L=F(V8;8K]F'(-BGV+'8L]BGV80@
MV+38K]F'(-F&V87;C.*`C-BJV8C8I]F&V*\@V*W9@=BX(-BTV8C8KP#8J-F$
MV8C:J2!W96%T:&5R+F-O;2#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ
M`-JOV++;C-F&V8?B@(S8I^*`C.*`C-N,VXP@V*_8L2#8K]BSV*K8L=BS(-F&
MVXS8L]BJ`-BHV*[8M-N,(-JIV8<@V*C8JMF(V*?9AMBO(-BHV+'8KMBW(-F&
MV878I]N,V+0@V*_8I]BOV8<@V+39B-BO(-F%V8C8K-F(V*\@V8;;C-BSV*H`
MV8;9B-N,V+/9A^*`C-F'V*?;C"#8LMN,V*?8K]N,(-BOV+$@V*?;C-F&(-F!
MVXS9A-BO(-F"V+'8I]BQ(-BOV*?8L=BO+B#8M-F%V*<@)7,@V8;9B-N,V+/9
MAR#9B-BGV+'8KR#:J=BQV*_9A^*`C-BGXH",VXS8KR#8K]BQ(-BMV*?9A-N,
M(-JIV8<@V+39A=BG(-BHV*?;C-BO(-JIV878JMBQ(-BGV+(@)7,@V8;9B-N,
MV+/9AR#9B-BGV+'8KR#:J=F&VXS8KP#9A=BTVJG9A-N,(-BOV+$@V*?8L=BS
MV*?9A"#9OMBQV8C9AMBOV8<@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ("5S(-BG
MV+'8L]BGV80@V8;8M-BO`-F%V+3:J=F$VXP@V*_8L2#8I]BQV+/8I]F$(-F^
MV+'9B-F&V*_9AR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@V*?9AMBOV*?8LMF'
M("5S(-BHVXS8M-BJV+$@V*?8LB#8K=BO(-F%V*S8I]BR(-BHV8C8K]F'(-BG
MV+/8JB`H("5D(-BHV*?;C-BJ*2X`V878M-JIV83;C"#8K]BQ(-BGV+'8L]BG
MV80@V;[8L=F(V8;8K]F'(-F(V*S9B-BO(-BOV*?8M-BJV8<@V*?8L]BJ.B`@
M)7,@V*C9AR#8M=F(V+'8JB#8JMJIV8?B@(S8I^*`C-N,VXP@V*?8L=BSV*?9
MA"#8M-BOV8<@V*?8L]BJ(`#8KMBWV*?;C-N,(-BOV+$@V8;9A=BGVXS8M"#8
MI]N,V88@V*C8KMBT(-F^VXS8NMBGV84@V+'8KB#8K]BGV*_9AR#8I]BSV*H`
MV*[8M]BGVXS;C"#8K]BQ(-BOV+'9B-F&XH",V*C8L=BO(-JIV+'8K]F&(-BO
MV*?8K]F'(-BJV878I]BS(-BQV*X@V*_8I]BOV8<@V*?8L]BJ`-BNV+?8I]N,
MVXP@V*_8L2#8K]BQV8C9AN*`C-BHV+'8KR#:J=BQV*_9AB#8K]BGV*_9A]F4
M(-BJV8+9B-N,V84@V+'8KB#8K]BGV*_9AR#8I]BSV*H`V*[8M]BGVXS;C"#8
MK]BQ(-F^VXS:J=BQV*C9AMBOVXP@V8'8L=F%(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJ+B#8M-BGVXS8KR#9@=N,V838KR#9A=F(V+'8KR#9AMN,V*?8LMN,(-BQ
MV*<@V*S8IR#8I]F&V*_8I]BNV*K9A^*`C-BGXH",VXS8KP#8KMBWV*?;C-N,
M(-BOV+$@V*?8K-BQV*<@VJG8L=BOV88@V+G9A=F$VXS8I]BJ(-F%V+38KMBU
M(-BTV*_9A]F4(-JIV*K8I]BHVH;9AR#8HMBOV+'8LR#8L=BN(-BOV*?8K]F'
M(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;
MC-BO`-BNV+?8I]N,VXP@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V*S8LMBF
MVXS8I]BJ(-BJV878I]BS(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#9A-BWV8'8
MI]F+(-BOV8C8J-BGV+'9AR#8L]BYVXP@VJG9AMN,V*\`V*[8M]BGVXS;C"#8
MK]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;
MC"#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQ
MV8<@V+/8N=N,(-JIV8;;C-BO`"#:J=BGV+'8L]BGV+(@24U!4-F^V8C8M-F'
MXH",V8?8I]N,(-F%V+38JMBQVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&
MV87;C.*`C-JIV8;8KP`@V*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JI
MV8<@V*+8L=BTVXS9B"!R87(@V878N=BJV*C8L=N,(-BHV*?8M-BO`"#8J-F'
M(-F&V+C8L2#9AMF%VXSB@(S8L=BSV*\@VJG9AR#9OMBQV8C9AMBOV8<@>FEP
M(-F%V+G8JMBHV+';C"#8J-BGV+38KP#8J-F'(-F&V+C8L2#9AMF%VXSB@(S8
ML=BSV*\@VJG9AR#8M-F%V*?8L=F'(-JIV*?8L=BJ(-F%V+G8JMBHV+';C"#8
MJ-BGV+38KP#8I]N,V88@V8';C-F$V*\@V879B-BQV*\@V8;;C-BGV+(@V*?8
ML]BJ`-BGVXS9AB#9@=N,V838KR#9A=F%VJG9AB#8I]BSV*H@V+38I]F%V80@
MV*?8N=BOV*?8KR#8M=BMVXS8K2#8J-BGV+38KP#8I]N,V88@V8';C-F$V*\@
MV879A=JIV88@V*?8L]BJ(-BTV*?9A=F$(-BGV+G8K]BGV*\@V8@@V8C;C-BQ
MVJ_9B-F$(-BHV*?8M-BO`-BGVXS9AB#9@=N,V838KR#9A=F%VJG9AB#8I]BS
MV*H@V+38I]F%V80@V879@MBGV*_;C-BQ(-F'V+38JB#9A]BTV*K;C"#8J-BG
MV+38KP#8I]N,V88@V8';C-F$V*\@V*C8I]N,V*\@V*W8I]F(VXP@VJG8I]F%
MV*<@V8@@VXS8IR#9@=F'V+'8L]BJVXP@V*?8LB#8I]BYV*_8I]BO(-BUV*W;
MC-BM(-BLV*_8IR#8M-BOV8<@V*C8IR#9AMF(VXS8L]F'(-BNV*?9A-N,(-BH
MV*?8M-BO`-BGVXS9AB#9@=N,V838KR#8J-BGVXS8KR#;C-JI(-BYV*_8KR#9
MA=BYV*K8J-BQ(-BHV*?8M-BO`-BGVXS9AB`E<R#9A=N,XH",V*C8I]BTV*\`
MV*?;C-F&(-F^VXS8NMBGV84@V*C8IR#9A=BLV879B-BYV8<@VJG8I]BQV*?:
MJ=BJV+$@)7,@V8;9B-BTV*K9AR#8M-BOV8<@V*?8L]BJ(-JIV8<@V*C8IR#9
MA=BLV879B-BYV8<@VJG8I]BQV*?:J=BJV+$@V+39A=BG(-F%V*K9@=BGV8C8
MJB#8I]BSV*H`V*?;C-F&(-BYV*_8KR#8K=BOV*?9@MF$(-BHV*?;C-BO(-N,
MVJD@V*C8I]BTV*\`V*?;C-F&(-JIV*?8L=BSV*?8LB#9OMBQV8C9AMBOV8?B
M@(S9A]BGVXP@>FEP(-F((&=Z:7`@V+'8IR#8J-BGV+(@V8;9A=N,XH",VJG9
MAMBO`-BGVXS9AB#8L]BGV878I]F&V8<@V*_8L2#8K=BGV80@V*W8I]BVV+$@
MV+K;C-BQ(-F!V+G8I]F$(-BGV+/8J@#8I]N,V88@V879@MBOV*?8L2#8J-BG
MVXS8KR#8N=BOV*\@V*C8I]BTV*\`V*?;C-F&(-F^V8;8K-BQV8<@V*C8I]N,
MV*\@V*?8LB#9OMF&V*S8L=F'V90@VJ_8LMN,V8;9A^*`C.*`C-F'V*<@V8'8
ML=BGV*[9B-BGV8;;C"#8M-F(V*\`V+'8N=BO`-BHV83;C-BWV8?8IP#8LMF%
MV*?9A@#8L=BOVXS8I]BHVXP@V++9A=BGV88`V8+8I]F$V*@@V++9A=BGV88`
M(-BGV8;8JMBNV*?8J"#8LMF%V*?9AB``V+G9AMF(V*?9A@#8N=F&V8C8I]F&
M("C8L=BGV8?9AMF%V*?;C"#8HMF&VXPI.@#8J-F'`-BHV+'8I]N,(-BGV8;8
MJMBNV*?8J"#:AMF&V*\@V8';C-F$V*_8C"#8K]JIV879AR!#=')L(-BQV8C;
MC"`H4$,I(-N,V*<@0V]M;6%N9"#8L=F(VXP@*$UA8RD@V+'8IR#8K]BQ(-F%
MV*_8JB#:J=F$VXS:J2#:J=BQV*_9AB#9AMJOV8?8K]BGV+';C-BO`-BGV878
ML=F(V+(`V8'8L=BOV*<`V*C8I]F$V*<`VH;8I]BQVH;9B-BH(-BHV*?9A-BG
M("C8J-BGV838IRD`V*K8L=BLV879A^*`C-F'V*<`V*_8L=BSV*H@V8@@VXS8
MIR#9AMBGV*_8L=BSV*H`V+/9AR#8M-F&V*C9AP!4=7)K:7-H("A)4T\M.#@U
M.2TY*0#8I]F&V*K8KMBGV*@@V*[9B-BO(-BQV*<@V*K8I]N,V;X@VJG9AMN,
MV*\Z`-BTV*?8KMBU(%4N5BX@.B``55),`%523#H`V*?9A=JIV*?9AB#8K]BS
MV*K8L=BSVXP@V*C9AR#8M-BGV*[9AR!61E,@V8;;C-BSV*H`V*?9A=JIV*?9
MAB#8I]BVV*?9@=F'(-JIV+'8K]F&(-BGV+?9A-BGV+G8I]BJ(-BGV+;8I]F!
MVXP@VJG8I]BQV*C8L2#8J-F'(-F'V8;:K]BGV84@V*O8J-BJ(-F&V*?9A2#9
MAMN,V+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#9A=BLV8C8LMF'V*<@V+'8IR#8
MJ-BQV*?;C"#9OMBQV8C9AMBOV8<@(B5S(B#8JMBZVXS;C-BQ(-BOV*?8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#9A=BLV8C8LMF'V*<@V+'8IR#8J-BQV*?;C"#9
MOMBQV8C9AMBOV8<@)7,O)7,@5D93("#8JMBZVXS;C-BQ(-BOV*?8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#8K]BQ("5S(-BJV+K;C-N,V+$@V*_8I]BO`-F&V87;
MC.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR(%-13-F%V*K8M=F$(-BT
MV*\`V8;9A=N,XH",V*K9B-BGV88@V*C8IR!34TP@V878JMBUV80@V+38KP#9
MAMF%VXSB@(S8JMF(V*?9AB#8I]BR(-F^V+'9B-F&V*_9AR!61E,@V+'9B-F&
MV8C8M-BJ(-BJV8?;C-F'(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BT
MV*?8KMF'(%9&4R`B)7,B(-BQV*<@V*?;C-BLV*?8KR#9AMF%V8C8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8I]N,V*S8I]BO(-F&
MV879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8
MIR#8I]N,V*S8I]BO(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9
MB-F&V*_9AR#8KMBGV83;C"!61E,@(-BGVXS8K-BGV*\@V8;9A=F(V*\`V8;9
MA=N,XH",V*K9B-BGV88@V*_8I]BOV8<@V+'8IR#8J-BGV+(@VJG8L=BO(`#8
MK=BPV8$@(B5S(B#9A=F%VJG9AB#9AMN,V+/8JMB,(-BTV*?8KMF'(-BNV*?9
MA-N,(-F&VXS8L]BJ`-F&V87;C.*`C-BJV8C8I]F&("(E<R(@V+'8IR#8K=BP
MV8$@VJG8L=BO.B`E<RX`V*W8L-F!("5S(-F%V87:J=F&(-F&VXS8L]BJV(P@
MV+38I]BNV8<@V*[8I]F$VXP@V8;;C-BSV*H`V8;9A=N,XH",V*K9B-BGV88@
MV+38I]BNV8<@5D93(-BQV*<@V*C9AR#8M=F(V+'8JB#8JMF((-BOV+$@V*K9
MB"#8K=BPV8$@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@
M5D93(-BQV*<@V*W8L-F!(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BT
MV*?8KMF'(%9&4R#8L=BG(-BMV+#9@2#9AMF%V8C8KSH@)7,N`-F&V87;C.*`
MC-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@(B5S(B#8L=BG(-BMV+#9@2#9
MAMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQ
MV*<@V*W8L-F!(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(%9&4R#8L=BG
M(-BHV8<@V+79B-BQV*H@V*K9B"#8K]BQ(-BJV8@@V*W8L-F!(-F&V879B-BO
M.B`E<RX`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8?9E"#9@=BYV83;C"#8
ML=BG(-BJV+38KMN,V+4@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-BLV++8
MIMN,V*?8JB#:K]F(V*?9A]N,(-BQV*<@V*?8L]BJV*[8L=BGV*P@V8;9A=F(
MV*\`V8;9A=N,XH",V*K9B-BGV88@V*K8N=BQVXS9@2`E<R`@V+'8IR#8J-BG
MV+$@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&
M4R#8L=BG(-BGV8;8JMF"V*?9A"#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@
MV;[8L=F(V8;8K]F'(%9&4R`B)7,B(-BQV*<@V*C8I]BR(-F&V879B-BO`-F&
MV87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8J-BQV*?;
MC"#9AMF(V+38JMF&(-BHV*?8LB#:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@
MV;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BHV*?8LB#9AMF%V8C8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#8HMBQV+3;C-F((-F!V+38L=BOV8<@V+'8IR#8J-BGV+(@
MVJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'('9F<W)O;W0@V+'8
MIR#8KMF(V*?9AMBO`-F&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*C9AR`E
M<R`@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO.B#9OMF(V+39AR#9A=F"V+78
MKR#8I]BR(-F"V*C9A"#9A=F(V*S9B-BO(-BGV+/8J@#9AMF%VXSB@(S8JMF(
MV*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BG
MV*\`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*K8NMN,
MVXS8L2#9AMBGV84@V*_8I]BO.B`E<RX`V8;9A=N,XH",V*K9B-BGV88@V;[8
ML=F(V8;8K]F'(%9&4R`B)7,B(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8
MI]BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@)7,O)7,@
MV+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\`V8;9A=N,XH",V*K9B-BG
MV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BO
MV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB`G;6MI<V]F<R<@V+'8IR#8I]BLV+'8
MIR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8I]N,V88@V+/9AMBO(%=O
M<F0@V+'8IR#8JMBQV*S9A=F'(-F&V879B-BO`"#9AMF%VXSB@(S8JMF(V*?9
MAB#8K]BQ(-F^V+'9B-F&V*_9AR`B)7,B(%9&4R`@V8;9B-BTV*H`(-F&V87;
MC.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'(%9&4R#9AMF(V+38JBX`
MV8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8?9E"#8K]BGV*_9
MAR!61E,@V8;9B-BTV*H`V++;C-BQV*[8M^*`C-BOV*?8L0#9B-BGVJ_8L=BO
MV*?9AMBOV88@V*K8NMN,VXS8L=BGV*H`V8C8I]JOV+'8K]BGV8;8K]F&(-BB
MV*[8L=N,V88@V+G9A=F$(-BTV878IP#9OMBGV+/8KB#8NMN,V+$@V879AMBJ
MV+C8L=F'(-BGV+(@VJG8I]BQV+/8I]BR(-BHV+$@V+'9B-N,(-BGV*K8M=BG
MV80Z`-F^V*?8L]BN(-BZVXS8L2#9A=F&V*K8N-BQV8<@V*?8LB#:J=BGV+'8
ML]BGV+(@V*C9ASH`V+K;C-BQ(-BMV8C8LMF'`%5N:6-O9&4@*%541BTX*0#9
MB-BGV*W8K]F'V*<`V*_8I]BOV8<@V8;8I]BTV8;8I]BNV*K9AP#9AMBGV84@
MVJG8I]BQV*C8L2#9B"#;C-BG(-BGV+/9A2#8L=F%V+(@V8;8I]BTV8;8I]BN
MV*K9AP#9@MBWV+D@V;[;C-F(V8;8KR#8N=F&V+78L2#9@=BYV83;C`#8J-N,
M(-F&V*?9A0#8K]BSV*H@XH",V8;9B-N,V+/9A]BGVXP@V*C8K]F(V88@V*?9
MA=BJVXS8I]BR(-BHV8<@V*_9A-N,V80@V*?9A=F&VXS8JMN,(-F&V87;C.*`
MC-BJV8C8I]F&V8;8KR#8I]BR(-BWV+';C-F"(-BHV+'9AMBGV879AR#9AMF(
MVXS8L]N,(-BHV+';C-BOV8<OV+'9B-F&V8C8M-BJ(-JOV+'9@=BJV8<OVH;8
ML]BHVXS8K]F'(-BTV8C9AMBO+B#:J=F$VXS8KR#8JMBCVXS;C-BO(-BQV*<@
MV8'8M-BGV+$@V*_9A]N,V*\@V*K8IR#9A=BJV88@V8'9AMN,XH",V*?B@(S;
MC-N,(-BQV*<@V*_8L2!M;WII;&QA+F]R9R#8J-BG(-BYV8;9B-BGV88@VH;:
MK]F(V8;:K]N,(-BOV+/8JMBQV+/;C"#;C-JI(-BOV+/8JB#B@(S9AMF(VXS8
MLR#8J-F'(-BJV*[8JMF'V90@V+'8L]F%(-BQV*<@V878M-BGV8?8K]F'(-JI
MV8;;C-BO`-BQV8;:KR#8JMF&V+C;C-F%(-F&V+38K]F'`-BHV+/8MR#8J-BO
MV8C9AB#9OMBTV*K;C-BHV*?9AMN,`-BHV+'9B-BRV+'8L]BGV8;;C`#8J-BQ
MV8C8LMBQV+/8I]F&VXP@)7,`V*C8L=F(V++8L=BSV*?9AMN,(-JIV*?8L=BH
MV+$`(B5S(B#8J-BQV8C8LMBQV+/8I]F&VXP@V+38KP#8K]BSV*KB@(P@V8;9
MB-N,V+,@V*C9A]N,V8;9A^*`C-BSV*?8LMN,(-BMV+#9@2#8M-BO`-BGV+'8
ML]BGV80@VJG8L=BOV88`V*K9A=BGV84@V;[8L=F(V8;8K]F'XH",XH",V8?8
MI]N,(-BJV8;8N-N,V84@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-JIV*?8L=BH
MV+'8K]N,(-BHV8<@VJG8I]BQV+/8I]BR(-BGV+'8L]BGV80@V+38KP#8K=BQ
MV8C9@2#8J-BRV+':KR#9A-BGV*K;C-F&`-BGV+G8K]BGV*\@VXS9B-F&V*?9
MAMN,(-BHV++8L=JO`"#8I]BSV*K9@=BGV*_9AR#9@=BYV83;C#H@)7,`V*?8
ML]BJV8'8I]BOV8<@V*?8LB!34TP`V*?:K]BQ(-F&V*?9A2_8I]BSV84@V+'9
MA=BR(-BHV+'8I]N,(-JIV*?8L=BSV*?8LB!)35-0(-F%V*K9@=BGV8C8JB#8
MI]BSV*K8C"#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KP#:J=BGV+'8J-BQ("5S
M("#8J-BQV*?;C"`E<R#8I]BMV+'8I]BR(-F'V8C;C-F1V*H@V8;8M-BOV8<@
MV*?8L]BJ`-BSV+'9OMBQV+/8JMN,(-JIV*?8L=BHV+$`VJ_8LMN,V8;9A^*`
MC-F'V*?;C"#:J=BGV+'8J-BQ`-BKV*C8JB#9AMBGV84@VJG8I]BQV*C8L0#8
MJ]BHV*H@VJG8I]BQV*C8L2#8J-BQV*?;C"#8I]N,V88@V;[8I]N,VJ_8I]F'
M(-BZVXS8L2#9@=BYV*?9A"#8M-BOV8<@V*?8L]BJ`-BMV+/8I]BH(-JIV*?8
ML=BHV+$@V;[;C-BOV*<@V8;8M-BO`-F&V*?9A2#:J=BGV+'8J-BQ`-F&V*?9
MA2#:J=BGV+'8J-BQ.@#9AMBGV84@VJG8I]BQV*C8L3H@`-JIV*?8L=BHV+'8
MI]F&(-BSV*?9A=BGV8;9ASH`V+38I]BNV8<@5D93(-F(V*S9B-BO(-F&V*_8
MI]BQV*\`V*K8N=BWVXS9A-BGV*H`V879B-F"V+G;C-BJV8?8I]N,(-F%V+G8
MJMBHV+$@VXS8I]F!V*K9AR#8M-BOV8<@V+G8J-BGV+'8JMF&V*\@V*?8LCH`
MV*?8N=BJV*C8I]BQ`-F%V8+8K]BGV+$@V*C9AR#8K]F"VXS9@MF'(-BGV+(@
MV*W8I]F$V*<`V879@MBOV*?8L2#8I]BR(-BHVXS8M-N,V8;9AR#8M]F(V80@
MV878K-BGV+(@)7,@V*C;C-BTV*K8L2#8I]BSV*H`V879@MBGV*_;C-BQ`-F%
MV8+8I]BOVXS8L2#8J-BQV*?;C"#8I]F&V*K8KMBGV*@@V*?8L@#9A=BJV+K;
MC-N,V+$`V8;8L]BNV8<`VJG9AMBJV+'9A"#9AMBSV*[9AP#8JMBQV*?8LB#8
MN=F%V8C8K]N,`-F!V*?8M=F$V8?B@(S:K]BPV*?8L=N,(-BYV879B-BOVXP`
MV+G9A=F(V*_;C#H`V*[;C-F$VXP@V*C8I]F$V*<`5FEE=&YA;65S92`H5DE3
M0TE)*0#9AMF%V*?;C"`E<P#9AMF%V*?;C"#;C-JI(-BUV8'8K=F'(-F(V*@@
MV*[8I]BQV*S;C``@V8;9A=BG(-BHV8<@V+G9AMF(V*?9AB`E<P#9@MBGV*C9
MA-N,V*H@V878M-BGV8?8K]F'`-F"V*?8J-F$VXS8JB#9A=BTV*?9A]BOV8<Z
M(`#8I]BNV+?8I]BQ(2$A(-BOV+/8JB#B@(S9AMF(VXS8LR#8L=BG(-BHV+?9
MB-BQ(-BOV+/8JMN,(-BGV+(@)7,@V*W8L-F!(-JIV8;;C-BO`-BGV*[8M]BG
MV+$Z(`#:AMF'V*?8L=BTV8;8J-F'`-F^VXS8M.*`C-BHVXS9AMN,(-F'V8C8
MIP#8K]BGV*_9AR#8HMBH(-F((-F'V8C8I]N,VXP@V8'8L=BGV8?9A2#8M-BO
MV8<@V*C9AR#9B-BSVXS9A-F'`'=E871H97(N8V]M`-F(V*@`V8C8J.*`C-JO
MV*?9AP#9A]F!V*K:K]N,`-BNV8C8M"#8HMF%V*_;C-BO`-BHV8<@)7,@V*[9
MB-BT(-BBV878K]N,V*\`)7/8C"#8KMF(V+0@V*+9A=BOVXS8KP!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`VH;9AR#8J-BQ
MV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"#8L=BG("5S(-BHV*?;C-BO(-BH
MV+G8KR#8I]BR(-F(V+'9B-BO(-F&V+38I]F&(-BOV8?8K]B?`-F&V8C;C-BS
MV8?9E.*`C"#8K=BGV*;9A"#:AMN,V+/8JMB?`-F&V8C;C-BSV8?B@(S;C"#9
MAMF"V80@V8+9B-F$(-J&VXS8L]BJV)\`VJG8K]BGV84@V8'8I]BR`-JIV*_8
MI]F%(-BHV+'9AMBGV879A^*`C-F'V*?;C"#9A=BJV+79A.*`C-JIV8;9AMBO
MV8<@XH",V*C8L=BGVXP@V8C;C-BQV*?;C-BTVJ_8L2#9A=BJV88@V8'8N=BG
MV80@V*C8I]BTV8;8KP#8N=BQV+8`(-F^V8?9AMBG(-BOV+$@V8C8I]BMV*\@
M0U-3(`#9OMF'V8;8I]N,(-JOV++;C-F&VJ_8I]F&("5S(-BOV+$@V+'8I]BS
MV*H@*-BOV+$@V8C8L=F(V*\@V*C8N=BOVXP@V879B-BKV+$@V87;C.*`C-JO
MV+'8K]BO*3H`V;[9A]F&V*?;C"#8K-BOV8C9A`#9B-BGV*W8KR#9OMF'V8;8
MIP#9OMF'V8;8ISH`5VEK:0#8J-BGV*\Z`-BHV*?8KR#8LMF(V*_9A]F&VJ_8
MI]F%.B``V+/8L=BYV*H@V*C8I]BO(-BHV+'8K=BSV*@@V8'9B-BJ(-BHV+$@
MV+/8I]BYV*H`V*C8I]BO.@#8J-BGV*\Z(`#8N=F"V80`VJG8I]BQ`-BBV*_8
ML=BS(-F%V*W9A"#:J=BGV+$`V*K9A-F!V88@V878K=F$(-JIV*?8L0#B@(Q9
M60!965E9`-BSV*?9A-BGV8;9AP#8HMBQVXP`V*C9A-F'V(P@V879B-BGV8'9
M@MF%`-BTV878IR#8K]BQ(-F%V*\@V878JMF&(-F'V+/8JMN,V*\N(-BGV+(@
MV*_:J=F%V8<@(%L\/ET@V*C8L=BGVXP@V*C8L=JOV+38JMF&(-BHV8<@5UE3
M25=91R#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KP#8M-F%V*<@V*K8M=BOVXS9
M@B#9A]F(VXS9D=BJ(-F&V+38K]N,V*\`V+39A=BG(-F&V87;C.*`C-BJV8C8
MI]F&VXS8KR#9AMF(VXS8L]F'("=<)R#8L=BG(-BOV+$@V8;8I]F%(-JIV*?9
MA=F$(-BNV8C8KR#8K]BGV+38JMF'(-BHV*?8M-N,V*\`V+39A=BG(-BBV*_8
ML=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V878N=BJV*C8L=N,(-F(
MV*?8L=BO(-F&VJG8L=BOV8?B@(S8I]N,V*\`V+39A=BG(-F'VXS:AB#9@=N,
MV838K]N,(-BQV*<@V*_8L2#9OMBQV8C9AMBOV8<@V*_8L=F(V8;B@(S8J-BQ
MV*\@V+38K]F'(-BHV8<@V8';C-F$V*\@V878JMF"V*?8J-F$VXP@V*_8L2`E
M<R#9AMJOV*?8M-BJ(-F&VJG8L=BOV8?B@(S8I]N,V*\`V+39A=BG(-BNV*?8
ML=BL(-BTV*_;C-BO`-BTV878IR#9A=BLV*C9B-BQ(-F'V+/8JMN,V*\@VXS:
MJ2#8M-F%V*?8L=F'(-BJV839@=F&(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9
MAMN,V*_8C"#8I]BR(-BYV838I]F%V*H@)RLG(-BHV+'8I]N,(-BTV878I]BQ
MV8?B@(S9A]BGVXP@V*C;C-F&(-BGV839A=F$V83;C"#8I]BSV*K9@=BGV*_9
MAR#:J=F&VXS8KP#8M-F%V*<@V878K-BHV8C8L2#9A]BSV*K;C-BO(-N,VJD@
MV879@MBOV*?8L2#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BO`-BTV878
MIR#8J-BGVXS8KR#;C-JI(-F^V+38JMN,V*C8I]F&(-BOV+'8KMBJ(-BOV*?8
MK]F'(-BHV+'8I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V*O8J-BJ(-F&V*?9
MA2#9OMN,VJG8L=BHV8;8K]N,(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;
MC-JI(-BSV*?9A=BGV8;9AR#9OMBTV*K;C-BHV*?9AB!61E,@V+'8IR#9OMN,
MVJG8L=BHV8;8K]N,(-JIV8;;C-BO`-F"V*C9A"#8I]BR(-BGV+'8L]BGV80@
MVJ_8LMBGV+'8M-B,(-BHV*?;C-BO(-F%V+3:J=F$(-BQV*<@V+38L=BM(-BO
MV8?;C-BO`-BTV878IR#8J-BGVXS8KR!54DS8I]N,(-JIV8<@V*?;C-F&(-F^
MVXS9B-F&V*\@V*C9AR#8HMF&(-BGV+38I]BQV8<@V87;C.*`C-JIV8;8KR#8
ML=BG(-F(V*?8L=BO(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-JI
MV*?8L=BSV*?8LMB,(-BHV+'8I]N,(-BMV+#9@2#:J=BQV*_9AB#8I]F&V*K8
MKMBGV*@@VJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(-N,VJD@V8;8I]F%(-JI
MV*?8L=BHV+'8C"#8J-BQV*?;C"#8K=BPV8$@VJG8L=BOV88@V878M-BNV+4@
MVJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(-N,VJD@V8;8I]F%(-JIV*?8L=BH
MV+'8C"#8J-BQV*?;C"#8K=BPV8$@V+38K]F&(-F%V+38KMBU(-JIV8;;C-BO
M`-BTV878IR#8J-BGVXS8KR#;C-JI(-F&V*?9A2#:J=BGV+'8J-BQV(P@V*C8
ML=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BTV*[8M2#:J=F&VXS8KP#8
MM-F%V*<@V*C8I]N,V*\@VXS:J2#8M-F&V*?8L]F'(-JIV*?8L=BHV+'8C"#8
MJ-BQV*?;C"#8J-BQV8C8LMBQV+/8I]F&VXP@V*?9AMBJV*[8I]BH(-JIV8;;
MC-BO`-BTV878IR#8J-BGVXS8KR#9A=BTV*[8M2#:J=F&VXS8KR#:J=F'(-J&
MV8<@V+G9A=F$VXP@V*C8I]N,V*\@V*?9AMBLV*?9A2#:K]N,V+'8KP#8M-F%
MV*<@V*C8I]N,V*\@V8;8I]F%(-BLV*_;C-BO(-BOV+/8JMF'(-BQV*<@V*K8
MI]N,V;X@VJG9AMN,V*\`V8;8M-BSV*H@)7,@V+39A=BG(-F%V8;9@MBVVXP@
MV+38K]F'(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V8C8I]BQ
MV*\@V+39B-N,V*\`V*+8K]BQV+,@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V+39
MA=BG`-BBV*_8L=BS(-F!V+'8L]BJV8;8K]F'.B#8M-F%V*<Z`-BGV+?9A-BG
MV+G8I]BJ(-BTV878IP#8HMBOV+'8LR#8I]N,V8;8JMBQV8;8JMN,(-BTV878
MIR#9AMBSV*C8JB#8J-F'(-BGV*C8JMBOV*?;C"#9AMBTV+/8JB`E<R#8M-F%
MV*<@V*K8NMN,VXS8L2#:J=BQV*_9AR#8I]BSV*HNV*C8L=BGVXP@V+'8N=BG
MVXS8JB#9A=BSV*?8IMF$(-BGV879AMN,V*K;C"#8J-BGVXS8KR#8K]F(V*C8
MI]BQV8<@V8C8I]BQV*\@V+39B-N,V*\`V8;8I]F%(-BTV878IP#8L]BGV878
MI]F&V8<@V;[8M-BJVXS8J-BGV88@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BT
MV878IR#9@=F'V+'8L]BJ(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-BQV*<@
MV;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V*_8C"#;C-BG(-BTV*?;
MC-BO(-BHV8;8IR#8J-F'(-BOV83;C-F$(-BOVXS:K]BQVXP@V*?;C-F&(-JI
MV*?8L2#8I]F&V*S8I]F%(-F&V87;C.*`C-BTV8C8KP#8N-BGV8?8L2#9A=BQ
MV8C8L=JOV+$@V+39A=BG(-F&V+/8J-BJ(-BHV8<@V*?8J-BJV*_8I]N,(-F&
MV+38L]BJ("5S(-BTV878IR#8JMBZVXS;C-BQ(-JIV+'8K]F'(-BGV+/8JB[8
MJ-BQV*?;C"#8L=BYV*?;C-BJ(-F%V+/8I]BFV80@V*?9A=F&VXS8JMN,(-BH
MV*?;C-BO(-BOV8C8J-BGV+'9AR#9B-BGV+'8KR#8M-F(VXS8KP#9A=BQV8C8
ML=JOV+$@V+39A=BG(-BGVXS9AB#9A=BTV*[8M=F'(-BQV*<@V;[8M-BJVXS8
MJ-BGV8;;C"#9AMF%VXSB@(S:J=F&V*\N`-BRV878I]F&(-F!V+G9A-N,(-F%
MV8;8M]F"V8<@V*S8NMBQV*?9@=N,V*?;C-N,(-BTV878ISH`V8?9B-N,V9'8
MJB#9OMN,V+0@V8'8L=BV(-BTV878ISH`V8;8I]F%(-JIV*?9A=F$(-BTV878
MISH`V8C8L=F(V*\@V+39A=BG(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8J@#8
MI]BSV84@V+'9A=BR("#8K-BOVXS8KR#8M-F%V*<@V*C8L=BGVXP@)7,@V8?8
ML]BJ.B`E<P#:K]BRVXS9AMF'XH",V8?8I]N,(-BTV878IR#8J-BQV*?;C"#8
MM]F(V80@V*?;C-F&(-F&V+38L]BJ(-BHV+'9B-BRV+'8L]BGV8;;C"#8M-BO
MV8<@V*?8L]BJ(`#:K]BRVXS9AMF'XH",V8?8I]N,(-BTV878IR#8J-BQV8C8
MLMBQV+/8I]F&VXP@V+38K]F'(-BGV+/8J@#8I]BSV84@V+'9A=BR("#8M-F%
MV*<@V*C8I]BRV8;8M-BGV8;;C"#8M-BOV8<@V*?8L]BJ`-BGV+/9A2#8L=F%
MV+(@V+39A=BG(-BHV*?8LMF&V+38I]F&VXP@V+38K]F'(-BGV+/8JMB,(-F^
MV+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V*[9B-BO(-BQV*<@VH;:J2#:J=F&
MVXS8KR#9B"#8J-BG(-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\@V*[9B-BO(-F(
MV*?8L=BO(-BTV8C;C-BO`-BGV+/9A2#8L=F%V+(@(-BTV878IR#9A=F&V8+8
MMMN,(-BTV*_9AR#8I]BSV*H`VJG8I]BQV+/8I]BRXH",V8?8I]N,(-BQV*?9
MA^*`C-BOV8C8L2#8M-F%V*<Z`%O9OMF&V8?8I]F&(-JIV+'8K]F&(-F%V*K9
MAB#9AMF"V80@V8+9B-F$(-BTV*_9AUT`6]JOV++8I]BQV+0@V878M-JIV81=
M(`!;V8;9A=BGVXS8M"#9A=BJV88@V8;9@MF$(-F"V8C9A"#8M-BOV8<@+0#9
MAMF%V*?;C-BT(-F%V*K9AB#9AMF"V80@V8+9B-F$(-BTV*_9AUL@+2`E<R#8
MKMBW70!;V*[8MR`E<R#8I]BR("5S(%T@`-BSV+'9OMBQV+/8JMN,`$-,20#8
MK]BQV*[8JB#8K]BGV*_9AP#8K=BPV8$@V+/8M]BQ`-JOV+'9B-F')B-X,C`P
M8SO9A]BG`-BQV*?9A]F&V878IP#8KMBUV8C8M=N,V*?8JB#8JMBUV8C;C-BQ
M+BXN`-F(V+'9B-BO`-BNV+'9B-BL`-BJV+K;C-N,V+$@V;[;C-F(V8;8KRXN
M+@#:K]BRVXS9AMF'XH",V8?8IP#9A=BLV8C8LMF'V*<`V*W8L-F!(-F^VXS9
MB-F&V*\N+BX`V+'8I]F')B-X,C`P8SO8I]F&V*_8I]BRVXP`V*[8M=F(V+7;
MC-BGV*H@V*S8K]F(V80N+BX`VJG8I]BQV*C8L=BGV88`VJG8JMBGV*C:AMF'
MV90@V*+8K]BQV+,@`-BJV8+9B-N,V84`V*+8L=BGV84`V*?;C-F&V*S8IR#8
ML=BG(-F!V+38I]BQ(-BOV8?;C-BO`-F^V+'9B-F&V*_9AP#8I]BR("5S("@E
M<RD@V*_8L2`E<R`E<P#8J-BGV*\`:#H`V8'9B-BQV*?9BP#8K]BQV*[8MP#8
MKMBWV8C8MUT`V8;8I]F%`-F^VXS8I]BOV8<@V+/8I]BRVXP@V8;8M-BOV8<`
MV8?9AMF(V+(@V;[;C-BGV*_9AR#8L]BGV++;C"#9AMBTV*_9AR#8I]BSV*H`
M;F]T97!A9`#8K]BQV+78KP#9OMN,VJG8L]F$V8?8IP#8M]F$V8C8N0#9AMF%
MV*?;C-BT(-BJV8'8I]F(V*K9A]BG`-F^VXSB@(S8K]BQV;[;C`#9@=F'V+'8
ML]BJ(-F(V+C;C-F!V8<`V*?8L]F%(-BQV878LB#8L=BG(-BHV+'8I]N,(-BJ
MV*/;C-N,V*\@V*_9B-BHV*?8L2#9B-BGV+'8KR#:J=F&VXS8KP#;C-JOV*?9
MAMF'(-BTV*_9AP#8J-N,(-F&V*?9A0#8I]F&V*K8KMBGV*@@VJG8I]BQV*C8
ML0!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O9F%?25(O:&5L<"YX;6P`````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-C$T`#$P-#$W,S8R-S<V`#`R,#,R
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B(#\^(`T*/&AE;'`^#0H@/&5N=')Y(&ED/2)S
M=6UM87)Y(B!M9#4](C8X8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U
M(B!S=&%T93TB=7!T;V1A=&4B/@T*("`\=&ET;&4^V*_8L=JOV*?9ASPO=&ET
M;&4^(`T*("`\<&%R83[8I]F*V88@V*_8L=JOV*?9AR#8KMF$V*?8M=F'XH",
MV*?9BMF*(-BGV+(@V*?8M]F$V*?8N=BGV*H@V879A]F%(-BTV878IR#8L=BG
M(-BOV+$@V*?8KMBJV8K8I]BQ(-F"V+'8I]BQ(-F%V8KB@(S8K]F'V*\N(-BH
MV+'8I]N,(-F%V*O8I]F$(-BGV8K9AB#8K]BQVJ_8I]F'(-F&V+38I]F&(-F%
MV8KB@(S8K]F'V*\@VJG9AR#:AMF&V*\@V8;8I]F%V8?9E"#8I]F$VJG8JMBQ
MV8C9AMF*VJG;C"#8JMBGV++9AR#8K]BQ(-F&V*?9A=F'XH",V*_8I]F&(-BT
MV878IR#9A=F(V*S9B-BO(-BGV+/8JMB,(-J&V8<@V8C9@MBGV8K8N=N,(-BW
MV*C9@B#8JMF"V8C9BMF%(-BTV878IR#8L=BN(-BOV*?8K]F'(-BGV+/8JMB,
M(-J&V8<@V8C8N-BGV8K9@=N,(-BWV*C9@B#9A-F*V+/8JB#9B-BXV*?9BMF!
M(-BTV878IR#8J-F'(-BYV8?8K]F'XH",V*?8JMBGV88@V*?8L]BJV(P@V+/8
ML=BJV8K8JMBQV8?8I]N,(-BSV+'9B-F*V+/9A]BGVXP@V*[8J-BQVXP@V*?9
MAMBJV*[8I]BHVXP@V+39A=BG(-J&V8K8L]BJ(-F(("XN+BX\+W!A<F$^(`T*
M("`\<&%R83[9A=BMV*K9B-BGVXP@V*?9BMF&(-BOV+':K]BGV8<@V*?8LB#8
MM]BQV8K9@B#8K]JOV879A]F4(-BLV*?9AMF%V*?8IMN,(-F%VXSB@(S8JMF(
MV*?9AMBO(-BHV8<@V+3:J=F$(-BOV838KMF(V*?9AR#8M-F%V*<@V*_8L=BH
MV8K8I]F*V*\N(-BHV+'8I]N,(-F%V*O8I]F$(-BTV878IR#9A=N,XH",V*K9
MB-BGV8;9BMBO(-F%V8C8I]BQV*\@V*_9A-BNV8C8I]F'(-BNV8C8KR#8L=BG
M(-BHV+'8I]N,(-F&V878I]F*V+0@V*_8L2#8K]BQVJ_8I]F'(-F((-F'V87:
MAMF&V8K9AB#8JMBQV*K9BMBH(-F&V878I]F*V+0@V*+9AMF'V*<@V+'8IR#9
MAMF*V+(@V*K8N=F*V8K9AB#9AMF%V*?9BMF*V*\N/"]P87)A/B`-"B`\+V5N
M=')Y/@T*(#QE;G1R>2!I9#TB;F%V8F%R(B!M9#4](F(X8V8P864Q.64U-V1F
M83!C,F(Y-C)E-3$V-S@R9C0W(B!S=&%T93TB=7!T;V1A=&4B/@T*("`\=&ET
M;&4^VJ_8LMN,V8;:K]BGV88@V878L=F(V+':K]BQ(-BHV+'9AMBGV879A^*`
MC-F'V*<\+W1I=&QE/B`-"B`@/'!A<F$^V*_8L2#8L]F%V*H@V+'8I]BSV*H@
MV*?9BMF&(-BOV+':K]BGV8<@VJ_8LMN,V8;:K]BGV88@V878L=F(V+':K]BQ
M(-BHV+'9AMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C"#9@MBQV*?8
ML2#8K]BGV+'8KR#:J=F'(-BHV*<@V8'8M-BQV*_9AB#8K]JOV879AR#9A=F(
MV+,@V*C8L2#8L=F(VXP@V8?8L2#9BMJI(-BGV+(@V*?9BMF&(-BHV+'9AMBG
MV879A^*`C-F'V*<@V*C9AR#8L=BGV*W8JMN,(-F%VXSB@(S8JMF(V*?9AMF*
MV*\@V*?8LB#8HMF&V8?8IR#8I]BSV*K9@=BGV*_9AR#9AMF%V*?9BMF*V*\N
M/"]P87)A/B`-"B`\+V5N=')Y/@T*(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I
M;G1E;F%N8V4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D
M,#`B('-T871E/2)U<'1O9&%T92(^#0H@(#QT:71L93[8JMBQV*S9BMBMV*?8
MJB`Z(-F&VJ_9A]BOV*?8L=N,(#H@V*?9AMBLV*?9A2#9AMJOV8?8K]BGV+';
MC#PO=&ET;&4^(`T*("`\<&%R83[8I]JOV+$@V+39A=BG(-F%V*?9BMF$(-BH
MV8<@V*?9AMBLV*?9A2#8N=F%V839BMBGV*H@V8;:K]F'V*_8I]BQVXP@V*C9
MAR#9A]F&VJ_8I]F%(-F(V+'9B-BO(-F%VXSB@(S8J-BGV+39BMBO(-BGV8K9
MAB#:K]BRV8K9AMF'(-BQV*<@V*C8I]F*V*\@V*?9AMBJV*[8I]BH(-JIV8;9
MBMBO+CPO<&%R83X@#0H@/"]E;G1R>3X-"B`\96YT<GD@:60](G!R969S+6-O
M;F9I<FU?;6%I;G1E;F%N8V4B(&UD-3TB83(Q,38R8V1F9C-B,60X9F%E861B
M-S(Y-C(T,#`S-F4B('-T871E/2)U<'1O9&%T92(^#0H@(#QT:71L93[8JMBQ
MV*S9BMBMV*?8JB`Z(-F&VJ_9A]BOV*?8L=N,(#H@V*K8H]BFV8K8KR#9AMJO
MV8?8K]BGV+';C#PO=&ET;&4^(`T*("`\<&%R83[8I]JOV+$@V+39A=BG(-F%
MV*?9BMF$(-F'V+/8JMF*V*\@VJG9AR#8N=F%V839BMBGV*H@V8;:K]F'V*_8
MI]BQVXP@V+'8IR#9@MBHV80@V*?8LB#8I]F&V*S8I]F%(-BBV8;9A]BG(-BJ
MV*/8IMF*V*\@VJG9AMF*V*_8C"#8I]F*V88@VJ_8LMF*V8;9AR#8L=BG(-BG
MV8;8JMBNV*?8J"#:J=F&V8K8KRX@V*_8L2#8NMF*V+$@V*?9BMF&(-BUV8C8
ML=BJ(-BJV878I]F%(-BYV879A-F*V*?8JB#9AMJOV8?8K]BGV+';C"#8J-F'
M(-F'V8;:K]BGV84@V8C8L=F(V*\@V*?9AMBLV*?9A2#9BMBGV8'8JMF'(-F(
M(-BTV878IR#8M-BGV8;8L]N,(-BHV+'8I]N,(-F%V838NMN,(-JIV+'8K]F&
M(-BBV88@V8;8KMF(V*?9A]F*V*\@V*_8I]BTV*HN/"]P87)A/B`-"B`\+V5N
M=')Y/@T*/"]H96QP/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9FE?1DDO````````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8R-S<V`#`Q-C8T-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F
M:5]&22],0U]-15-304=%4R\`````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`,#(P-#,Q`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V9I7T9)+TQ#7TU%4U-!1T53+VAO<F1E+FUO````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0Q,C0P,0`Q,#0Q-S,V,C<W-@`P,C(P
M-C8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MWA($E0````"*!P``'````&P\```3"@``O'@````````(H0``#@````FA```/
M````&*$```T````HH0``"````#:A```+````/Z$```P```!+H0``!````%BA
M```8````7:$``!L```!VH0``+0```)*A```=````P*$``"0```#>H0``*0``
M``.B```9````+:(``"8```!'H@``#````&ZB```D````>Z(```\```"@H@``
M"P```+"B```.````O*(```4```#+H@``*````-&B```(````^J(```H````#
MHP``%0````ZC```2````)*,```L````WHP``A0```$.C```.````R:,```H`
M``#8HP``#0```..C```.````\:,``!$`````I```#0```!*D```,````(*0`
M``T````MI```!@```#ND``"4````0J0```H```#7I```#P```.*D```8````
M\J0```P````+I0``#@```!BE```.````)Z4```@````VI0``"0```#^E```N
M````2:4``!H```!XI0``,@```).E```X````QJ4``%0```#_I0``40```%2F
M``!:````IJ8``%<````!IP``-````%FG```)````CJ<```T```"8IP``!P``
M`*:G```*````KJ<```\```"YIP``!0```,FG```&````SZ<``!$```#6IP``
M"````.BG```)````\:<```D```#[IP``)0````6H```@````*Z@``!,```!,
MJ```$````&"H```/````<:@```H```"!J````P```(RH```/````D*@``!0`
M``"@J```"0```+6H```-````OZ@``!(```#-J```&0```."H```>````^J@`
M``\````9J0``"@```"FI```/````-*D```@```!$J0``)````$VI```4````
M<JD``!8```"'J0``"````)ZI``!.````IZD``"T```#VJ0``&0```"2J```'
M````/JH```P```!&J@``+````%.J```.````@*H```,```"/J@``"P```).J
M```'````GZH```<```"GJ@``!0```*^J```%````M:H```H```"[J@```P``
M`,:J```7````RJH```H```#BJ@``#P```.VJ```.````_:H``!@````,JP``
M(P```"6K```.````2:L``!0```!8JP``%P```&VK```7````A:L``!<```"=
MJP``$P```+6K```/````R:L```X```#9JP``'P```.BK```=````"*P```<`
M```FK```!@```"ZL```(````-:P```\````^K```!@```$ZL```*````5:P`
M`!,```!@K```"P```'2L```0````@*P``!4```"1K```%0```*>L```'````
MO:P``!````#%K```!0```-:L```5````W*P``!$```#RK```#`````2M```[
M````$:T``#@```!-K0``"0```(:M```'````D*T``!0```"8K0```P```*VM
M```%````L:T``!````"WK0``"0```,BM```3````TJT``#D```#FK0``$@``
M`""N```G````,ZX``"P```!;K@``*@```(BN```E````LZX```H```#9K@``
M!@```.2N```)````ZZX```<```#UK@``+P```/VN```W````+:\``"X```!E
MKP``50```)2O```M````ZJ\``"T````8L```/0```$:P```_````A+```"T`
M``#$L```0````/*P```C````,[$``",```!7L0``0````'NQ```M````O+$`
M`#,```#JL0``)0```!ZR```5````1+(``!D```!:L@``*0```'2R```D````
MGK(``"@```##L@``$0```.RR```*````_K(```P````)LP``"@```!:S```0
M````(;,``!8````RLP``%@```$FS```'````8+,```<```!HLP``%````'"S
M```*````A;,```@```"0LP``)P```)FS```(````P;,```<```#*LP``!P``
M`-*S```&````VK,```4```#ALP``!P```.>S```&````[[,```@```#VLP``
M*0```/^S```.````*;0```H````XM```!````$.T```'````2+0```D```!0
MM```!@```%JT```1````8;0```<```!SM```%@```'NT```$````DK0```@`
M``"7M```!@```*"T```-````I[0```8```"UM```'@```+RT```1````V[0`
M``@```#MM```#0```/:T```,````!+4```<````1M0```P```!FU```#````
M';4``!<````AM0``$P```#FU```=````3;4```@```!KM0``!````'2U```(
M````>;4```@```""M0``00```(NU```:````S;4``"L```#HM0``(````!2V
M```5````-;8```8```!+M@``!@```%*V```5````6;8``!@```!OM@``(@``
M`(BV```N````J[8``!T```#:M@``(0```/BV``!4````&K<``"D```!OMP``
M"@```)FW```'````I+<```<```"LMP``%0```+2W```.````RK<```H```#9
MMP``#P```.2W```-````]+<```\````"N```#0```!*X```)````(+@``!0`
M```JN```!@```#^X```8````1K@``!T```!?N```$P```'VX```1````D;@`
M`!0```"CN```!````+BX```&````O;@``!0```#$N```5````-FX``!D````
M+KD```0```"3N0``#@```)BY```%````I[D```4```"MN0``&P```+.Y```:
M````S[D``!,```#JN0``$0```/ZY```1````$+H``!P````BN@``*@```#^Z
M```0````:KH``"$```![N@``!0```)VZ```3````H[H```L```"WN@``$@``
M`,.Z```*````UKH```\```#AN@``#0```/&Z```1````_[H``!,````1NP``
M#````"6[```&````,KL```P````YNP``!@```$:[```7````3;L``!````!E
MNP``$0```':[```(````B+L```4```"1NP``#````)>[```0````I+L```4`
M``"UNP``#0```+N[```&````R;L```<```#0NP``#0```-B[```'````YKL`
M``L```#NNP``!P```/J[```'`````KP```D````*O```"0```!2\```*````
M'KP``!D````IO```/0```$.\```=````@;P```P```"?O```$````*R\```%
M````O;P``"4```##O```$@```.F\```3````_+P``"L````0O0``.P```#R]
M```@````>+T```@```"9O0``-@```**]```A````V;T``!````#[O0``"```
M``R^```,````%;X```8````BO@``!````"F^```/````+KX```X````^O@``
M!P```$V^```*````5;X```T```!@O@``'P```&Z^```<````CKX``"$```"K
MO@``'@```,V^```9````[+X``!X````&OP``&P```"6_```A````0;\``"X`
M``!COP``)@```)*_```<````N;\``!X```#6OP``'````/6_```F````$L``
M`"L````YP```,P```&7````F````F<```"L```#`P```.````.S````=````
M)<$``!4```!#P0``+P```%G!```@````B<$``!(```"JP0``*0```+W!```>
M````Y\$``"`````&P@``$@```"?"``"B````.L(``!8```#=P@``(P```/3"
M```H````&,,``"D```!!PP``*````&O#```?````E,,``!4```"TPP``(```
M`,K#```E````Z\,``"@````1Q```+0```#K$```P````:,0``)(```"9Q```
M(0```"S%```6````3L4``!P```!EQ0``)@```(+%```J````J<4``$$```#4
MQ0``1````!;&```,````6\8```<```!HQ@``!P```'#&```&````>,8```T`
M``!_Q@``$````(W&```2````GL8``!,```"QQ@``$@```,7&```'````V,8`
M``0```#@Q@``$````.7&```0````]L8```P````'QP``#@```!3'```-````
M(\<```\````QQP``$P```$''```-````5<<``"@```!CQP```P```(S'```-
M````D,<```8```">QP``$0```*7'```7````M\<``!L```#/QP``#@```.O'
M```"````^L<``$D```#]QP``!0```$?(```0````3<@```\```!>R```!```
M`&[(```-````<\@```X```"!R````P```)#(```.````E,@```@```"CR```
M#P```*S(```/````O,@```<```#,R```#0```-3(```0````XL@```T```#S
MR```"P````')```&````#<D```L````4R0``#````"#)```*````+<D``!$`
M```XR0``&0```$K)```+````9,D```T```!PR0``(@```'[)```/````H<D`
M`!L```"QR0``-````,W)```*`````LH``!@````-R@``$@```";*```9````
M.<H``!8```!3R@``(@```&K*```-````C<H```<```";R@``%````*/*```+
M````N,H``"(```#$R@``+P```.?*```+````%\L```D````CRP``&0```"W+
M```+````1\L``!<```!3RP``%P```&O+```)````@\L``!8```"-RP``#P``
M`*3+```9````M,L``!8```#.RP``#@```.7+```8````],L```@````-S```
M#0```!;,```F````),P``$,```!+S```"````(_,```2````F,P``!\```"K
MS```"````,O,```+````U,P``"\```#@S```#@```!#-```%````'\T```8`
M```ES0``10```"S-```#````<LT```<```!VS0``!````'[-```*````@\T`
M``H```".S0``#P```)G-```0````J<T``!<```"ZS0``$0```-+-```9````
MY,T``!<```#^S0``"0```!;.```%````(,X```L````FS@``"@```#+.```"
M````/<X```4```!`S@``#0```$;.```;````5,X``!<```!PS@``%````(C.
M```)````G<X```X```"GS@``#0```+;.```2````Q,X``#@```#7S@``(```
M`!#/```(````,<\```X````ZSP``>P```$G/```8````Q<\``!@```#>SP``
M$0```/?/```'````"=````4````1T```&````!?0```>````,-```!L```!/
MT```&0```&O0```;````A=```!D```"AT```$P```+O0```'````S]````@`
M``#7T```!@```.#0```&````Y]```!````#NT```#P```/_0```0````#]$`
M``\````@T0``"P```##1```/````/-$```P```!,T0``#P```%G1```'````
M:=$```8```!QT0``#@```'C1```,````A]$``"@```"4T0``#P```+W1```(
M````S=$```@```#6T0``$P```-_1```>````\]$``"$````2T@``(````#32
M```9````5=(``!<```!OT@``)0```(?2```7````K=(``!8```#%T@``!```
M`-S2```;````X=(```T```#]T@``#`````O3```#````&-,```4````<TP``
M"````"+3```*````*],```P````VTP``"P```$/3```0````3],```P```!@
MTP``#@```&W3```+````?-,```0```"(TP``!````(W3```3````DM,``!0`
M``"FTP``#````+O3```)````R-,```X```#2TP``"P```.'3```;````[=,`
M``<````)U```!P```!'4```*````&=0```T````DU```"0```#+4```$````
M/-0```4```!!U````P```$?4```8````2]0```H```!DU```!````&_4```F
M````=-0```X```";U```?````*K4```5````)]4```4````]U0``!P```$/5
M```,````2]4```@```!8U0``"@```&'5```&````;-4```@```!SU0```@``
M`'S5```&````?]4```8```"&U0``%````(W5```-````HM4``!````"PU0``
M&P```,'5```$````W=4```D```#BU0``$````.S5```)````_=4```D````'
MU@``!0```!'6```:````%]8```@````RU@``!@```#O6```9````0M8```X`
M``!<U@``!P```&O6```'````<]8```4```![U@``"0```('6```*````B]8`
M``X```"6U@```@```*76```&````J-8```L```"OU@``#0```+O6```)````
MR=8```8```#3U@``$@```-K6```)````[=8```<```#WU@``%````/_6```=
M````%-<``$(````RUP``)0```'77```E````F]<```8```#!UP``"@```,C7
M```$````T]<```D```#8UP``"````.+7```1````Z]<```D```#]UP``!@``
M``?8```-````#M@```8````<V```!````"/8```Y````*-@``#T```!BV```
M.@```*#8```>````V]@```4```#ZV```#@````#9```$````#]D```8````4
MV0``!P```!O9```A````(]D```T```!%V0``%0```%/9```&````:=D```0`
M``!PV0``$0```'79```&````A]D```H```".V0``(@```)G9```$````O-D`
M``4```#!V0``'0```,?9```$````Y=D```P```#JV0``#@```/?9```*````
M!MH```@````1V@``"0```!K:```%````)-H``#H````JV@``,````&7:```U
M````EMH``"D```#,V@``1P```/;:```X````/ML``"D```!WVP``/P```*';
M```N````X=L``"T````0W```'P```#[<```/````7MP``!(```!NW```"P``
M`('<```F````C=P``"D```"TW```)````-[<```F`````]T```@````JW0``
M"@```#/=```)````/MT```<```!(W0``(````%#=```@````<=T``"8```"2
MW0``"@```+G=```9````Q-T``"D```#>W0``%@````C>```2````']X```<`
M```RW@``"@```#K>```,````1=X```\```!2W@``$````&+>``!`````<]X`
M`'````"TW@``9@```"7?```.````C-\```D```";WP``"@```*7?```2````
ML-\``!,```##WP``#````-??```&````Y-\```\```#KWP``$@```/O?```0
M````#N```!$````?X```'````#'@```C````3N```&H```!RX```#P```-W@
M```%````[>```!````#SX```"0````3A```$````#N$```L````3X0``(```
M`!_A```4````0.$```P```!5X0``#````&+A```/````;^$``!4```!_X0``
M*0```)7A```J````O^$``"8```#JX0``)P```!'B```I````.>(``"H```!C
MX@``&0```([B``!"````J.(``!$```#KX@``$@```/WB```3````$.,``!0`
M```DXP``#P```#GC```6````2>,``!<```!@XP``$````'CC```1````B>,`
M`#0```";XP``$P```-#C```2````Y.,``#4```#WXP``%````"WD```'````
M0N0```P```!*Y```(````%?D```0````>.0``!0```")Y```$0```)[D```7
M````L.0``!P```#(Y```$P```.7D```4````^>0``!H````.Y0``$0```"GE
M```:````.^4``!X```!6Y0``&@```'7E```3````D.4``!4```"DY0``$0``
M`+KE```7````S.4``!0```#DY0``%P```/GE```5````$>8```D````GY@``
M$````#'F```9````0N8```0```!<Y@``!P```&'F```+````:>8``!$```!U
MY@``!@```(?F```&````CN8```8```"5Y@``!0```)SF```'````HN8```<`
M``"JY@``!0```++F```6````N.8```8```#/Y@``!@```-;F```$````W>8`
M``0```#BY@``!P```.?F```.````[^8```P```#^Y@``#`````OG```-````
M&.<```H````FYP``#@```#'G```%````0.<``"@```!&YP``#@```&_G```,
M````?N<```\```"+YP``"@```)OG```(````IN<```D```"OYP``*P```+GG
M```$````Y><```@```#JYP``)@```//G```2````&N@```\````MZ```!@``
M`#WH```*````1.@```<```!/Z```"````%?H```@````8.@```D```"!Z```
M%````(OH```,````H.@```T```"MZ```#@```+OH```6````RN@``!$```#A
MZ```!@```//H```#````^N@```8```#^Z```&0````7I```'````'^D```0`
M```GZ0``"P```"SI```+````..D```<```!$Z0``!0```$SI```'````4ND`
M`!8```!:Z0``#0```''I```-````?^D```H```"-Z0``$````)CI```/````
MJ>D``!$```"YZ0``%P```,OI```*````X^D``!$```#NZ0``"`````#J```$
M````">H```\````.Z@``.@```![J```%````6>H```P```!?Z@``'@```&SJ
M```.````B^H``!````":Z@``"P```*OJ```,````M^H```D```#$Z@``!P``
M`,[J```*````UNH```D```#AZ@``#@```.OJ```0````^NH``!L````+ZP``
M&````"?K```:````0.L```H```!;ZP``"0```&;K```*````<.L```P```![
MZP``#P```(CK```(````F.L```8```"AZP``'````*CK```'````Q>L```4`
M``#-ZP``"P```-/K``!'````W^L```T````G[```"0```#7L```$````/^P`
M``,```!$[```$P```$CL```3````7.P``!,```!P[```"@```(3L```"````
MC^P```0```"2[```)0```)?L```#````O>P```4```#![```*@```,?L```*
M````\NP```4```#][```!`````/M```*````".T```T````3[0``!@```"'M
M```(````*.T```@````Q[0``!````#KM```%````/^T``&@```!%[0``"0``
M`*[M```,````N.T``!````#%[0``!0```-;M```&````W.T``!L```#C[0``
M+P```/_M```0````+^X```H```!`[@``#P```$ON```*````6^X```D```!F
M[@``$P```'#N```;````A.X``!@```"@[@``%P```+GN```?````T>X```X`
M``#Q[@```P````#O```'````!.\```@````,[P``!P```!7O```*````'>\`
M``L````H[P``!P```#3O``!1````/.\``!````".[P``#````)_O```-````
MK.\``!H```"Z[P``2@```-7O```9````(/````8````Z\```&@```$'P```E
M````7/````8```""\```!@```(GP```?````D/````8```"P\```"0```+?P
M```8````P?```!<```#:\```*````/+P```&````&_$```T````B\0``(@``
M`##Q``!7````4_$``!,```"K\0``(P```+_Q```3````X_$```(```#W\0``
M"P```/KQ```(````!O(```T````/\@``"@```!WR```'````*/(``!0````P
M\@``!@```$7R```(````3/(```X```!5\@``!P```&3R```*````;/(```L`
M``!W\@``,@```(/R```'````MO(```P```"^\@``#0```,OR```7````V?(`
M``P```#Q\@``"0```/[R```)````"/,```H````2\P``!P```!WS```)````
M)?,```<````O\P``"@```#?S```;````0O,```\```!>\P``$@```&[S```*
M````@?,``!8```",\P``"0```*/S```0````K?,```<```"^\P``$@```,;S
M```$````V?,```<```#>\P``!0```.;S```%````[/,```L```#R\P``%```
M`/[S```1````$_0``!H````E]```%@```$#T```4````5_0``!<```!L]```
M&````(3T```<````G?0``!D```"Z]```!P```-3T```%````W/0```T```#B
M]```#````/#T```(````_?0``!<````&]0``"P```![U```,````*O4``!\`
M```W]0``&@```%?U```3````<O4```0```"&]0``"@```(OU```$````EO4`
M``T```";]0``#````*GU```%````MO4```D```"\]0``!0```,;U```'````
MS/4```4```#4]0``!````-KU```"````W_4``#@```#B]0``+````!OV```2
M````2/8``"D```!;]@``,@```(7V```*````N/8``"P```##]@``+@```/#V
M```S````'_<``#,```!3]P``.````(?W```/````P/<``!@```#0]P``$```
M`.GW```/````^O<``!,````*^```%0```![X```4````-/@``!(```!)^```
M%````%SX```5````<?@``"T```"'^```+0```+7X```Q````X_@``"X````5
M^0``+P```$3Y```L````=/D``&(```"A^0``$P````3Z```-````&/H```@`
M```F^@``%P```"_Z```(````1_H```P```!0^@``*P```%WZ```A````B?H`
M`!H```"K^@``"0```,;Z``!%````T/H``$$````6^P``!````%C[```3````
M7?L``!0```!Q^P``#@```(;[```3````E?L``!@```"I^P``!@```,+[```)
M````R?L```H```#3^P``#P```-[[```0````[OL```<```#_^P``#@````?\
M```%````%OP``!L````<_```"````#C\```&````0?P``!0```!(_```$0``
M`%W\```.````;_P``#@```!^_````@```+?\```&````NOP```X```#!_```
M!0```-#\```'````UOP```X```#>_```!@```.W\```H````]/P```P````=
M_0``'````"K]```$````1_T``"D```!,_0``%P```';]```?````COT``%P`
M``"N_0``%`````O^```^````(/X``!\```!?_@``$````'_^```'````D/X`
M``X```"8_@``#````*?^```,````M/X``!,```#!_@``"@```-7^```=````
MX/X``!D```#^_@``!0```!C_```1````'O\``!$````P_P``)````$+_```2
M````9_\``!4```!Z_P``$@```)#_```.````H_\``!D```"R_P``"````,S_
M```)````U?\```T```#?_P``!P```.W_```*````]?\```<```````$`#P``
M``@``0`&````&``!``L````?``$`&@```"L``0`*````1@`!``<```!1``$`
M"````%D``0`%````8@`!`!\```!H``$`!@```(@``0`0````CP`!``@```"@
M``$`#0```*D``0`(````MP`!`!X```#```$`$@```-\``0`L````\@`!`!H`
M```?`0$`"0```#H!`0`*````1`$!`!4```!/`0$`!0```&4!`0`4````:P$!
M``0```"``0$`$````(4!`0`&````E@$!``<```"=`0$`'@```*4!`0`H````
MQ`$!``H```#M`0$`'````/@!`0`1````%0(!``L````G`@$`&@```#,"`0`4
M````3@(!``0```!C`@$`!````&@"`0`+````;0(!``4```!Y`@$`!@```'\"
M`0`(````A@(!``8```"/`@$`"@```)8"`0`;````H0(!`#0```"]`@$`-```
M`/("`0`@````)P,!`"D```!(`P$`(````'(#`0!!````DP,!`!H```#5`P$`
M*````/`#`0`I````&00!`%````!#!`$`(@```)0$`0`&````MP0!``@```"^
M!`$`!0```,<$`0`(````S00!`!D```#6!`$`&0```/`$`0`J````"@4!`",`
M```U!0$`&0```%D%`0`N````<P4!`#0```"B!0$`"````-<%`0`7````X`4!
M``H```#X!0$`!P````,&`0`A````"P8!`!`````M!@$`#@```#X&`0`+````
M308!``<```!9!@$`$P```&$&`0`(````=08!``L```!^!@$`"@```(H&`0`4
M````E08!``\```"J!@$`,@```+H&`0`+````[08!``X```#Y!@$`!0````@'
M`0`%````#@<!``4````4!P$`%P```!H'`0`/````,@<!``0```!"!P$`"@``
M`$<'`0`)````4@<!``L```!<!P$`#0```&@'`0`,````=@<!``X```"#!P$`
M!0```)('`0`$````F`<!``T```"=!P$`,@```*L'`0!%````W@<!`!<````D
M"`$`!P```#P(`0`>````1`@!`!0```!C"`$`!0```'@(`0`4````?@@!``8`
M``"3"`$`!P```)H(`0`.````H@@!`"H```"Q"`$`!@```-P(`0`,````XP@!
M``T```#P"`$`$0```/X(`0`+````$`D!`#8````<"0$`"@```%,)`0`B````
M7@D!``L```"!"0$`#P```(T)`0`R````G0D!`"4```#0"0$`,````/8)`0`Q
M````)PH!`"T```!9"@$`#@```(<*`0`%````E@H!``X```"<"@$`$P```*L*
M`0`2````OPH!``<```#2"@$`$0```-H*`0`3````[`H!``<`````"P$`%```
M``@+`0`8````'0L!``<````V"P$`!0```#X+`0`,````1`L!``P```!1"P$`
M$@```%X+`0`$````<0L!``<```!V"P$`"@```'X+`0`+````B0L!``P```"5
M"P$`#@```*(+`0`.````L0L!``4```#`"P$`!0```,8+`0`N````S`L!`"8`
M``#["P$`(P```"(,`0`#````1@P!`!(```!*#`$`!@```%T,`0`>````9`P!
M`!@```"##`$`)0```)P,`0`-````P@P!``D```#0#`$`'P```-H,`0`#````
M^@P!``<```#^#`$`"@````8-`0`"````$0T!``P````4#0$`%0```"$-`0`+
M````-PT!`!D```!##0$`(````%T-`0`2````?@T!``4```"1#0$`"@```)<-
M`0`5````H@T!`!(```"X#0$`#````,L-`0`$````V`T!``D```#=#0$`!P``
M`.<-`0`,````[PT!`%(```#\#0$`%P```$\.`0`D````9PX!`!(```",#@$`
M!P```)\.`0`&````IPX!``X```"N#@$`#````+T.`0`-````R@X!`!4```#8
M#@$`$@```.X.`0`/`````0\!`!0````1#P$`"@```"8/`0`;````,0\!`!``
M``!-#P$`"P```%X/`0!I````:@\!`!H```#4#P$`%P```.\/`0`G````!Q`!
M`!H````O$`$`%P```$H0`0`;````8A`!`!D```!^$`$`'P```)@0`0`3````
MN!`!``@```#,$`$`!P```-40`0`(````W1`!``D```#F$`$`%0```/`0`0`-
M````!A$!`",````4$0$`#0```#@1`0`3````1A$!``@```!:$0$``P```&,1
M`0!&````9Q$!`#\```"N$0$`-P```.X1`0!7````)A(!``4```!^$@$`'P``
M`(02`0`O````I!(!``H```#4$@$`"````-\2`0`-````Z!(!`"T```#V$@$`
M!````"03`0!/````*1,!`"4```!Y$P$`'````)\3`0`+````O!,!`!\```#(
M$P$`'0```.@3`0`E````!A0!`"`````L%`$`)````$T4`0`@````<A0!``L`
M``"3%`$`!P```)\4`0`-````IQ0!``P```"U%`$`%P```,(4`0`&````VA0!
M`#D```#A%`$`#````!L5`0`'````*!4!``D````P%0$`$P```#H5`0`)````
M3A4!``0```!8%0$`$````%T5`0`(````;A4!``@```!W%0$`!````(`5`0`+
M````A14!``P```"1%0$`$@```)X5`0`1````L14!``P```##%0$`&@```-`5
M`0`/````ZQ4!``<```#[%0$`#0````,6`0`4````$18!``X````F%@$`#```
M`#46`0`;````0A8!`"P```!>%@$`$P```(L6`0`<````GQ8!`"@```"\%@$`
M!@```.46`0`'````[!8!`!,```#T%@$`!0````@7`0`$````#A<!`!<````3
M%P$`"@```"L7`0`,````-A<!``D```!#%P$`!@```$T7`0`)````5!<!``@`
M``!>%P$`"0```&<7`0`*````<1<!`!$```!\%P$`!@```(X7`0`.````E1<!
M``X```"D%P$`#0```+,7`0`+````P1<!`!T```#-%P$`"P```.L7`0`"````
M]Q<!`!P```#Z%P$`!P```!<8`0`&````'Q@!`&0````F&`$`"0```(L8`0`'
M````E1@!`"8```"=&`$`.````,08`0`:````_1@!`"H````8&0$`.P```$,9
M`0`H````?QD!`#0```"H&0$`&0```-T9`0`5````]QD!``4````-&@$`!P``
M`!,:`0`(````&QH!``<````D&@$`!0```"P:`0`'````,AH!``X````Z&@$`
M"0```$D:`0`&````4QH!``@```!:&@$`"P```&,:`0`'````;QH!``@```!W
M&@$`!P```(`:`0`6````B!H!``D```"?&@$`!@```*D:`0`+````L!H!`!``
M``"\&@$`!@```,T:`0`<````U!H!`!0```#Q&@$`!P````8;`0`1````#AL!
M``@````@&P$`#@```"D;`0`(````.!L!``4```!!&P$`$````$<;`0`)````
M6!L!`!````!B&P$`!@```',;`0`9````>AL!``H```"4&P$`'````)\;`0`'
M````O!L!``4```#$&P$`$````,H;`0`4````VQL!``L```#P&P$`#0```/P;
M`0`H````"AP!`!@````S'`$`%P```$P<`0`$````9!P!``D```!I'`$`"@``
M`',<`0`'````?AP!``(```"&'`$`#@```(D<`0`(````F!P!`",```"A'`$`
M'P```,4<`0`X````Y1P!`"8````>'0$`,0```$4=`0`G````=QT!`&0```"?
M'0$`%`````0>`0!5````&1X!`#@```!O'@$`2@```*@>`0!;````\QX!`"@`
M``!/'P$`.````'@?`0`H````L1\!`"P```#:'P$`)@````<@`0`;````+B`!
M`#X```!*(`$`J0$``(D@`0`C````,R(!`!<```!7(@$`2````&\B`0"%````
MN"(!`#`````^(P$`)0```&\C`0!!````E2,!`%L```#7(P$`20```#,D`0`Q
M````?20!`!T```"O)`$`&````,TD`0`K````YB0!`"$````2)0$`'P```#0E
M`0`K````5"4!`"8```"`)0$`)P```*<E`0`Z````SR4!`!T````*)@$`$0``
M`"@F`0`S````.B8!`"4```!N)@$`)P```)0F`0`@````O"8!`!\```#=)@$`
M,````/TF`0!I````+B<!`#$```"8)P$`00```,HG`0`S````#"@!`"4```!`
M*`$`/0```&8H`0!E````I"@!`$T````**0$`+P```%@I`0`N````B"D!`#``
M``"W*0$`5````.@I`0!:````/2H!`$@```"8*@$`2@```.$J`0`R````+"L!
M`"\```!?*P$`+````(\K`0`M````O"L!`'$```#J*P$`9@```%PL`0!O````
MPRP!`+,````S+0$`%P```.<M`0`E````_RT!`#(````E+@$`*0```%@N`0`^
M````@BX!`"(```#!+@$`4@```.0N`0`E````-R\!``L```!=+P$`L0```&DO
M`0!%````&S`!`"$```!A,`$`,````(,P`0`E````M#`!`!P```#:,`$`,0``
M`/<P`0`'````*3$!``<````Q,0$`!````#DQ`0`-````/C$!``L```!,,0$`
M#@```%@Q`0`+````9S$!``4```!S,0$`$````'DQ`0`"````BC$!`%D```"-
M,0$`!0```.<Q`0`2````[3$!``0`````,@$`!P````4R`0`(````#3(!``4`
M```6,@$`,````!PR`0`#````33(!`!````!1,@$`#````&(R`0`3````;S(!
M``T```"#,@$``@```)$R`0`'````E#(!``8```"<,@$`%````*,R`0`,````
MN#(!`!@```#%,@$`!@```-XR`0`2````Y3(!``P```#X,@$``P````4S`0`J
M````"3,!``0````T,P$`!@```#DS`0`'````0#,!`!\```!(,P$`-0```&@S
M`0`N````GC,!`"\```#-,P$`%P```/TS`0`B````%30!`"4````X-`$`(```
M`%XT`0`;````?S0!`!@```";-`$`)````+0T`0`?````V30!`!H```#Y-`$`
M(0```!0U`0`@````-C4!`!H```!7-0$`,@```'(U`0`:````I34!`"\```#`
M-0$`*P```/`U`0`?````'#8!`",````\-@$`'P```&`V`0`:````@#8!`"$`
M``";-@$`)0```+TV`0`F````XS8!`"4````*-P$`)````#`W`0`8````53<!
M`!T```!N-P$`)````(PW`0`8````L3<!`"(```#*-P$`+````.TW`0`O````
M&C@!`!4```!*.`$`)0```&`X`0`\````AC@!`!\```##.`$`(P```.,X`0`?
M````!SD!`"`````G.0$`&@```$@Y`0`8````8SD!`"8```!\.0$`'@```*,Y
M`0`I````PCD!`!X```#L.0$`,0````LZ`0`)````/3H!``P```!'.@$`%P``
M`%0Z`0`O````;#H!`"0```"<.@$`!P```,$Z`0`/````R3H!`!0```#9.@$`
M#@```.XZ`0`-````_3H!`"0````+.P$`!0```#`[`0`'````-CL!`"(````^
M.P$`)0```&$[`0`:````ASL!`!T```"B.P$`&@```,`[`0`'````VSL!`,<`
M``#C.P$`"P```*L\`0`5````MSP!``8```#-/`$`"0```-0\`0`+````WCP!
M``T```#J/`$`%P```/@\`0`&````$#T!`#,````7/0$`$P```$L]`0`3````
M7ST!``<```!S/0$`#P```'L]`0`'````BST!`#(```"3/0$`!````,8]`0`A
M````RST!`!,```#M/0$`#`````$^`0`1````#CX!`#(````@/@$`%@```%,^
M`0`(````:CX!`!T```!S/@$`"0```)$^`0`*````FSX!`!0```"F/@$`"@``
M`+L^`0`=````QCX!``@```#D/@$`'P```.T^`0`(````#3\!`!H````6/P$`
M)P```#$_`0`&````63\!`!4```!@/P$`!P```'8_`0`(````?C\!``D```"'
M/P$`/P```)$_`0`'````T3\!``\```#9/P$`#@```.D_`0`0````^#\!``D`
M```)0`$`"0```!-``0`(````'4`!`!,````F0`$`!P```#I``0`9````0D`!
M``H```!<0`$`%P```&=``0`4````?T`!``H```"40`$`#````)]``0`7````
MK$`!``0```#$0`$`*@```,E``0`,````]$`!`!$````!00$`!P```!-!`0`"
M````&T$!`!`````>00$`&````"]!`0`+````2$$!``,```!400$`"````%A!
M`0`&````84$!``<```!H00$`#0```'!!`0`+````?D$!`!0```"*00$`%0``
M`)]!`0`.````M4$!`"\```#$00$`(````/1!`0`<````%4(!`!4````R0@$`
M#````$A"`0`Q````54(!``4```"'0@$`$@```(U"`0`_````H$(!`!(```#@
M0@$`"@```/-"`0`&````_D(!``0````%0P$`!`````I#`0`*````#T,!`!,`
M```:0P$`!0```"Y#`0`&````-$,!``8````[0P$`"````$)#`0`$````2T,!
M``P```!00P$`"@```%U#`0`Y````:$,!`"X```"B0P$`*0```-%#`0`%````
M^T,!`!@````!1`$`&0```!I$`0`?````-$0!`!T```!41`$`$0```')$`0`"
M````A$0!``0```"'1`$`"@```(Q$`0`&````ET0!``4```">1`$``P```*1$
M`0`,````J$0!`$4```"U1`$`,@```/M$`0`:````+D4!`#0```!)10$`*```
M`'Y%`0!3````IT4!`!D```#[10$`<@```!5&`0`@````B$8!`#4```"I1@$`
M(0```-]&`0!%`````4<!`#````!'1P$`*````'A'`0`I````H4<!`"8```#+
M1P$`)0```/)'`0`H````&$@!`"@```!!2`$`(@```&I(`0`K````C4@!`#``
M``"Y2`$`$@```.I(`0`3````_4@!`!`````120$`>0```"))`0`)````G$D!
M`*$```"F20$`<P```$A*`0!\````O$H!`"L````Y2P$`5````&5+`0`7````
MNDL!`"<```#22P$`%@```/I+`0`/````$4P!`!<````A3`$`'P```#E,`0!`
M````64P!`!\```":3`$`'````+I,`0!1````UTP!`!H````I30$`%````$1-
M`0`*````64T!``4```!D30$`!@```&I-`0`(````<4T!``4```!Z30$`$@``
M`(!-`0`0````DTT!`!,```"D30$`'0```+A-`0`/````UDT!``\```#F30$`
M!````/9-`0`)````^TT!``L````%3@$`!P```!%.`0`%````&4X!`!0````?
M3@$`!P```#1.`0`(````/$X!``\```!%3@$`"````%5.`0`,````7DX!``\`
M``!K3@$`!@```'M.`0`4````@DX!``8```"73@$`#````)Y.`0`1````JTX!
M``@```"]3@$`!````,9.`0`9````RTX!`!$```#E3@$`"@```/=.`0`8````
M`D\!`!,````;3P$`'````"]/`0`1````3$\!``0```!>3P$`#P```&-/`0`'
M````<T\!``0```![3P$`&0```(!/`0`'````FD\!``(```"B3P$``@```*5/
M`0`1````J$\!``D```"Z3P$`!@```,1/`0`2````RT\!`!<```#>3P$`!@``
M`/9/`0`G````_4\!``(````E4`$`!````"A0`0`/````+5`!`!,````]4`$`
M!P```%%0`0`'````65`!`!$```!A4`$`!@```'-0`0`8````>E`!``8```"3
M4`$`$P```)I0`0`0````KE`!`!(```"_4`$``@```-)0`0`&````U5`!``P`
M``#<4`$`"0```.E0`0`1````\U`!`"(````%40$`!P```"A1`0`'````,%$!
M``L````X40$`!0```$11`0`"````2E$!``L```!-40$`5P$``%E1`0`3````
ML5(!`!$```#%4@$`#@```-=2`0`)````YE(!``L```#P4@$`"````/Q2`0`!
M````!5,!`!4````'4P$`&@```!U3`0`J````.%,!`"$```!C4P$`(@```(53
M`0`:````J%,!`!(```##4P$`*@```-93`0`+`````50!`"8````-5`$`$@``
M`#14`0`-````1U0!``X```!55`$`!0```&14`0`C````:E0!``H```".5`$`
M$````)E4`0`.````JE0!`!(```"Y5`$`#P```,Q4`0!E````W%0!`!````!"
M50$`#````%-5`0`/````8%4!``P```!P50$`$````'U5`0`.````CE4!`!``
M``"=50$`$0```*Y5`0`&````P%4!`,(```#'50$`#P```(I6`0`5````FE8!
M`!4```"P5@$`#0```,96`0`5````U%8!`!4```#J5@$`"0````!7`0`*````
M"E<!`#P````55P$`%0```%)7`0`P````:%<!`$,```"95P$`7@```-U7`0!@
M````/%@!`%P```"=6`$`9@```/I8`0`R````85D!``D```"460$`$@```)Y9
M`0`'````L5D!``H```"Y60$`#@```,19`0`%````TUD!``8```#960$`$@``
M`.!9`0`*````\UD!``D```#^60$`#0````A:`0`N````%EH!`"T```!%6@$`
M&````'-:`0`:````C%H!`!8```"G6@$`"@```+Y:`0`%````R5H!``X```#/
M6@$`#P```-Y:`0`,````[EH!`!````#[6@$`$0````Q;`0`;````'EL!`!8`
M```Z6P$`%````%%;`0`,````9EL!`!,```!S6P$`"@```(=;`0`H````DEL!
M`!0```"[6P$`%0```-!;`0`.````YEL!`%L```#U6P$`.````%%<`0`A````
MBEP!``8```"L7`$`"P```+-<`0`Y````OUP!``@```#Y7`$`"0````)=`0`*
M````#%T!``<````770$`!P```!]=`0`%````)UT!``4````M70$`!P```#-=
M`0`&````.UT!`!X```!"70$`#0```&%=`0`/````;UT!`!D```!_70$`%0``
M`)E=`0`G````KUT!``X```#770$`)P```.9=`0`<````#EX!`"(````K7@$`
M(@```$Y>`0`5````<5X!`!8```"'7@$`$@```)Y>`0`7````L5X!`!H```#)
M7@$`!P```.1>`0`&````[%X!``@```#S7@$`#@```/Q>`0`'````"U\!``D`
M```37P$`$@```!U?`0`'````,%\!``P````X7P$`$@```$5?`0`A````6%\!
M``<```!Z7P$`#0```()?`0`(````D%\!`!4```"97P$`#````*]?`0`,````
MO%\!`#\```#)7P$`/P````E@`0`)````26`!``<```!38`$`$P```%M@`0`%
M````;V`!``4```!U8`$`$````'M@`0`+````C&`!`!8```"88`$`-P```*]@
M`0`0````YV`!`"4```#X8`$`)P```!YA`0`G````1F$!`"0```!N80$`#P``
M`)-A`0`&````HV$!``D```"J80$`"````+1A`0`V````O6$!`#\```#T80$`
M-0```#1B`0!=````:F(!`#0```#(8@$`-````/UB`0!!````,F,!`$,```!T
M8P$`-````+AC`0!'````[6,!`"@````U9`$`*@```%YD`0!%````B60!`#0`
M``#/9`$`.@````1E`0`L````/V4!`!D```!L90$`'0```(9E`0`N````I&4!
M`"L```#390$`*P```/]E`0`;````*V8!``L```!'9@$`#P```%-F`0`&````
M8V8!``H```!J9@$`&````'5F`0`>````CF8!``8```"M9@$`!P```+1F`0`4
M````O&8!``H```#19@$`"````-QF`0`N````Y68!``H````49P$`#````!]G
M`0`&````+&<!``8````S9P$`!0```#IG`0`'````0&<!``8```!(9P$`#```
M`$]G`0`H````7&<!``\```"%9P$`#````)5G`0`)````HF<!``<```"L9P$`
M#````+1G`0`%````P6<!``\```#'9P$`!@```-=G`0`2````WF<!``@```#Q
M9P$`"````/IG`0`$`````V@!``T````(:`$`"````!9H`0`G````'V@!`!``
M``!':`$`"````%AH`0`-````86@!``P```!O:`$`!P```'QH`0`#````A&@!
M``,```"(:`$`$P```(QH`0`0````H&@!`",```"Q:`$`"0```-5H`0`%````
MWV@!``D```#E:`$`!P```.]H`0!&````]V@!`"$````^:0$`.@```&!I`0`F
M````FVD!`!P```#":0$`!@```-]I`0`$````YFD!`!(```#K:0$`(````/YI
M`0`A````'VH!`"\```!!:@$`(0```'%J`0`H````DVH!`&$```"\:@$`*0``
M`!YK`0`)````2&L!``H```!2:P$`$````%UK`0`5````;FL!``T```"$:P$`
M#````))K`0`,````GVL!``P```"L:P$`#````+EK`0`,````QFL!``P```#3
M:P$`%````.!K`0`*````]6L!`!<`````;`$`&P```!AL`0`1````-&P!`!,`
M``!&;`$`%0```%IL`0`$````<&P!``4```!U;`$`$0```'ML`0!+````C6P!
M`%,```#9;`$`!@```"UM`0`3````-&T!``4```!(;0$`!0```$YM`0`@````
M5&T!`!@```!U;0$`#P```(YM`0`0````GFT!`!8```"O;0$`'P```,9M`0`P
M````YFT!``L````7;@$`(````"-N`0`&````1&X!`!4```!+;@$`#0```&%N
M`0`3````;VX!``\```"#;@$`%P```)-N`0`2````JVX!`!0```"^;@$`%P``
M`--N`0`,````ZVX!``8```#X;@$`$0```/]N`0`(````$6\!`!<````:;P$`
M%````#)O`0`2````1V\!``@```!:;P$`!````&-O`0`,````:&\!``L```!U
M;P$`!@```(%O`0`3````B&\!``H```"<;P$`!P```*=O`0`-````KV\!``D`
M``"];P$`#````,=O`0`'````U&\!``8```#<;P$`"P```.-O`0`(````[V\!
M``H```#X;P$`#P````-P`0!#````$W`!`!H```!7<`$`$@```')P`0`J````
MA7`!``4```"P<`$`'P```+9P`0`3````UG`!`!0```#J<`$`,P```/]P`0!"
M````,W$!`"0```!V<0$`#````)MQ`0`F````J'$!`!T```#/<0$`#@```.UQ
M`0`%````_'$!``L````"<@$`!@````YR`0`&````%7(!`!D````<<@$`#@``
M`#9R`0`'````17(!``H```!-<@$`$0```%AR`0`E````:G(!`#$```"0<@$`
M)P```,)R`0`S````ZG(!`!L````><P$`,````#IS`0`=````:W,!`",```")
M<P$`.0```*US`0`?````YW,!`"<````'=`$`*0```"]T`0`A````670!`"$`
M``![=`$`)P```)UT`0!"````Q70!`"$````(=0$`(0```"IU`0`K````3'4!
M`!\```!X=0$`'P```)AU`0`Z````N'4!`"(```#S=0$`%0```!9V`0`G````
M+'8!`"````!4=@$`*P```'5V`0`5````H78!`)(```"W=@$`&@```$IW`0`?
M````97<!`!\```"%=P$`(````*5W`0`N````QG<!`!T```#U=P$`'P```!-X
M`0`@````,W@!`"P```!4>`$`+@```(%X`0`P````L'@!`"\```#A>`$`H0``
M`!%Y`0`K````LWD!`"````#?>0$`)`````!Z`0`C````)7H!`"P```!)>@$`
M0````'9Z`0!$````MWH!``\```#\>@$``P````Q[`0`'````$'L!``,````8
M>P$`#P```!Q[`0`(````+'L!`!D````U>P$`$@```$][`0`2````8GL!``<`
M``!U>P$`!0```'U[`0`8````@WL!`!8```"<>P$`&0```+-[`0`4````S7L!
M`!<```#B>P$`$0```/I[`0`4````#'P!`!,````A?`$`3@```#5\`0`'````
MA'P!``\```",?`$`!@```)Q\`0`3````HWP!`!D```"W?`$`&P```-%\`0`0
M````[7P!``(```#^?`$`4`````%]`0`*````4GT!``\```!=?0$`#@```&U]
M`0`'````?'T!`!@```"$?0$`$P```)U]`0`%````L7T!``X```"W?0$`"```
M`,9]`0`0````SWT!`!,```#@?0$`!@```/1]`0`*````^WT!``X````&?@$`
M%````!5^`0`+````*GX!``8````V?@$`"P```#U^`0`,````27X!``L```!6
M?@$`#0```&)^`0`J````<'X!``L```";?@$`#0```*=^`0`K````M7X!`!0`
M``#A?@$`%P```/9^`0!!````#G\!``L```!0?P$`%P```%Q_`0`9````='\!
M`!4```".?P$`$P```*1_`0`?````N'\!``P```#8?P$`!@```.5_`0`/````
M['\!``8```#\?P$`.0````.``0`X````/8`!``<```!V@`$`#````'Z``0`?
M````BX`!``X```"K@`$`&@```+J``0`:````U8`!``D```#P@`$`'0```/J`
M`0`1````&($!`"0````J@0$`'````$^!`0`*````;($!`!,```!W@0$`"```
M`(N!`0`.````E($!`"0```"C@0$`0````,B!`0`.````"8(!`!@````8@@$`
M,````#&"`0`(````8H(!``L```!K@@$`)````'>"`0`/````G((!``<```"L
M@@$`$````+2"`0!6````Q8(!``4````<@P$`!P```"*#`0`'````*H,!``X`
M```R@P$`#@```$&#`0`0````4(,!`!$```!A@P$`&````'.#`0`2````C(,!
M`!@```"?@P$`%@```+B#`0`(````SX,!``8```#8@P$`"P```-^#`0`,````
MZX,!``(```#X@P$`"@```/N#`0`0````!H0!`"<````7A`$`&0```#^$`0`4
M````680!``8```!NA`$`#0```'6$`0`.````@X0!``\```"2A`$`.@```**$
M`0`M````W80!``X````+A0$`$0```!J%`0!G````+(4!`!0```"4A0$`%```
M`*F%`0`6````OH4!``<```#5A0$`!0```-V%`0`?````XX4!`"P````#A@$`
M(@```#"&`0`>````4X8!`"(```!RA@$`&@```)6&`0`;````L(8!``4```#,
MA@$`!P```-*&`0`'````VH8!``@```#BA@$`$@```.N&`0`1````_H8!`!(`
M```0AP$`$0```".'`0`@````-8<!`!0```!6AP$`#P```&N'`0`/````>X<!
M``<```"+AP$`"````).'`0`4````G(<!`!8```"QAP$`,````,B'`0`/````
M^8<!``L````)B`$`!P```!6(`0`@````'8@!`!L````^B`$`)````%J(`0`C
M````?X@!`!\```"CB`$`'P```,.(`0`I````XX@!`!P````-B0$`%@```"J)
M`0`&````08D!`!P```!(B0$`"@```&6)`0`-````<(D!``4```!^B0$`!@``
M`(2)`0`(````BXD!``L```"4B0$`#0```*")`0`0````KHD!`!0```"_B0$`
M#@```-2)`0`.````XXD!``\```#RB0$`!0````**`0`(````"(H!`"(````1
MB@$`(P```#2*`0`5````6(H!``X```!NB@$`$0```'V*`0`0````CXH!`"@`
M``"@B@$`"P```,F*`0`%````U8H!`!0```#;B@$`%0```/"*`0`,````!HL!
M``T````3BP$`!P```"&+`0`$````*8L!`!P````NBP$`#P```$N+`0`%````
M6XL!`"$```!ABP$`#0```(.+`0"3````D8L!`!4````EC`$`"0```#N,`0`*
M````18P!`!,```!0C`$`#````&2,`0`.````<8P!``@```"`C`$`$@```(F,
M`0`"````G(P!``@```"?C`$`!@```*B,`0`1````KXP!``X```#!C`$`$0``
M`-",`0`=````XHP!``D`````C0$`"@````J-`0`/````%8T!``@````EC0$`
M"0```"Z-`0`%````.(T!`!P````^C0$`"0```%N-`0`&````98T!`!````!L
MC0$`#P```'V-`0`'````C8T!``4```"5C0$`!0```)N-`0`)````H8T!``<`
M``"KC0$`$0```+.-`0`$````Q8T!``4```#*C0$`#0```-"-`0`+````WHT!
M``H```#JC0$`!P```/6-`0`4````_8T!``D````2C@$`!P```!R.`0`/````
M)(X!`",````TC@$`2````%B.`0`K````H8X!`"L```#-C@$`!@```/F.`0`*
M`````(\!``0````+CP$`"0```!"/`0`(````&H\!`!0````CCP$`"P```#B/
M`0`&````1(\!``T```!+CP$`!@```%F/`0`$````8(\!`$8```!ECP$`3P``
M`*R/`0!+````_(\!`"````!(D`$`!0```&F0`0`.````;Y`!``0```!^D`$`
M!@```(.0`0`&````BI`!`!@```"1D`$`%````*J0`0`5````OY`!``<```#5
MD`$`!````-V0`0`6````XI`!``0```#YD`$`#P```/Z0`0`;````#I$!``8`
M```JD0$`!0```#&1`0`G````-Y$!``0```!?D0$`"@```&21`0`-````;Y$!
M``X```!]D0$`"````(R1`0`)````E9$!``4```"?D0$`,````*61`0`R````
MUI$!`#H````)D@$`(````$22`0!)````99(!`#D```"OD@$`*0```.F2`0`X
M````$Y,!`"H```!,DP$`+````'>3`0`A````I),!`!$```#&DP$`$````-B3
M`0`+````Z9,!`"4```#UDP$`)P```!N4`0`A````0Y0!`",```!EE`$`!P``
M`(F4`0`)````D90!``H```";E`$`!@```*:4`0`I````K90!`"D```#7E`$`
M,@````&5`0`)````-)4!`!\````^E0$`+0```%Z5`0`6````C)4!`!$```"C
ME0$`!P```+65`0`+````O94!``T```#)E0$`$````->5`0`/````Z)4!`$``
M``#XE0$`C0```#F6`0!D````QY8!`!$````LEP$`"````#Z7`0`)````1Y<!
M`!````!1EP$`$0```&*7`0`,````=)<!``4```"!EP$`$````(>7`0`0````
MF)<!``X```"IEP$`$P```+B7`0`<````S)<!`"8```#IEP$`=````!"8`0`0
M````A9@!``4```"6F`$`%0```)R8`0`)````LI@!``0```"\F`$`"P```,&8
M`0`>````S9@!`!4```#LF`$`"@````*9`0`.````#9D!`!`````<F0$`$P``
M`"V9`0`B````09D!`"````!DF0$`(````(69`0`>````IID!`"0```#%F0$`
M(@```.J9`0`:````#9H!`#4````HF@$`$@```%Z:`0`0````<9H!`!(```""
MF@$`$@```)6:`0`4````J)H!`!4```"]F@$`$P```-.:`0`0````YYH!`!(`
M``#XF@$`*0````N;`0`3````-9L!`!4```!)FP$`2@```%^;`0`<````JIL!
M``P```#'FP$`$0```-2;`0`A````YIL!`!4````(G`$`$0```!Z<`0`2````
M,)P!`!T```!#G`$`'P```&&<`0`6````@9P!`!<```"8G`$`%0```+"<`0`3
M````QIP!`!T```#:G`$`(````/B<`0`E````&9T!`!,````_G0$`%````%.=
M`0`4````:)T!`!P```!]G0$`%0```)J=`0`5````L)T!`!D```#&G0$`"P``
M`."=`0`;````[)T!`!P````(G@$`!````"6>`0`'````*IX!``D````RG@$`
M%P```#R>`0`&````5)X!`!$```!;G@$`"@```&V>`0`&````>)X!``<```!_
MG@$`"````(>>`0`&````D)X!`!0```"7G@$`!@```*R>`0`(````LYX!``@`
M``"\G@$`!P```,6>`0`'````S9X!`!````#5G@$`#@```.:>`0`2````]9X!
M`!`````(GP$`"0```!F?`0`5````(Y\!``4````YGP$`,````#^?`0`3````
M<)\!``X```"$GP$`$````).?`0`.````I)\!``X```"SGP$`#@```,*?`0`K
M````T9\!``8```#]GP$`"`````2@`0`U````#:`!`!X```!#H`$`#@```&*@
M`0`&````<:`!``D```!XH`$`"0```(*@`0`%````C*`!`"0```"2H`$`%0``
M`+>@`0`9````S:`!`!8```#GH`$`%````/Z@`0`A````$Z$!`"4````UH0$`
M+0```%NA`0`&````B:$!``0```"0H0$`"````)6A`0`<````GJ$!``<```"[
MH0$`!0```,.A`0`,````R:$!``L```#6H0$`!@```.*A`0`$````Z:$!``<`
M``#NH0$`%0```/:A`0`,````#*(!``X````9H@$`#P```"BB`0`8````.*(!
M`!D```!1H@$`$P```&NB`0`=````?Z(!`!,```"=H@$`$P```+&B`0`)````
MQ:(!``8```#/H@$`$````-:B`0`_````YZ(!``8````GHP$`#P```"ZC`0`>
M````/J,!`!$```!=HP$`%0```&^C`0`,````A:,!``X```"2HP$`"P```*&C
M`0`)````K:,!``\```"WHP$`#````,>C`0`-````U*,!`!T```#BHP$`(@``
M``"D`0`B````(Z0!`"@```!&I`$`#````&^D`0`'````?*0!``L```"$I`$`
M$P```)"D`0`4````I*0!``8```"YI`$`#P```,"D`0`B````T*0!``T```#S
MI`$`#P````&E`0`>````$:4!`&4````PI0$`(````):E`0`,````MZ4!``<`
M``#$I0$`!@```,RE`0`>````TZ4!`!T```#RI0$`&@```!"F`0`)````*Z8!
M``(````UI@$`!````#BF`0`@````/:8!``8```!>I@$`!0```&6F`0`J````
M:Z8!``H```"6I@$`!P```*&F`0`*````J:8!``\```"TI@$`#@```,2F`0`&
M````TZ8!``<```#:I@$`"@```.*F`0`%````[:8!``4```#SI@$`@P```/FF
M`0`,````?:<!``\```"*IP$`&````)JG`0`)````LZ<!``H```"]IP$`'@``
M`,BG`0`L````YZ<!``\````4J`$`"@```"2H`0`0````+Z@!``H```!`J`$`
M"0```$NH`0`:````5:@!`"D```!PJ`$`)P```)JH`0`F````PJ@!`!X```#I
MJ`$`%@````BI`0`(````'ZD!``D````HJ0$`"@```#*I`0`'````/:D!``P`
M``!%J0$`#0```%*I`0`&````8*D!`%(```!GJ0$`#P```+JI`0`.````RJD!
M``D```#9J0$`(````..I`0!9````!*H!`!H```!>J@$`!@```'FJ`0`>````
M@*H!`"T```"?J@$`"````,VJ`0`'````UJH!`!\```#>J@$`"````/ZJ`0`+
M````!ZL!`"<````3JP$`)@```#NK`0`E````8JL!``D```"(JP$`"@```)*K
M`0`B````G:L!`%P```#`JP$`%````!VL`0`F````,JP!`!0```!9K`$``@``
M`&ZL`0`1````<:P!``L```"#K`$`%@```(^L`0`.````IJP!``<```"UK`$`
M$@```+VL`0`&````T*P!``@```#7K`$`$0```."L`0`-````\JP!``H`````
MK0$`#`````NM`0`S````&*T!``<```!,K0$`$0```%2M`0`2````9JT!`"``
M``!YK0$`%P```)JM`0`/````LJT!`!$```#"K0$`#P```-2M`0`/````Y*T!
M``\```#TK0$`#P````2N`0`(````%*X!`!P````=K@$`'@```#JN`0`+````
M6:X!`!(```!EK@$`'0```'BN`0`,````EJX!`!<```"CK@$`#P```+NN`0`-
M````RZX!``0```#9K@$`!P```-ZN`0`%````YJX!``4```#LK@$`"@```/*N
M`0`5````_:X!`!$````3KP$`&@```"6O`0`6````0*\!`!0```!7KP$`%P``
M`&RO`0`>````A*\!`!T```"CKP$`&@```,&O`0`&````W*\!``H```#CKP$`
M#@```.ZO`0`-````_:\!``<````+L`$`(P```!.P`0`-````-[`!``T```!%
ML`$`&@```%.P`0`F````;K`!`!0```"5L`$`!P```*JP`0`0````LK`!``@`
M``##L`$`%````,RP`0`3````X;`!``D```#UL`$`"0```/^P`0`%````";$!
M``<````/L0$``@```!>Q`0`$````&K$!``(````?L0$`1````"*Q`0!#````
M9[$!``T```"KL0$`(@```+FQ`0`V````W+$!``P````3L@$`*0```""R`0`=
M````2K(!`"(```!HL@$`(@```(NR`0`G````KK(!`!````#6L@$`%````.>R
M`0`>````_+(!`!4````;LP$`&````#&S`0`7````2K,!`!,```!BLP$`%P``
M`':S`0`<````CK,!`!H```"KLP$`+P```,:S`0`O````]K,!`#,````FM`$`
M,````%JT`0`Q````B[0!`"X```"]M`$`:P```.RT`0`E````6+4!`!D```!^
MM0$`"P```)BU`0`;````I+4!``H```#`M0$`%0```,NU`0`J````X;4!`"P`
M```,M@$`*````#FV`0`)````8K8!`%L```!LM@$`30```,BV`0`)````%K<!
M`"`````@MP$`)@```$&W`0`.````:+<!`!@```!WMP$`&P```)"W`0`%````
MK+<!``H```"RMP$`"````+VW`0`0````QK<!`!(```#7MP$`"P```.JW`0`*
M````]K<!``T````!N`$`)0````^X`0`)````-;@!``D````_N`$`$@```$FX
M`0`5````7+@!`!````!RN`$`.0```(.X`0`"````O;@!``<```#`N`$`#@``
M`,BX`0`'````U[@!``<```#?N`$`$P```.>X`0`(````^[@!`#@````$N0$`
M#@```#VY`0`9````3+D!``0```!FN0$`,````&NY`0`<````G+D!`"P```"Y
MN0$`50```.:Y`0`6````/+H!`$<```!3N@$`(P```)NZ`0`1````O[H!``D`
M``#1N@$`$````-NZ`0`1````[+H!``P```#^N@$`$P````N[`0`,````'[L!
M`!L````LNP$`&P```$B[`0`#````9+L!``L```!HNP$`$@```'2[`0`H````
MA[L!`!P```"PNP$`'@```,V[`0`3````[+L!`!(`````O`$`)P```!.\`0`)
M````.[P!`!$```!%O`$`$@```%>\`0`'````:KP!``H```!RO`$`!P```'V\
M`0`.````A;P!``<```"4O`$`$````)R\`0`<````K;P!`!(```#*O`$`!0``
M`-V\`0`(````X[P!``4```#LO`$`'````/*\`0`&````#[T!`!$````6O0$`
M"````"B]`0`1````,;T!``@```!#O0$`&@```$R]`0`.````9[T!`"L```!V
MO0$`%P```**]`0`)````NKT!``H```#$O0$`'0```,^]`0`%````[;T!`!,`
M``#SO0$`!0````>^`0`H````#;X!``<````VO@$`"0```#Z^`0`<````2+X!
M`#P```!EO@$`!@```**^`0`;````J;X!`!````#%O@$`"````-:^`0`3````
MW[X!``L```#SO@$`!````/^^`0`(````!+\!``L````-OP$`!P```!F_`0`)
M````(;\!``@````KOP$`!P```#2_`0`'````/+\!`!4```!$OP$`+0```%J_
M`0`[````B+\!`!<```#$OP$`(````-R_`0`5````_;\!`#X````3P`$`'```
M`%+``0`=````;\`!`"4```"-P`$`6````+/``0`@````#,$!``4````MP0$`
M"@```#/!`0`'````/L$!``D```!&P0$`$@```%#!`0`5````8\$!`#@```!Y
MP0$`(P```++!`0`?````UL$!`#4```#VP0$`.@```"S"`0`*````9\(!`!H`
M``!RP@$`#````(W"`0`*````FL(!`"$```"EP@$`$P```,?"`0`2````V\(!
M``X```#NP@$`!P```/W"`0`/````!<,!``D````5PP$`$````!_#`0`.````
M,,,!`!H````_PP$`%P```%K#`0`P````<L,!``L```"CPP$`'P```*_#`0`%
M````S\,!``8```#5PP$`!P```-S#`0`>````Y,,!``P````#Q`$`!````!#$
M`0`0````%<0!``\````FQ`$`"0```#;$`0`,````0,0!``X```!-Q`$`%@``
M`%S$`0`%````<\0!``0```!YQ`$`$@```'[$`0`Q````D<0!`$0```##Q`$`
M%P````C%`0`'````(,4!`",````HQ0$`&````$S%`0`4````9<4!``X```!Z
MQ0$`#P```(G%`0`-````F<4!``T```"GQ0$`+P```+7%`0`&````Y<4!``L`
M``#LQ0$`#0```/C%`0`/````!L8!``L````6Q@$`/````"+&`0`&````7\8!
M`!X```!FQ@$`#P```(7&`0`3````E<8!`"<```"IQ@$`'P```-'&`0`[````
M\<8!`#P````MQP$`.````&K'`0`1````H\<!``@```"UQP$`$0```+['`0`3
M````T,<!`!@```#DQP$`"````/W'`0`0````!L@!`!8````7R`$`!P```"[(
M`0`1````-L@!`!P```!(R`$`"P```&7(`0`%````<<@!``P```!WR`$`"P``
M`(3(`0`0````D,@!``4```"AR`$`!P```*?(`0`*````K\@!`!,```"ZR`$`
M$P```,[(`0`,````XL@!``P```#OR`$`!@```/S(`0`)`````\D!`#8````-
MR0$`*````$3)`0`C````;<D!``<```"1R0$`(````)G)`0`&````NLD!`"0`
M``#!R0$`%0```.;)`0`H````_,D!`!$````ER@$`$0```#?*`0`<````2<H!
M``,```!FR@$`"````&K*`0`2````<\H!``(```"&R@$`#````(G*`0`4````
MELH!``L```"KR@$`&````+?*`0`<````T,H!`!@```#MR@$`!0````;+`0`*
M````#,L!`!0````7RP$`'````"S+`0`-````2<L!``<```!7RP$`#````%_+
M`0`*````;,L!`!$```!WRP$`2@```(G+`0`<````U,L!`#<```#QRP$`&```
M`"G,`0`%````0LP!``0```!(S`$`"@```$W,`0`1````6,P!`!(```!JS`$`
M%P```'W,`0`5````E<P!`!````"KS`$`&@```+S,`0`.````U\P!`"0```#F
MS`$`#P````O-`0`0````&\T!`&L````LS0$`(````)C-`0`>````N<T!`!P`
M``#8S0$`(````/7-`0`8````%LX!`"0````OS@$`$@```%3.`0`9````9\X!
M`!0```"!S@$`"@```);.`0`'````H<X!``L```"IS@$`!P```+7.`0`4````
MO<X!``L```#2S@$`.@```-[.`0`3````&<\!`!H````MSP$`"````$C/`0`%
M````4<\!`$H```!7SP$`3P```*+/`0!-````\L\!`&0```!`T`$`!P```*70
M`0`H````K=`!`"P```#6T`$`"@````/1`0`(````#M$!``T````7T0$`,@``
M`"71`0`%````6-$!`%(```!>T0$`+````+'1`0`D````WM$!``X````#T@$`
M(````!+2`0`<````,](!`",```!0T@$`'0```'32`0`C````DM(!`!H```"V
MT@$`#````-'2`0`'````WM(!`!````#FT@$`$0```/?2`0`4````"=,!``@`
M```>TP$`0````"?3`0`,````:-,!``@```!UTP$`#0```'[3`0`:````C-,!
M``D```"GTP$`!````+'3`0`6````MM,!``@```#-TP$`"````-;3`0`$````
MW],!``L```#DTP$`"P```/#3`0`4````_-,!`!,````1U`$`#@```"74`0`4
M````--0!``X```!)U`$`!P```%C4`0`0````8-0!`!P```!QU`$`"P```([4
M`0`-````FM0!`!L```"HU`$`*@```,34`0`8````[]0!`!X````(U0$`*@``
M`"?5`0`$````4M4!``0```!7U0$`#0```%S5`0`'````:M4!``H```!RU0$`
M%@```'W5`0`(````E-4!``H```"=U0$`"````*C5`0`'````L=4!``D```"Y
MU0$`"0```,/5`0`)````S=4!``P```#7U0$`#@```.35`0`$````\]4!``X`
M``#XU0$`"@````?6`0`*````$M8!``\````=U@$`'````"W6`0`+````2M8!
M``(```!6U@$`'P```%G6`0`'````>=8!``8```"!U@$`:````(C6`0`,````
M\=8!``@```#^U@$`*`````?7`0!$````,-<!`!\```!UUP$`+0```)77`0!8
M````P]<!`"8````<V`$`*0```$/8`0`8````;=@!`!T```"&V`$`!0```*38
M`0`*````JM@!``T```"UV`$`#0```,/8`0`+````T=@!``T```#=V`$`%0``
M`.O8`0`/`````=D!``T````1V0$`#P```!_9`0`/````+]D!``0````_V0$`
M!P```$39`0`(````3-D!`!D```!5V0$`"````&_9`0`&````>-D!``<```!_
MV0$`$P```(?9`0`&````F]D!`!L```"BV0$`%@```+[9`0`+````U=D!`!D`
M``#AV0$`#````/O9`0`6````"-H!``P````?V@$`"````"S:`0`/````-=H!
M`!(```!%V@$`#P```%C:`0`&````:-H!`!<```!OV@$`"P```(?:`0`>````
MD]H!``8```"RV@$`"````+G:`0`-````PMH!`"````#0V@$`"0```/':`0`+
M````^]H!`"8````'VP$`&````"[;`0`0````1]L!``8```!8VP$`"P```%_;
M`0`.````:]L!``D```!ZVP$``@```(3;`0`.````A]L!``<```"6VP$`)@``
M`)[;`0`I````Q=L!`"L```#OVP$`'````!O<`0`L````.-P!`"D```!EW`$`
M6@```(_<`0`-````ZMP!`$T```#XW`$`-````$;=`0!3````>]T!`$P```#/
MW0$`(0```!S>`0`S````/MX!`"8```!RW@$`,@```)G>`0`K````S-X!`!,`
M``#XW@$`/0````S?`0"8`@``2M\!`!H```#CX0$`$````/[A`0`_````#^(!
M`(4```!/X@$`+@```-7B`0`E````!.,!`$0````JXP$`3P```&_C`0!*````
MO^,!`"P````*Y`$`&0```#?D`0`0````4>0!`"4```!BY`$`&P```(CD`0`<
M````I.0!`"@```#!Y`$`)P```.KD`0`J````$N4!`#`````]Y0$`&0```&[E
M`0`-````B.4!`"L```"6Y0$`)````,+E`0`H````Y^4!`"$````0Y@$`'```
M`#+F`0`Z````3^8!`&4```"*Y@$`-0```/#F`0!+````)N<!`#4```!RYP$`
M*````*CG`0`V````T><!`%P````(Z`$`.@```&7H`0`O````H.@!`"@```#0
MZ`$`+````/GH`0!7````)ND!`%8```!^Z0$`1P```-7I`0!%````'>H!`"\`
M``!CZ@$`*0```)/J`0`I````O>H!`"D```#GZ@$`:````!'K`0!B````>NL!
M`&L```#=ZP$`NP```$GL`0`:````!>T!`"X````@[0$`-P```$_M`0`H````
MA^T!`&0```"P[0$`&````!7N`0!8````+NX!`!P```"'[@$`"P```*3N`0#,
M````L.X!`$\```!][P$`(@```,WO`0`\````\.\!`"`````M\`$`&````$[P
M`0`S````9_`!``8```";\`$`!P```*+P`0`$````JO`!``P```"O\`$`$```
M`+SP`0`,````S?`!``L```#:\`$`!P```.;P`0`2````[O`!``T````!\0$`
M@@````_Q`0`&````DO$!`!4```"9\0$`!````*_Q`0`'````M/$!``@```"\
M\0$`!0```,7Q`0!2````R_$!``0````>\@$`&0```"/R`0`*````/?(!`!(`
M``!(\@$`$````%OR`0`"````;/(!``<```!O\@$`!@```'?R`0`3````?O(!
M``P```"2\@$`%@```)_R`0`&````MO(!`!0```"]\@$`#P```-+R`0`#````
MXO(!`"X```#F\@$`!````!7S`0`&````&O,!``<````A\P$`'@```"GS`0`\
M````2/,!`"X```"%\P$`+P```+3S`0`6````Y/,!`"@```#[\P$`,````"3T
M`0`B````5?0!`"H```!X]`$`(````*/T`0`C````Q/0!`!X```#H]`$`'```
M``?U`0`L````)/4!`"0```!1]0$`&@```';U`0`N````D?4!`!H```#`]0$`
M+````-OU`0`P````"/8!`"`````Y]@$`)````%KV`0`D````?_8!`!\```"D
M]@$`(P```,3V`0`L````Z/8!`"<````5]P$`)P```#WW`0`E````9?<!`!\`
M``"+]P$`)````*OW`0`P````T/<!`!T````!^`$`*@```!_X`0`V````2O@!
M`#D```"!^`$`&@```+OX`0`G````UO@!`$T```#^^`$`*0```$SY`0`M````
M=OD!`"T```"D^0$`+@```-+Y`0`H`````?H!`"8````J^@$`(0```%'Z`0`G
M````<_H!`#@```";^@$`*@```-3Z`0`U````__H!``P````U^P$`#@```$+[
M`0`@````4?L!`"H```!R^P$`(0```)W[`0`/````O_L!``\```#/^P$`&@``
M`-_[`0`:````^OL!``L````5_`$`)P```"'\`0`,````2?P!``H```!6_`$`
M)0```&'\`0`H````A_P!`"(```"P_`$`)P```-/\`0`B````^_P!``<````>
M_0$`W````";]`0`+`````_X!`!,````/_@$`!P```"/^`0`*````*_X!`!``
M```V_@$`$@```$?^`0`<````6OX!``,```!W_@$`,P```'O^`0`;````K_X!
M`!@```#+_@$`!P```.3^`0`2````[/X!`!(```#__@$`,P```!+_`0`(````
M1O\!`"D```!/_P$`$P```'G_`0`3````C?\!`!D```"A_P$`,P```+O_`0`=
M````[_\!``X````-``(`(P```!P``@`/````0``"`!````!0``(`%P```&$`
M`@`*````>0`"`!\```"$``(`#P```*0``@`=````M``"``\```#2``(`'@``
M`.(``@`F`````0$"``4````H`0(`$````"X!`@`'````/P$"``L```!'`0(`
M"0```%,!`@`X````70$"``8```"6`0(`#P```)T!`@`1````K0$"`!````"_
M`0(`"P```-`!`@`/````W`$"``<```#L`0(`$````/0!`@`(````!0("`!L`
M```.`@(`"````"H"`@`;````,P("`!L```!/`@(`"P```&L"`@`-````=P("
M`!P```"%`@(`"````*("`@`Q````JP("`!$```#=`@(`$````.\"`@`(````
M``,"``(````)`P(`"@````P#`@`8````%P,"``L````P`P(``P```#P#`@`+
M````0`,"``L```!,`P(`"@```%@#`@`7````8P,"``X```![`P(`&````(H#
M`@`>````HP,"``P```#"`P(`.0```,\#`@`B````"00"`",````L!`(`&0``
M`%`$`@`-````:@0"`$4```!X!`(`!@```+X$`@`:````Q00"`%8```#@!`(`
M#P```#<%`@`0````1P4"``<```!8!0(`!````&`%`@`%````904"`!$```!K
M!0(`%@```'T%`@`&````E`4"``<```";!0(`!P```*,%`@`+````JP4"``,`
M``"W!0(`#````+L%`@`-````R`4"`#D```#6!0(`+@```!`&`@`L````/P8"
M``4```!L!@(`%@```'(&`@`E````B08"`"(```"O!@(`'P```-(&`@`3````
M\@8"``(````&!P(`!`````D'`@`-````#@<"``H````<!P(`!0```"<'`@`%
M````+0<"``\````S!P(`30```$,'`@`D````D0<"`!<```"V!P(`(@```,X'
M`@`P````\0<"`$X````B"`(`%@```'$(`@!^````B`@"`!X````'"0(`60``
M`"8)`@`J````@`D"`$\```"K"0(`,````/L)`@`H````+`H"`"T```!5"@(`
M+0```(,*`@`K````L0H"`"X```#="@(`*0````P+`@`H````-@L"`"P```!?
M"P(`-P```(P+`@`4````Q`L"`!H```#9"P(`#````/0+`@"H`````0P"``8`
M``"J#`(`N0```+$,`@"%````:PT"`*````#Q#0(`(````)(.`@!7````LPX"
M`!`````+#P(`'0```!P/`@`1````.@\"``<```!,#P(`&0```%0/`@`>````
M;@\"`$$```"-#P(`&0```,\/`@`6````Z0\"`%<`````$`(`&@```%@0`@`/
M````<Q`"``H```"#$`(`!0```(X0`@`&````E!`"``@```";$`(`!0```*00
M`@`9````JA`"``D```#$$`(`&````,X0`@`B````YQ`"``\````*$0(`"0``
M`!H1`@`.````)!$"``D````S$0(`#````#T1`@`'````2A$"``4```!2$0(`
M$````%@1`@`0````:1$"``X```!Z$0(`$````(D1`@`*````FA$"``D```"E
M$0(`$````*\1`@`(````P!$"`!,```#)$0(`"@```-T1`@`+````Z!$"`!@`
M``#T$0(`"0````T2`@`&````%Q("`!L````>$@(`&````#H2`@`.````4Q("
M`!0```!B$@(`"P```'<2`@`F````@Q("`!0```"J$@(`!P```+\2`@`5````
MQQ("``<```#=$@(`"````.42`@`B````[A("``L````1$P(``@```!T3`@`"
M````(!,"`!H````C$P(`#````#X3`@`&````2Q,"``@```!2$P(`&@```%L3
M`@`&````=A,"`"4```!]$P(``@```*,3`@`$````IA,"`!$```"K$P(`%P``
M`+T3`@`+````U1,"``D```#A$P(`$````.L3`@`*````_!,"`!8````'%`(`
M!P```!X4`@`<````)A0"``H```!#%`(`%P```$X4`@`"````9A0"``4```!I
M%`(`$````&\4`@`,````@!0"`!(```"-%`(`*0```*`4`@`'````RA0"``<`
M``#2%`(`$0```-H4`@`%````[!0"``(```#R%`(`"P```/44`@`!````TP0`
M`!P$```Q!0``7P,```````"<`0``;0(``*`$````````E`,``,<!``#\!@``
M?```````````````A@(``"H'```+`0```````(('``#!````=P4``!4$``#Q
M!0``+````-L#``#"!@``)`<```@"```!!```O`4```,'```Q`P```````*8"
M``#P!0``9`(``+("```/!```@0,```````````````````````#6!```404`
M`(4$`````````````/8!``!P`@````````````!_`@``+@0````````C`0``
MI`4```````!C!P``Y`4``)`&```E`0``<08``/4$``!N`@``<`$``#0'``#"
M`0``T0(``"\$``!O`P``3P<``%H```"B`0``,P$``(H'````````>P$``.L`
M``"7!@``P`4``%T'``!*!0``S08```````"4!```8@(``/(````I`@``9@(`
M``````#;!```A08``-X%`````````````*4```````````````````"8`P``
M`````$````#E!@```````,T!````````G00``$@"``"_!0```````/T"``")
M!P````````P%````````3P0``,P%``#L`@``)@4``!<`````````-````%@`
M``"\`0````````````"U`@``6@0``&4#``!J`P``7P$``(,'````````````
M``````#Z`0``9`,``&\```#6`0```````'X&````````"0<``)``````````
M30,``)L"````````'`,``%X&``#T`0``WP```"@#``#<`0``T`$``+8#``!'
M`P```````!P'```2!P``)0,``/$```"P!0``T@0`````````````JP,``*0`
M````````RP4``&$#``!Y`P``E00```H$````````BP8``,`!````````X00`
M`'D'``#9`P``YP$```````#_!0``2P<``*D!``!8!```Y`$```````!/````
MO@$``````````````````"\#``!M!P```````+(`````````F`4``&<$``"E
M!@``X@$``$<&````````*@```/L!``!H`0``50<``-H#```I!@``HP0``%4&
M``!6!```L`8```````"=`@``6P```),&``"+`P``J0````````"L!0``TP``
M`*`#``!Z`0``9P(``,(#```I!P``>P,``"L`````````-@``````````````
M,0(``(,```#D!````````/8$``!Y!```10<```````#W``````````````"3
M`@``N@4````````7!0``J@,``"L"``![!P```````'0$```[`@``````````
M``"0`@``C@$``(H$``#<````?0<``%<%``":`P```P(``#P'``!>`P``!@$`
M``````!%!````````"X'``"?`P``I0$`````````````9P4``'$!````````
M`````$,&``#;````/@<``$H``````````@(````````I`0```````%8#````
M````G`0```````#,`0``800``!8#````````)P0``&$``````````````"4$
M``!W````[@,``&<&````````G08````&``![`````````!D&``"Q!````P``
M``0'``#=!0``N`8``,D#``!\`@``%P<``.P``````````````&,!````````
M[@(``)H```"2````G@,```````";`0``*P4``'$"``#S`P``1@,``+X"``"Z
M`0``W00``-<&``"T`P``XP0``,H$``"J!````````!D'```7`@``OP0``!@!
M``"Q`@````````````#B`P``CP(```````!^`0``_@4``&D!```7!@``^`$`
M`"H#``!+`P``<@,``$<$``"6`0``1P```,@!``!Q`P``3P8``#H```!A!@``
M4P```-8&``!V`@```````"X%```F`@``=`8``.T````+!@``!````.0"``!^
M`P``@P4``(D!``"3!```_@(``&4'``#G!0``%P$```````"?`0``#@<``'L"
M``!^````!00```H'```N!@``-08```````!2`@``OP````````!W`P``_P,`
M```````+````,P4`````````````9P<``"@&``#=`````````/0"``!`!P``
M`````-@#``#:!`````````````!H````#0(``',&````````U`8``,8&``!Q
M````H````/T&``!"`@```````)L$``"Y`P``P`````0$```/!@``3`$``)0"
M``"Y!0``H`$``,$!````````!0````````!-!P``U@(``&,`````````Q```
M`````````````````/($````````0`4``'`'````````S@8````````7`P``
M@@8`````````````4@4`````````````\P0``'<$``"D!@``;P0```@```!>
M````20<``+H#``!V!0``W@```(0#```D!```.P4``/@&``"<`P``=P(`````
M``!J`0``/@(``+\&``#N!0``O@0```````!P!@```````(D```"E`@``````
M`#0&````````'0<```````!5`0``(@0``#@!````````;00```````"'`@``
M>04``(`%``#6`````````"$"``!0!@``-P0``#,"`````````````)<#``#_
M!````0<```<#``!J!@```````/$!``#&````\`,``(\```!<!P``````````
M``#H!@``A0,`````````````W0(``"X#``!7`0``]08```````#E`0``_@``
M`$T```#-!```$`4````````V`0``D`,``'T!``"7````600``'\$``!S````
MIP4``%@"``""`@```````$(&``!V`0``_@$```````#G!````````"0`````
M````^`0``&L$``#&!```60$``"$$```&````GP(``%X"``````````````0&
M``"4!0```````.(&``".`P``/@```"L!```4`@``UP,``)(&``!!!P``````
M`&P#````````C@0``*,`````````Q0,``%$```"]`@``+`0``"`$``#I!```
M`````"T&``#V`@``+P8``%@%``````````````````"I`@``)`,`````````
M````LP$```````!]````)P,```````!S!P```````)$$````````S@$``/$&
M```(`0````````````````````$``$P%```Y!@```````,D%```1`0``7P0`
M`/H#``"<````L`,``,0!````````=00``'$$``#7`@``R@4``'P!``",`0``
M````````````````_04``#4$````````/P<``*8&``#0`P``J08``.T!``"F
M`````````.\"``````````````````"M!```ZP$``/D$``#?`P``*`0`````
M``!F!```GP```!`&``"Y!```Z@,```````#)!```6P(``(P$````````Q`(`
M`+X%``!"!0``=0<``-8%``"4!@```````&0'`````````````!L$````````
M]`,``%0```#9`````````$@```"6`````````%8"```W````(`8``#P"``!S
M`@```````/,"````````"`0``+<"``"E!```>`<```````#;!@``%0``````
M``#9!````````/P`````````'P4``(L%``#W`0``]P4``'P#``#9!@``M`4`
M`)4%```#!0```````````````````````(,$``"_`@``S@(```T'``"9`P``
M_P(```````#T!```/P(``%,!````````Q00``#(!````````RP(``(P`````
M`````````$L!`````````````+L&```)`0``W@$``"8$``"D`P``S04``',!
M```S!```$08``(L$``!B`````````"\```"A!@``.`(``%D"``"`!P``2`<`
M`(T%```9`````````*T```#O`P``T@8``'P%```R````O04``,H"````````
M]P8``+<&``!;!0``1`$`````````````'0(``!\'``#<!@````````X%````
M````8`$``#D"``!#`@``NP$``(`#````````*@$``$8```#0`@``%`8`````
M``!_````0@,``#8'```M`0``,00``.$!````````T@4``+0"``#H`0``5`,`
M`/@#``!]!````````*(#``#4`@``8@,``.L%`````````````%\````?`@``
M,@,``/P"````````<P0```````"!!@``-P4``#H%```8!````````'8```"C
M`P```````)<%``!B!0``$@(``&P!```B`0```````(X`````````:@4`````
M``#%!0``&@$``.`!````````DP,``)@`````````A04``!@`````````+`4`
M`(8$````````'````)H&``!I!@``^P(``(4!````````3`,``&D'``!Z!```
M$`0``&4```!4!0``Q08``'0"``#@``````````````"W`P``=0,`````````
M````````````````````7`$````````Y!P``?@(``&P``````````````(@"
M````````SP8```L"```/!0``;0$``"T"``#@!0``YP(``$\#```-`0``8```
M`&<`````````P`8``-D"``"Z!@``````````````````Z@```+($```H````
M`````#`'````````\P```*H%``#]`0``U00``!H```````````````````!B
M!````````,D&``!@!@``3@`````````3`@````````````!*!```%@8``",`
M```_````@@4``*@$``"X`@``D04``.0```!"!````````+@%``!!!0``'P$`
M`+@!````````FP4```````"U`````@<``"P'`````````````+`$````````
M:@<``'L%``!F````````````````````S@0```<!``!8!@````````````#@
M!@``80<``#L!```[!```=0(``.P&```Y!```(`<``/X&``!R!@``#`$`````
M``!(!@``G@8``+P$``!F!@``"04``$8'``````````````````!S`P``BP``
M`'H'``#2`P```0(``*,!```L`P```````+,$````````)0<```$#``#K`@``
M<````&X&``#8````$@8``$4#``!>!P``\P4``.D&``#1!```/P,```````#[
M!0``9@<``*`&``#2`@```````&L!``#1````B@8``#````#(`@``H00``.P!
M``#B````:@(``*8!``!<`@```````#@#````````7`8``"L$``!@`P``X04`
M``````#/````E@4``-@&``!%`@````````````"5`0`````````````'!@``
M1@4``/\&````````20,``&P%``!4!P``TP$``(`!````````````````````
M`````````/T$``!L!```!@0``#X#```?!```WP0```````!<`P``?@0``!$"
M```L!@``RP0``!L#````````?P8``'4````%`P``D0$```````"L````````
M``0"``!Y`0``*00``#4'````````>@```'0``````````````&(!``!4`0``
M#0```#\!``#>`P``M08``#@'`````````````"8```````````````````"(
M!0``CP0```````!&!````08```````"S````4`$``)$&``"R`0``%@(``%`"
M``"'`P``;P<``/4"``"V````\P8``/$#``!1`0``X@0``.\$````````T`8`
M```````O`@````````P'``!0`````````%0"````````3`8``($"````````
M'`8```````#T!@``C`8``+L```!=!@```````/D!``"$````1@8```````!U
M`0````````````!$`@``2`$``!4#````````)`$``%D#``#U````F@4``%,%
M``#=!@``.0$``!H'````````B`$``%P%``!7!```0@<``)H"```]`P``$0,`
M`*X%``!)`0```````)\$````````/@$``&H```!^!0``IP,``*@&```@````
M`````*X```!+````$@```*8$```!`0``>08```````#5`0``N@```.0#``"V
M`0````````````!H!`````````````"^````N0```'($````````$0```%\%
M``#F!```(`,``*L!``#F````(@(``)\&``"]`0``\@$``#H&``"#!@``````
M`($````2!```NP(``#T$``!_`0``&P```+,"````````O0,``'4%``!E`@``
MA0````````#-`@``Q`8``'\%````````5P(``)\%``#P`0``K0,```````"*
M!0``<@$``+$```"!!````````/`&````````$0<``&\"````````[0,`````
M```0`@``%`$``"T#``!$!````````-4#``#?`@```````'P&``!)!0``````
M`-L%``"'!````````+(&``#W`@``KP0```4"````````(0```/P%``!W`0``
M/`,```H&``#T!0``\`(``'$%``"X`P```````-0#``#H`@``608```````![
M!```00,````````J`@``G`4``,8%``#:!0``804```````````````<``'H%
M``!'`@``/````+P```````````````\#`````````````!`'```W!@``%`0`
M````````````80(```@'```S`P```````$`!```]!0```````)L&````````
M`````(<!``#)````Z0,``.0&``"]````BP$``+T$````````-@,``#4"```=
M!0```````(<&``"N!```!P(``.L$``"_`P``````````````````200``%$&
M``"U!```<P4``,0#````````:P,``-H!``"P`0```````),%````````R@8`
M`*(%````````"0,``'T#```3````#00``,4!```+!````````$$"``!5````
MXP4```````"L`P```P,``!D$```&!@````````````#J!```[`4```H#``"H
M!0``MP0``!8```!4!```-P$``%4%``"D`@``^0(```````"``@``(P4``/L#
M``!#`0``:@0`````````````/P4``!,!````````\@,``,<$``"^!@``````
M`$@#````````S0,``%T%``!\!```/08``/D````>!0``1@$```````"K````
M5@$``.@$``"-`````````,X#```X!@````````````#+````AP```-T#````
M`````````,P$````````4@<````````9!0```````.<#```Q````S`,``(D%
M```0`0``#@```&L'``"G````SP0``&('```8!@``V@```"$!``"B`@``F`(`
M`%X$```M!```(P<``&4!``!X`@``%`<``!T$``#9!0``G`(``%T`````````
MX`0``&8%```_!@``Y@(```````"R!0````````0#```>!```````````````
M````!`4```````"3`0``A@8``'0#``"O`P``^@8```````"2!```A0(``!X&
M````````W`,```````!;`0``6P<``!0#``#Q`@``,P<``'0%``"H`P``70$`
M`"L&``````````````````"O!@``X`,``$X#``#\!```.@<``'@$````````
M+P4``&@&``#4````H`(``/D#````````*`4``(8'``#M!0``<@(````````I
M``````````8"````````"P<``.4$````````4@8`````````````)P<```(&
M````````1@(``````````````````-<!``#-````-P,```0!````````*P<`
M`'('``!C!@```````($%``!N`0``KP(``,0$```N`@``500`````````````
M`````(0%```3!```D0(``%<&``#2````K@,``$D&```W!P``?`<```````#0
M!```&P4```````"Z!`````````````""`0`````````````C`@``6@$`````
M```;!P``,@<``"`"``"H`@``)@<````````Z!```B0(``&L```#R!@``.04`
M`#P!```1!0```````.4%``"*````'`$``*L$``")`P``!@4````````B!0``
M70(```````#J`0```````/H$````````WP$``$<%````````$P8``(@```#I
M`@``-`0``.4#``"K!0``S@4``,<#````````/P0``````````````````.H"
M``"A`P``_@,``!@%```S````]@4``'<'````````;P8```````#+`P``;P$`
M`!X#``!9!0```````(8```"#`0```````+0```"/`P``A`0``#`$``"W`0``
MF0(``*`%``"V`@``Y0(````````R!```H0```"P"``#(`P``"P,```````",
M!0```````!L&``"L!```````````````````:P4```````#8`0````````X$
M```(!@```````"4```#A`P``G@``````````````<@4``!\&````````%0$`
M`#X%```=````S`(``)X%``")!@``C@(``"$%``"6`@```````$`&``!!!@``
MH0$``*$%```G`@`````````````M````2@<``)4"``!2!``````````````T
M`@``^`4``'0!``!=`P``-0$```````!.!```5@4``*($```)````PP4``(,#
M````````6`$``&D"``#L`P``&0(```````#"`@``6@<``$,#```\!```D`$`
M`.8!``#C`P``400`````````````K`(```X"```<`@``3@$``$@$```*````
M`````$T&``#\`0``+@```(T!````````+0<``.T"``#I`0``SP$``&P"````
M`````````-H"``##`@``)P```+,#``"2!0```````&X````0`````````(T$
M```;`0``<`0``'8'`````P``WP4``%,'``"R`P``!P<``(T#````````C0(`
M`&<!``""`P``OP$``'<&``!N!```J@```$X"``!D!0```````(P#```O!P``
M@@0```````"\`P``/@0``!@"````````-P(``)(#``""``````0`````````
M``````````\"```5`@``P@```+L#````````T08``#`%``#N````P04`````
M``!(!0``$P<``%D'```"!```7@$`````````````V0$``$H&``#Q!```;08`
M`#@%```[!P``F@$``.$```"\`@``O@,``!8$`````````````)D%``#J!0``
M]0,```````!#!P``&0,``.P$``"5`P```@,```D&``".!@```````&P&``!@
M!P``+@$``"8&````````908``&D#````````7P8``+4#```*`@``20(``!\`
M```,!@``9`$`````````````3P(`````````````I@4``#$&``"Q`0``#08`
M`-(!```U!0``A@$``%P`````````.P8``.8#```:!0``NP0``*T"````````
M@````'H#``"(!@``R`4``(0&``#=`0``-0,``.\!``````````````P```"6
M`P``8P(``)X"``#R!0``````````````````9`0`````````````Z0```+8%
M``"B!@```````!X!``#!`P``/`8``'`%``"$`0``:P(```````!-!```YP8`
M``````#'!@``CP$```````##````'@<```````!C!```=`<````````-!0``
M/0$``%`'``!M`P``(@8``$0````6!P````````````#8`@``20```#L#```7
M!````````.\```!K!@````````H%``!3`P``!P4``"0%``"V!@``J00```<$
M``!'`0``1`8``````````````````"`%````````L````*\````P!@``[P8`
M`.,`````````(P8``!(#``#!!```V@8`````````````?P,```P$```8`P``
MK`$```````"Y`0``XP8``,X`````````D@$``'\'``#%`@```@4````````T
M`0```````*@````L`0``#@,```````"0!```&0$``*(```!0!0```````.H&
M``#5`@``````````````````"00``)D!``";`P``J@$```P"``#5!0``]04`
M`/4!```-`P```````)T!``#%`````````,8"``!7````.````"@"````````
M`````/T#``"G!```NP4```````#"!0```````$\!```=`0``[08``/D&``"6
M!```4`0```````"M`0````````````"D`0``J04``+`"``!D!@```````-8#
M```6!0``I@,````````:`@````4```````"'!P``@0<``-$%``#C`0``K08`
M`.,"``#!!@``JP(``'`#``"0!0``KP$```````#3!0``HP8```````"U!0``
M`````,\%``!M!0```````/@"````````W@8`````````````'P,``'X'``"T
M!```IP8```````#$!0``IP$``$,```"=`P``&P(```````!,!`````````(!
M``"7`@``3P4``$`#``!Z!@``W`(```````!'!P``8P4``(`&``!$`P``Y0``
M`$T%``##!@```````````````````````-````!;`P``MP```'D"``!#!0``
M`````%,&``#7!0``2@(``#T````M!0```````'L&``#@`@``8`0``!H#````
M``````````````##!````````-,#``#B`@``>`,``)0```"(!P``&@0`````
M``````````````````!!!```&@8`````````````40<````````I`P``_0``
M`%<#`````````````"('``!1`P``.@(``),```#S`0``50(`````````````
M#@8```````"9!````````$(!``!?`@``2P0``$P'``!N!0``L0,```````"$
M`@``3@8````````F`0```````-L!````````L04``'$'``#<!```:04``+0&
M```G!0``/0<``$0'``!*`P``:00``,\#````````:`(``*\%``"`!```=@,`
M`-$#``!0`P``F`$``.$"``!,`@``P@0```````"(!```;`<``'(`````````
M``````````#Z`@```````#(%``!H`P``!@<``",#``!]!@```````.@#``"7
M!```M0$``,L&``#/`@``*`$``)<!``#+`0```````%<'``!3`@``6@,``(8%
M````````,`(``/@```"9`````````,P```"N`@``-`4```````#7````````
M`*4%```````````````````E!@``F08``.X!```A`P``.P```)@&``!!`0``
MQ@,``(P"```%!P``%04``&4%```````````````````B`P``B@(``!X```"$
M!P``5@<``*T%``!%````=@8``#@$``##`0``U`$``$(```!E!```*`<``&\%
M``#V!@``5@````X!``#Z!0``30(``/X$``!:`@``HP4```4&``#I!0``(@``
M`$4%````````2P8``)@$``"<!@``P0(```,$`````````````+T&``!N`P``
M%08``.X&````````?04``.@````T`P``6@4``!(%```/`0``'@(```````!H
M!0```````"\!```]`@``30$``#`!```E`@``U0`````````E!0``9@,``/8`
M``!Z`@``CP8`````````````HP(```````"N`0``_`,``&$!``"X````D0``
M`````````````````)4````F`P``#P``````````````B@,```````!]`@``
MQP4``,8!````````A@,``"$'``">`0```````-L"``#)`0``"@$``%4#``!Y
M````U`0``,,#````````R@$``!,#``````````````````!N!P``\`0``'8$
M```(`P```````#X&``#8!````````*$"``!M````CP4``!@'````````6`<`
M`"H$```"````8`(``!P%````````^04``$X%````````R`````P#``"+`@``
M`````*4#```(!0```````#D#``#_`0``#P<``%T$```)`@```````$P```":
M!```T0$``"D%``#H!0```````'@`````````9@$``/````#O!0``2P(``+<%
M```%!0```````%(```#K`P``2P4``-4&```Y````R`0``)T%``#``@``7P<`
M``,!``!X!@``1`4``-\&``````````````<````V!0``*P,``/H```#(!@``
M%0<```,&``#*````>`$``!(!``#W`P``Y@4``*L&``!3!```4@$````````&
M`P``N0(``$X'```4````D0,``*H"``!<!```UP0``#H#```P`P``]````$`$
M````````W@(``+$&`````````````-P%``!B!@``P`,``,H#``#M!```6P0`
M`)0!``"(`P``:`<``(4'`````````````!,%``"-!@``I`0``#$'``"*`0``
M0P0``)L````A!@``\@(``'4&`````````````+8$````````$`,``.L&``!@
M!0```````/L$``"5!@``X@4``"H&`````````````/<$````````N@(`````
M``"T`0``108```````"N!@``5@8``#P%````````00```#8$````````,@(`
M```````!!0```````(X%```=`P``IP(`````````````4@,``"<&``#4!0``
M^P8```````"H`0``8P,``!$$`````````````%0&```G`0``LP4```````#F
M!@``TP(```````"'!0``@P(``+D&``!8`P``@0$```````#N!```)`(``-,&
M````````-0```+P&``#)`@``J0,``%D`````````,0$```````#A!@``LP8`
M``L%``!%`0``6P8``+@$```V!@```````%H&````````9````"0&``#'`@``
M`````)T```#_````!0$``$`"``")!```:0```-@%```@`0``G@0```````"2
M`@``%`4````````Z`0``T`4````````6`0```````'@%``#'````S`8`````
M````````7@4``",$``#V`P``*@4``.<```#`!```J@8``!T&``!*`0``,@8`
M```"``!G`P``W@0``#8"`````````````/L```"L!@``E@8``%$"````````
M,P8````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D
M87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B
M)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C
M:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A
M<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T
M960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X
M<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P
M<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I
M<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E
M<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E
M<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@
M8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO
M=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``
M+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S
M96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U
M<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S
M:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E
M+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3
M:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI
M<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N
M="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D
M($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!
M9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G
M<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!
M9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D
M('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T
M(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D
M;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`
M06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@
M57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED
M97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)
M35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)
M35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T
M92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM
M;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U
M9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I
M<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X
M:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG
M<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I
M`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A
M8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G
M=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A
M=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A
M:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA
M8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N
M9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D
M(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)
M4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"
M96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!"
M;&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C
M:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`
M0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(
M97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD
M`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I
M($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A
M<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?
M96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E
M9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E
M<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B
M+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@
M9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I
M97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H
M86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I
M<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO
M;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,
M:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I
M;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F
M:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R
M('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@
M0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO
M=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I
M80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#
M;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M
M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O
M;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`
M0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO
M;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@
M5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I
M;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O
M9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y
M(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A
M`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z
M(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S
M`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R
M>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U
M<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@
M;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`
M0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P
M96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@
M<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!
M0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R
M871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD
M;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S
M97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A
M=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R
M9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N
M="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N
M="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#
M=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+
M3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I
M;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B
M+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A
M<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$
M87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E
M8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)
M9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE
M=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES
M<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E
M;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B
M`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`
M1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`
M1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@
M<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T
M:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T
M('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES
M<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I
M`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI
M;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G
M<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R
M<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R
M`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%
M9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@
M;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P
M97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R
M`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA
M:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M
M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R
M9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U
M('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%
M;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L
M;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E
M871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C
M;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10
M('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@
M(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B
M+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&
M87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO
M=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%0
M5$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL
M90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE
M`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@
M<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1
M=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O
M<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U
M;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E
M+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA
M`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&
M=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R
M871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'
M97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I
M;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES
M8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N
M861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T
M96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U
M:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A
M9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(
M96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(
M;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(
M;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O
M<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE
M(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0
M(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`
M2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E
M="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y
M`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A
M:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R
M90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@
M=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE
M=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM
M86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L
M(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`
M26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S
M97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R
M="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?
M0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E
M<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M
M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`
M26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R
M90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T
M:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`
M26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@
M9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!)
M;G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D
M9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME
M>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP
M92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S
M:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN
M=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L
M:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@
M<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@
M=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA
M;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L
M>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0
M*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N
M=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+
M87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y
M($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E
M`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H
M155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T
M(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S
M`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA
M`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT
M(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R
M`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO
M=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI
M<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S
M8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E
M<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A
M;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S
M>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,
M;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E
M<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M
M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA
M9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`
M36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N
M`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`
M36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-
M875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@
M4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I
M8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E
M>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S
M(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE
M;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN
M9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@
M:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@
M;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T
M90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!2
M97!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N
M=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD
M(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S
M=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN
M9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H
M=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L
M92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N
M`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@
M3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD
M<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),
M`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),
M`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.
M979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@
M57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R
M;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI
M8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R
M96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N
M9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`
M3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU
M;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@
M4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E
M="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`
M3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.
M;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O
M;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D
M:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T
M960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E
M<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M
M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C
M="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E
M`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD
M('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z
M($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A
M<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG
M(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/
M<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES
M<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%
M05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N
M8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@
M4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U
M;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`
M4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@
M9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R
M=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE
M;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T
M;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@
M9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@
M2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`
M4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3
M;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R
M;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO
M=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO
M=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R
M9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U
M;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U
M;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S
M`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2
M;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R
M;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@
M0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3
M($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N
M80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE
M<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@
M5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R
M86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O
M;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@
M9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V
M97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N
M90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD
M(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E
M9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@
M<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S
M($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3
M:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA
M='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@
M36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E
M<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R
M<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@
M;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3
M;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R
M90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A
M8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R
M($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R
M=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E
M<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L
M;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3
M=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B
M)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E
M<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I
M<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I
M<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I
M;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD
M`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B
M;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R
M;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L
M92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R
M(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R
M871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B
M)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!4
M97AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I
M`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO
M;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`
M5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA
M:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4
M:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I
M;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB
M97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B92!C
M;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A
M+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S
M86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K
M;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R
M+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I
M<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M
M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S
M=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@
M:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD
M('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@
M8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE
M(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M
M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S
M;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM
M93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L
M;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE
M('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@
M<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B
M)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T
M:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O
M;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B
M)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E
M<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S
M`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M
M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O
M;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE
M(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME
M;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U
M<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?=&]P*0!4
M<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E
M`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM
M96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@
M>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A
M:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`
M56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S
M(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B
M.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`
M56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN
M92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE
M.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR
M96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T
M;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@
M0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A5
M5$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI
M=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`
M56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE
M9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@
M($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N
M;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@
M86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D
M($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T
M960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U
M9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T
M:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R
M(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR
M96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H
M92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E
M>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z
M(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I
M<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E
M<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R
M=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(
M:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W
M(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N
M9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6
M:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I
M82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&
M;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`
M5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X
M-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE
M<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I
M9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@
M=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A
M<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7
M:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU
M;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD
M("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I
M;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT
M96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA
M;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N
M<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S
M+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@
M87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY
M(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P
M;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L
M(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@
M8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@
M5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S
M="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U
M(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB
M97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@
M86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z
M`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@
M<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I
M9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@
M;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R
M(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB
M86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T
M70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?
M1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O
M<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?
M3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E
M<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E
M;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@
M870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE
M9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T
M=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE
M(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@
M:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D
M`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I
M8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA
M($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R
M87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER
M;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE
M<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$M8W9S"E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`V+3`R+3(W(#$Y.C4Q*S`R,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-BTP,BTR-"`Q,CHU.2LP,C`P"DQA<W0M5')A;G-L871O<CH@
M3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3X*3&%N9W5A9V4M5&5A;3H@1FEN
M;FES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP
M"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`@*"5S('#D:7;D
MY"!S:71T96XI`"`H4&EK86[D<'#D:6X@)7,I`"`H)7,@<.1I=N1S<^0I`"`H
M=.1NY.1N*0`@*&AU;VUE;FYA*0`@*&5I;&5N*0`@`"(E<R(@96D@;VQE(&AA
M:V5M:7-T;P`B)7,B(&5I(&ME;'!A82!V86QI;FYA:W-I+@`B)7,B(&5I(&]L
M92!A<V5N;F5T='4@2&]R9&5N(')E:VES=&5R:7-SY"X`(B5S(B!P=6ED96X@
M:W5V86%J86$@96D@;/9Y='EN>70N`"(E<R(@;&ESY'1T:6EN(')Y:&WD:N1R
M:F5S=&5L;>3D;BX`(B5S(B!L:7/D='1I:6X@;VEK975K<VEI;BX`(B5S(B!E
M:2!L=6]T=3H@)7,N`"4N,F9-0B!KY'ET971T>2`E+C)F34(@<V%L;&ET=7-T
M82`H)2XR9B4E*0`E9"`E<R!J82`E<P!386QA<V%N87-I('9A;FAE;G1U=2`E
M9"!PY&EVY&X@<.3D<W3D+@`E9"!PY&EVY&X@96YN=7-T=7,`)7,@+2!);&UO
M:71U<P`E<R!3;W)M96YJY&QK:0`E<R!+0@`E<R!9;&SD<&ET;W1O:6UE;G!I
M=&5E="`M(%9A<FUI<W1U<P`E<R!A<V5N;G5S`"5S(&MI<FIA=71U;6EN96X`
M)7,@:^1Y='3V96AD;W0`)7,@;VX@:F\@;VQE;6%S<V$N`"5S('-U=6YT82`E
M<R`E<P`E<R!O;B!V86QM:7,@<W5O<FET=&%M86%N('EL;.1P:71O=&]I;65N
M<&ET96ETY"X@5F%L:71S92!V86QI;G1A<G5U9'5I<W1A('-U;W)I=&5T=&%V
M870@=&]I;65N<&ET965T+@`E<R!O;B!P86MO;&QI;F5N`"5S(&UI;G5U='1I
M80`E<R!E:2!L]GET>6YY="X`)7,@+2`E<R`O("5S`"5S.FX@;W-O:71E:VER
M:F$`)7,Z;B!K86QE;G1E<FD`)7,Z;B!M=6ES=&EL:7-T80`E<SIN('1E:'3D
M=N1L:7-T80`E<SH@)7,`)7,@.B!4Y&WD('9I97-T:2!E:2!O;&4@=N1L='3D
M;>1T=.0@<VEL=.0@;.1H971TY&KD;'3D+"!J;VMA(&]N(&UE<FMI='1Y(&SD
M:&5T=.1JY&MS:2X@4W5H=&%U9'4@=F%R875K<V5L;&$@=FEE<W1I<W/D(&]L
M979I:6X@;&EN:VME:6AI;B!J82!V87)O(&%N=&%M87-T82!LY&AE='3D:N1L
M;&4@;6ETY.1N('EK<VEL]FEV:>0@=&EE=&]J82X`+"!P=75S:VET=&%I<W1A
M`"P@<'5U<VMI='1A:7-T82`E<R`E<P`L('9A:6AT96QE=F%A("5S("T@)7,`
M+2T@=F%L:71S92`M+0`Q,BUT=6YN:6X@:N1R:F5S=&5L;>0`,C0M='5N;FEN
M(&KD<FIE<W1E;&WD`#(T('1U;G1I80`\161E;&QI;F5N`%1I971O:V%N=&%T
M875S=&%JY')J97-T96QMY.0@96D@;VQE(&WDY')I=&5L='D@=.1L;&4@;W-I
M;VQL90!487!A:'1U:2!V86MA=F$@=FER:&4`5FEE<W1I;B!S86QA=6MS965N
M('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XN`$%L;&5K:7)J;VET971U
M;B!V:65S=&EN('1A<FMI<W1U:W-E96X@=&%R=FET86%N(&IU;&MI;F5N(%!'
M4"UA=F%I;BX`4V%L871U;B!V:65S=&EN(&%V86%M:7-E96X@=&%R=FET86%N
M(&IU;&MI;F5N(%!'4"UA=F%I;BP@<V%L86EN96X@4$=0+6%V86EN(&IA('-A
M;&%S86YA=&5K<W1I+@!6:65S=&EN(&%L;&5K:7)J;VET=&%M:7-E:W-I('1A
M<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'4"UA=F%I
M;B!J82!S86QA<V%N871E:W-T:2X`5FEE<W1I;B!A=F%A;6ES965N('1A<G9I
M=&%A;B!J=6QK:6YE;B!3+TU)344M879A:6XL('-A;&%I;F5N(%,O34E-12UA
M=F%I;B!J82!S86QA<V%N871E:W-T:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A
M;6ES96MS:2!T87)V:71A86X@:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA
M:6YE;B!3+TU)344M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@
M<V%L875K<V5E;B!T87)V:71A86X@:G5L:VEN96X@4TU)344M879A:6XN`$%-
M(%!I;'9IY`!!32!K979Y='3D('-A9&5T=&$`04T@<V%D90!!32!S871E:71A
M`$%-(&QU;6ES871E:71A`$%-+U!-`$%022!)1`!4:65T;VIA(&5D:71O<FES
M=&$`5&EE=&]J82XN+@!!8G,N(&%L:6X`06)S+B!K97-K96QLY`!3:6YU;&QA
M(&5I(&]L92!O:6ME=6MS:6$@;'5O9&$@5D93+6AA:V5M:7-T;V$N`%-I;G5L
M;&$@96D@;VQE(&]I:V5U:W-I82!L=6]D82!61E,M=&EE9&]S=&]A+@!+Y'ET
M=.1JY'1U;FYU:W-E;B!T:65D;W0`2^1Y='3D:N1T=6YN=6MS96X@<V%L87-A
M;F$`2^1Y='3D:N1T:6QI('-U;&IE='1U+@!+:7)J86YP:71O`$QI<^3D`$QI
M<^3D(&%L:7)Y:&WD`$QI<^3D(&%L:6]I:V5U<P!,:7/DY"!TY&CD;CH`3&ES
MY.0@=75S:2!R>6AMY`!,:7/DY"!U=7-I(&]I:V5U<P!,:7/DY"!A;&ER>6AM
MY"!R>6AMY.1N("(E<R(`3&ESY.0@86QI;VEK975D970@(B5S(@!,:7/DY"!U
M=7-I(&OD>71TY&KD.@!,:7/DY"!S87)A:V4`3&ESY.0@=75S:6$@:N1S96YI
MY`!,:7/DY"!P87)I`$QI<^3D("5S('9A;&EK:V\@36]Z:6QL86X@4VED96)A
M<B!O<VEO;VX`3&ESY.0@;W-O:71E:VER:F%A;CH`3&ESY.0@;W-O:71E:VER
M:F%A;FDZ`$QI<^3D(&OD>71TY&KD`$QI<^1T=&EI;B`B)7,B(&KD<FIE<W1E
M;&WDY&XL(&UU='1A(&5I('9O:2!L:7/D=.0@<VESY.1N:VER:F%U='5M:7-P
M>7EN;O9N(&QI<^1T:65T;VIA.B`E<RX`3&ESY'1T:6EN("(E<R(@:N1R:F5S
M=&5L;>3D;BX@5F]I="!N>70@:VER:F%U='5A('-I<^3D;BX`2^1Y='3D:FEE
M;B!L:7/DY&UI;F5N(&]N(&5S=&5T='DN`$]S;VET90!/<V]I=&5K:7)J80!6
M;VD@87-E='1A82!T86D@;>3D<FET96QLY"!O:6ME=6MS:6$@=&]I<VEL;&4@
M:^1Y='3D:FEL;&4`66QLY'!I=&\`36%I;F]K<V5T`$%F9V%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`%1A<V%A`%1A<V%U<SH`2V%I:VMI`$MA:6MK
M:2!A=71E;G1I:V]I9'5T(&OD>71TY&KD=`!+86EK:VD@<GEH;>1T`$MA:6MK
M:2!O:6ME=61E=`!+86EK:6QT82!N96QJY&QTY"!S:79U;'1A`%-A;&QI(&UO
M;F5T(&]S;VET=&5E=`!386QL:2!JY')J97-T971Y;B!L:7-T86X@='EY<&EN
M(&%S971U<RX`3VX@:F\@;VQE;6%S<V$`5F%I:'1O96AT;VEN96X@24U34"US
M:7/DY&YK:7)J875T=6UI;F5N`%9A:6AT;V5H=&]I;F5N($E-4U`M<V%L87-A
M;F$`5F%I:'1O96AT;VEN96X@24U34"UKY'ET=.1JY'1U;FYU<P!686EH=&]E
M:'1O:7-E="!SY&AK]G!O<W1I;W-O:71T965T`%9A:6AT;V5H=&]I<V5T(&UA
M;&QI=`!686EH=&]E:'1O:6YE;B!T96MS=&DZ`%EH9'ES=F%L=&%I;B!386UO
M80!!;FYE='1U(&%R=F\@96D@:V5L<&%A+@!T87!A:'1U:2!T=6YT96UA=&]N
M('9I<FAE+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>7EM:2!P<F]X
M>0!687-T875S`$%N=&%R:W1I<P!!;G1I9W5A(&IA($)A<F)U9&$`3VAJ96QM
M80!/:&IE;&UA;&ES=&$`3VAJ96QM82!O;B!V86QM:7,N`$QA:71A(&OD>71T
M]O9N(&MA:6MK:2!A;&EJ86MO:6AI;@!(>7;D:W-Y`$%R=FEO:71U(&MO:V\`
M:'5H=&EK=74`07)A8FEA("A7:6YD;W=S+3$R-38I`%!A:V5T:6X@:V]K;P!0
M86ME=&EN(&YI;6D`3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!P;VES=&%A
M('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V;B`E<R`_`$]L971K;R!V87)M82P@
M971TY"!H86QU870@<&]I<W1A82`B)7,B(&IA(&MA:6MK:2!S96X@86QI<GEH
M;>1T/P!!9V5N=&EI;F$`07)M96YI80!!<FUE;FEA("A!4DU30TE)+3@I`%1A
M:61E`$%R=6)A`$%S8V5N<VEO;B!S86%R970`07-C:6DM=&%I9&4`07-I86XO
M5'EY;F5N;65R96X@86QU90!+>7-Y('9A<FUI<W1U<R!E;FYE;B!K=6EN('1E
M:&3DY&X@>6QLY'!I=&]T;VEM96YP:71E970N`%1E:'3D=N1S87)A:VME970`
M67)I=&5T=&EI;B!P;VES=&%A(&]L96UA=&]N=&$@<GEH;>3D+@!9<FET971T
M:6EN('!O:7-T86$@;VQE;6%T;VYT82!O:6ME=71T82X`67)I=&5T=&EI;B!M
M=6]K871A(&]L96UA=&]N=&$@;VEK975T=&$N`%ER:71E='1I:6X@;75O:V%T
M82!O;&5M871O;G1A(&IA:V]A+@!,:7/D;>3D<FET>6MS970`96QO:W5U`$%U
M<W1R86QI80!)=.1V86QT80!!=71H7V-Y<G-Q;#H@5&%R=FET=&%V86$@24U!
M4"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T:%]C>7)U<SH@5&%U<W1A
M:N1R:F5S=&5L;>0@96D@='5E('1A<G9I='1A=FEA(&]M:6YA:7-U=6MS:6$N
M`$%U=&A?8WER=7,Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@
M;/9Y='EN>70N`$%U=&A?9G1P.B!T87)V:71T879A82!&5%`M;&%A:F5N;G5S
M=&$@96D@;/9Y='EN>70N($ODY&YNY"!02%`@:^1Y='3D96X@+2UE;F%B;&4M
M9G1P(&%S971U<W1A+@!!=71H7VEM87`Z(%1A<G9I='1A=F%A($E-05`M;&%A
M:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?:W)B-3H@5&%R=FET=&%V86$@
M:W)B-2UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T:%]L9&%P.B!KY'ET
M=.1J:65N(&QI<^3D;6EN96X@06-T:79E($1I<F5C=&]R>7EN(&5I(&]L92!T
M=65T='4`075T:%]L9&%P.B!+Y'ET=.1J:65N('!O:7-T86UI96YN($%C=&EV
M92!$:7)E8W1O<GES=.0@96D@;VQE('1U971T=0!!=71H7VQD87`Z(%1A<G9I
M='1A=F%A($Q$05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?;&1A
M<#H@16D@=F]I9&$@;&ESY'3D(&OD>71TY&KDY"`E<RX@4&%L=F5L:6UE;B!V
M:7)H96EL;6]I='5S(&]L:3H@`$%U=&A?;&1A<#H@16D@=F]I9&$@<&]I<W1A
M82!KY'ET=.1JY.0@)7,`075T:%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@
M:^1Y='3D:N3D("5S`$%U=&A?;&1A<#H@2^1Y='3D:FEE;B!PY&EV:71TY&UI
M;F5N($%C=&EV92!$:7)E8W1O<GEY;B!E:2!O;&4@='5E='1U+@!!=71H7VUC
M86PZ(%1A<G9I='1A=F%A($U#04PM;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N
M`$%U=&A?<VUB875T:#H@5&%R=FET=&%V86$@<VUB875T:"UL86%J96YN=7-T
M82!E:2!L]GET>6YY="X`075T96YT:6MO:6YT:2!)34%0+7!A;'9E;&EM96QL
M92!E<.1O;FYI<W1U:2X`075T96YT:6MO:6YT:2!E<.1O;FYI<W1U:0!!=71E
M;G1I:V]I;G1I(&5PY&]N;FES='5I+B`E<P!!=71E;G1I:V]I;G1I(%)!1$E5
M4RUP86QV96QI;65L=&$@97#D;VYN:7-T=6DN`$%U=&5N=&EK;VEN=&D@1E10
M+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`075T96YT:6MO:6YT:2!334(M
M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!+Y'ET971TY'9I<W/D;VQE=F%T
M(&ME;G3D=#H`07IE<F)A:7ID86X`0D]&2"!S96QI='EK<V5T`%1A=7-T80!4
M875S=&%VY')I`%;DY'+D(&ME<F)E<F]S('-A;&%S86YA+@!6Y.1RY"!K97)B
M97)O<R!KY'ET=.1JY'1U;FYU<RX`0F%H86UA`$)A:')A:6X`0F%L=&EA("A)
M4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!'<F%F:6EK;VED96X@
M<&5R=7-H86ME;6ES=&]A("(E<R(@96D@;/9Y='EN>70N`%!E<G5S=FEI=F$`
M5F%L:V\M5F5NY&KD`$)E;&=I80!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T
M86X`4WEN='EMY'#D:7;D`$]S:6]T82`B)7,B(&]H:F5L;6%L;&4@(B5S(B!E
M:2!L]GET>6YY="X`3W-I;VX@87-E='5K<V5T`$]S:6]N('1Y>7!P:0!,:6AA
M=F]I='4`0F]L:79I80!+:7)J86YM97)K:70`4F5U;F$`4F5U;F%N('9A:'9U
M=7,Z`%)E=6YA=`!";W-N:6$@2&5R>F5G;W9I;F$`36]L96UM870`0F]T<W=A
M;F$`06QI;@!";W5V970@<V%A<F5T`$)R87-I;&EA`$)R:71A;FYI86X@26YT
M:6%N('9A;'1A;65R96X@=&5R<FET;W)I;P!"<G5N96D@1&%R=7-A;&%M`$)U
M;&=A<FEA`%!A;&QU:VMA;&ES=&$`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3
M`$-20P!#4DPM:F%K96QU;W-O:71T965T`%-?;VQU;B!T:65D;W0N+BX`5N1L
M:6UU:7-T:6X@86QU<W1U<R!E:2!V86QM:7-T=6YU="X`2V%L96YT97)I`%1Y
M>6YI`$MA;7!U='-E80!+86UE<G5N`%-A;&%S86YA82!E:2!V;VD@='EH:F5N
M=.3D(&%U=&]M86%T=&ES97-T:2P@;W1A('EH=&5Y='3D('EL;.1P:73D:N3D
M;BX`16D@=F]I(&MI<FIO:71T86$@=&EE9&]S=&]O;B`B)7,B`%5L:V]I<VEA
M(&ES='5N=&]KY'-I='1E;&EJ]FETY"!E:2!O;&4@;6%H9&]L;&ES=&$@:&%L
M;&ET82X`24U!4"UP86QV96QI;65E;B!E:2!S86%T=2!Y:'1E>71TY#H@)7,`
M16D@=F]I(&%V871A('1I961O<W1O82`B)7,B+@!+86YA9&$`4&5R=0!097)U
M(&]N9V5L;6%V:65S=&D`16D@=F]I9&$@<&]I<W1A82!T:65D;W-T;V$@(B5S
M(BX`5N1L:6%I:V%I<VAA:V5M:7-T;V$@96D@;/9Y='EN>70N`$5I('9O:61A
M(&IA=&MA82!I;&UA;B`G=&%R9V5T1FEL92<@+7!A<F%M971R:6$N`$5I('9O
M:61A('!O:7-T86$@:&%K96UI<W1O82`B)7,B+@!%:2!V;VED82!P;VES=&%A
M+"`E9"!A;&ET87-O:F$@;VQE;6%S<V$N`$5I('9O:2!U=61E;&QE96YJY')J
M97-TY.0L(&%N;F5T='5J96X@=&EE='5E:61E;B!MY.1RY"!E:2!V87-T86$@
M=&%L;&5T971T=6IE;B!T:65T=65I9&5N(&WDY'+DY"X`16D@=F]I(&]H:F%T
M82!V:65S=&GD(&%N;F5T='5U;B!N=6UE<F]O;BX`2V%P(%9E<F1E`$MU=F%T
M96MS=&D`4&%L=F5L=6YT87)J;V%J80!+871E9V]R:6%T(&IA(&]T<VEK;W0`
M0V%Y;6%N('-A87)E=`!0=6AE;&EN*$=332D`4V]L=6X@=&EE9&]T`%-O;'5N
M('3D>71E.@!3;VQU;B!T:65D;W0`4V]L=6X@=N1L>7,Z`$UA=&MA<'5H96QI
M;@!+96QT=&D@*$E33RTX.#4Y+3$T*0!+97-K:71E='1Y`$ME<VMI+4%F<FEK
M86X@=&%S879A;'1A`$ME<VMI+45U<F]O<'!A("A)4T\M.#@U.2TR*0!687)M
M96YT965N('1I961O=`!687)M96YT965N(&]M:7-T86IA`%9A<FUE;G1E96X@
M<&]L:71I:6MA=`!4<V%D`$UU=71A`%9A:6AD82!S86QA<V%N87-I`%9O:70@
M;75U='1A82!LY&AE='3D;6ES<^1S:2!SY&AK]G!O<W1E:7-S82!NY&MY=FGD
M(&YI;6DM('1A:2!O<V]I=&5T:65T;VIA+@!386QA<V%N86X@=F%I:'1O(&5I
M(&]L92!KY'ET]G-SY"!N>6MY:7-I;&SD(&%S971U:W-I;&QA+B!/=&$@>6AT
M97ET=.0@>6QLY'!I=.1J:6EN+@!-97)K:VD`5&%R:VES=%]A(&QI;FMK:2XN
M+@!#:&EL90!+:6EN80!+:6EN82!Y:W-I;FME<G1A:7-T971T=2`H1T(R,S$R
M*0!+:6EN82!P97)I;G1E:6YE;B`H0FEG-2D`5F%L:71S92!O:&IE;&UA`%9A
M;&ET<V4@<V%L87-A;F$`5F%L:71S92!KY'ET=.1JY'1U;FYU<P!686QI='-E
M('#D:7;D;>3D<FEE;B!E<VET>7-A<W4Z`%9A;&ET<V4@;&ES=&%N('1Y>7!P
M:2`H:N1R:F5S=&5T>6EL;&4@;&ES=&]I;&QE*0!*;W5L=7-A87)E=`!,=6]K
M:V%MY.1R:71Y<W3D("5S(&5I(&SV>71Y;GET+@!396QK9>0`4&]I<W1A($U3
M3V9F:6-E('1A9VET`%!O:7-T82!K>7-E;'D`4&]I<W1A(&OD>71TY&KD.B`E
M<P!0;VES=&$@:^1Y='3D:N0`4&]I<W1A(&OD>71TY&KD;B!T:65D;W0`4V5L
M:V5N97;DY"!M>?9HY.1N`$YA<'-A=71A(&IA=&MA86MS97-I`$-L:6MA=&5L
M;"!(5%10.FX@:V%U='1A`%-U;&IE(&EK:W5N80!0:6QV:>0`4&EL=FEN96X@
M86EK86ES:6X`4&EL=FEN96X`2V]O:V]S("A+965L:6YG*2!S86%R970`4&EE
M;F5N;N0@<VEV=79A;&EK:V\`4&EE;F5N;F5T>70@<F5U;F%T`$MO;'5M8FEA
M`%;D<FD`5N1R:79A;&ET<VEN`%;D<FEV86QI;G1A`%-A<F%K.@!387)A:VME
M:61E;B!O='-I:V]T`%-A<FIA:W5V870`2V]M96YT;P!+;VUE;G1O='5L:VMI
M`$MO;6UE;G1T:0!9;&5I;F5N(&YI;6D`2V]M;W)I=`!9<FET>7,`5&EE=&]K
M;VYE970`3VQO<W5H9&4`3VQO<W5H=&5E=`!!<V5T=6MS:65N(&5R;W0`07-E
M='5K<V5T(%!$02UL86ET=&5I9&5N+"#D;'EP=6AE;&EM:65N(&IA($]U=&QO
M;VMI;B!S>6YK<F]N;VET:6EN+@!!<V5T=6MS:6$@<&ETY.0@<.1I=FET=.3D
M+@!!<V5T82!A<V5T=6MS970@)7,`5F%H=FES=&$@:VER:F]I='1A;6%L;&$@
M<V%L87-A;F$@=75D97-T86%N`$MO;F=O`$MO;F=O;B!D96UO:W)A871T:6YE
M;B!T87-A=F%L=&$`66AT97ES(&5PY&]N;FES='5I+@!9:'1E>7,@97#D;VYN
M:7-T=6DZ(`!9:'1E>7,@:G5L:VES=&5N(&%V86EN=&5N('!A;'9E;&EM96QL
M92!E<.1O;FYI<W1U:2X`66AT97ES(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV
M96QI;65L;&4@97#D;VYN:7-T=6DN(%9I<FAE.B`E<R`H)7,I`%EH=&5Y<R!F
M='`M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!9:'1E>7-T:65D;W0`66AT
M97ES=&EE9&]T(&QI<^1T=&EI;B!O<V]I=&5K:7)J86%S:2X`5&EI=FES=&5T
M>6X@=&EE9&]S=&]N('1Y>7!P:3H`(B5S(CIN('-I<^1L=/8`2F%T:V$`0V]O
M:R!S86%R970`17;D<W1E`$MO<&EO:0!+;W!I;VEN=&D@97#D;VYN:7-T=6DZ
M("5S`$MO<&EO:2!V86QI;G1A`$-O<W0@240`0V]S=&$@4FEC80!.;W)S=6YL
M=75R86YN:6MK;P!6:65S=&EN(%!'4"US86QA=7-T82!E:2!V;VET=2!T96AD
MY#H@`%9I97-T:6EN(&5I('9O:71U(&UU;V1O<W1A82!01U`M86QL96MI<FIO
M:71U<W1A.B``5FEE<W1I;B!3+TU)344M<V%L875S=&$@96D@=F]I='4@=&5H
M9.0N`%9I97-T:6EN(&5I('9O:71U(&UU;V1O<W1A82!3+TU)344M86QL96MI
M<FIO:71U<W1A+@!%:2!V;VET=2!O='1A82!Y:'1E>71TY"X@)7,`3&1A<"UP
M86QV96QI;65E;B!E:2!S86%T=2!A=71O<FES;VET=6$@>6AT97ET=.0N`$5I
M('9O:71U('1A<FMI<W1A82!S86QD;V$N("5S`$Q$05`M<&%L=F5L:6UE96X@
M96D@<V%A='4@>6AT97ET=.0N`$5I('9O:71U(&]T=&%A('EH=&5Y='3D('!A
M;'9E;&EM965N("(E<R(@:^1Y='3D96X@1E10.B`E<P!%:2!V;VET=2!L=6]D
M82!J86ME;'5L:7-T86$N("5S`%!'4"US86QA='1U82!T:65T;V$@96D@=F]I
M='4@875K86ES=&$Z(`!3+TU)344M<V%L871T=6$@=&EE=&]A(&5I('9O:71U
M(&%U:V%I<W1A+@!%:2!V;VET=2!P;VES=&%A('EH=&5Y<W1I971O82X@)7,`
M16D@=F]I='4@<&]I<W1A82!J86ME;'5L:7-T86$N("5S`$5I('9O:71U('!O
M:7-T86$@<.1I=FET>7-S:W)I<'1IY"`B)7,B+@!6:65S=&EN(&SD:&5T=.1J
MY&X@<^1H:_9P;W-T:6]S;VET971T82!E:2!P>7-T>71T>2!MY.1R:71T96QE
M;>3D;BX`16D@=F]I='4@:&%K96$@:V]K;R!O<V]I=&5K:7)J86$N`$5I('9O
M:71U(&AA:V5A(&MO:V\@:F%K96QU;&ES=&%A+@!%:2!V;VET=2!H86ME82!K
M;VMO(&QI<W1A82!J86ME;'5L:7-T;VES=&$N`$5I('9O:71U(&QU:V5A('-T
M<F%T96=I86$@(B5S(BX`2V]M96YT;R!M:V1I<B`B)7,B(&5PY&]N;FES='5I
M+@!*=6QK:7-T96X@879A:6YT96X@<&%L=F5L:6UE;'1A(&5I('-A871U(&IU
M;&MI<W1A(&%V86EN=&$N`%1I961O<W1O;VX@(B5S(B!E:2!V;VD@:VER:F]I
M='1A82X`16D@=F]I='4@875K86ES=&$@)7,N`%EL;.1P:71O;6]D=75L:6X@
M)7,@875K86ES=2!E<.1O;FYI<W1U:0!%:2!V;VD@875K86ES=&$@:&%K96UI
M<W1O82`B)7,B+@!,1$%0+7!A;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L;&ES
M=&$@971S:>0N`"5S.N3D(&5I('9O:71U(&QU:V5A+@!+Y'ET=.1JY&X@<V%L
M87-A;F%A(&5I('9O:71U(&YO;&QA=&$N($IO=&MU="!T87)V:71T879A="!T
M:65D;W0@;W9A="!VY.1R:6XN(%ER:73D('5U9&5S=&%A;B!T86D@;W1A('EH
M=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E="!L:7/DY"!A<'5A+@!%
M:2!V;VET=2!H86ME82!!0TPM=&EE=&]J80!%:2!V;VET=2!H86ME82!O<V]I
M=&5K:7)J86$N("5S`$5I('9O:71U(&AA:V5A(&IA:V5L=6QI<W1A82X@)7,`
M16D@=F]I='4@:&%K96$@:F%K96QU;&ES=&]J82X@)7,`16D@=F]I='4@:&%K
M96$@=&EE=&]J82!P86QV96QI;65N('1O:6UI;FYO:7-T80!%:2!V;VET=2!P
M86QA=71T86$@87-E='5K<VEA+@!+;VUE;G1O(')M9&ER("(E<R(@97#D;VYN
M:7-T=6DN`$5I('9O:71U('1A;&QE='1A82`E<R!A<V5T=6MS:6$N`$5I('9O
M:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R;75U<VMO<&EO=&$N`$5I('9O
M:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R;75U<VMO<&EO=&$@)7,`16D@
M=F]I='4@=&%L;&5T=&%A(&%S971U<W#D:79I='ES<VMR:7!T:>0Z("(E<R(N
M`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R;75U<VMO<&EO=&$@
M)7,N`$%S971U<W1I961O<W1O;B`E<R!T86QL971U<R!E<.1O;FYI<W1U:2X@
M5F]I="!KY'ET=.3D(&IO=&%K:6X@87-E='5S=&$@=&%L;&5T=&%A:W-E<VD@
M:V]O9&EN('1A:V%I<VEN("5S('1A:2!T86D@:V]P:6]I9&$@:^1S:6X@86QL
M82!O;&5V86X@:V]O9&EN('1I961O<W1O;VX@)7,N`$Q$05`M<&%L=F5L:6UE
M;'1A(&5I(&]L92!M86AD;VQL:7-T82!E='-IY"X`2V]M96YT;R!U;FQI;FL@
M(B5S(B!E<.1O;FYI<W1U:2X`16D@=F]I='4@<.1I=FET=.3D('EH=&5Y<W1I
M971O:F$N("5S`$5I('9O:71U('#D:79I='3DY"!J86ME;'5L:7-T86$N("5S
M`%9I97-T96KD(&5I('9O:71U('!O:7-T86$@:V%N<VEO<W1A("(E<R(Z("5S
M`$UO>FEL;&$@4VED96)A<B!E:2!L]GET>6YY="X@5F%R;6ES=&$@971TY"!3
M:61E8F%R(&]S:6\@;VX@875K:2X`2^1Y='3D:N1L;&4@(B5S(B!E:2!V;VET
M=2!A;G1A82!S975R86%V:6$@;VEK975S:6$@:V%N<VEO;VX@(B5S(CH@)7,`
M3&%S:V5T='4@=&5K<W1I`$UA80!+=7)S<VET`$QU;P!,=6\@=75S:2!L:6YK
M:VD`3'5O('5U<VD`5F]I(&QU;V1A('5U<VEA(&MA;G-I;VET80!/:6ME=61E
M="!T96MI:N1L;.0`3'5O='1O:V]R=&EN;G5M97)O`$MR;V%T:6$`2W5U8F$`
M5.1MY&YH971K:6YE;B`T('9A:6AE='1A`%3D;>1N:&5T:VES970@:7-T=6YN
M;W0`2V5L;&]N86EK82!TY&QLY"!H971K96QLY`!4Y&WD;FAE=&MI;F5N(%52
M3"!O;@!4Y&WD;FAE=&MI<V5T(&OD>71TY&KD=`!4Y&WD;FAE=&MI;F5N('/D
MY`!4Y&WD;FAE=&MI;F5N('1I;&$Z(`!4Y&WD;FAE=&MI;F5N('1Y>6QI`%9O
M:70@;75O:V%T82!T96ATY'9IY"P@:F]T:V$@<W5O<FET971A86X@:W5N(&MI
M<FIA=61U=&%A;B!S:7/DY&X@;VAJ96QM86%N("5S+@!,96EK:V%A`$QE:6MK
M86$@=F%L:71T=0!+>7!R;W,`2WER:6QL:6YE;B`H2T])."U2*0!+>7)I;&QI
M;F5N("A7:6YD;W=S+3$R-3$I`$MY<FEL;&EN96XO56MR86EN82`H2T])."U5
M*0!4<V5K:6X@=&%S879A;'1A`%!0`$133B`H;&ESY'1I971O82!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I`%#D:79I='3D:6X`1&%T851R964M<V5L86EN`%1I971O
M:V%N=&%H86MU`%#D:7;D>7,`4.1I=N1MY.1RY"!V87-T86%N;W1E='1U`%#D
M:7;D;>3D<N1N('9A;&EN=&$`4.1I=N0`4&]?:7-T82!S87)A:V4`:F]U;'5K
M=74`1&5S:6UA86QI;G5M97)O=`!0:65N96YNY"!S:7-E;FYY<W3D`$]L971U
M<P!/;&5T=7-VY')I`$]L971U<W!R;V9I:6QI`$]L971U<R!K;VUE;G1O='5L
M:VMI`$WDY')I=&5L;>1T`%!O:7-T80!0;VES=&$@<V]L=0!0;VES=&$@<GEH
M;>0`4&]I<W1A(&QO:VD`4&]I<W1A(&]I:V5U<P!6;VD@<&]I<W1A82!J82!T
M=6AO=&$@<&]I<W1E='1U:F$@=FEE<W1E:N0`4&]I<W1A('-O;'4`4&]I<W1A
M('-A<F%K90!0;VES=&$@;VQE;6%S<V$@;VQE=F%T('9A:6AT;V5H=&]I;F5N
M(&UA;&QI`%9O:2!P;VES=&%A('9I97-T96KD`%!O:7-T82`B)7,B.FX@;VEK
M975K<VEA`$]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82`B)7,B
M(&IA(&MA:6MK:2!S96X@86QI;VEK975D970_`%!O:7-T82!R:79I`%!O:7-T
M82!V86QI='1U('!R;V9I:6QI`%9O:2!L=6]D82!U=7-I82!K86YS:6]I=&$`
M4&]I<W1A('9A;&ET='4@<V%R86ME`%!O:7-T82!V86QI='1U(')I=FD`4&]I
M<W1E='1U('#D:79I='ES<VMR:7!T:2`B)7,B+@!4;VEM:71U<V%I:V$`5&%N
M<VMA`$]N9V5L;6%N(&MU=F%U<P!+=79A=7,`5&%R:V5M;6%T('1I961O="`H
M;/9Y='EVY'0@;7GV<R!(;W)D93IN(&QO:VET:65D;W-T;W-T82DZ`%1A<FME
M;6UA="!T:65D;W0@;VX@=&%L;&5T971T=2!Y;&SD<&ED;VX@:^1S:71E;'3D
M=N1K<VDN`$ME:&ET>7,`2V]S=&5U<W!I<W1E`$5D96QL:7-E;B!T=6YN:6X@
M:V]S=&5U<W!I<W1E.B``2V]S=&5U<W!I<W1E.B``4W5U;G1A('9A<V5M;6%L
M=&$@;VEK96%L;&4`4W5U;G1A(&]I:V5A;'1A('9A<V5M;6%L;&4`2&%K96UI
M<W1O`$OD>73D(#(T+71U;FYI;B!A:6MA97-I='ES=.0N`$[D:WEMY&X@87-E
M='5K<V5T`$5S:71Y<W1A<&$@>6MS:71Y:7-K;VAT86EN96X@96YN=7-T90!%
M<VET>7-T87!A(&5N;G5S=&5E;&QE("A4048I`$5S:71Y<W1A<&$`4&5R:6QL
M96UE;F]I;&UO:71U<P!$:FEB;W5T:0!%:2!S86$@<&]I<W1A80#$;.0@:^1Y
M=.0@<W5O<F%A;B!M86EN=&5N86YC92YP:'`Z=.0`2F]S(&5N<VEM;>1I;F5N
M(')I=FD@<VESY&QTY.0@<V%R86MK96ED96X@;W1S:6MO="P@;FEI;B!V86QI
M='-E.@!$;VUI;FEK86%N:6YE;@!$;VUI;FEK86%N:6YE;B!T87-A=F%L=&$`
M16EK]B!O;&4@:^1Y='3D:N1T=6YN=7-T83\@2VER:F%U9'4@:^1Y='3D:N1K
M<VDN`%1A;&QE;FYA`%1A;&QE;FYA("5S`%1A;&QE;FYA(&QU;W1U(&%S971U
M<R!02%`M<VMR:7!T:6[D+@!!;&%S=F5T;W9A;&EK:V\`2'5U;65E=`!3Y&AK
M]G!O<W1I;W-O:71E`$5-86EL+71O+5--4R!G871E=V%Y(&%J=7)I+"!N:6EL
M;&4@<&%L=F5L=6YT87)J;V%J:6QL92P@:F]T:V$@=&%R:F]A=F%T('3D=.0@
M<&%L=F5L=6$N`%9)4DA%`$5C=6%D;W(`375O:VMA80!-=6]K:V%A(&]S:6]T
M80!-=6]K:V%A(')Y:&WDY`!-=6]K:V%A(&]I:V5U='1A`$UU;VMK86$@;VEK
M975K<VEA`$UU;VMK86$@)R5S)SIN(&]I:V5U:W-I80!-=6]K:V%A(&%S971U
M:W-I83H`375O:VMA82`B)7,B.FX@;VEK975K<VEA`$UU;VMK86$@)7,Z;B!O
M:6ME=6MS:6$`2V]U;'5T=7,`16=Y<'1I`$5L(%-A;'9A9&]R`$5L96UE;G1T
M:2XN+@!%;0!3Y&AK]G!O<W1I`%/D:&OV<&]S=&EO<V]I=&4`4^1H:_9P;W-T
M:6]S;VET=&5I9&5N('!I=.3D(&]L;&$@<V%M870N`%/D:&OV<&]S=&D@=F%R
M;6ES='5K<V5L;&$`16UA:6PM=&\M4TU3($=A=&5W87D`2'EM:?9T`%1Y:&KD
M('9I97-T:2X`5'EH:N0@=F%S=&%U<RX`5'EH:N0@:&%K=71E<FUI`%-A;&QI
M(&MU=FEE;B!L86ET=&%M:6YE;B!K=79A9V%L;&5R:6%S=&$@=&5K<W1I;B!J
M;W5K:V]O;BX`3&%I=&$@<.3D;&QE(&]I:V5A;B!P86EN:6MK965N(&MO;G1E
M:W-T:6UE;G4N`%#DY'1T>6UI<W9U;W-I`%-U=7)E;FYA(&5D:71O<FEA`$%N
M;F$@:WES>6UY<R!J;VMA(&MY<WETY.1N+"!J;W,@<V%L87-A;F%S:2!J;W5D
M=71A86X@;F]L;&%A;6%A;B!E<VEM97)K:6MS:2`G;6EKY"!O;B!L96UM:6MK
M:7-I(&YI;6D_)SH`3&%I=&$@:W5V82!54DP@=.1HY&X`06YN82!K:7)J86EM
M970@86QL93H`16MV871O<FEA86QI;F5N($=U:6YE80!%<FET<F5A`%9I<FAE
M`%9I<FAE('#D:79I=&5T=.1E<W/D(&]S:6]T83H@)7,`5FER:&4@<.1I=FET
M971TY&5S<^0@<WEN8R!A;F-H;W(@+71I971O83H@)7,`5FER:&4@<&]I<W1E
M='1A97-S82!S>6YC(&QO:VEA.B`E<P!6:7)H92!H865T=&%E<W-A('-I<^1L
M=/;D.B`E<RX`5FER:&4@<.1I=FET971TY&5S<^0@<V%L87-A;F%A.B`E<P!6
M:7)H92!SY&AK]G!O<W1I=FEE<W1I<W/D+@!6:7)H92!K:7)J;VET971T865S
M<V$@(B5S(BX`165S=&D`171I;W!I80!%=&YI;F5N`$5U<F]O<'!A`#$U(&UI
M;G5U=&EN(';D;&5I;@`R(&UI;G5U=&EN(';D;&5I;@`S,"!S96MU;FYI;B!V
MY&QE:6X`-2!M:6YU=71I;B!VY&QE:6X`2F]K86ES96QL82!S:7/DY&YK:7)J
M875T=6UI<V5L;&$`4'5O;&5N('1U;FYI;B!VY&QE:6X`36EN=75T:6X@=N1L
M96EN`$5S:6UE<FMK:6%R=F]T.@!3=6]R:71A`$QA86IE;FYA`$QA86IE;FYA
M('-I=G5V86QI:VMO`$]D;W1E='1I:6X@;65R:VMIY"`G*2<`4V%N82!S96QL
M86ES96YA86X@=&%I(&AA:W5T97)M:2!L86EN875S;65R:V5I<W/D`$QO<'!U
M<.1I=N1MY.1RY`!%:W-P;VYE;G1T:0!&1R!VY')I`$%S971U<W1I961O<W1O
M:F5N('1U;VYT:2!&5%`Z;&SD`$%S971U<W1E;B!H86MU(&5PY&]N;FES='5I
M+@!9:'1E>7,@3$1!4"UP86QV96QI;65E;B!E<.1O;FYI<W1U:2X`66AT97ES
M(%--0BUP86QV96QI;65E;B!E<.1O;FYI<W1U:2X`2V]P:6]I;G1I("(E<R(Z
M;'3D(&5PY&]N;FES='5I+@!+;W!I;VEN=&D@(B5S(CIL;&4@97#D;VYN:7-T
M=6DN`%5U9&5N(%-!4TPM>6AT97ED96X@;'5O;6EN96X@97#D;VYN:7-T=6DN
M`%-I:7)T;R`B)7,B.N3D;B!E<.1O;FYI<W1U:2X`4VEI<G1O(&5PY&]N;FES
M='5I.B`E<P!+875N:7,`1F%L:VQA;F1I;B!S86%R970@*$UA;'9I;F%S*0!&
MY'(@<V%A<F5T`%9A:V%V82!V:7)H93H`1F%K<VD`1F%K<VET`&AE;&UI:W5U
M`%1U;G1U=2!K=6EN`%1U;G1U=2!K=6EN.B``375U=&%M:6$@<V%T96ET80!-
M=75T86UI82!L=6UI<V%T96ET80!+96YT=.1M871R:6ES:0!&:6=L970@0T%0
M5$-(00!&:6=L970@:VER:F%S:6X`1FED>FD`5&EE9&]S=&\`5&EE9&]S=&]J
M96X@;'5K=6WDY'+D.B`E<R!T:65D;W-T;P!4:65D;W-T;VIE;B!L=6MU;>3D
M<N0Z("5S('1I961O<W1O80!4:65D;W-T;VIE;B!KY'-I='1E;'D`5&EE9&]S
M=&]N(&YI;6D`5&EE9&]S=&]N('9A;&EN=&$`5&EE9&]S=&]N('1U;VYT:0!4
M:65D;W-T;VIE;B!T=6]N=&D@96D@;VQE(&OD>71E='3D=FES<^0N`%-U;V1A
M='1I;65T`%-U;VUI`$5N<VEM;>1I;F5N('!U;VQI<VMO`$5N<VEM;>1I;F5N
M(&YE;&KD;FYE<P!+;W)J86$@<W5H9&4`2^3D;F[D('EM<.1R:0!+96QL=79A
M`%-U;74`2V%N<VEO=&$@)7,@96D@;VQE(&]L96UA<W-A+@!+:7)J87-I;65N
M(';D<FD`4G5O:V$`4V5L86EM:6QL92P@:F]T:V$@96EVY'0@='5E(&MU=FEA
M`$5N;G5S=&4@*%1!1BD`16YN=7-T971T879A="!V=6]R;VMA=61E="`H2'5O
M;6%A=&AA;B!E='3D(&5N;G5S='5K<V5S<V$@;VX@=&EE9&]T('-E:^0@<.1I
M=FES=.0@971TY"#V:7-TY"P@:F]T96X@<W5U<FD@;>3D<N0@<.1I=FGD(&%I
M:&5U='1A82!L:6EA;B!L979EY&X@;W-I;VXI`%5N;VAD:71K;R!S86QA<V%N
M87-I/P!,;VUA:VME970`36EE=&5L875S90!-:65T96QA=7-E96X@='EY<'!I
M`$UI971E;&%U<V5E=`!-:65T96QA=7-E970@,@!&;V]R=6UI=`!5=61E;&QE
M96YO:&IA=6MS970`<&4`2V5H>6MS970`4F%N<VMA`%)A;G-K82P@365T<F]P
M;VQI`%)A;G-K86X@1W5Y86YA`%)A;G-K86X@4&]L>6YE<VEA`%)A;G-K86X@
M971E;.1I<V5T('1E<G)I=&]R:6]T`$SD:&5T=.1JY`!3=75N;F%S=&$@`%!I
M9&5M<&D@:W5V875S.@!4Y'ES:6MU=0!+;VMO(&YI;6D`1V%B;VX`1V%L;&5R
M:6$L(&IO<W1A(&MU=F$@;W1E=&%A;@!'86QL97)I83H`1V%M8FEA`%1E92`E
M<R!A<V5T=6MS970`1V5N97)O:71U(&MO;V1I`$=E;W)G:6$`4V%K<V$`1VAA
M;F$`1VEB<F%L=&%R`$5T=6YI;6D`66QE:7-E="!A<V5T=6MS970`365N90!'
M]F1E;`!';V]G;&4@2V%R=&%T`$=O;V=L92!H86MU`$AA<FUA87/D=GD`2W)E
M:6MK80!+<F5I:VMA("A)4T\M.#@U.2TW*0!'<O9N;&%N=&D`1W)E;F%D80!2
M>6AMY&X@>6QLY'!I=&\`4GEH;6EE;B!N:6UE="!E:7;D="!S86$@;VQL82!T
M>6AJ:>0`1W)O=7!?;&1A<#H@16D@=F]I9&$@;&ESY'3D(&OD>71TY&KDY"`E
M<RX@4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L:3H@`$=R;W5P7VQD87`Z
M($5I('9O:61A('#D:7;D='3DY"!KY'ET=.1JY.0@)7,`1W)O=7!?;&1A<#H@
M16D@=F]I9&$@<.1I=N1T=.3D(&OD>71TY&KDY"`E<P!2>6AMY'0`1W5A9&5L
M;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!6:65R86EL:6IA;B!O:6ME
M=61E=`!6:65R87-K:7)J80!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`
M2%1-3`!(5$U,07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES
M=&%M87-T82!R:79I;B!V:6EM96ES=.0@<V]L=6$N`$A434Q!<F5A('!E;&MU
M<FEM86ES97-T:2!K:65L=.1Y='EY('!O:7-T86UA<W1A('9I:6UE:7-TY"!S
M87)A:V5T=&$@=&%U;'5K;W-T82X`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I
M(&MI96QTY'ET>7D@<&]I<W1A;6%S=&$@=FEI;65I<W3D(')I=FGD('1A=6QU
M:V]S=&$N`$A45%`M875T96YT:6MO:6YT:6$@96D@;/9Y='EN>70N`$AA:71I
M`$AA<V@M86QG;W)I=&UI`%5S=F$`3W1S86ME`$]T<V%K90!(96%R9"!J82!-
M8T1O;F%L9"!S86%R970`5F]I;6%K87,@=6MK;W-M>7)S:WD`2&5P<F5A("A)
M4T\M.#@U.2TX+4DI`$MO<FME=7,`3VAJ90!!<'5A(&5D:71O<FEN(&OD>71T
M]O9N`$]H:F4`4&%L;&]N<'5O;&ES:V\Z`%3D<W/D(&]N('1I961O<W1O;B!A
M;&MU;W-A.@!+;W)K96$`2V]?=&D`4'EHY"!I<W1U:6X@*%9A=&EK86%N:6X@
M:V%U<'5N:VEV86QT:6\I`$MO=&D`2V]T:6]S;VET90!+;W1I:&%K96UI<W1O
M`%!U:&5L:6X@*&MO=&DI`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@17#D:V5L<&]A("5S(%A-3"UD871A82!V:65S=&ES<^0@)7,`
M2&]R9&4O2V]L86(Z(%EK<VEKY.1N('9I97-T:2!E:2!V87-T86$@;V)J96MT
M:6$@)7,`2&]R9&4O2V]L86(Z(%EH=.1KY.1N(&]B:F5K=&EA("5S(&5I(&SV
M>71Y;GET('9I97-T:7-TY"`E<P!(;W)D92]+;VQA8CH@4&]I<W1E='1I:6X@
M)7,@(B5S(@!(;W)D92]+;VQA8CH@26YT96=R86%T:6]K;VYE('9A871I:2!T
M;VEM:6%K<V5E;B`G9&]M>&UL)R!02%`M;&%A:F5N;G5K<V5N`$AO<F1E+TMO
M;&%B.B!%:2!V;VED82!L=6]D82!U=71T82!834PM<'5U=&$@;V)J96MT:6QL
M92`E<P!(;W)D92]+;VQA8CH@16D@=F]I='4@<&]I<W1A82`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@16D@=F]I9&$@:&%K96$@34E-12!)1#KD(&]S:6]L
M;&4@='EY<'!IY"`E<P!(;W)D92]+;VQA8CH@16D@=F]I('-Y:W)O;F]I9&$@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($5I('9O:61A('-Y;FMR;VYO:61A
M(&IA:V]J83H@)7,`2&]R9&4O2V]L86(Z(%1U;G1E;6%T;VX@:F%K;R`B)7,B
M`%9A86MA<W5O<F$@<^3D;G3V`%9A86MA<W5O<F$@=.1Y=&4`5F%A:V%S=6]R
M83H`36ET96X@='5L:70@=.1N;F4_("A287!O<G1O:2!K:6ET;W,A*0!+=6EN
M:V$@;6]N=&$@<V%R86ME='1A(&AA;'5A="!Y:&1I<W3DY#\`2V5N='1I96X@
M*'-A<F%K:V5I9&5N*2!L=6MU;>3D<N0N`$MU:6YK82!M;VYT82!R:79IY"!H
M86QU870@>6AD:7-TY.0_`$MO<W1E=7,`2V]S=&5U<SH@`$AU;6]R:7-T:70`
M56YK87)I`$E-05`M<&]S=&EL86%T:6MO;B!L=6]N=&D@97#D;VYN:7-T=6DZ
M("5S`$E-05`M<&]S=&EL86%T:6MO;B!P;VES=&\@97#D;VYN:7-T=6DZ("5S
M`$E-05`M<&]S=&EL86%T:6MO;B!K:6EN=&GV;B!L=6]N=&D@97#D;VYN:7-T
M=6DZ("5S`$E0+6]S;VET90!)4"UO<V]I=&4@96D@;VQE(&OD>71E='3D=FES
M<^0N`$E0+6]S;VET92!E:2!O;&4@<V%L;&ET=6X@0TE$4BUB;&]K:6X@<VES
MY&QLY`!)4"USY.1N;O9S=/9N(')I:VMO;75S`$Q?86ET82!R:79I(&5N;F5N
M`$ES;&%N=&D`5F%I;B!I:V]N:70`26MO;FET("5S.FQL90!):V]N:70@:F$@
M=&5K<W1I`%!R;V9I:6QI;B!N:6UI.@!*;W,@<VEV=2!E:2!NY'D@:W5N;F]L
M;&$L(&YI:6X@875K86ES92`E<R!E<FEL;&ES97-SY"!I:VMU;F%S<V$N`$IO
M<R!E="!NY&4@:6MO;F5I=&$@:^1Y='3D97-SY'-I($EN=&5R;F5T($5X<&QO
M<F5R('-E;&%I;G1A+"!N:6EN('-I;G5N('!I=.3D(&]T=&%A('!O:7,@<.3D
M;'3D(%!.1R!LY'!I;N1K>79Y>7,@<F%S=&ET=&%M86QL82!TY&WD(&QA871I
M:VMO+@!*;W,@;N1E="!TY&WD;B!V:65S=&EN+"!M=71T82!E="!K=79A82P@
M;FEI;B!T=6]M86%S:2!K=79A82!E:2!V;VD@;N1Y='3DY"!KY'ET=.1MY'-S
MY'-I('-E;&%I;65S<V$N`$MU=FEE;B!E<VEK871S96QU`$MU=F$@55),`$MU
M=F$@55),.@!+=79A(&=A;&QE<FEA<W1A`$MU=F$@9V%L;&5R:6%S=&$Z`$MU
M=F%N('9I96YT:0!+=79A=`!4=6]N=&DL(&%S:V5L("5D`%1U;W1U(&ME;G1T
MY#H@)7,`5'5O9'5T(&ME;G3D=#H`3&%?:71A(')I=FD@:N1L:V5E;@!6Y.1R
MY"!T;VEM:6YT;VMO;V1I(&%N;F5T='4N`$OD>71TY&KD='5N;G5S('1A:2!S
M86QA<V%N82!O;B!VY.1R:6XN`%;DY'+D(&OD>71TY&KD='5N;G5S('1A:2!V
M86EH=&]E:'1O:6YE;B!O<V]I=&4N(%ER:73D('5U9&5S=&%A;B!J82!O=&$@
M>6AT97ET=.0@>6QLY'!I=&]O;B!J;W,@=&%R=FET<V5T(&QI<^3D(&%P=6$N
M`$QI<^3D('-I<V5N;GES=.0`26YT:6$`66MS:71TY&ES970@:^1Y='3D:N1T
M`$EN9&]N97-I80!);F9O`$EN9F]R;6%A=&EO`%1I971O82!E:2!O;&4@96[D
MY"!S86%T879I;&QA+@!,86ET82!S7V%R86ME(&KD;&ME96X`3&%I=&$@:W5V
M80!,86ET82!T875L=6MK;P!,86ET82!W=W<M;&EN:VMI`$QA:71A(%]S87)A
M:V4@96YN96X`3&%I=&$@=75S:2!S87)A:V4@;GEK>6ES96X@:N1L:V5E;@!,
M86ET82!U=7-I('-A<F%K92!E;FYE;B!N>6MY:7-TY`!,86ET82!U=7-I(')I
M=FD@;GEK>6ES96X@:N1L:V5E;@!,86ET82!U=7-I(')I=FD@96YN96X@;GEK
M>6ES=.0`3&%I=&$@:V%P<&%L92!N>6MY:7-E;B!N;V1E;B!JY&QK965N`$QA
M:71A(&MA<'!A;&4@96YN96X@;GEK>6ES=.0@;F]D96$`3&%I=&$@=F%I:'1O
M96AT;VEN96X@;6%L;&D`06YN82!SY&AK]G!O<W1I;W-O:71E(&IO:&]N('5U
M<VD@<V%L87-A;F$@;.1H971E=.3D;CH`3&%I=&$@<V]L=2!JY&QK965N`$QA
M:71A('-O;'4@96YN96X`3&%I=&$@<V]L=2!JY&QK965N`$QA:71A('-A<F%K
M92!E;FYE;@!6;VD@;&%I='1A82!V:65S=&5JY`!,86ET82!K87!P86QE(&KD
M;&ME96X`3&%I=&$@:V%P<&%L92!E;FYE;@!,86ET82!R:79I(&5N;F5N`$QA
M:71A(')I=FD@:N1L:V5E;@!!;FYA('9A861I='1A=F$@=F%S=&%U<R!T=7)V
M86MY<WEM>6MS965N.@!,:6ETY"]-=6]K:V%A(&MU=FEA`$QI:73D+TUU;VMK
M86$@;&EN:VMIY`!3:6YU;&QA(&5I(&]L92!T87)P965K<VD@:W)E9&EI='1E
M:N0@;.1H971TY.1K<V5S:2!V:65S=&EN(&IA:V5L=6QI<W1A;&QE+@!2:6ET
M=.1MY'1T]FWD<W1I(&MR961I:71T96KD`$MO:V]N86ES;'5K=0!+;VMO;F%I
M<VQU:W5L:7-T80!%<.1K96QP;R`@541(("A5<V5R($1A=&$@2&5A9&5R*2X`
M17#D:V5L<&]A(%I)4"UT:65T;V$N`$5PY&ME;'!O(&]H:F5L;6$N`$5PY&ME
M;'!O(&)A=&-H($E$+@!,Y&AE=&5T=&EI;B!E<.1K96QP;V$@=&EE=&]A+@!%
M<.1K96QP;R!V87-T86%N;W1T86IA;B!O<V]I=&4N`$5PY&ME;'!O('1I961O
M<W1O;75O=&\`17#D:V5L<&\@;&ES96YS<VEA=F%I;BX`17#D:V5L<&\@<&%I
M:VMA=&EE=&\N`$5PY&ME;'!O(&US9U]T>7!E("X`17#D:V5L<&\@=&%I('!U
M=71T=79A(&%P:5]I9"X`17#D:V5L<&\@=&%I('!U=71T=79A('!A<F%M971R
M:2X`17#D:V5L=F]T(&]I:V5U9&5T('EL96UMY&QLY"!T87-O;&QA+@!%<.1K
M96QP;R!P87)N97(@:60N`$5PY&ME;'!O('1U;W1E:V]O9&DN`$5PY&ME;'!O
M('!R;W1O:V]L;&$N`$5PY&ME;'!O('9A<W1A86YO='1A:F$Z("(E<R(`17#D
M:V5L<&\@:F%K;RUO8FIE:W1I`$5PY&ME;'!O(&SD:&1E;W-O:71E+@!%<.1K
M96QP;V$@=6YI8V]D92UT:65T;V$N`$EN=F5N=&%A<FEO`$ODY&YNY"!V86QI
M;G1A(&ODY&YT96ES96MS:0!)<F%N+"!)<VQA;6EL86EN96X@=&%S879A;'1A
M`$ER86L`27)L86YT:0!-86XM<V%A<FD`17)I;&QI<VGD(%5K:V]S;7ER<VMY
M:N0`27-R865L`$QI:6MK965L;&5L87-K:6IA`$MU<G-I=F]I='4`271A;&EA
M`$IA;6%I:V$`=&%M;6EK=74`2F%P86YI`$IA<&%N:2`H25-/+3(P,C(M2E`I
M`$IE<G-E>0!*;W)D86YI80!H96ENY&MU=0!K97/D:W5U`$ME<VMI=.0`2V5S
M:VETY"!K97-K96QL90!+97-K:73D('3D>7-I;@!+97-K:73D('9A<V5M;6%L
M;&4`2V5S:VETY"!O:6ME86QL90!+87IA:W-T86X`4^1I;'ETY"!A;&MU<&5R
MY&EN96X_`$ME;FEA`$%U=&5N=&EK;VEN=&D@97#D;VYN:7-T=6D@2V5R8F5R
M;W,M<&%L=F5L:6UE;&QE+@!+97)N96P@86QO:71T96QI:F%T`$%V86EM96X@
M;'5O;G1I`$%V86EM96X@='5N;FES=&4`079A:6UE;B!P:71U=7,`079A:6UE
M;B!T>7EP<&D`079A:6UE;B!KY'ET=/8`079A:6X@;VX@:F\@:G5L:VES=&5N
M(&%V86EN=&5N('!A;'9E;&EM96QL80!,87!S970`2VER:6)A=&D`2V]R96$L
M(&1E;6]K<F%A='1I;F5N(&MA;G-A;G1A<V%V86QT82`H4&]H:F]I<RU+;W)E
M82D`2V]R96$L('1A<V%V86QT82`H171E;.0M2V]R96$I`$MO<F5A("A%54,M
M2U(I`$MU=V%I=`!+:7)G:7-T86X`07-?971T96QU`$MI96QI`$QA;W,L(&1E
M;6]K<F%A='1I;F5N(&MA;G-A;G1A<V%V86QT80!*Y&QK:6UMY&EN96X@<'5O
M;&ES:V\`161E;&QI;F5N('-A;&%S86YA;G9A:6AT;P!*Y&QK:6UMY&EN96X@
M;F5L:N1N;F5S`%#D:79I=&5T='D@=FEI;65K<VDZ`$5D96QL:6YE;B!S:7/D
MY&YK:7)J875T=6UI;F5N.B`E<P!%9&5L;&EN96X@<VESY.1N:VER:F%U='5M
M:6YE;CH@)7,L("5S`$5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI;F5N.B!%
M:2!M:6QL;VEN:V%A;@!,871V:6$`3&%K:0!!<V5T=&5L=0!*Y'3D('1Y:&KD
M:W-I(&IO<R!E:2!R975N;VIA`$QI8F%N;VX`5F%S96X`5F%S96X@;W1S86ME
M`%9A<V5N(&%R=F]T`$QE<V]T;P!487-O`$QI8F5R:6$`3&EB>6$@07)A8B!*
M86UA:&ER:7EA`$QI8VAT96YS=&%I;@!+979Y='3D('+D;G3DY`!+:7)J875D
M=2!S:7/DY&X`2V5V>71TY"!S861E='1A(&%I:V%I<VEN`$ME=GET=.0@<V%D
M971T82!M>?9H96UM:6X`2V5V>6ETY"!S861E:W5U<F]J80!+979Y='3D('-A
M9&5T=&$@:F$@;7ER<VMY:7-TY`!+979Y='3D(&QU;6ES861E='1A`$ME=GEI
M=.0@;'5M:6MU=7)O:F$`3&EM97)I:VET`$QI;FMK:0!,:6YK:VD@;W-O:71T
M86$Z`$QI;FMI=.0@<^1H:_9P;W-T:6]S;VET92!K:7)J;VET82!U=7-I('9I
M97-T:2!S:79U;&QE(&[D:WEMY'-SY`!,:6YK:70`3&EN=7@@<&EP87)E:71A
M`%9O:2!L:7-T875K<V5S<V$@;N1H9.0@:V%N<VEO;@!.Y'ETY"!T:65T;VMA
M;FYA=`!.Y'ETY"!O:&IE:61E;B!A:6AE970`3N1Y=.0@=&%U;'5T`$QI<W1A
M;BU!<FMI<W1O`$QI<W1A;BU/:&IE`$QI<W1A;BU)9`!,:7-T86XM3VUI<W1A
M:F$`3&ES=&$M=FEE<W1I`$QI<W1A;BU4:6QA=7,`3&ES=&%N+51I;&%U:W-E
M;BUL;W!E='1A;6EN96X`27-T=6YT;VIE;B!L:7-T875S(&5PY&]N;FES='5I
M.B`E<P!+Y'ET=.1J:65N(&QI<W1A=7,@97#D;VYN:7-T=6DZ("5S`$OD>71T
MY&KD=&EE=&]J96X@;N1Y='3D;6EN96X@;VX@97-T971T>2X`2VER:F%L;&ES
M=75S`$QI971T=6$`3&%D871A86XN+BX`4&%I:V%L;&ES=&$@86EK86$Z(`!,
M;VMA;&ES86%T:6\@:F$@86EK80!086EK:V$`2VER:F%U9'4@<VESY.1N`$5D
M96QL:7-E;B!S>6YK<F]N;VEN=&ES97-S:6]N(&QO:VD`2VER:F%U9'4@=6QO
M<P!+:7)J875D=2!S:7/DY&X`5&5H=.1VY'0@<VESY.1N:VER:F%U='5M:7-E
M<W-A`%-I<^3D;FMI<FIA=71U;6ES97-I(&5PY&]N;FES='5I+B!4;V1E;F[D
M:_9I<V5S=&D@:VER:F]I=&ET(';DY')I;B!KY'ET=.1JY'1U;FYU:W-E<VD@
M=&%I('-A;&%S86YA<VDN`%-I<^3D;FMI<FIA=71U;6EN96X@97#D;VYN:7-T
M=6DN`%!I=&OD('1E:W-T:0!286MK875S`$UA=&%L80!0:65N970@:W)E:6MK
M86QA:7-E="!K:7)J86EM970`4&EE;F5T(&QA=&EN86QA:7-E="!K:7)J86EM
M970`4&EE;F5T(')O;VUA;&%I<V5T(&YU;65R;W0`3'5X96UB=7)G`$M+`$U/
M5$0`35,M5$Y%1B!L:6ET971I961O<W1O(&]L:2!T>6AJY"X`5DE%4U1)`$UA
M8V%O`$UA:V5D;VYI82P@16YT:6YE;B!*=6=O<VQA=FEA;B!T87-A=F%L;&%N
M+@!-861A9V%S:V%R`%1A:6MU=7,`4^1H:_9P;W-T:0!0;W-T:6X@>6QLY'!I
M=&\`5&5E(&QI;FM?:VDN+BX`36%L87=I`$UA;&5S:6$`36%L961I:79I=`!0
M;W-T:0!-86QT80!6;VET(&AA;&QI;FYO:61A(&QI<W1A82!K871E9V]R:6]I
M<W1A+"!J;VED96X@879U;&QA('9O:70@;&EI='3DY"!A<VEO:71A('EH=&5E
M;B!S86UO:F5N(&]T<V%K:V5I9&5N(&%L;&4@:F$@;&EI='3DY"!N:6EH:6X@
M=N1R96KD+@!-87`R-"!K87)T=&$`36%P475E<W0@:V%R='1A`%9A<W1A879U
M=61E="!T86QL971E='1U+@!M86%L:7-K=74`36%R9VEN86%L:0!6;VD@;65R
M:VETY"!686YH82]5=7-I('1I971O:F$`5F]I(&UE<FMI=.0@=FEE<W1E:N0@
M*&5S:6TN(%3D<FMEY"]687-T871T=2D`36%R<VAA;&P@<V%A<F5T`$UA<G1I
M;FEQ=64`5.1S;>3D=N1T(&ME;G3D=`!-875R:71A;FEA`$UA=7)I=&EU<P!3
M=75R:6X@<V%L;&ET='D@:W)E9&EI='1I+@!3=75R:6X@<V%L;&ET='4@=FEE
M<W1I;W-I;VWDY'+D('EL:71E='1Y+@!%9&5L;&ES96X@,C0@='5N;FEN(&MO
M<FME:6X@;.1M</9T:6QA.B``161E;&QI<V5N(#8@='5N;FEN(&MO<FME:6X@
M;.1M</9T:6QA.B``4&]R=&%A;&EO<VEO:61E;B!E;FEM;>1I<VWDY'+D`%-U
M=7)I;B!S86QL:71T=2!P:71U=7,`=&]U:V]K=74`36%Y;VYE='1E`$SDY&ME
M=&EE9&4`2N1S96YE=`!-96YU;B!M=6]T;SH`66AD:7-TY"!S;VQU=`!6:65S
M=&D`5FEE<W1I;B!T87)K:7-T=7,@;VYN:7-T=6DL(&UU='1A(&%L;&5K:7)J
M;VET=&%J86X@=F%R;65N;F5T=&$@96D@=F]I='4@=&%R:VES=&%A+@!6:65S
M=&D@=F%N:&5N:2X`5FEE<W1I;B!T>7EP<&D`365T87(@<^3D`$UE=&%R+6]S
M:6\@96D@;VQE(&OD>71E='3D=FES<^0N`$UE=&%R+6]S:6\@96D@;VQE(&OD
M>71E='3D=FES<^0N(%1A<FME;6UA="!T:65D;W0@;VX@=&%L;&5T971T=2!Y
M;&SD<&ED;VX@:^1S:71E;'3D=N1K<VDN`$UE=&%R1$(@96D@;VQE('EH9&ES
M=&5T='DN`$UE=&]D:0!-971O9&EA("(E<R(@96D@;VQE(&WDY')I=&5L='D`
M365T;V1I82!E:2!O;&4@;>3D<FET96QT>2X@2W5T<W5V82!M971O9&DZ("5S
M`$UE=')I;F5N`$UE:W-I:V\`36EK<F]N97-I82P@66AD:7-T>6YE970@=F%L
M=&EO=`!+97-K96QLY`!-:6UE+71Y>7!P:0!%9&5L;&ES96X@,C0@='5N;FEN
M(&UA=&%L:6X@;.1M</9T:6QA.B``161E;&QI<V5N(#8@='5N;FEN(&UA=&%L
M:6X@;.1M</9T:6QA.B``4V%L87-A;F$@96D@;VQE('9I96SD('1A<G!E96MS
M:2!V86YH80!096EL:6MU=F$`4V5K86QA:7-E=`!014%2+7!A:V5T=&D@2%14
M4%]297%U97-T('!U=71T=74N`%!U=71T=79A="!A<V5T=7-T:65D;W-T;RX@
M4VEN=6X@<&ETY.0@=&5H9.0@87-E='5S=&EE9&]S=&\@:F]S(&AA;'5A="!K
MY'ET=.3D('3D=.0@;VAJ96QM86$N`%!U=71T=79A(&UE<W-A9V4@240N`%;D
M;'1TY&WD=/9N(%!%05(M<&%K971T:2!-86EL('!U=71T=74N`%!U=71T=79A
M('-E<W-I;VX@240N`&UA`$UO8FEI;&ESY&AK]G!O<W1I`$MO:'1A;&%I;F5N
M`$UU;VMK875K<V5N('#D:7;D;>3D<N0`375O:VMA82!54DPZ:6$`2V5R<F]I
M;@!-;VQD;W9A+"!T87-A=F%L=&$`36]N86-O`$UO;F=O;&EA`&MU=6MA=7-I
M(&IA('9U;W-I`$MU=6MA=7-I='1A:6X`36]N='-E<G)A=`!+=75N('9A:6AE
M970`4FEV:6QTY"`E9"!L]GET>6D@96YE;6WD;B!K96YT=&GD(&MU:6X@;V1O
M=&5T='4@)60N`$UA<F]K:V\`16YI;6WD:W-I('-E;&MEY.0`16YI;6WD:W-I
M('!I;'9I<W3D`$5N:6UMY&MS965N('!I;'9I<W3D(&IA('1U=6QI<W1A`$5N
M:6UMY&MS965N(&%U<FEN:V]I<W1A`%-I:7)RY"!A;&%S<.1I;@!3:6ER<N0@
M=F%S96UM86QL90!3:6ER<N0@;VEK96%L;&4`4VEI<G+D('EL]G-PY&EN`%-I
M:7)RY"!A;&%S<.1I;@!3:6ER<N0@>6SV<W#D:6X`36]S86UB:6L`36]N:71A
M<V]I;F5N(&%L87-V971O=F%L:6MK;P!-=6QT:6UA<"!)<V\M0G)I=&%N;FEA
M;B!K87)T=&$`36]N:79A;&EN=&$`2^1Y='3D:N1T=6YN=6MS96YI`$]M86X@
M:^1Y='3D:N1T=6YN=6MS96X@=&EE9&]T`$]M82!P;W)T86%L:0!/;6%N('!O
M<G1A86QI;B!A<V5T=&5L=0!->6%N;6%R("A"=7)M82D`14DL($5.('-U;W-T
M=0!.:6UI`$YA;6EB:6$`3F%U<G4`3F5P86P`06QA;FMO;6%A=`!!;&%N:V]M
M86ED96X@06YT:6QL:70`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P
M92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P
M92!34TPM<&%L=F5L:6UE;B!O<V]I=&4`3F5T<V-A<&4@=F%R;65N=&5E;B!K
M;VUM96YT=&D`3F5T<V-A<&4@=F%R;65N=&5E;B!T>7EP<&D`5F5R:VMO`$5I
M(&MO<VMA86X`575S:2U+86QE9&]N:6$`575S:2!L=6]K:71U<P!5=7-I:W5U
M`%5U<VD@:^1Y='3D:N1T=6YN=7,@*'9A<&%A96AT;VEN96XI`%5U<VDM4V5E
M;&%N=&D`575S:2!S86QA<V%N80!5=7-I('-A;&%S86YA('9A;FAE;F5E("5X
M+@!!;G1A;6%S:2!U=61E="!S86QA<V%N870@96EVY'0@=.1S;>3D+@!5=7-I
M(&EK:W5N82`H7V)L86YK*0!5=71I<V5T`$ME<VMU<W1E;'5R>6AMY'0`4V5U
M<F%A=F$`4V5U<F%A=F%T(#0@=F%I:&5T=&$`4V5U<F%A=F%T(&%S971U:W-E
M=`!3975R86%V83X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`6?8`3FEU90!%
M:0!!<V5T=7-T:65T;VIA(&5I(&]L92!S86%T879I;&QA+"!J;W-T82!V;VES
M:2!NY'ET=.3D(&5R;V%V86ES=75K<VEA+@!%:2!O;&4@<V%A=&%V:6QL82!S
M=75N;FET96QM86$@25-/(&QE=GEK=79A=&EE9&]S=&]J96X@=&5K96UI<V5K
M<VDN`$5I(&5RY&UA;&QI82X`3W-I;W1A(&5I(&]L92!P>7ED971Y<W/D('!A
M:6MA<W-A+@!+86QE;G1E<FEN(&YI;67D(&5I(&]L92!A;FYE='1U($U#04PM
M875T96YT:6MO:6YN:6QL92X`16D@;75U=&]S=&$N`$%L:71A<V]J82!E:2!V
M;VD@;&ESY'3D('3D;&QE(&]I:V5U9&5L;&4N`$%S971U:W-I82!E:2!L]GET
M>6YY="`E<SIL;&4N`$%S971U:W-I82!E:2!L]GET>6YY="!&5%`@5D93.FQL
M92X`07-E='5K<VEA(&5I(&SV>71Y;GET(%-13"!61E,Z;&QE+@!!<V5T=6MS
M:6$@96D@;/9Y='EN>70@4U%,+49I;&4@5D93.FQL92X`2W)E9&EI=&ET(&QO
M<'!U+@!+;VAD971T82!E:2!A;FYE='1U+@!%:2!T=6]T=2!A:6YU='1A:V%A
M;B!T:65D;W-T;V$`26MO;F5I=&$@96D@;/9Y='EN>70N`%!A:6MK86$@96D@
M;VQE(&%S971E='1U+@!086EK:V%A(&5I(&]L92!A;FYE='1U+@!%:2!A;FYE
M='1U('9I97-T:>0N`$YI;67D(&5I(&]L;'5T(&%N;F5T='4N`$QU:W5MY.1R
MY.0@96D@;VQL=70@86YN971T=2X`16D@;&]U:VMA879A="!M:65T96QA=7-E
M970`4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($A45%`M875T96YT:6MO:6YN
M:7-S82X`4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($E-05`M875T96YT:6MO
M:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($ME<F)E<F]S+6%U
M=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!,;V=I
M;B!A=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE(&%N;F5T='4@
M4$%34U=$+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@86YN
M971T=2!334(M875T96YT:6MO:6YN:7-S82X`4&]L:W5A($]P96Y34TP@:V]M
M96YT;V]N(&5I(&]L92!MY.1R:71E;'1Y+B!/<&5N4U-,('!I=.3D(&]L;&$@
M:^1Y=&5T=.1V:7-SY"!J;W,@:^1S:71E;&SDY&X@4$M#4R`Q,B!D871A82X`
M16D@<VESY.1N:VER:F%U='5M:7-P>7EN=/9JY"!J;VYO<W-A+@!+:6EN=&GV
M=.0@96D@;VQE(&%S971E='1U`$5I('/DY&YT]FKD`$5R;W1I;G1A(&5I(&]L
M92!MY.1R:71E;'1Y+@!%:2!R975N;VIA`$5I(&SV>71Y;GET('1I961O<W1O
M80!6Y&QI;75I<W1I;&QE(&5I(&]L92!VY&QI86EK86ES:&%K96UI<W1O82X`
M2^1Y='3D:N1T=6YN=7-T82!T86D@<V%L87-A;F%A(&5I(&SD:&5T971T>2X`
M2V%I:VMI('!A;&%U='5N=70@6$U,+61A=&$@;VQI(&5PY&ME;'!O80!%:2!A
M<G9O:F$`5F5R<VEO=&EE=&]J82!E:2!L]GET>6YY="!A;&MU<&5RY&ES:73D
M(&%S971U:W-I<W1A+B!3:6YU;B!P:73DY"!T96ADY"!A<V5T=6MS970@=75D
M97-T86%N+@!697)S:6]T:65T;VIA(&5I(&SV>71Y;GET(&%S971U:W-I<W1A
M+B!3:6YU;B!P:73DY"!T96ADY"!A<V5T=6MS970@=75D97-T86%N+@!%:2!M
M:73DY&X`16D@;6ETY.1N("A+Y'ETY"!I;7!L:7-I:71T:7-TY"D`3&%P<&DO
M4&]H:F]I<VUA870O17-K:6UO("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!S86%R
M970`4&]H:F]I;F5N('!A;&QO;G!U;VQI<VMO`%!O:&IO:7-E="!-87)I86%N
M:65N('-A87)E=`!.;W)J80!%:2!JY&QK965N`$5I(&5N;F5N`$5I(&]L92!H
M86ME;6ES=&\`16D@;VQE('1O=&5U=&5T='4N`$5I(&%S971E='1U`$5I('1U
M971T=2X`375I<W1I:6YP86YO=`!%:2!M:73DY&X@<V5L871T879A82P@<&%L
M86$@=&%K86ES:6XN`&UA<G)A<VMU=0!,=6MU;>3D<N0`365R:VMI96X@;'5K
M=6WDY'+D`%-A<F%K:V5I9&5N(&QU:W5MY.1RY`!2:79I96X@;'5K=6WDY'+D
M`$IA:V5L=6QI<W1A;B!N=6UE<F]I=&$@96D@;VQE(&WDY')I=&5L='D@<.1I
M=FET971TY';D:W-I+@!/2P!/8FIE:W1I`$]B:F5K=&EN(&QU;VIA`$]K=&%A
M;&D`;&]K86MU=0!,;W5K:V%A=G5U<W-U;V1A=&EN`%1O:6UI<W1O`%5U<VD@
M<V%L87-A;F$@96D@<V%A(&]L;&$@<V%M82!K=6EN(&YY:WEI;F5N('-A;&%S
M86YA<VDN`%9A;FAA('-A;&%S86YA`%9A;FAA('-A;&%S86YA(&]N(';DY')I
M;BX`3VUA;@!686EN($E-05`M<&%L=F5L:6UE="!T=6ME=F%T(&IA971T=6IA
M(&MA;G-I;VET82X`5F%I;B!L;W5K:V%A=F%T(&UI971E;&%U<V5E=`!6;VET
M(&QA:71T86$@=F%I;B!Y:&1E;B!SY&AK]G!O<W1I;W-O:71T965N+@!686EN
M(&]M:7-T86IA('1A:2!JY')J97-T96QMY&X@>6QLY'!I=.1JY"!V;VD@;75U
M='1A82!J86MO:F5N(&]M:7-T86II82!T86D@;VEK975K<VEA`$%V86$@=75D
M97-S82!I:VMU;F%S<V$`3W!E;E-33"!V:7)H93H@5&EE=&]J82!E:2!S86%T
M=2!E<VEL;&4@86QL96MI<FIO:71E='5S=&$@4R]-24U%+6]S87-T82X`079A
M82!TY&WD;B!L:6YK:6X@=75D97-S82!I:VMU;F%S<V$`2^1Y='3V:N1R:F5S
M=&5L;>0`07-E='5K<V5T`$%S971U:W-E="`E<SIL;&4`2N1R:F5S=&5T='D@
M;&ES=&$`3W)G86YI<V%A=&EO`$]R9V%N:7-A871I;WEK<VEK:_8`3W)G86YI
M<V]I;G1I`$%L:W5P97+D:6YE;B!O:&IE;&UA;B!M86QL:0!!;&MU<&5RY&ES
M970@;6%L;&ET("5S.G-SY#H`375U`$UU=70@=&EE9&]T`$]M:7-T86IA;B!O
M:6ME=61E=`!004TM875T96YT:6MO:6YT:6$@96D@;VQE(&OD>71E='3D=FES
M<^0N`%!%05(Z.DUA:6P@=&%U<W1A:N1R:F5S=&5L;>0`1&EG:71A86QI;F5N
M(%!'4"UA;&QE:VER:F]I='5S`%!'4"US86QA='1U82!T:65T;V$`2G5L:VEN
M96X@4$=0+6%V86EN`%!'4"UA;&QE:VER:F]I=&5T='5A(&IA('-A;&%T='5A
M('1I971O80!02%`M:V]O9&D`4$A0+6MO;65N=&]T=6QK:VD`4$T@:V5V>71T
MY"!S861E='1A`%!-('-A9&4`4$T@:W5U<F]J80!032!L=6UI`%!-(&QU;6ES
M871E:71A`%!-(&QU;6D`4$T@=6MK;W-M>7)S:WEJY`!03U-)6"UL86%J96YN
M=6MS970@<'5U='1U=F%T`%!?2%`M:V]M96YT;W1U;&MK:0!4Y'ET90!086MI
M<W1A;@!086QA=0!086QE<W1I:6YA("AM:65H:71E='1Y(&%L=64I`%!A;F%M
M80!087!U82!5=7-I+4=U:6YE80!087)A9W5A>0!/<VET=&%I;B!P:6QV:7-T
MY`!386QA<V%N80!386QA<V%N86X@=F%I:'1O(&]N;FES='5I+@!6Y.1RY"!S
M86QA<V%N80!386QA<V%N86$@=&%R=FET86%N(%)!1$E54RUA=71E;G1I:V]I
M;G1I:6XN`%-A;&%S86YA('9A<FUI<W1U:W-E;&QA`%-A;&%S86YA.@!386QA
M<V%N83H@`%-A;&%S86YO:F5N('!I=.3D(&]L;&$@<V%M870N`$QI:73D`$QI
M:73D(&QE:6ME</9Y9.1L=.0`4&]L:W4`2F]N;W-S82!O;&5V870@<VESY.1N
M:VER:F%U='5M:7-P>7EN;O9T.@!):&UI<V5T`%!R;W-E;G1T:0!3=6]R:71A
M('EL;.1P:71O=&]I;65N<&ET965T`%-U;W)I=&$@>6QLY'!I=&]T;VEM96YP
M:71E970@<VESY.1N:VER:F%U='5M:7-E;B!Y:'1E>61E<W/D+@!/:6ME=7,`
M3VEK975T=&$@(B5S(B!E:2!P;VES=&5T='4N`$OD>71T]B!K:65L;&5T='D`
M3VEK975D970`3VEK975K<VEE;B!Y;&SD<&ET;P!/;6%T('1I961O=`!097)U
M`$QE;6UI:VET`$9I;&EP<&EI;FET`%!U:&5L:6X`5F%L;VMU=F%T`%!I=&-A
M:7)N`%!I:W-E;&D`2VQI<V5E=`!.87!S875T82!J;W1A:6X@<V]L=6$`5F%R
M;6ES=&$@971TY"!H86QU870@<&]I<W1A82!TY&WD;B!E;&5M96YT:6XZ`%9A
M<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T86$@;&EN:VET>6MS96X@=.1HY&X@
M96QE;65N='1I:6XN`$%N;F$@:W5U:V%U<VD@:F$@=G5O<VDN`$%N;F$@;FEM
M:2!U=61E;&QE(&QU;VMI='5K<V5L;&4Z`$%N;F$@;VEK96$@25`M;W-O:71E
M+@!!;FYA(&]I:V5A('#D:7;D;>3D<N0[(%1A<FMI<W1A('#D:79I96X@;'5K
M=6WDY'+D(&MU=6MA=61E<W-A+@!!;FYA(&%I:V$@;VEK96%S<V$@;75O9&]S
M<V$N`$%N;F$@;'EH>70@:W5V875S(&]N9V5L;6%S=&$N`$%N;F$@:^1Y='3D
M:N1T=6YN=6MS97-I(&IA('-A;&%S86YA<VD`3'5E('-E=7)A879A('1E:W-T
M:2X@4VEN=6X@4$E4Q,0@<W5O<W1U82!KY'ET=/9E:'1O:6AI;B!V;VED86MS
M97-I(&OD>71TY.0@:N1R:F5S=&5L;>3D+@!!;FYA(&YI;6D@=75D96QL92!L
M=6]K:71U:W-E;&QE.@!0=6]L80!0;VQI=&EI:VMA`$MY<V5L>70`4&]R='5G
M86QI`%3D;>1N(&MU=F%N('!A:6MK80!4Y&WD;B!T875L=6MO;B!P86EK:V$`
M5F]I(&SD:&5T=.3D('9I97-T96KD(&MA;G-I;V]N("AE:2!K;W-K92!)34%0
M('EH=&5Y:W-IY"D`4V%D96WDY'+D(&5D96QL:7-I;&QE("5S('1U;FYI;&QE
M.B``2&%I:'1U=G5U<R`\8G(@+SYT;V1E;F[D:_9I<WEY<P!0<F5F<U]L9&%P
M.B!487)V:71T879A82!,1$%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!0
M<F5F<U]S97-S:6]N.B!487)V:71T879A82!S97-S:6]N+6QA86IE;FYU<W1A
M(&5I(&SV>71Y;GET`$EL;6%N<&%I;F4`26QM86YP86EN92!M97)E;G!I;FYA
M<W-A.B``26QM86YP86EN93H@`$5S:6MA='-E;'4`17-I:V%T<V5L92!K=79A
M('5U9&5S<V$@:6MK=6YA<W-A`$5D96QL:7-E="!A<V5T=6MS970`5'5L;W-T
M82!D;VMU;65N='1I`%-A;&%I;F5N(&%V86EN`$]N9V5L;6$`3VYG96QM86X@
M:W5V875S`%!R;VIE:W1I=`!+96AO='1E96X@=&5K<W1I`$IU;&MI;F5N(&%V
M86EN`$IU;&MI<V5N(&%V86EM96X@86QG;W)I=&UI`$IU;&MI<V5N(&%V86EM
M96X@=&EE9&]T`$IU;&MI<V5N+W-A;&%I<V5N(&%V86EN<&%R:6X@;'5O;G1I
M(&5PY&]N;FES='5I+@!0=65R=&\@4FEC;P!6;VD@='5H;W1A('!O:7-T971T
M=6IA('9I97-T96KD`%%A=&%R`$MY<V5L90!+:6EN=&GV`%)302!*=6QK:6YE
M;B!A=F%I;B`H)60@8FET=&GD*0!2861I;W!A:6YI:V4`4V%D90!3861E='1A
M(&%I:V%I<VEN`%-A9&5T=&$@;7GV:.3D;@!3861E:W5U<F\`5F5S:2!J82!L
M=6UI`%9E9&5S=.0@;'5M965N`%-A='5N;F%I;F5N(&UI971E;&%U<V4`4W5H
M9&4`3'5K=0!6;VD@;'5K96$@=FEE<W1E:N0`4&]I<W1E=&%A;FMO("5S/R!4
MY'3D('1O:6UI;G1O82!E:2!V;VD@<&5R=75T=&%A+@!0;VES=&5T86%N:V\@
M=&EE9&]T(&OD>71TY&KD<W3D("5S/R!4Y'3D('1O:6UI;G1O82!E:2!V;VD@
M<&5R=75T=&%A+@!4964@;75U=&]K<V5T('5U9&5S=&%A;@!0Y&EV:73D`%#D
M:7;D="!D>6YA86UI<V5T('9A;&EK:V]E;&5M96YT:70Z`%#D:79I=.0@<&]R
M=&%A;&ENY&MY;>3D.@!3Y.1N;O9L;&EN96X@;&%U<V5K90!296QA871I;W-E
M;&%I;@!,871A82!U=61E;&QE96X`375I<W1I:6YP86YO=`!%=.1P86QV96QI
M;65T`$5TY'!A;'9E;'5N(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%!O:7-T80!0;VES=&$@;W-I;P!0;VES=&$@<V%R86ME`%!O:7-T
M82!M=6]T;VEL=0!0;VES=&$@<&%R:0!0;VES=&$@=&%L;&5T971T=2!S:W)I
M<'1I('!A;'9E;&EM96X@=N1L:6%I:V%I<VAA:V5M:7-T;W-T82X`4&]I<W1A
M`%!O:7-T82!TY&WD(&YO;V1I(&1O:W5M96YT:7-T80!0;VES=&$@:^1Y='3D
M:N0`4&]I<W1A(&OD>71TY&KD.B`E<P!0>7EN=/;V;B!E:2!V;VET=2!V87-T
M871A+B!6:7)H96MO;V1I.B``4'EY9&5T='GD('!A;'9E;'5A(&5I(&SV>71Y
M;GET+@!487)V:71T879A82`B)7,B+71I971O82!E:2!O;&QU="!MY.1R:71E
M;'1Y("5S(&%S971U:W-I<W-A+@!487)V:71T879A82`B)7,B+71I971O82!E
M:2!O;&QU="!MY.1R:71E;'1Y(%9&4R!A<V5T=6MS:7-S82X`5&%R=FET=&%V
M86$@(B5S(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2!A<V5T=6MS:7-S
M82X`4&%K;VQL:6YE;B!K96YT=.0`5'EH:F5N;N0`5'EH:F5N;N0@<V%L87-A
M;F$`5'EH:F5N;N0@<V%L87-A;F%S:0!086QA=71A(&5D96QL:6YE;B!K>7-E
M;'D`5'5L;VMS970`4&%L86$@87-E='5K<VEI;@!686AV:7-T82!U=7-I('-A
M;&%S86YA`%)E=6YI;VX`4&%L875T82!A<V5T=6MS970`4FEC:"!497AT($5D
M:71O<FEN(&%S971U:W-E=`!!<G9O:71U:W-E=`!/:6ME80!/:6ME82!O='-A
M:V4`3VEK96$@87)V;W0`4FEV:5]N('1I961O="XN+@!2;V]L:0!2;VUA;FEA
M`$ODY&YNY"`Q.#``2^3D;F[D('9A<W1A<.1I=N3D;@!+Y.1N;N0@;7GV=.1P
MY&EVY.1N`%)I=FEN('1I961O=`!2:79I;B!T:65D;W0`4FEV:70Z`%9I:79O
M:71I;@!6:6EV;VET:6X@;N1K>7D@:V%I:VMI96X@<FEV:65N(&IA('-A<F%K
M:V5I9&5N(';D;&EL;.0`5FEI=F]I=&EN(&[D:WEY('9A:6X@<V%R86MK96ED
M96X@=N1L:6QLY`!6:6EV;VET:6X@;N1K>7D@=F%I;B!R:79I96X@=N1L:6QL
MY`!3=6]R:71A`%9E;N1JY&X@1F5D97)A=&EI=FEN96X@=&%S879A;'1A`%)U
M86YD80!3+TU)344@:W)Y<'1O9W)A869I;F5N(&%L;&5K:7)J;VET=7,`4R]-
M24U%('-A;&%T='4@=FEE<W1I`%-!4TPM875T96YT:6MO:6YT:2!E:2!O;&4@
M:^1Y=&5T=.1V:7-SY"X`4TU3(%1E:W-T:79I97-T:70`4U%,+6MO;65N=&]T
M=6QK:VD`4U%,+6QA=7-E(&%R=F]J96X@:&%K96UI<V5E;@!34T@`3TY.25-4
M54D`4U]13"UK;VUE;G1O='5L:VMI`&QA`%-A:6YT($AE;&5N80!386EN="!+
M:71T<R!J82!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@:F$@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!J82!'<F5N861I:6YI=`!386UA86X@:V5H
M>6MS965N("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!J82!0
M<FEN8VEP90!3871E;&QI:71T:2!P86QV96QU;G1A<FIO86IA`%-A=61I82!!
M<F%B:6$`5&%L;&5T80!486QL971A("(E<R(`5&%L;&5T82`E<P!486QL971A
M(&%S971U:W-E=`!486QL971A(&QU;V1U="!A<V5T=6MS970@4$A0+7-K<FEP
M=&ENY"!P86QV96QI;65S:2!VY&QI86EK86ES:&%K96UI<W1O;VXN(`!486QL
M971E='1I:6X@)7,Z;B!A<V5T=6MS970N`$%S971U<W1E;B!PY&EV:71Y<W-K
M<FEP=&D@;VX@=&%L;&5T971T=2!P86EK:V%A;CH@(B5S(BX`2&%J86YA:7-I
M82!U:VMO<VUY<G-K>6KD`%1I961E`$AA:W4`2&%K=6MO;F5E=`!686QI='-E
M('1I961O<W1O=`!686QI='-E('#D:7;D;>3D<N0`5F%L:71S92!L:7/D='3D
M=N0@<GEH;>0`5F%L:71S92!U=7-I(&]M:7-T86IA`%9A;&ET<V4@<&%L=F5L
M:6X`5F%L:71S92!L:7/D='3D=N0@:^1Y='3D:N0`5F%L:71S92!K86EK:VD`
M5F%L:71S92!K86EK:VD@<.1I=N1MY.1RY&MO;7!O;F5N=&ET`%9A;&ET<V4@
M;V)J96MT:0!4>6AJ96YNY"!V86QI;G1A`%9A;&ET<V4@=&%R=FET=&%V870@
M;65R:VET(&%L;&$@;VQE=FES=&$@=F%L:6MO:7-T82X@5F]I="!S96X@:N1L
M:V5E;B!K;W!I;VED82!J82!L:6ET=.3D(&UE<FMI="!T96MS=&EI<VDN`%9A
M;&ET<V4@<.1I=N1Y:W-E;B!E<F]T:6YM97)K:VDZ`%9A;&ET<V4@<.1I=N1Y
M:W-E;B!E<VET>7-T87!A.@!686QI='-E(&UU=71E='1A=F$@<')O9FEI;&DZ
M`%9A;&ET<V4@:V5L;&]N86IA;B!E<F]T:6YM97)K:VDZ`%9A;&ET<V4@86IA
M;B!E<VET>7-T87!A.@!686QI='-E(&MA:W-I('EH=&5E;G-O<&EV86$@:V5N
M='3DY"X`5F%L:71S92!VY')I=&5E;6$N`%9A;&ET<V4@:^1Y=&5T=.1VY"!K
M:65L:3H`3.1H973D(&]N9V5L;6%V:65S=&D`3.1H973D(%--4P!396YE9V%L
M`%1U;FYI<W1I;CH@`'-Y>7-K=74`4V5R8FEA(&IA($UO;G1E;F5G<F\`4V%R
M:F%N=6UE<F\`4&%L=F5L:6UE;B!T:65D;W0@;W9A="!VY.1R:>0@=&%I(&5I
M=N1T(&]L92!KY'ET971TY'9I<W/D+@!)<W1U;G1O:F5N(&AA;&QI;G1A`%-E
M<W-I;VX@240@;VX@=F%N:&5N='5N=70N`$ES='5N;F]T`$%S971A`%-A;&%S
M86YA;B!R97-E=&]I;G1I:6X@;&EI='1Y=FGD(&%S971U:W-I82P@:F]S(&IO
M<VMU<R!U;F]H9&%T('-A;&%S86YA<VDN`%9O:70@87-E='1A82!U;&MO:7-T
M96X@<&%L=F5L:6UI96X@87-E='5K<V5T+"!J;VET82!H86QU870@:^1Y='3D
MY"!P;W)T86%L:7-S82X`5F]I="!A<V5T=&%A(&OD>71E='3D=N1N(&MI96QE
M;BP@86EK879Y]FAY:VME96X@:F$@;75I=&$@<.1I=N1MY.1RY&%S971U:W-I
M82X`5F]I="!A<V5T=&%A(&%L;VET=7-O:&IE;&UA;BP@=N1R:71E96UA;BP@
M;N1K>6WD;B!PY&EV:71Y:W-E;B!J82!M=6ET82!NY&MY;>3D;B!L:6ET='EV
M:>0@87-E='5K<VEA+@!!<V5N;G5S`$%S96YN=6MS96X@<.1I=FET>7-S:W)I
M<'1I(&]N('-A871A=FEL;&$`57-E870@<&%I:V%T('-O<&EV870@86YN971T
M=75N('!A<F%M971R:6EN.B``4V5Y8VAE;&QI=`!/<W1O:W-E=`!,>6AY="!K
M=79A=7,Z`$%S971E=&$@<&EK879A;&EN=&%NY'!PY&EM970@=7-E:6UM:6QL
M92!L:6YK96EL;&4N`$[D>73D`$[D>73D(&5R;V%V86ES=75D970@87-E='5K
M<VEE;B!T86QL971E='5S<V$@:F$@=75D97-S82!J=75R:2!M=6]K871U<W-A
M('9E<G-I;W-S82X`3N1Y=.0@961E;&QI<V5N('-I<^3D;FMI<FIA=71U;6ES
M96X@<.1I=N1Y<RX`3N1Y=.0@87-E='5S('!I=.3D:W-E<VD@86QK=7!E<N1I
M<V5N`$[D>73D('9A;&ET<VEN`$[D>73D('1A=6QU:VMO=&]I;6EN;F]T('9A
M;&EK:V\N`$[D>73D('9A<V5M;6%L;&$@)7,@=F%L:6MK;RX`3N1Y=.0@=&%U
M;'5K;VX@<V]L=6X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@=&%U;'5K;VX@=&EE
M9&]T(&1I86QO9VD`3N1Y=.0@=&%U;'5K;VX@<FEV:6X@=&EE9&]T(&1I86QO
M9VD`3N1Y=.0@:W5V86X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@='5O;G1I`%-A
M=&5I=&$`4V%T96ET82!A:6MA:7-I;@!3871E:71A(&UY]FAE;6UI;@!3871E
M:71A(&SD:&5T='EV:6QL80!0:65N96YNY`!0:65N96YNY"!T86D@<VEI<G+D
M('9I97)E:7-IY"!O<VEO:71A+"!J;W1T82!N92!E:7;D="!O;&4@=&EE;&SD
M`%-I97)R82!,96]N90!+:7)J875D=0!!;&QE:VER:F]I='5S`$%L;&5K:7)J
M;VET=6MS96X@86QG;W)I=&UI`%-I;F=A<&]R90!+;VMO`$]H:71A('EL;.1P
M:71O=&5H=.1VY'0`4VQO=F%K:6$`4VQO=F5N:6$`3'5M:0!,=6UI<V%D971T
M80!,=6UI<V%T96ET80!,=6UI<V%T96ET82!A:6MA:7-I;@!,=6UI<V%T96ET
M82!M>?9HY.1N`$QU;65N('-Y=GEY<SH@`$QU;65N(&WDY'+D('9E=&5NY#H@
M`%-A;&]M;VX@<V%A<F5T`%-O;6%L:6$`3&%U;'5T(&IA(%)U;F]U<P!*Y')J
M97-T>6MS96X@<W5U;FYA;B!V86QI;G1A`$SD:&1E;W-O:71E`$5T96SD+4%F
M<FEK:V$`171E;.0M175R;V]P<&$@*$E33RTX.#4Y+3,I`$5T96SD+4=E;W)G
M:6$@:F$@971E;.1I<V5T(%-A;F1W:6-H('-A87)E=`!%=&5LY&EN96X@<&%L
M;&]N<'5O;&ES:V\`5N1L:2!V:65R96ES970@<V]L=6IE;B!VY&QI<W/D`%;D
M;&D@<V]L=6X@;&5I<.1T96MS=&EN(&IA(')E=6YA;B!VY&QI<W/D(`!6Y&QI
M`%;D;&D`5N1L:2!J82!TY'ET90!%<W!A;FIA`%)O<VMA<&]S=&D`17)I:V]I
M<VUE<FMK:65N('-Y]G1T]@!*86$@<V]L=0!*86$@<V%R86ME`$IA82!R:79I
M`%5R:&5I;'4`4W)I($QA;FMA`%-T86YD87)D:0!3=&%R(%1R96L`06QK86UI
M<W9U;W-I`$SDY&YI('1A:2!A;'5E`%1I;&$`5&%L;&5N;G5S;75O=&\`2V%T
M=6]S;VET90!,Y'!I;'GV;G1I`$UE<FMK:6IO;F]L:7-T80!0;VES=&$@=&]I
M;6EA;'5E(&]S;VET=&5E<W1A`%1Y>6QI(%M#4U-=`'-U`$%L:6AA:V5M:7-T
M;V$@(B5S(B!E:2!L]GET>6YY="X`3W1S:6MK;P!,Y&AE=.0`3.1H971E='1I
M:6X@(B5S(CIN(&QI<^1Y<W!Y>6YT]BX@170@=F]I(&MI<FIA=71U82!S:7/D
MY&X@96YN96X@:W5I;B!P>7EN=/9S:2!O;B!KY'-I=&5L='D@:F$@:'EVY&MS
M>71T>2X`06QI:VER:F]I='5S`$]N;FES='5I`"(E<R(Z(&QI<^3D;6EN96X@
M:N1R:F5S=&5L;>3D;B!O;FYI<W1U:2X`2^1Y='3D:N1N("(E<R(@:^1Y='3D
M:N1T:65T;VIE;B!P;VES=&%M:6YE;B!JY')J97-T96QMY'-TY"!O;FYI<W1U
M:2X`(B5S(B!P;VES=&5T=&EI;B!O;FYI<W1U;F5E<W1I+@`B)7,B.B!O;FYI
M<W1U='1I:6X@<&]I<W1A;6%A;B!JY')J97-T96QMY'-TY"X`4&%L871T:6EN
M(&]N;FES='5N965S=&D@=F%N:&]I:&EN(&%S971U:W-I:6XN($QA=&%A('-I
M=G4@=75D97-T86%N(&[D:&3D:W-E<VD@;75U=&]K<V5T+@!486QL96YN971T
M:6EN(&%S971U:W-I96X@=F%R;75U<VMO<&EO+@!486QL96YN971T:6EN(&%S
M971U:W-I96X@=F%R;75U<VMO<&EO("5S+@`G)7,G.B!PY&EV:71Y<R!O;FYI
M<W1U:2X`)7,Z;B!K:7)J;VET=&%M:6YE;B!O;FYI<W1U:2X`4W5D86X`66AT
M965N=F5T;P!!=7)I;F=O;FYO=7-U`$%U<FEN9V]N;&%S:W4`075R:6YK;VEN
M96X`075R:6YG;VYN;W5S=0!!=7)I;FMO(&YO=7-E92]L87-K964`075R:6YG
M;VYN;W5S=3H@`$%U<FEN9V]N;&%S:W4`075R:6YG;VYL87-K=3H@`%#DY&QL
M96MI<FIO:71U<P!4=6MI`%-U<FEN86T`4W5K=6YI;6D`2'5I<'!U=G5O<F5T
M(&IA($IA;B!-87EE;@!3=V%Z:6UA80!2=6]T<VD`4W9E:71S:0!3>6YC(&QO
M:VD@<&]I<W1E='1U`%-Y;F--3`!3>6YT86MS:79I<FAE(&AA:W5T97)M96ES
M<^0`4WEY<FEA+"!A<F%B:71A<V%V86QT80!5:VMO<VUY<G-K>0!5:VMO<VUY
M<G-K>6KD(&IA('1U=6QI<W1A`%5K:V]S;7ER<VMY=`!5:VMO<VUY<G-K>6KD
M(&%I:V%I<VEN`%135BUT:65D;W-T;P!4875L=6MK;P!4875L=6MO;B!T:65D
M;W0`5&%U;'5K;VX@87-E='5K<V5T`%1A=6QU:V]N('1I961O=`!486EW86X`
M5&%I=V%N+"!+:6EN86X@;6%A:W5N=&$`5&%D>FEK:7-T86X`5&%N>F%N:6$L
M(%EH9&ES='EN>70@=&%S879A;'1A`$MO:&1E.@!496ATY';D=`!0=6AE;&EN
M;G5M97)O`$SD;7#V=&EL82!E9&5L;&ES96QL92!T=6YN:6QL93H@`$SD;7#V
M=&EL80!,Y&UP]G1I;&$Z(`!,Y&UP]G1I;&$\8G(@+SXH)7-(:25S+R5S3&\E
M<RD@)F1E9SLE<P!-86QL:6$@(B5S(B!E:2!L]GET>6YY="X`36%L;&EE;B!H
M86QL:6YT80!496MS=&D`5F%I;B!T96MS=&D`5&5K<W1I;B!T87-A=7,`5&5K
M<W1I=&]P`'1O`%1H86D@*%1)4RTV,C`I`%1H86EM86$`1E10+6QI<^1T;VEM
M:6YT;R!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`2&ES=&]R>2!JY')J97-T96QM
MY"!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`2&]R9&4O2V]L86(@:6YT96=R;VEN
M=&EM;V]T=&]R:2!E:2!T=64@(B5S(@!)35-0(&QO:VEA(&5I('9O:71U(&%L
M=7-T86$N`$UA:6YT96YA;F-E.CH@+6QU;VMA;B!L871A86UI;F5N(&5PY&]N
M;FES='5I`$%S971U:W-E="!I:VMU;F$@;VX@<W5L:F5T='4N(%!O:7-T=71A
M86XN`%EL;.1P:61O;B!P:73DY"!O='1A82!KY'ET=/;V;B!P>7-Y=N0@=&%L
M;&5T=7-T>7EP<&D@4&5R;6ES<VEO;BP@:F]S(&AA;'5A="!KY'ET=.3D(&YI
M:73D+@!686EN(&%L87!U;VQI`$-O;G1A8W0@:60@;G5M97)O82!E:2!O;&4@
M;>3D<FET96QT>2P@;VX@='EH:N0@=&%I(&5I(&SV>71Y;GET('1I971O:V%N
M;F%S=&$N`%EH=&5Y<W1I961O="!L:7/D='1I:6X@;VYN:7-T=6YE97-T:2!O
M<V]I=&5K:7)J86%S:2X`5FEE<W1I;B!A;&QE:VER:F]I='5K<V5N('1A<FMI
M<W1A;6ES965N('1A<G9I=&%A;B!E<FEL;&EN96X@4$=0+6%L;&5K:7)J;VET
M=7-L;VAK;RX`2F%K96QU;&ES=&%N($E$(&5I(&]L;'5T(&WDY')I=&5L='DL
M(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY="!T:65T;VMA;FYA<W1A+@!*86ME
M;'5L:7-T86$@96D@;VQL=70@;>3D<FET96QT>2X`4V%L875S=&]I;6EN;F]N
M(&OD>71T]B!V86%T:2!S86QA='1U82!75U<M>6AT97ET=.0N`%1I961O<W1O
M<W-A("5S('!I=.1I<VD@;VQL82`E<R!A<V5T=7,N`%1I961O<W1O<W-A("5S
M('!I=.1I<VD@;VQL82!J;VET86MI;B`E<R!A<V5T=6MS:6$N`%1I961O<W1O
M82!E:2!V;VED82!K;W!I;VED82!I='-E;G/D('#DY&QL92X`5&EE9&]S=&\@
M;VQI('1Y:&KD+@!3975R86%V87-S82!O;B!O='-I:VMO=&EE9&]T('3D<W3D
M(&UE<W-A9V4O<F9C.#(R("UV:65S=&ES=.0N`$MO:V]R=75D=6X@;N1Y='3V
M=&EL82!A:6AE=71T86$@;VYG96QM:6$@:F]I;&QA:VEN($EN=&5R;F5T($5X
M<&QO<F5R('-E;&%I;65N(&OD>71TY&II;&SD+B!686QI=&5T=&%V87-T:2!K
M>7-E:6YE;B!S96QA:6X@<VESY&QTY.0@<&EI<G1E:73D(&IA('9I<FAE:73D
M(&IO:6AI;B!E:2!O;&4@;/9Y='EN>70@:V]R:F%U<W1A('1A:2!K96EN;V$@
M:VEE<G3DY"!O;F=E;&UA+B!(=6]M86%T:&%N(&5T=.0@:F]S(&OD>73D="!T
MY'3D(&[D>71T]G1I;&%A(&IA($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;G1A
M+"!N:6EN(&[D>71T]B!S86%T=&%A(&UE;F[D('-E:V%I<VEN+"!J;W1K=70@
M=&]I;6EN;F]T(&5I=N1T('1O:6UI('1A:2!S96QA:6X@<V%A='1A82!K86%T
M=6$N($IO<R!KY'ETY'0@5VEN9&]W<R`Y>"!T86D@344@=F5R<VEO=&$L(&YI
M:6X@;VX@;6%H9&]L;&ES=&$@971TY"!KY'ET=/9JY')J97-T96QMY"!K86%T
M=74@;G,N("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G("UV:7)H965S965N
M(&IA('-I;G5N('!I=.3D(&OD>6YN:7-TY.0@:V]N92!U=61E<W1A86XN7&Y<
M;B!-=6ES=&$@971TY"!S:6YU82!O;B!V87)O:71E='1U+B!.87!S875T82!/
M2RUN87!P=6QA82!J;W,@:&%L=6%T(&MO:V5I;&QE(&5D:71O<FEN(&MO:V]R
M=75T=2!NY'ET=/9T:6QA82X`4&]I<W1E='1I:6X@<')O9FEI;&D@(B5S(BX`
M5F%I;B!V87-E;B!P=6]L:0!';G501R!O:&IE;&UA;B!S:6IA:6YT:2!P:73D
MY"!MY.1R:71E;&SD($-R>7!T7W!G<#HZ("UL=6]K87-S82X`5FEE<W1I(&SD
M:&5T971T>2`E<R!V87-T86%N;W1T86IA;&QE("5S(&]T<VEK:V]N82`B)7,B
M(&]N(&[D>71E='1Y+@I%:2!O;&4@;6ETY.1N('1A:V5I=&$@<VEI=.0@971T
MY"!V:65S=&D@;VX@;'5E='1U('1A:2!Y;6WD<G)E='1Y+@!.:6UI(&IO=&$@
M:^1Y=&5TY.1N(&QI;FMI=&5T=.1E<W-A(&QU;R!S:79U;&QE`$ME;G1T:65N
M(&WDY'+D('!I=.3D(&%N=&%A(&YU;65R;VEN82X`36]D=75L:2!O<&5N<W-L
M('1A<G9I=&%A;B!(;W)D95]#<GEP=%]S;6EM93HZ("UL=6]K86X@:^1Y='3D
M;6ES96MS:2X`07-E='5S=&$@(B5S(B!K;W-K82!S96X@=&EE9&]T('EL:71T
M:7;D="!T86QL971U<W1A=F%N('-U=7)I;6UA;B!S86QL:71U;B!R86IA;@!/
M:&IE;&UA82P@:F]L;&$@=F]I(&MA='-O82!V:65S=&ET>7EP<&GD("@E<RDL
M(&5I(&SV>71Y;GET(&KD<FIE<W1E;&WD<W3D+@!,86EN875S;65R:VMI('!I
M=.3D(&]L;&$@>6MS:71TY&EN96X@;65R:VMI+@!686EN(&]I:V5A(&IA('9A
M<V5N('!U;VQI`%9A:6X@;VEK96$@<'5O;&D`17)O=&EN('!I=.3D(&]L;&$@
M>6MS:71TY&EN96X@;65R:VMI+@!086QV96QI;B`B)7,B(&]N('!O:7-T971T
M=2X`4&%L=F5L:6X@(B5S(B!O;B!T86QL971E='1U+@!3:7/DY&YK:7)J875T
M=6UI<W!Y>6YT]B`E<R!O;B!P;VES=&5T='4N`$WDY')I=&5L='GD(')I=FGD
M("@E9"D@96D@;VQE(&]L96UA<W-A+@!686QIY&%I:V%I<W1I961O<W1O82`B
M)7,B(&5I(&]L92!O;&5M87-S82X`2VER:F]I='1A;6%S:2!T96MS=&D@96D@
M=F%S=&%A('1E:W-T:>0@<G5U9'5L;&$N`%9A:6X@>6SD<'5O;&D@:F$@86QA
M<'5O;&D`5F%I;B!Y;.1P=6]L:0!4=6]T=2!T:65T;R!HY'9I<VD@961E;&QI
M<V5N(&MO:&1A;B!A:6MA;F$N`%1U;W1U82!T:65D;W-T;V$@96D@=F]I='4@
M=&%L;&5T=&%A+@!/<VEO=&$@=V5A=&AE<BYC;VT@96D@;VQE(&OD>71E='3D
M=FES<^0N`%1E96UA:&%K96UI<W1O82`B)7,B(&5I(&SV>71Y;GET+@!!<V5T
M=6MS:6$@96D@;VQE('-A871A=FEL;&$N`$5I(&]L92!O<VEO:71A+"!J;W1K
M82!V;VED86%N(&[D>71TY.0@=FEE<W1I96X@>6AT97ED97-SY"X`5.1S<^0@
M:V5N=.1S<^0@;VX@;&EI86X@;6]N=&$@;65R:VMIY"X@06YN;VET("5S(&UE
M<FMK:>0[('-I;G5N('!I=.3D(&%N=&%A(';D:&5M;>1N(&MU:6X@)7,@;65R
M:VMIY"X`2F]I=&%K:6X@;VYG96QM:6$@(B5S(B!L:7/DY&UI<V5S<^0@:N1R
M:F5S=&5L;>3D;CH@)7,`2^1Y='3D:N1N("(E<R(@:^1Y='3D:N1T:65T;VIE
M;B!P;VES=&%M:7-E<W-A(&KD<FIE<W1E;&WD<W/D(&]L:2!O;F=E;&UI83H@
M`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@<&]I<W1A;6ES97-S82!JY')J97-T
M96QMY'-TY#H@`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@<.1I=FET>6MS97-S
MY#H@)7,`5&EE9&]S=&]N('1U;VYN:7-S82!O;&D@;VYG96QM:6$N(%EH=.3D
M;B`E<SIA(&5I('1U;W1U`%1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L
M;6EA+B`E<R!K;VMO(&]L:2!S=75R96UP:2!K=6EN('-U=7)I;B!S86QL:71T
M=2!K;VMO("@E9"!T879U82DN`%1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N
M9V5L;6EA+B`E<R!L871A=71U:2!V86EN(&]S86MS:2X`5&%P86AT=6D@=FER
M:&4@;N1Y=&5T=.1E<W/D('9I97-T:6X@=.1TY"!O<VEO=&$`66AT97ES=&EE
M=&]J96X@='5O;FYI<W-A('1A<&%H='5I('9I<FAE+@!I0V%L96YD87(M=&EE
M=&]J96X@='5O;FYI<W-A('1A<&%H='5I('9I<FAE+@!!<V5T=7-T:65T;VQO
M;6%K:V5E<W-A(&]N(&IO:VEN('9I<FAE+B!%:&OD(&KD=&ET(&IO;FMU;B!P
M86MO;&QI<V5N(&MO:&1A;B!TY'ET=.1MY'1TY"X`5&%P86AT=6D@=FER:&4@
M>7)I=&5T=.1E<W/D('-U;W)I='1A82!O<V]I=&5K:7)J871O:6UI;G1O82X@
M67)I=.0@;7GV:&5M;6EN('5U9&5S=&%A;BX`66AT97ES=&EE=&]J96X@<.1I
M=FET>6MS97-SY"!T87!A:'1U:2!V:7)H92X@67)I=.0@;7GV:&5M;6EN('5U
M9&5S=&%A;BX`2F%K96QU;&ES=&%N('#D:79I='EK<V5S<^0@=&%P86AT=6D@
M=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U=61E<W1A86XN`%3D;>0@24U!4"!P
M86QV96QI;B!E:2!T=64@:V%N<VEO:61E;B!J86MA;6ES=&$N`%3D;>0@=&EE
M9&]S=&\@96D@=F%I:W5T82!R87(M=&EE9&]S=&]L=&$N`%3D;>0@=&EE9&]S
M=&\@96D@=F%I:W5T82!Z:7`M=&EE9&]S=&]L=&$N`%3D;>0@96D@=F%I:W5T
M82!O:6ME86QT82!K;W)T=&EN=6UE<F]L=&$N`%3D;&SD(&%J=7)I;&QA('9O
M:2!LY&AE='3DY"!V:65S=&5JY"!#;&EC:V%T96QL:6X@*&AT='`Z+R]C;&EC
M:V%T96QL+F-O;2D@9V%T97=A>2!P86QV96QU82!(5%10($%023IL;&$N`%3D
M;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2!G871E=V%Y('!A;'9E;'5N(&MA=71T82!(5%10($%0
M23IL;&$N`%3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y('!A;'9E
M;'5N(&MA=71T82!(5%10($%023IL;&$N`%3D;&SD(&%J=7)I;&QA('9O:2!L
MY&AE='3DY"!V:65S=&5JY"!6;V1A9F]N96X@;G5M97)O:6AI;B!33510.FQL
MY"!KY'ET=.1E;B!6;V1A9F]N92!)=&%L>2!G871E=V%Y('!A;'9E;'5A+B!4
MY'3D('!A;'9E;'5A('9O:2!KY'ET=.3D('9A:6X@5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2!T=6YN=6MS:6QL82X`5.1MY"!K96YT=.0@
M;VX@<&%K;VQL:6YE;BX`5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!V86EN
M(&MO:V]N86ES;'5K=6IA+@!4Y'-SY"!K96YTY'-SY"!P:73DY"!O;&QA(&YU
M;65R;VET82!J82!P:6QK:W4M;65R:VME:N0N`%3D<W/D(&ME;G3D<W/D('!I
M=.3D(&]L;&$@;VMT86%L:6QU:W5J82X`5.1S<^0@:V5N=.1S<^0@<&ETY.0@
M;VQL82!L:7-T82!K;VMO;F%I<VQU:W5J82P@:F]T:V$@<&ETY.0@;VQL82!E
M<F]T971T=2!P:6QK=6QL82!T86D@=N1L:6QY]FYN:6QLY`!!<G9O;B!P:73D
MY"!O;&QA(&YU;65R;RX`5.1S<^0@:V5N=.1S<^0@;VX@=N1R:6WDY')I='ES
M+"!J;VYK82!P:73DY"!O;&QA(%)'0B!(97@@;75O9&]S<RP@97-I;65R:VEK
M<VD@)R,Q,C,T868G+@!4Y&WD(&QO;6%K92!O;B!J;R!KY'-I=&5L='DN`%3D
M;>0@;VX@)7,N`%3D;>0@;VX@2V]L86(@1W)O=7!W87)E(&]B:F5K=&DN($MA
M='-O86MS97-I('3D;>1N(&]B:F5K=&EN('-I;G5L;&$@<&ETY.0@;VQL82!S
MY&AK]G!O<W1I;VAJ96QM82P@:F]K82!Y;6WD<G3DY"!+;VQA8B!'<F]U<'=A
M<F4@9F]R;6%A='1I82X@3&ES=&$@>6AT965N<V]P:79I<W1A('/D:&OV<&]S
M=&EO:&IE;&UI<W1A(&SV>71Y>2!O<V]I='1E97-T82`E<P!4Y&WD('9I97-T
M:2!O;B!K:7)J;VET971T=2!E<FD@;65R:VES=/9L;.0@*"5S*2!K=6EN(&UI
M:^0@<VEN=6QL82!O;B!KY'ET]G-SY"X@`$YU;65R;VX@<&ETY.0@;VQL82!V
MY&AI;G3DY&X@>6MS:2X`5.1L;.0@<&%L=F5L:6UE;&QA(&5I('9O:2!A=6MA
M:7-T82!Z:7`M('1A:2!G>FEP+71I961O<W1O:F$N`%3D;>0@:N1R:F5S=&5L
M;>0@;VX@<&]I<R!PY.1L=.0N`$%R=F]N('!I=.3D(&]L;&$@;G5M97)O+@!4
MY&WD;B!I:VMU;F%N('9O:2!A=6MA:7-T82!V86EN($%S971U:W-E="!I:VMU
M;F%S=&$`37ER<VMY`%1I:V5T:70`06EK80!!:F%N<V5U<F%N=&$`06IA;B!E
M<VET>7-M=6]T;P!!:F%N('9A;&EN=&$`5&EM;W(M3&5S=&4`5&ET=&5L:0!/
M='-I:VMO("AT;V]L=&EP*3H`5F%S=&%A;F]T=&%J80!6;VED86MS97-I('9A
M;&ET82!U<V5A;7!I82!V86EH=&]E:'1O:F$L('!I9.0@0V]N=')O;"T@*%!#
M*2!T86D@0V]M;6%N9"T@*$UA8RD@;N1P<.1I;G3D('!O:&IA<W-A(&MU;B!N
M87!S875T870@:&EI<F5N('!A:6YI:V5T=&$N`%3D;N3D;@!.Y'ETY"!(5$U,
M+6SD:&1E:V]O9&D`5&]G;P!4;VME;&%U`$AU;VUE;FYA`%1O;F=A`$QI:6%N
M(&UO;G1A(&5PY&]N;FES='5N=71T82!K:7)J875T=6UI<WER:71Y<W3D('9I
M:6UE:7-I;7!I96X@;6EN=75T=&EE;B!K=6QU97-S82X`66SV<P!9;&EM<.3D
M;B!K96AY:W-E96X@*%]T;W`I`$ODY&YN]FMS970`5')I;FED860@:F$@5&]B
M86=O`%1O<VD@=F%I(&5PY'1O<VD`=&D`5'5N:7-I80!4=7)K:VD`5'5R:VMI
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@:F$@0V%I8V]S('-A
M87)E=`!4=79A;'4`2VER:F]I=&$@=F%L:6YT87-I.B``52Y6+B`M:6YD96MS
M:3H@`%523`!54DP@:F]H;VX@<&%L875T971A86X@<VMR:7!T:6X@<W1A='5S
M(')A<&]R='1I`%523#H`56=A;F1A`%5K<F%I;F$`5D93+6AA:V5M:7-T;V$@
M96D@=F]I='4@;'5K96$N`$OD>71TY&KD;B!L:7/D=&EE=&]J96X@;&ESY'ES
M(&5I(&]N;FES='5N=70@:VER:F%U='5M:7-E<W-A+@!%:2!V;VD@=F%I:'1A
M82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE("(E<R(N`$5I('9O:2!V86EH
M=&%A(&]I:V5U:W-I82!61E,M=&EE9&]S=&]L;&4@)7,O)7,N`$5I('9O:61A
M('9A:6AT86$@)7,Z;BX`5&EE9&]S=&]N("(E<R(@:V]K;V$@96D@=F]I='4@
M=&%R:VES=&%A+@!%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&4RUT:65D
M;W-T;V$@(B5S+R5S(BX`4U%,+7!A;'9E;&EM965N(&5I('-A861A('EH=&5Y
M='3D+@!9:'1E>71TY"!E:2!V;VED82!M=6]D;W-T86$@4U-,+7-A;&%T='5N
M82X`5D93+71I961O<W1O82!E:2!V;VED82!K;W!I;VED82X`16D@=F]I9&$@
M;'5O9&$@5D93+6AA:V5M:7-T;V$@(B5S(BX`16D@=F]I9&$@;'5O9&$@5D93
M+6AA:V5M:7-T;V$N`$5I('9O:71U(&QU;V1A(%9&4RUT:65D;W-T;V$`16D@
M=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M:V%N<VEO=&$@(B5S(BX`16D@
M=F]I='4@;'5O9&$@='EH:N3D(%9&4RUT:65D;W-T;V$N`%1I971O82!E:2!V
M;VED82!L86%J96YT86$N`$5I('9O:61A('!O:7-T86$@(B5S(BP@:&%K96UI
M<W1O(&5I(&]L92!T>6AJY"X`16D@=F]I9&$@<&]I<W1A82`B)7,B.B`E<RX`
M16D@=F]I9&$@<&]I<W1A82`E<RP@:&%K96UI<W1O(&5I(&]L92!T>6AJY"X`
M16D@=F]I9&$@<&]I<W1A82!61E,M:&%K96UI<W1O82!R96MU<G-I:79I<V5S
M=&DN`$5I('9O:61A('!O:7-T86$@5D93+6AA:V5M:7-T;V$N`$5I('9O:61A
M('!O:7-T86$@5D93+6AA:V5M:7-T;V$Z("5S+@!%:2!V;VED82!P;VES=&%A
M(%9&4RUT:65D;W-T;V$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82!61E,M=&EE
M9&]S=&]A+@!%:2!V;VED82!P;VES=&%A(%9&4RUK86YS:6]T82`B)7,B+@!%
M:2!V;VED82!P;VES=&%A(%9&4SKDY"!R96MU<G-I:79I<V5S=&DZ("5S+@!.
M>6MY:7-TY"!H86ME;6ES=&]A(&5I('9O:71U('-E;'9I='3DY"X`5F%R;65N
M=&5E;B!T:65T;VIA(&5I('9O:61A(&5X=')A:W1O:61A`$WDY')I='EK<V5N
M("5S(&QU:V5M:6YE;B!E<.1O;FYI<W1U:2X`16D@=F]I9&$@<VEI<G3DY"!6
M1E,M=&EE9&]S=&]A+@!%:2!V;VED82!P;VES=&%A(%9&4RUT:65D;W-T;V$@
M(B5S(BX`16D@=F]I9&$@879A=&$@5D93+71I961O<W1O82!K:7)J;VET=7-T
M82!V87)T96XN`$5I('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$N`%1I:79I
M<W1E='EN('1I961O<W1O;B!A=6MA:7-U(&5PY&]N;FES='5I+@!%:2!V;VET
M=2!L=6ME82!61E,M=&EE9&]S=&]A("AF:6QE<VEZ92@I(&5PY&]N;FES='5I
M*2X`16D@=F]I9&$@;'5K96$@5D93+71I961O<W1O82`H9V5T1FEL95-I>F4H
M*2!E<.1O;FYI<W1U:2DN`$5I('9O:71U(&QU:V5A('1I961O<W1O83H@`'9F
M<W)O;W0@:G5U<FEH86ME;6ES=&]A(&5I('9O:71U(&QU:V5A+@!5=61E;&QE
M96YN:6UEY&UI;F5N("5S("5S.FMS:2!E<.1O;FYI<W1U:2!K;W-K82!K;VAD
M96AA:V5M:7-T;R!O;B!J;R!O;&5M87-S80!%:2!V;VED82!N:6UE=.0@=75D
M96QL965N(%9&4RUH86ME;6ES=&]A+@!%:2!V;VED82!N:6UE=.0@=75D96QL
M965N(%9&4RUH86ME;6ES=&]A.B`E<RX`16D@=F]I9&$@;FEM973D('5U9&5L
M;&5E;B!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&YI;65TY"!U=61E
M;&QE96X@5D93+71I961O<W1O82`E<R\E<RX`16D@=F]I='4@;FEM973D('5U
M9&5L;&5E;B!61E,M=&EE9&]S=&]A+@!%:2!V;VED82!S=6]R:71T86$@:V]M
M96YT;V$@)VUK:7-O9G,G+@!7;W)D+61O:W5M96YT=&EA(&5I('9O:71U(&OD
MY&YTY.0`16D@=F]I9&$@:VER:F]I='1A82!61E,M=&EE9&]S=&]A("(E<R(N
M`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O<W1O;VX@*&-O<'DH*2!E
M<.1O;FYI<W1U:2DN`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O<W1O
M;B!T:65T;VIA+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T;V$L
M(&MI:6YT:?8@;VX@=.1Y;F[D+@!!;&QE=FEI=F%T='4`4&5R=2!M=75T;VMS
M970`4&5R=75T=&%A(&5D96QL:7-E;B!T;VEM96YP:71E96X`5'5N=&5M871O
M;B!V87-T875S('!A;'9E;&EM96QT82!Y:'1E>71E96XZ`%1U;G1E;6%T;VX@
M=F%S=&%U<R!P86QV96QI;65L=&$Z(`!,=6]K:71T96QE;6%T;VX`56YI8V]D
M92`H551&+3@I`%EH9&ES='EN965T(&%R86)I96UI<F%A=&ET`%EH9&ES='EN
M965T(&MU;FEN9V%S:W5N;F%T`%EH9'ES=F%L;&%T`%EH9'ES=F%L=&]J96X@
M5'EY;F5N;65R96X@97)I;&QI<W-A87)E=`!-:71T87EK<VEK]G0`5'5N=&5M
M871O;@!4=6YT96UA=&]N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%1U
M;G1E;6%T;VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`06YN971T
M=2!P86EK:V%T:65T;R!O;B!T=6YT96UA=&]N+@!4=6YT96UA=&]N(&OD>71T
MY&KD='5N;G5S('1A:2!S86QA<V%N82X`4&]I<W1A(&YY:WEI<V5N(&5L96UE
M;G1I;B!L:6YK:71Y<P!.:6UE=/9N`%1I971O='5R=F%S>6ES=.0@96DM<')I
M=FEL965G:7-E="!S:W)I<'1I="!E:7;D="!V;VD@:W5T<W5A($QE:6MK86$O
M2V]P:6]I+TQI:73D('1O:6UI;G1O:F$N($YA<'-A=71A($]++6YA<'!U;&%A
M(&[D:&3D:W-E<VD@;6]Z:6QL82YO<F<@<VEV=6EL;&$@;VQE=F%N(&]H:F5E
M;BP@:F]S<V$@;F5U=F]T86%N(&UI=&5N('-K<FEP=&ES:2!V;VEV870@:^1Y
M='3DY"!L96EK97#V>73DY"X`4&]I<W1A(';D<FD`16DM='5E='1U(&QA86IE
M;FYU<P!0Y&EV:73D`%#D:79I=.0@)7,`4.1I=FETY"!KY'ET=.1JY`!0Y&EV
M:71E='1I:6X@(B5S(BX`4.1I=FET>7-S:W)I<'1I('!O:7-T971T:6EN+@!4
M=6\`='5O(&MA:6MK:2!O:&IE;&UI96X@87-E;FYU<W1I961O<W1O="!P86QV
M96QI;65L;&4N`$ES;W0@;&%T:6YA;&%I<V5T(&MI<FIA:6UE=`!)<V]T(')O
M;VUA;&%I<V5T(&YU;65R;W0`57)U9W5A>0!+Y'ETY"!N>6MY:7-TY#H@)7,`
M2^1Y=.0@4U-,+7-A;&%U<W1A`$OD>73D(&IO<R!T=6YN=7,O<V%L87-A;F$@
M;VX@97)I($E-4U`M<&%L=F5L:6UE;&QE+@!+Y'ET=.1JY`!+Y'ET=.1JY&QL
MY"`E<R!E:2!O;&4@;VEK975K<VEA('1E:&3D("5S+@!+Y'ET=.1J:65N('EL
M;.1P:71O`$OD>71TY&KD;B!A<V5T=6MS970`2^1Y='3D:N1N(')E:VES=&5R
M]FEM:6YE;@!4Y'-SY"!JY')J97-T96QMY'-SY"!E:2!V;VD@<F5K:7-T97+V
M:63D(&OD>71TY&IIY"X`2^1Y='3D:N1T=6YN=7-T82!E:2!L]GET>6YY="X`
M2^1Y='3D:N1T=6YN=7,`2^1Y='3D:N1T=6YN=7,@(B5S(B!O;B!J;R!O;&5M
M87-S82X`2^1Y='3D:N1T=6YN=7,Z`$OD>71TY&KD='5N;G5S.B``2N1R:F5S
M=&5L;>1N(&OD>71TY&KD=#H`57IB96MI<W1A;@!61E,M:&%K96UI<W1O82!E
M:2!O;&4@;VQE;6%S<V$N`%!O:7-S86]L;W9I97-T:0!086EK:V]J82!L]GET
M>6D@97-I;65R:VEK<VDZ(`!6;VEM87-S86]L;V%I:V$`07)V;R!M:6YU=71E
M:7-S82!N>6MY:&5T:V5S=.0N`$%R=F\@;VX@>6QI('!I='5U9&5N(&UA:W-I
M;6EA<G9O;B`E<RX\`$%R=F]T`%9A;&ET=&%V870@87)V;W0`5F%N=6%T=0!6
M86EH=&5L979A80!696YE>G5E;&$`5&%R:VES='5S(&5PY&]N;FES='5I("T@
M5.1TY"!V:65S=&GD(&]N('9O:71U(&OD<VET96QLY"X`5F5R<VEO`%9E<G-I
M;VYH86QL:6YT80!0>7-T>7-U;W)A('1A<V%U<P!0>7-T>7-U;W)A('3D>71E
M`%!Y<W1Y<W5O<F$Z`$5R:71TY&EN(&MO<FME80!6:65T;F%M`%9I971N86T@
M*%9)4T-)22D`3N1Y=.0@)7,`3N1Y=.0@97)I;&QI<V5NY"!W=W<M<VEV=6YA
M`$[D>73D("5S`$YE:71S>71S86%R970L($)R:71T:6SD:6YE;@!.96ET<WET
M<V%A<F5T+"!9:&1Y<W9A;'1A:6X`3N1K>7;D:7-Y>7,`3N1K>7;D:7-Y>7,Z
M(`!6;V1A9F]N92!)=&%L>2!33510.FX@879U;&QA`%9!4D])5%53`%9!4D])
M5%53(2$A(%!/25-402!32U))4%1)($OD4TE.(%!!3%9%3$E-14Q402`E<RX`
M5TE.($A45%`Z;B!A=G5L;&$`5V%L;&ES(&IA($9U='5N80!687)O:71U<P!K
M90!3Y.1E;FYU<W1E`%/DY'1I961O="!O;B!T;VEM:71T86YU=`!796%T:&5R
M+F-O;0!75U<`5U=7+7-I=G5S=&\`5FEI:V]I='1A:6X`5&5R=F5T=6QO80!4
M97)V971U;&]A(&]H:F5L;6%A;B`E<P!497)V971U;&]A+"`E<P!,Y&YS:6UA
M:6YE;B`H25-/+3@X-3DM,2D`3.1N<VEM86EN96XO175R;R`H25-/+3@X-3DM
M,34I`$SD;G-I+5-A:&%R80!-:6YKY"!O:&IE;&UA;B`E<R!KY'EN;FES=.3D
M('-I<^3D;FMI<FIA=71U;6ES96X@:N1L:V5E;BX`36ETY"!M97)K:VGD(&OD
M>71E=.3D;B!E<F]T=&EM96YA/P!-:73D(&UE<FMK:>0@:^1Y=&5TY.1N(&QA
M:6YA=6MS965N/P!7:&5R96ES($%U<W1R86QI86X@:V%R='1A`$UI=&OD('9A
M:6AE970`5F]I="!MY.1R:71E;&SD(&QI<^1T;VEM:6YT;VIA(&QA:71E=&%A
M;B!PY.1L;&4@4FEC:"!497AT(&5D:71O<FES<V$N`$QE=F5Y<P!,979E>7,@
M0U-3(&UI='1A>6MS:6MK]FENY`!687-E;6UA;&QA(&]L979A;B`E<R!V86QI
M:V]N(&QE=F5Y<R`H='5L964@=F]I;6%A;B!S975R86%V86QL82!S:7/DY&YK
M:7)J875T=6UI<V5L;&$I.@!4875L=6MO;B!L979E>7,`3&5V97ED96X@>6MS
M:6MK]@!,979E>7,Z`%=I:VD`5'5U;&D`5'5U;&ES=&$@86EK86ES:6X`5'5U
M;&5N;F]P975S('-O;&UU:7-S80!4=75L:3H`5'5U;&DZ(`!6:6ES875S`%1O
M:79E;&ES=&%T`%1Y]@!/<V]I=&4@*'1Y]BD`4'5H96QI;B`H='GV*0!6Y.1R
MY"!MY.1RY"!K96YT=&GD(')I=FEL;.0@)60N($]D;W1E='1I:6X@)60L(&SV
M>71Y:2`E9"X`5N3D<N0@;>3D<N0@:V5N='1IY"X@3V1O=&5T=&EI;B`E9"P@
M;/9Y='EI("5D+@!6Y.1RY"!P;VEK:V5A;6$@)60@;'5E='1A97-S82!61E,M
M=&EE9&]S=&]A+@!8+5)E9@!8-3`Y=C,@<&5R=7-R86IO:71T965T`%@U,#EV
M,R!L:7/D=&]I;6EN;F]T(&%V86EM96X@:^1Y=/9L;&4`6#4P.78S($MO:'1E
M96X@=F%I:'1O96AT;VEN96X@;FEM:0!8-3`Y=C,@2V]H=&5E;B!A=F%I;65N
M('1U;FYI<W1E`%@U,#EV,RUL86%J96YN=6MS970`5E8`5E965@!986AO;R$@
M:V%R='1A`%9U;W-I='1A:6X`2F5M96X`2WEL;.0`2WEL;.0L('-U;W-T=6XN
M`$OD>73D="!414M35$E424Q!02X@2^1Y=.0@6SP^72!N87!P=6QA82!V86EH
M=&%A:W-E<VD@=&%K86ES:6X@5UE325=91RUT:6QA86XN`$5T('9O:2!T96AD
MY"!E;F5M<.3D(&MU:6X@)60@;W-I;W1A+@!%="!O;&4@875T96YT:6MO:71U
M;G5T+@!.:6UE<W/D<VD@96D@<V%A(&]L;&$@)UPG+6UE<FMK:>0N`$5T(&%N
M=&%N=70@;VEK96%N(&UU;W1O:7-T82!SY&AK]G!O<W1I;W-O:71E='1A+@!%
M="!MY.1R:71E;&QY="!M:71KY"!T=6]D=6X@=&EE9&]S=&]N(&ME;G3D="!V
M87-T86%V870@;6ETY&MI;B!K96YT=&GD("5S.G-SY"X`3VQE="!K:7)J875T
M=6YU="!U;&]S+@!3:6YU;B!P:73DY"!A;G1A82!O:6ME82!M871K87!U:&5L
M:6YN=6UE<F\L('9A:6X@;G5M97)O:71A(&IA(&UA:&1O;&QI<V5S=&D@)RLG
M(&IO<R!KY'ETY'0@:V%N<V%I;G;D;&ES=.0@<'5H96QI;FYU;65R;VUU;W1O
M82X`4VEN=6X@=.1Y='EY(&%N=&%A(&]I:V5A(&%R=F\N`%-I;G5N('!I=.3D
M(&%S96YT86$@1&%T851R964M=&%U<W1A:N1R:F5S=&5L;>0@96YN96X@:W5I
M;B!V;VET(&OD>71TY.0@4VEG;G5P+71O:6UI;G1O:F$N`%-I;G5N('!I=.3D
M(&%S96YT86$@5D93+71A=7-T86KD<FIE<W1E;&WD+@!3:6YU;B!T=6QE92!K
M=79A:6QL82!O;F=E;&UA=&EL86YN971T82!E;FYE;B!K=6EN('9O:70@;.1H
M971TY.0@;VYG96QM879I97-T:6XN`%-I;G5N('!I=.3D(&%N=&%A(%523"!M
M:6AI;B!TY&WD(&QI;FMK:2!O<V]I='1A80!3:6YU;B!P:73DY"!V86QI=&$@
M<&]I<W1E='1A=F$@<&%L=F5L:6XN`%-I;G5N('!I=.3D(&%N=&%A('!O:7-T
M971T879A(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!A;G1A82!P;VES
M=&5T=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@;&ES
MY'1TY';D(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!A;G1A82!PY&EV
M:71E='3D=N0@:^1Y='3D:N1T=6YN=7,N`%-I;G5N('!I=.3D('9A;&ET82!S
M=6]R:71E='1A=F$@=&]I;6EN=&\N`%-I;G5N('!I=.3D(&%N=&%A('5U9&5N
M(&MA=&5G;W)I86X@;FEM:2X`4VEN=6X@<&ETY.0@86YT86$@:71A;&EA;&%I
M;F5N('!U:&5L:6YN=6UE<F\`27-T=6YT;W-I("5S(&]N('9A;FAE;G1U;G5T
M+B!+:7)J875D=2!U=61E;&QE96X@<VESY.1N+@!3Y&AK]G!O<W1I;W-O:71T
M965S:0!3:6YU;B!LY&AE='3D:N1O<V]I='1E97-I.@!/;6%T('1I971O<VD`
M4VEN=6X@=&EE=&]K;VYE97-I(&OD>71TY&WD('1I971O=F5R:VMO+6]S;VET
M92!O;B!M=75T='5N=70@<V5N(&KD;&ME96X@:W5N(&]L970@86QO:71T86YU
M="`E<R!I<W1U;FYO;BX@5&EE=&]T=7)V87-Y:7-TY"!S:6YU;B!P:73DY"!K
M:7)J875T=6$@=75D97-T86%N(&KD<FIE<W1E;&WDY&XN`$YI;65S:0!+Y'ET
M=.1MY'-I(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WD(&5I('1U
M92!KY'ET=.1J:65N(&QI<^3D;6ES=.0N($IO<R!H86QU870@:&%L;&EN;F]I
M9&$@:^1Y='3D:N1T=6YN=6MS:6$L('-I;G5N('!I=.3D(&OD>71TY.0@:F]T
M86MI;B!T;VES=&$@875T:&5N=&EC871I;VX@=&%U<W1A:N1R:F5S=&5L;>3D
M+@!+Y'ET=.1MY'-I(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WD
M(&5I('1U92!KY'ET=.1JY'1I971O:F5N(&[D>71TY&UI<W3D('1A:2!TY&WD
M('!I:7)R92!E:2!O;&4@:F]S=&%K:6X@<WEY<W3D(&OD>71E='3D=FES<^0N
M`%-I;G5N(&OD>71TY&WD<VD@=W=W+7-E;&%I;B!NY'ET=.3D(&]L979A;B!M
M=75T='5N=70@<V5N(&KD;&ME96X@:W5N(&]L970@86QO:71T86YU="`E<R!I
M<W1U;FYO;BX@5&EE=&]T=7)V87-Y:7-TY"!S:6YU;B!P:73DY"!K:7)J875T
M=6$@=75D97-T86%N:N1R:F5S=&5L;>3D;BX`4V5L86EM97-I(&5I('1U92!T
MY'3D('1O:6UI;G1O82X`4V5L86EM97-I(&5I('1U92!T87)V:71T879A82!T
M=6QO<W1U<W1O:6UI;G1O82X@4&%I;F$@0V]N=')O;"]/<'1I;VX@*R!0('1U
M;&]S=&%A:W-E<VDN`$%I:V%V>?9H>6MK965S:3H`3VQE='5S<')O9FEI;&ES
M:2!O;B!M=75T971T=2X`3VQE='5S<')O9FEI;&ES:3H`3FEM97-I.@!)<W1U
M;G1O<VD@;VX@=F%N:&5N='5N=70N`%-I;G5N('-A;&%S86YA<VD@)7,Z;&QE
M(&]N.B`E<P!!<V5T=6MS97-I(&]N('#D:79I=&5T='D@:F$@;F4@;W9A="!V
M;VEM87-S82!TY&WD;B!I<W1U;FYO;B!A:F%N+@!!<V5T=6MS97-I(&]N('#D
M:79I=&5T='DN`%-A;&%S86YA<VD@;VX@;F]L;&%T='4`4V%L87-A;F%S:2!O
M;B!N;VQL871T=2P@=&%R:VES=&$@<^1H:_9P;W-T:7-I(&IA(&MI<FIA=61U
M('-I<^3D;B!U=61E;&QA('-A;&%S86YA;&QA<VDN`%-A;&%S86YA<VD@;VX@
M=F%N:&5N='5N=70N`$5TY'!A;'9E;&EM97-I.@!*=6=O<VQA=FEA`%IA:7)E
M`%-A;6)I80!::6UB86)W90!::7!P>0!;4&EI;&]T82!L86EN871T=2!T96MS
M=&E=`%M/;F=E;&UA70!;3N1Y=.0@;&%I;F%T='4@=&5K<W1I("T`6T[D>73D
M(&QA:6YA='1U('1E:W-T:2`M("5S(')I=FGD70!;<FEV:6QLY"`E<R\E<UT`
M7UEL;.1P:71O`%]+;VUE;G1O='5L:VMI`%]$871A5')E90!?4&]I<W1A(')I
M=FD`7U)Y:&WD=`!?3VAJ90!?2W5V86X@=&EE9&]T+BXN`%]+:7)J875D=2!S
M:7/DY&X`7TMI<FIA=61U('5L;W,`7TUU;VMK86$@;&EN:VMIY`!?07-E='5K
M<V5T`%]/:6ME=61E=`!0;VES=&$@;&EN:VMI+BXN`%]!<V5N;G5S`%]4875L
M=6MO;B!T:65D;W0N+BX`7TOD>71TY&KD=`!O<V]I=&5K:7)J80!V87-T86%N
M;W1T86IA('1U;G1E;6%T;VX`:V%L96YT97)I`'1Y>6YTY`!E:2!V;VD@;'5O
M9&$@='5L;W-T:65D;W-T;V$`96D@=F]I(&%U:V%I<W1A(&SD:&1E='3D`&YA
M<'-A=71A('3D<W3D`'9I<FAE(&MO;65N=&]R:79I;&SD`&%S971U<W9I<FAE
M`&MR:6ET=&EN96X@:N1R:F5S=&5L;>1T:65D;W-T;R!P=75T='5U`&UU;W1O
M=FER:&4@=&EE9&]I<W-A`&UU;VMK86$`=&EE='5E='1A(&5I(&SV>71Y;GET
M`&QA<VME=F$`=&EE9&]S=&\`<W5U;FYA<W1A("5S("@E<RD@;F]P975D96QL
M82`E<R`E<P!P=75S:VET=&%I;@!H.@!H:`!T=6YT96UA=&]N('!A;'9E;&EM
M96X@;FEM:0!VY&QI='3V;>1S=&D`:6YL:6YE`&EO+79I<FAE`&]H:F5L;6ES
M=&]N('-I<^1I;F5N('9I<FAE`')I=FET70!M:VES;V9S('9I<FAE:V]O9&D@
M)60@25-/.F$@=&5H9&5S<^0N`&UM`&YI;6D`96D@;VQE('1O=&5U=&5T='4`
M96D@;VQE('9I96SD('1O=&5U=&5T='4`;75I<W1I;&ES=&$`<')O<V5N='1I
M`&OD>71T]B!K:65L;&5T='D`<&EK<V5L96ETY`!E=.1V:7)H92!P<F]T;VMO
M;&QA<W-A`&YO=7-E=F$`<&%L=F5L=2!E:2!O;&4@:^1Y=&5T=.1V:7-SY`!N
MY'ETY"!E<F]T`'-M<S)E;6%I;"!(5%10.FX@879U;&QA`'-S`'9A:V%A`&KD
M<FIE<W1E;&WD=FER:&4`=&5H=.1VY&QI<W1A`';D;&EA:6MA:6YE;B!V:7)H
M90!V87)M:7-T86%K<V5S:2!K:7)J;VET82!S86QA<V%N82!K86AD97-T:0!U
M;FEF:65D`&YI;65T]FX`:^1Y='3D:N1N('9A;&EN=&$`=D-A<F0`=SH`=V5A
M=&AE<BYC;VT`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9FE?1DDO:&5L<"YX;6P`````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,S,W`#$P-#$W
M,S8R-S<V`#`R,#,R,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z
M(&AO<F1E+VQO8V%L92]F:5]&22]H96QP+GAM;"QV(#$N,RXQ,"XS(#(P,#8O
M,#(O,C`@,3$Z,C`Z,3$@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@
M:60](G-U;6UA<GDB(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR
M8V1C,34B('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y0;W)T86%L:3PO=&ET
M;&4^"B`\<&%R83X*("!0;W)T86%L:7-S82!V;VET(&XF(WA%-#MH9"8C>$4T
M.R!P:6MA:7-E<W1I(&QY:'EE;B!Y:'1E96YV961O;B!T)B-X130[<FME)B-X
M130[:W-I"B`@;65R:VET<V5M:7-T)B-X130[(&%S:6]I<W1A+B!%<VEM97)K
M:6MS:2!V;VET(&XF(WA%-#MH9"8C>$4T.R!M;VYT86MO('5U='1A"B`@<R8C
M>$4T.VAK)B-X1C8[<&]S=&EV:65S=&DF(WA%-#L@<VEN=6QL92!O;B!T=6QL
M=70@24Y"3U@@:V%N<VEO;VXL('1U;&5V870*("!T87!A:'1U;6%T(&MA;&5N
M=&5R:7-S82P@=&5H="8C>$4T.W8F(WA%-#MT('1O+61O(&QI<W1A;&QA+"!O
M='-I:V]T"B`@=F%L:71S96UI<W1A<VD@=75T:7-P86QV96QU:7-T82!J;F4N
M($UO;F5T(&XF(WA%-#MI<W0F(WA%-#L@>6AT965N=F5D;VES=&$*("!S:7,F
M(WA%-#ML="8C>$4T.W8F(WA%-#MT(&QI;FMK96HF(WA%-#L@>6QE:7-I;7!I
M:6X@=&]I;6EN=&]I:&EN(&MU=&5N(&5S:6UE<FMI:W-I('9I97-T:6X*("!K
M:7)J;VET=7,L(&MA;&5N=&5R:6UE<FMI;FXF(WA%-#MN('1A:2!T96AT)B-X
M130[=B8C>$4T.VX@;&ES)B-X130[>7,@:FYE+@H@/"]P87)A/@H@/'!A<F$^
M"B`@4&]R=&%A;&EN('-I<R8C>$4T.VQT)B-X1C8[(&]N(&UU;VMA='1A=FES
M<V$@07-E='1E;'4@<&%I;FEK:V5E;B!K875T=&$N(%9O:70*("!E<VEM97)K
M:6MS:2!V86QI=&$@;6ET:R8C>$4T.R!A<VEA="!L:6ET970F(WA%-#LF(WA%
M-#MN('!O<G1A86QI:6X@:F$@;6ES<R8C>$4T.PH@(&HF(WA%-#MR:F5S='EK
M<V5S<R8C>$4T.R!N92!N)B-X130[>71E="8C>$4T.R8C>$4T.VXN"B`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B(&UD-3TB8CAC9C!A
M93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B('-T871E/2)U<'1O9&%T92(^
M"CQT:71L93Y/:&IE;&UI96X@;F%V:6=O:6YT:79A;&EK:V\\+W1I=&QE/@H@
M/'!A<F$^"B`@5W=W+7-I=G5N('9A<V5M86QL82!L86ED86QL82!O;B!N879I
M9V]I;G1I=F%L:6MK;R!E<FD@;VAJ96QM:6EN+@H@($YA<'-A=71T86UA;&QA
M(&EK;VYE:71A(&YA=FEG;VEN=&EV86QI:V]S<V$@=F]I="!H96QP;W-T:2!J
M80H@(&YO<&5A<W1I('9A:6AT86$@;VAJ96QM87-T82!T;VES965N+@H@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N
M8V4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B('-T
M871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^07-E='5K<V5T.B!9;&PF(WA%
M-#MP:71O=&]I;65N<&ET965T.B!3=6]R:71A('EL;"8C>$4T.W!I=&]T;VEM
M970\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!*;W,@:&%L=6%T('-U;W)I='1A
M82!Y;&PF(WA%-#MP:71O=&]I;65N<&ET96ET)B-X130[('-I<R8C>$4T.R8C
M>$4T.VYK:7)J875T=6UI<V5N"B`@("!Y:'1E>61E<W,F(WA%-#LL(&YI:6X@
M87-E=&$@="8C>$4T.VTF(WA%-#L@=&]I;6EN=&\@<"8C>$4T.R8C>$4T.VQL
M92!V86QI;G1A<G5U9'5S=&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!M9#4](F$R,3$V
M,F-D9F8S8C%D.&9A96%D8C<R.38R-#`P,S9E(B!S=&%T93TB=7!T;V1A=&4B
M/@H@("`@/'1I=&QE/D%S971U:W-E=#H@66QL)B-X130[<&ET;W1O:6UE;G!I
M=&5E=#H@5F%R;6ES=&$@>6QL)B-X130[<&ET;W1O:6UE=#PO=&ET;&4^"B`@
M("`\<&%R83X*("`@($IO<R!H86QU870@=F%R;6ES=&%A(&MA:6MK:2!Y;&PF
M(WA%-#MP:71O=&]I;65N<&ET965T(&5N96YN:W5I;B!N90H@("`@<W5O<FET
M971A86XL(&YI:6X@87-E=&$@="8C>$4T.VTF(WA%-#L@=&]I;6EN=&\@<"8C
M>$4T.R8C>$4T.VQL90H@("`@=F%L:6YT87)U=61U<W1A+B!*;W,@=F%R;6ES
M='5S=&$@96D@;VQE('`F(WA%-#LF(WA%-#ML;"8C>$4T.RP@;FEI;B!K86EK
M:VD*("`@('EL;"8C>$4T.W!I=&]T;VEM96YP:71E970@<W5O<FET971A86X@
M875T;VUA871T:7-E<W1I(&IA(&YI:70F(WA%-#L@96D@=F]I"B`@("!P97)U
M82X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9G)?1E(O
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S<V`#`Q-C8V-@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]F<E]&4B],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S8`,#(P-#4S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V9R7T92+TQ#7TU%4U-!1T53
M+VAO<F1E+FUO````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0R-#<S,0`Q,#0Q
M-S,V,C<W-@`P,C(Q,C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````WA($E0````"#!P``'````#0\```3"@``3'@```````"8
MH```#@```)F@```/````J*````T```"XH```"````,:@```+````SZ````P`
M``#;H```!````.B@```8````[:```!L````&H0``+0```"*A```=````4*$`
M`"0```!NH0``*0```).A```9````O:$``"8```#7H0``#````/ZA```D````
M"Z(```\````PH@``"P```$"B```.````3*(```4```!;H@``*````&&B```(
M````BJ(```H```"3H@``%0```)ZB```2````M*(```L```#'H@``A0```-.B
M```.````6:,```H```!HHP``#0```'.C```.````@:,``!$```"0HP``#0``
M`**C```,````L*,```T```"]HP``!@```,NC``"4````TJ,```H```!GI```
M#P```'*D```8````@J0```P```";I```#@```*BD```.````MZ0```@```#&
MI```"0```,^D```N````V:0``!H````(I0``,@```".E```X````5J4``%0`
M``"/I0``40```.2E``!:````-J8``%<```"1I@``-````.FF```)````'J<`
M``T````HIP``!P```#:G```*````/J<```\```!)IP``!0```%FG```&````
M7Z<``!$```!FIP``"````'BG```)````@:<```D```"+IP``)0```)6G```@
M````NZ<``!,```#<IP``$````/"G```/`````:@```H````1J````P```!RH
M```/````(*@``!0````PJ```"0```$6H```-````3Z@``!(```!=J```&0``
M`'"H```>````BJ@```\```"IJ```"@```+FH```/````Q*@```@```#4J```
M)````-VH```4`````JD``!8````7J0``"````"ZI``!.````-ZD``"T```"&
MJ0``&0```+2I```'````SJD```P```#6J0``+````..I```.````$*H```,`
M```?J@``"P```".J```'````+ZH```<````WJ@``!0```#^J```%````1:H`
M``H```!+J@```P```%:J```7````6JH```H```!RJ@``#P```'VJ```.````
MC:H``!@```"<J@``(P```+6J```.````V:H``!0```#HJ@``%P```/VJ```7
M````%:L``!<````MJP``$P```$6K```/````6:L```X```!IJP``'P```'BK
M```=````F*L```<```"VJP``!@```+ZK```(````Q:L```\```#.JP``!@``
M`-ZK```*````Y:L``!,```#PJP``"P````2L```0````$*P``!4````AK```
M%0```#>L```'````3:P``!````!5K```!0```&:L```5````;*P``!$```""
MK```#````)2L```[````H:P``#@```#=K```"0```!:M```'````(*T``!0`
M```HK0```P```#VM```%````0:T``!````!'K0``"0```%BM```3````8JT`
M`#D```!VK0``$@```+"M```G````PZT``"P```#KK0``*@```!BN```E````
M0ZX```H```!IK@``!@```'2N```)````>ZX```<```"%K@``+P```(VN```W
M````O:X``"X```#UK@``50```"2O```M````>J\``"T```"HKP``/0```-:O
M```_````%+```"T```!4L```0````(*P```C````P[```",```#GL```0```
M``NQ```M````3+$``#,```!ZL0``)0```*ZQ```5````U+$``!D```#JL0``
M*0````2R```D````+K(``"@```!3L@``$0```'RR```*````CK(```P```"9
ML@``"@```*:R```0````L;(``!8```#"L@``%@```-FR```'````\+(```<`
M``#XL@``%`````"S```*````%;,```@````@LP``)P```"FS```(````4;,`
M``<```!:LP``!P```&*S```&````:K,```4```!QLP``!P```'>S```&````
M?[,```@```"&LP``*0```(^S```.````N;,```H```#(LP``!````-.S```'
M````V+,```D```#@LP``!@```.JS```1````\;,```<````#M```%@````NT
M```$````(K0```@````GM```!@```#"T```-````-[0```8```!%M```'@``
M`$RT```1````:[0```@```!]M```#0```(:T```,````E+0```<```"AM```
M`P```*FT```#````K;0``!<```"QM```$P```,FT```=````W;0```@```#[
MM```!`````2U```(````";4```@````2M0``00```!NU```:````7;4``"L`
M``!XM0``(````*2U```5````Q;4```8```#;M0``!@```.*U```5````Z;4`
M`!@```#_M0``(@```!BV```N````.[8``!T```!JM@``(0```(BV``!4````
MJK8``"D```#_M@``"@```"FW```'````-+<```<````\MP``%0```$2W```.
M````6K<```H```!IMP``#P```'2W```-````A+<```\```"2MP``#0```**W
M```)````L+<``!0```"ZMP``!@```,^W```8````UK<``!T```#OMP``$P``
M``VX```1````(;@``!0````SN```!````$BX```&````3;@``!0```!4N```
M5````&FX``!D````OK@```0````CN0``#@```"BY```%````-[D```4````]
MN0``&P```$.Y```:````7[D``!,```!ZN0``$0```(ZY```1````H+D``!P`
M``"RN0``*@```,^Y```0````^KD``"$````+N@``!0```"VZ```3````,[H`
M``L```!'N@``$@```%.Z```*````9KH```\```!QN@``#0```(&Z```1````
MC[H``!,```"AN@``#````+6Z```&````PKH```P```#)N@``!@```-:Z```7
M````W;H``!````#UN@``$0````:[```(````&+L```4````ANP``#````">[
M```0````-+L```4```!%NP``#0```$N[```&````6;L```<```!@NP``#0``
M`&B[```'````=KL```L```!^NP``!P```(J[```'````DKL```D```":NP``
M"0```*2[```*````KKL``!D```"YNP``/0```-.[```=````$;P```P````O
MO```$````#R\```%````3;P``"4```!3O```$@```'F\```3````C+P``"L`
M``"@O```.P```,R\```@````"+T```@````IO0``-@```#*]```A````:;T`
M`!````"+O0``"````)R]```,````I;T```8```"RO0``!````+F]```/````
MOKT```X```#.O0``!P```-V]```*````Y;T```T```#PO0``'P```/Z]```<
M````'KX``"$````[O@``'@```%V^```9````?+X``!X```"6O@``'0```+6^
M```;````T[X``"````#OO@``+@```!"_```F````/[\``!P```!FOP``'@``
M`(._```<````HK\``"8```"_OP``*P```.:_```S````$L```"8```!&P```
M*P```&W````X````F<```!T```#2P```%0```/#````O````!L$``"`````V
MP0``$@```%?!```I````:L$``!X```"4P0``(````+/!```2````U,$``*(`
M``#GP0``%@```(K"```C````H<(``"@```#%P@``*0```.["```H````&,,`
M`!\```!!PP``%0```&'#```@````=\,``"4```"8PP``*````+[#```M````
MY\,``#`````5Q```D@```$;$```A````V<0``!8```#[Q```'````!+%```F
M````+\4``"H```!6Q0``00```('%``!$````P\4```P````(Q@``!P```!7&
M```'````'<8```8````EQ@``#0```"S&```0````.L8``!(```!+Q@``$P``
M`%[&```2````<L8```<```"%Q@``!````(W&```0````DL8``!````"CQ@``
M#````+3&```.````P<8```T```#0Q@``#P```-[&```3````[L8```T````"
MQP``*````!#'```#````.<<```T````]QP``!@```$O'```1````4L<``!<`
M``!DQP``&P```'S'```.````F,<```(```"GQP``20```*K'```%````],<`
M`!````#ZQP``#P````O(```$````&\@```T````@R```#@```"[(```#````
M/<@```X```!!R```"````%#(```/````6<@```\```!IR```!P```'G(```-
M````@<@``!````"/R```#0```*#(```+````KL@```8```"ZR```"P```,'(
M```,````S<@```H```#:R```$0```.7(```9````]\@```L````1R0``#0``
M`!W)```B````*\D``!L```!.R0``-````&K)```*````G\D``!@```"JR0``
M&0```,/)```6````W<D``"(```#TR0``#0```!?*```'````)<H``!0````M
MR@``"P```$+*```B````3LH``"\```!QR@``"P```*'*```)````K<H``!D`
M``"WR@``"P```-'*```7````W<H``!<```#UR@``"0````W+```6````%\L`
M``\````NRP``&0```#[+```6````6,L```X```!ORP``&````'[+```(````
ME\L```T```"@RP``)@```*[+``!#````U<L```@````9S```$@```"+,```?
M````-<P```@```!5S```"P```%[,```O````:LP```X```":S```!0```*G,
M```&````K\P``$4```"VS````P```/S,```'`````,T```0````(S0``"@``
M``W-```*````&,T```\````CS0``$````#/-```7````1,T``!$```!<S0``
M&0```&[-```7````B,T```D```"@S0``!0```*K-```+````L,T```H```"\
MS0```@```,?-```%````RLT```T```#0S0``&P```-[-```7````^LT``!0`
M```2S@``"0```"?.```.````,<X```T```!`S@``$@```$[.```X````8<X`
M`"````":S@``"````+O.```.````Q,X``'L```#3S@``&````$_/```8````
M:,\``!$```"!SP``!P```)//```%````F\\``!@```"ASP``'@```+K/```;
M````V<\``!D```#USP``&P````_0```9````*]```!,```!%T```!P```%G0
M```(````8=````8```!JT```!@```''0```0````>-````\```")T```$```
M`)G0```/````JM````L```"ZT```#P```,;0```,````UM````\```#CT```
M!P```//0```&````^]````X````"T0``#````!'1```H````'M$```\```!'
MT0``"````%?1```(````8-$``!,```!IT0``'@```'W1```A````G-$``"``
M``"^T0``&0```-_1```7````^=$``"4````1T@``%P```#?2```6````3](`
M``0```!FT@``&P```&O2```-````A](```P```"5T@```P```*+2```%````
MIM(```@```"LT@``"@```+72```,````P-(```L```#-T@``$````-G2```,
M````ZM(```X```#WT@``"P````;3```$````$M,```0````7TP``$P```!S3
M```4````,-,```P```!%TP``"0```%+3```.````7-,```L```!KTP``&P``
M`'?3```'````D],```<```";TP``"@```*/3```-````KM,```D```"\TP``
M!````,;3```%````R],```,```#1TP``&````-73```*````[M,```0```#Y
MTP``)@```/[3```.````)=0``'P````TU```%0```+'4```%````Q]0```<`
M``#-U```#````-74```(````XM0```H```#KU```!@```/;4```(````_=0`
M``(````&U0``!@````G5```&````$-4``!0````7U0``#0```"S5```0````
M.M4``!L```!+U0``!````&?5```)````;-4``!````!VU0``"0```(?5```)
M````D=4```4```";U0``&@```*'5```(````O-4```8```#%U0``&0```,S5
M```.````YM4```<```#UU0``!P```/W5```%````!=8```D````+U@``"@``
M`!76```"````(-8```8````CU@``"P```"K6```-````-M8```D```!$U@``
M!@```$[6```2````5=8```D```!HU@``!P```'+6```4````>M8``!T```"/
MU@``0@```*W6```E````\-8``"4````6UP``!@```#S7```*````0]<```0`
M``!.UP``"0```%/7```(````7=<``!$```!FUP``"0```'C7```&````@M<`
M``T```")UP``!@```)?7```$````GM<``#D```"CUP``/0```-W7```Z````
M&]@``!X```!6V```!0```'78```.````>]@```0```"*V```!@```(_8```'
M````EM@``"$```">V```#0```,#8```5````SM@```8```#DV```!````.O8
M```1````\-@```8````"V0``"@````G9```B````%-D```0````WV0``!0``
M`#S9```=````0MD```0```!@V0``#````&79```.````<MD```H```"!V0``
M"````(S9```)````E=D```4```"?V0``.@```*79```P````X-D``#4````1
MV@``*0```$?:``!'````<=H``#@```"YV@``*0```/+:```_````'-L``"X`
M``!<VP``+0```(O;```?````N=L```\```#9VP``$@```.G;```+````_-L`
M`"8````(W```*0```"_<```D````6=P``"8```!^W```"````*7<```*````
MKMP```D```"YW```!P```,/<```@````R]P``"````#LW```)@````W=```*
M````--T``!D````_W0``*0```%G=```6````@]T``!(```":W0``!P```*W=
M```*````M=T```P```#`W0``#P```,W=```0````W=T``$````#NW0``<```
M`"_>``!F````H-X```X````'WP``"0```!;?```*````(-\``!(````KWP``
M$P```#[?```,````4M\```8```!?WP``#P```&;?```2````=M\``!````")
MWP``$0```)K?```<````K-\``",```#)WP``:@```.W?```/````6.````4`
M``!HX```$````&[@```)````?^````0```")X```"P```([@```@````FN``
M`!0```"[X```#````-#@```,````W>````\```#JX```%0```/K@```I````
M$.$``"H````ZX0``)@```&7A```G````C.$``"D```"TX0``*@```-[A```9
M````">(``$(````CX@``$0```&;B```2````>.(``!,```"+X@``%````)_B
M```/````M.(``!8```#$X@``%P```-OB```0````\^(``!$````$XP``-```
M`!;C```3````2^,``!(```!?XP``-0```'+C```4````J.,```<```"]XP``
M#````,7C```@````TN,``!````#SXP``%`````3D```1````&>0``!<````K
MY```'````$/D```3````8.0``!0```!TY```&@```(GD```1````I.0``!H`
M``"VY```'@```-'D```:````\.0``!,````+Y0``%0```!_E```1````->4`
M`!<```!'Y0``%````%_E```7````=.4``!4```",Y0``"0```*+E```0````
MK.4``!D```"]Y0``!````-?E```'````W.4```L```#DY0``$0```/#E```&
M`````N8```8````)Y@``!@```!#F```%````%^8```<````=Y@``!P```"7F
M```%````+>8``!8````SY@``!@```$KF```&````4>8```0```!8Y@``!```
M`%WF```'````8N8```X```!JY@``#````'GF```,````AN8```T```"3Y@``
M"@```*'F```.````K.8```4```"[Y@``*````,'F```.````ZN8```P```#Y
MY@``#P````;G```*````%N<```@````AYP``"0```"KG```K````-.<```0`
M``!@YP``"````&7G```F````;N<``!(```"5YP``#P```*CG```&````N.<`
M``H```"_YP``!P```,KG```(````TN<``"````#;YP``"0```/SG```4````
M!N@```P````;Z```#0```"CH```.````-N@``!8```!%Z```$0```%SH```&
M````;N@```,```!UZ```!@```'GH```9````@.@```<```":Z```!````*+H
M```+````I^@```L```"SZ```!P```+_H```%````Q^@```<```#-Z```%@``
M`-7H```-````[.@```T```#ZZ```"@````CI```0````$^D```\````DZ0``
M$0```#3I```7````1ND```H```!>Z0``$0```&GI```(````>^D```0```"$
MZ0``#P```(GI```Z````F>D```4```#4Z0``#````-KI```>````Y^D```X`
M```&Z@``$````!7J```+````)NH```P````RZ@``"0```#_J```'````2>H`
M``H```!1Z@``"0```%SJ```.````9NH``!````!UZ@``&P```(;J```8````
MHNH``!H```"[Z@``"@```-;J```)````X>H```H```#KZ@``#````/;J```/
M`````^L```@````3ZP``!@```!SK```<````(^L```<```!`ZP``!0```$CK
M```+````3NL``$<```!:ZP``#0```*+K```)````L.L```0```"ZZP```P``
M`+_K```3````P^L``!,```#7ZP``$P```.OK```*````_^L```(````*[```
M!`````WL```E````$NP```,````X[```!0```#SL```J````0NP```H```!M
M[```!0```'CL```$````?NP```H```"#[```#0```([L```&````G.P```@`
M``"C[```"````*SL```$````M>P```4```"Z[```:````,#L```)````*>T`
M``P````S[0``$````$#M```%````4>T```8```!7[0``&P```%[M```O````
M>NT``!````"J[0``"@```+OM```/````QNT```H```#6[0``"0```.'M```3
M````Z^T``!L```#_[0``&````!ON```7````-.X``!\```!,[@``#@```&SN
M```#````>^X```<```!_[@``"````(?N```'````D.X```H```"8[@``"P``
M`*/N```'````K^X``%$```"W[@``$`````GO```,````&N\```T````G[P``
M&@```#7O``!*````4.\``!D```";[P``!@```+7O```:````O.\``"4```#7
M[P``!@```/WO```&````!/```!\````+\```!@```"OP```)````,O```!@`
M```\\```%P```%7P```H````;?````8```"6\```#0```)WP```B````J_``
M`%<```#.\```$P```";Q```C````.O$``!,```!>\0```@```'+Q```+````
M=?$```@```"!\0``#0```(KQ```*````F/$```<```"C\0``%````*OQ```&
M````P/$```@```#'\0``#@```-#Q```'````W_$```H```#G\0``"P```/+Q
M```R````_O$```<````Q\@``#````#GR```-````1O(```P```!4\@``"0``
M`&'R```)````:_(```H```!U\@``!P```(#R```)````B/(```<```"2\@``
M"@```)KR```;````I?(```\```#!\@``$@```-'R```*````Y/(``!8```#O
M\@``"0````;S```0````$/,```<````A\P``$@```"GS```$````//,```<`
M``!!\P``!0```$GS```%````3_,```L```!5\P``%````&'S```1````=O,`
M`!H```"(\P``%@```*/S```4````NO,``!<```#/\P``&````.?S```<````
M`/0``!D````=]```!P```#?T```%````/_0```T```!%]```#````%/T```1
M````8/0```@```!R]```%P```'OT```+````D_0```P```"?]```'P```*ST
M```:````S/0``!,```#G]```!````/OT```*`````/4```0````+]0``#0``
M`!#U```,````'O4```4````K]0``"0```#'U```%````._4```<```!!]0``
M!0```$GU```$````3_4```(```!4]0``.````%?U```L````D/4``!(```"]
M]0``*0```-#U```R````^O4```H````M]@``+````#CV```N````9?8``#,`
M``"4]@``,P```,CV```X````_/8```\````U]P``&````$7W```0````7O<`
M``\```!O]P``$P```'_W```5````D_<``!0```"I]P``$@```+[W```4````
MT?<``!4```#F]P``+0```/SW```M````*O@``#$```!8^```+@```(KX```O
M````N?@``"P```#I^```8@```!;Y```3````>?D```T```"-^0``"````)OY
M```7````I/D```@```"\^0``#````,7Y```K````TOD``"$```#^^0``&@``
M`"#Z```)````._H``$4```!%^@``00```(OZ```$````S?H``!,```#2^@``
M%````.;Z```.````^_H``!,````*^P``&````![[```&````-_L```D````^
M^P``"@```$C[```/````4_L``!````!C^P``!P```'3[```.````?/L```4`
M``"+^P``&P```)'[```(````K?L```8```"V^P``%````+W[```1````TOL`
M``X```#D^P``.````//[```"````+/P```8````O_```#@```#;\```%````
M1?P```<```!+_```#@```%/\```&````8OP``"@```!I_```#````)+\```<
M````G_P```0```"\_```*0```,'\```7````Z_P``!\````#_0``7````"/]
M```4````@/T``#X```"5_0``'P```-3]```0````]/T```<````%_@``#@``
M``W^```,````'/X```P````I_@``$P```#;^```*````2OX``!T```!5_@``
M&0```'/^```%````C?X``!$```"3_@``$0```*7^```D````M_X``!(```#<
M_@``%0```._^```2````!?\```X````8_P``&0```"?_```(````0?\```D`
M``!*_P``#0```%3_```*````8O\```<```!M_P``#P```'7_```&````A?\`
M``L```",_P``&@```)C_```*````L_\```<```"^_P``"````,;_```%````
MS_\``!\```#5_P``!@```/7_```0````_/\```@````-``$`#0```!8``0`(
M````)``!`!X````M``$`$@```$P``0`L````7P`!`!H```",``$`"0```*<`
M`0`*````L0`!`!4```"\``$`!0```-(``0`4````V``!``0```#M``$`$```
M`/(``0`&`````P$!``<````*`0$`'@```!(!`0`H````,0$!``H```!:`0$`
M'````&4!`0`1````@@$!``L```"4`0$`&@```*`!`0`4````NP$!``0```#0
M`0$`!````-4!`0`+````V@$!``4```#F`0$`!@```.P!`0`(````\P$!``8`
M``#\`0$`"@````,"`0`;````#@(!`#0````J`@$`-````%\"`0`@````E`(!
M`"D```"U`@$`(````-\"`0!!``````,!`!H```!"`P$`*````%T#`0`I````
MA@,!`%````"P`P$`(@````$$`0`&````)`0!``@````K!`$`!0```#0$`0`(
M````.@0!`!D```!#!`$`&0```%T$`0`J````=P0!`",```"B!`$`&0```,8$
M`0`N````X`0!`#0````/!0$`"````$0%`0`7````304!``H```!E!0$`!P``
M`'`%`0`A````>`4!`!````":!0$`#@```*L%`0`+````N@4!``<```#&!0$`
M$P```,X%`0`(````X@4!``L```#K!0$`"@```/<%`0`4`````@8!``\````7
M!@$`,@```"<&`0`+````6@8!``4```!F!@$`!0```&P&`0`%````<@8!`!<`
M``!X!@$`#P```)`&`0`$````H`8!``H```"E!@$`"0```+`&`0`+````N@8!
M``T```#&!@$`#````-0&`0`.````X08!``4```#P!@$`!````/8&`0`-````
M^P8!`#(````)!P$`10```#P'`0`7````@@<!``<```":!P$`'@```*('`0`4
M````P0<!``4```#6!P$`%````-P'`0`&````\0<!``<```#X!P$`#@`````(
M`0`J````#P@!``8````Z"`$`#````$$(`0`-````3@@!`!$```!<"`$`"P``
M`&X(`0`V````>@@!``H```"Q"`$`(@```+P(`0`+````WP@!``\```#K"`$`
M,@```/L(`0`E````+@D!`#````!4"0$`,0```(4)`0`M````MPD!``X```#E
M"0$`!0```/0)`0`.````^@D!`!,````)"@$`$@```!T*`0`'````,`H!`!$`
M```X"@$`$P```$H*`0`'````7@H!`!0```!F"@$`&````'L*`0`'````E`H!
M``4```"<"@$`#````*(*`0`,````KPH!`!(```"\"@$`!````,\*`0`'````
MU`H!``H```#<"@$`"P```.<*`0`,````\PH!``X`````"P$`#@````\+`0`%
M````'@L!``4````D"P$`+@```"H+`0`F````60L!`",```"`"P$``P```*0+
M`0`2````J`L!``8```"["P$`'@```,(+`0`8````X0L!`"4```#Z"P$`#0``
M`"`,`0`)````+@P!`!\````X#`$``P```%@,`0`'````7`P!``H```!D#`$`
M`@```&\,`0`,````<@P!`!4```!_#`$`"P```)4,`0`9````H0P!`"````"[
M#`$`$@```-P,`0`%````[PP!``H```#U#`$`%0`````-`0`2````%@T!``P`
M```I#0$`!````#8-`0`)````.PT!``<```!%#0$`#````$T-`0!2````6@T!
M`!<```"M#0$`)````,4-`0`2````Z@T!``<```#]#0$`!@````4.`0`.````
M#`X!``P````;#@$`#0```"@.`0`5````-@X!`!(```!,#@$`#P```%\.`0`4
M````;PX!``H```"$#@$`&P```(\.`0`0````JPX!``L```"\#@$`:0```,@.
M`0`:````,@\!`!<```!-#P$`)P```&4/`0`:````C0\!`!<```"H#P$`&P``
M`,`/`0`9````W`\!`!\```#V#P$`$P```!80`0`(````*A`!``<````S$`$`
M"````#L0`0`)````1!`!`!4```!.$`$`#0```&00`0`C````<A`!``T```"6
M$`$`$P```*00`0`(````N!`!``,```#!$`$`1@```,40`0`_````#!$!`#<`
M``!,$0$`5P```(01`0`%````W!$!`!\```#B$0$`+P````(2`0`*````,A(!
M``@````]$@$`#0```$82`0`M````5!(!``0```""$@$`3P```(<2`0`E````
MUQ(!`!P```#]$@$`"P```!H3`0`?````)A,!`!T```!&$P$`)0```&03`0`@
M````BA,!`"0```"K$P$`(````-`3`0`+````\1,!``<```#]$P$`#0````44
M`0`,````$Q0!`!<````@%`$`!@```#@4`0`Y````/Q0!``P```!Y%`$`!P``
M`(84`0`)````CA0!`!,```"8%`$`"0```*P4`0`$````MA0!`!````"[%`$`
M"````,P4`0`(````U10!``0```#>%`$`"P```.,4`0`,````[Q0!`!(```#\
M%`$`$0````\5`0`,````(14!`!H````N%0$`#P```$D5`0`'````614!``T`
M``!A%0$`%````&\5`0`.````A!4!``P```"3%0$`&P```*`5`0`L````O!4!
M`!,```#I%0$`'````/T5`0`H````&A8!``8```!#%@$`!P```$H6`0`3````
M4A8!``4```!F%@$`!````&P6`0`7````<18!``H```")%@$`#````)06`0`)
M````H18!``8```"K%@$`"0```+(6`0`(````O!8!``D```#%%@$`"@```,\6
M`0`1````VA8!``8```#L%@$`#@```/,6`0`.`````A<!``T````1%P$`"P``
M`!\7`0`=````*Q<!``L```!)%P$``@```%47`0`<````6!<!``<```!U%P$`
M!@```'T7`0!D````A!<!``D```#I%P$`!P```/,7`0`F````^Q<!`#@````B
M&`$`&@```%L8`0`J````=A@!`#L```"A&`$`*````-T8`0`T````!AD!`!D`
M```[&0$`%0```%49`0`%````:QD!``<```!Q&0$`"````'D9`0`'````@AD!
M``4```"*&0$`!P```)`9`0`.````F!D!``D```"G&0$`!@```+$9`0`(````
MN!D!``L```#!&0$`!P```,T9`0`(````U1D!``<```#>&0$`%@```.89`0`)
M````_1D!``8````'&@$`"P````X:`0`0````&AH!``8````K&@$`'````#(:
M`0`4````3QH!``<```!D&@$`$0```&P:`0`(````?AH!``X```"'&@$`"```
M`)8:`0`%````GQH!`!````"E&@$`"0```+8:`0`0````P!H!``8```#1&@$`
M&0```-@:`0`*````\AH!`!P```#]&@$`!P```!H;`0`%````(AL!`!`````H
M&P$`%````#D;`0`+````3AL!``T```!:&P$`*````&@;`0`8````D1L!`!<`
M``"J&P$`!````,(;`0`)````QQL!``H```#1&P$`!P```-P;`0`"````Y!L!
M``X```#G&P$`"````/8;`0`C````_QL!`#@````C'`$`)@```%P<`0`Q````
M@QP!`"<```"U'`$`9````-T<`0`4````0AT!`%4```!7'0$`.````*T=`0!*
M````YAT!`%L````Q'@$`*````(T>`0`X````MAX!`"@```#O'@$`+````!@?
M`0`F````11\!`!L```!L'P$`/@```(@?`0"I`0``QQ\!`",```!Q(0$`%P``
M`)4A`0!(````K2$!`(4```#V(0$`,````'PB`0`E````K2(!`$$```#3(@$`
M6P```!4C`0!)````<2,!`#$```"[(P$`'0```.TC`0`8````"R0!`"L````D
M)`$`(0```%`D`0`?````<B0!`"L```"2)`$`(0```+XD`0`G````X"0!`#H`
M```()0$`'0```$,E`0`1````824!`#,```!S)0$`)0```*<E`0`G````S24!
M`"````#U)0$`'P```!8F`0`P````-B8!`&D```!G)@$`,0```-$F`0!!````
M`R<!`#,```!%)P$`)0```'DG`0`]````GR<!`&4```#=)P$`30```$,H`0`O
M````D2@!`"X```#!*`$`,````/`H`0!4````(2D!`%H```!V*0$`2````-$I
M`0!*````&BH!`#(```!E*@$`+P```)@J`0`L````R"H!`"T```#U*@$`<0``
M`",K`0!F````E2L!`&\```#\*P$`LP```&PL`0`7````("T!`"4````X+0$`
M,@```%XM`0`I````D2T!`#X```"[+0$`(@```/HM`0!2````'2X!`"4```!P
M+@$`"P```)8N`0"Q````HBX!`$4```!4+P$`(0```)HO`0`P````O"\!`"4`
M``#M+P$`'````!,P`0`Q````,#`!``<```!B,`$`!P```&HP`0`$````<C`!
M``T```!W,`$`"P```(4P`0`.````D3`!``L```"@,`$`!0```*PP`0`0````
MLC`!``(```##,`$`60```,8P`0`%````(#$!`!(````F,0$`!````#DQ`0`'
M````/C$!``@```!&,0$`!0```$\Q`0`#````53$!`!````!9,0$`#````&HQ
M`0`3````=S$!``T```"+,0$``@```)DQ`0`'````G#$!``8```"D,0$`%```
M`*LQ`0`,````P#$!`!@```#-,0$`!@```.8Q`0`2````[3$!``P`````,@$`
M`P````TR`0`J````$3(!``0````\,@$`!@```$$R`0`'````2#(!`!\```!0
M,@$`-0```'`R`0`N````IC(!`"\```#5,@$`%P````4S`0`B````'3,!`"4`
M``!`,P$`(````&8S`0`;````AS,!`!@```"C,P$`)````+PS`0`?````X3,!
M`!H````!-`$`(0```!PT`0`@````/C0!`!H```!?-`$`,@```'HT`0`:````
MK30!`"\```#(-`$`*P```/@T`0`?````)#4!`",```!$-0$`'P```&@U`0`:
M````B#4!`"$```"C-0$`)0```,4U`0`F````ZS4!`"4````2-@$`)````#@V
M`0`8````738!`!T```!V-@$`)````)0V`0`8````N38!`"(```#2-@$`+```
M`/4V`0`O````(C<!`!4```!2-P$`)0```&@W`0`\````CC<!`!\```#+-P$`
M(P```.LW`0`?````#S@!`"`````O.`$`&@```%`X`0`8````:S@!`"8```"$
M.`$`'@```*LX`0`I````RC@!`!X```#T.`$`,0```!,Y`0`)````13D!``P`
M``!/.0$`%P```%PY`0`O````=#D!`"0```"D.0$`!P```,DY`0`/````T3D!
M`!0```#A.0$`#@```/8Y`0`-````!3H!`"0````3.@$`!0```#@Z`0`'````
M/CH!`"(```!&.@$`)0```&DZ`0`:````CSH!`!T```"J.@$`&@```,@Z`0`'
M````XSH!`,<```#K.@$`"P```+,[`0`5````OSL!``8```#5.P$`"0```-P[
M`0`+````YCL!``T```#R.P$`%P`````\`0`&````&#P!`#,````?/`$`$P``
M`%,\`0`3````9SP!``<```![/`$`#P```(,\`0`'````DSP!`#(```";/`$`
M!````,X\`0`A````TSP!`!,```#U/`$`#`````D]`0`1````%CT!`#(````H
M/0$`%@```%L]`0`(````<CT!`!T```![/0$`"0```)D]`0`*````HST!`!0`
M``"N/0$`"@```,,]`0`=````SCT!``@```#L/0$`'P```/4]`0`(````%3X!
M`!H````>/@$`)P```#D^`0`&````83X!`!4```!H/@$`!P```'X^`0`(````
MACX!``D```"//@$`/P```)D^`0`'````V3X!``\```#A/@$`#@```/$^`0`0
M`````#\!``D````1/P$`"0```!L_`0`(````)3\!`!,````N/P$`!P```$(_
M`0`9````2C\!``H```!D/P$`%P```&\_`0`4````AS\!``H```"</P$`#```
M`*<_`0`7````M#\!``0```#,/P$`*@```-$_`0`,````_#\!`!$````)0`$`
M!P```!M``0`"````(T`!`!`````F0`$`&````#=``0`+````4$`!``,```!<
M0`$`"````&!``0`&````:4`!``<```!P0`$`#0```'A``0`+````AD`!`!0`
M``"20`$`%0```*=``0`.````O4`!`"\```#,0`$`(````/Q``0`<````'4$!
M`!4````Z00$`#````%!!`0`Q````74$!``4```"/00$`$@```)5!`0`_````
MJ$$!`!(```#H00$`"@```/M!`0`&````!D(!``0````-0@$`!````!)"`0`*
M````%T(!`!,````B0@$`!0```#9"`0`&````/$(!``8```!#0@$`"````$I"
M`0`$````4T(!``P```!80@$`"@```&5"`0`Y````<$(!`"X```"J0@$`*0``
M`-E"`0`%`````T,!`!@````)0P$`&0```")#`0`?````/$,!`!T```!<0P$`
M$0```'I#`0`"````C$,!``0```"/0P$`"@```)1#`0`&````GT,!``4```"F
M0P$``P```*Q#`0`,````L$,!`$4```"]0P$`,@````-$`0`:````-D0!`#0`
M``!11`$`*````(9$`0!3````KT0!`!D````#10$`<@```!U%`0`@````D$4!
M`#4```"Q10$`(0```.=%`0!%````"48!`#````!/1@$`*````(!&`0`I````
MJ48!`"8```#31@$`)0```/I&`0`H````($<!`"@```!)1P$`(@```')'`0`K
M````E4<!`#````#!1P$`$@```/)'`0`3````!4@!`!`````92`$`>0```"I(
M`0`)````I$@!`*$```"N2`$`<P```%!)`0!\````Q$D!`"L```!!2@$`5```
M`&U*`0`7````PDH!`"<```#:2@$`%@````)+`0`/````&4L!`!<````I2P$`
M'P```$%+`0!`````84L!`!\```"B2P$`'````,)+`0!1````WTL!`!H````Q
M3`$`%````$Q,`0`*````84P!``4```!L3`$`!@```'),`0`(````>4P!``4`
M``""3`$`$@```(A,`0`0````FTP!`!,```"L3`$`'0```,!,`0`/````WDP!
M``\```#N3`$`!````/Y,`0`)`````TT!``L````-30$`!P```!E-`0`%````
M(4T!`!0````G30$`!P```#Q-`0`(````1$T!``\```!-30$`"````%U-`0`,
M````9DT!``\```!S30$`!@```(--`0`4````BDT!``8```"?30$`#````*9-
M`0`1````LTT!``@```#%30$`!````,Y-`0`9````TTT!`!$```#M30$`"@``
M`/]-`0`8````"DX!`!,````C3@$`'````#=.`0`1````5$X!``\```!F3@$`
M!P```'9.`0`$````?DX!`!D```"#3@$`!P```)U.`0`"````I4X!``(```"H
M3@$`$0```*M.`0`)````O4X!``8```#'3@$`$@```,Y.`0`7````X4X!``8`
M``#Y3@$`)P````!/`0`"````*$\!``0````K3P$`#P```#!/`0`3````0$\!
M``<```!43P$`!P```%Q/`0`1````9$\!``8```!V3P$`&````'U/`0`&````
MED\!`!,```"=3P$`$````+%/`0`2````PD\!``(```#53P$`!@```-A/`0`,
M````WT\!``D```#L3P$`$0```/9/`0`B````"%`!``<````K4`$`!P```#-0
M`0`+````.U`!``4```!'4`$``@```$U0`0`+````4%`!`'\!``!<4`$`$@``
M`-Q1`0`;````[U$!`!`````+4@$`#@```!Q2`0`)````*U(!``<````U4@$`
M`P```#U2`0`;````05(!`"$```!=4@$`-0```']2`0`Q````M5(!`"L```#G
M4@$`+P```!-3`0`=````0U,!`"T```!A4P$`"P```(]3`0`R````FU,!`!0`
M``#.4P$`"P```.-3`0`3````[U,!``4````#5`$`,0````E4`0`0````.U0!
M`!$```!,5`$`'@```%Y4`0`/````?50!``L```"-5`$`E@```)E4`0`2````
M,%4!``H```!#50$`#0```$Y5`0`-````7%4!`!<```!J50$`#````()5`0`0
M````CU4!`!4```"@50$`!P```+95`0"=````OE4!``P```!<5@$`#````&E6
M`0`4````=E8!`!(```"+5@$`$````)Y6`0`0````KU8!``D```#`5@$`"@``
M`,I6`0!$````U58!`"`````:5P$`/@```#M7`0!-````>E<!`&X```#(5P$`
M:@```#=8`0!T````HE@!`'`````760$`00```(A9`0`/````RED!`!4```#:
M60$`#@```/!9`0`0````_UD!`!@````06@$`!0```"E:`0`&````+UH!`!<`
M```V6@$`"P```$Y:`0`*````6EH!``T```!E6@$`-````'-:`0`P````J%H!
M`!0```#96@$`%@```.Y:`0`.````!5L!``<````46P$`!P```!Q;`0`6````
M)%L!`"0````[6P$`#0```&!;`0`9````;EL!`!\```"(6P$`'P```*A;`0`E
M````R%L!`!\```#N6P$`$P````Y<`0`;````(EP!`!$````^7`$`*````%!<
M`0`>````>5P!`!\```"87`$`%@```+A<`0!A````SUP!`#`````Q70$`,@``
M`&)=`0`'````E5T!`!$```"=70$`0P```*]=`0`.````\UT!``0````"7@$`
M"P````=>`0`'````$UX!``<````;7@$`!0```"->`0`'````*5X!``P````Q
M7@$`!````#Y>`0`B````0UX!`!````!F7@$`%@```'=>`0`0````CEX!`"P`
M``"?7@$`,0```,Q>`0`+````_EX!`"$````*7P$`'````"Q?`0`A````25\!
M`!\```!K7P$`#@```(M?`0`2````FE\!``\```"M7P$`)````+U?`0`C````
MXE\!``<````&8`$`!@````Y@`0`(````%6`!``T````>8`$`!P```"Q@`0`+
M````-&`!`!(```!`8`$`"P```%-@`0`4````7V`!`!<```!T8`$`&P```(Q@
M`0`(````J&`!`!0```"Q8`$`!0```,9@`0`4````S&`!`!D```#A8`$`$```
M`/M@`0!-````#&$!`$$```!:80$`"0```)QA`0`'````IF$!`!0```"N80$`
M`P```,-A`0`%````QV$!``\```#-80$`"0```-UA`0`5````YV$!`$D```#]
M80$`$P```$=B`0`N````6V(!`#4```"*8@$`-P```,!B`0`R````^&(!``H`
M```K8P$`!````#9C`0`)````.V,!``@```!%8P$`,````$YC`0`W````?V,!
M`"\```"W8P$`7@```.=C`0`O````1F0!`"\```!V9`$`2P```*9D`0!.````
M\F0!`"\```!!90$`5````'%E`0`T````QF4!`#<```#[90$`5P```#-F`0`O
M````BV8!`#4```"[9@$`+````/%F`0`;````'F<!`!X````Z9P$`+@```%EG
M`0`K````B&<!`"L```"T9P$`%````.!G`0`+````]6<!``P````!:`$`#P``
M``YH`0`/````'F@!`!T````N:`$`(0```$QH`0`'````;F@!``<```!V:`$`
M$P```'YH`0`*````DF@!``<```"=:`$`+````*5H`0`-````TF@!``<```#@
M:`$`"````.AH`0`&````\6@!``4```#X:`$`"````/YH`0`'````!VD!``P`
M```/:0$`*@```!QI`0`3````1VD!``P```!;:0$`!````&AI`0`'````;6D!
M``<```!U:0$`!P```'UI`0`9````A6D!``4```"?:0$`$@```*5I`0`(````
MN&D!``@```#!:0$``P```,II`0`&````SFD!``8```#5:0$`*@```-QI`0`2
M````!VH!``@````::@$`#0```"-J`0`,````,6H!``<````^:@$`$@```$9J
M`0`#````66H!`$$```!=:@$`&0```)]J`0`P````N6H!``8```#J:@$`!0``
M`/%J`0`(````]VH!``@`````:P$`9`````EK`0`J````;FL!`#\```"9:P$`
M*@```-EK`0`F````!&P!``8````K;`$`!P```#)L`0`>````.FP!`"H```!9
M;`$`+@```(1L`0`W````LVP!`"T```#K;`$`-P```!EM`0!O````46T!`#,`
M``#!;0$`"````/5M`0`'````_FT!``P````&;@$`&````!-N`0`+````+&X!
M`!0````X;@$`&````$UN`0`B````9FX!`!@```");@$`&@```*)N`0`5````
MO6X!`!,```#3;@$`!P```.=N`0`9````[VX!`!T````);P$`%0```"=O`0`:
M````/6\!`!H```!8;P$`!0```'-O`0`(````>6\!`!L```"";P$`<@```)YO
M`0!Y````$7`!``0```"+<`$`$0```)!P`0`%````HG`!``4```"H<`$`&@``
M`*YP`0`;````R7`!`!<```#E<`$`%P```/UP`0`;````%7$!`"<````Q<0$`
M-@```%EQ`0`.````D'$!`"H```"?<0$`!P```,IQ`0`>````TG$!`!(```#Q
M<0$`&0````1R`0`5````'G(!`"0````T<@$`'P```%ER`0`7````>7(!`!,`
M``"1<@$`$0```*5R`0`&````MW(!``\```"^<@$`!P```,YR`0`*````UG(!
M`!@```#A<@$`$0```/IR`0`(````#',!``<````5<P$`$P```!US`0`7````
M,7,!``8```!)<P$`$0```%!S`0`$````8G,!``@```!G<P$`#@```'!S`0`+
M````?W,!``D```"+<P$`!P```)5S`0`'````G7,!``L```"E<P$`"0```+%S
M`0`*````NW,!`!P```#&<P$`20```.-S`0`B````+70!``T```!0=`$`&0``
M`%YT`0`%````>'0!`"````!^=`$`%0```)]T`0`8````M70!`"T```#.=`$`
M/P```/QT`0`D````/'4!``@```!A=0$`/````&IU`0`G````IW4!`!$```#/
M=0$`"@```.%U`0`)````['4!``\```#V=0$`!@````9V`0`6````#78!`!4`
M```D=@$`"````#IV`0`*````0W8!``T```!.=@$`)````%QV`0`F````@78!
M`"X```"H=@$`)P```-=V`0`@````_W8!`"4````@=P$`)````$9W`0`J````
M:W<!`"4```"6=P$`-````+QW`0`P````\7<!`"L````B>`$`+````$YX`0`C
M````>W@!`#$```"?>`$`-@```-%X`0`V````"'D!`"L````_>0$`,0```&MY
M`0!!````G7D!`"H```#?>0$`*0````IZ`0!#````-'H!`"L```!X>@$`&P``
M`*1Z`0`Q````P'H!`"<```#R>@$`)P```!I[`0`:````0GL!`+,```!=>P$`
M'P```!%\`0`J````,7P!`"X```!<?`$`,````(M\`0`M````O'P!`#(```#J
M?`$`*0```!U]`0`K````1WT!`#L```!S?0$`.P```*]]`0!`````ZWT!`$(`
M```L?@$`L@```&]^`0`G````(G\!`"$```!*?P$`)0```&Q_`0`R````DG\!
M`#D```#%?P$`1@```/]_`0!/````1H`!``P```"6@`$`!````*.``0`%````
MJ(`!``4```"N@`$`#0```+2``0`0````PH`!`!4```#3@`$`%P```.F``0`9
M`````8$!``<````;@0$`!````".!`0`2````*($!`!$````[@0$`#@```$V!
M`0`:````7($!`!0```!W@0$`%@```(R!`0`5````HX$!``T```"Y@0$`.0``
M`,>!`0`&`````8(!`!,````(@@$`!@```!R"`0`3````(X(!`!D````W@@$`
M'0```%&"`0`2````;X(!``(```""@@$`20```(6"`0`+````SX(!`!8```#;
M@@$`$````/*"`0`$`````X,!`!$````(@P$`%````!J#`0`$````+X,!`!4`
M```T@P$`"````$J#`0`0````4X,!`!8```!D@P$`!@```'N#`0`2````@H,!
M`!,```"5@P$`(P```*F#`0`+````S8,!``<```#9@P$`$@```.&#`0`3````
M](,!`!`````(A`$`&````!F$`0`@````,H0!`!(```!3A`$`$@```&:$`0`B
M````>80!`"4```"<A`$`10```,*$`0`1````"(4!`"$````:A0$`&P```#R%
M`0`:````6(4!`#<```!SA0$`$@```*N%`0`(````OH4!`!,```#'A0$`"P``
M`-N%`0`T````YX4!`#0````<A@$`#0```%&&`0`.````7X8!`"@```!NA@$`
M$0```)>&`0`2````J88!`!(```"\A@$`"@```,^&`0`8````VH8!`!,```#S
MA@$`'P````>'`0`;````)X<!`!(```!#AP$`$0```%:'`0`(````:(<!`!``
M``!QAP$`+````(*'`0!B````KX<!``D````2B`$`%@```!R(`0`M````,X@!
M``L```!AB`$`#@```&V(`0`X````?(@!`!````"UB`$`!P```,:(`0`5````
MSH@!`$D```#DB`$``P```"Z)`0`(````,HD!``@````[B0$`#@```$2)`0`0
M````4XD!`!4```!DB0$`%@```'J)`0`B````D8D!`!D```"TB0$`(@```,Z)
M`0`>````\8D!``D````0B@$`!@```!J*`0`(````(8H!``H````JB@$``@``
M`#6*`0`4````.(H!`!0```!-B@$`,````&**`0`:````DXH!`!D```"NB@$`
M"@```,B*`0`-````TXH!``X```#AB@$`&````/"*`0!%````"8L!`"\```!/
MBP$`#@```'^+`0`2````CHL!`*````"ABP$`)@```$*,`0`?````:8P!`!(`
M``")C`$`"````)R,`0`&````I8P!`"<```"LC`$`0````-2,`0!`````%8T!
M`"X```!6C0$`,@```(6-`0`7````N(T!`"H```#0C0$`!P```/N-`0`(````
M`XX!``@````,C@$`!@```!6.`0`9````'(X!`!0````VC@$`%@```$N.`0`4
M````8HX!`!(```!WC@$`&@```(J.`0`2````I8X!`!0```"XC@$`"````,V.
M`0`*````UHX!`!@```#AC@$`#@```/J.`0`S````"8\!`!$````]CP$`#```
M`$^/`0`4````7(\!`#H```!QCP$`(P```*R/`0`F````T(\!`"4```#WCP$`
M(````!V0`0`?````/I`!`"\```!>D`$`(0```(Z0`0`B````L)`!``0```#3
MD`$`&0```-B0`0`*````\I`!``\```#]D`$``P````V1`0`*````$9$!``<`
M```<D0$`%0```"21`0`8````.I$!`!````!3D0$`&````&21`0`2````?9$!
M``X```"0D0$`&@```)^1`0`%````NI$!``<```#`D0$`%P```,B1`0`7````
MX)$!`!@```#XD0$`#@```!&2`0`0````()(!`!D````QD@$`+0```$N2`0`'
M````>9(!``@```"!D@$`#@```(J2`0`0````F9(!``X```"JD@$`"0```+F2
M`0`(````PY(!``H```#,D@$`%@```->2`0`1````[I(!``H`````DP$`,0``
M``N3`0`/````/9,!`(0```!-DP$`)0```-*3`0`+````^),!``@````$E`$`
M$`````V4`0`)````'I0!``L````HE`$`!@```#24`0`+````.Y0!``(```!'
ME`$`!@```$J4`0`&````490!`!4```!8E`$`$````&Z4`0`3````?Y0!`"L`
M``"3E`$``@```+^4`0`#````PI0!`!0```#&E`$`"P```-N4`0`+````YY0!
M``4```#SE`$`&@```/F4`0`'````%)4!``8````<E0$`'@```".5`0`+````
M0I4!``<```!.E0$`"0```%:5`0`%````8)4!``D```!FE0$`!@```'"5`0`%
M````=Y4!``8```!]E0$`#0```(25`0`0````DI4!``X```"CE0$`!0```+*5
M`0`1````N)4!``D```#*E0$`!P```-25`0`:````W)4!`"P```#WE0$`4```
M`"26`0`P````=98!`#$```"FE@$`!P```-B6`0`*````X)8!``0```#KE@$`
M"0```/"6`0`)````^I8!`!<````$EP$`"@```!R7`0`&````)Y<!``T````N
MEP$`!@```#R7`0`$````0Y<!`$8```!(EP$`1````(^7`0!#````U)<!`"(`
M```8F`$`!0```#N8`0`5````09@!``L```!7F`$`!P```&.8`0`(````:Y@!
M`!8```!TF`$`#P```(N8`0`5````FY@!``<```"QF`$`!````+F8`0`3````
MOI@!``0```#2F`$`"@```->8`0`;````XI@!``4```#^F`$`"`````29`0`/
M````#9D!``<````=F0$`$P```"69`0`4````.9D!`!,```!.F0$`"````&*9
M`0`)````:YD!``4```!UF0$`1````'N9`0`U````P)D!`#X```#VF0$`+```
M`#6:`0!+````8IH!`$4```"NF@$`,0```/2:`0!2````)IL!`#<```!YFP$`
M.@```+&;`0`D````[)L!`!$````1G`$`%@```".<`0`,````.IP!`#,```!'
MG`$`*P```'N<`0`G````IYP!`"H```#/G`$`"````/J<`0`+`````YT!``H`
M```/G0$`!P```!J=`0`O````(IT!`#(```!2G0$`.0```(6=`0`*````OYT!
M`!H```#*G0$`)````.6=`0`8````"IX!`!4````CG@$`!P```#F>`0`0````
M09X!``X```!2G@$`$0```&&>`0`/````<YX!`$T```"#G@$`BP```-&>`0!W
M````79\!`!,```#5GP$`%@```.F?`0`8`````*`!`!`````9H`$`$@```"J@
M`0`7````/:`!``8```!5H`$`%0```%R@`0`2````<J`!`!$```"%H`$`%0``
M`)>@`0`8````K:`!`#4```#&H`$`>````/R@`0`7````=:$!``0```"-H0$`
M&````)*A`0`)````JZ$!``0```"UH0$`#````+JA`0`D````QZ$!`!8```#L
MH0$`#0````.B`0`2````$:(!`!,````DH@$`%@```#BB`0`V````3Z(!`#8`
M``"&H@$`-````+VB`0`T````\J(!`#`````GHP$`,````%BC`0`7````B:,!
M`%0```"AHP$`%0```/:C`0`5````#*0!`!4````BI`$`%0```#BD`0`4````
M3J0!`!@```!CI`$`&````'RD`0`4````E:0!`!0```"JI`$`,````+^D`0`:
M````\*0!`!P````+I0$`.P```"BE`0`3````9*4!``8```!XI0$`#@```'^E
M`0`?````CJ4!`!0```"NI0$`%0```,.E`0`3````V:4!`!L```#MI0$`(```
M``FF`0`;````*J8!`!D```!&I@$`'0```&"F`0`4````?J8!`!X```"3I@$`
M(@```+*F`0`4````U:8!`!L```#JI@$`&0````:G`0`3````(*<!`!X````T
MIP$`&0```%.G`0`8````;:<!`!@```"&IP$`"@```)^G`0`5````JJ<!``0`
M``#`IP$`!````,6G`0`'````RJ<!``H```#2IP$`$````-VG`0`&````[J<!
M``@```#UIP$`"````/ZG`0`&````!Z@!``@````.J`$`!P```!>H`0`%````
M'Z@!`!8````EJ`$`!@```#RH`0`(````0Z@!``<```!,J`$`!````%2H`0`)
M````6:@!``<```!CJ`$`"0```&NH`0`0````=:@!`!````"&J`$`"@```)>H
M`0`3````HJ@!``4```"VJ`$`,````+RH`0`2````[:@!`!``````J0$`%```
M`!&I`0`3````)JD!``P````ZJ0$`%@```$>I`0`V````7JD!``<```"5J0$`
M"````)VI`0`-````IJD!``P```"TJ0$`#P```,&I`0`&````T:D!``P```#8
MJ0$`#0```.6I`0`&````\ZD!``0```#ZJ0$`#@```/^I`0`E````#JH!`!``
M```TJ@$`%@```$6J`0`7````7*H!`"8```!TJ@$`&P```)NJ`0`(````MZH!
M``,```#`J@$`#````,2J`0`I````T:H!``4```#[J@$`!@````&K`0`-````
M"*L!`!$````6JP$`!P```"BK`0`&````,*L!``<````WJP$`!0```#^K`0`-
M````1:L!``T```!3JP$`#````&&K`0`@````;JL!`!$```"/JP$`#P```*&K
M`0`:````L:L!`!,```#,JP$`%@```."K`0`%````]ZL!``0```#]JP$`%0``
M``*L`0!,````&*P!``4```!EK`$`#0```&NL`0`H````>:P!`!H```"BK`$`
M#P```+VL`0`3````S:P!`!0```#AK`$`$````/:L`0`/````!ZT!`!@````7
MK0$`$````#"M`0`5````0:T!`!D```!7K0$`(P```'&M`0`G````E:T!`#<`
M``"]K0$`"P```/6M`0`(`````:X!``T````*K@$`#P```!BN`0`/````**X!
M``0````XK@$`"0```#VN`0`O````1ZX!``L```!WK@$`"0```(.N`0`3````
MC:X!`&L```"AK@$`$P````VO`0`*````(:\!``4````LKP$`!@```#*O`0`:
M````.:\!`!D```!4KP$`&0```&ZO`0`*````B*\!``(```"3KP$`%@```):O
M`0`S````K:\!``,```#AKP$`!0```.6O`0`7````ZZ\!``H````#L`$`!0``
M``ZP`0`(````%+`!`!H````=L`$`#@```#BP`0`&````1[`!``@```!.L`$`
M"````%>P`0`$````8+`!``4```!EL`$`2@```&NP`0`/````MK`!`!(```#&
ML`$`'0```-FP`0`$````][`!``4```#\L`$`)0````*Q`0`Y````*+$!``T`
M``!BL0$`"@```'"Q`0`1````>[$!``H```"-L0$`"P```)BQ`0`6````I+$!
M`!L```"[L0$`+P```->Q`0`N````![(!`"(````VL@$`$````%FR`0`#````
M:K(!``<```!NL@$`"@```':R`0`'````@;(!``X```")L@$`%@```)BR`0`'
M````K[(!`%H```"WL@$`#P```!*S`0`/````(K,!``L````RLP$`)P```#ZS
M`0!=````9K,!`!L```#$LP$`!P```."S`0`C````Z+,!`"D````,M`$`"```
M`#:T`0`'````/[0!`!L```!'M`$`!@```&.T`0`)````:K0!`"X```!TM`$`
M+0```*.T`0`W````T;0!``8````)M0$`!@```!"U`0`L````%[4!`&8```!$
MM0$`%P```*NU`0`D````P[4!`!<```#HM0$``@````"V`0`1`````[8!``8`
M```5M@$`%````!RV`0`.````,;8!``8```!`M@$`"````$>V`0`&````4+8!
M``@```!7M@$`#0```&"V`0`-````;K8!``H```!\M@$`$0```(>V`0`[````
MF;8!``4```#5M@$`%P```-NV`0`4````\[8!`!<````(MP$`"P```""W`0`1
M````++<!`!$````^MP$`#````%"W`0`+````7;<!``P```!IMP$`"@```':W
M`0`@````@;<!`!4```"BMP$`$@```+BW`0`5````R[<!`!@```#AMP$`"P``
M`/JW`0`;````!K@!``@````BN`$`%0```"NX`0`#````0;@!``<```!%N`$`
M!0```$VX`0`%````4[@!``@```!9N`$`%@```&*X`0`7````>;@!`"0```"1
MN`$`(P```+:X`0`>````VK@!`!H```#YN`$`&P```!2Y`0`B````,+D!`!L`
M``!3N0$`!@```&^Y`0`&````=KD!`!(```!]N0$`$@```)"Y`0`4````H[D!
M``T```"XN0$`)0```,:Y`0`0````[+D!`!0```#]N0$`)P```!*Z`0`E````
M.KH!`!D```!@N@$`"0```'JZ`0`&````A+H!``<```"+N@$`$@```).Z`0`1
M````IKH!``@```"XN@$`"0```,&Z`0`%````R[H!``<```#1N@$`!````-FZ
M`0`$````WKH!``,```#CN@$`2````.>Z`0`V````,+L!`"4```!GNP$`*@``
M`(V[`0!!````N+L!``P```#ZNP$`0`````>\`0`V````2+P!`#D```!_O`$`
M.0```+F\`0`^````\[P!`!@````RO0$`&P```$N]`0`4````9[T!`!,```!\
MO0$`'````)"]`0`@````K;T!`!0```#.O0$`$P```..]`0`6````][T!`!H`
M```.O@$`.P```"F^`0`[````9;X!`#\```"AO@$`-````.&^`0`[````%K\!
M`#@```!2OP$`>P```(N_`0`>````!\`!`!@````FP`$`#0```#_``0`:````
M3<`!``P```!HP`$`$@```'7``0`X````B,`!`#,```#!P`$`*@```/7``0`-
M````(,$!`%,````NP0$`3````(+!`0`%````S\$!`!X```#5P0$`%@```/3!
M`0`+````"\(!``\````7P@$`%@```"?"`0`'````/L(!``D```!&P@$`"0``
M`%#"`0`.````6L(!``\```!IP@$`!P```'G"`0`3````@<(!``4```"5P@$`
M)@```)O"`0`(````PL(!``8```#+P@$`%````-+"`0`2````Y\(!`!$```#Z
MP@$`1`````S#`0`"````4<,!``4```!4PP$`$````%K#`0`%````:\,!``<`
M``!QPP$`%0```'G#`0`&````C\,!`#T```"6PP$`$P```-3#`0`C````Z,,!
M``0````,Q`$`.````!'$`0`F````2L0!`"8```!QQ`$`70```)C$`0`@````
M]L0!`$T````7Q0$`*@```&7%`0`6````D,4!``<```"GQ0$`#P```*_%`0`/
M````O\4!``P```#/Q0$`%P```-S%`0`,````],4!`!T````!Q@$`&P```!_&
M`0`%````.\8!`!,```!!Q@$`&P```%7&`0`L````<<8!`!$```">Q@$`%P``
M`+#&`0`5````R,8!`!$```#>Q@$`'0```/#&`0`(````#L<!`!`````7QP$`
M&0```"C'`0`4````0L<!`!(```!7QP$`'````&K'`0`3````A\<!`!,```";
MQP$`%P```*_'`0`1````Q\<!``L```#9QP$`"````.7'`0`%````[L<!`!T`
M``#TQP$`!@```!+(`0`9````&<@!``@````SR`$`%0```#S(`0`,````4L@!
M`"0```!?R`$`%@```(3(`0`S````F\@!`!X```#/R`$`#@```.[(`0`/````
M_<@!`"H````-R0$`!@```#C)`0`?````/\D!``8```!?R0$`&@```&;)`0`)
M````@<D!``L```"+R0$`)P```)?)`0`X````O\D!``H```#XR0$`*0````/*
M`0`2````+<H!``L```!`R@$`'@```$S*`0`4````:\H!``4```"`R@$`!P``
M`(;*`0`+````CLH!``D```":R@$`!@```*3*`0`(````J\H!``8```"TR@$`
M"@```+O*`0`<````QLH!`"T```#CR@$`,0```!'+`0`E````0\L!`#,```!I
MRP$`)@```)W+`0!'````Q,L!`"$````,S`$`)P```"[,`0`^````5LP!`%P`
M``"5S`$`,````/+,`0`'````(\T!``D````KS0$`"````#7-`0`(````/LT!
M`!<```!'S0$`%@```%_-`0`L````=LT!`"X```"CS0$`&0```-+-`0`P````
M[,T!`#H````=S@$`"````%C.`0`?````8<X!``L```"!S@$`!@```(W.`0`K
M````E,X!`!,```#`S@$`%````-3.`0`+````Z<X!``@```#US@$`%P```/[.
M`0`'````%L\!``L````>SP$`#0```"K/`0`;````.,\!`"$```!4SP$`/```
M`';/`0`*````L\\!``4```"^SP$`!P```,3/`0`%````S,\!`!L```#2SP$`
M#P```.[/`0`%````_L\!`!(````$T`$`&@```!?0`0`'````,M`!``X````Z
MT`$`$````$G0`0`3````6M`!``0```!NT`$`!````'/0`0`,````>-`!`!X`
M``"%T`$`6@```*30`0`?````_]`!``H````?T0$`*P```"K1`0`@````5M$!
M`!8```!WT0$`%@```([1`0`)````I=$!``D```"OT0$`$0```+G1`0`N````
MR]$!``<```#ZT0$`#P````+2`0`2````$M(!`!0````ET@$`$````#K2`0!!
M````2](!``H```"-T@$`'````)C2`0`5````M=(!`!H```#+T@$`.0```.;2
M`0`C````(-,!`$P```!$TP$`4````)'3`0!)````XM,!`!$````LU`$``P``
M`#[4`0`=````0M0!`"(```!@U`$`'0```(/4`0`)````H=0!`!,```"KU`$`
M(0```+_4`0`'````X=0!`"4```#IU`$`'@````_5`0`*````+M4!``8````Y
MU0$`$````$#5`0`1````4=4!`!P```!CU0$`!````(#5`0`(````A=4!``L`
M``".U0$`$````)K5`0`0````J]4!`!<```"\U0$`%P```-35`0`)````[-4!
M``8```#VU0$`0````/W5`0`T````/M8!`#,```!SU@$`!@```*?6`0`&````
MKM8!``8```"UU@$`'0```+S6`0`6````VM8!`"P```#QU@$`#@```![7`0`0
M````+=<!`"0````^UP$``P```&/7`0`&````9]<!`!$```!NUP$``@```(#7
M`0`-````@]<!`!H```"1UP$`#````*S7`0`8````N=<!`!\```#2UP$`$@``
M`/+7`0`2````!=@!``L````8V`$`%````"38`0`5````.=@!``\```!/V`$`
M"P```%_8`0`2````:]@!``X```!^V`$`%P```(W8`0!H````I=@!`"(````.
MV0$`/P```#'9`0`-````<=D!``<```!_V0$`"0```(?9`0`4````D=D!`!<`
M``"FV0$`%0```+[9`0`@````U-D!`"0```#UV0$`%P```!K:`0`E````,MH!
M`!$```!8V@$`+P```&K:`0`3````FMH!`!4```"NV@$`D````,3:`0`D````
M5=L!`"````!ZVP$`,0```)O;`0`D````S=L!`",```#RVP$`)````!;<`0`E
M````.]P!`"0```!AW`$`'0```(;<`0`+````I-P!``<```"PW`$`"````+C<
M`0`)````P=P!`!0```#+W`$`#P```.#<`0`W````\-P!`!L````HW0$`%@``
M`$3=`0`(````6]T!``P```!DW0$`:@```''=`0!"````W-T!`$H````?W@$`
M@````&K>`0`-````Z]X!`#$```#YW@$`,0```"O?`0`*````7=\!``4```!H
MWP$`!@```&[?`0!%````==\!``@```"[WP$`9@```,3?`0`U````*^`!`"@`
M``!AX`$`%````(K@`0`G````G^`!`!X```#'X`$`+0```.;@`0`W````%.$!
M`$0```!,X0$`-P```)'A`0`;````R>$!``<```#EX0$`&P```.WA`0`7````
M">(!`!4````AX@$`"0```#?B`0`T````0>(!``P```!VX@$`"@```(/B`0`)
M````CN(!`!<```"8X@$`"0```+#B`0`&````NN(!`!8```#!X@$`"0```-CB
M`0`(````XN(!``4```#KX@$`#P```/'B`0`0`````>,!`"0````2XP$`(```
M`#?C`0`3````6.,!`#0```!LXP$`#````*'C`0`'````KN,!`!(```"VXP$`
M&P```,GC`0`.````Y>,!``X```#TXP$`&0````/D`0`F````'>0!``X```!$
MY`$`(````%/D`0`V````=.0!``@```"KY`$`"@```+3D`0`9````O^0!``<`
M``#9Y`$`"````.'D`0`3````ZN0!`!(```#^Y`$`$@```!'E`0`1````).4!
M``8````VY0$`"0```#WE`0`(````1^4!``D```!0Y0$`#@```%KE`0`0````
M:>4!``8```!ZY0$`%````('E`0`#````EN4!``4```":Y0$`$````*#E`0`?
M````L>4!``L```#1Y0$``@```-WE`0`A````X.4!``4````"Y@$`!0````CF
M`0!R````#N8!``8```"!Y@$`!@```(CF`0`<````C^8!`$8```"LY@$`'@``
M`//F`0`<````$N<!`%L````OYP$`.P```(OG`0!/````Q^<!`"`````7Z`$`
M%0```#CH`0`&````3N@!``@```!5Z`$`#P```%[H`0`1````;N@!``H```"`
MZ`$`#P```(OH`0`7````F^@!`!$```"SZ`$`$0```,7H`0`4````U^@!``@`
M``#LZ`$`"@```/7H`0`=`````.D!``X````>Z0$`&@```"WI`0`)````2.D!
M``4```!2Z0$`!@```%CI`0`C````7^D!``8```"#Z0$`+@```(KI`0`%````
MN>D!``8```"_Z0$`#0```,;I`0`&````U.D!``\```#;Z0$`"P```.OI`0`'
M````]^D!`!4```#_Z0$`$@```!7J`0`5````*.H!``8````^Z@$`&0```$7J
M`0`*````7^H!``@```!JZ@$`!P```'/J`0`&````>^H!`!,```""Z@$`)0``
M`);J`0`+````O.H!``X```#(Z@$`*````-?J`0`8`````.L!`!H````9ZP$`
M!0```#3K`0`*````.NL!`!,```!%ZP$`#0```%GK`0`"````9^L!``X```!J
MZP$`"0```'GK`0`E````@^L!`#H```"IZP$`*P```.3K`0`X````$.P!`"P`
M``!)[`$`9P```';L`0`;````WNP!`&````#Z[`$`.````%OM`0!*````E.T!
M`%D```#?[0$`+P```#GN`0`Q````:>X!`"L```";[@$`,0```,?N`0`O````
M^>X!`"8````I[P$`/0```%#O`0`B`@``CN\!`",```"Q\0$`&````-7Q`0!*
M````[O$!`($````Y\@$`,P```+OR`0`O````[_(!`$`````?\P$`6@```&#S
M`0!0````N_,!`#D````,]`$`(P```$;T`0`7````:O0!`"P```""]`$`(0``
M`*_T`0`C````T?0!`#,```#U]`$`'P```"GU`0`J````2?4!`#8```!T]0$`
M&P```*OU`0`1````Q_4!`%0```#9]0$`*P```"[V`0`M````6O8!`"<```"(
M]@$`(@```+#V`0`M````T_8!`%D````!]P$`-0```%OW`0!4````D?<!`#H`
M``#F]P$`/````"'X`0!.````7O@!`&\```"M^`$`6````!WY`0!'````=OD!
M`$H```"^^0$`20````GZ`0!K````4_H!`'4```"_^@$`:0```#7[`0!F````
MG_L!`#\````&_`$`+0```$;\`0`L````=/P!`#````"A_`$`=P```-+\`0!F
M````2OT!`'4```"Q_0$`P````"?^`0`9````Z/X!`"H````"_P$`/0```"W_
M`0`R````:_\!`%(```">_P$`)````/'_`0!;````%@`"`"````!R``(`"0``
M`),``@"]````G0`"`$H```!;`0(`(P```*8!`@`]````R@$"`"8````(`@(`
M(0```"\"`@`^````40("``@```"0`@(`!P```)D"`@`%````H0("``T```"G
M`@(`#@```+4"`@`4````Q`("``X```#9`@(`!0```.@"`@`3````[@("``$`
M```"`P(`>0````0#`@`+````?@,"`!,```"*`P(`!````)X#`@`'````HP,"
M``8```"K`P(`!0```+(#`@`$````N`,"`!0```"]`P(`"P```-(#`@`1````
MW@,"``P```#P`P(``@```/T#`@`'``````0"``<````(!`(`$0```!`$`@`,
M````(@0"`!<````O!`(`!@```$<$`@`5````3@0"``P```!D!`(``P```'$$
M`@`M````=00"``0```"C!`(`!P```*@$`@`'````L`0"`"D```"X!`(`1@``
M`.($`@!"````*04"`$$```!L!0(`'@```*X%`@`V````S04"`#D````$!@(`
M)````#X&`@`;````8P8"`"0```!_!@(`+0```*0&`@`F````T@8"`",```#Y
M!@(`+0```!T'`@`I````2P<"`"X```!U!P(`/````*0'`@`F````X0<"`#<`
M```("`(`,````$`(`@`I````<0@"`"\```";"`(`+0```,L(`@`F````^0@"
M`#`````@"0(`*@```%$)`@`L````?`D"`"\```"I"0(`*@```-D)`@`F````
M!`H"`"H````K"@(`+P```%8*`@`C````A@H"`"T```"J"@(`.````-@*`@`[
M````$0L"`"````!-"P(`+````&X+`@`^````FPL"`"D```#:"P(`+@````0,
M`@`M````,PP"`"P```!A#`(`)@```(X,`@`@````M0P"`"@```#6#`(`*@``
M`/\,`@!#````*@T"`"\```!N#0(`/````)X-`@`)````VPT"`!<```#E#0(`
M'````/T-`@`U````&@X"`"(```!0#@(`#@```',.`@`/````@@X"`!,```"2
M#@(`"P```*8.`@`*````L@X"`!\```"]#@(`!@```-T.`@`'````Y`X"`"(`
M``#L#@(`)0````\/`@`@````-0\"`"H```!6#P(`&````($/`@`(````F@\"
M`/@```"C#P(`&@```)P0`@`=````MQ`"``@```#5$`(`"P```-X0`@`6````
MZA`"`!8````!$0(`)0```!@1`@`'````/A$"`%,```!&$0(`&@```)H1`@`:
M````M1$"``<```#0$0(`&0```-@1`@`,````\A$"`$P```#_$0(`"P```$P2
M`@`P````6!("`!\```")$@(`&````*D2`@`?````PA("`#P```#B$@(`'0``
M`!\3`@`1````/1,"`"<```!/$P(`$P```'<3`@`4````BQ,"`!8```"@$P(`
M"P```+<3`@`:````PQ,"``@```#>$P(`+````.<3`@`(````%!0"`"D````=
M%`(`+P```$<4`@`'````=Q0"`!D```!_%`(`!P```)D4`@`(````H10"``D`
M``"J%`(`10```+04`@`'````^A0"`!,````"%0(`$P```!85`@`4````*A4"
M``H````_%0(`"@```$H5`@`'````514"`!0```!=%0(`!P```'(5`@`9````
M>A4"``T```"4%0(`&0```*(5`@`;````O!4"``H```#8%0(`#0```.,5`@`7
M````\14"``8````)%@(`-````!`6`@`,````118"`!````!2%@(`"0```&,6
M`@`"````;18"`!````!P%@(`&@```($6`@`+````G!8"``,```"H%@(`"```
M`*P6`@`.````M18"``D```#$%@(`#@```,X6`@`-````W18"`!<```#K%@(`
M&`````,7`@`1````'!<"`#P````N%P(`)0```&L7`@`C````D1<"`!<```"U
M%P(`#@```,T7`@`T````W!<"``<````1&`(`%0```!D8`@!9````+Q@"`!(`
M``")&`(`$````)P8`@`)````K1@"``0```"W&`(`!````+P8`@`1````P1@"
M`!X```#3&`(`!@```/(8`@`'````^1@"``<````!&0(`$P````D9`@`'````
M'1D"`!<````E&0(`%P```#T9`@!"````51D"`#0```"8&0(`.````,T9`@`%
M````!AH"`!L````,&@(`(0```"@:`@`9````2AH"`"(```!D&@(`$0```(<:
M`@`"````F1H"``0```"<&@(`$0```*$:`@`,````LQH"``4```#`&@(``P``
M`,8:`@`.````RAH"`%8```#9&@(`,@```#`;`@`<````8QL"`$$```"`&P(`
M-@```,(;`@!8````^1L"`!D```!2'`(`>0```&P<`@`H````YAP"`$@````/
M'0(`)````%@=`@!'````?1T"`"P```#%'0(`+````/(=`@`O````'QX"`"X`
M``!/'@(`+@```'X>`@`X````K1X"`"P```#F'@(`-````!,?`@`M````2!\"
M`#4```!V'P(`&0```*P?`@`C````QA\"`!@```#J'P(`>@````,@`@`)````
M?B`"`,L```"((`(`D````%0A`@!\````Y2$"`"T```!B(@(`;@```)`B`@`=
M````_R("`"8````=(P(`$P```$0C`@`3````6","`!8```!L(P(`*@```(,C
M`@!`````KB,"`"$```#O(P(`)0```!$D`@!Q````-R0"`!P```"I)`(`%P``
M`,8D`@`+````WB0"``4```#J)`(`!@```/`D`@`(````]R0"``4`````)0(`
M%@````8E`@`5````'24"`!D````S)0(`)````$TE`@`0````<B4"``\```"#
M)0(`$@```),E`@`)````IB4"`!0```"P)0(`"````,4E`@`%````SB4"`!D`
M``#4)0(`"@```.XE`@`,````^24"`!@````&)@(`"````!\F`@`,````*"8"
M`!`````U)@(`#@```$8F`@`6````528"``T```!L)@(`$0```'HF`@`4````
MC"8"``8```"A)@(`!0```*@F`@`H````KB8"`!P```#7)@(`"P```/0F`@`L
M`````"<"`!<````M)P(`)0```$4G`@`:````:R<"`!$```"&)P(`!P```)@G
M`@`'````H"<"`!D```"H)P(`"0```,(G`@`#````S"<"``(```#0)P(`$@``
M`-,G`@`-````YB<"``H```#T)P(`%@```/\G`@`9````%B@"``<````P*`(`
M)@```#@H`@`"````7R@"``,```!B*`(`$@```&8H`@`9````>2@"``H```"3
M*`(`"P```)XH`@`2````JB@"``8```"]*`(`(0```,0H`@`)````YB@"`!<`
M``#P*`(`%P````@I`@`2````("D"``(````S*0(`!````#8I`@`.````.RD"
M``\```!**0(`$````%HI`@`O````:RD"``8```";*0(`"````*(I`@`7````
MJRD"``4```##*0(``P```,DI`@`+````S2D"``$```#/!```&@0``"T%``!=
M`P```````)T!``!L`@``G00```````"2`P``Q@$``"T'``!\````````````
M``"$`@``)`<```L!````````>P<``,$```!S!0``$P0``.P%```L````V`,`
M`+P&```>!P``!P(``/\#``"X!0``_08``"\#````````I`(``.L%``!C`@``
ML`(```T$``!_`P```````````````````````-($``!-!0``@@0`````````
M````]0$``&X"`````````````'T"```L!````````",!``"@!0``````````
M``#?!0``B@8``"4!``!K!@``6@$```4#``!Q`0``+@<``,$!``#/`@``+00`
M`&T#``!)!P``6@```*,!```S`0``@P<```````!\`0``ZP```)$&``"\!0``
M5P<``$8%``#'!@```````)$$``!A`@``\@```"@"``!E`@```````-<$``!_
M!@``V@4`````````````I0```````````````````)8#````````0````-\&
M````````S`$```````#*!0``1P(``+L%````````^P(``(('````````"`4`
M``````!-!```R`4``.H"```B!0``%P`````````T````6````+P!````````
M`````+,"``!8!```8P,``&@#``!@`0```````````````````````/D!``!B
M`P``;P```-4!````````>`8````````#!P``D`````````!+`P``F0(`````
M```:`P``6`8``/,!``#?````)@,``-L!``#/`0``M`,``$4#````````%@<`
M``P'```C`P``\0```*P%``#.!`````````````"I`P``I`````````#'!0``
M7P,``'<#``"2!```"`0```````"%!@``OP$```````#=!```<@<``-8#``#F
M`0```````/H%``!%!P``J@$``%8$``#C`0```````$\```":!```````````
M````````+0,``&8'````````L@````````"4!0``900``)\&``#A`0``K`8`
M```````J````^@$``&D!``!/!P``UP,``"0&``"@!```3P8``%0$``"J!@``
M`````)L"``!;````C08``(D#``"I`````````*@%``#3````G@,``'L!``!F
M`@``P`,``",'``!Y`P``*P`````````V```````````````P`@``@P```.`$
M````````\@0``'8$```_!P```````/<``````````````)$"``"V!0``````
M`!,%``"H`P``*@(``'0'````````<00``#H"`````````````(X"``"/`0``
MAP0``-P```!V!P``4P4``)@#```"`@``-@<``%P#```&`0```````$,$````
M````*`<``)T#``"F`0````````````!C!0``<@$`````````````/@8``-L`
M```X!P``2@`````````!`@```````"D!````````5`,```````"9!```````
M`,L!``!?!```%`,````````E!```80``````````````(P0``'<```#K`P``
M808```````"7!@``^P4``'L`````````%`8``*X$```#````_@8``-D%``"R
M!@``QP,``'H"```1!P``[```````````````9`$```````#L`@``F@```)(`
M``"<`P```````)P!```G!0``;P(``/`#``!$`P``O`(``+H!``#9!```T08`
M`+(#``#?!```Q@0``*<$````````$P<``!8"``"\!```&`$``*\"````````
M`````-\#``"-`@```````'\!``#Y!0``:@$``!(&``#W`0``*`,``$D#``!P
M`P``100``)<!``!'````QP$``&\#``!)!@``.@```%L&``!3````T`8``'0"
M````````*@4``"4"``!N!@``[0````8&```$````X@(``'P#``!_!0``B@$`
M`)`$``#\`@``7@<``.(%```7`0```````*`!```(!P``>0(``'X````#!```
M!`<``"D&```P!@```````%$"``"_`````````'4#``#]`P````````L````O
M!0````````````!@!P``(P8``-T`````````\@(``"P'````````U0,``-8$
M`````````````&@````,`@``;08```````#.!@``P`8``'$```"@````]P8`
M`$$"````````F`0``+<#``#``````@0```H&``!,`0``D@(``+4%``"A`0``
MP`$````````%`````````$<'``#4`@``8P````````#$````````````````
M````[@0````````\!0``:0<```````#(!@```````!4#``!\!@``````````
M``!.!0````````````#O!```=`0``)X&``!M!```"````%X```!#!P``N`,`
M`'(%``#>````@@,``"($```W!0``\@8``)H#``!U`@```````&L!```]`@``
MN08``.D%``"[!````````&H&````````B0```*,"````````+P8````````7
M!P```````%4!```@!```.`$```````!K!````````(4"``!U!0``?`4``-8`
M````````(`(``$H&```U!```,@(`````````````E0,``/L$``#[!@``````
M`&0&````````\`$``,8```#M`P``CP```%8'`````````````.(&``"#`P``
M``````````#;`@``+`,``%<!``#O!@```````.0!``#^````30```,D$```,
M!0```````#8!``".`P``?@$``)<```!7!```?`0``',```"C!0``5P(``(`"
M````````/08``'<!``#]`0```````.,$````````)`````````#T!```:00`
M````````````'P0```8```"=`@``70(`````````````X`8``)`%````````
MW`8``(P#```^````*P$``!,"``#4`P``C`8``#L'````````:@,```````"+
M!```HP````````##`P``40```+L"```J!```'@0``.4$````````*`8``/0"
M```J!@``5`4``````````````````*<"```B`P````````````"T`0``````
M`'T````E`P```````&P'````````C@0```````#-`0``ZP8```@!````````
M`````````````0``2`4``#0&````````Q04``!$!``!=!```^`,``)P```"N
M`P``PP$```````!R!```;@0``-4"``#&!0``?0$``(T!````````````````
M``#X!0``,P0````````Y!P``H`8``,X#``"C!@``[`$``*8`````````[0(`
M`````````````````*H$``#J`0``]00``-P#```F!````````&0$``"?````
M"P8``+8$``#G`P```````,4$``!:`@``B00```````#"`@``N@4``#X%``!N
M!P``T@4``(X&````````70<`````````````&00```````#Q`P``5````-D`
M````````2````)8`````````50(``#<````;!@``.P(``'$"````````\0(`
M```````&!```M0(``*($``!Q!P```````-4&```5`````````-4$````````
M_``````````;!0``AP4``/8!``#R!0``>@,``-,&``"P!0``D04``/\$````
M````````````````````@`0``+T"``#,`@``!P<``)<#``#]`@```````/`$
M```^`@``4P$```````#"!```,@$```````#)`@``C```````````````2P$`
M````````````M08```D!``#=`0``)`0``*(#``#)!0``=`$``#$$```,!@``
MB`0``&(`````````+P```)L&```W`@``6`(``'D'``!"!P``B04``!D`````
M````K0```.P#``#,!@``>`4``#(```"Y!0``R`(```````#Q!@``L08``%<%
M``!$`0`````````````<`@``&0<``-8&````````"@4```````!A`0``.`(`
M`$("``"[`0``?@,````````J`0``1@```,X"```/!@```````'\```!``P``
M,`<``"T!```O!```X`$```````#.!0``L@(``.<!``!2`P``]0,``'H$````
M````H`,``-("``!@`P``Y@4`````````````7P```!X"```P`P``^@(`````
M``!P!````````'L&```S!0``-@4``!8$````````=@```*$#````````DP4`
M`%X%```1`@``;0$``"(!````````C@````````!F!0```````,$%```:`0``
MWP$```````"1`P``F`````````"!!0``&``````````H!0``@P0````````<
M````E`8``&,&``#Y`@``A@$```````!*`P``8@<``'<$```.!```90```%`%
M``"_!@``<@(``.```````````````+4#``!S`P``````````````````````
M``````!=`0```````#,'``!\`@``;```````````````A@(```````#)!@``
M"@(```L%``!N`0``+`(``-P%``#E`@``30,```T!``!@````9P````````"Z
M!@``UP(``+0&``````````````````#J````KP0``"@`````````*@<`````
M``#S````I@4``/P!``#1!```&@```%@!`````````````&`$````````PP8`
M`%H&``!.`````````!("`````````````$@$```1!@``(P```#\```!^!0``
MI00``+8"``"-!0``Y````$`$````````M`4``#T%```?`0``N0$```````"7
M!0```````+4```#\!@``)@<`````````````K00```````!C!P``=P4``&8`
M``````````````````#*!```!P$``%(&`````````````-H&``!;!P``.P$`
M`#D$``!S`@``Y@8``#<$```:!P``^`8``&P&```,`0```````$(&``"8!@``
MN00``&`&```%!0``0`<``````````````````'$#``"+````<P<``-`#````
M`@``I`$``"H#````````L`0````````?!P``_P(``.D"``!P````:`8``-@`
M```-!@``0P,``%@'``#N!0``XP8``,T$```]`P```````/8%``!?!P``F@8`
M`-`"```Z!P``;`$``-$```"$!@``,````,8"``">!```ZP$``.(```!I`@``
MIP$``%L"````````-@,```````!6!@``*00``%X#``#V!@```````,\```"2
M!0``T@8``$0"`````````````)8!``````````````(&``!"!0``^08`````
M``!'`P``:`4``$X'``#2`0``@0$`````````````````````````````^00`
M`&H$```$!```/`,``!T$``#;!````````%H#``![!```$`(``"<&``#'!```
M&0,```````!Y!@``=0````,#``"2`0```````*P``````````P(``'H!```G
M!```+P<```````!Z````=```````````````8P$``%0!```-````/P$``-L#
M``"O!@``,@<`````````````)@```````````````````(0%``",!```````
M`$0$``#\!0```````+,```!0`0``BP8``+,!```5`@``3P(``(4#``!H!P``
M\P(``+8```#M!@``[@,``%$!``#>!```ZP0```````#*!@```````"X"````
M````!@<``%``````````4P(```````!&!@``?P(````````7!@```````.X&
M``"&!@``NP```%<&````````^`$``(0```!!!@```````'8!````````````
M`$,"``!(`0``$P,````````D`0``5P,``/4```"6!0``3P4``-<&```Y`0``
M%`<```````")`0``6`4``%4$```\!P``F`(``#L#```/`P``J@4``$D!````
M````G`0````````^`0``:@```'H%``"E`P``H@8``"``````````K@```$L`
M```2````HP0```$!``!S!@```````-0!``"Z````X0,``+<!````````````
M`&8$`````````````+X```"Y````;P0````````1````6P4``.($```>`P``
MK`$``.8````A`@``F08``+T!``#Q`0``-08``'T&````````@0```!`$``"Y
M`@``.P0``(`!```;````L0(```````"[`P``<04``&0"``"%`````````,L"
M``"^!@``>P4```````!6`@``FP4``.\!``"K`P```````(8%``!S`0``L0``
M`'X$````````Z@8````````+!P``;0(```````#J`P````````\"```4`0``
M*P,``$($````````?`<``-T"````````=@8``$4%````````UP4``(0$````
M````60<``/4"``"L!```!`(````````A````]P4``'@!```Z`P``!08``.\%
M``#N`@``;04``+8#````````T@,``.8"``!3!@```````'@$```_`P``````
M`"D"``"8!0``P@4``-8%``!=!0````````````#Z!@``=@4``$8"```\````
MO```````````````#0,`````````````"@<``#(&```2!`````````````!@
M`@``\00``#$#````````0`$``#D%````````E08`````````````B`$``,D`
M``#F`P``W@8``+T```",`0``N@0````````T`P``-`(``!D%````````@08`
M`*L$```&`@``YP0``+T#``````````````````!'!```2P8``+($``!O!0``
MP@,```````!I`P``V0$``+$!````````CP4```````#$!@``G@4````````'
M`P``>P,``!,````+!```Q`$```D$````````0`(``%4```#>!0```````*H#
M```!`P``%P0```$&`````````````.8$``#G!0``"`,``*0%``"T!```%@``
M`%($```W`0``404``*("``#W`@```````'X"```?!0``^0,``$,!``!H!```
M```````````[!0``$P$```````#O`P``PP0``+@&````````1@,```````#+
M`P``604``'D$```X!@``^0```!H%``!&`0```````*L```!6`0``Y`0``(T`
M````````S`,``#,&`````````````,L```"'````V@,`````````````R`0`
M``````!,!P```````!4%````````Y`,``#$```#*`P``A04``!`!```.````
M9`<``*<```#+!```7`<``!,&``#:````(0$``*`"``"6`@``7`0``"L$```=
M!P``9@$``'8"```.!P``&P0``-4%``":`@``70````````#<!```8@4``#H&
M``#D`@```````*X%`````````@,``!P$````````````````````!0``````
M`)0!``"`!@``<@,``*T#``#T!@```````(\$``"#`@``&08```````#9`P``
M`````%P!``!5!P``$@,``.\"````````<`4``*8#``!>`0``)@8`````````
M`````````*D&``#=`P``3`,``/@$```T!P``=00````````K!0``8@8``-0`
M``">`@``]P,````````D!0``?P<``.@%``!P`@```````"D`````````!0(`
M```````%!P``X00```````!,!@`````````````A!P``_04```````!%`@``
M````````````````U@$``,T````U`P``!`$````````E!P``:P<``%T&````
M````?04``&\!``"M`@``P00``"T"``!3!```````````````````@`4``!$$
M``"/`@``408``-(```"L`P``0P8``#$'``!U!P```````,P$```7!0``````
M`+<$`````````````(,!`````````````"("``!;`0```````!4'```"!P``
M'P(``*8"```@!P```````#@$``"'`@``:P```.P&```U!0``/`$```T%````
M````X`4``(H````<`0``J`0``(<#```"!0```````!X%``!<`@```````.D!
M````````]@0```````#>`0``0P4````````.!@``B````.<"```R!```X@,`
M`*<%```(!@``Q0,````````]!```````````````````Z`(``)\#``#\`P``
M%`4``#,```#Q!0``<`<```````!I!@```````,D#``!P`0``'`,``%4%````
M````A@```(0!````````M````(T#``"!!```+@0``+@!``"7`@``G`4``+0"
M``#C`@```````#`$``"A````*P(``,8#```)`P```````(@%````````%@8`
M`*D$``````````````````!G!0```````-<!````````#`0```,&````````
M)0```-X#``">``````````````!N!0``&@8````````5`0``.@4``!T```#*
M`@``F@4``(,&``",`@``'04``)0"````````.P8``#P&``"B`0``G04``"8"
M`````````````"T```!$!P``DP(``%`$`````````````#,"``#S!0``=0$`
M`%L#```U`0```````$P$``!2!0``GP0```D```"_!0``@0,```````!9`0``
M:`(``.D#```8`@```````,`"``!4!P``00,``#H$``"1`0``Y0$``.`#``!/
M!`````````````"J`@``#0(``!L"``!.`0``1@0```H`````````1P8``/L!
M```N````C@$````````G!P``ZP(``.@!``#.`0``:P(`````````````V`(`
M`,$"```G````L0,``(X%````````;@```!``````````B@0``!L!````````
M;P<``/X"``#;!0``30<``+`#```!!P``BP,```````"+`@``:`$``(`#``"^
M`0``<08``&P$``"J````30(``&`%````````B@,``"D'``!_!````````+H#
M```\!```%P(````````V`@``D`,``((```#^`P``````````````````#@(`
M`!0"``#"````N0,```````#+!@``+`4``.X```"]!0```````$0%```-!P``
M4P<````$``!?`0````````````#8`0``1`8``.T$``!G!@``-`4``#4'``";
M`0``X0```+H"``"\`P``%`0`````````````E04``.4%``#R`P```````#T'
M```7`P``Z`0``),#`````P``!`8``(@&````````9@8``%H'```N`0``(08`
M``````!?!@``9P,```````!9!@``LP,```D"``!(`@``'P````<&``!E`0``
M``````````!.`@````````````"B!0``+`8``+(!````````T0$``#$%``"'
M`0``7``````````V!@``XP,``!8%``"X!```JP(```````"`````>`,``((&
M``#$!0``?@8``-P!```S`P``[@$`````````````#````)0#``!B`@``G`(`
M`.T%``````````````````!B!`````````````#I````L@4``)P&````````
M'@$``+\#```W!@``;`4``(4!``!J`@```````$L$``#A!@```````,$&``"0
M`0```````,,````8!P```````&$$``!M!P````````D%```]`0``2@<``&L#
M```=!@``1````!`'`````````````-8"``!)````.0,``!4$````````[P``
M`&4&````````!@4``%$#```#!0``(`4``+`&``"F!```!00``$<!```_!@``
M````````````````'`4```````"P````KP```"L&``#I!@``XP`````````>
M!@``$`,``+X$``#4!@````````````!]`P``"@0``!8#``"M`0``````````
M``#=!@``S@````````"3`0``>`<``,,"``#^!````````#0!````````J```
M`"P!```,`P```````(T$```9`0``H@```$P%````````Y`8``-,"````````
M```````````'!```F@$``)D#``"K`0``"P(``-$%``#P!0``]`$```L#````
M````G@$``,4`````````Q`(``%<````X````)P(`````````````^P,``*0$
M``"W!0```````+X%````````3P$``!T!``#G!@``\P8``),$``!.!```````
M`*X!`````````````*4!``"E!0``K@(``%X&````````TP,``!(%``"D`P``
M`````!D"``#\!````````(`'``!Z!P``S04``.(!``"G!@``X0(``+L&``"I
M`@``;@,``(P%``"P`0```````,\%``"=!@```````+$%````````RP4``&D%
M````````]@(```````#8!@`````````````=`P``=P<``+$$``"A!@``````
M`,`%``"H`0``0P```)L#```:`@```````$H$`````````@$``)4"``!+!0``
M/@,``'0&``#:`@```````$$'``!?!0``>@8``$(#``#E````204``+T&````
M````````````````````T````%D#``"W````=P(``#\%````````308``-,%
M``!)`@``/0```"D%````````=08``-X"``!>!```&`,`````````````````
M`,`$````````T0,``.`"``!V`P``E````($'```8!```````````````````
M`````#\$```5!@````````````!+!P```````"<#``#]````50,`````````
M````'`<``$\#```Y`@``DP```/(!``!4`@```````/8#```)!@```````)8$
M````````0@$``%X"``!)!```1@<``&H%``"O`P```````(("``!(!@``````
M`"8!````````V@$```````"M!0``:@<``-@$``!E!0``K@8``",%```W!P``
M/@<``$@#``!G!```S0,```````!G`@``JP4``'T$``!T`P``SP,``$X#``"9
M`0``WP(``$L"``"_!````````(4$``!E!P``<@```````````````````/@"
M````````+@4``&8#````!P``(0,``'<&````````Y0,``)0$``"V`0``Q08`
M`,T"```H`0``F`$``,H!````````40<``%("``!8`P``@@4````````O`@``
M^````)D`````````S````*P"```P!0```````-<`````````H04`````````
M`````````"`&``"3!@``[0$``!\#```[````D@8``$$!``#$`P``B@(``/\&
M```1!0``804``````````````````"`#``"(`@``'@```'T'``!0!P``J04`
M`$4```!P!@``-@0``,(!``#3`0``0@```&,$```B!P``:P4``/`&``!6````
M#@$``/4%``!,`@``^@0``%D"``"?!0````8``.0%```B````004```````!%
M!@``E00``)8&``"_`@```00`````````````MP8``&P#```0!@``Z`8`````
M``!Y!0``Z````#(#``!6!0``#@4```\!```=`@```````&0%````````+P$`
M`#P"``!-`0``,`$``"0"``#5`````````"$%``!D`P``]@```'@"``")!@``
M``````````"A`@```````*\!``#Z`P``8@$``+@```"1````````````````
M````E0```"0#```/``````````````"(`P```````'L"``##!0``Q0$`````
M``"$`P``&P<``)\!````````V0(``,@!```*`0``4P,``'D```#0!```P0,`
M``````#)`0``$0,``````````````````&<'``#L!```<P0```8#````````
M.08``-0$````````GP(``&T```"+!0``$@<```````!2!P``*`0```(```!?
M`@``&`4```````#T!0``2@4```````#(````"@,``(D"````````HP,```0%
M````````-P,``/X!```)!P``6P0```@"````````3````)<$``#0`0``)04`
M`.,%````````>`````````!G`0``\````.H%``!*`@``LP4```$%````````
M4@```.@#``!'!0``SP8``#D```#$!```F04``+X"`````````P$``'(&``!`
M!0``V08`````````````!P```#(%```I`P``^@```,(&```/!P``_@4``,H`
M``!Y`0``$@$``/0#``#A!0``I08``%$$``!2`0````````0#``"W`@``2`<`
M`!0```"/`P``J`(``%H$``#3!```.`,``"X#``#T````/@0```````#<`@``
MJP8```````#_!0``V`4``%P&``"^`P``R`,``.D$``!9!```E0$``(8#``!A
M!P``?@<`````````````#P4``(<&``"A!```*P<``(L!``!!!```FP```!P&
M``#P`@``;P8`````````````LP0````````.`P``Y08``%P%````````]P0`
M`(\&``#=!0``)08`````````````\P0```````"X`@```````+4!``!`!@``
M`````*@&``!0!@``.`4```````!!````-`0````````Q`@```````/T$````
M````B@4``!L#``"E`@````````````!0`P``(@8``-`%``#U!@```````*D!
M``!A`P``#P0`````````````3@8``"<!``"O!0````````````#1`@``````
M`(,%``"!`@``LP8``%8#``""`0```````.H$```C`@``S08````````U````
MM@8``,<"``"G`P``60`````````Q`0```````-L&``"M!@``!P4``$4!``!5
M!@``M00``#$&````````5`8```````!D````'P8``,4"````````G0```/\`
M```%`0``/P(``(8$``!I````U`4``"`!``";!````````)`"```0!0``````
M`#H!``#,!0```````!8!````````=`4``,<```#&!@````````````!:!0``
M(00``/,#```F!0``YP```+T$``"D!@``&`8``$H!```M!@``_P$``&4#``#:
M!```-0(`````````````^P```*8&``"0!@``4`(````````N!@```"`H)7,@
M9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D
M87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T
M(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S
M(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E
M<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N
M,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N
M9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M
M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"
M`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@
M4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR
M96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O
M<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@
M0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T
M;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN
M=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S
M<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI
M<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H
M;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L
M:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N
M>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@
M)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q
M,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO
M=7,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L
M;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!
M32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@
M4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!
M8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D
M`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O
M=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O
M=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E
M<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U
M<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@
M=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E
M<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E
M9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET
M:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M
M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I
M;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG
M;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@
M1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M
M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`
M06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA
M;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E
M<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U
M<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`
M06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A
M=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE
M`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G
M96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A
M`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I
M;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A
M;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U
M=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD
M87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H
M96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!
M=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I
M;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S
M.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U
M;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@
M=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S
M*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y
M("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L
M:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@
M;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S
M`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R
M9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA
M`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA
M;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R
M=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A
M<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O
M<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-A;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@
M97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL
M92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R
M:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL
M(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L
M;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N
M=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N
M("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E
M($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG
M92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P
M;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI
M;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@
M5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E
M(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#
M;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A
M<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#
M;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S
M($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S
M92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O
M;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L
M97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO
M;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O
M;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T
M:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U
M=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R
M92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE
M8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T
M>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N
M=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E
M<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV
M;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A
M<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I
M;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@
M;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F
M<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R
M:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R
M;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I
M=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D
M('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R
M96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R
M;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R
M96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U
M<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N
M`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L
M:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A
M5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV
M960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R
M`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A
M=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I
M;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T
M92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S
M86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I
M='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L
M:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R
M:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$
M;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL
M;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K
M`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`
M161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I
M="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%
M;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A
M>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T
M>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!5
M4DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'
M=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`
M17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R
M('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN
M:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I
M;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P
M`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@
M8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE
M8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R
M:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R
M;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E
M96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H
M;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT
M`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`
M1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E
M<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO
M`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT
M($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&
M<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`
M1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB
M<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L
M92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`
M1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@
M;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L
M;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N
M<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(
M5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O
M<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y
M+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE
M;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(
M:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`
M2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R
M87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-
M3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z
M($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO
M;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S
M`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO
M<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H
M92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@
M='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO
M<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA
M;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M
M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@
M)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL
M8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!
M9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N
M<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@
M)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F
M<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`
M26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S
M<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA
M`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`
M26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU
M;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B
M($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R
M96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M
M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@
M<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R
M90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN
M<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P
M87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B
M969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I
M9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R
M`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L
M:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@
M9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A
M;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!)
M;G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@
M<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U
M8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z
M("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D
M<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@
M<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L
M86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U
M97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S
M92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I
M9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*
M=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N
M96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,
M96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L
M:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO
M=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`
M3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,
M87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R
M;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A
M=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D
M97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!
M<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI
M9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG
M:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@
M4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I
M;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES
M="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(
M96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I
M8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C
M86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G
M(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN
M(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@
M<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE
M9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W
M97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U
M<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`
M36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-
M86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA
M<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T
M86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T
M8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D
M(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA
M>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C
M96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF
M:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T
M:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T
M:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F
M:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER
M<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%
M05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL
M92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U
M;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT
M:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R
M92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E
M9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@
M4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``
M36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO
M;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L
M`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`
M3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA
M;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E
M=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@
M4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#
M86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE=R!-
M;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P
M87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`
M3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC
M;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R
M;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE
M9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@
M<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.
M;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S
M`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R
M;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E
M`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T
M('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@
M;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE
M8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E
M<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T
M+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E
M<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/
M<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E
M9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N
M:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@
M4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U
M;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`
M4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@
M9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R
M=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE
M;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T
M;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@
M9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A
M9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@
M4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T
M=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S
M:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E
M;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E
M(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T
M960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/
M<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N
M9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2
M:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE
M<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A
M=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`
M4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@
M8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL
M>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S
M<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@
M4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#
M0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A
M;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE
M("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I
M<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@
M(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A
M=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@
M5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T
M($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E
M;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E
M<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM
M92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E
M;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L
M($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!3
M97-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W
M`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO
M=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@
M3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@
M06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO
M=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`
M4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P
M=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N
M9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N
M`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN
M9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E
M;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E
M`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T
M:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R
M97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E
M<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U
M<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S
M<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E
M<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY
M('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN
M>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N
M<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V
M86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R
M;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3
M=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I
M;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O
M<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II
M:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!4
M87-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E
M;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(
M:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`
M5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A
M;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N
M<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P
M:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO
M=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@
M9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P
M;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B
M<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX
M(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@
M:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I
M;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED
M96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S
M="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E
M96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N
M=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@
M;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q
M=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`
M5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O
M=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E
M<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T
M8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S
M(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@
M8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@
M`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I
M;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E
M<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E
M<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE
M('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ
M`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#
M;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI
M;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M
M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS
M`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA
M`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R
M:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E
M.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV
M97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T
M;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R
M96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I
M;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE
M*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53
M:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD
M;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N
M:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`
M57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T
M:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U
M<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF
M9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P
M=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S
M(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO
M="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S
M+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5
M>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T
M:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`
M5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@
M;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T
M(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N
M`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA
M;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H
M`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@
M`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET
M90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T
M97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A
M;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@
M=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7
M:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P
M965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E9
M65D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T
M;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED
M(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O
M;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L
M9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.
M86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T
M:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S
M(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U
M;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C
M:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R
M9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R
M=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`
M6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O
M=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN
M92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$
M96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E
M<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E
M<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W
M;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N
M;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5N=')Y(&YO="!F;W5N9`!F
M86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG
M`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP
M=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S
M70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`
M;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E
M<&%D`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E
M<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S
M:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`
M<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE
M9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED
M+59E<G-I;VXZ(&9R7T92"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`Q+3`V(#$V
M.C,U*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,2TP-B`Q-CHT,"LP
M,3`P"DQA<W0M5')A;G-L871O<CH@5&AI97)R>2!4:&]M87,@/'1H:65R<GE`
M<&]M<&\N;F5T/@I,86YG=6%G92U496%M.B!&<F5N8V@@/&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU
M<F%L/2AN(#X@,2D["@`@*&EL('D@82`E<R!J;W5R<RD`("A4;W5C:&4@9"=A
M8V/H<R!R87!I9&4@)7,I`"`H9&%N<R`E<R!J;W5R<RD`("AA=6IO=7)D)VAU
M:2D`("AD96UA:6XI`"`H:&EE<BD`(.`@`*N@)7.@NR!N)V5S="!P87,@=6X@
M9&]S<VEE<@"KH"5SH+L@;B=E<W0@<&%S('5N(&-H;VEX('9A;&ED92X`JZ`E
M<Z"[(&XG97-T('!A<R!C;VYF:6=U<ND@9&%N<R!L92!R96=I<W1R92!D92!(
M;W)D92X`3"=I;G1E<G!RZ71E=7(@9"=A<F)R92"KH"5SH+L@;B=A('!A<R#I
M=.D@=')O=7;I+@"KH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64@9&5S
M(&=R;W5P97,N`*N@)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM92!D97,@
M<&5R;6ES<VEO;G,N`*N@)7.@NR!N)V$@<&%S(.ETZ2!C<NGIH#H@)7,N`"4N
M,F:@36\@=71I;&ESZ7,@<W5R("4N,F:@36\@<&5R;6ES("@E+C)FH"4E*0`E
M9"`E<R!E="`E<P`E9"!J;W5R<R!A=F%N="!L)V5X<&ER871I;VX@9&4@=F]T
M<F4@;6]T(&1E('!A<W-E+@`E9"UP<NEV:7-I;VX@9'4@:F]U<@`E<R`M($YO
M=&EC90!%;7!R96EN=&4@4$=0(&1E("5S`"5SH$MO`"5S(&]PZ7)A=&EO;G,@
M9&4@;6%I;G1E;F%N8V4@)FYD87-H.R!#;VYF:7)M871I;VX`0V]N9FEG=7)A
M=&EO;B`E<P!);G-C<FEP=&EO;B!D92`E<P!#;VYD:71I;VYS(&0G=71I;&ES
M871I;VX@9&4@)7,`)7,@97AI<W1E(&3I:N`N`"`E<Z#@("5S("5S`"5S(&5S
M="!P<NIT(.`@969F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA
M;F-E(&-O8VCI97,@8VDM9&5S<V]U<RX@4^EL96-T:6]N;F5Z(&QA(&]U(&QE
M<R!O<.ER871I;VXH<RD@<75E('9O=7,@=F]U;&5Z(&5F9F5C='5E<B!C971T
M92!F;VES+6-I+@`E<R!E<W0@;V)L:6=A=&]I<F4`)7,@;6EN=71E<P`E<R!N
M;VX@=')O=7;I`"5SH.`@)7,@9&4@)7,`0V%R;F5T(&0G861R97-S97,@9&4@
M)7,`06=E;F1A(&1E("5S`$)L;V,M;F]T97,@9&4@)7,`3&ES=&4@9&4@=.)C
M:&5S(&1E("5S`"5SH#H@)7,`)7.@.B!L)^EM971T975R(&1E(&-E(&UE<W-A
M9V4@82!P=2#J=')E(&9A;'-I9FGI+B!!='1E;G1I;VX@96X@<W5I=F%N="!L
M97,@;&EE;G,@<74G:6P@8V]N=&EE;G0@;W4@96X@9F]U<FYI<W-A;G0@9&5S
M(&EN9F]R;6%T:6]N<R!P97)S;VYN96QL97,@X"!L)^EM971T975R+@`L(&5N
M(')A9F%L92``<F%F86QE("5S("5S`'9A<FEA8FQE(&1U("5S(&%U("5S`"TM
M(%/I;&5C=&EO;FYE<B`M+0!&;W)M870@,3(@:&5U<F5S`$9O<FUA="`R-"!H
M975R97,`,C0@:&5U<F5S`#Q0<NECZ61E;G0`56YE(&)A<V4@9&4@9&]N;NEE
M<R!P<FEN8VEP86QE("AB86-K96YD*2!E<W0@;NEC97-S86ER92!P;W5R(&-E
M(&)L;V,`56YE(&5R<F5U<B!F871A;&4@<R=E<W0@<')O9'5I=&4`56YE(&-L
M968@<'5B;&EQ=64@4$=0(&5S="!NZ6-E<W-A:7)E('!O=7(@8VAI9F9R97(@
M=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4$=0(&5S="!NZ6-E<W-A
M:7)E('!O=7(@=NER:69I97(@;&$@<VEG;F%T=7)E(&0G=6X@;65S<V%G92X`
M56YE(&-L968@<'5B;&EQ=64@4$=0+"!U;F4@8VQE9B!P<FEVZ64@4$=0+"!E
M="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E<R!P;W5R(&3I
M8VAI9F9R97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4$=0+"!U
M;F4@8VQE9B!P<FEVZ64@4$=0+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N
M="!NZ6-E<W-A:7)E<R!P;W5R('-I9VYE<B!U;B!M97-S86=E+@!5;F4@8VQE
M9B!P=6)L:7%U92!3+TU)344L('5N92!C;&5F('!R:7;I92!3+TU)344L(&5T
M('5N92!P:')A<V4@<V5C<NAT92!S;VYT(&[I8V5S<V%I<F5S('!O=7(@9.EC
M:&EF9G)E<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!3+TU)344L
M('5N92!C;&5F('!R:7;I92!3+TU)344L(&5T('5N92!P:')A<V4@<V5C<NAT
M92!S;VYT(&[I8V5S<V%I<F5S('!O=7(@<VEG;F5R('5N(&UE<W-A9V4N`%5N
M92!C;&5F('!U8FQI<75E(%,O34E-12!E<W0@;NEC97-S86ER92!P;W5R(&-H
M:69F<F5R('5N(&UE<W-A9V4N`$YU86=E<R!L92!M871I;@!0;'5I92!LZ6?H
M<F4@;&4@;6%T:6X`4&QU:64@;&4@;6%T:6X`079E<G-E<R!L92!M871I;@!#
M:'5T97,@9&4@;F5I9V4@;&4@;6%T:6X`04TO4$T`05!)($E$`,`@<')O<&]S
M(&1E(&-E="#I9&ET975R`,`@<')O<&]S+BXN`$)A<R!A8G-O;'4`36EL:65U
M(&%B<V]L=0!!8V/H<R!R969U<^D@;&]R<R!D92!L82!C<NEA=&EO;B!D92!R
MZ7!E<G1O:7)E(%9&4R`N`$%C8^AS(')E9G5SZ2!L;W)S(&1E(&QA(&-RZ6%T
M:6]N(&1E(&9I8VAI97(@5D93+@!$;VYNZ65S('!E<G-O;FYE;&QE<P!-;W0@
M9&4@<&%S<V4@9'4@8V]M<'1E`$-O;7!T92!I;F%C=&EF`$-O;7!T97,`06IO
M=71E<@!!:F]U=&5R('5N('-O=7,M9W)O=7!E`$%J;W5T97(@=6YE(&YO=79E
M;&QE('-O=7,M<&5R;6ES<VEO;@!!:F]U=&5R(&EC::`Z`$%J;W5T97(@=6X@
M;F]U=F5A=2!G<F]U<&4`06IO=71E<B!U;F4@;F]U=F5L;&4@<&5R;6ES<VEO
M;@!!:F]U=&5R('5N(&=R;W5P92!F:6QS(.`@JZ`E<Z"[`$%J;W5T97(@=6YE
M('!E<FUI<W-I;VX@9FEL;&4@X""KH"5SH+L`06IO=71E<B!U;B!N;W5V96P@
M=71I;&ES871E=7*@.@!!:F]U=&5R('5N92!C;VQO;FYE`$%J;W5T97(@9&4@
M;F]U=F5A=7@@;65M8G)E<P!!:F]U=&5R('5N92!P86ER90!!:F]U=&5R(&QE
M(&UE;G4@)7,@X"!L82!B87)R92!D92!-;WII;&QA`$%J;W5T97(@874@8V%R
M;F5T(&0G861R97-S97.@.@!!:F]U=&5R(.`@;6]N(&-A<FYE="!D)V%D<F5S
M<V5S`$%J;W5T97(@=6X@=71I;&ES871E=7(`JZ`E<Z"[(&$@Z73I(&%J;W5T
MZ2!A=2!S>7-TZ&UE+"!M86ES(&PG86IO=70@9"=I;F9O<FUA=&EO;B!S=7!P
M;.EM96YT86ER97,@)7,@;B=E<W0@<&%S('!O<W-I8FQE+@"KH"5SH+L@82#I
M=.D@86IO=73I+B!6;W5S('!O=79E>B!V;W5S(&-O;FYE8W1E<BX`3&$@9F]N
M8W1I;VX@9"=A:F]U="!D)W5T:6QI<V%T975R<R!E<W0@9.ES86-T:7;I92X`
M061R97-S90!#87)N970@9"=A9')E<W-E<P!!9&UI;FES=')A=&5U<B`M(&%J
M=7-T97(@;&5S('!E<FUI<W-I;VYS('!O=7(@9"=A=71R97,@=71I;&ES871E
M=7)S`$%D;6EN:7-T<F%T:6]N`%!U8G,`069G:&%N:7-T86X`06QB86YI90!!
M;&?I<FEE`$%L:6%S`$%L:6=N97(`06QI9VYE;65N=*`Z`%1O=70`5&]U<R!L
M97,@<&%R=&EC:7!A;G1S(&%U=&AE;G1I9FGI<P!4;W5S(&QE<R!G<F]U<&5S
M`%1O=71E<R!L97,@<&5R;6ES<VEO;G,`3&5S('%U871R92!C]'3I<P!097)M
M971T<F4@9&5S(&%D<F5S<V5S(&1E(&-O=7)R:65L(&UU;'1I<&QE<P!!=71O
M<FES97(@;&$@;6ES92!E;B!P;&%C92!D92!L:7-T97,@;G5MZ7)O=.EE<Z`_
M`$5X:7-T92!DZ6K@`$YO;2!D)W5T:6QI<V%T975R($E-4U`@86QT97)N871I
M9@!-;W0@9&4@<&%S<V4@24U34"!A;'1E<FYA=&EF`$YO;2!D)W5T:6QI<V%T
M975R($E-4U`@86QT97)N871I9@!!9')E<W-E(&1E(&-O=7)R:65L(&%L=&5R
M;F%T:79E`$%U=')E<R!M;V3H;&5S`%1E>'1E(&%L=&5R;F%T:6:@.@!386UO
M82!!;>ER:6-A:6X`56YE('9A;&5U<B!I;&SI9V%L92!A(.ETZ2!S<.EC:69I
MZ64N`%5N92!E<G)E=7(@:6YC;VYN=64@<R=E<W0@<')O9'5I=&4N`$%N9&]R
M<F4`06YG;VQA`$%N9W5I;&QA`%!R;WAY(&%N;VYY;64`4NEP;VYS90!!;G1A
M<F-T:7%U90!!;G1I9W5A+65T+4)A<F)U9&$`07!P;&EC871I;VX`3&ES=&4@
M9"=A<'!L:6-A=&EO;G,`3"=A<'!L:6-A=&EO;B!E<W0@<'+J=&4`07!P;&EQ
M=65R(&%U>"!P87)T86=E<R!F:6QS`$%P<')O=7;I`%1A:6QL92!A<'!R;WAI
M;6%T:79E`$%V<FEL`$%R86)E("A7:6YD;W=S+3$R-38I`%1A:6QL92!D=2!F
M:6-H:65R(&%R8VAI=F4`3F]M(&1E(&PG87)C:&EV90#*=&5S+79O=7,@8V5R
M=&%I;B!D92!V;W5L;VER('-U<'!R:6UE<B!C971T92!R97%UZG1E(&0G:6YS
M8W)I<'1I;VX@('!O=7(@)7.@/P#*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L
M;VER(&5F9F%C97(@JZ`E<Z"[(&5T('-E<R!S;W5S+6=R;W5P97.@/P!!<F=E
M;G1I;F4`07)MZ6YI90!!<FWI;FEE;B`H05)-4T-)22TX*0!!<G0`07)U8F$`
M07-C96YS:6]N("C.;&4I`$%R="!!4T-)20!2Z6=I;VX@07-I92]086-I9FEQ
M=64`1&5M86YD97(@=6YE(&-O;F9I<FUA=&EO;B!A=F%N="!D92!L86YC97(@
M;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V6@/P!#;VQO;FYE<R!D97,@
M=.)C:&5S`%1E;G1A=&EV92!D)V5F9F%C96UE;G0@9"=U;B!G<F]U<&4@:6YE
M>&ES=&%N="X`5&5N=&%T:79E("!D)V5F9F%C96UE;G0@9"=U;F4@<&5R;6ES
M<VEO;B!I;F5X:7-T86YT92X`5&5N=&%T:79E(&1E(&UO9&EF:6-A=&EO;B!D
M)W5N92!P97)M:7-S:6]N(&EN97AI<W1A;G1E+@!496YT871I=F4@9&4@;6]D
M:69I8V%T:6]N(&0G=6X@<&%R=&%G92!I;F5X:7-T86YT+@!0<F]P<FGI=.ES
M`$%O^W0`075S=')A;&EE`$%U=')I8VAE`$%U=&A?8WER=7.@.B!%>'1E;G-I
M;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE+@!!=71H7V-Y<G5SH#H@;&4@
M8F%C:V5N9"!N)V$@<&%S(&QE<R!C87!A8VETZ7,@<F5Q=6ES97,N`$%U=&A?
M8WER=7.@.B!E>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE`$%U
M=&A?9G1PH#H@97AT96YS:6]N(')E<75I<V4@1E10(&YO;B!T<F]U=NEE+B!)
M;"!F875T(&-O;7!I;&5R(%!(4"!A=F5C(&PG;W!T:6]N("TM96YA8FQE+69T
M<"X`075T:%]I;6%PH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O
M=7;I92X`075T:%]K<F(UH#H@97AT96YS:6]N(')E<75I<V4@:W)B-2!N;VX@
M=')O=7;I92X`075T:%]L9&%PH#H@;"=A:F]U="!D)W5T:6QI<V%T975R<R!N
M)V5S="!P87,@<W5P<&]R=.D@879E8R!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<*`Z(&QE(')E=')A:70@9"=U=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U
M<'!O<G3I(&%V96,@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87"@.B!E>'1E
M;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE+@!!=71H7VQD87"@.B!I
M;7!O<W-I8FQE(&0G86IO=71E<B!L)W5T:6QI<V%T975R("5S+B!#96-I(&5S
M="!L82!RZ7!O;G-E(&1U('-E<G9E=7*@.B``075T:%]L9&%PH#H@:6UP;W-S
M:6)L92!D92!S=7!P<FEM97(@;"=U=&EL:7-A=&5U<B`E<P!!=71H7VQD87"@
M.B!M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D92!L)W5T:6QI<V%T975R("5S
M`$%U=&A?;&1A<*`Z(&QA(&UO9&EF:6-A=&EO;B!D97,@=71I;&ES871E=7)S
M(&XG97-T('!A<R!S=7!P;W)TZ64@879E8R!!8W1I=F4@1&ER96-T;W)Y+@!!
M=71H7VUC86R@.B!E>'1E;G-I;VX@<F5Q=6ES92!-0T%,(&YO;B!T<F]U=NEE
M+@!!=71H7W-M8F%U=&B@.B!E>'1E;G-I;VX@<F5Q=6ES92!S;6)A=71H(&YO
M;B!T<F]U=NEE+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX@874@<V5R
M=F5U<B!)34%0+@#)8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX`R6-H96,@
M9&4@;"=A=71H96YT:69I8V%T:6]N("5S`$QE('-E<G9E=7(@4D%$2553(&$@
M<F5J973I(&PG875T:&5N=&EF:6-A=&EO;BX`R6-H96,@9&4@;"=A=71H96YT
M:69I8V%T:6]N(&%U('-E<G9E=7(@1E10+@#)8VAE8R!D92!L)V%U=&AE;G1I
M9FEC871I;VX@874@<V5R=F5U<B!334(N`$-H86UP<R!D:7-P;VYI8FQE<Z`Z
M`$%Z97)B8>]D:F%N`$5X8W5S97,@0D]&2`!#;W5L975R(&1E(&9O;F0`0V]U
M;&5U<B!D92!F;VYD`$UO="!D92!P87-S92!+97)B97)O<R!E<G)O;NDN`$YO
M;2!D92!C;VYN97AI;VX@2V5R8F5R;W,@97)R;V[I+@!"86AA;6%S`$)A:')E
M[VX`0F%L=&4@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&4`4NEP
M97)T;VER92!D97,@9W)A<&AI<75E<R"KH"5SH+L@;F]N('1R;W5VZ2X`3&EG
M;F4@9&4@8F%S90!"Z6QA<G5S`$)E;&=I<75E`$)E;&EZ90!"Z6YI;@!"97)M
M=61E<P!":&]U=&%N`$%N;FEV97)S86ER90!";&]C(*LE<R"[(&1E(&PG87!P
M;&EC871I;VX@JZ`E<Z"[(&EN8V]N;G4`4'+I9NER96YC97,@9&4@8FQO8P!4
M>7!E(&1E(&)L;V,`1W)A<P!";VQI=FEE`%-I9VYE=',`0F]R9'5R90#)<&%I
M<W-E=7(@9&4@;&$@8F]R9'5R9:`Z`$)O<F1S`$)O<VYI92U(97)ZZ6=O=FEN
M90!,97,@9&5U>`!";W1S=V%N80!"87,`0F]U=F5T`$)RZ7-I;`!497)R:71O
M:7)E<R!B<FET86YN:7%U97,@9&4@;"=/8^EA;B!);F1I96X`4W5L=&%N870@
M9'4@0G)U;NEI`$)U;&=A<FEE`$QI<W1E(.`@<'5C97,`0G5R:VEN82!&87-O
M`$)U<G5N9&D`1V5S=&EO;B!D92!C;VYT96YU`$-20P!$:7-T<FEB=71I;VX@
M9&5S('!O:6YT<R!,4D,@*$QI<W1E(&1E('+I=F]C871I;VX@9&5S(&-E<G1I
M9FEC871S*0!0<F]P<FGI=.ES(&1E(&QA($-?96QL=6QE`$PG:6YI=&EA;&ES
M871I;VX@9'4@8V%C:&4@;F4@<R=E<W0@<&%S('1E<FUI;NEE+@!!9V5N9&$`
M0V%L;64`0V%M8F]D9V4`0V%M97)O=6X`26UP;W-S:6)L92!D92!RZ6EN:71I
M86QI<V5R(&QE(&UO="!D92!P87-S92!A=71O;6%T:7%U96UE;G0L(&-O;G1A
M8W1E>B!V;W1R92!A9&UI;FES=')A=&5U<B!S>7-TZ&UE+@!);7!O<W-I8FQE
M(&1E('-U<'!R:6UE<B!L92!F:6-H:65R(*N@)7.@NRX`26UP;W-S:6)L92!D
M)V%D;6EN:7-T<F5R(&1E<R!G97-T:6]N;F%I<F5S(&1E('-E<W-I;VX@97AT
M97)N97,N`,EC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R($E-05"@
M.B`E<P!);7!O<W-I8FQE(&0G;W5V<FER(&QE(&9I8VAI97(@JZ`E<Z"[+@!#
M86YA9&$`06YN=6QE<@!!;FYU;&5R(&QE(')A<'!O<G0@9'4@<')O8FSH;64`
M26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN`$EM
M<&]S<VEB;&4@9&4@=')O=79E<B!U;B!RZ7!E<G1O:7)E('1E;7!O<F%I<F4`
M26UP;W-S:6)L92!D92!P<F]CZ61E<B!S86YS(&QE('!A<F%MZ'1R92"K('1A
M<F=E=$9I;&4@NP!);7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!RZ7!E<G1O
M:7)E(*N@)7.@NRX`4W5P<')E<W-I;VX@:6UP;W-S:6)L92P@:6P@>2!A("5D
M(&5N<F5G:7-T<F5M96YT<R!F:6QS+@!);7!O<W-I8FQE(&1E('+I;W)D;VYN
M97(L(&QE(&YO;6)R92!D)^ELZ6UE;G1S(.`@<NEO<F1O;FYE<B!N92!C;W)R
M97-P;VYD('!A<R!A=2!N;VUB<F4@9"?I;.EM96YT<R!E;G)E9VES='+I<RX`
M3F4@<&5U="!D:7)I9V5R(&QE(&UE<W-A9V4@=F5R<R!L92!N;VUB<F4@<W#I
M8VEF:>DN`$-A<"U697)T`$SI9V5N9&4`5')A;G-P;W)T975R`$-A=.EG;W)I
M97,@970@R71I<75E='1E<P#.;&5S($-A[VUA;@!4Z6SI<&AO;F4@8V5L;'5L
M86ER90!0<F]P<FGI=.ES(&1E(&QA(&-E;&QU;&4`4F5M<&QI<W-A9V4@875T
M;W5R(&1E(&QA(&-E;&QU;&6@.@!0<F]P<FGI=.ES(&1E(&QA(&-E;&QU;&4`
M17-P86-E;65N="!D92!L82!C96QL=6QEH#H`5.ELZ7!H;VYE(&-E;&QU;&%I
M<F4@`$-E;'1E("A)4T\M.#@U.2TQ-"D`0V5N=')E<@!2Z7!U8FQI<75E(&-E
M;G1R869R:6-A:6YE`$5U<F]PZ65N(&-E;G1R86P@*$E33RTX.#4Y+3(I`$3I
M=&%I;',@9'4@8V5R=&EF:6-A=`!0<F]P<FGI=&%I<F4@9'4@8V5R=&EF:6-A
M=`!0;VQI=&EQ=64@9&4@8V5R=&EF:6-A=&EO;@!48VAA9`!-;V1I9FEE<@!-
M;V1I9FEE<B!V;W1R92!M;W0@9&4@<&%S<V4`0VAA;F=E<B!L92!N;VTL(&PG
M861R97-S92!E="!L82!S:6=N871U<F4@<75E(&QE<R!P97)S;VYN97,@=F]I
M96YT('%U86YD(&5L;&5S(&QI<V5N="!E="!RZ7!O;F1E;G0@X"!V;W,@;65S
M<V%G97,N`$QA(&UO9&EF:6-A=&EO;B!D92!V;W1R92!M;W0@9&4@<&%S<V4@
M;B=E<W0@<&%S('-U<'!O<G3I92!A=F5C(&QA(&-O;F9I9W5R871I;VX@86-T
M=65L;&4N($-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U<BX`0VAA<@!6
MZ5]R:69I97(@;&4@;&EE;@!#:&EL:0!#:&EN90!#:&EN;VES('-I;7!L:69I
MZ2`H1T(R,S$R*0!#:&EN;VES('1R861I=&EO;FYE;"`H0FEG-2D`0VAO:7-I
M<B!L)V%P<&QI8V%T:6]NH#H`0VAO:7-I<B!U;B!M;W0@9&4@<&%S<V4`0VAO
M:7-I<B!U;B!N;VT@9&4@8V]N;F5X:6]N`$-H;VES:7(@;&4@;6]D92!D)V%F
M9FEC:&%G92!D97,@9&%T97.@.@!#:&]I<VER(&QE('-T>6QE(&1E(&QI<W1E
M("AP;W5R(&QE<R!L:7-T97,@;G5MZ7)I<75E<RD`SFQE<R!#:')I<W1M87,`
M1.EF:6YI=&EO;B!D92!L82!C;&%S<V4@9&4@)7,@;F]N('1R;W5VZ64N`$5F
M9F%C97(`3F5T=&]Y97(@;&5S(&)A;&ES97,@35,M3V9F:6-E`$5F9F%C97(@
M;&$@<F5Q=>IT90!2971I<F5R(&PG=71I;&ES871E=7(Z("5S`$5F9F%C97(@
M;"=U=&EL:7-A=&5U<@!%9F9A8V5R(&QE<R!D;VYNZ65S(&1E(&PG=71I;&ES
M871E=7(`R6-L86ER8VEE<R!T87)D(&1A;G,@;&$@:F]U<F[I90!#;&EQ=65R
M('!O=7(@<&]U<G-U:79R90!#;&EC:V%T96QL('9I82!(5%10`$9E<FUE<B!L
M82!F96[J=')E`$YU86=E<P!.=6%G97,@;6%T:6YA=7@`3G5A9V5U>`#.;&5S
M($-O8V]S`%)E<&QI97(@;&$@8F%R<F4@9&4@8_1TZ0!2Z61U:7)E(&QE<R!B
M;W)D<P!#;VQO;6)I90!#;W5L975R`%!A;&5T=&4@9&4@8V]U;&5U<G,`4^EL
M96-T:6]N(&0G=6YE(&-O=6QE=7(`0V]L<Z`Z`%1I=')E<R!D92!C;VQO;FYE
M`$(N1"X`0V]M;6%N9&4`0V]M;6%N9&4@<VAE;&P`0V]M;65N=&%I<F4`3F]M
M('5S=65L`$-O;6]R97,`4V]C:>ETZ0!/<F1I;F%T975R<P!#;VYD:71I;VX`
M0V]N9&ET:6]N<P!$:69FZ7)E;F-E<R!D92!C;VYF:6=U<F%T:6]N`%-Y;F-H
M<F]N:7-A=&EO;B!D97,@87-S:7-T86YT<R!P97)S;VYN96QS+"`\23YS;6%R
M='!H;VYE<SPO23X@970@3W5T;&]O:RX`3&$@8V]N9FEG=7)A=&EO;B!N)V5S
M="!P87,@X"!J;W5R+@!#;VYF:6=U<F5R("5S`$-O;F9I<FUE<B!L92!M;W0@
M9&4@<&%S<V4`0V]N9V\`4NEP=6)L:7%U92!DZ6UO8W)A=&EQ=64@9'4@0V]N
M9V\`R6-H96,@9&4@;&$@8V]N;F5X:6]N`,EC:&5C(&1E(&QA(&-O;FYE>&EO
M;J`Z(`!#;VYN97AI;VX@874@<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@<F5F
M=7/I92X`0V]N;F5X:6]N(&%U('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC(')E
M9G5SZ64N(%)A:7-O;J`Z("`E<R`H)7,I`,EC:&5C(&1E(&QA(&-O;FYE>&EO
M;B!A=2!S97)V975R($944`!#;VYT86-T<P!#97,@8V]N=&%C=',@;VYT(&)I
M96X@Z73I(&%J;W5TZ7,@X"!V;W1R92!C87)N970@9"=A9')E<W-E<RX`5'EP
M92!D92!C;VYT96YU(&1U(&9I8VAI97(@8V]M<')E<W/IH#H@`$-O;G1E;G4@
M9&4@JZ`E<Z"[`%!O=7)S=6EV<F4`SFQE<R!#;V]K`%3I;6]I;B`H8V]O:VEE
M*0!#;W!I97(`R6-H96,@9&4@;&$@8V]P:66@.B`E<P!3Z6QE8W1I;VX@9"=U
M;F4@8V]P:64`260N(&-O^W0`0V]S=&$@4FEC80!#]'1E(&0G279O:7)E`$EM
M<&]S<VEB;&4@9&4@8VAI9F9R97(@;&4@;65S<V%G9:`Z(`!3:6=N871U<F4@
M4$=0(&1U(&UE<W-A9V4@:6UP;W-S:6)L9:`Z(`!);7!O<W-I8FQE(&1E(&-H
M:69F<F5R(&QE(&UE<W-A9V4@879E8R!3+TU)344N`%-I9VYA='5R92!3+TU)
M344@9'4@;65S<V%G92!I;7!O<W-I8FQE+@!!:F]U="!D=2!C;VYT86-T("5S
M(&EM<&]S<VEB;&4N(`!.92!P975T('-E(&-O;FYE8W1E<B!A=2!S97)V975R
M($Q$05`N`$YE('!E=70@<V4@8V]N;F5C=&5R(&%U('-E<G9E=7(@3$1!4`!6
MZ7)I9FEC871I;VX@9&4@;&$@8F%L86YC92`E<R!I;7!O<W-I8FQE+B``R6-H
M96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@3$1!4`#)8VAE8R!D92!L
M82!C;VYN97AI;VX@874@<V5R=F5U<B"KH"5SH+L@=FEA($944*`Z("5S`$-R
MZ6%T:6]N(&1E(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B!I;7!O<W-I8FQE+B`E
M<P!);7!O<W-I8FQE(&1E(&3I8VAI9F9R97(@;&5S(&1O;F[I97,@4$=0H#H@
M`$EM<&]S<VEB;&4@9&4@9.EC:&EF9G)E<B!L97,@9&]N;NEE<R!3+TU)344N
M`$YE('!E=70@<&%S('-U<'!R:6UE<B!L92!C;VYT86-T("5S`$YE('!E=70@
M<&%S('-U<'!R:6UE<B!L82!L:7-T92!D92!D:7-T<FEB=71I;VX@)7,`3F4@
M<&5U="!P87,@<W5P<')I;65R(&QE('-C<FEP="!D92!M:7-E(.`@:F]U<B"K
MH"5SH+LN`$3I=&5R;6EN871I;VX@9&4@;"=A9')E<W-E(&1U(&1E<W1I;F%T
M86ER92!I;7!O<W-I8FQE+@!.92!P975T('+I8W5PZ7)E<B!T;W5T(&QE(&-A
M<FYE="!D)V%D<F5S<V4N`$YE('!E=70@<NEC=7#I<F5R('1O=71E(&QA(&QI
M<W1E(&1E(&1I<W1R:6)U=&EO;BX`3B=A('!A<R!P=2!RZ6-U<.ER97(@;&$@
M;&ES=&4@8V]M<&SH=&4@9&4@;&ES=&5S(&1E(&1I<W1R:6)U=&EO;BX`26UP
M;W-S:6)L92!D92!C:&%R9V5R(&QA('-T<F%TZ6=I92"KH"5SH+LN`$EM<&]S
M<VEB;&4@9&4@8W+I97(@;&4@<NEP97)T;VER92"KH"5SH+LN`$EM<&]S<VEB
M;&4@9"=O8G1E;FER(&QA(&-L968@<'5B;&EQ=64@X"!P87)T:7(@9'4@<V5R
M=F5U<B!D92!C;&5F<RX`3W5V97)T=7)E(&1E(*N@)7.@NR!I;7!O<W-I8FQE
M(&5N(.EC<FET=7)E+@!/=79E<G1U<F4@9&4@)7,@:6UP;W-S:6)L92X`26UP
M;W-S:6)L92!D)V]U=G)I<B!L92!M;V1U;&4@36%I;G1E;F%N8V5?5&%S:R`E
M<P!/=79E<G1U<F4@9'4@9&]S<VEE<B"KH"5SH+L@:6UP;W-S:6)L92X`26UP
M;W-S:6)L92!D)V%T=&5I;F1R92!L92!S97)V975R($Q$05`N`$QE8W1U<F4@
M9&4@)7,@:6UP;W-S:6)L92X@`$XG82!P=2!R96UE='1R92#@('KI<F\@;&4@
M;6]T(&1E('!A<W-E('!O=7(@;"=U=&EL:7-A=&5U<B!D96UA;F3I+B!#97)T
M86EN<R`H;W4@=&]U<RD@;&5S(&3I=&%I;',@;F4@<V]N="!P87,@8V]R<F5C
M=',N(%+I97-S87EE>B!O=2!C;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E
M=7(@<&]U<B!D92!L)V%I9&4N`%+I8W5PZ7)A=&EO;B!D97,@04-,(&EM<&]S
M<VEB;&4`3F4@<&5U="!RZ6-U<.ER97(@;&4@8V%R;F5T(&0G861R97-S97,N
M("5S`$YE('!E=70@<NEC=7#I<F5R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO
M;BX@)7,`3F4@<&5U="!RZ6-U<.ER97(@;&5S(&QI<W1E<R!D92!D:7-T<FEB
M=71I;VXN("5S`$YE('!E=70@<NEC=7#I<F5R(&QE<R!P;W-S:6)I;&ETZ7,@
M9'4@<V5R=F5U<@!.92!P975T('!A<R!R979E;FER(.`@;&$@8V]N9FEG=7)A
M=&EO;B!P<NECZ61E;G1E+@!%9F9A8V5M96YT(&1U(&1O<W-I97(@JZ`E<Z"[
M(&EM<&]S<VEB;&4N(`!.92!P975T('!A<R!E;G)E9VES=')E<B!L82!C;VYF
M:6=U<F%T:6]N("5S`$YE('!E=70@<&%S(&5N<F5G:7-T<F5R('5N92!S875V
M96=A<F1E(&1E(&QA(&-O;F9I9W5R871I;VXN`$EM<&]S<VEB;&4@9"=E;G)E
M9VES=')E<B!U;F4@8V]P:64@9&4@;&$@8V]N9FEG=7)A=&EO;J`Z("5S`$EM
M<&]S<VEB;&4@9"=E;G)E9VES=')E<B!L92!S8W)I<'0@9&4@;6ES92#@(&IO
M=7(@9&%N<Z`Z(*N@)7.@NRX`26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R('5N
M92!C;W!I92!D=2!F:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N`$EM<&]S
M<VEB;&4@9"=E;G)E9VES=')E<B!L92!F:6-H:65R(&1E(&-O;F9I9W5R871I
M;VX@)7,N(%9O=7,@<&]U=F5Z('-O:70@=71I;&ES97(@=6YE(&1E<R!O<'1I
M;VYS('!O=7(@<V%U=F5R(&QE(&-O9&4@<W5R("5S('-O:70@8V]P:65R(&UA
M;G5E;&QE;65N="!L92!C;V1E(&-I+61E<W-O=7,@9&%N<R`E<RX`3F4@<&5U
M="!P87,@<F5C:&5R8VAE<B!L92!S97)V975R($Q$05`N`%-U<'!R97-S:6]N
M(&1E(*N@)7.@NR!I;7!O<W-I8FQE+@!-:7-E(.`@:F]U<B!D=2!C;VYT86-T
M(&EM<&]S<VEB;&4N("5S`$YE('!E=70@;65T=')E(.`@:F]U<B!L82!L:7-T
M92!D92!D:7-T<FEB=71I;VXN("5S`$YE('!E=70@<&%S(&5N<F5G:7-T<F5R
M(&QA(&-O;F9I9W5R871I;VX@<&]U<B"KH"5SH+N@.B`E<P!.92!P975T('1R
M;W5V97(@;&$@8F%R<F4@9&4@36]Z:6QL82X@($%S<W5R97HM=F]U<R!Q=2=E
M;&QE(&5S="!A8W1I=F4N`$YE('!E=70@871T<FEB=65R(&-E<R!D<F]I=',@
MX"!L)W5T:6QI<V%T975R(*N@)7.@NR`@<W5R(&QE(&1O<W-I97(@JZ`E<Z"[
MH#H@)7,`5&5X=&4@8V]M<'3I`%!A>7,`0V]U<G,`0W+I97(`0W+I97(@=6X@
M;&EE;@!#<NEE<B!U;B!N;W5V96%U`$-RZ65R('5N('-O=7,M9&]S<VEE<@!0
M97)M:7-S:6]N<R!$92!#<NEA=&5U<@!.=6WI<F\@9&4@8V%R=&4@9&4@8W+I
M9&ET`$-R;V%T:64`0W5B80`T('!H87-E<R!C;W5R86YT97,`4V5S<VEO;G,@
M96X@8V]U<G,`2&5U<F4@86-T=65L;&4`3"=A9')E<W-E(%523"!A8W1U96QL
M92!E<W0`571I;&ES871E=7)S(&%C='5E;',`3V)S97)V871I;VYS(&%C='5E
M;&QE<P!#;VYD:71I;VX@86-T=65L;&6@.B``4W1Y;&4@8V]U<F%N=`!$Z69I
M;FER(&QE<R!TXF-H97,@X"!E9F9E8W1U97(@;&]R<R!D92!L82!C;VYN97AI
M;VX@X"`E<RX`0V]U<&5R`$-O=7!E<B!L82!SZ6QE8W1I;VX`0VAY<')E`$-Y
M<FEL;&EQ=64@*$M/23@M4BD`0WER:6QL:7%U92`H5VEN9&]W<RTQ,C4Q*0!#
M>7)I;&QI<75E+U5K<F%I;FEE;B`H2T])."U5*0!2Z7!U8FQI<75E(%1C:.AQ
M=64`2DH`1%-.("A#9BX@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!#:&%Q=64@:F]U
M<@!.879I9V%T975R(&1E($1A=&%4<F5E`$%L:6%S(&1E(&QA(&)A<V4`1&%T
M90!$871E(&1E('+I8V5P=&EO;@!3Z6QE8W1I;VX@9"=U;F4@9&%T90!*;W5R
M`%-U<'!R:6UE<B!?;&$@8V]L;VYN90!$Z6-E;6)R90!.;VUB<F5S(&3I8VEM
M875X`$1I;6EN=65R(&PG:6YD96YT871I;VX`1.EF875T`$-O=6QE=7(@<&%R
M(&3I9F%U=`!)9&5N=&ETZ2!P87(@9.EF875T`$EN=&5R<'+I=&5U<B!D92!C
M;VUM86YD92!P87(@9.EF875T`$3I9FEN:71I;VYS`$5F9F%C97(`169F86-E
M<B!L82!C96QL=6QE`%-U<'!R:6UE<B!U;B!G<F]U<&4`169F86-E<B!L82!T
M<F%C90!3=7!P<FEM97(@=6YE('!E<FUI<W-I;VX`4W5P<')I;65R(&5T('!U
M<F=E<B!L97,@;65S<V%G97,`169F86-E<B!L82!C96QL=6QE`$5F9F%C97(@
M;&$@8V]L;VYN90!3=7!P<FEM97(@=6X@875T<F4@;6]DZ&QE(&5X:7-T86YT
M`%-U<'!R:6UE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`RG1E<RUV
M;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@
M<V]U<RUP97)M:7-S:6]N<Z`_`$5F9F%C97(@;&$@<F%N9^EE`%-U<'!R:6UE
M<B!L)VED96YT:73I('/I;&5C=&EO;F[I90!%9F9A8V5R(&QA(&-O;&]N;F4@
M86-T=65L;&4`169F86-E<B!L82!R86YGZ64@86-T=65L;&4`4V-R:7!T(&1E
M(&-O;F9I9W5R871I;VX@9&4@;6ES92#@(&IO=7(@<W5P<')I;>D@JZ`E<Z"[
M+@!(975R92!D92!L:79R86ES;VX`1&%N96UA<FL`1.EC<FER92!L92!P<F]B
M;.AM90!$97-C<FEP=&EO;@!$Z71A:6QS("AA=7-S:2!D86YS(&QE(&9I8VAI
M97(@9&4@=')A8V5S(&1E($AO<F1E*:`Z`$QE<R!DZ71A:6QS(&]N="#I=.D@
M8V]N<VEG;NES('!O=7(@;"=A9&UI;FES=')A=&5U<BX`1.EV96QO<'!E;65N
M=`!0;VEN="!D92!R;W/I90!0;VEN="!D92!R;W/I92!P;W5R(&QA(&1E<FYI
MZ')E(&AE=7)EH#H@`%!O:6YT(&1E(')O<^EEH#H@`$1E(&=A=6-H92#@(&1R
M;VET90!$92!D<F]I=&4@X"!G875C:&4`4NEP97)T;VER90!!9F9I8VAE<B!S
M=7(@,C0@:&5U<F5SH#\`3W!T:6]N<R!D)V%F9FEC:&%G90!!9F9I8VAE<B!L
M82!P<NEV:7-I;VX@9.ET86EL;.EE`$%F9FEC:&5R(&QA('!RZ79I<VEO;B`H
M5$%&*0!&;W)M870@9"=A9F9I8VAA9V4`079I<R!D92!L:79R86ES;VX`1&II
M8F]U=&D`3F4@<&%S('-U<'!R:6UE<@!.92!P87,@86-CZ61E<B!D:7)E8W1E
M;65N="#@(&UA:6YT96YA;F-E+G!H<`!,92!P<F5M:65R(&5N<F5G:7-T<F5M
M96YT(&-O;G1I96YT+6EL(&QE(&YO;2!D97,@8VAA;7!SH#\@1&%N<R!L)V%F
M9FER;6%T:79E+"!C;V-H97H@8V5T=&4@8F_N=&6@.@!$;VUI;FEQ=64`4NEP
M=6)L:7%U92!D;VUI;FEC86EN90!6;W5S(&XG879E>B!P87,@9&4@8V]M<'1E
MH#\@16YR96=I<W1R97HM=F]U<RX`5.ELZ6-H87)G97(`5.ELZ6-H87)G97(@
M)7,`5.ELZ6-H87)G97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE(&-O;6UE
M('5N('-C<FEP="!02%``3&ES=&4@9.ER;W5L86YT90!$<F]G=65S`$-O=7)R
M:65R(.EL96-T<F]N:7%U90!0:6QO=&4@9&4@<&%S<V5R96QL92!C;W5R<FEE
M<B`O(%--4RP@<&]U<B!L97,@9F]U<FYI<W-E=7)S(&1E(&-E('-E<G9I8V4N
M`$524@#)<75A=&5U<@!-;V1I9FEE<@#)9&ET97(@;&4@8FQO8P#)9&ET97(@
M=6X@9W)O=7!E`,ED:71E<B!U;F4@<&5R;6ES<VEO;@#)9&ET97(@;&5S('!E
M<FUI<W-I;VYS`,ED:71E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`
MR61I=&5R(&QE<R!O<'1I;VYS('!O=7*@.@#)9&ET97(@;&5S('!E<FUI<W-I
M;VYS('!O=7(@JZ`E<Z"[`,ED:71E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B`E
M<P#)9'5C871I;VX`R6=Y<'1E`%-A;'9A9&]R`,ELZ6UE;G0N+BX`16T`061R
M97-S92#I;&5C=')O;FEQ=64`061R97-S92#I;&5C=')O;FEQ=64`3&5S(&%D
M<F5S<V5S(.EL96-T<F]N:7%U97,@9&]I=F5N="!C;W)R97-P;VYD<F4N`$-O
M=7)R:65R(&%V96,@8V]N9FER;6%T:6]N`%!A<W-E<F5L;&4@8V]U<G)I97(@
M+R!335,`R6UO=&EC]&YE<P!-97-S86=E('9I9&4N`%+I<W5L=&%T('9I9&4N
M`%1E<FUE<R!D92!R96-H97)C:&4@=FED90!!8W1I=F5R(&PG:6YS97)T:6]N
M(&0G:6UA9V5S('9E;F%N="!D97,@86QB=6US('!H;W1O<R!D86YS(&QE('1E
M>'1EH#\`06-T:79E<B!L92!M96YU(&-O;G1E>'1U96P@879E8R!U;B!C;&EC
M(&1R;VETH#\`1FEN(&1E(&PG86YNZ64`06=R86YD:7(@;"?I9&ET975R`,EC
M<FEV97H@=6YE('%U97-T:6]N(&1E('/I8W5R:73I('%U)V]N('9O=7,@<&]S
M97)A('-I('9O=7,@9&5V97H@<F5M971T<F4@X"!ZZ7)O('9O=')E(&UO="!D
M92!P87-S92P@<&%R(&5X96UP;&4@JR!1=65L(&5S="!L92!N;VT@9&4@=F]T
M<F4@86YI;6%L('!RZ6;I<NF@/Z"[H#H`26YS8W)I=F5Z(&PG861R97-S92!5
M4DP@9&4@;"=I;6%G92!I8VD`16YT<F5Z(&QE<R!L971T<F5S(&-I+61E<W-O
M=7.@.@!'=6ENZ64@Z7%U871O<FEA;&4`R7)Y=&ARZ64`17)R975R`$5R<F5U
M<B!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1U(&)L;V.@.B`E<P!%<G)E=7(@;&]R
M<R!D92!L82!S=7!P<F5S<VEO;B!D92!L)V%N8W)E(&1E('-Y;F-H<F]N:7-A
M=&EO;J`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1U(&IO
M=7)N86P@9&4@<WEN8VAR;VYI<V%T:6]NH#H@)7,`17)R975R(&QO<G,@9&4@
M;&$@<NEC=7#I<F%T:6]N(&1U(&-O;G1E;G6@.B`E<P!%<G)E=7(@;&]R<R!D
M92!L82!M:7-E(.`@:F]U<B!D=2!M;W0@9&4@<&%S<V6@.B`E<P!%<G)E=7(@
M879E8R!L92!M97-S86=E+@!%<G)E=7(@;&]R<R!D92!L)V5N<F5G:7-T<F5M
M96YT(&1E(*N@)7.@NRX`17-T;VYI90#)=&AI;W!I90!%=&AN:7%U90!%=7)O
M<&4`5&]U<R!L97,@)F9R86,Q-#L@9"=H975R90!4;W5T97,@;&5S(#(@;6EN
M=71E<P!4;W5T97,@;&5S(#,P('-E8V]N9&5S`%1O=71E<R!L97,@-2!M:6YU
M=&5S`,`@8VAA<75E(&-O;FYE>&EO;@!4;W5T97,@;&5S("9F<F%C,3([(&AE
M=7)E<P!4;W5T97,@;&5S(&UI;G5T97,`17AE;7!L92!D92!V86QE=7)SH#H`
M17CI8W5T97(`1.EV96QO<'!E<@!$Z7!L:65R(&QA(&)A<G)E(&1E(&/T=.D`
MJR`I(+L@871T96YD=64`56X@<V5U;"!M;W0@;W4@97AP<F5S<VEO;B!E;G1R
M92!G=6EL;&5M971S(&%T=&5N9'5S`$1A=&4@9"=E>'!I<F%T:6]N`%)E<'+I
M<V5N=&%N=`!#;W5L975R(&0G879A;G0M<&QA;@!4Z6SI8VAA<F=E;65N="!V
M97)S(&QE('-E<G9E=7(@9&4@;&$@8V]N9FEG=7)A=&EO;B!P87(@1E10`$QE
M8W1U<F4@9&5S('!RZ6;I<F5N8V5S(&EM<&]S<VEB;&4N`,EC:&5C(&1E(&QA
M(&-O;FYE>&EO;B!A=2!S97)V975R($Q$05`N`,EC:&5C(&1E(&QA(&-O;FYE
M>&EO;B!A=2!S97)V975R(%--0BX`R6-H96,@9&4@;&$@8V]P:64@9&5P=6ES
M(*N@)7.@NRX`R6-H96,@9&4@;&$@8V]P:64@=F5R<R`@JZ`E<Z"[+@!);7!O
M<W-I8FQE(&1E(&-RZ65R('5N92!N;W5V96QL92!C;VYN97AI;VX@4T%33`#)
M8VAE8R!D=2!DZ7!L86-E;65N="!V97)S(*N@)7.@NRX`R6-H96,@;&]R<R!D
M92!L82!RZ6-U<.ER871I;VZ@.B`E<P!"96%U`,YL97,@1F%L:VQA;F0@*$UA
M;&]U:6YE<RD`SFQE<R!&Z7)OZ0!%<G)E=7(@9F%T86QEH#H`1F%X`%3I;.EC
M;W!I97,`1NEV<FEE<@!496UPZ7)A='5R92!R97-S96YT:64`5&5M<.ER871U
M<F4@<F5S<V5N=&EEH#H@`%%U96QQ=65S(&%V97)S97,`475E;'%U97,@8VAU
M=&5S(&1E(&YE:6=E`$UA=')I8V4@9&5S(&-H86UP<P!&:6=L970@0T%05$-(
M00!0;VQI8V4@9&4@;&$@/$D^9FEG;&5T/"])/@!&:61J:0!&:6-H:65R`$YO
M;6)R92!D92!F:6-H:65R<Z`Z("5S`$YO;6)R92!D92!F:6-H:65R<Z`Z("5S
M`$=E<W1I;VYN86ER92!D92!F:6-H:65R<P!.;VT@9'4@9FEC:&EE<@!#:&]I
M>"!D92!F:6-H:65R`%3I;.EC:&%R9V5M96YT(&1E(&9I8VAI97(`3"=E;G9O
M:2!D92!F:6-H:65R<R!N)V5S="!P87,@<')I<R!E;B!C;VUP=&4N`$9I;'1R
M97,`1FEN;&%N9&4`4')E;6GH<F4@9&5M:64`4')E;6EE<B!Q=6%R=&EE<@!&
M:7AE<B!L92!R871I;P!2971O=7)N97(`1FQO='1A;G0`0G)O=6EL;&%R9`!$
M;W-S:65R("5S(&EN97AI<W1A;G0N`$-O=6QE=7(@9&4@<&]L:6-E`$YO=7)R
M:71U<F4`4&]U<B!L97,@;F%V:6=A=&5U<G,@;F4@<W5P<&]R=&%N="!P87,@
M;&5S(&EM86=E<P!0<NEV:7-I;VX@*%1!1BD`2F]U<G,@9&4@<'+I=FES:6]N
M("AN;W1E>B!Q=64@;&5S('!RZ79I<VEO;G,@9F]U<FYI97,@9&]N;F5N="!L
M92!J;W5R(&5T(&QA(&YU:72@.R!U;B!G<F%N9"!N;VUB<F4@:6-I('!E=70@
M9F%I<F4@=6X@8FQO8R!T<NAS(&QA<F=E`%9O=7,@879E>B!O=6)L:>D@=F]T
M<F4@;6]T(&1E('!A<W-EH#\`1F]R;75L86ER97,`0VET871I;VX`5'EP92!D
M92!C:71A=&EO;@!#:71A=&EO;G,`0VET871I;VYS(#(`1F]R=6US`%)E9&ER
M96-T:6]N`%9E`$-A9')E<P!&<F%N8V4`1G)A;F-E(&WI=')O<&]L:71A:6YE
M`$=U>6%N92!F<F%NYV%I<V4`4&]L>6[I<VEE(&9R86[G86ES90!497)R97,@
M875S=')A;&5S(&5T(&%N=&%R8W1I<75E<R!F<F%NYV%I<V5S`$1E`$1U(`!$
M97-C<FEP=&EO;B!C;VUP;.AT90!0;&5I;F4@;'5N90!.;VT@8V]M<&QE=`!'
M86)O;@!!;&)U;2!D)V]R:6=I;F4@9&4@;"=I;6%G90!!;&)U;:`Z`$=A;6)I
M90!'Z6[I<F5R(&QA(&-O;F9I9W5R871I;VX@9&4@)7,`0V]D92!GZ6[I<ND`
M1^EO<F=I90!!;&QE;6%G;F4`1VAA;F$`1VEB<F%L=&%R`%!RZ6YO;0!!;&QE
M<@!';V5D96P`0V%R=&5S($=O;V=L90!296-H97)C:&4@1V]O9VQE`$YI=F5A
M=2!D92!G<FES`$=RZ&-E`$=R96,@*$E33RTX.#4Y+3<I`$=R;^MN;&%N9`!'
M<F5N861E`$%D;6EN:7-T<F%T:6]N(&1E<R!G<F]U<&5S`$QE<R!N;VUS(&1E
M(&=R;W5P92!N92!P975V96YT('!A<R#J=')E('9I9&5S`$=R;W5P7VQD87"@
M.B!I;7!O<W-I8FQE(&0G86IO=71E<B!L92!G<F]U<&4@)7,N($-E8VD@97-T
M(&QA('+I<&]N<V4@9'4@<V5R=F5U<J`Z`$=R;W5P7VQD87"@.B!S=7!P<F5S
M<VEO;B!I;7!O<W-I8FQE(&1U(&=R;W5P92`E<P!'<F]U<%]L9&%PH#H@;6]D
M:69I8V%T:6]N(&EM<&]S<VEB;&4@9'4@9W)O=7!E("5S`$=R;W5P97,`1W5A
M9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;F5S97D`4&5R;6ES<VEO;G,@
M9&5S(&EN=FETZ7,`3&EV<F4@9"=O<@!'=6ENZ64`1W5I;NEE+4)I<W-A=0!'
M=7EA;F$`2%1-3`!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I
M;65R(&QA(&1E<FYIZ')E(&-E;&QU;&4@9&4@;&$@<F%N9^EE`$A434Q!<F5A
M(')E9G5S92!BZG1E;65N="!D92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@8V]L
M;VYN92!D=2!T86)L96%U`$A434Q!<F5A(')E9G5S92!BZG1E;65N="!D92!S
M=7!P<FEM97(@;&$@9&5R;FGH<F4@<F%N9^EE(&1U('1A8FQE874`075T:&5N
M=&EF:6-A=&EO;B!(5%10(&YO;B!T<F]U=NEE+@!(8>]T:0!!;&=O<FET:&UE
M(&1E(&AA8VAA9V4`0G)U;64@<^AC:&4`16XM=.IT90!%;BUTZG1E<P#.;&5S
M($AE87)D(&5T($UC1&]N86QD`$]R86=E<R!V:6]L96YT<P!(Z6)R974@*$E3
M3RTX.#4Y+3@M22D`2&%U=&5U<@!!:61E`$%I9&4@<&]U<B!L)^ED:71E=7(`
M06ED90!(Z6UI<W!HZ')E`%9O:6-I(&QE(&3I8G5T(&1U(&9I8VAI97*@.@!(
M875T90!!7V-C=65I;`!#:73I(&1U(%9A=&EC86X`06-C=65I;`!!9')E<W-E
M('!E<G-O;FYE;&QE`%+I<&5R=&]I<F4@<&5R<V]N;F5L`%3I;.EP:&]N92!P
M97)S;VYN96P`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
MH#H@9&]N;NEE<R!834P@)7,@:6YV86QI9&5S(')E=')O=7;I97,@9&%N<R!L
M92!M97-S86=E("5S`$AO<F1E+TMO;&%BH#H@875C=6X@;65S<V%G92!N92!C
M;W)R97-P;VYD(&%U('-U:F5T("5S`$AO<F1E+TMO;&%BH#H@<&%S(&0G;V)J
M970@9&4@='EP92`E<R!T<F]U=ND@9&%N<R!L92!M97-S86=E("5S`$AO<F1E
M+TMO;&%BH#H@)7,@<W5P<')I;>D@JZ`E<Z"[(&%V96,@<W5C8^AS`$AO<F1E
M+TMO;&%BH#H@;&4@;6]T975R(&0G:6YTZ6=R871I;VX@;NEC97-S:71E(&PG
M97AT96YS:6]N("=D;VUX;6PG(&1E(%!(4`!(;W)D92]+;VQA8J`Z(&EM<&]S
M<VEB;&4@9&4@8W+I97(@=6X@;F]U=F5L(&%R8G)E(%A-3"!P;W5R(&PG;V)J
M970@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&0G96YL979E<B`E<R"K
MH"5SH+N@.B`E<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<NEC=7#I
M<F5R(&PG:61E;G1I9FEA;G0@34E-12!P;W5R(&QA('!A<G1I92!D92!T>7!E
M("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D92!S>6YC:')O;FES97(@
M)7,@JZ`E<Z"[H#H@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E('-Y
M;F-H<F]N:7-E<B!L97,@<&%R=&%G97.@.B`E<P!(;W)D92]+;VQA8J`Z('!A
M<G1A9V4@:6YC;VYN=2"KH"5SH+L`3&EG;F4@:&]R:7IO;G1A;&4`4F5M<&QI
M<W-A9V4@:&]R:7IO;G1A;`!(;W)I>F]N=&%LH#H`0V]M;65N="#J=&5S+79O
M=7,@87)R:7;I(&EC::`_("A35E`@<F%P<&]R=&5Z+6QEH"$I`$-O;6)I96X@
M9&4@8V]L;VYN97,@=F]U;&5Z+79O=7,@9G5S:6]N;F5RH#\`0V]M8FEE;B!D
M92!C:&%M<',@*&-O;&]N;F5S*2!Y(&$M="UI;*`_`$-O;6)I96X@9&4@<F%N
M9^EE<R!V;W5L97HM=F]U<R!F=7-I;VYN97*@/P!(=6UI9&ETZ0!(=6UI9&ET
MZ:`Z(`!(=6UO<FES=&5S`$AO;F=R:64`R6-H96,@;&]R<R!D92!L82!C<NEA
M=&EO;B!D92!L82!B;^YT92!)34%0H#H@)7,`R6-H96,@;&]R<R!D92!L82!S
M=7!P<F5S<VEO;B!D92!L82!B;^YT92!)34%0H#H@)7,`R6-H96,@;&]R<R!D
M92!L82!C<NEA=&EO;B!D=2!Q=6]T82!S=7(@;&$@8F_N=&4@24U!4*`Z("5S
M`$%D<F5S<V4@25``061R97-S92!)4"!N;VX@9&ES<&]N:6)L92X`061R97-S
M92!)4"!H;W)S(&1U(&)L;V,@0TE$4B!A;&QO=>DN`%9I;VQA=&EO;B!D92!B
M;&]C86=E($E0+@!)7VYSZ7)E<B!R86YGZ64@879A;G0`27-L86YD90!)8_1N
M97,@<V5U;&5M96YT`$EC]&YE<R!P;W5R("5S`$EC]&YE<R!P;'5S('1E>'1E
M`$YO;2!D=2!C;VUP=&6@.@!3:2!L)V%F9FEC:&%G92!N)V5S="!P87,@8V]R
M<F5C="P@)7,@<&]U<B!L)V]U=G)I<B!D86YS('5N92!N;W5V96QL92!F96[J
M=')E+@!3:2!V;W5S(&YE('9O>65Z(&%U8W5N(&EC]&YE(&5N('5T:6QI<V%N
M="!);G1E<FYE="!%>'!L;W)E<BP@=F]U<R!P;W5V97H@879O:7(@X"!C;V-H
M97(@8V5T=&4@8V%S92!P;W5R(&3I<V%C=&EV97(@;&$@=')A;G-P87)E;F-E
M(&1E<R!03D<N`%-I('9O=7,@=F]Y97H@8V4@;65S<V%G92!M86ES(&%U8W5N
M92!I;6%G92P@;"=I;6%G92!Q=64@=F]U<R!V;W5L97H@96YV;WEE<B!N92!P
M975T(.IT<F4@869F:6-HZ64@<&%R('9O=')E(&YA=FEG871E=7(N`$%P97+G
M=2!D92!L)VEM86=EH#H`061R97-S92!54DP@9&4@;"=I;6%G90!!9')E<W-E
M(%523"!D92!L)VEM86=EH#H`26UA9V4@9&4@;"=A;&)U;0!);6%G92!D92!L
M)V%L8G5MH#H`5.ELZ6-H87)G96UE;G0@9"=I;6%G97,`26UA9V5S`$EM<&]R
M=&%T:6]N+"#I=&%P92`E9`!#:&%M<"!I;7!O<G3IH#H@)7,`0VAA;7!S(&EM
M<&]R=.ESH#H`26Y?<^ER97(@<F%N9^EE(&%P<NAS`$-O9&4@9"=A8W1I;VX@
M:6YC;W)R96-T+@!.;VT@9"=U=&EL:7-A=&5U<B!E="]O=2!V;W1R92!M;W0@
M9&4@<&%S<V4@:6YC;W)R96-T+@!.;VT@9"=U=&EL:7-A=&5U<B!O=2!A9')E
M<W-E(&%L=&5R;F%T:79E(&EN8V]R<F5C="X@(%+I97-S87EE>B!O=2!C;VYT
M86-T97H@=F]T<F4@861M:6YI<W1R871E=7(@<WES=.AM92!P;W5R(&1E(&PG
M86ED92X`075G;65N=&5R(&PG:6YD96YT871I;VX`26YD90!5=&EL:7-A=&5U
M<G,@:6YD:79I9'5E;',`26YD;V[I<VEE`$EN9F\`26YF;W)M871I;VYS`$PG
M:6YF;W)M871I;VX@;B=E<W0@<&QU<R!D:7-P;VYI8FQE+@!);G/I<F5R(&-?
M;VQO;FYE(&%P<NAS`$EN<^ER97(@:6UA9V4`26YSZ7)E<B!U;B!T86)L96%U
M`$EN<^ER97(@=6X@;&EE;B!W96(`26YSZ7)E<B!?8V]L;VYN92!A=F%N=`!)
M;G/I<F5R('5N92!N;W5V96QL92!C;VQO;FYE(&%P<NAS(&QA(&-O;&]N;F4@
M86-T=65L;&4`26YSZ7)E<B!U;F4@;F]U=F5L;&4@8V]L;VYN92!A=F%N="!L
M82!C;VQO;FYE(&%C='5E;&QE`$EN<^ER97(@=6YE(&YO=79E;&QE(')A;F?I
M92!A<'+H<R!L82!R86YGZ64@86-T=65L;&4`26YSZ7)E<B!U;F4@;F]U=F5L
M;&4@<F%N9^EE(&%V86YT(&QA(')A;F?I92!A8W1U96QL90!);G/I<F5R('5N
M('!A<F%G<F%P:&4@87!RZ',@;&4@;B9O96QI9SMU9"!A8W1U96P`26YSZ7)E
M<B!U;B!P87)A9W)A<&AE(&%V86YT(&QE(&XF;V5L:6<[=60@86-T=65L`$EN
M<^ER97(@=6X@875T<F4@;6]DZ&QE`$EN<V-R:79E>B!U;F4@861R97-S92!D
M92!C;W5R<FEE<B#@(&QA<75E;&QE('9O=7,@<F5C979R97H@;&4@;F]U=F5A
M=2!M;W0@9&4@<&%S<V6@.@!);G/I<F5R(&-E;&QU;&4@87!RZ',`26YSZ7)E
M<B!C96QL=6QE(&%V86YT`$EN<^ER97(@8V]L;VYN92!A<'+H<P!);G/I<F5R
M(&-O;&]N;F4@879A;G0`26YSZ7)E<B!L97,@;65S<V%G97,`26YSZ7)E<B!P
M87)A9W)A<&AE(&%P<NAS`$EN<^ER97(@<&%R86=R87!H92!A=F%N=`!);G/I
M<F5R(')A;F?I92!A<'+H<P!);G/I<F5R(')A;F?I92!A=F%N=`!);G-C<FEV
M97H@;&$@<NEP;VYS92#@(&QA('%U97-T:6]N(&1E('/I8W5R:73IH#H`26YS
MZ7)E<B]-;V1I9FEE<B!U;F4@:6UA9V4`26YSZ7)E<B]-;V1I9FEE<B!U;B!L
M:65N('=E8@!#<NED:70@:6YS=69F:7-A;G0@<&]U<B!E;G9O>65R(.`@;&$@
M;&ES=&4@9&4@9&ES=')I8G5T:6]N+@!#<NED:70@:6YS=69F:7-A;G0N`$5N
M=&EE<@!,:7-T92!C;VUP;.AT90!51$@@*%5S97(@1&%T82!(96%D97(I(&EN
M=F%L:61E`$1O;F[I92!:25`@:6YV86QI9&4N`$%P<&QI8V%T:6]N(&EN=F%L
M:61E+@!'<F]U<&4@240@:6YV86QI9&4N`$5N=F]I(&1E(&1O;F[I97,@:6YV
M86QI9&5S+@!!9')E<W-E(&1E(&1E<W1I;F%T:6]N(&EN=F%L:61E+@!&;W)M
M870@9&4@9FEC:&EE<B!I;G9A;&ED92X`0VQE9B!D92!L:6-E;F-E(&EN=F%L
M:61E+@!%;7!L86-E;65N="!I;F1I<77I(&EN=F%L:61E+@"K;7-G7W1Y<&6[
M(&EN=F%L:61E+@"K87!I7VEDNR!I;G9A;&ED92!O=2!M86YQ=6%N="X`4&%R
M86WH=')E<R!I;G9A;&ED97,@;W4@;6%N<75A;G1S+@!097)M:7-S:6]N(&EN
M=F%L:61E+@!)9"X@9&4@<&%R=&5N86ER92!I;G9A;&ED92X`0V]D92!D92!P
M<F]D=6ET(&EN=F%L:61E+@!0<F]T;V-O;&4@:6YV86QI9&4N`$1E<W1I;F%T
M86ER92!I;G9A;&ED9:`Z(*N@)7.@NP!/8FIE="!D92!P87)T86=E(&EN=F%L
M:61E`$%D<F5S<V4@<V]U<F-E(&EN=F%L:61E+@!$;VYNZ64@56YI8V]D92!I
M;G9A;&ED92X`26YV96YT86ER90!);G9E<G-E<B!L82!SZ6QE8W1I;VX`27)A
M;@!)<F%K`$ER;&%N9&4`SFQE(&1E($UA;@!496UPZG1E<R!I<V]LZ65S`$ES
M<F'K;`#);65T=&5U<@!)=&%L:7%U90!)=&%L:64`2F%M8>]Q=64`2F%N=FEE
M<@!*87!O;@!*87!O;F%I<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YI
M90!*=6EL;&5T`$IU:6X`2G5S=&EF:65R`$-E;G1R97(`2G5S=&EF:65R`$%L
M:6=N97(@X"!G875C:&4`06QI9VYE<B#@(&1R;VET90!+87IA:VAS=&%N`$=A
M<F1E<B!L)V]R:6=I;F%LH#\`2V5N>6$`3&4@<V5R=F5U<B!+97)B97)O<R!A
M(')E:F5TZ2!L)V%U=&AE;G1I9FEC871I;VXN`$3I8G5T86YT<R!D=2!N;WEA
M=0!#<NEA=&EO;B!D92!C;&5F`$5M<')E:6YT92!D92!L82!C;&5F`$QO;F=U
M975R(&1E(&QA(&-L968`5'EP92!D92!C;&5F`%5T:6QI<V%T:6]N(&1E(&QA
M(&-L968`3&$@8VQE9B!S92!T<F]U=F4@9.EJX"!S=7(@;&4@<V5R=F5U<B!D
M92!C;&5F<R!P=6)L:6,N`$5N9F%N=',`2VER:6)A=&D`0V]RZ64@9'4@3F]R
M9`!#;W+I92!D=2!3=60`0V]RZ65N("A%54,M2U(I`$MO=V7O=`!+:7)G:&EZ
M:7-T86X`4'+I7W-E;G1A=&EO;@!,86YG=64`3&%O<P!$97)N:>AR92!D96UI
M90!$97)N:>AR92!M;V1I9FEC871I;VX@9'4@;6]T(&1E('!A<W-E`$1E<FYI
M97(@<75A<G1I97(`1&5R;FGH<F4@;6ES92#@(&IO=7*@.@!$97)N:>AR92!C
M;VYN97AI;VZ@.B`E<P!$97)N:>AR92!C;VYN97AI;VZ@.B`E<R#@('!A<G1I
M<B!D92`E<P!$97)N:>AR92!C;VYN97AI;VZ@.B!J86UA:7,`3&5T=&]N:64`
M3&]I`%!RZ7-E;G1A=&EO;@!,86ES<V5R('9I9&4@<&]U<B!N92!P87,@879O
M:7(@9&4@8F]R9'5R90!,:6)A;@!'875C:&4`16YTZG1E(&=A=6-H90!686QE
M=7)S(&1E(&=A=6-H90!,97-O=&AO`$YI=F5A=0!,:6+I<FEA`$QI8GEE`$QI
M96-H=&5N<W1E:6X`0G)U:6YE(&SI9^AR90!0;'5I92!LZ6?H<F4`4&QU:64@
M;.EGZ')E('3T="!D86YS(&QA(&IO=7)NZ64`4&QU:64@;.EGZ')E('1A<F0`
M079E<G-E<R!LZ6?H<F5S`%!L=6EE(&SI9^AR92!A=F5C('1O;FYE<G)E`$YE
M:6=E(&EN=&5R;6ET=&5N=&4`079E<G-E(&1E(&YE:6=E(&SI9^AR90!2:6UE
M<P!,:65N`$QE(&QI96X@<&]I;G1E('9E<G.@.@!,:64@;"=A9')E<W-E(&1E
M(&-O=7)R:65L(.`@;&$@<&%G92!D92!C;VUP;W-I=&EO;B!D=2!M97-S86=E
M(&5N(&PG869F:6-H86YT`$QI96YS`$)I<V-U:70@3&EN=7@`3&ES=&4@+2!U
M=&EL:7-A=&5U<B!P975T('9O:7(@;&4@9&]S<VEE<@!,:7-T92!D97,@8F%S
M97,@9&4@9&]N;NEE<P!);F1E>"!D92!L)V%I9&4`069F:6-H97(@;&5S('1A
M8FQE<P!!<F-H:79E<R!D92!L82!L:7-T90!!:61E(&1E(&QA(&QI<W1E`$ED
M+B!D92!L82!L:7-T90!0<F]P<FGI=&%I<F4@9&4@;&$@;&ES=&4`16YV;VD@
MX"!L82!L:7-T90!!8F]N;F5M96YT(.`@;&$@;&ES=&4`1.ES86)O;FYE;65N
M="!D92!L82!L:7-T90#)8VAE8R!D92!L82!L:7-T92!D97,@<V5S<VEO;G.@
M.B`E<P#)8VAE8R!D92!L82!L:7-T92!D97,@=71I;&ES871E=7)SH#H@)7,`
M3"=A9F9I8VAA9V4@9&4@;&$@;&ES=&4@9&5S('5T:6QI<V%T975R<R!E<W0@
M9.ES86-T:7;I+@!,:71TZ7)A='5R90!,:71U86YI90!#:&%R9V5M96YT+BXN
M`$AE=7)E(&QO8V%L9:`Z(`!(975R92!E="!L;V-A;&4`3&EE=0!#;VYN97AI
M;VX`5')A8V4@9&4@;&$@9&5R;FGH<F4@<V5S<VEO;B!D92!S>6YC:')O;FES
M871I;VX`1.EC;VYN97AI;VX`0V]N;F5X:6]N`%3B8VAE<R!D92!C;VYN97AI
M;VX`3&$@8V]N;F5X:6]N(&5S="!R969U<^EE+B!);"!E<W0@<')O8F%B;&4@
M<75E('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&]U('9O=')E(&UO="!D92!P
M87-S92!A(.ETZ2!M86P@<V%I<VD`R6-H96,@9&4@8V]N;F5X:6]N+@!497AT
M92!L;VYG`$%M;W5R`$9A:6)L90!,971T<F4@9W)E8W%U97,@;6EN=7-C=6QE
M<P!,971T<F4@;&%T:6YE<R!M:6YU<V-U;&5S`$YO;6)R92!R;VUA:6YS(&UI
M;G5S8W5L97,`3'5X96UB;W5R9P!-30!-97-S86=E(&1U(&IO=7(@*$U/5$0I
M`$QA('!IZ&-E(&IO:6YT92!-4RU43D5&(&YE(&-O;G1E;F%I="!A=6-U;F4@
M9&]N;NEE+@!-4T<`36%C86\`4NEP=6)L:7%U92!D92!-86/I9&]I;F4`36%D
M86=A<V-A<@!-86=I90!#;W5R<FEE<@!!9&UI;FES=')A=&EO;B!D=2!C;W5R
M<FEE;`!&86ER92!U;B!L:65?;@!-86QA=VD`36%L86ES:64`36%L9&EV97,`
M36%L:0!-86QT90!!9&UI;FES=')E>B!L82!L:7-T92!D92!C873I9V]R:65S
M(&5T(&QE<R!C;W5L975R<R!L:>EE<R#@(&-E<R!C873I9V]R:65S+@!#87)T
M92"K($UA<#(T(+L`0V%R=&4@JR!-87!Q=65S=""[`$-O<G)E<W!O;F1A;F-E
M<R!E;G)E9VES='+I97,N`$UA<G,`36%R9V4`36%R<75E<B!A=F5C(&1E<R#I
M=&EQ=65T=&5S(%9U+TYO;B!V=0!-87)Q=65R(&%V96,@9"=A=71R97,@Z71I
M<75E='1E<R`H97@N.B!);7!O<G1A;G0O4NEP;VYD=2D`SFQE<R!-87)S:&%L
M;`!-87)T:6YI<75E`$-H86UP<R!A<'!A<F5N=.ES`$UA=7)I=&%N:64`SFQE
M($UA=7)I8V4`0W+I9&ET(&UA>&EM=6T@86QL;W7I+@!,:6UI=&4@9'4@;65S
M<V%G92!DZ7!A<W/I92X`5&5M<.ER871U<F4@;6%X:6UA;&4@9&5S(#(T(&1E
M<FYIZ')E<R!H975R97.@.B``5&5M<.ER871U<F4@;6%X:6UA;&4@9&5S(#8@
M9&5R;FGH<F5S(&AE=7)E<Z`Z(`!.;VUB<F4@;6%X:6UU;2!D92!B;&]C<R!D
M=2!P;W)T86EL`$QO;F=U975R(&UA>&EM=6T`36%I`$UA>6]T=&4`3>ED:6-A
M;65N=`!-96UB<F5S`%1Y<&4@9&4@;65N=:`Z`$9U<VEO;FYE<B!L97,@8V5L
M;'5L97,`365S<V%G90!6Z7)I9FEC871I;VX@9'4@;65S<V%G92!RZ75S<VEE
M+"!M86ES(&QE(&-E<G1I9FEC870@9'4@<VEG;F%T86ER92!N)V$@<&%S('!U
M(.IT<F4@=NER:69IZ2X`365S<V%G92!E>'!I<NDN`%1Y<&4@9&4@;65S<V%G
M90!-Z73I;R!-971A<@!,92!B;&]C(*L@365T87(@NR!N)V5S="!P87,@9&ES
M<&]N:6)L92X`3&4@8FQO8R"K($UE=&%R(+L@;B=E<W0@<&%S(&1I<W!O;FEB
M;&4N("!,97,@9.ET86EL<R!O;G0@Z73I(&-O;G-I9V[I<R!P;W5R(&PG861M
M:6YI<W1R871E=7(N`$UE=&%R1$(@;B=E<W0@<&%S(&-O;FYE8W3I+@!-Z71H
M;V1E`$QA(&WI=&AO9&4@JZ`E<Z"[(&XG97-T('!A<R!DZ69I;FEE`$WI=&AO
M9&4@;F]N(&3I9FEN:64N($WI=&AO9&4@87!P96SI9:`Z("5S`$WI=')I<75E
M`$UE>&EQ=64`R71A=',@9NEDZ7+I<R!D92!-:6-R;V[I<VEE`$UI;&EE=0!4
M>7!E($U)344`5&5M<.ER871U<F4@;6EN:6UU;2!D97,@,C0@9&5R;FGH<F5S
M(&AE=7)E<Z`Z(`!496UPZ7)A='5R92!M:6YI;75M(&1E<R`V(&1E<FYIZ')E
M<R!H975R97.@.B``3&$@9'5RZ64@;6EN:6UA;&4@9'4@;6]T(&1E('!A<W-E
M(&XG82!P87,@96YC;W)E(&5X<&ERZ0!-:7)O:7(`5F%R:>ES`$QE('!A<75E
M=&%G92!(5%107W)E<75E<W0@4$5!4B!E<W0@;6%N<75A;G0N`$-O;F9I9W5R
M871I;VX@:6YE>&ES=&%N=&4N(%9O=7,@9&5V97H@;&$@9^ENZ7)E<B!M86EN
M=&5N86YT('-I('9O=7,@=F]U;&5Z('5T:6QI<V5R(&-E='1E(&%P<&QI8V%T
M:6]N+@!)1"!D=2!M97-S86=E(&UA;G%U86YT+@!,92!P87%U971A9V4@4$5!
M4B!-86EL(&5S="!M86YQ=6%N="X`240@9&4@<V5S<VEO;B!M86YQ=6%N="X`
M3'4`0V]U<G)I96P@<V%N<R!F:6P`36]DZ7+I`$1A=&4@9&4@;6]D:69I8V%T
M:6]N`$UO9&EF:65R(&PG55),`$UO9'5L;P!-;VQD879I90!-;VYA8V\`36]N
M9V]L:64`36]I<R!E="!A;F[I90!-96YS=65L;&5M96YT`$UO;G1S97)R870`
M4&AA<V5S(&1E(&QA(&QU;F4`0VAA;7!S('-U<'!LZ6UE;G1A:7)E<R!T<F]U
M=NES(.`@;&$@;&EG;F4@)60@*&%T=&5N9'5S("5D*2X`36%R;V,`1^ENZ7)A
M;&5M96YT(&5N<V]L96EL;.D`1^ENZ7)A;&5M96YT(&YU86=E=7@`1^ENZ7)A
M;&5M96YT(&5N<V]L96EL;.D`5F5R<R!L92!B87,`1.EP;&%C97(@X"!G875C
M:&4`1.EP;&%C97(@X"!D<F]I=&4`5F5R<R!L92!H875T`%9E<G,@;&4@8F%S
M`%9E<G,@;&4@:&%U=`!-;WIA;6)I<75E`$QI<W1E<R!DZ7)O=6QA;G1E<R!M
M=6QT:2UN:79E875X`$-A<G1E(*N@375L=&EM87`@54N@NP!3Z6QE8W1I;VX@
M;75L=&EP;&4`4&%R86WI=')A9V4@9'4@8V]M<'1E`$UE<R!D;VYNZ65S('!E
M<G-O;FYE;&QE<P!-;VX@<&]R=&%I;`!0<NES96YT871I;VX@9&4@;6]N('!O
M<G1A:6P`0FER;6%N:64`3D].+"!J92!N)V%C8V5P=&4@<&%S`$YO;0!.86UI
M8FEE`$YA=7)U`$[I<&%L`%!A>7,M0F%S`$%N=&EL;&5S(&[I97)L86YD86ES
M97,`55),(&1E(&)A<V4@9&4@3F5T<V-A<&4`55),(&1E('+I=F]C871I;VX@
M9&4@;"=!+D,N($YE='-C87!E`%523"!D92!L82!P;VQI=&EQ=64@9"=!+D,N
M($YE='-C87!E`%523"!D92!R96YO=79E;&QE;65N="!.971S8V%P90!54DP@
M9&4@<NEV;V-A=&EO;B!.971S8V%P90!.;VT@9'4@<V5R=F5U<B!34TP@3F5T
M<V-A<&4`0V]M;65N=&%I<F4@9'4@8V5R=&EF:6-A="!.971S8V%P90!4>7!E
M(&1U(&-E<G1I9FEC870@3F5T<V-A<&4`4NES96%U`$IA;6%I<P!.;W5V96QL
M92U#86SI9&]N:64`3F]U=F5L;&4@8V%TZ6=O<FEE`$YO=79E874@;65S<V%G
M92#@("5S`$YO=79E;&QE(&QU;F4`3F]U=F5A=2!N;VT@9&4@8V]N;F5X:6]N
M("AF86-U;'1A=&EF*0!.;W5V96QL92U:Z6QA;F1E`$YO=79E874@;6]T(&1E
M('!A<W-E`$QE(&YO=79E874@;6]T(&1E('!A<W-E(&5X<&ER97)A(&QE("5X
M+@!,97,@;F]U=F5A=7@@;6]T<R!D92!P87-S92!D:69FZ')E;G0N`$YO=79E
M;&QE(&9E;NIT<F4@*%]B;&%N:RD`3F]U=F5L;&5S`$9O<G5M<P!3=6EV86YT
M`#0@<&AA<V5S('-U:79A;G1E<P!/<'1I;VYS('-U:79A;G1E<P!3=6EV86YT
M/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.=6ET`$YI=64`3F]N`%!A<R!D
M92!D;VYNZ65S(&1E(&-O;F9I9W5R871I;VX@<&]U<B!L97-Q=65L;&5S(&UO
M;G1R97(@;&5S(&1I9F;I<F5N8V5S+@!087,@9&4@<W1R873I9VEE(&1I<W!O
M;FEB;&4@<&]U<B!F86ER92!D97,@:6UA9V5S($E33RX`4&%S(&1E(&=A8F%R
M:70@96X@=')A:71E;65N="!P87(@;&]T+@!!=6-U;B!B;&]C(&XG97AI<W1E
M(.`@;&$@<&]S:71I;VX@9&5M86YDZ64`4&%S(&1E(&YO;2!D92!C86QE;F1R
M:65R(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@34-!3"X`
M3F]N(&UO9&EF:>DN`$%U8W5N92!S;W5S+7!E<FUI<W-I;VX@;B=A(&)E<V]I
M;B!D)^IT<F4@86IO=73I92!S;W5S(&-E(&YI=F5A=2X`075C=6YE(&EN9F]R
M;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@<W#I8VEF:>EE('!O=7(@)7,N`$%U
M8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N:64@<&]U
M<B!&5%`@5D93+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO
M;B!F;W5R;FEE('!O=7(@4U%,(%9&4RX`075C=6YE(&EN9F]R;6%T:6]N(&1E
M(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R(%-13"U&:6QE(%9&4RX`075C
M=6X@8W+I9&ET(&1I<W!O;FEB;&4N`$%U8W5N92!D97-T:6YA=&EO;B!T<F]U
M=NEE+@!!=6-U;B!F:6-H:65R(&5N=F]YZ0!!=6-U;B!I8_1N92!T<F]U=NDN
M`$%U8W5N(&QI974@;B=E<W0@<^EL96-T:6]N;ND`075C=6X@96UP;&%C96UE
M;G0@;B=E<W0@:6YD:7%UZ2X`075C=6X@;65S<V%G92!F;W5R;FD`075C=6X@
M;F]M('-PZ6-I9FGI+@!!=6-U;B!N;VUB<F4@<W#I8VEF:>DN`%!A<R!D)V%P
M:&]R:7-M97,@8VAO<75A;G1S`$%U8W5N(&UO="!D92!P87-S92!F;W5R;FD@
M<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($A45%`N`$%U8W5N(&UO="!D
M92!P87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($E-
M05`N`$%U8W5N(&UO="!D92!P87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I
M9FEC871I;VX@<&%R($ME<F)E<F]S+@!!=6-U;B!M;W0@9&4@<&%S<V4@<W#I
M8VEF:>D@<&]U<B!L)V%U=&AE;G1I9FEC871I;VXN`$%U8W5N(&UO="!D92!P
M87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!005-35T0N
M`$%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF
M:6-A=&EO;B!334(N`$%U8W5N(&-H96UI;B!V97)S(&QE(&)I;F%I<F4@3W!E
M;E-33"!F;W5R;FDN($QE(&)I;F%I<F4@9"=/<&5N4U-,(&5S="!NZ6-E<W-A
M:7)E('!O=7(@9F]N8W1I;VYN97(@879E8R!D97,@9&]N;NEE<R!02T-3(#$R
M+@!!=6-U;F4@8V]N9FER;6%T:6]N(&5N(&%T=&5N=&4`4&%S(&1E('%U;W1A
M('!O<VET:6]N;NDN`%!A<R!D92!RZ&=L97,`075C=6X@<^EP87)A=&5U<B!S
M<.EC:69IZ2X`4&%S(&1E(&/T=.ES`$9I8VAI97(@:6YE>&ES=&%N=`!!=6-U
M;B!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@97-T(&1I<W!O;FEB;&4@<&]U<B!L
M82!C86-H90!!=6-U;B!N;VT@9"=U=&EL:7-A=&5U<B!E="`O;W4@;6]T(&1E
M('!A<W-E(&5N=F]YZ2X`075C=6YE(&1O;F[I92!834P@=F%L:61E(&XG82#I
M=.D@<F5T;W5R;NEE`%!A<R!D92!V86QE=7(`4&%S(&1E('9E<G-I;VX@=')O
M=7;I92!D86YS(&QA(&-O;F9I9W5R871I;VX@;W)I9VEN86QE+B!2Z6?I;NER
M97H@;&$@8V]N9FEG=7)A=&EO;BX`4&%S(&1E('9E<G-I;VX@=')O=7;I92!D
M86YS('9O=')E(&-O;F9I9W5R871I;VXN(%+I9^ENZ7)E>B!L82!C;VYF:6=U
M<F%T:6]N+@!!=6-U;@!!=6-U;B`H=71I;&ES97(@:6UP;&EC:71E;65N="D`
M3F]R9&EQ=64@*$E33RTX.#4Y+3$P*0#.;&4@3F]R9F]L:P!(Z6UI<W!HZ')E
M($YO<F0`SFQE<R!-87)I86YN97,@9'4@;F]R9`!.;W)VZ&=E`%!A<R!A<'+H
M<P!087,@879A;G0`4&%S('5N(&1O<W-I97(`3F]N(&EM<&SI;65N=.DN`$EN
M86-T:68`3F]N('!R:7,@96X@8V]M<'1E+@!.;W1E<P!2:65N(.`@;F%V:6=U
M97(L(')E=&]U<FYE>B!E;B!A<G)IZ')E+@!.;W9E;6)R90!.;VUB<F4`3F]M
M8G)E(&1E(&-A<F%C=.AR97,`3F]M8G)E(&1E(&-O;&]N;F5S`$YO;6)R92!D
M92!R86YGZ65S`$YO;6)R92!N;VX@<W#I8VEF:>D@<&]U<B!L82!M:7-E(.`@
M:F]U<B!D92!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN`$]+`$]B:F5T`$-R
MZ6%T975R(&0G;V)J970`3V-T86P`3V-T;V)R90!&:6QT<F4@86YT:2UO9F9E
M;G-A;G0`0G5R96%U`$PG86YC:65N(&5T(&QE(&YO=79E874@;6]T<R!D92!P
M87-S92!D;VEV96YT(.IT<F4@9&EF9NER96YT<RX`06YC:65N(&UO="!D92!P
M87-S90!,)V%N8VEE;B!M;W0@9&4@<&%S<V4@97-T(&EN8V]R<F5C=`!/;6%N
M`%-E=6P@;&5S('-E<G9E=7)S($E-05`@<W5P<&]R=&5N="!L97,@9&]S<VEE
M<G,@<&%R=&%GZ7,N`%-E=6QE;65N="!L97,@JZ!F;W)T=6YE<Z"[(&]F9F5N
M<V%N=&5S`%5N92!S975L92!A9')E<W-E(&1E(&-O=7)R:65L('!E<FUI<V4N
M`%-E=6QS(&QE('!R;W!R:>ET86ER92!O=2!L)V%D;6EN:7-T<F%T975R('-Y
M<W3H;64@<&5U="!M;V1I9FEE<B!L97,@<&5R;6ES<VEO;G,@9"=U;B!P87)T
M86=E+@!/=79R:7(@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R90!%<G)E=7(@
M3W!E;E-33*`Z(&EM<&]S<VEB;&4@9"=E>'1R86ER92!L97,@9&]N;NEE<R!D
M92!L82!P87)T:64@<VEG;NEE(%,O34E-10!/=79R:7(@;&5S(&QI96YS(&1A
M;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`4WES=.AM92!D)V5X<&QO:71A=&EO
M;@!/<'1I;VYS`$]P=&EO;G,@<&]U<B`E<P!,:7-T92!N=6WI<F]TZ64`3W)G
M86YI<V%T:6]N`%5N:73I(&]R9V%N:7-A=&EO;FYE;&QE`$]R9V%N:7-A=&EO
M;@!-;V3H;&4@;W)I9VEN86P@9"=A<'!L:6-A=&EO;@!-;V3H;&5S(&]R:6=I
M;F%U>"!D86YS("5SH#H`075T<F4`075T<F5S(&EN9F]R;6%T:6]N<P!097)M
M:7-S:6]N<R!D=2!P<F]P<FGI=&%I<F4`3"=A=71H96YT:69I8V%T:6]N(%!!
M32!N)V5S="!P87,@9&ES<&]N:6)L92X`36]D=6QE(%!%05(Z.DUA:6P`4VEG
M;F%T=7)E(&YU;>ER:7%U92!01U``1&]N;NEE<R!01U`@8VAI9F9RZ65S`$-L
M968@<'5B;&EQ=64@4$=0`$1O;F[I97,@4$=0('-I9V[I97,O8VAI9F9RZ65S
M`$-O9&4@4$A0`$EN=&5R<'+I=&5U<B!02%``4&QU:64@;.EGZ')E(&PG87!R
MZ',M;6ED:0!!=F5R<V5S(&PG87!RZ',M;6ED:0!.96EG92!L)V%P<NAS+6UI
M9&D`0VAU=&5S(&1E(&YE:6=E(&PG87!RZ',M;6ED:0!3;VQE:6P@;"=A<'+H
M<RUM:61I`$]R86=E<R!L)V%P<NAS+6UI9&D`17AT96YS:6]N(%!/4TE8(&%B
M<V5N=&4`26YT97)P<NET975R(%!?2%``4F5M<&QI<W-A9V4`4&%K:7-T86X`
M0F5L874`4&%L97-T:6YE("AT97)R:71O:7)E(&]C8W5PZ2D`4&%N86UA`%!A
M<&]U87-I92U.;W5V96QL92U'=6ENZ64`4&%R86=U87D`4&%R=&EE;&QE;65N
M="!N=6%G975X`$UO="!D92!P87-S90!#:&%N9V5M96YT(&1U(&UO="!D92!P
M87-S92!E9F9E8W1UZ2X`36]T(&1E('!A<W-E(&EN8V]R<F5C=`!-;W0@9&4@
M<&%S<V4@<F5Q=6ES('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%)!1$E54RX`
M36]T(&1E('!A<W-E(&%V96,@8V]N9FER;6%T:6]N`$UO="!D92!P87-S9:`Z
M`$UO="!D92!P87-S9:`Z(`!,97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT
M<F4@:61E;G1I<75E<RX`0V]L;&5R`$-O;&QE<B!D97!U:7,@;&4@<')E<W-E
M+7!A<&EE<G,`0VAE;6EN`$-O;F9I<FUA=&EO;G,@96X@871T96YT9:`Z`%!E
M<G-O;FYE<P!0;W5R8V5N=&%G90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@
M9&4@;6%I;G1E;F%N8V4`169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA
M:6YT96YA;F-E(.`@;&$@8V]N;F5X:6]NH#\`4&5R;6ES<VEO;@!,82!P97)M
M:7-S:6]N(*N@)7.@NR!N)V5S="!P87,@<W5P<')I;>EE+@!097)M:7-S:6]N
M(')E9G5SZ64`4&5R;6ES<VEO;G,`061M:6YI<W1R871I;VX@9&5S('!E<FUI
M<W-I;VYS`$1O;F[I97,@<&5R<V]N;F5L;&5S`%#I<F]U`$%N:6UA=7@`4&AI
M;&EP<&EN97,`5.ELZ7!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA
M=&ET=61E<P!35E`@8VQI<75E>B!D86YS('5N92!C96QL=6QE`%-64"!C;VYF
M:7)M97H@;&$@<W5P<')E<W-I;VX@9&4@8V5T(.ELZ6UE;G2@.@!35E`@8V]N
M9FER;65Z('%U92!V;W5S('9O=6QE>B!DZ6QI97(@8V5T(.ELZ6UE;G0N`%9E
M=6EL;&5Z('-A:7-I<B!U;B!M;VES(&5T('5N92!A;F[I92X`5F5U:6QL97H@
M<V%I<VER('5N(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A=.EG;W)I9:`Z`%9E
M=6EL;&5Z(&5N=')E<B!U;F4@861R97-S92!)4"!V86QI9&4N`%9E=6EL;&5Z
M(&5N=')E<B!U;F4@9&%T92!V86QI9&6@.R!VZ7)I9FEE>B!L92!N;VUB<F4@
M9&4@:F]U<G,@9'4@;6]I<RX@`%9E=6EL;&5Z(&5N=')E<B!U;F4@:&5U<F4@
M=F%L:61E+@!6975I;&QE>B!F;W5R;FER('5N('+I<W5MZ2!D=2!P<F]B;.AM
M92X`5F5U:6QL97H@9F]U<FYI<B!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!E
M="!V;W1R92!M;W0@9&4@<&%S<V4`5F5U:6QL97H@;&ER92!L92!T97AT92!S
M=6EV86YT+B!6;W5S(&1E=F5Z(&%C8V5P=&5R(&QE<R!C;VYD:71I;VYS('!O
M=7(@=71I;&ES97(@;&4@<WES=.AM92X`5F5U:6QL97H@96YT<F5R(&QE(&YO
M=79E874@;F]MH&1E(&QA(&-A=.EG;W)I9:`Z`%!O;&]G;F4`4&]L:71I<75E
M`%-C<G5T:6YS`%!O<G1U9V%L`%!O<VET:6]N(&1E(&-E='1E(&EM86=E`%!O
M<VET:6]N(&1E(&-E('1A8FQE874`16YV;WEE<B#@(&-E(&1O<W-I97(@*&YO
M;B!A<'!L:7%UZ2!P87(@24U!4"D`4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@
M)7,@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!0<F]B86)I;&ETZ3QB<B`O/F1E('!L
M=6EE`%!R969S7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T
M<F]U=NEE+@!0<F5F<U]S97-S:6]NH#H@97AT96YS:6]N(')E<75I<V4@JZ!S
M97-S:6]NH+L@;F]N('1R;W5VZ64N`%!R97-S:6]N`%!R97-S:6]N(&%U(&YI
M=F5A=2!D92!L82!M97*@.B``4')E<W-I;VZ@.B``07!E<N=U`$%P97+G=2!D
M92!L)VEM86=E(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`3W!T:6]N<R!P
M<NECZ61E;G1E<P!);7!R:6UE<B!L92!D;V-U;65N=`!#;&5F('!R:7;I90!0
M<F]B;.AM90!$97-C<FEP=&EO;B!D=2!P<F]B;.AM90!0<F]J971S`%1E>'1E
M(&-O=7)T`$-L968@<'5B;&EQ=64`06QG;W)I=&AM92!D92!C;&5F('!U8FQI
M<75E`$EN9F]R;6%T:6]N<R!S=7(@;&$@8VQE9B!P=6)L:7%U90#)8VAE8R!D
M92!L82!GZ6[I<F%T:6]N(&1E(&QA('!A:7)E(&1E(&-L969S('!U8FQI<75E
M+W!R:7;I92X`4&]R=&\@4FEC;P!1871A<@!297%UZG1E`%%U;W1A`$-L968@
M<'5B;&EQ=64@4E-!("@E9"!B:71S*0!3Z6QE8W1I;VX@<F%D:6\`4&QU:64`
M4&QU:64@=/1T(&QE(&UA=&EN`%!L=6EE('1A<F0@9&%N<R!L82!J;W5R;NEE
M`$%V97)S97,`4&QU:64@970@;F5I9V4`4&QU:64@<'5I<R!N96EG90!!<&AO
M<FES;64@874@:&%S87)D`%1A=7@`3&ER90!-97-S86=E<R!L=7,`4W5P<')E
M<W-I;VX@9.EF:6YI=&EV92!D92`E<Z`_`%-U<'!R97-S:6]N(&3I9FEN:71I
M=F4@9&5S(&1O;F[I97,@<&]U<B!L)W5T:6QI<V%T975R("5SH#\@0V5T=&4@
M;W#I<F%T:6]N(&5S="!DZ69I;FET:79E+@!297!R96YD<F4@=F]T<F4@9&5R
M;FGH<F4@86-T:6]N`%)A9G)A[F-H:7(`4F%F<F'N8VAI<B!L97,@Z6SI;65N
M=',@9'4@;65N=2!D>6YA;6EQ=66@.@!2869R8>YC:&ER(&PGZ6-R86X@9'4@
M<V]M;6%I<F6@.@!%>'!R97-S:6]N(')A=&EO;FYE;&QE`$YA=FEG871E=7(@
M<F5L871I;VYN96P`4F5C:&%R9V5R`%)E;6%R<75E<P!397)V975R<R!D:7-T
M86YT<P!54DP@9&ES=&%N=&4@*&AT='`Z+R]W=W<N97AE;7!L92YC;VTO:&]R
M9&4O*:`Z`%)E=&ER97(`4F5T:7)E<B!L92!B;&]C`%)E=&ER97(@;&$@8V]L
M;VYN90!2971I<F5R(&QE(&9O<FUA=&%G90!2971I<F5R(&QA('!A:7)E`$5N
M;&5V97(@;&4@<V-R:7!T(&5N<F5G:7-T<ND@9'4@<NEP97)T;VER92!T96UP
M;W)A:7)E(&1U('-E<G9E=7(N`%)E=&ER97(@;&4`4F5T:7)E<B!C92!N;V5U
M9"!D=2!D;V-U;65N=`!2971I<F5R(&PG=71I;&ES871E=7(`4F5T:7)E<B!L
M)W5T:6QI<V%T975RH#H@)7,`075C=6YE('+I<&]N<V4@X"!V;W1R92!R97%U
MZG1E+B!#;V1E(&0G97)R975R(')E=&]U<F[IH#H@`$QE('-E<G9I8V4@9&5M
M86YDZ2!E<W0@:6YT<F]U=F%B;&4N`$QE('!A<F%MZ'1R92!O8FQI9V%T;VER
M92"KH"5SH+L@;B=E<W0@<&%S('-PZ6-I9FGI(&1A;G,@;&$@8V]N9FEG=7)A
M=&EO;B`E<RX`3&4@<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S
M="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N(&1U(%9&4RX`
M3&4@<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I
M8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N+@!#:&%M<"!O8FQI9V%T;VER
M90!2P%H`4F5M:7-E(.`@>NER;R!D=2!M;W0@9&4@<&%S<V4`4F5M971T<F4@
MX"!ZZ7)O('9O=')E(&UO="!D92!P87-S90!2979E;FER(.`@;&$@9&5R;FGH
M<F4@<F5Q=>IT90!2Z7-U;'1A=',`4F5V96YI<B!A=7@@;W!T:6]N<P!2Z2UE
M;G1R97(@;&4@;F]U=F5A=2!M;W0@9&4@<&%S<V4`4NEU;FEO;@!2979E;FER
M(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E;G1E`$]P=&EO;G,@9&4@;"?I
M9&ET975R(%)I8V@@5&5X=`!$979I;F5T=&5S`$1R;VET90!%;G3J=&4@9&4@
M9')O:71E`%9A;&5U<G,@8V]R<F5C=&5S`%!R;W!R:>ETZ7,@9&4@;&$@<F%N
M7V?I92`N+BX`4O1L90!2;W5M86YI90!0:79O=&5R(#$X,`!0:79O=&5R(.`@
M9V%U8VAE`%!I=F]T97(@X"!D<F]I=&4`4')O<')IZ73I<R!D92!L82!R86YG
MZ64`4')O<')IZ73I<R!D92!L82!R86YGZ64`4F%N9^EE<Z`Z`%+H9VQE<P!$
M97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!T;W5T97,@;&5S(')A;F?I
M97,@970@;&5S(&-O;&]N;F5S`$1E<R!F:6QE=',@87!P87)A[G1R;VYT(&5N
M=')E(&QE<R!C;VQO;FYE<R!S975L96UE;G0`1&5S(&9I;&5T<R!A<'!A<F'N
M=')O;G0@96YT<F4@;&5S(')A;F?I97,@<V5U;&5M96YT`$QA;F-E<@!2=7-S
M:64`4G=A;F1A`%-I9VYA='5R92#I;&5C=')O;FEQ=64@4R]-24U%`$UE<W-A
M9V4@8VAI9F9RZ2!3+TU)344`3"=A=71H96YT:69I8V%T:6]N(%-!4TP@;B=E
M<W0@<&%S(&1I<W!O;FEB;&4`365S<V%G97)I92!335,`26YT97)P<NET975R
M(%-13`!/<F1R92!344P@<&]U<B!R971O=7)N97(@;&5S('9A;&5U<G,`4U-(
M`%-50T/(4P!);G1E<G!RZ71E=7(@4U]13`!380!386EN=&4M2.ELZ&YE`%-A
M:6YT+4-H<FES=&]P:&4M970M3FGI=NAS`%-A:6YT92U,=6-I90!386EN="U0
M:65R<F4@970@36EQ=65L;VX`4V%I;G0M5FEN8V5N="UE="UL97,@1W)E;F%D
M:6YE<P!-ZFUE(&-A9')E("A?<V5L9BD`4V%M;V$@;V-C:61E;G1A;&5S`%-A
M:6YT+4UA<FEN`%-A;RU4;VWI+65T+5!R:6YC:7!E`$9O=7)N:7-S975R('-A
M=&5L;&ET90!!<F%B:64@4V%O=61I=&4`16YR96=I<W1R97(`16YR96=I<W1R
M97(@JZ`E<Z"[`$5N<F5G:7-T<F5R("5S`$5N<F5G:7-T<F5R(&QE<R!O<'1I
M;VYS`$5N<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I;VX@9^ENZ7+I92!C;VUM
M92!U;B!S8W)I<'0@4$A0(&1A;G,@;&4@<NEP97)T;VER92!T96UP;W)A:7)E
M(&1E('9O=')E('-E<G9E=7(N`$5N<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I
M;VX@9&4@)7,`4V-R:7!T(&1E(&UI<V4@X"!J;W5R(&1E(&-O;F9I9W5R871I
M;VX@96YR96=I<W1RZ2!S;W5SH#H@JR`E<Z"[`$]R86=E<R!I<V]LZ7,`4V-I
M96YC90!296-H97)C:&4`36]T975R<R!D92!R96-H97)C:&4`0VAO:7-I<W-E
M>B!L97,@9FEC:&EE<G,`4^EL96-T:6]N;F5Z('5N92!D871E`%/I;&5C=&EO
M;FYE>B!U;B!G<F]U<&4@X"!A:F]U=&5R`%/I;&5C=&EO;FYE>B!U;B!N;W5V
M96%U('!R;W!R:>ET86ER90!3Z6QE8W1I;VYN97H@=6X@<V5R=F5U<@!3Z6QE
M8W1I;VYN97H@=6X@=71I;&ES871E=7(@X"!A:F]U=&5R`%1O=70@<^EL96-T
M:6]N;F5R`%/I;&5C=&EO;FYE>B!T;W5T97,@;&5S(&-O;7!O<V%N=&5S(&1E
M(&QA(&1A=&4N`$-H;VES:7-S97H@=6X@;V)J970`3F4@<^EL96-T:6]N;F5R
M(&%U8W5N`%/I;&5C=&EO;FYE>B!L97,@8V%R86-TZ')E<R!D;VYT('9O=7,@
M879E>B!B97-O:6X@X"!L)V%I9&4@9&4@;"=O=71I;"!C:2UD97-S;W5S+B!6
M;W5S('!O=79E>B!E;G-U:71E(&QE<R!C;W!I97(@970@;&5S(&-O;&QE<B!D
M86YS('9O=')E('1E>'1E+@!3Z6QE8W1I;VYN97H@;&4@9.EL:6UI=&5U<B!D
M92!D871EH#H`4^EL96-T:6]N;F5Z(&QE(&9O<FUA="!D92!D871EH#H`4^EL
M96-T:6]N;F5R(&QE('!R;V9I;"!Q=64@=F]U<R!DZ7-I<F5Z(&UO9&EF:65R
M.@!3Z6QE8W1I;VYN97H@;&4@9.EL:6UI=&5U<B!D)VAE=7)EH#H`4^EL96-T
M:6]N;F5Z(&QE(&9O<FUA="!D92!L)VAE=7)EH#H`4^EL96-T:6]N;F5Z(&1E
M=7@@8VAA;7!S(&%P<&%R96YTZ7,N`%/I;&5C=&EO;FYE>B!V;W1R92!T:.AM
M92!D92!C;W5L975R<RX`4^EL96-T:6]N;F5Z('9O=')E(&QA;F=U92!P<NEF
MZ7+I9:`Z`$5N=F]Y97(@;&4@<F%P<&]R="!D)V%N;VUA;&EE`$5N=F]Y97(@
M4TU3`%/I;NEG86P`4V]N9&6@.B``4V5P=&5M8G)E`%-E<F)I92!E="!-;VYT
M96YE9W)O`$YU;>ER;R!D92!SZ7)I90!,97,@9&]N;NEE<R!D=2!S97)V975R
M('-O;G0@9F%U<W-E<R!O=2!N;VX@9&ES<&]N:6)L97,N`$%D;6EN:7-T<F%T
M:6]N(&1E<R!S97-S:6]N<P!)9"X@9&4@<V5S<VEO;B!E>'!I<NDN`%-E<W-I
M;VYS`%/I;&5C=&EO;FYE<@!#;VYF:6=U<F5R(&QE<R!O<'1I;VYS('!O=7(@
M=F]U<R!P97)M971T<F4@9&4@<F5M971T<F4@X"!ZZ7)O('9O=')E(&UO="!D
M92!P87-S92!S:2!J86UA:7,@=F]U<R!L)V]U8FQI97HN`$-O;F9I9W5R97(@
M;&5S('-E<G9E=7)S(&1I<W1A;G1S(&%C8V5S<VEB;&5S(&1E<'5I<R!V;W1R
M92!P;W)T86EL+@!3Z6QE8W1I;VYN97H@=F]T<F4@;&%N9W5E('!RZ6;I<NEE
M+"!F=7-E874@:&]R86ER92!E="!L97,@;W!T:6]N<R!D92!D871E+@!$Z69I
M;FES<V5Z(&QA('!R96UIZ')E(&%P<&QI8V%T:6]N(&QA;F/I92P@;&4@=&CH
M;64@9&4@8V]U;&5U<G,L(&QE(')A9G)A[F-H:7-S96UE;G0@9&5S('!A9V5S
M+"!E="!D)V%U=')E<R!O<'1I;VYS(&0G869F:6-H86=E+@!#;VYF:6=U<F%T
M:6]N`%-C<FEP="!D92!C;VYF:6=U<F%T:6]N(&1E(&UI<V4@X"!J;W5R(&1I
M<W!O;FEB;&4`4&QU<VEE=7)S(&5N9')O:71S('!O<W-I8FQE<R!A=F5C(&QE
M('!A<F%MZ'1R9:`Z(`!397EC:&5L;&5S`$%C:&%T`%+I<W5MZ0!$;VET+6]N
M(&3I9FEN:7(@9&5S('1O=6-H97,@9&4@<F%C8V]U<F-I<R!P;W5R(&QA('!L
M=7!A<G0@9&5S(&QI96YSH#\`069F:6-H97(`36]N=')E<B!L97,@9&EF9NER
M96YC97,@96YT<F4@;&$@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I92!A8W1U
M96QL96UE;G0@970@8V5L;&4@;F]U=F5L;&5M96YT(&?I;NERZ64N`$UO;G1R
M97(@;"=H975R92!D92!L82!D97)N:>AR92!C;VYN97AI;VX@X"!L)V5N='+I
M9:`_`$UO;G1R97(@;"=O<'1I;VX@9&4@8V]N<V5R=F5R(&PG;W)I9VEN86P`
M36]N=')E<B!L92!SZ6QE8W1E=7(`069F:6-H97(@;&$@8F%R<F4@9&4@;65N
M=2!D92!T86)L96%U>*`_`$%F9FEC:&5R(&QE(&UE;G4@)7,@X"!G875C:&6@
M/P!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!T86)L96%U(&-E;&QU
M;&4`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ET
MZ7,@9'4@=&%B;&5A=0!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!D
M97,@<')O<')IZ73I<R!D92!L82!R86YGZ64@9'4@=&%B;&5A=0!!9F9I8VAE
M<B!L82!B;^YT92!D92!D:6%L;V=U92!D97,@<')O<')IZ73I<R!D92!L)VEM
M86=E`$%F9FEC:&5R(&PG96YV;VD@9&4@9FEC:&EE<@!!=F5R<V5S`$%V97)S
M97,@=/1T(&1A;G,@;&$@:F]U<F[I90!!=F5R<V5S('1A<F0@96X@:F]U<F[I
M90!!=F5R<V5S(&%U>"!A;&5N=&]U<G,`4F5S<V5R<F5R`%)E<W-E<G)E<B!O
M=2!DZ6=A9V5R(&0G86)O<F0@;&4H<RD@8FQO8RAS*2!V;VES:6XH<RD`4VEE
M<G)A($QE;VYE`%,G:6YS8W)I<F4`4VEG;F%T=7)E`$%L9V]R:71H;64@9&4@
M<VEG;F%T=7)E`%-I;F=A<&]U<@!486EL;&4`06YN=6QE<B!L82!M86EN=&5N
M86YC90!3;&]V87%U:64`4VQO=NEN:64`3F5I9V4`079E<G-E(&1E(&YE:6=E
M`$%V97)S97,@9&4@;F5I9V4`079E<G-E<R!D92!N96EG92!T]'0@9&%N<R!L
M82!J;W5R;NEE`$%V97)S97,@9&4@;F5I9V4@=&%R9"!E;B!J;W5R;NEE`$AA
M=71E=7(@9&4@;F5I9V6@.B``475A;G1I=.D@9"=E874@Z7%U:79A;&5N=&4@
MX"!L82!Q=6%N=&ETZ2!D92!N96EG9:`Z(`#.;&5S(%-A;&]M;VX`4V]M86QI
M90!#:&%N<V]N<R!E="!P;^AM97,`4^EL96-T:6]N(&1E(&PG;W)D<F4@9&4@
M=')I`$%D<F5S<V4@<V]U<F-E`$%F<FEQ=64@9'4@<W5D`%-U9"UE=7)O<.EE
M;B`H25-/+3@X-3DM,RD`1^EO<F=I92UD=2US=60@970@[FQE<R!386YD=VEC
M:"UD=2US=60`2.EM:7-P:.AR92!3=60`17-P86-E(&5N=')E(&-E;&QU;&5S
M(&%D:F%C96YT97,`17-P86-E(&5N=')E(&QE(&-O;G1E;G4@970@;&$@8F]R
M9'5R92!D86YS('5N92!C96QL=6QE`$5S<&%C975R`$5S<&%C96UE;G0`17-P
M86-E;65N="!E="!R96UP;&ES<V%G90!%<W!A9VYE`%!O=7)R:65L`$-A<F%C
M=.AR97,@<W#I8VEA=7@`4V-I;F1E<B!L82!C96QL=6QE`%-C:6YD97(@;&$@
M8V]L;VYN90!38VEN9&5R(&QA(')A;F?I90!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!!;F[I92!D92!DZ6)U=`#)=&%T(&]U('!R;W9I
M;F-E`%-T871U=`!&;W)M870@9&4@<V%U=F5G87)D90!2=64`0F%R<ND`3&ES
M=&4@9&4@8VAA[FYE<P!2971I<F5R(&QE(&1O;6%I;F4@9&4@;"=A9')E<W-E
M`%-T>6QE(%M#4U-=`$1I`%-O=7,M<NEP97)T;VER92"KH"5SH+L@;F]N('1R
M;W5VZ0!3=6IE=`!%;G9O:0!,82!D96UA;F1E(&0G86IO=70@9&4@JZ`E<Z"[
M(&%U('-Y<W3H;64@82#I=.D@<V]U;6ES92X@5F]U<R!N92!P;W5R<F5Z('!A
M<R!V;W5S(&-O;FYE8W1E<B!J=7-Q=2?@('-O;B!A<'!R;V)A=&EO;BX`26YD
M:6-E`%-U8V/H<P"KH"5SH+L@82!B:65N(.ETZ2!A:F]U=.DH92DN`$QE<R!D
M;VYNZ65S(&1E(&PG=71I;&ES871E=7(@JZ`E<Z"[(&]N="!B:65N(.ETZ2!R
M971I<NEE<R!D=2!S>7-TZ&UE+BX`JZ`E<Z"[(&$@8FEE;B#I=.D@<W5P<')I
M;>DH92DN`*N@)7.@NR!A(&)I96X@Z73I(')E=&ERZ2AE*2X`4F5T;W5R(.`@
M;&$@8V]N9FEG=7)A=&EO;B!I;FET:6%L92!RZ75S<VDN("!2869R8>YC:&ER
M(&QA('!A9V4@<&]U<B!V;VER(&QE<R!M;V1I9FEC871I;VYS+@!%;G)E9VES
M=')E;65N="!D92!L82!C;VYF:6=U<F%T:6]N(&1E(&QA('-A=79E9V%R9&4@
M<NEU<W-I+@!%;G)E9VES=')E;65N="!RZ75S<VD@9&4@;&$@8V]P:64@9&4@
M<V%U=F5G87)D92!D=2!F:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N`*N@
M)7.@NR!A(&)I96X@Z73I(&UI<RAE*2#@(&IO=7(N`,EC<FET=7)E(&1E("5S
M('+I=7-S:0!3;W5D86X`4V]M;6%I<F4`3&5V97(@9'4@4V]L96EL`$-O=6-H
M97(@9'4@4V]L96EL`$5N<V]L96EL;.D`3&5V97(@9'4@4V]L96EL`$QE=F5R
M+T-O=6-H97(@9'4@4V]L96EL`$QE=F5R(&1U(%-O;&5I;#H@`$-O=6-H97(@
M9'4@4V]L96EL`$-O=6-H97(@9'4@4V]L96ELH#H@`$5X<&]S86YT`$%S<VES
M=&%N8V4`4W5R:6YA;2!O=2!'=7EA;F4@:&]L;&%N9&%I<V4`3F]M(&1E(&9A
M;6EL;&4`SFQE<R!3=F%L8F%R9"!E="!*86X@36%Y96X`4W=A>FEL86YD`%-U
MZ&1E`%-U:7-S90!*;W5R;F%L(&1E('-Y;F-H<F]N:7-A=&EO;B!S=7!P<FEM
MZ0!3>6YC34P`17)R975R(&1E('-Y;G1A>&4@9&%N<R!L97,@=&5R;65S(&1E
M(')E8VAE<F-H90!3>7)I90!/<F%G97,`3W)A9V4@970@=F5N=`!/<F%G97,`
M3W)A9V5S(&UA=&EN875X`$9I8VAI97(@5%-6`%1A8FQE874`4')O<')IZ73I
M<R!D=2!T86)L96%U`%1A8FQE874@9&4@=F%L975R<P!0<F]P<FGI=.ES(&1U
M('1A8FQE874`5&'O=V%N`%1A[W=A;BP@<')O=FEN8V4@9&4@0VAI;F4`5&%J
M:6MI<W1A;@!486YZ86YI90!#:6)L9:`Z`%3B8VAE<P!.=6WI<F\@9&4@=.EL
MZ7!H;VYE`%1E;7#I<F%T=7)E('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``
M5&5M<.ER871U<F4`5&5M<.ER871U<F6@.B``5&5M<.ER871U<F4\8G(@+SXH
M)7-(825S+R5S0F$E<RD@)F1E9SLE<P!0<F]F:6P@JZ`E<Z"[(&YO;B!T<F]U
M=ND`061M:6YI<W1R871I;VX@9&5S(&UO9.AL97,`5&5X=&4`5&5X=&4@<V5U
M;`!!;&EG;F5M96YT(&1U('1E>'1E`%1E>'1E(&5N(&AA=70`2F4`5&AA[R`H
M5$E3+38R,"D`5&AA[VQA;F1E`$PG97AT96YS:6]N($944"!N)V5S="!P87,@
M9&ES<&]N:6)L92X`3&4@;6]T975R(&0G:6YTZ6=R871I;VX@2&]R9&4O2V]L
M86(@;F4@<W5P<&]R=&4@<&%S(*N@)7.@NP!,92!J;W5R;F%L($E-4U`@;B=A
M('!A<R!P=2#J=')E(&EN:71I86QI<^DN`$QA(&-L87-S92!-86EN=&5N86YC
M93HZ(&XG82!P87,@Z73I(&-H87)GZ64@8V]R<F5C=&5M96YT`$QA(&9E;NIT
M<F4@9&5S(&]P=&EO;G,@<R=E<W0@9F5R;>EE+B!3;W)T:64N`$PG861M:6YI
M<W1R871E=7(@9&]I="!C;VYF:6=U<F5R('5N(&)A8VME;F0@<&5R;6%N96YT
M('!O=7(@;&5S('!E<FUI<W-I;VYS('-I('9O=7,@=F]U;&5Z(&QE<R!E;7!L
M;WEE<BX`3&$@8F]R9'5R92!D=2!B87,@<V5U;&5M96YT`$PG240@9'4@8V]N
M=&%C="!N)V$@<&%S(.ETZ2!S<.EC:69IZ2P@;&%I<W/I('9I9&4@;W4@;B=A
M('!A<R#I=.D@=')O=7;I(&1A;G,@;&$@8F%S92!D92!D;VYNZ65S+@!#92!C
M;VYT86-T(&$@8FEE;B#I=.D@86IO=73I(.`@=F]T<F4@8V%R;F5T(&0G861R
M97-S97,N(`!,92!B;&]C(&1E('-I9VYA='5R92!01U`@<^EP87+I(&5S="!N
MZ6-E<W-A:7)E('!O=7(@=NER:69I97(@;&$@<VEG;F%T=7)E+@!,)TE$(&1E
M(&QA(&QI<W1E(&XG82!P87,@Z73I('-PZ6-I9FGI+"!L86ES<^D@=FED92!O
M=2!N;VX@=')O=7;I(&1A;G,@;&$@8F%S92!D92!D;VYNZ65S+@!,82!L:7-T
M92!D92!D:7-T<FEB=71I;VX@;B=A('!A<R#I=.D@<W#I8VEF:>EE+@!,92!C
M:&EF9G)E;65N="!NZ6-E<W-I=&4@=6YE(&-O;FYE>&EO;B!SZ6-U<FESZ64N
M`$QE(&9I8VAI97(@)7,@9&]I="!C;VYT96YI<B!L97,@;W!T:6]N<R`E<RX`
M3&4@9FEC:&EE<B`E<R!D;VET(&-O;G1E;FER(&-E<G1A:6YE<R!O<'1I;VYS
M("5S+@!,92!F:6-H:65R(&YE('!E=70@<&%S(.IT<F4@8V]P:>D@<W5R(&QU
M:2UMZFUE+@!,92!F:6-H:65R(&YE(&-O;G1E;F%I="!A=6-U;F4@9&]N;NEE
M+@!#92!Q=6D@<W5I="!S;VYT(&QE<R!E;BUTZG1E<R!P;W5R(&-E(&UE<W-A
M9V4@;65S<V%G92]21D,X,C(N`$QE(&UO9&4@<&QE:6X@Z6-R86X@8V%U<V4@
M9&5S('!R;V)LZ&UE<R!A=F5C($EN=&5R;F5T($5X<&QO<F5R(&3[(.`@9&5S
M(&)O9W5E<R!D=2!N879I9V%T975R('%U:2!N)V]N="!P=2#J=')E(&-O;G1O
M=7)NZ7,N(%9O=7,@<&]U=F5Z(.IT<F4@8V]N9G)O;G3I<R#@(&1E(&PG869F
M:6-H86=E(&1E(&-A<F%C=.AR97,@Z71R86YG97,L(&%U(&YO;BUF;VYC=&EO
M;FYE;65N="!D97,@8V5R=&%I;F5S(&9O;F-T:6]N<R!E="]O=2!A=2!P;&%N
M=&%G92!A;.EA=&]I<F4@9'4@;F%V:6=A=&5U<BX@4VD@=F]T<F4@<WES=.AM
M92!E<W0@=6X@5VEN9&]W<R`Y>"P@:6P@97-T('1RZ',@<&]S<VEB;&4@<75E
M('9O=7,@875R97H@=6YE("=&875T92!GZ6[I<F%L92!D92!P<F]T96-T:6]N
M)R!E="!Q=64@=F]U<R!D979R97H@<F5DZ6UA<G)E<B!V;W1R92!O<F1I;F%T
M975R+EQN7&Y6;W5S(&%V97H@Z73I('!RZ79E;G5S+B!35E`@87!P=7EE>B!S
M=7(@3TL@<VD@=F]U<R!V;W5L97H@=&]U:F]U<G,@97-S87EE<B!L92!M;V1E
M('!L96EN(.EC<F%N(&1E(&PGZ61I=&5U<@!,)VED96YT:73I(*N@)7.@NR`@
M82#I=.D@<W5P<')I;>EE+@!,92!C]'3I(&=A=6-H92!S975L96UE;G0`3"=E
M;7!L86-E;65N="!D=2!P<F]G<F%M;64@1VYU4$<@9&]I="#J=')E(&9O=7)N
M:2#@(&QA(&-L87-S92!#<GEP=%]P9W`Z.BX`3&4@;65S<V%G92!E;G9O>>D@
M;&4@)7,@X"`E<R!A=F5C(&-O;6UE('-U:F5T(*N@)7.@NR!A(.ETZ2!A9F9I
M8VCI+B`*26P@;B=Y(&$@875C=6YE(&=A<F%N=&EE('%U92!C92!M97-S86=E
M(&$@Z73I(&QU(&]U(&-O;7!R:7,N`$QE(&YO;2#@('5T:6QI<V5R(&5N(&QI
M86YT(.`@;&$@<&%G92!D92!C;VUP;W-I=&EO;@!,92!N;VUB<F4@9&4@8VAA
M;7!S(&1O:70@ZG1R92!U;B!N;VUB<F4@=F%L:61E+@!,92!M;V1U;&4@3W!E
M;E-33"!E<W0@<F5Q=6ES('!O=7(@;&$@8VQA<W-E($AO<F1E7T-R>7!T7W-M
M:6UE.CHN`$QA('!RZ6;I<F5N8V4@JZ`E<Z"[(&XG82!P87,@<'4@ZG1R92!E
M;G)E9VES='+I92!C87(@<V$@=&%I;&QE(&3I<&%S<V4@;&4@;6%X:6UU;2!A
M=71O<FESZ0!,92!P<F]G<F%M;64@=71I;&ESZ2!P;W5R('9I<W5A;&ES97(@
M8V4@='EP92!D92!D;VYNZ65S("@E<RD@;B=A('!A<R#I=.D@=')O=7;I+@!,
M92!C87)A8W3H<F4@9&4@<')O=&5C=&EO;B!D;VET(.IT<F4@=6X@8V%R86-T
MZ')E('5N:7%U92X`3&5S(&/T=.ES(&=A=6-H92!E="!D<F]I="!S975L96UE
M;G0`3&4@8_1TZ2!D<F]I="!S975L96UE;G0`3&4@<^EP87)A=&5U<B!D;VET
M(.IT<F4@=6X@8V%R86-TZ')E('5N:7%U92X`3&4@<V5R=F5U<B"KH"5SH+L@
M82#I=.D@<W5P<')I;>DN`$QE('-E<G9E=7(@JZ`E<Z"[(&$@Z73I(&5N<F5G
M:7-T<NDN`$QA(')E<77J=&4@9"=E;G)E9VES=')E;65N="!P;W5R("5S(&$@
MZ73I(&3I<&QA8^EE+@!,82!L:6=N92!D96UA;F3I92!N)V5X:7-T92!P87,N
M`$QE(&9I8VAI97(@=&5M<&]R86ER92"K("5SH+L@;B=E>&ES=&4@<&%S+@!,
M92!T97AT92!E;G1RZ2!N92!C;W)R97-P;VYD('!A<R!A=2!T97AT92!S=7(@
M;"?I8W)A;BX`3&4@:&%U="!E="!L92!B87,@<V5U;&5M96YT`$QE(&AA=70@
M<V5U;&5M96YT`$QE<R!D;VYNZ65S('3I;.EC:&%R9^EE<R!V97)S(&QE('-E
M<G9E=7(@;VYT(.ETZ2!P97)D=65S(&1E<'5I<R!L)^ET87!E('!RZ6/I9&5N
M=&4N(`!,92!F:6-H:65R(.EM:7,@;B=A('!A<R!P=2#J=')E(&5N<F5G:7-T
M<NDN`$QE(&)L;V,@JZ!W96%T:&5R+F-O;:"[(&XG97-T('!A<R!D:7-P;VYI
M8FQE+@!2Z7!E<G1O:7)E(&1E<R!T:.AM97,@JZ`E<Z"[(&YO;B!T<F]U=ND`
M26P@;B=Y(&$@<&%S(&0G;W!T:6]N<R!D:7-P;VYI8FQE<P!!=6-U;F4@<&%R
M=&EE(&YE('!E=70@ZG1R92!A9F9I8VCI92!E;B!L:6=N92X`26P@>2`@82!T
M<F]P(&1E(&-A<F%C=.AR97,@9&%N<R!C92!C:&%M<"X@5F]U<R!E;B!A=F5Z
M(&5N='+I("5SH#L@:6P@96X@9F%U="!M;VEN<R!D92`E<RX`56X@<')O8FSH
M;64@97-T(&%P<&%R=2!L;W)S(&1E(&PG86IO=70@9&4@JZ`E<Z"[H#H@)7,`
M56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA('-U<'!R97-S:6]N
M(&1E<R!D;VYNZ65S(&1E(&PG=71I;&ES871E=7(@JZ`E<Z"[H#H@`%5N('!R
M;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D92"K
MH"5SH+N@.B``56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA(&UI
M<V4@X"!J;W5R(&1E(*N@)7.@NZ`Z("5S`%5N('!R;V)LZ&UE(&5S="!A<'!A
M<G4@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!A=6-U;B`E<R!N)V$@
MZ73I('1R86YS;6ES+@!5;F4@97)R975R(&5S="!S=7)V96YU92!L;W)S(&1E
M(&PG96YV;VD@9'4@9FEC:&EE<J`Z(&QE("5S(.ET86ET('!L=7,@9W)O<R!Q
M=64@;&4@;6%X:6UU;2!A=71O<FESZ2`H)60@;V-T971S*2X`56YE(&5R<F5U
M<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!L
M92`E<R!A(.ETZ2!T<F%N<VUI<R!P87)T:65L;&5M96YT+@!5;F4@97)R975R
M(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=A9F9I8VAA9V4@9&4@8V5T=&4@
M<&%R=&4@9'4@;65S<V%G90!5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO
M<G,@9&4@;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE<R!D92!C92!C;VYT86-T
M+@!5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A
M=&EO;B!D92!C971T92!C87)T92!I0V%L96YD87(N`$EL('D@879A:70@=6YE
M(&5R<F5U<B!D86YS(&QE(&9O<FUU;&%I<F4@9&4@8V]N9FEG=7)A=&EO;BX@
M4&5U="WJ=')E(&%V97HM=F]U<R!L86ES<^D@=6X@8VAA;7`@<F5Q=6ES('9I
M9&4N`%5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L)V5XZ6-U
M=&EO;B!D92!C971T92!F;VYC=&EO;B!D=2!C87)N970@9"=A9')E<W-E+B!3
M5E`@97-S87EE<B#@(&YO=79E874@<&QU<R!T87)D+@!);"!Y(&$@974@=6YE
M(&5R<F5U<B!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1E<R!I;F9O<FUA=&EO
M;G,@<W5R(&QE(&-O;G1A8W0N("!6975I;&QE>B!E<W-A>65R(.`@;F]U=F5A
M=2X`26P@>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U
M<B!D92!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN("!6975I;&QE>B!E<W-A
M>65R(&1E(&YO=79E874N`$QE('!RZ7-E;G0@<V5R=F5U<B!)34%0(&YE('-U
M<'!O<G1E('!A<R!L92!P87)T86=E(&1E(&1O<W-I97)S+@#'82!N92!S96UB
M;&4@<&%S(.IT<F4@=6YE(&%R8VAI=F4@4D%2('9A;&ED92X`QV$@;F4@<V5M
M8FQE('!A<R#J=')E('5N(&9I8VAI97(@6DE0('9A;&ED92X`QV$@;F4@<V5M
M8FQE('!A<R#J=')E('5N(&YU;>ER;R!D92!C87)T92!V86QI9&4N`$-E('!I
M;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R#@('1R879E<G,@;&$@
M<&%S<V5R96QL92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI
M(&5N('5T:6QI<V%N="!L)T%022!(5%10`$-E('!I;&]T92!P97)M970@;"=E
M;G9O:2!D92!M97-S86=E<R!V:6$@;&$@<&%S<V5R96QL92!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144`!#92!P:6QO
M=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G97,@X"!T<F%V97)S(&QA('!A
M<W-E<F5L;&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@96X@
M=71I;&ES86YT(&PG05!)($A45%``0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I
M(&1E(&UE<W-A9V5S('!A<B!33510(.`@=')A=F5R<R!L82!P87-S97)E;&QE
M(%9O9&%F;VYE($ET86QI92P@<V5U;&5M96YT(&%U>"!N=6WI<F]S(%9O9&%F
M;VYE+B!#96QA(&[I8V5S<VET92!U;B!C;VUP=&4@9&4@8V]U<G)I96P@5F]D
M869O;F4@271A;&EE("AH='1P.B\O=W=W+C$Y,"YI="DN`$-E(&-H86UP(&5S
M="!O8FQI9V%T;VER92X`0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@
M9&5S(&5N=&EE<G,N`$-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E
M<R!N;VUB<F5S(&5T(&QE<R!D975X+7!O:6YT<RX`0V4@8VAA;7`@;F4@9&]I
M="!C;VYT96YI<B!Q=64@9&5S('9A;&5U<G,@;V-T86QE<RX`0V4@8VAA;7`@
M9&]I="!C;VYT96YI<B!U;F4@;&ES=&4@9"=E;G1I97)S('/I<&%RZ7,@<&%R
M(&1E<R!V:7)G=6QE<R!O=2!D97,@97-P86-E<P!#92!C:&%M<"!D;VET(.IT
M<F4@=6X@;F]M8G)E('9A;&ED92X`0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U
M;B!C;V1E(&1E(&-O=6QE=7(@874@9F]R;6%T(%)'0B!H97AA9.EC:6UA;"P@
M<&%R(&5X96UP;&4@)R,Q,C,T868G+@!#92!F;W)M=6QA:7)E(&$@9.EJX"#I
M=.D@=')A:73I+@!#)V5S="`E<RX`0V5C:2!E<W0@=6X@;V)J970@2V]L86(@
M1W)O=7!W87)E+B!0;W5R('9O:7(@8V5T(&]B:F5T+"!V;W5S(&1E=G)E>B!A
M=F]I<B!U;B!C;&EE;G0@9&4@8V]U<G)I96P@<75I(&-O;7!R96YD(&QE(&9O
M<FUA="!+;VQA8B!'<F]U<'=A<F4N(%!O=7(@=6YE(&QI<W1E(&1E(&-E<R!C
M;&EE;G1S(&1E(&-O=7)R:65L+"!V:7-I=&5Z("5S`$-E(&UE<W-A9V4@82#I
M=.D@Z6-R:70@9&%N<R!U;B!C;V1E(&1E(&-A<F%C=.AR97,@*"5S*2!A=71R
M92!Q=64@;&4@=O1T<F4N`$-E(&YO;6)R92!D;VET(.IT<F4@<W5PZ7)I975R
M(.`@=6XN`$-E('-E<G9E=7(@;F4@<&5U="!P87,@9.EC;VUP<F5S<V5R(&QE
M<R!F:6-H:65R<R!:25`@970@9WII<"X`0V4@<WES=.AM92!E<W0@<'+I<V5N
M=&5M96YT(&3I<V%C=&EVZ2X`0V5T=&4@=F%L975R(&1O:70@ZG1R92!U;B!N
M;VUB<F4N`$-E='1E(&9E;NIT<F4@9&]I="#J=')E(&%P<&5LZ64@9&5P=6ES
M('5N92!F96[J=')E(&1E<R!O<'1I;VYS`%1O;FYE<G)E`%1I8VME=',`2&5U
M<F4`4W5I=FD@:&]R86ER90!&;W)M870@9"=H975R90!3Z6QE8W1I;VX@9&4@
M;"=H975R90!4:6UO<B!O<FEE;G1A;`!4:71R90!4:71R92`H:6YF;V)U;&QE
M*:`Z`,``4&]U<B!SZ6QE8W1I;VYN97(@<&QU<VEE=7)S(&ET96US(.`@;&$@
M9F]I<RP@;6%I;G1E;F5Z(&5N9F]N8^D@;&4@8F]U=&]N(*N@0W1R;*"[("A0
M0RD@;W4@JZ!#;VUM86YD9:"[("A-86,I(&5N(&-L:7%U86YT+@!!=6IO=7)D
M)VAU:0!6;VER(&QA('-O=7)C92!(5$U,`%1O9V\`5&]K96QA=0!$96UA:6X`
M5&]N9V$`2&%U=`!#861R92!D=2!H875T("A?=&]P*0!4<F%D=6-T:6]N<P!4
M<FEN:73I+65T+51O8F%G;P!6<F%I(&]U(&9A=7@`36$`5'5N:7-I90!4=7)Q
M=6EE`%1U<F,@*$E33RTX.#4Y+3DI`%1U<FMMZ6YI<W1A;@#.;&5S(%1U<G%U
M97,@970@0V'O<75E<P!4=79A;'4`16YT<F5Z('9O=')E(&-H;VEXH#H@`$EN
M9&EC92!55J`Z(`!54DP`55),('!O=7(@=F]T<F4@<F%P<&]R="!D92!L:79R
M86ES;VX@9'4@<V-R:7!T`%523#H`3W5G86YD80!5:W)A:6YE`$EM<&]S<VEB
M;&4@9"=A='1E:6YD<F4@;&4@<NEP97)T;VER92!61E,N`$EM<&]S<VEB;&4@
M9"=A:F]U=&5R(&1E<R!I;F9O<FUA=&EO;G,@8V]M<&SI;65N=&%I<F5S(.`@
M;"=I;G-C<FEP=&EO;BX`26UP;W-S:6)L92!D92!M;V1I9FEE<B!L97,@<&5R
M;6ES<VEO;G,@<&]U<B!L92!F:6-H:65R(%9&4R"KH"5SH+LN`$EM<&]S<VEB
M;&4@9&4@;6]D:69I97(@;&5S('!E<FUI<W-I;VYS('!O=7(@;&4@9FEC:&EE
M<B!61E,@)7,O)7,N`$EM<&]S<VEB;&4@9&4@8VAA;F=E<B!P;W5R("5S+@!)
M;7!O<W-I8FQE(&1E(';I<FEF:65R(&QA('1A:6QL92!D=2!F:6-H:65R(&1E
M(*N@)7.@NRX`26UP;W-S:6)L92!D92!VZ7)I9FEE<B!L82!T86EL;&4@9'4@
M9FEC:&EE<B!D92"K("5S+R5S(+LN`$-O;FYE>&EO;B!I;7!O<W-I8FQE(&%U
M('-E<G9E=7(@4U%,+@!#;VYN97AI;VX@:6UP;W-S:6)L92!E;B!34TP`26UP
M;W-S:6)L92!D92!C;W!I97(@=6X@9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@
M9&4@8W+I97(@=6X@<NEP97)T;VER92!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE
M(&1E(&-RZ65R('5N('+I<&5R=&]I<F4@5D93+@!);7!O<W-I8FQE(&1E(&-R
MZ65R(&QE(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&1E(&-RZ65R(&QE('+I
M<&5R=&]I<F4@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D92!C<NEE<B!U;B!F
M:6-H:65R(%9&4R!V:61E+B``3W5V97)T=7)E(&EM<&]S<VEB;&4@9&4@;"=A
M<F-H:79E(&-O;7!R97-SZ64N(`!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E
M(*N@)7.@NRP@;&4@9&]S<VEE<B!N)V5S="!P87,@=FED92X`4W5P<')E<W-I
M;VX@:6UP;W-S:6)L92!D92"KH"5SH+N@.B`E<RX`4W5P<')E<W-I;VX@:6UP
M;W-S:6)L92!D92`E<RP@;&4@9&]S<VEE<B!N)V5S="!P87,@=FED90!3=7!P
M<F5S<VEO;B!RZ6-U<G-I=F4@9'4@9&]S<VEE<B!61E,@:6UP;W-S:6)L92X`
M4W5P<')E<W-I;VX@9'4@<NEP97)T;VER92!61E,@:6UP;W-S:6)L92X`26UP
M;W-S:6)L92!D92!S=7!P<FEM97(@;&4@<NEP97)T;VER92!61E.@.B`E<RX`
M4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!F:6-H:65R(%9&4R"KH"5SH+LN
M`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@9FEC:&EE<B!61E,N`%-U<'!R
M97-S:6]N(&EM<&]S<VEB;&4@9'4@<NEP97)T;VER92!61E,@JZ`E<Z"[+@!3
M=7!P<F5S<VEO;B!61E,@<NEC=7)S:79E(&EM<&]S<VEB;&6@.B`E<RX`26UP
M;W-S:6)L92!D92!DZ71E<FUI;F5R(&QE(&1O<W-I97(@8V]U<F%N="X`26UP
M;W-S:6)L92!D)V5X=')A:7)E(&QE<R!DZ71A:6QS(&1U(&-E<G1I9FEC870`
M26UP;W-S:6)L92!D92!C:&%R9V5R(&QA(&3I9FEN:71I;VX@9&4@)7,N`$EM
M<&]S<VEB;&4@9&4@9.EP;&%C97(@;&4@9FEC:&EE<B!61E,N`$EM<&]S<VEB
M;&4@9"=O=79R:7(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE
M(&0G;W5V<FER('5N(&9I8VAI97(@5D93(&5N(.EC<FET=7)E+@!);7!O<W-I
M8FQE(&0G;W5V<FER('5N(&9I8VAI97(@5D93+@!/=79E<G1U<F4@:6UP;W-S
M:6)L92!D92!L)V%R8VAI=F4@8V]M<')E<W/I92X`26UP;W-S:6)L92!D92!L
M:7)E(&QE(&9I8VAI97(@5D93("CI8VAE8R!D92!F:6QE<VEZ92@I*2X`26UP
M;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97(@5D93("CI8VAE8R!D92!G971&
M:6QE4VEZ92@I*2X`26UP;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97*@.B``
M3&5C='5R92!D=2!RZ7!E<G1O:7)E(')A8VEN92!61E,@:6UP;W-S:6)L92X`
M26UP;W-S:6)L92!D92!R96YO;6UE<B`E<R!E;B`E<Z`Z(&QE(&1O<W-I97(@
M8VEB;&4@97AI<W1E(&3I:N``26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!R
MZ7!E<G1O:7)E(%9&4RX`26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!RZ7!E
M<G1O:7)E(%9&4Z`Z("5S+@!);7!O<W-I8FQE(&1E(')E;F]M;65R(&QE(&9I
M8VAI97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!F
M:6-H:65R(%9&4R`E<R\E<RX`26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!F
M:6-H:65R(%9&4RX`26UP;W-S:6)L92!D)V5XZ6-U=&5R("=M:VES;V9S)RX`
M26UP;W-S:6)L92!D92!T<F%D=6ER92!C92!D;V-U;65N="!7;W)D+@!);7!O
M<W-I8FQE(&0GZ6-R:7)E(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP;W-S
M:6)L92!D)^EC<FER92!L97,@9&]N;NEE<R!D=2!F:6-H:65R(%9&4R`H8V]P
M>2@I(&EM<&]S<VEB;&4I+@!);7!O<W-I8FQE(&0GZ6-R:7)E(&QE<R!D;VYN
MZ65S(&1U(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&0GZ6-R:7)E(&QE(&9I
M8VAI97(@5D93+"!L92!Q=6]T82!S97)A:70@9.EP87-SZ2X`4V]U;&EG;F5R
M`$%N;G5L97(@;&5S(&-H86YG96UE;G1S`$%N;G5L92!V;W1R92!D97)N:>AR
M92!A8W1I;VX`4NEP;VYS92!I;F%T=&5N9'5E(&1U('-E<G9E=7(@;&]R<R!D
M92!L82!C;VYN97AI;VZ@.B``4NEP;VYS92!I;F%T=&5N9'5E(&1U('-E<G9E
M=7(@X*`Z(`!(;W)S(&-A=.EG;W)I90!5;FEC;V1E("A55$8M."D`R6UI<F%T
M<R!!<F%B97,@56YI<P!2;WEA=6UE+55N:0#)=&%T<RU5;FES`,YL97,@97AT
MZ7)I975R97,@9&5S(,ET871S+55N:7,`56YI=.ES`$EN8V]N;G4`87!I;7-G
M:60@:6YC;VYN=2`H05!)($UE<W-A9V4@240I+@!C;&EM<V=I9"!I;F-O;FYU
M("A#;&EE;G0@365S<V%G92!)1"DN`$5M<&QA8V5M96YT('/I;&5C=&EO;F[I
M(&EN8V]N;G4N`$YO;2!D)W5T:6QI<V%T975R(&]U(&UO="!D92!P87-S92!I
M;F-O;FYU+@!$Z6QI97(@;"?I;.EM96YT(&-O=7)A;G0`4V%N<R!N;VT`3&5S
M('-C<FEP=',@;F]N+7!R:79I;.EG:>ES(&YE('!E=79E;G0@86-CZ61E<B!A
M=7@@9F]N8W1I;VYS(&-O=7!E<B]C;W!I97(O8V]L;&5R('!O=7(@9&5S(')A
M:7-O;G,@9&4@<^EC=7)I=.DN($%P<'5Y97H@<W5R($]+('!O=7(@=F]I<B!U
M;F4@;F]T92!T96-H;FEQ=64@<W5R(&UO>FEL;&$N;W)G('%U:2!V;W5S(&5X
M<&QI<75E<F$@8V]M;65N="!A=71O<FES97(@=6X@<V-R:7!T(.`@=71I;&ES
M97(@;&4@<')E<W-E+7!A<&EE<G,`4F5M971T<F4@;&$@8V]U;&5U<B#@('KI
M<F\`17AT96YS:6]N(&YO;B!P<FES92!E;B!C;VUP=&4`36]D:69I97(`36]D
M:69I97(@)7,`36]D:69I97(@;"=U=&EL:7-A=&5U<@!-:7-E(.`@:F]U<B!D
M92"KH"5SH+LN`$QE('-C<FEP="!D92!M:7-E(.`@:F]U<B!E<W0@<W5P<')I
M;>D`0VAA<F=E<@!4;W5S(&QE<R!F:6-H:65R<R!D92!C;VYF:6=U<F%T:6]N
M(&1E<R!A<'!L:6-A=&EO;G,@;VYT(.ETZ2!E;G9O>>ES('-U<B!L92!S97)V
M975R+@!,971T<F5S(&QA=&EN97,@;6%J=7-C=6QE<P!.;VUB<F5S(')O;6%I
M;G,@;6%J=7-C=6QE<P!5<G5G=6%Y`$5M<&QO>>D@86-T=65L;&5M96YTH#H@
M)7,`571I;&ES97(@4U-,`%5T:6QI<V5R('-I(&QE(&YO;2!D)W5T:6QI<V%T
M975R+VUO="!D92!P87-S92!E<W0@9&EF9NER96YT(&1U('-E<G9E=7(@24U3
M4"X`571I;&ES871E=7(`3"=U=&EL:7-A=&5U<B`E<R!N)V$@<&%S(&PG875T
M;W)I<V%T:6]N('!O=7(@)7,N`$%D;6EN:7-T<F%T:6]N(&1E<R!U=&EL:7-A
M=&5U<G,`4'+I9NER96YC97,@<&5R<V]N;F5L;&5S`$5N<F5G:7-T<F5M96YT
M(&1E<R!U=&EL:7-A=&5U<G,`3"=E;G)E9VES=')E;65N="!D)W5T:6QI<V%T
M975R(&5S="!DZ7-A8W1I=ND@<W5R(&-E('-Y<W3H;64N`$-O;7!T92!U=&EL
M:7-A=&5U<B!N;VX@=')O=7;I`$YO;2!D)W5T:6QI<V%T975R`$QE(&YO;2!D
M92!C;VYN97AI;VX@JZ`E<Z"[(&5X:7-T92!DZ6K@+@!.;VT@9"=U=&EL:7-A
M=&5U<J`Z`$YO;2!D)W5T:6QI<V%T975RH#H@`%5T:6QI<V%T975R<R!DZ69I
M;FESH#H`3W5Z8NEK:7-T86X`4NEP97)T;VER92!61E,@:6YE>&ES=&%N="X`
M06)S96YC97,`3&5S(&5M<&QA8V5M96YT<R!V86QI9&5S('1R;W5VZ7,@:6YC
M;'5E;G2@.B``5F%L:61I=.D`5F%L975R(&5N(&UI;G5T97,@X"!P87)T:7(@
M9&4@;6%I;G1E;F%N="X`5F%L975R('-U<.ER:65U<F4@X"!L82!L;VYG=65U
M<B!M87AI;6%L92!D92`E<RX`5F%L975R<P!686QE=7)S(.`@<^EL96-T:6]N
M;F5R(&1E`%9A;G5A='4`5F%R:6%B;&4`5NENZ7IU96QA`,EC:&5C(&1E(&QA
M(';I<FEF:6-A=&EO;B`F;61A<V@[(&-E(&UE<W-A9V4@82!P975T+>IT<F4@
MZ73I(&9A;'-I9FGI+@!697)S:6]N`$-O;G1R]&QE(&1E('9E<G-I;VX`06QI
M9VYE;65N="!V97)T:6-A;`!296UP;&ES<V%G92!V97)T:6-A;`!697)T:6-A
M;*`Z`%1RZ',@:&%U=&4`5FEE=&YA;0!6:>IT+6YA;6EE;B`H5DE30TE)*0!6
M;VER("5S`%9O:7(@=6YE('!A9V4@=V5B(&5X=&5R;F4`5F]I<B!C;VUM92`E
M<P#.;&5S(%9I97)G97,@8G)I=&%N;FEQ=65S`,YL97,@5FEE<F=E<R!D97,@
MR71A=',M56YI<P!6:7-I8FEL:73I`%9I<VEB:6QI=.F@.B``5F]D869O;F4@
M271A;'D@=FEA(%--5%``3D]424-%`$%45$5.5$E/3B$A(2`@4U504%))3452
M($Q%(%-#4DE05"!-04Y514Q,14U%3E0@1$4@)7,`5TE.('9I82!(5%10`%=A
M;&QI<R!E="!&=71U;F$`071T96YT:6]N`$UE`%!RZ79I<VEO;G,@;>ETZ6\`
M1&]N;NEE<R!MZ73I;R!F;W5R;FEE<R!P87(`5V5A=&AE<BYC;VT`5V5B`%-I
M=&4@=V5B`$-H87%U92!S96UA:6YE`$)I96YV96YU90!":65N=F5N=64@X"`E
M<P!":65N=F5N=64L("5S`$]C8VED96YT86P@*$E33RTX.#4Y+3$I`$]C8VED
M96YT86P@*$E33RTX.#4Y+3$U*0!386AA<F$@3V-C:61E;G1A;`!1=65L;&4@
M87!P;&EC871I;VX@)7,@9&]I="UI;"!P<NES96YT97(@87!RZ',@;&$@8V]N
M;F5X:6]NH#\`475E;"!E<W0@;&4@8V%R86-TZ')E(&1E('/I<&%R871I;VZ@
M/P!1=65L(&5S="!L92!C87)A8W3H<F4@9&4@8VET871I;VZ@/P!#87)T92!7
M:&5R96ES($%U<W1R86QI90!1=65L;&5S('!H87-E<P!1=65L;&5S(&5X=&5N
M<VEO;G,@86-T:79E<B!P;W5R(&PGZ61I=&5U<B!2:6-H(%1E>'0N`$QA<F=E
M=7(`3&%R9V5U<B!E;B!U;FETZ7,@0U-3`$QA<F=E=7(@9'4@;65N=2!D92!G
M875C:&4@)7,@("AL82!C;VYF:6=U<F%T:6]N('!R96YD<F$@969F970@X"!L
M82!P<F]C:&%I;F4@8V]N;F5X:6]N*:`Z`$QA<F=E=7(@9'4@=&%B;&5A=0!5
M;FETZ2!D92!L87)G975R`$QA<F=E=7*@.@!7:6MI`%9E;G0`5F5N="!T]'0@
M;&4@;6%T:6X`5FET97-S92!D=2!V96YT(&5N(&XF;V5L:6<[=61S`%9E;G2@
M.@!696YTH#H@`%-A9V5S<V4`3&ES=&4@9&4@=B9O96QI9SMU>`!4<F%V86EL
M`$%D<F5S<V4@<')O9F5S<VEO;FYE;&QE`%3I;.EP:&]N92!P<F]F97-S:6]N
M;F5L`$YO;6)R92!D92!C:&%M<',@:6YC;W)R96-T(.`@;&$@;&EG;F4@)60N
M("5D(&%T=&5N9'5S+"`E9"!T<F]U=NES+@!.;VUB<F4@9&4@8VAA;7!S(&EN
M8V]R<F5C="X@)60@871T96YD=7,L("5D('1R;W5VZ7,N`$3I8V%L86=E("5D
M(&EN8V]R<F5C="!L;W)S(&1E(&QA(&QE8W1U<F4@9&4@9FEC:&EE<B!61E,N
M`%@M4F5F`$-O;G1R86EN=&5S(&)A<VEQ=65S(%@U,#EV,P!5=&EL:7-A=&EO
M;B!D92!C;.D@Z71E;F1U92!8-3`Y=C,`075T<F4@;F]M(&1U('-U:F5T(%@U
M,#EV,P!)9&5N=&EF:6%N="!D92!C;.D@9'4@<W5J970@6#4P.78S`$5X=&5N
M<VEO;G,@6#4P.78S`$%!`$%!04$`0V%R=&4@JZ!986AO;Z`AH+L`06YN=65L
M;&5M96YT`%GI;65N`$]U:0!/=6DL(&HG86-C97!T90!6;W5S(.IT97,@96X@
M;6]D92"KH%1E>'1EH+LN(%5T:6QI<V5Z(&QE(&)O=71O;B!;/#Y=('!O=7(@
M<F5V96YI<B!A=2!M;V1E(*N@5UE325=91Z"[+@!6;W5S(&XGZG1E<R!P87,@
M875T;W)I<^D@X"!C<NEE<B!P;'5S(&1E("5D(&)L;V-S+@!6;W5S(&XGZG1E
M<R!P87,@875T:&5N=&EF:>DN`%9O=7,@;F4@<&]U=F5Z('!A<R!A=F]I<B!L
M92!C87)A8W3H<F4@JUR[(&1A;G,@=F]T<F4@;F]M(&-O;7!L970N`%9O=7,@
M;B=A=F5Z('!A<R!S86ES:2!U;F4@861R97-S92#I;&5C=')O;FEQ=64@=F%L
M:61E+@!6;W5S(&XG879E>B!P87,@87-S;V-IZ2!L97,@8VAA;7!S(&1U(&9I
M8VAI97(@:6UP;W)TZ2!A=7@@8VAA;7!S(&-O<G)E<W!O;F1A;G1S(&1A;G,@
M)7,N`%9O=7,@879E>B#I=.D@9.EC;VYN96-TZ2X`5F]U<R!D979E>B!I;G-C
M<FER92!U;B!N=6WI<F\@9&4@8V5L;'5L86ER92!V86QI9&4L('-E=6QS(&1E
M<R!N;VUB<F5S(&5T('5N(*LKNR!O<'1I;VYN96P@<&]U<B!L97,@87!P96QS
M(&EN=&5R;F%T:6]N875X+@!6;W5S(&XG879E>B!P87,@<V%I<VD@=6YE(&5N
M='+I92!V86QI9&4N`%9O=7,@9&5V97H@8V]N9FEG=7)E<B!U;B!B86-K96YD
M($1A=&%4<F5E('!O=7(@=71I;&ES97(@;&5S(&EN<V-R:7!T:6]N<P!6;W5S
M(&1E=F5Z(&-O;F9I9W5R97(@=6X@;6]D=6QE(%9&4RX`5F]U<R!D979E>B!D
MZ6-R:7)E(&QE('!R;V)LZ&UE(&%V86YT(&1E(&YO=7,@9F%I<F4@<&%R=F5N
M:7(@;&4@<F%P<&]R="X`5F]U<R!D979E>B!E;G1R97(@=6YE(%523"!O^2!P
M;VEN=&4@9&4@;&EE;BX`26P@9F%U="!SZ6QE8W1I;VYN97(@=6X@<V5R=F5U
M<B#@('-U<'!R:6UE<BX`5F]U<R!D979E>B!S<.EC:69I97(@=6X@=71I;&ES
M871E=7(@X"!R971I<F5R+B``5F]U<R!D979E>B!S<.EC:69I97(@=6X@=71I
M;&ES871E=7(@X"!R971I<F5R+@!6;W5S(&1E=F5Z('-PZ6-I9FEE<B!U;B!U
M=&EL:7-A=&5U<B#@(&%J;W5T97(N`%9O=7,@9&5V97H@<W#I8VEF:65R(&QE
M(&YO;2!D92!L)W5T:6QI<V%T975R(.`@;6]D:69I97(N`%9O=7,@9&5V97H@
M:6YD:7%U97(@<75E;&QE(&%C=&EO;B!A8V-O;7!L:7(N`%9O=7,@9&5V97H@
MZ6-R:7)E('5N(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A=.EG;W)I92X`5F]U
M<R!D979E>B!F;W5R;FER('5N(&ZP(&1E('3I;.EP:&]N92!I=&%L:65N`%9O
M=')E('-E<W-I;VX@)7,@82!E>'!I<NDN(%9E=6EL;&5Z('9O=7,@<F5C;VYN
M96-T97(N`%9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96P`5F]T<F4@861R97-S
M92!D92!C;W5R<FEE;""K($1E.B"[H#H`5F]S(&1O;F[I97,@<&5R<V]N;F5L
M;&5S`%9O=')E(&%D<F5S<V4@26YT97)N970@82!C:&%N9^D@9&5P=6ES(&PG
M;W5V97)T=7)E(&1E('9O=')E('-E<W-I;VX@)7,N("!0;W5R('9O=')E('/I
M8W5R:73I+"!V;W5S(&1E=F5Z('9O=7,@<F5C;VYN96-T97(N`%9O=')E(&YO
M;0!6;W1R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N(&YE('-U<'!O<G1E
M('!A<R!L)V%J;W5T(&0G=71I;&ES871E=7)S+"!3:2!V;W5S('-O=6AA:71E
M>B!U=&EL:7-E>B!(;W)D92!P;W5R(&%D;6EN:7-T<F5R(&QE<R!C;VUP=&5S
M('5T:6QI<V%T975R<RP@=F]U<R!D979E>B!U=&EL:7-E<B!U;B!A=71R92!M
M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N+@!6;W1R92!M;V1U;&4@9"=A=71H
M96YT:69I8V%T:6]N(&XG97-T('!A<R!E;B!M97-U<F4@9"?I=&%B;&ER('5N
M92!L:7-T92!D97,@=71I;&ES871E=7)S+"!O=2!C971T92!F;VYC=&EO;B!A
M(.ETZ2!R971I<NEE('!O=7(@=6YE(&%U=')E(')A:7-O;BX`5F]T<F4@;F%V
M:6=A=&5U<B!S96UB;&4@879O:7(@8VAA;F?I(&1E<'5I<R!L92!DZ6)U="!D
M92!V;W1R92!S97-S:6]N("5S+B`@4&]U<B!V;W1R92!SZ6-U<FETZ2P@=F]U
M<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+@!6;W1R92!N879I9V%T975R(&YE
M('-U<'!O<G1E('!A<R!C971T92!O<'1I;VX`5F]T<F4@;F%V:6=A=&5U<B!N
M92!P<F5N9"!P87,@96X@8V]M<'1E(&-E='1E(&]P=&EO;B!D)VEM<')E<W-I
M;VXN(%!R97-S97H@0V]N='+T;&4O0V]M;6%N9&4@*R!0('!O=7(@:6UP<FEM
M97(`5F]T<F4@9G5S96%U(&AO<F%I<F4@86-T=65LH#H`5F]T<F4@<')O9FEL
M('!A<B!DZ69A=70@82#I=.D@;6]D:69IZ2X`4')O9FEL('!A<B!DZ69A=72@
M.@!6;W1R92!N;VT@8V]M<&QE=*`Z`%9O=')E(&-O;7!T92!A(&5X<&ERZ2X`
M5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@<&]U<B`E<R!E<W2@.B5S`%9O
M<R!O<'1I;VYS(&]N="#I=.D@;6ES97,@X"!J;W5R('!O=7(@;&$@9'5RZ64@
M9&4@8V5T=&4@<V5S<VEO;BX`5F]S(&]P=&EO;G,@;VYT(.ETZ2!M:7-E<R#@
M(&IO=7(N`%9O=')E(&UO="!D92!P87-S92!A(.ETZ2!R96UI<R#@('KI<F\`
M5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E;6ES(.`@>NER;RP@=NER:69I
M97(@=F]T<F4@8V]U<G)I97(@970@8V]N;F5C=&5Z+79O=7,@879E>B!V;W1R
M92!N;W5V96%U(&UO="!D92!P87-S92X`5F]T<F4@;6]T(&1E('!A<W-E(&$@
M97AP:7+I+@!6;W,@<V5R=F5U<G,@9&ES=&%N='.@.@!9;W5G;W-L879I90!:
M8>]R90!:86UB:64`6FEM8F%B=V4`6FEP<'D`6T-A8VAE<B!L97,@8VET871I
M;VYS70!;4F%P<&]R="!D92!P<F]B;.AM95T`6T%F9FEC:&5R(&QE('1E>'1E
M(&-I=.D@+0!;069F:6-H97(@;&4@=&5X=&4@8VETZ2`M("5S(&QI9VYE<UT`
M6VQI9VYE("5S(&1E("5S70!?061M:6YI<W1R871I;VX`3&EG;F4@9&4@7V-O
M;6UA;F1E`%]$871A5')E90!3=7!P<FEM97(@;&$@7W)A;F?I90!?1W)O=7!E
M<P!?06ED90!0<F]P<E]IZ73I<R!D92!L)VEM86=E+BXN`%]#;VYN97AI;VX`
M7T3I8V]N;F5X:6]N`%]-;V1I9FEE<B!U;B!L:65N('=E8BXN+@!?3W!T:6]N
M<P!?4&5R;6ES<VEO;G,`7U)E=&ER97(@=6X@;&EE;@!?0V]N9FEG=7)A=&EO
M;@!0<F]P<FGI=.ES(&1U(%]T86)L96%U`%]5=&EL:7-A=&5U<G,`8V%R;F5T
M(&0G861R97-S97,`9&5S=&EN871A:7)E(&EN8V]N;G4`86=E;F1A`&-A;&UE
M`&EM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!D92!S;W)T:64`:6UP
M;W-S:6)L92!D)V]U=G)I<B!L)V5N='+I90!C;&EQ=65Z(&EC:0!E<G)E=7(@
M9"=U=&EL:7-A=&EO;B!D92!L82!L:6=N92!D92!C;VUM86YD90!E<G)E=7(@
M9&4@8V]N9FEG=7)A=&EO;@!A8G-E;F-E(&-R:71I<75E(&0G=6X@9FEC:&EE
M<B!S>7-TZ&UE`&5R<F5U<B!D92!F;W)M870@9&4@9&]N;NEE`&5N='+I92!N
M;VX@=')O=7;I`'1O;6)A;G0`9FEC:&EE<@!D97!U:7,@;&4@)7,@*"5S*2#@
M("5S("5S`&5N(')A9F%L90!HH#H`:&@`;F]M(&0G:/1T92!I;F-O;FYU`&EM
M;>ED:6%T96UE;G0`:6YC;W)P;W+I90!E<G)E=7(@9"=E;G1RZ64O<V]R=&EE
M`&5R<F5U<B!L;V=I8VEE;&QE(&EN=&5R;F4`;&EG;F5S70!E<G)E=7(@;6MI
M<V]F<R!C;V1E("5D(&5N(&-RZ6%N="!L)TE33P!M;0!N;VT`;F]N('!R:7,@
M96X@8V]M<'1E`'!A<R!E;F-O<F4@<')I<R!E;B!C;VUP=&4`8FQO8RUN;W1E
M<P!P;W5R8V5N=&%G90!P97)M:7-S:6]N(')E9G5SZ64`<&EX96QS`&5R<F5U
M<B!D:7-T86YT92!D86YS(&QE('!R;W1O8V]L90!S)^EL979A;G0`<V5R=FEC
M92!N;VX@9&ES<&]N:6)L92X`;6]N=')E<B!L97,@9&EF9NER96YC97,`<VUS
M,F5M86EL('9I82!(5%10`'-S`&9I>&4`97)R975R('-Y<W3H;64`;&ES=&4@
M9&4@=.)C:&5S`.EC:&5C('1E;7!O<F%I<F4`96YT<F5Z(&QE(&UO="!D92!P
M87-S92!D975X(&9O:7,@<&]U<B!C;VYF:7)M97(`=6YI9FGI`'-A;G,@;F]M
M`%/I;&5C=&EO;B!D)W5T:6QI<V%T975R`'9#87)D`&R@.@!W96%T:&5R+F-O
M;0`````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F<E]&4B]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P,C,`,3`T
M,3<S-C(W-S8`,#(P,S,T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES
M;RTX.#4Y+3$B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]F<E]&4B]H
M96QP+GAM;"QV(#$N,BXQ,"XQ(#(P,#4O,3(O,#4@,3`Z,S`Z-#4@:F%N($5X
M<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)U
M<'1O9&%T92(@;60U/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q
M-2(^"CQT:71L93Y,82!P86=E('!O<G1A:6P@/"]T:71L93X*(#QP87)A/@H@
M($-E='1E('!A9V4@<&]R=&%I;"!V;W5S(&9O=7)N:70@=6X@<NES=6WI(&1E
M('9O<R!I;F9O<FUA=&EO;G,@:6UP;W)T86YT97,N(%!A<B!E>&5M<&QE+"!C
M96QA('!O=7)R86ET('9O=7,@<&5R;65T=')E(&0G869F:6-H97(@;&4@;F]M
M8G)E(&1E(&YO=79E875X(&UE<W-A9V5S(&1A;G,@=F]T<F4@8F_N=&4@9&4@
M<NEC97!T:6]N+"!L97,@;F]U=F5A=7@@Z7;H;F5M96YT<R!D92!V;W1R92!C
M86QE;F1R:65R+"!L97,@=.)C:&5S(&1E('9O=')E(&QI<W1E(&1E('1R879A
M=7@@X"!F86ER92P@;&5S(&=R86YD<R!T:71R97,@9&4@;F]U=F5L;&5S+"!E
M=&,N($QA('!L=7!A<G0@9&5S('+I<W5MZ7,@8V]N=&EE;F1R;VYT(&1E<R!R
M86-C;W5R8VES('9E<G,@9&5S(&9O;F-T:6]N<R!C;&%S<VEQ=65S(&-O;6UE
M(&QA(&-O;7!O<VET:6]N(&0G=6X@;F]U=F5A=2!M97-S86=E+"!L82!C<NEA
M=&EO;B!D)W5N(&YO=79E;"#I=NAN96UE;G0@9&%N<R!L92!C86QE;F1R:65R
M(&]U(&0G=6YE(&YO=79E;&QE('3B8VAE+@H@/"]P87)A/@H@/'!A<F$^"B`@
M3&4@8V]N=&5N=2!D92!C971T92!P86=E('!O<G1A:6P@<&5U="#J=')E('!E
M<G-O;FYA;&ESZ2#@(&PG86ED92!D=2!B;W5T;VX@)U!RZ7-E;G1A=&EO;B<N
M(%!A<B!E>&5M<&QE+"!V;W5S('!O=79E>B!C:&]I<VER(&QE<R!P;VEN=',@
M<'+I<V5N=',@<W5R(&-E='1E('!A9V4@<&]R=&%I;"!E="!L)V]R9')E(&1A
M;G,@;&5Q=65L(&EL<R!S97)O;G0@<'+I<V5N=.ES+@H@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB=7!T;V1A=&4B(&UD
M-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B/@H\=&ET;&4^
M3&4@;65N=2!(;W)D93PO=&ET;&4^"B`\<&%R83X*("!3=7(@;&4@8_1TZ2!G
M875C:&4@9&4@;&$@<&%G92!S92!T<F]U=F4@;&4@;65N=2!(;W)D92X*("!#
M;&EQ=65Z('-U<B!L97,@:6/T;F5S(&1E(&-E(&UE;G4@2&]R9&4@<&]U<B!A
M8V/I9&5R(')A<&ED96UE;G0@970@<VEM<&QE;65N="!A=7@@87!P;&EC871I
M;VYS(&1I<W!O;FEB;&5S+B`*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD
M-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B/@H@("`@/'1I
M=&QE/E!RZ6;I<F5N8V5S.B!-86EN=&5N86YC93H@169F96-T=65R(&QE<R!O
M<.ER871I;VYS(&1E(&UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@
M("`@4VD@=F]U<R!V;W5L97H@969F96-T=65R(&QE<R!O<.ER871I;VYS(&1E
M(&UA:6YT96YA;F-E(.`@;&$@8V]N;F5X:6]N+"!C;V-H97H@8V5T=&4@8V%S
M92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O
M;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)A,C$Q
M-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^4'+I
M9NER96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M97(\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!3:2!V;W5S('9O=6QE>B!D979O:7(@8V]N9FER;65R(&%V
M86YT(&1E(&QA;F-E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92P@
M8V]C:&5Z(&-E='1E(&-A<V4N(%-I('9O=7,@;F4@;&$@8V]C:&5Z('!A<RP@
M=&]U=&5S(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E('-E<F]N="!A
M=71O;6%T:7%U96UE;G0@;&%N8^EE<R#@(&QA(&-O;FYE>&EO;B!S86YS(&%U
M8W5N92!C:&%N8V4@9"=A;FYU;&%T:6]N+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H\+VAE;'`^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]G;%]%
M4R\`````````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C(W-S<`,#$V-C8R`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V=L7T53+TQ#7TU%4U-!1T53+P``````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-P`P,C`T-#<`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9VQ?15,O3$-?34534T%'
M15,O:&]R9&4N;6\`````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T,#(U`#$P
M-#$W,S8R-S<W`#`R,C$P-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#>$@25`````&0````<````/`,``(D```!<!@``````
M`(`(```H````@0@```@```"J"```!0```+,(```(````N0@```<```#""```
M!0```,H(```?````T`@``!$```#P"```"`````()```(````"PD``!4````4
M"0``"@```"H)```,````-0D```<```!""0``*0```$H)```"````=`D```4`
M``!W"0``$````'T)```4````C@D``"\```"C"0``#P```-,)```F````XPD`
M``4````*"@``#0```!`*```%````'@H``!`````D"@``$````#4*```/````
M1@H```L```!6"@``#P```&(*```,````<@H```\```!_"@``'@```(\*```A
M````K@H```,```#0"@``!````-0*```,````V0H```H```#F"@``!0```/$*
M```2````]PH``!`````*"P``"````!L+```0````)`L```8````U"P``!P``
M`#P+```"````1`L```0```!'"P``#P```$P+```'````7`L```<```!D"P``
M!````&P+```%````<0L```4```!W"P``!P```'T+```1````A0L```@```"7
M"P``'@```*`+```%````OPL``"@```#%"P``*0```.X+```3````&`P```L`
M```L#```$0```#@,```$````2@P```P```!/#```&@```%P,```7````=PP`
M`!<```"/#```&P```*<,```?````PPP``!,```#C#```$````/<,```7````
M"`T```<````@#0``!0```"@-```A````+@T``!P```!0#0``!0```&T-```#
M````<PT``"````!W#0``)@```)@-```,````OPT```P```#,#0``"````-D-
M```'````X@T```8```#J#0``#0```/$-```+````_PT```P````+#@``"@``
M`!@.```"````(PX```8````F#@``10```"T.```P````<PX``!````"D#@``
M'P```+4.```0````U0X```\```#F#@``!0```/8.``!O`0``_`X``"H```!L
M$```"````)<0```%````H!````X```"F$```"````+40```&````OA```"0`
M``#%$```$P```.H0```+````_A````H````*$0``'P```!41```.````-1$`
M``\```!$$0``"````%01```R````71$```(```"0$0``"P```),1```9````
MGQ$``!8```"Y$0``+P```-`1```8`````!(``"L````9$@``$@```$42```.
M````6!(```0```!G$@``#P```&P2```0````?!(```X```"-$@``%0```)P2
M```/````LA(```L```#"$@``$P```,X2```C````XA(``",````&$P```P``
M`"H3```%````+A,``!,````T$P``$P```$@3```%````7!,``!,```!B$P``
M$@```'83```&````B1,``!@```"0$P``!@```*D3```/````L!,```(```#`
M$P``!@```,,3```6````RA,```<```#A$P``#````.D3```$````]A,```4`
M``#[$P``!0````$4```'````!Q0``!$````/%```#P```"$4```A````,10`
M``@```!3%```'@```%P4```O````>Q0``!8```"K%```"P```,(4```3````
MSA0```<```#B%```$0```.H4```A````_!0``!T````>%0``'0```#P5```E
M````6A4``!0```"`%0``'0```)45```3````LQ4``!\```#'%0``#0```.<5
M```'````]14``"(```#]%0``&P```"`6```&````/!8```,```!#%@``*@``
M`$<6```O````<A8``!,```"B%@``$@```+86```'````R18```4```#1%@``
M#````-<6```,````Y!8```T```#Q%@``%````/\6```4````%!<```(````I
M%P``"@```"P7```N````-Q<``#P```!F%P``$0```*,7```?````M1<``!4`
M``#5%P``#P```.L7```9````^Q<```$````D`````````$X````=````3P``
M`!<```!%````!P```"(`````````30```"$`````````2P```&(````*````
M$0`````````,````,@```%,````Q`````````"4```!&````70````````!2
M````0@```%4`````````1P```"P````O````5@```%$````U````$`````@`
M```^````00```%\````K````#P```#D```!*````(P```!@````S````0```
M`"@```!@````"P``````````````5```````````````/0````D`````````
M+@```$@```!<````.@`````````.`````````%D`````````-@`````````;
M````/P```!P````:````#0```#L`````````!`````4`````````$@``````
M```3`````````%<````M`````````"8``````````````!4````&````````
M`%L````W````&0````````!>`````````#@````T`````````$D````?````
M6@```$0`````````'@``````````````8P````````!8````*0`````````P
M```````````````\````9````%``````````%@```"```````````P```&$`
M``!#````*@```"<```!,`````@`````````4`````"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,C0@:&]U<G,`04TO4$T`061D
M('!A:7(`061D<F5S<P!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A
M;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E(%=I;F1O=P!#
M;VUP86YY`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5S8W)I8F4@=&AE(%!R
M;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`
M179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN
M=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E
M`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!(96QP
M`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD
M.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI<W0@2&5L<"!4;W!I
M8W,`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-871C:&EN9R!F:65L9',`365S
M<V%G90!-;VYT:&QY`$YA;64`3F5V97(`3F]T97,`3W!T:6]N<P!/=&AE<B!)
M;F9O<FUA=&EO;@!087-S=V]R9`!097)F;W)M($UA:6YT96YA;F-E($]P97)A
M=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER`%)E='5R;B!T
M;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@
M=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O
M<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M=6-C97-S`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%523`!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`57-E<B!/<'1I
M;VYS`%5S97)N86UE`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E<&]R
M=%T`6VQI;F4@)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&4@,BXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R
M9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R
M,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP."TQ.2`Q,SHS-4=-5"LQ"DQA
M<W0M5')A;G-L871O<CH@4V5R=FEC:6\@9&4@3F]R;6%L:7IA8VEO;B!,:6YG
M=6ES=&EC82`\<VYL=7-C0'5S8RYE<SX*3&%N9W5A9V4M5&5A;3H@1V%L96=O
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*6"U'96YE<F%T;W(Z($M"86)E;"`P+CDN-0H`3W!E<F%C:?-N<R!D
M92!M86YT96UE;G1O("5S("T@0V]N9FER;6%C:?-N`#(T(&AO<F%S`$%-+U!-
M`$5N9V%D:7(@=6X@<&%R`$5N9&5R97IO`$%L8W5M90!/('9A;&]R('%U92!E
M<W!E8VEF:6-O=2!N;VX@Z2!VX6QI9&\`0V%M<&]S(&1I<W!O\6EB;&5S.@!!
M;FEV97)S87)I;P!#86QE;F1A<FEO`$-A;F-E;&%R(&\@:6YF;W)M92!D92!P
M<F]B;&5M87,`5&5LZ69O;F\@;?-B:6P`4&5C:&%R(&$@>&%N96QA`$-O;7!A
M\>UA`$9A;&QO(/,@86)R:7(@;R!M\V1U;&\@9&4@=&%R969A<R!D92!M86YT
M96UE;G1O("5S`$1$`$1I87)I86UE;G1E`$ED96YT:61A9&4@<')E9&5T97)M
M:6YA9&$`1&5S8W)I8VGS;B!D;R!P<F]B;&5M80!297AI<W1RX7)O;G-E(&]S
M(&1E=&%L;&5S('!A<F$@;R!A9&UI;FES=')A9&]R+@!/<&-I\VYS(&1E('9I
M<W5A;&EZ86-I\VX`3F]N(&%C8V5D82!D:7)E8W1A;65N=&4@82`B;6%I;G1E
M;F%N8V4N<&AP(@!#;W)R96\@96QE8W1R\VYI8V\`4V5N(')E<W5L=&%D;RX`
M17)R;P!#861A(#$U(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@
M;6EN=71O<P!#861A(&EN:6-I;R!D92!S97-I\VX`0V%D82!M961I82!H;W)A
M`$-A9&$@;6EN=71O`$5X96UP;&\@9&4@=F%L;W)E<SH`1F%L;&]U(/,@<F5C
M=7!E<F%R(&%S('!R969E<F5N8VEA<RX`1F%L;&]U(/,@8V]N96-T87(@8V\@
M<V5R=FED;W(@3$1!4"X`1F%X`$%X=61A`$5N9&5R97IO('!A<G1I8W5L87(`
M5&5LZ69O;F\@<&%R=&EC=6QA<@!(;W)D90!#86UP;R!I;7!O<G1A9&\Z("5S
M`$-A;7!O<R!I;7!O<G1A9&]S.@!,:6YG=6$`3&ES=&%R(&]S('1E;6%S(&1E
M(&%X=61A`$5N=')A<@!096-H87(@82!S97-I\VX`34T`0V]R<F5O`$-A;7!O
M<R!C;W)R97-P;VYD96YT97,`365N<V%X90!-96YS=6%L;65N=&4`3F]M90!.
M=6YC80!.;W1A<P!/<&-I\VYS`$]U=')A(&EN9F]R;6%C:?-N`$-H879E(&1E
M(&%C8V5S;P!296%L:7IA<B!O<&5R86-I\VYS(&1E(&UA;G1E;65N=&\`5&5L
MZ69O;F\`06-H96=U92!U;B!R97-U;6\@9&\@<')O8FQE;6$N`$%C:&5G=64@
M;R!S974@;F]M92!D92!U<W5A<FEO(&4@8VAA=F4@9&4@86-C97-O`$1E<V-R
M:6-I\VX@9&\@<')O8FQE;6$`4V%C87(@;R!P87(`4F5G<F5S87(@X7,@;W!C
M:?-N<P!&=6YC:?-N`$=A<F1A<B!A<R!O<&-I\VYS`%-E;&5C8VEO;F4@;R!D
M96QI;6ET861O<B!D82!D871A.@!396QE8V-I;VYE(&\@9F]R;6%T;R!D82!D
M871A.@!396QE8V-I;VYE(&\@9F]R;6%T;R!D82!H;W)A.@!396QE8V-I;VYE
M(&1O=7,@8V%M<&]S('%U92!C;VEN8VED86XN`%-E;&5C8VEO;F4@82!L:6YG
M=6$Z`$5N=FEA<B!O(&EN9F]R;64@9&4@<')O8FQE;6%S`$]M:71I<B!O(&UA
M;G1E;65N=&\`16YT<F%D82!D92!C87)A8W1E<F5S(&5S<&5C:6%I<P!#;W)R
M96-T86UE;G1E`%1A<F5F87,`3R!N^FUE<F\@9&5B92!S97(@<&]L;R!M96YO
M<R!U;B`Q+@!/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R;RX`5.UT=6QO`%52
M3`!.;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"X`
M3F]N(&9O:2!P;W-I8FQE('1R861U8VER(&5S=&4@9&]C=6UE;G1O(&1E(%=O
M<F0`1&5S9F%C97(@;W,@8V%M8FEO<P!/<&-I\VYS(&1O('5S=6%R:6\`57-U
M87)I;P!!=FES;P!396UA;F%L;65N=&4`0F5N=FED82!A("5S`$)E;G9I9&\O
M82P@)7,`16YD97)E>F\@9&\@=')A8F%L;&\`5&5LZ69O;F\@9&\@=')A8F%L
M;&\`04$`06YU86QM96YT90!$97-C<FEB82!O('!R;V)L96UA(&%N=&5S(&1E
M(&5N=FEA<B!O(&EN9F]R;64N`$-A9'5C;W4@82!S^F$@<V5S:?-N(&5N("5S
M(&5X<&ER;W4N($EN:6-I92!U;FAA(&YO=F$@<V5S:?-N+@!!('/Z82!I;F9O
M<FUA8VGS;@!!8W1U86QI>N%R;VYS92!A<R!S^F%S(&]P8VGS;G,N`%M);F9O
M<FUE(&1O(%!R;V)L96UA70!;;&GQ82`E<R!D92`E<UT`5&%R>&5T82!D92!V
M:7-I=&$@*'9#87)D*0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VAE
M7TE,+P``````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-P`P,38V-3$`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O:&5?24PO3$-?34534T%'15,O````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`R,#0S
M-@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]H95])3"],0U]-15-3
M04=%4R]H;W)D92YM;P``````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<S,#(`
M,3`T,3<S-C(W-S<`,#(R,#<T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````J0```!P```!D!0``XP```*P*````
M````.`X```P````Y#@``"P```$8.```'````4@X```<```!:#@``"@```&(.
M```)````;0X```<```!W#@``"0```'\.```'````B0X```<```"1#@``!P``
M`)D.```*````H0X```<```"L#@``!@```+0.```'````NPX```@```###@``
M!@```,P.```1````TPX```<```#E#@``"````.T.```(````]@X```8```#_
M#@``!@````8/```*````#0\``!@````8#P``!````#$/```%````-@\```4`
M```\#P``!0```$(/```&````2`\```@```!/#P``!0```%@/```*````7@\`
M``0```!I#P``!@```&X/```.````=0\```<```"$#P``$@```(P/```'````
MGP\```4```"G#P``"P```*T/```(````N0\```0```#"#P``!P```,</```#
M````SP\```8```#3#P``!0```-H/```&````X`\```<```#G#P``!P```.\/
M```%````]P\```(```#]#P``!@`````0```'````!Q````D````/$```!@``
M`!D0```&````(!````4````G$```#0```"T0```$````.Q```!T```!`$```
M"````%X0```(````9Q````H```!P$```!P```'L0```'````@Q````4```"+
M$```"0```)$0```9````FQ````0```"U$```!P```+H0```&````PA````4`
M``#)$```!P```,\0```%````UQ````8```#=$```!0```.00```&````ZA``
M``<```#Q$```!P```/D0```6`````1$```H````8$0``"@```",1```&````
M+A$```@````U$0``"````#X1```$````1Q$```4```!,$0``"@```%(1```)
M````71$```8```!G$0``!@```&X1```(````=1$```<```!^$0``"@```(81
M```$````D1$```4```"6$0``"P```)P1```+````J!$```D```"T$0``!0``
M`+X1```'````Q!$```8```#,$0``!````-,1```'````V!$```4```#@$0``
M"````.81```&````[Q$```@```#V$0``"````/\1```)````"!(```H````2
M$@``!````!T2```+````(A(```8````N$@``"````#42```%````/A(```<`
M``!$$@``$@```$P2```&````7Q(```P```!F$@``!@```',2```'````>A(`
M``H```""$@``#````(T2```)````FA(```<```"D$@``#````*P2```%````
MN1(```D```"_$@``!0```,D2```(````SQ(```D```#8$@``!@```.(2```+
M````Z1(``!0```#U$@``'`````H3```(````)Q,```4````P$P``$P```#83
M```'````2A,```8```!2$P```P```%D3```$````71,```8```!B$P``!P``
M`&D3```4````<1,```X```"&$P``#0```)43```&````HQ,```<```"J$P``
M"````+(3```'````NQ,```D```##$P``!P```,T3```(````U1,```0```#>
M$P``!0```.,3```&````Z1,```4```#P$P``"@```/83```&`````10```@`
M```(%```!0```!$4```(````%Q0```@````@%```#````"D4```$````-A0`
M`$X!```[%```$P```(H5```0````GA4```P```"O%0``#````+P5```?````
MR14``!````#I%0``#````/H5```0````!Q8```X````8%@``$0```"<6```,
M````.18```P```!&%@``"@```%,6```(````7A8```X```!G%@``#@```'86
M```*````A18```P```"0%@``#@```)T6```.````K!8```H```"[%@``"```
M`,86```&````SQ8```\```#6%@``+@```.86```$````%1<```@````:%P``
M!@```",7```3````*A<``!<````^%P``$````%87```*````9Q<``!,```!R
M%P``"````(87```.````CQ<```@```">%P``"````*<7```I````L!<```X`
M``#:%P``"@```.D7```5````]!<```X````*&```"````!D8```,````(A@`
M``@````O&```"````#@8```(````01@```H```!*&```#````%48```,````
M8A@```8```!O&```!````'88```(````>Q@```H```"$&```#@```(\8```*
M````GA@```H```"I&```"@```+08```<````OQ@```@```#<&```"@```.48
M```.````\!@```@```#_&```"0````@9```.````$AD```P````A&0``"```
M`"X9```2````-QD```@```!*&0``"````%,9```,````7!D```P```!I&0``
M#````'89```,````@QD```8```"0&0``"````)<9```(````H!D```P```"I
M&0``"@```+89```,````P1D```8```#.&0``$@```-49```,````Z!D```H`
M``#U&0``#@`````:```?````#QH```8````O&@``"````#8:```2````/QH`
M`!(```!2&@``#````&4:```*````<AH``!````!]&@``"@```(X:```.````
MF1H```0```"H&@``!@```*T:```*````M!H``!,```"_&@``$````-,:```(
M````Y!H```P```#M&@``$````/H:```*````"QL``!`````6&P``!@```"<;
M```,````+AL```@````[&P``#@```$0;```*````4QL```L```!>&P``#```
M`&H;```&````=QL``!0```!^&P``"@```),;```.````GAL```8```"M&P``
M#````+0;```*````P1L```P```#,&P``%0```-D;```*````[QL```@```#Z
M&P``$P````,<```5````%QP```X````M'```#````#P<```7````21P```@`
M``!A'```#P```&H<```(````>AP```P```"#'```$````)`<```,````H1P`
M``H```"N'```"@```+D<```,````Q!P```P```#1'```(````-X<```;````
M_QP```X````;'0``#@```"H=```&````.1T```<```!`'0``#````$@=```0
M````51T``",```!F'0``&P```(H=```7````IAT```H```"^'0``$````,D=
M```<````VAT```P```#W'0``#@````0>```*````$QX```\````>'@``!@``
M`"X>```'````-1X```@````]'@``"````$8>```2````3QX```P```!B'@``
M$````&\>```(````@!X```X```")'@``$````)@>```3````J1X```0```"]
M'@```0```*````!`````````````````````I@```*,````I````$P``````
M``!B````&````!````!,``````````<````Z````,@```&,```"-````&@``
M``````!*````6@```%X```!'````:@````P```!?````)````!4````H````
M,````((```!U````0@```)(```!;````D0```)@````]````,0````H````&
M````&0```',````````````````````N````'@`````````C`````@``````
M````````````````````````.0```%<`````````'````&D`````````````
M`&0```!Q````*P```"8```!=````=P```$X```!)````-````($```!X````
M`````&<```!O````@P````0```"I````C@```!8````M````9@````T```":
M````(@```!T````2````2P```*4`````````B@`````````L````>0```)X`
M`````````````#\`````````E@```&$```!\````90```&@`````````A0``
M`#4```![````@````"<````?````&P````````!6````+P```(<```"7````
M`````'\```!^`````````%(```"D````;`````4````\````G0`````````#
M````````````````````.P```````````````````%``````````````````
M``"A````7`````````!%````1@```#,``````````````!<`````````H@``
M`$,`````````:P```!0````W````00`````````/````(````)D```"(````
M50```"4````1````A```````````````"0```&X``````````````'0```!Z
M```````````````^````4P```*@``````````````)P```!/````-@```(P`
M``"/````8````)4`````````6````(L`````````B0```$@```"?````=@``
M``````!-````E````$0````J`````````"$```!M````DP````L```"G````
M<````%$```!9````FP````@`````````?0```%0```"0````<@```#@`````
M````A@````X`````061D<F5S<R!";V]K`$%F9VAA;FES=&%N`$%L8F%N:6$`
M06QG97)I80!!;G1A<F-T:6-A`$%R9V5N=&EN80!!<FUE;FEA`$%U<W1R86QI
M80!!=7-T<FEA`$)A:&%M87,`0F%H<F%I;@!"86YG;&%D97-H`$)E;&=I=6T`
M0F5L:7IE`$)O;&EV:6$`0F]T<W=A;F$`0G)A>FEL`$)R=6YE:2!$87)U<W-A
M;&%M`$)U<G5N9&D`0V%M8F]D:6$`0V%M97)O;VX`0V%N861A`$-A;F-E;`!#
M87!E(%9E<F1E`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#:&%D`$-H:6QE
M`$-H:6YA`$-L96%R`$-L;W5D>0!#;VQO;6)I80!#;VYG;P!#;W-T82!2:6-A
M`$-U8F$`0WEP<G5S`$-Z96-H(%)E<'5B;&EC`$1E;FUA<FL`1&]M:6YI8V%N
M(%)E<'5B;&EC`$5C=6%D;W(`16=Y<'0`16P@4V%L=F%D;W(`171H:6]P:6$`
M1FEJ:0!&:6YL86YD`$9O9P!&<F%N8V4`1V%B;VX`1V%M8FEA`$=E;W)G:6$`
M1V5R;6%N>0!':&%N80!';P!'<F5E8V4`1W)E;F%D80!'=6%T96UA;&$`1W5I
M;F5A`$=U>6%N80!(86ET:0!(96%V>2!4+5-T;W)M`$AE;'``2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92D`2&]N9'5R87,`2'5M:61I='D`2'5M:61I
M='DZ(`!(=6YG87)Y`$EC96QA;F0`26YD:6$`26YD;VYE<VEA`$ER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES<F%E;`!)=&%L>0!*
M86UA:6-A`$IA<&%N`$IO<F1A;@!+96YY80!+=7=A:70`3&5B86YO;@!,:6)E
M<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3'5X96UB;W5R9P!-861A9V%S
M8V%R`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA=7)I
M=&%N:6$`36%U<FET:75S`$UE>&EC;P!-;VYA8V\`36]N9V]L:6$`36]R;V-C
M;P!-;WIA;6)I<75E`$YA;64`3F5P86P`3F5T:&5R;&%N9',`3F5W(%IE86QA
M;F0`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3F]R=V%Y`$]M86X`3W!T:6]N
M<P!/=&AE<@!086MI<W1A;@!086YA;6$`4&%R86=U87D`4&%S<W=O<F0`4&%S
M<W=O<F0Z`%!A<W-W;W)D.B``4&5R=0!0:&EL:7!P:6YE<P!0;VQA;F0`4&]R
M='5G86P`46%T87(`4F]M86YI80!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A
M`%-A=61I($%R86)I80!396%R8V@`4V5N96=A;`!397EC:&5L;&5S`%-I97)R
M82!,96]N90!3:6YG87!O<F4`4V]M86QI80!3;W5T:"!!9G)I8V$`4W!A:6X`
M4W)I($QA;FMA`%-U9&%N`%-U<FEN86UE`%-W87II;&%N9`!3=V5D96X`4W=I
M='IE<FQA;F0`4WER:6%N($%R86(@4F5P=6)L:6,`5&%N>F%N:6$L(%5N:71E
M9"!297!U8FQI8R!O9@!4:&%I;&%N9`!4;VYG80!4<FEN:61A9"!A;F0@5&]B
M86=O`%1U;FES:6$`5'5R:V5Y`%523`!54DPZ`%5G86YD80!5:W)A:6YE`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`57!L;V%D`%5R=6=U87D`57-E<FYA;64`5F%N=6%T=0!696YE>G5E;&$`
M5F5R<VEO;@!6:65T($YA;0!7:6YD`%=I;F0Z`%=I;F0Z(`!996UE;@!9=6=O
M<VQA=FEA`%IA;6)I80!::6UB86)W90!?2&5L<`!?3&]G(&]U=`!?3W!T:6]N
M<P!A9&1R97-S(&)O;VL`;F%M90!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E
M(#,N,BUC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,#<@,#0Z,#@M,#4P
M,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3`W(#`T.C`X+3`U,#`*3&%S
M="U4<F%N<VQA=&]R.B!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D
M=3X*3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U6
M97)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/5541BTX"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`->AUZ37
MJ"#7F]>JUY77D=>5UZH`UY#7I->2UZ#7F=>AUZK7GP#7D-><UY'7H->9UY0`
MUY#7G->2UZC7F=>4`->9UY'7J=>JXH"3UY#7H->8UY#7J->GUYC7F=>GUY0`
MUY#7J->2UZ#7F->9UZ#7E`#7D->HUY[7H->9UY0`UY#7E=>AUYC7J-><UYG7
ME`#7D->5UZ'7F->HUYG7E`#7D->9UYGB@)/7D=>4UY[7E`#7D=>7UZC7F=>9
MUY\`UY'7H->2UYS7D]>I`->1UYS7DM>9UY0`UY'7G->9UY8`UY'7E=><UYG7
MD=>9UY0`UY'7E=>FUY77E=>@UY0`UY'7J->6UYG7G`#7D=>HUY77H->9UYD`
MUY'7E=>HUY77H->3UYD`UZ?7GM>1UY77D]>9UY0`UZ?7GM>HUY77GP#7I]>@
MUY/7E`#7J=>@UY0`UZ?7I->4(->5UZC7D]>4`->4UZ?7E->9UYS7F=>9UY0@
MUY37GM>HUYO7EN*`D]>0UZ37J->9UZ?7H->9UZH`UZ;7DP#7IM>9UYS7F0#7
MH=>9UY\`UZG7GM>9UYT@UY'7E->9UZC7G0#7J=>>UYG7G2#7GM>BUY77H->@
MUYG7G0#7I]>5UYS7E=>>UY'7F=>4`->GUY77H->2UY4`UZ?7E=>AUYC7E"#7
MJ->9UZ?7E`#7I]>5UY'7E`#7I]>DUZC7F=>AUYG7GP#7IM>;UYG7E`#7D]>@
MUYG7E`#7E->HUZ37E=>1UYS7F=>GUY0@UY37D]>5UY[7F=>@UYG7I]>@UYG7
MJ@#7D->GUY77E=>3UY77J`#7GM>FUZC7F=>=`->0UYSB@)/7H=><UY77E=>3
MUY77J`#7D->JUYG7E=>DUYG7E`#7I->9UY+7F0#7I->9UZ#7G->@UY,`UZ+7
MJ->DUYP`UZ;7J->DUZH`UY+7D=>5UY\`UY+7GM>1UYG7E`#7DM>5UZC7DM>9
MUY0`UY+7J->>UZ#7F=>4`->2UZ#7E`#7G->:`->9UY77E=>?`->2UZC7H->3
MUY0`UY+7E=>0UYC7GM><UY0`UY+7F=>@UY#7E`#7DM>9UY#7H->4`->4UY#7
MF=>8UYD`UZ'7E=>DUZKB@)/7J->BUY[7F=>=(->BUY;7E`#7HM>6UZC7E`#7
ME=>8UYG7I]>?`->4UY77H->3UY77J->A`-><UY?7E=>J`#K7G->7UYG7J@#7
ME->5UZ#7DM>HUYG7E`#7D->9UZ'7G->@UY,`UY37E=>3UY4`UY#7F=>@UY/7
ME=>@UY;7F=>4`->0UYG7J->?`->BUYG7J->G`->0UYG7J-><UZ#7DP#7F=>I
MUX'7J->0UYP`UY#7F=>8UYS7F=>4`->2UY[7F=>9UZ?7E`#7F=>DUY\`UYG7
MJ->3UY\`UZ?7H->9UY0`UYO7E=>5UYG7F=>J`-><UY'7H->5UY\`UYS7F=>1
MUZC7F=>4`-><UY77D0#7G->5UYO7H=>>UY'7E=>HUY(`UY[7D]>2UZ'7I]>H
M`->>UYS7E=>5UYD`UY[7G->9UYG7EM>9UY0`UY37D->9UYG7G2#7E->>UYS7
MD]>9UY77E=>9UYG7G0#7GM><UYD`UY[7G->8UY0`UY[7D->5UZC7F=>8UZ#7
MF=>4`->>UY#7E=>HUYG7IM>9UY77H0#7GM>;UZ'7F=>GUY4`UY[7E=>@UZ?7
ME0#7GM>5UZ#7DM>5UYS7F=>4`->>UZC7E=>GUY4`UY[7E=>6UY[7D=>9UZ<`
MUZG7G0#7H->DUYP`UY37E=><UZ#7DP#7H->9UY7B@)/7EM>9UYS7H->3`->@
MUYG7I]>HUY+7E=>0UY0`UZ#7F=>6UZ@`UZ#7F=>2UZC7F=>4`->@UY77J->5
MUY77DM>9UY0`UZ+7E=>>UY#7GP#7D->DUZG7J->5UYG7E=>J`->0UY?7J`#7
MI->GUYG7H=>JUY\`UZ37H->>UY0`UZ37J->2UY77D->9UYD`UZ'7F=>AUY[7
MD`#7H=>9UZ'7GM>0.@#7H=>9UZ'7GM>0.B``UZ37J->5`->DUYG7G->9UZ37
MF=>@UYG7F=>=`->DUY77G->9UY\`UZ37E=>HUYC7E=>2UYP`UZ?7F->H`->H
MUY77GM>@UYG7E`#7J->5UZ'7F=>4`->HUY77D->@UY/7E`#7HM>HUY$@UY37
MH=>BUY77D]>9UZH`UY?7F=>DUY77J0#7H=>@UY+7G`#7D->9UYGB@)/7H=>9
MUYG7J=><`->GUYG7F=>HUY0@UYS7F=>0UY77GP#7H=>9UZ#7DM>DUY77J`#7
MH=>5UY[7G->9UY0`UY/7J->5UYWB@)/7D->DUZC7F=>GUY0`UZ'7I->HUY,`
MUZ'7J->9(-><UZ#7I]>4`->AUY77D]>?`->AUY77J->9UZ#7G0#7H=>5UY77
MEM>9UYS7H->3`->IUY77E=>3UYG7E`#7J=>5UY77F=>E`->AUY77J->9UY0`
MUYC7H->6UZ#7F=>4`->JUY#7F=><UZ#7DP#7I]>1UY77IM>JXH"3UY#7F=>9
MXH"3UYC7E=>@UY+7E`#7F->HUYG7H->9UY/7DR#7E=>8UY77D=>2UY4`UYC7
ME=>@UYG7H=>9UY0`UYC7E=>HUZ?7F=>9UY0`UY#7JM>H`->0UZK7J#H`UY#7
ME=>2UZ#7D]>4`->0UY77I]>HUYG7F=>@UY0`UY37D->>UYG7J->5UYG7E=>J
M(->4UY[7D->5UY?7D]>5UZH`UY37GM>>UYS7F]>4(->4UY[7D->5UY?7D]>J
M`->0UZC7IM>5UZKB@)/7E->1UZC7F=>J`->4UZ+7G->0UY0`UY#7E=>HUY77
MDM>5UY77F0#7I]>5UY,@UY;7F=>4UY77F2#7GM>IUZK7GM>I`->5UZ#7E=>0
MUYC7E0#7E=>@UY;7E=>0UYS7E`#7DM>9UZC7H=>4`->5UYG7F=>8XH"3UZ#7
MG0#7J->5UY<`UZC7E=>7.@#7J->5UY<Z(`#7JM>9UY[7GP#7F=>5UY+7E=>A
MUYS7D=>9UY0`UY;7GM>1UYG7F=>4`->6UYG7GM>1UY'7E=>5UY0`UZ+7EM>H
MUY0`UY37JM>@UZK7I]>5UZH`UY#7I->IUZC7E=>9UY77J@#7H=>DUZ@@UYO7
MJM>5UY'7E=>J`->IUYT`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O:'5?2%4O````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`Q-C<P,0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]H=5](52],0U]-15-304=%4R\`````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-S<`,#(P-#8V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VAU7TA5
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#0R,S$P-0`Q,#0Q-S,V,C<W-P`P,C(Q,C8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0````!S!P``'````+0[``#O
M"0``3'<````````(GP``#@````F?```/````&)\```T````HGP``"````#:?
M```+````/Y\```P```!+GP``!````%B?```8````79\``!L```!VGP``+0``
M`)*?```=````P)\``"0```#>GP``*0````.@```9````+:```"8```!'H```
M#````&Z@```D````>Z````\```"@H```"P```+"@```.````O*```"@```#+
MH```"````/2@```*````_:```!4````(H0``$@```!ZA```+````,:$``(4`
M```]H0``#@```,.A```*````TJ$```T```#=H0``#@```.NA```1````^J$`
M``T````,H@``#````!JB```-````)Z(``)0````UH@``"@```,JB```/````
MU:(``!@```#EH@``#````/ZB```.````"Z,```X````:HP``"````"FC```)
M````,J,``"X````\HP``&@```&NC```R````AJ,``#@```"YHP``5````/*C
M``!1````1Z0``%H```"9I```5P```/2D```T````3*4```D```"!I0``#0``
M`(NE```'````F:4```H```"AI0``#P```*RE```%````O*4```8```#"I0``
M$0```,FE```(````VZ4```D```#DI0``"0```.ZE```E````^*4``"`````>
MI@``$P```#^F```0````4Z8```\```!DI@``"@```'2F```#````?Z8```\`
M``"#I@``%````).F```)````J*8```T```"RI@``$@```,"F```9````TZ8`
M`!X```#MI@``#P````RG```*````'*<```\````GIP``"````#>G```D````
M0*<``!0```!EIP``%@```'JG```(````D:<``$X```":IP``+0```.FG```9
M````%Z@```<````QJ```#````#FH```L````1J@```X```!SJ````P```(*H
M```+````AJ@```<```"2J```!P```)JH```%````HJ@```4```"HJ```"@``
M`*ZH```#````N:@``!<```"]J```"@```-6H```/````X*@```X```#PJ```
M&````/^H```C````&*D```X````\J0``%````$NI```7````8*D``!<```!X
MJ0``%P```)"I```3````J*D```\```"\J0``#@```,RI```?````VZD``!T`
M``#[J0``!P```!FJ```&````(:H```@````HJ@``#P```#&J```&````0:H`
M``H```!(J@``$P```%.J```+````9ZH``!````!SJ@``%0```(2J```5````
MFJH```<```"PJ@``$````+BJ```%````R:H``!4```#/J@``$0```.6J```,
M````]ZH``#L````$JP``.````$"K```)````>:L```<```"#JP``%````(NK
M```#````H*L```4```"DJP``$````*JK```)````NZL``!,```#%JP``.0``
M`-FK```2````$ZP``"<````FK```+````$ZL```J````>ZP``"4```"FK```
M"@```,RL```&````UZP```D```#>K```!P```.BL```O````\*P``#<````@
MK0``+@```%BM``!5````AZT``"T```#=K0``+0````NN```]````.:X``#\`
M``!WK@``+0```+>N``!`````Y:X``",````FKP``(P```$JO``!`````;J\`
M`"T```"OKP``,P```-VO```E````$;```!4````WL```&0```$VP```I````
M9[```"0```"1L```*````+:P```1````W[````H```#QL```#````/RP```*
M````";$``!`````4L0``%@```"6Q```6````/+$```<```!3L0``!P```%NQ
M```4````8[$```H```!XL0``"````(.Q```G````C+$```@```"TL0``!P``
M`+VQ```'````Q;$```8```#-L0``!0```-2Q```'````VK$```8```#BL0``
M"````.FQ```I````\K$```X````<L@``"@```"NR```$````-K(```<````[
ML@``"0```$.R```&````3;(``!$```!4L@``!P```&:R```6````;K(```0`
M``"%L@``"````(JR```&````D[(```T```":L@``!@```*BR```>````K[(`
M`!$```#.L@``"````."R```-````Z;(```P```#WL@``!P````2S```#````
M#+,```,````0LP``%P```!2S```3````++,``!T```!`LP``"````%ZS```$
M````9[,```@```!LLP``"````'6S``!!````?K,``!H```#`LP``*P```-NS
M```@````![0``!4````HM```!@```#ZT```&````1;0``!4```!,M```&```
M`&*T```B````>[0``"X```">M```'0```,VT```A````Z[0``%0````-M0``
M*0```&*U```*````C+4```<```"7M0``!P```)^U```5````I[4```X```"]
MM0``"@```,RU```/````U[4```T```#GM0``#P```/6U```-````!;8```D`
M```3M@``%````!VV```&````,K8``!@````YM@``'0```%*V```3````<+8`
M`!$```"$M@``%````):V```$````J[8```8```"PM@``%````+>V``!4````
MS+8``&0````AMP``!````(:W```.````B[<```4```":MP``!0```*"W```;
M````IK<``!H```#"MP``$P```-VW```1````\;<``!$````#N```'````!6X
M```J````,K@``!````!=N```(0```&ZX```%````D+@``!,```"6N```"P``
M`*JX```2````MK@```H```#)N```#P```-2X```-````Y+@``!$```#RN```
M$P````2Y```,````&+D```8````EN0``#````"RY```&````.;D``!<```!`
MN0``$````%BY```1````:;D```@```![N0``!0```(2Y```,````BKD``!``
M``"7N0``!0```*BY```-````KKD```8```"\N0``!P```,.Y```-````R[D`
M``<```#9N0``"P```.&Y```'````[;D```<```#UN0``"0```/VY```)````
M![H```H````1N@``&0```!RZ```]````-KH``!T```!TN@``#````)*Z```0
M````G[H```4```"PN@``)0```+:Z```2````W+H``!,```#ON@``*P````.[
M```[````+[L``"````!KNP``"````(R[```V````E;L``"$```#,NP``$```
M`.Z[```(````_[L```P````(O```!@```!6\```$````'+P```\````AO```
M#@```#&\```'````0+P```H```!(O```#0```%.\```?````8;P``!P```"!
MO```(0```)Z\```>````P+P``!D```#?O```'@```/F\```;````&+T``"$`
M```TO0``+@```%:]```F````A;T``!P```"LO0``'@```,F]```<````Z+T`
M`"8````%O@``*P```"R^```S````6+X``"8```",O@``*P```+.^```X````
MW[X``!T````8OP``%0```#:_```O````3+\``"````!\OP``$@```)V_```I
M````L+\``!X```#:OP``(````/F_```2````&L```*(````MP```%@```-#`
M```C````Y\```"@````+P0``*0```#3!```H````7L$``!\```"'P0``%0``
M`*?!```@````O<$``"4```#>P0``*`````3"```M````+<(``#````!;P@``
MD@```(S"```A````'\,``!8```!!PP``'````%C#```F````=<,``"H```"<
MPP``00```,?#``!$````"<0```P```!.Q```!P```%O$```'````8\0```8`
M``!KQ```#0```'+$```0````@,0``!(```"1Q```$P```*3$```2````N,0`
M``<```#+Q```!````-/$```0````V,0``!````#IQ```#````/K$```.````
M!\4```T````6Q0``#P```"3%```3````-,4```T```!(Q0``*````%;%```#
M````?\4```T```"#Q0``!@```)'%```1````F,4``!<```"JQ0``&P```,+%
M```.````WL4```(```#MQ0``20```/#%```%````.L8``!````!`Q@``#P``
M`%'&```$````8<8```T```!FQ@``#@```'3&```#````@\8```X```"'Q@``
M"````);&```/````G\8```\```"OQ@``!P```+_&```-````Q\8``!````#5
MQ@``#0```.;&```+````],8```8`````QP``"P````?'```,````$\<```H`
M```@QP``$0```"O'```9````/<<```L```!7QP``#0```&/'```B````<<<`
M``\```"4QP``&P```*3'```T````P,<```H```#UQP``&`````#(```2````
M&<@``!D````LR```%@```$;(```B````7<@```T```"`R```!P```([(```4
M````EL@```L```"KR```(@```+?(```O````VL@```L````*R0``"0```!;)
M```9````(,D```L````ZR0``%P```$;)```7````7LD```D```!VR0``%@``
M`(#)```/````E\D``!D```"GR0``%@```,')```.````V,D``!@```#GR0``
M"`````#*```-````"<H``"8````7R@``0P```#[*```(````@LH``!(```"+
MR@``'P```)[*```(````OLH```L```#'R@``+P```-/*```.`````\L```4`
M```2RP``!@```!C+``!%````'\L```,```!ERP``!P```&G+```$````<<L`
M``H```!VRP``"@```('+```/````C,L``!````"<RP``%P```*W+```1````
MQ<L``!D```#7RP``%P```/'+```)````"<P```4````3S```"P```!G,```*
M````)<P```(````PS```!0```#/,```-````.<P``!L```!'S```%P```&/,
M```4````>\P```D```"0S```#@```)K,```-````J<P``!(```"WS```.```
M`,K,```@`````\T```@````DS0``#@```"W-``![````/,T``!@```"XS0``
M&````-'-```1````ZLT```<```#\S0``!0````3.```8````"LX``!X````C
MS@``&P```$+.```9````7LX``!L```!XS@``&0```)3.```3````KLX```<`
M``#"S@``"````,K.```&````T\X```8```#:S@``$````.'.```/````\LX`
M`!`````"SP``#P```!//```+````(\\```\````OSP``#````#_/```/````
M3,\```<```!<SP``!@```&3/```.````:\\```P```!ZSP``*````(?/```/
M````L,\```@```#`SP``"````,G/```3````TL\``!X```#FSP``(0````70
M```@````)]```!D```!(T```%P```&+0```E````>M```!<```"@T```%@``
M`+C0```$````S]```!L```#4T```#0```/#0```,````_M````,````+T0``
M!0````_1```(````%=$```H````>T0``#````"G1```+````-M$``!````!"
MT0``#````%/1```.````8-$```0```!OT0``!````'31```3````>=$``!0`
M``"-T0``#````*+1```)````K]$```X```"YT0``"P```,C1```;````U-$`
M``<```#PT0``!P```/C1```*`````-(```T````+T@``"0```!G2```$````
M(](```,````HT@``&````"S2```*````1=(```0```!0T@``)@```%72```.
M````?-(``'P```"+T@``%0````C3```%````'M,```<````DTP``#````"S3
M```(````.=,```H```!"TP``!@```$W3```(````5-,```(```!=TP``!@``
M`&#3```&````9],``!0```!NTP``#0```(/3```0````D=,``!L```"BTP``
M!````+[3```)````P],``!````#-TP``"0```-[3```)````Z-,```4```#R
MTP``&@```/C3```(````$]0```8````<U```&0```"/4```.````/=0```<`
M``!,U```!P```%34```%````7-0```D```!BU```"@```&S4```.````=]0`
M``(```"&U```!@```(G4```+````D-0```T```"<U```"0```*K4```&````
MM-0``!(```"[U```"0```,[4```'````V-0``!0```#@U```'0```/74``!"
M````$]4``"4```!6U0``)0```'S5```&````HM4```H```"IU0``!````+35
M```)````N=4```@```##U0``$0```,S5```)````WM4```8```#HU0``#0``
M`._5```&````_=4``#D````$U@``/0```#[6```Z````?-8``!X```"WU@``
M!0```-;6```.````W-8```0```#KU@``!@```/#6```'````]]8``"$```#_
MU@``#0```"'7```5````+]<```8```!%UP``!````$S7```1````4=<```8`
M``!CUP``"@```&K7```B````==<```0```"8UP``!0```)W7```=````H]<`
M``0```#!UP``#````,;7```.````T]<```H```#BUP``"````.W7```)````
M]M<```4`````V```.@````;8```P````0=@``#4```!RV```*0```*C8``!'
M````TM@``#@````:V0``*0```%/9```_````?=D``"X```"]V0``+0```.S9
M```?````&MH```\````ZV@``$@```$K:```+````7=H``"8```!IV@``*0``
M`)#:```D````NMH``"8```#?V@``"`````;;```*````#]L```D````:VP``
M!P```"3;```@````+-L``"````!-VP``)@```&[;```*````E=L``!D```"@
MVP``*0```+K;```6````Y-L``!(```#[VP``!P````[<```*````%MP```P`
M```AW```#P```"[<```0````/MP``$````!/W```<````)#<``!F`````=T`
M``X```!HW0``"0```'?=```*````@=T``!(```",W0``$P```)_=```,````
ML]T```8```#`W0``#P```,?=```2````U]T``!````#JW0``$0```/O=```<
M````#=X``",````JW@``:@```$[>```/````N=X```4```#)W@``$````,_>
M```)````X-X```0```#JW@``"P```._>```@````^]X``!0````<WP``#```
M`#'?```,````/M\```\```!+WP``%0```%O?```I````<=\``"H```";WP``
M)@```,;?```G````[=\``"D````5X```*@```#_@```9````:N```$(```"$
MX```$0```,?@```2````V>```!,```#LX```%`````#A```/````%>$``!8`
M```EX0``%P```#SA```0````5.$``!$```!EX0``-````'?A```3````K.$`
M`!(```#`X0``-0```-/A```4````">(```<````>X@``#````";B```@````
M,^(``!````!4X@``%````&7B```1````>N(``!<```",X@``'````*3B```3
M````P>(``!0```#5X@``&@```.KB```1````!>,``!H````7XP``'@```#+C
M```:````4>,``!,```!LXP``%0```(#C```1````EN,``!<```"HXP``%```
M`,#C```7````U>,``!4```#MXP``"0````/D```0````#>0``!D````>Y```
M!````#CD```'````/>0```L```!%Y```$0```%'D```&````8^0```8```!J
MY```!@```''D```%````>.0```<```!^Y```!P```(;D```%````CN0``!8`
M``"4Y```!@```*OD```&````LN0```0```"YY```!````+[D```'````P^0`
M``X```#+Y```#````-KD```,````Y^0```T```#TY```"@````+E```.````
M#>4```4````<Y0``*````"+E```.````2^4```P```!:Y0``#P```&?E```*
M````=^4```@```""Y0``"0```(OE```K````E>4```0```#!Y0``"````,;E
M```F````S^4``!(```#VY0``#P````GF```&````&>8```H````@Y@``!P``
M`"OF```(````,^8``"`````\Y@``"0```%WF```4````9^8```P```!\Y@``
M#0```(GF```.````E^8``!8```"FY@``$0```+WF```&````S^8```,```#6
MY@``!@```-KF```9````X>8```<```#[Y@``!`````/G```+````".<```L`
M```4YP``!P```"#G```%````*.<```<````NYP``%@```#;G```-````3><`
M``T```!;YP``"@```&GG```0````=.<```\```"%YP``$0```)7G```7````
MI^<```H```"_YP``$0```,KG```$````W.<```\```#AYP``.@```/'G```%
M````+.@```P````RZ```'@```#_H```.````7N@``!````!MZ```"P```'[H
M```,````BN@```D```"7Z```!P```*'H```*````J>@```D```"TZ```#@``
M`+[H```0````S>@``!L```#>Z```&````/KH```:````$^D```H````NZ0``
M"0```#GI```*````0^D```P```!.Z0``#P```%OI```(````:^D```8```!T
MZ0``'````'OI```'````F.D```4```"@Z0``"P```*;I``!'````LND```T`
M``#ZZ0``"0````CJ```$````$NH```,````7Z@``$P```!OJ```3````+^H`
M`!,```!#Z@``"@```%?J```"````8NH```0```!EZ@``)0```&KJ```#````
MD.H```4```"4Z@``*@```)KJ```*````Q>H```4```#0Z@``!````-;J```*
M````V^H```T```#FZ@``!@```/3J```(````^^H```@````$ZP``!`````WK
M```%````$NL``&@````8ZP``"0```('K```,````B^L``!````"8ZP``!0``
M`*GK```&````K^L``!L```"VZP``+P```-+K```0`````NP```H````3[```
M#P```![L```*````+NP```D````Y[```$P```$/L```;````5^P``!@```!S
M[```%P```(SL```?````I.P```X```#$[````P```-/L```'````U^P```@`
M``#?[```!P```.CL```*````\.P```L```#[[```!P````?M``!1````#^T`
M`!````!A[0``#````'+M```-````?^T``!H```"-[0``2@```*CM```9````
M\^T```8````-[@``&@```!3N```E````+^X```8```!5[@``!@```%SN```?
M````8^X```8```"#[@``"0```(KN```8````E.X``!<```"M[@``*````,7N
M```&````[NX```T```#U[@``(@````/O``!7````)N\``!,```!^[P``(P``
M`)+O```3````MN\```(```#*[P``"P```,WO```(````V>\```T```#B[P``
M"@```/#O```'````^^\``!0````#\```!@```!CP```(````'_````X````H
M\```!P```#?P```*````/_````L```!*\```,@```%;P```'````B?````P`
M``"1\```#0```)[P```,````K/````D```"Y\```"0```,/P```*````S?``
M``<```#8\```"0```.#P```'````ZO````H```#R\```&P```/WP```/````
M&?$``!(````I\0``"@```#SQ```6````1_$```D```!>\0``$````&CQ```'
M````>?$``!(```"!\0``!````)3Q```'````F?$```4```"A\0``!0```*?Q
M```+````K?$``!0```"Y\0``$0```,[Q```:````X/$``!8```#[\0``%```
M`!+R```7````)_(``!@````_\@``'````%CR```9````=?(```<```"/\@``
M!0```)?R```-````G?(```P```"K\@``$0```+CR```(````RO(``!<```#3
M\@``"P```.OR```,````]_(``!\````$\P``&@```"3S```3````/_,```0`
M``!3\P``"@```%CS```$````8_,```T```!H\P``#````';S```%````@_,`
M``D```")\P``!0```)/S```'````F?,```4```"A\P``!````*?S```"````
MK/,``#@```"O\P``+````.CS```2````%?0``"D````H]```,@```%+T```*
M````A?0``"P```"0]```+@```+WT```S````[/0``#,````@]0``.````%3U
M```/````C?4``!@```"=]0``$````+;U```/````Q_4``!,```#7]0``%0``
M`.OU```4`````?8``!(````6]@``%````"GV```5````/O8``"T```!4]@``
M+0```(+V```Q````L/8``"X```#B]@``+P```!'W```L````0?<``&(```!N
M]P``$P```-'W```-````Y?<```@```#S]P``%P```/SW```(````%/@```P`
M```=^```*P```"KX```A````5O@``!H```!X^```"0```)/X``!%````G?@`
M`$$```#C^```!````"7Y```3````*OD``!0````^^0``#@```%/Y```3````
M8OD``!@```!V^0``!@```(_Y```)````EOD```H```"@^0``#P```*OY```0
M````N_D```<```#,^0``#@```-3Y```%````X_D``!L```#I^0``"`````7Z
M```&````#OH``!0````5^@``$0```"KZ```.````//H``#@```!+^@```@``
M`(3Z```&````A_H```X```".^@``!0```)WZ```'````H_H```X```"K^@``
M!@```+KZ```H````P?H```P```#J^@``'````/?Z```$````%/L``"D````9
M^P``%P```$/[```?````6_L``%P```![^P``%````-C[```^````[?L``!\`
M```L_```$````$S\```'````7?P```X```!E_```#````'3\```,````@?P`
M`!,```"._```"@```*+\```=````K?P``!D```#+_```!0```.7\```1````
MZ_P``!$```#]_```)`````_]```2````-/T``!4```!'_0``$@```%W]```.
M````</T``!D```!__0``"````)G]```-````HOT```<```"P_0``"@```+C]
M```'````P_T```\```#+_0``!@```-O]```+````XOT``!H```#N_0``!P``
M``G^```(````$?X```4````:_@``'P```"#^```&````0/X``!````!'_@``
M"````%C^```-````8?X```@```!O_@``'@```'C^```2````E_X``"P```"J
M_@``&@```-?^```)````\OX```H```#\_@``%0````?_```%````'?\``!0`
M```C_P``!````#C_```0````/?\```8```!._P``!P```%7_```>````7?\`
M`"@```!\_P``"@```*7_```<````L/\``!$```#-_P``"P```-__```:````
MZ_\``!0````&``$`!````!L``0`$````(``!``L````E``$`!0```#$``0`&
M````-P`!``@````^``$`!@```$<``0`*````3@`!`!L```!9``$`-````'4`
M`0`T````J@`!`"````#?``$`*0`````!`0`@````*@$!`$$```!+`0$`&@``
M`(T!`0`H````J`$!`"D```#1`0$`4````/L!`0`B````3`(!``8```!O`@$`
M"````'8"`0`%````?P(!``@```"%`@$`&0```(X"`0`9````J`(!`"H```#"
M`@$`(P```.T"`0`9````$0,!`"X````K`P$`-````%H#`0`(````CP,!`!<`
M``"8`P$`"@```+`#`0`'````NP,!`"$```##`P$`$````.4#`0`.````]@,!
M``L````%!`$`!P```!$$`0`3````&00!``@````M!`$`"P```#8$`0`*````
M0@0!`!0```!-!`$`#P```&($`0`R````<@0!``L```"E!`$`#@```+$$`0`%
M````P`0!``4```#&!`$`!0```,P$`0`7````T@0!``\```#J!`$`!````/H$
M`0`*````_P0!``D````*!0$`"P```!0%`0`-````(`4!``P````N!0$`#@``
M`#L%`0`%````2@4!``0```!0!0$`#0```%4%`0`R````8P4!`$4```"6!0$`
M%P```-P%`0`'````]`4!`!X```#\!0$`%````!L&`0`4````,`8!``8```!%
M!@$`!P```$P&`0`.````5`8!`"H```!C!@$`!@```(X&`0`,````E08!``T`
M``"B!@$`$0```+`&`0`+````P@8!`#8```#.!@$`"@````4'`0`B````$`<!
M``L````S!P$`#P```#\'`0`R````3P<!`"4```""!P$`,````*@'`0`Q````
MV0<!`"T````+"`$`#@```#D(`0`%````2`@!``X```!."`$`$P```%T(`0`2
M````<0@!``<```"$"`$`$0```(P(`0`3````G@@!``<```"R"`$`%````+H(
M`0`8````SP@!``<```#H"`$`!0```/`(`0`,````]@@!``P````#"0$`$@``
M`!`)`0`$````(PD!``<````H"0$`"@```#`)`0`+````.PD!``P```!'"0$`
M#@```%0)`0`.````8PD!``4```!R"0$`!0```'@)`0`N````?@D!`"8```"M
M"0$`(P```-0)`0`#````^`D!`!(```#\"0$`!@````\*`0`>````%@H!`!@`
M```U"@$`)0```$X*`0`-````=`H!`!\```"""@$``P```*(*`0`'````I@H!
M``(```"N"@$`#````+$*`0`5````O@H!``L```#4"@$`&0```.`*`0`@````
M^@H!`!(````;"P$`!0```"X+`0`*````-`L!`!4````_"P$`$@```%4+`0`,
M````:`L!``0```!U"P$`"0```'H+`0`'````A`L!``P```","P$`4@```)D+
M`0`7````[`L!`"0````$#`$`$@```"D,`0`'````/`P!``8```!$#`$`#@``
M`$L,`0`,````6@P!``T```!G#`$`%0```'4,`0`2````BPP!``\```">#`$`
M%````*X,`0`*````PPP!`!L```#.#`$`$````.H,`0`+````^PP!`&D````'
M#0$`&@```'$-`0`7````C`T!`"<```"D#0$`&@```,P-`0`7````YPT!`!L`
M``#_#0$`&0```!L.`0`?````-0X!`!,```!5#@$`"````&D.`0`'````<@X!
M``@```!Z#@$`"0```(,.`0`5````C0X!``T```"C#@$`(P```+$.`0`-````
MU0X!`!,```#C#@$`"````/<.`0`#``````\!`$8````$#P$`/P```$L/`0`W
M````BP\!`%<```###P$`!0```!L0`0`?````(1`!`"\```!!$`$`"@```'$0
M`0`(````?!`!``T```"%$`$`+0```),0`0`$````P1`!`$\```#&$`$`)0``
M`!81`0`<````/!$!``L```!9$0$`'P```&41`0`=````A1$!`"4```"C$0$`
M(````,D1`0`D````ZA$!`"`````/$@$`"P```#`2`0`'````/!(!``T```!$
M$@$`#````%(2`0`7````7Q(!``8```!W$@$`.0```'X2`0`,````N!(!``<`
M``#%$@$`"0```,T2`0`3````UQ(!``D```#K$@$`!````/42`0`0````^A(!
M``@````+$P$`"````!03`0`$````'1,!``L````B$P$`#````"X3`0`2````
M.Q,!`!$```!.$P$`#````&`3`0`:````;1,!``\```"($P$`!P```)@3`0`-
M````H!,!`!0```"N$P$`#@```,,3`0`,````TA,!`!L```#?$P$`+````/L3
M`0`3````*!0!`!P````\%`$`*````%D4`0`&````@A0!``<```")%`$`$P``
M`)$4`0`%````I10!``0```"K%`$`%P```+`4`0`*````R!0!``P```#3%`$`
M"0```.`4`0`&````ZA0!``D```#Q%`$`"````/L4`0`)````!!4!``H````.
M%0$`$0```!D5`0`&````*Q4!``X````R%0$`#@```$$5`0`-````4!4!``L`
M``!>%0$`'0```&H5`0`+````B!4!``(```"4%0$`'````)<5`0`'````M!4!
M``8```"\%0$`9````,,5`0`)````*!8!``<````R%@$`)@```#H6`0`X````
M818!`!H```":%@$`*@```+46`0`[````X!8!`"@````<%P$`-````$47`0`9
M````>A<!`!4```"4%P$`!0```*H7`0`'````L!<!``@```"X%P$`!P```,$7
M`0`%````R1<!``<```#/%P$`#@```-<7`0`)````YA<!``8```#P%P$`"```
M`/<7`0`+`````!@!``<````,&`$`"````!08`0`'````'1@!`!8````E&`$`
M"0```#P8`0`&````1A@!``L```!-&`$`$````%D8`0`<````:A@!`!0```"'
M&`$`!P```)P8`0`1````I!@!``@```"V&`$`#@```+\8`0`(````SA@!``4`
M``#7&`$`$````-T8`0`0````[A@!``8```#_&`$`&0````89`0`*````(!D!
M`!P````K&0$`!P```$@9`0`%````4!D!`!````!6&0$`%````&<9`0`+````
M?!D!``T```"(&0$`*````)89`0`8````OQD!`!<```#8&0$`!````/`9`0`)
M````]1D!``H```#_&0$`!P````H:`0`"````$AH!``X````5&@$`"````"0:
M`0`C````+1H!`!\```!1&@$`.````'$:`0`F````JAH!`#$```#1&@$`)P``
M``,;`0!D````*QL!`!0```"0&P$`50```*4;`0`X````^QL!`$H````T'`$`
M6P```'\<`0`H````VQP!`#@````$'0$`*````#T=`0`L````9AT!`"8```"3
M'0$`&P```+H=`0`^````UAT!`*D!```5'@$`(P```+\?`0`7````XQ\!`$@`
M``#['P$`A0```$0@`0`P````RB`!`"4```#[(`$`00```"$A`0!;````8R$!
M`$D```"_(0$`,0````DB`0`=````.R(!`!@```!9(@$`*P```'(B`0`A````
MGB(!`!\```#`(@$`*P```.`B`0`F````#",!`"<````S(P$`.@```%LC`0`=
M````EB,!`!$```"T(P$`,P```,8C`0`E````^B,!`"<````@)`$`(````$@D
M`0`?````:20!`#````"))`$`:0```+HD`0`Q````)"4!`$$```!6)0$`,P``
M`)@E`0`E````S"4!`#T```#R)0$`90```#`F`0!-````EB8!`"\```#D)@$`
M+@```!0G`0`P````0R<!`%0```!T)P$`6@```,DG`0!(````)"@!`$H```!M
M*`$`,@```+@H`0`O````ZR@!`"P````;*0$`+0```$@I`0!Q````=BD!`&8`
M``#H*0$`;P```$\J`0"S````ORH!`!<```!S*P$`)0```(LK`0`R````L2L!
M`"D```#D*P$`/@````XL`0`B````32P!`%(```!P+`$`)0```,,L`0`+````
MZ2P!`+$```#U+`$`10```*<M`0`A````[2T!`#`````/+@$`)0```$`N`0`<
M````9BX!`#$```"#+@$`!P```+4N`0`'````O2X!``0```#%+@$`#0```,HN
M`0`+````V"X!``X```#D+@$`"P```/,N`0`%````_RX!`!`````%+P$``@``
M`!8O`0!9````&2\!``4```!S+P$`$@```'DO`0`$````C"\!``<```"1+P$`
M"````)DO`0`%````HB\!``,```"H+P$`$````*PO`0`,````O2\!`!,```#*
M+P$`#0```-XO`0`"````["\!``<```#O+P$`!@```/<O`0`4````_B\!``P`
M```3,`$`&````"`P`0`&````.3`!`!(```!`,`$`#````%,P`0`#````8#`!
M`"H```!D,`$`!````(\P`0`&````E#`!``<```";,`$`'P```*,P`0`U````
MPS`!`"X```#Y,`$`+P```"@Q`0`7````6#$!`"(```!P,0$`)0```),Q`0`@
M````N3$!`!L```#:,0$`&````/8Q`0`D````#S(!`!\````T,@$`&@```%0R
M`0`A````;S(!`"````"1,@$`&@```+(R`0`R````S3(!`!H`````,P$`+P``
M`!LS`0`K````2S,!`!\```!W,P$`(P```)<S`0`?````NS,!`!H```#;,P$`
M(0```/8S`0`E````&#0!`"8````^-`$`)0```&4T`0`D````BS0!`!@```"P
M-`$`'0```,DT`0`D````YS0!`!@````,-0$`(@```"4U`0`L````2#4!`"\`
M``!U-0$`%0```*4U`0`E````NS4!`#P```#A-0$`'P```!XV`0`C````/C8!
M`!\```!B-@$`(````((V`0`:````HS8!`!@```"^-@$`)@```-<V`0`>````
M_C8!`"D````=-P$`'@```$<W`0`Q````9C<!``D```"8-P$`#````*(W`0`7
M````KS<!`"\```#'-P$`)````/<W`0`'````'#@!``\````D.`$`%````#0X
M`0`.````23@!``T```!8.`$`)````&8X`0`%````BS@!``<```"1.`$`(@``
M`)DX`0`E````O#@!`!H```#B.`$`'0```/TX`0`:````&SD!``<````V.0$`
MQP```#XY`0`+````!CH!`!4````2.@$`!@```"@Z`0`)````+SH!``L````Y
M.@$`#0```$4Z`0`7````4SH!``8```!K.@$`,P```'(Z`0`3````ICH!`!,`
M``"Z.@$`!P```,XZ`0`/````UCH!``<```#F.@$`,@```.XZ`0`$````(3L!
M`"$````F.P$`$P```$@[`0`,````7#L!`!$```!I.P$`,@```'L[`0`6````
MKCL!``@```#%.P$`'0```,X[`0`)````[#L!``H```#V.P$`%`````$\`0`*
M````%CP!`!T````A/`$`"````#\\`0`?````2#P!``@```!H/`$`&@```'$\
M`0`G````C#P!``8```"T/`$`%0```+L\`0`'````T3P!``@```#9/`$`"0``
M`.(\`0`_````[#P!``<````L/0$`#P```#0]`0`.````1#T!`!````!3/0$`
M"0```&0]`0`)````;CT!``@```!X/0$`$P```($]`0`'````E3T!`!D```"=
M/0$`"@```+<]`0`7````PCT!`!0```#:/0$`"@```.\]`0`,````^CT!`!<`
M```'/@$`!````!\^`0`J````)#X!``P```!//@$`$0```%P^`0`'````;CX!
M``(```!V/@$`$````'D^`0`8````BCX!``,```"C/@$`"````*<^`0`&````
ML#X!``<```"W/@$`#0```+\^`0`+````S3X!`!0```#9/@$`%0```.X^`0`.
M````!#\!`"\````3/P$`(````$,_`0`<````9#\!`!4```"!/P$`#````)<_
M`0`Q````I#\!``4```#6/P$`$@```-P_`0`_````[S\!`!(````O0`$`"@``
M`$)``0`&````34`!``0```!40`$`!````%E``0`*````7D`!`!,```!I0`$`
M!0```'U``0`&````@T`!``8```"*0`$`"````)%``0`$````FD`!``P```"?
M0`$`"@```*Q``0`Y````MT`!`"X```#Q0`$`*0```"!!`0`%````2D$!`!@`
M``!000$`&0```&E!`0`?````@T$!`!T```"C00$`$0```,%!`0`"````TT$!
M``0```#600$`"@```-M!`0`&````YD$!``4```#M00$``P```/-!`0`,````
M]T$!`$4````$0@$`,@```$I"`0`:````?4(!`#0```"80@$`*````,U"`0!3
M````]D(!`!D```!*0P$`<@```&1#`0`@````UT,!`#4```#X0P$`(0```"Y$
M`0!%````4$0!`#````"61`$`*````,=$`0`I````\$0!`"8````:10$`)0``
M`$%%`0`H````9T4!`"@```"010$`(@```+E%`0`K````W$4!`#`````(1@$`
M$@```#E&`0`3````3$8!`!````!@1@$`>0```'%&`0`)````ZT8!`*$```#U
M1@$`<P```)='`0!\````"T@!`"L```"(2`$`5````+1(`0`7````"4D!`"<`
M```A20$`%@```$E)`0`/````8$D!`!<```!P20$`'P```(A)`0!`````J$D!
M`!\```#I20$`'`````E*`0!1````)DH!`!H```!X2@$`%````)-*`0`*````
MJ$H!``4```"S2@$`!@```+E*`0`(````P$H!`!(```#)2@$`$````-Q*`0`3
M````[4H!`!T````!2P$`#P```!]+`0`/````+TL!``0````_2P$`"P```$1+
M`0`'````4$L!``4```!82P$`%````%Y+`0`'````<TL!``@```![2P$`#P``
M`(1+`0`(````E$L!``P```"=2P$`#P```*I+`0`&````NDL!`!0```#!2P$`
M!@```-9+`0`,````W4L!`!$```#J2P$`"````/Q+`0`$````!4P!`!D````*
M3`$`$0```"1,`0`*````-DP!`!@```!!3`$`$P```%I,`0`<````;DP!`!$`
M``"+3`$`!````)U,`0`/````HDP!``<```"R3`$`!````+I,`0`9````OTP!
M``<```#93`$``@```.%,`0`1````Y$P!``D```#V3`$`$@````!-`0`7````
M$TT!``8````K30$`)P```#)-`0`$````6DT!``\```!?30$`$P```&]-`0`'
M````@TT!``<```"+30$`$0```)--`0`&````I4T!`!@```"L30$`!@```,5-
M`0`3````S$T!`!````#@30$`$@```/%-`0`&````!$X!``P````+3@$`"0``
M`!A.`0`1````(DX!`"(````T3@$`!P```%=.`0`+````7TX!``4```!K3@$`
M`@```'%.`0!C`0``=$X!`!0```#83P$`$P```.U/`0`/`````5`!``4````1
M4`$`"0```!=0`0`)````(5`!``,````K4`$`%````"]0`0`<````1%`!`"P`
M``!A4`$`*P```(Y0`0`A````NE`!`"T```#<4`$`'`````I1`0`S````)U$!
M``L```!;40$`+````&=1`0`4````E%$!`!,```"I40$`"P```+U1`0`H````
MR5$!``P```#R40$`%0```/]1`0`;````%5(!`"$````Q4@$`"@```%-2`0"#
M````7E(!`!8```#B4@$`!P```/E2`0`1`````5,!`!4````34P$`#@```"E3
M`0`*````.%,!``\```!#4P$`$0```%-3`0":````95,!``T`````5`$`%0``
M``Y4`0`9````)%0!``\````^5`$`$````$Y4`0`0````7U0!``8```!P5`$`
M!@```'=4`0`\````?E0!`!X```"[5`$`.0```-I4`0!,````%%4!`&L```!A
M50$`9P```,U5`0!Q````-58!`&T```"G5@$`/````!57`0`2````4E<!`!,`
M``!E5P$`#````'E7`0`1````AE<!`!(```"85P$`!0```*M7`0`K````L5<!
M`!(```#=5P$`"@```/!7`0`)````^U<!``H````%6`$`,P```!!8`0`M````
M1%@!`!D```!R6`$`!@```(Q8`0`A````DU@!``D```"U6`$`!P```+]8`0`5
M````QU@!`"(```#=6`$`$0````!9`0`6````$ED!`!H````I60$`'0```$19
M`0`J````8ED!`!L```"-60$`%````*E9`0`2````OED!`!$```#160$`+@``
M`.-9`0`<````$EH!`!T````O6@$`&0```$U:`0!E````9UH!`$(```#-6@$`
M,````!!;`0`#````05L!``H```!%6P$`/````%!;`0`.````C5L!``H```"<
M6P$`"P```*=;`0`'````LUL!``<```"[6P$`!0```,-;`0`*````R5L!``D`
M``#46P$`"P```-Y;`0`=````ZEL!``X````(7`$`$@```!=<`0`@````*EP!
M`!L```!+7`$`,P```&=<`0`+````FUP!`!\```"G7`$`$@```,=<`0`>````
MVEP!``\```#Y7`$`$P````E=`0`2````'5T!``\````P70$`(@```$!=`0`8
M````8UT!``<```!\70$`!@```(1=`0`(````BUT!`"@```"470$`!@```+U=
M`0`*````Q%T!`!(```#/70$`"@```.)=`0`4````[5T!`!,````"7@$`+0``
M`!9>`0`*````1%X!`!$```!/7@$`!P```&%>`0`3````:5X!`!P```!]7@$`
M&@```)I>`0`]````M5X!`#H```#S7@$`"0```"Y?`0`,````.%\!`!(```!%
M7P$`"````%A?`0`%````85\!``<```!G7P$`#````&]?`0`:````?%\!`$D`
M``"77P$`%P```.%?`0`I````^5\!`"T````C8`$`-````%%@`0`Y````AF`!
M``T```#`8`$`"0```,Y@`0`*````V&`!``@```#C8`$`-````.Q@`0!(````
M(6$!`#,```!J80$`7@```)YA`0`R````_6$!`#(````P8@$`10```&-B`0`^
M````J6(!`#(```#H8@$`1@```!MC`0`N````8F,!`#L```"18P$`0@```,UC
M`0`R````$&0!`#@```!#9`$`.@```'QD`0`E````MV0!`"@```#=9`$`.0``
M``9E`0`Z````0&4!`#D```![90$`&P```+5E`0`,````T64!`"````#>90$`
M!@```/]E`0`+````!F8!`!X````29@$`)@```#%F`0`'````6&8!``<```!@
M9@$`$P```&AF`0`)````?&8!``@```"&9@$`-0```(]F`0`+````Q68!`!``
M``#19@$`!P```.)F`0`&````ZF8!``4```#Q9@$`!P```/=F`0`&````_V8!
M``L````&9P$`+0```!)G`0`6````0&<!`!(```!79P$`"````&IG`0`'````
M<V<!`!````![9P$`!0```(QG`0`/````DF<!``<```"B9P$`$P```*IG`0`)
M````OF<!``@```#(9P$`!````-%G`0`-````UF<!``@```#D9P$`&@```.UG
M`0`1````"&@!``@````::`$`"@```"-H`0`,````+F@!``<````[:`$`%0``
M`$-H`0`#````66@!`"P```!=:`$`$P```(IH`0`I````GF@!``8```#(:`$`
M!P```,]H`0`)````UV@!``<```#A:`$`0````.EH`0`>````*FD!`#L```!)
M:0$`*@```(5I`0`D````L&D!``8```#5:0$`!0```-QI`0`:````XFD!`"$`
M``#]:0$`/P```!]J`0`[````7VH!`",```";:@$`(@```+]J`0!7````XFH!
M`"P````Z:P$`$@```&=K`0`*````>FL!``L```"%:P$`%P```)%K`0`/````
MJ6L!``T```"Y:P$`$@```,=K`0`2````VFL!`!(```#M:P$`$P````!L`0`-
M````%&P!`!,````B;`$`!0```#9L`0`9````/&P!`!H```!6;`$`%P```'%L
M`0`9````B6P!`"0```"C;`$`!````,AL`0`+````S6P!`!,```#9;`$`1```
M`.UL`0!<````,FT!``@```"/;0$`$@```)AM`0`%````JVT!``0```"Q;0$`
M'@```+9M`0`9````U6T!`!T```#O;0$`$0````UN`0`>````'VX!`"T````^
M;@$`-@```&QN`0`2````HVX!`"@```"V;@$`!@```-]N`0`9````YFX!`!0`
M````;P$`%@```!5O`0`5````+&\!`!\```!";P$`$````&)O`0`D````<V\!
M`"@```"8;P$`$0```,%O`0`)````TV\!`!$```#=;P$`"@```.]O`0`/````
M^F\!`!T````*<`$`$0```"AP`0`(````.G`!``0```!#<`$`#````$AP`0`-
M````57`!``D```!C<`$`$0```&UP`0`&````?W`!``<```"&<`$`$````(YP
M`0`*````GW`!``X```"J<`$`#P```+EP`0`#````R7`!``P```#-<`$`$0``
M`-IP`0`1````['`!`!T```#^<`$`6````!QQ`0`@````=7$!`!$```"6<0$`
M%0```*AQ`0`%````OG$!`!\```#$<0$`%P```.1Q`0`8````_'$!`#8````5
M<@$`0P```$QR`0`L````D'(!``D```"]<@$`-````,=R`0`>````_'(!``T`
M```;<P$`"0```"ES`0`-````,W,!``0```!!<P$`"P```$9S`0`:````4G,!
M`!@```!M<P$`%````(9S`0`*````FW,!`!````"F<P$`+````+=S`0`O````
MY',!`#X````4=`$`,0```%-T`0`L````A70!`!X```"R=`$`1````-%T`0`L
M````%G4!`#X```!#=0$`+````()U`0`]````KW4!`#\```#M=0$`(@```"UV
M`0`H````4'8!`#<```!Y=@$`,0```+%V`0`M````XW8!`"\````1=P$`/```
M`$%W`0`B````?G<!`"<```"A=P$`/P```,EW`0`K````"7@!`!P````U>`$`
M*0```%)X`0`F````?'@!`!X```"C>`$`$0```,)X`0#$````U'@!`#H```"9
M>0$`*0```-1Y`0`K````_GD!`"T````J>@$`+P```%AZ`0`U````B'H!`",`
M``"^>@$`*````.)Z`0`N````"WL!`#$````Z>P$`.0```&Q[`0`T````IGL!
M`)````#;>P$`-````&Q\`0`8````H7P!`"T```"Z?`$`*P```.A\`0`O````
M%'T!`$0```!$?0$`2@```(E]`0`/````U'T!``8```#D?0$`"@```.M]`0`*
M````]GT!`!`````!?@$`#@```!)^`0`4````(7X!`"@````V?@$`#P```%]^
M`0`,````;WX!``0```!\?@$`$0```(%^`0`B````DWX!``H```"V?@$`#P``
M`,%^`0`6````T7X!`!(```#H?@$`'@```/M^`0`0````&G\!`$L````K?P$`
M!P```'=_`0`8````?W\!``8```"8?P$`#P```)]_`0`5````KW\!`!4```#%
M?P$`$````-M_`0`"````['\!`%T```#O?P$`!P```$V``0`1````58`!`!D`
M``!G@`$`!0```(&``0`1````AX`!`!(```"9@`$`!@```*R``0`.````LX`!
M``@```#"@`$`!@```,N``0`0````TH`!``\```#C@`$`'P```/.``0`A````
M$X$!`!4````U@0$`"@```$N!`0`&````5H$!``\```!=@0$`$0```&V!`0`7
M````?X$!`!4```"7@0$`#P```*V!`0`/````O8$!`!$```#-@0$`*````-^!
M`0`1````"((!`!T````:@@$`/@```#B"`0`-````=X(!`"````"%@@$`$P``
M`*:"`0`:````NH(!`!<```#5@@$`*P```.V"`0`2````&8,!``4````L@P$`
M&P```#*#`0`&````3H,!`"\```!5@P$`00```(6#`0`*````QX,!``H```#2
M@P$`%0```-V#`0`,````\X,!`!(`````A`$`$@```!.$`0`&````)H0!`#(`
M```MA`$`&0```&"$`0`E````>H0!`"8```"@A`$`%@```,>$`0`F````WH0!
M``@````%A0$`"P````Z%`0`L````&H4!`$````!'A0$`"````(B%`0`5````
MD84!`"<```"GA0$`"````,^%`0`/````V(4!`#T```#HA0$`#P```":&`0`,
M````-H8!``4```!#A@$`40```$F&`0`$````FX8!``<```"@A@$`"0```*B&
M`0`/````LH8!`!$```#"A@$`%0```-2&`0`8````ZH8!`!X````#AP$`'0``
M`"*'`0`@````0(<!`!X```!AAP$`!P```("'`0`(````B(<!``@```"1AP$`
M!P```)J'`0`6````HH<!``4```"YAP$`"0```+^'`0`A````R8<!`!<```#K
MAP$`$`````.(`0`.````%(@!``P````CB`$`#````#"(`0`9````/8@!`$,`
M``!7B`$`-@```)N(`0`,````TH@!`!8```#?B`$`>@```/:(`0`:````<8D!
M`!H```",B0$`$0```*>)`0`'````N8D!``0```#!B0$`)P```,:)`0`V````
M[HD!`#T````EB@$`(@```&.*`0`L````AHH!`!@```"SB@$`)P```,R*`0`*
M````](H!``<```#_B@$`#`````>+`0`&````%(L!``T````;BP$`#````"F+
M`0`2````-HL!``P```!)BP$`%P```%:+`0`+````;HL!``H```!ZBP$`#@``
M`(6+`0`+````E(L!``P```"@BP$`'P```*V+`0`;````S8L!`$T```#IBP$`
M%P```#>,`0`&````3XP!``0```!6C`$`)P```%N,`0`Q````@XP!`!X```"U
MC`$`'0```-2,`0`K````\HP!`"H````>C0$`+````$F-`0`M````=HT!`!P`
M``"DC0$`!@```,&-`0`<````R(T!``X```#EC0$`%P```/2-`0`#````#(X!
M``,````0C@$`!P```!2.`0`0````'(X!`!(````MC@$`#0```$".`0`6````
M3HX!``L```!EC@$`)@```'&.`0`&````F(X!``0```"?C@$`$@```*2.`0`2
M````MXX!``X```#*C@$`!P```-F.`0`.````X8X!``\```#PC@$`(0````"/
M`0`&````(H\!``H````ICP$`"````#2/`0`+````/8\!`!8```!)CP$`$0``
M`&"/`0`#````<H\!`!0```!VCP$`"````(N/`0`&````E(\!`#D```";CP$`
M&````-6/`0",````[H\!`!D```![D`$`#````)60`0`&````HI`!``X```"I
MD`$`"````+B0`0`*````P9`!``<```#,D`$`#````-20`0`"````X9`!``@`
M``#DD`$`#0```.V0`0`-````^Y`!``X````)D0$`$0```!B1`0`6````*I$!
M``8```!!D0$`!P```$B1`0`0````4)$!``@```!AD0$`"@```&J1`0`%````
M=9$!`"````![D0$`"P```)R1`0`&````J)$!`"0```"OD0$`$0```-21`0`&
M````YI$!``L```#MD0$`!0```/F1`0`)````_Y$!``H````)D@$`%````!22
M`0`%````*9(!``4````OD@$`#0```#62`0`.````0Y(!``P```!2D@$`"P``
M`%^2`0`2````:Y(!``@```!^D@$`!P```(>2`0`6````CY(!`!P```"FD@$`
M0P```,.2`0`K````!Y,!`#@````SDP$`"0```&R3`0`*````=I,!``0```"!
MDP$`"0```(:3`0`(````D),!`!0```"9DP$`"P```*Z3`0`&````NI,!``T`
M``#!DP$`!@```,^3`0!`````UI,!`$4````7E`$`0@```%V4`0`K````H)0!
M``4```#,E`$`#P```-*4`0`#````XI0!``8```#FE`$`!@```.V4`0`;````
M])0!``P````0E0$`%````!V5`0`(````,I4!``@````[E0$`(P```$25`0`(
M````:)4!``<```!QE0$`$````'F5`0`$````BI4!``@```"/E0$`#````)B5
M`0`(````I94!``L```"NE0$`%````+J5`0`/````SY4!``@```#?E0$`"```
M`.B5`0`%````\94!`#0```#WE0$`-P```"R6`0`W````9)8!`"P```"<E@$`
M10```,F6`0!#````#Y<!`"\```!3EP$`6````(.7`0`T````W)<!`$H````1
MF`$`+0```%R8`0`0````BI@!`!````";F`$`"P```*R8`0`C````N)@!`"0`
M``#<F`$`%P````&9`0`@````&9D!``P````ZF0$`#@```$>9`0`*````5ID!
M``P```!AF0$`+@```&Z9`0`J````G9D!`#\```#(F0$`!@````B:`0`>````
M#YH!`#`````NF@$`'````%^:`0`6````?)H!``8```"3F@$`"P```)J:`0`*
M````IIH!`!````"QF@$`)0```,*:`0!&````Z)H!`)$````OFP$`=````,&;
M`0`/````-IP!``P```!&G`$`#0```%.<`0`;````89P!`!<```!]G`$`#@``
M`)6<`0`%````I)P!`!4```"JG`$`%0```,"<`0`3````UIP!`!8```#JG`$`
M%P````&=`0`T````&9T!`(T```!.G0$`$````-R=`0`%````[9T!`!(```#S
MG0$`"0````:>`0`*````$)X!``H````;G@$`*````":>`0`7````3YX!`!``
M``!GG@$`%0```'B>`0`0````CIX!`!8```"?G@$`%P```+:>`0`6````SIX!
M`!,```#EG@$`$P```/F>`0`<````#9\!`!L````JGP$`(````$:?`0`_````
M9Y\!`!D```"GGP$`&````,&?`0`7````VI\!`!8```#RGP$`$@````F@`0`<
M````'*`!`!L````YH`$`$P```%6@`0`3````::`!`#````!]H`$`&P```*Z@
M`0`<````RJ`!`$(```#GH`$`'P```"JA`0`%````2J$!`!0```!0H0$`+0``
M`&6A`0`C````DZ$!`"$```"WH0$`)@```-FA`0`E`````*(!`!T````FH@$`
M(P```$2B`0`C````:*(!`!P```",H@$`(@```*FB`0!!````S*(!`"(````.
MHP$`)P```#&C`0`G````6:,!`"````"!HP$`(````**C`0`C````PZ,!`"D`
M``#GHP$`(@```!&D`0`C````-*0!``T```!8I`$`%P```&:D`0`8````?J0!
M``0```"7I`$`"````)RD`0`*````I:0!`!0```"PI`$`!@```,6D`0`5````
MS*0!``0```#BI`$`"P```.>D`0`'````\Z0!``8```#[I`$`!0````*E`0`3
M````"*4!``8````<I0$`"````".E`0`&````+*4!``8````SI0$`"@```#JE
M`0`0````1:4!`!H```!6I0$`$````'&E`0`1````@J4!``H```"4I0$`&```
M`)^E`0`%````N*4!`#D```"^I0$`%@```/BE`0`1````#Z8!`!$````AI@$`
M#@```#.F`0`+````0J8!`!(```!.I@$`+P```&&F`0`(````D:8!``@```":
MI@$`)````*.F`0`2````R*8!``\```#;I@$`!@```.NF`0`,````\J8!``D`
M``#_I@$`!0````FG`0`D````#Z<!``H````TIP$`%@```#^G`0`-````5J<!
M`!,```!DIP$`&````'BG`0`C````D:<!`"<```"UIP$`"@```-VG`0`#````
MZ*<!``H```#LIP$`(@```/>G`0`'````&J@!``,````BJ`$`$0```":H`0`2
M````.*@!``<```!+J`$`!0```%.H`0`'````6:@!`"H```!AJ`$`#0```(RH
M`0`2````FJ@!``H```"MJ`$`$P```+BH`0`7````S*@!``P```#DJ`$`#@``
M`/&H`0`.`````*D!``X````/J0$`!````!ZI`0`1````(ZD!`$,````UJ0$`
M!@```'FI`0`%````@*D!`"<```"&J0$`%@```*ZI`0`T````Q:D!`!4```#Z
MJ0$`#@```!"J`0`3````'ZH!``\````SJ@$`$````$.J`0`/````5*H!`!X`
M``!DJ@$`'P```(.J`0`U````HZH!`"L```#9J@$`)@````6K`0`(````+*L!
M``@````UJP$`"P```#ZK`0`+````2JL!`!$```!6JP$`!````&BK`0`-````
M;:L!`"H```![JP$`#0```*:K`0`-````M*L!`"8```#"JP$`40```.FK`0`=
M````.ZP!``T```!9K`$`"````&>L`0`(````<*P!``X```!YK`$`#@```(BL
M`0`5````EZP!``D```"MK`$``@```+>L`0`-````NJP!`",```#(K`$`!@``
M`.RL`0`%````\ZP!``D```#YK`$`"P````.M`0`)````#ZT!``D````9K0$`
M%````".M`0`.````.*T!``8```!'K0$`"````$ZM`0`/````5ZT!``0```!G
MK0$`!0```&RM`0!K````<JT!``P```#>K0$`#P```.NM`0`@````^ZT!``<`
M```<K@$`!0```"2N`0`J````*JX!`#$```!5K@$`$0```(>N`0`*````F:X!
M`!D```"DK@$`"@```+ZN`0`)````R:X!`"H```#3K@$`'@```/ZN`0`I````
M':\!`"@```!'KP$`*P```'"O`0`/````G*\!``4```"LKP$`!P```+*O`0`-
M````NJ\!``4```#(KP$`$P```,ZO`0`6````XJ\!``8```#YKP$`60````"P
M`0`>````6K`!`!````!YL`$`%@```(JP`0`D````H;`!`&8```#&L`$`&```
M`"VQ`0`'````1K$!`!\```!.L0$`,````&ZQ`0`(````G[$!``8```"HL0$`
M'@```*^Q`0`%````SK$!``H```#4L0$`+@```-^Q`0`M````#K(!`#L````\
ML@$`$P```'BR`0`&````C+(!`"0```"3L@$`5@```+BR`0`?````#[,!`!P`
M```OLP$`.0```$RS`0`"````AK,!`!D```")LP$`!P```*.S`0`2````J[,!
M`!$```"^LP$`!P```-"S`0`4````V+,!``8```#MLP$`"````/2S`0`+````
M_;,!``<````)M`$`"@```!&T`0`+````'+0!`"P````HM`$`!P```%6T`0`0
M````7;0!`!````!NM`$`#P```'^T`0`)````C[0!``P```"9M`$`#0```*:T
M`0`*````M+0!``D```"_M`$`"@```,FT`0`(````U+0!`!L```#=M`$`'@``
M`/FT`0`4````&+4!`!H````MM0$`%@```$BU`0`6````7[4!`"````!VM0$`
M!P```)>U`0`6````G[4!``,```"VM0$`!P```+JU`0`%````PK4!``4```#(
MM0$`"0```,ZU`0`0````V+4!`!(```#IM0$`,P```/RU`0`N````,+8!`"(`
M``!?M@$`)````(*V`0`7````I[8!`!\```"_M@$`&0```-^V`0`'````^;8!
M``0````!MP$`#`````:W`0`,````$[<!`!$````@MP$`!@```#*W`0`>````
M.;<!``D```!8MP$`"0```&*W`0`K````;+<!`"4```"8MP$`#P```+ZW`0`%
M````SK<!``P```#4MP$`"0```.&W`0`1````Z[<!`!````#]MP$`"@````ZX
M`0`)````&;@!``4````CN`$`!P```"FX`0`'````,;@!``0````YN`$``P``
M`#ZX`0!9````0K@!`"T```"<N`$`1````,JX`0`;````#[D!`#T````KN0$`
M#P```&FY`0!`````>;D!`"D```"ZN0$`'@```.2Y`0`>`````[H!`",````B
MN@$`-@```$:Z`0`-````?;H!`#````"+N@$`&0```+RZ`0`5````UKH!`!4`
M``#LN@$`#P````*[`0`4````$KL!`!4````GNP$`(0```#V[`0`]````7[L!
M`#X```"=NP$`00```-R[`0`^````'KP!`#\```!=O`$`/0```)V\`0!M````
MV[P!`!X```!)O0$`%@```&B]`0`:````?[T!`"4```":O0$`#P```,"]`0`0
M````T+T!`#L```#AO0$`*P```!V^`0`M````2;X!``H```!WO@$`*0```(*^
M`0`K````K+X!``4```#8O@$`)@```-Z^`0`6````!;\!``X````<OP$`#@``
M`"N_`0`7````.K\!``@```!2OP$`"@```%N_`0`,````9K\!``X```!SOP$`
M+P```(*_`0`/````LK\!``\```#"OP$`#````-*_`0`F````W[\!``@````&
MP`$`!`````_``0`0````%,`!``X````EP`$`"P```#3``0`U````0,`!``(`
M``!VP`$`"````'G``0`7````@L`!``P```":P`$`!P```*?``0`&````K\`!
M`!$```"VP`$`*P```,C``0`-````],`!`!P````"P0$`!````!_!`0`W````
M),$!`",```!<P0$`'@```(#!`0!W````G\$!`!<````7P@$`2````"_"`0`G
M````>,(!`!(```"@P@$`!@```+/"`0`.````NL(!`!0```#)P@$`"0```-["
M`0`1````Z,(!``X```#ZP@$`'@````G#`0`5````*,,!``4````^PP$`$```
M`$3#`0`:````5<,!`#(```!PPP$`%0```*/#`0`5````N<,!`!@```#/PP$`
M$P```.C#`0`?````_,,!``<````<Q`$`%P```"3$`0`+````/,0!`!0```!(
MQ`$`%````%W$`0`6````<L0!`!````")Q`$`%@```)K$`0`8````L<0!``L`
M``#*Q`$`"0```-;$`0`%````X,0!`!T```#FQ`$`!@````3%`0`/````"\4!
M``@````;Q0$`$@```"3%`0`&````-\4!`"0````^Q0$`%````&/%`0`S````
M>,4!`!4```"LQ0$`!P```,+%`0`(````RL4!`!X```#3Q0$`"P```/+%`0`;
M````_L4!``<````:Q@$`(P```"+&`0`'````1L8!``@```!.Q@$`)````%?&
M`0`[````?,8!``L```"XQ@$`)0```,3&`0`G````ZL8!``T````2QP$`&@``
M`"#'`0`0````.\<!``0```!,QP$`#@```%''`0`.````8,<!``<```!OQP$`
M#@```'?'`0`(````AL<!``4```"/QP$`"0```)7'`0`=````G\<!`"8```"]
MQP$`/P```.3'`0`H````),@!`"4```!-R`$`'P```'/(`0`[````D\@!`!X`
M``#/R`$`*@```.[(`0`R````&<D!`%T```!,R0$`)0```*K)`0`-````T,D!
M``@```#>R0$`"@```.?)`0`*````\LD!`!$```#]R0$`%@````_*`0!'````
M)LH!`"4```!NR@$`&@```)3*`0`X````K\H!`$````#HR@$`"0```"G+`0`F
M````,\L!``L```!:RP$`%````&;+`0`G````>\L!``P```"CRP$`&0```+#+
M`0`,````RLL!``X```#7RP$`#@```.;+`0`/````]<L!`!`````%S`$`#P``
M`!;,`0`;````)LP!`!H```!"S`$`-0```%W,`0`+````D\P!`!H```"?S`$`
M!0```+K,`0`5````P,P!``4```#6S`$`'@```-S,`0`7````^\P!``,````3
MS0$`#````!?-`0`0````),T!``4````US0$`#@```#O-`0`(````2LT!``\`
M``!3S0$`!0```&/-`0`'````:<T!`!````!QS0$`20```(+-`0!0````S,T!
M`"<````=S@$`"0```$7.`0`R````3\X!`"L```""S@$`$0```*[.`0`)````
MP,X!``P```#*S@$`$````-?.`0`R````Z,X!``8````;SP$`#0```"+/`0`.
M````,,\!`!4````_SP$`#0```%7/`0!<````8\\!``H```#`SP$`)0```,O/
M`0`5````\<\!`!8````'T`$`+````![0`0`F````2]`!`#X```!RT`$`00``
M`+'0`0`[````\]`!``X````OT0$`!0```#[1`0`3````1-$!`!P```!8T0$`
M(````'71`0`(````EM$!`!,```"?T0$`&P```+/1`0`'````S]$!`!\```#7
MT0$`%P```/?1`0`0````#](!``0````@T@$`$@```"72`0`3````.-(!`!0`
M``!,T@$`!@```&'2`0`'````:-(!`!,```!PT@$`#@```(32`0`/````D](!
M`!$```"CT@$`$0```+72`0`&````Q](!``<```#.T@$`*````-;2`0`D````
M_](!`"`````DTP$`"````$73`0`/````3M,!``8```!>TP$`&````&73`0`I
M````?M,!`"D```"HTP$`"@```-+3`0`8````W=,!``,```#VTP$`"````/K3
M`0`#`````]0!`!(````'U`$`%````!K4`0`+````+]0!`!@````[U`$`(P``
M`%34`0`7````>-0!``8```"0U`$`"@```)?4`0`4````HM0!`!<```"WU`$`
M#````,_4`0`&````W-0!``P```#CU`$`"@```/#4`0`5````^]0!`'D````1
MU0$`'P```(O5`0`O````J]4!`!0```#;U0$`"````/#5`0`'````^=4!`!<`
M```!U@$`%P```!G6`0`8````,=8!`"(```!*U@$`'0```&W6`0`2````B]8!
M`"4```">U@$`$0```,36`0`F````UM8!`!@```#]U@$`%P```!;7`0"#````
M+M<!`"@```"RUP$`'P```-O7`0`X````^]<!`"<````TV`$`'@```%S8`0`K
M````>]@!`",```"GV`$`)P```,O8`0`4````\]@!``L````(V0$`"````!39
M`0`)````'=D!``H````GV0$`%0```#+9`0`+````2-D!`#L```!4V0$`*0``
M`)#9`0`W````NMD!`!8```#RV0$`!@````G:`0!%````$-H!`%4```!6V@$`
M-````*S:`0"<````X=H!``L```!^VP$`-P```(K;`0`O````PML!`!(```#R
MVP$`"`````7<`0`3````#MP!`$0````BW`$`#````&?<`0!8````=-P!`$@`
M``#-W`$`*````!;=`0`4````/]T!`"(```!4W0$`(@```'?=`0`L````FMT!
M`"(```#'W0$`*P```.K=`0`?````%MX!`!4````VW@$`!P```$S>`0`0````
M5-X!`!0```!EW@$`#0```'K>`0`+````B-X!`%$```"4W@$`#````.;>`0`>
M````\]X!`!$````2WP$`'P```"3?`0`)````1-\!``4```!.WP$`&````%3?
M`0`)````;=\!``D```!WWP$`!P```('?`0`'````B=\!``D```"1WP$`$@``
M`)O?`0`<````KM\!``\```#+WP$`'P```-O?`0`0````^]\!``@````,X`$`
M#0```!7@`0`F````(^`!``L```!*X`$`"@```%;@`0`8````8>`!`"8```!Z
MX`$`#````*'@`0`B````KN`!`"L```#1X`$`"P```/W@`0`(````">$!`"$`
M```2X0$`#0```#3A`0`9````0N$!`!L```!<X0$`%````'CA`0`6````C>$!
M`!(```"DX0$`!0```+?A`0`)````O>$!``@```#'X0$`"0```-#A`0`*````
MVN$!`!0```#EX0$`!P```/KA`0`0`````N(!``H````3X@$`"````![B`0`,
M````)^(!`"$````TX@$`#````%;B`0`"````8^(!`",```!FX@$`!0```(KB
M`0`*````D.(!`'H```";X@$`"@```!;C`0`(````(>,!`"H````JXP$`.@``
M`%7C`0`:````D.,!`"X```"KXP$`70```-KC`0`C````..0!`#,```!<Y`$`
M+P```)#D`0`E````P.0!``8```#FY`$`#0```.WD`0`(````^^0!``D````$
MY0$`!0````[E`0`(````%.4!`!(````=Y0$`"@```##E`0`)````.^4!``L`
M``!%Y0$`"P```%'E`0`:````7>4!``@```!XY0$`"0```('E`0`5````B^4!
M``H```"AY0$`"@```*SE`0`%````M^4!`"X```"]Y0$`)@```.SE`0`8````
M$^8!``<````LY@$`$@```#3F`0`)````1^8!``\```!1Y@$`,P```&'F`0`(
M````E>8!`!@```">Y@$`&````+?F`0`&````T.8!``8```#7Y@$`#0```-[F
M`0`<````[.8!``8````)YP$`"0```!#G`0`+````&N<!`!P````FYP$`"P``
M`$/G`0`-````3^<!`"H```!=YP$`'P```(CG`0`8````J.<!``8```#!YP$`
M"P```,CG`0`0````U.<!``T```#EYP$``P```//G`0`.````]^<!``@````&
MZ`$`'0````_H`0`O````+>@!`#````!=Z`$`*@```([H`0`N````N>@!`"X`
M``#HZ`$`C@```!?I`0`6````IND!`&,```"]Z0$`.````"'J`0!A````6NH!
M`&D```"\Z@$`(0```";K`0!-````2.L!`#P```"6ZP$`1P```-/K`0`>````
M&^P!`!@````Z[`$`(P```%/L`0#]`0``=^P!`!T```!U[@$`'0```)/N`0!)
M````L>X!`*````#[[@$`-````)SO`0`I````T>\!`$<```#[[P$`6@```$/P
M`0!D````GO`!`#(````#\0$`(````#;Q`0`>````5_$!`#0```!V\0$`'```
M`*OQ`0`?````R/$!`"0```#H\0$`(`````WR`0`F````+O(!`"\```!5\@$`
M&@```(7R`0`6````H/(!`#$```"W\@$`*@```.GR`0`D````%/,!`#P````Y
M\P$`&@```';S`0`R````D?,!`'$```#$\P$`.P```#;T`0`Z````<O0!`#(`
M``"M]`$`*0```.#T`0!'````"O4!`&T```!2]0$`7P```,#U`0`P````(/8!
M`#````!1]@$`,P```(+V`0!.````MO8!`&8````%]P$`30```&SW`0!3````
MNO<!`$D````.^`$`)P```%CX`0`G````@/@!`"0```"H^`$`>````,WX`0!M
M````1OD!`'<```"T^0$`S@```"SZ`0`<````^_H!`"P````8^P$`-@```$7[
M`0`N````?/L!`%````"K^P$`'````/S[`0!`````&?P!`#\```!:_`$`!0``
M`)K\`0#(````H/P!`$8```!I_0$`(@```+#]`0`^````T_T!`"<````2_@$`
M'````#K^`0`L````5_X!``D```"$_@$`%@```([^`0`#````I?X!`!8```"I
M_@$`#````,#^`0`-````S?X!``L```#;_@$`!P```.?^`0`-````[_X!``<`
M``#]_@$`=0````7_`0`"````>_\!`!8```!^_P$`!````)7_`0`'````FO\!
M``8```"B_P$`!0```*G_`0`%````K_\!`!4```"U_P$`"@```,O_`0`2````
MUO\!``\```#I_P$``@```/G_`0`'````_/\!``L````$``(`$@```!```@`-
M````(P`"`!D````Q``(`!@```$L``@`9````4@`"``H```!L``(``P```'<`
M`@!;````>P`"``0```#7``(`!@```-P``@`'````XP`"`"<```#K``(`3```
M`!,!`@!&````8`$"`$<```"G`0(`*@```.\!`@`N````&@("`#$```!)`@(`
M'0```'L"`@`B````F0("`!P```"\`@(`,@```-D"`@`J````#`,"`"0````W
M`P(`)@```%P#`@`G````@P,"`"X```"K`P(`*P```-H#`@`>````!@0"`"D`
M```E!`(`*@```$\$`@`?````>@0"`",```":!`(`(0```+X$`@`9````X`0"
M`"(```#Z!`(`+````!T%`@`R````2@4"`#,```!]!0(`)P```+$%`@`=````
MV04"`"0```#W!0(`*0```!P&`@`=````1@8"`"<```!D!@(`.````(P&`@`[
M````Q08"`!D````!!P(`(P```!L'`@`Z````/P<"`"(```!Z!P(`)@```)T'
M`@`D````Q`<"`"4```#I!P(`'`````\(`@`D````+`@"`#````!1"`(`'@``
M`(((`@`Q````H0@"`"$```#3"`(`-@```/4(`@`)````+`D"`!`````V"0(`
M(@```$<)`@!'````:@D"`"P```"R"0(`#````-\)`@`/````[`D"`!<```#\
M"0(`$@```!0*`@`0````)PH"`"<````X"@(`!@```&`*`@`*````9PH"`"4`
M``!R"@(`*````)@*`@`;````P0H"`"@```#="@(`'`````8+`@`/````(PL"
M`/0````S"P(`%0```"@,`@`7````/@P"``D```!6#`(`%P```&`,`@`B````
M>`P"`!T```";#`(`'@```+D,`@`)````V`P"`#X```#B#`(`#P```"$-`@`6
M````,0T"``<```!(#0(`&P```%`-`@`1````;`T"`$X```!^#0(`$````,T-
M`@`B````W@T"`!P````!#@(`&````!X.`@`C````-PX"`&$```!;#@(`)P``
M`+T.`@`0````Y0X"`"<```#V#@(`$0```!X/`@`2````,`\"`!@```!##P(`
M"P```%P/`@`=````:`\"`"D```"&#P(`'P```+`/`@`+````T`\"`#,```#<
M#P(`/0```!`0`@`'````3A`"`!,```!6$`(`!P```&H0`@`'````<A`"``D`
M``!Z$`(`20```(00`@`&````SA`"``T```#5$`(`$````.,0`@`6````]!`"
M``L````+$0(`#````!<1`@`'````)!$"`!$````L$0(`#P```#X1`@`<````
M3A$"`!<```!K$0(`%````(,1`@`8````F!$"``P```"Q$0(`#@```+X1`@`L
M````S1$"``X```#Z$0(`-@````D2`@`:````0!("`!````!;$@(`#@```&P2
M`@`#````>Q("`!0```!_$@(`&P```)02`@`#````L!("``D```"T$@(`!P``
M`+X2`@`*````QA("``X```#1$@(`#@```.`2`@`;````[Q("`!P````+$P(`
M#@```"@3`@`T````-Q,"`!H```!L$P(`%0```(<3`@`9````G1,"``T```"W
M$P(`,@```,43`@`)````^!,"`!<````"%`(`5@```!H4`@`5````<10"`!D`
M``"'%`(`"@```*$4`@`$````K!0"``0```"Q%`(`%@```+84`@`5````S10"
M``4```#C%`(`!@```.D4`@`*````\!0"``T```#[%`(`!0````D5`@`.````
M#Q4"`!(````>%0(`/P```#$5`@`R````<14"`"D```"D%0(`(````,X5`@`<
M````[Q4"`",````,%@(`*````#`6`@`@````618"`!4```!Z%@(``@```)`6
M`@`$````DQ8"``T```"8%@(`!@```*86`@`%````K18"``0```"S%@(`$0``
M`+@6`@!X````RA8"`"0```!#%P(`+0```&@7`@`O````EA<"`",```#&%P(`
M2````.H7`@`9````,Q@"`(X```!-&`(`(@```-P8`@!4````_Q@"`"$```!4
M&0(`5P```'89`@`N````SAD"`"D```#]&0(`0````"<:`@`S````:!H"`"\`
M``"<&@(`/P```,P:`@`=````#!L"`"4````J&P(`*````%`;`@!-````>1L"
M`!````#'&P(`&P```-@;`@`4````]!L"`'4````)'`(`"@```'\<`@#6````
MBAP"`(4```!A'0(`?@```.<=`@`X````9AX"`'H```"?'@(`'````!H?`@`W
M````-Q\"`"H```!O'P(`$@```)H?`@`E````K1\"`"0```#3'P(`1@```/@?
M`@`B````/R`"`!P```!B(`(`60```'\@`@`O````V2`"`"8````)(0(`"P``
M`#`A`@`%````/"$"``8```!"(0(`"````$DA`@`B````4B$"``X```!U(0(`
M(````(0A`@`H````I2$"``L```#.(0(`#P```-HA`@`+````ZB$"``D```#V
M(0(`"@`````B`@`)````"R("`!8````5(@(`#0```"PB`@`.````.B("`!0`
M``!)(@(`!P```%XB`@`.````9B("`!$```!U(@(`#````(<B`@`6````E"("
M``T```"K(@(`"@```+DB`@`4````Q"("``8```#9(@(`!P```.`B`@`E````
MZ"("`"(````.(P(`#@```#$C`@`0````0","`!(```!1(P(`)````&0C`@`1
M````B2,"``D```";(P(`%0```*4C`@`'````NR,"``0```##(P(`(P```,@C
M`@`+````[","``(```#X(P(`%0```/LC`@`(````$20"`!$````:)`(`$0``
M`"PD`@`$````/B0"`$D```!#)`(``P```(TD`@`O````D20"`"\```#!)`(`
M"P```/$D`@`(````_20"`!P````&)0(`!0```",E`@`=````*24"``D```!'
M)0(`)````%$E`@`:````=B4"`"````"1)0(`"P```+(E`@`,````OB4"``P`
M``#+)0(`#0```-@E`@`I````YB4"``H````0)@(`'P```!LF`@`%````.R8"
M``,```!!)@(``0```,4%``#"`@``UP4``),"``#Z`P``9`8```````!*!@``
MV@4``"$$``"?````6@,``.(&````````GP$``'$%````````'@,```````!.
M`0``;P0``/<%``!F`0``\@$``-$#```,!@```````"("``#+`````````%H%
M``!W!0``*P8```````!(`@``M`0``&`#``#=````W`0`````````````K04`
M``````#8!@```````*(&``"R`0``H`4``$````#W`0```````/4$``#(````
MZ`4``&4'````````N`$```D&````````````````````````A`8``+8`````
M````7P0``$L`````````K`$``(`!``#?!@``RP(``+$````@!0``1P```$H#
M``#,!0``9`(``+,$```-`@``MP0``&P"``#H`0```````+T&``!8`@``-0``
M`(8%````````/0,```4!``!\````0P4``'H!``!"`0``$@,``#8"```H!P``
M/0(``)T&``!Q````QP4``,0#````````"@$``*H```"[!@```````,$&``!5
M````90````````````````````````!4`0``>@8``-`!```N`P```P(`````
M````````T0(``!8!``"Z!@``"`````````#L!```EP4```\'`````0``````
M```````A````Y@,``$0```#R!`````````$!``!Y!```,0$``"8"```D`P``
M$P,``,4!``"%`P```````)$%```M`0``6@<``-\```!P`0``QP$``'X$``"X
M`P```````*$!```,!```<P4``.0#`````````````*0"`````````````&8%
M``#:`0```04````````,`@``Z0```.T#````````R@0``"@!``#,`@``````
M`*`$``#*`P``40```$X$``"E````!P$```````"O`0``S@8``+L#``"V`P``
MEP,``!X%``",``````````0%``"`!0``4@```&8'``#_``````````````"4
M`0``0P8```````!=!P```````%P#`````````````%P"```&`@``#08``+,%
M``"5!0```````,T```!@!P``E@0``'P$``!,`P````````````!Z!0``<P<`
M``````!+!```LP,``+4"`````````````+`#``#;`0```````'\#``"^````
M`````/8%````````8@$```T%````````XP8`````````````#@(```````"J
M`P``N@$``&4&```R````X0(```````#4`@```````%X!```R!0``J@4``(<"
M```S!P``(04``/,$``"*````>@```,4"```>!P``"@4``+4`````````X08`
M`#H"``#6`@``:`0``+D&``#I`@``0P0````````&!0``.`````````!M!```
M?0```/L!``"O````&0,``*H&``#K`@``\P,```````#5!@```````,D#````
M`````````'D#```3!0``Z00``#L`````````_P(```D%```B!0```````+0`
M``"@`P``/`<``((&````````KP(```````#=`@```````-8#```E`@``"P8`
M``````!-`P``)04``(D#``#@`P``70```,4$``!N`@``I@```&4!``!-!0``
M.P$``-X$``#C!0``ZP```!L'``#"!@``JP4```\$``#.`P```````$$!``")
M!@`````````````&`P``YP8```````!*`````````/<#``##!```M04`````
M``#$`0``10<``,`$````````10$``%P```#]`0``?0$````````&!```````
M``````#Z!@``:P,```````!(!0``%`$``(X!``"V!```@P4``)("```,`P``
MQ@0`````````````TP$```````!0!0``]@0```@'``#.`0``900``.4&```[
M`@`````````$``!V!0``8`(```````!I`0``-0(``#\%``!%`@``A0(``%D'
M``!L!P``:@```"X%```F!P``1@0``)$"````````)00``$X"``!6````^P0`
M``````#L!@``<`4```````"-`P``!P4``(X#````````:P0```P'``"G!@``
M[P$``!<#````````/@```)`%``#I!0``VP8```````!:!@``K00``(`&````
M````Z@4``'L$``#F`````````````````````````.4```!V`0``K`0``-@!
M``"Q!0``$@8``%4'``!)`0``T04```````"Z````'@0````````6!@``T@``
M`(X```#L`P``AP$``+`&``!M!P`````````````G`0``%`8`````````````
M[P```"$!`````````````'("``!V!```108``",!``"``P``A`(`````````
M````I04``````````````````,@#``".!@```````-X```#6`0``&`0`````
M``!?`0``$`0``#@#```2`@``'P,``!P%``!B````!@8``(<```#J`P``GP8`
M````````````6````-L$````````#P```%,&`````````````$$&````````
M`````!<$``#)````X`4``)0$``"%``````````4%````````0@4``+@%````
M````?@4```````#$!```B@,``-$$```[!0``@@````````#3````A0$```,#
M````````'@(``,T#``#Y!0```````"P$```A`@``H@4````````?`0``100`
M`.,"``!(````^0(``'D%``!9!````````&0%``">!0``]`8```````"@`0``
MKP,```````!'!0``U0```"<#``!?````V````#P!```H`@``<0(``*,"``"3
M`0``;P8``"T$``"T`@```````*D!``!%`P``UP(``-<!``"E`0``````````
M``#N!@```````!D"```_`@``-P$``+L!``!]`P``Y00``!H!````````704`
M`)4"``!=`0``&`,``,L&``!I!```-`0``)(```#J!@``*P```'\```!L!0``
M,@(``/(`````````&@4``)X```"G!```>0(```````"W!@``10`````%````
M````,@<```````!-`@```````+4&``!5`P``3P8``%\&````````N@(``/$!
M``#-`0```````%<```#T`P``Q0,``/(#````````&00``!$$````````(```
M```````P!0``)@,``,P!````````H`8``#4#``!&````/@$````````E````
M`````%X'``"R!0``'00```H#``">!@```````'``````````[@$``)````"D
M`P``-`4``-X"``#J!```KP8``(@%``#Y!@``IP,``*,```#/````LP8``.L&
M```K!```20,``"8%``!\`@``VP`````````$!@``]04```0"``!S`0``D@,`
M````````````9@```%T"```G````@04``$H'``#-!0``1`,```````#(`0``
MBP(``!@&```=`@``C00````````P`0```````+`!``#M``````````````"=
M`P``"P<`````````````V@,``!`&```!`@``H08``#P#``"'!0```````#P%
M`````````````+,!``#J``````````````!^`@``GP(```````"\`@``````
M`&H&``#,````40$``````````````````(@```![!@``/P0```````![!0``
M`````-P````T!@``&P0``!$!````````LP```(<$``":!0``I08``-L%``!E
M`@``$`(```````#'!@``/`8``.0``````````````#L$``#.`````````#`&
M``"9!@``:`,``%<&````````[P(``(\%``#/!0``$@4``'\!```+`P``````
M`+``````````Q````&T#``!^`P``````````````````>@(``"H%``!1`P``
M&04``&,`````````@`0``',```"-````Q@```'\"``#P!0``0`,``,0%``!G
M!@```````/D!```````````````````+!0``-@```$P'```0`P``+````(,"
M``!O````-`````````!Y!@``'````.`&``"0!@``;P$``&T%``#(!0``````
M`"<&```]!P``#@``````````````G`4````````Q`@``4P````````!7!P``
M>`0``*(```!@`0```````-X#````````"0```!8$``#8`P``0P(`````````
M`````````,(#``!/`@``*0(``/H"``",!@``E0```"\!``!6`@``5P4``%P%
M``!A!@``(P4``'<!````````F@,```$#``"A!````````.,````<!@``P@4`
M``H"``"[!0```````#D%```*!@``1P,``````````````````*L&``!#`P``
MJP````4'``!D````O0```(,&````````FP,``*L#````````H0(``+$!``#"
M!```F`0``"@``````````````!$"``#X!@``,P````,&```X!0``7`<``-H$
M```V!```O@8``(L!````````A@,``!H$``````````````````!!`P``P@``
M```````)!P``I00```````#=`P```````)(&``"1`P```````.4!```_!P``
M=P0``&P!``!(!P````8``````````````````(8&````````<@```$`'```/
M!@```````#0"```C`````````.T%``"L!@``4P,``&0#``#&!0``2@0``,H"
M``!9````,0<``!0%`````````````/\%````````=0,```````"H!```````
M``````#B`@```````#D#`````````````/\!``",!0``/`(``+P&```B!@``
MQP0``%`&`````````````'H$``"$`P``U@```.\&``!9`0``FP0``+D$``"F
M!0``_@$``"P%````````!08``,H````Y!@```````,\"````````O````&\#
M``!?`P``*P,``-0&```S!@``"@```%T$````````R@8``&X$```I!```[P,`
M`"4#``"Q!```'`$```````!Q!```-@$```````"M`````````(0%``![`0``
M]@8``&<'````````'@8```````#5!````````+L$``!V`P``204`````````
M````40(``!4"``#Q!```A00```````"M`0``>0```-`$``!#````(`,``$P$
M```$````#0,``%D&``!W`P``0`8``.$````J````V0$````````L`P``H0``
M`",#```2!```=`(``.\$``"9!`````````````#U!@``8P(``%4%````````
M``````('```!!```J`(``+\"```\```````````````2````[@0``#$$````
M````Z`8``!4$````````5P(``+\!``".!0``^0````````#0!0```````($!
M```-!P``:````.0!``#4`0``%`<``+`"``"!!```N04``#0'````````-@4`
M`/\&``#:`@``B04``/0$````````CP(```<#``#&`0``,`0``"L'``!D!```
M,@0```````#R`@``B`(```H'``#?`@``508``'`"`````````````-,&``#!
M`P``3```````````````[0(``%P&``"U`0``.`8``(H$```@`0``2P<``%<$
M``#0`@``T@,````````?!P``.@0``#(#``!@!@```````&,#````````T@4`
M`%($``"_`P``````````````````2@(``!<!``#.`@``-@8``(L```#!`@``
MO0$````````F!```3`4```````"(`P```````*<```!;!P``)`<``/$```#X
M!0``^@$````````V`P``NP````,`````````H@(``%('``#W`@``G@(``&``
M``!^````7`$`````````````3P```'($````````4@,``!H&```4`@``G`(`
M`,T$````````AP8```````!F!```D@0```````"=`@``PP8``/``````````
MO`4``,`&``#@`0``+@(``%L"````````F04``'`#``!`!0``F@```'0%```,
M`0``-P4```0#````````:@(```````#T`0``IP(`````````````````````
M`````````````%0"``"9`P``/P$``)X$```M!0``&@````````"5!```-@<`
M`/`!`````````````-0%````````#0$```````#)!@```````$$'``"W`@``
M````````````````S`8``!T````Z`P````````````"+`P``K`4``%,"```N
M!```:P$```````#/!```+`<``%@!```C!```E@$`````````````O0(```X'
M``!K`@``80````````!A`@``E@```!$```"0`0``5@0`````````````&```
M`.$!````````:`$``#`#``#E`@``'P```'P!````````\P4``"4'``#)!0``
M*`4``!8'````````_@(``+0#``#D!````````&0'```]`0``2P,``"@$``"D
M`0```````,,"````````$````,,#``"&`@```````+X!`````````````$D'
M``#[`P``&`(``((%``!E`P``:`8``-8$`````````````-P!````````````
M`+\&``#1!@``E`8```L````T`0``Y04``'L#``"V`@```````*X&```H!@``
MY`8``!4'````````H@$`````````````Q`8``-H````(`@``=`0``!8#````
M````5P,``"4&```B!P````````````#P`P``!0,````````9````;`,``.<$
M``#+`0``^@0``)4!``!S!```WP$``-(!``#>`0```````/H```"B`P``4P4`
M``````"T`0```````/0```!\`P``U0$``)`#````````GP4````````;!@``
M!00``.D&```#!````````&H'``!C`0``J`8``,````#!````5`0``%D%``!R
M`P``QP(`````````````C0(``)P#```6!0``\04``#4!``")`@``CP```/X`
M``#Z!0````````````##`0``9`$```````"7!```E@,``/X$``#A!```T`,`
M`*T#``#+!0``W0$```````!M!@``MP``````````````2`0```````!/!P``
M400``,8&````````%P(```````"I`````````%`"``"]!```.@$``%4"```C
M`@``T@(```P```"5!@``KP0``+<!```B`0```````$,!``!R!P``#@4`````
M``!T`0``/@8``.P"```J`P```````%L$``#2!```Q@(`````````````H@0`
M`'X!``")!````````+4$``!6!P```````$$%``"2!0``Z@$``%0'``"8!0``
M!P<```````#G`P``J0,``)4#``#\!@``0@,``!L"```J!````````&L'``!G
M`0``/P8``)L"```O!P``?P4``+P!````````"P0````````Z````*P(```T$
M``!>!```\@8```````!A`P``O0,``$0&``#(`@```````'@#````````7P4`
M`$<&``!_!```U@4``(T&``#I`P``O@,``,`"```2!P```````(T%```3````
M,`<```````#1````*P4````````J!P``5@,```````!8!0``F@(```(&```\
M!`````````("``!H!P````````````#@````:@0``-````!?`@``NP(`````
M``"=````IP4``&@"``"I!```E@(``"`$```Q!0``X@0``-\#``#W!```>```
M```````3!P``_0,``'(%``#\`P````````````#+`P``1@,``+,"````````
MU`0```D$``!L!```'08````````/!0``20(``($"```]!@``B`8`````````
M````(0,``"$&```Z!@``5@8``#``````````CP$``"H!````````L@(`````
M````````*@8``-P"```(`0``7@(``/,"``#9!@```````.X%````````DP``
M``````!:!`````````````#(!@````````````"7`0``6P4``!X```!/`P``
M[0$``!X!``!A!P``````````````````Q08``!4#``"-`0```````'T$```D
M!0```````*D%``"L`@``)P<````````&!P````````````"V!0``'`(``-D"
M````````G0$``%<!```"`0``1@(``$\$``#K!0``2@4```````!N!P``````
M``H$``#'`````````"($``!X!@``@@$``$D$``#M!@``:P````````!V!@``
M`````.L#``#/`0``TP(``!0```"7`@````````````#7`P````````X$``"3
M!0```````#<'```G`@``:P8```````"%!0``OP0``#D```!.`P``QP,``&\"
M``";````I0(```````#\`@``FP8``%X```!`!```?04``"L!``"I`@``````
M`)D```#9`P``$04``/<````X`@``L@```,H%````````V04`````````````
M\`0`````````````YP4`````````````1P(``"\%````````L0(```````!I
M`P```````/\#```#!0``(`8``$8&```1`P```````)P$``#T!0``=@```%\'
M``"?!````````*X#``!!`@``FP4```D#`````````````$P&````````5@4`
M````````````XP0``+<%```N!@``V0```!`'``!S!@```````.D!```U!```
M;`8``#X'``"C!```9P````````!]!@``I0,````'```=!0``N0,```````!4
M!0``:`4``'L"`````````````'@"``".!```B0```((#``"3`P``:@$``&X#
M``#Y!```P`$``%("``"#`P``Z`0``(`````^`@``-08``$0%```T`P``"0$`
M`*@%`````````````)H$````````;P<``.$#```[`P````````````#6!@``
M`````)$!````````N`8``'$&```<!```]@(``+T%``![````@08``*H!````
M````<0,```L!``#F`@``.P8``#4'`````````````(0````=`P``&P4``#,!
M```M````EP8``,D$````````+`(``)<````:!P``"`,```````"/!```````
M`,\#````````BP0``"4!````````4`````````!8!P``4P<``%H```!I`@``
M``````X#``!$`0``6P,``#X$````````&@(```````"N````N```````````
M````8@8``-4%```?!@``5`,``'P&``!&`0``O@0``#@'````````````````
M``#:!@``A`0``$$````I`P``40<``+8!``#=!```9P,```````#%````F@$`
M```````5````5````.<!``#Q!@``G00``"@#``#7!```^`0``)$$````````
MF0$``#D!``!@!````````#,#``"_````#`4``.@#``#;`@``D@$``/$#``"P
M!```SP8``'X&``!"````&0$```````"/!@``8P8``(8$``!I!0```````.L!
M``!B!P``BP8``&T"```"`P````````````#!`0``L08``.X"````````+08`
M`)L!````````X@````````!0!P```````!0$```Q!@``I@,``$<'``#_!```
M0@<``/@!```"````1P$``',#```G!0```````!<%``!/`0``&`$``(<#````
M````6P8``(D!`````````````````````````````'0&````````CP,`````
M``#N`P``I@(``.,#```(!@``$P0``$L%``!G`@``!`<````````-`````P$`
M`/<&``"F!```8@4``-,#````````T`8``,T"``"C`0``2`8``$P!``#7````
M/@4```````!)````<@8``"H"````````@`(``/P!``#\!0````````````!W
M````!P8``-0````;`0``S@4````````&````_04``!<&``"M!@``V`(``%,!
M``"N`0``;P4``-X%``"A`P``_`0`````````````:0<``.T$``",`0``@P0`
M```"``!-`````````$("``"^`@``B`$``.(!````````V`4``"0````S!0``
M.`$``(0!``````````````````"Z`P``,0```)0```"0!```1`(````````O
M`````````'\&```O!@``F@8``````````````````!H#``#7!@``IP$``/4`
M`````````````*@```!"!@``M`8``(P"```U!0````````````!<!```4@4`
M``````#B!0``GP,```,'````````'P(``-,$```O!```.0(```````"R!@``
M`````/`&``"X!```R@$``#<#``"O!0```````'4````^`P``=P(```````"(
M!```P@$``````````````````+`%``!>!0``,@$``*0%``!!!```4`0`````
M```_````)`0``/X%`````````````),$`````````````*L$``!U!0``]0(`
M`-,%````````=`,``*X%``#E`P``N0$``!\%````````R0$`````````````
M2P$````````I!P``N@0``+X%``!L````8`4```````!N`0``(P8```<$````
M````500``+$#```6`@``3@4```````#K!```@@(``!`%``">`P``X04`````
M``!X`0``:0```($#``#F!0```````.<```!``0``#@$`````````````=@(`
M`(H&``#!!0``+P(`````````````````````````````1@<```````!U!```
M1P0``'H#``#P`@```````$($``#T`@````````````!#!P``WP4``!D'```D
M`@``F`(``%$&``!1!0``4`,``/$"``````````````````!*`0``2`,``#D'
M``!=`P``HP4`````````````@P$``"$'``!B`P```````$`"````````)@$`
M`$X```"K`0```````(H%``!-!@``<`8``%T&```S`@``300``,8#``#+!```
M`````+0%```7!P``&`4``%H!``!U`0``!@$``,$$```S!`````````````#-
M!@``1`0``(L%``#$`@````````````#`!0``Z`(``.`"```3!@``D`(``.H"
M```N`0``,@8``)D"`````````````&T```!6`0``800``+(#````````<0$`
M`&D&``#<`P```````/,```!;`0``%08``.<"``"Y`@``F`8``&T!````````
M8P<``%,$``"N`@```````)$````5`0```````*,&````````VP,``&<%```N
M````Y@$`````````````L@0``*P````@`@``<@$``/,!`````````````$D&
M``#L`0```````)8%````````Y@8``+8&````````A@```"D!````````T0$`
M`+@"``!$!P``.@4```````#[`@``!P````````"Y````$08```0!```<!P``
M`````.0%````````C`0```4"``!>`P``$@$``/T$````````$P(``(($````
M````]0,``*D&``"=!0``S`0``!L```!B!```WP0``/(%``"F`0``)@8``'T"
M````````'`,```@$````````8P0``+P$``!.!P``R`0``-X&````````_@,`
M`,P#```X!```)P0````#````````^`(``````````````````%@#```?!```
M"0(``*,#````````K0(````````Q`P``2`$``+P#``"4`P``G`$```````!5
M`0``[P4``.,!``"K`@``4@$``&4%````````1@4```4```!Q!P``.@<`````
M```W`@``"`4``*@!``#D`@```````&$!``!N!@```````/@```"%!@``_```
M`*H"``#X`P``%P```#\#``"8`P``/04``.`$````````I`0`````````````
M6P```.8$``##````.00``&,%``#9!```,`(```(%``"A!0```````.(#```'
M`@``E@8``!$'``"D````+`8``!8````M`P````````\"``#V````"P(``$X&
M``!N!0``F`$``/T&```W!@``<`0``)0%`````````0<``,D"``!/!0``````
M``````!2!@``W`4```($``!0`0``W04````````D`0``:P4`````````````
M8@(```````#[!@``*08``*8&````````\P8``&X``````````````"0&```!
M!@``'0<```````!G!```]@,```````!S`@``%`,``"8`````````9@,``*H$
M```I````5`8``!4%``#U`0``-P0``"T'``#]````+P,``.@```"U`P``````
M```````0`0````````````#2!@```````%@&````````'0$``'4"```/`0``
M@P```$L"``#[````W`8``%X&```]````&P,``*X$````````U0,``'<&``#8
M!```OP4``(8!``"4`@``(@```"X'``#.!```6@(```````"H`P``6`0`````
M````````804```````"D!@``9@8```````"*`0``MP,``'`'``".`@``G@$`
M`-0#``"L`P``G`8``)@```!,`@``P`,``$T!``#[!0``/00``)P```#Y`P``
M>0$``'4&``!J`P``+0(``/8!``#N`````````-4"````````!`0```````!X
M!0``?`4````````L`0``&08```````#]`@``D08``/X&``"*`@``=````",'
M``!+!@````````X&``!%!0```````&8"``!9`@``.P<```````"3!@``N@4`
M`&H%```I!0``H````-T&``````````````````!-!P``C`,```\#```@!P``
M$P$``%D#``#L````(@,``#<```"@`@```````````````````````,,%``"!
M````[`4``!@'````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H
M:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI
M`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@
M=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(
M;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`
M(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S
M(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO
M="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@
M*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S
M=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@
M1FEN9V5R<')I;G0`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E
M;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U
M:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`
M)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`
M)7,G<R!487-K;&ES=``E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O
M;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A
M;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET
M:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T
M:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@
M+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R
M979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S
M`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET
M;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S
M=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD
M($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W
M($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T
M;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N
M97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`
M061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A
M9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`
M061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A
M9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T
M<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`
M06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`
M06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL
M;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E
M9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO
M9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S
M97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP
M;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@
M;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R
M;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P
M;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D
M>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@
M4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE
M(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_
M`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!
M<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@
M4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN
M=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U
M<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q
M=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I
M=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I
M<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D
M9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`
M075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I
M8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I
M96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K
M9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E
M<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U
M.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C
M=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M
M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B
M)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T
M:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R
M`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O
M=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II
M;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S
M<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R
M=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R
M;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L
M96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A
M<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES
M=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@
M=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA
M9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E
M(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T
M96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#
M:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN
M`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H
M;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A
M9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`
M0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L
M;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO
M<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@
M=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#
M;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO
M;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG
M=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N
M9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF
M:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E
M;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B
M`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE
M9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@
M9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD
M(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'
M4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I
M<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T
M(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@
M;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T
M(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3
M;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U
M;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG
M=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I
M=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E
M871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S
M:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R
M<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT
M('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I
M`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O
M:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?
M;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E
M($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L
M;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E
M('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E
M('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T
M("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O
M8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R
M(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I
M9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I
M;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F
M;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO
M="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S
M/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@
M4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N
M;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA
M:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@
M=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`
M161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E
M<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N
M<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S
M:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE
M;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M
M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E
M<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I
M=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q
M=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@
M8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O
M<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H
M:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E
M9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A
M9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`
M1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL
M960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&
M96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&
M97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&
M:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I
M;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S
M`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&
M;&EP`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&
M;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O
M<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T
M=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@
M;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C
M:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N
M92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R
M`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U
M:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O
M;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`
M1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N
M97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!'
M:79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P
M<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX
M.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N
M`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N
M86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S
M`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S
M`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R
M;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N
M80!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N
M`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L
M9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@
M36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X
M-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`
M2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD
M=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`
M2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L
M.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N
M>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(
M=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0
M($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)
M7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O
M<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S
M97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E
M(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A
M9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD
M:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO
M;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O
M;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!7
M96(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T
M97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R
M96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@
M96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE
M=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F
M;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`
M26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T
M('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W
M(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C
M=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO
M9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G
M97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV
M86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN
M=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N
M`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O
M9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N
M=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A
M9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R
M="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER
M96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES
M<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N
M97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S
M=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T
M`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY
M80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME
M<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y
M($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U
M8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?
M>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R
M`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,
M96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE
M861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N
M($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`
M3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,
M:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H
M="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;FL`3&EN:R!P;VEN=',@=&\Z
M`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W
M:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@
M5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES
M="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T
M+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE
M.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E
M=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG
M('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I
M;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-
M3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'
M`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI
M;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@
M<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L
M86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS
M=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F
M:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET
M+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M
M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T
M=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE
M<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE
M<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T
M:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#
M86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU
M;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES
M8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-
M:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K
M86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`
M36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L
M9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y
M96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD
M<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O
M8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L
M:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C
M8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R
M=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA
M;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT
M:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L
M(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R
M=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P
M92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI
M80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`3F5W
M(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D
M`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D
M<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G
M<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.
M:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL
M86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F
M;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G
M97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE
M(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D
M(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD
M<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U
M;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N
M`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N
M=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S
M970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S
M`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`
M3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F
M;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA
M;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@
M9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R
M=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB
M97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU
M;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE
M8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC
M90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L
M9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F
M;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN
M9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`
M3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T
M97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI
M<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!0
M14%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%
M;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A`%!(4"!#;V1E`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3
M:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T
M;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!0861D:6YG`%!A:VES
M=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N
M86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!0
M87-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O
M<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W
M;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!0
M87-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O
M<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@
M1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0
M:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E
M(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@
M96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)
M4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T
M:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@
M82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L
M96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET
M:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F
M<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U
M<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y
M`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@
M=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+
M97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@
M<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A
M<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S
M96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E
M<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2
M871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F
M<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I
M97<Z`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T
M92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M
M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T
M:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@
M=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@
M8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`
M4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T
M;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y
M<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@
M:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2
M;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A
M=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,('-T871E;65N="!F
M;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!380!386EN="!(96QE;F$`
M4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O
M;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B
M:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S
M(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%
M;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R
M;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R
M`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!3
M35,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT
M96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N
M`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO
M=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%
M87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR
M:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U
M<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA
M:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`
M4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@
M3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``
M4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R
M9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I
M;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S
M`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T
M92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D
M9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G
M(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B
M<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S
M(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN
M`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B
M`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E
M`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E
M.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA
M;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3
M=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YT87@@97)R
M;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O
M<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`
M5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T
M:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T
M86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS
M`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R
M871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O
M)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP
M;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M
M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED
M92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S
M92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L
M96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U
M9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M
M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET
M;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@
M268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY
M('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M
M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E
M9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F
M97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A
M=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R
M;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO
M="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F
M="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P
M87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E
M>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N
M`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@
M;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`
M5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H
M92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N
M=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER
M960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O
M;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K
M871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A
M;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I
M;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4
M:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O
M9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`
M5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N
M9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K
M:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O
M<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E
M>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R
M97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T
M;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L
M92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O
M;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@
M)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D
M*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@
M9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE
M('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H
M8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S
M="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A
M=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED
M960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@
M8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@
M9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H
M;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W
M('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5
M;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T
M92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5
M<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S
M92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O
M<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!2
M96=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L
M960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R
M;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`
M57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T
M=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I
M;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A
M9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E
M("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N
M80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E
M<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R
M86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE
M;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ
M`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I
M;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z
M(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D
M("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN
M9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`
M6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U
M,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M
M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S
M92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L
M;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H
M879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@
M9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@
M<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT
M<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@
M97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O
M9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E
M<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M
M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#
M3$D`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N
M<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@
M4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U
M;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL
M90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U
M<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E
M;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E;G1R>2!N
M;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,`9W5S=&EN9P!H.@!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YP
M=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S
M70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O
M<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W
M(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`<WES=&5M
M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N;F%M960`=7-E<B!S96QE8W0`
M=D-A<F0`=SH`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$*4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#8M,#(M,3<@,3`Z,#`K,#$P,`I03RU2979I<VEO;BU$
M871E.B`R,#`V+3`R+3$W(#$P.C,X*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!,
M87-Z;&\@3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS;W1E+FAU/@I,86YG
M=6%G92U496%M.B!(=6YG87)I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-
M24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]:7-O+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET"@`@*"5S(&YA<'!A;"!E>F5L]71T*0`@*$%L="UB:6QL96YT>?L@)7,I
M`"`H)7,@;F%P(&WZ;'9A*0`@*&UA*0`@*&AO;&YA<"D`("AT96=N87`I`"`Z
M(``B)7,B(&YE;2!A;&OV;GEV=.%R+@`B)7,B(&YE;2#I<G;I;GEE<R!VX6QA
M<WITX7,N`"(E<R(@;FEN8W,@:V]N9FEG=7+A;'9A(&$@2&]R9&4@4F5G:7-T
M<GEB96XN`"(E<R(@9F%S=')U:W3Z<F$M;65G:F5L96[M=/4@;F5M('1A;.%L
M:&%T\RX`(B5S(BUT(&AO>GKA861T=6L@82!C<V]P;W)T;VMH;WHN`"(E<R(M
M="!H;WIZX6%D='5K(&$@:F]G;W-U;'1SX6=I(')E;F1S>F5R:&5Z+@`B)7,B
M+70@;F5M(&AO>G1U:R!LZ71R93H@)7,N`"4N,F9-0B!F96QH87-Z;N%L="!A
M("4N,F9-0B!M96=E;F=E9&5T=&+U;"`H)2XR9B4E*0`E9"`E<R#I<R`E<P`E
M9"!N87`@;?IL=F$@;&5JX7(@:F5L<WIA=N%N86L@Z7)VZ6YY97-SZ6=E+@`E
M9"!N87!O<R!E;/5R96IE;'KI<P`E<R`M($9I9WEE;&UE>G1E=.ES`"5S(&QE
M;GEO;6%T`"5S(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K("T@;65G97+U<^UT
MZ7,`)7,@8F7A;&SM=.%S`"5S(&QO9VEN(&[I=B!I9^EN>6SI<P`E<R!S>F]L
M9^%L=&%TX7-I(&9E;'3I=&5L96L`02`B)7,B(&YE=OL@X6QL;VWA;GD@;>%R
M(&SI=&5Z:6LN`"5S(#H@)7,@)7,`02AZ*2`E<R!KZ7-Z96X@X6QL(&%Z(&%L
MX6)B:2!K87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<^ER92Y*96SV
M;&IE(&MI(&%Z;VMA="!A(&9E;&%D871O*&MA*70L(&%M:2AK92ET(&UO<W0@
M96P@:^UVX6X@=NEG97IN:2X`)7,@:VET]FQTZ7-E('-Z_&MSZ6=E<P`E<R!P
M97)C`"5S(&YE;2!T86SA;&AA=/,N`"5S("T@)7,@*/9S<WIE<V5N("5S*0`E
M<R!C[6UJ96=Y>NEK90`E<R!N87!TX7)A`"5S(&9E;&IE9WEZZ7-E:0`E<R!F
M96QA9&%T;&ES=.%J80`E<SH@3&5H971SZ6=E<RP@:&]G>2!E>B!A(&QE=NEL
M('9A;/-JX6)A;B!N96T@82!M96=A9&]T="!F96QA9/-T\VP@<WKA<FUA>FEK
M+B!';VYD;VQJ82!M96<L(&UI96SU='0@<N%K871T:6YT('9A;&%M:7)E+"!V
M86=Y('-Z96WI;'EE<R!I;F9O<FWA8VGS="!A9"!M96<N`"P@<WKI;&SV:^ES
M96L`+"`E<R`E<RUS('-ZZ6QL]FOI<V5K`"P@=N%L=&]Z\R`E<R#I<R`E<R!K
M]GKV='0`+2T@=N%L87-S>F]N("TM`#$R(/-RX7,@9F]R;>%T=6T`,C0@\W+A
M<R!F;W)MX71U;0`R-"#S<F$`/$5L]7KU`$5Z96X@8FQO:VL@:&%S>F[A;&%T
MX6AO>B!E9WD@861A=&+A>FES(&%L<F5N9'-Z97(@<WK\:W/I9V5S+@!(96QY
M<F5H;WIH871A=&QA;B!H:6)A('3V<G3I;G0`02!L97;I;"!T:71K;W/M=.%S
MX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<R!S>OQK<^EG97,N`$$@9&EG
M:73A;&ES86X@86SA[7)T(&QE=NEL(&5L;&5N]7)ZZ7/I:&5Z(&5G>2!N>6EL
M=N%N;W,@4$=0(&MU;&-S('-Z_&MSZ6=E<RX`02!T:71K;W/M=&]T="!L97;I
M;"!D96OS9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S+"!E9WD@
M=&ET:V]S(%!'4"!K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z_&MSZ6=E<RX`
M02!L97;I;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y(&YY:6QVX6YO<R!0
M1U`@:W5L8W,L(&5G>2!T:71K;W,@4$=0(&MU;&-S(.ES(&5G>2!J96QM;VYD
M870@<WK\:W/I9V5S+@!!('1I=&MO<^UT;W1T(&QE=NEL(&1E:_-D;VSA<^%H
M;WH@96=Y(&YY:6QVX6YO<R!3+TU)344@:W5L8W,L(&5G>2!T:71K;W,@4R]-
M24U%(&MU;&-S(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+@!!(&QE=NEL
M(&1I9VETX6QI<R!A;.'M<N%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K
M=6QC<RP@96=Y('1I=&MO<R!3+TU)344@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A
M="!S>OQK<^EG97,N`$$@;&5VZ6P@=&ET:V]S[73A<^%H;WH@96=Y(&YY:6QV
MX6YO<R!3+TU)344@:W5L8W,@<WK\:W/I9V5S+@!$Z6QE;/5T="!B;W)U;'0@
MZ6<`1.EL96SU='0@9WEE;F=E(&5S]0!$Z6QE;/5T="!E<_4`1.EL96SU='1I
M('KA<&]R;VL`1.EL96SU='0@:/-ZX7!O<F]K`&1E+V1U`$%022!)1"`H82!P
M<F]G<F%M;WKA<VD@9F5L_&QE="!A>F]N;W/M=/-J82D`17)R]6P@87H@961I
M=&]R<O-L`$[I=FIE9WDN+BX`86)S>B!A;'5L`&%B<WH@:_9ZZ7``3FEN8W,@
M:F]G;W-U;'1SX6=A(&$@5D93(&%L:_9N>79TX7(@;.ET<F5H;WKA<^%H;WHN
M`$YI;F-S(&IO9V]S=6QT<^%G82!A(%9&4R!FX6IL(&SI=')E:&]ZX7/A:&]Z
M+@!"96IE;&5N=&ME>NES:2!I;F9O<FWA8VGS`$IE;'-Z\P!!(&IO9V]S=6QT
M<^%G(&9E;"!V86X@9OQG9V5S>G1V92X`4.EN>OQG>65K`$)E=FET96P`06QC
M<V]P;W)T(&SI=')E:&]ZX7-A`$IO9V]S=6QT<^%G:2!A;&-S;W!O<G0@;.ET
M<F5H;WKA<V$`061D:G5K(&AO>GKA(&ET=#H`VFH@8W-O<&]R="!LZ71R96AO
M>N%S80#::B!J;V=O<W5L='/A9R!LZ71R96AO>N%S80!!;&-S;W!O<G0@:&]Z
M>N%A9.%S82`B)7,B+6AE>@!*;V=O<W5L='/A9VD@86QC<V]P;W)T(&AO>GKA
M863A<V$@(B5S(BUH97H`VFH@9F5L:&%S>F[A;/,@;.ET<F5H;WKA<V$Z`-IJ
M(&]S>FQO<"!H;WIZX6%DX7-A`-IJ('1A9V]K(&9E;';I=&5L90#::B!PX7(@
M:&]Z>N%A9.%S80!!*'HI("5S(&UE;OQT(&%D:G5K(&AO>GKA(&$@36]Z:6QL
M82!M96[\<V]R:&]Z`$%D:G5K(&AO>GKA(&$@8^UM:F5G>7KI:VAE>CH`061J
M=6L@:&]Z>N$@82!C[6UJ96=Y>NEK96UH97H`VFH@9F5L:&%S>F[A;/,@:&]Z
M>N%A9.%S80`B)7,B(&9E;&AA<WINX6SS="!H;WIZX6%D='5K(&$@<F5N9'-Z
M97)H97HL(&1E(&YE;2!S:6ME<OQL="!A('3V8F)I(&)E:F5L96YT:V5ZZ7-I
M(&%D870@=.%R;VSA<V$Z("5S+@`B)7,B(&9E;&AA<WINX6SS="!F96QV971T
MZ6L@82!R96YD<WIE<F)E+B!-;W-T(&WA<B!B96IE;&5N=&ME>FAE="X`02!R
M96YD<WIE<FAE>B!N96T@861H873S:R!H;WIZX2#Z:B!F96QH87-Z;N%L\VLN
M`$/M;0!#[6UJ96=Y>NEK`$%D;6EN:7-Z='+A8VGS("T@:F]G;W-U;'1SX6=O
M:R!A9.%S82!T;W;A8F)I(&9E;&AA<WINX6SS:VYA:P!!9&UI;FES>G1RX6-I
M\P!(:7)D973I<V5K`$%F9V%N:7-Z=.%N`$%L8N%N:6$`06QGZ7)I80!!;&EA
M<P!%;&AE;'EE>NES`%)E;F1E>NES.@!A>B#V<W-Z97-E=`!-:6YD96X@;F5M
M('9E;F3I9R!F96QH87-Z;N%L\P!-:6YD96X@8W-O<&]R=`!-:6YD96X@:F]G
M;W-U;'1SX6<`36EN9"!A(&[I9WD@;VQD86QO;B!L96=Y96X@:V5R970`16YG
M961J_&YK(&UE9R!T]F)B(&/M;65T(&ES`$$@<V]R<WKA;6]S(&9E;'-O<F]L
MX7,@=.UP=7-A(';A;'1O>G1A=&AA=/,@;&5G>65N/P!-X7(@;.ET97II:P!)
M35-0(&)E:F5L96YT:V5ZZ7-I('!A<F%MZ71E<F5K`$WA<VEK+"!)35-0(&IE
M;'-Z\P!-X7-I:RP@24U34"!B96IE;&5N=&ME>NES:2!NZ78`3>%S:6L@96UA
M:6P@8^UM`$%L=&5R;F%T[78@<V%B;&]N;VL`06QT97)N873M=B!S>O9V96<Z
M`$%M97)I:V%I(%-Z86UO80!!(&UE9V%D;W1T(.ER=.EK(&YE;2!F;V=A9&AA
M=/,@96PN`$ES;65R971L96X@:&EB82!T]G)TZ6YT+@!!;F1O<G)A`$%N9V]L
M80!!;F=U:6QL80!!;F]N:6T@<')O>'EN(&ME<F5S>G3\;&D@:6YT97)N970@
M96SI<NES`%;A;&%S>@!!;G1A<FMT:7-Z`$%N=&EG=6$@Z7,@0F%R8G5D80!!
M;&MA;&UA>N%S`$%L:V%L;6%ZX7-O:R!L:7-TX6IA`$%Z(&%L:V%L;6%ZX7,@
M:^ES>BX`02!K]GKV<R!TX7)T97+\;&5T(&%L8W-O<&]R=&IA:7)A(&ES(.ER
M=NEN>65S`$KS=N%H86=YX7,`2_9R_&QB96S\;&D@;>ER970`X7!R:6QI<P!A
M<F%B("A7:6YD;W=S+3$R-38I`$$@=/9M]G+M=&5T="#A;&QO;>%N>2!MZ7)E
M=&4`02!T]FWV<NUT971T(.%L;&]MX6YY(&YE=F4`0FEZ=&]S(&)E;FYE+"!H
M;V=Y('3V<O9L;FD@:^UVX6YJ82`E<R!B96IE;&5N=&ME>NES:2!I9^EN>>ET
M/P!":7IT;W,L(&AO9WD@=/9R]FQN:2!A:V%R:F$@(B5S(BUT(&%L8W-O<&]R
M=&IA:79A;"!E9WG\='0_`$%R9V5N=.UN80#6<FWI;GEO<G-ZX6<`]G)MZ6YY
M("A!4DU30TE)+3@I`$W[=NES>F5T`$%R=6)A`%!O:&YP96D`07-C:6D@<F%J
M>F]K`,%Z<VEA+T-S96YD97,M\V-EX6YI('+I9VGS`$OI<FIE;B!A(')E;F1S
M>F5R(&UE9V5R]7/M=.ES="!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K(&5L
M=NEG>NES92!E;/5T=#\`2&]Z>N%R96YD96SI<VD@;W-Z;&]P;VL`3F5M;.ET
M97KU(&-S;W!O<G1O="!K[7/I<F5L="!M96<@=/9R]FQN:2X`3F5M;.ET97KU
M(&IO9V]S=6QT<^%G;W0@:^USZ7)E;'0@;65G('3V<O9L;FDN`$YE;6SI=&5Z
M]2!J;V=O<W5L='/A9V]T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT871N:2X`
M3F5M;.ET97KU(&OV>O9S('3A<G1E<OQL971E="!K[7/I<F5L="!M96<@;65G
M=N%L=&]Z=&%T;FDN`%1U;&%J9&]N<^%G;VL`875G=7-Z='5S`$%U<WIT<N%L
M:6$`075S>G1R:6$`075T:%]C>7)S<6PZ(&$@<WK\:W/I9V5S(&EM87`@8O5V
M[73I<R!N96T@=&%LX6QH873S+@!!=71H7V-Y<G5S.B!A(&CA='3I<G-Z;VQG
MX6QT873A<R!N96T@<F5N9&5L:V5Z:6L@82!K[7;A;G0@:^EP97-SZ6=E:VME
M;"X`075T:%]C>7)U<SH@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T
M86SA;&AA=/,N`$%U=&A?9G1P.B!A('-Z_&MSZ6=E<R!F='`@8O5V[73I<R!N
M96T@=&%LX6QH873S+B!&;W)D[71S82!L92!A(%!(4"UT(&%Z("TM96YA8FQE
M+69T<"!O<&-I\W9A;"X`075T:%]I;6%P.B!A('-Z_&MSZ6=E<R!I;6%P(&+U
M=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]K<F(U.B!A('-Z_&MSZ6=E<R!K
M<F(U(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]L9&%P.B!N96T@:&]Z
M:&%T\VL@;.ET<F4@^FH@9F5L:&%S>F[A;/-K($%C=&EV92!$:7)E8W1O<GD@
M97-E=.EN`$%U=&A?;&1A<#H@9F5L:&%S>F[A;/-K(&YE;2!T]G+V;&AE=/5K
M($%C=&EV92!$:7)E8W1O<GD@97-E=.EN`$%U=&A?;&1A<#H@82!S>OQK<^EG
M97,@3$1!4"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?;&1A<#H@)7,@
M9F5L:&%S>F[A;/,@:&]Z>N%A9.%S82!N96T@<VEK97+\;'0N($$@<WIE<G9E
M<B!VX6QA<WIA.B``075T:%]L9&%P.B`E<R!F96QH87-Z;N%L\R!T]G)LZ7-E
M(&YE;2!S:6ME<OQL=`!!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS(&%D871A
M:6YA:R!M96?Z:NUTX7-A(&YE;2!S:6ME<OQL=`!!=71H7VQD87`Z(&$@9F5L
M:&%S>F[A;/-K(&YE;2!M\V1O<^UT:&%T\VL@06-T:79E($1I<F5C=&]R>2!E
M<V5TZ6X`075T:%]M8V%L.B!A('-Z_&MSZ6=E<R!-0T%,(&+U=NUTZ7,@;F5M
M('1A;.%L:&%T\RX`075T:%]S;6)A=71H.B!A('-Z_&MSZ6=E<R!S;6)A=71H
M(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`3F5M('-I:V5R_&QT(&%Z($E-05`@
M<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S+@!!(&9E;&AA
M<WINX6SS87IO;F]S[73A<R!N96T@<VEK97+\;'0N`$$@9F5L:&%S>F[A;/-A
M>F]N;W/M=.%S(&YE;2!S:6ME<OQL="X@)7,`02!F96QH87-Z;N%L\R!A>F]N
M;W/M=.%SX70@82!2041)55,@<WIE<G9E<B!E;'5T87/M=&]T=&$N`$YE;2!S
M:6ME<OQL="!A>B!&5%`@<WIE<G9E<FAE>B!V86SS(&9E;&AA<WINX6SS87IO
M;F]S[73A<RX`3F5M('-I:V5R_&QT(&%Z(%--0B!S>F5R=F5R96X@=F%L\R!F
M96QH87-Z;N%L\V%Z;VYO<^UTX7,N`$$@<F5N9&5L:V5ZZ7-R92#A;&SS(&UE
M>O5K.@!!>F5R8F%J9'ISX6X`02!G;VYO<WH@<F5N9'-Z97)G87ID82!M96YT
M<^EG96D`2.%T=.ER`$CA='3I<B!S>NUN`$YE;2!M96=F96QE;/4@:V5R8F5R
M;W,@:F5L<WKS+@!.96T@;65G9F5L96SU(&ME<F)E<F]S(&9E;&AA<WINX6SS
M;NEV+@!"86AA;>%K`$)A:')E:6X`8F%L=&D@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97,`0F%R8F%D;W,`02!G<F%F:6MU<R#A;&QO;>%N>6]K("(E<R(@86QK
M]FYY=G3A<F$@;F5M('1A;.%L:&%T\RX`86QA<'9O;F%L;VX`1F5HZ7)O<F]S
M>F]R<WKA9P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=73A;@!3
M>OQL973I<VYA<`!!("(E<R(@8FQO:VL@82`B)7,B('!R;V=R86UM86P@;F5M
M('1A;.%L:&%T\RX`2^EP97)N>?5RZ7-Z(&)EX6QL[73A<P!+Z7!E<FYY]7+I
M<WH@=.UP=7,`9NEL:_9VZ7(`0F]L[79I80!+961V96YC('=E8F/M;65K`$ME
M<F5T`$ME<F5T=F%S=&%G<^%G.@!+97)E=&5K`$)O<WIN:6$M2&5R8V5G;W9I
M;F$`36EN9&ME='3U`$)O='-W86YA`&%L=6P`0F]U=F5T+7-Z:6=E=`!"<F%Z
M[6QI80!"<FET($EN9&EA:2WS8V7A;FD@5&5R_&QE=`!"<G5N96D@1&%R=7-S
M86QA;0!"=6QGX7)I80!&96QS;W)O;.%S`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`%=E8F]L9&%L(&MA<F)A;G1A<G3A<P!#4D,`02!T86[Z<^UT=N%N>79I<W-Z
M879O;N%S:2!L:7-TX6L@*$-23"D@8^UM96D`0V5L;&$@='5L86ID;VYSX6=O
M:P!!(&-A8VAE(&EN:6-I86QI>N%LX7-A(&YE;2!F96IE>O5D]G1T(&)E+@!.
M87!TX7(`3GEU9V]D=`!+86UB;V1Z<V$`2V%M97)U;@!.96T@<VEK97+\;'0@
M82!J96QS>O-T(.%TX6QL[71A;FDL(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z
M9.%H;WHN`$$H>BD@(B5S(B#A;&QO;>%N>2!N96T@[7)H873S+@!!(&O\;'/U
M(&9E;&AA<WINX6SS:V%P8W-O;&%T+6ME>F5L]6L@;F5M(&%D;6EN:7-Z='+A
M;&AA=/-K+@!!(&OV=F5T:V5Z]2!)34%0('-Z97)V97(@;F5M(.ER:&5T]2!E
M;#H@)7,`02AZ*2`B)7,B(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<N`$MA
M;F%D80!-Z6=S90!-Z6=S92!K_&QD]FL@:&EB86IE;&5N=.ES=`!!*'HI("(E
M<R(@X6QL;VWA;GD@;F5M('3V<O9L:&5T]2X`3F5M('1A;.%L:&%T\R!A>B!I
M9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7(N
M`$$@)W1A<F=E=$9I;&4G('!A<F%MZ71E<B!M96=A9.%S82!NZ6QK_&P@;F5M
M(&9O;'ET871H871J=6LN`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T]G+V
M;&AE=/4N`$YE;2!T]G+V;&AE=/4L("5D(&%L8W-O<&]R=&IA('9A;BX`07H@
M^FH@<V]R8F%R96YD97KI<R!N96T@;&5H971SZ6=E<RP@82!M96=A9&]T="!A
M9&%T;VL@<WKA;6$@;F5M(&5G>65Z:6L@82!TX7)O;'1A:^EV86PN`$$@;65G
M861O='0@<WKA;7)A(&YE;2!K_&QD:&5T]2!E;"!A>B#\>F5N970N`%KV;&0M
M9F]K:2US>FEG971E:P#!8G)A<WKV=F5G`%-Z;VQGX6QT873S`$MA=&5G\W)I
MX6L@Z7,@:F5L]FSI<_QK`$MA:FWA;BUS>FEG971E:P!-;V)I;"!T96QE9F]N
M`$-E;&QA='5L86ID;VYSX6=O:P!#96QL82!B96QS]2!M87)G\SH`0V5L;&%T
M=6QA:F1O;G/A9V]K`$-E;&SA:R!K]GKV='1I('+I<SH`36]B:6P@=&5L969O
M;@!K96QT82`H25-/+3@X-3DM,30I`&OV>NEP`$OV>NEP+6%F<FEK86D@2_9Z
M=.%R<V%SX6<`:V5L970M975R\W!A:2`H25-/+3@X-3DM,BD`02!T86[Z<^UT
M=N%N>2!RZ7-Z;&5T96D`02!T86[Z<^UT=N%N>2!T=6QA:F1O;F]S80!486[Z
M<^UT=N%N>2!F96QH87-Z;N%LX7-I(&ERX6YY96QV96L`0W/A9`!6X6QT;WIT
M873A<P!!(&IE;'-Z\R#A=.%L;.UTX7-A`$%Z(-9N(.%L=&%L(&5L:_QL9/9T
M="!L979E;&5K96X@<WIE<F5P;/4@;NEV(.ES(&/M;2!M96=VX6QT;WIT873A
M<V$N`$$@:F5L96X@:V]N9FEG=7+A8VGS8F%N(&YE;2!L96AE='/I9V5S(&$@
M:F5L<WIA=F%K(&WS9&]S[73A<V$N($9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z
M9.%H;WHN`$MA<F%K=&5R`$QI;E]K96QL96[U<GKI<RXN+@!#:&EL90!+[6YA
M`&OM;F%I+"!E9WES>F5R^W/M=&5T="`H1T(R,S$R*0!K[6YA:2P@:&%G>6]M
MX6YY;W,@*$)I9S4I`%;A;&%S<WIO;B!K:2!E9WD@86QK86QM87KA<W0Z`%;A
M;&%S<WIO;B!J96QS>O-T`%;A;&%S<WIO;B!E9WD@9F5L:&%S>F[A;/-N979E
M=`!6X6QA<W-Z82!K:2!A(&3A='5M;VL@;65G:F5L96[M=.ES:2!F;W)MX6KA
M=#H`5N%L87-S>F$@:VD@82!F96QS;W)O;.%S('3M<'5SX70@*'-ZX6UO>F]T
M="!L:7-TX6MNX6PI`$MA<N%C<V]N>2US>FEG971E:P!!*'HI("5S(&-L87-S
M(&1E9FEN[6-I\VIA(&YE;2!T86SA;&AA=/,N`$1E<OQL=`!4]G)L:2!A>B!-
M4T]F9FEC92!T86=E:V5T`$$@;&5KZ7)D97KI<R!T]G)LZ7-E`"5S(&9E;&AA
M<WINX6SS('3V<FSI<V4`02!F96QH87-Z;N%L\R!T]G)LZ7-E`$$@9F5L:&%S
M>F[A;/,@861A=&%I;F%K('3V<FSI<V4`17-TZ7)E(&1E<OQL="#I9P!!(&9O
M;'ET873A<VAO>B!K871T:6YT<V]N(&%Z(&5GZ7)R96P`0VQI8VMA=&5L;"!S
M>F]L9^%L=&%TX7,@2%144"UN(&ME<F5S>G3\;`!!>B!A8FQA:R!B97KA<N%S
M80!";W)U;'0@Z6<`4F5G9V5L(&9E;&CU<R!I9/4`1F5L:/5S(&ED]0!+\VMU
M<WHM<WII9V5T96L`5/QN=&5S<_QK(&5L(&%Z(&]L9&%L<_,@;65N_'0`UG-S
M>F5ZX7)T(&ME<F5T96L`2V]L=6UB:6$`4WKM;@!3>NUN=N%L87-Z=/,`4WKM
M;G;A;&%S>G3A<P!/<WIL;W!O:SH`07H@;W-Z;&]P;VL@8^UM96D`5FEC8V5K
M`%!A<F%N8W,`4&%R86YC<^ER=&5L;65Z]0!-96=J96=Y>NES`$[I=BP@96QN
M979E>NES`$-O;6]R92US>FEG971E:P!#Z6<`4WKA;>UT\V?I<&5K`$ED]6KA
M<N%S:2!H96QY>F5T`$ED]6KA<N%S:2!H96QY>F5T`$O\;/9N8G/I9V5K(&$@
M:V]N9FEG=7+A8VGS8F%N`$OI>FES>N%M[73S9^EP96MK96PL(&]K;W-T96QE
M9F]N;VMK86PL($]U=&QO;VMK86P@=F%L\R!A9&%T<WII;FMR;VYI>N%LX7,@
M:V]N9FEG=7+A8VGS:F$`02!K;VYF:6=U<N%C:?,@;>%R(&YE;2#I<G;I;GEE
M<RX`)7,@:V]N9FEG=7+A8VGS:F$`02!J96QS>O,@;65G97+U<^UTZ7-E`$MO
M;F?S`$MO;F?S:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<`4VEK97)T96QE
M;B!A(&MA<&-S;VQA="X`4VEK97)T96QE;B!A(&MA<&-S;VQA=#H@`$$@;GEI
M;';A;F]S(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA
M=&]T+@!!(&YY:6QVX6YO<R!K=6QC<V]K('-Z97)V97)E(&5L=71A<^UT:F$@
M82!K87!C<V]L871O="X@3VMA.B`E<R`H)7,I`%-I:V5R=&5L96X@87H@1E10
M('-Z97)V97)R96P@=F%L\R!K87!C<V]L870N`%!A<G1N97)E:P!!('!A<G1N
M97)E:V5T('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI:^EH97HN
M`$$@=/9M]G+M=&5T="#A;&QO;>%N>2!T[7!U<V$Z(``B)7,B('1A<G1A;&UA
M`$9O;'ET873A<P!#;V]K+7-Z:6=E=&5K`%/\=&D`3>%S;VQJ=6L@X70`02!M
MX7-O;.%S(&YE;2!S:6ME<OQL=#H@)7,`02!K:6IE;/9L="!RZ7-Z(&WA<V]L
MX7-A`%-ZX6ULX7KA<VD@87IO;F]S[73S`$-O<W1A(%)I8V$`16QE9N%N=&-S
M;VYT<&%R=`!.96T@<VEK97+\;'0@4$=0+79E;"!T:71K;W/M=&%N:2!A(&QE
M=F5L970Z(`!!(&QE=F5L970@;F5M('-I:V5R_&QT(%!'4"!A;.'M<N%S<V%L
M(&5L;.%T;FDZ(`!!(&QE=F5L970@;F5M('-I:V5R_&QT(&%Z(%,O34E-12!S
M>F%B=N%N>2!S>F5R:6YT('1I=&MO<^UT86YI+@!!(&QE=F5L970@;F5M('-I
M:V5R_&QT(%,O34E-12!A;.'M<N%S<V%L(&5L;.%T;FDN`$$@<&%R=&YE<B!A
M9&%T86ET(&YE;2!S:6ME<OQL="!E;'3A<F]L;FDN("5S`$%Z($Q$05`@<WIE
M<G9E<B!N96T@Z7)H973U(&5L+@!.96T@<VEK97+\;'0@96QL96[U<FEZ;FD@
M82!S>N%M;.%JX6X@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9V5T+B`E<P!.
M96T@<VEK97+\;'0@87H@3$1!4"!S>F5R=F5R:&5Z(&MA<&-S;VSS9&YI+@!.
M96T@<VEK97+\;'0@82AZ*2`B)7,B('-Z97)V97)R96P@1E10(&MA<&-S;VQA
M=&]T(&9E;'9E;FYI.B`E<P!.96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(&OV
M<FQE=NEL;&ES=.%T+B`E<P!!>B!A9&%T;VL@4$=0('1I=&MO<^UTX7-B\VP@
M=/9R=.EN]2!D96OS9&]LX7-A(&YE;2!S:6ME<OQL=#H@`$%Z(&%D871O:R!3
M+TU)344@=&ET:V]S[73A<V+S;"!T]G)TZ6[U(&1E:_-D;VSA<V$@;F5M('-I
M:V5R_&QT+@!!('!A<G1N97(@=/9R;.ES92!N96T@<VEK97+\;'0N("5S`$$@
M:_9R;&5VZ6QL:7-T82!T]G)LZ7-E(&YE;2!S:6ME<OQL="X@)7,`3F5M('-I
M:V5R_&QT('3V<O9L;FD@82AZ*2`B)7,B('-E='5P('5P9W)A9&4@<')O9W)A
M;6]T+@!.96T@<VEK97+\;'0@;65GX6QL87#M=&%N:2!A(&/M;7IE='0@96UA
M:6P@8^UMZ70N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@8^UM
M:F5G>7KI:V5T+@!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@=&5L:F5S(&OV
M<FQE=NEL;&ES=.%T+@!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5V
MZ6QL:7-TX6L@=&5L:F5S(&9E;'-O<F]LX7/A="X`02AZ*2`B)7,B('-T<F%T
MZ6=I82!N96T@=&%LX6QH873S+@!!*'HI("(E<R(@86QK]FYY=G3A<B!N96T@
M:&]Z:&%T\R!LZ71R92X`02!N>6EL=N%N;W,@:W5L8W-O="!N96T@<VEK97+\
M;'0@;65G<WIE<F5Z;FD@82!K=6QC<W-Z97)V97)R]6PN`$YE;2!S:6ME<OQL
M="`B)7,B+70@[7+A<VD@8^EL;&%L(&UE9VYY:71N:2X`3F5M('-I:V5R_&QT
M("5S+70@;65G;GEI=&YI+@!!("5S(&MA<F)A;G1A<G3A<VD@;6]D=6P@;F5M
M(&YY:71H873S(&UE9P!!*'HI("(E<R(@86QK]FYY=G3A<B!N96T@;GEI=&AA
M=/,@;65G+@!!>B!,1$%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`)7,@;F5M
M(&]L=F%S:&%T\RX`3F5M('-I:V5R_&QT(&$@:^UVX6YT(&9E;&AA<WINX6SS
M(&IE;'-Z87;A="#A=.%L;.UT86YI+B!!>B!M96=A9&]T="!A9&%T;VL@;F5M
M('9A9WD@;F5M('1E;&IE<V5N(&9E;&5L;F5K(&UE9RX@4'+S8N%L:F$@^FIR
M82P@=F%G>2!H82!T;W;A8F)I('-E9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+"!F
M;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+@!.96T@<VEK97+\;'0@;65G
M:&%TX7)O>FYI(&%Z(&5LZ7+I<VD@:F]G;W-U;'1SX6=O:V%T("A!0TPI`$YE
M;2!S:6ME<OQL="!B96]L=F%S;FD@82!C[6UJ96=Y>NEK970N("5S`$YE;2!S
M:6ME<OQL="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A="X@)7,`3F5M('-I
M:V5R_&QT(&)E;VQV87-N:2!A(&OV<FQE=NEL;&ES=.%K870N("5S`$YE;2!S
M:6ME<OQL="!M96=H873A<F]Z;FD@82!S>F5R=F5R(&OI<&5S<^EG96ET`$YE
M;2!S:6ME<OQL="!V:7-S>F'A;&SM=&%N:2!E>B!E<F5D971I(&MO;F9I9W5R
MX6-I\W0N`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N`$YE
M;2!S:6ME<OQL="!E;&UE;G1E;FD@)7,@:V]N9FEG=7+A8VGS="X`3F5M('-I
M:V5R_&QT(&5L;65N=&5N:2!A(&)A8VMU<"!K;VYF:6=U<N%C:?-T+@!.96T@
M<VEK97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I\W0Z("5S
M`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82AZ*2`B)7,B('-E='5P('5P9W)A
M9&4@<')O9W)A;6]T+@!.96T@<VEK97+\;'0@96QM96YT96YI(&$H>BD@)7,@
M8F%C:W5P(&MO;F9I9W5RX6-I\W0N`$$H>BD@)7,@:V]N9FEG=7+A8VGS<R#A
M;&QO;>%N>70@;F5M('-I:V5R_&QT(&5L;65N=&5N:2X@5F%G>2!H87-Z;N%L
M:F$@82`E<R!O;&1A;&]N(&QE=O4@;&5H973U<^EG96ME="P@=F%G>2!MX7-O
M;&IA(.%T(&%Z(&%LX6)B:2!K\V1O="!I9&4Z("5S+@!!>B!,1$%0('-Z97)V
M97)E;B!N96T@<VEK97+\;'0@96QVZ6=E>FYI(&$@:V5R97/I<W0N`"(E<R(@
M;F5M('9O;'0@=/9R]FQH973U+@!!('!A<G1N97(@861A=&%I="!N96T@<VEK
M97+\;'0@;?-D;W/M=&%N:2X@)7,`3F5M('-I:V5R_&QT(&$@:_9R;&5VZ6QL
M:7-T82!M\V1O<^UTX7-A+B`E<P!.96T@<VEK97+\;'0@96QM96YT96YI("(E
M<R(@:V]N9FEG=7+A8VGS:N%T.B`E<P!!($UO>FEL;&$@;65N_'-O<B!N96T@
M=&%LX6QH873S+B!%;&QE;O5R:7IZ92P@:&]G>2!M96<@=F%N+64@;GEI='9A
M+@!.96T@<VEK97+\;'0@(B5S(B!F96QH87-Z;N%L\VYA:R!J;V=O<W5L='/A
M9V]T(&%D;FD@82AZ*2`B)7,B(&UA<'#A:&]Z.B`E<P!+;W)LX71O<R!S>O9V
M96<`3W)S>N%G`%3A=F]K=&%TX7,`3.ET<F5H;WKA<P!,:6YK(&SI=')E:&]Z
MX7-A`-IJ(&SI=')E:&]ZX7-A`$%L;6%P<.%K(&SI=')E:&]ZX7-A`$%Z(&]B
M:F5K='5M(&SI=')E:&]Z\VKA;F%K(&IO9V]S=6QT<^%G86D`2&ET96QKX7)T
M>6%S>N%M`$AO<G;A=&]R<WKA9P!+=6)A`$IE;&5N;&5G:2`T(&;A>FES`$$@
M:F5L96YL96=I(&9E;&AA<WINX6SS:V%P8W-O;&%T;VL`4&]N=&]S(&ED]0!!
M(&IE;&5N;&5G:2!54DP`2F5L96YL96=I(&9E;&AA<WINX6SS:P!*96QE;FQE
M9VD@:63U:N%RX7,`02!J96QE;FQE9VD@:63U:N%RX7-I(&AE;'EZ970Z`$IE
M;&5N;&5G:2!S=.UL=7,`36EL>65N('!A<F%N8W-O:R!F=7-S86YA:R!L92!A
M=71O;6%T:6MU<V%N(&$@)7-B92!T]G)TZ6[U(&)E:F5L96YT:V5ZZ7-K;W(N
M`$MI=N%GX7,`02!K:6IE;/9L="!RZ7-Z(&MI=N%GX7-A`$-I<')U<P!C:7)I
M;&P@*$M/23@M4BD`8VER:6QL("A7:6YD;W=S+3$R-3$I`&-I<FEL;"UU:W+A
M;B`H2T])."U5*0!#<V5H($OV>G3A<G-A<^%G`$1$`$133B`H861A=&9O<G+A
M<VQE[7+S("T@;.%S9#H@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!N87!O;G1A`$1A
M=&%4<F5E(&+V;F?I<WKU`$%D871BX7II<V)A;B!V86SS(&ME<F5SZ7,`1.%T
M=6T`02!B9>ER:V5ZZ7,@;F%P:F$`1.%T=6T@:VEVX6QA<WITX7-A`&YA<'!A
M;`!/<WIL;W`@=/9R;.ES90!D96-E;6)E<@!S>N%M;VL`0F5K97IDZ7,@:VEJ
M:F5B8@!!;&%PZ7)T96QM97IE='0`07H@86QA<.ER=&5L;65ZZ7,@<WIE<FEN
M=&D@<WKM;@!!;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/,`06QA
M<.ER=&5L;65Z971T('-H96QL`$1E9FEN[6-I\VL`5/9R;.ES`$$@8V5L;&$@
M=/9R;.ES90!!(&-S;W!O<G0@=/9R;.ES90!!(&YA<&SSX6QL;VWA;GD@=/9R
M;.ES90!!(&IO9V]S=6QT<^%G('3V<FSI<V4`3&5V96QE:R!T]G)LZ7-E`$$@
M8V5L;&$@=/9R;.ES90!!>B!O<WIL;W`@=/9R;.ES90!4]G+V;&K\:R!K:2!A
M(&UE9VSI=O4@86QT97)N873M=B!S86)L;VYT`$$@;&5V96QE:R!T]G)LZ7-E
M`"(E<R(@:F]G;W-U;'1SX6=A:6YA:R!T]G)LZ7-E`%3V<O9L:OQK("(E<R(@
M:F]G;W-U;'1SX6=A:70@Z7,@96YN96L@97-E=&QE9V5S(&%L8W-O<&]R=&IA
M:70_`$$@<V]R('3V<FSI<V4`02!K:7;A;&%S>G1O='0@87IO;F]S[73S('3V
M<FSI<V4`07H@86QM87!PX6L@=/9R;.ES90!!(&IE;&5N;&5G:2!O<WIL;W`@
M=/9R;.ES90!!(&IE;&5N;&5G:2!S;W(@=/9R;.ES90!4]G+V;'3\:R!A*'HI
M("(E<R(@<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N`$$@:^EZ8F5S[73I<R!I
M9&5J90!$X6YI80!!9&IO;B!L9>URX7-T(&$@<')O8FSI;>%R\VP`3&7M<N%S
M`%+I<WIL971E:R`H82!(;W)D92!L;V=FX6IL8F%N(&ES(&UE9W1A;.%L:&%T
M\RDZ`$$@<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S>N%MX7)A(&OI<WK\
M;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN`$9E:FQE<WITZ7,`2&%R;6%T<&]N
M=`!(87)M871P;VYT(&IE;&5N;&5G.B``2&%R;6%T<&]N=#H@`&)A;'+S;"!J
M;V)B<F$@[7+A<P!J;V)B<O-L(&)A;')A(.URX7,`0^UM=.%R`$%Z(&ED]7!O
M;G1O:V%T(#(T(/-RX7,@9F]R;>%T=6UB86X@:F5L96[M='/\:R!M96<_`$UE
M9VIE;&5N[73I<VD@8F7A;&SM=.%S;VL`02!RZ7-Z;&5T97,@96SU<F5J96QZ
MZ7,@;65G:F5L96[M=.ES90!%;/5R96IE;'KI<R!M96=J96QE;NUTZ7-E("AR
M97#\;/5TZ7)I*0!-96=J96QE;NUTZ7-I(&9O<FWA='5M`,ER=&5S[73I<R!A
M(&OI>F)E<^UT971T(&QE=NEL('-O<G/A<O-L`$1Z<VEB=71I`$YE('3V<O9L
M:OQK`$$@;6%I;G1E;F%N8V4N<&AP(&YE;2#I<FAE=/4@96P@:_9Z=F5T;&5N
M_&PN`$%Z(&5L<_4@<V]R(&$@;65Z]6L@;F5V96ET('1A<G1A;&UA>GIA/R!(
M82!I9V5N+"!J96SV;&IE(&MI(&5Z=#H`1&]M:6YI:V$`1&]M:6YI:V%I($OV
M>G3A<G-A<^%G`$YI;F-S(&WI9R!L;V=I;B!N979E/R!)9^EN>65L:F5N(&5G
M>65T+@!,973V;'3I<P!4]FQT<_QK(&QE("5S+70`5/9L='/\:R!L92!02%`@
M<')O9W)A;2!F;W)MX6KA8F%N(&%Z(&5L:^ES>OQL="!K;VYF:6=U<N%C:?-T
M+@!,96?V<F3\;/4@;&ES=&$`2^%B[73S<WIE<F5K`&5M86EL`$5M86EL8O5L
M(%--4RUK_&QD]2!M96=H86IT\RP@:&$@82!T96QE9F]N=.%R<V%SX6<@8FEZ
M=&]S[71J82!E>G0@82!S>F]L9^%L=&%TX7-T+@!(24)!`$5C=6%D;W(`3?-D
M;W/M=.%S`$)L;VMK(&WS9&]S[73A<P!#<V]P;W)T(&WS9&]S[73A<P!*;V=O
M<W5L='/A9R!M\V1O<^UTX7,`2F]G;W-U;'1SX6=O:R!M\V1O<^UTX7-A`"5S
M(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S80!-96QY:6L@;W!C:?-K870@
M=N%L=&]Z=&%S<W5K.@`B)7,B(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S
M80`E<R!J;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$`3VMT873A<P!%9WEI
M<'1O;0!386QV861O<@!%;&5M+BXN`&%Z("=M)R!B973[('-ZZ6QE<W/I9V4`
M16UA:6P`16UA:6P@8^UM`$%Z(&5M86EL(&/M;65K;F5K(&5G>65Z;FG\:R!K
M96QL+@!%;6%I;"!V:7-S>F%I9V%Z;VSA<W-A;`!%;6%I;"U335,@X71JX7+S
M`$AA;F=U;&%T:6MO;F]K`-QR97,@_'IE;F5T+@!.:6YC<R!I;'EE;BX`5/9R
M]FQJ_&L@:VD@82!K97)E<^ES96ME=`!%;F=E9&K\:R!M96<L(&AO9WD@:^EP
M96ME="!I;&QE<W-Z_&YK(&$@<WKV=F5G8F4@82!&;W3S9V%LZ7)IX6MB\VP_
M`$QE9WEE;B!J;V)B(&5GZ7)G;VUB8F%L(&5LZ7)H973U+"!K;VYT97AT=7-F
M_&=G]2!M96[\/P!!>B!U=&]L<_,@Z78`P71VX6QTX7,@:_QL]FX@86)L86MR
M80!!9&IA(&UE9R!A>G0@82!B:7IT;VYSX6=I(&OI<F3I<W0L(&%M96QY<F4@
M;6%J9"!VX6QA<WIO;&YI82!K96QL(&IE;'-Z87;A;F%K(.%TX6QL[73A<^%H
M;WHL('!L+B`G:&]G>2!H[79JX6L@82!K=71YX6KA=#\G.@!!9&IA(&UE9R!A
M(&OI<"!54DPM:NET(&ET=`#-<FIA(&)E(&%Z(&%LX6)B:2!B973[:V5T.@!%
M9WEE;FSM=/5I+4=U:6YE80!%<FET<F5A`$AI8F$`2&EB82!T]G)TZ6YT(&$@
M8FQO:VL@;.ET<F5H;WKA<V%K;W(Z("5S`$AI8F$@=/9R=.EN="!A>B!A9&%T
M<WII;FMR;VYI>N%C:?-S(&IE;"!T]G)LZ7-E:V]R.B`E<P!!>B!A9&%T<WII
M;FMR;VYI>N%C:?-S(&YA<&SSX6QL;VWA;GD@=/9R;.ES92!N96T@<VEK97+\
M;'0Z("5S`$AI8F$@=/9R=.EN="!A>B!A9&%T;&5KZ7+I<V)E;CH@)7,`2&EB
M82!T]G)TZ6YT(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%S86MO<CH@)7,`2&EB
M82!A>B!E;6%I;"#\>F5N971B96XN`$$H>BD@(B5S(B#A;&QO;>%N>7)A(&YE
M;2!S:6ME<OQL="#M<FYI+@#)<WIT;W)S>N%G`$5T:?-P:6$`3F5M>F5T:7/I
M9V5K`$5U<O-P80`Q-2!P97)C96YKZ6YT`#(@<&5R8V5N:^EN=``S,"!MX7-O
M9'!E<F-E;FOI;G0`-2!P97)C96YKZ6YT`&UI;F1E;B!B96IE;&5N=&ME>NES
M:V]R`&;I;/-RX6YKZ6YT`'!E<F-E;FOI;G0`4.EL9&$@Z7)TZ6ME:SH`5NEG
M<F5H86ITX7,`3GEI<W-U:R!S>NET`$IE;&5N[71S_&L@;65G(&%Z(&]L9&%L
M<_,@;65N_'0`271T("<I)R!K96QL96YE(&OV=F5T:V5Z>F5N`$ET="!C<W5P
M87-Z('-Z\VYA:R!V86=Y(&EDZ7KU:F5L8F5N(&QE=O4@:V5R97/I<VD@:VEF
M96IE>NES;F5K(&ME;&QE;F4@;&5N;FEE`$%Z(.ER=NEN>65S<^EG(&QE:N%R
M871A`$MI=&5V]0!3>NUN`$$@:V]N9FEG=7+A8VGS($944"UN(.%T('9A;/,@
M9F5L=/9L=.ES90!!('-Z96WI;'EE<R!B9>%L;.UTX7-O:V%T(&YE;2!S:6ME
M<OQL="!B96]L=F%S;FDN`$%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L
M+@!!>B!334(@<WIE<G9E<B!N96T@Z7)H973U(&5L+@!.96T@<VEK97+\;'0@
M82AZ*2`B)7,B+6+U;"!T]G)TZ6[U(&WA<V]LX7,N`$YE;2!S:6ME<OQL="!A
M*'HI("(E<R(M8F4@=/9R=.EN]2!MX7-O;.%S+@!.96T@<VEK97+\;'0@^FH@
M4T%33"!K87!C<V]L871O="!LZ71R96AO>FYI+@!.96T@<VEK97+\;'0@82AZ
M*2`B)7,B+6)E('3V<G3I;O4@X71H96QY97KI<RX`P6QL;VWA;GEH;WIZX6;I
M<NES:2!H:6)A.B`E<P!4:7-Z=&$`1F%L:VQA;F0M<WII9V5T96L@*$UA;'9I
M;F%S*0!&87)O92US>FEG971E:P!(96QY<F5H;WIH871A=&QA;B!H:6)A.@!&
M87@`1F%X`&9E8G)UX7(`2/5MZ7)SZ6ML973I<GIE=`!(]6WI<G/I:VQE=.ER
M>F5T.B``16=Y+65G>2!ZX7!O<@!3>O-R=N%N>6]S86X@:/-ZX7!O<F]K`$UE
M>O4@;>%T<FEX`$9I9VQE="!#05!40TA!("AB973[:VER86OS(&AU;>%N=&5S
M>G0I`$9I9'IS:0!&X6IL`$$@9N%J;&]K('-ZX6UA.B`E<P!!(&;A:FQO:R!S
M>N%M83H@)7,`1N%J;"!M96YE9'IS97(`1N%J;&[I=@!&X6IL(&MI:F5L]FSI
M<P!&X6IL(&9E;'3V;'3I<V4`1N%J;&]K(&9E;'3V;'3I<V4@;F5M(&QE:&5T
M<^EG97,N`%-Z^W+U:P!&:6YN;W)S>N%G`&5L<_4@9NEL`&5L<_4@;F5G>65D
M`%;A;'1O>F%T;&%N(&WI<F5T87+A;GD`5/QK<O9ZZ7,@*&;V;"]L92D`2_9D
M`"5S(&UA<'!A(&YE;2!LZ71E>FEK`$)E=/MS>NUN`,ET96QE:P!/;'EA;B!B
M]FYGZ7-Z]6L@<WKA;>%R82P@86UI:R!N96T@:F5L96[M=&EK(&UE9R!A(&OI
M<&5K970`16SU<F5J96QZZ7,@*')E</QL]73I<FDI`$%Z(&5L]7)E:F5L>NES
M(&ED]71A<G1A;6$@;F%P;VMB86X@*&%Z(&5L]7)E:F5L>NES(&YA<'!A;&D@
MZ7,@Z6IS>F%K86D@861A=&]K870@=&%R=&%L;6%Z+"!E>NER="!A(&YA9WD@
M<WKA;6]K('-ZZ6QE<R!B;&]K:V]T(&5R961MZ6YY97IN96LI`$5L9F5L96IT
M971T92!A(&IE;'-Z87;A=#\`VW)L87!K97IE;.ES`$EDZ7IE=`!)9.EZ970@
M9F%J=.%J80!)9.EZ971E:P!)9.EZ971E:R`R`$;S<G5M;VL`5&]VX6)B[73A
M<V]K`%#I`$9R86UE+65K`$9R86YC:6%O<G-ZX6<`1G)A;F-I86]R<WKA9P!&
M<F%N8VEA($=U>6%N80!&<F%N8VEA(%!O;&ENZ7II80!&<F%N8VEA($3I;&D@
M5&5R_&QE=&5K`$9E;&%D\P!)<N%N>3H@`%+I<WIL971E<R!L9>URX7,`=&5L
M:6AO;&0`5&5L:F5S(&[I=@!'86)O;@!-96QY:6L@9V%LZ7)IX6+S;"!V96=Y
M_&L@82!KZ7!E=`!+Z7!G86SI<FEA.@!'86UB:6$`2&]Z>G5K(&SI=')E(&$H
M>BD@)7,@:V]N9FEG=7+A8VGS:N%T`$$@:V5L971K97IE='0@:_-D`$=R^GII
M80!.Z6UE=&]R<WKA9P!':.%N80!':6)R86QTX7(`2V5R97-Z=&[I=@!';&]B
MX6QI<R!B9>%L;.UTX7-O:P!-96AE=`!']F1E;`!';V]G;&4@=.ER:^EP`$=O
M;V=L92!K97)E<^ES`$9E:V5T92]F96CI<@!']G+V9V]R<WKA9P!G]G+V9R`H
M25-/+3@X-3DM-RD`1W+V;FQA;F0`1W)E;F%D80!#<V]P;W)T(&%D;6EN:7-Z
M='+A8VGS`$$@8W-O<&]R=&[I=B!M87)A9&AA="#\<F5S96X`1W)O=7!?;&1A
M<#H@)7,@8W-O<&]R="!H;WIZX6%DX7-A(&YE;2!S:6ME<OQL="X@02!S>F5R
M=F5R(';A;&%S>F$Z(`!'<F]U<%]L9&%P.B`E<R!C<V]P;W)T('3V<FSI<V4@
M;F5M('-I:V5R_&QT`$=R;W5P7VQD87`Z("5S(&-S;W!O<G0@861A=&%I;F%K
M(&UE9_IJ[73A<V$@;F5M('-I:V5R_&QT`$-S;W!O<G1O:P!'=6%D96QO=7!E
M`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`%9E;F3I9R!J;V=O<W5L='/A9V]K
M`%9E;F3I9VOV;GEV`$=U:6YE80!":7-S874M1W5I;F5A`$=U>6%N80!(5$U,
M07)E82!G>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!S;W(@=71O;'/S(&-E
M;&SA:N%T('3V<O9L;FDN`$A434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL
M86YD\R!A('3A8FSA>F%T('5T;VQS\R!O<WIL;W#A="!T]G+V;&YI+@!(5$U,
M07)E82!G>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA="!U=&]L
M<_,@<V]RX70@=/9R]FQN:2X`02!(5%10(&9E;&AA<WINX6SS87IO;F]S[73A
M<R!N96T@=&%LX6QH873S+@!(86ET:0!(87-H(&%L9V]R:71M=7,`2_9D`$9E
M:FSI8P!&96ILZ6,`2&5A<F0M(.ES($UC1&]N86QD+7-Z:6=E=&5K`$5R]7,@
M>FEV871A<@!HZ6)E<B`H25-/+3@X-3DM."U)*0!-86=A<W/A9P!396?M='/I
M9P!396?M='/I9R!A('-Z97)K97-Z=/4@:&%S>F[A;&%TX6AO>@!396?M='/I
M9P!&Z6QT96ME`$5Z(&$@9N%J;"!E;&5J93H`;F%G>0!+97ID]6QA<`!6871I
M:^%N=N%R;W,`2V5Z9/5L87``3W1T:&]N:2!C[6T`4WIE;>EL>65S(&%L:_9N
M>79TX7(`3W1T:&]N:2!T96QE9F]N`$AO;F1U<F%S`$AO;F=K;VYG`$AO<F1E
M`$AO<F1E+TMO;&%B.B!H:6+A<R`E<R!834P@861A="!V86X@82AZ*2`E<R#\
M>F5N971B96X`2&]R9&4O2V]L86(Z(&YI;F-S(&$H>BD@)7,@;V)J96MT=6UN
M86L@;65G9F5L96SU(/QZ96YE=`!(;W)D92]+;VQA8CH@;FEN8W,@)7,@=.UP
M=7/Z(&]B:F5K='5M(&$H>BD@)7,@_'IE;F5T8F5N`$AO<F1E+TMO;&%B.B!3
M:6ME<F5S96X@=/9R]FQT_&L@97IT.B`E<R`B)7,B`$AO<F1E+TMO;&%B.B!A
M>B!I;G1E9W+A;/,@<')O9W)A;6AO>B!S>OQK<^EG97,@82`G9&]M>&UL)R!0
M2%`@8O5V[73I<P!(;W)D92]+;VQA8CH@;F5M('-I:V5R_&QT(/IJ(%A-3"!F
MX70@;.ET<F5H;WIN:2!A*'HI("5S(&]B:F5K='5M:&]Z`$AO<F1E+TMO;&%B
M.B!.96T@<VEK97+\;'0@=/9R]FQN:2`E<RUT("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!N96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&$@34E-12!)1"UJX70@
M82!K]G9E=&ME>O4@=.UP=7/Z(&UE;&SI:VQE=&YE:SH@)7,`2&]R9&4O2V]L
M86(Z($YE;2!S:6ME<OQL="!S>FEN:W)O;FEZX6QN:2`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@3F5M('-I:V5R_&QT(&$@:_9V971K97KU(&OV>O9S('3A
M<G1E<OQL970@<WII;FMR;VYI>N%LX7-A.B`E<P!(;W)D92]+;VQA8CH@:7-M
M97)E=&QE;B!K]GKV<R!TX7)T97+\;&5T("(E<R(`5NUZ<WII;G1E<R!V;VYA
M;`!6[7IS>FEN=&5S(&UA<F?S`%;M>G-Z:6YT97,Z`$AO9WD@:G5T;W1T(&ED
M93\@*$OI<FK\:R#M<FIA(&UE9R$I`$CA;GD@;W-Z;&]P;W0@:^UVX6X@]G-S
M>F5O;'9A<WIT86YI/P!(X6YY(&UE>O4@*&]S>FQO<"D@=F%N/P!(X6YY('-O
M<G0@:^UVX6X@]G-S>F5O;'9A<WIT86YI/P!0X7)A=&%R=&%L;VT`4.%R871A
M<G1A;&]M.B``2'5M;W)I<W3A:P!-86=Y87)O<G-ZX6<`07H@24U!4"!L97;I
M;&SA9&$@;.ET<F5H;WKA<V$@;F5M('-I:V5R_&QT.B`E<P!!>B!)34%0(&QE
M=NEL;.%D82!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,`07H@24U!4"!L97;I
M;&SA9.%H;WH@=&%R=&]Z\R!K=O-T82!LZ71R96AO>N%S82!N96T@<VEK97+\
M;'0Z("5S`$E0(&/M;0!!>B!)4"!C[6T@;F5M(&AA=.%R;WIH873S(&UE9RX`
M07H@25`@8^UM(&YI;F-S(&$@;65G96YG961E='0@0TE$4B!T87)T;VWA;GEB
M86XN`%1I;'1O='0O;65G=N%L=&]Z;W1T($E0(&/M;2X`4V]R(&)E:6QL97-Z
M=.ES92!E9O9LZ0!)>FQA;F0`8W-A:R!I:V]N;VL`)7,@:6MO;FIA:0!I:V]N
M;VL@Z7,@<WKV=F5G`$%Z(&%Z;VYO<^UT\VAO>B!VX6QA<WIT;W1T(&5L;F5V
M97KI<SH`2&$@82!M96=J96QE;NUTZ7,@;F5M(&UE9V9E;&5L]2P@)7,@96=Y
M(/IJ(&%B;&%K8F%N('9A;/,@;65G;GEI=.%S:&]Z+@!(82#6;B!);G1E<FYE
M="!%>'!L;W)E<G0@:&%S>F[A;"P@Z7,@;F5M(&IE;&5N;F5K(&UE9R!A>B!I
M:V]N;VLL(&%K:V]R(';A;&%S<WIA(&5Z="!A>B!O<&-I\W0L(&UE;&QY96P@
M:VEK87!C<V]L:F$@82!03D<@:^EP96L@=')A;G-Z<&%R96YC:>%JX70N`$AA
M(&SA=&IA(&5Z="!A('-Z]G9E9V5T+"!D92!A(&OI<&5T(&YE;2P@86MK;W(@
M8O9N9^ES>O5P<F]G<F%M:F$@;F5M(&OI<&5S(&UE9VIE;&5N[71E;FD@82!S
M>F5R=F5R<F4@:_QL9&5N9/4@:^EP970N`$5L]7IE=&5S(&[I>F5T.@!!(&OI
M<"!54DPM:F4`02!KZ7`@55),+6IE.@!-96QY:6L@9V%LZ7)IX6+S;"!V86X@
M82!KZ7``2^EP(&5B8O5L(&$@9V%LZ7)IX6+S;#H`2^EP(&9E;'3V;'3I<V4`
M2^EP96L`26UP;W)TX6SA<RP@)60N(&SI<.ES`$%Z(&EM<&]R=.%L="!M97KU
M.B`E<P!!>B!I;7!O<G3A;'0@;65Z]6LZ`%-O<B!B96EL;&5S>G3I<V4@97IA
M;.$`2&EBX7,@<&%R86YC<W!A<F%MZ71E<BX`3F5M(&UE9V9E;&5L]2!A(&)E
M:F5L96YT:V5ZZ7-I(&[I=B#I<R]V86=Y(&$@:F5L<WKS+@!.96T@;65G9F5L
M96SU(&$@9F5L:&%S>F[A;/-I(&[I=B!V86=Y(&%Z(&%L=&5R;F%T[78@8^UM
M+B!0<O-BX6QJ82#Z:G)A('9A9WD@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87ID
MX6AO>BP@:&$@=&]VX6)B:2!S96?M='/I9W)E('9A;B!S>OQK<^EG92X`0F5K
M97IDZ7,@8F5L:F5B8@!);F1I80!%9WEE<R!F96QH87-Z;N%L\VL`26YD;V[I
M>FEA`$EN9F]R;>%C:?,`26YF;W)MX6-I\P!!>B!I;F9O<FWA8VGS(&WA<B!N
M96T@X6QL(')E;F1E;&ME>NES<F4N`$]S>FQO<"!B97-Z^G+A<V$@97IU=.%N
M`$OI<"!B96EL;&5S>G3I<V4`5.%B;.%Z870@8F5I;&QE<WITZ7-E`$QI;FL@
M;.ET<F5H;WKA<V$`3W-Z;&]P(&)E<WKZ<N%S82!E>F5LZ0!/<WIL;W`@8F5S
M>OIRX7-A(&5Z=73A;@!/<WIL;W`@8F5S>OIRX7-A(&5Z96SI`%-O<B!B97-Z
M^G+A<V$@97IA;.$`4V]R(&)E<WKZ<N%S82!E9O9LZ0!"96ME>F3I<R!B96EL
M;&5S>G3I<V4@97IU=.%N`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>F5LZ0!(
M;WIZ=6YK(&SI=')E(&%L=&5R;F%T[78@<V%B;&]N=`!!9&IO;B!M96<@96=Y
M(&5M86EL(&/M;65T+"!M96QY<F4@96QK_&QD:&5T]2!A>B#6;B#Z:B!J96QS
M>F%V83H`0V5L;&$@8F5I;&QE<WITZ7-E(&5Z=73A;@!#96QL82!B96EL;&5S
M>G3I<V4@97IE;.D`3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6X`3W-Z;&]P(&)E
M<WKZ<N%S82!E>F5LZ0!,979E;&5K(&)E;>%S;VSA<V$`0F5K97IDZ7,@8F5I
M;&QE<WITZ7-E(&5Z=73A;@!"96ME>F3I<R!B96EL;&5S>G3I<V4@97IE;.D`
M4V]R(&)E<WKZ<N%S82!E>F%LX0!3;W(@8F5S>OIRX7-A(&5F]FSI`$%D:F$@
M;65G(&$@:^UVX6YT(';A;&%S>G0@82!B:7IT;VYSX6=I(&OI<F3I<W)E.@!+
MZ7`@8F5I;&QE<WITZ7-E+VWS9&]S[73A<V$`3&EN:R!B96EL;&5S>G3I<V4O
M;?-D;W/M=.%S80!!('-ZX6ULX6KA;B!N:6YC<R!E;.EG(&9E9&5Z970@_'IE
M;F5T970@:_QL9&5N:2!A(&OV<FQE=NEL;&ES=.%R82X`02!S>N%M;.%JX6X@
M;FEN8W,@96SI9R!F961E>F5T+@!%9^ES>@!%9^ES>B!S>N%M;VL@;&ES=.%J
M80!(:6+A<R]E;&9O9V%D:&%T871L86X@541(("A5<V5R($1A=&$@2&5A9&5R
M*2X`2&EBX7,O96QF;V=A9&AA=&%T;&%N(%I)4"!T]FWV<NUTZ7,`2&EBX7,O
M96QF;V=A9&AA=&%T;&%N(&%L:V%L;6%ZX7,N`$AI8N%S+V5L9F]G861H871A
M=&QA;B!B871C:"!A>F]N;W/M=/,N`$$@:_QL9/9T="!A9&%T(&AI8N%S+V5L
M9F]G861H871A=&QA;BX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&/M;7KI<RX`
M2&EBX7,O96QF;V=A9&AA=&%T;&%N(&;A:FP@9F]R;>%T=6T`2&EBX7,O96QF
M;V=A9&AA=&%T;&%N(&QI8V5N<WIK=6QC<RX`2&EBX7,O96QF;V=A9&AA=&%T
M;&%N(';A<F]S+@!(:6+A<R]E;&9O9V%D:&%T871L86X@_'IE;F5T=.UP=7,N
M`$AI8N%S+V5L9F]G861H871A=&QA;B!V86=Y(&AIX6YY>O,@<')O9W)A;6]Z
MX7-I9F5L_&QE="UA>F]N;W/M=/,N`$AI8N%S+V5L9F]G861H871A=&QA;B!P
M87)A;>ET97)E:RX`2&EBX7,@87H@;V)J96MT=6T@96SI<NES:2!J;V=O<W5L
M='/A9V$N`$AI8N%S+V5L9F]G861H871A=&QA;B!P87)T;F5R87IO;F]S[73S
M+@!(:6+A<R]E;&9O9V%D:&%T871L86X@=&5R;>EK:_-D+@!(:6+A<R]E;&9O
M9V%D:&%T871L86X@<')O=&]K;VQL+@!(:6+A<R]E;&9O9V%D:&%T871L86X@
M8^UM>F5T=#H@(B5S(@!(:6+A<R]E;&9O9V%D:&%T871L86X@;65G;W-Z=&]T
M="!O8FIE:W1U;0!(:6+A<R]E;&9O9V%D:&%T871L86X@9F5L863S:2!C[6TN
M`$AI8N%S+V5L9F]G861H871A=&QA;B!U;FEC;V1E(&%D870N`$YY:6QVX6YT
M87)TX7,`02!K:6IE;/9LZ7,@:6YV97)TX6SA<V$`27+A;FD@27-Z;.%M($OV
M>G3A<G-A<^%G`$ER86L`S7)O<G-ZX6<`36%N+7-Z:6=E=`!3>O-R=N%N>6]S
M('II=F%T87)O:P!)>G)A96P`02!T86[Z<^UT=N%N>2!K:6%D\VIA`&3U;'0`
M3VQA<WIO<G-ZX6<`2F%M86EC80!J86YUX7(`2F%PX6X`:F%PX6X@*$E33RTR
M,#(R+4I0*0!*97)S97D`2F]R9.%N:6$`:OIL:75S`&KZ;FEU<P!3;W)K:7KA
M<N%S`&OV>NEP<F4@<F5N9&5ZZ7,`<V]R:VEZX7+A<R!M:6YD:^ET(&]L9&%L
M<F$`<V]R:VEZX7+A<R!B86QR80!S;W)K:7KA<N%S(&IO8F)R80!+87IA:'-Z
M=.%N`%1A<G1S=6L@;65G(&%Z(&5R961E=&ET/P!+96YY80!!(&ME<F)E<F]S
M('-Z97)V97(@96QU=&%S[71O='1A(&$@9F5L:&%S>F[A;/-A>F]N;W/M=.%S
M="X`2V5Z9/4@:V5R;F5L9F5J;&5S>G3U:P!+=6QC<R!LZ71R96AO>N%S80!!
M(&MU;&-S(&QE;GEO;6%T80!+=6QC<VAO<W-Z^G/A9P!+=6QC<R!T[7!U<P!!
M(&MU;&-S(&AA<WINX6QA=&$`02!K=6QC<R!MX7(@;.ET97II:R!A(&YY:6QV
MX6YO<R!K=6QC<W-Z97)V97)E;BX`1WEE<F5K96L`2VER:6)A=&D`2V]R96%I
M($[I<&D@1&5M;VMR871I:W5S($OV>G3A<G-A<^%G`$MO<F5A:2!+]GITX7)S
M87/A9P!K;W)E86D@*$550RU+4BD`2W5V86ET`$MI<F=I>FES>G3A;@!?5&5R
M=F5ZZ7,`3GEE;'8`3&%O<WII($[I<&D@1&5M;VMR871I:W5S($OV>G3A<G-A
M<^%G`'5T;VQS\R!FZ6P`07H@=71O;'/S(&IE;'-Z\W;A;'3A<P!U=&]L<_,@
M;F5G>65D`%5T;VQS\R!VX6QT;WIT873A<SH`571O;'/S(&)E:F5L96YT:V5Z
MZ7,Z("5S`%5T;VQS\R!B96IE;&5N=&ME>NES.B`E<RP@)7,@8^UM<O5L`%5T
M;VQS\R!B96IE;&5N=&ME>NES.B!MZ6<@<V]H82!N96T@=F]L=`!,971T;W)S
M>N%G`$IO9P!%;&AE;'EE>NES`$AA9WEJ82#\<F5S96XL(&AA(&YE;2!A:V%R
M(&ME<F5T970`3&EB86YO;@!B86P`0F%L(&]L9&%L:2!F96ILZ6,`0F%L(&]L
M9&%L:2#I<G3I:V5K`$QE<V]T:&\`4WII;G0`3&EBZ7)I80!,[6)I86D@07)A
M8B!3>F]C:6%L:7-T82!.86=Y($[I<&D@2_9Z]G-SZ6<`3&EE8VAT96YS=&5I
M;@!'>65N9V4@<WII=.%L\R!E<_4`1WEE;F=E(&5S]0!$Z6QE;/5T="!G>65N
M9V4@97/U`$3I;'5TX6XO97-T92!G>65N9V4@97/U`$=Y96YG92!ZX7!O<@!'
M>65N9V4@>FEV871A<@!'>65N9V4@:&%V87KA<P!'>65N9V4@:/-ZX7!O<@!,
M:6YK`$$@;&EN:R!I9&4@;75T870Z`$UE9VIE;&5N[73I<VMO<B!M=71A<W-O
M;B!E9WD@;&EN:R!A(&QE=NEL8^UM<O5L(&$@;&5VZ6SM<O,@86)L86MH;WH`
M3&EN:V5K`$QI;G5X`$QI<W3A>N%S("T@82!F96QH87-Z;N%L\R!LX71J82!A
M(&UA<'#A=`!!>B!A9&%T8N%Z:7-O:R!L:7-TX6IA`$%Z;VMN86L@82!TZ6WA
M:VYA:R!A(&QI<W3A:F$@86UI<O5L('-E9^UT<^EG(&MA<&AA=/,`07H@861A
M='3A8FSA:R!L:7-TX6IA`$QI<W1A(&%R8VCM=G5M`$QI<W1A('-E9^UT<^EG
M:^ERZ7,`3&ES=&$@87IO;F]S[73S`$QI<W1A('1U;&%J9&]N;W,`3&ES=&$@
M;&5VZ6SM<N%S`$QI<W1A(&9E;&ER871K;WKA<R`H<W5B<V-R:6)E*0!,:7-T
M82!L96ER871K;WKA<R`H=6YS=6)S8W)I8F4I`$$@9F5L:&%S>F[A;/-K87!C
M<V]L871O:R!K:6QI<W3A>N%S82!N96T@<VEK97+\;'0Z("5S`$$@9F5L:&%S
M>F[A;/-K(&MI;&ES=.%ZX7-A(&YE;2!S:6ME<OQL=#H@)7,`02!F96QH87-Z
M;N%L\VL@:VEL:7-TX7KA<V$@=&EL='9A('9A;BX`27)O9&%L;VT`3&ET=N%N
M:6$`3&5T]FQTZ7,N+BX`2&5L>6D@:63U.B``3GEE;'8L(&3A='5M+"!I9/4`
M2&5L>0!"96IE;&5N=&ME>NES`$%Z(&5L]7KU(&%D871S>FEN:W)O;FEZX6-I
M\R!N87!L\^%L;&]MX6YY80!+:6IE;&5N=&ME>NES`$)E:F5L96YT:V5ZZ7,`
M0F5J96QE;G1K97KI<W-E;"!K87!C<V]L871O<R!F96QA9&%T;VL`02!B96IE
M;&5N=&ME>NES(&YE;2!S:6ME<OQL="P@;65R="!R;W-S>B!F96QH87-Z;N%L
M\VYE=F5T('9A9WD@:F5L<WKS="!A9&]T="!M96<N`$$@8F5J96QE;G1K97KI
M<R!N96T@<VEK97+\;'0N`$AO<W-Z^B!S>O9V96<`4WIE<F5L96T`86QA8W-O
M;GD`9_9R]F<@:VES8F5T^VL`;&%T:6X@:VES8F5T^VL`:VES8F5T^W,@<O-M
M86D@<WKA;6]K`$QU>&5M8G5R9P!-30!.87!I(/QZ96YE=&5K`$%Z($U3+51.
M148@;65L;.EK;&5T8F5N(&YI;F-S(&%D870N`-Q:14Y%5`!-86MA\P!-86ME
M9/-N:6$`36%D86=A<WIKX7(`5F%RX7IS;&%T`$QE=F5L97KI<P!%;6%I;"!D
M;VUA:6X@:V5Z96SI<P!,:6YK(&OI<WKM=.ES90!-86QA=VD`36%L86IZ:6$`
M36%L9.UV+7-Z:6=E=&5K`$UA;&D`3>%L=&$`061A=&%I="!K871E9_-R:>%K
M8F$@<V]R;VQH871J82X@17IE:R!I='0@9&5F:6YIX6QH873S:RP@;?-D;W/M
M=&AA=/-K+"!T;W;A8F+A('-Z[6YE:R!R96YD96QH973U:R!H;WIZX6IU:RX`
M36%P,C0@=.ER:^EP`$UA<%%U97-T('3I<FOI<`!!(&AO>GKA<F5N9&5LZ7-E
M:V5T(&5L;65N=&5T=/QK+@!MX7)C:75S`$UA<F?S`$%Z($]L=F%S;W1T+T]L
M=F%S871L86X@:F5L>F5T96L@:&%S>F[A;&%T80!-X7,@:F5L>F5T96L@*'!L
M+B!&;VYT;W,O365G=N%L87-Z;VQT*2!H87-Z;N%L871A`$UA<G-H86QL+7-Z
M:6=E=&5K`$UA<G1I;FEQ=64`16=Y;>%S;F%K(&UE9V9E;&5L]2!M97KU:P!-
M875R:73A;FEA`$UA=7)I=&EU<P!-87AI;>%L:7,@<F5N9&5L:V5ZZ7-R92#A
M;&SS('-ZX6UL8?9S<WIE9RX`07H@_'IE;F5T('3Z;"!S;VL@<NES>F+U;"#A
M;&PN`$%Z(&5L;?IL="`R-"#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK;&5T93H@
M`$%Z(&5L;?IL="`V(/-R82!M87AI;>%L:7,@:/5MZ7)SZ6ML971E.B``07H@
M]G-S>F5G]6]L9&%L(&)L;VMK:F%I;F%K(&UA>&EMX6QI<R!S>N%M80!-87AI
M;>%L:7,@:&]S<WH`;>%J=7,`36%Y;W1T90!/<G9O<W1U9&]MX6YY`%1A9V]K
M`$$@;65N_"!M96=J96QE;NES93H`0V5L;.%K(&5G>6)E;VQV87-Z=.%S80#<
M>F5N970`02!D:6=I=.%L:7-A;B!A;.'M<G0@_'IE;F5T(&AI=&5L97,L(&1E
M(&%Z(&%LX>UR\R!T86[Z<^UT=N%N>>%T(&YE;2!S:6ME<OQL="!E;&QE;O5R
M:7IN:2X`3&5JX7)T(&%Z(/QZ96YE="#I<G;I;GEE<W/I9V4N`$%Z(/QZ96YE
M="!T[7!U<V$`365T87(@:63U:N%RX7-J96QE;G3I<P!!($UE=&%R(&)L;VMK
M(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X`02!-971A<B!B;&]K:R!N96T@X6QL
M(')E;F1E;&ME>NES<F4N($$@<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S
M>N%MX7)A(&OI<WK\;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN`$$@365T87)$
M0B!N96T@Z7)H973U(&5L+@!-\V1S>F5R`$$H>BD@(B5S(B!M\V1S>F5R(&1E
M9FEN:>%L871L86X`02!M\V1S>F5R(&1E9FEN:>%L871L86XN($$@;65G:.UV
M;W1T(&WS9'-Z97(Z("5S`$UE=')I:W5S`$UE>&EK\P!-:6MR;V[I>FEA:2!3
M>O9V971SZ6=I(,%L;&%M;VL`:_9ZZ7``34E-12!T[7!U<P!!>B!E;&WZ;'0@
M,C0@\W)A(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T93H@`$%Z(&5L;?IL
M="`V(/-R82!L96=A;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z(`!-Z6<@;F5M
M('1E;'0@96P@82!M:6YI;>%L:7,@:63U(&$@:F5L<WKS(&UE9W;A;'1O>G1A
M=.%SX6AO>@!4_&MR]GKI<R`H:F]B8B]B86PI`%9E9WEE<P!(:>%N>7II:R!A
M($A45%!?4F5Q=65S="!014%2(&-S;VUA9RX`2V]N9FEG=7+A8VGS('-Z_&MS
MZ6=E<RX@17IT(&UO<W0@:V5L;"!LZ71R96AO>FYI82P@:&$@:&%S>F[A;&YI
M(&%K87)J82!A>B!A;&MA;&UA>N%S="X`2&GA;GEZ:6L@87H@_'IE;F5T(&%Z
M;VYO<^UT\VIA+@!(:>%N>7II:R!A($UA:6P@4$5!4B!C<V]M86<N`$AIX6YY
M>FEK(&$@9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S[73S:F$@*'-E<W-I
M;VX@240I+@!(Z0!,979E;&5ZZ7,@;6]B:6QT96QE9F]N<O-L`$OV>F5P97,`
M02!M\V1O<^UTX7,@9.%T=6UA`$%Z(%523"!M\V1O<^UTX7-A`$UO9'5L=7,`
M36]L9&]V86D@2_9Z=.%R<V%SX6<`36]N86-O`$UO;F?S;&EA`$CS;F%P(.ES
M(.EV`&AA=F]N=&$`36]N='-E<G)A=`!(;VQD9N%Z:7-O:P!!("5D+B!S;W)B
M86X@=/9B8B!M97KU('9O;'0L(&UI;G0@82!VX7)T("5D+@!-87)O:VOS`%3V
M8F)N>6ER92!D97+\;'0`5/9B8FYY:7)E(&)O<G5L=`!4]F)B;GEI<F4@;F%P
M;W,`=FEG>?QK(&QE`'9I9WG\:R!B86QR80!V:6=Y_&L@:F]B8G)A`'9I9WG\
M:R!F]FP`=FEG>?QK(&QE`'9I9WG\:R!F]FP`36]Z86UB:6L`5/9B8G-Z:6YT
M^R!L96?V<F3\;/4@;&ES=.%K`$UU;'1I;6%P($YA9WDM0G)I=&%N;FEA('3I
M<FOI<`!4]F)B<WKV<O9S(';A;&%S>G3A<P!"96IE;&5N=&ME>NES:2!B9>%L
M;.UTX7-O:P!"96IE;&5N=&ME>NES:2!A9&%T86EM`%-A:N%T(/9S<WIE9WKU
M(&]L9&%L86T`4V%JX70@]G-S>F5G>O4@;VQD86QA;2!T97)V97KI<V4`36EA
M;FUA<@!.14TL(&YE;2!E9WEE>F5M(&)E;&4N`$[I=@!.86WM8FEA`$YA=7)U
M`$YE<.%L`$AO;&QA;F1I80!(;VQL86YD($%N=&EL;.%K`$YE='-C87!E(&+A
M>FES+5523`!.971S8V%P92!T86[Z<^UT=N%N>6MI863A<VEJ;V<H0T$I+79I
M<W-Z879O;N%S:2!54DP`3F5T<V-A<&4@=&%N^G/M=';A;GEF96QH87-Z;N%L
MX7-I(&ERX6YY96QV(%523`!.971S8V%P92!T86[Z<^UT=N%N>6UE9_IJ[73A
M<VD@55),`$YE='-C87!E('1A;OIS[71VX6YY=FES<WIA=F]NX7-I(%523`!.
M971S8V%P92!34TP@<WIE<G9E<F[I=@!.971S8V%P92!T86[Z<^UT=N%N>2!M
M96=J96=Y>NES`$YE='-C87!E('1A;OIS[71VX6YY=.UP=7,`2.%L\WIA=`!S
M;VAA`-IJ+4MA;&5D\VYI80#::B!K871E9_-R:6$`VFH@;&5VZ6P@)7,@8^UM
M<F4`^FIH;VQD`-IJ(&9E;&AA<WINX6SS;NEV("AO<&-I;V[A;&ES*0#::BU:
MZ6QA;F0`VFH@:F5L<WKS`$%Z(/IJ(&IE;'-Z\R#I<G;I;GEE<W/I9V4@96MK
M;W(@:N%R(&QE.B`E>"X`02!M96=A9&]T="#Z:B!J96QS>F%V86L@;F5M(&5G
M>65Z;F5K+@#::B!A8FQA:R`H_')E<RD`2.UR96L`2.UR8W-O<&]R=&]K`$OV
M=F5T:V5Z]0!+]G9E=&ME>O4@-"!FX7II<P!+]G9E=&ME>O4@;W!C:?-K`$OV
M=F5T:V5Z]3X`3FEC87)A9W5A`$YI9V5R`$YI9^ER:6$`Z6IS>F%K80!.:75E
M`$YE;0!.:6YC<R!R96YD96QK97KI<W)E(.%L;/,@:V]N9FEG=7+A8VGS+"!A
M;6EH97H@:^EP97-T(&$@:_QL]FYB<^EG96ME="!M96<@;&5H971N92!M=71A
M=&YI+@!.:6YC<R!L96AE=/5SZ6<@25-/(.%L;&]MX6YY;VL@;.ET<F5H;WKA
M<^%R82X`2&GA;GEZ:6L@82!K]G1E9V5L="!F96QD;VQG;WKA<VAO>B!S>OQK
M<^EG97,@;6EN=&$@*&)A=&-H('1E;7!L871E*2X`02!K[7;A;G0@:&5L>65N
M(&YI;F-S(&)L;VMK`$%Z($U#04P@9F5L:&%S>F[A;/-A>F]N;W/M=.%S:&]Z
M(&YI;F-S(&UE9V%D=F$@82!N87!TX7(@;F5V92X`3FEN8W,@=N%L=&]ZX7,N
M`$5H:&5Z(&$@:F]G;W-U;'1SX6=H;WH@;F5M(&AO>FAA=/,@;.ET<F4@:F]G
M;W-U;'1SX6=I(&%L8W-O<&]R="X`2&GA;GEO>FYA:R!A(&MO;F9I9W5RX6-I
M\W,@861A=&]K("5S+6AE>BX`07H@1E10(%9&4R!N:6YC<R!K;VYF:6=U<N%L
M=F$N`$%Z(%-13"!61E,@;FEN8W,@:V]N9FEG=7+A;'9A+@!!>B!344PM1FEL
M92!61E,@;FEN8W,@:V]N9FEG=7+A;'9A+@!!>B#6;B!S>N%M;.%JX6X@96QF
M;V=Y;W1T(&$@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9RX`3FEN8W,@8^UM
M>NES+@!!('-Z97)V97)R92!N96T@=/9L=/5D]G1T(&9E;"!S96UM:6QY96X@
MX6QL;VWA;GD`07H@:6MO;F]K(&YE;2!T86SA;&AA=/-K+@!.:6YC<R!M96=A
M9'9A(&$@:&5L>2X`3FEN8W,@;65G861V82!A(&AE;'DN`$%Z(/QZ96YE="#\
M<F5S+@!.:6YC<R!M96=A9'9A(&$@;NEV+@!.:6YC<R!M96=A9'9A(&$@<WKA
M;2X`3F4@;&5G>65N(&UE9V)O='+A;FMO>G1A=/,@:63I>F5T`$YI;F-S(&IE
M;'-Z\R!M96=A9'9A(&$@2%144"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S
M[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@87H@24U!4"!A;&%P^B!F
M96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D
M=F$@82!+97)B97)O<R!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO
M>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!,;V=I;B!A;&%P^B!F96QH87-Z
M;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!0
M05-35T0@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN`$YI;F-S
M(&IE;'-Z\R!M96=A9'9A(&%Z(%--0B!A;&%P^B!F96QH87-Z;N%L\VD@87IO
M;F]S[73A<VAO>BX`3FEN8W,@;65G861V82!A>B!/<&5N4U-,('!R;V=R86T@
M96SI<NES:2#Z='9O;F%L82X@07H@3W!E;E-33"!P<F]G<F%M('-Z_&MSZ6=E
M<R!A(%!+0U,@,3(@861A=&]K(&ME>F5LZ7/I:&5Z+@!.:6YC<R#Z:B!B96IE
M;&5N=&ME>NES:2!I9^EN>2X`3FEN8W,@:W;S=&$@8F7A;&SM='9A+@!.92!L
M96=Y96YE:R!V;VYA;&%K('-E:&]L+@!.:6YC<R!D969I;FGA;'9A(&5L=N%L
M87-Z=/,@:V%R86MT97(N`$YE(&QE9WEE;B!K97)E=`!.:6YC<R!I;'EE;B!F
MX6IL`$YI;F-S(&ED96EG;&5N97,@X6QL;VWA;GEO:R!TX7)O;.%SX7)A('-Z
M;VQGX6SS(&%L:_9N>79TX7(N`$AIX6YY>FEK(&$@9F5L:&%S>F[A;/-NZ78@
MZ7,O=F%G>2!A(&IE;'-Z\RX`02!V:7-S>F%K87!O='0@861A=&]K(&YE;2#I
M<G;I;GEE<R!834P@861A=&]K`$YI;F-S(&%D870`3FEN8W,@;>EG(&MO;F9I
M9W5RX6-I\RP@9V5N97+A;&IO;B!E9WEE="X`3FEN8W,@;>EG(&MO;F9I9W5R
MX6-I\VIA+"!G96YE<N%L:F]N(&5G>65T+@!N:6YC<P!N:6YC<R!M96=A9'9A
M("AL96=Y96X@86QA<.ER=&5L;65Z971T*0!N;W)D:6MU<R`H25-/+3@X-3DM
M,3`I`$YO<F9O;&LM<WII9V5T`,ES>F%K:2!FZ6QT96ME`,ES>F%K:2U-87)I
M86YA+7-Z:6=E=&5K`$YO<G;I9VEA`$YE;2!KZ7/U8F(`3F5M(&MO<N%B8F%N
M`$YE;2!A;&OV;GEV=.%R`$$@<')O9W)A;6YA:R!E>B!A('+I<WIE(&WI9R!N
M:6YC<R!M96=V86SS<^UT=F$N`$YI;F-S(&)EX6QL[71V80!.96T@=.%M;V=A
M=&]T="X`1F5L:F5G>7KI<V5K`$YI;F-S(&+V;F?I<WIH973U(&%D870L('3I
M<FIE;B!V:7-S>F$N`&YO=F5M8F5R`%-ZX6T`2V%R86MT97)E:R!S>N%M80!/
M<WIL;W!O:R!S>N%M80!3;W)O:R!S>N%M80!!(&OV<FQE=NEL;&ES=&$@;?-D
M;W/M=.%SX6AO>B!N96T@861O='0@;65G('-ZX6UO:V%T+@!/2P!/8FIE:W1U
M;0!!>B!O8FIE:W1U;2!LZ71R96AO>O-J80!/:W3A;&ES('-ZX6T`;VMT\V)E
M<@!3>OMRZ7,`2&EV871A;"]M=6YK86AE;'D`02!RZ6=I(.ES(&%Z(/IJ(&IE
M;'-Z\VYA:R!K_&SV;F+V>FYI92!K96QL+@!!('+I9VD@:F5L<WKS`$$@<NEG
M:2!J96QS>O,@;F5M(&UE9V9E;&5L]2X`3VWA;@!#<V%K(&%Z($E-05`@<WIE
M<G9E<F5K('3A;6]G871JX6L@82!M87!PX6L@;65G;W-Z=.%SX70N`$-S86L@
M;65G8F]T<N%N:V]Z=&%T\R!I9.EZ970@;&5G>65N`$-S86L@96=Y(&5M86EL
M(&/M;2!A9&AA=/,@;65G+@!#<V%K(&$@='5L86ID;VYO<R!V86=Y(&$@<F5N
M9'-Z97)G87ID82!VX6QT;WIT871H871J82!M96<@96=Y(&OV>O9S('3A<G1E
M<OQL970@='5L86ID;VYO<^%T('9A9WD@96SI<NES:2!J;V=O<W5L='/A9V%I
M=`!.>6ES<W5K(&UE9R#Z:B!A8FQA:V)A;@!/<&5N4U-,(&AI8F$Z($YE;2!S
M:6ME<OQL="!K:6YY97)N:2!A>B!A9&%T;VMA="!A>B!A;.'M<G0@4R]-24U%
M('+I<WIB]6P`3GEI<W-U:R!M96<@97IT(&$@8^UM970@96=Y(/IJ(&%B;&%K
M8F%N`$]P97+A8VGS<R!R96YD<WIE<@!/<&-I\VL`)7,@8F7A;&SM=.%S86D`
M4V]R<WKA;6]S(&9E;'-O<F]LX7,`4WIE<G9E>F5T`%-Z97)V97IE=&D@96=Y
M<^EG`$UU;FMA<WIE<G9E>NES`$%Z(&%L:V%L;6%ZX7,@97)E9&5T:2!S86)L
M;VYJ80`E<R!E<F5D971I('-A8FQO;FIA:3H`16=YZ6(`16=YZ6(@:6YF;W)M
MX6-I\P!!('1U;&%J9&]N;W,@:F]G;W-U;'1SX6=A:0!!(%!!32!F96QH87-Z
M;N%L\V%Z;VYO<^UTX7,@;F5M(.%L;"!R96YD96QK97KI<W)E+@!014%2.CI-
M86EL(&%L<F5N9'-Z97(`4$=0(&1I9VETX6QI<R!A;.'M<N%S`%!'4"UV96P@
M=&ET:V]S[71O='0@861A=`!01U`@;GEI;';A;F]S(&MU;&-S`%!'4"UV96P@
M86SA[7)T+W1I=&MO<^UT;W1T(&%D870`4$A0(&OS9`!$Z6QU=.%N+V5S=&4@
M9WEE;F=E(&5S]0!$Z6QU=.%N(&5S]0!$Z6QU=.%N+V5S=&4@>N%P;W)O:P!$
MZ6QU=.%N+V5S=&4@:&%V87KA<P!$Z6QU=.%N+V5S=&4@:/-ZX7!O<F]K`$3I
M;'5TX6X@;F%P<_QTZ7,`1.EL=73A;B]E<W1E('II=F%T87)O:P!(:>%N>7II
M:R!A(%!/4TE8(&+U=NUTZ7,`8F5L<_4@;6%R9_,`4&%K:7-Z=.%N`%!A;&%U
M`%!A;&5S>G1I;B!497+\;&5T("AM96=S>N%L;'0I`%!A;F%M80!0X7!U82#:
M:BU'=6EN96$`4&%R86=U87D`3>ER<^EK96QT96X@8F]R=6QT`$IE;'-Z\P!!
M(&IE;'-Z\W0@<VEK97)E<V5N(&UE9W;A;'1O>G1A='1U:RX`3F5M(&UE9V9E
M;&5L]2!J96QS>O,`02!2041)55,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S:&]Z
M(&IE;'-Z\R!S>OQK<^EG97,N`$IE;'-Z\R!M96=E<O5S[73I<W-E;`!*96QS
M>O,Z`$IE;'-Z\SH@`$$@:F5L<WIA=F%K;F%K(&5G>65Z;FG\:R!K96QL+@!"
M96EL;&5S>G3I<P!"96EL;&5S>G3A<R!A(';A9_-A<WIT86QR\VP`VG1V;VYA
M;`#::B!F96QH87-Z;N%L\VYA:R!B96IE;&5N=&ME>F5T=&5K.@!%;6)E<F5K
M`'-ZX7IA;.EK`$MA<F)A;G1A<G3A<VD@9F5L861A=&]K(';I9W)E:&%J=.%S
M80!"96IE;&5N=&ME>NES:V]R(&AA:G1S=6L@=NEG<F4@82!K87)B86YT87)T
MX7-I(&9E;&%D871O:V%T/P!*;V=O<W5L='/A9P!!*'HI("(E<R(@:F]G;W-U
M;'1SX6=O="!N96T@=/9R]FQT_&LN`-9N;F5K(&YI;F-S(&5H:&5Z(&5L96=E
M;F3U(&IO9V]S=6QT<^%G80!*;V=O<W5L='/A9V]K`$IO9V]S=6QT<^%G(&%D
M;6EN:7-Z='+A8VGS`%-Z96WI;'EE<R!A9&%T;VL`4&5R=0#!;&QA=&ME9'9E
M;F-E:P!&_&SV<"US>FEG971E:P!496QE9F]N`$;I;GEKZ7!G86SI<FEA`%!I
M=&-A:7)N`'!I>&5L`$OV>FAE;'EE:P!+871T:6YT<V]N('9A;&%M96QY:6L@
M8V5L;.%R80!":7IT;W-A;B!T]G+V;&YI(&%K87)J82!E>G0@87H@96QE;65T
M.@!+Z7)E;2!E<O5S[71S92!M96<L(&AO9WD@=F%L\V)A;B!T]G+V;&YI(&OM
M=N%N:F$@97IT(&%Z(&5L96UE="X`2^ER96T@861J;VX@;65G(&5G>2!H\VYA
M<&]T(.ES(&5G>2#I=F5T+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E9_-R
M:6$@;F5VZ70Z`$OI<F5M('9A;/-S($E0(&/M;65T(&%D:F]N(&UE9RX`2^ER
M96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<L(&5L;&5N]7)I>GIE(&$@:/-N
M87`@;F%P:F%I="X`2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<N`$OI
M<F5M('+V=FED96X@[7)J82!L92!A('!R;V)LZ6UA(&SI;GEE9^ET+@!+Z7)E
M;2!A9&IA(&UE9R!A(&)E:F5L96YT:V5ZZ7-I(&YE=NET(.ES(&IE;'-Z87;A
M=`!+Z7)E;2!O;'9A<W-A(&5L(&$@:_9V971K97KU('-Z]G9E9V5T+B!!(')E
M;F1S>F5R(&AA<WINX6QA=.%N86L@9F5L=.ET96QE:70@96P@2T5,3"!F;V=A
M9&YI82X`2^ER96T@861J82!M96<@87H@^FH@:V%T96?S<FEA(&YE=NET.@!,
M96YG>65L;W)S>N%G`%!O;&ET:6MA`%-Z879A>N%S;VL`4&]R='5GX6QI80!!
M(&OI<"!E;&AE;'EE>NES90!!('3A8FSA>F%T(&5L:&5L>65ZZ7-E`$OV>G9E
M=&QE;B!L97;I;&O\;&3I<R!E8F)E(&$@;6%P<.%B82`H24U!4"!N96T@;6EN
M9&EG('9E<WII(&9I9WEE;&5M8F4I`$%Z(&5L;?IL="`E<R#S<F$@8W-A<&%D
MZ6MM96YN>6ESZ6=E.B``0W-A<&%DZ6L\8G(@+SYV86SS<WKM;OMSZ6<`4')E
M9G-?;&1A<#H@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E<R!,1$%0(&MI=&5R
M:F5S>G3I<RX`4')E9G-?<V5S<VEO;CH@;F5M('1A;.%L:&%T\R!A('-Z_&MS
MZ6=E<R`H<V5S<VEO;BD@:VET97)J97-Z=.ES+@!,Z6=N>6]MX7,`02!T96YG
M97)S>FEN=&YE:R!M96=F96QE;/4@;.EG;GEO;>%S.B``3.EG;GEO;>%S.B``
M16SU>F5T97,@;65G=&5K:6YTZ7,`02!KZ7`@96SU>F5T97,@;65G=&5K:6YT
MZ7-E(/IJ(&%B;&%K8F%N`$5L]7KU(&]P8VGS:P!!(&1O:W5M96YT=6T@:VEN
M>6]M=&%TX7-A`%1I=&MO<R!K=6QC<P!(:6)A8F5J96QE;G3I<P!!(&AI8F$@
M;&7M<N%S80!0<F]J96MT(&ME>F5LZ7,`02!P<F]M<'0@<WKV=F5G90!.>6EL
M=N%N;W,@:W5L8W,`3GEI;';A;F]S(&MU;&-S^B!A;&=O<FET;75S`$YY:6QV
MX6YO<R!K=6QC<R!I;F9O<FWA8VGS`$$@;GEI;';A;F]S+W1I=&MO<R!K=6QC
M<W#A<G0@;F5M('-I:V5R_&QT(&SI=')E:&]Z;FDN`%!U97)T;R!2:6-O`$$@
M;&5V96QE:R!VZ6=L96=E<R!T]G)LZ7-E`$MA=&%R`$ME<F5S]2]P87)A;F-S
M('-T<FEN9P!+=O-T80!24T$@;GEI;';A;F]S(&MU;&-S("@E9"!B:71E<RD`
M4N%D:?-G;VUB;W,@:VEVX6QA<WITX7,`17/U`$5S]2!DZ6QE;/5T=`!%<_4@
M9.EL=73A;B]E<W1E`%KA<&]R`$5S]2#I<R!H879A>N%S`$AA=F%S97/U`%;I
M;&5T;&5N(&EDZ7IE=`!!<N%N>0!/;'9A<^%S`$QE=F5L96L@;VQV87/A<V$`
M5.EN>6QE9R!T]G+V;&K\:R`E<R!F96QH87-Z;N%L\W0_($5Z(&$@=N%L=&]Z
M=&%TX7,@;F5M(&9O<F3M=&AA=/,@=FES<WIA+@!4Z6YY;&5G('3V<O9L:OQK
M("5S(&9E;&AA<WINX6SS(&%D871A:70_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M
M(&9O<F3M=&AA=/,@=FES<WIA+@#::G)A(';I9W)E:&%J=&IA(&%Z('5T;VQS
M\R!VX6QT;WIT873A<W0`1G)I<W/M=.ES`$$@;65N_"!D:6YA;6EK=7,@96QE
M;65I;F5K(&9R:7-S[73I<VD@9WEA:V]R:7/A9V$Z`$%Z(/9S<WIE9WKU;VQD
M86P@9G)I<W/M=.ESZ6YE:R!G>6%K;W)I<^%G83H`3V)J96MT=6T@8O9N9^ES
M>O4`1G)I<W/M=.ES`$UE9VIE9WEZZ7-E:P!4X79O;&D@<WIE<G9E<F5K`$$@
M=.%V;VQI(%523"`H<&PN(&AT='`Z+R]W=W<N=F%L86UI+FAU+VUE9W9A;&%M
M:2DZ`%3V<FSI<P!";&]K:R!T]G)LZ7-E`$]S>FQO<"!T]G)LZ7-E`$$@9F]R
M;6%T=.%LX7,@=/9R;.ES90!!('#A<B!T]G)LZ7-E`%3V<O9L:OQK(&%Z(&5L
M;65N=&5T="!P<F]G<F%M;W0@82!S>F5R=F5R(&ED96EG;&5N97,@X6QL;VWA
M;GEO:V%T('1A<G1A;&UA>O,@86QK]FYY=G3A<N%B\VPN`%9E9WG\:R!K:2``
M5F5G>?QK(&MI(&5Z="!A('+I<WIT(&$@9&]K=6UE;G1U;6+S;`!!(&9E;&AA
M<WINX6SS('3V<FSI<V4`)7,@9F5L:&%S>F[A;/,@=/9R;.ES90!!(&OI<NES
M(&YE;2!T96QJ97/M=&AE=/4N($$@:V%P;W1T(&AI8F%K\V0Z(`!!(&ME<F5S
M971T('-Z;VQGX6QT873A<R!N96T@=&%LX6QH873S+@!!(&OV=&5L97KU96X@
M;65G861A;F3S("(E<R(@;F5M('-Z97)E<&5L("5S(&MO;F9I9W5RX6-I\VKA
M8F%N+@!!(&OV=&5L97KU96X@;65G861A;F3S("(E<R(@;F5M('-Z97)E<&5L
M(&$@5D93(&MO;F9I9W5RX6-I\VKA8F%N+@!!(&OV=&5L97KU96X@;65G861A
M;F3S("(E<R(@;F5M('-Z97)E<&5L(&$@:V]N9FEG=7+A8VGS8F%N+@!3>OQK
M<^EG97,@;65Z]0!297-E=`!!(&IE;'-Z\R#A=.%L;.UTX7-A`$%Z(-9N(&IE
M;'-Z87;A;F%K(.%TX6QL[73A<V$`07H@=71O;'/S(&ME<F5SZ7,@=FES<WIA
MX6QL[73A<V$`17)E9&WI;GD`5FES<WIA(&%Z(&]P8VGS:VAO>@!!>B#Z:B!J
M96QS>O-T(.UR:F$@8F4@:7-MZ70`4NEU;FEO;@#!;&SM='-U:R!V:7-S>F$@
M82!K;VYF:6=U<N%C:?-T`%)I8V@@5&5X="!%9&ET;W(@;W!C:?-K`%1A;.%L
M\W,@:^ER9.ES96L`:F]B8@!*;V)B(&]L9&%L:2!F96ILZ6,`2F]B8B!O;&1A
M;&D@Z7)TZ6ME:P!3;W(@='5L86ID;VYSX6=O:RXN+@!3>F5R97``4F]MX6YI
M80!&;W)G873A<R`Q.#`@9F]K:V%L`$)A;')A(&9O<F=A=.%S`$IO8F)R82!F
M;W)G873A<P!3;W(@='5L86ID;VYSX6=O:P!3;W(@='5L86ID;VYSX6=O:P!3
M;W)O:SH`5F]N86QA:P!-:6YD96X@<V]R(.ES(&]S>FQO<"!K]GKV='0@;&5G
M>65N('9O;F%L`$-S86L@87H@;W-Z;&]P;VL@:_9Z]G1T(&QE9WEE;B!V;VYA
M;`!#<V%K(&$@<V]R;VL@:_9Z]G1T(&QE9WEE;B!V;VYA;`!&=71T873A<P!/
M<F]S>B!&]F1E<N%C:?,`4G5A;F1A`%,O34E-12!D:6=I=.%L:7,@86SA[7+A
M<P!3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&]T="!L97;I;`!3
M05-,(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@=&%LX6QH873S+@!335,@
M:_QL9.ES`%-13"!P87)A;F-S(&$@:V5R97/I<VAE>@!34T@`4TE+15+<3%0`
M4WIO`%-Z96YT($EL;VYA+7-Z:6=E=`!386EN="!+:71T<R#I<R!.979I<P!3
M86EN="!,=6-I80!386EN="!0:65R<F4@Z7,@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="#I<R!'<F5N861I;F4M<WII9V5T96L`56=Y86YA>B!A(&9R86UE("A?
M<V5L9BD`4WIA;6]A`%-A;B!-87)I;F\`4V%O(%1O;>D@Z7,@4'+M;F-I<&4`
M3?MH;VQD87,@:6YT97)N971E;.ERZ7,`4WIA^F0M07+A8FEA`$UE;G3I<P`B
M)7,B(&UE;G3I<V4`)7,@;65N=.ES90!!(&)EX6QL[73A<V]K(&UE;G3I<V4`
M365N='/\:R!E;"!A>B!E;&OI<WK\;'0@:V]N9FEG=7+A8VGS="!02%`@<')O
M9W)A;2!F;W)MX6KA8F%N(&$@<WIE<G9E<B!I9&5I9VQE;F5S(.%L;&]MX6YY
M;VMA="!T87)T86QM87KS(&%L:_9N>79TX7+A8F%N+@`E<R!K;VYF:6=U<N%C
M:?-JX70@96QM96YT971T_&LN`$5L;65N=&5T=/QK(&$@<V5T=7`@=7!G<F%D
M92!P<F]G<F%M;W0@:61E.B`B)7,B`%-Z\W)VX6YY;W,@>FEV871A<F]K`%1U
M9&]MX6YY`$ME<F5SZ7,`2V5R97/I<VD@<WIO;&?A;'1A=.%S;VL`P6QL;VWA
M;GEO:R!K:7;A;&%S>G3A<V$`5N%L87-S>F]N(&MI(&5G>2!DX71U;6]T`$UE
M;'EI:R!C<V]P;W)T;W0@:^UVX6YJ82!H;WIZX6%D;FD`5N%L87-S>F$@:VD@
M87H@^FH@='5L86ID;VYO<W0`5N%L87-S>F]N('-Z97)V97)T`$UE;'EI:R!F
M96QH87-Z;N%L\W0@:^UVX6YJ82!H;WIZX6%D;FD`36EN9&5T(&MI:F5L]FQJ
M_&L`5N%L87-S>F$@:VD@87H@]G-S>F5S(&3A='5M]G-S>F5T97;U="X`5N%L
M87-S>F]N(&5G>2!O8FIE:W1U;6]T`$5G>2!S92!L96=Y96X@:VEJ96SV;'9E
M`%;A;&%S<WIA(&MI(&$@:^UVX6YT(&MA<F%K=&5R*&5K92ET(&%Z(&%LX6)B
M:2!L96AE=/5SZ6=E:R!K]GK\;"X@17IU=.%N(")C;W!Y+W!A<W1E(B!M\V1S
M>F5R<F5L(&$@;65G9F5L96SU(&AE;'ER92!MX7-O;&AA=&IA(/5K970N`%;A
M;&%S<WIA(&MI(&$@9.%T=6UE;';A;&%S>G3S(&MA<F%K=&5R=#H`5N%L87-S
M>F$@:VD@82!DX71U;2!F;W)MX71U;>%T.@!6X6QA<W-Z82!K:2P@;65L>6EK
M(&%Z;VYO<^UT\VKA="!K[7;A;FIA(&UE9W;A;'1O>G1A=&YI.@!6X6QA<W-Z
M82!K:2!A>B!I9/5E;';A;&%S>G3S(&MA<F%K=&5R=#H`5N%L87-S>F$@:VD@
M87H@:63U(&9O<FWA='5MX70Z`%;A;&%S<WIO;B!K:2!KZ70@96=Y;>%S;F%K
M(&UE9V9E;&5L]2!M97KU="X`5N%L87-S>F$@:VD@82!K[7;A;G0@<WKM;F5G
M>?QT=&5S="X`5N%L87-S>F$@:VD@87H@UFYN96L@;65G9F5L96SU(&YY96QV
M970Z`$AI8F%J96QE;G3I<R!K_&QDZ7-E`%--4R!K_&QDZ7-E`%-Z96YE9^%L
M`%-Z96YZ;W(Z(`!S>F5P=&5M8F5R`%-Z97)B:6$@Z7,@36]N=&5N96=R\P!3
M;W)O>F%T<WKA;0!!('-Z97)V97)T]6P@:V%P;W1T(&%D870@:&EBX7,L('9A
M9WD@;F5M(.%L;"!R96YD96QK97KI<W)E+@!!(&9E;&AA<WINX6SS:V%P8W-O
M;&%T;VL@861M:6YI<WIT<N%C:?-J80!,96KA<G0@82!F96QH87-Z;N%L\VMA
M<&-S;VQA="!A>F]N;W/M=/-J82`H<V5S<VEO;B!)1"DN`$9E;&AA<WINX6SS
M:V%P8W-O;&%T;VL`2&%L;6%Z`$QE:&5T]7/I9R!J96QS>F%VX6YA:R#A=.%L
M;.UTX7/A<F$L(&%B8F%N(&%Z(&5S971B96XL(&AA(&5L9F5L96IT96[I+@!4
MX79O;&D@<WIE<G9E<F5K(&5LZ7+I<V4@X6QL[71H873S(&)E+"!M96QY96ME
M="!A>B!I;F1U;/-O;&1A;.%N(&OM=N%N(&UE9VIE;&5N[71E;FDN`$$@:^UV
MX6YT(&YY96QV+"!I9/5Z\VYA(.ES(&3A='5M9F]R;>%T=6T@8F7A;&SM=.%S
M82X`0F7A;&SM=&AA=/,L(&AO9WD@;65L>6EK(&%L:V%L;6%ZX7,@:F5L96YJ
M96X@;65G(&$@8F5J96QE;G1K97KI<R!U=.%N+"!M:6QY96X@<WKM;F5G>?QT
M=&5S="P@;VQD86QF<FES<^UTZ7-I(&=Y86MO<FESX6=O="!I;&PN(&5G>>EB
M(&)EX6QL[73A<V]K870@<WIE<F5T;F4N`$)EX6QL[73A<V]K`$$@8F7A;&SM
M=.%S;VMA="!M96?Z:NUT\R!P<F]G<F%M;VL@X6QL;F%K(')E;F1E;&ME>NES
M<F4`02!M96=A9&]T="!P87)A;>ET97(@=/9B8B!H96QY970@:7,@:F5L96YT
M:&5T.B``4V5Y8VAE;&QE+7-Z:6=E=&5K`%;A<^%R;.%S`%+V=FED(/9S<WIE
M9F]G;&%LX7,`16P@:^UVX6YJ82#I<FYI(&%Z(&5G>65S(&9U;FMC:?-K870@
M06QT+6)I;&QE;G1Y^RUK;VUB:6[A8VGS:VMA;"!I<S\`365G:F5L96[M=.ES
M`$UU=&%S<W5K(&UE9R!A(&O\;/9N8G/I9V5K970@87H@96QM96YT971T(.ES
M(&%Z(/IJ;VYN86X@;.ET<F5H;WIO='0@:V]N9FEG=7+A8VGS(&OV>O9T="X`
M36EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(@[7+S9&KI:R!K:2!A(&MO<N%B8FD@
M=71O;'/S(&)E:F5L96YT:V5ZZ7,@:61E:F4_`%;A;&%S>G1H873S(&QE9WEE
M;B!A>B!E<F5D971I(&UE9W1A<G3A<V$`3&5G>65N(&3A='5M=N%L87-Z=/,`
M3&5G>65N(&5G>2!TX6)LX7IA=&ME>F5L]2!M96[\<V]R/P!-=71A<W-U:R!A
M("5S(&UE;OQT(&$@8F%L(&]L9&%L;VX_`$[I>GK\:R!M96<@=.%B;.%Z870@
M8V5L;.%I;F%K('1U;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@=.%B;.%Z870@
M='5L86ID;VYSX6=A:70`3NEZ>OQK(&UE9R!TX6)LX7IA="!S;W)A:6YA:R!T
M=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G(&$@:^EP('1U;&%J9&]N<^%G86ET
M`$UU=&%S<W5K(&$@9F5L=/9L=.ES=`!:X7!O<F]K`%KA<&]R;VL@9.EL96SU
M='0`6N%P;W)O:R!DZ6QU=.%N+V5S=&4`2&5L>6D@>N%P;W)O:P!+:6-S:6YY
M[73I<P!%;/5S>O9R(&MI8W-I;GGM=&5N:64@:V5L;"P@=F%G>2!E;"!K96QL
M(&UO>F3M=&%N:6$@82!H96QY970@96QF;V=L86SS(&)L;VMK;VMA="X`4VEE
M<G)A($QE;VYE`-IJ(&9E;&AA<WINX6SS:R!B96IE;&5N=&ME>NES90!$:6=I
M=.%L:7,@86SA[7+A<P!!(&1I9VETX6QI<R!A;.'M<N%S(&%L9V]R:71M=7-A
M`%-Z:6YG87#Z<@!-Z7)E=`!!(&MA<F)A;G1A<G3A<R!K:6AA9WGA<V$`4WIL
M;W;A:VEA`%-Z;&]VZ6YI80!(879A>N%S`$CS>N%P;W(`2/-ZX7!O<F]K`$CS
M>N%P;W)O:R!DZ6QE;/5T=`!+Z7/U(&3I;'5TX6YI+V5S=&D@:/-ZX7!O<F]K
M`$$@:/,@;>EL>7/I9V4Z(`!(\R!V[7IM96YN>6ESZ6=E8F5N(&MI9F5J97IV
M93H@`%-A;&%M;VXM<WII9V5T96L`4WIO;>%L:6$`1&%L;VLL('9E<G-E:P!!
M('-O<F)A<F5N9&5ZZ7,@:7+A;GGA;F%K(&MI=N%L87-Z=.%S80!&96QA9/-I
M(&/M;0!$Z6PM069R:6MA`&3I;"UE=7+S<&%I("A)4T\M.#@U.2TS*0!$Z6QI
M+4=E;W)G:6$@Z7,@1.EL:2!386YD=VEC:"US>FEG971E:P!$Z6QI(&;I;'1E
M:V4`4WIO;7-ZZ61O<R!C96QLX6L@:_9Z]G1T:2!TX79O;'/A9P!!(&-E;&QA
M('1A<G1A;&UA(.ES(&ME<F5T92!K]GKV='1I('3A=F]L<^%G`$AE;'EK:73V
M;'3U`%3A=F]L<^%G`%3A=F]L<^%G(.ES(&)E;'/U(&UA<F?S(&)EX6QL[73A
M<P!3<&%N>6]L;W)S>N%G`%-P86UA<W-A<W-I;F4@8F7A;&SM=.%S;VL`4W!E
M8VGA;&ES(&MA<F%K=&5R(&)E=FET96QE`$$@8V5L;&$@:V5T=.EB;VYTX7-A
M`$%Z(&]S>FQO<"!K971TZ6)O;G3A<V$`02!S;W(@:V5T=.EB;VYTX7-A`%-P
M;W)T`%-R[2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`07H@96QS]2#I=@#!
M;&QA;2!V86=Y('1A<G1O;>%N>0#!;&QA<&]T`$UE;G3I<VD@9F]R;>%T=6T`
M0^UM("AU=&-A*0#A=&CZ>F]T=`!3=')I;F<@;&ES=&$`5/9R]FQJ_&L@82!C
M[6UB]6P@82!`('5TX6YI('+I<WIT`%-T[6QU<R!;0U-370!680!!*'HI("(E
M<R(@86QK]FYY=G3A<B!N96T@=&%LX6QH873S+@!4X7)G>0!+_&QD:OQK(&5L
M`"(E<R(@^FH@9F5L:&%S>F[A;/,@8F5J96QE;G1K97KI<VD@:^ER96QMZ70@
M=&]VX6)B[71O='1U:RX@UFX@8W-A:R!KZ7)E;&WI;F5K(&5L9F]G863A<^%T
M(&OV=F5T]65N('1U9"!M86ID(&)E:F5L96YT:V5Z;FDN`&%L<_,@:6YD97@`
M4VEK97+\;'0`4VEK97)E<V5N(&AO>GKA861T=6L@(B5S(BUT(&$@<F5N9'-Z
M97)H97HN`"(E<R(@9F5L:&%S>F[A;/,@861A=&%I="!S:6ME<F5S96X@=/9R
M]FQT_&L@82!R96YD<WIE<F+U;"X`4VEK97)E<V5N('3V<O9L=/QK("(E<R(M
M="X`4VEK97)E<V5N(&5L=.%V;VSM=&]T='5K("(E<R(M="!A(')E;F1S>F5R
M8O5L+@!!(&MO;F9I9W5RX6-I\W0@<VEK97)E<V5N('9I<W-Z8>%L;.UT;W1T
M=6LN($$@=N%L=&]ZX7-O:R!M96=T96MI;G3I<^EH97H@9G)I<W/M='-E(&%Z
M(&]L9&%L="X`02!B86-K=7`@:V]N9FEG=7+A8VGS="!E;&UE;G1E='3\:RX`
M4VEK97)E<V5N(&5L;65N=&5T=/QK(&$H>BD@)7,@8F%C:W5P(&MO;F9I9W5R
MX6-I\W0N`"(E<R(@861A=&%I;F%K(&WS9&]S[73A<V$@<VEK97)E<V5N(&UE
M9W3V<G3I;G0N`%-I:V5R97-E;B!E;&UE;G1E='3\:R!A("5S(.%L;&]MX6YY
M="X`4WIU9.%N`-9S<WIE9F]G;&%LX7,`3F%P:V5L=&4`3F%P;GEU9W1A`&YA
M<&]S`$YA<&ME;'1E`$YA<&ME;'1E+VYA<&YY=6=T80!.87!K96QT93H@`$YA
M<&YY=6=T80!.87!N>75G=&$Z(`!F96QS]2!I;F1E>`!/;FQI;F4@:V]M;75N
M:6OA8VGS("AC:&%T*0!3=7)I;F%M90!#<V%LX61NZ78`4W9A;&)A<F0@Z7,@
M2F%N($UA>65N`%-Z=N%Z:6;V;&0`4W;I9&]R<WKA9P!3=N%J8P!!>B!A9&%T
M<WII;FMR;VYI>N%C:?-S(&YA<&SSX6QL;VWA;GET('3V<O9L=/QK`%-Z:6YT
M86MT:6MA:2!H:6)A(&$@:V5R97/U:VEF96IE>NES8F5N`%-Z[7)I86D@07)A
M8B!+]GITX7)S87/A9P!::79A=&%R`%II=F%T87(L(&5R]7,@<WKI;`!::79A
M=&%R;VL`2V]R86D@>FEV871A<F]K`%135B`H5$%"(&MA<F%K=&5R<F5L(&5L
M=N%L87-Z=&]T="#I<G3I:V5K*2#A;&QO;>%N>0!4X6)LX7IA=`!!('3A8FSA
M>F%T('1U;&%J9&]N<^%G86D`02!TX6)LX7IA="!T=6QA:F1O;G/A9V%I`%1A
M:G9A;@!486IV86X`5&%D>G-I:VES>G3A;@!486YZX6YI86D@16=Y97/\;'0@
M2VERX6QY<^%G`$$@8^EL.@!&96QA9&%T;VL`5&5L969O;G-ZX6T`07H@96QM
M^FQT(/-R82!H]6WI<G/I:VQE=&4Z(`!(]6WI<G/I:VQE=`!(]6WI<G/I:VQE
M=#H@`$CU;>ER<^EK;&5T/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE
M<P!!*'HI("(E<R(@<V%B;&]N(&YE;2!T86SA;&AA=/,N`%-A8FQO;F]K(&%D
M;6EN:7-Z=.%C:?-J80!3>O9V96<`8W-A:R!S>O9V96<`4WKV=F5G96QH96QY
M97KI<P!S>O9V96<@=&5T96IE`$-S_`!T:&%I("A425,M-C(P*0!4:&%I9O9L
M9`!!>B!F='`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!($AI<W1O<GD@<F5N
M9'-Z97(@;?MK]F3I<V4@;FEN8W,@96YG963I;'EE>G9E+@!!($AO<F1E+TMO
M;&%B(&EN=&5G<N%C:?,@97IT(&YE;2!TX6UO9V%T:F$Z("(E<R(`07H@24U3
M4"!N87!L\WKA<W0@;F5M('-I:V5R_&QT(&UE9VME>F1E;FDN`$$@36%I;G1E
M;F%N8V4Z.B!O<WITX6QY(&)E=/9L=.ES92!N96T@<VEK97+\;'0`07H@3W!C
M:?,@86)L86L@8F5ZX7)O9&]T="X@2VELZ7#I<R!K]G9E=&ME>FEK+@!!($IO
M9V]S=6QT<^%G;VL@:&%S>F[A;&%TX6YA:R!E;/5F96QTZ71E;&4L(&AO9WD@
M82!R96YD<WIE<F=A>F1A(&MO;F9I9W5RX6QJ;VX@96=Y(&$@:F]G;W-U;'1S
MX6=I(&%D871O:V%T('1A<G3S<V%N('3A<F]L;FD@:^EP97,@86QR96YD<WIE
M<G0N`$-S86L@86QU;"!L96=Y96X@:V5R970`02!P87)T;F5R(&%Z;VYO<^UT
M\W-ZX6UA(&YE;2!V;VQT(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z
M(&%D871BX7II<V)A;B!N96T@=F]L="!M96=T86SA;&AA=/,N`$$@<&%R=&YE
M<B!A9&%T86ET('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI:^EH
M97HN`$O\;/9NX6QL\R!01U`@86SA[7+A<VD@8FQO:VL@<WK\:W/I9V5S(&$@
M9&EG:73A;&ES86X@86SA[7)T(/QZ96YE="!H:71E;&5S<^EGZ6YE:R!E;&QE
M;O5R>NESZ6AE>BX`02!K]G)L97;I;&QI<W1A(&%Z;VYO<^UT\W-ZX6UA(&YE
M;2!V;VQT(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871BX7II
M<V)A;B!N96T@=F]L="!M96=T86SA;&AA=/,N`$$@:_9R;&5VZ6QL:7-T82!N
M96T@=F]L="!M96=A9'9A+@!!('1I=&MO<^UTX7-I('-Z;VQGX6QT873A<V]K
M:&]Z(&)I>G1O;G/A9V]S("AT:71K;W/M=&]T="D@=V5B(&MA<&-S;VQA="!K
M96QL+@!!*'HI("5S(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@
M96=Y("5S(&)EX6QL[73A<VYA:RX`02AZ*2`E<R#A;&QO;>%N>6)A;B!S>F5R
M97!E;&YI92!K96QL96YE('9A;&%M:6QY96X@)7,@8F7A;&SM=.%S*&]K*6YA
M:RX`02!FX6IL(&YE;2!MX7-O;&AA=/,@]FYM86?A<F$N`$$@9N%J;&)A;B!N
M96T@=F]L="!A9&%T+@!!>B#\>F5N970@9F5J;.EC<V]R86D@82!K]G9E=&ME
M>O5K+@!!('1E;&IE<R!KZ7!E<FYY]7,@_'IE;6WS9"!P<F]B;.EMX6MA="!O
M:V]Z:&%T(&%Z($EN=&5R;F5T($5X<&QO<F5R(&AA<WINX6QA=&$@97-E=.EN
M+"!M97)T(&5B8F5N(&]L>6%N('!R;V=R86UH:6+A:R!V86YN86LL(&%M:6ME
M="!N96T@='5D='5N:R!M96=K97+\;&YI+B!!(&OI<&5R;GGU:F4@;VQV87-H
M871A=&QA;F[A(';A;&AA="P@8FEZ;VYY;W,@961I=&]R(&9U;FMC:?-K(&AI
MX6YY;WIH871N86L@Z7,O=F%G>2!VX7)A=&QA;G5L(&QE9F%G>6AA="!A(&+V
M;F?I<WKU<')O9W)A;2X@5VEN9&]W<R`Y>"!H87-Z;N%L871A(&5S973I;B!N
M86=Y;VX@=F%L\W-Z[6[[+"!H;V=Y("='96YE<F%L('!R;W1E8W1I;VX@9F%U
M;'0G(&AI8F$@;6EA='0@^FIR82!K96QL(&EN9.UT86YI82!M86ID(&$@9^EP
MZ70N7&Y<;D9I9WEE;&UE>G1E='3\:R$@2V%T=&EN='-O;B!A>B!/2R!G;VUB
M<F$L(&AA(&WI9VES(&UE9R!K[7;A;FIA(&OM<^ER96QN:2!A('1E;&IE<R!K
MZ7!E<FYY]7,@_'IE;6WS9&]T+@!!("(E<R(@87IO;F]S[73S="!K:73V<O9L
M=/QK+@!#<V%K(&)A;"!O;&1A;&]N(&QE9WEE;B!K97)E=`!!($=N=5!'('!R
M;V=R86T@:&5L>>ET(&UE9R!K96QL(&%D;FD@82!#<GEP=%]P9W`Z.B!O<WIT
MX6QY(&AA<WINX6QA=.%H;WHN`$$@;&5VZ6PL(&UE;'EE="`E<R!N87!JX6X@
M:_QL9/9T="`E<R!C[6UZ971T;F5K("(E<R(@=.%R9WEB86XL(&$@8^UM>F5T
M="!S>N%M[73S9^EPZ6X@;65G:F5L96YT+B!!<G)A(&YI;F-S(&=A<F%N8VEA
M+"!H;V=Y(&5L(&ES(&]L=F%S=.%K(&EL;"X@:&]G>2!M96?I<G1E='3I:RX`
M36D@;&5G>65N(&$@;&5VZ6SM<O,@86)L86MH;WH@;75T873S(&QI;FL@96QN
M979E>NES90!!(&UE>O5K('-ZX6UA(&-S86L@;G5M97)I:W5S(.ER=.EK(&QE
M:&5T+@!!>B!O<&5N<W-L(&UO9'5L('-Z_&MSZ6=E<R!A($AO<F1E7T-R>7!T
M7W-M:6UE.CH@;W-Z=.%L>2!H87-Z;N%L873A:&]Z+@!!("(E<R(@<WIE;>EL
M>65S(&)EX6QL[73A<R!N96T@;65N=&AE=/4@96PL(&UE<G0@;>ER971E(&UE
M9VAA;&%D:F$@82!M96=E;F=E9&5T="!M87AI;75M;W0`3F5M('1A;.%L:&%T
M\R!A>B!A('!R;V=R86T@82!S>F5R=F5R96XL(&%M:2!S>OQK<^EG97,@96YN
M96L@87H@861A='3M<'5S;F%K("@E<RD@82!M96=J96QE;NUTZ7/I:&5Z+@!!
M>B!I9.EZ]6IE;"!K87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE
M:&5T+@!*;V)B(.ES(&)A;"!O;&1A;&]N(&QE9WEE;B!K97)E=`!#<V%K(&IO
M8F(@;VQD86QO;B!L96=Y96X@:V5R970`07H@96QVX6QA<WIT\R!K87)A:W1E
M<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+@!!*'HI("(E<R(@<WIE
M<G9E<G0@=/9R]FQT_&LN`$$H>BD@(B5S(B!S>F5R=F5R="!E;&UE;G1E='3\
M:RX`)7,@8F5J96QE;G1K97KI<VD@:^ER96QMZ70@=/9R]FQT_&LN`$$@;65G
M861O='0@<V]R("@E9"D@;F5M(&SI=&5Z:6LN`$$H>BD@(B5S(B!I9&5I9VQE
M;F5S(&;A:FP@;F5M(&SI=&5Z:6LN`$$@8F7M<G0@<WKV=F5G(&YE;2!E9WEE
M>FEK(&$@:^EP97)N>?5N(&QE=O5V96PN`$%L=6P@Z7,@9O9L_&P@;&5G>65N
M(&ME<F5T`$-S86L@9F5N="!L96=Y96X@:V5R970`02!F96QT]FQT]G1T(&%D
M871O:R!A>B!E;/5Z]2!LZ7#I<R#S=&$@96QV97-Z=&5K+@!!(&9E;'3V;'3V
M='0@9N%J;'0@;F5M('-I:V5R_&QT(&5L;65N=&5N:2X`02!W96%T:&5R+F-O
M;2!B;&]K:R!N96T@:&%S>F[A;&AA=/,N`$$@;65G:F5L96[I<VD@<W3M;'5S
M("AT:&5M97,I(&%L:_9N>79TX7(@(B5S(B!N96T@=&%LX6QH873S+@!.:6YC
M<V5N(';A;&%S>G1H873S(&]P8VGS+@!.:6YC<R!A(&QE=NEL(&)E;'-E:NEB
M96X@;65G:F5L96[M=&AE=/4@;65L;.EK;&5T+@!4^FP@<V]K(&MA<F%K=&5R
M('9A;B!E8F)E;B!A(&UE>O5B96XN(-9N("5S(&MA<F%K=&5R="!A9&]T="!M
M96<[(&$@;6%X:6WA;&ES86X@;65G861H873S('!E9&EG(&ME=F5S96)B+"!M
M:6YT("5S+@`B)7,B(&9E;&AA<WINX6SS;F%K(&$@<F5N9'-Z97)H97H@863A
M<V%K;W(@:&EB82!T]G)TZ6YT+B`E<P`B)7,B(&9E;&AA<WINX6SS(&%D871A
M:6YA:R!T]G)LZ7-E('-O<N%N(&AI8F$@;.EP971T(&9E;#H@`"(E<R(@<F5N
M9'-Z97)B]6P@=F%L\R!T]G)LZ7-E:V]R(&AI8F$@;.EP971T(&9E;#H@`"(E
M<R(@;?-D;W/M=.%S82!S;W+A;B!H:6)A(&SI<&5T="!F96PZ("5S`$%Z(.%L
M;&]MX6YY="!N96T@<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@
M)7,@;F5M('3V;'3U9/9T="!F96PN`$%Z(.%L;&]MX6YY="!N96T@<VEK97+\
M;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@)7,@;F%G>6]B8BP@;6EN="!A
M(&UA>&EMX6QI<V%N(&UE9V5N9V5D971T(&WI<F5T("@E9"!BX6IT*2X`07H@
MX6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI
M+B!!*'HI("5S(&;A:FQN86L@8W-A:R!E9WD@<NES>F4@=/9L=/5D]G1T(&;V
M;"X`02!L97;I;"!E('+I<WKI;F5K(&UE9VIE;&5N[73I<V5K;W(@:&EB82!T
M]G)TZ6YT`$$@<&%R=&YE<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@:&EB
M82!T]G)TZ6YT+@!!>B!I0V%L96YD87(@861A=&]K(&EM<&]R=.%LX7-A('-O
M<N%N(&AI8F$@=/9R=.EN="X`2&EBX7,@82!M96=A9&]T="!K;VYF:6=U<N%C
M:?,N($QE:&5T+"!H;V=Y(&YE;2!T]FQT]G1T(&MI(&5G>2!S>OQK<^EG97,@
M;65Z]70N`$$@<&%R=&YE<FIE9WEZZ6MK96P@:V%P8W-O;&%T;W,@9F5L861A
M="!VZ6=R96AA:G3A<V$@<V]RX6X@:&EB82!LZ7!E='0@9F5L+B!+Z7)E;2!P
M<O-BX6QJ82!M96<@:^ES]6)B+@!(:6)A('3V<G3I;G0@82!P87)T;F5R(&%D
M871A:6YA:R!F<FES<^UTZ7-E('-O<N%N+B!+Z7)E;2!P<O-BX6QJ82!M96<@
M:^ES]6)B+@!!(&OV<FQE=NEL;&ES=&$@861A=&%I;F%K(&9R:7-S[73I<V4@
M<V]RX6X@:&EB82!T]G)TZ6YT+B!+Z7)E;2!P<O-BX6QJ82!M96<@:^ES]6)B
M+@!%>B!A>B!)34%0('-Z97)V97(@;F5M('3A;6]G871J82!A(&UA<'#A:VAO
M>B!V86SS(&AO>GKA9NERZ7,@;65G;W-Z=.%SX70N`$5Z(&YE;2!T^VYI:R!S
M>F%BX6QY;W,@<F%R(.%L;&]MX6YY;F%K+@!%>B!N96T@=/MN:6L@<WIA8N%L
M>6]S('II<"#A;&QO;>%N>6YA:RX`17H@;F5M('3[;FEK(.ER=NEN>65S(&OA
M<G1Y87-ZX6UN86LN`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO
M9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<WIO;&?A;'1A=/-N(.%T+@!%
M>B!A(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y($A45%`M:V%P8W-O
M;&%T;VX@4TU3+70@:_QL9&K\;FL@82!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2!S>F]L9^%L=&%T\VX@X70N`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S
M>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A>B!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!S>F]L9^%L=&%T\VX@
MX70N`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@4TU44"UK
M87!C<V]L871O;B!335,M="!K_&QD:OQN:R!6;V1A9F]N92!S>N%M;VMR82!A
M(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@<WIO;&?A;'1A
M=/-N(.%T+B!!('-Z;VQGX6QT873A<R!I9^EN>6)E=NET96SI:&5Z(%9O9&%F
M;VYE($ET86QY(&5M86EL(&/M;2!S>OQK<^EG97,N`$5Z(&$@;65Z]2!N96T@
M;6%R861H870@_')E<RX`16)B96X@82!M97KU8F5N(&-S86L@96?I<WH@<WKA
M;6]K(.%L;&AA=&YA:RX`16)B96X@82!M97KU8F5N(&-S86L@96?I<WH@<WKA
M;6]K(.ES(&ME='3U<W!O;G0@;&5H970N`$5B8F5N(&$@;65Z]6)E;B!C<V%K
M(&]K=.%L:7,@<WKA;6]K(.%L;&AA=&YA:RX`17H@82!M97KU(&-S86L@=F5S
M<WKU=F5L('9A9WD@<WKS:_9Z>F5L(&5L=N%L87-Z=&]T="!E9^ES>B!S>N%M
M;VMA="!T87)T86QM87IH870`17H@87H@Z7)TZ6L@8W-A:R!S>N%M(&QE:&5T
M+@!%8F)E;B!A(&UE>O5B96X@:&5X861E8VEMX6QI<R!21T(@<WKM;FOS9"#A
M;&QH870L('!L+B`G(S$R,S1A9B<N`$5Z96X@861A=&]K:V%L(&MA<&-S;VQA
M=&]S(&9E;&%D871O:V%T(&$@<WIE<G9E<B!MX7(@96QVZ6=E>G1E+@!%>B`E
M<P!%>B!E9WD@2V]L86(@1W)O=7!W87)E(&]B:F5K='5M+B!!>B!I;'EE;B!O
M8FIE:W1U;2!M96=J96QE;NUTZ7/I:&5Z(&]L>6%N(&5M86EL(&ML:65N<W!R
M;V=R86T@<WK\:W/I9V5S+"!A;65L>2!KZ7!E<R!A($MO;&%B($=R;W5P=V%R
M92!F;W)MX71U;2!K97IE;.ESZ7)E+B!);'EE;B!E;6%I;"!K;&EE;G-E:R!L
M:7-TX6IA(&SA=&AA=/,@:71T.B`E<P!%>G0@82!L979E;&5T(&WA<R!K87)A
M:W1E<FOI<WIL971T96P@*"5S*2#M<G3A:RP@;6EN="!A;6ET(-9N(&AA<WIN
MX6PN`$5Z(&$@<WKA;2!N96T@;&5H970@96=Y;NEL(&MI<V5B8BX`17H@82!S
M>F5R=F5R(&YE;2!KZ7!E<R!K:6)O;G1A;FD@82!Z:7`@:6QL+B!G>FEP(.%L
M;&]MX6YY;VMA="X`17H@82!R96YD<WIE<B!J96QE;FQE9R!I;F%K=&EVX6QV
M82!V86XN`$5Z(&%Z(.ER=.EK(&-S86L@<WKA;2!L96AE="X`17IT(&%Z(&%B
M;&%K(&-S86L@87H@3W!C:?-K(&%B;&%K8O-L(&CM=FAA=/,`5FEL;.%M;.%S
M`$AI8F%B96IE;&5N=.ES+6ME>F5LZ7,`263U`$UU;FMA:63U+6YY:6QVX6YT
M87)TX7,`263U(&9O<FWA='5M`$ED]2!VX6QA<WITX7,`2V5L970M5&EM;W(`
M5&ET=6QU<P!#[6T@*'1O;VQT:7`I`$/M;7IE='0`2&$@=/9B8B!E;&5M970@
M:7,@:VD@86MA<B!J96SV;&YI+"!T87)T<V$@;&5N>6]M=F$@82!#;VYT<F]L
M("A00RD@=F%G>2!A($-O;6UA;F0@*$UA8RD@8FEL;&5N='G[="!A(&MA='1I
M;G3A<R!K]GIB96XN`$UA`$A434P@9F]R<N%S;NEZ970@:VDO8F4`5&]G;P!4
M;VME;&%U`$AO;&YA<`!4;VYG80!F]FS\;`!,96=F96QS]2!F<F%M92`H7W1O
M<"D`1F]R9.UTX7-O:P!4<FEN:61A9"#I<R!4;V)A9V\`26=A>B!V86=Y(&AA
M;6ES`$ME`%1U;NEZ:6$`5/9R]FMO<G-ZX6<`=/9R]FL@*$E33RTX.#4Y+3DI
M`%3\<FMM96YI<WITX6X`5'5R:W,M(.ES($-A:6-O<RUS>FEG971E:P!4=79A
M;'4`S7)J82!B92P@;6ET(';A;&%S>G1O='0Z(`!55B!I;F1E>#H@`%523`!5
M4DPL(&UE;'EE;B!E9WD@<')O9W)A;2!E;&9O9V%D:F$@82!S>F]L9^%L=&%T
M\R#A;'1A;"!K_&QD]G1T(&O\;&3V='0@:^EZ8F5S[73I<VD@:F5L96YTZ7-T
M`%523#H`56=A;F1A`%5K<F%J;F$`3F5M('-I:V5R_&QT(&$@5D93(&%L:_9N
M>73A<F)A(&)E;.EP;FDN`$$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6<@
M:6?I;GELZ7-E:V]R(&YE;2!S:6ME<OQL="!A>B!A9&%T;VL@96QTX7)O;.%S
M82X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(B!61E,@9N%J;"!E;.ERZ7-I(&IO
M9V]S=6QT<^%G86ET(&UE9W;A;'1O>G1A=&YI+@!.96T@<VEK97+\;'0@82AZ
M*2`E<R\E<R!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET(&UE9W;A
M;'1O>G1A=&YI+@!.96T@<VEK97+\;'0@82AZ*2`E<R!A;&OV;GEV=.%R8F$@
M8F5LZ7!N:2X`02AZ*2`B)7,B(.%L;&]MX6YY(&WI<F5T92!N96T@X6QL87#M
M=&AA=/,@;65G+@!!*'HI("(E<R\E<R(@X6QL;VWA;GD@;>ER971E(&YE;2#A
M;&QA<.UT:&%T\R!M96<N`$%Z(%-13"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN
M`$%Z(%-33"!K87!C<V]L870@;F5M(.EP[71H973U(&9E;"X`02!61E,@9N%J
M;"!N96T@;>%S;VQH873S(.%T+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B(%9&
M4R!A;&OV;GEV=.%R="!LZ71R96AO>FYI+@!.96T@<VEK97+\;'0@;.ET<F5H
M;WIN:2!A(%9&4R!A;&OV;GEV=.%R="X`3F5M('-I:V5R_&QT(&SI=')E:&]Z
M;FD@82!61E,@9N%J;'0N`$$H>BD@(B5S(B!61E,@;6%P<&$@;F5M(&AO>FAA
M=/,@;.ET<F4N`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI(/QR97,@5D93(&;A
M:FQT+@!!('3V;?9R[71E='0@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!K:6)O
M;G1A;FDN`"(E<R(@;F5M('3V<O9L:&5T]2P@87H@86QK]FYY=G3A<B!N96T@
M_')E<RX`(B5S(B!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,N`"5S(&YE;2!T
M]G+V;&AE=/4L(&%Z(&%L:_9N>79TX7(@;F5M(/QR97,N`$$@5D93(&%L:_9N
M>79TX7(@;F5M('3V<O9L:&5T]2!R96MU<GKM=F%N+@!!(%9&4R!A;&OV;GEV
M=.%R(&YE;2!T]G+V;&AE=/4N`$$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L
M:&5T]3H@)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@=/9R]FQH973U+@!!
M(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N`$$H>BD@(B5S(B!61E,@;6%P<&$@
M;F5M('3V<O9L:&5T]2X`3F5M(';I9V5Z:&5T\R!R96MU<GKM=B!T]G)LZ7,@
M82!61E,M8F5N.B`E<RX`3F5M(&AA=.%R;WIH873S(&UE9R!A(&IE;&5N;&5G
M(.ER=NEN>65S(&%L:_9N>73A<BX`02!T86[Z<^UT=N%N>2!RZ7-Z;&5T97,@
M861A=&%I(&YE;2!H873A<F]Z:&%T\VL@;65G`$YE;2!S:6ME<OQL="!B96]L
M=F%S;FD@)7,@9&5F:6[M8VGS:N%T+@!!(%9&4R!FX6IL(&YE;2!H96QY97IH
M973S(.%T+@!!*'HI("(E<R(@5D93(&;A:FP@;F5M(&YY:71H873S(&UE9RX`
M02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G(.URX7-I(&/I;&QA;"X`02!6
M1E,@9N%J;"!N96T@;GEI=&AA=/,@;65G("X`02!T]FWV<NUT971T(.%L;&]M
MX6YY(&YE;2!N>6ET:&%T\R!M96<N`$$@5D93(&;A:FP@;F5M(&]L=F%S:&%T
M\R`H82!F:6QE<VEZ92@I('-I:V5R=&5L96X@=F]L="DN`$$@5D93(&;A:FP@
M;F5M(&]L=F%S:&%T\R`H82!G971&:6QE4VEZ92@I('-I:V5R=&5L96X@=F]L
M="DN`$5Z(&$@9N%J;"!N96T@;VQV87-H873S.B``02!V9G-R;V]T(&%L:_9N
M>79TX7(@;F5M(&]L=F%S:&%T\RX`)7,@;F5M(&YE=F5Z:&5T]2#A="`E<R!N
MZ79R93H@;>%R(&SI=&5Z:6L@:6QY96X@;F5V^R!M87!P80!!(%9&4R!A;&OV
M;GEV=.%R(&YE;2!N979E>FAE=/4@X70N`$$@5D93(&%L:_9N>79TX7(@;F5M
M(&YE=F5Z:&5T]2#A=#H@)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@;F5V
M97IH973U(.%T+@!!*'HI("5S+R5S(%9&4R!FX6IL(&YE;2!N979E>FAE=/4@
MX70N`$$@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`07H@)VUK:7-O9G,G
M('!R;V=R86T@;F5M(&9U='1A=&AA=/,N`$YE;2!S:6ME<OQL="!L969O<F3M
M=&%N:2!E>G0@82!7;W)D(&1O:W5M96YT=6UO=`!!*'HI("(E<R(@5D93(&;A
M:FP@;F5M(.UR:&%T\RX`02!61E,@9N%J;"!N96T@[7)H873S("AA(&-O<'DH
M*2!S:6ME<G1E;&5N('9O;'0I+@!!(%9&4R!FX6IL(&%D871A:2!N96T@[7)H
M873S:R!K:2X`02!61E,@9N%J;"#M<N%S82!K=O-T873Z;&SI<.ES(&UI871T
M(&YE;2!F96IE>FAE=/4@8F4N`&%LX6CZ>F]T=`!-Z6=S92!M96YT<_QK(&5L
M`%9I<W-Z879O;FIA(&%Z('5T;VQS\R!VX6QT;WIT873A<W0`02!K87!C<V]L
M870@9F5L=NET96SI="!K]G9E=/5E;B!VX7)A=&QA;B!VX6QA<WH@Z7)K97IE
M='0@82!S>F5R=F5R=/5L.B``5N%R871L86X@=N%L87-Z(.ER:V5Z971T(&$@
M<WIE<G9E<G3U;"!E<G)E.B``0F5S;W)O;&%T;&%N`%5N:6-O9&4@*%541BTX
M*0!%9WEE<_QL="!!<F%B($5M[7)SZ6=E:P!%9WEE<_QL="!+:7+A;'ESX6<`
M16=Y97/\;'0@P6QL86UO:P!%9WEE<_QL="#!;&QA;6]K+"!K:7-E8F(@:_QL
M<_4@<WII9V5T96L`96=Y<^EG`$ES;65R971L96X`27-M97)E=&QE;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+@!)<VUE<F5T;&5N(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN`$$@;65G861O='0@:&5L>2!I<VUE<F5T;&5N
M+@!)<VUE<F5T;&5N(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!J96QS>O,N`%3A
M=F]L[71S=6L@96P@:6YN96X@82!L:6YK970`3FEN8W,@96QN979E>G9E`$)I
M>G1O;G/A9VD@;VMO:V+S;"!A(&9E;&AA<WINX6SS:2!P<F]G<F%M;VL@;F5M
M(&AA<WINX6QH871JX6L@82!+:7;A9^%S+TWA<V]LX7,O0F5I;&QE<WITZ7,@
M;?-D<WIE<G0N($MA='1I;G1S;VX@87H@3TL@9V]M8G)A+"!H82!A(&UO>FEL
M;&$N;W)G('=E8F]L9&%L;VX@96P@:^UVX6YJ82!O;'9A<VYI(&$@=&5C:&YI
M:V%I(&QE[7+A<W0@;65L>2!M96=A9&IA+"!H;V=Y86X@;&5H970@97IT(&WI
M9VES(&5N9V5DZ6QY97IN:2X`02!S>NUN('9I<W-Z8>%L;.UTX7-A`$YE;2!T
MX6UO9V%T;W1T(&5X=&5N>FGS`$WS9&]S[73A<P`E<R!A9&%T86EN86L@;?-D
M;W/M=.%S80!!(&9E;&AA<WINX6SS(&%D871A:6YA:R!M\V1O<^UTX7-A`"(E
M<R(@=N%L=&]ZX7-A:70@96QM96YT971T_&LN`$%Z('5P9W)A9&4@<')O9W)A
M;6]T('3V<O9L=/QK+@!&96QT]FQTZ7,`07H@]G-S>F5S(&%L:V%L;6%ZX7,@
M:V]N9FEG=7+A8VGS:N%T(&9E;'3V;'3V='3\:R!A('-Z97)V97)R92X`;&%T
M:6X@;F%G>6)E=/MK`&YA9WEB973[<R!R\VUA:2!S>N%M;VL`57)U9W5A>0!(
M87-Z;N%L:G5K(&$@:F5L96YL96=I=#H@)7,`2&%S>F[A;&IU;FL@4U-,+70`
M06MK;W(@:&%S>F[A;&IU:RP@:&$@87H@24U34"!S>F5R=F5R96X@;>%S(&$@
M8F5J96QE;G1K97KI<VD@;F5V_&YK+VIE;'-Z879U;FLN`$9E;&AA<WINX6SS
M:2!NZ78`)7,@9F5L:&%S>F[A;/,@;F5M(&IO9V]S=6QT("5S+7)E+@!&96QH
M87-Z;N%L\VL@861M:6YI<WIT<N%LX7-A`$9E;&AA<WINX6SS:2!B9>%L;.UT
MX7-O:P!"96IE;&5N=&ME>NES(&IO9V]S=6QT<^%G(&EGZ6YY;.ES90!%>F5N
M(&$@<F5N9'-Z97)E;B!N:6YC<R!E;F=E9.EL>65Z=F4@87H@^FH@9F5L:&%S
M>F[A;/-K(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%GX6YA:R!I9^EN>6SI
M<V4N`$%Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=/,@;F5M('1A;.%L:&%T\P!&
M96QH87-Z;N%L\VD@;NEV`$$H>BD@(B5S(B!F96QH87-Z;N%L\VD@;NEV(&WA
M<B!LZ71E>FEK+@!&96QH87-Z;N%L\VD@;NEV.@!&96QH87-Z;N%L\VD@;NEV
M.B``02!R96YD<WIE<B!F96QH87-Z;N%L\VDZ`-QZ8F5G:7-Z=.%N`$$@5D93
M(&%L:_9N>79TX7(@;F5M(&SI=&5Z:6LN`%-Z86)A9'/A9R!A;&%T=&D@875T
M;VUA=&EK=7,@96UA:6PM=N%L87-Z`$$@:_9V971K97KU(&AE;'EE:V5T('1A
M;.%L='5K.B``R7)VZ6YY97-SZ6<`07H@Z7)TZ6ME:V5T('!E<F-B96X@861J
M=6L@;65G+"!M;W-T86YT\VP@<WKA;>UT=F$N`$$@Z7)TZ6L@;F%G>6]B8BP@
M;6EN="!A(&QE9VYA9WEO8F(@;65G96YG961E='0@:&]S<WKZ<^%G.B`E<RX`
MR7)TZ6ME:P!6X6QA<WIT:&%T\R#I<G3I:V5K`%9A;G5A='4`=N%L=&]Z\P!6
M96YE>G5E;&$`02!H:71E;&5S[73I<R!N96T@<VEK97+\;'0@+2!L96AE="P@
M:&]G>2!A(&QE=F5L970@=F%L86MI(&UE9W;A;'1O>G1A='1A+@!697)Z:?,`
M5F5R>FGS:_9V973I<P!&_&=G+B!E;&AE;'EE>NES`$;\9V?U;&5G97,@8F5L
M<_4@;6%R9_,`9OQG9_5L96=E<SH`;F%G>6]N(&UA9V%S`%9I971N86T`=FEE
M=&YA;6D@*%9)4T-)22D`)7,@;65G=&5K:6YTZ7-E`$O\;'/U('=E8F]L9&%L
M(&UE9VIE;&5N[73I<V4`2F5L96[M='/\:R!M96<L(&UI;G0@)7,`0G)I="!6
M:7)G:6XM<WII9V5T96L`06UE<FEK86D@5FER9VEN+7-Z:6=E=&5K`$SA=/-T
MX79O;'/A9P!,X73S=.%V;VQSX6<Z(`!6;V1A9F]N92!)=&%L>2!S>F]L9^%L
M=&%TX7,@4TU44"UN(&ME<F5S>G3\;`!&24=914Q-15I4153)4P!&24=914Q-
M15I4153)4R$@2\E:6D5,(%3!5D],S51302!%3"!!(%-#4DE05$54("5S+5+5
M3"X`5TE.('-Z;VQGX6QT873A<R!(5%10+6X@X70`5V%L;&ES(.ES($9U='5N
M80!&:6=Y96QM97IT973I<P!3>F4`263U:N%RX7,@96SU<F5J96QZZ7,`07H@
M:63U:N%RX7-I(&%D871O:R!F;W)RX7-A`%=E8@!796)H96QY96L`:&5T96YT
M90#<9';V>O9L:OQK`-QD=O9Z]FQJ_&LZ("5S`-QD=O9Z]FQJ_&LL("5S`&YY
M=6=A="UE=7+S<&%I("A)4T\M.#@U.2TQ*0!N>75G870M975R\W!A:2`H25-/
M+3@X-3DM,34I`$YY=6=A="U3>F%H87)A`$UI;'EE;B!A;&MA;&UA>N%S="!M
M=71A<W-O;B`E<R!A(&)E:F5L96YT:V5ZZ7,@=73A;C\`36D@87H@96QVX6QA
M<WIT\R!K87)A:W1E<C\`36D@87H@:63I>F5T:V%R86MT97(_`%=H97)E:7,@
M075S>G1RX6QI82!TZ7)KZ7``365L>6EK(&-I:VQU<P!-96QY:6L@;6]D=6QO
M:V%T(&%K=&EVX6QJ=6L@82!2:6-H(%1E>'0@961I=&]R8F%N/P!3>NEL97-S
MZ6<`4WKI;&5S<^EG($-34R!E9WESZ6=B96X`02`E<R!M96[\('-ZZ6QE<W/I
M9V4@82!B86P@;VQD86QO;B`H82!K]G9E=&ME>O4@8F5J96QE;G1K97KI<W0@
M:_9V973U96X@;&5S>B#I<G;I;GEE<RD`02!TX6)LX7IA="!S>NEL97-SZ6=E
M`$$@<WKI;&5S<^EG(&WI<G3I:V5G>7/I9V4`4WKI;&5S<^EG.@!7:6MI`%-Z
MZ6P`4WKI;"!A(')E9V=E;&D@\W+A:V)A;@!3>NEL<V5B97-SZ6<@8W-O;?-B
M86X`4WKI;#H`4WKI;#H@`$+V;&-S97-SZ6<`2^UVX6YSX6=L:7-T80!-=6YK
M80!-=6YK86AE;'EI(&/M;0!-=6YK86AE;'EI('1E;&5F;VX`02`E9"X@<V]R
M8F%N(&YE;2!M96=F96QE;/4@82!M97KU:R!S>N%M82X@5N%R=#H@)60L('1A
M;.%L=#H@)60N`$YE;2!M96=F96QE;/4@82!M97KU:R!S>N%M82X@5N%R=#H@
M)60L('1A;.%L=#H@)60N`$AI8N%S(&]F9G-E="`H)60I(&$@5D93(&;A:FP@
M;VQV87/A<V%K;W(N`$QI;G5X(&9O<G+A<VOS9"!K97)E<WIR969E<F5N8VEA
M`%@U,#EV,R!A;&%P=F5T]2!K;W)LX71O>N%S;VL`6#4P.78S(&MI=&5R:F5S
M>G1E='0@:W5L8W-H87-Z;N%L870`6#4P.78S('1U;&%J9&]N;W,@86QT97)N
M873M=B!M96=N979E>NES90!8-3`Y=C,@='5L86ID;VYO<R!K=6QC<V%Z;VYO
M<^UT\P!8-3`Y=C,@:VET97)J97-Z=.ES96L`65D`65E960!986AO;R$@=.ER
M:^EP`.EV96YT90!*96UE;@!)9V5N`$EG96XL(&)E;&5G>65Z96TN`$UO<W0@
M2%1-3"!415A4(&WS9&)A;B!V86XN($AA<WINX6QJ82!A(%L\/ET@9V]M8F]T
M+"!H82!V:7-S>F$@86MA<B!VX6QT86YI(&$@<WIO:^%S;W,@9W)A9FEK=7,@
M*%=94TE764<I(&UE9VIE;&5N[73I<W)E+@!.96T@:&]Z:&%T(&SI=')E("5D
M(&)L;VMK;N%L('3V8F)E="X`07H@UFX@9F5L:&%S>F[A;/-A>F]N;W/M=.%S
M82!N96T@=/9R=.EN="!M96<N`$$@=&5L:F5S(&[I=F)E;B!N96T@<WIE<F5P
M96QH970@82`G7"<@:V%R86MT97(N`$YE;2!A9&]T="!M96<@Z7)VZ6YY97,@
M96UA:6P@8^UM970N`$YE;2!A9'1A(&UE9R!A(&UE9V9E;&5L=&5TZ7-T(&%Z
M(&EM<&]R=.%L="!FX6IL(.ES(&$H>BD@)7,@;65Z]6D@:_9Z]G1T+@!3:6ME
M<F5S96X@:VEJ96QE;G1K97IE='0N`$5G>2!M;V)I;'1E;&5F;VYS>N%M;W0@
M:V5L;"!M96=A9&YI82P@8W-A:R!A('-ZX6UJ96=Y96ME="P@97-E=&QE9R!E
M9WD@)RLG(&MA<F%K=&5R<F5L(&ME>F1V92P@:&$@;F5M>F5T:_9Z:2!TX7)C
M<^%ZX7-I(&WS9&]T(&OM=N%N(&AA<WINX6QN:2X`16QF;V=A9&AA=/,@Z7)T
MZ6ME="!K96QL(&UE9V%D;FEA+@!!($1A=&%4<F5E(&%L<F5N9'-Z97)T(&)E
M(&ME;&P@X6QL[71A;FD@82!B96IE;&5N=&ME>NES:2!J;V=O<W5L='/A9V]K
M(&EGZ6YY;.ESZ6AE>BX`02!61E,@86QR96YD<WIE<B!N:6YC<R!B9>%L;.UT
M=F$N`$5L]6)B(&QE(&ME;&P@[7)N:6$L(&AO9WD@;6EL>65N('!R;V)LZ6WA
M="!T87!A<WIT86QT+"!M:65L]71T(&5L:_QL9&D@82!H:6)A:F5L96YTZ7-T
M+@!-96<@:V5L;"!A9&YI(&5G>2!54DPM="P@86AO=F$@97H@82!L:6YK(&UU
M=&%T`$MI(&ME;&P@=N%L87-Z=&%N:2!E9WD@=/9R;&5N9/4@<WIE<G9E<G0N
M`$UE9R!K96QL(&%D;FEA+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T
M86ET(&OM=N%N:F$@=/9R]FQN:2X`365G(&ME;&P@861N:6$@87H@96QTX79O
M;.UT86YD\R!F96QH87-Z;N%L\VD@;F5V970N`$UE9R!K96QL(&%D;FEA(&$@
M:&]Z>N%A9&%N9/,@9F5L:&%S>F[A;/,@;F5VZ70N`$UE9R!K96QL(&%D;FEA
M+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N:F$@X73M
M<FYI+@!-96<@:V5L;"!A9&YI82!E9WD@<&%R86YC<V]T+@!-96<@:V5L;"!A
M9&YI82!A>B#Z:B!K871E9_-R:6$@;F5VZ70N`$]L87-Z;W)S>N%G:2!T96QE
M9F]N<WKA;6]T(&ME;&P@;65G861N:6$`07H@UFX@)7,@:V%P8W-O;&%T82!I
M9/5T^FQLZ7#I<R!M:6%T="!M96=S>F%K861T+B!+Z7)E;2!J96QE;G1K97IZ
M96X@8F4@^FIR82X`07H@UFX@96UA:6P@8^UM90!!>B#6;B!F96QA9/-I("A&
M<F]M.BD@8^UM93H`4WIE;>EL>65S(&EN9F]R;>%C:?,`07H@UFX@)7,@:V%P
M8W-O;&%TX6YA:R!K97ID971E(/-T82!M96=VX6QT;WIO='0@87H@:6YT97)N
M970@8^UM92X@0FEZ=&]N<^%GX6YA:R#I<F1E:^EB96X@:7-MZ70@8F4@:V5L
M;"!J96QE;G1K97IN:64N`$%Z(-9N(&YE=F4`07H@UFX@9F5L:&%S>F[A;/-A
M>F]N;W/M=/,@86QR96YD<WIE<F4@;F5M('1E<WII(&QE:&5T]7;I(&%Z(/IJ
M(&9E;&AA<WINX6SS:R!LZ71R96AO>N%SX70N($AA(&$@2&]R9&4@<F5N9'-Z
M97)R96P@:^UVX6YJ82!K97IE;&YI(&$@9F5L:&%S>F[A;/-I(&%D871O:V%T
M+"!A:VMO<B!MX7-I:R!F96QH87-Z;N%L\V%Z;VYO<^UT\R!A;')E;F1S>F5R
M<F4@=F%N('-Z_&MSZ6=E+@!!>B#6;B!F96QH87-Z;N%L\V%Z;VYO<^UT\R!A
M;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U=ND@82!F96QH87-Z;N%L\VL@
M;&ES=.%ZX7/A="P@=F%G>2!V86QA;6D@;VMB\VP@;&5T:6QT;W1TX6L@97IT
M(&$@;&5H973U<^EG970N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&UE9W;A
M;'1O>F]T="!A>B#6;B`E<R!M=6YK86MA<&-S;VQA=.%N86L@:V5Z9&5T92#S
M=&$N($)I>G1O;G/A9V$@Z7)D96OI8F5N(&ES;>ET(&)E(&ME;&P@:F5L96YT
M:V5Z;FEE+@!!>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82!N96T@=.%M;V=A=&IA
M(&5Z="!A(&QE:&5T]7/I9V5T+@!!>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82!N
M96T@=.%M;V=A=&IA(&5Z="!A(&YY;VUT873A<VD@;W!C:?-T+B!0<O-BX6QJ
M;VX@82!#=')L+5`@*'9A9WD@0V]M;6%N9"U0*2!L96YY;VWA<^%V86P@;GEO
M;71A=&YI+@!!(&IE;&5N;&5G(.ER=NEN>65S(&ED]7KS;F$Z`$%Z(-9N(&%L
M87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\VIA(&UE9W;A;'1O>F]T
M="X`07H@UFX@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S[73S:F$Z
M`$%Z(-9N('1E;&IE<R!N979E.@!,96KA<G0@82!B96IE;&5N=&ME>NES:2!J
M;V=O<W5L='/A9V$N`$%Z(-9N("5S+7)E(&AA<WINX6QT(/IJ(&IE;'-Z879A
M.B`E<P!!>B#6;B#Z:B!B9>%L;.UTX7-A:70@Z7)VZ6YY97/M=&5T=/QK(&$@
M;6]S=&%N:2!B96IE;&5N=&ME>NES(&ED96KI<F4N`$%Z(-9N(/IJ(&)EX6QL
M[73A<V%I="!E;&UE;G1E='3\:RX`07H@UFX@:F5L<WIA=N%T(.%TX6QL[71O
M='1U:P!!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T='5K+"!NZ7IZ92!M96<@
M82!L979E;&5I="P@;6%J9"!J96QE;G1K97IZ96X@8F4@87H@^FH@:F5L<WKS
M=F%L+@!!>B#6;B!J96QS>F%VX6YA:R!L96KA<G0@87H@Z7)VZ6YY97-SZ6=I
M(&ED96IE+@!!>B#6;B#A;'1A;"!H87-Z;N%L="!TX79O;&D@<WIE<G9E<F5K
M.@!*=6=O<WILX79I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6TYE(&UU=&%S
M<W5K(&$@8F5I9.EZ971T('-Z]G9E9V5T70!;2&EB86IE;&5N=.ES70!;375T
M87-S=6L@82!B96EDZ7IE='0@<WKV=F5G970@+0!;375T87-S=6L@82!B96ED
MZ7IE='0@<WKV=F5G970@+2`E<R!S;W)=`%LE<R\E<R!S;W)=`%]!9&UI;FES
M>G1RX6-I\P!?4&%R86YC<W-O<@!3;W)T]G)LZ7,`7T-S;W!O<G1O:P!395]G
M[71SZ6<`02!KZ7`@='5L86ID;VYSX6=A:2XN+@!"96IE;&5N=&ME>NES`%]+
M:6IE;&5N=&ME>NES`$$@;&EN:R!M\V1O<^UTX7-A+BXN`%]/<&-I\VL`7TIO
M9V]S=6QT<^%G;VL`02!L:6YK('3V<FSI<V4N+BX`7T)EX6QL[73A<V]K`%3A
M8FSA>F%T('1U;&%J9&]N<^%G;VL`7T9E;&AA<WINX6SS:P!C[6UJ96=Y>NEK
M`&$@8^UM>F5T="!I<VUE<F5T;&5N`&YA<'3A<@!N>75G;V1T`&$@:VEM96YE
M=&D@X6QL;VWA;GD@;F5M(&AO>FAA=/,@;.ET<F4`82!B96UE;O4@X6QL;VWA
M;GD@;F5M(&YY:71H873S(&UE9P!K871T:6YT<V]N(&ED90!P87)A;F-S<V]R
M:2!H:6)A`&MO;F9I9W5RX6-I\W,@:&EB80!H:>%N>7II:R!E9WD@9F]N=&]S
M(')E;F1S>F5RX6QL;VWA;GD`861A=&9O<FWA='5M(&AI8F$`;?-D;W/M=.%S
M`&%Z(&%D870@;F5M('1A;.%L:&%T\P!C<_9K:V5N`&;A:FP`)7,@*"5S*2!I
M<N%N>6+S;"P@)7,@)7,@<V5B97-SZ6=G96P`<WKI;&SV:^ES96L`;3H`82!G
MZ7`@;F5V92!N96T@:7-M97)T`&%Z;VYN86QI`&EN<'5T+V]U='!U="!H:6)A
M`&)E;'/U('!R;V=R86UH:6)A`'-O<ET`07H@;6MS:6]F<R!P<F]G<F%M("5D
M(&AI8F%K\V1D86P@;&7A;&QT(&%Z($E33R#A;&QO;>%N>2!KZ7-Z[73I<V4@
M:_9Z8F5N+@!NZ78`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S
M(&UE9W9A;/-S[71V82X`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI
M;F-S(&UE9W9A;/-S[71V82X`:F5G>7IE='3V;6(`<WKA>F%LZ6L`;FEN8W,@
M;65G9F5L96SU(&IO9V]S=6QT<^%G80!P:7AE;`!A9&%TX71V:71E;&D@*'!R
M;W1O:V]L;"D@:&EB80!E;65L:V5D:6L`82!S>F]L9^%L=&%TX7,@;F5M(.%L
M;"!R96YD96QK97KI<W)E`&[I>GK\:R!M96<@82!K_&SV;F)SZ6=E:V5T`'-M
M<S)E;6%I;"!S>F]L9^%L=&%TX7,@2%144"UN(.%T`';A;'1O>F%T;&%N`')E
M;F1S>F5R:&EB80!F96QA9&%T;&ES=&$`X71M96YE=&D@:&EB80!M96=E<O5S
M[73I<VOI;G0@:^ET<WIE<B#M<FIA(&)E(&$@:F5L<WKS=`!NZ78@;NEL:_QL
M`&$@9F5L:&%S>F[A;/,@X6QT86P@=N%L87-Z=&AA=/,`=D-A<F0`<WHZ````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:'5?2%4O:&5L<"YX;6P`````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,#<V`#$P-#$W,S8R
M-S<W`#`R,#,U-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U
M.2TR(C\^"CPA+2T@2&]R9&4@,RXQ(&AE;'`Z(&AU7TA5("1(;W)D93H@:&]R
M9&4O;&]C86QE+VAU7TA5+VAE;'`N>&UL+'8@,2XR+C$P+C,@,C`P-B\P,R\P
M,R`Q,SHT-#HQ,"!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M<W5M;6%R>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C8X8V$S,V8W9C!C.6%A
M931C,3`S96(T-S0Y,F-D8S$U(CX*/'1I=&QE/D$@<WIE;>EL>65S(/9S<WIE
M9WKU("AP;W)TX6PI(&]L9&%L/"]T:71L93X*(#QP87)A/@H@($5Z(&%Z(&]L
M9&%L(&=Y;W)S(/9S<WIE9WKI<W0@860@87H@UFX@<WKA;>%R82!F;VYT;W,@
M:6YF;W)MX6-I\VMR\VPN"B`@4&PN(&IE;&5Z:&5T:2P@:&]G>2!HX6YY(/IJ
M(&QE=F5L92!V86X@87H@24Y"3U@@;6%P<.%B86XL(&UI;'EE;B`*("!E;&9O
M9VQA;'1SX6=A:2!V86YN86L@8F7M<G9A(&$@:_9Z96QJ]G;U8F5N(&$@;F%P
M=.%R8F%N+"!M:6QY96X*("!E;&EN=.EZ96YD]2!D;VQG;VL@=F%N;F%K(&$@
M9F5L861A=&QI<W3A:N%B86XL(&1E(&UE9VIE;&5N[71H973U"B`@96=YZ6(@
M:_QL<_4@<WIO;&?A;'1A=.%S;VL@=&%R=&%L;6$@:7,L('-T8BX@17IE:V+U
M;"!A>B#V<W-Z96=ZZ7-E:V+U;`H@('-O:W-Z;W(@:_9Z=F5T;&5N_&P@:6YD
M[71H873S:R!A(&=Y86MR86X@:&%S>F[A;'0@9G5N:V-I\VLL('!L+@H@(/IJ
M(&QE=NEL(.URX7-A+"#Z:B!B96IE9WEZZ7,@:^ES>NUTZ7-E(&$@;F%P=.%R
M8F$@=F%G>2!A(&9E;&%D871L:7-TX6)A+"`*("!S=&(N"B`@/"]P87)A/@H@
M/'!A<F$^"B`@12!S>F5MZ6QY97,@]G-S>F5G>O4@;VQD86P@=&%R=&%L;>%T
M(&$@5&5R=F5ZZ7,@9V]M8F)A;"!M\V1O<^UT:&%T:F$N"B`@365G861H871J
M82!P;"XL(&AO9WD@;6EL>65N(&EN9F]R;>%C:?-K870@:^UVX6X@;65G:F5L
M96[M=&5N:2P@Z7,*("!M:6QY96X@96QR96YD97KI<V)E;BX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](G5P=&]D871E
M(B!M9#4](F(X8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I
M=&QE/D%Z(&%L:V%L;6%ZX7-VX6QA<WIT\R!M96[\/"]T:71L93X*(#QP87)A
M/@H@($$@=V5B;VQD86P@8F%L(&]L9&%LX6X@96=Y(&%L:V%L;6%ZX7-VX6QA
M<WIT\R!M96[\('1A;.%L:&%T\RX*("!!(&UE9V9E;&5L]2!F96QI<F%T;VMR
M82!K871T:6YT=F$@9WEO<G-A;B#I<R!K]FYN>65N(.%T=6=O<FAA="!E9WEI
M:PH@(&%L:V%L;6%ZX7-B\VP@82!MX7-I:V)A+@H@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U
M<'1O9&%T92(@;60U/2)D9#DU9&8P-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P
M,"(^"B`@("`\=&ET;&4^3W!C:?-K.B!"96IE;&5N=&ME>NES<V5L(&MA<&-S
M;VQA=&]S(&9E;&%D871O:SH@=NEG<F5H86ITX7,\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!(82!A>G0@<WIE<F5T;NDL(&AO9WD@8F5J96QE;G1K97KI<VMO
M<B!F=7-S86YA:PH@("`@;&4@82!K87)B86YT87)TX7-I(&9E;&%D871O:RP@
M:F5L]FQJ92!B92!A(&[I9WEZ971E="X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E
M/2)U<'1O9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P
M,#,V92(^"B`@("`\=&ET;&4^3W!C:?-K.B!"96IE;&5N=&ME>NES<V5L(&MA
M<&-S;VQA=&]S(&9E;&%D871O:SH@;65G97+U<^UTZ7,\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!(82!A>G0@<WIE<F5T;NDL(&AO9WD@82!R96YD<WIE<B!M
M96=E<O5S[73I<W0@:^ER:F5N(-9N=/5L(&UI96SU='0*("`@(';I9W)E:&%J
M=&%NX2!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K870L(&IE;/9L:F4@8F4@
M97IT(&$@;NEG>7IE=&5T+@H@("`@2&$@;F5M(&IE;/9L:2!B92P@82!K87)B
M86YT87)TX7-I(&9E;&%D871O:R!B96IE;&5N=&ME>NES:V]R(&%U=&]M871I
M:W5S86X@"B`@("!L92!F;V=N86L@9G5T;FDL(&%NZ6QK_&PL(&AO9WD@8F5F
M;VQYX7-O;&AA=&[A(/5K970N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:61?240O````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S<W`#`Q-C8T,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]I9%])1"],0U]-15-304=%4R\`````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#(P-#(V`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VED7TE$+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$V-#`Q-@`Q,#0Q-S,V
M,C<W-P`P,C(P-S$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````!U`P``'````,0;``"=!```;#<```````#@20``
M!````.%)```D````YDD``"D````+2@``&0```#5*```F````3TH```P```!V
M2@``)````(-*```/````J$H```L```"X2@``*````,1*```(````[4H``!4`
M``#V2@``"P````Q+``"%````&$L```H```">2P``#@```*E+```/````N$L`
M`!@```#(2P``#@```.%+```.````\$L```@```#_2P``+@````A,```)````
M-TP```T```!!3```!P```$],```*````5TP```\```!B3```!0```'),```1
M````>$P```@```"*3```"0```)-,```)````G4P``!,```"G3```$````+M,
M```*````S$P```,```#73```#P```-M,```)````ZTP```T```#U3```#P``
M``--```/````$TT```@````C30``)````"Q-```(````44T``!D```!:30``
M#````'1-```.````@4T```,```"030``!0```)1-```*````FDT```,```"E
M30``%P```*E-```*````P4T```X```#,30``(P```-M-```4````_TT``!<`
M```43@``%P```"Q.```7````1$X``!,```!<3@``#P```'!.```&````@$X`
M``L```"'3@``$````)-.```5````I$X``!4```"Z3@``!P```-!.```%````
MV$X``!4```#>3@``.P```/1.```4````,$\```,```!%3P``"0```$E/```Y
M````4T\``"<```"-3P``+````+5/```J````XD\``"4````-4```!@```#-0
M```1````.E````P```!,4```"@```%E0```0````9%```!0```!U4```"```
M`(I0```.````DU````H```"B4```!````*U0```)````LE````8```"\4```
M$0```,-0```'````U5````0```#=4```!@```.)0```-````Z5````,```#W
M4```$P```/M0```(````#U$```0````840``00```!U1```&````7U$``!4`
M``!F40``!P```'Q1```5````A%$```\```":40``#0```*I1```/````N%$`
M``T```#(40``%````-91```&````ZU$``!T```#R40``!@```!!2```4````
M%U(``%0````L4@``9````(%2```$````YE(```X```#K4@``&P```/I2```:
M````%E,``!P````Q4P``*@```$Y3```%````>5,``!,```!_4P``$@```)-3
M```*````IE,```\```"Q4P``#0```,%3```1````SU,```P```#A4P``!@``
M`.Y3```,````]5,```8````"5```$`````E4```1````&E0```4````L5```
M#````#)4```%````/U0```8```!%5```!P```$Q4```-````5%0```D```!B
M5```"0```&Q4```*````=E0``!D```"!5```'0```)M4```,````N50``!``
M``#&5```"````-=4```(````X%0```8```#I5```!````/!4```.````]50`
M`!T````$50``(````")5``"B````0U4``!\```#F50``(`````96```P````
M)U8``)(```!85@``00```.M6```'````+5<```8````U5P``#0```#Q7```0
M````2E<```P```!;5P``#@```&A7```/````=U<``!,```"'5P``#0```)M7
M```H````J5<```,```#25P``#0```-97```1````Y%<``!<```#V5P``&P``
M``Y8```"````*E@``!`````M6```#0```#Y8```#````3%@```X```!06```
M"````%]8```/````:%@```\```!X6```!P```(A8```-````D%@```T```">
M6```"P```*Q8```&````N%@```L```"_6```#````,M8```+````V%@```T`
M``#D6```(@```/)8```*````%5D``!@````@60``&0```#E9```6````4UD`
M`!0```!J60``"P```']9```+````BUD```D```"760``&0```*%9```+````
MNUD``!<```#'60``%P```-]9```)````]UD``!8````!6@``#P```!A:```9
M````*%H``!8```!"6@``)@```%E:``!#````@%H``!\```#$6@``+P```.1:
M```%````%%L```0````:6P``"@```!];```*````*EL``!`````U6P``%P``
M`$9;```1````7EL``!<```!P6P``"0```(A;```*````DEL```(```"=6P``
M#0```*!;```X````KEL``"````#G6P``#@````A<``![````%UP``!@```"3
M7```!0```*Q<```;````LEP```8```#.7```$````-5<```/````YEP``!``
M``#V7```#P````==```/````%UT```P````G70``#P```#1=```'````1%T`
M``X```!,70``"````%M=```3````9%T```0```!X70``!0```'U=```(````
M@UT```H```",70``#````)==```+````I%T``!````"P70``#````,%=```'
M````SET```H```#670``#0```.%=```%````[UT```,```#U70``"@```/E=
M```$````!%X``"8````)7@``#@```#!>``!\````/UX``!4```"\7@``!0``
M`-)>```'````V%X```P```#@7@``"````.U>```*````]EX```8````!7P``
M"`````A?```"````$5\```8````47P``"0```!M?```0````)5\```D````V
M7P``"0```$!?```:````2E\```@```!E7P``&0```&Y?```.````B%\```(`
M``"77P``!@```)I?```-````H5\``!(```"O7P``%````,)?```&````UU\`
M`!$```#>7P``"0```/!?```Y````^E\``#T````T8```.@```')@```$````
MK6```!4```"R8```!@```,A@```$````SV```!$```#48```"@```.9@```B
M````\6````0````480``!0```!EA```.````'V$```4````N80``#P```#1A
M```2````1&$```L```!780``)@```&-A```I````BF$``"0```"T80``)@``
M`-EA```(`````&(```H````)8@``"0```!1B```2````'F(```H````Q8@``
M#````#QB```/````26(``!````!98@``<````&IB```.````VV(```D```#J
M8@``"@```/1B```2````_V(``!,````28P``!@```"9C```/````+6,``!(`
M```]8P``$````%!C```1````86,``&H```!S8P``#P```-YC```0````[F,`
M``L```#_8P``(`````MD```4````+&0```P```!!9```#````$YD```/````
M6V0``!4```!K9```*0```(%D```J````JV0``"8```#69```)P```/UD```I
M````)64``"H```!/90``&0```'IE``!"````E&4``!$```#790``$@```.EE
M```3````_&4``!0````09@``%@```"5F```7````/&8``!````!49@``$0``
M`&5F```T````=V8``!,```"L9@``$@```,!F```4````TV8``!H```#H9@``
M"0````-G```1````#6<```8````?9P``!P```"9G```6````+F<```0```!%
M9P``!````$IG```'````3V<```X```!79P``#````&9G```,````<V<```T`
M``"`9P``#@```(YG```$````G6<```\```"B9P``!P```+)G```(````NF<`
M``D```##9P``%````,UG```,````XF<```T```#O9P```P```/UG```&````
M`6@``!D````(:```!````")H```-````)V@```H````U:```$````$!H```/
M````46@``!$```!A:```%P```'-H```*````BV@``!$```"6:```"````*AH
M```/````L6@```P```#!:```#@```,YH```0````W6@```L```#N:```&@``
M`/IH```*````%6D```P````@:0``#P```"UI```(````/6D```8```!&:0``
M!P```$UI```%````56D```L```!;:0``!````&=I```#````;&D``!,```!P
M:0``$P```(1I```3````F&D```(```"L:0``!````*]I```%````M&D```0`
M``"Z:0``"@```+]I```-````RFD``&@```#8:0``!0```$%J```&````1VH`
M``\```!.:@``&````%YJ```7````=VH``!\```"/:@```P```*]J```(````
MLVH```<```"\:@``"@```,1J```+````SVH```T```#;:@``&@```.EJ``!*
M````!&L```8```!/:P``!@```%9K```8````76L``!<```!V:P``#0```(YK
M``!7````G&L```(```#T:P``"P```/=K```(`````VP```H````,;```"P``
M`!=L```,````(VP```T````P;```#````#YL```*````2VP``!8```!6;```
M"0```&UL```0````=VP``!(```"(;```!P```)ML```%````HVP```P```"I
M;```"````+9L```7````OVP```P```#7;```&@```.1L```3````_VP```0`
M```3;0``"@```!AM```$````(VT```4````H;0``.````"YM```*````9VT`
M``\```!R;0``$P```()M```5````EFT``!,```"L;0``"````,!M```(````
MR6T``"L```#2;0``10```/YM``!!````1&X```0```"&;@``$P```(MN```4
M````GVX``!,```"T;@``!P```,AN```%````T&X``!L```#6;@``"````/)N
M```1````^VX```X````-;P```@```!QO```.````'V\```<````N;P``#@``
M`#9O```&````16\``"@```!,;P``#````'5O```<````@F\``!<```"?;P``
M7````+=O```4````%'```!\````I<```$````$EP```'````6G````X```!B
M<```#````'%P```*````?G```!T```")<```&0```*=P```%````P7```!$`
M``#'<```$0```-EP```(````ZW````D```#T<```#0```/YP```*````#'$`
M``<````7<0``#P```!]Q```&````+W$```L````V<0``&@```$)Q```*````
M77$```<```!H<0``#0```'!Q```(````?G$``!X```"'<0``"0```*9Q```*
M````L'$``!4```"[<0``!0```-%Q```4````UW$```0```#L<0``$````/%Q
M```&`````G(```<````)<@``'@```!%R```H````,'(``!P```!9<@``&@``
M`'9R```4````D7(```0```"F<@``!@```*MR```&````LG(```H```"Y<@``
M&P```,1R```T````X'(``#0````5<P``*0```$IS```H````=',``"D```"=
M<P``4````,=S```(````&'0```4````A=```&0```"=T```9````070``",`
M``!;=```&0```']T```(````F70``!<```"B=```"@```+IT```'````Q70`
M`"$```#-=```#@```.]T```3````_G0```@````2=0``!0```!MU```%````
M(74```0````G=0``"@```"QU```)````-W4```L```!!=0``#0```$UU```,
M````6W4```X```!H=0``!````'=U```R````?'4``$4```"O=0``%P```/5U
M```>````#78``!0````L=@``!P```$%V```.````278``"H```!8=@``!@``
M`(-V```,````BG8``!$```"7=@``"P```*EV```V````M78```H```#L=@``
M(@```/=V```+````&G<```\````F=P``!0```#9W```.````/'<``!,```!+
M=P``!P```%]W```1````9W<``!,```!Y=P``%````(UW```8````HG<```<`
M``"[=P``!0```,-W```2````R7<```X```#<=P``#@```.MW```%````^G<`
M``4`````>```+@````9X```F````-7@``",```!<>````P```(!X```-````
MA'@```D```"2>````P```)QX```*````H'@```(```"K>```$@```*YX```$
M````P7@```<```#&>```#````,YX``!2````VW@``!<````N>0``$@```$9Y
M```'````67D```8```!A>0``#@```&AY```5````=WD``!(```"->0``#P``
M`*!Y```4````L'D``&D```#%>0``&@```"]Z```7````2GH``"<```!B>@``
M&@```(IZ```7````I7H``!L```"]>@``&0```-EZ```?````\WH``!,````3
M>P``"````"=[```)````,'L``$8````Z>P``/P```(%[```W````P7L``%<`
M``#Y>P``!0```%%\```?````5WP``"\```!W?```"````*=\```-````L'P`
M`"T```"^?```!````.Q\``!/````\7P``"4```!!?0``'P```&=]```=````
MAWT``"4```"E?0``(````,M]```D````['T``"`````1?@``!P```#)^```-
M````.GX```P```!(?@``%P```%5^```0````;7X```0```!^?@``"P```(-^
M```,````CWX``!(```"<?@``$0```*]^```,````P7X``!H```#.?@``#0``
M`.E^```;````]WX``!,````3?P``'````"=_```H````1'\```<```!M?P``
M$P```'5_```$````B7\``!<```".?P``"@```*9_```,````L7\```D```"^
M?P``!@```,A_```(````SW\```D```#8?P``!@```.)_```-````Z7\```L`
M``#W?P```@````.````)````!H````<````0@```&@```!B````[````,X``
M`"@```!O@```-````)B````5````S8````<```#C@```"````.N````'````
M](````4```#\@```!P````*!```.````"H$```D````9@0``!@```".!```(
M````*H$```L````S@0``!P```#^!```'````1X$``!$```!/@0``"````&&!
M```0````:H$``!````![@0``!P```(R!```%````E($``!0```":@0``"P``
M`*^!```-````NX$``"@```#)@0``%P```/*!```)````"H(```H````4@@``
M!P```!^"```"````)X(```X````J@@``,0```#F"```G````:X(``!0```"3
M@@``J0$``*B"```C````4H0``!<```!VA```'0```(Z$```8````K(0``"$`
M``#%A```'P```.>$```K````!X4``!T````SA0``$0```%&%```G````8X4`
M`%0```"+A0``"P```."%```Q````[(4```<````>A@``!P```":&```-````
M+H8```L````\A@``!0```$B&```0````3H8```4```!?A@``$@```&6&```(
M````>(8```,```"!A@``$````(6&```,````EH8```(```"CA@``%````*:&
M```,````NX8```,```#(A@``!````,R&```:````T88```D```#LA@``#```
M`/:&```7`````X<```<````;AP``#P```".'```%````,X<``!H````YAP``
MQP```%2'```+````'(@```8````HB```"0```"^(```+````.8@```T```!%
MB```%P```%.(```&````:X@``#,```!RB```$P```*:(```3````NH@``#(`
M``#.B```$P````&)```1````%8D``#(````GB0``%@```%J)```(````<8D`
M``D```!ZB0``"@```(2)```4````CXD```@```"DB0``"````*V)```/````
MMHD```X```#&B0``$````-6)```)````YHD```D```#PB0``$P```/J)```9
M````#HH```H````HB@``#````#.*```J````0(H```<```!KB@```@```'.*
M```0````=HH``!@```"'B@```P```*"*```(````I(H```<```"MB@``#0``
M`+6*```+````PXH``!0```#/B@``%0```.2*```O````^HH``"`````JBP``
M'````$N+```,````:(L``#$```!UBP``!0```*>+```_````K8L``!(```#M
MBP``"@````",```&````"XP```0````2C```!````!>,```*````'(P``!,`
M```GC```!0```#N,```&````08P```8```!(C```"````$^,```$````6(P`
M``4```!=C````@```&.,```,````9HP``$4```!SC```,@```+F,``!%````
M[(P``#`````RC0``*````&.-```I````C(T``"8```"VC0``)0```-V-```H
M`````XX``!(````LC@``$P```#^.```0````4XX```D```!DC@``<P```&Z.
M```K````XHX``!<````.CP``)P```":/```6````3H\```\```!ECP``'P``
M`'6/```<````E8\``%$```"RCP``%`````20```%````&9```!(````?D```
M$````#*0```3````0Y````\```!7D```!````&>0```)````;)````L```!V
MD```!P```(*0```4````BI````\```"?D```#````*^0```/````O)````8`
M``#,D```%````-.0```&````Z)````0```#OD```!P```/20```9````_)``
M``<````6D0``!@```!Z1```&````)9$```0````LD0``!P```#&1```&````
M.9$```8```!`D0``$````$>1```&````6)$``"(```!?D0``!P```(*1```+
M````BI$``$8!``"6D0``!@```-V2```L````Y)(``"P````1DP``%@```#Z3
M``!`````59,```P```"6DP``,````*.3```5````U),``!(```#JDP``)```
M`/V3```(````(I0``!L````KE```#0```$>4``"_````590```@````5E0``
M#@```!Z5```5````+94``!@```!#E0``#0```%R5```-````:I4```8```!X
ME0``*P```'^5```*````JY4```H```"VE0``"````,&5```*````RI4``!``
M``#5E0``!0```.:5```2````[)4```L```#_E0``.@````N6```\````1I8`
M`!$```"#E@``#0```)66```)````HY8```8```"ME@``$````+26```.````
MQ98``!````#4E@``%0```.66```3````^Y8```\````/EP``+0```!^7```/
M````39<``"4```!=EP``#````(.7```,````D)<```4```"=EP``!````*.7
M```(````J)<```4```"QEP``$P```+>7```*````RY<``!````#6EP``,@``
M`.>7```4````&I@``!0````OF```'````$28```6````89@``!(```!XF```
M#P```(N8```'````FY@```@```"CF```#P```*R8```4````O)@``!L```#1
MF```"0```.V8```%````]Y@``!,```#]F```20```!&9```3````6YD```0`
M``!OF0``"@```'29```]````?YD``"P```"]F0``+````.J9```K````%YH`
M`"T```!#F@``!P```'&:```4````>9H```L```".F@``#@```)J:```4````
MJ9H``!0```"^F@``.0```-.:```/````#9L```D````=FP``"P```">;```4
M````,YL```8```!(FP``$````$^;```&````8)L```@```!GFP``!0```'";
M```-````=IL```,```"$FP``#0```(B;```(````EIL```8```"?FP``50``
M`*:;```%````_)L``!@````"G```"P```!N<```2````)YP```P````ZG```
M,0```$><```,````>9P``!8```"&G```%````)V<```&````LIP``!D```"Y
MG```!````-.<```/````V)P``&8```#HG```:````$^=```(````N)T```\`
M``#!G0``%P```-&=```7````Z9T``"4````!G@``,P```">>```)````6YX`
M`!8```!EG@``%@```'R>```2````DYX``!<```"FG@``&````+Z>```1````
MUYX```T```#IG@``!P```/>>```4````_YX```<````4GP``&````!R?```/
M````-9\```4```!%GP``#0```$N?```%````69\```8```!?GP``!P```&:?
M```-````;I\```@```!\GP``!P```(6?```'````C9\``!4```"5GP``*```
M`*N?```+````U)\``!````#@GP``!@```/&?```&````^)\```8```#_GP``
M!0````:@```-````#*```"8````:H```)````$&@``"[````9J```",````B
MH0``)0```$:A```Q````;*$``+T```">H0``5````%RB```&````L:(```0`
M``"XH@``"0```+VB```)````QZ(```X```#1H@``$P```."B```.````]*(`
M`!$````#HP``#0```!6C```W````(Z,```4```!;HP``#0```&&C```1````
M;Z,``!<```"!HP``&P```)FC```"````M:,``!````"XHP``$````,FC```$
M````VJ,```L```#?HP``"````.NC```-````]*,``!`````"I```!P```!.D
M```-````&Z0```T````II```"````#>D```%````0*0```D```!&I```"@``
M`%"D```)````6Z0```L```!EI```)P```'&D```+````F:0``!T```"EI```
M&0```,.D```9````W:0``!````#WI```"0````BE```,````$J4```L````?
MI0``'P```"NE```+````2Z4``!(```!7I0``$@```&JE```)````?:4``!<`
M``"'I0``$0```)^E```=````L:4``!T```#/I0``*0```.VE``!6````%Z8`
M`"H```!NI@``.````)FF```+````TJ8```0```#>I@``"P```..F```)````
M[Z8```D```#YI@``$@````.G```3````%J<``!(````JIP``"@```#VG```)
M````2*<```(```!2IP``#````%6G``!!````8J<``"$```"DIP``#P```,:G
M``"=````UJ<``!H```!TJ```"0```(^H```F````F:@```0```#`J```#P``
M`,6H```.````U:@```\```#DJ```#@```/2H```3`````ZD```P````7J0``
M$P```"2I```(````.*D``!<```!!J0``"````%FI```6````8JD```4```!Y
MJ0```P```'^I```(````@ZD```<```",J0``"````)2I```0````G:D``!8`
M``"NJ0``#````,6I```&````TJD``!\```#9J0``'P```/FI```%````&:H`
M``@````?J@``#0```"BJ```'````-JH``"\````^J@``$P```&ZJ``"?````
M@JH``!<````BJP``"````#JK```'````0ZL```P```!+JP``!P```%BK```)
M````8*L```4```!JJP``"@```'"K```#````>ZL```4```!_JP``!````(6K
M```1````BJL```T```"<JP``#````*JK```B````MZL```8```#:JP``'```
M`.&K```4````_JL```@````3K```!@```!RL```0````(ZP``!,````TK```
M$0```$BL```$````6JP```D```!?K```"0```&FL``!.````<ZP``%````#"
MK```4````!.M```(````9*T``!4```!MK0``!@```(.M```'````BJT``!H`
M``"2K0``#````*VM```?````NJT```8```#:K0``!0```.&M```.````YZT`
M``4```#VK0``'@```/RM```[````&ZX```L```!7K@``.@```&.N```N````
MGJX``"0```#-K@``+@```/*N```*````(:\```L````LKP``!P```#BO```9
M````0*\```H```!:KP``#0```&6O```0````<Z\```\```"$KP``F@```)2O
M```-````+[````H````]L```"P```$BP```2````5+```!,```!GL```#0``
M`'NP```1````B;```!8```";L```$P```+*P```9````QK```),```#@L```
M#@```'2Q```0````@[$```D```"4L0``(0```)ZQ```9````P+$```\```#:
ML0``#@```.JQ```1````^;$``!D````+L@``-````"6R```T````6K(``#0`
M``"/L@``-````,2R```P````^;(``#`````JLP``&P```%NS``!!````=[,`
M`!<```"YLP``%P```-&S```9````Z;,``!D````#M```'````!VT```<````
M.K0``!D```!7M```&0```'&T```\````B[0``!0```#(M```$@```-VT```5
M````\+0``!<````&M0``"@```!ZU```Y````*;4```P```!CM0``!P```'"U
M```4````>+4```0```"-M0``!````)*U```$````E[4```L```"<M0``$P``
M`*BU```)````O+4```H```#&M0``#@```-&U```)````X+4```X```#JM0``
M"````/FU```&`````K8``"`````)M@``&````"JV```@````0[8``!(```!D
MM@``!0```'>V```(````?;8``!X```"&M@``!````*6V```'````JK8```<`
M``"RM@``%````+JV```:````S[8```<```#JM@``%@```/*V```(````";<`
M``T````2MP``#0```""W```1````+K<```P```!`MP``#P```$VW```4````
M7;<```P```!RMP``'P```'^W```-````G[<```P```"MMP``&@```+JW```&
M````U;<```4```#<MP``!P```.*W```%````ZK<```L```#PMP``!0```/RW
M```&`````K@``!D````)N```&````".X```9````/+@```(```!6N```!```
M`%FX```%````7K@```4```!DN```"P```&JX```,````=K@``&P```"#N```
M!0```/"X```&````]K@``!$```#]N```+@````^Y```L````/KD``"D```!K
MN0```P```)6Y```+````F;D```<```"EN0``"@```*VY```-````N+D```P`
M``#&N0``'````-.Y``!%````\+D```8````VN@``!@```#VZ```L````1+H`
M`"L```!QN@``"0```)VZ``!R````I[H```,````:NP``"P```!Z[```&````
M*KL```@````QNP``"@```#J[```4````1;L``!8```!:NP``%````'&[```*
M````AKL``!0```"1NP``"````*:[```1````K[L``!@```#!NP``!P```-J[
M```,````XKL```T```#ONP``"@```/V[```<````"+P```H````EO```%P``
M`#"\```4````2+P```8```!=O```"P```&2\```*````<+P```4```![O```
M2P```(&\```4````S;P``!X```#BO```'0````&]```B````'[T``",```!"
MO0``$````&:]```.````=[T``#<```"&O0``8````+Z]``!;````'[X```D`
M``![O@``(@```(6^```9````J+X``!(```#"O@``#````-6^```'````XKX`
M`"\```#JO@``"````!J_```,````([\```P````POP```@```#V_```.````
M0+\```<```!/OP``$@```%>_```&````:K\``"(```!QOP``"@```)2_```7
M````G[\``!X```"WOP``:P```-:_```9````0L```"(```!<P```#@```'_`
M```'````CL```!````"6P```%````*?````(````O,```!8```#%P```&@``
M`-S````)````]\````X````!P0``#````!#!```(````'<$```D````FP0``
M"@```##!```*````.\$```L```!&P0``$````%+!```(````8\$``"H```!L
MP0``'@```)?!```)````ML$``!<```#`P0``$````-C!```%````Z<$``!8`
M``#OP0``!@````;"```&````#<(``!(````4P@``!0```"?"```7````+<(`
M``0```!%P@``&0```$K"```%````9,(```8```!JP@``(0```''"```S````
MD\(``"0```#'P@``$0```.S"```1````_L(``!,````0PP``!````"3#```%
M````*<,```\````OPP``(@```#_#```[````8L,``$0```">PP``+P```./#
M```I````$\0``"T````]Q```8@```&O$```'````SL0```<```#6Q```%P``
M`-[$```6````]L0``"(````-Q0``'````##%```'````3<4``!P```!5Q0``
M"````'+%```%````>\4``"<```"!Q0``#0```*G%```1````M\4```8```#)
MQ0``!0```-#%```%````UL4```4```#<Q0``$@```.+%```8````]<4```<`
M```.Q@``$@```!;&```<````*<8```P```!&Q@``!````%/&```]````6,8`
M`%P```"6Q@``&0```//&```<````#<<``!4````JQP``"````$#'```-````
M2<<``"D```!7QP``"0```(''```0````B\<``!4```"<QP``$@```++'``!%
M````Q<<```D````+R```'P```!7(```2````-<@``!8```!(R```#0```%_(
M```2````;<@``!<```"`R```!0```)C(```2````GL@``!8```"QR```%@``
M`,C(```8````W\@```D```#XR```!0````+)```1````",D```X````:R0``
M#@```"G)```&````.,D```8````_R0``-@```$;)```L````?<D``"P```"J
MR0``"````-?)```)````X,D```D```#JR0```P```/3)```*````^,D```,`
M```#R@``%P````?*```&````'\H```D````FR@``#@```##*``!?````/\H`
M`!X```"?R@``*0```+[*```0````Z,H```D```#YR@``#P````/+```9````
M$\L``!(````MRP``#````$#+```=````3<L``'D```!KRP``%````.7+```5
M````^LL``"P````0S```$@```#W,```3````4,P``!L```!DS```&````(#,
M```@````F<P``!4```"ZS```!P```-#,```)````V,P``%X```#BS```.@``
M`$'-``!`````?,T``%0```"]S0``!0```!+.```=````&,X``"X````VS@``
M!P```&7.```0````;<X``#D```!^S@``"0```+C.``!5````PLX``#$````8
MSP``(P```$K/```B````;L\``",```"1SP``'P```+7/```E````U<\``"``
M``#[SP``!P```!S0```4````)-```!H````YT```&0```%30```3````;M``
M``4```""T```#0```(C0```-````EM```!H```"DT```(````+_0```0````
MX-```"(```#QT```#````!31```:````(=$``!0````\T0``(````%'1```H
M````<M$```L```";T0``)P```*?1```$````S]$``!D```#4T0``#````.[1
M```.````^]$```X````*T@``"````!G2```'````(M(``!(````JT@``!@``
M`#W2```J````1-(```H```!OT@```P```'K2```X````?M(```@```"WT@``
M&P```,#2``!)````W-(``"L````FTP``,P```%+3```;````AM,```D```"B
MTP``#P```*S3```1````O-,```4```#.TP``#P```-33```A````Y-,``!``
M```&U```$0```!?4```2````*=0``#$````\U```"````&[4```G````=]0`
M`"T```"?U```)P```,W4```.````]=0```X````$U0``!P```!/5```%````
M&]4``!@````AU0``!````#K5```%````/]4``"$```!%U0``%0```&?5```*
M````?=4```T```"(U0``$````);5```#````I]4```X```"KU0``+0```+K5
M```L````Z-4``!<````5U@``'0(``"W6```=````2]@``!8```!IV```(```
M`(#8```7````H=@``",```"YV```)````-W8```[`````MD``"`````^V0``
M%@```%_9```E````=MD``%X```"<V0``#@```/O9```N````"MH```4````Y
MV@``!0```#_:```/````1=H```P```!5V@``!0```&+:```8````:-H```@`
M``"!V@``$0```(K:```%````G-H```0```"BV@``$0```*?:```)````N=H`
M``,```##V@``$@```,?:```+````VMH```,```#FV@``!````.K:```E````
M[]H```L````5VP``$@```"';```;````--L``!````!0VP``#P```&';```$
M````<=L``"<```!VVP``&0$``)[;```2````N-P```H```#+W```#0```-;<
M```3````Y-P``!@```#XW```'0```!'=```&````+]T``#,````VW0``&```
M`&K=```9````@]T``#H```"=W0``%0```-C=```4````[MT``#D````#W@``
M(````#W>```-````7MX```X```!LW@``#@```'O>```9````BMX```<```"D
MW@``"````*S>```-````M=X``#8```##W@``,0```/K>```)````+-\```T`
M```VWP``$````$3?```8````5=\```T```!NWP``#@```'S?```Y````B]\`
M``H```#%WP``!````-#?```-````U=\``!H```#CWP```P```/[?```(````
M`N````X````+X```%````!K@```2````+^```!0```!"X```%0```%?@```S
M````;>```"4```"AX```*0```,?@```.````\>```#P`````X0``!0```#WA
M``!'````0^$```L```"+X0``"@```)?A```&````HN$```0```"IX0``!0``
M`*[A```2````M.$``!T```#'X0``!@```.7A```&````[.$```X```#SX0``
M$`````+B```)````$^(```4````=X@```@```"/B```/````)N(``&(````V
MX@``-@```)GB``!.````T.(``#4````?XP``+@```%7C```[````A.,``#L`
M``#`XP``,P```/SC```W````,.0``!$```!HY```$@```'KD```.````C>0`
M``D```"<Y```?````*;D```M````(^4``!D```!1Y0``)````&OE```7````
MD.4``!(```"HY0``(P```+OE```=````W^4``&$```#]Y0``$P```%_F```%
M````<^8``!P```!YY@``$0```);F```:````J.8```T```##Y@``!````-'F
M```)````UN8```L```#@Y@``!0```.SF```2````\N8```P````%YP``!```
M`!+G```1````%^<```8````IYP``$0```##G```(````0N<```8```!+YP``
M!0```%+G```7````6.<```T```!PYP``%@```'[G```&````E><```0```"<
MYP``!@```*'G```%````J.<```0```"NYP``$P```+/G```%````Q^<``"D`
M``#-YP``"@```/?G```+`````N@```$```#/````7`(``!P"``#1`@``````
M`),````4````0`(``#H#``!L`0``L````$@#``#<`@```````(H"```H`P``
M$@```&X#`````````````%\#````````X0````````#D`@``&@(```````!Y
M````1P(`````````````X@```$X"``"_`@``/`$```````#7`0``\@```)(!
M``"``0``+P(``'`````T`P``:P```$L``````````````)P!``#N````<@,`
M`/$!``!5`@``$`$```,`````````:P$```````!\````)P```*8!```'`@``
M?0(``)@```"\`@```````!L!``!H````#``````````.`0``/P(```````!T
M`0````````````"7`@```````!\``````````````````````````````#8`
M``!S`0``A@(``/L```"+`@``]P(``"4#``!B`@``O`$``)L!```U````GP``
M`!L`````````F0(``.8````E````!0,``(<!``"/`0```````#T"````````
M"0```$T"``!=````9@(``($"``!C````DP$``',#````````7`,````````W
M`P``4P```!<`````````\`$``*L````"`@``!P```%8#``"L`0``GP$`````
M``#_`@```````/X"```.`P``CP(```8"``#S`0``AP```'`"``!9`P``````
M`)H```!/````Q@(``",```"S`````````-4"````````H0$``$,```#J````
M=@(```````#,`0``%@$``+H```!/`0``#`$``&0!```R`P``,````+H!``"M
M`0``,P,``!$!``#1`0````````<#````````(0```)4!```1`@``.P(``$H!
M````````[`$```````#%`@``)`$`````````````)@````````#O`0``M```
M`/0!``"'`@``*`(``-X!``#*````?0````````"#`0``,@$``,X```"Q`0``
M:@$``/\```#]`0``<`,``%\```"0`0```````&@#``"[`0``-P(``/$```!H
M`@``8P(``+@"``#@`0``S`(```````!O````M@````````#J`@```````)4"
M`````````````!P`````````^P$```````#8`@``:P,``!,"``!$`P``>P$`
M`&$"``!C`P``<@$``.0!```Z`@```````&D!`````````````&<#````````
M[0(```````"L````=P(``'<!``"^`0``50,``-P!``!#`0```````%\!``!/
M`@``10(```````!3`@``O0$``&T#```.`@``80,``!0!``"+````(@,``!`"
M```A`P``K`(``-,"``````````````````!_`@``LP(`````````````````
M``````#K````U`$```````#B`0``J0```+<"````````"`$```````"H`@``
M`0,`````````````&@,``-X```"4`0``<@```"P```#.`0```````$("```^
M`@``@`(````````M`P``CP````````!]`0``@@```)$"``#4`````````)@!
M``!X`0``9P$``"`#``#``0``K@$```````#E`````````),"``#H`0``````
M`',```!)`0``3@```$$"````````-0$````````R`@``F0$``,<"``"[`@``
M9`(`````````````<0(``$0!``!Q`````````"4"``!_````RP```(T````]
M`P``UP(```````!B````%0,```<!`````````````(,```"C`@``I`(``/H"
M`````````````(4```!9`0``A0$```````!U`P```````$P#````````9@$`
M`)<!````````"````&<````!`@``G0$``(D!```5`@``V@$```````#Q`@``
M-@$``'<````K`0```````/<````&````?`$````````6`@``=0``````````
M```````````````:`0``F@$``&,!````````^````&`````Q`@``,`(`````
M``!2`@``3`(``+D```!^`0``'@,````````A`0``*0```$8#``#+`@``*```
M`#0"```%````M`$``%(!``#0`0``;@$``$<!``"?`@`````````````G`0``
M!`$``#X`````````70(````````X`0``]0```-\```!A`0```````%(```"%
M`@``@0```(X"```=````%0$``!@"```I`P``T@$``-H`````````H`$``/,`
M``"E`0``#P(``)@"````````4`(``*8````4`P``B0(```````#L`@``6```
M````````````_0```#`#`````````````%`!```D````\````(``````````
MU0`````````U`@``/`,``#P```#(`0``T0``````````````TP```+\`````
M````N`````(#`````````````(@"```X`P``2@,``/<!````````V@(`````
M``!Z````90(``'4"``!Z`@``Q0$`````````````*`$``,(```"O`0``W0$`
M`!T!````````T@````4!``!+`P```````,4````3`P``Z````,L!```Q`P``
MX0(``$0"``"J`0``HP`````````$`@``P0$``)("``!0````/0```'X"```1
M````1P```/D```#5`0``QP```'@"``"U`````````)8```````````````\#
M``!@`@``L@(``#,!``#G````(P(``"X"``!Z`0``30```",!``!'`P``````
M````````````J0(```````!7````J`$```````!S`@````````````!J`P``
MG0```#H!````````[@$``"L#````````(`(``!8````F`0``7@,````````"
M`0``W0```*T"``#I`````````&T!``"A`@``[P(``&H"`````````````/H`
M``!#`P``(````$8```!I````````````````````M0(``/\!````````````
M``T```!I`P``VP$```4"```3`````````/@!``#9````E@$``*D!``!L````
M`````"X`````````[@(``%D````Y`P```````.4!``!8`@``+`$``+0"````
M````'P(``)H"``"!`0``10,``&8```"V`0``:@```$@!``"^`@``*@$``$H"
M```B````:0(``"P#``!1````#0$``'0```!O`@````````````">`@``8@$`
M```````-`P`````````````Q````@@(``/D!``#F`@``````````````````
M,P```+<``````````````+P`````````:P(``$\#``"9```````````````*
M`@``H````*X`````````6@$``'0"``#O````>P(``.,"```^`P``;@(``%$#
M````````#@`````````[````20(``"X!``"G`0```````%L!``">`0``BP$`
M`)L```!,`````````"H"````````.@````````!`````Z0(`````````````
M%P$``!(!``!P`0``50````````#?`@``6@(``/8````X`@`````````````P
M`0``S0```#8"```I`@``40(``"\!``#U`@``0@$``(D```#V`0```````'D!
M``!M`@``E0```%D"`````````@```!````!\`@``&`,``!,!``"$````````
M`"8#```1`P```````+X``````P````````````!-`0``B@$``&4```"Y`0``
M=@```%X````T`0``U`(``(P!````````)0$``*8"```X````K@(```````#`
M````6P``````````````80```.T!``".`0``N`$````````+`0``:`$```H#
M``!4`P``-````!T"``!%````-P```,0````_`0``"@``````````````&0(`
M`#D"``#)`0``(@(``-D"```&`0``&@```.<"```,`@``5P$```````"7````
M`````+<!```N`P```````*H````M````0`$``.@"```6`P````````````#'
M`0```````*4"```M`@``'@```+$"``#T````PP$`````````````H`(``%\"
M``"1````'@$``+H"````````JP$``%L#````````V````#P"```$````2P$`
M``P#```<`P```````&\#`````````````$0```#[`@``"@$``#4#````````
M,P(``$8!```)`P```````+T"``"1`0``R@$``"$"`````````````,,```#P
M`@``@P(``,$"```/``````(``+T```#U`0```````,("````````6P(`````
M``!V`0```````+`!```C`P``7`$``$X#```;`@``0@````````#R`0``V0$`
M`-`"``#B`@```````,T!``!)````N0(``!@!``#Y`@``]`(``.4"```9`0``
MQ@```#D!```G`@``0P(``"L"``!%`0````````````",````B`$```````!L
M`@```````)(```#G`0``SP$``)`"``#]`@````````````!O`0``;0``````
M``"R`0``&0```-@!```2`P``7@(``%@!``"&````4P$```,!````````````
M`#L#``!E`P``A@$``/X````;`P``ZP(``*L"``!R`@``SP(``-,!````````
M$`,``'X```#``@``[0```"0"``"S`0``00````````"O`@````````````#6
M`0``````````````````H0`````````&`P``90$``)T"```I`0``A`$``+4!
M```+`@``,@````````"P`@``````````````````1@(```````"G````"`(`
M`)0```#,````S@(``'\!```B`0``.P$```````"<`@``)P,``%<#````````
MH@````````#^`0``20,``-("````````G````&P#`````````````/,"``!"
M`P``/P,``.L!``#D````C@````````#@`@```````#D`````````)@(``%4!
M``!T`P``C0$``'L```!:`P``Q`$````````O````&0,```````#V`@``````
M`,D```!1`0```````%0"````````I````#T!````````W``````````K````
M;@```%T#```4`@``%P,```````"B`0``/P```$`#``",`@``PP(```````#\
M`0```````-`````$`P```````-8"``#\`````````+(```#?`0``4P,``$@"
M`````````````'D"```+`P``8`$``%8"``#(`@``Q@$``#X!```V`P``"0$`
M`%T!``!G`@``00,``!<"````````Q`(``*H"``#6````3@$``,@```#=`@``
M``````````!>`0``>````*\```````````$``"`!````````'`$``*,!````
M````%0```"\#``#;````E@(``)0"```J`P``````````````````"P```'$!
M``"*````NP``````````````#P$``/("``#7```````````````W`0``````
M`$L"``#-`@``P0```!X"``#;`@``FP(``*("````````5P(``/P"``"0````
M8@,``!T#```2`@``IP(``.$!``!-`P```````.P```#Z`0```P(```````"_
M`0```````,D"``"-`@``5`$``.,``````````````$P!`````````````(@`
M``!@`P``"0(``(0"``!*````Y@$``'$#```D`P``9````%0```!!`0``7```
M`"T!``#C`0```````((!``#*`@``6`,``%(#```!`0``*@```*0!``#@````
M`````'4!````````#0(``.H!````````6@```&8#`````````````%8```!(
M````+`(``*4```"Q````&````````````````````&0#``#X`@``5@$``#$!
M``"V`@``G@```!\#``!0`P``'P$```@#```#`P``P@$``.D!````````````
M`*T``````````````*@```#>`@```"!A="``(B5S(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR
M9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD
M("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD
M87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!497)M<R!O9B!!9W)E
M96UE;G0`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+@`E<R!M:6YU=&5S`"5S('1O("5S(&]F("5S`"P@
M9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`,3(@2&]U
M<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!32!#;&]U9',`
M04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W
M97)S`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O
M;0!!8G-M:61D;&4`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W
M;W)D`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@2&5R93H`
M061D($YE=R!'<F]U<`!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M96UB97)S
M`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A
M<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,@
M0F]O:P!!9&UI;FES=')A=&EO;@!!9',`06QI9VX`06QI9VYM96YT.@!!;&P`
M06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@9F]U<B!S
M:61E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;'1E
M<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E
M<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!
M;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;G-W97(`07!P
M;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D
M>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC
M("A7:6YD;W=S+3$R-38I`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R;65N:6%N("A!4DU3
M0TE)+3@I`$%R=`!!<V-I:2!!<G0`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('-H87)E+@!!=6=U<W0`079A:6QA8FQE(&9I96QD<SH`
M0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"86QT
M:6,@*$E33RTX.#4Y+3$S*0!"87-E;&EN90!";&]C:R!3971T:6YG<P!";&]C
M:R!4>7!E`$)O;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S
M.@!";W)D97)S`$)O=&@`0F]T=&]M`$)U;&QE=&5D($QI<W0`0TU3`$-?96QL
M(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86X@;F]T(')E<V5T('!A
M<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+@!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A<'1I;VX`0V%T
M96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I
M;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;'1I8R`H25-/
M+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*0!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O
M<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R
M871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C
M7VL@3&EN:RXN+@!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S
M92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#
M;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%
M87)L>0!#;&]U9'D`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R
M<P!#;VQO<@!#;VQO<B!0:6-K97(`0V]L<SH`0V]M:6-S`$-O;6UA;F0`0V]M
M;6%N9"!3:&5L;`!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYT86-T
M<P!#;VYT:6YU90!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N
M;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!L
M9&%P('-E<G9E<@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS
M(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&1N)W0@9FEN9"!T
M:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@
M;W!E;BX`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N
M97<@;VYE`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E
M871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S
M96QE8W1I;VX`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A=&%4<F5E
M($)R;W=S97(`1&%T92!296-E:79E9`!$87D`1&5?;&5T92!#;VQU;6X`1&5C
M96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT
M`$1E9F%U;'0@0V]L;W(`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE
M=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!C96QL`$1E;&5T
M92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$
M96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5S8W)I
M8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&5W(%!O
M:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`
M1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I
M;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*0!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"X`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1')U9W,`161I=`!%9&ET($)L;V-K`$5D:70@1W)O
M=7``161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%
M9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C
M871I;VX`16QE;65N="XN+@!%;0!%;6%I;"!!9&1R97-S`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N;&%R9V4@161I
M=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4`17)R;W(`17)R;W(@=7!D871I;F<@<&%S<W=O
M<F0Z("5S`$5T:&YI8P!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E
M<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M<&%N9"!3:61E8F%R`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I
M<@!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@
M4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I;&4@36%N86=E<@!&:6QT97)S
M`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&;&]A=`!&;V<`1F]N="!#;VQO
M<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@
M<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[
M(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B
M;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R
M='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S
M`$9R`$9R86UE<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO
M;VX`1G5L;"!.86UE`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE
M<GDZ`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`
M1V\`1V]E9&5L`$=O;V=L92!396%R8V@`1W)E96L@*$E33RTX.#4Y+3<I`$=R
M;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!'
M=65S=&)O;VL`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+@!(87IE`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L
M<`!(96QP('5S:6YG(&5D:71O<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VUE($1I<F5C=&]R
M>0!(;W)D90!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO
M<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI
M9&ET>3H@`$AU;6]R:7-T<P!)7VYS97)T(%)O=R!"969O<F4`26-O;G,@3VYL
M>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M
M93H`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@
M17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T
M=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!);6%G92!0<F5V:65W.@!);6%G
M92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O
M;2!G86QL97)Y.@!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I
M96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EV:61U86P@57-E
M<G,`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!4
M86)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H
M(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN
M<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C
M;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A
M<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E
M9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF
M>2!,:6YK`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN`$EN=F5N=&]R>0!)<V]L871E9"!4+5-T;W)M<P!)=&%L:6,`
M2F%N=6%R>0!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IU;'D`2G5N90!*=7-T
M:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`
M2G5S=&EF>2!2:6=H=`!+97)N96P@3F5W8FEE<P!+:61S`$MO<F5A;B`H155#
M+4M2*0!,85]Y;W5T`$QA;F=U86=E`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D
M($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87<`3&%Y;W5T
M`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5F=`!,:6=H="!$<FEZ>FQE
M`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`
M3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG
M:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK('!O:6YT
M<R!T;SH`3&EN=7@@0V]O:VEE`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4
M;W!I8W,`3&ES="!486)L97,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M3&ET97)A='5R90!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T
M:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO=F4`3&]W
M`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E
M<B!R;VUA;B!N=6UB97)S`$U-`$U/5$0`36%G:6,`36%I;`!-86EL($%D;6EN
M`$UA:V4@;&EN7VLN+BX`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O
M8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%R8V@`36%R9VEN`$UA
M=&-H:6YG(&9I96QD<P!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E
M;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L
M;V-K<P!-87D`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T<FEC`$UI9&1L90!-
M:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S
M.B``36ES8V5L;&%N96]U<P!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R!A<'!L:6-A=&EO;BX`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69Y
M(%523`!-;V]N(%!H87-E<P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-
M;W-T;'D@4W5N;GD`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N
M`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$Y/+"!)($1O($Y/5"!!9W)E
M90!.971W;W)K`$YE=F5R`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E
M<FYA;64@*&]P=&EO;F%L*0!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D<R!D
M;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U
M<',`3F5X=`!.:6=H=`!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!C:&%N9V4N`$YO(&EC;VYS
M(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&]F9F5N<VEV92!F;W)T
M=6YE<P!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S`$YO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U
M<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.
M;W)T:&5R;B!(96UI<W!H97)E`$YO="!S970`3F]T97,`3F]T:&EN9R!T;R!B
M<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<B!O9B!C;VQU;6YS`$YU
M;6)E<B!O9B!R;W=S`$]+`$]B:F5C="!#<F5A=&]R`$]C=&]B97(`3V9F96YS
M92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E
M(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="X`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A
M(&YE=R!W:6YD;W<`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/
M<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E
M9"!,:7-T`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA
M=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O
M<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!02%`@0V]D90!02%`@4VAE;&P`
M4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W
M97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES
M<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%R=&QY($-L;W5D>0!087-S=V]R
M9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0Z`%!A
M<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R
M;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R
M8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N("(E
M<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E
M<G-O;F%L($EN9F]R;6%T:6]N`%!E=',`4&AO=&]S`%!I>&5L<P!0;&%T:71U
M9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N
M="X`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`
M4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;VQI=&EC<P!0;VQL<P!0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E
M8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5S<W5R90!0<F5S<W5R92!A="!S
M96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O:F5C=',`475E<GD`475O=&$`4F%I;@!286EN($5A<FQY
M`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@
M4VYO=P!286YD;VT@1F]R='5N90!296%D`%)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@
M=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M
M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@
M9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R
M;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!2
M96UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R
M`%)E;6]V92!U<V5R.B`E<P!297-E=`!297-E="!087-S=V]R9`!297-E="!9
M;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E
M(&YE=R!P87-S=V]R9`!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2;U]W(%!R;W!E<G1I97,N
M+BX`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4TU3($UE<W-A
M9VEN9P!344P@4VAE;&P`4U-(`%-?44P@4VAE;&P`4V$`4V%M92!F<F%M92`H
M7W-E;&8I`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T
M:6]N+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O
M=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N<V]R.B``
M4V5P=&5M8F5R`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E
M;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U
M<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO
M;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A
M=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE
M<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T
M<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T
M:&4@<&%R86UE=&5R.B``4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@
M86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9P!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E
M<G,@:6X@=&AE(%9I8VEN:71Y`%-K:7`@36%I;G1E;F%N8V4`4VYO=P!3;F]W
M(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@
M4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z(`!3;VYG<R`F(%!O96US`%-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*0!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E
M;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@
M8V5L;`!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A;0!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI
M="!R;W<`4W!O<G1S`%-T86YD87)D`%-T87(@5')E:P!3=&%T=7,`4W1R:6ME
M=&AR;W5G:`!3='EL92!;0U-370!3=0!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C
M8V5S<V9U;&QY('=R;W1E("5S`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3
M=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`
M4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!4+5-T;W)M`%0M4W1O<FT@
M86YD(%=I;F1Y`%0M4W1O<FUS`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O
M<&5R=&EE<P!487)G970Z`%1A<VMS`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E
M;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(
M:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92!!9&UI;FES=')A=&EO;@!4
M97AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I
M`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES
M(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R
M97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W
M<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE
M<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H
M92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA
M;F0@<VED92!O;FQY`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H
M92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY
M`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AI<R!I<R`E
M<RX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS
M('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM92!4<F%C:VEN9P!4:6UE(&9O
M<FUA=`!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O9&%Y`%1O9V=L92!(5$U,
M(%-O=7)C90!4;VUO<G)O=P!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA
M=&EO;G,`5'4`5'5R:VES:"`H25-/+3@X-3DM.2D`52Y6+B!I;F1E>#H@`%52
M3`!54DPZ`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N9&5R;&EN90!5
M;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YF:6QE9`!5
M;FEC;V1E("A55$8M."D`56YI=',`56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5<&1A=&4`57!D
M871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I
M<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S
M`%5P<&5R(')O;6%N(&YU;6)E<G,`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@
M9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O
M=6YD`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H
M92!S>7-T96TZ`%9A8V%T:6]N`%9A<FEA8FQE`%9E<G-I;VX@0V]N=')O;`!6
M97)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y
M($AI9V@`5FEE=&YA;65S92`H5DE30TE)*0!6:65W(&%N(&5X=&5R;F%L('=E
M8B!P86=E`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!787)N:6YG`%=E`%=E871H
M97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E8@!796(@
M4VET90!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R
M;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=H870@87!P
M;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@
M:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E
M(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA
M8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H
M.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I
M;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!8+5)E9@!960!997,L
M($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E
M<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`
M66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!)
M;F9O<FUA=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO
M=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I
M=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%II
M<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W
M(%%U;W1E9"!497AT("T`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E
M`%]$96QE=&4@4F]W`%]'<F]U<',`7TEM86=E(%!R;W!E<G1I97,N+BX`7TUO
M9&EF>2!,:6YK+BXN`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E
M='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!C86QM`&9A;&QI;F<`
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&EN;&EN90!L:6YE
M<UT`;F%M90!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E
M<P!S=&5A9'D`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U
M;FEF:65D`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@,C`P-2TP
M."TP,PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#4M,#@M,#0@,#DZ,3`K,#(P,`I,87-T+51R
M86YS;&%T;W(Z($IA;65S(#QJ86UE<T!A8W1I;VYM97-S86=E+F-O;3X*3&%N
M9W5A9V4M5&5A;3H@:60@/&ED0&QI+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/553+4%30TE)"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#=B:70*`"!P861A(``B)7,B('-U
M9&%H(&1I=&%M8F%H:V%N(&ME(&1A;&%M('-I<W1E;2!G<G5P+@`B)7,B('-U
M9&%H(&1I=&%M8F%H:V%N(&ME(&1A;&%M(&EZ:6X@<VES=&5M+@`B)7,B(&)E
M;'5M(&1I8G5A=#H@)7,N`"4N,F9-0B!S=61A:"!D:6=U;F%K86X@9&%R:2`E
M+C)F34(@>6%N9R!S=61A:"!D:6EJ:6YK86X@*"4N,F8E)2D`)60@)7,@9&%N
M("5S`"5D(&AA<FD@<V%M<&%I('-A;F1I(&%N9&$@:&%B:7,@;6%S82!B97)L
M86MU;GEA+@`E9"UH87)I(')A;6%L86X@8W5A8V$`)7,@+2!096UB97)I=&%H
M=6%N`$MO;F9I<FUA<VD@+2!/<&5R87-I(%!E;65L:6AA<F%A;B`E<P`E<R!3
M971U<``E<R!3>6%R870M<WEA<F%T(%!E<FIA;FII86X`)7,@<&%D82`E<R`E
M<P`E<R!S:6%P('5N='5K(&UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA
M<F%A;B!Y86YG('-U9&%H(&1I=&%N9&%I(&1I(&)A=V%H(&EN:2X@0F5R:6QA
M:"!T86YD82!P861A(&MO=&%K('1E<G-E8G5T('5N='5K(&]P97)A<VD@;6%N
M87!U;B!Y86YG(&%N9&$@:6YG:6YK86X@=6YT=6L@9&EL86MS86YA:V%N('!A
M9&$@=V%K='4@:6YI+@`E<R!M96YI=``E<R!U;G1U:R`E<R`E<P`L(&%N9VEN
M(&ME;F-A;F<@)7,@)7,`+"!V87)I86)L92!D87)I("5S(&ME("5S`$9O<FUA
M="`Q,B!*86T`1F]R;6%T(#(T($IA;0`R-"!J86T`1&%T86)A<V4@8F%C:V5N
M9"!D:7!E<FQU:V%N('5N='5K(&%R96$@:6YI+@!!32!-96YD=6YG`$%-($=E
M<FEM:7,`04T@2'5J86X`04T@1V5R:6UI<P!!32!'97)I;6ES(%-A;&IU`$%-
M+U!-`%1E;G1A;F<@961I=&]R(&EN:0!496YT86YG+BXN(`!*87)A:R!A;G1A
M<F$@8F%G:6%N(&)A=V%H(&)A<FES(&1E;F=A;B!B86=I86X@8F%W86@@9V%M
M8F%R`$IA<F%K(&%N=&%R82!B86=I86X@=&5N9V%H(&)A<FES(&1E;F=A;B!B
M86=I86X@=&5N9V%H(&=A;6)A<@!);F9O<FUA<VD@06-C;W5N=`!386YD:2!!
M8V-O=6YT`$%K=6YT86YS:0!486UB86@`5&%M8F%H($=R=7`@06YA:P!486UB
M86@@1&ES:6YI.@!486UB86@@1W)U<"!"87)U`%1A;6)A:"!P96YG9W5N82!B
M87)U.@!486UB86@@86YG9V]T82!B87)U`%1A;6)A:"!P87-A;F=A;@!486UB
M86@@365N=2`E<R!S96)A9V%I(%!A;F5L(&YA=FEG87-I($UO>FEL;&$`5&%M
M8F%H('!E;F=G=6YA`%!E;F%M8F%H86X@<&5N9V=U;F$@=&ED86L@9&EA:W1I
M9FMA;BX`0G5K=2!!;&%M870@`$%D;6EN:7-T<F%S:0!):VQA;@!2871A`%!E
M<F%T86%N`%-E;75A`%-E;75A(%!E;F=G=6YA($%S;&D`4V5M=6$@1W)U<`!3
M96UU82!E;7!A="!S:7-I`$EZ:6YK86X@<&5N9V%T=7)A;B!D87)I('1I<&4@
M9&%F=&%R(&YO;6]R(&)E<G5R=70_`%!E;F=G86YT:2!,;V=I;B!)35-0`%!E
M;F=G86YT:2!386YD:2!)35-0`%!E;F=G86YT:2!.86UA(%!E;F=G=6YA($E-
M4U``4&5N9V=A;G1I(&%L86UA="!E;6%I;`!096YG9V%N=&D@=&5M<&QA=&4`
M4&5N9V=A;G1I('1E:W,Z`$IA=V%B86X`07!L:6MA<VD`1&%F=&%R($%P;&EK
M87-I`$%P;&EK87-I('-U9&%H('-I87`N`$1I9W5N86MA;B!U;G1U:R!"86=I
M86X@06YA:P!$:7-E='5J=6D`07!R:6P`07)A8B`H5VEN9&]W<RTQ,C4V*0!!
M<&%K86@@86YD82!Y86MI;B!A;F1A(&EN9VEN(&UE;6EN9&%H:V%N('!E<FUO
M:&]N86X@<&5N9&%F=&%R86X@=6YT=6L@)7,_`$%R;65N:6$@*$%235-#24DM
M."D`4V5N:0!+;V1E($%S8VEI`$UE;6EN=&$@:V]N9FER;6%S:2!S96)E;'5M
M(&UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;C\`365N8V]B82!U
M;G1U:R!M96YG:&%P=7,@9W)U<"!Y86YG('1I9&%K(&%D82X`365N8V]B82!U
M;G1U:R!M96YG:&%P=7,@:7II;B!Y86YG('1I9&%K(&%D82X`365N8V]B82!U
M;G1U:R!M96YG=6)A:"!I>FEN('EA;F<@=&ED86L@861A+@!-96YC;V)A('5N
M='5K(&UE;F=U8F%H(&)A9VEA;B!Y86YG('1I9&%K(&%D82X`06=U<W1U<P!+
M;VQO;2!Y86YG('1E<G-E9&EA.@!!;&%S86X@0D]&2`!,871A<B!"96QA:V%N
M9P!787)N82!,871A<B!"96QA:V%N9P!"86QT:6,@*$E33RTX.#4Y+3$S*0!*
M87)A:R!A;G1A<F$@8F%G:6%N(&)A=V%H(&=A;6)A<B!D96YG86X@9V%R:7,@
M9&%S87(@8F%R:7,`4&5N9V%T=7)A;B!!<F5A`%1I<&4@07)E80!(=7)U9B!4
M96)A;`!0971U;FIU:R!H86QA;6%N('=E8@!";W)D97(`2V5T96)A;&%N($)O
M<F1E<@!";W)D97(`2V5D=6%N>6$`0F%W86@`1&%F=&%R($)U;&QE=`!#35,`
M4')O<&5R=&D@4U]E;`!+86QE;F1E<@!496YA;F<`5&ED86L@9&%P870@;65N
M9V%T=7(@=6QA;F<@<V%N9&D@<V5C87)A(&]T;VUA=&ES+"!S:6QA:V%N(&AU
M8G5N9VD@861M:6YI<W1R871O<B!A;F1A+@!"871A;`!"871A;&MA;B!,87!O
M<F%N($UA<V%L86@`2G5D=6P@5&%B96P`2V%T96=O<FD@9&%N($QA8F5L`%!R
M;W!E<G1I(%-E;`!*87)A:R!S<&%S:2!D87)I(&)O<F1E<B!D96YG86X@=&5K
M<R!D:2!D86QA;2!S96PZ`'!R;W!E<G1I('-E;`!*87)A:R!S<&%S:2!A;G1A
M<B!S96PN`$-E;'1I8R`H25-/+3@X-3DM,30I`%1E;F=A:`!%<F]P82!496YG
M86@@*$E33RTX.#4Y+3(I`%5B86@`56)A:"!386YD:2!!;F1A`%5B86@@;F%M
M82!D86X@86QA;6%T('-E:&EN9V=A(&]R86YG(&1A<&%T(&UE;&EH871N>6$@
M:V5T:6MA(&UE<F5K82!M96UB86-A(&1A;B!M96UB86QA<R!K92!E;6%I;"!A
M;F1A+@!-96YG=6)A:"!S86YD:2!A;F1A('1I9&%K(&1I9'5K=6YG(&1E;F=A
M;B!K;VYF:6=U<F%S:2!Y86YG('-E:V%R86YG+B!3:6QA:V%N(&AU8G5N9VD@
M861M:6YI<W1R871O<B!A;F1A+@!+87)A:W1E<@!097)I:W-A($QI;FLN+BX`
M0VEN82!3961E<FAA;F$@*$=",C,Q,BD`0VEN82!4<F%D:7-I;VYI;"`H0FEG
M-2D`4&EL:6@@8V%R82!U;G1U:R!M96YA;7!I;&MA;B!T86YG9V%L.@!0:6QI
M:"!D869T87(@=&EP92!G87EA("AU;G1U:R!D869T87(@;F]M;W(@8F5R=7)U
M="D`0F5R<VEH:V%N`$)E<G-I:&MA;B!T86<@35-/9F9I8V4`0F5R<VEH:V%N
M('!E;F=G=6YA.B`E<P!"97)S:6AK86X@<&5N9V=U;F$`0F5R<VEH:V%N(&1A
M=&$@<&5N9V=U;F$`0V5R86@@8F5B97)A<&$@<V%A="!L86=I`$ML:6L@=6YT
M=6L@3&%N:G5T`%1U='5P($IE;F1E;&$`365N9'5N9P!-96YD=6YG(&1I('!A
M9VD@:&%R:0!"97)A=V%N`%!E<F)E<V%R(%!A;F5L($YA=FEG87-I(`!097)B
M97-A<B!B;W)D97(`5V%R;F$`4&5M:6QI:"!787)N80!+;VQO;0!#;VUI8W,`
M0V]M;6%N9`!#;VUM86YD(%-H96QL`$MO;7!U=&5R`$MO;F1I<VD`2V]N9&ES
M:0!097)B961A86X@2V]N9FEG=7)A<VD`2V]N9FEG=7)A<VD@<W5D86@@:&%B
M:7,@;6%S82!B97)L86MU;GEA+@!-96YG871U<B`E<P!+;VYF:7)M87-I(%-A
M;F1I`$MO;G1A:P!,86YJ=70`0V]O:VEE`%-A;&EN`%-A;&EN(%!I;&EH86X`
M5&ED86L@9&%P870@=&5R:6MA="!D96YG86X@<V5R=F5R(&QD87``5&ED86L@
M9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P`%1I9&%K(&1A<&%T(&UE
M;F=A='5R('5L86YG('5N='5K('!E;F=G=6YA('EA;F<@9&EM:6YT82X@0F5B
M97)A<&$@871A=2!S96UU82!D971I;"!T:61A:R!B96YA<BX@0V]B82!L86=I
M(&%T874@<VEL86MA;B!H=6)U;F=I(&%D;6EN:7-T<F%T;W(@86YD82!J:6MA
M(&%N9&$@;65M97)L=6MA;B!B86YT=6%N(&QE8FEH(&QA;FIU="X`5&ED86L@
M9&%P870@:V5M8F%L:2!K92!K;VYF:6=U<F%S:2X`5&ED86L@9&%P870@;65N
M>6EM<&%N(&MO;F9I9W5R87-I("5S+@!4:61A:R!D87!A="!M96YY:6UP86X@
M9FEL92!K;VYF:6=U<F%S:2!B86-K=7`@)7,N`%1I9&%K(&1A<&%T(&UE;GEI
M;7!A;B!F:6QE(&MO;F9I9W5R87-I("5S+B!!;F1A(&1A<&%T(&UE;F=G=6YA
M:V%N('-A;&%H('-A='4@9&%R:2!P:6QI:&%N('5N='5K(&UE;GEI;7!A;B!K
M;V1E('1E<G-E8G5T(&ME;6)A;&D@:V4@)7,@871A=7!U;B!M96YY86QI;B!K
M;V1E(&1I(&)A=V%H(&EN:2!S96-A<F$@;6%N=6%L(&ME("5S+@!4:61A:R!D
M87!A="!M96YE;75K86X@4&%N96P@3F%V:6=A<VD@36]Z:6QL82X@4&%S=&EK
M86X@<&%N96P@;F%V:6=A<VD@<W5D86@@=&5R8G5K82X`2W5R<W5S`$)U870`
M0G5A="!L:6YK`$)U870@8F%R=0!786MT=2!396MA<F%N9P!54DP@4V5K87)A
M;F<@861A;&%H`$-U86-A(%-E:V%R86YG`$MO;F1I<VD@4V5K87)A;F<Z`$=A
M>6$@4V5K87)A;F<`2V]S='5M:7-A<VD@='5G87,@=6YT=6L@9&EJ86QA;FMA
M;B!S96)E;'5M(&QO9V]N(&ME("5S+@!(87!U<P!(87!U<R!P:6QI:&%N`$-Y
M<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*0!$1`!$871A5')E92!"<F]W<V5R`%1A
M;F=G86P@1&ET97)I;6$`2&%R:0!(87!U<R!+;VQO;0!$97-E;6)E<@!!;F=K
M82!$97-I;6%L`$UE;F=U<F%N9VD@26YD96X`1&5F875L=`!$969A=6QT(%=A
M<FYA`$1E9F%U;'0@4VAE;&P`1&5F:6YI<VD`2&%P=7,`2&%P=7,@4V5L`$AA
M<'5S($=R=7``2&%P=7,@<V5L`$AA<'5S(&MO;&]M`$AA<'5S('!E;F=G86YT
M:2!T96UP;&%T92!Y86YG('-U9&%H(&%D80!(87!U<R!B87)I<P!(87!U<R!I
M9&5N=&ET87,@>6%N9R!T97)P:6QI:`!(87!U<R!K;VQO;2!Y86YG('-E:V%R
M86YG`$AA<'5S(&)A<FES('EA;F<@<V5K87)A;F<`2F5L87-K86X@36%S86QA
M:`!$97-K<FEP<VD`4&5R:V5M8F%N9V%N`%1I=&EK($5M8G5N`%1I=&EK($5M
M8G5N('5N='5K(&IA;2!T97)A:VAI<CH`5&ET:6L@16UB=6X`07)A:"!K:7)I
M(&ME(&MA;F%N`$%R86@@:V%N86X@:V4@:VER:0!$:7)E:W1O<FD`5&%M<&EL
M:V%N('=A:W1U(#(T(&IA;3\`5&%M<&EL:V%N(%!I;&EH86X`5&%M<&EL:V%N
M(&1E=&EL(')A;6%L86X@8W5A8V$`5&%M<&EL:V%N(')A;6%L86X@8W5A8V$@
M*%1!1BD`2F%N9V%N(&QA;F=S=6YG(&UE;F=A:W-E<R!M86EN=&5N86YC92YP
M:'``07!A:V%H(&)A<FES('EA;F<@<&5R=&%M82!T97)D:7)I(&1A<FD@:V]L
M;VT@;F%M83\@:FEK82!Y82P@8F5R:2!T86YD82!P861A(&MO=&%K(&EN:3H`
M5&ED86L@;65M:6QI:VD@86-C;W5N=#\@4VEL86MA;B!M96YD869T87(N`$1O
M=VYL;V%D(&MO;F9I9W5R87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C
M<FEP="!02%`N`$]B870M;V)A=&%N`%5B86@`56)A:"!";&]K:7(`56)A:"!'
M<G5P`%5B86@@27II;@!58F%H($EZ:6X@=6YT=6L@)7,`56)A:"!P:6QI:&%N
M('5N='5K.@!58F%H(&EZ:6X@=6YT=6L@)7,`4&5N9&ED:6MA;@!%;&5M96XN
M+BX`16T`06QA;6%T($5M86EL`$%K=&EF:V%N('!E;GEI<VEP86X@9V%M8F%R
M+6=A;6)A<B!D87)I($=A;&5R:2!&;W1O(&1I(&1A;&%M('1E:W,_`$%K=&EF
M:V%N(&ML:6L@:V%N86X@;65N=2!K;VYT96MS/P!097)B97-A<B!%9&ET;W(`
M36%S=6MK86X@<&5R=&%N>6%A;B!K96%M86YA;B!D:6UA;F$@86YD82!A:V%N
M(&1I=&%N>6%K86X@87!A8FEL82!A;F1A('!E<FQU('5N='5K(&UE;F=A='5R
M('5L86YG('-A;F1I(&%N9&$L("!C;VYT;V@@)V%P86MA:"!N86UA(&)I;F%T
M86YG(&ME<V%Y86YG86X@86YD83\G.@!-87-U:VMA;B!54DP@9V%M8F%R(&1I
M<VEN:0!+97-A;&%H86X`2V5S86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S
M86YD:3H@)7,`4W5K=0!3971I87`@,34@;65N:70`4V5T:6%P(#(@;65N:70`
M4V5T:6%P(#,P(&1E=&EK`%-E=&EA<"`U(&UE;FET`%-E=&EA<"!S971E;F=A
M:"!J86T`4V5T:6%P(&UE;FET`$-O;G1O:"!N:6QA:2UN:6QA:3H`2F%L86YK
M86X`4&5R8F5S87(@4&%N96P@3F%V:6=A<VD`5V%R;F$@1D<`1E10('5P;&]A
M9"!U;G1U:R!S971U<`!#97)A:`!&87@`1F5B<G5A<FD`4V5P97)T:0!397!E
M<G1I.@!'97)I;6ES(%-E8F%G:6%N`$=E<FEM:7,@4V%L:G4@4V5B86=I86X`
M1FEL92!-86YA9V5R`$9I;'1E<@!&87-E('!E<G1A;6$@9&%R:2!397!A<G5H
M($)U;&%N`$9A<V4@<&5R=&%M82!D87)I(%-E<&%R=6@@0G5L86X`1FQO870`
M0F5R:V%B=70`5V%R;F$@5'5L:7-A;@!-86MA;F%N`%5N='5K(&)R;W=S97(@
M>6%N9R!T:61A:R!D87!A="!M96YD=6MU;F<@9V%M8F%R`%)A;6%L86X@8W5A
M8V$@*%1!1BD`2&%R:2!286UA;&%N($-U86-A("AC871A=&%N(&)A:'=A(')A
M;6%L86X@8W5A8V$@>6%N9R!D:6ME;6)A;&EK86X@86MA;B!M96YG96UB86QI
M:V%N(&)A:6L@<VEA;F<@871A=2!M86QA;2!H87)I+"!S96IU;6QA:"!A;F=K
M82!D87!A="!D:6AA<VEL:V%N('!A9&$@87)E82!I;FDI`$QU<&$@9&5N9V%N
M('-A;F1I(&%N9&$_`$9O<FUU;&ER`%)A;6%L86X`5&EP92!286UA;&%N`%)A
M;6%L86X`4F%M86QA;B`R`$9O<G5M`$1I=&5R=7-K86X`2FUT`$9R86UE`$1A
M<FD`1&5S:W)I<'-I($QE;F=K87``0G5L86X@4'5R;F%M80!.86UA($QE;F=K
M87``1V%L97)I('5N='5K(&UE;F=A;6)I;"!G86UB87(@9&%R:0!'86QE<FD`
M365N9VAA<VEL:V%N("5S($MO;F9I9W5R87-I(`!+;V1E('EA;F<@9&EH87-I
M;&MA;@!*86QA;FMA;@!';V5D96P`4&5N8V%R:6%N($=O;V=L90!9=6YA;FD@
M*$E33RTX.#4Y+3<I`$%D;6EN:7-T<F%S:2!'<G5P`$=R=7``27II;B!T86UU
M`$)U:W4@=&%M=0!(5$U,07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K
M(&UE;F=H87!U<R!S96P@>6%N9R!T97)A:VAI<B!D:2!D86QA;2!B87)I<RX`
M2%1-3$%R96$@9&5N9V%N(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@
M:V]L;VT@>6%N9R!T97)A:VAI<B!D:2!D86QA;2!T86)E;"X`2%1-3$%R96$@
M9&5N9V%N(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@8F%R:7,@>6%N
M9R!T97)A:VAI<B!D:2!D86QA;2!T86)E;"X`0F5R:V%B=70`66%H=61I("A)
M4T\M.#@U.2TX+4DI`%1I;F=G:0!"86YT=6%N`$)A;G1U86X@;65N9V=U;F%K
M86X@961I=&]R`$)E;&%H86X@0G5M:0!);FD@861A;&%H('!E<FUU;&%A;B!D
M87)I(&9I;&4Z`%1I;F=G:0!(;U]M90!$:7)E:W1O<FD@2&]M90!(;W)D90!'
M87)I<R!(;W)I<V]N=&%L(&1I(&1A;&%M($A434P`2F%R86L@9V%R:7,@:&]R
M:7IO;G1A;"!D87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D86QA;2!S96P`
M2&]R:7IO;G1A;#H`0F%G86EM86YA(&-A<F$@86YD82!B:7-A('-A;7!A:2!D
M:7-I;FD_("A3:6QA:V%N(&UE;&%P;W(A*0!"97)A<&$@8F%N>6%K(&MO;&]M
M('EA;F<@:6YG:6X@86YD82!G86)U;F=K86X_`$)E<F%P82!B86YY86L@:V]L
M;VT@>6%N9R!A9&$@9&ES86YA/P!"97)A<&$@8F%N>6%K(&)A<FES('EA;F<@
M:6YG:6X@86YD82!G86)U;F=K86X_`$ME;&5M8F%B86X`2V5L96UB86)A;CH`
M4&5L87=A:P!-87-U:VMA;B!"87)I<R!396)E;'5M;GEA`$AA;GEA(&EK;VX`
M26MO;B!U;G1U:R`E<P!):V]N(&1E;F=A;B!T96MS`$YA;6$@261E;G1I=&%S
M.@!*:6MA(&%N9&$@=&ED86L@;65L:6AA="!I:V]N(&UA;F%P=6X@9&5N9V%N
M(&UE;F=G=6YA:V%N($EN=&5R;F5T($5X<&QO<F5R+"!A;F1A(&UU;F=K:6X@
M<&5R;'4@=6YT=6L@;65N86YD86D@:V]T86L@:6YI('5N='5K(&UE;F]N+6%K
M=&EF:V%N(&ME;&5M86AA;B!03D<N`$QI:&%T($=A;6)A<CH`55),($=A;6)A
M<@!54DP@1V%M8F%R.@!'86UB87(@9&%R:2!G86QE<FD`1V%M8F%R(&1A<FD@
M9V%L97)I.@!'86UB87(M9V%M8F%R`$EM<&]R+"!,86YG:V%H("5D`$MO;&]M
M('EA;F<@9&EI;7!O<CH@)7,`2V]L;VT@>6%N9R!D:6EM<&]R.@!-87-U:VMA
M;B!"87)I<R!"97)I:W5T;GEA`$YA;6$@<&5N9V=U;F$@871A=2!A;&%M870@
M96UA:6P@<&5N9V=A;G1I('1I9&%K(&)E;F%R+B!#;V)A(&QA9VD@871A=2!S
M:6QA:V%N(&AU8G5N9VD@861M:6YI<W1R871O<B!A;F1A(&II:V$@86YD82!M
M96UE<FQU:V%N(&)A;G1U86X@;&5B:6@@;&%N:G5T+@!-96YA;6)A:"!);F1E
M;@!096YG9W5N82!0<FEB861I`$EN9F]R;6%S:0!);F9O<FUA<VD@<W5D86@@
M=&ED86L@9&ES961I86MA;BX`36%S=6MK86X@2V]L;VT@0F5R:6MU=&YY80!-
M87-U:VMA;B!'86UB87(`36%S=6MK86X@5&%B96P`36%S=6MK86X@5V5B($QI
M;FL`36%S=6MK86X@2V]L;VT@4V5B96QU;6YY80!-87-U:VMA;B!K;VQO;2!Y
M86YG(&)A<G4@<V5T96QA:"!K;VQO;2!Y86YG('-E:V%R86YG`$UA<W5K:V%N
M(&MO;&]M('EA;F<@8F%R=2!S96)E;'5M(&MO;&]M('EA;F<@<V5K87)A;F<`
M36%S=6MK86X@8F%R:7,@>6%N9R!B87)U('-E=&5L86@@8F%R:7,@>6%N9R!S
M96MA<F%N9P!-87-U:VMA;B!B87)I<R!Y86YG(&)A<G4@<V5B96QU;2!K;VQO
M;2!Y86YG('-E:V%R86YG`$UA<W5K:V%N('!A<F%G<F%F('-E=&5L86@@<&%R
M86=R868@>6%N9R!S96MA<F%N9P!-87-U:VMA;B!P87)A9W)A9B!S96)E;'5M
M('!A<F%G<F%F('EA;F<@<V5K87)A;F<`36%S=6MK86X@=&5M<&QA=&4@<&5N
M9V=A;G1I`$UA<W5K:V%N(&%L86UA="!E;6%I;"!D:6UA;F$@86YD82!D87!A
M="!M96YE<FEM82!S86YD:2!Y86YG(&)A<G4Z`$UA<W5K:V%N('-E;"!B97)I
M:W5T;GEA`$UA<W5K:V%N('-E;"!S96)E;'5M;GEA`$UA<W5K:V%N(&MO;&]M
M(&)E<FEK=71N>6$`36%S=6MK86X@:V]L;VT@<V5B96QU;6YY80!-87-U:VMA
M;B!P87)A9W)A9B!B97)I:W5T;GEA`$UA<W5K:V%N('!A<F%G<F%F('-E8F5L
M=6UN>6$`36%S=6MK86X@8F%R:7,@8F5R:6MU=&YY80!-87-U:VMA;B!B87)I
M<R!S96)E;'5M;GEA`$UA<W5K:V%N(&IA=V%B86X@>6%N9R!D:7!E<FQU:V%N
M('5N='5K('!E<G1A;GEA86%N(&ME86UA;F%N.@!-87-U:VMA;B]58F%H($=A
M;6)A<@!-87-U:VMA;B]58F%H($QI;FL`07!L:6MA<VD@=&ED86L@=F%L:60N
M`$EZ:6X@:6YD=6L@=&ED86L@=F%L:60N`$EN=F5N=&]R:7,`2'5J86X@<&5T
M:7(@9&ES97)T86D@86YG:6X@<FEB=70@9&D@9&%E<F%H('EA;F<@=&5R<&5N
M8VEL`$AU<G5F($UI<FEN9P!*86YU87)I`$IE<&%N9R`H25-/+3(P,C(M2E`I
M`$IU;&D`2G5N:0!2871A`%)A=&$@5&5N9V%H`%)A=&$@2VER:2!D86X@2V%N
M86X`4F%T82!+:7)I`%)A=&$@2V%N86X`2V5R;F5L($YE=V)I97,`06YA:RUA
M;F%K`$MO<F5A("A%54,M2U(I`%1A;7!I;&%N`$)A:&%S80!&87-E('1E<F%K
M:&ER(&1A<FD@4V5P87)U:"!"=6QA;@!097)U8F%H86X@4V%N9&D@5&5R86MH
M:7(`1F%S92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86X`4&5R=6)A:&%N
M(%1E<F%K:7(Z`$AU:W5M`%1A;7!I;&%N`%1I;F=G86QK86X@:V]S;VYG('1A
M;G!A(&)O<F1E<@!+:7)I`$=E<FEM:7,`1V5R:6UI<P!'97)I;6ES(&1I('!A
M9VD@:&%R:0!'97)I;6ES(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$=E
M<FEM:7,@9&ES97)T86D@<&5T:7(`0F5R<V%L:G4`1V5R:6UI<R!386QJ=0!0
M86YT=6X@2F5N86MA`$QI;FL@;65N=6YJ=6L@:V4Z`$QI;G5X($-O;VMI90!$
M869T87(@1&%T86)A<V4`1&%F=&%R(%1O<&EK($)A;G1U86X`1&%F=&%R(%1A
M8F5L`$1A9G1A<B!P96YG9W5N82!D:6YO;BUA:W1I9FMA;BX`1&%F=&%R($)A
M8V%A;@!786MT=2!L;V-A;#H`5&5M<&%T(%!E<FES=&EW82!D86X@5V%K='4`
M3&]K87-I`$QO9VEN`$QO9R!O=70`3&]G:6X`5'5G87,@3&]G:6X`0VEN=&$`
M4F5N9&%H`%-I;6)O;"!(=7)U9B!K96-I;"!Y=6YA;FD`4VEM8F]L($AU<G5F
M(&ME8VEL(&QA=&EN`%-I;6)O;"!(=7)U9B!K96-I;"!R;VUA=VD`34T`34]4
M1`!3=6QA<`!3=7)A=`!3=7)A="!!9&UI;@!"=6%T(&QI;FLN+BX`365N9V%T
M=7(@9&%F=&%R(&MA=&5G;W)I('EA;F<@:&%R=7,@9&EB97)I(&QA8F5L(&ET
M96TL(&1A;B!W87)N82!Y86YG(&)E<FAU8G5N9V%N("!D96YG86X@:V%T96=O
M<FD@=&5R<V5B=70N`$UA<F5T`$UA<F=I;@!-96YC;V-O:VMA;B!K;VQO;0`@
M4W5H=2!M86MS:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ
M`%-U:'4@;6%K<VEM=6T@>6%N9R!B97)L86YG<W5N9R!S96QA;6$@-B!J86TZ
M`$IU;6QA:"!M86MS:6UU;2!D87)I('!O<G1A;"!Y86YG(&1I8FQO:VER`$UE
M:0!/8F%T+6]B871A;@!!;F=G;W1A`$UE;G4@;6]D93H`1V%B=6YG:V%N('-E
M;``@0W5A8V$@365T87(`07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+@!!
M<F5A($UE=&%R('1I9&%K(&1I<V5D:6%K86XN($1E=&EL('1E;&%H(&1I8V%T
M870@=6YT=6L@861M:6YI<W1R871O<BX`365T<FEK`%1E;F=A:`!3=6AU(&UI
M;FEM=6T@>6%N9R!B97)L86YG<W5N9R!S96QA;6$@,C0@:F%M.@!3=6AU(&UI
M;FEM=6T@>6%N9R!B97)L86YG<W5N9R!S96QA;6$@-B!J86TZ`$QA:6XM;&%I
M;@!+;VYF:6=U<F%S:2!T:61A:R!D:71E;75K86XN($%N9&$@:&%R=7,@;65N
M9VAA<VEK86X@:V]N9FEG=7)A<VD@<V5K87)A;F<@:FEK82!A;F1A(&EN9VEN
M(&UE;F=G=6YA:V%N(&%P;&EK87-I(&EN:2X`4V5N`$UO8FEL92!-86EL`%-E
M9&%N9P!58F%H(%523`!&87-E($)U;&%N`%-E8F%G:6%N(&)E<V%R($-E<F%H
M`%-E8F%G:6%N(&)E<V%R($)E<F%W86X`4V5B86=I86X@8F5S87(@0V5R86@`
M06-C;W5N="UK=0!);F9O<FUA<VD@06-C;W5N="UK=0!0;W)T86QK=0!486UP
M:6QA;B!0;W)T86QK=0!4241!2RP@4V%Y82!4241!2R!3971U:G4`3F5T=V]R
M:P!4:61A:R!P97)N86@`2V%T96=O<FD@0F%R=0!"=6QA;B!"87)U`$YA;6$@
M4&5N9V=U;F$@0F%R=2`H<&EL:6AA;BD`4V%N9&D@0F%R=0!386YD:2!B87)U
M('1I9&%K(&-O8V]K+@!7:6YD;W<@0F%R=2`H7V)L86YK*0!"97)I=&$`1W)U
M<"!"97)I=&$`0F5R:6MU=&YY80!-86QA;0!4:61A:R!A9&$@9&%T82!K;VYF
M:6=U<F%S:2!Y86YG('1E<G-E9&EA('5N='5K(&UE;G5N:G5K:V%N('!E<F)E
M9&%A;B!U;G1U:RX`5&ED86L@861A('!E<G5B86AA;BX`5&ED86L@861A(&EK
M;VX@>6%N9R!D:71E;75K86XN`%1I9&%K(&%D82!L;VMA<VD@>6%N9R!D:6%T
M=7(N`%1I9&%K(&%D82!R86UA;&%N('EA;F<@=&ED86L@<V]P86X`5&ED86L@
M861A('!E;F1A9G1A<F%N('EA;F<@9&ET=6YD82X`5&ED86L@861A(&%T=7)A
M;@!4:61A:R!A9&$@<VES:0!4:61A:R!A9&$@9&ER96MT;W)I('-E;65N=&%R
M82!Y86YG('1E<G-E9&EA('5N='5K(&-A8VAE`%1I9&%K(&%D82!V97)S:2!Y
M86YG(&1I=&5M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!Y86YG(&%S;&DN
M($UE;F=H87-I;&MA;B!K;VYF:6=U<F%S:2!K96UB86QI+@!4:61A:R!A9&$@
M=F5R<VD@>6%N9R!D:71E;75K86X@9&D@9&%L86T@:V]N9FEG=7)A<VD@86YD
M82X@365N9VAA<VEL:V%N(&MO;F9I9W5R87-I(&ME;6)A;&DN`%1I9&%K(&%D
M80!4:61A:R!A9&$@*&1I9W5N86MA;B!S96QE;F=K87!N>6$I`%-C86YD:6YA
M=FEA("A)4T\M.#@U.2TQ,"D`0F5L86AA;B!"=6UI(%5T87)A`$)E;'5M(&1I
M871U<@!#871A=&%N`%1I9&%K(&%D82!Y86YG(&1A<&%T(&1I8G)O=W-E+"!S
M:6QA:V%N(&ME;6)A;&DN`$YO=F5M8F5R`$IU;6QA:"!K;VQO;0!*=6UL86@@
M8F%R:7,`3TL`4&5N8VEP=&$@3V)J96L`3VMT;V)E<@!&:6QT97(@4&5L86YG
M9V%R86X`2V%N=&]R`%-A;F1I(&QA;6$@9&%N(&)A<G4@:&%R=7,@8F5R8F5D
M82X`4V%N9&D@;&%M80!386YD:2!L86UA('1I9&%K(&)E;F%R+@!(86YY82!R
M86UA;&%N('EA;F<@=&ED86L@<V]P86X`2&%N>6$@<&5M:6QI:R!A=&%U('-I
M<W1E;2!A9&UI;FES=')A=&]R('-A:F$@>6%N9R!D87!A="!M96YG=6)A:"!K
M97!E;6EL:6MA;B!A=&%U('!E;6EL:6L@:7II;B!U;G1U:R!B86=I86X`0G5K
M82!D:2!J96YD96QA('EA;F<@8F%R=0!"=6MA(&QI;FL@:6YI(&1I(&IE;F1E
M;&$@>6%N9R!B87)U`%-I<W1E;2!/<&5R87-I`%!I;&EH86X`4&EL:6AA;B!U
M;G1U:R`E<P!$869T87(@3F]M;W(@0F5R=7)U=`!-96YG871U<@!!<&QI:V%S
M:2!T96UP;&%T92!A<VQI`%1E;7!L871E(&%S;&D@9&D@9&%L86T@)7,Z`$QA
M:6XM;&%I;@!);F9O<FUA<VD@3&%I;@!)>FEN(%!E;6EL:6L`2V]D92!02%``
M4$A0(%-H96QL`%!-($=E<FEM:7,`4$T@1V5R:6UI<P!032!"97)S86QJ=0!0
M32!'97)I;6ES(%-A;&IU`%!-($-E<F%H`%!-($AU:F%N('!E=&ER(&1I<V5R
M=&%I(&1E;F=A;B!A;F=I;B!R:6)U=`!%:W-T96YS:2!03U-)6"!T:61A:R!D
M:71E;75K86X`4$A0(%-H96QL`$IA<F%K('-P87-I(&1A<FD@8F]R9&5R`%-E
M8F%G:6%N($)E<F%W86X`4V%N9&D`4V%N9&D@8F5R:&%S:6P@9&EU8F%H+@!3
M86YD:3H`4V%N9&DZ`%-A;F1I(&AA<G5S(&-O8V]K+@!386QI;@!,96MA=&MA
M;B!D87)I(&-L:7!B;V%R9`!0871H`%!E;F1A9G1A<F%N('EA;F<@9&ET=6YD
M83H`3W)A;F<`4&5R<V5N`$UE;&%K<V%N86MA;B!/<&5R87-I(%!E;65L:6AA
M<F%A;@!-96QA:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X@<&%D82!W
M86MT=2!L;V=I;C\`27II;B!U;G1U:R`B)7,B('1I9&%K(&1A<&%T(&1I:&%P
M=7,N`$EZ:6X@061M:6YI<W1R87-I`$EN9F]R;6%S:2!0<FEB861I`$)I;F%T
M86YG($ME<V%Y86YG86X`1F]T;P!0:7AE;`!+871A+6MA=&$@:VQI<V4`4VEL
M86MA;B!K;&EK(&ME(&1A;&%M(&)E8F5R87!A('-E;`!3:6QA:V%N(&MO;F9I
M<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96UI;F1A:&MA;B!E;&5M96X@:6YI
M.@!3:6QA:V%N(&MO;F9I<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96YG:&%P
M=7,@;&EN:R!U;G1U:R!E;&5M96X@:6YI+@!3:6QA:V%N(&UA<W5K:V%N(&YA
M;6$@=6YT=6L@:V%T96=O<FD@>6%N9R!B87)U.@!3:6QA:V%N(&UA<W5K:V%N
M(')I;F=K87-A;B!U;G1U:R!M87-A;&%H+@!3:6QA:V%N(&UA<W5K:V%N(&YA
M;6$@<&5N9V=U;F$@9&%N('-A;F1I(&%N9&$`4VEL86MA;B!M96UB86-A('1E
M:W,@8F5R:6MU="!I;FDN($%N9&$@2$%255,@<V5T=6IU(&1E;F=A;B!S>6%R
M870M<WEA<F%T('5N='5K(&UE;F=G=6YA:V%N('-I<W1E;2X`4&]L:71I:P!0
M;VQL:6YG`%!O<VES:2!U;G1U:R!G86UB87(@:6YI`%!O<VES:2!U;G1U:R!T
M86)E;"!I;FD`2'5J86X@<V%L:G4@=6YT=6L@)7,@:F%M('1E<F%K:&ER.@!+
M96UU;F=K:6YA;B`\8G(O/DAU:F%N('-A;&IU`%1E:V%N86X`5&5K86YA;B!P
M861A('!E<FUU:V%A;B!L875T.@!496MA;F%N.@!,:6AA=`!,:6AA="!G86UB
M87(@9&D@9&%L86T@:F5N9&5L82!Y86YG(&)A<G4`0V5T86L@9&]K=6UE;@!$
M97-K<FEP<VD@36%S86QA:`!0<F]J96L`475E<GD`2W5O=&$`2'5J86X`2'5J
M86X@9&D@<&%G:2!H87)I`$AU:F%N(&)E8F5R87!A('-A870@;&%G:0!'97)I
M;6ES`$AU:F%N(&1A;B!"97)S86QJ=0!(=6IA;B!B97)C86UP=7(@9&5N9V%N
M('-A;&IU`%)A;6%L86X@06-A:P!"86-A`%EA:VEN('5N='5K(&UE;F=H87!U
M<R`E<S\@3W!E<F%S:2!I;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`66%K
M:6X@=6YT=6L@;65M:6YD86AK86X@9&%T82!P96YG9W5N82!U;G1U:R!P96YG
M9W5N82`E<S\@3W!E<F%S:2!I;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`
M56QA;F=I(&%K<VD@=&5R86MH:7(@86YD80!2969R97-H($5L96UE;B!-96YU
M($1I;F%M:7,Z`%)E9G)E<V@@3&EH870@4&]R=&%L.@!$:71A;F1A:0!296UO
M=&4@4V5R=F5R`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I`%!I;F1A:&MA;@!0:6YD86AK86X@0FQO:VER`%!I;F1A:&MA;B!#
M87)A($9O<FUA=`!0:6YD86AK86X@<&%S86YG86X`4&EN9&%H:V%N('-C<FEP
M="!Y86YG('-U9&%H(&1I<VEM<&%N(&1A<FD@9&ER96MT;W)I('-E<G9E<B!S
M96UE;G1A<F$N`%!I;F1A:&MA;@!0:6YD86AK86X@;F]D92!I;FD@9&%R:2!D
M;VMU;65N`%!I;F1A:&MA;B!P96YG9W5N80!0:6YD86AK86X@<&5N9V=U;F$Z
M("5S`$%T=7(@:V5M8F%L:2``071U<B!K96UB86QI(%-A;F1I`$%T=7(@:V5M
M8F%L:2!386YD:2!!;F1A`$AA<VEL`$ME;6)A;&D@:V4@4&EL:6AA;@!+971I
M:R!U;&%N9R!S86YD:2!B87)U`$ME;6)A;&D@:V4@2V]N9FEG=7)A<VD`4&EL
M:6AA;B!%9&ET;W(@4FEC:"!497AT`%1E:V$M=&5K:0!+86YA;@!0<F]P97)T
M:2!"87)I<RXN+@!0<F]P97)T:2!"87)I<P!0<F]P97)T:2!B87)I<P!"87)I
M<SH`071U<F%N`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&1I86YT87)A('-E
M;75A(&)A<FES(&1A;B!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H
M86YY82!D:6%N=&%R82!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H
M86YY82!D:6%N=&%R82!B87)I<P!*86QA;FMA;@!097-A;B!335,`4U%,(%-H
M96QL`%-32`!37U%,(%-H96QL`%-B=`!&<F%M92!Y86YG('-A;6$@*%]S96QF
M*0!3:6UP86X`4VEM<&%N("5S`%-I;7!A;B!0:6QI:&%N`%-I;7!A;B!K;VYF
M:6=U<F%S:2!Y86YG(&1I:&%S:6QK86X@<V5B86=A:2!S8W)I<'0@4$A0(&ME
M(&1A;&%M(&1I<F5K=&]R:2!S97)V97(@<V5M96YT87)A(&%N9&$N`$MO;F9I
M9W5R87-I("5S('-U9&%H(&1I<VEM<&%N+@!396)A9VEA;B!(=6IA;B!P971I
M<B!D:7-E<G1A:2!A;F=I;B!R:6)U=`!);&UU(%!E;F=E=&%H=6%N`%!E;F-A
M<FEA;@!-97-I;B!096YC87)I86X`4&EL:6@@9W)U<"!U;G1U:R!D:71A;6)A
M:`!0:6QI:"!P96UI;&EK(&)A<G4`4&EL:6@@<V5R=F5R`%!I;&EH('!E;F=G
M=6YA('5N='5K(&1I=&%M8F%H`%!I;&EH(&MA<F%K=&5R('EA;F<@86YD82!P
M97)L=6MA;B!D87)I(&MO=&%K+6MO=&%K(&1I8F%W86@@:6YI+B!!;F1A(&1A
M<&%T(&UE;GEA;&EN(&1A;B!M96QE:V%T:V%N;GEA(&ME(&1A;&%M(&%R96$@
M=&5K<RX`4&EL:6@@8F%T87,@=&%N9V=A;#H`4&EL:6@@9F]R;6%T('1A;F=G
M86PZ`%!I;&EH(&ED96YT:71A<R!Y86YG(&EN9VEN(&1I=6)A:"!O;&5H(&%N
M9&$Z`%!I;&EH(&)A=&%S('=A:W1U.@!0:6QI:"!F;W)M870@=V%K='4Z`%!I
M;&EH(&1U82!K;VQO;2!Y86YG(&-O8V]K+@!0:6QI:"!W87)N82!S8VAE;64@
M86YD82X`4&EL:6@@8F%H87-A('EA;F<@86YD82!I;F=I;FMA;CH`2VER:6T@
M3&%P;W)A;B!-87-A;&%H`%-E;G-O<CH`4V5P=&5M8F5R`$%T=7(@<&EL:6AA
M;B!U;G1U:R!M96YG:7II;FMA;B!A;F1A(&1A<&%T(&UE;F=A='5R('5L86YG
M(&ME;6)A;&D@<V%N9&D@86YD82!A<&%B:6QA(&%N9&$@;'5P82X`071U<B!R
M96UO=&4@<V5R=F5R('EA;F<@:6YG:6X@86YD82!A:W-E<R!D87)I('!O<G1A
M;"!A;F1A+@!!='5R(&)A:&%S82P@>F]N82!W86MT=2!D86X@<&EL:6AA;B!T
M86YG9V%L+"!Y86YG(&%N9&$@:6YG:6YK86XN`$%T=7(@87!L:6MA<VD@87=A
M;"!A;F1A+"!W87)N82!S8VAE;64L(&AA;&%M86X@<F5F<F5S:"!D86X@<&EL
M:6AA;B!T86UP:6QA;B!L86EN;GEA+@!3971U<`!38W)I<'0@<V5T=7`@=7!G
M<F%D92!T97)S961I80!"96)E<F%P82!L;VMA<VD@>6%N9R!M=6YG:VEN(&1E
M;F=A;B!P87)A;65T97(Z`$)E;&%N:F$`4FEN9VMA<V%N(%!E;F1E:P!097)L
M=6MA:"!K=6YC:2!A:W-E<R!D:61E9FEN:7-I:V%N('5N='5K(&ME8F%N>6%K
M86X@;&EN:S\`5&%M<&EL:V%N`%1A;7!I;&MA;B!P97)B961A86X@9&EA;G1A
M<F$@:V]N9FEG=7)A<VD@>6%N9R!B87)U(&1I<VEM<&%N(&1A;B!Y86YG(&)A
M<G4@9&EH87-I;&MA;BX`5&%M<&EL:V%N('=A:W1U(&QO9VEN('1E<F%K:&ER
M(&ME=&EK82!A;F1A(&QO9VEN/P!486UP:6QK86X@<&%N96P@;65N=2!T86)E
M;"!O<&5R87-I/P!486UP:6QK86X@365N=2`E<R!D:2!S96)E;&%H(&MI<FD_
M`%1A;7!I;&MA;B!D:6%L;V<@4')O<&5R=&D@4V5L(%1A8F5L`%1A;7!I;&MA
M;B!D:6%L;V<@4')O<&5R=&D@5&%B96P`5&%M<&EL:V%N(&1I86QO9R!0<F]P
M97)T:2!"87)I<R!486)E;`!486UP:6QK86X@9&EA;&]G('!R;W!E<G1I(&=A
M;6)A<@!'97)I;6ES`$=E<FEM:7,@9&D@<&%G:2!H87)I`$=E<FEM:7,@8F5B
M97)A<&$@<V%A="!L86=I`$=E<FEM:7,@9&D@<V5K:71A<B!D865R86@`3&5W
M871I(%!E;65L:6AA<F%A;@!386QJ=0!'97)I;6ES(%-A;&IU`$=E<FEM:7,@
M4V%L:G4`1V5R:6UI<R!386QJ=2!D:2!P86=I(&AA<FD`1V5R:6UI<R!386QJ
M=2!B96)E<F%P82!S86%T(&QA9VD`2V5D86QA;6%N(%-A;&IU.@!097)B86YD
M:6YG86X@<V%L:G4@9&D@*&1A;&%M*2!A:7(Z`$QA9W4@)B!386IA:P!%<F]P
M82!396QA=&%N("A)4T\M.#@U.2TS*0!"96QA:&%N($)U;6D@4V5L871A;@!*
M87)A:R!A;G1A<F$@<V5L('EA;F<@8F5R9&5K871A;@!*87)A:R!A;G1A<F$@
M:7-I(&1A;B!B;W)D97(@9&D@9&%L86T@<V5L`$IA<F%K('-P87-I`$IA<F%K
M('-P87-I(&1A;B!J87)A:R!S<&%S:2!D87)I(&)O<F1E<@!3<&%M`$UA<W5K
M:V%N($MA<F%K=&5R(%-P97-I86P`4&ES86AK86X@4V5L`%!I<V%H:V%N(&MO
M;&]M`%!I<V%H:V%N(&)A<FES`$]L86AR86=A`%-T86YD87(`4&5R:F%L86YA
M;B!":6YT86YG`%-T871U<P!!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:6)E
M<FD@=&%N9&$@9V%R:7,`1V%Y82!;0U-370!-:6X`06YG:V$O:'5R=68O<VEM
M8F]L('EA;F<@9&ET=6QI<R!D:6)A=V%H(&=A<FES(&)A<FES('1E:W,`0F5R
M:&%S:6P`(B5S(G-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N`$MO;F9I9W5R87-I
M('-U9&%H(&)E<FAA<VEL(&1I:V5M8F%L:6MA;BX@56QA;F=I('5N='5K(&UE
M;&EH870@<&5R=6)A:&%N+B``0F%C:W5P(&MO;F9I9W5R87-I('-U9&%H(&)E
M<FAA<VEL(&1I<VEM<&%N+@!&:6QE($)A8VMU<"!+;VYF:6=U<F%S:2`E<R!S
M=61A:"!B97)H87-I;"!D:7-I;7!A;BX`)R5S)R!S=61A:"!B97)H87-I;"!D
M:71U;&ES`%)I;F=K87-A;@!-871A:&%R:2!497)B:70`36%T86AA<FD@5&5R
M8F5N86T`0V5R86@`36%T86AA<FD@5&5R8FET`$UA=&%H87)I(%1E<F)I="]-
M871A:&%R:2!497)B96YA;0!-871A:&%R:2!497)B:70Z`$UA=&%H87)I(%1E
M<F)E;F%M`$UA=&%H87)I(%1E<F)E;F%M.@!!;F=K82]H=7)U9B]S:6UB;VP@
M>6%N9R!D:71U;&ES(&1I871A<R!B87)I<R!T96MS`$1U:W5N9V%N`$AU:F%N
M('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!A;F=I;B!R:6)U=`!(=6IA;B!P971I
M<B!D:7-E<G1A:2!D96YG86X@8F%D86D@86YG:6X@<FEB=70`2'5J86X@<&5T
M:7(@9&ES97)T86D@9&5N9V%N(&%N9VEN(')I8G5T`%!R;W!E<G1I(%1A8F5L
M`%!R;W!E<G1I('1A8F5L`%1A<F=E=#H`5'5G87,`4W5H=2!U;G1U:R!J86T@
M=&5R86MH:7(Z`%-U:'4`4W5H=3H`4W5H=3QB<B`O/B@E<TAI)7,O)7-,;R5S
M*2`F9&5G.R5S`%1E;7!L871E($%D;6EN:7-T<F%S:0!(86YY82!496MS`%!E
M<F%T86%N(%1E:W,`5&5K<R!"86=I86X@071A<P!+;7,`5&AA:2`H5$E3+38R
M,"D`4&5M96QI:&%R86%N.CH@8VQA<W,@=&ED86L@8F5R:&%S:6P@9&EP86YG
M9VEL`%=I;F1O=R!0:6QI:&%N('-U9&%H(&1I='5T=7`N(%-I;&%K86X@2V5L
M=6%R`$AA;GEA('-I<VD@8F%G:6%N(&)A=V%H`$UO9&4@3&%Y87(@4&5N=6@@
M9&EK96YA;"!D87!A="!M96YY96)A8FMA;B!M87-A;&%H(&1E;F=A;B!);G1E
M<FYE="!%>'!L;W)E<BP@:G5G82!U;G1U:R!M96YC87)I(&ME<V%L86AA;B!Y
M86YG(&UE;GEE8F%B:V%N(&%N9&$@=&ED86L@;6%M<'4@8F5K97)J82!D96YG
M86X@8F%I:RX@06YD82!M=6YG:VEN('!E<FYA:"!M96YG86QA;6D@=&%M<&EL
M86X@>6%N9R!B=7)U:RP@:V5K=7)A;F=A;B!D87)I(&9U;F=S:2!E9&ET;W(@
M9&%N+V%T874@8G)O=W-E<B!Y86YG('-E<FEN9R!K86QI(')U<V%K(&1A;B!H
M87)U<R!D:75L86YG(&ME;6)A;&DN($II:V$@<VES=&5M(&%N9&$@861A;&%H
M(%=I;F1O=W,@.7@@861A(&ME;75N9VMI;F%N(&%N9&$@86MA;B!M96YD87!A
M=&MA;B`G2V5S86QA:&%N(%!E<FQI;F1U;F=A;B!5;75M)R!D86X@<&5R;'4@
M=6YT=6L@;64M<F5S=&%R="!K;VUP=71E<B!A;F1A+EQN7&X@06YD82!S=61A
M:"!D:7!E<FEN9V%T:2X@4VEL86MA;B!K;&EK($]+(&II:V$@86YD82!I;F=I
M;B!M96YC;V)A(&5D:71O<B!L87EA<B!P96YU:"X`261E;G1I=&%S("(E<R(@
M<W5D86@@9&EH87!U<RX`2&%N>6$@<VES:2!B86=I86X@:VER:0!(86YY82!S
M:7-I(&)A9VEA;B!K86YA;B!D86X@:VER:0!(86YY82!S:7-I(&)A9VEA;B!K
M86YA;@!397)V97(@(B5S(B!S=61A:"!B97)H87-I;"!D:6AA<'5S+@!397)V
M97(@(B5S(B!S=61A:"!B97)H87-I;"!D:7-I;7!A;BX`4&5R;6EN=&%A;B!P
M96YD869T87)A;B!U;G1U:R`E<R!S=61A:"!B97)H87-I;"!D:7!I;F1A:&MA
M;BX`2&%N>6$@<VES:2!B86=I86X@871A<R!D86X@8F%W86@`2&%N>6$@<VES
M:2!B86=I86X@871A<P!!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D
M:6%K86XN`$%D82!K97-A;&%H86X@9&D@9&%L86T@9F]R;75L:7(@:V]N9FEG
M=7)A<VDN($UU;F=K:6X@86YD82!T:61A:R!M96YG:7-I(&MO;&]M('EA;F<@
M9&EP97)L=6MA;BX`26YI(&%D86QA:"`E<RX`5VEN9&]W(&EN:2!H87)U<R!D
M:7!A;F=G:6P@9&%R:2!0:6QI:&%N(%=I;F1O=P!0971I<@!4:6ME=`!-96YG
M:6MU=&D@5V%K='4`1F]R;6%T(%=A:W1U`$IU9'5L`$IU9'5L("A#871A=&%N
M('!E='5N:G5K*0!(87)I($EN:0!'86YT:2!3;W5R8V4@2%1-3`!"97-O:P!!
M=&%S`$9R86UE($%T87,@*%]T;W`I`%1R86YS;&%S:0!396P`5'5R:VD@*$E3
M3RTX.#4Y+3DI`$EN9&5K<R!5+E8Z`%523`!54DPZ`%1I9&%K(&1A<&%T('5N
M='5K(&UE;F=H87!U<R`B)7,B.B`E<RX`1V%R:7,@8F%W86@`0F%T86QK86X@
M4&5R=6)A:&%N`$)A=&%L:V%N(&%K<VD@=&5R86MH:7(@86YD80!4:61A:R!D
M:6%R<VEP:V%N`%5N:6-O9&4@*%541BTX*0!5;FET`$)A=&%L:V%N(&QI;FL@
M<&%D82!E;&5M96X@>6%N9R!S96MA<F%N9P!38W)I<'0@>6%N9R!T:61A:R!M
M96UP=6YY86D@:&%K(&ES=&EM97=A('1I9&%K(&1A<&%T(&UE;F=A:W-E<R!(
M87!U<R]386QI;B],96MA=&MA;B!S97-U86D@<F5N8V%N82!U;G1U:R!A;&%S
M86X@:V5A;6%N86XN2VQI:R!/2R!U;G1U:R!M96QI:&%T(&-A=&%T86X@=&5K
M;FES('!A9&$@;6]Z:6QL82YO<F<@9&EM86YA(&%N9&$@86MA;B!D:7!E<FQI
M:&%T:V%N(&-A<F$@8F%G86EM86YA('5N='5K(&UE;F=I>FEN:V%N('-C<FEP
M="!U;G1U:R!D87!A="!M96YG86MS97,@:V4@8VQI<&)O87)D+@!787)N82!B
M96QU;2!D:6%T=7(`4&5R8F%H87)U:0!097)B86AA<G5I("5S`%!E<F)A:&%R
M=6D@<&5N9V=U;F$`(B5S(B!S=61A:"!D:7!E<F)A:&%R=6DN`%-C<FEP="!U
M<&=R861E('-U9&%H(&1I:&%P=7,N`%5P;&]A9`!396UU82!F:6QE('-E='5P
M(&%P;&EK87-I('-U9&%H(&1I=7!L;V%D(&ME('-E<G9E<BX`4VEM8F]L(&AU
M<G5F(&)E<V%R(&QA=&EN`%-I;6)O;"!H=7)U9B!B97-A<B!R;VUA=VD`1W5N
M86MA;FQA:"!J:6MA(&YA;6$O<V%N9&D@86YD82!B97)B961A('5N='5K('-E
M<G9E<B!)35-0+@!!9&UI;FES=')A<VD@4&5N9V=U;F$`4&5N9&%F=&%R86X@
M4&5N9V=U;F$`4&5N9&%F=&%R86X@4&5N9V=U;F$@<W5D86@@9&EN;VXM86MT
M:69K86X@=6YT=6L@<VET92!I;FDN`$%C8V]U;G0@4&5N9V=U;F$@=&ED86L@
M9&ET96UU:V%N`$YA;6$@4&5N9V=U;F$`3F%M82!096YG9W5N83H`3F%M82!0
M96YG9W5N83H`4&5N9V=U;F$@9&D@9&%L86T@<VES=&5M.@!,:6)U<F%N`%9A
M<FEA8FQE`%9E<G-I($MO;G1R;VP`2F%R86L@<&]S:7-I('9E<G1I:V%L(&%N
M=&%R82!G87)I<R!D87-A<B!D96YG86X@9V%M8F%R`$IA<F%K('!O<VES:2!V
M97)T:6MA;"!A;G1A<F$@8F]R9&5R(&1E;F=A;B!G86UB87(`5F5R=&EK86PZ
M`%-A;F=A="!4:6YG9VD`5FEE=&YA;2`H5DE30TE)*0!,:6AA="!W96(@<&%G
M92!E:W-T97)N86P`2F%R86L@4&%N9&%N9P!*87)A:R!086YD86YG.@!015))
M3D=!5$%.(2$A(%!)3D1!2$M!3B!30U))4%0@24Y)(%-%0T%202!-04Y504P@
M1$%222`E<RX`4&5R:6YG871A;@!286)U`%)A;6%L86X@0W5A8V$`1&%T82!#
M=6%C82!D:7-E9&EA:V%N(&]L96@`5V5B`%=E8B!3:71E`%-E;&%M870@1&%T
M86YG`%-E;&%M870@9&%T86YG(&ME("5S`%-E;&%M870@9&%T86YG+"`E<P!7
M97-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`07!A
M:V%H(&%P;&EK87-I("5S('!E<FQU(&1I=&%M<&EL:V%N('-E=&5L86@@;&]G
M:6X_`$%P86MA:"!Y86YG(&UE<G5P86MA;B!B871A<R!K87)A:W1E<C\`07!A
M:V%H('EA;F<@;65R=7!A:V%N(&MA<F%K=&5R(&EN9&5N=&%S:3\`1F%S92!Y
M86YG(&UA;F$`4&QU9VEN(&UA;F%K86@@>6%N9R!D87!A="!D:6%K=&EF:V%N
M('5N='5K(&5D:71O<B!2:6-H(%1E>'0N`$QE8F%R`$QE8F%R(&UE;G4@)7,@
M<&%D82!B86=I86X@:VER:2`H86MA;B!B97)P96YG87)U:"!P861A(&QO9VEN
M(&)E<FEK=71N>6$I`$QE8F%R('1A8F5L`$QE8F%R('5N:70`3&5B87(Z`%=I
M:VD`06YG:6X`06YG:6X@9&D@<&%G:2!H87)I`$ME8V5P871A;B!A;F=I;B!D
M:2!D86QA;2!K;F]T`$%N9VEN.@!!;F=I;CH`2V%T82!":6IA:W-A;F$`1&%F
M=&%R($ME:6YG:6YA;@!096ME<FIA86X`6"U2968`65D`66$L(%-!64$@4T54
M54I5`$%N9&$@8F5R861A(&1I(&1A;&%M($U/1$4@5$5+4RX@1W5N86MA;B!T
M;VUB;VP@6SP^72!U;G1U:R!M96YG9V%N=&D@:V5M8F%L:2!K92!D86QA;2!M
M;V1E(%=94TE764<N`$%N9&$@=&ED86L@9&EI>FEN:V%N('5N='5K(&UE;6)U
M870@;&5B:6@@9&%R:2`E9"!A<F5A+@!!;F1A(&AA<G5S(&UE;FIE;&%S:V%N
M(&UA<V%L86@@<V5B96QU;2!A;F1A(&1A<&%T(&UE;F=I<FEM:V%N(&QA<&]R
M86X@;6%S86QA:"X`06YD82!H87)U<R!M96UA<W5K:V%N(%523"!D:6UA;F$@
M;&EN:R!I;FD@;65N=6YJ=6L@:V4`06YD82!H87)U<R!M96UI;&EH('-E<G9E
M<B!U;G1U:R!D87!A="!D:6AA<'5S+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@
M;F%M82!P96YG9W5N82!Y86YG(&EN9VEN(&1I8F5R<VEH:V%N+@!!;F1A(&AA
M<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!Y86YG(&EN9VEN(&1I<&EN
M9&%H:V%N+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!U
M;G1U:R!D:71A;6)A:"X`06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N
M9V=U;F$@=6YT=6L@9&EP97)B86AA<G5I+@!!;&%M870@16UA:6P@06YD80!!
M;F1A($1A<FDZ(&%L86UA=#H`26YF;W)M87-I($%N9&$`3F%M82!!;F1A`$)A
M8VME;F0@87-L:2!A;F1A('1I9&%K(&1A<&%T(&UE;F1U:W5N9R!P96YD869T
M87)A;B!P96YG9W5N82P@871A=2!F:71U<B!I;FD@<W5D86@@9&EN;VXM86MT
M:69K86X@=6YT=6L@8F5B97)A<&$@86QA<V%N(&QA:6X`0G)O=W-E<B!A;F1A
M('1I9&%K(&UE;F1U:W5N9R!U;G1U:R!F:71U<B!I;FDN`%IO;F$@5V%K='4@
M06YD82!396MA<F%N9SH`1&5F875L="!I9&5N=&ET87,@86YD82!S=61A:"!D
M:75B86@N`$1E9F%U;'0@:61E;G1I=&%S(&%N9&$Z`$YA;6$@;&5N9VMA<"!A
M;F1A.@!386YD:2!B87)U(&%N9&$@=6YT=6L@)7,@861A;&%H.B`E<P!386YD
M:2!A;F1A('-U9&%H(&1I871U<B!U;&%N9P!386YD:2!A;F1A('-U9&%H(&1I
M871U<B!U;&%N9RP@<&5R:6MS86QA:"!E;6%I;"!A;F1A(&1A;B!L;V=I;B!D
M96YG86X@;65N9V=U;F%K86X@<V%N9&D@8F%R=2!A;F1A`%)E;6]T92!S97)V
M97(@86YD83H`0V5R:6$`6U-E;6)U;GEI:V%N($EN9&5N=&%S:2!496MS70!;
M3&%P;W)A;B!-87-A;&%H70!;5&%M<&EL86X@26YD96YT87-I(%1E:W,@+0!?
M061M:6YI<W1R87-I`%]#3$D`7T1A=&%4<F5E`$AA<'5S($)A<FES`%]'<G5P
M`%!R;W!E<G1I($=A;6)A<BXN+@!58F%H($QI;FLN+BX`27II;@!0:6YD86AK
M86X@3&EN:RXN+@!?4V5T=7``4')O<&5R=&D@5&%B96PN+BX`4&5N9V=U;F$`
M5&5N86YG`&IA='5H`$1A<FD@)7,@*"5S*2!P861A("5S("5S`&%N9VEN(&ME
M;F-A;F<`;6%S:6@@9&D@9&%L86T@86YT<FEA;@!B87)I<UT`;F%M80!P97)S
M96X`<&EX96P`;F%I:P!T86UP:6QK86X@<&5R8F5D86%N`'1E=&%P`$ME=&EK
M('-A;F1I(&1U82!K86QI('5N='5K(&UE;F=K;VYF:7)M87-I`&UE;GEA='5K
M86X`=V5A=&AE<BYC;VT`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O:7-?25,O````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`Q-C8W-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]I<U])4R],0U]-15-304=%4R\`````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-S<`,#(P-#8T`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VES7TE3
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,S<U,0`Q,#0Q-S,V,C<W-P`P,C(Q,C8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0````!W````'````-0#``"C
M````C`<````````8"@``#````!D*```#````)@H``!\````J"@``!0```$H*
M```&````4`H```0```!7"@``%@```%P*```&````<PH```8```!Z"@``&0``
M`($*```4````FPH```0```"P"@``!@```+4*```H````O`H```0```#E"@``
M"````.H*```0````\PH```8````$"P``#P````L+```(````&PL```L````D
M"P``!````#`+```-````-0L```4```!#"P``$````$D+```0````6@L```\`
M``!K"P``#P```'L+```,````BPL```@```"8"P``!P```*$+```$````J0L`
M``0```"N"P``$````+,+```'````Q`L```0```#,"P``!````-$+```(````
MU@L```T```#?"P``#@```.T+```6````_`L``!$````3#```!@```"4,```&
M````+`P```<````S#```!````#L,```'````0`P```D```!(#```!@```%(,
M```'````60P```L```!A#```!````&T,```&````<@P```@```!Y#```"```
M`((,```$````BPP```4```"0#```!@```)8,```0````G0P```H```"N#```
M`P```+D,```D````O0P```<```#B#```!@```.H,```?````\0P```8````1
M#0``#0```!@-```"````)@T```H````I#0``!@```#0-```&````.PT```D`
M``!"#0``!P```$P-```$````5`T```4```!9#0``!````%\-```"````9`T`
M``0```!G#0``"````&P-```"````=0T```<```!X#0``!P```(`-```(````
MB`T``!0```"1#0``*0```*8-```%````T`T```8```#6#0``'P```-T-```)
M````_0T```0````'#@``!P````P.```'````%`X```0````<#@``(P```"$.
M```O````10X``"$```!U#@``'````)<.```"````M`X```<```"W#@``#```
M`+\.```(````S`X```<```#5#@``!P```-T.```-````Y0X```,```#S#@``
M,````/<.```3````*`\``!`````\#P``4P```$T/```7````H0\``!8```"Y
M#P``#P```-`/```?````X`\```4`````$```"`````80```(````#Q````0`
M```8$```!@```!T0``!;`0``)!````L```"`$0``"@```(P1```6````EQ$`
M``4```"N$0``!0```+01```$````NA$``!8```"_$0``"0```-81```&````
MX!$``!L```#G$0``$0````,2```%````%1(```<````;$@``.````",2```$
M````7!(```@```!A$@``%````&H2```$````?Q(``!````"$$@``%@```)42
M```9````K!(```8```#&$@``!P```,T2```%````U1(``!````#;$@``$```
M`.P2```5````_1(``!$````3$P``#P```"43```'````-1,```0````]$P``
M`P```$(3```%````1A,```H```!,$P``!@```%<3```$````7A,```0```!C
M$P``"````&@3```/````<1,``!$```"!$P``&````),3```5````K!,```@`
M``#"$P``"P```,L3```'````UQ,```<```#?$P``!P```.<3```'````[Q,`
M``@```#W$P``!@`````4```5````!Q0```D````=%```!@```"<4```(````
M+A0```X````W%```!````$84```$````2Q0```<```!0%```#0```%@4```)
M````9A0```,```!P%```)@```'04```&````FQ0```8```"B%```"@```*D4
M```&````M!0```@```"[%````@```,04```+````QQ0```8```#3%```!@``
M`-H4```,````X10```H```#N%```!````/D4```&````_A0```4````%%0``
M`P````L5```%````#Q4```@````5%0``!@```!X5```'````)14```T````M
M%0``"````#L5```6````1!4``"$```!;%0``"@```'T5```%````B!4``!H`
M``".%0``"0```*D5```%````LQ4```0```"Y%0``"0```+X5```%````R!4`
M`!X```#.%0``,0```.T5```C````'Q8``"````!#%@```P```&06```&````
M:!8``!$```!O%@``"P```($6```'````C18```<```"5%@``$````)T6```"
M````KA8``"\```"Q%@``&P```.$6```+````_18``%4````)%P``%````%\7
M```6````=!<``!````"+%P``)@```)P7```%````PQ<```8```#)%P``"0``
M`-`7```%````VA<```@```#@%P```0````8`````````5P```&$````H````
M`````&0``````````````#T````I`````````$T```!*````;@`````````O
M````$````#8````.````9P````H````N````/P````(`````````$0```%$`
M``!<````-````"(````^````2P```&H```!"````,````!X````(````10``
M```````W``````````````!V``````````L```!T````#`````````!(````
M,0````````!L`````````$X``````````P```&````!H`````````!@```!M
M````1`````````!#`````````&8```!9``````````4`````````%0```%``
M````````90```"$`````````0````",````3`````````'4````Y````7@``
M`%,```!5````-0````````!!`````````!D```!8````<P```$D````6````
M````````````````:P`````````Z````'0```"0`````````````````````
M````*P```"T```!6`````````!(```!2````#0```!L````<`````````"P`
M````````3`````````!W````*@```%L```!&````8@```&D````@````)0``
M`$\````$````,P```#P```!'````<`````````!?````6@````\````'````
M```````````:````;P```"<`````````70```#@````4````,@```&,`````
M````)@```'(````)````'P```!<````[`````````'$```!4``````````!!
M9&1R97-S($)O;VL`06QL`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`07!R:6P`075G=7-T`$)O=&@`0G5I;&1I;F<@;&]C86QE("5S+BXN(`!#
M86YC96P`0VAA;F=E`$-L96%N:6YG('5P(&QO8V%L92`E<RXN+B``0V]M<&]S
M92!-97-S86=E("@E<RD`0V]P>0!#<F5A=&4`0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!$871E`$1E8V5M8F5R`$1E9F%U;'0@
M261E;G1I='D`1&5L971E`$1I<W!L87D@3W!T:6]N<P!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!%9&ET`$5M86EL($%D9')E<W,`17)R;W(`179E<GD@,34@;6EN
M=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H
M86QF(&AO=7(`179E<GD@;6EN=71E`$9E8G)U87)Y`$9I;'1E<G,`1G)O;0!(
M96QP`$ED96YT:71Y)W,@;F%M93H`2F%N=6%R>0!*=6QY`$IU;F4`3&%N9W5A
M9V4`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E
M<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87EO=70`3&5B
M86YO;@!,969T`$QI8F5R:6$`3&ET:'5A;FEA`$QO9R!I;@!,;V<@;W5T`$QO
M9VEN(%1A<VMS`$UA:6P`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`
M36%R8V@`36%R9VEN`$UA<G-H86QL($ES;&%N9',`36%U<FET86YI80!-87D`
M365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`
M365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ER<F]R
M`$UI<V-E;&QA;F5O=7,`36\`36]D:69Y(%523`!-;V1U;&4`36]N86-O`$UO
M=F4@1&]W;@!-;W9E(%5P`$YA;64`3F5V97(`3F5X=`!.;P!.;VYE`$YO=F5M
M8F5R`$]+`$]C=&]B97(`3W!T:6]N<P!087-S=V]R9`!097)S;VYA;"!);F9O
M<FUA=&EO;@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9`!297-E=`!396%R8V@`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E.@!397!T96UB97(`4VEZ90!3=6)J96-T`%-U8V-E<W,`5&5X=`!4:&4@
M:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+@!4;P!5;FYA;65D`%5S97(@3W!T:6]N<P!5<V5R;F%M90!6:65W
M("5S`%=A<FYI;F<`5V5L8V]M92!T;R`E<P!997,`66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@1G)O;3H@
M861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/
M<'1I;VX@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N`%](96QP`%],;V<@;W5T`%]/<'1I
M;VYS`&1O;F4`9F%I;&5D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP
M+C4*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#(M,#$M,3`@,3DZ,#`K,#$P,`I03RU2
M979I<VEO;BU$871E.B`R,#`U+3$Q+3$Y(#(P.C,S*S`P,#`*3&%S="U4<F%N
M<VQA=&]R.B!":F]R;B!$879I9'-S;VX@/&)J;W-S:4!S;F5R<&$N:7,^"DQA
M;F=U86=E+51E86TZ($EC96QA;F1I8R`\<W5P<&]R=$!S;F5R<&$N:7,^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*`$YE=&9A;F=A8O-K`-9L;"!S:V5Y=&D`TW3F:W0@9VEL9&D@=&EL9W)E
M:6YT+@!A<'+M;`#A9_IS=`!"YO!I`$)Y9V=I(&[Z(&QO8V%L92`E<R`N+BX`
M2.9T=&$@=FGP`$)R97ET80!(<F5I;G-A('1I;"#M(&QO8V%L92`E<R`N+BX`
M4V5M:F$@<VME>71I("@E<RD`069R:70`0OIA('1I;`!3=&EL;&$@8?!G97+P
M:7(@<V5M(&5R=2!F<F%M:W;F;61A<B#^96=A<B#^^B!T96YG:7-T("5S+@!$
M86=S`&1E<V5M8F5R`%-JX6QF9V5F:?`@:V5N;FEM87)K`$5Y\&$`VG1L:71S
M<W1I;&QI;F=A<@!3YFMJ82!Y9FER(.$@=FEN;G5S=/;P`%/F:VIA("5S('EF
M:7(@X2!V:6YN=7-T]O``0G)E>71A`$YE=&9A;F<`5FEL;&$`P2!K;W)T97)S
M(&9R97-T:0#!(#,P('-E:RX@9G)E<W1I`,$@9FEM;2!M[6[Z=&YA(&9R97-T
M:0#!(&CA;&9T[6UA(&9R97-T:0#!(&WM;OIT=2!F<F5S=&D`9F5B<OIA<@!3
M[75R`$9RX0!(:N%L<`!+96YN:6YA9FXZ`&IA;OIA<@!J^FSM`&KZ;NT`5'5N
M9W5MX6P`<^WP87-T('5P<&;F<G0Z`%/M\&%S="!T96YG<W0Z("5S`%/M\&%S
M="!T96YG<W0Z("5S(&9RX2`E<P!3[?!A<W0@=&5N9W-T.B!!;&1R96D`3&5T
M=&QA;F0`1G)A;7-E=&YI;F<`3.UB86YO;@!6:6YS=')I`$SM8F5R[6$`3&ET
M:.%E;@!496YG:F%S=`#:='-K<N$`5F5R:V5F;FD@=FGP('1E;F=I;F=U`%9E
M9G#S<W1U<@!-86QA=NT`36%L8>US[6$`1W+F;FCV9O!A97EJ87(`36%L[0!M
M87)S`%-PX7-S[6$`36%R<VAA;&QE>6IA<@!-X7+M=&%N[6$`;6'M`%-A;65I
M;F$@_OWP:6YG87(@9GER:7(@)7,@96EN:6YG=6YA+BXN`%-K97ET:0!-97CM
M:_,`3>UK<O-N97/M80!3<&5G;&$`W6UI<VQE9W0`3>$`0G)E>71A('-L\_``
M16EN:6YG`$WS;F%K\P!&;'ET:F$@;FGP=7(`1FQY=&IA('5P<`!.869N`$%L
M9')E:0!.YG-T80!.96D`16YG:6X`;O-V96UB97(`S2!L86=I`&]K=/-B97(`
M5F%L<W1I;&QI;F=A<@!,>6MI;&]R\`!5<'!L_7-I;F=A<B!U;2!N;W1A;F1A
M`%-LX?!U(&EN;B!N;W1A;F1A;F%F;B!O9R!L>6ML:6]R\`!%;F1U<G-E=&IA
M`$QE:71A`%9E;&1U('-JX6QF9V5F:?`@='5N9W5MX6PZ`'-E<'1E;6)E<@!3
M=.9R\`!%9FYI`$9R86UK=N9M=`!497AT:0!+96YN:6YU("(E<R(@:&5F=7(@
M=F5R:?`@97ET="X`5FEL;&$@:V]M('5P<"!V:?`@8FER=&EN9W4@_F5S<V$@
M:&QU=&$@<VME>71I<VEN<P!486QA;B!V97+P=7(@8?`@=F5R82!A\"!LX6=M
M87)K:2`Q+@#>971T82!G:6QD:2!V97+P=7(@8?`@=F5R82!T86QA+@!4:6P`
MTVYE9FYT`%9A;&MO<W1I<B!N;W1A;F1A`$YO=&%N9&%N869N`%/];F$@)7,`
M0?!V]G)U;@!696QK;VUI;BAN*2#M("5S`$KA`$QO=&%N("5S(&5R(')U;FYI
M;B#Z="#A('3M;6$N(%1E;F=D=2#^:6<@869T=7(N`$9U;&QT(&YE=&9A;F<@
M_FET="`H1G+A.BD@.@!5<'!L_7-I;F=A<@!6969S:V_P87)I(/YI;FX@<W1Y
M\'5R(&5K:VD@_F5S<V$@<')E;G1A\&=E<O`N($YO=&'P=2!#5%),+T]P=&EO
M;B!O9R!0('1I;"!A\"!P<F5N=&$N`$[Z=F5R86YD:2!T[6UA8F5L=&DZ`%-J
MX6QF9V5F:?`@:V5N;FD@_FET=#H`1G5L;'0@;F%F;B#^:71T.@!3=&EL;&EN
M9V%R(/[M;F%R(&AA9F$@=F5R:?`@=7!P9N9R\&%R+@!(:N%L<`#:='-K<N$`
M5F%L:V]S=&ER`&QO:VGP`&ML:6MK8?!I````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?0TXO````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S<W`#`Q-C8W,@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]Z:%]#3B],0U]-15-304=%4R\`````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#(P-#4W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+WIH7T-.+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$W-S4S,0`Q,#0Q-S,V
M,C<W-P`P,C(Q,S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````![!```'````/0C``#[!0``S$<```````"X7P``
M#@```+E?```/````R%\```@```#87P``#````.%?```$````[E\```\```#S
M7P``"P````-@```.````#V````4````>8```*````"1@```*````36```!4`
M``!88```$@```&Y@```+````@6````X```"-8```"@```)Q@```-````IV``
M``X```"U8```!@```,1@```/````RV```!@```#;8```#````/1@```(````
M`6$``"X````*80``&@```#EA```R````5&$``#@```"'80``5````,!A``!1
M````%6(``%H```!G8@``5P```,)B```T````&F,```4```!/8P``!@```%5C
M```1````7&,```@```!N8P``)0```'=C```@````G6,```\```"^8P``"@``
M`,YC```#````V6,```\```#=8P``%````.UC```)`````F0```T````,9```
M$@```!ID```/````+60```\````]9```"````$UD```D````5F0```@```![
M9```&0```(1D```'````GF0```P```"F9```+````+-D```.````X&0```,`
M``#O9```"P```/-D```'````_V0```<````'90``!0````]E```7````%64`
M``H````M90``#P```#AE```8````2&4```X```!A90``%````'!E```7````
MA64``!<```"=90``$P```+5E```.````R64``!\```#890``!P```/AE```&
M`````&8```@````'9@``#P```!!F```*````(&8``!,````K9@``"P```#]F
M```5````2V8``!4```!A9@``!P```'=F```%````?V8``!4```"%9@``$0``
M`)MF```,````K68``#L```"Z9@``"0```/9F```'`````&<``!0````(9P``
M!0```!UG```0````(V<``!,````T9P``.0```$AG```G````@F<``"P```"J
M9P``*@```-=G```E`````F@```H````H:```!@```#-H```)````.F@```<`
M``!$:```+P```$QH```W````?&@``"X```"T:```50```.-H```M````.6D`
M`"T```!G:0``+0```)5I``!`````PVD``",````$:@``(P```"AJ```M````
M3&H``#,```!Z:@``%0```*YJ```9````Q&H``"D```#>:@``)`````AK```1
M````+6L```H````_:P``$````$IK```6````6VL``!8```!R:P``!P```(EK
M```'````D6L``!0```"9:P``"@```*YK```(````N6L```<```#":P``!P``
M`,IK```&````TFL```4```#9:P``!P```-]K```&````YVL```@```#N:P``
M#@```/=K```*````!FP```0````1;```!P```!9L```)````'FP``!8````H
M;```"````#]L```-````2&P```8```!6;```'@```%UL```1````?&P```@`
M``".;```#0```)=L```,````I6P```<```"R;````P```+IL```#````OFP`
M`!<```#";```"````-IL```$````XVP```@```#H;```"````/%L```@````
M^FP```8````;;0``!@```")M```5````*6T``!@````_;0``'0```%AM``!4
M````=FT``"D```#+;0``"@```/5M```.`````&X```H````/;@``%````!IN
M```8````+VX``!T```!(;@``$P```&9N```4````>FX```0```"/;@``!@``
M`)1N```%````FVX```4```"A;@``&P```*=N```:````PVX``!$```#>;@``
M$0```/!N```<`````F\``!`````?;P``(0```#!O```1````4F\```P```!D
M;P``!@```'%O```7````>&\```@```"0;P``!0```)EO```,````GV\```8`
M``"L;P``!P```+-O```-````NV\```<```#);P``"P```-%O```'````W6\`
M``<```#E;P``"@```.UO```,````^&\``!`````%<```!0```!9P```E````
M''```!,```!"<```.P```%9P```@````DG````P```"S<```#@```,!P```*
M````SW````T```#:<```'@```.AP```;````!W$``"$````C<0``'@```$5Q
M```>````9'$``!L```"#<0``'@```)]Q```S````OG$``"\```#R<0``$@``
M`")R```I````-7(``!(```!?<@``%@```')R```H````B7(``"````"R<@``
M(0```--R``!!````]7(```<````W<P``!@```#]S```2````1G,``!,```!9
M<P``$@```&US```'````@',```0```"(<P``#````(US```/````FG,``!,`
M``"J<P``#0```+YS```-````S',```8```#:<P``$0```.%S```7````\W,`
M`!L````+=```#@```"=T```"````-G0```4````Y=```!````#]T```-````
M1'0```X```!2=````P```&%T```(````970```\```!N=```$````'YT```&
M````CW0```P```"6=```$0```*-T```9````M70```T```#/=```!P```-UT
M```4````Y70```L```#Z=```(@````9U```O````*74```L```!9=0``"0``
M`&5U```9````;W4```L```")=0``%P```)5U```7````K74```D```#%=0``
M%@```,]U```/````YG4```X```#V=0``"`````5V```-````#G8``"8````<
M=@``0P```$-V```(````AW8``!(```"0=@``"````*-V```+````K'8``"\`
M``"X=@``#@```.AV```&````]W8```,```#^=@``!P````)W```$````"G<`
M``H````/=P``"@```!IW```/````)7<``!`````U=P``%P```$9W```1````
M7G<``!<```!P=P``!0```(AW```+````CG<```4```":=P``#0```*!W```;
M````KG<``!<```#*=P``"0```.)W```.````['<```T```#[=P``"`````EX
M```.````$G@``!$````A>```!P```#-X```%````.W@```<```!!>```"```
M`$EX```&````4G@``!````!9>```$````&IX```/````>W@```L```"+>```
M#P```)=X```,````IW@```\```"T>```!P```,1X```&````S'@```\```#3
M>```"````.-X```3````['@``!X`````>0``(0```!]Y```@````07D``!D`
M``!B>0``%P```'QY```E````E'D``!<```"Z>0``&P```-)Y```-````[GD`
M``,```#\>0``"`````!Z```*````"7H```P````4>@``!````"%Z```3````
M)GH``!0````Z>@``#````$]Z```)````7'H```L```!F>@``&P```')Z```'
M````CGH```<```"6>@``"@```)YZ```-````J7H```D```"W>@``!````,%Z
M```8````QGH```H```#?>@``?````.IZ```%````9WL```<```!M>P``#```
M`'5[```(````@GL```8```"+>P``"````))[```"````FWL```8```">>P``
M#0```*5[```0````LWL```0```#$>P``"0```,E[```0````TWL```D```#D
M>P``"0```.Y[```%````^'L```8```#^>P``&0````5\```'````'WP```<`
M```G?```!0```"]\```)````-7P```H````_?````@```$I\```-````37P`
M``D```!;?```!@```&5\```2````;'P```D```!_?```!P```(E\```4````
MD7P``!T```"F?```!@```,1\```*````RWP```0```#6?```"0```-M\```(
M````Y7P``!$```#N?```"0````!]```&````"GT```T````1?0``!@```!]]
M```$````)GT``!X````K?0``!0```$I]```.````4'T```8```!??0``(0``
M`&9]```5````B'T```0```">?0``$0```*-]```&````M7T``"(```"\?0``
M'0```-]]```$````_7T```P````"?@``"@````]^```(````&GX```D````C
M?@``!0```"U^```/````,WX``"0```!#?@``"````&A^```*````<7X```<`
M``!\?@``(````(1^```@````I7X``"8```#&?@``&0```.U^```I````!W\`
M``<````Q?P``"@```#E_```/````1'\```P```!4?P``!@```&%_```/````
M:'\``!(```!X?P``$````(M_```<````G'\```\```"Y?P``!0```,E_```0
M````SW\```D```#@?P``!````.I_```+````[W\```P```#[?P``#P````B`
M```9````&(````\````R@```$P```$*````2````5H````<```!I@```#```
M`'&````@````?H```!0```"?@```$0```+2````7````QH```!P```#>@```
M$P```/N````1````#X$``!H````A@0``'@```#R!```:````6X$``!$```!V
M@0``%P```(B!```5````H($``!D```"V@0``!````-"!```'````U8$```L`
M``#=@0``!@```.F!```&````\($```8```#W@0``!0```/Z!```'````!((`
M``<````,@@``!0```!2"```6````&H(```8````Q@@``!@```#B"```$````
M/X(```0```!$@@``#@```$F"```,````6((```P```!E@@``#0```'*"```*
M````@((```X```"+@@``!0```)J"```H````H((```P```#)@@``#P```-:"
M```*````YH(```@```#Q@@``"0```/J"```K````!(,```@````P@P``)@``
M`#F#```2````8(,```\```!S@P``!@```(.#```*````BH,```@```"5@P``
M(````)Z#```)````OX,```P```#)@P``#0```-:#```.````Y(,``!8```#S
M@P``$0````J$```&````'(0```8````CA```!P```"J$```'````,H0```<`
M```ZA```%@```$*$```-````680```0```!GA```!0```&R$```>````<H0`
M`!````"1A```#````**$```)````KX0```<```"YA```"@```,&$```)````
MS(0```X```#6A```$````.6$```:````]H0```H````1A0``"0```!R%```,
M````)H4```\````SA0``"````$.%```&````3(4```<```!3A0``!0```%N%
M``!'````884```T```"IA0``"@```+>%```"````PH4```0```#%A0``)0``
M`,J%```#````\(4```4```#TA0``*@```/J%```*````)88```0````PA@``
M"@```#6&```&````0(8```@```!'A@``"````%"&```$````688```4```!>
MA@``!0```&2&```;````:H8``"\```"&A@``$````+:&```*````QX8```\`
M``#2A@``"@```.*&```)````[88``!L```#WA@``&````!.'```7````+(<`
M``X```!$AP```P```%.'```'````5X<```<```!?AP``"@```&>'```'````
M<H<``%$```!ZAP``$````,R'```,````W8<``!H```#JAP``2@````6(```&
M````4(@```8```!7B```!@```%Z(```?````98@```D```"%B```&````(^(
M```7````J(@```8```#`B```5P```,>(```3````'XD``!,````SB0```@``
M`$>)```+````2HD```T```!6B0``!P```&2)```4````;(D```8```"!B0``
M"````(B)```.````D8D```<```"@B0``"@```*B)```+````LXD```<```"_
MB0``"0```,>)```)````T8D```H```#;B0``!P```.:)```)````[HD```<`
M``#XB0``"@````"*```2````"XH```H````>B@``"0```"F*```0````,XH`
M``<```!$B@``$@```$R*```$````7XH```<```!DB@``!0```&R*```%````
M<HH```L```!XB@``%````(2*```1````F8H``!@```"KB@``'````,2*```9
M````X8H```<```#[B@``!0````.+```-````"8L```@````7BP``%P```""+
M```+````.(L``!,```!$BP``!````%B+```$````78L```P```!BBP``"0``
M`&^+```%````>8L```<```!_BP``!0```(>+```$````C8L``"D```"2BP``
M,@```+R+```N````[XL``#,````>C```,P```%*,```X````AHP``!````"_
MC```$P```-",```M````Y(P``"T````2C0``,0```$"-```N````<HT``"\`
M``"AC0``+````-&-```3````_HT``"L````2C@``&@```#Z.```)````68X`
M`$4```!CC@``00```*F.```$````ZXX``!0```#PC@``#@````6/```3````
M%(\``!@````HCP``!@```$&/```)````2(\```H```!2CP``#P```%V/```.
M````;8\```4```!\CP``"````(*/```&````BX\``!0```"2CP``$0```*>/
M```.````N8\```(```#(CP``#@```,N/```%````VH\```<```#@CP``!@``
M`.B/```$````[X\``"D```#TCP``'P```!Z0``!<````/I```!0```";D```
M!P```+"0```.````N)````P```#'D```#````-20```3````X9```!T```#U
MD```&0```!.1```%````+9$``!$````SD0``$0```$61```D````5Y$``!4`
M``!\D0``$@```)*1```.````I9$``!D```"TD0``"````,Z1```)````UY$`
M``@```#AD0``!0```.J1```?````\)$```8````0D@``$````!>2```(````
M*)(```@````QD@``+````#J2```:````9Y(```D```""D@``"@```(R2```5
M````EY(```4```"MD@``%````+.2```$````R)(``!````#-D@``'@```-Z2
M```H````_9(```H````FDP``$0```#&3```+````0Y,``!H```!/DP``%```
M`&J3```$````?Y,```L```"$DP``!0```)"3```&````EI,```@```"=DP``
M(````*:3``!!````QY,``!H````)E```*````"24```I````390```8```!W
ME```!0```'Z4```(````A)0``"H```"-E```(P```+B4```N````W)0``#0`
M```+E0``"````$"5```7````294```H```!AE0``!P```&R5```0````=)4`
M``L```"%E0``$P```)&5```(````I94```L```"NE0``"@```+J5```4````
MQ94``#(```#:E0``"P````V6```%````&98``!<````?E@``#P```#>6```%
M````1Y8```0```!-E@``#0```%*6```R````8)8``!<```"3E@``%````*N6
M```%````P)8```<```#&E@``#@```,Z6```J````W98```8````(EP``#```
M``^7```+````')<``#8````HEP``"P```%^7```/````:Y<``#(```![EP``
M!0```*Z7```'````M)<``!$```"\EP``!P```,Z7```$````UI<```<```#;
MEP``"@```..7```+````[I<```P```#ZEP```P````>8```2````"Y@```8`
M```>F```'@```"68```8````1)@``"4```!=F```#0```(.8```)````D9@`
M``,```";F```!P```)^8```"````IY@```P```"JF```%0```+>8```+````
MS9@``!D```#9F```(````/.8```2````%)D```4````GF0``"@```"V9```5
M````.)D``!(```!.F0``#````&&9```$````;ID```<```!SF0``#````'N9
M``!2````B)D``!<```#;F0``!@```/.9```-````^ID``!4````(F@``$@``
M`!Z:```/````,9H``!0```!!F@``&P```%::``!I````<IH``!H```#<F@``
M%P```/>:```:````#YL``!<````JFP``&P```$*;```9````7IL``!\```!X
MFP``$P```)B;```'````K)L```@```"TFP``"0```+V;```5````QYL```T`
M``#=FP``$P```.N;```#````_YL``#\````#G```-P```$.<``!7````>YP`
M`"\```#3G```"@````.=```(````#IT```T````7G0``+0```"6=```$````
M4YT``"4```!8G0``"P```'Z=```=````BIT```8```"HG0``#````*^=```'
M````O)T```D```#$G0``$P```,Z=```)````XIT```0```#LG0``$````/&=
M```(`````IX```@````+G@``#````!2>```/````(9X```<````QG@``%```
M`#F>```.````3IX```P```!=G@``&P```&J>```L````AIX``!,```"SG@``
M!0```,>>```$````S9X``!<```#2G@``"0```.J>```(````])X```H```#]
MG@``$0````B?```&````&I\```X````AGP``#@```#"?```-````/Y\```L`
M``!-GP```@```%F?```'````7)\```8```!DGP``"0```&N?```'````=9\`
M`!4```!]GP``!0```).?```'````F9\```@```"AGP``!P```*J?```'````
MLI\```X```"ZGP``"0```,F?```&````TY\```@```#:GP``"P```..?```'
M````[Y\```@```#WGP``!P````"@```6````"*````D````?H```!@```"F@
M```+````,*```!0````\H```"````%&@```&````6J```!D```!AH```"@``
M`'N@```<````AJ````<```"CH```!0```*N@```0````L:```!0```#"H```
M"P```->@```-````XZ```!<```#QH```!`````FA```)````#J$```(````8
MH0``#@```!NA```(````*J$``!\````SH0``(P```%.A```Q````=Z$``"<`
M``"IH0``2@```-&A```X````'*(``"@```!5H@``+````'ZB```;````JZ(`
M`#X```#'H@``2`````:C``!!````3Z,``%L```"1HP``20```.VC```A````
M-Z0``!\```!9I```*P```'FD```A````I:0``#,```#'I```)0```/ND```G
M````(:4``#````!)I0``:0```'JE```]````Y*4``&4````BI@``30```(BF
M```O````UJ8``"X````&IP``5````#6G```R````BJ<``"\```"]IP``+```
M`.VG```M````&J@``!<```!(J```)0```&"H```R````AJ@``"D```"YJ```
M/@```..H```B````(JD``%(```!%J0``)0```)BI```+````OJD``"$```#*
MJ0``,````.RI```E````':H``!P```!#J@``,0```&"J```$````DJH```T`
M``"7J@``"P```*6J```.````L:H```L```#`J@``!0```,RJ```"````TJH`
M`%D```#5J@``!0```"^K```2````-:L```0```!(JP``!P```$VK```(````
M5:L```4```!>JP``$P```&2K```-````>*L```(```"&JP``!P```(FK```&
M````D:L``!0```"8JP``#````*VK```8````NJL```8```#3JP``$@```-JK
M```,````[:L```,```#ZJP``!````/ZK```&`````ZP```<````*K```'P``
M`!*L```U````,JP``"X```!HK```+P```)>L```7````QZP``"````#?K```
M&P````"M```8````'*T``"0````UK0``'P```%JM```:````>JT``!H```"5
MK0``+P```+"M```K````X*T``!\````,K@``(P```"RN```?````4*X``!H`
M``!PK@``)0```(NN```F````L:X``"4```#8K@``)````/ZN```8````(Z\`
M`!T````\KP``)````%JO```8````?Z\``"(```"8KP``)0```+NO```?````
MX:\``",````!L```'P```"6P```@````1;```!H```!FL```)@```(&P```>
M````J+```!X```#'L```"0```.:P```,````\+```!<```#]L```+P```!6Q
M```D````1;$```\```!JL0``%````'JQ```.````C[$```T```">L0``)```
M`*RQ```%````T;$```<```#7L0``'0```-^Q```5````_;$```8````3L@``
M"0```!JR```+````)+(``!<````PL@``!@```$BR```S````3[(```<```"#
ML@``(0```(NR```3````K;(```P```#!L@``$0```,ZR```R````X+(```@`
M```3LP``"0```!RS```*````)K,``!0````QLP``"@```$:S```=````4;,`
M``@```!OLP``'P```'BS```(````F+,``!H```"ALP``!@```+RS```'````
MP[,```@```#+LP``"0```-2S```_````WK,```<````>M```#P```":T```(
M````-K0``!,````_M```!P```%.T```9````6[0```H```!UM```%P```("T
M```4````F+0```H```"MM```#````+BT```7````Q;0```0```#=M```*@``
M`.*T```1````#;4```<````?M0```@```">U```0````*K4```,````[M0``
M"````#^U```&````2+4```<```!/M0``#0```%>U```+````9;4``!0```!Q
MM0``%0```(:U```.````G+4``"\```"KM0``(````-NU```<````_+4``!,`
M```9M@``!0```"VV```&````,[8```P````ZM@``"@```$>V```1````4K8`
M``(```!DM@``!````&>V```*````;+8```8```!WM@``!0```'ZV```,````
MA+8``$4```"1M@``*````->V``!3`````+<``!D```!4MP``(````&ZW```U
M````C[<``$4```#%MP``,`````NX```H````/+@``"8```!EN```)0```(RX
M```H````LK@``"@```#;N```,`````2Y```2````-;D``!````!(N0``>0``
M`%FY```)````T[D``',```#=N0``?````%&Z```K````SKH``!<```#ZN@``
M'P```!*[```4````,KL```H```!'NP``!0```%*[```&````6+L```@```!?
MNP``$````&B[```/````>;L```0```")NP``&0```(Z[```"````J+L```D`
M``"KNP``!````+6[```/````NKL``!,```#*NP``(@```-Z[```'`````;P`
M``L````)O```!0```!6\```"````&[P```L````>O```3P$``"J\```*````
M>KT```P```"%O0``!P```)*]```'````FKT```(```"BO0``$@```*6]```+
M````N+T```<```#$O0``!0```,R]```2````TKT```<```#EO0``"P```.V]
M```)````^;T```L````#O@``"0````^^```%````&;X```H````?O@``#P``
M`"J^```&````.KX```P```!!O@``$@```$Z^```*````8;X```D```!LO@``
M'0```':^```4````E+X``"4```"IO@``+0```,^^```\````_;X``$`````Z
MOP``0````'N_``!&````O+\``"<````#P```!0```"O````(````,<````X`
M```ZP```!P```$G````;````4<```!L```!MP```"P```(G````$````E<``
M``0```":P```"@```)_````,````JL````H```"WP```"@```,+````(````
MS<````T```#6P```#0```.3````&````\L```!\```#YP```"````!G!```9
M````(L$```0````\P0``!@```$'!```?````2,$```0```!HP0``"````&W!
M```&````=L$```H```!]P0``"@```(C!```$````D\$``!````"8P0``"@``
M`*G!```(````M,$``!0```"]P0``!@```-+!```.````V<$```X```#HP0``
M#@```/?!```(````!L(```H````/P@``%0```!K"```&````,,(```8````W
MP@``!@```#["```(````1<(```8```!.P@``$````%7"```(````9L(```X`
M``!OP@``$@```'["```$````D<(```0```"6P@``%P```)O"```,````L\(`
M``P```#`P@``&@```,W"```&````Z,(```@```#OP@``%@```/C"```&````
M#\,```H````6PP``#P```"'#```=````,<,``!L```!/PP``&0```&O#```;
M````A<,``!D```"APP``!````+O#```$````P,,```@```#%PP``!@```,[#
M```J````U<,``",`````Q```*0```"3$``!K````3L0``"@```"ZQ```*```
M`./$```H````#,4``"<````UQ0``&@```%W%```:````>,4``"@```"3Q0``
M+@```+S%```)````Z\4```P```#UQ0``$`````+&```-````$\8```L````A
MQ@``"````"W&```(````-L8``!(````_Q@``%````%+&```*````9\8```0`
M``!RQ@``&````'?&```(````D,8```@```"9Q@``"````*+&```&````J\8`
M``8```"RQ@``!````+G&```*````OL8```0```#)Q@``!````,[&```(````
MT\8```@```#<Q@``!````.7&```(````ZL8```0```#SQ@``%````/C&```(
M````#<<```@````6QP``!````!_'```.````),<```0````SQP``"````#C'
M```(````0<<```H```!*QP``!@```%7'```,````7,<```,```!IQP``"@``
M`&W'```$````>,<```8```!]QP``!@```(3'```&````B\<``!H```"2QP``
M!@```*W'```$````M,<```P```"YQP``$@```,;'```2````V<<``#$```#L
MQP``&0```![(```&````.,@```@````_R```"````$C(```6````4<@```H`
M``!HR```$0```'/(```(````A<@```@```".R```!````)?(```$````G,@`
M``0```"AR```!````*;(```1````J\@```\```"]R```"````,W(```.````
MUL@```T```#ER```!@```//(```5````^L@```P````0R0``"````!W)```$
M````)LD```H````KR0``"````#;)```$````/\D```8```!$R0``!````$O)
M```$````4,D```@```!5R0``!````%[)```&````8\D```8```!JR0``!```
M`'')```$````=LD```<```![R0``"````(/)```$````C,D```H```"1R0``
M"@```)S)```K````I\D``!H```#3R0``"````.[)```(````]\D```H`````
MR@``"`````O*```4````%,H``!@````IR@``%P```$+*```7````6LH``!0`
M``!RR@``$@```(?*```5````FLH``!T```"PR@``'0```,[*```,````[,H`
M`!<```#YR@``#````!'+```7````'LL``!@````VRP``$P```$_+```6````
M8\L``#````!ZRP``!````*O+```$````L,L```P```"URP``#````,++```*
M````S\L```@```#:RP``!````./+```(````Z,L```@```#QRP``"@```/K+
M```(````!<P```@````.S```"````!?,```1````(,P``!<````RS```&@``
M`$K,```*````9<P```(```!PS```!````'/,```$````>,P```@```!]S```
M"````(;,```$````C\P```8```"4S```"````)O,```,````I,P```0```"Q
MS```"@```+;,```(````P<P```X```#*S```"````-G,```$````XLP```@`
M``#GS```!````/#,```=````]<P``!<````3S0``!````"O-```(````,,T`
M`!8````YS0``"@```%#-```(````6\T```@```!DS0``!````&W-```1````
M<LT```@```"$S0``"````(W-```&````ELT```8```"=S0``'````*3-```I
M````P<T```@```#KS0``#@```/3-```$`````\X```<````(S@``'@```!#.
M```(````+\X```@````XS@``!````$'.```(````1LX```0```!/S@``"```
M`%3.```*````7<X```@```!HS@``"````''.```.````>LX```@```")S@``
M#@```)+.```$````H<X```@```"FS@``"````*_.```,````N,X``!4```#%
MS@``#````-O.```(````Z,X```D```#QS@``"0```/O.```$````!<\```H`
M```*SP``"@```!7/```*````(,\```0````KSP``"````##/```*````.<\`
M``0```!$SP``"@```$G/```*````5,\```D```!?SP``"````&G/```*````
M<L\```D```!]SP``!P```(?/```$````C\\```0```"4SP``!@```)G/```&
M````H,\```T```"GSP``$````+7/```5````QL\``!0```#<SP``$````/'/
M```0`````M```!L````3T```$````"_0```=````0-````@```!>T```!```
M`&?0```$````;-````@```!QT```"@```'K0```$````A=```!,```"*T```
M$0```)[0```*````L-````@```"[T```"````,30```5````S=````8```#C
MT```!````.K0```&````[]````8```#VT```"````/W0```$````!M$```X`
M```+T0``"````!K1``!.````(]$```0```!RT0``!````'?1```(````?-$`
M``0```"%T0``!````(K1```(````C]$```8```"8T0``!````)_1```*````
MI-$```X```"OT0``!@```+[1```"````Q=$```@```#(T0``!````-'1```$
M````UM$```0```#;T0``!@```.#1```2````Y]$```@```#ZT0``!`````/2
M```$````"-(```@````-T@```@```!;2```$````&=(```L````>T@``!```
M`"K2```$````+](``!,````TT@``!@```$C2```(````3](```H```!8T@``
M$@```&/2```&````=M(```H```!]T@``!````(C2```(````C=(```@```"6
MT@``"````)_2```(````J-(```8```"QT@``$````+C2```&````R=(```0`
M``#0T@``$0```-72```$````Y](```D```#LT@``!````/;2```0````^](`
M`!<````,TP``!````"33```.````*=,```0````XTP``$0```#W3```&````
M3],```0```!6TP``"````%O3```(````9-,```@```!MTP``"````';3```%
M````?],```8```"%TP``#0```(S3```$````FM,```8```"?TP``!@```*;3
M```5````K=,``!4```##TP``'0```-G3```0````]],``"`````(U```!```
M`"G4```(````+M0```H````WU```"````$+4```$````2]0```T```!0U```
M#````%[4```)````:]0``!,```!UU```"````(G4```$````DM0```@```"7
MU```"@```*#4```$````J]0```0```"PU```"````+74```,````OM0```X`
M``#+U```"````-K4```-````X]0``!$```#QU```!`````/5```&````"-4`
M`!D````/U0``#P```"G5```/````.=4```\```!)U0``#@```%G5```0````
M:-4``!````!YU0``%@```(K5```3````H=4```\```"UU0``#P```,75```/
M````U=4``!$```#EU0``$````/?5```&````"-8```8````/U@``!````!;6
M```&````&]8```8````BU@``!````"G6```&````+M8```8````UU@``!```
M`#S6```,````0=8``!(```!.U@``!@```&'6```$````:-8```0```!MU@``
M!````'+6```$````=]8```@```!\U@``"````(76```(````CM8```H```"7
MU@``"@```*+6```&````K=8``!(```"TU@``"````,?6```(````T-8```@`
M``#9U@``"````.+6```(````Z]8``"@```#TU@``#@```!W7```$````+-<`
M``0````QUP``#0```#;7```&````1-<```H```!+UP``!````%;7```$````
M6]<```8```!@UP``!@```&?7```)````;M<```X```!XUP``%````(?7```6
M````G-<```@```"SUP``"````+S7```&````Q=<```8```#,UP``"````-/7
M```&````W-<```H```#CUP``!````.[7```$````\]<``!T```#XUP``#```
M`!;8```1````(]@```\````UV```$P```$78```1````6=@``!$```!KV```
M#P```'W8```3````C=@``!0```"AV```!````+;8```&````N]@```H```#"
MV```"@```,W8```$````V-@```0```#=V```!````.+8```$````Y]@``"L`
M``#LV```"0```!C9```&````(MD```(````IV0``"````"S9```;````-=D`
M``,```!1V0``"````%79```,````7MD```P```!KV0``!````'C9```(````
M?=D```8```"&V0``"````(W9```(````EMD```0```"?V0``!@```*39```$
M````J]D``!(```"PV0``)````,/9```*````Z-D```H```#SV0``#````/[9
M```*````"]H```@````6V@``%P```!_:```8````-]H``!<```!0V@``#```
M`&C:```$````==H```H```!ZV@``!````(7:```)````BMH```0```"4V@``
M+````)G:```+````QMH```@```#2V@``$P```-O:```K````[]H```0````;
MVP``!````"#;```&````)=L``!(````LVP``"0```#_;```8````2=L``!<`
M``!BVP``!````'K;```W````?]L``!````"WVP``$````,C;```&````V=L`
M``@```#@VP``"````.G;```$````\ML```@```#WVP``!@````#<```$````
M!]P```8````,W```!````!/<```*````&-P```@````CW```!@```"S<```$
M````,]P```0````XW```!````#W<```$````0MP```0```!'W```!````$S<
M```(````4=P```0```!:W```"````%_<```(````:-P``!````!QW```!```
M`(+<```+````A]P```0```"3W```"````)C<```$````H=P```8```"FW```
M!````*W<```,````LMP``!,```"_W```%P```-/<```3````Z]P``!$```#_
MW```!````!'=```$````%MT```P````;W0``!````"C=```1````+=T```8`
M```_W0``#P```$;=```$````5MT```8```!;W0``"@```&+=```(````;=T`
M``8```!VW0``"````'W=```$````AMT```8```"+W0``&@```)+=```?````
MK=T``!<```#-W0``'````.7=```;`````MX``"`````>W@``"@```#_>```0
M````2MX``!L```!;W@``&P```'?>```?````D]X``!P```"SW@``'0```-#>
M```:````[MX``!,````)WP``$P```!W?```9````,=\```8```!+WP``+P``
M`%+?```Q````@M\```(```"TWP``%@```+??```(````SM\```8```#7WP``
M#@```-[?```$````[=\```8```#RWP``!@```/G?```,`````.````@````-
MX```!@```!;@```&````'>````0````DX```!@```"G@```(````,.````0`
M```YX````@```#[@```*````0>````8```!,X```!````%/@```&````6.``
M``0```!?X```(P```&3@```3````B.```"8```"<X```#@```,/@```$````
MTN````D```#7X```"````.'@```$````ZN````@```#OX```$````/C@```4
M````">$```0````>X0``"````"/A```*````+.$```T````WX0``#````$7A
M```,````4N$```P```!?X0``%@```&SA```,````@^$```@```"0X0``"```
M`)GA```$````HN$``!````"GX0``!@```+CA```.````O^$```8```#.X0``
M!````-7A```=````VN$```@```#XX0``!0````'B```&````!^(```T````.
MX@``!````!SB```$````(>(```0````FX@``"@```"OB```,````-N(``!,`
M``!#X@``!````%?B```(````7.(```0```!EX@``"````&KB```$````<^(`
M``0```!XX@``!@```'WB```$````A.(```0```")X@``"````([B```5````
ME^(``"8```"MX@``$0```-3B```1````YN(``!8```#XX@``!`````_C```$
M````%.,```8````9XP``*P```"#C```6````3.,``"D```!CXP``+P```(WC
M```$````O>,```P```#"XP``!@```,_C```$````UN,```H```#;XP``"```
M`.;C```(````[^,```0```#XXP``"````/WC```(````!N0```P````/Y```
M&@```!SD```(````-^0```8```!`Y```%````$?D```$````7.0```0```!A
MY```!````&;D```(````:^0``"4```!TY```"````)KD```-````H^0```H`
M``"QY```!````+SD```*````P>0``"@```#,Y```!````/7D```(````^N0`
M``8````#Y0``)P````KE```(````,N4```P````[Y0``%P```$CE```$````
M8.4```0```!EY0``"````&KE```2````<^4```0```"&Y0``$@```(OE```+
M````GN4```@```"JY0``"````+/E```$````O.4``!L```#!Y0``#P```-WE
M```/````[>4``!8```#]Y0``#@```!3F```$````(^8```H````HY@``"@``
M`#/F```$````/N8```8```!#Y@``"@```$KF```.````5>8```H```!DY@``
M%````&_F```2````A.8``!(```"7Y@``!@```*KF```(````L>8``!````"Z
MY@``"@```,OF```*````UN8```0```#AY@``!P```.;F```(````[N8``#H`
M``#WY@``#P```#+G```$````0N<```P```!'YP``%@```%3G```2````:^<`
M``X```!^YP``%````(WG```1````HN<``$,```"TYP``#0```/CG```1````
M!N@```T````8Z```$0```";H```7````..@``!````!0Z```#0```&'H```,
M````;^@``!(```!\Z```"````(_H```$````F.@``"P```"=Z```!````,KH
M```/````S^@```0```#?Z```(0```.3H```C````!ND``#H````JZ0``'```
M`&7I```3````@ND```0```"6Z0``"````)OI```A````I.D```0```#&Z0``
M(````,OI```*````[.D``!,```#WZ0``!`````OJ```7````$.H```0````H
MZ@``!````"WJ```(````,NH``!(````[Z@``!````$[J```(````4^H``!,`
M``!<Z@``%0```'#J```*````ANH``!P```"1Z@``$@```*[J```,````P>H`
M``@```#.Z@``$P```-?J```1````Z^H``"P```#]Z@``!@```"KK```.````
M,>L```@```!`ZP``#````$GK```4````5NL```0```!KZP``"````'#K```"
M````>>L```0```!\ZP``"````('K```$````BNL```8```"/ZP``"````);K
M```&````G^L```0```"FZP``!````*OK```$````L.L```0```"UZP``#0``
M`+KK```,````R.L```0```#5ZP``!````-KK```$````W^L```0```#DZP``
M"0```.GK```&````\^L```0```#ZZP``!@```/_K```$````!NP```0````+
M[```$0```!#L```$````(NP``!8````G[```%````#[L```-````4^P``!(`
M``!A[```'0```'3L```0````DNP```0```"C[```!````*CL```5````K>P`
M`"<```##[```!0```.OL```(````\>P```@```#Z[```$@````/M```$````
M%NT```8````;[0``"````"+M```$````*^T```8````P[0``!@```#?M```.
M````/NT```\```!-[0``$0```%WM```8````;^T``!P```"([0``%@```*7M
M```H````O.T``!L```#E[0``'0````'N```=````'^X``!$````][@``&0``
M`$_N```R````:>X``"\```"<[@``,0```,SN```O````_NX``!<````N[P``
M%P```$;O```6````7N\``!,```!U[P``'P```(GO```3````J>\``!D```"]
M[P``$0```-?O``!"````Z>\``"0````L\```.0```%'P```O````B_```!<`
M``"[\```&P```-/P```X````[_```"4````H\0``'@```$[Q```>````;?$`
M`!L```",\0``$0```*CQ```9````NO$``!L```#4\0``&P```/#Q```D````
M#/(```\````Q\@``/0```$'R```3````?_(```@```"3\@``$P```)SR```M
M````L/(``!<```#>\@``#P```/;R```D````!O,```0````K\P``"````##S
M```(````.?,```@```!"\P``"P```$OS```$````5_,```8```!<\P``3P``
M`&/S```$````L_,```T```"X\P``!````,;S```*````R_,```0```#6\P``
M!````-OS```0````X/,```8```#Q\P``!@```/CS```&````__,```8````&
M]```%0````WT```*````(_0``!(````N]```!@```$'T```.````2/0```P`
M``!7]```!````&3T```%````:?0```8```!O]```!@```';T```2````??0`
M`!T```"0]```'@```*[T```?````S?0```X```#M]```%@```/ST```2````
M$_4``!(````F]0``%P```#GU```2````4?4``!(```!D]0``$0```'?U```:
M````B?4``!$```"D]0``$@```+;U```6````R?4``!<```#@]0``$@```/CU
M```5````"_8``!,````A]@``$````#7V```7````1O8``!(```!>]@``%P``
M`''V```2````B?8``!(```"<]@``$0```*_V```6````P?8``!@```#8]@``
M%@```/'V```>````"/<``!\````G]P``&````$?W```2````8/<``!<```!S
M]P``%@```(OW```&````HO<```@```"I]P``!````++W```>````M_<``!L`
M``#6]P``#@```/+W```0`````?@```0````2^```!````!?X```D````'/@`
M``0```!!^```!@```$;X```3````3?@```X```!A^```!````'#X```'````
M=?@```@```!]^```#P```(;X```$````EO@``"4```";^```!@```,'X```=
M````R/@```@```#F^```"````._X```(````^/@``!L````!^0``!@```!WY
M```'````)/D```8````L^0``#0```#/Y```,````0?D``!$```!.^0``!```
M`&#Y```2````9?D```8```!X^0``&````'_Y```"````F/D```@```";^0``
M!````*3Y```(````J?D``"0```"R^0``!````-?Y```(````W/D```0```#E
M^0``#P```.KY```'````^OD```P````"^@``"@````_Z```.````&OH```P`
M```I^@``!@```#;Z```(````/?H``!T```!&^@``!````&3Z```;````:?H`
M`!````"%^@``!````);Z```&````F_H```@```"B^@``!````*OZ```$````
ML/H```0```"U^@``!````+KZ```)````O_H```@```#)^@``$0```-+Z```2
M````Y/H```@```#W^@``(P````#[```/````)/L```T````T^P``"````$+[
M```%````2_L```8```!1^P``"@```%C[```*````8_L```T```!N^P```@``
M`'S[```"````?_L```P```""^P``!````(_[```$````E/L```L```"9^P``
M/0```*7[```A````X_L``"4````%_```"P```"O\```7````-_P``#\```!/
M_```(0```(_\```<````L?P``!4```#._```$P```.3\```3````^/P``!,`
M```,_0``$P```"#]```>````-/T``!````!3_0``"````&3]``!1````;?T`
M``@```"__0``*P```,C]``!1````]/T``!L```!&_@``$P```&+^```/````
M=OX```\```"&_@``"````);^```&````G_X```8```"F_@``"````*W^```*
M````MOX``!0```#!_@``!````-;^```3````V_X```,```#O_@``!````//^
M```$````^/X```D```#]_@``"0````?_```:````$?\```8````L_P``"```
M`#/_```%````//\```4```!"_P``$````$C_```!````*@,``/@!```<`P``
MF`(``.T#````````<`,``,8"```(`P``!`0``%<"``"4`@```````)X!``!2
M`0``4P,``*X!``"R````/00```D"`````````````*$!``#D`P``G`,``"4!
M``"5`0``F0,```````"N`@```````%(#``"(`0``^`,````````7!```````
M```````\`0``.P(``#<"```7`P``8@,```\!``#R`0``Q````,````"9`0``
M3P(``````````````````%P`````````2`,``&,$`````````````.H#``!M
M`P``.0,``,`!``"U````Y0,``!X$````````:P(``!\#````````#`(`````
M````````9P$``-4#````````B0```(,"``!T!```7P```.H````#`0``````
M`%4```"U`@``````````````````9@(``*T"````````'`$``%0"````````
MXP,``)@`````````B@````H"```&````[P```((`````````10,```4"``#<
M`@`````````````X`@```````!8$````````9P0``*H````=`@``,`$`````
M``#1`P``XP````````#B````6@```(@#````````]0```"8#``"+`0``[0``
M`!,"````````,P```'("``!C`@``&`$``%\$``!*`@``L@,``)8#``"$`P``
M1`$``%$$``!0````5P0``#@`````````9@````("````````1P(``($!``"'
M`0``^P,``````````````````%D```!@`@``$P$```````"9````[`,``/\!
M```,`P``:@$``%P$``"`````*P,``&$$``"1````>@,``'@$``#O`0``S0``
M`-,````X`P``_`$``-`"``!N`P``"@,``*$#``#A``````````````!:`0``
M(0,``+@"``#Z``````````````#/`0``NP```&H#``"W`@``/P,``&$!``"O
M`@``+`(```````#T````````````````````'````!(!````````H@```#P`
M``"Z`P``%P(``'@````>`@``100``!\!````````(@`````````+`@``W0``
M``````"L`0``````````````````>0```/$``````````````-@#````````
M`````&\#````````-`0``$(`````````:0,``"T$``#Y````T`$```<$``"/
M`0``HP,```````#2`@``C@$``#X#```F`0``I`,`````````````(````$D!
M```T`@``E````!$"``!Q`P``#0(``"8"``!U`@``%P```'4```#N`@``````
M`-<"``"=`0```````*L#``"E`@```````",$`````P``%P$``&H"````````
M60(``'D#`````````````"L$````````-P```#X"```D!```&````,T!``#-
M`@```````*8"``!T`@``3@,``.,!````````(P````````!N`@``7@0`````
M```M`P``%`0``,L#``"A`````P(``#$#```R````0@$``&@`````````````
M````````````X0,`````````````R@,``*H"``!&`@````````0#``!:!```
M6`$```````"\`@``T0$``#0!``!``@``<P0``.@#```V!```&@(``$X```"M
M````VP,``"<$``"O`P``*P```%L$``"0`@``]@$``!0!```N`0``^0(``#4#
M```N`@``3`,``'H```";`````````$L```#%`0``ZP```(`"``#P`P``K`,`
M`/H!``!^`P```````,<"``!?`@```````#`$```_!```4@0``!L!``!+`@``
MF@````````"7`0```````&$#```4`P``,P0```````!;`0```````#<!``#\
M`P```````$L#`````````````%8```!P!```7P,````````A`@``<00``'`!
M``#Z`P``W0,``#@$``#<`P````````(!``#X`@```````"\"``#,`P``7`(`
M`"4"``!;`@```0$``$,$``!4`````````&\!``"N````&0```,D"``#S`@``
M`````#$!``#B`P``M````$````#S````<```````````````G0(``)$"``!;
M````VP(``)\```#N`0``T0````````!(`@``R0$````````J!````````)P"
M``!Z`0``ZP(``"P$``#5`@``_@(``(\"`````````````%T`````````(0$`
M`"L"``!+`0``L0$``!4#``"0`0``4`0``/0"````````1@```,X"``!]````
M<P,``$D$``".`@``>P,``/\#``""`@``3@(``.$!``!(!````````+`"```[
M`0``40$``*`#``!#`@```````(8!````````HP````````!$`P``9@0``.<#
M``!*`0``H@$``(X```!%`````````$<`````````7P$````````1!```M`(`
M`"$$``#,`@``&00````````\`@``W0$```````"G`@```````&P#``!D`@``
M0`0``.0"````````#P0``+D#``"+````HP(```````````````````8!``!V
M!```?@(``+<```"7`@```````'@!`````0``2`$`````````````^P$```X$
M``!C`P``]P```#L$````````40,```````#+`@```P0```````"#`P``=@(`
M`.\"``"*`0```````+0!``#"````3P$``"0```!-`0```````#D$````````
M`````(D!``!Q`0``*````'X!``!(````````````````````,````#$```!]
M`0``L0,``"D#``!$!```"P$``)P!``"#`0``/@0``&0#``"%`P``W@``````
M``#]`@```````,$!````````/0(``,`"```0`0``$0,`````````````300`
M`,@"```@`P``!0,``%H"````````P@$``!,#``!``0``N`,```8#```H`@``
MX@$``%@"``#N`P```````*8#``#V`@``3P,``'P```!#`P``QP```(0`````
M````F`$``%8#``#D`0``5@(```@```#E`@````````L#``#Y`P``P0,``-8#
M``!&!`````````````#)````A@```&<````+!```)@```(T!``#R`P``?P``
M`/P"``#I`0```````%<!```-`0``]P,``+T"``!4`P``RP$``#H#````````
M=00``#P$``"_`@``&`0``*<#````````\0,``&($````````.0$``"("```B
M!```9`0``-8"``#X````50,``(@"```E!```"0,``*4#``!-````!`(`````
M``#Z`@``Q@$``)T```!X`@``.0``````````````50(``#<#``#.````````
M``````!``P```````!H$```8`P```````.\#``#'`P``=`,```8"``#4````
M7`,```````!Q````,`,``````````````````!X!``!V`P``6````!4"``"*
M`@```````/\````Y`@``KP$`````````````BP(``.H"````````!00``,\`
M````````:P$```8$``#Q`@``>0(```@$```>`P``^P````````"H`P``V0``
M``X!``"[`@``[`$``#T!``!C`0``````````````````I`(``(<```#K`P``
M`````!T```!4`0```````'P#```8`@``D````"D"````````,@,````````M
M`@``40```#,"````````R`,``*0!``!\`@``UP,``,4#````````70(``,0!
M``#@````!````&D```!_`P``E`$``"<#``#?`P````````````!F`P``O@,`
M`"`!```=`0``\````$D``````````````/`!``#"`@``V@,``(<#```;`P``
M600```````"H`0``[`(``"\$``!>`0``'@```"\!````````E0(`````````
M`````````,H```#+``````````````!8`P``ZP$`````````````W@$``+H`
M``#F`P````````(#``"R`0``````````````````>P(```````"2`0``````
M`+D```!<`0```````'8```",`0```````&L#````````Q`(``($"``"]````
M1````-@!``"/````*0$``!8!```]````PP$```````"&`P``E0,``*P"``"2
M`````````*,!````````O@$```````#.`0```````"\#``"S`0```````%T!
M```-`P``_0,``-<```"Z`0``W@,```````"6````-@(`````````````O0,`
M`%T$``"?`@``I````/P`````````F@$```````!H`@``O0$````````6`P``
MM@`````````N````*`0```````#&````>@0``"@!``"3````GP,```````#I
M`````````&P!```Z`0``.P````````!/````$`0``#$"``!C````&P(``.D"
M````````NP$``#,!```,!```.@0``%X#``#,`0```````*<!```,````J0(`
M`$$``````````P,``````````````````*("``"Y`@``;`(``#4`````````
MGP$```````#S`0````````````!2````50$``````````````````'\!````
M````D@,```T`````````A`$``#\```````````````D$``!W`P```````$\$
M````````Z0,```````!0`P``V0$``"@#```^`0``3@$```````#:````Q0(`
M`+("```<`@```````)X````2`@``B0(``!,````U!```*@$``$$$``#6````
M`````!$``````````````*8````\`P```````$<$````````^P(``!T$``#D
M````*P$``-4`````````4P(``)0#````````00$```````!"!```]P(`````
M```,`0````````````"V`P``Y@```',```!H`P```````+X`````````````
M`````````````````$X$```"!```1@$``!(```":`@``90(``-(!````````
MXP(``/T````/`P``"@0``)`#``!J!````````!T#```S`P``,@$```(```#W
M`0``!P$``"$````?`@``JP$````````[`P``8@$``%X```!,`0``W0(```0!
M``"1`P```````&4$``"@`@``FP$````````*`````````)P```#9`P``JP(`
M`(P#``",`@``J`````````!N`````````"(!``#@`0`````````````.````
M%0`````````Z`@``1P$``"X#``#5`0```````-`#``!"`P``3`(``,P````:
M`0```````,\#``!@`P``````````````````OP```"D```"N`P``9P(``"<`
M```G`0```````$T"````````%00``$4!``#;````TP,``(X#``"1`0``````
M`&D!``"8`P``A0(```````"F`0``PP```),#``#Y`0```````*L```"_`P``
M@0````````"3`0``D@(``!8"````````>P0``$$#``!\`0``L`$``%D!``#?
M`@``L0(``%("```5`0``G0,```````"O````5P,``%T#````````````````
M``"-````,@(``#8!``#R`@``@0,```````!X`P``\@````````!M!```X`(`
M```````4`@```````%`!```L````T0(``(<"``"W`P``TP$``-D"````````
MTP(````````D`@``R````"4```!D`0``O````#\!```/````>P```-\`````
M````6P,``)8!`````````````.@```!6!```V@$``)L"````````E@(``,(#
M````````20(``#8`````````]@```*H!``">`P``VP$````"``"/`P``S@,`
M`.X`````````$@0``$,```#U`P``A@(``"0!```@!````````-(```#V`P``
M?0,``'X```````````````````"A`@````````````"Y`0``[0(``.("```C
M`0```````!P$`````````````+@!```B`P```0,``"D$````````M@(`````
M``!S`0``<@```/X``````````````'4#``"M`P``=0$```````"\`P``````
M`!D"``"P`P``4P```/X#``#!`````````!`#``"T`P``Y0$```````!N`0``
MJ0,``#0```!W!```1`(``#0#``"U`P``:00``,4``````````````*<````'
M````P0(``&`$````````:`$``&L```!5!````````*(#``#Q`0``_0$`````
M``"$`@``I0```)4`````````W@(``'D!``!G`P```````$("``"L````;P0`
M`',"```(`@``20,```````!T`0``40(``+,"``!R!```P`,``+X"```M`0``
MW`$``'<````]`P```````(H#```6````;`0```````"``P``4P$```X"```4
M````-0(``+4!``"%`0``>00```````#@`P``+0```````````````````*H#
M``!*````T`````````!3!````0(``*`````(`0``U`,``&`!````````3```
M`-\!```D`P``R@(````````)`0```````&@$``##`P```````%8!````````
M_@$``,<!```V`P``````````````````>P$``!D#``#2`P``SP(``/4"```Q
M!```YP````X#``#-`P```00```````"9`@``O`$``+8!``"S````6@,``!``
M``#L````)@0``!\`````````Y@(`````````````"0```%@$``!B````'P0`
M`$4"``!N!````````&T!``"Z`@``]`,``&4!````````R0,```````":`P``
M`````(T"```@`@``;P(``#\"``!L````NP,`````````````1P,``!L`````
M````BP,``'0```!A`@``J`(``,0#````````YP(```````!P`@``=@$```T$
M````````W````!$!``!J`````````!H```!>`@``-0$```````#&`P``````
M`'$"``"-`P``;0(``","``!Z`@````````````!,!````````.T!```'`@``
ML````,,"``#S`P``V`(```````!W`0``)P(```````````````````````#A
M`@``Y@$``)X"``#7`0``00(``(`!````````Z@$``'T"```X`0``&0$`````
M``#U`0``60,``$H#```2`P```````"4#``!+!````P```"X$````````OP$`
M````````````DP(``(@`````````=P(````````+````_P(``&("``!I`@``
M"@$``&4#``#:`@``LP,``,H!``!7````4`(``%0$``";`P``U`$``(D#``!#
M`0``I0$``&\`````````8````#`"``"X````;0`````````L`P``!0```&4`
M```L`0``#P(``-@``````````````-0"``",`````````)<#```;!```YP$`
M```````:`P```````"H"``!F`0``!0$``-8!``"#````J0```*T!``"%````
M<@$````$``"I`0``1@,``#<$``!*!````````#X````O````EP```"H`````
M````@@$``!,$```R!```!P,```````#H`@``H`$```````""`P``$`(``",#
M``#P`@``Y0```#H`````````<@,``$T#`````````````'\"``"Q````9```
M``````"W`0``Z`$``/0!````````R`$``&$```!K!````"`H)7,@9&%Y<R!A
M9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@*'EE<W1E<F1A>2D`(&%T
M(``E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`
M)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y
M(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E
M<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S.B`E<P`L(&=U<W1I
M;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M
M+0`R-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R
M('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN
M+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@9G)O>F5N+@!!
M8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI
M<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S
M:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`
M061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!U<V5R
M`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O
M;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E
M<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG
M97)I80!!;&EA<P!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QR
M96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-
M4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E
M('1E;7!L871E<P!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U
M<R!0<F]X>0!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC
M871I;VX`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H
M87)E<P!!<'!R;W9E`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H
M:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G
M96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)U8F$`07-C
M96YS:6]N($ES;&%N9`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!
M=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N
M9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B
M-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E
M<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H
M7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL
M960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I
M;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)A8VMG<F]U;F0@0V]L;W(`0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A
M:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H
M`$)A<F)A9&]S`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D
M80!":'5T86X`0FER=&AD87D`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!"
M;VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`
M0F]T<W=A;F$`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U
M;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<P!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D
M80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN
M;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E
M;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O
M=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#
M87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H860`0VAA;F=E`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O
M<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L:6-K('1O($-O;G1I;G5E`$-L;W-E
M(%=I;F1O=P!#;&]U9',`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;VUB
M:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@
M4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]N
M9&ET:6]N<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I
M;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"X`0V]O:R!)<VQA;F1S`$-O<'D@<V5L96-T:6]N`$-O
M<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82X`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N
M;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@
M<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N=')Y`$-R96%T90!#
M<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@
M8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT
M(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U
M="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#
M>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871E`$1A=&4@4F5C96EV960`1&%T
M92!S96QE8W1I;VX`1&%Y`$1E8V5M8F5R`$1E8W)E87-E($EN9&5N=`!$969A
M=6QT($ED96YT:71Y`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI
M<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QI=F5R>2!T:6UE
M`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N
M=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I
M;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P
M;&%Y($]P=&EO;G,`1&ES<&QA>2!F;W)M870`1&II8F]U=&D`1&\@;F]T(&1E
M;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U
M8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!%
M+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``
M161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S
M:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N
M<R!F;W(@)7,`16=Y<'0`16P@4V%L=F%D;W(`16UA:6P`16UA:6P@061D<F5S
M<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF
M:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L
M="X`16YD('EE87(`16YL87)G92!%9&ET;W(`17%U871O<FEA;"!'=6EN96$`
M17)I=')E80!%<G)O<@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V
M97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L
M92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&ER871I;VX@1&%T90!%>'!O
M;F5N=`!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O
M<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@
M=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E
M('1O("(E<R(N`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)
M<VQA;F1S`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&
M:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`
M1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('5P;&]A9`!&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`
M1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0`1F]N="!#;VQO<@!&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S
M`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%N8V4`1G)E;F-H($=U:6%N80!&<F5N
M8V@@4&]L>6YE<VEA`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`
M1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86UB:6$`1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;@!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=I=F5N($YA;64`1V\`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E
M`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!
M9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'
M<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S
M="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`
M1W5Y86YA`$A434P`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA
M:71I`$AA<V@M06QG;W)I=&AM`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O
M9B!T:&4@9FEL93H`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R:7IO;G1A;"!2=6QE`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;F=A<GD`24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N
M(&9A:6QE9#H@)7,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)8V5L86YD`$EC
M;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$EM86=E('5P;&]A9`!);6%G97,`
M26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC<F5A<V4@
M26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`
M26YF;W)M871I;VX`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!M97-S86=E<P!);G-E<G0O
M36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G1E9V5R`$EN=&5G
M97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A
M;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN
M=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O
M<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<')O=&]C
M;VPN`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D
M871A+@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)
M<VQE(&]F($UA;@!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A
M`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`
M2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`
M2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R
M:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE
M;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:7)I8F%T:0!+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`
M2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T
M(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO
M9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87EO
M=70`3&5B86YO;@!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI
M<FEY80!,:65C:'1E;G-T96EN`$QI;FL`3&EN:W,`3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R`$QI<W0@2&5L<"!4;W!I8W,`3&ES="U!<F-H:79E
M`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M
M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]C86P@=&EM93H@`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QU>&5M
M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L
M878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86EL`$UA:6P@061M:6X`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%R8V@`36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R
M=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T
M:`!-87D`36%Y;W1T90!-96UB97)S`$UE;G4@;6]D93H`365S<V%G90!-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I
M<F5D+@!-97-S86=E('1Y<&4`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=')I8P!-
M97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:6UE(%1Y
M<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UI<G)O<@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E
M('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A
M<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG('-E<W-I
M;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&EF:65D($1A=&4`36]D=6QU<P!-
M;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD
M('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`
M36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D
M;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:7!L92!S96QE8W1I;VX`37D@
M06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/
M+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T
M:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!5
M4DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC
M871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K
M`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($UO;VX`3F5W(%5S97)N86UE("AO
M<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S
M`$YE>'0`3F5X="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI
M9VAT`$YI=64`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&9I
M;&4@=7!L;V%D960`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P96YD:6YG('-I9VYU<',N`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A
M:6QA8FQE(&9O<B!C86-H92X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`
M3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;VYE`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@
M27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)
M<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E
M8W1O<GD`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]V96UB97(`3G5M8F5R`$YU
M;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!R;W=S`$]+`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F:6-E
M`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RX`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O
M=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R
M<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN
M(&$@;F5W('=I;F1O=P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@
M3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS
M`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG
M:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@
M2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H
M96QL`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%S<W=O
M<F0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@1&5N:65D`%!E
M<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I
M=&-A:7)N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&]L86YD`%!O
M;&QS`%!O<G1U9V%L`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``
M4')E<W-U<F4Z(`!0<F5V:65W`%!R979I;W5S(&]P=&EO;G,`4')I=F%T92!+
M97D`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0
M=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2
M:6-O`%%A=&%R`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C
M=&EO;@!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5M
M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@
M<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@`%)E<V5T`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2
M;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG
M:'0`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S
M86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-A`%-A:6YT($AE;&5N80!3
M86EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M
M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I
M80!3879E`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`
M4V5A<F-H`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E
M;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E
M<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE
M(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N96=A;`!3
M96YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA
M;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T('5P(')E;6]T
M92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P
M;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D
M:7-P;&%Y(&]P=&EO;G,N`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I
M;F<@:6X_`%-H;W<@<&EC:V5R`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H<FEN:P!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<@9&5P=&@Z(`!3;VQO;6]N($ES
M;&%N9',`4V]M86QI80!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D
M<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-O=71H97)N($AE;6ES<&AE<F4`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A
M8W1E<B!);G!U=`!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<G0@>65A<@!3=&%T
M92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D
M9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=0!3=6)J96-T`%-U
M8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@=W)O=&4@)7,`
M4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;G)I<V4`4W5N<FES
M92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP
M=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-
M87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y<FEA;B!!<F%B
M(%)E<'5B;&EC`%135B!F:6QE`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S
M="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!
M9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!4:`!4:&%I("A425,M-C(P
M*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V]N=&%I;F5D
M(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC
M92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M
M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U
M;F0@;VX@=&AE('-Y<W1E;2X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E
M8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L
M;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@
M8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S
M(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E
M<75I<F5D(&9I96QD+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES
M("5S+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H
M:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1I;64`5&EM92!4<F%C:VEN9P!4
M:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4
M;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N
M=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG
M+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R
M<F]W`%1O;F=A`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4
M=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO
M=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DPZ`%5G86YD80!5:W)A
M:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I
M;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG
M97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N:6-O9&4@*%541BTX*0!5;FET960@
M07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN
M;W=N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N<W5P<&]R=&5D
M($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A
M9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57)U9W5A>0!5<V5R
M("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A
M=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E
M<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E
M;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!6
M86-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED
M:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686YU871U
M`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)
M*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E
M<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3
M+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&
M4D]-("5S+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@
M1F]R96-A<W0`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R
M;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5V]R:R!!
M9&1R97-S`%=O<FL@4&AO;F4`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!9
M86AO;R$@;6%P`%EE87)L>0!996UE;@!997,L($D@06=R964`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA
M:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I
M;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A
M5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI
M;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@
M9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA
M:6P@061D<F5S<P!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E
M<UT`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z`&EM;65D:6%T
M90!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`'1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YN86UE9`!U<V5R
M('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#(N,`I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ
M,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#$M,#8M,3@@,C(Z,#4K,#@P
M,`I,87-T+51R86YS;&%T;W(Z(&QI86]B:6X@/&QI86]B:6Y`:FET92YN970^
M"DQA;F=U86=E+51E86TZ($-H:6YE<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]1T(R,S$R"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M
M8FET"@`@*"5S(,SLQ[`I`"`HO^R]W;S\("5S*0`@*+WQS.PI`"`HU_+,["D`
MT]H`U^Z]_"`E9"#,[,;XS_/4I+&H`"5S("T@L;C-_,*\`"5S(-:XSL8`)7,@
M2T(`)7,@SJR[I++9U_<@+2#(M\C/`"5S(->BLN$`)7,@S:S2XL_NQ+\`)7,@
MTM&TYM3:`"5S(-3:("5S("5S`+'8T.C2JB`E<P`E<R"WU@#5TK*[M;T@)7,N
M`"`E<R"UO2`E<R"YLB`E<P`E<SH@)7,`+"#5\[?G("5S("5S`"RQY+NOP;^T
MTR`E<R"UO2`E<P`M+2#1H=3Q("TM`#(T(-"ARK'6Q@"TR\?XO^FQV-#KTJK6
MN+:HROV^W;_BM_[.\;;++@"WHLGZP<O2N[CVT<_6V+7$M.W.\P#3^[S3P]S3
MRKS^++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<U+\N`-/[T>G6I-+1QZG#^[7$
MT\J\_BR[N=#HTJK3T-*[N/8@4$=0(+FKOZK#W-2_+@#3^[WBP]S3RKS^++NY
MT.C2JM/0TKNX]KFKOZH@4$=0(,/<U+\LR[W#W"!01U`@P]S4ORS2U+RPO]K!
M[BX`T_O6M-#0T\J\_L>IP_LLN[G0Z-*JT]#2N[CVN:N_JB!01U`@P]S4ORS+
MO</<(%!'4"##W-2_+-+4O+"_VL'N+@#3^[WBP]S3RKS^++NYT.C2JM/0TKNX
M]KFKOZH@4TU)344@P]S4ORS+O</<(%--24U%(,/<U+\LTM2\L+_:P>XN`-/[
MUK30T-/*O/['J</[++NYT.C2JM/0TKNX]KFKOZH@4R]-24U%(,/<U+\LR[W#
MW"!3+TU)344@P]S4ORS2U+RPO]K![BX`T_N\T\/<T\J\_BR[N=#HTJK3T-*[
MN/8@4TU)344@N:N_JL/<U+\N`$%-+U!-`$%022"QX+K%`+G8T]K5XKCVL>"\
MK<;W`+G8T]HN+BX`R*C/WK*[U^,LSMZWJ+VHP:(@5D93(,2_PKPN`,BHS]ZR
MN]?C+,[>MZB]J,&B(%9&4R#.Q+S^+@#5R[K%TM&VL[WA+@"]X=7*`-#"U/8`
MT,+4]L_"O+;7Z0#0PM3VS\*\MLBHS]X`U-JTR]#"U/:CN@#0PM3VT\.[I]?I
M`-#"U/;(J,_>`-#"U/;2N[CVT\.[ISH`T,+4]M*[N/:SR=2Q.@#0PM3VMM0`
MT,+4]B`E<R#.JB!-;WII;&QA(%-I9&5B87(@LLNUI0#0PM3VT\.[IP#0PM3V
MT\.[I[7$N:;$W+6QQ["QN[G8L=4N`+78UK<`S:C1MK*^`+/)SJJYW,#MU+$@
M+2#.JL;DR_S3P[NGQ>36P\BHS]X`N=S`[0"YX[CFN=S`[0"PHKB[NKD`L**V
M^[#-Q.'1QP"PHK;[O+#`^]''`+'PP_L`R_G3T-+1T>G6I+7$T\.[IP#+^=/0
MT\.[I]?I`,OYT]#(J,_>`-3*T.VVX+CVM>?7T]/*O/ZUV-:W`-+1M.;4V@"Q
MY+C\($E-4U`@M<?"O`"QY+C\($E-4U`@P]S"ZP"QY+C\($E-4U`@T\.[IP"Q
MY+C\Q*.PY@##P,KTR/C$IM''`-*[N/:RN[K/MZBUQ-:UL;O*N=/#+@"PLK7`
MMOL`L+*XY\"M`+"RN>?`K0#$Y,/[M/K`[0#$S[RKUMX`L++,X;G/O+"PS;;[
MLKRT[P#3IM/#L\S0\@#3IM/#L\S0\M+1OLW0]P#3IM/#M;W+^=/0S\*\MKFR
MS^T`Q?K7O`#+Q-3"`+"BP*VRKL[$("A7:6YD;W=S+3$R-38I`-&YR_7.Q+S^
MM//0H0#1N<OUSL2\_L/[L\8`Q/K(M[:HTJK)OK/]("5S(+7$UZ*RX<+P(#\`
ML**X^<VB`-''P\#$X=''`-''P\#$X=''SL0@*$%235-#24DM."D`L*+"L[#-
M`+"BR:W+R<BZM;H`T<?6WB_,J\:]T?.UV,?X`-:TT-#.K+NDLMG7]\>PS]3*
MOLBWR,^VU+NPO_(_`,K4S;S)OK/]TKNX]K*[M.;4VK7$T\.[I]?I+@#*U,V\
MR;ZS_=*[N/:RN[3FU-JUQ,BHS]XN`,K4S;RQX+RMTKNX]K*[M.;4VK7$T\.[
MI]?I+@#*U,V\L>"\K=*[N/:RN[3FU-JUQ+FRS^TN`,KTT-0`L,O4P@"PQ+3S
MP/O1QP"PPK78P/L`075T:%]C<GES<6PZ(-72LKNUO<OYT.C2JK7$(&EM87`@
MP*G5N=?IO/XN`$%U=&A?8WER=7,Z(+?^SO&VR[*BSK3,X;FIN,//[M:GL]8N
M`$%U=&A?8W)Y=7,Z(-72LKNUO<OYT.C2JK7$(&EM87`@P*G5N=?IO/XN`$%U
M=&A?9G1P.B#5TK*[M;W+^=#HTJJUQ"!&5%`@P*G5N=?IO/XNQ^O6V-#"L>#2
MZR!02%`@LJ+'TKS3R.L@+2UE;F%B;&4M9G1P(-&AS^XLP/W(YR!C;VYF:6=U
M<F4@+2UE;F%B;&4M9G1P`$%U=&A?:6UA<#H@U=*RN[6]R_G0Z-*JM<0@24U!
M4"#`J=6YU^F\_BX`075T:%]K<F(U.B#5TK*[M;W+^=#HTJJUQ"!K<F(U(,"I
MU;G7Z;S^+@!!=71H7VQD87`Z(-72LKNUO<OYT.C2JK7$($Q$05`@P*G5N=?I
MO/XN`$%U=&A?;&1A<#H@SMZWJ-#"U/;3P[NG("5S+B"W_L[QQO>[V-.F.@!!
M=71H7VQD87`Z(,[>MZC)OK/]T\.[IR`E<P!!=71H7VQD87`Z(,[>MZBX_-#"
MT\.[IR`E<P!!=71H7VUC86PZ(-72LKNUO<OYT.C2JK7$($U#04P@P*G5N=?I
MO/XN`$%U=&A?<VUB875T:#H@U=*RN[6]R_G0Z-*JM<0@<VUB875T:"#`J=6Y
MU^F\_BX`T>G6I,JGL-PN`-'IUJ3*I[#<+B`E<P!2041)55,@T>G6I+3MSO,N
M`$944"#1Z=:DM.W.\RX`O\G3P[7$U]:VSCH`L*+(^[#=O:X`L;.^L-'5R:L`
M:V5R8F5R;W,@P]S"Z[3MSO,N`&ME<F)E<F]S(-/#NZ?#^[3MSO,N`+#-N?["
M[<BZM;H`L,W!U@"RJ,+>M<2ZH\[$("A)4T\M.#@U.2TQ,RD`P\^\T\"MN?H`
ML,VPS;;@R[D`L->V[<+>R[D`L<C`^\JQ`+*NP/O7R`"QM,3^`+#9Q+VT\\BZ
MM;H`LKNUI`#)^LC5`,?XO^G%Y-;#`,?XO^G`X-#-`+36S.4`LJ/`^\ZLT<<`
MRNG'J0"RJ,NYQ.'1Q[K-NMK(^[CGSJS$QP"RJ;3$S=_$R0"RJ,ZLS-BUN@"P
MS<[W`-.BRO33H;;(T?/![+78`,[$P+,`L:.\T\#[T<<`S^[$O[?[NL4`LKR\
MJL3)MZC+]P"RO,*AM<\`Q-K(W;G<P.W/M<VS`$-20P!#4DP@M]:RO+7C`,C5
MP/H`P>.\MK?G`+SMQM+5KP"_IL+SPJ$`SMZWJ,&JN_K6P2!)34%0(+?^SO'&
M]SH@)7,`O-/$P[3S`,BAS_L`R*'/^\[*S.*QJ+CF`,[>MZC)OK/]SL2\_B`B
M)7,B+@#.WK>HR;ZS_<2_PKP@(B5S(BX`SMZWJ-;8U^FAH\OYS.&YJ;7$O,?"
MO,K]Q+_3Z\_(Q[#+^;&CM.:UQ,K]OMVRN[?[+@#.WK>HM*O+S=#%SZ*UO=:X
MMJBUQ+K%PNLN`+?PM<.]QP"_JL+\R+JUN@#2QK:OM>>[L`#(^[;[S-C.Q"`H
M25-/+3@X-3DM,30I`-;0M\>YLKK-N?H`UM#%MR`H25-/+3@X-3DM,BD`QK[6
MI,^XO=H`QK[6I++?PM0`U:>UPP"X_+C$`-;'P/L`UM"Y^@"\\LSEUM#.Q"`H
M1T(R,S$R*0"WL<SEUM#.Q"`H0FEG-2D`T:'4\</<PNL`T:'4\=*[N/;3P[NG
MP_L`R-7&VL_4RKZWO<J].@#*I;6NM;H`U=*RN[6]("5S(+7$P."Q\+:HTN4N
M`+"TRO.QZKS\O,S0^`"YV+'5M+"_V@#4QL&_`+_&O\;+N<BZM;H`N.?"U['(
MT<<`T=7)JP"U]\FKQ<P`OZC-J`##_,'N`,/\P>Z]Q;&^`,;`PML`S:C3P\/[
M`+_&Q*;"W@"YJ\N^`,SUO/X`Q>36PR`E<P#(M\C/P]S"ZP"XU;G[`+C5N?NY
MLKK-N?H`P:R]T\JGL-PZ(`#!K+W3UL&YJ[^JP]S4O[?^SO'&]\JQU.*^W+[X
M+B#4K=+R.B`E<R`H)7,I`,&LO=/6P2!&5%`@SL2\_K?^SO'&]\JGL-PN`+_B
MO\O(NK6Z`+BTUL;1H=3Q`+CGR[FT[\#HO-,`O\;,V+7/S=\`SMZWJ-+4(%!'
M4""\T\/<T\J\_BX`SMZWJ,ZJ(%!'4"#6M-#0T\J\_L>IP_LN`,[>MZC2U"!3
M+TU)344@O-/#W-/*O/XN`,[>MZC.JB!3+TU)344@T\J\_L>IP_LN`,[>MZBP
M\[:H($Q$05`@M_[.\<;W`,[>MZB]XL/<(%!'4"#*_;[=+@#.WK>HO>+#W"!3
M+TU)344@ROV^W2X`SMZWJ+[VMJC*U;S^R,NUQ+7GU]/3RKS^M=C6MRX`SMZW
MJ-?4P]S4O[?^SO'&]\BAM<.YJ[^JP]S4ORX`SMZWJ+3ROZH@)7,N`,[>MZBT
M\K^JSJR[I+FDU_?$H[_I("5S`,[>MZBVP<BA("5S+@#.WK>HML'(H;3FR*&_
MV-;&L>TH04-,*0#.WK>HML'(H;?^SO'&][7$S^"YV,S8T-0`SMZWJ+&CM.8@
M)7,@M<3%Y-;#+@#.WK>HLNG5TB!,1$%0(""W_L[QQO<N`-72LKNUO2!-;WII
M;&QA(%-I9&5B87(N(,?KR+?(SR!S:61E8F%R(,K'M_&T\K^J+@"Y^KS2`+VH
MP:(`O:C!HM?3SL2\_KS0`+VHP:+5W[7$R*C/W@#0Q=/#OZBZQ<+K`+_+PMZU
MV-''`+G%L,T`M;''L,JQO.0`M;''L,SLQO@`M;''L->TO_8Z(`"UL<>PM^>X
M\0"\],?0T:'4\0#(^\;6PK?+N0#.]\#OMOO.Q"`H2T])."U2*0#.]\#OMOO.
MQ"`H5VEN9&]W<RTQ,C4Q*0#.]\#OMOO.Q"_.VK_+P+S.Q"`H2T])."U5*0"]
MW;_+N;*ZS;GZ`,C5`,._R-4`R-7&V@#*U;6]R-7&V@#1H=3QR-7&V@"PU\SL
M`,JNMO[4P@"\]<G9R_7%Q0#$K,C/R>VWW<JVL?``R;ZS_0#)OK/]T\.[I]?I
M`,F^L_W(J,_>`,F^L_VAHL?EO]73RKS^`+7=R\W*L;SD`+6DPO,`SLK,XL/H
MRO8`P^C*]@#/N+W:("C'Z[+.O[P@2&]R9&4@O,?"O,[$O/XI.@#/N+W:Q^NR
MSK^\S[7-L[G<P.VUQ\*\+@#1T+>B`,*VM>/.PK;(`-?NNO/2N]"ARK&UQ,*V
MM>/.PK;(.B``PK:UX\["ML@Z(`"TT]?SUL'3T@"TT]/2UL'7\P#$O\*\`-+4
M(#(T(-"ARK'6QL_4RKX_`,_4RK[1H<_N`,_4RKZX\<J]`+RJLKS,X0"RN\F^
ML_T`LKO2JM:QO=.TYLBA(&UA:6YT96YA;F-E+G!H<`"UVM*[L<J\Q\*\RL>W
M\;#\NJS7UK;.P_NSQC\@R.>Y^\K'Q^O1H=3Q+@"VX,/7Q.&\TP"VX,/7Q.&\
MT[FRNLVY^@#/PM38`,_"U-@@)7,`S\+4V,GZL\FUQ,7DUL/.Q+S^SJH@4$A0
M(+/,T/(N`,_"P*VRR[6E`+7GU]/3RKS^`+3MSO,`MO*YS[;@MOL`L>"\K0"Q
MX+RMQ_B_Z0"QX+RMT\.[I]?I`+'@O*W(J,_>`+'@O*W(J,_>`+'@O*T@)7,@
MM<3(J,_>`+'@O*W1H<_N`+'@O*T@)7,@M<3(J,_>`+"CO+``R/BV^\W?MN``
MM>?7T]/*O/X`M>?7T]/*O/ZUV-:W`+7GU]/3RKS^M=C6M['8T.O.Q[K/+@"U
MY]?3T\J\_LBWR,\`L>W'Z;?[NL4`O]6PU]#%O/XN`+_5L->]X;G[+@#$ZK77
M`+?%M/.QX+RMQO<`L^"UP+RXQ-K1QP"V\L&BS-C`[]''`+3MSO,`L*[)L\3A
MT<<`L*/(^[;ML<C1QP#%M];>`,._(#$U(+?6UM,`P[\@,S`@P^O6TP##OR`U
M(+?6UM,`P[^TSK7'PKP`P[\@,S`@M];6TP##OR`Q(+?6UM,`M[;`_=:U.@#6
MM-#0`-6YOZH`M;W&VLC5`+WBR[74L0!&5%`@R<^TJ\7DUL,N`+;!R*'&J[K#
MQ>36P\JGL-P`SMZWJ,&LO=,@3$1!4""W_L[QQO<N`,[>MZC!K+W3(%--0B"W
M_L[QQO<N`+BTUL;*I[#<U]0@(B5S(BX`N+36QLJGL-RUO2`B)7,B+@#.WK>H
MO:C!HM*[N/;0PK7$(%-!4TP@P:R]TRX`TL:VK[6]("(E<R+*I[#<+@"WJ,"\
MO\NXH\BZM;H@*,+MMOO.K,3)R[G(NK6Z*0"WJ,+>R+JUN@"TJ]7F`+;^U,(`
MN-"^]<_QRL<`N-"^]<_QRL<Z(`#LL[S#`,[$O/[*_<2_.B`E<R"X]L[$O/X`
MSL2\_LK]Q+\Z("5S(,[$O/X`SL2\_KG<P.W&]P#.Q+S^P_NSQ@#.Q+S^R<^T
MJP#.Q+S^R<^TJ[FFQ-S.M+&[UJ>SUBX`N?W"R\;W`+?2P+P`R<^PZ]3"`,G/
MS]+4P@"YS+:HL<C`_0"WK=>J`,2_PKP@)7,@LKNTYM3:`-?6T,W1U<FK`-2D
ML:C,[,K]("C4I+&HS.S*_;#\P*BPU\SLTM2\L-*YO.2UQ,K]OMT[R.>Y^]2D
ML:C,[,K]O<^SI+VKU;S3P['(O<^_[;?YM<2PYL/F*0"TL,SE`,OCP_P`R^/#
M_,#@T,T`R^/#_`#"V\RS`-?4MJ_7JM#%`-#'QMK.Y0"WJ+GZ`+>HRO2YY]''
MQ,<`MZC*]+*CP/O$X<[WT<<`O,2\_LC+`+33`,WJU?O#Z,KV`,+ZU,(`R*O#
M^P"\T\7N`+C4L<C1QP"R^LGZ("5S(+7$S[7-L\7DUL,`N/'"L[RJT<<`M<*Y
M^@#ER,3)`-:QLKS"WLW3`,/[`->JM;T`1V]O9VQE(,O1R_<`N]*VR`#/H\"P
M`,^CP+#.Q"`H25-/+3@X-3DM-RD`N/'!ZL"\`+CQP=;$R;3O`-/#NZ?7Z;G<
MP.T`T\.[I]?IP_NSQK*[M<._U;#7`-/#NZ?7Z0"YS[7"PM[&U;6Z`+G8M;H`
MSJ.UV,+MP*T`N/&V]\[WM;H`M\._S<BHS]X`M\._S<'TT=0`O+C$VM''`+RX
MQ-K1Q['(R=RYLKK-N?H`N>?1Q\3'`$A434P`U=*RN[6]($A45%`@T>G6I"X`
MNJ.UV`#4T[35+<OCMZ@`L>W-MP"ZU;7"NLW"]+6QP,W(NK6Z`,^CLJ[`M,[$
M("A)4T\M.#@U.2TX+4DI`+#OUOH`L>"\K<;WRKG3P[#OUOH`L._6^@#5XL#O
MRL?.Q+S^M<2_JLJ\.@#H\[79N-0`RM?2LP#*U]*SM=C6MP#*U]*SM>>[L`"Z
MZ;:\P*W+N0#6T+GZS^.XVP!(;W)D90#+KL:]S]\`U]:VSLK]Q+^YLKS&/P#*
MJK;(`,JJML@Z(`#0V='`P/L`24U!4"#3RL_DO:C!HLJGL-PZ("5S`$E-05`@
MT\K/Y,F^L_W*I[#<.B`E<P!)34%0(-/*S^2TQ<7,Q>36P[VHP:+*I[#<.B`E
M<P!)4""UV-:WSMZWJ,JYT\,N`$E0(+78UK>RHK*[U-H@0TE$4B"UQ+W3RMS'
M^+_IUM`N`+'YM;H`UKO3T,V\L>H`S;RQZKRPSL37U@#)S[2KS;S&K`#-O,:L
M`+OCR.LL(+*]UN@@)60`N^/(Z]?6MLXZ("5S`+OCR.O7UK;..@#*Y,CKLKO5
M_<BWM<37]]/#PNLN`-3VO-/+]<7%`-.AML@`N/:Q\-/#NZ<`TZ&VR,3ASO?1
MQP#0Q<^B`-#%SZ(`LN7(Z['MN/$`LN7(Z\WXPN?!K+W3`++ER.N_R<SFM/K$
MH[#F`++ER.O3RKS^`++ER.LOL>2X_,V\QJP`LN7(ZR^QY+C\S?C"Y\&LO=,`
MU?O*_0#5^\K]P=``SM[0I[7$(%5$2"C3P[NGROV^W;'MS;<I+@#.WM"GM<33
MIM/#L\S0\BX`SM[0I[7$Q?JTSKK%PNLN`,SAO;NUQ,K]OMW.WM"G+@#.WM"G
MM<3$O['JUZ'6MP"RN[K/MZBUQ,[$O/ZX\<J]`,[>T*>UQ"!M<V=?='EP92X`
MSM[0I[7$N_+5TK*[M;T@87!I7VED+@#.WM"GM<2[\M72LKNUO;+.ROTN`+*[
MNL^WJ+7$N+C(J,_>+@#.WM"GM<3-J-&VT*W2Z2X`SM[0I[7$P+34M->AUK<N
M`,[>T*>UQ,WRT\/"Z\K]OMTN`-+!P,K2P<NYP+RYLKK-N?H`TL'`K;_+`+"N
MMOO`O`#"_+6Z`-+4R:O!T`#'J;>BU=\`T+',Y0#2XK3SP/L`T<#"\KS3`-*[
MU,(`2F%P86X@*,C5L;XI`,C5SL0@*$E33RTR,#(R+4I0*0#4\\[WM;H`U+RU
MJ0#&W]3"`,'YU,(`UL/6T`#7\]/2MM3&ZP"_O]?SMM3&ZP"_O]/2MM3&ZP"Y
M_LCXO\O+N<RY`+&CP?34K='Y(#\`O\_$X=''`$ME<F)E<F]S(,C/UJ2T[<[S
M+@##W-2_O:C!H@##W-2_S-C5]P##W-2_LZ2VR`##W-2_P.#0S0##W-2_T^^W
MJ`"UL<>PM<2YJ[^JP]S4O[?^SO'&]];0+-+1OJVTYM3:Q/JUQ,/<U+\N`+OY
MP.^PS<NYN;*ZS;GZ`+.OS\H`NJNY^@"ZJ\[$("A%54,M2U(I`+_&S?[,V`"\
MJK;[O*K+N<RY`-/OT=0`P,_.S@#/PK#KU,(`S\+/TM3"`,G/M,ZX_-#".@#)
MS]*[M,ZUQ\*\.B`E<P#)S]*[M,ZUQ\*\.B`E<R#7U"`E<P#)S]*[M,ZUQ\*\
M.B"UVM*[M,ZUQ\*\`,"MS='.K-''`+#FP^;%Y-;#`,#HL,W$VP#`L\OWS=``
MP/NQR,#OT<<`P/NQR-''`,'0UJ>VV,J_M<<`P:R]TP#!K+W3`,'0L_8@+2#3
MP[NGO\G2U+^TM;W5XKCVSL2\_KS0`,'0L_;+M</WL>K,X@#,UL+;T\.[I]?I
M+<[$O/ZY\0#,UL+;T\.[I]?I+<?SUOH`S-;"V]/#NZ?7Z2W*MK'PNL7"ZP#,
MUL+;T\.[I]?I+=.UT]#5WP#,UL+;T\.[I]?I+;S$O/[(RP#,UL+;T\.[I]?I
M+;:IU,0`S-;"V]/#NZ?7Z2W(H<_[MJG4Q`#!T+/VT\.[I[7$N:;$W+&[N=BQ
MU0#.Q-&G`,&BS-7-\`"UL;78RK&\Y#H@`+78Q_C3Z\JQO.0`M=C'^`"UQ\*\
M`->BS_H`M<?"O`"UQ\*\RJ>PW"P@Q^N\[++IQ/JUQ-/#NZ?#^[K-P]S"ZRP@
MR+NZ\];8RM0N`+7'PKS*I[#<+@#"K,FML:0`U,(`P[_(U=#%SZ(`35,M5$Y%
M1B"XO;S3SL2\_M;0P[O3T,K]OMTN`$U31P#6T+GZL,3#Q0#"[<;DMMFYLKK-
MN?H`PNVT[[S3R[F\T[6Z`-/*O/X`T\J\_KG<P.T`PNW`K<W^`,+MP+3.]]''
M`,+MMONT^K?R`,+MP/L`PNVV^LO[`,C]U,(`L>J\Q[/)(+^TN?TOSK2_M+G]
M`+'JO,>SR<;DR_RUQ,JVL?`@*,#]R.<N(-;8TJHOTM&[V+BT*0#"[<G<MOO(
MNK6Z`,+MS.'$X;_+M;H`U?W4VL:EQ>37UK;.`,.KP._+_L3AT<<`PZO`[\?S
MR[D`N+V\_LK]Q+_2T;.LL_:]T\K<R<_/WBX`U^Z]_"`R-"#0H<JQM<37[KC?
MSL*VR#H@`-?NO?P@-B#0H<JQM<37[KC?SL*VR#H@`+W3RMS7[K3SLZ2VR`#.
MY=3"`,+MU+S,V,BZM;H`L\G4L0#1H;6EQ*/*O3H`T\J\_@#3RKS^T>G6I-+1
MS>JSR2RUJ\K'T\.[I[7$QZG#^\BTSMZWJ,VHN?W1Z=:D+@#0Q<^BTM&Y_<;:
M+@#0Q<^BP.#0S0!-971A<B#'^+_ISMZWJ,JYT\,N`$UE=&%R(,?XO^G.WK>H
MRKG3PRX@S[B]VL?KLLZ_O,^US;.YW,#MM<?"O"X`M[VWJ`"YJ];&`,2KSO>X
MYP##W+_+PM[$X<[WT<?!JK#NN?H`36EM92#`X-#-`-?NO?P@,C0@T*'*L;7$
MU^ZUS<["ML@Z(`#7[KW\(#8@T*'*L;7$U^ZXW\["ML@Z(`#3L\GD`,7DUL/.
MQ+S^TL7*IRX@R.>Y^]*JRKG3P]7BN/;3IM/#L\S0\L3ZL=C0Z\_6U-J^S;+Z
MR?K+^RX`U=*RN[6]T,7/HK7$($E$+@#5TK*[M;V[X<;:M<0@240N`-#'QMK2
MNP#0T+:OT\J\_@"X_-#"R-7&V@#$H[_I`,2FMONVX,W?`,2FQ,FXYP##R;G%
M`-3"NLW$Z@##O]3"`,/)S-C(^\"MS-@`U,+!P=.OO_<`Q*;"Y;CG`,_"TL8`
MU_/2Q@#3TM+&`,G/TL8`S\+2Q@#)S]+&`,2JR:.QR+_+`+BTT:$`SM*UQ-7+
MNL4`SM*UQ,/%NZ<`SM*UQ,/%NZ?2L\/FQ>36PP##Y;7I`+*[+,[2LKO-K-+B
M`,/[L\8`Q,G#U['(T<<`Z*?"LP#$X;*TMOL`NLG`O`"ZR<KTL+*UV,'0R[D`
MN_G3VDYE='-C87!E(+7$S?C6MP!.971S8V%P92!34TP@M_[.\<;WP_NSQ@!.
M971S8V%P92#(S]:DM<3%^M>B`$YE='-C87!E(,C/UJ3`X-#-`,WXPN<`M-/.
MM`#0PK^FP.^VX,3AT<<`T,+4P@#0PM/#NZ?#^R`HM\>QV-*J*0#0PL[WP+P`
MT,*TL+_:("A?8FQA;FLI`-#"SL4`S\+2N[*]`,_"TKNX]M&AS^X`Q.&\T\"M
MN<\`Q.'(U;;[`,3AR-7`^]''`,WMR<\`Q::PH[6Z`,OYUKBVJ+7$SKO6P\G/
MP[O3T,?XO^FTYM3:`,.[T]#,X;FIR-7`^L/[L\;2U+FI($U#04P@T>G6I"X`
MP[O3T-:XMJBUQ"`E<R#%Y-;#T,7/HBX`P[O3T-:XMJBUQ"!&5%`@5D93(,7D
MUL/0Q<^B+@##N]/0UKBVJ+7$(%-13"!61E/%Y-;#T,7/HBX`P[O3T-:XMJBU
MQ"!344PM1FEL92!61E/%Y-;#T,7/HBX`SL2\_LZTR<^TJP#.N];#T,7/HLG0
MSK3%Y-;#`,.[T]#6N+:HP]S"Z]+4N:D@2%144"#1Z=:D+@##N]/0UKBVJ,/<
MPNO2U+FI($E-05`@T>G6I"X`P[O3T-:XMJC#W,+KTM2YJ2!+97)B97)O<R#1
MZ=:D+@##N]/0UKBVJ,/<PNO2U+FI($QO9VEN(-'IUJ0N`,.[T]#6N+:HP]S"
MZ]+4N:D@4$%34U=$(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4N:D@4TU"(-'IUJ0N
M`,.[T]"T_<GSM<37HK+AR>K'ZRX`SM[4W;3FQ+_"O+_)N:F_[,BA+@##N]/0
MNL^WJ+7$(%A-3"#*_;[=L;NTJ[O8`+_5L-?6M0#4K<J\Q>36P\[$O/[6T-72
MLKNUO;#FL;[0Q<^B+B#6V-#"LOK)^L7DUL/.Q+S^+@#4VL3ZM<3%Y-;#SL2\
M_M;0U=*RN[6]L.:QOM#%SZ(N(-;8T,*R^LGZQ>36P\[$O/XN`,[>`,C5MOK"
M_,[$("A)4T\M.#@U.2TQ,"D`Q;6XH[_+M;H`L;&PZ\?R`+&QPNW`[]''Q,G(
MNK6Z`,6RS?X`M\?6KKKS`+?'UJ['L`"RN\K'TKNX]L2_PKP`SK2QN]:GL]8`
ML;C-_,*\`,JNTKO4P@#*_=?6`-?6M_O*_0#7UK;.ROW$OP"QRLK]`$]+`+;4
MS_.]J,&BU=\`L,N]^,Z[`,JNU,(`L.RYJ\K2`+"BPOP`UKO3T"!)34%0(+?^
MSO'&]]:GL];.Q+S^O-"YLL_MN:;$W"X`UKN]T\K<TKNX]M/*O/ZUV-:W+@#6
MN]/0T[73T-7?T^O/M<VSN=S`[=2QO\G2U+'DN/RYLL_MR*C/W@#4VM#"M+"_
MVM;0M/*_J@#1H<_N`"5S(+7$T:'/[@#/[L2_L>"ZQ0#7Z=:O`-?IUJ^UI<Z[
M`-2MRKS3IM/#L\S0\L2CL.8`U-H@)7,Z(-;0M<34K<J\Q*.PYBX`QN3+_`#&
MY,O\T,7/H@#3M=/0U=_(J,_>`%!!32#1Z=:DSM[0IRX`4$=0(,K]U];'J</[
M`%!'4""\T\/<U\K!SP!01U`@N:N_JL/<U+\`4$=0(-+1QZG#^R_2T;S3P]P@
MU\K!SP!02%`@L\S0\K3ZPNL`4$A0(+W%L;X`L,V[^<NYS+D`Q<'`S0"PS<#5
MR[G,N;&[U;S![,?X`+#-Q,/"[0"PS;*\T<?0PKRXQ-K1QP"PS<"MN><`P]S"
MZP##N]/0UKBVJ,/<PNO2U+FI(%)!1$E54R#1Z=:D+@##W,+KR+?(SP##W,+K
M.@##W,+K.B``P]S"Z['8T.O.Q[K/+@#,^<G/`,SYR<\`PK>^M@"T_<GSM<?"
MO*.Z`-:TT-#.K+NDLMG7]P"UQ\*\NO/6M-#0SJR[I++9U_<_`,BHS]X`M.;(
MH=3BOMP`R*C/W@#(J,_>N=S`[0#.TK7$`,/8PK,`M\;"R;'V`+7GN[``U=7&
MK`#&I,S8O[6UN@#'Z\KDR.O2N[CVU,*WW;RPQ.JWW2X`Q^O*Y,CKTKNX]KK/
MMZBUQ,C5QMH[T:'4\;3+U,*WW;7$R-7&VBX`Q^O*Y,CKNL^WJ+7$RK&\Y"X`
MQ^O,X;FISLK,XK7$U:K2JBX`Q^O*Y,CKQ/JUQ-/#NZ?#^[RPP]S"ZP"RJ,"\
M`,VVQK$`QL_,T='``+7=R\W3RKS^M;W5XKCVSL2\_KS0("AN;W0@96YF;W)C
M960@8GD@24U!4"D`U^Z]_"`E<R#0H<JQM<2]M=/JP;\Z(`!0<F5F<U]L9&%P
M.B#5TK*[M;W+^=#HTJJUQ"!,1$%0(,"IU;G7Z;S^+@!0<F5F<U]S97-S:6]N
M.B#5TK*[M;W+^=#HTJJUQ"!S97-S:6]N(,"IU;G7Z;S^+@#&^-&Y`+JCQKW#
MYL;XT;DZ(`#&^-&Y.B``U*3`P`#)S]*[N/;1H<_N`,N]P]S#W-2_`,[*S.+#
MZ,KV`->HL+@`S.'*OL3:R-T`N:N_JL/<U+\`N:N_JL/<U+_1W<OC`+FKOZHO
MR[W#W,/<U+^VU+*BSK2QN[+ZR?HN`+*HMN#`Z+CW`+^HR_ZV^P!24T$@N:N_
MJL/<U+\@*"5D(,Z[*0"UI=&A`+'(PLH`ML'(H0"VP<BAT\J\_@#5YK7$TJK)
MOK/]("5S(,+P/R#5XL_NLMG7][VKSMZWJ+O6N+0N`,BAS_NXM-2M`,NBT,+#
MQ;NGRM/-O#H`N>;4\K'MM._*O0#&P,+;`-2VL\RW_L[QQO<`U+:SS,WXUK<@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@#)OK/]`,F^L_W'^+_I
M`,F^L_VVU`#7U+?^SO'&]]3=M.;$O\*\UM#)OK/]TM&QH[3FM<3%Y-;#L\S0
M\BX`R;ZS_=/#NZ<`R;ZS_=/#NZ<Z("5S`-#HQ_/.M+&[S^S3ICH@M.W.\[K%
MPNLZ`-;8R>@`O>&Y^P"WM;O8T:'/[@!2975N:6]N("C!],3AS?JUNBD`O<?)
MJP!2;VUA;FEA("C"WL+MQ.'1QRD`T/W7JB`Q.#`@ML@`S_+7\]#]UZH`S_+3
MTM#]UZH`UK30T`!2=7-S:6%N($9E9&5R871I;VX@*+;MPM[+N2D`4G=A;F1A
M("C"K+"RM.\I`%,O34E-12"\T\/<QZG#^P#3RKS^TM'*N=/#(%,O34E-12"\
MT\/<`%-!4TP@T>G6I,[>T*<N`-#%SZ(`ROV^W;_BO<6QO@"\T\/<UM6VR[OZ
M`+/)N:8`T,?&VL'Y`,JENM7`U<3#M;H`RJ6[^;7"NLW!T,ZLR[D`RJ7"K,[W
MT<>UN@#*I<:DL*.V^[K-PO._R\+7R+JUN@#*I<[$R:W,V+K-N/'!UL3)M.\`
MS:S2N[CVM+"_VB`H7W-E;&8I`,CXQ*;1QP#*I<+MP:;%M0#*I;;@P\"ZS<;5
MP=;.]['(`,[`T,?,X;FIU=\`R;/,V+"BP*VRK@"QH[3F`+&CM.8@)7,`L:.T
MYM&AS^X`O:NR^LGZM<3%Y-;#SL2\_M+4(%!(4"#3[]'4N/'*O;&CM.:UO<3Z
MM<2W_L[QQO?4W;3FQ+_"O-;0+@#%Y-;#("5S(-+1L:.TYBX`R]'1L`#1H=3Q
MTKNX]LC5QMH`T:'4\=*[N/;3P[NGU^G3P]+4T,+4]@#1H=3QTKO.N]#"M<33
MM=/0U=\`T:'4\=*[LK^W_L[QQO<`T:'4\=*[SKO3P[NGT\/2U-#"U/8`T:'4
M\<OYT]#(U<;:U^F\_BX`T]K2U,_"M<2TL+_:UM#1H<BAQ/K2JK7$U]:W^R[2
MU,KSL>JXM-;&R_G1H<[$U]8LR+NZ\\SYR<_.Q+S^L>"\K<?X+@#1H=3QR-7&
MVK?6N/0Z`-&AU/'(U<;:R-7&VKCQRKTZ`-&AU/'*L;SDM]:X]#H`T:'4\<C5
MQMK*L;SDN/'*O3H`T:'4\<_@NZ7&I<7DM<2V_KCVU]:VSBX`T:'4\<3ZM<31
MU<FKQ>36PP#1H=3QQJNZP]/OT=0Z`+2KR\W.RLSBM[33I@!396YE9V%L("C(
M^\3:O-.V^RD`M*NXT,;W.B``OL74P@!397)B:6$@86YD($UO;G1E;F5G<F\@
M*,C[MOO.K-''T^O#R<S8Q.&XY\+>*0#0\KK%`+OAQMH@240@TM&Y_<;:+@#%
MY-;#`,7DUL/4MK/,M_[.\<;WR<_*]-/:Q/JUQ+CVR,O5OLRH+@#%Y-;#Q/JU
MQ,:KNL/3[]'4+"#*L<?XTM2\L,C5QMJX\<J]+@#%Y-;#Q/JUQ,;TRKS3IM/#
ML\S0\BS1U<FKQ>36PRS2L\/FN/S0PL:UPLHLO+#&Y,O\S]3*OM&AS^XN`-/0
MNL.\N+CVM=BUX[K-U>*X]K+.ROW3T+G8.B``4V5Y8VAE;&QE<R`HR/O.]+;[
M*0"YNL[O`+SRMLS5JM*J`,K'M_'.JK3SLK^WW;7$P:R]T[:HTN6_[+W=N:;$
MW+S\/P#/U,J^`,._M,ZUQ\*\NO//U,J^R<_2N[3.M<2UQ\*\RK&\Y"`_`,_4
MRKZUX]&AQO<`T]K7\['?S]3*OB`E<R"RR[6E/P#*U<OU`%-I97)R82!,96]N
M92`HRJC7T\F]N?HI`->BLN$`QZG#^P#'J</[T=W+XP!3:6YG87!O<F4@*-#"
MO-/&PBD`M//0H0#"U+G]SJR[I`!3;&]V86MI82`HR[G"Y;>EO\LI`%-L;W9E
M;FEA("C+N<+EMZ7$X=''*0"[_=&IR>ZVR#H@`%-O;&]M;VX@27-L86YD<R`H
MR_?"WL/%R+JUNBD`4V]M86QI82`HR_?"[<#[T<<I`,7%P="WO<_RT:'4\0#`
MM-2TM=C6MP!3;W5T:"!!9G)I8V$@*,3/M\<I`,3/Q;<@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`,3/L.O'\@!3<&%I;B`HSO>PX-'`*0#`K+OXT\J\_@#,V,KBU]:W^\KDR.L`
M4W)I($QA;FMA("C+N<#OP+R_J"D`L>K7O`#&],J\Q.JWW0#*H0#7M,RL`+&C
MM.:X\<J]`+W6M<``R;ZS_<_?`-?6M_NTKL'0`-#'QMK,[`#6]]:\`,SAO;L`
MS\*QZ@"SR;FF`-+1L\FYIKBRN,<@)7,`4W5D86X@*,O5M:0I`-6JTJH`R-6S
M]@#(U<+D`,C5L_8`R-6S]B_(U<+D`,C5L_8Z(`#(U<+D`,C5PN0Z(`#)S['J
M`-:GL]8`4W5R:6YA;64@*,O5P/O$SRD`M,*ZQ0!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9"`HRK?-W[S#P+PI`%-W961E;B`HR/"UY"D`4W=I
M='IE<FQA;F0@*,CPRK\I`%-Y<FEA;B!!<F%B(%)E<'5B;&EC("C0\,#[T<<I
M`%1!0B"WUKCTN/'*O<[$O/X`S*C-Y0#,J,WE`%1A:FEK:7-T86X@*,O^O*K+
MN<RY*0!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F("C,N<G0Q.'1QRD`
MQ+^QZCH`M/VP[,K"S^X`M>>[L+K%PNL`U^Z]_-*[T*'*L;7$SL*VR#H@`,["
MML@`SL*VR#H@`,2CL.:YW,#M`,3:R-T`M+_.Q-?6`-#'QMK+Q`#,J<[$("A4
M25,M-C(P*0!4:&%I;&%N9"`HS*FY^BD`T+O0N\3ZRKG3P[&^S[7-LRX`1E10
M(-'3R>PH97AT96YS:6]N*<[>T*<N`$UA:6YT96YA;F-E(,#@L?"RHLZTL\FY
MIM38R.L`T:'/[K2PO]K2U+G8L=4NP.N_JM;0+@#1Z=:DT\J\_L>IP_O0Z-*J
MT]#2N[CVTM&]XK^JM<0@4$=0(,?XO^DN`-#HTJK2N[CVOJVY_;S3P]RUQ,WX
MPN?!K+W3+@#.Q+S^("5S(-.FN,.P_+JLTKNX]B`E<R#%Y-;#+@#.Q+S^("5S
M(-.FN,.P_+JLTKO0J2`E<R#%Y-;#+@"TR\[$O/[6T,.[T]#*_;[=+@#2U,_"
MRL<@<F9C.#(R(-/*O/ZUQ+'MS;<N`$=N=5!'(+;^U*K.Q+S^M<3"M[ZVL=C0
MZ[:HTN74VB!#<GEP=%]P9W`Z.B#`X+'PUM`N`$AO<F1E7T-R>7!T7W-M:6UE
M.CH@P."Q\"RQV-#HTJK3T"!O<&5N<W-L(,2CO^DN`+3+QJNZPR`B)7,B(,K]
MOMW2\LZJLZRY_=?NM/.]T\K<UK4LR_G2U,[>MZBQN[&CM.8`T\/2U+SLRM.T
MR\K]OMW`X-#-("@E<RD@M<2SS-#RLJ*RN[3FU-K3VL^US;/)SRX`M,NW_L[Q
MQO<@(B5S(B#2T;&[R;ZS_2X`M,NW_L[QQO<@(B5S(B#2T;&[L:.TYBX`)7,@
MM<37HK+AT.C'\]+1L;O)OK/]+@#6N+:HM<2\Q\*\LJ*RN[3FU-HN`+33R<_2
MN[CVLKW6Z-:NNO/)S[2KM<3*_;[=TL7*IRX`R<^TJ\[$O/ZRHLZTL;NQH[3F
M+@!W96%T:&5R+F-O;2#'^+_ISMZWJ,JYT\,N`,[>N+V\_K_)UK&]T[3ROZHN
M`+3+U]:VSM;0L/RZK,RKMN"UQ-?6ROTNQ/K2T<KDR.L@)7,@N/;7ULK].\3Z
MRN3(Z[7$U];*_;'8T.O0H=/:("5S+@#)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB
M.B`E<R#.M+&[R<^TJRX`R<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@)7,@M//0
MH;.LN?V]T\K<U^ZT\]:U("@E9"!B>71E<RDN`,G/M*O.Q+S^RK&WHLGZTKNX
M]L[*S.(Z(+WVLK^WUK7$("5S(,[$O/ZQN\G/M*LN`+SLRM/3RKS^RK&WHLGZ
MTKNX]K3MSO,N`+OCR.NTR\VHT;:ROLK]OMW*L;>BR?JT[<[S+@#4VL7DUL.T
ML,SEUM"WHLGZP<O2N[CVM.W.\R[3T+_)Q-S$^M+%PJG!R['8T.O,[M"TM<37
MUK;.+@"TRR!)34%0(+?^SO'&][*BSK36I[/6SL2\_KS0M];/[;FFQ-PN`-7B
MR\:Z];*[RL?5_<BWM<0@<F%R(-&YR_7.Q+S^+@#5XLO&NO6RN\K'U?W(M[7$
M('II<"#1N<OUSL2\_BX`U>++QKKULKO*Q]7]R+>UQ-#%T\._J+K%PNLN`+3+
MU]:VSLK'L=C0Z-*JM<0N`+3+U]:VSL3:R-W6N[W3RMS5^\K]ROW7UBX`M,O7
MUK;.Q-K(W=:[O=/*W,K]U]:\L,.PNL4N`+3+U]:VSL3:R-W6N[W3RMRPR[WX
MUL;*_=:U+@"TR]?6ML[$VLC=L=C0Z\ZJMKJZQ;ORO]6PU[?6N/2UQ,K]U]8`
ML=C0Z\K'TKNX]LK]U]8N`+3+U]:VSL3:R-VQV-#KL/RZK-*[U^G*KL'YO?C6
MQK7$(%)'0B#1U<FKM/K"ZRS`_<CG("<C,3(S-&%F)RX`U>*X]K2PS.72T;&[
MM*;`[;G]+@#5XLK'("5S+@"TR\K]UK77[LG9L=C0Z\K'(#$N`+3+M_[.\<;W
MSMZWJ+;4('II<""\L"!G>FEP(+CQRKW.Q+S^O?C0T+WBT;G+]0"TR\^US;.U
ML<>PRL?-H]/#M<37M,RL+@"QV-#KRL?2N[CVROW7UBX`M,NTL+_:L=C0Z]*J
MT\G1H<_NM+"_VBA/<'1I;VXIR_FZ]+W0`,JQO.0`RK&\Y->WU]D`RK&\Y+CQ
MRKT`RK''^-&AU/$`5&EM;W(M3&5S=&4`L>K,X@#*U;S^R,L`R.>Y^]*JN+31
MH2S'Z]3:M>/1H<KSL>JUQ,VLRK&PM"!#;VYT<F]LO/PHN/;(R[S&R^.[^BD@
MN_(@0V]M;6%N9+S\*,:[N?N\QLOCN_HI+@"]\<SL`$A434P@U*W*O,[$O/X`
MMN"XYP#-T+_+P,W(NK6Z`,/WS.P`S,"\TP#,V,&BQ.&T[[K-MN"PS;CG`-7F
MN_*\V0#0Q\;:MOX`S;O$X<NY`,W!MOK&Y`#-P;;ZQN3.Q"`H25-/+3@X-3DM
M.2D`S<&_XL+\R[G,N0#,V+_+R[FZS;^MO\;+N<BZM;H`S;S-W\*L`,KDR.O$
M^K7$T:'4\3H@`-?/S>+/W]:XROTZ(`#-^-:W`,WXUK<Z`,[:N,FT[P#.VK_+
MP+P`SMZWJ+3FR*$@5D93(,2_PKPN`->BLN'*L<[>MZC4]KS3MN[-XK7$T\.[
MI]#%SZ(N`,[>MZBXQ+'D(%9&4R#.Q+S^("(E<R(@M<3(J,_>+@#.WK>HL>2X
M_"!61E,@SL2\_B`E<R\E<R"UQ,BHS]XN`,[>MZBQY+C\SJH@)7,N`,[>MZC!
MK+W3UL$@4U%,(+?^SO'&]RX`SMZWJ,JYT\,@4U-,(,&LO=,N`,[>MZBXM-;&
M(%9&4R#.Q+S^+@#.WK>HO:C!HB!61E,@Q+_"O"`B)7,B+@#.WK>HO:C!HB!6
M1E,@Q+_"O"X`SMZWJ+VHP:(@5D93(,[$O/XN`,[>MZB]J\K]OMV]XM&YR_4N
M`,[>MZC)OK/]("5S++3+Q+_"O+*BM\>_U;#7`,[>MZBUW;GIR;ZS_<2_PKPN
M`,[>MZC)OK/](%9&4R#$O\*\+@#.WK>HR;ZS_2!61E,@Q+_"O#H@)7,N`,[>
MMZC)OK/](%9&4R#.Q+S^("(E<R(N`,[>MZC)OK/](%9&4R#.Q+S^+@#.WK>H
MM=VYZ<F^L_T@5D93.B`E<RX`SMZWJ,70ML^UL<>PM<3$O\*\+@#.WK>HO>*_
MJL:^UJ3/N+W:`,[>MZB\T]38("5S(+7$MJC2Y<K]OMTN`,[>MZC2QK:O(%9&
M4R#.Q+S^+@#.WK>HM/*_JB!61E,@SL2\_B`B)7,B+@#.WK>HT+3(ZR!61E,@
MSL2\_BX`SMZWJ+3ROZH@5D93(,[$O/XN`,[>MZBT\K^JT;G+]<[$O/XN`,[>
MMZBVP<BA('9F<W)O;W0@Q+_"O"X`SMZWJ+'DN/P@5D93(,2_PKRUQ,/[L\8N
M`,[>MZC)OK/](%9&4R#$O\*\.B`E<RX`SMZWJ+'DN/P@5D93(,[$O/X@(B5S
M(B"UQ,/[L\8N`,[>MZBQY+C\(%9&4R#.Q+S^("5S+R5S(+7$P_NSQBX`SMZW
MJ+'DN/P@5D93(,[$O/ZUQ,/[L\8N`,[>MZC7JKN[(%=O<F0@SL2\_@#.WK>H
MT+3(ZR!61E,@(B5S(B#.Q+S^+@#.WK>HT+3(ZR!61E,@SL2\_LK]OMTN`,_"
MNZ[/WP#(H<_[N/RXQ`"XM-2M`+?^SO'&]\&LO=/*L;>BR?K.M-2DQMJUQ+O8
MTZ8Z(`"WHLGZSK34I,;:M<2[V-.F+-/)M_[.\<;W.B``S?+3P\+K("A55$8M
M."D`L*+`K;*NP:JZS\?ULZ2Y^@#3HKGZ`,/`N?H`56YI=&5D(%-T871E<R!-
M:6YO<B!/=71L>6EN9R!)<VQA;F1S`+6EU*H`SK36JK7$`,ZTUJJUQ-/#NZ?#
M^[ORP]S"ZRX`SK36I[/6M<3`J=6YP_L`L>2X_`"X_-#"("5S`+C\T,+3P[NG
M`+C\T,*SS-#RTM')OK/]+@#)S[2K`-+1R<^TJ\OYT]#3IM/#L\S0\K7$Q>36
MP\[$O/ZUO;?^SO'&]RX`SMK`K;GG`-/#NZ<@)7,@SK3-J+G]("5S(+7$RMK(
MJ-'IUJ0N`-/#NZ>YW,#M`-/#NZ?1H<_N`-/#NZ?7HK+A`+3+U;[,J+7$T\.[
MI]>BLN'/M<VSTM'-H]/#+@#3P[NGP_L`T\.[I\/[.@#3P[NG.B``S[7-L];0
MM<33P[NG.@#.VM?(L?"_R\NYS+D`5D93(,2_PKRRHK*[M.;4VBX`O-G&V@#2
MT=72M;W3T-"GM<2UV+7C.B``T]#0I]#4`-+4M];6T\ZJM:7.NRBTT\_6U-K&
M\,OC*0#6M0#-W\*SL*+-O`"QY+NO`,ZOQ-K(\,"M`-'IUJ3*I[#<("T@M,O3
MRKS^O\G$W-+1U.+(R\G#U]2TV[C$+@"PYK&^`+#FL;Z_V-;&`-2]Q,\`U+W$
MS\[$("A625-#24DI`+SLRM,@)7,`U-K0PK2PO]JT\K^J`-+4("5S(++IO[0`
MTZ+*],ZLMON^J<BZM;H`P\#*],ZLOJG(NK6Z`,3<O/NVR`#$W+S[ML@Z(`#2
MXK3SP/NW_+7"M^>UY]#%N:O+OLVXN?T@4TU44`"^K[CF`+ZON.8A(2$@M-,@
M)7,@RM:VK\F^L_VSS-#R+@#-W\#[R[FZS;B[S;S(NK6Z`+ZON.8`T,?&VLC]
M`,SLQOC4I++B`,WXU;X`S?C5O@##O];<`+NVTZT`N[;3K;6]("5S`+NVTZTL
M("5S`,[WQ;<@*$E33RTX.#4Y+3$I`,[WQ;<@*$E33RTX.#4Y+3$U*0#.]\CV
MN?[`K0"UQ\*\NO/3IKC#S\C/U,J^("5S(,3$TKNX]M.FT\.SS-#R/P#7UK;.
MM<2WUKCTU]:W^S\`TOW*]K7$Q["UO+?[/P"WY\O9*+W:*0"WY\O9.@"WY\O9
M.B``L.RYJ\K2M=C6MP"P[+FKRM*UY[NP`%@U,#EV,R#`J=6YP_L`Q.H`Q.H`
M66%H;V\@(2"UV,V\`,._Q.H`TK+#Q0#*Q[7$+,[2S:S2X@#$^K6QQ[#*N=/#
MM+_.Q-?6L>#0M,2CRKTN(,JYT\,@6SP^72"PM,6EO\G'T+N[SJK-^-*SL>#0
MM,2CRKTN`,3ZLJ+.M,KDR.O2N[CVNL^WJ+7$M>?7T]/*O/ZUV-:W+@#$^K*B
MSK33R;6\R.NUQ,[$O/[6T+;4T[/(SKK.U]:VSK6]("5S`,3ZTM&^K=>BS_HN
M`,3ZL=C0Z\KDR.O2N[CVNL^WJ+7$UK4N`,3ZL=C0Z\_(N>:[KKK#ROV^W<KW
M*$1A=&%4<F5E*;?^SO&VR[+%Q-R\S-#XRKG3P]#"T\.[I]>BLN&W_L[Q+@#'
MZ\/HRO;.RLSBHZS4VL3ZM*O+S<[*S.*QJ+CFUJ['L"X`Q/JQV-#KRN3(Z[3+
MP:R]T\OYUKC/\K7$S?C6MP#'Z]:XMJC2JLF^L_VUQ+?^SO'&]RX`Q^O6N+:H
MTJK)OK/]M<33P[NG+@#'Z]:XMJC2JM#"U/:UQ-/#NZ<N`,?KUKBVJ-*JN/S0
MPK7$T\.[IRX`Q^O6N+:HTJK6M-#0M<37]]/#+@#$^K7$("5S(+OAQMK2T;G]
MRK$NQ^O6V-#"M<?"O"X`Q/JUQ+7GU]/3RKS^M=C6MP#$^K7$T,7/H@#7U+33
MQ/JUQ"`E<R"[X<;:OZK*O-+4P+3$^K7$TO+,V,WXM=C6M]+1L>2X_"X@SJJQ
MH[NDQ/JUQ+"RR*O&\+S[HZS$^K'8T.O6V-#"M<?"O"X`Q/JUQ-#5P_L`Q/JU
MQ-'IUJ2VR[*BSK36I[/6P="S]M/#NZ>[\KC#N:;$W-+1L;NYV+'5+@#7U+33
MQ/JUQ"`E<R"[X<;:OZK*O-+4P+3$^K7$Y*_`P,;WR\:Z]=+1L>2X_"X@SJJQ
MH[NDQ/JUQ+"RR*O&\+S[HZS$^K'8T.O6V-#"M<?"O"X`Q/JUQ.2OP,#&][*B
MSK36I[/6U>*X]KFFQ-PN`,3ZM;''L,OYQ>36P[7$RK''^#H`Q/JUQ-&AS^[2
MT;C\T,(N`,3ZM<34MK/,M_[.\<;W.@#$S\NYP*VW\@#4^M+!MOL`U-ZQR-''
M`+WRL,VRO,ZD`%O.RLSBL:BXYET`6\Z[T]K0T"`E<R"YLB`E<R#0T%T`SL2\
M_@"TTR`E<R`H)7,I(-/:("5S("5S`,JQ.@#!HKRT`,/[L\8`R=#.M,JUS]8N
M`,G0SK3*M<_6+@#4V;3.RN3(Z\3ZM<3#W,+KTM3(M\C/SM[.\P#.M,/\P_L`
MT\.[I]&AU/$`=D-A<F0`T,?&VCH`=V5A=&AE<BYC;VT@S?C5O@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+WIH7T-.+VAE;'`N>&UL````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#0Q-S,V,C<W-P`P,C`S,S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O
M>FA?0TXO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,B!J86X@
M17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4]
M(FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^
M"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@
M;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M
M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G
M97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@
M;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L
M(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S
M;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN
M('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S
M"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N
M97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A
M<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U
M<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP
M;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@
M=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@
M=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N
M($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T
M(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N
M(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES
M(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*
M("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC
M92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A
M/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E
M;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B
M;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U
M=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]I=%])5"\`````````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#$V-S`Q`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VET7TE4+TQ#7TU%4U-!1T53+P``
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,C<W-P`P,C`T-C8`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:71?
M250O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,3`R-3,U`#$P-#$W,S8R-S<W`#`R,C$R-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25`````$8"```<````3!(`
M`!,#``!\)````````,@P```$````R3````P```#.,```"P```-LP```H````
MYS```!4````0,0``"P```"8Q```*````,C$```T````],0``#@```$LQ```/
M````6C$``!@```!J,0``#@```(,Q```.````DC$```@```"A,0``"@```*HQ
M```%````M3$```D```"[,0``"0```,4Q```0````SS$```H```#@,0```P``
M`.LQ```/````[S$```D```#_,0``#0````DR```/````%S(```\````G,@``
M"````#<R```(````0#(``!D```!),@``#````&,R```.````<#(```,```!_
M,@``!0```(,R```*````B3(``!<```"4,@``"@```*PR```/````MS(```X`
M``#',@``%P```-8R```7````[C(``!,````&,P``#P```!HS```&````*C,`
M``L````Q,P``%0```#TS```%````4S,``#L```!9,P``.0```)4S```G````
MSS,``"P```#W,P``*@```"0T```E````3S0```8```!U-```$0```'PT```*
M````CC0```@```"9-```#@```*(T```*````L30```0```"\-```"0```,$T
M```&````RS0```<```#2-```!@```-HT```#````X30``!,```#E-```"```
M`/DT```$`````C4```8````'-0``%0````XU```'````)#4``!4````L-0``
M#P```$(U```-````4C4```\```!@-0``#0```'`U```&````?C4```8```"%
M-0``5````(PU```$````X34```X```#F-0``'````/4U```2````$C8```H`
M```E-@``#P```#`V```1````0#8```P```!2-@``!@```%\V```&````9C8`
M`!$```!M-@``!0```'\V```,````A38```4```"2-@``!@```)@V```'````
MGS8```T```"G-@``"@```+4V```,````P#8``!````#--@``"````-XV```$
M````YS8```X```#L-@``'P```/LV```@````&S<``"4````\-P``!P```&(W
M```&````:C<```T```!Q-P``$````'\W```3````D#<```P```"D-P``#@``
M`+$W```/````P#<``!,```#0-P``#0```.0W```H````\C<```,````;.```
M#0```!\X```"````+3@``!`````P.```#0```$$X```#````3S@```X```!3
M.```"````&(X```/````:S@```T```![.```!@```(DX```,````D#@```L`
M``"=.```#0```*DX```B````MS@```H```#:.```&````.4X```9````_C@`
M`!8````8.0``%````"\Y```+````1#D```L```!0.0``"0```%PY```)````
M9CD``!8```!P.0``#P```(<Y```-````ESD``"8```"E.0``0P```,PY```O
M````$#H```0```!`.@``"@```$4Z```*````4#H``!````!;.@``%P```&PZ
M```1````A#H``!<```"6.@``#0```*XZ```%````O#H``!````#".@``#P``
M`-,Z```0````XSH```\```#T.@``#P````0[```,````%#L```\````A.P``
M!P```#$[```(````.3L``!,```!".P``!````%8[```(````6SL```H```!D
M.P``#````&\[```+````?#L```P```"(.P``!P```)4[```*````G3L```T`
M``"H.P``!0```+8[```*````O#L``"8```#'.P``%0```.X[```%````!#P`
M``<````*/```#````!(\```(````'SP```8````H/```"````"\\```"````
M.#P```8````[/```"0```$(\```0````3#P```D```!=/```"0```&<\```9
M````<3P```X```"+/````@```)H\```-````G3P``!0```"K/```!@```,`\
M```1````QSP```8```#9/```!````.`\```*````Y3P```0```#P/```!0``
M`/4\```%````^SP``!(````!/0``"P```!0]```I````(#T``"0```!*/0``
M)@```&\]```(````ECT``!(```"?/0``"@```+(]```/````O3T``!````#-
M/0``#@```-X]```)````[3T```H```#W/0``!@````(^```/````"3X``!(`
M```9/@``$````"P^```1````/3X``!````!//@``"P```&`^```4````;#X`
M``P```"!/@``#````(X^```/````FSX``!4```"K/@``*0```,$^```J````
MZSX``"8````6/P``)P```#T_```9````93\``!$```!_/P``$@```)$_```3
M````I#\``!0```"X/P``%@```,T_```7````Y#\``!````#\/P``$0````U`
M```3````'T```!0````S0```&@```$A````)````8T````8```!M0```!P``
M`'1````6````?$````0```"30```!````)A````'````G4````<```"E0```
M"````*U````,````MD````T```##0```#@```-%````6````X$```!$```#W
M0```!@````E!```$````$$$```H````500``$````"!!```:````,4$```H`
M``!,00``#````%=!```/````9$$```@```!T00``!@```'U!```'````A$$`
M``L```",00```P```)A!```3````G$$```(```"P00``!````+-!```*````
MN$$``&@```##00``!0```"Q"```&````,D(```\````Y0@```P```$E"```'
M````34(```L```!50@``#0```&%"```:````;T(``$H```"*0@``!@```-5"
M```&````W$(```(```#C0@``"P```.9"```(````\D(```H```#[0@``#```
M``9#```*````$T,```D````>0P``$````"A#```2````.4,```<```!,0P``
M!0```%1#```,````6D,``!<```!G0P``!````']#```*````A$,```0```"/
M0P``!0```)1#```L````FD,``!,```#'0P``"````-M#```(````Y$,``"L`
M``#M0P``10```!E$``!!````7T0```0```"A1```!P```*9$```%````KD0`
M``@```"T1```$0```+U$```.````ST0```(```#>1```#@```.%$```'````
M\$0```8```#X1```%````/]$```?````%$4```<````T10``#@```#Q%```*
M````2T4``!T```!610``!0```'1%```1````>D4``!$```",10``"````)Y%
M```-````IT4```@```"U10``"0```+Y%```*````R$4``!4```#310``!0``
M`.E%```$````[T4``!````#T10``!P````5&```>````#48``"@````L1@``
M"@```%5&```:````8$8``!0```![1@``!@```)!&```&````ET8``#0```">
M1@``-````--&```I````"$<``"D````R1P``!0```%Q'```9````8D<``!D`
M``!\1P``"````)9'```7````GT<```H```"W1P``!P```,)'```A````RD<`
M``X```#L1P``!P```/M'```3`````T@```@````72```!0```"!(```$````
M)D@```H````K2```"0```#9(```.````0$@```0```!/2```,@```%1(``!%
M````AT@``!0```#-2```!P```.)(```.````ZD@``"H```#Y2```!@```"1)
M```,````*TD``!$````X20``"P```$I)```*````5DD```L```!A20``#P``
M`&U)```%````?4D```X```"#20``$P```)))```'````IDD``!$```"N20``
M%````,!)```8````U4D```<```#N20``!0```/9)```2````_$D```X````/
M2@``#@```!Y*```%````+4H```4````S2@```P```#E*```-````/4H```(`
M``!+2@``!````$Y*```'````4TH```P```!;2@``4@```&A*```7````NTH`
M``8```#32@``#@```-I*```5````Z4H``!(```#_2@``#P```!)+```4````
M(DL``&D````W2P``&@```*%+```7````O$L``!H```#42P``%P```.]+```;
M````!TP``!D````C3```'P```#U,```3````74P```@```!Q3```"0```'I,
M```_````A$P``#<```#$3```5P```/Q,```?````5$T```@```!T30``#0``
M`'U-```M````BTT```0```"Y30``)0```+Y-```?````Y$T``!T````$3@``
M)0```").```@````2$X``"0```!I3@``!P```(Y.```-````EDX```P```"D
M3@``$````+%.```,````PDX```<```#/3@``!````-=.```7````W$X```H`
M``#T3@``#````/].```)````#$\```@````63P``!@```!]/```"````)D\`
M``D````I3P``!P```#-/```H````.T\``!4```!D3P``!P```'I/```(````
M@D\```<```"+3P``!P```)-/```.````FT\```D```"J3P``!@```+1/```(
M````NT\```L```#$3P``!P```-!/```'````V$\```@```#@3P``$````.E/
M```0````^D\```<````+4```!0```!-0```4````&5````L````N4```#0``
M`#I0```7````2%````D```!@4```"@```&I0```'````=5````(```!]4```
M'P```(!0```C````H%```"$```#$4```'P```.90```K````!E$``"<````R
M40``"P```%I1```'````9E$```<```!N40``#0```'91```+````A%$```4`
M``"040``!0```)91```(````G%$```,```"E40```@```*E1```#````K%$`
M``0```"P40``"0```+51```,````OU$```<```#,40``!0```-11```:````
MVE$```L```#U40``!@````%2```)````"%(```L````24@``%P```!Y2```&
M````-E(``!,````]4@``$P```%%2```1````95(``#(```!W4@``"````*I2
M```)````LU(```H```"]4@``%````,A2```(````W5(```@```#F4@``#P``
M`.]2```.````_U(``!`````.4P``"0```!]3```)````*5,``!D````S4P``
M"@```$U3```,````6%,```(```!E4P``$````&A3```#````>5,```<```!]
M4P``#0```(53```+````DU,``"\```"?4P``(````,]3```<````\%,```4`
M```-5```$@```!-4```*````)E0```8````Q5```!0```#A4```&````/E0`
M``(```!%5```#````$A4```9````550``"@```!O5```*0```)A4```F````
MPE0``"4```#I5```*`````]5```2````.%4``!,```!+50``$````%]5```)
M````<%4``',```!Z50``*P```.Y5```7````&E8``!8````R5@``#P```$E6
M```4````658``!````!N5@``$P```']6```/````DU8```D```"C5@``"P``
M`*U6```'````N58```4```#!5@``%````,=6```(````W%8```\```#E5@``
M"````/56```,````_E8```\````+5P``%````!M7```&````,%<```0````W
M5P``&0```#Q7```&````5E<```0```!=5P``!P```&)7```&````:E<```8`
M``!Q5P``!@```'A7```B````?U<```L```"B5P``:`$``*Y7```&````%UD`
M``H````>60``#P```"E9```H````.5D``!````!B60``"@```'-9```)````
M?ED```\```"(60``#0```)A9```)````IED``!8```"P60``#@```,=9```.
M````UED```8```#E60``"0```.Q9```%````]ED```4```#\60``!@````):
M```0````"5H```P````:6@``"````"=:```5````,%H```T```!&6@``%0``
M`%1:```9````:EH``!@```"$6@``#0```)U:```/````JUH``"P```"[6@``
M!P```.A:```/````\%H```H`````6P``#`````M;```-````&%L``!P````F
M6P``#@```$-;```0````4EL``!0```!C6P``%P```'A;```;````D%L``!<`
M``"L6P``$@```,1;```(````UUL```P```#@6P``%P```.U;```&````!5P`
M`$`````,7```/````$U<```T````BEP``#4```"_7```,````/5<```P````
M)ET```8```!770``$@```%Y=```&````<5T```@```!X70``$P```(%=```.
M````E5T```D```"D70``"0```*Y=```'````N%T```<```#`70``!0```,A=
M```#````SET``!D```#270``"@```.Q=```%````]UT```@```#]70``'```
M``9>```'````(UX``!4````K7@``%0```$%>```/````5UX``!4```!G7@``
M#0```'U>```&````BUX```@```"27@``=````)M>```$````$%\``!$````5
M7P``)````"=?```2````3%\```X```!?7P``(P```&Y?```5````DE\``!(`
M``"H7P``!@```+M?```&````PE\``!(```#)7P``!@```-Q?```0````XU\`
M``@```#T7P``"````/U?```'````!F```!`````.8```"@```!]@```,````
M*F```!$````W8```"````$E@```%````4F```!(```!88```*````&M@```I
M````E&```#P```"^8```!0```/M@```$`````6$``!0````&80``$````!MA
M```4````+&$```L```!!80``$````$UA```-````7F$``!0```!L80``#0``
M`(%A```U````CV$```8```#%80``$````,QA```"````W6$``!````#@80``
M#0```/%A```&````_V$``!`````&8@``"````!=B```/````(&(``!$````P
M8@``"````$)B```-````2V(```T```!98@``#P```&=B```7````=V(```L`
M``"/8@``'@```)MB```;````NF(``!@```#68@``%````.]B```+````!&,`
M``@````08P``$````!EC```(````*F,``!X````S8P``%P```%)C```-````
M:F,``"L```!X8P``3@```*1C```S````\V,```@````G9```#P```#!D```/
M````0&0``!$```!09```&````&)D```5````>V0``!@```"19```$@```*ID
M```&````O60```X```#$9```#0```--D```/````X60```T```#Q9```#0``
M`/]D```+````#64``!(````990``"@```"QE```)````-V4``"D```!!90``
M!@```&ME```(````<F4```T```![90``#P```(EE```0````F64```P```"J
M90``!@```+=E```+````OF4```\```#*90``!0```-IE```+````X&4``"H`
M``#L90``(````!=F```&````.&8```@````_9@``#````$AF```(````568`
M``4```!>9@``!P```&1F```#````;&8```8```!P9@``!````'=F```4````
M?&8```H```"19@``#0```)QF```9````JF8```\```#$9@``!0```-1F```.
M````VF8``!8```#I9@``!@````!G```/````!V<```<````79P``!0```!]G
M```(````)6<```0````N9P``!@```#-G```%````.F<``!<```!`9P``#```
M`%AG```:````96<``!\```"`9P``&````*!G```'````N6<``!@```#!9P``
M"@```-IG```/````Y6<``!,```#U9P``$@````EH```,````'&@```P````I
M:```"````#9H```1````/V@``!,```!1:```$````&5H```8````=F@``!(`
M``"/:```#````*)H```;````KV@``!4```#+:```$0```.%H```:````\V@`
M`!@````.:0``,````"=I```T````6&D``"T```"-:0``,0```+MI```A````
M[6D``!0````/:@``%0```"1J```5````.FH``!<```!0:@``&````&AJ```9
M````@6H``!,```";:@``%````*]J```;````Q&H``!8```#@:@``$````/=J
M```*````"&L```<````3:P``!P```!MK```8````(VL```8````\:P``!@``
M`$-K```,````2FL```@```!7:P``!@```&!K```-````9VL``!4```!U:P``
M$@```(MK```8````GFL``!,```"W:P``!P```,MK```(````TVL```\```#<
M:P``'0```.QK```J````"FP```H````U;```#````$!L```,````36P```4`
M``!:;```!0```&!L```$````9FP``!H```!K;```!0```(9L```7````C&P`
M``(```"D;```!0```*=L```8````K6P``%8```#&;```!0```!UM```'````
M(VT``!0````K;0``!@```$!M```&````1VT```P```!.;0``#0```%MM```6
M````:6T``"4```"`;0``!P```*9M```&````KFT```,```"U;0``"P```+EM
M```(````Q6T```P```#.;0``%0```-MM```+````\6T```L```#];0``%P``
M``EN```7````(6X```0````Y;@```P```#YN```/````0FX``!T```!2;@``
M!P```'!N```1````>&X```@```"*;@``!0```)-N```H````F6X``"````#"
M;@``#@```.-N```+````\FX``#8```#^;@``5````#5O``!.````BF\```<`
M``#9;P``#0```.%O```$````[V\```@```#T;P``$0```/UO```/````#W``
M``(````?<```#````")P```'````+W````<````W<```%@```#]P```J````
M5G````<```"!<```#@```(EP```)````F'```!0```"B<```!0```+=P```2
M````O7```!D```#0<```"@```.IP```2````]7````@````(<0``"0```!%Q
M```*````&W$``"$````F<0``!P```$AQ```(````4'$``!@```!9<0``"P``
M`')Q```D````?G$``"X```"C<0``"````-)Q```<````VW$``!8```#X<0``
M!`````]R```%````%'(``"<````:<@``(P```$)R```I````9G(``"X```"0
M<@``"````+]R```B````R'(``"````#K<@``"0````QS```>````%G,```L`
M```U<P``"0```$%S```I````2W,``!$```!U<P``"````(=S```8````D',`
M``@```"I<P``!P```+)S```'````NG,```X```#"<P``#0```-%S```/````
MWW,```4```#O<P``0P```/5S``!.````.70``"0```"(=```!````*UT```-
M````LG0``"H```#`=```!P```.MT```.````\W0``!4````"=0``#````!AU
M```*````)74```X````P=0``$@```#]U```'````4G4``!````!:=0``%P``
M`&MU```)````@W4``!,```"-=0``&0```*%U```8````NW4```<```#4=0``
M!@```-QU```8````XW4``!0```#\=0``%````!%V```&````)G8```8````M
M=@``!@```#1V```,````.W8```,```!(=@``!0```$QV```(````4G8```T`
M``!;=@``6@```&EV```=````Q'8```<```#B=@``$0```.IV```@````_'8`
M`!\````==P``$P```#UW```A````47<``',```!S=P``(@```.=W```?````
M"G@``",````J>```&P```$YX```C````:G@``!\```".>```(P```*YX```<
M````TG@```D```#O>```"0```/EX```_`````WD``"\```!#>0``7@```'-Y
M```M````TGD```@`````>@``#P````EZ```M````&7H```8```!'>@``(@``
M`$YZ```O````<7H``"$```"A>@``(0```,-Z```;````Y7H``"`````!>P``
M"@```")[```2````+7L``!````!`>P``$@```%%[```5````9'L```H```!Z
M>P``!````(5[```2````BGL```P```"=>P``#@```*I[```+````N7L```@`
M``#%>P``!0```,Y[```#````U'L```L```#8>P``"````.1[```:````[7L`
M`!<````(?```"0```"!\```$````*GP```@````O?```!````#A\```-````
M/7P```8```!+?```"````%)\```*````6WP```L```!F?```"````')\```*
M````>WP```H```"&?```$0```)%\```1````HWP```T```"U?```"````,-\
M```8````S'P```L```#E?```#0```/%\```8````_WP```H````8?0``$@``
M`"-]```-````-GT```,```!$?0``(````$A]```C````:7T``"(```"-?0``
M(````+!]```W````T7T``"@````)?@``#0```#)^```%````0'X```8```!&
M?@``$@```$U^```+````8'X```8```!L?@``!````'-^```&````>'X```0`
M``!_?@```P```(1^```#````B'X```0```",?@``"@```)%^```4````G'X`
M``H```"Q?@``!0```+Q^```9````PGX```X```#<?@``"````.M^```+````
M]'X```\`````?P``(@```!!_```(````,W\``!$````\?P``%@```$Y_```4
M````97\``#@```!Z?P``"P```+-_```,````OW\```P```#,?P``$P```-E_
M```'````[7\```D```#U?P``$@```/]_```,````$H```!4````?@```"@``
M`#6````*````0(```"$```!+@```"@```&V````,````>(````,```"%@```
M$````(F````#````FH````D```">@```#@```*B````-````MX```#````#%
M@```'@```/:````@````%8$```D````V@0``%@```$"!```/````5X$```H`
M``!G@0``!@```'*!```'````>8$```(```"!@0``$@```(2!```>````EX$`
M`"@```"V@0``*@```-^!```J````"H(``"L````U@@``*P```&&"```3````
MC8(``!,```"A@@``$P```+6"```+````R8(``(<```#5@@``*0```%V#```;
M````AX,``!,```"C@P``#````+>#```5````Q(,``"<```#:@P``%P````*$
M```0````&H0```D````KA```#0```#6$```'````0X0```8```!+A```&P``
M`%*$```.````;H0``!(```!]A```"````)"$```)````F80``!````"CA```
M&````+2$```'````S80```4```#5A```&````-N$```&````](0```0```#[
MA```"`````"%```&````"84```L````0A0``"````!R%```K````)84```L`
M``!1A0```0```.H!``````````````<```"7````-````+(!``#A````)`(`
M``4```!A`0``TP``````````````M````*8!```)`0```````"\```">`0``
M\0$``"8"```W`0``0P(``&D!``!,`0``IP$``.P`````````K0```-H!``!1
M````L0$``"X!```?`@```````$$"``#2`0````````````!N````F@```!$"
M``"<````/P```.8!``"0`0````````````!-`0``.````/<`````````W0``
M``````!(`0```````.`!```I`@``9`$`````````````M`$``"L!``!*````
MB``````````9````L@```.0!``"Q````"P(``-$````=`0``I0```"4```!V
M````I0$``$,!``#6`0``Y0```/X````Q`@``%0$``/@````B`@``+@```%L!
M``#B`0``/0$```````#J````,P```!`!``!S````3@`````````D````"0``
M`"@```"X`0``#P$``!8"```G`0```````-0!``"X````D0```,<!```R`@``
M``````````"$``````````````!(````(P```,X`````````I@```!L````\
M`0```````.T!``"8`0``>@$````````;`0```````'@!```9`0``J@$``!8!
M`````````````!@!```5`@``@````!P```!/````M@$``"`"```[````)@``
M`)P!```8`@``)@$``/,```#C````GP```)@``````````````*@!``".````
MO0````````!5`0`````````````!`@``)0$```4"``!^````BP```*P`````
M````\@$``'D!``#D````K0$``/$```#[```````````````3````6@$``'8!
M````````_0```(L!````````*0```"<````>`0``%P(``*X!````````(@``
M`($!``"C`0``90```'H````?````7`$``#0"`````````````(<```!X````
M10```'\`````````T````!(!``````````````(!``!W`0``9@````````#)
M````````````````````R0$``+,````,`0``T`$`````````````````````
M``"[````Z0$``*D````W````$@```(D`````````.@(```````#Y`0``#P``
M`!`"```_`0```````(D!```6``````````H```!8`0``6`````T!``"%`0``
M!P$``((!````````60```/\`````````=0```$(````A`````````"H````R
M````9@$``*0!```1`0``@0````````!$`0``VP$```L```#5````00$``!0`
M````````RP$```@!``"&`````````)(!````````4@```/,!````````EP$`
M`,$!``"W`0``=`$```````!Y````SP$```````"O`0``IP```%T!```#`@``
M`````#T`````````(0(``&\````L`0``.P$``%D!````````Q@$```````"3
M`0``M0```((````U`0``;`$````````3`@``V0$```````"2````I````"\!
M````````$````,P````&````]````````````````````%(!``#9````:`$`
M`!T```````````(``"`!````````B@$``````````````````%H`````````
M`````#@!``#G`0```````/@!````````T0$````````$`````P$`````````
M````M@```*\```#_`0```````(8!``#%````D````)0`````````5`$`````
M````````+0(``+````!'`0``-P(`````````````00```!0"````````=P``
M``X!```9`@``U@```'4!``!7`0``H`$```\"``````````````````#B````
M10(``!P!```7````>P```/<!`````````````.`````&`@```````!@````"
M````40$``.@!```*`0``SP`````````3`0``R````$L```#:````_0$``'T!
M````````&@```)T`````````.P(```````#5`0``$0``````````````JP$`
M```````*`@``[P```)4!``"L`0``G0$``&T```#U````FP$``"H"``!<````
M8@$```````!;`````````/D`````````>P$``#8"``#2````Q@```%T````P
M`0````````````#+````?````/H`````````'P$``+H!``#^`0``N0```","
M``!H````R@$````````5````)`$``*(```"Y`0``W@`````````;`@``?0``
M`,$```#T`0``U``````````Z````*`(```````!$````TP$``.<```!'````
M`````)H!```L````90$```````````````````````"\````/P(``#(!``!,
M````UP```+H```"*````+0```-@`````````,`````0!``#*````<```````
M``">````7P$``!T"``#V`0``$@(`````````````A`$```````".`0``*@$`
M`#4"`````````````#@"``#[`0``8@`````````\`@``*`$``%````!P`0``
MFP```````````````````(\```"6`````0$``*D!``#M````C`$``%,!````
M````0````#D```!``@```P```,0```"C````80```%`!``#O`0``MP```'X!
M``#U`0````````P"``#R````/@(``'\!```P`@``_`$``#8`````````````
M`*@```#Z`0``/@$```````!K````#````"L```!C`````````(,!``"B`0``
M`````.4!```E`@``S0```'(````(`@```````$`!``#L`0``2P$``(T!````
M````<0$``$(!`````````````&D```````````````````"]`0``<P$`````
M``#>`0``1@````````!4````:@$````````K`@``\`````X"``"A````H0$`
M`#T"````````WP```$0"````````8`$````````(````XP$``!X````"`@``
M%P$``.X`````````9P```#0!``#K`0```````,T!```Q`0``L`$```````#?
M`0``A0```&L!``#F````E@$``"``````````S@$```````!>````C`````T"
M````````0@(``&P``````0``:@```,(````:`@``GP$```````"/`0``'@(`
M`(,```#<`0``]@``````````````AP$``*X````L`@```````%<`````````
M(@$``.X!``"_`0``#@```$D!```U````!`(``+4!``"K`````````-T!``#8
M`0````````````!O`0``!P(``'P!``!G`0``9`````````!&`0``B`$`````
M``#;`````````.@````^````,P(``+X!``##````,0```+X`````````5@``
M`$X!````````=````)0!```)`@``+0$``+P!``"9````W````)D!````````
M5@$``$T`````````4P```+L!`````````````,````"5``````````L!````
M````(P$``#D!``#P`0``&@$``%\`````````0P```,P!````````,P$``$4!
M`````````````"D!````````8`````````#'````'`(``/P`````````DP``
M`&T!``"-`````````#P```#7`0``P`$```````"``0``#0```*H`````````
M``````8!``"1`0```````'(!```G`@``.@$````````N`@``+P(```````#(
M`0``<0```,,!``#I````8P$``$D```!N`0``Q0$``!0!````````P@$``.$!
M``!5````LP$``$H!```V`0``ZP````````!/`0``!0$````````Y`@``````
M`%X!```````````````````A`0```````$8"````````Q`$``*``````````
MOP`````@870@`"5D("5S(&%N9"`E<P`E<R`M($YO=&EC90`E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%1E<FUS(&]F($%G
M<F5E;65N=``E<R!A="`E<R`E<P`E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`
M)7,@=&\@)7,@;V8@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<P`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H
M;W5R<P!!32!3:&]W97)S`$%-+U!-`$%B<V)O='1O;0!!8G-M:61D;&4`06-C
M;W5N="!087-S=V]R9`!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``
M061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D(&$@;F5W('5S97(Z`$%D9"!N
M97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,@0F]O:P!!9&UI;FES=')A=&EO;@!!9',`06QI
M9VX`06QI9VYM96YT.@!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O
M=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;'1E<FYA=&4@
M24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA
M=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;G-W97(`07!P;&EC871I
M;VX`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<FEL`$%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`
M075G=7-T`$%V86EL86)L92!F:65L9',Z`$)A8VMG<F]U;F0`0F%S96QI;F4`
M0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;VMM87)K<P!";W)D
M97(`0F]R9&5R<P!";W1T;VT`0TU3`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L
M96YD87(`0V%L;0!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A<'1I
M;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4')O<&5R=&EE<P!#96QL
M('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;G1E
M<@!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.@!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U
M<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-L;W5D
M<P!#;&]U9'D`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L;W(@4&EC:V5R
M`$-O;',Z`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]N9&ET:6]N
M<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYT:6YU90!#;W!Y
M`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5R<V5S`$-R96%T90!#
M<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871O<B!097)M:7-S
M:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T
M:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI
M>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L
M96-T:6]N`$1$`$1A=&%4<F5E($)R;W=S97(`1&%T92!296-E:79E9`!$87D`
M1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E9F%U
M;'0@0V]L;W(`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@8V5L;`!$96QE
M=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`
M1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H
M92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=F5L;W!M96YT`$1E=R!0
M;VEN=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y
M($]P=&EO;G,`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$5D
M:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@)7,`16UA:6P@061D<F5S<P!%<G)O<@!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$9'($-O;&]R`$944"!U<&QO860@;V8@
M<V5T=7``1F%I<@!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&
M97<@4VAO=V5R<P!&:6QE($UA;F%G97(`1FEL=&5R<P!&:7)S="!(86QF`$9I
M<G-T(%%U87)T97(`1FQO870`1F]N="!#;VQO<@!&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)G;W0@>6]U<B!P87-S=V]R9#\`
M1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R=6US`$9O
M<G=A<F1S`$9R`$9R86UE<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`
M1V5N97)A=&5D($-O9&4`1V\`1V]O9VQE(%-E87)C:`!'<F]U<"!!9&UI;FES
M=')A=&EO;@!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`2&5I9VAT`$AE;'``
M2&5M:7-P:&5R90!(:6=H`$AO7VUE`$AO<F1E`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M
M:61I='D`25]N<V5R="!2;W<@0F5F;W)E`$EC;VYS($]N;'D`26-O;G,@=VET
M:"!T97AT`$ED96YT:71Y)W,@;F%M93H`26UA9V4@4')E=FEE=SH`26UA9V4@
M55),`$EM86=E(%523#H`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E
M<@!);F1I=FED=6%L(%5S97)S`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN
M($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,
M:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&-E
M;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T
M97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T('!A<F%G<F%P:"!A9G1E
M<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN
M<V5R="!R;W<@8F5F;W)E`$EN<V5R="]-;V1I9GD@26UA9V4`26YV86QI9"!A
M<'!L:6-A=&EO;BX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV96YT
M;W)Y`$ET86QI8P!*86YU87)Y`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2G5L
M>0!*=6YE`$IU<W1I9GD`3&%?>6]U=`!,86YG=6%G90!,87-T(%%U87)T97(`
M3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F
M<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA>6]U=`!,969T`$QI9VAT(%)A
M:6X`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!,:71E<F%T=7)E`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C
M871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]W`$QO=V5R(')O
M;6%N(&YU;6)E<G,`34T`36%I;`!-86EL($%D;6EN`$UA;F%G92!T:&4@;&ES
M="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L
M(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N
M`$UA<F-H`$UA<F=I;@!-871C:&EN9R!F:65L9',`36%Y`$UE;6)E<G,`365R
M9V4@8V5L;',`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971R:6,`36ED
M9&QE`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF>2!54DP`36]S=&QY
M($-L96%R`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`
M3D\L($D@1&\@3D]4($%G<F5E`$YE='=O<FL`3F5V97(`3F5W($-A=&5G;W)Y
M`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=W,`3F5W<V=R;W5P<P!.97AT
M`$YI9VAT`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`3F\@<VED97,`
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`
M3F]N90!.;W0@<V5T`$YO=&5S`$YO=F5M8F5R`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$]+`$]B:F5C="!#<F5A=&]R`$]C=&]B97(`3V9F
M:6-E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A;FEZ:6YG
M`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]T:&5R`$]T:&5R($EN
M9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!(4"!#;V1E`%!-($QI9VAT
M(%)A:6X`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!097)C
M96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`
M4&AO=&]S`%!I>&5L<P!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&]L;',`4&]S:71I;VYI;F<@;V8@
M=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!R97-S=7)E
M`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')I;G0@9&]C=6UE
M;G0`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%%U97)Y
M`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%N9&]M($9O<G1U;F4`4F5A
M9`!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!"
M;&]C:P!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@=&AE
M`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297-E=`!297-E="!087-S
M=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P
M=&EO;G,`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/
M<'1I;VYS`%)I9&1L97,`4FEG:'0`4F]?=R!0<F]P97)T:65S+BXN`%)O=R!0
M<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;@!335,@
M365S<V%G:6YG`%-A`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T(&$@9W)O
M=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`
M4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M
M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`
M4V5N9"!0<F]B;&5M(%)E<&]R=`!396YS;W(Z(`!397!T96UB97(`4V5T('5P
M(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@
M>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM
M97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L
M:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O
M=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2
M;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H
M;W=E<G,@3&%T90!3:VEP($UA:6YT96YA;F-E`%-N;W<@9&5P=&@Z(`!3<&%C
M:6YG`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3
M<&QI="!C;VQU;6X`4W!L:70@<F]W`%-T86YD87)D`%-T871U<P!3=0!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VXN`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6UM87)Y`%-U;B!2
M:7-E`%-U;B!3970`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``
M4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`5"U3=&]R;0!4
M+5-T;W)M<P!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%R
M9V5T.@!487-K<P!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!4
M96UP97)A='5R93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0@3VYL
M>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA;FL@>6]U(&9O<B!U<VEN9R!T
M:&4@<WES=&5M+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D
M+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E
M<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(&AA<R!B965N(')E;6]V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+@!4:&ES(&ES("5S+@!4:'5N9&5R`%1I8VME=',`
M5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:71L90!4;V1A>0!4;VUO<G)O
M=P!4;W``5'4`55),`%523#H`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F9I
M;&5D`%5N:71S`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N<V5T(&-O
M;&]R`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!G<F%D92!S8W)I
M<'0@9&5L971E9"X`57!L;V%D`%5P<&5R(')O;6%N(&YU;6)E<G,`57-E<B!!
M9&UI;FES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R;F%M
M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!6
M86-A=&EO;@!687)I86)L90!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI
M9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I97<@
M86X@97AT97)N86P@=V5B('!A9V4`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``
M5V4`5V5A=&AE<B!&;W)E8V%S=`!796(`5V5L8V]M90!796QC;VUE('1O("5S
M`%=E;&-O;64L("5S`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VED=&@`5VED=&@@
M;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I;F0Z`%=I;F0Z(`!9
M60!997,L($D@06=R964`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@3F%M90!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!R96UO
M=&4@<V5R=F5R<SH`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X
M="`M`%]!9&UI;FES=')A=&EO;@!?1&%T851R964`7T1E;&5T92!2;W<`7T=R
M;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&]U=`!?36]D
M:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN
M:RXN+@!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`8V%L;0!F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S`&QI;F5S70!N86UE`'!E<F-E;G0`<&EX96QS
M`')I<VEN9P!S=&5A9'D`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N
M9FER;0!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N
M,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`U+3`R+3(S(#$P.C$S*S`Q,#`*3&%S="U4
M<F%N<VQA=&]R.B!-87)C;R!0:7)O=F%N;R`\;6%R8V\N<&ER;W9A;F]`=6YI
M8F]C8V]N:2YI=#X*3&%N9W5A9V4M5&5A;3H@271A;&EA;B`\9&5V0&QI<W1S
M+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=`H`(&%L;&4@`"5D("5S(&4@)7,`)7,@+2!!='1E
M;GII;VYE`"5S($]P97)A>FEO;FD@9&D@36%N=71E;GII;VYE("T@0V]N9F5R
M;6$`)7,@5&5R;6EN:2!D)U5S;P`E<R!A("5S("5S`"5S(&UI;G5T:0`E<R!N
M;VX@=')O=F%T;RX`)7,@82`E<R!D:2`E<P`L(&$@)7,@)7,`+"!V87)I86)I
M;&4@9&$@)7,@82`E<P!&;W)M871O(#$R(&]R90!&;W)M871O(#(T(&]R90`R
M-"!O<F4`36]S=')A($%-`$%-+U!-`%9A:2!A`%)E9V]L90!!8V-O=6YT(%!A
M<W-W;W)D`$-O;G1A8FEL:71A)P!!9V=I=6YG:0!!9V=I=6YG:2!3;W1T;R!'
M<G5P<&\`06=G:75N9VD@<75I.@!!9V=I=6YG:2!.=6]V;R!5=&5N=&4`06=G
M:75N9VD@=6X@;G5O=F\@=71E;G1E.@!!9V=I=6YG:2!U;B!N=6]V;R!M96UB
M<F\`06=G:75N9VD@<&%I;P!!9V=I=6YG:2!U=&5N=&4`3&$@9G5N>FEO;F4@
M9&D@86=G:75N=&$@=71E;G1I(&YO;B#H(&%T=&EV82X`4G5B<FEC80!!;6UI
M;FES=')A>FEO;F4`4'5B8FQI8VETX`!!;&QI;F5A;65N=&\`06QL:6YE86UE
M;G1O.@!4=71T:2!G;&D@571E;G1I($%U=&5N=&EC871I`%1U='1I(&D@1W)U
M<'!I`%1U='1I(&D@4&5R;65S<VD`5'5T=&D@:2!Q=6%T=')O(&QA=&D`571E
M;GIA($E-4U`@86QT97)N871I=F$`26YD:7)I>GIO(&5M86EL(&%L=&5R;F%T
M:79O`$%V=FES82!S=2!A9V=I;W)N86UE;G1I`%1E<W1O(&%L=&5R;F%T:79O
M.@!2:7-P;W-T80!!<'!L:6-A>FEO;F4`07!P;&EC87II;VYE(&4G('!R;VYT
M82X`07!R:6QE`%-E:2!S:6-U<F\@9&D@=F]L97(@96QI;6EN87)E(&QA(')I
M8VAI97-T82!D:2!I<V-R:7II;VYE('!E<B`E<S\`0VAI961I(&-O;F9E<FUA
M('!R:6UA(&1I(&5S96=U:7)E(&]P97)A>FEO;FD@9&D@;6%N=71E;GII;VYE
M`%1E;G1A=&EV;R!D:2!C86YC96QL87II;VYE(&1I('5N(&=R=7!P;R!I;F5S
M:7-T96YT92X`5&5N=&%T:79O(&1I(&5L:6UI;F%Z:6]N92!D:2!U;B!P97)M
M97-S;R!I;F5S:7-T96YT92X`5&5N=&%T:79O(&1I(&UO9&EF:6-A(&1I('5N
M('!E<FUE<W-O(&EN97-I<W1E;G1E`%1E;G1A=&EV;R!D:2!M;V1I9FEC82!D
M:2!U;B!P97)M97-S;R!I;F5S:7-T96YT90!!9V]S=&\`0V%M<&D@9&ES<&]N
M:6)I;&DZ`%-F;VYD;P!"87-E;&EN90!);7!O<W1A>FEO;FD@0FQO8V-O`%1I
M<&\@9&D@0FQO8V-O`$=R87-S971T;P!0<F5F97)I=&D`36%R9VEN90!-87)G
M:6YI`$)A<W-O`$--4P!0<F]P<FEE=.`@9&5L;&4@0U]E;&QE+BXN`$-A;&5N
M9&%R:6\`0V%L;6\`0V%N8V5L;&$`16QI;6EN82!287!P;W)T;R!D:2!0<F]B
M;&5M80!/<'II;VYI`$-A=&5G;W)I92!E($5T:6-H971T90!0<F]P<FEE=.`@
M9&5L;&4@8V5L;&4`4W!E<W-O<F4@8V5L;&4Z`%!R;W!R:65TX"!D96QL92!C
M96QL90!3<&%Z:6\@8V5L;&4Z`$-E;G1R80!-;V1I9FEC80!-;V1I9FEC82!N
M;VUE+"!I;F1I<FEZ>F\@92!F:7)M82!C:&4@=F5R<F%N;F\@=FES=6%L:7IZ
M871I(&1A;&QE('!E<G-O;F4@8VAE(&QE9V=O;F\@92!R:7-P;VYD;VYO(&%I
M="!T=6]I(&UE<W-A9V=I+@!#:6%D`%9E<FEF:5]C82!,:6YK+BXN`%-E;&5Z
M:6]N82!C;VUE('9I<W5A;&EZ>F%R92!L92!D871E.@!%;&EM:6YA('5T96YT
M93H@)7,`16QI;6EN82!U=&5N=&4`16QI;6EN82!L92!I;F9O<FUA>FEO;FD@
M9&5L;"=U=&5N=&4`0VQI8V-A('!E<B!#;VYT:6YU87)E`$-H:75D:2!L82!&
M:6YE<W1R80!.=79O;&4`3G5V;VQE`$UA<F=I;FD@8V]L;&%S<V%T:0!#;VQO
M<F4`4V5L97II;VYA($-O;&]R90!#;VQO;FYE.@!6:6=N971T90!#;VUA;F1O
M`%-H96QL(&1I($-O;6%N9&D`0V]N9&EZ:6]N:0!#;VYF:6=U<F$@)7,`0V]N
M9F5R;6$@4&%S<W=O<F0`0V]N=&EN=6$`0V]P:6$`4V5L97II;VYE(&QA(&-O
M<&EA`$EM<&]S<VEB:6QE(&EN=F5R=&ER92!L82!C;VYF:6=U<F%Z:6]N92X`
M26UP;W-S:6)I;&4@<V%L=F%R92!L82!C;VYF:6=U<F%Z:6]N92`E<RX`26UP
M;W-S:6)I;&4@<V%L=F%R92!U;F$@8V]P:6$@9&D@<V-O<G1A(&1E;&QA(&-O
M;F9I9W5R87II;VYE`$-O<G-I`$-R96$`0W)E82!U;B!C;VQL96=A;65N=&\`
M0W)E86YE('5N;R!N=6]V;P!097)M97-S:2!D:2!#<F5A=&]R90!/<F$@871T
M=6%L90!,82!54DP@871T=6%L92#H`$UE=&5O($%T='5A;&4`0V]N9&EZ:6]N
M:2!A='1U86QI.B``4W1I;&4@871T=6%L90!);7!O<W1A(&QE(&]P97)A>FEO
M;FD@9&$@97-E9W5I<F4@<75A;F1O(&5N=')I(&EN("5S+@!486=L:6$`4V5L
M97II;VYE(%1A9VQI80!'1P!"<F]W<V5R($1A=&%4<F5E`$1A=&$@4FEC979U
M=&\`1VEO<FYO`$5?;&EM:6YA($-O;&]N;F$`1&EC96UB<F4`3G5M97)O(&1E
M8VEM86QE`$-O;&]R92!D:2!$969A=6QT`$-A;F-E;&QA`$5L;6EN82!'<G5P
M<&\`16QI;6EN82!C96QL80!%;&EM:6YA(&-O;&]N;F$`079V:7-A('-U(&%G
M9VEO<FYA;65N=&D`16QM:6YA(')I9V$`16QI;6EN82!L)VED96YT:73@('-E
M;&5Z:6]N871A`$5L:6UI;F$@;&$@8V]L;VYN82!C;W)R96YT90!%;&EM:6YA
M(&QA(')I9V$@8V]R<F5N=&4`1&5S8W)I=FD@:6P@4')O8FQE;6$`1&5S8W)I
M>FEO;F4`4W9I;'5P<&\`4'5N=&\@9&D@4G5G:6%D80!#87)T96QL80!6:7-U
M86QI>GIA(&YE;"!F;W)M871O(#(T(&]R93\`3W!Z:6]N:2!6:7-U86QI>GIA
M>FEO;F4`3F]N(&5L:6UI;F%R90!.;VX@86-C961E<F4@9&ER971T86UE;G1E
M(&$@;6%I;G1E;F%N8V4N<&AP`$QA('!R:6UA(')I9V$@8V]N=&EE;F4@;&4@
M971I8VAE='1E(&1I(&-A;7!O/R!-87)C82!S92!S:2P@;&%S8VEA('9U;W1A
M('-E(&YO.@!38V%R:6-A(&QA(&-O;F9I9W5R87II;VYE(&=E;F5R871A(&-O
M;64@<V-R:7!T(%!(4"X`36]D:69I8V$`36]D:69I8V$@0FQO8V-O`$UO9&EF
M:6-A($=R=7!P;P!-;V1I9FEC82!097)M97-S:0!-;V1I9FEC82!P97)M97-S
M:2!P97(@)7,`36]D:69I8V$@;W!Z:6]N:2!P97(Z`$UO9&EF:6-A('!E<FUE
M<W-I('!E<B`E<P!);F1I<FEZ>F\@9&D@4&]S=&$`17)R;W)E`$]G;FD@,34@
M;6EN=71I`$]G;FD@,B!M:6YU=&D`3V=N:2`S,"!S96-O;F1I`$]G;FD@-2!M
M:6YU=&D`3V=N:2!-97IZ)V]R80!/9VYI(&UI;G5T;P!686QO<FD@9&D@97-E
M;7!I;SH`17-E8W5Z:6]N90!#;VQO<F4@1D<`57!L;V%D("A#87)I8V%M96YT
M;RD@9FEL92!N;VX@<W5P<&]R=&%T;RX`1VEU<W1O`$9E8F)R86EO`%-I('-E
M;G1E(&-O;64`4VD@<V5N=&4@8V]M93H@`%!O8VAI($%C<75A>GIO;FD`1FEL
M92!-86YA9V5R`$9I;'1R:0!0<FEM82!-971A)P!0<FEM;R!4<FEM97-T<F4`
M1FQO870`0V]L;W)E($9O;G0`4&5R(&)R;W=S97(@8VAE(&YO;B!S;W!P;W)T
M86YO(&QE(&EM;6%G:6YI`$AA:2!D:6UE;G1I8V%T;R!L82!T=6$@<&%S<W=O
M<F0_`$UO9'5L:0!);F1O=FEN;P!&;W)T=6YE(%1Y<&4`1F]R='5N97,`1F]R
M=6T`26YO;'1R:0!696X`1G)A;65S`$1A;"``1&5S8W)I>FEO;F4@0V]M<&QE
M=&$`3'5N82!0:65N80!.;VUE($-O;7!L971O`$=E;F5R82!#;VYF:6=U<F%Z
M:6]N92`E<R``0V]D:6-E($=E;F5R871O`%9A:2!A`%)I8V5R8V$@1V]O9VQE
M`$%M;6EN:7-T<F%Z:6]N92!'<G5P<&D`1W)U<'!I`%!E<FUE<W-I($]S<&ET
M:0!!;'1E>GIA`$%I=71O`$5M:7-F97)O`$%L=&$`2&]?<F1E`$AO<F1E`%)I
M96UP:6UE;G1O($]R:7IZ;VYT86QE`$]R:7IZ;VYT86QE.@!1=6%N=&4@8V]L
M;VYN92!V=6]I('5N:7)E/P!1=6%N=&D@8V%M<&D@*&-O;&]N;F4I(&-I('-O
M;F\_`%%U86YT92!R:6=H92!V=6]I('5N:7)E/P!5;6ED:73@`$E?;G-E<FES
M8VD@;&$@<FEG82!P<FEM80!3;VQO($EC;VYE`$EC;VYE(&-O;B!497-T;P!.
M;VUE(&1E;&PG261E;G1I=.`Z`$%N=&5P<FEM92!);6UA9VEN90!54DP@26UM
M86=I;F4`55),($EM;6%G:6YE`$EM;6%G:6YI`$EM<&]R=&$L(%!A<W-O("5D
M`$-A;7!O(&EM<&]R=&%T;SH@)7,`0V%M<&D@:6UP;W)T871I.@!);E]S97)I
M<V-I('5N82!R:6=A(&1O<&\`571E;G1I($EN9&EV:61U86QI`$EN9F]R;6%Z
M:6]N90!);G-E<FES8VD@=6YA($-?;VQO;FYA(&1O<&\`26YS97)I<V-I('5N
M)VEM;6%G:6YE`$EN<V5R:7-C:2!486)E;&QA`$EN<V5R:7-C:2!#;VQL96=A
M;65N=&\@5V5B`$EN<V5R:7-C:2!?8V]L;VYN82!0<FEM80!);G-E<FES8VD@
M=6YA(&YU;W9A(&-O;&]N;F$@9&]P;R!Q=65L;&$@8V]R<F5N=&4`26YS97)I
M<V-I('5N82!N=6]V82!C;VQO;FYA('!R:6UA(&1I('%U96QL82!C;W)R96YT
M90!);G-E<FES8VD@=6YA(&YU;W9A(')I9V$@9&]P;R!Q=65L;&$@8V]R<F5N
M=&4`26YS97)I<V-I('5N82!N=6]V82!R:6=A('!R:6UA(&1I('%U96QL82!C
M;W)R96YT90!);G-E<FES8VD@=6X@=&5M<&QA=&4@86QT97)N871I=F\`26YS
M97)I<V-I(&-E;&QA(&1O<&\`26YS97)I<V-I(&-E;&QA('!R:6UA`$%G9VEU
M;F=I(&-O;&]N;F$@9&]P;P!);G-E<FES8VD@8V]L;VYN82!P<FEM80!);G-E
M<FES8VD@<&%R86=R869O(&1O<&\`26YS97)I<V-I('!A<F%G<F%F;R!P<FEM
M80!);G-E<FES8VD@<FEG82!D;W!O`$EN<V5R:7-C:2!R:6=A('!R:6UA`$EN
M<V5R:7-C:2]-;V1I9FEC82!);6UA9VEN90!!<'!L:6-A>FEO;F4@:6YV86QI
M9&$N`$1A=&\@;F]N('9A;&ED;RX`26YV96YT87)I;P!#;W)S:79O`$=E;FYA
M:6\`1VEA<'!O;F5S92`H25-/+3(P,C(M2E`I`$QU9VQI;P!':75G;F\`1VEU
M<W1I9FEC871O`%]&;W)M871O`$QI;F=U80!5;'1I;6\@475A<G1O`%5L=&EM
M;R!!9V=I;W)N86UE;G1O.@!5;'1I;6\@86-C97-S;SH@)7,`56QT:6UO(&%C
M8V5S<V\Z("5S(&1A("5S`%5L=&EM;R!A8V-E<W-O.B!-86D`1F]R;6%T;P!S
M:6YI<W1R80!0:6]G9VEA($QE9V=E<F$`16QE;F-A(&=L:2!A<F=O;65N=&D@
M9&D@06EU=&\`3F]N(.@@871T:79A(&QA(&9U;GII;VYE(&1I(&5L96YC;R!U
M=&5N=&DN`$QI=&5R871U<F$`3W)A(&QO8V%L93H@`$QI;F=U82!E($]R80!,
M=6]G;P!%;G1R80!%<V-I`$-O;7!I=&D@9&D@:6YI>FEO('-E<W-I;VYE`$)A
M<W-A`&YU;65R:2!R;VUA;FD@<&GY(&)A<W-I`$U-`%!O<W1A`$EN9&ER:7IZ
M;R!!;6UI;FES=')A=&]R90!'97-T:7-C:2!L82!L:7-T82!D96QL92!C871E
M9V]R:64@9&%N9&\@;&]R;R!U;B=E=&EC:&5T=&$@92!A<W-O8VEA;F1O(&QO
M<F\@=6X@8V]L;W)E+@!-87)Z;P!-87)G:6YE`$-A;7!I(&-O<G)I<W!O;F1E
M;G1I`$UA9V=I;P!-96UB<FD`56YI<V-I($-E;&QE`$UE=&5O($%T='5A;&4`
M0FQO8VL@;F]N(&1I<W!O;FEB:6QE+@!$971T86=L:2!L;V=G871I('!E<B!L
M)V%M;6EN:7-T<F%T;W)E`&UE=')I8V\`0V5N=')O`$QU;@!-;V)I;&4@36%I
M;`!-;V1E<F%T;P!-;V1I9FEC82!54DP`4')I;F-I<&%L;65N=&4@4V5R96YO
M`$UI;R!!8V-O=6YT`$UI;R!0;W)T86QE`$9O<FUA=&\@9&5L($UI;R!0;W)T
M86QE`$Y/+"!.3TX@4V]N;R!D)T%C8V]R9&\N`%)E=&4`36%I`$YU;W9A($-A
M=&5G;W)I80!.=6]V;R!.;VUE(%5T96YT92`H3W!Z:6]N86QE*0!.;W1I>FEE
M`$=R=7!P:2!D:2!N;W1I>FEE`%!R;W-S:6UO`$YO='1E`$YO;B!P=6]I(&-R
M96%R92!F:6=L:2!A('%U97-T;R!P97)M97-S;RX`3F5S<W5N82!R96=I<W1R
M87II;VYE(&EN(&%T=&5S82X`3F5S<W5N82!R96=O;&$`3F5S<W5N(&QA=&\`
M3F5S<W5N(&1I<F5T=&]R:6\@=&5M<&]R86YE;R!D:7-P;VYI8FEL92!P97(@
M;&$@8V%C:&4N`$YE<W-U;F$@=F5R<VEO;F4@=')O=F%T82!N96QL82!C;VYF
M:6=U<F%Z:6]N92!O<FEG:6YA;&4N(%)E9V5N97)A(&QA(&-O;F9I9W5R87II
M;VYE+@!.97-S=6YA('9E<G-I;VYE('1R;W9A=&$@;F5L;&$@='5A(&-O;F9I
M9W5R87II;VYE+B!296=E;F5R82!L82!C;VYF:6=U<F%Z:6]N92X`3F5S<W5N
M;P!.;VX@:6UP;W-T871O`$YO=&4`3F]V96UB<F4`3G5M97)O(&1I(&-O;&]N
M;F4`3G5M97)O(&1I(')I9VAE`$]+`%!R;W!R:65T87)I;P!/='1O8G)E`%5F
M9FEC:6\`07!R:2!I;B!N=6]V82!F:6YE<W1R80!!<')I('%U97-T;R!C;VQL
M96=A;65N=&\@:6X@;G5O=F$@9FEN97-T<F$`3W!Z:6]N:0!/<'II;VYI(&9O
M<B`E<P!'<F]U<%=A<F4`87!P;&EC87II;VYE(&EN=&5R;F$`06QT<F\`06QT
M<F4@26YF;W)M87II;VYI`%!E<FUE<W-I(&1E;"!0<F]P<FEE=&%R:6\`0V]D
M:6-E(%!(4`!032!0:6]G9VEA($QE9V=E<F$`4&%S<W=O<F0`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``3&4@<&%S<W=O<F0@9&5V;VYO(&-O<G)I<W!O;F1E<F4N
M`$EN8V]L;&$`4&5R8V]R<V\`4F5G:7-T<F%Z:6]N:2!I;B!!='1E<V$Z`%!E
M<F-E;G1U86QE`$5S96=U:2!L92!/<&5R87II;VYI(&1I($UA;G5T96YZ:6]N
M90!%<V5G=6D@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4@86P@;&]G
M:6X_`%!E<FUE<W-I`$%M;6EN:7-T<F%Z:6]N92!D96D@4&5R;65S<VD`26YF
M;W)M87II;VYI(%!E<G-O;F%L:0!&;W1O`%!I>&5L`%!R96=O(&-O;F9E<FUA
M<F4@96QI;6EN87II;VYE(&5L96UE;G1O.@!0<F5G;R!C;VYF97)M87)E(&5L
M:6UI;F%Z:6]N92!L:6YK.@!);G-E<FES8VD@=6X@;F]M92!P97(@;&$@;G5O
M=F$@8V%T96=O<FEA.@!$979I(&EN<V5R:7)E(&EL('1U;R!N;VUE('5T96YT
M92!E(&QA('!A<W-W;W)D`%-O;F1A9V=I`%!O<VEZ:6]N86UE;G1O(&1I('%U
M97-T82!I;6UA9VEN92X`4&]S:7II;VYA;65N=&\@9&D@<75E<W1A('1A8F5L
M;&$`4')E<W-I;VYE`%!R97-S:6]N92!A;"!L:79E;&QO(&1I(&UA<F4Z(`!0
M<F5S<VEO;F4Z(`!!;G1E<')I;6$`06YT97!R:6UA(&1E;&PG:6UM86=I;F4@
M:6X@;G5O=F$@9FEN97-T<F$`4W1A;7!A(&1O8W5M96YT;R``4')O8FQE;6$`
M1&5S8W)I>FEO;F4@9&5L('!R;V)L96UA`%!R;V=E='1I`$1O;6%N9&$`4&EO
M9V=I80!0:6]G9VEA(%!R97-T;P!0:6]G9VEA(%1A<F1I`$9O<G1U;F$@0V%S
M=6%L90!,96=G:0!3:6-U<F\@9&D@=F]L97(@96QI;6EC87)E)7,_($PG;W!E
M<F%Z:6]N92!N;VX@<'5O)R!E<W-E<F4@86YN=6QL871A`%-I8W5R;R!D:2!V
M;VQE<B!E;&EM:6YA<F4@:2!D871I(&1I("5S/R!,)V]P97)A>FEO;F4@;F]N
M('!U;R<@97-S97)E(&%N;G5L;&%T80!!9V=I;W)N82!L82!V:7-U86QI>GIA
M>FEO;F4@4&]R=&%L93H`3F]T90!397)V97(@4F5M;W1I`%523"!R96UO=&$@
M*&AT='`Z+R]W=W<N97-E;7!I;RYC;VTO:&]R9&4I.@!%;&EM:6YA`$5L:6UI
M;F$@8FQO8V-O`%)I;75O=FD@1F]R;6%T=&%Z:6]N90!%;&EM:6YA('!A:6\`
M16QI;6EN82!I;`!%;&EM:6YA('5T96YT90!%;&EM:6YA('5T96YT93H@)7,`
M06YN=6QL80!!;FYU;&QA(%!A<W-W;W)D`$%N;G5L;&$@;&$@='5A(%!A<W-W
M;W)D`%)I<W5L=&%T:0!4;W)N82!A;&QE($]P>FEO;FDN`$EN=F5R=&D@;&$@
M0V]N9FEG=7)A>FEO;F4`3W!Z:6]N:2!%9&ET;W(@4FEC:"!497AT`%)I9&1L
M97,`1&5S=')A`%!R;W!R:65TX"!D96QL82!27VEG82XN+@!0<F]P<FEE=&$@
M9&5L;&$@<FEG80!0<F]P<FEE=.`@9&5L;&$@<FEG80!2:6=H93H`4F5G;VQE
M`$5S96=U:0!-97-S86=G:2!335,`4V%B`%-A;'9A`%-A;'9A("5S`%-A;'9A
M($]P>FEO;FD`4V%L=F$@;&$@8V]N9FEG=7)A>FEO;F4@9V5N97)A=&4@8V]M
M92!S8W)I<'0@4$A0('-U;&QA(&-A<G1E;&QA('1E;7!O<F%N96$@9&5L('1U
M;R!S97)V97(N`%-A;'9A=&\@;&$@8V]N9FEG=7)A>FEO;F4@)7,N`%)I8V5R
M8V$`36]T;W)E(&1I(')I8V5R8V$`4VQE>FEO;F$@=6X@9W)U<'!O(&1A(&%G
M9VEU;F=E<F4`4V5L97II;VYA('5N(&YU;W9O('!R;W!R:65T87)I;P!396QE
M>FEO;F$@=6X@<V5R=F5R`%-E;&5Z:6]N82!U;B!U=&5N=&4@9&$@86=G:75N
M9V5R90!396QE>FEO;F$@:2!C87)A='1E<FD@9&D@8W5I(&AA:2!B:7-O9VYO
M(&1A;&QE(&-A<V5L;&4@<75I('-O='1O+B!0=6]I('%U:6YD:2!C;W!I87)L
M92!E(&EN8V]L;&%R;&4@9&%L;&$@=&5X=&%R96$N`%-E;&5Z:6]N82!I;"!D
M96QI;6ET871O<F4@9&D@9&%T83H`4V5S8V5G;&D@:6P@9F]R;6%T;R!D96QL
M82!D871A.@!396QE>FEO;F$@:6P@9&5L:6UI=&%T;W)E(&1E;&PG;W)A.@!3
M8V5G;&D@:6P@9F]R;6%T;R!D96QL)V]R83H`4V5L97II;VYA(&1U92!C86UP
M:2!C;W)R:7-P;VYD96YT:2X`4V5L97II;VYA(&EL('1U;R!S8VAE;6$@8V]L
M;W)I+@!396QE>FEO;F$@;&$@;&EN9W5A(&-H92!P<F5F97)I<V-I.@!);G9I
M82!I;"!R97!O<G0@9&5L('!R;V)L96UA`%-E;G-O<F4Z(`!3971T96UB<F4`
M26UP;W-T:2!I('-E<G9E<B!R96UO=&D@86D@<75A;&D@=G5O:2!A8V-E9&5R
M92!D86P@='5O('!O<G1A;&4N`%-E;&5Z:6]N82!L82!L:6YG=6$@<')E9F5R
M:71A(&4@:6P@9G5S;R!O<F%R:6\N`$UO9&EF:6-A(&QA('1U82!A<'!L:6-A
M>FEO;F4@9&D@879V:6\L(&=L:2!S8VAE;6D@8V]L;W)E+"!E9"!A;'1R92!O
M<'II;VYI(&1I('9I<W5A;&EZ>F%Z:6]N92X`4V-R:7!T(&1I(&%G9VEO<FYA
M;65N=&\@9&5L('-E='5P(&1I<W!O;FEB:6QE`%-H;W!P:6YG`$)R979E(%)I
M87-S=6YT;P!$969I;FEA;6\@9VQI(&%C8V5S<VD@9&$@=&%S=&EE<F$@<&5R
M(&D@;&EN:S\`36]S=')A`$UO<W1R82!L)W5L=&EM;R!L;V=I;B!A;&PG86-C
M97-S;S\`36]S=')A('1A8F5L;&$@;W!E<F%Z:6]N:2!N96QL82!B87)R82!D
M96P@;65N=3\`36]S=')A(&EL("5S($UE;F\@<W5L;&$@<VEN:7-T<F$_`$UO
M<W1R82!L92!0<F]P<FEE=.`@5&%B96QL82!#96QL80!-;W-T<F$@;&4@4')O
M<')I973@(%1A8F5L;&$`36]S=')A(&QE(%!R;W!R:65TX"!486)E;&QA(%)I
M9V$`06-Q=6%Z>F]N:0!!8W%U87IZ;VYI(&$@0G)E=F4`06-Q=6%Z>F]N:2!4
M87)D:0!386QT82!-86YU=&5N>FEO;F4`4')O9F]N9&ET82<@9&D@;F5V93H@
M`%-P87II871U<F$`4W!A;0!#87)A='1E<F4@4W!E8VEA;&4`1&EV:61I($-E
M;&QA`$1I=FED:2!C;VQO;FYA`$1I=FED:2!2:6=A`%-T86YD87)D`%-T871O
M`$1O;0!3;W1T;W-C<FEV:0!3=6-C97-S;P!386QV871O(&QA(&-O;F9I9W5R
M87II;VYE+@!38W)I='1O(&-O;B!S=6-C97-S;R`E<P!2:6%S<W5N=&\`06QB
M80!4<F%M;VYT;P!!;&)A`$%L8F$O5')A;6]N=&\`06QB83H@`%1R86UO;G1O
M`%1R86UO;G1O.B``4W5P97)S8W)I<'0`4W5P<&]R=&\`5"U496UP97-T80!4
M+51E;7!E<W1E`%!R;W!R:65TX"!486)E;&QA`%!R;W!R:65TX"!486)E;&QA
M`$1E<W1I;F%Z:6]N93H`071T:79I=.``5&5M<&5R871U<F$@=6QT:6UA(&]R
M83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``06UM:6YI<W1R87II;VYE
M(%1E;7!L871E`%-O;&\@5&5S=&\`06QL:6YE86UE;G1O('1E<W1O`%1E<W1O
M(&EN(&%L=&\`1VEO`$=R87II92!D:2!A=F5R('5S871O(&EL('-I<W1E;6$N
M`$PG:61E;G1I=.`@(B5S(B!E)R!S=&%T82!E;&EM:6YA=&$N`$EL('-E<G9E
M<B`B)7,B(&4G('-T871O(&5L:6UI;F%T;RX`26P@<V5R=F5R("(E<R(@92<@
M<W1A=&\@<V%L=F%T;RX`3&$@<FEC:&EE<W1A(&1I(')E9VES=')A>FEO;F4@
M<&5R("5S(.@@<W1A=&$@96QI;6EN871A+@!);"!M;V1U;&\@=V5A=&AE<BYC
M;VT@;F]N(.@@9&ES<&]N:6)I;&4N`%%U97-T;R!E)R`E<RX`5'5O;F\`5&EC
M:V5T`$=E<W1I;VYE(&1E;"!496UP;P!&;W)M871O($]R80!4:71O;&\`3V=G
M:0!$;VUA;FD`06QT;P!-87(`55),`%523#H`4V]T=&]L:6YE80!!;FYU;&QA
M(&QE($UO9&EF:6-H90!);F1E9FEN:71O`%5N:73@`$5L:6UI;F$@16QE;65N
M=&\@0V]R<F5N=&4`16QI;6EN82!#;VQO<F4`06=G:6]R;F$`06=G:6]R;F$@
M)7,`06=G:6]R;F$@=71E;G1E`%-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&5L
M:6UI;F%T;RX`06=G:6]R;F$`3G5M97(@<F]M86YI(&%L=&D`06UM:6YI<W1R
M87II;VYE(%5T96YT:0!296=I<W1R87II;VYE(%5T96YT90!)<V-R:7II;VYE
M(%5T96YT92!E)R!S=&%T;R!D:7-A8FEL:71A=&\@<&5R('%U97-T;R!S:71O
M+@!.;VUE(%5T96YT90!.;VUE(%5T96YT93H`3F]M92!5=&5N=&4Z`%5T96YT
M:2!N96P@<VES=&5M83H`5F%C86YZ90!687)I86)I;&4`0V]N=')O;&QO(%9E
M<G-I;VYE`$%L;&EN96%M96YT;P!2:65M<&EM96YT;R!697)T:6-A;&4`5F5R
M=&EC86QE.@!-;VQT;R!!;'1O`%9I<W5A;&EZ>F$@=6YA('!A9VEN82!W96(@
M97-T97)N80!6:7-I8FEL:73@`%9I<VEB:6QI=.`Z(`!-97(`4')E=FES:6]N
M92!-971E;P!796(`0F5N=F5N=71O`$)E;G9E;G5T;R!A("5S`$)E;G9E;G5T
M;RP@)7,`0VAE(&%P<&QI8V%Z:6]N92`E<R!D979E(&UO<W1R87)E(&1O<&\@
M:6P@;&]G:6X_`$-O<V$@92<@8V%R871T97)E(&1E;&EM:71A=&]R90!#;W-A
M(&4G(&EL(&-A<F%T=&5R92!V:7)G;VQE='1E/P!,87)G:&5Z>F$`06UP:65Z
M>F$@9&5L;&$@=&%B96QL80!5;FETX"!,87)G:&5Z>F$`3&%R9VAE>GIA.@!6
M96YT;SH`5F5N=&\Z(`!!00!3:2P@<V]N;R!D)V%C8V]R9&\`3&$@<V5S<VEO
M;F4@Z"!S=&%T82!T97)M:6YA=&$N`$1E=FD@<W!E8VEF:6-A<F4@:6P@<V5R
M=F5R(&1A(&5L:6UI;F%R92X`1&5V:2!S<&5C:69I8V%R92!L;R!U<V5R;F%M
M92!D82!R:6UU;W9E<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@
M9&$@<FEM=6]V97)E+@!$979I('-P96-I9FEC87)E(&QO('5S97)N86UE(&1A
M(&%G9VEU;F=E<F4N`$1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@9&$@
M86=G:6]R;F%R92X`5'5O($EN9&ER:7IZ;R!%;6%I;`!4=6\@26YD:7)I>GIO
M($5M86EL`%9O<W1R82!I;F9O<FUA>FEO;F4`26P@='5O(&YO;64`26P@='5O
M(&)A8VME;F0@9&D@875T96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A(&QA(&5L
M96YC87II;VYE(&1E9VQI('5T96YT:2P@;R!L82!C87)A='1E<FES=&EC82#H
M('-T871A(&1I<V%B:6QI=&%T82!P97(@<75A;&-H92!M;W1I=F\N`$EL('1U
M;R!B<F]W<V5R(&YO;B!H82!Q=65S=&$@8V%P86)I;&ET82<N`$EL('1U;R!F
M=7-O(&]R87)I;R!A='1U86QE.@!)9&5N=&ETX"!D:2!$969A=6QT`$EL('1U
M;R!N;VUE.@!)('1U;VD@<V5R=F5R(')E;6]T:3H`6T1O8W5M96YT;R!D:2!D
M97-C<FEZ:6]N92!D96P@<')O8FQE;6%=`%M-;W-T<F$@5&5S=&\@<75O=&%T
M;R`M`%]!;6UI;FES=')A>FEO;F4`7T1A=&%4<F5E`%]%;&EM:6YA(%)I9V$`
M7T=R=7!P:0!?06EU=&\`4')O<')I973@(&1E;&PG7TEM;6%G:6YE+BXN`%]&
M:6YE('-E<W-I;VYE`%]-;V1I9FEC82!,:6YK+BXN.@!?3W!Z:6]N:0!?4&5R
M;65S<VD`7T5L:6UI;F$@3&EN:RXN+@!0<F]P<FEE=.`@9&5L;&$@7U1A8F5L
M;&$`7U5T96YT:0!C86QM;P!D86QL92`E<R`H)7,I(&%L;&4@)7,@)7,`;&EN
M965=`&YO;64`<&5R8V5N=&\`<&EX96QS`&%U;65N=&%N9&\G`&-O<W1A;G1E
M`&1I9VET82!L82!P87-S=V]R9"!D=64@=F]L=&4@<&5R(&-O;F9E<FUA<F4`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VET7TE4+VAE;'`N>&UL````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#0R-P`Q,#0Q
M-S,V,C<W-P`P,C`S-3<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O
M+3@X-3DM,2(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+VET7TE4+VAE
M;'`N>&UL+'8@,2XR+C$P+C(@,C`P-2\Q,"\Q."`Q,3HS,SHT,R!J86X@17AP
M("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](G5P
M=&]D871E(B!M9#4](C8X8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U
M(CX*/'1I=&QE/E!A9VEN82!D:2!I;F=R97-S;R!D96P@<&]R=&%L93PO=&ET
M;&4^"B`\<&%R83X*("!1=65S=&$@<&%G:6YA(&1I(&EN9W)E<W-O(&1E;"!P
M;W)T86QE(&9O<FYI<V-E('5N(&)R979E('-O;6UA<FEO(&1I('1U='1E(&QE
M('1U90H@(&EN9F]R;6%Z:6]N:2!I;7!O<G1A;G1I+B!!9"!E<V5M<&EO+"!T
M:2!P=?(@;6]S=')A<F4@<75A;G1I(&YU;W9I(&UE<W-A9V=I(&-I"B`@<V]N
M;R!N96QL82!T=6$@24Y"3U@L(&D@<')O<W-I;6D@979E;G1I(&YE;"!T=6\@
M8V%L96YD87)I;RP@;&4@871T:79I=.`@;F5L;&$*("!T=6$@;&ES=&$L(&QE
M('5L=&EM92!N;W1I>FEE(&1A('-E<G9I>FD@<V5L97II;VYA=&D@92!C;W/L
M('9I82X@36]L=&D@9&D@<75E<W1I"B`@<V]M;6%R:2!C;VYT97)R86YN;R!D
M96D@8V]L;&5G86UE;G1I(&$@9G5N>FEO;FD@8V]M=6YI+"!Q=6%L:2!A9"!E
M<V5M<&EO(&QA(&-O;7!O<VEZ:6]N90H@(&1I('5N82!N=6]V;R!M97-S86=G
M:6\L(&QA(&-R96%Z:6]N92!D:2!U;F\@;G5O=F\@979E;G1O(&1A(&EN<V5R
M:7)E(&YE;"!C86QE;F1A<FEO"B`@;R!L82!C<F5A>FEO;F4@9&D@=6YA(&YU
M;W9A(&%T=&EV:73@(&1A(&EN<V5R:7)E(&YE;&QA(&QI<W1A+"!E8V,N"B`\
M+W!A<F$^"B`\<&%R83X*("!)(&-O;G1E;G5T:2!D:2!Q=65S=&$@<&%G:6YA
M(&1E;"!P;W)T86QE('-O;F\@<&5R<V]N86QI>GIA8FEL:2!T<F%M:71E(&EL
M(&)O='1O;F4@1F]R;6%T;RX*("!!9"!E<V5M<&EO+"!P=6]I('-C96=L:65R
M92!Q=6%L:2!I;F9O<FUA>FEO;FD@:6YS97)I<F4@;F5L;&$@<&%G:6YA(&-O
M;64@86YC:&4@:6X*("!Q=6%L92!O<F1I;F4@=F5R<F%N;F\@;6]S=')A=&4N
M"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E
M/2)U<'1O9&%T92(@;60U/2)B.&-F,&%E,3EE-3=D9F$P8S)B.38R934Q-C<X
M,F8T-R(^"CQT:71L93Y,82!B87)R82!D:2!N879I9V%Z:6]N92!D96QL92!A
M<'!L:6-A>FEO;FD\+W1I=&QE/@H@/'!A<F$^"B`@4W5L;&$@<VEN:7-T<F$@
M9&5L;&$@<&%G:6YA('=E8B#H('!R97-E;G1E(&QA(&)A<G)A(&1I(&YA=FEG
M87II;VYE(&1E;&QE(&%P<&QI8V%Z:6]N:2X*("!#;&EC8V$@<W5L;"=I8V]N
M82!P<F5S96YT92!N96QL82!B87)R82!D:2!N879I9V%Z:6]N92!P97(@<&%S
M<V%R92!R87!I9&%M96YT92!E"B`@=F5L;V-E;65N=&4@=')A(&QE('9A<FEE
M(&%P<&QI8V%Z:6]N:2!D:7-P;VYI8FEL:2X*(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B
M/@H@("`@/'1I=&QE/E!R969E<F5N>F4Z($UA;G5T96YZ:6]N93H@17-E9W5I
M(&QA(&UA;G5T96YZ:6]N93PO=&ET;&4^"B`@("`\<&%R83X*("`@(%-E('9U
M;VD@97-E9W5I<F4@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4@87!P
M96YA(&5N=')A=&\@;F5L('!O<G1A;&4L"B`@("!S96QE>FEO;F4@<75E<W1A
M(&-A<V5L;&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD
M-3TB83(Q,38R8V1F9C-B,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I
M=&QE/E!R969E<F5N>F4Z($UA;G5T96YZ:6]N93H@0V]N9F5R;6$@;&$@;6%N
M=71E;GII;VYE/"]T:71L93X*("`@(#QP87)A/@H@("`@4V4@9&5S:61E<FD@
M8VAE('9E;F=A(&-H:65S=&$@;&$@8V]N9F5R;6$@<')I;6$@8VAE('1U='1E
M(&QE(&]P97)A>FEO;FD@9&D@;6%N=71E;GII;VYE(`H@("`@=F5N9V%N;R!E
M<V5G=6ET92P@<V5L97II;VYA('%U97-T82!C87-E;&QA+@H@("`@4V4@;&$@
M8V%S96QL82!N;VX@=FEE;F4@<V5L97II;VYA=&$L('1U='1E(&QE(&]P97)A
M>FEO;FD@9&D@;6%N=71E;GII;VYE(&-H92!S;VYO"B`@("!P<F]G<F%M;6%T
M92!V97)R86YN;R!E<V5G=6ET92!A=71O;6%T:6-A;65N=&4@<V5N>F$@;&$@
M<&]S<VEB:6QI=.`@9&D@8V%N8V5L;&%R;&4*("`@('%U86YD;R!S:2!E;G1R
M82!N96P@<&]R=&%L92X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VMM7TM(
M+P``````````````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,C<W-P`P,38V-C(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O:VU?2T@O3$-?34534T%'15,O````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`R,#0T-P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]K;5]+2"],0U]-15-304=%
M4R]H;W)D92YM;P``````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3$W-3,`,3`T
M,3<S-C(W-S<`,#(R,3$R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-X2!)4`````1`(``!P````\$@``!0,``%PD````````
M<#````X```!Q,```#P```(`P```(````D#````L```"9,```#````*4P```8
M````LC```!L```#+,```#````.<P```%````]#````4```#Z,```!@`````Q
M```,````!S$```X````4,0``#@```",Q```(````,C$```D````[,0``"```
M`$4Q```3````3C$```,```!B,0``"````&8Q```'````;S$```P```!W,0``
M#@```(0Q```+````DS$```<```"?,0``!P```*<Q```%````KS$```4```"U
M,0```P```+LQ```7````OS$```X```#7,0``!P```.8Q```&````[C$```@`
M``#U,0``"@```/XQ```3````"3(```L````=,@``!0```"DR```5````+S(`
M``D```!%,@``!P```$\R```%````5S(```H```!=,@``!@```&@R```)````
M;S(```<```!Y,@``%0```($R```*````ES(```H```"B,@``$````*TR```'
M````OC(```<```#&,@``"@```,XR```(````V3(```<```#B,@``!P```.HR
M```&````\C(```4```#Y,@``!P```/\R```&````!S,```@````.,P``!```
M`!<S```'````'#,```D````D,P``!@```"XS```'````-3,``!8````],P``
M!````%0S```(````63,```8```!B,P``#0```&DS```&````=S,``!X```!^
M,P``$0```)TS```(````KS,```P```"X,P``!P```,4S```#````S3,```@`
M``#1,P``"````-HS```(````XS,```8```#L,P``!@```/,S```*````^C,`
M``<````%-```!P````TT```.````%30```8````D-```&````"LT```$````
M1#0```8```!)-```!0```%`T```%````5C0``!````!<-```!0```&TT```+
M````<S0```P```!_-```%P```(PT```(````I#0```4```"M-```!P```+,T
M```'````NS0```L```##-```!P```,\T```'````US0```D```#?-```"0``
M`.DT```*````\S0``!4```#^-```&0```!0U```%````+C4``!(````T-0``
M"````$<U```(````4#4```P```!9-0``!````&8U```*````:S4```<```!V
M-0``!@```'XU```'````A34```0```"--0``#````)(U```-````GS4``"@`
M``"M-0```P```-8U```&````VC4``!$```#A-0``%P```/,U```.````"S8`
M``(````:-@``!0```!TV```$````(S8```,````H-@``"````"PV```/````
M-38```<```!%-@``!@```$TV```-````5#8```H```!B-@``!P```&TV```+
M````=38```L```"!-@``"0```(TV```(````ES8```@```"@-@``$@```*DV
M```?````O#8```@```#<-@``#````.4V```&````\C8```<```#Y-@``!```
M``$W```)````!C<```4````0-P``"P```!8W```%````(C<```T````H-P``
M&P```#8W```)````4C<``!$```!<-P``!P```&XW```%````=C<```<```!\
M-P``"````(0W```&````C3<``!````"4-P``$````*4W```/````MC<```\`
M``#&-P``#````-8W```'````XS<```8```#K-P``"````/(W```;````^S<`
M``T````7.````P```"4X```(````*3@```0````R.```!````#<X```)````
M/#@```<```!&.```!P```$XX```$````5C@```4```!;.```"@```&$X```%
M````;#@```8```!R.```!@```'DX```-````@#@``!````"..```&P```)\X
M```$````NS@```D```#`.```!0```,HX```&````T#@```<```#7.```!P``
M`-\X```%````YS@```D```#M.```"@```/<X```.`````CD```(````1.0``
M"0```!0Y```&````'CD``!(````E.0``"0```#@Y```'````0CD```8```!*
M.0``"@```%$Y```$````7#D```D```!A.0``!@```&LY```-````<CD```8`
M``"`.0``!````(<Y```%````C#D```8```"2.0``!P```)DY```A````H3D`
M``8```##.0``!````,HY```$````SSD``!T```#4.0``!````/(Y```,````
M]SD```X````$.@``"@```!,Z```(````'CH```D````G.@``!P```#$Z```*
M````.3H```<```!$.@``"@```$PZ```&````5SH```\```!>.@``!0```&XZ
M```)````=#H```0```!^.@``"P```(,Z```,````CSH```<```"<.@``!```
M`*0Z```'````J3H```8```"Q.@``!@```+@Z```&````OSH```4```#&.@``
M!P```,PZ```'````U#H```4```#<.@``%@```.(Z```&````^3H```0`````
M.P``!`````4[```'````"CL```H````2.P``!0```!T[```*````(SL```@`
M```N.P``"````#<[```/````0#L```8```!0.P``"@```%<[```(````8CL`
M`"````!K.P``!@```(P[```&````DSL```<```":.P``!````*([```'````
MISL```4```"O.P``!P```+4[```6````O3L```T```#4.P``!````.([```%
M````YSL```D```#M.P``"@```/<[```(`````CP```8````+/```!P```!(\
M```%````&CP```L````@/```!````"P\```#````,3P```H````U/````@``
M`$`\```%````0SP```H```!)/```!````%0\```&````63P```@```!@/```
M"````&D\```$````<CP```4```!W/```!0```'T\```&````@SP``!````"*
M/```"@```)L\```*````ICP```D```"Q/````P```+L\```'````OSP```<`
M``#'/```!P```,\\```&````USP```8```#>/```!@```.4\```)````[#P`
M``8```#V/```#0```/T\```&````"ST```@````2/0``#@```!L]```'````
M*CT```H````R/0``!P```#T]```)````13T```D```!//0``"@```%D]```'
M````9#T```D```!L/0``!P```'8]```*````?CT```<```")/0``!````)$]
M```'````ECT```4```">/0``!0```*0]```+````JCT``!0```"V/0``!P``
M`,L]```%````TST```T```#9/0``$0```.<]```+````^3T```P````%/@``
M!````!(^```*````%SX```0````B/@``"0```"<^```%````,3X```<````W
M/@``!0```#\^```$````13X```(```!*/@``!````$T^```.````4CX``!@`
M``!A/@``!@```'H^```%````@3X```@```"'/@``!@```)`^```4````ESX`
M``(```"L/@``!@```*\^```'````MCX```8```"^/@``#````,4^```$````
MTCX``!0```#7/@``$````.P^```'````_3X```4````%/P``!P````L_```(
M````$S\```4````</P``!@```"(_```0````*3\```@````Z/P``"````$,_
M```)````3#\```4```!6/P``!````%P_```&````83\```<```!H/P``*```
M`'`_```*````F3\```L```"D/P``%````+`_```$````Q3\```L```#*/P``
M!0```-8_```(````W#\```8```#E/P``!@```.P_```(````\S\```@```#\
M/P``!P````5````(````#4````H````60```"P```"%````%````+4````4`
M```S0```!0```#E````$````/T````<```!$0```#0```$Q````&````6D``
M``<```!A0```!@```&E````%````<$````<```!V0```$0```'Y````'````
MD$````4```"80```!````)Y````'````HT````L```"K0```#````+=````%
M````Q$````,```#*0```$@```,Y````&````X4````,```#H0```#````.Q`
M```5````^4````L````/00``&0```!M!```@````-4$```4```!600``"@``
M`%Q!```5````9T$```P```!]00``!````(I!```,````CT$```8```"<00``
M#@```*-!```-````LD$```H```#`00``"P```,M!```'````UT$```D```#?
M00``%0```.E!```-````_T$```@````-0@```P```!9"```%````&D(```H`
M```@0@``!````"M"```&````,$(```P````W0@``"0```$1"```)````3D(`
M``0```!80@``"````%U"```(````9D(```\```!O0@``!P```']"```,````
MAT(``"P```"40@``!P```,%"```%````R4(```0```#/0@``"0```-1"```(
M````WD(```8```#G0@``#0```.Y"```'````_$(```8````$0P``"0````M#
M```'````%4,```4````=0P``!P```"-#```+````*T,```<````W0P``"```
M`#]#```6````2$,```D```!?0P``!@```&E#```+````<$,``!0```!\0P``
M!0```)%#```0````ET,``!````"H0P``!@```+E#```*````P$,```4```#+
M0P``$````-%#```+````XD,```0```#N0P``"0```/-#```(````_4,``"\`
M```&1```!````#9$```+````.T0```4```!'1````@```$U$```%````4$0`
M``0```!61```!P```%M$```%````8T0```,```!I1```$P```&U$```'````
M@40```8```")1```%````)!$```,````I40``!@```"R1```!@```,M$```#
M````TD0```0```#61```!@```-M$```'````XD0```D```#J1```!P```/1$
M```/````_$0``!0````,10``#@```"%%```-````,$4``"0````^10``!0``
M`&-%```'````:44```<```!Q10``!@```'E%```&````@$4```<```"'10``
M!````(]%```3````E$4```@```"H10``"0```+%%```*````NT4```@```#&
M10``!@```,]%```'````UD4```@```#>10``"0```.=%```'````\44```\`
M``#Y10``!P````E&```4````$48``!$````F1@``!P```#A&```#````0$8`
M``@```!$1@``!@```$U&```'````5$8```T```!<1@``#@```&I&```%````
M>48```8```!_1@``"````(9&```,````CT8```H```"<1@```@```*=&```$
M````JD8```8```"O1@``!0```+9&```#````O$8```D```#`1@``"@```,I&
M```%````U48```8```#;1@``"````.)&```(````ZT8``!$```#T1@``&0``
M``9'```1````($<``!@````R1P``$P```$M'```<````7T<``!$```!\1P``
M#P```(Y'```"````GD<``!$```"A1P``$@```+-'```7````QD<```(```#>
M1P``!````.%'```1````YD<```8```#X1P``&````/]'```3````&$@```(`
M```L2```#````"](```1````/$@```T```!.2```!P```%Q(```%````9$@`
M`"4!``!J2```+0```)!)``!%````ODD``!L````$2@``(0```"!*```>````
M0DH``#T```!A2@``:@```)]*```2````"DL```4````=2P``%0```"-+```)
M````.4L``!4```!#2P``,@```%E+```R````C$L``!,```"_2P``"@```--+
M```2````WDL``#````#Q2P``$@```"),```V````-4P``!L```!L3```+0``
M`(A,```J````MDP``"<```#A3```&`````E-```>````(DT``#````!!30``
M$@```')-```8````A4T``$(```">30``*````.%-```8````"DX``!L````C
M3@``'@```#].```G````7DX``#X```"&3@``&````,5.```,````WDX``"0`
M``#K3@``'@```!!/```2````+T\``!(```!"3P``&P```%5/```,````<4\`
M`!X```!^3P``%0```)U/``"!````LT\``"T````U4```*@```&-0```V````
MCE```!@```#%4```$@```-Y0```D````\5```!@````640``&P```"]1```>
M````2U$``!4```!J40``$@```(!1```8````DU$``!(```"L40``&P```+]1
M```)````VU$``!(```#E40``)````/A1```,````'5(```\````J4@``30``
M`#I2```;````B%(``!L```"D4@``"0```,!2```>````RE(``!@```#I4@``
M6`````)3```\````6U,``!X```"84P``*@```+=3```8````XE,```,```#[
M4P``&````/]3```5````&%0``!@````N5```$@```$=4```2````6E0``!(`
M``!M5```%0```(!4```P````EE0``!X```#'5```$@```.94``!1````^50`
M``D```!+50``)````%55```,````>E4```D```"'50``+0```)%5```/````
MOU4``"$```#/50``'@```/%5```J````$%8``!@````[5@``"0```%16```A
M````7E8``#,```"`5@``)````+16```>````V58``!L```#X5@``'@```!17
M```8````,U<``!@```!,5P``0@```&57``!1````J%<``!4```#Z5P``2@``
M`!!8```(````6U@```P```!D6```%0```'%8```/````AU@``!X```"76```
M$@```+98```2````R5@``!4```#<6```#P```/)8```\`````ED``$(````_
M60``N0```()9```,````/%H``!(```!)6@``(0```%Q:```M````?EH``"T`
M``"L6@```@```-I:```;````W5H``"<```#Y6@``#````"%;```,````+EL`
M`#$````[6P``&````&U;```,````AEL``!X```"36P``'@```+);```8````
MT5L``!X```#J6P``&`````E<```&````(EP``!L````I7```&````$5<```\
M````7EP``%$```";7```#P```.U<```M````_5P``!(````K70``&P```#Y=
M```;````6ET``!L```!V70``&````))=```G````JUT``!(```#370``,```
M`.9=``!H````%UX``"H```"`7@``,````*M>```8````W%X```\```#U7@``
M&`````5?```8````'E\``!(````W7P``+P```$I?```U````>E\``"D```"P
M7P``.0```-I?```D````%&```!X````Y8```$@```%A@```J````:V```$(`
M``"68```(0```-E@```2````^V```!(````.80``&P```"%A```/````/6$`
M`"$```!-80``#P```&]A```;````?V$``!(```";80``#P```*YA```M````
MOF$``"0```#L80``#````!%B```2````'F(``#<````Q8@``,P```&EB``!&
M````G6(```8```#D8@``&P```.MB```5````!V,``!@````=8P``&P```#9C
M```>````4F,``!(```!Q8P``)````(1C```8````J6,``!X```#"8P``!@``
M`.%C```S````Z&,```\````<9```'````"QD```5````260``!X```!?9```
M#P```'YD```G````CF0``!(```"V9```(0```,ED```2````ZV0``"$```#^
M9```&P```"!E```$````/&4```P```!!90``%0```$YE```2````9&4``$T`
M``!W90``$@```,5E```/````V&4```\```#H90``40```/AE```8````2F8`
M`"H```!C9@``$@```(YF```G````H68``!X```#)9@``$@```.AF```5````
M^V8``"$````19P``&````#-G```A````3&<``!(```!N9P``0@```(%G```/
M````Q&<``!X```#49P``%0```/-G```5````"6@``"0````?:```&P```$1H
M```8````8&@``!(```!Y:```'@```(QH```8````JV@```\```#$:```%0``
M`-1H```5````ZF@```P`````:0``#P````UI```@````'6D``!L````^:0``
M$@```%II```2````;6D``"<```"`:0``)P```*AI```2````T&D``"0```#C
M:0``,P````AJ```8````/&H``!L```!5:@``&````'%J```D````BFH```P`
M``"O:@``=0```+QJ```8````,FL``!(```!+:P``#P```%YK```/````;FL`
M`!(```!^:P``$@```)%K```;````I&L``$\```#`:P``(0```!!L```)````
M,FP```D````\;```&P```$9L```D````8FP``!(```"';```"0```)IL```)
M````I&P```D```"N;```)````+AL```M````W6P```D````+;0``'@```!5M
M```"````-&T``!(````W;0``*@```$IM```5````=6T``!4```"+;0``&```
M`*%M```8````NFT```\```#3;0``%0```.-M```,````^6T``!L````&;@``
M$@```")N```;````-6X``!L```!1;@``&````&UN```,````AFX``!(```"3
M;@``$@```*9N```)````N6X``"$```##;@``&````.5N```2````_FX``!<`
M```1;P``#P```"EO```5````.6\``!4```!/;P``'@```&5O```@````A&\`
M`!4```"E;P``&P```+MO```5````UV\``#D```#M;P``-@```"=P```V````
M7G```#````"5<```&P```,9P```2````XG```"0```#U<```'@```!IQ```/
M````.7$``!4```!)<0``#````%]Q```5````;'$``!@```""<0``+0```)MQ
M```2````R7$```D```#<<0``)P```.9Q```D````#G(``"<````S<@``-@``
M`%MR```5````DG(``"H```"H<@``%0```--R```D````Z7(``!4````.<P``
M(0```"1S```)````1G,```D```!0<P``!@```%IS```/````87,``"$```!Q
M<P``10```)-S```2````V7,```\```#L<P``&````/QS```)````%70``"<`
M```?=```%0```$=T```/````770```P```!M=```&P```'IT```V````EG0`
M``\```#-=```10```-UT``!"````(W4``!4```!F=0``$@```'QU```2````
MCW4``!X```"B=0``#P```,%U```8````T74``"H```#J=0``(0```!5V```G
M````-W8``"P```!?=@``&P```(QV```/````J'8``!(```"X=@``#P```,MV
M``!F````VW8``!(```!"=P``$@```%5W```\````:'<``!(```"E=P``&P``
M`+AW```8````U'<``!L```#M=P``$@````EX```2````''@``"0````O>```
M$@```%1X```D````9W@``!(```",>```)P```)]X```;````QW@```P```#C
M>```$@```/!X```,`````WD```D````0>0``*@```!IY``!!````17D``"<`
M``"'>0``)P```*]Y```2````UWD``"<```#J>0``%0```!)Z```P````*'H`
M`"$```!9>@``$@```'MZ```2````CGH``!4```"A>@``+0```+=Z```M````
MY7H``!H````3>P``#````"Y[```M````.WL``!@```!I>P```P```()[```>
M````AGL``"P```"E>P``(0```-)[``!$````]'L``$T````Y?```$@```(=\
M```A````FGP``!4```"\?```,P```-)\```D````!GT``#$````K?0``%0``
M`%U]```M````<WT``#,```"A?0``)P```-5]```A````_7T``!X````??@``
M#P```#Y^``!$````3GX``"$```"3?@``#````+5^```/````PGX```\```#2
M?@``%0```.)^```2````^'X``!(````+?P``'@```!Y_```8````/7\``!L`
M``!6?P``#````')_```;````?W\``!L```";?P``)````+=_```5````W'\`
M`#8```#R?P``@````"F````2````JH```!@```"]@```*@```-:````;````
M`8$``!X````=@0``&````#R!```A````58$``!L```!W@0``&P```).!```M
M````KX$``!(```#=@0``$@```/"!```2`````X(``"0````6@@``$@```#N"
M```;````3H(``$<```!J@@``)````+*"```5````UX(``!(```#M@@``1@``
M``"#```/````1X,``#\```!7@P``40```)>#```5````Z8,``"T```#_@P``
M&````"V$```D````1H0``!X```!KA```$@```(J$```8````G80```8```"V
MA```D0```+V$```;````3X4``$L```!KA0``&````+>%```&````T(4``!@`
M``#7A0``$@```/"%```;`````X8``!4````?A@``#P```#6&``!$````188`
M`!@```"*A@``#P```*.&```<````LX8``"0```#0A@``,@```/6&```;````
M*(<```,```!$AP``!````$B'```>````38<``!L```!LAP``,P```(B'```G
M````O(<``!T```#DAP``(0````*(```P````)(@``"<```!5B```6@```'V(
M```,````V(@``!X```#EB```(0````2)```V````)HD``!L```!=B0``)```
M`'F)```;````GHD``$4```"ZB0``+0````"*```R````+HH``"T```!AB@``
M%0```(^*```/````I8H``"$```"UB@``#````->*```G````Y(H```P````,
MBP``0@```!F+```,````7(L``$8```!IBP``/@```+"+```2````[XL```D`
M```"C```(0````R,```D````+HP``"0```!3C```/P```'B,```M````N(P`
M``\```#FC```$````/:,```J````!XT``$L````RC0``40```'Z-```"````
MT(T```0```#3C0``(0```-B-```/````^HT``!,````*C@``*@```!Z.```D
M````28X```8```!NC@``&````'6.```A````CHX```P```"PC@``5````+V.
M``!1````$H\``$X```!DCP``8P```+./``!4````%Y```&````!LD```2P``
M`,V0``!"````&9$```(```!<D0``2````%^1```W````J)$``$4```#@D0``
M"````":2```/````+Y(``$4````_D@``$@```(62``!7````F)(``#D```#P
MD@```@```"J3```J````+9,``#D```!8DP``,````)*3```A````PY,```4`
M``#EDP```0```$8```#S`0``N``````````S`0```0$``/X````=`@``U@$`
M```````I`0``!0(``-(!````````)@````````"S`````````$P```"[````
MV````),```"S`0``#0(```````!4`0``Y@```)$```#&````,@(``,4`````
M````40```%(!```=`0````````````!%````^P```.(!```(`@``(P```"4"
M````````IP```(,!``"9````YP$``!8"```_`@``PP$```,!``"D`0``````
M`-\!``"P````P````%D````.`@``,0$`````````````U0```,<```"/`0``
M0`$```````#J`0``E@```%8````````````````````:`@``D@```'0!``#1
M````@@```.\```"`````+0```)H!``#E`0``R0```#(!```=`````````-,`
M```H`@``=P```/4!``#Z````JP```/D!`````````````'4!````````[`$`
M`,H`````````U0$``+$!```\`0``B````"\!``"B````9@$``!<"```F`0``
M`````$8!`````````````.L````M`0```````#<"``````````````````#O
M`0```````)8!`````````````-,!``#0`0``\@````````"/``````````H"
M``!J`0``.`$``"0````.`````````+H!``"C`````````#X```!Y`0``````
M````````````[@````````!)`0``M0`````````S````WP````````">````
M`````/`!``!O````4`$``.,```">`0````````@```!M`0``B`$`````````
M``````````````"+`0``^`````````"^````&P(```````!P````80```&``
M```+`@``AP````D```";``````````````!V````'@(``+T!```#````$`(`
M``````!O`0``Z`$``"H````O`````````*P```!8`0```````'4````H`0``
M#P```'8!``!R````GP```-$!``!I````L@```/\```#M`0``HP$``,0````,
M`````````$0!``"A`0````````````!-````0@````````"$````-0(`````
M``#!``````````````"T````X0$````````?````H`$```````"_`0``,`(`
M``````"*````J@```-D!````````+`(``%0````>`0``0P$``+@!````````
M````````````````NP$```````"2`0``)P````````#M````EP```*8```!@
M`0``I````#L!``#W````-````)L!``#@`0``/0(```````!G````.0``````
M````````F`$``!,!``#,`0``K@````````!D````KP```*4```##````N0$`
M`*(!``#D`````````#H"````````C````%,!``"%`0``2@```'$````X````
M80$``%H`````````1P```#,"``!*`0```````.P`````````'`$``!4"```T
M`@``!````#`!```T`0```````/$```"M````O`$``-H`````````````````
M`````````````,8!```7````3`$``*8!``"5````JP$``"D```!+`0``(0(`
M`'T!``!(````;0```$0"````````@0$``'0```#G````"P$```P!```\````
M;`$````````U`````0(``"0!``!-`0```````-H!```?`0``H````!H`````
M````]P$``#8!``":```````````````#`@```````$(!``"!````"0$``&(!
M``#^`0``R`$``"0"````````W`$``.4`````````.@$````````V`@``7`$`
M`"(```!N`````````(T```!0````Q`$``.(`````````+`$``!8```!S`0``
MF`````````"#````10$``#L```!K````J@$``$`"``#``0``K`$``"<!``!5
M`0``)0$``"8"````````"@```/P!``````````````<!``"``0``6P$`````
M``#Z`0```````,T`````````?````$0`````````X````)P```#T`0``&0``
M`%\```!>`0``T@```.D!``",`0``N@```'@`````````3@``````````````
MC@$``/,````+````%0$``-D```!+````F0$``!<!``#*`0``MP```*@!````
M````=P$``"L"``"0````70```%P````9`0``*0(``"<"````````$@``````
M``"3`0``AP$``/(!```[`@``:P$``/P``````````````((!```&`@``````
M```````&````&0(`````````````6P```!$"````````7P$``%X````Y`@``
M!0$``"P```#I````RP```%,`````````E0$``!(!``#_`0``#P$``.X!````
M`@```````*T!```R````-0$``,\```#0````'`(``#D!``!:`0```````",!
M``#.`0``3@$``/@!``!"`@``\0$``$,"`````````````',`````````````
M`"X```!B```````````````*`0```````-L```#U````X0```/0```!Y````
M`````/D```````````````(!``!7`0``K@$```(```#"`0``IP$``.@`````
M````D0$``(8```"I````/0$``!,"``#.`````````)0````@`0``$P```","
M```8`0```````.,!```_`0``>`$``+X!````````````````````````P0$`
M`(T!````````U`$``-X!``#K`0``!`(```````"=`0``S````(D````'`@``
M%````%4```"V`0``KP$``!@"``!D`0```````&4`````````,````%D!``"R
M`0``(0````````#7````!0````````!1`0``4@```#H````N`0```````)\!
M```4`@``L0```"L```"E`0``?@````````!C`0````````````#'`0``RP$`
M`!\"``#)`0```````-X```!\`0``Y@$``$,```"T`0```````/T!````````
M$0````````"W`0``9P$``+4!````````A@$``"T"````````70$``'(!``"+
M````\`````8!```\`@```````-@!`````````````+T```#%`0``U````/L!
M``!!`@```````.H```"H````H0```$<!``")`0``(````$@!````````````
M`-8`````````;@$``+\```!E`0```````"H"```Q`@``0````)`!```)`@``
MSP$````````H```````````````_````W0```/8````@`@``5P```'$!``!I
M`0``(@$``(0!`````````````!("``"7`0``J0$``'X!```W````00``````
M``!P`0```````!L````0`0`````````!```B`@``+P(``$$!``#]````C@``
M`"$!```1`0``N0```&@!```X`@``"`$``-T!``"\````;````'T````-`0``
M%`$``!X``````````````!H!``#;`0``20```'H!```^`0```````!4````8
M````)0````<```![`0```````#T```!J````>@```)T`````````R```````
M``!6`0``$`````````!C````#0```"H!```K`0```@(```````!_`0``+@(`
M```````Q``````````````![``````````````"*`0``UP$``,(````/`@``
ME`$``#<!```6`0```````-P``````````````,T!``!8````?P```#X"``!/
M````L`$```0!``"%````3P$````````.`0``&P$``+8````V``````````P"
M``!H````G`$``.0!````````'````/8!`````````````&8`````("@E<R!D
M87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I
M`"`H>65S=&5R9&%Y*0`B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N`"5D("5S(&%N9"`E<P`E<R!+0@`E<R!-
M0@`E<SH@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@
M1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!8F]U="XN+@!!8V-O=6YT($EN
M9F]R;6%T:6]N`$%D9`!!9&0@=7-E<@!!9&1R97-S`$%D9')E<W,@0F]O:P!!
M9&UI;FES=')A=&EO;@!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI
M87,`06QI9VX`06QL`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%M97)I8V%N
M(%-A;6]A`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N=&%R8W1I8V$`06YT
M:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<')I;`!!<F%B:6,@*%=I
M;F1O=W,M,3(U-BD`07)G96YT:6YA`$%R;65N:6$`07)U8F$`071T<FEB=71E
M<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:&5N=&EC871I;VX@9F%I
M;&5D`$%Z97)B86EJ86X`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A
M:&%M87,`0F%H<F%I;@!"86YG;&%D97-H`$)A<F)A9&]S`$)E;&%R=7,`0F5L
M9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0F]L
M9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R<P!";W-N:6$@86YD
M($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA
M;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N
M96D@1&%R=7-S86QA;0!"=6QG87)I80!"=7)K:6YA($9A<V\`0G5R=6YD:0!#
M4D,`0V%L96YD87(`0V%M8F]D:6$`0V%M97)O;VX`0V%N861A`$-A;F-E;`!#
M87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#87EM86X@27-L86YD<P!#96YT
M97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-H860`0VAA;F=E`$-H:6QE
M`$-H:6YA`$-H<FES=&UA<R!)<VQA;F0`0VQE87(`0VQE87(@475E<GD`0VQO
M<V4@5VEN9&]W`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&]M8FEA`$-O
M;&]R`$-O;6UA;F0`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A
M;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I<FT@16UA
M:6P@061D<F5S<P!#;VYF:7)M(&YE=R!E;6%I;"!A9&1R97-S`$-O;F=O`$-O
M;FYE8W1I;VX@9F%I;&5D+@!#;VYT86-T<P!#;VYT:6YU90!#;V]K($ES;&%N
M9',`0V]P>0!#;W-T82!2:6-A`$-O=6YT<GD`0W)E871E`$-R;V%T:6$`0W5B
M80!#=7)R96YT(%1I;64`0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#>7!R=7,`0WER:6QL:6,@
M*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WIE8V@@4F5P=6)L
M:6,`1$0`1&%I;'D`1&%T90!$87D`1&5C96UB97(`1&5C<F5A<V4@26YD96YT
M`$1E9F%U;'0`1&5L971E`$1E;&5T92!C;VQU;6X`1&5L971E(')O=P!$96YM
M87)K`$1E<V-R:7!T:6]N`$1E=F5L;W!M96YT`$1I<F5C=&]R>0!$:FEB;W5T
M:0!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A
M8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$>6YA;6EC($UA:6P`12U-86EL
M`$5C=6%D;W(`161I=`!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16UA
M:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`
M16UO=&EC;VYS`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17-T
M;VYI80!%=&AI;W!I80!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`S
M,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X96-U=&4`17AP86YD`$5X<&]N96YT`$9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A>`!&96)R=6%R>0!&
M:6II`$9I;&4`1FEL92!.86UE`$9I;'1E<G,`1FEN;&%N9`!&;&EP`$9L;V%T
M`$9O;G0@0V]L;W(`1F]R;7,`1G)A;65S`$9R86YC90!&<F5N8V@@1W5I86YA
M`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M`$9R;VT`1G5L;"!.86UE`$=A8F]N`$=A;6)I80!'96]R9VEA`$=E<FUA;GD`
M1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`
M1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD
M`$=R96YA9&$`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5I
M;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2&%I=&D`2&5A9&5R`$AE
M861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE:6=H
M=`!(96QP`$AI9V@`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD
M=7)A<P!(;VYG($MO;F<`2'5N9V%R>0!)4"!!9&1R97-S`$EC96QA;F0`26-O
M;G,@3VYL>0!);6%G97,`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&]N97-I
M80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!486)L90!);G1E9V5R`$ER87$`
M27)E;&%N9`!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA
M;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*;W)D86X`2G5L
M>0!*=6YE`$IU<W1I9GD`2V%Z86MH<W1A;@!+96YY80!+97D@3&5N9W1H`$ME
M>2!4>7!E`$MI<FEB871I`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ
M<W1A;@!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8P!,871V:6$`3&%Y;W5T`$QE8F%N;VX`3&5F=`!,97-O=&AO`$QE=F5L`$QI
M8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI
M;FL`3&EN:W,`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C871I;VX`3&]G(&EN
M`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]V90!,;W<`3'5X96UB;W5R
M9P!-30!-86-A;P!-861A9V%S8V%R`$UA:6P`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%R8V@`36%R9VEN`$UA<G-H86QL($ES;&%N
M9',`36%R=&EN:7%U90!-875R:71A;FEA`$UA=7)I=&EU<P!-87D`36%Y;W1T
M90!-96UB97)S`$UE<W-A9V4`365T:&]D`$UE>&EC;P!-:61D;&4`36EM92!4
M>7!E`$UI<G)O<@!-:7-C96QL86YE;W5S`$UO;F%C;P!-;VYG;VQI80!-;VYT
M:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]R;V-C;P!-;W9E($1O
M=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V
M92!U<`!-;WIA;6)I<75E`$UY86YM87(`3F%M90!.86UI8FEA`$YA=7)U`$YE
M<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='=O<FL`
M3F5V97(`3F5W($-A;&5D;VYI80!.97<@365S<V%G92!T;R`E<P!.97<@6F5A
M;&%N9`!.97<@<&%S<W=O<F0`3F5W<P!.97=S9W)O=7!S`$YE>'0`3FEC87)A
M9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;VYE`$YO<F9O;&L@
M27-L86YD`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T97,`
M3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$]+`$]B:F5C
M=`!/8W1O8F5R`$]F9FEC90!/;&0@<&%S<W=O<F0`3VUA;@!/<&5N(&EN(&$@
M;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W1H97(`4&%D
M9&EN9P!086MI<W1A;@!086QA=0!086YA;6$`4&%P=6$@3F5W($=U:6YE80!0
M87)A9W5A>0!087-S=V]R9`!087-S=V]R9#H`4&%S=&4`4&%T:`!096]P;&4`
M4&5R8V5N=`!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,`4&5R<V]N86P@26YF;W)M871I
M;VX`4&5R=0!0:&EL:7!P:6YE<P!0:&]N90!0:71C86ER;@!0:7AE;',`4&]L
M86YD`%!O<G1U9V%L`%!R97-S=7)E`%!R979I97<`4')O:F5C=',`4'5B;&EC
M($ME>0!0=65R=&\@4FEC;P!1871A<@!1=65R>0!1=6]T80!296%D`%)E9G)E
M<V@`4F5F<F5S:"!R871E.@!296QO860`4F5M87)K<P!296UO=F4`4F5S970`
M4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)I9VAT`%)O;&4`
M4F]M86YI80!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W<SH`4G5N`%)U
M<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4U-(`%-A:6YT($AE;&5N80!386EN
M="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!3
M86UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3875D:2!!
M<F%B:6$`4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E87)C:"!%;F=I;F5S
M`%-E;&5C="!A(&1A=&4`4V5L96-T(&%L;`!396QE8W0@;F]N90!396YE9V%L
M`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E
M<@!397-S:6]N<P!3970`4V5T=7``4V5Y8VAE;&QE<P!3:&]W`%-H<FEN:P!3
M:65R<F$@3&5O;F4`4VEG;F%T=7)E`%-I;F=A<&]R90!3:7IE`%-L;W9A:VEA
M`%-L;W9E;FEA`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O=71H($%F<FEC
M80!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD
M<P!3<&%C:6YG`%-P86EN`%-P86T`4W)I($QA;FMA`%-T86YD87)D`%-T871U
M<P!3=')I:V5T:')O=6=H`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C
M97-S`%-U9&%N`%-U;6UA<GD`4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M
M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I
M='IE<FQA;F0`4WER:6%N($%R86(@4F5P=6)L:6,`5&%B;&4`5&%B;&4@4')O
M<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486II:VES=&%N`%1A
M<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<&5R871U<F4`5&5X=`!497AT($]N
M;'D`5&AA:6QA;F0`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI
M<R!M97-S86=E('!A<G0`5&EM90!4:6UE(&9O<FUA=`!4:71L90!4;P!4;V1A
M>0!4;V=O`%1O:V5L874`5&]N9V$`5&]P`%1R:6YI9&%D(&%N9"!4;V)A9V\`
M5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`55),`%523#H`
M56=A;F1A`%5K<F%I;F4`56YD97)L:6YE`%5N9FEL960`56YI8V]D92`H551&
M+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E
M9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M`%5N:71S`%5N:VYO=VX`56YN86UE9`!5<&1A=&4`57!L;V%D`%5R=6=U87D`
M57-E<@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97)N86UE`%5S97)N86UE.@!5
M>F)E:VES=&%N`%9A;&ED:71Y`%9A;'5E<P!686YU871U`%9A<FEA8FQE`%9E
M;F5Z=65L80!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6:65W("5S`%9I<F=I
M;B!)<VQA;F1S+"!5+E,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V5B
M`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5S=&5R
M;B!386AA<F$`5VED=&@`5VED=&@Z`%=I<VAL:7-T`%=O<FL@061D<F5S<P!7
M;W)K(%!H;VYE`%E9`%E965D`665A<FQY`%EE;65N`%EE<P!9;W5R($YA;64`
M675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`7TQO9R!O=70`861D
M<F5S<V5E('5N:VYO=VX`8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN
M;W0@;W!E;B!I;G!U=`!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG
M=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A
M=&$@9F]R;6%T(&5R<F]R`&5N=')Y(&YO="!F;W5N9`!H:`!H;W-T(&YA;64@
M=6YK;F]W;@!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@
M97)R;W(`;6T`;F%M90!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L`'-E<G9I8V4@=6YA=F%I;&%B;&4`<W,`<WES
M=&5M(&5R<F]R`'1E;7!O<F%R>2!F86EL=7)E`'5N:VYO=VX@97)R;W(`=6YN
M86UE9`!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($E-4`I03U0M0W)E871I
M;VXM1&%T93H@,C`P-"TQ,BTP."`Q,#HR."LP,3`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#4M,#8M,34@,3$Z-3,K,#<P,`I,87-T+51R86YS;&%T;W(Z($QE
M86YG($-H=6US;V)E;B`\<V]B96Y`:VAM97)O<RYI;F9O/@I,86YG=6%G92U4
M96%M.B!+:&UE<B`\<W5P<&]R=$!K:&UE<F]S+FEN9F\^"DU)344M5F5R<VEO
M;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UU=&8M
M.`I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*"5S(.&>D.&?
MDN&>A.&?@^*`B^&>@.&>D^&?DN&>F^&>A.*`B^&>D>&?A2D`("CAGH+AGY+A
MGIKAGK;AGI3AGXOB@(OAGH7AGKOAGH7B@(OAGI7AGY+AGIOAGKSAGISB@(OA
MGH#AGK;AGH_AGXL@)7,I`"`HX9Z0X9^2X9Z$X9^#XH"+X9Z3X9^!X9^'*0`@
M*.&>D.&?DN&>A.&?@^*`B^&>G^&?DN&>HN&?@N&>@"D`("CAGICAGY+AGI_A
MGK?AGIOAGICAGXGAGK?AGHDI`"(E<R(@X9Z8X9ZWX9Z3XH"+X9Z8X9^"X9Z3
MXH"+X9Z'X9ZVXH"+X9Z0X9Z/XH"+X9ZAX9Z^X9Z9PJ#AGY0`(B5S(B#AGICA
MGK?AGI/B@(OAGICAGX+AGI/B@(OAGH?AGK;B@(OAGH?AGICAGY+AGIKAGK[A
MGI_B@(OAGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSAGISB@(OAGJ'AGK[A
MGIG"H.&?E``E9"`E<R#AGI/AGK?AGH0@)7,`)7,@2T(`)7,@X9Z8X9^!X9Z`
MX9ZVX9Z4X9^#`"5S(.&?EB`E<P`M+2#AGH?AGY+AGIKAGK[AGI\@+2T`X9Z1
MX9^2X9Z:X9Z$X9^+X9Z1X9^2X9Z:X9ZVX9Z9(.&?H>&?HB#AGICAGXGAGX3A
MGH0`X9Z1X9^2X9Z:X9Z$X9^+X9Z1X9^2X9Z:X9ZVX9Z9(.&?HN&?I"#AGICA
MGXGAGX3AGH0`X9^BX9^D(.&>F.&?B>&?A.&>A``\X9Z8X9Z[X9Z3`.&>HN&?
MAN&>EN&>N.*`BRXN+@#AGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGJ+AGX;A
MGI;AGKCAGH+AGH[AGI/AGK@`X9Z4X9Z3X9^2X9Z0X9^"X9Z8`.&>E.&>D^&?
MDN&>D.&?@N&>F.*`B^*`B^*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>
MO@#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,`X9Z?X9^`X9Z<X9Z7X9^%
MXH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3`.&>@.&>MN&>FN*`B^&>
M@N&?DN&>FN&>E.&?B^*`B^&>@N&?DN&>FN&>A`#AGJ+AGK;AGJ#AGY+AGH+A
MGK;AGI/AGKCAGI_AGY+AGI#AGK;AGI,`X9ZBX9ZVX9Z;X9^+X9Z4X9ZVX9Z3
MX9ZX`.&>HN&>MN&>F^&?B^&>H.&?DN&>G^&?@>&>FN&>N`#AGHCAGY+AGICA
MGX3AGX?B@(OAGH#AGY+AGIOAGX+AGH3AGH#AGY+AGIOAGK;AGID`X9Z/X9Z8
MX9^2X9Z:X9ZYX9Z8`.&>D>&>MN&?AN&>A.*`B^&>HN&>G^&?BP#AGI3AGY+A
MGHKAGKSAGIKB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGJ+A
MGXKAGKCAGICAGX+AGIL`X9Z?X9ZVX9Z8X9Z\X9ZBX9ZV(.&>HN&>MN&>F.&?
M@>&>FN&>M^&>@`#AGJ+AGH3AGXOAGHKAGKSAGIKAGXGAGK8`X9ZBX9Z$X9^+
MX9Z@X9^2X9Z"X9^$X9ZAX9ZV`.&>HN&>A.&?B^&>H.&?DN&>G^&?BN&>N.&>
MH>&>M@#AGI?AGK;AGH+B@(OAGH'AGK;AGH3B@(OAGH_AGY+AGI3AGKSAGH0`
MX9ZBX9Z$X9^+X9Z1X9ZXX9Z@X9^2X9Z"X9ZV(.&>D^&>M^&>A"#AGI3AGK;A
MGI3AGXKAGKOAGIGAGHKAGK8`X9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZX`.&>
MF.&?@>&>G^&>M@#AGJ+AGK;AGIKAGXGAGK;AGI3AGXL@*%=I;F1O=W,M,3(U
M-BD`X9ZBX9ZVX9Z@X9^2X9Z?X9Z$X9^+X9Z1X9ZXX9Z3`.&>HN&>MN&>F.&?
M@>&>D^&>N`#AGJ+AGK;AGIKAGKSAGI3AGK8`X9Z"X9Z[X9Z.X9Z;X9Z`X9^2
MX9Z!X9Z.X9^(`.&>G^&>N.&>H.&>M@#AGJ+AGKSAGI_AGY+AGH_AGY+AGIKA
MGK;AGIOAGK@`X9ZBX9Z\X9Z1X9^2X9Z:X9ZXX9Z?`.&>@.&>MN&>FN*`B^&>
ME>&?DN&>D>&?@.&>A.*`B^&>E>&?DN&>D>&>MN&>C^&?B^*`B^&>E^&>MN&>
MEN*`B^&>C^&?DN&>FN&>N>&>F.*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>
MMN&>D^*`B^&>E.&>FN&>MN&>A^&?D.&>F0#AGJ+AGK;AGJ#AGY+AGI_AGXKA
MGX+AGIKAGI3AGX+AGJ#AGY+AGI_AGH3AGXL`X9Z5X9^2X9Z1X9^#XH"+X9Z!
MX9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9`.&>EN&>CN&?C.*`B^&>E>&?DN&>
MD>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F0#AGI3AGK;AGJ#A
MGK;AGICAGXGAGK;AGI\`X9Z4X9ZVX9Z:X9^)X9^"X9Z3`.&>E.&>A.&?B^&>
M@.&?DN&>F^&>MN&>BN&?@>&>G^&?DN&>H`#AGI3AGK;AGIKAGI3AGK;AGHKA
MGKSAGI\`X9Z4X9^!X9ZAX9ZVX9Z:X9Z[X9Z?X9^2X9Z?`.&>E.&?@N&>F^*`
MB^&>H.&?DN&>G^&?BN&>M^&>@`#AGI3AGX'AGIOAGKCAGJ#AGY+AGI\`X9Z4
MX9^!X9Z.X9ZVX9^&X9Z$`.&>E.&?BN&?@>&>FN&>F.&>O.&>BN&>M@#AGI3A
MGXKAGKSAGH_AGK;AGI,`X9Z0X9^2X9Z$X9^#X9Z`X9^&X9Z.X9Z^X9Z/`.&>
MBN&>M^&>CP#AGI3AGKSAGIOAGKCAGISAGK@`X9Z`X9Z3X9^2X9Z;X9^"X9Z$
MXH"+X9Z%X9^&X9Z.X9ZVX9^&`.&>G^&?BN&>N^&>F`#AGI_AGXKAGKOAGICB
M@(L`X9Z4X9Z\X9Z?X9^2X9Z3X9^*X9ZX(.&>D^&>M^&>A"#AGJ#AGKKAGJ#A
MGY+AGI_AGXKAGX'AGJ#AGY+AGH+AGX3AGISAGKCAGH[AGK8`X9Z1X9ZVX9^&
MX9Z$XH"+X9Z6X9ZXX9Z:XH"+`.&>E.&>N^&>C^&>G^&?DN&>G.&>MN&>CN&>
MM@#AGI3AGK;AGH\`X9Z`X9^$X9^'XH"+X9Z4X9^*X9Z\X9Z<X9^)X9^"`.&>
ME.&?DN&>FN&?@>&>G^&?BN&>N.&>FP#AGJ+AGK;AGH[AGK;AGH7AGH#AGY+A
MGIKB@(OAGI_AGICAGKOAGI'AGY+AGIKB@(OAGJ7AGH[AGY+AGHSAGK8@X9ZB
MX9Z$X9^+X9Z"X9^2X9Z;X9^!X9Z?`.&>E.&?DN&>FN&?BN&>N^&>F>&>CN&?
M@>*`B^&>BN&>MN&>FN&?BN&>N^&>F>&>G^&>MN&>H>&>MN&>F`#AGI3AGXKA
MGKOAGIOAGJ#AGY+AGH+AGK;AGIKAGK@`X9Z4X9^*X9Z\X9Z:X9Z"X9ZXX9Z.
MX9ZVX9Z@X9^2X9Z<X9ZVX9Z?X9Z\`.&>E.&?BN&>O.&>FN&>N^&>D^&>C.&>
MN`!#4D,`X9Z4X9^2X9Z:X9Z/X9ZWX9Z1X9ZWX9Z3`.&>@.&>F.&?DN&>EN&>
MN^&>A^&>M@#AGH#AGK;AGICAGXGAGK;AGIKAGKSAGI,`X9Z`X9ZVX9Z.X9ZV
MX9Z*X9ZV`.&>E.&?A.&?A^&>E.&>A.&?BP#AGH#AGK;AGI3AGISAGX+AGIH`
MX9Z%X9^&X9Z.X9Z$X9Z'X9Z^X9Z$`.&>G.&>C^&?DN&>D.&>N^*`B^&>BN&>
MN>&>@.*`B^&>A^&>B>&?DN&>A^&>O.&>DP#AGH#AGX3AGX?B@(OAGH#AGX/A
MGICAGXGAGK;AGI,`X9Z`X9Z.X9^2X9Z/X9ZVX9Z;`.&>G^&>MN&>DN&>MN&>
MFN&>CN&>FN&>BN&?DN&>B^*`B^&>HN&>MN&>H.&?DN&>G.&?DN&>FN&>M^&>
M@.*`B^&>@.&>CN&?DN&>BN&>MN&>FP#AGH;AGK;AGHH`X9Z5X9^2X9Z;X9ZV
MX9Z?X9^+XH"+X9Z4X9^2X9Z/X9Z\X9Z:`.&>B.&>N.&>F^&>N`#AGH7AGK?A
MGI,`X9Z`X9^$X9^'XH"+X9Z"X9^2X9Z:X9ZXX9Z?X9^2X9Z/X9Z8X9^)X9ZV
MX9Z?`.&>A^&>F.&?DN&>FN&?AP#AGH?AGICAGY+AGIKAGX?B@(OAGI_AGX;A
MGH[AGKWAGIH`X9Z4X9ZWX9Z1XH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%`.&>@.&?
MA.&?A^*`B^&>@.&>O.&>@.&>O"`HX9Z#X9ZXX9Z;X9ZXX9Z$*0#AGH#AGKSA
MGJ'AGKOAGX;AGI3AGXKAGK@`X9Z6X9Z.X9^,`.&>EN&>MN&>@.&?DN&>F>*`
MB^&>E.&>B>&?DN&>A^&>M@#AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OB@(OA
MGJ+AGI+AGK?AGI3AGY+AGI3AGK;AGID`X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z2
MX9Z8X9^2X9Z8X9Z/X9ZV`.&>@.&>N^&?AN&>F.&?B>&>O.&>FN&?B>&>O.&>
MGP#AGH#AGY+AGIKAGKOAGICAGJ#AGXKAGKOAGI,`X9Z`X9Z[X9^&X9Z6X9^2
MX9Z9X9Z\X9Z1X9^0X9Z:`.&>F^&>@.&?DN&>@>&>@>&>CN&?DN&>C`#AGIOA
MGH#AGY+AGH'AGH'AGH[AGY+AGHP`X9ZBX9^'X9ZBX9ZVX9Z$XH"+X9ZBX9ZV
MX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;`.&>
MHN&?A^&>HN&>MN&>A.*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`
MB^&>HN&?BN&>N.&>F.&?@N&>F^*`B^&>D.&?DN&>F.&>N`#AGH#AGKOAGH3A
MGJ#AGY+AGH+AGX0`X9Z`X9ZVX9Z:XH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+
MXH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9XH"+PJ#AGY0`0V]N
M=&%C=',`X9Z4X9Z3X9^2X9Z/`.&>@.&?A.&?A^*`B^&>@.&>O.&>@`#AGH7A
MGICAGY+AGIOAGH0`X9Z`X9Z\X9Z?X9^2X9Z/X9ZVX9Z:X9ZXX9Z`X9ZV`.&>
ME.&?DN&>FN&>D>&?@>&>GP#AGI3AGH3AGY+AGH#AGK[AGH\`X9Z`X9^2X9Z:
MX9Z\X9ZBX9ZVX9Z/`.&>@N&>N^&>F>&>E.&>M@#AGI;AGX'AGIOB@(OAGISA
MGX'AGIOAGK;B@(OAGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+AGI,`
MX9Z:X9Z%X9Z3X9ZVX9Z4X9^0X9Z1X9^2X9Z8XH"+X9Z4X9Z%X9^2X9Z%X9Z[
MX9Z4X9^2X9Z4X9Z3X9^2X9Z3XH"+`.&>E.&?DN&>C^&>O.&>FN*`B^&>E^&>
MMN&>FN&>@.&>M^&>A>&?DN&>A>*`B^&>BN&?@N&>F^*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>FN&>C^&?B^*`B^&>C^&>MN&>F.*`B^&>E.&?AN&>CN&>A"#A
MGJ+AGK;AGI_AGY+AGIKAGY#AGIGB@(OAGIOAGK[B@(OAGH#AGK;AGIKB@(OA
MGH7AGKSAGIOB@(OAGI'AGX7B@(L@)7,@X9^4`.&>@.&>MN&>C^&?BP#AGI_A
MGXKAGKCAGI;AGIKAGXT`X9Z?X9^*X9ZXX9Z:X9ZXX9Z;X9ZXX9Z`("A+3TDX
M+5(I`.*`B^*`B^&>G^&?BN&>N.&>FN&>N.&>F^&>N.&>@"`H5VEN9&]W<RTQ
M,C4Q*0#AGI_AGK;AGI+AGK;AGIKAGH[B@(OAGIKAGHKAGY+AGHOB@(OAGH;A
MGX'AGH``1$0`X9Z:X9ZVX9Z;X9^+XH"+X9Z0X9^2X9Z$X9^#`.&>@.&>MN&>
MF^*`B^*`B^&>E.&>FN&>M^&>A>&?@>&?DN&>AN&>D0#AGI#AGY+AGH3AGX,`
MX9Z2X9^2X9Z3X9Z\`.&>E.&>D^&?DN&>D.&>F2#AGH7AGKSAGIOB@(OAGI3A
MGI/AGY+AGI'AGK;AGH_AGXL`X9Z;X9^&X9Z3X9ZVX9^&X9Z*X9Z^X9Z8`.&>
MF^&>N^&>E.*`BP#AGIOAGKOAGI3B@(OAGH?AGKWAGIKB@(OAGHCAGIH`X9Z;
MX9Z[X9Z4XH"+X9Z'X9Z]X9Z:X9Z*X9^!X9Z``.&>BN&>MN&>CN&>NN&>F.&?
MB>&>MN&>@`#AGH#AGK;AGIKAGI;AGK?AGI;AGH[AGXSAGI/AGK8`XH"+X9ZB
MX9Z7X9ZWX9Z<X9Z,X9^2X9Z-`.&>D.&>CP#AGJ#AGY+AGI_AGXKAGKCAGI3A
MGKSAGI'AGK@`X9Z*X9Z\X9Z8X9ZXX9Z3X9ZXX9Z`X9ZV`.&>G^&>MN&>DN&>
MMN&>FN&>CN&>FN&>BN&?DN&>B^*`B^&>BN&>O.&>F.&>N.&>D^&>N.&>@.&?
M@N&>DP#AGICAGK?AGI/B@(OAGICAGK;AGI/B@(OAGH+AGH[AGI/AGKC"H#\@
MX9Z?X9Z\X9Z8XH"+X9Z%X9Z[X9^'X9Z(X9^2X9Z8X9^$X9^'PJ#AGY0`X9Z1
MX9ZVX9Z)X9Z9X9Z``.&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>D.&>MN&>
MF.&>G.&>D^&?DN&>CP#AGJ+AGXKAGKCAGICAGX+AGIL`X9ZBX9^!X9Z`X9^2
MX9Z<X9ZVX9Z,X9^0X9Z:`.&>@.&?@N*`B^&>G^&>F.&?DN&>FN&>O>&>FP#A
MGH#AGK;AGIKB@(OAGJ+AGI3AGXOAGIKAGX8`X9ZBX9^!X9Z@X9^2X9Z?X9^*
MX9ZXX9Z4`.&>HN&?@N&>F^&>G^&>MN&>F^&?B^&>G.&?B>&>MN&>C.&?D.&>
MF@#AGJ+AGXKAGKCAGICAGX+AGIL`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZV
MX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;`.&>HN&>MN&>G^&>F>&>BN&?DN&>
MB^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>
MG.*`B^&>C^&?@N*`B^&>BN&>O.&>A>&>@N&?DN&>D^&>ML*@X9^4`.&>G^&>
MB>&?DN&>B>&>MN*`B^&>HN&>MN&>FN&>F.&?DN&>F.&>CN&?C0#AGJ#AGY+A
MGH+AGKCAGH[AGX'B@(OAGJ+AGX'AGH#AGY+AGISAGK;AGI'AGY#AGIH`X9ZB
MX9^!X9Z:X9ZXX9Z1X9^2X9Z:X9ZV`.&>@.&?AN&>H.&>N^&>GP#AGJ+AGX'A
MGI_AGY+AGH_AGKSAGI/AGK@`X9ZBX9^!X9Z/X9^2X9Z9X9Z\X9Z6X9ZX`.&>
MHN&>NN&>FN&?B>&>N^&>E`#AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXOB@(L@
MX9^AX9^E(.&>D^&>MN&>D>&>N`#AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXOB
M@(L@X9^CX9^@(.&>G.&>M^&>D^&>MN&>D>&>N`#AGIKAGX#AGH3B@(OAGIKA
MGK;AGIOAGXL@X9^E(.&>D^&>MN&>D>&>N`#AGIKAGX#AGH3B@(OAGIKAGK;A
MGIOAGXOB@(OAGH#AGI/AGY+AGIOAGX?B@(OAGICAGXGAGX3AGH0`X9Z:X9^`
MX9Z$XH"+X9Z:X9ZVX9Z;X9^+X9Z3X9ZVX9Z1X9ZX`.&>E.&?DN&>FN&>C^&>
MM^&>E.&>C^&?DN&>C^&>MP#AGI3AGI/AGY+AGIOAGK;AGID`X9ZBX9^*X9ZW
MX9Z%X9Z?X9^2X9Z4X9Z\X9Z.X9Z$X9^+X9Z?X9^"X9Z;`.&>@.&?A.&?A^*`
MB^&>H.&?DN&>G.&?B>&>@.&>H>&>A.&?BR`HX9Z8X9^)X9ZVX9Z;X9^+X9Z<
MX9ZXX9Z.X9ZV*0#AGH#AGX3AGX?AGJ#AGY+AGISAGK;AGJ+AGX'AGIKAGKP`
MX9Z1X9Z\X9Z:X9Z?X9ZVX9Z:`.&>@.&>N^&>F.&?DN&>E^&?B`#AGJ#AGY+A
MGISAGKCAGJ#AGY+AGI_AGXKAGK@`X9ZOX9Z`X9Z?X9ZVX9Z:`.&>B.&?DN&>
MF.&?A.&?A^*`B^&>K^&>@.&>G^&>MN&>F@#AGH_AGICAGY+AGIKAGH0`X9Z@
MX9^2X9Z<X9ZVX9^&X9Z$X9ZAX9Z$X9^+`.&>C^&?DN&>FN&>H>&>E.&?BP#A
MGI'AGI_AGI?AGK;AGH(`X9Z6X9Z.X9^,XH"+X9Z6X9Z[X9Z8X9^2X9Z6XH"+
MX9ZBX9Z`X9^2X9Z?X9Z:`.&>G^&?AN&>CN&>N^&?AN*`B^*`B^&>E.&?@N&>
ME.&>E.&>D0#AGI_AGXKAGKOAGI@`X9Z4X9ZVX9Z:X9ZVX9^&X9Z$`.&>H.&?
MDN&>@N&>O.&>HN&?BN&>N.&>F>&?B>&>MN&>CN&>MB#AGI3AGK;AGIKAGK;A
MGX;AGH0`X9Z4X9^)X9Z\X9Z;X9ZXX9Z3X9^!X9Z?X9^*X9ZXXH"+X9Z4X9ZV
MX9Z:X9ZVX9^&X9Z$`.&>HN&>MN&>CN&>A>&>@.&?DN&>FN*`B^&>@>&>MN&>
MA.*`B^&>C^&?DN&>E.&>O.&>A"#AGI3AGK;AGIKAGK;AGX;AGH0`X9Z6X9ZX
M`.&>B.&?DN&>F.&?A.&?A^*`B^&>EN&?@>&>B0#AGJ#AGY+AGH+AGK;AGI3A
MGKOAGH0`X9Z@X9^2X9Z`X9ZVX9^&X9Z4X9^*X9ZX`.&>H.&?DN&>G^&>@.&>
MH.&?DN&>G^&?BN&>N`#AGJ+AGK;AGIOAGY+AGIOAGKKAGICAGXGAGH3AGXL`
MX9Z@X9^2X9Z`X9ZVX9Z.X9ZV`.&>H.&?DN&>@N&>N.&>E.&?DN&>FN&>MN&>
MF^&?B^&>C^&>M@#AGI/AGK;AGICAGH'AGY+AGIOAGKWAGI,`X9Z'X9Z8X9^2
MX9Z:X9Z^X9Z?XH"+X9Z?X9Z`X9Z;`.&>D>&?A0#AGICAGK;AGH_AGY+AGIKA
MGHKAGY+AGHOAGK;AGI/B@(OAGI3AGY+AGIKAGI7AGX'AGX<`X9Z`X9^2X9Z:
MX9ZWX9Z``.&>@.&?DN&>FN&>M^&>@"`H25-/+3@X-3DM-RD`X9Z"X9^2X9Z:
MX9ZXX9ZAX9Z$X9^+`.&>H.&?DN&>@N&?DN&>FN&>N.&>CN&>MN&>BN&>M@#A
MGH#AGY+AGIKAGKOAGI@`X9Z@X9^2X9Z"X9Z\X9ZBX9ZVX9Z*X9ZZX9Z;X9Z\
MX9Z4X9^)X9^!`.&>H.&?DN&>@N&>MN&?AN&>F`#AGJ#AGY+AGH+AGK;AGH_A
MGX'AGICAGXGAGK;AGJ'AGK8`X9Z@X9^2X9Z"X9ZXX9Z.X9^!`.&>H.&?DN&>
M@N&>N.&>CN&?@>&>E.&?BN&>N.&>G^&?A0#AGJ#AGY+AGH+AGKCAGIGAGXGA
MGK;AGH[AGK8`2%1-3`#AGJ#AGX/AGI'AGK@`X9Z4X9Z+X9Z8X9Z`X9Z0X9ZV
MXH"+`.&>E.&>B^&>F.&>@.&>D.&>M@#AGH#AGX3AGX?B@(OAGJ#AGXKAGK[A
MGHH@X9Z3X9ZWX9Z$(.&>@.&?A.&?A^*`B^&>F.&?B>&>MN&>@.&>BN&>O.&>
MCN&>MN&>F^&?BP#AGH#AGICAGY+AGI;AGI_AGXL`X9Z'X9^&X9Z3X9Z]X9Z9
M`.&>@>&?DN&>EN&>G^&?BP#AGJ#AGKSAGIOAGKCAGI_AGXKAGK@@*.&>FN&>
MBN&?DN&>B^*`B^&>@.&?DN&>FN&>N^&>A.*`B^&>G.&?B>&>MN&>D>&>N.&>
M@.&>A.&?BRD`X9Z"X9^!X9Z@X9Z1X9^&X9Z6X9^0X9Z:`.&>HN&>MN&>G^&>
MF>&>BN&?DN&>B^&>MN&>D^*`B^&>E>&?DN&>D>&?AP#AGI#AGH_AGI7AGY+A
MGI'AGX<`X9Z1X9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1XH"+X9Z5X9^2X9Z1X9^'
M`.&>H.&>N^&>A.&>C.&>O.&>FN&?B>&>MN&>G^&?BP#AGJ#AGKOAGH3AGH#A
MGKOAGH0`X9Z@X9Z[X9Z$X9Z"X9^2X9Z:X9ZX`.&>HN&>MN&>G^&>F>&>BN&?
MDN&>B^&>MN&>D^*`BR!)4`#AGJ+AGXKAGKCAGI_AGY+AGIOAGH3AGXL`X9Z/
MX9^"XH"+X9Z:X9Z\X9Z4X9Z/X9^&X9Z.X9ZVX9Z$`.&>FN&>O.&>E.&>E^&>
MMN&>E@#AGI3AGH3AGY+AGH#AGK[AGI/B@(OAGH#AGK;AGIKB@(OAGH7AGKSA
MGIOB@(OAGI3AGI/AGY+AGI'AGK;AGH_AGXL`X9ZEX9Z.X9^2X9Z,X9ZV`.&>
MI>&>CN&?DN&>C.&>O.&>D^&?@>&>G^&?BN&>N`#AGI;AGY#AGH_AGXSAGICA
MGK;AGI,`X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3`.&>E.&>B>&?DN&>A>&>O.&>
MF^*`B^&>C^&>MN&>FN&>MN&>A`#AGH7AGX;AGI/AGKWAGI/B@(OAGH+AGH_A
MGXL`X9ZBX9^*X9ZXX9Z:X9^)X9ZVX9Z`X9^+`.&>HN&?@.&>FN&>H>&>A.&?
MBP#AGJ+AGXKAGKCAGI_AGY+AGIKAGK;AGJ+AGX+AGIL`X9ZBX9^2X9Z3X9Z`
MXH"+X9Z%X9^!X9Z)`.&>D>&?DN&>FN&?@>&>CP#AGJ+AGXKAGKCAGH_AGK;A
MGIOAGK@`X9Z%X9ZVX9Z8X9^)X9^#X9Z`X9ZV`.&>F.&>@.&>FN&>M@#AGH?A
MGI3AGXGAGKOAGI,`XH"+X9Z'X9Z4X9^)X9Z[X9Z3("A)4T\M,C`R,BU*4"D`
MX9Z@X9^2X9Z?X9^*X9Z`X9Z*X9ZVX9Z3X9ZX`.&>@.&>@.&?DN&>@.&>BN&>
MM@#AGICAGK?AGI#AGKOAGI/AGK8`X9Z/X9Z8X9^2X9Z:X9ZYX9Z8XH"+X9Z?
MX9Z$XH"+X9Z!X9ZVX9Z$`.&>@.&>MN&>H.&?DN&>G^&>MN&>@.&?B^&>G^&?
MDN&>C^&>A.&?BP#AGH#AGX+AGI/AGIGAGXGAGK8`X9Z4X9^2X9Z:X9Z<X9^"
MX9Z$XH"+X9Z`X9Z\X9Z3X9Z?X9^$`.&>E.&?DN&>FN&>E^&?@>&>D>*`B^&>
M@N&?DN&>FN&>MN&>E.&?B^*`B^&>A>&>N^&>A0#AGH+AGK?AGIKAGK?AGI3A
MGK;AGI'AGK@`XH"+X9Z`X9Z\X9Z:X9^)X9^!("A%54,M2U(I`.&>@N&>N^&>
MF>*`B^&>G.&?B>&?@N&>CP#AGH+AGX#AGIKAGJ#AGY+AGH+AGKCAGI_AGY+A
MGH_AGH3AGXL`X9Z7X9ZVX9Z?X9ZV`.&>G^&>MN&>DN&>MN&>FN&>CN&>FN&>
MBN&?DN&>B^*`B^&>E.&?DN&>FN&>A^&>MN&>DN&>M^&>E.&>C^&?@>&>F>&?
MDN&>F>*`B^&>E.&?DN&>FN&>A^&>MN&>F.&>MN&>D^&>M^&>C^*`B^&>H>&>
MMN&>G`#AGJ'AGK;AGH_AGISAGKCAGIGAGXGAGK8`X9Z4X9^2X9Z;X9Z$X9^+
MXH"+`.&>F^&>N.&>E.&>A.&?BP#AGH;AGY+AGISAGX'AGH0`X9ZAX9^!X9Z?
MX9Z\X9Z/X9Z\`.&>@.&>F.&?DN&>FN&>M^&>CP#AGIOAGKCAGI3AGX'AGIKA
MGKCAGIGAGXGAGK8`X9Z%X9ZVX9Z8X9^)X9ZVX9ZBX9^*X9ZWX9Z:X9ZXX9Z9
MX9^)X9ZVXH"+X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+(.&>F^&>N.&>E.&?BN&>
MN`#AGIOAGK?AGH7AGI'AGX'AGI/AGI_AGY+AGH_AGX+AGI,`X9Z/X9^&X9Z.
M`.&>C^&?AN&>C@#AGIOAGKCAGI'AGKOAGIGAGJ+AGK;AGI/AGK@`X9Z`X9^&
MX9Z6X9Z[X9Z$XH"+X9Z5X9^2X9Z1X9Z[X9Z`+BXN`.&>D>&>N.&>C^&>MN&?
MAN&>A`#AGH7AGKSAGIL`X9Z%X9^!X9Z)`.&>A>&>O.&>FP#AGI?AGK;AGIKA
MGH#AGK?AGH7AGY+AGH7B@(OAGH7AGKSAGIL`X9Z?X9^!X9Z%X9Z`X9^2X9Z/
MX9ZXXH"+X9Z?X9^2X9Z:X9ZAX9ZVX9Z)X9^+`.&>D>&>MN&>E`#AGIOAGKOA
MGH7AGJ#AGY+AGI_AGX;AGI3AGKWAGIH`34T`X9Z8X9^)X9ZVX9Z`X9ZVX9Z<
M`.&>F.&?B>&>MN&>BN&>MN&>H.&?DN&>@.&>MN&>G^&?DN&>@.&>MN&>F@#A
MGI_AGX;AGI3AGKOAGH_AGY+AGIH`X9Z8X9^)X9ZVX9ZAX9ZVX9Z<X9^#`.&>
MF.&?B>&>MN&>H>&?@>&>G^&?BN&>N`#AGICAGXGAGK;AGIOAGXOAGHSAGKCA
MGIP`X9Z8X9^)X9ZVX9Z;X9ZX`.&>F.&?B>&>MN&>F^&?B^&>C^&>M@#AGICA
MGKCAGI/AGK8`X9Z:X9ZYX9Z8XH"+X9Z1X9^&X9Z6X9^0X9Z:`.&>@.&?A.&?
MAR!-87)S:&%L;`#AGICAGXGAGK;AGIKAGI'AGKCAGI/AGKCAGH(`X9Z8X9^)
MX9Z\X9Z:X9ZXX9Z/X9ZVX9Z3X9ZX`.&>F.&?B>&>O.&>FN&>N.&>D>&>N^&>
MGP#AGJ?AGI_AGI?AGK8`X9Z8X9^#X9ZBX9Z\X9Z/X9^!`.&>G^&>F.&>MN&>
MA^&>M^&>@`#AGI_AGK;AGIH`X9Z<X9ZWX9Z2X9ZXX9Z?X9ZVX9Z?X9^2X9Z:
MX9^2X9Z/`.&>F.&?B>&>M^&>A>&>G^&?BN&>M^&>@`#AGH#AGH[AGY+AGH_A
MGK;AGIL`X9Z4X9^2X9Z:X9Z7X9^!X9Z1($UI;64`X9Z&X9^2X9Z;X9Z[X9^'
M`.&>E>&?DN&>G^&?@>&>A.&?E^*`BP#AGICAGXGAGKSAGH[AGK;AGH#AGKP`
MX9Z8X9^)X9Z[X9Z$X9Z@X9^2X9Z"X9^$X9Z;X9ZX`.&>@>&?@B#AGI/AGK?A
MGH0@X9Z&X9^2X9Z3X9ZVX9^&`.&>FN&>MN&>F^&?B^*`B^&>@>&?@@#AGICA
MGXGAGKOAGH3AGI_AGX'AGIKAGXGAGK8`X9Z8X9^)X9ZVX9Z:X9^)X9Z[X9Z`
M`.&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`B^&>A>&>N^&?A^*`B^&>
M@.&?DN&>FN&?A.&>F`#AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OA
MGI'AGX7B@(OAGH;AGY+AGISAGX'AGH0`X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+
MX9Z1X9ZXXH"+X9Z1X9^%XH"+X9Z?X9^2X9Z/X9ZVX9^&`.&>E>&?DN&>F^&>
MMN&>G^&?B^*`B^&>D>&>N.*`B^&>H>&>ON&>A.*`B^&>F^&>O@#AGH7AGKOA
MGX?B@(OAGH#AGY+AGIKAGX3AGI@`X9ZAX9Z^X9Z$XH"+X9Z;X9Z^`.&>F.&?
MB>&>O.&>H.&?DN&>G^&>MN&?AN&>E.&?BN&>M^&>@`#AGICAGKCAGIGAGXGA
MGK;AGI/AGXOAGICAGXGAGK8`X9Z(X9^2X9Z8X9^$X9^'`.&>CN&>MN&>F.&>
MN.&>E.&?BN&>N`#AGH[AGKSAGIKAGKL`X9Z3X9^!X9Z4X9^)X9ZVX9Z;X9^+
M`.*`B^&>H.&>N^&>F^&?DN&>F^&>A.&?BP#AGJ+AGH3AGXOAGI'AGKCAGIGA
MGXWB@(OAGJ#AGKSAGIOAGY+AGIOAGH3AGXL`X9Z4X9Z.X9^2X9Z/X9ZVX9Z)
M`.&>@.&>N^&?A@#AGI/AGKSAGISAGX+AGIOAGH#AGK;AGIOAGX'AGHKAGKSA
MGI/AGK@`X9Z?X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZXXH"+X9Z1X9^%("5S`.&>
MD^&>O.&>G.&?@N&>F^&>H.&?BN&?DN&>G^&?@>&>H>&>A.&?BP#AGI;AGK;A
MGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;AGH_AGXOB@(OAGI#AGY+AGICA
MGK@`X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3`.&>G.&?@>&>D>&>M^&>@.&>MN*`
MB^&>EN&?D.&>C^&?C.&>F.&>MN&>DP#AGI3AGI/AGY+AGI'AGK;AGI3AGXL`
MX9Z3X9ZXX9Z`X9ZVX9Z:X9^)X9ZVX9Z@X9^2X9Z"X9^0X9Z:`.&>D^&>N.&>
MH.&?DN&>G^&?@>&>F@#AGI/AGKCAGJ#AGY+AGI_AGX'AGIKAGKCAGIGAGXGA
MGK8`X9Z9X9Z4X9^+`.&>D^&>N.&>G`#AGI'AGX$`X9Z"X9^2X9Z8X9ZVX9Z3
M`.&>@.&?A.&?A^*`B^&>CN&?B>&>H.&?DN&>G.&?B>&>@`#AGH#AGX3AGX?B
M@(OAGICAGXGAGK;AGIKAGX#AGH[AGK;B@(OAGI?AGK;AGH+B@(OAGH'AGK;A
MGH3B@(OAGH?AGK[AGH0`X9Z3X9^0X9Z:X9Z<X9^"X9Z?`.&>A>&?AN&>CN&>
MMN&?A@#AGISAGK?AGH7AGY+AGH;AGK?AGH#AGK8`X9Z;X9^!X9Z!`.&>A>&?
MAN&>D^&>O>&>D^*`B^&>C^&>O>&>HN&>@.&?DN&>G^&>F@#AGIGAGIOAGXOA
MGI;AGY+AGIKAGI@`X9Z<X9Z/X9^2X9Z0X9Z[`.&>C^&>N^&>F^&>M@#AGH#A
MGK;AGIKAGK?AGIGAGK;AGIOAGY#AGID`X9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?
MX9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z%X9ZVX9Z?X9^+`.&>HN&>O.&>F.&?
M@N&>DP#AGI3AGK[AGH#B@(OB@(OAGH#AGY+AGI/AGKOAGH3B@(OB@(OAGI3A
MGH3AGY+AGJ+AGKWAGH7B@(OAGI#AGY+AGICAGK@`X9Z4X9^2X9Z:X9Z6X9^0
MX9Z3X9^2X9Z2XH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z4X9Z/X9^2X9Z/X9ZWX9Z`
MX9ZVX9Z:`.&>A^&>F.&?DN&>FN&>ON&>G^*`BP#AGI7AGY+AGI_AGX'AGH3A
MGY<`X9Z%X9Z3X9^2X9Z;X9^$X9^'`.&>E.&?B>&>MN&>@N&>N.&>G^&?DN&>
MD.&>MN&>DP#AGI3AGXGAGK;AGJ'AGKP`X9Z4X9^)X9ZVX9Z.X9ZVX9Z8X9^)
MX9ZV`.&>E.&?B>&>MN&>EN&>O.&>B>&>O.&>G.&>H.&?DN&>@N&>N.&>CN&?
M@0#AGI3AGXGAGK;AGIKAGXGAGK;AGJ#AGY+AGH+AGK;AGID`X9Z6X9ZVX9Z`
MX9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+`.&>EN&>MN&>@.&?DN&>
MF>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B\*@X9^6`.&>E.&>M^&>D>&>E^&?
MDN&>A^&>MN&>E.&?BP#AGI7AGY+AGIOAGKSAGIP`X9Z8X9Z3X9Z[X9Z?X9^2
MX9Z?`.&>E^&>MN&>@N&>FN&>F0#AGI+AGY+AGISAGK[B@(OAGI3AGY+AGIKA
MGH_AGK?AGI3AGH_AGY+AGH_AGK?AGH#AGK;AGIKB@(OAGH_AGX;AGJ#AGX+A
MGI'AGK;AGX8@X9Z6X9^!X9Z;XH"+X9Z%X9Z\X9Z;(#\`X9Z?X9ZWX9Z1X9^2
MX9Z2X9ZW`.&>G^&>M^&>D>&?DN&>DN&>MP#AGI;AGY#AGH_AGXSAGICAGK;A
MGI/B@(OAGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI,`X9Z4
MX9^)X9^!X9Z:X9^)X9Z\`.&>H.&?DN&>G.&>N.&>F^&>N.&>EN&>N.&>DP#A
MGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI$`X9Z6X9ZXX9Z/X9Z!X9ZVX9Z9X9Z:
MX9ZWX9Z3`.&>E^&>N.&>@.&>G^&?@N&>FP#AGI3AGXGAGKSAGJ'AGKSAGHD`
MX9Z6X9^0X9Z:X9Z1X9Z[X9Z9X9Z@X9^2X9Z"X9ZVX9Z;X9^+`.&>G^&>F.&?
MDN&>EN&>MN&>D@#AGICAGK[AGIOB@(OAGH?AGK;B@(OB@(OB@(OAGICAGKOA
MGI,`X9Z"X9Z8X9^2X9Z:X9^$X9Z$`.&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>
MMN&>DN&>MN&>FN&>CN&?B`#AGI;AGY#AGIKAGH_AGKSAGIKAGKCAGH#AGKP`
MX9Z`X9ZVX9Z/X9ZV`.&>G^&?AN&>CN&>O>&>FN*`BP#AGH#AGKSAGH_AGK8`
MX9ZBX9ZVX9Z3`.&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>G^&?DN&>
MFN&>G^&?BP#AGJ+AGH_AGY+AGIKAGK;B@(OAGI+AGY+AGISAGK[B@(OAGK+A
MGY+AGIGB@(OAGI_AGY+AGIKAGI_AGXO"H.&?E@#AGI7AGY+AGI'AGKOAGH#B
M@(OAGJ'AGK[AGH3B@(OAGISAGK?AGHD`X9Z`X9^&X9Z.X9Z/X9^+XH"+X9Z?
MX9Z8X9^2X9Z"X9ZVX9Z;X9^+`.&>F>&>@.*`B^&>A>&?@>&>B0#AGH#AGX;A
MGH[AGH_AGXOB@(OAGJ'AGK[AGH3B@(OAGISAGK?AGHD`X9Z;X9Z1X9^2X9Z2
MXH"+X9Z5X9Z;`.&>C^&?DN&>FN&>H>&>E.&?B^*`B^&>D>&?A>*`B^&>A^&>
MF.&?DN&>FN&>ON&>GP#AGIKAGKCAGJ+AGKOAGIGAGI/AGKCAGIGAGXGAGKOA
MGH0`XH"+X9Z?X9^2X9Z/X9ZVX9^&`.&>C^&>O>&>D^&>MN&>D>&>N`#AGIKA
MGKSAGICAGXGAGK;AGI/AGK@`X9Z4X9Z$X9^2X9Z<X9ZWX9Z;XH"+X9Z1X9^%
MXH"+X9Z&X9^2X9Z<X9^!X9Z$`.&>E.&>A.&?DN&>G.&>M^&>F^*`B^&>D>&?
MA>*`B^&>G^&?DN&>BN&>MN&?A@#AGH?AGKWAGIKB@(OAGHKAGX'AGH#"H.&?
ME@#AGIKAGH_AGXOB@(L`X9Z?X9Z@X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z:X9Z[
MX9Z?X9^2X9Z?X9^*X9ZX`.&>FN&>G.&?B>&>MN&>D^&?B^&>BN&>M@!34T@`
MX9Z?X9Z$X9^+XH"+X9Z@X9^!X9ZAX9^!X9Z.X9ZV`.&>G^&>A.&?B^&>@^&>
MN.&>CR#AGI/AGK?AGH0@X9Z3X9^!X9Z<X9ZXX9Z?`.&>G^&>A.&?B^&>F^&>
MO.&>G^&?BN&>N.&>F>&?B>&>M@#AGI_AGH3AGXOB@(OAGI;AGY+AGIGAGX+A
MGIH@X9Z3X9ZWX9Z$(.&>F.&>N.&>@N&>N^&>F>&>HN&?@>&>H>&>N^&>A`#A
MGI_AGH3AGXOAGISAGK;AGX;AGH3AGI_AGH3AGXL@X9Z3X9ZWX9Z$(.*`B^&>
MH.&?DN&>@N&?DN&>FN&>N.&>CN&>MN&>C.&>N.&>DP#AGI_AGK;AGICAGKSA
MGJ+AGK8`X9Z?X9ZVX9Z3X9^+X9Z8X9^)X9ZVX9Z:X9ZXX9Z.X9Z\`%-A;R!4
M;VUE(&%N9"!0<FEN8VEP90#AGJ+AGK;AGIKAGXGAGK;AGI3AGXOB@(OAGI3A
MGXKAGKCAGI_AGK;AGJ+AGKSAGHSAGK@`X9Z:X9Z`X9^2X9Z?X9ZVXH"+XH"+
MX9Z1X9Z[X9Z`XH"+XH"+`.&>FN&>@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`
MBR#AGH?AGICAGY+AGIKAGK[AGI\`X9Z?X9^2X9Z<X9^"X9Z$X9Z:X9Z``.&>
MF.&?B>&>MN&>G^&?BN&>N.&>D^*`B^&>G^&?DN&>G.&?@N&>A.&>FN&>@`#A
MGH?AGY+AGIKAGK[AGI_B@(OAGH#AGK;AGIOAGI3AGIKAGK?AGH7AGY+AGH;A
MGX'AGI$`X9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z1X9ZVX9^&X9Z$X9ZBX9Z?X9^+
M`.&>A^&?DN&>FN&>ON&>G^*`B^&>@N&?DN&>F.&>MN&>DP#AGI_AGX'AGH[A
MGX'AGJ#AGY+AGH+AGK;AGIOAGXL`X9Z`X9Z)X9^2X9Z)X9ZV`.&>G^&?@N&>
ME.&?BN&>N"#AGI/AGK?AGH0@X9Z8X9^)X9Z[X9Z$X9Z/X9^!X9Z.X9^!X9Z@
MX9^2X9Z`X9^2X9Z:X9Z\`.&>F^&?@>&>@>*`B^&>G^&>F.&?DN&>@N&>MN&>
MF^&?BP#AGI_AGICAGY#AGID`X9Z`X9^&X9Z.X9Z/X9^+`.&>BN&?AN&>H>&>
MON&>A`#AGI_AGKCAGI_AGY+AGJ#AGX+AGIL`X9Z4X9Z$X9^2X9Z@X9ZVX9Z)
M`.&>E.&>A.&?DN&>FN&>O>&>B0#AGI_AGX'AGIKAGXGAGK;AGJ'AGX'AGJ+A
MGKSAGI,`X9Z@X9Z/X9^2X9Z0X9Z;X9^!X9Z!X9ZV`.&>G^&>N>&>A.&?DN&>
MH.&>E.&>N^&>FN&>N`#AGI'AGX;AGJ#AGX8`X9Z?X9^2X9Z;X9Z\X9Z<X9^)
MX9ZVX9Z"X9ZX`.&>G^&?DN&>F^&>O.&>G.&?B>&>MN&>D^&>N`#AGH#AGX3A
MGX?B@(OAGI_AGKSAGJ'AGKSAGICAGXGAGKSAGI,`X9Z?X9Z\X9Z8X9^)X9ZV
MX9Z;X9ZX`.&>HN&>MN&>H.&?DN&>FN&>M^&>@.*`B^*`B^&>@>&>MN&>A.*`
MB^&>C^&?DN&>E.&>O.&>A`#AGJ#AGY+AGI_AGH#AGJ#AGY+AGI_AGXKAGKCB
M@(OAGH'AGK;AGH3B@(OAGH_AGY+AGI3AGKSAGH0@X9Z3X9ZWX9Z$(.&>@.&?
MA.&?A^&>G^&>MN&?AN&>A.&>G.&>M^&>A>*`B^&>@>&>MN&>A.*`B^&>C^&?
MDN&>E.&>O.&>A`#AGH+AGICAGY+AGIOAGK;AGH\`X9ZBX9^!X9Z?X9^)X9^2
MX9Z4X9ZVX9Z)`.&>G^&>MN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>
M@.&>MN&>F@#AGI_AGY+AGIKAGKCAGIOAGH3AGY+AGH#AGK8`X9Z!X9^2X9Z3
MX9ZVX9Z/XH"+X9Z"X9^&X9Z:X9Z\`.&>G^&?DN&>D.&>MN&>D^&>E^&>MN&>
ME@#AGI3AGI/AGY+AGI'AGK;AGH_AGXOB@(OAGH;AGKSAGH\`X9Z4X9^2X9Z:
MX9Z2X9ZVX9Z3XH"+X9Z4X9Z1`.&>BN&>MN&>@.&?B^*`B^&>G^&?DN&>D^&>
MO@#AGJ+AGH#AGY+AGI_AGIKB@(OAGH_AGKSAGH7B@(OAGH#AGY+AGIKAGX3A
MGI@`X9Z'X9^$X9Z"X9Z'X9^0X9Z9`.&>G^&?BN&>O.&>BN&>A.&?BP#AGI_A
MGH3AGY+AGH'AGX'AGI0`X9ZBX9Z`X9^2X9Z?X9Z:XH"+X9Z/X9Z\X9Z%XH"+
MX9Z;X9Z^`.&>@N&>MN&?AN&>D>&?DN&>F@#AGI_AGXKAGKSAGIKAGKCAGH[A
MGK;AGICAGK@`X9Z?X9^2X9Z<X9ZVX9Z;X9^+X9Z4X9ZVX9Z/(.&>D^&>M^&>
MA"#AGJ#AGY+AGI_AGH3AGXOAGICAGXGAGK;AGIGAGX'AGI,`X9Z?X9^2X9Z<
MX9ZVX9Z@X9^2X9Z?X9^*X9ZXX9ZAX9Z$X9^+`.&>G^&?BN&>N^&>F>&>HN&?
M@N&>B@#AGI_AGY+AGISAGXKAGKCAGI\`X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:
MX9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+(.&>G^&?BN&>N.&>
MFN&>N`#AGH_AGK;AGIKAGK;AGH0`X9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z?
MX9Z8X9^2X9Z4X9Z/X9^2X9Z/X9ZWXH"+X9Z/X9ZVX9Z:X9ZVX9Z$`.&>F^&>
M@.&?DN&>@>&>CN&?B.*`B^&>G^&>F.&?DN&>E.&>C^&?DN&>C^&>M^*`B^&>
MFN&>E.&>G^&?B^*`B^*`B^&>C^&>MN&>FN&>MN&>A`#AGH_AGX/AGISAGXGA
MGK;AGI/AGXL`X9Z/X9ZVX9Z*X9Z@X9^2X9Z?X9^*X9ZXX9Z"X9ZXX9Z?X9^2
MX9Z/X9Z$X9^+`.&>E^&>MN&>FN&>@.&>M^&>A>&?DN&>A0#AGIOAGX'AGH'B
M@(OAGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI$`X9Z?X9ZXX9Z/X9Z[X9Z.X9^2
MX9Z@X9Z7X9ZVX9Z6`.&>HN&>C^&?DN&>D.&>E.&>D0#AGH_AGX+AGJ+AGH_A
MGY+AGI#AGI3AGI$`X9Z0X9^#`.&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>N^&>
MG^*`B^&>F.&>O>&>F2#AGH#AGY+AGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OA
MGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI7AGY+AGI/AGX+AGH#B@(OAGIKAGI3A
MGI_AGXOB@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX<`X9Z6X9^!X9Z;XH"+X9Z<
MX9^!X9Z;X9ZVXH"+`.&>D>&?DN&>FN&>A.&?B^*`B^&>D>&?DN&>FN&>MN&>
MF>*`B^*`B^*`B^*`B^&>EN&?@>&>F^*`B^*`B^&>G.&?@>&>F^&>MN*`BP#A
MGH7AGX;AGH[AGH3B@(OAGH?AGK[AGH0`X9Z1X9^%`.&>D.&?DN&>A.&?@^*`
MB^&>D^&?@>&?AP#AGH_AGKSAGJ#AGY+AGH+AGX0`X9Z/X9Z\X9Z`X9^!X9ZA
MX9ZVX9ZBX9^*X9Z\`.&>C^&>N^&>A.&>H.&?DN&>@N&?A`#AGH#AGX;AGI;A
MGKSAGIL`X9Z1X9^2X9Z:X9ZXX9Z3X9ZXX9Z*X9ZVX9Z*(.&>D^&>M^&>A.*`
MB^*`BR#AGH_AGKSAGI3AGK;AGJ#AGY+AGH+AGX0`X9Z1X9Z[X9Z9X9Z.X9^!
MX9Z?X9^*X9ZX`.&>D>&>O>&>FN&>@N&>N`#AGI'AGKWAGIKAGH+AGK@@*$E3
M3RTX.#4Y+3DI`.&>D>&>O>&>@N&>F.&?@>&>D^&>N.&>G^&?DN&>C^&>A.&?
MBP#AGH#AGX3AGX?B@(OAGI'AGKWAGH`@X9Z3X9ZWX9Z$XH"+(.&>@.&?@^&>
M@.&>O.&>GP#AGI'AGKOAGIGAGISAGXGAGK;AGIOAGKOAGID`55),`%523#H`
MX9ZBX9^*X9Z\X9Z@X9^2X9Z"X9Z$X9^+X9Z*X9ZV`.&>HN&?BN&>N^&>F>&>
M@.&?DN&>FN&?@N&>DP#AGH+AGKSAGI_B@(OAGI3AGI/AGY+AGI'AGK;AGH_A
MGXOB@(OAGH#AGY+AGIKAGX3AGI@`X9Z8X9ZWX9Z3XH"+X9Z4X9ZVX9Z3XH"+
MX9Z:X9^`X9Z4X9Z%X9^&`.&>F>&>O.&>D^&>N.&>@.&>O.&>BB`H551&+3@I
M`.&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>FN&>O>&>F`#AGH7AGH#AGY+A
MGIKB@(OAGI?AGI;B@(OAGJ+AGH3AGXOAGH+AGY+AGIOAGX'AGI\`X9Z?X9Z@
MX9Z:X9Z*X9^2X9Z+X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z``.&>@.&?A.&?A^*`
MB^&>AN&?DN&>A.&>MN&>F>&?E^*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>H.&>
MFN&>BN&?DN&>B^*`B^&>HN&>MN&>F.&?@>&>FN&>M^&>@`#AGJ_AGH#AGH_A
MGK8`X9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+`.&>@N&?DN&>F.&>
MMN&>D^*`B^&>B.&?DN&>F.&?A.&?AP#AGI+AGY+AGISAGK[B@(OAGK+AGY+A
MGIGB@(OAGI'AGK;AGI/AGXOB@(OAGI_AGICAGY#AGID`X9Z5X9^2X9Z1X9Z[
MX9Z`XH"+X9ZAX9Z^X9Z$`.&>HN&?BN&>N^&>F>&>FN&?B>&>MN&>H.&?DN&>
M@N&>MN&>F0#AGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKX`X9Z`X9ZVX9Z:
MXH"+X9Z"X9^2X9Z:X9Z4X9^+X9Z"X9^2X9Z:X9Z$XH"+X9ZBX9^2X9Z3X9Z`
MXH"+X9Z4X9^2X9Z:X9Z^`.&>B.&?DN&>F.&?A.&?A^*`B^&>HN&?DN&>D^&>
M@.*`B^&>E.&?DN&>FN&>O@#AGHCAGY+AGICAGX3AGX?B@(OAGJ+AGY+AGI/A
MGH#B@(OAGI3AGY+AGIKAGK["H.&?E@#AGJ+AGXKAGKSAGJ#AGY+AGI_AGI3A
MGX'AGH+AGKCAGI_AGY+AGH_AGH3AGXL`X9Z?X9Z[X9Z6X9Z;X9Z7X9ZVX9Z6
M`.&>C^&>F.&?DN&>F^&?@P#AGISAGXGAGK;AGI/AGKOAGIGAGJ+AGK;AGI'A
MGKOAGID`X9ZBX9Z0X9^!X9Z:`.&>G.&?@>&>CN&?@>&>H.&?DN&>G^&>N^&>
MF>&>HN&?@>&>H>&>M@#AGH#AGX;AGH[AGX(`X9Z`X9ZVX9Z:XH"+X9Z/X9^2
MX9Z:X9Z]X9Z/XH"+X9Z6X9ZWX9Z3X9ZWX9Z/X9^2X9Z9XH"+X9Z`X9^&X9Z.
MX9^"`.&>F.&>ON&>FR`E<P#AGH#AGX3AGX?B@(OAGISAGKCAGH?AGKCAGI,@
MX9Z?X9Z@X9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z``.&>
MG.&?B>&>MN&>F^&>N.&>GR#AGI/AGK?AGH0@X9Z@X9^2X9Z<X9^*X9Z\XH"+
MX9Z1X9Z[X9Z9X9Z.X9ZV`.&>EN&?DN&>FN&>F.&>MN&>DP#AGISAGK?AGI0`
MX9Z/X9^&X9Z4X9Z3X9^+X9Z4X9Z.X9^2X9Z/X9ZVX9Z)`.&>FN&>MN&>F^&?
MB^*`B^&>G^&>E.&?DN&>BN&>MN&>H.&?C0#AGI_AGKSAGICB@(OAGI_AGY+A
MGISAGK;AGH+AGICAGI/AGXT`X9Z?X9Z\X9Z8XH"+X9Z?X9^2X9Z<X9ZVX9Z"
MX9Z8X9Z3X9^-XH"+X9Z8X9Z`XH"+X9Z`X9ZVX9Z3X9^+("5S`.&>G^&>MN&>
MH.&>MN&>FN&?B>&>MN*`B^&>@>&>MN&>A.*`B^&>F^&>M^&>A0#AGI'AGI'A
MGKGAGH3B@(L`X9Z1X9Z1X9ZYX9Z$(.&?E@#AGI3AGHGAGY+AGH?AGKCB@(OA
MGI3AGY+AGIKAGK;AGI#AGY+AGI/AGK8`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+
MX9ZVX9Z3XH"+X9Z`X9Z3X9^2X9Z;X9^"X9Z$XH"+X9Z2X9^2X9Z<X9Z^XH"+
MX9Z`X9ZVX9Z:`.&>D>&>O.&>FN&>G^&?D.&>EN&?DN&>D>*`B^*`B^*`B^&>
M@.&>D^&?DN&>F^&?@N&>A.*`B^*`B^*`B^&>DN&?DN&>G.&>ON&>@.&>MN&>
MF@!960!965E9`.&>E.&?DN&>FN&>A>&>MN&?AN&>AN&?DN&>D^&>MN&?A@#A
MGIGAGX'AGICAGX+AGI,`X9Z4X9ZVX9Z1+^&>A>&>MN&>GP#AGHCAGY+AGICA
MGX3AGX?B@(OAGIKAGI3AGI_AGXOAGJ+AGY+AGI/AGH``X9Z9X9Z\X9Z@X9^2
MX9Z"X9^$X9Z?X9^2X9Z;X9ZVX9Z<X9ZX`.&>G^&?@P#AGJ#AGY+AGI_AGK;A
MGX;AGI3AGXKAGK@`X9Z@X9^2X9Z?X9^*X9ZXX9Z8X9Z4X9ZVX9Z<X9^)X9^!
M`%],X9Z%X9^!X9Z)(`#AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOAGXOB
M@(OAGJ+AGY+AGI/AGH#B@(OAGI'AGI'AGKWAGIOB@(OAGI_AGX;AGI3AGKOA
MGH_AGY+AGIH`X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z$X9^2X9Z`
MX9Z^X9Z/XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z;X9Z1X9^2X9Z2X9Z5X9Z;
M`.&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>E.&>ON&>@.*`B^&>EN&?D.&>
MC^&?C.&>F.&>MN&>D^*`B^&>E.&>B>&?DN&>A>&>O.&>FP#AGH#AGX;AGJ#A
MGKOAGI_B@(OAGH#AGK;AGIKB@(OAGI3AGY+AGIKAGK[B@(OAGI3AGI/AGY+A
MGI'AGK;AGH_AGXOB@(OAGI;AGK;AGH#AGY+AGIGAGI3AGHGAGY+AGH?AGK8`
MX9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9ZVX9Z:XH"+X9Z`X9^&X9Z.X9Z/X9^+
MXH"+X9Z:X9Z%X9Z3X9ZVX9Z?X9Z8X9^2X9Z6X9^0X9Z3X9^2X9Z2`.&>E.&>
MMN&>C^&?B^*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>E.&?DN&>FN&>EN&?D.&>
MD^&?DN&>DN*`B^&>G^&?AN&>@>&>MN&>D^&?B^*`B^&>E.&?AN&>E>&>N^&>
MCP#AGH#AGX;AGJ#AGKOAGI_B@(OAGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKA
MGK;AGIGB@(OAGI'AGK?AGI/AGY+AGI/AGI/AGY#AGID`X9Z:X9Z`XH"+X9Z8
MX9ZWX9Z3XH"+X9Z#X9Z^X9Z)XH"+X9Z2X9ZVX9Z/X9Z[XH"+X9Z4X9Z)X9^2
MX9Z%X9Z\X9Z;`&AH`.&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?B^*`
MB^&>B.&?DN&>F.&?A.&?A^*`B^&>F.&?B>&>MN&>G^&?BN&>N.&>DP#AGH#A
MGX;AGJ#AGKOAGI_B@(OAGI3AGHGAGY+AGH7AGX'AGHDOX9Z4X9Z)X9^2X9Z%
MX9Z\X9Z;`.&>@.&?AN&>H.&>N^&>G^*`B^&>@.&>F.&?DN&>F.&>G.&>M^&>
MDN&>N.*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A0#AGI@NX9Z8+@#AGHCA
MGY+AGICAGX3AGX<`X9Z?X9ZWX9Z1X9^2X9Z2X9ZWXH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z*X9ZWX9Z?X9^!X9Z2`.&>E^&>N.&>
M@.&>G^&?@N&>FP#AGH#AGX;AGJ#AGKOAGI_B@(OAGI;AGKCB@(OAGH7AGICA
MGY+AGH3AGK;AGIGB@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI;AGK?AGI+AGKCA
MGH#AGK;AGIH`X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z:X9Z`XH"+X9Z?
MX9^!X9Z<X9ZVXH"+X9Z4X9ZVX9Z3`'-S`.&>@.&?AN&>H.&>N^&>G^*`B^&>
ME.&?DN&>FN&>EN&?D.&>D^&?DN&>D@#AGI3AGIKAGK;AGH?AGY#AGIGB@(OA
MGI3AGH[AGY+AGHKAGX3AGX?AGJ+AGK;AGI_AGI/AGY+AGI,`X9Z8X9ZWX9Z3
MXH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z`X9^&X9Z@X9Z[X9Z?`.&>@N&?
MDN&>F.&>MN&>D^*`B^&>B.&?DN&>F.&?A.&?AP!V0V%R9```````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]K
M;U]+4B\`````````````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#$V-C<V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+VMO7TM2+TQ#7TU%4U-!1T53+P``````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-P`P,C`T
M-C,`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:V]?2U(O3$-?3453
M4T%'15,O:&]R9&4N;6\`````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4Q,#4U
M`#$P-#$W,S8R-S<W`#`R,C$R-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#>$@25`````(L!```<````=`P``!T"``#,&```
M`````$`A```/````02$```@```!1(0``"P```%HA```,````9B$``"@```!S
M(0``$@```)PA```(````KR$```4```"X(0``$0```+XA```#````T"$```\`
M``#4(0``"````.0A```(````[2$``!D```#V(0``!P```!`B```,````&"(`
M``X````E(@``!0```#0B```%````.B(```H```!`(@```P```$LB```.````
M3R(```\```!>(@``'P```&XB```%````CB(``#D```"4(@``!@```,XB```1
M````U2(```H```#G(@``$````/(B```(`````R,```0````,(P``!@```!$C
M```1````&",```<````J(P``!````#(C```&````-R,```T````^(P``$P``
M`$PC```(````8",```8```!I(P``%0```'`C```'````AB,```H```".(P``
M#P```)DC```-````J2,```\```"W(P``#0```,<C```)````U2,```8```#?
M(P``!@```.8C```.````[2,```4```#\(P``*@````(D```3````+20```P`
M``!!)```$````$XD```1````7R0```4```!Q)```!0```'<D```&````?20`
M``<```"$)```$````(PD```$````G20```X```"B)```*0```+$D```&````
MVR0```T```#B)```#@```/`D```-````_R0```,````-)0``#0```!$E```"
M````'R4```4````B)0``!````"@E```.````+24```@````\)0``#P```$4E
M```/````524```<```!E)0``$````&TE```&````?B4```L```"%)0``#0``
M`)$E```*````GR4``!D```"J)0``%@```,0E```4````VR4```L```#P)0``
M+P```/PE```)````+"8```\````V)@``)@```$8F``!#````;28```@```"Q
M)@``"P```+HF```$````QB8``!<```#+)@``$0```.,F```*````]28```(`
M````)P``!0````,G```)````"2<```T````3)P``#@```"$G```8````,"<`
M``4```!))P``$````$\G```0````8"<```\```!Q)P``"P```($G```/````
MC2<```P```"=)P``#P```*HG```.````NB<```@```#))P``'@```-(G```A
M````\2<```,````3*```"````!<H```,````("@```<````M*```"@```#4H
M```&````0"@```0```!'*```!P```$PH```"````5"@```8```!7*```!```
M`%XH```1````8R@``"(```!U*```#````)@H```*````I2@```4```"P*```
M#P```+8H```2````QB@```L```#9*```*0```.4H```D````#RD``"8````T
M*0``$@```%LI```*````;BD```\```!Y*0``$````(DI```.````FBD```D`
M``"I*0``"@```+,I```2````OBD``!````#1*0``$0```.(I```/````]"D`
M`!0````$*@``#````!DJ```,````)BH```\````S*@``%0```$,J```I````
M62H``"H```"#*@``)@```*XJ```G````U2H``"D```#]*@``*@```"<K```1
M````4BL``!(```!D*P``$P```'<K```4````BRL``!8```"@*P``%P```+<K
M```0````SRL``!$```#@*P``$P```/(K```2````!BP```8````9+```!P``
M`"`L```%````*"P``!8````N+```!````$4L```$````2BP```<```!/+```
M#@```%<L```,````9BP```P```!S+```#0```(`L```2````CBP```\```"A
M+```"````+$L```.````NBP``!8```#)+```$0```.`L```&````\BP```0`
M``#Y+```$````/XL```:````#RT```8````J+0``!P```#$M```+````.2T`
M`!,```!%+0``$P```%DM```3````;2T```(```"!+0``!````(0M```-````
MB2T```4```"7+0``!@```)TM```/````I"T```,```"T+0``"@```+@M```+
M````PRT```<```#/+0``!@```-<M```*````WBT```<```#I+0``"0```/$M
M```'````^RT```0````#+@``!P````@N```%````$"X``!,````6+@``!```
M`"HN```"````+RX``#,````R+@``,P```&8N```X````FBX```0```#3+@``
M!0```-@N```(````WBX``!$```#G+@``#@```/DN```'````""\``!\````0
M+P``!P```#`O```.````."\```P```!'+P``#````%0O```%````82\``!$`
M``!G+P``!P```'DO```(````@2\``!4```"*+P``!0```*`O```4````IB\`
M``0```"[+P``!P```,`O```>````R"\``!0```#G+P``!0```/PO```&````
M`C```"@````),```*0```#(P```'````7#```"$```!D,```#@```(8P```3
M````E3```!<```"I,```"P```,$P```%````S3```!$```#3,```!0```.4P
M```2````ZS````0```#^,```#@````,Q```.````$C$```4````A,0``$@``
M`"<Q```$````.C$```P````_,0``!@```$PQ``!I````4S$``!H```"],0``
M%P```-@Q```7````\#$``!L````(,@``'P```"0R```3````1#(```D```!8
M,@``)0```&(R```@````B#(``"0```"I,@``(````,XR```$````[S(``!``
M``#T,@``'`````4S```H````(C,```<```!+,P``$P```%,S```7````9S,`
M``H```!_,P``#````(HS```)````ES,```T```"A,P``"P```*\S```'````
MNS,```8```##,P``"0```,HS```'````U#,```<```#<,P``"P```.0S```0
M````\#,``!`````!-```!0```!(T```$````&#0```D````=-```"@```"<T
M```?````,C0``!L```!2-```/@```&XT```C````K30``!\```#1-```/0``
M`/$T```A````+S4``!P```!1-0``!0```&XU```0````=#4```(```"%-0``
M$@```(@U```#````FS4``!````"?-0```P```+`U```O````M#4``"````#D
M-0``)`````4V```E````*C8``"````!0-@``)@```'$V```)````F#8```P`
M``"B-@``%P```*\V```.````QS8```T```#6-@``&@```.0V```'````_S8`
M``L````'-P``$P```!,W```3````)S<```P````[-P``"````$@W```4````
M43<```X```!F-P``$````'4W```'````AC<```<```".-P``!@```)8W```'
M````G3<```T```"E-P``"P```+,W```@````OS<``!P```#@-P``!0```/TW
M```2`````S@```H````6.```!@```"$X```,````*#@```H````U.````@``
M`$`X```&````0S@```,```!*.```10```$XX```9````E#@``$4```"N.```
M,````/0X```F````)3D``"4```!,.0``,````'(Y```2````HSD``!,```"V
M.0``$````,HY```)````VSD``',```#E.0``*P```%DZ```7````A3H``!8`
M``"=.@``#P```+0Z``!`````Q#H``!\````%.P``$@```"4[```0````.#L`
M`!,```!).P``'0```%T[```/````>SL```\```"+.P``"P```)L[```%````
MISL``!0```"M.P``"````,([```/````RSL```@```#;.P``#P```.0[```4
M````]#L```8````)/```!````!`\```'````%3P```8````=/```!P```"0\
M```%````+#P``%(!```R/```#````(4]```'````DCT```<```":/0``!P``
M`*(]```7````JCT``!4```#"/0``!P```-@]```)````X#T```L```#J/0``
M!````/8]```3````^ST```\````//@``"P```!\^```4````*SX```0```!`
M/@``!@```$4^```$````3#X```H```!1/@``!````%P^```%````83X```D`
M``!G/@``"````'$^```'````>CX``!<```""/@```P```)H^```7````GCX`
M``,```"V/@``#````+H^```$````QSX```D```#,/@``!````-8^```$````
MVSX```0```#@/@``"0```.4^```$````[SX```0```#T/@``!````/D^```+
M````_CX```P````*/P``!````!<_```$````'#\``!(````A/P``!````#0_
M```&````.3\```<```!`/P``!P```$@_```'````4#\```<```!8/P``!@``
M`&`_```&````9S\```0```!N/P``#@```',_```$````@C\``!4```"'/P``
M%````)T_```'````LC\```T```"Z/P``"P```,@_```$````U#\```,```#9
M/P``!@```-T_```$````Y#\```D```#I/P``!````/,_```$````^#\``"L`
M``#]/P``!@```"E````+````,$````H````\0```"P```$=````&````4T``
M``8```!:0````@```&%````$````9$````0```!I0```"0```&Y````$````
M>$````0```!]0```"````()````$````BT````L```"00```!````)Q````'
M````H4````<```"I0```!P```+%````,````N4````P```#&0```"0```--`
M```%````W4```"H```#C0```"`````Y!```)````%T$``"<````A00``0P``
M`$E!```(````C4$```L```"600``!````*)!```,````IT$```X```"T00``
M!P```,-!```"````RT$```8```#.00``"````-5!```)````WD$```L```#H
M00``#0```/1!```$`````D(```D````'0@``"0```!%"```(````&T(```L`
M```D0@``"0```#!"```$````.D(```,````_0@``#0```$-"```&````44(`
M`!,```!80@``$P```&Q"```$````@$(```,```"%0@``"P```(E"```$````
ME4(```D```":0@``!@```*1"```$````JT(```0```"P0@``!````+5"```$
M````ND(```8```"_0@``!@```,9"```>````S4(```<```#L0@``"P```/1"
M```%`````$,```8````&0P``"0````U#```%````%T,``!,````=0P``#@``
M`#%#```3````0$,```X```!40P``!@```&-#```-````:D,```P```!X0P``
M#@```(5#```(````E$,```D```"=0P``#P```*=#```,````MT,``!````#$
M0P``"````-5#```0````WD,```D```#O0P``!P```/E#```,`````40```X`
M```.1```%P```!U$```7````-40``!<```!-1```%P```&5$```8````?40`
M`!@```"61```#````*]$```,````O$0```P```#)1```#````-9$```.````
MXT0```X```#R1```#`````%%```,````#D4```X````;10``#@```"I%```(
M````.44```,```!"10``!````$9%```4````2T4```,```!@10```P```&1%
M```$````:$4```L```!M10``"0```'E%```)````@T4```L```"-10``"```
M`)E%```/````HD4```0```"R10``$0```+=%```@````R44``!,```#J10``
M"````/Y%```$````!T8```L````,1@``&P```!A&```&````-$8```@````[
M1@``#P```$1&```-````5$8```L```!B1@``$````&Y&```"````?T8```0`
M``""1@``$````(=&```#````F$8```@```"<1@``#0```*5&```#````LT8`
M``D```"W1@``"0```,%&```&````RT8```8```#21@``"````-E&```$````
MXD8```L```#G1@``"0```/-&```$````_48```@````"1P``"`````M'```-
M````%$<```0````B1P``!@```"='```C````+D<``!P```!21P``(0```&]'
M```-````D4<```0```"?1P``!````*1'```'````J4<```<```"Q1P``!```
M`+E'```1````OD<```@```#01P``"P```-E'```)````Y4<```0```#O1P``
M!````/1'```)````^4<```0````#2```!`````A(```9````#4@```8````G
M2```$P```"Y(```$````0D@```8```!'2```$P```$Y(```)````8D@```@`
M``!L2```!````'5(```A````>D@``!X```"<2```"````+M(```0````Q$@`
M``D```#52```"0```-](```0````Z4@```\```#Z2```"0````I)```1````
M%$D```8````F20``#````"U)```$````.DD```<````_20``!P```$=)```#
M````3TD``!(```!320``!````&9)```-````:TD```0```!Y20``.P```'Y)
M```3````NDD```X```#.20``#@```-U)```9````[$D``!\````&2@``&```
M`"9*```#````/TH```X```!#2@``#@```%)*```.````84H``!````!P2@``
M!````(%*```-````ADH```8```"42@``&@```)M*```$````MDH```T```"[
M2@``#@```,E*```'````V$H```<```#@2@``!P```.A*```(````\$H```L`
M``#Y2@``!`````5+```$````"DL```@````/2P``!````!A+```$````'4L`
M``8````B2P``!P```"E+```'````,4L```0````Y2P``!@```#Y+```$````
M14L```D```!*2P``&````%1+```>````;4L``"T```",2P``'@```+I+```?
M````V4L``#\```#Y2P``*0```#E,```8````8TP```0```!\3```#0```(%,
M```)````CTP```X```"93````@```*A,```1````JTP```,```"]3```+0``
M`,%,```>````[TP``!L````.30``)````"I-```H````3TT``"$```!X30``
M!````)I-```1````GTT``!````"Q30``!````,)-```$````QTT``!4```#,
M30``"0```.)-```)````[$T```T```#V30``$`````1.```/````%4X```@`
M```E3@``$````"Y.```)````/TX```D```!)3@``!P```%-.```$````6TX`
M``0```!@3@``!````&5.```6````:DX```X```"!3@``%P```)!.```7````
MJ$X```0```#`3@``"0```,5.```)````STX```4```#93@``"@```-].```-
M````ZDX```(```#X3@``!````/M.```"`````$\``#T````#3P``%````$%/
M```^````5D\``"D```"53P``)0```+]/```E````Y4\``"P````+4```#```
M`#A0```*````15````0```!04```!0```%50``!S````6U```"<```#/4```
M#````/=0```,````!%$```H````140``'P```!Q1```6````/%$```T```!3
M40``#P```&%1```,````<5$``!,```!^40``#@```))1```&````H5$```D`
M``"H40``!@```+)1```.````N5$```H```#(40``#@```--1```*````XE$`
M``T```#M40``#````/M1```#````"%(```0````,4@``!@```!%2```$````
M&%(```D````=4@``!0```"=2```!````]P```&\!````````4P$```````!:
M````K````!<!```@`````````#\````*````RP```(T```!G````Y````"P!
M``#=`````````&D```"Q````>@```*0`````````^0```(8```!B````6`$`
M`!,!```X````````````````````'P$``#,!``#F````^P```+,`````````
MO`````````"C````W@`````````U````/@`````````2`0``@@$``"\```!;
M`0``1`$``%\```!\`0``C@``````````````W````````````````````'X!
M``!=````````````````````````````````````I@```,@```!:`0``J0``
M`$H```#U`````````,P`````````&P```!T!``">````%@````@!``"X````
MUP````(`````````F0```/(````#````TP```-0```#2````=`$``%<```#N
M``````$``&T!``!'`0``R@```````````````````!`!``#J````BP```.P`
M``!Q````)0$``,\`````````!P```"8!````````"````"L```"K````````
M````````````B@```$\!``"4````>`$``!H`````````$@```&T````]`0``
M5````&8`````````3P```#<!``!;````,@$``'T``````````````/P`````
M````J@````````!5`0``%P```(4```!`````BP$``/H`````````H````%8`
M```8`0``F````#P```!+`0``=@```$8```#$`````````#X!````````/0``
M`.(```"`````:@$``&4`````````(0$``&4!````````@@```%P!````````
M[P````````"&`0``00```$H!```4`0``OP```(@```!K`````````-D`````
M````S@```&0`````````!@```.4```#C````3````$`!``"Y````&@$`````
M``!?`0``YP````,!````````:P$``(<!````````2`````````"#````:`$`
M```````[`0``'`$``.@```"R````U@```$<``````````````,T```"``0``
M_P```#H```!^`````````"(`````````0@$``,D`````````40```%D!``"3
M`````````!$```#``````````'<!``!P````_@```+T`````````2`$`````
M``!\`````````&D!``!>`0``B0``````````````+````!,`````````````
M`(<```#"``````````````!]`0``+P$```0!```*`0``=@$```X!``!_`0``
M`````/0`````````40$`````````````1@$``%(``````````````-L```#S
M````#@```'0```#A`````````#H!``!0`0``Q0```)8`````````8P```.L`
M```S````+@```-H````$````9@$`````````````80```",````"`0``H0``
M`'D!``"#`0``M````%(!``"V````#````'@`````````&`````````"^````
M#`$```T!``"2````/`$````````/`0```````',```!.````'@$``!P`````
M````T`````````"1````(0````````#I````)````'4```#1````%@$`````
M````````E0`````````N`0``1````",!```P`0``$0$``"D!```4````````
M`#(``````````````%````"Z````)P```(D!````````G````,<`````````
M-@$````````T`0```````&P`````````!P$``%D```!>````A`$```$!``"%
M`0``&0```&X!````````9P$`````````````M0````````!-`0```````'L`
M``"(`0``3`$``&(!``!Z`0``7`````T```!.`0```````"T```!7`0``````
M`#0`````````#P```'D````;`0````````````"P````%0$````````%````
M"0````4!```K`0``^`````8!````````9`$``#L```!W``````````````!A
M`0`````````````=````NP```&P!```5````20```"H!``"!````?P``````
M``!Q`0``;P```*(````_`0````````````!"`````````&,!``!S`0``K@``
M`!``````````K0```#8`````````,````"@!````````6````&H```"0````
M``````````#&`````````'`!````````*````%4```#]`````````'(````M
M`0``)0````D!```G`0``I0````````#!````X```````````````V````"8`
M````````CP```/``````````>P$``)T`````````KP````````"W````=0$`
M```````9`0``.0$``"`!```D`0```````#D`````````"P``````````````
M(@$``*<```"$````F@```&`````>````,0$``(P```!@`0``*@```$,!``!-
M````20$``%,```##````2P````L!`````````````$,```!6`0``J````#4!
M````````GP```#@!````````;@```/$```!4`0``*0```&@```#5````````
M`!\````Q````-P```)<```!=`0``@0$``'(!````````]@```$$!``#M````
MFP```$4!````````WP```$4```"*`0```"`H06-C97-S:V5Y("5S*0`@*'1O
M9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!A;')E861Y(&5X:7-T<RX`
M,C0@:&]U<G,`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`061D`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%L
M:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!F;W5R('-I9&5S`$%L=&5R
M;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P
M<FEL`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!=6=U<W0`079A:6QA8FQE(&9I96QD<SH`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)I<G1H9&%Y`$)O;&0`0F]R9&5R
M`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T
M960@3&ES=`!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;F-E;`!#
M86YC96P@4')O8FQE;2!297!O<G0`0V%P=&EO;@!#96QL(%!H;VYE`$-E;&P@
M4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL
M('-P86-I;F<Z`$-E;&QP:&]N90!#96YT97(`0VAA;F=E`$-H96-?:R!,:6YK
M+BXN`$-H:6YA`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D
M(&QI<W1S*0!#;&5A<B!-4T]F9FEC92!T86=S`$-L;W-E(%=I;F1O=P!#;VQL
M87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O;',Z`$-O
M;6EC<P!#;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]P>0!#;W!Y('-E;&5C
M=&EO;@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#=7)R96YT(%523"!I<P!#=7)R96YT
M('-T>6QE`$-U=`!#=70@<V5L96-T:6]N`$1$`$1A:6QY`$1A=&4`1&5?;&5T
M92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN
M9&5N=`!$969A=6QT`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T92!C
M96QL`$1E;&5T92!C;VQU;6X`1&5L971E(')O=P!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@3W!T
M:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S`$5D
M:70`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`
M16QE;65N="XN+@!%;0!%;6%I;`!%;6]T:6-O;G,`16UP='D@<F5S=6QT+@!%
M;FQA<F=E($5D:71O<@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17)R;W(`
M179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN
M=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E
M`$5X86UP;&4@=F%L=65S.@!%>'!A;F0@4VED96)A<@!&1R!#;VQO<@!&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$9A>`!&96)R=6%R>0!&:6QE($UA;F%G97(`1FEL
M=&5R<P!&;VYT($-O;&]R`$9R86UE<P!&<F]M`$=E<FUA;GD`1V\`2&5I9VAT
M`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.@!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!(
M;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ
M`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!)7VYS97)T(%)O=R!"969O
M<F4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE
M.@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E
M<@!);F-R96%S92!);F1E;G0`26YS97)T($-?;VQU;6X@069T97(`26YS97)T
M($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#
M;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T
M(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!C
M96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F
M=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T
M97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!)
M;G-E<G0@<F]W(&)E9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-
M;V1I9GD@3&EN:P!)=&%L:6,`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/
M+3(P,C(M2E`I`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU
M<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+;W)E82P@
M4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$QA;F=U86=E`$QA<W0@;&]G
M:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V
M97(`3&%Y;W5T`$QE9G0`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;W=E
M<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M
M86X@;G5M8F5R<P!-30!-86EL`$UA:V4@;&EN7VLN+BX`36%R8V@`36%R9VEN
M`$UA=&-H:6YG(&9I96QD<P!-87D`365N=2!M;V1E.@!-97)G92!C96QL<P!-
M97-S86=E`$UI9&1L90!-;V1I9GD@55),`$UO;G1H;'D`36]V92!$;W=N`$UO
M=F4@57``3F%M90!.971W;W)K`$YE=F5R`$YE=R!W:6YD;W<@*%]B;&%N:RD`
M3F5X=`!.;P!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO;F4`3F]T97,`
M3F]V96UB97(`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3V-T
M;V)E<@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`
M3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!0861D:6YG`%!A<W-W;W)D`%!A<W-W;W)D
M<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H
M`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<G-O
M;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!I>&5L<P!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!R979I97<`4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5M;W9E('!A:7(`
M4F5S970`4F5T=7)N('1O($]P=&EO;G,`4FEG:'0`4F]?=R!0<F]P97)T:65S
M+BXN`%)O;&4`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`
M4V%M92!F<F%M92`H7W-E;&8I`%-A=F4`4V%V92!/<'1I;VYS`%-E87)C:`!3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@
M=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!397!T96UB97(`
M4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@
M4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;`!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!E8VEA;"!#
M:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@
M<F]W`%-T<FEK971H<F]U9V@`4W1Y;&4@6T-34UT`4W5B:F5C=`!3=6)M:70`
M4W5B<V-R:7!T`%-U8V-E<W,`4W5M;6%R>0!3=7!E<G-C<FEP=`!486)L92!0
M<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%S:W,`5&5X=`!497AT($]N
M;'D`5&5X="!A;&EG;@!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN
M`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R
M92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E
M+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BX`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;V=G
M;&4@2%1-3"!3;W5R8V4`5&]P`%1O<"!F<F%M92`H7W1O<"D`55),`%5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O
M)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`
M56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<V5T(&-O;&]R`%5P<&5R(&QA=&EN(&QE
M='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<V5R($]P=&EO;G,`57-E<FYA
M;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`5F5R=&EC86P@86QI9VX`5F5R=&EC
M86P@<&%D9&EN9P!6:65W("5S`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=I9'1H
M`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!A<F4@:6X@5$58
M5"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T
M;R!765-)5UE'+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L
M;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D
M<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES(&9E871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;2&ED92!1
M=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X
M="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F
M("5S70!?061M:6YI<W1R871I;VX`7T1E;&5T92!2;W<`7TAE;'``7TEM86=E
M(%!R;W!E<G1I97,N+BX`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I
M;VYS`%]296UO=F4@3&EN:RXN+@!?5&%B;&4@4')O<&5R=&EE<RXN+@!L:6YE
M<UT`;F%M90!P97)C96YT`'!I>&5L<P!U;FYA;65D`'9#87)D`%!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#$M,3$M
M,#D@,38Z,CDK,#DP,`I,87-T+51R86YS;&%T;W(Z($II;FAY;VL@2&5O(#QN
M;W9E;6)R94!O=7)N871U<F4N;W)G/@I,86YG=6%G92U496%M.B!I,3AN0&QI
M<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]155#+4M2"D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:70*`"`HM-S#X,6P("5S*0`@*+_`M,,I`"`HL[O`SRD`
M("B^[L&F*0`E<R#`K\'VL/RXKB#`V[[W("T@R*[`S@`B)7,BM,(@P,RYS"#`
MUKW`M,^TV2X`,C0@O<.PHP"_P,#\+[_`R,0`P,P@OZ&U\,7-M,(`P]^PH0"[
M];?.O^X@N^>_Z\#:(,/?L*$Z`,;DONXH<&%I<BD@P]^PH0"[Y[_KP-H@P]^P
MH0"[Y[_KP-H@P]^PH2"[Y[_KOLC'U`#!UKS2`,'6O-*WSP"P_+BN`+[SMO/`
MS+[NO;H`P:2WQ`#!I+?$.@"X\+7.(+RQQ<,`N/"UYR`TN.D`M.O#O""QVP#`
MW[CXM<@@N:[`VK"A(,#6O<"TS[39+@`TO_D`P*_!]K#\N*Z]Q\?@P/P@R*[`
MSL?/L>(`.+_Y`+"AM,G'T2#'RK7E.@"YZ+#F`+GHL.8@N_:Q\@"[_<#/`+&]
ML-0`L.:PZ`"PYK#H(+7.LK(`L.:PZ`"X\+7.`+[&MZ$`L>+(HR"XKKVZQJX`
M7V6\OR"\T[RZ+BXN`+3>M\(`P^N\T@"_P+?Y(+JXL.W'S['B(,/KO-(`Q+B\
MQP#(WK3KQOD`O+\@O-.\N@"\OR#&Y+7Y`+R_(+S3O+H`O+\@L*.PW0#(WK3K
MQOD`L*&_[K6E`+JOL.8`7VNXM<6I(+#+N^<N+BX`P=^QN0"\^+RM(+BNO;K&
MKB#!OK?Y(+RQQ<,`35._P,?'O;H@Q=>QUR#!]K_LL>(`PZ(@M-VQX@"_WL+*
MN+>TZR"TW;'B`,?5P\3!^""PYK#H`+OVL?(`OZTZ`$-O;6EC<P#(N+OG`+[/
MR*,@R*[`S@"ZN;OG`+JYN^<`36%I;G1E;F%N8V5?5&%S:R"X\+7B("5S(+BF
M(+^M(+SV(+[XO<"TS[39+@"XN+7IL>(`N+7%J2"XN+7IL>(`Q_;`YR!54DS`
MN@#']L#G(+VZQ;C`SP#`VKBCL>(`P-JXH['B`$1$`,#/NK``LZ_"I0!?;+^M
M(+OHP:8`,3*_^0"\_<#:`+.[ONZ^LK'B`+'BNKL`L>*ZNR"]Q+JPP-H`N^C!
MI@"\OR"[Z,&F`+^M(+OHP:8`Q^`@N^C!I@#']L#G(+^M(,'VO_(`Q_;`YR#'
MX"#!]K_R`+_`M_D@O+.X[0"\L[CM.@"\O+K.P:2ZN+"A(+#\N*[`VKBF(,"G
MQ]@@L>*WS[7'ON[!L[W`M,^TV2X`M?"WNL7DN*X`R*VXZ2"\L\&D`&UA:6YT
M96YA;F-E+G!H<+^A(,'WP:(@P:*QV<?/P?8@N+:\O+_D+@##N;GXPK`@Q^#`
MNB#'U[CQ(,#,N*?`NR"PKK#M(,#6O<"TS['N/R"QU[>XM-FXZ2P@OZFQXKBF
M(,.\Q:G'S[R\O^0Z`+.[M\&YWK'B`"5S(+.[M\&YWK'B`+SVP:0`)7,@L<?'
MT2"\]L&D`+RQQ<.[Y\?7(+SVP:0Z`+_DO-(N+BX`96T`P,RXWL#/`,#,N/#&
MO,3<`+#AL/H@OOC`O0#&[<']L>(@R*ZTZP"QU[BR(%523"#`U+?"`+_`M_D`
M,36ZT""XMK39`#,PP\H@N+:TV0`UNM`@N+:TV0"X\+7G(+?.L=?`S@`S,+K0
M(+BVM-D`N,6ZT`"_N3H`O]["RKBWM.L@R*[`Y0#`_+#FN_8`R*^PYKRSP:0@
MP-"QXB"_P+?Y+@!,1$%0(+RMN?8@P:*\TR"]Q\;0`,;1O;H`,K_Y`,;$P,\@
ML/RXKL#:`,?*Q<T`L=O`VB"[]K'R`,?!M[G`TP#`I\2A`+6VP,\`L*&QX@"S
M],#,`+6UO_*XNP"UM;_RN+L`QL3`S\#'(+W#P-O`S""TV<"]L/H@L+"]P+3/
MM-DZ`,'](,'6O-(`P?T@P/S(K;GXR*,`2&]R9&4`O/;&\KRQ`+"AM\X@PZ2_
M\@"PH;?..@#'U<2AL.T@O<W`NB"_K<#'(+SV`,?7N/$HOZTIP,<@O/8_`,?5
MQ*&P[2"]S<"Z(,?@P,<@O/8`7VZ^U;^A(,?@(,/?L*$`OL;`S,3<`+[&P,S$
MW+#Z(+FNP-H`O<2ZL,#:(,#,N*<Z`+'7N+(@N<RXKKJXL>(Z`+'7N+(@55),
M`+'7N+(@55),.@"PH<&NO\(@Q]>X\3H@)7,`L*'!KK_"(,?7N/$Z`%]SM-G`
MO;^A(,?@(,/?L*$`M>F_J;ZRL>(`7V^TV<"]OZ$@OZT@P]^PH0"QU[BR(,/?
ML*$`QZ4@P]^PH0#`I2"XM<6I(,/?L*$`7V.^U;^A(+^M(,/?L*$`Q_;`YR"_
MK2"UVK^A(+OU(+^M(,/?L*$`Q_;`YR"_K2"^U;^A(+OU(+^M(,/?L*$`Q_;`
MYR#'X""UVK^A(+OU(,?@(,/?L*$`Q_;`YR#'X""^U;^A(+OU(,?@(,/?L*$`
MQ_;`YR#!]L&A(+7:OZ$@M-RV]"##W["A`,?VP.<@P?;!H2"^U;^A(+3<MO0@
MP]^PH0"UVK^A(+R_(,/?L*$`OM6_H2"\OR##W["A`+7:OZ$@OZT@P]^PH0"^
MU;^A(+^M(,/?L*$`M=J_H2"TW+;T(,/?L*$`OM6_H2"TW+;T(,/?L*$`M=J_
MH2#'X"##W["A`+[5OZ$@Q^`@P]^PH0"QU[BR(,/?L*$OO/;!I`"XM<6I(,/?
ML*$OO/;!I`"QXK_OP,RQX@`QO_D`P,^ZNP#`S[J[ONX@*$E33RTR,#(R+4I0
M*0`WO_D`-K_Y`,&DM\0`L*&_[K6E(,&DM\0`ON?"RB#!I+?$`+_>PLH@P:2W
MQ`"_P+BEPLH@P:2WQ`"TZ\?1N<ZQN0#'T;&YONX@*$550RU+4BD`OO"^[@"X
MML'VN+<@M\ZQU\#..B`E<P"XML'VN+<@M\ZQU\#..B`E<RP@P:*\TR#`I\2A
M.B`E<P"XML'VN+<@M\ZQU\#..B"^^,"]`+>YP,R^QK_T`+_>PLH`M;6_\K[+
M(+CQPO<`N^>_Z\?2(+SV(+[XM,(@N^>_Z\#:(+CQM\\N`+?.L=?`S@"WSK'7
MOL:_]`"WSK'7P,X@O</`V\#;OO<`L=>XKKVZ(+S2N:[`V@"V\\:^(+S2N:[`
MV@"WSKBV(+S2N:[`VB"\_<#:`$U-`+C>P,\`7VNXM<6I(+BXM>FQXBXN+@`S
MO_D`L*'`Y<#:N*X`P,_$H<?/M,(@Q]>X\0`UO_D`N-ZTNB"X\+7E`+R_(,?5
MQ*&QX@"XWKW#P?8`L*&_[K6E`%523""\]L&D`+C%O_D`OL:WH;?.(,#,M;\`
MP*>WSB#`S+6_`,#,N*<`L]?&KK_VQ:D`N^>_Z[[(Q]0`N_4@PZ(H7V)L86YK
M*0"TV<"]`+[&M,^_P`!&5%`@5D93N*8@P*?'T2"\L\&DP:2ZN+"A(+[XO<"T
MS[39+@!344P@5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN`%-13"U&:6QE(%9&
M4R"\L\&DP:2ZN+"A(+[XO<"TS[39+@"\L<7#Q\_!]B"^RL"]`,+\P;8`,3&_
M^0"_K<#'(+SV`,?@P,<@O/8`,3"_^0"[]2##HK^A(+BUQ:D@OZVQX@"\L<7#
MN^?'UP`E<R"\L<7#N^?'UP"\_<#:(+CQM\\`M-S#O`"QXL6X`+'BQ;@@P:2Z
MN`#&Y+7Y`+[/R*,`OL_(H["A(,#/Q*''S\'V(+[*O<"TS[39+@"ZV<#,L>(`
MQ:RXL[JXM>6_H;RM(+K9P,RQX@"PYK?.`,;;O+[&K@#`K\'V(+#\N*X@P-N^
M]R"]Q\?@`+"SP,X@P:2ZN`#`_,BMN?C(HP#'R+R_`+FNP::_H2"TZ\?1(+_D
MON#`NR#`U+?"Q]@@P=:\O+_D+@"[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'
MS[R\O^0`N<RXKKJXL>(`N_4@PZ*_H2"YS+BNNKBQX@"YKKRM(,#.O.(`N:[!
MIB"\L[CM`+BVP?:XMR"X[;?)(+G=NKD`QN2^[BAP86ER*2"[Z,&F`,#4M\(@
MP^N\T@"_R;S'P+BWSB"UN;[&L*&QX@"_P+BEPLH`7W?'X""\T[RZ+BXN`+^J
MQ](`Q^`@O-.\N@#'X""\T[RZ`,?@.@"PL,"Z(,?!M[G`TRA?<V5L9BD`P/K`
MY0"\L<7#N^?'UR#`^L#E`+#+N_8`OL:WH2"[\\#:OZ&\K2#'RK_DQ]$@N:[`
MVKBF(+RQQ</'S[#M(+JYN^?'S[^I(+K9OZFSUL"XO+R_Y"X`LZ_`VB"QN+K0
MQZ6]PR"\L<7#.@"SK\#:(,?\O<0@O+'%PP"]P["C(,?\O<0@O+'%PP"USK"S
MP,<@P,_$H<?/M,(@Q]>X\2"\L<7#`,#:P=:[Y[_KQ\^TPB"^\+[NN*8@O+'%
MP\?/O+R_Y"X`N:[!IKG?N_T@NKBP[;RM(,#\O-O'S['B`#F_^0"\OR"\T[RZ
MPZ(@NKBQX@#'I2"\T[RZPZ(@NKBQX@"_K2"\T[RZPZ(@NKBQX@"QU[BR(+S3
MO+K#HB"ZN+'B`,6IL>(`P*_!]K#\N*X@N_VWJP"\O["CL-T`O+\@L.:PZ+_-
M(+.[O^L@N^?`S,#'(+"CL-T`L,6XK@"PQ;BNO\T@PZ2_[+'B`,:OO/8@N:[`
MVB#`U+?"`+R_(+K0Q](`OZT@NM#'T@#'X""ZT,?2`+"AO^ZUI<'9`+VZQ;C`
MSUM#4U-=`,&FN/$`P:;#X@"^QK>AP[?`V@"\NK#X`+_DON``P*W#M\#:`,>E
M(+S3O+H`QZ4@O-.\N@#`V[[W`+FNP-J_K0"YKL#:`+FNP-H@P:2WQ`"[Y[_K
MQ]C!UKS%O*T@L*B[Y\?5M,^TV2X`QL3`S[^A(+[&N:NWL2#`VK?AL*$@OOB]
MP+3/M-DN`+[&MZ&TPB#`S"!M97-S86=E+W)F8S@R,B#&[<'VP,<@N-.XM+B[
MP-2TS[39+@"]Q+JPP-H@(B5S(B"PH2"[Z,&FM<>^^KW`M,^TV2X`P,R_Z["A
MM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+@#&Q,#/(+_#N*ZQXK^A(+FNP::P
MH2#`UKW`M,^TV2X@)7,@QL3`S\#,(+[WM\ZUY;7'P?8@OLJ^TKW`M,^TV2X`
MP,P@O/W`VK3"(,/6O-+'T2`QP-JXKB#`S+OSP,R^[K[?(,?5M,^TV2X`P,P@
ML*K`NB"\_<#:OZF^WR#'U;3/M-DN`,&FN/$`Q;C`S,:R*,7XQL$I.@"YWK3"
M(+OGMO<`2%1-3""\TKVZ(+JXL>(`P*<`N_/`IR#'P;>YP-,H7W1O<"D`55),
M`%9&4R#&Q,#/("5S+R5SP,<@QMNYS+S'P+L@NJ^PYL?2(+SV(+[XO<"TS[39
M+@!344P@O*VY]K^A(,&BO-/'TB"\]B"^^+W`M,^TV2X`)7,@P:3`Q[BF(,#0
MP+L@O/8@OOB]P+3/M-DN`'9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[X
MO<"TS[39+@!61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/
MM-DN`,#,(+_VM>6YKKRMN*8@NJ^PYL?2(+SV(+[XO<"TS[39+@"YV,'9`+JO
ML.:[Y\?7(+7'M;FXKK'B`+BVP?:XMR"X[;?)(,/KO-(`O[6QN0"YS+&Y`,?V
MP.<@O^2\TK^A(+BUQ:D@P::PQ0#`S+BG(+[XP+T`N_:Q\B#!IK#%`+;SQKZ^
M[B"TZ[FNP-H`M\ZXMB"TZ[FNP-H@O/W`V@"[Y[_KP-H@O+'%P[OGQ]<`N^>_
MZ\#:N.T`O<.]NL7;P,<@N^>_Z\#:.@"\]L'W(,&DM\0`O/;!]R##I+_R`"5S
M(+JXL>(`L.:P[0"XQ<'6`,BOO[4`R*^_M<?5M,^TV2$@)7,@P-2TS[39+@#(
MK[^UQ]6TS[39+"`E<P"QN+K0(+FNP-JTPB"YJ[[YP-2TS['N/P#`SK_K(+K.
MR*.TPB"YJ[[YP-2TS['N/P"SRKKQ`,>EP,<@L\JZ\0"SRKKQ(+3<P*<`L\JZ
M\3H`P??`Y2#!UKS2.@#!]\#E(,#\R*VY^,BC`%E9`+C%L^(`O[D`5$585+CP
MM>7`U+3/M-DN(%L\/ET@N?;&L,"[(+2IN*.XZ2!765-)5UE'(+CPM>6WSB"U
MN;[&L*FTS[39+@"WSK'7OL:_]"#'S[^TO<"TS[39+@"YKL&F(+JXL.V\K;BF
M(+JXL[NQXL#\OZ$@P,RYKL&FOZ$@M.O'T2"\L[CMP+L@P-2WPL?8OM\@Q]6T
MS[39+@#`S""XM<6IL*$@L*&XKL2AM,(@55),P+L@P-2WPL?8OM\@Q]6TS[39
M+@"[Z,&FQ](@N^>_Z\#:(,#,N*?`NR#`U+?"Q]B^WR#'U;3/M-DN`,/?L*''
MTB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2X`)7,@O+R\Q\#,(+BX
MM^&UQ[[ZO<"TS[39+B"TV;W#(+?.L=?`SL?/O+R_Y"X`P,RXWL#/(,'6O-(Z
M`+C>P,\@P=:\TCH`P:2ZN`#`S+BG.@"TY[W%P,<@P,[!]<6LMO/`S+[PQJZP
MH2"[Y[_KP-H@N/&WS[JXL>*XIB#!]K_XQ\_!]B"^RKW`M,^TV2X@ML>TPB"T
MV;BE(,#,P*^WSB"[Y[_KP-H@N/&WS[JXL>*XIB"[Y[_KQ](@O/8@OOB]P+3/
MM-DN`+KJMO._[,#ZL*$@P,P@L>*TR<"[(,'VO_C'S\'V(+[*O<"TS[39+@#'
M]L#G(+W#L*.TZSH`L>*ZNR"]Q+JPP-HZ`,#\P[P@P,RXISH`P,P@O+R\QR"U
MO[[((+_)O,?`S"#`^L#EM<NTS[39+@"_R;S'P,P@P/K`Y;7'OOJ]P+3/M-DN
M`%O`SK_K(+S[L>*QXET`6[_`M_D@NKBP[<?/L>)=`%O`SK_K(+JXL>(@+0!;
MP,Z_ZR"ZN+'B("T@)7,@P=E=`%NV\\#.("5S("\@)7-=`%]!L/RXK@!?1,?@
M(,'VO_(`M;6_\KB[`%])L=>XLB"\T[RZ+BXN`%],M\ZQU[[&O_0`7VVXM<6I
M(+SVP:0N+BX`7T^\L<7#N^?'UP!?<KBUQ:D@N^C!IBXN`%]TQZ4@O-.\NBXN
M+@#!V5T`P,RXIP#&V[R^QJX`Q\B\OP#`S+BG(+[XP+T`=D-A<F0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]K
M;U]+4B]H96QP+GAM;```````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#,S,C``,3`T,3<S-C(W-S<`,#(P,S0S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_>&UL('9E<G-I;VX](C$N
M,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+VMO7TM2+VAE;'`N>&UL
M+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,30@:F%N($5X<"`D("TM/@H\:&5L
M<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^
M5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L
M('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM
M<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@
M<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@
M:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD
M87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O
M;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F
M('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U
M=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A
M(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V
M96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT
M96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA
M('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H
M;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A
M9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N
M+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T
M93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A
M<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@
M=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A
M<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A
M<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@
M879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT
M96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI
M:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER
M;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W
M;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E
M9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N
M8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D
M('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I
M=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*
M/"]E;G1R>3X*/"]H96QP/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;'1?3%0O
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8R-S<W`#`Q-C<P-P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]L=%],5"],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#(P-#<T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VQT7TQ4+TQ#7TU%4U-!1T53
M+VAO<F1E+FUO````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,S,C(T,@`Q,#0Q
M-S,V,C<W-P`P,C(Q,S4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````WA($E0````!T!@``'````+PS``";"```7&<```````#(
MB0``#@```,F)```/````V(D```@```#HB0``#````/&)```$````_HD```P`
M```#B@``#P```!"*```+````((H```X````LB@``!0```#N*```H````08H`
M``H```!JB@``%0```'6*```2````BXH```L```">B@``#@```*J*```*````
MN8H```T```#$B@``#@```-**```1````X8H```T```#SB@``#`````&+```-
M````#HL```8````<BP``#P```".+```8````,XL```P```!,BP``#@```%F+
M```.````:(L```@```!WBP``+@```("+```:````KXL``#(```#*BP``.```
M`/V+``!4````-HP``%$```"+C```6@```-V,``!7````.(T``#0```"0C0``
M"@```,6-```%````T(T```8```#6C0``$0```-V-```(````[XT```D```#X
MC0``"0````*.```E````#(X``"`````RC@``$````%..```/````9(X```H`
M``!TC@```P```'^.```/````@XX``!0```"3C@``"0```*B.```-````LHX`
M`!(```#`C@``#P```-..```*````XXX```\```#NC@``"````/Z.```D````
M!X\``!0````LCP``%@```$&/```(````6(\``!D```!ACP``!P```'N/```,
M````@X\``"P```"0CP``#@```+V/```#````S(\```L```#0CP``!P```-R/
M```'````Y(\```4```#LCP``!0```/*/```*````^(\```,````#D```%P``
M``>0```*````'Y````\````JD```#@```#J0```8````29```",```!BD```
M#@```(:0```4````E9```!<```"JD```%P```,*0```7````VI```!,```#R
MD```#P````:1```.````%I$``!\````ED0``!P```$61```&````39$```@`
M``!4D0``#P```%V1```&````;9$```H```!TD0``$P```'^1```+````DY$`
M`!4```"?D0``%0```+61```'````RY$```4```#3D0``%0```-F1```1````
M[Y$```P````!D@``.P````Z2```)````2I(```<```!4D@``%````%R2```#
M````<9(```4```!UD@``$````'N2```)````C)(``!,```"6D@``.0```*J2
M```2````Y)(``"<```#WD@``+````!^3```J````3),``"4```!WDP``"@``
M`)V3```&````J),```D```"ODP``!P```+F3```O````P9,``#<```#QDP``
M+@```"F4``!5````6)0``"T```"NE```+0```-R4```M````"I4``$`````X
ME0``(P```'F5```C````G94``"T```#!E0``,P```.^5```5````(Y8``!D`
M```YE@``*0```%.6```D````?98``!$```"BE@``"@```+26```,````OY8`
M``H```#,E@``$````->6```6````Z)8``!8```#_E@``!P```!:7```'````
M'I<``!0````FEP``"@```#N7```(````1I<```@```!/EP``!P```%B7```'
M````8)<```8```!HEP``!0```&^7```'````=9<```8```!]EP``"````(27
M```.````C9<```H```"<EP``!````*>7```'````K)<```D```"TEP``!@``
M`+Z7```1````Q9<```<```#7EP``%@```-^7```$````]I<```@```#[EP``
M!@````28```-````"Y@```8````9F```'@```""8```1````/Y@```@```!1
MF```#0```%J8```,````:)@```<```!UF````P```'V8```#````@9@``!<`
M``"%F```$P```)V8```(````L9@```0```"ZF```"````+^8```(````R)@`
M`$$```#1F```(````!.9```&````-)D```8````[F0``%0```$*9```8````
M6)D``"(```!QF0``+@```)29```=````PYD``"$```#AF0``5`````.:```I
M````6)H```H```""F@``!P```(V:```5````E9H```X```"KF@``"@```+J:
M```/````Q9H```T```#5F@``#P```..:```-````\YH```D````!FP``%```
M``N;```&````()L``!@````GFP``'0```$";```3````7IL``!0```!RFP``
M!````(>;```&````C)L``%0```"3FP``!````.B;```.````[9L```4```#\
MFP``!0````*<```;````")P``!H````DG```$0```#^<```1````49P``!P`
M``!CG```*@```("<```0````JYP``"$```"\G```!0```-Z<```3````Y)P`
M`!(```#XG```"@````N=```/````%IT``!$````FG0``$P```#B=```,````
M3)T```8```!9G0``!@```&"=```7````9YT``!$```!_G0``"````)&=```%
M````FIT```P```"@G0``$````*V=```%````OIT```T```#$G0``!@```-*=
M```'````V9T```T```#AG0``!P```.^=```+````]YT```<````#G@``!P``
M``N>```)````$YX```H````=G@``&0```"B>```,````0IX``!````!/G@``
M!0```&">```E````9IX``!(```",G@``$P```)^>```K````LYX``#L```#?
MG@``(````!N?```V````/)\```@```!SGP``#````'R?```&````B9\```0`
M``"0GP``#@```)6?```*````I)\```T```"OGP``'@```+V?```;````W)\`
M`"$```#XGP``'@```!J@```9````.:```!X```!3H```&P```'*@```F````
MCJ```!L```"UH```'@```-&@```<````\*```"8````-H0``,P```#2A```F
M````:*$``"L```"/H0``.````+NA```O````]*$``!(````DH@``*0```#>B
M```2````8:(``*(```!TH@``%@```!>C```C````+J,``"@```!2HP``*0``
M`'NC```H````I:,``!\```#.HP``(````.ZC```E````#Z0``"$````UI```
M'````%>D```F````=*0``$$```";I```#````-VD```'````ZJ0```<```#R
MI```!@```/JD```-`````:4``!`````/I0``$@```""E```3````,Z4``!(`
M``!'I0``!P```%JE```$````8J4```P```!GI0``#@```'2E```/````@Z4`
M`!,```"3I0``#0```*>E```H````M:4```,```#>I0``#0```.*E```&````
M\*4``!$```#WI0``%P````FF```;````(:8```X````]I@```@```$RF```%
M````3Z8``!````!5I@``!````&:F```-````:Z8```X```!YI@```P```(BF
M```.````C*8```@```";I@``#P```*2F```/````M*8```T```#$I@``$```
M`-*F```+````XZ8```8```#OI@``#````/:F```1`````Z<``!D````5IP``
M"P```"^G```-````.Z<``"(```!)IP``"@```&RG```8````=Z<``!D```"0
MIP``%@```*JG```-````P:<```<```#/IP``%````->G```+````[*<``"(`
M``#XIP``+P```!NH```+````2Z@```D```!7J```&0```&&H```+````>Z@`
M`!<```"'J```%P```)^H```)````MZ@``!8```#!J```#P```-BH```6````
MZ*@```X```#_J```&`````ZI```(````)ZD```T````PJ0``)@```#ZI``!#
M````9:D```@```"IJ0``$@```+*I```(````Q:D```L```#.J0``+P```-JI
M```.````"JH```4````9J@``!@```!^J```#````)JH```<````JJ@``!```
M`#*J```*````-ZH```H```!"J@``#P```$VJ```0````7:H``!<```!NJ@``
M$0```(:J```7````F*H```D```"PJ@``!0```+JJ```+````P*H```H```#,
MJ@```@```->J```%````VJH```T```#@J@``&P```.ZJ```7````"JL```D`
M```BJP``#@```"RK```-````.ZL``!(```!)JP``.````%RK```@````E:L`
M``@```"VJP``#@```+^K``![````SJL``!@```!*K```$0```&.L```'````
M=:P```4```!]K```&0```(.L```'````G:P```@```"EK```!@```*ZL```&
M````M:P``!````"\K```#P```,VL```0````W:P```\```#NK```"P```/ZL
M```/````"JT```P````:K0``#P```">M```'````-ZT```8````_K0``#```
M`$:M```H````4ZT```\```!\K0``"````(RM```(````E:T``!,```">K0``
M'@```+*M```A````T:T``"````#SK0``&0```!2N```7````+JX``"4```!&
MK@``%P```&RN```$````A*X``!L```")K@``#0```*6N```#````LZX```@`
M``"WK@``"@```,"N```,````RZX```L```#8K@``!````.2N```3````Z:X`
M`!0```#]K@``#````!*O```)````'Z\```X````IKP``"P```#BO```;````
M1*\```<```!@KP``!P```&BO```*````<*\```T```![KP``"0```(FO```$
M````DZ\```4```"8KP```P```)ZO```8````HJ\```H```"[KP``!````,:O
M```F````RZ\```X```#RKP``?`````&P```5````?K````4```"4L```!P``
M`)JP```,````HK````@```"OL```"@```+BP```&````P[````@```#*L```
M`@```-.P```&````UK````8```#=L```%````.2P```-````^;```!`````'
ML0``&P```!BQ```$````-+$```D````YL0``$````$.Q```)````5+$```D`
M``!>L0``!0```&BQ```:````;K$```@```")L0``!@```)*Q```9````F;$`
M``X```"SL0``!P```,*Q```'````RK$```4```#2L0``"0```-BQ```*````
MXK$```(```#ML0``!@```/"Q```-````][$```D````%L@``!@````^R```2
M````%K(```D````IL@``!P```#.R```4````.[(``!T```!0L@``!@```&ZR
M```*````=;(```0```"`L@``"0```(6R```(````C[(``!$```"8L@``"0``
M`*JR```&````M+(```T```"[L@``!@```,FR```$````T+(``#D```#5L@``
M/0````^S```Z````3;,``!X```"(LP``!0```*>S```.````K;,```0```"\
MLP``!@```,&S```A````R+,``!4```#JLP``!@````"T```$````![0``!$`
M```,M```!@```!ZT```*````);0``"(````PM```!````%.T```%````6+0`
M`!T```!>M```!````'RT```,````@;0```H```".M```"````)FT```)````
MHK0```4```"LM```.@```+*T```P````[;0``#4````>M0``*0```%2U``!'
M````?K4``#@```#&M0``*0```/^U```_````*;8``"X```!IM@``+0```)BV
M```?````QK8```\```#FM@``$@```/:V```+````";<``"8````5MP``*0``
M`#RW```D````9K<``"8```"+MP``"````+*W```*````N[<```D```#&MP``
M!P```-"W```@````V+<``"````#YMP``)@```!JX```*````0;@``!D```!,
MN```*0```&:X```6````D+@``!(```"GN```!P```+JX```*````PK@```\`
M``#-N```$````-VX``!`````[K@``&8````ON0``#@```):Y```)````I;D`
M``H```"ON0``$@```+JY```3````S;D```P```#AN0``!@```.ZY```/````
M];D``!(````%N@``$````!BZ```1````*;H``!P````[N@``(P```%BZ``!J
M````?+H```\```#GN@``!0```/>Z```0````_;H```D````.NP``!````!B[
M```+````';L``!0````INP``#````#Z[```,````2[L```\```!8NP``%0``
M`&B[```I````?KL``"H```"HNP``)@```-.[```G````^KL``"D````BO```
M*@```$R\```9````=[P``$(```"1O```$0```-2\```2````YKP``!,```#Y
MO```%`````V]```/````(KT``!8````RO0``%P```$F]```0````8;T``!$`
M``!RO0``-````(2]```3````N;T``!(```#-O0``-0```."]```4````%KX`
M``<````KO@``#````#.^```@````0+X``!0```!AO@``$0```':^```7````
MB+X``!P```"@O@``$P```+V^```1````T;X``!H```#CO@``'@```/Z^```:
M````';\``!$````XOP``%````$J_```7````7[\``!4```!WOP``"0```(V_
M```9````E[\```0```"QOP``!P```+:_```+````OK\``!$```#*OP``!@``
M`-R_```&````X[\```8```#JOP``!0```/&_```'````][\```<```#_OP``
M!0````?````6````#<````8````DP```!@```"O````$````,L````0````W
MP```!P```#S````.````1,````P```!3P```#````&#````-````;<````H`
M``![P```#@```(;````%````E<```"@```";P```#@```,3````,````T\``
M``\```#@P```"@```/#````(````^\````D````$P0``*P````[!```$````
M.L$```@````_P0``)@```$C!```2````;\$```\```""P0``!@```)+!```*
M````F<$```<```"DP0``"````*S!```@````M<$```D```#6P0``#````.#!
M```-````[<$```X```#[P0``%@````K"```1````(<(```8````SP@```P``
M`#K"```&````/L(``!D```!%P@``!P```%_"```$````9\(```L```!LP@``
M"P```'C"```'````A,(```<```",P@``%@```)3"```-````J\(```T```"Y
MP@``"@```,?"```0````TL(```\```#CP@``$0```//"```7````!<,```H`
M```=PP``$0```"C#```(````.L,```0```!#PP``#P```$C#```Z````6,,`
M``4```"3PP``#````)G#```>````IL,```X```#%PP``$````-3#```+````
MY<,```P```#QPP``"0```/[#```'````",0```H````0Q```"0```!O$```.
M````)<0``!`````TQ```&@```$7$```*````8,0```D```!KQ```"@```'7$
M```,````@,0```\```"-Q```"````)W$```&````IL0```<```"MQ```"P``
M`+7$``!'````P<0```T````)Q0``"0```!?%```$````(<4```,````FQ0``
M$P```"K%```3````/L4``!,```!2Q0``"@```&;%```"````<<4```0```!T
MQ0``)0```'G%```#````G\4```4```"CQ0``*@```*G%```*````U,4```4`
M``#?Q0``!````.7%```*````ZL4```T```#UQ0``!@````/&```(````"L8`
M``@````3Q@``!````!S&```%````(<8``&@````GQ@``"0```)#&```,````
MFL8```4```"GQ@``!@```*W&```;````M,8``"\```#0Q@``$`````#'```*
M````$<<```\````<QP``"@```"S'```)````-\<``!,```!!QP``&P```%7'
M```8````<<<``!<```"*QP``#@```*+'```#````L<<```<```"UQP``"```
M`+W'```'````QL<```H```#.QP``"P```-G'```'````Y<<``%$```#MQP``
M$````#_(```,````4,@```T```!=R```&@```&O(``!*````AL@```8```#1
MR```!@```-C(```&````W\@``!\```#FR```!@````;)```)````#<D``!@`
M```7R0``%P```##)```&````2,D```T```!/R0``(@```%W)``!7````@,D`
M`!,```#8R0``(P```.S)```3````$,H```(````DR@``"P```"?*```(````
M,\H```T````\R@``"@```$K*```'````5<H``!0```!=R@``!@```'+*```(
M````><H```X```""R@``!P```)'*```*````F<H```L```"DR@``!P```+#*
M```,````N,H```T```#%R@``#````-/*```)````X,H```D```#JR@``"@``
M`/3*```'````_\H```D````'RP``!P```!'+```*````&<L``!L````DRP``
M$@```$#+```*````4\L```D```!>RP``$````&C+```'````><L``!(```"!
MRP``!````)3+```'````F<L```4```"ARP``!0```*?+```+````K<L``!0`
M``"YRP``$0```,[+```:````X,L``!8```#[RP``%````!+,```7````)\P`
M`!@````_S```'````%C,```9````=<P```<```"/S```!0```)?,```-````
MG<P```P```"KS```"````+C,```7````P<P```L```#9S```$P```.7,```$
M````^<P```H```#^S```!`````G-```,````#LT```D````;S0``!0```"7-
M```'````*\T```4````SS0``!````#G-```"````/LT``#@```!!S0``+```
M`'K-```2````I\T``"D```"ZS0``,@```.3-```*````%\X``"P````BS@``
M+@```$_.```S````?LX``#,```"RS@``.````.;.```/````'\\``!@````O
MSP``$````$C/```3````6<\``!0```!MSP``$@```(+/```4````E<\``!4`
M``"JSP``+0```,#/```M````[L\``#$````<T```+@```$[0```O````?=``
M`"P```"MT```8@```-K0```3````/=$```@```!1T0``"````%K1```K````
M8]$``"$```"/T0``&@```+'1```)````S-$``$4```#6T0``00```!S2```$
M````7M(``!,```!CT@``%````'?2```.````C-(``!,```";T@``&````*_2
M```&````R-(```D```#/T@``"@```-G2```/````Y-(``!````#TT@``!P``
M``73```.````#=,```4````<TP``&P```"+3```(````/M,```8```!'TP``
M%````$[3```1````8],```X```!UTP``.````(33```"````O=,```8```#`
MTP``#@```,?3```%````UM,```<```#<TP``#@```.33```&````\],```0`
M``#ZTP``*0```/_3```7````*=0``!\```!!U```7````&'4```4````OM0`
M`!\```#3U```$````//4```'````!-4```X````,U0``#````!O5```,````
M*-4``!,````UU0``"@```$G5```=````5-4``!D```!RU0``!0```(S5```1
M````DM4``!$```"DU0``)````+;5```5````V]4``!(```#QU0``#@````36
M```9````$]8```@````MU@``"0```#;6```-````0-8```H```!.U@``"P``
M`%G6```*````9=8```<```!PU@``"````'C6```%````@=8``!\```"'U@``
M!@```*?6```0````KM8```@```"_U@``#0```,C6```(````UM8``!(```#?
MU@``+````/+6```:````']<```D````ZUP``"@```$37```5````3]<```4`
M``!EUP``%````&O7```$````@-<``!````"%UP``!@```);7```'````G=<`
M`!X```"EUP``*````,37```*````[=<``!H```#XUP``%````!/8```$````
M*-@```0````MV```"P```#+8```%````/M@```8```!$V```"````$O8```&
M````5-@```H```!;V```&P```&;8```T````@M@``#0```"WV```(````.S8
M```I````#=D``"`````WV0``00```%C9```:````FMD``"@```"UV0``*0``
M`-[9```B````"-H```8````KV@``"````#+:```%````.]H```@```!!V@``
M&0```$K:```9````9-H``"H```!^V@``(P```*G:```N````S=H``#0```#\
MV@``"````#';```7````.ML```H```!2VP``!P```%W;```A````9=L``!``
M``"'VP``#@```)C;```+````I]L```<```"SVP``$P```+O;```(````S]L`
M``L```#8VP``"@```.3;```4````[]L``#(````$W```"P```#?<```%````
M0]P```4```!)W```%P```$_<```/````9]P```0```!WW```"@```'S<```)
M````A]P```L```"1W```#@```)W<```%````K-P```0```"RW```#0```+?<
M```R````Q=P``$4```#XW```%P```#[=```>````5MT``!0```!UW0``!0``
M`(K=```4````D-T```<```"EW0``#@```*W=```J````O-T```8```#GW0``
M#````.[=```-````^]T``!$````)W@``"P```!O>```V````)]X```H```!>
MW@``(@```&G>```+````C-X```\```"8W@``,@```*C>```%````V]X```X`
M``#AW@``$P```/#>```'````!-\``!$````,WP``!P```![?```4````)M\`
M`!@````[WP``!P```%3?```%````7-\```P```!BWP``#````&_?```2````
M?-\```0```"/WP``!P```)3?```*````G-\```L```"GWP``#````+/?```.
M````P-\```X```#/WP``!0```-[?```%````Y-\``"X```#JWP``)@```!G@
M```C````0.````,```!DX```$@```&C@```&````>^```!X```""X```&```
M`*'@```E````NN````T```#@X```"0```.[@```#````^.````<```#\X```
M"@````3A```"````#^$```P````2X0``%0```!_A```+````->$``!D```!!
MX0``(````%OA```2````?.$```4```"/X0``"@```)7A```5````H.$``!(`
M``"VX0``#````,GA```$````UN$```<```#;X0``#````./A``!2````\.$`
M`!<```!#X@``!P```%OB```&````8^(```X```!JX@``#````'GB```-````
MAN(``!4```"4X@``$@```*KB```/````O>(``!0```#-X@``&P```.+B```0
M````_N(``&D````/XP``&@```'GC```7````E.,``"<```"LXP``&@```-3C
M```7````[^,``!L````'Y```&0```"/D```?````/>0``!,```!=Y```"```
M`''D```'````>N0```@```""Y```"0```(OD```5````E>0```T```"KY```
M$P```+GD```#````S>0``$8```#1Y```/P```!CE```W````6.4``%<```"0
MY0``'P```.CE```O````".8```H````XY@``"````$/F```-````3.8``"T`
M``!:Y@``!````(CF``!/````C>8``"4```#=Y@``'`````/G```+````(.<`
M`!\````LYP``'0```$SG```E````:N<``"````"0YP``)````+'G```@````
MUN<```L```#WYP``!P````/H```-````"^@```P````9Z```!@```";H```Y
M````+>@```P```!GZ```!P```'3H```)````?.@``!,```"&Z```"0```)KH
M```$````I.@``!````"IZ```"````+KH```(````P^@```L```#,Z```#```
M`-CH```:````Y>@```\`````Z0``!P```!#I```-````&.D``!0````FZ0``
M#@```#OI```,````2ND``!L```!7Z0``+````'/I```3````H.D``!P```"T
MZ0``*````-'I```&````^ND```<````!Z@``$P````GJ```%````'>H```0`
M```CZ@``%P```"CJ```*````0.H```P```!+Z@``"0```%CJ```&````8NH`
M``D```!IZ@``"````'/J```)````?.H```H```"&Z@``$0```)'J```&````
MH^H```X```"JZ@``#@```+GJ```-````R.H```L```#6Z@``'0```.+J```+
M`````.L```(````,ZP``!P````_K```&````%^L```D````>ZP``!P```"CK
M```[````,.L``"@```!LZP``%0```)7K```%````J^L```<```"QZP``"```
M`+GK```'````PNL```4```#*ZP``!P```-#K```.````V.L```D```#GZP``
M!@```/'K```(````^.L```L````![```!P````WL```(````%>P```<````>
M[```%@```";L```)````/>P```8```!'[```"P```$[L```<````6NP``!0`
M``!W[```!P```(SL```(````E.P```@```"=[```!0```*;L```0````K.P`
M`!````"][```!@```,[L```9````U>P```H```#O[```'````/KL```'````
M%^T```4````?[0``$````"7M```4````-NT```L```!+[0``#0```%?M```7
M````9>T```0```!][0``"0```(+M```*````C.T```<```"7[0```@```)_M
M```.````HNT```@```"Q[0``'P```+KM```C````VNT``#@```#^[0``,0``
M`#?N```G````:>X``&0```"1[@``%````/;N``!5````"^\``#@```!A[P``
M2@```)KO``!;````Y>\``"@```!!\```.````&KP```H````H_```"P```#,
M\```)P```/GP```;````(?$``#X````]\0``J0$``'SQ```C````)O,``!<`
M``!*\P``2````&+S``"%````J_,``#`````Q]```00```&+T``!;````I/0`
M`$D`````]0``'0```$KU```8````:/4``"$```"!]0``'P```*/U```K````
MP_4``"$```#O]0``'0```!'V```1````+_8``#,```!!]@``)0```'7V```G
M````F_8``!\```##]@``,````./V``!I````%/<``#T```!^]P``90```+SW
M``!-````(O@``"\```!P^```+@```*#X```P````S_@``%0`````^0``6@``
M`%7Y``!(````L/D``$H```#Y^0``,@```$3Z```O````=_H``"P```"G^@``
M+0```-3Z``!Q`````OL``&\```!T^P``LP```.3[```7````F/P``"4```"P
M_```,@```-;\```I````"?T``#X````S_0``(@```'+]``!2````E?T``"4`
M``#H_0``"P````[^``"Q````&OX``$4```#,_@``(0```!+_```P````-/\`
M`"4```!E_P``'````(O_```Q````J/\```<```#:_P``!P```.+_```$````
MZO\```T```#O_P``"P```/W_```.````"0`!``L````8``$`!0```"0``0`0
M````*@`!``(````[``$`60```#X``0`%````F``!`!(```">``$`!````+$`
M`0`'````M@`!``@```"^``$`!0```,<``0`#````S0`!`!````#1``$`#```
M`.(``0`3````[P`!``T````#`0$``@```!$!`0`'````%`$!``8````<`0$`
M%````",!`0`,````.`$!`!@```!%`0$`!@```%X!`0`2````90$!``P```!X
M`0$``P```(4!`0`J````B0$!``0```"T`0$`!@```+D!`0`'````P`$!`!\`
M``#(`0$`-0```.@!`0`N````'@(!`"\```!-`@$`%P```'T"`0`@````E0(!
M`!L```"V`@$`&````-("`0`D````ZP(!`!\````0`P$`&@```#`#`0`@````
M2P,!`!H```!L`P$`,@```(<#`0`O````N@,!`"L```#J`P$`'P```!8$`0`C
M````-@0!`!\```!:!`$`&@```'H$`0`E````E00!`"8```"[!`$`)0```.($
M`0`D````"`4!`!@````M!0$`'0```$8%`0`D````9`4!`!@```")!0$`(@``
M`*(%`0`E````Q04!`#P```#K!0$`'P```"@&`0`C````2`8!`!\```!L!@$`
M(````(P&`0`:````K08!`!@```#(!@$`)@```.$&`0`>````"`<!`"D````G
M!P$`'@```%$'`0`)````<`<!``P```!Z!P$`%P```(<'`0`O````GP<!`"0`
M``#/!P$`!P```/0'`0`/````_`<!`!0````,"`$`#@```"$(`0`-````,`@!
M`"0````^"`$`!0```&,(`0`'````:0@!`"(```!Q"`$`)0```)0(`0`=````
MN@@!`!H```#8"`$`!P```/,(`0#'````^P@!``L```##"0$`%0```,\)`0`&
M````Y0D!``D```#L"0$`"P```/8)`0`7`````@H!``8````:"@$`,P```"$*
M`0`3````50H!`!,```!I"@$`!P```'T*`0`/````A0H!``<```"5"@$`,@``
M`)T*`0`A````T`H!`!,```#R"@$`#`````8+`0`1````$PL!`#(````E"P$`
M"````%@+`0`)````80L!``H```!K"P$`%````'8+`0`*````BPL!`!T```"6
M"P$`"````+0+`0`?````O0L!``@```#="P$`&@```.8+`0`&`````0P!`!4`
M```(#`$`!P```!X,`0`(````)@P!``D````O#`$`/P```#D,`0`'````>0P!
M``\```"!#`$`#@```)$,`0`0````H`P!``D```"Q#`$`"0```+L,`0`(````
MQ0P!`!,```#.#`$`!P```.(,`0`9````Z@P!``H````$#0$`%P````\-`0`4
M````)PT!``H````\#0$`#````$<-`0`7````5`T!``0```!L#0$`*@```'$-
M`0`1````G`T!``<```"N#0$``@```+8-`0`0````N0T!`!@```#*#0$`"P``
M`.,-`0`#````[PT!``@```#S#0$`!@```/P-`0`'`````PX!``T````+#@$`
M"P```!D.`0`4````)0X!`!4````Z#@$`#@```%`.`0`O````7PX!`"````"/
M#@$`'````+`.`0`,````S0X!`#$```#:#@$`!0````P/`0`2````$@\!`#\`
M```E#P$`$@```&4/`0`*````>`\!``8```"##P$`!````(H/`0`3````CP\!
M``4```"C#P$`!@```*D/`0`&````L`\!``0```"W#P$`#````+P/`0`*````
MR0\!``4```#4#P$`&````-H/`0`9````\P\!`!\````-$`$`'0```"T0`0`1
M````2Q`!``(```!=$`$`!````&`0`0`*````91`!``8```!P$`$`!0```'<0
M`0`#````?1`!``P```"!$`$`10```(X0`0`:````U!`!`#4```#O$`$`*```
M`"41`0!3````3A$!`!D```"B$0$`<@```+P1`0`@````+Q(!`#4```!0$@$`
M10```(82`0`P````S!(!`"@```#]$@$`*0```"83`0`F````4!,!`"4```!W
M$P$`*````)T3`0`H````QA,!`"(```#O$P$`,````!(4`0`2````0Q0!`!,`
M``!6%`$`$````&H4`0!Y````>Q0!``D```#U%`$`<P```/\4`0!\````<Q4!
M`"L```#P%0$`%P```!P6`0`6````-!8!``\```!+%@$`'P```%L6`0`?````
M>Q8!`!P```";%@$`40```+@6`0`4````"A<!``H````?%P$`!0```"H7`0`&
M````,!<!``@````W%P$`!0```$`7`0`2````1A<!`!````!9%P$`$P```&H7
M`0`=````?A<!``\```"<%P$`#P```*P7`0`$````O!<!``D```#!%P$`"P``
M`,L7`0`'````UQ<!``4```#?%P$`%````.47`0`'````^A<!``@````"&`$`
M#P````L8`0`(````&Q@!``P````D&`$`#P```#$8`0`&````01@!`!0```!(
M&`$`!@```%T8`0`,````9!@!``@```!Q&`$`!````'H8`0`*````?Q@!``<`
M``"*&`$`!````)(8`0`9````EQ@!``(```"Q&`$`"0```+08`0`&````OA@!
M``8```#%&`$`)P```,P8`0`$````]!@!``\```#Y&`$`$P````D9`0`'````
M'1D!``<````E&0$`!@```"T9`0`&````-!D!`!`````[&0$`$@```$P9`0`&
M````7QD!``D```!F&0$`(@```'`9`0`'````DQD!``<```";&0$`"P```*,9
M`0`%````KQD!``(```"U&0$`"P```+@9`0!7`0``Q!D!`!(````<&P$`#@``
M`"\;`0`+````/AL!``@```!*&P$``0```%,;`0`+````51L!`!$```!A&P$`
M#````',;`0`-````@!L!``4```".&P$`*0```)0;`0`/````OAL!``P```#.
M&P$`$@```-L;`0`(````[AL!`!$```#W&P$`"@````D<`0`,````%!P!`!,`
M```A'`$`$0```#4<`0`.````1QP!`!$```!6'`$`$````&@<`0`&````>1P!
M``X```"`'`$`%0```(\<`0`1````I1P!`!,```"W'`$`$P```,L<`0`+````
MWQP!`"P```#K'`$`$@```!@=`0`]````*QT!`$D```!I'0$`90```+,=`0!F
M````&1X!`&@```"`'@$`:0```.D>`0!`````4Q\!``H```"4'P$`!0```)\?
M`0`&````I1\!`!(```"L'P$`!P```+\?`0`1````QQ\!`!,```#9'P$`*P``
M`.T?`0`H````&2`!``L```!"(`$`$P```$X@`0`(````8B`!``<```!K(`$`
M#P```',@`0`0````@R`!`!````"4(`$`$P```*4@`0`5````N2`!`!H```#/
M(`$`$````.H@`0`6````^R`!``P````2(0$`+0```!\A`0`:````32$!`!\`
M``!H(0$`$0```(@A`0`<````FB$!``<```"W(0$`!P```+\A`0`Y````QR$!
M``@````!(@$`"`````HB`0`,````$R(!``@````@(@$`!P```"DB`0`(````
M,2(!``@````Z(@$`"P```$,B`0`%````3R(!`!H```!5(@$`#````'`B`0`,
M````?2(!`!0```"*(@$`%````)\B`0`A````M"(!``X```#6(@$`'P```.4B
M`0`=````!2,!`"(````C(P$`'@```$8C`0`5````92,!`!0```![(P$`#@``
M`)`C`0`;````GR,!``8```"[(P$`!@```,(C`0`'````R2,!`!D```#1(P$`
M"0```.LC`0`*````]2,!`!(`````)`$`!P```!,D`0`5````&R0!`!<````Q
M)`$`"P```$DD`0`(````520!`!<```!>)`$`$P```'8D`0`9````BB0!`#,`
M``"D)`$`"0```-@D`0`(````XB0!`!4```#K)`$`!0````$E`0`%````!R4!
M`!T````-)0$`"P```"LE`0`@````-R4!`"X```!8)0$`%0```(<E`0`H````
MG24!`"H```#&)0$`*P```/$E`0`K````'28!``D```!))@$`"0```%,F`0`*
M````728!``@```!H)@$`+P```'$F`0`L````H28!`"X```#.)@$`4````/TF
M`0`M````3B<!`"T```!\)P$`+0```*HG`0`_````V"<!`"D````8*`$`*P``
M`$(H`0`M````;B@!`#,```"<*`$`%````-`H`0`8````Y2@!`"H```#^*`$`
M)P```"DI`0`.````42D!``T```!@*0$`$0```&XI`0`%````@"D!``L```"&
M*0$`(0```)(I`0`F````M"D!``<```#;*0$`"0```.,I`0`6````[2D!``H`
M```$*@$`"@````\J`0`.````&BH!``L````I*@$`!P```#4J`0`'````/2H!
M``<```!%*@$`"````$TJ`0`'````5BH!``L```!>*@$`$````&HJ`0`+````
M>RH!``H```"'*@$`"````)(J`0`'````FRH!``<```"C*@$`$````*LJ`0`'
M````O"H!`!8```#$*@$`!0```-LJ`0`(````X2H!``@```#J*@$`"@```/,J
M`0`)````_BH!`"`````(*P$`%0```"DK`0`)````/RL!`!$```!)*P$`#@``
M`%LK`0`)````:BL!``,```!T*P$``P```'@K`0`7````?"L!`!0```"4*P$`
M"P```*DK`0`$````M2L!``@```"Z*P$`"0```,,K`0!/````S2L!`"H````=
M+`$`!@```$@L`0`(````3RP!`!P```!8+`$`'````'4L`0`A````DBP!`"@`
M``"T+`$`'P```-TL`0`I````_2P!`%@````G+0$`+````(`M`0`*````K2T!
M``L```"X+0$`"P```,0M`0`-````T"T!`!$```#>+0$`$````/`M`0`.````
M`2X!`!`````0+@$`$@```"$N`0`3````-"X!`!,```!(+@$`!@```%PN`0`<
M````8RX!`!X```"`+@$`$P```)\N`0`2````LRX!``4```#&+@$`"````,PN
M`0!B````U2X!``@````X+P$`%@```$$O`0`$````6"\!``8```!=+P$`'```
M`&0O`0`;````@2\!`!8```"=+P$`&P```+0O`0`A````T"\!`"0```#R+P$`
M"P```!<P`0`/````(S`!``8````S,`$`&````#HP`0`=````4S`!`!L```!Q
M,`$`&P```(TP`0`%````J3`!`!,```"O,`$`#@```,,P`0`)````TC`!``D`
M``#<,`$`%@```.8P`0`;````_3`!``D````9,0$`!@```",Q`0`2````*C$!
M`!0````],0$`"P```%(Q`0`5````7C$!``@```!T,0$`!P```'TQ`0`0````
MA3$!``H```"6,0$`#@```*$Q`0`'````L#$!``D```"X,0$`#````,(Q`0`'
M````SS$!`!0```#7,0$`#P```.PQ`0`5````_#$!``8````2,@$`'````!DR
M`0`5````-C(!`!8```!,,@$`,0```&,R`0`^````E3(!`"<```#4,@$`,@``
M`/PR`0`%````+S,!``H````U,P$`#@```$`S`0`)````3S,!`!4```!9,P$`
M"@```&\S`0`6````>C,!`!X```"1,P$`'P```+`S`0`A````T#,!`"(```#R
M,P$`'0```!4T`0`H````,S0!`!\```!<-`$`*0```'PT`0`?````IC0!`"(`
M``#&-`$`'@```.DT`0`J````"#4!`"L````S-0$`(P```%\U`0`I````@S4!
M`#````"M-0$`+P```-XU`0`6````#C8!`"X````E-@$`%0```%0V`0"W````
M:C8!`!(````B-P$`(@```#4W`0`G````6#<!`"<```"`-P$`)0```*@W`0`<
M````SC<!`"````#K-P$`+P````PX`0`@````/#@!`"````!=.`$`+````'XX
M`0!'````JS@!``\```#S.`$`"`````,Y`0`&````##D!``<````3.0$`#P``
M`!LY`0`4````*SD!`!0```!`.0$`$````%4Y`0`;````9CD!``@```"".0$`
M!````(LY`0`1````D#D!`!$```"B.0$`%@```+0Y`0`4````RSD!`!(```#@
M.0$`,P```/,Y`0`(````)SH!`!0````P.@$`!@```$4Z`0`1````3#H!`!<`
M``!>.@$`'P```'8Z`0`2````ECH!``(```"I.@$`!P```*PZ`0`7````M#H!
M``0```#,.@$`!0```-$Z`0`2````USH!``4```#J.@$`$@```/`Z`0`'````
M`SL!`!4````+.P$`%0```"$[`0`2````-SL!`!0```!*.P$`"P```%\[`0`(
M````:SL!``X```!T.P$`#@```(,[`0`9````DCL!``T```"L.P$`$0```+H[
M`0`J````S#L!``\```#W.P$`&@````<\`0`4````(CP!`!,````W/`$`$0``
M`$L\`0`&````73P!`!,```!D/`$`"0```'@\`0`N````@CP!`"T```"Q/`$`
M"````-\\`0`)````Z#P!`!T```#R/`$`"P```!`]`0`:````'#T!`!H````W
M/0$`"0```%(]`0`:````7#T!`!4```!W/0$`%0```(T]`0`3````HST!`!P`
M``"W/0$`"````-0]`0`(````W3T!`"H```#F/0$`(@```!$^`0`(````-#X!
M`!0````]/@$`"@```%(^`0`-````73X!`#0```!K/@$`&0```*`^`0`'````
MNCX!`!$```#"/@$``P```-0^`0`)````V#X!``8```#B/@$`%P```.D^`0`/
M`````3\!`!`````1/P$`$````"(_`0`5````,S\!`!(```!)/P$`%0```%P_
M`0`'````<C\!``<```!Z/P$`"@```((_`0`,````C3\!``(```":/P$`"@``
M`)T_`0`1````J#\!`!\```"Z/P$`(0```-H_`0`*````_#\!``X````'0`$`
M$P```!9``0`;````*D`!`#L```!&0`$`)@```()``0`.````J4`!`!,```"X
M0`$`<@```,Q``0`9````/T$!`!(```!900$`"````&Q!`0`&````=4$!``X`
M``!\00$`!@```(M!`0`(````DD$!``<```";00$`!@```*-!`0`.````JD$!
M``T```"Y00$`$````,=!`0`-````V$$!`!L```#F00$`#@````)"`0`*````
M$4(!``L````<0@$`!P```"A"`0`*````,$(!``\````[0@$`/````$M"`0`.
M````B$(!``H```"70@$`#0```*)"`0`<````L$(!`!T```#-0@$`*````.M"
M`0`G````%$,!`!T````\0P$`'````%I#`0`B````=T,!`!D```":0P$`!P``
M`+1#`0`:````O$,!``P```#70P$`!@```.1#`0`'````ZT,!``H```#S0P$`
M#````/Y#`0`3````"T0!``8````?1`$`&0```"9$`0`<````0$0!``\```!=
M1`$`$0```&U$`0`2````?T0!``\```"21`$`(@```*)$`0`'````Q40!``<`
M``#-1`$`#````-5$`0`2````XD0!`!<```#U1`$`"P````U%`0`*````&44!
M``4````D10$`&0```"I%`0`-````1$4!``<```!210$`*0```%I%`0`2````
MA$4!`(<```"710$`&@```!]&`0`&````.D8!``4```!!1@$`#````$=&`0`&
M````5$8!``@```!;1@$`"@```&1&`0`,````;T8!``4```!\1@$`"0```()&
M`0`*````C$8!`!8```"71@$`$@```*Y&`0`6````P48!`"````#81@$``P``
M`/E&`0`$````_48!`!`````"1P$`"````!-'`0`-````'$<!``<````J1P$`
M-0```#)'`0`)````:$<!``<```!R1P$`%P```'I'`0`2````DD<!``<```"E
M1P$`"0```*U'`0`$````MT<!``L```"\1P$`!@```,A'`0`&````ST<!``<`
M``#61P$`#@```-Y'`0`+````[4<!``@```#Y1P$`%@````)(`0`+````&4@!
M``<````E2`$`%@```"U(`0`A````1$@!``8```!F2`$`"0```&U(`0`%````
M=T@!``D```!]2`$`!P```(=(`0`-````CT@!``P```"=2`$`!P```*I(`0`.
M````LD@!``8```#!2`$`!````,A(`0`S````S4@!`#<````!20$`-@```#E)
M`0`@````<$D!``8```"120$`#P```)A)`0`%````J$D!``@```"N20$`'@``
M`+=)`0`6````UDD!``<```#M20$`!P```/5)`0`@````_4D!``T````>2@$`
M"0```"Q*`0`;````-DH!``8```!22@$`"0```%E*`0`D````8TH!``@```"(
M2@$`#````)%*`0`.````GDH!``@```"M2@$`"0```+9*`0`(````P$H!`#,`
M``#)2@$`+P```/U*`0`R````+4L!`"8```!@2P$`1@```(=+`0`Z````SDL!
M`"H````)3`$`,@```#1,`0`R````9TP!`#,```":3`$`)0```,Y,`0`2````
M]$P!`!,````'30$`#@```!M-`0`@````*DT!`!\```!+30$`'P```&M-`0`=
M````BTT!``D```"I30$`"P```+--`0`*````OTT!``@```#*30$`)P```---
M`0`H````^TT!`#`````D3@$`"@```%5.`0`9````8$X!`",```!Z3@$`#@``
M`)Y.`0`7````K4X!``D```#%3@$`#P```,].`0`5````WTX!`!,```#U3@$`
M*`````E/`0!I````,D\!`!4```"<3P$`$````+)/`0`1````PT\!`!D```#5
M3P$`&@```.]/`0`5````"E`!``<````@4`$`%0```"A0`0`2````/E`!``X`
M``!14`$`&````&!0`0`:````>5`!`#$```"44`$`HP```,90`0`5````:E$!
M``8```"`40$`%P```(=1`0`*````GU$!``L```"J40$`"P```+91`0`;````
MPE$!`!,```#>40$`#P```/)1`0`/`````E(!`!D````24@$`+P```"Q2`0`N
M````7%(!`"P```"+4@$`*P```+A2`0`C````Y%(!`"(````(4P$`&P```"M3
M`0!!````1U,!`!(```")4P$`%@```)Q3`0`9````LU,!`!@```#-4P$`#P``
M`.93`0`7````]E,!`!L````.5`$`%````"I4`0`8````/U0!`"\```!85`$`
M'0```(A4`0`9````IE0!`#$```#`5`$`$@```/)4`0`(````!54!``\````.
M50$`)````!Y5`0`4````0U4!``\```!850$`&P```&A5`0`4````A%4!`!H`
M``"950$`%0```+15`0`=````RE4!`",```#H50$`'@````Q6`0`7````*U8!
M`!0```!#5@$`'0```%A6`0`<````=E8!``L```"35@$`&@```)]6`0`&````
MNE8!``8```#!5@$`"0```,A6`0`3````TE8!``@```#F5@$`"0```.]6`0`(
M````^58!``<````"5P$`!P````I7`0`&````$E<!``@````95P$`%P```")7
M`0`'````.E<!``D```!"5P$`!0```$Q7`0`(````4E<!``8```!;5P$`#P``
M`&)7`0`.````<E<!`!````"!5P$`$0```))7`0`+````I%<!`!0```"P5P$`
M!@```,57`0`L````S%<!`!,```#Y5P$`#0````U8`0`/````&U@!``L````K
M6`$`"P```#=8`0`2````0U@!`"<```!66`$`!@```'Y8`0`)````A5@!`"<`
M``"/6`$`$@```+=8`0`5````RE@!``@```#@6`$`"0```.E8`0`+````\U@!
M``4```#_6`$`)0````59`0`*````*UD!`!0````V60$`"P```$M9`0`<````
M5UD!`"D```!T60$`&````)Y9`0`'````MUD!``4```"_60$`"@```,59`0`P
M````T%D!``<````!6@$`!P````E:`0`1````$5H!`!,````C6@$`!P```#=:
M`0`(````/UH!`!8```!(6@$`#@```%]:`0`.````;EH!`!````!]6@$`%0``
M`(Y:`0`7````I%H!``\```"\6@$`'0```,Q:`0`1````ZEH!`!(```#\6@$`
M"0````];`0`'````&5L!``H````A6P$`.0```"Q;`0`(````9EL!`!0```!O
M6P$`+P```(1;`0`;````M%L!`!4```#06P$`%@```.9;`0`6````_5L!`!4`
M```47`$`$````"I<`0`8````.UP!`!4```!47`$`'@```&I<`0`<````B5P!
M`!T```"F7`$`"@```,1<`0`'````SUP!``D```#77`$`$0```.%<`0`0````
M\UP!``4````$70$`"P````I=`0`*````%ET!`!,````A70$`5````#5=`0`5
M````BET!``T```"@70$`!0```*Y=`0`(````M%T!`!H```"]70$`&@```-A=
M`0`:````\UT!``T````.7@$``@```!Q>`0`$````'UX!`"@````D7@$``P``
M`$U>`0`%````45X!``H```!77@$`#````&)>`0`&````;UX!``8```!V7@$`
M#@```'U>`0`3````C%X!``<```"@7@$`"0```*A>`0`(````LEX!``4```"[
M7@$`!0```,%>`0!7````QUX!``\````?7P$`$@```"]?`0`%````0E\!``<`
M``!(7P$`(P```%!?`0`Q````=%\!``T```"F7P$`"0```+1?`0`/````OE\!
M``L```#.7P$`"@```-I?`0`4````Y5\!`"L```#Z7P$`&@```"9@`0`9````
M06`!`!````!;8`$`!@```&Q@`0`&````<V`!``@```!Z8`$`!@```(-@`0`.
M````BF`!``X```"98`$`!@```*A@`0!,````KV`!`!(```#\8`$`#0````]A
M`0`+````'6$!`!8````I80$`1````$!A`0`'````A6$!``4```"-80$`!P``
M`)-A`0`B````FV$!``@```"^80$`"@```,=A`0`9````TF$!`!H```#L80$`
M"0````=B`0`%````$6(!`",````78@$`20```#MB`0`0````A6(!`"<```"6
M8@$`$````+YB`0`%````SV(!``X```#58@$`"0```.1B`0`/````[F(!``H`
M``#^8@$`!P````EC`0`3````$6,!``<````E8P$`"0```"UC`0`1````-V,!
M``H```!)8P$`"@```%1C`0`-````7V,!``<```!M8P$`$0```'5C`0`4````
MAV,!`!(```"<8P$`#P```*]C`0`0````OV,!`!$```#08P$`$0```.)C`0`0
M````]&,!`!(````%9`$`"@```!AD`0`F````(V0!`!,```!*9`$`#0```%YD
M`0`-````;&0!`!<```!Z9`$`"0```))D`0`-````G&0!``8```"J9`$`"```
M`+%D`0`&````NF0!``<```#!9`$`"P```,ED`0`2````U60!`!4```#H9`$`
M(0```/YD`0`?````(&4!`!@```!`90$`%@```%EE`0`<````<&4!`!X```"-
M90$`&@```*QE`0`'````QV4!``<```#/90$`$@```-=E`0`0````ZF4!``X`
M``#[90$`(P````IF`0`1````+F8!`!8```!`9@$`"0```%=F`0`/````868!
M``@```!Q9@$`$P```'IF`0`)````CF8!``<```"89@$`"````*!F`0`&````
MJ68!``4```"P9@$``@```+9F`0`E````N68!`"(```#?9@$`%P````)G`0`@
M````&F<!`#0````[9P$`#@```'!G`0`C````?V<!`"@```"C9P$`+0```,QG
M`0`M````^F<!`#(````H:`$`%````%MH`0`2````<&@!`!(```"#:`$`%```
M`)9H`0`2````JV@!`!````"^:`$`$@```,]H`0`<````XF@!`"T```#_:`$`
M+0```"UI`0`Q````6VD!`"X```"-:0$`+P```+QI`0`L````[&D!`&`````9
M:@$`(````'IJ`0`2````FVH!`!$```"N:@$`)````,!J`0`Q````Y6H!`!D`
M```7:P$`#0```#%K`0!`````/VL!`$````"`:P$`"@```,%K`0`$````S&L!
M`!4```#1:P$`#@```.=K`0`2````]FL!`!@````);`$`"0```")L`0`(````
M+&P!``P````U;`$`#````$)L`0`-````3VP!``H```!=;`$`#0```&AL`0`'
M````=FP!`"$```!^;`$`"0```*!L`0`'````JFP!`!$```"R;`$`$@```,1L
M`0`0````UVP!`#,```#H;`$``@```!QM`0`(````'VT!`!(````H;0$`"P``
M`#MM`0`&````1VT!`!````!.;0$`!@```%]M`0`&````9FT!`"\```!M;0$`
M&````)UM`0`H````MFT!`%8```#?;0$`%P```#9N`0`C````3FX!`!(```!R
M;@$`"@```(5N`0`-````D&X!`!,```">;@$`#````+)N`0`)````OVX!``P`
M``#);@$`'P```-9N`0`7````]FX!``0````.;P$`$````!-O`0`1````)&\!
M`"4````V;P$`&````%QO`0`9````=6\!`!,```"/;P$`(0```*-O`0`)````
MQ6\!``<```#/;P$`$0```-=O`0`)````Z6\!``H```#S;P$`"````/YO`0`-
M````!W`!``H````5<`$`!0```"!P`0`>````)G`!``8```!%<`$`%0```$QP
M`0`*````8G`!`!$```!M<`$`"P```']P`0`7````BW`!`"P```"C<`$`&P``
M`-!P`0`,````['`!``T```#Y<`$`&P````=Q`0`&````(W$!`"L````J<0$`
M!@```%9Q`0`=````77$!``8```![<0$`"0```()Q`0`?````C'$!`#4```"L
M<0$`!@```.)Q`0`6````Z7$!`!0`````<@$`!````!5R`0`'````&G(!``D`
M```B<@$`"0```"QR`0`*````-G(!``D```!!<@$`"0```$MR`0`)````57(!
M`!L```!?<@$`-0```'MR`0`^````L7(!`!D```#P<@$`)P````IS`0`<````
M,G,!`#P```!/<P$`&````(QS`0`4````I7,!`"X```"Z<P$`)@```.ES`0`'
M````$'0!``D````8=`$`"@```")T`0`+````+70!`!4````Y=`$`$0```$]T
M`0`I````870!`"````"+=`$`+@```*QT`0`S````VW0!``8````/=0$`%0``
M`!9U`0`(````+'4!``@````U=0$`)````#YU`0`4````8W4!`!8```!X=0$`
M$````(]U`0`(````H'4!`!,```"I=0$`"0```+UU`0`0````QW4!``\```#8
M=0$`&````.AU`0`J`````78!``P````L=@$`!P```#EV`0`'````078!`!X`
M``!)=@$`%````&AV`0`&````?78!``L```"$=@$`#0```)!V`0`&````GG8!
M`!$```"E=@$`"````+=V`0`(````P'8!`!,```#)=@$`,````-UV`0!#````
M#G<!`!L```!2=P$`)````&YW`0`:````DW<!``4```"N=P$`$````+1W`0`(
M````Q7<!`!````#.=P$`+````-]W`0`(````#'@!``\````5>`$`$P```"5X
M`0`6````.7@!``T```!0>`$`/````%YX`0`)````FW@!`"(```"E>`$`$@``
M`,AX`0`6````VW@!`"P```#R>`$`"````!]Y`0`3````*'D!`!4````\>0$`
M"@```%)Y`0`3````77D!``@```!Q>0$`%P```'IY`0`<````DGD!``8```"O
M>0$`"````+9Y`0`2````OWD!`!0```#2>0$`%@```.=Y`0`$````_GD!``@`
M```#>@$`"P````QZ`0`.````&'H!``\````G>@$`$@```#=Z`0`2````2GH!
M``@```!=>@$`"0```&9Z`0`H````<'H!`!P```"9>@$`&@```+9Z`0`'````
MT7H!`!(```#9>@$`!@```.QZ`0`.````\WH!`!D````">P$`)@```!Q[`0`+
M````0WL!``<```!/>P$``P```%=[`0`&````6WL!``@```!B>P$`!0```&M[
M`0`/````<7L!`!<```"!>P$`#0```)E[`0`=````IWL!`!T```#%>P$`&@``
M`.-[`0`%````_GL!``L````$?`$`%````!!\`0`)````)7P!``T````O?`$`
M"0```#U\`0`,````1WP!`!0```!4?`$`5@```&E\`0`8````P'P!``<```#9
M?`$`!P```.%\`0`'````Z7P!`!(```#Q?`$`$`````1]`0`1````%7T!`!L`
M```G?0$`$P```$-]`0`5````5WT!`"0```!M?0$`$P```))]`0!B````IGT!
M`!L````)?@$`&@```"5^`0`I````0'X!`!L```!J?@$`&@```(9^`0`D````
MH7X!`!H```#&?@$`&0```.%^`0`:````^WX!``H````6?P$`"0```"%_`0`+
M````*W\!``@````W?P$`%@```$!_`0`/````5W\!`!4```!G?P$`"````'U_
M`0!0````AG\!`$$```#7?P$`*````!F``0!/````0H`!`!L```"2@`$`*P``
M`*Z``0`(````VH`!``H```#C@`$`$0```.Z``0`I`````($!``8````J@0$`
M30```#&!`0`E````?X$!`"$```"E@0$`$@```,>!`0`@````VH$!`!@```#[
M@0$`'````!2"`0`?````,8(!`!X```!1@@$`(P```'""`0`4````E((!``8`
M``"I@@$`"P```+""`0`-````O((!``D```#*@@$`*@```-2"`0`+````_X(!
M``P````+@P$`!P```!B#`0`1````((,!``H````R@P$`!0```#V#`0`6````
M0X,!``D```!:@P$`"0```&2#`0`$````;H,!``X```!S@P$`&````(*#`0`.
M````FX,!``<```"J@P$`%0```+*#`0`>````R(,!`!````#G@P$`#````/B#
M`0`:````!80!`"@````@A`$`$0```$F$`0`1````6X0!`"8```!MA`$`!@``
M`)2$`0`1````FX0!``8```"MA`$`"````+2$`0`&````O80!`!T```#$A`$`
M#@```.*$`0`2````\80!`!`````$A0$`!P```!6%`0`)````'84!``H````G
MA0$`#````#*%`0`/````/X4!`!<```!/A0$`!@```&>%`0`2````;H4!``X`
M``"!A0$`"0```)"%`0`.````FH4!`!@```"IA0$`#0```,*%`0`%````T(4!
M``0```#6A0$`!@```-N%`0`(````XH4!``@```#KA0$`5````/2%`0`T````
M288!`!D```!^A@$`!P```)B&`0`'````H(8!``H```"HA@$`"@```+.&`0`'
M````OH8!``H```#&A@$`%0```-&&`0`,````YX8!``H```#TA@$`#````/^&
M`0`(````#(<!``P````5AP$`"0```"*'`0`'````+(<!`!@````TAP$`"P``
M`$V'`0`'````68<!``H```!AAP$`)0```&R'`0`8````DH<!``<```"KAP$`
M"````+.'`0`*````O(<!``<```#'AP$`$P```,^'`0`3````XX<!``@```#W
MAP$`'`````"(`0`-````'8@!`!X````KB`$`"0```$J(`0`&````5(@!`!``
M``!;B`$`%0```&R(`0`+````@H@!``T```".B`$`%P```)R(`0`'````M(@!
M``L```"\B`$`#P```,B(`0`.````V(@!``4```#GB`$`&````.V(`0`)````
M!HD!`!P````0B0$`$0```"V)`0`S````/XD!`"8```!SB0$`(P```)J)`0![
M````OHD!`!0````ZB@$`/P```$^*`0`T````CXH!`$4```#$B@$`0P````J+
M`0`?````3HL!`&0```!NBP$`)@```-.+`0`S````^HL!`"H````NC`$`$P``
M`%F,`0`8````;8P!`'T!``"&C`$`%P````2.`0`2````'(X!`#@````OC@$`
M@0```&B.`0`\````ZHX!`#<````GCP$`20```%^/`0!$````J8\!`!X```#N
MCP$`$P````V0`0`8````(9`!`!D````ZD`$`)````%20`0`=````>9`!`",`
M``"7D`$`%````+N0`0`;````T)`!`"$```#LD`$`%P````Z1`0`/````)I$!
M`#`````VD0$`6P```&>1`0`L````PY$!`%(```#PD0$`.0```$.2`0`C````
M?9(!`"8```"AD@$`(P```,B2`0!'````[)(!`$<````TDP$`/0```'R3`0`\
M````NI,!`#````#WDP$`*@```"B4`0`J````4Y0!`"T```!^E`$`9P```*R4
M`0!E````%)4!`*L```!ZE0$`%@```":6`0`M````/98!`#$```!KE@$`,```
M`)V6`0!)````SI8!`!X````8EP$`3@```#>7`0`6````AI<!``<```"=EP$`
ML0```*67`0!%````5Y@!`"@```"=F`$`,P```,:8`0`:````^I@!`!X````5
MF0$`+@```#29`0`)````8YD!``@```!MF0$`!@```':9`0`.````?9D!``X`
M``",F0$`$@```)N9`0`*````KID!``@```"YF0$`#````,*9`0`#````SYD!
M`&P```#3F0$`"````$":`0`0````29H!``4```!:F@$`!P```&":`0`%````
M:)H!``4```!NF@$`!P```'2:`0`9````?)H!``@```"6F@$`%0```)^:`0`,
M````M9H!``4```#"F@$`!P```,B:`0`'````T)H!`!4```#8F@$`"@```.Z:
M`0`7````^9H!``8````1FP$`&P```!B;`0`/````-)L!``,```!$FP$`)@``
M`$B;`0`$````;YL!``8```!TFP$`!P```'N;`0`B````@YL!`$$```"FFP$`
M*````.B;`0`J````$9P!`!8````\G`$`)P```%.<`0`@````>YP!`!\```"<
MG`$`(P```+R<`0`>````X)P!`!L```#_G`$`(@```!N=`0`>````/IT!`"L`
M``!=G0$`*0```(F=`0`K````LYT!`!\```#?G0$`(P```/^=`0`A````(YX!
M`!P```!%G@$`)@```&*>`0`G````B9X!`",```"QG@$`'@```-6>`0`<````
M])X!`"(````1GP$`)0```#2?`0`=````6I\!`"4```!XGP$`)@```)Z?`0`Z
M````Q9\!`"$`````H`$`)0```"*@`0`C````2*`!`"0```!LH`$`'@```)&@
M`0`<````L*`!`"0```#-H`$`(````/*@`0`K````$Z$!`",````_H0$`"0``
M`&.A`0`3````;:$!`!H```"!H0$`&@```)RA`0`:````MZ$!``H```#2H0$`
M$````-VA`0`9````[J$!`!(````(H@$`$P```!NB`0`B````+Z(!``@```!2
MH@$`"0```%NB`0`D````9:(!`"<```"*H@$`+P```+*B`0`A````XJ(!``P`
M```$HP$`^@```!&C`0`1````#*0!`!4````>I`$`"@```#2D`0`-````/Z0!
M`!0```!-I`$`'P```&*D`0`(````@J0!`#$```"+I`$`'````+VD`0`:````
MVJ0!``D```#UI`$`%0```/^D`0`+````%:4!`$4````AI0$`+P```&>E`0`9
M````EZ4!`!0```"QI0$`%@```,:E`0`@````W:4!`!````#^I0$`$0````^F
M`0`2````(:8!`!L````TI@$`#````%"F`0`;````7:8!``D```!YI@$`&P``
M`(.F`0`*````GZ8!`!P```"JI@$`"````,>F`0`C````T*8!``<```#TI@$`
M"0```/RF`0`)````!J<!`#$````0IP$`!P```$*G`0`0````2J<!`!0```!;
MIP$`$0```'"G`0`+````@J<!``T```".IP$`"0```)RG`0`7````IJ<!``T`
M``"^IP$`%@```,RG`0`2````XZ<!`!<```#VIP$`%0````ZH`0`)````)*@!
M``L````NJ`$`&0```#JH`0`$````5*@!`"H```!9J`$`#P```(2H`0`'````
ME*@!``4```"<J`$`#````**H`0`2````KZ@!``L```#"J`$``P```,ZH`0`,
M````TJ@!``L```#?J`$`!@```.NH`0`2````\J@!``D````%J0$`$P````^I
M`0`4````(ZD!``X````XJ0$`*P```$>I`0`7````<ZD!`!8```"+J0$`#```
M`**I`0`D````KZD!``8```#4J0$`$0```-NI`0!&````[:D!``\````TJ@$`
M#````$2J`0`'````4:H!``0```!9J@$`%````%ZJ`0`&````<ZH!``<```!Z
MJ@$`"````(*J`0`&````BZH!``T```"2J@$`#P```*"J`0`%````L*H!`!X`
M``"VJ@$`(@```-6J`0`:````^*H!`!T````3JP$`#P```#&K`0`"````0:L!
M``0```!$JP$`$````$FK`0`&````6JL!``<```!AJP$`!````&FK`0`0````
M;JL!`$<```!_JP$`$0```,>K`0`I````V:L!`"0````#K`$`1````"BL`0`0
M````;:P!`&4```!^K`$`&P```.2L`0!8`````*T!`"X```!9K0$`%@```(BM
M`0`P````GZT!`#,```#0K0$`)`````2N`0`C````*:X!`"<```!-K@$`$P``
M`'6N`0`P````B:X!`#````"ZK@$`%P```.NN`0`2`````Z\!`!0````6KP$`
M3P```"NO`0`3````>Z\!`&T```"/KP$`5````/VO`0`G````4K`!`!(```!Z
ML`$`&@```(VP`0`4````J+`!`"(```"]L`$`&P```."P`0`:````_+`!`%P`
M```7L0$`%@```'2Q`0`+````B[$!``8```"7L0$`!P```)ZQ`0`(````IK$!
M``H```"OL0$`&P```+JQ`0`6````UK$!`!H```#ML0$`)@````BR`0`1````
M+[(!``D```!!L@$`!````$NR`0`.````4+(!`!````!?L@$`!P```'"R`0`(
M````>+(!`!L```"!L@$`#````)VR`0`+````JK(!`!$```"VL@$`"P```,BR
M`0`'````U+(!`!0```#<L@$`#@```/&R`0`7`````+,!``L````8LP$`#@``
M`"2S`0`+````,[,!``4````_LP$`#0```$6S`0`&````4[,!``8```!:LP$`
M$0```&&S`0`"````<[,!``H```!VLP$`"````(&S`0`(````BK,!`"8```"3
MLP$`!@```+JS`0`,````P;,!`!````#.LP$`#@```-^S`0`)````[K,!``D`
M``#XLP$`!`````*T`0`0````![0!`!(````8M`$`!P```"NT`0`-````,[0!
M`",```!!M`$`"@```&6T`0`%````<+0!`!8```!VM`$`!0```(VT`0`"````
MD[0!``L```"6M`$``0```!`#``"'`@``&@,``*L%````````'P(``$X!```U
M!```J`4``$H"`````````````.<#````````D`0``*`!``"J`0```````,4"
M````````104```````"?!0```````&@$`````````````"D"```H`P``1P8`
M`/0````O!@``,0(```,#`````````````/4````O!0``508``&4#````````
M;@,``!H!````````7`$```````"[````)@(``,P!````````9P0``'$$```\
M`0``NP$```````#9`@``60(``",#``">`@``B@0``&$`````````````````
M```S`P````````````"I`P``OP0`````````````/@0``'X````^`0``^P``
M````````````*P,``.(%````````8````&$#``"F`0``JP(``.`$````````
M`````#H!```H!```T@(``-\%```2`P``600```````!R!@```````+,$```;
M`P``H04`````````````]@$```````",!````````$T$``!-!0``O`$`````
M````````E`4``.<%``````````````@"````````1P```%L$```R!```````
M```````I`````````+,!`````````0$``!T#````````6@8``*,```!)!0``
MD`(`````````````$P8``'\!````````_@$``)\#``!N!@``````````````
M````J0$``(X`````````DP```&\$``#?!```&`0`````````````-@$``)L%
M````````S`(``($#````````'0(``"X!``""!```,P4``&,&````````SP4`
M`.<!`````````````#<```!:````^00``*<"``!D`P``N0(```````"F`P``
M``````````"4`0``/P$``(D$``#'!```L@,``+P"````````X0```!D`````
M````6```````````````C@$``#,!````````O````#\$``"I`@``HP$```H"
M``"M````)08````````K!```E0````0"````````4@`````````M````````
M`$,&``!D`@``W`0``"T&````````MP,`````````````<@4``.X#``#"`P``
M````````````````````````````````?00```(!```,`P``/0(``)T#``"-
M!````````)4!``#W`@``P0```$X%````````)@,``'P#``#M````A0$``/P"
M``#^`@``$@4````````*`0``L@``````````````LP4``,,"``!B!0``$P$`
M`*X$``!(`@``3`0``,X````J!`````````@&```O````'@```%L&```F!0``
M=P,```````#O`P``F04``-(!``#Z!0``1@4``-$!```0`@``.`8``%`"``"A
M`P``X04``#(%```4`0``&`8``&D&```S!```C@,```($``!/!```6@0``(@"
M```V!0``1@,```("``!F!0``60,``%$&``!'`0``"P(``%,"```O!```````
M`)(```#/`P``00$``/4$`````````````/X```"$````308``+<"```[`@``
M`````,\!```&!````````-4#```%`0``VP0```````#1!0``P`$``'<%````
M````$0```$X`````````S00``+H"````````1`8```D#````````*`(``'D%
M``"*`0``_P0``"T$```:!```704``.\"``!$`@```````*P!``!N`@``+P,`
M`+P#```-!@``\P0``/P!``"C!0``O0(``(T!``"3!```8@(``#4#``!6`@``
MF`0``"($``"1`0``^````%8```#2!0``[0,``.4```#J````'@$``'8```![
M`P``5@,````````R````>0```(4#``#X!```L`(``/(%````````G0$``&0`
M```$`0``M@,``&4```#1````4`0``%D&```_````,@(``$L%````````````
M``````#3!```H`4````````&`P``J````'4#``#W!0``808``!P$``"3`@``
M4@0``!$"``"$`P```````"4```#_`P``````````````````(0,````````]
M!@``O04``#<#```````````````````C`@``B04```L&````````W@```)L`
M``!T`````````*0"```U`@``/@8```````!K!@``%08``$,"``"/`P``5P8`
M`)X$`````````````&4&```?`P```````*X"```=`0``VP(``,`%```^`P``
MNP4``)````#[`P``'@8```````#*`0``S``````````S`````````/,%``"N
M`0```````-T%``!6`0````````````#4````+@8``)H`````````6P,``+@!
M````````A@(``)<$`````````````!P%``!4````#`0``.@```"O`@``````
M`)($``!#`P``J04``+8"```\!```A00``'L`````````]@(``*4"``"$!```
M%@(``&P"``!"````Q`$```H&`````````````)8!````````700``#0"```@
M!0```````!````!2`P```````*<%``!M`@``M`(``.D%``!_`P``.P0``%8$
M``!)`@```````&,```!Q````20```,4!````````7````)L!``!T`@``;```
M`/D!````````P`,``'<`````````\@0``&8!``"N!0``J@4``)X#````````
M>``````````\`@````````X%```!`P``4`$``$X$```Z!0``.@0```4#``!.
M!@```````*(``````````````%,$``"-`P````````````#R`0```````/\%
M``"'`0``D`$``+$%``"+`P``(`````````#)`0``NP0``+0$``#+!0``````
M`!\&``"=!0``7P(```````!O`@``9P$```````#>`@``C`````````#8`@``
M=`$``(P#``#R`@```````)H$``!G`P``1`0``/@!``#8!0````````(#``")
M````I0$```````!K```````````````1!```+`,``!`$``#A`0``&`4`````
M``"F`@``-P4``'X%``"^`P`````````$`````````````(X%``!@!```10``
M`*L!``"+!```?````-<#``"V`````````&P!``"W````$`4`````````````
MOP,```````!T!@``30(``.\$``"$`0``+`$````````T````Q`,``-$#````
M````,0,``$@%``!3`0```````.X$``!O!0``W0$```,!```O`@``+````$<"
M````````ZP(``!\!``#@`P``2@,``'("````````J@(``*T%``">!0``````
M``H$``"_`@``%P8``&8"``!F`````````!8```"(`0``4P4``"4#``"T````
M0@0`````````````R`(``+4$```]````Y0,`````````````#`8``+`#``"2
M`P``U@```$@$```9`@```````.0#````````*P(``)\!``#D!```%@8`````
M``!L`P``#````+L"````````8@,``````````````````"P$```A````4@8`
M`(D#````````"@,``&X!``"(`````````!<"``!1!0``#@`````````U````
MA0(```````#D`@``;`4``'L$``!H````\0````````!X`0``\0(```````!<
M!0``E`0``)P%``!(````W`4``-L````]!0```````/$$````````]P0`````
M```8`@``6`,``%@%``"?````FP0```L$````````2@`````````O`0``DP$`
M`"H%``````````````````"U!0```````*,"``"A!````````(T%````````
M7@8``'(!```\`P``V@,``.8%``!T`P``^P(``(,%``#C!````````"4"``!+
M`@```````````````````````$4#````````_04``+@"```K````,0$``.T%
M``"7`@``I`4```````#.!```K`0````````.`@``B@(``"H#``#3`@``````
M`/D%`````````````.,!``#$`@```````$L#```?!```WP```#8&``"]`0``
M4P8````````````````````````1!@```````*@#```-`0``C`4``),#````
M````X`$```````!@`P``7@$``,0%``"O`P``!P4``%T#``!5!```F@,`````
M``!$`P```````#H&``!D!@```````$T!````````#P$```\%``!'!```N@4`
M`/,```#1`@``N0```!@#``#7`@``>@,``'P!```9`P``E`,``*\!``!=`0``
M3P```/(#``!X`@``8@8````````R`0``YP``````````````&P0```````"A
M`0````8```````"S````F`$``/8#```````````````````9!```@P(`````
M``!?`0``.`,``,L$```D!````````"<%``#V````^@```'8%``#R````M0,`
M`,<#``````````````8&``#!`@``%00``%0$```Q!```8P,```````!<`P``
M7P```.D#``````````````````#+`@``U0```#,"``!``0``.`4``+H```!>
M````0`,``,L```#@````[`0``-$$```H````\0,``(<#``!1`@``I04`````
M````````9@8``-@#``#5`0``*P$``.P%``!\!0``30,``!`!```@!@``.0(`
M`,,%```>`P``8`$``&T%``"``P``8P$``(D"````````M0(``"<&``"]!```
M`````)<%``!7!```````````````````G`(``&8#```T`P``%P```'@%````
M````$04```````!R````(@,``,D"````````M`,``(@%``!Q`0``#0,``$<%
M``!:`P```````!("``!&`@``)@$``"("``!0!0``IP````````"@`P``90$`
M`.<$``#F`0``D0````````!J!```604``!0#```.`P``[````*<!```W`@``
M=0(`````````````<P$`````````````E@(```````#%!```R@,``(`"``!M
M`P```````+`$````````<P8``/H"``!)!```30```.`"``!3````6P4``-(#
M```(`P``%@,```````"6!```W@4``,D```"C!````````.@"``"V`0``````
M``````"\!```M0```(,```!G````5`8`````````````Y`4```````#-`0``
M50,``/P%````````.`0``%@"````````+@(``-X#``!^!``````````````@
M!```Q@$``,`$``"L`@``U@0``+8$``#&````I`,``,T%``#S`0``(0$``,<%
M````````?0$````````M!0```````.(#```4`@``[`$``'4```#6`0``!P0`
M`,D$``!4`0``0@$```````!;`0``J`(``!0`````````#`4`````````````
M+@`````````Z`@`````````````<`0``.@``````````````50(``'8"``"H
M`0``CP4``$$#``!N!````````-T$```L!@``J@,``&\#```,`@``0P4``%X#
M``"2`0``20,``"8&```]`P``K@```&<%``#4`P````````````#T!0``S`4`
M`"0"````````%`8``)$"````````J0```%<!``!A!```K0(```````#K`P``
M````````````````GP(`````````````I0````````"?!```V@$```0$```V
M`P``\`4``+4!``#"!```]04``-8#``!6!0``K00``,$#``#8``````````X!
M``!Z!````````$D!``#<`@````````````````````````````#&!0``D0,`
M`%(!```_!0```````&`"````````X@$``%X$````````;`0``'`&```1`P``
M-@(``#````"L````%@$````"``"Q````:@,``.$$````````,@,``",!````
M````<`,``-,%`````````04````````C!````````````````````````!$!
M``!O`0``L````%P&``!U!0``%P,```````#3`0``X0(``+$"``!I`````P8`
M`+P%```A!````````'@$``#0`0```````#P&``#B````IP,``.($````````
MMP$``)<!````````O@0``"@&``!`!```[00``!(```#E!`````````````#K
M!````````)H"``````````````@$``#>`0````````````##!````````.L!
M``"N`P``XP```'`"``!,!@``'08````````6!0``D00``$H!``!S!```A`(`
M`%4```#J`0````````````!R!```-P8``)D$``#J`P``+@0```,%``!'`P``
M7P0```````"L`P``?@(``'L!``"Q!```?P```#D%``#&!```2`$``$("````
M````*08``#8$``"*````[0$```````````````````````#H!0```````.8#
M```0!@``Y04``($```#*!0````,``',#`````````P(``)`#``#_````2@0`
M```````G````^P0``$$```"&`P``CP$``"0```"/````-@```,8"``!C`@``
M3`(``%4!``!Y`0``.`(``*L```![!0```````/T"````````3@,``),%``!M
M````]P,``&\```#.`P``@0(``)@"`````````````#<!```-````SP```(4`
M````!0``H@0``%P$````````R0,``.P"``"8````*@(```\#````````````
M`%\&``#^!```&P8``+$#``"X````K0,``#D$```Z`P``VP4``+,#```%!@``
MS`0``+\```#-````!P(``%$```#V!0``.P4```````"[`P``[P````````#N
M`@``>`,`````````````&0$```H%````````AP0``!,#``!_`@``````````
M``"C`P``-`4``%4%```U!0``H@4```````!H`@``?`0``/\!```&````#@8`
M`&4%``!R`P``````````````````ZP4``!H"````````&``````````M`@``
M:`,``%H!``!S!0```````%8&``#D`````@8`````````````2P8``,$$````
M````9P8``+D$````````F`,``)P`````````)P$``$4$```'`0``PP$``$`&
M```$````@````'D"``!7````2`,```````"+`@``@@``````````````8@0`
M``````#G`@``R````/4!```%!```40,``-4$````````B0$```8%``"6`P``
M@00``*\$````````C@0```````!M`0``QP$```D$``"^`0``+@4````````)
M!0``'@(``&L"``"(!```70(``+0%````````!0````````!8`0``.0``````
M````````TP,``-0!`````````````*T!``#9`````````"D%``"4````=00`
M`#$```#8`0``=P0````````;!0``:@(``,(`````````400``-<!``!!!@``
MH@(``"`#``!W`0``Z@(``/,#````````60$``-D$```D`P``]`,``(L```"^
M``````````L#``#/!```Z`0``"4%```;`0``R`,``$H&```Y`P``MP4``#0$
M``"6````.0$```````"+!0``<0,````````K!@``$P(``(\"``!(!@``60``
M`$L!````````TP```",%``"O`````````"D#``!A`0``^`(``$D&```8`0``
M0@8``-T#````````10$```````"7`P````````````!1`0`````````````]
M`0```````,$!``"D`0``A@```&0!``!`!0````````````!4`@``4`8``*D$
M``"*`P````````````#9!0``C0````````!,`0```@4``#P`````````8`8`
M`,,#``#.`@```````)H!````````JP0``%<%``!B`0```````/P#``"P`0``
MT@```+H!``#(!0``OP4``%T&``#I`````````!T$``!M!`````````````!4
M`P````````\&``"4`@``I`0``&L%````````(08``+H$````````>@```/D"
M``!J!0``W0(``/4#````````1````(L!``"5!0``;08``(,$``"S`@``````
M`)<```!!!````````)T$``"5`@``C`(``((%``#Z!`````````````!4!0``
MT`,```````#H`P``"P4```````"#`P``UP```#L!````````F0,``"(&````
M`````````/<!``#O!0``:@$``,(%``"_`0``:@8``&$%```7!```````````
M``#F````;P8```4"``!Q!0``1@$``#@!````````[@4``+("````````````
M``````!U`0```````#<$````````@`4``#0&````````<`$``%@&``"X`P``
M`````$X"```X````"0$``,4%`````````````+<$``!Y`P```````(`!``!,
M!0``!P,``($%``!S`@``P04```````````````````````#]`0``Y@0`````
M``!A`@``+@,``$\"``"Q`0``^P4```````"<`P```````%@$``#M`@``V@4`
M`'8$``#0!```004``&@&``#-`P```````````````````````.,"``!Q`@``
M%`0``&X%``"A`@``3P8``,<"``"F!````````'T"``#9`P``:`$```````#6
M!0```````&@%``!,````%0```)("```!!```I@4````!```P`@``[@$``-`"
M``"A````QP```!X$``!7`@``*`$``/H!``````````````@!```2!@``````
M`)@%```:````H@,``'H%``#<`P``/@4``-D!``#+`0``&P(``.P#```P!@``
M`````.,%`````````````,0$```B`0``R@0``-\"``!^`0``*P4```````!=
M````_0```-<$``!]!0``O@(```X$```Q!@``?P4``!4!``"X!0``A@$```0#
M``#*````"P```)(%``"-`@``'P```/@#``#P`@```````'D$````````!P``
M`,H"````````A@4``(<%``#@!0``4@4``!P```";`@``U@(``+D%``"9````
M.P8``%P"``!T!```1@```````````````````#D&``!W`@``J`0```````!P
M!```J@0`````````````(`(``!T%``!&!@```````/4"```_`P``E00`````
M``````````````````"P!0``-08``'\$``#D`0``V@```/0!```:!0``>@$`
M`+0!``#;`P``Z0$```````"`!```Q````((!````````/P8```D&``!K`0``
MU04```````"L!0```````(("```!!@``#P0````````;``````````4%```+
M`0```````*4#````````.P,``/T$``#H`0``,`,``$,$``#4`@``'`,``-\#
M```*````JP,``/`!``!K`P```````&D!``#:`@``U`0```$"```9!@``S0(`
M`"D!`````````````"`!````````)@0``&<"``#]`P``VP$``(H%``!/`0``
MS@$```````#N````V@0````````)`@``=@,``$8$````````L@0``$\#```&
M`@``9@0``!($``">`0```````%<#``"Z`P``/00``"<"````````(@4``/X%
M````````\`,``!T```!P````900``,8#````````0P$```T%```$!@``````
M`(\$``!B````2P0```````"R`0``Z0(``/0"``!$!0``4````-($````````
M#0(```D```!;`@``$P```+(%````````:0,``#0!```<`@``F0(```<&``!N
M`````````#X"``#Y`P``$P0``"4$``"@`@``3`,``!D%````````Z@0`````
M````````\04```````#E`0``ZP````(`````````%P4``'L"``#B`@``)P,`
M`*H```"5`P``R`$```````"^!0``]P```$\%```5!0``4`,``"H```"]`P``
M`````(8$``````````````````#0````WP$``"0&````````.P````````"=
M`@``(P```"$"````````4P,``"H&``#"`@``N`0``!<!``"$!0``(@```'8!
M``#Z`P``N0,``&D"``":!0``<`4``/8$``#P!````````,4#````````)0$`
M`$(%```P!````````````````````P````````";`P``P`(``"$%```R!@``
M)@```'T#``!D!``````````````(!0``B`,``````````````````*8```#_
M`@```````$0!``!>!0``>@(``/@%```C!@``U`4``)P!```S!@```````&,$
M``!!`@```````(,!``"G!`````````T$``!:!0`````````````6!```,04`
M````````````%`4``,L#``!``@``0````)$%```(````F0$``!4#``!?`P``
M\`````,$``#=````^0```$4&``!C!0``I````,X%``",`0``*00``*\%``#\
M````N0$``,\"```3!0``Q0`````````/````=`4``+8%``#0!0``)P0`````
M`````````````,````!D!0``!`4``)T```#)!0``:04``#4!``!J````Y@(`
M```````&`0``W@0``.,#``#\!````````"H!``!E`@``,`4``#`!```>!0``
M4@(``.D$``!Q!@``Y0(``)P$``!]```````````````<!@``]`0``,(!``">
M````<P```%L```!?!0``_@,```````#5`@``W````.\!```/`@``/`4``-@$
M```_`@``C@(``!\%````````?`(``%H"```L`@``\P(```````#A`P``)`$`
M``````##````+`4``!(!``!*!0``7@(``$(#``""`P``#`$`````````````
MH`````````#(!```S`,``$4"`````````````"T!``"0!0``Z@4``$L`````
M`````````"T#````````O0```)8%````````W`$``'X#``"%!0```````&P&
M```5`@``*`4``"0%``"B`0``\0$```````"@!```UP4``(<````^````8`4`
M`&D$``"E!````````!H&``!#``````````````#[`0``:P0``($!````````
M```````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`
M("AY97-T97)D87DI`"!A="``)60@)7,@86YD("5S`"5D+61A>2!F;W)E8V%S
M=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-I9VX@57``)7,@
M5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E
M<R`E<P`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`
M)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A
M<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G=7-T:6YG
M("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`
M,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A
M8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!3:&]W97)S
M`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B
M;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I
M<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C
M;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`
M061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E
M.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@
M=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D
M('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R
M97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!
M9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!
M9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA
M`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D
M(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I
M9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@
M24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@
M24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA
M=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG;VQA
M`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!
M;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES
M(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!
M<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV
M92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N
M:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S
M8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I
M9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@
M=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X
M8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O
M<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A
M:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O
M<P!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU
M9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`
M0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S
M<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A
M;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"
M=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE
M;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL
M92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@
M3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T
M:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN
M9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE
M<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/
M9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A
M<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@
M2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D>0!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#
M;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET
M;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM
M;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`
M0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER
M;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE
M9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"X`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`
M0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO
M="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I;B!P
M=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@
M)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R
M96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O
M871I80!#=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT
M(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U
M="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#
M>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`
M1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU
M;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$
M969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L
M971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD
M('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM
M87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W
M(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/
M<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE
M=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L
M:6,`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U
M9W,`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R
M;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q
M=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E
M<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD
M<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R
M`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`
M17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A
M<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$94
M4"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC
M97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@
M=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M
M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A
M=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S
M(BX`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L
M86YD<P!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W
M(%-H;W=E<G,`1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z
M("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I
M;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I
M;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A
M=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&
M;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R
M="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T
M:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N
M9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@
M82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R
M='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`
M1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A
M;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I
M;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@
M:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`
M1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R8V@`
M1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD
M`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S
M="!B92!N;VXM96UP='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA
M;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE
M80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO
M;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R
M`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@*$E3
M3RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L
M<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I
M`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N
M8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A
M9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O
M8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL
M)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E
M<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@
M4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y
M;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU
M;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO
M="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@
M0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E
M;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F
M<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`
M26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S
M<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA
M`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`
M26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L
M90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`
M26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E
M:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R
M="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU
M;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F
M=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`
M26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E
M`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E
M9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A
M=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M
M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN
M=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!)
M;G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA
M;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E
M<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E
M("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF
M>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU
M<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE
M;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE
M;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI
M8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U
M=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,
M87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I
M;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E
M<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO
M`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN
M`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI
M9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I
M=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R
M:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`
M3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,
M:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I
M;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S
M92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R
M<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E
M<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M
M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G
M:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y
M<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@
M;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-
M871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W
M960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA
M>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N
M=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@
M='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`
M365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE
M`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@
M;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-
M:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E
M<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A
M=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO
M;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R
M870`36]O;B!0:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L
M;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I
M9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY
M($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.
M3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE
M=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@
M55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O
M;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.
M971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-
M;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W
M:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I
M;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/
M(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!L;V-A
M=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E
M8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R
M='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`
M3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!2
M96=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@
M>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P
M*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N
M($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`
M3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@
M<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`
M3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O
M9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE
M9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C
M=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R
M`$]F9FEC90!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D
M(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M
M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES
M=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N
M:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN
M("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N
M<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I
M9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC
M($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3
M:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@5"U3=&]R;7,`4%](
M4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R
M86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E
M8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N
M=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI
M<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E
M<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX
M96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@
M=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U
M9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@
M=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@
M8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R
M97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E
M($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O
M;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@
M8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T
M90!286EN(%-H;W=E<@!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@
M;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@
M0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L
M;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A
M:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M
M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q
M=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E
M.B``4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!2
M97-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I
M9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG
M:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N
M+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E
M(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U
M;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O
M;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I
M86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG
M;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H
M96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA
M`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3
M8VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L
M96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W
M(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@
M=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@
M=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--
M4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E
M;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3
M970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O
M<'1I;VYS+@!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R
M86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E
M>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG
M:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B
M87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAR
M:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U
M<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA
M:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<@4VAO=V5R`%-N;W<@
M9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES
M;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T
M:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A
M;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@
M8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D
M9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET
M(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA
M`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I
M;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I
M:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP
M=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U
M;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S
M8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*
M86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M
M4W1O<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE
M<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S
M="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!
M9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T
M;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U
M<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A
M:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED
M92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S
M92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N
M`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R
M92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E
M+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B
M;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B
M=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@
M;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I
M=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@
M($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L
M>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT
M)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T
M:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C
M871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H
M92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H
M:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@
M<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES
M(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`
M5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S
M92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I
M9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@
M>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R
M9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E
M=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N
M(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@
M82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T
M('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N
M9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@
M<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A
M9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@
M=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N
M`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I
M8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L
M96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`
M5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O
M=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I
M;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R
M:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5
M+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@
M<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A
M8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R
M(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE
M=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE
M=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C
M=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A
M=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E
M<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I
M;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH
M*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD
M97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ
M(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE
M9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D
M($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL
M:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@
M<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA
M=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A
M=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL
M97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R
M;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`
M57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E
M<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN
M('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU
M97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N
M97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N
M=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L
M.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W
M("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G
M:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I
M8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!7
M05).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S
M+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A
M<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!7
M96(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L
M("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U
M*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA
M<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H
M87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z
M`%=I:VD`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M
M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`6"U2968`6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+
M97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O
M(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO
M=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL
M(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S
M<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E
M9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T
M:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@
M8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`
M66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@
M<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@
M86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@
M16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M
M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA
M;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@
M<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E
M<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y
M`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U
M;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI
M;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?
M1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN
M`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]0
M97)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P
M97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L96YD87(`8V%L;0!C
M;&EC:R!H97)E`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S`&@Z`&EM;65D:6%T90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`
M<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T
M96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N
M9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A
M=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-"TQ,2TR.2`Q,CHU,BLP,C`P"DQA<W0M5')A;G-L871O
M<CH@5FEL:75S(%-U;7-K87,@/'9I;&EU<T!L;FLN;'0^"DQA;F=U86=E+51E
M86TZ($QI=&AU86YI86X@/'9I;&EU<T!L;FLN;'0^"DU)344M5F5R<VEO;CH@
M,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U
M.2TQ,PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*'!R:67P
M("5S(&1I96YA<RD`("AM>6=T=6MA<R`E<RD`("CP:6%N9&EE;BD`("AV86MA
M<BD`(``E9"`E<R!I<B`E<P`E9"UD:65N^"!P<F]G;F]ZZP`E<R`M('!A<W1A
M8F$`)7,@86YT<W!A=61A<P`E<R!+0@`E<R!P<F]F:6QA:W1I:V]S('9E:6MS
M;6%I("T@<&%T=FER=&EN:6UA<P`E<R!R96=I<W1R86-I:F$`)7,@;G5O<W1A
M=&]S`"5S(&IA=2!E9WII<W1U;VIA+@`E<R`E<R`E<P`E<R!Y<F$@<')I=F%L
M;VUA<P`E<R!M:6YU=.MS`"5S(&YE<F%S=&%S+@!N=6\@)7,@:6MI("5S(&GP
M("5S`"5S(&%D<F5S^"!K;GEG96SK`"5S(&MA;&5N9&]R:75S`"5S('7^<F'P
M^"!K;GEG96SK`"5S(&1A<F+X('/@<F'P87,`)7,Z("5S`"P@9_MS:6%I("5S
M("5S`"P@:VEN=&$@;G5O("5S(&EK:2`E<P`M+2!P87-I<FEN:VET92`M+0`Q
M,B!V86QA;F3X(&9O<FUA=&%S`#(T('9A;&%N9/@@9F]R;6%T87,`,C0@=F%L
M86YD;W,`T&EA;2!B;&]K=6D@<F5I:V%L:6YG82!V:65T82!D=6]M96[X(&)A
M>NMJ92X`P79Y:V\@<FEM=&$@:VQA:61A`$YO<NMD86UI('7^:V]D=6]T:2!L
M86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%!'4"!R86MTX"X`3F]R
MZV1A;6D@<&%T:6MR:6YT:2!P87-I<F'P>73@(&QA:?!KX"!P<FEV86QO=&4@
M='5RZW1I('9I9?#@:N$@4$=0(')A:W3@+@!.;W+K9&%M:2!A=&MO9'5O=&D@
M;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!0
M1U`@<F%K='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+@!.;W+K9&%M
M:2!P87-I<F'P>71I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@
M:7(@<VQA<'3@:N$@4$=0(')A:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F
M<F%ZYBX`3F]RZV1A;6D@871K;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5R
MZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%(')A:W1U<RP@8F5I(/YI
M;F]T:2!S;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@<&%S:7)A\'ET:2!L86GP
M:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%,O34E-
M12!R86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N`$YO<NMD86UI
M('7^:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%,O
M34E-12!R86MTX"X`04T@<F]D>6UA<P!!32]030!!4$D@240`07!I92#PX2!R
M961A:W1O<FGX`$%P:64N+BX`5FES:?!K86D@87!AZ&EO:F4`5FES:?!K86D@
M<&5R('9I9'5RX0!3:7-T96UA(&YE='5R:2!T96ES:?@@<W5K=7)T:2!61E,@
M:V%T86QO9^`N`%-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!F
M86ELX"X`4VQA<'1A_F]D:7,`4^!S:V%I=&$@=?[P86QD>71A+@!!<'-K86ET
M80!3=6MU<G1I`%-U:W5R=&D@<&]G<G5PX0!3=6MU<G1I('!O=&5I<V5S`$)L
M;VMO(.%T97)P:6UA<SH`4W5K=7)T:2!N875JX"!G<G5PY@!3=6MU<G1I(&YA
M=6IA<R!T96ES97,`3F%U:F\@=F%R=&]T;VIO('-U:_MR:6UA<SH`4')I9.MT
M:2!S='5L<&5LX0!.875J^"!N87)I^"!P<FEDZVII;6%S`%-U:W5R=&D@<&]R
MX`!0<FEDZW1I("5S(&UE;FEU('!R:64@36]Z:6QO<R#A<F%N:VGX(&IU;W-T
M;W,`P71R875K=&D@X2!A9')E<_@@:VYY9V5LYCH`P71R875K=&D@X2!M86YO
M(&%D<F5S^"!K;GEG96SF.@!3=6MU<G1I('9A<G1O=&]JX`!687)T;W1O:O@@
M:_MR:6UA<R!I\&IU;F=T87,N`$%D<F5S87,`061R97-A:0!!9&UI;FES=')U
M;W1I("T@9V%L:2!N=7-T871Y=&D@=&5I<V5S(&MI=&EE;7,@=F%R=&]T;VIA
M;7,`5F%L9'EM87,`0F%N97)I86D`069G86YI<W1A;F%S`$%L8F%N:6IA`$%L
M_GER87,`4')A=F%R9.L`3'EG:75O=&D`3'EG:6%V:6UA<SH`5FES;W,`5FES
M:2!P<FES:6IU;F?F('9A<G1O=&]J86D`5FES;W,@9W)U<.MS`%9I<V]S('1E
M:7/K<P!6:7-O<R!K971U<FEO<R!P=7/K<P!,96ES=&D@:V5L973@(&%D<F5S
M^`!,96ES=&D@;F%U9&]T:2!S=7+[\&EU;W3@('/@<F'PX#\`2F%U(&5G>FES
M='5O:F$`06QT97)N871Y=G5S($E-4U`@<')I<VEJ=6YG:6UA<P!!;'1E<FYA
M='EV=7,@24U34"!S;&%P=&'^;V1I<P!!;'1E<FYA='EV=7,@24U34"!V87)T
M;W1O:F\@=F%R9&%S`$%L=&5R;F%T>79U<R!E;"X@<&'P=&\@861R97-A<P!!
M;'1E<FYA='EV^W,@\&%B;&]N86D`06QT97)N871Y=G5S('1E:W-T87,`06UE
M<FEK;W,@4V%M;V$`P79E9.MT92!N96QE:7-T:6[@(')E:6OP;>8N`$%N9&]R
M80!!;F=O;&$`06YG:6QA:0!!;F]N:6UI;FES('!R;WAY('-E<G9E<FES`$%T
M<V%K>6UA<P!!;G1A<FMT:61A`$%N=&EG=6$@:7(@0F%R8G5D80!-;V1U;&ES
M`$UO9'5L:7,@=F5I:VEA(&=E<F%I+@!0<FET86EK>71I(&ER('!O\&%K:6%M
M<P!0871V:7)T:6YT:0!"86QA;F1I<P!!<F%B:?!K82`H5VEN9&]W<RTQ,C4V
M*0!!<F-H>79O(&9A:6QO(&1Y9&ES`$%R8VAY=F\@9F%I;&\@<&%V861I;FEM
M87,`07(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2`E<R!R96=I<W1R86-I:F]S
M('!R8?!Y;>`_`$%R9V5N=&EN80!!<FWK;FEJ80!!<FWK;FGP:V$@*$%235-#
M24DM."D`365N87,`07)U8F$`2W)I<W1A=7,@_F5N9VEM;R#A(&1A;F?X('-A
M;&$`06-S:6D@;65N87,`07II:F$O4F%M:6]J;R!V86YD96YY;F\@<F5G:6]N
M87,`07(@<')A\'ET:2!P871V:7)T:6YT:2!P<F]F:6QA:W1I:V]S('9E:6MS
M;75S/P!0<FES:WER:6UO('-T=6QP96QI86D`0F%N9&]T92!I\'1R:6YT:2!N
M965G>FES='5O:F%NZ&G@(&=R=7#F+@!"86YD;W1E(&GP=')I;G1I(&YE96=Z
M:7-T=6]J86[H:6%S('1E:7-E<RX`0F%N9&]T92!R961A9W5O=&D@;F5E9WII
M<W1U;VIA;NAI87,@=&5I<V5S+@!"86YD;W1E(')E9&%G=6]T:2!N965G>FES
M='5O:F%N=.$@96QE;65N=.`N`$%T<FEB=71A:0!2=6=P:OMT:7,`075S=')A
M;&EJ80!!=7-T<FEJ80!!=71H7V-Y<G-Q;#H@;F5R87-T87,@<F5I:V%L:6YG
M87,@24U!4"!M;V1U;&ES+@!!=71H7V-Y<G5S.B!C>7)U<R!N971U<FD@<F5I
M:VEA;?@@9V%L:6UY8FGX+@!!=71H7V-Y<G5S.B!N97)A<W1A<R!R96EK86QI
M;F=A<R!)34%0(&UO9'5L:7,N`$%U=&A?9G1P.B!N97)A<W1A<R!R96EK86QI
M;F=A<R!&5%`@;6]D=6QI<RX@4W5K;VUP:6QI=6]K:71E(%!(4"!S=2`M+65N
M86)L92UF='`N`$%U=&A?:6UA<#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!
M4"!M;V1U;&ES+@!!=71H7VMR8C4Z(&YE<F%S=&%S(')E:6MA;&EN9V%S(&MR
M8C4@;6]D=6QI<RX`075T:%]L9&%P.B!N97)A<W1A<R!R96EK86QI;F=A<R!,
M1$%0(&UO9'5L:7,N`$%U=&A?;&1A<#H@<W5K=7)T:2!V87)T;W1O:N`@)7,@
M;F5P879Y:V\N(%-E<G9E<FEO('!R86YE\&EM87,Z(`!!=71H7VQD87`Z(&GP
M=')I;G1I('9A<G1O=&]JX"`E<R!N97!A=GEK;P!!=71H7VQD87`Z(&%T;F%U
M:FEN=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO`$%U=&A?;6-A;#H@;F5R87-T
M87,@<F5I:V%L:6YG87,@34-!3"!M;V1U;&ES+@!!=71H7W-M8F%U=&@Z(&YE
M<F%S=&%S(')E:6MA;&EN9V%S('-M8F%U=&@@;6]D=6QI<RX`4')I<VEJ=6YG
M=&D@;F5P879Y:V\`4')I<VEJ=6YG=&D@;F5P879Y:V\N("5S`%)!1$E54R!S
M97)V97)I<R!N96QE:63^:6$@875T96YT:69I:W5O=&ES+@!0<FES:6IU;F=T
M:2!P<FEE($944"!S97)V97)I;R!N97!A=GEK;RX`1V%L:6UI(&QA=6MA:3H`
M07IE<F)A:63^86YA<P!"3T9((&%T<VEP<F'P>6UA:0!&;VYA<P!&;VYO('-P
M86QV80!.971E:7-I;F=A<R!K97)B97)O<R!S;&%P=&'^;V1I<RX`3F5T96ES
M:6YG87,@:V5R8F5R;W,@=F%R=&]T;VIO('9A<F1A<RX`0F%H86UA:0!"86AR
M96EN87,`0F%L=&GP:V$@*$E33RTX.#4Y+3$S*0!"86=L861E\&%S`$)A<F)A
M9&]S87,`4&%G<BX@;&EN:6IO:F4`0F%L=&%R=7-I:F$`0F5L9VEJ80!"96QI
M>F%S`$)E;FEN87,`0F5R;75D86D`0G5T86YA<P!':6UT861I96YI<P!";&]K
M;R!P87)A;65T<F%I`$)L;VMO('1I<&%S`%!A<W1O<FEN=&D`0F]L:79I:F$`
M073^>6UO<P!+<F'P=&%S`$MR8?!T;R!S=&]R=6UA<SH`2W)A\'1A:0!";W-N
M:6IA(&ER($AE<F-E9V]V:6YA`%9I<V]S`$)O='-V86YA`$%P8>AI;VIE`$)U
M=F5T('-A;&$`0G)A>FEL:6IA`$)R:73X($EN9&EJ;W,@=F%N9&5N>6YO('1E
M<FET;VIA`$)R=6[K:F%U<R!D87)U<V%L96UA<P!"=6QG87)I:F$`4W7^>6WK
M=&%S('/@<F'P87,`0G5R:VEN87,@1F%S87,`0G5R=6YD:6IA`%164P!#4D,`
M0U),('!A<VMI<G-T>6UO('!U;FMT86D`7T-E;.MS(&YU<W1A='EM86DN+BX`
M2V%L96YD;W)I=7,`4F%M=0!+86UB;V3^80!+86UE<OMN87,`3F5V96EK:6$@
M875T;VUA=&EN:7,@<VQA<'1A_F]D_FEO('!A:V5I=&EM87,L('-U<VES:65K
M:71E('-U(&%D;6EN:7-T<F%T;W)I=6UI+@!.96=A;&EU('!R:7-I:G5N9W1I
M('!R:64@24U!4"!S97)V97)I;SH@)7,`2V%N861A`$%T\&%U:W1I`$%T\&%U
M:W1I('!R;V)L96UO<R!P<F%N9?!I;>``3F5G86QI=2!I\'1R:6YT:2!F86EL
M;R`B)7,B+@!.96=A;&EU(')A<W1I(&QA:6MI;F]J;R!K871A;&]G;RX`3F5G
M86QI=2!A<&1O<F]T:2`G=&%R9V5T1FEL92<@<&%R86UE=')O+@!.96=A;&EU
M(&GP=')I;G1I(&MA=&%L;V=O("(E<R(N`$YE9V%L:74@:?!T<FEN=&DN($5G
M>FES='5O:F$@)60@<&_P86MI86DN`$YE9V%L:74@<&5R<OOP:75O=&DN(,%V
M97-T87,@X7)A\/@@<VMA:>AI=7,@;F5S=71A;7!A('-U(.%R8?#X('-K86GH
M:75M:2!D=6]M96[X(&)A>NMJ92X`3F5G86QI=2!N=6MR96EP=&D@_FEN=73K
M<R#A(&YU<F]D>73@(&YU;65RX2X`2V5I<'9E<F1I<P!0879A9&EN:6UA<P!+
M871E9V]R:6IO<P!+86EM86[X('-A;&]S`$UO8FEL=7,@=&5L969O;F%S`$-E
M;.MS(&YU<W1A='EM86D`5&%R<&%I(&-E;.MS93H`0V5LZW,@;G5S=&%T>6UA
M:0!487)P86D@=&%R<"!C96QI^#H`36]B:6QU<VES('1E;&5F;VYA<P!+96QT
M^"`H25-/+3@X-3DM,30I`$-E;G1R90!#96YT<FENZW,@069R:6MO<R!297-P
M=6)L:6MA`$-E;G1R:6[K<R!%=7)O<&]S("A)4T\M.#@U.2TR*0!397)T:69I
M:V%T;R!D971A;.MS`%-E<G1I9FEK871O('1E:7/K<P#(861A<P!086ME:7-T
M:0!*^W/X('9A<F1O(&ER(&%D<F5S;RP@:W5R:75O<R!M871Y<R#^;6]NZW,L
M('-K86ET86YT>7,@:7(@871S86MI;NMJ86YT>7,@X2!*^W/X(&QA:?!K=7,L
M(&ME:71I;6%S+@!3:6UB;VQI<P!085]T:6MR:6YT:2!N=6]R;V3@+BXN`,AI
M;.L`2VEN:6IA`$MI;FEE=&GP:V$@<&%P<F%S=&$@*$=",C,Q,BD`2VEN:65T
M:?!K82!T<F%D:6-I;NL@*$)I9S4I`%!A<VER:6YK:71E('-L87!T8?YO9.$`
M4&%S:7)I;FMI=&4@=F%R=&]T;VIO('9A<F3@`%!A<VER:6YK:71E(&MA:7`@
M=F%I>F1U;W1I(&1A=&%S.@!087-I<FEN:VET92!S=7+[\&EU;W1O('/@<F'P
M;R!S=&EL:?@`2V%LZV3X('-A;&$`2VQA<^MS("5S(&[K<F$N`$=I961R80!)
M\'1R:6YT:2!-4R!/9F9I8V4@_GEM97,`5F%R=&]T;VIO(&1U;VUE;O@@=F%L
M>6UA<SH@)7,`2?!V86QY=&D@=F%R=&]T;VIO(&1U;VUE;FES`$GP=F%L>71I
M('9A<G1O=&]J;R!D=6]M96YI<P!4YG-T:0!#;&EC:V%T96QL('!E<B!(5%10
M`%7^9&%R>71I(&QA;F?@`$1E8F5S=6]T80!$96)E<W5O=&$`2V]K;W-O("A+
M>6QI;F=O*2!S86QO<P!4=?#H:?@@8V5L:?@@:W)A\'3X(')O9'EM87,`2V]L
M=6UB:6IA`%-P86QV80!087-I<FEN:VET92!S<&%L=N``4W!A;'9O<R!P87-I
M<FEN:VEM87,`4W1U;'!E;&EA:3H`4W1U;'!E;&GX('!A=F%D:6YI;6%I`$MO
M;6EK<V%I`$MO;6%N9&$`2V]M86YD:6[K(&5I;'5TZP!+;VUE;G1A<F%S`%9A
M<F1A<R]P879A<F3K`$MO;6]R86D`2V]M<&%N:6IA`$MO;7!I=71E<FEA:0!3
MX&QY9V]S`$YU<W1A='EM^"!P86ME:71I;6%I`$MO;F9I9_MR=6]T:2`E<P!3
M;&%P=&'^;V1I<R!D87(@:V%R=.``2V]N9V%S`$1E;6]K<F%T:6[K($MO;F=O
M(%)E<W!U8FQI:V$`4')I<VEJ=6YG=&D@;F5P879Y:V\N`%!R:7-I:G5N9W1I
M(&YE<&%V>6MO.B``4')I<VEJ=6YG=&D@<')I92!V:67P^&KX(')A:W3X('-E
M<G9E<FEO(&YE<&%V>6MO+@!0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K
M=/@@<V5R=F5R:6\@;F5P879Y:V\L(&YE<SH@)7,@*"5S*0!0<FES:6IU;F=T
M:2!P<FEE($944"!S97)V97)I;R!N97!A=GEK;RX`2V]N:V%K=&%I('/K:VUI
M;F=A:2#A=')A=6MT:2#A($K[<_@@861R97/X(&MN>6=E;.8`5.9S=&D`2W5K
M;R!S86QO<P!,86EMZW,@_FEN=73K<P!+;W!I:G5O=&D`2V]P:6IU;W1I('!A
M<VER:6YK:6W@`$MO<W1A(%)I:V$`1')A;6)L:6\@2V%U;&\@2W)A;G1A<P!.
M97!A=GEK;R!U_FMO9'5O=&D@4$=0(&QA:?!K;RX`3F5P879Y:V\@<&%S:7)A
M\'ET:2!01U`@;&%I\&MO+@!.97!A=GEK;R!U_FMO9'5O=&D@4R]-24U%(&QA
M:?!K;RX`3F5P879Y:V\@<&%S:7)A\'ET:2!3+TU)344@;&%I\&MO+@!.97!A
M=GEK;R!P<FEDZW1I(&MO;G1A:W1O+B`E<P!.97!A=GEK;R!A=71E;G1I9FEK
M=6]T:7,@X2!,1$%0('-E<G9E<N$N`$YE<&%V>6MO('!A=&EK<FEN=&D@8F%L
M86YS;RX@)7,`3F5P879Y:V\@<W5K=7)T:2!D:7-T<FEB=6-I:F]S('/@<F'P
M;RX@)7,`3F5P879Y:V\@871K;V1U;W1I(%!'4"!D=6]M96[X+@!.97!A=GEK
M;R!A=&MO9'5O=&D@4R]-24U%(&1U;VUE;O@N`$YE<&%V>6MO(&GP=')I;G1I
M(&MO;G1A:W1O+B`E<P!.97!A=GEK;R!I\'1R:6YT:2!D:7-T<FEB=6-I:F]S
M('/@<F'P;RX@)7,`3F5P879Y:V\@;G5S=&%T>71I(&=A=NMJ;R!E;"X@<&'P
M=&\@861R97-O+@!0879Y:V\@9V%U=&D@=FES;W,@861R97/X(&MN>6=E;.MS
M+@!.97!A=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+@!.
M97!A=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?#X('/@<F'P
M;RX`3F5P879Y:V\@9V%U=&D@=FEE\&]J;R!R86MT;R!I\"!R86MT^"!S97)V
M97)I;RX`3F5P879Y:V\@871I9&%R>71I("5S+@!.97!A=GEK;R!A=&ED87)Y
M=&D@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&EO("5S`$YE<&%V>6MO('-K86ET
M>71I("5S+@!.97!A=GEK;R!P86ME:7-T:2!S;&%P=&'^;V3^:6\@\&EA;2!V
M87)T;W1O:G5I+B!+86D@:W5R:2!A<F)A('9I<V$@:6YF;W)M86-I:F$@>7)A
M(&YE=&EK<VQI+B!086)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S=7-I<VEE
M:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA;&EN
M9V$@<&%G86QB82X`3F5P879Y:V\@9V%U=&D@04-,`$YE<&%V>6MO(&=A=71I
M(&%D<F5S^"!K;GEG96SK<RX@)7,`3F5P879Y:V\@9V%U=&D@9&ES=')I8G5C
M:6IO<R!SX')A\&\N("5S`$YE<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ;W,@
M<^!R8?#X+B`E<P!.97!A=GEK;R!N=7-T871Y=&D@<V5R=F5R:6\@9V%L:6UY
M8FGX`$YE<&%V>6MO(&%T:V5I<W1I(&YU<W1A='EM^"X`3F5P879Y:V\@:?!S
M875G;W1I("5S(&YU<W1A='EM^"X`3F5P879Y:V\@<&%D87)Y=&D@871S87)G
M:6[K<R!N=7-T871Y;?@@:V]P:6IO<RX`3F5P879Y:V\@<&%I9?!K82!,1$%0
M('-E<G9E<GEJ92X`3F5P879Y:V\@871N875J:6YT:2!K;VYT86MT;RX@)7,`
M3F5P879Y:V\@871N875J:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`
M3F5P879Y:V\@<F%S=&D@36]Z:6QO<R#A<F%N:VGX(&IU;W-T;W,N(,%S:71I
M:VEN:VET92P@:V%D(&II(&%T:61A<GET82X`4FEB;W1A<R!T96MS=&%S`%9A
M;'-T>6+K`$MU<G-A:0!3=6MU<G1I`%-U:W5R=&D@;G5O<F]DX`!3=6MU<G1I
M(&YA=6K@(&%P<F'PX`!3=6MU<G1I('!A:V%T86QO9VEU<P!3879I;FEN:V\@
M=&5I<^MS`$MR961I=&ENZW,@:V]R=&5LZW,@;G5M97)I<P!+<F]A=&EJ80!+
M=6)A`$1A8F%R=&EN:7,@;&%I:V%S`-!I=6\@;65T=2!54DP@>7)A`$1A8F%R
M=&ENZW,@;W)O('/@;'EG;W,`1&%B87)T:6[K<R!SX&QY9V]S.B``1&%B87)T
M:6YI<R!S=&EL:75S`%9E:6MS;?@L(&%T;&EE:V%M^"!P<FES:6IU;F=U<R!P
M<FEE("5S+"!N=7-T871Y;6%S+@!097)K96QT:0!097)K96QT:2!P87-I<FEN
M:VEMX`!+:7!R87,`2VER:6QI8V$@*$M/23@M4BD`2VER:6QI8V$@*%=I;F1O
M=W,M,3(U,2D`2VER:6QI8V$O56MR86EN:65T:?!K82`H2T])."U5*0#(96MI
M:F]S(%)E<W!U8FQI:V$`1$0`2V%S9&EE;@!$=6]M96[X(&UE9/YI;R!N87+P
M>6MLZP!$871A`$=A=71A`$1A=&]S('!A<VER:6YK:6UA<P!$:65N80!)\'1R
M:6YT:2!?<W1U;'!E;.$`1W)U;V1I<P!$9?!I;71A:6YI86D@<VMA:>AI86D`
M4W5M8?YI;G1I(&%T:71R875K:6W@`%-T86YD87)T:6[K('-P86QV80!3=&%N
M9&%R=&EN:7,@87!R8?!A<P!!<&EB<NO^:6UA:0!)\'1R:6YT:0!)\'1R:6YT
M:2!G<G5PY@!)\'1R:6YT:2!T96ESY@!6:7-I\&MA:2!I\'1R:6YT:2!L86GP
M:W5S`$GP=')I;G1I(&-E;.8`2?!T<FEN=&D@<W1U;'!E;.$`2?!T<FEN=&D@
M96=Z:7-T=6]J86YTX2!A;'1E<FYA='EV^"#P86)L;V[@`$GP=')I;G1I(&5I
M;'5TY@!)\'1R:6YT:2!P87-I<FEN:W3@(&%P<F'PX`!)\'1R:6YT:2#PX2!S
M='5L<&5LX0!)\'1R:6YT:2#P:>`@96EL=73F`%!R:7-T871Y;6\@;&%I:V%S
M`$1A;FEJ80!0<F]B;&5M;W,@87!R8?!Y;6%S`$%P<F'P>6UA<P!$971A;&EA
M=2`H=&%I<"!P870@_FG[<NMK:71E($AO<F1E(&QO9R!F86EL92DZ`$%D;6EN
M:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L=7,@87!R8?!Y;6%S+@!6>7-T
M>6UA<P!$<NMG;G5M87,`1'+K9VYU;6%S('!A<VMU=&ENYB!V86QA;F3@.B``
M1'+K9VYU;6%S.B``2W)Y<'1I<R!I\"!K86ERZW,@X2!D9?!I;N8`2W)Y<'1I
M<R!I\"!D9?!I;NMS(.$@:V%I<N8`2V%T86QO9V%S`%)O9'ET:2`R-"UI^"!V
M86PN(&9O<FUA=.`_`%9A:7ID879I;6\@;G5S=&%T>6UA:0!2;V1Y=&D@<')O
M9W)O;N8@*%1!1BD`5F%I>F1A=FEM;R!F;W)M871A<P!,86GP:V\@<')I<W1A
M='EM;R!P<F%N9?!I;6%I`$3^:6)U=&ES`$YE=')I;G1I`$YE<VEK<F5I<&MI
M=&4@=&EE<VEO9VEA:2#A(&UA:6YT96YA;F-E+G!H<`!!<B!P:7)M87,@X7)A
M\&%S('ER82!L875K;R!V87)D86D_`$1O;6EN:6MA`$1O;6EN:6MO<R!297-P
M=6)L:6MA`$%T<VES:?AS=&D`071S:7-I^'-T:2`E<P!!='-I<VGX<W1I('-U
M9V5N97)U;W1U<R!N=7-T871Y;75S(&MA:7`@4$A0('-K<FEP=.`N`$GP<VES
M:VQE:63^:6%N=&ES('/@<F'P87,`5F%I<W1A:0!%;"X@<&'P=&\@861R97-A
M<P!%4E(`16MV861O<F%S`$ME:7-T:0!+96ES=&D@8FQO:V\@<&%R86UE=')U
M<P!2961A9W5O=&D@9W)U<.8`4F5D86=U;W1I('1E:7-E<P!2961A9W5O=&D@
M=&5I<V5S`"5S('1E:7-I^"!R961A9V%V:6UA<P!+96ES=&D@;G5S=&%T>6UU
M<SH`)7,@=&5I<VGX(')E9&%G879I;6%S`%5G9'EM87,`16=I<'1A<P!386QV
M861O<F%S`$5L96UE;G1A<RXN+@!%;0!%;"X@<&'P=&%S`$5L+B!P8?!T;R!A
M9')E<V%S`$5L+B!P8?!T;R!A9')E<V%I('1U<FD@<W5T87!T:2X`16PN('!A
M\'1O(&%D<F5S87,@<W4@<&%T=FER=&EN:6UU`-!Y<'-E;NMLZW,`WFEN=73K
M('1U\.AI82X`4F5Z=6QT871A<R!T=?#H:6%S+@!.96YU<F]DZW1E('!A:67P
M:V]S('1E<FUI;O@`3&5I<W1I('1E:W-T92#A=&5R<'1I('!A=F5I:W-LZVQI
M=7,@:?`@3G5O=')A=6OX(&=A;&5R:6IO<S\`P6IU;F=T:2!D9?!I;FEO:F\@
M<&5LZW,@;7EG='5K;R!M96YI=3\`1V%L:6YI86D@;65T86D`2?!P;.MS=&D@
M<F5D86MT;W)I^`#!<F'P>6MI=&4@:VQA=7-I;>`L(&MU<FES(&IU;7,@8G5S
M('7^9'5O=&%S(&IE:6=U('!A;6ER\&ET92!S879O('-L87!T8?YO9.$L('!V
M>BXZ("=K;VMS('ER82!*^W/X(&=Y=OMN;R!V87)D87,_)SH`P79E<VMI=&4@
M<&%V96EK<VSK;&EO(%523`!%:W9A=&]R:6[K($=V:6[K:F$`17)I='+K:F$`
M2VQA:61A`$ML86ED82!L86GP:V4N`$5S=&EJ80!%=&EO<&EJ80!%=&YI;NMS
M`$5U<F]P80!+87,@,34@;6EN=>AI^`!+87,@,B!M:6YU=&5S`$MA<R`S,"!S
M96MU;F3^:?@`2V%S(#4@;6EN=71E<P!+:65K=FEE;F\@<')I<VEJ=6YG:6UO
M(&UE='4`2V%S('!U<W9A;&%N9.$`2V%S(&UI;G5TY@!0879Y>F3^:75I.@!6
M>6MD>71I`$GP<VML96ES=&D`4F5I:V%L:6YG87,@)RDG`%)E:6MA;&EN9V%S
M(/YO9&ES(&%R8F$@:V%B=73K<V4@X7)A\'ET87,@<&%I9?!K;W,@:W)I=&5R
M:6IU<P!'86QI;VII;6\@9&%T80!%:W-P;VYE;G3K`%1E:W-T;R!S<&%L=F$`
M3G5S=&%T>6WX('-I=6YT:6UA<R!P97(@1E10+@!+;&%I9&$@;G5S:V%I=&%N
M="!N=7-T871Y;75S+@!.97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE($Q$05`@
M<V5R=F5R:6\N`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4TU"('-E<G9E
M<FEO+@!.97!A=GEK;R!N=6MO<&EJ=6]T:2!I\"`B)7,B+@!.97!A=GEK;R!N
M=6MO<&EJ=6]T:2#A("(E<R(N`$YE<&%V>6MO('-U:W5R=&D@;F%U:F\@4T%3
M3"!R>?!I;RX`3F5P879Y:V\@<&5R:V5L=&D@X2`B)7,B+@#0=F5L;G5S`$9O
M;&ML86YD^"!S86QO<R`H36%L=FEN86DI`$9A<F5R^"!S86QO<P!&86MS87,`
M5F%S87)I<P!!=')O9&\@;'EG`$%T<F]D;R!L>6<Z(`!4<G5M<&%L86EK:7,@
M;&EE='5S`$9I9/YI<P!&86EL^"!S:V%IZ&EU<SH@)7,@9F%I;&%S`$9A:6SX
M('-K86GH:75S.B`E<R!F86EL86DH^"D`1F%I;/@@='9A<FMY;6%S`$9A:6QO
M('!A=F%D:6YI;6%S`$9A:6QO('!A<VER:6YK:6UA<P!&86EL;R!S:75N=&EM
M87,`3F%R\'EK;.L@;F5P86QA:6MO(&9A:6SX('-I=6YT:6UO+@!&:6QT<F%I
M`%-U;VUI:F$`4&ER;6]J:2!P=7/K`%!I<FUA<VES(&ME='9I<G1I<P!.=7-T
M871Y=&%S(&MO969I8VEE;G1A<P!!='9I<FOPZ&EA<P!)\&3K<W1Y;6%S`%+[
M:V%S`$MA=&%L;V=A<R`E<R!N965G>FES='5O:F$`5&5K<W1O('-P86QV80!-
M86ES=&%S`$YA<O!Y:VSK;7,L(&MU<FEO<R!N97!A;&%I:V\@<&%V96EK<VSK
M;&GX`$]R^"!P<F]G;F]ZZR`H5$%&*0!/<O@@<')O9VYO>NMS(&%P:6UT:7,@
M*.%S:63K;>MK:71E+"!K860@\&D@9G5N:V-I:F$@9W)A_FEN82!I<B!D:65N
M;W,@:7(@;F%K=&EE<R!P<F]G;F]ZYCL@<&5R(&1I9&5L:7,@<VMA:>AI=7,@
M9V%L:2!S=61A<FMY=&D@9&EZ86ENX"D`4&%M:7+P;W1E('-A=F\@<VQA<'1A
M_F]DX3\`1F]R;6]S`$9R87KK`$9R87II^"!T:7!A<P!&<F%ZZW,`1G)A>NMS
M(#(`1&ES:W5S:6IO<P!097)S:75N=&EM86D`4&5N:RX`2W)A\'1I;NMS`%!R
M86YC^WII:F$`4')A;F/[>FEJ82P@365T<F]P;VQI<P!0<F%N8_MZ:6IO<R!'
M=FEA;F$`4')A;F/[>FEJ;W,@4&]L:6YE>FEJ80!0<F%N8_MZ:6IO<R!P:65T
M:6[K<R!T97)I=&]R:6IO<P!.=6\`3G5O(`!0:6QN87,@87!R8?!Y;6%S`%!I
M;&YA=&ES`%!I;&YA<R!V87)D87,`1V%B;VYA<P!'86QE<FEJ82!I\"!K=7)I
M;W,@:?`@:W5R:6]S(&)U<R!R;V1O;6%S('!A=F5I:W-LZVQI<P!'86QE<FEJ
M83H`1V%M8FEJ80!'96YE<G5O=&D@)7,@;G5S=&%T>6UU<P!3=6=E;F5R=6]T
M87,@:V]D87,`1W)U>FEJ80!6;VMI971I:F$`1V%N80!':6)R86QT87)A<P!6
M87)D87,`4F]D>71I`$=A9&5L:7,`1V]O9VQE('!A:67P:V$`3F5S<&%L=F]T
M87,`1W)A:6MI:F$`1W)A:6MI\&MA("A)4T\M.#@U.2TW*0!'<F5N;&%N9&EJ
M80!'<F5N861A`$=R=7!I^"!A9&UI;FES=')A=FEM87,`1W)U<.MS('9A<F1A
M<R!T=7)I(&+[=&D@;F5T=?#H:6%S`$=R=7#K<P!'=F%D96QU<.L`1W5A;6$`
M1W9A=&5M86QA`$=E<FYS:7,`4W9EZ&GX('1E:7/K<P!3=F7H:?@@:VYY9V$`
M1W9I;NMJ80!":7-S874M1W9I;NMJ80!'86IA;F$`2%1-3`!(5$U,07)E82!N
M96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!C96SK<R!E:6QU=.MJ92X`2%1-
M3$%R96$@;F5G86QI(&GP<FEN=&D@<&%S:W5T:6YI;R!S='5L<&5L:6\@;&5N
M=&5LZVIE+@!(5$U,07)E82!N96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!E
M:6QU=.MS(&QE;G1E;.MJ92X`4F5I:V%L:6YG82!(5%10(&%U=&5N=&EF:6MA
M8VEJ82X`2&%I=&ES`$AA<V@M06QG;W)I=&UA<P!-:6=L80!!;G1R8?!TZP!(
M97)D;R!S86QA(&ER($UA:V1O;F%L9&\@<V%L;W,`2&5B<F%J^"`H25-/+3@X
M-3DM."U)*0!!=6OP=&ES`%!A9V%L8F$`4F5D86MT;W)I875S(&YA=61O:FEM
M;W-I('!A9V%L8F$`4&%G86QB:6YI;FMA<P!(96UI<V9E<F$`T'1A:2#H:6$@
M>7)A(&9A:6QO('!R863^:6$Z`%-V87)B=0!?4&]R=&%L87,`T'9E;G1A<VES
M(%-O<W1A<R`H5F%T:6MA;F\@=F%L<W1I:F$I`%!O<G1A;&%S`$YA;?@@861R
M97-A<P!.86WX('1E;&5F;VYA<P!(;VYD^W)A<P!(;VYK;VYG87,`4&]R=&%L
M87,`2&]R9&4O2V]L86(Z(&YE=&5I<VEN9VD@)7,@6$U,(&1U;VUE;GES(/YI
M;G5TZVIE("5S`$AO<F1E+TMO;&%B.B!O8FIE:W1O("5S(&YE871I=&EN:V$@
M:F]K:6$@_FEN=73K`$AO<F1E+TMO;&%B.B!O8FIE:W1O('1I<&%S("5S(&YE
M<F%S=&%S(/YI;G5TZVIE("5S`$AO<F1E+TMO;&%B.B`E<R`B)7,B('/K:VUI
M;F%I(&GP=')I;G1A`$AO<F1E+TMO;&%B.B!I;G1E9W)A8VEJ;W,@=F%R:6ML
M:75K=6D@<F5I:V%L:6YG87,@)V1O;7AM;"<@4$A0(&UO9'5L:7,`2&]R9&4O
M2V]L86(Z(&YE<&%V>6MO('-U:W5R=&D@;F%U:F\@6$U,(&UE9/YI;R!O8FIE
M:W1U:2`E<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@:?!T<FEN=&D@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO(&=A=71I($U)344@240@9&%L
M:6%I("5S('1I<&\`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI
M>G5O=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN
M8VAR;VYI>G5O=&D@96QE;65N=/@Z("5S`$AO<F1E+TMO;&%B.B!N9?YI;F]M
M87,@96QE;65N=&%S("(E<R(`2&]R:7IO;G1A;&D@;&EN:6IA`$AO<FEZ;VYT
M86QU<R!T87)P87,`2&]R:7IO;G1A;&EA:3H`2V%I<"#H:6$@<&%T96MO=&4_
M("A0<F%N9?!K:71E(2D`2VEE:R!S='5L<&5L:?@@;F]R:71E('-U:G5N9W1I
M/P!+:65K(&QA=6OX("AS='5L<&5L:?@I('1E;B!Y<F$_`$MI96L@96EL=>AI
M^"!N;W)I=&4@<W5J=6YG=&D_`$1RZV=N=6UA<P!$<NMG;G5M87,Z(`!*=6UO
M<F5S:V]S`%9E;F=R:6IA`$YE<&%V>6MO('-U:W5R=&D@24U!4"!P8?!T;R!D
MZ_YU=.MS.B`E<P!.97!A=GEK;R!I\'1R:6YT:2!)34%0('!A\'1O(&3K_G5T
MZW,Z("5S`$YE<&%V>6MO(&YU<W1A='ET:2!)34%0('!A\'1O(&3K_G5TZW,@
M9'ED_FEO.B`E<P!)4"!A9')E<V%S`$YE<&%V>6MO(&=A=71I($E0(&%D<F5S
M;RX`25`@861R97-A<R!N971E:7-I;F=A;64@0TE$4B!B;&]K92X`25`@=?YR
M86MI;G1A<RX`7\%T97)P=&D@96EL=73F('9I<O!U:F4`27-L86YD:6IA`%1I
M:R!P:6MT;V=R86UO<P!0:6MT;V=R86UO<R!S=2!T96MS='4`07!R8?!O('!A
M=F%D:6YI;6%S.@!*96D@;F5G86QI=&4@<&5R<VMA:71Y=&D@\&EO(&QA:?!K
M;RP@)7,N`$IE:6=U(&UA=&]T92#P:>`@_FEN=73F('9I971O:B!P879E:6MS
M;.ML:6\L(&MU<N$@;F]R:71E(.%K96QT:2P@=&%I($K[<_@@;F%R\'EK;.L@
M;F5G86QI(&IO(&%T=F%I>F1U;W1I+@!0879E:6MS;.ML:6\@<&5R_FG[<F$`
M4&%V96EK<VSK;&EO(%523`!0879E:6MS;.ML:6\@55),.@!0879E:6MS;.ML
M:7,@:?`@9V%L97)I:F]S`%!A=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,Z`%!A
M=F5I:W-LZVQI;R#A:^ML:6UA<P!686EZ9&%I`,%KZVQI;6%S+"`E9"#^:6YG
M<VYI<P!,875K87,@X6ME;'1A<SH@)7,`P6ME;'1I(&QA=6MA:3H`P5]T97)P
M=&D@96EL=73F(&%P8>AI;VIE`$YE=&5I<VEN9V%S('9E:6MS;6\@:V]D87,N
M`$YE=&5I<VEN9V%S('9A<G1O=&]J;R!V87)D87,@:7(O87)B82!S;&%P=&'^
M;V1I<RX`3F5I=&5I<VEN9V%S('9A<G1O=&]J;R!V87)D87,@87)B82!A;'1E
M<FYA='EV=7,@96PN('!A\'1O(&%D<F5S87,N($)A;F1Y:VET92!D87(@:V%R
M=.`@87)B82!S=7-I<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI
M(&IE:6=U(')E:6MA;&EN9V$@=&]L97-NZR!P86=A;&)A+@!0861I9&EN=&D@
M871I=')A=6MI;>``26YD:6IA`$EN9&EV:61U86S[<R!V87)T;W1O:F%I`$EN
M9&]N97II:F$`26YF;W)M86-I:F$`26YF;W)M86-I:F$`P71R875K=&D@<W1U
M;'!E;.$@7V1E\&ENZVIE`,%T97)P=&D@<&%V96EK<VSK;.$`P71E<G!T:2!L
M96YT96SF`,%T97)P=&D@;G5O<F]DX`#!=&5R<'1I('-T=6QP96SA(%]K86ER
MZVIE`,%T97)P=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&1E
M\&ENZVIE`,%T97)P=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO
M(&MA:7+K:F4`P71E<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@
M87!AZ&EO:F4`P71E<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@
M=FER\'5J90#!=&5R<'1I('!A<F%G<F%FX"!E;&5M96YT;R!A<&'H:6]J90#!
M=&5R<'1I('!A<F%G<F%GX"!E;&5M96YT;R!V:7+P=6IE`,%T97)P=&D@86QT
M97)N871Y=O@@\&%B;&]NX`#!<F'P>6MI=&4@96PN('!A\'1O(&%D<F5SX"P@
MX2!K=7+A(&YO<FET92!G875T:2!N875JX"!S;&%P=&'^;V3A.@#!=&5R<'1I
M(&-E;.8@<&\@=&\`P71E<G!T:2!C96SF('!R:67P('1A:0#!=&5R<'1I('-T
M=6QP96SA(&1E\&ENZVIE`,%T97)P=&D@<W1U;'!E;.$@:V%I<NMJ90#!=&5R
M<'1I(&QA:?!K=7,`P71E<G!T:2!P87)A9W)A9N`@<&\@=&\`P71E<G!T:2!P
M87)A9W)A9N`@<')I9?`@=&%I`,%T97)P=&D@96EL=73F('!O('1O`,%T97)P
M=&D@96EL=73F('!R:67P('1A:0#!<F'P>6MI=&4@<F5I:VEA;>`@871S86MY
M;>`@X2!K;&%U<VEMX"!V:7+P=6IE.@#!=&5R<'1I+W)E9&%G=6]T:2!P879E
M:6MS;.MLX0#!=&5R<'1I+U)E9&%G=6]T:2!N=6]R;V3@`$1I<W1R:6)U8VEJ
M;W,@<^!R8?!U:2!N=7-I^'-T:2!N977^=&5N:V$@:W)E9&ET;RX`3F5U_G1E
M;FMA(&MR961I=&\N`%-K86GH:75S`%-K86GH:?@@<^!R8?!A<P!.971E:7-I
M;F=A<R!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`3F5T96ES:6YG87,@;6]D
M=6QI<RX`3F5T96ES:6YG87,@240N`,%V97-T:2!N971E:7-I;F=I(&1U;VUE
M;GES+@!.971E:7-I;F=A<R!A9')E<V%S+@!.971E:7-I;F=A<R!F86EL;R!F
M;W)M871A<P!.971E:7-I;F=A<R!M<V=?='EP92X`3F5T96ES:6YG87,@87)B
M82!NZW)A(&%P:5]I9"X`4&%R86UE=')A:2!N971E:7-I;F=I(&%R8F$@:O@@
M;NMR82X`3F5T96ES:6YG;W,@<&%V96QD:6UO<R!T96ESZW,N`$YE=&5I<VEN
M9V%S('!R;W1O:V]L87,N`$YE=&5I<VEN9V%S(&]B:F5K=&%S`$YE=&5I<VEN
M9V%S('-I=6YTZVIO(&%D<F5S87,N`$YE=&5I<VEN9VD@=6YI:V]D;R!D=6]M
M96YY<RX`26YV96YT;W)I=7,`27-L86UI\&MA($ER86YO(%)E<W!U8FQI:V$`
M27)A:V%S`$%I<FEJ80!-96YO('-A;&$`27IO;&EU;W1O<R!4+6%U9')O<P!)
M>G)A96QI<P!)\&1A=NMJ87,`2W5R<WEV87,`271A;&EJ80!*86UA:6MA`%-A
M=7-I<P!*87!O;FEJ80!*87!O;FGP:V$@*$E33RTR,#(R+4I0*0!$_F5R<VES
M`$IO<F1A;FEJ80!,:65P80!":7+^96QI<P!0:6QN86D`3'EG:75O=&D@8V5N
M=')E`$QY9W5O=&D@<&EL;F%I`$QY9VEU;W1I(&MA:7+K:F4`3'EG:75O=&D@
M9&7P:6[K:F4`2V%Z86MS=&%N87,`2?!S875G;W1I(&]R:6=I;F%LX#\`2V5N
M:6IA`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@2V5R8F5R;W,@<V5R=F5R
M:6\N`$)R86YD=6]L:6\@;F%U:F]K86D`4F%K=&\@:_MR:6UA<P!286MT;R!A
M='-P875D87,`4F%K=&\@:6QG:7,`4F%K=&\@=&EP87,`4F%K=&\@<&%N875D
M;VII;6%S`%)A:W1A<R!J874@>7)A('9I9?#X:O@@<F%K=/@@<V5R=F5R>6IE
M+@!686EK86D`2VER:6)A=&ES`$1E;6]K<F%T:6[K($MO<NMJ;W,@3&EA=61I
M97,@4F5S<'5B;&EK80!+;W+K:F]S(%)E<W!U8FQI:V$`2V]RZVII971I\&MA
M("A%54,M2U(I`$MU=F5I=&%S`$MI<F=I>FEJ80!?2?!DZW-T>6UA<P!+86QB
M80!,86]S;R!$96UO:W)A=&ENZR!,:6%U9&EE<R!297-P=6)L:6MA`$%N=')A
M('!U<^L`4&%S:W5T:6YI<R!K971V:7)T:7,`071N875J:6YT83H`4&%S:W5T
M:6YI<R!P<FES:6IU;F=I;6%S.B`E<P!087-K=71I;FES('!R:7-I:G5N9VEM
M87,Z("5S(&GP(&%D<F5S;R`E<P!0<FES:6IU;F?K=&4@<&ER;>`@:V%R=.``
M3&%T=FEJ80!496ESZP!)\&3K<W1Y;6%S`$IE:6=U(&YE;F]R:71E(&YE;F%U
M9&]T:2!K<F'P=/@L('!A;&EK:71E('1U\.AIX`!,:6)A;F%S`$MA:7+K:F4`
M2V%I<FEO:FD@86YT<F'P=.L`2V%I<FEO<VEO<R!R96EK\&WK<P!,97-O=&%S
M`$QI8F5R:6IA`$QI8FEJ;W,@07)A8O@@16UY<F%T86D`3&EC:'1E;O!T96EN
M87,`4VUU;&MU<R!L:65T=7,`3F5D:61E;&ES(&QI971U<P!.961I9&5L:7,@
M;&EE='5S(')Y=&4`3F5D:61E;&ES(&QI971U<R!V86MA<F4`3F5D:61E;.L@
M;&G[=&ES`$YE9&ED96QI<R!L:65T=7,@<W4@<&5R:_MN:6IA`$YE9&ED96QI
M<R!S;FEE9V%S`$YE9&ED96SK(/!L87!D<FEB80!,:6UE<FEK87,`3G5O<F]D
M80!.=6]R;V1A(.$Z`%!A9&%R>71I(&5L+B!P8?!T;R!A9')E<^`@;G5O<F]D
M82#A(&QA:?!K;R!R8?!Y;6\@<'5S;&%PX0!.=6]R;V1O<P!,:6YU>"!L86EM
MZW,@_FEN=73K<P!2;V1Y=&D@+2!V87)T;W1O:F%S(&=A;&D@;6%T>71I(&MA
M=&%L;V=O('1U<FENX0!2;V1Y=&D@9'5O;65N^"!B87II^"!SX')A\.``4F]D
M>71I('!A9V%L8F]S('1E;6%S`%)O9'ET:2!L96YT96QI^"!SX')A\.``2V]N
M9F5R96YC:6IO<R!A<F-H>79A<P!+;VYF97)E;F-I:F]S('!A9V%L8F$`2V]N
M9F5R96YC:6IO<R!)1`!+;VYF97)E;F-I:F]S('-A=FEN:6YK87,`4F'P>71I
M(.$@:V]N9F5R96YC:6K@`%!R:7-I:G5N9W1I('!R:64@:V]N9F5R96YC:6IO
M<P!!='-I:G5N9W1I(&YU;R!K;VYF97)E;F-I:F]S`%9A<G1O=&]J^"!SX')A
M\&%S('7^9')A=7-T87,N`$QI=&5R873[<F$`3&EE='5V80!+<F%U;F$N+BX`
M5FEE=&EN:7,@;&%I:V%S.B``3&]K86SK(&ER(&QA:6MA<P!6:65T80!0<FES
M:6IU;F=T:0!!='-I:G5N9W1I`%!R:7-I:G5N9VEM;R!D87)B86D`4')I<VEJ
M=6YG=&D@;F5P879Y:V\N($YE=&5I<VEN9V%S($K[<_@@;G5R;V1Y=&%S('9A
M<G1O=&]J;R!V87)D87,@:7(O87(@<VQA<'1A_F]D:7,N`%!R:7-I:G5N9W1I
M(&YE<&%V>6MO+@!);&=A<R!T96MS=&%S`$UE:6SK`$YE<W9A<F)U`$UA_F]S
M:6]S(&=R86EK:?!K;W,@<F%I9.MS`$UA_F]S:6]S(&QO='EN:?!K;W,@<F%I
M9.MS`$UA_FEE:FD@<F]MZVYI\&MI('-K86GH:6%I`$QI=6MS96UB=7)G87,`
M34T`34]41`!0<FEK86)I;G1A;64@35,M5$Y%1B!F86EL92!NZW)A(&1U;VWK
M;O@N`$U31P!-86MA;P!-86ME9&]N:6IA`$UA9&%G87-K87)A<P!-86=I:F$`
M4&'P=&%S`%!A\'1O('9A;&1Y;6%S`%-U:W5R=&D@7VYU;W)O9.`N+BX`36%L
M879I<P!-86QA:7II:F$`36%L9'EV86D`36%L:7,`36%L=&$`2V%T96=O<FEJ
M^"!SX')A\&\L(&MU<FEO;7,@<')I<VMI<FEA;6D@;V)J96MT86DL(&ER('-U
M(&IO;6ES('-U<VEJ=7-I^"!S<&%L=O@@:V5I=&EM87,N`$UA<#(T(/YE;>ML
M87!I<P!-87!1=65S="#^96WK;&%P:7,`2V]V87,`4&%R8?!TZP!08?YY;>MT
M:2!K86EP('-K86ET>71U<R]N97-K86ET>71U<P!08?YY;>MT:2!K:71A:7,@
M871R:6)U=&%I<R`H<'9Z+B!S=F%R8G4O871S86MY=&$I`$UA<O!A;&\@<V%L
M;W,`36%R=&EN:6MA`%-U:G5N9W1I(&QA=6MA:0!-875R:71A;FEJ80!-875R
M:6-I:G5S`$UA:W-I;6%L=7,@:W)E9&ET87,N`$UA:W-I;6%L=7,@_FEN=>AI
M^"!D86QI^"!K:65K:7,@:?!E:6MV;W1A<RX`36%K<RX@=&5M<"X@<&%S:RX@
M,C0@=F%L.B``36%K<RX@=&5M<"X@<&%S:RX@-B!V86PZ(`!-86MS:6UA;'5S
M(&EL9VES`$=E9W7^ZP!-;VIO=.L`365D:6-I;F$`3F%R:6%I`$UE;FEU(')E
M_FEM87,Z`%-U:G5N9W1I(&-E;&5S`-YI;G5TZP!,86GP:V%S('!A=FER=&EN
M=&%S+"!T8>AI874@;F5P871V:7)T:6YT87,@<&%S:7)A\&EU<VEO(&%S;65N
M<R!S97)T:69I:V%T87,N`-YI;G5TZR!N96GP<VGX<W1A+@#>:6YU=.MS('1I
M<&%S`$]R;R!S86QY9V]S`$]R;R!SX&QY9_@@8FQO:V\@;NMR82X`3W)O('/@
M;'EG^"!B;&]K;R!NZW)A+B!!9&UI;FES=')A=&]R:75I(&GP<VGX<W1A<R!D
M971A;'5S(&%P<F'P>6UA<RX`365T;V1A<P!-871A:0!-96MS:6MA`$UI:W)O
M;F5Z:6IO<R!&961E<F%C:6[K<R!686QS=&EJ;W,`5FED=7)Y:F4`34E-12!T
M:7!A<P!-:6XN('1E;7`N('!A<VLN(#(T('9A;#H@`$UI;BX@=&5M<"X@<&%S
M:RX@-B!H;W5R<SH@`$%T<W!I;F1Y<P!+:71O<P!.97)A<W1A<R!014%2($A4
M5%!?4F5Q=65S="!P86ME=&%S+@!.=7-T871Y;?@@;NMR82X@2F5I9W4@;F]R
M:71E(&YA=61O=&D@\.$@;6]D=6SA+"!T=7)I=&4@:N$@<W5K;VYF:6?[<G5O
M=&DN`$[K<F$@_FEN=73K<R!)1"X`3F5R87-T87,@<F5I:V%L:6YG87,@4$5!
M4B!-86EL('!A:V5T87,N`$[K<F$@<V5S:6IO<R!)1"X`4&ER;2X`36]B:6QU
M<R!P8?!T87,`5FED=71I;FES`%)E9&%G879I;6\@9&%T80!+96ES=&D@55),
M`$UO9'5L:7,`36]L9&]V;W,@4F5S<'5B;&EK80!-;VYA:V%S`$UO;F=O;&EJ
M80!-ZVYE<VEA:2!I<B!M971A:0!+87,@;>MN97/A`$UO;G-E<F%T87,`3>MN
M=6QI;R!F87KK<P!-87)O:V%S`$1A=6=I875S:6$@9VEE9')A`$1A=6=I875S
M:6$@87!S:6YA=6OF`$1A=6=I875S:6$@<V%U;.MT80!097)K96QT:2#^96UI
M874`4&5R:V5L=&D@:V%I<FEA=0!097)K96QT:2!D9?!I;FEA=0!097)K96QT
M:2!A=6OPZ&EA=0!097)KZVQI;6%S(/YE;7EN`%!E<FOK;&EM87,@875K\'1Y
M;@!-;WIA;6)I:V%S`$ME;&5T;R!L>6=I^"!I\'-I<VML96ED_FEA;G1I<R!S
MX')A\&%S`$ME;&5T87,@<&%S:7)I;FMI;?@`36%N;R!SX'-K86ET80!-86YO
M('!O<G1A;&%S`$UA;F\@<&]R=&%L;R!I\&3K<W1Y;6%S`$UA:6YM87)A<P!.
M12P@3D53551)3DM5`%9A<F1A<P!.86UI8FEJ80!.875R87,`3F5P86QA<P!.
M>61E<FQA;F1A:0!.>61E<FQA;F3X($%N=&EL86D`3F5T<V-P87!E(&)A>FEN
M:7,@55),`$YE='-C<&%E('-E<FEF:6MA=&\@873P875K:6UO(%523`!.971S
M8W!A92!S97)T:69I:V%T;R!T96ES:?@@55),`$YE='-C87!E(&%T;F%U:FEN
M;VUO(%523`!.971S8V%P92!A=/!A=6MI;6\@55),`$YE='-C87!E(%-33"!S
M97)V97)I;R!V87)D87,`3F5T<V-A<&4@<V5R=&EF:6MA=&\@87!R8?!Y;6%S
M`$YE='-C87!E('-E<G1I9FEK871O('1I<&%S`%1I;FML87,`3FEE:V%D80!.
M875J;VII($MA;&5D;VYI:F$`3F%U:F$@:V%T96=O<FEJ80!.875J87,@;>MN
M=6QI<P!.875J87,@=F%R=&]T;VIO('9A<F1A<R`H;F5B^W1I;F%S*0!.875J
M;VII(%IE;&%N9&EJ80!.875J86UE(&QA;F=E("A?8FQA;FLI`$YA=6II96YO
M<P!.875J:65N^"!G<G5PZW,`4V5K86YT:7,`4V5K86YT>7,@;G5S=&%T>6UA
M:0!.:6MA<F%G=F$`3FEG97)I<P!.:6=E<FEJ80!.86MT:7,`3FEU:NL`3F4`
M3F5U_G1E;FMA(&1U;VUE;O@@<VMI<G1U;?@@<&%R;V1Y;75I+@!.96YU<F]D
M>71A('-T<F%T96=I:F$@25-/(')A\'EM=6DN`$[K<F$@<W5DZW1I;FEO(/!A
M8FQO;F\N`$YU<F]D>71O:F4@<&]Z:6-I:F]J92!B;&]K;R!NZW)A`$YEX79E
M9.MT92!K86QE;F1O<FEA=7,@=F%R9&\@34-!3"!A=71E;G1I9FEK86-I:F]J
M92X`4VMI<G1U;?@@;NMR82X`T&EO<R!T96ESZW,@;F5G86QI('1U<NMT:2!P
M;W1E:7-I^"X`3NMR82!I;F9O<FUA8VEJ;W,@87!I92`E<R!K;VYF:6?[<F%C
M:6K@+@!.ZW)A(&EN9F]R;6%C:6IO<R!A<&EE($944"!61E,@:V]N9FEG^W)A
M8VEJX"X`3NMR82!I;F9O<FUA8VEJ;W,@87!I92!344P@5D93(&MO;F9I9_MR
M86-I:N`N`$[K<F$@:6YF;W)M86-I:F]S(&%P:64@4U%,+49I;&4@5D93(&MO
M;F9I9_MR86-I:N`N`$MR961I=&%S(&GP96EK=F]T87,N`$YEX79E<W1A<R!G
M87;K:F%S+@!&86EL87,@;F5N=7-I^'-T87,`3F5N=7-T871Y=&$@=FEE=&]V
MZRX`3F7A<F'PZW1E(/YI;G5TZW,N`$YEX7)A\.MT92!V87)D;RX`3F7A<F'P
MZW1E(&YU;65R:6\N`$YE<F]D>71I(.'^96ED_FEA;NAI^"!F<F%Z:?@`3F7A
M=F5DZW1E('-L87!T8?YO9/YI;R!(5%10(&%U=&5N=&EF:6MA8VEJ86DN`$YE
MX79E9.MT92!S;&%P=&'^;V3^:6\@24U!4"!A=71E;G1I9FEK86-I:F%I+@!.
M9>%V963K=&4@<VQA<'1A_F]D_FEO($ME<F)E<F]S(&%U=&5N=&EF:6MA8VEJ
M86DN`$YEX79E9.MT92!S;&%P=&'^;V3^:6\@3&]G:6X@875T96YT:69I:V%C
M:6IA:2X`3F7A=F5DZW1E('-L87!T8?YO9/YI;R!005-35T0@875T96YT:69I
M:V%C:6IA:2X`3F7A=F5DZW1E('-L87!T8?YO9/YI;R!334(@875T96YT:69I
M:V%C:6IA:2X`3F7A=F5S=&%S(&ME;&EA<R!I:VD@3W!E;E-33"!P86=R:6YD
M:6YI^"!F86EL^"X@3W!E;E-33"!R96EK86QI;F=A(&1A<F)U:2!S=2!02T-3
M(#$R(&1U;VUE;FEM:7,N`$YE<&%T=FER=&EN=/@@<F5G:7-T<F%C:6KX(&[K
M<F$N`$YE;F%U9&]T:2!S:VER='5K^`!.ZR!V:65N;VIE('!U<^MJ90!3<&%R
M=&EN:6UU:2!NZW)A(&QA:6MI;F]J;R!K871A;&]G;RX`5F%R=&]T;VIO('9A
M<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES(&YE;G5S:?AS=&%S+@!496ES:6YG
M^"!834P@9'5O;65N^"!NZW)A`$[K<F$@<F5I:_!M:?@`2V]N9FEG^W)A8VEN
M:6%M92!F86EL92!NZW)A('9E<G-I:F]S+B!097)G96YE<G5O:VET92!N=7-T
M871Y;75S+@!+;VYF:6?[<F%C:6YI86UE(&9A:6QE(&[K<F$@=F5R<VEJ;W,N
M(%!E<F=E;F5R=6]K:71E(&YU<W1A='EM=7,N`$YE;G5R;V1Y=&$`3NMR80#0
M:6%U<NMS("A)4T\M.#@U.2TQ,"D`3F]R9F]L:V\@<V%L;W,`T&EA=7)I;NL@
M:&5M:7-F97)A`-!I875R:6[K<R!-87)I:F%N^"!S86QO<P!.;W)V96=I:F$`
M3F4@<&\@=&\`3F4@<')I9?`@=&%I`$YE(&MA=&%L;V=A<P!.97)E86QI>G5O
M=&$N`$YE;G5R;V1Y=&$`3F5P86QA:6MO;6%S+@!5_G)A\&%I`$[K<F$@:^`@
M<&5R_FG[<NMT:2P@96EK:71E(&%T9V%L+@!,87!K<FET:7,`3G5M97)I<P!3
M:6UB;VQI^"!S:V%IZ&EU<P!3='5L<&5L:?@@<VMA:>AI=7,`16EL=>AI^"!S
M:V%IZ&EU<P!.9>%V97-T:2!D:7-T<FEB=6-I:F]S('/@<F'P;R!A=&YA=6II
M;FEM;R!S:V%IZ&EA:2X`3TL`3V)J96MT87,`3V)J96MT;R!S879I;FEN:V%S
M`$'P='5N=&%I;FES`%-P86QI<P#>:6%U<G5M;R!F:6QT<F%S`$]F:7-A<P!/
M;6%N87,`2V%T86QO9_@@9&%L:6II;>!S:2!P86QA:6MO('1I:R!)34%0('-E
M<G9E<FEA:2X`5&EK(.'^96ED_FEA;NAI;W,@9G)A>NMS`$QE:63^:6%M87,@
M=&EK('9I96YA<R!E;"X@<&'P=&\@861R97-A<RX`16QE;65N=&\@<V%V:6YI
M;FMO('1E:7-E<R!G86QI(&ME:7-T:2!T:6L@:F\@<V%V:6YI;FMA<R!A<F)A
M('-I<W1E;6]S(&%D;6EN:7-T<F%T;W)I=7,`071I9&%R>71I(&YA=6IA;64@
M;&%N9V4`071I9&%R>71I(/!IX"!N=6]R;V3@(&YA=6IA;64@;&%N9V4`3W!R
M86-I;NMS('-I<W1E;6]S`$YU<W1A='EM86D`)7,@;G5S=&%T>6UA:0!3=7+[
M\&EU;W1A<R!SX')A\&%S`$]R9V%N:7IA8VEJ80!0861A;&EN>7,`4VES=&5M
M:6YI;6%S`$]R:6=I;F%L=7,@87!L:6MA8VEJ;W,@\&%B;&]N87,`3W)I9VEN
M86SX<R#P86)L;VYA:2`E<SH`2VET80!+:71A(&EN9F]R;6%C:6IA`%-A=FEN
M:6YI:V\@=&5I<^MS`$[K<F$@4$%-(&%U=&5N=&EF:6MA8VEJ;W,@;65C:&%N
M:7IM;RX`4$=0('-K86ET;65N:6YI<R!P87)A\&%S`%!'4"!U_FMO9'5O=&$@
M:6YF;W)M86-I:F$`4$=0('9I9?!A<VES(')A:W1A<P!01U`@<&%S:7)A\'ET
M:2]U_FMO9'5O=&D@9'5O;65N>7,`4$A0(&MO9&%S`%!(4"!#3$D`4$T@;&5N
M9W9A<R!L:65T=7,`4$T@;&G[=&ES`%!-(%0M875D<F$`4%](4"!#3$D`5&%R
M<&%I(&-E;.MS90!086MI<W1A;F%S`%!A;&%U`%7^:6UT;VII(%!A;&5S=&EN
M;W,@=&5R:71O<FEJ80!086YA;6$`4&%P=6$@3F%U:F]J:2!'=FENZVIA`%!A
M<F%G=F%J=7,`1&%L:6YA:2!D96)E<W5O=&$`4VQA<'1A_F]D:7,`4VQA<'1A
M_F]D:7,@;F5T96ES:6YG87,`4D%$2553(&%U=&5N=&EF:6MA8VEJ86D@<F5I
M:VEA('-L87!T8?YO9/YI;RX`4VQA<'1A_F]D:7,@<W4@<&%T=FER=&EN:6UU
M`%-L87!T8?YO9&ES.@!3;&%P=&'^;V1I<SH@`%-L87!T8?YO9/YI86D@='5R
M:2!S=71A<'1I+@#!:V5L=&D`P6ME;'1I(&GP(&QA:6MI;F]S:6]S('-A=6=Y
M:VQO<R`H8VQI<&)O87)D*0!+96QI87,`3F5P871V:7)T:6YT;W,@<F5G:7-T
M<F%C:6IO<SH`WFUO;NMS`%!R;V-E;G1A:0!!=&QI:W1I('!R;V9I;&%K=&EN
M:75S('9E:6MS;75S`$%R(&%T;&EK=&D@<')O9FEL86MT:6YI=7,@=F5I:W-M
M=7,@<')I<VEJ=6YG:6UO(&UE='4_`%1E:7/K<P!496ES:?@@861M:6YI<W1R
M879I;6%S`$%S;65N:6[K(&EN9F]R;6%C:6IA`%!E<G4`1WEV^VYA:0!&:6QI
M<&EN86D`5&5L969O;F%S`$YU;W1R875K;W,`4&ET:W)A;F%S`%!I:W-E;&EA
M:0!"86YA;'EBZW,`2?!S:7)I;FMI=&4@:W5R:>`@;F]R<R!C96SF`%!A='9I
M<G1I;FMI=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\.$@96QE;65N
M=.`Z`%!A='9I<G1I;FMI=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@
M\&EO(&5L96UE;G1O(&YU;W)O9.`N`,%V97-K:71E(&WK;F5SX2!I<B!M971U
M<RX`P79E<VMI=&4@;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z`,%V
M97-K:71E('1E:7-I;F?@($E0(&%D<F5SX"X`P79E<VMI=&4@=&5I<VEN9^`@
M9&%TX"P@<&%T:6MR:6YK:71E(&1I96[X('-K86GH:?@@;>MN97-Y:F4N`,%V
M97-K:71E('1E:7-I;F?@(&QA:6O@+@!!<')A\'EK:71E('!R;V)L96W@+@!.
M=7)O9'EK:71E('-A=F\@=F%R=&]T;VIO('9A<F3@(&)E:2!S;&%P=&'^;V3A
M`,%V97-K:71E(&YA=6K@(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z`$QE;FMI
M:F$`4&]L:71I:V%I`$)A;'-A=FEM86D`4&]R='5G86QI:F$`4&%V96EK<VSK
M;&EO('!O>FEC:6IA`$QE;G1E;.MS('!O>FEC:6IA`$GP<V%U9V]T:2#P:6%M
M92!K871A;&]G92`H;F5G86QI;VIA($E-05`I`$MR:71U;&EA:2!P87-K+B`E
M<R!V86QA;F3@*&%S*3H@`%!R969S7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN
M9V%S($Q$05`@;6]D=6QI<RX`4')E9G-?<V5S<VEO;CH@;F5R87-T87,@<F5I
M:V%L:6YG87,@<V5S:6KX(&UO9'5L:7,N`%-LZV=I<P!3;.MG:7,@:OMR;W,@
M;'EG>6IE.B``4VSK9VES.B``4&5R_FG[<F$`4&5R_FG[<NMT:2!P879E:6MS
M;.MLX2!N875J86UE(&QA;F=E`$%N:W-T97-N:2!N=7-T871Y;6%I`$%T<W!A
M=7-D:6YT:2!D;VMU;65N=.``4VQA<'1A<VES(')A:W1A<P!0<F]B;&5M80!0
M<F]B;&5M;W,@87!R8?!Y;6%S`%!R;VIE:W1A:0!0<F'P>6UA<R!T96MS='5I
M`%9I9?!A<VES(')A:W1A<P!6:67P;VIO(')A:W1O(&%L9V]R:71M87,`5FEE
M\&]J;R]S;&%P=&]J;R!R86MT^"!P;W)A(&YE<W5G96YE<G5O=&$N`%!U97)T
M;R!2:6MA<P!+871A<F%S`%-A:VEN>7,`4E-!('9I9?!A<VES(')A:W1A<R`H
M)60@8FET86DI`"=2861I;R<@<&%S:7)I;FMI;6%S`$QI971U<P!,:65T=7,@
M<GET90!,:65T=7,@=F%K87)E`$QI^W1I<P!!='-I=&EK=&ENZR!F<F%ZZP!3
M86YT>6MI<P!3:V%I='ET:0!097)S:V%I='ET:2!L86GP:V%I`%1I:W)A:2!I
M\'1R:6YT:2`E<S\@1W)A_FEN=&D@871G86P@;F5B96=A;.MS:71E+@!4:6MR
M86D@:?!T<FEN=&D@=F%R=&]T;VIO("5S(&1U;VUE;FES/R!'<F'^:6YT:2!A
M=&=A;"!N96)E9V%LZW-I=&4N`%!A:V%R=&]T:2!A;FMS=&5S;N$@=F5I:W-M
MX`!!=&YA=6II;G1I(&MA:7)I;VIO(&UE;FEU(&5L96UE;G1U<SH`071N875J
M:6YT:2!P;W)T86QO('9A:7IDX#H`4F5G97@`4^!R>?!I^"!N87+P>6MLZP!0
M87-T86)O<P!.=71O;.8@<V5R=F5R:6%I`$YU=&]LYG,@55),("AH='1P.B\O
M=W=W+G!A=GEZ9'ES+F-O;2]H;W)D92DZ`$GP=')I;G1I`%!A\&%L:6YT:2!B
M;&]KX`!086YA:6MI;G1I('-T=6QP96SA`%!A;F%I:VEN=&D@9F]R;6%T879I
M;>``2?!T<FEN=&D@<&]RX`!)\'1R:6YT:2!A=&YA=6II;FEM;R!S:W)I<'3@
M(&GP('-E<G9E<FEO(&QA:6MI;F]J;R!K871A;&]G;RX`4&'P86QI;G1I`%!A
M\&%L:6YT:2#PX2!E;&5M96YTX"!I\"!D;VMU;65N=&\`2?!T<FEN=&D@=F%R
M=&]T;VK@`%9A<G1O=&]J;R!T<GEN:6UA<SH@)7,`3F5G86QI=2!A='-A:WET
M:2#A('7^:VQA=7/@+B!+;&%I9&]S(&MO9&%S.B``2?`@;F%U:F\`4&%K96ES
M=&D@<VQA<'1A_F]DX0!3;&%P=&'^;V3^:6\@:V5I=&EM87,`4F5Z=6QT871A
M:0!'<N'^=&D@X2!N=7-T871Y;75S`%)E:OMN:6IA`$%T<W1A='ET:2!K;VYF
M:6?[<F%C:6K@`$A434P@<F5D86MT;W)I875S(&YU<W1A='EM86D`3>%S;.MS
M`$1E\&ENZVIE`$1E\&EN:6]J:2!A;G1R8?!TZP!$9?!I;FEO<VEO<R!R96EK
M\&WK<P!?16EL=73K<R!N=7-T871Y;6%I+BXN`%)O;.L`4G5M=6YI:F$`4&%S
M=6MT:2`Q.#``4&%S=6MT:2!K86ERZVX`4&%S=6MT:2!D9?!I;NMN`$5I;'5T
MZW,@;G5S=&%T>6UA:0!%:6QU=.MS(&YU<W1A='EM86D`16EL=73K<SH`4VMI
M<G1U:V%I`%-K:7)T=6MA:2!T87)P('9I<_@@96EL=>AI^"!I<B!S='5L<&5L
M:?@`4VMI<G1U:V%I('1I:R!T87)P('-T=6QP96QI^`!3:VER='5K86D@=&EK
M('1A<G`@96EL=>AI^`!6>6MD>71I`%)U<VEJ;W,@1F5D97)A8VEJ80!2=6%N
M9&$`4R]-24U%('!A<F'P87,`4R]-24U%('7^:V]D=6]T87,@;&%I\&MA<P!.
MZW)A(%-!4TP@875T96YT:69I:V%C:6IO<R!M96-H86YI>FUO+@!335,@_FEN
M=73K<P!344P@0TQ)`%-32`!005992T\`4U]13"!#3$D`T&7P="X`T'9E;G1O
M:FD@2&5L96YA`%-A:6YT($MI='-A<R!I<B!.979I<V%S`%-A:6YT($QI=6-I
M:F$`T'9E;G1A<VES(%!E=')A<R!I<B!-:6=E;&]N87,`4V%I;G0@5FEN8V5N
M=&%S(&ER($=R96YA9&EN86D`5&%M92!P8>AI86UE(&QA;F=E("A?<V5L9BD`
M4V%M;V$`4V%N($UA<FEN87,`4V%O(%1O;64@:7(@4')I;F-I<.L`4&%L>61O
M=F%S`%-A=61O($%R86)I:F$`2?!S875G;W1I`$GP<V%U9V]T:2`E<P!)\'-A
M=6=O=&D@;G5S=&%T>6UU<P!)\'-A=6=O=&D@<W5G96YE<G5O='5S(&YU<W1A
M='EM=7,@:V%I<"!02%`@<VMR:7!TX"!J^W/X('-E<G9E<FEO(&QA:6MI;F%J
M86UE(&MA=&%L;V=E+@`E<R!N=7-T871Y;6%I(&GP<V%U9V]T:2X`36]K<VQA
M<P!)9?!K;W1I`%!A:67P:V$`4&%S:7)I;FMI=&4@9F%I;'5S`%!A<VER:6YK
M:71E(&1A=.``4&%S:7)I;FMI=&4@9W)U<.8`4&%S:7)I;FMI=&4@;F%U:N`@
M<V%V:6YI;FO@`%!A<VER:6YK:71E('-E<G9E<N$`4&%S:7)I;FMI=&4@=F%R
M=&]T;VK@`%!A<VER:6YK:71E('9I<W5S(&1A=&]S(&MO;7!O;F5N='5S+@!0
M87-I<FEN:VET92!O8FIE:W3@`$GP(/YE;6EA=2!E<V%NZ&GX('/@<F'P^"!P
M87-I<FEN:VET92!R96EK:6%M=7,@<VEM8F]L:75S+B!6ZVQI874@9V%L:71E
M(&IU;W,@;G5K;W!I:G5O=&D@X2!L86GP:^`N`%!A<VER:6YK:71E(&1A=&]S
M('-K:7)T=6O@.@!087-I<FEN:VET92!D871O<R!F;W)M873@.@!087-I<FEN
M:VET92!A<')A\.`@:W5RX2!N;W)I=&4@<F5D86=U;W1I.@!087-I<FEN:VET
M92!L86EK;R!S:VER='5KX#H`4&%S:7)I;FMI=&4@;&%I:V\@9F]R;6%TX#H`
M4&%S:7)I;FMI=&4@9'4@871I=&EN:V%NZ&EU<R!L875K=7,N`%!A<VER:6YK
M:71E('-P86QV^"!D97)I;N$N`%!A<VER:6YK:71E(&YO<FEMX"!K86QBX#H`
M4VGX<W1I('!R;V)L96UO<R!P<F%N9?!I;>``4VGX<W1I(%--4P!396YE9V%L
M87,`4V5N<V]R:75S.B``4G5G<^MJ:7,`4V5R8FEJ82!I<B!-;VYT96YE9W)A
M<P!397)I:F]S(&YU;65R:7,`4V5S:6IO<R!)1"!P87-I8F%I9^LN`%)I;FMI
M;GES`$YU<W1A='EM86D@;&5I9/YI86YT>7,@2G5M<R!P87-I:V5I<W1I('-L
M87!T8?YO9.$L(&IE:6=U(&KA(&MA9&$@;F]R<R!P86UI<O!I=&4N`$YU=&]L
M=7-I^"!S97)V97)I^"P@:W5R:75O<R!N;W)I=&4@;6%T>71I(&GP('!O<G1A
M;&\L(&YU<W1A='EM86DN`$MA;&)O<RP@;&%I:V\@>F]N;W,@:7(@9&%T;W,@
M;G5S=&%T>6UA:2X`4'5S;&%P:6\@<W!A;';X+"!A='-I;F%U:FEN:6UO(&1A
M_FYU;6\@:7(@:VET^"!V86EZ9&%V:6UO('!A<F%M971R^"!N=7-T871Y;6%I
M+@!287-T87,@871N875J:6YI;6\@<VMR:7!T87,`4W4@\&EU;R!P87)A;65T
M<G4@9V%L:6UO<R!K96QI;W,@=FEE=&]VZW,Z(`!396GP96QA:0!087)D=6]T
M=7;K`%1R=6UP87,@87!R8?!Y;6%S`$%R(&YA=61O=&D@:VQA=FEA=/MR;W,@
M;7EG='5K=7,@=F%L9'EM=6D_`%)O9'ET:0!087)O9'ET:2!S:VER='5M=7,@
M=&%R<"!I\'-A=6=O=&\@:7(@:^`@=&EK('-U9V5N97)U;W1O(&MO;F9I9_MR
M86-I;FEO(&9A:6QO+@!2;V1Y=&D@<&%S:W5T:6YI;R!P<FES:6IU;F=I;6\@
M;&%I:^`_`%)O9'ET:2!G86QI;7EBYB!P86QI:W1I(&]R:6=I;F%LX`!2;V1Y
M=&D@<&%R:7-I;FMI;>``4F]D>71I(&QE;G1E;.MS(&]P97)A8VEJ^"!M96YI
M=3\`4F]D>71I("5S(&UE;FEU(&MA:7+K:F4_`%)O9'ET:2!C96SK<R!N=7-T
M871Y;?@@;&%N9^``4F]D>71I(&QE;G1E;.MS(&YU<W1A='EM^"!L86YGX`!2
M;V1Y=&D@96EL=73K<R!N=7-T871Y;?@@;&%N9^``4F]D>71I('!A=F5I:W-L
MZVQI;R!N=7-T871Y;?@@;&%N9^``4F]D>71I(&9A:6SX(.%KZVQI;>``3&G[
M=&ES`$QI^W1I<R!R>71E`$QI^W1I<R!V86MA<F4`4W5M8?YI;G1I`%-U;6'^
M:6YT:2!A<F)A('!A<W1U;71I(&MA:6UY;FEN:75S(&)L;VMU<P!3:65R82!,
M96]NZP!296=I<W1R86-I:F$`4&%R8?!A<P!087)A\&\@86QG;W)I=&UA<P!3
M:6YG87#[<F%S`$1Y9&ES`%!R86QE:7-T:2!P<F]F:6QA:W1I:^``4VQO=F%K
M:6IA`%-L;W;K;FEJ80!0^V=A`%-N:65G;R!G>6QI<SH@`%-N:65G;R!K:65K
M:7,@=F%N9&5N:74Z(`!3;VQO;6]N;R!S86QO<P!3;VUA;&EA`$1A:6YO<R!I
M<B!%:6SK<F'PZ&EA:0!2^_!I879I;6\@='9A<FMO<R!P87-I<FEN:VEM87,`
M4VEU;G3K:F\@861R97-A<P!0:65T^"!!9G)I:V$`4&EE=/@@175R;W!O<R`H
M25-/+3@X-3DM,RD`4&EE=/@@1/YO<F3^:6IO<R!I<B!0:65T^"!386YD=FGH
M;R!S86QO<P!0:65T:6[K(&AE;6ES9F5R80!487)P87,@=&%R<"!C96QI^`!4
M87)P87,@=&%R<"!C96SK<R!T=7)I;FEO(&ER(&MR8?!T:6[K<P!487)P87,`
M5&%R<&%I('1A<G`@8V5L:?@`5&%R<&%I`$ES<&%N:6IA`%-P86UA<P!3<&5C
M:69I;FGX('-I;6)O;&GX(.%T97)P:6UA<P!097)S:V5L=&D@8V5LY@!097)S
M:V5L=&D@<W1U;'!E;.$`4&5R<VME;'1I(&5I;'5TY@!3<&]R=&%S`-!R:2!,
M86YK80!3=&%N9&%R=&%S`%-T87(@5')E:R=A<P!0<F%D:6YI86D@;65T86D`
M4F%J;VYA<R!A<F)A('!R;W9I;F-I:F$`0OMS96YA`%-A=6=O:FEM;R!F;W)M
M871A<P!'871VZW,@861R97-A<P!5_F)R875K=&D`WF]D_FGX('/@<F'P87,`
M3G5I;71I(&1O;65NX"!N=6\@861R97-O`%-T:6QI=7,@6T-34UT`4V5K;2X`
M5&5M80#!=F5S=&D`26YD96MS87,`4^MK;6EN9V$`2V]N9FEG^W)A8VEJ82!A
M='-T871Y=&$@<^MK;6EN9V%I+B!097)K<F%U:VET92!P=7-L87#A+"!K860@
M<&%M871Y='5MZW1E('!A:V5I='5M=7,N`$%T<V%R9VENZR!K;VYF:6?[<F%C
M:6IO<R!K;W!I:F$@<^MK;6EN9V%I(&GP<V%U9V]T82X`)R5S)R!SZVMM:6YG
M86D@=?YR8?!Y=&%S+@!3=61A;F%S`%1U<FEN>7,`4V%U;.MT96MI<P!3875L
MZVQY9VES`%-A=6SK=&$`4V%U;.MT96MI<P!3875LZW1E:VES+U-A=6SK;'ED
M:7,`4V%U;.MT96MI<SH@`%-A=6SK;'EG:7,`4V%U;.ML>6=I<SH@`$QA:7!S
M;FES`$%P=&%R;F%V:6UA<P!3=7)I;F%M87,`4&%V87)DZP!3=F%L8F%R9&%S
M(&ER($3^86YM86EN87,`4W9A>FEL86YD87,`T'9E9&EJ80#0=F5I8V%R:6IA
M`%-I;G1A:W/K<R!K;&%I9&$@<&%I9?!K;W,@:W)I=&5R:6IU:F4`4VER:6IO
M<R!!<F%B^"!297-P=6)L:6MA`%0M875D<F$`5"UA=61R;W,`5%-6(&9A:6QA
M<P!,96YT96SK`$QE;G1E;.MS(&YU<W1A='EM86D`3&5N=&5LZW,@;G5S=&%T
M>6UA:0!486EV86YA<P!486EV86YA<RP@2VEN:6IO<R!P<F]V:6YC:6IA`%1A
M9/YI:VES=&%N87,`2G5N9W1I;NL@5&%N>F%N:6IO<R!297-P=6)L:6MA`%1A
M:6MI;GES.@!$87)B86D`5&5L969O;F\@;G5M97)I<P!496UP+B!P87-K+B!V
M86QA;F3@.B``5&5M<&5R873[<F$`5&5M<&5R873[<F$Z(`#086)L;V[X(&%D
M;6EN:7-T<F%V:6UA<P!496MS=&%S`%1I:R!T96MS=&%S`$QY9VEU;W1I('1E
M:W-TX`!496MS=&\@=FER\'5J90!+971V+@!486EL86YD:65T:?!K82`H5$E3
M+38R,"D`5&%I;&%N9&%S`$'H:?L@:V%D(&YA=61O:F%TZW,@<VES=&5M82X`
M3NMR82!&5%`@;6]D=6QI;RX`2&]R9&4O2V]L86(@:6YT96=R86-I:F]S('9A
M<FEK;&EU:V%S(&YE<&%L86EK;R`B)7,B`$YE<&%V>6MO('7^:W)A=71I($UA
M:6YT96YA;F-E.CH@:VQA<^MS`$YU<W1A='EM^"!L86YG87,@=?YD87)Y=&%S
M+B!)\&5I;G4N`$IE:6=U(&YO<FET92!N875D;W1I(&YU<W1A='EM=7,L('!A
M<')A\'EK:71E(&MA9"!A9&UI;FES=')A=&]R:75S('-U:V]N9FEG^W)U;W3X
M('!A<W1O=FG@(&1U;VUE;O@@8F%ZYB!N=7-T871Y;6%M<R!S875G;W1I+@!4
M:6L@87!A=&ENZVIE('!U<^MJ90!.9>%R8?#K=&4@8V]N=&%K=&\@240@;G5M
M97)I;R!A<F)A(&II<R!N97)A<W1A<R!D=6]M96[X(&)A>NMJ92X`2V]N=&%K
M=&%S('/K:VUI;F=A:2#A=')A=6MT87,@X2!*^W/X(&%D<F5S^"!K;GEG96SF
M+@!.;W+K9&%M:2!P871I:W)I;G1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I
M(&%T<VMI<N`@4$=0('!A<F'P;R!B;&]KX"X`3F7A<F'PZW1E(&1I<W1R:6)U
M8VEJ;W,@<^!R8?!O($E$(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%Z
MZVIE+@!.9>%R8?#K=&4@9&ES=')I8G5C:6IO<R!SX')A\&\N`%!'4"!U_FMO
M9&%V:6UO(&=A;&EM>6+K(')E:6MA;&%U:F$@<V%U9V%U<R!P<FES:6IU;F=I
M;6\N($)A;F1Y:VET92!R8?!Y=&D@:'1T<',Z+R\@861R97-O('!R863^:6]J
M92X`1F%I;&%S("5S('!R:79A;&\@='5RZW1I("5S('!A<F%M971RX"X`1F%I
M;&%S("5S('!R:79A;&\@='5RZW1I(&MA:2!K=7)I=6]S("5S('!A<F%M971R
M=7,N`$9A:6QA<R!N96=A;&D@8OMT:2!N=6MO<&EJ=6]T87,@86YT('-A=N9S
M+@!&86EL92!NZW)A(&1U;VUE;O@N`%)&0S@X,B!L86GP:V\@86YT<F'P=.MS
M+@!*96EG=2!D:7)B871E($EN=&5R;F5T($5X<&QO<F5R(&YA<O!Y:VQE+"!P
M:6QN865K<F%N:7,@<F5D86MT;W)I875S(')E_FEM87,@9V%L:2!S=6ME;'1I
M('!R;V)L96WX+"!DZVP@\&EO<R!N87+P>6MLZW,@:VQA:63X+B!'86QI=&4@
M;F5M871Y=&D@:V%I(&MU<FGX(')E9&%K=&]R:6%U<R!E;&5M96YT^"X@2F5I
M9W4@;F%U9&]J871E(%=I;F1O=W,@.7@@3U,@9W)E:>AI875S:6%I(&K[<_@@
M:V]M<&EU=&5R:7,@<&%P<F'PZ&EA=7-I86D@;G5L=?`@<&%S:V5L8F1A;6%S
M(&%P:64@<&%G<FEN9&ENYB!K;&%I9.`N7&Y<;DK[<R!B=79O=&4@<&5R<W#K
M=&%S+B!*96EG=2!V:7-T:65K(&YO<FET92!I\&)A;F1Y=&D@<&EL;F%E:W)A
M;N$@<F7^:6W@('-P875S:VET92!/2RX`07!R8?!A<R`B)7,B(&GP=')I;G1A
M<RX`5&EK(&MA:7+K:F4@<'5SZVIE`$-R>7!T7W!Q<#HZ(&ML87-E:2!R96EK
M:6$@;G5R;V1Y=&D@:W5R('ER82!';G501R!F86EL86DN`$QA:?!K87,@:?!S
M:?AS=&%S("5S(&%D<F5S871U:2`E<R!T96UA("(E<R(@8G5V;R!P87)O9'ET
M87,N"E1AZ&EA=2!T86D@;F5G87)A;G1U;VIA(&MA9"!L86GP:V%S(&)U=F\@
M<&5R<VMA:71Y=&%S(&%R8F$@<W5P<F%S=&%S+@!0879A9&EN:6UA<R!K=7+A
M(&YA=61O<VET92!N=6]R;V1O:F4@X2!L86GP:V\@<F'P>6UO('!U<VQA<.$`
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!K;&%S96D@<F5I:V%L:6YG87,@3W!E;E-3
M3"!M;V1U;&ES+@!.96=A;&EU(&GP<V%U9V]T:2!N=7-T871Y;6\@(B5S(BP@
M;F5S(&1U;VUE;O@@9'ED:7,@=FER\'EJ82!L96ES=&ENX"!R:6+@`%!R;V=R
M86UA+"!S:VER=&$@<&5R_FG[<NMT:2#PX2!D=6]M96[X('1I<.`@*"5S*2P@
M;F5R87-T82!S:7-T96UO:F4N`%1I:R!K86ERZVIE(&ER(&1E\&ENZVIE('!U
M<^MS90!4:6L@9&7P:6[K:F4@<'5SZVIE`%-E<G9E<FES("(E<R(@:?!T<FEN
M=&%S+@!397)V97)I<R`B)7,B(&GP<V%U9V]T87,N`"5S(')E9VES=')A8VEJ
M;W,@<')A\'EM87,@:?!T<FEN=&%S+@!.=7)O9'ET82!E:6QU=.L@;F5E9WII
M<W1U;VIA+@!4:6L@=FER\'5T:6[K:F4@:7(@87!A=&ENZVIE('!U<^MS90!4
M:6L@87!A=&ENZVIE('!U<^MJ90!.=7-I^'-T:2!D=6]M96YY<R!P<F%R87-T
M:2X`3F5G86QI=2!I\'-A=6=O=&D@;G5S:?AS=&\@9F%I;&\N`%=E871H97(N
M8V]M(&)L;VMO(&[K<F$N`$YU<W1A='EM^"!NZW)A+@!$86QI^"P@:W5R:6%S
M(&=A;&EM82!R;V1Y=&D@;&%I\&MO('1E:W-T92P@;NMR82X`T&EA;64@;&%U
M:V4@X79E<W1A('!E<B!D875G('-I;6)O;&GX+B!*^W,@X79E9.MT92`E<RP@
M;R!M86MS:6UA;'5S('-K86GH:75S("T@)7,@<VEM8F]L:6%I+@!0<F]B;&5M
M;W,@<W4@9F%I;/@@<VEU;G1I;74Z("5S(&YE;G5S:?AS=&%S+@!.=7-I^'-T
M:2!F86EL;R!N97!A=GEK;RX@1F%I;&%S("5S('ER82!D:61E<VYI<R!N96=U
M(&QE:63^:6%M87,@9'ED:7,@*"5D(&)A:71A:2DN`$YU<VGX<W1I(&9A:6QO
M(&YE<&%V>6MO+B!&86EL87,@)7,@=&EK(&1A;&EN86D@;G5S:?AS=&%S+@!.
M96=A;&EU('!A<F]D>71I(/!I;W,@;&%I\&MO(&1A;&EE<P!+;&%I9&$@X6ME
M;&EA;G0@:V]N=&%K=&EN:75S(&1U;VUE;FES+@!+;&%I9&$@X6ME;&EA;G0@
M:4-A;&5N9&%R(&1U;VUE;FES+@!+;&%I9&$@:V]N9FEG^W)A8VEJ;W,@9F]R
M;6]J92X@1W)E:>AI875S:6%I(&YE=?YP:6QDZW1E(')E:6MI86WX(&QA=6OX
M+@!+;&%I9&$@871L:65K86YT(&YU<F]D>73@(&%D<F5S^"!K;GEG96SK<R!F
M=6YK8VEJX"X@4&%B86YD>6MI=&4@=NML:6%U+@!+;&%I9&$@871N875J:6YA
M;G0@:V]N=&%K=&EN:75S(&1U;VUE;FES+B!086)A;F1Y:VET92!VZVQI874N
M`$ML86ED82!A=&YA=6II;F%N="!D:7-T<FEB=6-I:F]S('/@<F'PX"X@4&%B
M86YD>6MI=&4@=NML:6%U+@#0:7,@24U!4"!S97)V97)I<R!N97!A;&%I:V\@
M:V%T86QO9_@@9&%L:6II;6]S:2X`071R;V1O+"!K860@=&%I(&YE='9A<FMI
M;F=A<R!205(@87)C:'EV87,N`$%T<F]D;RP@:V%D('1A:2!N971V87)K:6YG
M87,@6DE0(&%R8VAY=F%S+@!!=')O9&\L(&MA9"!T86D@;F5T96ES:6YG87,@
M:V]R=&5LZW,@;G5M97)I<RX`T&D@='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I
M(/YI;G5T97,@<&5R($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O
M;2D@<&%S:6YA=61O:F%N="!(5%10('!R;W1O:V]L=0#0:2!T=F%R:WEK;.L@
M;&5I9/YI82!S:?AS=&D@_FEN=71E<R!P97(@<VUS,F5M86EL("AH='1P.B\O
M<VUS,F5M86EL+F-O;2D@<&%S:6YA=61O:F%N="!(5%10('!R;W1O:V]L=0#0
M:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!33510('!R;W1O
M:V]L=2!P97(@5F]D869O;F4@271A;&EJ;W,@=F%R='5S+"!T:6L@5F]D869O
M;F4@;G5M97)I86US+B!*:2!R96EK86QA=6IA(&5L+B!P8?!T;R!A9')E<V\@
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`T&ES(&QA=6MA
M<R!P<FEV86QO;6%S+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-V96EK
M:65J:2!S:V%IZ&EA:2X`T&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S:V%I
MZ&EA:2!I<B!D=FET8?!K:6%I+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK
M(&'P='5N=&%I;FEA:2!S:V%IZ&EA:2X`T&EA;64@;&%U:V4@='5R:2!B^W1I
M(&MA8FQE;&EA:7,@87)B82!T87)P86ES(&%T<VMI<G1I('-V96EK:65J:2!S
M:V%IZ&EA:0#0:2!R96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RX`T&EA;64@
M;&%U:V4@9V%L:2!B^W1I('1I:R!S<&%L=F]S(&MO9&%S(%)'0B!(97@@9F]R
M;6%T92P@<&%V>7ID_FEU:2`G(S$R,S1!1B<N`-!I(&9O<FUA(&IA=2!A<&1O
M<F]T82X`5&%I("5S+@!486D@2V]L86(@1W)O=7!W87)E(&]B:F5K=&%S+B!.
M;W+K9&%M:2!P97+^:?MRZW1I(&]B:F5K=.`@<')I=F%L;W1E('1U<NMT:2!E
M;"X@<&'P=&\@:VQI96YTX"P@:W5R:7,@<W5P<F%N=.`@\.$@9F]R;6%TX"X@
M5&]K:?@@96PN('!A\'1O(&ML:65N=/@@<^!R8?#@(&=A;&ET92!R87-T:2!A
M<'-I;&%N:^8@)7,`T&ES(&QA:?!K87,@8G5V;R!P87)A\'ET87,@)7,@:V]D
M=6]T92X@2OMS(&YA=61O:F%T92!K:71O:VG@(&MO9'5O=.8N`-!I<R!S:V%I
MZ&EU<R!T=7)I(&+[=&D@9&ED97-N:7,@=?X@;G5LX2X`T&ES('-E<G9E<FES
M(&YE9V%L:2!I\&%R8VAY=G5O=&D@>FEP(&ER(&=Z:7`@9F%I;/@N`-!I('-I
M<W1E;6$@9&%B87(@:?!J=6YG=&$N`-!I(')E:6OP;>L@='5R:2!B^W1I('-K
M86GH:75S+@#0X2!L86YGX"!R96EK:6$@871I9&%R:6[K=&D@:?`@;G5S=&%T
M>6WX(&QA;F=O`%!E<FO[;FEJ80!":6QI971A:0!,86EK87,`3&%I:V\@87!S
M:V%I=&$`3&%I:V\@9F]R;6%T87,`3&%I:V\@<&%S:7)I;FMI;6%S`%1I;6]R
M;&5S=.L`4&%R96EG;W,`4&%V861I;FEM87,Z`$MA;0!.;W+K9&%M:2!P87-I
M<FEN:W1I(&ME;&5TX"!E;&5M96YT^"P@;&%I:WEK:71E($-O;G1R;VP@*%!#
M*2!A<F)A($-O;6UN860@*$UA8RD@:VQA=FGPX"P@:7(@<&%S:7)I;FMI=&4@
M<&5L92X`T&EA;F1I96X`4F]D>71I($A434P@:V]DX`!4;V=A<P!4;VME;&%U
M`%)Y=&]J`%1O;F=A`%9I<O!U:F4`5FER\'5T:6YI86UE(&QA;F=E("A?=&]P
M*0!697)T:6UA:0!4<FEN:61A9&%S(&ER(%1O8F%G87,`5&%I<"!A<F)A(&YE
M`$%N='(N`%1U;FES87,`5'5R:VEJ80!4=7)K:?!K82`H25-/+3@X-3DM.2D`
M5'5R:VWK;FEJ80!4=7)K<V\@:7(@2V%I:V]S;R!S86QO<P!4=79A;'4`P79E
M<VMI=&4@<V%V;R!P87-I<FEN:VEMX#H@`%4N5BX@:6YD96MS87,Z(`!54DP`
M4VMR:7!T;R!P<FES=&%T>6UO('-T871U<V\@<F%P;W)T;R!54DP`55),.@!5
M9V%N9&$`56MR86EN80!.97!A=GEK;R!P97)S:V%I='ET:2!61E,@:V%T86QO
M9V\N`$YE<&%V>6MO('!R:63K=&D@<&%P:6QD;VUO<R!V87)T;W1O:F\@<F5G
M:7-T<F%C:6IO<R!I;F9O<FUA8VEJ;W,N`$YE<&%V>6MO('!A:V5I<W1I(%9&
M4R!F86EL;R`B)7,B('1E:7-I^"X`3F5P879Y:V\@<&%K96ES=&D@=&5I<VGX
M(%9&4R!F86EL=6D@)7,O)7,N`$YE<&%V>6MO('!E<F5I=&D@X2`E<RX`3F5P
M879Y:V\@<')I<VEJ=6YG=&D@<')I92!344P@<V5R=F5R:6\N`$YE<&%V>6MO
M('!R:7-I:G5N9W1I(%-33"!R9?YI;74N`$YE<&%V>6MO(&YU:V]P:6IU;W1I
M(%9&4R!F86EL;RX`3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO9V\@(B5S
M(BX`3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO('-U
M:W5R=&D@5D93(&9A:6QO+@!.97!A=GEK;R!S=6MU<G1I('1U\.AI;R!61E,@
M9F%I;&\N`$YE<&%V>6MO(&GP87)C:'EV=6]T:2!D=6]M96[X+@!.97!A=GEK
M;R!I\'1R:6YT:2`B)7,B+"!K871A;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO
M(&GP=')I;G1I("5S+"!K871A;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO(')E
M:W5R<VGP:V%I(&GP=')I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@:?!T
M<FEN=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T
M86QO9V\Z("5S+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\@(B5S(BX`
M3F5P879Y:V\@:?!T<FEN=&D@5D93(&9A:6QO+@!.97!A=GEK;R!R96MU<G-I
M\&MA:2!I\'1R:6YT:2!61E,Z("5S+@!.97!A=GEK;R!N=7-T871Y=&D@9&%B
M87)T:6YI;R!K871A;&]G;RX`3F5P879Y:V\@9V%U=&D@<V5R=&EF:6MA=&\@
M87!R8?!Y;6\`3F5P879Y:V\@=?YK<F%U=&D@)7,@87!R8?!Y;6\N`$YE<&%V
M>6MO('!E<FME;'1I(%9&4R!F86EL;RX`3F5P879Y:V\@871I9&%R>71I(%9&
M4R!F86EL;R`B)7,B+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO(')A
M\'EM=6DN`$YE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\N`$YE<&%V>6MO
M(&%T:61A<GET:2!S=7-P875S=&\@87)C:'EV;RX`3F5P879Y:V\@<&5R<VMA
M:71Y=&D@=F9S<F]O="!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT:2`E
M<R#A("5S.B!T;VMS(&MA=&%L;V=A<R!J874@96=Z:7-T=6]J80!.97!A=GEK
M;R!P97)V861I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT
M:2!61E,@:V%T86QO9V\Z("5S+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F
M86EL;R`B)7,B+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`E<R\E
M<RX`3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\N`$YE<&%V>6MO('!A
M;&5I<W1I("=M:VES;V9S)RX`3F5P879Y:V\@:?!V97)S=&D@\&EO(%=O<F0@
M9&]K=6UE;G1O`$YE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("(E<R(N`$YE
M<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("AC;W!Y*"D@:VQA:61A*2X`3F5P
M879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@9'5O;65N^"X`4&%B<F%U:W1I`$%T
M\&%U:W1I('!A:V5I=&EM=7,`073P875K=&D@86YK<W1E<V[A('9E:6MS;>``
M3F5T:6OK=&$@<V5R=F5R:6\@:VQA:61A.B``3F5T:6OK=&$@<V5R=F5R:6\@
M:VQA:61A.B``3F5N=7)O9'ET80!5;FEK;V1A<R`H551&+3@I`$IU;F=T:6YI
M86D@07)A8O@@16UY<F%T86D`2G5N9W1I;NL@2V%R86QY<W3K`$IU;F=T:6[K
M<R!686QS=&EJ;W,`2G5N9W1I;FGX(%9A;'-T>6KX($%T;VME<V[K<R!S86QO
M<P!6:65N971A:0!.9?YI;F]M87,`3F7^:6YO;6%S(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN`$YE_FEN;VUA<R!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+@!.9?YI;F]M87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L
M87!T8?YO9&ES+@!086YA:6MI;G1I(&YU;W)O9.`@\&EA;2!E;&5M96YT=6D`
M3F7A=F%R9&EN=&%S`%-A=6=U;6\@<W5M971I;6%I<R!N97!R:79I;&5G:6IU
M;W1I('-K<FEP=&%I(&YE9V%L:2!A=&QI:W1I(%!E<FOK;&EM;R]+;W!I:F%V
M:6UO+\%KZVQI;6\@<')O9W)A;6GP:V%I+B!.;W+K9&%M:2!P97+^:?MRZW1I
M('1E8VAN:6YE<R!D971A;&5S(&UO>FEL;&$N;W)G('1I;FML87!Y:F4L(&ER
M('-U_FEN;W1I(&MA:7`@<VMR:7!T86US(&QE:7-T:2!P<FEE:71I('!R:64@
M;&%I:VEN;W-I;W,@<V%U9WEK;&]S+"!P87-P875S:VET92!/2RX`3F5N875D
M;W1I('-P86QV;W,`4&SK=&EN>7,@;F5P86QA:6MO;6%S`$%T;F%U:FEN=&D`
M071N875J:6YT:2`E<P!!=&YA=6II;G1I('9A<G1O=&]JX`!!=&YA=6II;FEM
M;R!S:W)I<'1A<R!I\'1R:6YT87,N`$YU<VGX<W1I`%9I<VD@;6]D=6QI^"!A
M=&YA=6II;FEM;R!F86EL86D@X6ME;'1I(.$@<V5R=F5RX2X`1&ED_FEO<VEO
M<R!L;W1I;FGP:V]S(')A:63K<P!$:61I96II(')O;>MN:?!K:2!S:V%IZ&EA
M:0!5<G5G=F%J=7,`3F%U9&]T:2!D86)A<G1I;N8Z("5S`$YA=61O=&D@4U-,
M`$YA=61O=&D@:F5I9W4@=F%R=&]T;VIO('9A<F1A<R]S;&%P=&'^;V1I<R!)
M35-0('-E<G9E<FEU:2!Y<F$@:VET;VMS+@!687)T;W1O:F%S("5S(&YE875T
M;W)I>G5O=&%S('!R:>MJ:6UU:2!P<FEE("5S+@!687)T;W1O:O@@861M:6YI
M<W1R879I;6%S`%9A<G1O=&]J;R!N=7-T871Y;6%I`%9A<G1O=&]J^"!R96=I
M<W1R86-I:F$`5F%R=&]T;VKX(')E9VES=')A8VEJ82!I\&IU;F=T82X`5F%R
M=&]T;VIO('9A<F1A<P!687)T;W1O:F\@=F%R9&%S.@!687)T;W1O:F\@=F%R
M9&%S.B``5F%R=&]T;VIA:2#P:6]J92!S:7-T96UO:F4Z`%5Z8F5K:7-T86YA
M<P!61E,@:V%T86QO9V%S(&YE96=Z:7-T=6]J82X`071O<W1O9V]S`%)A<W1O
M<R!T96ES:6YG;W,@=FEE=&]VZW,Z(`!'86QI;VII;6%S`%)E:6OP;>L@;6EN
M=73K;6ES(&YU;R!D86)A<BX`4F5I:_!MZW,`4F5I:_!MZW,@:?`@:W5R:?@@
M9V%L:6UA('!A<VER:6YK=&D`5F%N=6%T=0!+:6YT86YT:7,`5F5N97-U96QA
M`%!A='9I<G1I;FEM87,@;F5B86EG=&%S("T@\&ES(&QA:?!K87,@<W5G861I
M;G1A<RX`5F5R<VEJ80!697)S:6KX(&MO;G1R;VSK`$QY9VEU;W1I('9E<G1I
M:V%L:6%I`%9E<G1I:V%L=7,@=&%R<&%S`%9E<G1I:V%L=7,Z`$QA8F%I(&1I
M9&5L:7,`5FEE=&YA;6%S`%9I971N86UI971I\&MA("A625-#24DI`%!E<OYI
M^W+K=&D@)7,`4F]D>71I(&GP;W)I;N$@<'5S;&%PX0!097+^:?MRZW1I(&MA
M:7`@)7,`0G)I=/@@5FER9/YI;FEJ;W,@<V%L;W,`2D%6(%9I<F3^:6YI:F]S
M('-A;&]S`$UA=&]M=6UA<P!-871O;75M87,Z(`!6;V1A9F]N92!)=&%L:6IA
M('!E<B!33510`%=!4DX`1,M-15-)3R$A(2!005194R!)T%1224Y+251%(%-+
M4DE05,`@2=`@)7,N`%9A;&ES(&ER($9U='5N80!$ZVUE<VEO`%1R9>@N`$]R
M^"!P<F]G;F]ZZP!/<O@@<')O9VYO>NL@<&%G86P`5V5A=&AE<BYC;VT`5U=7
M`%=75R!P=7-L87!I<P!+87,@<V%V86ETY@!3=F5I:VD`4W9E:6MI(&%T=GEK
MYB#A("5S`$QA8F%S+"`E<P!686MA<O@@*$E33RTX.#4Y+3$I`%9A:V%R^"`H
M25-/+3@X-3DM,34I`%9A:V%R^"!386-H87)A`$MO:^$@;6]D=6SA("5S('1U
M<FD@<F]D>71I('!O('!R:7-I:G5N9VEM;S\`2V]K<R!S:VER='5K;R!S:6UB
M;VQI<S\`2V]K<R!K86)UZ&GX('-I;6)O;&ES/P!+=7)I;W,@9F%ZZW,`2%1-
M3"!R961A:W1O<FEA=7,@;6]D=6QI^"#A:G5N9VEM87,N`%!L;W1I<P!0;&]T
M:7,@0U-3(&UA=&%I<P`E<R!K86ER:6]J;R!M96YI=2!P;&]T:7,@*'!A:V5I
M=&EM86D@8G5S(&UA='ET:2!P;R!K:71O('!R:7-I:G5N9VEM;RDZ`$QE;G1E
M;.MS('!L;W1I<P!0;&_H:6\@;6%T87,`4&QO=&ES.@!7:6MI`%;K:F\@9W)E
M:71I<R!M87IG86ES`%;K:F%S.@!6ZVIA<SH@`$GP;6EN=&ES`$1A<F)A<P!$
M87)B;R!A9')E<V%S`$1A<F)O('1E;&5F;VYA<P!8+5)E9@!8-3`Y=C,@<&%G
M<FEN9&EN:6%I(&YU<W1A='EM86D`6#4P.78S(&GP<&SK<W1O(')A:W1O('!A
M;F%U9&]J:6UA<P!8-3`Y=C,@86QT97)N871Y=G5S('9A<F1A<P!8-3`Y=C,@
M<F%K=&\@:61E;G1I9FEK871O<FEU<P!8-3`Y=C,@;6]D=6QI86D`65D`65E9
M60!986AO;R$@_F5MZVQA<&ES`$MA<VUE=`!*96UE;F%S`%1A:7``5&%I<"P@
M8?`@<W5T:6YK=0!*^W,@97-A=&4@5$5+4U1)3DE!344@4D7>24U%+B!.;W+K
M9&%M:2!G<N'^=&D@X2!765-)5UE'('-P875S:VET92!;/#Y=+@!*^W,@;F5P
M<FES:6IU;F?F+@!3879O('9A<F1E(&YE9V%L:71E(&YA=61O=&D@<VEM8F]L
M:6\@)UPG+@#!=F5DZW1E(&YE=&5I<VEN9^`@96PN('!A\'1O(&%D<F5SX"X`
M3F5P<FEJ=6YGZW1E(&IO:VGX(&QA=6OX(&GP(.%K96QI86UO(&9A:6QO('!R
M:64@)7,@871I=&EN:V%M^"!L875K^"X`2OMS(&%T<VEJ=6YGZW1E+@!4=7)I
M=&4@X79E<W1I('1E:7-I;F?@('1E;&5F;VYO(&YU;65RX2`H=&EK('-K86GH
M:75S(&ER("<K)RP@:F5I9W4@;F]R:71E(&YU<F]D>71I('1A<G!T875T:6[A
M(&MO9.`I+@#!=F5DZW1E(&YE=&5I<VEN9^`@<F5I:_!MYBX`3F]RZV1A;6D@
M;F%U9V]T:7,@<F5G:7-T<F%C:6IO<R!S:7-T96UA+"!T=7)I=&4@<W5K;VYF
M:6?[<G5O=&D@9'5O;65N^"!M963^:6\@<&]S:7-T96WF+@!0<FEE\"!S:?AS
M9&%M:2!P<F%N9?!I;>`L(&%P<F'P>6MI=&4@<')O8FQE;>`N`,%R8?!Y:VET
M92!N=6]R;V1O<R!54DP`5'5R:71E('!A<VER:6YK=&D@<V5R=F5RX2P@:W5R
MX2!N;W)I=&4@:?!T<FEN=&DN`$YU<F]D>6MI=&4@=F%R=&]T;VIO('9A<F3@
M+"!K=7)I;R!D=6]M96YI<R!T<FEN871E+@!.=7)O9'EK:71E('9A<G1O=&]J
M;R!V87)DX"!T<GEN:6UU:2X`3G5R;V1Y:VET92!K=7)I86UO('9A<G1O=&]J
M;R!V87)DX"X`3G5R;V1Y:VET92!A=&YA=6II;F%M;R!V87)T;W1O:F\@=F%R
M9.`N`$YU<F]D>6MI=&4@=F5I:W-MX"X`2OMS('1U<FET92#A=F5S=&D@;F%U
M:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`N`"5S('-E<VEJ82!B86EGZW-I
M+B!0<F'P;VUE('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X(&5L+B!P8?!T
M;R!A9')E<V%S.@!%;"X@<&'P=&\@861R97-A<SH`26YF;W)M86-I:F$@87!I
M92!*=7,`3G5O("5S('-E<VEJ;W,@<')A9/YI;W,@:OMS^"!)4"!A9')E<V%S
M('!A<VEK96ETZRX@5'5R:71E('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X
M('9A<F1A<R]P879A<F3K`$K[<_@@875T96YT:69I:V%V:6UO('-I<W1E;6$@
M;F5P86QA:6MO('9A<G1O=&]J^"!SX')A\&\L(&%R8F$@\&D@9G5N:V-I:F$@
M=?YD<F%U<W1A(&3K;"!T86T@=&EK<O@@<')I9?YA<^AI^"X`3G5O("5S('-E
M<VEJ;W,@<')A9/YI;W,@:OMS^"!N87+P>6MLZW,@=&EP87,@<&%S:6ME:73K
M+B!4=7)I=&4@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@;F%R\'EK;.L@
M;F5P86QA:6MO(/!I;W,@9V%L:6UY8NMS+@!*^W/X(&QA:6MO(&IU;W-T83H`
M2OMS^"!S=&%N9&%R=&EN:7,@87!R8?!A<SH`2OMS^"!V87)D87,O<&%V87)D
MZSH`2OMS^"!N875J87,@)7,@<VQA<'1A_F]D:7,@>7)A.B`E<P!*^W/X(&YU
M<W1A='EM86D@871N875J:6YT:2X`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T
M87,`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,N(%!A<VET:6MR:6YK:71E
M('-A=F\@<&'P=.`@:7(@<')I<VEJ=6YK:71E('-U(&YA=6IU('-L87!T8?YO
M9/YI=2X`2OMS^"!N=71O;.8@<V5R=F5R:6%I.@!*=6=O<VQA=FEJ80!:86ER
M87,`6F%M8FEJ80!::6UB86)VZP!%;F5R9VEN9V]S`%M087-LZW!T:2!C:71U
M;VIA;>`@=&5K<W3@70!;4')O8FQE;6]S('!R86YE\&EM87-=`%M2;V1Y=&D@
M8VET=6]J86W@('1E:W-TX"`M`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M
M("5S(&5I;'5T97-=`%ME:6QU=.L@)7,@:?`@)7-=`%]686QD>6UA<P!?0TQ)
M`%]$=6]M96[X(&UE9&ES`%])\'1R:6YT:2!E:6QU=.8`1U]R=7#K<P!085]G
M86QB80!?4&%V96EK<VSK;&EO(&YU<W1A='EM86DN+BX`4')I<VE?:G5N9W1I
M`$%T<VE?:G5N9W1I`%]+96ES=&D@;G5O<F]DX"XN`%].=7-T871Y;6%I`%]4
M96ESZW,`7TGP=')I;G1I(&YU;W)O9.`N+BX`7TMO;F9I9_MR86-I:F$`7TQE
M;G1E;.MS(&YU<W1A='EM86DN+BX`5E]A<G1O=&]J86D`861R97/X(&MN>6=E
M;.L`2V%L96YD;W)I=7,`<F%M=7,`<W!A=7-K:71E(.AI80!K<F5N=&$`9F%I
M;&%S`&YU;R`E<R`H)7,I("5S("5S`&$Z`'1U;VIA=2!P870`<&%P<F%S=&D`
M96EL=71E<UT`;6MI<V]F<R!K;&%I9&]S(&MO9&%S("5D(&)E9&%R86YT($E3
M3RX`=F%R9&%S`&YE<F5A;&EZ=6]T80!D87(@;F5R96%L:7IU;W1A`'7^<F'P
M^"!K;GEG96SK`'!R;V-E;G1A:0!P:6MS96QI86D`:WEL80!R;V1Y=&D@<VMI
M<G1U;75S`'-M<S)E;6%I;"!P97(@2%144`!S=&%B:6QI`&1A<F+X('/@<F'P
M87,`<VQA<'1A_F]DX2!T=7)I=&4@X7)A\'ET:2!D=2!K87)T=7,`=6YI9FEK
M=6]T:0!D86QI<P!V87)T;W1O:F\@<&%S:7)I;FMI;6%S`'9#87)D`'`Z`'=E
M871H97(N8V]M````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;'1?3%0O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P
M`#$P-#$W,S8R-S<W`#`R,#,U-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D
M2&]R9&4Z(&AO<F1E+VQO8V%L92]L=%],5"]H96QP+GAM;"QV(#$N,B`R,#`T
M+S`U+S(W(#(P.C(R.C$T(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y
M(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@
M4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I
M9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I
M;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA
M;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"
M3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O
M;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@
M;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U
M;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO
M;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M
M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K
M+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI
M<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T
M(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@
M:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L
M;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT
M:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@
M/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G
M92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@
M;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML
M>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A
M<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI
M<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N
M8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T
M;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A
M<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L
M;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@
M=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC
M92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VQV7TQ6+P``````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,C<W-P`P,38W,3,`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M;'9?3%8O3$-?34534T%'15,O````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`R,#4P,``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]L=E],5B],0U]-15-304=%4R]H;W)D92YM;P``
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,U-S$`,3`T,3<S-C(W-S<`,#(R
M,30R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````9````!P````\`P``B0```%P&````````@`@``"@```"!"```
M"````*H(```%````LP@```@```"Y"```!P```,((```%````R@@``!\```#0
M"```$0```/`(```(`````@D```@````+"0``%0```!0)```*````*@D```P`
M```U"0``!P```$()```I````2@D```(```!T"0``!0```'<)```0````?0D`
M`!0```"."0``+P```*,)```/````TPD``"8```#C"0``!0````H*```-````
M$`H```4````>"@``$````"0*```0````-0H```\```!&"@``"P```%8*```/
M````8@H```P```!R"@``#P```'\*```>````CPH``"$```"N"@```P```-`*
M```$````U`H```P```#9"@``"@```.8*```%````\0H``!(```#W"@``$```
M``H+```(````&PL``!`````D"P``!@```#4+```'````/`L```(```!$"P``
M!````$<+```/````3`L```<```!<"P``!P```&0+```$````;`L```4```!Q
M"P``!0```'<+```'````?0L``!$```"%"P``"````)<+```>````H`L```4`
M``"_"P``*````,4+```I````[@L``!,````8#```"P```"P,```1````.`P`
M``0```!*#```#````$\,```:````7`P``!<```!W#```%P```(\,```;````
MIPP``!\```###```$P```.,,```0````]PP``!<````(#0``!P```"`-```%
M````*`T``"$````N#0``'````%`-```%````;0T```,```!S#0``(````'<-
M```F````F`T```P```"_#0``#````,P-```(````V0T```<```#B#0``!@``
M`.H-```-````\0T```L```#_#0``#`````L.```*````&`X```(````C#@``
M!@```"8.``!%````+0X``#````!S#@``$````*0.```?````M0X``!````#5
M#@``#P```.8.```%````]@X``%<!``#\#@``*@```%00```*````?Q````4`
M``"*$```#@```)`0```&````GQ````P```"F$```&0```+,0```0````S1``
M``\```#>$```"0```.X0```;````^!```!$````4$0``#````"81```(````
M,Q$``"L````\$0```@```&@1```(````:Q$``!(```!T$0``$P```(<1```O
M````FQ$``!(```#+$0``(@```-X1```'`````1(``!`````)$@``!0```!H2
M```1````(!(``!(````R$@``$````$42```8````5A(```\```!O$@``#```
M`'\2```.````C!(``!X```";$@``)````+H2```%````WQ(```D```#E$@``
M#````.\2```.````_!(```4````+$P``%````!$3```0````)A,```8````W
M$P``&@```#X3```+````61,```4```!E$P```@```&L3```%````;A,``!``
M``!T$P``!````(43```,````BA,```4```"7$P``!0```)T3```(````HQ,`
M``<```"L$P``$````+03```&````Q1,``!\```#,$P``"````.P3```C````
M]1,``"T````9%```$@```$<4```,````6A0``!<```!G%```!````'\4```0
M````A!0``!X```"5%```&P```+04```:````T!0``",```#K%```$P````\5
M```<````(Q4``!(```!`%0``%````%,5```'````:!4```@```!P%0``'P``
M`'D5```?````F14```H```"Y%0```P```,05```G````R!4``"L```#P%0``
M#P```!P6```1````+!8```\````^%@``"P```$X6```,````6A8``!````!G
M%@``$````'@6```,````B18```X```"6%@```@```*46```*````J!8``"\`
M``"S%@``/````.,6```0````(!<``!L````Q%P``%````$T7```0````8A<`
M``4```!S%P```0```"0`````````3@```!T```!/````%P```$4````'````
M(@````````!-````(0````````!+````8@````H````1``````````P````R
M````4P```#$`````````)0```$8```!=`````````%(```!"````50``````
M``!'````+````"\```!6````40```#4````0````"````#X```!!````7P``
M`"L````/````.0```$H````C````&````#,```!`````*````&`````+````
M``````````!4```````````````]````"0`````````N````2````%P````Z
M``````````X`````````60`````````V`````````!L````_````'````!H`
M```-````.P`````````$````!0`````````2`````````!,`````````5P``
M`"T`````````)@``````````````%0````8`````````6P```#<````9````
M`````%X`````````.````#0`````````20```!\```!:````1``````````>
M``````````````!C`````````%@````I`````````#```````````````#P`
M``!D````4``````````6````(``````````#````80```$,````J````)P``
M`$P````"`````````!0`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`R-"!H;W5R<P!!32]030!!9&0@<&%I<@!!9&1R97-S
M`$%L:6%S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`079A:6QA
M8FQE(&9I96QD<SH`0FER=&AD87D`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`
M1&5F875L="!)9&5N=&ET>0!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7-P
M;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'``16UA:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$AE;'``2&]M92!!9&1R97-S
M`$AO;64@4&AO;F4`2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D
M(&9I96QD<SH`3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC<P!,;V<@:6X`3&]G
M(&]U=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-97-S86=E`$UO;G1H;'D`
M3F%M90!.979E<@!.;W1E<P!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A
M<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5T=7)N('1O($]P=&EO;G,`4F]L
M90!3879E($]P=&EO;G,`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3:VEP($UA:6YT
M96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`5&%S:W,`
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R($]P=&EO;G,`57-E<FYA;64`
M5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K
M($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O
M9B`E<UT`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C$*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO
M;BU$871E.B`R,#`R+3$Q+3(X(#$T.C`P*S`R,#`*3&%S="U4<F%N<VQA=&]R
M.B!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^"DQA;F=U86=E
M+51E86TZ($QA='9I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E
M<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M0U`Q,C4W"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`E<R!5
M>G1U<N?P86YA<R!O<&5RXF-I:F%S("T@87!S=&EP<FENXFIU;7,`,C0@<W1U
M;F1A<P!!32]030!0:65V:65N;W0@<.)R:0!!9')E<V4`06EZ<W3B:G;B<F1S
M`$YO<N)D[G1A(&YE9&5R[F=A(';G<G3N8F$`4&EE96IA;6EE(&QA=6MI.@!$
M>FEM\&%N87,@9&EE;F$`2V%L96YDXG)S`$%T8V5L="!P<F]B;.=M87,@<&EE
M=&5I:W5M=0!-;V)I;&%I<R!TXFQR=6YI<P!!:7IVYW)T(&QO9W4`57KRYVUU
M;7,`3F5I>F1E=N)S(&%T=N=R="!-86EN=&5N86YC95]487-K(&UO9'5L:2`E
M<P!$1`!):V1I96YA<P!087)A<W3B(&ED96YT:73B=&4`07!R86MS=&EE="!P
M<F]B;.=M=0!3[FOB:V$@:6YF;W)MXF-I:F$@:7(@;F]S^W3N=&$@861M:6YI
M<W1R871O<F%M+@!%:W+B;F$@:65S=&%T[FIU;6D`3F%V('1I9?!A<R!P:65E
M:F%S(&UA:6YT96YA;F-E+G!H<`!%+7!A<W1S`%1U:_!S(')E>G5L=.)T<RX`
M2^_[9&$`2V%T<F%S(#$U(&UI;OMT97,`2V%T<F%S(#,P('-E:W5N9&5S`$MA
M=')A<R`U(&UI;OMT97,`2V%T<N(@<&EE<VSG9_!A;N)S(')E:7KG`$MA=')U
M('!U<W-T=6YD=0!+871R=2!M:6[[=&D`4&%R875G=N=R=.YB87,`3F5I>F1E
M=N)S('-A\F5M="!I97-T873N:G5M=7,N`$YE:7ID97;B<R!P:65S;.=G=&EE
M<R!,1$%0('-E<G9E<FEM+@!&86MS<P!086SN9'KN8F$`3>)J87,@861R97-E
M`$WB:F%S('1E;&5F;VYS`$AO<F1E`$EE;.)DYW1A:7,@;&%U:W,Z("5S`$EE
M;.)DYW1I92!L875K:3H`5F%L;V1A`%!A<N)D[G0@<&%L[F1Z[F)A<R!T96UA
M='5S`%!I97-LYV=T:65S`$EZ:65T`$U-`%!A<W1S`%-A<VMA;F_P:64@;&%U
M:VD`6FGR80!+871R=2!MYVYE<VD`5N)R9',`3F5K860`4&EE>NYM97,`3W!C
M:6IA<P!#:71A(&EN9F]R;>)C:6IA`%!A<F]L90!)>G!I;&3N="!U>G1U<N?P
M86YA<R!O<&5RXF-I:F%S`%3B;')U;FES`$S[9'IU(&YO<N)D:65T('!R;V)L
MYVUA<R!A;F]TXF-I:G4N`$S[9'IU(&YO<N)D:65T('-A=G4@;&EE=&]TXFIA
M(';B<F1U('5N('!A<F]L:0!0<F]B;.=M87,@87!R86MS=',`27ID>N=S="!P
MXG)I`$%T9W)I97IT:65S('!I92!O<&-I:N)M`$QO;6$`4V%G;&%BXG0@;W!C
M:6IA<P!)>G;G;&EE=&EE<R!D871U;6$@871D86SN=.)J=3H`27IVYVQI971I
M97,@9&%T=6UA(&9O<FWB='4Z`$EZ=N=L:65T:65S(&QA:6MA(&9O<FWB='4Z
M`$EZ=N=L:65T:65S(&1I=G5S('-A9&5R[F=U<R!L875K=7,N`$EZ=N=L:65T
M:65S('9A;&]D=3H`3F]S^W3N="!P<F]B;.=M87,@<&EE=&5I:W5M=0!)>FQA
M:7-T('5Z='5RY_!A;G4`SG!A\&\@<VEM8F]L=2!I979A9&4`5F5I:W-M90!5
M>F1E=G5M:0#0:6T@<VMA:71L:6T@:7(@:N)B^W0@=FES;6%Z(#$N`-!A:2!V
MYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI;2X`5FER<W)A:W-T<P!54DP`3F%V
M(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN`$YA=B!I97-P
MYVIA;7,@:6YT97)P<F5TYW0@\&\@5V]R9"!D;VMU;65N='4`071C96QT(&EZ
M;6%I\F%S`$QI971O=.)J82!O<&-I:F%S`$QI971O=.)J82!VXG)D<P!"<NYD
M:6[B:G5M<P!+871R=2!N963G[W4`3&%I<&YI(&S[9'IA;2`E<P!,86EP;FD@
M;/MD>FTL("5S`$1A<F)A(&%D<F5S90!$87)B82!TXFQR=6YI<P!'1P!+871R
M=2!G861U`$%P<F%K<W1I970@<')O8FSG;74@<&ER;7,@<&EE=&5I:W5M82!S
M^W3N\&%N87,N`$K[<W4@)7,@<V5S:6IA(&ER(&)E:6=U<VEE<RX@3/MD>G4@
M<&EE<VSG9'II971I97,@871KXG)T;W1I+@!*^W-U(&EN9F]R;>)C:6IA`$K[
M<W4@;W!C:6IA<R!I<B!S86=L86+B=&%S+@!;4')O8FSG;6%S('II\F]J=6US
M70!;<FEN9&$@)7,@;F\@)7-=`'9#87)D````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+VUK7TU++P``````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-P`P,38V-C<`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;6M?34LO3$-?34534T%'
M15,O````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S<W`#`R,#0U-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]M:U]-2R],0U]-15-304=%4R]H;W)D92YM;P``````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3(V,3``,3`T,3<S-C(W-S<`,#(R,3`W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````6````!P`
M``#<`@``?P```)P%````````F`<``"@```"9!P``"````,('```%````RP<`
M``\```#1!P``"````.$'```(````Z@<``!D```#S!P``!P````T(```.````
M%0@```4````D"```$0```"H(```(````/`@``!4```!%"```"@```%L(```,
M````9@@```<```!S"```$````'L(```I````C`@```(```"V"```!0```+D(
M```0````OP@```8```#0"```%````-<(```F````[`@```4````3"0``#0``
M`!D)```%````)PD```L````M"0``#P```#D)```A````20D```,```!K"0``
M!````&\)```,````=`D```H```"!"0``!0```(P)```2````D@D``!````"E
M"0``$````+8)```:````QPD```8```#B"0``!P```.D)```"````\0D```0`
M``#T"0``#P```/D)```'````"0H```<````1"@``!````!D*```%````'@H`
M``@````D"@``%0```"T*```>````0PH```4```!B"@``*````&@*```I````
MD0H``!,```"["@``"P```,\*```%````VPH``!$```#A"@``!````/,*```,
M````^`H``!H````%"P``%P```"`+```7````.`L``!L```!0"P``$P```&P+
M```0````@`L``!<```"1"P``!P```*D+```%````L0L```,```"W"P``(```
M`+L+```F````W`L```P````##```"````!`,```4````&0P```<````N#```
M!@```#8,```+````/0P```P```!)#```"@```%8,```"````80P```8```!D
M#```10```&L,```F````L0P``"4```#8#```<P```/X,```0````<@T``'$!
M``"##0``(@```/4.```'````&`\```4````@#P``%````"8/```*````.P\`
M``\```!&#P``)P```%8/```&````?@\```X```"%#P``!0```)0/```0````
MF@\```@```"K#P``%0```+0/```'````R@\``!4```#2#P``!0```.@/```/
M````[@\``#L```#^#P```@```#H0```&````/1```!0```!$$```!P```%D0
M```1````81```"H```!S$```!P```)X0```0````IA````8```"W$```$0``
M`+X0```'````T!```"4```#8$```!````/X0```%`````Q$```\````)$0``
M#P```!D1```%````*1$``!0````O$0``$P```$01```6````6!$``"8```!O
M$0``"````)81```%````GQ$```(```"E$0``!0```*@1```6````KA$```8`
M``#%$0``!P```,P1```#````U!$```D```#8$0``!P```.(1```=````ZA$`
M`!P````($@``!P```"42```@````+1(``#````!.$@``$0```'\2```,````
MD1(```4```">$@``$0```*02```%````MA(```T```"\$@``'````,H2```9
M````YQ(``!D````!$P``'@```!L3```;````.A,``!,```!6$P``'0```&H3
M```'````B!,```8```"0$P```P```)<3```J````FQ,``"L```#&$P``$P``
M`/(3```.````!A0``!8````5%```"````"P4```'````-10```X````]%```
M$````$P4```1````710```(```!O%```!P```'(4```P````>A0``"L```"K
M%```*0```-<4``!N`````14``!<```!P%0```0```"P````J`````````%8`
M```+`````````!@``````````````$0````H`````````!0`````````````
M`#4````%````2@````(````#````.P```$@````2`````````%$````^````
M,P```"$````R````3````!H`````````+P```"```````````````%<````6
M````*P```!,`````````1@```!\````&````.0````````````````````H`
M``!"````)P``````````````)`````\````,````30```$<````V````````
M`#H````I````2P````<````C````````````````````4P```$`````>````
M-````!P`````````'0`````````B````$0``````````````/P``````````
M````%P```$,```!4````3P```"4````5````,````$X`````````#@```#P`
M```0````6```````````````10`````````-`````````!L````)````"```
M``````!0````&0`````````F````!````#$````X````/0```%4```!2````
M+0``````````````20```$$````W`````````"X````````````````E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`#(T(&AO=7)S
M`$%-+U!-`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E<@!!9&1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061M:6YI<W1R871I;VX`
M06QI87,`079A:6QA8FQE(&9I96QD<SH`0FER=&AD87D`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]N
M9FER;2!087-S=V]R9`!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<P!$1`!$86EL>0!$969A=6QT($ED96YT:71Y`$1E;&5T90!$
M97-C<FEB92!T:&4@4')O8FQE;0!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R`$5V97)Y
M($QO9VEN`$5X86UP;&4@=F%L=65S.@!&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`1F%X`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&ES
M="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@
M:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-97-S86=E`$UO
M;G1H;'D`3F%M90!.;W1E<P!087-S=V]R9`!087-S=V]R9',@;75S="!M871C
M:"X`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!H;VYE`%!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4')O8FQE;2!$97-C
M<FEP=&EO;@!296UO=F4@<&%I<@!297-E=`!2971U<FX@=&\@3W!T:6]N<P!2
M;VQE`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-U8V-E<W,`5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M`%5N9&\@0VAA;F=E<P!5<V5R;F%M90!5<V5R<R!I;B!T:&4@<WES=&5M.@!7
M87)N:6YG`%=E96ML>0!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0
M:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!;4')O8FQE;2!297!O<G1=`%!R;VIE8W0M260M5F5R<VEO;CH@
M;6M?34L*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`S+3`V+3(V(#$U.C$X*S`R,#`*3&%S="U4
M<F%N<VQA=&]R.B!3=&]J86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M+FUK/@I,
M86YG=6%G92U496%M.B!-86-E9&]N:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4E33RTX.#4Y+34*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=`I8+4=E;F5R871O<CH@2T)A8F5L(#$N,"XQ"@`E<R"^W]7@T.;8
MV"#7T"#>U.#6X]+0^M4@+2"_WN+2X-30`#(T(.?0X=``04TO4$T`M-[4T-38
M(-W>TB#:WN#8X=W8VCH`M-[4T-38(-_0X`"TWM30U-@@VM[@V.'=V-H`M-[4
MT-+0^M7BWB#=T"#:WN#8X=W8YM@@U2#>W=72WM?<WM;5W=XN`+#4X-7AT`"P
MU-S8W=CAXN#0YMCXT`!!;&EA<P"TWN'BT-_=V"#?WMO8^M`Z`,#>U-7=U-7=
M`+[BVM#6V""_X-[1V]7<(,#5W][@X@"\WM'8V]7=`+?0XM+>X-@@T]X@W^#>
MU][@U>;>X@#$V.#<T`"_WN+2X-38(-O>U]C=VM``O-[4X]O>XB#=T"#7T-30
MY]#BT"#7T"#>U.#6X]+0^M4@)7,@W=4@W-[6U2#4T"#1V-35(-[BTM[@U=T`
M1$0`M-W5TMW>`,'BT-W4T.#4U=T@V-35W>+8XM7B`+C7T>#8Z-@`OM_8X2#=
MT"#?X-[1V]7<WN(`O=4@W^#8X>+0W^/2T/@@U-C@U=KBW=X@U-X@;6%I;G1E
M;F%N8V4N<&AP`-4MW][HXM``O^#0U]7=(.#5U^/;XM#B+@"SX-7HVM``P=7:
MWM4@W^#8^-#2X]+0^M4`O^#8W-7@.@"]U>/AW]7HW=`@VM[=U=KFV/C0(.'>
M($Q$05`@X=7@TM7@WN(N`,30VN$`O][<WN@`M-[<T.C=T"#0U.#5X=`Z`+3>
MW-#HU=T@XM7;U>3>W0!(;W)D90"XW-_>X.+8X-#=WB#?WMO5.B`E<P"XW-_>
MX.+8X-#=V"#?WMO8^M`Z`+C7V]CAXM#X(.+5W-@@U]`@W][<WN@`N]CAXM#Z
MU>+>(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=WBX`N][3V.#0^M4`N-?;
MU=<`34T`O][HXM``NM[@U>'?WMW4V.#0Y]K8(-_>V]CZT`"_WN#0VM``O-7A
MU>?=W@"XW-4`M]#1U=O5Z-K8`+O>U]C=VM``N][7V-W:V.+5(-S>X-`@U-`@
MT=C4T.(@V.'BV"X`N-?2X.C8(-[?U>#0YMC8(-?0(-[4X-;CTM#ZU0#"U=O5
MY-[=`++5(-S>V]C<U2#=T-+5U-7BU2#3WB#?X-[1V]7<WN(N`++5(-S>V]C<
MU2#=T-+5U-7BU2#2T.C5(-K>X-CAW=CGVMX@V-S5(-@@V][7V-W:T`"^W]CA
M(-W0(-_@WM';U=S>X@"^U.'BX-#=V"#?T.``4F5S970`O=#7T-0@VM[=(-[?
MYMC8XM4`P]O>T]``M]#GX]+0^"#>W^;8V`"XU]'5X-@@X=7?T.#0XM[@(-?0
M(-30XN/<WN(Z`+C7T=7@V"#DWN#<T.(@U]`@U-#BX]S>XCH`N-?1U>#8(.3>
MX-S0XB#7T"#2X-7<U>+>.@"XU]'5X-@@U-+5(-[4T][2T.#0Y]K8(-_>V]CZ
MT"X`O^#0XM@@V-?2U>CBT/@@U]`@W^#>T=O5W-[B`+_@U>':WMK=V"#>U.#6
MX]+0^M4`LMW5X>/2T/K5(-W0(.'?U>;8^-#;W=@@U]W0YM@`P^'?U>C=W@"]
MT.';WM(`55),`+W5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5
MX-+5X-[B+@"]U2#<WM;5TB#4T"#3WB#?X-72U=30W"#>TM[X(%=O<F0@U-[:
MX]S5W>(N`+[BVM#6V"#3V"#?X-[<U=W8XM4`NM[@V.'=V.?:WB#8W-4`NM[@
MV.'=V.;8(-+>(.'8X>+5W-[B.@"RW=C<T-W8U0"]U=35V]W>`+3>T>#5U-[X
MU-4L("5S`+#4X-7AT"#=T"#@T-'>XM``PM7;U>3>W2#=T"#@T-'>XM``L[,`
ML][4V.C=W@"^W]CHU>+5(-/>(-_@WM';U=S>XB#?X-74(-30(-CAW^#0XM7B
MU2#8U]+5Z.+0^"X`O=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5
M(-[BX>+@T-W8+@"]T-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8W-4@U-`@X=4@
MU-[4T-35+@"RT.C8WN(@T-+BWN#8U]#FV-[=U=T@W^#>XM[:WML@W=4@W][4
MX-;CTM`@V]CAXM#ZU2#:WN#8X=W8YM@L(-C;V"#BT-`@W-[6W=[AXB#5(-[=
MU=+>U]S>UM7=T"#>U"#4X./3V"#?X-CGV-W8+@!;N-?2U>CBT/@@U]`@W^#>
MT=O5W-[B70``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N8E].3R\`````````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C(W-S<`,#$V-C8T`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYB
M7TY/+TQ#7TU%4U-!1T53+P``````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-P`P,C`T-3$`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O;F)?3D\O3$-?34534T%'15,O:&]R9&4N;6\`````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,38Q,#0S`#$P-#$W,S8R-S<W`#`R,C$Q
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````%$#```<````I!H``'\$```L-0```````"A'``!(````*4<```X`
M``!R1P``#P```(%'```-````D4<```@```"?1P``"P```*A'```,````M$<`
M``0```#!1P``#````,9'```1````TT<``"4```#E1P``#P````M(```+````
M&T@``!$````G2```#@```#E(```%````2$@``"@```!.2```"````'=(```*
M````@$@``!4```"+2```$@```*%(```+````M$@``!0```#`2```)@```-5(
M```G````_$@``"8````D20``$P```$M)```.````7TD```H```!N20``#0``
M`'E)```G````ATD``"````"O20``#@```-!)```7````WTD``"(```#W20``
M-0```!I*```1````4$H```T```!B2@``#````'!*```-````?4H```8```"+
M2@``&P```))*```M````KDH``"0```#<2@``*0````%+```9````*TL``!@`
M``!%2P``#````%Y+```.````:TL```X```!Z2P``"````(E+```N````DDL`
M`!H```#!2P``,@```-Q+```X````#TP``%0```!(3```40```)U,``!:````
M[TP``%<```!*30``-````*)-```%````UTT``!$```#=30``"````.]-```)
M````^$T```D````"3@``#@````Q.```(````&TX``"4````D3@``(````$I.
M```0````:TX```\```!\3@``"@```(Q.```'````ETX```,```"?3@``#P``
M`*-.```4````LTX```D```#(3@``#0```-).```2````X$X``!D```#S3@``
M'@````U/```/````+$\```H````\3P``#P```$=/```(````5T\``"0```!@
M3P``%P```(5/```4````G4\``!8```"R3P``"````,E/``!.````TD\``"T`
M```A4```'P```$]0```9````;U````<```")4```#````)%0```L````GE``
M``X```#+4````P```-I0```%````WE````4```#D4```"@```.I0```#````
M]5```!<```#Y4```"@```!%1```/````'%$```X````L40``&````#M1```C
M````5%$```X```!X40``%````(=1```7````G%$``!<```"T40``%P```,Q1
M```3````Y%$```\```#X40``'P````A2```/````*%(```8````X4@``"P``
M`#]2```0````2U(``!4```!<4@``%0```')2```'````B%(``!````"04@``
M$0```*%2```,````LU(``#L```#`4@``.````/Q2```#````-5,```D````Y
M4P``.0```$-3```2````?5,``#D```"04P``)P```,I3```L````\E,``"H`
M```?5```)0```$I4```)````<%0```H```!Z5```!P```(54```O````C50`
M`#<```"]5```+@```/54``!5````)%4``"T```!Z50``+0```*A5```M````
MUE4``$`````$5@``(P```$56```C````:58``"T```"-5@``,P```+M6```5
M````[U8``!D````%5P``*0```!]7```D````25<``!$```!N5P``$0```(!7
M```,````DE<```H```"?5P``$````*I7```6````NU<``!8```#25P``!```
M`.E7```G````[E<```@````66```!P```!]8```(````)U@``"D````P6```
M#@```%I8```*````:5@```0```!T6```"0```'E8```&````@U@``!$```"*
M6```!P```)Q8```$````I%@```8```"I6```#0```+!8```#````OE@```,`
M``#"6```%P```,98```3````WE@```@```#R6```!````/M8``!!`````%D`
M`"````!"60``!@```&-9```&````:ED``!4```!Q60``&````(=9```B````
MH%D``"X```##60``'0```/)9```A````$%H``%0````R6@``*0```(=:```'
M````L5H``!4```"Y6@``"@```,]:```/````VEH```T```#J6@``#P```/A:
M```-````"%L```D````66P``!@```"!;```3````)UL``!0````[6P``#```
M`%!;```&````75L``%0```!D6P``!````+E;```.````OEL``$0```#-6P``
M$0```!)<```1````)%P``!$````V7```'````$A<```J````95P``"$```"0
M7```!0```+)<```3````N%P``!(```#,7```"@```-]<```/````ZEP``!$`
M``#Z7```$P````Q=```,````(%T```8````M70``!@```#1=```0````.UT`
M`!$```!,70``!0```%Y=```,````9%T``!````!Q70``#0```()=```&````
MD%T```<```"770``#0```)]=```0````K5T```D```"^70``!P```,A=```+
M````T%T```L```#<70``!P```.A=```)````\%T``!0```#Z70``"0````]>
M```*````&5X``!D````D7@``'0```#Y>```,````7%X``!````!I7@``$@``
M`'I>```3````C5X``"L```"A7@``.P```,U>```@````"5\``#8````J7P``
M$````&%?```(````<E\```8```![7P``!````()?```.````AU\``!````"6
M7P``'@```*=?```;````QE\``"$```#B7P``'@````1@```9````(V```!X`
M```]8```&P```%Q@```N````>&```!<```"G8```)@```+]@```P````YF``
M`!L````780``'@```#-A```<````4F$``"8```!O80``*P```)9A```S````
MPF$``"8```#V80``*P```!UB```X````26(``!T```""8@``%0```*!B```O
M````MF(``!(```#F8@``(````/EB```I````&F,``!X```!$8P``$@```&-C
M``"B````=F,``!8````99```(P```#!D```H````5&0``"D```!]9```*```
M`*=D```?````T&0``!4```#P9```(`````9E```E````)V4``"@```!-90``
M+0```'9E```P````I&4``)(```#590``(0```&AF```6````BF8``!P```"A
M9@``)@```+YF```J````Y68``$$````09P``1````%)G```,````EV<```<`
M``"D9P``!P```*QG```&````M&<```T```"[9P``$````,EG```2````VF<`
M`!,```#M9P``$@````%H```-````%&@```P````B:```#P```"]H```3````
M/V@```T```!3:```*````&%H```#````BF@```T```".:```!@```)QH```"
M````HV@```4```"F:```!````*QH```0````L6@```0```#":```#0```,=H
M```.````U6@```,```#D:```#@```.AH```(````]V@```\`````:0``"```
M`!!I```/````&6D```<````I:0``#0```#%I```0````/VD``!,```!0:0``
M$P```&1I```+````>&D``!$```"$:0``"0```)9I```&````H&D```P```"G
M:0``$0```+1I```9````QFD```L```#@:0``#0```.QI```B````^FD``!L`
M```=:@``-````#EJ```*````;FH``!@```!Y:@``&0```))J```6````K&H`
M`"\```##:@``(@```/-J```-````%FL```<````D:P``#````"QK```F````
M.6L``!0```!@:P``"P```'5K```B````@6L``"\```"D:P``"P```-1K```)
M````X&L``!D```#J:P``"P````1L```7````$&P``!<````H;```"0```$!L
M```6````2FP```\```!A;```%@```'%L```.````B&P``!@```"7;```#0``
M`+!L```F````OFP``$,```#E;```"````"EM```O````,FT```X```!B;0``
M!0```'%M```&````=VT```,```!^;0``!````()M```*````AVT```H```"2
M;0``#P```)UM```0````K6T``!<```"^;0``$0```-9M```7````Z&T``!D`
M````;@``"0```!IN```*````)&X```(````O;@``!0```#)N```-````.&X`
M`!L```!&;@``%P```&)N```)````>FX```X```"$;@``#0```)-N```2````
MH6X``#@```"T;@``(````.UN```#````#F\```@````2;P``#@```!MO``![
M````*F\``!@```"F;P``!0```+]O```8````Q6\``!D```#>;P``$P```/AO
M```'````#'````8````4<```$````!MP```/````+'```!`````\<```#P``
M`$UP```+````77````\```!I<```#````'EP```/````AG````<```"6<```
M"@```)YP```&````J7````X```"P<```#````+]P```H````S'````\```#U
M<```"`````5Q```(````#G$``!,````7<0``'@```"MQ```A````2G$``"``
M``!L<0``&0```(UQ```7````IW$``"4```"_<0``%P```.5Q```$````_7$`
M``P````"<@```P````]R```(````$W(```H````<<@``#````"=R```+````
M-'(``!````!`<@``#````%%R```3````7G(``!0```!R<@``#````(=R```)
M````E'(```X```"><@``"P```*UR```;````N7(```<```#5<@``"@```-UR
M```-````Z'(```D```#V<@``!`````!S```%````!7,```,````+<P``&```
M``]S```*````*',```0````S<P``)@```#AS```.````7W,``'P```!N<P``
M%0```.MS```%`````70```<````'=```#`````]T```(````''0```H````E
M=```!@```#!T```(````-W0``!8```!`=```$@```%=T```"````:G0```8`
M``!M=```%0```'1T```/````BG0``!$```":=```&@```*QT```$````QW0`
M``D```#,=```$````-9T```)````YW0```D```#Q=```&@```/MT```(````
M%G4``!D````?=0``#@```#EU```.````2'4```H```!7=0```@```&)U```-
M````974```D```!S=0``!@```'UU```)````A'4``!0```".=0``'0```*-U
M```1````P74```8```#3=0``$0```-IU```1````['4```D```#^=0```@``
M``AV```$````"W8``#D````0=@``/0```$IV```Z````B'8``!X```##=@``
M#@```.)V```$````\78```8```#V=@``!@```/UV```$````!'<``!$````)
M=P``!@```!MW```*````(G<``"(````M=P``!````%!W```E````57<```4`
M``![=P``!````(%W```,````AG<```H```"3=P``!0```)YW```Z````I'<`
M`#````#?=P``-0```!!X```I````1G@``"X```!P>```1P```)]X```X````
MYW@``"D````@>0``/P```$IY```N````BGD``"T```"Y>0``'P```.=Y```/
M````!WH``!(````7>@``"P```"IZ```F````-GH``"D```!=>@``)````(=Z
M```F````K'H```@```#3>@``"@```-QZ```)````YWH``"````#Q>@``(```
M`!)[```F````,WL```H```!:>P``&0```&5[```I````?WL``!8```"I>P``
M$@```,![```*````TWL```P```#>>P``#P```.M[```0````^WL``$`````,
M?```<````$U\``!F````OGP```X````E?0``"0```#1]```*````/GT``!(`
M``!)?0``$P```%Q]```,````<'T```8```!]?0``#P```(1]```2````E'T`
M`!````"G?0``"@```+A]```1````PWT``!P```#5?0``(P```/)]``!J````
M%GX```\```"!?@``$````)%^```$````HGX```L```"G?@``%````+-^```,
M````R'X```P```#5?@``#P```.)^```5````\GX``"D````(?P``*@```#)_
M```F````77\``"<```"$?P``*0```*Q_```J````UG\``!D````!@```0@``
M`!N````1````7H```!(```!P@```$P```(.````4````EX````\```"L@```
M%@```+R````7````TX```!````#K@```$0```/R````T````#H$``!,```!#
M@0``$@```%>!```U````:H$``!0```"@@0``!P```+6!```K````O8$``"``
M``#I@0``%`````J"```1````'X(``!<````Q@@``'````$F"```3````9H(`
M`!$```!Z@@``&@```(R"```>````IX(``!H```#&@@``$0```.&"```7````
M\X(``!0````+@P``%P```""#```5````.(,```D```!.@P``$0```%B#```&
M````:H,```8```!Q@P``!P```'B#```$````@(,```0```"%@P``!P```(J#
M```.````DH,```X```"A@P``*````+"#```.````V8,```P```#H@P``#P``
M`/6#```*````!80```@````0A```"0```!F$```K````(X0```0```!/A```
M!P```%2$```(````7(0```D```!EA```#````&^$```-````?(0```X```"*
MA```%@```)F$```1````L(0```,```#"A```!@```,:$```9````S80```0`
M``#GA```"P```.R$```+````^(0```T````$A0``"@```!*%```0````'84`
M``\````NA0``$0```#Z%```7````4(4```H```!HA0``$0```'.%```(````
MA84```0```".A0``#P```).%```Z````HX4```4```#>A0``#````.2%```>
M````\84```X````0A@``$````!^&```+````,(8```P````\A@``"0```$F&
M```'````4X8```H```!;A@``"0```&:&```.````<(8``!````!_A@``&@``
M`)"&```*````JX8``!0```"VA@``"@```,N&```,````UH8```\```#CA@``
M"````/.&```&````_(8```<````#AP``"P````N'``!'````%X<```T```!?
MAP``"0```&V'```$````=X<```,```!\AP``$P```("'```3````E(<```(`
M``"HAP``!````*N'```/````L(<``!0```#`AP``$P```-6'```0````Z8<`
M``T```#ZAP``#@````B(```6````%X@```H````NB```!P```#F(```'````
M08@```D```!)B```!P```%.(```$````6X@```P```!@B```!0```&V(```$
M````<X@```0```!XB```"0```'V(```"````AX@```\```"*B```!````)J(
M```%````GX@```8```"EB````@```*R(```&````KX@``!0```"VB```!P``
M`,N(```*````TX@``!$```#>B```"````/"(```>````^8@``"@````8B0``
M%````$&)```%````5HD``"@```!<B0``*0```(6)``!7````KXD``"P````'
MB@``!P```#2*```-````/(H``!,```!*B@``(P```%Z*```+````@HH```L`
M``".B@``(````)J*```G````NXH``"L```#CB@``%`````^+```%````)(L`
M`!$````JBP``!````#R+```$````08L```P```!&BP``!@```%.+```-````
M6HL``!H```!HBP``%P```(.+```7````FXL``!L```"SBP``'P```,^+```7
M````[XL``!,````'C```&0```!N,```$````-8P``!`````ZC```%P```$N,
M```%````8XP```8```!IC```!P```'",```&````>(P```<```!_C```!P``
M`(>,```%````CXP``!H```"5C```%````+",```)````Q8P``!P```#/C```
M*0```.R,```X````%HT``"\```!/C0``*P```'^-```J````JXT``#X```#6
MC0``'0```!6.```C````,XX``"$```!7C@``'````'F.```%````EHX```(`
M``"<C@```P```)^.```@````HXX``"8```#$C@``#````.N.```?````^(X`
M``<````8CP``&````""/```&````.8\```P```!`CP``"````$V/```)````
M5H\```<```!@CP``"@```&B/```)````<X\```<```!]CP``!@```(6/```-
M````C(\```L```":CP``#````*:/```*````LX\```(```"^CP``!@```,&/
M```#````R(\``$4```#,CP``,````!*0```0````0Y````D```!4D```4P``
M`%Z0```?````LI```!````#2D```#P```..0```%````\Y````@```#YD```
M"`````*1```$````"Y$```4````0D0``:`$``!:1``!/````?Y(``!$```#/
MD@``$````.&2```1````\I(```@````$DP``"P````V3```(````&9,```4`
M```BDP``"P```"B3```1````-),``"D```!&DP``$````'"3```-````@9,`
M`!$```"/DP``#@```*&3```%````L),``"@```"VDP``#P```-^3```/````
M[Y,```\```#_DP``$P````^4```+````(Y0``!4````OE```1````$64```D
M````BI0``"X```"OE```%@```-Z4```-````]90```L````#E0``#P````^5
M```S````'Y4``"$```!3E0``#0```'65```9````@Y4``"<```"=E0``.@``
M`,65```2`````)8```\````3E@``$0```".6```3````-98```8```!)E@``
M'````%"6```L````;98``!\```":E@``)0```+J6```:````X)8``!H```#[
ME@``"@```!:7```0````(9<``!`````REP``"````$.7```P````3)<``!H`
M``!]EP``/````)B7``!$````U9<``&`````:F```70```'N8``!G````V9@`
M`&0```!!F0``0````*:9```%````YYD``!$```#MF0``!0```/^9```0````
M!9H```T````6F@``%````"2:```'````.9H``"X```!!F@``*@```'":```-
M````FYH```T```"IF@``%0```+>:```*````S9H```@```#8F@``%````.&:
M```9````]IH```T````0FP``$@```!Z;```5````,9L``"````!'FP``(```
M`&B;```3````B9L``!````"=FP``%@```*Z;```,````Q9L``"8```#2FP``
M%P```/F;```7````$9P``!H````IG```#P```$2<``!.````5)P``"H```"C
MG```'@```,Z<```S````[9P```<````AG0``"P```"F=```P````-9T```X`
M``!FG0``"````'6=```%````?IT```<```"$G0``"@```(R=```$````EYT`
M`!D```"<G0``#````+:=```0````PYT```\```#4G0``%@```.2=```Q````
M^YT``!,````MG@``%0```$&>```8````5YX``!L```!PG@``&0```(R>```1
M````IIX``!$```"XG@``'0```,J>```,````Z)X```0```#UG@``!P```/J>
M```,`````I\``!0````/GP``-0```"2?```(````6I\``!0```!CGP``%P``
M`'B?```)````D)\``$,```":GP``.P```-Z?```%````&J````L````@H```
M/@```"R@```0````:Z```$$```!\H```,````+Z@```S````[Z```#4````C
MH0``.````%FA```)````DJ$```@```"<H0``"0```*6A```[````KZ$``#H`
M``#KH0``.@```":B``!6````8:(``#D```"XH@``.0```/*B```Y````+*,`
M`#@```!FHP``*````)^C```I````R*,``#D```#RHP``/P```"RD```4````
M;*0``!@```"!I```)@```)JD```F````P:0``!,```#HI```#@```/RD```,
M````"Z4```@````8I0``#@```"&E```6````,*4``!D```!'I0``!0```&&E
M```M````9Z4```H```"5I0``!@```*"E```'````IZ4``"X```"OI0``$P``
M`-ZE```*````\J4```,```#]I0``"0````&F```%````"Z8```X````1I@``
M!@```""F```%````)Z8```0````MI@``"@```#*F```#````/:8```,```!!
MI@``&````$6F```8````7J8```@```!WI@``!@```("F``!"````AZ8``"0`
M``#*I@``!@```.^F```&````]J8``!4```#]I@``&P```!.G```?````+Z<`
M`"\```!/IP``'P```'^G```D````GZ<``'4```#$IP``-P```#JH```&````
M<J@``!<```!YJ```#````)&H```4````GJ@``!P```"SJ```%````-"H```2
M````Y:@```P```#XJ```!@````6I```7````#*D``!X````DJ0``"0```$.I
M```%````3:D``$T```!3J0``!````*&I```.````IJD``"8```"UJ0``$```
M`-RI```3````[:D```X````!J@``(````!"J```N````,:H``"@```!@J@``
M!0```(FJ```3````CZH``!````"CJ@``#````+2J```0````P:H``!4```#2
MJ@``$P```.BJ```*````_*H```4````'JP``!0````VK```5````$ZL``!$`
M```IJP``!0```#NK```+````0:L```D```!-JP``#@```%>K```+````9JL`
M``@```!RJP``#0```'NK```2````B:L```L```"<JP``"0```*BK```*````
MLJL```L```"]JP``!0```,FK```&````SZL``!(```#6JP``#````.FK```&
M````]JL``!P```#]JP``(@```!JL```-````/:P```\```!+K```%0```%NL
M```6````<:P``#,```"(K```0@```+RL```E````_ZP``"0````EK0``#@``
M`$JM```(````6:T```8```!BK0``!@```&FM```3````<*T``!(```"$K0``
M'P```)>M```>````MZT``"D```#6K0``*`````"N```@````*:X``"(```!*
MK@``*@```&VN```Y````F*X``!P```#2K@``)@```.^N```Q````%J\``"(`
M``!(KP``)0```&NO```@````D:\``"L```"RKP``,0```-ZO```J````$+``
M`"8````[L```)P```&*P```X````BK```",```##L```(P```.>P```X````
M"[$``!,```!$L0``(@```%BQ```I````>[$``!\```"EL0``$@```,6Q``"Q
M````V+$``!<```"*L@``(@```**R```J````Q;(``"H```#PL@``/0```!NS
M```F````6;,``"$```"`LP``(@```**S```I````Q;,``"P```#OLP``.```
M`!RT```O````5;0``*````"%M```)P```":U```7````3K4``"````!FM0``
M+````(>U```L````M+4``#<```#AM0``/P```!FV```*````6;8```0```!D
MM@``!@```&FV```'````<+8```\```!XM@``#0```(BV```3````EK8``!0`
M``"JM@``$0```+^V```.````T;8```T```#@M@``#0```.ZV```4````_+8`
M``X````1MP``,@```""W```(````4[<``!4```!<MP``!@```'*W```"````
M>;<```8```!\MP``!````(.W```1````B+<```0```":MP``#````)^W```)
M````K+<```,```"VMP``#0```+JW```(````R+<```L```#1MP``!P```-VW
M```/````Y;<```@```#UMP``#@```/ZW```1````#;@``!0````?N```%```
M`#2X```,````2;@``!````!6N```"````&>X```%````<+@```P```!VN```
M#P```(.X```8````D[@```L```"LN```#0```+BX```A````QK@``!L```#H
MN```-@````2Y```)````.[D``!4```!%N0``%P```%NY```3````<[D``#,`
M``"'N0``)@```+NY```,````XKD```<```#ON0``$0```/>Y```O````";H`
M`!$````YN@``"P```$NZ```B````5[H``"X```!ZN@``"0```*FZ```)````
ML[H``!\```"]N@``"P```-VZ```=````Z;H``!T````'NP``!P```"6[```4
M````+;L```P```!"NP``$P```$^[```.````8[L``!(```!RNP``"@```(6[
M```@````D+L``#H```"QNP``"````.R[```O````];L```X````EO```"0``
M`#2\```&````/KP```,```!%O```!P```$F\```.````4;P```X```!@O```
M$P```&^\```2````@[P``!H```"6O```$0```+&\```:````P[P``!H```#>
MO```"0```/F\```*`````[T```(````.O0``!@```!&]```-````&+T``!@`
M```FO0``%@```#^]```(````5KT```P```!?O0``#@```&R]```1````>[T`
M`$````"-O0``&0```,Z]```%````Z+T```@```#NO0``%````/>]``"0````
M#+X``"$```"=O@``!````+^^```<````Q+X``!H```#AO@``&P```/R^```&
M````&+\```8````?OP``$````":_```/````-[\``!````!'OP``#P```%B_
M```/````:+\```T```!XOP``#````(:_```0````D[\```0```"DOP``!P``
M`*F_```%````L;\```T```"WOP``#0```,6_```N````T[\```H````"P```
M"0````W````.````%\```!L````FP```(0```$+````B````9,```"$```"'
MP```'@```*G````>````R,```"H```#GP```'0```!+!```(````,,$```P`
M```YP0```P```$;!```'````2L$```D```!2P0``"P```%S!```(````:,$`
M``L```!QP0``"P```'W!```6````B<$``!8```"@P0``#````+?!```'````
MQ,$```<```#,P0``#@```-3!```A````X\$```8````%P@``#P````S"```0
M````',(```P````MP@```P```#K"```$````/L(```0```!#P@``&0```$C"
M```)````8L(```,```!LP@``)@```'#"```/````E\(``(X```"GP@``$```
M`#;#```(````1\,```T```!0PP``$@```%[#```.````<<,``!````"`PP``
M!P```)'#```,````F<,``!0```"FPP``$````+O#```"````S,,```8```#/
MPP``&0```-;#```2````\,,``!D````#Q```(0```!W$```#````/\0```0`
M``!#Q```$````$C$```(````6<0```H```!BQ```(P```&W$```(````D<0`
M`!@```":Q```#0```+/$```-````P<0```D```#/Q````@```-G$```-````
MW,0```<```#JQ```!@```/+$```(````^<0``!4````"Q0``'@```!C%```1
M````-\4```<```!)Q0``%0```%'%```5````9\4```D```!]Q0```@```(?%
M```$````BL4``#,```"/Q0``-P```,/%```T````^\4``!\````PQ@``#@``
M`%#&```#````7\8```0```!CQ@``!0```&C&```%````;L8``!@```!TQ@``
M!P```(W&```(````E<8``!P```">Q@```P```+O&```P````O\8```4```#P
MQ@``!````/;&```-````^\8```X````)QP``!0```!C'```T````'L<``#$`
M``!3QP``.0```(7'```<````O\<``"(```#<QP``/@```/_'```]````/L@`
M`"H```!\R```.@```*?(```P````XL@``#@````3R0``)0```$S)```0````
M<LD``!(```"#R0``"P```);)```J````HLD``"L```#-R0``)````/G)```H
M````'LH```D```!'R@``"P```%'*```*````7<H``"<```!HR@``)@```)#*
M```P````M\H```H```#HR@``'0```//*```L````$<L``!4````^RP``%```
M`%3+```*````:<L```T```!TRP``$````(++```2````D\L``#<```"FRP``
MD````-[+``!U````;\P``!D```#ES```#````/_,```-````#,T``!$````:
MS0``$@```"S-```3````/\T```8```!3S0``%````%K-```3````;\T``!``
M``"#S0``#````)3-```3````H<T``!@```"US0``)````,[-``"!````\\T`
M``H```!US@``%````(#.```$````E<X```L```":S@``%P```*;.```.````
MOLX```\```#-S@``$````-W.```5````[LX``"H````$SP``*````"_/```F
M````6,\``"0```!_SP``+0```*3/```K````TL\``!<```#^SP``0@```!;0
M```4````6=```!0```!NT```%@```(/0```4````FM```!(```"OT```&0``
M`,+0```7````W-```!(```#TT```$`````?1```]````&-$``!<```!6T0``
M%@```&[1```[````A=$``!$```#!T0``!P```-/1```M````V]$``"`````)
MT@``$````"K2```0````.](``!,```!,T@``&0```&#2```1````>M(``!0`
M``",T@``'P```*'2```C````P=(``!4```#ET@``$@```/O2```6````#M,`
M`!,````ETP``%````#G3```5````3M,```<```!DTP``%P```&S3```'````
MA-,```8```",TP``!@```)/3```$````FM,```0```"?TP``!@```*33```)
M````J],``!````"UTP``*@```,;3```2````\=,``!`````$U```$@```!74
M```-````*-0```L````VU```"@```$+4```\````3=0```0```"*U```"0``
M`(_4```%````F=0```T```"?U```#0```*W4```2````N]0``!0```#.U```
M&P```./4```7````_]0```,````7U0``"````!O5```K````)-4```<```!0
MU0``#````%C5```/````9=4```T```!UU0``"0```(/5```3````C=4``!4`
M``"AU0``#P```+?5```4````Q]4```P```#<U0``#@```.G5```(````^-4`
M``0````!U@``#P````;6```T````%M8```8```!+U@``#````%+6```=````
M7]8```X```!]U@``#0```(S6```-````FM8```L```"HU@``"@```+36```(
M````O]8```T```#(U@``"@```-;6```0````X=8``!H```#RU@``*P````W7
M```*````.=<``!4```!$UP``"0```%K7```*````9-<```P```!OUP``"```
M`'S7```(````A=<```<```".UP``$P```);7``!&````JM<```T```#QUP``
M"@```/_7```*````"M@```,````5V```%````!G8```6````+M@```(```!%
MV```!P```$C8```0````4-@```T```!AV```#P```&_8```/````?]@```@`
M``"/V```#P```)C8```=````J-@```H```#&V```!P```-'8```)````V=@`
M``D```#CV```"0```.W8```$````]]@``!````#\V```!0````W9```'````
M$]D```4````;V0``"@```"'9```#````+-D```T````PV0``!0```#[9```'
M````1-D```0```!,V0```@```%'9```&````5-D``!````!;V0``!````&S9
M```,````<=D``!$```!^V0``!P```)#9```=````F-D``"T```"VV0``%0``
M`.39```'````^MD``"@````"V@``*````"O:``!8````5-H``#$```"MV@``
M#P```-_:```,````[]H``!(```#\V@``'P````_;```)````+]L```L````Y
MVP``'@```$7;```P````9-L``#0```"5VP``%0```,K;```)````X-L``!``
M``#JVP``!0```/O;```)`````=P```H````+W````P```!;<```,````&MP`
M`!0````GW```#P```#S<```0````3-P``!D```!=W```$@```'?<```6````
MBMP``!,```"AW```(````+7<```)````UMP``!4```#@W```%0```/;<```%
M````#-T```8````2W0``!````!G=```$````'MT```<````CW0``"@```"O=
M```(````-MT``!L````_W0``#P```%O=```)````:]T``!<```!UW0``.```
M`(W=```O````QMT``#X```#VW0``-P```#7>```U````;=X``$X```"CW@``
M*````/+>```M````&]\``!T```!)WP``%@```&??```&````?M\```,```"%
MWP```P```(G?```?````C=\``"@```"MWP``#P```-;?```@````YM\```D`
M```'X```'````!'@```(````+N````H````WX```"@```$+@```+````3>``
M``8```!9X```#````&#@```.````;>````@```!\X```"````(7@```0````
MCN````T```"?X```#````*W@```,````NN````(```#'X```!0```,K@```"
M````T.```#P```#3X```-@```!#A```/````1^$```H```!7X0``8@```&+A
M```=````Q>$``!````#CX0``$````/3A```%````!>(```<````+X@``!```
M`!/B```$````&.(```4````=X@```0```,H"``#-````J````%L"``!/`0``
M`````!`#````````U@```)L```#.````3@,``$0"``!$`0``````````````
M```````````````Q`P``'P```%0```#=`0``-@```,P!``"U`@``A0$`````
M``"C`0```````,\!```A`P```````(0!````````ZP(`````````````\P(`
M`%$"```(`@```````#H#```G`0````````````""`@``#P(``(P!```6`@``
MM@```(T!``"2`@``/0$```````#V````]`(```````!&`0``:````&D"``#N
M````%P$``*0```"Z`````P```(@!``!.`0``V`$```0!``````````````X"
M``#H`@```````````````````````$4!``#W`````````+X!``!6````.P,`
M``````"!`@``%`,````````E`@```````&L"``!#`P```````)P!```-````
M`@(``%````#_````!P,``$`#```8`0```````-,````2````"0```%T"````
M`````````$D"``"9````4P```&8"``#W`0```````+<```!8`0``&@$``!8#
M``!S`0``````````````````Q`````L!```N`0``A@```*P```!4`0``WP``
M```````````````````````.`0``I@```!`"````````T0$`````````````
M``````@````Q`@``RP```&4```"L`0`````````````H`0``E0$``#,#``#D
M````)@,``/X`````````\@```!T!``!E`0````````````#E`@``L0(`````
M``"#````U`(``````````````````*X```!9````+P$````````E`P```0$`
M`*@"```3`0``9`$``+T```!^````,P````````"Q`````````),!``#U`@``
M$@,``.4```#L`@```P$``+`!```V`@``FP$``)T!````````#0,``,T"````
M````.@(````````3`P``0P(```````#_`0``BP```!L"```1`````````#4"
M```0`````````%8"``````````````````!+`0```````!L```````````(`
M`'`````:````#`$``(H!``#<````#`(``%4"``#3`0```````!<`````````
M`````.`!``!(`````@$``"P```!F`````````!$#``!2``````````L#``!!
M`P``_`$````````/`0``H`(``'P"``#'`0``/@```$(#````````.@$``*T!
M``!-`@``P@$````````A````UP```````````````````+(!```=````````
M`*P"``#^`@``,`$```````!<`@````````````!&`@```````,H!```M`0``
MD````$L"``##`0```````-`!```%`@``_`(``$4"``!@````;0`````````-
M`@```````!0!``#%`````````+0```!R`0``NP$``%H!``"4`0``$P```%$!
M`````````````#0```!*````*0(``"T#``#_`@``;P(``#H```!!`@``>`(`
M```````;`0``L@(`````````````"@,``/H"````````>````&H````Q`0``
M]`````````#G`@``3@```$D!``!5````'P$``(@```".````+@```$@!``!?
M````80(```````!"`````````*<`````````V@$``$$```#Q`0``J0$``)@`
M``"O````-0$``!\"``!P`0``AP$``(L!``"_`@````````````!2`0``````
M`%D!```<`@````````````#]````Q@````$"``!H`@````$``*<"``#P`0``
M>P``````````````^0(``%X````W`0```````&`!``#:```````````````]
M`@```````'H"````````E`(``!D#``"A`@``,P$``.H!``!5`0``D0$``$H"
M``!B````*0$```````"U`````````(8"``````````````````#[`0``0```
M``,"``"0`0````````````"C`````````*<!``"6`@``]@$``&0"```*````
M#0$``-D!``#G`0``XP(``)D!```X`0``@@$``*$```#.`@```````$D```!%
M``````````````!*`0``B0```-\!``"``````````!@`````````\````/@"
M```9`@```````'8"``"<``````````@!``"J`@`````````````"````````
M````````````[0$``+X`````````;P$``'4"``#$`@``<0(``)`"``!T`0``
M40,``(0``````````````)X!``"<`@``(P(``(H``````````````),```#8
M````8@(``#@#``#,````5P```.L!``"%`@``R`$``*T"``!8````_0$``!H#
M```<`P``+@(``'T!```\`0``Z0$```8#````````F@```.,!``!,`@``30,`
M``````"K`0`````````````````````````````M`@``X@````8"```@`0``
M``````````!T`@````````P```"F`@```````+@```##`@``L````(,!````
M````2@,``,\```#&`0``1````!@#``#7`@``ZP````````"Y````;````',`
M``#X````BP(``*H```!L`@``Q`$``)D"``"Y`0``D@``````````````9P``
M`(X"```)`@``;`$``#@"````````Z@(```$#```R`0```@,``$4#```'`@``
M`````!X#````````O@(``$<!``#5`0``-P,``"@```!;````````````````
M````4P(``,$```"5````/`(``/X!``"E`0``K@(```````#W`@``D0```-4"
M```D`0```````(`!``#I`````````%<"```E````70$``/P```"N`0``````
M``0"```\````M@(``"````!/`P``OP$``!D````B`@``<`(``(D"````````
M(`(``%T`````````.0$``,L"``"@`0``&@(`````````````*@````````!9
M`@``V0(``.8```!G`0```````+P!```[`0``N`(``"P"``"K````?`$``'@!
M`````````````+T!````````Y0$``,P"``!``0``%0```)T"````````8@$`
M`,D!`````````````)\!```D`P``J@$```````#U`0``T`(``-L```#Z````
M`````!`!````````B0$``*(!``#3`@``CP$``*\"`````````````(\`````
M````8P$```````!A````H````#\!```_`P``[P$````````C`P``'@(`````
M````````L`(``$X"```3`@``?`````````!6`0``MP(```````!;`0``&P,`
M``H"``",````L0$````````K`0```````(X!``!"`0``"0,````````\`P``
M+P(``"H#```%````%0,``*0!``"5`@``$0$``+P"``"!`0``NP````````#;
M`@``&`(```````"$`@``0@(``$<"``!H`0``1@,`````````````5`(``/,`
M``!W`@``!`,``,$!``!-````````````````````W@(``(T```!<````[0``
M`"L`````````X@$``"8"``#L````\`(```````"*`@``E@$``"D```"!````
M`````-0``````````````)X``````P``3````(`"````````#P```*\!``!^
M`0``,````,H````2`@``*P,``'("``"1`@``]@(````````5`@``XP``````
M``!E`@``W`$``#L"``#/`@```````*$!```U`P``AP```/L"````````=@$`
M`",!````````=P```'(``````````````"@"``!K`0``T0(``!X!````````
M"`,``'D`````````+P````````"U`0``F`(``+@!``"B`@``(0(``"H!``#]
M`@```````%$```"H`0``W@$```````"(`@``'0(```````"%````^P```#T`
M````````Z@````````#6`0`````````````%`P``Z0(``(<"``!-`0``+@,`
M`&X"``!_````'````-<!``"7`0``[P(``,`"``#.`0``0`(`````````````
M`````-H"```A`0``^0````````"7````-P(``"<"``!7`0``J0(``-8"```D
M`@``O0(``,@```!M`@``.0,``"L"``!J`@```````#(```"S`0``7`$``,("
M``!?`0``$0(``)X"```]`P``M@$``.<```!@`@``:0``````````````F@$`
M`.@``````````````/D!``"I````HP(````````.`P``\0(```````#-`0``
M[P``````````````2`,``.$"```G`P``+`,```````!_`@``M`(```````"?
M`@``:@$`````````````6@(``$,!``!8`@``7@$``.`"````````;@``````
M```6`0```````.X"``#``0``WP(``"8```#>````,`(``((`````````VP$`
M``````#0````"0$`````````````FP(```L````P`P``!P```,8"```2`0``
M+P,``"0`````````CP(``.X!```^`@``Y`(````````+`@``R`(``*4````7
M`P``1@```#(#``"E`@`````````````Q````<0```#D"```B````?0```-D`
M``!Y`@```````!4!``!!`0````````````#)``````````````!,`P``\@$`
M`.P!```B`P``'P,``#0"```&`0``%P(``+<!``"T`0`````````````#`P``
MX`````````##````K0```,(``````````````"@#````````NP(``&,````$
M````T@$``.0!```T`P``7P(````````@`P``T0```````````````````#\"
M````````'`$``"4!``"D`@``/@,``/0!```^`0``@P(``*L"```,`P``=@``
M`%X"```F`0``OP```.8!``!Z````-@,``&\```"6````Y@(``&,"``!'````
MW0(```````!Y`0``\@(``.("``!_`0``:P```+D"````````-`$``-("````
M````#@```,<`````````!P$``,<"````````````````````````;0$``+H!
M``"3`@``;@$``$D#``#4`0``1P,``#<``````````````#("``"=````'@``
M`(P"``!U`0``/P```#8!```/`P``^@$``+(````9`0``'0,```````"4````
MQ0(``'H!```&````(@$``-(```#%`0```````/,!```U````=0`````````4
M````X0```#D`````````[0(``"D#```S`@``9P(```````!^`@``P0(``&D!
M````````%`(``.$!```M````6@```%`"``!/```````````````%`0``.P``
M`$L`````````3P(```````!Q`0``R0(``"<```"Z`@````````````"\````
M.````$P!````````>P$``&0`````````9@$```````#=````(P```*(```!(
M`@``4`$``$L#```J`@``=P$``,````"&`0``V`(``!8`````````80$``*8!
M````````=````)@!``````````````H!``"-`@```````'T"``!$`P``\0``
M````````````>P(``"P!``#5````LP```%`#``"2`0``````````````````
M````````````````]0```%,!``!#````EP(``/@!``"S`@``4@(```````":
M`@````````````#<`@``<P(``.@!````````RP$``)\`````("8C,34Q.R`E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E
M9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F
M;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!H87,@
M8V%N8V5L;&5D("5S+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R
M97%U97-T+@`E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E
M<RX`)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@
M:7,@;F]T('=R:71A8FQE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S
M(&YO="!F;W5N9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('1O
M("5S(&]F("5S`"5S('=I<VAE<R!T;R!A9&0@=&\@)7,N`"5S('=I<VAE<R!T
M;R!M86ME('EO=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I=F4@
M=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`)R5S)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"<E<R<@:7,@
M;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`G)7,G('=A
M<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`)R5S)R!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`)R5S)R!W87,@;F]T(&-R96%T
M960Z("5S+@`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM
M`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F
M871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`06)O
M=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!
M8V-E<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I
M;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I
M;F<`06-T:6]N<P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M
M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES
M<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`G)7,G`$%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@)R5S)P!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!
M9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T
M;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S
M97(`061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("<E
M<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@
M;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S
M`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D
M(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I
M9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@
M24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@
M24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA
M=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`07!P;&EC
M871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`
M07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ
M90!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A
M;GD@<W5B+6=R;W5P<S\`07)T`$%S8VEI($%R=`!!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S
M:6=N;65N="!C;VQU;6YS`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE
M(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@<V5N=`!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!S:&%R92X`071T96YD965S`$%T=')I8G5T97,`075S=')I80!!
M=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF
M='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@
M56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D
M`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E
M<W!O;G-E`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L
M;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA
M;64N`$)A<F4`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U
M;F0N`$)A<V5L:6YE`$)E;&=I=6T`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A
M<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO
M8VL@5'EP90!";VQD`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S
M<SH`0F]R9&5R<P!";W1H`$)O='1O;0!"=6QL971E9"!,:7-T`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#
M86QE;F1A<@!#86QM`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!T
M:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#96QL(%!H;VYE`$-E;&P@4')O
M<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P
M86-I;F<Z`$-E;&QP:&]N90!#96YT97(`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!0;VQI8VEE<P!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R`$-H96-?
M:R!,:6YK+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H
M;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R
M(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC
M:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O
M=P!#;&]U9',`0VQO=61Y`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L
M=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UA
M;F0@;W!T:6]N<SH`0V]M;6%N9',Z`$-O;6UE;G0`0V]M;6ET=&EN9SH`0V]M
M;6]N($YA;64`0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!-97-S86=E("@E
M<RD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<P!#;VYF:6=U<F%T:6]N(&YE961S('5P9&%T:6YG+@!#;VYF:6=U<F4@
M)7,`0V]N9FER;2!087-S=V]R9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C
M=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`G)7,G`$-O
M;G1I;G5E`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'EI;F<@)7,@
M=&\@)7,`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO
M="!C;W!Y("5S('1O("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!C<F5A=&4@;&]C86QE(&1I<F5C=&]R>2!F
M;W(@;&]C86QE("5S.@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G
M)7,G+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@
M8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`G)7,G
M+@!#;W5L9"!N;W0@;6MD:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L
M:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N
M`$-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N
M(&1I<F5C=&]R>2`G)7,G+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T
M(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3
M;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U
M;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG
M=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("<E<R<N`$-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@)R5S)RX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("<E<R<N`$-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R("<E<R<Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I
M=F4@=7-E<B`G)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R("<E<R<Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E
M871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W5R<F5N="!0:&%S90!#=7)R96YT(%1I;64`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<')U<P!$1`!$86EL>0!$871A`$1A=&%4<F5E($)R;W=S97(`1&%T
M90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O
M;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A
M<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT
M:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M:7-S:6]N<P!$
M969I;FET:6]N<P!$96QE9V%T92!P;W-I=&EO;@!$96QE9V%T960`1&5L971E
M`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R("<E<R<`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T
M:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="`G)7,G+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5N>2!R97%U97-T`$1E
M;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y
M`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$
M;W=N;&]A9`!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5D
M:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET
M(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T
M:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("<E<R<`161U8V%T:6]N`$5L96UE;G0N+BX`16T`16UA:6P`
M16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA
M:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N
M`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9`!%;F0@>65A
M<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5R<F]R`$5R<F]R('-E
M;F1I;F<@<F5P;'DZ("5S+@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R
M<F]R('=R:71I;F<@)R5S)RX`17)R;W(Z(`!%=7)O<&4`179E<GD@,34@;6EN
M=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U
M(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI
M;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>&5C=71I;F<Z`$5X<&%N
M9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W
M;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP
M;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A
M:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S
M(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL
M960@=&\@;6]V92!T;R`B)7,B+@!&86ER`$9A=&%L($5R<F]R.@!&87@`1F5B
M<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W
M(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEL92!#;W5N=#H@)7,@9FEL
M90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE
M`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@
M<W5P<&]R=&5D+@!&:6QT97)S`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&
M:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M
M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O
M<G5M<P!&;W)W87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I
M<F5C=&]R:65S.@!&<@!&<F%M97,`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R
M964O0G5S>2!297!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q
M=65S="!297-P;VYS90!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N
M`$9U;&P@36]O;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VT`1V%L;&5R>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T
M960@0V]D90!'971O<'0@17)R;W(Z(`!':79E;B!.86UE`$=O`$=O;V=L92!3
M96%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E;FQA;F0`1W)O=7`@061M:6YI
M<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7`@
M<&5R;6ES<VEO;G,`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T('!E
M<FUI<W-I;VYS`$=U97-T8F]O:P!(2`!(5$U,`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO
M;B!N;W0@9F]U;F0N`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE:6=H
M=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(:7-T;W)Y
M(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$AO7VUE`$AO;64`2&]M
M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L
M:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D
M92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S
M("(E<R(`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES960@
M)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA
M<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO
M<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI
M9&ET>3H@`$AU;6]R:7-T<P!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0
M($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)
M7VYS97)T(%)O=R!"969O<F4`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O
M;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I
M<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN
M9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE
M="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G
M92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A
M;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S
M`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@
M9FEE;&1S.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`
M26YD:79I9'5A;"!5<V5R<P!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L
M=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E
M8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E
M;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W
M('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O
M<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!)
M;G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@
M<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@
M8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D
M:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D
M:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E
M<@!);G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N
M`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P
M;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M
M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F
M:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV
M86QI9"!R96-I<&EE;G0Z("<E<R<`26YV86QI9"!S:&%R92!O8FIE8W0`26YV
M86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN
M=F5N=&]R>0!)<V]L871E9"!4+5-T;W)M<P!)<W-U97(`271A;&EC`$IA;G5A
M<GD`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2V5E<"!O<FEG
M:6YA;#\`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT
M`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!,85]Y;W5T`$QA
M;F=U86=E`$QA<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QI9VAT($1R:7IZ;&4`
M3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,
M:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H
M="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P
M;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,
M:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T
M+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C
M<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$QI=&5R871U<F4`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN
M+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I
M;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO
M=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T
M;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R
M965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!-30!-86EL`$UA=&-H
M:6YG(&9I96QD<P!-965T:6YG($-A;F-E;&QA=&EO;@!-965T:6YG($EN9F]R
M;6%T:6]N`$UE971I;F<@4')O<&]S86P`365E=&EN9R!297!L>0!-965T:6YG
M(%5P9&%T90!-965T:6YG(%5P9&%T92!297%U97-T`$UE;G4@;6]D93H`365S
M<V%G90!-;VYT:&QY`$UO=F4@9&]W;@!-;W9E('5P`$YA;64`3F5E9',@06-T
M:6]N`$YE=F5R`$YE=W,`3F5X=`!.97AT(%!A9V4`3F\`3F]N(%!A<G1I8VEP
M86YT`$YO;F4`3F]T97,`3F]T:6-E`$]+`$]F9FEC90!/<'1I;VYA;"!087)T
M:6-I<&%N=`!/<'1I;VYS`$]R9V%N:7II;F<`3W1H97(@26YF;W)M871I;VX`
M4&%S<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R<V]N86P@
M26YF;W)M871I;VX`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M
M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N
M=2!B96QO=RX`4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N
M=2!B96QO=RX`4')E=FEE=P!0<F5V:6]U<R!086=E`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M
M;W9E('!A:7(`4F5P;'D@4V5N="X`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D
M($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT
M:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BX`4F5Q=6ER960@4&%R=&EC:7!A;G0`4F5S970`4F5T=7)N('1O($]P=&EO
M;G,`4F]L90!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5L96-T(&$@9&%T
M90!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.@!396YD($QA=&5S="!);F9O<FUA=&EO;@!396YD(%!R;V)L96T@4F5P;W)T
M`%-I9VX@=7`@:68@;F]T(')E9VES=&5R960`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-T87)T`%-T871U<P!3=6)J
M96-T`%-U8FUI=`!3=6-C97-S`%-U;6UA<GD`5&%S:W,`5&5N=&%T:79E;'D@
M06-C97!T(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5X="!/;FQY
M`%1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE('1A<VL@:&%S(&)E
M96X@861D960@=&\@>6]U<B!T87-K;&ES="X`5&AE('5S97(G<R!F<F5E+V)U
M<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N.B`E<RX`5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI
M<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"X`5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BX`5&ET;&4`5&\`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M`%5N9&\@0VAA;F=E<P!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S
M`%5N;F%M960`57!D871E(')E<W!O;F1E;G0@<W1A='5S`%5P;&]A9`!5<V5R
M($]P=&EO;G,`57-E<FYA;64`57-E<FYA;64Z`%9I97<@)7,`5FEE=R!E=F5N
M=`!6:65W('1A<VL`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC
M;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($YA;64`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R!P
M<FEN="X`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE
M;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!?2&5L<`!?3&]G(&]U=`!?3W!T
M:6]N<P!N86UE`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP
M+C0*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,#4M,3@@,3(Z-#,K,#(P,`I03RU2
M979I<VEO;BU$871E.B`R,#`U+3`U+3$X(#$T.C,W*S`R,#`*3&%S="U4<F%N
M<VQA=&]R.B!'96ER($\N($AO9V)E<F<@/&AO<F1E0'-K>61I=F5R+FYO/@I,
M86YG=6%G92U496%M.B!.;W)W96=I86X@*$)O:VUA;"D@/&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET"@`@)B,Q-3$[("5S(&5R(&ML87(@9F]R(.4@=71F
M^')E('9E9&QI:V5H;VQD<V]P97)A<VIO;F5N92!S;VT@97(@=F%L9W0@;F5D
M96YF;W(N`"`H)7,@9&%G97(@<VED96XI`"`H:'5R=&EG=&%S="`E<RD`("AI
M;FYE;B`E<R!D86=E<BD`("AI(&1A9RD`("AI(&UO<F=E;BD`("AI(&?E<BD`
M(&1E;B``)60@)7,@;V<@)7,`)60@8GET97,@<VMR979E="X`)60@878@)60@
M;W!P9OAR:6YG97(@;6%R:V5T('-O;2!O<'!D871E<G0`)60M9&%G97)S('9A
M<G-E;``E<R`M(%1I;"!I;F9O`"5S(&%D;6EN:7-T<F%S:F]N`"5S($9I;F=E
M<G!R:6YT`"5S($M"`"5S('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R("T@0F5K
M<F5F=&5L<V4`)7,@:6YS=&EL;&EN9V5R`"5S(')E9VES=')E<FEN9P`E<R!A
M=G1A;&5V:6QKY7(`)7,@9FEN;F5S(&%L;&5R961E+@`E<R!PY2`E<R`E<P`E
M<R!H87(@:V%N<V5L;&5R="`E<RX`)7,@:&%R(&)E<W9A<G0@96X@9F]R97-P
M^')S96P@;VT@:6YF;W)M87-J;VX@86YGY65N9&4@;&5D:6<O;W!P=&%T="X`
M)7,@:&%R('-V87)T('#E(&EN=FET87-J;VYE;B!T:6P@)7,N`"5S(&AA<B!S
M96YD="!D96<@:6YF;W)M87-J;VX@;VT@;&5D:6<O;W!P=&%T="X`)7,@97(@
M<VMR:79E8F5S:WET=&5T+@`E<R!E<B!PY6MR979D`"5S(&UI;G5T=&5R`"5S
M(&EK:V4@9G5N;F5T+@`E<R!F;W)E<W#X<B!I;F9O<FUA<VIO;B!O;2!NY7(@
M9'4@97(@;&5D:6<O;W!T=&%T="X`)7,@9F]R97-P^'(@9&EN(&1E;'1A9V5L
M<V4@<.4@)7,N`"5S("T@)7,@878@)7,`)7,@^&YS:V5R(.4@;&5G9V4@=&EL
M("5S+@`E<R#X;G-K97(@Y2!G:OAR92!D96<@;W!P;65R:W-O;2!PY2`E<RX`
M)7,@^&YS:V5R(.4@;6]T=&$@9&5N('-I<W0@;W!P9&%T97)T92!I;F9O<FUA
M<VIO;F5N(&]M("5S+@!!9&1R97-S96)O:R!F;W(@)7,`2V%L96YD97(@9F]R
M("5S`$YO=&%T8FQO:VL@9F]R("5S`$]P<&=A=F5L:7-T92!F;W(@)7,`)7,Z
M("5S`"<E<R<@97(@:6MK92!E="!G>6QD:6<@=F%L9RX`)R5S)R!E<B!I:VME
M(&-O;F9I9W5R97)T(&D@2&]R9&4@4F5G:7-T97)E="X`)7,@8FQE(&QA9W0@
M=&EL(&=R=7!P97-Y<W1E;65T+@`G)7,G(&)L92!L86=T('1I;"!R971T:6=H
M971S<WES=&5M970N`"5S(&)L92!I:VME(&]P<')E='1E=#H@)7,N`"P@=F%R
M:6%B96P@;65L;&]M("5S(&]G("5S`"TM('9E;&<@+2T`,3(@5&EM97)S(&9O
M<FUA=``R-"!4:6UE<G,@9F]R;6%T`#(T('1I;65R`$5N(&1A=&%B87-E:V]B
M;&EN9R!E<B!PY6MR979D(&9O<B!D96YN92!B;&]K:V5N+@!%;B!F871A;"!F
M96EL(&AA<B!O<'!S=.5T=`!%;B!O9F9E;G1L:6<@4$=0+6[X:VME;"!E<B!P
MY6MR979D(&9O<B#E(&MR>7!T97)E(&UE;&1I;F=E;BX`16X@;V9F96YT;&EG
M(%!'4"UN^&MK96P@97(@<.5K<F5V9"!F;W(@Y2!V97)I9FES97)E('-I9VYE
M<G0@;65L9&EN9RX`16X@;V9F96YT;&EG(%!'4"UN^&MK96PL('!R:79A="!0
M1U`M;OAK:V5L(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"!F;W(@Y2!D96MR
M>7!T97)E(&5N(&UE;&1I;F<N`$5N(&]F9F5N=&QI9R!01U`M;OAK:V5L+"!P
M<FEV870@4$=0+6[X:VME;"!O9R!P87-S<&AR87-E(&5R('#E:W)E=F0@9F]R
M(.4@<VEG;F5R92!E;B!M96QD:6YG+@!%;B!O9F9E;G1L:6<@4R]-24U%+6[X
M:VME;"P@<')I=F%T(%,O34E-12UN^&MK96PL(&]G('!A<W-P:')A<V4@97(@
M<.5K<F5V9"!F;W(@Y2!D96MR>7!T97)E(&5N(&UE;&1I;F<N`$5N(&]F9F5N
M=&QI9R!3+TU)344M;OAK:V5L+"!P<FEV870@4R]-24U%+6[X:VME;"P@;V<@
M<&%S<W!H<F%S92!E<B!PY6MR979D(&9O<B#E('-I9VYE<F4@96X@;65L9&EN
M9RX`16X@;V9F96YT;&EG(%,O34E-12UN^&MK96P@97(@<.5K<F5V9"!F;W(@
MY2!K<GEP=&5R92!E;B!M96QD:6YG+@!!32]030!/;2!D96YN92!E9&ET;W)E
M;@!/;2XN+@!!8G-O;'5T="!N961E<G-T`$%B<V]L=71T(&UI9'0`1V]D:VIE
M;FX@9F]R97-P^')S96P`1V]D=&%T=`!4:6QG86YG(&YE:W1E="!V960@;W!P
M<F5T=&5L<V4@878@5D93(&MA=&%L;V<N`%1I;&=A;F<@;F5K=&5T('9E9"!O
M<'!R971T96QS92!A=B!61E,@9FEL+@!+;VYT;R!087-S;W)D`$MO;G1O(&9R
M^'-E="X`0F]K:&]L9&EN9R]!8V-O=6YT:6YG`$AA;F1L:6YG97(`3&5G9R!T
M:6P`3&5G9R!T:6P@=6YD97)G<G5P<&4`3&5G9R!T:6P@=6YD97)R971T:6=H
M971E<@!,96=G('1I;"!H97(Z`$QE9V<@=&EL(&YY(&=R=7!P90!,96=G('1I
M;"!N>2!R971T:6=H970`3&5G9R!T:6P@96X@=6YD97)G<G5P<&4@=&EL("<E
M<R<`3&5G9R!T:6P@=6YD97)R971T:6=H970@=&EL("<E<R<`3&5G9R!T:6P@
M;GD@8G)U:V5R.@!,96=G('1I;"!K;VQO;FYE`$QE9V<@=&EL(&YY92!M961L
M96UM97(`3&5G9R!T:6P@<&%R`$QE9V<@=&EL("5S(&UE;GEE;B!S;VT@36]Z
M:6QL82!3:61E8F%R`$QE9V<@=&EL(&D@;6EN(&MA;&5N9&5R`$QE9V<@=&EL
M(&D@861D<F5S<V5B;VLZ`$QE9V<@=&EL(&D@;6EN(&%D9')E<W-E8F]K`$QE
M9V<@=&EL(&)R=6ME<@!,82!T:6P@)R5S)R!I('-Y<W1E;65T+"!M96X@:W5N
M;F4@:6MK92!L96=G92!T:6P@96MS=')A(')E9VES=')E<FEN9W-I;F9O.B`E
M<RX`3&$@)R5S)R!T:6P@<WES=&5M970N($1U(&MA;B!L;V=G92!I;FX@;N4N
M`$QA('1I;"!N>64@9FEL97(@:2!R97!O<VET;W)Y.@!-=6QI9VAE="!F;W(@
MY2!L96=G92!T:6P@;GEE(&)R=6ME<F4@97(@9&5A:W1I=F5R="X`061R97-S
M90!!9')E<W-E($)O:P!!9&UI;FES=')E<B`M('-E='0@<F5T=&EG:&5T97(@
M9F]R(&%N9')E(&)R=6ME<F4`061M:6YI<W1R87-J;VX`4F5K;&%M97(`06QI
M87,`2G5S=&5R90!*=7-T97)I;F<Z`$%L;&4`06QL92!A=71E;G1I<V5R=&4@
M8G)U:V5R90!!;&QE($=R=7!P97(`06QL92!R961D:6=H971E<@!!;&QE(&9I
M<F4@<VED97(`5&EL;&%T="!F;&5R92!A9')E<W-E<@!4:6QL871T(&5N9')I
M;F<@878@9F]R;6%T970@<.4@;G5M;65R97)T92!L:7-T97(_`$5K<VES=&5R
M97(@86QL97)E9&4`06QT97)N871I=B!)35-0($QO9VEN`$%L=&5R;F%T:79T
M($E-4U`@<&%S<V]R9`!!;'1E<FYA=&EV="!)35-0(&)R=6ME<FYA=FX`06QT
M97)N871I=B!E+7!O<W0@861R97-S90!!;'1E<FYA=&EV92!M86QE<@!!;'1E
M<FYA=&EV('1E:W-T.@!%;B!U;&]V;&EG('9E<F1I('9A<B!O<'!G:71T+@!!
M;F]N>6T@4')O>'D`4W9A<@!0<F]G<F%M`%!R;V=R86UL:7-T90!0<F]G<F%M
M;65T(&5R(&ML87)T+@!/<'!D871E<B!O9W/E(')E:W5R<VEV="!N961O=F5R
M(&9O<B!U;F1E<FUA<'!E<B]F:6QE<@!';V1K:F5N;@!/;71R96YT;&EG('-T
M^')R96QS90!&:6QS=/AR<F5L<V4@<.4@87)K:79E=`!!<FMI=FYA=FX`17(@
M9'4@4TE+2T52('#E(&%T(&1U('9I;"!F:F5R;F4@<F5G:7-T<F5R:6YG<V9O
M<F5S</AR<V5L96X@9F]R("5S/P!%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL
M('-L971T92`G)7,G(&]G(&1E;G,@=6YD97)G<G5P<&5R/P!+=6YS=`!!<V-I
M:2!K=6YS=`!"92!O;2!B96MR969T96QS92!F^'(@9VIE;FYO;6;X<FEN9R!A
M=B!V961L:6ME:&]L9'-O<&5R87-J;VYE<@!+;VQO;FYE86YV:7-N:6YG`%9E
M9&QA9W0@:2!S=F%R970@97(@96X@:4-A;&5N9&%R(&9I;"!F;W(@96X@9F]R
M97-P^')S96P@9'4@<V5N9'1E`$9O<G/X:W1E(.4@<VQE='1E(&5N(&=R=7!P
M92!S;VT@:6MK92!E:W-I<W1E<F5R+@!&;W)S^&MT92#E('-L971T92!E;B!R
M971T:6=H970@<V]M(&EK:V4@96MS:7-T97)E<BX`1F]R<_AK=&4@Y2!R961I
M9V5R92!E;B!R971T:6=H970@<V]M(&EK:V4@96MS:7-T97)E<BX`1F]R<_AK
M=&4@Y2!R961I9V5R92!E;B!D96QT(')E<W-U<G,@<V]M(&EK:V4@96MS:7-T
M97)E<BX`1&5L=&%G97)E`$%T=')I8G5T`-AS=&5R<FEK90!!=71H7V-Y<G-Q
M;#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I9&5L
M<V5N+@!!=71H7V-Y<G5S.B!"86-K96YD(&EN;F5H87(@:6MK92!N^&1V96YD
M:6<@9G5N:W-J;VYA;&ET970N`$%U=&A?8WER=7,Z($MA;B!I:VME(&9I;FYE
M(&1E;B!N^&1V96YD:6=E($E-05`@=71V:61E;'-E;BX`075T:%]F='`Z($MA
M;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E($944"!U='9I9&5L<V5N+B!+
M;VUP:6QE<B!02%`@;65D("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!+86X@
M:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!)34%0('5T=FED96QS96XN`$%U
M=&A?:W)B-3H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@:W)B-2!U
M='9I9&5L<V5N+@!!=71H7VQD87`Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V
M96YD:6=E($Q$05`@=71V:61E;'-E;BX`075T:%]L9&%P.B!+=6YN92!I:VME
M(&QE9V=E('1I;"!B<G5K97(@)7,N(%-E<G9E<F5N('-A.B``075T:%]L9&%P
M.B!+=6YN92!I:VME(&9J97)N92!B<G5K97)E;B`E<P!!=71H7VQD87`Z($MU
M;FYE(&EK:V4@;W!P9&%T97)E(&)R=6ME<B`E<P!!=71H7VUC86PZ($MA;B!I
M:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E($U#04P@=71V:61E;'-E;BX`075T
M:%]S;6)A=71H.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!S;6)A
M=71H('5T=FED96QS96XN`$%U=&5N=&ES97)I;F<@9F5I;&5T`$%U=&5N=&ES
M97)I;F<@9F5I;&5T+B`E<P!!=71E;G1I<V5R:6YG(&YE:W1E="!A=B!2041)
M55,@=&IE;F5R+@!!=71E;G1I<V5R:6YG(&UO="!&5%`@=&IE;F5R96X@9F5I
M;&5T+@!4:6QG:F5N9V5L:6=E(&9E;'0Z`%9E;G1E<B!PY2!S=F%R`$)/1D@@
M17AC=7-E<P!"86MG<G5N;@!"86MG<G5N;G-F87)G90!&96EL(&ME<F)E<F]S
M('!A<W-O<F0N`$9E:6P@:V5R8F5R;W,@8G)U:V5R;F%V;BX`0FQA;FL`0F%S
M96MA=&%L;V<@9F]R(&=R869I:VL@)R5S)R!B;&4@:6MK92!F=6YN970N`$=R
M=6YN;&EN:F4`0F5L:6=A`$)U<G-D86<`0FQO:VL@(B5S(B!A=B!P<F]G<F%M
M;65T("(E<R(@8FQE(&EK:V4@9G5N;F5T+@!";&]K:R!I;FYS=&EL;&EN9V5R
M`$)L;VMK('1Y<&4`1F5T`$)O:VUE<FME<@!286UM90!286UM971Y:VME;'-E
M.@!286UM97(`0F5G9V4`0G5N;@!0=6YK=&QI<W1E`$--4P!#4D,`0U),($1I
M<W1R:6)U<VIO;G-P=6YK=&5R`$5G96YS:V%P97(@9F]R(&-?96QL92XN+@!+
M86QE;F1E<@!3=&EL;&4`2V%N(&EK:V4@;G5L;'-T:6QL92!P87-S;W)D(&%U
M=&]M871I<VLL(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(N`$MA;B!I:VME
M(&MO8FQE('1I;"!)34%0('1J96YE<F5N.B`E<P!+86YA9&$`079B<GET`$%V
M8G)Y="!P<F]B;&5M<F%P<&]R=`!+86X@:6MK92!S;&5T=&4@9FEL96X@(B5S
M(BX`2V%N(&EK:V4@9FEN;F4@96X@=&5M<"UK871A;&]G+@!+86X@:6MK92!F
M;W)T<V5T=&4@=71E;B`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!+86X@:6MK
M92!S;&5T=&4@:V%T86QO9V5N("(E<R(N`$MA;B!I:VME('-L971T92P@)60@
M8F%R;B!E:W-I<W1E<F5R+@!+86X@:6MK92!E;F1R92!R96MK96;X;&=E;BP@
M86YT86QL970@;W!P9OAR:6YG97(@=F%L9W0@9F]R(&]M<V]R=&5R:6YG('-T
M96UM97(@:6MK92!M960@86YT86QL970@;&%G<F5D92!O<'!F^')I;F=E<BX`
M2V%N(&EK:V4@<V5N9&4@;65L9&EN9V5N('1I;"!D970@<W!E<VEF:7-E<G1E
M(&YU;6UE<F5T+@!5=&1R86<`2V%T96=O<FEE<B!O9R!E=&EK971T97(`36]B
M:6QT96QE9F]N`$5G96YS:V%P97(@9F]R(&-E;&QE`$QU9G0@<G5N9'0@:6YN
M:&]L9"!A=B!C96QL93H`16=E;G-K87!E<B!F;W(@8V5L;&4`3'5F="!R=6YD
M="!C96QL96XZ`$UO8FEL=&5L969O;@!396YT97(`1&5T86QJ97(@9F]R('-E
M<G1I9FEK870`4F5T=&YI;F=S;&EN:F5R(&9O<B!S97)T:69I:V%T`$]R9'-T
M>7)E<@!%;F1R90!%;F1R92!N879N(&]G(&%D<F5S<V4@<V]M(&UO='1A:V5R
M92!S97(@;N5R(&1E(&QE<V5R(&]G('-V87)E<B!PY2!P;W-T96X@9&EN+@!4
M96=N`%-J96M?:R!L:6YK+BXN`%9E;&<@9&4@;W!E<F%S:F]N96YE(&1U('9I
M;"!U=&;X<F4@;N4N`%9E;&<@971T('!A<W-O<F0`5F5L9R!E='0@8G)U:V5R
M;F%V;@!696QG(&AA;F1L:6YG.@!696QG(&AV;W)D86X@9'4@=FEL('9I<V4@
M9&%T;V5R.@!696QG('-T:6P@<.4@;&ES=&5T>7!E("AF;W(@;G5M;65R97)T
M92!L:7-T97(I`$ML87-S961E9FEN:7-J;VX@9F]R("5S(&)L92!I:VME(&9U
M;FYE="X`2VQA<G0`1FIE<FX@35-/9F9I8V4@=&%G<P!&:F5R;B!B<G5K97(Z
M("5S`$9J97)N(&)R=6ME<@!&:F5R;B!B<G5K97)D871A`$ML:6MK(&9O<B#E
M(&9O<G1S971T90!#;&EC:V%T96QL('9I82!(5%10`$QU:VL@=FEN9'4`4VMY
M97(`4VMY970`4VSE('-A;6UE;B!S:61E;&EN:F5N`%-A;6UE;G-LY71T(')A
M;6UE`$9A<F=E`$9A<F=E=F5L9V5R`$9A<F=E=F%L9P!+;VQO;FYE+71I=&QE
M<@!496=N97-E<FEE<@!+;VUM86YD;P!+;VUM86YD;W9I;F1U`%9A;&<@9F]R
M(&MO;6UA;F1O.@!+;VUM86YD;V5R.@!+;VUM96YT87(`4VIE:VL@:6YN.@!6
M86YL:6<@;F%V;@!&:7)M80!&97)D:6<`4VMR:78@;65L9&EN9R`H)7,I`$1A
M=&%M87-K:6YE<@!6:6QKY7(`1F]R<VMJ96QL97(@:2!I;FYS=&EL;&EN9V5N
M90!);FYS=&EL;&EN9V5R(&)E:/AV97(@;W!P9&%T97)I;F<N`$MO;F9I9W5R
M97(@)7,`0F5K<F5F="!P87-S;W)D`%1I;&MO8FQI;F<@;6ES;'EK=&5S+@!4
M:6QK;V)L:6YG(&UI<VQY:W1E<SH@`$MO8FQI;F=E;B!T:6P@9&5N(&]F9F5N
M=&QI9V4@;OAK:V5L=&IE;F5R96X@9F5I;&5T+@!+;V)L:6YG96X@=&EL(&1E
M;B!O9F9E;G1L:6=E(&[X:VME;'1J96YE<F5N(&9E:6QE="X@Q7)S86LZ("5S
M("@E<RD`2V]B;&EN9V5N('1I;"!&5%`@=&IE;F5R96X@;6ES;'EK=&5S+@!+
M;VYT86MT96YE(&)L92!L86=T('1I;"!A9')E<W-E8F]K96X`26YN:&]L9"!I
M("<E<R<`1F]R='-E='0`0V]O:VEE`$MO<&EE<@!+;W!I97(@=F%L9W0@;VUR
MY61E`$MO<&EE<F5R("5S('1I;"`E<P!+=6YN92!I:VME(%!'4"UK<GEP=&5R
M92!M96QD:6YG`$MU;FYE(&EK:V4@4$=0+7-I9VYE<F4@;65L9&EN9P!+=6YN
M92!I:VME(&MR>7!T97)E(&UE;&1I;F=E;B!M960@4R]-24U%+@!+=6YN92!I
M:VME('-I9VYE<F4@;65L9&EN9V5N(&UE9"!3+TU)344N`$MU;FYE(&EK:V4@
M;&5G9V4@=&EL(&MO;G1A:W0Z("5S`%1I;&MO8FQI;F<@=&EL($Q$05`M<V5R
M=F5R(&9E:6QE="X`2W5N;F4@:6MK92!S:F5K:V4@=&EL9VIE;F=E;&EG(&MR
M961I='0N("5S`$ML87)T92!I:VME(.4@:V]B;&4@=&EL('1J96YE<F5N("<E
M<R<@=F5D(&)R=6L@878@1E10.B`E<P!+=6YN92!I:VME(&MO<&EE<F4@)7,@
M=&EL("5S`$MU;FYE(&EK:V4@;&%G92!D:7-T<FEB=7-J;VYS;&ES=&4N("5S
M`$MU;FYE(&EK:V4@;W!P<F5T=&4@;&]C86QE(&MA=&%L;V<@9F]R(&QO8V%L
M92`E<SH`2W5N;F4@:6MK92!D96MR>7!T97)E(%!'4"!M96QD:6YG+@!+=6YN
M92!I:VME(&1E:W)Y<'1E<F4@4R]-24U%(&UE;&1I;F<N`$ML87)T92!I:VME
M(.4@<VQE='1E(&MO;G1A:W0N("5S`$ML87)T92!I:VME(.4@<VQE='1E(&1I
M<W1R:6)U<VIO;G-L:7-T92X@)7,`2W5N;F4@:6MK92!S;&5T=&4@<V5T=7`@
M;W!P9W)A9&5R:6YG<W-C<FEP="`G)7,G+@!+=6YN92!I:VME(&9I;FYE(&UO
M='1A:V5R<R!E+7!O<W0@861R97-S92X`2W5N;F4@:6MK92!H96YT92!U="!H
M96QE(&%D<F5S<V5B;VME;BX`2W5N;F4@:6MK92!U="!H96QE(&1I<W1R:6)U
M<VIO;G-L:7-T96XN`$MU;FYE(&EK:V4@:&5N=&4@=70@:&5L92!L:7-T96X@
M;65D(&1I<W1R:6)U<VIO;G-L:7-T97(N`$MU;FYE(&EK:V4@;&%S=&4@:6YN
M('-T<F%T96=I("<E<R<N`$MU;FYE(&EK:V4@;W!P<F5T=&4@:V%T86QO9V5N
M("<E<R<N`$MU;FYE(&EK:V4@:&5N=&4@=70@;V9F96YT;&EG(&[X:VME;"!F
M<F$@;OAK:V5L=&IE;F5R96XN`$MU;FYE(&EK:V4@Y7!N92`E<RX`2W5N;F4@
M:6MK92#E<&YE("<E<R<@9F]R('-K<FEV:6YG+@!+86X@:6MK92#E<&YE($UA
M:6YT96YA;F-E7U1A<VLM;6]D=6QE;B`E<P!+=6YN92!I:VME(.5P;F4@:V%T
M86QO9V5N("<E<R<N`$MU;FYE(&EK:V4@;&5S92`E<P!+=6YN92!I:VME(&YU
M;&QS=&EL;&4@<&%S<V]R9&5T(&9O<B!D96X@9F]R97-P=7)T92!B<G5K97)E
M;BX@3F]E;B!E;&QE<B!A;&QE(&1E=&%L:F5N92!E<B!U<FEK=&EG92X@1F]R
M<_AK(&EG:F5N(&5L;&5R(&MO;G1A:W0@861M:6YI<W1R871O<F5N(&AV:7,@
M9'4@=')E;F=E<B!Y='1E<FQI9V5R92!H:F5L<"X`2W5N;F4@:6MK92!H96YT
M92!U="!!0TP`2W5N;F4@:6MK92!H96YT92!U="!A9')E<W-E8F]K+B`E<P!+
M=6YN92!I:VME(&AE;G1E('5T(&1I<W1R:6)U<VIO;G-L:7-T92X@)7,`2W5N
M;F4@:6MK92!H96YT92!U="!D:7-T<FEB=7-J;VYS;&ES=&4N("5S`$MU;FYE
M(&EK:V4@:&5N=&4@=70@:6YF;W)M87-J;VX@;VT@=&IE;F5R96YS(&9U;FMS
M:F]N86QI=&5T97(`2W5N;F4@:6MK92!R979E<G1E<F4@:V]N9FEG=7)A<VIO
M;F5N92X`2W5N;F4@:6MK92!F:F5R;F4@:V%T86QO9V5N("<E<R<N`$MU;FYE
M(&EK:V4@;&%G<F4@)7,@:V]N9FEG=7)A<VIO;BX`2W5N;F4@:6MK92!L86=R
M92!E;B!B86-K=7`@:V]N9FEG=7)A<VIO;BX`2W5N;F4@:6MK92!L86=R92!E
M;B!B86-K=7`@8V]N9FEG=7)A<VIO;CH@)7,`2W5N;F4@:6MK92!L86=R92!S
M971U<"!O<'!G<F%D97)I;F=S+7-C<FEP=&5T('1I;#H@)R5S)RX`2W5N;F4@
M:6MK92!L86=R92!B86-K=7`@:V]N9FEG=7)A<VIO;G-F:6QE;B`E<RX`2W5N
M;F4@:6MK92!L86=R92!K;VYF:6=U<F%S:F]N<V9I;&5N("5S+B!$=2!K86X@
M96YT96X@8F5N>71T92!D96<@878@96X@878@;75L:6=H971E;F4@9F]R(.4@
M;&%G<F4@9&%T82!T:6QB86ME('1I;"`E<R!E;&QE<B!K;W!I97)E(&MO9&5N
M('5N9&5R(&UA;G5E;'0@=&EL("5S+@!+=6YN92!I:VME('5T9OAR92!S^&L@
M<.4@3$1!4"!T:F5N97)E;BX`2W5N;F4@:6MK92!F:F5R;F4@)R5S)RX`2W5N
M;F4@:6MK92!O<'!D871E<F4@:V]N=&%K="X@)7,`2W5N;F4@:6MK92!O<'!D
M871E<F4@9&ES=')I8G5S:F]N<VQI<W1E;BX@)7,`2W5N;F4@:6MK92!S:W)I
M=F4@:V]N9FEG=7)A<VIO;B!F;W(@)R5S)SH@)7,`2W5N;F4@:6MK92!F:6YN
M92!-;WII;&QA(%-I9&5B87(N(%-J96MK(&%T(&1E;B!E<B#E<&5N+@!"<G5K
M97)E;B`G)7,G(&)L92!G:71T(&;X;&=E;F1E(')E='1I9VAE=&5R('1I;"!M
M87!P96X@)R5S)SH@)7,`5&%L="!T96MS=`!,86YD`$MU<G-E<@!/<'!R971T
M`$]P<')E='0@96X@;&EN:P!/<'!R971T(&5N(&YY`$]P<')E='0@=6YD97)M
M87!P97(`4F5T=&EG:&5T97(@9F]R(&5I97(`2W)E9&ET=&MO<G1N=6UM97(`
M1VIE;&1E;F1E(&9A<V4`1VIE;&1E;F1E('1I9`!':F5L9&5N9&4@=N9R`$=J
M96QD96YD92!U='-I:W1E<CH@`$=J96QD96YD92!S=&EL`%1I;'!A<W,@;W!P
M9V%V97(@<V]M(&MJ^')E<R!V960@:6YN;&]G9VEN9R!T:6P@)7,N`$ML:7!P
M('5T`$ML:7!P('5T('9A;&=T(&]M<N5D90!+>7!R;W,`1$0`1&%G;&EG`$1A
M=&$`1&%T851R92!U=&9O<G-K97(`1&%T;P!$871O($UO='1A='0`1&%T;R!V
M86QG`$1A9P!3;&5T="!K;VQO;FYE`$1E<V5M8F5R`$1E<VEM86QT86QL`$%V
M<VSE='0`4F5D=7-E<B!I;FYR>6MK`%-T86YD87)D`%-T86YD87)D(&9A<F=E
M`%-T86YD87)D:61E;G1I=&5T`%-T86YD87)D(')E='1I9VAE=&5R`%-T86YD
M87)D(')E='1I9VAE=&5R`$1E9FEN:7-J;VYE<@!$96QE9V5R('!O<VES:F]N
M`$1E;&5G97)T`%-L971T`%-L971T(&=R=7!P90!3;&5T="!R971T:6=H970`
M4VQE='0@;V<@9FIE<FX@;65L9&EN9V5R`%-L971T(&-E;&QE`%-L971T(&MO
M;&]N;F4`4VQE='0@96MS:7-T97)E;F1E(&%L=&5R;F%T:78@;6%L`$9J97)N
M(')E='1I9VAE=&5N92!T:6P@)R5S)P!&:F5R;B!R971T:6=H971E;F4@=&EL
M("<E<R<@;V<@86QL92!U;F1E<BUR971T:6=H971E<C\`4VQE='0@<F%D`%-L
M971T('9A;&=T(&ED96YT:71E=`!3;&5T="!G:F5L9&5N9&4@:V]L;VYN90!3
M;&5T="!G:F5L9&5N9&4@<F%D`%-L971T92!D96YN92!R971T:6=H971E;B!O
M9R!A;&QE('5N9&5R+7)E='1I9VAE=&5R/P!3;&5T="!S971U<"!O<'!G<F%D
M97)I;F=S+7-C<FEP="`G)7,G+@!,979E<FEN9W-T:60`1&%N;6%R:P!!=G-L
MY2!F;W)E<W#X<G-E;`!!=G-LY2!F;W)E<W#X<G-E;"!F;W(@;&5D:6<O;W!P
M=&%T="UI;F9O<FUA<VIO;@!"97-K<FEV('!R;V)L96UE=`!"97-K<FEV96QS
M90!$971A;&IE<B`H;V=SY2!I($AO<F1E)W,@;&]G9V9I;"DZ`$1E=&%L:F5R
M(&AA<B!B;&ET="!L;V=G970@9F]R(&%D;6EN:7-T<F%T;W)E;BX`571V:6ML
M:6YG`$1O9V=P=6YK=`!$;V=G<'5N:W0@9F]R(&1E;B!S:7-T92!T:6UE;CH@
M`$1O9V=P=6YK=#H@`%)E=&YI;F<@9G)A('9E;G-T<F4@;6]T(&CX>7)E`%)E
M=&YI;F<@9G)A(&CX>7)E(&UO="!V96YS=')E`$MA=&%L;V<`5FES(#(T+71I
M;65R<R!T:61E<C\`5FES;FEN9W-V86QG`%9I<R!F;W)V87)S96P@*%1!1BD`
M5FES;FEN9W-F;W)M870`365L9&EN9R!O;2!O<F1N:6YG`$EK:V4@<VQE='0`
M26MK92#E<&YE(&UA:6YE;F%N8V4N<&AP(&1I<F5K=&4`2W)Y<W,@878@:&5R
M(&AV:7,@9&5N(&;X<G-T92!R861E;B!I;FYE:&]L9&5R(&9E;'0M;F%V;F5T
M.@!,87-T(&YE9`!,87-T(&YE9"!G96YE<F5R="!K;VYF:6=U<F%S:F]N('-O
M;2!02%`@<V-R:7!T+@!.961T<F5K:W-L:7-T90!-961I<VEN97(`12UP;W-T
M`$524@!2961I9V5R`%)E9&EG97)E(&)L;VMK`%)E9&EG97(@1W)U<'!E`%)E
M9&EG97(@<F5T=&EG:&5T97(`4F5D:6=E<B!R971T:6=H=&5R`%)E9&EG97(@
M<F5T=&EG:&5T97(@9F]R("5S`%)E9&EG97(@=F%L9R!F;W(Z`%)E9&EG97(@
M<F5T=&EG:&5T97(@9F]R("5S`%)E9&EG97(@<F5T=&EG:&5T97(@9F]R("5S
M`$]P<&SF<FEN9P!%;&5M96YT+BXN`$5M`$4M<&]S=`!%+7!O<W1A9')E<W-E
M`$4M<&]S=&%D<F5S<V4@;>4@<W1E;6UE+@!%+7!O<W0@;65D(&)E:W)E9G1E
M;'-E`$;X;&5L<V5R`%1O;2!M96QD:6YG+@!4;VUT(')E<W5L=&%T+@!4^&T@
M<_AK96MR:71E<FEE<@!!:W1I=F5R(&UU;&EG:&5T(&9O<B#E('-E='1E(&EN
M;B!B:6QD97(@9G)A(&=A;&QE<FEE<B!I('1E:W-T96X_`$%K=&EV97)E(&CX
M>7)E:VQI:VL@;65N>3\`4VQU='0`Q7)S<VQU='0`1VKX<B!E9&ET;W)E;B!S
M=/AR<F4`4VMR:78@:6YN(&5T="!S:6MK97)H971S<W#X<G-MY6P@<V]M(&1U
M('9I;"!B;&D@<W!U<G0@;VT@:'9I<R!D=2#X;G-K97(@Y2!N=6QL<W1I;&QE
M('!A<W-O<F1E="!D:71T+"!F+F5K<RX@)VAV82!E<B!N879N970@<.4@:VKF
M;&5D>7)E="!D:71T/R<Z`%-K<FEV(&EN;B!A9')E<W-E;B!T:6P@8FEL9&5T
M(&AE<@!&96EL`$9E:6P@=F5D('-E;F1I;F<@878@<W9A<CH@)7,`1F5I;"!M
M960@92UP;W-T(&UE;&1I;F=E;BX`1F5I;"!V960@<VMR:79I;F<@=&EL("<E
M<R<N`$9E:6PZ(`!%=7)O<&$`2'9E<G0@,34N(&UI;G5T=`!(=F5R="`R+B!M
M:6YU='0`2'9E<G0@,S`N('-E:W5N9`!(=F5R="`U+B!M:6YU='0`2'9E<B!I
M;FYL;V=G:6YG`$AV97(@:&%L=G1I;64`2'9E<G0@;6EN=71T`$5K<V5M<&5L
M=F5R9&EE<CH`2VKX<@!+:OAR97(Z`%5T=FED`%5T=FED(%-I9&5B87(`1F]R
M=F5N=&5T("<I)P!&;W)V96YT970@8FQA;FMT(&]R9"!E;&QE<B!Q=6]T970@
M<_AK96MR:71E<FEE`%5T;/AP<V1A=&\`16MS<&]N96YT`$9O<F=R=6YN<V9A
M<F=E`$]P<&QA<W1I;F<@878@<V5T=7`@=FEA($944`!5=&AE;G1I;F<@878@
M:6YS=&EL;&EN9V5R(&9E:6QE="X`5&EL:V]B;&EN9R!T:6P@3$1!4"UT:F5N
M97(@9F5I;&5T+@!4:6QK;V)L:6YG('1I;"!334(M=&IE;F5R(&9E:6QE="X`
M1F5I;&5T('9E9"!K;W!I97)I;F<@9G)A("(E<R(N`$9E:6QE="!V960@:V]P
M:65R:6YG('1I;"`B)7,B+@!&96EL970@=F5D(&]P<')E='1E;'-E(&%V(&YY
M(%-!4TP@:V]B;&EN9RX`1F5I;&5T('9E9"!F;'ET=&EN9R!T:6P@(B5S(BX`
M4&5N="!VYG(`1F%T86P@1F5I;#H@`$9A>`!&96)R=6%R`$;X;&5S('-O;0!&
M^&QE<R!S;VTZ(`!&Y2!B>6=E<@!&Y2!S;OAB>6=E<@!&96QT;6%T<FES90!!
M;G1A;&P@9FEL97(Z("5S(&9I;&5R`$%N=&%L;"!F:6QE<CH@)7,@9FEL97(`
M1FEL8F5H86YD;&5R`$9I;&YA=FX`1FEL=F%L9P!,87-T(&]P<"!F:6QE<@!/
M<'!L87-T:6YG(&%V(&9I;&5R('-T^'1T97,@:6MK92X`1FEL=&5R`$;X<G-T
M92!H86QV;>5N90!&^')S=&4@:W9A<G1MY6YE`$9A<W0@9F]R:&]L9`!3;G4`
M1FQY=`!4Y6ME`$UA<'!E;B`E<R!E:W-I<W1E<F5R(&EK:V4`1F]N=&9A<F=E
M`$UA=`!&;W(@;F5T=&QE<V5R92!S;VT@:6MK92!S=/AT=&5R(&)I;&1E<@!&
M;W)V87)S96P@*%1!1BD`06YT86QL(&1A9V5R<R!F;W)V87)S96P@*';F<B!O
M8G,@<.4@870@9&5T(')E='5R;F5R=&4@9F]R=F%R<VQE="!I;FYE:&]L9&5R
M(&+E9&4@9&%G(&]G(&YA='0[(&5N('-T;W(@=F5R9&D@:&5R(&MA;B!R97-U
M;'1E<F4@:2!E;B!S=&]R(&)L;VMK*0!';&5M="!P87-S;W)D970_`%-K:F5M
M865R`%-K:F5B;F4O;'EK:V4`5'EP92!S:VIE8FYE+VQY:VME`%-K:F5B;F5R
M+VQY:VME`%-K:F5B;F5R+VQY:VME(#(`1F]R=6UE<@!6:61E<F5S96YD=&4`
M1F%N="!P<F]G<F%M;65N93H@)7,`1F%N="!K871A;&]G96YE.@!&<@!286UM
M97(`3&5D:6<O;W!P=&%T="UI;F9O<FUA<VIO;@!,961I9R]O<'!T871T('-V
M87(`3&5D:6<O;W!P=&%T="!F;W)E<W#X<G-E;`!3=F%R('#E(&QE9&EG+V]P
M<'1A='0@9F]R97-P^')S96P`1G)A`$9R82``1G5L;"!B97-K<FEV96QS90!&
M=6QL;>5N90!&=6QL="!N879N`$=A;&QE<FD@9'4@^&YS:V5R(.4@:&5N=&4@
M8FEL9&4@9G)A`$=A;&QE<FDZ`$=E;F5R97(@)7,@:V]N9FEG=7)A<VIO;@!'
M96YE<F5R="!K;V1E`$=E=&]P="!&96EL.B``1VET="!.879N`$=O`%/X:R!P
MY2!';V]G;&4`1W+E=&]N90!(96QL87,`1W+X;FQA;F0`1W)U<'!E(&%D;6EN
M:7-T<F%S:F]N`$=R=7!P96YA=FX@:V%N(&EK:V4@=N9R92!T;VUM90!'<G5P
M<&5R971T:6=H971E<@!'<G5P<&5R`%)E='1I9VAE=&5R(&9O<B!G:F5S=`!2
M971T:6=H971E<B!F;W(@9VIE<W0`1VIE<W1E8F]K`$A(`$A434P`2%1-3$%R
M96$@;F5K=&5R(.4@<VQE='1E(&1E;B!S:7-T92!C96QL96X@:2!E;B!R860N
M`$A434Q!<F5A(&YE:W1E<B#E('-L971T92!D96X@<VES=&4@:V]L;VYN96X@
M:2!T86)E;&QE;BX`2%1-3$%R96$@;F5K=&5R(.4@<VQE='1E(&1E;B!S:7-T
M92!R861E;B!I('1A8F5L;&5N+@!(5%10(&%U=&5N=&ES97)I;F<@:6MK92!F
M=6YN970N`$AA<V@M86QG;W)I=&UE`$1I<P!(;V1E`$CX>61E`$AJ96QP`$AJ
M96QP('1I;"!B<G5K(&%V(&5D:71O<@!(:F5L<&5R`$AA;'9K=6QE`$AE<B!E
M<B!B96=Y;FYE;'-E;B!PY2!F:6QE;CH`2/AY`$AI<W1O<FEE;W!P9OAR:6YG
M97(@<.4@:&$@;F%V;B!S;VT@:6MK92!E<B!T;VUM90!(:F5?;0!(:F5M`$AJ
M96UM96%D<F5S<V4`5&5L969O;B!H:F5M;64`2&]R9&4`2&]R9&4O2V]L86(Z
M(%5G>6QD:6<@)7,@6$U,(&1A=&$@9G5N;F5T(&D@;65L9&EN9R`E<P!(;W)D
M92]+;VQA8CH@26YG96X@;65L9&EN9R!P87-S97(@;65D(&]B:F5K=&5T("5S
M`$AO<F1E+TMO;&%B.B!);G1E="!O8FIE:W0@878@='EP96X@)7,@9G5N;F5T
M(&D@;65L9&EN9R`E<P!(;W)D92]+;VQA8CH@1FIE<FYE="`E<R`B)7,B`$AO
M<F1E+TMO;&%B.B!3>6YK<F]N:7-E<G1E("5S("(E<R(`2&]R9&4O2V]L86(Z
M($EN=&5G<F%S:F]N<VUO=&]R96X@:W)E=F5R(%!(4"`G9&]M>&UL)R!U='9I
M9&5L<V4`2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@;W!P<F5T=&4@;GET="!8
M34P@=')E(&9O<B!O8FIE:W1E="`E<P!(;W)D92]+;VQA8CH@2W5N;F4@:6MK
M92!F:F5R;F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@
M:&5N=&4@34E-12!)1"!F;W(@9&5L96X@878@='EP92`E<P!(;W)D92]+;VQA
M8CH@2W5N;F4@:6MK92!S>6YK<F]N:7-E<F4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z($MU;FYE(&EK:V4@<WEN:W)O;FES97)E(&1E;'1E(')E<W-U<G-E
M<CH@)7,`2&]R9&4O2V]L86(Z(%5K:F5N="!D96QT(')E<W-U<G,@(B5S(@!(
M;W)I<V]N=&%L(&QI;FIE`$AO<FES;VYT86P@<&%D9&EN9P!(;W)I<V]N=&%L
M.@!(=F]R9&%N(&MO;2!D=2!H:70_("A696YN;&EG<W0@<F%P<&]R=&5R(2D`
M2'9O<B!M86YG92!K;VQO;FYE<B#X;G-K97(@9'4@Y2!S;.4@<V%M;65N/P!(
M=F]R(&UA;F=E(&9E;'1E<B`H:V]L;VYN97(I(&5R(&1E=#\`2'9O<B!M86YG
M92!R861E<B#X;G-K97(@9'4@Y2!S;.4@<V%M;65N/P!&=6MT:6=H970`1G5K
M=&EG:&5T.B``2'5M;W)I<W1E<@!/<'!R971T96QS92!A=B!)34%0('!O<W1B
M;VMS(&9E:6QE=#H@)7,`4VQE='1I;F<@878@24U!4"!P;W-T8F]K<V5N(&9E
M:6QE=#H@)7,`3W!P<F5T=&5L<V4@878@:W9O=&4@<.4@24U!4"!P;W-T8F]K
M<R!F96EL970Z("5S`$E0($%D<F5S<V4`25`@061R97-S92!I:VME('1I;&=J
M96YG96QI9RX`25`@061R97-S92!I:VME(&EN;F5N9F]R('1I;&%T=&4@0TE$
M4B!B;&]K:RX`0G)U9&0@<.4@25`@;&]C:V1O=VXN`%-?971T(&EN;B!N>2!R
M860@9OAR`$MU;B!I:V]N97(`26MO;F5R(&9O<B`E<P!):V]N97(@;65D('1E
M:W-T`$ED96YT:71E=&5N<R!N879N.@!(=FES(&1E;B!I:VME('9I<V5S(')I
M:W1I9RP@)7,@9F]R(.4@Y7!N92!I(&YY='0@=FEN9'4N`$AV:7,@9'4@:6MK
M92!S97(@;F]E;B!I:V]N97(@;N5R(&1U(&)E;GET=&5R($EN=&5R;F5T($5X
M<&QO<F5R+"!K86X@9&5T(&AE;F1E(&1U('1R96YG97(@Y2!K<GES<V4@878@
M9&5N;F4@8F]K<V5N(&9O<B#E('-K<G4@878@=')A;G-P87)E;G0@4$Y'+@!(
M=FES(&1U('-E<B!D96YN92!M96QD:6YG96X@;65N(&EN=&5T(&)I;&1E+"!K
M86X@9&5T(&AE;F1E(&%T(&)I;&1E="!D=2!V:6P@;&%S=&4@;W!P(&EK:V4@
M:V%N('9I<V5S(&D@9&EN(&YE='1L97-E<BX`1F]R:.5N9'-V:7-N:6YG(&%V
M(&)I;&1E.@!":6QD96%D<F5S<V4`0FEL9&5A9')E<W-E.@!":6QD92!F<F$@
M9V%L;&5R:0!":6QD92!F<F$@9V%L;&5R:3H`3W!P;&%S=&EN9R!A=B!B:6QD
M90!":6QD97(`26UP;W)T97)I;F<L('-T96<@)60`26UP;W)T97)T92!F96QT
M.B`E<P!);7!O<G1E<G1E(&9E;'0Z`%5N9&5R(&%R8F5I9`!?4V5T="!I;FX@
M<F%D(&5T=&5R`$9E:6P@:&%N9&QI;F=S:V]D92!G:71T+@!59WEL9&EG(&)R
M=6ME<FYA=FX@;V<O96QL97(@<&%S<V]R9"X`1F5I;"!B<G5K97)N879N(&5L
M;&5R(&%L=&5R;F%T:78@861R97-S92X@5F5N;FQI9W-T(&9O<G/X:R!I9VIE
M;B!E;&QE<B!K;VYT86MT('-Y<W1E;6%D;6EN:7-T<F%T;W)E;B!D:6X@9F]R
M('ET=&5R;&EG97)E<F4@:&IE;'`N`-AK(&EN;G)Y:VL`26YD:79I9'5E;&QE
M(&)R=6ME<F4`26YF;P!);F9O<FUA<VIO;@!3971T(&EN;B!K7V]L;VYN92!E
M='1E<@!3971T(&EN;B!B:6QD90!3971T(&EN;B!T86)E;&P`4V5T="!I;FX@
M=V5B;&EN:P!3971T(&EN;B!?:V]L;VYN92!F^'(`4V5T="!I;FX@96X@;GD@
M:V]L;VYN92!E='1E<B!D96X@9VIE;&1E;F1E`%-E='0@:6YN(&5N(&YY(&MO
M;&]N;F4@9OAR(&1E;B!G:F5L9&5N9&4`4V5T="!I;FX@96X@;GD@<F%D(&5T
M=&5R(&1E;B!G:F5L9&5N9&4`4V5T="!I;FX@96X@;GD@<F%D(&;X<B!D96X@
M9VIE;&1E;F1E`%-E='0@:6YN(&QI;FIE<VMI9G0@971T97(@9&5N(&=J96QD
M96YD92!N;V1E;@!3971T(&EN;B!L:6YJ97-K:69T(&;X<B!D96X@9VIE;&1E
M;F1E(&YO9&5N`%-E='0@:6YN(&%L=&5R;F%T:78@;6%L`%-E='0@:6YN(&5N
M(&4M<&]S="!A9')E<W-E(&1U(/AN<VME<B#E(&UO='1A(&1E="!N>64@<&%S
M<V]R9&5T('#E.@!3971T(&EN;B!C96QL92!E='1E<@!3971T(&EN;B!C96QL
M92!E='1E<@!3971T(&EN;B!K;VQO;FYE(&5T=&5R`%-E='0@:6YN(&MO;&]N
M;F4@9OAR`%-E='0@:6YN(&UE;&1I;F=E<@!3971T(&EN;B!L:6YJ97-K:69T
M(&5T=&5R`%-E='0@:6YN(&QI;FIE<VMI9G0@9OAR`%-E='0@:6YN(')A9"!E
M='1E<@!3971T(&EN;B!R860@9OAR`%-E='0@:6YN(&1E="!PY6MR979D92!S
M=F%R970@=&EL(&;X;&=E;F1E('-I:VME<FAE='-S</AR<VWE;#H`4V5T="!I
M;FXO<F5D:6=E<F4@8FEL9&4`4V5T="!I;FXO<F5D:6=E<F4@;&EN:P!):VME
M(&YO:R!K<F5D:71T(&9O<B#E(&MU;FYE('-E;F1E('1I;"!D:7-T<FEB=7-J
M;VYS;&ES=&5N+@!):VME(&YO:R!K<F5D:71T+@!);G1E9V5R`%5G>6QD:6<@
M:&%N9&QI;F<@=F%L9W0@9F]R(&1E;FYE(&MO;7!O;F5N=&5N+@!59WEL9&EG
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!59WEL9&EG('!R;V=R86TN`%5G
M>6QD:6<@8F%T8V@@240`56=Y;&1I9R!D871A('-E;F1T+@!59WEL9&EG(&UO
M='1A:V5R(&%D<F5S<V4N`%5G>6QD:6<@9FEL9F]R;6%T`%5G>6QD:6<@;65L
M9&EN9W-T>7!E`%5G>6QD:6<@96QL97(@;6%N9VQE;F1E(&%P:5]I9"X`56=Y
M;&1I9R!E;&QE<B!M86YG;&5N9&4@<&%R86UE=&5R92X`56=Y;&1I9V4@<F5T
M=&EG:&5T97(N`%5G>6QD:6<@<')O=&]K;VQL+@!59WEL9&EG(&UO='1A:V5R
M.B`G)7,G`%5G>6QD:6<@9&5L="!O8FIE:W0`56=Y;&1I9R!K:6QD96%D<F5S
M<V4`56=Y;&1I9R!U;FEC;V1E(&1A=&$N`$EN;FAO;&0`27-O;&5R=&4@=&]R
M9&5N+7-T;W)M97(`571G:79E<@!+=7)S:78`2F%N=6%R`$IU;&D`2G5N:0!*
M=7-T97(`36ED='-T:6QL`$)E:&]L9&4@;W)G:6YA;#\`2V5R8F5R;W,@=&IE
M;F5R96X@879V:7-T92!A=71E;G1I<V5R:6YG96XN`$ME<FYE;"!.>6)E9WEN
M;F5R90!.^&MK96QG96YE<F5R:6YG`$[X:VME;"!F:6YG97)P<FEN=`!.^&MK
M96P@;&5N9V1E`$[X:VME;"!T>7!E`$[X:VME;&)R=6L`3OAK:V5L(&5K<VES
M=&5R97(@86QL97)E9&4@<.4@9&5N(&]F9F5N=&QI9V4@;OAK:V5L=&IE;F5R
M96XN`$)A<FX`571?<V5E;F1E`%-P<N5K`%-I<W1E(&AA;'1I;64`4VES=&4@
M:W9A<G1E<@!3:7-T92!O<'!D871E<FEN9SH`4VES=&4@:6YN;&]G9VEN9SH@
M)7,`4VES=&4@:6YN;&]G9VEN9SH@)7,@9G)A("5S`%-I<W1E(&EN;FQO9V=I
M;F<Z($%L9')I`$QO=@!5='-E96YD90#8;G-K97,@:6YG96X@<F%M;65R(&QA
M<B!D=2!F96QT970@=N9R92!T;VUT`%9E;G-T<F4`5F5N<W1R92!H;V1E`%9E
M;G-T<F4@=F5R9&EE<@!,971T(&1U<VMR96=N`$QE='0@<F5G;@!,971T(&9O
M<FUI9&1A9W-R96=N`$QE='0@971T97)M:61D86=S<F5G;@!,971T92!R96=N
M8GEG97(`3&5T="!R96=N(&UE9"!T;W)D96X`3&5T="!S;OAF86QL`$QE='1E
M('-N^&)Y9V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P96ME<B!T:6PZ`$QI;FL@
M92UP;W-T(&%D<F5S<V5N('1I;"`G<VMR:78@;GDG+7-I9&4@=F5D('9I<VYI
M;F<`3&EN:V5R`$QI;G5X($-O;VMI90!,:7-T("T@8G)U:V5R96X@:V%N('-E
M(&UA<'!E;@!,:7-T(&1A=&%B87-E<@!%;6YE<B!I($AJ96QP`$QI<W0@=&%B
M96QL97(`3&ES=&4M87)K:78`3&ES=&5H:F5L<`!,:7-T92U)9`!%:65R(&%V
M(&QI<W1E`$QI<W1E+7!O<W0`06)B;VYE<B!PY2!L:7-T90!3=&]P<"!A8F)O
M;FYE;65N="!PY2!L:7-T90!-=6QI9VAE="!F;W(@Y2!L:7-T92!B<G5K97)E
M(&5R(&1E86MT:79E<G0N`$QI='1E<F%T=7(`3&%S=&5R(&)I8FQI;W1E:V5R
M+BXN`$QA<W1E<BXN+@!,;VMA;"!T:60Z`%-P<N5K(&]G('1I9`!,;VMA<VIO
M;@!,;V=G(&EN;@!,;V=G('5T`$EN;FQO9V=I;F=S;W!P9V%V97(`3&]G:6X@
M9F5I;&5T(&9O<F1I(&)R=6ME<FYA=FYE="!E;&QE<B!P87-S;W)D970@9'4@
M<VMR978@:6YN('9A<B!F96EL+@!,;V=I;B!F96EL970N`$QA;F<@=&5K<W0`
M2VKF<FQI9VAE=`!,878`4VWE(&=R97-K92!B;VMS=&%V97(`4VWE(&QA=&EN
M<VME(&)O:W-T879E<@!-30!);FYB;VMS`%-A;7-V87)E;F1E(&9E;'0`3?AT
M96%V;'ES;FEN9P!-^'1E:6YF;W)M87-J;VX`3?AT96EN;FMA;&QE;'-E`$WX
M=&5S=F%R`$WX=&5O<'!D871E<FEN9P!&;W)E<_AR<V5L(&]M(&WX=&5O<'!D
M871E<FEN9P!-96YY;6]D=7,Z`$UE;&1I;F<`3>5N961T;&EG`&9L>71T(&YE
M9`!F;'ET="!O<'``3F%V;@!4<F5N9V5R(&AA;F1L:6YG`$%L9')I`$YY:&5T
M97(`3F5S=&4`3F5S=&4@<VED90!.96D`26MK92!D96QT86=E<@!);F=E;@!.
M;W1A=&5R`$]B<R$`3TL`2V]N=&]R`%9A;&=F<FD@9&5L=&%G97(`5F%L9P!/
M<F=A;FES97)I;F<`06YN96X@:6YF;W)M87-J;VX`4&%S<V]R9`!5=&;X<B!V
M961L:6ME:&]L9'-O<&5R87-J;VYE<@!5=&;X<B!V961L:6ME:&]L9'-O<&5R
M87-J;VYE<B!V960@:6YN;&]G9VEN9S\`4&5R<V]N;&EG(&EN9F]R;6%S:F]N
M`%1E;&5F;VX`5F5N;FQI9W-T(&=I(&5T('-A;6UE;F1R86<@878@<')O8FQE
M;65T+@!696YN;&ES="!S:W)I=B!I;FX@8G)U:V5R;F%V;B!O9R!P87-S;W)D
M`%9E;FYL:6=S="!S92!O=F5R(&1E;B!F^&QG96YD92!I;F9O<FUA<VIO;F5N
M+"!V96QG('/E(&5N(&AA;F1L:6YG(&9R82!M96YY96X@;F5D96YU;F1E<BX`
M5F5N;FQI9W-T('9E;&<@96X@:&%N9&QI;F<@9G)A(&UE;GEE;B!N961E;G5N
M9&5R+@!&;W)HY6YD<W9I<VYI;F<`1F]R<FEG92!S:61E`%!R;V)L96UB97-K
M<FEV96QS90!(=7-K(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXN`$9J97)N
M('!A<@!3=F%R('-E;F1T+@!3=F%R(&%T(&UE;&1I;F=E;B!I:VME('-T^'1T
M97,`4W9A<B!M960@;&5D:6<O;W!P=&%T="!F;W(@9&4@;F5S=&4@=&\@;>5N
M961E;F4N`%-V87(@;65D(&1E;B!F;W)E<W!U<G1E(&QE9&EG+V]P<'1A='0M
M:6YF;W)M87-J;VYE;BX`3V)L:6=A=&]R:7-K(&1E;'1A9V5R`$YU;&QS=&EL
M;`!4:6QB86ME('1I;"!686QG`%)O;&QE`$QA9W)E('-O;0!,86=R92!686QG
M`%/X:P!696QG(&5N(&1A=&\`5F5L9R!D871O<VMI;&QE=&5G;CH`5F5L9R!D
M871O9F]R;6%T`%9E;&<@=&ED<V9O<FUA=#H`5F5L9R!T;R!S86US=F%R96YD
M92!F96QT+@!696QG(/AN<VME="!S<'+E:SH`4V5N9"!S:7-T92!I;F9O<FUA
M<VIO;@!396YD('!R;V)L96UR87!P;W)T`%)E9VES=')E<B!D96<@;VT@:6MK
M92!R96=I<W1R97)T`%-T^')R96QS90!(;W!P(&]V97(@=F5D;&EK96AO;&0`
M4W!E<VEA;'1E9VYI;FYT87-T:6YG`%-T87)T`%-T871U<P!%;6YE`%-E;F0`
M4W5K<V5S<P!386UM96YD<F%G`$]P<&=A=F5R`$=O9'1A(&9O<F5S</AR<V5L
M(&9O<F5L^'!I9P!';V1T82!F;W)E;/AP:6<`2W5N('1E:W-T`$MA;&5N9&5R
M9&%T82!E<B!U9WEL9&EG`$AA;F1L:6YG96X@:&%R(&)L:71T(&QA9W0@=&EL
M(&1I;B!L:7-T92!O=F5R(&AA;F1L:6YG97(N`$)R=6ME<F5N<R!L961I9R]O
M<'!T871T(&EN9F]R;6%S:F]N(&)L92!L86=R970N`$1E="!O<'!S=&]D(&5N
M(&9E:6P@=6YD97(@9F]R<_AK('#E(.4@=FES92!D96YN92!M96QD:6YG<V1E
M;&5N`$1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@:6UP;W)T97)I;F<@878@
M:&5N9&5L<V5N.B`E<RX`1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T
M97)I;F<@878@:&5N9&5L<V5N.B`E<RX`1&5T(&]P<'-T;V0@96X@9F5I;"!V
M960@:6UP;W)T97)I;F<@878@8G)U:V5R96YS(&QE9&EG+V]P<'1A='0M:6YF
M;W)M87-J;VXZ("5S`$1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK:V4@
M<W1O='1E="X`1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK92!I;7!L
M96UE;G1E<G0N`$1E='1E('1A;&QE="!MY2!VYG)E(&UI;G-T(#$N`$1E='1E
M(&WE(';F<F4@970@=&%L;"X`5&ET=&5L`%1I;`!54DP`2V%N(&EK:V4@:V]B
M;&4@=&EL(%-13'-E<G9E<F5N+@!+86X@:6MK92!O=F5R<V5T=&4@9&5T=&4@
M5V]R9"UD;VMU;65N=&5T`$%N9W)E(&5N9')I;F=E<@!5:.5N9'1E<G0@:V]M
M<&]N96YT(&%V('1Y<&5N.B`E<P!5=&5N(&YA=FX`3W!P9&%T97(@<W1A='5S
M('#E(&%V<V5N9&5R90!,87-T(&]P<`!,86=R92!686QG`$)R=6ME<FYA=FX`
M0G)U:V5R;F%V;CH`5FES("5S`%9I<R!H96YD96QS90!6:7,@:&%N9&QI;F=E
M<@!!9'9A<G-E;`!5:V5N=&QI9P!696QK;VUM96X@=&EL("5S`%9E;&MO;6UE
M;BP@)7,`1FER;6%A9')E<W-E`$9I<FUA=&5L969O;@#EY0#E<FQI9P!*80!$
M=2!MY2!B97-K<FEV92!P<F]B;&5M970@9OAR(&1U(&MA;B!S96YD92!E;B!P
M<F]B;&5M<F%P<&]R="X`1&EN("5S('1I;&MO8FEN9R!H87(@9^5T="!U="X@
M5F5N;FQI9W-T(&QO9R!I;FX@:6=J96XN`$1I;B!I;F9O<FUA<VIO;@!&=6QL
M="!N879N`$YE='1L97-E<F5N(&1I;B!S=/AT=&5R(&EK:V4@9&5N;F4@=71S
M:VEF='-O<&5R87-J;VYE;BX@5')Y:VL@2V]N=')O;&PO3W!S:F]N("L@4"!F
M;W(@Y2!S:W)I=F4@=70N`$1I;F4@=F%L9R!H87(@8FQI='0@;W!P9&%T97)T
M`%M0<F]B;&5M<F%P<&]R=%T`6VQI;FIE("5S(&%V("5S70!(:F5L<`!,;V=G
M('5T`%9A;&<`;F%V;@!V0V%R9```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N8E].3R]H96QP
M+GAM;```````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S
M,C``,3`T,3<S-C(W-S<`,#(P,S,Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM
M("1(;W)D93H@:&]R9&4O;&]C86QE+VYB7TY/+VAE;'`N>&UL+'8@,2XR(#(P
M,#0O,#4O,C<@,C`Z,C(Z,30@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A
M;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O
M=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@
M(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@
M;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)
M3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS
M(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E
M9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@
M<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M
M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL
M(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A
M<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T
M:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO
M=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC
M:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W
M96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*
M/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^
M"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P
M86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC
M:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC
M:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE
M(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T
M:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T
M:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N
M86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME
M('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y
M(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@
M86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U
M;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA
M;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M/"]H96QP/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FQ?3DPO````````````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S<W`#`Q-C8W,P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]N;%].3"],0U]-15-304=%4R\`````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#(P-#8P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+VYL7TY,+TQ#7TU%4U-!1T53+VAO<F1E+FUO
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0Q-3`P-P`Q,#0Q-S,V,C<W-P`P
M,C(Q,C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````")!P``'````&0\```3"@``K'@```````#XH```#@```/F@
M```/````"*$```T````8H0``"````":A```+````+Z$```P````[H0``!```
M`$BA```8````3:$``!L```!FH0``+0```(*A```=````L*$``"0```#.H0``
M*0```/.A```9````':(``"8````WH@``#````%ZB```D````:Z(```\```"0
MH@``"P```*"B```.````K*(```4```"[H@``*````,&B```(````ZJ(```H`
M``#SH@``%0```/ZB```2````%*,```L````GHP``A0```#.C```.````N:,`
M``H```#(HP``#0```-.C```.````X:,``!$```#PHP``#0````*D```,````
M$*0```T````=I```!@```"ND``"4````,J0```H```#'I```#P```-*D```8
M````XJ0```P```#[I```#@````BE```.````%Z4```@````FI0``"0```"^E
M```N````.:4``!H```!HI0``,@```(.E```X````MJ4``%0```#OI0``40``
M`$2F``!:````EJ8``%<```#QI@``-````$FG```)````?J<```T```"(IP``
M!P```):G```*````GJ<```\```"IIP``!0```+FG```&````OZ<``!$```#&
MIP``"````-BG```)````X:<```D```#KIP``)0```/6G```@````&Z@``!,`
M```\J```$````%"H```/````8:@```H```!QJ````P```'RH```/````@*@`
M`!0```"0J```"0```*6H```-````KZ@``!(```"]J```&0```-"H```>````
MZJ@```\````)J0``"@```!FI```/````)*D```@````TJ0``)````#VI```4
M````8JD``!8```!WJ0``"````(ZI``!.````EZD``"T```#FJ0``&0```!2J
M```'````+JH```P````VJ@``+````$.J```.````<*H```,```!_J@``"P``
M`(.J```'````CZH```<```"7J@``!0```)^J```%````I:H```H```"KJ@``
M`P```+:J```7````NJH```H```#2J@``#P```-VJ```.````[:H``!@```#\
MJ@``(P```!6K```.````.:L``!0```!(JP``%P```%VK```7````=:L``!<`
M``"-JP``$P```*6K```/````N:L```X```#)JP``'P```-BK```=````^*L`
M``<````6K```!@```!ZL```(````):P```\````NK```!@```#ZL```*````
M1:P``!,```!0K```"P```&2L```0````<*P``!4```"!K```%0```)>L```'
M````K:P``!````"UK```!0```,:L```5````S*P``!$```#BK```#````/2L
M```[`````:T``#@````]K0``"0```':M```'````@*T``!0```"(K0```P``
M`)VM```%````H:T``!````"GK0``"0```+BM```3````PJT``#D```#6K0``
M$@```!"N```G````(ZX``"P```!+K@``*@```'BN```E````HZX```H```#)
MK@``!@```-2N```)````VZX```<```#EK@``+P```.VN```W````':\``"X`
M``!5KP``50```(2O```M````VJ\``"T````(L```/0```#:P```_````=+``
M`"T```"TL```0````.*P```C````([$``",```!'L0``0````&NQ```M````
MK+$``#,```#:L0``)0````ZR```5````-+(``!D```!*L@``*0```&2R```D
M````CK(``"@```"SL@``$0```-RR```*````[K(```P```#YL@``"@````:S
M```0````$;,``!8````BLP``%@```#FS```'````4+,```<```!8LP``%```
M`&"S```*````=;,```@```"`LP``)P```(FS```(````L;,```<```"ZLP``
M!P```,*S```&````RK,```4```#1LP``!P```->S```&````W[,```@```#F
MLP``*0```.^S```.````&;0```H````HM```!````#.T```'````.+0```D`
M``!`M```!@```$JT```1````4;0```<```!CM```%@```&NT```$````@K0`
M``@```"'M```!@```)"T```-````E[0```8```"EM```'@```*RT```1````
MR[0```@```#=M```#0```.:T```,````]+0```<````!M0```P````FU```#
M````#;4``!<````1M0``$P```"FU```=````/;4```@```!;M0``!````&2U
M```(````:;4```@```!RM0``00```'NU```:````O;4``"L```#8M0``(```
M``2V```5````);8```8````[M@``!@```$*V```5````2;8``!@```!?M@``
M(@```'BV```N````F[8``!T```#*M@``(0```.BV``!4````"K<``"D```!?
MMP``"@```(FW```'````E+<```<```"<MP``%0```*2W```.````NK<```H`
M``#)MP``#P```-2W```-````Y+<```\```#RMP``#0````*X```)````$+@`
M`!0````:N```!@```"^X```8````-K@``!T```!/N```$P```&VX```1````
M@;@``!0```"3N```!````*BX```&````K;@``!0```"TN```5````,FX``!D
M````'KD```0```"#N0``#@```(BY```%````E[D```4```"=N0``&P```*.Y
M```:````O[D``!,```#:N0``$0```.ZY```1`````+H``!P````2N@``*@``
M`"^Z```0````6KH``"$```!KN@``!0```(VZ```3````D[H```L```"GN@``
M$@```+.Z```*````QKH```\```#1N@``#0```.&Z```1````[[H``!,````!
MNP``#````!6[```&````(KL```P````INP``!@```#:[```7````/;L``!``
M``!5NP``$0```&:[```(````>+L```4```"!NP``#````(>[```0````E+L`
M``4```"ENP``#0```*N[```&````N;L```<```#`NP``#0```,B[```'````
MUKL```L```#>NP``!P```.J[```'````\KL```D```#ZNP``"0````2\```*
M````#KP``!D````9O```/0```#.\```=````<;P```P```"/O```$````)R\
M```%````K;P``"4```"SO```$@```-F\```3````[+P``"L`````O0``.P``
M`"R]```@````:+T```@```")O0``-@```)*]```A````R;T``!````#KO0``
M"````/R]```,````!;X```8````2O@``!````!F^```/````'KX```X````N
MO@``!P```#V^```*````1;X```T```!0O@``'P```%Z^```<````?KX``"$`
M``";O@``'@```+V^```9````W+X``!X```#VO@``&P```!6_```A````,;\`
M`"X```!3OP``)@```(*_```<````J;\``!X```#&OP``'````.6_```F````
M`L```"L````IP```,P```%7````F````B<```"L```"PP```.````-S````=
M````%<$``!4````SP0``+P```$G!```@````><$``!(```":P0``*0```*W!
M```>````U\$``"````#VP0``$@```!?"``"B````*L(``!8```#-P@``(P``
M`.3"```H````",,``"D````QPP``*````%O#```?````A,,``!4```"DPP``
M(````+K#```E````V\,``"@````!Q```+0```"K$```P````6,0``)(```")
MQ```(0```!S%```6````/L4``!P```!5Q0``)@```'+%```J````F<4``$$`
M``#$Q0``1`````;&```,````2\8```<```!8Q@``!P```&#&```&````:,8`
M``T```!OQ@``$````'W&```2````CL8``!,```"AQ@``$@```+7&```'````
MR,8```0```#0Q@``$````-7&```0````YL8```P```#WQ@``#@````3'```-
M````$\<```\````AQP``$P```#''```-````1<<``"@```!3QP```P```'S'
M```-````@,<```8```".QP``$0```)7'```7````I\<``!L```"_QP``#@``
M`-O'```"````ZL<``$D```#MQP``!0```#?(```0````/<@```\```!.R```
M!````%[(```-````8\@```X```!QR````P```(#(```.````A,@```@```"3
MR```#P```)S(```/````K,@```<```"\R```#0```,3(```0````TL@```T`
M``#CR```"P```/'(```&````_<@```L````$R0``#````!#)```*````'<D`
M`!$````HR0``&0```#K)```+````5,D```T```!@R0``(@```&[)```/````
MD<D``!L```"AR0``-````+W)```*````\LD``!@```#]R0``$@```!;*```9
M````*<H``!8```!#R@``(@```%K*```-````?<H```<```"+R@``%````)/*
M```+````J,H``"(```"TR@``+P```-?*```+````!\L```D````3RP``&0``
M`!W+```+````-\L``!<```!#RP``%P```%O+```)````<\L``!8```!]RP``
M#P```)3+```9````I,L``!8```"^RP``#@```-7+```8````Y,L```@```#]
MRP``#0````;,```F````%,P``$,````[S```"````'_,```2````B,P``!\`
M``";S```"````+O,```+````Q,P``"\```#0S```#@````#-```%````#\T`
M``8````5S0``10```!S-```#````8LT```<```!FS0``!````&[-```*````
M<\T```H```!^S0``#P```(G-```0````F<T``!<```"JS0``$0```,+-```9
M````U,T``!<```#NS0``"0````;.```%````$,X```L````6S@``"@```"+.
M```"````+<X```4````PS@``#0```#;.```;````1,X``!<```!@S@``%```
M`'C.```)````C<X```X```"7S@``#0```*;.```2````M,X``#@```#'S@``
M(`````#/```(````(<\```X````JSP``>P```#G/```8````M<\``!@```#.
MSP``$0```.?/```'````^<\```4````!T```&`````?0```>````(-```!L`
M```_T```&0```%O0```;````==```!D```"1T```$P```*O0```'````O]``
M``@```#'T```!@```-#0```&````U]```!````#>T```#P```._0```0````
M_]````\````0T0``"P```"#1```/````+-$```P````\T0``#P```$G1```'
M````6=$```8```!AT0``#@```&C1```,````=]$``"@```"$T0``#P```*W1
M```(````O=$```@```#&T0``$P```,_1```>````X]$``"$````"T@``(```
M`"32```9````1=(``!<```!?T@``)0```'?2```7````G=(``!8```"UT@``
M!````,S2```;````T=(```T```#MT@``#````/O2```#````"-,```4````,
MTP``"````!+3```*````&],```P````FTP``"P```#/3```0````/],```P`
M``!0TP``#@```%W3```+````;-,```0```!XTP``!````'W3```3````@M,`
M`!0```"6TP``#````*O3```)````N-,```X```#"TP``"P```-'3```;````
MW=,```<```#YTP``!P````'4```*````"=0```T````4U```"0```"+4```$
M````+-0```4````QU````P```#?4```8````.]0```H```!4U```!````%_4
M```F````9-0```X```"+U```?````)K4```5````%]4```4````MU0``!P``
M`#/5```,````.]4```@```!(U0``"@```%'5```&````7-4```@```!CU0``
M`@```&S5```&````;]4```8```!VU0``%````'W5```-````DM4``!````"@
MU0``&P```+'5```$````S=4```D```#2U0``$````-S5```)````[=4```D`
M``#WU0``!0````'6```:````!]8```@````BU@``!@```"O6```9````,M8`
M``X```!,U@``!P```%O6```'````8]8```4```!KU@``"0```''6```*````
M>]8```X```"&U@```@```)76```&````F-8```L```"?U@``#0```*O6```)
M````N=8```8```##U@``$@```,K6```)````W=8```<```#GU@``%````._6
M```=````!-<``$(````BUP``)0```&77```E````B]<```8```"QUP``"@``
M`+C7```$````P]<```D```#(UP``"````-+7```1````V]<```D```#MUP``
M!@```/?7```-````_M<```8````,V```!````!/8```Y````&-@``#T```!2
MV```.@```)#8```>````R]@```4```#JV```#@```/#8```$````_]@```8`
M```$V0``!P````O9```A````$]D```T````UV0``%0```$/9```&````6=D`
M``0```!@V0``$0```&79```&````=]D```H```!^V0``(@```(G9```$````
MK-D```4```"QV0``'0```+?9```$````U=D```P```#:V0``#@```.?9```*
M````]MD```@````!V@``"0````K:```%````%-H``#H````:V@``,````%7:
M```U````AMH``"D```"\V@``1P```.;:```X````+ML``"D```!GVP``/P``
M`)';```N````T=L``"T`````W```'P```"[<```/````3MP``!(```!>W```
M"P```''<```F````?=P``"D```"DW```)````,[<```F````\]P```@````:
MW0``"@```"/=```)````+MT```<````XW0``(````$#=```@````8=T``"8`
M``""W0``"@```*G=```9````M-T``"D```#.W0``%@```/C=```2````#]X`
M``<````BW@``"@```"K>```,````-=X```\```!"W@``$````%+>``!`````
M8]X``'````"DW@``9@```!7?```.````?-\```D```"+WP``"@```)7?```2
M````H-\``!,```"SWP``#````,??```&````U-\```\```#;WP``$@```.O?
M```0````_M\``!$````/X```'````"'@```C````/N```&H```!BX```#P``
M`,W@```%````W>```!````#CX```"0```/3@```$````_N````L````#X0``
M(`````_A```4````,.$```P```!%X0``#````%+A```/````7^$``!4```!O
MX0``*0```(7A```J````K^$``"8```#:X0``)P````'B```I````*>(``"H`
M``!3X@``&0```'[B``!"````F.(``!$```#;X@``$@```.WB```3`````.,`
M`!0````4XP``#P```"GC```6````.>,``!<```!0XP``$````&CC```1````
M>>,``#0```"+XP``$P```,#C```2````U.,``#4```#GXP``%````!WD```'
M````,N0```P````ZY```(````$?D```0````:.0``!0```!YY```$0```([D
M```7````H.0``!P```"XY```$P```-7D```4````Z>0``!H```#^Y```$0``
M`!GE```:````*^4``!X```!&Y0``&@```&7E```3````@.4``!4```"4Y0``
M$0```*KE```7````O.4``!0```#4Y0``%P```.GE```5`````>8```D````7
MY@``$````"'F```9````,N8```0```!,Y@``!P```%'F```+````6>8``!$`
M``!EY@``!@```'?F```&````?N8```8```"%Y@``!0```(SF```'````DN8`
M``<```":Y@``!0```*+F```6````J.8```8```"_Y@``!@```,;F```$````
MS>8```0```#2Y@``!P```-?F```.````W^8```P```#NY@``#````/OF```-
M````".<```H````6YP``#@```"'G```%````,.<``"@````VYP``#@```%_G
M```,````;N<```\```![YP``"@```(OG```(````EN<```D```"?YP``*P``
M`*GG```$````U><```@```#:YP``)@```./G```2````"N@```\````=Z```
M!@```"WH```*````-.@```<````_Z```"````$?H```@````4.@```D```!Q
MZ```%````'OH```,````D.@```T```"=Z```#@```*OH```6````NN@``!$`
M``#1Z```!@```./H```#````ZN@```8```#NZ```&0```/7H```'````#^D`
M``0````7Z0``"P```!SI```+````*.D```<````TZ0``!0```#SI```'````
M0ND``!8```!*Z0``#0```&'I```-````;^D```H```!]Z0``$````(CI```/
M````F>D``!$```"IZ0``%P```+OI```*````T^D``!$```#>Z0``"````/#I
M```$````^>D```\```#^Z0``.@````[J```%````2>H```P```!/Z@``'@``
M`%SJ```.````>^H``!````"*Z@``"P```)OJ```,````I^H```D```"TZ@``
M!P```+[J```*````QNH```D```#1Z@``#@```-OJ```0````ZNH``!L```#[
MZ@``&````!?K```:````,.L```H```!+ZP``"0```%;K```*````8.L```P`
M``!KZP``#P```'CK```(````B.L```8```"1ZP``'````)CK```'````M>L`
M``4```"]ZP``"P```,/K``!'````S^L```T````7[```"0```"7L```$````
M+^P```,````T[```$P```#CL```3````3.P``!,```!@[```"@```'3L```"
M````?^P```0```""[```)0```(?L```#````K>P```4```"Q[```*@```+?L
M```*````XNP```4```#M[```!````//L```*````^.P```T````#[0``!@``
M`!'M```(````&.T```@````A[0``!````"KM```%````+^T``&@````U[0``
M"0```)[M```,````J.T``!````"U[0``!0```,;M```&````S.T``!L```#3
M[0``+P```._M```0````'^X```H````P[@``#P```#ON```*````2^X```D`
M``!6[@``$P```&#N```;````=.X``!@```"0[@``%P```*GN```?````P>X`
M``X```#A[@```P```/#N```'````].X```@```#\[@``!P````7O```*````
M#>\```L````8[P``!P```"3O``!1````+.\``!````!^[P``#````(_O```-
M````G.\``!H```"J[P``2@```,7O```9````$/````8````J\```&@```#'P
M```E````3/````8```!R\```!@```'GP```?````@/````8```"@\```"0``
M`*?P```8````L?```!<```#*\```*````.+P```&````"_$```T````2\0``
M(@```"#Q``!7````0_$``!,```";\0``(P```*_Q```3````T_$```(```#G
M\0``"P```.KQ```(````]O$```T```#_\0``"@````WR```'````&/(``!0`
M```@\@``!@```#7R```(````//(```X```!%\@``!P```%3R```*````7/(`
M``L```!G\@``,@```'/R```'````IO(```P```"N\@``#0```+OR```7````
MR?(```P```#A\@``"0```.[R```)````^/(```H````"\P``!P````WS```)
M````%?,```<````?\P``"@```"?S```;````,O,```\```!.\P``$@```%[S
M```*````<?,``!8```!\\P``"0```)/S```0````G?,```<```"N\P``$@``
M`+;S```$````R?,```<```#.\P``!0```-;S```%````W/,```L```#B\P``
M%````.[S```1`````_0``!H````5]```%@```##T```4````1_0``!<```!<
M]```&````'3T```<````C?0``!D```"J]```!P```,3T```%````S/0```T`
M``#2]```#````.#T```(````[?0``!<```#V]```"P````[U```,````&O4`
M`!\````G]0``&@```$?U```3````8O4```0```!V]0``"@```'OU```$````
MAO4```T```"+]0``#````)GU```%````IO4```D```"L]0``!0```+;U```'
M````O/4```4```#$]0``!````,KU```"````S_4``#@```#2]0``+`````OV
M```2````./8``"D```!+]@``,@```'7V```*````J/8``"P```"S]@``+@``
M`.#V```S````#_<``#,```!#]P``.````'?W```/````L/<``!@```#`]P``
M$````-GW```/````ZO<``!,```#Z]P``%0````[X```4````)/@``!(````Y
M^```%````$SX```5````8?@``"T```!W^```+0```*7X```Q````T_@``"X`
M```%^0``+P```#3Y```L````9/D``&(```"1^0``$P```/3Y```-````"/H`
M``@````6^@``%P```!_Z```(````-_H```P```!`^@``*P```$WZ```A````
M>?H``!H```";^@``"0```+;Z``!%````P/H``$$````&^P``!````$C[```3
M````3?L``!0```!A^P``#@```';[```3````A?L``!@```"9^P``!@```++[
M```)````N?L```H```##^P``#P```,[[```0````WOL```<```#O^P``#@``
M`/?[```%````!OP``!L````,_```"````"C\```&````,?P``!0````X_```
M$0```$W\```.````7_P``#@```!N_````@```*?\```&````JOP```X```"Q
M_```!0```,#\```'````QOP```X```#._```!@```-W\```H````Y/P```P`
M```-_0``'````!K]```$````-_T``"D````\_0``%P```&;]```?````?OT`
M`%P```">_0``%````/O]```^````$/X``!\```!/_@``$````&_^```'````
M@/X```X```"(_@``#````)?^```,````I/X``!,```"Q_@``"@```,7^```=
M````T/X``!D```#N_@``!0````C_```1````#O\``!$````@_P``)````#+_
M```2````5_\``!4```!J_P``$@```(#_```.````D_\``!D```"B_P``"```
M`+S_```)````Q?\```T```#/_P``!P```-W_```*````Y?\```<```#P_P``
M#P```/C_```&````"``!``L````/``$`&@```!L``0`*````-@`!``<```!!
M``$`"````$D``0`%````4@`!`!\```!8``$`!@```'@``0`0````?P`!``@`
M``"0``$`#0```)D``0`(````IP`!`!X```"P``$`$@```,\``0`L````X@`!
M`!H````/`0$`"0```"H!`0`*````-`$!`!4````_`0$`!0```%4!`0`4````
M6P$!``0```!P`0$`$````'4!`0`&````A@$!``<```"-`0$`'@```)4!`0`H
M````M`$!``H```#=`0$`'````.@!`0`1````!0(!``L````7`@$`&@```","
M`0`4````/@(!``0```!3`@$`!````%@"`0`+````70(!``4```!I`@$`!@``
M`&\"`0`(````=@(!``8```!_`@$`"@```(8"`0`;````D0(!`#0```"M`@$`
M-````.("`0`@````%P,!`"D````X`P$`(````&(#`0!!````@P,!`!H```#%
M`P$`*````.`#`0`I````"00!`%`````S!`$`(@```(0$`0`&````IP0!``@`
M``"N!`$`!0```+<$`0`(````O00!`!D```#&!`$`&0```.`$`0`J````^@0!
M`",````E!0$`&0```$D%`0`N````8P4!`#0```"2!0$`"````,<%`0`7````
MT`4!``H```#H!0$`!P```/,%`0`A````^P4!`!`````=!@$`#@```"X&`0`+
M````/08!``<```!)!@$`$P```%$&`0`(````908!``L```!N!@$`"@```'H&
M`0`4````A08!``\```":!@$`,@```*H&`0`+````W08!``X```#I!@$`!0``
M`/@&`0`%````_@8!``4````$!P$`%P````H'`0`/````(@<!``0````R!P$`
M"@```#<'`0`)````0@<!``L```!,!P$`#0```%@'`0`,````9@<!``X```!S
M!P$`!0```(('`0`$````B`<!``T```"-!P$`,@```)L'`0!%````S@<!`!<`
M```4"`$`!P```"P(`0`>````-`@!`!0```!3"`$`!0```&@(`0`4````;@@!
M``8```"#"`$`!P```(H(`0`.````D@@!`"H```"A"`$`!@```,P(`0`,````
MTP@!``T```#@"`$`$0```.X(`0`+``````D!`#8````,"0$`"@```$,)`0`B
M````3@D!``L```!Q"0$`#P```'T)`0`R````C0D!`"4```#`"0$`,````.8)
M`0`Q````%PH!`"T```!)"@$`#@```'<*`0`%````A@H!``X```","@$`$P``
M`)L*`0`2````KPH!``<```#""@$`$0```,H*`0`3````W`H!``<```#P"@$`
M%````/@*`0`8````#0L!``<````F"P$`!0```"X+`0`,````-`L!``P```!!
M"P$`$@```$X+`0`$````80L!``<```!F"P$`"@```&X+`0`+````>0L!``P`
M``"%"P$`#@```)(+`0`.````H0L!``4```"P"P$`!0```+8+`0`N````O`L!
M`"8```#K"P$`(P```!(,`0`#````-@P!`!(````Z#`$`!@```$T,`0`>````
M5`P!`!@```!S#`$`)0```(P,`0`-````L@P!``D```#`#`$`'P```,H,`0`#
M````Z@P!``<```#N#`$`"@```/8,`0`"`````0T!``P````$#0$`%0```!$-
M`0`+````)PT!`!D````S#0$`(````$T-`0`2````;@T!``4```"!#0$`"@``
M`(<-`0`5````D@T!`!(```"H#0$`#````+L-`0`$````R`T!``D```#-#0$`
M!P```-<-`0`,````WPT!`%(```#L#0$`%P```#\.`0`D````5PX!`!(```!\
M#@$`!P```(\.`0`&````EPX!``X```">#@$`#````*T.`0`-````N@X!`!4`
M``#(#@$`$@```-X.`0`/````\0X!`!0````!#P$`"@```!8/`0`;````(0\!
M`!`````]#P$`"P```$X/`0!I````6@\!`!H```#$#P$`%P```-\/`0`G````
M]P\!`!H````?$`$`%P```#H0`0`;````4A`!`!D```!N$`$`'P```(@0`0`3
M````J!`!``@```"\$`$`!P```,40`0`(````S1`!``D```#6$`$`%0```.`0
M`0`-````]A`!`",````$$0$`#0```"@1`0`3````-A$!``@```!*$0$``P``
M`%,1`0!&````5Q$!`#\```">$0$`-P```-X1`0!7````%A(!``4```!N$@$`
M'P```'02`0`O````E!(!``H```#$$@$`"````,\2`0`-````V!(!`"T```#F
M$@$`!````!03`0!/````&1,!`"4```!I$P$`'````(\3`0`+````K!,!`!\`
M``"X$P$`'0```-@3`0`E````]A,!`"`````<%`$`)````#T4`0`@````8A0!
M``L```"#%`$`!P```(\4`0`-````EQ0!``P```"E%`$`%P```+(4`0`&````
MRA0!`#D```#1%`$`#`````L5`0`'````&!4!``D````@%0$`$P```"H5`0`)
M````/A4!``0```!(%0$`$````$T5`0`(````7A4!``@```!G%0$`!````'`5
M`0`+````=14!``P```"!%0$`$@```(X5`0`1````H14!``P```"S%0$`&@``
M`,`5`0`/````VQ4!``<```#K%0$`#0```/,5`0`4`````18!``X````6%@$`
M#````"46`0`;````,A8!`"P```!.%@$`$P```'L6`0`<````CQ8!`"@```"L
M%@$`!@```-46`0`'````W!8!`!,```#D%@$`!0```/@6`0`$````_A8!`!<`
M```#%P$`"@```!L7`0`,````)A<!``D````S%P$`!@```#T7`0`)````1!<!
M``@```!.%P$`"0```%<7`0`*````81<!`!$```!L%P$`!@```'X7`0`.````
MA1<!``X```"4%P$`#0```*,7`0`+````L1<!`!T```"]%P$`"P```-L7`0`"
M````YQ<!`!P```#J%P$`!P````<8`0`&````#Q@!`&0````6&`$`"0```'L8
M`0`'````A1@!`"8```"-&`$`.````+08`0`:````[1@!`"H````(&0$`.P``
M`#,9`0`H````;QD!`#0```"8&0$`&0```,T9`0`5````YQD!``4```#]&0$`
M!P````,:`0`(````"QH!``<````4&@$`!0```!P:`0`'````(AH!``X````J
M&@$`"0```#D:`0`&````0QH!``@```!*&@$`"P```%,:`0`'````7QH!``@`
M``!G&@$`!P```'`:`0`6````>!H!``D```"/&@$`!@```)D:`0`+````H!H!
M`!````"L&@$`!@```+T:`0`<````Q!H!`!0```#A&@$`!P```/8:`0`1````
M_AH!``@````0&P$`#@```!D;`0`(````*!L!`!`````Q&P$`"0```$(;`0`0
M````3!L!``8```!=&P$`&0```&0;`0`*````?AL!`!P```")&P$`!P```*8;
M`0`%````KAL!`!````"T&P$`%````,4;`0`+````VAL!``T```#F&P$`*```
M`/0;`0`8````'1P!`!<````V'`$`!````$X<`0`)````4QP!``H```!='`$`
M!P```&@<`0`"````<!P!``X```!S'`$`"````((<`0`C````BQP!`!\```"O
M'`$`.````,\<`0`F````"!T!`#$````O'0$`)P```&$=`0!D````B1T!`!0`
M``#N'0$`50````,>`0`X````61X!`$H```"2'@$`6P```-T>`0`H````.1\!
M`#@```!B'P$`*````)L?`0`L````Q!\!`"8```#Q'P$`&P```!@@`0`^````
M-"`!`*D!``!S(`$`(P```!TB`0`7````02(!`$@```!9(@$`A0```*(B`0`P
M````*",!`"4```!9(P$`00```'\C`0!;````P2,!`$D````=)`$`,0```&<D
M`0`=````F20!`!@```"W)`$`*P```-`D`0`A````_"0!`!\````>)0$`*P``
M`#XE`0`F````:B4!`"<```"1)0$`.@```+DE`0`=````]"4!`!$````2)@$`
M,P```"0F`0`E````6"8!`"<```!^)@$`(````*8F`0`?````QR8!`#````#G
M)@$`:0```!@G`0`Q````@B<!`$$```"T)P$`,P```/8G`0`E````*B@!`#T`
M``!0*`$`90```(XH`0!-````]"@!`"\```!"*0$`+@```'(I`0`P````H2D!
M`%0```#2*0$`6@```"<J`0!(````@BH!`$H```#+*@$`,@```!8K`0`O````
M22L!`"P```!Y*P$`+0```*8K`0!Q````U"L!`&8```!&+`$`;P```*TL`0"S
M````'2T!`!<```#1+0$`)0```.DM`0`R````#RX!`"D```!"+@$`/@```&PN
M`0`B````JRX!`%(```#.+@$`)0```"$O`0`+````1R\!`+$```!3+P$`10``
M``4P`0`A````2S`!`#````!M,`$`)0```)XP`0`<````Q#`!`#$```#A,`$`
M!P```!,Q`0`'````&S$!``0````C,0$`#0```"@Q`0`+````-C$!``X```!"
M,0$`"P```%$Q`0`%````73$!`!````!C,0$``@```'0Q`0!9````=S$!``4`
M``#1,0$`$@```-<Q`0`$````ZC$!``<```#O,0$`"````/<Q`0`%`````#(!
M`#`````&,@$``P```#<R`0`0````.S(!``P```!,,@$`$P```%DR`0`-````
M;3(!``(```![,@$`!P```'XR`0`&````AC(!`!0```"-,@$`#````*(R`0`8
M````KS(!``8```#(,@$`$@```,\R`0`,````XC(!``,```#O,@$`*@```/,R
M`0`$````'C,!``8````C,P$`!P```"HS`0`?````,C,!`#4```!2,P$`+@``
M`(@S`0`O````MS,!`!<```#G,P$`(@```/\S`0`E````(C0!`"````!(-`$`
M&P```&DT`0`8````A30!`"0```">-`$`'P```,,T`0`:````XS0!`"$```#^
M-`$`(````"`U`0`:````034!`#(```!<-0$`&@```(\U`0`O````JC4!`"L`
M``#:-0$`'P````8V`0`C````)C8!`!\```!*-@$`&@```&HV`0`A````A38!
M`"4```"G-@$`)@```,TV`0`E````]#8!`"0````:-P$`&````#\W`0`=````
M6#<!`"0```!V-P$`&````)LW`0`B````M#<!`"P```#7-P$`+P````0X`0`5
M````-#@!`"4```!*.`$`/````'`X`0`?````K3@!`",```#-.`$`'P```/$X
M`0`@````$3D!`!H````R.0$`&````$TY`0`F````9CD!`!X```"-.0$`*0``
M`*PY`0`>````UCD!`#$```#U.0$`"0```"<Z`0`,````,3H!`!<````^.@$`
M+P```%8Z`0`D````ACH!``<```"K.@$`#P```+,Z`0`4````PSH!``X```#8
M.@$`#0```.<Z`0`D````]3H!``4````:.P$`!P```"`[`0`B````*#L!`"4`
M``!+.P$`&@```'$[`0`=````C#L!`!H```"J.P$`!P```,4[`0#'````S3L!
M``L```"5/`$`%0```*$\`0`&````MSP!``D```"^/`$`"P```,@\`0`-````
MU#P!`!<```#B/`$`!@```/H\`0`S`````3T!`!,````U/0$`$P```$D]`0`'
M````73T!``\```!E/0$`!P```'4]`0`R````?3T!``0```"P/0$`(0```+4]
M`0`3````UST!``P```#K/0$`$0```/@]`0`R````"CX!`!8````]/@$`"```
M`%0^`0`=````73X!``D```![/@$`"@```(4^`0`4````D#X!``H```"E/@$`
M'0```+`^`0`(````SCX!`!\```#7/@$`"````/<^`0`:`````#\!`"<````;
M/P$`!@```$,_`0`5````2C\!``<```!@/P$`"````&@_`0`)````<3\!`#\`
M``![/P$`!P```+L_`0`/````PS\!``X```#3/P$`$````.(_`0`)````\S\!
M``D```#]/P$`"`````=``0`3````$$`!``<````D0`$`&0```"Q``0`*````
M1D`!`!<```!10`$`%````&E``0`*````?D`!``P```")0`$`%P```)9``0`$
M````KD`!`"H```"S0`$`#````-Y``0`1````ZT`!``<```#]0`$``@````5!
M`0`0````"$$!`!@````900$`"P```#)!`0`#````/D$!``@```!"00$`!@``
M`$M!`0`'````4D$!``T```!:00$`"P```&A!`0`4````=$$!`!4```")00$`
M#@```)]!`0`O````KD$!`"````#>00$`'````/]!`0`5````'$(!``P````R
M0@$`,0```#]"`0`%````<4(!`!(```!W0@$`/P```(I"`0`2````RD(!``H`
M``#=0@$`!@```.A"`0`$````[T(!``0```#T0@$`"@```/E"`0`3````!$,!
M``4````80P$`!@```!Y#`0`&````)4,!``@````L0P$`!````#5#`0`,````
M.D,!``H```!'0P$`.0```%)#`0`N````C$,!`"D```"[0P$`!0```.5#`0`8
M````ZT,!`!D````$1`$`'P```!Y$`0`=````/D0!`!$```!<1`$``@```&Y$
M`0`$````<40!``H```!V1`$`!@```(%$`0`%````B$0!``,```".1`$`#```
M`))$`0!%````GT0!`#(```#E1`$`&@```!A%`0`T````,T4!`"@```!H10$`
M4P```)%%`0`9````Y44!`'(```#_10$`(````')&`0`U````DT8!`"$```#)
M1@$`10```.M&`0`P````,4<!`"@```!B1P$`*0```(M'`0`F````M4<!`"4`
M``#<1P$`*`````)(`0`H````*T@!`"(```!42`$`*P```'=(`0`P````HT@!
M`!(```#42`$`$P```.=(`0`0````^T@!`'D````,20$`"0```(9)`0"A````
MD$D!`',````R2@$`?````*9*`0`K````(TL!`%0```!/2P$`%P```*1+`0`G
M````O$L!`!8```#D2P$`#P```/M+`0`7````"TP!`!\````C3`$`0````$-,
M`0`?````A$P!`!P```"D3`$`40```,%,`0`:````$TT!`!0````N30$`"@``
M`$--`0`%````3DT!``8```!430$`"````%M-`0`%````9$T!`!(```!J30$`
M$````'U-`0`3````CDT!`!T```"B30$`#P```,!-`0`/````T$T!``0```#@
M30$`"0```.5-`0`+````[TT!``<```#[30$`!0````-.`0`4````"4X!``<`
M```>3@$`"````"9.`0`/````+TX!``@````_3@$`#````$A.`0`/````54X!
M``8```!E3@$`%````&Q.`0`&````@4X!``P```"(3@$`$0```)5.`0`(````
MITX!``0```"P3@$`&0```+5.`0`1````STX!``H```#A3@$`&````.Q.`0`3
M````!4\!`!P````93P$`$0```#9/`0`$````2$\!``\```!-3P$`!P```%U/
M`0`$````94\!`!D```!J3P$`!P```(1/`0`"````C$\!``(```"/3P$`$0``
M`))/`0`)````I$\!``8```"N3P$`$@```+5/`0`7````R$\!``8```#@3P$`
M)P```.=/`0`"````#U`!``0````24`$`#P```!=0`0`3````)U`!``<````[
M4`$`!P```$-0`0`1````2U`!``8```!=4`$`&````&10`0`&````?5`!`!,`
M``"$4`$`$````)A0`0`2````J5`!``(```"\4`$`!@```+]0`0`,````QE`!
M``D```#34`$`$0```-U0`0`B````[U`!``<````240$`!P```!I1`0`+````
M(E$!``4````N40$``@```#11`0`+````-U$!`&4!``!#40$`$P```*E2`0`/
M````O5(!`!(```#-4@$`"@```.!2`0`)````ZU(!``L```#U4@$`!`````%3
M`0`7````!E,!`!L````>4P$`,@```#I3`0`B````;5,!`"<```"04P$`)P``
M`+A3`0`<````X%,!`"X```#]4P$`"P```"Q4`0`C````.%0!`!,```!<5`$`
M#@```'!4`0`/````?U0!``4```"/5`$`*````)54`0`,````OE0!``X```#+
M5`$`&0```-I4`0`.````]%0!``L````#50$`CP````]5`0`-````GU4!``H`
M``"M50$`$0```+A5`0`0````RE4!``X```#;50$`"P```.I5`0`0````]E4!
M``\````'5@$`!@```!=6`0"R````'E8!``T```#15@$`$@```-]6`0`8````
M\E8!`!`````+5P$`#P```!Q7`0`/````+%<!``<````\5P$`!P```$17`0`N
M````3%<!`"@```![5P$`/@```*17`0!-````XU<!`&@````Q6`$`:P```)I8
M`0!N````!ED!`'$```!U60$`0````.=9`0`8````*%H!`!L```!!6@$`%```
M`%U:`0`4````<EH!`!H```"'6@$`!0```*):`0`&````J%H!`!````"O6@$`
M!P```,!:`0`)````R%H!``D```#26@$`,@```-Q:`0`P````#UL!`!$```!`
M6P$`$0```%);`0`1````9%L!``X```!V6P$`"0```(5;`0`5````CUL!`!4`
M``"E6P$`#P```+M;`0`6````RUL!`!4```#B6P$`(P```/A;`0`C````'%P!
M`!L```!`7`$`#P```%Q<`0`6````;%P!``X```"#7`$`+0```))<`0`7````
MP%P!`!L```#87`$`$P```/1<`0!;````"%T!`#4```!D70$`*@```)I=`0`%
M````Q5T!``D```#+70$`,0```-5=`0`&````!UX!``P````.7@$`"@```!M>
M`0`'````)EX!``@````N7@$`!0```#=>`0`)````/5X!``L```!'7@$`!```
M`%->`0`@````6%X!``P```!Y7@$`#````(9>`0`0````DUX!`!H```"D7@$`
M+````+]>`0`*````[%X!`!P```#W7@$`&P```!1?`0`@````,%\!`!<```!1
M7P$`%@```&E?`0`3````@%\!`!````"47P$`'P```*5?`0`K````Q5\!``<`
M``#Q7P$`!@```/E?`0`(`````&`!``X````)8`$`"````!A@`0`*````(6`!
M`!(````L8`$`"@```#]@`0`1````2F`!`!4```!<8`$`&````')@`0`*````
MBV`!`!$```"68`$`!0```*A@`0`7````KF`!`!8```#&8`$`"P```-U@`0!"
M````Z6`!`#P````L80$`"@```&EA`0`'````=&$!`!,```!\80$`!0```)!A
M`0`%````EF$!`!````"<80$`"P```*UA`0`5````N6$!`$4```#/80$`$0``
M`!5B`0`R````)V(!`#$```!:8@$`+@```(QB`0`O````NV(!``H```#K8@$`
M"````/9B`0`)````_V(!``H````)8P$`,@```!1C`0`X````1V,!`#$```"`
M8P$`5P```+)C`0`P````"F0!`#`````[9`$`4````&QD`0!2````O60!`#``
M```090$`1@```$%E`0`T````B&4!`#,```"]90$`40```/%E`0`P````0V8!
M`#8```!T9@$`)0```*MF`0`5````T68!`!D```#G9@$`+@````%G`0`D````
M,&<!`"<```!59P$`$P```'UG`0`,````D6<!``P```">9P$`"P```*MG`0`0
M````MV<!`!@```#(9P$`'0```.%G`0`'````_V<!``<````':`$`%@````]H
M`0`*````)F@!``@````Q:`$`+P```#IH`0`)````:F@!``L```!T:`$`!@``
M`(!H`0`&````AV@!``4```".:`$`!P```)1H`0`&````G&@!``H```"C:`$`
M+````*YH`0`0````VV@!``@```#L:`$``P```/5H`0`'````^6@!``D````!
M:0$`!`````MI`0`*````$&D!``8````;:0$`%0```")I`0`&````.&D!``@`
M```_:0$`"0```$AI`0`-````4FD!``@```!@:0$`(0```&EI`0`1````BVD!
M``D```"=:0$`$0```*=I`0`,````N6D!``<```#&:0$``P```,YI`0`#````
MTFD!`!4```#6:0$`%````.QI`0`E`````6H!``8````G:@$`!````"YJ`0`(
M````,VH!``@````\:@$`4@```$5J`0`D````F&H!`"<```"]:@$`)@```.5J
M`0`=````#&L!``8````J:P$`"````#%K`0`8````.FL!`"(```!3:P$`)0``
M`'9K`0`P````G&L!`"0```#-:P$`*@```/)K`0!Z````'6P!`#4```"8;`$`
M"@```,YL`0`)````V6P!``8```#C;`$`%0```.IL`0`/`````&T!``T````0
M;0$`$````!YM`0`1````+VT!`!````!!;0$`#@```%)M`0`-````86T!`!8`
M``!O;0$`!@```(9M`0`=````C6T!`!X```"K;0$`$@```,IM`0`3````W6T!
M`!$```#Q;0$`!@````-N`0`(````"FX!`!0````3;@$`80```"AN`0!X````
MBFX!``@````#;P$`$P````QO`0`%````(&\!``4````F;P$`'@```"QO`0`;
M````2V\!`!````!G;P$`$P```'AO`0`7````C&\!`!,```"D;P$`+````+AO
M`0`0````Y6\!`"0```#V;P$`!@```!MP`0`4````(G`!``D````W<`$`$0``
M`$%P`0`-````4W`!`!(```!A<`$`$````'1P`0`6````A7`!`!,```"<<`$`
M#````+!P`0`&````O7`!`!````#$<`$`!P```-5P`0`8````W7`!`!$```#V
M<`$`$0````AQ`0`(````&G$!``4````C<0$`#0```"EQ`0`-````-W$!``D`
M``!%<0$`"P```$]Q`0`&````6W$!``@```!B<0$`#0```&MQ`0`)````>7$!
M``T```"#<0$`!P```)%Q`0`'````F7$!``D```"A<0$`"````*MQ`0`)````
MM'$!`!L```"^<0$`1P```-IQ`0`:````(G(!``\````]<@$`$P```$UR`0`%
M````87(!`"@```!G<@$`$P```)!R`0`4````I'(!`#@```"Y<@$`1P```/)R
M`0`B````.G,!``@```!=<P$`-0```&9S`0`H````G',!``\```#%<P$`"```
M`-5S`0`-````WG,!``8```#L<P$`"````/-S`0`4````_',!`!`````1=`$`
M"0```")T`0`*````+'0!``D````W=`$`'@```$%T`0`C````8'0!`"````"$
M=`$`)0```*5T`0`<````RW0!`"T```#H=`$`'P```!9U`0`C````-G4!`"X`
M``!:=0$`(P```(EU`0`=````K74!`!\```#+=0$`'@```.MU`0`I````"G8!
M`"\````T=@$`,@```&1V`0`D````EW8!`"L```"\=@$`-P```.AV`0`>````
M('<!`!X````_=P$`/0```%YW`0`D````G'<!`!,```#!=P$`*````-5W`0`?
M````_G<!`"$````>>`$`$@```$!X`0#$````4W@!`!0````8>0$`'@```"UY
M`0`E````3'D!`"<```!R>0$`(P```)IY`0`B````OGD!`"0```#A>0$`(0``
M``9Z`0`D````*'H!`"<```!->@$`,````'5Z`0`R````IGH!`*8```#9>@$`
M(P```(![`0`:````I'L!`!P```"_>P$`)P```-Q[`0`P````!'P!`$<````U
M?`$`1````'U\`0`-````PGP!``0```#0?`$`"0```-5\`0`%````WWP!``T`
M``#E?`$`#P```/-\`0`.`````WT!``\````2?0$`$````")]`0`'````,WT!
M``0````[?0$`#P```$!]`0`/````4'T!``P```!@?0$`#@```&U]`0`2````
M?'T!``L```"/?0$`$@```)M]`0`-````KGT!`"X```"\?0$`!P```.M]`0`0
M````\WT!``8````$?@$`$P````M^`0`9````'WX!`!L````Y?@$`%0```%5^
M`0`"````:WX!`$D```!N?@$`"0```+A^`0`0````PGX!`!,```#3?@$`!0``
M`.=^`0`/````[7X!``X```#]?@$``P````Q_`0`0````$'\!``@````A?P$`
M$0```"I_`0`5````/'\!``D```!2?P$`#P```%Q_`0`4````;'\!``\```"!
M?P$`"@```)%_`0`+````G'\!``T```"H?P$`$0```+9_`0`-````R'\!`!$`
M``#6?P$`&@```.A_`0`-`````X`!``\````1@`$`*0```"&``0`3````2X`!
M`!P```!?@`$`-@```'R``0`-````LX`!`"0```#!@`$`$P```.:``0`:````
M^H`!`!@````5@0$`)0```"Z!`0`+````5($!``H```!@@0$`%@```&N!`0`,
M````@H$!`"0```"/@0$`+0```+2!`0`,````XH$!``@```#O@0$`(0```/B!
M`0`*````&H(!`!D````E@@$`&@```#^"`0`)````6H(!`!4```!D@@$`#@``
M`'J"`0`F````B8(!`!T```"P@@$`#P```,Z"`0`9````WH(!``@```#X@@$`
M$`````&#`0`F````$H,!`#T````Y@P$`"````'>#`0`6````@(,!`!L```"7
M@P$`"@```+.#`0`-````OH,!`#(```#,@P$`#P```/^#`0`%````#X0!``8`
M```5A`$`4P```!R$`0`#````<(0!``<```!TA`$`"````'R$`0`-````A80!
M``X```"3A`$`#@```**$`0`0````L80!`!D```#"A`$`%0```-R$`0`9````
M\H0!`!<````,A0$`"0```"2%`0`&````+H4!``L````UA0$`"@```$&%`0`"
M````3(4!``8```!/A0$`"P```%:%`0`C````8H4!`!8```"&A0$`%P```)V%
M`0`)````M84!``T```"_A0$`#P```,V%`0`/````W84!`#X```#MA0$`)@``
M`"R&`0`(````4X8!``\```!<A@$`BP```&R&`0`>````^(8!`!T````7AP$`
M$@```#6'`0`'````2(<!``0```!0AP$`&P```%6'`0`G````<8<!`"4```"9
MAP$`'P```+^'`0`E````WX<!`!<````%B`$`'````!V(`0`'````.H@!``@`
M``!"B`$`!P```$N(`0`&````4X@!``\```!:B`$`#@```&J(`0`0````>8@!
M``X```"*B`$`#P```)F(`0`,````J8@!``L```"VB`$`$0```,*(`0`)````
MU(@!``H```#>B`$`$@```.F(`0`.````_(@!`"X````+B0$`"P```#J)`0`(
M````1HD!``X```!/B0$`%````%Z)`0`F````<XD!`"D```":B0$`*````,2)
M`0`=````[8D!`!X````+B@$`+````"J*`0`A````5XH!`!D```!YB@$`!```
M`).*`0`<````F(H!``\```"UB@$`#````,6*`0`#````THH!``4```#6B@$`
M"````-R*`0`)````Y8H!``L```#OB@$`#````/N*`0`1````"(L!``H````:
MBP$`#@```"6+`0`+````-(L!``0```!`BP$`!P```$6+`0`<````38L!`!X`
M``!JBP$`#0```(F+`0`,````EXL!``X```"DBP$`#0```+.+`0`G````P8L!
M``<```#IBP$`!P```/&+`0`,````^8L!``\````&C`$`%0```!:,`0`'````
M+(P!``<````TC`$`!````#R,`0`3````08P!``D```!5C`$`!P```%^,`0`P
M````9XP!`!<```"8C`$`@@```+",`0`7````,XT!``L```!+C0$`!P```%>-
M`0`+````7XT!``@```!KC0$`"@```'2-`0`&````?XT!``H```"&C0$``@``
M`)&-`0`&````E(T!``D```";C0$`&0```*6-`0`,````OXT!``\```#,C0$`
M'````-R-`0`#````^8T!``<```#]C0$`%@````6.`0`*````'(X!``X````G
MC@$`!0```#:.`0`S````/(X!``8```!PC@$`!@```'>.`0`8````?HX!`!$`
M``"7C@$`!P```*F.`0`)````L8X!``4```"[C@$`"0```,&.`0`(````RXX!
M``X```#4C@$``@```...`0`&````YHX!``X```#MC@$`#0```/R.`0`+````
M"H\!``L````6CP$`$P```"*/`0`)````-H\!``<```!`CP$`#````$B/`0`?
M````58\!`$,```!UCP$`,0```+F/`0`P````ZX\!``<````<D`$`"@```"20
M`0`$````+Y`!``D````TD`$`"````#Z0`0`,````1Y`!``H```!4D`$`!@``
M`%^0`0`-````9I`!``8```!TD`$`!````'N0`0!`````@)`!`$0```#!D`$`
M0@````:1`0`A````29$!``4```!KD0$`#P```'&1`0`%````@9$!``,```"'
MD0$`!@```(N1`0`A````DI$!`!````"TD0$`&````,61`0`&````WI$!``0`
M``#ED0$`&P```.J1`0`&````!I(!``@````-D@$`(@```!:2`0`$````.9(!
M``4````^D@$`%P```$22`0`$````7)(!``T```!AD@$`#0```&^2`0`/````
M?9(!``@```"-D@$`"0```):2`0`%````H)(!`#T```"FD@$`-@```.22`0`[
M````&Y,!`"H```!7DP$`.````(*3`0`Z````NY,!`"T```#VDP$`4@```"24
M`0`P````=Y0!`#D```"HE`$`*0```.*4`0`0````#)4!`!@````=E0$`#```
M`#:5`0`D````0Y4!`"0```!HE0$`(@```(V5`0`A````L)4!``L```#2E0$`
M#0```-Z5`0`*````[)4!``D```#WE0$`(@````&6`0`H````))8!`"@```!-
ME@$`"````':6`0`:````?Y8!`#,```":E@$`&````,Z6`0`2````YY8!``<`
M``#ZE@$`$P````*7`0`4````%I<!`!8````KEP$`$````$*7`0!1````4Y<!
M`)$```"EEP$`A````#>8`0`7````O)@!``X```#4F`$`#P```..8`0`4````
M\Y@!`!4````(F0$`$0```!Z9`0`,````,)D!`!,````]F0$`%0```%&9`0`5
M````9YD!``\```!]F0$`(@```(V9`0`I````L)D!`(T```#:F0$`%````&B:
M`0`%````?9H!`!8```"#F@$`"0```)J:`0`$````I)H!``H```"IF@$`(P``
M`+2:`0`1````V)H!`!,```#JF@$`#@```/Z:`0`0````#9L!`!0````>FP$`
M)P```#.;`0`I````6YL!`"4```"%FP$`)0```*N;`0`P````T9L!`#`````"
MG`$`'0```#.<`0!%````49P!``\```"7G`$`$0```*><`0`1````N9P!`!,`
M``#+G`$`$@```-^<`0`5````\IP!`!<````(G0$`#P```""=`0`1````,)T!
M`#D```!"G0$`'0```'R=`0`7````FIT!`#H```"RG0$`$P```.V=`0`'````
M`9X!``T````)G@$`(@```!>>`0`2````.IX!`!4```!-G@$`$@```&.>`0`9
M````=IX!`!D```"0G@$`%````*J>`0`:````OYX!`!P```#:G@$`$@```/>>
M`0`>````"I\!`"0````IGP$`%@```$Z?`0`4````99\!`!@```!ZGP$`$@``
M`).?`0`9````II\!`!<```#`GP$`$P```-B?`0`7````[)\!``H````$H`$`
M$`````^@`0`@````(*`!``0```!!H`$`!P```$:@`0`*````3J`!`!@```!9
MH`$`!@```'*@`0`(````>:`!``<```""H`$`!@```(J@`0`'````D:`!``<`
M``"9H`$`!0```*&@`0`4````IZ`!``8```"\H`$`"````,.@`0`$````S*`!
M``0```#1H`$`"0```-:@`0`5````X*`!`!(```#VH`$`#P````FA`0`0````
M&:$!``H````JH0$`$P```#6A`0`%````2:$!`"<```!/H0$`#@```'>A`0`-
M````AJ$!`!,```"4H0$`#0```*BA`0`+````MJ$!``X```#"H0$`,P```-&A
M`0`(````!:(!``@````.H@$`)P```!>B`0`4````/Z(!`!$```!4H@$`!P``
M`&:B`0`)````;J(!``<```!XH@$`!````("B`0`@````A:(!``T```"FH@$`
M&P```+2B`0`0````T*(!`!(```#AH@$`%@```/2B`0`=````"Z,!`!D````I
MHP$`!P```$.C`0`'````2Z,!``8```!3HP$`&````%JC`0`'````<Z,!``4`
M``![HP$`"@```(&C`0`.````C*,!``<```";HP$`!@```*.C`0`'````JJ,!
M`!T```"RHP$`#0```-"C`0`,````WJ,!``P```#KHP$`$@```/BC`0`,````
M"Z0!``\````8I`$`%P```"BD`0`-````0*0!`!````!.I`$`"````%^D`0`$
M````:*0!`!````!MI`$`00```'ZD`0`%````P*0!``P```#&I`$`(0```-.D
M`0`-````]:0!`!D````#I0$`"@```!VE`0`-````**4!``H````VI0$`"```
M`$&E`0`.````2J4!``H```!9I0$`$0```&2E`0`2````=J4!`"@```")I0$`
M+````+*E`0`O````WZ4!``H````/I@$`"````!JF`0`(````(Z8!``P````L
MI@$`%@```#FF`0`'````4*8!``D```!8I@$`'@```&*F`0`(````@:8!``D`
M``"*I@$`#````)2F`0!.````H:8!`!,```#PI@$`"P````2G`0`&````$*<!
M``0````7IP$`%@```!RG`0`7````,Z<!`!@```!+IP$`"0```&2G`0`"````
M;J<!``0```!QIP$`(@```':G`0`#````F:<!``4```"=IP$`,P```*.G`0`*
M````UZ<!``4```#BIP$`!@```.BG`0`-````[Z<!``T```#]IP$`!@````NH
M`0`(````$J@!``D````;J`$`!````"6H`0`%````*J@!`&(````PJ`$`"P``
M`).H`0`-````GZ@!`!<```"MJ`$`!0```,6H`0`%````RZ@!`"8```#1J`$`
M-P```/BH`0`1````,*D!``H```!"J0$`%0```$VI`0`*````8ZD!``D```!N
MJ0$`'````'BI`0`G````E:D!`"T```"]J0$`+````.NI`0`=````&*H!``X`
M```VJ@$``P```$6J`0`'````2:H!``L```!1J@$`!0```%VJ`0`*````8ZH!
M`!(```!NJ@$`!P```(&J`0!I````B:H!`!$```#SJ@$`"P````6K`0`*````
M$:L!`!\````<JP$`30```#RK`0`:````BJL!``<```"EJP$`(0```*VK`0`U
M````SZL!``@````%K`$`!@````ZL`0`?````%:P!``8````UK`$`"0```#RL
M`0`M````1JP!`"P```!TK`$`+P```*&L`0`&````T:P!``H```#8K`$`)0``
M`..L`0!A````":T!`!8```!KK0$`*````(*M`0`5````JZT!``(```#!K0$`
M#@```,2M`0`)````TZT!``\```#=K0$`"@```.VM`0`'````^*T!`!<`````
MK@$`!@```!BN`0`(````'ZX!``T````HK@$`"P```#:N`0`*````0JX!``D`
M``!-K@$`-P```%>N`0`'````CZX!`!8```"7K@$`%````*ZN`0`@````PZX!
M`!,```#DK@$`#````/BN`0`*````!:\!``L````0KP$`"@```!RO`0`,````
M)Z\!``H````TKP$`"@```#^O`0`=````2J\!`!$```!HKP$`%````'JO`0`,
M````CZ\!`!0```"<KP$`#````+&O`0`2````OJ\!``4```#1KP$`)0```->O
M`0`$````_:\!``<````"L`$`!0````JP`0`%````$+`!``D````6L`$`$P``
M`""P`0`2````-+`!`!H```!'L`$`%@```&*P`0`8````>;`!`!<```"2L`$`
M%P```*JP`0`>````PK`!`!@```#AL`$`!P```/JP`0`%`````K$!``\````(
ML0$`$````!BQ`0`+````*;$!`"$````UL0$`#0```%>Q`0`0````9;$!`"0`
M``!VL0$`)P```)NQ`0`5````P[$!``8```#9L0$`#0```."Q`0`(````[K$!
M`!````#WL0$`#P````BR`0`)````&+(!``D````BL@$`!0```"RR`0`'````
M,K(!``4````ZL@$`!````$"R`0`#````1;(!`#\```!)L@$`.0```(FR`0`3
M````P[(!`"P```#7L@$`,@````2S`0`1````-[,!`#H```!)LP$`+@```(2S
M`0`S````L[,!`#,```#GLP$`.P```!NT`0`2````5[0!`!H```!JM`$`%0``
M`(6T`0`;````F[0!`!T```"WM`$`%P```-6T`0`6````[;0!`!0````$M0$`
M%0```!FU`0`9````+[4!`#(```!)M0$`,@```'RU`0`U````K[4!`#,```#E
MM0$`-````!FV`0`Q````3K8!`&L```"`M@$`'0```.RV`0`5````"K<!``X`
M```@MP$`'P```"^W`0`+````3[<!`!8```!;MP$`,````'*W`0`O````H[<!
M`",```#3MP$`#````/>W`0!)````!+@!`$(```!.N`$`!````)&X`0`0````
MEK@!`!P```"GN`$`#@```,2X`0`3````T[@!``@```#GN`$`"0```/"X`0`'
M````^K@!``D````"N0$`#@````RY`0`5````&[D!``X````QN0$`$0```$"Y
M`0`(````4KD!`!P```!;N0$`"````'BY`0`%````@;D!`!````"'N0$`#P``
M`)BY`0`,````J+D!`#\```"UN0$``@```/6Y`0`&````^+D!``X```#_N0$`
M!@````ZZ`0`'````%;H!`!`````=N@$`!P```"ZZ`0`X````-KH!``\```!O
MN@$`'0```'^Z`0`$````G;H!`#$```"BN@$`&P```-2Z`0`B````\+H!`%@`
M```3NP$`&````&R[`0!(````A;L!`",```#.NP$`$````/*[`0`&`````[P!
M``X````*O`$`#P```!F\`0`,````*;P!`!,````VO`$`"P```$J\`0`=````
M5KP!`!H```!TO`$`!@```(^\`0`1````EKP!``\```"HO`$`)@```+B\`0`2
M````W[P!`!D```#RO`$`$P````R]`0`4````(+T!`"`````UO0$`"````%:]
M`0`)````7[T!`!D```!IO0$`$@```(.]`0`2````EKT!`!,```"IO0$`&```
M`+V]`0`0````UKT!`!D```#GO0$`&`````&^`0`*````&KX!``P````EO@$`
M"````#*^`0`%````.[X!`!T```!!O@$`!@```%^^`0`2````9KX!``@```!Y
MO@$`%````(*^`0`*````E[X!`"````"BO@$`$@```,.^`0`P````UKX!`!H`
M```'OP$`"P```"*_`0`,````+K\!`"$````[OP$`!P```%V_`0`6````9;\!
M``,```!\OP$`&````("_`0`&````F;\!``<```"@OP$`(0```*B_`0`Q````
MRK\!``4```#\OP$`&P````+``0`/````'L`!``<````NP`$`#0```#;``0`7
M````1,`!``0```!<P`$`"@```&'``0`,````;,`!``@```!YP`$`!@```(+`
M`0`(````B<`!``8```"2P`$`"@```)G``0`7````I,`!`#0```"\P`$`-```
M`/'``0`B````)L$!`#,```!)P0$`(````'W!`0!'````GL$!`!T```#FP0$`
M+@````3"`0`L````,\(!`&8```!@P@$`)0```,?"`0`%````[<(!``@```#S
MP@$`"0```/S"`0`(````!L,!`"$````/PP$`'````#'#`0`P````3L,!`",`
M``!_PP$`$@```*/#`0`Q````ML,!`#8```#HPP$`"0```!_$`0`8````*<0!
M``L```!"Q`$`"@```$[$`0`K````6<0!``T```"%Q`$`$@```)/$`0`-````
MIL0!``@```"TQ`$`%````+W$`0`)````TL0!``P```#<Q`$`$````.G$`0`;
M````^L0!`!H````6Q0$`+````#'%`0`+````7L4!``T```!JQ0$`!@```'C%
M`0`%````?\4!``4```"%Q0$`'0```(O%`0`4````J<4!``4```"^Q0$`"P``
M`,3%`0`*````T,4!``@```#;Q0$`#P```.3%`0`1````],4!``X````&Q@$`
M"@```!7&`0`%````(,8!``X````FQ@$`10```#7&`0!B````>\8!`!P```#>
MQ@$`"0```/O&`0`C````!<<!`!D````IQP$`!0```$/'`0`4````2<<!``@`
M``!>QP$`"P```&?'`0`2````<\<!`"X```"&QP$`"P```+7'`0`0````P<<!
M`!$```#2QP$`$@```.3'`0`0````]\<!`$D````(R`$`#````%+(`0`D````
M7\@!`!4```"$R`$`%P```)K(`0`]````LL@!`"X```#PR`$`,````!_)`0`Q
M````4,D!`"T```""R0$`#````+#)`0`*````O<D!`!````#(R0$`$P```-G)
M`0`;````[<D!``H````)R@$`$0```!3*`0`<````)LH!``<```!#R@$`&```
M`$O*`0`7````9,H!``@```!\R@$`!@```(7*`0`+````C,H!``\```"8R@$`
M%````*C*`0`#````O<H!``@```#!R@$`"P```,K*`0`2````ULH!`!,```#I
MR@$`$0```/W*`0`1````#\L!``8````ARP$`"0```"C+`0`W````,LL!`#``
M``!JRP$`+0```)O+`0`'````R<L!`!,```#1RP$`!@```.7+`0`C````[,L!
M`!@````0S`$`)P```"G,`0`-````4<P!``D```!?S`$`)P```&G,`0`#````
MD<P!``8```"5S`$`"@```)S,`0`"````I\P!``D```"JS`$`$0```+3,`0`(
M````QLP!`!4```#/S`$`&P```.7,`0`4`````<T!``4````6S0$`"@```!S-
M`0`4````)\T!`!$````\S0$`#````$[-`0`'````6\T!``P```!CS0$`"@``
M`'#-`0`.````>\T!`%T```"*S0$`&@```.C-`0`K`````\X!`!8````OS@$`
M"@```$;.`0`&````4<X!``P```!8S@$`#@```&7.`0`3````=,X!`"0```"(
MS@$`'0```*W.`0`4````R\X!`"@```#@S@$`$`````G/`0`@````&L\!`!0`
M```[SP$`$````%#/`0!T````8<\!`",```#6SP$`&P```/K/`0`L````%M`!
M`"(```!#T`$`&P```&;0`0`E````@M`!`!D```"HT`$`&P```,+0`0`9````
MWM`!``L```#XT`$`!P````31`0`(````#-$!``D````5T0$`%````!_1`0`+
M````--$!`"0```!`T0$`#P```&71`0`3````==$!``<```")T0$`"0```)'1
M`0!>````F]$!`$<```#ZT0$`.````$+2`0!;````>](!``D```#7T@$`(0``
M`.'2`0`R`````],!``H````VTP$`"````$'3`0`2````2M,!`#\```!=TP$`
M"0```)W3`0!H````I],!`#`````0U`$`)P```$'4`0`0````:=0!`"(```!Z
MU`$`)````)W4`0`N````PM0!`"L```#QU`$`+@```!W5`0`Q````3-4!`!``
M``!^U0$`!0```(_5`0`+````E=4!``H```"AU0$`%0```*S5`0`*````PM4!
M`"P```#-U0$`#````/K5`0`)````!]8!``P````1U@$`%P```![6`0`)````
M-M8!``<```!`U@$`$P```$C6`0`)````7-8!``@```!FU@$`!@```&_6`0`+
M````=M8!``L```""U@$`$0```([6`0`0````H-8!``X```"QU@$`&P```,#6
M`0`0````W-8!``<```#MU@$`%0```/76`0`8````"]<!``D````DUP$`"P``
M`"[7`0`:````.M<!`"D```!5UP$`$@```'_7`0`E````DM<!`"<```"XUP$`
M#P```.#7`0`*````\-<!`!H```#[UP$`!@```!;8`0`$````'=@!`!@````B
MV`$`#@```#O8`0`0````2M@!``X```!;V`$`!0```&K8`0`)````<-@!``D`
M``!ZV`$`"0```(38`0`)````CM@!`!(```"8V`$`!@```*O8`0`-````LM@!
M``4```#`V`$`"0```,;8`0`+````T-@!`!H```#<V`$`"P```/?8`0`"````
M`]D!`"`````&V0$`"0```"?9`0`*````,=D!`&T````\V0$`"0```*K9`0`&
M````M-D!`"L```"[V0$`/@```.?9`0`;````)MH!`"L```!"V@$`1````&[:
M`0`J````L]H!`#0```#>V@$`&@```!/;`0`8````+ML!``8```!'VP$`#```
M`$[;`0`*````6]L!``T```!FVP$`!@```'3;`0`*````>]L!`!@```"&VP$`
M#````)_;`0`-````K-L!``\```"ZVP$`"P```,K;`0`-````UML!``@```#D
MVP$`"@```.W;`0`8````^-L!``D````1W`$`!@```!O<`0`+````(MP!`!,`
M```NW`$`!@```$+<`0`8````2=P!`!P```!BW`$`"@```'_<`0`8````BMP!
M``P```"CW`$`$@```+#<`0`+````P]P!`!(```#/W`$`"````.+<`0`2````
MZ]P!``8```#^W`$`&P````7=`0`,````(=T!`"$````NW0$`!0```%#=`0`%
M````5MT!``X```!<W0$`(P```&O=`0`+````C]T!``T```";W0$`+````*G=
M`0`<````UMT!``X```#SW0$`!0````+>`0`,````"-X!``\````5W@$`#@``
M`"7>`0`"````--X!``\````WW@$`"````$?>`0`D````4-X!`"D```!UW@$`
M+P```)_>`0`M````S]X!`"@```#]W@$`*````";?`0!=````3]\!`!,```"M
MWP$`60```,'?`0`T````&^`!`%X```!0X`$`6P```*_@`0`F````"^$!`#T`
M```RX0$`,P```'#A`0`W````I.$!`#4```#<X0$`'@```!+B`0`[````,>(!
M`.0!``!MX@$`(0```%+D`0`4````=.0!`%0```")Y`$`@@```-[D`0!"````
M8>4!`"D```"DY0$`/P```,[E`0!R````#N8!`%(```"!Y@$`,@```-3F`0`@
M````!^<!`!4````HYP$`,@```#[G`0`=````<><!`!T```"/YP$`+0```*WG
M`0`C````V^<!`"@```#_YP$`00```"CH`0`=````:N@!`!,```"(Z`$`.@``
M`)SH`0`H````U^@!`"D`````Z0$`(@```"KI`0`8````3>D!`$````!FZ0$`
M:0```*?I`0`[````$>H!`$X```!-Z@$`.P```)SJ`0`K````V.H!`#H````$
MZP$`8P```#_K`0!,````H^L!`#(```#PZP$`+0```"/L`0`Q````4>P!`%0`
M``"#[`$`6P```-CL`0!-````-.T!`%$```""[0$`-````-3M`0`N````">X!
M`"X````X[@$`+@```&?N`0"(````ENX!`'T````?[P$`A@```)WO`0#0````
M)/`!`!,```#U\`$`)@````GQ`0`Y````,/$!`"P```!J\0$`2````)?Q`0`K
M````X/$!`$P````,\@$`(````%GR`0`*````>O(!`,$```"%\@$`1P```$?S
M`0`F````C_,!`#4```"V\P$`)P```.SS`0`D````%/0!`#X````Y]`$`!@``
M`'CT`0`'````?_0!``0```"']`$`#````(ST`0`+````F?0!``P```"E]`$`
M"P```++T`0`%````OO0!`!````#$]`$``P```-7T`0!G````V?0!``<```!!
M]0$`%0```$GU`0`$````7_4!``<```!D]0$`!@```&SU`0`%````<_4!`#X`
M``!Y]0$`"0```+CU`0`5````PO4!``L```#8]0$`$@```.3U`0`-````]_4!
M``(````%]@$`!P````CV`0`'````$/8!`!(````8]@$`#````"OV`0`8````
M./8!``8```!1]@$`#@```%CV`0`,````9_8!``,```!T]@$`*P```'CV`0`$
M````I/8!``<```"I]@$`"````+'V`0`K````NO8!`$<```#F]@$`.@```"[W
M`0`[````:?<!`"(```"E]P$`-@```,CW`0`Y````__<!`"T````Y^`$`(P``
M`&?X`0`F````B_@!`"H```"R^`$`)0```-WX`0`C`````_D!`"0````G^0$`
M+````$SY`0`A````>?D!`#P```";^0$`)@```-CY`0`Z````__D!`#4````Z
M^@$`*P```'#Z`0`N````G/H!`"X```#+^@$`*0```/KZ`0`J````)/L!`"X`
M``!/^P$`*P```'[[`0`P````JOL!`"X```#;^P$`*0````K\`0`I````-/P!
M`#,```!>_`$`)````)+\`0`N````M_P!`#@```#F_`$`.P```!_]`0`@````
M6_T!`"H```!\_0$`0P```*?]`0`I````Z_T!`"P````5_@$`+````$+^`0`M
M````;_X!`"<```"=_@$`'0```,7^`0`K````X_X!`"P````/_P$`-P```#S_
M`0`L````=/\!`$$```"A_P$`#````./_`0`3````\/\!`"`````$``(`,0``
M`"4``@`D````5P`"``D```!\``(`#P```(8``@`<````E@`"`!0```"S``(`
M$````,@``@`Q````V0`"``@````+`0(`"````!0!`@`C````'0$"`"8```!!
M`0(`'````&@!`@`G````A0$"`!\```"M`0(`"0```,T!`@#A````UP$"`!(`
M``"Y`@(`&@```,P"`@`)````YP("``P```#Q`@(`%````/X"`@`0````$P,"
M`!H````D`P(`!@```#\#`@`W````1@,"`!4```!^`P(`%P```)0#`@`'````
MK`,"`!,```"T`P(`"P```,@#`@`\````U`,"``D````1!`(`*P```!L$`@`0
M````1P0"`!````!8!`(`%0```&D$`@`T````?P0"`"````"T!`(`#@```-4$
M`@`?````Y`0"``\````$!0(`$````!0%`@`:````)04"``L```!`!0(`&P``
M`$P%`@`+````:`4"`"0```!T!0(`"@```)D%`@`;````I`4"`"L```#`!0(`
M!P```.P%`@`G````]`4"``<````<!@(`"0```"0&`@`)````+@8"`#L````X
M!@(`!@```'0&`@`.````>P8"`!,```"*!@(`%@```)X&`@`*````M08"``@`
M``#`!@(`!P```,D&`@`3````T08"``L```#E!@(`'````/$&`@`/````#@<"
M`!@````>!P(`%@```#<'`@`%````3@<"``<```!4!P(`%P```%P'`@`$````
M=`<"`#,```!Y!P(`#````*T'`@`0````N@<"``P```#+!P(``@```-@'`@`1
M````VP<"`"(```#M!P(`"P```!`(`@`#````'`@"``<````@"`(`"0```"@(
M`@`&````,@@"``T````Y"`(`"@```$<(`@`4````4@@"`!4```!G"`(`$0``
M`'T(`@`V````CP@"`!X```#&"`(`&@```.4(`@`7``````D"``L````8"0(`
M,P```"0)`@`'````6`D"`!<```!@"0(`2P```'@)`@`4````Q`D"``\```#9
M"0(`"````.D)`@`$````\@D"``0```#W"0(`"@```/P)`@`6````!PH"``4`
M```>"@(`!@```"0*`@`(````*PH"``D````T"@(`!````#X*`@`)````0PH"
M``X```!-"@(`/0```%P*`@`Q````F@H"`"X```#,"@(`!0```/L*`@`7````
M`0L"`"`````9"P(`(0```#H+`@`E````7`L"`!````"""P(``@```),+`@`$
M````E@L"``H```";"P(`"0```*8+`@`%````L`L"``(```"V"P(`'P```+D+
M`@!.````V0L"`#D````H#`(`'@```&(,`@`S````@0P"`"H```"U#`(`8```
M`.`,`@`0````00T"`'P```!2#0(`)P```,\-`@!3````]PT"`"@```!+#@(`
M4@```'0.`@`X````QPX"`#,`````#P(`-````#0/`@`Y````:0\"`#@```"C
M#P(`/P```-P/`@`_````'!`"`"T```!<$`(`,````(H0`@`S````NQ`"``X`
M``#O$`(`#@```/X0`@`-````#1$"`(,````;$0(`"````)\1`@"Q````J!$"
M`(T```!:$@(`B````.@2`@`N````<1,"`%H```"@$P(`%````/L3`@`E````
M$!0"`!@````V%`(`$@```$\4`@`:````8A0"`",```!]%`(`-P```*$4`@`:
M````V10"`!@```#T%`(`5@````T5`@`:````9!4"`!8```!_%0(`"P```)85
M`@`%````HA4"``8```"H%0(`"````*\5`@`%````N!4"`!L```"^%0(`$0``
M`-H5`@`>````[!4"`!\````+%@(`$0```"L6`@`'````/18"``0```!%%@(`
M"0```$H6`@`.````5!8"``@```!C%@(`!0```&P6`@`<````<A8"``H```"/
M%@(`"0```)H6`@`/````I!8"``<```"T%@(`"````+P6`@`2````Q18"``H`
M``#8%@(`%@```.,6`@`+````^A8"``D````&%P(`%@```!`7`@`(````)Q<"
M``0````P%P(`'````#47`@`5````4A<"``D```!H%P(`&@```'(7`@`0````
MC1<"`"$```">%P(`#P```,`7`@`(````T!<"`!0```#9%P(`!@```.X7`@`'
M````]1<"`!<```#]%P(`"````!48`@`"````'A@"``(````A&`(`$0```"08
M`@`+````-A@"``8```!"&`(`$0```$D8`@`4````6Q@"``<```!P&`(`+0``
M`'@8`@`"````IA@"``0```"I&`(`$P```*X8`@`7````PA@"``L```#:&`(`
M!P```.88`@`/````[A@"``8```#^&`(`%P````49`@`(````'1D"`!@````F
M&0(`$````#\9`@`2````4!D"``(```!C&0(`!P```&89`@`+````;AD"``H`
M``!Z&0(`%0```(49`@`R````FQD"``<```#.&0(`"0```-89`@`1````X!D"
M``4```#R&0(``@```/@9`@`+````^QD"``$```#3!```'`0``#$%``!?`P``
M`````)P!``!M`@``H`0```````"4`P``QP$``/L&``!\``````````````"&
M`@``*0<```L!````````@0<``,$```!W!0``%00``/`%```L````VP,``,$&
M```C!P``"`(```$$``"\!0```@<``#$#````````I@(``.\%``!D`@``L@(`
M``\$``"!`P```````````````````````-8$``!1!0``A00`````````````
M]@$``'`"`````````````'\"```N!````````",!``"D!0```````&('``#C
M!0``CP8``"4!``!P!@``]00``&X"``!P`0``,P<``,(!``#1`@``+P0``&\#
M``!.!P``6@```*(!```S`0``B0<```````![`0``ZP```)8&``#`!0``7`<`
M`$H%``#,!@```````)0$``!B`@``\@```"D"``!F`@```````-L$``"$!@``
MW04`````````````I0```````````````````)@#````````0````.0&````
M````S0$```````"=!```2`(``+\%````````_0(``(@'````````#`4`````
M``!/!```RP4``.P"```F!0``%P`````````T````6````+P!````````````
M`+4"``!:!```90,``&H#``!?`0``@@<``````````````````/H!``!D`P``
M;P```-8!````````?08````````(!P``D`````````!-`P``FP(````````<
M`P``708``/0!``#?````*`,``-P!``#0`0``M@,``$<#````````&P<``!$'
M```E`P``\0```+`%``#2!`````````````"K`P``I`````````#*!0``80,`
M`'D#``"5!```"@0```````"*!@``P`$```````#A!```>`<``-D#``#G`0``
M`````/X%``!*!P``J0$``%@$``#D`0```````$\```"^`0``````````````
M````+P,``&P'````````L@````````"8!0``9P0``*0&``#B`0``1@8`````
M```J````^P$``&@!``!4!P``V@,``"@&``"C!```5`8``%8$``"O!@``````
M`)T"``!;````D@8``(L#``"I`````````*P%``#3````H`,``'H!``!G`@``
MP@,``"@'``![`P``*P`````````V```````````````Q`@``@P```.0$````
M````]@0``'D$``!$!P```````/<``````````````),"``"Z!0```````!<%
M``"J`P``*P(``'H'````````=`0``#L"`````````````)`"``".`0``B@0`
M`-P```!\!P``5P4``)H#```#`@``.P<``%X#```&`0```````$4$````````
M+0<``)\#``"E`0````````````!G!0``<0$`````````````0@8``-L````]
M!P``2@`````````"`@```````"D!````````5@,```````"<!````````,P!
M``!A!```%@,````````G!```80``````````````)00``'<```#N`P``9@8`
M``````"<!@``_P4``'L`````````&`8``+$$```#`````P<``-P%``"W!@``
MR0,``'P"```6!P``[```````````````8P$```````#N`@``F@```)(```">
M`P```````)L!```K!0``<0(``/,#``!&`P``O@(``+H!``#=!```U@8``+0#
M``#C!```R@0``*H$````````&`<``!<"``"_!```&`$``+$"````````````
M`.(#``"/`@```````'X!``#]!0``:0$``!8&``#X`0``*@,``$L#``!R`P``
M1P0``)8!``!'````R`$``'$#``!.!@``.@```&`&``!3````U08``'8"````
M````+@4``"8"``!S!@``[0````H&```$````Y`(``'X#``"#!0``B0$``),$
M``#^`@``9`<``.8%```7`0```````)\!```-!P``>P(``'X````%!```"0<`
M`"T&```T!@```````%("``"_`````````'<#``#_`P````````L````S!0``
M``````````!F!P``)P8``-T`````````]`(``#\'````````V`,``-H$````
M`````````&@````-`@``<@8```````#3!@``Q08``'$```"@````_`8``$("
M````````FP0``+D#``#`````!`0```X&``!,`0``E`(``+D%``"@`0``P0$`
M```````%`````````$P'``#6`@``8P````````#$````````````````````
M\@0```````!`!0``;P<```````#-!@```````!<#``"!!@````````````!2
M!0````````````#S!```=P0``*,&``!O!```"````%X```!(!P``N@,``'8%
M``#>````A`,``"0$```[!0``]P8``)P#``!W`@```````&H!```^`@``O@8`
M`.T%``"^!````````&\&````````B0```*4"````````,P8````````<!P``
M`````%4!```B!```.`$```````!M!````````(<"``!Y!0``@`4``-8`````
M````(0(``$\&```W!```,P(`````````````EP,``/\$````!P``!P,``&D&
M````````\0$``,8```#P`P``CP```%L'`````````````.<&``"%`P``````
M``````#=`@``+@,``%<!``#T!@```````.4!``#^````30```,T$```0!0``
M`````#8!``"0`P``?0$``)<```!9!```?P0``',```"G!0``6`(``(("````
M````008``'8!``#^`0```````.<$````````)`````````#X!```:P0``,8$
M``!9`0``(00```8```"?`@``7@(``````````````P8``)0%````````X08`
M`(X#```^````*P$``!0"``#7`P``D08``$`'````````;`,```````".!```
MHP````````#%`P``40```+T"```L!```(`0``.D$````````+`8``/8"```N
M!@``6`4``````````````````*D"```D`P````````````"S`0```````'T`
M```G`P```````'('````````D00```````#.`0``\`8```@!````````````
M`````````0``3`4``#@&````````R`4``!$!``!?!```^@,``)P```"P`P``
MQ`$```````!U!```<00``-<"``#)!0``?`$``(P!``````````````````#\
M!0``-00````````^!P``I08``-`#``"H!@``[0$``*8`````````[P(`````
M`````````````*T$``#K`0``^00``-\#```H!````````&8$``"?````#P8`
M`+D$``#J`P```````,D$``!;`@``C`0```````#$`@``O@4``$(%``!T!P``
MU04``),&````````8P<`````````````&P0```````#T`P``5````-D`````
M````2````)8`````````5@(``#<````?!@``/`(``',"````````\P(`````
M```(!```MP(``*4$``!W!P```````-H&```5`````````-D$````````_```
M```````?!0``BP4``/<!``#V!0``?`,``-@&``"T!0``E04```,%````````
M````````````````@P0``+\"``#.`@``#`<``)D#``#_`@```````/0$```_
M`@``4P$```````#%!```,@$```````#+`@``C```````````````2P$`````
M````````N@8```D!``#>`0``)@0``*0#``#,!0``<P$``#,$```0!@``BP0`
M`&(`````````+P```*`&```X`@``60(``'\'``!'!P``C04``!D`````````
MK0```.\#``#1!@``?`4``#(```"]!0``R@(```````#V!@``M@8``%L%``!$
M`0`````````````=`@``'@<``-L&````````#@4```````!@`0``.0(``$,"
M``"[`0``@`,````````J`0``1@```-`"```3!@```````'\```!"`P``-0<`
M`"T!```Q!```X0$```````#1!0``M`(``.@!``!4`P``^`,``'T$````````
MH@,``-0"``!B`P``Z@4`````````````7P```!\"```R`P``_`(```````!S
M!````````(`&```W!0``.@4``!@$````````=@```*,#````````EP4``&(%
M```2`@``;`$``"(!````````C@````````!J!0```````,4%```:`0``X`$`
M``````"3`P``F`````````"%!0``&``````````L!0``A@0````````<````
MF08``&@&``#[`@``A0$```````!,`P``:`<``'H$```0!```90```%0%``#$
M!@``=`(``.```````````````+<#``!U`P``````````````````````````
M``!<`0```````#@'``!^`@``;```````````````B`(```````#.!@``"P(`
M``\%``!M`0``+0(``-\%``#G`@``3P,```T!``!@````9P````````"_!@``
MV0(``+D&``````````````````#J````L@0``"@`````````+P<```````#S
M````J@4``/T!``#5!```&@```````````````````&($````````R`8``%\&
M``!.`````````!,"`````````````$H$```5!@``(P```#\```""!0``J`0`
M`+@"``"1!0``Y````$($````````N`4``$$%```?`0``N`$```````";!0``
M`````+4````!!P``*P<`````````````L`0```````!I!P``>P4``&8`````
M``````````````#.!```!P$``%<&`````````````-\&``!@!P``.P$``#L$
M``!U`@``ZP8``#D$```?!P``_08``'$&```,`0```````$<&``"=!@``O`0`
M`&4&```)!0``10<``````````````````',#``"+````>0<``-(#```!`@``
MHP$``"P#````````LP0````````D!P```0,``.L"``!P````;08``-@````1
M!@``10,``%T'``#R!0``Z`8``-$$```_`P```````/H%``!E!P``GP8``-("
M````````:P$``-$```")!@``,````,@"``"A!```[`$``.(```!J`@``I@$`
M`%P"````````.`,```````!;!@``*P0``&`#``#@!0```````,\```"6!0``
MUP8``$4"`````````````)4!``````````````8&``!&!0``_@8```````!)
M`P``;`4``%,'``#3`0``@`$`````````````````````````````_00``&P$
M```&!```/@,``!\$``#?!````````%P#``!^!```$0(``"L&``#+!```&P,`
M``````!^!@``=0````4#``"1`0```````*P`````````!`(``'D!```I!```
M-`<```````!Z````=```````````````8@$``%0!```-````/P$``-X#``"T
M!@``-P<`````````````)@```````````````````(@%``"/!````````$8$
M````!@```````+,```!0`0``D`8``+(!```6`@``4`(``(<#``!N!P``]0(`
M`+8```#R!@``\0,``%$!``#B!```[P0```````#/!@```````"\"````````
M"P<``%``````````5`(```````!+!@``@0(````````;!@```````/,&``"+
M!@``NP```%P&````````^0$``(0```!%!@```````'4!`````````````$0"
M``!(`0``%0,````````D`0``60,``/4```":!0``4P4``-P&```Y`0``&0<`
M``````"(`0``7`4``%<$``!!!P``F@(``#T#```1`P``K@4``$D!````````
MGP0````````^`0``:@```'X%``"G`P``IP8``"``````````K@```$L````2
M````I@0```$!``!X!@```````-4!``"Z````Y`,``+8!`````````````&@$
M`````````````+X```"Y````<@0````````1````7P4``.8$```@`P``JP$`
M`.8````B`@``G@8``+T!``#R`0``.08``((&````````@0```!($``"[`@``
M/00``'\!```;````LP(```````"]`P``=04``&4"``"%`````````,T"``##
M!@``?P4```````!7`@``GP4``/`!``"M`P```````(H%``!R`0``L0```($$
M````````[P8````````0!P``;P(```````#M`P```````!`"```4`0``+0,`
M`$0$````````U0,``-\"````````>P8``$D%````````V@4``(<$````````
ML08``/<"``"O!```!0(````````A````^P4``'<!```\`P``"08``/,%``#P
M`@``<04``+@#````````U`,``.@"``!8!@```````'L$``!!`P```````"H"
M``"<!0``Q@4``-D%``!A!0````````````#_!@``>@4``$<"```\````O```
M````````````#P,`````````````#P<``#8&```4!`````````````!A`@``
M!P<``#,#````````0`$``#T%````````F@8`````````````AP$``,D```#I
M`P``XP8``+T```"+`0``O00````````V`P``-0(``!T%````````A@8``*X$
M```'`@``ZP0``+\#``````````````````!)!```4`8``+4$``!S!0``Q`,`
M``````!K`P``V@$``+`!````````DP4```````#)!@``H@4````````)`P``
M?0,``!,````-!```Q0$```L$````````00(``%4```#B!0```````*P#```#
M`P``&00```4&`````````````.H$``#K!0``"@,``*@%``"W!```%@```%0$
M```W`0``504``*0"``#Y`@```````(`"```C!0``^P,``$,!``!J!```````
M```````_!0``$P$```````#R`P``QP0``+T&````````2`,```````#-`P``
M704``'P$```\!@``^0```!X%``!&`0```````*L```!6`0``Z`0``(T`````
M````S@,``#<&`````````````,L```"'````W0,`````````````S`0`````
M``!1!P```````!D%````````YP,``#$```#,`P``B04``!`!```.````:@<`
M`*<```#/!```80<``!<&``#:````(0$``*("``"8`@``7@0``"T$```B!P``
M90$``'@"```3!P``'00``-@%``"<`@``70````````#@!```9@4``#X&``#F
M`@```````+(%````````!`,``!X$```````````````````$!0```````),!
M``"%!@``=`,``*\#``#Y!@```````)($``"%`@``'08```````#<`P``````
M`%L!``!:!P``%`,``/$"```R!P``=`4``*@#``!=`0``*@8`````````````
M`````*X&``#@`P``3@,``/P$```Y!P``>`0````````O!0``9P8``-0```"@
M`@``^0,````````H!0``A0<``.P%``!R`@```````"D`````````!@(`````
M```*!P``Y00```````!1!@`````````````F!P```08```````!&`@``````
M````````````UP$``,T````W`P``!`$````````J!P``<0<``&(&````````
M@04``&X!``"O`@``Q`0``"X"``!5!```````````````````A`4``!,$``"1
M`@``5@8``-(```"N`P``2`8``#8'``![!P```````-`$```;!0```````+H$
M`````````````((!`````````````","``!:`0```````!H'```Q!P``(`(`
M`*@"```E!P```````#H$``")`@``:P```/$&```Y!0``/`$``!$%````````
MY`4``(H````<`0``JP0``(D#```&!0```````"(%``!=`@```````.H!````
M````^@0```````#?`0``1P4````````2!@``B````.D"```T!```Y0,``*L%
M``#-!0``QP,````````_!```````````````````Z@(``*$#``#^`P``&`4`
M`#,```#U!0``=@<```````!N!@```````,L#``!O`0``'@,``%D%````````
MA@```(,!````````M````(\#``"$!```,`0``+<!``"9`@``H`4``+8"``#E
M`@```````#($``"A````+`(``,@#```+`P```````(P%````````&@8``*P$
M``````````````````!K!0```````-@!````````#@0```<&````````)0``
M`.$#``">``````````````!R!0``'@8````````5`0``/@4``!T```#,`@``
MG@4``(@&``".`@``(04``)8"````````/P8``$`&``"A`0``H04``"<"````
M`````````"T```!)!P``E0(``%($`````````````#0"``#W!0``=`$``%T#
M```U`0```````$X$``!6!0``H@0```D```##!0``@P,```````!8`0``:0(`
M`.P#```9`@```````,("``!9!P``0P,``#P$``"0`0``Y@$``.,#``!1!```
M``````````"L`@``#@(``!P"``!.`0``2`0```H`````````3`8``/P!```N
M````C0$````````L!P``[0(``.D!``#/`0``;`(`````````````V@(``,,"
M```G````LP,``)(%````````;@```!``````````C00``!L!``!P!```=0<`
M```#``#>!0``4@<``+(#```&!P``C0,```````"-`@``9P$``((#``"_`0``
M=@8``&X$``"J````3@(``&0%````````C`,``"X'``""!````````+P#```^
M!```&`(````````W`@``D@,``((`````!```````````````````#P(``!4"
M``#"````NP,```````#0!@``,`4``.X```#!!0```````$@%```2!P``6`<`
M``($``!>`0````````````#9`0``208``/$$``!L!@``.`4``#H'``":`0``
MX0```+P"``"^`P``%@0`````````````F04``.D%``#U`P```````$('```9
M`P``[`0``)4#```"`P``"`8``(T&````````:P8``%\'```N`0``)08`````
M``!D!@``:0,```````!>!@``M0,```H"``!)`@``'P````L&``!D`0``````
M``````!/`@````````````"F!0``,`8``+$!```,!@``T@$``#4%``"&`0``
M7``````````Z!@``Y@,``!H%``"[!```K0(```````"`````>@,``(<&````
M````@P8``-T!```U`P``[P$`````````````#````)8#``!C`@``G@(``/$%
M``````````````````!D!`````````````#I````M@4``*$&````````'@$`
M`,$#```[!@``<`4``(0!``!K`@```````$T$``#F!@```````,8&``"/`0``
M`````,,````=!P```````&,$``!S!P````````T%```]`0``3P<``&T#```A
M!@``1````!4'`````````````-@"``!)````.P,``!<$````````[P```&H&
M````````"@4``%,#```'!0``)`4``+4&``"I!```!P0``$<!``!#!@``````
M````````````(`4```````"P````KP```"\&``#N!@``XP`````````B!@``
M$@,``,$$``#9!@````````````!_`P``#`0``!@#``"L`0```````+D!``#B
M!@``S@````````"2`0``?@<``,4"```"!0```````#0!````````J````"P!
M```.`P```````)`$```9`0``H@```%`%````````Z08``-4"````````````
M```````)!```F0$``)L#``"J`0``#`(``-0%``#T!0``]0$```T#````````
MG0$``,4`````````Q@(``%<````X````*`(`````````````_0,``*<$``"[
M!0```````,(%````````3P$``!T!``#L!@``^`8``)8$``!0!````````*T!
M`````````````*0!``"I!0``L`(``&,&````````U@,``!8%``"F`P``````
M`!H"````!0```````(8'``"`!P``T`4``.,!``"L!@``XP(``,`&``"K`@``
M<`,``)`%``"O`0```````-(%``"B!@```````+4%````````S@4``&T%````
M````^`(```````#=!@`````````````?`P``?0<``+0$``"F!@```````,0%
M``"G`0``0P```)T#```;`@```````$P$`````````@$``)<"``!/!0``0`,`
M`'D&``#<`@```````$8'``!C!0``?P8``$0#``#E````304``,(&````````
M````````````````T````%L#``"W````>0(``$,%````````4@8``-8%``!*
M`@``/0```"T%````````>@8``.`"``!@!```&@,``````````````````,,$
M````````TP,``.("``!X`P``E````(<'```:!```````````````````````
M`$$$```9!@````````````!0!P```````"D#``#]````5P,`````````````
M(0<``%$#```Z`@``DP```/,!``!5`@`````````````-!@```````)D$````
M````0@$``%\"``!+!```2P<``&X%``"Q`P```````(0"``!-!@```````"8!
M````````VP$```````"Q!0``<`<``-P$``!I!0``LP8``"<%```\!P``0P<`
M`$H#``!I!```SP,```````!H`@``KP4``(`$``!V`P``T0,``%`#``"8`0``
MX0(``$P"``#"!````````(@$``!K!P``<@```````````````````/H"````
M````,@4``&@#```%!P``(P,``'P&````````Z`,``)<$``"U`0``R@8``,\"
M```H`0``EP$``,L!````````5@<``%,"``!:`P``A@4````````P`@``^```
M`)D`````````S````*X"```T!0```````-<`````````I04`````````````
M`````"0&``"8!@``[@$``"$#```[````EP8``$$!``#&`P``C`(```0'```5
M!0``904``````````````````"(#``"*`@``'@```(,'``!5!P``K04``$4`
M``!U!@``.`0``,,!``#4`0``0@```&4$```G!P``;P4``/4&``!6````#@$`
M`/D%``!-`@``_@0``%H"``"C!0``!`8``.@%```B````104```````!*!@``
MF`0``)L&``#!`@```P0`````````````O`8``&X#```4!@``[08```````!]
M!0``Z````#0#``!:!0``$@4```\!```>`@```````&@%````````+P$``#T"
M``!-`0``,`$``"4"``#5`````````"4%``!F`P``]@```'H"``".!@``````
M``````"C`@```````*X!``#\`P``80$``+@```"1````````````````````
ME0```"8#```/``````````````"*`P```````'T"``#'!0``Q@$```````"&
M`P``(`<``)X!````````VP(``,D!```*`0``50,``'D```#4!```PP,`````
M``#*`0``$P,``````````````````&T'``#P!```=@0```@#````````/08`
M`-@$````````H0(``&T```"/!0``%P<```````!7!P``*@0```(```!@`@``
M'`4```````#X!0``3@4```````#(````#`,``(L"````````I0,```@%````
M````.0,``/\!```.!P``700```D"````````3````)H$``#1`0``*04``.<%
M````````>`````````!F`0``\````.X%``!+`@``MP4```4%````````4@``
M`.L#``!+!0``U`8``#D```#(!```G04``,`"``!>!P```P$``'<&``!$!0``
MW@8`````````````!P```#8%```K`P``^@```,<&```4!P```@8``,H```!X
M`0``$@$``/<#``#E!0``J@8``%,$``!2`0````````8#``"Y`@``30<``!0`
M``"1`P``J@(``%P$``#7!```.@,``#`#``#T````0`0```````#>`@``L`8`
M````````````VP4``&$&``#``P``R@,``.T$``!;!```E`$``(@#``!G!P``
MA`<`````````````$P4``(P&``"D!```,`<``(H!``!#!```FP```"`&``#R
M`@``=`8`````````````M@0````````0`P``Z@8``&`%````````^P0``)0&
M``#A!0``*08`````````````]P0```````"Z`@```````+0!``!$!@``````
M`*T&``!5!@``/`4```````!!````-@0````````R`@````````$%````````
MC@4``!T#``"G`@````````````!2`P``)@8``-,%``#Z!@```````*@!``!C
M`P``$00`````````````4P8``"<!``"S!0```````.4&``#3`@```````(<%
M``"#`@``N`8``%@#``"!`0```````.X$```D`@``T@8````````U````NP8`
M`,D"``"I`P``60`````````Q`0```````.`&``"R!@``"P4``$4!``!:!@``
MN`0``#4&````````608```````!D````(P8``,<"````````G0```/\````%
M`0``0`(``(D$``!I````UP4``"`!``">!````````)("```4!0```````#H!
M``#/!0```````!8!````````>`4``,<```#+!@````````````!>!0``(P0`
M`/8#```J!0``YP```,`$``"I!@``'`8``$H!```Q!@````(``&<#``#>!```
M-@(`````````````^P```*L&``"5!@``40(````````R!@```"`H)7,@9&%Y
M<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI
M`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@
M9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@
M=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H
M92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES
M<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-
M0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E
M<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y
M(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T
M=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D
M>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE
M8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E
M<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!"
M;V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`
M)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@
M:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK
M<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P
M97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@
M)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(
M;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`
M02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K
M+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)
M344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#
M;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO
M=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U
M="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C
M8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``
M061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``
M061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`
M061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R
M.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE
M("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@
M8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B
M)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E
M="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`
M061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!
M;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O
M=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT
M:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT
M97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`
M06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!
M;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU
M92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS
M=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO
M;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L
M>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P
M<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!
M<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT
M:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S
M8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA
M`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B
M-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A
M;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT
M:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@
M=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!
M>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@
M0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E
M<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@
M87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L
M;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R
M('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O
M=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"
M=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--
M4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE
M<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#
M86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A
M;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT
M97)N86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0
M('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC
M96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B
M)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO
M="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N
M;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@
M8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT
M<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB
M97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@
M;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S
M(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R
M;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S
M<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W
M;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9
M;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T
M960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`
M0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@
M<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E
M9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A
M<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U
M<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC
M:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A
M<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3
M:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R
M(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`
M0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I
M=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N
M(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO
M;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E
M<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I
M8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I
M;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E
M(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN
M=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#
M;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER
M90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N
M;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E
M<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z
M(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D
M<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O
M9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y
M("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN
M('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E
M;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T
M(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@
M=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@
M86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@
M<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G
M<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N
M+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S
M879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@
M8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T
M92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S
M(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R
M("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S
M(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E
M871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R
M<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A
M=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U
M<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E
M;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`
M0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H
M<"D`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T
M90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O
M;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT
M`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U
M;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T
M92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A
M;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$
M96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S
M86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI
M<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE
M=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O
M;&1E<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U
M<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`
M1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E
M<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H
M;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U
M<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R
M96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T
M90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI
M8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O
M=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I
M;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P
M<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L
M;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO
M;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`
M161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O
M<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%
M;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T
M97=A>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%
M;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L
M:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT
M97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME
M9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G
M92!54DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA
M;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T
M:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R
M<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%
M=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S
M`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN
M`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z
M`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%
M>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER
M871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E
M='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@
M=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R
M971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`
M1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y
M`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W
M(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F
M;VYT`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z
M("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I
M;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I
M;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A
M=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&
M;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R
M="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T
M:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N
M9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@
M82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R
M='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`
M1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A
M;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I
M;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@
M:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`
M1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L
M`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'
M<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M
M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U
M<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U"
M:7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L
M92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N
M9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(
M96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R
M;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN
M9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN
M:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N
M($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y
M`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO
M;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@
M;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@
M;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK
M;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A
M9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A
M<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_
M`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED
M:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X
M(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D
M9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD
M;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O
M;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y
M)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S
M('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E
M(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N
M965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A
M<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@
M=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y
M960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`
M26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL
M97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O
M<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!
M9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC
M<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA
M`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL
M86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R
M="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E
M`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R
M`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R
M="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R
M87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@
M869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y
M($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE
M;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@
M87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S
M=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI
M9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO
M8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R
M(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R
M<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R
M(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`
M26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`
M26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N
M`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M
M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N
M=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D
M86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&
M=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E
M<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U
M=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y
M($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED
M<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I
M=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA
M;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T
M=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A
M;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E
M;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I
M;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,
M:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W
M:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE
M<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS
M`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`
M3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,
M:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T
M+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG
M('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S
M`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A
M;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,
M;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R
M(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA
M;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I
M8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES
M:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M
M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN
M`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA
M;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U
M<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS
M`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`
M365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A
M9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I
M;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T
M<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI
M9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N
M;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-
M:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E
M<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A
M=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO
M;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R
M870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T
M:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S
M=&QY($-L;W5D>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T;'D@4W5N
M;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V
M92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!-
M>2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY
M(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M
M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S
M($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C
M871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N
M97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE
M9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T
M:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@
M=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X
M="`T(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T
M96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO
M;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U
M<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE
M9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.
M;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L
M:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R
M=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R
M=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@
M:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB
M97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@
M<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T
M86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E
M;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X
M=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K
M96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`
M4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@
M0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E
M<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS
M`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN
M9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P
M:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#
M;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN
M`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`
M4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU
M<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M
M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP
M<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S
M`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@
M8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E
M(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES
M=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N
M9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@
M9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N
M8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@
M`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV
M871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`
M4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0
M=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G
M97,`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`
M4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I
M;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O
M<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R
M96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R
M97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O
M<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`
M4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO
M=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V
M92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E
M<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@
M4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O
M($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#
M;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S
M`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T
M:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O
M=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S
M.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O
M;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2
M=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-1
M3"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!3
M54-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S
M(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E
M;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A
M;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN
M8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V
M92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`
M4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E
M9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE
M8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`
M4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U
M<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A
M<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I
M86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3
M970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H
M;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R
M<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R
M92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3
M;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R
M<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D
M97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L
M86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I
M;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N
M("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E
M96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D
M:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@
M8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`
M4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN
M8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK
M971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D
M9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@
M(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C
M97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F
M=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L
M;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z
M97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I
M;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4
M+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@
M9FEL90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T
M:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T
M86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS
M`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R
M871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O
M)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP
M;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M
M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED
M92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S
M92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L
M96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U
M9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M
M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET
M;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@
M268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY
M('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M
M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E
M9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F
M97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A
M=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R
M;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO
M="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F
M="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P
M87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E
M>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N
M`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@
M;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`
M5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H
M92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N
M=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER
M960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O
M;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K
M871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A
M;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I
M;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4
M:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O
M9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`
M5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T
M97,N`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A
M9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`
M5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@
M:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W
M:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5
M;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE
M9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A
M:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@
M)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E
M(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%
M;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3
M=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R
M;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@
M=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U
M(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R
M9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5
M<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C
M<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E
M<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E
M<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E
M9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S
M97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`
M57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA
M;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A
M;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@
M;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A
M;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!6
M97)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A
M;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA
M;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A
M9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@
M27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&
M=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T
M82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY
M`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)
M4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA
M<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L
M;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I
M<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``
M5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@
M4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I
M9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@
M;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI
M=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K
M;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!
M9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L
M:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O
M9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T
M("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+
M97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O
M(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T
M960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R
M(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A
M9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM
M<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S
M+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A
M;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@
M<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9
M;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O
M=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!
M9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES
M=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A
M=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT
M('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H
M86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z
M`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E
M;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@
M<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU
M9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U
M;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT
M("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@
M)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O
M=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`
M7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N
M<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN
M`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD
M87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N
M(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O
M;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL
M:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z
M`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O
M;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M
M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O
M<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W
M(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES
M=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U
M<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E
M<G-I;VXZ($AO<F1E(#,N,2XQ+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP
M,RTQ,B`P,#HS,2LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,3,@
M,C(Z-#`K,#$P,`I,87-T+51R86YS;&%T;W(Z($IA;B!+=6EP97)S(#QJ<FMU
M:7!E<G-`;&%U=V5R<V-O;&QE9V4N;FP^"DQA;F=U86=E+51E86TZ($1U=&-H
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R!D86=E;B!G96QE
M9&5N*0`@*%-N96QT;V5T<R`E<RD`("AB:6YN96X@)7,@9&%G96XI`"`H=F%N
M9&%A9RD`("AM;W)G96XI`"`H9VES=&5R96XI`"!O<"``(B5S(B!I<R!G965N
M(&1I<F5C=&]R>2X`(B5S(B!I<R!G965N(&=E;&1I9V4@:V5U>F4N`"(E<R(@
M:7,@;FEE="!G96-O;F9I9W5R965R9"!I;B!H970@2&]R9&4@<F5G:7-T97(N
M`"(E<R(@=')E92!W965R9V5V97(@;FEE="!G979O;F1E;BX`(B5S(B!A86X@
M:&5T(&=R;V5P96YS>7-T965M('1O96=E=F]E9V0N`"(E<R(@86%N(&AE="!R
M96-H=&5N<WES=&5E;2!T;V5G979O96=D+@`B)7,B(&ES(&YI970@86%N9V5M
M86%K=#H@)7,N`"4N,F9-0B!G96)R=6EK="!V86X@)2XR9DU"('1O96=E<W1A
M86X@*"4N,F8E)2D`)60@)7,@96X@)7,`)60@9&%G96X@=&]T('5W('=A8VAT
M=V]O<F0@=F5R=F%L="X`)60M9&%G('9O;W)U:71Z:6-H=``E<R`M($]P;65R
M:VEN9P`E<R!V:6YG97)A9F1R=6L`)7,@2T(`)7,@3VYD97)H;W5D<W=E<FMZ
M86%M:&5D96X@+2!"979E<W1I9VEN9P`E<R!);G-T96QL96X`)7,@:6YS8VAR
M:6IV96X`)7,@9V5B<G5I:V5R<V]V97)E96YK;VUS=``E<R!B97-T86%T(&%L
M+@`E<R!O<"`E<R`E<P`E<R!I<R!G97)E960@;VT@;VYD97)S=&%A;F1E(&=E
M<V5L96-T965R9&4@;VYD97)H;W5D<W=E<FMZ86%M:&5D96X@=6ET('1E('9O
M97)E;BX@5FEN:R!D92!B97=E<FMI;F<H96XI(&%A;B!D:64@=2!O<"!D:70@
M;6]M96YT('=I;'0@=6ET=F]E<F5N+@`E<R!I<R!V97)E:7-T`"5S(&UI;G5T
M96X`)7,@;FEE="!G979O;F1E;BX`)7,@=&]T("5S('9A;B`E<P`E<R=S(&%D
M<F5S8F]E:P`E<R=S(&%G96YD80`E<R=S(&YO=&ET:65B;V5K`"5S)W,@=&%K
M96YL:6IS=``E<SH@)7,`)7,Z($1I="!B97)I8VAT(&MO;70@;6ES<V-H:65N
M(&YI970@=F%N(&1E9V5N92!D:64@:&5T(&)E=V5E<G0@=&4@>FEJ;BX@5V5E
M<R!V;V]R>FEC:'1I9R!B:6H@:&5T(&ML:6MK96X@;W`@;&EN:W,@:6X@:&5T
M(&)E<FEC:'0@;V8@9&4@869Z96YD97(@<&5R<V]O;FQI:FME(&EN9F]R;6%T
M:64@=&4@<W1U<F5N+@`L('=I;F1V;&%G96X@`"P@=VEN9'9L86=E;B`E<R`E
M<P`L('9A<FEA8F5L('9A;B`E<R!T;W0@)7,`+2T@<V5L96-T97)E;B`M+0`Q
M,B!U=7)S=V5E<F=A=F4`,C0@=75R<W=E97)G879E`#(T('5U<G,`/%9O<FEG
M90!%96X@9&%T86)A<V4@8F%C:V5N9"!I<R!V97)E:7-T('9O;W(@9&ET(&)L
M;VLN`$5R(&AE969T('II8V@@965N(&9A=&%L92!F;W5T('9O;W)G961A86X`
M165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES('9E<F5I<W0@;VT@965N(&)E
M<FEC:'0@=&4@8V]D97)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES
M('9E<F5I<W0@;VT@965N(&]N9&5R=&5K96YD(&)E<FEC:'0@=&4@=F5R:69I
MZW)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!01U`@<VQE
M=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B
M97)I8VAT('1E(&1E8V]D97)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L
M+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V
M97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BX`165N(&]P
M96YB87)E(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)344@<VQE=71E;"!E
M;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT
M('1E(&1E8V]D97)E;BX`165N(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P
M<FEVZ2!3+TU)344@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V
M97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BX`165N(&]P
M96YB87)E(%--24U%('-L975T96P@:7,@=F5R96ES="!O;2!E96X@8F5R:6-H
M="!T92!C;V1E<F5N+@!"97=O;&MI;F<@=F]O<B`Q,BXP,"!U=7(`3&EC:'1E
M(')E9V5N('9O;W(@,3(N,#`@=75R`%)E9V5N('9O;W(@,3(N,#`@=75R`$)U
M:65N('9O;W(@,3(N,#`@=75R`%-N965U=V)U:65N('9O;W(@,3(N,#`@=75R
M`$%-+U!-`$%022!)1`!/=F5R(&1E>F4@961I=&]R`$]V97(N+BX`06)S8F]T
M=&]M`$%B<VUI9&1L90!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N
M('9A;B!61E,@9&ER96-T;W)Y+@!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T
M(&UA:V5N('9A;B!61E,@8F5S=&%N9"X`06-C;W5N=&EN9F]R;6%T:64`06-C
M;W5N='=A8VAT=V]O<F0`06-C;W5N="!B979R;W)E;BX`5F5R86YT=V]O<F1I
M;F<`5&]E=F]E9V5N`$-H:6QD(&=R;V5P('1O979O96=E;@!#:&EL9"!R96-H
M="!T;V5V;V5G96X`2&EE<B!T;V5V;V5G96XZ`$YI975W92!G<F]E<"!T;V5V
M;V5G96X`3FEE=7<@<F5C:'0@=&]E=F]E9V5N`$5E;B`B8VAI;&1G<F]E<"(@
M86%N("(E<R(@=&]E=F]E9V5N`$5E;B`B8VAI;&1R96-H="(@86%N("(E<R(@
M=&]E=F]E9V5N`$YI975W92!G96)R=6EK97(@=&]E=F]E9V5N.@!+;VQO;2!T
M;V5V;V5G96X`3FEE=7=E(&QE9&5N('1O979O96=E;@!086%R('1O979O96=E
M;@!(970@)7,@;65N=2!T;V5V;V5G96X@86QS(&5E;B!-;WII;&QA(%-I9&5B
M87(`5F]E9R!T;V4@86%N(&%D<F5S8F]E:SH`5F]E9R!T;V4@86%N(&UI:FX@
M861R97-B;V5K`$=E8G)U:6ME<B!T;V5V;V5G96X`(B5S(B!A86X@:&5T('-Y
M<W1E96T@=&]E9V5V;V5G9"P@;6%A<B!K;VX@9V5E;B!E>'1R82!I;G-C:')I
M:G9I;F=S:6YF;W)M871I92!T;V5V;V5G96XZ("5S+@`B)7,B(&%A;B!H970@
M<WES=&5E;2!T;V5G979O96=D+B!5(&MU;G0@;G4@86%N;65L9&5N+@!4;V5V
M;V5G96X@=F%N(&=E8G)U:6ME<G,@:7,@=6ET9V5S8VAA:V5L9"X`061R97,`
M061R97-B;V5K`$)E:&5E<B`M(')E8VAT96X@=F]O<B!A;F1E<F4@9V5B<G5I
M:V5R<R!I;G-T96QL96X`0F5H965R`$%D=F5R=&5N=&EE<P!!9F=A;FES=&%N
M`$%L8F%N:>L`06QG97)I:F4`06QI87,`56ET;&EJ;F5N`%5I=&QI:FYI;F<Z
M`$%L;&4`06QL92!G96%U=&AE;G1I8V5E<F1E(&=E8G)U:6ME<G,`06QL92!G
M<F]E<&5N`$%L;&4@<F5C:'1E;@!!;&QE('9I97(@>FEJ9&5N`$UE97)D97)E
M(&%D<F5S<V5N('1O97-T86%N`$EN<W1E;&QE;B!V86X@9V5O<F1E;F1E(&QI
M:G-T('1Y<&4@=&]E<W1A86X_`$)E<W1A870@86P`06QT97)N871I979E($E-
M4U`@86%N;65L9&EN9P!!;'1E<FYA=&EE9B!)35-0('=A8VAT=V]O<F0`06QT
M97)N871I979E($E-4U`@9V5B<G5I:V5R<VYA86T`06QT97)N871I968@92UM
M86EL861R97,`06QT97)N871I979E('-J86)L;VYE;@!!;'1E<FYA=&EE=F4@
M=&5K<W0Z`$%M97)I:V%A;G,@4V%M;V$`165N(&]N9V5L9&EG92!W86%R9&4@
M;W!G96=E=F5N+@!%<B!H965F="!Z:6-H(&5E;B!O;F)E:V5N9&5F;W5T('9O
M;W)G961A86XN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI96UE('!R
M;WAY`$%N='=O;W)D`$%N=&%R8W1I8V$`06YT:6=U82!E;B!"87)B=61A`%1O
M97!A<W-I;F<`5&]E<&%S<VEN9V5N;&EJ<W0`5&]E<&%S<VEN9R!I<R!G97)E
M960N`$]P(&-H:6QD<VAA<F5S('1O97!A<W-E;@!';V5D:V5U<F5N`$=E<V-H
M871T92!G<F]O='1E`$%P<FEL`$%R86)I<V-H("A7:6YD;W=S+3$R-38I`$%R
M8VAI969B97-T86YD<V=R;V]T=&4`07)C:&EE9FYA86T`5V5E="!U('IE:V5R
M(&1A="!U(&AE="!A86YM96QD:6YG<W9E<GIO96L@=F%N("5S('=I;'0@=F5R
M=VEJ9&5R96X_`%=E970@=2!Z96ME<B!D870@=2`B)7,B(&5N(&%L;&4@<W5B
M9W)O97!E;B!W:6QT('9E<G=I:F1E<F5N/P!!<F=E;G1I;FGK`$%R;65N:>L`
M07)M965N<R`H05)-4T-)22TX*0!+=6YS=`!!<G5B80!!<V-E;G-I;VX@96EL
M86YD`$%S8VEI(&MU;G-T`$%Z:>LO4&%C:69I<V-H92!296=I;P!/;2!B979E
M<W1I9VEN9R!V<F%G96X@=F]O<B!H970@=6ET=F]E<F5N('9A;B!O;F1E<FAO
M=61S=V5R:WIA86UH961E;C\`3W!D<F%C:'0@:V]L;VUM96X`4&]G:6YG(&]M
M(&5E;B!N:65T(&)E<W1A86YD92!G<F]E<"!T92!V97)W:6ID97)E;BX`4&]G
M:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD(')E8VAT('1E('9E<G=I:F1E<F5N
M+@!0;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@8F5W97)K
M96XN`%!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9&4@<VAA<F4@=&4@8F5W
M97)K96XN`$%T=')I8G5T96X`075G=7-T=7,`075S=')A;&GK`$]O<W1E;G)I
M:FL`075T:%]C>7)S<6PZ('9E<F5I<W1E(&EM87`@97AT96YT:64@;FEE="!G
M979O;F1E;BX`075T:%]C>7)U<SH@8F%C:V5N9"!H965F="!N:65T(&1E('9E
M<F5I<W1E(&)E:W=A86UH961E;BX`075T:%]C>7)U<SH@=F5R96ES=&4@:6UA
M<"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7V9T<#H@=F5R96ES=&4@
M1E10(&5X=&5N=&EE(&YI970@9V5V;VYD96XN($-O;7!I;&5E<B!02%`@;65T
M(&1E("TM96YA8FQE+69T<"!O<'1I92X`075T:%]I;6%P.B!V97)E:7-T92!)
M34%0(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?:W)B-3H@=F5R96ES
M=&4@:W)B-2!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7VQD87`Z('1O
M979O96=E;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R<W1E=6YD
M('9O;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%9E<G=I:F1E<F5N
M('9A;B!G96)R=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O<B!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@=F5R96ES=&4@3$1!4"!E>'1E
M;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7VQD87`Z($YI970@:6X@<W1A870@
M9V5B<G5I:V5R("5S('1O92!T92!V;V5G96XN($1E('-E<G9E<B!M96QD=#H@
M`$%U=&A?;&1A<#H@3FEE="!I;B!S=&%A="!G96)R=6EK97(@)7,@=&4@=F5R
M=VEJ9&5R96X`075T:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E
M<R!B:6H@=&4@=V5R:V5N`$%U=&A?;&1A<#H@0FEJ=V5R:V5N('9A;B!G96)R
M=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O<B!!8W1I=F4@1&ER
M96-T;W)Y+@!!=71H7VUC86PZ('9E<F5I<W1E($U#04P@97AT96YT:64@;FEE
M="!G979O;F1E;BX`075T:%]S;6)A=71H.B!V97)E:7-T92!S;6)A=71H(&5X
M=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&AE;G1I8V%T:64@;W`@24U!4"!S
M97)V97(@;6ES;'5K="X`075T:&5N=&EC871I92!M:7-L=6MT`$%U=&AE;G1I
M8V%T:64@;6ES;'5K="X@)7,`075T:&5N=&EC871I92!G97=E:6=E<F0@9&]O
M<B!D92!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EE(&]P($944"!S97)V
M97(@;6ES;'5K="X`075T:&5N=&EC871I92!O<"!D92!334(@<V5R=F5R(&UI
M<VQU:W0N`$)E<V-H:6MB87)E('9E;&1E;CH`07IE<F)A:61Z:F%N`$)/1D@@
M17AC=7-E<P!!8VAT97)G<F]N9`!!8VAT97)G<F]N9&ML975R`$9O=70@:V5R
M8F5R;W-W86-H='=O;W)D+@!&;W5T92!K97)B97)O<V=E8G)U:6ME<G-N86%M
M+@!"86AA;6%S`$)A:')E:6X`0F%L=&ES8V@@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97-H`$)A<F)A9&]S`$)A<VES(&%F8F5E;&1I;F=E;F1I<F5C=&]R>2`B
M)7,B(&YI970@9V5V;VYD96XN`$)A<VES;&EJ;@!7:70@<G5S;&%N9`!"96QG
M:>L`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`%9E<FIA87)D86<`0FQO
M:R`B)7,B('9A;B!T;V5P87-S:6YG("(E<R(@;FEE="!G979O;F1E;BX`0FQO
M:VEN<W1E;&QI;F=E;@!";&]K='EP90!6970`0F]L:79I80!";V]K;6%R:W,`
M4F%N9`!286YD9&EK=&4Z`%)A;F1E;@!";W-N:>L@96X@2&5R>F5G;W9I;F$`
M0F5I9&5N`$)O='-W86YA`$]N9&5R:V%N=`!";W5V970@96EL86YD`$)R87II
M;&GK`$)R:71S($EN9&ES8VAE($]C96%A;B!497)R:71O<FEU;0!"<G5N96D@
M1&%R=7-S86QA;0!"=6QG87)I:F4`3VYG96]R9&5N9&4@;&EJ<W0`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:65P=6YT96X`
M0U]E;&5I9V5N<V-H87!P96XN+BX`0V%C:&4@:6YI=&EA;&ES871I92!I<R!N
M:65T(&%F9V5R;VYD+@!!9V5N9&$`2V%L;0!#86UB;V1J80!+86UE<F]E;@!+
M86X@=V%C:'1W;V]R9"!N:65T(&%U=&]M871I<V-H(')E<V5T=&5N+"!N965M
M(&-O;G1A8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(N`$MA;B!N:65T
M(&YA87(@8F5S=&%N9"`B)7,B('-C:')I:G9E;@!+86X@9V5E;B!E>'1E<FYE
M('-E<W-I96AA;F1L97(@8F5H97)E;BX`2V%N(&YI970@=F5R8FEN9&5N(&UE
M="!)34%0('-E<G9E<CH@)7,`2V%N(&)E<W1A;F0@(B5S(B!N:65T(&]P96YE
M;BX`0V%N861A`$%F8G)E:V5N`%!R;V)L965M<F%P<&]R="!A9F)R96ME;@!+
M86X@8F5S=&%N9"`B)7,B(&YI970@=F5R=VEJ9&5R96XN`$MA;B!G965N('1I
M:F1E;&EJ:V4@9&ER96-T;W)Y('9I;F1E;BX`2V%N(&YI970@9&]O<F=A86X@
M>F]N9&5R("=T87)G971&:6QE)R!P87)A;65T97(N`$MA;B!D:7)E8W1O<GD@
M(B5S(B!N:65T('9E<G=I:F1E<F5N+@!+86X@;FEE="!V97)W:6ID97)E;CL@
M)60@8VAI;&1R96X@8F5S=&%A;BX`2V%N(&YI970@;W!N:65U=R!R86YG<V-H
M:6MK96XL(&AE="!A86YT86P@:6YV;V5R96X@;VT@;W!N:65U=R!T92!R86YG
M<V-H:6MK96X@:V]M="!N:65T(&]V97)E96X@;65T(&AE="!O<&=E<VQA9V5N
M(&%A;G1A;"X`2V%N(&)E<FEC:'0@;FEE="!N86%R(&AE="!O<&=E9V5V96X@
M;G5M;65R('9E<G-T=7)E;BX`2V%A<"!697)D90!/<'-C:')I9G0`1')A9V5R
M`$-A=&5G;W)I9>MN(&5N(&QA8F5L<P!#87EM86X@96EL86YD96X`5&5L+FYR
M+FUO8FEE;`!#96QE:6=E;G-C:&%P<&5N`$-E;"!V<FEJ92!R=6EM=&4Z`$-E
M;&5I9V5N<V-H87!P96X`0V5L<W!A=&GK<FEN9SH`5&5L+FYR+FUO8FEE;`!+
M96QT:7-C:"`H25-/+3@X-3DM,30I`$UI9&1E;@!#96YT<F%A;"!!9G)I:V%A
M;G-E(%)E<'5B;&EE:P!#96YT<F%A;"!%=7)O<&5E<R`H25-/+3@X-3DM,BD`
M0V5R=&EF:6-A871D971A:6QS`$-E<G1I9FEC86%T96EG96YA87(`0V5R=&EF
M:6-A871B96QE:60`5'-J86%D`%=I:GII9V5N`%=I:GII9R!U=R!W86-H='=O
M;W)D`%=I:GII9R!D92!N86%M+"!A9')E<R!E;B!O;F1E<G1E:V5N:6YG(&1I
M92!M96X@>FEE="!B:6H@:&5T(&QE>F5N(&5N(&)E86YT=V]O<F1E;B!V86X@
M=7<@92UM86EL<RX`5VEJ>FEG96X@=F%N('5W('=A8VAT=V]O<F0@=V]R9'0@
M;FEE="!O;F1E<G-T975N9"!D;V]R(&1E(&AU:61I9V4@8V]N9FEG=7)A=&EE
M+B!.965M(&-O;G1A8W0@;W`@;65T('5W('-Y<W1E96UB96AE97)D97(N`$MA
M<F%K=&5R`$-O;G1?<F]L965R(&QI;FLN+BX`0VAI;&D`0VAI;F$`0VAI;F5E
M<R!V97)E96YV;W5D:6=D("A'0C(S,3(I`$-H:6YE97,@=')A9&ET:6]N965L
M("A":6<U*0!+:65S('1O97!A<W-I;F<Z`$MI97,@965N('=A8VAT=V]O<F0`
M2VEE<R!E96X@9V5B<G5I:V5R<VYA86T`2VEE<R!D871U;7=E97)G879E.@!+
M:65S(&QI:G-T<W1I:FQT>7!E("AV;V]R(&=E;W)D96YD92!L:6IS=&5N*0!#
M:')I<W1M87,@96EL86YD`$-L87-S9&5F:6YI=&EE('9A;B`E<R!N:65T(&=E
M=F]N9&5N+@!(96QD97(`35-/9F9I8V4@=&%G<R!W:7-S96X`5VES('%U97)Y
M`%=I<R!G96)R=6EK97(Z("5S`%=I<R!G96)R=6EK97(`5VES(&=E8G)U:6ME
M<G-D871A`$QA=&4@;W!K;&%R:6YG96X`2VQI:R!O;2!V97)D97(@=&4@9V%A
M;@!#;&EC:V%T96QL('9I82!(5%10`%-L=6ET('-C:&5R;0!7;VQK96X`5G)O
M96=E(&)E=V]L:VEN9P!"97=O;&MT`$-O8V]S("A+965L:6YG*2!E:6QA;F1E
M;@!::6IB86QK(&EN:VQA<'!E;@!);F=E:VQA<'1E(')A;F1E;@!#;VQO;6)I
M80!+;&5U<@!+;&5U<F5N:VEE>F5R`$ML975R<V5L96-T:64`2V]L;VUM96XZ
M`$MO;&]M=&ET96QS`%-T<FEP<P!/<&1R86-H=`!/<&1R86-H='-H96QL`$]P
M;65R:VEN9P!!;&=E;65N92!N86%M`$-O;6]R96X`0F5D<FEJ9@!#;VUP=71E
M<G,`0V]N9&ET:64`0V]N9&ET:65S`%9E<G-C:&EL;&5N(&EN(&-O;F9I9W5R
M871I90!#;VYF:6=U<F%T:64@=F]O<B!H970@<WEN8VAR;VYI<V5R96X@;65T
M(%!$02=S+"!3;6%R='!H;VYE<R!E;B!/=71L;V]K+@!#;VYF:6=U<F%T:64@
M:7,@=F5R;W5D97)D+@`E<R!C;VYF:6=U<F5R96X`0F5V97-T:6<@=V%C:'1W
M;V]R9`!+;VYG;P!+;VYG;RP@1&4@1&5M;V-R871I<V-H92!297!U8FQI96L@
M=F%N(&1E`%9E<F)I;F1I;F<@;6ES;'5K="X`5F5R8FEN9&EN9R!M:7-L=6MT
M.B``5F5R8FEN9&EN9RP@;65T(&1E(&]P96YB87)E('-L975T96QS97)V97(L
M(&ES(&=E=V5I9V5R9"X`5F5R8FEN9&EN9RP@;65T(&1E(&]P96YB87)E('-L
M975T96QS97)V97(L(&ES(&=E=V5I9V5R9"X@4F5D96XZ("5S("@E<RD`5F5R
M8FEN9&EN9R!M970@1E10('-E<G9E<B!M:7-L=6MT+@!!9')E<W-E;@!!9')E
M<W-E;B!Z:6IN(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E:R!T;V5G979O
M96=D+@!#;VYT96YT('1Y<&4@=F%N(&=E8V]M<')I;65E<F0@8F5S=&%N9#H@
M`$EN:&]U9"!V86X@(B5S(@!$;V]R9V%A;@!#;V]K(&5I;&%N9&5N`$-O;VMI
M90!+;W!IZW)E;@!+;W!IZW)E;B!M:7-L=6MT.B`E<P!+;W!I965R('-E;&5C
M=&EE`$MO<W1E;B!)1`!#;W-T82!2:6-A`$EV;V]R:W5S=`!+;VX@4$=0(&)E
M<FEC:'0@;FEE="!C;V1E<F5N.B``2V]N(%!'4"!B97)I8VAT(&YI970@;VYD
M97)T96ME;F5N.B``2V]N(&)E<FEC:'0@;FEE="!3+TU)344@8V]D97)E;BX`
M2V]N(&)E<FEC:'0@;FEE="!3+TU)344@;VYD97)T96ME;F5N+@!+;VX@861R
M97,@)7,@;FEE="!T;V5V;V5G96XN`$MO;B!G965N('9E<F)I;F1I;F<@;65T
M(&1E($Q$05`M<V5R=F5R(&UA:V5N+@!+;VX@=&5G;V5D("5S(&YI970@8V]N
M=')O;&5R96XN`$MO;B!N:65T('9E<F)I;F1E;B!M970@3$1!4"!S97)V97(N
M`$MO;B!N:65T('9E<F)I;F1E;B!M970@<V5R=F5R("(E<R(@;65T($944#H@
M)7,`2V]N(&=E96X@9&ES=')I8G5T:65L:6IS="`E<R!M86ME;BX`2V]N(%!'
M4"!D871A(&YI970@9&5C;V1E<F5N.B``2V]N(%,O34E-12!D871A(&YI970@
M9&5C;V1E<F5N+@!+;VX@861R97,@)7,@;FEE="!V97)W:6ID97)E;BX`2V]N
M(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!V97)W:6ID97)E;BX`2V]N('-E
M='5P('5P9W)A9&4@<V-R:7!T("(E<R(@;FEE="!V97)W:6ID97)E;BX`2V]N
M(&AE="!E+6UA:6QA9')E<R!V86X@9&4@;VYT=F%N9V5R(&YI970@8F5P86QE
M;BX`2V]N(&-O;7!L971E(&%D<F5S8F]E:R!N:65T(&]P:&%L96XN`$MO;B!C
M;VUP;&5T92!D:7-T<FEB=71I96QI:G-T(&YI970@;W!H86QE;BX`2V]N(&-O
M;7!L971E(&QI:G-T('9A;B!D:7-T<FEB=71I96QI:G-T96X@;FEE="!O<&AA
M;&5N+@!+;VX@<W1R871E9VEE("(E<R(@;FEE="!L861E;BX`2V]N(&1I<F5C
M=&]R>2`B)7,B(&YI970@;6%K96XN`$MO;B!D92!O<&5N8F%R92!S;&5U=&5L
M(&YI970@=F5R:W)I:F=E;B!V86X@9&4@<VQE=71E;'-E<G9E<BX`2V]N("(E
M<R(@;FEE="!O<&5N96X@=F]O<B!S8VAR:6IV96XN`$MO;B`E<R!N:65T(&]P
M96YE;BX`2V]N(&]N9&5R:&]U9'-T86ME;FUO9'5L92`E<R!N:65T(&]P96YE
M;@!+;VX@9&ER96-T;W)Y("(E<R(@;FEE="!O<&5N96XN`$MO;B!D92!,1$%0
M+7-E<G9E<B!N:65T(&)E<F5I:V5N+@!+;VX@)7,@;FEE="!L97IE;BX`2V]N
M(&AE="!W86-H='=O;W)D('9A;B!D92!G97=E;G-T92!G96)R=6EK97(@;FEE
M="!R97-E='1E;BX@4V]M;6EG92!O9B!A;&QE(&1E=&%I;',@>FEJ;B!N:65T
M(&IU:7-T+B!0<F]B965R(&]P;FEE=7<@;V8@;F5E;2!C;VYT86-T(&]P(&UE
M="!D92!S>7-T965M8F5H965R9&5R+"!W86YN965R('4@=F5R9&5R92!H=6QP
M(&YO9&EG(&AE969T+@!+;VX@04-,(&YI970@;W!H86QE;@!+;VX@861R97-B
M;V5K("5S(&YI970@;W!H86QE;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@
M;FEE="!O<&AA;&5N+@!+;VX@9&ES=')I8G5T:65L:6IS=&5N("5S(&YI970@
M;W!H86QE;BX`2V]N('-E<G9E<F)E:W=A86UH961E;B!N:65T(&]P:&%L96X`
M2V]N(&-O;F9I9W5R871I92!N:65T('1E<G5G>F5T=&5N+@!+;VX@9&ER96-T
M;W)Y("(E<R(@;FEE="!V97)W:6ID97)E;BX`2V]N(&-O;F9I9W5R871I92`E
M<R!N:65T(&]P<VQA86XN`$MO;B!G965N(&)A8VMU<&-O;F9I9W5R871I92!O
M<'-L86%N+@!+;VX@9V5E;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S;&%A;CH@
M)7,`2V]N('-E='5P('5P9W)A9&4@<V-R:7!T(&YI970@;W!S;&%A;B!A;',Z
M("(E<R(N`$MO;B!H970@8F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N9"!N:65T
M(&]P<VQA86X@)7,N`$MO;B!H970@8V]N9FEG=7)A=&EE8F5S=&%N9"`E<R!N
M:65T(&]P<VQA86XN(%4@:W5N="!O9B#KZVX@=F%N(&1E(&]P=&EE<R!G96)R
M=6EK96X@;VT@9&4@8V]D92!T97)U9R!O<"!T92!S;&%A;B!O<"`E<R!O9B!O
M;F1E<G-T86%N9&4@8V]D92!H86YD;6%T:6<@;F%A<B`E<R!K;W!IZW)E;BX`
M2V]N(&1E($Q$05`M<V5R=F5R(&YI970@9&]O<GIO96ME;BX`2V]N("(E<R(@
M;FEE="!L;W-K;W!P96QE;BX`2V]N(&%D<F5S("5S(&YI970@8FEJ=V5R:V5N
M+@!+;VX@9&ES=')I8G5T:65L:6IS="`E<R!N:65T(&)I:G=E<FME;BX`2V]N
M(&-O;F9I9W5R871I92!V;V]R("(E<R(@;FEE="!W96=S8VAR:6IV96XZ("5S
M`$MO;B!D92!-;WII;&QA(%-I9&5B87(@;FEE="!V:6YD96XN(%IO<F<@97)V
M;V]R(&1A="!D92!S:61E8F%R(&]P96X@:7,N`$MO;B!G96)R=6EK97(@(B5S
M(B!D92!V;VQG96YD92!R96-H=&5N(&]P(&1E(&UA<"`B)7,B(&YI970@9V5V
M96XZ("5S`$=E=&5L9&4@=&5K<W0`3&%N9`!#=7)S=7-S96X`36%K96X`36%A
M:R!E96X@;&EN:P!-86%K(&5E;B!N:65U=V4`36%A:R!S=6)M87!P96X`16EG
M96YA87)R96-H=&5N`$-R961I=&-A<F1N=6UM97(`2W)O871IZP!#=6)A`$AU
M:61I9V4@-"!F87-E;@!(=6ED:6=E('-E<W-I97,`2'5I9&EG92!T:6ID`$AU
M:61I9V4@55),(&ES`$AU:61I9V4@9V5B<G5I:V5R<P!(=6ED:6<@=V5E<@!(
M=6ED:6=E(&-O;F1I=&EE.B``2'5I9&EG92!S=&EJ;`!!86YP87-S96X@=F%N
M('1A:V5N('1I:F1E;G,@86%N;65L9&EN9R!B:6H@)7,N`$MN:7!P96X`4V5L
M96-T:64@:VYI<'!E;@!#>7!R=7,`0WER:6QL:7-C:"`H2T])."U2*0!#>7)I
M;&QI<V-H("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&ES8V@O56MR86EN<R`H2T])
M."U5*0!4<VIE8VAI<V-H92!297!U8FQI96L`1$0`1%-.("AZ:64@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*0!$86=E;&EJ:W,`1&%T851R964@8G)O=W-E<@!$871A
M8F%S92!D;V]R>F]E:V5N`$1A='5M`$1A='5M($]N='9A;F=E;@!$871U;2!S
M96QE8W1I90!$86<`5F5R7W=I:F1E<B!K;VQO;0!$96-E;6)E<@!$96-I;6%L
M92!G971A;&QE;@!);G-P<FEN9V5N('9E<FML96EN96X`4W1A;F1A87)D`%-T
M86YD86%R9"!K;&5U<@!3=&%N9&%A<F0@:61E;G1I=&5I=`!3=&%N9&%A<F0@
M<VAE;&P`1&5F:6YI=&EE<P!697)W:6ID97)E;@!697)W:6ID97(@8V5L`$=R
M;V5P('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!L;V<`4F5C:'0@=F5R=VEJ9&5R
M96X`5F5R=VEJ9&5R(&5N('=I<R!B97)I8VAT96X`5F5R=VEJ9&5R(&-E;`!6
M97)W:6ID97(@:V]L;VT`0F5S=&%A;F0@86QT97)N871I968@<VIA8FQO;VX@
M=F5R=VEJ9&5R96X`5F5R=VEJ9&5R(&)E<FEC:'1E;@!296-H=&5N('9A;B`B
M)7,B('9E<G=I:F1E<F5N`%)E8VAT96X@96X@979E;G1U96QE('-U8G)E8VAT
M96X@=F]O<B`B)7,B('9E<G=I:F1E<F5N/P!697)W:6ID97(@<FEJ`$=E<V5L
M96-T965R9&4@:61E;G1I=&5I="!V97)W:6ID97)E;@!697)W:6ID97(@<W5B
M;6%P<&5N`%9E<G=I:F1E<B!D92!H=6ED:6=E(&MO;&]M`%9E<G=I:F1E<B!D
M92!H=6ED:6=E(')I:@!3971U<"!U<&=R861E('-C<FEP="`B)7,B('9E<G=I
M:F1E<F0N`$%F;&5V97)T:6ID`$1E;F5M87)K96X`0F5S8VAR:6IF(&AE="!P
M<F]B;&5E;0!"97-C:')I:G9I;F<`1&5T86EL<R`H;V]K(&EN($AO<F1E)W,@
M;&]G8F5S=&%N9"DZ`$1E=&%I;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S>7-T
M965M8F5H965R9&5R+@!/;G1W:6MK96QI;F<`1&%U=W!U;G0`1&%U=W!U;G0@
M=F]O<B!H970@869G96QO<&5N('5U<CH@`$1A=7=P=6YT.B``4FEC:'1I;F<@
M;&EN:W,@;F%A<B!R96-H=`!2:6-H=&EN9R!R96-H=',@;F%A<B!L:6YK<P!$
M:7)E8W1O<GD`,C0M=75R<R!T:6ID=V5E<F=A=F4_`%=E97)G879E;W!T:65S
M`$=E9&5T86EL;&5E<F1E('=E97)S=F]O<G-P96QL:6YG('1O;F5N`%=E97)S
M=F]O<G-P96QL:6YG('1O;F5N("A4048I`%=E97)G879E9F]R;6%A=`!6;V]R
M8F5R96ED:6YG<VYO=&EF:6-A=&EE`$1J:6)O=71I`$YI970@=F5R=VEJ9&5R
M96X`;6%I;G1E;F%N8V4N<&AP(&YI970@9&ER96-T(&%A;G-P<F5K96X`0F5V
M870@9&4@965R<W1E(')I:B!D92!V96QD;F%M96X_(%IO(&IA+"!D:70@:&]K
M:F4@86%N=FEN:V5N.@!$;VUI;FEC80!$;VUI;FEC86%N<V4@4F5P=6)L:65K
M`$=E96X@86-C;W5N=#\@4V-H<FEJ9B!U(&EN+@!$;W=N;&]A9&5N`"5S(&1O
M=VYL;V%D96X`1&]W;FQO860@9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92!A
M;',@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI:G-T`$1R=6=S`$4M36%I;`!%
M+6UA:6P@;F%A<B!335,@9V%T97=A>2!S='5U<G!R;V=R86UM82P@=F]O<B!D
M<F%G97)S(&1I92!D97IE('-E<G9I8V4@;VYD97)S=&5U;F5N+@!%4E(`16-U
M861O<@!"97=E<FME;@!";&]K(&)E=V5R:V5N`$=R;V5P(&)E=V5R:V5N`%)E
M8VAT(&)E=V5R:V5N`%)E8VAT96X@8F5W97)K96X`4F5C:'1E;B!V86X@)R5S
M)R!B97=E<FME;@!/<'1I97,@8F5W97)K96X@=F]O<CH`4F5C:'1E;B!V86X@
M(B5S(B!B97=E<FME;@!296-H=&5N('9A;B`E<R!B97=E<FME;@!/;F1E<G=I
M:G,`16=Y<'1E`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`12UM86EL`$4M
M;6%I;&%D<F5S`$4M;6%I;&%D<F5S<V5N(&UO971E;B!O=F5R965N:V]M96XN
M`$4M;6%I;"!M970@8F5V97-T:6=I;F<`12UM86EL(&YA87(@4TU3(&=A=&5W
M87D`16UO=&EC;VYS`$QE96<@8F5R:6-H="X`1V5E;B!R97-U;'1A870N`$QE
M9V4@>F]E:W1E<FUE;@!);G9O96=E;B!V86X@869B965L9&EN9V5N('5I="!F
M;W1O86QB=6US(&EN('1E:W-T(&EN<V-H86ME;&5N/P!296-H=&ML:6MK96X@
M8V]N=&5X="!M96YU(&EN<V-H86ME;&5N/P!%:6YD:F%A<@!697)G<F]O="!E
M9&ET;W(`1V5E9B!E96X@8F5V96EL:6=I;F=S=G)A86<@9&EE('4@9V5V<F%A
M9V0@=V]R9'0L('=A;FYE97(@:&5T(&YO9&EG(&ES(&]M('5W('=A8VAT=V]O
M<F0@=&4@<F5S971T96XL(&(N=BX@)W=A="!I<R!D92!N86%M('9A;B!U=R!H
M=6ES9&EE<C\G.@!6;V5R(&1E(&%F8F5E;&1I;F<@55),(&AI97(@:6X`5F]E
M<B!O;F1E<G-T86%N9&4@;&5T=&5R<R!I;CH`17%U871O<FEA86P@1W5I;F5E
M`$5R:71R96$`1F]U=`!&;W5T(&)I:B!M86ME;B!V86X@8FQO:SH@)7,`1F]U
M="!B:6H@=F5R=VEJ9&5R96X@=F%N('-Y;F,@86YK97(Z("5S`$9O=70@8FEJ
M('9E<G=I:F1E<F5N('9A;B!S>6YC(&QO9SH@)7,`1F]U="!B:6H@;W!H86QE
M;B!V86X@:6YH;W5D.B`E<P!&;W5T(&)I:B!B:6IW97)K96X@=F%N('=A8VAT
M=V]O<F0Z("5S`$9O=70@;65T(&4M;6%I;&)E<FEC:'0N`$9O=70@8FEJ('-C
M:')I:G9E;B!V86X@(B5S(BX`17-T;&%N9`!%=&AI;W!IZP!%=&YI<V-H`$5U
M<F]P80!%;&ME(#$U(&UI;G5T96X`16QK92`R(&UI;G5T96X`16QK92`S,"!S
M96-O;F1E;@!%;&ME(#4@;6EN=71E;@!%;&ME(&%A;FUE;&1I;F<`16QK(&AA
M;&8@=75R`$5L:V4@;6EN=75T`%9O;W)B965L9'=A87)D96XZ`%5I='9O97)E
M;@!5:71K;&%P<&5N`%II:F)A;&L@=6ET:VQA<'!E;@!697)W86-H='1E("<I
M)P!697)W86-H='1E(&5N:V5L('=O;W)D(&]F(&%A;F=E:&%A;&1E('IO96MT
M97)M`%9E<G9A;&1A='5M`$5X<&]N96YT`%9O;W)G<F]N9&ML975R`$944"!U
M<&QO860@=F%N('-E='5P`$]P:&%L96X@=F]O<FME=7)S:6YS=&5L;&EN9V5N
M(&UI<VQU:W0N`%9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&ES(&UI
M<VQU:W0N`%9E<F)I;F1I;F<@;65T(&1E(%--0BUS97)V97(@:7,@;6ES;'5K
M="X`2V]P:>MR96X@=6ET("(E<R(@:7,@;6ES;'5K="X`2V]P:>MR96X@;F%A
M<B`B)7,B(&ES(&UI<VQU:W0N`$UA:V5N('9A;B!N:65U=V4@4T%33"!V97)B
M:6YD:6YG(&ES(&UI<VQU:W0N`%9E<G!L86%T<V5N(&YA87(@(B5S(B!I<R!M
M:7-L=6MT+@!/<&AA;&5N('9A;B`E<R!I<R!M:7-L=6MT`$UO;VD`1F%L:VQA
M;F0@96EL86YD96X@*$UA;'9I;F%S*0!&87)OZW(@96EL86YD96X`1F%T86QE
M(&9O=70Z`$9A>`!&87AE;@!&96)R=6%R:0!6;V5L="!A;',`5F]E;'0@86QS
M.B``16YK96QE(&)U:65N`$5N:6=E('-N965U=V)U:65N`%9E;&1M871R:7@`
M1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!"97-T86YD`$%A;G1A
M;"!B97-T86YD96XZ("5S(&)E<W1A;F0`06%N=&%L(&)E<W1A;F1E;CH@)7,@
M8F5S=&%N9&5N`$)E<W1A;F1B96AE97(`0F5S=&%N9'-N86%M`$)E<W1A;F0@
M:VEE>F5N`$)E<W1A;F1U<&QO860`0F5S=&%N9'5P;&]A9',@=V]R9&5N(&YI
M970@;VYD97)S=&5U;F0N`$9I;'1E<G,`1FEN;&%N9`!%97)S=&4@:&5L9G0`
M165R<W1E(&MW87)T86%L`%9E<FAO=61I;F<@:&5R<W1E;&QE;@!/;6ME<F5N
M`$1R:6IV96X`36ES=`!-87`@)7,@8F5S=&%A="!N:65T`$9O;G1K;&5U<@!6
M;V5D<V5L`%9O;W(@8G)O=W-E<G,@9&EE(&=E96X@869B965L9&EN9V5N(&]N
M9&5R<W1E=6YE;@!7965R<W9O;W)S<&5L;&EN9R`H5$%&*0!6;V]R=6ET>FEC
M:'1D86=E;B`H;65R:R!O<"!D870@:&5T(&=E9V5V96X@=F]O<G5I='II8VAT
M(&1A9V5N(&5N(&YA8VAT96X@9V5E9G0[(&5E;B!G<F]O="!A86YT86P@:V%N
M(')E<W5L=&5R96X@:6X@965N(&)R965D(&)L;VLI`%5W('=A8VAT=V]O<F0@
M=F5R9V5T96X_`$9O<FUU;&EE<F5N`$9O<G1U;F4`1F]R='5N971Y<&4`1F]R
M='5N97,`1F]R='5N97,@,@!&;W)U;7,`1&]O<G-T=7)E;@!6<@!&<F%M97,`
M1G)A;FMR:6IK`$9R86YK<FEJ:RP@2&]O9F1S=&5D96QI:FL`1G)A;G,@1W5Y
M86YA`$9R86YS(%!O;'EN97-IZP!&<F%N<V4@6G5I9&5L:6IK92!497)R:71O
M<FEA`%9A;@!686X@9&4@`%9O;&QE9&EG92!B97-C:')I:G9I;F<`5F]L;&4@
M;6%A;@!6;VQL961I9V4@;F%A;0!'86)O;@!!;&)U;2!W86%R=6ET(&1E(&%F
M8F5E;&1I;F<@9V5H86%L9"!D:65N="!T92!W;W)D96X`06QB=6TZ`$=A;6)I
M80!'96YE<F5E<B`E<R!C;VYF:6=U<F%T:64`1V5G96YE<F5E<F1E(&-O9&4`
M1V5O<F=IZP!$=6ET<VQA;F0`1VAA;F$`1VEB<F%L=&%R`%9O;W)N86%M`$=L
M;V)A;&4@;W!T:65S`$=A`$=O961E;`!';V]G;&4@:V%A<G1E;@!';V]G;&4@
M>F]E:V5N`$=R:6IS<V-H86%L`$=R:65K96YL86YD`$=R:65K<R`H25-/+3@X
M-3DM-RD`1W)O96YL86YD`$=R96YA9&$`1W)O97!S8F5H965R`$=R;V5P;F%M
M96X@;6]G96X@;FEE="!L965G('II:FX`1W)O=7!?;&1A<#H@3FEE="!I;B!S
M=&%A="!G<F]E<"`E<R!T;V4@=&4@=F]E9V5N+B!$92!S97)V97(@;65L9'0Z
M(`!'<F]U<%]L9&%P.B!.:65T(&EN('-T86%T(&=R;V5P("5S('1E('9E<G=I
M:F1E<F5N`$=R;W5P7VQD87`Z($YI970@:6X@<W1A870@9W)O97`@)7,@8FEJ
M('1E('=E<FME;@!'<F]E<&5N`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`
M1W5E<FYS97D`1V%S="!R96-H=&5N`$=A<W1E;F)O96L`1W5I;F5E`$=U:6YE
M92U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@=V5I9V5R="!L868@;VT@
M9&4@;&%A='-T92!C96P@:6X@9&4@<FEJ('1E('9E<G=I:F1E<F5N+@!(5$U,
M07)E82!W96EG97)T(&QA9B!O;2!D92!L86%T<W1E(&MO;&]M(&EN(&1E('1A
M8F5L('1E('9E<G=I:F1E<F5N+@!(5$U,07)E82!W96EG97)T(&QA9B!O;2!D
M92!L86%T<W1E(')I:B!I;B!D92!T86)E;"!T92!V97)W:6ID97)E;BX`2%14
M4"!A=71H96YT:6-A=&EE(&YI970@9V5V;VYD96XN`$AA:71I`$AA<V@M86QG
M;W)I=&AM90!.979E;`!+;W``2V]P<&5N`$AE87)D(&5I;&%N9"!E;B!-8T1O
M;F%L9"!E:6QA;F1E;@!:=V%R92!O;G=E97)S8G5I`$AE8G)E975W<R`H25-/
M+3@X-3DM."U)*0!(;V]G=&4`2&5L<`!(96QP(&)I:B!G96)R=6EK('9A;B!E
M9&ET;W(`2&5L<&5R`$AA;&9R;VYD`$AI97(@:7,@:&5T(&)E9VEN('9A;B!H
M970@8F5S=&%N9#H`2&]O9P!(;U]M90!(;VQY(%-E92`H5F%T:6-A86YS=&%D
M*0!(;VUE`$%D<F5S("AP<FEVZ2D`2&]M961I<F5C=&]R>0!496PN;G(N("AP
M<FEVZ2D`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!/
M;F=E;&1I9V4@)7,@6$U,(&1A=&$@=&5G96YG96MO;65N(&EN(&)E<FEC:'0@
M)7,`2&]R9&4O2V]L86(Z($=E96X@8F5R:6-H="!C;W)R97-P;VYD965R="!M
M970@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!'965N(&]B:F5C="!V86X@='EP
M92`E<R!G979O;F1E;B!I;B!B97)I8VAT("5S`$AO<F1E+TMO;&%B.B`E<R!M
M970@<W5C8V5S('9E<G=I:F1E<F0@(B5S(@!(;W)D92]+;VQA8CH@1&4@:6YT
M97)G<F%T:64@=F5R96ES="!D92`G9&]M>&UL)R!E>'1E;G-I90!(;W)D92]+
M;VQA8CH@2V%N(&=E96X@;FEE=7=E(%A-3"!B;V]M(&UA:V5N('9O;W(@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!+86X@)7,@(B5S(B!N:65T('9E<G=I:F1E
M<F5N.B`E<P!(;W)D92]+;VQA8CH@3FEE="!I;B!S=&%A="!H970@34E-12!)
M1"P@=F]O<B!H970@9V5D965L=&4@;65T('1Y<&4@)7,L(&]P('1E(&AA;&5N
M`$AO<F1E+TMO;&%B.B!+86X@)7,@(B5S(B!N:65T('-Y;F-H<F]N:7-E<F5N
M.B`E<P!(;W)D92]+;VQA8CH@2V%N(&=E9&5E;&1E(&)R;VYN96X@;FEE="!S
M>6YC:')O;FES97)E;CH@)7,`2&]R9&4O2V]L86(Z($]N8F5K96YD92!G961E
M96QD92!B<F]N("(E<R(`2&]R:7IO;G1A;&4@;&EJ;@!(;W)I>F]N=&%L92!V
M<FEJ92!R=6EM=&4`2&]R:7IO;G1A86PZ`$AO92!K=V%M('4@:&EE<C\@*$=R
M86%G(')A<'!O<G1A9V4A*0!(;V5V965L(&MO;&]M;65N('=I;'0@=2!S86UE
M;G9O96=E;C\`2&]E=F5E;"!V96QD96X@*&MO;&]M;65N*2!Z:6IN(&5R/P!(
M;V5V965L(')I:F5N('=I;'0@=2!S86UE;G9O96=E;C\`5F]C:'1I9VAE:60`
M5F]C:'1I9VAE:60Z(`!(=6UO<FES=&5N`$AO;F=A<FEJ90!-86ME;B!V86X@
M24U!4"!M86EL8F]X(&UI<VQU:W0Z("5S`%9E<G=I:F1E<F5N('9A;B!)34%0
M(&UA:6QB;W@@;6ES;'5K=#H@)7,`36%K96X@=F%N($E-05`@;6%I;&)O>"!Q
M=6]T82!M:7-L=6MT.B`E<P!)4"!!9')E<P!)4"!A9')E<R!N:65T(&)E<V-H
M:6MB86%R+@!)4"!A9')E<R!V86QT(&YI970@8FEN;F5N(&AE="!T;V5G97-T
M86YE($-)1%(@8FQO:RX`25`@;&]C:V1O=VX@;W9E<G1R961I;F<N`%)I:B!I
M7VYV;V5G96X@=F]O<@!)2G-L86YD`$%L;&5E;B!P:6-T;V=R86UM96X`4&EC
M=&]G<F%M;65N('9O;W(@)7,`4&EC=&]G<F%M;65N(&UE="!T96MS=`!)9&5N
M=&ET96ET<VYA86TZ`%=A;FYE97(@:&5T(&YI970@9V]E9"!W;W)D="!W965R
M9V5G979E;BP@)7,@;VT@:&5T(&EN(&5E;B!N:65U=R!S8VAE<FT@=&4@;W!E
M;F5N+@!!;',@=2!G965N('!I8W1O9W)A;6UE;B!Z:65T+"!B:6H@9V5B<G5I
M:R!V86X@26YT97)N970@17AP;&]R97(L(&MA;B!H970@;F]D:6<@>FEJ;B!D
M:70@=F%K:F4@86%N('1E('9I;FME;B!O;2!03D<@=')A;G-P87)A=&EE('5I
M="!T92!S8VAA:V5L96XN`%=A;FYE97(@=2!D:70@8F5R:6-H="!Z:65T+"!M
M86%R(&=E96X@869B965L9&EN9RP@9&%N(&MA;B!D92!A9F)E96QD:6YG(&1I
M92!U('=I;'0@=7!L;V%D96X@;FEE="!D;V]R('5W(&)R;W=S97(@=V]R9&5N
M('=E97)G96=E=F5N+@!!9F)E96QD:6YG<V)E;V]R9&5L:6YG.@!!9F)E96QD
M:6YG(%523`!!9F)E96QD:6YG(%523#H`069B965L9&EN9R!U:70@86QB=6T`
M069B965L9&EN9R!U:70@86QB=6TZ`$%F8F5E;&1I;F=S=7!L;V%D`$%F8F5E
M;&1I;F=E;@!);7!O<G1E<F5N+"!S=&%P("5D`$=E:6UP;W)T965R9"!V96QD
M.B`E<P!'96EM<&]R=&5E<F1E('9E;&1E;CH`4FEJ(&EN=F]E9V5N(&YA`$]N
M:G5I<W1E(&)E=V5R:VEN9W-C;V1E(&]P9V5G979E;BX`3VYJ=6ES=&4@9V5B
M<G5I:V5R<VYA86T@96XO;V8@=V%C:'1W;V]R9"X`3VYJ=6ES=&4@9V5B<G5I
M:V5R<VYA86T@;V8@86QT97)N871I968@861R97,N(%!R;V)E97(@;W!N:65U
M=R!O9B!N965M(&-O;G1A8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(L
M('=A;FYE97(@=2!V97)D97)E(&AU;'`@;F]D:6<@:&5E9G0N`%9E<F=R;V]T
M(&EN<W!R:6YG:6YG`$EN9&EA`$EN9&EV:61U96QE(&=E8G)U:6ME<G,`26YD
M;VYE<VGK`$EN9F\`26YF;W)M871I90!);F9O<FUA=&EE(&YI970@;&%N9V5R
M(&)E<V-H:6MB86%R+@!+;VQO;2!I;G9O96=E;B!N80!!9F)E96QD:6YG(&EN
M=F]E9V5N`%1A8F5L(&EN=F]E9V5N`%=E8FQI;FL@:6YV;V5G96X`7TMO;&]M
M(&EN=F]E9V5N('9O;W(`165N(&YI975W92!K;VQO;2!I;G9O96=E;B!N82!D
M92!H=6ED:6=E`$5E;B!N:65U=V4@:V]L;VT@:6YV;V5G96X@=F]O<B!D92!H
M=6ED:6=E`$5E;B!N:65U=V4@<FEJ(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4`
M165N(&YI975W92!R:6H@:6YV;V5G96X@;F$@9&4@:'5I9&EG90!%96X@;FEE
M=7=E('!A<F%G<F%A9B!I;G9O96=E;B!N82!D92!H=6ED:6=E(&YO9&4`165N
M(&YI975W92!P87)A9W)A868@:6YV;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E
M`$%L=&5R;F%T:65F('-J86)L;V]N(&EN=F]E9V5N`$5E;B!E+6UA:6QA9')E
M<R!I;G9O96=E;BP@=V%A<B!U(&AE="!N:65U=V4@=V%C:'1W;V]R9"!K86X@
M;VYT=F%N9V5N.@!#96P@:6YV;V5G96X@;F$`0V5L(&EN=F]E9V5N('9O;W(`
M2V]L;VT@:6YV;V5G96X@;F$`2V]L;VT@:6YV;V5G96X@=F]O<@!"97)I8VAT
M96X@:6YV;V5G96X`4&%R86=R86%F(&EN=F]E9V5N(&YA`%!A<F%G<F%A9B!I
M;G9O96=E;B!V;V]R`%)I:B!I;G9O96=E;B!N80!2:6H@:6YV;V5G96X@=F]O
M<@!(970@9V5W96YS=&4@86YT=V]O<F0@=F]O<B!D92!B979E:6QI9VEN9W-V
M<F%A9R!I;G9O96=E;CH`069B965L9&EN9R!I;G9O96=E;B]A86YP87-S96X`
M3&EN:R!I;G9O96=E;B]A86YP87-S96X`3VYV;VQD;V5N9&4@:W)E9&EE="!O
M;2!N86%R(&1E(&1I<W1R:6)U=&EE;&EJ<W0@=&4@>F5N9&5N+@!/;G9O;&1O
M96YD92!K<F5D:65T`$EN=&5G97(`26YT96=E<B!L:6IS=`!/;F=E;&1I9V4@
M541(+B`H57-E<B!$871A($AE861E<BDN`$]N9V5L9&EG92!:25`@9&%T80!/
M;F=E;&1I9V4@=&]E<&%S<VEN9RX`3VYG96QD:6<@8F%T8V@@240N`$]N9V5L
M9&EG92!D871A(&]P9V5G979E;BX`3VYG96QD:6<@8F5S=&5M;6EN9V%D<F5S
M+@!/;F=E;&1I9R!T:6ID9F]R;6%A=`!/;F=E;&1I9V4@;&EC96YT:65S;&5U
M=&5L+@!/;F=E;&1I9V4@;&]C871I92!O<&=E9V5V96XN`$]N9V5L9&EG(&US
M9U]T>7!E+@!/;F=E;&1I9R!O9B!O;G1B<F5K96YD(&%P:5]I9"X`3VYG96QD
M:6=E(&]F(&]N=&)R96ME;F1E('!A<F%M971E<G,N`$]N9V5L9&EG('!A<F5N
M="!R96-H="X`3VYG96QD:6<@<&%R=&YE<B!I9"X`3VYG96QD:6=E('!R;V1U
M8W1I96-O9&4N`$]N9V5L9&EG('!R;W1O8V]L+@!/;F=E;&1I9V4@;VYT=F%N
M9V5R.B`B)7,B`$]N9V5L9&EG92!G961E96QD92!B<F]N`$]N9V5L9&EG(&)R
M;VYA9')E<RX`3VYG96QD:6=E('5N:6-O9&4@9&%T82X`26YV96YT87)I<P!3
M96QE8W1I92!O;6ME<F5N`$ER86XL($ES;&%M:71I<V-H92!297!U8FQI96L@
M=F%N`$ER86L`265R;&%N9`!%:6QA;F0@36%N`$=E:7-O;&5E<F1E(&]N=V5E
M<G-B=6EE;@!)<W)AZVP`56ET9V5V97(`0W5R<VEE9@!)=&%L:>L`2F%M86EC
M80!*86YU87)I`$IA<&%N`$IA<&%N<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*
M;W)D86YIZP!*=6QI`$IU;FD`=6ET;&EJ;F5N`$=E8V5N=')E97)D('5I=&QI
M:FYE;@!6;VQL961I9R!U:71L:6IN96X`3&EN:W,@=6ET;&EJ;F5N`%)E8VAT
M<R!U:71L:6IN96X`2V%Z86-H<W1A;@!/<FEG:6YE96P@8F5H;W5D96X_`$ME
M;FEA`$ME<F)E<F]S('-E<G9E<B!W96EG97)D92!A=71H96YT:6-A=&EE+@!+
M97)N96P@3F5W8FEE<P!3;&5U=&5L(&UA:V5N`%-L975T96QV:6YG97)A9F1R
M=6L`4VQE=71E;&QE;F=T90!3;&5U=&5L='EP90!3;&5U=&5L9V5B<G5I:P!$
M92!S;&5U=&5L(&)E<W1A870@86P@;W`@9&4@;W!E;F)A<F4@<VQE=71E;'-E
M<G9E<BX`2VEN9&5R96X`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:7-C:&4@
M5F]L:W-R97!U8FQI96L@=F%N`$MO<F5A+"!297!U8FQI96L@=F%N`$MO<F5A
M86YS("A%54,M2U(I`$MO97=E:70`2WER9VEE<VGK`$]?<&UA86L`5&%A;`!$
M96UO8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K($QA;P!,86%T<W1E(&AE;&9T
M`$QA871S=&4@=V%C:'1W;V]R9'=I:GII9VEN9P!,86%T<W1E(&MW87)T:65R
M`$QA871S="!B:6IG97=E<FMT.@!,86%T<W1E(&%A;FUE;&1I;F<Z("5S`$QA
M871S=&4@86%N;65L9&EN9SH@)7,@=F%N("5S`$QA871S=&4@86%N;65L9&EN
M9SH@3F]O:70`3&5T;&%N9`!296-H=&5N`$]P;6%A:P!,86%T(&QE96<@=F]O
M<B!G965N(')A;F0`3&EB86YO;@!,:6YK<P!,:6YK<V4@:V]P`$QI;FMS92!W
M86%R9&5N`$QE<V]T:&\`3FEV96%U`$QI8F5R:6$`3&EB:7-C:&4@07)A8FES
M8VAE($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!:86-H="!B=6ET:F4`3&EC
M:'1E(')E9V5N`%9R;V5G(&QI8VAT92!R96=E;@!,:6-H=&4@<F5G96X`3&EC
M:'1E(')E9V5N8G5I`$QI8VAT92!R96=E;B!M970@;VYW965R`$QI8VAT92!S
M;F5E=7<`3&EC:'1E('-N965U=V)U:0!,:6UE<FEC:P!,:6YK`$QI;FL@=VEJ
M<W0@;F%A<CH`3&EN:R!H970@92UM86EL861R97,@86%N(&1E(&YI975W(&)E
M<FEC:'0@<&%G:6YA('1I:F1E;G,@=V5E<F=A=F4`3&EN:W,`3&EN=7@@0V]O
M:VEE`$QI:G-T("T@9V5B<G5I:V5R(&MA;B!D92!M87`@>FEE;@!$871A8F%S
M96QI:G-T`$QI:G-T('9A;B!H96QP(&]N9&5R9&5L96X`5&%B96QL:6IS=`!,
M:6IS="U!<F-H:65F`$QI:G-T+4AE;'``3&EJ<W0M260`3&EJ<W0M16EG96YA
M87(`3&EJ<W0M4&]S=`!,:6IS="U);G-C:')I:G9E;@!,:6IS="U5:71S8VAR
M:6IV96X`5V5E<F=E=F5N('9A;B!S97-S:65L:6IS="!I<R!M:7-L=6MT.B`E
M<P!7965R9V5V96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!M:7-L=6MT.B`E
M<P!7965R9V5V96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!U:71G97-C:&%K
M96QD+@!,:71E<F%T=75R`$QI=&]U=V5N`$QA9&5N+BXN`$QO:V%L92!T:6ID
M.@!,86YD:6YS=&5L;&EN9R!E;B!T:6ID`$QO8V%T:64`06%N;65L9&5N`$QO
M9R!V86X@=F]O<F=A86YD92!S>6YC('-E<W-I90!!9FUE;&1E;@!!86YM96QD
M96X`06%N;65L9'1A:V5N`$%A;FUE;&1I;F<@;6ES;'5K="!O;61A="!U=R!G
M96)R=6EK97)S;F%A;2!O9B!W86-H='=O;W)D(&]N:G5I<W0@:7,@:6YG979O
M97)D+@!!86YM96QD:6YG(&UI<VQU:W0N`$QA;F=E('1E:W-T`$QI969D90!,
M86%G`$=R:65K<V4@:VQE:6YE(&QE='1E<G,`3&%T:6IN<V4@:VQE:6YE(&QE
M='1E<G,`2VQE:6YE(%)O;65I;G-E(&=E=&%L;&5N`$QU>&5M8G5R9P!-30!-
M3U1$`$U3+51.148@8FEJ;&%G92!B979A='1E(&=E96X@9&%T82X`35-'`$UA
M8V%O`$UA8V5D;VYIZRP@1&4@=G)O96=E<F4@2F]E9V]S;&%V:7-C:&4@4F5P
M=6)L:65K('9A;@!-861A9V%S8V%R`$UA9VEE`$4M;6%I;`!-86EL8F5H965R
M9&5R`$UA86L@;&EN7VLN+BX`36%L87=I`$UA;&5I<VGK`$UA;&%D:79E;@!-
M86QI`$UA;'1A`$)E:&5E<B!U=R!L:6IS="!M970@8V%T96=O<FEEZVX@96X@
M9&4@8V]R<F5S<&]N9&5R96YD92!K;&5U<F5N+"!W86%R;65E(&]N9&5R9&5L
M96X@=V]R9&5N(&=E;&%B96QD`$UA<#(T(&MA87)T`$UA<%%U97-T:V%A<G0`
M2V]P<&5L:6YG96X@;W!G97-L86=E;BX`36%A<G0`36%R9V4`36%R:V5E<B!M
M970@1V5Z:65N+TYI970@1V5Z:65N('9L86=G96X`36%R:V5E<B!M970@86YD
M97)E('9L86=G96X@*&(N=BX@0F5L86YG<FEJ:R]"96%N='=O;W)D*0!-87)C
M:&%L;"!E:6QA;F1E;@!-87)T:6YI<75E`$]V97)E96YK;VUE;F1E('9E;&1E
M;@!-875R971A;FGK`$UA=7)I=&EU<P!-87AI;6%A;"!T;V5G97-T86%N(&MR
M961I970N`$UA>&EM=6T@8F5R:6-H=&]N9&5R9&5L96X@;W9E<G-C:')E9&5N
M+@!-87AI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@,C0@=75R
M.B``36%X:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N(#8@=75R
M.B``36%X:6UU;2!A86YT86P@<&]R=&%A;&)L;VMK96X`36%X:6UU;2!L96YG
M=&4`365I`$UA>6]T=&4`1V5N965S:W5N9&4`3&5D96X`365N=2!M;V1E.@!#
M96QL96X@<V%M96YV;V5G96X`0F5R:6-H=`!"97)I8VAT(&UE="!S=6-C97,@
M9V5V97)I9FEE97)D+"!M86%R(&AE="!C97)T:69I8V%A="!V86X@9&4@;VYD
M97)G971E:V5N9&4@:V]N(&YI970@=V]R9&5N(&=E=F5R:69I965R9"X`0F5R
M:6-H="!V97)L;W!E;BX`0F5R:6-H='1Y<&4`365T87(@5V5E<@!-151!4B!B
M;&]K(&ES(&YI970@8F5S8VAI:V)A87(N`$U%5$%2(&)L;VL@:7,@;FEE="!B
M97-C:&EK8F%A<BX@1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E
M96UB96AE97)D97(N`$UE=&%R1$(@:7,@;FEE="!V97)B;VYD96XN`$UE=&AO
M9&4`365T:&]D92`B)7,B(&ES(&YI970@9V5D969I;FEE97)D`$UE=&AO9&4@
M:7,@;FEE="!G961E9FEN:65E<F0N($%A;F=E<F]E<&5N(&UE=&AO9&4Z("5S
M`$UE=')I<V-H`$UE>&EC;P!-:6-R;VYE<VGK+"!&961E<F%L92!3=&%T96X@
M=F%N`$UI9&1E;@!-:6UE('1Y<&4`36EN:6UU;2!T96UP97)A='5U<B!V86X@
M9&4@869G96QO<&5N(#(T('5U<CH@`$UI;FEM=6T@=&5M<&5R871U=7(@=F%N
M(&1E(&%F9V5L;W!E;B`V('5U<CH@`$UI;FEM=6T@=V%C:'1W;V]R9&QE969T
M:6ID(&ES(&YO9R!N:65T('9E<FQO<&5N`$UI<G)O<@!!;&QE<FAA;F1E`$]N
M=&)R96ME;F1E(%!%05(@;6]D=6QE($A45%!?4F5Q=65S="X`3VYT8G)E:V5N
M9&4@8V]N9FEG=7)A=&EE+B!5(&1I96YT(&1E>F4@;G4@=&4@9V5N97)E<F5N
M+"!W86YN965R('4@9&5Z92!T;V5P87-S:6YG('=I;'0@9V5B<G5I:V5N+@!/
M;G1B<F5K96YD(&)E<FEC:'0@240N`$]N=&)R96ME;F1E+"!V97)E:7-T92P@
M4$5!4B!M;V1U;&4@36%I;"X`3VYT8G)E:V5N9"!S97-S:64@240N`$UA`$UO
M8FEE;&4@92UM86EL`$=E;6ED9&5L9`!7:6IZ:6=I;F=S9&%T=6T`5VEJ>FEG
M(%523`!-;V1U;'5S`$UO;&1A=FGK+"!297!U8FQI96L@=F%N`$UO;F%C;P!-
M;VYG;VQIZP!-86%N9"!E;B!J86%R`$UA86YD96QI:FMS`$UO;G1S97)R870`
M36%A;F9A<V5N`$UE97(@=F5L9&5N(&EN(')E9V5L("5D(&=E=F]N9&5N+"!D
M86X@9&4@=F5R=V%C:'1T92`E9"X`36%R;VMK;P!6;V]R;F%M96QI:FL@;VYB
M97=O;&MT`%9O;W)N86UE;&EJ:R!B97=O;&MT`%9O;W)N86UE;&EJ:R!B97=O
M;&MT(&5N('=I;F1E<FEG`%9O;W)N86UE;&EJ:R!Z;VYN:6<`3F%A<B!B96YE
M9&5N`$YA87(@;&EN:W,`3F%A<B!R96-H=',`3F%A<B!B;W9E;@!.86%R(&)E
M;F5D96X`3F%A<B!B;W9E;@!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:6IS=&5N`$UU;'1I;6%P(%9+(&MA87)T`$UE97)V;W5D:6=E('-E
M;&5C=&EE`$UI:FX@86-C;W5N=`!5=R!A8V-O=6YT:6YF;W)M871I90!-:6IN
M('!O<G1A86P`36EJ;B!P;W)T86%L;&%Y;W5T`$)I<FUA`$YE92P@:6L@86-C
M97!T965R(&1E('9O;W)W86%R9&5N($Y)150`3F%A;0!.86UI8FGK`$YA=7)U
M`$YE<&%L`$YE9&5R;&%N9`!.961E<FQA;F1S($%N=&EL;&5N`$YE='-C87!E
M($)A<VES(%523`!.971S8V%P92!#02!I;G1R96MK:6YG(%523`!.971S8V%P
M92!#02!B96QE:60@55),`$YE='-C87!E('9E<FYI975W:6YG(%523`!.971S
M8V%P92!I;G1R96MK:6YG(%523`!.971S8V%P92!34TP@<V5R=F5R;F%A;0!.
M971S8V%P92!C97)T:69I8V%A=&-O;6UE;G1A87(`3F5T<V-A<&4@8V5R=&EF
M:6-A871T>7!E`$YE='=E<FL`3F]O:70`3FEE=7<@0V%L961O;FGK`$YI975W
M92!C871E9V]R:64`3FEE=7=E(&UA86X`3FEE=7=E(&=E8G)U:6ME<G-N86%M
M("AO<'1I;VYE96PI`$YI975W(%IE96QA;F0`3FEE=7<@=V%C:'1W;V]R9`!.
M:65U=R!W86-H='=O;W)D('IA;"!V97)L;W!E;B!O<"`E>"X`3FEE=7=E(%=A
M8VAT=V]O<F1E;B!K;VUE;B!N:65T(&]V97)E96XN`$YI975W('-C:&5R;2`H
M7V)L86YK*0!.:65U=W,`3FEE=7=S9W)O97!E;@!6;VQG96YD90!6;VQG96YD
M92`T(&9A<V5N`%9O;&=E;F1E(&]P=&EE<P!6;VQG96YD93X`3FEC87)A9W5A
M`$YI9V5R`$YI9V5R:6$`3F%C:'0`3FEU90!.964`1V5E;B!B97-C:&EK8F%R
M92!C;VYF:6=U<F%T:65D871A(&]M('9E<G-C:&EL;&5N('1E(&QA=&5N('II
M96XN`$=E96X@8F5S8VAI:V)A<F4@<W1R871E9VEE('9O;W(@:&5T(&UA:V5N
M('9A;B!)4T\@:6UA9V5S+@!'965N(&)A=&-H<VIA8FQO;VXN`$5R(&)E<W1A
M870@9V5E;B!B;&]K(&]P(&1E(&=E=G)A86=D92!P;W-I=&EE`$=E96X@86=E
M;F1A;F%A;2!O<&=E9V5V96X@=F]O<B!-0T%,(&%U=&AE;G1I8V%T:64N`$=E
M96X@=VEJ>FEG:6YG96XN`$%A;B!D:70@<F5C:'0@:W5N;F5N(&=E96X@8VAI
M;&0@<F5C:'1E;B!W;W)D96X@=&]E9V5V;V5G9"X`1V5E;B!C;VYF:6=U<F%T
M:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R("5S+@!'965N(&-O;F9I9W5R
M871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O;W(@1E10(%9&4RX`1V5E;B!C
M;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R(%-13"!61E,N
M`$=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!3
M44PM8F5S=&%N9"!61E,N`$=E96X@:W)E9&EE="!M965R+@!'965N(&)E<W1E
M;6UI;F<@;W!G96=E=F5N+@!'965N(&)E<W1A;F0@=7!L;V%D960`1V5E;B!P
M:6-T;V=R86UM96X@9V5V;VYD96XN`$5R(&ES(&=E96X@;&]C871I92!I;F=E
M<W1E;&0N`$=E96X@;&]C871I92!O<&=E9V5V96XN`$=E96X@8F5R:6-H="!G
M96QE=F5R9"X`1V5E;B!N86%M(&]P9V5G979E;BX`1V5E;B!G971A;"!O<&=E
M9V5V96XN`$=E96X@8F5L961I9V5N9&4@9F]R='5N97,`1V5E;B!W86-H='=O
M;W)D(&]P9V5G979E;B!V;V]R($A45%`@875T:&5N=&EC871I92X`1V5E;B!W
M86-H='=O;W)D(&]P9V5G979E;B!V;V]R($E-05`@875T:&5N=&EC871I92X`
M1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V86X@2V5R8F5R;W,@875T:&5N
M=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R($QO9VEN
M(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O
M<B!005-35T0@875T:&5N=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G
M979E;B!V;V]R(%--0B!A=71H96YT:6-A=&EE+@!'965N('!A9"!N86%R(&1E
M($]P96Y34TP@8FEN87)Y(&]P9V5G979E;BX@1&4@3W!E;E-33"!B:6YA<GD@
M:7,@;F]D:6<@;VT@=&4@:W5N;F5N('=E<FME;B!M970@4$M#4R`Q,B!D871A
M+@!'965N(&AA;F=E;F1E(&EN<V-H<FEJ=FEN9V5N+@!'965N('%U;W1A(&EN
M9V5S=&5L9"X`1V5E;B!L:6YIZW)I;F<`1V5E;B!S8VAE:61I;F=S=&5K96X@
M;W!G96=E=F5N+@!'965N('II:F1E;@!'965N(&1E<F=E;&EJ:R!B97-T86YD
M`$=E96X@=&EJ9&5L:6IK(&1I<F5C=&]R>2!B97-C:&EK8F%A<B!V;V]R(&-A
M8VAE+@!'965N(&=E8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT=V]O<F0@=F5R
M>F]N9&5N+@!'965N(&=E;&1I9V4@6$U,(&1A=&$@=&5R=6=G97-T=75R9`!'
M965N('=A87)D96X`1V5E;B!V97)S:64@9V5V;VYD96X@:6X@;W)I9VEN96QE
M(&-O;F9I9W5R871I92X@2&5R9V5N97)E97(@8V]N9FEG=7)A=&EE+@!'965N
M('9E<G-I92!G979O;F1E;B!I;B!U=R!C;VYF:6=U<F%T:64N($AE<F=E;F5R
M965R(&-O;F9I9W5R871I92X`1V5E;@!'965N("AV97)P;&EC:'0I`$YO;W)D
M($5U<F]P965S("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!E:6QA;F0`3F]O<F1E
M;&EJ:R!H86QF<F]N9`!-87)I86YE;@!.;V]R=V5G96X`3FEE="!N80!.:65T
M('9O;W(`1V5E;B!D:7)E8W1O<GD`3FEE="!G96EM<&QE;65N=&5E<F0N`$YI
M970@:6YG97-T96QD`$YI970@;VYD97)S=&5U;F0N`$YO=&ET:65S`$YI971S
M('1E(&)L861E<F5N+"!G82!T97)U9RX`3F]V96UB97(`1V5T86P`06%N=&%L
M(&MA<F%K=&5R<P!!86YT86P@:V]L;VUM96X`06%N=&%L(')I:F5N`$=E=&%L
M;&5N(&YI970@;W!G96=E=F5N('9O;W(@8FEJ=V5R:V5N(&EN(&5E;B!D:7-T
M<FEB=71I96QI:G-T+@!/2P!/8FIE8W0`3V)J96-T96EG96YA87(`3V-T86%L
M`$]K=&]B97(`0F5L961I9VEN9V9I;'1E<@!+86YT;V]R`$]U9&4@96X@;FEE
M=7=E('=A8VAT=V]O<F1E;B!D:65N96X@=F5R<V-H:6QL96YD('1E('II:FXN
M`$]U9&4@=V%C:'1W;V]R9`!/=61E('=A8VAT=V]O<F0@:7,@;FEE="!J=6ES
M=`!/;6%N`$%L;&5E;B!)34%0('-E<G9E<G,@;VYD97)S=&5U;F5N(&=E9&5E
M;&1E(&UA<'!E;BX`06QL965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S`%-L96-H
M="#IZ6X@92UM86EL861R97,@=&]E9V5S=&%A;BX`06QL965N(&1E(&5I9V5N
M86%R(&]F(&5E;B!S>7-T965M8F5H965R9&5R(&UA9R!D92!E:6=E;F%A<G)E
M8VAT96X@=F%N(&5E;B!S:&%R92!W:6IZ:6=E;@!/<&5N(&EN(&5E;B!N:65U
M=R!S8VAE<FT`3W!E;E-33"!F;W5T.B!K;VX@9V5E;B!D871A('5I="!H970@
M;VYD97)T96ME;F1E(%,O34E-12!O;F1E<F1E96P@:&%L96XN`$]P96YT(&1E
M>F4@;&EN:R!I;B!E96X@;FEE=7<@<V-H97)M`$)E<W1U<FEN9W-S>71E96T`
M3W!T:65S`$]P=&EE<R!V;V]R("5S`$=E;W)D96YD92!L:6IS=`!/<F=A;FES
M=&%T:64`3W)G86YI<V%T:64@965N:&5I9`!/<F=A;FES97)E;@!/<FEG:6YE
M96P@=&]E<&%S<VEN9W-S:F%B;&]O;@!/<FEG:6YE;&4@<VIA8FQO;F5N(&EN
M("5S.@!!;F1E<F4`06YD97)E(&EN9F]R;6%T:64`16EG96YA87)R96-H=&5N
M`%!!32!A=71H96YT:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`%!%05(Z
M.DUA:6P@8F%C:V5N9`!$:6=I=&%L92!01U`@:&%N9'1E:V5N:6YG`$=E8V]D
M965R9&4@4$=0(&1A=&$`3W!E;F)A<F4@4$=0('-L975T96P`3VYD97)T96ME
M;F1E+V=E8V]D965R9&4@4$=0(&1A=&$`4$A0(&-O9&4`4$A0('-H96QL`$QI
M8VAT92!R96=E;B!N82`Q,BXP,"!U=7(`4F5G96X@;F$@,3(N,#`@=75R`$)U
M:65N(&YA(#$R+C`P('5U<@!3;F5E=7<@;F$@,3(N,#`@=75R`%-N965U=V)U
M:65N(&YA(#$R+C`P('5U<@!:;VX@;F$@,3(N,#`@=75R`$]N=V5E<G-B=6EE
M;B!N82`Q,BXP,"!U=7(`4$]325@@97AT96YS:64@;VYT8G)E96MT`%!(4"!?
M4VAE;&P`5G)I:F4@<G5I;71E`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EJ;G,@
M5&5R<FET;W)I=6TL($)E>F5T`%!A;F%M80!087!U82!.:65U=R!'=6EN96$`
M4&%R86=U87D`1V5D965L=&5L:6IK(&)E=V]L:W0`5V%C:'1W;V]R9`!786-H
M='=O;W)D(&UE="!S=6-C97,@9V5W:6IZ:6=D+@!786-H='=O;W)D(&]N:G5I
M<W0`5V%C:'1W;V]R9"!I<R!V97)E:7-T('9O;W(@4D%$2553(&%U=&AE;G1I
M8V%T:64N`%=A8VAT=V]O<F0@;65T(&)E=F5S=&EG:6YG`%=A8VAT=V]O<F0Z
M`%=A8VAT=V]O<F0Z(`!786-H='=O;W)D96X@;6]E=&5N(&]V97)E96YK;VUE
M;BX`4&QA:VME;@!0;&%K:V5N('9A;F%F('!R:6MB;W)D`%!A9`!(86YG96YD
M92!I;G-C:')I:G9I;F=E;CH`365N<V5N`%!R;V-E;G0`3VYD97)H;W5D<W=E
M<FMZ86%M:&5D96X@=6ET=F]E<F5N`$]N9&5R:&]U9'-W97)K>F%A;6AE9&5N
M('5I='9O97)E;B!B:6H@86%N;65L9&EN9S\`4F5C:'0`4F5C:'0@(B5S(B!N
M:65T('9E<G=I:F1E<F0N`%)E8VAT(&=E=V5I9V5R9`!296-H=&5N`%)E8VAT
M96YB96AE97(`4&5R<V]O;FQI:FME(&EN9F]R;6%T:64`4&5R=0!(=6ES9&EE
M<F5N`%!H:6QI<'!I:FYE;@!496QE9F]O;@!&;W1O)W,`4&ET8V%I<FX`4&EX
M96QS`%!L871I='5D97,`2VQI:R!I;B!E96X@8V5L+"!A+G4N8BX`0F5V97-T
M:6<L(&1A="!U(&1I="!E;&5M96YT('=I;'0@=F5R=VEJ9&5R96XL(&$N=2YB
M.@!"979E<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!L;W-K;W!P96QE
M;BP@82YU+F(N`$=E968@965N(&UA86YD(&5N(&5E;B!J86%R+"!A+G4N8BX`
M165N(&YA86T@=F]O<B!D92!N:65U=V4@8V%T96=O<FEE(&EN=F]E<F5N+"!A
M+G4N8BXZ`$=E968@965N(&=E;&1I9R!)4"!A9')E<RP@82YU+F(N`$=E968@
M965N(&=E;&1I9V4@9&%T=6T@82YU+F(N+"!C;VYT<F]L965R(&AE="!A86YT
M86P@9&%G96X@:6X@9&4@;6%A;F0N`$=E968@965N(&=E;&1I9V4@=&EJ9"P@
M82YU+F(N`$=E968@965N('-A;65N=F%T=&EN9R!V86X@:&5T('!R;V)L965M
M+"!A+G4N8BX`1V5E9B!U=R!G96)R=6EK97)S;F%A;2!E;B!W86-H='=O;W)D
M+"!A+G4N8BX`3&5E<R!D92!V;VQG96YD92!T96MS="P@82YU+F(N(%4@34]%
M5"!D92!V;V]R=V%A<F1E;B!T92!A8V-E<'1E<F5N(&]M(&AE="!S>7-T965M
M('1E(&MU;FYE;B!G96)R=6EK96XN`$=E968@9&4@;FEE=7=E(&-A=&5G;W)I
M96YA86TL(&$N=2YB+CH`4&]L96X`4&]L:71I96L`4&5I;&EN9V5N`%!O<G1U
M9V%L`%!O<VET:6]N97)I;F<@=F%N(&1E>F4@869B965L9&EN9P!0;W-I=&EO
M;F5R:6YG('9A;B!D97IE('1A8F5L`%-T=75R(&YA87(@9&5Z92!M87`@*&YI
M970@869G961W;VYG96X@9&]O<B!)34%0*0!.965R<VQA9R!V86X@9&4@869G
M96QO<&5N("5S('5R96XZ(`!.965R<VQA9SQB<B`O/FMA;G,`4')E9G-?;&1A
M<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!0<F5F
M<U]S97-S:6]N.B!V97)E:7-T92!S97-S:64@97AT96YT:64@;FEE="!G979O
M;F1E;BX`3'5C:'1D<G5K`$QU8VAT9')U:R!O<"!Z965N:79E874Z(`!,=6-H
M=&1R=6LZ(`!"96]O<F1E;&5N`$)E;V]R9&5E;"!D92!A9F)E96QD:6YG(&EN
M(&5E;B!N:65U=R!S8VAE<FT`5F]R:6=E(&]P=&EE<P!$;V-U;65N="!A9F1R
M=6MK96X`4')I=F4@<VQE=71E;`!0<F]B;&5E;0!0<F]B;&5E;6)E<V-H<FEJ
M=FEN9P!0<F]J96-T96X`4')O;7!T('1E:W-T`$]P96YB87)E('-L975T96P`
M3W!E;F)A<F4@<VQE=71E;"!A;&=O<FET:&UE`$]P96YB87)E('-L975T96QI
M;F9O<FUA=&EE`$]P96YB86%R+U!R:79E('-L975T96QP86%R(&YI970@9V5G
M96YE<F5E<F0N`%!U97)T;R!2:6-O`%=I<R!B97)I8VAT96X`475A=&%R`%%U
M97)Y`%%U;W1A`%)302!O<&5N8F%R92!S;&5U=&5L("@E9"!B:70I`$ME=7IE
M<F]N9&IE('-E;&5C=&EE`%)E9V5N`%9R;V5G(')E9V5N`$QA870@<F5G96X`
M4F5G96YB=6D`4F5G96X@96X@<VYE975W`%)E9V5N(&YA87(@<VYE975W`%)A
M;F1O;2!&;W)T=6YE`%9E<FAO=61I;F<`3&5Z96X`3&5E<R!B97)I8VAT96X`
M)7,@96-H="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@
M;VYG961A86X@9V5M86%K="!W;W)D96XN`$=E8G)U:6ME<G-D871A('9A;B!G
M96)R=6EK97(@)7,@96-H="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@
M:V%N(&YI970@;VYG961A86X@9V5M86%K="!W;W)D96XN`$AE<FAA86QT('5W
M('9O<FEG92!B97=E<FMI;F<`5F5R=F5R<V5N`%9E<G9E<G,@9'EN86UI<V-H
M92!M96YU(&]N9&5R9&5L96XZ`%!O<G1A;'=E97)G879E('9E<G9E<G-E;CH`
M4F5G97@`0F5T<F5K:VEN9V5N(&)R;W=S97(`2&5R;&%D96X`3W!M97)K:6YG
M96X`4V5R=F5R<R!O<"!A9G-T86YD`%523"!O<"!A9G-T86YD("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`5F5R=VEJ9&5R96X`0FQO:R!V97)W
M:6ID97)E;@!+;VQO;2!V97)W:6ID97)E;@!/<&UA86L@=F5R=VEJ9&5R96X`
M4&%A<B!V97)W:6ID97)E;@!697)W:6ID97(@:&5T(&]P9V5S;&%G96X@<V-R
M:7!T('5I="!D92!T:6ID96QI:FME(&1I<F5C=&]R>2!O<"!D92!S97)V97(N
M`%9E<G=I:F1E<B!D90!697)W:6ID97(@9&5Z92!N;V1E('5I="!H970@9&]C
M=6UE;G0`1V5B<G5I:V5R('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!G96)R=6EK
M97(Z("5S`%9E<GIO96L@:V]N(&YI970@=V]R9&5N(&)E86YT=V]O<F0N($=E
M<F5T;W5R;F5E<F1E(&9O=71C;V1E.B``1&4@9V5V<F%A9V1E('-E<G9I8V4@
M:V]N(&YI970@=V]R9&5N(&=E=F]N9&5N+@!697)E:7-T92`B)7,B(&YI970@
M;W!G96=E=F5N(&EN("5S(&-O;F9I9W5R871I92X`5F5R96ES=&4@(B5S(B!N
M:65T(&]P9V5G979E;B!I;B!61E,@8V]N9FEG=7)A=&EE+@!697)E:7-T92`B
M)7,B(&YI970@;W!G96=E=F5N(&EN(&-O;F9I9W5R871I92X`5F5R96ES="!V
M96QD`$AE<G-T96QL96X`4F5S970@=V%C:'1W;V]R9`!297-E="!U=R!W86-H
M='=O;W)D`%9O;W)G86%N9&4@<75E<GD@:&5R<W1E;&QE;@!297-U;'1A=&5N
M`%1E<G5G(&YA87(@;W!T:65S`%1Y<"!N:65U=R!W86-H='=O;W)D(&]P;FEE
M=7<`4F5U;FEO;@!#;VYF:6=U<F%T:64@=&5R=6=Z971T96X`4FEC:"!497AT
M($5D:71O<B!O<'1I97,`4F%A9'-E;',`4F5C:'1S`%)E8VAT<V4@:V]P`%)E
M8VAT<V4@=V%A<F1E;@!2:5]J96EG96YS8VAA<'!E;BXN+@!2;VP`4F]E;65N
M:>L`,3@P(&1R86%I96X`3F%A<B!L:6YK<R!D<F%A:65N`$YA87(@<F5C:'1S
M(&1R86%I96X`4FEJ(&5I9V5N<V-H87!P96X`4FEJ(&5I9V5N<V-H87!P96X`
M4FEJ96XZ`$QI;FGK<FEN9P!,:6YIZW)I;F<@>F%L('9E<G-C:&EJ;F5N('1U
M<W-E;B!A;&QE(')I:F5N(&5N(&MO;&]M;65N`$QI;FGK<FEN9R!Z86P@86QL
M965N('1U<W-E;B!K;VQO;6UE;B!V97)S8VAI:FYE;@!,:6YIZW)I;F<@>F%L
M(&%L;&5E;B!T=7-S96X@<FEJ96X@=F5R<V-H:6IN96X`4W1A<G1E;@!2=7-S
M:7-C:&4@1F5D97)A=&EE`%)W86YD80!#<GEP=&]G<F%F:7-C:&4@4R]-24U%
M(&AA;F1T96ME;FEN9P!3+TU)344@9V5C;V1E97)D(&)E<FEC:'0`4T%33"!A
M=71H96YT:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`%--4R!V97)S='5R
M96X`4U%,('-H96QL`%-13"!S=&%T96UE;G0@=F]O<B!W86%R9&5Z;V5K;W!D
M<F%C:'1E;@!34T@`4U5#0T53`%-?44P@<VAE;&P`6F$`4W0@2&5L96YA`%-T
M($MI='1S(&5N($YE=FES`%-T($QU8VEA`%-T(%!I97)R92!E;B!-:7%U96QO
M;@!3="!6:6YC96YT(&5N(&1E($=R96YA9&EN97,`6F5L9F1E(&9R86UE("A?
M<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!E;B!0<FEN8VEP90!3
M871E;&QI971P<F]V:61E<@!3875D:2!!<F%B:>L`3W!S;&%A;@`B)7,B(&]P
M<VQA86X`)7,@;W!S;&%A;@!/<'1I97,@;W!S;&%A;@!'96=E;F5R965R9&4@
M8V]N9FEG=7)A=&EE(&%L<R!02%`@<V-R:7!T(&]P9V5S;&%G96X@:6X@9&4@
M=&EJ9&5L:6IK92!D:7)E8W1O<GD@=F%N('5W('-E<G9E<BX`)7,@8V]N9FEG
M=7)A=&EE(&]P9V5S;&%G96X`4V5T=7`@=7!G<F%D92!S8W)I<'0@;W!G97-L
M86=E;B!N86%R.B`B)7,B+@!'97-P<F5I9&4@;VYW965R<V)U:65N`%=E=&5N
M<V-H87``6F]E:V5N`%IO96MM86-H:6YE<P!+:65S(&)E<W1A;F1E;@!396QE
M8W1E97(@965N(&1A='5M`%-E;&5C=&5E<B!E96X@9W)O97`@;VT@=&]E('1E
M('9O96=E;@!396QE8W1E97(@965N(&YI975W92!E:6=E;F%A<@!396QE8W1E
M97(@965N('-E<G9E<@!396QE8W1E97(@965N(&=E8G)U:6ME<B!O;2!T;V4@
M=&4@=F]E9V5N`$%L;&5S('-E;&5C=&5R96X`4V5L96-T965R(&%L;&4@9&%T
M=6UC;VUP;VYE;G1E;BX`4V5L96-T965R(&5E;B!O8FIE8W0`3FEE=',@<V5L
M96-T97)E;@!396QE8W1E97(@9&4@8F5N;V1I9V1E(&MA<F%K=&5R<R!U:70@
M9&4@;VYD97)S=&%A;F1E('9A:VIE<RX@52!K=6YT(&1E>F4@9&%N(&MO<&GK
M<F5N(&5N('!L86MK96X@:6X@:&5T('1E:W-T9V5B:65D+@!396QE8W1E97(@
M:&5T(&1A='5M<V-H96ED:6YG<W1E:V5N.@!396QE8W1E97(@:&5T(&1A='5M
M9F]R;6%A=#H`4V5L96-T965R(&1E(&ED96YT:71E:70@9&EE('4@=VEL="!W
M:6IZ:6=E;CH`4V5L96-T965R(&AE="!T:6ID<V-H96ED:6YG<W1E:V5N.@!3
M96QE8W1E97(@:&5T('1I:F1S9F]R;6%A=#H`4V5L96-T965R('1W964@;W9E
M<F5E;FMO;65N9&4@=F5L9&5N+@!396QE8W1E97(@=7<@:VQE=7)S8VAE;6$N
M`%-E;&5C=&5E<B!U=R!G97=E;G-T92!T86%L.@!0<F]B;&5E;7)A<'!O<G0@
M=F5R>F5N9&5N`%9E<GIE;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E<G9IZR!E;B!-;VYT96YE9W)O`%-E<FEE;G5M;65R`%-E<G9E<F1A
M=&$@9F]U="!O9B!N:65T(&)E<V-H:6MB86%R+@!397-S:65B96AE97)D97(`
M4V5S<VEE($E$('9E<FQO<&5N+@!397-S:65S`$EN<W1E;&QE;@!);G-T96QL
M96X@=F%N(&]P=&EE<R!O;2!U('1O92!T92!S=&%A;B!U=R!W86-H='=O;W)D
M('1E(')E<V5T=&5N+"!W86YN965R('4@9&ET(&)E;G0@=F5R9V5T96XN`$EN
M<W1E;&QE;B!V86X@<V5R=F5R<R!O<"!A9G-T86YD(&1I92!U('=I;'0@8F5N
M861E<F5N('9A;G5I="!U=R!P;W)T86PN`$EN<W1E;&QE;B!V86X@=7<@9V5W
M96YS=&4@=&%A;"P@=&EJ9'IO;F4@96X@9&%T=6UO<'1I97,N`$EN<W1E;&QE
M;B!V86X@=7<@;W!S=&%R='1O97!A<W-I;F<L(&ML975R<V-H96UA+"!P86=I
M;F%V97)V97)S:6YG(&5N(&%N9&5R92!W965R9V%V96]P=&EE<RX`26YS=&5L
M;&5N`%-E='5P('5P9W)A9&4@<V-R:7!T<R!B97-C:&EK8F%A<@!697)S8VAI
M;&QE;F1E(&QO8V%T:65S(&UO9V5L:6IK(&UE="!D92!P87)A;6%T97(Z(`!3
M97EC:&5L;&5N`%=I;FME;&5N`$MO<G1E('-A;65N=F%T=&EN9P!$:65N96X@
M<VYE;'1O971S96X@=F]O<B!D92!M965S=&4@;&EN:W,@9V5D969I;FEE97)D
M('1E('=O<F1E;C\`5V5E<F=E=F5N`%9E<G-C:&EL;&5N(&QA=&5N('II96X@
M='5S<V5N(&1E(&AU:61I9V4@;W!G97-L86=E;B!C;VYF:6=U<F%T:64@96X@
M9&4@;FEE=7=E(&=E9V5N97)E97)D92!C;VYF:6=U<F%T:64N`$QA871S=&4@
M86%N;65L9&EN9W-T:6ID('=E97)G979E;B!B:6H@86%N;65L9&5N/P!/<'1I
M92!W965R9V5V96X@;VT@;W)I9VEN965L('1E(&)E=V%R96X`2VEE>F5R('=E
M97)G979E;@!486)E;&)E=V5R:VEN9W-T86%K8F%L:R!W965R9V5V96X_`"5S
M(&UE;G4@86%N(&1E(&QI;FME<FMA;G0@=V5E<F=E=F5N/P!486)E;&-E;&5I
M9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N`%1A8F5L96EG
M96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96X`5&%B96QR:6IE
M:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS=&5R('=E97)G979E;@!!9F)E96QD
M:6YG<V5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N`%5P
M;&]A9"!W965R9V5V96X`0G5I96X`0G5I96X@=G)O96<`0G5I96X@;&%A=`!"
M=6EE;B!I;B!D92!N86)I:FAE:60`5F5R:VQE:6YE;@!697)K;&5I;B!O9B!V
M97)P;&%A=',@;F%B=7)I9V4@8FQO:VME;B!E97)S=`!3:65R<F$@3&5O;F4`
M26YT96ME;F5N`$AA;F1T96ME;FEN9P!(86YD=&5K96YI;F<@86QG;W)I=&AM
M90!3:6YG87!O<F4`1W)O;W1T90!/;F1E<FAO=60@;W9E<G-L86%N`%-L;W=A
M:VEJ90!3;&]V96YIZP!3;F5E=7<`4VYE975W=FQA86<`4VYE975W8G5I96X`
M<VYE975W8G5I96X@=G)O96<`4VYE975W8G5I96X@;&%A=`!3;F5E=7=D:65P
M=&4Z(`!3;F5E=7=E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!E:6QA
M;F1E;@!3;VUA;&GK`$QI961E<F5N(&5N(&=E9&EC:'1E;@!3;W)T965R=F]L
M9V]R9&4@<V5L96-T:64`0G)O;F%D<F5S`%IU:60@069R:6MA`%IU:60@175R
M;W!E97,@*$E33RTX.#4Y+3,I`%IU:60@1V5O<F=IZR!E;B!D92!:=6ED(%-A
M;F1W:6-H(&5I;&%N9&5N`%IU:61E;&EJ:R!H86QF<F]N9`!3<&%T:>MR:6YG
M('1U<W-E;B!A86YG<F5N>F5N9&4@8V5L;&5N`%-P871IZW)I;F<@='5S<V5N
M(&EN:&]U9"!E;B!R86YD(&EN(&-E;`!38VAE:61I;F=S=&5K96X`4W!A=&GK
M<FEN9P!3<&%T:>MR:6YG(&5N('9R:6IE(')U:6UT90!3<&%N:F4`4W!A;0!3
M<&5C:6%A;"!K87)A:W1E<B!I;G9O97(`0V5L(&]P<W!L:71S96X`2V]L;VT@
M;W!S<&QI='-E;@!2:6H@;W!S<&QI='-E;@!3<&]R=`!3<FD@3&%N:V$`4W1A
M;F1A87)D`%-T87(@5')E:P!3=&%R=&IA87(`4W1A870@;V8@<')O=FEN8VEE
M`%-T871U<P!/<'-L86=F;W)M86%T`$%D<F5S`$1O;W)H86QE;@!3=')I;F=L
M:6IS=`!3=')I<"!D;VUE:6X@=F%N(&AE="!A9')E<P!3=&EJ;"!;0U-370!:
M;P!3=6)D:7)E8W1O<GD@(B5S(B!N:65T(&=E=F]N9&5N+@!/;F1E<G=E<G``
M0F5V97-T:6=E;@!697)Z;V5K('9E<G-T=75R9"!O;2`B)7,B(&%A;B!H970@
M<WES=&5E;2!T;V4@=&4@=F]E9V5N+B!5(&MU;G0@;FEE="!A86YM96QD96X@
M=&]T('5W('9E<GIO96L@:7,@9V]E9&=E:V5U<F0N`%-U8G-C<FEP=`!3=6-C
M97,`(B5S(B!M970@<W5C8V5S(&%A;B!H970@<WES=&5E;2!T;V5G979O96=D
M+@!$871A('9A;B!G96)R=6EK97(@(B5S(B!M970@<W5C8V5S('5I="!H970@
M<WES=&5E;2!V97)W:6ID97)D+@`B)7,B(&UE="!S=6-C97,@=F5R=VEJ9&5R
M9"X`(B5S(B!M970@<W5C8V5S('5I="!H970@<WES=&5E;2!V97)W:6ID97)D
M+@!#;VYF:6=U<F%T:64@;65T('-U8V-E<R!T97)U9V=E>F5T+B!697)N:65U
M=R!O;2!W:6IZ:6=I;F=E;B!T92!Z:65N+@!"86-K=7!C;VYF:6=U<F%T:64@
M;65T('-U8V-E<W,@;W!G97-L86=E;BX`0F%C:W5P8V]N9FEG=7)A=&EE8F5S
M=&%N9"`E<R!M970@<W5C8V5S<R!O<&=E<VQA9V5N+@`B)7,B(&UE="!S=6-C
M97,@8FEJ9V5W97)K=``E<R!M970@<W5C8V5S(&=E<V-H<F5V96X`4V]E9&%N
M`%-A;65N=F%T=&EN9P!:;VYS;W!G86YG`%IO;G-O;F1E<F=A;F<`6F]N;FEG
M`%IO;G-O<&=A;F<`6F]N<V]P9V%N9R]:;VYS;VYD97)G86YG`%IO;G-O<&=A
M;F<Z(`!:;VYS;VYD97)G86YG`%IO;G-O;F1E<F=A;F<Z(`!3=7!E<G-C<FEP
M=`!/;F1E<G-T975N:6YG`%-U<FEN86UE`$%C:'1E<FYA86T`4W!I='-B97)G
M96X@96X@2F%N($UA>65N`%-W87II;&%N9`!:=V5D96X`6G=I='-E<FQA;F0`
M4WEN8R!L;V<@=F5R=VEJ9&5R9`!3>6YC34P`4WEN=&%X9F]U="!I;B!Z;V5K
M=&5R;65N`%-Y<FES8VAE($%R86)I<V-H92!297!U8FQI96L`3VYW965R<V)U
M:0!/;G=E97)S8G5I96X@96X@=VEN9&5R:6<`3VYW965R<V)U:65N`$]N=V5E
M<G-B=6EE;B!V<F]E9P!44U8@8F5S=&%N9`!486)E;&5I9V5N<V-H87!P96X`
M5&%B96QS970`5&%B96QE:6=E;G-C:&%P<&5N`%1A:7=A;@!486EW86XL(%!R
M;W9I;F-I92!V86X@0VAI;F$`5&%D>FII:VES=&%N`%1A;GIA;FEA+"!697)E
M;FEG9&4@4F5P=6)L:65K('9A;@!$;V5L.@!486ME;@!496QE9F]O;FYU;6UE
M<@!496UP97)A='5U<B!V86X@:&5T(&%F9V5L;W!E;B!U=7(Z(`!496UP97)A
M='5U<@!496UP97)A='5U<CH@`%1E;7!E<F%T=75R/&)R("\^*"5S2&]O9R5S
M+R5S3&%A9R5S*2`F9W)D.R5S`%-J86)L;V]N("(E<R(@;FEE="!G979O;F1E
M;BX`4VIA8FQO;VYB96AE97(`5&5K<W0`06QL965N('1E:W-T`%1E:W-T('5I
M=&QI:FYE;@!496MS=&)O=F5N:V%N=`!$;P!4:&%I<R`H5$E3+38R,"D`5&AA
M:6QA;F0`1&4@1E10(&5X=&5N=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`$AE
M="!G97-C:&EE9&5N:7-S>7-T965M(&ES('5I=&=E<V-H86ME;&0N`$1E($AO
M<F1E+TMO;&%B(&EN=&5G<F%T:64@;VYD97)S=&5U;G0@(B5S(B!N:65T`$AE
M="!)35-0(&QO9R!K;VX@;FEE="!W;W)D96X@9V5I;FET:6%L:7-E97)D+@!$
M92!-86EN=&5N86YC93HZ(&-L87-S('=E<F0@;FEE="!G96QA9&5N`$AE="!/
M<'1I97-S8VAE<FT@:7,@9V5S;&]T96XN($%F<VQU:71E;BX`1&4@8F5H965R
M9&5R(&1I96YT(&5E;B!P97)M86YE;G0@<F5C:'1E;F)A8VME;F0@=&4@8V]N
M9FEG=7)E<F5N(&%L<R!U(')E8VAT96X@=VEL="!G96)R=6EK96XN`$%L;&5E
M;B!D92!O;F1E<FMA;G0`2&5T(&-O;G1A8W0@240@;G5M;65R(&ES(&YI970@
M;W!G96=E=F5N+"!L965G(&=E;&%T96X@;V8@:7,@;FEE="!G979O;F1E;B!I
M;B!D92!D871A8F%S92X`2&5T(&%D<F5S(&ES(&UE="!S=6-C97,@86%N('5W
M(&%D<F5S8F]E:R!T;V5G979O96=D+@!(970@;&]S9V5K;W!P96QD92!01U`@
M;VYD97)T96ME;FEN9W-B;&]K(&ES('9E<F5I<W0@;VT@:&5T(&]N9&5R=&5K
M96YD92!B97)I8VAT('1E('9E<FEF:>MR96XN`$AE="!D:7-T<G5B=71I96QI
M:G-T($E$(&ES(&YI970@;W!G96=E=F5N+"!L965G(&=E;&%T96X@;V8@:7,@
M;FEE="!G979O;F1E;B!I;B!D92!D871A8F%S92X`1&4@9&ES=')I8G5T:65L
M:6IS="!I<R!N:65T(&]P9V5G979E;BX`1&4@8V]D965R;6]G96QI:FMH961E
M;B!V97)E:7-E;B!E96X@8F5V96EL:6=D92!W96)V97)B:6YD:6YG+@!(970@
M8F5S=&%N9"`E<R!D:65N="!E96X@)7,@:6YS=&5L;&EN9R!T92!B979A='1E
M;BX`2&5T(&)E<W1A;F0@)7,@9&EE;G0@96YI9V4@)7,@:6YS=&5L;&EN9V5N
M('1E(&)E=F%T=&5N+@!(970@8F5S=&%N9"!K86X@;FEE="!N86%R('II8VAZ
M96QF(&=E:V]P:65E<F0@=V]R9&5N+@!(970@8F5S=&%N9"!B979A='1E(&=E
M96X@9&%T82X`2&5T('9O;&=E;F1E('II:FX@9&4@:V]P<&5N('9A;B!D:70@
M;65S<V%G92]R9F,X,C(@8F5R:6-H="X`5F%N(&1E('9O;&QE9&EG('-C:&5R
M;2!M;V1E(&ES(&)E:V5N9"P@9&%T(&1I="!P<F]B;&5M96X@:V%N('9E<F]O
M<GIA:V5N(&UE="!);G1E<FYE="!%>'!L;W)E<BP@=F%N=V5G92!B<F]W<V5R
M8G5G<R!W86%R('=I:B!N:65T(&]M:&5E;B!K=6YN96XN($AE="!I<R!M;V=E
M;&EJ:R!D870@=2!R;VUM96P@:6X@:&5T(&)E96QD<V-H97)M+"!G96)R96L@
M86%N(&5D:71O<F9U;F-T:65S(&5N+V]F(')A;F1O;2!B<F]W<V5R+2!C<F%S
M:&5S(&5R=F%A<G0N(%=A;FYE97(@=7<@<WES=&5E;2!7:6YD;W=S(#EX(&ES
M+"!I<R!H970@=V%A<G-C:&EJ;FQI:FL@9&%T('4@965N("=!;&=E;65N92!"
M979E:6QI9VEN9W,@1F]U="<@:W)I:F=T+"!E;B!O<&YI975W(&1I96YT('1E
M(&AE<G-T87)T96XN7&Y<;E4@8F5N="!G97=A87)S8VAU=V0N($1R=6L@;W`@
M3TL@=V%N;F5E<B!U('1O8V@@9&4@=F]L;&5D:6<@<V-H97)M(&5D:71O<B!W
M:6QT('!R;V)E<F5N+@!$92!I9&5N=&ET96ET("(E<R(@:7,@=F5R=VEJ9&5R
M9"X`06QL965N(&1E(&QI;FME<FMA;G0`1&4@<&QA871S('9A;B!H970@1VYU
M4$<@<')O9W)A;6UA(&1I96YT(&]P9V5G979E;B!T92!W;W)D96X@:6X@9&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N`$AE="!B97)I8VAT('9E<G-T=75R9"!O<"`E
M<R!A86X@)7,@;65T(&]N9&5R=V5R<"`B)7,B(&ES('=E97)G96=E=F5N+@I$
M:70@:7,@9V5E;B!G87)A;G1I92!D870@:&5T(&)E<FEC:'0@:7,@9V5L97IE
M;B!O9B!B96=R97!E;BX`1&4@;F%A;2!D:64@9V5B<G5I:W0@=V]R9'0@8FEJ
M(&QI;FME;B!N86%R(&1E(&YI975W(&)E<FEC:'0@<&%G:6YA`$AE="!A86YT
M86P@=F5L9&5N(&1I96YT(&YU;65R:65K('1E('II:FXN`$1E(&]P96YS<VP@
M;6]D=6QE(&ES('9E<F5I<W0@=F]O<B!D92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+@!$92!V;V]R:V5U<G-I;G-T96QL:6YG("(E<R(@:V]N(&YI970@
M=V]R9&5N(&]P9V5S;&%G96XL(&]M9&%T(&1E(&1A=&$@9&4@;6%X:6UU;2!T
M;V5L86%T8F%R92!G<F]O='1E(&]V97)S8VAR:6ID="X`2&5T('!R;V=R86UM
M82!O;2!D:70@9&%T871Y<&4@*"5S*2!T92!B96MI:FME;BP@=V5R9"!N:65T
M(&]P(&AE="!S>7-T965M(&=E=F]N9&5N+@!(970@86%N:&%L:6YG<W1E:V5N
M(&1I96YT(.OK;B!E;FME;"!T96ME;B!T92!Z:6IN+@!!;&QE96X@9&4@<F5C
M:'1E<BT@96X@;&EN:V5R:V%N=`!!;&QE96X@9&4@<F5C:'1E<FMA;G0`2&5T
M('-C:&5I9&EN9W-T96ME;B!D:65N="#KZVX@96YK96P@=&5K96X@=&4@>FEJ
M;BX`1&4@<V5R=F5R("(E<R(@:7,@=F5R=VEJ9&5R9"X`1&4@<V5R=F5R("(E
M<R(@:7,@;W!G97-L86=E;BX`2&5T(&%A;FUE;&1I;F=S=F5R>F]E:R!V;V]R
M("5S(&ES('9E<G=I:F1E<F0N`$1E(&]P9V5G979E;B!R:6H@*"5D*2!B97-T
M86%T(&YI970N`$AE="!T:6ID96QI:FL@8F5S=&%N9"`B)7,B(&)E<W1A870@
M;FEE="X`1&4@:6YG979O97)D92!T96MS="!K;VUT(&YI970@;W9E<F5E;B!M
M970@9&4@=&5K<W0@;W`@:&5T('-C:&5R;2X`06QL965N(&1E(&)O=F5N+2!E
M;B!O;F1E<FMA;G0`06QL965N(&1E(&)O=F5N:V%N=`!$92!U<&QO861E9"!D
M871A(&ES(&YA(&1E('9O;W)G86%N9&4@<W1A<"!V97)L;W)E;B!G96=A86XN
M`$AE="!U<&QO861E9"!B97-T86YD(&ES(&YI970@;W!G97-L86=E;BX`2&5T
M('=E871H97(N8V]M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX`5&AE;6%D
M:7)E8W1O<GD@(B5S(B!N:65T(&=E=F]N9&5N+@!'965N(&]P=&EE<R!B97-C
M:&EK8F%A<BX`17(@>FEJ;B!G965N(&]N9&5R9&5L96XL('=E;&ME(&EN;&EN
M92!W965R9V5G979E;B!K=6YN96X@=V]R9&5N+@!%<B!Z:6IN('1E('9E96P@
M:V%R86MT97)S(&EN(&1I="!V96QD+B!5(&AE969T("5S(&MA<F%K=&5R<R!O
M<&=E9V5V96X[('4@9&EE;G0@;6EN9&5R(&1A;B`E<R!O<"!T92!G979E;BX`
M165N('!R;V)L965M(&UE="!H970@=&]E=F]E9V5N('9A;B`B)7,B(&%A;B!H
M970@<WES=&5E;3H@)7,`165N('!R;V)L965M(&UE="!H970@=F5R=VEJ9&5R
M96X@=F%N(&1A=&$@=F%N(&=E8G)U:6ME<B`B)7,B('5I="!H970@<WES=&5E
M;3H@`$5E;B!P<F]B;&5E;2!M970@:&5T('9E<G=I:F1E<F5N('9A;B`B)7,B
M('5I="!H970@<WES=&5E;3H@`$5E;B!P<F]B;&5E;2!M970@:&5T(&)I:G=E
M<FME;B!V86X@(B5S(CH@)7,`165N('!R;V)L965M(&UE="!D92!B97-T86YD
M<W5P;&]A9#H@1V5E;B`E<R!W97)D(&=E=7!L;V%D+@!%96X@<')O8FQE96T@
M;65T(&1E(&)E<W1A;F1S=7!L;V%D.B!(970@)7,@:7,@9W)O=&5R(&1A;B!D
M92!M87AI;75M('1O96QA871B87)E(&=R;V]T=&4@*"5D(&)Y=&5S*2X`165N
M('!R;V)L965M(&UE="!D92!B97-T86YD<W5P;&]A9#H@2&5T("5S(&ES('-L
M96-H=',@9V5D965L=&5L:6IK(&=E=7!L;V%D+@!%96X@9F]U="!B:6H@:&5T
M(&)E:VEJ:V5N('9A;B!D:70@8F5R:6-H=&]N9&5R9&5E;`!%96X@9F]U="!B
M:6H@:&5T(&EM<&]R=&5R96X@=F%N(&1E(&%D<F5S9&%T82X`165N(&9O=70@
M8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D92!I0V%L96YD87)D871A+@!%96X@
M9F]U="!I;B!H970@8V]N9FEG=7)A=&EE9F]R;75L:65R+B!-:7-S8VAI96X@
M8F5N="!U(&5E;B!V97)P;&EC:'0@=F5L9"!V97)G971E;BX`165N(&9O=70@
M8FEJ(&AE="!U:71V;V5R96X@=F%N(&1E(&]P9V5G979E;B!A9')E<V)O96MF
M=6YC=&EE+B!0<F]B965R(&QA=&5R(&]P;FEE=7<L(&$N=2YB+@!%96X@9F]U
M="!M970@:&5T(&)I:G=E<FME;B!V86X@9&4@861R97-D971A:6QS+B!0<F]B
M965R(&QA=&5R(&]P;FEE=7<L(&$N=2YB+@!%96X@9F]U="!M970@:&5T(&)I
M:G=E<FME;B!V86X@9&4@9&ES=')I8G5T:65L:6IS="X@4')O8F5E<B!L871E
M<B!O<&YI975W+"!A+G4N8BX`1&5Z92!)34%0('-E<G9E<B!O;F1E<G-T975N
M="!G965N(&1E;&EN9R!V86X@;6%P<&5N+@!$:70@;&EJ:W0@;FEE="!E96X@
M9V5L9&EG(')A<B!B97-T86YD('1E('II:FXN`$1I="!L:6IK="!N:65T(&5E
M;B!G96QD:6<@>FEP(&)E<W1A;F0@=&4@>FEJ;BX`1&ET(&QI:FMT(&YI970@
M965N(&=E;&1I9R!K86%R=&YU;6UE<B!T92!Z:6IN+@!$:70@<W1U=7)P<F]G
M<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@
M9&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y
M('1E('9E<GIE;F1E;BP@9"YM+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R
M;V=R86UM82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I
M82!D92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y('1E('9E<GIE
M;F1E;BP@9"YM+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R;V=R86UM82!G
M965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!S;7,R
M96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y('1E('9E<GIE
M;F1E;BP@9"YM+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R;V=R86UM82!G
M965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!33510(&0N
M;2YV+B!D92!6;V1A9F]N92!)=&%L>2!G871E=V%Y('1E('9E<GIE;F1E;B!N
M86%R(%9O9&%F;VYE(&YU;6UE<G,N($AI97)V;V]R(&ES(&5E;B!6;V1A9F]N
M92!)=&%L>2!E+6UA:6QA9')E<R`H:'1T<#HO+W=W=RXQ.3`N:70I(&YO;V1Z
M86ME;&EJ:RX`1&ET('9E;&0@:7,@=F5R96ES=`!$:70@=F5L9"!M86<@86QL
M965N(&EN=&5G97)S(&)E=F%T=&5N+@!$:70@=F5L9"!M86<@86QL965N(&=E
M=&%L;&5N(&5N(&1E(&1U8F)E;&4@<'5N="!B979A='1E;BX`1&ET('9E;&0@
M;6%G(&%L;&5E;B!O8W1A86P@=V%A<F1E;B!B979A='1E;BX`1&ET('9E;&0@
M9&EE;G0@965N(&MO;6UA(&]F('-P871I92!G97-C:&5I9&5N(&QI:G-T(&UE
M="!I;G1E9V5R<R!T92!Z:6IN`$1E>F4@=V%A<F1E(&1I96YT(&5E;B!G96QD
M:6<@9V5T86P@=&4@>FEJ;BX`1&ET('9E;&0@9&EE;G0@965N(&ML975R8V]D
M92!I;B!21T(@2$58+69O<FUA870@=&4@8F5V871T96XL(&(N=BX@)R,Q,C,T
M868G+@!$:70@9F]R;75L:65R(&ES(')E961S('9E<G=E<FMT+@!$:70@:7,@
M)7,N`$1I="!I<R!E96X@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@3VT@9&ET
M(&]B:F5C="!W965R('1E(&=E=F5N(&AE969T('4@965N(&4M;6%I;"!C;&EE
M;G0@;F]D:6<@9&EE(&AE="!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A="!B96=R
M:6IP="X@5F]O<B!E96X@;&EJ<W0@;65T(&1E>F4@92UM86EL8VQI96YT<RP@
M8F5Z;V5K("5S+"!A+G4N8BX`1&ET(&)E<FEC:'0@:7,@:6X@965N(&%N9&5R
M92!K87)A:W1E<G-E="`H)7,I(&=E<V-H<F5V96XL(&1A;B!U=R!E:6=E;BX`
M1&ET(&=E=&%L(&1I96YT('1E;FUI;G-T92#IZ6X@=&4@>FEJ;BX`1&5Z92!S
M97)V97(@:V%N(&=E96X@>FEP(&5N(&=Z:7`@8F5S=&%N9&5N('5I='!A:VME
M;BX`2&5T('-Y<W1E96T@:7,@;6]M96YT965L('5I=&=E<V-H86ME;&0N`$1E
M>F4@=V%A<F1E(&1I96YT(&5E;B!G971A;"!T92!Z:6IN+@!$:70@<V-H97)M
M(&1I96YT(&%A;F=E<F]E<&5N('1E('=O<F1E;B!V86YU:70@965N($]P=&EE
M<W-C:&5R;0!/;G=E97(`5&EC:V5T<P!4:6ID`%1I:F1P;&%N;FEN9P!4:6ID
M9F]R;6%A=`!4:6ID<V5L96-T:64`5&EM;W(M3&5S=&4`5&ET96P`5&ET96P@
M*'1O;VQT:7`I.@!!86X`3VT@;65E<F1E<F4@;VYD97)D96QE;B!T92!S96QE
M8W1E<F5N+"!H;W5D(&1E($-O;G1R;VP@*%!#*2!O9B!#;VUM86YD("A-86,I
M('1O971S('9A<W0@=&EJ9&5N<R!K;&EK:V5N+@!686YD86%G`$A434P@8G)O
M;B!O;7-C:&%K96QE;@!4;V=O`%1O:V5L874`36]R9V5N`%1O;F=A`%1E('9E
M96P@;VYG96QD:6=E(&%A;FUE;&1I;F=E;B!G961U<F5N9&4@9&4@869G96QO
M<&5N(&UI;G5T96XN`$)O=F5N:V%N=`!";W9E;G-T92!F<F%M92`H7W1O<"D`
M5F5R=&%L:6YG96X`5')I;FED860@96X@5&]B86=O`%1R=64@;V8@9F%L<V4`
M1&D`5'5N97-IZP!4=7)K:6IE`%1U<FMS("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,@96X@0V%I8V]S(&5I;&%N9&5N`%1U=F%L=0!4>7`@=7<@
M:V5U>F4Z(`!5+E8N(&EN9&5X.B``55),`%523"!V;V]R('5W(&%F;&5V97)I
M;F=S<W1A='5S<F%P<&]R="!S8W)I<'0`55),.@!/96=A;F1A`$]E:W)A[VYE
M`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!A86X@=&4@<W!R96ME;BX`
M3FEE="!I;B!S=&%A="!E>'1R82!G96)R=6EK97)S:6YF;W)M871I92!T;V4@
M=&4@=F]E9V5N(&)I:B!I;G-C:')I:G9E;BX`3FEE="!I;B!S=&%A="!D92!R
M96-H=&5N('9A;B!61E,@8F5S=&%N9"`B)7,B('1E('=I:GII9V5N+@!.:65T
M(&EN('-T86%T(&1E(')E8VAT96X@=F%N(%9&4R!B97-T86YD("5S+R5S('1E
M('=I:GII9V5N+@!.:65T(&EN('-T86%T('1E('=I:GII9V5N(&YA87(@)7,N
M`$YI970@:6X@<W1A870@8F5S=&%N9'-G<F]O='1E('9A;B`B)7,B('1E(&-O
M;G1R;VQE<F5N+@!.:65T(&EN('-T86%T(&)E<W1A;F1S9W)O;W1T92!V86X@
M(B5S+R5S(B!T92!C;VYT<F]L97)E;BX`3FEE="!I;B!S=&%A="!M970@9&4@
M4U%,('-E<G9E<B!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@;65T(%-3
M3"!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@
M:V]P:>MR96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`B)7,B('1E
M(&UA:V5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@;6%K96XN
M`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@:6X@
M<W1A870@5D93(&UA<"`B)7,B('1E(&UA:V5N+@!.:65T(&EN('-T86%T(&5E
M;B!L965G(%9&4R!B97-T86YD('1E(&UA:V5N+@!.:65T(&EN('-T86%T(&1A
M=&$@=6ET('1E('!A:VME;BX`3FEE="!I;B!S=&%A="`B)7,B('1E('9E<G=I
M:F1E<F5N+"!D92!D:7)E8W1O<GD@:7,@;FEE="!L965G`$YI970@:6X@<W1A
M870@(B5S(CH@)7,@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@)7,@
M=&4@=F5R=VEJ9&5R96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE96<`3FEE
M="!I;B!S=&%A="!61E,@9&ER96-T;W)Y(')E8W5R<VEE9B!T92!V97)W:6ID
M97)E;BX`3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E('9E<G=I:F1E
M<F5N+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@)7,@=&4@=F5R=VEJ
M9&5R96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!V97)W
M:6ID97)E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!V97)W:6ID
M97)E;BX`3FEE="!I;B!S=&%A="!61E,@;6%P("(E<R(@=&4@=F5R=VEJ9&5R
M96XN`$YI970@:6X@<W1A870@5D93("5S(')E8W5R<VEE9B!T92!V97)W:6ID
M97)E;BX`3FEE="!I;B!S=&%A="!H=6ED:6=E(&1I<F5C=&]R>2!T92!B97!A
M;&5N+@!.:65T(&EN('-T86%T(&-E<G1I9FEC86%T9&5T86EL<R!U:70@=&4@
M9FEL=&5R96X`3FEE="!I;B!S=&%A="!O;2!D92!D969I;FET:64@=F%N("5S
M('1E(&QA9&5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E('9E<G!L
M86%T<V5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD("(E<R(@=&4@;W!E
M;F5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&]P96YE;B!V;V]R
M('-C:')I:G9E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!O<&5N
M96XN`$YI970@:6X@<W1A870@:&5T(&EN9V5P86MT92!B97-T86YD('1E(&]P
M96YE;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!L97IE;B`H9FEL
M97-I>F4H*2!M:7-L=6MT*2X`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T
M92!L97IE;B`H9V5T1FEL95-I>F4H*2!M:7-L=6MT*2X`3FEE="!I;B!S=&%A
M="!B97-T86YD('1E(&QE>F5N.B``3FEE="!I;B!S=&%A="!V9G-R;V]T(&1I
M<F5C=&]R>2!T92!O<&5N96XN`$YI970@:6X@<W1A870@;VT@)7,@=&4@:&5R
M;F]E;65N(&YA87(@)7,Z(&)E<W1E;6UI;F=S;6%P(&)E<W1A870@86P`3FEE
M="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E(&AE<FYO96UE;BX`3FEE="!I
M;B!S=&%A="!61E,@9&ER96-T;W)Y("5S('1E(&AE<FYO96UE;BX`3FEE="!I
M;B!S=&%A="!61E,@8F5S=&%N9"`B)7,B('1E(&AE<FYO96UE;BX`3FEE="!I
M;B!S=&%A="!61E,@8F5S=&%N9"`E<R\E<R!T92!H97)N;V5M96XN`$YI970@
M:6X@<W1A870@5D93(&)E<W1A;F0@=&4@:&5R;F]E;65N+@!+86X@)VUK:7-O
M9G,G(&YI970@=6ET=F]E<F5N+@!.:65T(&EN('-T86%T(&1I="!7;W)D(&1O
M8W5M96YT('1E('9E<G1A;&5N`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M(B5S(B!T92!S8VAR:6IV96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M=&4@<V-H<FEJ=F5N("AC;W!Y*"D@9F%I;&5D*2X`3FEE="!I;B!S=&%A="!6
M1E,@8F5S=&%N9'-D871A('1E('-C:')I:G9E;BX`3FEE="!I;B!S=&%A="!6
M1E,@8F5S=&%N9"!T92!S8VAR:6IV96XL('%U;W1A('=O<F1T(&]V97)S8VAR
M961E;BX`3VYD97)S=')E<&5N`$AE<G-T96P@=VEJ>FEG:6YG96X`1&]E="!U
M=R!L86%T<W1E(&)E=V5R:VEN9R!T96YI970`3VYV97)W86-H="!A;G1W;V]R
M9"!V86X@9&4@<V5R=F5R(&]P('9E<F)I;F1I;F<Z(`!/;G9E<G=A8VAT(&%N
M='=O;W)D('9A;B!S97)V97(@86%N.B``3VYB96YO96UD`%5N:6-O9&4@*%54
M1BTX*0!697)E;FEG9&4@07)A8FES8VAE($5M:7)A=&5N`%9E<F5N:6=D($MO
M;FEN9VMR:6IK`%9E<F5N:6=D92!3=&%T96X`5F5R96YI9V1E(%-T871E;BP@
M:VQE:6YE(&)U:71E;B!L:6=G96YD92!E:6QA;F1E;@!%96YH961E;@!/;F)E
M:V5N9`!/;F)E:V5N9"!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!/;F)E
M:V5N9"!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!/;F)E:V5N9&4@
M;&]C871I92!O<&=E9V5V96XN`$]N8F5K96YD92!G96)R=6EK97)S;F%A;2!O
M9B!W86-H='=O;W)D+@!(970@:'5I9&EG92!E;&5M96YT(&QO<VMO<'!E;&5N
M`$]N8F5N;V5M9`!.:65T(&=E<F5C:'1I9V1E('-C<FEP=',@:W5N;F5N('!R
M;V=R86UM86UA=&EG(&YI970@2VYI<'!E;B]+;W!IZW)E;B]0;&%K:V5N+"!V
M86YW96=E(&)E=F5I;&EG:6YG<W)E9&5N96XN($ML:6L@;W`@3TL@;VT@965N
M('1E8VAN:7-C:&4@;W!M97)K:6YG(&]P(&UO>FEL;&$N;W)G('1E(&)E:VEJ
M:V5N(&AO92!U(&5E;B!S8W)I<'0@=&]E<W1A870@:&5T('!R:6MB;W)D('1E
M(&)E;F%D97)E;BX`2VQE=7(@=&5R=6=S=&5L;&5N`$YI970@;VYD97)S=&5U
M;F1E(&5X=&5N=&EE`$)I:G=E<FME;@`E<R!B:6IW97)K96X`1V5B<G5I:V5R
M(&)I:G=E<FME;BX`(B5S(B!B:6IG97=E<FMT+@!5<&=R861E('-C<FEP="!V
M97)W:6ID97)D+@!5<&QO860`06QL92!T;V5P87-S:6YG('-E='5P8F5S=&%N
M9&5N(&YA87(@9&4@<V5R=F5R(&=E=7!L;V%D+@!,871I:FYS92!H;V]F9&QE
M='1E<G,`1W)O=&4@4F]M96EN<V4@9V5T86QL96X`57)U9W5A>0!'96)R=6EK
M(&AU:61I9V4Z("5S`$=E8G)U:6L@4U-,`$=E8G)U:6ME;B!W86YN965R(&YA
M86TO=V%C:'1W;V]R9"!V97)S8VAI;'0@;65T($E-4U`@<V5R=F5R+@!'96)R
M=6EK97(`1V5B<G5I:V5R("5S(&ES(&YI970@9V5A=71O<FES965R9"!V;V]R
M("5S+@!'96)R=6EK97)S8F5H965R`$=E8G)U:6ME<G-O<'1I97,`1V5B<G5I
M:V5R<W)E9VES=')A=&EE`$=E8G)U:6ME<G-R96=I<W1R871I92!I<R!U:71G
M97-C:&%K96QD(&]P(&1E>F4@<VET92X`1V5B<G5I:V5R<V%C8V]U;G0@;FEE
M="!G979O;F1E;BX`1V5B<G5I:V5R<VYA86T`1V5B<G5I:V5R<VYA86T@(B5S
M(B!B97-T86%T(&%L+@!'96)R=6EK97)S;F%A;3H`1V5B<G5I:V5R<VYA86TZ
M(`!'96)R=6EK97)S(&EN(&AE="!S>7-T965M.@!/97IB96MI<W1A;@!61E,@
M9&ER96-T;W)Y(&)E<W1A870@;FEE="X`069W97II9VAE:60`1V5V;VYD96X@
M9V5L9&EG92!L;V-A=&EE<R!B979A='1E;CH@`$=E;&1I9VAE:60`5V%A<F1E
M(&EN(&UI;G5T96X@=F%N868@;G4N`%=A87)D92!L:6=T(&)O=F5N(&1E(&UA
M>&EM=6T@;&5N9W1E('9A;B`E<RX`5V%A<F1E;@!786%R9&5N('=A87)U:70@
M9V5S96QE8W1E97)D(&MA;B!W;W)D96X`5F%N=6%T=0!687)I86)E;&4`5F5N
M97IU96QA`%9E<FEF:6-A=&EE(&UI<VQU:W0@+2!E<B!K86X@;65T(&1I="!B
M97)I8VAT(&=E:VYO96ED('II:FXN`%9E<G-I90!697)S:65C;VYT<F]L90!6
M97)T:6MA86P@=6ET;&EJ;F5N`%9E<G1I:V%L92!V<FEJ92!R=6EM=&4`5F5R
M=&EK86%L.@!%<F<@:&]O9P!6:65T;F%M`%9I971N86UE97,@*%9)4T-)22D`
M)7,@8F5K:6IK96X`0F5K:6IK(&5E;B!E>'1E<FYE('=E8G!A9VEN80!"96MI
M:FME;B!A;',@)7,`36%A9V1E;B!E:6QA;F1E;BP@0G)I='-E`$UA86=D96X@
M96EL86YD96XL(%8N4RX`6FEC:'0`6FEC:'0Z(`!6;V1A9F]N92!)=&%L>2!V
M:6$@4TU44`!705).`%=!05)30TA55TE.1R$A(2`@5D525TE*1$52(%-#4DE0
M5"!(04Y$34%424<@54E4("5S+@!724X@=FEA($A45%``5V%L;&ES(&5N($9U
M='5N80!786%R<V-H=7=I;F<`5V\`5V5E<G-V;V]R=6ET>FEC:'0`5V5E<F)E
M<FEC:'0@9V5G979E;G,@9V5L979E<F0@9&]O<@!796%T:&5R+F-O;0!796(`
M5V5B<VET90!796ME;&EJ:W,`5V5L:V]M`%=E;&MO;2!B:6H@)7,`5V5L:V]M
M+"`E<P!797-T97)S("A)4T\M.#@U.2TQ*0!797-T97)S("A)4T\M.#@U.2TQ
M-2D`5V5S=&5L:6IK92!386AA<F$`5V5L:V4@=&]E<&%S<VEN9R!D:65N="`E
M<R!W965R('1E(&=E=F5N(&YA(&%A;FUE;&1I;F<_`%=A="!I<R!H970@<V-H
M96ED:6YG<VMA<F%K=&5R/P!7870@:7,@:&5T(&-I=&%A=&MA<F%K=&5R/P!7
M:&5R96ES($%U<W1R86QIZR!K86%R=`!796QK92!F87-E;@!796QK92!P;'5G
M:6YS('9O;W(@9&4@4FEC:"!497AT(&5D:71O<B!I;G-C:&%K96QE;BX`0G)E
M961T90!"<F5E9'1E(&EN($-34R!E96YH961E;@!"<F5E9'1E('9A;B!H970@
M)7,@;65N=2!A86X@9&4@;&EN:V5R:V%N="`H86MT:65F(&)I:B!V;VQG96YD
M92!A86YM96QD:6YG*3H`0G)E961T92!V86X@9&4@=&%B96P`0G)E961T92!E
M96YH96ED`$)R965D=&4Z`%=I:VD`5VEN9`!7:6YD('9R;V5G`%=I;F1S;F5L
M:&5I9"!I;B!K;F]P96X`5VEN9#H`5VEN9#H@`%=I:G-H96ED`%=E;G-L:6IS
M=`!797)K`%=E<FMA9')E<P!496PN;G(N("AW97)K*0!697)K965R9"!A86YT
M86P@=F5L9&5N(&EN(')E9V5L("5D+B!697)W86-H="`E9"P@9V5V;VYD96X@
M)60N`%9E<FME97)D(&%A;G1A;"!V96QD96XN(%9E<G=A8VAT("5D+"!G979O
M;F1E;B`E9"X`5F5R:V5E<F1E(&]F9G-E="`E9"!B:6H@;&5Z96X@=F%N(%9&
M4R!B97-T86YD+@!8+5)E9@!8-3`Y=C,@8F%S:7-B97!E<FMI;F=E;@!8-3`Y
M=C,@=6ET9V5B<F5I9"!S;&5U=&5L9V5B<G5I:P!8-3`Y=C,@86QT97)N871I
M979E(&]N9&5R=V5R<&YA86T`6#4P.78S(&]N9&5R=V5R<"!S;&5U=&5L:61E
M;G1I9FEC871O<@!8-3`Y=C,@97AT96YT:65S`$I*`$I*2DH`66%H;V\A(&UA
M<`!*86%R;&EJ:W,`2F5M96X`2F$`2F$L(&EK(&%C8V5P=&5E<B!D92!V;V]R
M=V%A<F1E;@!5(&)E;G0@:6X@5$5+4U0@34]$12X@1V5B<G5I:R!D92!;/#Y=
M(&MN;W`@;VT@;F%A<B!765-)5UE'('1E<G5G('1E('-C:&%K96QE;BX`2&5T
M(&ES('4@;FEE="!T;V5G97-T86%N(&]M(&UE97(@9&%N("5D(&)L;VMK96X@
M=&4@;6%K96XN`%4@8F5N="!N:65T(&=E875T:&5N=&EF:6-E97)D+@!5(&MU
M;G0@9V5E;B`G7"<@:V%R86MT97(@:6X@=7<@=F]L;&5G92!N86%M(&AE8F)E
M;BX`52!H965F="!G965N(&=E;&1I9R!E+6UA:6QA9')E<R!O<&=E9V5V96XN
M`%4@:&5E9G0@9V5E;B!V96QD96X@=6ET(&AE="!G96EM<&]R=&5E<F1E(&)E
M<W1A;F0@9V5K;W!P96QD(&UE="!D92!O=F5R965N:V]M<W1I9V4@=F5L9&5N
M(&EN("5S+@!5(&)E;G0@869G96UE;&0N`%4@9&EE;G0@965N(&=E;&1I9R!M
M;V)I96P@;G5M;65R(&EN('1E('9O97)E;BP@86QL965N(&-I:F9E<G,@;65T
M(&5E;B!O<'1I;VYE;&4@)RLG('9O;W(@:&5T(&EN=&5R;F%T:6]N86QE(&MI
M97-V;V]R=F]E9W-E;"X`52!D:65N="!E96X@9V5L9&EG92!W86%R9&4@;W`@
M=&4@9V5V96XN`%4@9&EE;G0@965N($1A=&%4<F5E(&)A8VME;F0@=&4@8V]N
M9FEG=7)E<F5N(&]M(&EN<V-H<FEJ=FEN9V5N('1E(&MU;FYE;B!G96)R=6EK
M96XN`%4@9&EE;G0@965N(%9&4R!B86-K96YD('1E(&-O;F9I9W5R97)E;BX`
M52!D:65N="!H970@<')O8FQE96T@=&4@8F5S8VAR:6IV96XL('9O;W)D870@
M=2!H970@<')O8FQE96UR87!P;W)T(&MU;G0@=F5R>F5N9&5N+@!5(&1I96YT
M(&5E;B!54DP@:6X@=&4@=F]E<F5N('=A87)N86%R(&1E>F4@;&EN:R!V97)W
M:6IS=`!5(&1I96YT(&5E;B!S97)V97(@=&4@<V5L96-T97)E;B!O;2!T92!V
M97)W:6ID97)E;BX`52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@
M9V5V96X@;VT@=&4@=VES<V5N+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A
M;2!O<"!T92!G979E;B!O;2!T92!V97)W:6ID97)E;BX`52!D:65N="!E96X@
M9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@=&]E('1E('9O96=E;BX`
M52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@8FEJ
M('1E(&MU;FYE;B!W97)K96XN`%4@9&EE;G0@965N(&)E=V5R:VEN9R!O<"!T
M92!G979E;B!W96QK92!U:71G979O97)D(&UO970@=V]R9&5N+@!5(&1I96YT
M(&5E;B!N:65U=V4@8V%T96=O<FEE;F%A;2!O<"!T92!G979E;BX`52!D:65N
M="!E96X@271A;&EA86YS('1E;&5F;V]N;G5M;65R(&]P('1E(&=E=F5N`%5W
M("5S('-E<W-I92!I<R!V97)L;W!E;BX@3W!N:65U=R!A86YM96QD96XL(&$N
M=2YB+@!5=R!E+6UA:6QA9')E<P!5=R!686XZ(&%D<F5S.@!5=R!I;F9O<FUA
M=&EE`%5W(&EN=&5R;F5T861R97,@:7,@9V5W:6IZ:6=D('-I;F1S(&AE="!B
M96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U=R!V96EL:6=H96ED('1E(&)E
M<V-H97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T92!M96QD96XN
M`%5W(&YA86TZ`$AE="!T;V5V;V5G96X@=F%N(&=E8G)U:6ME<G,@=V]R9'0@
M;FEE="!O;F1E<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T:64@8F%C:V5N
M9"X@5V%N;F5E<B!U($AO<F1E(&=E8G)U:6ME<G,@=VEL="!B96AE<F5N+"!D
M:65N="!U(&5E;B!A;F1E<B!A=71H96YT:6-A=&EE(&)A8VME;F0@=&4@9V5B
M<G5I:V5N+@!(970@=V5E<F=E=F5N('9A;B!E96X@9V5B<G5I:V5R<VQI:G-T
M('=O<F1T(&YI970@;VYD97)S=&5U;F0@9&]O<B!U=R!A=71H96YT:6-A=&EE
M(&)A8VME;F0L(&]F(&1E>F4@;W!T:64@:7,@;VT@86YD97)E(')E9&5N96X@
M=6ET9V5S8VAA:V5L9"X`57<@8G)O=W-E<B!L:6IK="!T92!Z:6IN(&=E=VEJ
M>FEG9"!S:6YD<R!H970@8F5G:6X@=F%N('5W("5S('-E<W-I92X@3VT@=7<@
M=F5I;&EG:&5I9"!T92!B97-C:&5R;65N+"!D:65N="!U('II8V@@;W!N:65U
M=R!A86X@=&4@;65L9&5N+@!5=R!B<F]W<V5R(&]N9&5R<W1E=6YT(&1E>F4@
M;6]G96QI:FMH96ED(&YI970N`%5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z
M92!P<FEN=&]P=&EE(&YI970N($1R=6L@;W`@0V]N=')O;"]#;VUM86YD("L@
M4"!O;2!A9B!T92!D<G5K:V5N+@!5=R!H=6ED:6=E('1I:F1Z;VYE.@!5=R!S
M=&%N9&%A<F0@:61E;G1I=&5I="!I<R!G97=I:GII9V0N`%5W('-T86YD86%R
M9"!I9&5N=&ET96ET.@!5=R!V;VQL961I9V4@;F%A;3H`57<@86%N;65L9&EN
M9R!I<R!V97)L;W!E;BX`57<@;FEE=7=E('=A8VAT=V]O<F0@=F]O<B`E<R!I
M<SH@)7,`57<@;W!T:65S('II:FX@8FEJ9V5W97)K="!V;V]R(&1E(&1U=7(@
M=F%N(&1E>F4@<V5S<VEE+@!5=R!O<'1I97,@>FEJ;B!B:6IG97=E<FMT+@!5
M=R!W86-H='=O;W)D(&ES(&=E<F5S970`57<@=V%C:'1W;V]R9"!I<R!V97)N
M:65U=V0L(&-O;G1R;VQE97(@=7<@92UM86EL(&5N(&UE;&0@86%N(&UE="!U
M=R!N:65U=V4@=V%C:'1W;V]R9"X`57<@=V%C:'1W;V]R9"!I<R!V97)L;W!E
M;BX`57<@<V5R=F5R<R!O<"!A9G-T86YD.@!*;V5G;W-L879IZP!:8>]R90!:
M86UB:6$`6FEM8F%B=V4`6FEP<'D`6U9E<F)E<F<@86%N9V5H86%L9&4@=&5K
M<W1=`%M0<F]B;&5E;7)A<'!O<G1=`%M!86YG96AA86QD92!T96MS="!W965R
M9V5V96X@+0!;06%N9V5H86%L9&4@=&5K<W0@+2`E<R!R96=E;'-=`%MR96=E
M;"`E<R!V86X@)7-=`$)?96AE97(`7T-,20!?1&%T851R964`5F5R7W=I:F1E
M<B!R:6H`7T=R;V5P96X`7TAE;'``7T%F8F5E;&1I;F=S96EG96YS8VAA<'!E
M;BXN+@!?06%N;65L9&5N`%]!9FUE;&1E;@!?5VEJ>FEG(&QI;FLN+BX`7T]P
M=&EE<P!?4F5C:'1E;@!?5F5R=VEJ9&5R(&QI;FLN+BX`7TEN<W1E;&QE;@!?
M5&%B96QE:6=E;G-C:&%P<&5N+BXN`$=E7V)R=6EK97)S`$%D<F5S8F]E:P!'
M96%D<F5S<V5E<F1E(&]N8F5K96YD`$MA;&5N9&5R`$MA;&T`2V%N(&]U='!U
M=&)E<W1A;F0@;FEE="!M86ME;@!+86X@:6YP=70@;FEE="!O<&5N96X`2VQI
M:R!H:65R`$-O;6UA;F1O<F5G96P@9V5B<G5I:W-F;W5T`$-O;F9I9W5R871I
M969O=70`2W)I=&ES8V@@<WES=&5E;6)E<W1A;F0@;VYT8G)E96MT`$1A=&%F
M;W)M86%T9F]U=`!B97=E<FME;@!I;G9O97(@;FEE="!G979O;F1E;@!D86QE
M;F0`8F5S=&%N9`!V86X@9&4@)7,@*"5S*2!O<"`E<R`E<P!V;&%G97)I9P!H
M.@!H:`!H;W-T;F%A;2!O;F)E:V5N9`!O;FUI9&1E;&EJ:P!I;FQI;F4`:6YP
M=70O;W5T<'5T(&9O=70`:6YT97)N92!S;V9T=V%R969O=70`<F5G96QS70!M
M:VES;V9S(&9O=71C;V1E("5D(&)I:B!H970@86%N;6%K96X@=F%N($E33RX`
M;6T`;F%A;0!N:65T('9A;B!T;V5P87-S:6YG`$YO9R!N:65T('9A;B!T;V5P
M87-S:6YG`&YO=&ET:65B;V5K`'!R;V-E;G0`4F5C:'0@9V5W96EG97)D`'!I
M>&5L<P!296UO=&4@9F]U="!I;B!P<F]T;V-O;`!S=&EJ9V5N9`!397)V:6-E
M(&YI970@8F5S8VAI:V)A87(`=&]O;B!V97)S8VAI;&QE;@!S;7,R96UA:6P@
M=FEA($A45%``<W,`<W1A8FEE;`!S>7-T965M9F]U=`!T86ME;FQI:G-T`'1I
M:F1E;&EJ:V4@;6ES;'5K:VEN9P!6;V5R+"!T97(@8F5V97-T:6=I;F<L(&AE
M="!W86-H='=O;W)D('1W964@;6%A;"!I;@!U;FEF:65D`&]N8F5N;V5M9`!'
M96)R=6EK97)S96QE8W1I90!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FQ?3DPO:&5L
M<"YX;6P`````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S
M,S(P`#$P-#$W,S8R-S<W`#`R,#,T,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M
M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]N;%].3"]H96QP+GAM;"QV(#$N,B`R
M,#`T+S`U+S(W(#(P.C(R.C$T(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N
M=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T
M86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R
M;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*
M("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W
M(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@
M24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K
M<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T
M960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@
M('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O
M;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I
M;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T
M87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@
M=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y
M;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI
M8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@
M=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^
M"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE
M/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@
M<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI
M8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I
M8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L
M92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@
M=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E
M;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK
M92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE
M>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L
M(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R
M=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H
M86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"CPO:&5L<#X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYN7TY/+P``````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<W-P`P,38W,#``(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O;FY?3D\O3$-?34534T%'15,O````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`R,#0V-0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]N;E].3R],0U]-15-304=%4R]H;W)D92YM
M;P``````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C,R,#$`,3`T,3<S-C(W-S<`
M,#(R,3$V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-X2!)4`````F0```!P```#D!```TP```*P)````````^`P```L```#Y
M#```*`````4-```5````+@T```@```!$#0``!0```$T-```#````4PT```\`
M``!7#0``"````&<-```(````<`T``!D```!Y#0``!P```),-```,````FPT`
M``X```"H#0``!0```+<-```?````O0T``#D```#=#0``)P```!<.```L````
M/PX``"H```!L#@``$0```)<.```(````J0X```@```"R#@``!@```+L.```5
M````P@X```H```#8#@``$0```.,.```,````]0X```<````"#P``$`````H/
M```K````&P\``!X```!'#P``&P```&8/```;````@@\``#,```">#P``+P``
M`-(/```I`````A````(````L$```!0```"\0```0````-1````8```!&$```
M%````$T0```O````8A````\```"2$```)@```*(0```$````R1````4```#.
M$```#0```-00```%````XA```!````#H$```$````/D0```/````"A$```L`
M```:$0``#P```"81```,````-A$```\```!#$0``'@```%,1```A````<A$`
M``,```"4$0``#````)@1```4````I1$```8```"Z$0``!````,$1```,````
MQA$```H```#3$0``!0```-X1```2````Y!$``!````#W$0``"`````@2```0
M````$1(``!H````B$@``!@```#T2```'````1!(```(```!,$@``)0```$\2
M```$````=1(```\```!Z$@``!P```(H2```'````DA(```D```":$@``!P``
M`*02```2````K!(```0```"_$@``!P```,02```%````S!(``#,```#2$@``
M&@````83```%````(1,```<````G$P``$0```"\3```(````01,``!4```!*
M$P``'@```&`3```H````?Q,```L```"H$P``&@```+03```%````SQ,``"@`
M``#5$P``*0```/X3```3````*!0``#(````\%```!````&\4```&````=!0`
M``L```![%```!0```(<4```1````C10```0```"?%```#````*04```:````
ML10``!<```#,%```%P```.04```;````_!0``!D````8%0``'P```#(5```3
M````4A4```0```!F%0``$````&L5```7````?!4```<```"4%0``!0```)P5
M```Q````HA4``#@```#4%0``(0````T6```<````+Q8```4```!,%@```P``
M`%(6```@````5A8``"8```!W%@``#````)X6```&````JQ8``!,```"R%@``
M#````,86```(````TQ8``!0```#<%@``!P```/$6```&````^18```T`````
M%P``"P````X7```,````&A<```H````G%P```@```#(7```&````-1<```P`
M```\%P``10```$D7```F````CQ<``"4```"V%P``,````-P7```0````#1@`
M`',````>&```'P```)(8```0````LA@```\```##&```!0```-,8``!B`0``
MV1@```H````\&@``*````$<:```4````<!H```@```"%&@``!0```(X:```(
M````E!H``!,```"=&@``#````+$:```/````OAH``!X```#.&@``!P```.T:
M```*````]1H```X`````&P``!0````\;```C````%1L``#L````Y&P``+0``
M`'4;```O````HQL``"X```#3&P``$P````(<```'````%AP```@````>'```
M!@```"<<```5````+AP```P```!$'```%@```%$<```.````:!P```4```!W
M'```$````'T<```K````CAP``!T```"Z'```(````-@<```<````^1P``#``
M```6'0``-@```$<=```L````?AT```(```"K'0``!@```*X=```1````M1T`
M``8```#''0``$0```,X=```F````X!T``!$````''@``(P```!D>```%````
M/1X```8```!#'@``#@```$H>```$````61X``!````!>'@``$````&\>```/
M````@!X```\```"0'@``#P```*`>```,````L!X``!````"]'@``'P```,X>
M```C````[AX```0````2'P``#0```!<?```4````)1\```<````Z'P``!0``
M`$(?```/````2!\```\```!8'P``!0```&@?```3````;A\``!````""'P``
M!0```),?```2````F1\``"````"L'P``"````,T?```'````UA\```(```#>
M'P``)0```.$?```&````!R```!`````.(```"0```!\@```'````*2````D`
M```Q(```"````#L@```5````1"````0```!:(```"````%\@```%````:"``
M`#@```!N(```(````*<@```'````R"````H```#0(```$0```-L@```'````
M[2```!4```#U(```'`````LA```L````*"$```<```!5(0``%@```%TA```'
M````="$``"4```!\(0``)````*(A```6````QR$``"\```#>(0```P````XB
M```%````$B(```D````8(@``"0```"(B```6````+"(```4```!#(@``$```
M`$DB```9````6B(```\```!T(@``#P```(0B```8````E"(``!````"M(@``
M$````+XB```3````SR(```,```#C(@``%0```.<B```:````_2(```<````8
M(P``"````"`C```I````*2,``#4```!3(P``'@```(DC```>````J",```8`
M``#'(P```P```,XC```>````TB,``"@```#Q(P``#P```!HD```(````*B0`
M`!0````S)```$````$@D```*````620``!0```!D)```"````'DD```)````
M@B0```\```",)```#````)PD```/````J20```\```"Y)````@```,DD```%
M````S"0```X```#2)```.@```.$D```J````'"4``"T```!')0``,@```'4E
M```/````J"4``'D```"X)0``)@```#(F```0````628``!````!J)@``!0``
M`'LF```!````;@````````"+````!@```````````````````&,````3````
M#0``````````````A@```(`````9````3P```!(````:````=0````D```!V
M````!````"@````%`````````&T```!(````.````$(`````````80````P`
M`````````````($```"-````0P```&8````L````"``````````W````/@``
M`((```!H`````````&H````\````9`````````!$````<0```#````!0````
M>0```%H```"0````5P```!4`````````$0```)D`````````'`````,`````
M````AP```#T```!]``````````````!X````:0```"L```")`````````"D`
M````````<``````````+````A0```````````````````(,```"*````````
M````````````>@``````````````)`````````!'````6````!````!*````
M*@```"8````4``````````````!E````70```)<``````````````',```"4
M````C@```(\``````````````#4```![````,@```'<``````````````"4`
M``!-````50```"T```"$````(@```$8`````````-````%$`````````'P``
M`%(````/``````````(````>``````````````"5````DP```$4```!T````
MC````'\`````````,P```'X`````````&````%8``````````````!T`````
M`````````#8`````````)P``````````````B````&\````Q````7P````H`
M````````5````%X````@`````````'(```!G````D@```$D````6````3@``
M``X````[````0````$L```!B````&P```&P```"6````4P```#H```!\````
M`````&L```!,````D0````<````A`````````%D````Y````F````#\````C
M````8`````````!<````%P```$$`````````6P```"X````O`````"5S("T@
M3F]T:6-E`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VX`)7,@5&5R;7,@;V8@06=R965M96YT`#(T(&AO=7)S`$%-+U!-`$%D9`!!
M9&0@82!N97<@=7-E<CH`061D('!A:7(`061D('5S97(`061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=')A
M=&EO;@!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E
M;`!#86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&EC:R!T;R!#
M;VYT:6YU90!#;&]S92!7:6YD;W<`0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D
M`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%9&ET`$5M86EL`$5M<'1Y(')E
M<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S
M`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N`$9A>`!&:6QE($UA;F%G97(`1W)O=7`@061M:6YI<W1R871I;VX`1W)O
M=7!S`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`26UP;W)T
M960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N9W5A9V4`3&ES="!(
M96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@:6X`
M3&]G(&]U=`!-30!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE;6)E<G,`365S<V%G90!-:6UE
M(%1Y<&4`36]N=&AL>0!.3RP@22!$;R!.3U0@06=R964`3F%M90!.971W;W)K
M`$YE=F5R`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344P@5D93+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;W1E
M<P!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!A<W-W;W)D
M<R!M=7-T(&UA=&-H+@!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M
M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0:&]N90!0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2X`4F5A9`!296UO=F4`4F5M;W9E('!A:7(`4F5S970`
M4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-H;W<`4VMI
M<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S
M`%1A<VMS`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AI<R!N=6UB97(@;75S="!B92!A
M="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET
M;&4`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E
M<P!5<&1A=&4`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E
M<FYA;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN9P!7965K;'D`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!960!996%R;'D`665S+"!)($%G<F5E`%EO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=`%ML
M:6YE("5S(&]F("5S70!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E
M(#,N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P
M,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`V+3`X(#(R.C,P*S`Q,#`*3&%S
M="U4<F%N<VQA=&]R.B!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^
M"DQA;F=U86=E+51E86TZ($YO<G=E9VEA;B!.>6YO<G-K(#QN>6YO<G-K0&]R
M<W1A+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=`H`)7,@+2!.;W1I<P`E<R!V961L:6ME:&%L9'-O<&5R
M87-J;VYA<B`M(%-T861F97-T:6YG`"5S(%9I;&OE<B!F;W(@879T86QE`#(T
M('1I;6%R`$%-+U!-`$QE9V<@=&EL`$QE9V<@=&EL(&YY(&)R=6MA<CH`3&5G
M9R!T:6P@<&%R`$QE9V<@=&EL(&)R=6MA<@!,96=G('1I;"!B<G5K87)A<B!E
M<B!S;.5T="!A=BX`061R97-S90!!9')E<W-E8F]K`$%D;6EN:7-T<F5R:6YG
M`$%L:6%S`$5I;B!U;&]V;&5G('9E<F1I('9A<G0@<W!E<VEF:7-E<G0N`%-P
M^'(@;VT@<W1A9&9E<W1I;F<@9OAR(&OX>7)I;F<@878@=F5D;&EK96AA;&1S
M;W!E<F%S:F]N87(_`%!R^'9D92#E('-L971T92!E:2!I:VMJ92UE:W-I<W1E
M<F%N9&4@9W)U<'!E+@!0<OAV9&4@Y2!S;&5T=&4@96EN(&EK:VIE+65K<VES
M=&5R86YD92!T:6QG86YG+@!0<OAV9&4@Y2!E;F1R92!E:6X@:6MK:F4M96MS
M:7-T97)A;F1E('1I;&=A;F<N`%1I;&=J96YG96QE9V4@9F5L=#H`0G5R<V1A
M9P!+86QE;F1E<@!!=F)R>70`079B<GET('!R;V)L96UR87!P;W)T`$UO8FEL
M=&5L969O;@!+;&EK:R!F;W(@Y2!H86QD92!F<F%M`$QU:VL@=FEN9&%U9V5T
M`$9I<FUA`%-T861F97-T('!A<W-O<F0`3W!P:V]P;&EN9R!M;W0@;V9F96YT
M;&5G(&[X:VME;'1E;F%R(&YE:W1A+@!+=6YN92!I:VMJ92!01U`M:V]D92!M
M96QD:6YG+@!+=6YN92!I:VMJ92!01U`M<VEG;F5R92!M96QD:6YG+@!+=6YN
M92!I:VMJ92!D96MO9&4@4$=0+61A=&$N`$MU;FYE(&EK:VIE(&%V9VIE<F4@
M;6]T=&%K87)E;B!S:2!E+7!O<W1A9')E<W-E+@!+=6YN92!I:VMJ92!S:V%F
M9F4@;V9F96YT;&5G(&[X:VME;"!F<N4@;OAK:V5L=&5N87)E;BX`2W5N;F4@
M:6MK:F4@;W!N92!-86EN=&5N86YC95]487-K+6UO9'5L96X@)7,`1$0`1&%G
M;&5G`%-T86YD87)D:61E;G1I=&5T`%-L971T90!3:VEL9')E('!R;V)L96UE
M=`!$971A;&IA<B!E<B!L;V=G82!F;W(@861M:6YI<W1R871O<F5N+@!6:7-I
M;F=S86QT97)N871I=@!):VMJ92!B<G5K(&UA:6YT96YA;F-E+G!H<"!D:7)E
M:W1E+@!%;F1R90!%+7!O<W0`5&]M="!R97-U;'1A="X`1F5I;`!+=F%R="`Q
M-2X@;6EN=71T`$MV87)T(#,P+B!S96MU;F0`2W9A<G0@-2X@;6EN=71T`$MV
M87(@:6YN;&]G9VEN9P!+=F%R(&AA;'9E('1I;64`2W9A<G0@;6EN=71T`$5K
M<V5M<&5L=F5R9&EA<CH`2W5N;F4@:6MK:F4@:&5N=&4@:6YN<W1I;&QI;F=A
M<@!+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N+@!&86MS`$9I
M;&AA;F1S86UI;F<`1W)U<'!E861M:6YI<W1R97)I;F<`1W)U<'!E<@!(:F5L
M<`!!9')E<W-E+"!P<FEV870`5&5L969O;BP@<')I=F%T`$AO<F1E`$EM<&]R
M=&5R=&4@9F5L=#H@)7,`26UP;W)T97)T92!F96QT.@!3<'+E:P!6:7,@96UN
M92!F<N4@2&IE;'``3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S;.5T="!A=BX`
M3&]G9R!I;FX`3&]G9R!U=`!-30!-4RU43D5&+79E9&QE9V<@:6YN96AE;&1T
M(&EN9V5N(&1A=&$N`$4M<&]S=`!386US=F%R86YD92!F96QT`$UE9&QE;6UA
M<@!-96QD:6YG`$U)344M='EP90!-Y6YA9&QE9P!.14DL(&5G(&5R($E+2TI%
M('-A;60`3F%M;@!.971T=F5R:P!!;&1R:0!);F=E;B!K;VYF:6=U<F%S:F]N
M<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344P@5D93+@!);F=E;B!G
M>6QD:6=E(%A-3"UD871A(')E='5R;F5R=`!.;W1A=&%R`$%L=&5R;F%T:78`
M06YN86X@:6YF;W)M87-J;VX`4&%S<V]R9`!087-S;W)D82!MY2!S86US=F%R
M92X`2_AY<B!V961L:6ME:&%L9'-O<&5R87-J;VYA<@!+^'ER('9E9&QI:V5H
M86QD<V]P97)A<VIO;F%R('9E9"!I;FYL;V=G:6YG/P!4:6QG86YG`%1I;&=A
M;F=S861M:6YI<W1R97)I;F<`5&5L969O;@!3:W)I=B!I;FX@96ET('-A;6%N
M9')A9R!A=B!P<F]B;&5M970N`%-K<FEV(&EN;B!D:71T(&)R=6MA<FYA;6X@
M;V<@<&%S<V]R9`!3:VEL9')I;F<@878@<')O8FQE;65T`$]F9F5N=&QE9R]P
M<FEV870@;OAK:V5L<&%R('9A<G0@:6MK:F4@9V5N97)E<G0N`$QE<P!&:F5R
M;@!&:F5R;B!P87(`3G5L;'-T:6QL`%1I;&)A:V4@=&EL(&%L=&5R;F%T:78`
M4F]L;&4`3&%G<F4@86QT97)N871I=@!696P@<VMI;&IE=&5I:VX@9F]R(&1A
M=&\Z`%9E;"!D871O9F]R;6%T.@!696P@=&ED<V9O<FUA=#H`5F5L('1O('-A
M;7-V87)A;F1E(&9E;'0N`%9E;"!F87)G97-K:F5M82X`5F5L(/AN<VMA('-P
M<N5K.@!396YD('!R;V)L96UR87!P;W)T`%9I<P!(;W!P(&]V97(@=F5D;&EK
M96AA;&0`26YN=&%S=&EN9R!A=B!S<&5S:6%L=&5I:VX`4W5K<V5S<P!/<'!G
MY79E<@!+;&%S<V$@36%I;G1E;F%N8V4Z.B!V87)T(&EK:VIE(&QA<W1A(&EN
M;@!+<GEP=&5R:6YG<V9U;FMS:F]N86YE(&MR978@96D@<VEK:V5R(&YE='1O
M<'!K;W!L:6YG+@!$971T92!T86QE="!MY2!V97)E(&UI;G-T(&5I;BX`1&5N
M;F4@=F5R9&EE;B!MY2!V97)E(&5I="!T86PN`%1I='1E;`!54DP`2V%N(&EK
M:VIE(&MO<&QE('1I;"!344PM=&5N87(N`$MA;B!I:VMJ92!O;7-E=&IE(&1E
M='1E(%=O<F0M9&]K=6UE;G1E="X`06YG<F4@96YD<FEN9V%R`$]P<&1A=&5R
M`$)R=6MA<F%D;6EN:7-T<F5R:6YG`$)R=6MA<F%L=&5R;F%T:78`0G)U:V%R
M;F%M;@!"<G5K87)A<B!I('-Y<W1E;65T.@#%='9A<FEN9P!+=F%R('9E:V4`
M5F5L:V]M96X@=&EL("5S`%9E;&MO;65N+"`E<P!!9')E<W-E+"!A<F)E:60`
M5&5L969O;BP@87)B96ED`,7%`,5R;&5G`$IA+"!E9R!E<B!S86UD`$1U(&WE
M('-K:6QD<F4@<')O8FQE;65T(&;X<B!D=2!K86X@<V5N9&4@<')O8FQE;7)A
M<'!O<G1E;BX`1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!F
M:F5R;F4N`$1U(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N86UN(.4@;&5G
M9V4@=&EL+@#8:W1A(&1I("@E<RD@:&%R(&?E='0@=70@<.4@=&ED+B!,;V=G
M(&EN;B!PY2!N>71T+@!$:6X@:6YF;W)M87-J;VX`3&ES=&EN9R!A=B!B<G5K
M87)A<B!E<B!I:VMJ92!S=/AT=&$@878@8F%K<F4@875T96YT:7-E<FEN9RP@
M96QL97(@9G5N:W-J;VYE;B!H87(@878@96EN(&5L;&5R(&%N;F%N(&=R=6YN
M(&)L:71T('-LY71T(&%V+@!!;'1E<FYA=&EV82!D:6YE(&AA<B!B;&ET="!O
M<'!D871E<G1E+@!;4')O8FQE;7)A<'!O<G1=`%ML:6YJ92`E<R!A=B`E<UT`
M=D-A<F0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]N;E].3R]H96QP+GAM;```````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`T,3<S-C(W-S<`,#(P
M,S0U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C
M86QE+VYN7TY/+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,3,@
M:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T
M871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP
M87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM
M87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@
M97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE
M<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E
M;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L
M:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A
M;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N
M=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C
M:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG
M(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*
M(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R
M92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E
M>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E
M(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R
M9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A
M=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@
M;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A
M=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@
M=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I
M=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA
M;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E
M;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-
M86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA
M:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H
M:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE
M9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L
M;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O<&Q?4$PO````````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`Q-C8W-P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]P;%]03"],0U]-15-304=%
M4R\`````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C(W-S<`,#(P-#8T`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+W!L7U!,+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#$T,3`Q-0`Q,#0Q-S,V,C<W-P`P,C(Q,C$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````!!`P``'```
M`"0:``!=!```+#0```````"@10``2````*%%```.````ZD4```\```#Y10``
M#0````E&```(````%T8```L````@1@``#````"Q&```;````.48``"T```!5
M1@``)````(-&```I````J$8``!D```#21@``#````.Q&```+````^48``!$`
M```%1P``#@```!='```%````)D<``"@````L1P``"````%5'```*````7D<`
M`!(```!I1P``#@```'Q'```*````BT<```T```"61P``#@```*1'```1````
MLT<```T```#%1P``#````--'```-````X$<```8```#N1P``#````/5'```.
M`````D@```X````12```"````"!(```)````*4@``!H````S2```,@```$Y(
M```X````@4@``%0```"Z2```40````])``!:````84D``%<```"\20``-```
M`!1*```%````24H``!$```!/2@``"````&%*```0````:DH```\```![2@``
M"@```(M*```#````EDH```D```":2@``#0```*1*```2````LDH```\```#%
M2@``"@```-5*```/````X$H```@```#P2@``)````/E*```4````'DL``!8`
M```S2P``"````$I+```M````4TL``!D```"!2P``!P```)M+```,````HTL`
M``X```"P2P```P```+]+```+````PTL```<```#/2P``!P```-=+```%````
MWTL```,```#E2P``%P```.E+```*`````4P```\````,3```&````!Q,```.
M````-4P``!0```!$3```%P```%E,```7````<4P``!<```")3```#P```*%,
M```?````L4P```<```#13```!@```-E,```(````X$P```\```#I3```!@``
M`/E,```*`````$T```L````+30``%0```!=-```'````+4T```4````U30``
M$0```#M-```,````34T```D```!:30``!P```&1-```%````;$T``#D```!R
M30``"@```*Q-```&````MTT```D```"^30``!P```,A-```O````T$T``"X`
M````3@``50```"].```M````A4X``"T```"S3@``+0```.%.```C````#T\`
M`",````S3P``+0```%=/```S````A4\``!4```"Y3P``&0```,]/```I````
MZ4\``"0````34```$0```#A0```*````2E````P```!54```"@```&)0```0
M````;5```!8```!^4```%@```)50```'````K%````<```"T4```%````+Q0
M```*````T5````<```#<4```!P```.10```&````[%````4```#S4```!P``
M`/E0```&`````5$```@````(40``#@```!%1```*````(%$```<````K40``
M"0```#-1```6````/5$```0```!440``!@```%E1```(````8%$```,```!I
M40```P```&U1```3````<5$```@```"%40``"````(Y1```(````EU$``$$`
M``"@40``(````.)1```&`````U(```8````*4@``%0```!%2```8````)U(`
M`"(```!`4@``'0```&-2```*````@5(``!4```",4@``"@```*)2```/````
MK5(```\```"]4@``"0```,U2```4````UU(``!@```#L4@``'0````53```3
M````(U,``!$````W4P``!````$E3```&````3E,``%0```!54P``#@```*I3
M``!$````N5,```4```#^4P``!0````14```1````"E0``!$````<5```'```
M`"Y4```0````2U0``!$```!<5```#````&Y4```7````>U0``!````"35```
M"````*14```%````K50```P```"S5```$````,!4```-````T50```<```#?
M5```#0```.=4```'````]50```<```#]5```!P````55```4````#54```D`
M```B50``"@```"Q5```,````-U4``!````!$50``!0```%55```E````6U4`
M`!(```"!50``$P```)15```K````J%4``#L```#450``(````!!6```V````
M,58``!````!H5@``"````'E6```,````@E8```0```"/5@``#@```)16```>
M````HU8``!L```#"5@``(0```-Y6```>`````%<``!X````?5P``+@```#Y7
M```;````;5<``!X```")5P``,P```*A7```O````W%<``"`````,6```$@``
M`"U8```I````0%@``!X```!J6```%@```(E8``!!````H%@```<```#B6```
M!@```.I8```-````\5@``!````#_6```$@```!!9```'````(UD```0````K
M60``#````#!9```H````/5D```,```!F60``!@```&I9```.````<5D```(`
M``"`60``!0```(-9```$````B5D```X```".60``"````)U9```-````IED`
M`!````"T60``$P```,59```3````V5D```8```#M60``#````/19```1````
M`5H``!D````36@``"P```"U:```-````.5H``!L```!'6@``-````&-:```*
M````F%H``!@```"C6@``&0```+Q:```6````UEH``"\```#M6@``!P```!U;
M```4````)5L``"\````Z6P``"0```&I;```6````=%L```\```"+6P``"```
M`)M;```-````I%L``"8```"R6P``"````-E;```2````XEL```@```#U6P``
M"P```/Y;```%````"EP```8````07```!P```!=<```$````'UP```H````D
M7```#P```"]<```0````/UP``!<```!07```$0```&A<```7````>EP```4`
M``"27```"P```)A<```%````I%P```T```"J7```&P```+A<```)````U%P`
M``X```#>7```#0```.U<```@````^UP``!$````<70``!P```"Y=```%````
M-ET``!,````\70``!P```%!=```(````6%T```8```!A70``$````&A=```/
M````>5T``!````")70``#P```)I=```+````JET```\```"V70``#````,9=
M```/````TUT```<```#C70``!@```.M=```.````\ET``"$````!7@``&0``
M`"->```7````/5X``!<```!57@``&P```&U>```-````B5X```P```"77@``
M`P```*1>```(````J%X```0```"Q7@``#````+9>```)````PUX```X```#-
M7@``"P```-Q>```;````Z%X```<````$7P``!P````Q?```$````%%\``!4`
M```97P``!@```"]?```-````-E\``!````!$7P``&P```%5?```$````<5\`
M``4```!V7P``!@```'Q?```'````@U\```4```"+7P``"0```)%?```"````
MFU\```T```">7P``!@```*Q?```)````LU\```<```"]7P``!@```,5?```*
M````S%\```0```#77P``"0```-Q?```(````YE\```8```#O7P``#0```/9?
M```&````!&````0````+8```!0```!!@```A````%F````0````X8```!```
M`#U@```%````0F```!T```!(8```!````&9@```,````:V````H```!X8```
M"````(-@```)````C&````4```"68```*0```)Q@```'````QF````<```#.
M8```"@```-9@```/````X6```!````#Q8```!@````)A```2````"6$``!``
M```<80``!0```"UA```)````,V$```0````]80``#````$)A```7````3V$`
M`!P```!G80``$P```(1A```4````F&$``!D```"M80``!````,=A```'````
MS&$```8```#480``!@```-MA```%````XF$```<```#H80``!P```/!A```%
M````^&$```8```#^80``!`````5B```$````"F(```H````/8@``!0```!IB
M```,````(&(```\````M8@``"@```#UB```(````2&(``"L```!18@``!```
M`'UB```(````@F(``"8```"+8@``$@```+)B```&````Q6(```H```#,8@``
M!P```-=B```(````WV(``"````#H8@``#@````EC```6````&&,``!$````O
M8P``!@```$%C```'````2&,```<```!08P``%@```%AC```-````;V,``!``
M``!]8P``&@```(YC```)````J6,```H```"S8P``#````+YC```/````RV,`
M``8```#;8P``!P```.)C```+````ZF,``$<```#V8P``#0```#YD```#````
M3&0```H```!09````@```%MD```$````7F0```,```!C9```!0```&=D```J
M````;60```H```"89```!````*-D```&````J&0```@```"O9```"````+AD
M```$````P60```4```#&9```:````,QD```%````-64```8````[90``$```
M`$)E```*````4V4```\```!>90``"@```&YE```)````>64```,```"#90``
M!P```(=E```*````CV4```L```":90``!P```*9E```:````KF4``$H```#)
M90``!@```!1F```)````&V8```T````E9@``"@```#-F```'````/F8``!0`
M``!&9@``!@```%MF```(````8F8```<```!K9@``"@```'-F```+````?F8`
M``<```"*9@``"0```))F```)````G&8```H```"F9@``!P```+%F```)````
MN68```<```##9@``"@```,MF```*````UF8```D```#A9@``!P```.MF```$
M````\V8```<```#X9@``!0````!G```%````!F<```L````,9P``%````!AG
M```'````+6<```4````U9P``#0```#MG```,````26<```L```!69P``!```
M`&)G```$````9V<```P```!L9P``"0```'EG```%````@V<```<```")9P``
M!````)%G```*````EF<``"X```"A9P``$````-!G```M````X6<``"T````/
M:```,0```#UH```M````;V@``"X```"=:```+P```,QH```L````_&@```0`
M```I:0``#@```"YI```&````/6D``!````!$:0``!P```%5I```.````76D`
M``4```!L:0``!@```')I```(````>6D``!$```"":0``#@```)1I```"````
MHVD```<```"F:0``!@```*YI```$````M6D``!\```"Z:0``%````-II```'
M````[VD```X```#W:0``#`````9J```3````$VH```H````G:@``!0```#)J
M```1````.&H``!$```!*:@``)````%QJ```5````@6H``!(```"7:@``#@``
M`*IJ```9````N6H```@```#3:@``"0```-QJ```*````YFH```@```#Q:@``
M!0```/IJ```&`````&L``!`````':P``"````!AK```(````(6L``!(````J
M:P``&@```#UK```)````6&L```H```!B:P``%0```&UK```%````@VL``!0`
M``"):P``'@```)YK```H````O6L```H```#F:P``#P```/%K```4`````6P`
M``0````6;```"P```!ML```%````)VP```@````M;```-````#9L```T````
M:VP``"````"@;```&@```,%L```H````W&P``"D````%;0``!@```"]M```(
M````-FT```<````_;0``"P```$=M```'````4VT``!,```!;;0``"@```&]M
M```4````>FT```\```"/;0``,@```)]M```+````TFT```4```#>;0``!0``
M`.1M```7````ZFT``!X````";@``%````"%N```.````-FX```8```!%;@``
M#````$QN```-````66X```L```!G;@``"@```'-N```+````?FX```\```"*
M;@``!0```)IN```.````H&X``!,```"O;@``!P```,-N```1````RVX```<`
M``#=;@``&````.5N```$````_FX```<````#;P``"@````MO```+````%F\`
M``P````B;P``#@```"]O```2````/F\```8```!1;P``&````%AO```E````
M<6\```D```"7;P```P```*%O```*````I6\```P```"P;P``%0```+UO```+
M````TV\``!D```#?;P``(````/EO```%````&G````H````@<```#````"MP
M```$````.'````D````]<```!P```$=P```,````3W````8```!<<```#```
M`&-P```:````<'```!<```"+<```)P```*-P```:````RW```!<```#F<```
M&P```/YP```9````&G$``!\````T<0``$P```%1Q```'````:'$```D```!P
M<0``#0```'IQ```#````B'$``#\```",<0``-P```,QQ``!7````!'(```4`
M``!<<@``"@```&)R```-````;7(```0```![<@``)0```(!R```=````IG(`
M``P```#$<@``&0```-%R```)````ZW(``!,```#U<@``"0````ES```$````
M$W,``!`````8<P``"````"ES```(````,G,```\````[<P``!P```$MS```,
M````4W,``!L```!@<P``+````'QS```%````J7,```0```"O<P``%P```+1S
M```*````S',```P```#7<P``"0```.1S```)````[G,``!$```#X<P``!@``
M``IT```.````$70```<````@=```!@```"AT```'````+W0``"8````W=```
M.````%YT```:````EW0``"H```"R=```&0```-UT```%````]W0```X```#]
M=```"`````QU```)````%74```8````?=0``"P```"9U```4````,G4```8`
M``!'=0``&0```$YU```*````:'4``!P```!S=0``!0```)!U```0````EG4`
M``D```"G=0``"````+%U```?````NG4``",```#:=0``(0```/YU```?````
M('8``"<```!`=@``'P```&AV```Q````B'8``$$```"Z=@``,P```/QV```E
M````,'<``"\```!6=P``,````(9W```O````MW<``"P```#G=P``%P```!1X
M```B````+'@``$4```!/>```,````)5X```$````QG@```L```#+>```!0``
M`-=X```"````W7@``%D```#@>```!0```#IY```$````0'D```<```!%>0``
M"````$UY```%````5GD``!,```!<>0``#0```'!Y```'````?GD```8```"&
M>0``%````(UY```,````HGD```8```"O>0```P```+9Y```$````NGD```8`
M``"_>0``!P```,9Y```7````SGD``"````#F>0``&@````=Z```F````(GH`
M``P```!)>@``%````%9Z```.````:WH```T```!Z>@``!P```(AZ```'````
MD'H``!4```"8>@``!@```*YZ```&````M7H```<```"\>@``#````,1Z```1
M````T7H```@```#C>@``'0```.QZ```)````"GL```H````4>P``%````!][
M```*````-'L```@````_>P``!P```$A[```)````4'L```<```!:>P``"```
M`&)[```'````:WL``!D```!S>P``"@```(U[```7````F'L``!0```"P>P``
M$0```,5[```'````UWL```,```#?>P``!@```.-[```'````ZGL```T```#R
M>P``"P````!\```4````#'P``!4````A?```#@```#=\```O````1GP``#$`
M``!V?```/P```*A\```,````Z'P```H```#U?````@````!]```$`````WT`
M``8````(?0``!0````]]```#````%7T```P````9?0``&0```"9]``!%````
M0'T``"8```"&?0``)0```*U]```2````TWT``!,```#F?0``$````/I]``!Y
M````"WX```D```"%?@``<@```(]^``!S`````G\``!<```!V?P``%@```(Y_
M```/````I7\``!\```"U?P``0````-5_```?````%H```!0````V@```"@``
M`$N````%````5H````8```!<@```"````&.````0````;(````\```!]@```
M!````(V````+````DH````<```">@```!0```*:````'````K(````@```"T
M@```#P```+V````(````S8````P```#6@```#P```..````&````\X````8`
M``#Z@```#`````&!```(````#H$```0````7@0``!````!R!```'````(8$`
M``<````I@0``!0```#&!``!3`0``-X$``$,```"+@@``#@```,^"```2````
MWH(``!$```#Q@@``!P````.#```(````"X,```H````4@P``(@```!^#```O
M````0H,``!T```!R@P``(@```)"#```>````LX,```H```#2@P``"@```-V#
M```0````Z(,```\```#Y@P``!0````F$```G````#X0```\````WA```#@``
M`$>$```0````5H0``!````!GA```"````'B$```1````@80```T```"3A```
M$P```*&$```,````M80```L```#"A```#@```,Z$```&````W80```T```#D
MA```$@```/*$```2````!84```@````8A0``"@```"&%```7````+(4``#\`
M``!$A0``2````(2%``!<````S84``%D````JA@``8@```(2&``!?````YX8`
M`$$```!'AP``!0```(F'```.````CX<```X```">AP``#@```*V'```2````
MO(<```4```#/AP``!0```-6'```,````VX<``!````#HAP``%@```/F'```9
M````$(@```T````JB```%0```#B(```*````3H@``!X```!9B```&P```'B(
M```@````E(@``!$```"UB```+0```,>(```F````]8@```4````<B0``$```
M`"*)```-````,XD```<```!!B0``"@```$F)```'````5(D```@```!<B0``
M!0```&6)```(````:XD``",```!TB0``#P```)B)```5````J(D``!<```"^
MB0``#````-:)```7````XXD``!<```#[B0``(P```!.*```8````-XH``!,`
M``!0B@``)0```&2*```&````BHH```8```"1B@``"````)B*```/````H8H`
M``D```"QB@``"@```+N*```)````QHH``!````#0B@``"0```.&*```(````
MZXH``!$```#TB@``#@````:+```)````%8L```<````?BP``!0```">+```]
M````+8L```@```!KBP``"````'2+```)````?8L```<```"'BP``.````(^+
M```X````R(L``%L````!C```-P```%V,```W````E8P``#<```#-C```+@``
M``6-```R````-(T``#<```!GC0``/0```)^-```A````W8T``"4```#_C0``
M+P```"6.```Q````58X```X```"'C@``"P```):.```,````HHX```,```"O
MC@``"0```+..```4````O8X``!\```#2C@``#````/*.```'````_XX``!8`
M```'CP``"@```!Z/```(````*8\```8````RCP``!@```#F/```%````0(\`
M``<```!&CP``!@```$Z/```.````58\``!````!DCP``"0```'6/```'````
M?X\```@```"'CP``%````)"/```#````I8\```@```"ICP``"````+*/```#
M````NX\```,```"_CP``&P```,./```)````WX\```@```#ICP``!P```/*/
M``!/````^H\``"T```!*D```!@```'B0```&````?Y```!D```"&D```'0``
M`*"0```L````OI```"````#KD```&0````R1```6````)I$```D````]D0``
M$P```$>1```3````6Y$```D```!OD0``%@```'F1```:````D)$``!\```"K
MD0``%0```,N1```6````X9$```0```#XD0``!0```/V1``!&`````Y(```\`
M``!*D@``,P```%J2```%````CI(```4```"4D@``"P```)J2```7````II(`
M`"````"^D@``%P```-^2```6````]Y(```P````.DP``&0```!N3```-````
M-9,```@```!#DP``!0```$R3```-````4I,```P```!@DP``#0```&V3```'
M````>Y,```<```"#DP``"0```(N3```&````E9,```4```"<DP``%0```**3
M```)````N),```<```#"DP``#@```,J3```/````V9,```4```#IDP``'0``
M`.^3```<````#90``!T````JE```+````$B4```[````=90``"D```"QE```
M/@```-N4```.````&I4```@````IE0``"P```#*5```'````/I4```T```!&
ME0``*P```%25```H````@)4``"X```"IE0``*P```-B5```J````!)8``#D`
M```OE@``)0```&F6```H````CY8``"T```"XE@``,P```.:6```F````&I<`
M`!8```!!EP``+0```%B7```@````AI<``"(```"GEP``10```,J7```$````
M$)@```8````5F```"P```!R8```+````*)@``!8````TF```"0```$N8```$
M````59@```L```!:F```-P```&:8```&````GI@```0```"EF```#P```*J8
M```"````NI@```H```"]F```!````,B8```-````S9@```@```#;F```#@``
M`.28```2````\Y@``!0````&F0``%````!N9```$````,)D```H````UF0``
M$````$"9```9````49D```P```!KF0``#````'B9```;````A9D``#H```"A
MF0``"P```-R9```8````Z)D``!4````!F@``%````!>:```T````+)H```4`
M``!AF@``#0```&>:```P````=9H```<```"FF@``)@```*Z:```2````U9H`
M``<```#HF@``"0```/":```N````^IH``!T````IFP``(P```$>;```(````
M:YL```L```!TFP``"0```(";```&````BIL```<```"1FP``!@```)F;```*
M````H)L``!$```"KFP``$0```+V;```8````SYL``!4```#HFP``&````/Z;
M```%````%YP```@````=G```!0```":<```+````+)P``"4````XG```"0``
M`%Z<```0````:)P``!````!YG```-@```(J<```0````P9P```<```#2G```
M!````-J<```7````WYP```<```#WG```!P```/^<```&````!YT``!$````.
MG0``$0```""=```2````,IT``!````!%G0``%````%:=```4````:YT```\`
M``"`G0``%0```)"=```'````IIT```8```"NG0``#````+6=```J````PIT`
M`!\```#MG0``(`````V>```B````+IX``!,```!1G@``"P```&6>```0````
M<9X```0```""G@``!````(>>```%````C)X```\```"2G@``"P```**>```+
M````KIX```\```"ZG@``)@```,J>```&````\9X```D```#XG@``"`````*?
M```2````"Y\```<````>GP``$````":?```3````-Y\``"X```!+GP```@``
M`'J?```%````?9\```8```"#GP``!@```(J?```%````D9\```D```"7GP``
M`P```*&?```3````I9\```8```"YGP``"@```,"?```'````RY\``!````#3
MGP``"0```.2?```$````[I\```D```#SGP``"````/V?```&````!J````T`
M```-H```!@```!N@```$````(J````4````GH```%P```"V@```%````1:``
M``8```!+H```!@```%*@```<````6:````@```!VH```#````'^@```)````
MC*````@```"6H```"````)^@```%````J*```"4```"NH```!0```-2@```(
M````VJ````L```#CH```#P```.^@```1````_Z````<````1H0``%````!FA
M```1````+J$```4```!`H0``"0```$:A```$````4*$```T```!5H0``&P``
M`&.A```=````?Z$``!H```"=H0``'0```+BA```$````UJ$```0```#;H0``
M"````."A```&````Z:$```<```#PH0``!@```/BA```'````_Z$```<````'
MH@``!P````^B```&````%Z(```8````>H@``"````"6B```*````+J(```4`
M```YH@``$````#^B```-````4*(```X```!>H@``"@```&VB```Q````>*(`
M``8```"JH@``"````+&B```H````NJ(```\```#CH@``!@```/.B```)````
M^J(```L````$HP``!0```!"C```$````%J,``!8````;HP``&P```#*C```9
M````3J,```4```!HHP``!P```&ZC```'````=J,```4```!^HP``#0```(2C
M```6````DJ,``"<```"IHP``!0```-&C```,````UZ,```X```#DHP``&0``
M`/.C```'````#:0```<````5I```%@```!VD``!7````-*0``!L```",I```
M!0```*BD```*````KJ0```(```"YI```!````+RD```#````P:0```4```#%
MI```"0```,ND```*````U:0```8```#@I```!@```.>D```'````[J0```@`
M``#VI```!````/^D```%````!*4``%L````*I0``!@```&:E```(````;:4`
M``\```!VI0``"0```(:E```-````D*4```H```">I0``"0```*FE```#````
MLZ4```<```"WI0``"@```+^E```.````RJ4```D```#9I0``'P```..E``!:
M`````Z8```8```!>I@``"````&6F```4````;J8```H```"#I@``"````(ZF
M```2````EZ8```8```"JI@``"````+&F```*````NJ8```H```#%I@``#0``
M`-"F```&````WJ8```T```#EI@``#@```/.F```/`````J<```X````2IP``
M#@```"&G```.````,*<```@````_IP``!0```$BG```*````3J<```4```!9
MIP``"````%^G```'````:*<```4```!PIP``!0```':G```(````?*<``!,`
M``"%IP``!````)FG```%````GJ<```X```"DIP``#@```+.G```-````PJ<`
M``H```#0IP``"````-NG```.````Y*<```D```#SIP``!0```/VG```'````
M`Z@```0````+J```"@```!"H```9````&Z@``!`````UJ```*P```$:H```K
M````<J@``"\```">J```*P```,ZH```L````^J@``"T````GJ0``*@```%6I
M```%````@*D```<```"&J0``"````(ZI```5````EZD```P```"MJ0``#@``
M`+JI```%````R:D```4```#/J0``"````-6I```-````WJD```X```#LJ0``
M`@```/NI```+````_JD```4````*J@``!````!"J```G````%:H``!0````]
MJ@``!0```%*J```(````6*H```L```!AJ@``%P```&VJ```+````A:H```0`
M``"1J@``#P```):J```0````IJH``"<```"WJ@``$@```-^J```:````\JH`
M`!,````-JP``+````"&K```'````3JL```L```!6JP``#````&*K```(````
M;ZL```4```!XJP``!@```'ZK```1````A:L```@```"7JP``!0```*"K```3
M````IJL``!8```"ZJP``!@```-&K```'````V*L``!,```#@JP``!0```/2K
M```0````^JL``!H````+K```+0```":L```+````5*P```\```!@K```$P``
M`'"L```$````A*P```@```")K```!P```)*L```(````FJP``"0```"CK```
M(````,BL```?````Z:P``!L````)K0``%@```"6M```F````/*T```8```!C
MK0``"@```&JM```'````=:T```X```!]K0``!P```(RM```-````E*T```\`
M``"BK0``&P```+*M```>````SJT``#H```#MK0``"0```"BN```%````,JX`
M``D````XK@``'@```$*N```A````8:X``!8```"#K@``#@```)JN```$````
MJ:X```D```"NK@``#````+BN```)````Q:X```0```#/K@``$````-2N```6
M````Y:X```4```#\K@``#0````*O```3````$*\```8````DKP``#P```"NO
M```'````.Z\``!D```!#KP``"@```%VO```'````:*\``!(```!PKP``#```
M`(.O```-````D*\``!P```">KP``!0```+NO```&````P:\``!T```#(KP``
M*````.:O```+````#[````,````;L```#````!^P```-````++```!,````Z
ML```"P```$ZP```7````6K```!D```!RL```!0```(RP```*````DK```!``
M``"=L```!@```*ZP```+````M;````D```#!L```#````,NP```&````V+``
M``T```#?L```&P```.VP```4````";$``!P````>L0``&P```#NQ```5````
M5[$``!H```!ML0``&````(BQ```?````H;$``!D```#!L0``!P```-NQ```(
M````X[$```T```#LL0``!0```/JQ```^`````+(``#4````_L@``5@```'6R
M```,````S+(```@```#9L@``"P```.*R```%````[K(``#,```#TL@``%P``
M`"BS```,````0+,``#````!-LP``!@```'ZS```0````A;,```@```"6LP``
M"````)^S```8````J+,```@```#!LP``"````,JS```.````T[,```<```#B
MLP``$0```.JS```A````_+,``!(````>M```"0```#&T```$````.[0``!D`
M``!`M```#P```%JT```/````:K0```X```!ZM```"0```(FT```4````D[0`
M``8```"HM```#````*^T```%````O+0```8```#"M```"@```,FT```@````
MU+0``"````#UM```%@```!:U```@````+;4``!D```!.M0``!0```&BU```4
M````;K4```<```"#M0``!0```(NU```'````D;4```H```"9M0``!0```*2U
M```&````JK4```8```"QM0``"P```+BU```(````Q+4```<```#-M0``#@``
M`-6U```+````Y+4```D```#PM0``)````/JU```@````'[8``!P```!`M@``
M'````%VV```C````>K8``"````">M@``,P```+^V``!'````\[8``"X````[
MMP``+````&JW```X````E[<``#,```#0MP``*@````2X```J````+[@``!8`
M``!:N```(0```'&X``!"````D[@``#@```#6N```!`````^Y```,````%+D`
M``4````AN0```@```">Y``!>````*KD```0```")N0``!````(ZY```'````
MD[D```4```";N0``!0```*&Y```1````I[D``!````"YN0``!P```,JY```&
M````TKD``!0```#9N0``#````.ZY```&````^[D```,````"N@``!`````:Z
M```&````"[H```<````2N@``&@```!JZ```I````-;H``",```!?N@``+0``
M`(.Z```-````L;H``!P```"_N@``#P```-RZ```#````[+H```@```#PN@``
M"0```/FZ```;`````[L```H````?NP``!P```"J[```'````,KL``!$````Z
MNP``%P```$R[```1````9+L``"8```!VNP``$@```)V[```3````L+L``!<`
M``#$NP``"@```-R[```'````Y[L```<```#ONP``"0```/>[```&`````;P`
M``<````(O```"````!"\```0````&;P```T````JO```&@```#B\```D````
M4[P```\```!XO```"P```(B\```#````E+P```H```"8O```!@```*.\```+
M````JKP```H```"VO```%0```,&\```6````U[P``!````#NO```,P```/^\
M```W````,[T``$\```!KO0``#@```+N]```-````RKT```(```#8O0``!```
M`-N]```&````X+T```4```#GO0```P```.V]```0````\;T``!`````"O@``
M)P```!.^```S````.[X``#(```!OO@``$0```**^```.````M+X``!````##
MO@``@0```-2^```*````5K\``%T```!AOP``7@```+^_```<````'L```!,`
M```[P```'````$_````@````;,```$````"-P```)@```,[````5````]<``
M``H````+P0``!````!;!```&````&\$```@````BP0``%````"O!```.````
M0,$```0```!/P0``#````%3!```&````8<$```8```!HP0``"````&_!```(
M````>,$```T```"!P0``!@```(_!```,````EL$```P```"CP0``#0```+#!
M```,````OL$``!````#+P0``"0```-S!```$````YL$```@```#KP0``"```
M`/3!```)````_<$```4````'P@```0```*H``````````````%@`````````
MO`$```````#:````"@```&@````T`P``G`(``!(````^`@``PP$``)4```"5
M`0```````$<!``!-`0````````````"R`@``P0(``!4```!#`@``R@$``,8`
M``!P````;P$``%T"```*`P``EP(```````"9``````````````!?````\0``
M`$8"````````,`$``&4!``#3`@```````,L!````````I0```)8```!<````
MA0(```T!``"V`@````````````!V````!`(```````"O````_`(```````"0
M````S0```'(!``#5`````````+L````"`@``N`(````````1`````````,P"
M``!T````=0(``(H````Z````X0$```4"``!>`````````#4````F`@``````
M`"<#``"F`@```@```"$#```#`P``Y````#8!````````=0`````````,`0``
MJ`$``*L```#:`@``MP(``%\!``"V````8`$``"`#```C`P``J0```/0!````
M````'`$```\"````````]0$``!T#``!@`@``B0```*\!````````0@$``!("
M```U`P``$`,``-\!````````T````$`!``!0`@``:@$```````#%````]P``
M`%8!`````````````%$`````````9@`````````J`P``&0,``)`"````````
M6@```/L````4`0``^@$``,$``````````````*4"```[`0```````.X```#[
M`@````````````"C`0``=P$`````````````Z@(``-@"````````Q@$``$\`
M``!Z`0```````%\"``!/`0````````````!O`@``10(``"@"``"?`@``P@$`
M`#@#````````90````T"`````````````#8```!7`@```````%(````Z`P``
M4P(```````!`````_@$``#$```"L`@``:P$``/\"````````80````````!9
M`0``*@(```````!D````!P$```````#[`0``*0$```````#I````-`(``/X"
M``"#`0``N`$````````B`P``/@```!<"``#+````W0(``'H"````````````
M`,<"``#=`0``"@(``,<`````````?`````P#``#C`@``P@(``.(`````````
M:@````````"E`0``M@$```````#<`0``*0,``#T"``".`````````$L"````
M````QP$```````"^`0``SP$``/4"``"A``````````````">`0``G@(``,D!
M``#6`````0$```````#+`@``-0(``,X"``!(````&P(``'$`````````````
M`"8!``"'`0``)0,````````M`@``H`(``*<!``````````````````!+`0``
MZ`$``$P````^`P```````$,!```%````OP```!H#``!.`0``````````````
M````8@(``+0```"8````%@(``#\"```_`0``F@(``+`!``!M`````````$T`
M``"$`0``:0(``!0```#)`@`````````````Y`0```````'\!``#Z````H@$`
M`'P!``#;````F0(`````````````=@$``'$"``#B`0``.P(``)D!````````
M'`(````````:`@``ZP$```````#S`@````````$"``"`````O0(``.L"``#S
M`0``UP(``!`"````````'0(``!$!``!%````[P(``*0````V`P``@@$``#("
M````````-P```&X"``!(`@``&P,``.X"```P````_`$```8!````````\```
M`#@`````````HP(``)T"``!8`0``1P```#D```#Q`@``+`(```````"[`@``
M*P```$$```````````````D"````````D@$``````````````````/,```#T
M`@``UP$``(T`````````:P(``"T```#W`0``&@$``/D"``!4`@``)P$``$(`
M``"+`@``$P$``%("``!]````[0(`````````````$0,```````",````````
M````````````'P``````````````]0````0```#=````2P```&P"````````
MXP$```````!P`@``+`,``(D"````````4P$``#X!````````^0````@"``!.
M````G`$```````!&`````````(L````7`P````````````#G`0```````'T"
M`````````````($```#(`@``O0``````````````N````"(```#G````8P$`
M```````\````M0(``,@!``""`@``L`(``#(```"@`0``D@(```````"Y`0``
M`````)T!``#>````&0(``"$`````````00,``+<```"Y`````````#$"``"8
M`0``,P````````"M`0``SP```'8"``!6`@``%@,```````"(`@``````````
M````````!@(```````![`@``1````%D"`````P``#P```"`"```N`@``````
M`&<```!:`@``-P$```T```!/`@``,@,``"\```!8`@``K@`````````C`@``
M/`$```````#;`@````````<````*`0``)`$``(8"``#E`````````&D!``!*
M````>P$``.$```"H````A@````````"Z````N@(``%P!```>`0``?@(`````
M``#)`````````-0!````````'@```-X!````````ZP```),```"A`@``(P``
M``````#1`0``T@`````````C`0```````(H"````````)0(``$`"``"4`@``
M"````$X"````````A0```$,```#$`0``V@$``'\````9````Y`$```0#``!,
M`0``$@$`````````````4`$``+P"````````UP````<#```S`0``DP(``#P#
M``#_`0``70````,!```9`0``HP```)H```#&`@```````%$!```T````)P``
M`"L"``"W`0``J@$``!H````E````A0$``!`!``!F`@``,@$``*0!```.`@``
M`````#T#````````1P(``)$`````````-P,``/("````````G@```/T!```.
M`0``+`$``$D```!Z````.P,``-P```"$`@````````````##````E`````0!
M````````*0```'D"``#L`0``B0$``+P```!O````&P``````````````\@$`
M```````+`@``*P$``(T"``",`@``N@$```````#D`@``#@```.`!``!E`@``
M"P$``)<!``#;`0``(````-4!````````M0$``/X```!J`@``?@$``"8```"5
M`@``:0```/<"``#J`0```````!(#``!Q`0````````D!``!M`@``P`$``'P"
M``"2````L@`````````7`0``.@$````````,`@``S@``````````````````
M`"T#````````K`$``*L!```+`````0,``#$!````````,`(``-`"``#Q`0``
M`````#@"``#Z`@``V0(``"@#``#X`@``U``````!``#*``````````````"M
M````Y0$``(<"```6````"`$``',`````````*@$````````&`P``[`(`````
M``"7````'`,``*``````````]@````````#O````;`$```\!````````)`,`
M`-@!````````Z0(``.```````````````````````````````!0#``!Y````
M`````-D```"(`0``\`$``+````!G`0``SP(``%T!```A`@````````````#`
M`@```````#,#```3`P``S@$``*<"``!G`@``-`$````````>`P``J0(``)$"
M````````'P,``'0!``!]`0``%0$```````#F````.`$``'<```"6`@``!0,`
M`%D```!U`0``T`$``-$`````````.@(``',!`````````````,P!````````
M7@$``&$"``!5`0``[0```.<"```G`@``L@$``&X```!1`@``,0,``+\"````
M````9`(``!T!``#F`0``1`(``)P```"^````C0$``%4``````@```````*T"
M``!!`@``Y@(``#4!```5`@``@0$``/T``````````````%4"````````````
M`.H```#C````=`(``-X"``!M`0``S0$``+,!``!*`@``0`,`````````````
M$0(``$P"``#!`0``+P(``````````````````!<````[````U0(``"D"```+
M`P``*`$``)T`````````X`(``,0```"#`@````````````!>`@``````````
M````````C@$```````"O`@``!0$``"L#`````````````.D!````````>`(`
M`.$"``!L````Z````(X"``!7````'@(``!\"``!@````6P(``%<!```J````
M<P(```````"!`@```````,4!``"T`@``DP$``'("``"6`0``'0```-("```8
M`@```````,T"``":`0``A@$```,`````````T0(``/8"`````````````"0`
M``"G````A`````````!R````:P````,"```A`0``>P````````!)`@``````
M`*(```"/`0``P````+,"``#(`````````$H!``!N`0``$P````\#````````
M4````)L!``"_`0``)0$``&@"```6`0``9@$``)$!```<````]@$``*X!``"?
M````FP````````#3`0``(@(``(L!```4`@``/0````(#`````````````#\#
M````````M`$``$8!```O`0``_0(``(P!``##`@``)@,``-,````8`0``6P``
M`)L"``"J`@``CP```*X"````````I`(``-\"```N``````````````!A`0``
MD`$``&,"````````&````-D!``#6`@``6P$``+,```"H`@``9`$``"`!````
M````@`$``-(!````````=P(```T#``#8````L0(``#T!``#H`@``7`(``"\#
M``"U````[0$``*$!````````X@(``````````````````+X"``!X`0``````
M``X#````````-@(``+$!`````````````((```!!`0```````/@```!Y`0``
MP@```&(```````````````````!4````O0$```````"B`@``\@```-\`````
M````[````#P"``!P`0``1`$``*P```"?`0``)`(```````!X`````````'X`
M``!B`0``Q0(```````#X`0``NP$`````````````$P(```````"8`@``6@$`
M`!\!```B`0``&P$````````Y`@````````````!6````"`,``%0!```L````
MI@$``!4#````````^0$``(,````_``````````````"Y`@``30(``$4!````
M`````````(`"``"/`@```````)0!``#<`@``_````"X#``#T````,P(``$D!
M``!H`0``Q`(``%,`````````4@$``(H!```0````?P(`````````````Y0(`
M``````!"`@``!@```-8!``"K`@```````#D#```N`0```````(@`````````
MR@(``/\````H````U`(``````````````````.X!```)````AP````<"````
M````8P```/`"```)`P``2`$```P```"I`0```````#<"``"Q`````````,P`
M```"`0``[P$``#`#`````````````!@#```M`0``I@`````@)B,Q-3$[("5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@
M)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T
M97)D87DI`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!W87,@
M861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D
M.B`E<RX`)60@)7,@86YD("5S`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T
M:6]N`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!A
M;')E861Y(&5X:7-T<RX`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N
M;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S
M)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S
M`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R
M-"!H;W5R<P`\4')E=FEO=7,`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S
M86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`
M06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!
M9&0`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N
M`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!
M9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`
M061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!
M9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R
M<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`
M06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA
M;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E>'0Z`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`
M06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%P
M<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!R;W9E`$%P<FEL
M`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F=E;G1I;F$`07)M
M96YI80!!<G5B80!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T<FEB=71E<P!!=6=U<W0`075S
M=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V
M92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A
M8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O
M<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A
M;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F5L87)U<P!"96QG:75M
M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R!3
M971T:6YG<P!";&]C:R!4>7!E`$)O;&EV:6$`0F]O:VUA<FMS`$)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$`0F]T:`!"<F%Z:6P`0G5L9V%R:6$`0TU3`$-20P!#
M7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;6)O9&EA`$-A;65R;V]N
M`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N
M`$-A<&4@5F5R9&4`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<')O<&5R=&EE<P!#96QL<&AO;F4`0V5L
M=&EC("A)4T\M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I
M;',`0V5R=&EF:6-A=&4@3W=N97(`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N
M86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H96-?:R!,:6YK+BXN`$-H
M96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SH`0VAR:7-T;6%S($ES;&%N9`!#;&EC:R!T;R!#;VYT:6YU90!#
M;&]S92!7:6YD;W<`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@
M4VED96)A<@!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E
M;&5C=&EO;@!#;VQU;6X@=&ET;&5S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#
M;VUM96YT`$-O;6]R;W,`0V]M<&%N>0!#;VUP;W-E($UE<W-A9V4@*"5S*0!#
M;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S
M=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S
M;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA
M;F1S`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S
M`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC
M(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@
M9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E
M;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D
M:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+@!#;W5N=')Y`$-R96%T90!#<F5A=&4@82!L:6YK`$-R
M96%T92!A(&YE=R!O;F4`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B
M80!#=7)R96YT(%1I;64`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+@!#=70`0WEP<G5S`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY
M`$1A=&4`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5F875L="!#;VQO<@!$
M969A=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P
M97)M:7-S:6]N<P!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S
M:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L
M971E(&-O;'5M;@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L
M971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`
M1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES
M<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&II8F]U=&D`
M1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<`!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`
M1&]W;FQO860@)7,`1')U9W,`12U-86EL`$5C=6%D;W(`161I=`!%9&ET($=R
M;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL($%D
M9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M;W1I8V]N<P!%
M;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5N86)L92!R:6=H="!C;&EC
M:R!C;VYT97AT(&UE;G4_`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R
M;W(`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P
M90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M<&%N9`!%>'!A;F0@4VED96)A<@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@
M8V]P>2!T;R`B)7,B+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O
M<CH`1F%X`$9E8G)U87)Y`$9I:FD`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&
M:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9O;V0`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9R86YC90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`
M1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1V%B;VX`1V%M8FEA
M`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=O`$=O;V=L92!396%R8V@`1W)E
M96-E`$=R965N;&%N9`!'<F5N861A`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`
M1W5A=&5M86QA`$=U97)N<V5Y`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N
M80!(5$U,`$AA:71I`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<P!(96QP`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S("(E<R(`2'5N9V%R>0!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@=VET
M:"!T97AT`$ED96YT:71Y)W,@;F%M93H`26UA9V5S`$EM<&]R=&5D(&9I96QD
M.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN9&EA`$EN9&]N97-I80!);F9O`$EN
M<V5R="!);6%G90!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI
M9"!L:6-E;G-E(&ME>2X`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q
M`$ER96QA;F0`27-R865L`$ES<W5E<@!)=&%L>0!*86UA:6-A`$IA;G5A<GD`
M2F%P86X`2F]R9&%N`$IU;'D`2G5N90!+87IA:VAS=&%N`$ME;GEA`$ME>2!#
M<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+
M97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI
M9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MU=V%I=`!+>7)G>7IS=&%N`$QA
M7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L
M:6,`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T
M(&QO9VEN.B!.979E<@!,871V:6$`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!
M<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:7-T($AE;'`@5&]P:6-S
M`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&AU86YI80!,;V%D:6YG
M+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]G(&EN`$QO9R!O
M=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R
M;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G
M:6X@9F%I;&5D+@!,;W<`3'5X96UB;W5R9P!-30!-3U1$`$U31P!-86-A;P!-
M86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D
M86=A<V-A<@!-86EL`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA
M;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N`$UA<F-H`$UA<F=I;@!-87)S:&%L;"!)<VQA
M;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U
M<FET:75S`$UA>0!-87EO='1E`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S
M<V%G90!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-97AI8V\`36EM92!4>7!E`$UO9&EF:65D($1A
M=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO
M;F%C;P!-;VYG;VQI80!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`
M36]R;V-C;P!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UY($%C8V]U;G0`37D@
M4&]R=&%L`$UY86YM87(`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE
M<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='=O<FL`3F5V97(`3F5W
M($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W(%IE86QA;F0`3F5W<P!.97AT
M`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:75E`$YO
M(&-H86YG92X`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R("5S+@!.;R!F:6QE('5P;&]A9&5D`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;VYE
M`$YO<F9O;&L@27-L86YD`$YO<G=A>0!.;W0@:6UP;&5M96YT960N`$YO="!S
M970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:6-E`$YO=F5M8F5R`$YU;6)E
M<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$]+`$]C=&]B97(`3V9F:6-E
M`$]M86X`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/<&5N(&EN
M(&$@;F5W('=I;F1O=P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9V%N:7-A
M=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W1H97(`3W1H
M97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4%](4"!3:&5L
M;`!086MI<W1A;@!086QA=0!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@
M9F]R`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`4&AO
M;F4`4&ET8V%I<FX`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&]L86YD`%!O
M<G1U9V%L`%!R979I97<`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E
M<V-R:7!T:6]N`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B
M;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R
M871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)3
M02!0=6)L:6,@2V5Y("@E9"!B:70I`%)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296UO=&4@4V5R=F5R<P!2
M96UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E('!A:7(`
M4F5M;W9E('1H90!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5S970`
M4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E
M='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T
M92!2:6=H=`!2;W<@<')O<&5R=&EE<P!2=7-S:6%N($9E9&5R871I;VX`4G=A
M;F1A`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%-13"!3:&5L;`!34T@`4U]13"!3:&5L
M;`!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,`4V%M;V$`4V%N($UA<FEN;P!3875D:2!!<F%B
M:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V5A<F-H
M`%-E;&5C="!&:6QE<P!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W
M86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F5G86P`
M4V5P=&5M8F5R`%-E<FEA;"!.=6UB97(`4V5T`%-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA
M>2!O<'1I;VYS+@!3971U<`!397EC:&5L;&5S`%-H;W)T(%-U;6UA<GD`4VAO
M=P!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-I97)R82!,96]N90!3:6=N('5P
M(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I
M=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`
M4VQO=F5N:6$`4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]U=&@@069R:6-A
M`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3<&%I;@!3<&%M`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P
M;&ET(')O=P!3<FD@3&%N:V$`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T
M<F5E="!!9&1R97-S`%-U8FIE8W0`4W5B;6ET`%-U8V-E<W,`4W5C8V5S<V9U
M;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E
M<R(`4W5D86X`4W5N<FES92]3=6YS970`4W5R:6YA;64`4W=A>FEL86YD`%-W
M961E;@!3=VET>F5R;&%N9`!3>7)I86X@07)A8B!297!U8FQI8P!486EW86X`
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!4
M97AT($]N;'D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ
M("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&9I96QD
M(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S
M970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&EM90!4:6UE(&9O
M<FUA=`!4:71L90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H
M:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N
M9V$`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U;FES:6$`
M5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=79A
M;'4`55),`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&-H86YG92!T
M;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5N:71E9"!!<F%B($5M:7)A
M=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YK;F]W;@!5;FYA
M;65D`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!L;V%D`%5R=6=U
M87D`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N86UE`%5S
M97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M
M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5F%C871I;VX`
M5F%N=6%T=0!696YE>G5E;&$`5F5R<VEO;@!6:65T($YA;0!6:65W("5S`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!786QL:7,@86YD
M($9U='5N80!787)N:6YG`%=E8@!7965K;'D`5V5L8V]M90!796QC;VUE('1O
M("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@
M*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.@!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!965E9`%EE
M87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"X`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@
M1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T
M($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L
M;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!;4')O8FQE;2!297!O<G1=`%]!9&UI;FES=')A=&EO;@!?
M0TQ)`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TQO9R!I;@!?3&]G(&]U
M=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO
M=F4@3&EN:RXN+@!?4V5T=7``7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A
M<@!F:6QE`&YA;64`;F]T97!A9`!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M
M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,2TR-"`R,#HU-BLP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,3$M,C0@
M,C$Z-#8K,#$P,`I,87-T+51R86YS;&%T;W(Z($MR>GES>G1O9B!+;WIL;W=S
M:VD@/&MO>FEK,4!O,BYP;#X*3&%N9W5A9V4M5&5A;3H@4&]L:7-H(#QP;$!L
M:2YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#@M8FET"@`E<R`M(&=O=&]W>2!D;R!W>6MO;F%N:6$@8WEK;&EC
M>FYY8V@@;W!E<F%C:FD@>F%Z;F%C>F]N>6-H('!O;FF_96HN`"`H)7,@9&YI
M('1E;74I`"AK;'5C>B!D;W-TZG!U("5S*0`@*'<@8VFQ9W4@)7,@9&YI*0`@
M*&1Z:;8I`"`H:G5T<F\I`"`H=V-Z;W)A:BD`(B5S(B!N:64@:F5S="!P<F%W
M:62S;W=Y;2!W>6)O<F5M+@`B)7,B(&YI92!J97-T('-K;VYF:6=U<F]W86YY
M('<@<F5J97-T<GIE($AO<F1E+@!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!G
M<G5P+@!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!U<')A=VYI9?$N`"(E<R(@
M;FEE('IO<W1ALR!U='=O<GIO;GDZ("5S+@`E9"`E<R!I("5S`"5S("T@57=A
M9V$`061M:6YI<W1R86-J82`E<P`E<R!O9&-I<VL@<&%L8V$`)7,@:T(`)7,@
M+2!O<&5R86-J92!C>6ML:6-Z;F4@+2!P;W1W:65R9'IE;FEE`$MO;F9I9W5R
M86-J82`E<P!296IE<W1R86-J82`E<P`E<R!J=;\@:7-T;FEE:F4N`"5S(&IE
M<W0@=WEM86=A;GD`)7,@;6EN=70`)7,@;FEE>FYA;&5Z:6]N>2X`)7,@9&\@
M)7,@>B`E<P!+<VFQOVMA(&%D<F5S;W=A("5S`$MA;&5N9&%R>B`E<P!.;W1A
M=&YI:R`E<P!,:7-T82!Z861A\2`E<P`E<SH@)7,`+2T@=WEB:65R>B`M+0`Q
M,BUG;V1Z:6YN>2!F;W)M870`,C0M9V]D>FEN;GD@9F]R;6%T`#(T(&=O9'HN
M`#Q0;W!R>F5D;FD`3F%S=+%P:;,@8K.Q9"!K<GET>6-Z;GD`4&]T<GIE8FYY
M(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!Z87-Z>69R;W=A;FEA('=I
M861O;6^V8VDN`%!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!01U`@
M9&\@<W!R87=D>F5N:6$@<&]D<&ES86YE:B!W:6%D;VUOMF-I+@!0;W1R>F5B
M;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%!'4"P@:VQU8WH@<')Y=V%T;GD@4$=0
M(&]R87H@:&%SLV\@9&\@;V1S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!0;W1R
M>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%!'4"P@:VQU8WH@<')Y=V%T;GD@
M4$=0(&]R87H@:&%SLV\@9&\@<&]D<&ES86YI82!W:6%D;VUOMF-I+@!0;W1R
M>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T
M;GD@4R]-24U%(&]R87H@:&%SLV\@9&\@;V1S>GEF<F]W86YI82!W:6%D;VUO
MMF-I+@!0;W1R>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU
M8WH@<')Y=V%T;GD@4R]-24U%(&]R87H@:&%SLV\@9&\@<&]D<&ES86YI82!W
M:6%D;VUOMF-I+@!0;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4TU)
M344@9&\@>F%S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!!32]030!/('1Y;2!E
M9'ET;W)Z90!/('!R;V=R86UI92XN+@!(87.S;R!D;R!K;VYT80!+;VYT;R!Z
M86)L;VMO=V%N92X`2V]N=&$`1&]D86H`1&]D86H@='5T86HZ`$1O9&%J(&YO
M=[$@9W)U<.H`1&]D86H@;F]W92!U<')A=VYI96YI90!$;V1A:B!N;W=E9V\@
M=;]Y=&MO=VYI:V$Z`$1O9&%J(&MO;'5M;NH`1&]D86H@;F]W>6-H(&-ZLV]N
M:_-W`$1O9&%J('!A<NH`1&]D86H@;65N=2`E<R!D;R!P87-K82!-;WII;&QI
M`$1O9&%J(&1O(&MS:;&_:VD@861R97-O=V5J.@!$;V1A:B!D;R!M;VIE:B!K
M<VFQ>FMI(&%D<F5S;W=E:@!$;V1A:B!UOWET:V]W;FEK80!$;V1A;F\@(B5S
M(B!D;R!S>7-T96UU+B!-;[]E<WH@<VGJ('IA;&]G;W=AYBX`1&]D87=A;FEE
M('6_>71K;W=N:6OS=R!J97-T('=YLV%C>F]N92X`061R97,`2W-IL;]K82!A
M9')E<V]W80!!9&UI;FES=')A8VIA`%)E:VQA;7D`069G86YI<W1A;@!!;&)A
M;FEA`$%L9VEE<FEA`$%L:6%S`%=S>GES=&MO`%=S>GES8WD@=7=I97)Z>71E
M;&YI96YI('6_>71K;W=N:6-Y`%=S>GES=&MI92!G<G5P>0!7<WIY<W1K:64@
M=7!R87=N:65N:6$`4&]Z=_-L(&YA('=I96QE(&%D<F5S\W<`2G6_(&ES=&YI
M96IE`$%L=&5R;F%T>7=N>2!L;V=I;B!)35-0`$%L=&5R;F%T>7=N>2!H87.S
M;R!)35-0`$%L=&5R;F%T>7=N82!N87IW82!UOWET:V]W;FEK82!)35-0`$%L
M=&5R;F%T>7=N>2!A9')E<R!E;6%I;`!!;'1E<FYA='EW;GD@=&5K<W0Z`%IO
M<W1ALV$@<&]D86YA(&YI97!R87=I9+-O=V$@=V%R=&^VYBX`06YD;W)A`$%N
M9V]L80!!;F=U:6QL80!!;F]N:6UO=V4@4')O>'D`3V1P;W=I962\`$%N=&%R
M:W1Y9&$`07!L:6MA8VIA`$%P;&EK86-J82!G;W1O=V$`6F%T=VEE<F2\`$MW
M:65C:67Q`%=I96QK;[;F(&%R8VAI=W5M`$YA>G=A(&%R8VAI=W5M`$%R9V5N
M='EN80!!<FUE;FEA`$%R=6)A`%!O<')OMB!O('!O='=I97)D>F5N:64@<')Z
M960@=WEK;VYA;FEE;2!O<&5R86-J:2!C>6ML:6-Z;GEC:#\`071R>6)U='D`
M4VEE<G!I9?$`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)U<SH@3FEE('IN
M86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@:6UA<"X`075T:%]C
M>7)U<SH@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@
M:6UA<"X`075T:%]F='`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z
M<WIE<GIE;FEA($944"X@4VMO;7!I;'5J(%!(4"!Z('!A<F%M971R96T@+2UE
M;F%B;&4@+@!!=71H7VEM87`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@
M<F]Z<WIE<GIE;FEA($E-05`N`$%U=&A?:W)B-3H@3FEE('IN86QE>FEO;F\@
M=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@:W)B-2X`075T:%]L9&%P.B!.:64@
M>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!,1$%0+@!!=71H
M7VQD87`Z($YI92!U9&&S;R!S:>H@=7-U;K'F('6_>71K;W=N:6MA("5S`$%U
M=&A?;&1A<#H@3FEE('5D8;-O('-IZB!U86MT=6%L;FGF('6_>71K;W=N:6MA
M("5S`$%U=&A?;6-A;#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS
M>F5R>F5N:6$@34-!3"X`075T:%]S;6)A=71H.B!.:64@>FYA;&5Z:6]N;R!W
M>6UA9V%N96=O(')O>G-Z97)Z96YI82!S;6)A=71H+@!5=VEE<GIY=&5L;FEE
M;FEE(&YI92!P;W=I;V2S;R!S:>H`57=I97)Z>71E;&YI96YI92!N:64@<&]W
M:6]DLV\@<VGJ+B`E<P!5=VEE<GIY=&5L;FEE;FEE(&]D<GIU8V]N92!P<GIE
M>B!S97)W97(@4D%$2553+@!5=VEE<GIY=&5L;FEE;FEE(&1O('-E<G=E<F$@
M1E10(&YI92!P;W=I;V2S;R!S:>HN`$1O<W3J<&YE('!O;&$Z`$%Z97)B96ID
MOV%N`%=Y;?-W:VD@0D]&2`!4LV\`2V]L;W(@=+-A`%JS92!H87.S;R!+97)B
M97)O<V$N`%JS82!N87IW82!UOWET:V]W;FEK82!+97)B97)O<V$`5WES<'D@
M0F%H86UA`$)A:')A:FX`0F&S='EC:VD@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-Z`$)I8;-O<G6V`$)E;&=I80!"96QI>F4`0F5N:6X`0F5R;75D>0!":'5T
M86X`1&%T82!U<F]D>F5N:6$`57-T87=I96YI82!B;&]K=0!4>7`@8FQO:W4`
M0F]L:7=I80!:86NS861K:0!";[9N:6$@:2!(97)C96=O=VEN80!/8F$`0G)A
M>GEL:6$`0G6S9V%R:6$`0TU3`$-20P!7LV&V8VEW;[9C:2!K;VWS<FMI+BXN
M("A?8RD`2V%L96YD87)Z`$MA;6)O9+]A`$MA;65R=6X`3FEE('5D8;-O('-I
MZB!Z<F5S971O=V'F(&AA<[-A(&%U=&]M871Y8WIN:64L('-K;VYT86MT=6H@
M<VGJ('H@861M:6YI<W1R871O<F5M+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@
M<VGJ('H@<V5R=V5R96T@24U!4#H@)7,`2V%N861A`$%N=6QU:@!!;G5L=6H@
M<F%P;W)T(&\@<')O8FQE;6EE`$YI92!M;[]N82!S:V%S;W=AYB!P;&EK=2`B
M)7,B`$YI92!U9&&S;R!S:>H@>FYA;&6\YB!K871A;&]G=2!T>6UC>F%S;W=E
M9V\N`$YI92!M;[]N82!S:V%S;W=AYB!K871A;&]G=2`B)7,B`%=Y<W!Y(%II
M96QO;F5G;R!0<GIY;+%D:V$`2V%T96=O<FEE(&D@;WIN86-Z96YI80!496PN
M(&MO;2X`5[-AMF-I=V^V8VD@:V]M\W)K:0!7LV&V8VEW;[9C:2!K;VWS<FMI
M`%1E;"X@:V]M+@!#96QT>6-K:2`H25-/+3@X-3DM,30I`%)E<'5B;&EK82"F
M<F]D:V]W96H@069R>6MI`*9R;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM
M,BD`4WIC>F5G\[-Y(&-E<G1Y9FEK871U`%>S8;9C:6-I96P@8V5R='EF:6MA
M='4`0WIA9`!:;6EE\0!:;6EE\2!I;6GJ+"!N87IW:7-K;R!I(&%D<F5S+"!K
M=/-R>2!I;FYI('=I9'JQ('<@5'=O:6-H(&QI<W1A8V@@96UA:6PN`%-P<F%W
M9+P@;&EN:RXN+@!:87IN86-Z('!O>GEC:NH@9&QA(&MT\W)E:B!C:&-E<WH@
M=WEK;VYAYB!O<&5R86-JZBX`0VAI;&4`0VAI;GD`4&]D86H@:&%SLV\`4&]D
M86H@;F%Z=^H@=;]Y=&MO=VYI:V$`5WEB:65R>B!S<&]S\V(@=WFV=VEE=&QA
M;FEA(&1A=#H`5WES<&$@0F^_96=O($YA<F]D>F5N:6$`2VQI:VYI:B!B>2!K
M;VYT>6YU;W=AY@!:86UK;FEJ(&]K;F\`5WES<'D@2V]K;W-O=V4@*$ME96QI
M;F=A*0!38VAO=V%J('!A<V5K`$MO;'5M8FEA`$MO;&]R`%=Y8FEE<GH@:V]L
M;W(`5WEB\W(@:V]L;W)U`%1Y='6S>2!K;VQU;6X`2V]M96YD80!0;W>S;VMA
M`$MO;65N=&%R>@!+;VUO<GD`1FER;6$`4W1W\W)Z('=I861O;6^VYB`H)7,I
M`$MO;7!U=&5R>0!787)U;FMI`%-K;VYF:6=U<G5J("5S`%!O='=I97)DO"!H
M87.S;P!+;VYG;P!$96UO:W)A='EC>FYA(%)E<'5B;&EK82!+;VYG;P!0;[.Q
M8WIE;FEE(&YI92!P;W=I;V2S;R!S:>HN`%!OL[%C>F5N:64@;FEE('!O=VEO
M9+-O('-IZCH@`$]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O
M('-E<G=E<F$N`$]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O
M('-E<G=E<F$N(%!O=_-D.B`E<R`H)7,I`$*SL60@<&]D8WIA<R"SL6-Z96YI
M82!S:>H@>B!S97)W97)E;2!&5%`N`$MO;G1A:W1Y('IO<W1ALWD@<&]M>;9L
M;FEE(&1O9&%N92!D;R!4=V]J96H@:W-IL;]K:2!A9')E<V]W96HN`%IA=V%R
M=&^VYB`B)7,B`$MO;GEN=75J`%=Y<W!Y($-O;VMA`%-K;W!I=6H`4VMO<&EU
M:B!W>6+S<@!.:64@=61ALV\@<VGJ('IA<WIY9G)O=V'F("A01U`I('=I861O
M;6^V8VDN`$YI92!U9&&S;R!S:>H@<&]D<&ES8>8@*%!'4"D@=VEA9&]M;[9C
M:2X`3FEE('5D8;-O('-IZB!Z87-Z>69R;W=AYB`H4R]-24U%*2!W:6%D;VUO
MMF-I+@!.:64@=61ALV\@<VGJ('!O9'!I<V'F("A3+TU)344I('=I861O;6^V
M8VDN`$*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!,1$%0
M+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@(B5S(B!P
M;W!R>F5Z($944#H@)7,`3FEE('5D8;-O('-IZB!O9'-Z>69R;W=AYB!D86YY
M8V@@4$=0+@!.:64@=61ALV\@<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!3+TU)
M344N`$YI92!U9&&S;R!S:>H@=7-T86QIYB!A9')E<W4@92UM86EL(&]D8FEO
M<F-Y+@!.:64@=61ALV\@<VGJ('5Z>7-K8>8@>B!S97)W97)A(&ML=6-Z82!P
M8G5L:6-Z;F5G;RX`3FEE('5D8;-O('-IZB!O='=O<GIYYB`B)7,B(&1O('IA
M<&ES=2X`3FEE(&UOOVYA(&]T=V]R>GGF("5S+@!.:64@;6^_;F$@;W1W;W)Z
M>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,`3FEE(&UOOVYA(&]T=V]R
M>GGF(&MA=&%L;V=U("(E<R(`3FEE('5D8;-O('-IZB!S:V%S;W=AYB!P;&EK
M=2`B)7,B+@!.:64@=61ALV\@<VGJ('IN86QEO.8@<&%S:V$@36]Z:6QL:2X@
M57!E=VYI:B!S:>HL(+]E(&IE<W0@;VX@;W1W87)T>2X`2W)A:@!3='?S<GH`
M4W1W\W)Z(&QI;FL`4W1W\W)Z(&YO=[$`3G5M97(@:V%R='D@:W)E9'ET;W=E
M:@!#:&]R=V%C:F$`2W5B80!/8F5C;GD@8WIA<P!3<&5R<V]N86QI>G5J('IA
M9&%N:6$@=7)U8VAA;6EA;F4@<')Z>2!L;V=O=V%N:74@9&\@)7,N`%=Y=&YI
M:@!#>7!R`%)E<'5B;&EK82!#>F5C:`!$1`!#;V1Z:65N;FEE`$1A=&$`7U5S
M=?$@:V]L=6UNZ@!'<G5D>FEE\0!$;VUYMFQN>2!K;VQO<@!$;VUYMFQN82!T
M;[]S86UOMN8`1&]M>;9L;F4@=7!R87=N:65N:6$`1&]M>;9L;F4@=7!R87=N
M:65N:6$`57-U\0!5<W7Q($=R=7#J`%5S=?$@=7!R87=N:65N:6$`57-U\2!I
M('=Y8WIYMN8@=VEA9&]M;[9C:0!5<W7Q(&MO;?-R:^H`57-U\2!K;VQU;6[J
M`%-K87-U:B!U<')A=VYI96YI82!D;&$@(B5S(@!3:V%S;W=AYB!U<')A=VYI
M96YI82!D;&$@(B5S(B!I('=S>GES=&MI92!P;V0M=7!R87=N:65N:6$_`%5S
M=?$@=VEE<G-Z`%-K87-U:B!W>6)R86ZQ('1OOW-A;6^VY@!5<W7Q(&%K='5A
M;&ZQ(&MO;'5M;NH`57-U\2!A:W1U86QN>2!W:65R<WH`4VMA<V]W8>8@=&\@
M=7!R87=N:65N:64@:2!W<WIY<W1K:64@<&]D+75P<F%W;FEE;FEA/P!$86YI
M80!/<&ES>B!P<F]B;&5M`%-Z8WIE9_.S>2!Z;W-T8;-Y('IA;&]G;W=A;F4@
M9&QA(&%D;6EN:7-T<F%T;W)A+@!+871A;&]G`%=YMG=I971L(&-Z87,@=R!F
M;W)M86-I92`R-"UG;V1Z:6YN>6T_`%5S=&%W:65N:6$@=WEG;+%D=0!$OVEB
M=71I`$YI92!K87-U:@!"<F%K(&)E>G!OMG)E9&YI96=O(&1O<W3J<'4@9&\@
M;6%I;G1E;F%N8V4N<&AP`$1O;6EN:6MA("A7<W#S;&YO=&$@1&]M:6YI:VDI
M`$1O;6EN:6MA;F$@*%)E<'5B;&EK82!$;VUI;FEK8?%S:V$I`*9C:;%G;FEJ
M`*9C:;%G;FEJ("5S`$YA<FMO='EK:0!%+6UA:6P`16MW861O<@!%9'EC:F$`
M57-U\2!'<G5PZ@!:;6EE\2!U<')A=VYI96YI90!:;6EE\2!U<')A=VYI96YI
M80!:;6EE\2!U<')A=VYI96YI82!D;&$@)7,`6FUI9?$@=7-T87=I96YI82!D
M;&$Z`%IM:67Q('5P<F%W;FEE;FEA(&1L82`E<P!%9VEP=`!386QW861O<@!%
M;6%I;`!!9')E<R!E;6%I;`!!9')E<WD@96UA:6P@;75S>K$@9&\@<VEE8FEE
M('!A<V]W8>8N`$5M;W1I:V]N>0!0=7-T82!W:6%D;VUOMN8N`$)R86L@<F5Z
M=6QT873S=RX`5[.Q8WIYYB!M96YU(&MO;G1E:W-T;W=E('!O9"!P<F%W>6T@
M<')Z>6-I<VMI96T@;7ES>GD_`$=W:6YE82!2\W=N:6MO=V$`17)Y=')E80!"
ML[%D`$*SL60@<')Z>2!Z87!I<VEE("(E<R(N`$5S=&]N:6$`171I;W!I80!%
M=7)O<&$`0V\@:V&_9&4@,34@;6EN=70`0V\@:V&_9&4@,B!M:6YU='D`0V\@
M:V&_9&4@,S`@<V5K=6YD`$-O(&MAOV1E(#4@;6EN=70`0V\@:V&_9&4@>F%L
M;V=O=V%N:64`0V\@:V&_9&4@</.S(&=O9'II;GD`0V\@:V&_9+$@;6EN=73J
M`%!R>GEKLV%D;W=E('=A<G1OMF-I.@!7>6MO;F%J`%)O>G=I\0!2;WIW:?$@
M<&%S96L`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$
M05`N`$*SL60@<&]D8WIA<R!K;W!I;W=A;FEA('H@(B5S(BX`0K.Q9"!P;V1C
M>F%S(&MO<&EO=V%N:6$@9&\@(B5S(BX`0K.Q9"!P;V1C>F%S('!R>F5N;W-Z
M96YI82!D;R`B)7,B+@!&86QK;&%N9'D@*$UA;'=I;GDI`%=Y<W!Y($]W8WIE
M`$*SL60@:W)Y='EC>FYY.B``1F%K<P!,=71Y`$9I9+]I`$UE;F5DOV5R('!L
M:6OS=P!.87IW82!P;&EK=0!7>6+S<B!P;&EK=0!79W)Y=V%N:64@<&QI:W4`
M5V=R>7=A;FEE('!L:6OS=R!N:64@:F5S="!O8G.S=6=I=V%N92X`1FEL=')Y
M`$9I;FQA;F1I80!*961Z96YI90!:87!O;6YI8;-EMB!H87.S83\`1G)A;F-J
M80!'=6IA;F$@1G)A;F-U<VMA`%!O;&EN97IJ82!&<F%N8W5S:V$`1G)A;F-U
M<VMI92!497)Y=&]R:6$@4&^S=61N:6]W92!I($%N=&%R:W1Y8WIN90!/9`!'
M86)O;@!'86UB:6$`3FEE;6-Y`$=H86YA`$=I8G)A;'1A<@!)9+P`5WES>G5K
M:7=A<FMA($=O;V=L90!'<F5C:F$`1W)E;FQA;F1I80!'<F5N861A`$=R=7!Y
M(&1Y<VMU<WEJ;F4`1W=A9&5L=7!A`$=U86T`1W=A=&5M86QA`$=U97)N<V5Y
M`$=W:6YE80!'=VEN96$@0FES<V%U`$=U:F%N80!(5$U,`$AA:71I`%=Y<W!Y
M($AE87)D(&D@36-$;VYA;&1A`%!O;6]C`%=Y<V]K:0!?4W1A<G0`5V%T>6MA
M;B`H4W1O;&EC82!!<&]S=&]L<VMA*0!0;V-ZL71E:P!!9')E<R!D;VUO=WD`
M5&5L+B!D;VTN`$AO;F1U<F%S`$AO;F=+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!59&&S;R!S:>H@=7-U;K'F("5S("(E<R(`5^IG<GD`27-L86YD:6$`5'EL
M:V\@:6MO;GD`26MO;GD@>B!T96MS=&5M`$YA>G=A('1OOW-A;6^V8VDZ`$=R
M869I:V$`26UP;W)T;W=A;F4@<&]L93H@)7,`26UP;W)T;W=A;F4@<&]L83H`
M26YD:64`26YD;VYE>FIA`$EN9F\`5VML96H@;V)R87IE:P!7>7.S86YE(&YI
M97!R87=I9+-O=V4@9&%N92X`3FEE<')A=VEDLV]W>2!A9')E<R!D;V-E;&]W
M>2X`3FEE<')A=VEDLV]W>2!F;W)M870@<&QI:W4`3FEE<')A=VEDLV]W>2!K
M;'5C>B!L:6-E;F-J:2X`27)A;@!)<F%K`$ER;&%N9&EA`$EZ<F%E;`!7>61A
M=V-A`%>S;V-H>0!*86UA:FMA`%-T>6-Z9?$`2F%P;VYI80!*;W)D86X`3&EP
M:65C`$-Z97)W:65C`$MA>F%C:'-T86X`2V5N:6$`5'=O<GIE;FEE(&ML=6-Z
M80!/9&-I<VL@:VQU8WIA`$2S=6=OMN8@:VQU8WIA`%1Y<"!K;'5C>F$`2VQU
M8WH@:G6_(&ES=&YI96IE(&YA('!U8FQI8WIN>6T@<V5R=V5R>F4@:VQU8WIY
M+@!$>FEE8VD`2VER:6)A=&D`2V]R96'Q<VMA(%)E<'5B;&EK82!,=61O=V\M
M1&5M;VMR871Y8WIN80!297!U8FQI:V$@2V]R96D`2W5W96IT`$MI<F=I<W1A
M;@!7>6=LL60@*%]Y*0!*ZGIY:P!,86]S`$]S=&%T;FEE(&QO9V]W86YI93H@
M)7,`3W-T871N:64@;&]G;W=A;FEE.B`E<R!Z("5S`$]S=&%T;FEE(&QO9V]W
M86YI93H@;FEG9'D`HV]T=V$`3&5S;W1H;P!,:6)E<FEA`$QI8FEA`$QI96-H
M=&5N<W1E:6X`5WFV=VEE=&P@=&5M871Y('!O;6]C>0!,:7-T;W=A;FEE('6_
M>71K;W=N:6OS=R!J97-T('=YL[%C>F]N92X`3&ET=V$`HV%D;W=A;FEE+BXN
M`$-Z87,@;&]K86QN>3H@`%5S=&%W:65N:6$@;&]K86QN92!I(&-Z87,`6F%L
M;V=U:@!7>6QO9W5J`%IA9&%N:6$@<')Z>2!L;V=O=V%N:74`3&]G;W=A;FEE
M(&YI92!P;W=I;V2S;R!S:>HL('!O;FEE=V&_('!O9&&S9;8@;FEE<')A=VED
MLV]W92!H87.S;R!L=6(@;F%Z=^H@=;]Y=&MO=VYI:V$N`$QO9V]W86YI92!N
M:64@<&]W:6]DLV\@<VGJ+@!.:7-K:0!,=6MS96UB=7)G`$U-`$U/5$0`35-'
M`$UA:V%U`$UA8V5D;VYI80!-861A9V%S:V%R`%!O8WIT80!-86QA=VD`36%L
M97IJ80!-86QE9&EW>0!-86QI`$UA;'1A`%IA<GJQ9'IA:B!L:7-TL2!K871E
M9V]R:6DL(&MT\W)Y;6D@8NID>FEE<WH@;WIN86-Z8;,@<&]Z>6-J92P@:2!K
M;VQO<F%M:2!Z(&YI;6D@>G=IL7IA;GEM:2X`36%R>F5C`$UA<F=I;F5S`%=Y
M<W!Y($UA<G-H86QL80!-87)T>6YI:V$`4&%S=6JQ8V4@<&]L80!-875R971A
M;FEA`$UA=7)I=&EU<P!-86H`36%J;W1T80!4<GEB(&UE;G4Z`%!OL[%C>B!K
M;VWS<FMI`%=I861O;6^VY@!";&]K(")-971A<B(@;FEE(&IE<W0@9&]S=.IP
M;GDN`$)L;VL@(DUE=&%R(B!N:64@:F5S="!D;W-TZG!N>2X@4WIC>F5G\[-Y
M('ID87)Z96YI82!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D;6EN:7-T<F%T
M;W)A+@!-96MS>6L`5'EP($UI;64`3W-T871N:6$@;6]D>69I:V%C:F$`6FUI
M9?$@;&EN:P!-;[-D87=I80!297!U8FQI:V$@36^S9&%W:6D`36]N86MO`$UO
M;F=O;&EA`$-O(&UI97-IL6,`36]N='-E<G)A=`!&87IY(&MS:>J_>6-A`$UA
M<F]K;P!0<GIE<W7Q('<@9/.S`%!R>F5S=?$@=R!L97=O`%!R>F5S=?$@=R!P
M<F%W;P!0<GIE<W7Q('<@9_-RZ@!0<GIE;FEEMB!W(&3SLP!0<GIE<W7Q('<@
M9_-RZ@!-;WIA;6)I:P!+;VYT;P!-\VH@<&]R=&%L`$)I<FUA`$YA>G=I<VMO
M`$YA;6EB:6$`3F%U<G4`3F5P86P`2&]L86YD:6$`06YT>6QE($AO;&5N9&5R
M<VMI90!3:67F`$YI9V1Y`$YO=V$@2V%L961O;FEA`$YO=V$@:V%T96=O<FEA
M`$YO=V$@6F5L86YD:6$`5VEA9&]M;[9C:0!.87-TZG!N90!.87-TZG!N92!O
M<&-J90!.:6MA<F%G=6$`3FEG97(`3FEG97)I80!.:75E`$)E>B!Z;6EA;BX`
M0G)A:R!K;VYF:6=U<F%C:FD@9&QA("5S+@!.:64@=V=R86YO('!L:6MU`$YI
M92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@2%144"X`3FEE
M('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!)34%0+@!.:64@
M<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($ME<F)E<F]S+@!.
M:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($Q$05`N`$YI
M92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@3$]'24XN`$YI
M92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@4$%34U=$+@!.
M:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA(%--0BX`KV%D
M;F$`3F]R9F]L:P!.;W)W96=I80!.:64@>F%I;7!L96UE;G1O=V%N;RX`3FEE
M=7-T87=I;VYE`$YI96]B<[-U9VEW86YE`%5W86=I`%5W86=A`$QI<W1O<&%D
M`$QI8WIB82!K;VQU;6X`3&EC>F)A('=I97)S>GD`3TL`4&&\9'II97)N:6L`
M0FEU<F\`3VUA;@!4=_-J(&IE9&5N(&%D<F5S(&4M;6%I;"!J97-T(&1O>G=O
M;&]N>2X`3W1W\W)Z('<@;F]W>6T@;VMN:64`3W!C:F4`3W!C:F4@)7,`3W)G
M86YI>F%C:F$`2F5D;F]S=&MA(&]R9V%N:7IA8WEJ;F$`3W)G86YI>F%T;W(`
M26YN90!);FYE(&EN9F]R;6%C:F4`26YN92!U<')A=VYI96YI80!5=VEE<GIY
M=&5L;FEE;FEE(%!!32!N:64@:F5S="!D;W-TZG!N92X`0WEF<F]W>2!P;V1P
M:7,@4$=0`%=I861O;6^VYB!Z87-Z>69R;W=A;F$@4$=0`$ML=6-Z('!U8FQI
M8WIN>2!01U``5VEA9&]M;[;F('IA<WIY9G)O=V%N82]P;V1P:7-A;F$@:VQU
M8WIE;2!01U``2V]D(%!(4`!0;W>S;VMA(%!(4`!0;W>S;VMA(%!?2%``4&%K
M:7-T86X`4&%L874`4&%N86UA`%!A<'5A+4YO=V$@1W=I;F5A`%!A<F%G=V%J
M`$AA<[-O`$AA<[-O(&YI97!R87=I9+-O=V4`2&%SLV\@>B!P;W1W:65R9'IE
M;FEE;0!(87.S;SH`2&%SLV\Z(`!(87.S;R!M=7-I('!A<V]W8>8N`%=K;&5J
M`%=K;&5J('IE('-C:&]W:V$`5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4`
M5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4@<&]D8WIA<R!L;V=O=V%N:6$_
M`%5P<F%W;FEE;FEE`%5P<F%W;FEE;FEA(&1L80!);F9O<FUA8VIE(&]S;V)I
M<W1E`%!E<G4`1FEL:7!I;GD`5&5L969O;@!0:71C86ER;@!.82!P97=N;R!U
M<W5NL>8@=&5N('=Y8G)A;GD@96QE;65N=#H`3F$@<&5W;F\@=7-U;K'F('=Y
M8G)A;GD@96QE;65N=#H`4')O<WKJ('!O9&'F('!O<')A=VYY(&%D<F5S($E0
M+@!0<F]S>NH@<&]D8>8@<&]P<F%W;GD@8WIA<RX`4')O<WKJ(&]P:7-AYB!P
M<F]B;&5M+@!0<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S
M;P!0;VQS:V$`4&]R='5G86QI80!0;V1G;+%D`$ML=6-Z('!R>7=A=&YY`%!R
M;V)L96T`3W!I<R!P<F]B;&5M=0!+;'5C>B!P=6)L:6-Z;GD`06QG;W)Y=&T@
M:VQU8WIA('!U8FQI8WIN96=O`$EN9F]R;6%C:F4@;R!K;'5C>G4@<'5B;&EC
M>FYY;0!087)A(&ML=6-Z>2!O<V]B:7-T>6-H(&YI92!Z;W-T8;-A('=Y9V5N
M97)O=V%N82!P;VUYMFQN:64N`%!O<G1O<GEK;P!+871A<@!:87!Y=&%N:64`
M2VQU8WH@<'5B;&EC>FYY(%)302`H)60@8FET\W<I`$]DMG=I9;\@9'EN86UI
M8WIN92!E;&5M96YT>2!M96YU.@!/9+9W:66_('=I9&]K('-E<G=I<W4Z`%ID
M86QN92!S97)W97)Y`%5S=?$`57-U\2!B;&]K`%5S=?$@:V]L=6UNZ@!5<W7Q
M('!A<NH`57-U\0!5<W7Q('6_>71K;W=N:6MA`%ID86QN92!UOWET:V]W;FEK
M83H@)7,`2V%S=6H`5WEC>GFVYB!H87.S;P!7>6-Z>;;F(%1W;VIE(&AA<[-O
M`%=Y;FEK:0!0;W=R\W0@9&\@;W!C:FD`4F5U;FEO;@!2;WIB=61O=V%N>2!E
M9'ET;W(@=&5K<W1U`%-T86YO=VES:V\`4G5M=6YI80!/8G+SYB!O(#$X,"!S
M=&]P;FD`3V)R\^8@=R!L97=O`$]B<O/F('<@<')A=V\`5[-AMF-I=V^V8VD@
M<GKJ9'4@4')O<&5R=&EE<P!2;W-J80!2=6%N9&$`5VEA9&]M;[;F('IA<WIY
M9G)O=V%N82!3+TU)344`57=I97)Z>71E;&YI96YI92!305-,(&YI92!J97-T
M(&1O<W3J<&YE+@!0;W=L;VMA(%-13`!34T@`4&]WLV]K82!37U%,`*9W:>IT
M82!(96QE;F$`4V%I;G0@2VET=',@:2!.979I<P!386EN="!,=6-I80!386EN
M="U0:65R<F4@:2!-:7%U96QO;@!386EN="!6:6YC96YT(&D@1W)E;F%D>6YY
M`%-A;6]A`%-A;B!-87)I;F\`07)A8FEA(%-A=61Y:G-K80!:87!I<WH`6F%P
M:7-Z("(E<R(`6F%P:7-Z("5S`%IA<&ES>B!O<&-J90!3>G5K86H`5WEB:65R
M>B!P;&EK:0!7>6)I97)Z('IN86L@<&]D>FEALW4@9&%T>3H`5WEB:65R>B!F
M;W)M870@9&%T>3H`5WEB:65R>B!T;[]S86UOMN8@9&\@>FUI86YY.@!7>6)I
M97)Z('IN86L@<&]D>FEALW4@9&%T>3H`5WEB:65R>B!F;W)M870@8WIA<W4Z
M`%=Y8FEE<GH@9'=A('!A<W5JL6-E('!O;&$N`%=Y8FEE<GH@<V-H96UA="!K
M;VQO<O-W+@!7>6)I97)Z('1W\VH@<')E9F5R;W=A;GD@:NIZ>6LZ`%=YMFQI
M:B!R87!O<G0@;R!P<F]B;&5M:64`4V5N96=A;`!7<GIE<VEE\0!.=6UE<B!S
M97)Y:FYY`%5S=&%W`%5S=&%W('ID86QN92!S97)W97)Y+"!D;R!K=/-R>6-H
M(&-H8V5S>B!M:67F(&1O<W3J<"!Z('-E<G=I<W4N`%5S=&%W('!R969E<F]W
M86YY(&KJ>GEK+"!S=')E9NH@8WIA<V]WL2!I(&]P8VIE(&1A='DN`%5S=&%W
M('5SLW5GZB!P;V-ZL71K;W>Q+"!S8VAE;6%T(&MO;&]R\W<L(&]DMG=I9;]A
M;FEE('-T<F]N>2!I(&EN;F4@;W!C:F4@=WFV=VEE=&QA;FEA`$MO;F9I9W5R
M86-J80!3>F5S>F5L90!+<O-T:VD@;W!I<P!0;VMAOP!0;VMA>GEW8>8@8WIA
M<R!O<W1A=&YI96=O('IA;&]G;W=A;FEA('!O(&QO9V]W86YI=3\`4&]K8;\@
M;65N=2`E<R!P;R!L97=E:C\`4VEE<G)A($QE;VYE`%IA<F5J97-T<G5J('-I
MZBP@:F6V;&D@:F5S>F-Z92!T96=O(&YI92!Z<F]B:;-EM@!0;V1P:7,`06QG
M;W)Y=&T@<&]D<&ES=0!3:6YG87!U<@!7:65L:V^VY@!0;VUI\2!O<&5R86-J
M92!C>6ML:6-Z;F4`4[-O=V%C:F$`4[-O=V5N:6$`5WES<'D@4V%L;VUO;F$`
M4V]M86QI80!0;[-U9&YI;W=A($%F<GEK80!0;[-U9&YI;W=O975R;W!E:G-K
M:2`H25-/+3@X-3DM,RD`1V5O<F=I82!0;[-U9&YI;W=A`$AI<WIP86YI80!3
M<&%M`$5D>6-J82!Z;F%K\W<@<W!E8VIA;&YY8V@`4&]D>FEE;"!K;VWS<FOJ
M`%!O9'II96P@:V]L=6UNZ@!0;V1Z:65L('=I97)S>@!3<FD@3&%N:V$`5V]J
M97?S9+QT=V\@;'5B('-T86X`4W1A='5S`$%D<F5S(&1O;6]W>0!496UA=`!7
M>;9L:6H`4&]W;V1Z96YI90!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!S>7-T
M96UU+@!59&&S;R!S:>H@=7-U;K'F("(E<R(@>B!S>7-T96UU+@!59&&S;R!S
M:>H@=7-U;K'F("(E<R(N`%5D8;-O('-IZB!U<W5NL>8@(B5S(B!Z('-Y<W1E
M;74N`%5D8;-O('-IZB!U86MT=6%L;FGF("(E<R(`4W5D86X`5W-C:/-D+WIA
M8VCS9"!SLV_Q8V$`4W5R:6YA;0!3=6%Z:0!3>G=E8VIA`%-Z=V%J8V%R:6$`
M4WER:6$`5&%J=V%N`%1A:G=A;@!4862_>6MI<W1A;@!486YZ86YI80!:861A
M;FEA`$YU;65R('1E;&5F;VYU`%1Y;&MO('1E:W-T`%1A:FQA;F1I80!$>FGJ
M:W5J96UY('IA(&MO<GIY<W1A;FEE('H@<V5R=VES=2X`5&^_<V%M;[;F("(E
M<R(@>F]S=&&S82!U<W5N:>IT82X`4V5R=V5R("(E<R(@>F]S=&&S('5S=6YI
MZG1Y+@!397)W97(@(B5S(B!Z;W-T8;,@>F%P:7-A;GDN`$)L;VL@=V5A=&AE
M<BYC;VT@;FEE(&IE<W0@9&]S=.IP;GDN`$YI92!M82"_861N>6-H(&1O<W3J
M<&YY8V@@;W!C:FDN`%=Y<W2Q<&FS('!R;V)L96T@<')Z>2!D;V1A=V%N:74@
M(B5S(B!D;R!S>7-T96UU.B`E<P!7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U
M=V%N:74@9&%N>6-H(&1L82!UOWET:V]W;FEK82`B)7,B('<@<WES=&5M:64Z
M(`!7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@(B5S(B!Z('-Y<W1E
M;74N`%=Y<W2Q<&FS('!R;V)L96T@<')Z>2!U86MT=6%L;FEA;FEU("(E<R(Z
M("5S`%=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!W>;9W:65T;&%N:6$@=&5J(&-Z
MZK9C:2!W:6%D;VUOMF-I`%=Y<W2Q<&FS(&*SL60@<&]C>F%S(&EM<&]R=&]W
M86YI82!D86YY8V@@:4-A;&5N9&%R+@!0;&EK(&YI92!W>6=LL61A(&YA('!O
M<')A=VYE(&%R8VAI=W5M(%)!4BX`4&QI:R!N:64@=WEG;+%D82!N82!P;W!R
M87=N92!A<F-H:7=U;2!:25`N`%1O('!O;&4@:F5S="!W>6UA9V%N92X`5&\@
M<&]L92!M=7-I(&)YYB!P;W!R87=NL2!L:6-Z8K$N`%=I861O;6^VYB!Z;W-T
M8;-A(&YA<&ES86YA('<@:6YN96H@;FF_('1W;VIA('-T<F]N:64@:V]D;W=E
M:B`H)7,I+@!496X@<V5R=V5R(&YI92!P;W1R869I(')O>G!A:V]W>7=AYB!A
M<F-H:7?S=R!Z:7`@:2!G>FEP+@!#>F%S`$9O<FUA="!C>F%S=0!4>71ULP!$
M;P!!8GD@=WEB<F'F('=I96QO:W)O=&YE('!O;&$@<')Z>71R>GEM86H@<')Z
M>6-I<VL@0W1R;"`H4$,I(&QU8B!#;VUM86YD("A-86,I('!O9&-Z87,@:VQI
M:V%N:6$N`$1Z:;8`5&]G;P!4;VME;&%U`$IU=')O`%1O;F=A`%1R>6YI9&%D
M(&D@5&]B86=O`%!R87=D82!L=6(@9F&S<WH`5'5N97IJ80!4=7)C:F$`5'5R
M96-K:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U=F%L=0!54DP`55),
M.@!59V%N9&$`56MR86EN80!"L[%D('!O9&-Z87,@>FUI86YY(&1O("5S+@!"
ML[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+@!"L[%D
M('!O9&-Z87,@<F]Z<&%K;W=Y=V%N:6$@9&%N>6-H+@!.:64@;6^_;F$@<')Z
M972S=6UA8WIYYB!T96=O(&1O:W5M96YT=2!7;W)D+6$`0V]F;FEJ('IM:6%N
M>0!::F5D;F]C>F]N92!%;6ER871Y($%R86)S:VEE`%=I96QK82!"<GET86YI
M80!54T$`3FEE>FYA;F4`0F5Z(&YA>G=Y`$YI96]B<[-U9VEW86YE(')O>G-Z
M97)Z96YI90!586MT=6%L;FEJ`%IALV%D=6H`57)U9W=A:@!/<&-J92!UOWET
M:V]W;FEK80!296IE<W1R86-J82!UOWET:V]W;FEK80!.87IW82!UOWET:V]W
M;FEK80!5OWET:V]W;FEK(&\@;F%Z=VEE("(E<R(@:G6_(&ES=&YI96IE+@!.
M87IW82!UOWET:V]W;FEK83H`3F%Z=V$@=;]Y=&MO=VYI:V$Z(`!5OWET:V]W
M;FEC>2!W('-Y<W1E;6EE.@!5>F)E:VES=&%N`%=A:V%C:F4`5F%N=6%T=0!7
M96YE>G5E;&$`5V5R<VIA`%=I971N86T`5VED;VL@)7,`4&]K8;\@<W1R;V[J
M(%=75P!0;VMAOR!J86MO("5S`$)R>71Y:G-K:64@5WES<'D@1'II97=I8WIE
M`%=Y<W!Y($1Z:65W:6-Z92!3=&%N\W<@6FIE9&YO8WIO;GEC:`!786QL:7,@
M:2!&=71U;F$`3W-T<GIEOV5N:64`5U=7`$-O('1Y9'II9?$`5VET86UY`%=I
M=&%M>2!W("5S`%=I=&%M>2P@)7,`6F%C:&]D;FD@*$E33RTX.#4Y+3$I`%IA
M8VAO9&YI("A)4T\M.#@U.2TQ-2D`4V%H87)A(%IA8VAO9&YI80!*86NQ(&%P
M;&EK86-JZB!M82`E<R!W>;9W:65T;&'F('!O('IA;&]G;W=A;FEU('-IZC\`
M2F%K:64@=W1Y8WIK:2!A:W1Y=V]W8>8@=R!2;WIB=61O=V%N>6T@961Y=&]R
M>F4@=&5K<W1U+@!3>F5R;VMOMN8@;&5W96=O(&UE;G4@)7,@*'IM:6%N82!Z
M86-Z;FEE(&]B;W=IL7IY=V'F('!R>GD@;F%S=.IP;GEM(&QO9V]W86YI=2DZ
M`$%D<F5S(&1O('!R86-Y`%1E;"X@9&\@<')A8WD`4E(`4E)24@!#;R!R;VL`
M2F5M96X`5&%K`%1A:RP@>F=A9'IA;2!S:>H`5WEL;V=O=V&S9;8@<VGJ+@!-
M=7-I<WH@;W!I<V'F('!R;V)L96T@>F%N:6T@9V\@=WFV;&5S>BX`375S:7-Z
M(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N
M`$UU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@
M9&]D8>8N`%1W\VH@861R97,@92UM86EL`%1W\VH@861R97,@3V0Z`%1W;VIE
M(&EN9F]R;6%C:F4`5'?S:B!A9')E<R!I;G1E<FYE=&]W>2!S:>H@>FUI96YI
MLR!O9"!P;V-ZL71K=2!S97-J:2`E<RX@5R!Z=VFQ>FMU('H@8F5Z<&EE8WIE
M\7-T=V5M(%1W;VIE9V\@:V]N=&$@;75S:7-Z('IA;&]G;W=AYB!S:>H@<&]N
M;W=N:64N`%1W;VIE(&EM:>H`5&5N('-Y<W1E;2!A=71E;G1Y:V%C:FD@;FEE
M(&]B<[-U9W5J92!D;V1A=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@=&$@;W!C
M:F$@>F]S=&&S82!W>;.Q8WIO;F$N`%1E;B!S>7-T96T@875T96YT>6MA8VII
M(&YI92!O8G.S=6=U:F4@;&ES=&]W86YI82!UOWET:V]W;FEK\W<L(&QU8B!T
M82!O<&-J82!Z;W-T8;-A('=YL[%C>F]N82X`5'=O:F$@;V)E8VYA('-T<F5F
M82!C>F%S;W=A.@!$;VUYMFQN82!T;[]S86UOMN8Z`%1W;VIE('!ELVYE(&EM
M:>H@:2!N87IW:7-K;SH`5'=O:6T@;F]W>6T@:&%SLV5M('<@)7,@:F5S=#H@
M)7,`5'=O:F4@=7-T87=I96YI82!Z;W-T8;-Y('5A:W1U86QN:6]N92!N82!C
M>F%S('1R=V%N:6$@=&5J('-E<VII+@!4=V]J92!U<W1A=VEE;FEA('IO<W1A
MLWD@=6%K='5A;&YI;VYE+@!4=V]J92!Z9&%L;F4@<V5R=V5R>3H`2G5G;W.S
M87=I80!:86ER`%IA;6)I80!::6UB86)W90!;4F%P;W)T(&\@<')O8FQE;6EE
M70!?061M:6YI<W1R86-J80!?0TQ)`%]5<W7Q('=I97)S>@!?1W)U<'D`7U!O
M;6]C`%]:86QO9W5J`%]7>6QO9W5J`%IM:67Q(&QI;FLN+BX`7T]P8VIE`%]5
M<')A=VYI96YI80!5<W7Q(&QI;FLN+BX`7TMO;F9I9W5R86-J80!?5;]Y=&MO
M=VYI8WD`:W-IL;]K82!A9')E<V]W80!K86QE;F1A<GH`<&QI:P!.87IW:7-K
M;P!N;W1A=&YI:P!B97H@;F%Z=WD`=D-A<F0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+W!L7U!,+VAE;'`N>&UL````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#0Q-S,V,C<W-P`P
M,C`S-#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L
M;V-A;&4O<&Q?4$PO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ
M,R!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@
M<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@
M/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U
M;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O
M<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@
M;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E
M=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@
M(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L
M(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C
M;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S
M=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I
M;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A
M/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@
M87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R
M(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU
M9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@
M;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI
M8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H
M92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI
M8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O
M;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S
M=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E
M;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-
M86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN
M=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@
M(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@
M;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@
M=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R
M;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N
M(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]P=%]"4B\`````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#$V-C<W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!T7T)2+TQ#7TU%4U-!
M1T53+P``````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,C<W-P`P,C`T-C0`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O<'1?0E(O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P-#$U,34Q`#$P-#$W,S8R-S<W`#`R,C$R-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#>$@25`````(8'```<
M````3#P``!,*``!\>````````,B@```.````R:````\```#8H```#0```.B@
M```(````]J````L```#_H```#`````NA```$````&*$``!@````=H0``&P``
M`#:A```M````4J$``!T```"`H0``)````)ZA```I````PZ$``!D```#MH0``
M)@````>B```,````+J(``"0````[H@``#P```&"B```+````<*(```X```!\
MH@``!0```(NB```H````D:(```@```"ZH@``"@```,.B```5````SJ(``!(`
M``#DH@``"P```/>B``"%`````Z,```X```")HP``"@```)BC```-````HZ,`
M``X```"QHP``$0```,"C```-````TJ,```P```#@HP``#0```.VC```&````
M^Z,``)0````"I```"@```)>D```/````HJ0``!@```"RI```#````,ND```.
M````V*0```X```#GI```"````/:D```)````_Z0``"X````)I0``&@```#BE
M```R````4Z4``#@```"&I0``5````+^E``!1````%*8``%H```!FI@``5P``
M`,&F```T````&:<```D```!.IP``#0```%BG```'````9J<```H```!NIP``
M#P```'FG```%````B:<```8```"/IP``$0```):G```(````J*<```D```"Q
MIP``"0```+NG```E````Q:<``"````#KIP``$P````RH```0````(*@```\`
M```QJ```"@```$&H```#````3*@```\```!0J```%````&"H```)````=:@`
M``T```!_J```$@```(VH```9````H*@``!X```"ZJ```#P```-FH```*````
MZ:@```\```#TJ```"`````2I```D````#:D``!0````RJ0``%@```$>I```(
M````7JD``$X```!GJ0``+0```+:I```9````Y*D```<```#^J0``#`````:J
M```L````$ZH```X```!`J@```P```$^J```+````4ZH```<```!?J@``!P``
M`&>J```%````;ZH```4```!UJ@``"@```'NJ```#````AJH``!<```"*J@``
M"@```**J```/````K:H```X```"]J@``&````,RJ```C````Y:H```X````)
MJP``%````!BK```7````+:L``!<```!%JP``%P```%VK```3````=:L```\`
M``")JP``#@```)FK```?````J*L``!T```#(JP``!P```.:K```&````[JL`
M``@```#UJP``#P```/ZK```&````#JP```H````5K```$P```""L```+````
M-*P``!````!`K```%0```%&L```5````9ZP```<```!]K```$````(6L```%
M````EJP``!4```"<K```$0```+*L```,````Q*P``#L```#1K```.`````VM
M```)````1JT```<```!0K0``%````%BM```#````;:T```4```!QK0``$```
M`'>M```)````B*T``!,```"2K0``.0```*:M```2````X*T``"<```#SK0``
M+````!NN```J````2*X``"4```!SK@``"@```)FN```&````I*X```D```"K
MK@``!P```+6N```O````O:X``#<```#MK@``+@```"6O``!5````5*\``"T`
M``"JKP``+0```-BO```]````!K```#\```!$L```+0```(2P``!`````LK``
M`",```#SL```(P```!>Q``!`````.[$``"T```!\L0``,P```*JQ```E````
MWK$``!4````$L@``&0```!JR```I````-+(``"0```!>L@``*````(.R```1
M````K+(```H```"^L@``#````,FR```*````UK(``!````#AL@``%@```/*R
M```6````";,```<````@LP``!P```"BS```4````,+,```H```!%LP``"```
M`%"S```G````6;,```@```"!LP``!P```(JS```'````DK,```8```":LP``
M!0```*&S```'````I[,```8```"OLP``"````+:S```I````O[,```X```#I
MLP``"@```/BS```$`````[0```<````(M```"0```!"T```&````&K0``!$`
M```AM```!P```#.T```6````.[0```0```!2M```"````%>T```&````8+0`
M``T```!GM```!@```'6T```>````?+0``!$```";M```"````*VT```-````
MMK0```P```#$M```!P```-&T```#````V;0```,```#=M```%P```.&T```3
M````^;0``!T````-M0``"````"NU```$````-+4```@````YM0``"````$*U
M``!!````2[4``!H```"-M0``*P```*BU```@````U+4``!4```#UM0``!@``
M``NV```&````$K8``!4````9M@``&````"^V```B````2+8``"X```!KM@``
M'0```)JV```A````N+8``%0```#:M@``*0```"^W```*````6;<```<```!D
MMP``!P```&RW```5````=+<```X```"*MP``"@```)FW```/````I+<```T`
M``"TMP``#P```,*W```-````TK<```D```#@MP``%````.JW```&````_[<`
M`!@````&N```'0```!^X```3````/;@``!$```!1N```%````&.X```$````
M>+@```8```!]N```%````(2X``!4````F;@``&0```#NN```!````%.Y```.
M````6+D```4```!GN0``!0```&VY```;````<[D``!H```"/N0``$P```*JY
M```1````OKD``!$```#0N0``'````.*Y```J````_[D``!`````JN@``(0``
M`#NZ```%````7;H``!,```!CN@``"P```'>Z```2````@[H```H```"6N@``
M#P```*&Z```-````L;H``!$```"_N@``$P```-&Z```,````Y;H```8```#R
MN@``#````/FZ```&````!KL``!<````-NP``$````"6[```1````-KL```@`
M``!(NP``!0```%&[```,````5[L``!````!DNP``!0```'6[```-````>[L`
M``8```")NP``!P```)"[```-````F+L```<```"FNP``"P```*Z[```'````
MNKL```<```#"NP``"0```,J[```)````U+L```H```#>NP``&0```.F[```]
M`````[P``!T```!!O```#````%^\```0````;+P```4```!]O```)0```(.\
M```2````J;P``!,```"\O```*P```-"\```[````_+P``"`````XO0``"```
M`%F]```V````8KT``"$```"9O0``$````+N]```(````S+T```P```#5O0``
M!@```.*]```$````Z;T```\```#NO0``#@```/Z]```'````#;X```H````5
MO@``#0```""^```?````+KX``!P```!.O@``(0```&N^```>````C;X``!D`
M``"LO@``'@```,:^```;````Y;X``"$````!OP``+@```"._```F````4K\`
M`!P```!YOP``'@```):_```<````M;\``"8```#2OP``*P```/F_```S````
M)<```"8```!9P```*P```(#````X````K,```!T```#EP```%0````/!```O
M````&<$``"````!)P0``$@```&K!```I````?<$``!X```"GP0``(````,;!
M```2````Y\$``*(```#ZP0``%@```)W"```C````M,(``"@```#8P@``*0``
M``'#```H````*\,``!\```!4PP``%0```'3#```@````BL,``"4```"KPP``
M*````-'#```M````^L,``#`````HQ```D@```%G$```A````[,0``!8````.
MQ0``'````"7%```F````0L4``"H```!IQ0``00```)3%``!$````UL4```P`
M```;Q@``!P```"C&```'````,,8```8````XQ@``#0```#_&```0````3<8`
M`!(```!>Q@``$P```''&```2````A<8```<```"8Q@``!````*#&```0````
MI<8``!````"VQ@``#````,?&```.````U,8```T```#CQ@``#P```/'&```3
M`````<<```T````5QP``*````"/'```#````3,<```T```!0QP``!@```%['
M```1````9<<``!<```!WQP``&P```(_'```.````J\<```(```"ZQP``20``
M`+W'```%````!\@``!`````-R```#P```![(```$````+L@```T````SR```
M#@```$'(```#````4,@```X```!4R```"````&/(```/````;,@```\```!\
MR```!P```(S(```-````E,@``!````"BR```#0```+/(```+````P<@```8`
M``#-R```"P```-3(```,````X,@```H```#MR```$0```/C(```9````"LD`
M``L````DR0``#0```##)```B````/LD``!L```!AR0``-````'W)```*````
MLLD``!@```"]R0``&0```-;)```6````\,D``"(````'R@``#0```"K*```'
M````.,H``!0```!`R@``"P```%7*```B````8<H``"\```"$R@``"P```+3*
M```)````P,H``!D```#*R@``"P```.3*```7````\,H``!<````(RP``"0``
M`"#+```6````*LL```\```!!RP``&0```%'+```6````:\L```X```""RP``
M&````)'+```(````JLL```T```"SRP``)@```,'+``!#````Z,L```@````L
MS```$@```#7,```?````2,P```@```!HS```"P```'',```O````?<P```X`
M``"MS```!0```+S,```&````PLP``$4```#)S````P````_-```'````$\T`
M``0````;S0``"@```"#-```*````*\T```\````VS0``$````$;-```7````
M5\T``!$```!OS0``&0```('-```7````F\T```D```"SS0``!0```+W-```+
M````P\T```H```#/S0```@```-K-```%````W<T```T```#CS0``&P```/'-
M```7````#<X``!0````ES@``"0```#K.```.````1,X```T```!3S@``$@``
M`&'.```X````=,X``"````"MS@``"````,[.```.````U\X``'L```#FS@``
M&````&+/```8````>\\``!$```"4SP``!P```*;/```%````KL\``!@```"T
MSP``'@```,W/```;````[,\``!D````(T```&P```"+0```9````/M```!,`
M``!8T```!P```&S0```(````=-````8```!]T```!@```(30```0````B]``
M``\```"<T```$````*S0```/````O=````L```#-T```#P```-G0```,````
MZ=````\```#VT```!P````;1```&````#M$```X````5T0``#````"31```H
M````,=$```\```!:T0``"````&K1```(````<]$``!,```!\T0``'@```)#1
M```A````K]$``"````#1T0``&0```/+1```7````#-(``"4````DT@``%P``
M`$K2```6````8M(```0```!YT@``&P```'[2```-````FM(```P```"HT@``
M`P```+72```%````N=(```@```"_T@``"@```,C2```,````T](```L```#@
MT@``$````.S2```,````_=(```X````*TP``"P```!G3```$````)=,```0`
M```JTP``$P```"_3```4````0],```P```!8TP``"0```&73```.````;],`
M``L```!^TP``&P```(K3```'````IM,```<```"NTP``"@```+;3```-````
MP=,```D```#/TP``!````-G3```%````WM,```,```#DTP``&````.C3```*
M`````=0```0````,U```)@```!'4```.````.-0``'P```!'U```%0```,34
M```%````VM0```<```#@U```#````.C4```(````]=0```H```#^U```!@``
M``G5```(````$-4```(````9U0``!@```!S5```&````(]4``!0````JU0``
M#0```#_5```0````3=4``!L```!>U0``!````'K5```)````?]4``!````")
MU0``"0```)K5```)````I-4```4```"NU0``&@```+35```(````S]4```8`
M``#8U0``&0```-_5```.````^=4```<````(U@``!P```!#6```%````&-8`
M``D````>U@``"@```"C6```.````,]8```(```!"U@``!@```$76```+````
M3-8```T```!8U@``"0```&;6```&````<-8``!(```!WU@``"0```(K6```'
M````E-8``!0```"<U@``'0```+'6``!"````S]8``"4````2UP``)0```#C7
M```&````7M<```H```!EUP``!````'#7```)````==<```@```!_UP``$0``
M`(C7```)````FM<```8```"DUP``#0```*O7```&````N=<```0```#`UP``
M.0```,77```]````_]<``#H````]V```'@```'C8```%````E]@```X```"=
MV```!````*S8```&````L=@```<```"XV```(0```,#8```-````XM@``!4`
M``#PV```!@````;9```$````#=D``!$````2V0``!@```"39```*````*]D`
M`"(````VV0``!````%G9```%````7MD``!T```!DV0``!````(+9```,````
MA]D```X```"4V0``"@```*/9```(````KMD```D```"WV0``!0```,'9```Z
M````Q]D``#`````"V@``-0```#/:```I````:=H``$<```"3V@``.````-O:
M```I````%-L``#\````^VP``+@```'[;```M````K=L``!\```#;VP``#P``
M`/O;```2````"]P```L````>W```)@```"K<```I````4=P``"0```![W```
M)@```*#<```(````Q]P```H```#0W```"0```-O<```'````Y=P``"````#M
MW```(`````[=```F````+]T```H```!6W0``&0```&'=```I````>]T``!8`
M``"EW0``$@```+S=```'````S]T```H```#7W0``#````.+=```/````[]T`
M`!````#_W0``0````!#>``!P````4=X``&8```#"W@``#@```"G?```)````
M.-\```H```!"WP``$@```$W?```3````8-\```P```!TWP``!@```('?```/
M````B-\``!(```"8WP``$````*O?```1````O-\``!P```#.WP``(P```.O?
M``!J````#^````\```!ZX```!0```(K@```0````D.````D```"AX```!```
M`*O@```+````L.```"````"\X```%````-W@```,````\N````P```#_X```
M#P````SA```5````'.$``"D````RX0``*@```%SA```F````A^$``"<```"N
MX0``*0```-;A```J`````.(``!D````KX@``0@```$7B```1````B.(``!(`
M``":X@``$P```*WB```4````P>(```\```#6X@``%@```.;B```7````_>(`
M`!`````5XP``$0```";C```T````..,``!,```!MXP``$@```('C```U````
ME.,``!0```#*XP``!P```-_C```,````Y^,``"````#TXP``$````!7D```4
M````)N0``!$````[Y```%P```$WD```<````9>0``!,```""Y```%````);D
M```:````J^0``!$```#&Y```&@```-CD```>````\^0``!H````2Y0``$P``
M`"WE```5````0>4``!$```!7Y0``%P```&GE```4````@>4``!<```"6Y0``
M%0```*[E```)````Q.4``!````#.Y0``&0```-_E```$````^>4```<```#^
MY0``"P````;F```1````$N8```8````DY@``!@```"OF```&````,N8```4`
M```YY@``!P```#_F```'````1^8```4```!/Y@``%@```%7F```&````;.8`
M``8```!SY@``!````'KF```$````?^8```<```"$Y@``#@```(SF```,````
MF^8```P```"HY@``#0```+7F```*````P^8```X```#.Y@``!0```-WF```H
M````X^8```X````,YP``#````!OG```/````*.<```H````XYP``"````$/G
M```)````3.<``"L```!6YP``!````(+G```(````A^<``"8```"0YP``$@``
M`+?G```/````RN<```8```#:YP``"@```.'G```'````[.<```@```#TYP``
M(````/WG```)````'N@``!0````HZ```#````#WH```-````2N@```X```!8
MZ```%@```&?H```1````?N@```8```"0Z````P```)?H```&````F^@``!D`
M``"BZ```!P```+SH```$````Q.@```L```#)Z```"P```-7H```'````X>@`
M``4```#IZ```!P```._H```6````]^@```T````.Z0``#0```!SI```*````
M*ND``!`````UZ0``#P```$;I```1````5ND``!<```!HZ0``"@```(#I```1
M````B^D```@```"=Z0``!````*;I```/````J^D``#H```"[Z0``!0```/;I
M```,````_.D``!X````)Z@``#@```"CJ```0````-^H```L```!(Z@``#```
M`%3J```)````8>H```<```!KZ@``"@```'/J```)````?NH```X```"(Z@``
M$````)?J```;````J.H``!@```#$Z@``&@```-WJ```*````^.H```D````#
MZP``"@````WK```,````&.L```\````EZP``"````#7K```&````/NL``!P`
M``!%ZP``!P```&+K```%````:NL```L```!PZP``1P```'SK```-````Q.L`
M``D```#2ZP``!````-SK```#````X>L``!,```#EZP``$P```/GK```3````
M#>P```H````A[````@```"SL```$````+^P``"4````T[````P```%KL```%
M````7NP``"H```!D[```"@```(_L```%````FNP```0```"@[```"@```*7L
M```-````L.P```8```"^[```"````,7L```(````SNP```0```#7[```!0``
M`-SL``!H````XNP```D```!+[0``#````%7M```0````8NT```4```!S[0``
M!@```'GM```;````@.T``"\```"<[0``$````,SM```*````W>T```\```#H
M[0``"@```/CM```)`````^X``!,````-[@``&P```"'N```8````/>X``!<`
M``!6[@``'P```&[N```.````CNX```,```"=[@``!P```*'N```(````J>X`
M``<```"R[@``"@```+KN```+````Q>X```<```#1[@``40```-GN```0````
M*^\```P````\[P``#0```$GO```:````5^\``$H```!R[P``&0```+WO```&
M````U^\``!H```#>[P``)0```/GO```&````'_````8````F\```'P```"WP
M```&````3?````D```!4\```&````%[P```7````=_```"@```"/\```!@``
M`+CP```-````O_```"(```#-\```5P```/#P```3````2/$``",```!<\0``
M$P```(#Q```"````E/$```L```"7\0``"````*/Q```-````K/$```H```"Z
M\0``!P```,7Q```4````S?$```8```#B\0``"````.GQ```.````\O$```<`
M```!\@``"@````GR```+````%/(``#(````@\@``!P```%/R```,````6_(`
M``T```!H\@``#````';R```)````@_(```D```"-\@``"@```)?R```'````
MHO(```D```"J\@``!P```+3R```*````O/(``!L```#'\@``#P```./R```2
M````\_(```H````&\P``%@```!'S```)````*/,``!`````R\P``!P```$/S
M```2````2_,```0```!>\P``!P```&/S```%````:_,```4```!Q\P``"P``
M`'?S```4````@_,``!$```"8\P``&@```*KS```6````Q?,``!0```#<\P``
M%P```/'S```8````"?0``!P````B]```&0```#_T```'````6?0```4```!A
M]```#0```&?T```,````=?0``!$```""]```"````)3T```7````G?0```L`
M``"U]```#````,'T```?````SO0``!H```#N]```$P````GU```$````'?4`
M``H````B]0``!````"WU```-````,O4```P```!`]0``!0```$WU```)````
M4_4```4```!=]0``!P```&/U```%````:_4```0```!Q]0```@```';U```X
M````>?4``"P```"R]0``$@```-_U```I````\O4``#(````<]@``"@```$_V
M```L````6O8``"X```"']@``,P```+;V```S````ZO8``#@````>]P``#P``
M`%?W```8````9_<``!````"`]P``#P```)'W```3````H?<``!4```"U]P``
M%````,OW```2````X/<``!0```#S]P``%0````CX```M````'O@``"T```!,
M^```,0```'KX```N````K/@``"\```#;^```+`````OY``!B````./D``!,`
M``";^0``#0```*_Y```(````O?D``!<```#&^0``"````-[Y```,````Y_D`
M`"L```#T^0``(0```"#Z```:````0OH```D```!=^@``10```&?Z``!!````
MK?H```0```#O^@``$P```/3Z```4````"/L```X````=^P``$P```"S[```8
M````0/L```8```!9^P``"0```&#[```*````:OL```\```!U^P``$````(7[
M```'````EOL```X```">^P``!0```*W[```;````L_L```@```#/^P``!@``
M`-C[```4````W_L``!$```#T^P``#@````;\```X````%?P```(```!._```
M!@```%'\```.````6/P```4```!G_```!P```&W\```.````=?P```8```"$
M_```*````(O\```,````M/P``!P```#!_```!````-[\```I````X_P``!<`
M```-_0``'P```"7]``!<````1?T``!0```"B_0``/@```+?]```?````]OT`
M`!`````6_@``!P```"?^```.````+_X```P````^_@``#````$O^```3````
M6/X```H```!L_@``'0```'?^```9````E?X```4```"O_@``$0```+7^```1
M````Q_X``"0```#9_@``$@```/[^```5````$?\``!(````G_P``#@```#K_
M```9````2?\```@```!C_P``"0```&S_```-````=O\```<```"$_P``"@``
M`(S_```'````E_\```\```"?_P``!@```*__```+````MO\``!H```#"_P``
M"@```-W_```'````Z/\```@```#P_P``!0```/G_```?````__\```8````?
M``$`$````"8``0`(````-P`!``T```!```$`"````$X``0`>````5P`!`!(`
M``!V``$`+````(D``0`:````M@`!``D```#1``$`"@```-L``0`5````Y@`!
M``4```#\``$`%`````(!`0`$````%P$!`!`````<`0$`!@```"T!`0`'````
M-`$!`!X````\`0$`*````%L!`0`*````A`$!`!P```"/`0$`$0```*P!`0`+
M````O@$!`!H```#*`0$`%````.4!`0`$````^@$!``0```#_`0$`"P````0"
M`0`%````$`(!``8````6`@$`"````!T"`0`&````)@(!``H````M`@$`&P``
M`#@"`0`T````5`(!`#0```")`@$`(````+X"`0`I````WP(!`"`````)`P$`
M00```"H#`0`:````;`,!`"@```"'`P$`*0```+`#`0!0````V@,!`"(````K
M!`$`!@```$X$`0`(````500!``4```!>!`$`"````&0$`0`9````;00!`!D`
M``"'!`$`*@```*$$`0`C````S`0!`!D```#P!`$`+@````H%`0`T````.04!
M``@```!N!0$`%P```'<%`0`*````CP4!``<```":!0$`(0```*(%`0`0````
MQ`4!``X```#5!0$`"P```.0%`0`'````\`4!`!,```#X!0$`"`````P&`0`+
M````%08!``H````A!@$`%````"P&`0`/````008!`#(```!1!@$`"P```(0&
M`0`%````D`8!``4```"6!@$`!0```)P&`0`7````H@8!``\```"Z!@$`!```
M`,H&`0`*````SP8!``D```#:!@$`"P```.0&`0`-````\`8!``P```#^!@$`
M#@````L'`0`%````&@<!``0````@!P$`#0```"4'`0`R````,P<!`$4```!F
M!P$`%P```*P'`0`'````Q`<!`!X```#,!P$`%````.L'`0`%``````@!`!0`
M```&"`$`!@```!L(`0`'````(@@!``X````J"`$`*@```#D(`0`&````9`@!
M``P```!K"`$`#0```'@(`0`1````A@@!``L```"8"`$`-@```*0(`0`*````
MVP@!`"(```#F"`$`"P````D)`0`/````%0D!`#(````E"0$`)0```%@)`0`P
M````?@D!`#$```"O"0$`+0```.$)`0`.````#PH!``4````>"@$`#@```"0*
M`0`3````,PH!`!(```!'"@$`!P```%H*`0`1````8@H!`!,```!T"@$`!P``
M`(@*`0`4````D`H!`!@```"E"@$`!P```+X*`0`%````Q@H!``P```#,"@$`
M#````-D*`0`2````Y@H!``0```#Y"@$`!P```/X*`0`*````!@L!``L````1
M"P$`#````!T+`0`.````*@L!``X````Y"P$`!0```$@+`0`%````3@L!`"X`
M``!4"P$`)@```(,+`0`C````J@L!``,```#."P$`$@```-(+`0`&````Y0L!
M`!X```#L"P$`&`````L,`0`E````)`P!``T```!*#`$`"0```%@,`0`?````
M8@P!``,```""#`$`!P```(8,`0`*````C@P!``(```"9#`$`#````)P,`0`5
M````J0P!``L```"_#`$`&0```,L,`0`@````Y0P!`!(````&#0$`!0```!D-
M`0`*````'PT!`!4````J#0$`$@```$`-`0`,````4PT!``0```!@#0$`"0``
M`&4-`0`'````;PT!``P```!W#0$`4@```(0-`0`7````UPT!`"0```#O#0$`
M$@```!0.`0`'````)PX!``8````O#@$`#@```#8.`0`,````10X!``T```!2
M#@$`%0```&`.`0`2````=@X!``\```")#@$`%````)D.`0`*````K@X!`!L`
M``"Y#@$`$````-4.`0`+````Y@X!`&D```#R#@$`&@```%P/`0`7````=P\!
M`"<```"/#P$`&@```+</`0`7````T@\!`!L```#J#P$`&0````80`0`?````
M(!`!`!,```!`$`$`"````%00`0`'````71`!``@```!E$`$`"0```&X0`0`5
M````>!`!``T```".$`$`(P```)P0`0`-````P!`!`!,```#.$`$`"````.(0
M`0`#````ZQ`!`$8```#O$`$`/P```#81`0`W````=A$!`%<```"N$0$`!0``
M``82`0`?````#!(!`"\````L$@$`"@```%P2`0`(````9Q(!``T```!P$@$`
M+0```'X2`0`$````K!(!`$\```"Q$@$`)0````$3`0`<````)Q,!``L```!$
M$P$`'P```%`3`0`=````<!,!`"4```".$P$`(````+03`0`D````U1,!`"``
M``#Z$P$`"P```!L4`0`'````)Q0!``T````O%`$`#````#T4`0`7````2A0!
M``8```!B%`$`.0```&D4`0`,````HQ0!``<```"P%`$`"0```+@4`0`3````
MPA0!``D```#6%`$`!````.`4`0`0````Y10!``@```#V%`$`"````/\4`0`$
M````"!4!``L````-%0$`#````!D5`0`2````)A4!`!$````Y%0$`#````$L5
M`0`:````6!4!``\```!S%0$`!P```(,5`0`-````BQ4!`!0```"9%0$`#@``
M`*X5`0`,````O14!`!L```#*%0$`+````.85`0`3````$Q8!`!P````G%@$`
M*````$06`0`&````;18!``<```!T%@$`$P```'P6`0`%````D!8!``0```"6
M%@$`%P```)L6`0`*````LQ8!``P```"^%@$`"0```,L6`0`&````U18!``D`
M``#<%@$`"````.86`0`)````[Q8!``H```#Y%@$`$0````07`0`&````%A<!
M``X````=%P$`#@```"P7`0`-````.Q<!``L```!)%P$`'0```%47`0`+````
M<Q<!``(```!_%P$`'````((7`0`'````GQ<!``8```"G%P$`9````*X7`0`)
M````$Q@!``<````=&`$`)@```"48`0`X````3!@!`!H```"%&`$`*@```*`8
M`0`[````RQ@!`"@````'&0$`-````#`9`0`9````91D!`!4```!_&0$`!0``
M`)49`0`'````FQD!``@```"C&0$`!P```*P9`0`%````M!D!``<```"Z&0$`
M#@```,(9`0`)````T1D!``8```#;&0$`"````.(9`0`+````ZQD!``<```#W
M&0$`"````/\9`0`'````"!H!`!8````0&@$`"0```"<:`0`&````,1H!``L`
M```X&@$`$````$0:`0`&````51H!`!P```!<&@$`%````'D:`0`'````CAH!
M`!$```"6&@$`"````*@:`0`.````L1H!``@```#`&@$`!0```,D:`0`0````
MSQH!``D```#@&@$`$````.H:`0`&````^QH!`!D````"&P$`"@```!P;`0`<
M````)QL!``<```!$&P$`!0```$P;`0`0````4AL!`!0```!C&P$`"P```'@;
M`0`-````A!L!`"@```"2&P$`&````+L;`0`7````U!L!``0```#L&P$`"0``
M`/$;`0`*````^QL!``<````&'`$``@````X<`0`.````$1P!``@````@'`$`
M(P```"D<`0`?````31P!`#@```!M'`$`)@```*8<`0`Q````S1P!`"<```#_
M'`$`9````"<=`0`4````C!T!`%4```"A'0$`.````/<=`0!*````,!X!`%L`
M``!['@$`*````-<>`0`X`````!\!`"@````Y'P$`+````&(?`0`F````CQ\!
M`!L```"V'P$`/@```-(?`0"I`0``$2`!`",```"[(0$`%P```-\A`0!(````
M]R$!`(4```!`(@$`,````,8B`0`E````]R(!`$$````=(P$`6P```%\C`0!)
M````NR,!`#$````%)`$`'0```#<D`0`8````520!`"L```!N)`$`(0```)HD
M`0`?````O"0!`"L```#<)`$`)@````@E`0`G````+R4!`#H```!7)0$`'0``
M`)(E`0`1````L"4!`#,```#")0$`)0```/8E`0`G````'"8!`"````!$)@$`
M'P```&4F`0`P````A28!`&D```"V)@$`,0```"`G`0!!````4B<!`#,```"4
M)P$`)0```,@G`0`]````[B<!`&4````L*`$`30```)(H`0`O````X"@!`"X`
M```0*0$`,````#\I`0!4````<"D!`%H```#%*0$`2````"`J`0!*````:2H!
M`#(```"T*@$`+P```.<J`0`L````%RL!`"T```!$*P$`<0```'(K`0!F````
MY"L!`&\```!++`$`LP```+LL`0`7````;RT!`"4```"'+0$`,@```*TM`0`I
M````X"T!`#X````*+@$`(@```$DN`0!2````;"X!`"4```"_+@$`"P```.4N
M`0"Q````\2X!`$4```"C+P$`(0```.DO`0`P````"S`!`"4````\,`$`'```
M`&(P`0`Q````?S`!``<```"Q,`$`!P```+DP`0`$````P3`!``T```#&,`$`
M"P```-0P`0`.````X#`!``L```#O,`$`!0```/LP`0`0`````3$!``(````2
M,0$`60```!4Q`0`%````;S$!`!(```!U,0$`!````(@Q`0`'````C3$!``@`
M``"5,0$`!0```)XQ`0`#````I#$!`!````"H,0$`#````+DQ`0`3````QC$!
M``T```#:,0$``@```.@Q`0`'````ZS$!``8```#S,0$`%````/HQ`0`,````
M#S(!`!@````<,@$`!@```#4R`0`2````/#(!``P```!/,@$``P```%PR`0`J
M````8#(!``0```"+,@$`!@```)`R`0`'````ES(!`!\```"?,@$`-0```+\R
M`0`N````]3(!`"\````D,P$`%P```%0S`0`B````;#,!`"4```"/,P$`(```
M`+4S`0`;````UC,!`!@```#R,P$`)`````LT`0`?````,#0!`!H```!0-`$`
M(0```&LT`0`@````C30!`!H```"N-`$`,@```,DT`0`:````_#0!`"\````7
M-0$`*P```$<U`0`?````<S4!`",```"3-0$`'P```+<U`0`:````US4!`"$`
M``#R-0$`)0```!0V`0`F````.C8!`"4```!A-@$`)````(<V`0`8````K#8!
M`!T```#%-@$`)````.,V`0`8````"#<!`"(````A-P$`+````$0W`0`O````
M<3<!`!4```"A-P$`)0```+<W`0`\````W3<!`!\````:.`$`(P```#HX`0`?
M````7C@!`"````!^.`$`&@```)\X`0`8````NC@!`"8```#3.`$`'@```/HX
M`0`I````&3D!`!X```!#.0$`,0```&(Y`0`)````E#D!``P```">.0$`%P``
M`*LY`0`O````PSD!`"0```#S.0$`!P```!@Z`0`/````(#H!`!0````P.@$`
M#@```$4Z`0`-````5#H!`"0```!B.@$`!0```(<Z`0`'````C3H!`"(```"5
M.@$`)0```+@Z`0`:````WCH!`!T```#Y.@$`&@```!<[`0`'````,CL!`,<`
M```Z.P$`"P````(\`0`5````#CP!``8````D/`$`"0```"L\`0`+````-3P!
M``T```!!/`$`%P```$\\`0`&````9SP!`#,```!N/`$`$P```*(\`0`3````
MMCP!``<```#*/`$`#P```-(\`0`'````XCP!`#(```#J/`$`!````!T]`0`A
M````(CT!`!,```!$/0$`#````%@]`0`1````93T!`#(```!W/0$`%@```*H]
M`0`(````P3T!`!T```#*/0$`"0```.@]`0`*````\CT!`!0```#]/0$`"@``
M`!(^`0`=````'3X!``@````[/@$`'P```$0^`0`(````9#X!`!H```!M/@$`
M)P```(@^`0`&````L#X!`!4```"W/@$`!P```,T^`0`(````U3X!``D```#>
M/@$`/P```.@^`0`'````*#\!``\````P/P$`#@```$`_`0`0````3S\!``D`
M``!@/P$`"0```&H_`0`(````=#\!`!,```!]/P$`!P```)$_`0`9````F3\!
M``H```"S/P$`%P```+X_`0`4````UC\!``H```#K/P$`#````/8_`0`7````
M`T`!``0````;0`$`*@```"!``0`,````2T`!`!$```!80`$`!P```&I``0`"
M````<D`!`!````!U0`$`&````(9``0`+````GT`!``,```"K0`$`"````*]`
M`0`&````N$`!``<```"_0`$`#0```,=``0`+````U4`!`!0```#A0`$`%0``
M`/9``0`.````#$$!`"\````;00$`(````$M!`0`<````;$$!`!4```")00$`
M#````)]!`0`Q````K$$!``4```#>00$`$@```.1!`0`_````]T$!`!(````W
M0@$`"@```$I"`0`&````54(!``0```!<0@$`!````&%"`0`*````9D(!`!,`
M``!Q0@$`!0```(5"`0`&````BT(!``8```"20@$`"````)E"`0`$````HD(!
M``P```"G0@$`"@```+1"`0`Y````OT(!`"X```#Y0@$`*0```"A#`0`%````
M4D,!`!@```!80P$`&0```'%#`0`?````BT,!`!T```"K0P$`$0```,E#`0`"
M````VT,!``0```#>0P$`"@```.-#`0`&````[D,!``4```#U0P$``P```/M#
M`0`,````_T,!`$4````,1`$`,@```%)$`0`:````A40!`#0```"@1`$`*```
M`-5$`0!3````_D0!`!D```!210$`<@```&Q%`0`@````WT4!`#4`````1@$`
M(0```#9&`0!%````6$8!`#````">1@$`*````,]&`0`I````^$8!`"8````B
M1P$`)0```$E'`0`H````;T<!`"@```"81P$`(@```,%'`0`K````Y$<!`#``
M```02`$`$@```$%(`0`3````5$@!`!````!H2`$`>0```'E(`0`)````\T@!
M`*$```#]2`$`<P```)])`0!\````$TH!`"L```"02@$`5````+Q*`0`7````
M$4L!`"<````I2P$`%@```%%+`0`/````:$L!`!<```!X2P$`'P```)!+`0!`
M````L$L!`!\```#Q2P$`'````!%,`0!1````+DP!`!H```"`3`$`%````)M,
M`0`*````L$P!``4```"[3`$`!@```,%,`0`(````R$P!``4```#13`$`$@``
M`-=,`0`0````ZDP!`!,```#[3`$`'0````]-`0`/````+4T!``\````]30$`
M!````$U-`0`)````4DT!``L```!<30$`!P```&A-`0`%````<$T!`!0```!V
M30$`!P```(M-`0`(````DTT!``\```"<30$`"````*Q-`0`,````M4T!``\`
M``#"30$`!@```-)-`0`4````V4T!``8```#N30$`#````/5-`0`1`````DX!
M``@````43@$`!````!U.`0`9````(DX!`!$````\3@$`"@```$Y.`0`8````
M64X!`!,```!R3@$`'````(9.`0`1````HTX!``0```"U3@$`#P```+I.`0`'
M````RDX!``0```#23@$`&0```-=.`0`'````\4X!``(```#Y3@$``@```/Q.
M`0`1````_TX!``D````13P$`!@```!M/`0`2````(D\!`!<````U3P$`!@``
M`$U/`0`G````5$\!``(```!\3P$`!````']/`0`/````A$\!`!,```"43P$`
M!P```*A/`0`'````L$\!`!$```"X3P$`!@```,I/`0`8````T4\!``8```#J
M3P$`$P```/%/`0`0````!5`!`!(````64`$``@```"E0`0`&````+%`!``P`
M```S4`$`"0```$!0`0`1````2E`!`"(```!<4`$`!P```']0`0`'````AU`!
M``L```"/4`$`!0```)M0`0`"````H5`!``L```"D4`$`I0$``+!0`0`0````
M5E(!`!4```!G4@$`#0```'U2`0`'````BU(!``D```"34@$`"````)U2`0`#
M````IE(!`!@```"J4@$`'@```,-2`0`O````XE(!`"L````24P$`*0```#Y3
M`0`M````:%,!`!D```"64P$`*@```+!3`0`*````VU,!`!X```#F4P$`$@``
M``54`0`*````&%0!`!<````C5`$`!0```#M4`0`H````050!`!(```!J5`$`
M#@```'U4`0`3````C%0!``T```"@5`$`"@```*Y4`0"2````N50!`!````!,
M50$`"@```%U5`0`2````:%4!``T```![50$`&P```(E5`0`,````I54!``\`
M``"R50$`%@```,)5`0`&````V54!`)D```#@50$`"````'I6`0`-````@U8!
M`!@```"15@$`#P```*I6`0`0````NE8!`!````#+5@$`"````-Q6`0`0````
MY58!`#P```#V5@$`%0```#-7`0!#````25<!`$D```"-5P$`50```-=7`0!-
M````+5@!`'(```![6`$`:@```.Y8`0!&````65D!`!````"@60$`%@```+%9
M`0`.````R%D!`!````#760$`$@```.A9`0`%````^UD!``8````!6@$`$0``
M``A:`0`(````&EH!``D````C6@$`"0```"U:`0`E````-UH!`",```!=6@$`
M$````(%:`0`.````DEH!`!$```"A6@$`!@```+-:`0`)````NEH!`!L```#$
M6@$`(0```.!:`0`.`````EL!`!0````16P$`&````"9;`0`E````/UL!`"H`
M``!E6P$`&@```)!;`0`0````JUL!`!<```"\6P$`#0```-1;`0`U````XEL!
M`",````87`$`)@```#Q<`0`1````8UP!`%@```!U7`$`-@```,Y<`0`E````
M!5T!``@````K70$`%0```#1=`0`W````2ET!``T```""70$`"````)!=`0`+
M````F5T!``<```"E70$`!P```*U=`0`'````M5T!``<```"]70$`#````,5=
M`0`%````TET!`!L```#870$`#````/1=`0`0`````5X!`!(````27@$`'```
M`"5>`0`O````0EX!``D```!R7@$`%@```'Q>`0`6````DUX!`!@```"J7@$`
M'@```,->`0`4````XEX!`!(```#W7@$`#P````I?`0`A````&E\!`!T````\
M7P$`!P```%I?`0`&````8E\!``@```!I7P$`#0```')?`0`(````@%\!``D`
M``")7P$`$@```)-?`0`)````IE\!`!,```"P7P$`&````,1?`0`J````W5\!
M``<````(8`$`$@```!!@`0`%````(V`!`!8````I8`$`$@```$!@`0`/````
M4V`!`$(```!C8`$`.@```*9@`0`)````X6`!``<```#K8`$`$P```/-@`0`$
M````!V$!``4````,80$`#0```!)A`0`*````(&$!`!<````K80$`0P```$-A
M`0`5````AV$!`"0```"=80$`*P```,)A`0`J````[F$!`#`````98@$`"0``
M`$IB`0`&````5&(!``D```!;8@$`!P```&5B`0`[````;6(!`#T```"I8@$`
M.@```.=B`0!?````(F,!`#D```""8P$`.0```+QC`0!%````]F,!`$4````\
M9`$`.0```()D`0!2````O&0!`"H````/90$`+````#IE`0!)````9V4!`#D`
M``"Q90$`/P```.ME`0`E````*V8!`!4```!19@$`&0```&=F`0`L````@68!
M`"8```"N9@$`)@```-5F`0`3````_&8!``H````09P$`$0```!MG`0`%````
M+6<!``P````S9P$`&0```$!G`0`;````6F<!``<```!V9P$`!P```'YG`0`5
M````AF<!``H```"<9P$`"````*=G`0`T````L&<!`!````#E9P$`"@```/9G
M`0`'`````6@!``8````):`$`!0```!!H`0`(````%F@!``4````?:`$`"P``
M`"5H`0`R````,6@!`!8```!D:`$`#0```'MH`0`'````B6@!``<```"1:`$`
M"0```)EH`0`%````HV@!`!$```"I:`$`!@```+MH`0`4````PF@!``4```#7
M:`$`"````-UH`0`&````YF@!``L```#M:`$`!@```/EH`0`B`````&D!``8`
M```C:0$`"````"II`0`4````,VD!``P```!(:0$`!P```%5I`0`#````76D!
M``,```!A:0$`&@```&5I`0`:````@&D!`"T```";:0$`!@```,EI`0`%````
MT&D!``@```#6:0$`"````-]I`0!:````Z&D!`"$```!#:@$`/````&5J`0`L
M````HFH!`"$```#/:@$`!@```/%J`0`(````^&H!`!X````!:P$`)@```"!K
M`0`Q````1VL!`#8```!Y:P$`*````+!K`0`O````V6L!`&T````);`$`.@``
M`'=L`0`*````LFP!``8```"];`$`"0```,1L`0`2````SFP!``P```#A;`$`
M$````.YL`0`6````_VP!`!$````6;0$`%@```"AM`0`6````/VT!`!````!6
M;0$`%0```&=M`0`&````?6T!`!L```"$;0$`&P```*!M`0`7````O&T!`!L`
M``#4;0$`&````/!M`0`&````"6X!``<````0;@$`$````!AN`0!<````*6X!
M`&````"&;@$`!````.=N`0`2````[&X!``4```#_;@$`!0````5O`0`<````
M"V\!`!D````H;P$`%````$)O`0`1````5V\!`!(```!I;P$`&@```'QO`0`Z
M````EV\!``\```#2;P$`+P```.)O`0`&````$G`!`!0````9<`$`#P```"YP
M`0`3````/G`!``\```!2<`$`&````&)P`0`2````>W`!`!4```".<`$`$P``
M`*1P`0`-````N'`!``8```#&<`$`$@```,UP`0`'````X'`!``X```#H<`$`
M%@```/=P`0`/````#G$!``@````><0$``P```"=Q`0`0````*W$!``X````\
M<0$`!0```$MQ`0`3````47$!``H```!E<0$`!P```'!Q`0`0````>'$!``@`
M``")<0$`!````))Q`0`'````EW$!``<```"?<0$`#````*=Q`0`(````M'$!
M``D```"]<0$`&@```,=Q`0`^````XG$!`"8````A<@$`#0```$AR`0`0````
M5G(!``4```!G<@$`'P```&UR`0`1````C7(!`!(```"?<@$`,@```+)R`0!"
M````Y7(!`"$````H<P$`"````$IS`0!'````4W,!`"@```";<P$`$````,1S
M`0`)````U7,!``H```#?<P$`!@```.IS`0`&````\7,!`!(```#X<P$`#@``
M``MT`0`+````&G0!``H````F=`$`#P```#%T`0`L````070!`"<```!N=`$`
M-````)9T`0`O````RW0!`"8```#[=`$`*P```")U`0`F````3G4!`"4```!U
M=0$`/0```)MU`0`R````V74!`"D````,=@$`+P```#9V`0`F````9G8!`#0`
M``"-=@$`1@```,)V`0!!````"7<!`#T```!+=P$`/0```(EW`0!'````QW<!
M`"P````/>`$`*````#QX`0!&````97@!`"H```"L>`$`&@```-=X`0`U````
M\G@!`"@````H>0$`+````%%Y`0`8````?GD!`,D```"7>0$`'````&%Z`0`R
M````?GH!`#(```"Q>@$`-````.1Z`0`Q````&7L!`"D```!+>P$`*@```'5[
M`0`J````H'L!`#(```#+>P$`-0```/Y[`0!)````-'P!`#L```!^?`$`J0``
M`+I\`0`L````9'T!`"4```"1?0$`*````+=]`0`V````X'T!`#(````7?@$`
M60```$I^`0!.````I'X!``T```#S?@$`!`````%_`0`&````!G\!``4````-
M?P$`#0```!-_`0`.````(7\!`!`````P?P$`%0```$%_`0`;````5W\!``<`
M``!S?P$`!````'M_`0`.````@'\!``X```"/?P$`"@```)Y_`0`-````J7\!
M`!,```"W?P$`"P```,M_`0`0````UW\!``P```#H?P$`-@```/5_`0`&````
M+(`!``X````S@`$`!@```$*``0`1````28`!`!<```!;@`$`&P```'.``0`0
M````CX`!``(```"@@`$`2@```*.``0`+````[H`!`!4```#Z@`$`&@```!"!
M`0`$````*X$!`!,````P@0$`#P```$2!`0`#````5($!``\```!8@0$`"```
M`&B!`0`0````<8$!`!````""@0$`!@```).!`0`*````FH$!`!$```"E@0$`
M#````+>!`0`*````Q($!``<```#/@0$`#@```->!`0`-````YH$!``L```#T
M@0$`$0````""`0`:````$H(!``X````M@@$`#@```#R"`0`C````2X(!`!P`
M``!O@@$`/````(R"`0`-````R8(!`!X```#7@@$`%@```/:"`0`5````#8,!
M`#0````C@P$`#P```%B#`0`)````:(,!`!,```!R@P$`"0```(:#`0`U````
MD(,!`#<```#&@P$`#P```/Z#`0`0````#H0!`"4````?A`$`$@```$6$`0`@
M````6(0!`"````!YA`$`"0```)J$`0`;````I(0!`!(```#`A`$`&0```-.$
M`0`5````[80!``X````#A0$`&0```!*%`0`'````+(4!``L````TA0$`)@``
M`$"%`0!(````9X4!``H```"PA0$`%````+N%`0`?````T(4!``8```#PA0$`
M"0```/>%`0`P`````88!`!`````RA@$`!@```$.&`0`'````2H8!`%0```!2
MA@$``P```*>&`0`'````JX8!``8```"SA@$`#````+J&`0`,````QX8!`!``
M``#4A@$`$0```.6&`0`9````]X8!`!$````1AP$`&0```".'`0`9````/8<!
M``@```!7AP$`!0```&"'`0`+````9H<!``L```!RAP$``@```'Z'`0`&````
M@8<!`!(```"(AP$`)P```)N'`0`8````PX<!`!D```#<AP$`"0```/:'`0`3
M`````(@!`!0````4B`$`'````"F(`0!&````1H@!`"\```"-B`$`#````+V(
M`0`/````RH@!`(H```#:B`$`'````&6)`0`8````@HD!`!````";B0$`"```
M`*R)`0`$````M8D!`!<```"ZB0$`*P```-*)`0`H````_HD!`!H````GB@$`
M'0```$**`0`1````8(H!`!,```!RB@$`!P```(:*`0`'````CHH!``8```"6
MB@$`!@```)V*`0`/````I(H!``X```"TB@$`$````,.*`0`.````U(H!``P`
M``#CB@$`#@```/"*`0`+````_XH!`!,````+BP$`"````!^+`0`(````*(L!
M`!8````QBP$`#````$B+`0`U````58L!`!$```"+BP$`"````)V+`0`5````
MIHL!`"4```"\BP$`&P```.*+`0`C````_HL!`"(````BC`$`&````$6,`0`:
M````7HP!`"4```!YC`$`&0```)^,`0`2````N8P!``4```#,C`$`&0```-*,
M`0`+````[(P!``L```#XC`$``P````2-`0`%````"(T!``D````.C0$`$```
M`!B-`0`2````*8T!`!$````\C0$`"@```$Z-`0`/````68T!``X```!IC0$`
M#````'B-`0`$````A8T!``<```"*C0$`(````)*-`0`A````LXT!`!<```#5
MC0$`#P```.V-`0`2````_8T!`!`````0C@$`(@```"&.`0`'````1(X!``D`
M``!,C@$`#P```%:.`0`/````9HX!``D```!VC@$`!0```(".`0`*````AHX!
M``4```"1C@$`$P```)>.`0`,````JXX!``8```"XC@$`*0```+^.`0`.````
MZ8X!`(,```#XC@$`$0```'R/`0`+````CH\!``4```":CP$`#0```*"/`0`&
M````KH\!``@```"UCP$`!@```+Z/`0`1````Q8\!``,```#7CP$`!P```-N/
M`0`&````XX\!`!0```#JCP$`#P```/^/`0`2````#Y`!`!P````BD`$``@``
M`#^0`0`%````0I`!`!(```!(D`$`"0```%N0`0`-````99`!``4```!SD`$`
M(````'F0`0`(````FI`!``8```"CD`$`&@```*J0`0`-````Q9`!``<```#3
MD`$`"````-N0`0`$````Y)`!``D```#ID`$`#0```/.0`0`.`````9$!``(`
M```0D0$`!@```!.1`0`,````&I$!`!,````GD0$`$````#N1`0`&````3)$!
M`!(```!3D0$`"@```&:1`0`'````<9$!`!<```!YD0$`*0```)&1`0!*````
MNY$!`"<````&D@$`*0```"Z2`0`&````6)(!``D```!?D@$`!````&F2`0`)
M````;I(!``@```!XD@$`%P```(&2`0`0````F9(!``4```"JD@$`#````+"2
M`0`&````O9(!``0```#$D@$`00```,F2`0!"````"Y,!`$$```!.DP$`(0``
M`)"3`0`%````LI,!``X```"XDP$`!P```,>3`0`)````SY,!``D```#9DP$`
M&P```..3`0`0````_Y,!`!4````0E`$`!@```":4`0`%````+90!``\````S
ME`$`"@```$.4`0`*````3I0!`!X```!9E`$`!````'B4`0`'````?90!`"0`
M``"%E`$`!@```*J4`0`4````L90!`!$```#&E`$`$````-B4`0`(````Z90!
M``D```#RE`$`!0```/R4`0`[`````I4!`#8````^E0$`0P```'65`0`I````
MN94!`$(```#CE0$`0@```":6`0`K````:98!`$H```"5E@$`+P```."6`0`Y
M````$)<!`"\```!*EP$`$````'J7`0`1````BY<!``L```"=EP$`+0```*F7
M`0`I````UY<!`"$````!F`$`*````".8`0`'````3)@!``D```!4F`$`"@``
M`%Z8`0`'````:9@!`"0```!QF`$`)@```):8`0`M````O9@!``L```#KF`$`
M&P```/>8`0`M````$YD!`!@```!!F0$`$P```%J9`0`(````;ID!``X```!W
MF0$`#@```(:9`0`.````E9D!`!,```"DF0$`1````+B9`0!^````_9D!`'$`
M``!\F@$`&P```.Z:`0`-````"IL!``X````8FP$`$0```">;`0`2````.9L!
M``\```!,FP$`!P```%R;`0`2````9)L!`!,```!WFP$`$@```(N;`0`3````
MGIL!`"@```"RFP$`'@```-N;`0"$````^IL!`!(```!_G`$`!0```)*<`0`4
M````F)P!``D```"MG`$`"@```+><`0`*````PIP!`!\```#-G`$`%````.V<
M`0`.`````IT!``X````1G0$`$P```""=`0`5````-)T!`"0```!*G0$`)@``
M`&^=`0`C````EIT!`"4```"ZG0$`(0```."=`0`C`````IX!`!T````FG@$`
M10```$2>`0`3````BIX!`!0```">G@$`$P```+.>`0`4````QYX!`!$```#<
MG@$`%@```.Z>`0`7````!9\!`!(````=GP$`$P```#"?`0`\````1)\!`!8`
M``"!GP$`%````)B?`0`^````K9\!`!4```#LGP$`#@````*@`0`1````$:`!
M`"T````CH`$`$P```%&@`0`3````9:`!`"````!YH`$`'0```)J@`0`?````
MN*`!`!T```#8H`$`&P```/:@`0`A````$J$!`!P````TH0$`(P```%&A`0`A
M````=:$!`"````"7H0$`(````+BA`0`=````V:$!`!,```#WH0$`&P````NB
M`0`=````)Z(!`!L```!%H@$`&````&&B`0`*````>J(!`!````"%H@$`&@``
M`):B`0`&````L:(!``<```"XH@$`#0```,"B`0`4````SJ(!``8```#CH@$`
M!P```.JB`0`'````\J(!``8```#ZH@$`!P````&C`0`'````":,!``4````1
MHP$`%0```!>C`0`&````+:,!``@````THP$`!0```#VC`0`%````0Z,!``H`
M``!)HP$`$0```%2C`0`*````9J,!`!(```!QHP$`$0```(2C`0`+````EJ,!
M`!(```"BHP$`!@```+6C`0`J````O*,!`!$```#GHP$`$````/FC`0`:````
M"J0!`!`````EI`$`#0```#:D`0`,````1*0!`"\```!1I`$`"````(&D`0`(
M````BJ0!`"@```"3I`$`%````+RD`0`0````T:0!``8```#BI`$`"P```.FD
M`0`'````]:0!``8```#]I`$`(0````2E`0`-````)J4!`!`````TI0$`#0``
M`$6E`0`3````4Z4!`!````!GI0$`'P```'BE`0`3````F*4!``<```"LI0$`
M`P```+2E`0`&````N*4!`!\```"_I0$`!@```-^E`0`(````YJ4!`!(```#O
MI0$`$P````*F`0`&````%J8!``0````=I@$`!P```"*F`0`6````*J8!``T`
M``!!I@$`#0```$^F`0`+````7:8!`!0```!II@$`%@```'ZF`0`7````E:8!
M`!D```"MI@$`"@```,>F`0`-````TJ8!``8```#@I@$`!````.>F`0`1````
M[*8!`#L```#^I@$`!0```#JG`0`/````0*<!`"$```!0IP$`%@```'*G`0`7
M````B:<!``X```"AIP$`#````+"G`0`)````O:<!``<```#'IP$`"@```,^G
M`0`)````VJ<!``X```#DIP$`$````/.G`0`@````!*@!`"$````EJ`$`)P``
M`$>H`0`*````;Z@!``@```!ZJ`$`#0```(.H`0`,````D:@!`!(```">J`$`
M!@```+&H`0`(````N*@!`"<```#!J`$`"P```.FH`0`(````]:@!`!(```#^
MJ`$`/````!&I`0`/````3JD!``L```!>J0$`!````&JI`0`%````;ZD!`!L`
M``!UJ0$`'````)&I`0`<````KJD!``H```#+J0$``@```-:I`0`$````V:D!
M`"$```#>J0$``P````"J`0`%````!*H!`"D````*J@$`"@```#2J`0`&````
M/ZH!``<```!&J@$`&````$ZJ`0`.````9ZH!``8```!VJ@$`!P```'VJ`0`(
M````A:H!``0```".J@$`!0```).J`0`\````F:H!`!````#6J@$`$P```.>J
M`0`5````^ZH!``4````1JP$`!@```!>K`0`>````'JL!`#,````]JP$`#@``
M`'&K`0`)````@*L!`!8```"*JP$`"@```*&K`0`(````K*L!`!D```"UJP$`
M+````,^K`0`I````_*L!`"@````FK`$`(0```$^L`0`.````<:P!``0```"`
MK`$`!P```(6L`0`(````C:P!``<```"6K`$`#0```)ZL`0`/````K*P!``@`
M``"\K`$`5P```,6L`0`2````':T!`!`````PK0$`"P```$&M`0`;````3:T!
M`%````!IK0$`'0```+JM`0`&````V*T!`!T```#?K0$`)P```/VM`0`'````
M):X!``8````MK@$`(````#2N`0`$````5:X!``D```!:K@$`*0```&2N`0`H
M````CJX!`"<```"WK@$`!P```-^N`0`(````YZX!`"(```#PK@$`60```!.O
M`0`8````;:\!`"8```"&KP$`%@```*VO`0`#````Q*\!``T```#(KP$`!P``
M`-:O`0`/````WJ\!``L```#NKP$`!@```/JO`0`5`````;`!``8````7L`$`
M"````!ZP`0`)````)[`!``L````QL`$`"@```#VP`0`,````2+`!`#T```!5
ML`$`"````).P`0`2````G+`!`!0```"OL`$`%P```,2P`0`,````W+`!`!``
M``#IL`$`#P```/JP`0`+````"K$!``8````6L0$`!0```!VQ`0`*````([$!
M`"4````NL0$`%P```%2Q`0`0````;+$!``L```!]L0$`$````(FQ`0`*````
MFK$!`!0```"EL0$`"````+JQ`0`4````P[$!``0```#8L0$`!P```-VQ`0`%
M````Y;$!``4```#KL0$`!P```/&Q`0`3````^;$!`!0````-L@$`(@```"*R
M`0`B````1;(!`!P```!HL@$`'````(6R`0`@````HK(!`"4```##L@$`'P``
M`.FR`0`$````";,!``4````.LP$`#@```!2S`0`.````([,!`!4````RLP$`
M"````$BS`0`7````4;,!``T```!ILP$`"@```'>S`0`:````@K,!`!\```"=
MLP$`%````+VS`0`(````TK,!`!(```#;LP$`!P```.ZS`0`0````]K,!``\`
M```'M`$`"````!>T`0`)````(+0!``4````JM`$`!P```#"T`0`%````.+0!
M``0````^M`$``P```$.T`0!!````1[0!`#4```")M`$`%P```+^T`0`I````
MU[0!`#D````!M0$`$@```#NU`0`X````3K4!`#@```"'M0$`/0```,"U`0`]
M````_K4!`$(````\M@$`&````'^V`0`9````F+8!`!8```"RM@$`&````,FV
M`0`@````XK8!`"`````#MP$`&P```"2W`0`9````0+<!`!L```!:MP$`%```
M`':W`0`Q````B[<!`#$```"]MP$`-0```.^W`0`R````);@!`#,```!8N`$`
M,````(RX`0!W````O;@!`!D````UN0$`%@```$^Y`0`*````9KD!`"(```!Q
MN0$`"0```)2Y`0`3````GKD!`#0```"RN0$`)0```.>Y`0`@````#;H!``L`
M```NN@$`40```#JZ`0!-````C+H!``<```#:N@$`%P```.*Z`0`5````^KH!
M``P````0NP$`$````!V[`0`6````+KL!``<```!%NP$`"````$V[`0`)````
M5KL!`!(```!@NP$`$0```'.[`0`/````A;L!``X```"5NP$`"0```*2[`0`8
M````KKL!``@```#'NP$`!@```-"[`0`4````U[L!`!$```#LNP$`$````/Z[
M`0!"````#[P!``(```!2O`$`!@```%6\`0`1````7+P!``4```!NO`$`!P``
M`'2\`0`/````?+P!``H```",O`$`*@```)>\`0`,````PKP!`!X```#/O`$`
M`P```.Z\`0`W````\KP!`!@````JO0$`*````$.]`0"&````;+T!`!@```#S
MO0$`00````R^`0`A````3KX!`!,```!PO@$`!@```(2^`0`,````B[X!``X`
M``"8O@$`"P```*>^`0`6````L[X!``L```#*O@$`'````-:^`0`6````\[X!
M``4````*OP$`$@```!"_`0`:````([\!`"4````^OP$`$P```&2_`0`6````
M>+\!`!P```"/OP$`$0```*R_`0`F````OK\!``H```#EOP$`%````/"_`0`6
M````!<`!`!`````<P`$`$@```"W``0`/````0,`!`!(```!0P`$`#P```&/`
M`0`5````<\`!`!X```")P`$`%0```*C``0`&````OL`!``D```#%P`$`!0``
M`,_``0`=````U<`!``8```#SP`$`$````/K``0`(````"\$!`!0````4P0$`
M!0```"G!`0`;````+\$!``\```!+P0$`+0```%O!`0`5````B<$!``8```"?
MP0$`!P```*;!`0`8````KL$!``4```#'P0$`'@```,W!`0`$````[,$!`!0`
M``#QP0$`!P````;"`0`+````#L(!`"`````:P@$`+0```#O"`0`)````:<(!
M`!P```!SP@$`$````)#"`0`*````H<(!`!L```"LP@$`%````,C"`0`$````
MW<(!`!0```#BP@$`"0```/?"`0`(`````<,!``4````*PP$`"````!##`0`&
M````&<,!``8````@PP$`(0```"?#`0`W````2<,!`#\```"!PP$`(@```,'#
M`0`P````Y,,!`"@````5Q`$`10```#[$`0`B````A,0!`"@```"GQ`$`)0``
M`-#$`0!5````]L0!`"H```!,Q0$`!P```'?%`0`(````?\4!``<```"(Q0$`
M"````)#%`0`4````F<4!`!0```"NQ0$`,````,/%`0`M````],4!`!@````B
MQ@$`-0```#O&`0`]````<<8!``<```"OQ@$`&0```+?&`0`)````T<8!`!``
M``#;Q@$`(@```.S&`0`1````#\<!`!(````AQP$`#0```#3'`0`(````0L<!
M`!4```!+QP$`"````&''`0`+````:L<!``T```!VQP$`&@```(3'`0`-````
MG\<!`#P```"MQP$`"@```.K'`0`%````]<<!``D```#[QP$`!0````7(`0`:
M````"\@!`!$````FR`$`!0```#C(`0`.````/L@!`!````!-R`$`$0```%[(
M`0`,````<,@!``\```!]R`$`#P```(W(`0`'````G<@!``,```"ER`$`#0``
M`*G(`0`Z````M\@!`$X```#RR`$`%0```$')`0`)````5\D!`"8```!AR0$`
M'0```(C)`0`%````ILD!`!4```"LR0$``P```,+)`0`+````QLD!`!(```#2
MR0$`*@```.7)`0`'````$,H!``T````8R@$`#@```";*`0`2````-<H!``L`
M``!(R@$`.P```%3*`0`)````D,H!`!P```":R@$`#P```+?*`0`3````Q\H!
M`#\```#;R@$`+@```!O+`0`Y````2LL!`#H```"$RP$`-@```+_+`0`1````
M]LL!``8````(S`$`$`````_,`0`0````(,P!``T````QS`$`"@```#_,`0`1
M````2LP!`!T```!<S`$`!P```'K,`0`5````@LP!`!H```"8S`$`"````+/,
M`0`'````O,P!`!$```#$S`$`$@```-;,`0`9````Z<P!``8````#S0$`!P``
M``K-`0`/````$LT!`!4````BS0$`%````#C-`0`5````3<T!`!4```!CS0$`
M!P```'G-`0`&````@<T!`#$```"(S0$`)P```+K-`0`F````XLT!``@````)
MS@$`#P```!+.`0`&````(LX!`!\````IS@$`(0```$G.`0`F````:\X!``L`
M``"2S@$`%````)[.`0`F````L\X!``,```#:S@$`!P```-[.`0`5````YLX!
M``,```#\S@$`#`````#/`0`1````#<\!``L````?SP$`%````"O/`0`8````
M0,\!`!0```!9SP$`!0```&[/`0`*````=,\!`!,```!_SP$`%````)//`0`.
M````J,\!``8```"WSP$`"0```+[/`0`)````R,\!``T```#2SP$`6@```.#/
M`0`6````.]`!`#4```!2T`$`%````(C0`0`'````G=`!``D```"ET`$`%```
M`*_0`0`5````Q-`!`!(```#:T`$`(0```.W0`0`8````#]$!`!4````HT0$`
M(P```#[1`0`0````8M$!`"<```!ST0$`$P```)O1`0`5````K]$!`'````#%
MT0$`(0```#;2`0`<````6-(!`"T```!UT@$`(0```*/2`0`<````Q=(!`"8`
M``#BT@$`'P````G3`0`?````*=,!`!P```!)TP$`"@```&;3`0`'````<=,!
M``@```!YTP$`"````(+3`0`3````B],!``\```"?TP$`+0```*_3`0`7````
MW=,!`!4```#UTP$`!P````O4`0`'````$]0!`$\````;U`$`20```&O4`0`^
M````M=0!`&8```#TU`$`#````%O5`0`R````:-4!`#````";U0$`"0```,S5
M`0`'````UM4!``8```#>U0$`0````.75`0`&````)M8!`$`````MU@$`-```
M`&[6`0`C````H]8!``X```#'U@$`+0```-;6`0`<````!-<!`#,````AUP$`
M*````%77`0`R````?M<!`"@```"QUP$`#0```-K7`0`&````Z-<!``\```#O
MUP$`$@```/_7`0`5````$M@!``<````HV`$`0@```##8`0`*````<]@!``D`
M``!^V`$`"@```(C8`0`7````D]@!``D```"KV`$`!P```+78`0`2````O=@!
M``H```#0V`$`"0```-O8`0`$````Y=@!``<```#JV`$`"````/+8`0`/````
M^]@!`!0````+V0$`%@```"#9`0`=````-]D!``T```!5V0$`!P```&/9`0`0
M````:]D!``\```!\V0$`$@```(S9`0`-````G]D!`!@```"MV0$`*````,;9
M`0`.````[]D!`!\```#^V0$`*0```![:`0`)````2-H!``L```!2V@$`%```
M`%[:`0`'````<]H!``0```![V@$`'P```(#:`0`.````H-H!``X```"OV@$`
M#0```+[:`0`(````S-H!``D```#5V@$`!@```-_:`0`)````YMH!``L```#P
MV@$`$P```/S:`0`(````$-L!`!@````9VP$`"P```#+;`0`'````/ML!`!X`
M``!&VP$`)@```&7;`0`,````C-L!``,```"9VP$`(0```)W;`0`'````O]L!
M``8```#'VP$`=````,[;`0`*````0]P!``<```!.W`$`)P```%;<`0!`````
M?MP!`!H```"_W`$`)0```-K<`0!$`````-T!`"D```!%W0$`/0```&_=`0`;
M````K=T!`!8```#)W0$`!0```.#=`0`&````YMT!``D```#MW0$`"@```/?=
M`0`*`````MX!``D````-W@$`%````!?>`0`+````+-X!``H````XW@$`#```
M`$/>`0`,````4-X!``<```!=W@$`"````&7>`0`)````;MX!`!0```!XW@$`
M"P```(W>`0`&````F=X!``4```"@W@$`"P```*;>`0`&````LMX!`"8```"Y
MW@$`&````.#>`0`*````^=X!`!8````$WP$`"P```!O?`0`4````)]\!``L`
M```\WP$`!@```$C?`0`6````3]\!``8```!FWP$`%@```&W?`0`&````A-\!
M`!H```"+WP$`"P```*;?`0`6````LM\!``4```#)WP$`!P```,_?`0`2````
MU]\!`"````#JWP$`"P````O@`0`-````%^`!`"T````EX`$`&P```%/@`0`8
M````;^`!``4```"(X`$`#0```([@`0`4````G.`!`!<```"QX`$``P```,G@
M`0`3````S>`!``D```#AX`$`(P```.O@`0`I````#^$!`#,````YX0$`)0``
M`&WA`0`T````D^$!`"<```#(X0$`:0```/#A`0`7````6N(!`&<```!RX@$`
M0@```-KB`0!4````'>,!`&X```!RXP$`+0```.'C`0`[````#^0!`#,```!+
MY`$`.````'_D`0`N````N.0!`!L```#GY`$`-`````/E`0#7`0``..4!`!\`
M```0YP$`%P```##G`0!*````2.<!`'<```"3YP$`,P````OH`0`E````/^@!
M`$$```!EZ`$`7````*?H`0!:````!.D!`"H```!?Z0$`(P```(KI`0`6````
MKND!`"@```#%Z0$`'0```.[I`0`:````#.H!`"T````GZ@$`)0```%7J`0`E
M````>^H!`#H```"AZ@$`(P```-SJ`0`6`````.L!`#@````7ZP$`)0```%#K
M`0`J````=NL!`"T```"AZP$`'P```,_K`0`X````[^L!`&T````H[`$`,0``
M`);L`0!"````R.P!`"X````+[0$`)P```#KM`0!`````8NT!`&,```"C[0$`
M2`````?N`0`N````4.X!`"X```!_[@$`,````*[N`0!?````W^X!`&\````_
M[P$`6````*_O`0!9````"/`!`#4```!B\`$`*@```)CP`0`J````P_`!`"\`
M``#N\`$`:P```![Q`0!Q````BO$!`'$```#\\0$`N0```&[R`0`9````*/,!
M`"\```!"\P$`,````'+S`0`M````H_,!`%(```#1\P$`)0```"3T`0!3````
M2O0!`"(```">]`$`"@```,'T`0#8````S/0!`%@```"E]0$`(P```/[U`0`X
M````(O8!`"@```!;]@$`'@```(3V`0`Y````H_8!``0```#=]@$`"````.+V
M`0`$````Z_8!`!D```#P]@$`#P````KW`0`/````&O<!``L````J]P$`!@``
M`#;W`0`/````/?<!``0```!-]P$`6````%+W`0`$````J_<!`!<```"P]P$`
M!````,CW`0`'````S?<!``8```#5]P$`!0```-SW`0`$````XO<!`!4```#G
M]P$`"0```/WW`0`1````!_@!`!,````9^`$``P```"WX`0`'````,?@!``<`
M```Y^`$`$@```$'X`0`-````5/@!`!0```!B^`$`!@```'?X`0`:````?O@!
M``T```"9^`$``P```*?X`0`K````J_@!``0```#7^`$`!@```-SX`0`'````
MX_@!`"$```#K^`$`0`````WY`0`Q````3OD!`#(```"`^0$`&P```+/Y`0`R
M````S_D!`#4````"^@$`)````#CZ`0`C````7?H!`!X```"!^@$`)````*#Z
M`0`?````Q?H!`!T```#E^@$`)0````/[`0`C````*?L!`!X```!-^P$`-```
M`&S[`0`<````H?L!`#$```"^^P$`,@```/#[`0`A````(_P!`"4```!%_`$`
M)````&O\`0`?````D/P!`"0```"P_`$`*@```-7\`0`H`````/T!`"H````I
M_0$`)@```%3]`0`?````>_T!`"(```";_0$`*P```+[]`0`=````ZOT!`"0`
M```(_@$`+P```"W^`0`R````7?X!`!H```"0_@$`)P```*O^`0`\````T_X!
M`"0````0_P$`)@```#7_`0`E````7/\!`"8```""_P$`(````*G_`0`>````
MRO\!`"<```#I_P$`(P```!$``@`N````-0`"`"<```!D``(`+@```(P``@`*
M````NP`"`!,```#&``(`%@```-H``@`S````\0`"`"8````E`0(`#0```$P!
M`@`/````6@$"`!8```!J`0(`"P```($!`@`.````C0$"`"P```"<`0(`"```
M`,D!`@`,````T@$"`"<```#?`0(`*@````<"`@`@````,@("`!\```!3`@(`
M'````',"`@`(````D`("`-0```"9`@(`#0```&X#`@`6````?`,"``D```"3
M`P(`#0```)T#`@`1````JP,"`!````"]`P(`'P```,X#`@`&````[@,"`$L`
M``#U`P(`'````$$$`@`<````7@0"``<```![!`(`$@```(,$`@`,````E@0"
M`#8```"C!`(`"````-H$`@`G````XP0"`!D````+!0(`$@```"4%`@`4````
M.`4"`#(```!-!0(`'P```(`%`@`'````H`4"`!<```"H!0(`"````,`%`@`)
M````R04"`!0```#3!0(`"P```.@%`@`;````]`4"``8````0!@(`*@```!<&
M`@`(````0@8"`",```!+!@(`*P```&\&`@`'````FP8"`!<```"C!@(`!P``
M`+L&`@`(````PP8"``D```#,!@(`/@```-8&`@`&````%0<"`!(````<!P(`
M%````"\'`@`/````1`<"``D```!4!P(`"@```%X'`@`&````:0<"`!,```!P
M!P(`!@```(0'`@`A````BP<"`!(```"M!P(`&0```,`'`@`5````V@<"``P`
M``#P!P(`#@```/T'`@`:````#`@"``<````G"`(`+0```"\(`@`,````70@"
M``\```!J"`(`!P```'H(`@`#````@@@"`!$```"&"`(`'````)@(`@`+````
MM0@"``,```#!"`(`"````,4(`@`,````S@@"``D```#;"`(`#P```.4(`@`-
M````]0@"`!8````#"0(`%P```!H)`@`0````,@D"`"\```!#"0(`'0```',)
M`@`<````D0D"`!H```"N"0(`"P```,D)`@`P````U0D"``<````&"@(`%P``
M``X*`@!%````)@H"`!$```!L"@(`$@```'X*`@`(````D0H"``0```":"@(`
M!0```)\*`@`1````I0H"`!H```"W"@(`!@```-(*`@`'````V0H"``D```#A
M"@(`$````.L*`@`(````_`H"`!(````%"P(`#@```!@+`@!%````)PL"`#8`
M``!M"P(`*0```*0+`@`%````S@L"`!D```#4"P(`)````.X+`@`B````$PP"
M`"@````V#`(`$````%\,`@`"````<`P"``0```!S#`(`"P```'@,`@`*````
MA`P"``4```"/#`(``P```)4,`@`0````F0P"`$\```"J#`(`,P```/H,`@`:
M````+@T"`"L```!)#0(`+P```'4-`@!3````I0T"`!8```#Y#0(`A0```!`.
M`@`D````E@X"`$(```"[#@(`)0```/X.`@!'````)`\"`"L```!L#P(`,P``
M`)@/`@`N````S`\"`"X```#[#P(`,````"H0`@`P````6Q`"`"T```",$`(`
M,@```+H0`@`T````[1`"`#<````B$0(`%@```%H1`@`@````<1$"`!````"2
M$0(`?````*,1`@`(````(!("`'`````I$@(`<@```)H2`@"`````#1,"`"8`
M``".$P(`7@```+43`@`7````%!0"`",````L%`(`%@```%`4`@`2````9Q0"
M`!0```!Z%`(`'````(\4`@!`````K!0"`!X```#M%`(`&0````P5`@!0````
M)A4"`!(```!W%0(`&````(H5`@`*````HQ4"``4```"N%0(`!@```+05`@`(
M````NQ4"``4```#$%0(`%@```,H5`@`7````X14"`!8```#Y%0(`(0```!`6
M`@`0````,A8"``X```!#%@(`!````%(6`@`)````5Q8"``\```!A%@(`!P``
M`'$6`@`&````>18"`!H```"`%@(`"0```)L6`@`,````I18"`!````"R%@(`
M!P```,,6`@`+````RQ8"`!````#7%@(`"P```.@6`@`:````]!8"``D````/
M%P(`%0```!D7`@`5````+Q<"``8```!%%P(`!0```$P7`@`C````4A<"`!D`
M``!V%P(`"P```)`7`@`C````G!<"`!0```#`%P(`*P```-47`@`9`````1@"
M``8````;&`(`%P```"(8`@`%````.A@"``<```!`&`(`&P```$@8`@`%````
M9!@"``(```!J&`(``@```&T8`@`;````<!@"``@```",&`(`"P```)48`@`5
M````H1@"`!@```"W&`(`!P```-`8`@`S````V!@"``(````,&0(`!`````\9
M`@`0````%!D"`!8````E&0(`#@```#P9`@`+````2QD"``D```!7&0(`!@``
M`&$9`@`8````:!D"``@```"!&0(`%````(H9`@`1````GQD"`!(```"Q&0(`
M`@```,09`@`'````QQD"``\```#/&0(`$````-\9`@`0````\!D"`"P````!
M&@(`"0```"X:`@`(````.!H"`!(```!!&@(`!0```%0:`@`"````6AH"``L`
M``!=&@(``0```-`$```:!```+@4``%T#````````G`$``&L"``">!```````
M`)(#``#%`0``^`8``'P``````````````(0"```F!P``"P$```````!^!P``
MP0```'0%```3!```[@4``"P```#8`P``O@8``"`'```&`@``_P,``+D%``#_
M!@``+P,```````"D`@``[04``&("``"P`@``#00``'\#````````````````
M````````TP0``$X%``"#!`````````````#T`0``;@(`````````````?0(`
M`"P$````````(P$``*$%````````7P<``.$%``",!@``)0$``&T&``#R!```
M;`(``'`!```P!P``P`$``,\"```M!```;0,``$L'``!:````H@$``#,!``"&
M!P```````'L!``#K````DP8``+T%``!9!P``1P4``,D&````````D@0``&`"
M``#R````)P(``&0"````````V`0``($&``#;!0````````````"E````````
M````````````E@,```````!`````X08```````#+`0```````,L%``!&`@``
MO`4```````#[`@``A0<````````)!0```````$T$``#)!0``Z@(``",%```7
M`````````#0```!8````NP$`````````````LP(``%@$``!C`P``:`,``%\!
M````````````````````````^`$``&(#``!O````U`$```````!Z!@``````
M``4'``"0`````````$L#``"9`@```````!H#``!:!@``\@$``-\````F`P``
MV@$``,X!``"T`P``10,````````8!P``#@<``",#``#Q````K04``,\$````
M`````````*D#``"D`````````,@%``!?`P``=P,``),$```(!````````(<&
M``"^`0```````-X$``!U!P``U@,``.4!````````_`4``$<'``"I`0``5@0`
M`.(!````````3P```)L$```````````````````M`P``:0<```````"R````
M`````)4%``!E!```H08``.`!``"N!@```````"H```#Y`0``:`$``%$'``#7
M`P``)@8``*$$``!1!@``5`0``*P&````````FP(``%L```"/!@``B0,``*D`
M````````J04``-,```">`P``>@$``&4"``#``P``)0<``'D#```K````````
M`#8``````````````"\"``"#````X00```````#S!```=P0``$$'````````
M]P``````````````D0(``+<%````````%`4``*@#```I`@``=P<```````!R
M!```.0(`````````````C@(``(X!``"(!```W````'D'``!4!0``F`,```$"
M```X!P``7`,```8!````````0P0````````J!P``G0,``*4!````````````
M`&0%``!Q`0````````````!`!@``VP```#H'``!*```````````"````````
M*0$```````!4`P```````)H$````````R@$``%\$```4`P```````"4$``!A
M```````````````C!```=P```.L#``!C!@```````)D&``#]!0``>P``````
M```6!@``KP0```,`````!P``V@4``+0&``#'`P``>@(``!,'``#L````````
M``````!C`0```````.P"``":````D@```)P#````````FP$``"@%``!O`@``
M\`,``$0#``"\`@``N0$``-H$``#3!@``L@,``.`$``#'!```J`0````````5
M!P``%0(``+T$```8`0``KP(`````````````WP,``(T"````````?@$``/L%
M``!I`0``%`8``/8!```H`P``20,``'`#``!%!```E@$``$<```#&`0``;P,`
M`$L&```Z````708``%,```#2!@``=`(````````K!0``)`(``'`&``#M````
M"`8```0```#B`@``?`,``(`%``")`0``D00``/P"``!A!P``Y`4``!<!````
M````GP$```H'``!Y`@``?@````,$```&!P``*P8``#(&````````4`(``+\`
M````````=0,``/T#````````"P```#`%`````````````&,'```E!@``W0``
M``````#R`@``/`<```````#5`P``UP0`````````````:`````L"``!O!@``
M`````-`&``#"!@``<0```*````#Y!@``0`(```````"9!```MP,``,`````"
M!```#`8``$P!``"2`@``M@4``*`!``"_`0````````4`````````20<``-0"
M``!C`````````,0```````````````````#O!````````#T%``!L!P``````
M`,H&````````%0,``'X&`````````````$\%`````````````/`$``!U!```
MH`8``&T$```(````7@```$4'``"X`P``<P4``-X```""`P``(@0``#@%``#T
M!@``F@,``'4"````````:@$``#P"``"[!@``ZP4``+P$````````;`8`````
M``")````HP(````````Q!@```````!D'````````50$``"`$```X`0``````
M`&L$````````A0(``'8%``!]!0``U@`````````?`@``3`8``#4$```Q`@``
M``````````"5`P``_`0``/T&```%`P``9@8```````#O`0``Q@```.T#``"/
M````6`<`````````````Y`8``(,#`````````````-L"```L`P``5P$``/$&
M````````XP$``/X```!-````R@0```T%````````-@$``(X#``!]`0``EP``
M`%<$``!]!```<P```*0%``!6`@``@`(````````_!@``=@$``/P!````````
MY`0````````D`````````/4$``!I!````````%D!```?!```!@```)T"``!<
M`@`````````````!!@``D04```````#>!@``C`,``#X````K`0``$@(``-0#
M``".!@``/0<```````!J`P```````(P$``"C`````````,,#``!1````NP(`
M`"H$```>!```Y@0````````J!@``]`(``"P&``!5!0``````````````````
MIP(``"(#`````````````+,!````````?0```"4#````````;P<```````"/
M!````````,P!``#M!@``"`$````````````````````!``!)!0``-@8`````
M``#&!0``$0$``%T$``#X`P``G````*X#``#"`0```````',$``!O!```U0(`
M`,<%``!\`0``C`$``````````````````/H%```S!````````#L'``"B!@``
MS@,``*4&``#K`0``I@````````#M`@``````````````````JP0``.D!``#V
M!```W`,``"8$````````9`0``)\````-!@``MP0``.<#````````Q@0``%D"
M``"*!````````,("``"[!0``/P4``'$'``#3!0``D`8```````!@!P``````
M```````9!````````/$#``!4````V0````````!(````E@````````!4`@``
M-P```!T&```Z`@``<0(```````#Q`@````````8$``"U`@``HP0``'0'````
M````UP8``!4`````````U@0```````#\`````````!P%``"(!0``]0$``/0%
M``!Z`P``U08``+$%``"2!0````4```````````````````````"!!```O0(`
M`,P"```)!P``EP,``/T"````````\00``#T"``!3`0```````,,$```R`0``
M`````,D"``",``````````````!+`0````````````"W!@``"0$``-P!```D
M!```H@,``,H%``!S`0``,00```X&``")!```8@`````````O````G08``#8"
M``!7`@``?`<``$0'``"*!0``&0````````"M````[`,``,X&``!Y!0``,@``
M`+H%``#(`@```````/,&``"S!@``6`4``$0!`````````````!L"```;!P``
MV`8````````+!0```````&`!```W`@``00(``+H!``!^`P```````"H!``!&
M````S@(``!$&````````?P```$`#```R!P``+0$``"\$``#?`0```````,\%
M``"R`@``Y@$``%(#``#U`P``>P0```````"@`P``T@(``&`#``#H!0``````
M``````!?````'0(``#`#``#Z`@```````'$$````````?08``#0%```W!0``
M%@0```````!V````H0,```````"4!0``7P4``!`"``!L`0``(@$```````".
M`````````&<%````````P@4``!H!``#>`0```````)$#``"8`````````((%
M```8`````````"D%``"$!````````!P```"6!@``908``/D"``"%`0``````
M`$H#``!E!P``>`0```X$``!E````404``,$&``!R`@``X```````````````
MM0,``',#`````````````````````````````%P!````````-0<``'P"``!L
M``````````````"&`@```````,L&```)`@``#`4``&T!```K`@``W04``.4"
M``!-`P``#0$``&````!G`````````+P&``#7`@``M@8`````````````````
M`.H```"P!```*``````````L!P```````/,```"G!0``^P$``-($```:````
M````````````````8`0```````#%!@``7`8``$X`````````$0(`````````
M````2`0``!,&```C````/P```'\%``"F!```M@(``(X%``#D````0`0`````
M``"U!0``/@4``!\!``"X`0```````)@%````````M0```/X&```H!P``````
M``````"N!````````&8'``!X!0``9@```````````````````,L$```'`0``
M5`8`````````````W`8``%T'```[`0``.00``',"``#H!@``-P0``!P'``#Z
M!@``;@8```P!````````1`8``)H&``"Z!```8@8```8%``!"!P``````````
M````````<0,``(L```!V!P``T`,``/\!``"C`0``*@,```````"Q!```````
M`"$'``#_`@``Z0(``'````!J!@``V`````\&``!#`P``6@<``/`%``#E!@``
MS@0``#T#````````^`4``&('``"<!@``T`(```````!K`0``T0```(8&```P
M````Q@(``)\$``#J`0``X@```&@"``"F`0``6@(````````V`P```````%@&
M```I!```7@,``-X%````````SP```),%``#4!@``0P(`````````````E0$`
M````````````!`8``$,%``#[!@```````$<#``!I!0``4`<``-$!``"``0``
M``````````````````````````#Z!```:@0```0$```\`P``'00``-P$````
M````6@,``'P$```/`@``*08``,@$```9`P```````'L&``!U`````P,``)$!
M````````K``````````"`@``>0$``"<$```Q!P```````'H```!T````````
M``````!B`0``5`$```T````_`0``VP,``+$&```T!P`````````````F````
M````````````````A04``(T$````````1`0``/X%````````LP```%`!``"-
M!@``L@$``!0"``!.`@``A0,``&L'``#S`@``M@```.\&``#N`P``40$``-\$
M``#L!````````,P&````````+0(````````(!P``4`````````!2`@``````
M`$@&``!_`@```````!D&````````\`8``(@&``"[````608```````#W`0``
MA````$,&````````=0$`````````````0@(``$@!```3`P```````"0!``!7
M`P``]0```)<%``!0!0``V08``#D!```6!P```````(@!``!9!0``500``#X'
M``"8`@``.P,```\#``"K!0``20$```````"=!````````#X!``!J````>P4`
M`*4#``"D!@``(`````````"N````2P```!(```"D!````0$``'4&````````
MTP$``+H```#A`P``M@$`````````````9@0`````````````O@```+D```!P
M!````````!$```!<!0``XP0``!X#``"K`0``Y@```"`"``";!@``O`$``/`!
M```W!@``?P8```````"!````$`0``+D"```[!```?P$``!L```"Q`@``````
M`+L#``!R!0``8P(``(4`````````RP(``,`&``!\!0```````%4"``"<!0``
M[@$``*L#````````AP4``'(!``"Q````?P0```````#L!@````````T'``!M
M`@```````.H#````````#@(``!0!```K`P``0@0```````!_!P``W0(`````
M``!X!@``1@4```````#8!0``A00```````!;!P``]0(``*T$```#`@``````
M`"$```#Y!0``=P$``#H#```'!@``\04``.X"``!N!0``M@,```````#2`P``
MY@(``%4&````````>00``#\#````````*`(``)D%``##!0``UP4``%X%````
M`````````/P&``!W!0``10(``#P```"\```````````````-`P``````````
M```,!P``-`8``!($`````````````%\"```$!P``,0,```````!``0``.@4`
M``````"7!@````````````"'`0``R0```.8#``#@!@``O0```(L!``"[!```
M`````#0#```S`@``&@4```````"#!@``K`0```4"``#H!```O0,`````````
M`````````$<$``!-!@``LP0``'`%``#"`P```````&D#``#8`0``L`$`````
M``"0!0```````,8&``"?!0````````<#``![`P``$P````L$``##`0``"00`
M```````_`@``50```.`%````````J@,```$#```7!````P8`````````````
MYP0``.D%```(`P``I04``+4$```6````4@0``#<!``!2!0``H@(``/<"````
M````?@(``"`%``#Y`P``0P$``&@$`````````````#P%```3`0```````.\#
M``#$!```N@8```````!&`P```````,L#``!:!0``>@0``#H&``#Y````&P4`
M`$8!````````JP```%8!``#E!```C0````````#,`P``-08`````````````
MRP```(<```#:`P````````````#)!````````$X'````````%@4```````#D
M`P``,0```,H#``"&!0``$`$```X```!G!P``IP```,P$``!>!P``%08``-H`
M```A`0``H`(``)8"``!<!```*P0``!\'``!E`0``=@(``!`'```;!```U@4`
M`)H"``!=`````````-T$``!C!0``/`8``.0"````````KP4````````"`P``
M'`0```````````````````$%````````DP$``((&``!R`P``K0,``/8&````
M````D`0``(,"```;!@```````-D#````````6P$``%<'```2`P``[P(``"\'
M``!Q!0``I@,``%T!```H!@``````````````````JP8``-T#``!,`P``^00`
M`#8'``!V!````````"P%``!D!@``U````)X"``#W`P```````"4%``""!P``
MZ@4``'`"````````*0`````````$`@````````<'``#B!````````$X&````
M`````````",'``#_!0```````$0"``````````````````#5`0``S0```#4#
M```$`0```````"<'``!N!P``7P8```````!^!0``;@$``*T"``#"!```+`(`
M`%,$``````````````````"!!0``$00``(\"``!3!@``T@```*P#``!%!@``
M,P<``'@'````````S00``!@%````````N`0`````````````@@$`````````
M````(0(``%H!````````%P<``"X'```>`@``I@(``"('````````.`0``(<"
M``!K````[@8``#8%```\`0``#@4```````#B!0``B@```!P!``"I!```AP,`
M``,%````````'P4``%L"````````Z`$```````#W!````````-T!``!$!0``
M`````!`&``"(````YP(``#($``#B`P``J`4```H&``#%`P```````#T$````
M``````````````#H`@``GP,``/P#```5!0``,P```/,%``!S!P```````&L&
M````````R0,``&\!```<`P``5@4```````"&````@P$```````"T````C0,`
M`(($```N!```MP$``)<"``"=!0``M`(``.,"````````,`0``*$````J`@``
MQ@,```D#````````B04````````8!@``J@0``````````````````&@%````
M````U@$````````,!```!08````````E````W@,``)X``````````````&\%
M```<!@```````!4!```[!0``'0```,H"``";!0``A08``(P"```>!0``E`(`
M```````]!@``/@8``*$!``">!0``)0(`````````````+0```$8'``"3`@``
M4`0`````````````,@(``/4%``!T`0``6P,``#4!````````3`0``%,%``"@
M!```"0```,`%``"!`P```````%@!``!G`@``Z0,``!<"````````P`(``%8'
M``!!`P``.@0``)`!``#D`0``X`,``$\$`````````````*H"```,`@``&@(`
M`$X!``!&!```"@````````!)!@``^@$``"X```"-`0```````"D'``#K`@``
MYP$``,T!``!J`@````````````#8`@``P0(``"<```"Q`P``CP4```````!N
M````$`````````"+!```&P$``&X$``!R!P``_@(``-P%``!/!P``L`,```,'
M``"+`P```````(L"``!G`0``@`,``+T!``!S!@``;`0``*H```!,`@``804`
M``````"*`P``*P<``(`$````````N@,``#P$```6`@```````#4"``"0`P``
M@@```/X#```````````````````-`@``$P(``,(```"Y`P```````,T&```M
M!0``[@```+X%````````104```\'``!5!P````0``%X!`````````````-<!
M``!&!@``[@0``&D&```U!0``-P<``)H!``#A````N@(``+P#```4!```````
M``````"6!0``YP4``/(#````````/P<``!<#``#I!```DP,````#```&!@``
MB@8```````!H!@``7`<``"X!```C!@```````&$&``!G`P```````%L&``"S
M`P``"`(``$<"```?````"08``&0!`````````````$T"`````````````*,%
M```N!@``L0$```````#0`0``,@4``(8!``!<`````````#@&``#C`P``%P4`
M`+D$``"K`@```````(````!X`P``A`8``,4%``"`!@``VP$``#,#``#M`0``
M```````````,````E`,``&$"``"<`@``[P4``````````````````&($````
M`````````.D```"S!0``G@8````````>`0``OP,``#D&``!M!0``A`$``&D"
M````````2P0``.,&````````PP8``(\!````````PP```!H'````````800`
M`'`'````````"@4``#T!``!,!P``:P,``!\&``!$````$@<`````````````
MU@(``$D````Y`P``%00```````#O````9P8````````'!0``40,```0%```A
M!0``L@8``*<$```%!```1P$``$$&```````````````````=!0```````+``
M``"O````+08``.L&``#C`````````"`&```0`P``OP0``-8&````````````
M`'T#```*!```%@,``*P!`````````````-\&``#.`````````)(!``![!P``
MPP(``/\$````````-`$```````"H````+`$```P#````````C@0``!D!``"B
M````304```````#F!@``TP(```````````````````<$``"9`0``F0,``*H!
M```*`@``T@4``/(%``#S`0``"P,```````"=`0``Q0````````#$`@``5P``
M`#@````F`@````````````#[`P``I00``+@%````````OP4```````!/`0``
M'0$``.D&``#U!@``E`0``$X$````````K0$`````````````I`$``*8%``"N
M`@``8`8```````#3`P``$P4``*0#````````&`(``/T$````````@P<``'T'
M``#.!0``X0$``*D&``#A`@``O08``*D"``!N`P``C04``*\!````````T`4`
M`)\&````````L@4```````#,!0``:@4```````#V`@```````-H&````````
M`````!T#``!Z!P``L@0``*,&````````P04``*<!``!#````FP,``!D"````
M````2@0````````"`0``E0(``$P%```^`P``=@8``-H"````````0P<``&`%
M``!\!@``0@,``.4```!*!0``OP8```````````````````````#0````60,`
M`+<```!W`@``0`4```````!/!@``U`4``$@"```]````*@4```````!W!@``
MW@(``%X$```8`P``````````````````P00```````#1`P``X`(``'8#``"4
M````A`<``!@$````````````````````````/P0``!<&`````````````$T'
M````````)P,``/T```!5`P`````````````>!P``3P,``#@"``"3````\0$`
M`%,"````````]@,```L&````````EP0```````!"`0``70(``$D$``!(!P``
M:P4``*\#````````@@(``$H&````````)@$```````#9`0```````*X%``!M
M!P``V00``&8%``"P!@``)`4``#D'``!`!P``2`,``&<$``#-`P```````&8"
M``"L!0``?@0``'0#``#/`P``3@,``)@!``#?`@``2@(``,`$````````A@0`
M`&@'``!R````````````````````^`(````````O!0``9@,```('```A`P``
M>08```````#E`P``E00``+4!``#'!@``S0(``"@!``"7`0``R0$```````!3
M!P``40(``%@#``"#!0```````"X"``#X````F0````````#,````K`(``#$%
M````````UP````````"B!0``````````````````(@8``)4&``#L`0``'P,`
M`#L```"4!@``00$``,0#``"*`@```0<``!(%``!B!0``````````````````
M(`,``(@"```>````@`<``%('``"J!0``10```'(&```V!```P0$``-(!``!"
M````8P0``"0'``!L!0``\@8``%8````.`0``]P4``$L"``#[!```6`(``*`%
M```"!@``Y@4``"(```!"!0```````$<&``"6!```F`8``+\"```!!```````
M``````"Y!@``;`,``!(&``#J!@```````'H%``#H````,@,``%<%```/!0``
M#P$``!P"````````904````````O`0``.P(``$T!```P`0``(P(``-4`````
M````(@4``&0#``#V````>`(``(L&`````````````*$"````````K@$``/H#
M``!A`0``N````)$```````````````````"5````)`,```\`````````````
M`(@#````````>P(``,0%``#$`0```````(0#```=!P``G@$```````#9`@``
MQP$```H!``!3`P``>0```-$$``#!`P```````,@!```1`P``````````````
M````:@<``.T$``!T!```!@,````````[!@``U00```````"?`@``;0```(P%
M```4!P```````%0'```H!````@```%X"```9!0```````/8%``!+!0``````
M`,@````*`P``B0(```````"C`P``!04````````W`P``_0$```L'``!;!```
M!P(```````!,````F`0``,\!```F!0``Y04```````!X`````````&8!``#P
M````[`4``$D"``"T!0```@4```````!2````Z`,``$@%``#1!@``.0```,4$
M``":!0``O@(````````#`0``=`8``$$%``#;!@`````````````'````,P4`
M`"D#``#Z````Q`8``!$'````!@``R@```'@!```2`0``]`,``.,%``"G!@``
M400``%(!````````!`,``+<"``!*!P``%````(\#``"H`@``6@0``-0$```X
M`P``+@,``/0````^!````````-P"``"M!@````````````#9!0``7@8``+X#
M``#(`P``Z@0``%D$``"4`0``A@,``&0'``"!!P`````````````0!0``B08`
M`*($```M!P``B@$``$$$``";````'@8``/`"``!Q!@````````````"T!```
M``````X#``#G!@``704```````#X!```D08``-\%```G!@````````````#T
M!````````+@"````````M`$``$(&````````J@8``%(&```Y!0```````$$`
M```T!````````#`"````````_@0```````"+!0``&P,``*4"````````````
M`%`#```D!@``T04``/<&````````J`$``&$#```/!`````````````!0!@``
M)P$``+`%````````X@8``-$"````````A`4``($"``"U!@``5@,``($!````
M````ZP0``"("``#/!@```````#4```"X!@``QP(``*<#``!9`````````#$!
M````````W08``*\&```(!0``10$``%<&``"V!```,P8```````!6!@``````
M`&0````A!@``Q0(```````"=````_P````4!```^`@``AP0``&D```#5!0``
M(`$``)P$````````D`(``!$%````````.@$``,T%````````%@$```````!U
M!0``QP```,@&`````````````%L%```A!```\P,``"<%``#G````O@0``*8&
M```:!@``2@$``"\&``#^`0``90,``-L$```T`@````````````#[````J`8`
M`)(&``!/`@```````#`&````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@
M)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T
M97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@
M=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I
M8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@
M=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E
M<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@
M1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@
M:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN
M`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)
M($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R
M;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U
M;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO
M;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`
M061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE
M=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D
M<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T
M<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R
M9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D
M<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R
M:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I
M9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`
M07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!
M<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S
M+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@
M86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA
M;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I
M:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N
M;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!
M='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U
M=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB
M875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)
M34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H
M96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U
M<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@
M<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR
M86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`
M0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L
M:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T
M86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO
M="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV
M:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S
M`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`
M0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI
M<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T
M:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S
M(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O
M;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE
M("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O
M<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!2
M97!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G
M=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R
M>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N
M;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R
M96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`
M0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@
M27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I
M;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#
M96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E
M<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC
M871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L
M:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO
M=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT
M(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO
M;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U
M<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L
M:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@
M27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A
M<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U
M<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,
M871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO
M<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE
M8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY
M`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!0
M1$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`
M0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#
M;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A
M8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE
M.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O
M:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@
M240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK
M9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S
M(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N
M;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`
M0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO
M;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@
M4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@
M55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@
M8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U
M<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#
M>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`
M1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"
M<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T
M92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM
M86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O
M;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N
M<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`
M1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$
M96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@
M=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N
M`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO
M<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W
M('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`
M1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H
M879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S
M`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I
M<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@
M9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H
M:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@
M1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M
M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C
M871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%
M;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T
M:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R
M8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T
M;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H
M92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R
M90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN96$`
M17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@
M;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R
M<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R
M;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P
M('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA
M;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`
M17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T
M90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T
M;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@
M)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L
M86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI
M:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`
M1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`
M1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S
M`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U
M<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN
M;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``
M1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-
M;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'
M96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-
M87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/
M+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I
M;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@
M)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U
M<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!0
M97)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y
M86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`
M2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA
M;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@
M*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`
M2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO
M;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E
M<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R
M:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED
M:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D
M<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T
M('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA
M=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)
M8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF
M('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E
M('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),
M.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G
M92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O
M<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA
M=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD
M96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF
M;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS
M97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!)
M;G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C
M96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@
M8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R
M`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS
M97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@
M=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN
M<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@
M=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET
M+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I
M;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@
M87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A
M;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R
M96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S
M;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R
M>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`
M27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES
M<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A
M;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*
M=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I
M9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA
M;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R
M:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T
M:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E
M82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS
M=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@
M475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,
M87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`
M3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$
M<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN
M($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK
M`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H
M92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O
M;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A
M8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI
M=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES
M="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS
M(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I
M;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO
M9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA
M:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV
M97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E
M<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N
M9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I
M;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA
M>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@
M;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E
M.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-
M971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC
M;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE
M(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N
M`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y
M(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG
M;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0
M:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E
M>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D
M>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE
M('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`
M37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.
M3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S
M`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C
M87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`
M3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE
M=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O
M("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L
M86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B
M;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT
M(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`
M3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H
M;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R
M(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO
M8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD
M87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@
M8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M
M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET
M(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A
M9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO
M8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE
M('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E
M(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@
M8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S
M87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG
M;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E
M8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`
M3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)
M4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R
M90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.
M;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO
M="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R
M<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E
M;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO
M="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA
M<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE
M(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N
M97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD
M;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M
M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W
M('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@
M)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5
M;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`
M3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA
M=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L
M(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`
M4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`
M4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3
M;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO
M;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA
M=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U
M82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`
M4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R
M<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T
M:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S
M<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O
M;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C
M96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R
M;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!0
M97)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA
M;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO
M=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I
M;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@
M;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S
M<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E
M<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@
M=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL
M<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S
M:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R
M97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E
M=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO
M=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M
M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B
M;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI
M8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L
M>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O
M(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S
M`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L
M87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@
M0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E
M;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO
M9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z
M("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N
M9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W
M;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E
M<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2
M975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU
M97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P
M`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@
M<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-
M12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE
M<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!3
M35,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU
M92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L
M96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0
M:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N
M861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A
M;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@
M07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R
M8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@
M82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E
M<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N
M;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y
M('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E
M<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E
M;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@
M36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R
M(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I
M<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D
M92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L
M92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H
M;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U
M<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E
M<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y
M`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG
M;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO
M=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W
M97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R
M="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A
M`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H
M97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3
M<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T
M97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P
M;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`
M4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E
M="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@
M<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T
M(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N
M`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D
M("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L
M;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@
M(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@
M4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N
M<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U
M<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA
M;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,
M`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P
M=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T
M;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A
M8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I
M;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F
M;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E
M("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L
M92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S
M(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU
M;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T
M(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A
M=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE
M<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES
M(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R
M97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W
M<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE
M<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H
M92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA
M;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA
M<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N
M86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@
M86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4
M:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH
M86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D
M+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE
M9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE
M("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I
M9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P
M;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N
M`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E
M871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E
M8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN
M('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F
M<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG
M("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@
M>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R
M9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H
M:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES
M("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T
M:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&
M;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O
M<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H
M=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI
M;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O
M:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A
M;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4
M=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO
M=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN
M90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A
M9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N
M`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D
M96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@
M)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@
M`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A
M9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H
M86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&
M+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E
M9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@
M240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%
M>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D
M("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`
M57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U
M87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A
M8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A
M9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@
M<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI
M<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``
M5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@
M=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R
M:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N
M('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I
M8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG
M:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A
M;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S
M+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES
M:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@
M2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E
M8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E
M:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T
M;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T
M:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE
M9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H
M92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L
M>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES
M:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE
M+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R
M92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE
M+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R
M`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9
M;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E
M($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@
M=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R
M:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y
M.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I
M;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R
M96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B
M=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`
M6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI
M;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A
M=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E
M<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P
M=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A
M8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S
M964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T
M(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI
M;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT
M<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I
M871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A
M<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM
M<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P
M:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E
M('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(
M5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R
M>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N
M8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V
M+3`R+3$U(#$V.C4P+3`R,#`*3&%S="U4<F%N<VQA=&]R.B!&86)I;R!';VUE
M<R`\9FQG;VUS0'5O;"YC;VTN8G(^"DQA;F=U86=E+51E86TZ($)R87II;&EA
M;B!0;W)T=6=U97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S
M:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E3
M3RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E
M;F5R871O<CH@2T)A8F5L(#$N,RXQ"E!L=7)A;"U&;W)M<SH@(&YP;'5R86QS
M/3([('!L=7)A;#TH;B`^(#$I.PH`("@E<R!D:6%S(&%T<N%S*0`@*%1E8VQA
M(&1E($%T86QH;R`E<RD`("AE;2`E<R!D:6%S*0`@*&AO:F4I`"`H86UA;FCC
M*0`@*&]N=&5M*0`@82``(B5S(B!.XV\@Z2!U;2!D:7)E=/-R:6\N`"<E<R<@
M;N-O(.D@=6UA(&5S8V]L:&$@=N%L:61A+@`G)7,G(&[C;R!E<W3A(&-O;F9I
M9W5R861O(&YO(%)E9VES=')O(&1O($AO<F1E+@!R96YD97)I>F%D;W(@9&4@
MX7)V;W)E("(E<R(@;N-O(&5N8V]N=')A9&\N`"(E<R(@9F]I(&%D:6-I;VYA
M9&\@86\@<VES=&5M82!D92!G<G5P;W,N`"(E<R(@9F]I(&%D:6-I;VYA9&\@
M86\@<VES=&5M82!D92!P97)M:7-S]65S+@`B)R5S(B!NXV\@9F]I(&-R:6%D
M;SH@)7,N`"4N,F9-0B!U<V%D;W,@9&4E+C)F34(@<&5R;6ET:61O<R`H)2XR
M9B4E*0`E9"`E<R!E("5S`"5D(&1I87,@873I('-U82!S96YH82!E>'!I<F%R
M+@`E9"!P<F5V:7/C;R!D;R!D:6$`)7,@+2!!=FES;P!);7!R97-SXV\@1&EG
M:71A;"!D92`E<P`E<R!+0@`E<R!/<&5R8>?U97,@9&4@36%N=71E;N?C;R`M
M($-O;F9I<FUAY^-O`$-O;F9I9W5R8>?C;R!D92`E<P!#861A<W1R;R!D92`E
M<P`E<R!497)M;W,@9&\@06-O<F1O`"5S(&KA(&5X:7-T92X`)7,@82`E<R`E
M<P`E<R!E<W3A('!R;VYT;R!P87)A(&5X96-U=&%R(&%S(&]P97)AY_5E<R!D
M92!M86YU=&5NY^-O(&UA<F-A9&%S(&%B86EX;RX@36%R<75E(&$@8V%I>&$@
M<&%R82!Q=6%L<75E<B!O<&5R8>?C;R!Q=64@=F]CZB!Q=65I<F$@97AE8W5T
M87(@9&5S=&$@=F5Z+@`E<R#I(&]B<FEG873S<FEO`"5S(&UI;G5T;W,`)7,@
M;N-O(&5N8V]N=')A9&\N`"5S(&$@)7,@9&4@)7,`0V%TX6QO9V\@9&4@16YD
M97)EYV]S(&1E("5S`$%G96YD82!D92`E<P!!;F]T8>?U97,@9&4@)7,`3&ES
M=&$@9&4@5&%R969A<R!D92`E<P`E<SH@)7,`)7,Z($5S=&$@;65N<V%G96T@
M<&]D92!NXV\@<V5R(&1E('%U96T@96QA(&1I>B!S97(N(%1O;64@8W5I9&%D
M;R!C;VT@<75A;'%U97(@;&EN:R!P<F5S96YT92!N96QA(&]U(&5M(&9O<FYE
M8V5R(&%O(')E;65T96YT92!Q=6%L<75E<B!I;F9O<FUAY^-O('!E<W-O86PN
M`"P@8G)I<V$@`"P@8G)I<V$@)7,@)7,`+"!V87)IX79E;"!D92`E<R!P87)A
M("5S`"TM('-E;&5C:6]N92`M+0!&;W)M871O(#$R($AO<F%S`$9O<FUA=&\@
M,C0@2&]R87,`,C0@:&]R87,`/%#A9VEN82!!;G1E<FEO<@!5;2!C;VYE8W1O
M<B!D92!B86YC;R!D92!D861O<R#I(&]B<FEG873S<FEO('!A<F$@97-T92!B
M;&]C;RX`56T@97)R;R!F871A;"!O8V]R<F5U`%5M82!C:&%V92!P^F)L:6-A
M(%!'4"#I(&]B<FEG873S<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS
M86=E;2X`56UA(&-H879E('#Z8FQI8V$@4$=0(.D@;V)R:6=A=/-R:6$@<&%R
M82!V97)I9FEC87(@=6UA(&UE;G-A9V5M(&%S<VEN861A+@!5;6$@8VAA=F4@
M<')I=F%D82!01U`@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA<R!P87)A
M(&1E<V-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P<FEV
M861A(%!'4"!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S
M:6YA<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12P@
M=6UA(&-H879E('!R:79A9&$@4R]-24U%(&4@=6UA('-E;FAA('/C;R!O8G)I
M9V%T\W)I87,@<&%R82!D97-C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+@!5
M;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O
M34E-12!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA
M<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12#I(&]B
M<FEG873S<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`3G5V
M96YS(&UA='5T:6YA<P!#:'5V82!&<F%C82!697-P97)T:6YA`$-H=79A(&UA
M='5T:6YA`$-H=79A<R!M871U=&EN87,`3F5V87-C87,@36%T=71I;F%S`$%-
M+U!-`$%022!)1`!3;V)R92!E<W1E(&5D:71O<@!3;V)R92XN+@!!8G-B;W1T
M;VT`06)S;6ED9&QE`$%C97-S;R!N96=A9&\@86\@8W)I87(@9&ER973S<FEO
M(%9&4RX`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O(%9&4RX`4W5A
M<R!);F9O<FUAY_5E<P!396YH82!D82!#;VYT80!#;VYT82!D97-A=&EV861A
M+@!#;VYT87,`061I8VEO;F%R`$%D:6-I;VYA<B!'<G5P;R!3=6)O<F1I;F%D
M;P!!9&EC:6]N87(@4&5R;6ES<_5E<R!3=6)O<F1I;F%D87,`061I8VEO;F4@
M07%U:3H`061I8VEO;F%R($YO=F\@1W)U<&\`061I8VEO;F%R($YO=F$@4&5R
M;6ES<^-O`$%D:6-I;VYA<B!U;2!G<G5P;R!S=6)O<F1I;F%D;R!A("<E<R<`
M061I8VEO;F%R('5M82!P97)M:7-SXV\@<W5B;W)D:6YA9&$@82`G)7,G`$%D
M:6-I;VYA<B!U;2!N;W9O('5S=>%R:6\Z`$%D:6-I;VYA<B!C;VQU;F$`061I
M8VEO;F%R(&YO=F]S(&UE;6)R;W,`061I8VEO;F%R('!A<@!!9&EC:6]N87(@
M;R!-96YU("5S(&-O;6\@=6UA($)A<G)A($QA=&5R86P@9&\@36]Z:6QL80!!
M9&EC:6]N87(@86\@8V%TX6QO9V\@9&4@96YD97)EYV]S.@!!9&EC:6]N87(@
M86\@;65U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!!9&EC:6]N87(@=7-UX7)I
M;P`G)7,G(&%D:6-I;VYA9&\@86\@<VES=&5M82P@;6%S(&[C;R!P=61E(&EN
M8VQU:7(@:6YF;W)M8>?U97,@861I8VEO;F%I<R!D;R!C861A<W1R;SH@)7,N
M`"5S(&%D:6-I;VYA9&\@86\@<VES=&5M82X@5F]CZB!P;V1E('-E(&-O;F5C
M=&%R(&%G;W)A+@!!9&GGXV\@9&4@=7-UX7)I;W,@97-TX2!D97-A8FEL:71A
M9&$N`$5N9&5R9>=O`$-A=.%L;V=O(&1E($5N9&5R9>=O<P!!9&UI;FES=')A
M<B`M(&-O;F9I9W5R82!P97)M:7-S]65S('!A<F$@;W5T<F]S('5S=>%R:6]S
M`$%D;6EN:7-T<F'GXV\`06[Z;F-I;W,`069E9V%N:7-TXV\`06QBXFYI80!!
M<F?I<FEA`$%P96QI9&\`06QI;FAA<@!!;&EN:&%M96YT;SH`5&]D;W,`5&]D
M;W,@57-UX7)I;W,@075T96YT:6-A9&]S`%1O9&]S($=R=7!O<P!4;V1A<R!0
M97)M:7-S]65S`%1O9&]S('%U871R;R!L861O<P!097)M:71I<B!M^FQT:7!L
M;W,@96YD97)EYV]S`%!E<FUI=&ER(&-O;F9I9W5R87(@;R!T:7!O(&1E(&QI
M<W1A<R!O<F1E;F%D87,_`$KA(&5X:7-T90!,;V=I;B!)35-0($%L=&5R;F%T
M:79O`%-E;FAA($E-4U`@06QT97)N871I=F$`57-UX7)I;R!)35-0($%L=&5R
M;F%T:79O`$5N9&5R9>=O(&1E(&4M;6%I;"!A;'1E<FYA=&EV;P!-;V1E;&]S
M(&%L=&5R;F%T:79O<P!497AT;R!A;'1E<FYA=&EV;SH`4V%M;V$@06UE<FEC
M86YA`%5M('9A;&]R(&EL96=A;"!F;VD@97-P96-I9FEC861O+@!/8V]R<F5U
M('5M(&5R<F\@9&5S8V]N:&5C:61O+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL
M80!0<F]X>2!A;O1N:6UO`%)E<W!O<W1A`$%N=.%R=&ED80!!;G1I9W5A(&4@
M0F%R8F%D;W,`07!L:6-AY^-O`$QI<W1A(&1E($%P;&EC8>?U97,`02!A<&QI
M8V'GXV\@97-TX2!P<F]N=&$N`$%P;&EC87(@86]S($-O;7!A<G1I;&AA;65N
M=&]S(%-U8F]R9&EN861O<P!!<')O=F%R`%1A;6%N:&\@07!R;WAI;6%D;P!!
M8G)I;`!!<N%B:6-O("A7:6YD;W=S+3$R-38I`%1A;6%N:&\@9&\@07)Q=6EV
M;P!.;VUE(&1O($%R<75I=F\`5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!R
M96UO=F5R(&$@<V]L:6-I=&'GXV\@9&4@8V%D87-T<F\@9&4@)7,_`%9O8^H@
M=&5M(&-E<G1E>F$@<75E(&1E<V5J82!E>&-L=6ER("<E<R<@92!S975S('-U
M8F=R=7!O<S\`07)G96YT:6YA`$%R;>IN:6$`07)MZFYI;R`H05)-4T-)22TX
M*0!!<G1E`$%R=6)A`$EL:&$@07-C96YSXV\`07)T92!!<V-I:0#!<VEA+U)E
M9VGC;R!D;R!086/M9FEC;P!3;VQI8VET87(@8V]N9FER;6'GXV\@86YT97,@
M9&4@97AE8W5T87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\_`$-O;'5N
M87,@9&4@9&5S:6=N8>?C;P!496YT;W4@97AC;'5I<B!U;2!G<G5P;R!I;F5X
M:7-T96YT92X`5&5N=&]U(&5X8VQU:7(@=6UA('!E<FUI<W/C;R!NXV\@97AI
M<W1E;G1E+@!496YT;W4@961I=&%R('5M82!P97)M:7-SXV\@;N-O(&5X:7-T
M96YT92X`5&5N=&]U(&5D:71A<B!U;2!C;VUP87)T:6QH86UE;G1O(&[C;R!E
M>&ES=&5N=&4N`$%T<FEB=71O<P!!9V]S=&\`075S='+A;&EA`,%U<W1R:6$`
M075T:%]C>7)S<6PZ($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM
M87`@;F5C97-SX7)I82X`075T:%]C>7)U<SH@3R!C;VYE8W1O<B!NXV\@<&]S
M<W5I(&%S(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S+@!!=71H7V-Y<G5S.B!.
MXV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N
M`$%U=&A?9G1P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!&5%`@
M;F5C97-SX7)I82X@0V]M<&EL92!O(%!(4"!C;VT@82!O<.?C;R`M+65N86)L
M92UF='`N`$%U=&A?:6UA<#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YS
MXV\@:6UA<"!N96-E<W/A<FEA+@!!=71H7VMR8C4Z($[C;R!F;VD@96YC;VYT
M<F%D82!A(&5X=&5N<^-O(&MR8C4@;F5C97-SX7)I82X`075T:%]L9&%P.B!)
M;F-L=7/C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!8W1I
M=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@17AC;'5SXV\@9&4@=7-UX7)I;W,@
M;N-O(.D@<W5P;W)T861A('!A<F$@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($Q$05`@;F5C97-S
MX7)I82X`075T:%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!O('5S=>%R
M:6\@)7,N($ES=&\@9F]I(&\@<75E(&\@<V5R=FED;W(@<F5P;W)T;W4Z(`!!
M=71H7VQD87`Z($EM<&]S<^UV96P@<F5M;W9E<B!O('5S=>%R:6\@)7,`075T
M:%]L9&%P.B!);7!O<W/M=F5L(&%T=6%L:7IA<B!O('5S=>%R:6\@)7,`075T
M:%]L9&%P.B!!='5A;&EZ8>?C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A
M9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ($[C;R!F;VD@
M96YC;VYT<F%D82!A(&5X=&5N<^-O($U#04P@;F5C97-SX7)I82X`075T:%]S
M;6)A=71H.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!S;6)A=71H
M(&YE8V5S<^%R:6$N`$%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!)34%0(&9A
M;&AO=2X`1F%L:&$@;F$@875T96YT:6-AY^-O`$9A;&AA(&YA(&%U=&5N=&EC
M8>?C;SH@)7,`075T96YT:6-AY^-O(')E:F5I=&%D82!P96QO('-E<G9I9&]R
M(%)!1$E54RX`02!A=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@1E10(&9A;&AO
M=2X`02!A=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@4TU"(&9A;&AO=2X`0V%M
M<&]S(&1I<W!O;NUV96ES.@!!>F5R8F%I:N-O`$1E<V-U;'!A<R!D;R!"3T9(
M`$9U;F1O`$-O<B!D92!&=6YD;P!396YH82!K97)B97)O<R!I;F-O<G)E=&$N
M`%5S=>%R:6\@:V5R8F5R;W,@:6YC;W)R971O+@!"86AA;6%S`$)A:')A:6X`
M0N%L=&EC;R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`3N-O
M(&9O:2!E;F-O;G1R861O(&\@9&ER973S<FEO(&)A<V4@9&4@:6UA9V5N<R`G
M)7,G+@!,:6YH82!D92!087)T:61A`$)E;&]R^G-S:6$`0NEL9VEC80!"96QI
M>F4`0F5N:6X`0F5R;75D87,`0G5TXV\`06YI=F5R<^%R:6\`3N-O(&9O:2!E
M;F-O;G1R861O(&\@8FQO8V\@(B5S(B!D82!A<&QI8V'GXV\@(B5S(BX`0V]N
M9FEG=7)AY_5E<R!D;R!";&]C;P!4:7!O(&1E($)L;V-O`$YE9W)I=&\`0F]L
M[79I80!&879O<FET;W,`0F]R9&$`3&%R9W5R82!D82!B;W)D83H`0F]R9&%S
M`$+S<VYI82!E($AE<GIE9V]V:6YA`$%M8F]S`$)O='-U86YA`%)O9&%PZ0!)
M;&AA($)O=79E=`!"<F%S:6P`5&5R<FET\W)I;R!D;R!/8V5A;F\@S6YD:6-O
M($EN9VSJ<P!"<G5N96D`0G5L9^%R:6$`3&ES=&$@8V]M($UA<F-A9&]R97,`
M0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!0;VYT;W,@9&4@1&ES=')I
M8G5IY^-O($-23`!0<F]P<FEE9&%D97,@9&$@0^E?;'5L82XN+@!!(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82X`06=E;F1A
M`$-A;&UO`$-A;6)O9&IA`$-A;6%R]65S`$[C;R#I('!O<W/M=F5L(&=E<F%R
M('5M82!N;W9A('-E;FAA(&%U=&]M871I8V%M96YT92P@96YT<F4@96T@8V]N
M=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R+@!.XV\@8V]N<VEG;R!G<F%V87(@
M;R!A<G%U:79O("(E<R(`3N-O(.D@<&]S<^UV96P@861M:6YI<W1R87(@9V5R
M96YC:6%D;W)E<R!E>'1E<FYO<R!D92!S97-SXV\N`$[C;R#I('!O<W/M=F5L
M(&-O;F5C=&%R(&%O('-E<G9I9&]R($E-05`Z("5S`$[C;R!C;VYS:6=O(&%B
M<FER(&\@87)Q=6EV;R`B)7,B+@!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@
M4F5L873S<FEO(&1E(%!R;V)L96UA`$[C;R#I('!O<W/M=F5L(&5X8VQU:7(@
M;R!A<G%U:79O("(E<R(N`$[C;R#I('!O<W/M=F5L(&5N8V]N=')A<B!U;2!D
M:7)E=/-R:6\@=&5M<&]RX7)I;RX`3N-O(.D@<&]S<^UV96P@8V]N=&EN=6%R
M('-E;2!O('!A<N)M971R;R`G=&%R9V5T1FEL92<N`$[C;R#I('!O<W/M=F5L
M(&5X8VQU:7(@;R!D:7)E=/-R:6\@(B5S(BX`3N-O(.D@<&]S<^UV96P@97AC
M;'5I<BP@)60@<&]S<W5I('-U8F]R9&EN861O<RX`3N-O(.D@<&]S<^UV96P@
M<F5O<F1E;F%R+"!N^FUE<F\@9&4@<F5G:7-T<F]S(&9O<FYE8VED;W,@<&%R
M82!R96]R9&5N87(@;N-O(&-O<G)E<W!O;F1E(&%O(&[Z;65R;R!A<FUA>F5N
M861O+@!.XV\@Z2!P;W-S[79E;"!R;W1E87(@;65N<V%G96T@<&%R82!O(&[Z
M;65R;R!E<W!E8VEF:6-A9&\N`$-A8F\@5F5R9&4`5.UT=6QO`$]P97)A9&]R
M80!#871E9V]R:6%S(&4@3F]M97,`26QH87,@0V%Y;6%N`%1E;&5F;VYE($-E
M;'5L87(`4')O<')I961A9&5S(&1A($/I;'5L80!-87)G96T@9&$@8^EL=6QA
M.@!0<F]P<FEE9&%D97,@9&$@0^EL=6QA`$5S<&'G86UE;G1O(&1A(&/I;'5L
M83H`5&5L969O;F4@8V5L=6QA<@!#Z6QT:6-O("A)4T\M.#@U.2TQ-"D`0V5N
M=')O`%)E</IB;&EC82!D82#!9G)I8V$@0V5N=')A;`!%=7)O<&$@0V5N=')A
M;"`H25-/+3@X-3DM,BD`1&5T86QH97,@9&\@0V5R=&EF:6-A9&\`4')O<')I
M973A<FEO(&1O($-E<G1I9FEC861O`%!O;.UT:6-A<R!D;R!#97)T:69I8V%D
M;P!48VAA9&4`06QT97)A<@!!;'1E<F4@4W5A(%-E;FAA`$%L=&5R87(@;R!N
M;VUE(&4@;R!E;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!VZF5M('%U86YD;R!E
M;&%S(&SJ96T@92!R97-P;VYD96T@<W5A<R!M96YS86=E;G,N`$%L=&5R8>?C
M;R!D92!S96YH82!NXV\@Z2!S=7!O<G1A9&$@;F$@8V]N9FEG=7)AY^-O(&%T
M=6%L+B`@16YT<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R+@!#
M:&%R`%9E<FEF:6-A<B!,:6Y?:RXN+@!#:&EL90!#:&EN80!#:&ENZG,@4VEM
M<&QI9FEC861O("A'0C(S,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2D`
M17-C;VQH82!A($%P;&EC8>?C;SH`17-C;VQH82!U;6$@<V5N:&$`17-C;VQH
M82!U;2!U<W7A<FEO`$5S8V]L:&$@8V]M;R!E>&EB:7(@9&%T87,Z`$5S8V]L
M:&$@;R!T:7!O(&1E(&5S=&EL;R!D92!L:7-T87,@*'!A<F$@;&ES=&%S(&]R
M9&5N861A<RD`26QH87,@0VAR:7-T;6%S`$[C;R!F;VD@96YC;VYT<F%D82!A
M(&1E9FEN:>?C;R!D92!C;&%S<V4@9&4@)7,N`$QI;7!A<@!,:6UP87(@=&%G
M<R!-4T]F9FEC90!%>&-L=6ER('5S=>%R:6\`17AC;'5I<B!U<W7A<FEO.B`E
M<P!%>&-L=6ER('5S=>%R:6\`17AC;'5I<B!D861O<R!D;R!U<W7A<FEO`$/I
M=2!A8F5R=&\@82!487)D90!#;&EQ=64@<&%R82!#;VYT:6YU87(`0VQI8VMA
M=&5L;"!V:6$@2%144`!&96-H87(@2F%N96QA`$YU=F5N<P!.=6)L861O('!E
M;&$@36%N:.,`3G5B;&%D;P!);&AA<R!D92!#;V-O<P!#;VYT<F%I<B!"87)R
M82!,871E<F%L`$-O;G1R86ER(&)O<F1A<P!#;VST;6)I80!#;W(`4&%L:&5T
M82!D92!#;W)E<P!396QEY^-O(&1E($-O<@!#;VQS.@!4[71U;&]S(&1A<R!#
M;VQU;F%S`%%U861R:6YH;W,`0V]M86YD;P!,:6YH82!D92!#;VUA;F1O`$-O
M;65N=&%R`$YO;64`0V]M;W)O<P!%;7!R97-A`$-O;7!U=&%D;W)E<P!#;VYD
M:>?C;P!#;VYD:>?U97,`1&EF97)E;N=A<R!D92!#;VYF:6=U<F'GXV\`0V]N
M9FEG=7)AY^-O(&1E('-I;F-R;VYI>F'GXV\@8V]M(%!$07,L(%-M87)T<&AO
M;F5S(&4@3W5T;&]O:RX`0V]N9FEG=7)AY^-O(&YE8V5S<VET82!D92!A='5A
M;&EZ8>?C;RX`0V]N9FEG=7)A<B`E<P!#;VYF:7)M92!A(%-E;FAA`$-O;F=O
M`$-O;F=O+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\`1F%L:&$@;F$@8V]N
M97CC;RX`1F%L:&$@;F$@8V]N97CC;SH@`$-O;F5XXV\@<F5C=7-A9&$@<&5L
M;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N`$-O;F5XXV\@<F5C=7-A
M9&$@<&5L;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N($UO=&EV;SH@
M)7,@*"5S*0!!(&-O;F5XXV\@86\@<V5R=FED;W(@1E10(&9A;&AO=2X`0V]N
M=&%T;W,`3W,@8V]N=&%T;W,@9F]R86T@861I8VEO;F%D;W,@8V]M('-U8V5S
M<V\@86\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RX`5&EP92!D92!C;VYT
M9?ID;R!D;R!A<G%U:79O(&-O;7!R:6UI9&\Z(`!#;VYT9?ID;R!D92`G)7,G
M`$-O;G1I;G5A<@!);&AA<R!#;V]K`$-O;VMI90!#;W!I87(`1F%L:&$@;F$@
M8_-P:6$Z("5S`$-O<&EA<B!S96QEY^-O`$E$(&1E($-U<W1O`$-O<W1A(%)I
M8V$`0V]S=&$@9&\@36%R9FEM`$EM<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@
M;65N<V%G96T@8V]M(%!'4#H@`$EM<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A
M9V5M(&-O;2!01U`Z(`!.XV\@9F]I('!O<W/M=F5L(&-R:7!T;V=R869A<B!A
M(&UE;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@87-S:6YA
M<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@861I
M8VEO;F%R(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@
M86\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!V97)I9FEC87(@
M;R!S86QD;RX@)7,`26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!,
M1$%0+@!.XV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R("<E
M<R<@=71I;&EZ86YD;R!&5%`Z("5S`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@
M82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$EM<&]S<^UV96P@9&5S8W)I
M<'1O9W)A9F%R(&]S(&1A9&]S(%!'4#H@`$[C;R!F;VD@<&]S<^UV96P@9&5S
M8W)I<'1O9W)A9F%R(&\@9&%D;R!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@
M97AC;'5I<B!O(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I
M<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E
M;"!E>&-L=6ER(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R
M8>?C;R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@;R!E;F1E
M<F7G;R!D92!E+6UA:6P@9&\@9&5S=&EN873A<FEO+@!.XV\@9F]I('!O<W/M
M=F5L(&]B=&5R(&-O;7!L971A;65N=&4@;R!C873A;&]G;R!D92!E;F1E<F7G
M;W,N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!A(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C
M;VUP;&5T86UE;G1E(&$@;&ES=&$@9&4@;&ES=&%S(&1E(&1I<W1R:6)U:>?C
M;RX`3N-O(&9O:2!P;W-S[79E;"!C87)R96=A<B!A(&5S=')A=.EG:6$@)R5S
M)RX`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!O(&1I<F5T\W)I;R`G)7,G+@!.
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@8VAA=F4@</IB;&EC82!A('!A<G1I
M<B!D;R!S97)V:61O<B!D92!C:&%V97,N`$[C;R!F;VD@<&]S<^UV96P@86)R
M:7(@)R5S)R!P87)A(&=R879AY^-O+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER
M("5S+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO("=-86EN=&5N
M86YC95]487-K)R`E<P!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@9&ER973S
M<FEO("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@<&5S<75I<V%R(&YO('-E<G9I
M9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@;&5R("5S+@!.XV\@9F]I('!O
M<W/M=F5L(&=E<F%R('5M82!N;W9A('-E;FAA('!A<F$@;R!U<W7A<FEO('-O
M;&EC:71A9&\N($%L9W5N<R!O=2!T;V1O<R!O<R!D971A;&AE<R!NXV\@97-T
MXV\@8V]R<F5T;W,N(%1E;G1E(&YO=F%M96YT92!O=2!E;G1R92!E;2!C;VYT
M871O(&-O;2!O(&%D;6EN:7-T<F%D;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@
M;6%I<R!A:G5D82X`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A($%#3`!.XV\@
M9F]I('!O<W/M=F5L(&]B=&5R(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S+B`E
M<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5I
MY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&QI<W1A<R!D92!D
M:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@8V%P
M86-I9&%D97,@9&\@<V5R=FED;W(`3N-O(&9O:2!P;W-S[79E;"!R979E<G1E
M<B!A(&-O;F9I9W5R8>?C;RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@
M9&ER973S<FEO("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@<V%L=F%R(&$@8V]N
M9FEG=7)AY^-O("5S+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K
M=7`@9&$@8V]N9FEG=7)AY^-O+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U
M;2!B86-K=7`@9&$@8V]N9FEG=7)AY^-O.B`E<P!.XV\@9F]I('!O<W/M=F5L
M('-A;'9A<B!O('-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'G
MXV\@96TZ("<E<R<N`$[C;R!C;VYS96=U:2!S86QV87(@;R!B86-K=7`@9&\@
M87)Q=6EV;R!D92!C;VYF:6=U<F'GXV\@)7,N`$[C;R!C;VYS96=U:2!S86QV
M87(@;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX@5F]CZB!P;V1E(&]U
M('5T:6QI>F%R('5M82!D87,@;W#G]65S('!A<F$@<V%L=F%R(&\@8_-D:6=O
M(&1E('9O;'1A(&5M("5S(&]U(&-O<&EA<B!M86YU86QM96YT92!O(&/S9&EG
M;R!A8F%I>&\@<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@
M;F\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@
M;&EN:R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&%T=6%L:7IA<B!O(&-O;G1A
M=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@871U86QI>F%R(&$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&=R879A<B!A(&-O
M;F9I9W5R8>?C;R!D92`G)7,G.B`E<P!.XV\@9F]I('!O<W/M=F5L(&5N8V]N
M=')A<B!A($)A<G)A($QA=&5R86P@9&\@36]Z:6QL82X@0V5R=&EF:7%U92US
M92!Q=64@96QA(&5S=.$@86)E<G1A+@!.XV\@9F]I('!O<W/M=F5L(&1A<B!A
M;R!U<W7A<FEO("5S(&]S('-E9W5I;G1E<R!D:7)E:71O<R!P87)A(&$@<&%S
M=&$@)R5S)SH@)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O<P!#<FEA<@!#
M<FEA<B!U;2!L:6YK`$-R:6%R('5M82!N;W9A`$-R:6%R('-U8B!P87-T87,`
M4&5R;6ES<_5E<R!D;R!C<FEA9&]R`$[Z;65R;R!D;R!C87)TXV\@9&4@8W+I
M9&ET;P!#<F_A8VEA`$-U8F$`-"!&87-E<R!!='5A:7,`4V5S<_5E<R!!='5A
M:7,`2&]R82!!='5A;`!!(%523"!A='5A;"#I`%5S=>%R:6]S(&YO(&UO;65N
M=&\`0VQI;6$@071U86P`0V]N9&GGXV\@871U86PZ(`!%<W1I;&\@871U86P`
M0W5S=&]M:7IA('1A<F5F87,@82!S97)E;2!E>&5C=71A9&%S(&%O(&-O;F5C
M=&%R(&$@)7,N`$-O<G1A<@!#;W)T87(@<V5L9>?C;P!#:&EP<F4`0VER[6QI
M8V\@*$M/23@M4BD`0VER[6QI8V\@*%=I;F1O=W,M,3(U,2D`0VER[6QI8V\O
M56-R86YI86YO("A+3TDX+54I`%)E</IB;&EC82!48VAE8V$`1$0`1%-.("AV
M96IA(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&EA<FEA;65N=&4`3F%V96=A9&]R
M(&1E($1A=&%4<F5E`%!E<W%U:7-A(&YO($)A;F-O(&1E($1A9&]S`$1A=&$`
M1&%T82!D92!296-E8FEM96YT;P!396QEY^-O(&1E(&1A=&$`1&EA`$5?>&-L
M=6ER($-O;'5N80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E8W5A<B!)
M9&5N=&'GXV\`4&%D<N-O`$-O<B!0861RXV\`261E;G1I9&%D92!0861RXV\`
M4VAE;&P@4&%D<N-O`$1E9FEN:>?U97,`17AC;'5I<@!%>&-L=6ER(&/I;'5L
M80!%>&-L=6ER($=R=7!O`$5X8VQU:7(@3&]G`$5X8VQU:7(@4&5R;6ES<^-O
M`$5X8VQU:7(@92!P=7)G87(@;65N<V%G96YS`$5X8VQU:7(@8^EL=6QA`$5X
M8VQU:7(@8V]L=6YA`$5X8VQU:7(@;6]D96QO('-U8G-T:71U=&\@97AI<W1E
M;G1E`$5X8VQU:7(@<&5R;6ES<_5E<R!P87)A("<E<R<`17AC;'5I<B!P97)M
M:7-S]65S('!A<F$@)R5S)R!E('%U86QQ=65R(&]U=')A('-U8BUP97)M:7-S
MXV\_`$5X8VQU:7(@;&EN:&$`17AC;'5I<B!I9&5N=&ED861E('-E;&5C:6]N
M861A`$5X8VQU:7(@82!C;VQU;F$@871U86P`17AC;'5I<B!A(&QI;FAA(&%T
M=6%L`%-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@)R5S
M)R!E>&-L=>UD;RX`2&]R82!D92!E;G1R96=A`$1I;F%M87)C80!$97-C<F5V
M82!O('!R;V)L96UA`$1E<V-R:>?C;P!$971A;&AE<R`H=&%M8NEM(&YO(')E
M9VES=')O(&1E(&%T:79I9&%D97,@9&\@2&]R9&4I.@!/<R!D971A;&AE<R!F
M;W)A;2!G<F%V861O<R!E;2!L;V<@<&%R82!O(&%D;6EN:7-T<F%D;W(N`$1E
M<V5N=F]L=FEM96YT;P!0;VYT;R!D92!/<G9A;&AO`%!O;G1O(&1E($]R=F%L
M:&\@<&%R82!A(/IL=&EM82!H;W)A.B``4&]N=&\@9&4@3W)V86QH;SH@`$1I
M<F7GXV\@9&$@97-Q=65R9&$@<&%R82!D:7)E:71A`$1I<F7GXV\@9&$@9&ER
M96ET82!P87)A(&5S<75E<F1A`$1I<F5T\W)I;P!%>&EB:7(@96T@9F]R;6%T
M;R`R-"!H;W)A<S\`3W#G]65S(&1E($5X:6)IY^-O`$5X:6)I<B!P<F5V:7/C
M;R!D971A;&AA9&$`17AI8FER('!R979I<^-O("A4048I`$5X:6)I<B!F;W)M
M871O`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.XV\@97AC
M;'5I<@!.XV\@86-E<W-E(&1I<F5T86UE;G1E(&UA:6YT96YA;F-E+G!H<`!!
M('!R:6UE:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S/R!3
M92!S:6TL(&-L:7%U92!N97-T82!C86EX83H`1&]M:6YI8V%N80!297#Z8FQI
M8V$@1&]M:6YI8V%N80!.XV\@=&5M('5M82!C;VYT83\@0V%D87-T<F4M<V4N
M`$)A:7AA<@!"86EX87(@)7,`0F%I>&%R(&$@8V]N9FEG=7)AY^-O(&=E<F%D
M82!C;VUO('5M('-C<FEP="!02%`N`$QI<W1A(&1E('-E;&7GXV\`1')O9V%S
M`$-O<G)E:6\`0V]N96-T;W(@9&\@9V%T97=A>2!%36%I;"UP87)A+5--4RP@
M<&%R82!O<&5R861O<F%S('%U92!D:7-P;VYI8FEL:7IA;2!E<W1E('-E<G9I
MYV\N`$524@!%<75A9&]R`$5D:71A<@!%9&ET87(@0FQO8V\`161I=&%R($=R
M=7!O`$5D:71A<B!097)M:7-SXV\`161I=&%R(%!E<FUI<W/U97,`161I=&%R
M(%!E<FUI<W/U97,@<&%R82`E<P!%9&ET87(@;W#G]65S(&1E.@!%9&ET87(@
M<&5R;6ES<_5E<R!P87)A("5S`$5D:71A<B!P97)M:7-S]65S('!A<F$@)7,`
M161U8V'GXV\`16=I=&\`16P@4V%L=F%D;W(`16QE;65N=&\N+BX`16T`12UM
M86EL`$5N9&5R9>=O(&1E($4M36%I;`!/(&5N9&5R9>=O(&1E(&4M;6%I;"!D
M979E(&-O<G)E<W!O;F1E<BX`365N<V%G96T@8V]M(&-O;F9I<FUAY^-O`$=A
M=&5W87D@9&4@14UA:6PM<&%R82U335,`16UO=&EC;VYS`$UE;G-A9V5M(&5M
M(&)R86YC;RX`4F5S=6QT861O(&5M(&)R86YC;RX`5&5R;6]S(&1E('!E<W%U
M:7-A(&5M(&)R86YC;P!(86)I;&ET87(@:6YS97+GXV\@9&4@:6UA9V5N<R!A
M('!A<G1I<B!D82!'86QE<FEA(&1E($EM86=E;G,@;F\@=&5X=&\_`$AA8FEL
M:71A<B!M96YU(&1E(&-O;G1E>'1O(&-O;2!O(&)O=.-O(&1I<F5I=&\_`$9I
M;F%L(&1O(&%N;P!!=6UE;G1A<B!%9&ET;W(`1F]R;F7G82!U;6$@<&5R9W5N
M=&$@9&4@<V5G=7)A;N=A(&$@<75A;"!V;V/J('-E<N$@<&5R9W5N=&%D;R!S
M92!V;V/J(&YE8V5S<VET87(@9V5R87(@=6UA(&YO=F$@<V5N:&$L(&5X+B`G
M<75A;"!O(&YO;64@9&\@<V5U(&-A8VAO<G)O/R<Z`$9O<FYEYV$@82!54DP@
M9&$@:6UA9V5M(&%Q=6D`1&EG:71E(&%S(&QE=')A<R!A8F%I>&\Z`$=U:6[I
M($5Q=6%T;W)I86P`17)I='+I:6$`17)R;P!%<G)O(&%O(&-R:6%R(&)L;V-O
M.B`E<P!%<G)O(&%O(&5X8VQU:7(@XFYC;W)A(&1E('-I;F-R;VYI>F'GXV\Z
M("5S`$5R<F\@86\@97AC;'5I<B!L;V<@9&4@<VEN8W)O;FEZ8>?C;SH@)7,`
M17)R;R!A;R!O8G1E<B!C;VYT9?ID;SH@)7,`17)R;R!A;R!A='5A;&EZ87(@
M82!S96YH83H@)7,`17)R;R!N82!M96YS86=E;2X`17)R;R!G<F%V86YD;R`G
M)7,G+@!%<W3T;FEA`$5T:?-P:6$`R71N:6-O`$5U<F]P80!#861A(#$U(&UI
M;G5T;W,`0V%D82`R(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@
M;6EN=71O<P!#861A($-O;F5XXV\`0V%D82!M96EA(&AO<F$`0V%D82!M:6YU
M=&\`5F%L;W)E<R!D92!E>&5M<&QO.@!%>&5C=71A<@!%>'!A;F1I<@!%>'!A
M;F1I<B!"87)R82!,871E<F%L`$5S<&5R861O("<I)P!%<W!E<F%D;R!U;6$@
M<&%L879R82!O=2!T97)M;R!D92!P97-Q=6ES82!E;G1R92!A<W!A<P!$871A
M(&1E($5X<&ER8>?C;P!%>'!O96YT90!#;W(@9&\@<')I;65I<F\@<&QA;F\`
M0V]N9FEG=7)AY^-O(&1E(&5N=FEO(&1E(&%R<75I=F]S($944`!&86QH82!O
M8G1E;F1O('!R969E<NIN8VEA<RX`1F%L:&$@86\@8V]N96-T87(@86\@<V5R
M=FED;W(@3$1!4"X`1F%L:&$@86\@8V]N96-T87(@86\@<V5R=FED;W(@4TU"
M+@!&86QH82!A;R!C;W!I87(@9&4@(B5S(BX`1F%L:&$@86\@8V]P:6%R('!A
M<F$@(B5S(BX`1F%L:&$@86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!305-,
M+@!&86QH82!A;R!M;W9E<B!P87)A("(E<R(N`$9A;&AA(&%O(&]B=&5R.B`E
M<P!*=7-T;P!);&AA<R!&86QK;&%N9"`H36%L=FEN87,I`$EL:&%S($9A<F]E
M`$5R<F\@1F%T86PZ`$9A>`!&87AE<P!&979E<F5I<F\`4V5N<V'GXV\@5.ER
M;6EC80!396YS8>?C;R!TZ7)M:6-A.B``4&%N8V%D87,@9&4@0VAU=F$`3F5V
M92!&<F%C80!-871R:7H@9&\@8V%M<&\`1FEG;&5T($-!4%1#2$$`1F]N=&4@
M1FEG;&5T`$9I:FD`87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@
M87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,`1V5R
M96YC:6%D;W(@9&4@07)Q=6EV;W,`3F]M92!D;R!!<G%U:79O`%-E;&7GXV\@
M9&4@87)Q=6EV;P!%;G9I;R!D92!A<G%U:79O`$5N=FEO(&1E(&%R<75I=F]S
M(&[C;R#I('-U<&]R=&%D;RX`1FEL=')O<P!&:6YLXFYD:6$`4')I;65I<F$@
M365T861E`%!R:6UE:7)O(%%U87)T;P!487AA(&9I>&$`1VER87(`1&ES<&]S
M:>?C;P!.Z79O80!087-T82`E<R!NXV\@97AI<W1E`$-O<B!D82!&;VYT90!#
M;VUI9&$`4&%R82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R=&%M(&EM86=E
M;G,`4')E=FESXV\@*%1!1BD`1&EA<R!0<F5V:7-T;W,@*$YO=&4@<75E(&$@
M<')E=FESXV\@<F5T;W)N861A(&5X:6)E(&%M8F]S(&1I82!E(&YO:71E.R!U
M;2!N^FUE<F\@;75I=&\@86QT;R!A<75I('!O9&4@<F5S=6QT87(@96T@=6T@
M8FQO8V\@97AT96YS;RD`17-Q=65C974@82!S96YH83\`1F]R;75LX7)I;W,`
M4V]R=&4`5&EP;R!D92!3;W)T90!3;W)T97,`4V]R=&5S(#(`1O-R=6YS`%)E
M9&ER96-I;VYA;65N=&]S`%-E>`!1=6%D<F]S`$9R86[G80!&<F%NYV$@365T
M<F]P;VQI=&%N80!'=6EA;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A
M`%1E<G)I=/-R:6]S($9R86YC97-E<R!D;R!3=6P`1&4`1&\H82D`1&5S8W)I
MY^-O($-O;7!L971A`$QU82!#:&5I80!.;VUE($-O;7!L971O`$=A8N-O`$=A
M;&5R:6$@9&4@;VYD92!O8G1E<B!A<R!I;6%G96YS`$=A;&5R:6$Z`$?B;6)I
M80!'97)A<B!A($-O;F9I9W5R8>?C;R!D92`E<P!#\V1I9V\@1V5R861O`$=E
M\W)G:6$`06QE;6%N:&$`1V%N80!':6)R86QT87(`4')I;65I<F\@3F]M90!/
M<.?U97,@1VQO8F%I<P!)<@!';V5D96P`1V]O9VQE($UA<&%S`%!E<W%U:7-A
M<B!N;R!';V]G;&4`17-C86QA(&1E($-I;GIA<P!'<NEC:6$`1W)E9V\@*$E3
M3RTX.#4Y+3<I`$=R;V5LXFYD:6$`1W)A;F%D80!!9&UI;FES=')AY^-O(&1E
M($=R=7!O<P!.;VUE<R!D92!G<G5P;W,@;N-O(&1E=F5M(&5S=&%R(&5M(&)R
M86YC;P!'<F]U<%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!G<G5P;R`E
M<RX@27-T;R#I(&\@<75E(&\@<V5R=FED;W(@9&ES<V4Z(`!'<F]U<%]L9&%P
M.B!);7!O<W/M=F5L(&5X8VQU:7(@9W)U<&\@)7,`1W)O=7!?;&1A<#H@26UP
M;W-S[79E;"!A='5A;&EZ87(@9W)U<&\@)7,`1W)U<&]S`$=U861A;'5P90!'
M=6%M`$=U871E;&%M80!'=65R;G-E>0!097)M:7-S]65S(&1E($-O;G9I9&%D
M;P!,:79R;R!D92!6:7-I=&%S`$=U:6[I`$=U:6[I+4)I<W-A=0!'=6EA;F$`
M2%1-3`!(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@
M82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA+@!(5$U,07)E82!S92!N96=A(&-O
M=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@8V]L=6YA(&1A('1A8F5L
M82X`2%1-3$%R96$@<V4@;F5G82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@
M^FQT:6UA(&QI;FAA(&1A('1A8F5L82X`075T96YT:6-AY^-O($A45%`@;N-O
M(&5N8V]N=')A9&$N`$AA:71I`$%L9V]R:71M;R!(87-H`$YE8FQI;F$`0V%B
M9>=A;&AO`$-A8F7G86QH;P!);&AA($AE87)D(&4@26QH87,@36-$;VYA;&0`
M5&5M<&5S=&%D92!&;W)T90!(96)R974@*$E33RTX.#4Y+3@M22D`06QT=7)A
M`$%J=61A`$%J=61A(&1O(&5D:71O<@!!<W-I<W1E;G1E`$AE;6ES9NER:6\`
M07%U:2!E<W3A(&\@:6[M8VEO(&1O(&%R<75I=F\Z`$%L=&$`25]N[6-I;P!3
M86YT82!3Z2`H0VED861E+45S=&%D;R!D;R!6871I8V%N;RD`26[M8VEO`$5N
M9&5R9>=O(%)E<VED96YC:6%L`$1I<F5T\W)I;R!097-S;V%L`$9O;F4@4F5S
M:61E;F-I86P`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!$861O(%A-3"`E<R!I;G;A;&ED;R!E;F-O;G1R861O(&YA(&UE;G-A9V5M
M("5S`$AO<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E<W!O;F1E
M(&%O(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@3F5N:'5M(&]B:F5T;R!D;R!T
M:7!O("5S(&9O:2!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S`$AO<F1E+TMO
M;&%B.B!296UO=FED;R!C;VT@<W5C97-S;R`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!!(&5N9VEN92!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N<^-O(%!(
M4"`G9&]M>&UL)P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!C<FEA<B!U;6$@
M;F]V82#A<G9O<F4@6$U,('!A<F$@;R!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z
M($EM<&]S<^UV96P@<F5M;W9E<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M26UP;W-S[79E;"!O8G1E<B!A(&ED96YT:69I8V'GXV\@34E-12!P87)A(&$@
M<&%R=&4@9&\@=&EP;R`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC
M<F]N:7IA<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S
M:6YC<F]N:7IA<B!C;VUP87)T:6QH86UE;G1O<SH@)7,`2&]R9&4O2V]L86(Z
M($-O;7!A<G1I;&AA;65N=&\@9&5S8V]N:&5C:61O("(E<R(`3&EN:&$@2&]R
M:7IO;G1A;`!-87)G96T@:&]R:7IO;G1A;`!(;W)I>F]N=&%L.@!#;VUO('9O
M8^H@8VAE9V]U(&%Q=6D_("A0;W(@9F%V;W(@8V]M=6YI<75E(2D`475A;G1A
M<R!C;VQU;F%S('9O8^H@9V]S=&%R:6$@9&4@;65S8VQA<C\`475A;G1O<R!C
M86UP;W,@*&-O;'5N87,I(&5X:7-T96T_`%%U86YT87,@;&EN:&%S('9O8^H@
M9V]S=&%R:6$@9&4@;65S8VQA<C\`56UI9&%D90!5;6ED861E.B``2'5M;W)I
M<W1A<P!(=6YG<NUA`$9A;&AA(&%O(&-R:6%R(&-A:7AA('!O<W1A;"!)34%0
M.B`E<P!&86QH82!A;R!E>&-L=6ER(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&
M86QH82!A;R!C<FEA<B!Q=6]T82!D82!C86EX82!P;W-T86P@24U!4#H@)7,`
M16YD97)EYV\@25``16YD97)EYV\@25`@;N-O(&1I<W!O;NUV96PN`$5N9&5R
M9>=O($E0(&[C;R!E<W3A(&YO(&)L;V-O('!E<FUI=&ED;R!#2412+@!6:6]L
M8>?C;R!D;R!B;&]Q=65I;R!)4"X`25]N<VER82!,:6YH82!!;G1E<P!)<VSB
M;F1I80!3;VUE;G1E(,UC;VYE<P#-8V]N97,@<&%R82`E<P#-8V]N97,@92!T
M97AT;P!.;VUE(&1A(&ED96YT:61A9&4Z`%-E(&[C;R!F;W(@97AI8FED;R!C
M;W)R971A;65N=&4L("5S('!A<F$@86)R[2UL;R!E;2!U;6$@;F]V82!J86YE
M;&$N`%-E('9O8^H@;N-O(';J(&YE;FAU;2#M8V]N92!A;R!U=&EL:7IA<B!O
M($EN=&5R;F5T($5X<&QO<F5R+"!V;V/J('!O9&4@8VAE8V%R(&5S=&$@8V%I
M>&$@<&%R82!D97-A8FEL:71A<B!A('1R86YS<&%RZFYC:6$@4$Y'+@!392!V
M;V/J(';J(&5S=&$@;65N<V%G96T@;6%S(&[C;R!A(&EM86=E;2P@82!I;6%G
M96T@<75E('9O8^H@<75E<B!E;G9I87(@;N-O('!O9&4@<V5R(&5X:6)I9&$@
M<&5L;R!S974@;F%V96=A9&]R+@!0<NDM=FES=6%L:7IAY^-O(&1A($EM86=E
M;3H`55),(&1A($EM86=E;0!54DP@9&$@26UA9V5M.@!);6%G96T@9&$@9V%L
M97)I80!);6%G96T@9&$@9V%L97)I83H`16YV:6\@9&4@26UA9V5M`$EM86=E
M;G,`26UP;W)T87(L(%!A<W-O("5D`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M
M<&]S(&EM<&]R=&%D;W,Z`$EN7W-E<FER($QI;FAA($%P\W,`0_-D:6=O(&1E
M(&'GXV\@9F]R;F5C:61O(&5S=.$@:6YC;W)R971O+@!5<W7A<FEO(&4O;W4@
M<V5N:&$@:6YC;W)R971O<RX`57-UX7)I;R!O=2!E;F1E<F7G;R!A;'1E<FYA
M=&EV;R!I;F-O<G)E=&]S+B!496YT92!N;W9A;65N=&4@;W4@96YT<F4@96T@
M8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R('-E('9O8^H@;F5C97-S:71A
M(&1E(&UA:7,@86IU9&$N`$%U;65N=&%R($ED96YT8>?C;P#-;F1I80!5<W7A
M<FEO<R!I;F1I=FED=6%I<P!);F1O;NES:6$`26YF;W)M8>?C;P!);F9O<FUA
MY^-O`$[C;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M=F5I<RX`26YS97)I<B!#
M7V]L=6YA($%P\W,`26YS97)I<B!);6%G96T`26YS97)I<B!486)E;&$`26YS
M97)I<B!,:6YK(&1A(%=E8@!);G-E<FER(%]#;VQU;F$@06YT97,`26YS97)I
M<B!U;6$@;F]V82!C;VQU;F$@87#S<R!A(&%T=6%L`$EN<V5R:7(@=6UA(&YO
M=F$@8V]L=6YA(&%N=&5S(&1A(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@;&EN
M:&$@87#S<R!A(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@;&EN:&$@86YT97,@
M9&$@871U86P`26YS97)I<B!U;2!P87+A9W)A9F\@87#S<R!O(&%T=6%L`$EN
M<V5R:7(@=6T@<&%RX6=R869O(&%N=&5S(&1O(&%T=6%L`$EN<V5R:7(@=6T@
M;6]D96QO(&%L=&5R;F%T:79O`$9O<FYEYV$@=6T@96YD97)EYV\@9&4@92UM
M86EL(&YO('%U86P@=F]CZB!P;V1E(')E8V5B97(@82!N;W9A('-E;FAA.@!)
M;G-E<FER(&/I;'5L82!A</-S`$EN<V5R:7(@8^EL=6QA(&%N=&5S`$EN<V5R
M:7(@8V]L=6YA(&%P\W,`26YS97)I<B!C;VQU;F$@86YT97,`26YS97)I<B!M
M96YS86=E;G,`26YS97)I<B!P87+A9W)A9F\@87#S<P!);G-E<FER('!A<N%G
M<F%F;R!A;G1E<P!);G-E<FER(&QI;FAA(&%P\W,`26YS97)I<B!L:6YH82!A
M;G1E<P!&;W)N9>=A(&$@<F5S<&]S=&$@;V)R:6=A=/-R:6$@<&%R82!A('!E
M<F=U;G1A(&1E('-E9W5R86[G83H`26YS97)I<B]!;'1E<F%R($EM86=E;0!)
M;G-E<FER+T%L=&5R87(@3&EN:P!#<NED:71O(&EN<W5F:6-I96YT92!P87)A
M(&5N=FEA<B!P87)A(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+@!#<NED:71O
M(&EN<W5F:6-I96YT92X`3OIM97)O($EN=&5I<F\`3&ES=&$@9&4@26YT96ER
M;W,`0T15("A#86)EYV%L:&\@9&4@1&%D;W,@9&4@57-UX7)I;RD@:6YVX6QI
M9&\N`$1A9&]S(%I)4"!I;G;A;&ED;W,`07!L:6-AY^-O(&EN=N%L:61A+@!)
M9&5N=&EF:6-AY^-O(&1O(&)A=&-H(&EN=N%L:61A+@!$861O<R!E;G9I861O
M<R!SXV\@:6YVX6QI9&]S+@!%;F1E<F7G;R!D92!D97-T:6YO(.D@:6YVX6QI
M9&\N`$9O<FUA=&\@9&\@87)Q=6EV;R#I(&EN=N%L:61O`$[Z;65R;R!D92!L
M:6-E;N=A(&EN=N%L:61O+@!,;V-A;&EZ8>?C;R!F;W)N96-I9&$@Z2!I;G;A
M;&ED82X`5&EP;R!D82!M96YS86=E;2#I(&EN=N%L:61O+@!!<&E?:60@Z2!I
M;G;A;&ED;R!O=2!E<W3A(&9A;'1A;F1O+@!087+B;65T<F]S(&EN=N%L:61O
M<R!O=2!F86QT86YD;RX`4&5R;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L:61A
M<RX`4&5R;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L:61A<RX`0_-D:6=O(&1O
M('!R;V1U=&\@Z2!I;G;A;&ED;RX`4')O=&]C;VQO(&EN=N%L:61O+@!$97-T
M:6YA=.%R:6\@:6YVX6QI9&\Z("<E<R<`3V)J971O(&-O;7!A<G1I;&AA9&\@
M:6YVX6QI9&\`1F]N=&4@9&\@96YD97)EYV\@:6YVX6QI9&$N`$1A9&]S('5N
M:6-O9&4@:6YVX6QI9&]S+@!);G9E;G3A<FEO`$EN=F5R=&5R('-E;&7GXV\`
M27+C+"!297#Z8FQI8V$@27-LXFUI8V$@9&\`27)A<75E`$ER;&%N9&$`26QH
M82!D;R!(;VUE;0!496UP97-T861E<R!)<V]L861A<P!)<W)A96P`16UI<W-O
M<@!)=.%L:6-O`$ETX6QI80!*86UA:6-A`$IA;F5I<F\`2F%PXV\`2F%P;V[J
M<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)DXFYI80!*=6QH;P!*=6YH;P!*
M=7-T:69I8V%R`$%L:6YH87(@86\@0V5N=')O`$IU<W1I9FEC87(`06QI;FAA
M<B#@($5S<75E<F1A`$%L:6YH87(@X"!$:7)E:71A`$-A>F%Q=6ES=.-O`$UA
M;G1E<B!O(&]R:6=I;F%L/P!1=>IN:6$`4V5R=FED;W(@:V5R8F5R;W,@<F5J
M96ET;W4@82!A=71E;G1I8V'GXV\N`$YO=F%T;W,@9&4@2V5R;F5L`$-R:6'G
MXV\@9&4@0VAA=F4`26UP<F5S<^-O($1I9VET86P@9&$@0VAA=F4`5&%M86YH
M;R!D82!#:&%V90!4:7!O(&1A($-H879E`%5S;R!D82!#:&%V90!#:&%V92!J
MX2!E>&ES=&4@;F\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!#<FEA
M;N=A<P!+:7)I8F%T:0!#;W+I:6$L(%)E</IB;&EC82!0;W!U;&%R($1E;6]C
M<N%T:6-A(&1A`$-O<NEI82P@4F5P^F)L:6-A(&1A`$-O<F5A;F\@*$550RU+
M4BD`2W5W86ET`%%U:7)G=6ES=.-O`$QA7WEO=70`261I;VUA`$QA;R!297#Z
M8FQI8V$@1&5M;V-RX71I8V$@4&]P=6QA<@#:;'1I;6$@365T861E`$=E<F%R
M($YO=F$@4V5N:&$`VFQT:6UO(%%U87)T;P#:;'1I;6$@071U86QI>F'GXV\Z
M`-IL=&EM;R!L;V=I;CH@)7,`VFQT:6UO(&QO9VEN.B`E<R#@('!A<G1I<B!D
M92`E<P#:;'1I;6\@;&]G:6XZ($YU;F-A`$QE=/1N:6$`3&5I`$QA>6]U=`!$
M96EX82!V87II;R!S92!Q=6ES97(@<V5M(&)O<F1A`$SM8F%N;P!%<W%U97)D
M80!#86)EYV%L:&\@97-Q=65R9&\`5F%L;W)E<R!D82!E<W%U97)D80!,97-O
M=&\`06UO<@!,:6+I<FEA`$SM8FEA(,%R86)E($IA;6%H:7)I>6$`3&EE8VAT
M96YS=&5I;@!#:&EV:7-C;T9R86-O`$-H=79A($9R86-A`$-H=79A($9R86-A
M($UA='5T:6YA`$-H=79A($9R86-A(%9E<W!E<G1I;F$`3&5V97,@4&%N8V%D
M87,@9&4@0VAU=F$`0VAU=F%S($9R86-A<R!C;VT@5')O=O5E<P!.979E($9R
M86-A`$)R979E($YE=F%S8V$`4&_J;6%S`$QI;FL`3&EN:R!A<&]N=&$@<&%R
M83H`3&EG87(@;R!E;F1E<F7G;R!D92!E+6UA:6P@X"!PX6=I;F$@9&4@8V]M
M<&]S:>?C;R!A;R!E>&EB:7(`3&EN:W,`0V]O:VEE(&1O($QI;G5X`$QI<W1A
M<B`M('5S=>%R:6\@<&]D92!V97(@82!P87-T80!,:7-T87(@0F%N8V]S(&1E
M($1A9&]S`$QI<W1A<B!4\W!I8V]S(&1E($%J=61A`$QI<W1A<B!486)E;&%S
M`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI
M<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$$@;&ES
M=&%G96T@9&4@<V5S<_5E<R!F86QH;W4Z("5S`$$@;&ES=&%G96T@9&4@=7-U
MX7)I;W,@9F%L:&]U.B`E<P!,:7-T86=E;2!D92!U<W7A<FEO<R!E<W3A(&1E
M<V%B:6QI=&%D82X`3&ET97)A='5R80!,:71UXFYI80!#87)R96=A;F1O+BXN
M`$AO<F$@;&]C86PZ(`!,;V-A;&EZ8>?C;R!E($AO<F$`4F5G:>-O`$-O;F5C
M=&%R`$QO9R!D82!S97-SXV\@9&4@<VEN8W)O;FEZ8>?C;R!A;G1E<FEO<@!$
M97-C;VYE8W1A<@!#;VYE8W1A<@!487)E9F%S(&1E($-O;F5XXV\`3R!L;V=I
M;B!F86QH;W4@<&]R<75E('-E=2!U<W7A<FEO(&]U('-E;FAA(&5S=&%V82!I
M;F-O<G)E=&$N`$9A;&AA(&1E($QO9VEN+@!497AT;R!L;VYG;P!!;6]R`$)A
M:7AA`$%L9F%B971O(&=R96=O(&5M(&UI;OIS8W5L;P!!;&9A8F5T;R!L871I
M;F\@96T@;6EN^G-C=6QO`$[Z;65R;W,@<F]M86YO<R!E;2!M:6[Z<V-U;&\`
M3'5X96UB=7)G;P!-30!-3U1$`$\@86YE>&\@35,M5$Y%1B!NXV\@8V]N=.EM
M(&1A9&]S+@!-4T<`36%C86\`36%C961O;FEA+"!!;G1I9V$@4F5P^F)L:6-A
M($EU9V]S;.%V:6$@9&$`36%D86=A<V-A<@!-X6=I8V\`0V]R<F5I;P!!9&UI
M;FES=')A9&]R(&1O($-O<G)E:6\`0W)I87(@;&EN7VLN+BX`36%L87=I`$UA
M;.%S:6$`36%L9&EV87,`36%L:0!-86QT80!'97)E;F-I82!A(&QI<W1A(&1E
M(&-A=&5G;W)I87,@92!A<R!C;W)E<R!A<W-O8VEA9&%S(&$@96QA<RX`36%P
M96%M96YT;R!-87`R-`!-87!E86UE;G1O($UA<%%U97-T`$UA<&5A;65N=&]S
M(&=R879A9&]S+@!-87+G;P!-87)G96T`36%R8V%R(&-O;2!F;&%G<R!,:61A
M+T[C;R!,:61A`$UA<F-A<B!C;VT@;W5T<F]S(&9L86=S("AE>"X@26UP;W)T
M86YT92]297-P;VYD:61A*0!);&AA<R!-87)S:&%L;`!-87)T:6YI8V$`0V%M
M<&]S(&-O<G)E<W!O;F1E;G1E<P!-875R:73B;FEA`$UA=7+M8VEO`$-RZ61I
M=&\@;>%X:6UO('!E<FUI=&ED;RX`3OIM97)O(&WA>&EM;R!D92!P87)T97,@
M9&$@;65N<V%G96T@97AC961E=2X`5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z
M;'1I;6%S(#(T(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I
M;6%S(#8@:&]R87,Z(`!.^FUE<F\@3>%X:6UO(&1E($)L;V-O<R!D92!0;W)T
M86P`5&%M86YH;R!MX7AI;6\`36%I;P!-87EO='1E`$UE9&EC:6YA`$UE;6)R
M;W,`36]D;R!D;R!M96YU.@!-97-C;&%R(&/I;'5L87,`365N<V%G96T`365N
M<V%G96T@5F5R:69I8V%D82!C;VT@4W5C97-S;R!M87,@;R!C97)T:69I8V%D
M;R!D;R!A<W-I;F%N=&4@;N-O('#T9&4@<V5R('9E<FEF:6-A9&\N`$UE;G-A
M9V5M(&5X<&ER861A+@!4:7!O(&1E(&UE;G-A9V5M`$-L:6UA($UE=&%R`$)L
M;V-O($UE=&%R(&[C;R!D:7-P;V[M=F5L+@!";&]C;R!-971A<B!NXV\@9&ES
M<&]N[79E;"X@1&5T86QH97,@9F]R86T@9W)A=F%D;W,@96T@;&]G('!A<F$@
M;R!A9&UI;FES=')A9&]R+@!/($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861O
M+@!-Z71O9&\`3>ET;V1O("<E<R<@;N-O(&5S=.$@9&5F:6YI9&\`3>ET;V1O
M(&[C;R!D969I;FED;RX@3>ET;V1O(&-H86UA9&\Z("5S`$WI=')I8V$`3>EX
M:6-O`$UI8W)O;NES:6$L($5S=&%D;W,@1F5D97)A9&]S(&1A`$UE:6\`5&EP
M;R!-:6UE`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A
M<SH@`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`V(&AO<F%S.B``
M261A9&4@;>UN:6UA(&1A('-E;FAA(&%I;F1A(&[C;R!E>'!I<F]U`$5S<&5L
M:&\`1&EV97)S;W,`4&%C;W1E(%!%05(@2%144%]297%U97-T(&9A;'1A;F1O
M+@!#;VYF:6=U<F'GXV\@9F%L=&%N9&\N(%9O8^H@=&5M('%U92!G97)A<B!E
M;&$@86=O<F$@<V4@=F]CZB!Q=65R('5T:6QI>F%R(&5S=&$@87!L:6-AY^-O
M+@!)1"!D82!M96YS86=E;2!F86QT86YD;RX`4&%C;W1E(&]B<FEG873S<FEO
M(%!%05(@36%I;"!F86QT86YD;RX`240@9&$@<V5S<^-O(&9A;'1A;F1O+@!3
M96<`0V]R<F5I;R!-\W9E;`!-;V1E<F%R`$1A=&$@36]D:69I8V%D80!!;'1E
M<F%R(%523`!-\V1U;&\`36]L9&]V82P@4F5P^F)L:6-A(&1A`$WT;F%C;P!-
M;VYG\VQI80!-ZG,@92!A;F\`365N<V%L;65N=&4`36]N='-E<G)A=`!&87-E
M<R!D82!,=6$`36%I<R!C86UP;W,@96YC;VYT<F%D;W,@;F$@;&EN:&$@)60@
M<75E(&\@;OIM97)O(&5S<&5R861O("5D+@!-87)R;V-O<P!'<F%N9&4@4&%R
M=&4@3&EM<&$`1W)A;F1E(%!A<G1E($YU8FQA9&\`1W)A;F1E(%!A<G1E($5N
M<V]L87)A9&\`36]V97(@06)A:7AO`$UO=F5R(.`@17-Q=65R9&$`36]V97(@
MX"!$:7)E:71A`$UO=F5R($%C:6UA`$%B86EX;P!!8VEM80!-;^=A;6)I<75E
M`$QI<W1A<R!D92!S96QEY^-O(&1E(&WZ;'1I<&QO<R!N[79E:7,`36%P87,@
M26YG;&5S97,@375L=&EM87``4V5L9>?C;R!M^FQT:7!L80!-:6YH82!#;VYT
M80!3=6%S($EN9F]R;6'G]65S`$UE=2!0;W)T86P`365U($QA>6]U="!D92!0
M;W)T86P`0FER;>)N:6$`3L-/+"!%=2!.PT\@0V]N8V]R9&\`3F]M90!.86WM
M8FEA`$YA=7)U`$YE<&%L`$AO;&%N9&$`06YT:6QH87,@2&]L86YD97-A<P!5
M4DP@0F%S92!D;R!.971S8V%P90!54DP@9&4@4F5V;V=AY^-O(&1E($-!(&1O
M($YE='-C87!E`%523"!D92!P;VSM=&EC87,@9&4@0T$@9&\@3F5T<V-A<&4`
M55),(&1E(%)E;F]V8>?C;R!D;R!.971S8V%P90!54DP@9&4@4F5V;V=AY^-O
M(&1O($YE='-C87!E`$YO;64@9&\@<V5R=FED;W(@4U-,(&1O($YE='-C87!E
M`$-O;65N=.%R:6\@9&\@8V5R=&EF:6-A9&\@9&\@3F5T<V-A<&4`5&EP;R!D
M92!C97)T:69I8V%D;R!D;R!.971S8V%P90!2961E`$YU;F-A`$YO=F$@0V%L
M963T;FEA`$YO=F$@0V%T96=O<FEA`$YO=F$@365N<V%G96T@<&%R82`E<P!,
M=6$@3F]V80!.;W9O(%5S=>%R:6\@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA
M`$YO=F$@<V5N:&$`3F]V82!S96YH82!E>'!I<F%RX2!E;2`E>"X`07,@;F]V
M87,@<V5N:&%S(&[C;R!SXV\@:6=U86ES+@!.;W9A(&IA;F5L82`H7V)L86YK
M*0!.;W3M8VEA<P!'<G5P;W,@9&4@3F]T[6-I87,`4'+S>&EM80!0<O-X:6UA
M<R`T($9A<V5S`%!R\WAI;6%S(&]PY_5E<P!0<O-X:6UA/@!.:6-A<N%G=6$`
M3FEG97(`3FEGZ7)I80!.;VET90!.:75E`$[C;P!.96YH=6T@9&%D;R!D92!C
M;VYF:6=U<F'GXV\@9&ES<&]N[79E;"!P87)A(&5X:6)I<B!A<R!D:69E<F5N
MYV%S+@!.96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(&-R:6%R
M(&EM86=E;G,@25-/+@!.96YH=6T@;6]D96QO(&1E(&)A=&-H+@!.96YH=6T@
M8FQO8V\@97AI<W1E(&YA('!O<VGGXV\@<V]L:6-I=&%D80!.96YH=6T@;F]M
M92!D92!A9V5N9&$@9F]R;F5C:61O('!A<F$@82!A=71E;G1I8V'GXV\@34-!
M3"X`3F5N:'5M82!A;'1E<F'GXV\N`$YE;FAU;2!S=6)O<F1I;F%D;R!P;V1E
M('-E<B!A9&EC:6]N861O(&$@97-T82!P97)M:7-SXV\N`$YE;FAU;6$@:6YF
M;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@)7,N
M`$YE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC
M861A('!A<F$@1E10(%9&4RX`3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I
M9W5R8>?C;R!E<W!E8VEF:6-A9&$@<&%R82!344P@5D93+@!.96YH=6UA(&EN
M9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A(%-1
M3"U&:6QE(%9&4RX`3F5N:'5M(&-RZ61I=&\@<F5S=&%N=&4N`$YE;FAU;2!D
M97-T:6YO(&9O<FYE8VED;RX`3F5N:'5M(&%R<75I=F\@96YV:6%D;P!.96YH
M=6T@[6-O;F4@96YC;VYT<F%D;RX`3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF
M:6=U<F%D82X`3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82X`3F5N
M:'5M82!M96YS86=E;2!F;W)N96-I9&$N`$YE;FAU;2!N;VUE(&5S<&5C:69I
M8V%D;RX`3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A9&\N`%-E;2!S;W)T97,@
M;V9E;G-I=F%S`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E
M;G1I8V'GXV\@2%144"X`3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A
M(&%U=&5N=&EC8>?C;R!)34%0+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P
M87)A(&$@875T96YT:6-AY^-O($ME<F)E<F]S+@!.96YH=6UA('-E;FAA(&9O
M<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O($QO9VEN+@!.96YH=6UA('-E
M;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O(%!!4U-71"X`3F5N
M:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!334(N
M`$YE;FAU;2!P871H('!A<F$@;R!B:6[A<FEO(&1O($]P96Y34TP@9F]I(&9O
M<FYE8VED;RX@3R!B:6[A<FEO(&1O($]P96Y34TP@Z2!N96-E<W/A<FEO('!A
M<F$@;6%N:7!U;&%R(&]S(&1A9&]S(%!+0U,@,3(N`$YE;FAU;2!C861A<W1R
M;R!P96YD96YT92X`475O=&$@;N-O(&-O;F9I9W5R861A+@!396T@;&EN:&%S
M`$YE;FAU;2!S97!A<F%D;W(@9F]I(&5S<&5C:69I8V%D;RX`4V5M(&QA9&]S
M`$%R<75I=F\@:6YE>&ES=&5N=&4`3F5N:'5M(&1I<F5T\W)I;R!T96UP;W+A
M<FEO(&1I<W!O;NUV96P@<&%R82!O(&-A8VAE+@!.96YH=6T@=7-UX7)I;R!E
M+V]U('-E;FAA(&9O<FYE8VED;W,N`$YE;FAU;2!D861O(%A-3"!VX6QI9&\@
M<F5T;W)N861O`%-E;2!V86QO<F5S`$YE;FAU;2!V97)SXV\@96YC;VYT<F%D
M82!N82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN($=E<F4@;F]V86UE;G1E(&$@
M8V]N9FEG=7)AY^-O+@!.96YH=6UA('9E<G/C;R!E;F-O;G1R861A(&YA('-U
M82!C;VYF:6=U<F'GXV\N($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O
M+@!.96YH=6UA`$YE;FAU;6$@*'5S;R!I;7!L[6-I=&\I`$[S<F1I8V\@*$E3
M3RTX.#4Y+3$P*0!);&AA($YO<F9O;&L`2&5M:7-FZ7)I;R!.;W)T90!);&AA
M<R!-87)I86YA(&1O($YO<G1E`$YO<G5E9V$`3N-O($%P\W,`3N-O($%N=&5S
M`$[C;R#I('5M(&1I<F5T\W)I;P!.XV\@26UP;&5M96YT861O+@!.XV\@8V]N
M9FEG=7)A9&\`3N-O('-U<&]R=&%D;RX`06YO=&'G]65S`$YA9&$@<&%R82!E
M>&EB:7(L('9O;'1E+@!.;W9E;6)R;P!.^FUE<F\`3OIM97)O(&1E(&-A<F%C
M=&5R97,`3OIM97)O(&1E(&-O;'5N87,`3OIM97)O(&1E(&QI;FAA<P!.^FUE
M<F\@;N-O(&5S<&5C:69I8V%D;R!P87)A(&%T=6%L:7IAY^-O(&YA(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RX`3TL`3V)J971O`$-R:6%D;W(@9&\@3V)J971O
M`$]C=&%L`$]U='5B<F\`1FEL=')O(&]F96YS:79O`$5S8W)I=/-R:6\`4V5N
M:&%S(&%N=&EG82!E(&YO=F$@9&5V96T@<V5R(&1I9F5R96YT97,N`%-E;FAA
M(&%N=&EG80!396YH82!A;G1I9V$@;N-O(&5S=.$@8V]R<F5T82X`3VWC`%-O
M;65N=&4@<V5R=FED;W)E<R!)34%0('-U<&]R=&%M('!A<W1A<R!C;VUP87)T
M:6QH861A<RX`4V]M96YT92!S;W)T97,@;V9E;G-I=F%S`%-O;65N=&4@=6T@
M96YD97)EYV\@9&4@92UM86EL('!E<FUI=&ED;RX`4V]M96YT92!O('!R;W!R
M:65TX7)I;R!O=2!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M82!P;V1E;2!A
M;'1E<F%R(&%S('!E<FUI<W/U97,@9&4@<')O<')I961A9&4@;W4@<')O<')I
M973A<FEO(&1E('5M(&-O;7!A<G1I;&AA;65N=&\`06)R:7(@96T@=6UA(&YO
M=F$@:F%N96QA`$5R<F\@9&\@3W!E;E-33#H@3N-O('!U9&4@97AT<F%I<B!D
M861O<R!D82!P87)T92!A<W-I;F%D82!3+TU)344N`$%B<F4@97-T92!L:6YK
M(&5M('5M82!N;W9A(&IA;F5L80!3:7-T96UA($]P97)A8VEO;F%L`$]PY_5E
M<P!/<.?U97,@9&4@)7,`3&ES=&$@3W)D96YA9&$`3W)G86YI>F'GXV\`56YI
M9&%D92!/<F=A;FEZ86-I;VYA;`!/<F=A;FEZ86YD;P!-;V1E;&\@;W)I9VEN
M86P@9&4@87!L:6-AY^-O`$UO9&5L;R!O<FEG:6YA;"!E;2`E<SH`3W5T<F\`
M3W5T<F%S($EN9F]R;6'G]65S`%!E<FUI<W/U97,@9&\@4')O<')I973A<FEO
M`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E;"X`0V]N96-T
M;W(@4$5!4CHZ36%I;`!!<W-I;F%T=7)A($1I9VET86P@4$=0`$1A9&]S($-R
M:7!T;V=R869A9&]S(&-O;2!01U``0VAA=F4@4/IB;&EC82!01U``1&%D;W,@
M07-S:6YA9&]S+T-R:7!T;V=R869A9&]S(&-O;2!01U``0_-D:6=O(%!(4`!,
M:6YH82!D92!#;VUA;F1O(%!(4`!#:'5V82!&<F%C82!697-P97)T:6YA`$-H
M=79A(%9E<W!E<G1I;F$`0VAU=F%S(%9E<W!E<G1I;F%S`$YE=F4@5F5S<&5R
M=&EN80!.979A<V-A(%9E<W!E<G1I;F$`3F5V92!697-P97)T:6YA`%1R;W9O
M861A<R!697-P97)T:6YA<P!%<W3A(&9A;'1A;F1O(&$@97AT96YSXV\@4$]3
M25@`3&EN:&$@9&4@0V]M86YD;R!07TA0`$UA<F=E;0!087%U:7-TXV\`4&%L
M874`4&%L97-T:6YO+"!497)R:73S<FEO($]C=7!A9&\`4&%N86WA`%#A<'5A
M($YO=F$@1W5I;ND`4&%R86=U86D`4&%R8VEA;&UE;G1E($YU8FQA9&\`4V5N
M:&$`4V5N:&$@86QT97)A9&$@8V]M('-U8V5S<V\N`%-E;FAA(&EN8V]R<F5T
M80!396YH82!O8G)I9V%T\W)I82!P87)A(&$@875T96YT:6-AY^-O(%)!1$E5
M4RX`4V5N:&$@8V]M(&-O;F9I<FUAY^-O`%-E;FAA.@!396YH83H@`%-E;FAA
M<R!D979E;2!S97(@:6=U86ES+@!#;VQA<@!#;VQA<B!D82#A<F5A(&1E('1R
M86YS9F5RZFYC:6$`4&%T:`!#861A<W1R;W,@4&5N9&5N=&5S.@!097-S;V%S
M`%!O<F-E;G1A9V5M`$5X96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O
M`$5X96-U=&%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%O(&-O;F5C=&%R
M/P!097)M:7-SXV\`4&5R;6ES<^-O("(E<R(@;N-O(&5X8VQU[61A+@!097)M
M:7-SXV\@3F5G861A`%!E<FUI<W/U97,`061M:6YI<W1R8>?C;R!D92!097)M
M:7-S]65S`$EN9F]R;6'G]65S(%!E<W-O86ES`%!E<G4`06YI;6%I<R!D92!%
M<W1I;6'GXV\`1FEL:7!I;F%S`%1E;&5F;VYE`$9O=&]S`%!I=&-A:7)N`%!I
M>&5L<P!#;&EC:.D`4&]R(&9A=F]R(&-L:7%U92!E;2!A;&=U;6$@8^EL=6QA
M`%!O<B!F879O<B!C;VYF:7)M92!Q=64@=F]CZB!Q=65R(')E;6]V97(@97-T
M92!E;&5M96YT;SH`4&]R(&9A=F]R(&-O;F9I<FUE('%U92!V;V/J('%U97(@
M<F5M;W9E<B!O(&QI;FL@9&5S=&4@96QE;65N=&\N`%!O<B!F879O<B!F;W)N
M9>=A('5M(&WJ<R!E('5M(&%N;RX`4&]R(&9A=F]R(&9O<FYEYV$@=6T@;F]M
M92!P87)A(&$@;F]V82!C871E9V]R:6$Z`%!O<B!F879O<B!F;W)N9>=A('5M
M(&5N9&5R9>=O($E0(';A;&ED;RX`4&]R(&9A=F]R(&9O<FYEYV$@=6UA(&1A
M=&$@=N%L:61A+"!V97)I9FEQ=64@;R!N^FUE<F\@9&4@9&EA<R!N;R!MZG,N
M`%!O<B!F879O<B!F;W)N9>=A('5M82!H;W)A(';A;&ED82X`4&]R(&9A=F]R
M(&9O<FYEYV$@=6T@<F5S=6UO(&1O('!R;V)L96UA+@!0;W(@9F%V;W(@9F]R
M;F7G82!S974@=7-UX7)I;R!E('-E;FAA`%!O<B!F879O<B!L96EA(&\@=&5X
M=&\@82!S96=U:7(N(%9O8^H@1$5612!C;VYC;W)D87(@8V]M(&]S('1E<FUO
M<R!D92!U<V\@9&\@<VES=&5M82X`4&]R(&9A=F]R(&1I9VET92!O(&YO;64@
M9&$@;F]V82!C871E9V]R:6$Z`%!O;/1N:6$`4&]L[71I8V$`16YQ=65T90!0
M;W)T=6=A;`!0;W-IY^-O(&1E<W1A(&EM86=E;0!0;W-IY^-O(&1E<W1A('1A
M8F5L80!%;G9I92!P87)A(&5S=&$@<&%S=&$@*&[C;R#I(&]B<FEG861O('!E
M;&\@24U!4"D`4')E8VEP:71AY^-O('!A<F$@82AS*2#Z;'1I;6$H<RD@)7,@
M:&]R82AS*3H@`%!R96-I<&ET8>?C;SQB<B`O/F-H86YC90!0<F5F<U]L9&%P
M.B!%>'1E;G/C;R!,1$%0(&]B<FEG873S<FEA(&[C;R!E;F-O;G1R861A+@!0
M<F5F<U]S97-S:6]N.B!%>'1E;G/C;R!D92!S97-SXV\@;V)R:6=A=/-R:6$@
M;N-O(&5N8V]N=')A9&$N`%!R97-SXV\`4')E<W/C;R!E;2!N[79E;"!D;R!M
M87(Z(`!0<F5S<^-O.B``4'+I+79I<W5A;&EZ8>?C;P!0<F5V97(@82!I;6%G
M96T@96T@=6UA(&YO=F$@:F%N96QA`$]PY_5E<R!A;G1E<FEO<F5S`$EM<')I
M;6ER(&1O8W5M96YT;P!#:&%V92!0<FEV861A`%!R;V)L96UA`$1E<V-R:>?C
M;R!D;R!0<F]B;&5M80!0<F]J971O<P!497AT;R!B<F5V90!#:&%V92!0^F)L
M:6-A`$%L9V]R:71M;R!D82!#:&%V92!0^F)L:6-A`$-H879E(%#Z8FQI8V$`
M4&%R(&1E(&-H879E<R!0^F)L:6-A+U!R:79A9&$@;N-O(&9O<F%M(&=E<F%D
M;W,@8V]M('-U8V5S<V\N`%!O<G1O(%)I8V\`46%T87(`0V]N<W5L=&%R`%%A
M=&%R`$-H879E(%#Z8FQI8V$@4E-!("@E9"!B:70I`$)O=/5E<R!D92!S96QE
MY^-O`$-H=79A`$-H=79A($UA='5T:6YA`$-H=79A(%9E<W!E<G1I;F$`4&%N
M8V%D87,@9&4@0VAU=F$`0VAU=F$@92!.979E`$-H=79A('!A<F$@3F5V90!3
M;W)T92!!;&5A=/-R:6$`4F5L8>?C;P!,97(`3&5R(&UE;G-A9V5N<P!%>&-L
M=6ER(')E86QM96YT92`E<S\@17-T82!O<&5R8>?C;R!NXV\@<&]D92!S97(@
M9&5S9F5I=&$N`%)E;6]V97(@<F5A;&UE;G1E(&]S(&1A9&]S(&1O('5S=>%R
M:6\@)7,_($5S=&$@;W!E<F'GXV\@;N-O('!O9&4@<V5R(&1E<V9E:71A+@!2
M969A>B!S=6$@^FQT:6UA(&'GXV\`071U86QI>F%R`$%T=6%L:7IA<B!-96YU
M(&1E($5L96UE;G1O<R!$:6[B;6EC;W,Z`$%T=6%L:7IA<B!%>&EB:>?C;R!D
M;R!0;W)T86PZ`%)E9V5X`$YA=F5G861O<B!D92!296QAY_5E<P!,97(`3V)S
M97)V8>?U97,`4V5R=FED;W)E<R!296UO=&]S`%523"!296UO=&$@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F5R`%)E;6]V97(@0FQO
M8V\`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!F;W)M871AY^-O`%)E;6]V97(@
M<&%R`%)E;6]V97(@<V-R:7!T(&=R879A9&\@;F\@9&ER973S<FEO('1E;7!O
M<N%R:6\@9&\@<V5R=FED;W(N`%)E;6]V97(@;P!296UO=F5R(&5S=&4@;O,@
M9&\@9&]C=6UE;G1O`%)E;6]V97(@=7-UX7)I;P!296UO=F5R('5S=>%R:6\Z
M("5S`%-O;&EC:71AY^-O(&[C;R!P]&1E('-E<B!R97-P;VYD:61A+B!#\V1I
M9V\@9&4@97)R;R!R971O<FYA9&\Z(`!/('-E<G9IYV\@<F5Q=6ES:71A9&\@
M;N-O('!O9&4@<V5R(&5N8V]N=')A9&\N`"<E<R<@;V)R:6=A=/-R:6\@;N-O
M(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O("5S+@`G)7,G(&]B
M<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C
M;R!61E,N`"<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@
M;F$@8V]N9FEG=7)AY^-O+@!#86UP;R!/8G)I9V%T\W)I;P!,:6UP87(`1V5R
M87(@3F]V82!396YH80!'97)A<B!.;W9A(%-E;FAA`-IL=&EM;R!1=6%R=&\`
M4F5S=6QT861O<P!2971O<FYA<B#@($]PY_5E<P!$:6=I=&4@82!N;W9A('-E
M;FAA(&YO=F%M96YT90!2975N:>-O`%)E=F5R=&5R($-O;F9I9W5R8>?C;P!/
M<.?U97,@9&\@161I=&]R(%)I8V@@5&5X=`!#:&%R861A<P!$:7)E:71A`$-A
M8F7G86QH;R!D:7)E:71O`%9A;&]R97,@9&$@9&ER96ET80!0<F]P<FEE9&%D
M97,@9&$@7TQI;FAA+BXN`$9U;N?C;P!2;VWJ;FEA`$=I<F%R(#$X,"!G<F%U
M<P!':7)A<B!P87)A(&$@17-Q=65R9&$`1VER87(@<&%R82!A($1I<F5I=&$`
M4')O<')I961A9&5S(&1A($QI;FAA`%!R;W!R:65D861E<R!D82!L:6YH80!,
M:6YH87,Z`$QI;FAA<P!,:6YH87,@87!A<F5C97+C;R!E;G1R92!T;V1A<R!A
M<R!L:6YH87,@92!C;VQU;F%S`$QI;FAA<R!A<&%R96-E<N-O('-O;65N=&4@
M96YT<F4@8V]L=6YA<P!,:6YH87,@87!A<F5C97+C;R!S;VUE;G1E(&5N=')E
M(&QI;FAA<P!%>&5C=71A<@!&961E<F'GXV\@4G5S<V$`4G5A;F1A`$%S<VEN
M871U<F$@0W)I<'1O9W+A9FEC82!3+TU)344`365N<V%G96T@0W)I<'1O9W)A
M9F%D82!C;VT@4R]-24U%`$%U=&5N=&EC8>?C;R!305-,(&[C;R!E<W3A(&1I
M<W!O;NUV96PN`$-O<G)E:6\@4TU3`$QI;FAA(&1E(&-O;6%N9&\@4U%,`%-E
M;G1E;N=A(%-13"!P87)A('!E<W%U:7-A<R!D92!V86QO<F5S`%-32`!354-%
M4U-/`$QI;FAA(&1E(&-O;6%N9&\@4U]13`!386(`4V%N=&$@2&5L96YA`%/C
M;R!+:71T<R!E($YE=FES`%-A;G1A($QU>FEA`%/C;R!0961R;R!E($UI<75E
M;&]N`%/C;R!6:6-E;G1E(&4@1W)A;F%D:6YA<P!-97-M;R!Q=6%D<F\@*%]S
M96QF*0!386UO80!386X@36%R:6YO`%/C;R!4;VWI(&4@4'+M;F-I<&4`4')O
M=F5D;W(@9&4@4V%TZ6QI=&4`07+A8FEA(%-A=61I=&$`4V%L=F%R`%-A;'9A
M<B`E<P!386QV87(@)7,`4V%L=F%R($]PY_5E<P!386QV87(@8V]N9FEG=7)A
MY^-O(&=E<F%D82!C;VUO('5M('-C<FEP="!02%`@<&%R82!O(&1I<F5T\W)I
M;R!T96UP;W+A<FEO(&1O('-E=2!S97)V:61O<BX`0V]N9FEG=7)AY^-O("5S
M('-A;'9A+@!38W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O
M('-A;'9O(&5M.B`G)7,G+@!496UP97-T861E<R!)<V]L861A<P!#:>IN8VEA
M`%!E<W%U:7-A<@!%;F=I;F5S(&1E(%!E<W%U:7-A(`!396QE8VEO;F4@;W,@
M07)Q=6EV;W,`4V5L96-I;VYE('5M82!D871A`%-E;&5C:6]N92!U;2!G<G5P
M;R!P87)A(&%D:6-I;VYA<@!396QE8VEO;F4@=6T@;F]V;R!M96UB<F\`4V5L
M96-I;VYE('5M('-E<G9I9&]R`%-E;&5C:6]N92!U;2!U<W7A<FEO('!A<F$@
M861I8VEO;F%R`%-E;&5C:6]N87(@=&]D;W,`4V5L96-I;VYE('1O9&]S(&]S
M(&-O;7!O;F5N=&5S(&1E(&1A=&$N`%-E;&5C:6]N92!U;2!O8FIE=&\`3N-O
M('-E;&5C:6]N87(@;F5N:'5M`%-E;&5C:6]N92!O<R!C87)A8W1E<F5S('%U
M92!V;V/J('!R96-I<V$@;F$@8V%I>&$@86)A:7AO+B!6;V/J('!O9&4@96YT
MXV\@8V]P:>$M;&]S(&4@8V]LX2UL;W,@;F$@X7)E82!D92!T97AT;RX`4V5L
M96-I;VYE('5M(&1E;&EM:71A9&]R(&1E(&1A=&$Z`%-E;&5C:6]N92!O(&9O
M<FUA=&\@9&4@9&%T83H`4V5L96-I;VYE(&$@:61E;G1I9&%D92!Q=64@=F]C
MZB!Q=65R(&%L=&5R87(Z`%-E;&5C:6]N92!U;2!D96QI;6ET861O<B!D92!H
M;W)A.@!396QE8VEO;F4@;R!F;W)M871O(&1E(&AO<F$Z`%-E;&5C:6]N92!D
M;VES(&-A;7!O<R!C;W)R97-P;VYD96YT97,N`%-E;&5C:6]N92!S974@97-Q
M=65M82!D92!C;W)E<RX`4V5L96-I;VYE('-E=2!I9&EO;6$@<')E9F5R:61O
M.@!%;G9I87(@4F5L873S<FEO(&1E(%!R;V)L96UA`$5N=FEA<B!335,`4V5N
M96=A;`!396YS;W(Z(`!3971E;6)R;P!397)V:6$@92!-;VYT96YE9W)O`$[Z
M;65R;R!D92!3Z7)I90!$861O<R!D;R!S97)V:61O<B!E<G)A9&]S(&]U(&[C
M;R!D:7-P;V[M=F5I<RX`061M:6YI<W1R861O<B!D92!397-SXV\`240@9&$@
M4V5S<^-O(&5X<&ER;W4N`%-E<W/U97,`06IU<W1A<@!#;VYF:6=U<F$@87,@
M;W#G]65S('!A<F$@<&5R;6ET:7(@=F]CZB!G97)A<B!U;6$@;F]V82!S96YH
M82!S92!V;V/J(&5S<75E8^HM;&$N`$-O;F9I9W5R82!O<R!S97)V:61O<F5S
M(')E;6]T;W,@<75E('9O8^H@<75E<B!A8V5S<V%R(.`@<&%R=&ER(&1O('!O
M<G1A;"X`0V]N9FEG=7)A('-E=2!I9&EO;6$@<')E9F5R:61O+"!F=7-O(&AO
M<N%R:6\@92!O<.?U97,@9&4@9&%T82X`0V]N9FEG=7)A('-U82!A<&QI8V'G
MXV\@:6YI8VEA;"P@97-Q=65M82!D92!C;W)E<RP@871U86QI>F'GXV\@9&4@
M<.%G:6YA<R!E(&]U=')A<R!O<.?U97,@9&4@97AI8FGGXV\N`$-O;F9I9W5R
M8>?C;P!38W)I<'1S(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!D
M:7-P;V[M=F5I<P!$:79E<G-A<R!L;V-A;&ED861E<R!P;W-S[79E:7,@8V]M
M(&\@<&%RXFUE=')O.B``4V5I8VAE;&5S`$-O;7!R87,`4F5S=6UO`%1E8VQA
M<R!D92!A=&%L:&\@9&5V97+C;R!S97(@9&5F:6YI9&%S('!A<F$@82!M86EO
M<FEA(&1O<R!L:6YK<S\`17AI8FER`$5X:6)I<B!A<R!D:69E<F5NYV%S(&5N
M=')E(&$@8V]N9FEG=7)AY^-O(&%T=6%L(&4@82!N;W9A(&=E<F%D82X`17AI
M8FER(&1A=&$@92!H;W)A(&1A(/IL=&EM82!C;VYE>.-O(&%O('-E(&-O;F5C
M=&%R/P!%>&EB:7(@82!O<.?C;R!D92!M86YT97(@;R!O<FEG:6YA;`!%>&EB
M:7(@<V5L971O<@!%>&EB:7(@8F%R<F$@9&4@;65N=2!C;VT@;W!E<F'G]65S
M(&1E('1A8F5L83\`17AI8FER(&\@365N=2`E<R#@(&5S<75E<F1A/P!%>&EB
M:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D82!486)E
M;&$`17AI8FER(&1IX6QO9V\@9&4@4')O<')I961A9&5S(&1A(%1A8F5L80!%
M>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@3&EN:&%S(&1A(%1A
M8F5L80!%>&EB:7(@9&GA;&]G;R!D92!P<F]P<FEE9&%D97,@9&4@:6UA9V5M
M`$5X:6)I<B!U<&QO860`0VAU=F%S`$-H=79A<R!M871I;F%I<P!#:'5V87,@
M5F5S<&5R=&EN87,`0VAU=F%S(&YA<R!R961O;F1E>F%S`%)E9'5Z:7(`4')I
M;65I<F%M96YT92!R961U>F$@;W4@=&ER92!D;R!C86UI;FAO(&\H<RD@8FQO
M8V\H<RD@861J86-E;G1E*',I`%-E<G)A($QE;V$`4F5G:7-T<F%R`$%S<VEN
M871U<F$`06QG;W)I=&UO(&1A($%S<VEN871U<F$`0VEN9V%P=7)A`%1A;6%N
M:&\`26=N;W)A<B!-86YU=&5NY^-O`$5S;&]VX7%U:6$`17-L;W9E;FEA`$YE
M=F4`3F5V87-C80!.979A<V-A<P!#:'5V87,@;6%T:6YA:7,`3F5V87-C87,@
M5F5S<&5R=&EN87,`4')O9G5N9&ED861E(&1A($YE=F4Z(`!%<75I=F%L96YT
M92!D92!N979E(&5M(.%G=6$Z(`!);&AA<R!386QO;>-O`%-O;>%L:6$`0V%N
MY_5E<R`F(%!O96UA<P!/<F1E;F%R('-E;&7GXV\`16YD97)EYV\@9&4@;W)I
M9V5M`,%F<FEC82!D;R!3=6P`4W5L($5U<F]P974@*$E33RTX.#4Y+3,I`%-U
M;"!D82!'96]R9VEA(&4@4W5L(&1A<R!);&AA<R!386YD=>UC:&4`2&5M:7-F
MZ7)I;R!3=6P`17-P8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E<P!%<W!A
MYV\@96YT<F4@;R!C;VYT9?ID;R!E(&)O<F1A(&1A(&/I;'5L80!%<W!AYV%D
M;W(`17-P8>=A;65N=&\`17-P8>=A;65N=&\@92!M87)G96T`17-P86YH80!3
M<&%M`$5N=')A9&$@9&4@0V%R86-T97)E<R!%<W!E8VEA:7,`1&EV:61I<B!C
MZ6QU;&$`1&EV:61I<B!C;VQU;F$`1&EV:61I<B!L:6YH80!%<W!O<G1E<P!3
M<FD@3&%N:V$`4&%D<N-O`%-T87(@5')E:P!!;F\@:6YI8VEA;`!%<W1A9&\@
M;W4@4')O=NUN8VEA`%-I='5AY^-O`$9O<FUA=&\@9&\@87)M87IE;F%M96YT
M;P!.;VUE(&1A(%)U80!4<F'G861O`$QI<W1A(&1E(&-A9&5I87,@9&4@8V%R
M86-T97)E<P!2971I<F%R(&$@<&%R=&4@9&\@9&]M[6YI;R!D;R!E;F1E<F7G
M;P!%<W1I;&\@6T-34UT`1&]M`%-U8F1I<F5T\W)I;R`G)7,G(&[C;R!E;F-O
M;G1R861O+@!!<W-U;G1O`$5N=FEA<@!%;G9I861A(&$@<V]L:6-I=&'GXV\@
M9&4@861I8VEO;F%R("(E<R(@86\@<VES=&5M82X@5F]CZB!NXV\@<&]D92!C
M;VYE8W1A<BUS92!A=.D@<75E('-U82!S;VQI8VET8>?C;R!S96IA(&%P<F]V
M861A+@!3=6)S8W)E=F5R`%-U8V5S<V\`)R5S)R!A9&EC:6]N861O(&-O;2!S
M=6-E<W-O(&%O('-I<W1E;6$N`$]S(&1A9&]S(&1O('5S=>%R:6\@)R5S)R!F
M;W)A;2!R96UO=FED;W,@9&\@<VES=&5M82!C;VT@<W5C97-S;RX`)R5S)R!E
M>&-L=>UD;R!C;VT@<W5C97-S;RX`17AC;'7M9&\@)R5S)R!D;R!S:7-T96UA
M(&-O;2!S=6-E<W-O+@!#;VYF:6=U<F'GXV\@<F5V97)T:61A(&-O;2!S=6-E
M<W-O+B!!='5A;&EZ92!P87)A('9E<B!A<R!A;'1E<F'G]65S+@!"86-K=7`@
M9&$@8V]N9FEG=7)AY^-O('-A;'9A(&-O;2!S=6-E<W-O+@!/(&)A8VMU<"!D
M;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<R!F;VD@<V%L=F\@8V]M('-U
M8V5S<V\N`"<E<R<@871U86QI>F%D;R!C;VT@<W5C97-S;P`E<R!G<F%V861O
M(&-O;2!S=6-E<W-O`%-U9.-O`%)E<W5M;P!!;6%N:&5C97(`4/1R+61O+5-O
M;`!%;G-O;&%R861O`$%M86YH96-E<@!!;6%N:&5C97(O4/1R+61O+5-O;`!!
M;6%N:&5C97(Z(`!0]'(M9&\M4V]L`%#T<BUD;RU3;VPZ(`!3;V)R97-C<F5V
M97(`4W5P;W)T90!3=7)I;F%M90!3;V)R96YO;64`4W9A;&)A<F0@92!*86X@
M36%Y96X`4W5A>FELXFYD:6$`4W7I8VEA`%-U[>=A`$[C;R!E>&-L=6ER`%-Y
M;F--3`!%<G)O(&1E('-I;G1A>&4@;F]S('1E<FUO<R!D82!P97-Q=6ES80!2
M97#Z8FQI8V$@P7)A8F4@9&$@4^UR:6$`5&5M<&5S=&%D90!496UP97-T861E
M<R!E(%9E;G1A;FEA`%1E;7!E<W1A9&5S`%1E;7!E<W1A9&5S($UA=&EN86ES
M`$%R<75I=F\@5%-6`%1A8F5L80!0<F]P<FEE9&%D97,@9&$@5&%B96QA`%1A
M8F5L80!0<F]P<FEE9&%D97,@9&$@=&%B96QA`%1A:7=A;@!486EW86XL(%!R
M;W;M;F-I82!D82!#:&EN80!486II<75I<W3C;P!486YZXFYI82P@4F5P^F)L
M:6-A(&1A`$%L=F\Z`%1A<F5F87,`3OIM97)O(&1E(%1E;&5F;VYE`%1E;7!E
M<F%T=7)A('!A<F$@82#Z;'1I;6$@:&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E
M<F%T=7)A.B``5&5M<&5R871U<F$\8G(@+SXH)7-!;'1A)7,O)7-"86EX825S
M*2`F9&5G.R5S`$UO9&5L;R`G)7,G(&[C;R!E;F-O;G1R861O+@!!9&UI;FES
M=')AY^-O(&1E($UO9&5L;W,`5&5X=&\`4V]M96YT92!497AT;P!!;&EN:&%M
M96YT;R!D92!497AT;P!";W)D82!S=7!E<FEO<B!D;R!497AT;P!1=6D`5&%I
M;&%N9.IS("A425,M-C(P*0!486ELXFYD:6$`02!E>'1E;G/C;R!&5%`@;N-O
M(&5S=.$@9&ES<&]N[79E;"X`3R!H:7-T\W)I8V\@9&\@<VES=&5M82!E<W3A
M(&1E<V%B:6QI=&%D;RX`02!E;F=I;F4@9&4@:6YT96=R8>?C;R!(;W)D92]+
M;VQA8B!NXV\@<W5P;W)T82`B)7,B`$\@;&]G($E-4U`@;N-O('!O9&4@<V5R
M(&EN:6-I86QI>F%D;RX`02!C;&%S<V4@(DUA:6YT96YA;F-E(B!NXV\@9F]I
M(&-A<G)E9V%D82!C;VT@<W5C97-S;P!!(&IA;F5L82!D92!/<.?U97,@9F]I
M(&9E8VAA9&$N(%-A:6YD;RX`3R!A9&UI;FES=')A9&]R('!R96-I<V$@8V]N
M9FEG=7)A<B!U;2!C;VYE8W1O<B!P97)M86YE;G1E(&1E(%!E<FUI<W/U97,@
M<V4@=F]CZB!Q=65R('5T:6QI>F%R(%!E<FUI<W/U97,N`%-O;65N=&4@;R!L
M861O(&1E(&)A:7AO`$\@;OIM97)O($E$(&1O(&-O;G1A=&\@;N-O(&9O:2!E
M<W!E8VEF:6-A9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@96YC
M;VYT<F%D;R!N;R!B86YC;R!D92!D861O<RX`3R!C;VYT871O(&9O:2!A9&EC
M:6]N861O(&-O;2!S=6-E<W-O(&%O('-E=2!C873A;&]G;R!D92!E;F1E<F7G
M;W,N`%!A<F$@=F5R:69I8V%R(&$@;65N<V%G96T@87-S:6YA9&$@Z2!N96-E
M<W/A<FEO('5M(&)L;V-O('-E<&%R861O(&1A(&%S<VEN871U<F$@4$=0+@!/
M($E$(&1A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I
M8V%D;RP@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O
M(&YO(&)A;F-O(&1E(&1A9&]S+@!!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!N
MXV\@9F]I(&5S<&5C:69I8V%D82X`07,@9G5NY_5E<R!D92!C<FEP=&]G<F%F
M:6$@<F5Q=65R96T@=6UA(&-O;F5XXV\@=V5B('-E9W5R82X`3R!A<G%U:79O
M("5S(&1E=F5R:6$@8V]N=&5R('5M82!C;VYF:6=U<F'GXV\@9&4@)7,N`$\@
M87)Q=6EV;R`E<R!D979E<FEA(&-O;G1E<B!A;&=U;6%S(&-O;F9I9W5R8>?U
M97,@9&4@)7,N`$\@87)Q=6EV;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A
M(&5L92!M97-M;RX`3R!A<G%U:79O(&[C;R!C;VYTZ6T@9&%D;W,N`%-E9W5E
M;2!O<R!C86)EYV%L:&]S(&1E<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F8S@R
M,BX`R2!S86)I9&\@<75E(&\@;6]D;R!T96QA(&-H96EA(&-A=7-A('!R;V)L
M96UA<R!C;VT@;R!);G1E<FYE="!%>'!L;W)E<BP@96T@=FER='5D92!D92!B
M=6=S(&1O(&YA=F5G861O<B!Q=64@;O-S(&[C;R!E<W1A;6]S(&%P=&]S(&$@
M8V]N=&]R;F%R+B!6;V/J('!O9&4@;V)S97)V87(@97)R;W,@9&4@97AI8FGG
MXV\L(&9A;'1A(&1E(&9U;N?U97,@9&\@961I=&]R(&4O;W4@=')A=F%M96YT
M;W,@86QE873S<FEO<R!D;R!N879E9V%D;W(N(%-E('-E=2!S:7-T96UA(.D@
M5VEN9&]W<R`Y>"#I(&UU:71O('!R;W;A=F5L('%U92!V;V/J(')E8V5B82!U
M;2!E<G)O(&1E("=&86QH82!'97)A;"!D92!0<F]T9>?C;R<@92!P<F5C:7-A
M<N$@<F5I;FEC:6%R+B!<;EQN(%9O8^H@9F]I(&%V:7-A9&\N(%!O<B!F879O
M<B!P<F5S<VEO;F4@3TL@<V4@=F]CZB!A:6YD82!Q=65R('1E;G1A<B!U<V%R
M(&\@961I=&]R(&1E('1E;&$@8VAE:6$N`$$@:61E;G1I9&%D92`B)7,B(&9O
M:2!E>&-L=>UD82X`4V]M96YT92!O(&QA9&\@97-Q=65R9&\`02!L;V-A;&EZ
M8>?C;R!D;R!B:6[A<FEO(&1O($=N=5!'(&1E=F4@<V5R(&9O<FYE8VED82#@
M(&-L87-S92`B0W)Y<'1?<&=P(BX`02!M96YS86=E;2!E;G9I861A(&5M("5S
M('!A<F$@)7,@8V]M(&\@87-S=6YT;R`B)7,B(&9O:2!E>&EB:61A+@I)<W1O
M(&[C;R!G87)A;G1E('%U92!A(&UE;G-A9V5M(&9O:2!L:61A(&]U(&5N=&5N
M9&ED82X`3R!N;VUE('5T:6QI>F%D;R!A;R!V:6YC=6QA<B!A('#A9VEN82!D
M92!C;VUP;W-IY^-O`$\@;OIM97)O(&1E(&-A;7!O<R!D979E('-E<B!N=6WI
M<FEC;RX`3R!M\V1U;&\@;W!E;G-S;"#I(&]B<FEG873S<FEO('!A<F$@82!C
M;&%S<V4@(DAO<F1E7T-R>7!T7W-M:6UE(BX`02!P<F5F97+J;F-I82`B)7,B
M(&[C;R!P;V1E('-E<B!S86QV82!P;W)Q=64@<V5U<R!D861O<R!E>&-E9&5R
M86T@;R!T86UA;FAO(&WA>&EM;R!P97)M:71I9&\`3R!P<F]G<F%M82!U=&EL
M:7IA9&\@<&%R82!V:7-U86QI>F%R(&5S=&4@=&EP;R!D92!D861O("@E<RD@
M;N-O(&9O:2!E;F-O;G1R861O(&YO('-I<W1E;6$N`$\@8V%R86-T97)E('!A
M<F$@8VET8>?C;R!D92!S97(@87!E;F%S('5M+@!3;VUE;G1E(&]S(&QA9&]S
M(&1I<F5I=&\@92!E<W%U97)D;P!3;VUE;G1E(&\@;&%D;R!D:7)E:71O`$\@
M<V5P87)A9&]R(&1E=F4@<V5R('5M(/IN:6-O(&-A<F%C=&5R92X`3R!S97)V
M:61O<B`B)7,B(&9O:2!E>&-L=>UD;RX`3R!S97)V:61O<B`B)7,B(&9O:2!S
M86QV;RX`02!S;VQI8VET8>?C;R!D92!C861A<W1R;R!D92`E<R!F;VD@97AC
M;'7M9&$N`$$@;&EN:&$@97-P96-I9FEC861A("@E9"D@;N-O(&5X:7-T92X`
M3R!A<G%U:79O('1E;7!O<N%R:6\@(B5S(B!NXV\@97AI<W1E+@!/('1E>'1O
M('%U92!V;V/J(&1I9VET;W4@;N-O(&-O<G)E<W!O;F1E(&%O('1E>'1O(&YA
M('1E;&$N`%-O;65N=&4@;W,@;&%D;W,@9&4@8VEM82!E(&1E(&)A:7AO`%-O
M;65N=&4@;R!L861O(&1E(&-I;6$`3W,@9&%D;W,@96YV:6%D;W,@9F]R86T@
M<&5R9&ED;W,@9&5S9&4@;R!P87-S;R!A;G1E<FEO<BX`3R!A<G%U:79O(&5N
M=FEA9&\@;N-O('#T9&4@<V5R('-A;'9O+@!/(&)L;V-O(")W96%T:&5R+F-O
M;2(@;N-O(&5S=.$@9&ES<&]N[79E;"X`3R!D:7)E=/-R:6\@9&4@=&5M87,@
M)R5S)R!NXV\@9F]I(&5N8V]N=')A9&\N`$[C;R!E>&ES=&5M(&]PY_5E<R!D
M:7-P;V[M=F5I<RX`3N-O(&5X:7-T96T@<&%R=&5S('%U92!P;W-S86T@<V5R
M(&5X:6)I9&%S(&EN8V]R<&]R861A<RX`17AI<W1E;2!M=6ET;W,@8V%R86-T
M97)E<R!N97-T92!C86UP;RX@5F]CZB!P<F5E;F-H974@8V]M("5S(&-A<F%C
M=&5R97,[('9O8^H@9&5V92!P<F5E;F-H97(@8V]M("5S(&]U(&UE;F]S+@!(
M;W5V92!U;2!P<F]B;&5M82!A9&EC:6]N86YD;R`G)7,G(&%O('-I<W1E;6$Z
M("5S`$AO=79E('5M('!R;V)L96UA(&%O(&5X8VQU:7(@9&\@<VES=&5M82!O
M<R!D861O<R!D;R!U<W7A<FEO("<E<R<Z(`!(;W5V92!U;2!P<F]B;&5M82!A
M;R!E>&-L=6ER("<E<R<@9&\@<VES=&5M83H@`$AO=79E('5M('!R;V)L96UA
M(&%O(&%T=6%L:7IA<B`G)7,G.B`E<P!(;W5V92!U;2!P<F]B;&5M82!C;VT@
M;R!E;G9I;R!D;R!A<G%U:79O.B!.96YH=6T@)7,@9F]I(&5N=FEA9&\N`$AO
M=79E('5M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\N($\@)7,@
M97)A(&UA:6]R('%U92!O('1A;6%N:&\@;>%X:6UO('!E<FUI=&ED;R`H)60@
M8GET97,I+@!(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A<G%U
M:79O+B!/("5S(&9O:2!E;G9I861O('!A<F-I86QM96YT92X`2&]U=F4@=6T@
M97)R;R!A;R!E>&EB:7(@97-T82!P87)T92!D82!M96YS86=E;0!(;W5V92!U
M;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S(&1O(&-O;G1A=&\N`$AO=79E
M('5M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@9&\@:4-A;&5N9&%R+@!(
M;W5V92!U;2!E<G)O(&YO(&9O<FUU;.%R:6\@9&4@8V]N9FEG=7)AY^-O+B!4
M86QV97H@=F]CZB!D96EX;W4@=6T@8V%M<&\@;V)R:6=A=/-R:6\@96T@8G)A
M;F-O+@!(;W5V92!U;2!E<G)O(&%O(&5X96-U=&%R(&$@9G5NY^-O(&1E(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<R!E<W!E8VEF:6-A9&$N(%!O<B!F879O<B!T
M96YT92!N;W9A;65N=&4@;6%I<R!T87)D92X`2&]U=F4@=6T@97)R;R!A;R!A
M='5A;&EZ87(@;W,@9&5T86QH97,@9&\@8V]N=&%T;RX@4&]R(&9A=F]R('1E
M;G1E(&YO=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T
M=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E
M;G1E(&YO=F%M96YT92!M86ES('1A<F1E+@!%<W1E('-E<G9I9&]R($E-05`@
M;N-O('-U<&]R=&$@<&%S=&%S(&-O;7!A<G1I;&AA9&%S+@!%<W1E(&[C;R!P
M87)E8V4@<V5R('5M(&%R<75I=F\@<F%R(';A;&ED;RX`17-T92!NXV\@<&%R
M96-E('-E<B!U;2!A<G%U:79O('II<"!VX6QI9&\N`$5S=&4@;N-O('!A<F5C
M92!S97(@=6T@;OIM97)O(&1E(&-A<G3C;R!VX6QI9&\N`$5S=&4@8V]N96-T
M;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2P@=71I;&EZ86YD;R!A($%0
M22!(5%10`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS
M(&%T<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PN8V]M*2P@=71I;&EZ86YD;R!O($%022!(5%10`$5S=&4@8V]N96-T;W(@
M<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@9V%T97=A>2!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=71I;&EZ86YD;R!O
M($%022!(5%10`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@=6UA(&UE
M;G-A9V5M('9I82!33510(&%T<F%VZ7,@9&\@5F]D869O;F4@271A;&EA;F\L
M('-O;65N=&4@<&%R82!N^FUE<F]S(%9O9&%F;VYE+B#)(&]B<FEG873S<FEO
M('!O<W-U:7(@=6UA(&-O;G1A(&YO(%9O9&%F;VYE($ET86QI86YO("AH='1P
M.B\O=W=W+C$Y,"YI="DN`$5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RX`17-T
M92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@;OIM97)O<R!I;G1E:7)O<RX`
M17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@;OIM97)O<R!E(';M<F=U
M;&$N`$5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S('9A;&]R97,@;V-T
M86ES+@!%<W1E(&-A;7!O(&1E=F4@<V5R('5M82!L:7-T82!D92!N^FUE<F]S
M(&EN=&5I<F]S('-E<&%R861A('!O<B!V[7)G=6QA<R!O=2!E<W!AYV]S`$5S
M=&4@8V%M<&\@9&5V92!S97(@=6T@;OIM97)O(';A;&ED;RX`17-T92!C86UP
M;R!D979E(&-O;G1E<B!U;2!C\V1I9V\@9&4@8V]R(&5M(&9O<FUA=&\@4D="
M($AE>&$L('!O<B!E>&5M<&QO("<C,3(S-&%F)RX`17-T92!F;W)M=6SA<FEO
M(&KA(&9O:2!P<F]C97-S861O+@!)<W1O(.D@)7,N`$5S=&4@Z2!U;2!O8FIE
M=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9I<W5A;&EZ87(@97-T92!O8FIE
M=&\@=F]CZB!P<F5C:7-A<N$@9&4@=6T@8VQI96YT92!D92!C;W)R96EO('%U
M92!E;G1E;F1A(&\@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=6UA
M(&QI<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@8V]M(&5S=&%S(&9U;N?U
M97,@<&]R(&9A=F]R('9I<VET92`E<P!%<W1A(&UE;G-A9V5M(&9O:2!E<V-R
M:71A(&5M('5M(&-O;FIU;G1O(&1E(&-A<F%C=&5R97,@*"5S*2!Q=64@;N-O
M(.D@;R!M97-M;R!Q=64@;R!S974N`$5S=&4@;OIM97)O(&1E=F4@<V5R('!E
M;&\@;65N;W,@=6TN`$5S=&4@<V5R=FED;W(@;N-O('!O9&4@9&5S8V]M<')I
M;6ER(&%R<75I=F]S('II<"!E(&=Z:7`N`$5S=&4@<VES=&5M82!E<W3A(&%T
M=6%L;65N=&4@9&5S871I=F%D;RX`17-T92!V86QO<B!D979E('-E<B!U;2!N
M^FUE<F\N`$5S=&$@:F%N96QA(&1E=F4@<V5R(&-H86UA9&$@82!P87)T:7(@
M9&$@:F%N96QA(&1E($]PY_5E<P!286EO`$)I;&AE=&5S`$AO<F$`06-O;7!A
M;FAA;65N=&\@9&4@2&]RX7)I;P!&;W)M871O(&1E(&AO<F$`4V5L9>?C;R!D
M92!H;W)A`%1I;6]R($QE<W1E`%3M='5L;P!!<W-U;G1O("AD:6-A*3H`4&%R
M80!087)A('-E;&5C:6]N87(@;?IL=&EP;&]S(.UT96YS+"!S96=U<F4@82!T
M96-L82!#;VYT<F]L("A00RD@;W4@0V]M;6%N9"`H36%C*2!A;R!C;&EC87(N
M`$AO:F4`5')O8V%R('!A<F$@8_-D:6=O($A434P`5&]G;P!4;VME;&%U`$%M
M86YHXP!4;VYG80!4;W!O`%%U861R;R!D;R!4;W!O("A?=&]P*0!4<F%D=>?U
M97,`5')I;F1A9&4@92!4;V)A9V\`5F5R9&%D96ER;R!O=2!F86QS;P!497(`
M5'5N[7-I80!4=7)Q=6EA`%1U<F-O("A)4T\M.#@U.2TY*0!4=7)C;VUE;FES
M=.-O`$EL:&%S(%1U<FMS(&4@0V%I8V]S`%1U=F%L=0!0<F5E;F-H82!C;VT@
M<W5A(&5S8V]L:&$Z(`#-;F1I8V4@52Y6+CH@`%523`!54DP@9&\@<V5U(')E
M;&%T\W)I;R!D92!S:71U8>?C;R!D92!E;G1R96=A`%523#H`56=A;F1A`%5C
M<N)N:6$`26UP;W-S[79E;"!A8V5S<V%R(&1I<F5T\W)I;R!61E,N`$EM<&]S
M<^UV96P@861I8VEO;F%R(&EN9F]R;6'G]65S(&5X=')A<R!D92!U<W7A<FEO
M(&%O(')E9VES=')A<BX`26UP;W-S[79E;"!A;'1E<F%R('!E<FUI<W/C;R!D
M;R!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&%L=&5R87(@<&5R;6ES
M<^-O(&1O(&%R<75I=F\@5D93("5S+R5S+@!);7!O<W/M=F5L(&%L=&5R87(@
M<&%R82`E<RX`26UP;W-S[79E;"!V97)I9FEC87(@;R!T86UA;FAO(&1O(&%R
M<75I=F\@9&4@(B5S(BX`26UP;W-S[79E;"!V97)I9FEC87(@;R!T86UA;FAO
M(&1O(&%R<75I=F\@9&4@(B5S+R5S(BX`26UP;W-S[79E;"!C;VYE8W1A<B!A
M;R!S97)V:61O<B!344PN`$EM<&]S<^UV96P@8V]N96-T87(@=71I;&EZ86YD
M;R!34TPN`$EM<&]S<^UV96P@8V]P:6%R(&%R<75I=F\@5D93+@!);7!O<W/M
M=F5L(&-R:6%R(&1I<F5T\W)I;R!61E,@(B5S(BX`26UP;W-S[79E;"!C<FEA
M<B!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@5D93
M+@!);7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93("(E<R(N`$EM<&]S
M<^UV96P@8W)I87(@87)Q=6EV;R!61E,@=F%Z:6\N`$EM<&]S<^UV96P@9&5S
M8V]M<')I;6ER(&1A9&]S+@!);7!O<W/M=F5L(&5X8VQU:7(@(B5S(BP@;R!D
M:7)E=/-R:6\@;N-O(&5S=.$@=F%Z:6\N`$EM<&]S<^UV96P@97AC;'5I<B`B
M)7,B.B`E<RX`26UP;W-S[79E;"!E>&-L=6ER("5S+"!O(&1I<F5T\W)I;R!N
MXV\@97-TX2!V87II;P!);7!O<W/M=F5L(&5X8VQU:7(@<F5C=7)S:79A;65N
M=&4@;R!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@9&ER973S
M<FEO(%9&4RX`26UP;W-S[79E;"!E>&-L=6ER(&1I<F5T\W)I;R!61E,Z("5S
M+@!);7!O<W/M=F5L(&5X8VQU:7(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S
M[79E;"!E>&-L=6ER(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@
M87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!E>&-L=6ER(%9&4R!R96-U
M<G-I=F%M96YT93H@)7,N`$EM<&]S<^UV96P@9&5T97)M:6YA<B!O(&1I<F5T
M\W)I;R!A='5A;"X`26UP;W-S[79E;"!E>'1R86ER(&1E=&%L:&5S(&1O(&-E
M<G1I9FEC861O`$EM<&]S<^UV96P@8V%R<F5G87(@82!D969I;FGGXV\@9&4@
M)7,N`$EM<&]S<^UV96P@;6]V97(@;R!A<G%U:79O(%9&4RX`26UP;W-S[79E
M;"!A8G)I<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&%B<FER(&%R
M<75I=F\@5D93('!A<F$@9W)A=F'GXV\N`$EM<&]S<^UV96P@86)R:7(@87)Q
M=6EV;R!61E,N`$EM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!C;VUP<FEM:61O
M+@!);7!O<W/M=F5L(&QE<B!A<G%U:79O(%9&4R`H9FEL97-I>F4H*2!F86QH
M;W4I+@!);7!O<W/M=F5L(&QE<B!A<G%U:79O(%9&4R`H9V5T1FEL95-I>F4H
M*2!F86QH;W4I+@!);7!O<W/M=F5L(&QE<B!O(&%R<75I=F\Z(`!);7!O<W/M
M=F5L(&QE<B!A(')A:7H@9&\@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!R
M96YO;65A<B`E<R!P87)A("5S.B!A('!A<W1A(&1E(&1E<W1I;F\@:N$@97AI
M<W1E`$EM<&]S<^UV96P@<F5N;VUE87(@;R!D:7)E=/-R:6\@5D93+@!);7!O
M<W/M=F5L(')E;F]M96%R(&1I<F5T\W)I;R!61E,Z("5S+@!);7!O<W/M=F5L
M(')E;F]M96%R(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@<F5N;VUE
M87(@87)Q=6EV;R!61E,@)7,O)7,N`$EM<&]S<^UV96P@<F5N;VUE87(@87)Q
M=6EV;R!61E,N`$EM<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G+@!);7!O
M<W/M=F5L('1R861U>FER(&5S=&4@9&]C=6UE;G1O(%=O<F0`26UP;W-S[79E
M;"!G<F%V87(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!G<F%V87(@
M87)Q=6EV;R!61E,@*&-O<'DH*2!F86QH;W4I+@!);7!O<W/M=F5L(&=R879A
M<B!D861O<R!D;R!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!G<F%V87(@87)Q
M=6EV;R!61E,L('%U;W1A(&5X8V5D97+A+@!3=6)L:6YH861O`$1E<V9A>F5R
M($%L=&5R8>?U97,`1&5S9F%Z('-U82#Z;'1I;6$@8>?C;P!297-P;W-T82!I
M;F5S<&5R861A(&1O('-E<G9I9&]R(&1U<F%N=&4@82!C;VYE>.-O.B``4F5S
M<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!P87)A.B``4V5M(&-A=&5G
M;W)I80!5;FEC;V1E("A55$8M."D`16UI<F%D;W,@P7)A8F5S(%5N:61O<P!2
M96EN;R!5;FED;P!%<W1A9&]S(%5N:61O<P!);&AA<R!097)I9NER:6-A<R!-
M96YO<F5S(&1O<R!%<W1A9&]S(%5N:61O<P!5;FED861E<P!$97-C;VYH96-I
M9&\`87!I;7-G:60@9&5S8V]N:&5C:61O("A!4$D@365S<V%G92!)1"DN`&-L
M:6US9VED(&1E<V-O;FAE8VED;R`H0VQI96YT($UE<W-A9V4@240I+@!.96YH
M=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+@!5<W7A<FEO(&]U('-E;FAA
M(&1E<V-O;FAE8VED;W,N`$1E<W9I;F-U;&%R(&\@96QE;65N=&\@871U86P`
M4V5M($YO;64`4V-R:7!T<R!NXV\@<')I=FEL96=I861O<R!NXV\@<&]D96T@
M=71I;&EZ87(@0V]R=&%R+T-O<&EA<B]#;VQA<B!P;W(@<F%Z]65S(&1E('-E
M9W5R86[G82X@0VQI<75E(&5M($]+('!A<F$@=F5R(&$@;F]T82!TZ6-N:6-A
M(&5M(&UO>FEL;&$N;W)G(&$@<75A;"!E;G-I;F$@8V]M;R!P97)M:71I<B!S
M8W)I<'1S(&%C97-S87)E;2!A(.%R96$@9&4@=')A;G-F97+J;F-I82X`1&5S
M;6%R8V%R(&-O<@!%>'1E;G/C;R!.XV\@4W5P;W)T861A`$%T=6%L:7IA<@`E
M<R!A='5A;&EZ861O`$%T=6%L:7IA<B!U<W7A<FEO`"<E<R<@871U86QI>F%D
M;RX`4V-R:7!T(&1E(&%T=6%L:7IAY^-O(')E;6]V:61O+@!%;G9I87(`5&]D
M;W,@87)Q=6EV;W,@9&4@(&-O;F9I9W5R8>?U97,@9&%S(&%P;&EC8>?U97,@
M9F]R86T@96YV:6%D;W,@86\@<V5R=FED;W(N`$%L9F%B971O(&QA=&EN;R!E
M;2!M86GZ<V-U;&\`3OIM97)O<R!R;VUA;F]S(&5M(&UA:?IS8W5L;P!5<G5G
M=6%I`%5T:6QI>F%R($%T=6%L.B`E<P!5=&EL:7IA<B!34TP`571I;&EZ87(@
M<V4@;R!N;VUE+W-E;FAA(.D@9&EF97)E;G1E(&YO('-E<G9I9&]R($E-4U`N
M`%5S=>%R:6]S`%5S=>%R:6\@)7,@;N-O(&5S=.$@875T;W)I>F%D;R!P87)A
M("5S+@!!9&UI;FES=')AY^-O(&1E(%5S=>%R:6]S`$]PY_5E<R!D92!5<W7A
M<FEO<P!296=I<W1R;R!D92!5<W7A<FEO<P!296=I<W1R;R!D92!5<W7A<FEO
M<R!E<W3A(&1E<V%B:6QI=&%D;R!N97-T92!S:71E+@!#;VYT82!D92!U<W7A
M<FEO(&[C;R!E;F-O;G1R861A`%5S=>%R:6\`57-UX7)I;R`G)7,G(&KA(&5X
M:7-T92X`57-UX7)I;SH`57-UX7)I;SH@`%5S=>%R:6]S(&YO('-I<W1E;6$Z
M`%5Z8F5Q=6ES=.-O`$\@9&ER973S<FEO(%9&4R!NXV\@97AI<W1E+@!&Z7)I
M87,`3&]C86QI>F'G]65S(';A;&ED87,@96YC;VYT<F%D87,@:6YC;'5E;3H@
M`%9A;&ED861E`%9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@9&4@86=O<F$N
M`$\@=F%L;W(@97-TX2!A8VEM82!D;R!T86UA;FAO(&WA>&EM;R!D92`E<RX`
M5F%L;W)E<P!686QO<F5S('!A<F$@<V5L96-I;VYA<@!686YU871U`%9A<FGA
M=F5L`%9E;F5Z=65L80!&86QH82!N82!V97)I9FEC8>?C;R`M(&5S=&$@;65N
M<V%G96T@<&]D92!T97(@<VED;R!A9'5L=&5R861A+@!697)SXV\`0V]N=')O
M;&4@9&4@5F5R<^-O`$%L:6YH86UE;G1O('9E<G1I8V%L`$UA<F=E;2!V97)T
M:6-A;`!697)T:6-A;#H`375I=&\@06QT80!6:65T;N,`5FEE=&YA;6ET82`H
M5DE30TE)*0!697(@)7,`5FES=6%L:7IA<B!U;6$@<.%G:6YA('=E8B!E>'1E
M<FYA`%9I<W5A;&EZ87(@8V]M;R`E<P!);&AA<R!6:7)G96YS+"!"<FETXFYI
M8V%S`$EL:&%S(%9I<F=E;G,L($4N52Y!+@!6:7-I8FEL:61A9&4`5FES:6)I
M;&ED861E.B``5F]D869O;F4@271A;&EA;F\@=FEA(%--5%``051%3L?#3P!!
M5$5.Q\-/(2$A(%)%34]602!/(%-#4DE05"!-04Y504Q-14Y412!$12`E<RX`
M5TE.('9I82!(5%10`%=A;&QI<R!E($9U='5N80!!=&5NY^-O`%%U80!0<F5V
M:7/C;R!D;R!496UP;P!$861O<R!D;R!#;&EM82!F;W)N96-I9&\@<&]R`%=E
M871H97(N8V]M`%=E8@!3:71E(%=E8@!396UA;F%L;65N=&4`0F5M+79I;F1O
M`$)E;2UV:6YD;R!A;R`E<P!"96TM=FEN9&\L("5S`$]C:61E;G1A;"`H25-/
M+3@X-3DM,2D`3V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4V%H87)A($]C:61E
M;G1A;`!1=64@87!L:6-AY^-O("5S(&1E=F5R:6$@97AI8FER(&%P\W,@82!C
M;VYE>.-O/P!1=6%L(&\@8V%R86-T97)E(&1E;&EM:71A9&]R/P!1=6%L(&\@
M8V%R86-T97)E(&1E(&-I=&'GXV\_`$UA<&%S($%U<W1R86QI86YO<R!7:&5R
M96ES`%%U86ES(&9A<V5S`%%U86ES('!L=6=I;G,@:&%B:6QI=&%R('!A<F$@
M;R!E9&ET;W(@4FEC:"!497AT+@!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D
M97,@0U-3`$QA<F=U<F$@9&\@;65N=2`E<R!D;R!L861O(&5S<75E<F1O("AT
M97+A(&5F96ET;R!N82!P<O-X:6UA(&-O;F5XXV\I.@!,87)G=7)A(&1A('1A
M8F5L80!5;FED861E(&1E($QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT;P!6
M96YT;W,@<&5L82!M86YHXP!696QO8VED861E(&1O('9E;G1O(&5M(&[S<P!6
M96YT;SH`5F5N=&\Z(`!386)E9&]R:6$`3&ES=&$@9&4@<&5D:61O<P!4<F%B
M86QH;P!%;F1E<F7G;R!#;VUE<F-I86P`1F]N92!#;VUE<F-I86P`3OIM97)O
M(&EN8V]R<F5T;R!D92!C86UP;W,@;F$@;&EN:&$@)60N($5S<&5R861O<R`E
M9"P@96YC;VYT<F%D;W,@)60N`$[Z;65R;R!E<G)A9&\@9&4@8V%M<&]S+B!%
M<W!E<F%D;W,@)60L(&5N8V]N=')A9&]S("5D+@!/9F9S970@)60@:6YC;W)R
M971O(&%O(&QE<B!O(&%R<75I=F\@5D93+@!8+5)E9@!297-T<FGG]65S($+A
M<VEC87,@6#4P.78S`%5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U
M,#EV,P!.;VUE($%L=&5R;F%T:79O(&1E($%S<W5N=&\@6#4P.78S`$ED96YT
M:69I8V%D;W(@9&$@0VAA=F4@9&4@07-S=6YT;R!8-3`Y=C,`17AT96YS]65S
M(%@U,#EV,P!!00!!04%!`$UA<&$@66%H;V\A`$%N=6%L;65N=&4`3.IM96X`
M4VEM`%-I;2P@174@0V]N8V]R9&\`5F]CZB!E<W3A(&5M($U/1$\@5$585$\N
M("!5=&EL:7IA(&\@8F]TXV\@6SP^72!P87)A('9O;'1A<B!P87)A(&\@;6]D
M;R!765-)5UE'+@!6;V/J(&[C;R!E<W3A(&%U=&]R:7IA9&\@82!C<FEA<B!M
M86ES(&1E("5D(&)L;V-O<RX`5F]CZB!NXV\@97-TX2!A=71E;G1I8V%D;RX`
M5F]CZB!NXV\@<&]D92!T97(@;R!C87)A8W1E<B!<(&YO('-E=2!N;VUE+@!6
M;V/J(&[C;R!F;W)N96-E=2!U;2!E;F1E<F7G;R!D92!E+6UA:6P@=N%L:61O
M+@!6;V/J(&[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R<75I=F\@:6UP
M;W)T861O(&%O<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S(&5M("5S+@!6;V/J
M(&9O:2!D97-C;VYE8W1A9&\N`%9O8^H@9&5V92!P<F5E;F-H97(@=6T@;OIM
M97)O(&1E('1E;&5F;VYE(&-E;'5L87(@=N%L:61O+"!S;VUE;G1E(&3M9VET
M;W,@8V]M('5M(&]P8VEO;F%L("<K)R!P87)A(&1I<V-A9V5M(&1E('!R969I
M>&\@:6YT97)N86-I;VYA;"X`5F]CZB!D979E('!R965N8VAE<B!U;2!V86QO
M<B!VX6QI9&\N`%9O8^H@9&5V92!C;VYF:6=U<F%R('5M(&-O;F5C=&]R($1A
M=&%4<F5E('!A<F$@=71I;&EZ87(@0V%D87-T<F]S+@!6;V/J(&1E=F4@8V]N
M9FEG=7)A<B!U;2!C;VYE8W1O<B!61E,N`%9O8^H@9&5V92!D97-C<F5V97(@
M;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R:6\@9&4@<')O
M8FQE;6$N`%9O8^H@9&5V92!F;W)N96-E<B!A(%523"!O;F1E(&\@;&EN:R!A
M<&]N=&$`5F]CZB!D979E('-E;&5C:6]N87(@=6T@<V5R=FED;W(@<&%R82!S
M97(@97AC;'7M9&\N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO
M('!A<F$@97AC;'5I<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R
M:6\@<&%R82!R96UO=F5R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-U
MX7)I;R!P87)A(&%D:6-I;VYA<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M
M('5S=>%R:6\@<&%R82!A='5A;&EZ87(N`%9O8^H@9&5V92!E<W!E8VEF:6-A
M<B!U;6$@8>?C;R!P87)A(&5X96-U=&%R+@!6;V/J(&1E=F4@<')E96YC:&5R
M('5M(&YO;64@<&%R82!A(&YO=F$@8V%T96=O<FEA+@!6;V/J('!R96-I<V$@
M9F]R;F5C97(@=6T@;OIM97)O(&1E('1E;&5F;VYE(&ET86QI86YO`%-U82!S
M97-SXV\@)7,@97AP:7)O=2X@4&]R(&9A=F]R+"!C;VYE8W1E+7-E(&YO=F%M
M96YT92X`4V5U($5N9&5R9>=O(&1E($4M;6%I;`!3974@16YD97)EYV\@9&4@
M4F5M971E;G1E("A$93HI.@!3=6%S($EN9F]R;6'G]65S`%-E=2!%;F1E<F7G
M;R!D92!);G1E<FYE="!M=61O=2!D97-D92!O(&EN[6-I;R!D92!S=6$@<V5S
M<^-O("5S+B!087)A('!R;W1E9V5R('-U82!S96=U<F%NYV$@=F]CZB!D979E
M(&-O;F5C=&%R+7-E(&YO=F%M96YT92X`4V5U($YO;64`4V5U(&)A8VME;F0@
M9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&%D:>?C;R!D92!U<W7A<FEO
M<RP@;W4@82!F=6[GXV\@9F]I(&1E<V%B:6QI=&%D82!P;W(@86QG=6UA(&]U
M=')A(')A>N-O+@!3974@8F%C:V5N9"!D92!A=71E;G1I8V'GXV\@;N-O('-U
M<&]R=&$@;&ES=&%G96T@9&4@=7-UX7)I;W,L(&]U(&$@9G5NY^-O(&9O:2!D
M97-A8FEL:71A9&$@<&]R(&%L9W5M82!O=71R82!R87KC;RX`4V5U(&YA=F5G
M861O<B!P87)E8V4@=&5R(&%L=&5R861O(&1E<V1E(&\@:6[M8VEO(&1E('-U
M82!S97-SXV\@)7,N(%!A<F$@<')O=&5G97(@<W5A('-E9W5R86[G82P@=F]C
MZB!D979E(&-O;F5C=&%R+7-E(&YO=F%M96YT92X`4V5U(&YA=F5G861O<B!N
MXV\@<W5P;W)T82!E<W1A(&9U;N?C;RX`4V5U(&YA=F5G861O<B!NXV\@<W5P
M;W)T82!E<W1A(&]PY^-O(&1E(&EM<')E<W/C;RX@4')E<W-I;VYE($-O;G1R
M;VPO3W!T:6]N("L@4"!P87)A(&EM<')I;6ER+@!3974@9G5S;R!H;W+A<FEO
M(&%T=6%L.@!3=6$@:61E;G1I9&%D92!P861RXV\@9F]I(&%L=&5R861A+@!3
M=6$@:61E;G1I9&%D92!P861RXV\Z`%-E=2!N;VUE(&-O;7!L971O.@!3=6$@
M8V]N97CC;R!E>'!I<F]U+@!3=6$@;F]V82!S96YH82!P87)A("5S(.DZ("5S
M`%-U87,@;W#G]65S(&9O<F%M(&%T=6%L:7IA9&%S('!O<B!C875S82!D82!D
M=7)AY^-O(&1E<W1A('-E<W/C;RX`4W5A<R!O<.?U97,@9F]R86T@871U86QI
M>F%D87,N`%-U82!N;W9A('-E;FAA(&9O:2!G97)A9&$`4W5A(&YO=F$@<V5N
M:&$@9F]I(&=E<F%D82P@=F5R:69I<75E('-E=2!E+6UA:6P@92!C;VYE8W1E
M+7-E(&-O;2!S=6$@;F]V82!S96YH82X`4W5A('-E;FAA(&5X<&ER;W4N`%-E
M=7,@<V5R=FED;W)E<R!R96UO=&]S.@!)=6=O<VSA=FEA`%IA:7)E`%KB;6)I
M80!::6UB86)W90!::7!P>0!;3V-U;'1A<B!497AT;R!#:71A9&]=`%M296QA
M=/-R:6\@9&4@4')O8FQE;6%=`%M%>&EB:7(@5&5X=&\@0VET861O("T`6T5X
M:6)I<B!497AT;R!#:71A9&\@+2`E<R!L:6YH87-=`%ML:6YH82`E<R!D92`E
M<UT`7T%D;6EN:7-T<F'GXV\`7T-,20!$871A7U1R964`15]X8VQU:7(@0V]L
M=6YA`%]'<G5P;W,`05]J=61A`%!R;W!R:65D861E<R!D82!?26UA9V5M+BXN
M`%]#;VYE8W1A<@!?1&5S8V]N96-T87(`05]L=&5R87(@3&EN:RXN+@!?3W#G
M]65S`%]097)M:7-S]65S`%]296UO=F5R($QI;FLN+BX`0V]N9FEG=7)A7W(`
M4')O<')I961A9&5S(&1A(%]486)E;&$N+BX`7U5S=>%R:6]S`&-A=.%L;V=O
M(&1E(&5N9&5R9>=O<P!C873A;&]G;R!D92!E;F1E<F7G;W,`86=E;F1A`&-A
M;&UO`&EM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!D92!D97-T:6YO`&EM<&]S
M<^UV96P@86)R:7(@82!O<FEG96T`8VQI<75E(&%Q=6D`97)R;R!D92!S:6YT
M87AE(&1A(&QI;FAA(&1E(&-O;6%N9&\`97)R;R!D92!C;VYF:6=U<F'GXV\`
M=6T@87)Q=6EV;R!C<NUT:6-O(&1O('-I<W1E;6$@97-TX2!F86QT86YD;P!E
M<G)O(&YO(&9O<FUA=&\@9&]S(&1A9&]S`&5D:71A<@!R96=I<W1R;R!NXV\@
M96YC;VYT<F%D;P!Q=65D80!A<G%U:79O`&$@<&%R=&ER(&1E("5S("@E<RD@
MX"`E<R`E<P!B<FES80!H.@!H:`!N;VUE(&1O(&AO<W0@Z2!D97-C;VYH96-I
M9&\`:6UE9&EA=&\`:6YC;W)P;W)A9&\`97)R;R!D92!E;G1R861A+W-A[61A
M`&5R<F\@:6YT97)N;R!D;R!P<F]G<F%M80!L:6YH87-=`&/S9&EG;R!D92!E
M<G)O("5D(&1O(&UK:7-O9G,@96YQ=6%N=&\@9V5R879A(&$@25-/+@!M;0!N
M;VUE`&[C;R!I;7!L96UE;G1A9&\`;N-O(&EM<&QE;65N=&%D;R!A:6YD80!B
M;&]C;R!D92!N;W1A<P!P;W)C96YT86=E;0!097)M:7-SXV\`<&EX96QS`&5R
M<F\@<F5M;W1O(&YO('!R;W1O8V]L;P!N87-C96YT90!S97)V:>=O(&EN9&ES
M<&]N[79E;`!E>&EB:7(@9&EF97)E;N=A<P!S;7,R96UA:6P@=FEA($A45%``
M<W,`97-TX79E;`!E<G)O(&1E('-I<W1E;6$`;&ES=&$@9&4@=&%R969A<P!F
M86QH82!T96UP;W+A<FEA`'!R965N8VAA('-U82!S96YH82!D=6%S('9E>F5S
M('!A<F$@8V]N9FER;6%R`'5N:69I8V%D;P!S96T@;F]M90!S96QEY^-O(&1E
M('5S=>%R:6\`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]P=%]"4B]H96QP+GAM;```````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`T,3<S-C(W-S<`
M,#(P,S0T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O
M;&]C86QE+W!T7T)2+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z
M,3,@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB
M('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*
M(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S
M=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&
M;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL
M(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@
M979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*
M("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S
M+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@
M8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@
M<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T
M:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R
M83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E
M(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O
M<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L
M=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H
M(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L
M:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T
M:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L
M:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@
M;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@
M<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT
M96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A
M/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I
M;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@
M("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL
M(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K
M('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O
M<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O
M;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O<'1?4%0O````````````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`Q-C<Q
M-P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]P=%]05"],0U]-15-3
M04=%4R\`````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C(W-S<`,#(P-3`T`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+W!T7U!4+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#0R-S,R-P`Q,#0Q-S,V,C<W-P`P,C(Q-38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````WA($E0````!S!P``
M'````+0[``#O"0``3'<````````(GP``30````F?``"_````5Y\``&0````7
MH```O@```'R@``"0````.Z$``$,```#,H0``/````!"B```K````3:(``"X`
M``!YH@``*0```*BB```H````TJ(``$4```#[H@``1P```$&C``!*````B:,`
M`$<```#4HP``10```!RD``!(````8J0``#D```"KI```1@```.6D``!(````
M+*4``#````!UI0``10```*:E``!&````[*4``$P````SI@``-````("F```R
M````M:8``&D```#HI@``,````%*G```E````@Z<``(@```"IIP``0````#*H
M``#V````<Z@``$H```!JJ0``+````+6I``"%````XJD``$@```!HJ@``#@``
M`+&J```/````P*H```T```#0J@``"````-ZJ```+````YZH```P```#SJ@``
M!`````"K```;````!:L``"T````AJP``'0```$^K```D````;:L``"D```"2
MJP``&0```+RK```,````UJL``!$```#CJP``)0```/6K```/````&ZP```L`
M```KK```$0```#>L```.````2:P```4```!8K```*````%ZL```(````AZP`
M``H```"0K```%0```)NL```2````L:P```L```#$K```$P```-"L```.````
MY*P```H```#SK```#0```/ZL```N````#*T```X````[K0``$0```$JM```-
M````7*T```P```!JK0``#0```'>M```&````A:T```H```",K0``#P```)>M
M```8````IZT```P```#`K0``&P```,VM```.````Z:T```X```#XK0``"```
M``>N```)````$*X``$(````:K@``+@```%VN```:````C*X``#(```"GK@``
M.````-JN``!4````$Z\``%$```!HKP``6@```+JO``!7````%;```#0```!M
ML```"0```**P```-````K+````<```"ZL```"@```,*P```/````S;````4`
M``#=L```!@```..P```1````ZK````@```#\L```"0````6Q```)````#[$`
M`"4````9L0``(````#^Q```0````8+$```\```!QL0``"@```(&Q```#````
MC+$```\```"0L0``%````*"Q```)````M;$```T```"_L0``$@```,VQ```9
M````X+$``!X```#ZL0``#P```!FR```*````*;(```\````TL@``"````$2R
M```D````3;(``!0```!RL@``%@```(>R```(````GK(``$X```"GL@``+0``
M`/:R```?````)+,``!D```!$LP``!P```%ZS```,````9K,``"P```!SLP``
M#@```*"S```#````K[,```L```"SLP``!P```+^S```'````Q[,```4```#/
MLP``!0```-6S```*````V[,```,```#FLP``%P```.JS```*`````K0```\`
M```-M```#@```!VT```8````++0``",```!%M```#@```&FT```4````>+0`
M`!<```"-M```%P```*6T```7````O;0``!,```#5M```#P```.FT```.````
M^;0``!\````(M0``'0```"BU```'````1K4```8```!.M0``"````%6U```/
M````7K4```8```!NM0``"@```'6U```3````@+4```L```"4M0``%0```*"U
M```5````MK4```<```#,M0``$````-2U```%````Y;4``!4```#KM0``$0``
M``&V```,````$[8``#L````@M@``.````%RV```)````E;8```<```"?M@``
M%````*>V```#````O+8```4```#`M@``$````,:V```)````U[8``!,```#A
MM@``.0```/6V```2````+[<``"<```!"MP``+````&JW```J````E[<``"4`
M``#"MP``"@```.BW```&````\[<```D```#ZMP``!P````2X```O````#+@`
M`#<````\N```+@```'2X``!5````H[@``"T```#YN```+0```">Y```M````
M5;D``$````"#N0``(P```,2Y```C````Z+D``"T````,N@``,P```#JZ```5
M````;KH``!D```"$N@``*0```)ZZ```D````R+H``!$```#MN@``"@```/^Z
M```,````"KL```H````7NP``$````"*[```6````,[L``!8```!*NP``!P``
M`&&[```'````:;L``!0```!QNP``"@```(:[```(````D;L```@```":NP``
M!P```*.[```'````J[L```8```"SNP``!0```+J[```'````P+L```8```#(
MNP``"````,^[```I````V+L```X````"O```"@```!&\```$````'+P```<`
M```AO```"0```"F\```&````,[P``!$````ZO```!P```$R\```6````5+P`
M``0```!KO```"````'"\```&````>;P```T```"`O```!@```(Z\```>````
ME;P``!$```"TO```(@```,:\```6````Z;P```@`````O0``#0````F]```,
M````%[T```<````DO0```P```"R]```#````,+T``!<````TO0``$P```$R]
M```=````8+T```@```!^O0``!````(>]```(````C+T```@```"5O0``00``
M`)Z]```@````X+T```8````!O@``!@````B^```5````#[X``!@````EO@``
M(@```#Z^```N````8;X``!T```"0O@``(0```*Z^``!4````T+X``"D````E
MOP``"@```$^_```'````6K\``!4```!BOP``#@```'B_```*````A[\```\`
M``"2OP``#0```**_```/````L+\```T```#`OP``"0```,Z_```4````V+\`
M``8```#MOP``&````/2_```=````#<```!,````KP```$0```#_````4````
M4<````0```!FP```!@```&O```!4````<L````0```#'P```#@```,S```!$
M````V\````4````@P0``!0```";!```;````+,$``!H```!(P0``$0```&/!
M```1````=<$``!P```"'P0``*@```*3!```0````S\$``"$```#@P0``)0``
M``+"```9````*,(```4```!"P@``$P```$C"```2````7,(```H```!OP@``
M#P```'K"```-````BL(``!$```"8P@``$P```*K"```,````OL(```8```#+
MP@``#````-+"```&````W\(``!<```#FP@``$````/["```1````#\,```@`
M```APP``!0```"K#```,````,,,``!`````]PP``!0```$[#```-````5,,`
M``8```!BPP``!P```&G#```-````<<,``!````!_PP``"0```)##```'````
MFL,```L```"BPP``"P```*[#```'````NL,```<```#"PP``%````,K#```)
M````W\,```D```#IPP``"@```//#```9````_L,``!T````8Q```#````#;$
M```0````0\0```4```!4Q```)0```%K$```2````@,0``!,```"3Q```*P``
M`*?$```[````T\0``"`````/Q0``-@```##%```A````9\4``!````")Q0``
M"````)K%```,````H\4```8```"PQ0``!````+?%```.````O,4``!````#+
MQ0``"@```-S%```-````Y\4``!X```#UQ0``&P```!3&```A````,,8``!X`
M``!2Q@``&0```''&```>````B\8``!L```"JQ@``+@```,;&```7````]<8`
M`"8````-QP``,````#3'```;````9<<``!X```"!QP``'````*#'```F````
MO<<``"L```#DQP``,P```!#(```F````1,@``"L```!KR```.````)?(```=
M````T,@``!4```#NR```+P````3)```@````-,D``!(```!5R0``*0```&C)
M```>````DLD``!(```"QR0``H@```,3)```6````9\H``",```!^R@``*```
M`*+*```I````R\H``"@```#UR@``'P```![+```5````/LL``"````!4RP``
M)0```'7+```H````F\L``"T```#$RP``,````/++``"2````(\P``"$```"V
MS```%@```-C,```<````[\P``"8````,S0``*@```#/-``!!````7LT``$0`
M``"@S0``#````.7-```'````\LT```<```#ZS0``!@````+.```-````"<X`
M`!`````7S@``$@```"C.```3````.\X``!(```!/S@``!P```&+.```$````
M:LX``!````!OS@``#````(#.```.````C<X```\```"<S@``$P```*S.```-
M````P,X``"@```#.S@```P```/?.```-````^\X```8````)SP``$0```!#/
M```7````(L\``!L````ZSP``#@```%;/```"````9<\```4```!HSP``$```
M`&[/```$````?\\```T```"$SP``#@```)+/```#````H<\```X```"ESP``
M"````+3/```/````O<\```\```#-SP``!P```-W/```-````Y<\``!````#S
MSP``$P````30```3````&-````L````LT```!@```#C0```,````/]```!$`
M``!,T```&0```%[0```+````>-````T```"$T```(@```)+0```;````M=``
M`#0```#1T```"@````;1```8````$=$``!D````JT0``%@```$31```O````
M6]$``"(```"+T0``#0```*[1```'````O-$``!0```#$T0``"P```-G1```B
M````Y=$``"\````(T@``"P```#C2```)````1-(``!D```!.T@``"P```&C2
M```7````=-(``!<```",T@``"0```*32```6````KM(```\```#%T@``&0``
M`-72```6````[](```X````&TP``&````!73```(````+M,```T````WTP``
M)@```$73``!#````;-,```@```"PTP``$@```+G3```(````S-,```L```#5
MTP``+P```.'3```.````$=0```4````@U```!@```";4```#````+=0```<`
M```QU```!````#G4```*````/M0```H```!)U```#P```%34```0````9-0`
M`!<```!UU```$0```(W4```9````G]0``!<```"YU```"0```-'4```%````
MV]0```L```#AU```"@```.W4```"````^-0```4```#[U```#0````'5```;
M````#]4``!<````KU0``"0```$/5```.````3=4```T```!<U0``$@```&K5
M```X````?=4``"````"VU0``"````-?5```.````X-4``'L```#OU0``&```
M`&O6``!`````A-8``!$```#%U@``!P```-?6```%````W]8``!D```#EU@``
M$P```/_6```'````$]<```<````;UP``"````"/7```&````+-<```8````S
MUP``$````#K7```/````2]<``!````!;UP``#P```&S7```+````?-<```\`
M``"(UP``#````)C7```/````I=<```<```"UUP``"@```+W7```&````R-<`
M``X```#/UP``#````-[7```H````Z]<```\````4V```"````"38```6````
M+=@```@```!$V```$P```$W8```>````8=@``"$```"`V```(````*+8```9
M````P]@``!<```#=V```)0```/78```7````&]D```0````SV0``&P```#C9
M```-````5-D```P```!BV0```P```&_9```(````<]D```H```!\V0``#```
M`(?9```+````E-D``!````"@V0``#````+'9```$````OMD``!,```##V0``
M%````-?9```,````[-D```D```#YV0``#@````/:```+````$MH``!L````>
MV@``!P```#K:```'````0MH```H```!*V@``#0```%7:```)````8]H```0`
M``!MV@``!0```'+:```#````>-H``!@```!\V@``"@```)7:```$````H-H`
M`"8```"EV@``#@```,S:``!\````V]H``!4```!8VP``!0```&[;```'````
M=-L```P```!\VP``"````(G;```*````DML```8```"=VP``"````*3;```6
M````K=L``!(```#$VP```@```-?;```&````VML```8```#AVP``%````.C;
M```-````_=L``!`````+W```&P```!S<```$````.-P```D````]W```$```
M`$?<```)````6-P```D```!BW```!0```&S<```%````<MP``!H```!XW```
M"````)/<```&````G-P``!D```"CW```#@```+W<```B````S-P```<```#O
MW```!P```/?<```.````_]P```4````.W0``"0```!3=```*````'MT```(`
M```IW0``!@```"S=```-````,]T```D```!!W0``!@```$O=```2````4MT`
M``D```!EW0``!P```&_=```4````=]T``!T```",W0``$0```*K=```&````
MO-T```H```##W0``!````,[=```)````T]T```@```#=W0``$0```.;=```1
M````^-T```D````*W@``!@```!3>```-````&]X```8````IW@``!````##>
M```Y````-=X``#T```!OW@``.@```*W>```>````Z-X```4````'WP``#@``
M``W?```$````'-\```8````AWP``(0```"C?```-````2M\``!4```!8WP``
M!@```&[?```$````==\``!$```!ZWP``!@```(S?``"@````D]\```H````T
MX```(@```#_@```$````8N```"4```!GX```!0```(W@```=````D^````0`
M``"QX```#````+;@```*````P^````@```#.X```"0```-?@```%````X>``
M`!L```#GX```.@````/A```P````/N$``#4```!OX0``*0```*7A```N````
MS^$``$<```#^X0``.````$;B```I````?^(``#\```"IX@``+@```.GB```M
M````&.,``!\```!&XP``#P```&;C```2````=N,```L```")XP``)@```)7C
M```I````O.,``"0```#FXP``)@````OD```(````,N0```H````[Y```"0``
M`$;D```'````4.0``"````!8Y```(````'GD```F````FN0```H```#!Y```
M&0```,SD```I````YN0``!8````0Y0``$@```"?E```'````.N4```H```!"
MY0``#P```$WE```0````7>4``$````!NY0``<````*_E``!F````(.8```X`
M``"'Y@``"0```);F```*````H.8``!(```"KY@``$P```+[F```,````TN8`
M``8```#?Y@``#P```.;F```2````]N8``!`````)YP``$0```!KG```<````
M+.<``",```!)YP``:@```&WG```/````V.<```4```#HYP``$````.[G```)
M````_^<```0````)Z```"P````[H```@````&N@``!H````[Z```%````%;H
M```,````:^@```P```!XZ```#P```(7H```5````E>@``"D```"KZ```*@``
M`-7H```F`````.D``"<````GZ0``*0```$_I```J````>>D``!D```"DZ0``
M0@```+[I```1`````>H``!(````3Z@``$P```";J```4````.NH```\```!/
MZ@``%@```%_J```7````=NH``!````".Z@``$0```)_J```T````L>H``!,`
M``#FZ@``$@```/KJ```U````#>L``!0```!#ZP``!P```%CK```,````8.L`
M`"````!MZP``$````([K```4````G^L``!$```"TZP``%P```,;K```<````
MWNL``!,```#[ZP``%`````_L```:````).P``!$````_[```&@```%'L```>
M````;.P``!H```"+[```$P```*;L```5````NNP``!$```#0[```%P```.+L
M```4````^NP``!<````/[0``%0```"?M```)````/>T``!D```!'[0``!```
M`&'M```'````9NT```L```!N[0``$0```'KM```&````C.T```8```"3[0``
M!@```)KM```%````H>T```<```"G[0``!P```*_M```%````M^T``!8```"]
M[0``!@```-3M```&````V^T```0```#B[0``!````.?M```'````[.T```X`
M``#T[0``#`````/N```,````$.X```T````=[@``"@```"ON```.````-NX`
M``4```!%[@``*````$ON```.````=.X```P```"#[@``#P```)#N```*````
MH.X```@```"K[@``"0```+3N```K````ONX```0```#J[@``"````._N```F
M````^.X``!(````?[P``#P```#+O```&````0N\```H```!)[P``!P```%3O
M```(````7.\``"````!E[P``"0```(;O```,````D.\```T```"=[P``#@``
M`*OO```6````NN\``!$```#1[P``!@```./O```#````ZN\```8```#N[P``
M&0```/7O```'````#_````0````7\```"P```!SP```+````*/````<````T
M\```!P```#SP```6````1/````T```!;\```#0```&GP```*````=_```!``
M``""\```#P```)/P```1````H_```!<```"U\```"@```,WP```1````V/``
M``@```#J\```!````//P```/````^/```#H````(\0``!0```$/Q```,````
M2?$``!X```!6\0``#@```'7Q```0````A/$```L```"5\0``#````*'Q```)
M````KO$```<```"X\0``"@```,#Q```)````R_$```X```#5\0``$````.3Q
M```:````]?$```H````0\@``"0```!OR```4````)?(```H````Z\@``#```
M`$7R```/````4O(```@```!B\@``!@```&OR```'````<O(```L```!Z\@``
M1P```(;R```-````SO(```D```#<\@``!````.;R```#````Z_(``!,```#O
M\@``$P````/S```3````%_,```H````K\P```@```#;S```$````.?,``"4`
M```^\P```P```&3S```%````:/,``"H```!N\P``"@```)GS```%````I/,`
M``0```"J\P``"@```*_S```-````NO,``$````#(\P``$P````GT```&````
M'?0```@````D]```"````"WT```$````-O0```4````[]```:````$'T```)
M````JO0```P```"T]```!0```,'T```&````Q_0``!L```#.]```+P```.KT
M```0````&O4```H````K]0``#P```#;U```*````1O4```D```!1]0``$P``
M`%OU```;````;_4``!@```"+]0``%P```*3U```.````O/4```,```#+]0``
M!P```,_U```(````U_4```<```#@]0``"@```.CU```+````\_4``"T```#_
M]0``%0```"WV```P````0_8``"0```!T]@``!P```)GV``!1````H?8``!``
M``#S]@``#`````3W```-````$?<``!H````?]P``2@```#KW```9````A?<`
M``8```"?]P``&@```*;W```&````P?<```8```#(]P``'P```,_W```&````
M[_<```D```#V]P``&`````#X```7````&?@```8````Q^```#0```#CX```B
M````1O@``%<```!I^```$P```,'X```C````U?@``!,```#Y^````@````WY
M```+````$/D```@````<^0``#0```"7Y```*````,_D```8````^^0``!P``
M`$7Y```4````3?D```8```!B^0``"````&GY```.````<OD```<```"!^0``
M"@```(GY```+````E/D```<```"@^0``#````*CY```-````M?D```P```##
M^0``"0```-#Y```)````VOD```H```#D^0``!P```._Y```)````]_D```<`
M```!^@``"@````GZ```;````%/H``!(````P^@``"@```$/Z```)````3OH`
M`!````!8^@``!P```&GZ```2````<?H```0```"$^@``!P```(GZ```%````
MD?H```4```"7^@``"P```)WZ```4````J?H``!$```"^^@``&@```-#Z```6
M````Z_H``!0````"^P``%P```!?[```8````+_L``!P```!(^P``&0```&7[
M```'````?_L```4```"'^P``#0```(W[```,````F_L```@```"H^P``%P``
M`+'[```+````R?L``!,```#5^P``!````.G[```*````[OL```0```#Y^P``
M#0```/[[```,````#/P```4````9_```"0```!_\```%````*?P```<````O
M_```!0```#?\```$````/?P```(```!"_```.````$7\```L````?OP``!(`
M``"K_```*0```+[\```R````Z/P```H````;_0``-@```";]```L````7?T`
M`!4```"*_0``+@```*#]```S````S_T``#,````#_@``.````#?^```/````
M</X``!@```"`_@``.P```)G^```0````U?X``!0```#F_@``$P```/O^```5
M````#_\``!0````E_P``$@```#K_```4````3?\``!4```!B_P``+0```'C_
M```M````IO\``#$```#4_P``+0````8``0`N````-``!`"\```!C``$`+```
M`),``0!B````P``!`!,````C`0$`"````#<!`0`(````0`$!`"L```!)`0$`
M(0```'4!`0`:````EP$!``D```"R`0$`10```+P!`0!!`````@(!``0```!$
M`@$`$P```$D"`0`4````70(!``X```!R`@$`$P```($"`0`8````E0(!``8`
M``"N`@$`"0```+4"`0`*````OP(!``\```#*`@$`$````-H"`0`'````ZP(!
M``X```#S`@$`!0````(#`0`;````"`,!``8````D`P$`"````"L#`0`&````
M-`,!`!0````[`P$`$0```%`#`0`.````8@,!`#@```!Q`P$``@```*H#`0`&
M````K0,!``X```"T`P$`&@```,,#`0`%````W@,!``<```#D`P$`#@```.P#
M`0`&````^P,!``0````"!`$`*0````<$`0`7````,00!`!\```!)!`$`7```
M`&D$`0`4````Q@0!`#X```#;!`$`'P```!H%`0`0````.@4!``<```!+!0$`
M#@```%,%`0`(````8@4!``P```!K!0$`#````'@%`0`3````A04!``H```"9
M!0$`'0```*0%`0`9````P@4!``4```#<!0$`$0```.(%`0`1````]`4!`"0`
M```&!@$`%0```"L&`0`2````008!``X```!4!@$`&0```&,&`0`(````?08!
M``D```"&!@$`#0```)`&`0`*````G@8!``<```"I!@$`#P```+$&`0`&````
MP08!``L```#(!@$`"@```-0&`0`'````WP8!``@```#G!@$`!0```/`&`0`?
M````]@8!``8````6!P$`$````!T'`0`(````+@<!``T````W!P$`"````$4'
M`0`2````3@<!`"P```!A!P$`&@```(X'`0`)````J0<!``H```"S!P$`%0``
M`+X'`0`%````U`<!`!0```#:!P$`!````.\'`0`0````]`<!``8````%"`$`
M!P````P(`0`>````%`@!`"@````S"`$`"@```%P(`0`<````9P@!`!H```"$
M"`$`#P```)\(`0`4````KP@!``0```#$"`$`!````,D(`0`+````S@@!``4`
M``#:"`$`!@```.`(`0`(````YP@!``8```#P"`$`"@```/<(`0`;`````@D!
M`#0````>"0$`-````%,)`0`@````B`D!`"D```"I"0$`(````-,)`0!!````
M]`D!`!H````V"@$`*````%$*`0`I````>@H!`%$```"D"@$`+P```/8*`0`B
M````)@L!``8```!)"P$`"````%`+`0`%````60L!``@```!?"P$`&0```&@+
M`0`9````@@L!`"H```"<"P$`(P```,<+`0`9````ZPL!`"X````%#`$`-```
M`#0,`0`(````:0P!`!<```!R#`$`"@```(H,`0`'````E0P!`"$```"=#`$`
M$````+\,`0`.````T`P!``L```#?#`$`!P```.L,`0`3````\PP!``@````'
M#0$`"P```!`-`0`*````'`T!`!0````G#0$`#P```#P-`0`R````3`T!``L`
M``!_#0$`!0```(L-`0`%````D0T!`!<```"7#0$`#P```*\-`0`$````OPT!
M``H```#$#0$`"0```,\-`0`+````V0T!``T```#E#0$`#````/,-`0`.````
M``X!``4````/#@$`!````!4.`0`-````&@X!`#(````H#@$`10```%L.`0`7
M````H0X!`!X```"Y#@$`%````-@.`0`%````[0X!`!0```#S#@$`!P````@/
M`0`.````$`\!`"H````?#P$`!@```$H/`0`,````40\!``T```!>#P$`$0``
M`&P/`0`+````?@\!`#8```"*#P$`"@```,$/`0`B````S`\!``L```#O#P$`
M#P```/L/`0`R````"Q`!`"4````^$`$`,````&00`0`Q````E1`!`"T```#'
M$`$`#@```/40`0`%````!!$!``X````*$0$`$P```!D1`0`'````+1$!`!H`
M```U$0$`"````%`1`0`1````61$!``<```!K$0$`%````',1`0`8````B!$!
M``<```"A$0$`!0```*D1`0`,````KQ$!``P```"\$0$`$@```,D1`0`$````
MW!$!``<```#A$0$`"@```.D1`0`+````]!$!``P`````$@$`#@````T2`0`.
M````'!(!``4````K$@$`!0```#$2`0`N````-Q(!`"8```!F$@$`(P```(T2
M`0`#````L1(!`!(```"U$@$`!@```,@2`0`>````SQ(!`!@```#N$@$`)0``
M``<3`0`-````+1,!``D````[$P$``P```$43`0`'````21,!``H```!1$P$`
M`@```%P3`0`,````7Q,!`!4```!L$P$`"P```((3`0`9````CA,!`"````"H
M$P$`$@```,D3`0`%````W!,!``H```#B$P$`%0```.T3`0`2`````Q0!``P`
M```6%`$`!````",4`0`'````*!0!``D````P%`$`#````#H4`0!2````1Q0!
M`!<```":%`$`)````+(4`0`2````UQ0!``<```#J%`$`!@```/(4`0`.````
M^10!`"(````(%0$`'0```"L5`0`,````214!``T```!6%0$`%0```&05`0`2
M````>A4!``\```"-%0$`%````)T5`0`;````LA4!`!````#.%0$`:0```-\5
M`0`:````218!`!<```!D%@$`)P```'P6`0`:````I!8!`!<```"_%@$`&P``
M`-<6`0`9````\Q8!`!\````-%P$`$P```"T7`0`(````01<!``<```!*%P$`
M"````%(7`0`)````6Q<!`!4```!E%P$`#0```'L7`0`C````B1<!`!,```"M
M%P$``P```,$7`0!&````Q1<!`#\````,&`$`-P```$P8`0!7````A!@!``4`
M``#<&`$`'P```.(8`0`O`````AD!``H````R&0$`"````#T9`0`-````1AD!
M`"T```!4&0$`!````((9`0!/````AQD!`"4```#7&0$`'````/T9`0`+````
M&AH!`!\````F&@$`'0```$8:`0`E````9!H!`"````"*&@$`)````*L:`0`@
M````T!H!``L```#Q&@$`!P```/T:`0`-````!1L!``P````3&P$`%P```"`;
M`0`&````.!L!`#D````_&P$`#````'D;`0`'````AAL!`!D```".&P$`"0``
M`*@;`0`3````LAL!``D```#&&P$`!````-`;`0`0````U1L!``H```#F&P$`
M"````/$;`0`(````^AL!``0````#'`$`"P````@<`0`,````%!P!`!(````A
M'`$`$0```#0<`0`,````1AP!`!H```!3'`$`#P```&X<`0`'````?AP!``T`
M``"&'`$`%````)0<`0`.````J1P!``P```"X'`$`&P```,4<`0`L````X1P!
M`!,````.'0$`'````"(=`0`H````/QT!``8```!H'0$`!P```&\=`0`3````
M=QT!``4```"+'0$`!````)$=`0`7````EAT!``H```"N'0$`#````+D=`0`)
M````QAT!``8```#0'0$`"0```-<=`0`(````X1T!``D```#J'0$`"@```/0=
M`0`1````_QT!``8````1'@$`&````!@>`0`.````,1X!``X```!`'@$`#0``
M`$\>`0`+````71X!`!T```!I'@$`"P```(<>`0`"````DQX!``<```"6'@$`
M!@```)X>`0!E````I1X!``D````+'P$`!P```!4?`0`F````'1\!`#@```!$
M'P$`&@```'T?`0`J````F!\!`#L```##'P$`*````/\?`0`T````*"`!`!D`
M``!=(`$`%0```'<@`0`%````C2`!``<```"3(`$`"````)L@`0`'````I"`!
M``4```"L(`$`!P```+(@`0`.````NB`!``D```#)(`$`!@```-,@`0`(````
MVB`!``L```#C(`$`!P```.\@`0`(````]R`!``<`````(0$`%@````@A`0`)
M````'R$!``8````I(0$`"P```#`A`0`<````/"$!`!0```!9(0$`!P```&XA
M`0`1````=B$!``@```"((0$`#@```)$A`0`(````H"$!``4```"I(0$`$```
M`*\A`0`0````P"$!``8```#1(0$`&0```-@A`0`*````\B$!`!P```#](0$`
M!P```!HB`0`%````(B(!`!`````H(@$`%````#DB`0`+````3B(!``T```!:
M(@$`*````&@B`0`8````D2(!`!<```"J(@$`!````,(B`0`)````QR(!``H`
M``#1(@$`!P```-PB`0`"````Y"(!``X```#G(@$`"````/8B`0`?````_R(!
M`#X````?(P$`(P```%XC`0`X````@B,!`"8```"[(P$`,0```.(C`0`G````
M%"0!`&0````\)`$`%````*$D`0!5````MB0!`#@````,)0$`2@```$4E`0!;
M````D"4!`"@```#L)0$`.````!4F`0`H````3B8!`"P```!W)@$`)P```*0F
M`0`;````S"8!`#X```#H)@$`J0$``"<G`0`H````T2@!`",```#Z*`$`%P``
M`!XI`0!(````-BD!`(4```!_*0$`,`````4J`0!!````-BH!`%L```!X*@$`
M20```-0J`0`=````'BL!`!@````\*P$`(0```%4K`0`?````=RL!`"L```"7
M*P$`(0```,,K`0`G````Y2L!`!T````-+`$`$0```"LL`0`S````/2P!`"4`
M``!Q+`$`)P```)<L`0`?````ORP!`#````#?+`$`:0```!`M`0`K````>BT!
M`#$```"F+0$`00```-@M`0`S````&BX!`"4```!.+@$`/0```'0N`0!E````
MLBX!`$T````8+P$`+P```&8O`0`N````EB\!`#````#%+P$`5````/8O`0"#
M````2S`!`%H```#/,`$`2````"HQ`0!*````<S$!`#(```"^,0$`+P```/$Q
M`0`L````(3(!`"T```!.,@$`<0```'PR`0!O````[C(!`+,```!>,P$`%P``
M`!(T`0`E````*C0!`#(```!0-`$`*0```(,T`0`^````K30!`"(```#L-`$`
M4@````\U`0`E````8C4!``L```"(-0$`L0```)0U`0!%````1C8!`"$```",
M-@$`+@```*XV`0`P````W38!`"4````.-P$`'````#0W`0`Q````43<!``<`
M``"#-P$`!P```(LW`0`$````DS<!``T```"8-P$`"P```*8W`0`.````LC<!
M``L```#!-P$`!0```,TW`0`0````TS<!``(```#D-P$`60```.<W`0`%````
M03@!`!(```!'.`$`!````%HX`0`'````7S@!``@```!G.`$`!0```'`X`0`#
M````=C@!`!````!Z.`$`"@```(LX`0`,````EC@!`!,```"C.`$`#0```+<X
M`0`"````Q3@!``<```#(.`$`!@```-`X`0`4````US@!``P```#L.`$`&```
M`/DX`0`&````$CD!`!(````9.0$`#````"PY`0`#````.3D!`"H````].0$`
M!````&@Y`0`&````;3D!``<```!T.0$`'P```'PY`0`U````G#D!`"X```#2
M.0$`+P````$Z`0`7````,3H!`"````!).@$`&P```&HZ`0`8````ACH!`"0`
M``"?.@$`'P```,0Z`0`:````Y#H!`"````#_.@$`&@```"`[`0`R````.SL!
M`!H```!N.P$`+P```(D[`0`K````N3L!`!\```#E.P$`(P````4\`0`?````
M*3P!`!H```!)/`$`)0```&0\`0`F````BCP!`"4```"Q/`$`)````-<\`0`8
M````_#P!`!T````5/0$`)````#,]`0`8````6#T!`"(```!Q/0$`%0```)0]
M`0`E````JCT!`#P```#0/0$`'P````T^`0`C````+3X!`!\```!1/@$`(```
M`'$^`0`:````DCX!`!@```"M/@$`)@```,8^`0`>````[3X!`"D````,/P$`
M'@```#8_`0`)````53\!``P```!?/P$`%P```&P_`0`O````A#\!`"0```"T
M/P$`!P```-D_`0`/````X3\!`!0```#Q/P$`#@````9``0`-````%4`!`"0`
M```C0`$`!0```$A``0`'````3D`!`"(```!60`$`)0```'E``0`3````GT`!
M`!H```"S0`$`'0```,Y``0`:````[$`!``<````'00$`QP````]!`0`+````
MUT$!`!4```#C00$`#````/E!`0`&````!D(!``D````-0@$`"P```!="`0`-
M````(T(!`!T````Q0@$`%P```$]"`0`&````9T(!`#,```!N0@$`$P```*)"
M`0`3````MD(!``<```#*0@$`!@```-)"`0`/````V4(!``<```#I0@$`,@``
M`/%"`0`A````)$,!`!,```!&0P$`#````%I#`0`1````9T,!`#(```!Y0P$`
M$````*Q#`0`(````O4,!`!T```#&0P$`"0```.1#`0`*````[D,!``4```#Y
M0P$`%````/]#`0`*````%$0!`!T````?1`$`"````#U$`0`?````1D0!``@`
M``!F1`$`&@```&]$`0`G````BD0!``8```"R1`$`%0```+E$`0`'````ST0!
M``@```#71`$`"0```.!$`0`_````ZD0!``<````J10$`#P```#)%`0`.````
M0D4!`!````!110$`"0```&)%`0`)````;$4!``@```!V10$`$P```']%`0`'
M````DT4!`!D```";10$`"@```+5%`0`7````P$4!`!0```#810$`"@```.U%
M`0`,````^$4!`!<````%1@$`!````!U&`0`J````(D8!`!$```!-1@$`!P``
M`%]&`0`)````9T8!``(```!Q1@$`$````'1&`0`8````A48!``L```">1@$`
M`P```*I&`0`(````KD8!``8```"W1@$`!P```+Y&`0`-````QD8!``L```#4
M1@$`%````.!&`0`5````]48!``X````+1P$`+P```!I'`0`@````2D<!`!P`
M``!K1P$`#````(A'`0`Q````E4<!``4```#'1P$`$@```,U'`0`_````X$<!
M`!(````@2`$`"@```#-(`0`&````/D@!``0```!%2`$`!````$I(`0`*````
M3T@!`!,```!:2`$`!0```&Y(`0`&````=$@!``8```![2`$`"0```()(`0`$
M````C$@!``P```"12`$`"@```)Y(`0`@````J4@!``4```#*2`$`&````-!(
M`0`9````Z4@!`!\````#20$`'0```"-)`0`1````04D!``(```!320$`!```
M`%9)`0`*````6TD!``8```!F20$`!0```&U)`0`#````<TD!``P```!W20$`
M10```(1)`0`:````RDD!`#4```#E20$`*````!M*`0!3````1$H!`!D```"8
M2@$`<@```+)*`0`@````)4L!`#4```!&2P$`(0```'Q+`0!%````GDL!`#``
M``#D2P$`*````!5,`0`I````/DP!`"8```!H3`$`)0```(],`0`H````M4P!
M`"@```#>3`$`(@````=-`0`K````*DT!`#````!630$`$@```(=-`0`3````
MFDT!`!````"N30$`>0```+]-`0`)````.4X!`'(```!#3@$`<P```+9.`0!\
M````*D\!`"L```"G3P$`5````--/`0`7````*%`!`!8```!`4`$`#P```%=0
M`0!E````9U`!`!\```#-4`$`0````.U0`0`?````+E$!`!P```!.40$`40``
M`&M1`0`4````O5$!``H```#240$`!0```-U1`0`&````XU$!``@```#J40$`
M!0```/-1`0`2````^5$!`!`````,4@$`$P```!U2`0`=````,5(!``\```!/
M4@$`#P```%]2`0`$````;U(!``D```!T4@$`"P```'Y2`0`'````BE(!``4`
M``"24@$`%````)A2`0`'````K5(!``@```"U4@$`#P```+Y2`0`(````SE(!
M``P```#74@$`#P```.12`0`&````]%(!`!0```#[4@$`!@```!!3`0`,````
M%U,!`!4````D4P$`"````#I3`0`$````0U,!``H```!(4P$`!````%-3`0`&
M````6%,!``<```!?4P$`!````&=3`0`'````;%,!`!D```!T4P$`!P```(Y3
M`0`"````EE,!``(```"94P$`"0```)Q3`0`&````IE,!``8```"M4P$`)P``
M`+13`0`"````W%,!``0```#?4P$`"P```.13`0`)````\%,!``\```#Z4P$`
M$P````I4`0`'````'E0!``<````F5`$`!@```"Y4`0`&````-50!`!`````\
M5`$`$@```$U4`0`"````8%0!``8```!C5`$`"0```&I4`0`S````=%0!`"(`
M``"H5`$`!P```,M4`0`'````TU0!``<```#;5`$`"P```.-4`0`%````[U0!
M``(```#U5`$`"P```/A4`0!B`0``!%4!`',```!G5@$`N````-M6`0!"````
ME%<!`,````#75P$`D````)A8`0!&````*5D!`#<```!P60$`,P```*A9`0`V
M````W%D!`"\````36@$`+@```$-:`0!H````<EH!`&4```#;6@$`9P```$%;
M`0!E````J5L!`&<````/7`$`;P```'=<`0`_````YUP!`&0````G70$`0P``
M`(Q=`0`O````T%T!`$T`````7@$`1````$Y>`0!*````DUX!`#,```#>7@$`
M.````!)?`0!N````2U\!`"X```"Z7P$`+0```.E?`0"(````%V`!`&(```"@
M8`$`#P$```-A`0!.````$V(!`#0```!B8@$`BP```)=B`0!0````(V,!`!``
M``!T8P$`%0```(5C`0`4````FV,!``<```"P8P$`"0```+AC`0`(````PF,!
M``4```#+8P$`'@```-%C`0`N````\&,!`"P````?9`$`*0```$QD`0`N````
M=F0!`!@```"E9`$`"@```+YD`0`1````R60!`"L```#;9`$`$P````=E`0`0
M````&V4!`!`````L90$`%````#UE`0`%````4F4!`"@```!890$`#0```(%E
M`0`-````CV4!`!,```"=90$`#0```+%E`0`+````OV4!`!L```#+90$`$```
M`.=E`0`*````^&4!`!8````#9@$`/P```!IF`0`-````6F8!``\```!H9@$`
M$````'AF`0`+````B68!``T```"59@$`!@```*-F`0`-````JF8!`!,```"X
M9@$`%0```,QF`0`-````XF8!`!L```#P9@$`&P````QG`0`3````*&<!``@`
M```\9P$`"0```$5G`0!8````3V<!`#0```"H9P$`%0```-UG`0`]````\V<!
M`$X````Q:`$`:@```(!H`0!I````ZV@!`'````!5:0$`;P```,9I`0!"````
M-FH!``\```!Y:@$`$@```(EJ`0`.````G&H!`!,```"K:@$`#P```+]J`0`%
M````SVH!``8```#5:@$`$P```-QJ`0`)````\&H!``\```#Z:@$`$0````IK
M`0`A````'&L!`",````^:P$`%@```&)K`0`0````>6L!``T```"*:P$`"0``
M`)AK`0`5````HFL!`!D```"X:P$`$0```-)K`0`5````Y&L!`!@```#Z:P$`
M'P```!-L`0`D````,VP!`!H```!8;`$`$````'-L`0`7````A&P!`!(```"<
M;`$`+@```*]L`0`8````WFP!`!P```#W;`$`%````!1M`0!9````*6T!`"H`
M``"#;0$`*@```*YM`0`J````V6T!``@````$;@$`"0````UN`0`W````%VX!
M``T```!/;@$`"````%UN`0`+````9FX!``<```!R;@$`!P```'IN`0`'````
M@FX!``<```"*;@$`#````))N`0`$````GVX!`"(```"D;@$`#P```,=N`0`3
M````UVX!`!<```#K;@$`'`````-O`0`P````(&\!``D```!1;P$`&````%MO
M`0`>````=&\!`",```"3;P$`$0```+=O`0`4````R6\!`!(```#>;P$`#P``
M`/%O`0`C`````7`!`!T````E<`$`!P```$-P`0`&````2W`!``<```!2<`$`
M&@```%IP`0`(````=7`!``H```!^<`$`$0```(EP`0`)````FW`!`!$```"E
M<`$`&@```+=P`0`'````TG`!`!(```#:<`$`!0```.UP`0`6````\W`!`!X`
M```*<0$`#P```"EQ`0`_````.7$!`#L```!Y<0$`"0```+5Q`0`'````OW$!
M`!,```#'<0$`!````-MQ`0`%````X'$!`!````#F<0$`"@```/=Q`0`4````
M`G(!`#P````7<@$`%0```%1R`0`M````:G(!`#(```"8<@$`,0```,MR`0`P
M````_7(!``D````N<P$`!@```#AS`0`)````/W,!``<```!)<P$`.P```%%S
M`0`[````C7,!`#H```#)<P$`7P````1T`0`Y````9'0!`#D```">=`$`.0``
M`-AT`0!+````$G4!`"T```!>=0$`,````(QU`0`Y````O74!`#\```#W=0$`
M%0```#=V`0`9````378!`#(```!G=@$`)@```)IV`0`3````P78!``H```#5
M=@$`$````.!V`0`%````\78!``P```#W=@$`'@````1W`0`C````(W<!``8`
M``!'=P$`!0```$YW`0`5````5'<!``L```!J=P$`"````'9W`0`*````?W<!
M``P```"*=P$`!P```)=W`0`&````GW<!``4```"F=P$`!P```*QW`0`%````
MM'<!``L```"Z=P$`,@```,9W`0`7````^7<!``T````1>`$`!P```!]X`0`'
M````)W@!``H````O>`$`!0```#IX`0`3````0'@!``8```!4>`$`$@```%MX
M`0`%````;G@!``@```!T>`$`!````'UX`0`+````@G@!``8```".>`$`)0``
M`)5X`0`1````NW@!`"L```#->`$`'@```/EX`0`(````&'D!``X````A>0$`
M#0```#!Y`0`'````/GD!``,```!&>0$``P```$IY`0`:````3GD!`"````!I
M>0$`*P```(IY`0`*````MGD!``4```#!>0$`"````,=Y`0`(````T'D!`%X`
M``#9>0$`*````#AZ`0`&````87H!``@```!H>@$`'P```'%Z`0`D````D7H!
M`"\```"V>@$`,@```.9Z`0`F````&7L!`"8```!`>P$`70```&=[`0`^````
MQ7L!`!<````$?`$`!P```!Q\`0`2````)'P!``P````W?`$`$````$1\`0`8
M````57P!`!<```!N?`$`&````(9\`0`8````GWP!``D```"X?`$`%0```,)\
M`0`'````V'P!`!D```#@?`$`&P```/I\`0`9````%GT!`!,````P?0$`&```
M`$1]`0`2````77T!``<```!P?0$`6P```'A]`0`)````U'T!`!4```#>?0$`
M-@```/1]`0`2````*WX!`!H````^?@$`'0```%E^`0`9````=WX!`!<```"1
M?@$`'0```*E^`0`>````QWX!`#(```#F?@$`#0```!E_`0`L````)W\!`"<`
M``!4?P$`'0```'Q_`0`&````FG\!`!P```"A?P$`'@```+Y_`0`:````W7\!
M`!H```#X?P$`"P```!.``0`5````'X`!`!,````U@`$`#0```$F``0`&````
M5X`!``\```!>@`$`"````&Z``0`5````=X`!`!8```"-@`$`$0```*2``0`5
M````MH`!``4```#,@`$`!@```-*``0`1````V8`!``@```#K@`$`$P```/2`
M`0`"````"($!``<````+@0$`$P```!.!`0`2````)X$!``D````Z@0$`"@``
M`$2!`0`)````3X$!``H```!9@0$`!P```&2!`0`'````;($!``T```!T@0$`
M#````(*!`0`(````CX$!``D```"8@0$`&@```**!`0`B````O8$!``T```#@
M@0$`&````.Z!`0`>````!X(!`!X````F@@$`#P```$6"`0`0````58(!`#``
M``!F@@$`/P```)>"`0`A````UX(!`#P```#Y@@$`*````#:#`0`.````7X,!
M``D```!N@P$`"@```'B#`0`.````@X,!``8```"2@P$`#P```)F#`0`6````
MJ8,!`!<```#`@P$`'````-B#`0`N````]8,!`"P````DA`$`,````%&$`0`O
M````@H0!`"D```"RA`$`*0```-R$`0`F````!H4!`#D````MA0$`(@```&>%
M`0`P````BH4!`$(```"[A0$`,0```/Z%`0`R````,(8!`"4```!CA@$`,@``
M`(F&`0`Y````O(8!`$X```#VA@$`-0```$6'`0`X````>X<!`$,```"TAP$`
M)````/B'`0`6````'8@!`$\````TB`$`*0```(2(`0`:````KH@!`#L```#)
MB`$`(@````6)`0`8````*(D!`-4```!!B0$`&@```!>*`0`M````,HH!`#``
M``!@B@$`,0```)&*`0`R````PXH!`"D```#VB@$`%@```""+`0`N````-XL!
M`#<```!FBP$`.@```)Z+`0`]````V8L!`#H````7C`$`F@```%*,`0`K````
M[8P!`!\````9C0$`*````#F-`0`W````8HT!`#8```":C0$`5@```-&-`0!9
M````*(X!``T```""C@$`!````)".`0`&````E8X!``4```"<C@$`$0```**.
M`0`.````M(X!`!````##C@$`%0```-2.`0`;````ZHX!`!0````&CP$`$0``
M`!N/`0`6````+8\!``D```!$CP$`#@```$Z/`0`/````78\!`!$```!MCP$`
M#0```'^/`0!#````C8\!``8```#1CP$`$0```-B/`0`3````ZH\!`!$```#^
MCP$`%P```!"0`0`;````*)`!``\```!$D`$``@```%20`0`+````5Y`!`!P`
M``!CD`$`!````("0`0`0````A9`!`!````"6D`$``P```*>0`0`/````JY`!
M``@```"[D`$`$````,20`0`2````U9`!``L```#HD`$`#P```/20`0`1````
M!)$!`!8````6D0$`%@```"V1`0`*````1)$!``<```!/D0$`#0```%>1`0`1
M````99$!`!H```!WD0$`#@```)*1`0`.````H9$!`"0```"PD0$`&@```-61
M`0`X````\)$!``T````ID@$`'P```#>2`0`9````5Y(!`!@```!QD@$`-@``
M`(J2`0`G````P9(!`!(```#ID@$`"0```/R2`0`3````!I,!``D````:DP$`
M,````"23`0`[````59,!``\```"1DP$`$````*&3`0`A````LI,!`!(```#4
MDP$`(P```.>3`0`C````"Y0!``H````OE`$`'````#J4`0`6````5Y0!`!X`
M``!NE`$`%@```(V4`0`7````I)0!`!D```"\E`$`!P```-:4`0`+````WI0!
M`"H```#JE`$`2@```!65`0`(````8)4!`!0```!IE0$`!P```'Z5`0`*````
MAI4!`#<```"1E0$`$P```,F5`0`&````W94!`!,```#DE0$``P```/B5`0`4
M````_)4!``8````1E@$`#````!B6`0`,````)98!`!$````RE@$`$0```$26
M`0`7````5I8!`!$```!NE@$`&0```("6`0`7````FI8!``@```"RE@$`!@``
M`+N6`0`8````PI8!``L```#;E@$``@```.>6`0`3````ZI8!`!\```#^E@$`
M'P```!Z7`0`8````/I<!`!(```!7EP$`#P```&J7`0`/````>I<!`!4```"*
MEP$`/@```*"7`0`R````WY<!``H````2F`$`#P```!V8`0"B````+9@!`!X`
M``#0F`$`30```.^8`0`0````/9D!`!(```!.F0$`!````&&9`0`H````9ID!
M`!8```"/F0$`!@```*:9`0`4````K9D!`"@```#"F0$`!0```.N9`0`&````
M\9D!``\```#XF0$`#@````B:`0`0````%YH!``X````HF@$`#````#>:`0`.
M````1)H!``L```!3F@$`$````%^:`0`(````<)H!``L```!YF@$`"````(6:
M`0`5````CIH!``P```"DF@$`/P```+&:`0`1````\9H!``@````#FP$`$P``
M``R;`0`5````()L!`"L````VFP$`)P```&*;`0`B````BIL!`"$```"MFP$`
M&````,^;`0`:````Z)L!`"4````#G`$`&0```"F<`0`#````0YP!`!D```!'
MG`$`"P```&&<`0`+````;9P!``,```!YG`$`"0```'V<`0`(````AYP!``H`
M``"0G`$`$0```)N<`0`-````K9P!`!````"[G`$`!````,R<`0`@````T9P!
M`"$```#RG`$`$P```!2=`0`/````*)T!`!,````XG0$`%P```$R=`0`N````
M9)T!``<```"3G0$`"0```)N=`0`0````I9T!`!````"VG0$`"P```,>=`0`(
M````TYT!``D```#<G0$`"````.:=`0`6````[YT!``P````&G@$`!@```!.>
M`0`I````&IX!``X```!$G@$`B0```%.>`0`=````W9X!``<```#[G@$`!0``
M``.?`0`-````"9\!``4````7GP$`!P```!V?`0`&````)9\!``@````LGP$`
M)````#6?`0`3````6I\!``(```!NGP$`"````'&?`0`2````>I\!`!4```"-
MGP$`#P```*.?`0`2````LY\!`"<```#&GP$``@```.Z?`0`#````\9\!`!(`
M``#UGP$`"0````B@`0`-````$J`!``<````@H`$`$@```"B@`0`@````.Z`!
M``@```!<H`$`$P```&6@`0`5````>:`!``T```"/H`$`(````)V@`0`'````
MOJ`!`!T```#&H`$`#P```.2@`0`1````]*`!``D````&H0$`#````!"A`0`"
M````':$!``4````@H0$`#P```":A`0`2````-J$!``8```!)H0$`$@```%"A
M`0`+````8Z$!``<```!OH0$`%P```'>A`0`F````CZ$!`!,```"VH0$`!@``
M`,JA`0`)````T:$!``0```#;H0$`%@```."A`0`(````]Z$!`!8`````H@$`
M%@```!>B`0`0````+J(!``4````_H@$`#````$6B`0`@````4J(!``0```!S
MH@$`10```'BB`0!&````OJ(!`$4````%HP$`)0```$NC`0`2````<:,!`!,`
M``"$HP$`!P```)BC`0`)````H*,!`!8```"JHP$`$````,&C`0`5````TJ,!
M``8```#HHP$`!0```.^C`0`4````]:,!``4````*I`$`G````!"D`0`*````
MK:0!`!X```"XI`$`!````->D`0`S````W*0!``4````0I0$`'````!:E`0`$
M````,Z4!`!`````XI0$`$````$FE`0`6````6J4!``P```!QI0$`!0```'ZE
M`0`:````A*4!`#(```"?I0$`-P```-*E`0!`````"J8!`"P```!+I@$`,@``
M`'BF`0!!````JZ8!`$H```#MI@$`,0```#BG`0!%````:J<!`#4```"PIP$`
M-P```.:G`0`G````'J@!`!````!&J`$`%0```%>H`0`+````;:@!`"@```!Y
MJ`$`(````**H`0`A````PZ@!`!\```#EJ`$`"`````6I`0`*````#JD!``H`
M```9J0$`%````"2I`0`I````.:D!`"<```!CJ0$`,````(NI`0`+````O*D!
M`!D```#(J0$`*0```.*I`0`:````#*H!`!0````GJ@$`%````#RJ`0`-````
M4:H!`!````!?J@$`$P```'"J`0!$````A*H!`'T```#)J@$`@@```$>K`0`3
M````RJL!``T```#>JP$`#@```.RK`0`1````^ZL!`!(````-K`$`%@```""L
M`0`'````-ZP!`!(````_K`$`$P```%*L`0`2````9JP!`!4```!YK`$`+```
M`(^L`0`L````O*P!`&T```#IK`$`%0```%>M`0`2````;:T!`!@```"`K0$`
M%@```)FM`0`*````L*T!``H```"[K0$`(0```,:M`0`=````Z*T!`!8````&
MK@$`#@```!VN`0`.````+*X!`!4````[K@$`%0```%&N`0`J````9ZX!`"D`
M``"2K@$`*0```+RN`0`H````YJX!`"<````/KP$`*0```#>O`0`:````8:\!
M`%4```!\KP$`$P```-*O`0`5````YJ\!`!4```#\KP$`%````!*P`0`1````
M)[`!`!<````YL`$`%P```%&P`0`4````:;`!`!,```!^L`$`.@```)*P`0`8
M````S;`!`!D```#FL`$`/@````"Q`0`5````/[$!``<```!5L0$`$0```%VQ
M`0`@````;[$!`!,```"0L0$`$P```*2Q`0`>````N+$!`"(```#7L0$`'0``
M`/JQ`0`;````&+(!`!H````TL@$`(@```$^R`0`2````<K(!`!P```"%L@$`
M(0```**R`0`<````Q+(!`!@```#AL@$`&P```/JR`0`3````%K,!`!L````J
MLP$`'````$:S`0`<````8[,!`!@```"`LP$`"@```)FS`0`:````I+,!`!,`
M``"_LP$`%````-.S`0`+````Z+,!`!0```#TLP$`$`````FT`0`'````&K0!
M``<````BM`$`$@```"JT`0`'````/;0!``<```!%M`$`!0```$VT`0`5````
M4[0!``8```!IM`$`&P```'"T`0`%````C+0!``4```"2M`$`"@```)BT`0`'
M````H[0!``H```"KM`$`%0```+:T`0`4````S+0!`!@```#AM`$`%0```/JT
M`0`3````$+4!`"P````DM0$`$P```%&U`0`0````9;4!`!H```!VM0$`%```
M`)&U`0`-````IK4!`!,```"TM0$`,0```,BU`0`&````^K4!``D````!M@$`
M)P````NV`0`3````,[8!`!````!'M@$`!@```%BV`0`3````7[8!``L```!S
MM@$`!@```'^V`0`A````AK8!`!(```"HM@$`$@```+NV`0`4````SK8!`!(`
M``#CM@$`&````/:V`0`5````#[<!`!0````EMP$``P```#JW`0`*````/K<!
M`"$```!)MP$`!@```&NW`0`(````<K<!`!4```![MP$`$@```)&W`0`&````
MI+<!``<```"KMP$`,P```+.W`0`,````Y[<!`!,```#TMP$`"0````BX`0`2
M````$K@!`!4````EN`$`$0```#NX`0`5````3;@!``T```!CN`$`!````'&X
M`0`*````=K@!``<```"!N`$`%````(FX`0!)````GK@!``@```#HN`$`#P``
M`/&X`0`E`````;D!`!4````GN0$`&````#VY`0`.````5KD!`!````!EN0$`
M#@```':Y`0`+````A;D!``T```"1N0$`$P```)^Y`0`3````L[D!`!<```#'
MN0$`+````-^Y`0`+````#+H!`!4````8N@$`&0```"ZZ`0`-````2+H!``P`
M``!6N@$`&@```&.Z`0`+````?KH!``8```"*N@$`!````)&Z`0`2````EKH!
M`%8```"IN@$`%@````"[`0`+````%[L!``0````CNP$`!0```"B[`0`8````
M+KL!`!D```!'NP$`&@```&&[`0`*````?+L!``(```"'NP$`!````(J[`0`C
M````C[L!``,```"SNP$`!0```+>[`0`H````O;L!``H```#FNP$`!0```/&[
M`0`'````][L!`!@```#_NP$`$0```!B\`0!1````*KP!`!(```!\O`$`!@``
M`(^\`0`'````EKP!``@```">O`$`!````*>\`0`%````K+P!`&0```"RO`$`
M"@```!>]`0`-````(KT!``4````PO0$`!@```#:]`0`9````/;T!`#@```!7
MO0$`#@```)"]`0`)````G[T!`!<```"IO0$`"@```,&]`0`(````S+T!`!D`
M``#5O0$`+P```.^]`0`I````'[X!`"@```!)O@$`$@```'*^`0`$````A;X!
M``<```"*O@$`"````)*^`0`'````F[X!``T```"CO@$`#````+&^`0`V````
MOKX!`!\```#UO@$`,0```!6_`0`E````1[\!``@```!MOP$`60```':_`0`1
M````T+\!`!````#BOP$`$@```/._`0`9````!L`!`$X````@P`$`'0```&_`
M`0`&````C<`!`!\```"4P`$`!P```+3``0`&````O,`!`"````##P`$`!@``
M`.3``0`)````Z\`!`"<```#UP`$`)@```!W!`0`'````1,$!``H```!,P0$`
M)0```%?!`0!+````?<$!`!@```#)P0$`'0```.+!`0`6`````,(!``(````7
MP@$`#0```!K"`0`(````*,(!`!,````QP@$`#0```$7"`0`&````4\(!``8`
M``!:P@$`%````&'"`0`4````=L(!``@```"+P@$`"0```)3"`0`+````GL(!
M``H```"JP@$`"P```+7"`0`1````P<(!``\```#3P@$`$@```./"`0`3````
M]L(!``8````*PP$`%0```!'#`0`4````)\,!``4````\PP$`!@```$+#`0`%
M````2<,!`!<```!/PP$`(````&?#`0`1````B,,!``T```":PP$`#````*C#
M`0`4````M<,!`!````#*PP$`$0```-O#`0`$````[<,!`!0```#RPP$`!0``
M``?$`0`%````#<0!`!<````3Q`$`$P```"O$`0`4````/\0!`!P```!4Q`$`
M(0```''$`0`9````D\0!`!D```"MQ`$`'0```,?$`0`B````Y<0!`!P````(
MQ0$`!````"7%`0`%````*L4!``X````PQ0$`#@```#_%`0`(````3L4!`"(`
M``!7Q0$`#0```'K%`0`4````B,4!``@```"=Q0$`$@```*;%`0`'````N<4!
M`!````#!Q0$`#P```-+%`0`(````XL4!`!8```#KQ0$`$@````+&`0`<````
M%<8!``4````RQ@$`!````#C&`0`#````/<8!`%$```!!Q@$`/P```)/&`0`>
M````T\8!`"0```#RQ@$`00```!?'`0`1````6<<!`#X```!KQP$`+@```*K'
M`0`<````V<<!`#H```#VQP$`2@```#'(`0!7````?,@!`%P```#4R`$`$```
M`#')`0`B````0LD!`$<```!ER0$`%0```*W)`0`A````P\D!`!X```#ER0$`
M(P````3*`0`?````*,H!`!D```!(R@$`&P```&+*`0`3````?LH!`#D```"2
MR@$`.0```,S*`0`]````!LL!`#D```!$RP$`.@```'[+`0`[````N<L!`#@`
M``#URP$`<0```"[,`0`=````H,P!``H```"^S`$`"0```,G,`0`P````T\P!
M`#L````$S0$`*0```$#-`0`+````:LT!`$L```!VS0$`1@```,+-`0`'````
M"<X!`!<````1S@$`%0```"G.`0`/````/\X!`!````!/S@$`%P```&#.`0`0
M````>,X!``\```")S@$`#@```)G.`0`3````J,X!`!$```"\S@$`#````,[.
M`0`.````V\X!``4```#JS@$`(P```/#.`0`$````%,\!``@````9SP$`!@``
M`"+/`0`4````*<\!`!$````^SP$`$````%#/`0!2````8<\!``(```"TSP$`
M!P```+?/`0`2````O\\!`"````#2SP$`!0```///`0`'````^<\!`!L````!
MT`$`"````!W0`0`0````)M`!`#(````WT`$`%@```&K0`0`R````@=`!`'8`
M``"TT`$`%0```"O1`0!.````0=$!`"(```"0T0$`$0```+/1`0`&````Q=$!
M``P```#,T0$`!P```-G1`0`.````X=$!``L```#PT0$`%@```/S1`0`+````
M$](!`!P````?T@$`&````#S2`0`%````5=(!`!(```!;T@$`$@```&[2`0`E
M````@=(!`!8```"GT@$`%0```+[2`0`1````U-(!`",```#FT@$`"@````K3
M`0`,````%=,!`!0````BTP$`$P```#?3`0`,````2],!``X```!8TP$`"P``
M`&?3`0`3````<],!``T```"'TP$`"@```)73`0`?````H-,!`!(```#`TP$`
M%P```-/3`0`&````Z],!`!````#RTP$`%0````/4`0`6````&=0!``T````P
MU`$`&````#[4`0`Q````5]0!`!T```")U`$`#@```*?4`0`/````MM0!`"0`
M``#&U`$`!0```.O4`0`1````\=0!``<````#U0$`%@````O5`0`'````(M4!
M``L````JU0$`(````#;5`0`T````5]4!``D```",U0$`(@```);5`0`;````
MN=4!``T```#5U0$`%````./5`0`$````^-4!`!0```#]U0$`"0```!+6`0`(
M````'-8!``L````EU@$`#@```#'6`0`&````0-8!``H```!'U@$`(0```%+6
M`0`_````=-8!`$````"TU@$`)````/76`0`M````&M<!`"H```!(UP$`1P``
M`'/7`0`D````N]<!`#,```#@UP$`0P```!38`0!A````6-@!`#0```"ZV`$`
M+0```._8`0`'````'=D!``@````EV0$`"0```"[9`0`4````.-D!`!L```!-
MV0$`&P```&G9`0`P````A=D!`"4```"VV0$`(@```-S9`0`Z````_]D!`$(`
M```ZV@$`!P```'W:`0`9````A=H!``D```"?V@$`"````*G:`0`@````LMH!
M`!$```#3V@$`%````.7:`0`-````^MH!``@````(VP$`%0```!';`0`)````
M)]L!``\````QVP$`#0```$';`0`:````3]L!`!@```!JVP$`.P```(/;`0`*
M````O]L!``\```#*VP$`!@```-K;`0`:````X=L!`!````#\VP$`!0````W<
M`0`-````$]P!`!`````AW`$`"0```#+<`0`,````/-P!``P```!)W`$`#@``
M`%;<`0`'````9=P!``,```!MW`$`#0```''<`0`V````?]P!`$@```"VW`$`
M&````/_<`0`E````&-T!`"$````^W0$`$0```&#=`0`5````<MT!``L```"(
MW0$`$@```)3=`0`I````I]T!``<```#1W0$`#0```-G=`0`.````Y]T!`!(`
M``#VW0$`"P````G>`0`\````%=X!``D```!2W@$`'````%S>`0`2````>=X!
M`!8```",W@$`0````*/>`0`D````Y-X!`#P````)WP$`.@```$;?`0`V````
M@=\!`!$```"XWP$`!@```,K?`0`7````T=\!`!P```#IWP$`"@````;@`0`=
M````$>`!``L````OX`$`$````#O@`0`'````3.`!`!4```!4X`$`%0```&K@
M`0`)````@.`!``<```"*X`$`%````)+@`0`1````I^`!`!D```"YX`$`!0``
M`-/@`0`'````V>`!``D```#AX`$`$````.O@`0`/````_.`!`!4````,X0$`
M%0```"+A`0`'````..$!``8```!`X0$`,0```$?A`0`I````>>$!`"4```"C
MX0$`"````,GA`0`/````TN$!`!,```#BX0$`'P```/;A`0`>````%N(!`!\`
M```UX@$`#0```%7B`0`,````8^(!``,```!PX@$`!P```'3B`0`-````?.(!
M``(```"*X@$`#````(WB`0`1````FN(!``L```"LX@$`%````+CB`0`8````
MS>(!`!4```#FX@$`'````/SB`0`C````&>,!`!,````]XP$`%@```%'C`0`.
M````:.,!``<```!WXP$`"@```'_C`0`,````BN,!``X```"7XP$`6@```*;C
M`0`8`````>0!`"P````:Y`$`%0```$?D`0`'````7>0!``@```!EY`$`$@``
M`&[D`0`K````@>0!`"0```"MY`$`%````-+D`0`3````Y^0!`"$```#[Y`$`
M&````!WE`0`6````-N4!`"0```!-Y0$`*````'+E`0`5````F^4!`%\```"Q
MY0$`(0```!'F`0`=````,^8!`"T```!1Y@$`(P```'_F`0`=````H^8!`"0`
M``#!Y@$`(````.;F`0`B````!^<!`!T````JYP$`"@```$CG`0`4````4^<!
M``D```!HYP$`"````'+G`0`3````>^<!``\```"/YP$`*P```)_G`0`5````
MR^<!``@```#AYP$`8````.KG`0`_````2^@!`%````"+Z`$`<````-SH`0`*
M````3>D!`"4```!8Z0$`+P```'[I`0`)````KND!``<```"XZ0$`#0```,#I
M`0`^````SND!``<````-Z@$`20```!7J`0`M````7^H!`"<```"-Z@$`#@``
M`+7J`0`W````Q.H!`!T```#\Z@$`00```!KK`0`V````7.L!`#\```"3ZP$`
M-0```-/K`0`4````">P!``H````>[`$`$P```"GL`0`6````/>P!`!@```!4
M[`$`"````&WL`0`Q````=NP!``H```"H[`$`"@```+/L`0`F````ONP!``H`
M``#E[`$`%P```/#L`0`6````".T!``<````?[0$`$0```"?M`0`1````.>T!
M``H```!+[0$`%@```%;M`0`$````;>T!``4```!R[0$`!@```'CM`0`/````
M?^T!`!(```"/[0$`$````*+M`0`=````L^T!``T```#1[0$`!P```-_M`0`0
M````Y^T!`"````#X[0$`$@```!GN`0`-````+.X!`!H````Z[@$`)@```%7N
M`0`.````?.X!`!\```"+[@$`+P```*ON`0`)````V^X!``L```#E[@$`&```
M`/'N`0`0````"N\!`!8````;[P$`&0```#+O`0`.````3.\!`!````!;[P$`
M#0```&SO`0`)````>N\!`"T```"$[P$`!@```++O`0`)````N>\!``T```##
M[P$`$P```-'O`0`&````Y>\!`!P```#L[P$`&`````GP`0`/````(O`!``@`
M```R\`$`'@```#OP`0`;````6O`!``P```!V\`$``@```(/P`0`'````AO`!
M``@```".\`$`;@```)?P`0`0````!O$!``<````7\0$`)P```!_Q`0!&````
M1_$!`!P```".\0$`)P```*OQ`0!$````T_$!`#$````8\@$`0````$KR`0`<
M````B_(!`!8```"H\@$`$@```+_R`0`&````TO(!``T```#9\@$`"@```.?R
M`0`)````\O(!``T```#\\@$`$0````KS`0`/````'/,!``H````L\P$`#```
M`#?S`0`0````1/,!``<```!5\P$`"````%WS`0`'````9O,!`!0```!N\P$`
M%````(/S`0`/````F/,!``4```"H\P$`)0```*[S`0`5````U/,!``H```#J
M\P$`%````/7S`0`+````"O0!`!0````6]`$`"P```"OT`0`&````-_0!`!8`
M```^]`$`%@```%7T`0`'````;/0!``<```!T]`$`&0```'ST`0`(````EO0!
M``4```"?]`$`!P```*7T`0`2````K?0!`!L```#`]`$`"P```-ST`0`-````
MZ/0!`"T```#V]`$`(0```"3U`0`8````1O4!``4```!?]0$`#````&7U`0`4
M````<O4!``T```"']0$``@```)7U`0`3````F/4!`!(```"L]0$`'P```+_U
M`0!`````W_4!`",````@]@$`-````$3V`0`Q````>?8!`#0```"K]@$`(@``
M`.#V`0!B`````_<!`!8```!F]P$`;@```'WW`0`[````[/<!`%8````H^`$`
M<0```'_X`0`M````\?@!`#P````?^0$`*P```%SY`0`P````B/D!`#````"Y
M^0$`'````.KY`0`Z````!_H!`+\!``!"^@$`*P````+\`0`?````+OP!`!8`
M``!._`$`5@```&7\`0",````O/P!`#,```!)_0$`0````'W]`0!:````OOT!
M`%`````9_@$`(@```&K^`0`5````C?X!`!T```"C_@$`'0```,'^`0`J````
MW_X!`!P````*_P$`)0```"?_`0`C````3?\!`!8```!Q_P$`-P```(C_`0`J
M````P/\!`"@```#K_P$`&@```!0``@`P````+P`"`&(```!@``(`+0```,,`
M`@`T````\0`"`$4````F`0(`,@```&P!`@`K````GP$"`$<```#+`0(`90``
M`!,"`@!:````>0("`#$```#4`@(`+@````8#`@`L````-0,"`%D```!B`P(`
ME0```+P#`@!L````4@0"`%P```"_!`(`6@```!P%`@`R````=P4"`"4```"J
M!0(`)0```-`%`@`K````]@4"`&X````B!@(`:P```)$&`@#`````_08"`!D`
M``"^!P(`)P```-@'`@`^``````@"`"T````_"`(`40```&T(`@`G````OP@"
M`%P```#G"`(`'@```$0)`@`*````8PD"`-X```!N"0(`.P```$T*`@`I````
MB0H"`$(```"S"@(`/0```/8*`@`E````-`L"`"````!:"P(`/P```'L+`@`(
M````NPL"``@```#$"P(`"0```,T+`@`3````UPL"`!````#K"P(`$@```/P+
M`@`+````#PP"``8````;#`(`#@```"(,`@`$````,0P"`%P````V#`(`!```
M`),,`@`1````F`P"`!(```"J#`(`"````+T,`@`&````Q@P"``X```#-#`(`
M!````-P,`@`6````X0P"``H```#X#`(`"0````,-`@`1````#0T"`!,````?
M#0(``@```#,-`@`4````-@T"`!0```!+#0(`$@```&`-`@`.````<PT"`!4`
M``""#0(`!@```)@-`@`6````GPT"``T```"V#0(``P```,0-`@`T````R`T"
M``0```#]#0(`$P````(.`@`'````%@X"`"0````>#@(`4````$,.`@`Y````
ME`X"`#H```#.#@(`'P````D/`@`G````*0\"`"(```!1#P(`)@```'0/`@`H
M````FP\"`",```#$#P(`)0```.@/`@`L````#A`"`"<````[$`(`.P```&,0
M`@`B````GQ`"`#@```#"$`(`-````/L0`@`E````,!$"`"D```!6$0(`+```
M`(`1`@`G````K1$"`"P```#5$0(`+0````(2`@`U````,!("`"$```!F$@(`
M)0```(@2`@`J````KA("`#(```#9$@(`)0````P3`@`L````,A,"`!L```!?
M$P(`)0```'L3`@!"````H1,"`"8```#D$P(`*@````L4`@`M````-A0"`"X`
M``!D%`(`)@```),4`@`D````NA0"`"X```#?%`(`*P````X5`@`X````.A4"
M`!T```!S%0(`"@```)$5`@`3````G!4"`!D```"P%0(`+````,H5`@`C````
M]Q4"``T````;%@(`#P```"D6`@`6````.18"``L```!0%@(`&0```%P6`@`J
M````=A8"``@```"A%@(`#````*H6`@`A````MQ8"`#(```#9%@(`&`````P7
M`@`K````)1<"`"L```!1%P(`)````'T7`@`(````HA<"`.8```"K%P(`$0``
M`)(8`@`6````I!@"``P```"[&`(`"0```,@8`@`-````TA@"`!4```#@&`(`
M$0```/88`@`I````"!D"`"(````R&0(`!@```%49`@!%````7!D"`!P```"B
M&0(`'0```+\9`@`=````W1D"``L```#[&0(`$P````<:`@`)````&QH"`%(`
M```E&@(`*@```'@:`@`=````HQH"`!0```#!&@(`%P```-8:`@`H````[AH"
M`!@````7&P(`$@```#`;`@`D````0QL"`!,```!H&P(`%````'P;`@`,````
MD1L"`!@```">&P(`&````+<;`@`7````T!L"``@```#H&P(`+````/$;`@`)
M````'AP"`"D````H'`(`*````%(<`@`'````>QP"`!L```"#'`(`!P```)\<
M`@`(````IQP"``D```"P'`(`/````+H<`@`&````]QP"`!,```#^'`(`%```
M`!(=`@`.````)QT"``D````V'0(`"@```$`=`@`@````2QT"`!,```!L'0(`
M#0```(`=`@`6````CAT"`!(```"E'0(`&````+@=`@`8````T1T"``P```#J
M'0(`#@```/<=`@`8````!AX"``0````?'@(`+P```"0>`@`/````5!X"``4`
M``!D'@(`!P```&H>`@`"````<AX"`!$```!U'@(`(P```(<>`@`+````JQX"
M``,```"W'@(`!@```+L>`@`,````PAX"``P```#/'@(`$0```-P>`@`0````
M[AX"`!8```#_'@(`%P```!8?`@`%````+A\"`"\````T'P(`'P```&0?`@`>
M````A!\"``D```"C'P(`*0```*T?`@`'````UQ\"`!<```#?'P(`/@```/<?
M`@`1````-B`"`!(```!((`(`"````%L@`@`$````9"`"``4```!I(`(`#0``
M`&\@`@`:````?2`"``8```"8(`(`!P```)\@`@`)````IR`"`!$```"Q(`(`
M"````,,@`@`2````S"`"`!(```#?(`(`,````/(@`@`4````(R$"`!D````X
M(0(`)````%(A`@`B````=R$"`"4```":(0(`$````,`A`@`"````T2$"``0`
M``#4(0(`"P```-DA`@`*````Y2$"``4```#P(0(``P```/8A`@`-````^B$"
M`$<````((@(`%0```%`B`@`R````9B("`#D```"9(@(`4@```-,B`@`/````
M)B,"`'8````V(P(`(@```*TC`@!.````T","`"\````?)`(`-@```$\D`@`]
M````AB0"`"D```#$)`(`)P```.XD`@`P````%B4"`#0```!')0(`+0```'PE
M`@`I````JB4"`"P```#4)0(`+@````$F`@`Q````,"8"`"8```!B)@(`%```
M`(DF`@`0````GB8"`'L```"O)@(`"@```"LG`@!X````-B<"`'H```"O)P(`
M>0```"HH`@`P````I"@"`&$```#5*`(`%````#<I`@`2````3"D"``T```!?
M*0(`@P```&TI`@`F````\2D"`#D````8*@(`(@```%(J`@`@````=2H"`&L`
M``"6*@(`&P````(K`@`*````'BL"``4````I*P(`!@```"\K`@`(````-BL"
M``4````_*P(`%P```$4K`@`9````72L"`!<```!W*P(`(@```(\K`@`0````
MLBL"``X```##*P(`"````-(K`@`'````VRL"``X```#C*P(`!P```/(K`@`&
M````^BL"`!<````!+`(`!P```!DL`@`%````(2P"`!(````G+`(`!P```#HL
M`@`+````0BP"`!,```!.+`(`#0```&(L`@`7````<"P"``T```"(+`(`"0``
M`)8L`@`0````H"P"``H```"Q+`(`!0```+PL`@`+````PBP"``4```#.+`(`
M!@```-0L`@`*````VRP"``@```#F+`(`#````.\L`@`3````_"P"``<````0
M+0(``@```!@M`@`"````&RT"``@````>+0(`"````"<M`@`'````,"T"`"P`
M```X+0(``@```&4M`@`$````:"T"``X```!M+0(`#@```'PM`@`0````BRT"
M`!4```"<+0(`$````+(M`@`+````PRT"``8```#/+0(`!P```-8M`@`2````
MWBT"`!(```#Q+0(``@````0N`@`'````!RX"`!`````/+@(`*@```"`N`@`V
M````2RX"``D```""+@(`"````(PN`@`+````E2X"`!P```"A+@(`!0```+XN
M`@`&````Q"X"``L```#++@(``0```,X%``#7`@``X04``*<"```'!```:@8`
M``````!3!@``Y`4``#($``#&````;@,``+D&````````NP$``'L%````````
M,P,``#H&``!M`0``O`4```````"&`0``"0(``.0#```3!@```````#8"``#L
M`````````&(%``"!!0``,P8```````!9`@``P`0``'0#`````0``Y00```D`
M```'````MP4```````#?!@````````````#,`0``"````&@````-`@``````
M`/X$``#I````\P4``/$%````````T0$``!`&````````````````````````
M;`$``-@`````````D@8``!,`````````1@(``)\!````````X`(``-,````J
M!0``;@````````#5!0``>`(``+\$```?`@``PP0``($"``#_`0```````,,&
M``!K`@``70```)`%````````40,``"0!``"D````2P4``)D!``!C`0``)P,`
M```````L`P``30(``*(&``"9````T`4``-@#````````)P$``,X```#!!@``
M`````,<&``!\````C0````````"E!`````````````!S`0``?08``.D!``!#
M`P``&0(```````!+!```Y@(``#,!``#`!@``+`````````#4!@``H04`````
M```?`0````````P```!'````]P,``$X"``#[!````````"`!``"8!@``4@$`
M`#H"```Y`P``*`,``-X!``"6`P```````)P%``!+`0````````(!``"/`0``
MX`$``(H$``#+`P```````+P!```:!```?04``/4#``">!@```````%T#````
M````[04``&\%``#R`0``"@4````````>`@``"0$``/X#``#)`0``U`0``$8!
M``#A`@````````````#>`P``>````%L$``#*````20$`````````````TP8`
M`,X#````````J0,``"@%``"S``````````T%``"*!0``>0```&\!```>`0``
M&04```````"Q`0``3`8``````````````````'`#`````````````&\"``""
M!```%`8``+T%``"?!0```````.X```!@!P``X@0``(@$``!?`P``[P8`````
M``"$!0``<@<``$\'```Z!P``QP,``,L"`````````````,0#``#S`0``````
M`)`#``#?`````````/X%````````@@$``!8%``"B!0``Z08`````````````
M(`(```````"_`P``TP$``.`&``!:````]P(```````#I`@```````'X!```\
M!0``M`4``)L"```U!P```````/P$``"Q````H@```-H"``!O!P``$P4``-<`
M````````YP8``$H"``#K`@``=@0``+\&``#_`@``4@0``!8'``!!````8```
M`','``!Z!```I0```!$"``#2````+@,``*\&```!`P```P0`````````````
M2P```-T#`````````````(H#```=!0``\@0``&,`````````%0,``!(%```L
M!0``M0,``-8```"Q`P``/P<``(0&````````Q0(```````#S`@```````.D#
M```Y`@``JP0```````!@`P``,04``!$&``#Q`P``A0```,\$``""`@``RP``
M`(4!``!5!0``7`$``.<$```/!P``"P$```````!P`0``M04``!X$``#A`P``
M`````&(!``"+!@`````````````<`@``[08```````!Q``````````````#-
M!```O@4```````#=`0``2`<``,L$```P!0``90$``(0````3`@``G`$`````
M```3!````````,$#``#^!@``$0<```````!0!0``,0$``*P!``#"!```C04`
M`*4"```E````T`0`````````````[`$```````!8!0``_P0``)`&``#G`0``
M<@0``.L&``!+`@````````T$``"`!0``=`(``(\#``")`0``^0```$D%``!6
M`@``F0(`````````````D@`````````H!P``5@0``*0"`````````````%\"
M``!]````!`4`````````````"P````````"@`P``"08``"L'````````>`0`
M`!L&``"L!@```@```+\"````````9@```)L%``#T!0``X@8`````````````
MN00```````"F`@``]04``(<$```````````````````I!P```````"T&``"5
M`0``N`0``/$!``"[!0``&@8```````!I`0``V@4```````#<````+P0``/4&
M````````-0```+4```#]`P``I@$```````!J!P``U08```````!%`0``(P``
M`#@"````````\P```#\!````````C08``(8"``"#!```3@8``$$!``"1`P``
MF`(`````````````KP4``````````````````-P#``"1!@``[@(```$!``#O
M`0``*`0```````!_`0``'P0``$T#``!W`0``-`,``"4%``"*````#08``$<'
M``#[`P``I08`````````````?P```.0$````````,@```-X&````````3@$`
M`$H&`````````````"<$``#J````Z@4``)\$``"L``````````X%````````
M`````,$%````````B`4``-8#``#.!```G0,```````!%!0``J0````````#T
M````I`$``!D#````````,@(``.`#`````````````#H$```U`@``K`4`````
M```]`0``5`0``/D"``!O````#P,``(,%``!G!````````&T%``"H!0``#@<`
M````````````PP,```````!/!0``]@```#P#``"'````^P```%T!```[`@``
MA0(``+D"``"P`0``T08``#L$``#*`@```````,0!``!9`P```04``/`!``#`
M`0````````````#T!@```````"P"``!/`@``60$``-0!``".`P``9P,``#@!
M````````904``*D"``!]`0``+0,`````````````0@0``+D```#P!@``4@``
M`%\!``!V!0``1`(``!(!````````)`4``,4```"S!```BP(```````"]!@``
M;`````D%````````,P<```````!>`@``8P8``+L&``!I`P``6`8``&4&````
M````T`(```@"``#F`0```````'X````U`0``V0,``"H$````````*00``"`$
M````````1@`````````Z!0``.P,``.4!````````I@8``$H#``!M````````
M``````"N`````````%L'``!8!P``+00``"`#``"C!@```````)@```!>`0``
M!0(``+<```"Y`P``/@4``/0"``#S!```M08``)(%````````O`,```````#P
M````W00``*T&```Y!```50$``#(%``".`@``_@`````````+!@``_04`````
M``"2`0``I`,``&4$```D````C@```'`"``!-````BP4``$T'``#6!0``6`,`
M``````#A`0``L`4``!\&```P`@``F`0```````!0`0```````%$!```-`0``
M``````````"N`P``````````````````[`,``!@&```7`@``IP8``%`#``"1
M!0```````$8%`````````````,T!```*`0````````````"0`@``M`(``-4#
M``#2`@```````&\&``#M`````````````````````````*\````L!@``3@0`
M``````"%!0```````/\````\!@``*P0``"X!````````U0```),$``"D!0``
MJ@8``.4%``!Z`@``(@(``#0```#-!@``108```<!````````?@8``$D$``#O
M`````````#@&``!R!0``>@,``&D'````````!0,``)H%``#8!0``'`4``)X!
M```A`P```````'0$````````Y0```&0"```Q`@``````````````````C`(`
M`!8```!D`P``(P4``(L`````````C`0``)L```"T````YP```)("``!Y!@``
M5`,``,T%``!L!@``]@4```\"````````````````````````7@```-(!```E
M`P``4P```)<"``"7````7`````````!\!@```````&4"``"3!@``C@$``'<%
M``#1!0```````,("``!`!P``,0``````````````I@4``!4```!#`@``>@``
M``````!5!P``A00``($```"``0```````%4`````````G@,``"8$````````
M*0$``````````````````-<!``!@`@``/`(``!`#``".!@``O````$T!``!I
M`@``7P4``&0%``!G!@``+04``)8!````````K`,``!<#``"M!`````````8!
M```C!@``RP4``!L"```@`````````$,%````````6P,`````````````````
M`+`&``!7`P``[`(```@'``",````$`4``(4&````````1`0``,`#````````
MM@(```````#,!```HP0``$X``````````````","``#\!@``6P````H&``!"
M!0```````.,$````````Q`8``*H!````````F0,``#P'````````````````
M``!5`P``XP`````````,!P``L00``$@$``#N`P``#P$``)4&``"C`P``````
M`/P!``!"!P``A`0``(L!````````!@8``!4&```V!0```````(@&``#.!@``
MF@```$,'```7!@```````",'``!)`````````/<%``"Q!@``9@,```````#/
M!0``M@8```X$```;````,@<``!X%````````[@0```<'````````A@,`````
M``"T!`````````````#X`@``OP4`````````````4P<``!4"``"7!0``3`(`
M`,(&```I!@``T00``%D&`````````````(8$``"5`P``]P````````!X`0``
MI@0``,4$````````%`(``(H"```V`P``#`8``.L```!!!@```````.0"````
M````W@```($#``!S`P``0`,``-L&```[!@``+0```&L$````````T`8``'L$
M```W!`````0``#H#``"]!```.@$```````!^!```6`$``%<'``#0````````
M`(X%``":`0``^@8``&4'````````)08``````````````````,<$``"'`P``
M404`````````````8@(``"<"``#Z!```D00````````B````H0```-H$``!K
M````-0,``+<#```H````(@,``&`&``"(`P``208```0!``!1````H00`````
M``!!`P``R````#@#```A!```B`(``.D%``"D!```````````````````=P(`
M`%T%```$!`````````8'```J`P``O@(``&T$``!D````````````````````
M^`0``#\$````````[@8``"4$````````:@(```````"9!0``&`$```````#9
M!0```````*`!```0!P``D````/L!``#M`0``%P<``,8"``"-!```P@4``#8'
M```J`@``0`4```,'``#P`@``DP4``/T$````````H@(``!T#``#?`0``/@0`
M`"T'``!Q!```0`0````````6`@``G`(```T'``#U`@``7`8``(0"````````
M``````,```#4`P``<P```````````````P,``&(&``#/`0``0`8````````^
M`0```````&0$``#E`@``Y0,````````B!P``'`,``$<#``!F!@```````'<#
M````````VP4``%\$``#2`P``````````````````6P(``#8!``#C`@``/@8`
M`+(```#6`@``U0$````````X````5`4```````";`P``EP0``,P`````````
M6@<``!$!````!@``$`(```````!+`P``W0```"<`````````MP(````````-
M`P``L@(``(@```"F````?`$``.\#````````=@```'\$``#'`0``90,``"$&
M```F`@``L`(``-<$````````B08```````!S!```G00```````"Q`@``R08`
M`!`!````````Q04``,8&```U!@``0`(``&X"````````HP4``#,%```Y!P``
MP0```'X%```J`0``004``!H#````````?@,````````+`@``O0(`````````
M`````````````````````````&<"``"K`P``8`$``*D$```X!0``/P``````
M``"@!```.`<```<"``"``P``````````````````*P$```````#/!@``````
M`$0'``#-`@``.@``````````````T@8``$(```!.`P````````````!V!@``
MM@4``&8"``#<!@``B@$```````#9!```D`0``'8!``!/!@``LP$`````````
M````TP(```````"``@``B0````````!U`@``O0```#,```"5!```8P0``.8#
M````````/0```/@!````````B`$``$4#``#[`@``1````)L!````````````
M`+@```#2!0``-`4``!D'``"&!@``%`,``,@#``"X`P```````%`'``"<````
M7@,``#8$``"_`0```````-@"`````````````-<#``":`@```````-8!````
M`````````$P'```(!```*P(``(P%``"<`P``;08``-\$`````````````/0!
M`````````````,4&``#7!@``EP8``"X```!6`0``[P4``(P#``#,`@``````
M`+0&```P!@``Z@8``!@'````````O0$``*L%````````R@8``/T```!'!0``
M@00``"L#````````:P,``'D!```E!P`````````````!!```&P,````````^
M````?P,``/`$``#D`0```P4``+(!``"`!```]P$``.L!``#V`0```````!D!
M``"S`P``6P4``/\%``#.`0```````!0!``"-`P``[@$``*(#```4````J04`
M`!X````B!@``$@0``!\````0!````````&<'``"#`0```````.$```#B````
M800``&$%``"#`P``W`(`````````````H`(``"L%```@!0``^@4``%<!``"=
M`@``M@```!T!```!!@```````!P&``#<`0``A`$``"0$``"B!```J`,```<%
M``#J!```XP,``,(#``"S!@``]0$```````!R!@``V0``````````````6`0`
M``````!P!P``7@0``,P&``!W!@``*0(```````#-`````````&$"``#)!```
M6P$``&@"```W`@``YP(``"\```"9!@``NP0``,L&``!``0``-`$``,@"````
M````&`4```````"3`0``1P8```(#```_`P```````&D$``#;!```VP(`````
M````````K@0``)T!```1`````````,$$``!4!P````````````"=!0```0(`
M`%$'``#M!```"@<```````#X`P``O@,``*<#````!P``5@,``"X"```X!```
M``````````"'`0``2`8``*\"```P!P``B04`````````````&`0```````!B
M````/@(``!P$``!L!```^`8```````!U`P``T`,``$T&``#=`@```````(D#
M````````9P4``%`&``"+!```X`4``'$%``#Z`P``T0,``-4"```5!P``````
M`)@%```V````H`4```````#R```````````````L!P``:@,``'P"``!@!0``
M``````@&``!*!````````!@"`````````````#0'```#`0``=P0``/$```!S
M`@``T0(```````#$````L04``'X"``"U!```JP(``#$$```[!0``ZP0``/`#
M````!0``H`````````"L!```"@0``'P%```)!````````&L'```R!@``6@,`
M`,D"````````W@0```````!Y!```)`8```````#W!```6@(``)0"``!&!@``
MB@8``!D$````````10```"@&``!"!@``708``%@`````````K0$``$@!````
M`````````````````````````/("```F`0``<0(```D#`````````````/@%
M````````N@````````!H!`````````````"8`P````````````"T`0``8P4`
M`$,```!B`P``!`(``#P!``!A!P``````````````````%`4``!H````*`P``
M`````(D$```N!0```````+,%```A````J@(``/@``````````````'L#```$
M````+P(``!D````7!0```````$H%```A`0``5P(``%P$``!R`@``4@4`````
M````````9`<``!H!``#H`````````#,$``![!@``H0$``%D$``#S!@``DP``
M`.,%```%!P```````/P#``#H`0``Z`(``#<```"L`@``-P4```````#J`P``
M`````!T$``!<!P```````%P#```>!P``<`8```````"/!0``R@0``&$```!A
M`P``VP,``(,"``#"````NP(````````2`P``H`8``(8```!/!```+P4``(P&
M```8````'0(``,````#K`P``&P4``!8!``!(`@``U````-,%````````?`0`
M````````````^00`````````````\@4`````````````6`(``#D%````````
MQP(```````!\`P````````P$```,!0``)P8``!('```F`P```````*<$``#\
M!0``G@```%T'``"J!`````````````!1`@``I04``!\#`````````````%4&
M````````7@4`````````````[`0``,`%```V!@``_````!,'````````````
M```"```U!```+P8``$$'``"O!```CP````````"`!@``N@,````````G!0``
MS`,```````!<!0``>0(```\&`````````````+H"``"9!```L````),#``"E
M`P``60<``+0#```"!0``V0$``&,"``"4`P``\00``*<```!Z!@``/08``$P%
M``!)`P``V`$``"($`````````````)T```"D!@``;`<``/(#``!/`P``````
M```````(`P``+@0``*X!````````O@8``'0&```L!```#`,``,8%``"C````
M@P8``,4!``"'!0``@@,``"@!``#\`@``0P8``#<'`````````````*L````R
M`P``7@8``%0!``!4````FP8``-,$``#(`0``/P(``+X````=!P``'@,`````
M``":!```L@8``.(#`````````````$,!````````=P`````````N!P``````
M`((```!_`@```````",#``!D`0``;P,``$T$````````+0(```````#1````
MV@``````````````:`8``-\%```F!@``:`,``'\&``!F`0``'`````````"=
M!@````````````#A!@``RP$``&D````^`P```````-`!``#F!```>0,`````
M``#F````MP$````````Y````>P```/X!``#W!@``J`0``#T#``#@!```````
M`)P$```2````M@$``%H!``!N!````````$@#``#@````%04``/D#``#Q`@``
MKP$```($``"\!```"0<```````!J````&`,```````!2!P``:08``)($``!S
M!0````````````!B!P``$````,0%```Q!P````````````#:`0``MP8```0#
M```/!0``>@4``+@!````````!0$``````````````````+@"```Y!@``NP,`
M`$H'```(!0``10<```X"```F````9P$``(0#````````4P(```````!N`0``
M-P$``)H#````````808``*@!``````````````````!?!P```````%`"````
M````H0,```````#_`P``O`(``/0#```F!0``(P0``%,%``!]`@``````````
M```P````(@$``/L&``"R!```:@4``.\"````````U@8``.("``"^`0``408`
M`&L!``#Z````2`4``%0"``!P````=08``#T"``!M!P``DP(``!("```#!@``
M``````````"?````#@8``/4````Y`0``UP4````````J````!`8``!X&````
M````[0(``'(!``#*`0``>04``.@%``"R`P``5@<`````````````9@<``/4$
M``"K`0``CP0``*T#``!T`````````%("``#4`@``IP$``/D!````````X@4`
M`$H````]!0``500``*,!``#H!@``7@<```````#-`P``60```+L```";!```
M50(```````!7`````````($&```W!@``GP8``````````````````"\#````
M````P@$``(T"``````````````````!+!@``N@8``)\"```_!0``````````
M``!J!```6@4```````#L!0``L`,`````````````,P(``-P$```]!```20(`
M``````"X!@```````/8&``#$!```XP$``$P#``"Y!0```````'(```!2`P``
M(04```````"4!```VP$``````````````````+H%``!F!0``4P$``*X%``!0
M!```700``-T%``!G````-`0```4&`````````````)X$``!#!```:P4`````
M``!_!0``"P,``-X%````````A0,``+@%``#V`P``@@8``"D%````````X@$`
M````````````````````````````Q@0``,<%``"4````:`4```````"-`0``
M*@8``!0$``"6!0``8@0``,4#```H`@``5@4```````#T!```E0(``!H%``"O
M`P``ZP4```````"7`0``D0```)(#``#P!0````````@!``!A`0``+`$`````
M````````_08``%````#*!0``00(`````````````!@(`````````````20<`
M```````7````5P0``(L#```&`P```````%$$```\!```2P<``(\&``!&!P``
M`````!P'```%````K0(``%H&``!9!0``8P,```<#`````````````"0"``!J
M`0``MP0``#L'``!Q`P``K04```````!H!P``H@$```````!V`P```````(``
M````````1`$``'4```#&`0```````)0%``!6!@```````!<$``!%`@``6@0`
M`-H#``#5!````````,@&```:!P``(@4```("``"4`0``)0$``.8&``!!!```
ML@4`````````````4P0``)4%``#9`@````````````#)!0``_@(``/8"``#<
M!0``HP(````#``!,`0``LP(``*X"``#V!```(0<``)4```!U`0``;P0``,8#
M````````D`$``&X&``#M`P```````!,!``![`0``'08``/T"``#/`@``G`8`
M`(P!````````8P<``&`$``#$`@``V@8```\````R`0``>@$``"H'````````
MJ08``'`%``!6````_0$```````#Q!@``O@0``,\````T`@``D0$```H"````
M`````````%(&```#`@```````'4$````````[`8``+P&````````K0```$<!
M````````Z@$``,X"````````1`4````````1`P``*P````````#;````&08`
M`",!```?!P``1`8``.X%````````E@0``!8$``!R`P``+P$```8%````````
M)0(``(X$````````!00``*X&``"G!0``U@0``$``````````Z`0``/L%``#!
M`0``+@8``(\"````````,0,``!4$````````<`0``,@$````````T@0``.4&
M````````"P0``-\#``!&!```5P4``!8#````````#@,`````````````````
M`&P#```P!```&@(```$'````````PP(```````!&`P``:`$``,\#``"F`P``
MN0$```````!T`0``^04``/H!``#!`@``<0$``&X%````````3@4``"D`````
M````/0<```````!'`@``$04``,,!``#Z`@```````($!``!S!@```````!<!
M``"'!@``&P$``,`"```T!@``/````%,#``"J`P```````.D$````````L`0`
M`"<'````````@P```.\$``#D````1P0``&P%````````0@(```L%```*````
M`````/,#````````F@8``!0'``#)`````````#L```!"`P```````"$"```5
M`0``3P$``%<&``!X!0``M0$``/D&```_!@``?00``)X%`````````````-X"
M``````````````````#R!@``Y@4```\$```%!0``YP4```L'``!"`0``=04`
M`)8"```2!@``=@(```````#_!@``,08``*L&````````<0<``)8`````````
M`````"L&```'!@``(`<```````#4!0``)`<```````"'`@``*0,``$P`````
M````>`,``+8$``!/````6P8``!\%````````100````````<`0``1`,``*@&
M``#)`P``<08```````````````````````#8!@``&P0``%\&``"V`P``.P$`
M`(D"```M`0``J@```%P"```-````XP8``&0&``!E````,`,``+H$````````
MZ`,```0'``#A!```R`4``*4!``"H`@``2````"\'``#8!```;0(```````"]
M`P``9@0```````!N!P``:04``*H%``#9!@``:P8```````"I`0``R@,```8`
M``"A`@``N@$``.<#``"1`@``H08``+\```!=`@``TP,``!T````"!@``3`0`
M`,,````&!```F`$``'@&``!]`P``WP(```P"```.`0```````.H"````````
M$00```````""!0``A@4```````!*`0``(`8````````3`P``E`8```('``">
M`@``#@```"8'``!4!@```````!8&``!-!0```````'L"``!L`@``/@<``-T&
M``"6!@``PP4``'0%```U!0``QP```.0&``````````````````!.!P``GP,`
M`"0#````````,`$``&T#```,`0``-P,``%\```"U`@```````)<#````````
M`````,P%``"H`````````!L'````("`M32P@+2UM97-S86=E/4U%4U-!1T4@
M(%5S92!T:&ES(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0@;VYE<RX`("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@
M9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F
M97)E;G0@8G)A;F-H('1O"B`@("`@("`@("`@("`@("`@("`@("`@('1H92!G
M96YE<F%T960@8V]M<&5N9&EU;2X`("`M8BP@+2UB87-E/2]0051(("!&=6QL
M('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U
M;&0@8F4*("`@("`@("`@("`@("`@("`@("!U<V5D+@`@("UC+"`M+6-O;7!E
M;F1I=6T]1DE,12`@365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O
M;7!E;F1I=6T@9FEL90H@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A
M9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE"B`@
M("`@("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E8W1O<GDN`"`@
M+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I
M;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L=`H@("`@("`@("`@("`@("`@("`@
M("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E
M8W1O<GDI+@`@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G
M97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I97,N`"`@+60L("TM9&ER96-T
M;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y
M+@`@("UH+"`M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N
M`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L
M92X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92X`
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+@`@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO
M;G,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U
M;&4]34]$54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E
M(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM
M;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N
M)W0@;65R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2X`
M("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I
M=6TN`"`@+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N
M('-T871I<W1I8W,@:6X@82!L;V-A;"!F:6QE+@`@("UT+"`M+71E<W0@("`@
M("`@(%-H;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@
M86YY=&AI;F<N`"`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U
M<"!F<F]M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RX`("!C
M;VUM:70@("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R
M=F5R+@`@(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#
M5E,@<V5R=F5R+@`@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I
M=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H90H@("`@("`@
M("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2X`("!E>'1R86-T("`@("!'96YE
M<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N`"`@:&5L<"`@("`@("`@
M4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`("!I;FET("`@("`@("!#<F5A=&4@
M;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN
M9SH@5&AI<PH@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG
M(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+@`@(&UA:V4@("`@("`@($)U:6QD
M(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N
M`"`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE
M;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9`H@("`@("`@("`@("`@('!R
M97!A<F4@=&AE(&9I;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A
M=&4M:&5L<"X@66]U"B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA
M:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE"B`@
M("`@("`@("`@("`@:&5L<"!F:6QE+@`@(&UE<F=E("`@("`@($UE<F=E('1H
M92!C=7)R96YT(%!/(&9I;&4@=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T
M92!F:6QE+@`@('5P9&%T92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S
M97%U96YT+@`@('5P9&%T92UH96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA
M;F=E9"!E;G1R:65S(&9R;VT@=&AE($5N9VQI<V@@6$U,(&AE;'`*("`@("`@
M("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG
M(&]N97,N`"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@
M*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A('9A
M;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@
M8W)E871E9#H@)7,N`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E
M9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F
M;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!N
M;W0@=W)I=&%B;&4N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T
M(&9O=6YD+@`E<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT<F%C
M="<@9FER<W0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S
M)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S
M`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E
M<R!T;R`E<P`M+2!S96QE8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0
M<F5V:6]U<P`\9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RX*
M3W!E;FEN9R!T86<@9F]U;F0@:6X@;&EN92`E9"X`02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@
M4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-
M`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`
M06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!0
M87-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H
M:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@
M3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U
M<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@
M82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A
M:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T
M;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S
M97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E
M<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@
M;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S
M`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E
M<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!
M;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R
M`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!
M<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P
M<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M
M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A
M;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N
M("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI
M($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM
M96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T
M=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N
M`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S
M97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2
M041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S
M97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P
M87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A
M:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"
M87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`
M0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S
M(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!"
M;VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R
M9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T
M=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6EL9&EN9R!-3R!F:6QE
M<R!F;W(@;6]D=6QE("5S+BXN`$)U:6QD:6YG(&QO8V%L92`E<RXN+B``0G5L
M9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`
M0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N
M+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L
M;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG
M="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A
M;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O
M8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD
M<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@
M<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T
M;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BX`0V%P92!697)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#
M87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL
M('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP
M:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E
M<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A
M=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@
M=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF
M:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S
M92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R
M9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M
M;V1U;&4@)7,N+BX`0VQE86YI;F<@=7`@;&]C86QE("5S+BXN(`!#;&5A<@!#
M;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U
M<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O
M;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D
M<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S
M`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`
M0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L
M=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UA
M;F0@;W!T:6]N<SH`0V]M;6%N9',Z`$-O;6UE;G0`0V]M;6ET=&EN9SH`0V]M
M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!O<V4@365S<V%G92`H)7,I
M`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O
M;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@
M1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N
M`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E
M(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN
M=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O
M<'EI;F<@)7,@=&\@)7,`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O
M=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8V]P>2`E<R!T
M;R`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E
M<SH`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R
M>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@
M;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L
M:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T
M(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I
M;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M(B5S(BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U
M;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E
M<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@
M82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@5&EM90!#=7)R96YT(%52
M3"!I<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R
M96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX
M+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA
M;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"
M<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`
M1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E
M87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N
M=&ET>0!$969A=6QT(%!E<FUI<W-I;VYS`$1E9F%U;'0@<&5R;6ES<VEO;G,`
M1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES
M<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E
M;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@
M<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@
M<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S
M971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA
M<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H
M86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@
M4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$
M:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P
M=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C
M87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`
M1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D
M("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O
M<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`
M161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET
M(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O
M<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M
M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E
M87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N
M=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E
M8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO
M=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@
M=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H
M97)E`$5N=')I97,Z("5D('1O=&%L+"`E9"!U<"UT;RUD871E+"`E9"!N97<L
M("5D(&-H86YG960L("5D('5N:VYO=VX`17%U871O<FEA;"!'=6EN96$`17)I
M=')E80!%<G)O<@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R
M:71I;F<@(B5S(BX`17)R;W(Z(`!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%
M=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@
M,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@
M:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T
M90!%>&5C=71I;F<Z`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G
M*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%
M>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`17AT<F%C=&EN9R!F<F]M("5S+BXN
M(`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&
M965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3
M:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`
M1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&
M:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A
M<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D
M;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD
M(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D
M/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE
M<R`R`$9O<G5M<P!&;W)W87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O
M=6YD(&1I<F5C=&]R:65S.@!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T
M<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$
M97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9U>GIY`$=A8F]N`$=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;F5R871I
M;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BX`1V5O<F=I80!'97)M86YY`$=E
M=&]P="!%<G)O<CH@`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O
M961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E3
M3RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T
M:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI
M<W-I;VYS`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T
M8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(
M87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`
M2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE
M;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;'!E<B!A<'!L:6-A=&EO
M;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@=&AE
M($AO<F1E"F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RX*1F]R(&%N
M(&EN=')O9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES(&1I
M<F5C=&]R>2X`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z`$AI9V@`2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>0!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(
M;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(`2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC
M:')O;FES960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N
M(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@
M240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P
M861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E
M/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI
M9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!
M9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K
M9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC
M;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U
M<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K
M('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B
M<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!)
M;6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U
M<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT
M`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M
M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YI=&EA
M;&EZ:6YG(&UO9'5L92`E<RXN+B``26YS97)T($-?;VQU;6X@069T97(`26YS
M97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T
M(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@
M=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN
M<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L
M=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E
M<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F
M;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U
M9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES
M=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)
M4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N
M`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@
M:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T
M>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`
M26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV
M86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI
M9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI
M9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T
M;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A
M<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N
M`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L
M;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@
M;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&
M:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`
M2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@
M;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`
M2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5
M<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S
M`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE
M9G0@=F%L=65S`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER
M:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI
M9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO
M=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@
M4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN
M:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@
M9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I
M8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED
M`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS
M=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R
M90!,:71H=6%N:6$`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN+@!,
M;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,
M;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86ME('-U<F4@=&AA="!Y;W4@
M:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N
M`$UA:VEN9R!D:7)E8W1O<GD@)7,`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S
M`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T
M(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L
M9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H
M`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G
M92!C96QL<P!-97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@8V]M<&5N
M9&EU;2XN+B``365R9VEN9R!L;V-A;&4@)7,N+BX@`$UE<F=I;F<@=&AE(%!/
M(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG('1R
M86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BX`365S<V%G90!-97-S86=E(%9E
M<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC
M871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-
M97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"
M(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@
M9&5F:6YE9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO
M=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA
M;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN
M9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-
M86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R
M871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;&4`36]D=6QU<P!-
M;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD
M('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`
M36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@
M1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-
M;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S
M`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0
M;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`
M3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!
M;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T
M:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W
M86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S
M97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C
M87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O
M;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO
M;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W
M<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^
M`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM
M86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T
M:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED
M960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI
M;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V
M96PN`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN`$YO(&-O;6UA;F0@<W!E8VEF:65D+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+@!.;R!E;G1R>2!W:71H('1H92!I9"`B)7,B(&5X:7-T<R!I;B!T:&4@
M;W)I9VEN86P@:&5L<"!F:6QE+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%L
M92!S<&5C:69I960N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@
M<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF
M:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N
M97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@
M875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y
M('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O
M('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`
M3F\@<G5L97,`3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I
M;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@
M<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO
M=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.
M;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`
M3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-
M87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO
M="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U
M<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO
M=&EC90!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M
M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`
M3V)J96-T`$]B:F5C="!#<F5A=&]R`$]B:F5C="!C<F5A=&]R('!E<FUI<W-I
M;VYS`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]M86X`
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F
M;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN
M9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<'1I;VYS.@!/<F1E
M<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G
M86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W
M;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$
M871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`
M4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!0
M32!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4%](
M4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R
M86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E
M8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N
M=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI
M<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VX`4&5R;6ES<VEO;G,@9F]R`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E
M<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX
M96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@
M=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O
M(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I
M<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S
M=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W
M('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0
M<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L
M:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A
M=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O
M(%)I8V\`46%T87(`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D
M:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3
M:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U
M;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`
M4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UO=&4@4V5R
M=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F
M;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`
M4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N
M(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN
M("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T
M`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!2
M97-U;'1S("AI;F-L=61I;F<@2&]R9&4I.@!297-U;'1S.@!2971U<FX@=&\@
M3W!T:6]N<P!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X
M="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2
M:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2
M;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R
M=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A
M;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!3
M7U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V
M:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L
M9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T
M96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@)7,`4V%V
M92`G)7,G`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R
M;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H:6YG($AO
M<F1E(&%P<&QI8V%T:6]N<R!I;B`E<P!396%R8VAI;F<@9V5T=&5X="!B:6YA
M<FEE<RXN+@!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G
M<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E
M<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N
M96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N
M9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E
M<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($E$
M(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO
M=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%
M87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR
M:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N('5P
M(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I
M=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VMI<'!E9"XN
M+@!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO
M=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO
M=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@
M27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE
M8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P
M96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@
M4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P
M861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L
M:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N
M:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O
M=FEN8V4`4W1A='5S`%-T871U<R!F;W(@;&]C86QE("5S+BXN(`!3=&]R86=E
M(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L
M:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=
M`%-U`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B
M)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C
M97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F
M=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L
M;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z
M97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R
M86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M
M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L
M87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S
M(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X
M="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4
M:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E
M<R!H96QP(&9I;&4@9F]R("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN
M9R!A(&YE=R!O;F4N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI
M=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N
M($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R
M92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT
M('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE
M(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N
M=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T
M<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I
M;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@
M9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N`%1H92!H96QP(&9I;&4@)7,@9&ED;B=T('-T87)T('=I
M=&@@/#]X;6P`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!'
M;G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@
M8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J
M96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A
M;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S
M=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M
M<&]S92!P86=E`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E
M("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL
M>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E
M9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D
M+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O
M<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O
M='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R
M+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@9&]E
M<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+@!4:&5R92!W87,@
M82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E
M('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R
M;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@
M(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G
M97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E
M<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A
M<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T
M<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R
M<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M
M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA
M;F0@;&EN92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD
M97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM
M92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I
M.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K
M:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O
M;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T960`
M5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS
M90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K
M;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E
M('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M
M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@
M07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN
M;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&-O;6UA
M;F0Z("5S`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E
M<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U
M<'!O<G1E9"!%>'1E;G-I;VX`56YT<F%N<VQA=&5D`%5P9&%T90!5<&1A=&4@
M)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&1A=&EN9R`E<R!H96QP
M(&9I;&4@9F]R("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`
M57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S
M97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R
M<P!5<G5G=6%Y`%5S86=E.@!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI
M;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92X`57-E<B!P97)M:7-S:6]N<P!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L
M<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<P!5<V5R
M<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E
M<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE
M>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@
M:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT
M<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ
M`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@
M)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I
M;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB
M:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!
M4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N
M`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V%R;FEN9SH@`%=E`%=E871H
M97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N
M8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S
M`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N
M:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@
M:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K
M($%D9')E<W,`5V]R:R!0:&]N90!7<FET:6YG('5P9&%T960@:&5L<"!F:6QE
M('1O("5S+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E
M>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S
M`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R
M92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG
M(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT
M97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@
M9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O
M;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N
M`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@
M9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E
M<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B
M86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F
M;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T
M(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N
M('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M
M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`
M66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I
M;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N
M=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V97)S:6]N(&ES
M('1O;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+@I.
M;W0@86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO=7(@;F5W('!A
M<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O
M<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M
M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE
M;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO
M;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%])
M;6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,
M:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`
M7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O
M;VL`86X@97)R;W(@:&%S(&]C8W5R960Z`&-A;&5N9&%R`&-A;&T`8VQI8VL@
M:&5R90!D;VYE`&9A:6QE9`!F86QL:6YG`&9I;&4`9F]U;F0Z(`!F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:6UM961I871E`&EN
M;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N`&UM`&YA;64`;F]T(&-H86YG960`;F]T(&9O=6YD`&YO="!I;7!L
M96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P
M:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(
M5%10`'-S`'-T96%D>0!T87-K(&QI<W0`=&AE($AO<F1E(%!/(&9I;&4@9F]R
M('1H92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z`'1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5P9&%T960`
M=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U6
M97)S:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$Q
M+3(T(#`Q.C$X*S`P,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP,2TR,2`Q
M.#HR,BTP,#`P"DQA<W0M5')A;G-L871O<CH@3G5N;R!,;W5R96ER;R`\;G5N
M;T!E=&@N<'0^"DQA;F=U86=E+51E86TZ(%!O<G1U9V%L(%!O<G1U9W5E<V4@
M/&1E=D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`@+4TL("TM;65S<V%G93U-
M14Y304=%32!5<V%R(&5S=&$@;65N<V%G96T@9&4@8V]M971I;65N=&\@96T@
M=F5Z(&1A"B`@("`@("`@("`@("`@("`@("`@("`@("!M96YS86=E;2!P;W(@
M;VUI<W/C;RX`("`M82P@+2UA9&0]05)154E63R`@("`@061I8VEO;F%R(&5S
M=&4@87)Q=6EV;R!03R!A;R!C;VUPZFYD:6\N(%5T:6P@<&%R80H@("`@("`@
M("`@("`@("`@("`@("`@("!I;F-L=6ER('5M(&-O;7#J;F1I;R!D92!U;2!R
M86UO(&1I9F5R96YT92!N;PH@("`@("`@("`@("`@("`@("`@("`@("!C;VUP
MZFYD:6\@9V5R861O+@`@("UB+"`M+6)A<V4]+T-!34D@($-A;6EN:&\@<&%R
M82!O(&1I<F5C=/-R:6\@8F%S92`H2&]R9&4I(&$@=7-A<BX`("`M8RP@+2UC
M;VUP96YD:75M/4%2454@($EN=&5G<F%R(&YO=F%S('1R861UY_5E<R!A(&5S
M=&4@87)Q=6EV;R!D92!C;VUPZFYD:6\*("`@("`@("`@("`@("`@("`@("`@
M("`@(&4@;N-O(&%O(&-O;7#J;F1I;R!P;W(@;VUI<W/C;R`H8V]M<&5N9&EU
M;2YP;R!N80H@("`@("`@("`@("`@("`@("`@("`@("`@<&%S=&$@:&]R9&4O
M<&\N`"`@+6,L("TM8V]M<&5N9&EU;3U!4E%5("!5<V%R(&5S=&4@87)Q=6EV
M;R!D92!C;VUPZFYD:6\@96T@=F5Z(&1O(&%R<75I=F\*("`@("`@("`@("`@
M("`@("`@("`@("`@('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O(&YA('!A
M<W1A(&AO<F1E+W!O+@`@("UD+"`M+61E8G5G("`@("`@($UO<W1R87(@;65N
M<V%G96YS(&1E(&5R<F\@9&]S(&)I;N%R:6]S(&5X96-U=&%D;W,N`"`@+60L
M("TM9&ER96-T;W)Y/5!!4U1!($-R:6%R('5M(&-O;7#J;F1I;R!N97-T82!P
M87-T82X`("`M:"P@+2UH96QP("`@("`@("!-;W-T<F%R(&5S=&$@;65N<V%G
M96T@9&4@86IU9&$N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V%R(&%P
M96YA<R!E<W1A(&QO8V%L:7IAY^-O+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@
M("`@57-A<B!E<W1A(&QO8V%L:7IAY^-O+@`@("UL+"`M+6QO8V%L93UL;%]#
M0R`@("!5<V%R(&5S=&$@;&]C86QI>F'GXV\N`"`@+6TL("TM;6]D=6QE/4W3
M1%5,3R`@("!#;VYS=')U:7(@87)Q=6EV;W,@34\@87!E;F%S('!A<F$@97-T
M92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN`"`@
M+6TL("TM;6]D=6QE/4W31%5,3R`@("!,:6UP87(@87)Q=6EV;W,@4$\@87!E
M;F%S('!A<F$@97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@
M("A(;W)D92DN`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#;VUE=&5R(&%S
M('1R861UY_5E<R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@
M("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/
M("`@($-R:6%R(&\@87)Q=6EV;R!03R!A<&5N87,@<&%R82!E<W1E(&WS9'5L
M;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@+2UM
M;V1U;&4]3=-$54Q/("`@($EN=&5G<F%R(&%R<75I=F]S(%!/(&%P96YA<R!P
M87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R
M9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@06-T=6%L:7IA<B!A<G%U
M:79O<R!D92!A:G5D82!A<&5N87,@<&%R82!E<W1E"B`@("`@("`@("`@("`@
M("`@("`@("`@("!M\V1U;&\@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($%C='5A;&EZ87(@87!E;F%S(&5S=&4@;?-D=6QO("A(;W)D92DN
M`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!'97)A<B!A<F-H:79O(%!/5"!A
M<&5N87,@<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@("`@
M("`@*$AO<F1E*2X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($[C;R!I;G1E
M9W)A<B!N;W9A<R!T<F%D=>?U97,@;F\@8V]M<.IN9&EO+@`@("UN+"`M+6YO
M+6-O;7!E;F1I=6T@("`@3N-O('5S87(@=6T@8V]M<.IN9&EO+@`@("US+"`M
M+7-T871I<W1I8W,@("`@("`@1W5A<F1A<B!E<W1A=.US=&EC87,@9&4@=')A
M9'7GXV\@;G5M(&9I8VAE:7)O(&QO8V%L+@`@("UT+"`M+71E<W0@("`@("`@
M($UO<W1R87(@;W,@<')O9W)A;6%S(&$@97AE8W5T87(@;6%S(&[C;R!O(&9A
M>F5R+@`@(&-L96%N=7`@("`@($QI;7!A<B!O9B!A<G%U:79O<R!03R!D92!E
M;G1R861A<R!P;W(@=')A9'5Z:7(@;W4@;V)S;VQE=&%S+@`@(&-O;6UI="`@
M("`@($-O;65T97(@87,@=')A9'7G]65S(&YO('-E<G9I9&]R($-64RX`("!C
M;VUM:70M:&5L<"!#;VUE=&5R(&%R<75I=F]S(&1E(&%J=61A(&YO('-E<G9I
M9&]R($-64RX`("!C;VUP96YD:75M("!296-O;G-T<G5I<B!O(&%R<75I=F\@
M9&4@8V]M<.IN9&EO+B!!=&5NY^-O.B!/(&YO=F\@87)Q=6EV;PH@("`@("`@
M("`@("`@('-O8G)E</5E+7-E(&%O(&%N=&EG;RX`("!E>'1R86-T("`@("!'
M97)A<B!A<G%U:79O<R!M;V1E;&\@4$\@*"YP;W0I+@`@(&AE;'`@("`@("`@
M($UO<W1R87(@97-T82!M96YS86=E;2!D92!A:G5D82X`("!I;FET("`@("`@
M("!#<FEA<B!U;2!O=2!M86ES(&%R<75I=F]S(%!/('!A<F$@=6UA(&YO=F$@
M;&]C86QI>F'GXV\N"B`@("`@("`@("`@("`@071E;N?C;SH@3W,@;F]V;W,@
M87)Q=6EV;W,@<V]P<F5P]65M+7-E(&%O<R!A;G1I9V]S+@`@(&UA:V4@("`@
M("`@($-O;G-T<G5I<B!A<G%U:79O<R!B:6[A<FEO<R!-3R!A('!A<G1I<B!D
M;W,@87)Q=6EV;W,*("`@("`@("`@("`@("!03R!E<W!E8VEF:6-A9&]S+@`@
M(&UA:V4M:&5L<"`@($UA<F-A<B!T;V1A<R!A<R!E;G1R861A<R!N;R!A<G%U
M:79O(%A-3"!D92!A:G5D82!C;VUO(&5S=&%N9&\*("`@("`@("`@("`@("!A
M8W1U86QI>F%D87,@92!P<F5P87)A<B!O(&%R<75I=F\@<&%R82!A('!R\WAI
M;6$@97AE8W7GXV\*("`@("`@("`@("`@("!D92!U<&1A=&4M:&5L<"X@1&5V
M92US92!E>&5C=71A<B!M86ME+6AE;'`@1$503TE3(&1E"B`@("`@("`@("`@
M("`@=7!D871E+6AE;'`@92!D92!R979E<B!O(&%R<75I=F\@9&4@86IU9&$N
M`"`@;65R9V4@("`@("`@26YT96=R87(@;R!A<G%U:79O(%!/(&-O<G)E;G1E
M(&-O;2!O(&%R<75I=F\@;6]D96QO(%!/(&-O<G)E;G1E+@`@('5P9&%T92`@
M("`@($5X96-U=&%R(&5X=')A8W0@92!M97)G92!E;2!S97%UZFYC:6$N`"`@
M=7!D871E+6AE;'`@17AT<F%I<B!T;V1A<R!A<R!E;G1R861A<R!N;W9A<R!E
M(&UO9&EF:6-A9&%S(&1O(&%R<75I=F\@9&4*("`@("`@("`@("`@("!A:G5D
M82!834P@96T@:6YG;.IS(&4@:6YT96=RX2UL87,@8V]M(&%S(&5X:7-T96YT
M92X`("8C,34Q.R`E<R!E<W3A('!R;VYT;R!P87)A(&5F96-T=6%R(&%S(&]P
M97)AY_5E<R!D92!M86YU=&5NY^-O(&UA<F-A9&%S(&%B86EX;RX`("@E<R!D
M:6%S(&%T<N%S*0`@*$-H879E(&1E(&%C97-S;R`E<RD`("AD96YT<F\@9&4@
M)7,@9&EA<RD`("AH;VIE*0`@*&%M86YHXRD`("AO;G1E;2D`(&-O;2``(B5S
M(B!NXV\@Z2!U;6$@97-C;VQH82!VX6QI9&$N`"(E<R(@;N-O(&5S=.$@8V]N
M9FEG=7)A9&\@;F\@4F5G:7-T;R!D;R!(;W)D92X`(B5S(B!R97!R97-E;G1A
M9&]R(&1E(.%R=F]R92!NXV\@96YC;VYT<F%D;RX`(B5S(B!F;VD@861I8VEO
M;F%D;R!A;R!S:7-T96UA(&1E(&=R=7!O<RX`(B5S(B<@9F]I(&%D:6-I;VYA
M9&\@86\@<VES=&5M82!D92!P97)M:7-S]65S+@`B)7,B(&[C;R!F;VD@8W)I
M861O.B`E<RX`)60@)7,@92`E<P`E9"!B>71E<R!E<V-R:71O<P`E9"!D92`E
M9"!E;G1R861A(&UA<F-A9&%S(&-O;6\@86-T=6%L:7IA9&%S`'!R979I<^-O
M(&1E("5D(&1I87,`)7,@+2!.;W1I9FEC8>?C;P`E<R!!9&UI;FES=')AY^-O
M`"5S($EM<')E<W/C;R!$:6=I=&%L`"5S($M"`"5S($]P97)AY_5E<R!D92!-
M86YU=&5NY^-O("T@0V]N9FER;6'GXV\`0V]N9FEG=7)A<B`E<P`E<R!3=6)S
M8W)E=F5R`"5S(%1E<FUO<R!D;R!!8V]R9&\`)7,@:N$@97AI<W1E+@`E<R!E
M;2`E<R`E<P!NXV\@<V4@<&]D92!E<V-R979E<B!E;2`E<RX`)7,@Z2!O8G)I
M9V%T\W)I;P`E<R!M:6YU=&]S`"5S(&[C;R!F;VD@96YC;VYT<F%D;RX`)7,@
M;N-O(&9O:2!E;F-O;G1R861O+B!%>&5C=71A<B`G=')A;G-L871I;VX@97AT
M<F%C="<@<')I;65I<F\N`"5S(&$@)7,@9&4@)7,`0V]N=&%C=&]S(&1E("5S
M`$-A;&5N9.%R:6\@9&4@)7,`3F]T87,@9&4@)7,`5&%R969A<R!D92`E<P`E
M<SH@)7,`+"!C;VT@<F%J861A<P`L(&-O;2!R86IA9&%S("5S("5S`"P@=F%R
M:>%V96P@9&4@)7,@82`E<P`M+2!E<V-O;&AA("TM`"TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0!&;W)M871O(&1E(#$R(&AO<F%S("A!32]032D`1F]R
M;6%T;R!D92`R-"!H;W)A<P`R-"!H;W)A<P`\06YT97)I;W(`971I<75E=&$@
M/&=E='1E>'0^('!O<B!F96-H87(@;F\@9FEC:&5I<F\@)7,N"D%B<FEN9&\@
M82!E=&EQ=65T82!E;F-O;G1R861A(&YA(&QI;FAA("5D+@!%<W1E(&)L;V-O
M(&5X:6=E('5M(&UE8V%N:7-M;R!U<V%N9&\@8F%S97,@9&4@9&%D;W,N`$]C
M;W)R974@=6T@97)R;R!F871A;`#)(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z
M8FQI8V$@4$=0('!A<F$@96YC<FEP=&%R(&$@;65N<V%G96TN`,D@;F5C97-S
MX7)I82!U;6$@8VAA=F4@</IB;&EC82!01U`@<&%R82!V97)I9FEC87(@82!A
M<W-I;F%T=7)A(&1E('5M82!M96YS86=E;0!087)A(&1E8VEF<F%R('5M82!M
M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4$=0
M+"!U;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@9G)A<V4M<&%S<V4N`%!A
M<F$@87-S:6YA<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C
M:&%V92!P^F)L:6-A(%!'4"P@=6UA(&-H879E('!R:79A9&$@4$=0(&4@=6UA
M(&9R87-E+7!A<W-E+@!087)A(&1E8VEF<F%R('5M82!M96YS86=E;2!SXV\@
M;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@8VAA
M=F4@<')I=F%D82!3+TU)344@92!U;6$@9G)A<V4M<&%S<V4N`%!A<F$@87-S
M:6YA<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V92!P
M^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-24U%(&4@=6UA
M(&9R87-E+7!A<W-E+@#)(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@
M4R]-24U%('!A<F$@96YC<FEP=&%R('5M82!M96YS86=E;2X`3OIV96YS(&1E
M(&UA;FCC`$-H=79I<V-O<R!D92!-86YHXP!#:'5V82!D92!M86YHXP!!9W5A
M8V5I<F]S(&1E(&UA;FCC`$YE=O5E<R!D92!M86YHXP!!32]030!!4$D@240`
M06-E<F-A(&1E<W1E(&5D:71O<@!!8V5R8V$N+BX`0F%S97,@86QI;FAA9&%S
M`$-E;G1R;W,@86QI;FAA9&]S`$%C97-S;R!N96=A9&\@86\@8W)I87(@<&%S
M=&$@5D93+@!!8V5S<V\@;F5G861O(&%O(&-R:6%R(&%R<75I=F\@5D93+@!0
M86QA=G)A+5!A<W-E(&1A($-O;G1A`$-O;G1A(&-O;F=E;&%D82X`0V]N=&%B
M:6QI9&%D90!!9&EC:6]N87(`061I8VEO;F%R($=R=7!O($9I;&AO`$%D:6-I
M;VYA<B!097)M:7-SXV\@1FEL:&$`06-R97-C96YT87(@07%U:3H`061D:6-I
M;VYA<B!.;W9O($=R=7!O`$%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C;P!!9&EC
M:6]N87(@=6T@9W)U<&\@9FEL:&\@82`B)7,B`$%D:6-I;VYA<B!U;6$@<&5R
M;6ES<^-O(&9I;&AA(&$@(B5S(@!!9&EC:6]N87(@;F]V;R!U=&EL:7IA9&]R
M.@!!9&EC:6]N87(@8V]L=6YA`$%D:6-I;VYA<B!N;W9O<R!M96UB<F]S`$%D
M:6-I;VYA<B!P87)C96ER;P!!9&EC:6]N87(@;R!-96YU("5S(&-O;6\@0F%R
M<F$@3&%T97)A;"!-;WII;&QA`$%D:6-I;VYA<B!A;W,@0V]N=&%C=&]S.@!!
M9&EC:6]N87(@86]S(&UE=7,@8V]N=&%C=&]S`$%D:6-I;VYA<B!U=&EL:7IA
M9&]R`$%D:6-I;VYE:2`B)7,B(&%O('-I<W1E;6$L(&UA<R!NXV\@<'5D92!A
M9&EC:6]N87(@:6YF;W)M8>?C;R!D92!S=6)S8W)IY^-O(&%D:6-I;VYA;#H@
M)7,N`$%D:6-I;VYE:2`B)7,B(&%O('-I<W1E;6$N($KA('!O9&4@96YT<F%R
M+@!!9&EC:6]N86YD;R!N;W9O<R!A<G%U:79O<R!A;R!R97!O<VET\W)I;SH`
M02!A9&GGXV\@9&4@=71I;&EZ861O<F5S(&5S=.$@9&5S86-T:79A9&$N`$5N
M9&5R9>=O`$-O;G1A8W1O<P!!9&UI;FES=')A<B`M(&%T<FEB=6ER('!E<FUI
M<W/U97,@82!O=71R;W,@=71I;&EZ861O<F5S`$%D;6EN:7-T<F'GXV\`06[Z
M;F-I;W,`069E9V%N:7-TXV\`06QBXFYI80!!<F?I;&EA`$%L8W5N:&$`06QI
M;FAA<@!!;&EN:&%M96YT;SH`5'5D;P!4;V1O<R!O<R!5=&EL:7IA9&]R97,@
M075T96YT:6-A9&]S`%1O9&]S(&]S($=R=7!O<P!4;V1A<R!A<R!097)M:7-S
M]65S`%1O9&]S(&]S("AQ=6%T<F\I(&QA9&]S`%!E<FUI=&ER(&WZ;'1I<&QO
M<R!E;F1E<F7G;W,`4&5R;6ET:7(@871R:6)U:>?C;R!D;R!T:7!O(&1E(&QI
M<W1A<R!O<F1E;F%D87,_`$KA(&5X:7-T90!%;G1R861A($E-4U`@06QT97)N
M871I=F$`4&%L879R82U087-S92!)35-0($%L=&5R;F%T:79A`$YO;64@9&4@
M571I;&EZ861O<B!)35-0($%L=&5R;F%T:79O`$5N9&5R9>=O(&EN=N%L:61O
M`$UO9&5L;W,@86QT97)N871I=F]S`%1E>'1O(&%L=&5R;F%T:79O.@!386UO
M82!!;65R:6-A;F$`1F]I(&5S<&5C:69I8V%D;R!U;2!V86QO<B!I;G;A;&ED
M;RX`3V-O<G)E=2!U;2!E<G)O(&1E<V-O;FAE8VED;RX`06YD;W)R80!!;F=O
M;&$`06YG=6EL80!%;G1R97!O<W1O("AP<F]X>2D@06[S;FEM;P!297-P;W-T
M80!!;G3A<F-T:6-O`$%N=.UG=6$@92!"87)B=61A`$%P;&EC8>?C;P!!<&QI
M8V'GXV\@<')O;G1A+@!!<&QI8V%R(&$@4&%R=&EL:&%S($9I;&AA<P!!<')O
M=F%R`%1A;6%N:&\@07!R;WAI;6%D;P!!8G)I;`!!<N%B:6-O("A7:6YD;W=S
M+3$R-38I`%1A;6%N:&\@9&\@1FEC:&5I<F\@9&4@07)Q=6EV;P!.;VUE(&1O
M($%R<75I=F\`5&5M(&$@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(&\@<&5D
M:61O(&1E('-U8G-C<FGGXV\@<&%R82`E<R`_`%1E;2!A(&-E<G1E>F$@<75E
M('%U97(@<F5M;W9E<B`B)7,B(&4@<75A:7-Q=65R('-U8BUG<G5P;W,_`$%R
M9V5N=&EN80!!<FWI;FEA`$%R;>EN:6\@*$%235-#24DM."D`07)T90!!<G5B
M80!);&AA(&1E($%S8V5N<^-O`$%R=&4@05-#24D`4F5G:>-O(,%S:6$O4&%C
M[69I8V\`4&5D:7(@8V]N9FER;6'GXV\@86YT97,@9&4@<F5A;&EZ87(@;W!E
M<F'G]65S(&1E(&UA;G5T96[GXV\_`$-O;'5N87,@9&4@871R:6)U:>?C;P!4
M96YT871I=F$@9&4@<F5M;^?C;R!D92!U;2!G<G5P;R!I;F5X:7-T96YT92X`
M5&5N=&%T:79A(&1E(')E;6_GXV\@9&4@=6UA('!E<FUI<W/C;R!I;F5X:7-T
M96YT92X`5&5N=&%T:79A(&1E(&5D:>?C;R!D92!U;6$@<&5R;6ES<^-O(&EN
M97AI<W1E;G1E+@!496YT871I=F$@9&4@961IY^-O(&1E('5M82!P87)T:6QH
M82!I;F5X:7-T96YT92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<N%L:6$`P75S
M=')I80!!=71H7V-Y<G-Q;#H@02!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@
M;N-O(&9O:2!E;F-O;G1R861A+@!!=71H7V-Y<G5S.B!/(&UE8V%N:7-M;R!N
MXV\@=&5M(&%S(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S+@!!=71H7V-Y<G5S
M.B!!(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A
M9&$N`$%U=&A?9G1P.B!!(&5X=&5N<^-O($944"!N96-E<W/A<FEA(&[C;R!F
M;VD@96YC;VYT<F%D82X@0V]M<&EL92!O(%!(4"!C;VT@82!O<.?C;R`M+65N
M86)L92UF='`N`$%U=&A?:6UA<#H@02!E>'1E;G/C;R!)34%0(&YE8V5S<^%R
M:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!=71H7VMR8C4Z($$@97AT96YSXV\@
M:W)B-2!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]L9&%P
M.B!!(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A
M9&$N`$%U=&A?;&1A<#H@26UP;W-S[79E;"!A9&EC:6]N87(@=71I;&EZ861O
M<B`E<RX@16ES(&\@<75E(&\@<V5R=FED;W(@9&ES<V4Z(`!!=71H7VQD87`Z
M($EM<&]S<^UV96P@<F5M;W9E<B!O('5T:6QI>F%D;W(@)7,`075T:%]L9&%P
M.B!);7!O<W/M=F5L(&%C='5A;&EZ87(@;R!U=&EL:7IA9&]R("5S`$%U=&A?
M;6-A;#H@02!E>'1E;G/C;R!-0T%,(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O
M;G1R861A+@!!=71H7W-M8F%U=&@Z($$@97AT96YSXV\@<VUB875T:"!N96-E
M<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`02!A=71E;G1I8V'GXV\@9F%L
M:&]U`$$@875T96YT:6-AY^-O(&9A;&AO=2X@)7,`02!A=71E;G1I8V'GXV\@
M9F]I(')E:F5I=&%D82!P96QO('-E<G9I9&]R(%)!1$E54RX`02!A=71E;G1I
M8V'GXV\@;F\@<V5R=FED;W(@1E10(&9A;&AO=2X`0V%M<&]S(&1I<W!O;NUV
M96ES.@!!>F5R8F%I:N-O`$1E<V-U;'!A<R`B0D]&2"(`1G5N9&\`0V]R(&1O
M($9U;F1O`%!A;&%V<F$M4&%S<V4@:V5R8F5R;W,@97)R861A+@!.;VUE(&1E
M(%5T:6QI>F%D;W(@:V5R8F5R;W,@97)R861O+@!"86%M87,`0F%RZ6T`0N%L
M=&EC;R`H25-/+3@X-3DM,3,I`$)A;F=L861E8VAE`$)A<F)A9&]S`$QI;FAA
M(&)A<V4`0FEE;&]R<OIS<VEA`$+I;&=I8V$`0F5L:7IE`$)E;FEM`$)E<FUU
M9&$`0G5TXV\`06YI=F5R<^%R:6\`3R!B;&]C;R`B)7,B(&1A(&%P;&EC8>?C
M;R`B)7,B(&[C;R!F;VD@96YC;VYT<F%D;RX`0V]N9FEG=7)AY_5E<R!D92!"
M;&]C;W,`5&EP;R!D92!";&]C;P!.96=R:71O`$)O;.UV:6$`36%R8V%D;W)E
M<P!";W)D80!%<W!E<W-U<F$@9&$@8F]R9&$Z`$)O<F1A<P!"\W-N:6$M2&5R
M>F5G;W9I;F$`06UB87,`0F]T<W5A;F$`0F%S90!);&AA($)O=79E=`!"<F%S
M:6P`5&5R<FET\W)I;R!"<FETXFYI8V\@9&\@3V-E86YO(,UN9&EC;P!"<G5N
M96D@1&%R=7-S86QA;0!#;VYS=')U:6YD;R!A<G%U:79O<R!-3R!P87)A(&\@
M;?-D=6QO("5S+BXN`$-O;G-T<G5I;F1O(&QO8V%L:7IAY^-O("5S+BXN(`!"
M=6QGX7)I80!,:7-T($ET96UI>F%D80!"=7)Q=6EN82!&87-O`$)U<OIN9&D`
M0TU3`$-20P!0;VYT;W,@9&4@1&ES=')I8G5IY^-O($-23`!0<F]P<FEE9&%D
M97,@9&$H<RD@0^E?;'5L82AS*2XN+@!);FEC:6%L:7IAY^-O(&1A(")C86-H
M92(@;N-O(&9O:2!C;VYC;'7M9&$N`$-A;&5N9.%R:6\`0V%L;6\`0V%M8F]D
M:F$`0V%M87+U97,`3N-O('!O<W-O(')E:6YI8VEA<B!A('!A;&%V<F$M<&%S
M<V4@875T;VUA=&EC86UE;G1E+"!C;VYT86-T92!O('-E=2!A9&UI;FES=')A
M9&]R(&1E('-I<W1E;6%S+@!);7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I
M9&]R($E-05`Z("5S`$-A;F%DX0!#86YC96QA<@!#86YC96QA<B!296QA=/-R
M:6\@9&4@4')O8FQE;6%S`$[C;R!C;VYS:6=O(')E;6]V97(@;R!F:6-H96ER
M;R`B)7,B+@!.XV\@8V]N<VEG;R!E;F-O;G1R87(@=6T@9&ER96-T\W)I;R!T
M96UP;W+A<FEO+@!);7!O<W/M=F5L(&-O;G1I;G5A<B!S96T@;R!P87+B;65T
M<F\@)W1A<F=E=$9I;&4G+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P
M87-T82`B)7,B+@!);7!O<W/M=F5L(')E;6]V97(L(&5X:7-T96T@)60@9FEL
M:&]S+@!.XV\@Z2!P;W-S[79E;"!R96]R9&5N87(Z(&\@;OIM97)O(&1E(&5N
M=')A9&%S(&9O<FYE8VED87,@;N-O(&-O<G)E<W!O;F1E(&%O(&[Z;65R;R!G
M=6%R9&%D;RX`3N-O(&9O:2!P;W-S[79E;"!E;F-A;6EN:&%R(&$@;65N<V%G
M96T@<&%R82!O(&[Z;65R;R!I;F1I8V%D;RX`4F5P^F)L:6-A(&1E($-A8F\@
M5F5R9&4`3&5G96YD80!#871E9V]R:6%S(&4@0V]R97,`26QH87,@0V%I;>-O
M`%1E;&5F;VYE($-E;'5L87(`4')O<')I961A9&5S(&1A<R!#Z6QU;&%S`$5N
M8VAI;65N=&\@9&%S($/I;'5L87,Z`%!R;W!R:65D861E<R!D87,@8^EL=6QA
M<P!%<W!AYV%M96YT;R!D87,@8^EL=6QA<SH`5&5L96WS=F5L`$/I;'1I8V\@
M*$E33RTX.#4Y+3$T*0!#96YT<F%R`%)E</IB;&EC82!#96YT<F\@069R:6-A
M;F$`175R;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I`%!O<FUE;F]R97,@9&\@
M0V5R=&EF:6-A9&\`1&]N;R!D;R!#97)T:69I8V%D;P!0;VSM=&EC87,@9&4@
M0V5R=&EF:6-A9&\`4F5P^F)L:6-A(&1O($-H861E`$%L=&5R87(`06QT97)E
M(&\@;F]M92!E(&5N9&5R9>=O('%U92!A<R!P97-S;V%S('9E<N-O('%U86YD
M;R!L97)E;2!E(')E<W!O;F1E<F5M(.!S('-U87,@;65N<V%G96YS+@!#87)A
M8W1E<F4`5F5R:5]F:6-A<B!,:6=AY^-O+BXN`$UA<G%U92!A<R!O<&5R8>?U
M97,@<75E(&1E<V5J82!E>&5C=71A<B!N97-T92!M;VUE;G1O+@!297#Z8FQI
M8V$@9&\@0VAI;&4`4F5P^F)L:6-A(%!O<'5L87(@9&$@0VAI;F$`0VAI;NIS
M(%-I;7!L:69I8V%D;W,@*$=",C,Q,BD`0VAI;NIS(%1R861I8VEO;F%L("A"
M:6<U*0!%<V-O;&AA(&$@<&%L879R82UP87-S90!%<V-O;&AA('5M($YO;64@
M9&4@571I;&EZ861O<@!%<V-O;&AA(&-O;6\@;6]S=')A<B!A<R!D871A<SH`
M17-C;VQH82!O(&5S=&EL;R!D87,@;&ES=&$@*'!A<F$@;&ES=&%S(&]R9&5N
M861A<RD`26QH82!D;R!.871A;`!.XV\@9F]I(&5N8V]N=')A9&$@82!D969I
M;FGGXV\@9&$@8VQA<W-E("5S+@!,:6UP86YD;R!O<R!A<G%U:79O<R!03R!D
M;R!M\V1U;&\@)7,N+BX`3&EM<&%N9&\@82!L;V-A;&EZ8>?C;R`E<RXN+B``
M3&EM<&%R`$QI;7!A<B!E=&EQ=65T87,@9&\@35-/9F9I8V4`3&EM<&%R(&1A
M9&]S(&1O('5T:6QI>F%D;W(Z("5S`$QI;7!A<B!D861O<R!D;R!U=&EL:7IA
M9&]R`$QI;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R`$QI;7!A(%1A<F1E`$-L
M:7%U92!P87)A($-O;G1I;G5A<@!#;&EC:V%T96QL('9I82!(5%10`$9E8VAA
M<B!J86YE;&$`3OIV96YS`$[Z=F5N<R!-871I;F%I<P!%;F5V;V%D;P!);&AA
M<R!#;V-O<R`H2V5E;&EN9RD`0V]L87!S87(@0F%R<F$@3&%T97)A;`!";W)D
M87,@0V]L87!S861A<P!297#Z8FQI8V$@9&$@0V]L]&UB:6$`0V]R97,`4&%L
M971E`%-E;&5CY^-O(&1E(&-O<F5R`$-O;'5N87,Z`%3M='5L;W,@9&%S(&-O
M;'5N87,`0D0`0V]M86YD;P!#;VYS;VQA(&1E($-O;6%N9&]S`$]PY_5E<R!D
M;R!C;VUA;F1O.@!#;VUA;F1O<SH`0V]M96YTX7)I;P!#;VUE=&5N9&\`3F]M
M92!#;VUU;0!#;VUO<F]S`$5M<')E<V$`17-C<F5V97(@*"5S*0!#;VUP=71A
M9&]R97,`0V]N9&GGXV\`0V]N9&GG]65S`$1I9F5R96[G87,@9&4@0V]N9FEG
M=7)AY^-O`$$@8V]N9FEG=7)AY^-O(&5S=.$@9&5S86-T=6%L:7IA9&$`0V]N
M9FEG=7)A<B`E<P!#;VYF:7)M92!A(%!A;&%V<F$M4&%S<V4`4F5P^F)L:6-A
M($1E;6]C<N%T:6-A(&1O($-O;F=O`%)E</IB;&EC82!$96UO8W+A=&EC82!D
M;R!#;VYG;P!#;VYE>.-O(&9A;&AO=2X`0V]N97CC;R!F86QH;W4Z(`!#;VYE
M>.-O(&%O('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<R!R96-U<V%D82X`
M0V]N97CC;R!A;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,@<F5C=7-A
M9&$N(%)A>N-O.B`E<R`H)7,I`$-O;F5XXV\@86\@<V5R=FED;W(@1E10(')E
M8W5S861A+@!#;VYT86-T;W,@861I8VEO;F%D;W,@8V]M('-U8V5S<V\@86\@
M<V5U(&QI=G)O(&1E(&5N9&5R9>=O<RX`5&EP;R!D92!C;VYT9?ID;R!D;R!A
M<G%U:79O(&-O;7!R:6UI9&\Z(`!#;VYT9?ID;R!D92`E<P!#;VYT:6YU87(`
M26QH87,@0V]O:P!";VQI;FAO(&-H:6[J<P!#;W!I87(`0V]P:6%R('-E;&5C
MY^-O`$-O<&EA;F1O(&1E("5S('!A<F$@)7,`4F5P^F)L:6-A(&1A($-O<W1A
M(%)I8V$`4F5P^F)L:6-A(&1A($-O<W1A(&1O($UA<F9I;0!.XV\@9F]I('!O
M<W/M=F5L(&5N8W)I<'1A<B!A(&UE;G-A9V5M(&-O;2!01U`N`$[C;R!F;VD@
M<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!01U`N`$[C;R!F;VD@
M<&]S<^UV96P@96YC<FEP87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.XV\@
M9F]I('!O<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.
MXV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA<B!O(&-O;G1A8W1O+B`E<P!&86QH
M82!N82!L:6=AY^-O("AB:6YD*2!A;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I
M('!O<W/M=F5L('9E<FEF:6-A<B!O('-A;&1O+B`E<P!.XV\@9F]I('!O<W/M
M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R("(E<R(@=7-A;F1O($944#H@)7,`
M3N-O(&9O:2!P;W-S[79E;"!C;W!I87(@)7,@<&%R82`E<P!.XV\@9F]I('!O
M<W/M=F5L(&-R:6%R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O
M:2!P;W-S[79E;"!C<FEA<B!P87-T82!D92!L;V-A;&EZ8>?C;R!P87)A(&$@
M;&]C86QI>F'GXV\@)7,Z`$[C;R!F;VD@<&]S<^UV96P@9&5S96YC<FEP=&%R
M(&]S(&1A9&]S(&-O;2!O(%!'4"X`3N-O(&9O:2!P;W-S[79E;"!D97-E;F-R
M:7!T87(@;W,@9&%D;W,@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!R
M96UO=F5R(&-O;G1A8W1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@
M;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@;R`B<V-R:7!T(B!D92!A8W1U86QI>F'GXV\@(B5S(BX`3N-O(&9O
M:2!P;W-S[79E;"!D971E<FUI;F%R(&\@96YD97)EYV\@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;R!D;R!D97-T:6YA=.%R:6\N`$[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@;R!L:79R;R!D92!E;F1E<F7G;W,@8V]M<&QE=&\N`$[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\@8V]M<&QE
M=&$N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!L:7-T82!C;VUP;&5T82!D
M87,@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX`26UP;W-S[79E;"!C87)R96=A
M<B!E<W1R873I9VEA("(E<R(N`$EM<&]S<^UV96P@;6MD:7(@(B5S(BX`3N-O
M(&9O:2!P;W-S[79E;"!O8G1E<B!A(&-H879E('#Z8FQI8V$@82!P87)T:7(@
M9&\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!.XV\@9F]I('!O<W/M
M=F5L(&%B<FER("(E<R(@<&%R82!E<V-R:71A+@!.XV\@9F]I('!O<W/M=F5L
M(&%B<FER("5S+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO(&1E
M($UA;G5T96[GXV\@9&4@5&%R969A<R`E<P!.XV\@9F]I('!O<W/M=F5L(&%B
M<FER('!A<W1A("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@;&5R("5S+@!.XV\@
M9F]I('!O<W/M=F5L(')E:6YI8VEA<B!A('!A;&%V<F$M<&%S<V4@9&\@=71I
M;&EZ861O<B!I;F1I8V%D;RX@06QG=6T@;W4@=&]D;W,@;W,@<&]R;65N;W)E
M<R!NXV\@97-T879A;2!C;W)R96-T;W,N(%!O<B!F879O<B!T96YT92!D92!N
M;W9O(&]U(&-O;G1A8W1E(&\@<V5U(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M
M87,@<V4@<')E8VES87(@9&4@;6%I<R!A:G5D82X`3N-O(&9O:2!P;W-S[79E
M;"!O8G1E<B!!0TP`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!L:79R;R!D92!E
M;F1E<F7G;W,N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI<W1A
M<R!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@
M87,@8V]M<&5TZFYC:6%S(&1O('-E<G9I9&]R`$[C;R!F;VD@<&]S<^UV96P@
M<F5V97)T97(@82!C;VYF:6=U<F'GXV\N`$EM<&]S<^UV96P@<FUD:7(@(B5S
M(BX`3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E
M("5S+@!.XV\@9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@
M9&4@<V%L=F%G=6%R9&$N`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A(&-O
M;F9I9W5R8>?C;R!D92!S86QV86=U87)D83H@)7,`3N-O(&9O:2!P;W-S[79E
M;"!G=6%R9&%R(&\@(G-C<FEP="(@9&4@86-T=6%L:7IAY^-O(&5M.B`B)7,B
M+@!.XV\@9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@
M<V%L=F%G=6%R9&$@)7,N`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!O(&%R
M<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+B!0;V1E('5S87(@=6UA(&1A<R!O
M<.?U97,@<&%R82!G=6%R9&%R(&\@8_-D:6=O(&5M("5S(&]U(&-O<&EA<B!M
M86YU86QM96YT92!O(&/S9&EG;R!A8F%I>&\@<&%R82`E<RX`3N-O(&9O:2!P
M;W-S[79E;"!P<F]C=7)A<B!N;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O
M<W/M=F5L(&1E<VQI9V%R("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@86-T=6%L
M:7IA<B!C;VYT86-T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!A8W1U86QI>F%R
M(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L
M(&5S8W)E=F5R(&$@8V]N9FEG=7)AY^-O('!A<F$@(B5S(CH@)7,`3N-O(&5N
M8V]N=')E:2!A($)A<G)A($QA=&5R86P@9&\@36]Z:6QL82X@07-S96=U<F4M
M<V4@<75E(&$@8F%R<F$@;&%T97)A;"!E<W3A(&%B97)T82X`3N-O(&9O:2!P
M;W-S[79E;"!A=')I8G5I<B!A;R!U=&EL:7IA9&]R("(E<R(@;W,@<V5G=6EN
M=&5S(&1I<F5I=&]S('-O8G)E(&$@<&%S=&$@(B5S(CH@)7,`5&5X=&\@0V]N
M=&%D;P!08>US`$-U<G-O<P!#<FEA<@!#<FEA<B!U;6$@;&EG8>?C;P!#<FEA
M<B!U;6$@;F]V80!#<FEA<B!S=6(M<&%S=&%S`%!E<FUI<W/U97,@9&\@0W)I
M861O<@!.^FUE<F\@9&\@8V%R=.-O(&1E(&-RZ61I=&\`4F5P^F)L:6-A(&1A
M($-R;^%C:6$`4F5P^F)L:6-A(&1E($-U8F$`475A=')O(&9A<V5S(&-O<G)E
M;G1E<P!$871A+TAO<F$`55),(&-O<G)E;G1E(.D`17-T861O(&1O(%1E;7!O
M`%-I='5AY^-O(&%C='5A;#H@`$5S=&EL;R!A8W1U86P`4&5R<V]N86QI>F%R
M(&%S('1A<F5F87,@<75E('-E<N-O(&5X96-U=&%D87,@87%U86YD;R!O(&QO
M9VEN(&YO("5S+@!#;W)T87(`0V]R=&%R(&$@<V5L96/GXV\`4F5P^F)L:6-A
M(&1E($-H:7!R90!#:7+M;&EC;R`H2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W
M<RTQ,C4V*0!#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A
M($-H96-A`$1$`$1I87)I86UE;G1E`$YA=F5G861O<B!D92#!<G9O<F4@9&4@
M1&%D;W,`1&%T80!$871A(&1E(%)E8V5PY^-O`%-E;&5CY^-O(&1E(&1A=&$`
M1&EA`%)E;6]V97(@0V]?;'5N80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES
M`%)E9'5Z:7(@:6YD96YT8>?C;P!0;W(@3VUI<W/C;P!#;W(@4&]R($]M:7-S
MXV\`261E;G1I9&%D92!0861RXV\`4&5R;6ES<_5E<R!0;W(@3VUI<W/C;P!0
M97)M:7-S]65S('!O<B!O;6ES<^-O`$1E9FEN:>?U97,`4F5M;W9E<@!296UO
M=F5R($=R=7!O`%)E;6]V97(@4&5R;6ES<^-O`%)E;6]V97(@92!P=7)G87(@
M;65N<V%G96YS`%)E;6]V97(@8^EL=6QA`%)E;6]V97(@8V]L=6YA`%)E;6]V
M97(@;6]D96QO(&%L=&5R;F%T:79O(&5X:7-T96YT90!296UO=F5R('!E<FUI
M<W/U97,@9&4@(B5S(@!296UO=F5R('!E<FUI<W/U97,@<&%R82`G)7,G(&4@
M<75A:7-Q=65R('-U8BUP97)M:7-S]65S/P!296UO=F5R(&QI;FAA`%)E;6]V
M97(@:61E;G1I9&%D92!S96QE8V-I;VYA9&$`4F5M;W9E<B!A(&-O;'5N82!C
M;W)R96YT90!296UO=F5R(&$@;&EN:&$@8V]R<F5N=&4`4F5M;W9E<B!E<W1A
M('!E<FUI<W/C;R!E('1O9&%S(&%S('-U87,@<W5B+7!E<FUI<W/U97,_`")3
M8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R`B)7,B(')E;6]V:61O+@!-;VUE;G1O
M(&1E(&5N=')E9V$`1&EN86UA<F-A`$1E<V-R979A(&\@4')O8FQE;6$`1&5S
M8W)IY^-O`%!O<FUE;F]R97,@*'1A;6+I;2!N;R!R96=I<W1O+"`B;&]G(BP@
M9&\@2&]R9&4I.@!/<R!D971A;&AE<R!F;W)A;2!E;G9I861O<R!P87)A(&\@
M861M:6YI<W1R861O<B!D;R!S:7-T96UA+@!$97-E;G9O;'9I;65N=&\`4&]N
M=&\@9&4@3W)V86QH;P!0;VYT;R!D92!/<G9A;&AO(&YA(/IL=&EM82!H;W)A
M.B``4&]N=&\@9&4@;W)V86QH;SH@`$1I<F5CY^-O(&1A(&5S<75E<F1A('!A
M<F$@82!D:7)E:71A`$1I<F5CY^-O(&1A(&1I<F5I=&$@<&%R82!A(&5S<75E
M<F1A`$1I<F5C=/-R:6\`36]S=')A<B!T96UP;W,@8V]M(#(T(&AO<F%S/P!/
M<.?U97,@9&4@5FES=6%L:7IAY^-O`$UO<W1R87(@<')E=FESXV\@<&]R;65N
M;W)I>F%D80!-;W-T<F%R('!R979I<^-O("A4048I`$9O<FUA=&\@9&4@=FES
M=6%L:7IAY^-O`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.
MXV\@<F5M;W9E<@!.XV\@=71I;&EZ92!O(&UA:6YT96YA;F-E+G!H<"!D:7)E
M8W1A;65N=&4`02!P<FEM96ER82!L:6YH82!C;VYTZ6T@;W,@;F]M97,@9&]S
M(&-A;7!O<S\@4V4@<VEM+"!A<W-I;F%L87(@97-T82!C86EX83H`1&]M:6YI
M8V$`4F5P^F)L:6-A($1O;6EN:6-A;F$`4F5C96)E<@!296-E8F5R("5S`$1E
M<V-A<G)E9V%R(&$@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(")S8W)I
M<'0B(%!(4"X`3&ES=&$@9&4@9&5S96YR;VQA<@!$<F]G87,`0V]R<F5I;R!E
M;&5C='+S;FEC;P!%4E(`4F5P^F)L:6-A(&1O($5Q=6%D;W(`161I=&%R`$5D
M:71A<B!";&]C;P!%9&ET87(@1W)U<&\`161I=&%R(%!E<FUI<W/U97,`161I
M=&%R(%!E<FUI<W/U97,`161I=&%R('!E<FUI<W/U97,@9&4@)7,`161I=&%R
M(&]PY_5E<R!D93H`161I=&%R('!E<FUI<W/U97,@9&4@(B5S(@!%9&ET87(@
M<&5R;6ES<_5E<R!D92`E<P!%9'5C8>?C;P!%9VEP=&\`4F5P^F)L:6-A(&1E
M($5L(%-A;'9A9&]R`$5L96UE;G1O+BXN`$5M`$-O<G)E:6\@16QE8W1R\VYI
M8V\`16YD97)EYV\@9&4@0V]R<F5I;R!%;&5C='+S;FEC;P!/<R!E;F1E<F7G
M;W,@=.IM('%U92!C;VEN8VED:7(N`$UE;G-A9V5M(&-O;2!C;VYF:7)M8>?C
M;P!3[6UB;VQO<R!D92!%;6_GXV\`365N<V%G96T@=F%Z:6$N`%-E;2!R97-U
M;'1A9&]S+@!396T@=&5R;6]S(&1E('!R;V-U<F$`06-T:79A<B!I;G-E<N?C
M;R!D92!I;6%G96YS(&1E($=A;&5R:6%S($9O=&]G<N%F:6-A<R!N;R!T97AT
M;S\`06-T:79A<B!M96YU(&1E(&-O;G1E>'1O(&YO(&)O=.-O(&1I<F5I=&\@
M9&\@<F%T;S\`06YO(&1E(&9I;0!!=6UE;G1A<B!%9&ET;W(`26YT<F]D=7IA
M('5M82!P97)G=6YT82!D92!S96=U<F%NYV$@<75E('-E<N$@8V]N=FED861O
M(&$@<F5S<&]N9&5R('-E('!R96-I<V%R(&1E(')E:6YI8VEA<B!A('-U82!P
M86QA=G)A+7!A<W-E+"!E+F<N+"`G8V]M;R!S92!C:&%M82!O('-E=2!A;FEM
M86P@9&4@97-T:6UAY^-O/R<Z`$EN=')O9'5Z82!O(%523"!D82!I;6%G96T@
M87%U:0!%;G1R861A<SH@)60@=&]T86PL("5D(&%C='5A;&EZ861A<RP@)60@
M;F]V87,L("5D(&%L=&5R861A<RP@)60@9&5S8V]N:&5C:61A<P!'=6ENZ2!%
M<75A=&]R:6%L`$5S=&%D;R!D82!%<FET<F5I80!%<G)O`$5R<F\@;F$@;65N
M<V%G96T@9&4@8V]R<F5I;R!E;&5C='+S;FEC;RX`17)R;R!A;R!E<V-R979E
M<B`B)7,B+@!%<G)O.B``4F5P^F)L:6-A(&1A($5S=/-N:6$`4F5P^F)L:6-A
M($1E;6]C<N%T:6-A($9E9&5R86P@9&$@171I\W!I80#)=&EC;P!%=7)O<&$`
M0V%D82`Q-2!M:6YU=&]S`$-A9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD
M;W,`0V%D82`U(&UI;G5T;W,`0V%D82!%;G1R861A`$-A9&$@;65I82!H;W)A
M`$-A9&$@;6EN=71O`%9A;&]R97,@97AE;7!L;SH`17AE8W5T87(`17AE8W5T
M86YD;SH`17AP86YD:7(`36]S=')A<B!"87)R82!,871E<F%L`"<I)R!E<W!E
M<F%D;P!%<W!E<F%V82!U;6$@<VEM<&QE<R!P86QA=G)A(&]U('5M('1E<FUO
M(&1E('!R;V-U<F$@96YT<F4@87-P87,`1&%T82!D92!%>'!I<F'GXV\`17AP
M;V5N=&4`17AT<F%I;F1O(&1E("5S+BXN(`!#;W(@9&\@4')I;65I<F\@4&QA
M;F\`0V%R<F5G87(@8V]N9FEG=7)AY^-O(&1E(&EN<W1A;&'GXV\@<&]R($94
M4`!.XV\@9F]I('!O<W/M=F5L('!U>&%R(&%S('!R969E<NIN8VEA<RX`1F%L
M:&$@;F$@;&EG8>?C;R!A;R!S97)V:61O<B!,1$%0+@!&86QH82!N82!L:6=A
MY^-O(&%O('-E<G9I9&]R(%--0BX`1F%L:&$@86\@8V]P:6%R(&1E("(E<R(N
M`$9A;&AA(&%O(&-O<&EA<B!P87)A("(E<R(N`$9A;&AA(&%O(&-R:6%R('5M
M82!N;W9A(&-O;F5XXV\@4T%33"X`1F%L:&$@86\@;6]V97(@<&%R82`B)7,B
M+@!";VT`26QH87,@1F%L:VQA;F0@*$UA;'9I;F%S*0!);&AA<R!&87)O90!%
M<G)O($9A=&%L.@!&87@`1F5V97)E:7)O`$%P87)E;G1A`$%P87)E;G1A.B``
M06QG=6YS($%G=6%C96ER;W,`06QG=6YS($YE=O5E<P!-871R:7H@9&4@8V%M
M<&]S`$9I:FD`0V]N=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\`0V]N
M=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F]S`$=E<W3C;R!D92!&:6-H
M96ER;W,`3F]M92!D;R!!<G%U:79O`%-E;&5CY^-O(&1O(&%R<75I=F\`0V%R
M<F5G86UE;G1O(&1E(&%R<75I=F\`0V%R<F5G86UE;G1O<R!D92!F:6-H96ER
M;W,@;N-O('/C;R!S=7!O<G1A9&]S+@!&:6QT<F]S`$9I;FSB;F1I80!1=6%R
M=&\@0W)E<V-E;G1E`%%U87)T;R!#<F5S8V5N=&4`1FEX87(@<N%C:6\`26YV
M97)T97(`1FQU='5A;G1E`$YE=F]E:7)O`$$@<&%S=&$@)7,@;N-O(&5X:7-T
M92X`0V]R(&1O(%1E>'1O`$-O;6ED80!087)A(&YA=F5G861O<F5S('%U92!N
MXV\@<W5P;W)T86T@:6UA9V5N<P!0<F5V:7/C;R`H5$%&*0!$:6%S(&1E(%!R
M979I<^-O("AN;W1E+7-E('%U92!A<R!P<F5V:7/U97,@:6YC;'5E;2!T86YT
M;R!D:6%S(&-O;6\@;F]I=&5S.R!U;2!V86QO<B!D96UA<VEA9&\@9W)A;F1E
M('!O9&4@<F5S=6QT87(@;G5M(&)L;V-O(&UU:71O(&QA<F=O*0!%<W%U96-E
M=2US92!D82!P86QA=G)A+7!A<W-E/P!-;V1E;&]S`$1I=&]S`%1I<&\@9&4@
M9&ET;W,`1&ET;W,`1&ET;W,@,@!&\W)U;G,`4F5E;G9I;W,`07!L:6-AY_5E
M<R`H;?-D=6QO<RD@96YC;VYT<F%D87,Z("5S`%!A<W1A<R!E;F-O;G1R861A
M<SH`-JH`36]L9'5R87,`4F5P^F)L:6-A($9R86YC97-A`$9R86[G82P@365T
M<F]P;VQI=&%N80!'=6EA;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A
M`%1E<G)A<R!!=7-T<F%I<R!E($%N=.%R8W1I8V%S($9R86YC97-A<P!$90!$
M92``1&5S8W)IY^-O($-O;7!L971A`$QU82!#:&5I80!.;VUE($-O;7!L971O
M`$1I9G5S87,`4F5P^F)L:6-A($=A8F]N97-A`$=A;&5R:6$@9&4@;VYD92!R
M971I<F%R(&$@:6UA9V5M`$=A;&5R:6$Z`%)E</IB;&EC82!D82!'XFUB:6$`
M1V5R87(@0V]N9FEG=7)AY^-O("5S`$/S9&EG;R!'97)A9&\`1V5R86YD;R!O
M(&5S=&%D;R!D;R!M\V1U;&\@)7,N+BX`1V7S<F=I80!297#Z8FQI8V$@1F5D
M97)A;"!D82!!;&5M86YH80!%<G)O(&5M(&=E=&]P=#H`4F5P^F)L:6-A(&1O
M($=A;F$`1VEB<F%L=&%R`$YO;64@4'+S<')I;P!)<@!']F1E;`!097-Q=6ES
M82!';V]G;&4`3NUV96ES(&1E(&-I;GIE;G1O`$=RZ6-I80!'<F5G;R`H25-/
M+3@X-3DM-RD`1W)O;F5LXFYD:6$`1W)A;F%D80!!9&UI;FES=')AY^-O(&1E
M($=R=7!O<P!.;VUE<R!D92!G<G5P;W,@;N-O('!O9&5M(&5S=&%R('9A>FEO
M<P!097)M:7-S]65S(&1E(&=R=7!O`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!2
M97#Z8FQI8V$@9&$@1W5A=&5M86QA`$=U97)N<V5Y`%!E<FUI<W/U97,@9&%S
M(%9I<VET87,`4&5R;6ES<_5E<R!D87,@5FES:71A<P!,:79R;R!D92!6:7-I
M=&%S`$=U:6[I`$=U:6[I+4)I<W-A=0!297#Z8FQI8V$@0V\M;W!E<F%T:79A
M(&1A($=U:6%N80!(5$U,`$\@2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M
M96YT92!A(')E;6]V97(@82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA+@!/($A4
M34Q!<F5A(')E8W5S82US92!C;V)A<F1E;65N=&4@82!R96UO=F5R(&$@^FQT
M:6UA(&-O;'5N82!D82!T86)E;&$N`$\@2%1-3$%R96$@<F5C=7-A+7-E(&-O
M8F%R9&5M96YT92!A(')E;6]V97(@82#Z;'1I;6$@;&EN:&$@9&$@=&%B96QA
M+@!!=71E;G1I8V'GXV\@2%104"!NXV\@9F]I(&5N8V]N=')A9&$N`%)E</IB
M;&EC82!D;R!(86ET:0!!;&=O<FET;6\@9&4@(DAA<V@B`$YE8FQI;F$`0V%B
M9>=A;&AO`$EL:&%S($AE87)D(&4@36-$;VYA;&0`5&5M<&]R86PM5"!&;W)T
M90!(96)R974@*$E33RTX.#4Y+3@M22D`06QT=7)A`$%J=61A`$%J=61A('-O
M8G)E(&\@961I=&]R`$%J=61A`$%P;&EC8>?C;R!A=7AI;&EA<B!P87)A(&-R
M:6%R(&4@;6%N=&5R('1R861UY_5E<R!D82!P;&%T869O<FUA"DAO<F1E(&4@
M9&%S('-U87,@87!L:6-AY_5E<R`H;?-D=6QO<RDN"E!A<F$@=6UA(&EN=')O
M9'7GXV\@;&5R(&\@9FEC:&5I<F\@4D5!1$U%(&YE<W1A('!A<W1A+@!(96UI
M<V;I<FEO`$%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A<G%U:79O.@!!;'1A`$YO
M;65S(&1A<R!E;G1R861A<R!H:7-T\W)I87,@;N-O('!O9&5M(&5S=&%R('9A
M>FEO<P!#85]S80!%<W1A9&\@9&$@0VED861E(&1O(%9A=&EC86YO`$-A<V$`
M16YD97)EYV\@9&4@0V%S80!496QE9F]N92!D92!#87-A`%)E</IB;&EC82!D
M87,@2&]N9'5R87,`2&]N9W5E8V]N9W5E`$AO<F1E`$=E<F%D;W(@9&4@=')A
M9'7G]65S($AO<F1E`$AO<F1E+TMO;&%B.B!$861O<R!834P@)7,@:6YVX6QI
M9&]S(&YA(&UE;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A
M9V5M(&-O<G)E<W!O;F1E(&%O(&]B:F5C=&\@)7,`2&]R9&4O2V]L86(Z($YE
M;FAU;2!O8FIE8W1O(&1O('1I<&\@)7,@96YC;VYT<F%D;R!N82!M96YS86=E
M;2`E<P!(;W)D92]+;VQA8CH@4F5M;^?C;R!D92`E<R`B)7,B('1E=F4@<W5C
M97-S;P!(;W)D92]+;VQA8CH@4VEN8W)O;FEZ8>?C;R!D92`E<R`B)7,B('1E
M=F4@<W5C97-S;P!(;W)D92]+;VQA8CH@3R!M;W1O<B!D92!I;G1E9W)AY^-O
M(')E<75E<B!A(&5X=&5N<^-O(%!(4"`G9&]M>&UL)P!(;W)D92]+;VQA8CH@
M3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A<G9O<F5S(%A-3"!P
M87)A(&\@;V)J96-T;R`E<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E
M;"!R96UO=F5R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O
M<W/M=F5L(&]B=&5R(&\@240@34E-12!P87)A(&$@<&%R=&4@9&4@=&EP;R`E
M<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S:6YC
M<F]N:7IA<B!P87)T:6QH87,Z("5S`$AO<F1E+TMO;&%B.B!087)T:6QH82`B
M)7,B(&1E<V-O;FAE8VED80!4<F'G;R!(;W)I>F]N=&%L`$5N8VAI;65N=&\@
M:&]R:7IO;G1A;`!(;W)I>F]N=&%L.@!#;VUO(&-H96=O=2!A<75I/R`H4&]R
M(&9A=F]R(')E<&]R=&4M;R$I`%%U86YT87,@8V]L=6YA<R!P<F5T96YD92!J
M=6YT87(_`%%U86YT;W,@8V%M<&]S("AC;VQU;F%S*2!E>&ES=&5M/P!1=6%N
M=&%S(&QI;FAA<R!P<F5T96YD92!J=6YT87(_`$AU;6ED861E`$AU;6ED861E
M.B``2'5M;W)I<W1A<P!297#Z8FQI8V$@9&$@2'5N9W)I80!!(&-R:6'GXV\@
M9&$@8V%I>&$@<&]S=&%L($E-05`@9F%L:&]U.B`E<P!296UOY^-O(&1A(&-A
M:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,`0W)I8>?C;R!D92!Q=6]T82!D
M92!C86EX82!P;W-T86P@24U!4"!F86QH;W4Z("5S`$5N9&5R9>=O($E0`$5N
M9&5R9>=O($E0(&EN9&ES<&]N[79E;"X`16YD97)EYV\@25`@9F]R82!D;R!B
M;&]C;R!#2412('!E<FUI=&ED;RX`5FEO;&'GXV\@9&4@8FQO<75E:6\@9&4@
M25``25]N<V5R:7(@3&EN:&$@06YT97,`4F5P^F)L:6-A(&1A($ES;.)N9&D`
M07!E;F%S(,UC;VYE<P#-8V]N97,@8V]M(%1E>'1O`$YO;64@9&$@:61E;G1I
M9&%D93H`4V4@;N-O(&9O<B!M;W-T<F%D;R!C;W)R96-T86UE;G1E+"`E<R!P
M87)A(&\@86)R:7(@;G5M82!N;W9A(&IA;F5L82X`4V4@;N-O('9I<B!Q=6%L
M<75E<B#M8V]N92!A;R!U<V%R(&\@26YT97)N970@17AP;&]R97(L('!O9&4@
M<')E8VES87(@9&4@<V5L96-C:6]N87(@97-T82!C86EX82!P87)A(&1E<VQI
M9V%R(&$@=')A;G-P87+J;F-I82X`4V4@=FER(&5S=&$@;65N<V%G96T@;FUA
M<R!NXV\@82!I;6%G96T@<')O<')I86UE;G1E(&1I=&$L(&$@:6UA9V5M('%U
M92!P<F5T96YD92!C87)R96=A<B!NXV\@<&]D92!S97(@;6]S=')A9&$@<&5L
M;R!S974@;F%V96=A9&]R+@!0<F5V:7/C;R!D82!);6%G96TZ`%523"!D82!I
M;6%G96T`55),(&1A(&EM86=E;3H`26UA9V5M(&1E(&=A;&5R:6$`26UA9V5M
M(&1E(&=A;&5R:6$Z`$-A<G)E9V%M96YT;R!D82!I;6%G96T`26UA9V5N<P!)
M;7!O<G1A<BP@4&%S<V\@)60`0V%M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@
M:6UP;W)T861O<SH`26Y?<V5R:7(@3&EN:&$@1&5P;VES`$/S9&EG;R!D92!A
M8^?C;R!I;G1R;V1U>FED;R!E<W3A(&EN8V]R<F5C=&\N`$YO;64@9&4@=71I
M;&EZ861O<B!O=2!P86QA=G)A+7!A<W-E(&5R<F%D;W,N`$YO;64@9&4@=71I
M;&EZ861O<B!O=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!E<G)A9&]S+B!#;VYT
M86-T92!O('-E=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6$@<&%R82!O8G1E
M<B!A:G5D82X`075M96YT87(@82!);F1E;G1AY^-O`%)E</IB;&EC82!D82#-
M;F1I80!5=&EL:7IA9&]R97,@26YD:79I9'5A:7,`4F5P^F)L:6-A(&1A($EN
M9&]NZ7-I80!);F9O<FUAY^-O`$EN9F]R;6'GXV\`26YF;W)M8>?C;R!JX2!N
MXV\@97-TX2!D:7-P;V[M=F5L`$EN:6-I86QI>F%N9&\@;R!M\V1U;&\@)7,N
M+BX@`$EN<V5R:7(@0U]O;'5N82!$97!O:7,`26YS97)I<B!);6%G96T`26YS
M97)I<B!486)E;&$`26YS97)I<B!,:6=AY^-O(.`@5V5B`$EN<V5R:7(@7T-O
M;'5N82!!;G1E<P!);G-I<FER('5M82!N;W9A(&-O;'5N82!D97!O:7,@9&$@
M8V]R<F5N=&4`26YS:7)I<B!U;6$@;F]V82!C;VQU;F$@86YT97,@9&$@8V]R
M<F5N=&4`26YS:7)I<B!U;6$@;F]V82!L:6YH82!D97!O:7,@9&$@8V]R<F5N
M=&4`26YS:7)I<B!U;6$@;F]V82!L:6YH82!A;G1E<R!D82!C;W)R96YT90!)
M;G-E<FER('5M('!A<N%G<F%F;R!A</-S(&\@;O,@8V]R<F5N=&4`26YS97)I
M<B!U;2!P87+A9W)A9F\@86YT97,@9&\@;O,@8V]R<F5N=&4`26YS:7)I<B!M
M;V1E;&\@86QT97)N871I=F\`26YT<F]D=7IA('5M(&5N9&5R9>=O(&1E(&-O
M<G)E:6\@96QE8W1R\VYI8V\@;VYD92!P;W-S82!R96-E8F5R(&$@;F]V82!P
M86QA=G)A+7!A<W-E.@!);G-I<FER(&/I;'5L82!A</-S`$EN<V5R:7(@8^EL
M=6QA<R!A;G1E<P!);G-E<FER(&/I;'5L82!D97!O:7,`26YS97)I<B!C;VQU
M;F$@86YT97,`26YS97)I<B!M96YS86=E;G,`26YS97)I<B!P87+A9W)A9F\@
M86YT97,`26YS97)I<B!P87+A9W)A9F\@86YT97,`26YS97)I<B!L:6YH82!D
M97!O:7,`26YS97)I<B!L:6YH82!A;G1E<P!);G1R;V1U>F$@82!R97-P;W-T
M82!E>&EG:61A('!A<F$@82!P97)G=6YT82!D92!S96=U<F%NYV$Z`$EN<V5R
M:7(O36]D:69I8V%R($EM86=E;0!);G-E<FER+TUO9&EF:6-A<B!,:6=AY^-O
M`$-RZ61I=&\@:6YS=69I8VEE;G1E('!A<F$@96YV:6%R('!A<F$@82!L:7-T
M82!D92!D:7-T<FEB=6GGXV\N`$-RZ61I=&\@:6YS=69I8VEE;G1E+@!);G1E
M:7)O`$QI<W1A(&1E(&EN=&5I<F]S`%5$2"`H57-E<B!$871A($AE861E<BD@
M:6YVX6QI9&\N`$1A9&]S(%I)4"!I;G;A;&ED;W,`07!L:6-AY^-O(&EN=N%L
M:61A+@!)1"!D92!L;W1E("@B8F%T8V@B*2!I;G;A;&ED;RX`3W,@9&%D;W,@
M<W5B;65T:61O<R!SXV\@:6YVX6QI9&]S+@!%;F1E<F7G;R!D92!D97-T:6YO
M(&EN=N%L:61O+@!&;W)M871O(&1O(&%R<75I=F\@:6YVX6QI9&\`0VAA=F4@
M9&$@;&EC96[G82!I;G;A;&ED82X`3&]C86QI>F'GXV\@:6YVX6QI9&$@97-P
M96-I9FEC861A+@!M<V=?='EP92!I;G;A;&ED;RX`87!I7VED(&EN=N%L:61O
M(&]U(&5M(&9A;'1A+@!087+B;65T<F]S(&EN=N%L:61O<R!O=2!E;2!F86QT
M82X`4&5R;6ES<^-O('!A<F5N=&%L(&EN=N%L:61A+@!)1"!D92!P87)C96ER
M;R!I;G;A;&ED;RX`0_-D:6=O(&1E('!R;V1U=&\@:6YVX6QI9&\N`%!R;W1O
M8V]L;R!I;G;A;&ED;RX`1&5S=&EN873A<FEO(&EN=N%L:61O.B`B)7,B`$]B
M:F5C=&\@9&4@<&%R=&EL:&$@:6YVX6QI9&\`16YD97)EYV\@9&$@;W)I9V5M
M(&EN=N%L:61O+@!$861O<R!U;FEC;V1E(&EN=N%L:61O<RX`26YV96YTX7)I
M;P!297#Z8FQI8V$@27-LXFUI8V$@9&\@27+C;P!297#Z8FQI8V$@9&\@27)A
M<75E`%)E</IB;&EC82!D82!)<FQA;F1A`$EL:&$@9&4@36%N`%1E;7!O<F%I
M<RU4($ES;VQA9&]S`$5S=&%D;R!D92!)<W)A96P`16UI<W-O<@!)=.%L:6-O
M`%)E</IB;&EC82!)=&%L:6%N80!*86UA:6-A`$IA;F5I<F\`2F%PXV\`2F%P
M;V[J<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!296EN;R!(87-H96UI=&$@9&$@
M2F]R9.)N:6$`2G5L:&\`2G5N:&\`2G5S=&EF:6-A<@!#96YT<F%R`$IU<W1I
M9FEC87(`2G5S=&EF:6-A<B#@($5S<75E<F1A`$IU<W1I9FEC87(@X"!$:7)E
M:71A`%)E</IB;&EC82!D;R!#87IA<75I<W3C;P!0<F5S97)V87(@;R!O<FEG
M:6YA;#\`4F5P^F)L:6-A(&1O(%%UZ6YI80!/('-E<G9I9&]R($ME<F)E<F]S
M(')E:F5I=&]U(&$@875T96YT:6-AY^-O+@!.;W9A=&]S(&YO(")+97)N96PB
M`$-R:6'GXV\@9&$@0VAA=F4`26UP<F5S<^-O(&1I9VET86P@9&$@8VAA=F4`
M0V]M<')I;65N=&\@9&$@8VAA=F4`5&EP;R!D82!#:&%V90!5=&EL:7IAY^-O
M(&1A($-H879E`$$@8VAA=F4@:N$@97AI<W1E(&YO('-E<G9I9&]R(&1E(&-H
M879E<R!P^F)L:6-A<RX`36GZ9&]S`%%U:7)I8F%T:0!297#Z8FQI8V$@4&]P
M=6QA<B!$96UO8W+A=&EC82!D82!#;W)E:6$`4F5P^F)L:6-A(&1A($-O<F5I
M80!#;W)E86YO("A%54,M2U(I`$MU=V%I=`!297#Z8FQI8V$@475I<F=U:7IE
M`%]$:7-P;W-IY^-O`$ED:6]M80!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A
M=&EC82!,86\`475A<G1O($1E8W)E<V-E;G1E`%%U87)T;R!$96-R97-C96YT
M90#:;'1I;6$@06-T=6%L:7IAY^-O.@#:;'1I;6$@96YT<F%D83H@)7,`VFQT
M:6UA(&5N=')A9&$Z("5S(&1E("5S`-IL=&EM82!E;G1R861A.B!.=6YC80!2
M97#Z8FQI8V$@9&$@3&5T\VYI80!,96D`1&ES<&]S:>?C;P!$96EX87(@=F%Z
M:6\@<&%R82!F:6-A<B!S96T@8F]R9&$`3.UB86YO`$5S<75E<F1A`$-A8F7G
M86QH;R!D82!E<W%U97)D80!686QO<F5S(.`@97-Q=65R9&$`3&5S;W1O`$QI
M8NER:6$`1W)A;F1E($IA;6%H:7)I>6$@4V]C:6%L:7-T82!0;W!U;&%R(,%R
M86)E(&1A($SM8FEA`$QI<W1E;G-T86EN90!#:'5V82`B36]L:&$M5&]L;W,B
M`$-H=79I<V-O<P!#:'5V:7-C;W,@36%T:6YA:7,`0VAU=FES8V]S(%9E<W!E
M<G1I;F]S`%!E<75E;F\@06=U86-E:7)O`$-H=79I<V-O(&-O;2!4<F]V;V%D
M80!1=65D82!D92!.979E`$YE=F4`(DQI;65R:6-K(@!,:6=AY^-O`$QI9V'G
MXV\@87!O;G1A('!A<F$Z`$QI9V%R(&\@96YD97)EYV\@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;R#@('#A9VEN82!D92!C;VUP;W-IY^-O(&%O(&UO<W1R87(`
M3&EG8>?U97,`0F]L:6YH;R!L:6YU>.IS`$QI<W1A("T@;R!U=&EL:7IA9&]R
M('!O9&4@=F5R(&$@<&%S=&$`3&ES=&%R($)A<V5S(&1E($1A9&]S`$UO<W1R
M87(@5/-P:6-O<R!D92!!:G5D80!,:7-T87(@5&%B96QA<P!,:7-T86=E;2U!
M<G%U:79O`$QI<W1A9V5M+4%J=61A`$E$(&1A($QI<W1A`$QI<W1A9V5M+41O
M;F\`3&ES=&%G96TM4W5B;6ES<_5E<P!,:7-T86=E;2U3=6)S8W)I=&%S`$QI
M<W1A9V5M+4[C;R!S=6)S8W)I=&%S`$$@;&ES=&%G96T@9&4@=71I;&EZ861O
M<F5S(&5S=.$@9&5S86-T:79A9&$N`$QI=&5R871U<F$Z`%)E</IB;&EC82!D
M82!,:71UXFYI80!#87)R96=A;F1O(&)I8FQI;W1E8V%S+BXN`$-A<G)E9V%N
M9&\N+BX`5&5M<&\@;&]C86PZ`$QO8V%L:7IAY^-O(&4@1G5S;R!(;W+A<FEO
M`$QO8V%L:7IAY^-O`$5N=')A<@!386ER`%1A<F5F87,@9&4@16YT<F%D80!!
M(&%U=&5N=&EC8>?C;R!F86QH;W4@<&]R(&\@3F]M92!D92!5=&EL:7IA9&]R
M(&]U(&$@4&%L879R82U087-S92!E<W1A<F5M(&EN8V]R<F5C=&]S+@!!(&%U
M=&5N=&EC8>?C;R!F86QH;W4N`%1E>'1O(&QO;F=O`$%M;W(`0F%I>&\`3&5T
M<F%S(&=R96=A<R!M:6[Z<V-U;&%S`$QE=')A<R!L871I;F%S(&UI;OIS8W5L
M87,`3OIM97)O<R!R;VUA;F]S(&UI;OIS8W5L;W,`3'5X96UB=7)G;P!-30!-
M3U1$`$\@86YE>&\@35,M5$Y%1B!NXV\@8V]N=&EN:&$@9&%D;W,N`$U31P!-
M86-A=0!-86-E9/-N:6$L($%N=&EG82!297#Z8FQI8V$@2G5G;W-L879A(&1A
M`$UA9&%GX7-C87(`36%G:6$`0V]R<F5I;P!!9&UI;FES=')AY^-O(&1E($-O
M<G)E:6\`1F%Z97(@;&E?9V'GXV\N+BX`07-S96=U<F4M<V4@9&4@<75E('1E
M;2!O(%!%05(@:6YS=&%L861O(&4@;F\@8V%M:6YH;R!D92!I;F-L=7/U97,@
M*&EN8VQU9&4@<&%T:"DN`$-R:6%N9&\@82!P87-T82`E<P!-86QA=6D`36%L
MX7-I80!-86QD:79A<P!-86QI`$UA;'1A`$=I<F$@82!L:7-T82!D92!C871E
M9V]R:6%S('%U92!P;V1E(&%T<FEB=6ER(&%O<R!I=&5N<RP@8F5M(&-O;6\@
M87,@8V]R97,@<75E(&QH97,@97-TXV\@87-S;V-I861A<RX`36%P82!-87`R
M-`!-87!A($UA<%%U97-T`$UA<N=O`$UA<F=E;0!-87)C87(@8V]M;R!,:61A
M+T[C;R!L:61A`$UA<F-A<B!D92!O=71R87,@9F]R;6%S("AE+F<N+"!);7!O
M<G1A;G1E+U!O<B!R97-P;VYD97(I`$EL:&%S($UA<G-H86QL`$UA<G1I;FEC
M80!#86UP;W,@<75E(&-O<G)E<W!O;F1E;0!-875R:73B;FEA`$UA=7+M8VEO
M`$WA>&EM;R!C<NED:71O('!E<FUI=&ED;RX`3>%X:6UO(&[Z;65R;R!D92!P
M87)T97,@;G5M82!M96YS86=E;2!E>&-E9&ED;RX`5&5M<&5R871U<F$@;>%X
M:6UA(&YA<R#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA
M(&YA<R#Z;'1I;6%S(#8@:&]R87,Z(`!#;VUP<FEM96YT;R!MX7AI;6\`36%I
M;P!-87EO='1E`$UE9&EC:6YA`$UE;6)R;W,`36]D;R!D;R!M96YU.@!5;FER
M(&/I;'5L87,`26YT96=R86YD;R!T;V1O<R!O<R!F:6-H96ER;W,@)7,N<&\@
M8V]M(&\@8V]M<.IN9&EO+BXN`$EN=&5G<F%N9&\@82!L;V-A;&EZ8>?C;R`E
M<RXN+B``26YT96=R86YD;R!O(&%R<75I=F\@4$\@9&4@)7,@8V]M(&\@8V]M
M<.IN9&EO+BXN(`!);G1E9W)A;F1O(&$@=')A9'7GXV\@9&\@;?-D=6QO("5S
M+BXN`$UE;G-A9V5M`$UE;G-A9V5N(%9E<FEF:6-A9&$@8V]M(%-U8V5S<V\L
M(&UA<R!O(&-E<G1I9FEC861O(&1O('-U8G-C<FET;W(@;N-O('#T9&4@<V5R
M('9E<FEF:6-A9&\N`$UE;G-A9V5M(&5X<&ER;W4N`%1I<&\@9&4@;65N<V%G
M96T`365T96]R;VQO9VEA($U%5$%2`$)L;V-O($U%5$%2(&EN9&ES<&]N[79E
M;"X`0FQO8V\@345405(@:6YD:7-P;V[M=F5L+B!/<R!P;W)M96YO<F5S(&9O
M<F%M(')E9VES=&%D;W,@<&%R82!O(&%D;6EN:7-T<F%D;W(N`$$@365T87)$
M0B!NXV\@97-TX2!C;VYE8W1A9&$N`$WI=&]D;P!/(&WI=&]D;R`B)7,B(&[C
M;R!E<W3A(&1E9FEN:61O`$WI=')I8V\`3>EX:6-O`$UI8W)O;NES:6$L($5S
M=&%D;W,@1F5D97)A9&]S(&1A`$-E;G1R;P!4:7!O($U)344`5&5M<&5R871U
M<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#(T(&AO<F%S`%1E;7!E<F%T=7)A(&WM
M;FEM82!N87,@^FQT:6UA<R`V(&AO<F%S`$5S<&5L:&\`36ES8V5LXFYE80!0
M86-O=&4@2%144%]297%U97-T(&1O(%!%05(@96T@9F%L=&$N`$-O;F9I9W5R
M8>?C;R!E;2!F86QT82X@5&5RX2!D92!A(&=E<F%R(&%G;W)A('-E('%U:7-E
M<B!U<V%R(&5S=&$@87!L:6-AY^-O+@!)1"!D82!M96YS86=E;2!E;2!F86QT
M82X`4&%C;W1E($UA:6P@9&\@4$5!4B!E;2!F86QT82X`240@9&$@<V5S<^-O
M(&5M(&9A;'1A+@`RJ@!#;W)R96EO($WS=F5L`$UO9&5R861O`$1A=&$@9&4@
M36]D:69I8V'GXV\`36]D:69I8V%R(%523`!-\V1U;&\`3?-D=6QO`%)E</IB
M;&EC82!D82!-;VQD;W9A`%!R:6YC:7!A9&\@9&\@3?-N86-O`$UO;F?S;&EA
M`$WJ<R!E(&%N;P!-96YS86QM96YT90!-;VYT<V5R<F%T`$9A<V4@9&$@3'5A
M`%)E:6YO(&1E($UA<G)O8V]S`%-O8G)E='5D;R!,:6UP;P!3;V)R971U9&\@
M16YE=F]A9&\`4V]B<F5T=61O(%-O;&%R96YG;P!$97-C97(`36]V97(@<&%R
M82!A($5S<75E<F1A`$UO=F5R('!A<F$@82!$:7)E:71A`%-U8FER`$1E<V-E
M<@!3=6)I<@!297#Z8FQI8V$@9&4@36_G86UB:7%U90!,:7-T87,@9&4@9&5S
M96YR;VQA<B!M=6QT:2UN[79E;`!396QE8^?C;R!M^FQT:7!L80!!($UI;FAA
M($-O;G1A`$\@365U(%!O<G1A;`!$:7-P;W-IY^-O(&1O(%!O<G1A;`!5;FGC
M;R!D92!->6%N;6%R`$[C;RP@;N-O(&-O;F-O<F1O`$YO;64`4F5P^F)L:6-A
M(&1A($YA;>UB:6$`3F%U<G4`3F5P86P`4F5I;F\@9&]S(%!A[7-E<R!"86EX
M;W,`06YT:6QH87,@2&]L86YD97-A<P!54DP@9&4@0F%S92!.971S8V%P90!5
M4DP@9&4@4F5V;V=AY^-O($-!($YE='-C87!E`%523"!C;VT@82!P;VSM=&EC
M82!D92!#02!.971S8V%P90!54DP@9&4@4F5N;W9AY^-O($YE='-C87!E`%52
M3"!D92!2979O9V'GXV\@3F5T<V-A<&4`3F]M92!D;R!S97)V:61O<B!34TP@
M3F5T<V-A<&4`0V]M96YTX7)I;R!D92!C97)T:69I8V%D;R!.971S8V%P90!4
M:7!O(&1E(&-E<G1I9FEC861O($YE='-C87!E`%)E9&4`3G5N8V$`3F]V82!#
M86QE9/-N:6$`3F]V82!#871E9V]R:6$`3'5A($YO=F$`3F]V;R!.;VUE(&1E
M(%5T:6QI>F%D;W(@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA`$YO=F$@:F%N
M96QA("A?8FQA;FLI`$YO=.UC:6%S`$=R=7!O<R!D92!.;W3M8VEA<P!0<O-X
M:6UA`%!R\WAI;6%S(#0@1F%S97,`4'+S>&EM87,@;W#G]65S`%!R\WAI;6$^
M`%)E</IB;&EC82!D82!.:6-A<N%G=6$`4F5P^F)L:6-A(&1O($[M9V5R`%)E
M</IB;&EC82!&961E<F%L(&1A($YI9V5R:6$`3F]I=&4`3FEU90!.XV\`3N-O
M(&CA(&1A9&]S(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<R!E;2!R96QA
MY^-O(&%O<R!Q=6%I<R!M;W-T<F%R(&1I9F5R96[G87,N`$[C;R!HX2!N96YH
M=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(')E86QI>F%R(&EM86=E
M;G,@25-/+@!.XV\@:.$@;6]D96QO(&1E(&QO=&4@(F)A=&-H(BX`3N-O(&5X
M:7-T92!B;&]C;R!N82!P;W-IY^-O(&EN9&EC861A`$[C;R!F;VD@9F]R;F5C
M:61O('5M(&YO;64@9&4@8V%L96YDX7)I;R!P87)A(&$@875T96YT:6-AY^-O
M($U#04PN`%-E;2!M;V1I9FEC8>?U97,N`$[C;R!S92!P;V1E(&%D:6-I;VYA
M<B!P97)M:7-S]65S(&1E(&9I;&AO<R!A8F%I>&\@9&5S=&4@;NUV96PN`$[C
M;R!S92!P;V1E(&%D:6-I;VYA<B!F:6QH;W,@82!E<W1A('!E<FUI<W/C;RX`
M3F5N:'5M(&-O;6%N9&\@97-P96-I9FEC861O+@!.XV\@9F]I(&5S<&5C:69I
M8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O('!A<F$@)7,N`$[C
M;R!F;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'G
MXV\@<&%R82!61E,@8F%S96%D;R!E;2!&5%`N`$[C;R!F;VD@97-P96-I9FEC
M861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@;F5C97-SX7)I82!P
M87)A(&\@5D93(&)A<V5A9&\@96T@4U%,+@!.XV\@9F]I(&5S<&5C:69I8V%D
M82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&YE8V5S<^%R:6$@<&%R
M82!O(%9&4R!B87-E861O(&5M(%-13"U&:6QE+@!#<NED:71O(&5S9V]T;W4N
M`$YE;FAU;2!D97-T:6YA=.%R:6\@9F]I(&9O<FYE8VED;RX`3N-O(&5X:7-T
M92!Q=6%L<75E<B!E;G1R861A(&-O;2!O(&ED("(E<R(@;F\@87)Q=6EV;R!D
M92!A:G5D82!O<FEG:6YA;"X`3N-O('-E(&-A<G)E9V]U(&YA9&$N`$YE;FAU
M;6$@;&]C86QI>F'GXV\@97-P96-I9FEC861A+@!&86QT82!I;F1I8V%R('5M
M82!L;V-A;&EZ8>?C;RX`02!L;V-A;&EZ8>?C;R!NXV\@9F]I(&5S<&5C:69I
M8V%D82X`3F5N:'5M82!M96YS86=E;2!F;VD@9F]R;F5C:61A+@!.96YH=6T@
M;F]M92!E<W!E8VEF:6-A9&\N`$YE;FAU;2!N^FUE<F\@97-P96-I9FEC861O
M+@!396T@9&ET;W,@;V9E;G-I=F]S`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V
M<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!(5%10+@!.XV\@9F]I(&9O
M<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@24U!
M4"X`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T
M96YT:6-AY^-O($ME<F)E<F]S+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A
M+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@3$1!4"X`3N-O(&9O:2!F;W)N
M96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($QO9VEN
M+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E
M;G1I8V'GXV\@4$%34U=$+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A
M<W-E('!A<F$@82!A=71E;G1I8V'GXV\@4TU"+@!.XV\@9F]I(&EN9&EC861O
M(&-A;6EN:&\@<&%R82!O(&)I;N%R:6\@3W!E;E-33"X@3R!B:6[A<FEO($]P
M96Y34TP@Z2!N96-E<W/A<FEO('!A<F$@=')A8F%L:&%R(&-O;2!D861O<R!0
M2T-3(#$R+@!.XV\@:.$@<W5B<V-R:>?U97,@<&5N9&5N=&5S+@!396T@=')A
MYV]S`%-E;2!L861O<P!.XV\@:.$@<&%S=&$@=&5M<&]RX7)I82!D:7-P;V[M
M=F5L('!A<F$@(F-A8VAE(BX`3N-O(&9O<F%M(&5N=FEA9&]S(&\@;F]M92!D
M;R!U=&EL:7IA9&]R(&]U(&$@<&%L879R82UP87-S92X`3N-O(&9O<F%M(')E
M=&]R;F%D;W,@9&%D;W,@96T@6$U,(';A;&ED;W,`4V5M('9A;&]R97,`3N-O
M(&9O:2!E;F-O;G1R861A('9E<G/C;R!N82!C;VYF:6=U<F'GXV\@;W)I9VEN
M86PN(%)E9V5N97)A<B!C;VYF:6=U<F'GXV\N`$[C;R!F;VD@96YC;VYT<F%D
M82!V97)SXV\@;F$@<W5A(&-O;F9I9W5R8>?C;RX@4F5G96YE<F%R(&-O;F9I
M9W5R8>?C;RX`3F5N:'5M80!.96YH=6T@*'5S87(@:6UP;.UC:71O*0!.\W)D
M:6-O("A)4T\M.#@U.2TQ,"D`26QH82!D92!.;W)F;VQK`$AE;6ES9NER:6\@
M3F]R=&4`26QH87,@36%R:6%N87,@9&\@3F]R=&4`4F5I;F\@9&$@3F]R=65G
M80!.=6YC82!$97!O:7,@9&4`3G5N8V$@06YT97,@9&4`3N-O(.D@=6T@9&ER
M96-T\W)I;P!.XV\@:6UP;&5M96YT861A+@!0;W(@871R:6)U:7(`3N-O('-U
M<&]R=&%D;RX`3F]T87,`3F%D82!P87)A(&YA=F5G87(L('9O;'1E('!A<F$@
M='+A<RX`3F]T80!.;W9E;6)R;P!.^FUE<F\`3OIM97)O(&1E(&-A<F%C=&5R
M97,`3OIM97)O(&1E(&-O;'5N87,`3OIM97)O(&1E(&QI;FAA<P!.82!L:7-T
M82!D92!D:7-T<FEB=6GGXV\@:.$@;OIM97)O<R!Q=64@;N-O(&9O<F%M(&5S
M<&5C:69I8V%D;W,@<&%R82!A8W1U86QI>F'GXV\N`$]+`$]B:F5C=&\`0W)I
M861O<B!D;R!/8FIE8W1O`%!E<FUI<W/U97,@9&\@8W)I861O<B!D;R!O8FIE
M8W1O`$]C=&%L`$]U='5B<F\`1FEL=')O(&1E(&UA=&5R:6%L(&]F96YS:79O
M`$=A8FEN971E`%-U;'1A;F%T;R!D;R!/;>,`4_,@;W,@<V5R=FED;W)E<R!)
M34%0('-U<&]R=&%M('!A<W1A<R!P87)T:6QH861A<RX`07!E;F%S(&1I=&]S
M(&]F96YS:79O<P!3\R#I('!E<FUI=&ED;R!U;2!E;F1E<F7G;R!D92!C;W)R
M96EO(&5L96-T<O-N:6-O+@!!<&5N87,@;R!D;VYO(&]U('5M(&%D;6EN:7-T
M<F%D;W(@9&4@<VES=&5M87,@<&]D92!A;'1E<F%R(&$@=&ET=6QA<FED861E
M(&1E('5M82!P87)T:6QH82!O=2!A<R!P97)M:7-S]65S(&1O('-E=2!D;VYO
M`$%B<F4@;G5M82!N;W9A(&IA;F5L80!%<G)O($]P96Y34TPZ($[C;R!F;VD@
M<&]S<^UV96P@97AT<F%I<B!D861O<R!D92!U;6$@<&%R=&4@87-S:6YA9&$@
M8V]M(%,O34E-12X`06)R92!E<W1A(&QI9V'GXV\@;G5M82!N;W9A(&IA;F5L
M80!3:7-T96UA($]P97)A=&EV;P!/<.?U97,`3W#G]65S(&1O("5S`$]PY_5E
M<SH`3&ES=&$@3W)D96YA9&$`3W)G86YI>F'GXV\`56YI9&%D92!/<F=A;FEZ
M86-I;VYA;`!/<F=A;FEZ8>?C;P!-;V1E;&\@;W)I9VEN86P@9&$@87!L:6-A
MY^-O`$UO9&5L;W,@;W)I9VEN86ES(&5M("5S.@!/=71R;P!/=71R87,@26YF
M;W)M8>?U97,`4&5R;6ES<_5E<R!D;R!$;VYO`$%U=&5N=&EC8>?C;R!004T@
M;N-O(&5S=.$@9&ES<&]N[79E;"X`07-S:6YA='5R82!$:6=I=&%L(%!'4`!$
M861O<R!E;F-R:7!T861O<R!01U``0VAA=F4@4/IB;&EC82!01U``1&%D;W,@
M07-S:6YA9&]S+T5N8W)I<'1A9&]S(&-O;2!01U``0_-D:6=O(%!(4`!#;VUA
M;F1O<R!02%``0VAU=FES8V]S('!E;&$@5&%R9&4`06=U86-E:7)O<R!D92!4
M87)D90!.979E(.`@5&%R9&4`3F5V]65S(.`@5&%R9&4`4V]L(.`@5&%R9&4`
M5&5M<&]R86ES+50@X"!487)D90!#;VUA;F1O<R!07TA0`$5N8VAI;65N=&\`
M4F5P^F)L:6-A($ES;.)M:6-A(&1O(%!A<75I<W3C;P!297#Z8FQI8V$@9&4@
M4&%L874`5&5R<FET\W)I;R!086QE<W1I;FEA;F\`4&%N86WA`%!A<'5A($YO
M=F$@1W5I;ND`4F5P^F)L:6-A(&1O(%!A<F%G=6%I`%!A<F-I86QM96YT92!%
M;F-O8F5R=&\`4&%L879R82U087-S90!086QA=G)A+5!A<W-E(&EN8V]R<F5C
M=&$`4&%L879R82U087-S92!N96-E<W/A<FEA('!A<F$@875T96YT:6-AY^-O
M(%)!1$E54P!086QA=G)A+5!A<W-E(&-O;2!C;VYF:7)M8>?C;P!086QA=G)A
M+5!A<W-E.@!086QA=G)A+5!A<W-E.B``07,@<&%L879R87,M<&%S<V4@=.IM
M(&1E('-E<B!I9W5A:7,N`$-O;&%R`$-O;&%R(&1E(')E8V]R=&5S`$-A;6EN
M:&\`4W5B<V-R:>?U97,@4&5N9&5N=&5S.@!097-S;V%S`%!E<F-E;G1A9V5M
M`$5X96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O`$5X96-U=&%R(&]P
M97)AY_5E<R!D92!M86YU=&5NY^-O(&%Q=6%N9&\@9&$@96YT<F%D83\`4&5R
M;6ES<^-O`$$@<&5R;6ES<^-O("(E<R(@;N-O(&9O:2!R96UO=FED82X`061M
M:6YI<W1R8>?C;R!D92!097)M:7-S]65S`%!E<FUI<W/U97,@9&4`26YF;W)M
M8>?U97,@4&5S<V]A:7,`4&5R^@!!;FEM86ES(&1E($5S=&EM8>?C;P!&:6QI
M<&EN87,`5&5L969O;F4`1F]T;V=R869I87,`26QH87,@4&ET8V%I<FX`4.UX
M96ES`%!L871I='5D97,`4&]R(&9A=F]R(&-L:7%U92!S;V)R92!U;6$@8^EL
M=6QA`%!O<B!F879O<B!C;VYF:7)M92!S92!R96%L;65N=&4@<')E=&5N9&4@
M<F5M;W9E<B!E<W1E(&5L96UE;G1O.@!0;W(@9F%V;W(@8V]N9FER;64@<V4@
M<F5A;&UE;G1E('!R971E;F1E(&1E<VQI9V%R(&5S=&4@96QE;65N=&\N`%!O
M<B!F879O<B!I;G1R;V1U>F$@=6T@;>IS(&4@=6T@86YO+@!0;W(@9F%V;W(@
M:6YT<F]D=7IA(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83H`4&]R(&9A=F]R
M(&EN=')O9'5Z82!U;2!E;F1E<F7G;R!)4"!VX6QI9&\N`%!O<B!F879O<B!I
M;G1R;V1U>F$@=6UA(&1A=&$@=N%L:61A.R!V97)I9FEQ=64@;R!N^FUE<F\@
M9&4@9&EA<R!D;R!MZG,N`%!O<B!F879O<B!I;G1R;V1U>F$@=6UA(&AO<F$@
M=N%L:61A+@!0;W(@9F%V;W(L(&9O<FYEYV$@=6UA(&)R979E(&1E<V-R:>?C
M;R!D;R!P<F]B;&5M82X`4&]R(&9A=F]R+"!I;G1R;V1U>F$@;R!S974@3F]M
M92!D92!5=&EL:7IA9&]R(&4@82!S=6$@4&%L879R82U087-S90!0;W(@9F%V
M;W(@;&5I82!O('1E>'1O('-E9W5I;G1E+B!496T@9&4@0T].0T]21$%2(&-O
M;2!O<R!T97)M;W,@9&5S=&4@86-O<F1O('!A<F$@=7-A<B!O('-I<W1E;6$N
M`%!O<B!F879O<B!R97!O<G1E(&]S(&5R<F]S('!A<F$@:3$X;D!L:7-T<RYH
M;W)D92YO<F<`4&]R(&9A=F]R(&EN=')O9'5Z82!O(&YO;64@9&$@;F]V82!C
M871E9V]R:6$Z`%!O;/-N:6$`4&]L[71I8V$`4V]N9&%G96YS`%)E</IB;&EC
M82!0;W)T=6=U97-A`%!O<VEC:6]N86UE;G1O(&1E<W1A(&EM86=E;0!0;W-I
M8VEO;F%M96YT;R!D97-T82!T86)E;&$`(E!O<W0B('!A<F$@97-T82!P87-T
M82`H;N-O(.D@<F5Q=6ES:71O(&1O($E-05`I`%!R96-I<&ET8>?C;R!N87,@
M^FQT:6UA<R`E<R!H;W)A*',I.B``4')O8F%B:6QI9&%D92!D93QB<B`O/E!R
M96-I<&ET8>?C;P!0<F5F<U]L9&%P.B!!(&5X=&5N<^-O($Q$05`@;F5C97-S
MX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`%!R969S7W-E<W-I;VXZ($$@97AT
M96YSXV\@9&4@<V5S<^-O(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A
M+@!0<F5S<^-O`%!R97-SXV\@86\@;NUV96P@9&\@;6%R.B``4')E<W/C;SH@
M`%!R979I<^-O`%!R979E<B!A(&EM86=E;2!N=6UA(&YO=F$@:F%N96QA`$]P
MY_5E<R!A;G1E<FEO<F5S`$EM<')I;6ER(&\@9&]C=6UE;G1O`$-H879E(%!R
M:79A9&$`4')O8FQE;6$`1&5S8W)IY^-O(&1O(%!R;V)L96UA`%!R;VIE8W1O
M<P!-96YS86=E;2UP<F]N=&\`0VAA=F4@4/IB;&EC80!!;&=O<FET;6\@9&4@
M0VAA=F4@4/IB;&EC80!);F9O<FUAY^-O(%-O8G)E(&$@0VAA=F4`3R!P87(@
M9&4@8VAA=F5S(%!U8FQI8V$O4')I=F%D82!NXV\@9F]I(&=E<F%D82!C;VT@
M<W5C97-S;RX`4&]R=&\@4FEC;P!%<W1A9&\@9&\@46%T87(`4&5D:61O`$-H
M879E(%#Z8FQI8V$@4E-!("@E9"!B:70I`%-E;&5CY^-O(")RX61I;R(`0VAU
M=F$`0VAU=F$@36%T:6YA;`!#:'5V82!697-P97)T:6YA`$%G=6%C96ER;P!#
M:'5V82!E($YE=F4`0VAU=F$@82!.979E`$1I=&\@06QE873S<FEO`%)E;&'G
MXV\`3&5R`$QE<B!M96YS86=E;G,`475E<B!M97-M;R!R96UO=F5R("5S/R!%
M<W1A(&]P97)AY^-O(&[C;R!T96T@<F5G<F5S<V\N`%)E;6]V97(@;65S;6\@
M;W,@9&%D;W,@9&\@=71I;&EZ861O<B`E<S\@17-T82!O<&5R8>?C;R!NXV\@
M=&5M(')E9W)E<W-O+@!2969A>B!A('-U82#Z;'1I;6$@86/GXV\`4F5F<F5S
M8V%R($5L96UE;G1O<R!D92!-96YU($1I;N)M:6-O.@!2969R97-C87(@5FES
M=6%L:7IAY^-O(&1O(%!O<G1A;#H`17AP<F5S<^-O(%)E9W5L87(`3F%V96=A
M9&]R(&1E(%)E;&'G]65S`$]B<V5R=F'G]65S`%-E<G9I9&]R97,@4F5M;W1O
M<P!54DP@4F5M;W1O("AH='1P.B\O=W=W+F5X96UP;&\N<'0O:&]R9&4I.@!2
M96UO=F5R`%)E;6]V97(@0FQO8V\`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!F
M;W)M871AY^-O`%)E;6]V97(@<&%R`%)E;6]V97(@;R`B<V-R:7!T(B!G=6%R
M9&%D;R!D82!P87-T82!T96UP;W+A<FEA(&1O('-E<G9I9&]R+@!296UO=F5R
M(&\`4F5M;W9E<B!E<W1E(&[S(&1O(&1O8W5M96YT;P!296UO=F5R(%5T:6QI
M>F%D;W(`4F5M;W9E<B!U=&EL:7IA9&]R.B`E<P!.XV\@9F]I('!O<W/M=F5L
M(')E<W!O;F1E<B!A;R!P961I9&\N($/S9&EG;R!D92!E<G)O(&1E=F]L=FED
M;SH@`$\@<V5R=FGG;R!P961I9&\@;N-O(&9O:2!E;F-O;G1R861A+@`B)7,B
M(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R
M8>?C;R!D92`E<RX`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I
M8V%D;R!N82!C;VYF:6=U<F'GXV\@5D93+@`B)7,B(&]B<FEG873S<FEO(&[C
M;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;RX`0V%M<&\@3V)R
M:6=A=/-R:6\`3&EM<&%R`%)E:6YI8VEA<B!086QA=G)A+5!A<W-E`%)E:6YI
M8VEE(&$@4W5A(%!A;&%V<F$M4&%S<V4`4F5S=6QT861O<P!297-U;'1A9&]S
M("AI;F-L=6EN9&\@2&]R9&4I.@!297-U;'1A9&]S.@!6;VQT87(@X',@3W#G
M]65S`%)E=6YIXV\`4D5V97)T97(@0V]N9FEG=7)AY^-O`$]PY_5E<R!D92!%
M9&GGXV\@4FEC80!!9&EV:6YH87,`1&ER96ET80!#86)EYV%L:&\@9&$@9&ER
M96ET80!686QO<F5S(.`@9&ER96ET80!0<F]P<FEE9&%D97,@9&$@3&EN7VAA
M+BXN`%)E9W)A`%)O;>EN:6$`4F]D87(@,3@P`%)O9&%R(.`@17-Q=65R9&$`
M4F]D87(@X"!D:7)E:71A`%!R;W!R:65D861E<R!D82!,:6YH80!0<F]P<FEE
M9&%D97,@9&$@;&EN:&$`3&EN:&%S.@!4<F'G;W,`5')AYV]S(&%P87)E8V5R
MXV\@96YT<F4@=&]D87,@87,@;&EN:&%S(&4@8V]L=6YA<P!4<F'G;W,@87!A
M<F5C97+C;R!A<&5N87,@96YT<F4@87,@8V]L=6YA<P!4<F'G;W,@87!A<F5C
M97+C;R!A<&5N87,@96YT<F4@;&EN:&%S`$5X96-U=&%R`$9E9&5R8>?C;R!2
M=7-S80!297#Z8FQI8V$@9&\@4G5A;F1A`$%S<VEN871U<F$@0W)I<'1O9W+A
M9FEC82!3+TU)344`365N<V%G96T@16YC<FEP=&%D82!C;VT@4R]-24U%`$%U
M=&5N=&EC8>?C;R!305-,(&EN9&ES<&]N[79E;"X`365N<V%G96YS(%--4P!#
M;VUA;F1O<R!344P`4U-(`%-50T534T\`0V]M86YD;W,@4U]13`!SX0!386YT
M82!(96QE;F$`4^-O($MI='1S(&4@3F5V:7,`4V%N=&$@3/IC:6$`4^-O(%!E
M9')O(&4@36EQ=65L;VX`4^-O(%9I8V5N=&4@92!'<F5N861I;F5S`$UE<VUA
M(&UO;&1U<F$@*%]S96QF*0!%<W1A9&\@26YD97!E;F1E;G1E(&1A(%-A;6]A
M`%)E</IB;&EC82!397)E;NUS<VEM82!D92!3XV\@36%R:6YO`%/C;R!4;VWI
M(&4@4'+M;F-I<&4`1F]R;F5C961O<B!D;R!3873I;&ET90!!<N%B:6$@4V%U
M9&ET80!'=6%R9&%R`$=U87)D87(@)7,`1W5A<F1A<B`G)7,G`$=U87)D87(@
M3W#G]65S`$=U87)D87(@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(")S
M8W)I<'0B(%!(4"!N;R!D:7)E8W3S<FEO('1E;7!O<N%R:6\@9&\@<V5U('-E
M<G9I9&]R+@!'=6%R9&5I(&-O;F9I9W5R8>?C;R`E<RX`1W5A<F1E:2!O(")S
M8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R!E;3H@(B5S(BX`5&5M<&]R86ES+50@
M1&ES<&5R<V]S`$-IZFYC:6$`4')O8W5R87(`36]T;W)E<R!D92!0<F]C=7)A
M`%!R;V-U<F%N9&\@87!L:6-AY_5E<R`H;?-D=6QO<RD@2&]R9&4@96T@)7,`
M4')O8W5R86YD;R!O<R!B:6[A<FEO<R!D92!G971T97AT+BXN`%-E;&5C8VEO
M;F%R($%R<75I=F]S`%-E;&5C8VEO;F4@=6UA(&1A=&$`4V5L96-C:6]N92!U
M;2!G<G5P;R!A(&%C<F5S8V5N=&%R`%-E;&5C8VEO;F%R('5M(&YO=F\@9&]N
M;P!396QE8V-I;VYE('5M('-E<G9I9&]R`%-E;&5C8VEO;F4@=6T@=71I;&EZ
M861O<B!A(&%D:6-I;VYA<@!396QE8V-I;VYE('1O9&]S(&]S(&-O;7!O;F5N
M=&5S(&1A(&1A=&$N`%-E;&5C8VEO;F4@=6T@;V)J96-T;P!396QE8V-I;VYE
M(&]S(&-A<F%C=&5R97,@;F%S(&-A:7AA<R!A8F%I>&\N(%!O9&5RX2!E;G3C
M;R!C;W!IX2UL;W,@92!C;VSA+6QO<R!N82#A<F5A(&1E('1E>'1O+@!396QE
M8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&$@9&%T83H`4V5L96-C:6]N92!O(&9O
M<FUA=&\@9&$@9&%T83H`4V5L96-C:6]N92!A(&ED96YT:61A9&4@<75E('!R
M971E;F1E(&%L=&5R87(Z`%-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D87,@
M:&]R87,Z`%-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&AO<F$Z`%-E;&5C8VEO
M;F4@9&]I<R!C86UP;W,@<F5L86-I;VYA9&]S+@!%<V-O;&AA(&\@<V5U(&-O
M;FIU;G1O(&1E(&-O<F5S+@!396QE8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F
M97)I9&\Z`$5N=FEA<B!296QA=/-R:6\@9&4@4')O8FQE;6%S`$5N=FEA<B!3
M35,`4F5P^F)L:6-A(&1O(%-E;F5G86P`(%-E;G-O<CH@`%-E=&5M8G)O`%/I
M<G9I82!E($UO;G1E;F5G<F\`3OIM97)O(&1E(%/I<FEE`$1A9&]S(&1O('-E
M<G9I9&]R(&5R<F%D;W,@;W4@:6YD:7-P;V[M=F5I<RX`240@9&4@<V5S<^-O
M(&5X<&ER;W4N`$%T<FEB=6ER`$5S=&%B96QEYV$@;W#G]65S('%U92!L:&4@
M<&5R;6ET86T@<F5I;FEC:6%R(&$@<W5A('!A;&%V<F$M<&%S<V4@<V4@86QG
M=6UA('9E>B!D96QA('-E(&5S<75E8V5R+@!%<W!E8VEF:6-A<B!S97)V:61O
M<F5S(')E;6]T;W,@<75E(&1E<V5J82!A8V5D97(@;F\@<V5U('!O<G1A;"X`
M4V5L96-C:6]N92!O('-E=2!I9&EO;6$@<')E9F5R:61O+"!O('-E=2!F=7-O
M(&AO<N%R:6\@92!A<R!S=6%S(&]PY_5E<R!D92!D871A<RX`17-C;VQH82!A
M('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@;R!E<W%U96UA(&1E(&-O<F5S+"!O
M(')E9G)E<V-A;65N=&\@9&4@<.%G:6YA<R!E(&]U=')A<R!O<.?U97,@9&4@
M=FES=6%L:7IAY^-O+@!#;VYF:6=U<F%R`")38W)I<'1S(B!D92!A8W1U86QI
M>F'GXV\@9&ES<&]N[79E:7,`5N%R:6%S(&QO8V%L:7IAY_5E<R!P;W-S[79E
M:7,@8V]M(&\@<&%RXFUE=')O.B``4V5I8VAE;&5S`$-O;7!R87,`0G)E=F4@
M4W5MX7)I;P!$979E;2US92!D969I;FER('1E8VQA<R!D92!A8V5S<V\@<&%R
M82!A(&UA:6]R:6$@9&%S(&QI9V'G]65S/P!-;W-T<F%R`$UO<W1R87(@9&EF
M97)E;N=A<R!E;G1R92!A(&-O;F9I9W5R8>?C;R!G=6%R9&%D82!E(&%Q=64@
M9F]I(&%G;W)A(&=E<F%D82X`36]S=')A<B!M;VUE;G1O(&1A(/IL=&EM82!E
M;G1R861A(&YO('-I<W1E;6$_`$UO<W1R87(@;W#GXV\@<&%R82!P<F5S97)V
M87(@;R!O<FEG:6YA;`!-;W-T<F%R('!A;&5T90!-;W-T<F%R(&$@8F%R<F$@
M9&4@;65N=2!C;VT@87,@;W!E<F'G]65S('-O8G)E('1A8F5L87,_`$UO<W1R
M87(@;R!-96YU("5S(.`@97-Q=65R9&$_`$UO<W1R87(@82!C86EX82!D92!D
M:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D92!486)E;&$_
M`$UO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@
M9&4@5&%B96QA<P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O
M<')I961A9&5S(&1E($QI;FAA<R!D92!486)E;&$`36]S=')A<B!A(&-A:7AA
M(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!);6%G96T`36]S=')A
M<B!C87)R96=A;65N=&\`06=U86-E:7)O<P!!9W5A8V5I<F]S($UA=&EN86ES
M`$%G=6%C96ER;W,@5F5S<&5R=&EN;W,`06=U86-E:7)O<R!N82!6:7II;FAA
M;N=A`$5N8V]L:&5R`$5N8V]L:&$@;W4@;6]V82!O*',I(&)L;V-O*',I('9I
M>FEN:&\H<RD@<')I;65I<F\`4V5R<F$@3&7C;P!3=6)S8W)E=F5R`%-U8G-C
M<F5V82P@<V4@86EN9&$@;N-O(&5S=.$@<F5G:7-T861O`$%S<VEN871U<F$`
M06QG;W)I=&UO(&1E($%S<VEN871U<F$`4F5P^F)L:6-A(&1E(%-I;F=A<'5R
M80!486UA;FAO`%-A;'1A<B!-86YU=&5NY^-O`$[C;R!P<F]C97-S861O+BXN
M`$5S;&]VX7%U:6$`4F5P^F)L:6-A(&1A($5S;&]VZ6YI80!.979E`$YE=N-O
M`$YE=O5E<P!.97;U97,@36%T:6YA:7,`3F5V]65S(%9E<W!E<G1I;F]S`$%L
M='5R82!D92!N979E.B``36]S=')A<B!E<75I=F%L96YT92!N82#A9W5A.B``
M26QH87,@4V%L;VWC;P!3;VWA;&EA`$-A;N?U97,@92!0;V5M87,`4V5L96/G
MXV\@9&\@<V5N=&ED;R!D82!O<F1E;F'GXV\`16YD97)EYV\@9&4@;W)I9V5M
M`,%F<FEC82!D;R!3=6P`175R;W!A(&1O(%-U;"`H25-/+3@X-3DM,RD`1V7S
M<F=I82!D;R!3=6P@92!);&AA<R!386YD=VEC:"!D;R!3=6P`2&5M:7-FZ7)I
M;R!3=6P`17-P8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E<P!%<W!AYV\@
M96YT<F4@;R!C;VYT9?ID;R!E(&$@8F]R9&$@9&4@=6UA(&/I;'5L80!%<W!A
MYV%D;W(`17-P8>=A;65N=&\`17-P8>=A;65N=&\@92!E;F-H:6UE;G1O`%)E
M:6YO(&1E($5S<&%N:&$`0V]R<F5I;R!NXV\@<V]L:6-I=&%D;P!);G-E<FER
M($-A<F%C=&5R($5S<&5C:6%L`$1I=FED:7(@8^EL=6QA`$%D:6-I;VYA<B!C
M;VQU;F$`1&EV:61I<B!L:6YH80!$97-P;W)T;W,`4F5P^F)L:6-A($1E;6]C
M<N%T:6-A(%-O8VEA;&ES=&$@9&\@4W)I($QA;FMA`%!A9'+C;P!3=&%R(%1R
M96L`06YO(&1E(&EN[6-I;P!%<W1A9&\@;W4@4')O=NUN8VEA`%-T871U<P!%
M<W1A9&\@9&$@;&]C86QI>F'GXV\@)7,N+BX@`$9O<FUA=&\@9&4@87)M87IE
M;F%M96YT;P!%;F1E<F7G;R!D92!2=6$`4F%S=7)A9&\`3&ES=&$@9&4@8V%D
M96EA<R!D92!C87)A8W1E<F5S`%)E=&ER87(@9&]M[6YI;R!D;R!E;F1E<F7G
M;P!%<W1I;&\@6T-34UT`9&\`07-S=6YT;P!3=6)M971E<@!&;VD@<W5B;65T
M:61O('!E9&ED;R!P87)A(&%D:6-I;VYA<B`B)7,B(&%O('-I<W1E;6$N($[C
M;R!P;V1E<N$@96YT<F%R(&5N<75A;G1O(&\@<V5U('!E9&ED;R!NXV\@9F]R
M(&%P<F]V861O+@!);F9E<FEO<B#@(&QI;FAA`%-U8V5S<V\`(B5S(B!A9&EC
M:6]N861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N`$QI;7!E>F$@9&\@<VES
M=&5M82!D;W,@9&%D;W,@9&\@=71I;&EZ861O<B`B)7,B(')E86QI>F%D82!C
M;VT@<W5C97-S;RX`4F5M;^?C;R!D92`B)7,B(&-O;2!S=6-E<W-O+@!296UO
MY^-O(&1E("(E<R(@9&\@<VES=&5M82!C;VT@<W5C97-S;RX`0V]N9FEG=7)A
MY^-O(')E=F5R=&ED82!C;VT@<W5C97-S;RX@4F5C87)R96=U92!P87)A('9E
M<B!A<R!M=61A;N=A<RX`0V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A(&=U
M87)D861A(&-O;2!S=6-E<W-O+@!&:6-H96ER;R!D92!C;VYF:6=U<F'GXV\@
M9&4@<V%L=F%G=6%R9&$@)7,@9W5A<F1A9&\@8V]M('-U8V5S<V\N`"(E<R(@
M86-T=6%L:7IA9&\@8V]M('-U8V5S<V\`)7,@97-C<FET;R!C;VT@<W5C97-S
M;P!297#Z8FQI8V$@9&\@4W5DXV\`4F5S=6UO`$YA<V-E<B!D;R!3;VP`4/1R
M(&1O(%-O;`!3;VQA<F5N9V\`3F%S8V5R(&1O(%-O;`!.87-C97(O4/1R(&1O
M(%-O;`!.87-C97(@9&\@4V]L.B``4/1R(&1O(%-O;`!0]'(@9&\@4V]L.B``
M4W5P97)I;W(@X"!L:6YH80!3=7!O<G1E`%-U<FEN86UE`$%P96QI9&\`4W9A
M;&)A<F0@92!*86X@36%Y96X`4F5I;F\@9&$@4W5A>FELXFYD:6$`4F5I;F\@
M9&$@4W7I8VEA`%-U[>=A`$5R<F\@9&4@<VEN=&%X92!N;W,@=&5R;6]S(&1E
M('!R;V-U<F$`4F5P^F)L:6-A(,%R86)E(%/M<FEA`%1E;7!O<F%L+50`5&5M
M<&]R86PM5"!E(%9E;G1O<V\`5&5M<&]R86ES+50`5&5M<&]R86ES+50@36%T
M:6YA:7,`07)Q=6EV;R!44U8`5&%B96QA`%!R;W!R:65D861E<R!D82!486)E
M;&$`4')O<')I961A9&5S(&1A('1A8F5L80!&;W)M;W-A`$9O<FUO<V$`4F5P
M^F)L:6-A(&1O(%1A9&II<75I<W3C;P!486YZXFYI80!!;'9O.@!487)E9F%S
M`$[Z;65R;R!D92!496QE9F]N90!496UP97)A='5R82!D82#Z;'1I;6$@:&]R
M83H`5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!496UP97)A='5R83QB<B`O
M/B@E<T%L=&$E<R\E<T)A:7AA)7,I("9D96<[)7,`3R!M;V1E;&\@(B5S(B!N
MXV\@9F]I(&5N8V]N=')A9&\N`$%D;6EN:7-T<F'GXV\@9&4@36]D96QO<P!4
M97AT;P!!<&5N87,@5&5X=&\`06QI;FAA;65N=&\@9&\@=&5X=&\`5&]P;R!D
M;R!T97AT;P`UJ@!486EL86YDZG,@*%1)4RTV,C`I`%)E:6YO(&1A(%1A:6SB
M;F1I80!/8G)I9V%D;R!P;W(@=7-A<B!E<W1E('-I<W1E;6$N`$\@87)Q=6EV
M;R!D92!A:G5D82`E<R!P87)A("5S(&[C;R!E>&ES=&4@86EN9&$N($-R:6%N
M9&\@=6T@;F]V;RX`02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N[79E
M;"X`3R!E;F=E;FAO(&1E(&EN=&5G<F'GXV\@2&]R9&4O2V]L86(@;N-O('-U
M<&]R=&$@(B5S(@!/(')E9VES=&\@*")L;V<B*2!)35-0(&[C;R!P]&1E('-E
M<B!I;FEC:6%L:7IA9&\N`$$@8VQA<W-E($UA:6YT96YA;F-E.CH@;N-O(&9O
M:2!C87)R96=A9&$@8V]M('-U8V5S<V\`02!J86YE;&$@9&4@3W#G]65S(&9E
M8VAO=2X@4V'M;F1O+@!/(&%D;6EN:7-T<F%D;W(@=&5M(&1E(&-O;F9I9W5R
M87(@=6T@;65C86YI<VUO(&1E('!E<FUI<W/U97,@<&5R;6%N96YT92!S92!Q
M=6ES97(@=7-A<B!097)M:7-S]65S+@!!<&5N87,@;R!L861O(&EN9F5R:6]R
M`$\@;OIM97)O(&1E($E$(&1O(&-O;G1A8W1O(&[C;R!F;VD@97-P96-I9FEC
M861O+"!F;VD@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R
M861O(&YA(&)A<V4@9&4@9&%D;W,N`$\@8V]N=&%C=&\@9F]I(&%D:6-I;VYA
M9&\@X"!L:7-T82!D92!C;VYT86-T;W,@8V]M('-U8V5S<V\N`$\@8FQO8V\@
M9&4@87-S:6YA='5R82!01U`@9&5S=&%C861O(.D@;F5C97-SX7)I;R!P87)A
M('9E<FEF:6-A<B!U;6$@;65N<V%G96T@87-S:6YA9&$N`$\@240@9&$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@
M9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A
M<V4@9&4@9&%D;W,N`$$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@
M97-P96-I9FEC861A+@!!<R!F=6YC:6]N86QI9&%D97,@9&4@96YC<FEP=&'G
MXV\@97AI9V5M('5M82!L:6=AY^-O('-E9W5R82X`3R!A<G%U:79O("5S(&1E
M=F5R:6$@8V]N=&5R('5M(&%T<FEB=71O("5S+@!/(&%R<75I=F\@)7,@9&5V
M97)I82!C;VYT97(@86QG=6YS(&%T<FEB=71O<R`E<RX`3R!F:6-H96ER;R!N
MXV\@<&]D92!S97(@8V]P:6%D;R!P87)A('-I('!R\W!R:6\N`$\@9FEC:&5I
M<F\@;N-O(&-O;G3I;2!D861O<RX`06)A:7AO(&5S=.-O(&]S(&-A8F7G86QH
M;W,@9&5S=&$@;65N<V%G96TO;65N<V%G96T@<F9C.#(R+@!/(&UO9&\@9&4@
M96-RXR!I;G1E:7)O(&-A=7-A('!R;V)L96UA<R!N;R!);G1E<FYE="!%>'!L
M;W)E<BP@9&5V:61O(&$@97)R;W,@;F\@;F%V96=A9&]R('%U92!NXV\@8V]N
M<V5G=6EM;W,@=6QT<F%P87-S87(N("!0;V1E('-U<F=I<B!L:7AO+"!P;V1E
M;2!D97-A<&%R96-E<B!F=6YC:6]N86QI9&%D97,@9&\@961I=&]R(&4O;W4@
M;R!S974@;F%V96=A9&]R('!O9&4@86)O<G1A<BX@4V4@;R!S974@<VES=&5M
M82#I('5M(%=I;F1O=W,@.7@L(.D@;75I=&\@<')O=N%V96P@<75E(&]B=&5N
M:&$@=6T@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@92!P<F5C:7-E(&1E
M(')E:6YI8VEA<B!O('-I<W1E;6$N7&Y<;D9O:2!A=FES861O+B`@4&]R(&9A
M=F]R('!R97-S:6]N92!/2R!S92!A:6YD82!A<W-I;2!Q=6ES97(@97AP97)I
M;65N=&%R(&\@961I=&]R(&1E(&5C<N,@:6YT96ER;RX`3R!F:6-H96ER;R!D
M92!A:G5D82`E<R!NXV\@8V]M9>=A(&-O;2`\/WAM;`!!(&ED96YT:61A9&4@
M(B5S(B!F;VD@<F5M;W9I9&$N`$%P96YA<R!O(&QA9&\@97-Q=65R9&\`02!L
M;V-A;&EZ8>?C;R!D;R!A<G%U:79O(&5X96-U=.%V96P@9&4@1VYU4$<@=&5M
M(&1E('-E<B!I;F1I8V%D82#@(&-L87-S92!#<GEP=%]P9W`Z.BX`02!M96YS
M86=E;2!E;G9I861A(&5M("5S('!A<F$@)7,@8V]M(&%S<W5N=&\@(B5S(B!F
M;VD@;6]S=')A9&$N"D[C;R!HX2!G87)A;G1I82!D92!Q=64@82!M96YS86=E
M;2!T96YH82!S:61O(')E86QM96YT92!L:61A(&]U(&-O;7!R965N9&ED82X`
M3R!N;VUE(&$@=7-A<B!Q=6%N9&\@;&EG86YD;R#@('#A9VEN82!D92!C;VUP
M;W-IY^-O`$\@;?-D=6QO(&]P96YS<VP@Z2!N96-E<W/A<FEO('!A<F$@82!C
M;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BX`02!O<.?C;R`B)7,B(&[C;R!P
M]&1E('-E<B!G=6%R9&%D82P@<&]I<R!O<R!S975S(&1A9&]S(&5X8V5D96T@
M82!D:6UE;G/C;R!MX7AI;6$@<&5R;6ET:61A`$\@<')O9W)A;6$@=7-A9&\@
M<&%R82!V97(@97-T92!T:7!O(&1E(&1A9&]S("@E<RD@;N-O(&9O:2!E;F-O
M;G1R861O(&YO('-I<W1E;6$N`$%P96YA<R!O<R!L861O<R!E<W%U97)D;R!E
M(&1I<F5I=&\`07!E;F%S(&\@;&%D;R!D:7)E:71O`$\@<V5R=FED;W(@(B5S
M(B!F;VD@<F5M;W9I9&\N`$\@<V5R=FED;W(@(B5S(B!F;VD@9W5A<F1A9&\N
M`$\@<&5D:61O(&1E('-U8G-C<FGGXV\@9&4@)7,@9F]I(')E;6]V:61O+@!!
M(&QI;FAA(&EN9&EC861A(&[C;R!E>&ES=&4N`$\@87)Q=6EV;R!T96UP;W+A
M<FEO("(E<R(@;N-O(&5X:7-T92X`07!E;F%S(&]S(&QA9&]S('-U<&5R:6]R
M(&4@:6YF97)I;W(`07!E;F%S(&\@;&%D;R!S=7!E<FEO<@!/<R!D861O<R!C
M87)R96=A9&]S('!E<F1E<F%M+7-E(&1E<V1E(&\@<&%S<V\@86YT97)I;W(N
M`$\@87)Q=6EV;R!C87)R96=A9&\@;N-O('#T9&4@<V5R(&=U87)D861O+@!/
M(&)L;V-O('=E871H97(N8V]M(&[C;R!E<W3A(&1I<W!O;NUV96PN`$[C;R!H
MX2!O<.?U97,@9&ES<&]N[79E:7,N`$[C;R!HX2!P87)T97,@<75E('!O<W-A
M;2!S97(@;6]S=')A9&%S(&5M(&QI;FAA+@!(X2!D96UA<VEA9&]S(&-A<F%C
M=&5R97,@;F5S=&4@8V%M<&\N($EN=')O9'5Z:74@)7,@8V%R86-T97)E<SL@
M=&5M(&1E(&EN=')O9'5Z:7(@;65N;W,@9&\@<75E("5S+@!.XV\@97AI<W1E
M(&%I;F1A('5M(&%R<75I=F\@9&4@86IU9&$@<&%R82`E<RX`3V-O<G)E=2!U
M;2!P<F]B;&5M82!N82!A9&GGXV\@9&4@(B5S(B!A;R!S:7-T96UA.B`E<P!/
M8V]R<F5U('5M('!R;V)L96UA(&%O(&QI;7!A<B!O<R!D861O<R!D;R!U=&EL
M:7IA9&]R("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B;&5M82!N
M82!R96UOY^-O(&1E("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B
M;&5M82!A;R!A8W1U86QI>F%R("(E<R(Z("5S+@!(;W5V92!U;2!P<F]B;&5M
M82!C;VT@;R!C87)R96=A;65N=&\@9&\@9FEC:&5I<F\Z("5S(&[C;R!F;VD@
M8V%R<F5G861O+@!/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M
M96YT;R!D;R!A<G%U:79O.B!/("5S(&5X8V5D92!O('1A;6%N:&\@;>%X:6UO
M('!E<FUI=&ED;R`H)60@8GET97,I+@!/8V]R<F5U('5M('!R;V)L96UA(&-O
M;2!O(&-A<G)E9V%M96YT;R!D;R!A<G%U:79O.B!/("5S(&9O:2!A<&5N87,@
M<&%R8VEA;&UE;G1E(&-A<G)E9V%D;RX`3V-O<G)E=2!U;2!E<G)O(&%O(&UO
M<W1R87(@97-T82!P87)T92!D82!M96YS86=E;0!/8V]R<F5U('5M(&5R<F\@
M86\@:6UP;W)T87(@9&%D;W,@9&4@8V]N=&%C=&\N`$]C;W)R974@=6T@97)R
M;R!A;R!I;7!O<G1A<B!D861O<R!I0V%L96YD87(N`$]C;W)R974@=6T@97)R
M;R!N;R!F;W)M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('1E;FAA
M(&]M:71I9&\@=6T@8V%M<&\@;V)R:6=A=/-R:6\N`$]C;W)R974@=6T@97)R
M;R!A;R!A8G)I<B!O(&%R<75I=F\@)7,N($5X<&5R:6UE;G1E(&5X96-U=&%R
M('1R86YS;&%T:6]N+G!H<"!C;VT@82!O<.?C;R`M9"!P87)A(&-O;G-E9W5I
M<B!V97(@87,@;65N<V%G96YS(&1E(&5R<F\@9&\@86YA;&ES861O<B!834PN
M`$]C;W)R974@=6T@97)R;R!A;R!R96%L:7IA<B!A(&9U;N?C;R!D92!L:79R
M;R!D92!E;F1E<F7G;W,@97-P96-I9FEC861A+B!0;W(@9F%V;W(@=&5N=&4@
M9&4@;F]V;R!M86ES('1A<F1E+@!/8V]R<F5U('5M(&5R<F\@86\@86-T=6%L
M:7IA<B!O<R!P;W)M96YO<F5S(&1O(&-O;G1A8W1O+B!0;W(@9F%V;W(@=&5N
M=&4@9&4@;F]V;R!M86ES('1A<F1E+@!/8V]R<F5U('5M(&5R<F\@86\@86-T
M=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E
M;G1E(&1E(&YO=F\@;6%I<R!T87)D92X`17-T92!S97)V:61O<B!)34%0(&[C
M;R!S=7!O<G1A('!A<G1I;&AA(&1E('!A<W1A<RX`3N-O('!A<F5C92!S97(@
M=6T@87)Q=6EV;R!R87(@=N%L:61O+@!.XV\@<&%R96-E('-E<B!U;2!A<G%U
M:79O('II<"!VX6QI9&\N`$[C;R!P87)E8V4@<V5R('5M82!N^FUE<F\@9&4@
M8V%R=.-O(';A;&ED;RX`17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV
M:6\@9&4@;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2P@=7-A;F1O(&$@05!)($A45%``17-T92!C;VYT
M<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@;65N<V%G96YS(&%T<F%VZ7,@
M9&\@<VUS,FUA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=7-A;F1O(&$@
M05!)($A45%``17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@
M;65N<V%G96YS('9I82!33510(&%T<F%VZ7,@9&$@5F]D869O;F4@273A;&EA
M(&4@87!E;F%S('!A<F$@;OIM97)O<R!6;V1A9F]N92X@17AI9V4@=6UA(&-O
M;G1A(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@;F$@5F]D869O;F4@273A;&EA
M("AH='1P.B\O=W=W+C$Y,"YI="DN`$5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I
M;RX`17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@:6YT96ER;W,N`$5S
M=&4@8V%M<&\@<&]D92!A<&5N87,@8V]N=&5R(&[Z;65R;W,@92!O('/M;6)O
M;&\@9&]I<RUP;VYT;W,N`$5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S
M('9A;&]R97,@;V-T86ES+@!%<W1E(&-A;7!O('1E;2!D92!C;VYT97(@=6UA
M(&QI<W1A(&1E(&EN=&5I<F]S('-E<&%R861O<R!P;W(@97-P8>=O<R!O=2!V
M[7)G=6QA<RX`17-T92!C86UP;R!T96T@9&4@<V5R('5M(&[Z;65R;R!VX6QI
M9&\N`$5S=&4@8V%M<&\@=&5M(&1E(&-O;G1E<B!U;2!C\V1I9V\@9&4@8V]R
M(&YO(&9O<FUA=&\@4D="(&AE>&%D96-I;6%L+"!P;W(@97AE;7!L;R`G(S$R
M,S1A9B<N`$5S=&4@;6]D96QO(&KA(&9O:2!P<F]C97-S861O+@!)<W1O(.D@
M)7,N`$5S=&4@Z2!U;2!O8FIE8W1O($MO;&%B($=R;W5P=V%R92X@4&%R82!V
M97(@97-T92!O8FIE8W1O('!R96-I<V$@9&4@=6T@8VQI96YT92!D92!C;W)R
M96EO(&5L96-T<O-N:6-O('%U92!C;VYH9>=A(&\@9F]R;6%T;R!+;VQA8B!'
M<F]U<'=A<F4N(%!A<F$@=6UA(&QI<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E
M:6\@96QE8W1R\VYI8V\@;F5S<V%S(&-I<F-U;G-TXFYC:6%S('9I<VET92`E
M<P!%<W1A(&UE;G-A9V5M(&9O:2!E<V-R:71A(&YU;2!C\V1I9V\@*"5S*2!D
M:69E<F5N=&4@9&\@<V5U+@!%<W1E(&[Z;65R;R!P<F5C:7-A(&1E('-E<B!P
M96QO(&UE;F]S('5M+@!%<W1E(")S8W)I<'0B('1E;2!S97(@97AE8W5T861O
M(&$@<&%R=&ER(&1E('5M82!L:6YH82!D92!C;VUA;F1O<RX`17-T92!S97)V
M:61O<B!NXV\@8V]N<V5G=64@9&5S8V]M<')I;6ER(&%R<75I=F]S('II<"!O
M=2!G>FEP+@!%<W1E('-I<W1E;6$@96YC;VYT<F$M<V4@9&5S86-T:79A9&\N
M`$5S=&$@=F%L;W(@=&5M(&1E('-E<B!U;2!N^FUE<F\N`$5S=&$@:F%N96QA
M('1E;2!D92!S97(@8VAA;6%D82!A('!A<G1I<B!D92!U;6$@:F%N96QA(&1E
M($]PY_5E<P!4<F]V;V%D80!":6QH971E<P!$871A+TAO<F$`4V5G=6EM96YT
M;R!496UP;W)A;`!&;W)M871O(&1O('1E;7!O`%-E;&5CY^-O(&1A=&$O:&]R
M80!4:6UO<BU,97-T90!4[71U;&\`5.UT=6QO("AD:6-A*3H`4&%R80!087)A
M('-E;&5C8VEO;F%R(&WZ;'1I<&QO<R!I=&5N<RP@8V%R<F5G=64@96T@0V]N
M=')O;"`H4$,I(&]U($-O;6UA;F0@*$UA8RD@96YQ=6%N=&\@8VQI8V%R+@!(
M;VIE`%1R;V-A<B!&;VYT92!(5$U,`%)E</IB;&EC82!4;V=O;&5S80!4;W%U
M96QA=0!!;6%N:.,`4F5I;F\@9&\@5&]N9V$`5&]P;P!-;VQD=7)A(&1E('1O
M<&\@*%]T;W`I`%1R861U>FED87,`5')A9'7G]65S`%1R:6YD861E(&4@5&]B
M86=O`%9E<F1A9&5I<F\@;W4@9F%L<V\`,ZH`4F5P^F)L:6-A(&1A(%1U;NUS
M:6$`4F5P^F)L:6-A(&1A(%1U<G%U:6$`5'5R8V\@*$E33RTX.#4Y+3DI`%1U
M<G%U96UE;FES=.-O`$EL:&%S(%1U<F-A<R!E($-A:6-O<P!4=79A;'4`17-C
M<F5V82!A('-U82!E<V-O;&AA.@#-;F1I8V4@52Y6+CH@`%523`!54DP@9&\@
M<V5U(')E;&%T\W)I;R!D92!E<W1A9&\@9&\@96YV:6\@9&4@(G-C<FEP=',B
M`%523#H`4F5P^F)L:6-A(&1O(%5G86YD80!58W+B;FEA`$[C;R!F;VD@<&]S
M<^UV96P@86-E9&5R(.`@<&%S=&$@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%D
M:6-I;VYA<B!I;F9O<FUAY^-O(&1E('5T:6QI>F%D;W(@97AT<F$@87%U86YD
M;R!D82!S=6)S8W)IY^-O+@!.XV\@9F]I('!O<W/M=F5L(&UU9&%R(&%S('!E
M<FUI<W/U97,@9&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E
M;"!M=61A<B!A<R!P97)M:7-S]65S(&1O(&%R<75I=F\@5D93("5S+R5S+@!.
MXV\@9F]I('!O<W/M=F5L(&UU9&%R('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV
M96P@;&EG87(@86\@<V5R=FED;W(@4U%,+@!.XV\@9F]I('!O<W/M=F5L(&QI
M9V%R('5S86YD;R!34TPN`$[C;R!F;VD@<&]S<^UV96P@8V]P:6%R(&\@87)Q
M=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!P87-T82!61E,@
M(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4RX`3N-O
M(&9O:2!P;W-S[79E;"!C<FEA<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O
M<W/M=F5L(&-R:6%R('5M(&%R<75I=F\@5D93('9A>FEO+@!.XV\@9F]I('!O
M<W/M=F5L(&1E<V-O;7!R:6UI<B!O<R!D861O<RX`3N-O(&9O:2!P;W-S[79E
M;"!R96UO=F5R("(E<R(L('!O:7,@82!P87-T82!NXV\@97-TX2!V87II82X`
M3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R("(E<R(Z("5S+@!.XV\@9F]I('!O
M<W/M=F5L(')E;6]V97(@)7,L('!O:7,@82!P87-T82!NXV\@97-TX2!V87II
M80!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,@<F5C=7)S
M:79A;65N=&4N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&
M4RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@5D93.B`E<RX`
M3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@87)Q=6EV;R!61E,@(B5S(BX`
M3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@87)Q=6EV;R!61E,N`$[C;R!F
M;VD@<&]S<^UV96P@<F5M;W9E<B!R96-U<G-I=F%M96YT93H@)7,N`$[C;R!F
M;VD@<&]S<^UV96P@9&5T97)M:6YA<B!A('!A<W1A(&-O<G)E;G1E+@!.XV\@
M9F]I('!O<W/M=F5L(&5X=')A:7(@;W,@<&]R;65N;W)E<R!D;R!C97)T:69I
M8V%D;P!);7!O<W/M=F5L(&QE<B!A(&1E9FEN:>?C;R!D92`E<RX`3N-O(&9O
M:2!P;W-S[79E;"!M;W9E<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M
M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E
M;"!A8G)I<B!O(&%R<75I=F\@5D93('!A<F$@97-C<FET82X`3N-O(&9O:2!P
M;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L
M(&%B<FER(&\@87)Q=6EV;R!C;VUP<FEM:61O+@!.XV\@8V]N<VEG;R!L97(@
M;R!A<G%U:79O.B``3N-O(&9O:2!P;W-S[79E;"!L97(@82!P87-T82!V9G-R
M;V]T+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R("5S(&-O;6\@)7,Z(&$@
M<&%S=&$@9&4@9&5S=&EN;R!JX2!E>&ES=&4`3N-O(&9O:2!P;W-S[79E;"!R
M96YO;65A<B!A('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A
M<B!A('!A<W1A(%9&4SH@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@
M;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R
M(&\@87)Q=6EV;R!61E,@)7,O)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE
M87(@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@97AE8W5T87(@)VUK
M:7-O9G,G+@!.XV\@9F]I('!O<W/M=F5L(&-O;G9E<G1E<B!E<W1E(&1O8W5M
M96YT;R!7;W)D`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@87)Q=6EV;R!6
M1E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!O(&%R<75I=F\@
M5D93("AC;W!Y*"D@9F%L:&]U*2X`3N-O(&-O;G-I9V\@<F5M;W9E<B`G)7,G
M.B`E<RX`4W5B;&EN:&%D;P!$97-F87IE<B!!;'1E<F'G]65S`$1E<V9A>B!A
M('-U82#Z;'1I;6$@86/GXV\`4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V
M:61O<B!N82!C;VYE>.-O.B``4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V
M:61O<B!A.B``4V5M(&-A=&5G;W)I80!5;FEC;V1E("A55$8M."D`16UI<F%D
M;W,@P7)A8F5S(%5N:61O<P!296EN;R!5;FED;P!%<W1A9&]S(%5N:61O<R!D
M82!!;>ER:6-A`$EL:&%S($UE;F]R97,@1&ES=&%N=&5S(&1O<R!%<W1A9&]S
M(%5N:61O<P!5;FED861E<P!$97-C;VYH96-I9&\`87!I;7-G:60@*$E$(&1E
M($UE;G-A9V5M(&1E($%022DN`&-L:6US9VED(&1E<V-O;FAE8VED;R`H240@
M9&4@365N<V%G96T@9&4@0VQI96YT92DN`$-O;6%N9&\@9&5S8V]N:&5C:61O
M.B`E<P!&;VD@9F]R;F5C:61A('5M82!L;V-A;&EZ8>?C;R!D97-C;VYH96-I
M9&$N`$YO;64@9&4@=71I;&EZ861O<B!O=2!P86QA=G)A+7!A<W-E(&5R<F%D
M;W,`4F5M;W9E<B!L:6=AY^-O(&1O(&5L96UE;G1O(&-O<G)E;G1E`%-E;2!N
M;VUE`%!O<B!R87KU97,@9&4@<V5G=7)A;N=A+"`B<V-R:7!T<R(@<V5M('!R
M:79I;.EG:6\@;N-O('!O9&5M(&%C961E<B!A($-O<G1A<B]#;W!I87(O0V]L
M87(@<')O9W)A;6%T:6-A;65N=&4N($-A<G)E9W5E(&5M($]+('!A<F$@=F5R
M('5M82!N;W1A('3I8VYI8V$@96T@;6]Z:6QL82YO<F<@<75E(&QH92!M;W-T
M<F%RX2!C;VUO(&%U=&]R:7IA<B!U;2`B<V-R:7!T(B!A(&%C961E<B!A;W,@
M<F5C;W)T97,N`%)E;6]V97(@8V]L;W)AY^-O`$5X=&5N<^-O(&[C;R!3=7!O
M<G1A9&$`4&]R('1R861U>FER`$UO9&EF:6-A<@!!8W1U86QI>F%R("5S`$%C
M='5A;&EZ87(@=71I;&EZ861O<@`B)7,B(&%C='5A;&EZ861O+@!!8W1U86QI
M>F%N9&\@87)Q=6EV;R!D92!A:G5D82`E<R!P87)A("5S+@`B4V-R:7!T(B!D
M92!A8W1U86QI>F'GXV\@<F5M;W9I9&\N`%5P;&]A9`!#87)R96=A9&]S(&YO
M('-E<G9I9&]R('1O9&]S(&]S(&%R<75I=F]S(&1E(&EN<W1A;&'GXV\@9&4@
M87!L:6-AY_5E<RX`3&5T<F%S(&QA=&EN87,@96T@;6%I^G-C=6QA<P!.^FUE
M<F]S(')O;6%N;W,@96T@;6%I^G-C=6QA<P!297#Z8FQI8V$@3W)I96YT86P@
M9&\@57)U9W5A:0!5=&EL:7IAY^-O.@!5<V%R(&\@0V]R<F5N=&4Z("5S`%5S
M87(@4U-,+@!5<V%R('-E(&\@;F]M92!D92!U=&EL:7IA9&]R(&]U(&$@<&%L
M879R82UP87-S92!F;W)E;2!D:69E<F5N=&5S(&YO('-E<G9I9&]R($E-4U`N
M`%5T:6QI>F%D;W(@)7,@;N-O(&5S=.$@875T;W)I<V%D;R!P87)A("5S+@!!
M9&UI;FES=')AY^-O(&1E(%5T:6QI>F%D;W)E<P!/<.?U97,@9&\@571I;&EZ
M861O<@!296=I<W1O(&1E(%5T:6QI>F%D;W)E<P!/(%)E9VES=&\@9&4@571I
M;&EZ861O<F5S(&5S=.$@:6YA8W1I=F\N`%!E<FUI<W/U97,@9&\@=71I;&EZ
M861O<@!.;VUE(&1E(%5T:6QI>F%D;W(`3R!.;VUE(&1E(%5T:6QI>F%D;W(@
M(B5S(B!JX2!E>&ES=&4N`$YO;64@9&4@571I;&EZ861O<CH`3F]M92!D92!5
M=&EL:7IA9&]R.B``571I;&EZ861O<F5S`%5T:6QI>F%D;W)E<R!D;R!S:7-T
M96UA.@!297#Z8FQI8V$@9&\@57IB97%U:7-TXV\`02!P87-T82!61E,@;N-O
M(&5X:7-T92X`075SZFYC:6$`07,@;&]C86QI>F'G]65S(';A;&ED87,@96YC
M;VYT<F%D87,@:6YC;'5E;3H`5F%L:61A9&4N`%9A;&]R(&5M(&UI;G5T;W,@
M82!P87)T:7(@9&5S=&4@:6YS=&%N=&4N`%9A;&]R(&5X8V5D92!O(&-O;7!R
M:6UE;G1O(&WA>&EM;R!D92`E<RX`5F%L;W)E<P!0;W-S[79E;"!V86QO<F5S
M(&$@97-C;VQH97(`5F%N=6%T=0!687)IX79E;`!696YE>G5E;&$`5F5R:69I
M8V'GXV\@9F%L:&]U("T@97-T82!M96YS86=E;2!P;V1E('1E<B!S:61O(&%D
M=6QT97)A9&$N`%9E<G/C;P!#;VYT<F]L;R!D92!697)S]65S`$%L:6YH86UE
M;G1O(%9E<G1I8V%L`$-A;.=O(%9E<G1I8V%L`%9E<G1I8V%L.@!-=6ET;R!!
M;'1O`%)E</IB;&EC82!3;V-I86QI<W1A(&1O(%9I971N86UE`%9I971N86UI
M=&$@*%9)4T-)22D`5FES=6%L:7IA<B`E<P!697(@=6UA('#A9VEN82!E>'1E
M<FYA`%9I<W5A;&EZ87(@8V]M;R`E<P!);&AA<R!6:7)G96YS($)R:73B;FEC
M87,`26QH87,@5FER9V5N<R!!;65R:6-A;F%S`%9I<VEB:6QI9&%D90!6:7-I
M8FEL:61A9&4Z(`!6;V1A9F]N92!)=.%L:6$@=FEA(%--5%``059)4P!!5$5.
MQ\-/(2$A(%)%34]602!/(")30U))4%0B($U!3E5!3$U%3E1%($1%("5S+@!7
M86QL:7,@92!&=71U;F$`079I<V\`079I<V\Z(``TJ@!0<F5V:7/C;R!D;R!4
M96UP;P!$861O<R!M971E;W)O;/-G:6-O<R!F;W)N96-I9&]S('!O<@!796%T
M:&5R+F-O;0!796(`4.%G:6YA`%-E;6%N86QM96YT90!"96TM=FEN9&$H;RD`
M0F5M+79I;F1A*&\I(&$@)7,`0F5M+79I;F1A*&\I+"`E<P!/8VED96YT86P@
M*$E33RTX.#4Y+3$I`$]C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A87)A`%%U
M92!A<&QI8V'GXV\@9&5V92!O("5S(&UO<W1R87(@87#S<R!A(&5N=')A9&$_
M`%%U86P@Z2!O(&-A<F%C=&5R92!D96QI;6ET861O<C\`475A;"#I(&\@8V%R
M86-T97)E(&1E(&-I=&'GXV\_`%%U92!F87-E<P!1=64@(G!L=6=I;G,B(&%C
M=&EV87(@<&%R82!A($5D:>?C;R!2:6-A+@!,87)G=7)A`$QA<F=U<F$@96T@
M=6YI9&%D97,@0U-3`$QA<F=U<F$@9&\@365N=2`E<R#@(&5S<75E<F1A("AT
M96T@969E:71O(&YA('!R\WAI;6$@96YT<F%D82DZ`$QA<F=U<F$@9&$@=&%B
M96QA`%5N:61A9&4@9&4@;&%R9W5R80!,87)G=7)A.@!7:6MI`%9E;G1O`%9E
M;G1O($UA=&EN86P`5F5L;V-I9&%D92!D;R!V96YT;R!E;2!N\W,`5F5N=&\Z
M`%9E;G1O.B``4V%B961O<FEA`$QI<W1A<R!D92!$97-E:F]S`%1R86)A;&AO
M`$5N9&5R9>=O("A%;7!R96=O*0!496QE9F]N92`H16UP<F5G;RD`17-C<F5V
M96YD;R!A<G%U:79O(&1E(&%J=61A(&%C='5A;&EZ861O('!A<F$@)7,N`%)E
M9F5RZFYC:6%S(&-R=7IA9&%S`%)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y=C,`
M571I;&EZ8>?C;R!D92!#:&%V92!%>'1E;F1I9&$@6#4P.78S`$YO;64@06QT
M97)N871I=F\@9&4@4W5J96ET;R!8-3`Y=C,`261E;G1I9FEC861O<B!#:&%V
M92!D92!3=6IE:71O(%@U,#EV,P!%>'1E;G/U97,@6#4P.78S`$%!`$%!04$`
M36%P82!986AO;R$`06YU86QM96YT90!)Z6UE;@!3:6T`4VEM+"!#;VYC;W)D
M;P!%<W3A(&5M($U/1$\@9&4@5$585"X@(%5S92!O(&)O=.-O(%L\/ET@<&%R
M82!T<F]C87(@<&%R82!O(&UO9&\@5DE354%,+@!.XV\@97-TX2!A=71E;G1I
M8V%D;RX`3N-O('!O9&4@=&5R(&\@8V%R86-T97)E("=<)R!N;R!S974@;F]M
M92!C;VUP;&5T;RX`3N-O(&EN=')O9'5Z:74@=6T@96YD97)EYV\@9&4@8V]R
M<F5I;R!E;&5C='+S;FEC;R!VX6QI9&\N`$[C;R!M87!E;W4@;F5N:'5M(&-A
M;7!O(&1O(&%R<75I=F\@:6UP;W)T861O('!A<F$@;W,@8V%M<&]S(&-O<G)E
M<W!O;F1E;G1E<R!E;2`E<RX`06-A8F]U(&1E('-A:7(N`%1E;2!D92!I;G1R
M;V1U>FER('5M(&[Z;65R;R!D92!T96QE;?-V96P@=N%L:61O+"!S\R!C;VT@
M9.UG:71O<RP@;6%S(&-O;2!U;2`G*R<@;W!C:6]N86P@<&%R82!O('!R969I
M>&\@:6YT97)N86-I;VYA;"X`5&5M(&1E(&EN=')O9'5Z:7(@=6T@=F%L;W(@
M=N%L:61O+@!496T@9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@8N%S:6-O
M('!A<F$@1&%T851R964@<V4@<75I<V5R('5S87(@4W5B<V-R:>?U97,`5&5M
M(&1E(&-O;F9I9W5R87(@=6T@;65C86YI<VUO(&)A<V4@<&%R82!O(%9&4RX`
M1&5V92!D97-C<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R
M96QA=/-R:6\N`%1E;2!D92!I;G1R;V1U>FER(&\@55),(&1O(')E8W5R<V\@
M<75E(&5S=&$@;&EG8>?C;R!S92!R969E<F4`5&5M(&1E('-E;&5C8VEO;F%R
M('5M('-E<G9I9&]R(&$@<F5M;W9E<BX`1&5V92!E<W!E8VEF:6-A<B!O('5T
M:6QI>F%D;W(@82!L:6UP87(N`$1E=F4@97-P96-I9FEC87(@;R!N;VUE(&1O
M('5T:6QI>F%D;W(@82!R96UO=F5R+@!496T@9&4@97-P96-I9FEC87(@;R!N
M;VUE(&1O('5T:6QI>F%D;W(@82!A9&EC:6]N87(N`%1E;2!D92!E<W!E8VEF
M:6-A<B!O('5T:6QI>F%D;W(@82!A8W1U86QI>F%R+@!496T@9&4@97-P96-I
M9FEC87(@82!A8^?C;R!A(&1E<V5M<&5N:&%R+@!496T@9&4@:6YT<F]D=7II
M<B!U;2!N;W9O(&YO;64@9&4@8V%T96=O<FEA+@!496T@9&4@9F]R;F5C97(@
M=6T@;OIM97)O(&1E('1E;&5F;VYE(&ET86QI86YO`$$@<W5A('-E<W/C;R`E
M<R!E>'!I<F]U+B!0;W(@9F%V;W(@96YT<F4@9&4@;F]V;RX`3R!S974@16YD
M97)EYV\@9&4@0V]R<F5I;R!%;&5C='+S;FEC;SH`3R!S974@96YD97)EYV\@
M(D1E.B(`02!S=6$@26YF;W)M8>?C;P!/('-E=2!E;F1E<F7G;R!)4"!P87)E
M8V4@=&5R(&UU9&%D;R!D97-D92!O(&EN[6-I;R!D82!S97-SXV\@)7,N(%!A
M<F$@9V%R86YT:7(@82!S=6$@<V5G=7)A;N=A+"!D979E(&%U=&5N=&EC87(M
M<V4@9&4@;F]V;RX`3R!3974@3F]M90!/('-E=2!M96-A;FES;6\@9&4@875T
M96YT:6-AY^-O(&[C;R!S=7!O<G1A(&%D:>?C;R!D92!U=&EL:7IA9&]R97,@
M;W4@97-T82!O<.?C;R!F;VD@9&5S86-T:79A9&$@<&]R(&%L9W5M(&]U=')O
M(&UO=&EV;RX`3R!S974@;65C86YI<VUO(&1E(&%U=&5N=&EC8>?C;R!NXV\@
M<W5P;W)T82!L:7-T86=E;2!D92!U=&EL:7IA9&]R97,@;W4@97-T82!O<.?C
M;R!F;VD@9&5S86-T:79A9&$@<&]R(&%L9W5M(&]U=')O(&UO=&EV;RX`3R!S
M974@;F%V96=A9&]R('!A<F5C92!T97(@;75D861O(&1E<V1E(&\@:6[M8VEO
M(&1A('-E<W/C;R`E<RX@4&%R82!G87)A;G1I<B!A('-U82!S96=U<F%NYV$L
M(&1E=F4@875T96YT:6-A<BUS92!D92!N;W9O+@!/('-E=2!N879E9V%D;W(@
M;N-O('-U<&]R=&$@97-T82!F=6YC:6]N86QI9&%D92X`3R!S974@;F%V96=A
M9&]R(&[C;R!S=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O+B!0<F5S
M<VEO;F4@0V]N=')O;"]#;VUM86YD("L@4"!P87)A(&EM<')I;6ER+@!&=7-O
M(&AO<N%R:6\@86-T=6%L.@!)9&5N=&ED861E('!A9'+C;SH`3F]M92!C;VUP
M;&5T;P!!('-U82!V97)SXV\@9&\@9V5T=&5X="#I(&1E;6%S:6%D;R!A;G1I
M9V$L(&[C;R!S=7!O<G1A;F1O(%!(4"!D92!F;W)M82!N871I=F$N($YE;2!T
M;V1A<R!A<R!C861E:6%S(&1E(&-A<F%C=&5R97,@<V5RXV\@97AT<F'M9&%S
M+@!!('-U82!N;W9A('!A;&%V<F$M<&%S<V4@<&%R82`E<R#I.B`E<P!!<R!S
M=6%S(&]PY_5E<R!F;W)A;2!A;'1E<F%D87,@873I(&%O(&9I;F%L(&1E<W1A
M('-E<W/C;RX`07,@<W5A<R!O<.?U97,@9F]R86T@86-T=6%L:7IA9&%S+@!!
M('-U82!P86QA=G)A+7!A<W-E(&9O:2!R96-R:6%D80!!('-U82!P86QA=G)A
M+7!A<W-E(&9O:2!R96-R:6%D82P@=F5R:69I<75E(&\@<V5U(&-O<G)E:6\@
M96QE8W1R\VYI8V\@92!E;G1R92!C;VT@82!S=6$@;F]V82!P86QA=G)A+7!A
M<W-E+@!/<R!S975S('-E<G9I9&]R97,@<F5M;W1O<SH`2G5G;W-LX79I80!:
M86ER90!:XFUB:6$`6FEM8F%B=>D`6FEP<'D`6T5S8V]N9&5R(%1E>'1O($-I
M=&%D;UT`6U)E;&%T\W)I;R!D92!0<F]B;&5M87-=(`!;36]S=')A<B!497AT
M;R!#:71A9&\@+0!;36]S=')A<B!497AT;R!#:71A9&\@+2`E<R!L:6YH87-=
M`%ML:6YH82`E<R!D92`E<UT`7T%D;6EN:7-T<F'GXV\`7T-O;G-O;&$`P7)?
M=F]R90!?4F5M;W9E<B!,:6YH80!?1W)U<&]S`$%?:G5D80!0<F]P<FEE9&%D
M97,@9&$@7TEM86=E;0!?16YT<F%R`%]386ER`%]-;V1I9FEC87(@3&EG8>?C
M;P!?3W#G]65S`%]097)M:7-S]65S`%]296UO=F5R($QI9V'GXV\N+BX`7T-O
M;F9I9W5R8>?C;P!0<F]P<FEE9&%D97,@9&$@7U1A8F5L80!?571I;&EZ861O
M<F5S`&-O;G1A8W1O<P!O8V]R<F5U('5M(&5R<F\Z`&-A;&5N9.%R:6\`8V%L
M;6\`8VQI<75E(&%Q=6D`9F5I=&\`9F%L:&]U`&1I;6EN=6EN9&\`9FEC:&5I
M<F\`96YC;VYT<F%D;SH@`&1O("5S("@E<RD@X',@)7,@)7,`<F%J861A<P!H
M.@!H:`!I;65D:6%T;P!E;2!L:6YH80!L:6YH87-=`$5R<F\@;6MI<V]F<R!C
M;VT@8_-D:6=O("5D(&%O(&-O;G-T<G5I<B!)4T\N`&UM`&YO;64`<V5M(&%L
M=&5R8>?U97,`;N-O(&5N8V]N=')A9&\`;N-O(&EM<&QE;65N=&%D80!A:6YD
M82!P;W(@:6UP;&5M96YT87(`8V%D97)N;R!D92!N;W1A<P!P97)C96YT86=E
M;0!P[7AE:7,`<W5B:6YD;P!M;W-T<F%R(&1I9F5R96[G87,`<VUS,F5M86EL
M('9I82!(5%10`'-S`&5S=.%V96P`;&ES=&$@9&4@=&%R969A<P!/(&9I8VAE
M:7)O(%!/('!A<F$@;R!L;V-A;&4@)7,@;N-O(&5X:7-T92X`:6YT<F]D=7IA
M(&$@<&%L879R82UP87-S92!D=6%S('9E>F5S+"!P87)A(&-O;F9I<FUAY^-O
M`'5N:69I8V%D;P!S96T@;F]M90!A8W1U86QI>F%D;P!S96QE8V-I;VYA9&$@
M<&5L;R!U=&EL:7IA9&]R`'9#87)D`%)E96YC.@!W96%T:&5R+F-O;0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]P=%]05"]H96QP+GAM;```````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`T,3<S-C(W-S<`,#(P,S8T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_>&UL
M('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+W!T
M7U!4+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,3,@:F%N($5X
M<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N
M97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@
M(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F
M(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L
M92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S
M('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N
M('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H
M96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@
M;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q
M=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@
M(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W
M(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A
M/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T
M;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE
M+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H
M:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H
M97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.
M879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H
M86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N
M879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N
M879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@
M8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@
M>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA
M;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X
M+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O
M;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O<F]?4D\O````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8R-S<W`#`Q-C<Q,0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]R;U]23R],0U]-15-304=%4R\`````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W
M-S<`,#(P-#<V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W)O7U)/
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,S<Q-0`Q,#0Q-S,V,C<W-P`P,C(Q-#``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0````!D````'````#P#``")
M````7`8```````"`"```*````($(```(````J@@```4```"S"```"````+D(
M```'````P@@```4```#*"```'P```-`(```1````\`@```@````""0``"```
M``L)```5````%`D```H````J"0``#````#4)```'````0@D``"D```!*"0``
M`@```'0)```%````=PD``!````!]"0``%````(X)```O````HPD```\```#3
M"0``)@```.,)```%````"@H```T````0"@``!0```!X*```0````)`H``!``
M```U"@``#P```$8*```+````5@H```\```!B"@``#````'(*```/````?PH`
M`!X```"/"@``(0```*X*```#````T`H```0```#4"@``#````-D*```*````
MY@H```4```#Q"@``$@```/<*```0````"@L```@````;"P``$````"0+```&
M````-0L```<````\"P```@```$0+```$````1PL```\```!,"P``!P```%P+
M```'````9`L```0```!L"P``!0```'$+```%````=PL```<```!]"P``$0``
M`(4+```(````EPL``!X```"@"P``!0```+\+```H````Q0L``"D```#N"P``
M$P```!@,```+````+`P``!$````X#```!````$H,```,````3PP``!H```!<
M#```%P```'<,```7````CPP``!L```"G#```'P```,,,```3````XPP``!``
M``#W#```%P````@-```'````(`T```4````H#0``(0```"X-```<````4`T`
M``4```!M#0```P```',-```@````=PT``"8```"8#0``#````+\-```,````
MS`T```@```#9#0``!P```.(-```&````Z@T```T```#Q#0``"P```/\-```,
M````"PX```H````8#@```@```",.```&````)@X``$4````M#@``,````',.
M```0````I`X``!\```"U#@``$````-4.```/````Y@X```4```#V#@``6P$`
M`/P.```H````6!````D```"!$```!0```(L0```/````D1````8```"A$```
M!0```*@0```C````KA```!0```#2$```#P```.<0```(````]Q```!$`````
M$0``#0```!(1```1````(!$```@````R$0``*````#L1```"````9!$```8`
M``!G$0``%````&X1```0````@Q$``#$```"4$0``$@```,81```G````V1$`
M``4````!$@``&0````<2```&````(1(``!,````H$@``%````#P2```3````
M41(``!0```!E$@``$P```'H2```0````CA(``!(```"?$@``&0```+(2```F
M````S!(```,```#S$@``!````/<2```/````_!(``!(````,$P``!0```!\3
M```1````)1,``!(````W$P``!0```$H3```:````4!,```D```!K$P``"P``
M`'43```"````@1,```T```"$$P``'0```)(3```%````L!,```4```"V$P``
M!````+P3```)````P1,```0```#+$P``!P```-`3```/````V!,```8```#H
M$P``(@```.\3```'````$A0``"<````:%```,````$(4```4````<Q0```\`
M``"(%```$0```)@4```0````JA0```\```"[%```%````,L4```<````X!0`
M`!L```#]%```(@```!D5```;````/!4``!@```!8%0``%0```'$5```6````
MAQ4```8```">%0``!P```*45```6````K14``"@```#$%0``!0```.T5```#
M````\Q4``"(```#W%0``+@```!H6```4````218``!(```!>%@``"@```'$6
M```'````?!8```H```"$%@``'````(\6```1````K!8``!(```"^%@``$P``
M`-$6```"````Y18```4```#H%@``.@```.X6```[````*1<``!8```!E%P``
M&@```'P7```1````EQ<``!$```"I%P``$0```+L7```!````)`````````!.
M````'0```$\````7````10````<````B`````````$T````A`````````$L`
M``!B````"@```!$`````````#````#(```!3````,0`````````E````1@``
M`%T`````````4@```$(```!5`````````$<````L````+P```%8```!1````
M-0```!`````(````/@```$$```!?````*P````\````Y````2@```",````8
M````,P```$`````H````8`````L``````````````%0``````````````#T`
M```)`````````"X```!(````7````#H`````````#@````````!9````````
M`#8`````````&P```#\````<````&@````T````[``````````0````%````
M`````!(`````````$P````````!7````+0`````````F```````````````5
M````!@````````!;````-P```!D`````````7@`````````X````-```````
M``!)````'P```%H```!$`````````!X``````````````&,`````````6```
M`"D`````````,```````````````/````&0```!0`````````!8````@````
M``````,```!A````0P```"H````G````3`````(`````````%``````E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`#(T(&AO=7)S
M`$%-+U!-`$%D9"!P86ER`$%D9')E<W,`06QI87,`06X@:6QL96=A;"!V86QU
M92!W87,@<W!E8VEF:65D+@!!=F%I;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!#
M86QE;F1A<@!#86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&]S
M92!7:6YD;W<`0V]M<&%N>0!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!$1`!$86EL>0!$969A=6QT($ED96YT:71Y`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%;6%I;`!%;7!T>2!R97-U
M;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%
M=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V
M97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!&87@`2&5L<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!);7!O
M<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!,86YG=6%G90!,:7-T
M($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@
M9FEE;&1S`$UE<W-A9V4`36]N=&AL>0!.86UE`$YE=F5R`$YO=&5S`$]P=&EO
M;G,`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&5R9F]R;2!-86EN=&5N
M86YC92!/<&5R871I;VYS`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M;6%R
M>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M92!A;F0@<&%S<W=O<F0`4')O8FQE;2!$97-C<FEP=&EO;@!296UO=F4@<&%I
M<@!2971U<FX@=&\@3W!T:6]N<P!2;VQE`%-A=F4@3W!T:6]N<P!396QE8W0@
M=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!3
M96QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RX`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R
M;V)L96T@4F5P;W)T`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T
M97(@26YP=70`4W5C8V5S<P!487-K<P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:71L
M90!54DP`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE
M('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S
M`%5S97(@3W!T:6]N<P!5<V5R;F%M90!787)N:6YG`%=E96ML>0!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9
M`%EE87)L>0!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@26YF
M;W)M871I;VX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O
M8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!V0V%R9`!0<F]J96-T+4ED
M+59E<G-I;VXZ($A/4D1%(#(N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#@M,#$@,#DZ
M,S0K,#(Z,#`*3&%S="U4<F%N<VQA=&]R.B!#;W)N96QI=2!-55-!5"`\8VUU
M<V%T0&ME>7-Y<RYR;SX*3&%N9W5A9V4M5&5A;3H@4D]-04Y)04X@/&DQ.&Y`
M;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET"@`E<R!/<&5R871I=6YI(&1E(&UE;G1E
M;F%N=&$@+2!#;VYF:7)M87)E`#(T(&1E(&]R90!!32]030!!9&%U9V$@<&5R
M96-H96$`061R97-A`$%L:6%S`%,M82!S<&5C:69I8V%T(&\@=F%L;V%R92!I
M;F-O<F5C=&$N`$-I;7!U<FD@9&ES<&]N:6)I;&4Z`%II=6$@9&4@;F%S=&5R
M90!#86QE;F1A<@!296YU;G1A(&QA(%)A<&]R=`!496QE9F]N($UO8FEL`$EN
M8VAI9&4@9F5R96%S=')A`$-O;7!A;FEA`$YU('!O="!D97-C:&ED92!M;V1U
M;'5L(&1E($UE;G1E;F%N=&$@)7,`6EH`6FEL;FEC`$ED96YT:71A=&4@26UP
M;&EC:71A`$1E<V-R:64@<')O8FQE;6$`1&5T86QI:2!I;G)E9VES=')A=&4@
M:6X@3$]'('!E;G1R=2!A9&UI;FES=')A=&]R+@!/<'1I=6YI(&1E($%F:7-A
M<F4`5&4@<F]G(&YU(&%C8V5S82!D:7)E8W0@;6%I;G1E;F%N8V4N<&AP`$5M
M86EL`$5M<'1Y(')E<W5L="X@+2!D92!T<F%D=7,`17)O87)E`$\@9&%T82!L
M82`Q-2!M:6YU=&4`3R!D871A(&QA(#,P('-E8W5N9&4`3&$@9FEE8V%R92`U
M(&UI;G5T90!,82!F:65C87)E($-O;F5C=&%R90!/(&1A=&$@;&$@,S`@;6EN
M=71E`$EN(&9I96-A<F4@;6EN=70`17AE;7!L92!D92!V86QO<FDZ`$YU('!O
M="!C:71I('!R969E<FEN=&5L92X`3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R
M=F5R=6P@9&4@3$1!4"X`1F%X`$AE;'``061R97-A(&1E(&%C87-A`%1E;&5F
M;VYU;"!D92!A8V%S80!(;W)D90!#:6UP(&EM<&]R=&%T.B`E<P!#:6UP=7)I
M(&EM<&]R=&%T93H`3&EM8F$`3&ES=&$@<W5B:65C=&5L;W(@9&EN($AE;'``
M0V]N96-T87)E`$1E8V]N96-T87)E`$Q,`$-O<F5S<&]N9&5N=&$`0VEM<'5R
M:2!P;W1R:79I=&4@+2!D92!T<F%D=7,`365S86H`3'5N87(`3G5M90!.:6-I
M;V1A=&$`3F]T90!/<'1I=6YI`$%L=&4@:6YF;W)M871I:0!087)O;&$`17AE
M8W5T82!/<&5R871I=6YI;&4@9&4@365N=&5N86YT80!496QE9F]N`%1E(')O
M9R!S<&5C:69I8V$@=6X@<W5M87(@86P@<')O8FQE;65I+@!492!R;V<@:6YT
M<F]D=2!U;B!N=6UE(&1E('5T:6QI>F%T;W(@<VD@;R!P87)O;&$`1&5S8W)I
M97)E82!P<F]B;&5M96D`4W1E<F=E('!E<F5C:&5A`$EN87!O:2!L82!O<'1I
M=6YI`%)O;&4@+2!D92!T<F%D=7,`4V%L=F%Z82!/<'1I=6YI`$1E;&EM:71A
M=&]R(&1E(&1A=&$Z`$9O<FUA='5L(&1E(&%F:7-A<F4@82!D871E:3H`1F]R
M;6%T=6P@9&4@869I<V%R92!A(&]R96DZ`%-E;&5C=&5A>F$@9&]U82!C:6UP
M=7)I('!O=')I=FET92X`4V5L96-T96%Z82!L:6UB82!P<F5F97)A=&$Z`%1R
M:6UI=&4@4F%P;W)T(&1E($5R;V%R90!387)I('!E<W1E($UE;G1E;F%N=&$`
M0V%R86-T97)E(%-P96-I86QE("XN+@!3=6-C97,`4V%R8VEN:0!686QO87)E
M82!M:6YI;6$@97-T92`Q`$%C96%S=&$@=F%L;V%R92!T<F5B=6EE('-A(&9I
M92!N=6UE<FEC82X`5&ET;'4`55),`$YU(&UA('!O="!C;VYE8W1A(&QA('-E
M<G9E<G5L(%-13"X`3G4@<&]T('1R861U8V4@86-E<W0@9&]C=6UE;G0@5V]R
M9"`M(&1E('1R861U<P!!;G5L96%Z82!38VAI;6)A<FEL90!/<'1I=6YI(%5T
M:6QI>F%T;W(`571I;&EZ871O<@!!=&5N=&EE`%-A<'1A;6EN86P`0FEN92!A
M:2!V96YI="!I;B!S:7-T96UU;"`E<P!":6YE(&%I('9E;FET+"`E<P!!9')E
M<V$@;&$@4V5R=FEC:74`5&5L969O;B!L82!397)V:6-I=0!!00!!;G5A;`!4
M<F5B=6EE('-A(&1E<V-R:6D@<')O8FQE;6$@:6YA:6YT92!D92!A('1R:6UI
M=&4@<F%P;W)T=6PN`%-E<VEU;F5A('1A(&1E("5S(&$@97AP:7)A="X@5&4@
M<F]G('-A(&9A8VD@3&]G($EN(&1I;B!N;W4N`$EN9F]R;6%T:6D@9&5S<')E
M('1I;F4`3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T92X`6U)A<&]R="!0<F]B
M;&5M85T`6VQI;FEA("5S(&1I;B`E<UT`=D-A<F0@+2!D92!T<F%D=7,`````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<G5?4E4O````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S<W`#`Q-C<R-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]R=5]252],0U]-15-304=%4R\`````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#(P-3$R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W)U7U)5+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,C,W-0`Q,#0Q-S,V
M,C<W-P`P,C(Q-C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0`````C`0``'````#0)``"%`0``3!(```````!@&```
M*````&$8```.````BA@```X```"9&```"````*@8```%````L1@``!,```"W
M&````P```,L8```)````SQ@```@```#9&```)````.(8```'````!QD```P`
M```/&0``+````!P9```.````21D```4```!8&0``%P```%X9```*````=AD`
M``\```"!&0``(P```)$9```4````M1D``!<```#*&0``%P```.(9```?````
M^AD```L````:&@``%0```"8:```Y````/!H``"P```!V&@``*@```*,:```1
M````SAH```@```#@&@``#@```.D:```*````^!H```@````#&P``!@````P;
M```5````$QL``!4````I&P``"@```#\;``!4````2AL``$0```"?&P``$P``
M`.0;```<````^!L```P````5'```$````"(<```'````,QP``!T````['```
M*0```%D<```&````@QP``!````"*'```$P```)L<```,````KQP``"@```"\
M'````@```.4<```%````Z!P```0```#N'```#0```/,<```0`````1T```8`
M```2'0``&````!D=```4````,AT``"\```!''0``"0```'<=```6````@1T`
M``\```"8'0``)@```*@=``!#````SQT```@````3'@``"P```!P>```$````
M*!X```H````M'@``%P```#@>```1````4!X```4```!B'@``#0```&@>```@
M````=AX```4```"7'@``$````)T>```/````KAX``!````"^'@``#P```,\>
M```+````WQX```\```#K'@``#````/L>```/````"!\```8````8'P``'@``
M`!\?```A````/A\```,```!@'P``!````&0?```,````:1\```<```!V'P``
M$````'X?```.````CQ\```(```">'P``#0```*$?```&````KQ\``!$```"V
M'P``!P```,@?```$````T!\```H```#5'P``(@```.`?```%`````R````0`
M```)(```#`````X@```*````&R````4````F(```"@```"P@```/````-R``
M`!````!'(```!@```%@@```/````7R```!(```!O(```$````((@```0````
MDR````<```"D(```"````*P@```.````M2```!8```#$(```$0```-L@```&
M````[2```!````#T(```#P````4A```(````%2$```8````>(0``!P```"4A
M```%````+2$```L````S(0```@```#\A```$````0B$``&@```!'(0``#P``
M`+`A```*````P"$```<```#+(0``!P```-,A```+````VR$```D```#G(0``
M"0```/$A```*````^R$```<````&(@``"0````XB```'````&"(```H````@
M(@``%@```"LB```$````0B(```4```!'(@``#````$TB```$````6B(```0`
M``!?(@``#````&0B```"````<2(```D```!T(@``!````'XB```3````@R(`
M``4```"7(@```@```)TB```'````H"(```X```"H(@``"@```+<B```1````
MPB(```@```#4(@``"0```-TB```*````YR(``!X```#R(@``*````!$C```*
M````.B,```L```!%(P``%````%$C```%````9B,``"D```!L(P``*````)8C
M```I````OR,``!````#I(P``!P```/HC```3`````B0```0````6)```!P``
M`!LD```>````(R0``!0```!")```#@```%<D```J````9B0```8```"1)```
M#````)@D```+````I20```4```"Q)```$0```+<D```8````R20```0```#B
M)```!````.<D```,````["0```8```#Y)```#P`````E```*````$"4```L`
M```;)0``&@```"<E```7````0B4``"<```!:)0``%P```((E```;````FB4`
M`!D```"V)0``'P```-`E```3````\"4``#\````$)@``-P```$0F``!7````
M?"8```4```#4)@``#0```-HF```M````Z"8```0````6)P``)0```!LG```?
M````02<``!T```!A)P``!@```'\G```$````AB<``!````"+)P``$P```)PG
M```7````L"<```8```#()P``!P```,\G```&````UR<```<```#>)P``-```
M`.8G```5````&R@```X````Q*```!0```$`H```)````1B@``"$```!0*```
M'P```'(H```?````DB@``#````"R*```+P```.,H```A````$RD``!P````U
M*0``!P```%(I```+````6BD```4```!F*0```@```&PI``!9````;RD```,`
M``#)*0``(````,TI```D````[BD``"8````3*@``#````#HJ```'````1RH`
M``8```!/*@``,@```%8J```$````B2H```P```".*@``"````)LJ```)````
MI"H```H```"N*@``!P```+DJ```9````P2H```<```#;*@```P```.,J```&
M````YRH```T```#N*@``"P```/PJ```O````""L```P````X*P``,0```$4K
M```_````=RL```P```"W*P``"@```,0K```"````SRL```8```#2*P```P``
M`-DK```9````W2L``$4```#W*P``,````#TL```2````;BP``!,```"!+```
M$````)4L```)````IBP``!<```"P+```%@```,@L```/````WRP``!\```#O
M+```%`````\M```0````)"T```\````U+0``#P```$4M```'````52T```4`
M``!=+0``"````&,M```(````;"T```P```!U+0``!@```((M```&````B2T`
M``0```"0+0``!P```)4M```%````G2T``%H!``"C+0``)0```/XN```*````
M)"\```H````O+P``!P```#HO```%````0B\```X```!(+P``"````%<O```)
M````8"\```T```!J+P``&````'@O```%````D2\```X```"7+P``,P```*8O
M```*````VB\```D```#E+P``#````.\O```*````_"\```D````',```'@``
M`!$P```3````,#````<```!$,```%@```$PP```C````8S````H```"',```
M"0```)(P``!"````G#```"0```#?,```*@````0Q```/````+S$```T````_
M,0``"@```$TQ```*````6#$```D```!C,0``!@```&TQ```8````=#$``!$`
M``"-,0``%````)\Q```A````M#$``#X```#6,0``%````!4R```8````*C(`
M``P```!#,@``"P```%`R```(````7#(``!4```!E,@``*@```'LR```'````
MIC(``!4```"N,@``"0```,0R```-````SC(``"(```#<,@```@```/\R```)
M`````C,```0````,,P``$0```!$S```4````(S,```<````X,P``&0```$`S
M```0````6C,``#8```!K,P``!P```*(S```F````JC,``!````#1,P``+```
M`.(S``!!````#S0```D```!1-```#````%LT```.````:#0```T```!W-```
M%0```(4T```)````FS0```4```"E-```$@```*LT```N````OC0```8```#M
M-```#P```/0T```/````!#4``!`````4-0``#@```"4U```4````-#4```X`
M``!)-0``#0```%@U```0````9C4```D```!W-0``(P```($U```E````I34`
M``0```#+-0``!````-`U```)````U34```<```#?-0``&0```.<U```&````
M`38```<````(-@``#@```!`V```&````'S8```4````F-@``"0```"PV```)
M````-C8```D```!`-@``-````$HV```&````?S8```8```"&-@``#@```(TV
M```0````G#8```8```"M-@``#0```+0V```0````PC8```P```#3-@``"```
M`.`V```.````Z38``!8```#X-@``$P````\W```,````(S<```D````P-P``
M!````#HW```7````/S<``"<```!7-P``'P```'\W```%````GS<``!D```"E
M-P``"P```+\W```,````RS<```0```#8-P``!0```-TW```.````XS<```0`
M``#R-P```@```/<W```%````^C<``#(`````.```$````#,X```+````1#@`
M``D```!0.```"@```%HX```)````93@``!````!O.```$0```(`X```2````
MDC@``!$```"E.```$````+<X```1````R#@```X```#:.```#P```.DX```#
M````^3@```<```#].```#P````4Y```'````%3D```4````=.0``$@```",Y
M```#````-CD```T````Z.0``"P```$@Y```2````5#D```<```!G.0```@``
M`&\Y```)````<CD``!$```!\.0``"@```(XY```1````F3D```8```"K.0``
M!@```+(Y```&````N3D``"````#`.0``-````.$Y```%````%CH```T````<
M.@``!@```"HZ```'````,3H``"$````Y.@``(P```%LZ```R````?SH``!,`
M``"R.@``"0```,8Z```1````T#H```8```#B.@``"````.DZ```C````\CH`
M`!4````6.P``$````"P[```G````/3L```<```!E.P``#````&T[```,````
M>CL```@```"'.P``%@```)`[```?````ISL```@```#'.P``"0```-`[```3
M````VCL```4```#N.P``#P```/0[```+````!#P```X````0/```(````!\\
M```5````0#P``!\```!6/```)````'8\```>````FSP``!,```"Z/```$```
M`,X\```<````WSP``$T```#\/```10```$H]``!,````D#T```H```#=/0``
M$@```.@]```F````^ST```@````B/@``*0```"L^```B````53X``!D```!X
M/@``!@```)(^```&````F3X``!0```"@/@``#P```+4^```3````Q3X```8`
M``#9/@``!````.`^```&````Y3X```<```#L/@``*````/0^```B````'3\`
M`!0```!`/P``!@```%4_```,````7#\``!0```!I/P``%````'X_```7````
MDS\``#<```"K/P``*P```.,_```G````#T```"`````W0```!P```%A````2
M````8$````D```!S0```!````'U```!#````@D````,```#&0```)@```,I`
M```D````\4```"L````600``$@```$)!```&````54$```D```!<00``2```
M`&9!```,````KT$``!8```"\00``$````--!```0````Y$$``!````#U00``
M"P````9"```5````$D(```@````H0@```P```#%"```+````-4(``!4```!!
M0@``%````%="```E````;$(```0```"20@``,0```)="```Z````R4(```T`
M```$0P``#P```!)#```"````(D,```@````E0P```@```"Y#```4````,4,`
M`$@```!&0P``00```(]#```*````T4,``!8```#<0P``#P```/-#```)````
M`T0```P````-1```&0```!I$```)````-$0``!X````^1```$0```%U$```6
M````;T0``!$```"&1```"@```)A$```&````HT0```8```"J1```!0```+%$
M```)````MT0```4```#!1```"@```,=$```,````TD0```<```#?1```#P``
M`.=$```%````]T0```$```!:`````````)0`````````7``````````-`0``
M"@$``.L```##````&P````````#5````=0``````````````/P````````#7
M`````````$4```"C````"P```)<```"5````KP```!4`````````!P$``",!
M``#3````2P```+$`````````2@```/0````R````.@```&8```"'````/```
M`!H!````````T0```'X`````````A0```"8```"@````C0```(````!D````
M`````)@```#V``````````@`````````V0````````!/`````````&<```![
M``````````````",````7P````,!``"^````I````"``````````T@```((`
M`````````````&\```!V````7@```($````X`````````+L```!7````#P$`
M``````!'````G@````P```!J````IP`````````=`0``M0```,8```#I````
M````````````````!`$``!L!````````T````+T```#:````'@$``+8````7
M``````$``.\````9`0``,0```!X```!X````30```.T````3`0``5@```!0`
M``!A````_`````````#N`````````!````!C`````````"@```#"````````
M`#`````8`0````````````"2````/0``````````````40```)D```!8````
M(0````(!``#D````&@```*P````S````%0$``#8`````````W0````````"Y
M````#@$``&P```!]````N`````X```!;````'`$`````````````70```$X`
M``#8`````````'0```#U``````````````";`````````.4````0`0``````
M`!<!``!R````*0```(D```":````$@```/````"=````Q````,H````)`0``
MD0`````````=````MP```)8```!P````4@```"<```#W````J0```.,````&
M`0```````````````````````.@```#B````(`$``(,````?````SP```-0`
M``"3````1@`````````#````S0```&(````E````I0```&D```!_````````
M`(8```#,`````````"H``````````````,<```"?````/@````4`````````
M=P```#D```"$````^````$,````N````R0```,4`````````+P````````#Z
M`````````&X```"T````_@`````````?`0``%`$``!@````)````LP``````
M``!4````C@``````````````JP```&````"H````<0```/T```"J````^0``
M`/$```!K````WP```-P`````````$P````<````(`0``+0``````````````
MX0``````````````"@```!$!``!0````OP`````````6`0``^P```.P```#;
M``````````T```#6```````````````D`````````.<```"P````_P````0`
M``"(`````@```"(!```C`````````.````!$````20```%,```!S````K0``
M`)P```"B````#P````````"+`````````(H`````````$0```&T`````````
M`````,$```#>````%@````L!``!"````2````!P```#.````CP```+(`````
M```````````````9````.P```%D`````````-P`````````%`0``D````'P`
M``!,````>0```.8`````````H0```+P```!E````:````"(````A`0``````
M`/,```!5````>@````````"N`````````/(`````````0`````8````,`0``
M$@$``#0```````````````````"F````P````"P````K````RP```#4`````
M````00```,@```#J`````````````````````0$```````"Z`````"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,3(@2&]U<B!&
M;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`04TO4$T`06-C;W5N="!)
M;F9O<FUA=&EO;@!!9&0`061D($AE<F4Z`$%D9"!P86ER`$%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<P!!9&UI;FES=')A=&EO;@!!;&EA<P!!;&P@075T:&5N=&EC871E9"!5<V5R
M<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E
M<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P<&QI8V%T:6]N`$%P
M<&QI8V%T:6]N(&ES(')E861Y+@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%V86EL86)L92!F:65L
M9',Z`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0V%L96YD
M87(`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#871E9V]R:65S(&%N
M9"!,86)E;',`0V5L;"!0:&]N90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAO;W-E
M($%P<&QI8V%T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-L
M;W-E(%=I;F1O=P!#;VQL87!S92!3:61E8F%R`$-O;7!A;GD`0V]N9FEG=7)A
M=&EO;B!I<R!O=70@;V8@9&%T92X`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,`0W)E871E`$-R96%T92!A(&YE=R!O;F4`0W)E
M871O<B!097)M:7-S:6]N<P!#=7)R96YT(%1I;64`0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!$1`!$86EL>0!$871E`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<F5C=&]R
M>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F
M:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE
M8VL@=&AI<R!B;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S`$5D:70`161I="!"
M;&]C:P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%;6%I;`!%;7!T>2!R97-U;'0N`$5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$5X<&%N9`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&:6QE`$9I;&4@
M36%N86=E<@!&:6QT97)S`$9U;&P@1&5S8W)I<'1I;VX`1VQO8F%L($]P=&EO
M;G,`1V\`1V]O9VQE(%-E87)C:`!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`
M2&5A9&5R<P!(96QP`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.@!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H
M;VYE`$AO<F1E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y
M)W,@;F%M93H`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F1I=FED=6%L(%5S97)S`$QA7WEO
M=70`3&%N9W5A9V4`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87EO=70`3&ES="!(96QP(%1O<&EC
M<P!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G
M:6X`3&]G:6X@5&%S:W,`34T`36%I;`!-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-871C:&EN
M9R!F:65L9',`365N=2!M;V1E.@!-97-S86=E`$UO;G1H;'D`36]O;B!0:&%S
M97,`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V
M92!D;W=N`$UO=F4@=7``37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T
M:6]N`$YA;64`3F5V97(`3F5W($-A=&5G;W)Y`$YE=W,`3F5X=`!.97AT(&]P
M=&EO;G,`3F\`3F\@=F%L=65S`$YO;F4`3F]R=&AE<FX@2&5M:7-P:&5R90!.
M;W1E<P!/2P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9V%N:7II;F<`3W1H
M97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N<P!097)S;VYA;"!);F9O<FUA=&EO;@!0:&]N90!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!R979I;W5S(&]P=&EO;G,`4')O8FQE
M;0!0<F]B;&5M($1E<V-R:7!T:6]N`%)E860`4F5F<F5S:`!2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M
M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E('!A:7(`4F5S
M970`4F5T=7)N('1O($]P=&EO;G,`4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M`%)O;&4`4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C="!A('-E<G9E
M<@!396QE8W0@86QL`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9F]R
M;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z
M`%-E;F0@4')O8FQE;2!297!O<G0`4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T
M:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H
M96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO
M;G,N`%-E='5P`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E
M(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!L87-T(&QO9VEN
M('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H<FEN
M:P!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4V]U=&AE<FX@2&5M:7-P:&5R90!3
M<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=&%T=7,`4W5B:F5C=`!3=6)M:70`
M4W5C8V5S<P!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6YR:7-E
M+U-U;G-E=`!487-K<P!497AT($]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@
M<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AI<R!N
M=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BX`5&EC:V5T<P!4:6UE(&9O<FUA=`!4:71L90!4;P!4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!54DP`
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5P9&%T
M90!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+@!5<V5R`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5<V5R;F%M93H`
M57-E<FYA;64Z(`!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`
M5V%R;FEN9P!796(`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=O<FL@
M061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E
M<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO
M=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF
M;W)M871I;VX`66]U<B!.86UE`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO
M=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`
M6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T
M:6]N`%]'<F]U<',`7TAE;'``7TQO9R!O=70`7T]P=&EO;G,`7U!E<FUI<W-I
M;VYS`%]3971U<`!?57-E<G,`961I=`!U;FYA;65D`'9#87)D`%!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@=C,N,2U20S,*4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#8M,#(M,#<@,3$Z,3`K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R
M+3$W(#$W.C`P*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!!;&5X97D@6F%K:&%R
M;W8@/&)A8F5R0&UO<V=A+FYE=#X*3&%N9W5A9V4M5&5A;3H@4G5S<VEA;B`\
M:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`SN_E\.#VZ/\@[^[DY.7PYNKH("5S
M("T@S^[D\N+E\.;DY>WHY0`Q,BWWX/'NXN[I`#(T+??@\>[B[ND`,C0@]^#Q
MX`!!32]030#3]^7R[>#_(.?@[^CQ_`#$[N'@XNCR_`#$[N'@XNCR_#H`Q.[A
MX.+H\OP@[^#P\P#$[N'@XNCR_"!-;WII;&QA(%-I9&5B87(`P.3PY?$`P.3P
MY?'MX/\@ZNWHX^``S>#Q\O#NZ>KH("T@\_'RX.WNXNK@(._PX.(@Y.O_(.3P
M\^/H]2#O[NO\Y^[BX/+EZ^7I`-/O\.#BZ^7MZ.4`S_'EXN3N[>CL`,+QY2#B
M[OCEY/CHY0#"\>4@X_#S[^_[`,+QY2#O\.#BX`#0X.?PY?CH\OP@[N_E\.#V
MZ.@@\>X@\>_H\>K@[.@`P.O\\N7P[>#RZ.+M^^D@25--4`#/X/#NZ_PZ`,CL
M_R#O[NO\Y^[BX/+EZ_\@25--4#H`P?OK[B#SZN#GX.WN(.WEZN[P\.7J\NWN
MY2#G[>#WY>WHY2X`S_#HZ^[FY>WHY0#-X/'R\.[E[>X`Q^#O\.#XZ.+@\OP@
M[^[D\N+E\.;DY>WHY2#OY?#EY"#B^^_NZ^WE[>CE["#N[^7PX/;HZ2#NX?'K
M\^;HXN#MZ/\_`,_N[_ORZN`@\^3@Z^CR_"#MY?'S^>7Q\N+S_OGHY2#O\.#B
MX`#/[N_[\NK@(/#EY.#J\NCP[N+@\OP@[>7Q\_GE\?+B\_[YZ.4@[_#@XN``
MQ.[Q\O/O[?OE(._NZ_\Z`,3E[?P@\.[FY.7MZ/\`S>#Q\O#NZ>K@.@#0X/'X
MZ/#E[>CE`,K@Z^7MY.#P_`#.\NSE[>``SO+LY>W@(.[R]^7RX"#N(._P[N'K
MY>SE`,K@\N7C[O#HZ"#H(.SE\NKH`,KKY?+N]^W@_R#PX.3H[O'B_^?\`,W@
M\?+P[NGJZ"#H[.7MZ"P@X.3PY?'@+"#O[N3OZ/'H+@#.\NSE\OSRY2#TZ^#F
MZN#LZ"#N[^7PX/;H_BCHZ"DL(.KN\N[P^^4@POL@]>[RZ/+E(.[Q\_GE\?+B
MZ/+\+@#"^^'E\.CRY2#O\.CK[N;E[>CE.@#4[O#LX/(@[O+NX?#@YN7MZ/\@
MY.#R^SH`Q^#J\/OR_"#NZNWN`-/A\.#R_"#LY>W^`,KN[._@[>C_`,KN[?3H
MX_/PX/;H_R#S\?+@\.7KX`#-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT
M96YA;F-E7U1A<VL@)7,`T>[GY.#R_`#1[N?DX/+\(.WNXOOI(._P[O3HZ_P`
MT>[GY.#RY>O\`-+EZO/YY>4@XO#E[/\`Q^#DX/?H+"#GX._S\>K@Y>S[Y2#O
M\.@@XO7NY.4@XB`E<P#$Q`#%YN7D[>7B[>X`Q.#RX`#6XN7R(._N(//L[NOW
MX.WH_@#/\.[TZ.O\(._N(//L[NOWX.WH_@#3Y.#KZ/+\`-/DX.OH\OP@XOOA
M\.#M[?OI(._P[O3HZ_P`SN_H^.CRY2#O\.[AZ^7L\P#/[N3P[N'M[O'RZ"#A
M^^OH(.?@[^CQX.W[(.(@YO/P[>#K(.3K_R#@Y.SH[>CQ\O#@\N[PX"X`RN#R
MX.ONXP#.\N[A\.#FX/+\(.+PY>S_(.(@,C0M]^#Q[N+N["#T[O#LX/+E/P#$
M\//CZ.4@[>#Q\O#NZ>KH`,WE(.+[Y_OBX.GRY2!M86EN=&5N86YC92YP:'`@
M[>7O[O'PY>3Q\N+E[>WN`,(@[^7PXN[I(/'R\.[JY2#SZN#GX.W[(.CLY>W@
M(._NZ^7I/R#%\>OH(.3@+"#O[O'RX.+\\N4@X^#K[O?J\SH@`,?@X_#SY^CR
M_`#'X./P\^?H\OP@)7,`T.7DX.KRZ/#NXN#MZ.4`T.7DX.KRZ/#NXN#R_`#3
M\?+@[>[BZN`@[_#@XB#DZ_\@)7,`S>#Q\O#NZ>KH`$5M86EL`,WSZ^7B[ND@
M\.7G\^O\\N#R+@#*[NWRY>KQ\NWNY2#LY>W^(._N(.W@YN#RZ.@@[_#@XN[I
M(.KM[N_JZ"#L^_CH`,[XZ.'JX`#*X.;D^^4@,34@[.CM\_(`RN#FY/OE(#(@
M[.CM\_+[`,K@YN3[Y2`S,"#QY>KS[>0`RN#FY/OE(#4@[.CM\_(`RN#FY/OI
M(/#@YR#O\.@@XO7NY.4`RN#FY/OE(._NZ_?@\>``RN#FY//^(.SH[?/R\P#/
M\.CLY?`@Y^W@]^7MZ.DZ`-#@\?CH\.CR_`#"[O'Q\N#M[N+KY>WHY2#MX/'R
M\.[EZB#MY2#SY.#K[O'\+@#-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E
M\.[L($Q$05`N`-3@ZO$`U.#IZP#5\.#MZ.OH^>``U.CK_/+P^P#/[NOM[N4@
M[N_H\>#MZ.4@[_#NX>OE[/LZ`,_N\/+@ZP#/Y?#EZ?+H`,_NZ/'J(.(@1V]O
M9VQE`,/P\^_O^P##[O'R_`#'X./NZ^[BZN@`S^[D\>K@Y^K@`,_NZ_/XX/#H
MY0#-Z.;E(._PY>3Q\N#BZ^7MX"#H[?3N\.S@]NC_(.CG(/'@[.[C[B#MX/?@
MZ^`@].#IZ^`Z`,_N\/+@ZP#/[O#RX.L`Q.[LX/CMZ.D@X.3PY?$`Q.[LX/CM
MZ.D@\N7KY?3N[0#/[O#RX.L`TN[K_.KN(.CJ[NWJZ`#(ZN[MZN@@\2#RY>KQ
M\N[L`,CL_R#O\.[TZ.O_.@#*X/#RZ.WJZ`#([._N\/(L(/C@XR`E9`#([._N
M\/+H\.[BX.WN(._NZ^4Z("5S`,CL[^[P\NCP[N+@[?L@[^[K_SH`S^[K_.?N
MXN#RY>OH`-#@\>KKX.3JX`#?Y_OJ`,_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S
M`,_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S(/$@ZN[L[_S^\N7PX"`E<P#/\.7D
M^^3S^>CI(.+U[N0@[>4@Y^#TZ.KQZ/#NXN#M`,+[]>[D`-'OZ/'NZB#PX.?D
MY>ONXB#O[N3QZN#GZN@`R^[JX.OHY^#VZ/\`T.#Q[^[K[N;E[>CE`,+U[N0`
MPOOU[N0`T_?E\NW@_R#GX._H\?P`PO7NY`#,S`#/[O?RX`#-X/'R\.[IZN`@
M\>_H\>K@(.K@\N7C[O#HZ2#H(/;BY?+NXB#H]2#N\N[A\.#FY>WH_P#1[N+O
MX.3@_OGHY2#O[NO_`-#EYNCL(.SE[?XZ`-'N[N'YY>WHY0#%YN7LY?'_]^WN
M`-3@Y_L@R_/M^P#OY?#E[.7Q\NCR_"#B[>CG`._E\.7LY?'RZ/+\(.+KY>+N
M`._E\.7LY?'RZ/+\(.+O\.#B[@#OY?#E[.7Q\NCR_"#BXN7P]0#OY?#E[.7Q
M\NCR_"#B[>CG`._E\.7LY?'RZ/+\(.+BY?#U`-/WY?+MX/\@Y^#OZ/'\`,+@
M^.`@Z.WT[O#LX/;H_P#([/\`S>CJ[N/DX`#-[N+@_R#JX/+EX^[PZ/\`S>[B
M[O'RZ`#$X.OEY0#1Z^7D\_[YX/\@\?+PX.WH]N``S>7R`,WE(.[O\.7DY>OE
M[>X`+>WE(.+[X?#@[2T`T>7BY?#M[N4@[^[K\_C@\.CE`,?@[.7RZN@`3TL`
MS>#Q\O#NZ>KH`,W@\?+P[NGJZ"#DZ_\Z("5S`,[PX^#MX.GGY?``S_#N]^#_
M(.CM].[P[.#VZ/\`S^#P[NO\`,_@\.[K_`#/X/#NZ_P`SO'S^>7Q\N+KY>WH
MY2#N[^7PX/;HZ2#O[N3DY?#FZN@`POOO[NOMZ/+\(.[OY?#@]NCH(.[A\>OS
MYNCBX.WH_R#O\.@@XO7NY.4@XB#QZ/'RY>SS/P#/\.#BX`#/\.#BX"#D[O'R
M\^_@`,OH]^W[Y0#2Y>OE].[M`,+BY>3H\N4@[>#GXN#MZ.4@[>[B[ND@ZN#R
MY>/N\.CH.@#/[N;@Z_/I\?+@+"#Q[N[A^>CRY2#Q\_+\(._P[N'KY>S[+@#/
M[N;@Z_/I\?+@+"#BXN7DZ/+E(,+@^.@@Z.S_(._NZ_SG[N+@\N7K_R#H(._@
M\.[K_`#/\.7D^^3S^>#_(/'R\.#MZ/;@`,_P[N'KY>S@/P#.[^CQX.WHY2#O
M\.[AZ^7L^P#7Z/+@\OP`SN'M[N+H\OP`SN'M[N+K__+\(.3H[>#LZ/?E\>KH
MY2#O\^WJ\OL@[.7M_CH`SN'M[N+K__+\(.CM].[P[.#VZ/XZ`,_N]_+NXOOE
M(/'E\.+E\.``P.3PY?$@\>7PXN7PX"`H[>#O\.CLY?`@:'1T<#HO+VUA:6PN
M<G4I`-/DX.OH\OP`T^3@Z^CR_"#AZ^[J`-/DX.OH\OP@[^#P\P#1X?#N\>CR
M_`#"Y?#M\_+\\?\@ZB#MX/'R\.[IZN#L`,W@\?+P[NGJZ"#BZ.?SX.O\[>[C
M[B#PY>3@ZO+N\.``T?;E[>#PZ.D`T>[U\.#MZ/+\`-'N]?#@[>CR_"#MX/'R
M\.[IZN@`S^[H\>H`POOAY?#H\N4@\>7PXN7P`,+[X?#@\OP@XO'E`,[R[.7M
MZ/+\(.+[X>[P`,+[X>7PZ/+E(/#@Y^3EZ^CRY>O\(._NZ^7I(.3@\OLZ`,+[
MX>7PZ/+E(/3N\.S@\B#DX/+[.@#"^^'E\.CRY2#O\.[TZ.O\(.3K_R#MX/'R
M\.[IZN@Z`,+[X>7PZ/+E(.[R[N'PX.;E[>C_(/3N\.S@\B#B\.7LY>WH.@#"
M^^'E\.CRY2#DXN`@\>[B[^#DX/[YZ/4@[^[K_RX`PN#XX"#VXN7R[N+@_R#Q
M]>7LX`#?Y_OJ(.[R[N'PX.;E[>C_`,_N\>O@\OP@\>[NX?GE[>CE(.X@[_#N
MX>OE[.4`Q.[O[NOMZ/+EZ_SM^^4@[^[W\N[B^^4@\>7PXN7PX"P@ZB#J[O+N
M\/OL(.+[(/7N\NCRY2#H[.7R_"#D[O'R\^\@Z.<@S^[P\N#KX"X`T_'RX.WN
MXNK@(/_G^^K@(.+[XN[DX"P@XO#E[.7M[>[I(.?N[?L@Z"#T[O#LX/+@(.[R
M[N'PX.;E[>C_(.+PY>SE[>@N`-/Q\N#M[N+JX"#O\.CK[N;E[>C_(._N(//L
M[NOWX.WH_BP@]N+E\N[B[ND@\?7E[/L@Z"#O\.[WZ/4@[N_VZ.D@[O+NX?#@
MYN7MZ/\`S_#HZ^[FY>WH_P#*\.#RZN[E(.[A[N'YY>WHY3H`SN_PY>3EZ^CR
M_"#A^_'R\/OE(.KKX.+H^.@@Y.O_(/'Q^^ONZC\`S^[JX.?@\OP`S^[JX.?[
MXN#R_"#H[?3N\.S@]NC^(.X@[_#EY/OD\_GE["#B]>[DY3\`S^[JX.?@\OP@
M[.7M_B#N[^7PX/;HZ2#Q(/+@X>OH]N#LZ`#.\N[A\.#FX/+\(.SE[?X@)7,@
M\>OEXN`_`-'SY^CR_`#0X.?LY?``S_#N[_/Q\NCR_"#O[N3DY?#FZO,`WN;M
M[N4@[^[K\_C@\.CE`-'OY?;HX.O\[?OE(/'H[.+NZ_L`T?+@\O/Q`-+E[.``
MR/'JX/+\`-/Q[^7X[>X`T?+@\.#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE[>`@
MXB#TX.GK.B`E<P#-[N+@_R#J[NWTZ./S\.#VZ/\@\>[U\.#MY>W@(.(Z("5S
M`,+PY>S_(.+N\?7NY.`OY^#JX/+@`,?@Y.#WZ`#2[NO\ZNX@\N7J\?(`T>7P
MXN7P("5S(.'[ZR#SY.#KY>T`T>7PXN7P("5S(.'[ZR#Q[N?DX.T`S>7R(.3N
M\?+S[^W[]2#MX/'R\.[EZBX`T>[NX?GE[>CE(.(@[>7BY?#M[NP@].[P[.#R
MY2#H(.WE(.SNYN7R(.'[\OP@[O+NX?#@YN7M[@#.^.CAZN`@[_#H(.[R[N'P
MX.;E[>CH(/WR[ND@]^#Q\N@@\>[NX?GE[>C_`-WR[B#WZ/'K[B#MY2#L[N;E
M\B#A^_+\(.SE[?SXY2#EY.CMZ/;[+@#=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[
M\OP@]^CQZ^[L+@#'X._P[O'[`-3N\.S@\B#N\N[A\.#FY>WH_P#'X./NZ^[B
M[NH`RN[L\P#7\N[A^R#B^^'PX/+\(.WE\>KNZ_SJ[B#]Z^7LY>WR[N(L(//D
MY?#FZ.+@Z?+E(.W@YN#R[ND@ZNO@XNCF\R!#=')L`%523`#-Y>+NY^SNYNWN
M(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+@#-Y>+NY^SNYNWN(.?@X_#S
MY^CR_"#N[_#EY.7KY>WHY2`E<RX`W?+N\B#D[NKS[.7M\B!7;W)D(.WE(.SN
MYN7R(.'[\OP@[^7PY>+EY.7M+@#.\NSE[>CR_"#HY^SE[>7MZ/\`S_/Q\N[I
M`,_PZ.SE[>CR_`#(\>_NZ_SG\^7R\?\@Y?'KZ"#BX/CH(.CL_R_OX/#NZ_P@
MY.O_($E-4U`@\>7PXN7PX"#N\NOH]^#^\O'_(.[R(/+EZO/YZ/4`S^[K_.?N
MXN#RY>O\`,W@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\`R.S_(._NZ_SG[N+@\N7K
M_P#([/\@[^[K_.?NXN#RY>O_`,CL_R#O[NO\Y^[BX/+EZ_\`S_#N\>SN\O`@
M)7,`S^[JX.?@\OP@XN7A+?'R\.#MZ/;S`,+MZ.S@[>CE`,+EX0#%YN7MY>3E
MZ_SM[@#$[N'P[B#O[N;@Z^[BX/+\(.(@)7,`Q.[A\.X@[^[FX.ONXN#R_"P@
M)7,`U_+N(.[R[N'PX.;@\OP@[^[QZ^4@XO7NY.`@XB#QZ/'RY>SS.@#4X.?@
M`,K@ZNCE(.[O]NCH(.'SY//R(.3N\?+S[^W[(.(@XNCG\^#K_.WN["#PY>3@
MZO+N\.4`V.CPZ.W@(.SE[?X@)7,@\>OEXN`@*.'SY.7R(._PZ.SE[>7MX"#O
M\.@@\>OEY//^^>7L(.+U[N3E*0#0X.'N]^CI(.#D\.7Q`-#@X>[WZ.D@\N7K
MY?3N[0##PP#%YN7C[N3M[@#$X`#"^R#B^_CKZ"#HYR#QZ/'RY>S[+@#"^R#D
M[NOF[?L@[N_H\>#R_"#O\.[AZ^7L^RP@[_#EYN3E(/?E["#Q[.[FY?+E(.[R
M[O'KX/+\(/'N[N'YY>WHY2#N(.WEZ2X`PN#XX"`E<R#QY?'QZ/\@Y^#J[NWW
MZ.O@\?PN(,_NYN#K\^GQ\N`L(.+NZ>3H\N4@XB#QZ/'RY>SS(.?@[>[B[BX`
MPN#X($5M86EL.@#"X/@@X.3PY?$@[O+O\.#BZ/+EZ_\Z`,+@^.`@Z.WT[O#L
MX/;H_P#"X/CE(.CL_SH`U^#Q[N+NZ2#O[O_Q`,+@^"#O\.[TZ.O\(._N(//L
M[NOWX.WH_CH`PN#XY2#H[/\Z`,+@^.@@[>#Q\O#NZ>KH(.'[Z^@@[N'M[N+K
MY>W[+@#1\N[P[NWMZ.D@\>7PXN7P.@!;T>[NX?GE[>CE(.X@[_#NX>OE[.5=
M`%OQ\O#NZN`@)7,@Z.<@)7-=`-/O\.#BZ^7MZ.4`P_#S[^_[`,_N[.[Y_`#"
M^_7NY`#-X/'R\.[IZN@`S_#@XN``S_#HZ^[FY>WH_P#/[NO\Y^[BX/+EZ^@`
MS_#@XNCR_`#RY>KQ\B#Q[N[A^>7MZ/\`=D-A<F0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+W)U7U)5+VAE;'`N>&UL````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#0Q-S,V,C<W-P`P,C`S-S(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]X;6P@=F5R
M<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O<G5?4E4O
M:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@
M+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^
M"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI
M<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL
M('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I
M="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U
M"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U
M<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L
M:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@
M($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K
M('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M
M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L
M96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@
M5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ
M86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO
M=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P
M;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A
M<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B
M87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG
M871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@
M<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG
M871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG
M871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W
M965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@
M1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@
M268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@
M=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF
M(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T
M:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I
M8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]S:U]32R\`````````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#$V-S`S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+W-K7U-++TQ#7TU%4U-!1T53+P``````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,C<W-P`P
M,C`T-S``(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VM?4TLO3$-?
M34534T%'15,O:&]R9&4N;6\`````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#`T
M,3<S`#$P-#$W,S8R-S<W`#`R,C$S-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````&,'```<````-#L``-D)``!,
M=@```````+"=```.````L9T```\```#`G0``#0```-"=```(````WIT```L`
M``#GG0``#````/.=```$`````)X``!@````%G@``&P```!Z>```M````.IX`
M`!T```!HG@``)````(:>```I````JYX``!D```#5G@``)@```.^>```,````
M%I\``"0````CGP``#P```$B?```+````6)\```X```!DGP``!0```'.?```H
M````>9\```@```"BGP``"@```*N?```5````MI\``!(```#,GP``"P```-^?
M``"%````ZY\```X```!QH```"@```("@```-````BZ````X```"9H```$0``
M`*B@```-````NJ````P```#(H```#0```-6@```&````XZ```)0```#JH```
M"@```'^A```/````BJ$``!@```":H0``#````+.A```.````P*$```X```#/
MH0``"````-ZA```)````YZ$``"X```#QH0``&@```""B```R````.Z(``#@`
M``!NH@``5````*>B``!1````_*(``%H```!.HP``5P```*FC```T`````:0`
M``D````VI```#0```$"D```'````3J0```H```!6I```#P```&&D```%````
M<:0```8```!WI```$0```'ZD```(````D*0```D```"9I```"0```*.D```E
M````K:0``"````#3I```$P```/2D```0````"*4```\````9I0``"@```"FE
M```#````-*4```\````XI0``%````$BE```)````7:4```T```!GI0``$@``
M`'6E```9````B*4``!X```"BI0``#P```,&E```*````T:4```\```#<I0``
M"````.RE```D````]:4``!0````:I@``%@```"^F```(````1J8``$X```!/
MI@``+0```)ZF```9````S*8```<```#FI@``#````.ZF```L````^Z8```X`
M```HIP```P```#>G```+````.Z<```<```!'IP``!P```$^G```%````5Z<`
M``4```!=IP``"@```&.G```#````;J<``!<```!RIP``"@```(JG```/````
ME:<```X```"EIP``&````+2G```C````S:<```X```#QIP``%`````"H```7
M````%:@``!<````MJ```%P```$6H```3````7:@```\```!QJ```#@```(&H
M```?````D*@``!T```"PJ```!P```,ZH```&````UJ@```@```#=J```#P``
M`.:H```&````]J@```H```#]J```$P````BI```+````'*D``!`````HJ0``
M%0```#FI```5````3ZD```<```!EJ0``$````&VI```%````?JD``!$```"$
MJ0``#````):I```[````HZD``#@```#?J0``"0```!BJ```'````(JH```,`
M```JJ@``!0```"ZJ```0````-*H```D```!%J@``$P```$^J```Y````8ZH`
M`"<```"=J@``+````,6J```J````\JH``"4````=JP``"@```$.K```&````
M3JL```D```!5JP``!P```%^K```O````9ZL``#<```"7JP``+@```,^K``!5
M````_JL``"T```!4K```+0```(*L```]````L*P``#\```#NK```+0```"ZM
M``!`````7*T``",```"=K0``(P```,&M``!`````Y:T``"T````FK@``,P``
M`%2N```E````B*X``!4```"NK@``&0```,2N```I````WJX``"0````(KP``
M*````"VO```1````5J\```H```!HKP``#````'.O```*````@*\``!````"+
MKP``%@```)RO```6````LZ\```<```#*KP``!P```-*O```*````VJ\```@`
M``#EKP``)P```.ZO```(````%K````<````?L```!P```">P```&````+[``
M``4````VL```!P```#RP```&````1+````@```!+L```*0```%2P```.````
M?K````H```"-L```!````)BP```'````G;````D```"EL```!@```*^P```1
M````MK````<```#(L```%@```-"P```$````Y[````@```#LL```!@```/6P
M```-````_+````8````*L0``'@```!&Q```1````,+$```@```!"L0``#0``
M`$NQ```,````6;$```<```!FL0```P```&ZQ```#````<K$``!<```!VL0``
M$P```(ZQ```=````HK$```@```#`L0``!````,FQ```(````SK$```@```#7
ML0``00```."Q```:````(K(``"L````]L@``(````&FR```5````BK(```8`
M``"@L@``!@```*>R```5````KK(``!@```#$L@``(@```-VR```N`````+,`
M`!T````OLP``(0```$VS``!4````;[,``"D```#$LP``"@```.ZS```'````
M^;,``!4````!M```#@```!>T```*````)K0```\````QM```#0```$&T```/
M````3[0```T```!?M```"0```&VT```&````=[0``!@```!^M```$P```)>T
M```1````J[0``!0```"]M```!````-*T```&````U[0``!0```#>M```5```
M`/.T``!D````2+4```0```"MM0``#@```+*U```%````P;4```4```#'M0``
M$P```,VU```1````X;4``!$```#SM0``'`````6V```J````(K8``!````!-
MM@``(0```%ZV```%````@+8``!,```"&M@``"P```)JV```2````IK8```H`
M``"YM@``#P```,2V```-````U+8``!$```#BM@``$P```/2V```,````"+<`
M``8````5MP``#````!RW```&````*;<``!<````PMP``$````$BW```1````
M6;<```@```!KMP``!0```'2W```,````>K<``!````"'MP``!0```)BW```-
M````GK<```8```"LMP``!P```+.W```-````N[<```<```#)MP``"P```-&W
M```'````W;<```<```#EMP``"0```.VW```)````][<```H````!N```&0``
M``RX```]````)K@``!T```!DN```#````(*X```0````C[@```4```"@N```
M)0```*:X```2````S+@``!,```#?N```*P```/.X```[````'[D``"````!;
MN0``"````'RY```V````A;D``"$```"\N0``$````-ZY```(````[[D```P`
M``#XN0``!@````6Z```$````#+H```\````1N@``#@```"&Z```*````,+H`
M``T````[N@``'P```$FZ```<````:;H``"$```"&N@``'@```*BZ```9````
MQ[H``!X```#AN@``'0````"[```;````'KL``"`````ZNP``+@```%N[```F
M````BKL``!P```"QNP``'@```,Z[```<````[;L``"8````*O```*P```#&\
M```S````7;P``"8```"1O```*P```+B\```X````Y+P``!T````=O0``%0``
M`#N]```O````4;T``"````"!O0``$@```**]```I````M;T``!X```#?O0``
M(````/Z]```2````'[X``*(````RO@``%@```-6^```C````[+X``"@````0
MOP``*0```#F_```H````8[\``!\```",OP``%0```*R_```@````PK\``"4`
M``#COP``*`````G````M````,L```#````!@P```D@```)'````A````),$`
M`!8```!&P0``'````%W!```F````>L$``"H```"AP0``00```,S!``!$````
M#L(```P```!3P@``!P```&#"```'````:,(```8```!PP@``#0```'?"```0
M````A<(``!(```"6P@``$P```*G"```2````O<(```<```#0P@``!````-C"
M```0````W<(``!````#NP@``#````/_"```.````#,,```T````;PP``#P``
M`"G#```3````.<,```T```!-PP``*````%O#```#````A,,```T```"(PP``
M!@```);#```.````G<,```(```"LPP``20```*_#```%````^<,``!````#_
MPP``#P```!#$```$````(,0```T````EQ```#@```#/$```#````0L0```X`
M``!&Q```"````%7$```/````7L0```\```!NQ```!P```'[$```-````AL0`
M`!````"4Q```#0```*7$```+````L\0```8```"_Q```"P```,;$```,````
MTL0```H```#?Q```$0```.K$```9````_,0```L````6Q0``#0```"+%```B
M````,,4``!L```!3Q0``-````&_%```*````I,4``!@```"OQ0``&0```,C%
M```6````XL4``"(```#YQ0``#0```!S&```'````*L8``!0````RQ@``"P``
M`$?&```B````4\8``"\```!VQ@``"P```*;&```)````LL8``!D```"\Q@``
M"P```-;&```7````XL8``!<```#ZQ@``"0```!+'```6````',<```\````S
MQP``&0```$/'```6````7<<```X```!TQP``&````(/'```(````G,<```T`
M``"EQP``)@```+/'``!#````VL<```@````>R```$@```"?(```?````.L@`
M``@```!:R```"P```&/(```O````;\@```X```"?R```!0```*[(```&````
MM,@```,```"[R```!P```+_(```$````Q\@```H```#,R```"@```-?(```/
M````XL@``!````#RR```%P````/)```1````&\D``!D````MR0``%P```$?)
M```)````7\D```4```!IR0``"P```&_)```*````>\D```(```"&R0``!0``
M`(G)```-````C\D``!L```"=R0``%P```+G)```4````T<D```D```#FR0``
M#@```/#)```-````_\D``!(````-R@``.````"#*```@````6<H```@```!Z
MR@``#@```(/*``![````DLH``!@````.RP``&````"?+```1````0,L```<`
M``!2RP``!0```%K+```8````8,L``!X```!YRP``&P```)C+```9````M,L`
M`!L```#.RP``&0```.K+```3````!,P```<````8S```"````"#,```&````
M*<P```8````PS```$````#?,```/````2,P``!````!8S```#P```&G,```+
M````><P```\```"%S```#````)7,```/````HLP```<```"RS```!@```+K,
M```.````P<P```P```#0S```*````-W,```/````!LT```@````6S0``"```
M`!_-```3````*,T``!X````\S0``(0```%O-```@````?<T``!D```">S0``
M%P```+C-```E````T,T``!<```#VS0``%@````[.```$````)<X``!L````J
MS@``#0```$;.```,````5,X```,```!AS@``!0```&7.```(````:\X```H`
M``!TS@``#````'_.```+````C,X``!````"8S@``#````*G.```$````MLX`
M``0```"[S@``$P```,#.```4````U,X```P```#IS@``"0```/;.```.````
M`,\```L````/SP``&P```!O/```'````-\\```<````_SP``"@```$?/```-
M````4L\```D```!@SP``!````&K/```%````;\\```,```!USP``&````'G/
M```*````DL\```0```"=SP``)@```*+/```.````R<\``'P```#8SP``%0``
M`%70```%````:]````<```!QT```#````'G0```(````AM````H```"/T```
M!@```)K0```(````H=````(```"JT```!@```*W0```&````M-```!0```"[
MT```#0```-#0```0````WM```!L```#OT```!`````O1```)````$-$``!``
M```:T0``"0```"O1```)````-=$```4````_T0``&@```$71```(````8-$`
M``8```!IT0``&0```'#1```.````BM$```<```"9T0``!P```*'1```%````
MJ=$```D```"OT0``"@```+G1```"````Q-$```8```#'T0``"P```,[1```-
M````VM$```D```#HT0``!@```/+1```)````^=$```<````#T@``%`````O2
M```=````(-(``$(````^T@``)0```('2```E````I](```8```#-T@``"@``
M`-32```$````W](```D```#DT@``"````.[2```1````]](```D````)TP``
M!@```!/3```-````&M,```8````HTP``!````"_3```Y````--,``#T```!N
MTP``.@```*S3```>````Y],```4````&U```#@````S4```$````&]0```8`
M```@U```!P```"?4```A````+]0```T```!1U```!@```%_4```$````9M0`
M`!$```!KU```!@```'W4```*````A-0``"(```"/U```!````++4```%````
MM]0``!T```"]U```!````-O4```,````X-0```X```#MU```"@```/S4```(
M````!]4```D````0U0``!0```!K5```Z````(-4``#````!;U0``-0```(S5
M```I````PM4``$<```#LU0``.````#36```I````;=8``#\```"7U@``+@``
M`-?6```M````!M<``!\````TUP``#P```%37```2````9-<```L```!WUP``
M)@```(/7```I````JM<``"0```#4UP``)@```/G7```(````(-@```H````I
MV```"0```#38```'````/M@``"````!&V```(````&?8```F````B-@```H`
M``"OV```&0```+K8```I````U-@``!8```#^V```$@```!79```'````*-D`
M``H````PV0``#````#O9```/````2-D``!````!8V0``0````&G9``!P````
MJMD``&8````;V@``#@```(+:```)````D=H```H```";V@``$@```*;:```3
M````N=H```P```#-V@``!@```-K:```/````X=H``!(```#QV@``$`````3;
M```1````%=L``!P````GVP``(P```$3;``!J````:-L```\```#3VP``!0``
M`./;```0````Z=L```D```#ZVP``!`````3<```+````"=P``"`````5W```
M%````#;<```,````2]P```P```!8W```#P```&7<```5````==P``"D```"+
MW```*@```+7<```F````X-P``"<````'W0``*0```"_=```J````6=T``!D`
M``"$W0``0@```)[=```1````X=T``!(```#SW0``$P````;>```4````&MX`
M``\````OW@``%@```#_>```7````5MX``!````!NW@``$0```'_>```T````
MD=X``!,```#&W@``$@```-K>```U````[=X``!0````CWP``!P```#C?```,
M````0-\``"````!-WP``$````&[?```4````?]\``!$```"4WP``%P```*;?
M```<````OM\``!,```#;WP``%````._?```:````!.```!$````?X```&@``
M`#'@```>````3.```!H```!KX```$P```(;@```5````FN```!$```"PX```
M%P```,+@```4````VN```!<```#OX```%0````?A```)````'>$``!`````G
MX0``&0```#CA```$````4N$```<```!7X0``"P```%_A```1````:^$```8`
M``!]X0``!@```(3A```&````B^$```4```"2X0``!P```)CA```'````H.$`
M``4```"HX0``!@```*[A```&````M>$```0```"\X0``!````,'A```'````
MQN$```X```#.X0``#````-WA```,````ZN$```T```#WX0``"@````7B```.
M````$.(```4````?X@``*````"7B```.````3N(```P```!=X@``#P```&KB
M```*````>N(```@```"%X@``"0```([B```K````F.(```0```#$X@``"```
M`,GB```F````TN(``!(```#YX@``!@````SC```*````$^,```<````>XP``
M"````";C```@````+^,```D```!0XP``%````%KC```,````;^,```T```!\
MXP``#@```(KC```6````F>,``!$```"PXP``!@```,+C```#````R>,```8`
M``#-XP``&0```-3C```'````[N,```0```#VXP``"P```/OC```+````!^0`
M``<````3Y```!0```!OD```'````(>0``!8````IY```#0```$#D```-````
M3N0```H```!<Y```$````&?D```/````>.0``!$```"(Y```%P```)KD```*
M````LN0``!$```"]Y```"````,_D```$````V.0```\```#=Y```.@```.WD
M```%````*.4```P````NY0``'@```#OE```.````6N4``!````!IY0``"P``
M`'KE```,````AN4```D```"3Y0``!P```)WE```*````I>4```D```"PY0``
M#@```+KE```0````R>4``!L```#:Y0``&````/;E```:````#^8```H````J
MY@``"0```#7F```*````/^8```P```!*Y@``#P```%?F```(````9^8```8`
M``!PY@``'````'?F```'````E.8```4```"<Y@``"P```*+F``!'````KN8`
M``T```#VY@``"0````3G```$````#N<```,````3YP``$P```!?G```3````
M*^<``!,````_YP``"@```%/G```"````7N<```0```!AYP``)0```&;G```#
M````C.<```4```"0YP``*@```);G```*````P><```4```#,YP``!````-+G
M```*````U^<```T```#BYP``!@```/#G```(````]^<```@`````Z```!```
M``GH```%````#N@``&@````4Z```"0```'WH```,````A^@``!````"4Z```
M!0```*7H```&````J^@``!L```"RZ```+P```,[H```0````_N@```H````/
MZ0``#P```!KI```*````*ND```D````UZ0``$P```#_I```;````4^D``!@`
M``!OZ0``%P```(CI```?````H.D```X```#`Z0```P```,_I```'````T^D`
M``@```#;Z0``!P```.3I```*````[.D```L```#WZ0``!P````/J``!1````
M"^H``!````!=Z@``#````&[J```-````>^H``!H```")Z@``2@```*3J```9
M````[^H```8````)ZP``&@```!#K```E````*^L```8```!1ZP``!@```%CK
M```?````7^L```8```!_ZP``"0```(;K```8````D.L``!<```"IZP``*```
M`,'K```&````ZNL```T```#QZP``(@```/_K``!7````(NP``!,```!Z[```
M(P```([L```3````LNP```(```#&[```"P```,GL```(````U>P```T```#>
M[```"@```.SL```'````]^P``!0```#_[```!@```!3M```(````&^T```X`
M```D[0``!P```#/M```*````.^T```L```!&[0``,@```%+M```'````A>T`
M``P```"-[0``#0```)KM```,````J.T```D```"U[0``"0```+_M```*````
MR>T```<```#4[0``"0```-SM```'````YNT```H```#N[0``&P```/GM```2
M````%>X```H````H[@``%@```#/N```)````2NX``!````!4[@``!P```&7N
M```2````;>X```0```"`[@``!P```(7N```%````C>X```4```"3[@``"P``
M`)GN```4````I>X``!$```"Z[@``&@```,SN```6````Y^X``!0```#^[@``
M%P```!/O```8````*^\``!P```!$[P``&0```&'O```'````>^\```4```"#
M[P``#0```(GO```,````E^\``!$```"D[P``"````+;O```7````O^\```L`
M``#7[P``#````./O```?````\.\``!H````0\```$P```"OP```$````/_``
M``H```!$\```!````$_P```-````5/````P```!B\```!0```&_P```)````
M=?````4```!_\```!P```(7P```%````C?````0```"3\````@```)CP```X
M````F_```"P```#4\```$@````'Q```I````%/$``#(````^\0``"@```''Q
M```L````?/$``"X```"I\0``,P```-CQ```S````#/(``#@```!`\@``#P``
M`'GR```8````B?(``!````"B\@``#P```+/R```3````P_(``!4```#7\@``
M%````.WR```2`````O,``!0````5\P``%0```"KS```M````0/,``"T```!N
M\P``,0```)SS```N````SO,``"\```#]\P``+````"WT``!B````6O0``!,`
M``"]]```#0```-'T```(````W_0``!<```#H]```"`````#U```,````"?4`
M`"L````6]0``(0```$+U```:````9/4```D```!_]0``10```(GU``!!````
MS_4```0````1]@``$P```!;V```.````*O8``!,````Y]@``&````$WV```&
M````9O8```D```!M]@``"@```'?V```/````@O8``!````"2]@``!P```*/V
M```.````J_8```4```"Z]@``&P```,#V```(````W/8```8```#E]@``%```
M`.SV```1`````?<```X````3]P``.````"+W```"````6_<```8```!>]P``
M#@```&7W```%````=/<```<```!Z]P``#@```(+W```&````D?<``"@```"8
M]P``#````,'W```<````SO<```0```#K]P``*0```/#W```7````&O@``!\`
M```R^```7````%+X```4````K_@``#X```#$^```'P````/Y```0````(_D`
M``<````T^0``#@```#SY```,````2_D```P```!8^0``$P```&7Y```*````
M>?D``!T```"$^0``&0```*+Y```%````O/D``!$```#"^0``$0```-3Y```D
M````YOD``!(````+^@``%0```![Z```2````-/H```X```!'^@``&0```%;Z
M```(````</H```D```!Y^@``#0```(/Z```*````D?H```<```"<^@``#P``
M`*3Z```&````M/H```L```"[^@``&@```,?Z```*````XOH```<```#M^@``
M"````/7Z```%````_OH``!\````$^P``!@```"3[```0````*_L```@````\
M^P``#0```$7[```(````4_L``!X```!<^P``$@```'O[```L````COL``!H`
M``"[^P``"0```-;[```*````X/L``!4```#K^P``!0````'\```4````!_P`
M``0````<_```$````"'\```&````,OP```<````Y_```'@```$'\```H````
M8/P```H```")_```'````)3\```1````L?P```L```##_```&@```,_\```4
M````ZOP```0```#__```!`````3]```+````"?T```4````5_0``!@```!O]
M```(````(OT```8````K_0``&P```#+]```T````3OT``#0```"#_0``(```
M`+C]```I````V?T``"`````#_@``00```"3^```:````9OX``"@```"!_@``
M*0```*K^``!0````U/X``"(````E_P``!@```$C_```(````3_\```4```!8
M_P``"````%[_```9````9_\``!D```"!_P``*@```)O_```C````QO\``!D`
M``#J_P``+@````0``0`T````,P`!``@```!H``$`%P```'$``0`*````B0`!
M``<```"4``$`(0```)P``0`0````O@`!``X```#/``$`"P```-X``0`'````
MZ@`!`!,```#R``$`"`````8!`0`+````#P$!``H````;`0$`%````"8!`0`/
M````.P$!`#(```!+`0$`"P```'X!`0`%````B@$!``4```"0`0$`!0```)8!
M`0`7````G`$!``\```"T`0$`!````,0!`0`*````R0$!``D```#4`0$`"P``
M`-X!`0`-````Z@$!``P```#X`0$`#@````4"`0`%````%`(!``0````:`@$`
M#0```!\"`0`R````+0(!`$4```!@`@$`%P```*8"`0`'````O@(!`!X```#&
M`@$`%````.4"`0`%````^@(!`!0``````P$`!@```!4#`0`'````'`,!``X`
M```D`P$`*@```#,#`0`&````7@,!``P```!E`P$`#0```'(#`0`1````@`,!
M``L```"2`P$`-@```)X#`0`*````U0,!`"(```#@`P$`"P````,$`0`/````
M#P0!`#(````?!`$`)0```%($`0`P````>`0!`#$```"I!`$`+0```-L$`0`.
M````"04!``4````8!0$`#@```!X%`0`3````+04!`!(```!!!0$`!P```%0%
M`0`1````7`4!`!,```!N!0$`!P```((%`0`4````B@4!`!@```"?!0$`!P``
M`+@%`0`%````P`4!``P```#&!0$`#````-,%`0`2````X`4!``0```#S!0$`
M!P```/@%`0`*``````8!``L````+!@$`#````!<&`0`.````)`8!``X````S
M!@$`!0```$(&`0`%````2`8!`"X```!.!@$`)@```'T&`0`C````I`8!``,`
M``#(!@$`$@```,P&`0`&````WP8!`!X```#F!@$`&`````4'`0`E````'@<!
M``T```!$!P$`"0```%('`0`?````7`<!``,```!\!P$`!P```(`'`0`*````
MB`<!``(```"3!P$`#````)8'`0`5````HP<!``L```"Y!P$`&0```,4'`0`@
M````WP<!`!(`````"`$`!0```!,(`0`*````&0@!`!4````D"`$`$@```#H(
M`0`,````30@!``0```!:"`$`"0```%\(`0`'````:0@!``P```!Q"`$`4@``
M`'X(`0`7````T0@!`"0```#I"`$`$@````X)`0`'````(0D!``8````I"0$`
M#@```#`)`0`,````/PD!``T```!,"0$`%0```%H)`0`2````<`D!``\```"#
M"0$`%````),)`0`*````J`D!`!L```"S"0$`$````,\)`0`+````X`D!`&D`
M``#L"0$`&@```%8*`0`7````<0H!`"<```")"@$`&@```+$*`0`7````S`H!
M`!L```#D"@$`&0`````+`0`?````&@L!`!,````Z"P$`"````$X+`0`'````
M5PL!``@```!?"P$`"0```&@+`0`5````<@L!``T```"("P$`(P```)8+`0`-
M````N@L!`!,```#("P$`"````-P+`0`#````Y0L!`$8```#I"P$`/P```#`,
M`0`W````<`P!`%<```"H#`$`!0`````-`0`?````!@T!`"\````F#0$`"@``
M`%8-`0`(````80T!``T```!J#0$`+0```'@-`0`$````I@T!`$\```"K#0$`
M)0```/L-`0`<````(0X!``L````^#@$`'P```$H.`0`=````:@X!`"4```"(
M#@$`(````*X.`0`D````SPX!`"````#T#@$`"P```!4/`0`'````(0\!``T`
M```I#P$`#````#</`0`7````1`\!``8```!<#P$`.0```&,/`0`,````G0\!
M``<```"J#P$`"0```+(/`0`3````O`\!``D```#0#P$`!````-H/`0`0````
MWP\!``@```#P#P$`"````/D/`0`$`````A`!``L````'$`$`#````!,0`0`2
M````(!`!`!$````S$`$`#````$40`0`:````4A`!``\```!M$`$`!P```'T0
M`0`-````A1`!`!0```"3$`$`#@```*@0`0`,````MQ`!`"P```#$$`$`$P``
M`/$0`0`<````!1$!`"@````B$0$`!@```$L1`0`'````4A$!`!,```!:$0$`
M!0```&X1`0`$````=!$!`!<```!Y$0$`"@```)$1`0`,````G!$!``D```"I
M$0$`!@```+,1`0`)````NA$!``@```#$$0$`"0```,T1`0`*````UQ$!`!$`
M``#B$0$`!@```/01`0`.````^Q$!``X````*$@$`#0```!D2`0`+````)Q(!
M`!T````S$@$`"P```%$2`0`"````71(!`!P```!@$@$`!P```'T2`0`&````
MA1(!`&0```",$@$`"0```/$2`0`'````^Q(!`"8````#$P$`.````"H3`0`:
M````8Q,!`"H```!^$P$`.P```*D3`0`H````Y1,!`#0````.%`$`&0```$,4
M`0`5````710!``4```!S%`$`!P```'D4`0`(````@10!``<```"*%`$`!0``
M`)(4`0`'````F!0!``X```"@%`$`"0```*\4`0`&````N10!``@```#`%`$`
M"P```,D4`0`'````U10!``@```#=%`$`!P```.84`0`6````[A0!``D````%
M%0$`!@````\5`0`+````%A4!`!`````B%0$`!@```#,5`0`<````.A4!`!0`
M``!7%0$`!P```&P5`0`1````=!4!``@```"&%0$`#@```(\5`0`(````GA4!
M``4```"G%0$`$````*T5`0`0````OA4!``8```#/%0$`&0```-85`0`*````
M\!4!`!P```#[%0$`!P```!@6`0`%````(!8!`!`````F%@$`%````#<6`0`+
M````3!8!``T```!8%@$`*````&86`0`8````CQ8!`!<```"H%@$`!````,`6
M`0`)````Q18!``H```#/%@$`!P```-H6`0`"````XA8!``@```#E%@$`(P``
M`.X6`0`X````$A<!`"8```!+%P$`,0```'(7`0`G````I!<!`&0```#,%P$`
M%````#$8`0!5````1A@!`#@```"<&`$`2@```-48`0!;````(!D!`"@```!\
M&0$`.````*49`0`H````WAD!`"P````'&@$`)@```#0:`0`;````6QH!`#X`
M``!W&@$`J0$``+8:`0`C````8!P!`!<```"$'`$`2````)P<`0"%````Y1P!
M`#````!K'0$`)0```)P=`0!!````PAT!`%L````$'@$`20```&`>`0`Q````
MJAX!`!T```#<'@$`&````/H>`0`K````$Q\!`"$````_'P$`'P```&$?`0`K
M````@1\!`"$```"M'P$`)P```,\?`0`Z````]Q\!`!T````R(`$`$0```%`@
M`0`S````8B`!`"4```"6(`$`)P```+P@`0`@````Y"`!`!\````%(0$`,```
M`"4A`0!I````5B$!`#$```#`(0$`00```/(A`0`S````-"(!`"4```!H(@$`
M/0```(XB`0!E````S"(!`$T````R(P$`+P```(`C`0`N````L",!`#````#?
M(P$`5````!`D`0!:````920!`$@```#`)`$`2@````DE`0`R````5"4!`"\`
M``"')0$`+````+<E`0`M````Y"4!`'$````2)@$`9@```(0F`0!O````ZR8!
M`+,```!;)P$`%P````\H`0`E````)R@!`#(```!-*`$`*0```(`H`0`^````
MJB@!`"(```#I*`$`4@````PI`0`E````7RD!``L```"%*0$`L0```)$I`0!%
M````0RH!`"$```")*@$`,````*LJ`0`E````W"H!`!P````"*P$`,0```!\K
M`0`'````42L!``<```!9*P$`!````&$K`0`-````9BL!``L```!T*P$`#@``
M`(`K`0`+````CRL!``4```";*P$`$````*$K`0`"````LBL!`%D```"U*P$`
M!0````\L`0`2````%2P!``0````H+`$`!P```"TL`0`(````-2P!``4````^
M+`$``P```$0L`0`0````2"P!``P```!9+`$`$P```&8L`0`-````>BP!``(`
M``"(+`$`!P```(LL`0`&````DRP!``P```":+`$`&````*<L`0`&````P"P!
M`!(```#'+`$`#````-HL`0`#````YRP!`"H```#K+`$`!````!8M`0`&````
M&RT!``<````B+0$`'P```"HM`0`U````2BT!`"X```"`+0$`+P```*\M`0`7
M````WRT!`"(```#W+0$`)0```!HN`0`@````0"X!`!L```!A+@$`&````'TN
M`0`D````EBX!`!\```"[+@$`&@```-LN`0`A````]BX!`"`````8+P$`&@``
M`#DO`0`R````5"\!`!H```"'+P$`+P```*(O`0`K````TB\!`!\```#^+P$`
M(P```!XP`0`?````0C`!`!H```!B,`$`(0```'TP`0`E````GS`!`"8```#%
M,`$`)0```.PP`0`D````$C$!`!@````W,0$`'0```%`Q`0`D````;C$!`!@`
M``"3,0$`(@```*PQ`0`L````SS$!`"\```#\,0$`%0```"PR`0`E````0C(!
M`#P```!H,@$`'P```*4R`0`C````Q3(!`!\```#I,@$`(`````DS`0`:````
M*C,!`!@```!%,P$`)@```%XS`0`>````A3,!`"D```"D,P$`'@```,XS`0`Q
M````[3,!``D````?-`$`#````"DT`0`7````-C0!`"\```!.-`$`)````'XT
M`0`'````HS0!`!0```"K-`$`#@```,`T`0`-````SS0!``4```#=-`$`!P``
M`.,T`0`B````ZS0!`"4````.-0$`&@```#0U`0`=````3S4!`!H```!M-0$`
M!P```(@U`0#'````D#4!``L```!8-@$`%0```&0V`0`&````>C8!``D```"!
M-@$`"P```(LV`0`-````ES8!`!<```"E-@$`!@```+TV`0`S````Q#8!`!,`
M``#X-@$`$P````PW`0`'````(#<!``\````H-P$`!P```#@W`0`R````0#<!
M``0```!S-P$`(0```'@W`0`3````FC<!``P```"N-P$`$0```+LW`0`R````
MS3<!`!8`````.`$`"````!<X`0`=````(#@!``D````^.`$`"@```$@X`0`4
M````4S@!``H```!H.`$`'0```',X`0`(````D3@!`!\```":.`$`"````+HX
M`0`:````PS@!`"<```#>.`$`!@````8Y`0`5````#3D!``<````C.0$`"```
M`"LY`0`)````-#D!`#\````^.0$`!P```'XY`0`/````ACD!``X```"6.0$`
M$````*4Y`0`)````MCD!``D```#`.0$`"````,HY`0`'````TSD!`!D```#;
M.0$`"@```/4Y`0`7`````#H!`!0````8.@$`"@```"TZ`0`,````.#H!`!<`
M``!%.@$`!````%TZ`0`J````8CH!``P```"-.@$`$0```)HZ`0`'````K#H!
M``(```"T.@$`$````+<Z`0`8````R#H!``L```#A.@$``P```.TZ`0`(````
M\3H!``8```#Z.@$`!P````$[`0`-````"3L!``L````7.P$`#@```",[`0`O
M````,CL!`"````!B.P$`'````(,[`0`5````H#L!``P```"V.P$`,0```,,[
M`0`%````]3L!`!(```#[.P$`/P````X\`0`2````3CP!``H```!A/`$`!@``
M`&P\`0`$````<SP!``0```!X/`$`"@```'T\`0`3````B#P!``4```"</`$`
M!@```*(\`0`&````J3P!``@```"P/`$`!````+D\`0`,````OCP!``H```#+
M/`$`.0```-8\`0`N````$#T!`"D````_/0$`!0```&D]`0`8````;ST!`!D`
M``"(/0$`'P```*(]`0`=````PCT!`!$```#@/0$``@```/(]`0`$````]3T!
M``H```#Z/0$`!@````4^`0`%````##X!``,````2/@$`#````!8^`0!%````
M(SX!`#(```!I/@$`&@```)P^`0`T````MSX!`"@```#L/@$`4P```!4_`0`9
M````:3\!`'(```"#/P$`(````/8_`0`U````%T`!`"$```!-0`$`10```&]`
M`0`P````M4`!`"@```#F0`$`*0````]!`0`F````.4$!`"4```!@00$`*```
M`(9!`0`H````KT$!`"(```#800$`*P```/M!`0`P````)T(!`!(```!80@$`
M$P```&M"`0`0````?T(!`'D```"00@$`"0````I#`0"A````%$,!`',```"V
M0P$`?````"I$`0`K````IT0!`%0```#31`$`%P```"A%`0`G````0$4!`!8`
M``!H10$`#P```']%`0`7````CT4!`!\```"G10$`0````,=%`0`?````"$8!
M`!P````H1@$`40```$5&`0`:````ET8!`!0```"R1@$`"@```,=&`0`%````
MTD8!``8```#81@$`"````-]&`0`%````Z$8!`!(```#N1@$`$`````%'`0`3
M````$D<!`!T````F1P$`#P```$1'`0`/````5$<!``0```!D1P$`"0```&E'
M`0`+````<T<!``<```!_1P$`!0```(='`0`4````C4<!``<```"B1P$`"```
M`*I'`0`/````LT<!``@```##1P$`#````,Q'`0`/````V4<!``8```#I1P$`
M%````/!'`0`&````!4@!``P````,2`$`$0```!E(`0`(````*T@!``0````T
M2`$`&0```#E(`0`1````4T@!``H```!E2`$`&````'!(`0`3````B4@!`!P`
M``"=2`$`$0```+I(`0`/````S$@!``<```#<2`$`!````.1(`0`9````Z4@!
M``<````#20$``@````M)`0`"````#DD!`!$````120$`"0```"-)`0`&````
M+4D!`!(````T20$`%P```$=)`0`&````7TD!`"<```!F20$``@```(Y)`0`$
M````D4D!``\```"620$`$P```*9)`0`'````NDD!``<```#"20$`$0```,I)
M`0`&````W$D!`!@```#C20$`!@```/Q)`0`3`````TH!`!`````72@$`$@``
M`"A*`0`"````.TH!``8````^2@$`#````$5*`0`)````4DH!`!$```!<2@$`
M(@```&Y*`0`'````D4H!``<```"92@$`"P```*%*`0`%````K4H!``(```"S
M2@$`"P```+9*`0!)`0``PDH!`!`````,3`$`%P```!U,`0`+````-4P!``8`
M``!!3`$`"0```$A,`0`(````4DP!``H```!;3`$`%````&9,`0`9````>TP!
M`"T```"53`$`)0```,-,`0`E````Z4P!`",````/30$`'P```#--`0`M````
M4TT!``H```"!30$`*@```(Q-`0`3````MTT!``T```#+30$`"P```-E-`0`%
M````Y4T!`"T```#K30$`#0```!E.`0`=````)TX!`!4```!%3@$`#P```%M.
M`0`1````:TX!`'0```!]3@$`#@```/).`0`(`````4\!`!$````*3P$`#0``
M`!Q/`0`6````*D\!`!<```!!3P$`%P```%E/`0`:````<4\!``8```",3P$`
MOP```)-/`0`+````4U`!`!(```!?4`$`'0```')0`0`0````D%`!`!(```"A
M4`$`$@```+10`0`(````QU`!``\```#04`$`,````.!0`0`9````$5$!`#8`
M```K40$`/0```&)1`0!0````H%$!`$\```#Q40$`6````$%2`0!6````FE(!
M`#@```#Q4@$`%````"I3`0`7````/U,!`!$```!74P$`%0```&E3`0`=````
M?U,!``@```"=4P$`!@```*93`0`/````K5,!``0```"]4P$`$````,)3`0`/
M````TU,!`#(```#C4P$`,````!94`0`1````1U0!``X```!95`$`$0```&A4
M`0`)````>E0!``8```"$5`$`&0```(M4`0`7````I50!``<```"]5`$`#@``
M`,54`0`1````U%0!`!X```#F5`$`'`````55`0`3````(E4!``T````V50$`
M#0```$15`0`*````4E4!`"8```!=50$`$P```(15`0`8````F%4!`!(```"Q
M50$`5````,15`0`W````&58!`"0```!15@$`!@```'96`0`'````?58!`#8`
M``"%5@$`#0```+Q6`0`'````RE8!``H```#25@$`"````-U6`0`(````YE8!
M``4```#O5@$`"````/56`0`+````_E8!``8````*5P$`(P```!%7`0`.````
M-5<!``P```!$5P$`$P```%%7`0`6````95<!`"L```!\5P$`"P```*A7`0`D
M````M%<!`!<```#95P$`)````/%7`0`=````%E@!`!0````T6`$`$@```$E8
M`0`.````7%@!`!P```!K6`$`%@```(A8`0`'````GU@!``8```"G6`$`"```
M`*Y8`0`.````MU@!``<```#&6`$`"@```,Y8`0`1````V5@!``D```#K6`$`
M$````/58`0`8````!ED!`"H````?60$`"````$I9`0`1````4UD!``4```!E
M60$`#P```&M9`0`,````>UD!`#$```"(60$`+P```+I9`0`)````ZED!``@`
M``#T60$`!@```/U9`0`%````!%H!`!`````*6@$`#````!M:`0`5````*%H!
M`#0````^6@$`*````'-:`0`G````G%H!`"0```#$6@$`,0```.E:`0`(````
M&UL!``8````D6P$`"0```"M;`0`'````-5L!`#<````]6P$`+P```'5;`0`V
M````I5L!`%X```#<6P$`-0```#M<`0`U````<5P!`$H```"G7`$`2P```/)<
M`0`U````/ET!`$(```!T70$`,0```+==`0`T````Z5T!`$P````>7@$`-0``
M`&M>`0`[````H5X!`"P```#=7@$`%@````I?`0`:````(5\!`"8````\7P$`
M*P```&-?`0`K````CU\!`!$```"[7P$`"P```,U?`0`,````V5\!``<```#F
M7P$`#0```.Y?`0`7````_%\!`"0````48`$`!@```#E@`0`'````0&`!``D`
M``!(8`$`"````%)@`0`H````6V`!``\```"$8`$`"@```)1@`0`(````GV`!
M``8```"H8`$`!0```*]@`0`'````M6`!``4```"]8`$`"@```,-@`0`G````
MSF`!`!````#V8`$`"0````=A`0`%````$6$!``<````780$`!P```!]A`0`%
M````)V$!``T````M80$`!@```#MA`0`3````0F$!``,```!680$`"````%IA
M`0`&````8V$!``T```!J80$`"````'AA`0`@````@6$!`!$```"B80$`"0``
M`+1A`0`2````OF$!``P```#180$`!P```-YA`0`#````YF$!``,```#J80$`
M%````.YA`0`4`````V(!`#(````88@$`"````$MB`0`)````5&(!``@```!>
M8@$`!P```&=B`0!+````;V(!`"0```"[8@$`+0```.!B`0`H````#F,!`"$`
M```W8P$`!@```%EC`0`&````8&,!`!@```!G8P$`(0```(!C`0`D````HF,!
M`"X```#'8P$`)0```/9C`0`M````'&0!`&````!*9`$`+@```*MD`0`2````
MVF0!``<```#M9`$`$P```/5D`0`1````"64!``\````;90$`$````"ME`0`0
M````/&4!`!````!-90$`$````%YE`0`/````;V4!``D```!_90$`%P```(EE
M`0`A````H64!`!0```##90$`&````-AE`0`#````\64!``8```#U90$`$0``
M`/QE`0!5````#F8!`%P```!D9@$`!````,%F`0`6````QF8!``4```#=9@$`
M!````.-F`0`2````Z&8!``\```#[9@$`'`````MG`0`D````*&<!`#````!-
M9P$`#P```'YG`0`C````CF<!``4```"R9P$`&@```+AG`0`-````TV<!`!D`
M``#A9P$`%0```/MG`0`;````$6@!`!$````M:`$`&0```#]H`0`3````66@!
M``T```!M:`$`!@```'MH`0`,````@F@!``<```"/:`$`%P```)=H`0`2````
MKV@!``X```#":`$`"````-%H`0`%````VF@!``L```#@:`$`"P```.QH`0`'
M````^&@!``\`````:0$`!@```!!I`0`&````%VD!`!4````>:0$`"````#1I
M`0`*````/6D!``8```!(:0$`"@```$]I`0`(````6FD!``0```!C:0$`!```
M`&AI`0`7````;6D!`$P```"%:0$`)````-)I`0`/````]VD!``X````':@$`
M!0```!9J`0`<````'&H!`!$````Y:@$`$@```$MJ`0`N````7FH!`#T```"-
M:@$`(````,MJ`0`(````[&H!`#````#U:@$`&@```"9K`0`*````06L!``H`
M``!,:P$`#P```%=K`0`&````9VL!``D```!N:P$`%P```'AK`0`/````D&L!
M``D```"@:P$`$@```*IK`0`M````O6L!`"L```#K:P$`+P```!=L`0`M````
M1VP!`"$```!U;`$`)@```)=L`0`E````OFP!`"D```#D;`$`*0````YM`0`U
M````.&T!`"L```!N;0$`)````)IM`0`F````OVT!`"$```#F;0$`*@````AN
M`0`Z````,VX!`"X```!N;@$`)````)UN`0`P````PFX!`#D```#S;@$`)0``
M`"UO`0`A````4V\!`#0```!U;P$`)0```*IO`0`9````T&\!`"\```#J;P$`
M(P```!IP`0`F````/G`!`!H```!E<`$`L0```(!P`0`2````,G$!`"````!%
M<0$`*0```&9Q`0`I````D'$!`#$```"Z<0$`(@```.QQ`0`A````#W(!`"4`
M```Q<@$`*0```%=R`0`L````@7(!`#H```"N<@$`+````.ER`0"3````%G,!
M`"4```"J<P$`&P```-!S`0`F````[',!`"\````3=`$`+P```$-T`0!&````
M<W0!`$0```"Z=`$`#0```/]T`0`'````#74!``4````5=0$`"````!MU`0`.
M````)'4!``T````S=0$`%0```$%U`0`,````5W4!`!4```!D=0$`"@```'IU
M`0`$````A74!``\```"*=0$`$````)IU`0`,````JW4!``\```"X=0$`%0``
M`,AU`0`0````WG4!`!0```#O=0$`#0````1V`0!"````$G8!``H```!5=@$`
M$````&!V`0`&````<78!``\```!X=@$``@```(AV`0!+````BW8!``4```#7
M=@$`(P```-UV`0`7`````7<!``4````9=P$`#@```!]W`0`,````+G<!``,`
M```[=P$`$0```#]W`0`(````47<!`!````!:=P$`$0```&MW`0`-````?7<!
M`!,```"+=P$`&P```)]W`0`C````NW<!``D```#?=P$`!P```.EW`0`-````
M\7<!``\```#_=P$`#@````]X`0`-````'G@!`!H````L>`$`#0```$=X`0`.
M````57@!`"<```!D>`$`%@```(QX`0`K````HW@!``X```#/>`$`&````-YX
M`0`7````]W@!`!<````/>0$`,0```"=Y`0`-````67D!``8```!G>0$`#P``
M`&YY`0`%````?GD!`"L```"$>0$`+````+!Y`0`%````W7D!``D```#C>0$`
M'@```.UY`0`+````#'H!`!(````8>@$`$@```"MZ`0`'````/GH!`"8```!&
M>@$`%0```&UZ`0`;````@WH!`!@```"?>@$`$0```+AZ`0`5````RGH!``D`
M``#@>@$`"0```.IZ`0`C````]'H!`#T````8>P$`"````%9[`0`6````7WL!
M`!X```!V>P$`"````)5[`0`+````GGL!`#(```"J>P$`$````-U[`0`%````
M[GL!``8```#T>P$``P```/M[`0`'````_WL!``<````'?`$`#`````]\`0`/
M````''P!``T````L?`$`#0```#I\`0`4````2'P!`!<```!=?`$`%@```'5\
M`0`4````C'P!``L```"A?`$`!0```*U\`0`(````LWP!``H```"\?`$``@``
M`,=\`0`%````RGP!`!````#0?`$`(P```.%\`0`3````!7T!`!(````9?0$`
M"0```"Q]`0`/````-GT!`!$```!&?0$`&@```%A]`0`M````<WT!`"L```"A
M?0$`"P```,U]`0`.````V7T!`'8```#H?0$`$P```%]^`0`?````<WX!`!``
M``"3?@$`!P```*1^`0`%````K'X!`!T```"R?@$`,0```-!^`0`O`````G\!
M`!X````R?P$`(````%%_`0`:````<G\!`!H```"-?P$`"````*A_`0`'````
ML7\!``<```"Y?P$`!@```,%_`0`0````R'\!``X```#9?P$`$0```.A_`0`/
M````^G\!`!4````*@`$`#P```""``0`,````,(`!``H````]@`$`!P```$B`
M`0`(````4(`!`!0```!9@`$`#@```&Z``0`W````?8`!``\```"U@`$`"```
M`,6``0`+````SH`!`!H```#:@`$`(````/6``0`J````%H$!`"D```!!@0$`
M'P```&N!`0`@````BX$!`"H```"L@0$`'P```->!`0`8````]X$!``4````0
M@@$`'0```!:"`0`/````-((!``X```!$@@$``P```%."`0`$````5X(!``<`
M``!<@@$`#0```&2"`0`/````<H(!``L```""@@$`%0```(Z"`0`+````I((!
M``4```"P@@$`!0```+:"`0`7````O((!`!D```#4@@$`#P```.Z"`0`+````
M_H(!``P````*@P$`#P```!>#`0`F````)X,!``8```!.@P$`!@```%6#`0`-
M````7(,!``H```!J@P$`"P```'6#`0`&````@8,!``X```"(@P$`!````)>#
M`0`7````G(,!``L```"T@P$`!P```,"#`0`J````R(,!``\```#S@P$`@P``
M``.$`0`2````AX0!``D```":A`$`!P```*2$`0`+````K(0!``<```"XA`$`
M"0```,"$`0`$````RH0!``T```#/A`$``P```-V$`0`%````X80!``H```#G
MA`$`$P```/*$`0`2````!H4!`!0````9A0$`&@```"Z%`0`"````284!``D`
M``!,A0$`"P```%:%`0`$````8H4!``H```!GA0$`!0```'*%`0`F````>(4!
M``@```"?A0$`!@```*B%`0`G````KX4!``X```#7A0$`!P```.:%`0`'````
M[H4!``4```#VA0$`"0```/R%`0`+````!H8!``<````2A@$`!@```!J&`0`+
M````(88!`!`````MA@$`#0```#Z&`0`&````3(8!``<```!3A@$`!P```%N&
M`0`4````8X8!`!T```!XA@$`/P```):&`0`L````UH8!`#$````#AP$`!P``
M`#6'`0`*````/8<!``0```!(AP$`"0```$V'`0`(````5X<!`!T```!@AP$`
M"0```'Z'`0`&````B(<!``T```"/AP$`!@```)V'`0`$````I(<!`#(```"I
MAP$`-````-R'`0`T````$8@!`",```!&B`$`!0```&J(`0`=````<(@!``0`
M``".B`$`"````).(`0`(````G(@!`"0```"EB`$`"P```,J(`0`%````UH@!
M``@```#<B`$`'P```.6(`0`(````!8D!``@````.B0$`%@```!>)`0`&````
M+HD!``8````UB0$`!P```#R)`0`%````1(D!``T```!*B0$`$````%B)`0`-
M````:8D!``@```!WB0$`"0```(")`0`%````BHD!`#L```"0B0$`.````,R)
M`0`\````!8H!`"<```!"B@$`.````&J*`0!`````HXH!`#````#DB@$`.@``
M`!6+`0`U````4(L!`#X```"&BP$`*0```,6+`0`2````[XL!`!8````"C`$`
M#0```!F,`0`J````)XP!`!P```!2C`$`'0```&^,`0`<````C8P!``<```"J
MC`$`"0```+*,`0`)````O(P!``@```#&C`$`*````,^,`0`G````^(P!`"4`
M```@C0$`"0```$:-`0`:````4(T!`"\```!KC0$`)@```)N-`0`1````PHT!
M``8```#4C0$`"0```-N-`0`,````Y8T!``P```#RC0$`#P```/^-`0`V````
M#XX!`((```!&C@$`=@```,F.`0`/````0(\!``L```!0CP$`#````%R/`0`1
M````:8\!`!(```![CP$`$````(Z/`0`'````GX\!``\```"GCP$`%````+>/
M`0`2````S(\!``\```#?CP$`'P```.^/`0`J````#Y`!`(8````ZD`$`$0``
M`,&0`0`%````TY`!`!<```#9D`$`"0```/&0`0`$````^Y`!``H`````D0$`
M'@````N1`0`1````*I$!``X````\D0$`#@```$N1`0`,````6I$!`!,```!G
MD0$`'@```'N1`0`@````FI$!`!X```"[D0$`(````-J1`0`?````^Y$!`"$`
M```;D@$`&P```#V2`0`X````69(!``\```"2D@$`$0```**2`0`0````M)(!
M`!(```#%D@$`#0```-B2`0`2````YI(!`!0```#YD@$`$`````Z3`0`2````
M'Y,!`#(````RDP$`%@```&63`0`4````?),!`#T```"1DP$`%````,^3`0`*
M````Y),!`!,```#ODP$`00````.4`0`;````190!`!,```!AE`$`$@```'64
M`0`=````B)0!`!@```"FE`$`%@```+^4`0`7````UI0!`!X```#NE`$`&@``
M``V5`0`H````*)4!`",```!1E0$`&@```'65`0`5````D)4!`!8```"FE0$`
M$0```+V5`0`7````SY4!`!D```#GE0$`&0````&6`0`7````&Y8!``@````S
ME@$`$````#R6`0`$````398!``0```!2E@$`!0```%>6`0`+````798!``\`
M``!IE@$`!@```'F6`0`)````@)8!``<```"*E@$`"0```)*6`0`'````G)8!
M``8```"DE@$`"````*N6`0`&````M)8!``8```"[E@$``P```,*6`0`#````
MQI8!``@```#*E@$`$@```-.6`0`1````YI8!``X```#XE@$`#P````>7`0`*
M````%Y<!`!(````BEP$`!````#67`0`H````.I<!`!(```!CEP$`$````':7
M`0`8````AY<!``L```"@EP$`"0```*R7`0`.````MI<!`"T```#%EP$`!```
M`/.7`0`(````^)<!`"(````!F`$`$@```"28`0`&````-Y@!``D````^F`$`
M!P```$B8`0`%````4)@!``0```!6F`$`$0```%N8`0`4````;9@!``X```""
MF`$`%@```)&8`0`8````J)@!`!T```#!F`$`&P```-^8`0`(````^Y@!``4`
M```$F0$`!@````J9`0`A````$9D!``<````SF0$`!0```#N9`0`.````09D!
M``T```!0F0$`!P```%Z9`0`&````9ID!``<```!MF0$`!0```'69`0`/````
M>YD!``\```"+F0$`"@```)N9`0`/````IID!`!$```"VF0$`%@```,B9`0`4
M````WYD!``X```#TF0$`%@````.:`0`(````&IH!``4````CF@$`$0```"F:
M`0`V````.YH!``4```!RF@$`#````'B:`0`C````A9H!`!8```"IF@$`%```
M`,":`0`7````U9H!``P```#MF@$`"0```/J:`0`'````!)L!``H````,FP$`
M"0```!>;`0`.````(9L!`!`````PFP$`'0```$&;`0`C````7YL!`"X```"#
MFP$`"@```+*;`0`%````O9L!``X```##FP$`#0```-*;`0`1````X)L!``@`
M``#RFP$`"P```/N;`0`F````!YP!``@````NG`$`"P```#><`0`4````0YP!
M`%$```!8G`$`%````*J<`0`)````OYP!``4```#)G`$`!0```,^<`0`3````
MU9P!`!4```#IG`$`$P```/^<`0`+````$YT!``(````?G0$`"@```"*=`0`J
M````+9T!``,```!8G0$`!0```%R=`0`*````8IT!``H```!MG0$`!0```'B=
M`0`%````?IT!`!X```"$G0$`$@```*.=`0`&````MIT!``@```"]G0$`"```
M`,:=`0`$````SYT!``4```#4G0$`80```-J=`0`*````/)X!``T```!'G@$`
M$@```%6>`0`%````:)X!``4```!NG@$`)P```'2>`0`T````G)X!`!,```#1
MG@$`"````.6>`0`,````[IX!``H```#[G@$`"0````:?`0`:````$)\!`"P`
M```KGP$`*@```%B?`0`I````@Y\!`!X```"MGP$`#P```,R?`0`#````W)\!
M``<```#@GP$`"````.B?`0`(````\9\!`!````#ZGP$`#`````N@`0`&````
M&*`!`$D````?H`$`&0```&F@`0`*````@Z`!``T```".H`$`'````)R@`0!-
M````N:`!`"`````'H0$`!@```"BA`0`=````+Z$!`"@```!-H0$`"````':A
M`0`&````?Z$!`!T```"&H0$`!0```*2A`0`(````JJ$!`"H```"SH0$`*0``
M`-ZA`0`N````"*(!`!$````WH@$`!0```$FB`0`>````3Z(!`%T```!NH@$`
M$````,RB`0`A````W:(!`!$```#_H@$``P```!&C`0`,````%:,!``8````B
MHP$`%0```"FC`0`+````/Z,!``<```!+HP$`"0```%.C`0`&````7:,!``D`
M``!DHP$`#````&ZC`0`'````>Z,!``H```"#HP$`#````(ZC`0`Y````FZ,!
M``8```#5HP$`#@```-RC`0`0````ZZ,!`!````#\HP$`#0````VD`0`.````
M&Z0!``\````JI`$`#0```#JD`0`-````2*0!``T```!6I`$`"````&2D`0`>
M````;:0!`!$```",I`$`"@```)ZD`0`7````J:0!``H```#!I`$`%````,RD
M`0`'````X:0!`!````#II`$`!````/JD`0`'````_Z0!``4````'I0$`!0``
M``VE`0`)````$Z4!`!`````=I0$`%0```"ZE`0`M````1*4!`!P```!RI0$`
M,0```(^E`0`J````P:4!`!D```#LI0$`'0````:F`0`8````)*8!``0````]
MI@$`!0```$*F`0`.````2*8!``X```!7I@$`$@```&:F`0`#````>:8!`",`
M``!]I@$`"P```*&F`0`*````K:8!`"````"XI@$`&@```-FF`0`2````]*8!
M``0````'IP$`$`````RG`0`%````':<!`!(````CIP$`$0```#:G`0`,````
M2*<!``D```!5IP$`!0```%^G`0`'````9:<!``,```!MIP$`!````'&G`0`#
M````=J<!`%(```!ZIP$`0````,VG`0`=````#J@!`"X````LJ`$`-0```%NH
M`0`-````D:@!`#8```"?J`$`(@```-:H`0`G````^:@!`"<````AJ0$`+```
M`$FI`0`.````=JD!`"0```"%J0$`%````*JI`0`<````OZD!`!H```#<J0$`
M%P```/>I`0`<````#ZH!`"$````LJ@$`&P```$ZJ`0`7````:JH!`"P```""
MJ@$`+````*^J`0`P````W*H!`"T````-JP$`+@```#NK`0`K````:JL!`%X`
M``"6JP$`(````/6K`0`7````%JP!``@````NK`$`'@```#>L`0`)````5JP!
M``\```!@K`$`0````'"L`0`Q````L:P!`!\```#CK`$`#@````.M`0!5````
M$JT!`$P```!HK0$`!@```+6M`0`B````O*T!``X```#?K0$`$````.ZM`0`9
M````_ZT!``8````9K@$`"@```""N`0`,````*ZX!``X````XK@$`%@```$>N
M`0`+````7JX!`!,```!JK@$`"````'ZN`0`B````AZX!``@```"JK@$`!0``
M`+.N`0`,````N:X!``T```#&K@$`#0```-2N`0`^````XJX!``(````AKP$`
M!@```"2O`0`-````*Z\!``D````YKP$`!P```$.O`0`1````2Z\!``H```!=
MKP$`)0```&BO`0`+````CJ\!`"(```":KP$`!````+VO`0`N````PJ\!`!0`
M``#QKP$`*`````:P`0!J````+[`!`!0```":L`$`1````*^P`0`?````]+`!
M``\````4L0$`"@```"2Q`0`-````+[$!``\````]L0$`"P```$VQ`0`4````
M6;$!``T```!NL0$`&0```'RQ`0`5````EK$!``,```"LL0$`$0```+"Q`0`/
M````PK$!`",```#2L0$`$0```/:Q`0`4````"+(!`!T````=L@$`$````#NR
M`0`G````3+(!``<```!TL@$`"0```'RR`0`4````AK(!`!(```";L@$`$@``
M`*ZR`0`:````P;(!`!(```#<L@$`#P```.^R`0`6````_[(!``H````6LP$`
M"0```"&S`0`(````*[,!`!`````TLP$`$@```$6S`0`&````6+,!`!$```!?
MLP$`"````'&S`0`1````>K,!``4```",LP$`&P```)*S`0`/````KK,!`"X`
M``"^LP$`$@```.VS`0`&`````+0!``<````'M`$`&`````^T`0`&````*+0!
M`!(````OM`$`!0```$*T`0`9````2+0!``4```!BM`$`!P```&BT`0`7````
M<+0!`"<```"(M`$`!0```+"T`0`;````MK0!`!(```#2M`$`!0```.6T`0`2
M````Z[0!`!$```#^M`$`!````!"U`0`/````%;4!``@````EM0$`!P```"ZU
M`0`*````-K4!``@```!!M0$`!0```$JU`0`@````4+4!`#,```!QM0$`/```
M`*6U`0`<````XK4!`"<```#_M0$`(````">V`0`^````2+8!`!H```"'M@$`
M(````**V`0`O````P[8!`%@```#SM@$`)P```$RW`0`&````=+<!``@```![
MMP$`!@```(2W`0`+````B[<!`!D```"7MP$`&0```+&W`0`L````R[<!`!\`
M``#XMP$`&P```!BX`0`V````-+@!`#P```!KN`$`!````*BX`0`5````K;@!
M``8```##N`$`!@```,JX`0`D````T;@!`!D```#VN`$`$0```!"Y`0`-````
M(KD!``<````PN0$`#@```#BY`0`(````1[D!`!8```!0N0$`#````&>Y`0`:
M````=+D!`!L```"/N0$`.````*NY`0`)````Y+D!``4```#NN0$`!0```/2Y
M`0`%````^KD!`!L`````N@$`$@```!RZ`0`$````+[H!``D````TN@$`"P``
M`#ZZ`0`0````2KH!``X```!;N@$`'0```&JZ`0`/````B+H!``4```"8N@$`
M!0```)ZZ`0`,````I+H!`#4```"QN@$`60```.>Z`0`>````0;L!``<```!@
MNP$`(@```&B[`0`;````B[L!``\```"GNP$`$@```+>[`0`-````RKL!``@`
M``#8NP$`$0```.&[`0`M````\[L!``D````AO`$`#@```"N\`0`0````.KP!
M`!8```!+O`$`#0```&*\`0`Z````<+P!``D```"KO`$`'P```+6\`0`5````
MU;P!`!D```#KO`$`.P````6]`0`F````0;T!`#X```!HO0$`/P```*>]`0`[
M````Y[T!``P````CO@$`$````#"^`0`-````0;X!`!(```!/O@$`%@```&*^
M`0`(````>;X!`!0```""O@$`$@```)>^`0`'````JKX!`!,```"RO@$`*```
M`,:^`0`'````[[X!``8```#WO@$`#P```/Z^`0`.````#K\!`!4````=OP$`
M!````#._`0`(````.+\!``P```!!OP$`#````$Z_`0`-````6[\!`!$```!I
MOP$`$0```'N_`0`'````C;\!``4```"5OP$`-````)N_`0`D````T+\!`"0`
M``#UOP$`!P```!K``0`/````(L`!``8````RP`$`'````#G``0`A````5L`!
M`"0```!XP`$`#@```)W``0`)````K,`!`!X```"VP`$``P```-7``0`&````
MV<`!``H```#@P`$``@```.O``0`,````[L`!`!,```#[P`$`"P````_!`0`5
M````&\$!`!D````QP0$`%@```$O!`0`%````8L$!``H```!HP0$`$P```'/!
M`0`6````A\$!``X```">P0$`!@```*W!`0`+````M,$!``D```#`P0$`$0``
M`,K!`0!5````W,$!`!T````RP@$`,0```%#"`0`/````@L(!``0```"2P@$`
M!@```)?"`0`+````GL(!``X```"JP@$`#0```+G"`0`;````Q\(!`!@```#C
MP@$`#@```/S"`0`?````"\,!``X````KPP$`(````#K#`0`.````6\,!``P`
M``!JPP$`:@```'?#`0`D````XL,!`!8````'Q`$`)@```![$`0`B````1<0!
M`!0```!HQ`$`&0```'W$`0`9````E\0!``X```"QQ`$`&````,#$`0`*````
MV<0!``<```#DQ`$`"````.S$`0`)````]<0!`!0```#_Q`$`#0```!3%`0`T
M````(L4!`!0```!7Q0$`'0```&S%`0`'````BL4!``X```"2Q0$`.P```*'%
M`0!.````W<4!`"\````LQ@$`>````%S&`0`*````U<8!`"@```#@Q@$`-P``
M``G'`0`(````0<<!``@```!*QP$`#````%/'`0`V````8,<!``@```"7QP$`
M20```*#'`0`Y````ZL<!`"@````DR`$`(````$W(`0`G````;L@!`"$```"6
MR`$`+````+C(`0`F````Y<@!`"T````,R0$`)@```#K)`0`0````8<D!``@`
M``!RR0$`#0```'O)`0`/````B<D!``X```"9R0$`!P```*C)`0`T````L,D!
M``P```#ER0$`$````/+)`0`&`````\H!`!(````*R@$`"````!W*`0`'````
M)LH!`!`````NR@$`"0```#_*`0`)````2<H!``@```!3R@$`$````%S*`0`0
M````;<H!`!4```!^R@$`%P```)3*`0`-````K,H!`"(```"ZR@$`$@```-W*
M`0`(````\,H!``X```#YR@$`%0````C+`0`/````'LL!``P````NRP$`)@``
M`#O+`0`.````8LL!`!\```!QRP$`)0```)'+`0`)````M\L!``8```#!RP$`
M$@```,C+`0`*````V\L!``0```#FRP$`&P```.O+`0`.````!\P!``\````6
MS`$`#P```";,`0`&````-LP!``D````]S`$`"@```$?,`0`)````4LP!``X`
M``!<S`$`%````&O,`0`$````@,P!``\```"%S`$`"````)7,`0`+````GLP!
M``\```"JS`$`&0```+K,`0`*````U,P!``(```#?S`$`(````.+,`0`'````
M`\T!``<````+S0$`<@```!/-`0`+````ALT!``8```"2S0$`)@```)G-`0`^
M````P,T!`!P```#_S0$`)P```!S.`0!1````1,X!`"$```"6S@$`,@```+C.
M`0`?````Z\X!`!0````+SP$`!0```"#/`0`%````)L\!``P````LSP$`"P``
M`#G/`0`'````1<\!``P```!-SP$`$@```%K/`0`.````;<\!``L```!\SP$`
M#0```(C/`0`+````EL\!``<```"BSP$`!P```*K/`0`*````LL\!`!0```"]
MSP$`"0```-+/`0`'````W,\!``L```#DSP$`(0```/#/`0`&````$M`!`"@`
M```9T`$`!0```$+0`0`%````2-`!``\```!.T`$`!0```%[0`0`*````9-`!
M``D```!OT`$`!P```'G0`0`2````@=`!`!(```"4T`$`!@```*?0`0`6````
MKM`!``L```#%T`$`"````-'0`0`%````VM`!``4```#@T`$`#P```.;0`0`<
M````]M`!``<````3T0$`"0```!O1`0`F````)=$!`!P```!,T0$`#0```&G1
M`0`$````=]$!``@```!\T0$`$````(71`0`)````EM$!``(```"@T0$`!P``
M`*/1`0`?````J]$!`"<```#+T0$`(0```//1`0`J````%=(!`"D```!`T@$`
M6@```&K2`0`1````Q=(!`%\```#7T@$`+@```#?3`0!)````9M,!`&P```"P
MTP$`'@```!W4`0`P````/-0!`"@```!MU`$`,0```);4`0`K````R-0!`!\`
M``#TU`$`.@```!35`0#+`0``3]4!`!P````;UP$`#P```#C7`0`_````2-<!
M`'P```"(UP$`0P````78`0`:````2=@!`#(```!DV`$`7@```)?8`0!(````
M]M@!`"$````_V0$`%P```&'9`0`0````>=D!`!X```"*V0$`&0```*G9`0`8
M````P]D!`"<```#<V0$`(`````3:`0`>````)=H!`#$```!$V@$`&0```';:
M`0`0````D-H!`#0```"AV@$`(P```-;:`0`A````^MH!`"$````<VP$`(@``
M`#[;`0`Y````8=L!`%0```";VP$`+P```/#;`0!'````(-P!`#````!HW`$`
M)P```)G<`0!!````P=P!`%X````#W0$`10```&+=`0`P````J-T!`"P```#9
MW0$`*P````;>`0!6````,MX!`$\```")W@$`2@```-G>`0!)````)-\!`#,`
M``!NWP$`+````*+?`0`L````S]\!`"T```#\WP$`90```"K@`0!:````D.`!
M`&,```#KX`$`G0```$_A`0`5````[>$!`",````#X@$`+P```"?B`0`O````
M5^(!`$$```"'X@$`(````,GB`0!4````ZN(!`"$````_XP$`"P```&'C`0"U
M````;>,!`$@````CY`$`'P```&SD`0`V````C.0!`"(```##Y`$`'@```.;D
M`0`L````!>4!``<````RY0$`!P```#KE`0`#````0N4!``T```!&Y0$`"P``
M`%3E`0`*````8.4!``L```!KY0$`!P```'?E`0`9````?^4!``,```"9Y0$`
M6P```)WE`0`$````^>4!`"<```#^Y0$`!````";F`0`'````*^8!``8````S
MY@$`!0```#KF`0`$````0.8!`!,```!%Y@$`"````%GF`0`1````8N8!`!4`
M``!TY@$``@```(KF`0`'````C>8!``<```"5Y@$`#````)WF`0`.````JN8!
M``8```"YY@$`%````,#F`0`,````U>8!``,```#BY@$`)P```.;F`0`$````
M#N<!``8````3YP$`"````!KG`0`P````(^<!`$<```!4YP$`+@```)SG`0`O
M````R^<!`!L```#[YP$`+P```!?H`0`R````1^@!`"0```!ZZ`$`(0```)_H
M`0`C````P>@!`"@```#EZ`$`(P````[I`0`A````,ND!`"H```!4Z0$`*0``
M`'_I`0`B````J>D!`#,```#,Z0$`'P````#J`0`P````(.H!`"T```!1Z@$`
M(@```'_J`0`F````HNH!`"4```#)Z@$`(````._J`0`I````$.L!`"D````Z
MZP$`)0```&3K`0`O````BNL!`!P```"ZZP$`(0```-?K`0`E````^>L!`"D`
M```?[`$`(````$GL`0`J````:NP!`#X```"5[`$`00```-3L`0`=````%NT!
M`"0````T[0$`0````%GM`0`E````FNT!`"D```#`[0$`*````.KM`0`I````
M$^X!`",````][@$`(````&'N`0`J````@NX!`"4```"M[@$`.0```-/N`0`G
M````#>\!`#4````U[P$`#````&OO`0`,````>.\!`!0```"%[P$`+P```)KO
M`0`C````RN\!``L```#N[P$`%P```/KO`0`.````$O`!`!8````A\`$`"```
M`#CP`0`'````0?`!`"(```!)\`$`)0```&SP`0`>````DO`!`"<```"Q\`$`
M)0```-GP`0`,````__`!`.L````,\0$`#P```/CQ`0`8````"/(!``P````A
M\@$`#P```"[R`0`8````/O(!`!\```!7\@$`'P```'?R`0`&````E_(!`#4`
M``">\@$`%@```-3R`0`4````Z_(!``<`````\P$`$P````CS`0`*````'/,!
M`#P````G\P$`"@```&3S`0`H````;_,!`!,```"8\P$`&````*SS`0`7````
MQ?,!`#@```#=\P$`(````!;T`0`2````-_0!`"0```!*]`$`$P```&_T`0`4
M````@_0!`!4```"8]`$`"@```*[T`0`7````N?0!``D```#1]`$`'0```-OT
M`0`(````^?0!`!P````"]0$`)@```!_U`0`'````1O4!`",```!.]0$`!P``
M`'+U`0`(````>O4!``D```"#]0$`-````(WU`0`&````PO4!`!````#)]0$`
M%0```-KU`0`4````\/4!``L````%]@$`#````!'V`0`'````'O8!``L````F
M]@$`'````#+V`0`/````3_8!`!@```!?]@$`&0```'CV`0`+````DO8!``T`
M``">]@$`%P```*SV`0`)````Q/8!`"L```#.]@$`#````/KV`0`/````!_<!
M``D````7]P$``@```"'W`0`1````)/<!`!@````V]P$`"P```$_W`0`#````
M6_<!``L```!?]P$`"````&OW`0`'````=/<!``L```!\]P$`"P```(CW`0`.
M````E/<!`"T```"C]P$`&@```-'W`0`:````[/<!`"$````'^`$`"@```"GX
M`0`Z````-/@!``4```!O^`$`%@```'7X`0`W````C/@!``T```#$^`$`#@``
M`-+X`0`&````X?@!``0```#H^`$`!@```.WX`0`+````]/@!`!<`````^0$`
M!P```!CY`0`(````(/D!``<````I^0$`"````#'Y`0`%````.OD!``\```!`
M^0$`$````%#Y`0`^````8?D!`#$```"@^0$`)````-+Y`0`%````]_D!`!H`
M``#]^0$`(0```!CZ`0`A````.OH!`",```!<^@$`$0```(#Z`0`"````DOH!
M``0```"5^@$`"@```)KZ`0`%````I?H!``4```"K^@$``P```+'Z`0`)````
MM?H!`$P```"_^@$`)0````S[`0`8````,OL!`"T```!+^P$`)0```'G[`0!?
M````G_L!`!,```#_^P$`>0```!/\`0`<````C?P!`%,```"J_`$`(@```/[\
M`0`_````(?T!`#0```!A_0$`+````);]`0`V````P_T!`#8```#Z_0$`-0``
M`#'^`0`S````9_X!`"@```";_@$`(@```,3^`0`F````Y_X!`$P````._P$`
M%````%O_`0`T````</\!``\```"E_P$`;P```+7_`0`)````)0`"`*(````O
M``(`>P```-(``@!P````3@$"`"@```"_`0(`5````.@!`@`:````/0("`"D`
M``!8`@(`%P```(("`@`*````F@("`!T```"E`@(`'0```,,"`@`T````X0("
M`",````6`P(`&````#H#`@!4````4P,"`!X```"H`P(`%P```,<#`@`*````
MWP,"``0```#J`P(`!@```.\#`@`(````]@,"``4```#_`P(`%0````4$`@`3
M````&P0"`!D````O!`(`)0```$D$`@`0````;P0"``X```"`!`(`!````(\$
M`@`)````E`0"``\```">!`(`"````*X$`@`)````MP0"`!8```#!!`(`#0``
M`-@$`@`,````Y@0"`!$```#S!`(`"P````4%`@`&````$04"`!,````8!0(`
M"P```"P%`@`6````.`4"``T```!/!0(`!P```%T%`@`/````904"``@```!U
M!0(`"0```'X%`@`E````B`4"`!L```"N!0(`#````,H%`@`D````UP4"`!(`
M``#\!0(`'@````\&`@`4````+@8"`!$```!#!@(`!0```%4&`@`%````6P8"
M`"$```!A!@(`"````(,&`@`"````C`8"``(```"/!@(`%@```)(&`@`(````
MJ08"``@```"R!@(`%````+L&`@`6````T`8"``@```#G!@(`+0```/`&`@`"
M````'@<"``0````A!P(`$````"8'`@`7````-P<"``\```!/!P(`!P```%\'
M`@`2````9P<"``4```!Z!P(`&P```(`'`@`%````G`<"`!8```"B!P(`$0``
M`+D'`@`2````RP<"``(```#>!P(`"````.$'`@`/````Z@<"``L```#Z!P(`
M#0````8(`@`D````%`@"``L````Y"`(`#````$4(`@`3````4@@"``4```!F
M"`(``@```&P(`@`+````;P@"``$```!_!```FP(```````!&`P``:0(``"\$
M```?!@```````%,!``!3``````0```,!````````?`$``-@$``!]!```00<`
M`$D%```V`P``)0,```X#``!W`P``,P0``*<!`````````````"T`````````
M``````````#/!````````+L```#-`0``!04``-4#```-`@``````````````
M````W08``'D!``"M!@``N@$```````#J`0``I`0``%("```L`0``O@4``%\%
M````````-04``-$%``!]`0``7`0``",'````````]0$``&D%```6`P``M@,`
M```````9!0``YP$``"X&``!J`@``C04```````!A`@``N04``(``````````
M`````+\"```[`@``JP4``'0"```U`P``'04``)P!``"_!0``V0$``#X%``"Q
M`@``D04```````#G!0``+`````````!C`P``%0```)L!``!Z`P``TP$``$T!
M``!,!@``XP```.T#``!F`0``QP(``,@"```Z!P``&0,`````````````1P4`
M`$4&``"&`0``"P0``(T$````````"P```!<!```>`@```````'8&````````
M]`8```````#,`@``-P<````````S`````````+0"``#S!0```````#8%``"8
M!0``:@$``,X!````````$P<``%P```"Q`P``>P8```````!]````C08`````
M``!9`0``30(``/L!```&````T@``````````````V````!$&````````[P``
M`````````````````$,"``"B!@```````.,#``!J!```)P4``!`%``"L!0``
M1`````````!)````8@(``-L%```[!P```````%@%``"I!0``%`(``($!````
M`````````!X&``"]`````````&$'``"<!@```````!T"``!(!0``T`8``#8`
M```F!0````$``+@!``"Q`0```````.0&``!3!P```````&0`````````````
M`/0#``!5`P``Z@4````````%`0``P@(``$,&````````>@8``.@%````````
M3@(``#L$``#2`@``$0`````````]`0``>P0``&(#``".!@``````````````
M`````````&`%``#X!@``&`0``*L!``"&!0```````*D```"W`@``````````
M````````&`,``)<&``#?`P``^@0```````#D````\00``*\$``!<!0``^0(`
M``<!```!!P``4`4```````!'`P```````.0%``"T!```@0````8$``"E!@``
M'P4`````````````V00``&4!``!0!```]0,``!$"```'!```Z`(```````!\
M!```S@4``)T%````````\`$``&H%```(`0``:`4``*\#````````'P,``$<!
M``!C!@``E`,`````````````?`,``+T$``!6!```VP```/($````````M08`
M``L'``#1!```:00``*`!``":!0``L@,``$H#``#R!0``7@8``'$````<!```
M`````$@&``#/`0``X`$````````H`@``9@(``,0!````````Z0```-@"``":
M`P```````!X%````````$`$``"L!``#K````UP4```````!1`P``U08``#$!
M```<!P``;`$``$4#```V`@``E``````````Q````FP8``+4$``!L!@``M`,`
M``````"4!0``]04``$@$`````````````"P'``#U!@``.0<``$T````I!P``
M+04``"<!````````6@,```````#7!@``)@,```````#7!```0@````````#\
M`@``N00``',&``!F!0``>P,```\$```2!@``%`,```````!M`P```````*$&
M`````````````-4"``"!!0``308``!L#```/`@```````'X$```(`@``;0$`
M``````#^!0``.@,```````````````````````#B````CP$``!D!``">````
M`````/`$`````````````$D$```1`0``N`````D$``"(!0``````````````
M````/@```"T&``!"!```P@0``````````````````$<$````````W`,``(8#
M````````Y`(```````"X`@``)`,``'8!``"+`0```@(``'@$```_!0``#P,`
M``````"6`@``_P8``#,&``!H`@``(`,``!0`````````KP(``+P$``"5````
M1`4``#T&``#6````%0$``-8$``#A!@````````````!!`P``\P,``-P"````
M````T@4``-0%````````!@$``),``````````````/$%```$````!0,``#``
M```T!@``*08``#4&``!I`P``/`,``+<&``#-!```G@4``.$%```4!```````
M`'<!``#+!@``&`<```````!E`@```````)P%````````"`<``)0$````````
M`````(X!``#L!0``*0```'L%``!C````F@(``,T#``!1````I`,```````"_
M!```;P8``)\%```@`@```````-X$``""`P``!P(``,L%``"@!@``S0```%8&
M```>`P``D@(``#T$````````>@4``"H%``"S````=0```$X#``!``P``;@4`
M```````*````[`,``````````````````"('````````F0$`````````````
MI`8``%<%``!%!P```````/(```"K`P``$@$````````C!```<P(```````#@
M!@``K@(``$D!``!I!@``+0<``'P```"$`@``T0$``&`#`````````````$4`
M``#T`@```````.X!``!Q`P``*@```+0!````````_`$``.D"``"C!```OP$`
M``````"J````/`<``,T&````````,@(```P'``"V!```:@```&<"```Y!0``
M``````@#````````0@$``(0&````````&@$``"\%``"R!@``%0(``/4"````
M````QP```&$&``"V!@``Q@```(@$```>!````````(4!``#Q!@``X````#,'
M``"'!@``XP(`````````````J`(``/T"``!?`@``*P4````````U!```/`0`
M`%D"``"R!```F00``"H"``#F!@``2`,`````````````R`4`````````````
MN@4``%@&``"G`P`````````````-!0```````)@!``#L``````8``!H%````
M````?P4``/P#``"6`P``.P8```````#Y!0```````/0`````````@`4```H'
M``!M!```@@8```````#F!``````````````W!@``@P4```````#N`@``N0$`
M`)4$``#X`P``MP4``&X!``#^`````````)$&``"7!0```````&0&```A!@``
M``````T````@!```@`8````````A!P```````*@#```=`P``GP````````!.
M!````````(P````A!```SP4``*<&``#6!@``C`(``````````````````"P%
M``#-!0``1@0``!L!`````````````%(!``"M`0``K@$``/L&``#V`0``K@8`
M`$H````2!0``100```````!L`P``-@0``'X%```Z`0``/@(``&<!```H!@``
M6@(````````/````R@4``#P```````````````````#+`0``S@````````#Z
M!0``DP8``"`'``#G`P```````#(!`````````````*$#``#H`P``!0(```0#
M``"@!0```````!4&``"S!````````/<$``"V`0```````$(#``";`P``9`,`
M`,4"``"L`0`````````````;`@``,0<``!P%```W!0``3P```.0!``"A````
M&`4``"0$````````DP(```````"Q!@``5````,P$````````$P(``)$!``!1
M!0``1`0``'(%``!+!0``$@0``+(%``!<!@``6P8``%\$```!!@``/`8``+`!
M``"$!```G0```&(```#R`@``\0,``&T`````````R`,``!8!```:`@``_P0`
M`%8'````````+`,```````"X!@``SP,``(\"``!/!@``QP$`````````````
M`````)<!````````F0,``'0&````````F`(``'D```#!`P``)P(``#(%```0
M!@``9`(``/T%``#+!````````"P$``##`0``&`(``'D%``"7`P``:P````P$
M````````60```#T%``#9`````````%L!```-`0``<00`````````````"`8`
M``````!H````B@```%0"````````O@(``*,&```3````FP4``&0!``#7`0``
M)`(``*L&``";!```!`8``````````````````&('``#"!0```````#`"```X
M!0``(P8``(,!```!`P``2@$``*@%``#%````'````#4```#O!@``(P(`````
M``"E`@``"0,``),!````````AP```!L$`````````````(\#````````+P``
M`$8&`````````````%H'``"I!``````````````A`@``30<``+@#```K!```
MV@`````````>`0``G0,``!H$```\`0``#@8``%H$````````````````````
M````)04``)D%````````U`0```````!9`P``(`4````````X`P```````%L'
M````````U````+\```"H````,P4```````"?`0``!P8``(8&``!!````````
M`!@!```_`@```````'@&```7!```/P<``+H$``"X!0``'0`````````J!```
M5P0```````#0````!`$``(T```"D````C0(``(($`````````````*\&```Y
M!@``O@$```4```!N`P``L@```"L"```6!```D00``%`"``#C!```YP(``-H"
M```Z`````@0``"D#``!3`P```````.0#``#>`@``^@$``/X"````````R00`
M`!8"````````^@(``+<!``#1````=@4````````V!@``V`,``-,$``"Y````
M%`8``.D$``"!!`````````````"Y!@```````.8```!]!@```````&P```"`
M`0``(@4``,P!``#,!@```````!L&``!.!0```````+,&``!<!P```````$L`
M``"I!@``*04``&X````S`@````````0%``!Q!@```````$H%``!9!@``&0``
M`(0!``#5!0``.P,```$"````````'@```'("``!H`P``P`0``'($``#E!0``
MH0$```````!,!```Y0```(P!```*`0```````"T"```_!```R04``.$$```2
M`@``$0,````````Q`P```````+0`````````!@8````````.`0``(P``````
M``!=`0``W0,```````````````````````"J`P``\P```)X$``"8````604`
M``````!!`@```````)X#````````;P(``%8!``"A`@```````"X$``#'!```
M`````+X$````````?P8``/@$````````[@0```````"V````K`(```,%```T
M!P``%@<``,0$```C`P``-`,``!<```!.!@``*0(``-<"``#[`P``UP,``#4"
M``#E!```J`8````````<!@``[@````````#*``````````````!5!```)@(`
M`!<"``#=``````````````#?``````````````"O`0``4@````H"````````
M]@4```````!&````C0$``'X&```Z!0````````````#;`0``(0,```````#6
M`P```````$X'``"F`@``+00``,@$``#B`0``,`,``%0%``##`P``,@<``"0&
M````````:`0```````#O`0``6P(``#$%```6`````````'`&``!=!0``#`8`
M`+H"``!/`P``RP,``$P#``!V````KP```!L```#J!@``908``.@!```5!```
MJ0(```````"2`0``4@4``-X#```T`0``I04``'(#```T!```W`````````"[
M!0``````````````````@P0``*H%```$!P``]`$``#<```"?`P``\P$`````
M````````C`4```````#\````E0$```````!F`P``!P<```````!O`P``A@0`
M`)\$``!\`@``I0,````````K`P``*@<``'D#``"1`P``K@0``%$!``!``@``
M`````-P!``#S`@``IP```$8%``"@!````````/@!``#M!@``1`(``!X'``#*
M!```;P$``.<$``#C`0``_0`````````0`@``C@,``!,&``!8`0``(@(`````
M``"%!0``9P0``.$"``"'!0``5P,``"8$``!<`0```````!T'``":!```G`,`
M`((!``!0`0``+@4```````#(`0``0`4```H#````````*P```&X"``"C`P``
M>@(``)D&````````70(``,D````X````A@```!`'```P`0``?@,``/(&``!N
M!```PP(`````````````B@8```<```#I!@```````,P#````````N0(``!('
M``!K`@``T@8``*(!````````*00``!\```"%`@``C@```#,#```N!P``20,`
M```````R!@```P```,`&````````V`$``%$$``#$!@```````(0%```_!@``
MT`4``/4```````````````````")!```:@8``%(&``!I`0```````&`'````
M````HP4``#4'````````\`````````#G!@``[P,``)<```"'`@```````%T`
M````````#@4``!0!`````````````*<"````````1P````````#)`@``0`8`
M```````K!P```````/8#``!"!0``2P8``$<"``#=!0``300``-$"``".!```
M`````/<%````````6`,``'T%```Q!````````&`$``#2`0``K@,``"@'``"*
M`P````````````!L!````````/L```#7````"0<``/<&``!A`0``50<``"@%
M````````EP(``&4`````````Y0(``$4"````````&@,``.P"``!E`P``R0$`
M`-T!``"\!0``D`0```````!X!0``2`(`````````````X0```)T$``!!`0``
MI`4`````````````2P(``/D&``!S`0``*0$``*P&``!/`0``/P,``(L"``!8
M!P```````,4$````````]`4```````!+`P```````&`!`````````````/<#
M````````D@4``'0$``#K!@``,`<``(D```!K`P``Z04```````#4`0``>P``
M`&@&````````A08``-L&````````@P(``%(#```"`````````.T$````````
MS@0``*X````O!@```````!T&``"G!```PP```&$`````````4`8``)H!``!0
M`P``)0```+`&``"'`P``/@<``$D&``"0`@``.`<````````-!P``&@```'`"
M``"D`@``BP0``+4%``!F````WP$``%8#``#O!```E`(``"`&```P!```;P``
M`(P#```B!```H@4``!P#``!"!@``XP4```X`````````=@(`````````````
M"`4``%X`````````3@$``(@&``!,`````````"<``````````````'(!````
M!0``<0$``/`"``"_`P``A`,`````````````P@8``)`#````````"````"<'
M``!8`@``7@$``'`!``!S!```2`$```````#1!@``.`0``%`'``!K!0``````
M`%0'`````````````'X```#Q`0``V@,``%8```!>!P``)08````````)`@``
MWP4```$$``!E!```20<```P#``"^!@``Y08```0$``!1!P``:P0``)`!```.
M`@```````/8"````````7P8```````!]`@``[P(```````!*!```YP```(4$
M``#Y````3P<``-\$``"=!@```````&X&``#J`P``^@8``-@%````````````
M`+T%``````````````````!=`P``7@0`````````````Q08``*8#````````
M!08`````````````I@8````````N`0``Q`,``/<!````````Q@$``+L#```#
M!P```````$H'``"'!````````/`#``````````````````"O!0```````%X%
M``!P!```R0,``',```#``P``$````-X```!2!```4P(```````#/`@``R@,`
M`.X&```%!P````````````!4`P``/0(``/X&```H!```E@8``"(`````````
M!@<``%4````W!```W00``-L"``"M`@```````!(#``#M`@``&0<``&T"``#.
M!@``.`8``+P#``!?`P```````%D'```L`@```````,P%``#*`@``XP8``"@`
M```7!P```````/\```![`@``"04````````V`0``HP(``+8"``!%`0``F0``
M`*L"```<`@````````,"`````````````+`%``!T````BP``````````````
M`````)P$``!7!@``U0$``*8```!``0``Y@4``#8'````````W0(`````````
M`````````%H```!4!@```````"<$``"M!0``C`0```````!_`@``I@0``+,%
M```Q!@``,`8``(H"``!6`@``B@4``',#``!0````T`,```,#``"`!```````
M````````````_@,```P```"5`@``3`<``)`%``"T!0```````(T#````````
M=P```.T!``!'!@``F`,``%8%````````````````````````C@(``,4%``#%
M`P``2P<``-P&```1!0``:`$``*,````F!@``W@4``$\"`````````````,H&
M`````@``=0$```````!$!P``^0$``.T```#)!@``(P$```````#I`P``A0``
M`%4!``!D!```L`(```\&```6!0``O`$````````T`@```@4``(0`````````
MP0$``(4#``#H!```EP0```````"4!@``E08``&4%``#V!```;`4``+,!```7
M!0``.00```````#P!@``20(```````"P!``````````````+`0``>@$``-H$
M``!#!0``"P8``)8!``#?!@```````!0%``!#!P``+0,```\%````````9P``
M`-`"`````````````'`%```+`@``G`(```````#3````:P8``&`&````````
M`````````````````````(,&`````````````,X#``!T`P``"@4``*`#````
M````TP4``"(#``"<`````````)\"```\!0``N@,``.($```9`@``>`,`````
M``#]`0```````&(%``"H`0``P```````````````7P```*P$``!C!P``(0``
M```````"`0``#`(``+L$```6!@``Y@(```8"``#`!0``Q@,``'`````S`0``
MWP(``$T%`````````````)0!````````7`,``)($``!K`0````````````#P
M!0``````````````````.`(``'4"````````8`(``&H#``!"!P``````````
M``"Z````"0```"$%````````?`4``)T!``#N`P```````/@````^`0``2```
M`/4$``"C`0``6@$``+<#```=!``````````````F`0``T`0``(("```,`0``
M600``'L!```^!@``\0```-H!``!?`0``]@```+L"``#;`P````````````#A
M`0``.0(``#H"```-!````````/P$````````,@,``$L!``#H!@``,@0`````
M```;!P``JP0``'`#``!!!```B`$``%4%```F!P```````'D"``!U`P``MP``
M`,@```":!@``@08``/D$```T!0``8P$``,0%``"I`0``0`0```````#J`@``
M804``&T&``"J!@```````&8&````````W@8``&8$````````E@4```8#```^
M!```)`````````"/!```CP4``"\#``#T!```3P0```````"M`````````'4&
M````````$P0````````?`@``````````````````$P$``$8'``#A`P``=P(`
M``4$````````Q@(``*($``!:!0``-`````````"Z!@``&P4``)\&``!!!0``
M%0,``$L$``"U````SP````````"&`@``@@```,,&```)!@```````/D#``!Z
M````/@,``,$```````````````````!O!```Q@4````````8!@``>08``,0`
M``"#````O0,```<#``"D`0``L00``+<$```E`@``6P```-`!``!S!0``Y@,`
M`'\``````````````-0"``"``@``ZP,``$P%``##!```ZP4``)4%````````
M0@(``'@!`````````````"$!````````(````&(&```!`0``$@````````"@
M`@``)`$``,8&``"M!```[@4``$4%``"\``````````````#J````L0````(&
M``"M`P``E@0``,<%``!_`P````````````"[`0``5P<``*@$````````$`0`
M`!\$```5!0```````-L$``#_!0```````'$%```W`P``H04```````#B`@``
M*@,``'H$``#Z`P``+@````````#J!```508````````@`0``8P4``(\&````
M````Q@0``%L%````````9`4``%T$```3`P``(@$``-(#``#H`````````.8!
M``!;!```)`<``&<%``"``P``E@```!D&``"+!0```````+$%``#4!@``_@0`
M`'8$``#'!@```````)T"``":````C@4``$H&``"U`0````````````"E`0``
M(@8``$$&``#6`@``1@$``&<#``!1!@``_`8``$,```#B`P````````````"B
M`P``M@4``)(&``!.`````````'<%``!4`0``B@$``*H!````````8P0``#H$
M```O!P```````#$"``#_`P``0P,``/\"``!3!0``B@0``%$"```?!P``M`8`
M`.P!```[`0``B04``+T&``"L`P``Y0,``'8#``!=!P``5P```/(!````````
MTP(```T#```D!0``.P4``.4!```L!@``8````.L!```W`@```````+P"``!_
M`0``V@8``.(&``#<!0````````````````````````````"@`````````$P"
M````````.@8``/T$``"F!0``%0<``'0%``#S!```BP,```````"(`@``50(`
M`)(#``#_`0``RP(```````!>`P``U00```@$``"0````%`<``(L&````````
M%P,``%@$``!]`P``>`(```X$````````[`0`````````````H@(``"\"````
M!P``*P8``!`#``#R`P``?`8``$````"J!```9P8``*D#````````/0```!$'
M``#3`P````````H$``#K!```V04````````9!```DP0``),%``"R`@``V@4`
M`!<&``#W`@```````+L&`````````@<``$0#```'!0``O`8``+``````````
M#P$``&\%````````R@$`````````````^`4``$,!```J!@```````&,"``#`
M`0``U0```-8%````````P@$`````````````=`$``.`$`````````````.`"
M````````8@0``#T'```-!@``Y`0``&P"`````````````"T!```+`P``_08`
M`",%``")`0``&@<``'D$````````0P0`````````````S0(``%T&``"S`P``
M/P```/L"``````````````````#>`0``1`8``,4!````````V`8``#`%``!8
M````4P8``+`#````````F`8```````!?!P``D0(``$H"``#9`@``80,``&$$
M``"J`@``G@8`````````````"@8``/$"``#@!0``D@```%0$```+!0``````
M`"@!``"U`P``O@,``+T!``"8!`````````````#!!0``.0$``*4```#@`P``
M``,``(D&``#!!```+@(```D!``"(`P``SP8``($#````````:0```+T"``#!
M!@``1P<``/@"```!!0``)P8``"H!````````'0$``(@```#9!@``L@$`````
M`````````````'4$`````````````%('``#"````Q`(`````````````C`8`
M`/L%````````M0(``"\!````````G@$``-,&``">`@```````/P%``""!0``
M``````P%``!W!````````$`'`````````````-$#````````OP8``)$````E
M!P``3P4``.L"``"B````#@<``-P$``"G!0``D`8`````````````````````
M`````````````#4!````````+@,``"4$```/!P``N`0``#T#``#L!@``_0,`
M``0"``"^````T@0```````#V!@````````````#M!0```````,X"```[````
MK````#(```"#`P```````,$"``!U!0``K@4``#\!````````)@```'@`````
M````LP(``-0#``!:!@``<0(```````!R````;04``$P!````````[P4``'X!
M```1!````````%P"````````@0(``,`"```<`0``I00``$@'``#^`0``R`8`
M`(<!``"9`@```````(\``````````````-D#```W`0``?@(``#@!``#6`0``
M`````%<!````````JP```)4#``#'`P``<@8```8%````````/`(``$8"``#W
M````1`$``!@```!7`@```````&(!``#+````Z0$``*8!```H`P``^P0``$T#
M``#Z````X@4```````")`@``$P4```````#"`P````````````";````````
M```````Y````&@8```,&``!3!````````),#````````7@(`````````````
MH00```(#```Y`P``'P$````````#!```=P8``"<#```E`0```````/,&````
M````S````,,%``")`P``N0,``%L#````("@E<R!D87ES(&%G;RD`("A!8V-E
M<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`
M("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E
M<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U
M<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R
M(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR
M9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT
M:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@
M+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE
M;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H
M:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@
M8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F
M('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R
M;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T
M($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H
M="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO
M4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O
M;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT
M($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN
M`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R
M;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI
M<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`
M061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@
M;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y
M<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF
M;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R
M97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS
M(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T
M86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL
M`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI
M<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E
M<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y
M(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!0
M87-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA
M:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT
M.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC
M80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N
M($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H
M87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)C:&EV92!&
M:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U
M<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L
M86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!
M=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N
M9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B
M-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD
M87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P
M9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@
M9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I
M;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O
M=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"
M860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86YG;&%D
M97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T
M(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC
M871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y
M<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K
M;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T
M<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I
M80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A
M;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@
M=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N
M8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C
M965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E
M;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R
M96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O
M<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A
M>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@
M<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H
M;VYE`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5R=&EF:6-A
M=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI
M8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H;V]S92!!<'!L:6-A
M=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/
M9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE
M87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T
M;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#
M;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M
M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z
M`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#
M;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`
M0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F
M86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN
M96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S
M(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O
M<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@
M9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O
M(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B
M('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N
M;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N
M`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O
M=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O
M<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER
M96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO
M="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U
M;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN
M:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`
M0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM
M90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE
M<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C
M=&EO;@!#>7!R=7,`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E
M($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y
M`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R
M96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E
M;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E
M($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I
M;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE
M=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`
M1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O
M=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT
M`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER
M96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS
M`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`
M1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN
M:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_
M(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L
M:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`
M161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M
M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y
M`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y
M('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M
M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@
M:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%52
M3"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U
M:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI
M8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E
M<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E
M<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE
M8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO
M;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C
M;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I
M979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O
M92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E
M;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO
M=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I
M;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M
M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@
M475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S
M="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R
M;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W
M;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T
M=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC
M92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I
M80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``
M1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`
M1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`
M1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R
M965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A
M9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U
M<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`
M1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E
M;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I
M=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O
M;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5I9VAT`$AE;'``2&5L<"!U
M<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T
M;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@
M=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F
M;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-
M12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@
M56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L
M('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0
M;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE
M<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU
M;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL
M8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO
M8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`
M26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT
M:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL
M("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@
M<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA
M>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N
M<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G
M92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P
M;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!5
M4DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G
M86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!)
M;7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O
M=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C
M="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`
M26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE
M<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V
M86EL86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN
M<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F
M;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F
M=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN
M<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R
M86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R
M;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E
M9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D
M:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I
M8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L
M:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T
M82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV
M86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED
M(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED
M(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T
M;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O
M;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE
M8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A
M=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D
M(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`
M2F%N=6%R>0!*87!A;@!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y
M`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S
M=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L
M($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N
M9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@
M=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E
M;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC
M(&]F`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S
M<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@
M;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@
M3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O
M<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S
M;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE
M8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I
M;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG
M:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H
M;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E
M;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y
M:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T
M(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/
M=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB
M90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F
M86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U
M<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A
M;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@
M<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`
M3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,
M;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E
M9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A
M<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA
M=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI
M<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H
M+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S
M+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R
M8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I
M=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S
M:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I
M=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A
M9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-
M87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T
M86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE
M`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A
M9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R
M=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER
M960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE
M=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES
M(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-
M:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B
M;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY
M`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@
M;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@
M0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO
M=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``
M36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP
M;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO
M;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O
M($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N
M9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%52
M3`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%52
M3`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`
M3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@
M=&\@)7,`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE
M86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O
M;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H
M7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE
M>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H
M=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE
M;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.
M;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D
M:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L
M;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA
M;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I
M=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E
M<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S
M:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S
M<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE
M9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)F;VQK
M($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@
M27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER
M96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D
M+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`
M3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@
M0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P
M87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M
M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@
M82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#
M;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T
M+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3
M>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I
M;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2
M.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R
M>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E
M9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H
M;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O
M<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D
M9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L
M>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@
M4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C
M:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I
M9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!0
M97)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI
M;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI
M;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE
M87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I
M8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R
M93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`
M4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T
M97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME
M>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U;W1A`%)3
M02!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A
M:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`
M4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M
M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I
M;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E
M;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T
M=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V
M92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E
M="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1
M=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S
M<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG
M:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T
M871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I
M97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD
M80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F
M;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A
M:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`
M4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA
M<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R
M`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T
M:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C
M<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A
M=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R
M8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!3
M96QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B
M:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W
M<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@
M240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P
M<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I
M;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G
M:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC
M:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R
M<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6
M:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L
M;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N
M('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3
M:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3
M;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N
M;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@
M:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O
M96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H
M($%F<FEC80!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3
M<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A
M<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A
M='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U
M9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`
M4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3
M=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U
M8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R
M96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O
M=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U
M;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z
M(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A
M<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD
M`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M
M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!4
M86)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N
M`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE
M($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP
M97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D
M96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN
M:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4
M:`!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@
M<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%
M>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N
M(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I
M;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W
M97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE
M;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS
M(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T
M96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL
M(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O
M(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E
M<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E
M;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N
M`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@
M1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ
M(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B
M:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O
M;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R
M:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@
M8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@
M=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T
M;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY
M`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N
M`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`
M5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A
M<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT
M97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY
M`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U
M<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M
M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R
M92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F
M<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U
M<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W
M87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@
M8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A
M;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R
M,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`
M5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E
M('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A
M8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`
M5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`
M5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`
M5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T
M;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@
M9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VUE;FES=&%N`%1U<FMS(&%N
M9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N
M5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S
M=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S
M(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S
M:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A
M:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I
M(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL
M(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@=&\Z(`!5;F9I;&5D`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E
M9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=',`56YK;F]W;@!5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N
M<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E
M("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@
M9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U
M<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P
M<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E
M(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-
M4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E
M9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N
M86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5
M<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U
M`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I97<@)7,`5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`
M5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V
M:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@
M1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M
M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E
M;&-O;64L("5S`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`
M5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H
M`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@
M;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD
M($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O
M;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O
M=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X
M=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`
M665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y
M(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@
M;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R
M<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@
M<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9
M;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!:
M:6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,
M20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@
M4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN
M+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U
M<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D
M9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I
M8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`96YT
M<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I
M871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A
M<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM
M<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P
M:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E
M('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(
M5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R
M>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N
M8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ"E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`Q+3`V(#$T.C$P*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-BTP,2TS,"`R,3HR-BLP,C`P"DQA<W0M5')A;G-L871O<CH@279A;B!.
M;W)I<R`\=FEX0'9A>FMA+G-K/@I,86YG=6%G92U496%M.B!3;&]V86L@/'9I
M>$!V87IK82YS:SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@."UB:70*`"`H<')E9"`E<R!D\F%M:2D`("A+;.%V97-O
M=N$@<VMR871K82`E<RD`("AO("5S(&1N[2D`*&1N97,I`"`H>F%J=')A*0`@
M*';H97)A*0`@<OUC:&QO<[L@`"(E<R(@;FEE(&IE(&%D<F5SX7(N`"(E<R(@
M;FEE(&IE('!L871NX2!V;[5B82X`(B5S(B!N:64@:F4@;F%K;VYF:6=U<F]V
M86[I('8@<F5G:7-T<FD@2&]R9&4N`'IO8G)A>F]V8>@@<W1R;VUU("(E<R(@
M;F5B;VP@;N%J9&5N_2X`4VMU<&EN82`B)7,B(&)O;&$@<')I9&%NX2!D;R!S
M>7-TZ6UU+@!0<N%V;R`B)7,B(&)O;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+@`B
M)7,B(&YE8F]L;R!M;[YNZ2!V>71V;W)INSH@)7,N`%!O=;YI=/UC:"`E+C)F
M34(@>B!D;W9O;&5N_6-H("4N,F9-0B`H)2XR9B4E*0`E9"`E<R!A("5S`"5D
M(&1N[2!D;R!V>7!RN6%N:6$@<&QA=&YO<W1I(%;AN6AO(&AE<VQA+@!P<F5D
M<&]V9>\@;F$@)60@9&[M`"5S("T@4&]Z;N%M:V$`3V1T;&'H;VL@)7,`)7,@
M2T(`3W!E<N%C:64@^F1ROF)Y('!R92!A<&QI:^%C:74@)7,@+2!0;W1V<F1E
M;FEE`$YA<W1A=F5N:64@)7,`4F5G:7-T<F]V86YI92!D;R!A<&QI:^%C:64@
M)7,`4&]D;6EE;FMY('!O=;YI=&EA("5S`"5S('6^(&5X:7-T=6IE+@`E<R!V
M;R!V_;EK92`E<R`E<P!!<&QI:^%C:6$@)7,@:F4@<')I<')A=F5NX2!N82!V
M>6MO;F%N:64@;W!E<N%C:>T@^F1ROF)Y+D]Z;F'H=&4@N71V;W+H96L@<')I
M(&]P97+A8VGA8V@L(&MT;W+I(&-H8V5T92!V>6MO;F&[('1E<F%Z+@!0;[YA
M9'5J92!S82`E<P`E<R!M:6[Z=``E<R!N96)O;"!NX6ID96[]+@`E<R!AOB`E
M<R!Z("5S`$%D<F5SX7(@<&]UONUV871EM6$@)7,`2V%L96YDX7(@<&]UONUV
M871EM6$@)7,`4&]Z;N%M:WD@<&]UONUV871EM6$@)7,`6F]Z;F%M(/IL;V@@
M<&]UONUV871EM6$@)7,`)7,Z("5S`"5S.B!4X71O('-P<N%V82!N96UU<^T@
M8GF[(&]D(&]D;W-I96QA=&6U82P@:W1O<OT@<V$@>F]B<F%Z=6IE(&%K;R!O
M9&]S:65L871EM2!S<'+A=GDN(%IA8VAO=F%J=&4@;W!A=')N;W.[('!R:2!K
M;&EK86[M(&YA(&QI;FMY('8@<W!RX79E(&%L96)O('!O<VMY=&]V86[M(&]S
M;V)N_6-H(&EN9F]R;>%C:>T@;V1O<VEE;&%T9;5O=FDN`"P@;N%R87IO=OT@
M`"P@=B!NX7)A>F]C:"`E<R`E<P`L('!R96UE;F[A('8@<F]Z<V%H=2`E<R!A
MOB`E<P`M+2!V>6)E<G1E('-I("TM`#$R+6AO9&EN;W;](&9O<FWA=``R-"UH
M;V1I;F]V_2!F;W)MX70`,C0@:&]D[6X`/%!R961C:.%D>F%J^F-A`%!R92!T
M96YT;R!B;&]K(&IE('!OOF%D;W9A;OT@9&%T86+A>F]V_2!B86-K96YD+@!6
M>7-K>71L82!S82!ZX79AOF[A(&-H>6)A`$YA('IAN6EF<F]V86YI92!S<'+A
M=GD@:F4@<&^^861O=F%N_2!V97)E:F[](%!(4"!KM?KH+@!.82!O=F5R96YI
M92!P;V1P[7-A;F5J('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J;OT@4$=0
M(&NU^N@N`$YA(&1EN6EF<F]V86YI92!S<'+A=GD@<_H@<&]T<F5B;NDZ('9E
M<F5J;OT@4$=0(&NU^N@L('!R:7;A=&YY(%!'4"!KM?KH(&$@:&5S;&\N`$YA
M('!O9'#M<V%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9R96IN_2!01U`@
M:[7ZZ"P@<')I=N%T;GD@4$=0(&NU^N@@82!H97-L;RX`3F$@9&6Y:69R;W9A
M;FEE('-P<N%V>2!S^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH
M+"!P<FEVX71N>2!3+TU)344@:[7ZZ"!A(&AE<VQO+@!.82!P;V1P[7-A;FEE
M('-P<N%V>2!S^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH+"!P
M<FEVX71N>2!3+TU)344@:[7ZZ"!A(&AE<VQO+@!.82!Z8;EI9G)O=F%N:64@
M<W!RX79Y(&IE('!OOF%D;W9A;OT@=F5R96IN_2!334E-12!KM?KH+@!0<F5D
M<&]L=61N[6T@;V)L8>AN;P!0<F5D<&]L=61N[6T@M6%H:_T@9.&^[P!0<F5D
M<&]L=61N[6T@9.&^[P!0<F5D<&]L=61N[6T@<')E:.%N:WD`4')E9'!O;'5D
M;NUM('-N96AO=ND@<')E:.%N:WD`,3(@:&]D[6X`05!)($E$`$\@=&]M=&\@
M961I=&]R90!/+BXN`$%B<V]L^G1N>2!S<&]D;VL`06)S;VSZ=&YY('-T<F5D
M`%!R:2!V>71VX7)A;NT@5D93(&%D<F5SX7)A(&)O;"!Z86UI971N=73]('!R
M[7-T=7`N`%!R:2!V>71VX7)A;NT@5D93('/Z8F]R=2!B;VP@>F%M:65T;G5T
M_2!P<NUS='5P+@!);F9O<FWA8VEE(&\@^NAT90!(97-L;R!P<F4@^NAE=`#:
MZ&5T('IA8FQO:V]V86[]+@#:Z'1O=F%N:64`4')I9&&[`%!R:61ANR!P;V1R
M:6%D96[Z('-K=7!I;G4`4')I9&&[('!O9')I861E;ND@<'+A=F\`4')I9&&[
M.@!0<FED8;L@<VMU<&EN=0!0<FED8;L@;F]VZ2!P<N%V;P!0<FED8;L@9&/I
M<G-K=2!S:W5P:6YU(&1O("(E<R(`4')I9&&[(&1CZ7)S:V4@<'+A=F\@9&\@
M(B5S(@!0<FED8;L@<&]UONUV871EM6$Z`%!R:61ANR!S=.5P96,`4')I9&&[
M(.AL96YO=@!0<FED8;L@<.%R`%!R:61ANR!M96YU("5S(&%K;R!";^AN_2!P
M86YE;"!-;WII;&QY`%!R:61ANR!D;R!A9')E<^%R83H`4')I9&&[(&1O(&WT
M:FAO(&%D<F5SX7)A`%!R:61ANR!P;W6^[79A=&6U80`B)7,B(&)O;"!P<FED
M86[](&1O('-Y<W3I;74L(&%L92!N96UOOFYO('!R:61ANR#O86RY:64@<')I
M:&QA<V]V86-I92!I;F9O<FWA8VEE.B`E<RX`(B5S(B!B;VP@<')I9&%N_2!D
M;R!S>7-TZ6UU+B!497)A>B!S82!M]+YE=&4@<')I:&SA<VF[+@!0<FEDX79A
M;FEE('!O=;[M=F%T9;5O=B!J92!Z86OA>F%NZ2X`061R97-A`$%D<F5SX7(`
M061M:6YI<W1RX6-I82`M(&YA<W1A=F5N:64@<'+A=B!P<F4@:6[]8V@@<&]U
MONUV871EM6]V`$%D;6EN:7-T<N%C:6$`4F5K;&%M>0!!9F=A;FES=&%N`$%L
M8N%N<VMO`$%LONUR<VMO`$%L:6%S`%IA<F]V;F&[`%IA<F]V;F%N:64Z`%:Y
M971K>0!6N65T8VD@875T96YT:69I:V]V86[M('!O=;[M=F%T96QI80!6N65T
M:WD@<VMU<&EN>0!6N65T:WD@<'+A=F$`5KEE=&MY(+ET>7)I('-T<F%N>0!0
M;W9O;&F[('9I86-E<ND@861R97-Y`%!O=F]L:;L@;F%S=&%V96YI92!T>7!U
M('IO<F%D96[I:&\@>F]Z;F%M=3\`5;X@97AI<W1U:F4`06QT97)N873M=FYE
M('!R:6AL87-O=F%C:64@;65N;R!)35-0`$%L=&5R;F%T[79N92!H97-L;R!)
M35-0`$%L=&5R;F%T[79N92!P;W6^[79A=&6U<VOI(&UE;F\@24U34`!!;'1E
M<FYA=.UV;F$@92UM86EL;W;A(&%D<F5S80!!;'1E<FYA=.UV;F4@N6%B;/-N
M>0!!;'1E<FYA=.UV;GD@=&5X=#H`06UE<FEC:^$@4V%M;V$`0F]L82!Z861A
M;N$@;F5P;&%T;N$@:&]D;F]T80!.87-T86QA(&YE>F[A;6$@8VAY8F$N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6[I('!R;WAY`$]D<&]V9>\`
M06YT87)K=&EK80!!;G1I9W5A(&$@0F%R8G5D80!!<&QI:^%C:6$`6F]Z;F%M
M(&%P;&EKX6-I[0!!<&QI:^%C:6$@:F4@<')I<')A=F5NX2X`07!L:6MO=F&[
M(&YA('!O9')I861E;ND@>F1I9;5A;ND@<')I9>AI;FMY`%-C:';A;&F[`%!R
M:6)L:;YNX2!V9;5K;W.[`$%P<NUL`%9EM6MO<[L@87)C:.UV=0!-96YO(&%R
M8VCM=G4`3F%O>F%J(&-H8V5T92!V>6UA>F&[(+YI861O<[L@;R!P<FEH;.%S
M96YI92`G)7,G/P!.86]Z86H@8VAC971E('9Y;6%Z8;L@(B5S(B!A(':Y971K
M>2!P;V1S:W5P:6YY/P!!<F=E;G3M;F$`07)MZ6YS:V\`56UE;FEE`$%R=6)A
M`$]S=')O=B!!<V-E;G-I;VX`07-C:6D@=6UE;FEE`,%Z:6$O4&%C:69I8VO]
M(')E9VGS;@!6>;YA9&]V8;L@<&]T=G)D96YI92!P<F5D('9Y:V]N86[M;2!O
M<&5RX6-I[2#Z9'*^8GD_`%!O:W5S(&\@=GEM87IA;FEE(&YE97AI<W1U:OIC
M96H@<VMU<&EN>2X`4&]K=7,@;R!V>6UA>F%N:64@;F5E>&ES='5J^F-E:&\@
M<'+A=F$N`%!O:W5S(&\@^G!R879U(&YE97AI<W1U:OIC96AO('!RX79A+@!0
M;VMU<R!O(/IP<F%V=2!N965X:7-T=6KZ8V5H;R!Z9&EEM6%NZ6AO(&]B:F5K
M='4N`$%T<FEB^G1Y`$%U9W5S=`!!=7-T<N%L:6$`4F%K^G-K;P!!=71H7V-Y
M<G-Q;#H@4&^^861O=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B;VQO(&[A:F1E
M;NDN`$%U=&A?8WER=7,Z(&)A8VME;F0@;F5MX2!P;[YA9&]V86[I('-C:&]P
M;F]S=&DN`$%U=&A?8WER=7,Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!I;6%P
M(&YE8F]L;R!NX6ID96[I+@!!=71H7V9T<#H@<&^^861O=F%NZ2!R;WJY[7)E
M;FEE($944"!N96)O;&\@;N%J9&5NZ2X@4VMO;7!I;'5J=&4@4$A0(',@<')E
M<.UN8>AO;2`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@<&^^861O=F%NZ2!R
M;WJY[7)E;FEE($E-05`@;F5B;VQO(&[A:F1E;NDN`$%U=&A?:W)B-3H@<&^^
M861O=F%NZ2!R;WJY[7)E;FEE(&MR8C4@;F5B;VQO(&[A:F1E;NDN`$%U=&A?
M;&1A<#H@<')I9.%V86YI92!P;W6^[79A=&6U;W8@;FEE(&IE('!O9'!O<F]V
M86[I('!R92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@=GEM87KA=F%N
M:64@<&]UONUV871EM6]V(&YI92!J92!P;V1P;W)O=F%NZ2!P<F4@06-T:79E
M($1I<F5C=&]R>0!!=71H7VQD87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!,
M1$%0(&YE8F]L;R!NX6ID96[I+@!!=71H7VQD87`Z($YE<&]D87)I;&\@<V$@
M<')I9&&[('!O=;[M=F%T9;5A("5S+B!397)V97(@;V1P;W9E9&%L.B``075T
M:%]L9&%P.B!N97!O9&%R:6QO('-A(&]D<W1RX6YINR!P;W6^[79A=&6U82`E
M<P!!=71H7VQD87`Z(&YE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('!O=;[M
M=F%T9;5A("5S`$%U=&A?;&1A<#H@86MT=6%L:7KA8VEA('!O=;[M=F%T9;5O
M=B!N:64@:F4@<&]D<&]R;W9A;N$@<')E($%C=&EV92!$:7)E8W1O<GD`075T
M:%]M8V%L.B!P;[YA9&]V86[I(')O>KGM<F5N:64@34-!3"!N96)O;&\@;N%J
M9&5NZ2X`075T:%]S;6)A=71H.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<VUB
M875T:"!N96)O;&\@;N%J9&5NZ2X`075T96YT:69I:^%C:6$@<&]M;V-O=2!)
M34%0('-E<G9E<F$@>FQY:&%L82X`075T96YT:69I:^%C:6$@>FQY:&%L80!!
M=71E;G1I9FEKX6-I82!Z;'EH86QA+B`E<P!397)V97(@4D%$2553('IA;6EE
M=&]L(&%U=&5N=&EF:6OA8VEU+@!!=71E;G1I9FEKX6-I82!P;VUO8V]U($94
M4"!S97)V97)A('IL>6AA;&$N`$%U=&5N=&EF:6OA8VEA('!O;6]C;W4@4TU"
M('-E<G9E<F$@>FQY:&%L82X`1&]S='5P;ND@<&]L;[YK>3H`07IE<F)A:F2^
M86X`0D]&2"!%>&-U<V5S`%!O>F%D:64`1F%R8F$@<&]Z861I80!:;.D@:&5S
M;&\@<')E(&ME<F)E<F]S+@!:;.D@<&]UONUV871EM7-KZ2!M96YO('!R92!K
M97)B97)O<RX`0F%H86UY`$)A:')A:FX`0F%N9VQA9.FY`$)A<F)A9&]S`%!R
M:67H:6YO:R!S(&=R869I:V]U("(E<R(@;F5B;VP@;N%J9&5N_2X`6N%K;&%D
M;OT@<FEA9&]K`$)I96QO<G5S:V\`0F5L9VEC:V\`0F5L:7IE`$)E;FEN`$)E
M<FUU9'D`0G5TX6X`3F%R;V1E;FEN>0!";&]K("(E<R(@87!L:6OA8VEE("(E
M<R(@;F5B;VP@;N%J9&5N_2X`3F%S=&%V96YI82!B;&]K=0!4>7`@8FQO:W4`
M5'7H;ND`0F]L[79I80!:X6QOOFMY`$]K<F%J`*GM<FMA(&]K<F%J83H`3VMR
M86IE`$)O<VYA(&$@2&5R8V5G;W9I;F$`3V)E`$)O='-W86YA`$)O='1O;0!"
M;W5V970@27-L86YD`$)R87KM;&EA`$)R:71S:^D@^GIE;6EE('8@26YD:6-K
M;VT@;V-EX6YE`$)R=6YE:2!$87)U<W-A;&%M`$)U;&AA<G-K;P!:;WIN86T@
M<R!O9'+AOFMA;6D`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!$:7-T
M<FEB=>ANZ2!B;V1Y($-23`!6;&%S=&YO<W1I(%]B=6YK>2XN+@!);F-I86QI
M>N%C:6$@=GER;W9NX79A8V5J('!A;>1T:2!N96)O;&$@9&]K;V[H96[A+@!+
M86QE;F3A<@!"97IV971R:64`2V%M8F]DOF$`2V%M97)U;@!.97!O9&%R:6QO
M('-A(&%U=&]M871I8VMY(&]B;F]V:;L@:&5S;&\L(&MO;G1A:W1U:G1E('-V
M;VIH;R!A9&UI;FES='+A=&]R82X`3F5P;V1A<FEL;R!S82!Z87#M<V&[(&1O
M('/Z8F]R=2`B)7,B`$YE;6^^;F\@861M:6ES=')O=F&[(&5X=&5R;ND@;W9L
MX61AZ&4@<V5D96[M+@!.97!O9&%R:6QO('-A('-P;VIINR!S($E-05`@<V5R
M=F5R;VTZ("5S`$YE<&]D87)I;&\@<V$@;W1V;W)INR!S^F)O<B`B)7,B+@!+
M86YA9&$`6G)UN6F[`%IR=;EINR!S<'+A=G4@;R!P<F]B;.EM90!.97!O9&%R
M:6QO('-A('9Y;6%Z8;L@<_IB;W(@(B5S(BX`3F5P;V1A<FEL;R!S82!NX6IS
MNR!D;^AA<V[](&%D<F5SX7(N`$YE;6^^;F\@<&]K<F'H;W9ANR!B97H@<&%R
M86UE=')A("=T87)G971&:6QE)RX`3F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@
M861R97/A<B`B)7,B+@!.96UOOFYO(&]D<W1RX6YINRP@97AI<W1U:F4@)60@
M;F%S;&5D;W9N[6MO=BX`3F5M;[YN;R!P<F5U<W!O<FEA9&&[+"!P;^AE="!P
M;VQOOFEE:R!P<F4@<')E=7-P;W)I861A;FEE(&YE<_IH;&%S[2!S('!OZ'1O
M;2!U;&^^96[]8V@@<&]L;[YI96LN`$YE<&]D87)I;&\@<V$@<VUE<F]V8;L@
M<W!RX79U(&YA('5RZ&5NZ2#H[7-L;RX`2V%P=F5R9'-KZ2!O<W1R;W9Y`%1I
M='5L;VL`2V%T96?S<FEE(&$@<&]P:7-K>0!+86IM86YS:^D@;W-T<F]V>0!-
M;V)I;&[]('1E;&5F\VX`5FQA<W1N;W-T:2!B=6YK>0!6>7!L;F5N:64@8G5N
M:WDZ`%9L87-T;F]S=&D@8G5N:WD`4F]Z;W-T=7`@8G5N:65K.@!-;V)I;&[]
M('1E;&5F\VX`1&\@<W1R961U`%-T<F5D;V%F<FEC:^$@<F5P=6)L:6MA`%!O
M9')O8F[I(&EN9F]R;>%C:64@;R!C97)T:69I:^%T90!6;&%S=&[M:R!C97)T
M:69I:^%T=0!0;VQI=&EK>2!P<F4@8V5R=&EF:6OA='D`R&%D`%IM96YINP!:
M;65N:;L@5F&Y92!H97-L;P!.87-T879E;FEE(&UE;F$@82!A9')I97,L(&MT
M;W+I('9I9&EA(+5U9&EA+"!K9>\@Z.UT86KZ(&$@;V1P;W9E9&%J^B!N82!6
M8;EE(&4M;6%I;'DN`%IM96YA(&AE<VQA(&YI92!J92!V(&%K='7A;&YE:B!K
M;VYF:6=U<N%C:6D@<&]D<&]R;W9A;N$N("!+;VYT86MT=6IT92!S=F]J:&\@
M861M:6YI<W1RX71O<F$N`%IN86L`4U]K;VYT<F]L;W9ANR!L:6YK=2XN+@!#
M:&EL90#([6YA`%9Y8F5R=&4@87!L:6OA8VEU.@!:=F^U=&4@<VD@:&5S;&\`
M6G9OM71E('-I('!O=;[M=F%T9;5S:^D@;65N;P!6>6)E<G1E('-P]'-O8B!Z
M;V)R87IO=F%N:6$@9.%T=6UO=CH`5GEB97)T92!T>7`@N73];'4@>F]Z;F%M
M=2`H<')E('IO<F%D96[I('IO>FYA;7DI`%9I86YOZ&[](&]S=')O=@!$969I
M;NUC:6$@=')I961Y("5S(&YE8F]L82!NX6ID96[A+@!*87-N;P!/9'-T<N%N
M:;L@<'+M:V%Z>2!-4T]F9FEC90!6>6UA>F&[(&1O=&%Z`$]D<W1RX6YINR!P
M;W6^[79A=&6U83H@)7,`3V1S='+A;FF[('!O=;[M=F%T9;5A`%9Y;6%Z8;L@
M<&]UONUV871EM7-KZ2#Z9&%J90!.97-K]'(@=GEJ87-N96YI90!+;&EK;FET
M92!P<F4@<&]K<F'H;W9A;FEE`$-L:6-K871E;&P@8V5Z($A45%``6F%T=F]R
M:;L@;VMN;P!/8FQA:WD`4N%N;R!O8FQAZ&YO`$]B;&'H;F\`0V]C;W,@*$ME
M96QI;F<I($ES;&%N9',`6F)A;&F[($)OZ&[]('!A;F5L`%IB86QE;ND@;VMR
M86IE`$MO;'5M8FEA`$9A<F)A`%;]8F5R(&9A<F)Y`%;]8F5R(&9A<F)Y`%-T
MY7!C93H`3F%D<&ES>2!S=.5P8V]V`$MO;6EK<P!0<NUK87H`4'+M:V%Z;W;]
M(&EN=&5R<')E=&5R`$MO;65N=.%R`$)EOF[I(&UE;F\`2V]M;W)Y`%-P;VQO
MZ&YO<[L`4&_H[71AZ&4`4W1A=@!3=&%V`%)O>F1I96QY('8@:V]N9FEG=7+A
M8VEI`$MO;F9I9W5RX6-I82!P<F4@<WEN8VAR;VYI>N%C:74@<R!01$$L(&EN
M=&5L:6=E;G1N_6UI('1E;&5F\VYM:2!A($]U=&QO;VMO;2X`2V]N9FEG=7+A
M8VEA('!O=')E8G5J92!A:W1U86QI>N%C:74N`$MO;F9I9W5R;W9ANR`E<P!0
M;W1V<N]T92!H97-L;P!+;VYG;P!$96UO:W)A=&EC:^$@<F5P=6)L:6MA($MO
M;F=O`%-P;VIE;FEE('IL>6AA;&\N`%-P;VIE;FEE('IL>6AA;&\Z(`!+M?KH
M(&)O;"!Z86UI971N=73]('-E<G9E<F]M('9E<F5J;OUC:"!KM?KH;W8N`$NU
M^N@@8F]L('IA;6EE=&YU=/T@<V5R=F5R;VT@=F5R96IN_6-H(&NU^NAO=BX@
M1/1V;V0Z("5S("@E<RD`4W!O:F5N:64@<R!&5%`@<V5R=F5R;VT@>FQY:&%L
M;RX`2V]N=&%K='D`2V]N=&%K='D@8F]L:2#Z<W!EN6YE('9L;[YE;N$@9&\@
M5N&Y:&\@861R97/A<F$N`%1Y<"!K;VUP<FEM;W9A;NEH;R!S^F)O<G4Z`$]B
M<V%H("(E<R(`4&]K<F'H;W9ANP!#;V]K;W9E(&]S=')O=GD`0V]O:VEE`$MO
M<.UR;W9ANP!+;W#M<F]V86YI92!Z;'EH86QO.B`E<P!+;W#M<F]V8;L@=OUB
M97(`2V]S=&%R:6MA`%!O8G)EOFEE('-L;VYO=FEN>0!.97!O9&%R:6QO('-A
M('IAN6EF<F]V8;L@<W!RX79U('!O;6]C;W4@4$=0.B``3F5P;V1A<FEL;R!S
M82!P;V1P[7-ANR!S<'+A=G4@<&]M;V-O=2!01U`Z(`!.97!O9&%R:6QO('-A
M('IAN6EF<F]V8;L@<W!RX79U('!O;6]C;W4@4R]-24U%+@!.97!O9&%R:6QO
M('-A('!O9'#M<V&[('-P<N%V=2!P;VUO8V]U(%,O34E-12X`3F5P;V1A<FEL
M;R!S82!P<FED8;L@:V]N=&%K="X@)7,N`$YE<&]D87)I;&\@<V$@<')I<&]J
M:;L@:R!,1$%0('-E<G9E<G4N`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!,
M1$%0('-E<G9E<G4`3F5P;V1A<FEL;R!S82!O=F5R:;L@>F]S=&%T;VL@;F$@
M^NAT92X@)7,`3F%S=&%L82!C:'EB82!P<FD@<'+M<W1U<&4@:R!,1$%0('-E
M<G9E<G4`3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K('-E<G9E<G4@(B5S(B!P
M;VUO8V]U($944#H@)7,`3F5P;V1A<FEL;R!S82!V>71V;W)INR!Z;WIN86T@
M<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO('-A(&1EN6EF<F]V8;L@4$=0(/ID
M86IE.B``3F5P;V1A<FEL;R!S82!D9;EI9G)O=F&[(%,O34E-12#Z9&%J92X`
M3F5P;V1A<FEL;R!S82!V>6UA>F&[(&MO;G1A:W0N("5S`$YE<&]D87)I;&\@
M<V$@=GEM87IANR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO('-A
M('9Y;6%Z8;L@<VMR:7!T(&YA('5P9W)A9&4@:V]N9FEG=7+A8VEE("(E<R(N
M`$YE<&]D87)I;&\@<V$@=7+H:;L@92UM86EL;W;Z(&%D<F5S=2!P<NUJ96UC
M=2X`3F5P;V1A<FEL;R!S82!S=&EA:&YUNR!C96S](&%D<F5SX7(N`$YE<&]D
M87)I;&\@<V$@>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@<'+M:F5M8V]V+@!.
M97!O9&%R:6QO('-A('KM<VMANR!K;VUP;&5T;OT@>F]Z;F%M('IO>FYA;6]V
M('!R[6IE;6-O=BX`3F5P;V1A<FEL;R!S82!N8>CM=&&[('-T<F%TZ6=I=2`B
M)7,B+@!.97!O9&%R:6QO('-A('-P=7-T:;L@;6MD:7(@(B5S(BX`3F5P;V1A
M<FEL;R!S82!Z[7-K8;L@=F5R96IN_2!KM?KH('IO('-E<G9E<F$@:[7ZZ&]V
M+@!.97!O9&%R:6QO('-A(&]T=F]R:;L@(B5S(B!P<F4@>N%P:7,N`$YE<&]D
M87)I;&\@<V$@;W1V;W)INR`E<RX`3F5P;V1A<FEL;R!S82!O='9O<FF[(&UO
M9'5L($UA:6YT96YA;F-E7U1A<VL@)7,`3F5P;V1A<FEL;R!S82!O='9O<FF[
M(&%D<F5SX7(@(B5S(BX`3F5P;V1A<FEL;R!S82!P<FEP;VIINR!N82!,1$%0
M('-E<G9E<BX`3F5P;V1A<FEL;R!S82!P<F7H[71ANR`E<RX`3F5P;V1A<FEL
M;R!S82!O8FYO=FF[(&AE<VQO('IA9&%NZ6AO('!O=;[M=F%T9;5A+B!.:65K
M=&]RZ2!A;&5B;R!VN65T:WD@<&]D<F]B;F]S=&D@;FEE('/Z('-P<N%V;F4N
M(%-K^G-T92!T;R!Z;F]V=2!A;&5B;R!K;VYT86MT=6IT92!6X;EH;R!A9&UI
M;FES='+A=&]R82P@86L@<&]T<F5B=6IE=&4@<&]M;V,N`$YE;6^^;F\@>NUS
M:V&[($%#3`!.97!O9&%R:6QO('-A('KM<VMANR!A9')E<^%R+B`E<P!.97!O
M9&%R:6QO('-A('KM<VMANR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R
M:6QO('-A('KM<VMANR!Z;WIN86UY('!R[6IE;6-O=B`E<P!.96UOOFYO('KM
M<VMANR!I;F9O<FWA8VEE(&\@=FQA<W1N;W-T:6%C:"!S97)V97)A`$YE<&]D
M87)I;&\@<V$@=G+A=&F[(&MO;F9I9W5RX6-I=2X`3F5P;V1A<FEL;R!S82!S
M<'5S=&F[(')M9&ER("(E<R(N`$YE<&]D87)I;&\@<V$@=6QOOFF[(&MO;F9I
M9W5RX6-I=2`E<RX`3F5P;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I
M9W5RX6-I92X`3F5P;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5R
MX6-I93H@)7,`3F5P;V1A<FEL;R!S82!U;&^^:;L@<VMR:7!T(&YA('5P9W)A
M9&4@;F%S=&%V96[M(&1O.B`B)7,B+@!.97!O9&%R:6QO('-A('5L;[YINR!Z
MX6QO:'4@:V]N9FEG=7+A8VEE("5S+@!.97!O9&%R:6QO('-A('IA<.US8;L@
M:V]N9FEG=7)AZ&[]('/Z8F]R("5S+B!-]+YE=&4@<&]UOFF[(&YI96MT;W+Z
M('H@;6^^;F]S=.T@;F$@>N%P:7,@:_-D=2!N82`E<R!A;&5B;R!S:V]P[7)O
M=F&[(')UZ&YE(&OS9"!U=F5D96[](&YIOKEI92!D;R`E<RX`3F5P;V1A<FEL
M;R!S82!HM6%D8;L@;F$@3$1!4"!S97)V97)I+@!.97!O9&%R:6QO('-A('9Y
M;6%Z8;L@(B5S(BX`3F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@:V]N=&%K
M="X@)7,`3F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@>F]Z;F%M('!R[6IE
M;6-O=BX@)7,`3F5P;V1A<FEL;R!S82!Z87#M<V&[(&MO;F9I9W5RX6-I=2!P
M<F4@(B5S(CH@)7,`3F5M;[YN;R!NX6ISNR!";^AN_2!P86YE;"!-;WII;&QY
M+B!3:V]N=')O;'5J=&4L(+YE(&IE('!A;F5L(&]T=F]R96[]+@!0;W6^[79A
M=&6U;W9I("(E<R(@<V$@;F5P;V1A<FEL;R!P<FED8;L@<'+A=F$@<')E('!R
M:67H:6YO:R`B)7,B.B`E<P!0;^CM=&%N_2!T97AT`$MR86II;F$`2W5R>GD`
M5GET=F]R:;L`5GET=F]R:;L@;&EN:W4`5GET=F]R:;L@;F]V_0!6>71V;W)I
MNR!P;V1P<FEEZ&EN;VL`4'+A=F$@='9O<F-U`,CM<VQO(&MR961I=&YE:B!K
M87)T>0!#:&]R=N%T<VMO`$MU8F$`06MT=>%L;F4@-"!FX7IY`$%K='7A;&YE
M('-E9&5N:6$`06MT=>%L;GD@Z&%S`$%K='7A;&YA(%523"!J90!!:W1UX6QN
M:2!P;W6^[79A=&5L:6$`06MT=>%L;F4@<&_H87-I90!!:W1UX6QN92!P;V1M
M:65N:WDZ(`!!:W1UX6QN>2"Y=/UL`$YA<W1A=F5N:64@^FQO:"P@:W1O<ND@
M<V$@<W#ZN;MA:OH@<')I('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S+@!6
M>7-T<FEH;OJ[`%9Y<W1R:6AN^KL@=OUB97(`0WEP<G5S`,AE<VOA(')E<'5B
M;&EK80!$1`!$4TX@*'!O>G)I(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&5N;F4`
M4')E>F5R8>@@9.%T;W;I:&\@<W1R;VUU("A$871A5')E92D`5GEHM6%DX79A
M;FEE('8@9&%T86+A>F4`1.%T=6T`1.%T=6T@<')I:F%T:6$`5OUB97(@9.%T
M=6UU`$1E\@!/7V1S='+A;FF[('-TY7!E8P!$96-E;6)E<@!$97-I871K;W;I
M(.CM<VQA`%IM96ZY:;L@;V1S861E;FEE`%!R961N87-T879E;ND`4')E9&YA
M<W1A=F5NX2!F87)B80!68;EA('!R961N87-T879E;N$@:61E;G1I=&$`4')E
M9&YA<W1A=F5N_2!P<NUK87IO=OT@:6YT97)P<F5T97(`1&5F:6[M8VEE`%9Y
M;6%Z8;L`5GEM87IANR!B=6YK=0!6>6UA>F&[('-K=7!I;G4`5GEM87IANR!Z
MX7IN86T`5GEM87IANR!P<N%V;P!6>6UA>F&[(&$@;V1S='+A;FF[('-P<N%V
M>0!6>6UA>F&[(&)U;FMU`%9Y;6%Z8;L@<W3E<&5C`%9Y;6%Z8;L@97AI<W1U
M:OIC=2!A;'1E<FYA=.UV;G4@N6%B;/-N=0!6>6UA>F&[('!RX79A('!R92`B
M)7,B`$-H8V5T92!V>6UA>F&[("(E<R(@82!VN65T:WD@:F5H;R!P;V1P<N%V
M83\`5GEM87IANR!R:6%D;VL`5GEM87IANR!V>6)R86[Z(&ED96YT:71U`%9Y
M;6%Z8;L@86MT=>%L;GD@<W3E<&5C`%9Y;6%Z8;L@86MT=>%L;GD@<FEA9&]K
M`%-K<FEP="!N82!U<&=R861E(&MO;F9I9W5RX6-I92`B)7,B(&)O;"!V>6UA
M>F%N_2X`R&%S(&1O<G7H96YI80!$X6YS:V\`4&]P[;ET92!P<F]B;.EM`%!O
M<&ES`%!O9')O8FYO<W1I("AT:66^('8@;&]G;W9A8V]M('/Z8F]R92!(;W)D
M92D`1&5T86EL>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R
M82X`5OUV;VH`4F]S;OT@8F]D`%)O<V[](&)O9"!Z82!P;W-L961N^B!H;V1I
M;G4Z(`!2;W-N_2!B;V0Z(`!3;65R('JU879A(&1O<')A=F$`4VUE<B!S<')A
M=F$@9&^U879A`$%D<F5SX7(`6F]B<F%Z;W9ANR#H87,@=B`R-"UH;V1I;F]V
M;VT@9F]R;>%T93\`3F%S=&%V96YI92!Z;V)R87IE;FEA`%IO8G)A>FF[('!O
M9')O8F[Z('!R961P;W9E[P!:;V)R87IINR!P<F5D<&]V9>\@*%1!1BD`1F]R
M;>%T('IO8G)A>F5N:6$`4&]T=G)D96YI92!O(&1O<G7H96[M`$2^:6)U='-K
M;P!.979Y;6%Z8;L`3F5P;W6^[79A:G1E('!R:6%M;R!M86EN=&5N86YC92YP
M:'``3V)S86AU:F4@<')V_2!R:6%D;VL@;N%Z=GD@<&]L[3\@06L@X6YO+"!Z
M8;EK<G1N:71E('!O;.WH:V\Z(`!$;VUI;FEC80!$;VUI;FEKX6YS:V$@<F5P
M=6)L:6MA`$YE;>%T92#ZZ&5T/R!:87)E9VES=')U:G1E('-A+@!3=&EA:&YU
MNP!3=&EA:&YUNR`E<P!3=&EA:&YUNR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A
M8VEU(&%K;R!02%`@<VMR:7!T+@!:;WIN86T@<R!V_6)E<F]M`$1R;V=Y`$4M
M;6%I;`!%4E(`16MVX61O<@!5<')A=FF[`%5P<F%V:;L@8FQO:P!5<')A=FF[
M('-K=7!I;G4`57!R879INR!P<N%V;P!5<')A=FF[('!RX79A`%5P<F%V:;L@
M<'+A=F$@<')E("5S`%5P<F%V:;L@;F%S=&%V96YI82!P<F4Z`%5P<F%V:;L@
M<'+A=F$@<')E("(E<R(`57!R879INR!P<N%V82!P<F4@)7,`5GID96SA=F%N
M:64`16=Y<'0`4V%L=N%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;&]V
MX2!A9')E<V$Z`$4M;6%I;&]VZ2!A9')E<WD@;75S:6$@8GF[(')O=FYA:^DN
M`$4M;6%I;"!S('!O='9R9&5N[6T`0G+A;F$@16UA:6PM;F$M4TU3`$5M;W1I
M:V]N>0!0<N%Z9&YA('-P<N%V82X`4'+A>F1N>2!V_7-L961O:RX`4'+A>F1N
M92!P;V1M:65N:WD@:+5A9&%N:6$`4&]V;VQINR!V;&^^96YI92!O8G+A>FMO
M=B!Z($=A;.ER:>T@9&\@=&5X='4_`%!O=F]L:;L@:V]N=&5X=&]VZ2!M96YU
M('!R92!P<F%VZ2!T;&'H:61L;S\`2V]N:65C(')O:V$`6G;DZ+EINR!E9&ET
M;W(`6F%D86IT92!B97IP9>AN;W-T;OH@;W3A>FMU+"!N82!K=&]R^B!B=61E
M=&4@;75S:66[(&]D<&]V961ANR!A:R!Z86)U9&YE=&4@:&5S;&\L(&YA<'(N
M("=A:V\@<V$@=F]LX2!M;VIE('IV:65R871K;S\G.@!:861A:G1E(%523"!O
M8G+A>FMA`%IA9&%J=&4@<.US;65NX2!U=F5D96[I(&YIOKEI93H`4F]V;NUK
M;W;A($=U:6YE80!%<FET<F5A`$-H>6)A`$-H>6)A('!R:2!V>71VX7)A;NT@
M8FQO:W4Z("5S`$-H>6)A('!R:2!V>6UA>N%V86[M('5K;W1V96YI82!S>6YC
M:')O;FEZX6-I93H@)7,`0VAY8F$@<')I('9Y;6%ZX79A;NT@>N%Z;F%M=2!S
M>6YC:')O;FEZX6-I93H@)7,`0VAY8F$@<')I('KM<VMA=F%N[2!O8G-A:'4Z
M("5S`$-H>6)A('!R:2!A:W1U86QI>N%C:6D@:&5S;&$Z("5S`$-H>6)A('8@
M92UM86EL;W9E:B!S<'+A=F4N`$-H>6)A('!R:2!Z87!I<V]V86[M("(E<R(N
M`$5S=/-N<VMO`$5T:?-P:6$`171N:6-KZ0!%=7+S<&$`2V&^9/UC:"`Q-2!M
M:6[Z=`!+8;YDZ2`R(&UI;OIT>0!+8;YD_6-H(#,P('-E:_IN9`!+8;YD_6-H
M(#4@;6EN^G0`4')I(&MAOF1O;2!P<FEH;.%S96[M`$MAOF3Z('!O;&AO9&EN
M=0!+8;YD^B!M:6[Z='4`3F%P<NUK;&%D.@!3<'5S=&F[`%)O>F)A;&F[`%)O
M>F)A;&F[($)OZ&[]('!A;F5L`$_H86OA=F$@<V$@)RDG`$_H86OA=F$@<V$@
M<VQO=F\@86QE8F\@<&]D;6EE;FMA(&BU861A;FEA('8@^G9O9'IO=FOA8V@`
M1.%T=6T@97AP:7+A8VEE`$5X<&]N96YT`$9A<F)A('1E>'1U`$YA:')ANR!K
M;VYF:6=U<N%C:74@;F$@1E10`$YE<&]D87)I;&\@<V$@>NUS:V&[(&YA<W1A
M=F5N:6$N`$YA<W1A;&$@8VAY8F$@<')I('-P;VIE;NT@<R!,1$%0('-E<G9E
M<F]M+@!.87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K(%--0B!S97)V97)U
M+@!.97!O9&%R:6QO('-A(&MO<.UR;W9ANR!Z("(E<R(N`$YE<&]D87)I;&\@
M<V$@:V]P[7)O=F&[(&1O("(E<R(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@
M;F]VZ2!305-,('-P;VIE;FEE+@!.97!O9&%R:6QO('-A('!R97-U;OJ[(&1O
M("(E<R(N`$YE<&]D87)I;&\@<V$@>NUS:V&[.B`E<P!$;V)RZ0!&86QK;&%N
M9'-KZ2!O<W1R;W9Y("A-86QV[6YY*0!&865R<VOI(&]S=')O=GD`6N%V8;YN
MX2!C:'EB83H`1F%X`$9A>'D`1F5B<G7A<@!0;V-I="!T97!L;W1Y`%!O8VET
M('1E<&QO='DZ(`!-86SI('IRX;YK>0!-86SI('-N96AO=ND@<')E:.%N:WD`
M36%T:6-A('!O;.T`1FEDOFD`4_IB;W(`4&_H970@<_IB;W)O=CH@)7,@<_IB
M;W(`4&_H970@<_IB;W)O=CH@)7,@<_IB;W)O=@!3<'+A=F-A('/Z8F]R;W8`
M365N;R!S^F)O<G4`5OUB97(@<_IB;W)U`$YA:')A=&EE('/Z8F]R=0!.86AR
MX79A;FEE('/Z8F]R;W8@;FEE(&IE('!O9'!O<F]V86[I+@!&:6QT<F4`1NUN
M<VMO`%!R=N$@<&]L;W9I8V$`4')VX2"Y='9RNP!0979N_2!P;VUE<@!/=&_H
M:;L`4&SA=F%J^F-I('1E>'0`2&UL80!0<FEEZ&EN;VL@)7,@;F5E>&ES='5J
M90!&87)B82!P[7-M80!0;W1R879A`%!R92!P<F5H;&EA9&'H92P@:W1O<ND@
M;F5P;V1P;W)U:OH@;V)RX7IK>0!0<F5D<&]V9>\@*%1!1BD`4')E9'!O=F7O
M(&YA('5V961E;OT@<&_H970@9&[M("AP86WD=&%J=&4@;F$@=&\L(+YE('!R
M961P;W9E[R!J92!P<F4@9&YI(&%J(&YO8VD@82!T86L@;?2^92!V9;5KZ2#H
M[7-L;R!V>71V;W)INR!V9;5M:2"Y:7)O:_T@8FQO:RD`6F%B=61L:2!S=&4@
M:&5S;&\_`$9O<FUU;.%R90!&;W)T=6YA`%1Y<"!F;W)T=6YY`$9O<G1U;GD`
M1F]R='5N>2`R`$;S<F$`4')E<VUE<F]V86YI80!0:6$`4N%M8V4`1G)A;F/Z
M>G-K;P!&<F%N8_IZ<VMO("A%=7+S<&$I`$9R86YC^GIS:V$@1W5A>6%N80!&
M<F%N8_IZ<VMA(%!O;'ENZ7II80!&<F%N8_IZ<VME(&IUOF[I('1E<FET\W)I
MX0!/9`!:;R!S;65R=2``VG!L;OT@<&]P:7,`4W!L;@!#96SI(&UE;F\Z`$=A
M8G5N`$=A;.ER:6$L('H@:W1O<F5J(&-H8V5T92!V>FEANR!O8G+A>F]K`$=A
M;.ER:6$Z`$=A;6)I80!'96YE<F]V8;L@:V]N9FEG=7+A8VEU('!R92!A<&QI
M:^%C:74@)7,`1V5N97)O=F%N_2!K\V0`1V5O<F=I80!.96UE8VMO`$=H86YA
M`$=I8G)A;'3A<@!+<G-T;ND@;65N;P!/9&]S;&&[`$=O961E;`!';V]G;&4@
M36%P<P!(M6%D8;L@;F$@1V]O9VQE`$]D=&EE;F4@N65D96H`1W+I8VMO`$=R
M\VYS:V\`1W)E;F%D80!!9&UI;FES='+A8VEA('-K=7#M;@!-96[A('-K=7#M
M;B!N97-M^B!B>;L@<'+A>F1N90!'<F]U<%]L9&%P.B!.97!O9&%R:6QO('-A
M('!R:61ANR!S:W5P:6YU("5S+B!397)V97(@;V1P;W9E9&%L.B``1W)O=7!?
M;&1A<#H@;F5P;V1A<FEL;R!S82!V>6UA>F&[('-K=7!I;G4@)7,`1W)O=7!?
M;&1A<#H@;F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@<VMU<&EN=2`E<P!3
M:W5P:6YY`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`4'+A
M=F$@86YO;GEM;OUC:"!P;W6^[79A=&6U;W8`1W5E<W1B;V]K`$=U:6YE80!'
M=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&YE9&]V;VSM('9Y
M;6%Z8;L@<&]S;&5D;OH@8G5N:W4@=B!R:6%D:W4N`$A434Q!<F5A(&YE9&]V
M;VSM('9Y;6%Z8;L@<&]S;&5D;OT@<W3E<&5C('8@=&%B=;5K92X`2%1-3$%R
M96$@;F5D;W9O;.T@=GEM87IANR!P;W-L961N_2!R:6%D;VL@=B!T86)UM6ME
M+@!(5%10(&%U=&5N=&EF:6OA8VEA(&YE8F]L82!NX6ID96[A+@!(86ET:0!!
M;&=O<FET;75S(&AA<VAO=F%C96H@9G5N:V-I90!/<&%R`$AL879IZ&MA`$AL
M879IZ&MY`$AE87)D;W8@;W-T<F]V(&$@36-$;VYA;&1O=F4@;W-T<F]V>0!3
M:6QNX2!B^G)K80!6_;EK80!0;VUO8V[M:P!0;VUO8V[M:R!P<F4@<&]UONUV
M86YI92!E9&ET;W)A`%!O;6]C;NUK`%!O;&]G=;5A`%1U(&IE('IAZ&EA=&]K
M('/Z8F]R=3H`5GES;VOA`$1O7VUO=@!6871I:^%N`$1O;6]V`$1O;>%C82!A
M9')E<V$`1&]MX6-I('!R:67H:6YO:P!496QE9O-N(&1O;6]V`$AO;F1U<F%S
M`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@=B!S<'+A=F4@)7,@8F]L
M:2!NX6ID96[I(&YE<&QA=&[I("5S(%A-3"#Z9&%J90!(;W)D92]+;VQA8CH@
M<R!O8FIE:W1O;2`E<R!N96MO<F6Y<&]N9'5J92"^:6%D;F$@<W!RX79A+@!(
M;W)D92]+;VQA8CH@=B!S<'+A=F4@)7,@;F5B;VP@;N%J9&5N_2"^:6%D96X@
M;V)J96MT('1Y<'4@)7,`2&]R9&4O2V]L86(Z(/IS<&6Y;F4@;V1S='+A;F5N
MZ2`E<R`B)7,B`$AO<F1E+TMO;&%B.B!I;G1E9W+A8VEA('9YOF%D=6IE(%!(
M4"!R;WJY[7)E;FEE("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!N97!O9&%R:6QO
M('-A('9Y='9O<FF[(&YO=OT@6$U,('-T<F]M('!R92!O8FIE:W0@)7,`2&]R
M9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@;V1S='+A;FF[("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A('KM<VMANR!-24U%($E$('!R
M92#H87.[('1Y<'4@)7,`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@<WEN
M8VAR;VYI>F]V8;L@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&]D87)I
M;&\@<V$@<WEN8VAR;VYI>F]V8;L@>F1I9;5A;ND@;V)J96MT>3H@)7,`2&]R
M9&4O2V]L86(Z(&YE>F[A;7D@>F1I9;5A;OT@;V)J96MT("(E<R(`2&]R:7IO
M;G3A;&YA(.AI87)A`$AO<FEZ;VYTX6QN92!V>7!L;F5N:64`2&]R:7IO;G3A
M;&YE.@!!:V\@<W1E('-A('-E;2!D;W-T86QI/R`H4')O<^UM(&YA:&SA<W1E
M(2D`2V^U:V\@<W3E<&-O=B!C:&-E=&4@>FSZZ&F[/P!:861A:G1E('!OZ&5T
M('!O;.T@*'-TY7!C;W8I/P!+;[5K;R!R:6%D:V]V(&-H8V5T92!Z;/KH:;L_
M`%9L:&MO<[L`5FQH:V]SNSH@`$AU;6]R:7-T:0!-8>]A<G-K;P!.97!O9&%R
M:6QO('-A('9Y='9O<FF[($E-05`@<V-H<N%N:W4Z("5S`$YE<&]D87)I;&\@
M<V$@=GEM87IANR!)34%0('-C:'+A;FMU.B`E<P!.97!O9&%R:6QO('-A('9Y
M='9O<FF[($E-05`@:W;S='4Z("5S`$E0(&%D<F5S80!)4"!A9')E<V$@;FEE
M(&IE(&1O<W1U<&[A+@!)4"!A9')E<V$@;FEE(&IE('8@<N%M8VD@9&]V;VQE
M;NEH;R!#2412(&)L;VMU+@!0;W)UN65N:64@<')A=FED;&$@;R!P979N96H@
M25`@861R97-E+@!6;&^^:;L@:[7ZZ"!?<')E9`!)<VQA;F0`26)A(&EK;VYY
M`$EK;VYY('!R92`E<P!):V]N>2!A('1E>'0`3N%Z;W8@:61E;G1I='DZ`$%K
M('-A(&YE>F]B<F%Z[2!K;W)E:W1N92P@)7,@82!O='9O<NT@<V$@=B!N;W9O
M;2!O:VYE+@!!:R!N979I9.UT92!P<FD@<&]UOFET[2!);G1E<FYE="!%>'!L
M;W)E<F$@OFEA9&YE(&EK;VYY+"!P;W1R96)U:F5T92!Z8;EK<G1N^KL@=/IT
M;R!V;[5B=2!P<F4@=GEP;G5T:64@<')I97-V:71N;W-T:2!03D<@;V)RX7IK
M;W8N`$%K('9I9.UT92!T^G1O('-P<N%V=2!A(&YE=FED[71E(&]B<N%Z;VLL
M(&]B<N%Z;VLL(&MT;W+]('-T92!C:&-E;&D@;F%H<F&[+"!N96WTOF4@8GF[
M('IO8G)A>F5N_2!V;R!68;EO;2!P<F5H;&EA9&'H:2X`56OAOFMA(&]B<N%Z
M:V$Z`%523"!O8G+A>FMA`%523"!O8G+A>FMA.@!/8G+A>F]K('H@9V%LZ7)I
M90!/8G+A>F]K('H@9V%LZ7)I93H`3F%H<F%T:64@;V)RX7IK=0!/8G+A>FMY
M`$EM<&]R="P@:W)O:R`E9`!);7!O<G1O=F%NZ2!P;VQE.B`E<P!);7!O<G1O
M=F%NZ2!P;VQI83H`5FQOOFF[(&NU^N@@7WIA`$)O;"!Z861A;OT@;F5S<'+A
M=FYY(&OS9"!A:V-I92X`3F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A
M+V%L96)O(&AE<VQO`$YE<W!RX79N92!P;W6^[79A=&6U<VOI(&UE;F\@86QE
M8F\@86QT97)N873M=FYA(&%D<F5S82X@4VOZ<W1E('1O('IN;W9U(&%L96)O
M(&MO;G1A:W1U:G1E('-P<N%V8W4@5N&Y:&\@<WES=.EM=2P@86L@<&]T<F5B
M=6IE=&4@<&]M;V,N`%IVY.BY:;L@;V1S861E;FEE`$EN9&EA`$IE9&YO=&QI
M=NT@<&]UONUV871E;&EA`$EN9&]NZ7II80!);F9O`$EN9F]R;>%C:64`26YF
M;W)MX6-I92!UOB!N:64@<_H@9&]S='5P;NDN`%9L;[YINR!?<W3E<&5C('IA
M`%9L;[YINR!O8G+A>F]K`%9L;[YINR!T86)UM6MU`%9L;[YINR!L:6YK=0!6
M;&^^:;L@7W-TY7!E8R!P<F5D`%9L;[YINR!N;W;]('-TY7!E8R!Z82!A:W1U
MX6QN>0!6;&^^:;L@;F]V_2!S=.5P96,@<')E9"!A:W1UX6QN>0!6;&^^:;L@
M;F]V_2!R:6%D;VL@>F$@86MT=>%L;GD`5FQOOFF[(&YO=OT@<FEA9&]K('!R
M960@86MT=>%L;GD`5FQOOFF[(&]D<W1A=F5C('IA(&%K='7A;&YY(&)O9`!6
M;&^^:;L@;V1S=&%V96,@<')E9"!A:W1UX6QN>2!B;V0`5FQOOFF[(&%L=&5R
M;F%T[79N=2"Y86)L\VYU`%IA9&%J=&4@92UM86EL;W;Z(&%D<F5S=2P@;F$@
M:W1O<OH@9&]S=&%N971E(&YO=ND@:&5S;&\Z`%9L;[YINR!B=6YK=2!Z80!6
M;&^^:;L@8G5N:W4@<')E9`!6;&^^:;L@<W3E<&5C('IA`%9L;[YINR!S=.5P
M96,@<')E9`!6;&^^=&4@<W!RX79Y`%9L;[YINR!O9'-T879E8R!Z80!6;&^^
M:;L@;V1S=&%V96,@<')E9`!6;&^^:;L@<FEA9&]K('IA`%9L;[YINR!R:6%D
M;VL@<')E9`!:861A:G1E('!OOF%D;W9A;OH@;V1P;W9E[R!N82!B97IP9>AN
M;W-T;OH@;W3A>FMU.@!6;&^^:;LO=7!R879INR!O8G+A>F]K`%9L;[YINR]U
M<')A=FF[(&QI;FMU`$YA(&]D;W-I96QA;FEE('!R92!Z;WIN86T@<'+M:F5M
M8V]V(&YE;>%T92!D;W-T871OZ&[](&MR961I="X`3F5D;W-T871OZ&[](&MR
M961I="X`0V5LZ2#H[7-L;P!:;WIN86T@8V5L_6-H(.AI<V5L`$YE<&QA9&[I
M(%5$2"`H57-E<B!$871A($AE861E<BP@2&QA=FGH:V$@<&]UONUV871EM7-K
M_6-H(/ID86IO=BDN`$YE<&QA=&[I(/ID86IE(&9O<FWA='4@6DE0+@!.97!L
M871NX2!A<&QI:^%C:6$N`$YE<&QA=&[I($E$(&3A=FMY+@!";VQI(&]D;W-L
M86[I(&YE<&QA=&[I(/ID86IE+@!.97!L871NX2!C:66U;W;A(&%D<F5S82X`
M3F5P;&%T;OT@9F]R;>%T('/Z8F]R=0!.97!L871N_2!L:6-E;NAN_2!KM?KH
M+@!";VQA('IA9&%NX2!N97!L871NX2!L;VMA;&ET82X`3F5P;&%T;N$@:&]D
M;F]T82!M<V=?='EP92X`3F5P;&%T;N$@86QE8F\@8VC]8F%J^F-A(&AO9&YO
M=&$@87!I7VED+@!.97!L871NZ2!A;&5B;R!C:/UB86KZ8V4@<&%R86UE=')E
M+@!.97!L871NZ2!R;V1IZ&]V<VOI('!RX79O+@!.97!L871NZ2!I9"!P87)T
M;F5R82X`3F5P;&%T;OT@:_-D('!R;V1U:W1U+@!.97!L871N_2!P<F]T;VMO
M;`!.97!L871N_2!P<NUJ96UC83H@(B5S(@!.97!L871N_2!O8FIE:W0@>F1I
M9;5A;FEA`$YE<&QA=&[A('ID<F]J;W;A(&%D<F5S82X`3F5P;&%T;ND@^F1A
M:F4@=6YI8V]D92X`26YV96YTX7(`26YV97)T;W9ANR!V_6)E<@!)<N%N`$ER
M86L`S7)S:V\`27-L92!O9B!-86X`3VIE9&EN96SI(&+Z<FMY`$EZ<F%E;`!6
M>61A=F%T9;4`2W5R>NUV80!486QI86YS:V\`2F%M86IK80!*86YUX7(`2F%P
M;VYS:V\`2F5R<V5Y`$IO<F3A;@!*^FP`2OIN`%IA<F]V;F&[`%IA<F]V;F&[
M(&1O('-T<F5D=0!:87)O=FYANR!D;R!B;&]K=0!:87)O=FYANR!VM6%V;P!:
M87)O=FYANR!V<')A=F\`2V%Z86-H<W1A;@!0;VYE8VAANR!O<FEG:6[A;#\`
M2V7R80!+97)B97)O<R!S97)V97(@>F%M:65T;VP@875T96YT:69I:^%C:74N
M`$ME<FYE;"UN;W;AZ&EK;W9I80!6>71V;W)E;FEE(&NU^NAA`$1I9VETX6QN
M>2!O9'1L8>AO:R!KM?KH80!$Y;YK82!KM?KH80!4>7`@:[7ZZ&$`4&]UOFET
M:64@:[7ZZ&$`2[7ZZ"!UOB!E>&ES='5J92!N82!S97)V97)I('9E<F5J;OUC
M:"!KM?KH;W8N`$1E=&D`2VER:6)A=&D`I75D;W9O9&5M;VMR871I8VOA(')E
M<'5B;&EK82!+\W)E80!+\W)E:G-KX2!R97!U8FQI:V$`2W5V86IT`$MI<F=I
MN7-K;P!6>E]HM6%D`$IA>GEK`$QA;W,`4&]S;&5D;N$@<&]L;W9I8V$`4&]S
M;&5D;N$@>FUE;F$@:&5S;&$`4&]S;&5D;N$@N71V<KL`4&]S;&5D;N$@86MT
M=6%L:7KA8VEA.@!0;W-L961NZ2!P<FEH;.%S96YI93H@)7,`4&]S;&5D;ND@
M<')I:&SA<V5N:64Z("5S('H@)7,`4&]S;&5D;ND@<')I:&SA<V5N:64Z(&YI
M:V1Y`$QO='FY<VMO`%!RX79O`%9Z:+5A9`!.96-H86IT92!P<N%Z9&YE('!R
M92"^:6%D96X@;VMR86H`3&EB86YO;@!6M6%V;P!(;&%V:>AK82!VM6%V;P!(
M;V1N;W1Y(':U879O`$QE<V]T:&\`VG)O=F7R`$QI8NER:6$`3.UB>6$`3&EC
M:'1E;KET86IN<VMO`*5A:&OI(&UR:&]L96YI90"E86AK_2!DX;[O`%+A;F\@
MM6%H:_T@9.&^[P!.97-K]'(@M6%H:_T@9.&^[P"E86AKZ2!D8;[O;W;I('!R
M96CA;FMY`*5A:&O](&3AON\@<R!H<FUE;NUM`*5A:&OI('-N9;YE;FEE`*5A
M:&OI('-N96AO=ND@<')E:.%N:WD`3&EM97)I8VL`3&EN:V$`3&EN:V$@=6MA
M>G5J92!N83H`4')E<&]J:;L@92UM86EL;W;Z(&%D<F5S=2!S;R!S='+A;FMO
M=2!N82!P[7-A;FEE('!ON71Y`$QI;FMY`$QI;G5X($-O;VMI90!:;WIN86T@
M+2!P;W6^[79A=&6U('5V:63M('!R:67H:6YO:P!6>7#M<V&[('IO>FYA;2!D
M871A8N%Z`%IO>FYA;2!TZ6T@4&]M;V-N[6MA`%9Y<.US8;L@>F]Z;F%M('1A
M8G5L:65K`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W
M;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E
M`%IO8G)A>F5N:64@<V5D96[M('IL>6AA;&\Z("5S`%IO8G)A>F5N:64@<&]U
MONUV871EM6]V('IL>6AA;&\Z("5S`%IO8G)A>F]V86YI92!Z;WIN86UU('!O
M=;[M=F%T9;5O=B!J92!Z86OA>F%NZ2X`3&ET97)A=/IR80!,:71V80!.8>CM
M=&%V82!S82XN+@!-:65S=&YY(.AA<SH@`$QO:V%L:7KA8VEA(&$@Z&%S`$QO
M:V%L:71A`%!R:6ALX7-E;FEE`%KA>FYA;7D@<')E9&-HX61Z86KZ8V5J('-Y
M;F-H<F]N:7KA8VEE`$]D:&SA<VF[`%!R:6ALX7-E;FEE`-IL;VAY('!R:2!P
M<FEH;.%S96[M`%!R:6ALX7-E;FEE('IL>6AA;&\L('!R971OOF4@<W1E('IA
M9&%L:2!N97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&%L96)O(&AE<VQO
M+@!0<FEH;.%S96YI92!Z;'EH86QO+@!$;&C]('1E>'0`3.%S:V$`3NUZ:V$`
M36%LZ2!G<NEC:V4@<.US;65NX0!-86SI(&QA=&EN<VOI('#M<VUE;N$`36%L
MZ2!R[6US:V4@Z.US;&EC90!,=7AE;6)U<G-K;P!-30!3<'+A=F$@9/)A`%!R
M[6QO:&$@35,M5$Y%1B!N96]B<V%H;W9A;&$@OFEA9&YE(/ID86IE+@!-4T<`
M36%C86\`36%C963S;G-K;P!-861A9V%S:V%R`$WA9VEA`%!ON71A`%!O<VQA
MNR!E+6UA:6P@861M:6YI<W1RX71O<F]V:0!6>71V;W)INR!L:6Y?:W4N+BX`
M36%L87=I`$UA;&%J>FEA`$UA;&5D:79Y`$UA;&D`36%L=&$`4W!R879O=F&[
M('IO>FYA;2!K871E9_-R:>TL(',@:W1O<OUM:2!O>FYAZ'5J971E('!O;&^^
M:WD@82!F87)B>2!A<V]C:6]V86[I(',@=/UM:71O(&MA=&5G\W)I86UI+@!-
M87!A($UA<#(T`$UA<&$@36%P475E<W0`36%P;W9A;FEA('5L;[YE;NDN`$UA
M<F5C`$]K<F%J`$]Z;F'H:;L@<'+M>FYA:VUI(%!R9>CM=&%NZ2].97!R9>CM
M=&%NZ0!/>FYAZ&F[(&EN_6UI('!R[7IN86MM:2`H;F%P<BX@1/1L9;YI=.DO
M6F]D<&]V961A;NDI`$UA<G-H86QL;W9E(&]S=')O=GD`36%R=&EN:6L`6FAO
M9&[I('!O;&EA`$UA=7)E=.%N:6$`36%U<NUT:75S`$UA>&EMX6QN>2!P;W9O
M;&5N_2!K<F5D:70N`$)O;"!P<F5K<F_H96[](&UA>&EMX6QN>2!P;^AE="#H
M87-T[2!S<'+A=GDN`$YA:G9YN;EI82!T97!L;W1A('IA('!O<VQE9&[]8V@@
M,C0@:&]D[6XZ(`!.86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#8@
M:&]D[6XZ(`!-87AI;>%L;GD@<&_H970@8FQO:V]V('!O<G3A;'4`36%X:6WA
M;&YA(&3EOFMA`$WA:@!-87EO='1E`$UE9&EC[6YA`,AL96YO=FEA`%IO8G)A
M>F5N:64@;65N=3H`6FSZZ&F[(&)U;FMY`%-P<N%V80!3<'+A=F$@8F]L82#Z
M<W!EN6YE(&]V97)E;N$L(&%L92!C97)T:69I:^%T('!O9'!I<W4@<V$@;F5P
M;V1A<FEL;R!O=F5R:;LN`%!L871N;W.[('-P<N%V>2!V>7!RN6%L82X`5'EP
M('-P<N%V>0!0;^AA<VEE($UE=&%R`-ID86IE($UE=&%R(&YI92!S^B!D;W-T
M=7!NZ2X`VF1A:F4@365T87(@;FEE('/Z(&L@9&ES<&]Z[6-I:2X@1&5T86EL
M>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82X`4WES=.EM
M($UE=&%R1$(@;FEE(&IE('!R:7!O:F5N_2X`365T\V1A`$UE=/-D82`B)7,B
M(&YI92!J92!D969I;F]V86[A`$YE9&5F:6YO=F%NX2!M973S9&$N(%9O;&%N
MZ2!Z(&UE=/-D>3H@)7,`365T<FEC:^D`365X:6-O`$UI:W)O;NEZ<VME(&9E
M9&5R873M=FYE(+ETX71Y`%-T<F5D`%1Y<"!-:6UE`$YA:FYIOKEI82!T97!L
M;W1A('IA('!O<VQE9&[]8V@@,C0@:&]D[6XZ(`!.86IN:;ZY:6$@=&5P;&]T
M82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ(`!-:6YI;>%L;F$@9&]B82!P;&%T
M;F]S=&D@:&5S;&$@9;ET92!N979Y<'*Y86QA`%IR:V%D;&]V;R!O8G+A=&F[
M`%+T>FYE`$-H_6)A(&)A;.UK(%!%05(@2%144%]297%U97-T+@!#:/UB82!K
M;VYF:6=U<N%C:6$N($%K(&-H8V5T92!P;W6^[79ANR!T^G1O(&%P;&EKX6-I
M=2P@;75S[71E('1E<F%Z('9Y9V5N97)O=F&[(&MO;F9I9W5RX6-I=2X`0VC]
M8F$@240@<W!RX79Y+@!#:/UB82!P;[YA9&]V86[](%!%05(@8F%L[6L@36%I
M;"X`0VC]8F$@240@<F5LX6-I92X`4&]N`$UO8FEL;OT@;6%I;`!-:65R;GD`
M1.%T=6T@<&]S;&5D;F5J('IM96YY`%5P<F%V:;L@55),`$UO9'5L=7,`36]L
M9&%V<VMO`$UO;F%K;P!-;VYG;VQS:V\`365S:6%C(&$@<F]K`$UE<V'H;F4`
M36]N='-E<G)A=`!-97-AZ&[I(&;A>GD`3F$@<FEA9&MU("5D(&)O;&\@;N%J
M9&5N_6-H('9I86,@<&]L[2!A:V\@;^AA:^%V86[]8V@@)60N`$UA<F]K;P!0
M<F5V8;YN92!J87-N;P!0<F5V8;YN92!O8FQAZ&YO`%!R979AOFYE('-L;F7H
M;F\`4')E<W5N^KL@9&]L=0!0<F5S=6[ZNR!VM6%V;P!0<F5S=6[ZNR!V<')A
M=F\`4')E<W5N^KL@:&]R90!0<F5S=6[ZNR!D;VQU`%!R97-U;OJ[(&AO<F4`
M36]Z86)M:6L`5FEA8_IR;W;R;W;I('9Y8F5R86-I92!Z;WIN86UY`%9I86-N
MX7-O8F[](';]8F5R`$UO:F4@:V]N=&\`26YF;W)MX6-I92!O(&UO:F]M(/KH
M=&4`3?1J('!O<G3A;`!6>FBU860@;?1J:&\@<&]R=.%L=0!->6%N;6%R`$YI
M92P@3D53VDA,05/-32X`365N;P!.86WM8FEA`$YA=7)U`$YE<.%L`$AO;&%N
M9'-K;P!(;VQA;F1S:^D@06YT:6QY`%KA:VQA9&[A(%523"!.971S8V%P90!5
M4DP@<')E('IN97!L871N96YI92!C97)T:69I:^%T;W8@0T$@3F5T<V-A<&4`
M55),('!R92!P;VQI=&EK=2!#02!.971S8V%P90!54DP@<')E(&]B;F]V96YI
M92!P;&%T;F]S=&D@8V5R=&EF:6OA=&]V($YE='-C87!E`%523"!P<F4@>FYE
M<&QA=&YE;FEE(&-E<G1I9FEKX71O=B!.971S8V%P90!-96YO(%-33"!S97)V
M97)A($YE='-C87!E`$MO;65N=.%R(&-E<G1I9FEKX71U($YE='-C87!E`%1Y
M<"!C97)T:69I:^%T=2!.971S8V%P90!3:66[`$YI:V1Y`$YO=N$@2V%L963S
M;FEA`$YO=N$@:V%T96?S<FEA`$YO=N$@<W!RX79A('!R92`E<P!.;W8`3F]V
MZ2!P;W6^[79A=&6U<VOI(&UE;F\@*&YE<&]V:6YNZ2D`3F]V_2!:Z6QA;F0`
M3F]VZ2!H97-L;P!0;&%T;F]SNR!N;W;I:&\@:&5S;&$@=GEP<KGM("5X+@!.
M;W;I(&AE<VSA(&YI92!S^B!R;W9N86OI+@!.;W;I(&]K;F\@*%]B;&%N:RD`
M3F5W<P!$:7-K=7-NZ2!S:W5P:6YY`,]A;&5J`$YA<VQE9'5J^F-E(#0@9N%Z
M>0#/86RY:64@;F%S=&%V96YI80!.87-L961U:OIC83X`3FEK87)A9W5A`$YI
M9V5R`$YI9^ER:6$`3F]C`$YI=64`3FEE`$YI92!S^B!D;W-T=7!NZ2"^:6%D
M;F4@:V]N9FEG=7)AZ&[I(/ID86IE+"!P<F4@:W1O<ND@8GD@<V$@9&%L:2!Z
M;V)R87IINR!R;WID:65L>2X`4')E('9Y=';A<F%N:64@25-/(&]B<F%Z;W8@
M;FEE(&IE(&L@9&ES<&]Z[6-I:2"^:6%D;F$@<W1R873I9VEA+@!.965X:7-T
M=6IE(+EA8FSS;F$@<')E(&3A=FMU+@!.82!P;[YA9&]V86YE:B!P;WKM8VEI
M(&YE97AI<W1U:F4@OFEA9&5N(&)L;VLN`%!R92!-0T%,(&%U=&5N=&EF:6OA
M8VEU(&YE8F]L;R!Z861A;ND@;65N;R!K86QE;F3A<F$N`*YI861N82!Z;65N
M82X`2R!T;VUU=&\@<'+A=G4@;F5M;[YN;R!P<FED8;L@OFEA9&YE('!O9')I
M861E;ND@<'+A=F$N`%!R92`E<R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I
M82X`4')E($944"!61E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N`%!R
M92!344P@5D93(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@!0<F4@4U%,
M+49I;&4@5D93(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@"N:6%D96X@
M:W)E9&ET+@!.96)O;&\@N7!E8VEF:6MO=F%NZ2!M:65S=&\@=7+H96YI82X`
M4_IB;W(@;F5B;VP@;F%H<F%N_2X`3F5B;VQI(&[A:F1E;ND@OFEA9&YE(&EK
M;VYY+@!.:64@:F4@;F%S=&%V96[A(&QO:V%L:71A+@!.96)O;&$@>F%D86[A
M(&QO:V%L:71A+@!.96)O;&$@>F%D86[A(+YI861N82!S<'+A=F$N`$YE8F]L
M;R"Y<&5C:69I:V]V86[I(+YI861N92!M96YO+@!.96)O;&\@N7!E8VEF:6MO
M=F%NZ2#H[7-L;RX`KFEA9&YE('5RX;YL:7;I(&9O<G1U;GD`4')E($A45%`@
M875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($E-05`@
M875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($ME<F)E
M<F]S(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!,
M;V=I;B!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@
M4$%34U=$(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R
M92!334(@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`3F5B
M;VQA('IA9&%NX2!C97-T82!K('!R;V=R86UU($]P96Y34TPN(%!R;V=R86T@
M3W!E;E-33"!J92!P;W1R96)N_2!N82!P<N%C=2!S(/ID86IM:2!02T-3(#$R
M+@"N:6%D;F4@<')E8FEE:&%J^F-E('!R:6ALX7-E;FEA+@!+=O-T82!N:64@
M:F4@;F%S=&%V96[A+@!"97H@Z&EA<@!.96)O;""Y<&5C:69I:V]V86[](&]D
M9&6U;W9AZ"X`0F5Z('-T<N%N`%/Z8F]R(&YE;N%J9&5N_0!0<F4@=GER;W9N
MX79A8VEU('!A;>2[(&YI92!J92!D;W-T=7!N_2"^:6%D96X@9&_H87-N_2!P
M<FEEZ&EN;VLN`$YE8F]L;R!O9&]S;&%NZ2!P;W6^[79A=&6U<VOI(&UE;F\@
M82]A;&5B;R!H97-L;RX`3F5B;VQI('9RX71E;ND@<&QA=&[I(%A-3"#Z9&%J
M90"N:6%D;F4@:&]D;F]T>0!6('#T=F]D;F5J(&MO;F9I9W5RX6-I:2!N96)O
M;&$@;N%J9&5NX2"^:6%D;F$@=F5R>FEA+B!6>6=E;F5R=6IT92!Z;F]V=2!K
M;VYF:6=U<N%C:74N`%8@:V]N9FEG=7+A8VEI(&YE8F]L82!NX6ID96[A(+YI
M861N82!V97)Z:6$N(%9Y9V5N97)U:G1E('IN;W9U(&MO;F9I9W5RX6-I=2X`
MKFEA9&5N`*YI861N92`H<&]UOFF[(&EM<&QI8VET;OH@:&]D;F]T=2D`3W-T
M<F]V($YO<F9O;&L`4V5V97)NX2!P;VQO9W6U80!3979E<F[I($UA<FGA;G-K
M92!O<W1R;W9Y`$[S<G-K;P!.97!L873M('!O`$YE<&QA=.T@<')E9`!.:64@
M:F4@861R97/A<@!.:64@:F4@:6UP;&5M96YT;W9A;NDN`$YE;F%S=&%V96[I
M`$YI92!J92!P;V1P;W)O=F%NZ2X`4&]Z;N%M:WD`3FGH(&YA('!R97IE<F%N
M:64L('9RX;MT92!S82!S<.2[+@!.;W9E;6)E<@#([7-L;P!0;^AE="!Z;F%K
M;W8`4&_H970@<W3E<&-O=@!0;^AE="!R:6%D:V]V`%!R92!A:W1U86QI>N%C
M:74@>F]Z;F%M=2!P<NUJ96UC;W8@;F5B;VQI(+EP96-I9FEK;W9A;ND@Z.US
M;&$N`$]+`$]B:F5K=`!!=71O<B!O8FIE:W1U`$]S;6GH:V]V_0!/:W3S8F5R
M`$9I;'1E<B!N82!N863A=FMY`%!R86-O=FES:V\`4W1A<ND@82!N;W;I(&AE
M<VQO(&UU<VEA(&)YNR!O9&QIN6[I+@!3=&%RZ2!H97-L;P!3=&%RZ2!H97-L
M;R!N96)O;&\@>F%D86[I('-P<N%V;F4N`$]MX6X`26)A($E-05`@<V5R=F5R
M>2!P;V1P;W)U:OH@>F1I9;5A;ND@<')I9>AI;FMY+@!)8F$@=7+AOFQI=ND@
M9F]R='5N>0!*92!P<NUP=7-T;N$@:6)A(&IE9&YA(&4M;6%I;&]VX2!A9')E
M<V$N`%9L87-T;NUK82!A;&5B;R!P<N%V82!V;&%S=&[M:V$@<')E('ID:66U
M86[](&]B:F5K="!M]+YE('IM96YINR!I8F$@=FQA<W1N[6L@86QE8F\@<WES
M=.EM;W;](&%D;6EN:7-T<N%T;W(`3W1V;W)INR!V(&YO=F]M(&]K;F4`0VAY
M8F$@3W!E;E-33#H@;F5P;V1A<FEL;R!S82!Z[7-K8;L@^F1A:F4@>B!P;V1P
M[7-A;F5J(.AA<W1I(%,O34E-12X`3W1V;W)INR!T^G1O(&QI;FMU('8@;F]V
M;VT@;VMN90!/<&5R8>AN_2!S>7-TZ6T`3F%S=&%V96YI80!.87-T879E;FEA
M("5S`%IO<F%D96[]('IO>FYA;0!/<F=A;FEZX6-I80!/<F=A;FEZ8>ANX2!J
M961N;W1K80!/<F=A;FEZ;W9A;FEE`%#T=F]D;N$@N6%B;/-N82!A<&QI:^%C
M:64`4/1V;V1NZ2"Y86)L\VYY('8@)7,Z`$ENZ0#/86RY:64@:6YF;W)MX6-I
M90!0<N%V82!V;&%S=&[M:V$`4$%-(&%U=&5N=&EF:6OA8VEA(&YI92!J92!D
M;W-T=7!NX2X`4$5!4CI-86EL(&)A8VME;F0`1&EG:73A;&YY('!O9'!I<R!0
M1U``VF1A:F4@>F&Y:69R;W9A;ND@<&]M;V-O=2!01U``4$=0('9E<F5J;OT@
M:[7ZZ`#:9&%J92!P;V1P[7-A;NDO>F&Y:69R;W9A;ND@<&]M;V-O=2!01U``
M4$A0(&OS9`!02%`@4VAE;&P`4&]P;VQU9&[M(+5A:&O](&3AON\`4&]P;VQU
M9&[M('!R96CA;FMY`%!O<&]L=61N[2!S;F6^96YI90!0;W!O;'5D;NT@<VYE
M:&]VZ2!P<F5HX6YK>0!0;W!O;'5D;NT@<VYEOF5N:64`4&]P;VQU9&[M(&+Z
M<FMY`$-H_6)A(')O>KGM<F5N:64@4$]325@`4%](4"!3:&5L;`!6>7!L;F5N
M:64`4&%K:7-T86X`4&%L875S:^D@;W-T<F]V>0!086QE<W3M;G-K92#Z>F5M
M:64`4&%N86UA`%!A<'5A($YO=N$@1W5I;F5A`%!A<F%G=6%Y`,AI87-T;^AN
M92!O8FQAZ&YO`$AE<VQO`$AE<VQO(&)O;&\@^G-P9;EN92!Z;65N96[I+@!.
M97-P<N%V;F4@:&5S;&\`4')E(&%U=&5N=&EF:6OA8VEU(%)!1$E54R!J92!V
M>;YA9&]V86[I(&AE<VQO+@!(97-L;R!S('!O='9R9&5N[6T`2&5S;&\Z`$AE
M<VQO.B``2&5S;.$@;75S:6$@8GF[(')O=FYA:^DN`%9L;[YINP!6;&^^:;L@
M>F\@<V-H<N%N:WD`0V5S=&$`4')E8FEE:&%J^F-E(')E9VES='+A8VEE.@"E
M=61I80!097)C96YT`%9Y:V]N8;L@;W!E<N%C:64@^F1ROF)Y`%9Y:V]N8;L@
M;W!E<N%C:64@^F1ROF)Y('!R:2!P<FEH;.%S96[M/P!0<N%V;P!0<N%V;R`B
M)7,B(&YE8F]L;R!V>6UA>F%NZ2X`4'+M<W1U<"!Z86UI971N=73]`%!RX79A
M`$%D;6EN:7-T<N%C:6$@<'+A=@!/<V]B;ND@:6YF;W)MX6-I90!097)U`$1O
M;>%C92!Z=FEE<F%TX0!&:6QI<.UN>0!496QE9O-N`$9O=&]G<F%F:64`4&ET
M8V%I<FX`0F]D;W8`2VQI:VYI=&4@<')O<^UM(&1O(&YE:F%K96H@8G5N:WD`
M4&]T=G+O=&4@<')O<^UM+""^92!C:&-E=&4@;V1S='+A;FF[('1E;G1O(&5L
M96UE;G0Z`%!O='9R[W1E('!R;W/M;2P@OF4@8VAC971E(&]D<W1RX6YINR!L
M:6YK=2!Z('1O:'1O(&5L96UE;G1U+@!:861A:G1E('!R;W/M;2!M97-I86,@
M82!R;VLN`%IA9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S<FEU
M.@!:861A:G1E('!R;W/M;2!P;&%T;OH@25`@861R97-U+@!:861A:G1E('!R
M;W/M;2!P;&%T;OT@9.%T=6TL('-K;VYT<F]L=6IT92!P;^AE="!D;NT@=B!M
M97-I86-I+@!:861A:G1E('!R;W/M;2!P;&%T;OT@Z&%S+@!0<F]S[6T@=79E
M[W1E('IH<FYU=&EE('!R;V)LZ6UU+@!0<F]S[6T@>F%D86IT92!S=F]J92!P
M;W6^[79A=&6U<VOI(&UE;F\@82!H97-L;P!0<F7H[71A:G1E('-I('!R;W/M
M;2!N87-L961U:OIC:2!T97AT+B!-55/-5$4@<_IH;&%S:;L@<R!P;V1M:65N
M:V%M:2!P;W6^[79A;FEA('-Y<W3I;74N`%IA9&%J=&4@<')O<^UM(&UE;F\@
M<')E(&YO=OH@:V%T96?S<FEU.@!0;[5S:V\`4&]L:71I:V$`06YK971Y`%!O
M<G1U9V%L<VMO`%5M:65S=&YE;FEE('1O:'1O(&]B<N%Z:W4`56UI97-T;F5N
M:64@=&5J=&\@=&%B=;5K>0!/9&]S;&&[(&1O('1O:'1O('!R:67H:6YK82`H
M;F5V>6YU8W5J92!)34%0*0!:<N&^:WD@>F$@<&]S;&5D;OUC:"`E<R!H;V3M
M;CH@`%!R879D97!O9&]B;F]SNSQB<B`O/GIRX;YO:P!0<F5F<U]L9&%P.B!P
M;[YA9&]V86[I(')O>KGM<F5N:64@3$1!4"!N96)O;&\@;N%J9&5NZ2X`4')E
M9G-?<V5S<VEO;CH@<&^^861O=F%NZ2!R;WJY[7)E;FEE('-E<W-I;VX@;F5B
M;VQO(&[A:F1E;NDN`%1L86L`5&QA:R!N82#Z<F]V;FD@;6]R83H@`%1L86LZ
M(`!5:^&^:V$`6F]B<F%Z:;L@=6OAOFMU(&]B<N%Z:W4@=B!N;W9O;2!O:VYE
M`%!R961C:.%D>F%J^F-E(&YA<W1A=F5N:6$`5GET;&'H:;L@9&]K=6UE;G0`
M4')I=N%T;GD@:[7ZZ`!0<F]B;.EM`%!O<&ES('!R;V)LZ6UU`%!R;VIE:W1Y
M`%;]>G9A(&YA('IA9&%N:64@=&5X='4`5F5R96IN_2!KM?KH`$%L9V]R:71M
M=7,@=F5R96INZ6AO(&NU^NAA`$EN9F]R;>%C:64@;R!V97)E:FYO;2!KM?KH
M:0!697)E:F[]+W!R:7;A=&YY(&NU^NAO=OT@<.%R(&YE8F]L(/IS<&6Y;F4@
M=GEG96YE<F]V86[]+@!0;W)T;W)I:V\`2V%T87(`1&]T87H`2W;S=&$`4E-!
M('9E<F5J;OT@:[7ZZ"`H)60@8FET;W8I`%!R97#M;F'H(',@=OUB97)O;0!$
MX;[O`%+A;F\@9.&^[P!.97-K]'(@9.&^[P!$8;[O;W;I('!R96CA;FMY`$3A
MON\@<V\@<VYE:&]M`$3AON\@<')E8VCA9'IA:OIC:2!V('-N9;YE;FEE`$[A
M:&]D;N$@9F]R='5N80!0;VUE<@#([71ANP#([71ANR!S<'+A=GD`3F%O>F%J
M('9Y;6%Z8;L@)7,_(%3Z=&\@;W!E<N%C:74@;F5M;[YN;R!V<N%T:;L@<W#D
MNRX`3F%O>F%J('9Y;6%Z8;L@<&]UONUV871EM7-KZ2#Z9&%J92!P<F4@<&]U
MONUV871EM6$@)7,_(%3Z=&\@;W!E<N%C:74@;F5M;[YN;R!V<N%T:;L@<W#D
MNRX`5G+A=&D@<W#DNR!68;EU('!O<VQE9&[Z(&%K8VEU`$]B;F]V:;L`3V)N
M;W9INR!E;&5M96YT>2!D>6YA;6EC:^EH;R!M96YU.@!/8FYO=FF[('IO8G)A
M>F5N:64@<&]R=.%L=3H`4F5G=6SA<FYY(';]<F%Z`%!R96AL:6%D8>@@=GJ[
M86AO=@!:;F]V=2!N8>CM=&&[`%!O<W1R96AY`%9Z9&EA;&5NZ2!S97)V97)Y
M`%9Z9&EA;&5NX2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.@!/9'-T<N%N:;L`3V1S='+A;FF[(&)L;VL`3V1S='+A;FF[('-TY7!E8P!/
M9'-T<N%N:;L@9F]R;>%T;W9A;FEE`$]D<W1RX6YINR!PX7(`3V1S='+A;FF[
M('5L;[YE;OT@<VMR:7!T('H@9&_H87-NZ6AO('!R:67H:6YK82!N82!S97)V
M97)I+@!/9'-T<N%N:;L`3V1S='+A;FF[('1E;G1O(&)O9"!Z(&1O:W5M96YT
M=0!/9'-T<N%N:;L@<&]UONUV871EM6$`3V1S='+A;FF[('!O=;[M=F%T9;5A
M.B`E<P!.82!P;[YI861A=FMU(&YE8F]L;R!M;[YNZ2!O9'!O=F5D8;LN($[A
M=G)A=&]V_2!K\V0@8VAY8GDZ(`!0;[YA9&]V86[Z('-L=;YB=2!S82!N97!O
M9&%R:6QO(&[A:G.[+@!6(&MO;F9I9W5RX6-I:2`E<R!N:64@:F4@N7!E8VEF
M:6MO=F%NX2!P;[YA9&]V86[A('!O;&^^:V$@(B5S(@!6(&MO;F9I9W5RX6-I
M:2!61E,@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA
M("(E<R(`5B!K;VYF:6=U<N%C:6D@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^
M861O=F%NX2!P;VQOOFMA("(E<R(`4&]V:6YNZ2!P;VQE`%9Y;6%Z8;L@9F]R
M;75LX7(`3V)N;W9INR!H97-L;P!/8FYO=FF[(%9AN64@:&5S;&\`3V)N;W9I
MNR!P;W-L961N_2!D;W1A>@!6_7-L961K>0!.X79R870@;F$@;F%S=&%V96YI
M80!:861A:G1E(&YO=ND@:&5S;&\`4F5U;FEO;@!6<N%T:;L@:V]N9FEG=7+A
M8VEU`$YA<W1A=F5N:6$@<F]ZN>UR96[I:&\@=&5X=&]VZ6AO(&5D:71O<G4`
M2.%D86YK>0!6<')A=F\`2&QA=FGH:V$@=G!R879O`$AO9&YO='D@=G!R879O
M`%9L87-T;F]S=&D@7W)I861K82XN+@!2;VQA`%)U;75N<VMO`$]T;^AINR!O
M(#$X,`!/=&_H:;L@=K5A=F\`3W1OZ&F[('9P<F%V;P!6;&%S=&YO<W1I(')I
M861K80!6;&%S=&YO<W1I(')I861K80!2:6%D:WDZ`,AI87)Y`,AI87)Y('-A
M('IO8G)A>FEA(&UE9'II(':Y971K_6UI(')I861K86UI(&$@<W3E<&-A;6D`
MR&EA<GD@<V$@>F]B<F%Z:6$@:6)A(&UE9'II('-TY7!C86UI`,AI87)Y('-A
M('IO8G)A>FEA(&EB82!M961Z:2!R:6%D:V%M:0!3<'5S=&F[`%)U<VOA(&9E
M9&5RX6-I80!2=V%N9&$`4R]-24U%(&MR>7!T;V=R869I8VO]('!O9'!I<P!3
M<'+A=F$@>F&Y:69R;W9A;N$@<&]M;V-O=2!3+TU)344`4T%33"!A=71E;G1I
M9FEKX6-I82!N:64@:F4@9&]S='5P;N$N`%!O<VEE;&%N:64@4TU3`%-13"!3
M:&5L;`!344P@<'+M:V%Z('!R92!HM6%D86YI92!H;V1N]'0`4U-(`-I34$5#
M2`!37U%,(%-H96QL`%-O`%-VY'3A($AE;&5N80!3=N1T_2!+:71T<R!A($YE
M=FES`%-VY'3A($QU8VEA`%-V+B!0:65R<F4@82!-:7%U96QO;@!3=N1T_2!6
M:6YC96YT(&$@1W)E;F%D:6YY`%1E;B!I<W3]('+A;65C("A?<V5L9BD`4V%M
M;V$`4V%N($UA<FEN;P!386\@5&]M92!A(%!R:6YC:7!E`%-A=&5L:71N_2!P
M;W-K>71O=F%T9;4`4V%U9'-KX2!!<N%B:6$`56QOOFF[`%5L;[YINR`B)7,B
M`%5L;[YINR`E<P!5;&^^:;L@;F%S=&%V96YI80!5;&^^:;L@=GEG96YE<F]V
M86[Z(&MO;F9I9W5RX6-I=2!A:V\@4$A0('-K<FEP="!D;R!D;^AA<V[I:&\@
M<')I9>AI;FMA(%;AN6AO('-E<G9E<F$N`$MO;F9I9W5RX6-I82`E<R!B;VQA
M('5L;[YE;N$N`%-K<FEP="!N82!U<&=R861E(&YA<W1A=F5N[2!B;VP@=6QO
MOF5N_2!D;SH@(B5S(BX`3VIE9&EN96SI(&+Z<FMY`%9E9&$`2+5A9&&[`%9Y
M:+5A9.%V8>AE`%9Y8F5R=&4@<_IB;W)Y`%9Y8F5R=&4@9.%T=6T`5GEB97)T
M92!S:W5P:6YU(&YA('!R:61A;FEE`%9Y8F5R=&4@;F]VZ6AO('9L87-T;NUK
M80!6>6)E<G1E('-E<G9E<@!6>6)E<G1E('!O=;[M=F%T9;5A(&YA('!R:61A
M;FEE`%9Y8F5R=&4@=KEE=&MY`%9Y8F5R=&4@=KEE=&MY(&MO;7!O;F5N='D@
M9.%T=6UU`%9Y8F5R=&4@;V)J96MT`%IR=;EINR!V_6)E<@!6>6)E<G1E('IN
M86MY+"!K=&]RZ2!P;W1R96)U:F5T92P@>B!O:VEE;F]K(&YIOKEI92X@4&]T
M;VT@:6-H(&WTOF5T92!S:V]P[7)O=F&[(&$@=FQOOFF[('H@=&5X=&]VZ6AO
M('!OM6$N`%9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA=&4@9.%T=6UU.@!6
M>6)E<G1E(&9O<FWA="!DX71U;74Z`%9Y8F5R=&4@:61E;G1I='4L(&MT;W+Z
M(&-H8V5T92!Z;65N:;LZ`%9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA=&4@
MZ&%S=3H`5GEB97)T92!F;W)MX70@Z&%S=3H`5GEB97)T92!D=F4@>FAO9&[I
M('!O;&EA+@!6>6)E<G1E('-I(&9A<F5B;OH@<V-HZ6UU`%9Y8F5R=&4@:F%Z
M>6LZ`%!O<VQANR!S<'+A=G4@;R!P<F]B;.EM90!0;W-L8;L@4TU3`%-E;F5G
M86P`4V5N>F]R.B``4V5P=&5M8F5R`%-R8G-K;R!A(,AI97)N82!H;W)A`%/I
M<FEO=ND@Z.US;&\`VF1A:F4@>F\@<V5R=F5R82!S^B!N97-P<N%V;F4@86QE
M8F\@;FEE('/Z(&1O<W1U<&[I+@!!9&UI;FES='+A8VEA('-E9&5N[0!0;&%T
M;F]SNR!)1"!S961E;FEA('9Y<'*Y86QA+@!3961E;FEA`$UN;[YI;F$@:&]D
M;O1T`$YA<W1A=G1E(&UOOFYO<W1I(&YA(&]B;F]V96YI92!6X;EH;R!H97-L
M82!A:R!H;R!Z86)U9&YE=&4N`$YA<W1A=F5N:64@=GID:6%L96[]8V@@<V5R
M=F5R;W8L(&MU(&MT;W+];2!C:&-E=&4@<')I<W1U<&]V8;L@>B!6X;EH;R!P
M;W)TX6QU+@!6>6)E<G1E(&IA>GEK+"#H87-O=OH@>O-N=2!A(&YA<W1A=F5N
M:6$@9.%T=6UU+@!.87-T879E;FEE(&%P;&EKX6-I92!S</JYNV%N96H@<')I
M(+ET87)T92P@9F%R96)N96H@<V-HZ6UY+"!I;G1E<G9A;'4@;V)N;W9O=F%N
M:6$@<W1RX6YK>2!A(&EN_6-H('9L87-T;F]S=.T@>F]B<F%Z96YI82X`3F%S
M=&%V96YI90!3^B!D;W-T=7!NZ2!S:W)I<'1Y(&YA('5P9W)A9&4@;F%S=&%V
M96[M`$1O(/IV86AY('!R:6-HX61Z82!N:65K;[5K;R!L;VMA;.UT('!O;6]C
M;W4@<&%R86UE=')A.B``4V5Y8VAE;'D`4VAO<'!I;F<`2W+A=&MY('/Z:')N
M`$UA:OH@<V$@<')E(';DZ+EI;G4@;&EN:65K('9Y='9O<FF[('-K<F%T:V]V
MZ2!K;.%V97-Y/P!:;V)R87IINP!:;V)R87IINR!R;WID:65L>2!M961Z:2!P
M<N%V92!U;&^^96YO=2!A(&YO=F]V>6=E;F5R;W9A;F]U(&MO;F9I9W5RX6-I
M;W4N`$WA('-A('!R:2!P<FEH;.%S96[M('IO8G)A>FF[(.AA<R!P;W-L961N
MZ6AO('!R:6ALX7-E;FEA/P!:;V)R87IINR!M;[YN;W.[(&YA('!O;F5C:&%N
M:64@;W)I9VENX6QU`%IO8G)A>FF[(&[A<W1R;VH@;F$@=OUB97(@9F%R:65B
M`%IO8G)A>FF[(&UE;G4@<')E(&]P97+A8VEE(',@=&%B=;5K86UI/P!:;V)R
M87IINR!M96YU("5S(&YA(+5A=F5J('-T<F%N93\`6F]B<F%Z:;L@9&EA;/-G
M(',@=FQA<W1N;W.[86UI(&)U;FMY('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G
M(',@=FQA<W1N;W.[86UI('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA
M<W1N;W.[86UI(')I861K=2!T86)UM6MY`%IO8G)A>FF[(&1I86SS9R!S('9L
M87-T;F]SNV%M:2!O8G+A>FMU`%IO8G)A>FF[(&YA:')A;ND`4')E:.%N:WD`
M4N%N;R!P<F5HX6YK>0!.97-K]'(@<')E:.%N:WD`6G+AOFMY('8@;VMO;.T`
M6FUE;KEINP!.86IP<G8@;75S[71E('IM96ZY:;L@86QE8F\@<')E<W5N^KL@
M<W5S961N_2!B;&]K*'DI`%-I97)R82!,96]N90!:87)E9VES=')O=F&[('-A
M`%!O9'!I<P!!;&=O<FET;75S('!O9'!I<W4`4VEN9V%P=7(`5F6U:V]SNP!0
M<F5S:V_H:;L@^F1ROF)U`%-L;W9E;G-K;P!3;&]V:6YS:V\`4VYEOF5N:64`
M4VYE:&]VX2!P<F5HX6YK80!3;F5H;W;I('!R96CA;FMY`%+A;F\@<VYE:&]V
MZ2!P<F5HX6YK>0!.97-K]'(@<VYE:&]VZ2!P<F5HX6YK>0!(Y6)K82!S;F5H
M=3H@`$UN;[YS='9O('9O9'D@96MV:79A;&5N=&[I('-N96AU.B``J6%L86WZ
M;F]V92!O<W1R;W9Y`%-O;>%L<VMO`%!I97-N92!A(&+A<VYE`%;]8F5R('-M
M97)U('1R:65D96YI80!:9')O:F]VX2!A9')E<V$`2G6^;N$@069R:6MA`$IU
MOF[A($=E;W)G:6$@82!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$IUOF[A('!O
M;&]G=;5A`$UE9'IE<F$@;65D>FD@<W5S961N_6UI(&)U;FMA;6D`365D>F5R
M82!M961Z:2!O8G-A:&]M(&$@;VMR86IO;2!B=6YK>0!/9&1EM6]V8>@`3V1S
M='5P`$]D<W1U<"!A('9Y<&QN96YI90"I<&%N:65L<VMO`%-P86T`5FQOOF5N
M:64@N7!E8VGA;&YY8V@@>FYA:V]V`%)O>F1E;&F[(&)U;FMU`%)O>F1E;&F[
M('-TY7!E8P!2;WID96QINR!R:6%D;VL`J7!O<G1Y`%-R[2!,86YK80"I=&%N
M9&%R9&[I`%-T87(@5')E:P!0;^AI871OZ&[](')O:P"I=.%T(&%L96)O('!R
M;W9I;F-I80!3=&%V`$9O<FWA="!U;&^^96YI80!">61L:7-K;P!0<F6Y:W)T
M;G5TZ0!:;WIN86T@<F6[87IC;W8`3V1S='+A;FF[(&1O;>EN=2!Z(&%D<F5S
M>0"I=/UL(%M#4U-=`$YE`%!O9'!R:67H:6YO:R`B)7,B(&YE8F]L(&[A:F1E
M;OTN`%!R961M970`3V1O<VQANP!0;[YI861A=FMA(&YA('!R:61A;FEE("(E
M<R(@9&\@<WES=.EM=2!B;VQA(&]D;W-L86[A+B!.96WTOF5T92!S82!P<FEH
M;.%S:;LL(&O];2!N96)U9&4@5F&Y82!P;[YI861A=FMA('-C:';A;&5NX2X`
M1&]L;OT@:6YD97@`VG-P96-H`%!R:61A;FEE("(E<R(@9&\@<WES=.EM=2!B
M;VQO(/IS<&6Y;NDN`%9Y;6%Z86YI92#Z9&%J;W8@>F\@<WES=.EM=2!P<F4@
M<&]UONUV871EM6$@(B5S(B!B;VQO(/IS<&6Y;NDN`%9Y;6%Z86YI92`B)7,B
M(&)O;&\@^G-P9;ENZ2X`5GEM87IA;FEE("(E<R(@>F\@<WES=.EM=2!B;VQO
M(/IS<&6Y;NDN`$[A=G)A="!K=2!K;VYF:6=U<N%C:6D@8F]L(/IS<&6Y;OTN
M(%!R92!Z;V)R87IE;FEE('IM:65N('IN;W9U(&YAZ.UT86IT92!S='+A;FMU
M+@!:X6QO:&$@:V]N9FEG=7+A8VEE(&)O;&$@=6QOOF5NX2X`6N%L;[YN_2!K
M;VYF:6=U<F'H;OT@<_IB;W(@)7,@8F]L(/IS<&6Y;F4@=6QOOF5N_2X`06MT
M=6%L:7KA8VEA("(E<R(@8F]L82#Z<W!EN6[A+@!:X7!I<R`E<R!B;VP@^G-P
M9;EN_0!3=63A;@!3^FAR;@!6_6-H;V0@<VQN:V$`6N%P860@<VQN:V$`4VQN
M9>AN;P!6_6-H;V0@<VQN:V$`5OUC:&]D+WKA<&%D('-L;FMA`%;]8VAO9"!S
M;&YK83H@`%KA<&%D('-L;FMA`%KA<&%D('-L;FMA.B``2&]R;OT@:6YD97@`
M4&]D<&]R80!3=7)I;F%M`%!R:65Z=FES:V\`4W9A;&)A<F0@82!*86X@36%Y
M96X`4W9A>FEJ<VMO`*EVZ61S:V\`J79A:NAI87)S:V\`6N%Z;F%M>2!O('-Y
M;F-H<F]N:7KA8VEI('9Y;6%Z86[I`%-Y;F--3`!3>6YT86MT:6-KX2!C:'EB
M82!V('!O9&UI96YK86-H(&BU861A;FEA`%/]<FEA`$+Z<FMA`$+Z<FMA(&$@
M=F5T97)N;P!"^G)K>0!2X6YO(&+Z<FMY`%135B!S^F)O<@!486)UM6MA`%9L
M87-T;F]S=&D@=&%B=;5K>0!6;&%S=&YO<W1I('1A8G6U:WD`5&%I=V%N`%1A
M:7=A;BP@<')O=FEN8VEA(,CM;GD`5&%DOFEK:7-T86X`5&%N>N%N:6$`0VEE
MM3H`VFQO:'D`5&5L96;S;FYE(.CM<VQO`%1E<&QO=&$@>F$@<&]S;&5D;OH@
M:&]D:6YU.B``5&5P;&]T80!497!L;W1A.B``5&5P;&]T83QB<B`O/B@E<TUA
M>"5S+R5S36EN)7,I("9D96<[)7,`J6%B;/-N82`B)7,B(&YE8F]L82!NX6ID
M96[A+@!3<'+A=F$@N6%B;/-N`%1E>'0`26)A('1E>'0`6F%R;W9N86YI92!T
M97AT=0!497AT(&AO<F4`J70`5&AA:G-K;P!2;WJY[7)E;FEE($944"!N:64@
M:F4@9&]S='5P;NDN`$EN=&5G<N%C:6$@2&]R9&4O2V]L86(@;F5P;V1P;W)U
M:F4@(B5S(@!)35-0('KA>FYA;2!S82!N97!O9&%R:6QO('5L;[YINRX`5')I
M961A($UA:6YT96YA;F-E.CH@<V$@;F5N8>CM=&%L82#Z<W!EN6YE`$]K;F\@
M<R!N87-T879E;FEA;6D@<V$@>F%T=F]R:6QO+B!+;VYI96,N`$%D;6EN:7-T
M<N%T;W(@;75S[2!N86MO;F9I9W5R;W9ANR!P97)M86YE;G1N_2!B86-K96YD
M('!R92!0<N%V82P@86L@8VAC971E('!O=;[M=F&[(%!RX79A+@!)8F$@<W!O
M9&[A('-T<F%N80!)1"#H[7-L;R!K;VYT86MT=2!N96)O;&\@N7!E8VEF:6MO
M=F%NZ2P@8F]L;R!P;VYE8VAA;ND@<'+A>F1N92!A;&5B;R!N96)O;&\@;N%J
M9&5NZ2!V(&1A=&%BX7IE+@!+;VYT86MT(&)O;"#Z<W!EN6YE('9L;[YE;OT@
M9&\@5N&Y:&\@861R97/A<F$N`$YA(&]V97)E;FEE('!O9'#M<V%N96H@<W!R
MX79Y(&IE('!OOF%D;W9A;OT@;V1D96QE;OT@8FQO:R!S(%!'4"!P;V1P:7-O
M;2X`240@>F]Z;F%M=2!P<NUJ96UC;W8@8G7O(&YE8F]L;R"Y<&5C:69I:V]V
M86[I+"!A;&5B;R!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE(&%L96)O(&YE8F]L
M;R!NX6ID96[I('8@9&%T86+A>F4N`$YE8F]L('5RZ&5N_2!Z;WIN86T@<'+M
M:F5M8V]V+@"I:69R;W9A;FEE('9YOF%D=6IE(&)E>G!EZ&[I('!R:7!O:F5N
M:64@*&AT='!S*2X`4_IB;W(@)7,@8GD@;6%L(&]B<V%H;W9ANR!N87-T879E
M;FEE("5S+@!3^F)O<B`E<R!B>2!M86P@;V)S86AO=F&[(&YI96MT;W+I(&YA
M<W1A=F5N:6$@)7,N`%ID<F]J;W;](&$@8VEEM6]V_2!S^F)O<B!M=7-I82!B
M>;L@;V1L:;ENZ2X`4_IB;W(@;F5O8G-A:&]V86P@OFEA9&YE(/ID86IE+@!.
M87-L961U:OH@:&QA=FGH:WD@=&5J=&\@<W!RX79Y('9O(&9O<FWA=&4@;65S
M<V%G92]R9F,X,C(N`$-E;&]O8G)A>F]V:V]V_2!R9;YI;2!S</1S;V)U:F4@
M<')O8FSI;7D@=B!);G1E<FYE="!%>'!L;W)E<FD@:W;T;&D@8VAY8N%M('!R
M96AL:6%D8>AA+"!K=&]RZ2!S82!NX6T@;F5P;V1A<FEL;R!O8NUSNRX@3?2^
M=2!S82!P<F5J879INR!N97-P<N%V;GEM('IO8G)A>F5N[6TL(&-H_6)A:OIC
M:6UI(&9U;FMC:6%M:2!E9&ET;W)A(&$O86QE8F\@;N%H;V1N_6UI('#A9&UI
M('!R96AL:6%D8>AA+B!!:R!J92!6X;D@<WES=.EM(%=I;F1O=W,@.7@L(&IE
M('9EM6UI('!R879D97!O9&]B;NDL(+YE('-A('IO8G)A>NT@8VAY8F$@)T=E
M;F5R86P@4')O=&5C=&EO;B!&875L="<@82!B=61E=&4@;75S:66[(')EN71A
M<G1O=F&[('!OZ.UT8>@N7&Y<;E9A<F]V86QI('-M92!6X7,N(%-T;&'H=&4@
M<')O<^UM($]+(&%K(&YA;WIA:B!C:&-E=&4@<&]UOFF[(&5D:71O<B!V(&-E
M;&]O8G)A>F]V:V]V;VT@<F6^:6UE+@!)9&5N=&ET82`B)7,B(&)O;&$@=GEM
M87IA;N$N`$EB82"U87;A('-T<F%N80!4<FEE9&$@0W)Y<'1?<&=P.CH@<&]T
M<F5B=6IE('!O>FYANR!U;6EE<W1N96YI92!P<F]G<F%M=2!';G501RX`4W!R
MX79A(&]D;W-L86[A("5S('!R92`E<R!S('!R961M971O;2`B)7,B(&)O;&$@
M>F]B<F%Z96[A+@I.965X:7-T=6IE(':Y86L@>N%R=6MA+""^92!S<'+A=F$@
M8F]L82!P<F7H[71A;N$@86QE8F\@<&]C:&]P96[A+@!-96YO+"!K=&]RZ2!S
M82!MX2!P;W6^:;L@<')I(&QI;FMO=F%N[2!N82!S='+A;FMU(&YA('#M<V%N
M:64@<W!RX78@`%!OZ&5T('!O;.T@;75S[2!B>;L@Z.US;&\N`%1R:65D82!(
M;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN`$YA
M<W1A=F5N:64@(B5S(B!S82!N97!O9&%R:6QO('5L;[YINRP@<')E=&^^92!J
M96AO(/ID86IE('!R96MR8>AU:OH@;6%X:6WA;&YU('!O=F]L96[Z('9EM6MO
M<[L`4')O9W)A;2!P;W6^[79A;OT@;F$@>F]B<F%Z96YI92!T;VAT;R#Z9&%J
M;W;I:&\@='EP=2`H)7,I(&YE8F]L(&[A:F1E;OTN`%IN86L@8VETX6-I92!M
M=7/M(&)YNR!J961E;B!Z;F%K+@!)8F$@<')A=N$@82"U87;A('-T<F%N80!)
M8F$@<')A=N$@<W1R86YA`$]D9&6U;W9AZ"!M=7/M(&)YNR!J961E;B!Z;F%K
M+@!397)V97(@(B5S(B!B;VP@=GEM87IA;OTN`%-E<G9E<B`B)7,B(&)O;"!U
M;&^^96[]+@"N:6%D;W.[(&\@<')I:&SA<V5N:64@)7,@8F]L82!V>6UA>F%N
MX2X`J7!E8VEF:6MO=F%N_2!R:6%D;VL@;F5E>&ES='5J92X`1&_H87-N_2!S
M^F)O<B`B)7,B(&YE97AI<W1U:F4N`%IA9&%N_2!T97AT(&YI92!J92!R;W9N
M86O](&%K;R!T97AT(&YA(&]B<F%Z;W9K92X`26)A(&AO<F[A(&$@<W!O9&[A
M('-T<F%N80!)8F$@:&]R;N$@<W1R86YA`$YA:')A;ND@^F1A:F4@<V$@;V0@
M<')E9&-HX61Z86KZ8V5H;R!K<F]K=2!S=')A=&EL:2X`3F%H<F%N_2!S^F)O
M<B!S82!N97!O9&%R:6QO('5L;[YINRX`0FQO:R!W96%T:&5R+F-O;2!N:64@
M:F4@9&]S='5P;OTN`%!R:67H:6YO:R!TZ6T@(B5S(B!N96)O;"!NX6ID96[]
M+@"N:6%D;F4@;F%S=&%V96YI82!N:64@<_H@9&]S='5P;NDN`*YI861N92!A
M;'1E<FYA=.UV;F4@Z&%S=&D@;F5M;[YN;R!Z;V)R87IINR!V('1E;&4@<W!R
MX79Y+@!6('1O;71O('!O;&D@:F4@<'+M;&FY('9EM6$@>FYA:V]V+B!:861A
M;&D@<W1E("5S('IN86MO=CL@;75S[71E('IA9&&[(&UE;F5J(&%K;R`E<RX`
M3F%S=&%L82!C:'EB82!P<FD@<')I9.%V86[M("(E<R(@9&\@<WES=.EM=3H@
M)7,`3F%S=&%L82!C:'EB82!P<FD@;V1S=')A\F]V86[M('!O=;[M=F%T9;5S
M:_UC:"#Z9&%J;W8@(B5S(B!Z;R!S>7-TZ6UU.B``3F%S=&%L82!C:'EB82!P
M<FD@;V1S=')A\F]V86[M("(E<R(@>F\@<WES=.EM=3H@`$YA<W1A;&$@8VAY
M8F$@<')I(&%K='5A;&EZX6-I:2`B)7,B.B`E<P!6>7-K>71O;"!S82!P<F]B
M;.EM(',@;F%H<N%V86[M;2!S^F)O<G4Z(*YI861E;B`E<R!N96)O;"!N86AR
M86[]+@!6>7-K>71O;"!S82!P<F]B;.EM(',@;F%H<N%V86[M;2!S^F)O<G4Z
M("5S(&)O;"!VY.BY[2!A:V\@;F%J=N3HN>T@<&]V;VQE;OT@;&EM:70@*"5D
M(&)A:G1O=BDN`%9Y<VMY=&]L('-A('!R;V)LZ6T@<R!U:VQA9&%N[6T@<_IB
M;W)U.B`E<R!B;VP@;F%H<F%N_2!L96X@Z&EA<W1OZ&YE+@!.87-T86QA(&-H
M>6)A('!R:2!Z;V)R87IO=F%N[2!T96IT;R#H87-T:2!S<'+A=GD`3F%S=&%L
M82!C:'EB82!P<FD@:6UP;W)T92#Z9&%J;W8@;R!K;VYT86MT92X`3F%S=&%L
M82!C:'EB82!P<FD@:6UP;W)T92#Z9&%J;W8@:4-A;&5N9&%R+@!.87-T86QA
M(&-H>6)A('8@:V]N9FEG=7)AZ&YO;2!F;W)M=6SA<FDN(%!R879D97!O9&]B
M;F4@<W1E(&YE=GEP;&YI;&D@<&^^861O=F%NZ2!P;VQE+@!.87-T86QA(&-H
M>6)A('!R:2!V>6MO;N%V86[M('5RZ&5N96H@9G5N:V-I92!A9')E<^%R82X@
M4')O<^UM('-K^G-T92!T;R!N97-K]'(N`$YA<W1A;&$@8VAY8F$@<')I(&%K
M='5A;&EZX6-I:2!D971A:6QO=B!K;VYT86MT=2X@4')O<^UM('-K^G-T92!T
M;R!N97-K]'(N`$YA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2!Z;WIN
M86UU('!R[6IE;6-O=BX@4')O<^UM('-K^G-T92!T;R!Z;F]V=2X`5&5N=&\@
M24U!4"!S97)V97(@;F5P;V1P;W)U:F4@>F1I9;5A;FEE('!R:67H:6YK;W8N
M`%1O=&\@<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!R87(N
M`%1O=&\@<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!Z:7`N
M`%1O=&\@<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[I(.CM<VQO(&MA<G1Y
M+@!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@8V5Z
M(&)RX6YU($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<&]M
M;V-O=2!(5%10($%020!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N
M:64@<W!RX78@8V5Z(&)RX6YU(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI('!O
M;6]C;W4@2%144"!!4$D`5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA
M;FEE('-P<N%V(&-E>B!B<N%N=2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PN8V]M*2!P;VUO8V]U($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U
M:F4@<&]S:65L8;L@<W!RX79Y(&-E>B!33510(&-E>B!B<N%N=2!6;V1A9F]N
M92!)=&%L>2`H:6)A(&YA(.CM<VQA(%9O9&%F;VYE*2X@5GF^861U:F4@92UM
M86EL;W;](/KH970@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2X`5&]T;R!P;VQE(&IE('!O=FEN;NDN`%1O=&\@<&]L92!M]+YE(&]B<V%H
M;W9ANR!I8F$@Z.US;&$N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@
MZ.US;&$@82!D=F]J8F]D:W4N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I
M8F$@;W-M:>AK;W;I(&AO9&YO='DN`%1O=&\@<&]L92!M=7/M(&)YNR!Z;WIN
M86T@Z.US96P@;V1D96QE;OUC:"#H:6%R:V]U(&%L96)O(&UE9'IE<F]U`%1O
M=&\@<&]L92!M=7/M(&)YNR!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M=7/M
M(&]B<V%H;W9ANR!K\V0@9F%R8GD@=B"Y97-T;N%S=&MO=F]M(&9O<FWA=&4@
M4D="+"!N87!R[6ML860@)R,Q,C,T868G+@!496YT;R!F;W)M=6SA<B!UOB!B
M;VP@<W!R86-O=F%N_2X`5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE:W0@2V]L
M86(@1W)O=7!W87)E+B!0<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE:W1U('!O
M=')E8G5J971E(&4M;6%I;&]VZ6AO(&ML:65N=&$L(&MT;W+](')O>G5M:64@
M9F]R;>%T=2!+;VQA8B!'<F]U<'=A<F4N(%!R92!Z;WIN86T@=&%K_6-H=&\@
M:VQI96YT;W8@;F%VN73M=G1E('!R;W/M;2`E<P!4X71O('-P<N%V82!B;VQA
M(&YA<.US86[A('8@:6YE:B!A:V\@5F%M:2!P;W6^[79A;F5J('IN86MO=F5J
M('-A9&4@*"5S*2X`5&]T;R#H[7-L;R!M=7/M(&)YNR!N86IM96YE:B`Q+@!4
M96YT;R!S97)V97(@;F5D;VOAOF4@9&5K;VUP<FEM;W9ANR!S^F)O<GD@>FEP
M(&$@9WII<"X`4WES=.EM(&IE(&UO;65N=.%L;F4@9&5A:W1I=F]V86[]+@!4
MX71O(&AO9&YO=&$@;75S[2!B>;L@Z.US96QNX2X`5&]T;R!O:VYO(&UU<^T@
M8GF[('IA=F]L86[I('H@;VMN82!.87-T879E;NT`2')M96YI90!4:6-K971S
M`,AA<P!4:6UE(%1R86-K:6YG`$9O<FWA="#H87-U`%;]8F5R(.AA<W4`5&EM
M;W(M3&5S=&4`5&ET=6QO:P!.861P:7,@*&)U8FQI;F]V_2!V_7!I<RDZ`%!R
M90!0<F4@=OUB97(@=FEA8V5R_6-H('!O;&^^:65K(&1ROG1E('!OZ&%S(&ML
M:6MA;FEA(&MLX79E<W4@0V]N=')O;"`H4$,I(&%L96)O($-O;6UA;F0@*$UA
M8RDN`$1N97,`4')E<&[ZNR!Z;V)R87IE;FEE('ID<F]J;W;I:&\@:_-D=2!(
M5$U,`%1O9V\`5&]K96QA=0!:86IT<F$`5&]N9V$`5G)C:`!6<F-H;OT@<N%M
M96,@*%]T;W`I`%!R96ML861Y`%1R:6YI9&%D(&$@5&]B86=O`%!R879D82!A
M;&5B;R!N97!R879D80!5=`!4=6YI<VMO`%1U<F5C:V\`5'5R:VUE;FES=&%N
M`%1U<FMS(&$@0V%I8V]S`%1U=F%L=0!:861A:G1E(%9AN74@=F^U8G4Z(`!5
M+E8N(&EN9&5X.B``55),`%523"!6X;EH;R!S:W)I<'1U('!R92!S<'+A=G4@
M;R!D;W)UZ&5N[0!54DPZ`%5G86YD80!5:W)A:FEN80!.97!O9&%R:6QO('-A
M('5S:W5T;^AN:;L@<'+M<W1U<"!K(%9&4R!A9')E<^%R=2X`3F5P;V1A<FEL
M;R!S82!P<FED8;L@[V%LN6EE(&EN9F]R;>%C:64@;R!P;W6^[79A=&6U;W9I
M('!R:2!R96=I<W1RX6-I:2X`3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@
M<')E(%9&4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IM96YINR!P<N%V
M;R!P<F4@5D93('/Z8F]R("5S+R5S+@!.97!O9&%R:6QO('-A('IM96YINR!N
M82`E<RX`3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S^F)O
M<G4@(B5S(BX`3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S
M^F)O<G4@(B5S+R5S(BX`3F5P;V1A<FEL;R!S82!S<&]J:;L@<R!344P@<V5R
M=F5R;VTN`$YE<&]D87)I;&\@<V$@<W!O:FF[('!O;6]C;W4@4U-,+@!.97!O
M9&%R:6QO('-A('-K;W#M<F]V8;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A
M('9Y='9O<FF[(%9&4R!A9')E<^%R("(E<R(N`$YE<&]D87)I;&\@<V$@=GET
M=F]R:;L@5D93(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93
M('/Z8F]R+@!.97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!P<FEEZ&EN;VL@
M(B5S(BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!P<N%Z9&YY(%9&4R!S^F)O
M<BX`3F5P;V1A<FEL;R!S82!D96MO;7!R:6UO=F&[(/ID86IE+@!.97!O9&%R
M:6QO('-A('9Y;6%Z8;L@(B5S(BP@861R97/A<B!N:64@:F4@<'+A>F1N>2X`
M3F5P;V1A<FEL;R!S82!V>6UA>F&[("(E<R(Z("5S+@!.97!O9&%R:6QO('-A
M('9Y;6%Z8;L@)7,L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GD`3F5P;V1A<FEL
M;R!S82!R96MU<GKM=FYE('9Y;6%Z8;L@5D93(&%D<F5SX7(N`$YE<&]D87)I
M;&\@<V$@=GEM87IANR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!V>6UA
M>F&[(%9&4R!A9')E<^%R.B`E<RX`3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&
M4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('/Z8F]R
M+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('!R:67H:6YO:R`B)7,B+@!.
M97!O9&%R:6QO('-A(')E:W5R>NUV;F4@=GEM87IANR!61E,Z("5S+@!.97!O
M9&%R:6QO('-A('5RZ&F[(&%K='7A;&YY(&%D<F5SX7(N`$YE<&]D87)I;&\@
M<V$@>FES=&F[('!O9')O8FYO<W1I(&\@8V5R=&EF:6OA=&4N`$YE;6^^;ND@
M;F%H<F&[(&1E9FEN[6-I=2`E<RX`3F5P;V1A<FEL;R!S82!P<F5S=6[ZNR!6
M1E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(@(B5S
M(BX`3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B!N82!ZX7!I<RX`
M3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S
M82!O='9O<FF[(&MO;7!R:6UO=F%N_2!A<F-H[78N`$YE<&]D87)I;&\@<V$@
M<')EZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA(&9I;&5S:7IE*"D@>FQY:&%L
M82DN`$YE<&]D87)I;&\@<V$@<')EZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA
M(&=E=$9I;&53:7IE*"D@>FQY:&%L82DN`$YE<&]D87)I;&\@<V$@<')EZ.UT
M8;L@<_IB;W(Z`$YE<&]D87)I;&\@<V$@Z.UT8;L@861R97/A<B!V9G-R;V]T
M+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@)7,@;F$@)7,Z(&-I9;5O=OT@
M<')I9>AI;F]K('6^(&5X:7-T=6IE`$YE<&]D87)I;&\@<V$@<')E;65N;W9A
MNR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A
M9')E<^%R.B`E<RX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O
M<B`B)7,B+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R("5S
M+R5S+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R+@!.97!O
M9&%R:6QO('-A('-P=7-T:;L@)VUK:7-O9G,G+@!.97!O9&%R:6QO('-A('!R
M96QOOFF[('1E;G1O(&1O:W5M96YT(%=O<F0`3F5P;V1A<FEL;R!S82!Z87#M
M<V&[(%9&4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IA<.US8;L@5D93
M('/Z8F]R("AF=6YK8VEA(&-O<'DH*2!Z;'EH86QA*2X`3F5P;V1A<FEL;R!S
M82!Z87#M<V&[(/ID86IE(%9&4R!S^F)O<G4N`$YE<&]D87)I;&\@<V$@>F%P
M[7-ANR!61E,@<_IB;W(L(&MV\W1A(&IE('!R96MR;^AE;N$N`%!O9.AI87)K
M;G5TZ0!:<G6Y:;L@>FUE;GD`6G)UN>T@<&]S;&5D;OH@86MC:74`3F5OZ&%K
MX79A;N$@;V1P;W9E[R!O9"!S97)V97)A('!OZ&%S('-P;VIE;FEA.B``3F5O
MZ&%KX79A;N$@;V1P;W9E[R!O9"!S97)V97)A(&YA.B``3F5N87-T879E;N$`
M4W!O:F5NZ2!A<F%B<VOI(&5M:7+A='D`5F6U:^$@0G)I=.%N:6$`4W!O:F5N
MZ2"Y=.%T>2!!;65R:6-KZ0!*961N;W1K>0!.97INX6UE`$YE>F[A;64@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`3F5Z;N%M92!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!";VQA('IA9&%NX2!N97!L871NX2!L;VMA;&ET
M82X`3F5Z;N%M92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S;&\N`$]D
M<W1RX6YINR!L:6YK=2!Z(&%K='7A;&YE:&\@96QE;65N='4`3F5P;VUE;F]V
M86[A`$YE<')I=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6%J^B!Z(&)E>G!EZ&YO
M<W1N_6-H(&3T=F]D;W8@<'+M<W1U<"!K('9OM6+A;2!6>7-T<FEH;OJ[+TMO
M<.UR;W9ANR]6;&^^:;LN($ML:6MN:71E(&YA($]+(&$@>F]B<F%Z[2!S82!T
M96-H;FEC:^$@:6YF;W)MX6-I82!N82!S='+A;FME(&UO>FEL;&$N;W)G+"!K
M=&]RX2!6X7,@:6YF;W)M=6IE+"!A:V\@=6UOOFYINR!S:W)I<'1U('!R[7-T
M=7`@:R!S8VARX6YK92X`3V1S='+A;FF[(&9A<F)U`$YE<&]D<&]R;W9A;ND@
M<F]ZN>UR96YI90!!:W1U86QI>N%C:6$`06MT=6%L:7IO=F&[("5S`$%K='5A
M;&EZ;W9ANR!P;W6^[79A=&6U80!!:W1U86QI>N%C:6$@(B5S(B!B;VQA(/IS
M<&6Y;N$N`%-K<FEP="!N82!U<&=R861E(&)O;"!V>6UA>F%N_2X`3F%H<F&[
M`%:Y971K>2!S^F)O<GD@<R!K;VYF:6=U<N%C:6]U(&)O;&D@;F%H<F%NZ2!N
M82!S97)V97(N`%9EM6OI(&QA=&EN<VOI('#M<VUE;N$`5F6U:^D@<NUM<VME
M(.CM<VQI8V4`57)U9W5A>0!0;W6^:;L@86MT=>%L;F4Z("5S`%!O=;YINR!3
M4TP`4&]UOFET92!V('!R[7!A9&4L(+YE(&IE(&UE;F\O:&5S;&\@;V1L:;EN
MZ2!P<F4@24U34"!S97)V97(N`%!O=;[M=F%T9;4`4&]UONUV871EM2`E<R!N
M:64@:F4@875T;W)I>F]V86[](&YA("5S+@!3<'+A=F$@<&]UONUV871EM6]V
M`%!O=;[M=F%T9;5S:^D@;F%S=&%V96YI80!296=I<W1RX6-I82!P;W6^[79A
M=&6U80!296=I<W1RX6-I82!P;W6^[79A=&6U;W8@8F]L82!P<F4@=&5N=&\@
M<WES=.EM('IA:^%Z86[A+@!0;W6^[79A=&6U<VO](/KH970@;F5B;VP@;N%J
M9&5N_0!0;W6^[79A=&6U<VOI(&UE;F\`4&]UONUV871EM7-KZ2!M96YO("(E
M<R(@=;X@97AI<W1U:F4N`%!O=;[M=F%T9;5S:^D@;65N;SH`4&]UONUV871E
MM7-KZ2!M96YO.B``4&]UONUV871E;&EA('-Y<W3I;74Z`%5Z8F5K:7-T86X`
M5D93(&%D<F5SX7(@;F5E>&ES='5J92X`1&]V;VQE;FMA`%!L871NZ2!U;6EE
M<W1N96YI82!Z86C@\F%J^CH@`%!L871N;W.[`%!L871N;W.[('8@;6EN^G1A
M8V@@;V1T97)A>BX`2&]D;F]T82!P<F5K<F_H:6QA(&UA>&EMX6QN=2!DY;YK
M=2`E<RX`2&]D;F]T>0!(;V1N;W1Y+"!Z(&MT;W+]8V@@<VD@;?2^971E('9Y
M8G)ANP!686YU871U`%!R96UE;F[A`%9E;F5Z=65L80!/=F5R96YI92!Z;'EH
M86QO("T@=.%T;R!S<'+A=F$@;6]H;&$@8GF[('-F86RY;W9A;N$N`%9E<GII
M80!-86YAOFUE;G0@=F5R>FGM`%9E<G1I:^%L;F4@>F%R;W9N86YI90!697)T
M:6OA;&YE('9Y<&QN96YI90!697)T:6OA;&YE.@!69;5M:2!V>7-O:^$`5FEE
M=&YA;0!:;V)R87IINR`E<P!:;V)R87IINR!E>'1E<F[Z('=W=R!S='+A;FMU
M`%IO8G)A>FF[(&%K;R`E<P!"<FET<VOI(%!A;F5N<VOI(&]S=')O=GD`06UE
M<FEC:^D@4&%N96YS:^D@;W-T<F]V>0!6:61I=&6U;F]SNP!6:61I=&6U;F]S
MNSH@`%9O9&%F;VYE($ET86QY(&-E>B!33510`%9!4D]604Y)10!54$]:3U).
M14Y)12$A(2!/1%-44L'25$4@4TM225!4(%H@)7,@4E7(3D4N`%=)3B!C97H@
M2%144`!786QL:7,@82!&=71U;F$`5F%R;W9A;FEE`%-T`%!R961P;W9E[R!P
M;^AA<VEA`-ID86IE(&\@<&_H87/M('!O<VMY='5J90!796%T:&5R+F-O;0!7
M96(`5U=7('-T<N%N:V$`5/V^9&5N;F4`5FET86IT90!6[71A(%;A<R`E<P!6
M:71A:G1E+"`E<P!:X7!A9&[A(%-A:&%R80!+=&]R^B!A<&QI:^%C:74@;>$@
M)7,@>F]B<F%Z:;L@<&\@<')I:&SA<V5N[3\`06O](&IE('IN86L@<')E(&]D
M9&6U;W9AZ#\`06O](&IE('IN86L@<')E(/IV;V1Z;W9K=3\`36%P82!!=7-T
M<N%L:64@<')E('-L=;YB=2!7:&5R96ES`$MT;W+I(&;A>GD`2W1O<ND@>N%S
M=79NZ2!M;V1U;'D@<&]V;VQINR!P<F4@<F]ZN>UR96[]('1E>'1O=OT@961I
M=&]R+@"I[7)K80"I[7)K82!V(&IE9&YO=&OA8V@@0U-3`*GM<FMA(&UE;G4@
M)7,@=K5A=F\@*'!R96IA=NT@<V$@<')I(.]A;+EO;2!P<FEH;.%S96[M*3H`
MJ>UR:V$@=&%B=;5K>0!*961N;W1K82"Y[7)K>0"I[7)K83H`5VEK:0!6:65T
M;W(`4N%N;R!V:65T;W(`4OUC:&QO<[L@=F5T<F$@=B!U>FQO8V@`5FEE=&]R
M.@!6:65T;W(Z(`!-^F1R;W.[`%=I<VAL:7-T`%!RX6-A`$%D<F5S82!D;R!P
M<N%C90!496QE9O-N(&1O('!RX6-E`$YE<W!RX79N>2!P;^AE="!P;VSM(&YA
M(')I861K=2`E9"X@3^AA:^%V82!S82`E9"P@;F&Y;&\@<V$@)60N`$YE<W!R
MX79N>2!P;^AE="!P;VSM+B!/Z&%KX79A('-A("5D+"!N8;EL;R!S82`E9"X`
M6FS](&]F9G-E="`E9"!P<FD@Z.UT86[M(%9&4R!S^F)O<G4N`%@M4F5F`%KA
M:VQA9&[I(&]B;65D>F5N:6$@6#4P.78S`%!O=;YI=&EE(')O>KGM<F5NZ6AO
M(&NU^NAA(%@U,#EV,P!!;'1E<FYA=.UV;F4@;65N;R!S=6)J96MT=2!8-3`Y
M=C,`261E;G1I9FEKX71O<B!KM?KH82!S=6)J96MT=2!8-3`Y=C,`6#4P.78S
M(')O>KGM<F5N:6$`65D`65E960!986AO;R$@;6%P`%)OZ&YE`$IE;65N`$%N
M;P!3^FAL87/M;2X`4W1E('8@5$585$]63TT@4D6N24U%+B!0;W6^:71E('1L
M8>AI9&QO(%L\/ET@;F$@<')E<&YU=&EE(&YA<W#DNR!D;R!765-)5UE'+@!.
M96WTOF5T92!V>71V;W)INR!V:6%C(&%K;R`E9"!B;&]K;W8N`$YI92!S=&4@
M875T96YT:69I:V]V86[]+@!6;R!68;EO;2!P;&YO;2!M96YE(&YE;?2^971E
M('!O=;YINR!Z;F%K("=<)RX`3F5Z861A;&D@<W1E('!L871N^B!E+6UA:6QO
M=OH@861R97-U+@!.975RZ&EL:2!S=&4@=GJ[86@@;65D>FD@OFEA9&YY;6D@
M<&]L:6%M:2!Z(&EM<&]R=&]V86[I:&\@<_IB;W)U(&$@>F]D<&]V961A:OIC
M:6UI('!OM6%M:2!V("5S+@!";VQI('-T92!O9&ALX7-E;OTN`$UU<^UT92!Z
M861ANR!P;&%T;ND@Z.US;&\@;6]B:6QNZ6AO('1E;&5F\VYU+"!K=&]RZ2!O
M8G-A:'5J92!I8F$@Z.US;&$@<R!V;VQI=&6U;OUM('!R969I>&]M("<K)R!P
M<F4@;65D>FENX7)O9&[](&9O<FWA="X`375S[71E('IA9&&[('!L871N^B!H
M;V1N;W1U+@!!8GD@<W1E(&UO:&QI('!O=;[M=F&[(%)E9VES='+A8VEE+"!M
M=7/M=&4@;F%J<VOT<B!N86MO;F9I9W5R;W9ANR!$871A5')E92!B86-K96YD
M+@!-=7/M=&4@;F%K;VYF:6=U<F]V8;L@5D93(&)A8VME;F0N`$UU<^UT92!P
M;W#M<V&[('!R;V)LZ6T@<')E9'3];2P@86MO(&]D;[EL971E('-P<N%V=2!O
M('!R;V)LZ6UE+@!-=7/M=&4@>F%D8;L@55),(&%D<F5S=2P@;F$@:W1O<OH@
M=.%T;R!L:6YK82!U:V%Z=6IE`$UU<^UT92!V>6)R8;L@<V5R=F5R+"!K=&]R
M_2!MX2!B>;L@=GEM87IA;OTN`$UU<^UT92!U<NAINR!M96YO('!O=;[M=F%T
M9;5A+"!K=&]RZ6AO(&-H8V5T92!V>6UA>F&[+@!-=7/M=&4@=7+H:;L@;65N
M;R!P;W6^[79A=&6U82P@:W1O<NEH;R!C:&-E=&4@=GEM87IANRX`375S[71E
M('5RZ&F[(&UE;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC971E('!R:61A
MNRX`375S[71E('5RZ&F[('!O=;[M=F%T9;5A+"!K=&]R_2!S82!MX2!A:W1U
M86QI>F]V8;LN`$UU<^UT92!U<NAINR!A:V-I=2P@:W1O<N$@<V$@;>$@=GEK
M;VYANRX`375S[71E('IA9&&[(&UE;F\@;F]V96H@:V%T96?S<FEE+@!-=7/M
M=&4@>F%D8;L@=&%L:6%N<VME('1E;&5F\VYN92#H[7-L;P!0;&%T;F]SNR!6
M8;EE:B!R96SA8VEE('!R92!A<&QI:^%C:74@)7,@=GEP<KEA;&$N(%!R;W/M
M;2!P<FEH;.%S=&4@<V$@>FYO=G4N`%9AN6$@16UA:6QO=N$@861R97-A`%9A
MN6$@16UA:6QO=N$@861R97-A('!O=;YI=.$@<')E(&]D8VCA9'IA:OIC=2!P
M;[ET=3H`5F&Y92!I;F9O<FWA8VEE`%9AN6$@:6YT97)N971O=N$@861R97-A
M('-A('IM96YI;&$@;V0@>F'H:6%T:W4@5F&Y96H@<F5LX6-I92`E<RX@4')E
M(%9AN74@8F5Z<&7H;F]SNR!S82!M=7/M=&4@>FYO=G4@<')I:&SA<VF[+@!6
M8;EE(&UE;F\`5N&Y(&%U=&5N=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE
M('!R:63A=F%N:64@<&]UONUV871EM6]V+B!!:R!S:2"^96SA=&4@<&]UOFF[
M($AO<F1E(&YA('-P<N%V=2!P;W6^[79A=&6U<VO]8V@@^NAT;W8L(&UU<^UT
M92!P;W6^:;L@:6[](&%U=&5N=&EF:6MAZ&[](&)A8VME;F0N`%;AN2!A=71E
M;G1I9FEK8>AN_2!M;V1U;"!N97!O9'!O<G5J92!Z;V)R87IO=F%N:64@>F]Z
M;F%M=2!P;W6^[79A=&6U;W8L(&%L96)O(&)O;&$@=.%T;R!M;[YN;W.[('H@
M;F5J86OI:&\@9/1V;V1U('IA:^%Z86[A+@!:9.$@<V$L(+YE(%;AN2!P<F5H
M;&EA9&'H('-A('IM96YI;"!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S
M+B!0<F4@5F&Y=2!B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S
M:;LN`%;AN2!P<F5H;&EA9&'H(&YE<&]D<&]R=6IE('3Z=&\@9G5N:V-I=2X`
M5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU('1L8>AE
M+B!3=&QAZ'1E($-O;G1R;VPO0V]M;6%N9"`K(%`@<')E('1L8>@N`%9AN6$@
M86MT=>%L;F$@Z&%S;W;A('KS;F$Z`%9AN6$@<')E9&YA<W1A=F5NX2!I9&5N
M=&ET82!B;VQA('IM96YE;N$N`%!R961N87-T879E;N$@:61E;G1I=&$Z`%9A
MN64@;65N;SH`4&QA=&YO<[L@5N&Y:&\@^NAT=2!V>7!RN6%L82X`5F&Y92!N
M;W;I(&AE<VQO('!R92`E<R!J93H@)7,`5F&Y92!N87-T879E;FEA(&)O;&D@
M86MT=6%L:7IO=F%NZ2!P<F4@=&]T;R!S961E;FEE+@!68;EE(&YA<W1A=F5N
M:6$@8F]L:2!A:W1U86QI>F]V86[I+@!68;EE(&AE<VQO(&)O;&\@;V)N;W9E
M;ND`5F&Y92!H97-L;R!B;VQO(&]B;F]V96[I+"!S:V]N=')O;'5J=&4@<VD@
M<&^Y='4@82!P<FEH;.%S=&4@<V$@<R!68;GM;2!N;W;];2!H97-L;VTN`%!L
M871N;W.[(%;AN6AO(&AE<VQA('9Y<'*Y86QA+@!68;EE('9Z9&EA;&5NZ2!S
M97)V97)Y.@!*=6AO<VSA=FEA`%IA:7(`6F%M8FEA`%II;6)A8G=E`%II<'!Y
M`%M3:W)YNR!C:71O=F%N_2!T97AT70!;4W!RX79A(&\@<')O8FSI;65=`%M:
M;V)R87IINR!C:71O=F%N_2!T97AT("T`6UIO8G)A>FF[(&-I=&]V86[]('1E
M>'0@+2`E<R!R:6%D:V]V70!;<FEA9&]K("5S('H@)7-=`%]!9&UI;FES='+A
M8VEA`%]#3$D`7T1A=&%4<F5E`%]6>6UA>F&[(')I861O:P!?4VMU<&EN>0!?
M4&]M;V-N[6L`5FQA<W1N;W-T:2!?;V)RX7IK=2XN+@!?4')I:&SA<VF[('-A
M`%]/9&ALX7-INR!S80!?57!R879INR!L:6YK=2XN+@!?3F%S=&%V96YI80!?
M4'+A=F$`3V1S=%]RX6YINR!L:6YK=2XN+@!.85]S=&%V96YI90!6;&%S=&YO
M<W1I(%]T86)UM6MY+BXN`%!O7W6^[79A=&5L:6$`861R97/A<@!A9')E<^%T
M(&YE>F[A;7D`:V%L96YDX7(`8F5Z=F5T<FEE`&YE<&]D87)I;&\@<V$@=GET
M=F]R:;L@=OUS='5P;OT@<_IB;W(`;F5P;V1A<FEL;R!S82!O='9O<FF[('9S
M='5P`&ML:6MN:71E('-E;0!C:'EB82!P<FD@<&]UOFET[2!P<NUK87IO=NEH
M;R!R:6%D:W4`8VAY8F$@:V]N9FEG=7+A8VEE`&-H_6)A(&3T;&6^:73]('-Y
M<W3I;6]V_2!S^F)O<@!C:'EB82!F;W)MX71U(/ID86IO=@!P;VQOOFMA(&YE
M;N%J9&5NX0!K;&5SX0!S^F)O<@!Z;R!S;65R=2`E<R`H)7,I('+]8VAL;W.[
M;W4@)7,@)7,`;N%R87IO=OT`=CH`:&@`;F5Z;N%M92!M96YO(&AO<W1I=&6U
M80!O:V%MOFET90!V('-P<N%V90!C:'EB82!V<W1U<'4O=OUS='5P=0!I;G1E
M<F[A(&-H>6)A('-O9G1VZ7)U`')I861K;W9=`'!OZ&%S('9Y=';A<F%N:6$@
M25-/(&YA<W1A;&$@8VAY8F$@;6MI<V]F<R`E9`!M;0!M96YO`&YE:6UP;&5M
M96YT;W9A;ND`>F%T:6&U(&YE:6UP;&5M96YT;W9A;ND`<&]Z;N%M:V]V_2!B
M;&]K`'!E<F-E;G0`<'+M<W1U<"!Z86UI971N=73]`&)O9&]V`'9Z9&EA;&5N
MX2!C:'EB82!V('!R;W1O:V]L90!S=/IP80!S;'6^8F$@;FEE(&IE(&1O<W1U
M<&[A`'IO8G)A>FF[(')O>F1I96QY`'-M<S)E;6%I;"!C97H@2%144`!S<P!U
M<W3A;&5N_0!S>7-TZ6UO=N$@8VAY8F$`>F]Z;F%M(/IL;V@`9&_H87-NX2!C
M:'EB80!P<F4@<&]T=G)D96YI92!Z861A:G1E(&AE<VQO(&1V86MRX70`=6YI
M9FEK;W9A;ND`;F5P;VUE;F]V86[A`&1E9FEN=6IE('!O=;[M=F%T9;4`=D-A
M<F0`N3H`=V5A=&AE<BYC;VT`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S:U]32R]H96QP
M+GAM;```````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S
M,C``,3`T,3<S-C(W-S<`,#(P,S4P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM
M("1(;W)D93H@:&]R9&4O;&]C86QE+W-K7U-++VAE;'`N>&UL+'8@,2XR(#(P
M,#0O,#4O,C<@,C`Z,C(Z,3,@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A
M;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O
M=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@
M(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@
M;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)
M3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS
M(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E
M9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@
M<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M
M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL
M(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A
M<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T
M:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO
M=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC
M:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W
M96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*
M/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^
M"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P
M86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC
M:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC
M:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE
M(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T
M:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T
M:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N
M86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME
M('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y
M(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@
M86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U
M;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA
M;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M/"]H96QP/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VQ?4TDO````````````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8R-S<W`#`Q-C<P,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]S;%]322],0U]-15-304=%4R\`````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#(P-#8W`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+W-L7U-)+TQ#7TU%4U-!1T53+VAO<F1E+FUO
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,S,S4P,0`Q,#0Q-S,V,C<W-P`P
M,C(Q,C<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````"$!@``'````#PT``"]"```7&@```````!0BP``#@```%&+
M```/````8(L```T```!PBP``"````'Z+```+````AXL```P```"3BP``!```
M`*"+```,````I8L```\```"RBP``"P```,*+```.````SHL```4```#=BP``
M*````..+```*````#(P``!4````7C```$@```"V,```+````0(P```X```!,
MC```"@```%N,```-````9HP```X```!TC```$0```(.,```-````E8P```P`
M``"CC```#0```+",```&````OHP```\```#%C```&````-6,```,````[HP`
M``X```#[C```#@````J-```(````&8T``"X````BC0``&@```%&-```R````
M;(T``#@```"?C0``5````-B-``!1````+8X``%H```!_C@``5P```-J.```T
M````,H\```H```!GCP``!0```'*/```&````>(\``!$```!_CP``"````)&/
M```)````FH\```D```"DCP``)0```*Z/```@````U(\``!````#UCP``#P``
M``:0```*````%I````,````AD```#P```"60```4````-9````D```!*D```
M#0```%20```2````8I````\```!UD```"@```(60```/````D)````@```"@
MD```)````*F0```4````SI```!8```#CD```"````/J0```9`````Y$```<`
M```=D0``#````"61```L````,I$```X```!?D0```P```&Z1```+````<I$`
M``<```!^D0``!P```(:1```%````CI$```4```"4D0``"@```)J1```#````
MI9$``!<```"ID0``"@```,&1```/````S)$```X```#<D0``&````.N1```C
M````!)(```X````HD@``%````#>2```7````3)(``!<```!DD@``%P```'R2
M```3````E)(```\```"HD@``#@```+B2```?````QY(```<```#GD@``!@``
M`.^2```(````]I(```\```#_D@``!@````^3```*````%I,``!,````ADP``
M"P```#63```0````09,``!4```!2DP``%0```&B3```'````?I,```4```"&
MDP``%0```(R3```1````HI,```P```"TDP``.P```,&3```)````_9,```<`
M```'E```%`````^4```#````))0```4````HE```$````"Z4```)````/Y0`
M`!,```!)E```.0```%V4```2````EY0``"<```"JE```+````-*4```J````
M_Y0``"4````JE0``"@```%"5```&````6Y4```D```!BE0``!P```&R5```O
M````=)4``#<```"DE0``+@```-R5``!5````"Y8``"T```!AE@``+0```(^6
M```M````O98``$````#KE@``(P```"R7```C````4)<``"T```!TEP``,P``
M`**7```5````UI<``!D```#LEP``*0````:8```D````,)@``!$```!5F```
M"@```&>8```,````<I@```H```!_F```$````(J8```6````FY@``!8```"R
MF```!P```,F8```'````T9@``!0```#9F```"@```.Z8```(````^9@```@`
M```"F0``!P````N9```'````$YD```8````;F0``!0```"*9```'````*)D`
M``8````PF0``"````#>9```I````0)D```X```!JF0``"@```'F9```$````
MA)D```<```")F0``"0```)&9```&````FYD``!$```"BF0``!P```+29```6
M````O)D```0```#3F0``"````-B9```&````X9D```T```#HF0``!@```/:9
M```>````_9D``!$````<F@``"````"Z:```-````-YH```P```!%F@``!P``
M`%*:```#````6IH```,```!>F@``%P```&*:```3````>IH```@```".F@``
M!````)>:```(````G)H```@```"EF@``00```*Z:```@````\)H```8````1
MFP``!@```!B;```5````'YL``!@````UFP``(@```$Z;```N````<9L``!T`
M``"@FP``(0```+Z;``!4````X)L``"D````UG```"@```%^<```'````:IP`
M`!4```!RG```#@```(B<```*````EYP```\```"BG```#0```+*<```/````
MP)P```T```#0G```"0```-Z<```4````Z)P```8```#]G```&`````2=```=
M````'9T``!,````[G0``%````$^=```$````9)T```8```!IG0``5````'"=
M```$````Q9T```X```#*G0``!0```-F=```%````WYT``!L```#EG0``&@``
M``&>```1````')X``!$````NG@``'````$">```J````79X``!````"(G@``
M(0```)F>```%````NYX``!,```#!G@``$@```-6>```*````Z)X```\```#S
MG@``$0````.?```3````%9\```P````IGP``!@```#:?```&````/9\``!<`
M``!$GP``$````%R?```1````;9\```@```!_GP``!0```(B?```,````CI\`
M`!````";GP``!0```*R?```-````LI\```8```#`GP``!P```,>?```-````
MSY\```<```#=GP``"P```.6?```'````\9\```<```#YGP``"0````&@```*
M````"Z```!D````6H```#````#"@```0````/:````4```!.H```)0```%2@
M```2````>J```!,```"-H```*P```*&@```[````S:```"`````)H0``-@``
M`"JA```(````8:$```P```!JH0``!@```'>A```$````?J$```X```"#H0``
M"@```)*A```-````G:$``!X```"KH0``&P```,JA```A````YJ$``!X````(
MH@``&0```">B```>````0:(``!L```!@H@``)@```'RB```;````HZ(``!X`
M``"_H@``'````-ZB```F````^Z(``#,````BHP``)@```%:C```K````?:,`
M`#@```"IHP``+P```.*C```2````$J0``"D````EI```$@```$^D``"B````
M8J0``!8````%I0``(P```!RE```H````0*4``"D```!II0``*````).E```?
M````O*4``"````#<I0``)0```/VE```H````(Z8``"$```!,I@``'````&ZF
M```F````BZ8``$$```"RI@``#````/2F```'`````:<```<````)IP``!@``
M`!&G```-````&*<``!`````FIP``$@```#>G```3````2J<``!(```!>IP``
M!P```'&G```$````>:<```P```!^IP``#@```(NG```/````FJ<``!,```"J
MIP``#0```+ZG```H````S*<```,```#UIP``#0```/FG```&````!Z@``!$`
M```.J```%P```""H```;````.*@```X```!4J````@```&.H```%````9J@`
M`!````!LJ```!````'VH```-````@J@```X```"0J````P```)^H```.````
MHZ@```@```"RJ```#P```+NH```/````RZ@```T```#;J```$````.FH```+
M````^J@```8````&J0``#`````VI```1````&JD``!D````LJ0``"P```$:I
M```-````4JD``"(```!@J0``"@```(.I```8````CJD``!D```"GJ0``%@``
M`,&I```-````V*D```<```#FJ0``%````.ZI```+`````ZH``"(````/J@``
M+P```#*J```+````8JH```D```!NJ@``&0```'BJ```+````DJH``!<```">
MJ@``%P```+:J```)````SJH``!8```#8J@``#P```.^J```6````_ZH```X`
M```6JP``&````"6K```(````/JL```T```!'JP``)@```%6K``!#````?*L`
M``@```#`JP``$@```,FK```(````W*L```L```#EJP``+P```/&K```.````
M(:P```4````PK```!@```#:L```#````/:P```<```!!K```!````$FL```*
M````3JP```H```!9K```#P```&2L```0````=*P``!<```"%K```$0```)VL
M```7````KZP```D```#'K```!0```-&L```+````UZP```H```#CK````@``
M`.ZL```%````\:P```T```#WK```&P````6M```7````(:T```D````YK0``
M#@```$.M```-````4JT``!(```!@K0``.````'.M```@````K*T```@```#-
MK0``#@```-:M``![````Y:T``!@```!AK@``$0```'JN```'````C*X```4`
M``"4K@``&0```)JN```'````M*X```@```"\K@``!@```,6N```&````S*X`
M`!````#3K@``#P```.2N```0````]*X```\````%KP``"P```!6O```/````
M(:\```P````QKP``#P```#ZO```'````3J\```8```!6KP``#@```%VO```,
M````;*\``"@```!YKP``#P```**O```(````LJ\```@```"[KP``$P```,2O
M```>````V*\``"$```#WKP``(````!FP```9````.K```!<```!4L```)0``
M`&RP```7````DK````0```"JL```&P```*^P```-````R[````,```#9L```
M"````-VP```*````YK````P```#QL```"P```/ZP```$````"K$``!,````/
ML0``%````".Q```,````.+$```D```!%L0``#@```$^Q```+````7K$``!L`
M``!JL0``!P```(:Q```'````CK$```H```"6L0``#0```*&Q```)````K[$`
M``0```"YL0``!0```+ZQ```#````Q+$``!@```#(L0``"@```.&Q```$````
M[+$``"8```#QL0``#@```!BR``!\````)[(``!4```"DL@``!0```+JR```'
M````P+(```P```#(L@``"````-6R```*````WK(```8```#IL@``"````/"R
M```"````^;(```8```#\L@``!@````.S```4````"K,```T````?LP``$```
M`"VS```;````/K,```0```!:LP``"0```%^S```0````:;,```D```!ZLP``
M"0```(2S```%````CK,``!H```"4LP``"````*^S```&````N+,``!D```"_
MLP``#@```-FS```'````Z+,```<```#PLP``!0```/BS```)````_K,```H`
M```(M````@```!.T```&````%K0```T````=M```"0```"NT```&````-;0`
M`!(````\M```"0```$^T```'````6;0``!0```!AM```'0```':T```&````
ME+0```H```";M```!````*:T```)````J[0```@```"UM```$0```+ZT```)
M````T+0```8```#:M```#0```.&T```&````[[0```0```#VM```.0```/NT
M```]````-;4``#H```!SM0``'@```*ZU```%````S;4```X```#3M0``!```
M`.*U```&````Y[4``"$```#NM0``%0```!"V```&````)K8```0````MM@``
M$0```#*V```&````1+8```H```!+M@``(@```%:V```$````>;8```4```!^
MM@``'0```(2V```$````HK8```P```"GM@``"@```+2V```(````O[8```D`
M``#(M@``!0```-*V```Z````V+8``#`````3MP``-0```$2W```I````>K<`
M`$<```"DMP``.````.RW```I````);@``#\```!/N```+@```(^X```M````
MOK@``!\```#LN```#P````RY```2````'+D```L````ON0``)@```#NY```I
M````8KD``"0```",N0``)@```+&Y```(````V+D```H```#AN0``"0```.RY
M```'````]KD``"````#^N0``(````!^Z```F````0+H```H```!GN@``&0``
M`'*Z```I````C+H``!8```"VN@``$@```,VZ```'````X+H```H```#HN@``
M#````/.Z```/`````+L``!`````0NP``0````"&[``!P````8KL``&8```#3
MNP``#@```#J\```)````2;P```H```!3O```$@```%Z\```3````<;P```P`
M``"%O```!@```)*\```/````F;P``!(```"IO```$````+R\```1````S;P`
M`!P```#?O```(P```/R\``!J````(+T```\```"+O0``!0```)N]```0````
MH;T```D```"RO0``!````+R]```+````P;T``!0```#-O0``#````.*]```,
M````[[T```\```#\O0``%0````R^```I````(KX``"H```!,O@``)@```'>^
M```G````GKX``"D```#&O@``*@```/"^```9````&[\``$(````UOP``$0``
M`'B_```2````BK\``!,```"=OP``%````+&_```/````QK\``!8```#6OP``
M%P```.V_```0````!<```!$````6P```-````"C````3````7<```!(```!Q
MP```-0```(3````4````NL````<```#/P```#````-?````@````Y,```!0`
M```%P0``$0```!K!```7````+,$``!P```!$P0``$P```&'!```1````=<$`
M`!H```"'P0``'@```*+!```:````P<$``!$```#<P0``%````.[!```7````
M`\(``!4````;P@``"0```#'"```9````.\(```0```!5P@``!P```%K"```+
M````8L(``!$```!NP@``!@```(#"```&````A\(```8```".P@``!0```)7"
M```'````F\(```<```"CP@``!0```*O"```6````L<(```8```#(P@``!@``
M`,_"```$````UL(```0```#;P@``!P```.#"```.````Z,(```P```#WP@``
M#`````3#```-````$<,```H````?PP``#@```"K#```%````.<,``"@````_
MPP``#@```&C#```,````=\,```\```"$PP``"@```)3#```(````G\,```D`
M``"HPP``*P```++#```$````WL,```@```#CPP``)@```.S#```2````$\0`
M``\````FQ```!@```#;$```*````/<0```<```!(Q```"````%#$```@````
M6<0```D```!ZQ```#````(3$```-````D<0```X```"?Q```%@```*[$```1
M````Q<0```8```#7Q````P```-[$```&````XL0``!D```#IQ```!P````/%
M```$````"\4```L````0Q0``"P```!S%```'````*,4```<````PQ0``%@``
M`#C%```-````3\4```T```!=Q0``"@```&O%```0````=L4```\```"'Q0``
M$0```)?%```7````J<4```H```#!Q0``$0```,S%```(````WL4```0```#G
MQ0``#P```.S%```Z````_,4```4````WQ@``#````#W&```>````2L8```X`
M``!IQ@``$````'C&```+````B<8```P```"5Q@``"0```*+&```'````K,8`
M``H```"TQ@``"0```+_&```.````R<8``!````#8Q@``&@```.G&```*````
M!,<```D````/QP``"@```!G'```,````),<```\````QQP``"````$''```&
M````2L<```<```!1QP``"P```%G'``!'````9<<```T```"MQP``"0```+O'
M```$````Q<<```,```#*QP``$P```,['```3````XL<``!,```#VQP``"@``
M``K(```"````%<@```0````8R```)0```!W(```#````0\@```4```!'R```
M*@```$W(```*````>,@```4```"#R```!````(G(```*````CL@```T```"9
MR```!@```*?(```(````KL@```@```"WR```!````,#(```%````Q<@``&@`
M``#+R```"0```#3)```,````/LD```4```!+R0``!@```%')```;````6,D`
M`"\```!TR0``$````*3)```*````M<D```\```#`R0``"@```-#)```)````
MV\D``!,```#ER0``&P```/G)```8````%<H``!<````NR@``#@```$;*```#
M````5<H```<```!9R@``"````&'*```'````:LH```H```!RR@``"P```'W*
M```'````B<H``%$```"1R@``$````./*```,````],H```T````!RP``&@``
M``_+``!*````*LL```8```!URP``!@```'S+```&````@\L``!\```"*RP``
M!@```*K+```)````L<L``!@```"[RP``%P```-3+```&````[,L```T```#S
MRP``(@````',``!7````),P``!,```!\S```(P```)#,```3````M,P```(`
M``#(S```"P```,O,```(````U\P```T```#@S```"@```.[,```'````^<P`
M`!0````!S0``!@```!;-```(````'<T```X````FS0``!P```#7-```*````
M/<T```L```!(S0``!P```%3-```,````7,T```T```!IS0``#````'?-```)
M````A,T```D```".S0``"@```)C-```'````H\T```D```"KS0``!P```+7-
M```*````O<T``!L```#(S0``$@```.3-```*````]\T```D````"S@``$```
M``S.```'````'<X``!(````ES@``!````#C.```'````/<X```4```!%S@``
M!0```$O.```+````4<X``!0```!=S@``$0```'+.```:````A,X``!8```"?
MS@``%````+;.```7````R\X``!@```#CS@``'````/S.```9````&<\```<`
M```SSP``!0```#O/```-````0<\```P```!/SP``"````%S/```7````9<\`
M``L```!]SP``$P```(G/```$````G<\```H```"BSP``!````*W/```,````
MLL\```D```"_SP``!0```,G/```'````S\\```4```#7SP``!````-W/```"
M````XL\``#@```#ESP``+````![0```2````2]```"D```!>T```,@```(C0
M```*````N]```"P```#&T```+@```//0```S````(M$``#,```!6T0``.```
M`(K1```/````P]$``!@```#3T0``$````.S1```/````_=$``!,````-T@``
M%````"'2```2````-M(``!0```!)T@``%0```%[2```M````=-(``"T```"B
MT@``,0```-#2```N`````M,``"\````QTP``+````&'3``!B````CM,``!,`
M``#QTP``"`````74```(````#M0``"L````7U```(0```$/4```:````9=0`
M``D```"`U```10```(K4``!!````T-0```0````2U0``$P```!?5```4````
M*]4```X```!`U0``$P```$_5```8````8]4```8```!\U0``"0```(/5```*
M````C=4```\```"8U0``$````*C5```'````N=4```X```#!U0``!0```-#5
M```;````UM4```@```#RU0``!@```/O5```4`````M8``!$````7U@``#@``
M`"G6```X````.-8```(```!QU@``!@```'36```.````>]8```4```"*U@``
M!P```)#6```.````F-8```8```"GU@``!````*[6```I````L]8``!<```#=
MU@``'P```/76``!<````%=<``!0```!RUP``/@```(?7```?````QM<``!``
M``#FUP``!P```/?7```.````_]<```P````.V```#````!O8```3````*-@`
M``H````\V```'0```$?8```9````9=@```4```!_V```$0```(78```1````
ME]@``"0```"IV```%0```,[8```2````Y-@```X```#WV```&0````;9```(
M````(-D```D````IV0``#0```#/9```*````0=D```L```!,V0``"@```%C9
M```'````8]D```@```!KV0``!0```'39```?````>MD```8```":V0``$```
M`*'9```(````LMD```T```"[V0``"````,G9```2````TMD``"P```#EV0``
M&@```!+:```)````+=H```H````WV@``%0```$+:```%````6-H``!0```!>
MV@``!````'/:```0````>-H```8```")V@``!P```)#:```>````F-H``"@`
M``"WV@``"@```.#:```:````Z]H``!0````&VP``!````!O;```$````(-L`
M``L````EVP``!0```#';```&````-]L```@````^VP``!@```$?;```*````
M3ML``!L```!9VP``-````'7;```T````JML``"````#?VP``*0````#<```@
M````*MP``$$```!+W```&@```(W<```H````J-P``"D```#1W```(@```/O<
M```&````'MT```@````EW0``!0```"[=```(````--T``!D````]W0``&0``
M`%?=```J````<=T``",```"<W0``+@```,#=```T````[]T```@````DW@``
M%P```"W>```*````1=X```<```!0W@``(0```%C>```0````>MX```X```"+
MW@``"P```)K>```'````IMX``!,```"NW@``"````,+>```+````R]X```H`
M``#7W@``%````.+>```R````]]X```L````JWP``!0```#;?```%````/-\`
M`!<```!"WP``#P```%K?```$````:M\```H```!OWP``"0```'K?```+````
MA-\```X```"0WP``!0```)_?```$````I=\```T```"JWP``,@```+C?``!%
M````Z]\``!<````QX```'@```$G@```4````:.````4```!]X```%````(/@
M```'````F.````X```"@X```*@```*_@```&````VN````P```#AX```#0``
M`.[@```1````_.````L````.X0``-@```!KA```*````4>$``"(```!<X0``
M"P```'_A```/````B^$``#(```";X0``!0```,[A```.````U.$``!,```#C
MX0``!P```/?A```1````_^$```<````1X@``%````!GB```8````+N(```<`
M``!'X@``!0```$_B```,````5>(```P```!BX@``$@```&_B```$````@N(`
M``<```"'X@``"@```(_B```+````FN(```P```"FX@``#@```+/B```.````
MPN(```4```#1X@``!0```-?B```N````W>(``"8````,XP``(P```#/C```#
M````5^,``!(```!;XP``!@```&[C```>````=>,``!@```"4XP``)0```*WC
M```-````T^,```D```#AXP```P```.OC```'````[^,```H```#WXP```@``
M``+D```,````!>0``!4````2Y```"P```"CD```9````-.0``"````!.Y```
M$@```&_D```%````@N0```H```"(Y```%0```)/D```2````J>0```P```"\
MY```!````,GD```'````SN0```P```#6Y```4@```./D```7````-N4```<`
M``!.Y0``!@```%;E```.````7>4```P```!LY0``#0```'GE```5````A^4`
M`!(```"=Y0``#P```+#E```4````P.4``!L```#5Y0``$````/'E``!I````
M`N8``!H```!LY@``%P```(?F```G````G^8``!H```#'Y@``%P```.+F```;
M````^N8``!D````6YP``'P```##G```3````4.<```@```!DYP``!P```&WG
M```(````=><```D```!^YP``%0```(CG```-````GN<``!,```"LYP```P``
M`,#G``!&````Q.<``#\````+Z```-P```$OH``!7````@^@``!\```#;Z```
M+P```/OH```*````*^D```@````VZ0``#0```#_I```M````3>D```0```![
MZ0``3P```(#I```E````T.D``!P```#VZ0``"P```!/J```?````'^H``!T`
M```_Z@``)0```%WJ```@````@^H``"0```"DZ@``(````,GJ```+````ZNH`
M``<```#VZ@``#0```/[J```,````#.L```8````9ZP``.0```"#K```,````
M6NL```<```!GZP``"0```&_K```3````>>L```D```"-ZP``!````)?K```0
M````G.L```@```"MZP``"````+;K```$````O^L```L```#$ZP``#````-#K
M```1````W>L```P```#OZP``&@```/SK```/````%^P```<````G[```#0``
M`"_L```4````/>P```X```!2[```#````&'L```;````;NP``"P```"*[```
M$P```+?L```<````R^P``"@```#H[```!@```!'M```'````&.T``!,````@
M[0``!0```#3M```$````.NT``!<````_[0``"@```%?M```,````8NT```D`
M``!O[0``!@```'GM```)````@.T```@```"*[0``"0```)/M```*````G>T`
M`!$```"H[0``!@```+KM```.````P>T```X```#0[0``#0```-_M```+````
M[>T``!T```#Y[0``"P```!?N```"````(^X```<````F[@``!@```"[N```)
M````->X```<````_[@``.P```$?N```H````@^X``!4```"L[@``!0```,+N
M```'````R.X```@```#0[@``!P```-GN```%````X>X```<```#G[@``#@``
M`._N```)````_NX```8````([P``"`````_O```+````&.\```<````D[P``
M"````"SO```'````->\``!8````][P``"0```%3O```&````7N\```L```!E
M[P``'````''O```4````CN\```<```"C[P``"````*OO```(````M.\```4`
M``"][P``$````,/O```0````U.\```8```#E[P``&0```.SO```*````!O``
M`!P````1\```!P```"[P```%````-O```!`````\\```%````$WP```+````
M8O````T```!N\```%P```'SP```$````E/````D```"9\```"@```*/P```'
M````KO````(```"V\```#@```+GP```(````R/```!\```#1\```(P```/'P
M```X````%?$``#$```!.\0``)P```(#Q``!D````J/$``!0````-\@``50``
M`"+R```X````>/(``$H```"Q\@``6P```/SR```H````6/,``#@```"!\P``
M*````+KS```L````X_,``"<````0]```&P```#CT```^````5/0``*D!``"3
M]```(P```#WV```7````8?8``$@```!Y]@``A0```,+V```P````2/<``$$`
M``!Y]P``6P```+OW``!)````%_@``!T```!A^```&````'_X```A````F/@`
M`!\```"Z^```*P```-KX```A````!OD``!T````H^0``$0```$;Y```S````
M6/D``"4```",^0``)P```++Y```?````VOD``#````#Z^0``:0```"OZ```]
M````E?H``&4```#3^@``30```#G[```O````A_L``"X```"W^P``,````.;[
M``!4````%_P``%H```!L_```2````,?\``!*````$/T``#(```!;_0``+P``
M`([]```L````OOT``"T```#K_0``<0```!G^``!O````B_X``+,```#[_@``
M%P```*__```E````Q_\``#(```#M_P``*0```"```0`^````2@`!`"(```")
M``$`4@```*P``0`E````_P`!``L````E`0$`L0```#$!`0!%````XP$!`"$`
M```I`@$`,````$L"`0`E````?`(!`!P```"B`@$`,0```+\"`0`'````\0(!
M``<```#Y`@$`!`````$#`0`-````!@,!``L````4`P$`#@```"`#`0`+````
M+P,!``4````[`P$`$````$$#`0`"````4@,!`%D```!5`P$`!0```*\#`0`2
M````M0,!``0```#(`P$`!P```,T#`0`(````U0,!``4```#>`P$``P```.0#
M`0`0````Z`,!``P```#Y`P$`$P````8$`0`-````&@0!``(````H!`$`!P``
M`"L$`0`&````,P0!`!0````Z!`$`#````$\$`0`8````7`0!``8```!U!`$`
M$@```'P$`0`,````CP0!``,```"<!`$`*@```*`$`0`$````RP0!``8```#0
M!`$`!P```-<$`0`?````WP0!`#4```#_!`$`+@```#4%`0`O````9`4!`!<`
M``"4!0$`(````*P%`0`;````S04!`!@```#I!0$`)`````(&`0`?````)P8!
M`!H```!'!@$`(````&(&`0`:````@P8!`#(```">!@$`+P```-$&`0`K````
M`0<!`!\````M!P$`(P```$T'`0`?````<0<!`!H```"1!P$`)0```*P'`0`F
M````T@<!`"4```#Y!P$`)````!\(`0`8````1`@!`!T```!="`$`)````'L(
M`0`8````H`@!`"(```"Y"`$`)0```-P(`0`\`````@D!`!\````_"0$`(P``
M`%\)`0`?````@PD!`"````"C"0$`&@```,0)`0`8````WPD!`"8```#X"0$`
M'@```!\*`0`I````/@H!`!X```!H"@$`"0```(<*`0`,````D0H!`!<```">
M"@$`+P```+8*`0`D````Y@H!``<````+"P$`#P```!,+`0`4````(PL!``X`
M```X"P$`#0```$<+`0`D````50L!``4```!Z"P$`!P```(`+`0`B````B`L!
M`"4```"K"P$`'0```-$+`0`:````[PL!``<````*#`$`QP```!(,`0`+````
MV@P!`!4```#F#`$`!@```/P,`0`)`````PT!``L````-#0$`%P```!D-`0`&
M````,0T!`#,````X#0$`$P```&P-`0`3````@`T!``<```"4#0$`#P```)P-
M`0`'````K`T!`#(```"T#0$`(0```.<-`0`3````"0X!``P````=#@$`$0``
M`"H.`0`R````/`X!``@```!O#@$`"0```'@.`0`*````@@X!`!0```"-#@$`
M"@```*(.`0`=````K0X!``@```#+#@$`'P```-0.`0`(````]`X!`!H```#]
M#@$`!@```!@/`0`5````'P\!``<````U#P$`"````#T/`0`)````1@\!`#\`
M``!0#P$`!P```)`/`0`/````F`\!``X```"H#P$`$````+</`0`)````R`\!
M``D```#2#P$`"````-P/`0`3````Y0\!``<```#Y#P$`&0````$0`0`*````
M&Q`!`!<````F$`$`%````#X0`0`*````4Q`!``P```!>$`$`%P```&L0`0`$
M````@Q`!`"H```"($`$`$0```+,0`0`'````Q1`!``(```#-$`$`$````-`0
M`0`8````X1`!``L```#Z$`$``P````81`0`(````"A$!``8````3$0$`!P``
M`!H1`0`-````(A$!``L````P$0$`%````#P1`0`5````41$!``X```!G$0$`
M+P```'81`0`@````IA$!`!P```#'$0$`#````.01`0`Q````\1$!``4````C
M$@$`$@```"D2`0`_````/!(!`!(```!\$@$`"@```(\2`0`&````FA(!``0`
M``"A$@$`!````*82`0`3````JQ(!``4```"_$@$`!@```,42`0`&````S!(!
M``0```#3$@$`#````-@2`0`*````Y1(!``4```#P$@$`&````/82`0`9````
M#Q,!`!\````I$P$`'0```$D3`0`1````9Q,!``(```!Y$P$`!````'P3`0`*
M````@1,!``8```",$P$`!0```),3`0`#````F1,!``P```"=$P$`10```*H3
M`0`:````\!,!`#4````+%`$`*````$$4`0!3````:A0!`!D```"^%`$`<@``
M`-@4`0`@````2Q4!`#4```!L%0$`(0```*(5`0!%````Q!4!`#`````*%@$`
M*````#L6`0`I````9!8!`"8```".%@$`)0```+46`0`H````VQ8!`"@````$
M%P$`(@```"T7`0`P````4!<!`!(```"!%P$`$P```)07`0`0````J!<!`'D`
M``"Y%P$`"0```#,8`0!S````/1@!`'P```"Q&`$`*P```"X9`0`7````6AD!
M`!8```!R&0$`#P```(D9`0`?````F1D!`!\```"Y&0$`'````-D9`0!1````
M]AD!`!0```!(&@$`"@```%T:`0`%````:!H!``8```!N&@$`"````'4:`0`%
M````?AH!`!(```"$&@$`$````)<:`0`3````J!H!`!T```"\&@$`#P```-H:
M`0`/````ZAH!``0```#Z&@$`"0```/\:`0`+````"1L!``<````5&P$`!0``
M`!T;`0`4````(QL!``<````X&P$`"````$`;`0`/````21L!``@```!9&P$`
M#````&(;`0`/````;QL!``8```!_&P$`%````(8;`0`&````FQL!``P```"B
M&P$`"````*\;`0`$````N!L!``H```"]&P$`!P```,@;`0`$````T!L!`!D`
M``#5&P$``@```.\;`0`)````\AL!``8```#\&P$`!@````,<`0`G````"AP!
M``0````R'`$`#P```#<<`0`3````1QP!``<```!;'`$`!P```&,<`0`&````
M:QP!``8```!R'`$`$````'D<`0`2````BAP!``8```"='`$`"0```*0<`0`B
M````KAP!``<```#1'`$`!P```-D<`0`+````X1P!``4```#M'`$``@```/,<
M`0`+````]AP!`$4!```"'0$`#P```$@>`0`/````6!X!``P```!H'@$`"```
M`'4>`0`(````?AX!``D```"''@$`!0```)$>`0`+````EQX!`!$```"C'@$`
M#@```+4>`0`/````Q!X!``4```#4'@$`&@```-H>`0`*````]1X!`!$`````
M'P$`#@```!(?`0`,````(1\!``X````N'P$`"````#T?`0`3````1A\!``T`
M``!:'P$`#0```&@?`0`-````=A\!`!````"$'P$`%````)4?`0`&````JA\!
M``\```"Q'P$`&@```,$?`0`,````W!\!``X```#I'P$`#@```/@?`0`%````
M!R`!`"X````-(`$`&@```#P@`0`T````5R`!`#X```",(`$`4@```,L@`0!,
M````'B$!`%@```!K(0$`4@```,0A`0`W````%R(!``@```!/(@$`!0```%@B
M`0`&````7B(!`!(```!E(@$`!````'@B`0`)````?2(!``D```"'(@$`*0``
M`)$B`0`M````NR(!``P```#I(@$`$````/8B`0`-````!R,!``4````5(P$`
M$````!LC`0`8````+",!``P```!%(P$`$@```%(C`0`5````92,!`!@```![
M(P$`#0```)0C`0`0````HB,!``D```"S(P$`(0```+TC`0`0````WR,!`!,`
M``#P(P$`$`````0D`0`E````%20!``<````[)`$`!P```$,D`0`T````2R0!
M``X```"`)`$`!P```(\D`0`*````ER0!``@```"B)`$`"````*LD`0`)````
MM"0!``@```"^)`$`"@```,<D`0`#````TB0!`!<```#6)`$`"P```.XD`0`.
M````^B0!`!`````))0$`$P```!HE`0`I````+B4!``H```!8)0$`&0```&,E
M`0`7````?24!`"$```"5)0$`'````+<E`0`5````U"4!`!8```#J)0$`#@``
M``$F`0`A````$"8!``8````R)@$`!@```#DF`0`'````0"8!``X```!()@$`
M!P```%<F`0`*````7R8!`!(```!J)@$`"@```'TF`0`0````B"8!`!L```"9
M)@$`*@```+4F`0`&````X"8!``4```#G)@$`%@```.TF`0`:````!"<!``H`
M```?)P$`0````"HG`0`)````:R<!``@```!U)P$`%@```'XG`0`(````E2<!
M``4```">)P$`#@```*0G`0`+````LR<!`!@```"_)P$`-P```-@G`0`4````
M$"@!`"0````E*`$`*0```$HH`0`I````="@!`"@```">*`$`"````,<H`0`&
M````T"@!``H```#7*`$`"````.(H`0`U````ZR@!`#@````A*0$`-````%HI
M`0!:````CRD!`#,```#J*0$`,P```!XJ`0`S````4BH!`#T```"&*@$`+0``
M`,0J`0`M````\BH!`#,````@*P$`.0```%0K`0`3````CBL!`!<```"B*P$`
M*````+HK`0`E````XRL!`!4````)+`$`"P```!\L`0`-````*RP!``8````Y
M+`$`#````$`L`0`:````32P!`"0```!H+`$`!@```(TL`0`'````E"P!`!8`
M``"<+`$`"0```+,L`0`(````O2P!``8```#&+`$`"@```,TL`0`'````V"P!
M``8```#@+`$`!0```.<L`0`'````[2P!``4```#U+`$`"P```/LL`0`K````
M!RT!`!`````S+0$`"P```$0M`0`&````4"T!``@```!7+0$`#````&`M`0`#
M````;2T!``X```!Q+0$`!@```(`M`0`4````ART!``4```"<+0$`!P```*(M
M`0`&````JBT!``L```"Q+0$`"0```+TM`0`C````QRT!`!$```#K+0$`"0``
M`/TM`0`/````!RX!``P````7+@$`!P```"0N`0`#````+"X!``,````P+@$`
M%@```#0N`0`4````2RX!``<```!@+@$`!0```&@N`0`(````;BX!``<```!W
M+@$`3P```'\N`0`T````SRX!``8````$+P$`"`````LO`0`7````%"\!`"(`
M```L+P$`'0```$\O`0`R````;2\!`!\```"@+P$`-0```,`O`0!S````]B\!
M`"\```!J,`$`"@```)HP`0`&````I3`!`!0```"L,`$`#P```,$P`0`/````
MT3`!`!````#A,`$`&````/(P`0`0````"S$!`!P````<,0$`#P```#DQ`0`5
M````23$!``<```!?,0$`&````&<Q`0`<````@#$!`!0```"=,0$`$0```+(Q
M`0`#````Q#$!``@```#(,0$`5````-$Q`0`$````)C(!`!0````K,@$`!```
M`$`R`0`(````13(!`"````!.,@$`'0```&\R`0`.````C3(!`!@```"<,@$`
M'P```+4R`0`L````U3(!`!`````",P$`)@```!,S`0`%````.C,!`!@```!`
M,P$`%@```%DS`0`2````<#,!`!P```"#,P$`%@```*`S`0`5````MS,!``H`
M``#-,P$`!@```-@S`0`'````WS,!`!````#G,P$`$P```/@S`0`,````##0!
M``D````9-`$`!0```",T`0`-````*30!``P````W-`$`"````$0T`0`0````
M330!``8```!>-`$`!````&4T`0`-````:C0!``@```!X-`$``P```($T`0`&
M````A30!``@```",-`$`"P```)4T`0`&````H30!`!4```"H-`$`"@```+XT
M`0`,````R30!``4```#6-`$`&P```-PT`0`3````^#0!`!,````,-0$`+@``
M`"`U`0`^````3S4!`",```".-0$`)P```+(U`0`&````VC4!``T```#A-0$`
M"````.\U`0`'````^#4!``\`````-@$`"0```!`V`0`2````&C8!`"<````M
M-@$`)P```%4V`0`L````?38!`"P```"J-@$`'P```-<V`0`I````]S8!`",`
M```A-P$`+@```$4W`0`H````=#<!`"L```"=-P$`(@```,DW`0`O````[#<!
M`#L````<.`$`)P```%@X`0`P````@#@!`#D```"Q.`$`.@```.LX`0`5````
M)CD!`"P````\.0$`%@```&DY`0"[````@#D!`!L````\.@$`(````%@Z`0`I
M````>3H!`"H```"C.@$`+````,XZ`0`R````^SH!`"8````N.P$`-````%4[
M`0`W````BCL!`"$```#".P$`(P```.0[`0`P````"#P!`$D````Y/`$`$P``
M`(,\`0`&````ESP!``8```">/`$`!P```*4\`0`0````K3P!``P```"^/`$`
M#P```,L\`0`0````VSP!`!D```#L/`$`!P````8]`0`$````#CT!``P````3
M/0$`#P```"`]`0`.````,#T!`!`````_/0$`#0```%`]`0`S````7CT!``8`
M``"2/0$`#@```)D]`0`%````J#T!`!$```"N/0$`%P```,`]`0`:````V#T!
M``4```#S/0$``@```/D]`0`&````_#T!`!(````#/@$`!0```!8^`0`-````
M'#X!``T````J/@$``P```#@^`0`/````/#X!``@```!,/@$`"0```%4^`0`.
M````7SX!``X```!N/@$`$P```'T^`0`*````D3X!``<```"</@$`#P```*0^
M`0`/````M#X!`!P```#$/@$`#@```.$^`0`/````\#X!`"<`````/P$`#P``
M`"@_`0`:````.#\!`!@```!3/P$`&````&P_`0`+````A3\!``8```"1/P$`
M#0```)@_`0`$````IC\!`"@```"K/P$`*0```-0_`0`&````_C\!``0````%
M0`$`$@````I``0`&````'4`!`!@````D0`$`&````#U``0`&````5D`!`!P`
M``!=0`$`$````'I``0`5````BT`!``X```"A0`$`%P```+!``0`'````R$`!
M``H```#00`$`,0```-M``0`X````#4$!``@```!&00$`%@```$]!`0`'````
M9D$!``H```!N00$`,0```'E!`0`/````JT$!``4```"[00$`!P```,%!`0`#
M````R4$!``<```#-00$`!0```-5!`0`*````VT$!``T```#F00$`#0```/1!
M`0`-`````D(!`!,````00@$`$@```"1"`0`3````-T(!``D```!+0@$`!0``
M`%5"`0`(````6T(!``H```!D0@$``@```&]"`0`'````<D(!``\```!Z0@$`
M(P```(I"`0`5````KD(!``8```#$0@$`$0```,M"`0`0````W4(!`!0```#N
M0@$`-0````-#`0`:````.4,!``H```!40P$`$P```%]#`0!Z````<T,!`!4`
M``#N0P$`%`````1$`0`(````&40!``8````B1`$`'@```"E$`0`(````2$0!
M``@```!11`$`!````%I$`0`&````7T0!``\```!F1`$`#@```'9$`0`0````
MA40!``X```"61`$`$````*5$`0`-````MD0!``P```#$1`$`"````-%$`0`&
M````VD0!``<```#A1`$`%0```.E$`0`.````_T0!`#X````.10$`$0```$U%
M`0`)````7T4!``X```!I10$`%0```'A%`0`;````CD4!`"0```"J10$`(P``
M`,]%`0`<````\T4!`!L````01@$`+````"Q&`0`<````648!``0```!V1@$`
M$0```'M&`0`+````C48!``0```"91@$`!P```)Y&`0`)````ID8!``L```"P
M1@$`"@```+Q&`0`%````QT8!`!P```#-1@$`&P```.I&`0`2````!D<!``P`
M```91P$`#P```"9'`0`;````-D<!`"D```!21P$`!@```'Q'`0`&````@T<!
M``T```"*1P$`#0```)A'`0`/````ID<!``D```"V1P$`!@```,!'`0`%````
MQT<!`!(```#-1P$`#@```.!'`0`%````[T<!`",```#U1P$`#0```!E(`0!B
M````)T@!`!,```"*2`$`!P```)Y(`0`'````ID@!``X```"N2`$`!P```+U(
M`0`)````Q4@!``<```#/2`$`#````-=(`0`"````Y$@!``<```#G2`$`"```
M`.](`0`/````^$@!`!`````(20$`%````!E)`0`7````+DD!``(```!&20$`
M`P```$E)`0`*````34D!``H```!820$`"0```&-)`0`%````;4D!`!<```!S
M20$`"0```(M)`0`'````E4D!`!H```"=20$`%P```+A)`0`'````T$D!``<`
M``#820$`!````.!)`0`)````Y4D!``H```#O20$`!0```/I)`0`&`````$H!
M``X````'2@$`$0```!9*`0`&````*$H!`!(````O2@$`#````$)*`0`'````
M3TH!`!4```!72@$`(0```&U*`0`'````CTH!``H```"72@$`!````*)*`0`)
M````ITH!``@```"Q2@$`#0```+I*`0`-````R$H!``<```#62@$`#@```-Y*
M`0`'````[4H!``0```#U2@$`/````/I*`0`^````-TL!`#P```!V2P$`'P``
M`+-+`0`%````TTL!``X```#92P$`!@```.A+`0`%````[TL!`!T```#U2P$`
M&````!-,`0`&````+$P!``4````S3`$`'@```#E,`0`(````6$P!``<```!A
M3`$`%P```&E,`0`&````@4P!``8```"(3`$`)@```(],`0`%````MDP!``T`
M``"\3`$`#@```,I,`0`(````V4P!``D```#B3`$`!0```.Q,`0`Z````\DP!
M`#0````M30$`.````&)-`0`F````FTT!`#<```#"30$`/P```/I-`0`M````
M.DX!`#<```!H3@$`,0```*!.`0`U````TDX!`"<````(3P$`#@```#!/`0`/
M````/T\!``H```!/3P$`*P```%I/`0`?````AD\!`!\```"F3P$`'0```,9/
M`0`(````Y$\!``D```#M3P$`"0```/=/`0`)`````5`!`"H````+4`$`)P``
M`#90`0`M````7E`!``D```",4`$`%@```)90`0`C````K5`!`!X```#14`$`
M%````/!0`0`)````!5$!``H````/40$`"P```!I1`0`/````)E$!``\````V
M40$`,@```$91`0!O````>5$!`&L```#I40$`$````%52`0`)````9E(!``H`
M``!P4@$`$0```'M2`0`2````C5(!`!@```"@4@$`!0```+E2`0`.````OU(!
M`!$```#.4@$`#@```.!2`0`5````[U(!`!\````%4P$`*````"53`0![````
M3E,!``T```#*4P$`!@```-A3`0`4````WU,!``H```#T4P$`!````/]3`0`+
M````!%0!`!4````05`$`#````"94`0`-````,U0!`!<```!!5`$`%P```%E4
M`0`?````<50!`"$```"15`$`'@```+-4`0`A````TE0!`"8```#T5`$`*```
M`!M5`0`<````1%4!`#@```!A50$`$P```)I5`0`5````KE4!`!0```#$50$`
M%@```-E5`0`0````\%4!`!<````!5@$`%0```!E6`0`4````+U8!`!8```!$
M5@$`,0```%M6`0`2````C58!`!4```"@5@$`.0```+96`0`2````\%8!``<`
M```#5P$`#0````M7`0`@````&5<!`!,````Z5P$`$@```$Y7`0`7````85<!
M`!P```!Y5P$`%P```)97`0`1````KE<!`!P```#`5P$`(````-U7`0`G````
M_E<!`!$````F6`$`'P```#A8`0`:````6%@!`!@```!S6`$`"0```(Q8`0`$
M````EE@!``0```";6`$`!0```*!8`0`*````IE@!`!$```"Q6`$`!@```,-8
M`0`*````RE@!``<```#56`$`!P```-U8`0`'````Y5@!``8```#M6`$`"```
M`/18`0`6````_5@!``8````460$`!@```!M9`0`%````(ED!``4````H60$`
M"0```"Y9`0`3````.%D!`!<```!,60$`#@```&19`0`/````<UD!``D```"#
M60$`$0```(U9`0`&````GUD!`"8```"F60$`#P```,U9`0`/````W5D!`!,`
M``#M60$`#@````%:`0`,````$%H!``X````=6@$`+@```"Q:`0`&````6UH!
M``@```!B6@$`)@```&M:`0`1````DEH!`!$```"D6@$`!@```+9:`0`+````
MO5H!``L```#)6@$`!0```-5:`0`$````VUH!``\```#@6@$`#P```/!:`0`5
M`````%L!`!(````66P$`%P```"E;`0`6````05L!``<```!86P$`!0```&!;
M`0`*````9EL!`!L```!Q6P$`!P```(U;`0`$````E5L!``H```":6P$`#@``
M`*5;`0`&````M%L!``@```"[6P$`!@```,1;`0`+````RUL!``T```#76P$`
M"0```.5;`0`0````[UL!``\`````7`$`$P```!!<`0`4````)%P!``X````Y
M7`$`$@```$A<`0`(````6UP!``@```!D7`$`$0```&U<`0`X````?UP!``@`
M``"X7`$`#@```,%<`0`B````T%P!`!4```#S7`$`$P````E=`0`.````'5T!
M``P````L70$`#````#E=`0`)````1ET!``X```!070$`#````%]=`0`-````
M;%T!``X```!Z70$`*````(E=`0`*````LET!``4```"]70$`"@```,-=`0`-
M````SET!``P```#<70$`"````.E=`0`'````\ET!``8```#Z70$`$P````%>
M`0!)````%5X!`!(```!?7@$`#@```')>`0`(````@5X!``4```"*7@$`#P``
M`)!>`0`2````H%X!`!0```"S7@$`"@```,A>`0`"````TUX!``0```#67@$`
M)P```-M>`0`#`````U\!``4````'7P$`"@````U?`0`*````&%\!``8````C
M7P$`!0```"I?`0`0````,%\!`!$```!!7P$`!@```%-?`0`(````6E\!``<`
M``!C7P$`!````&M?`0`%````<%\!`&,```!V7P$`#P```-I?`0`2````ZE\!
M``4```#]7P$`!0````-@`0`@````"6`!`#4````J8`$`$0```&!@`0`*````
M<F`!``\```!]8`$`"P```(U@`0`)````F6`!`!L```"C8`$`+P```+]@`0`D
M````[V`!`",````480$`$@```#AA`0`#````2V$!``<```!/80$`"0```%=A
M`0`%````86$!``T```!G80$`#````'5A`0`)````@F$!`%@```",80$`%@``
M`.5A`0`/````_&$!``L````,8@$`%P```!AB`0!(````,&(!``8```!Y8@$`
M#@```(!B`0`'````CV(!``L```"78@$`!P```*-B`0`(````JV(!`"0```"T
M8@$`(P```-EB`0`&````_6(!``4````$8P$`'P````IC`0!5````*F,!`!0`
M``"`8P$`(````)5C`0`/````MF,!``(```#&8P$`#0```,EC`0`&````UV,!
M``\```#>8P$`#````.YC`0`&````^V,!``D````"9`$`!@````QD`0`)````
M$V0!``T````=9`$`!P```"MD`0`(````,V0!``L````\9`$`!@```$AD`0`.
M````3V0!`!````!>9`$`#P```&]D`0`,````?V0!``T```",9`$`#@```)ID
M`0`,````J60!``P```"V9`$`#````,-D`0`(````T&0!`!T```#99`$`$```
M`/=D`0`)````"&4!``H````290$`%0```!UE`0`'````,V4!`!(````[90$`
M`P```$YE`0`'````4F4!``4```!:90$`!0```&!E`0`*````9F4!`!$```!Q
M90$`%````(-E`0`C````F&4!`!@```"\90$`'P```-5E`0`@````]64!`!H`
M```69@$`&@```#%F`0`7````3&8!``<```!D9@$`!@```&QF`0`/````<V8!
M``\```"#9@$`!````)-F`0`?````F&8!``X```"X9@$`$@```,=F`0`&````
MVF8!`!,```#A9@$`!@```/5F`0`2````_&8!``D````/9P$`!0```!EG`0`(
M````'V<!``,````H9P$`!````"QG`0`"````,6<!`#\````T9P$`-@```'1G
M`0`;````JV<!`"0```#'9P$`-````.QG`0`/````(6@!`"X````Q:`$`,P``
M`&!H`0`X````E&@!`#@```#-:`$`/0````9I`0`/````1&D!`!L```!4:0$`
M(````'!I`0`5````D6D!`!@```"G:0$`&0```,!I`0`3````VFD!`!@```#N
M:0$`'P````=J`0`K````)VH!`"L```!3:@$`+P```']J`0`L````KVH!`"T`
M``#<:@$`*@````IK`0!>````-6L!`!,```"4:P$`"````*AK`0`,````L6L!
M`"(```"^:P$`+0```.%K`0`F````#VP!``X````V;`$`1````$5L`0`^````
MBFP!``0```#);`$`&0```,YL`0`7````Z&P!``X`````;0$`#P````]M`0`5
M````'VT!``@````U;0$`!0```#YM`0`'````1&T!``<```!,;0$`$@```%1M
M`0`-````9VT!``L```!U;0$`!P```(%M`0`?````B6T!``@```"I;0$`!P``
M`+)M`0`.````NFT!`!````#);0$`#@```-IM`0`W````Z6T!``8````A;@$`
M!@```"AN`0`.````+VX!``<````^;@$`!P```$9N`0`.````3FX!``<```!=
M;@$`!````&5N`0`Q````:FX!`!8```"<;@$`)````+-N`0!:````V&X!`!(`
M```S;P$`1@```$9O`0`>````C6\!`!(```"L;P$`"````+]O`0`.````R&\!
M``T```#7;P$`#````.5O`0`2````\F\!``P````%<`$`'@```!)P`0`9````
M,7`!``4```!+<`$`$0```%%P`0`0````8W`!`!X```!T<`$`%````)-P`0`5
M````J'`!``\```"^<`$`'P```,YP`0`(````[G`!`!$```#W<`$`$@````EQ
M`0`1````''$!`!,````N<0$`$@```$)Q`0`&````57$!``@```!<<0$`!0``
M`&5Q`0`3````:W$!``8```!_<0$`$@```(9Q`0`(````F7$!``T```"B<0$`
M!0```+!Q`0`0````MG$!`"<```#'<0$`$0```.]Q`0`&`````7(!``<````(
M<@$`&````!!R`0`'````*7(!`!,````Q<@$``P```$5R`0`/````27(!``8`
M``!9<@$`"````&!R`0`<````:7(!`"@```"&<@$`!P```*]R`0`5````MW(!
M`!(```#-<@$`!````.!R`0`-````Y7(!``@```#S<@$`!P```/QR`0`+````
M!',!``@````0<P$`!@```!ES`0`)````(',!`!@````J<P$`*@```$-S`0`M
M````;G,!`!T```"<<P$`)@```+IS`0`B````X7,!`#X````$=`$`'````$-T
M`0`A````8'0!`"P```""=`$`(P```*]T`0`'````TW0!``@```#;=`$`!@``
M`.1T`0`+````ZW0!`!````#W=`$`$0````AU`0`G````&G4!`"0```!"=0$`
M+````&=U`0`R````E'4!``<```#'=0$`&@```,]U`0`)````ZG4!``D```#T
M=0$`'````/YU`0`1````&W8!`!`````M=@$`#0```#YV`0`'````3'8!``T`
M``!4=@$`"````&)V`0`2````:W8!``L```!^=@$`&````(IV`0`O````HW8!
M``D```#3=@$`!0```-UV`0`)````XW8!`!D```#M=@$`!@````=W`0`#````
M#G<!``H````2=P$`"0```!UW`0`-````)W<!`!$````U=P$`"````$=W`0`'
M````4'<!`!$```!8=P$`,@```&IW`0!+````G7<!`!T```#I=P$`(0````=X
M`0`6````*7@!``4```!`>`$`$0```$9X`0`(````6'@!`!,```!A>`$`+```
M`'5X`0`(````HG@!``T```"K>`$`$````+EX`0`4````RG@!``P```#?>`$`
M-P```.QX`0`(````)'D!`"$````M>0$`$P```$]Y`0`7````8WD!`"X```![
M>0$`"0```*IY`0`/````M'D!`!8```#$>0$`"0```-MY`0`1````Y7D!``<`
M``#W>0$`&@```/]Y`0`J````&GH!``8```!%>@$`!0```$QZ`0`+````4GH!
M``\```!>>@$`$@```&YZ`0`%````@7H!``@```"'>@$`#0```)!Z`0`+````
MGGH!``P```"J>@$`$0```+=Z`0`1````R7H!``@```#;>@$`!````.1Z`0`R
M````Z7H!`"0````<>P$`)@```$%[`0`&````:'L!``8```!O>P$`!@```'9[
M`0`;````?7L!`!H```"9>P$`&P```+1[`0`.````T'L!``H```#?>P$``P``
M`.I[`0`&````[GL!``L```#U>P$``@````%\`0`*````!'P!`!0````/?`$`
M"P```"1\`0`8````,'P!`!H```!)?`$`$@```&1\`0`%````=WP!``H```!]
M?`$`%````(A\`0`=````G7P!``\```"[?`$`!@```,M\`0`)````TGP!``\`
M``#<?`$`4@```.Q\`0`;````/WT!``<```!;?0$`!P```&-]`0`.````:WT!
M`!$```!Z?0$`#@```(Q]`0`D````FWT!`!@```#`?0$`$0```-E]`0`G````
MZWT!`!\````3?@$`#0```#-^`0!E````07X!`!L```"G?@$`'````,-^`0`M
M````X'X!`!L````.?P$`'@```"I_`0`=````27\!`!P```!G?P$`%@```(1_
M`0`8````FW\!``H```"T?P$`!P```+]_`0`(````QW\!``D```#0?P$`$P``
M`-I_`0`1````[G\!`!,`````@`$`!P```!2``0!!````'(`!`$,```!>@`$`
M,P```**``0!9````UH`!`"P````P@0$`*````%V!`0`'````AH$!``L```".
M@0$`#P```)J!`0`E````JH$!``<```#0@0$`2````-B!`0`L````(8(!`"8`
M``!.@@$`%P```'6"`0`A````C8(!`!D```"O@@$`+@```,F"`0`G````^((!
M`"\````@@P$`)@```%"#`0`@````=X,!``4```"8@P$`#````)Z#`0`+````
MJX,!``4```"W@P$`*````+V#`0`,````YH,!``<```#S@P$`!@```/N#`0`1
M`````H0!``@````4A`$`"````!V$`0`4````)H0!``@````[A`$`"0```$2$
M`0`$````3H0!``P```!3A`$`#````&"$`0`2````;80!`!<```"`A`$`%0``
M`)B$`0`0````KH0!``@```"_A`$`#P```,B$`0`0````V(0!``X```#IA`$`
M#````/B$`0`;````!84!`"4````AA0$`#0```$>%`0`?````584!`",```!U
MA0$`"@```)F%`0`&````I(4!`!$```"KA0$`!P```+V%`0`$````Q84!`!0`
M``#*A0$`#@```-^%`0`/````[H4!``\```#^A0$`!0````Z&`0`(````%(8!
M``@````=A@$`#0```":&`0`,````-(8!`!,```!!A@$`!@```%6&`0`3````
M7(8!``8```!PA@$`"0```'>&`0`/````@88!`!H```"1A@$`"@```*R&`0`"
M````MX8!``8```"ZA@$`!@```,&&`0`)````R(8!``<```#2A@$`,P```-J&
M`0`O````#H<!`!(````^AP$`!0```%&'`0`(````5X<!``P```!@AP$`#```
M`&V'`0`&````>H<!``P```"!AP$`$@```(Z'`0`.````H8<!``P```"PAP$`
M#0```+V'`0`)````RX<!``<```#5AP$`!P```-V'`0`'````Y8<!`!4```#M
MAP$`!0````.(`0`'````"8@!``4````1B`$`'P```!>(`0`:````-X@!``<`
M``!2B`$`!P```%J(`0`,````8H@!``8```!OB`$`$````':(`0`0````AX@!
M``8```"8B`$`&0```)^(`0`+````N8@!``D```#%B`$`!0```,^(`0`(````
MU8@!`!,```#>B`$`%P```/*(`0`+````"HD!``T````6B0$`$P```"2)`0`(
M````.(D!``P```!!B0$`$@```$Z)`0`,````88D!``(```!NB0$`$````'&)
M`0`&````@HD!`!D```")B0$`&````*.)`0`G````O(D!`"H```#DB0$`)```
M``^*`0!>````-(H!`!(```"3B@$`50```*:*`0`H````_(H!`$X````EBP$`
M8@```'2+`0`?````UXL!`#4```#WBP$`+@```"V,`0`N````7(P!`"8```"+
MC`$`'0```+*,`0`L````T(P!`,D!``#]C`$`(@```,>.`0`/````ZHX!`$4`
M``#ZC@$`>P```$"/`0`Y````O(\!`#$```#VCP$`4@```"B0`0!(````>Y`!
M`!D```#$D`$`$````-Z0`0`>````[Y`!`!X````.D0$`*@```"V1`0`=````
M6)$!`"````!VD0$`%0```)>1`0!`````K9$!`"D```#ND0$`'0```!B2`0`=
M````-I(!`#X```!4D@$`40```).2`0!&````Y9(!`&X````LDP$`3P```)N3
M`0`X````ZY,!`#(````DE`$`-````%>4`0!:````C)0!`&$```#GE`$`2P``
M`$F5`0!*````E94!`#4```#@E0$`*````!:6`0`H````/Y8!`#<```!HE@$`
M:P```*"6`0!I````#)<!`+(```!VEP$`%````"F8`0`E````/I@!`#$```!D
MF`$`+@```):8`0!$````Q9@!`"H````*F0$`2````#69`0`=````?ID!``D`
M``"<F0$`F````*:9`0!$````/YH!`!X```"$F@$`-P```*.:`0`?````VYH!
M`!X```#[F@$`+````!J;`0`&````1YL!``D```!.FP$``P```%B;`0`-````
M7)L!`!(```!JFP$`"P```'V;`0`+````B9L!``8```"5FP$`$@```)R;`0`"
M````KYL!`&@```"RFP$`!0```!N<`0`9````(9P!``0````[G`$`!P```$"<
M`0`%````2)P!``4```!.G`$`!@```%2<`0`4````6YP!``<```!PG`$`$@``
M`'B<`0`0````BYP!``(```"<G`$`"````)^<`0`'````J)P!`!,```"PG`$`
M#````,2<`0`5````T9P!``8```#GG`$`$````.Z<`0`-````_YP!``,````-
MG0$`'@```!&=`0`$````,)T!``8````UG0$`"````#R=`0`<````19T!`$,`
M``!BG0$`,0```*:=`0`R````V)T!`!@````+G@$`(P```"2>`0`9````2)X!
M`"$```!BG@$`(0```(2>`0`<````IIX!`"````##G@$`)P```.2>`0`B````
M#)\!`"D````OGP$`)@```%F?`0`H````@)\!`!T```"IGP$`(0```,>?`0`F
M````Z9\!`"$````0H`$`)P```#*@`0`G````6J`!`"X```""H`$`(0```+&@
M`0`B````TZ`!`"0```#VH`$`*0```!NA`0`?````1:$!`"@```!EH0$`(```
M`(ZA`0`O````KZ$!`"````#?H0$`)`````"B`0`I````):(!`"H```!/H@$`
M)````'JB`0`B````GZ(!`"0```#"H@$`)0```.>B`0`[````#:,!`"L```!)
MHP$`"0```'6C`0`4````?Z,!`!D```"4HP$`*@```*ZC`0`A````V:,!``P`
M``#[HP$`#P````BD`0`8````&*0!`!,````QI`$`#P```$6D`0`K````5:0!
M``4```"!I`$`!@```(>D`0`C````CJ0!`"T```"RI`$`(@```."D`0`E````
M`Z4!``H````II0$`R````#2E`0`3````_:4!`!`````1I@$`"````"*F`0`+
M````*Z8!`!,````WI@$`(````$NF`0`2````;*8!`#````!_I@$`%````+"F
M`0`6````Q:8!``<```#<I@$`%````.2F`0`+````^:8!`#4````%IP$`(0``
M`#NG`0`:````7:<!`!0```!XIP$`&````(VG`0`\````IJ<!``\```#CIP$`
M$````/.G`0`1````!*@!`!4````6J`$`"@```"RH`0`4````-Z@!``8```!,
MJ`$`)P```%.H`0`*````>Z@!`"0```"&J`$`"0```*NH`0`3````M:@!``<`
M``#)J`$`#````-&H`0`)````WJ@!`#4```#HJ`$`!P```!ZI`0`-````)JD!
M`!(````TJ0$`#@```$>I`0`)````5JD!``L```!@J0$`!P```&RI`0`3````
M=*D!``H```"(J0$`'0```).I`0`.````L:D!`!<```#`J0$`%@```-BI`0`*
M````[ZD!``P```#ZJ0$`&P````>J`0`'````(ZH!`"P````KJ@$`$````%BJ
M`0`)````::H!``(```!SJ@$`$0```':J`0`;````B*H!``L```"DJ@$`!0``
M`+"J`0`-````MJH!``@```#$J@$`"@```,VJ`0`/````V*H!``X```#HJ@$`
M%````/>J`0`5````#*L!``X````BJP$`+````#&K`0`<````7JL!`"<```![
MJP$`"P```*.K`0!'````KZL!``8```#WJP$`$P```/ZK`0`V````$JP!``T`
M``!)K`$`#````%>L`0`'````9*P!``0```!LK`$`!0```'&L`0`6````=ZP!
M``8```".K`$`!P```)6L`0`'````G:P!``0```"EK`$`#P```*JL`0`0````
MNJP!``4```#+K`$`%P```-&L`0`@````Z:P!`"`````*K0$`)0```"NM`0`.
M````4:T!``(```!@K0$`!````&.M`0`0````:*T!``4```!YK0$`!0```'^M
M`0`"````A:T!``\```"(K0$`2````)BM`0`4````X:T!`"H```#VK0$`*0``
M`"&N`0!*````2ZX!`!````"6K@$`:P```*>N`0`A````$Z\!`#$````UKP$`
M&0```&>O`0`Y````@:\!`"T```"[KP$`,````.FO`0`W````&K`!`#@```!2
ML`$`-````(NP`0`X````P+`!`"D```#YL`$`(P```".Q`0`N````1[$!`!0`
M``!VL0$`#P```(NQ`0`,````F[$!`&T```"HL0$`"````!:R`0!Y````'[(!
M`&H```"9L@$`)0````2S`0`9````*K,!`!D```!$LP$`#P```%ZS`0`<````
M;K,!`"4```"+LP$`(````+&S`0!7````TK,!`!D````JM`$`"P```$2T`0`%
M````4+0!``<```!6M`$`"````%ZT`0`%````9[0!`!D```!MM`$`$P```(>T
M`0`<````F[0!`"<```"XM`$`$@```."T`0`/````\[0!``0````#M0$`"0``
M``BU`0`0````$K4!``@````CM0$`!@```"RU`0`3````,[4!``@```!'M0$`
M!P```%"U`0`5````6+4!``D```!NM0$`"````'BU`0`5````@;4!``L```"7
MM0$`%````*.U`0`+````N+4!``<```#$M0$`!P```,RU`0`%````U+4!``P`
M``#:M0$`!P```.>U`0`(````[[4!`!0```#XM0$``@````VV`0`(````$+8!
M``@````9M@$`"````"*V`0`U````*[8!``,```!AM@$`$````&6V`0`3````
M=K8!``D```"*M@$`"````)2V`0`&````G;8!``8```"DM@$`#@```*NV`0`4
M````NK8!``4```#/M@$`#@```-6V`0`B````Y+8!``<````'MP$`"@````^W
M`0`1````&K<!``4````LMP$``@```#*W`0`+````-;<!``$```!K`0``````
M`(D$``!,`@``L`,``(`#``"+`@``7@,```````"O`0``)00``#4%``#,!0``
MO`,``,\%````````G@,``","``#C`@```````/X$``!Y`0``)P````````"E
M`P``0@(```````!T`@``'@$``!$!``!D`@``OP```$H#`````````````#(!
M``#<`0```````/L%``#K````7@(``$8!````````4P4`````````````4`$`
M````````````]P,```````#2````Z@0``%H!``!,````A`4````````B!0``
M`0(``.H#```B!````````%(%````````K00```````!$!@``L00````````=
M`@``P@0``&\"``"\!0``^0(``/`$``#@`0````````````!*!@```````%,`
M``#:`P``=@8``"L%``!,`P``W@(``*4%``#Z`P````````````""`0``D@$`
M``````!8!````````+@```!]!````````.T$```L!```0P4```````":`P``
M``````````"F````'P(```0$``!!`P``]0````P$``!N!```]P````````#C
M````S``````````Y!```!0,``"<!```<!```F`4````````C!```3@4``*\%
M````````60```````````````````/(#``!8`P``#@8``/D!``"9!0``<P``
M``````#1!0``<P(``$$`````````A0$``.@$```4!```308``(H#````````
M``````````"H`P``C0$``*`"``"I!0```````*,#``"D`0``_P$``%0```#W
M!```!P`````````[`P``BP$``)P$``#,`0``=P```&<#````````<`,``-4!
M````````QP4``*X!``````````````````"Y`0```````.8#````````P```
M`+P$````````0@,``&D```````````````````"-`P``KP```"`$``!&`P``
M``````````"#!````````$\#``".````"P(``%H"``!B!0``-`$``"P&````
M````T`````````#(!`````````````!X!@``.@,```````"#`@```````&8#
M`````````0,``%8#``"Q`0``%08```````!]`P``%@$```P&````````+`(`
M````````````0P```'L&``#R`0``"P0``.@%````````100``$L$```V`0``
M7`$`````````````"`(``&$!``![`0``O@(``$D&``!5`0``UP,``)T$````
M````8`0``&````#7````W````%4&````````````````````````B`$``)``
M```=!@``&@``````````````^@4``!@%`````````````/H```#S`@``````
M``````!<`````````'D#````````:@0``#D%``"4`@``3P8```````##`@``
M^````+X!```F`P```@8``)T"``"=!0``^0```.<````8`P``904``/T%``!Y
M!@``?0$``(L$```L`P``M@`````````5`@``=@```/X"``#:!0``Q@4``-@`
M```0!```\P```*0$``!$!0``JP$```````#M!0``\@(```````"``0``'0,`
M`"<$```9`@``T`4``%($````!0``D`,``($$``#]````2@(``&T#```4!@``
M-@``````````````?`0```````#K`@``XP4``'\"```F`0``;@,``(H"``#V
M`P``Q0$```````!`!0```````($%````````E`4``!`%``#(`0``A`8``"8%
M``#%!0``[@$``'0```"<````808``%P%```\`P`````````````>!@``````
M`!4````2`0``!00``),$``#J`0``LP$``&<"``#3!0``2P8``)(%``!H`0``
M#`4`````````````T@$``````````````````-(%``!(````Z`$```````!?
M!0``EP(``'8!```@`@``Y@```"\%``!'!0``1P8``&`%``"%!```VP```/P#
M``!X!0``20```````````````````'(&```S````PP4``!<```!=`@``OP,`
M````````````'````%D#````````;0`````````D`````````"\#````````
MY@(``!4!``#\!```X@0``((%```E`@``E@0``,`"``!8!@``?@8``%0&``!2
M!@``V@```!0"``!M`0``/0(``%````!>`````````%,$```;`P``````````
M``!A!```I`4``#<````_!```^`0```````!*!````````$,#````````````
M`!0!```X!```*`(```````"K`P``D@(``$H`````````_0(``-<%````````
M6P0``-<"```K`0``W`,`````````````M00`````````````%P0``!H#```T
M`P```````'H```#0`@``5`(``"D"```-`P``.@$`````````````=P0``,P#
M```\`@``0@0``*$````&!@```````#,!````````H00``*$!``!W!0``2P,`
M`&8$``"&```````````````H`P``7P8```L%``!S`P``>`$```````"U!0``
M!@$```````!F`@``IP4``*(`````````SP```*@!``"S`@``F0(``,@%``"G
M!```&@8``-H"``"]!0``=0(``!P#``#.`P``B`0````````:`0``]0$``*T%
M``#+`0``5P4``"P````1!```0`0``*4```````````````\$````````````
M``````",!0``'P````H%``#[````\P,```````!K!0``^P$```0%``#1!```
M!`(``,H"````````\0(``)X$````````>``````````^!@``H@(``+D$``!S
M`0``V`,``#4$````````X`0``!X"``"]````=@(``.$"``#?````TP````,$
M``#+`@``\@0``"T!``!1````<@0``"D#````````$P$``.P#``"5!0``MP0`
M```````%````.0,``$(```!7!@```````$D%````````'00``#0$``!2`0``
M`````$P%```J`@```````%8"``!,!```&`$```````#I`0``S0(``%`$``":
M!```X00``+@"``!]!@``;00````"``"/!0``"`0``(D```"L!````````$$"
M```````````````````O`@````````P!``!X`P``"0$```0#``"*!0```P,`
M`(@#``!O!@``O@```$<"``"#!@``!@(```````![````;`(``'8$````````
M``0``$T```!B`@``R@$``,(!````````E`,```P```!I!@```````.8$````
M````'@,`````````````R`(``'$%``".!```^0,````````3````,00`````
M``"+!0``;@$``%(#`````````````-X$````````^00```````!$!```H`$`
M`&$"```J`P``]`(``*D$````````_@```'4```!^!0``6@8``$(!````````
M/`$``*($```!`0```````,X"``!N!@``8P````````#?`@``+P```&$%```X
M````-0,```````#V`0``I`(``&$````N!````````/<!``!:!0``90(``,D#
M````````X0```.\$``"M`0``"`,``#$&``#"````H`4``#4!``#F!0``````
M`$$&``#M````'P8```````#D````W00``!L&``"_!0``A@,```````!B!@``
M<0,```````"%!0``&@4``'L"``#T`P``L@0``+8#```V`@``X0$``!<!````
M`````````$4"``"-````U@0``%T````<`0``/0```$$$````````(P4``)X%
M``"F`@``EP```/(`````````Q`$``)D$````````!0(``&D"``#P`0``6@``
M`$`"``!8!0``@`0``*<!````````/P```)4!```M!@``*@8```````"#!0``
M``````X"``#X!0``5P````````!``0```````.0"``!N````,`(``/H"``"'
M`P````````````!E`0``\`,```H```#7`0```````(H!``"H!0``?04``",#
M``""!```@@(``*0#````````QP(``!L$``",`````````+L!```-!@``````
M`!0````^!0```````#`$``!/!```_`$``.D$`````````````*L`````````
MC`(``'$```#-````?@,```````!<!@``9`8``%T$```6!@``<@```"T#``!#
M`@```````#$%`````````````)`!````````]P4``%<$```<!0```````'D"
M``````````````````#L!0``R04``,L#````````+@,``/0$``!W!@``````
M``````"T`@``\0,````````D!```MP(``(0!``#5!0``*0$``,$#```W`P``
M```````````@`0``+@4```````"T````>`(``$,$``#G`0``L@$````````"
M`@```````````````````````',&`````````````)P!````````.P8`````
M```M!0```````!@"```(`0``T@0`````````````_`(``*P"````````=P$`
M````````````V0(```````!J!0``E00```L&``";````:`(``'L#````````
M`````!,&````````LP,``+\$``#=`0``=`4``)\%``"1`@``Q````+T#``!]
M````VP$``$,!````````2@4`````````````#P(``!$%`````````````&,$
M``"S!````````````````````````'L%``"Q!0``5P$```````#N!0``````
M`)@!```0!@``9P0``.,#````````*08``+(```"A`P``>@(```````".`0``
M%@```"$"``#E`0``T`0``.T"``!U`0``L@4``!<#``"N!0``U00``(8"``#+
M````N`$```($```(!@```````-$````C````7@8```D#``"R`@``K`4`````
M````````-08```````"3`P``,@0``'$&````````T`,``&4#```G`@``````
M`',%```X`0``V0$```H$``#_````]`4```,&``#*````<@(```(!``#I`P``
M``````````"``@``#0$```$%``"7!```@0(``#H&````````5`0``"``````
M````_P4``$$!``">`@``;P0```<#```S!@``5P(``.H"````````@````+``
M``!-!````````"4&``"%`````````+4"``#*!0``,0$``,T#````````*@$`
M`-,$````````3P4```````#"!0```````%0#``````````````````#O`P``
M`````*@```!5!0```````*``````````JP4``(4"``"I`@```````#`````B
M`0``TP$``%8$```&!0``#P$```````"$`````````&$#``#,!```"P,``&P`
M`````````````.$%``!1!0```````%H#```>!0``#04``&H&``#G`@``MP$`
M`#\%````````6P$``(8!```"!0``U@$```````#P`@``TP,``%\"``!<`P``
M,`,``*H$```%!@``IP,``%X%````````408``%D&``"Q````(04``/\"```-
M!```8`(``+D#``#V!0``?`8``"@$````````8@$``-,"``!L!```,P0``+T"
M```@!0``A0,``$T#``"`!0``)P4``#`!```[!0``%@4``$\!```*`P``W0``
M`%\#``#:!```*@0``+4```#&!```T@(``,`%``#6`P``.P0```````#B`P``
ML0,``&8&``!,!@``6P``````````````&`8``)@$``!G!@```````%("````
M````_P0``%$$``#]!````````.<#``!8`0```````/L$````````\P0`````
M``"/`0``=`0``-(#```[`@``X@````L``````````````&\```"T`0``_@,`
M`!8$````````P`,``*H!````````'0$``*@"```8!```8`,``%T!``#E````
M`````%X!``"C!0``1P,``%T%``!S!``````````````]!```50,``*8$````
M````70,``#\!````````V`0```````#.!```"`````4%``"N`@``O`(`````
M``!<`@``N@,``*D```"3``````````````"=`0``[0$`````````````U@``
M``0`````````Z`,```X$```,`@``W0(``(L#```W!0``X0,``,0$````````
M8@0``,0%````````C@(``)(````N````YP4``/\#```0`P``;P,``'H$````
M`````````"8```#J````40$``"8&``#9````"0(```\#```*!@``)@(``)L#
M``!8````+00``/4%``!?!```AP0``-@%`````````````.,$```J````W0,`
M``````"G`@``K@,``!4$```P!@``^P(``!X`````````[`(```````#1`P``
MY`4``#8#```R`P```````"4!``"H!```$@8``%L#``!G````B@0```X```"<
M`P``E`$```````"'!0```````"0&`````````````.0#``!F`0``5`4``'0!
M```?`P``K0,``$4#``!(!0``Q@(``'`&``#=!0``[@(``*,$````````5@4`
M`+X%```&`P`````````````S`@``GP(``)$!``#8`@``C@4``/,!``!3`0``
MF`,```$$```L!0``UP0``*L$``!(!```-0(``````````````````#0&``"E
M!```HP```!(#``"W!0``E`0``.0!````````O@,``&P&``"[`P```````-\$
M````````?P`````````)!@``&04``)`"```````````````````_!@``<`4`
M`"4#``#G!```60$```````"'`@``3@0``($#````````'@0``,8#``#'`0``
M`````!,#``!U!````````+`$```+`0`````````````D`P``4P8`````````
M````]@0`````````````<@$```````!0!0``Z0(`````````````4`8`````
M```J!0``W`(``````````````````%\!```X`P```````"8$````````````
M`-4#``!F!0```````'0#````!@``304```````"2!```8@,``(0$``"1!```
M,`4``/4$``#(`P````````````!H````.@0``"X"``"Z!0``0P8```````#Q
M````2`$``),!```X!0``SP0``!$#``!K````S@4``-0%``#"`@``(@(`````
M````````J0$``*8!``````````````\%``"&!0``L`4``.D```!_!```````
M```````H`0``@0$``&,"``!'!```%P4``+\!``")`P``^@$``#\"``"6`@``
MQ0```(<```"R`P``K````.("```9`P``CP0``'H%````````GP0``)T`````
M`````````.L$````````M`,``#@&````````,@8``%P$``!+````+@8``"L`
M``",`0``J@```)D```!\`@```````-L%```5`P``PP$``'D%```I!```/`8`
M`'0&````````7@0``-L$``#H````4`(``&4$``")!0``3P(`````````````
M200``,,#```K`P``&P(``)L!```W`@``"@$```D%``!M!@````$``&H"``!Y
M````;@4````````B!@``.08``,$%``"6`0``FP(``,,```!_!0``>@8```\&
M``"P`0``(0$``&<%``#?!0``[@```/0!```6`P``=08``#("``#!`@``<@4`
M``````"@!```<`(``#<$```^`0``-`4``(0"```<!@``#@$```````"Z`@``
M```````````\`````````,D$``!1`P``8P4``$4&````````@@8``$@&```]
M`P```````"<#``#!!`````````````#T````R@0``!0%``#@`````````"0!
M``",`P``"`4``.H%``#V````20,``(T%`````````````"L"````````V`$`
M`*(#```U`````````&P%```````````````````K!````````-L#````````
M_@$```````"#`0``7P```)4```!!!0``Y@$``&0```#H`@``:`,``+0%``"&
M!```>@,````````.!0``K0(``!L```"[`@``E@````T"``"S````,0```-8%
M``````````````````!M`@``^`(``)$%````````"0```/@!``!+`@``````
M`*$"```2````2`(`````````````1@4````````````````````````\!```
M:`8``/(%````````,@4``'\&```*`@``Q0,``&@$``"E`0``JP(```````!Q
M!```=P,``#\#``"Y!0````````````"[````RP0``,<````Z`````````#<!
M````````'P0```<$``#'!```Q`,`````````````M`0``"L&``!C`0``S0$`
M`)H!``#U`@``2@$`````````````@P,``,4$``!@`0``EP,````#````````
MW@```+X$````````+@$``$````````````````,"``!$`P``@@```.\!``"<
M!0````````````!`!@``PP0``$X#``#/`0``E@4``#8&``#,`@```````,0"
M````````)`4```T````Z!0``20$```````!8`@```08``)D!````````````
M`*\$``"?`P``6P4```\`````````Q0(``&`&````````B@```($```"]!```
MS@```&@%```$!@``V04``+H```#``0`````````````M`@``O0$```````"V
M`@```````$X``````````````#@"````````!`$````````?`0``20(``&D#
M````````1@8``)<!`````````````&\%``#-!0``]@(``-\!``#\````;`$`
M`)L$```V!0``W@4``-X#``!1`@```````.\`````````FP4``!$&``"O`@``
MH04``)$```!Z`0```````.4"````````:P0``/`%``#;`@```````&4````O
M`0````````````!$```````````````Y`@``=P(```````#)`0``KP,``+D"
M``"-`@``E0,```````!9!0``D`4``&D%``#@`P``AP$``$4`````````W`0`
M`(T$```3`@```````+@#``"(`@``P`0```````"W`P``B````&L"````````
M`````)@"```0````G@```&L&``"1`P```````#,%```3!0``B`4`````````
M``````````````!/``````````````!4`0``5@```%,#````````/@,``+@$
M`````````````)0````C!@``)0````D$```M````!P$``.\"``!P````:@,`
M`$L%```2!```3@(``!`!````````K@``````````````;@(```````#6`@``
MBP```+H$```]!@```````(\#``!$`@````````<"````````9`0``/$!``!J
M````!0$``!<"``""`P``I@,````````:!`````````8$``!9!```1`$``$T"
M``"G````500```````"M````]0,```````!(`P```````,$!``!X!```````
M`,8!```^````CP```!P"``!-`0``'04``-4```"U`P``U`,``.0$``#C`0``
ML0(``$<````D`@``,0(``'X````@`P``LP4``'(#``#-!```1P$``"\&``"$
M`P````````````"`!@````````````!;`@``.P$``'\!````````$@(``+4!
M````````HP$``-`!```2!0``DP(``#0"``#+!0```````!D&````````J@,`
M``````":!0``ZP$``,(#```,`P``E@,``/D%````````0`,``&0!````````
MX@4``+L%`````````````.D%``!&`@```````#L````W!@``F```````````
M````D@,``%(```"X!0```````+D`````````?````*`#``"J!0```````%8!
M``#]`P``K`,```````"D``````````````!V`P``[0,``(D!````````5@8`
M`#(````9!```(`8``+8!``!Q`0``#@,``/H$``!0`P``F@````````!]`@``
M`@```*(!`````````````.X#```=````*`8``!,$````````)P8``#T%```;
M`0``'P4``,\"``!,`0```````&8``````````````-0$``#:`0``908``!D!
M``#@!0`````````````Q`P``;`,``+8$``#^!0``&``````````\!0``K@0`
M`"@%`````````````-0````^`@``%`,```````"0!```50(```````#P````
MO`$``",!`````````````#0```!\!0``U`(``%D"``!&````@08``),%``!P
M`0```@,``'4#``",!```:@$``,<#``!.!@````````````"P`@``W`4``-D#
M``#1`@``OP(``&,#``!U!0``.0````````!.`0```````&,&```S`P``(0``
M`,H#``"?````T0$``,X!``"J`@``MP```&<!``"7!0``0@4``.4#``"/`@``
MG@$```````````````````````!;!@``K`$```````!"!@``?`$``)P"````
M````<`0```````#O!0``Y00``.P````I````I@4``'L$`````````````!`"
M```A!`````````````!\`P``\04``'$"`````````````.(!```Y`0``J0,`
M````````````\P4``%,"``!I!```C@,```````!B````+`$``.P$``!^!```
M9`4``&T%````````^`,``"D%``#E!0```````%<#``"5`@``:P,``/<"``#9
M!```/@0``)\!``!_`P``^P,``"\$``#!````R0(`````````````F@(``*4"
M``!:!````````&D!``!+`0``O`````````!Y!```%P8``+L$```]`0``1@0`
M`,8```!V!0``!@```!L%````````_`4``,D```"=`P````````````#Q!```
MB0(`````````````F0,```,!```'!@``&@(``#8$``#@`@``U0(`````````
M`````````-\#````````!P4``'X!````````R`````````#K!0``W@$``*(%
M``#K`P``$0(``$4!````````9`,```````"C`@``_0$``,\#``#L`0``(@``
M`"$#``!%!0``%@(``"@```"#````.@(``.X$````````$0```"$&``!=!@``
M``````,%``#4`0``(@,```````!^`@```````+8%````````;P$``+H!```#
M````%04`````````````50```!D````E!0```"`H)7,@9&%Y<R!A9V\I`"`H
M06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R
M;W<I`"`H>65S=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U
M;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L
M96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@9W5S
M=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T
M("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@
M9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@4VAO
M=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`
M06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`
M061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@
M2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@
M;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER
M`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@
M861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R
M`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O
M;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E
M<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG
M97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC
M871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U
M<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M
M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N
M9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I
M8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO
M;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3
M:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B
M80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G
M:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R
M86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U
M:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT
M:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD
M<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O
M=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S
M('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN90!"96QA<G5S`$)E;&=I
M=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K
M("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E
M='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D
M97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE
M9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A
M>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R
M=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@
M4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N
M`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E
M=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S
M(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@
M;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I
M;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN
M+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO
M;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR
M:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N
M9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R
M`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O
M;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`
M0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT
M86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@
M<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@
M4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@
M8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@
M9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S
M(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M.B`E<P!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N=&5D
M('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R
M96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R
M;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R
M96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E
M;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y
M<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q
M*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`
M1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`
M1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E
M8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L="!#;VQO<@!$
M969A=6QT($ED96YT:71Y`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@1W)O
M=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E
M<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@
M:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE
M(&-U<G)E;G0@<F]W`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T
M:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T
M('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O
M=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`
M16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI
M<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%
M9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G
M92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`
M16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC
M:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<75A=&]R:6%L($=U:6YE
M80!%<FET<F5A`$5R<F]R`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17-T
M;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU
M=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`
M17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R
M`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E
M87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&
M5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O
M;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E
M<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES
M;&%N9',`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E
M=R!3:&]W97)S`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT
M.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T
M:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&
M:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R
M871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`
M1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O
M<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@
M=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A
M;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN
M(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O
M<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US
M`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET
M86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T
M:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T
M:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I
M9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA
M`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@4V5A<F-H
M`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N
M9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M
M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E
M<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S
M86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@
M;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L
M(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M
M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H
M8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(
M=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W
M($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS
M('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@
M17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T
M=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@
M4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL
M97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!)
M;7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I
M96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E
M(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!)
M;F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED
M=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#
M7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T
M(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@
M8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@
M8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U
M<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A
M;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@
M;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B
M969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R
M90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E
M<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R
M;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S
M96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O
M36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H
M92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT
M96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`
M26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N
M`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A
M;&ED('!R;W1O8V]L+@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O
M=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y
M`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@
M;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC
M`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P
M,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF
M>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I
M9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@
M<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE
M<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y
M(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I
M8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R
M96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A
M9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF
M`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA
M<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA
M`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N
M`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$
M<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN
M($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK
M`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H
M92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O
M;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A
M8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI
M=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES
M="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO
M8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO
M9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U
M<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`
M3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@
M;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E
M<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`
M36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD
M:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S
M;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1
M=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N
M<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@
M9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I
M="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE
M;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`
M365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T
M87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE>&EC;P!-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y
M<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K
M86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@
M:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H
M:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R
M97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$
M+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF
M>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N
M9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@
M4&AA<V5S`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S
M=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E
M(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@
M9')O<"!D;W=N(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT
M`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@
M3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD
M<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),
M`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),
M`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.
M979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@
M57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W("A?
M8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.:6-A
M<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N
M`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I
M;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N
M`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@
M;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N
M<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG
M('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO
M('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/
M+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T
M($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@
M<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G
M;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`
M3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`
M3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS
M92!F:6QT97(`3V9F:6-E`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O
M<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O
M<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W
M('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A
M(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@
M82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS
M(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO
M;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP
M;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN
M9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0
M($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`
M4$T@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`4&%K
M:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!0
M86YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y
M`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S
M="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD
M:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S
M`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K
M('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E
M<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0
M;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@
M=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@
M=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T
M:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E
M<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`
M4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R
M979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I
M;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE
M;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y
M`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R
M`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO
M;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A;F1O
M;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L
M(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M
M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!2
M96UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E
M('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V
M92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297-E=`!297-E="!087-S
M=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P
M=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG
M:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T
M871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I
M97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD
M80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]1
M3"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES
M`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I
M`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L
M;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@
M3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-C:65N8V4`4V5A<F-H`%-E87)C
M:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A
M(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R
M=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP
M;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R
M<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N
M(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L
M96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA
M=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3
M96YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``
M4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB
M;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3
M:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C
M=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W
M97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:')I;FL`4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I
M97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I
M=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`
M4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3
M:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`
M4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R
M:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA
M(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI
M<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T
M=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN
M9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W
M`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE
M87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T
M<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@
M9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5C
M=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C
M8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S
M9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T
M`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E
M=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA
M;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W
M:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N
M($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!486)L
M90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU
M;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A
M='5R93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY
M`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N
M9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E
M9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N
M<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES
M<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@
M8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T
M:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I
M9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@
M<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B
M965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@
M;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP
M=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI
M;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA
M;F0@<VED92!O;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D
M+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE
M9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S:61E
M<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@
M9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C
M:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T
M:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H
M)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D
M971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O
M9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A
M9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI
M<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I
M<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM
M92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET
M;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I
M`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L
M<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R
M:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP
M92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R
M('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K
M<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A
M8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N
M`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA
M;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T
M960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!G
M<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I
M;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R
M<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`
M57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`57-E<FYA;64Z`%5S
M97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T
M97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N
M=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M
M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E
M<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L
M('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M
M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)
M<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE
M($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`
M5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`
M5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O
M;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S
M=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H
M87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3
M('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME
M<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`
M5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@<W!E960@:6X@:VYO
M=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7;W)K
M(%!H;VYE`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X
M=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`
M665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE
M+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`
M66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE
M.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R
M(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U
M<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM
M8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R
M=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S
M(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`
M7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R
M;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`
M7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``
M7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE
M;F1A<@!C86QM`&-L:6-K(&AE<F4`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S
M("@E<RD@870@)7,@)7,`:#H`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T
M(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C
M96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@
M=FEA($A45%``<W1E861Y`'1A<VL@;&ES=`!T>7!E('1H92!P87-S=V]R9"!T
M=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V
M0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($A/4D1%
M(#,N,"XR"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP,BTR,2`Q-3HR-2LP,3`P"DQA<W0M
M5')A;G-L871O<CH@36%T:6,@1&]L87(@/'-M97-N:4!M961I=6TN<VD^"DQA
M;F=U86=E+51E86TZ(%-L;W9E;KGH:6YA"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@9&YI(&YA>F%J
M*0`@*$)L:;YN:FEC82`E<RD`("AV("5S(&1N96@I`"`H9&%N97,I`"`H:G5T
M<FDI`"`H=NAE<F%J*0`@<')I(``E9"`E<R!I;B`E<P`E9"UD;F5V;F$@;F%P
M;W9E9``E<R`M($]B=F5S=&EL;P`E<R!0<G-T;FD@;V1T:7,`)7,@2T(`)7,@
M5GID<KYE=F%N:F4@+2!0;W1R9&ET978`)7,@4')I:F%V80`E<R!0;V=O:FD@
M=7!O<F%B90`E<R"^92!O8G-T86IA+@`E<R!P<FD@)7,@)7,`)7,@:F4@>F%H
M=&5V86X`)7,@;6EN=70`)7,@;FD@;6]G;^AE(&YA:G1I+@`E<R!K("5S(&]D
M("5S`"5S+6]V($%D<F5S87(`)7,M;W8@2V]L961A<@`E<RUO=F$@0F5L9;YN
M:6-A`"5S+6]V(%-E>FYA;2!O<')A=FEL`"5S.B`E<P`L('!I:&%J;^@@)7,@
M)7,`+"!S<')E;65N;&II=F\@;V0@)7,@9&\@)7,`+2T@:7IB97)I("TM`#$R
M(%5R;F$@;V)L:6MA`#(T(%5R;F$@;V)L:6MA`#(T('5R`%IA('1A(&)L;VL@
M:F4@>F%H=&5V86YA('5P;W)A8F$@8F%Z92!P;V1A=&MO=BX`4')IN6QO(&IE
M(&1O('5S;V1N92!N87!A:V4`6F$@N6EF<FER86YJ92!S<&]R;^AI;&$@:F4@
M<&]T<F5B96X@:F%V;FD@4$=0(&ML:G7H+@!:82!O=F5R:71E=B!P;V1P:7-A
M;F5G82!S<&]R;^AI;&$@:F4@>F%H=&5V86X@:F%V;FD@4$=0(&ML:G7H+@!:
M82!D9;EI9G)I<F%N:F4@<W!O<F_H:6QA('-O('!O=')E8FYI(&IA=FYI(%!'
M4"!K;&IUZ"P@>F%S96)N:2!01U`@:VQJ=>@@:6X@9V5S;&\N`%IA('!O9'!I
M<R!S<&]R;^AI;&$@<V\@<&]T<F5B;FD@:F%V;FD@4$=0(&ML:G7H+"!Z87-E
M8FYI(%!'4"!K;&IUZ"!I;B!G97-L;RX`6F$@9&6Y:69R:7)A;FIE('-P;W)O
MZ&EL82!S;R!P;W1R96)N:2!J879N:2!3+TU)344@:VQJ=>@L('IA<V5B;FD@
M4R]-24U%(&ML:G7H(&EN(&=E<VQO+@!:82!P;V1P:7,@<W!O<F_H:6QA('-O
M('!O=')E8FYI(&IA=FYI(%,O34E-12!K;&IUZ"P@>F%S96)N:2!3+TU)344@
M:VQJ=>@@:6X@9V5S;&\N`%IA(+EI9G)I<F%N:F4@<W!O<F_H:6QA(&IE('!O
M=')E8F5N(&IA=FYI(%,O34E-12!K;&IUZ"X`04T@4&QO:&4`04TO4$T`05!)
M($E$`$\@=&5M('5R96IE=F%L;FEK=0!/+BXN`$%B<V)O='1O;0!!8G-M:61D
M;&4`1&]S=&]P('!R:2!I>F1E;&]V86YJ=2!61E,@;6%P92!Z879R;FIE;BX`
M1&]S=&]P('!R:2!I>F1E;&]V86YJ=2!61E,@9&%T;W1E:V4@>F%V<FYJ96XN
M`$=E<VQO(')AZ'5N80!28>AU;B!Z86UR>FYJ96XN`%)AZ'5N;W9O9'-T=F\`
M1&]D86H`1&]D86H@<&]D<VMU<&EN;P!$;V1A:B!P<F%V:6-E('!O9'-K=7!I
M;F4`1&]D86H@='5K86HZ`$1O9&%J(&YO=F\@<VMU<&EN;P!$;V1A:B!N;W9O
M(&1O=F]L:F5N:F4`1&]D86H@;F]V96=A('5P;W)A8FYI:V$Z`$1O9&%J('-T
M;VQP96,`1&]D86H@;F]V92#H;&%N90!$;V1A:B!P87(`1&]D86H@)7,@;65N
M=2!K;W0@36]Z:6QL82!3:61E8F%R`$1O9&%J('8@861R97-A<CH`1&]D86H@
M=B!M;VH@861R97-A<@!$;V1A:B!U<&]R86)N:6MA`$1O9&%J86YJ92!U<&]R
M86)N:6MO=B!J92!O;F5M;V=OZ&5N;RX`3F%S;&]V:0!!9')E<V%R`$%D;6EN
M:7-T<F%C:6IA("T@;F%S=&%V:2!P<F%V:6-E(&]S=&%L:6@@=7!O<F%B;FEK
M;W8`061M:6YI<W1R86-I:F$`4F5K;&%M90!!9F=A;FES=&%N`$%L8F%N:6IA
M`$%LOFER:6IA`%!S979D;VYI;0!0;W)A=FYA:@!0;W)A=FYA=F$Z`%9S:0!6
M<VD@3W9E<FIE;FD@=7!O<F%B;FEK:0!6<V4@4VMU<&EN90!6<V$@1&]V;VQJ
M96YJ80!6<V4@N71I<FD@<W1R86YI`$1O=F]L:2!V9>@@;F%S;&]V;W8`1&]V
M;VQI(&YA<W1A=FET978@=7)E:F5N96=A('1I<&$@<V5Z;F%M83\`KF4@;V)S
M=&%J80!!;'1E<FYA=&EV;F$@24U34"!P<FEJ879A`$%L=&5R;F%T:79N;R!)
M35-0(&=E<VQO`$%L=&5R;F%T:79N;R!)35-0('5P;W)A8FYIN6MO(&EM90!!
M;'1E<FYA=&EV96X@92UP;[ET;FD@;F%S;&]V`$%L=&5R;F%T:79N92!P<F5D
M;&]G90!!;'1E<FYA=&EV;F\@8F5S961I;&\Z`$%M97)IN6MA(%-A;6]A`%9N
M9;EE;F$@:F4@8FEL82!N87!AZ&YA('9R961N;W-T+@!!;F1O<F$`06YG;VQA
M`$%N9W5I;&$`06YO;FEM96X@<')O>'D`3V1G;W9O<@!!;FMT87)T:6MA`$%N
M=&EG=F$@:6X@0F%R8G5D80!!<&QI:V%C:6IA`%-E>FYA;2!A<&QI:V%C:6H`
M07!L:6MA8VEJ82!J92!P<FEP<F%V;&IE;F$N`%5P;W)A8FD@>F$@<&]D<F5J
M96YE(&]B:F5K=&4@=B!S:W5P;FD@<F%B:0!/9&]B<FD`07!R:6P`07)A8G-K
M;R`H5VEN9&]W<RTQ,C4V*0!696QI:V]S="!A<FAI=G-K92!D871O=&5K90!)
M;64@87)H:79A`$%L:2!S=&4@<')E<')IZ&%N:2!D82"^96QI=&4@;V1S=')A
M;FET:2!P<FEJ879N;R!Z86AT979O('IA("5S(#\`07)G96YT:6YA`$%R;65N
M:6IA`$%R;65N:6IS:V\@*$%235-#24DM."D`56UE=&YO<W0`07)U8F$`3W1O
M:R!!<V-E;G-I;VX`07-C:6D@<VQI:V4`07II:G-K82]086-I9FFY:V$@<F5G
M:6IA`%9P<F&Y86T@>F$@<&]T<F1I=&5V('!R960@:7IV961B;R!O<&5R86-I
M:B!V>F1ROF5V86YJ83\`4W1O;'!C:2!Z82!D;VQOZ&ET978`4&]S:W5S(&)R
M:7-A;FIA(&YE;V)S=&]J9>AE('-K=7!I;F4N`%!O<VMU<R!B<FES86YJ82!N
M96]B<W1O:F7H96=A(&1O=F]L:F5N:F$N`%!O<VMU<R!U<F5J86YJ82!N96]B
M<W1O:F7H96=A(&1O=F]L:F5N:F$N`%!O<VMU<R!U<F5J86YJ82!N96]B<W1O
M:F7H92!S:W5P;F4@<F%B92X`071R:6)U=&D`079G=7-T`$%V<W1R86QI:F$`
M079S=')I:F$`075T:%]C>7)S<6PZ(%!O=')E8FYE9V$@24U!4"!D;V1A=&MA
M(&YI(&UO9V_H92!N86IT:2X`075T:%]C>7)U<SH@2')B=&5N:6-A('!R;V=R
M86UA(&YI;6$@<&]T<F5B;FEH('IM;[YN;W-T:2X`075T:%]C>7)U<SH@4&]T
M<F5B;F5G82!)34%0(&1O9&%T:V$@;FD@;6]G;^AE(&YA:G1I+@!!=71H7V9T
M<#H@4&]T<F5B;F5G82!&5%`@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN($-O
M;7!I;&%J=&4@4$A0('H@;6^^;F]S=&IO("TM96YA8FQE+69T<"X`075T:%]I
M;6%P.B!0;W1R96)N96=A($E-05`@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN
M`$%U=&A?:W)B-3H@4&]T<F5B;F5G82!K<F(U(&1O9&%T:V$@;FD@;6]G;^AE
M(&YA:G1I+@!!=71H7VQD87`Z(%!O=')E8FYE9V$@3$1!4"!D;V1A=&MA(&YI
M(&UO9V_H92!N86IT:2X`075T:%]L9&%P.B!5<&]R86)N:6MA("5S(&YI(&UO
M9V_H92!D;V1A=&DN(%-T<F6^;FEK(&IE(&IA=FEL.@!!=71H7VQD87`Z(%5P
M;W)A8FYI:V$@)7,@;FD@;6]G;^AE(&]D<W1R86YI=&D`075T:%]L9&%P.B!5
M<&]R86)N:6MA("5S(&YI(&UO9V_H92!P;W-O9&]B:71I`$%U=&A?;6-A;#H@
M4&]T<F5B;F5G82!-0T%,(&1O9&%T:V$@;FD@;6]G;^AE(&YA:G1I+@!!=71H
M7W-M8F%U=&@Z(%!O=')E8FYE9V$@<VUB875T:"!D;V1A=&MA(&YI(&UO9V_H
M92!N86IT:2X`3W9E<FIA;FIE(&YI('5S<&5L;P!/=F5R:F%N:F4@;FD@=7-P
M96QO+B`E<P!/=F5R:F%N:F4@>F%V<FYJ96YO(&YA(%)!1$E54R!S=')EOFYI
M:W4N`$]V97)J86YJ92!N82!&5%`@<W1R9;YN:6MU(&YI('5S<&5L;RX`4&]L
M:F$@:VD@<V\@;F$@=F]L:F\Z`$%Z97)B86IDOF%N`$)/1D@@27IG;W9O<FD`
M3WIA9&IE`$)A<G9A(&]Z861J80!.97!R879I;&YO(&ME<F)E<F]S(&=E<VQO
M+@!.97!R879I;&YO(&ME<F)E<F]S('5P;W)A8FYIN6MO(&EM92X`0F%H86UI
M`$)A:')A:FX`0F%L=&FY:V\@*$E33RTX.#4Y+3$S*0!"86YG;&%D9;D`0F%R
M8F%D;W,`3W-N;W9A`$)E;&]R=7-I:F$`0F5L9VEJ80!"96QI>F4`0F5N:6X`
M0F5R;75D80!"=71A;@!2;VIS=&YI(&1A;@!";&]K82`B)7,B(&%P;&EK86-I
M:F4@(B5S(B!N:2!M;V=OZ&4@;F%J=&DN`$YA<W1A=FET=F4@8FQO:V$`5G)S
M=&$@8FQO:V$`2W)E<&MO`$)O;&EV:6IA`%!R:6QJ=6)L:F5N90!2;V(`1&5B
M96QI;F$@<F]B=3H`4F]B;W9I`$)O<VYA(&EN($AE<F-E9V]V:6YA`$]B;VIE
M`$)O8W9A;F$`4W!O9&%J`$]T;VL@0F]U=F5T`$)R87II;&EJ80!"<FET86YS
M:V\@;WIE;6QJ92!);F1I:G-K96=A(&]C96%N80!"<G5N96H@1&%R=7-S86QA
M;0!"=6QG87)I:F$`3WIN8>AE;FD@<V5Z;F%M`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`5&_H:V4@9&ES=')I8G5C:6IE($-23`!,87-T;F]S=&D@
M8U]E;&EC92XN+@!+;VQE9&%R`$UI<FYO`$MA;6)O9+YA`$MA;65R=6X`1V5S
M;&$@;FD@;6]G;^AE('!O;F%S=&%V:71I(&%V=&]M871IZ&YO+"!K;VYT86MT
M:7)A:G1E('-V;VIE9V$@861M:6YI<W1R871O<FIA+@!0;W9E>F%V92!Z($E-
M05`@<W1R9;YN:6MO;2!N:2!M;V=OZ&4@=GIP;W-T879I=&DZ("5S`$MA;F%D
M80!0<F5K;&GH:0!0<F5K;&GH:2!P<FEJ879O(&YA<&%K90!$871O=&5K92`B
M)7,B(&YI(&UO9V_H92!I>F)R:7-A=&DN`%IAZ&%S;F4@;6%P92!N:2!M;V=O
MZ&4@;F%J=&DN`$)R97H@)W1A<F=E=$9I;&4G('!A<F%M971R82!N:2!M;V=O
MZ&4@;F%D86QJ979A=&DN`$UA<&4@(B5S(B!N:2!M;V=OZ&4@;V1S=')A;FET
M:2X`3V)J96MT82!N:2!M;V=OZ&4@;V1S=')A;FET:2P@;V)S=&%J82`E9"!P
M;V1O8FIE:W1O=BX`4&]N;W9N82!R87IV<G-T:71E=B!N:2!M;V=OZ&$L(+ET
M979I;&\@<&]D86YI:"!V<&ES;W8@;F4@=7-T<F5Z82!S:')A;FIE;F5M=2"Y
M=&5V:6QU('9P:7-O=B!Z82!P;VYO=FYO(')A>G9R<W1I=&5V+@!3<&]R;^AI
M;&$@;FD@;6]G;^AE('5S;65R:71I(&YA('!O9&%N;R"Y=&5V:6QO+@!#87!E
M(%9E<F1E`$YA<VQO=@!+871E9V]R:6IE(&EN(&]Z;F%K90!+86IM86YS:VD@
M;W1O:VD`36]B:6QN:2!T96QE9F]N`$QA<W1N;W-T:2!C96QI8V4`4')A>F5N
M('!R;W-T;W(@=B!C96QI8VDZ`$QA<W1N;W-T:2!C96QI8V4`4')A>F5N('!R
M;W-T;W(@;65D(&-E;&EC86UI.@!-;V)I;&YI('1E;&5F;VX`2V5L='-K;R`H
M25-/+3@X-3DM,30I`%-R961I;F$`4W)E9&YJ96%F<FFY:V$@4F5P=6)L:6MA
M`%-R961N:F5E=G)O<'-K;R`H25-/+3@X-3DM,BD`4&]D<F]B;F]S=&D@<&]T
M<F1I;&$`4&]L:71I:V$@<&]T<F1I;&$`R&%D`%-P<F5M96YI`$YA<W1A=FD@
M:6UE(&EN(&YA<VQO=BP@:VD@9V$@;W-E8F4@=FED:6IO+"!K;R!B97)E:F\@
M:6X@;V1G;W9A<FIA:F\@;F$@=F&Y;R!E+7!ON71O+@!:;F%K`%!R979?97)I
M('!O=F5Z879O+BXN`,AI;&4`2VET86IS:V$`4&]E;F]S=&%V;&IE;F\@2VET
M86IS:V\@*$=",C,Q,BD`5')A9&EC:6]N86QN;R!+:71A:G-K;R`H0FEG-2D`
M27IB97)I=&4@9V5S;&\`27IB97)I=&4@=7!O<F%B;FFY:V\@:6UE`$EZ8F5R
M:71E(&YAZ&EN('!R:6MA>F$@9&%T=6UO=CH`27IB97)I=&4@:7IG;&5D('-E
M>FYA;6$@*'IA('5R96IE;F4@<V5Z;F%M92D`5F5L:6MO;F_H;FD@;W1O:P!$
M969I;FEC:6IE(')A>G)E9&$@)7,@;FD@;6]G;^AE(&YA:G1I+@!*87-N;P!0
M;^AI<W1I($U33V9F:6-E(&]Z;F'H8F4`4&_H:7-T:2!U<&]R86)N:6MA.B`E
M<P!0;^AI<W1I('5P;W)A8FYI:V$`4&_H:7-T:2!P;V1A=&ME(&\@=7!O<F%B
M;FEK=0!+;&EK;FD@>F$@;F%D86QJ979A;FIE`$-L:6-K871E;&P@<')E:V\@
M2%144`!:87!R:2!O:VYO`$]B;&%K:0!/8FQAZ&YO`$ME96QI;F=O=FD@;W1O
M:VD`4VMR:6H@<W1R86YS:VD@;65N=0!3:W)I:B!R;V)O=F4`2V]L=6UB:6IA
M`$)A<G9A`$)A<G9N82!T86)E;&$`27IB:7)A(&)A<G9E`%-T;VQP8VDZ`$YA
M<VQO=FD@<W1O;'!C978`4W1R:7!I`%5K87H`56MA>FYA(&QU<&EN80!+;VUE
M;G1A<@!);64`2V]M;W)I`%!O9&IE=&IE`%)AZ'5N86QN:6MI`%!O9V]J:0!2
M87IL:6ME('8@;F%S=&%V:71V86@`3F%S=&%V:2`E<P!0;W1R9&D@9V5S;&\`
M2V]N9V\`1&5M;VMR871S:V$@4F5P=6)L:6MA($MO;F=O`%!O=F5Z879A(&YI
M('5S<&5L82X`4&]V97IA=F$@;FD@=7-P96QA.@!0;W9E>F%V82!N82!J879N
M:2!S=')EOFYI:R!S(&ML:G7H:2!Z879R;FIE;F$N`%!O=F5Z879A(&YA(&IA
M=FYI('-T<F6^;FEK(',@:VQJ=>AI('IA=G)N:F5N82X@4F%Z;&]G.B`E<R`H
M)7,I`%!O=F5Z879A(&YA($944"!S=')EOFYI:R!N:2!U<W!E;&$N`%-T:6MI
M('-O(&)I;&D@=7-P9;EN;R!D;V1A;FD@=B!A9')E<V%R+@!.87!R96H`0V]O
M:V]V:2!O=&]K:0!0:;EK;W1E:P!+;W!I<F%J`$MO<&ER86H@:7IB<F%N;P!+
M;W-T87)I:V$`4VQO;F]K;[GH96YA(&]B86QA`%!'4"!S<&]R;^AI;&$@;FD@
M8FEL;R!M;V=OZ&4@N6EF<FER871I+@!01U`@<W!O<F_H:6QA(&YI(&)I;&\@
M;6]G;^AE('!O9'!I<V%T:2X`4W!O<F_H:6QA(&YI(&)I;&\@;6]G;^AE(+EI
M9G)I<F%T:2!S(%,O34E-12X`4W!O<F_H:6QA(&YI(&)I;&\@;6]G;^AE('!O
M9'!I<V%T:2!S(%,O34E-12X`4W1I:V$@;FD@8FEL;R!M;V=OZ&4@9&]D871I
M+B`E<P!0;W9E>F%V82!N82!,1$%0('-T<F6^;FEK(&YI(&)I;&$@;6]G;^AA
M+@!3=&%N:F$@;FD@8FEL;R!M;V=OZ&4@<')E=F5R:71I+B`E<P!397IN86UA
M(')A>F1E;&ET=F4@;FD@8FEL;R!M;V=OZ&4@:7ID96QA=&DN("5S`%!'4"!P
M;V1A=&MO=B!N:2!B:6QO(&UO9V_H92!D9;EI9G)I<F%T:2X`4R]-24U%('!O
M9&%T:V]V(&YI(&)I;&\@;6]G;^AE(&1EN6EF<FER871I+@!3=&EK82!N:2!B
M:6QO(&UO9V_H92!P;V)R:7-A=&DN("5S`%-E>FYA;6$@<F%Z9&5L:71V92!N
M:2!B:6QO(&UO9V_H92!P;V)R:7-A=&DN("5S`%!R96IE;6YI:V]V96=A(&4M
M<&^Y=&YE9V$@;F%S;&]V82!N:2!B:6QO(&UO9V_H92!U9V]T;W9I=&DN`$-E
M;&]T;F5G82!A9')E<V%R:F$@;FD@;6]G;^AE('!R96)R871I+@!#96QO=&YE
M9V$@<V5Z;F%M82!R87ID96QI='9E(&YI(&UO9V_H92!P<F5B<F%T:2X`0V5L
M;W1N96=A('-E>FYA;6$@<V5Z;F%M;W8@<F%Z9&5L:71V92!N:2!M;V=OZ&4@
M<')E8G)A=&DN`%,@<W1R9;YN:6MA(',@:VQJ=>AI(&YI(&)I;&\@;6]G;^AE
M(&1O8FET:2!J879N96=A(&ML:G7H82X`)7,@;FD@;6]G;^AE(&]D<')E=&DN
M`$UO9'5L82!-86EN=&5N86YC95]487-K(&YI(&UO9V_H92!O9'!R971I("5S
M`"5S(&YI(&UO9V_H92!P<F5B<F%T:2X`6F$@>F%H=&5V86YE9V$@=7!O<F%B
M;FEK82!N:2!B:6QO(&UO9V_H92!P;VYA<W1A=FET:2!G97-L82X@3F5K871E
M<FD@86QI('9S:2!P;V1A=&MI(&YI<V\@<')A=FEL;FDN(%!O<VMU<VET92!P
M;VYO=FYO+"!A;&D@<&$@<V4@;V)R;FET92!N82!S=F]J96=A('-K<F)N:6MA
M(.AE('!O=')E8G5J971E(&YA9&%L:FYO('!O;6_H+@!!0TP@;FD@8FEL;R!M
M;V=OZ&4@<')E8G)A=&D`061R97-A<FIA(&YI(&UO9V_H92!P<F5B<F%T:2X@
M)7,`4V5Z;F%M82!R87ID96QI='9E(&YI(&UO9V_H92!P<F5B<F%T:2X@)7,`
M4V5Z;F%M;W8@<F%Z9&5L:71V92!N:2!M;V=OZ&4@<')E8G)A=&DN("5S`%IM
M;[YN;W-T:2!S=')EOFYI:V$@;FD@8FEL;R!M;V=OZ&4@=6=O=&]V:71I`$YA
M<W1A=FET978@;FD@8FEL;R!M;V=OZ&4@=G)N:71I(&YA('!R=F]T;F\@<W1A
M;FIE`$YA<W1A=FET978@)7,@;FD@8FEL;R!M;V=OZ&4@<VAR86YI=&DN`%9A
M<FYO<W1N92!K;W!I:F4@;F%S=&%V:71E=B!N:2!B:6QO(&UO9V_H92!S:')A
M;FET:2X`5F%R;F]S=&YE(&MO<&EJ92!N87-T879I=&5V(&YI(&)I;&\@;6]G
M;^AE('-H<F%N:71I.B`E<P!)<VMA;FIE($Q$05`@<W1R9;YN:6MA(&YI('5S
M<&5L;RX`4W1I:V$@;FD@8FEL;R!M;V=OZ&4@<&]S;V1O8FET:2X@)7,`4V5Z
M;F%M82!R87ID96QI='9E(&YI(&)I;&\@;6]G;^AE('!O<V]D;V)I=&DN("5S
M`$UE;G5J82!-;WII;&QA(%-I9&5B87(@;FD@8FEL;R!M;V=OZ&4@;F%J=&DN
M(%!R97!R:>AA:G1E('-E+"!D82!J92!O9'!R="X`57!ON71E=F%N;R!B97-E
M9&EL;P!$<KYA=F$`5&7H86II`%5S='9A<FD`57-T=F%R:2!P;W9E>F%V;P!5
M<W1V87)I(&YO=F\`57-T=F%R:2!P;V1M87!O`%!R879I8V4@;&%S=&YI:V$`
MJ71E=FEL:V$@:W)E9&ET;F4@:V%R=&EC90!(<G9AN6MA`$MU8F$`5')E;G5T
M96X@Z&%S`%1R96YU=&5N(%523"!J90!4<F5N=71N;R!V<F5M90!4<F5N=71N
M;R!S=&%N:F4Z`%1R96YU=&5N('-T:6P`4')I;&%G;V1I(&]P<F%V:6QA+"!K
M:2!S92!Z8;YE;F5J;R!O8B!P<FEJ879I('8@)7,N`$EZ<F6^:0!)>G)EOFD@
M:7IB<F%N;P!#:7!E<@!#:7)I;&EC82`H2T])."U2*0!#:7)I;&EC82`H5VEN
M9&]W<RTQ,C4Q*0!#:7)I;&EC82]5:W)A:FEN82`H2T])."U5*0#(9;EK80!$
M1`!$;F5V;F\`0G)S:V%L;FEK($1A=&%4<F5E`$1A='5M`$1A='5M('!R96IE
M;6$`27IB:7)A(&1A='5M80!$86X`27IB<FFY:2!S=&]L<&5C`$1E8V5M8F5R
M`$1E8VEM86QK90!:;6%N:KEA:B!Z86UI:P!0<FEV>F5T82!B87)V80!0<FEV
M>F5T82!I9&5N=&ET971A`$1E9FEN:6-I:F4`27IB<FFY:0!)>F)R:;EI('-K
M=7!I;F\`27IB<FFY:2!P<F%V:6-O`$EZ8G)IN6D@:6X@<&_H:7-T:2!S<&]R
M;^AI;&$`27IB<FFY:2!C96QI8V\`27IB<FFY:2!S=&]L<&5C`$EZ8G)IN6D@
M;V)S=&]J9>AO(&%L=&5R;F%T:79N;R!P<F5D;&]G;P!)>F)R:;EI('9R<W1I
M8V\`27IB<FFY:2!I>F)R86YO(&ED96YT:71E=&\`27IB<FFY:2!T<F5N=71E
M;B!S=&]L<&5C`$EZ8G)IN6D@=')E;G5T;F\@=G)S=&EC;P#(87,@9&]S=&%V
M90!$86YS:V$`3W!IN6D@<')O8FQE;0!/<&ES`%!O9')O8FYO<W1I("AT=61I
M('8@2&]R9&4@;&]G(&1A=&]T96MI*3H`4&]D<F]B;F]S=&D@<V\@8FEL92!Z
M87!I<V%N92!Z82!S:W)B;FEK82X`4F%Z=F]J`%)O<V$`4F]S82!V('IA9&YJ
M:2!U<FDZ`%)O<V$Z(`!3;65R(&]D(&QE=F4@<')O=&D@9&5S;FD`4VUE<B!O
M9"!D97-N92!P<F]T:2!L979I`$EM96YI:P!0<FEK8;YE;2#H87,@=B!O8FQI
M:VD@,C0@=7(_`$UOOFYO<W1I('!R:6MA>F$`4')I:V&^:2!N87!O=F5D("A4
M048I`$]B;&EK82!P<FEK87IA`$]B=F5S=&EL;R!O(&1I<W!O>FEC:6II`$2^
M:6)U=&D`3F4@<&]B<FFY:0!.92!D;W-T;W!A:G1E(&1A=&]T96ME(&UA:6YT
M96YA;F-E+G!H<"!N97!O<W)E9&YO`$%L:2!P<G9A('9R<W1I8V$@=G-E8G5J
M92!I;65N82!P;VQJ/R#(92!D82P@;V1K;&IU:V%J=&4Z`$1O;6EN:6-A`$1O
M;6EN:6MA;G-K82!R97!U8FQI:V$`4')E;F5S:0!0<F5N97-I("5S`%!R96YE
M<VD@9V5N97)I<F%N;R!K;VYF:6=U<F%C:6IO(&MO="!02%`@<VMR:7!T;RX`
M4V5Z;F%M('H@:7IB:7)O`$1R;V=E`$4M<&^Y=&$`15)2`$5K=F%D;W(`57)E
M9&D`57)E9&D@8FQO:P!5<F5D:2!S:W5P:6YO`%5R961I('!R879I8V\`57)E
M9&D@<')A=FEC90!5<F5D:2!P<F%V:6-E('IA("5S`%5R961I(&UOOFYO<W1I
M('IA.@!5<F5D:2!P<F%V:6-E('IA("5S`$EZ;V)R87IB80!%9VEP=`!386QV
M861O<@!%;&5M96YT+BXN`$5M`$4M<&^Y=&$`12UP;[ET;FD@;F%S;&]V`$4M
M<&^Y=&YI(&YA<VQO=FD@<V4@;6]R86IO('5J96UA=&DN`$4M<&^Y=&$@<R!P
M;W1R9&ET=FEJ;P!3;66Y:VD`4')A>FYO('-P;W)OZ&EL;RX`4')A>F5N(')E
M>G5L=&%T+@!0<F%Z;F$@:7-K86QN82!P;VQJ80!/;6]G;^AI('9S=&%V;&IA
M;FIE('-L:6L@:7H@1F]T;R!G86QE<FEJ92!V(&)E<V5D:6QO/P!/;6]G;^AI
M(&1E<VYI(&ML:6L@>F$@;65N=0!,971O(&MO;F-A`%!O=F7H86H@=7)E:F5V
M86QN:6L`5FYE<VET92!V<')AN6%N:F4L(&MI('9A;2!B;R!Z87-T879L:F5N
M;RP@Z&4@8F]S=&4@OF5L96QI('!O;F%S=&%V:71I('-V;VIE(&=E<VQO+"!N
M<'(N("=+86MO(&IE(&EM92!V8;EI(&1O;6'H:2"^:79A;&D_)SH`5'5K86H@
M=G!IN6D@55),('-L:6ME`$5K=F%T;W)I86QN82!'=FEN96IA`$5R:71R96IA
M`$YA<&%K80!.87!A:V$@>B!E+7!ON71N:6T@<W!O<F_H:6QO;2X`17-T;VYI
M:F$`171I;W!I:F$`171N;P!%=G)O<&$`5G-A:VEH(#$U(&UI;G5T`%9S86MI
M(#(@;6EN=71I`%9S86MI:"`S,"!S96MU;F0`5G-A:VEH(#4@;6EN=70`3V(@
M=G-A:VD@<')I:F%V:0!6<V%K92!P;VP@=7)E`%9S86MO(&UI;G5T;P!0<FEM
M97)I.@!)>G9E9&D`4F%ZN6ER:0!287JY:7)I('-T<F%N<VMI(&UE;G4`4')I
MZ&%K;W9A;"`G*2<`4')IZ&%K;W9A;F$@:F4@8FEL82!B97-E9&$@86QI('-T
M879E:R!Z82!I<VMA;FIE('8@;F%R96MO=F%J:6@`1&%T=6T@=F5L:F%V;F]S
M=&D`16MS<&]N96YT`$)A<G9A(&]S<')E9&IA`$944"!P<F5N;W,@;F%M97-T
M:71V90!0<F5N;W,@;F%S=&%V:71E=B!N:2!U<W!E;"X`4&]V97IA=F$@;F$@
M3$1!4"!S=')EOFYI:R!N:2!U<W!E;&$N`%!O=F5Z879A(&YA(%--0B!S=')E
MOFYI:R!N:2!U<W!E;&$N`$MO<&ER86YJ92!I>B`B)7,B(&YI('5S<&5L;RX`
M2V]P:7)A;FIE('8@(B5S(B!N:2!U<W!E;&\N`%9Z<&]S=&%V;&IA;FIE(&YO
M=F4@4T%33"!P;W9E>F%V92!N:2!U<W!E;&\N`%!R96UI:V%N:F4@=B`B)7,B
M(&YI('5S<&5L;RX`3&5P;P!&86QK;&%N9'-K:2!O=&]K:0!&87)O92!O=&]K
M:0!&86MS`$9E8G)U87(`R'5T:71I(&IE`,AU=&ET:2!J93H@`$YE:V%J('!L
M;V@`1FEDOFD`J71E=FEL;R!D871O=&5K.B`E<R!D871O=&5K80"I=&5V:6QO
M(&1A=&]T96LZ("5S(&1A=&]T96L`57!R879I=&5L:B!D871O=&5K`$EM92!D
M871O=&5K90!)>F)I<F$@9&%T;W1E:V4`4')E;F]S(&1A=&]T96ME(&YA('-T
M<F6^;FEK`%!R96YO<VD@9&%T;W1E:R!N82!S=')EOFYI:R!N:7-O('!O9'!R
M=&DN`$9I;'1R:0!&:6YS:V$`4')V82!P;VQO=FEC80!0<G9A(.AE=')T:6YA
M`$9I:W-N;R!R87IM97)J90!0<F5Z<F-A;&D`3&5B9&7H`$UE9VQA`$UA<&$@
M)7,@;F4@;V)S=&%J80!"87)V82!B97-E9&EL80!(<F%N80!:82!B<G-K86QN
M:6ME+"!K:2!N92!P;V1P:7)A:F\@<VQI:P!.87!O=F5D("A4048I`$1N979I
M(&YA<&]V961I("AN87!O=F5D(&)O('9R;FIE;F$@>F$@;V)O:F4@9&%N(&EN
M(&YOZ#L@=FES;VMA(+ET979I;&MA(&QA:&MO('!O=GIR;^AI(+EI<F]K(&)L
M;VLI`%-T92!P;WIA8FEL:2!G97-L;S\`3V)R87IC:0!&;W)T=6YI`%9R<W1A
M($9O<G1U;F]V`$9O<G1U;FD`1F]R='5N:2`R`$]B<F%Z8VD`4&]S<F5D;W9A
M;FIA`%!E`$]K=FER:FD`1G)A;F-I:F$`1G)A;F-I:F$L($UE<W1O`$9R86YC
M;W-K82!'=6EA;F$`1G)A;F-O<VMA(%!O;&EN97II:F$`2G6^;F$@1G)A;F-O
M<VMA(&]Z96UL:F$`3V0`3V0@`%!O;&YI(&]P:7,`4&]L;F$@;'5N80!0;VQN
M;R!I;64`1V%B;VT`5GIE;6D@<VQI:V\@:7H@9V%L97)I:F4`1V%L97)I:F$Z
M`$=A;6)I:F$`1V5N97)I<F%J("5S(&MO;F9I9W5R86-I:F\`1V5N97)I<F%N
M82!I>G9O<FYA(&MO9&$`1V5O<F=I80!.96WH:6IA`$=A;F$`1VEB<F%L=&%R
M`$QA<W1N;R!I;64`4&]J9&D`1V]E9&5L`$=O;V=L92!I<VMA;FIE`%-I=FEN
M<VMA(&QE<W1V:6-A`$=RZ&EJ80!'<KEK;R`H25-/+3@X-3DM-RD`1W)E96YL
M86YD:6IA`$=R96YA9&$`061M:6YI<W1R86-I:F$@<VMU<&EN`$EM96YA('-K
M=7!I;B!N92!S;65J;R!B:71I('!R87IN80!3:W5P:6YE`$=U861E;&]U<&4`
M1W5A;0!'=F%T96UA;&$`1W5E<FYS97D`4')A=FEC92!';W-T80!+;FII9V$@
M9V]S=&]V`$=V:6YE:F$`1W9I;F5J82!":7-S874`1W9A:F%N80!(5$U,`$A4
M34Q!<F5A('-T<F%H;W!E=&YO(&YOZ&4@<&]B<FES871I('IA9&YJ92!C96QI
M8V4@=B!V<G-T:6-I+@!(5$U,07)E82!S=')A:&]P971N;R!N;^AE('!O8G)I
M<V%T:2!Z861N:F5G82!S=&]L<&-A('8@=&%B96QI+@!(5$U,07)E82!S=')A
M:&]P971N;R!N;^AE('!O8G)I<V%T:2!Z861N:F4@=G)S=&EC92!V('1A8F5L
M:2X`2%144"!O=F5R:F%N:F4@;FD@8FEL;R!N86ID96YO+@!(86ET:0!(87-H
M+4%L9V]R:71E;0!3;W!A<F$`1VQA=F$`2&5A<F0@;W1O:VD@:6X@36-$;VYA
M;&0@;W1O:VD`2&5B<F5V<VMO("A)4T\M.#@U.2TX+4DI`%9IN6EN80!0;VUO
MZ`!0;VUOZ"!P<FD@=7!O<F%B:2!U<F5J979A;&YI:V$`4&]M;^AN:6L`4&]L
M;V)L80!3;&5D:2!Z8>AE=&5K(&1A=&]T96ME.@!6:7-O:V\`1&]?;6]V`%-V
M971I('-E9&6^("A6871I:V%N<VMA(&UE<W1N82!D<KYA=F$I`$1O;6]V`$1O
M;6'H:2!N87-L;W8`1&]M8>AI('1E;&5F;VX`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<F1E+TMO;&%B.B!.87!AZ&YI("5S(%A-3"!P;V1A=&MI(&YA
M:F1E;FD@=B!S<&]R;^AI;'4@)7,`2&]R9&4O2V]L86(Z($YO8F5N;R!S<&]R
M;^AI;&\@;F4@=7-T<F5Z82!O8FIE:W1U("5S(`!(;W)D92]+;VQA8CH@3V)J
M96MT('1I<&$@)7,@;FD@8FEL(&YA:F1E;B!V('-P;W)OZ&EL=2`E<P!(;W)D
M92]+;VQA8CH@57-P9;EN;R!O9'-T<F%N:6P@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@26YT96=R86-I:F$@<&]T<F5B=6IE(%!(4"!D;V1A=&5K("=D;VUX;6PG
M`$AO<F1E+TMO;&%B.B!.:2!M;V=OZ&4@:7ID96QA=&D@;F]V96=A(%A-3"!D
M<F5V97-A('IA(&]B:F5K="`E<P!(;W)D92]+;VQA8CH@3FD@;6]G;^AE(&]D
M<W1R86YI=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YI(&UO9V_H92!P
M<FED;V)I=&D@34E-12!)1"!Z82!D96P@=&EP82`E<P!(;W)D92]+;VQA8CH@
M3FD@;6]G;^AE('-I;FAR;VYI>FER871I("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!.:2!M;V=OZ&4@<VEN:')O;FEZ:7)A=&D@<VMU<&YE(')A8F4Z("5S
M`$AO<F1E+TMO;&%B.B!.97!O>FYA;F$@<VMU<&YA(')A8F$@(B5S(@!6;V1O
M<F%V;F$@Z')T80!6;V1O<F%V;FD@;V1M:6L`5F]D;W)A=FYO.@!+86MO('-T
M92!P<FFY;&D@9&\@<V5M/R`H4')O<VEM(&]B=F5S=&ET92$I`$MO;&EK;R!S
M=&]L<&-E=B"^96QI=&4@<W!O:FET:3\`2V]L:6MO('!O;&H@*'-T;VQP8V5V
M*2!O8G-T86IA/P!+;VQI:V\@=G)S=&EC(+YE;&ET92!S<&]J:71I/P!6;&&^
M;F]S=`!6;&&^;F]S=#H`2'5M;W)I<W1I`$UA9+YA<G-K80!5<W1V87)J86YJ
M92!)34%0(&YA8FER86QN:6MA(&YI('5S<&5L;SH@)7,`0G)I<V%N:F4@24U!
M4"!N86)I<F%L;FEK82!N:2!U<W!E;&\Z("5S`$EZ9&5L879A(&MV;W1E($E-
M05`@;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<P!)4"!N87-L;W8`25`@;F%S
M;&]V(&YI(&YA('9O;&IO+@!)4"!N87-L;W8@;FD@9&]V;VQJ96X@=B!#2412
M(&)L;VMU+@!+<KEI=&5V('IA:VQE;FET=F4@25`@;F%S;&]V82X`5E]S=&%V
M:2!V<G-T:6-E('!R960`27-L86YD:6IA`%-A;6\@:6MO;F4`26MO;F4@>F$@
M)7,`26MO;F4@<R!T96MS=&]M`$EM92!I9&5N=&ET971E.@#(92!P<FEK87H@
M;FD@<')A=FEL96XL("5S('IA(&]D<')T:F4@=B!N;W9E;2!O:VYU+@#(92!P
M<FD@=7!O<F%B:2!);G1E<FYE="!%>'!L;W)E<FIA(&YE('9I9&ET92!I:V]N
M+"!O9&ML:G5K86IT92!T;R!M;[YN;W-T('IA(&]N96UO9V_H96YJ92!P<F]Z
M;W)N;W-T:2!S;&EK(%!.1RX`R&4@=FED:71E('1O('-P;W)OZ&EL;RP@<VQI
M:V4@<&$@;F4L('-L:6MA(&MI(&IO(+YE;&ET92!P<F5N97-T:2!N92!M;W)E
M(&)I=&D@<')I:V%Z86YA('8@=F&Y96T@8G)S:V%L;FEK=2X`4')E9&]G;&5D
M('-L:6ME.@!54DP@<VQI:V4`55),('-L:6ME.@!3;&EK82!I>B!G86QE<FEJ
M90!3;&EK82!I>B!G86QE<FEJ93H`4')E;F]S('-L:6ME(&YA('-T<F6^;FEK
M`%-L:6ME`%5V;WHL(&MO<F%K("5D`%5V;[YE;F\@<&]L:F4Z("5S`%5V;[YE
M;F$@<&]L:F$Z`%9?<W1A=FD@=G)S=&EC92!Z861A:@!0;V1A;F$@;F5P<F%V
M:6QN82!K;V1A(&1E:F%N:F$N`$YE<')A=FEL;F\@=7!O<F%B;FFY:V\@:6UE
M(&EN+V%L:2!G97-L;RX`3F5P<F%V:6QN;R!U<&]R86)N:;EK;R!I;64@86QI
M(&YA<VQO=BX@4&]S:W5S:71E('!O;F]V;F\@86QI(&MO;G1A:W1I<F%J=&4@
M<W9O:F5G82!S:W)B;FEK82P@Z&4@<&]T<F5B=6IE=&4@;F%D86QJ;F\@<&]M
M;^@N`%!O=F7H86H@>F%M:6L`26YD:6IA`%!O<V%M97IN:2!U<&]R86)N:6MI
M`$EN9&]N97II:F$`26YF;P!);F9O<FUA8VEJ90!6<W1A=FD@<W1?;VQP96,@
M>F%D86H`5G-T879I('-L:6MO`%9S=&%V:2!T86)E;&\`5G-T879I('-P;&5T
M;F\@<&]V97IA=F\`5G-T879I('-T;U]L<&5C('-P<F5D86H`5G-T879I(&YO
M=B!S=&]L<&5C('IA('1R96YU=&YI;0!6<W1A=FD@;F]V('-T;VQP96,@<')E
M9"!T<F5N=71N:6T`5G-A=FD@;F]V;R!V<G-T:6-O('IA('1R96YU=&YO`%9S
M=&%V:2!N;W9O('9R<W1I8V\@<')E9"!T<F5N=71N;P!6<W1A=FD@;V1S=&%V
M96L@>F$@=')E;G5T;FEM('9O>FQIN>AE;0!6<W1A=FD@;V1S=&%V96L@<')E
M9"!T<F5N=71N:6T@=F]Z;&FYZ&5M`%9S=&%V:2!A;'1E<FYA=&EV;F\@<')E
M9&QO9V\`5G!IN6ET92!E+7!ON71N:2!N87-L;W8@:V%M;W(@OF5L:71E('!R
M96IE=&D@;F]V;R!G97-L;SH`5G-T879I(&-E;&EC;R!Z861A:@!6<W1A=FD@
M8V5L:6-O('-P<F5D86H`5G-T879I('-T;VQP96,@>F%D86H`5G-T879I('-T
M;VQP96,@<W!R961A:@!6<W1A=FD@<W!O<F_H:6QA`%9S=&%V:2!O9'-T879E
M:R!S<')E9&%J`%9S=&%V:2!O9'-T879E:R!Z861A:@!6<W1A=FD@=G)S=&EC
M;R!Z861A:@!6<W1A=FD@=G)S=&EC;R!S<')E9&%J`%9P:;EI=&4@;V1G;W9O
M<B!N82!Z86AT979A;F\@=F%R;F]S=&YO('9P<F&Y86YJ93H`5G-T879I+U5R
M961I('-L:6MO`%9S=&%V:2]5<F5D:2!P;W9E>F%V;P!.97IA9&]S=&5N(&MR
M961I="!Z82!P;[EI;&IA;FIE(&YA('-E>FYA;6$@<F%Z<&^Y:6QJ86YJ82X`
M3F5Z861O<W1E;B!K<F5D:70N`*ET979I;&\`4V5Z;F%M(+ET979I;`!.87!A
MZ&5N(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!.87!AZ&YA(&%P;&EK86-I
M:F$N`$YA<&'H96X@240@<&%K971A+@!/9&1A;FD@;F%P8>AN:2!P;V1A=&MI
M+@!.87!AZ&YE;B!N87-L;W8@9&5S=&EN86-I:F4N`$YA<&'H;F$@;V)L:6MA
M(&1A=&]T96ME`$YA<&'H96X@;7-G7W1Y<&4N`$YA<&'H96X@86QI(&UA;FMA
M:F_H(&%P:5]I9"X`3F%P8>AN:2!A;&D@;6%N:V%J;^AI('!A<F%M971R:2X`
M3F%P8>AN82!D;W9O;&IE;FIA(&YA9')E:F5N96=A(&]B:F5K=&$N`$YA<&'H
M96X@<')O=&]K;VPN`$YE=F5L:F%V96X@;V)J96MT('8@<VMU<&YI(')A8FD`
M3F5V96QJ879E;B!I>G9O<FYI(&YA<VQO=BX`3F%P8>AN:2!U;FEC;V1E('!O
M9&%T:VDN`$EN=F5N='5R80!)<F%N`$ER86L`27)S:V$`36%N;W8@;W1O:P!)
M>F]L:7)A;F4@;F5V:6AT90!)>G)A96P`27ID86IA=&5L:@!0;[EE=FYO`$ET
M86QI:F$`2F%M86IK80!*86YU87(`2F%P;VYS:V$`2F%P;VYS:V\@*$E33RTR
M,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;&EJ`$IU;FEJ`%!O<F%V;F%V80!3
M<F5D:6YS:V$@<&]R879N879A`$]B;VIE<W1R86YS:V$@<&]R879N879A`$QE
M=F$@<&]R879N879A`$1E<VYA('!O<F%V;F%V80!+87IA:'-T86X`3V)D<KYI
M;2!O<FEG:6YA;#\`2V5N:6IA`$ME<F)E<F]S('-T<F6^;FEK(&IE('IA=G)N
M:6P@;W9E<FET978N`$YO=FEN8VD@:V5R;F5L80!)>F1E;&%V82!K;&IUZ&$`
M4')S=&YI(&]D=&ES(&ML:G7H80!$;VR^:6YA(&ML:G7H80!6<G-T82!K;&IU
MZ&$`57!O<F%B82!K;&IUZ&$`2VQJ=>@@OF4@;V)S=&%J82!N82!J879N96T@
M<W1R9;YN:6MU(',@:VQJ=>AI+@!/=')O8VD`2VER:6)A=&D`2V]R96IA+"!,
M:G5D<VMA(&1E;6]K<F%T:>AN82!R97!U8FQI:V$`2V]R96IA+"!R97!U8FQI
M:V$`2V]R96IS:V\@*$550RU+4BD`2W5V86IT`$MI<F=I>FES=&%N`%!O<W1?
M879I=&5V`$IE>FEK`$QA;W,`6F%D;FIA('!O;&]V:6-A`%IA9&YJ82#H971R
M=&EN80!:861N:FGH('!O<V]D;V)L:F5N;SH`6F%D;FIA('!R:6IA=F$Z("5S
M`%IA9&YJ82!P<FEJ879A.B`E<R!Z("5S`%IA9&YJ82!P<FEJ879A.B!.:6MO
M;&D`3&%T=FEJ80!:86MO;@!0;W-T879I=&5V`%!U<W1I=&4@<')A>FYO('IA
M(&)R97H@<F]B=0!,:6)A;F]N`$QE=F\`3&5V82!G;&%V80!,979E('9R961N
M;W-T:0!,97-O=&\`3&EB97)I:F$`3&EB:6IA`$QI:'1E;KET86IN`%)A:&QO
M(')O<V5N:F4`4F%H96P@9&6^`%)A:&5L(&1EOB!Z9V]D86H`4F%H96P@9&6^
M('!O>FYO`%)A:&QA(&1EOF5V;F$@<&QO:&$`4F%H96P@9&6^(',@<W1R96QA
M;6D`4F%H;&\@<VYEOF5N:F4`4F%H;&$@<VYEOFYA('!L;VAA`$QI;65R:6-K
M`%!O=F5Z879A`%!O=F5Z879A(&MAOF4@;F$Z`%!O=F6^:2!E+7!ON71N:2!N
M87-L;W8@;F$@<W1R86X@>F$@<V5S=&%V;&IA;FIE('-P;W)OZ&EL`%!O=F5Z
M879E`$QI;G5X('!IN6MO=&5K`%-E>FYA;2`M('5P;W)A8FYI:R!L86AK;R!V
M:61I(&UA<&\`4')I:V&^:2!B87IE('!O9&%T:V]V`%!R:6MAOFD@=&5M92!P
M;VUOZ&D`4')I:V&^:2!T86)E;&4`4V5Z;F%M+4%R:&EV`%-E>FYA;2U0;VUO
MZ`!397IN86TM260`4V5Z;F%M+4QA<W1N:6L`4V5Z;F%M+4UE<W1O`%-E>FYA
M;2U.87)OZ&D`4V5Z;F%M+4]D<&]V96H`4')I:V%Z;W9A;FIE('5P;W)A8FYI
M:V]V(&IE(&]N96UO9V_H96YO+@!,:71E<F%T=7)A`$QI='9A`$YA;&%G86TN
M+BX`3&]K86QE;B#H87,Z(`!*97II:R!I;B#H87,`3&]K86-I:F$`4')I:F%V
M80!/9&IA=F$`3W!R879I;&$@;V(@<')I:F%V:0!0<FEJ879A(&YI('5S<&5L
M82!Z87)A9&D@;F%P8>AN;R!V<&ES86YE9V$@=7!O<F%B;FFY:V5G82!I;65N
M82!A;&D@9V5S;&$N`%!R:6IA=F$@;FD@=7-P96QA+@!$;VQG;R!B97-E9&EL
M;P!,:G5B97IE;@!.:7IK;P!-86QE(&=RN6ME(.AR:V4`36%L92!L871I;G-K
M92#H<FME`$UA;&4@<FEM<VME(+ET979I;&ME`$QU:W-E;6)U<F<`34T`34]4
M1`!-4RU43D5&('!R:7!O;FMA(&YI('9S96)O=F%L82!P;V1A=&MO=BX`35-'
M`$UA:V%O`$UA:V5D;VYI:F$`36%D86=A<VMA<@!-86=I:F$`4&^Y=&$`57!R
M879I=&5L:B!P;[ET90!5<W1V87)I('!O=F5?>F%V;P!-86QA=FD`36%L97II
M:F$`36%L9&EV:0!-86QI`$UA;'1A`%5R961I=&4@<V5Z;F%M(&MA=&5G;W)I
M:BP@<R!K871E<FEM:2"^96QI=&4@;WIN8>AI=&D@;V)J96MT92!I;B!B87)V
M92!P;W9E>F%N92!S('1E;6D@:V%T96=O<FEJ86UI+@!:96UL:F5V:60@36%P
M,C0`6F5M;&IE=FED($UA<%%U97-T`$UA<F5C`$]D;6EK`$]Z;F'H:2!Z(&]Z
M;F%K;R!6:61E;F\O3F4@=FED96YO`$]Z;F'H:2!Z(&1R=6=I;6D@;WIN86MA
M;6D@*&YP<BX@4&]M96UB;F\O3V1G;W9O<FIE;F\I`$UA<G-H86QL;W9I(&]T
M;VMI`$UA<G1I;FEQ=64`56IE;6%J;^AA('!O;&IA`$UA=G)E=&%N:6IA`$UA
M=7)I=&EU<P!-86MS:6UA;&YI(&1O=F]L:F5N(&MR961I="X`36%K<VEM86QN
M;R"Y=&5V:6QO(&1E;&]V('-P;W)OZ&EL82!P<F5K;W)AZ&5N;RX`3F%J=FFY
M:F$@=&5M<&5R871U<F$@>F%D;FII:"`R-"!U<CH@`$YA:G9IN6IA('1E;7!E
M<F%T=7)A('IA9&YJ:6@@-B!U<CH@`$UA:W-I;6%L;F$@9&]LOFEN80!-86H`
M36%Y;W1T90!:9')A=G-T=F\`R&QA;FD`5G)S=&$@;65N=6IA.@!3<&]J:2!C
M96QI8V4`4W!O<F_H:6QO`%-P;W)OZ&EL;R!J92!B:6QO('5S<&6Y;F\@<')E
M=F5R:F5N;RP@<&]D<&ES;FEK;W9E9V$@<&]T<F1I;&$@<&$@;FD@8FEL;R!M
M;V=OZ&4@;W9E<FET:2X`4W!O<F_H:6QO(&IE('!R971E:VQO+@!6<G-T82!S
M<&]R;^AI;&$`365T87(@5G)E;64`365T87(@8FQO:R!N:2!N82!V;VQJ;RX`
M365T87(@8FQO:R!N:2!N82!V;VQJ;RX@4&]D<F]B;F]S=&D@<V\@8FEL92!L
M;V=I<F%N92!Z82!A9&UI;FES=')A=&]R:F$N`$UE=&]D80!-971R:>AN82!S
M:V%L80!-96MS:6MA`$UI:W)O;F5Z:6IA`%-R961I;F$`5&EP($UI;64`3F%J
M;FF^:F$@=&5M<&5R871U<F$@>F%D;FII:"`R-"!U<CH@`$YA:FYIOFIA('1E
M;7!E<F%T=7)A('IA9&YJ:6@@-B!U<CH@`%IR8V%L:0!287IN;P!-86YJ:V$@
M4$5!4B!P86ME="!(5%107U)E<75E<W0N`$MO;F9I9W5R86-I:F$@;6%N:FMA
M+B#(92"^96QI=&4@=7!O<F%B;&IA=&D@=&\@87!L:6MA8VEJ;RP@:F\@;6]R
M871E('ID86H@9V5N97)I<F%T:2X`36%N:FMA($E$('-P;W)OZ&EL82X`36%N
M:FMA('IA:'1E=F%N(%!%05(@<&%K970@36%I;"X`36%N:FMA($E$('-E:F4N
M`%!O`$UO8FEL;F$@<&^Y=&$`6FUE<FYO`$1A='5M('-P<F5M96UB90!3<')E
M;65N:2!54DP`36]D=6QI`$UO;&1A=FEJ80!-;VYA:V\`36]N9V]L:6IA`$UE
M<V5C(&EN(&QE=&\`365S9>AN;P!-;VYS97)A=`!,=6YI;F4@;65N90!-87)O
M:V\`4')E=&6^;F\@:F%S;F\`4')E=&6^;F\@;V)L8>AN;P!0<F5T9;YN;R!S
M;V[H;F\`4')E;6%K;FD@9&]L`%!R96UA:VYI(&QE=F\`4')E;6%K;FD@9&5S
M;F\`4')E;6%K;FD@9V]R`%!R96UA:VYI(&1O;`!0<F5M86MN:2!G;W(`36]Z
M86UB:6L`5F7H+6YI=F]J<VMI('-E>FYA;6D@>B!I>F)I<F\`5F7H:W)A=&YA
M(&EZ8FER80!-;VH@<F'H=6X`36]J('!O<G1A;`!/8FQI:V$@;6]J96=A('!O
M<G1A;&$`36%J;FUA<@!.12P@;F4@<W1R:6YJ86T@<V4`26UE`$YA;6)I:F$`
M3F%U<G4`3F5P86P`3FEZ;WIE;7-K80!.:7IO>F5M<VMI($%N=&EL:0!/<VYO
M=FYI($YE='-C87!E(%523`!54DP@>F$@<')E:VQI8R!P;W1R9&EL82!.971S
M8V%P92!#00!54DP@<&]L:71I:V4@3F5T<V-A<&4@0T$`55),('IA(&]B;F]V
M;R!P;W1R9&EL82!.971S8V%P90!54DP@>F$@<')E:VQI8R!P;W1R9&EL82!.
M971S8V%P90!);64@<W1R9;YN:6MA($YE='-C87!E(%-33`!+;VUE;G1A<B!P
M;W1R9&EL82!.971S8V%P90!6<G-T82!P;W1R9&EL82!.971S8V%P90!/;7)E
MOFIE`$YI:V]L:0!.;W9A($MA;&5D;VYI:F$`3F]V82!K871E9V]R:6IA`$UL
M86H`3F]V;R!U<&]R86)N:;EK;R!I;64@*&]P8VEJ<VMO*0!.;W9A(%IE;&%N
M9&EJ80!.;W9O(&]K;F\@*%]B;&%N:RD`3F]V:6-E`$YO=FGH:V%R<VME('-K
M=7!I;F4`3F%P<F5J`$YA<VQE9&YJ92!M;[YN;W-T:0!.:6MA<F%G=F$`3FEG
M97(`3FEG97)I:F$`3F_H`$YI=64`3F4`4&]D871K:2!K;VYF:6=U<F%C:6IE
M(&YI<V\@;F$@=F]L:F\L(')A>FQI:R!N:2!M;V=OZ&4@<&]K87IA=&DN`$YA
M('9O;&IO(&YI(&YO8F5N96=A(&YAZ&EN82!Z82!I>F1E;&%V;R!)4T\@<&]S
M;F5T:V]V+@!0<F5D;&]G82!P86ME=&$@;F4@;V)S=&%J82X`3F$@OF5L:F5N
M96T@<&]L;[YA:G4@8FQO:R!N92!O8G-T86IA`%IA($U#04P@879T96YT:6MA
M8VEJ;R!N:2!B:6QO('!O9&%T;F\@:6UE(&MO;&5D87)J82X`0G)E>B!S<')E
M;65M8F4N`%!O9')E:F5N92!P<F%V:6-E('-E('1E:B!P<F%V:6-I(&QA:&MO
M(&1O9&%J;RX`26YF;W)M86-I:F4@;R!K;VYF:6=U<F%C:6II('IA("5S(&YI
M<V\@8FEL92!P;V1A;F4N`$EN9F]R;6%C:6IE(&\@:V]N9FEG=7)A8VEJ:2!Z
M82!&5%`@5D93(&YI<V\@8FEL92!P;V1A;F4N`$EN9F]R;6%C:6IE(&\@:V]N
M9FEG=7)A8VEJ:2!Z82!344P@5D93(&YI<V\@8FEL92!P;V1A;F4N`$EN9F]R
M;6%C:6IE(&\@:V]N9FEG=7)A8VEJ:2!Z82!344PM1FEL92!61E,@;FES;R!B
M:6QE('!O9&%N92X`2W)E9&ET82!N:2!V9>@N`$1E<W1I;F%C:6IA(&YI(&)I
M;&$@<&]D86YA+@!$871O=&5K82!N:2!P<F5N9;EE;F%N82!S=')EOFYI:P!)
M:V]N(&YI(&UO9V_H92!N86IT:2X`3&]K86-I:F$@;FD@;F%S=&%V;&IE;F$N
M`%-P;W)OZ&EL;R!N:2!B:6QO('!O9&%N;RX`26UE(&YI(&)I;&\@<&]D86YO
M+@"I=&5V:6QK82!N:2!B:6QA('!O9&%N82X`3F4@<')I:V%Z=6H@OF%L:FEV
M:6@@9F]R='5N92UO=@!'97-L;R!Z82!(5%10(&%V=&5N=&EK86-I:F\@;FD@
M8FEL;R!P;V1A;F\N`$=E<VQO('IA($E-05`@879T96YT:6MA8VEJ;R!N:2!B
M:6QO('!O9&%N;RX`1V5S;&\@>F$@2V5R8F5R;W,@879T96YT:6MA8VEJ;R!N
M:2!B:6QO('!O9&%N;RX`1V5S;&\@>F$@3&]G:6X@879T96YT:6MA8VEJ;R!N
M:2!B:6QO('!O9&%N;RX`1V5S;&\@>F$@4$%34U=$(&%V=&5N=&EK86-I:F\@
M;FD@8FEL;R!P;V1A;F\N`$=E<VQO('IA(%--0B!A=G1E;G1I:V%C:6IO(&YI
M(&)I;&\@<&]D86YO+@!0;W0@9&\@3W!E;E-33"!I>G9RN6EL;F4@9&%T;W1E
M:V4@;FD@8FEL82!P;V1A;F$N($QE+71A(&IE('!O=')E8FYA('IA(&1E;&\@
M<R!P;V1A=&MI(%!+0U,@,3(N`$YO8F5N('9P:7,@;F4@Z&%K82X`0G)E>B#H
M<G0`0G)E>B!S=')A;FEC`$YA('9O;&IO(&YI('IAZ&%S;F4@;6%P92!Z82!C
M86-H92X`57!O<F%B;FFY:V\@:6UE(&EN+V%L:2!G97-L;R!N:2!B:6QO('!O
M<VQA;F\N`$YI<V\@8FEL:2!V<FYJ96YI('9E;&IA=FYI(%A-3"!P;V1A=&MI
M`$)R97H@=G)E9&YO<W1I`%8@;W)I9VEN86QN:2!K;VYF:6=U<F%C:6II('9E
M<GII:F$@;FD@;F%J9&5N82X@6FYO=F$@:F\@9V5N97)I<F%J=&4N`%8@=F&Y
M:2!K;VYF:6=U<F%C:6II('9E<GII:F$@;FD@;F%J9&5N82X@6FYO=F$@:F\@
M9V5N97)I<F%J=&4N`$)R97H`0G)E>B`H=7!O<F%B:2!I;7!L:6-I=&YO*0!.
M;W)D:6IS:V\@*$E33RTX.#4Y+3$P*0!.;W)F;VRY:VD@;W1O:P!3979E<FYA
M('!O;&]B;&$`4V5V97)N:2!-87)I86YA(&]T;VMI`$YO<G9EN6MA`$YE('!O
M`$YE('!R960`3FD@;6%P80!.:2!I;7!L96UE;G1I<F%N;RX`3FD@;F%S=&%V
M;&IE;@!.:2!P;V1P<G1O+@!:87!I<VMI`$YIZ&5S87(@>F$@<')E8G)S:V%T
M:2P@=G)N:2!S92X`3F]V96UB97(`J71E=FEL;P"I=&5V:6QO('IN86MO=@"I
M=&5V:6QO('-T;VQP8V5V`*ET979I;&\@=G)S=&EC`*ET979I;&ME('IA('!O
M<V]D;V)I=&5V('-E>FYA;6$@<F%Z9&5L:71V92!N:7-O('!O9&%N92X`5B!R
M961U`$]B:F5K=`!4=F]R96,@;V)J96MT80!/:W1A;&YO`$]K=&]B97(`1FEL
M=&5R(+YA;&II=FL`4&ES87)N80!/;6%N`%-A;6\@24U!4"!S=')EOFYI:VD@
M<&]D<&ER86IO(&UA<&4@=B!S:W5P;FD@<F%B:2X`4V%M;R"^86QJ:79I(&9O
M<G1U;F4M:0!$;W9O;&IE;B!J92!S86UO(&5N(&4M<&^Y=&YI(&YA<VQO=BX`
M4V%M;R!L87-T;FEK(&%L:2!S:W)B;FEK('-I<W1E;6$@;&%H:V\@<W!R96UE
M;FD@;&%S=&YIN71V;R!A;&D@;&%S=&YI:V$@<')A=FEC('-K=7!N92!R86)E
M`$]D<')I('8@;F]V96T@;VMN=0!/<&5N4U-,(&YA<&%K83H@4&]D871K;W8@
M:7H@4R]-24U%('!O9'!I<V%N96=A(&1E;&$@;FD@;6]G;^AE(&EZ=FQEZ&DN
M`$]D<')E('1O('!O=F5Z879O('8@;F]V96T@;VMN=0!/<&5R86-I:G-K:2!S
M:7-T96T`36^^;F]S=&D`36^^;F]S=&D@>F$@)7,`57)E:F5N('-E>FYA;0!/
M<F=A;FEZ86-I:F$`16YO=&$@;W)G86YI>F%C:6IE`$]R9V%N:7IA8VEJ80!/
M<FEG:6YA;&YA('!R961L;V=A(&%P;&EK86-I:F4`3W)I9VEN86QN92!P<F5D
M;&]G92!V("5S.@!$<G5G;P!$<G5G92!I;F9O<FUA8VEJ90!0<F%V:6-E(&QA
M<W1N:6MA`%!!32!A=G1E;G1I:V%C:6IA(&YI(&YA('9O;&IO+@!01U`@9&EG
M:71A;&YI('!O9'!I<P!01U`@N6EF<FER86YI('!O9&%T:VD`4$=0(&IA=FYI
M(&ML:G7H`%!'4"!P;V1P:7-A;FDON6ER9FER86YI('!O9&%T:VD`4$A0(&MO
M9&$`4$A0('5K87IN82!L=7!I;F$`4&]P;VQD86X@<F%H96P@9&6^`%!O<&]L
M9&%N<VME('!L;VAE`%!O<&]L9&%N<VME(&YE=FEH=&4`4%](4"!U:V%Z;F$@
M;'5P:6YA`$]B<F]B80!086MI<W1A;@!086QA=0!086QE<W1I;G-K;R!O>F5M
M;&IE`%!A;F%M80!087!U82!.;W9A($=V:6YE:F$`4&%R86=V86H`1&5L;F\@
M;V)L8>AN;P!'97-L;P!.97!R879I;&YO(&=E<VQO`$=E<VQO('!O=')E8FYO
M('IA(%)!1$E54R!A=G1E;G1I:V%C:6IO+@!'97-L;R!S('!O=')D:6QO;0!'
M97-L;SH`1V5S;&\Z(`!'97-L:2!S92!M;W)A=&$@=6IE;6%T:2X`4')I;&5P
M:0!0<FEL97!I('H@;V1L;[YIN>AA`%!O=`#(86MA:F_H:2!V<&ES:3H`3&IU
M9&IE`$]D<W1O=&5K`$EZ=F5D:2!O<&5R86-I:F4@=GID<KYE=F%N:F$`27IV
M961I(&]P97)A8VEJ92!V>F1ROF5V86YJ82!O8B!P<FEJ879I/P!0<F%V:6-A
M`$%D;6EN:7-T<F%C:6IA('!R879I8P!/<V5B;F4@:6YF;W)M86-I:F4`4&5R
M=0!$;VUAZ&4@OFEV86QI`$9I;&EP:6YI`%1E;&5F;VX`1F]T;V=R869I:F4`
M4&ET8V%I<FX`4&EK<VQI`%!L871I='5D90!0<F]S:6T@:VQI:VYI=&4@=B!C
M96QI8V\`4')O<VEM('!O=')D:71E(&]D<W1R86YI=&5V('1E9V$@96QE;65N
M=&$Z`%!R;W-I;2!P;W1R9&ET92!O9'-T86YI=&5V('!O=F5Z879E(&5L96UE
M;G1A.@!0<F]S:6T@=G!IN6ET92!M97-E8R!I;B!L971O+@!0<F]S:6T@=G!I
MN6ET92!I;64@>F$@;F]V;R!K871E9V]R:6IO.@!0<F]S:6T@=G!IN6ET92!V
M96QJ879E;B!)4"!N87-L;W8N`%!R;W-I;2!V<&FY:71E('9E;&IA=F5N(&1A
M='5M+"!P<F5V97)I=&4@N71E=FEL;R!D;FD@=B!M97-E8W4N`%!R;W-I;2!V
M<&FY:71E('9E;&IA=F5N(.AA<RX`4')O<VEM('9P:;EI=&4@<&]V>F5T96L@
M<')O8FQE;6$N`%!R;W-I;2!V<&FY:71E('9AN64@=7!O<F%B;FFY:V\@:6UE
M(&EN(&=E<VQO`%!R;W-I;2!V<&FY:71E(&EM92!N;W9E(&MA=&5G;W)I:F4Z
M`%!O;&IS:V$`4&]L:71I:V$`06YK971E`%!O<G1U9V%L<VMA`%!O<W1A=FET
M978@<VQI:V4`4&]S=&%V:71E=B!T86)E;&4`4VAR86YI('8@=&\@;6%P;R`H
M24U!4"!T96=A(&YE('IA:'1E=F$I`$MO;&GH:6YA('!A9&%V:6X@=B!Z861N
M:FEH("5S('5R86@Z(`!0<F5F<U]L9&%P.B!0;W1R96)E;B!,1$%0(&1O9&%T
M96L@;FD@;F%J9&5N+@!0<F5F<U]S97-S:6]N.B!0;W1R96)E;B!S97-S:6]N
M(&1O9&%T96L@;FD@;F%J9&5N+@!0<FET:7-K`%!R:71I<VL@;F$@;6]R<VMI
M('9IN6EN:3H@`%!R:71I<VLZ(`!0<F5D;V=L960`4')E9&]G;&5D('-L:6ME
M('8@;F]V96T@;VMN=0!0<F5JN6YJ92!M;[YN;W-T:0!.871I<VYI(&1O:W5M
M96YT`%IA<V5B;FD@:VQJ=>@`4')O8FQE;0!/<&ES('!R;V)L96UA`%!R;VIE
M:W1I`$)E<V5D:6QO('!O>FEV;FEK80!*879N:2!K;&IUZ`!!;&=O<FET96T@
M:F%V;F5G82!K;&IUZ&$`1V5N97)I<F%N:F4@<&%R82!*879N:2]:87-E8FYI
M(&ML:G7H(&YI('5S<&5L;RX`4&]R=&]R:6MO`%%A=&%R`%!O:7IV961B80!2
M4T$@:F%V;FD@:VQJ=>@@*"4@8FET96XI`$EZ8FER80!$9;X`1&6^('IG;V1A
M:@!$9;X@<&]Z;F\`1&6^979N82!P;&]H80!.86ML:G7H96X@9F]R='5N90!2
M87IM97)J90!0<F5B97)I`%!R96)E<FD@<W!O<F_H:6QA`%)E<R!P;V)R:;EE
M;2`E<S\@3W!E<F%C:6IE(&YI(&UO9V_H92!R87IV96QJ879I=&DN`%)E<R!O
M9'-T<F%N:6T@=7!O<F%B;FEK;W9E('!O9&%T:V4@>F$@)7,_($]P97)A8VEJ
M92!N:2!M;V=OZ&4@<F%Z=F5L:F%V:71I+@!0;VYO=FYO(&EZ=F5D:2!Z861N
M:F4@9&5J86YJ90!/<W9EOFD@9&EN86UIZ&YE(&5L96UE;G1E(&UE;G5J83H`
M3W-V9;YI('!O9VQE9"!P;W)T86QA.@!296=E>`!"<G-K86QN:6L@;V1N;W-O
M=@!0<FEP;VUB90!/9&1A;&IE;FD@<W1R9;YN:6MI`$]D9&%L:F5N(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$]D<W1R86YI`$]D<W1R
M86YI(&)L;VL`3V1S=')A;FD@<W1O;'!E8P!/9'-T<F%N:2!O8FQI:V]V86YJ
M90!/9'-T<F%N:2!P87(`3V1S=')A;FD@<VAR86YJ96YO('-K<FEP=&\@:7H@
M<W1R9;YN:6MO=F4@>F'H87-N92!M87!E+@!/9'-T<F%N:0!/9'-T<F%N:2!T
M;R!V;WIL:;GH92!I>B!D;VMU;65N=&$`3V1S=')A;FD@=7!O<F%B;FEK80!/
M9'-T<F%N:2!U<&]R86)N:6MA.B`E<P!.82!Z86AT979O(&YI(&)I;&\@;6]G
M;^AE(&]D9V]V;W)I=&DN($YA<&%K83H@`%!O;F%S=&%V:0!0;VYA<W1A=FD@
M9V5S;&\`4&]N87-T879I=&4@=F&Y92!G97-L;P!297IU;'1A=&D`3F%Z86H@
M;F$@36^^;F]S=&D`4F5U;FEO;@!/8FYO=FD@<')E:KEN:F4@;F%S=&%V:71V
M90!-;[YN;W-T:2!U<F5J979A;&YI:V$@;V)O9V%T96YE9V$@8F5S961I;&$`
M56=A;FME`$1E<VYO`$1E<VYA(&=L879A`$1E<VYE('9R961N;W-T:0!,87-?
M=&YO<W1I('9R<W1I8V4`5FQO9V$`4F]M=6YI:F$`6F%S=>AI('IA(#$X,`!:
M87-UZ&D@;&5V;P!:87-UZ&D@9&5S;F\`3&%S=&YO<W1I('9R<W1I8V4`3&%S
M=&YO<W1I('9R<W1I8V4`5G)S=&EC93H`R')T90#(<G1E(&)O9&\@<')I:V%Z
M86YE(&UE9"!V<V5M:2!V<G-T:6-A;6D@:6X@<W1O;'!C:0#(<G1E(&)O9&\@
M<')I:V%Z86YE('-A;6\@;65D('-T;VQP8VD`R')T92!B;V1O('!R:6MA>F%N
M92!S86UO(&UE9"!V<G-T:6-A;6D`4&^^96YI`%)U<VEJ80!2=6%N9&$`4R]-
M24U%(&MR:7!T;V=R869S:VD@<&]D<&ES`%,O34E-12"Y:69R:7)A;F\@<W!O
M<F_H:6QO`%-!4TP@;W9E<FIA;FIE(&YI(&YA('9O;&IO+@!335,@<W!O<F_H
M86YJ90!344P@;'5P:6YA`%-32`!54U!%3$\`4U]13"!L=7!I;F$`4V\`4W8N
M($AE;&5N80!386EN="!+:71T<R!I;B!.979I<P!386EN="!,=6-I80!386EN
M="!0:65R<F4@:6X@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!I;B!'<F5N861I
M;F4`27-T:2!O:W9I<B`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O
M;64@:6X@4')I;F-I<&4`4&]N=61N:6L@<V%T96QI='-K96=A(&1O<W1O<&$`
M4V%U9&]V82!!<F%B:6IA`%-H<F%N:0!3:')A;FD@)7,`4VAR86YI(&UOOFYO
M<W1I`%-H<F%N:2!G96YE<FER86YO(&MO;F9I9W5R86-I:F\@:V]T(%!(4"!S
M:W)I<'1O('8@>F'H87-N;R!M87!O(&YA('9AN65M('-T<F6^;FEK=2X`2V]N
M9FEG=7)A8VEJ82`E<R!S:')A;FIE;F$N`%IN86YO<W0`27-K86YJ90!)<VMA
M;&YA(&]R;V1J80!)>F)E<FET92!D871O=&5K90!)>F)E<FET92!D871U;0!)
M>F)E<FET92!S:W5P:6YO(&MI(&IO(+YE;&ET92!D;V1A=&D`27IB97)I=&4@
M;F]V96=A(&QA<W1N:6MA`$EZ8F5R:71E('-T<F6^;FEK`$EZ8F5R:71E('5P
M;W)A8FYI:V$@:VD@9V$@OF5L:71E(&1O9&%T:0!)>F)E<FD@=G-E(&1A='5M
M<VME(&MO;7!O;F5N=&4N`$EZ8F5R:2!O8FIE:W0`27IB97)I=&4@>FYA:V4L
M(&MI(&II:"!P;W1R96)U:F5T92!I>B!S<&]D;FII:"!P;VQJ+B!.871O(&II
M:"!L86AK;R!K;W!I<F%T92!I;B!P<FEL97!I=&4@:7H@;V)R87IC82X`27IB
M97)I(')A>FUE:FET978@>F$@9&%T=6TZ`$EZ8F5R:2!O8FQI:V\@>F%P:7-A
M(&1A='5M83H`27IB97)I=&4@:61E;G1I=&5T;RP@:VD@:F\@OF5L:71E('-P
M<F5M96YI=&DZ`$EZ8F5R:71E(')A>FUE:FET978@>F$@Z&%S.@!)>F)E<FET
M92!O8FQI:V\@>F%P:7-A('IA(.AA<SH`27IB97)I=&4@9'9E('5J96UA:F'H
M:2!P;VQJ:2X`27IB97)I=&4@<W9O:F\@8F%R=FYO('-H96UO+@!)>F)E<FET
M92"^96QJ96X@:F5Z:6LZ`%!ON6QJ:2!P;W)OZ&EL;R!O(&YA<&%K:0!0;[EL
M:FD@4TU3`%-E;F5G86P`4V5N>F]R.B``4V5P=&5M8F5R`%-R8FEJ82!I;B#(
M<FYA($=O<F$`4V5R:6IS:V$@N71E=FEL:V$`240@<V5J92!J92!P;W1E:VQA
M+@!.87-T879I`$YA<W1A=FD@;6^^;F]S=&D@>F$@<&]N87-T879I=&5V(&=E
M<VQA+"!V('!R:6UE<G4@9&$@9V$@<&]Z86)I=&4N`$YA<W1A=FD@;V1D86QJ
M96YE('-T<F6^;FEK92P@9&\@:V%T97)I:""^96QI=&4@9&]S=&]P871I(',@
M<&]R=&%L82X`3F%S=&%V:2"^96QJ96X@:F5Z:6LL(.AA<V]V;FD@<&%S(&EN
M('!R:6MA>B!D871U;6$N`$YA<W1A=FD@>F'H971N;R!A<&QI:V%C:6IO+"!B
M87)V;F\@<VAE;6\L(&]S=F6^979A;FIE('-T<F%N:2P@:6X@;W-T86QE(&UO
MOFYO<W1I('!R:6MA>F$N`$YA;65S=&ET978@<VMR:7!T('IA('!O<V]D;V)I
M=&5V(&IE(&YA('9O;&IO`%!O9&%N:6T@<&%R86UE=')O;2!U<W1R97IA('9E
MZ"!L;VMA8VEJ.B``4V5JN65L:0!.86MU<&]V86YJ90!+<F%T96L@<&]V>F5T
M96L`3F%S=&%V:6T@8FQIOFYJ:6-E('IA('9EZ&EN;R!P;W9E>F%V/P!0<FEK
M8;YI`%!R:6MAOFD@<F%Z;&EK92!M960@=')E;G5T;F\@<VAR86YJ96YO(&EN
M(&YO=F\@9V5N97)I<F%N;R!K;VYF:6=U<F%C:6IO+@!0<FEK8;YE;2#H87,@
M>F%D;FIE('!R:6IA=F4@;V(@<')I:F%V;&IA;FIU/P!0<FEK8;YI(&UOOFYO
M<W0@>F$@;VAR86YI=&5V(&]R:6=I;F%L80!0;VMAOFD@;W)O9&IE('IA(&EZ
M8FER;P!0<FEK8;YE;2!M96YU('IA('5R96IA;FIE('1A8F5L93\`4')I:V&^
M96T@)7,@365N=2!N82!L979I/P!0<FEK8;YI('!O9V]V;W)N;R!O:VYO($QA
M<W1N;W-T:2!C96QI8V4@=&%B96QE`%!R:6MAOFD@<&]G;W9O<FYO(&]K;F\@
M3&%S=&YO<W1I('1A8F5L90!0<FEK8;YI('!O9V]V;W)N;R!O:VYO($QA<W1N
M;W-T:2!V<G-T:6-E('1A8F5L90!0<FEK8;YI('!O9V]V;W)N;R!O:VYO($QA
M<W1N;W-T:2!S;&EK90!0<FEK8;YI('-H<F%N:F5V86YJ92!N82!S=')EOFYI
M:P!0;&]H90!0;&]H92!Z9V]D86H`4&QO:&4@<&]Z;F\`4VMRZ&D`3F%J<')E
M:B!S:W+H:2!A;&D@;V1M86MN:2!S;W-E9&YJ92!B;&]K90!3:65R<F$@3&5O
M;F4`4')I:F%V80!0;V1P:7,`06QG;W)I=&5M('!O9'!I<V$`4VEN9V%P=7(`
M5F5L:6MO<W0`4')E<VMOZ&D@=GID<KYE=F%N:F4`4VQO=F&Y:V$`4VQO=F5N
M:6IA`%-N96<`4VYEOFYA('!L;VAA`%-N9;YN92!P;&]H90!3;F6^;F4@<&QO
M:&4@<&]Z;F\`1&5B96QI;F$@<VYEOFYE(&]D96IE.B``16YA:V$@:V]L:>AI
M;F$@=F]D93H@`%-A;&]M;VYO=FD@;W1O:VD`4V]M86QI:F$`4&5S;6D@)B!0
M;V5Z:6IA`%)A>G9R<W1I(&EZ8G)A;F\`27IV;W)N:2!N87-L;W8`2G6^;F$@
M069R:6MA`$IUOFYO($5V<F]P<VMO("A)4T\M.#@U.2TS*0!*=;YN82!'96]R
M9VEA(&EN($IUOFYI(%-A;F1W:6-H(&]T;VMI`$IUOFYA('!O;&]B;&$`4')O
M<W1O<B!M960@<V]S961N:FEM82!C96QI8V%M80!0<F]S=&]R(&UE9"!V<V5B
M:6YO(&EN(')O8F]M(&-E;&EC90!0<F5S;&5D;FEK`%)A>FUA:P!287IM86MI
M(&EN(&]D;6EK:0"I<&%N:6IA`%-P86T`5FYO<R!P;W-E8FYI:"!Z;F%K;W8`
M4F%Z9&5L:2!C96QI8V\`4F%Z9&5L:2!S=&]L<&5C`%)A>F1E;&D@=G)S=&EC
M;P"I<&]R=`"I<FEL86YK80!3=&%N9&%R9`!:=F5Z9&YE('-T97IE`$QE=&\@
M>F'H971K80!$<KYA=F$@86QI('!R;W9I;F-A`%-T86YJ90!/8FQI:V$@<VAR
M86YJ979A;FIA`$YA<VQO=@!0<F7H<G1A;F\`4V5Z;F%M(&)E<V5D:6QA`$]D
M<W1R86YI(&1O;65N;R!I>B!N87-L;W9A`%-T:6P@6T-34UT`3F4`6F%D979A
M`%!ON6QJ:0!0;V1P:7-A;F\`57-P9;EN;P!5<W!EN6YO('!O=G)N:6P@;F%S
M=&%V:71V92X@4&]N;W9N;R!N86QOOFET92!S=')A;BX`57-P9;EN;R!S:')A
M;FEL('9A<FYO<W1N;R!K;W!I:F\@:V]N9FEG=7)A8VEJ92X`57-P9;EN;R!Z
M87!I<V%L("5S`%-U9&%N`%!O=GIE=&5K`%-O;NAN:2!V>FAO9`!3;V[H;FD@
M>F%H;V0`4V]NZ&YO`%-O;NAN:2!V>FAO9`!3;V[H;FD@=GIH;V0O>F%H;V0`
M4V]NZ&YI('9Z:&]D.B``4V]NZ&YI('IA:&]D`%-O;NAN:2!Z86AO9#H`3F%D
M<&ES86YO`%!O9'!O<F$`4W5R:6YA;0!0<FEI;65K`%-V86QB87)D(&EN($IA
M;B!-87EE;@!3=F%Z:0"I=F5D<VMA`*EV:6-A`$YA<&'H;F$@<VEN=&%K<V$@
M:7-K86YI:"!P;VIM;W8`4VER:6IS:V$@07)A8G-K82!297!U8FQI:V$`3F5V
M:6AT80!.979I:'1E`%135B!D871O=&5K80!486)E;&$`3&%S=&YO<W1I('1A
M8F5L90!,87-T;F]S=&D@=&%B96QE`%1A:G9A;@!486IV86XL($MI=&%J<VMA
M('!R;W9I;F-A`%1A9+YI:VES=&%N`%1A;GIA;FEJ80!#:6QJ.@!/<')A=FEL
M80!496QE9F]N<VMA(+ET979I;&MA`%1E;65R871U<F$@>F%D;FIO('5R;SH@
M`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``57!R879L:F%N:F4@<')E9&QO
M9P!"97-E9&EL;P!386UO(&)E<V5D:6\`4&]R879N879A(&)E<V5D:6QA`%9R
M:"!B97-E9&EL80#(90!486IS:V\@*%1)4RTV,C`I`%1A:G-K80!(=F%L82!Z
M82!U<&]R86)O('-I<W1E;6$N`$944"!D;V1A=&5K(&YI(&YA('9O;&IO+@!(
M;W)D92]+;VQA8B!I;G1E9W)A8VEJ82!N92!P;V1P:7)A("(E<R(`4F%Z<F5D
M($UA:6YT96YA;F-E.CH@<V4@;FD@=7-P9;EN;R!N86QOOFEL`$]K;F\@;6^^
M;F]S=&D@<V4@:F4@>F%P<FQO+B!:87!I<F%M+@!3:W)B;FEK(&UO<F$@;F%M
M97-T:71I('-T86QN;R!H<F)T96YI8V\@>F$@9&]D96QJ979A;FIE('!R879I
M8RP@Z&4@OF5L:71E('5P;W)A8FQJ871I(%!R879I8V4N`%-A;6\@<W!O9&YJ
M82!S=')A;@!)1""Y=&5V:6QK82!S=&EK82!N:2!B:6QA('!O9&%N82P@<'6Y
MZ&5N82!P<F%Z;F$@86QI(&YI(&)I;&$@;F%J9&5N82!V(&)A>FD@<&]D871K
M;W8N`%-T:6L@:F4@8FEL('5S<&6Y;F\@9&]D86X@=B!V8;D@861R97-A<BX`
M3V1D=F]J96X@4$=0('!O9'!I<VYI(&)L;VL@:F4@<&]T<F5B96X@>F$@879T
M96YT:6MA8VEJ;R!P;V1P:7-A;F5G82!S<&]R;^AI;&$N`$E$(+ET979I;&MA
M('-E>FYA;6$@<F%Z9&5L:71V92!N:2!B:6QA('!O9&%N82P@<'6YZ&5N82!P
M<F%Z;F$@86QI(&YI(&)I;&$@;F%J9&5N82!V(&)A>FD@<&]D871K;W8N`%-E
M>FYA;2!R87ID96QI='9E(&YI(&)I;"!P;V1A;BX`36^^;F]S=&D@N6EF<FER
M86YJ82!Z86AT979A:F\@=F%R;F\@<W!L971N;R!P;W9E>F%V;RX`1&%T;W1E
M:V$@)7,@8FD@;6]R86QA('9S96)O=F%T:2!N87-T879I=&5V("5S+@!$871O
M=&5K82`E<R!B:2!M;W)A;&$@=G-E8F]V871I(&YA<W1A=FET=F4@)7,N`$1A
M=&]T96ME(&YI(&UO9V_H92!P<F5S;F5T:2!S86UE('9A<V4N`$1A=&]T96MA
M(&YE('9S96)U:F4@<&]D871K;W8N`%-L961I(&=L879A('IA('1O('-P;W)O
MZ&EL;R]R9F,X,C(@<W!O<F_H:6QO`$YAZ&EN(&1E;&]V86YJ82#H97H@8V5L
M('IA<VQO;B!L86AK;R!P;W9Z<F_H:2!P<F]B;&5M92!V(&1E;&]V86YJ=2!)
M;G1E<FYE="!%>'!L;W)E<FIA('IA<F%D:2!H<F^YZ&5V(&)R<VMA;&YI:V$L
M(&MI('-E(&II;2!N:7-M;R!U<W!E;&D@;V=N:71I+B!/<&%Z:71E(&QA:&MO
M(.AU9&5N('!R:6MA>BP@;6%N:FMA:F_H92!M;[YN;W-T:2!U<F5J979A;&YI
M:V$@:6XO86QI(&YA:VQJ=>AN82!S97-U=&IA(&)R<VMA;&YI:V$N(,AE('5P
M;W)A8FQJ871E(%=I;F1O=W,@.7@L(&)O(&YA<&%K82!V97)J971N;R`G1V5N
M97)A;"!0<F]T96-T:6]N($9A=6QT)R!K:2!B;R!Z86AT979A;&$@<&]N;W9N
M:2!Z86=O;BY<;EQN0FEL:2!S=&4@;W!O>F]R:F5N:2X@4')O<VEM(&EZ8F5R
M:71E($]+(.AE(+EE('9E9&YO(+YE;&ET92!P;W-K=7-I=&D@=7!O<F%B;&IA
M=&D@8V5L;WIA<VQO;G-K:2!U<F5J979A;&YI:RX`261E;G1I=&5T82`B)7,B
M(&IE(&)I;&$@:7IB<FES86YA+@!386UO(&QE=F$@<W1R86X`4F%Z<F5D=2!#
M<GEP=%]P9W`Z.B!M;W)A(&)I=&D@<&]D86YA('!O="!D;R!';G501R!I>G9R
MN6EL;F4@9&%T;W1E:V4N`%-P;W)OZ&EL;R!P;W-L86YO("5S('IA("5S('H@
M>F%D979O("(E<R(@:F4@8FEL;R!P<FEK87IA;F\N"E1O(&YI('IA9V]T;W9I
M;&\L(&1A(&IE(&)I;&\@<W!O<F_H:6QO('!R96)R86YO(&%L:2!R87IU;6QJ
M96YO+@!);64L('5P;W)A8FQJ96YO('!R:2!P;W9E>F]V86YJ=2!N82!S=')A
M;B!Z82!S97-T879L:F%N:F4`4F%Z<F5D($AO<F1E7T-R>7!T7W-M:6UE.CH@
M>F%H=&5V82!M;V1U;"!O<&5N<W-L+@!.87-T879I='9E("(E<R(@;FD@8FEL
M;R!M;V=OZ&4@<VAR86YI=&DL(&ME<B!P<F5S96=A(&UA:W-I;6%L;F\@9&]V
M;VQJ96YO('9E;&EK;W-T`%!R;V=R86TL(&MI('-E('5P;W)A8FQJ82!Z82!P
M<FEK87H@=&4@=G)S=&4@<&]D871K;W8@*"5S*2!N:2!B:6P@;F%J9&5N+@!3
M86UO(&1E<VYE(&EN(&QE=F4@<W1R86YI`%-A;6\@9&5S;F$@<W1R86X`4W1R
M9;YN:6L@(B5S(B!J92!B:6P@:7IB<FES86XN`%-T<F6^;FEK("(E<R(@:F4@
M8FEL('-H<F%N:F5N+@!:86AT979A('IA('!R:6IA=F\@)7,@:F4@8FEL82!O
M9'-T<F%N:F5N82X`26UE;F]V86YA('9R<W1I8V$@;F4@;V)S=&%J82X`4V%M
M;R!Z9V]R;FIA(&EN('-P;V1N:F$@<W1R86YI8V$`4V%M;R!Z9V]R;FIA('-T
M<F%N:6-A`%!O9&%T:VD@<&]S;F5T:2!N82!S=')EOFYI:R!S;R!S92!O9"!P
M<F5JN6YJ96=A(&MO<F%K82!I>F=U8FEL:2X`4&]S;F5T92!D871O=&5K92!N
M:2!B:6QO(&UO9V_H92!S:')A;FET:2X`0FQO:R!W96%T:&5R+F-O;2!N:2!N
M82!V;VQJ;RX`3F]B96YA(&UOOFYO<W0@;FES;R!N82!V;VQJ;RX`3F]B96YE
M9V$@9&5L82!S<&]R;^AI;&$@;FD@;6]G;^AE('!R:6MA>F%T:2!Z;F]T<F%J
M('1E9V$@;VMN82X`4&]L:F4@=G-E8G5J92!P<F5V9>@@>FYA:V]V+B!6;F5S
M;&D@<W1E("5S('IN86MO=CL@=FYE<W1I(&II:"!M;W)A=&4@;6%N:B!K;W0@
M)7,N`%!R:2!S;F5M86YJ=2!D871O=&5K92!N82!S=')EOFYI:R!J92!P<FFY
M;&\@9&\@;F%P86ME.B`E<R!N:2!S:')A;FIE;BX`4')I('-N96UA;FIU(&1A
M=&]T96ME(&YA('-T<F6^;FEK(&IE('!R:;EL;R!D;R!N87!A:V4Z("5S(&IE
M('9EZ&IA(&]D(&YA:G9EZ&IE(&1O=F]L:F5N92!V96QI:V]S=&D@*"5D(&)Y
M=&]V*2X`4')I('-N96UA;FIU(&1A=&]T96ME(&YA('-T<F6^;FEK(&IE('!R
M:;EL;R!D;R!N87!A:V4Z("5S(&IE('!O<VYE="!S86UO(&1E;&YO+@!0<FD@
M<')I:V%Z;W9A;FIU('1E9V$@9&5L82!S<&]R;^AI;&$@:F4@<')IN6QO(&1O
M(&YA<&%K90!0<FD@=79AOF%N:G4@<&]D871K;W8@;R!S=&EK=2!J92!P<FFY
M;&\@9&\@;F%P86ME+@!0<FD@=79AOF%N:G4@<&]D871K;W8@:4-A;&5N9&%R
M(&IE('!R:;EL;R!D;R!N87!A:V4N`$1O(&YA<&%K92!J92!P<FFY;&\@=B!O
M8G)A>F-U('IA(&MO;F9I9W5R86-I:F\N($UO9V_H92!S=&4@<'5S=&EL:2!P
M<F%Z;F\@>F%H=&5V86YO('!O;&IE+@!0<FFY;&\@:F4@9&\@;F%P86ME('!R
M:2!I>G9A:F%N:G4@>F%H=&5V86YE(&9U;FMC:6IE(&%D<F5S87)J82X@4')O
M<VEM('!O<VMU<VET92!P;VYO=FYO(&MA<VYE:F4N`%!R:;EL;R!J92!D;R!N
M87!A:V4@<')I(&]S=F6^979A;FIU('!O9')O8FYO<W1I(&\@<W1I:W4N(%!O
M<VMU<VET92!K87-N96IE+@!0<FFY;&\@:F4@9&\@;F%P86ME('!R:2!O<W9E
MOF5V86YJ=2!S97IN86UA(')A>F1E;&ET=F4N(%!O<VMU<VET92!K87-N96IE
M+@!482!)34%0('-T<F6^;FEK(&YE('!O9'!I<F$@<VMU<&YE(')A8F4@;F%B
M:7)A;&YI:V]V+@!$871O=&5K82!V97)J971N;R!N:2!V96QJ879E;B!R87(@
M87)H:78N`$1A=&]T96MA('9E<FIE=&YO(&YI('9E;&IA=F5N('II<"!A<FAI
M=BX`5G!I<V%N82"Y=&5V:6QK82!N:2!V96QJ879N82"Y=&5V:6QK82!K<F5D
M:71N92!K87)T:6-E+@!482!G;VYI;&YI:R!O;6]G;^AA('!ON6EL:F%N:F4@
M<W!O<F_H:6P@<')E:V\@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN
M8V]M*2!P<F5H;V1A('H@=7!O<F%B;R!(5%10($%020!482!G;VYI;&YI:R!O
M;6]G;^AA('!ON6EL:F%N:F4@<W!O<F_H:6P@<')E:V\@<VUS,F5M86EL("AH
M='1P.B\O<VUS,F5M86EL+F-O;2D@<')E:&]D82!Z('5P;W)A8F\@2%144"!!
M4$D`5&$@9V]N:6QN:6L@;VUO9V_H82!P;[EI;&IA;FIE('-P;W)OZ&EL('!R
M96MO(%--5%`@<')E:&]D82!6;V1A9F]N92!)=&%L:6IA<V%M;R!6;V1A9F]N
M92"Y=&5V:6QK86TN(%IA:'1E=F%N(&IE(&]B<W1O:F7H(&4M<&^Y=&YI(&YA
M<VQO=B!P<FD@5F]D869O;F4@271A;&EJ82`H:'1T<#HO+W=W=RXQ.3`N:70I
M+@!4;R!P;VQJ92!J92!O8G9E>FYO+@!4;R!P;VQJ92!L86AK;R!V<V5B=6IE
M('-A;6\@N71E=FEL:V4N`%1O('!O;&IE(&QA:&MO('9S96)U:F4@<V%M;R"Y
M=&5V:6QK92!I;B!D=F]P:>AJ92X`5&\@<&]L:F4@;&%H:V\@=G-E8G5J92!S
M86UO(&]K=&%L;F4@=G)E9&YO<W1I+@!4;R!P;VQJ92!M;W)A('9S96)O=F%T
M:2!S97IN86T@N71E=FEL(&QOZ&5N('H@9'9O<&GH:FD@86QI('!R97-L961K
M:0!4;R!P;VQJ92!M;W)A('9S96)O=F%T:2!V96QJ879N;R"Y=&5V:6QK;RX`
M5&\@<&]L:F4@;6]R82!V<V5B;W9A=&D@:V]D;R!B87)V92!V(&]B;&EK:2!2
M1T(@2&5X+"!N87!R:6UE<B`G(S$R,S1A9B<N`%1A(&]B<F%Z96,@:F4@8FEL
M(+YE(&]B9&5L86XN`%1O(&IE("5S+@!482!O8FIE:W0@:F4@:7H@2V]L86(@
M1W)O=7!W87)E+B#(92!G82"^96QI=&4@<')I:V%Z871I+"!P;W1R96)U:F5T
M92!P<F]G<F%M>F$@92UP;[ET;RP@:VD@<&]Z;F$@9F]R;6%T($MO;&%B($=R
M;W5P=V%R92X@6F$@<V5Z;F%M('!R;V=R86UO=B!O8FFYZ&ET92`E<P!4;R!S
M<&]R;^AI;&\@:F4@8FEL;R!N87!I<V%N;R!V(&1R=6=I(&MO9&YI('1A8F5L
M:2`H)7,I(&MO="!J92!V8;EA+@!4;R"Y=&5V:6QO(&UO<F$@8FET:2!V<V%J
M(&5N82X`5&$@<W1R9;YN:6L@;F4@;6]R92!O9&MO;7!R97-I<F%T:2!Z:7`@
M:6X@9WII<"!D871O=&5K+@!3:7-T96T@:F4@=')E;G5T;F\@9&5A:W1I=FER
M86XN`%1A('9R961N;W-T(&UO<F$@8FET:2"Y=&5V:6QO+@!4;R!O:VYO(&IE
M('!O=')E8FYO(&]D<')E=&D@:7H@;VMN82!-;[YN;W-T:0!3=')E;&$`5G-T
M;W!N:6-E`,AA<P!3;&5D96YJ92#H87-A`$]B;&EK82!Z87!I<V$@Z&%S80!)
M>F)I<F$@Z&%S80!4:6UO<BU,97-T90!.87-L;W8`3F%S;&]V("AO:W9I<NAE
M:RDZ`%IA`%IA(&EZ8FER;R!V9>AI:"!M;[YN;W-T:2P@9'*^:71E('1I<&MO
M($-O;G1R;VP@*%!#*2!A;&D@0V]M;6%N9"`H36%C*2!M960@:VQI:V%N:F5M
M(&YA(+YE;&IE;F4@;6^^;F]S=&DN`$1A;F5S`%!R:6MAOFD@2%1-3"!I>G9O
M<FYO(&MO9&\`5&]G;P!4;VME;&%U`$IU=')I`%1O;F=A`%IG;W)A:@!:9V]R
M;FII(&]K=FER("A?=&]P*0!0<F5V;V1I`%1R:6YI9&%D(&EN(%1O8F%G;P!$
M<KYI(&%L:2!N92!D<KYI`%1O`%1U;FEZ:6IA`%1U<NAI:F$`5'5RN6MO("A)
M4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@:6X@0V%I8V]S(&]T;VMI
M`%1U=F%L:0!6<&FY:71E(&EZ8FER;SH@`%4N5BX@:6YD96MS.B``55),`%52
M3"!Z82!D;W-T879O('-T871U<V$@<VMR:7!T90!54DPZ`%5G86YD80!5:W)A
M:FEN80!$;W-T;W`@9&\@5D93(&UA<&4@;FD@;6]G;^@N`%!R:2!P<FEJ879L
M:F%N:G4@;FD@;6]G;^AE(&1O9&%T:2!D;V1A=&YI:"!I;F9O<FUA8VEJ(&\@
M=7!O<F%B;FEK=2X`3FD@;6]G;^AE('-P<F5M96YI=&D@<')A=FEC('IA(%9&
M4R!D871O=&5K;R`B)7,B+@!.:2!M;V=OZ&4@<W!R96UE;FET:2!P<F%V:6,@
M>F$@5D93(&1A=&]T96MO("5S+R5S+@`E<R!N:2!M;V=OZ&4@<W!R96UE;FET
M:2X`4&]V97IA=F$@;F$@4U%,('-T<F6^;FEK(&YI(&UO9V_H82X`4&]V97IA
M=F$@<R!34TP@;FD@;6]G;^AA+@!+;W!I<F%N:F4@5D93(&1A=&]T96ME(&YI
M(&UO9V_H92X`27ID96QA=F$@5D93(&UA<&4@(B5S(B!N:2!M;V=OZ&$N`$EZ
M9&5L879A(%9&4R!M87!E(&YI(&UO9V_H82X`27ID96QA=F$@5D93(&1A=&]T
M96ME(&YI(&UO9V_H82X`27ID96QA=F$@<')A>FYE(%9&4R!D871O=&5K92!N
M:2!M;V=OZ&$N`%!O9&%T:V]V(&YI(&UO9V_H92!O9&MO;7!R97-I<F%T:2X`
M(B5S(B!N:2!M;V=OZ&4@<&]B<FES871I+"!M87!A(&YI('!R87IN82X`)7,@
M;FD@;6]G;^AE('!O8G)I<V%T:2P@;6%P82!N:2!P<F%Z;F$`5D93(&UA<&4@
M;FD@;6]G;^AE(')E:W5R>FEV;F\@<&]B<FES871I+@!61E,@;6%P92!N:2!M
M;V=OZ&4@<&]B<FES871I+@!61E,@;6%P92!N:2!M;V=OZ&4@<&]B<FES871I
M.B`E<RX`5D93(&1A=&]T96ME(&YI(&UO9V_H92!P;V)R:7-A=&D@(B5S(BX`
M5D93(&1A=&]T96ME(&YI(&UO9V_H92!P;V)R:7-A=&DN`%9&4R!N:2!M;V=O
MZ&4@<F5K=7)Z:79N;R!P;V)R:7-A=&DZ("5S+@!4<F5N=71N92!M87!E(&YI
M(&)I;&\@;6]G;^AE('5G;W1O=FET:2X`4&]D<F]B;F]S=&D@;R!P;W1R9&EL
M=2!N:2!B:6QO(&UO9V_H92!I>G9L9>AI+@!$969I;FEC:6IE("5S(&YI(&UO
M9V_H92!N86QOOFET:2X`5D93(&1A=&]T96ME(&YI(&UO9V_H92!P<F5M86MN
M:71I+@!61E,@9&%T;W1E:V4@(B5S(B!N:2!M;V=OZ&4@;V1P<F5T:2X`5D93
M(&1A=&]T96ME(&YI(&UO9V_H92!O9'!R971I('IA(&)R86YJ92X`5D93(&1A
M=&]T96ME(&YI(&UO9V_H92!O9'!R971I+@!+;VUP<F5S:7)A;F5G82!A<FAI
M=F$@;FD@;6]G;^AE(&]D<')E=&DN`'9F<W)O;W0@;6%P92!N:2!M;V=OZ&4@
M<')E8G)A=&DN`"5S(&YI(&UO9V_H92!P<F5I;65N;W9A=&D@=B`E<SH@;6%P
M82"^92!O8G-T86IA`%9&4R!M87!E(&YI(&UO9V_H92!P<F5I;65N;W9A=&DN
M`%9&4R!M87!E(&YI(&UO9V_H92!P<F5I;65N;W9A=&DZ("5S+@!61E,@9&%T
M;W1E:V4@(B5S(B!N:2!M;V=OZ&4@<')E:6UE;F]V871I+@!61E,@9&%T;W1E
M:V4@)7,O)7,@;F\@;6]G;^AE('!R96EM96YO=F%T:2X`5D93(&1A=&]T96ME
M(&YI(&UO9V_H92!P<F5I;65N;W9A=&DN`%5K87IA("=M:VES;V9S)R!N:2!M
M;V=OZ&4@>F%G;F%T:2X`5V]R9&]V92!D871O=&5K92!N:2!M;V=OZ&4@<')E
M=F5S=&DN`%9&4R!D871O=&5K92`B)7,B(&YI(&UO9V_H92!Z87!I<V%T:2X`
M5D93(&1A=&]T96ME(&YI(&UO9V_H92!Z87!I<V%T:2`H=6MA>B!C;W!Y*"D@
M:F4@<W!O9&QE=&5L*2X`4&]D871K;W8@;R!61E,@9&%T;W1E:VD@;FD@;6]G
M;^AE('IA<&ES871I+@!0;V3H<G1A;F\`4F%Z=F5L:F%V:2!S<')E;65M8F4`
M4F%Z=F5L:F%V:2!Z861N:F4@9&5J86YJ90!.97!R:>AA:V]V86X@;V1Z:78@
M<W1R9;YN:6MA(&]B('!O=F5Z879I.B``3F5P<FGH86MO=F%N(&]D>FEV('-T
M<F6^;FEK82!N83H@`$YE;F%P;VQN:F5N;P!5;FEC;V1E("A55$8M."D`6F1R
M=;YE;FD@07)A8G-K:2!%;6ER871I`%ID<G6^96YO(&MR86QJ97-T=F\`6F1R
M=;YE;F4@9'*^879E`%ID<G6^96YE(&1ROF%V92`M(&UA;FJY:2!I>G9E;BUL
M9;YEZ&D@;W1O:VD`16YO=&4`3F5Z;F%N`$YE>FYA;B!A<&EM<V=I9"`H240@
M05!)('-P;W)OZ&EL82DN`$YE>FYA;B!C;&EM<V=I9"`H240@;V1J96UA;.AE
M=F5G82!S<&]R;^AI;&$I+@!.97IN86YO('5P;W)A8FYIN6MO(&EM92!A;&D@
M9V5S;&\N`$]D<W1R86YI('!O=F5Z879O('1R96YU=&YE9V$@96QE;65N=&$`
M3F5I;65N;W9A;@!3:W)I<'1E(&)R97H@<')A=FEC(&YE(&UO<F%J;R!U<&]R
M86)L:F%T:2!U:V%Z;W8@27IR9;YI+TMO<&ER86HO4')I;&5P:2!I>B!V87)N
M;W-T;FEH(')A>FQO9V]V+B!+;&EK;FET92!/2R!Z82!T96AN:>AN;R!R87IL
M86=O(&YA(&UO>FEL;&$N;W)G(&MI('!O;F%Z87)J82P@:V%K;R!O;6]G;^AI
M=&D@<VMR:7!T:2!D;W-T;W`@9&\@;V1L;[YIN>AA+@!.96YA<W1A=FQJ96YA
M(&)A<G9A`$YE<&]D<')T(&1O9&%T96L`4&]S;V1O8FD`4&]S;V1O8FD@)7,`
M4&]S;V1O8FD@=7!O<F%B;FEK80!3:W)I<'1A('IA(&YA9&=R861N:F\@<&]B
M<FES86YA+@!3:')A;FD@;F$@<W1R9;YN:6L`5G-E(&YA;65S=&ET=F5N92!D
M871O=&5K92!S:')A;FIE;F4@;F$@<W1R9;YN:6LN`%9E;&EK92!L871I;G-K
M92#H<FME`%9E;&EK92!R:6US:V4@N71E=FEL:V4`57)A9W9A:@!5<&]R86)I
M('1R96YU=&YO.B`E<P!5<&]R86)I(%-33`!5<&]R86)I(.AE('-E(&EM92]G
M97-L;R!R87IL:6MU:F5T82!Z82!)35-0('-T<F6^;FEK+@!5<&]R86)N:6L@
M)7,@;FD@<&]O8FQAN>AE;B!Z82`E<RX`061M:6YI<W1R86-I:F$@=7!O<F%B
M;FEK;W8`36^^;F]S=&D@=7!O<F%B;FEK;W8`4F5G:7-T<F%C:6IA('5P;W)A
M8FYI:V]V`%)E9VES=')A8VEJ82!U<&]R86)N:6MO=B!J92!Z82!T;R!S<&QE
M=&YO(&UE<W1O(&]N96UO9V_H96YA+@!5<&]R86)N:;EK;R!I;64`57!O<F%B
M;FFY:V\@:6UE.@!5<&]R86)N:;EK;R!I;64Z(`!5<&]R86)N:6MI('8@<VES
M=&5M=3H`57IB96MI<W1A;@!61E,@;6%P82!N92!O8G-T86IA+@!$;W!U<W0`
M57-T<F5Z;F4@;F%J9&5N92!L;VMA8VEJ92!V:VQJ=>AU:F5J;SH@`%9E;&IA
M=FYO<W0`5G)E9&YO<W0@=B!M:6YU=&%H(&]D('1E9V$@=')E;G5T:V$N`%9R
M961N;W-T:0!6<F5D;F]S=&D@>F$@:7IB:7)O`%9A;G5A='4`4W!R96UE;FQJ
M:79O`%9E;F5Z=65L80!/=F5R:F%N:F4@<W!O9&QE=&5L;R`M('-P;W)OZ&EL
M;R!J92!B:6QO('-P<F5M96YJ96YO+@!697)Z:6IA`$YA9'IO<B!V97)Z:6H`
M3F%V<&GH;F$@<&]R879N879A`$YA=G!IZ&5N(&]D;6EK`$YA=G!IZ&YO.@!:
M96QO('9I<V]K;P!6:65T;F%M`%9I971N86US:V\@*%9)4T-)22D`4')I:V&^
M:2`E<P!0<FEK8;YI('IU;F%N:F\@<W!L971N;R!S=')A;@!0<FEK8;YI(&MO
M="`E<P!"<FET86YS:VD@1&5V:;EK:2!O=&]K:0!!;65R:;EK:2!$979IN6MI
M(&]T;VMI`%9I9&QJ:79O<W0`5FED;&II=F]S=#H@`%9O9&%F;VYE($ET86QI
M:F$@<')E:V\@4TU44`!/4$]:3U))`$]03UI/4DE,3R$A(2!23\A.3R!/1%-4
M4D%.251%(%-+4DE05$\@25H@)7,N`%=A;&QI<R!I;B!&=71U;F$`3W!O>F]R
M:6QO`%-R`%9R96UE;G-K82!N87!O=F5D`%9R96UE;G-K;R!N87!O=F5D('!R
M:7-K<F)E;`!796%T:&5R+F-O;0!3<&QE=`!3<&QE=&YO(&UE<W1O`%1E9&5N
M<VMO`$1O8G)O9&^Y;&D`1&]B<F]D;[EL:2!V("5S`$1O8G)O9&^Y96PL("5S
M`%IA:&]D;F\@*$E33RTX.#4Y+3$I`%IA:&]D;F\@*$E33RTX.#4Y+3$U*0!:
M86AO9&YA(%-A:&%R80!+871E<F\@87!L:6MA8VEJ;R!N86H@)7,@<')I:V&^
M92!P;R!P<FEJ879I/P!+871E<FD@>FYA:R!R87IM96IU:F4@<&]L:F$_`$MA
M=&5R:2!Z;F%K(&IE('5P;W)A8FQJ96X@>F$@8VET:7)A;FIE/P!+871E<F4@
M;65N90!+871E<FD@<&QU9VEN:2T@;F%J(&)O9&\@;VUO9V_H96YI('IA('5R
M96IE=F%L;FEK(&]B;V=A=&5N96=A(&)E<V5D:6QA+@"I:7)I;F$`J6ER:6YA
M('8@0U-3(&5N;W1A:`"I:7)I;F$@)7,@;65N=6IA(&YA(&QE=FD@*'9E;&IA
M(&]B(&YA<VQE9&YJ:2!P<FEJ879I*3H`J6ER:6YA('1A8F5L90!%;F]T82"Y
M:7)I;F4`J6ER:6YA.@!7:6MI`%9E=&5R`$AI=')O<W0@=F5T<F$@=B!V;WIL
M:6@`5F5T97(Z`%9E=&5R.B``36]D<F]S=`!$96QO`%-L=;YB96YI(&YA<VQO
M=@!3;'6^8F5N:2!T96QE9F]N`%@M4F5F`%@U,#EV,R!/<VYO=FYE(&]M96II
M='9E`%@U,#EV,R!0;V1A;&JY86YA('5P;W)A8F$@:VQJ=>AA`%@U,#EV,R!!
M;'1E<FYA=&EV;F\@:6UE('-U8FIE:W1A`%@U,#EV,R!)9&5N=&EF:6MA8VEJ
M82!K;&IUZ&$@<W5B:F5K=&$`6#4P.78S(&1O9&%T:VD`3$P`3$Q,3`!986AO
M;R$@>F5M;&IE=FED`$QE=&YO`$IE;65N`$1A`$1A+"!S=')I;FIA;2!S90!3
M=&4@=B!"15-%1$E,3D5-($Y!R$E.52X@57!O<F%B:71E(%L\/ET@9W5M8B!Z
M82!P<F5K;&]P(&YA>F%J('8@5UE325=91RX`3FES=&4@8FEL:2!O=F5R:F5N
M:2X`5F&Y92!P;VQN;R!I;64@;F4@<VUE('9S96)O=F%T:2!Z;F%K82`G7"<N
M`$YI<W1E('9P:7-A;&D@=F5L:F%V;F5G82!N87-L;W9A(&4M<&^Y=&4N`$YI
M<W1E('!O=F5Z86QI(&YO8F5N96=A('!O;&IA(&EZ('5V;[YE;F4@9&%T;W1E
M:V4@>B!U<W1R97IN:6UI('!O;&II('8@)7,N`$]D:F%V:6QI('-T92!S92X`
M5G!I<V%T:2!M;W)A=&4@=F5L:F%V;F\@N71E=FEL:V\@;6]B:6QN96=A('1E
M;&5F;VYA("T@<V%M;R"Y=&5V:6QK92!Z(&]P8VEJ<VMI;2`G*R<@>F$@;65D
M;F%R;V1N;R!P<F5D<&]N;RX`5G!I<V%T:2!M;W)A=&4@=F5L:F%V;F\@=G)E
M9&YO<W0N`$1A=&%T<F5E(&UO<F%T92!K;VYF:6=U<FER871I('IA('5P;W)A
M8F\@4VEG;G5P<RX`5D93(&UO<F%T92!K;VYF:6=U<FER871I+@!0<F5D96X@
M<&^Y;&IE=&4@<&]R;^AI;&\@;R!N87!A:VDL(&UO<F%T92!N87!A:V\@;W!I
M<V%T:2X`5G!I<V%T:2!M;W)A=&4@55),(&MA;6]R(&YA:B!T82!P;W9E>F%V
M82!K8;YE`$EZ8G)A=&D@;6]R871E('-T<F6^;FEK+"!K:2!G82"^96QI=&4@
M:7IB<FES871I+@!.879E<W1I(&UO<F%T92!U<&]R86)N:;EK;R!I;64L(&MI
M(&=A(+YE;&ET92!P;^AI<W1I=&DN`$YA=F5S=&D@;6]R871E('5P;W)A8FYI
MN6MO(&EM92P@:VD@9V$@OF5L:71E(&]D<W1R86YI=&DN`$YA=F5S=&D@;6]R
M871E('5P;W)A8FYIN6MO(&EM92P@:VD@9V$@OF5L:71E(&1O9&%T:2X`3F%V
M97-T:2!M;W)A=&4@=7!O<F%B;FFY:V\@:6UE+"!K:2!G82"^96QI=&4@<&]S
M;V1O8FET:2X`3F%V97-T:2!M;W)A=&4@9&5J86YJ92P@:VD@;F%J('-E(&EZ
M=F5D92X`5G!I<V%T:2!M;W)A=&4@:6UE(&YO=F4@:V%T96=O<FEJ92X`5F&Y
M82`E<R!S96IA(&IE('!O=&5K;&$N(%!O;F]V;F\@<V4@<')I:F%V:71E+@!6
M8;EA(&4M<&^Y=&YI(&YA<VQO=@!68;D@3V0Z(&YA<VQO=CH`5F&Y:2!P;V1A
M=&MI`%9AN2!I;G1E<FYE=&YI(&YA<VQO=B!S92!J92!S<')E;65N:6P@;V0@
M>F'H971K82`E<R!S96IE+B!)>B!V87)N;W-T;FEH(')A>FQO9V]V('-E(&UO
M<F%T92!P;VYO=FYO('!R:6IA=FET:2X`5F&Y92!I;64`5F&Y82!H<F)T96YI
M8V$@>F$@;W9E<FIA;FIE(&YE('!O9'!I<F$@<')I:V%Z;W9A;FIA('5P;W)A
M8FYI:V]V+"!A;&D@<&$@:F4@8FEL82!T82!M;[YN;W-T(&EZ(&YE:V5G82!R
M87IL;V=A(&]N96UO9V_H96YA+@!68;D@8G)S:V%L;FEK('-E(&IE('-P<F5M
M96YI;"!O9"!Z8>AE=&MA('9AN64@)7,@<V5J92X@27H@=F%R;F]S=&YI:"!R
M87IL;V=O=B!S92!M;W)A=&4@<&]N;W9N;R!P<FEJ879I=&DN`%9AN2!B<G-K
M86QN:6L@;F4@<&]D<&ER82!T92!M;[YN;W-T:2X`5F&Y('1R96YU=&5N(.AA
M<V]V;FD@<&%S.@!68;EA('!R:79Z971A(&ED96YT:71E=&$Z`%9AN64@<&]L
M;F\@:6UE.@!68;EE(&YO=F\@9V5S;&\@>F$@)7,@:F4Z("5S`%9AN64@;F%S
M=&%V:71V92!S;R!B:6QE('!O<V]D;V)L:F5N92X`5F&Y92!G97-L;R!J92!B
M:6QO('!O;F%S=&%V;&IE;F\`5F&Y92!G97-L;R!J92!B:6QO('!O;F%S=&%V
M;&IE;F\N(%!O9VQE:G1E('9AN6\@92UP;[ET;R!I;B!S92!P<FEJ879I=&4@
M>B!N;W9I;2!G97-L;VTN`%9AN6D@;V1D86QJ96YI('-T<F6^;FEK:3H`2G5G
M;W-L879I:F$`6F%I<F4`6F%M8FEJ80!::6UB86)V90!::7!P:0!;4VMR:6H@
M8VET:7)A;F\@8F5S961I;&]=`%M0;W)OZ&EL;R!O(&YA<&%K:5T`6U!R:6MA
MOFD@8VET:7)A;F\@8F5S961I;&\@+0!;4')I:V&^:2!C:71I<F%N;R!B97-E
M9&EL;R`M("5S('9R<W1I8UT`6W9R<W1I8V$@)7,@;V0@)7-=`%]!9&UI;FES
M=')A8VEJ80!?0TQ)`%]$871A5')E90!?27IB<FFY:2!V<G-T:6-O`%]3:W5P
M:6YE`%]0;VUOZ`!?3&%S=&YO<W1I('-L:6ME+BXN`%]0<FEJ879A`%]/9&IA
M=F$`7U-P<F5M96YI('!O=F5Z879O+BXN`%]-;[YN;W-T:0!?4')A=FEC90!?
M3V1S=')A;FD@<&]V97IA=F\N+BX`7TYA;65S=&ET978`7TQA<W1N;W-T:2!T
M86)E;&4N+BX`7U5P;W)A8FYI:VD`861R97-A<@!K;VQE9&%R`&UI<FYO`&ML
M:6MN:71E('-E;0!P861A:F_H`&1A=&]T96MA`&]D("5S("@E<RD@<')I("5S
M("5S`'8Z`'1A:V]JN6YI`&YO=')A;FII`'9R<W1I8V5=`&UK:7-O9G,@;F%P
M86MA(+ET979I;&MA("5D(&UE9"!I>F1E;&%V;R!)4T\@<&]S;F5T:V$N`&EM
M90!N:2!I;7!L96UE;G1I<F%N`+EE(&YI(&EM<&QE;65N=&ER86X`8F5L9;YN
M:6-A`&]D<W1O=&5K`'!I>&QO=@!R87-T;^@`<&]K8;YI(')A>FQI:V4`<VUS
M,F5M86EL('!R96MO($A45%``;6ER;F\`<V5Z;F%M(&]P<F%V:6P`=G!IN6ET
M92!G97-L;R!D=F%K<F%T('IA('!O=')D:71E=@!Z9')UOF5N`&YE:6UE;F]V
M86X`:7IB:7)A('5P;W)A8FYI:V$`=D-A<F0`N3H`=V5A=&AE<BYC;VT`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S;%]3
M22]H96QP+GAM;```````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#,S,C``,3`T,3<S-C(W-S<`,#(P,S0W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_
M/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+W-L7U-)+VAE;'`N>&UL+'8@
M,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,3,@:F%N($5X<"`D("TM/@H\:&5L<#X*
M("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE
M(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A
M9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R
M=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO
M=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@
M>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L
M('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S
M96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H
M97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@
M=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE
M=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT
M(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT
M<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H
M92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S
M92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@
M87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB
M;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO
M=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE
M('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*
M("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T
M;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A
M:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA
M;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@
M=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C
M:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-
M86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L
M9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R
M92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE
M8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O
M(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@
M;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*/"]H96QP/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<W9?4T4O````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8R-S<W`#`Q-C<Q,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]S=E]312],0U]-15-304=%4R\`````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C(W-S<`,#(P-#<U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W-V7U-%+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0Q,S4T-@`Q,#0Q-S,V
M,C<W-P`P,C(Q-#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````#D!P``'````#P_``"%"@``7'X```````!PJ```
M2````'&H```.````NJ@```\```#)J```#````-FH```-````YJ@```@```#T
MJ```"P```/VH```,````":D```0````6J0``&````!NI```;````-*D``"T`
M``!0J0``'0```'ZI```D````G*D``"D```#!J0``&0```.NI```F````!:H`
M``P````LJ@``)````#FJ```/````7JH```L```!NJ@``#@```'JJ```%````
MB:H``"@```"/J@``"````+BJ```*````P:H``!4```#,J@``$@```.*J```+
M````]:H``!0````!JP``)@```!:K```G````/:L``"8```!EJP``A0```(RK
M```.````$JP```H````AK```#0```"RL```G````.JP``"````!BK```#@``
M`(.L```7````DJP``"(```"JK```-0```,VL```1`````ZT```T````5K0``
M#````".M```-````,*T```8````^K0``E````$6M```*````VJT```\```#E
MK0``&````/6M```,````#JX```X````;K@``#@```"JN```(````.:X```D`
M``!"K@``+@```$RN```:````>ZX``#(```"6K@``.````,FN``!4`````J\`
M`%$```!7KP``6@```*FO``!7````!+```#0```!<L```"0```)&P```-````
MF[````<```"IL```"@```+&P```/````O+````4```#,L```!@```-*P```1
M````V;````@```#KL```"0```/2P```)````_K````X````(L0``"````!>Q
M```E````(+$``"````!&L0``$P```&>Q```0````>[$```\```",L0``"@``
M`)RQ```'````I[$```,```"OL0``!@```+.Q```/````NK$``!0```#*L0``
M"0```-^Q```-````Z;$``!(```#WL0``&0````JR```>````)+(```\```!#
ML@``"@```%.R```/````7K(```@```!NL@``)````'>R```7````G+(``!0`
M``"TL@``%@```,FR```(````X+(``$X```#IL@``+0```#BS```9````9K,`
M``<```"`LP``#````(BS```L````E;,```X```#"LP```P```-&S```+````
MU;,```<```#ALP``!P```.FS```%````\;,```4```#WLP``"@```/VS```#
M````"+0``!<````,M```"@```"2T```/````+[0```X````_M```&````$ZT
M```C````9[0```X```"+M```%````)JT```7````K[0``!<```#'M```%P``
M`-^T```3````][0```\````+M0``#@```!NU```I````*K4``!\```!4M0``
M'0```'2U```'````DK4```8```":M0``"````*&U```/````JK4```8```"Z
MM0``"@```,&U```3````S+4```L```#@M0``$````.RU```5````_;4``!4`
M```3M@``!P```"FV```0````,;8```4```!"M@``%0```$BV```1````7K8`
M``P```!PM@``.P```'VV```X````N;8```D```#RM@``!P```/RV```4````
M!+<```,````9MP``!0```!VW```0````([<```D````TMP``$P```#ZW```Y
M````4K<``!(```",MP``.0```)^W```G````V;<``"P````!N```*@```"ZX
M```E````6;@```D```!_N```"@```(FX```&````E+@```D```";N```!P``
M`*6X```O````K;@``#<```#=N```+@```!6Y``!5````1+D``"T```":N0``
M+0```,BY```]````]KD``#\````TN@``+0```'2Z``!`````HKH``",```#C
MN@``(P````>[``!`````*[L``"T```!LNP``,P```)J[```E````SKL``!4`
M``#TNP``&0````J\```I````)+P``"0```!.O```*````'.\```1````G+P`
M`!$```"NO```"@```,"\```$````R[P```P```#0O```"@```-V\```0````
MZ+P``!8```#YO```%@```!"]```'````)[T```<````OO0``%````#>]```*
M````3+T```@```!7O0``"````&"]```(````:;T```8```!RO0``)P```'F]
M```(````H;T```<```"JO0``!P```+*]```&````NKT```4```#!O0``!P``
M`,>]```&````S[T```@```#6O0``*0```-^]```.````";X```H````8O@``
M"0```".^```.````+;X```0````\O@``!P```$&^```)````2;X```8```!3
MO@``$0```%J^```'````;+X``!8```!TO@``!````(N^```(````D+X```8`
M``"9O@``#0```*"^```&````KKX``!X```"UO@``!0```-2^```1````VKX`
M``@```#LO@``#0```/6^```,`````[\```P````0OP``!P```!V_```#````
M);\```,````IOP``%P```"V_```3````1;\``!T```!9OP``"````'>_```$
M````@+\```@```"%OP``"````(Z_```*````E[\``$$```"BOP``&@```.2_
M```K````_[\``"`````KP```%0```$S````&````8L````8```!IP```%0``
M`'#````8````AL```"(```"?P```+@```,+````=````\<```"$````/P0``
M*0```#'!```*````6\$```<```!FP0``!P```&[!```5````=L$```X```",
MP0``"@```)O!```/````IL$```T```"VP0``#P```,3!```-````U,$```D`
M``#BP0``%````.S!```&`````<(``!@````(P@``'0```"'"```3````/\(`
M`!$```!3P@``%````&7"```$````>L(```P```!_P@``!@```(S"```4````
MD\(``!<```"HP@``5````,#"``!D````%<,```0```!ZPP``#@```'_#``!$
M````CL,```4```#3PP``!0```-G#```;````W\,``!H```#[PP``$P```!;$
M```1````*L0``!$````\Q```$0```$[$```<````8,0``"H```!]Q```$```
M`*C$```A````N<0```4```#;Q```$P```.'$```+````]<0``!(````!Q0``
M"@```!3%```/````'\4```T````OQ0``$0```#W%```3````3\4```P```!C
MQ0``!@```'#%```,````=\4```8```"$Q0``%P```(O%```0````H\4``!$`
M``"TQ0``"````,;%```%````S\4```P```#5Q0``$````.+%```%````\\4`
M``T```#YQ0``!@````?&```'````#L8```T````6Q@``!P```"3&```+````
M+,8```<````XQ@``!P```$#&```)````2,8``!0```!2Q@``"0```&?&```)
M````<<8```H```![Q@``&0```(;&```]````H,8``!T```#>Q@``#````/S&
M```0````"<<```4````:QP``)0```"#'```2````1L<``!,```!9QP``*P``
M`&W'```[````F<<``"````#5QP``"````/;'```V````_\<``"$````VR```
M$````%C(```(````:<@```P```!RR```!@```'_(```$````AL@```\```"+
MR```#@```)O(```*````JL@```<```"UR```"@```+W(```-````R,@``!X`
M``#6R```'P```/7(```;````%<D``!P````QR0``(0```$[)```>````<,D`
M`!D```"/R0``'@```*G)```;````R,D``"$```#DR0``+@````;*```F````
M-<H``!L```!<R@``'````'C*```>````E<H``!P```"TR@``)@```-'*```K
M````^,H``#,````DRP``)@```%C+```K````?\L``#@```"KRP``'0```.3+
M```=`````LP``!4````@S```%0```#;,```O````3,P``"````!\S```$@``
M`)W,```@````L,P``"D```#1S```'@```/O,```>````&LT``"`````YS0``
M$@```%K-``"B````;<T``!8````0S@``(P```"?.```H````2\X``"D```!T
MS@``*````)[.```?````Q\X``!4```#GS@``%0```/W.```@````$\\``"4`
M```TSP``*````%K/```M````@\\``#````"QSP``D@```.+/```A````==``
M`!8```"7T```%@```*[0```<````Q=```"8```#BT```*@````G1``!!````
M--$``$0```!VT0``#````+O1```'````R-$```<```#0T0``!@```-C1```-
M````W]$``!````#MT0``$@```/[1```3````$=(``!(````ET@``!P```#C2
M```$````0-(``!````!%T@``$````%;2```,````9](```X```!TT@``#0``
M`(/2```/````D=(``!,```"AT@``#0```+72```H````P](```,```#LT@``
M#0```/#2```&````_M(``!$````%TP``%P```!?3```;````+],```X```!+
MTP```@```%K3```%````7=,``!````!CTP``#P```'33```$````A-,```T`
M``")TP``#@```)?3```#````IM,```X```"JTP``"````+G3```/````PM,`
M``@```#2TP``#P```-O3```'````Z],```T```#STP``$`````'4```-````
M$M0```L````@U```$0```"S4```)````/M0```8```!(U```"P```$_4```,
M````6]0```H```!HU```$0```'/4```9````A=0```L```"?U```#0```*O4
M```B````N=0```\```#<U```&P```.S4```T````"-4```H````]U0``&```
M`$C5```2````8=4``!D```!TU0``%@```([5```0````I=4``"(```"VU0``
M#0```-G5```'````Y]4```P```#OU0``)@```/S5```4````(]8```L````X
MU@``(@```$36```O````9]8```L```"7U@``"0```*/6```9````K=8```L`
M``#'U@``%P```-/6```7````Z]8```D````#UP``%@````W7```/````)-<`
M`!D````TUP``%@```$[7```.````9=<```<```!TUP``"````'S7```-````
MA=<``"8```"3UP``0P```+K7```2````_M<``!\````1V```"````#'8```+
M````.M@``"\```!&V```#@```';8```%````A=@```8```"+V```10```)+8
M```#````V-@```<```#<V```!````.38```*````Z=@```H```#TV```#P``
M`/_8```0````#]D``!<````@V0``$0```#C9```9````2MD``!<```!DV0``
M"0```'S9```%````AMD```L```",V0``"@```)C9```"````H]D```4```"F
MV0``#0```*S9```;````NMD``!<```#6V0``%````.[9```)`````]H```X`
M```-V@``#0```!S:```2````*MH```,````]V@``"````$':```.````2MH`
M`!@```!9V@``&````'+:```%````B]H``!@```"1V@``'@```*K:```;````
MR=H``!D```#EV@``&````/_:```;````&-L``!,````TVP``$P```$C;```'
M````7-L```@```!DVP``!@```&W;```&````=-L``!````![VP``#P```(S;
M```0````G-L```\```"MVP``"P```+W;```/````R=L```P```#9VP``#P``
M`.;;```'````]ML```8```#^VP``#@````7<```,````%-P``"@````AW```
M#P```$K<```(````6MP```@```!CW```$P```&S<```>````@-P``"$```"?
MW```(````,'<```9````XMP``!<```#\W```)0```!3=```7````.MT``!8`
M``!2W0``!````&G=```;````;MT```T```"*W0``#````)C=```#````I=T`
M``4```"IW0``"````*_=```*````N-T```P```##W0``"P```-#=```0````
MW-T```P```#MW0``#@```/K=```+````"=X```0````5W@``!````!K>```3
M````']X``!0````SW@``#````$C>```)````5=X```X```!?W@``"P```&[>
M```;````>MX```<```"6W@``!P```)[>```*````IMX```T```"QW@``&```
M`+_>```*````V-X```0```#CW@``)@```.C>```.````#]\``'P````>WP``
M%0```)O?```%````L=\```<```"WWP``#````+_?```(````S-\```H```#5
MWP``!@```.#?```(````Y]\```(```#PWP``!@```//?```&````^M\``!0`
M```!X```%0```!;@```/````+.```!$````\X```&@```$[@```-````:>``
M`!````!WX```&P```(C@```$````I.````D```"IX```$````+/@```)````
MQ.````D```#.X```!0```-C@```:````WN````@```#YX```!@````+A```9
M````">$```X````CX0``!P```#+A```'````.N$```4```!"X0``"0```$CA
M```*````4N$```X```!=X0```@```&SA```&````;^$```L```!VX0``#0``
M`(+A```)````D.$```8```":X0``!0```*'A```)````I^$```<```"QX0``
M!````+GA```4````ON$``$(```#3X0``)0```!;B```E````/.(```8```!B
MX@``!````&GB```)````;N(```@```!XX@``$0```('B```.````D^(```D`
M``"BX@``!@```*SB```-````L^(```8```#!X@``!````,CB```Y````S>(`
M`#T````'XP``.@```$7C```>````@.,```4```"?XP``#@```*7C```$````
MM.,```8```"YXP``!P```,#C```A````R.,```T```#JXP``%0```/CC```&
M````#N0``!(````5Y```!````"CD```1````+>0```8````_Y```"@```$;D
M```B````4>0```0```!TY```!0```'GD```$````?^0```P```"$Y```#@``
M`)'D```*````H.0```@```"KY```"0```+3D```%````ON0``#H```#$Y```
M,````/_D```U````,.4``"D```!FY0``1P```)#E```X````V.4``"D````1
MY@``/P```#OF```N````>^8``"T```"JY@``'P```-CF```/````^.8``!(`
M```(YP``"P```!OG```F````)^<``"D```!.YP``)````'CG```F````G><`
M``@```#$YP``"@```,WG```)````V.<```<```#BYP``(````.KG```@````
M"^@``"8````LZ```"@```%/H```9````7N@``"D```!XZ```%@```*+H```2
M````N>@```<```#,Z```"@```-3H```,````W^@```\```#LZ```$````/SH
M``!`````#>D``'````!.Z0``9@```+_I```.````)NH```D````UZ@``"@``
M`#_J```2````2NH``!,```!=Z@``#````''J```&````?NH```\```"%Z@``
M$@```)7J```0````J.H```H```"YZ@``$0```,3J```<````UNH``",```#S
MZ@``:@```!?K```/````@NL```4```"2ZP``$````)CK```)````J>L```0`
M``"SZP``"P```+CK```@````Q.L``!0```#EZP``#````/KK```,````!^P`
M``\````4[```%0```"3L```I````.NP``"H```!D[```)@```(_L```G````
MMNP``"D```#>[```*@````CM```9````,^T``!$```!-[0``$@```%_M```3
M````<NT``!0```"&[0``#P```)OM```6````J^T``!<```#"[0``$````-KM
M```1````Z^T``#0```#][0``$P```#+N```2````1NX``#4```!9[@``%```
M`(_N```'````I.X```P```"L[@``*P```+GN```@````Y>X``!`````&[P``
M%````!?O```1````+.\``!<````^[P``'````%;O```3````<^\``!0```"'
M[P``&@```)SO```1````M^\``!H```#)[P``'@```.3O```:`````_```!,`
M```>\```%0```#+P```1````2/```!<```!:\```%````'+P```7````A_``
M`!4```"?\```"0```+7P```0````O_```!D```#0\```!````.KP```'````
M[_````L```#W\```$0````/Q```&````%?$```8````<\0``!@```"/Q```%
M````*O$```<````P\0``!P```#CQ```%````0/$``!8```!&\0``!@```%WQ
M```&````9/$```0```!K\0``!````'#Q```'````=?$```X```!]\0``#```
M`(SQ```,````F?$```T```"F\0``!0```+3Q```H````NO$```P```#C\0``
M#P```/#Q```*`````/(```@````+\@``"0```!3R```K````'O(```0```!*
M\@``"````$_R```%````6/(``"8```!>\@``$@```(7R```/````F/(```8`
M``"H\@``"@```*_R```'````NO(```@```#"\@``(````,OR```)````[/(`
M`!0```#V\@``#`````OS```-````&/,```X````F\P``%@```#7S```1````
M3/,```8```!>\P``"````&7S```#````;O,```8```!R\P``&0```'GS```'
M````D_,```0```";\P``"P```*#S```+````K/,```<```"X\P``!0```,#S
M```'````QO,``!8```#.\P``#0```.7S```*````\_,```T```#^\P``"@``
M``ST```0````%_0```\````H]```$0```#CT```7````2O0```H```!B]```
M$0```&WT```(````?_0```0```"(]```#P```(WT```Z````G?0```4```#8
M]```#````-[T```>````Z_0```X````*]0``$````!GU```+````*O4```P`
M```V]0``"0```$/U```'````3?4```H```!5]0``"0```&#U```.````:O4`
M`!````!Y]0``&P```(KU```8````IO4``!H```"_]0``"@```-KU```)````
MY?4```H```#O]0``#````/KU```/````!_8```@````7]@``!@```"#V```'
M````)_8```4````O]@``"P```#7V``!'````0?8```T```")]@``"0```)?V
M```$````H?8```,```"F]@``$P```*KV```3````OO8``!,```#2]@``!@``
M`.;V```+````[?8```H```#Y]@```@````3W```$````!_<``"4````,]P``
M`P```#+W```%````-O<``"H````\]P``"@```&?W```%````<O<```0```!X
M]P``"@```'WW```-````B/<```8```"6]P``"````)WW```(````IO<```0`
M``"O]P``!0```+3W``!H````NO<```D````C^```#````"WX```0````.O@`
M``4```!+^```!@```%'X```;````6/@``"\```!T^```$````*3X```*````
MM?@```\```#`^```"@```-#X```)````V_@``!,```#E^```&P```/GX```8
M````%?D``!<````N^0``'P```$;Y```.````9OD```,```!U^0``!P```'GY
M```(````@?D``!0```"*^0``$P```)_Y```0````L_D```T```#$^0``#@``
M`-+Y```6````X?D```<```#X^0``"@````#Z```+````"_H```<````7^@``
M40```!_Z```0````<?H```P```""^@``#0```(_Z```:````G?H``$H```"X
M^@``&0````/[```&````'?L``!H````D^P``)0```#_[```&````9?L```8`
M``!L^P``'P```'/[```&````D_L```D```":^P``&````*3[```7````O?L`
M`"@```#5^P``!@```/[[```-````!?P``"(````3_```5P```#;\```3````
MCOP``",```"B_```$P```,;\```"````VOP```L```#=_```"````.G\```-
M````\OP```H`````_0``!P````O]```4````$_T```8````H_0``"````"_]
M```.````./T```<```!'_0``"@```$_]```+````6OT``#(```!F_0``!P``
M`)G]```,````H?T```T```"N_0``#````+S]```)````R?T```D```#3_0``
M"@```-W]```'````Z/T```D```#P_0``!P```/K]```*`````OX```<````-
M_@``&P```!7^```/````,?X``!(```!!_@``"@```%3^```6````7_X```D`
M``!V_@``$````(#^```'````D?X``!(```"9_@``!````*S^```'````L?X`
M``4```"Y_@``!````+_^```,````Q/X```4```#1_@``"P```-?^```4````
MX_X``!$```#X_@``%`````K_```7````'_\``!@````W_P``'````%#_```9
M````;?\```<```"'_P``!0```(__```-````E?\```P```"C_P``$0```+#_
M```(````PO\``!<```#+_P``"P```./_```,````[_\``!\```#\_P``&@``
M`!P``0`3````-P`!``0```!+``$`"@```%```0`$````6P`!``T```!@``$`
M#````&X``0`%````>P`!``D```"!``$`!0```(L``0`'````D0`!``4```"9
M``$`!````)\``0`"````I``!`#@```"G``$`+````.```0`2````#0$!`"D`
M```@`0$`,@```$H!`0`*````?0$!`"P```"(`0$`+@```+4!`0`S````Y`$!
M`#,````8`@$`.````$P"`0`/````A0(!`!0```"5`@$`&````*H"`0`0````
MPP(!``\```#4`@$`$P```.0"`0`5````^`(!`!0````.`P$`$@```",#`0`4
M````-@,!`!4```!+`P$`+0```&$#`0`M````CP,!`#$```"]`P$`+@```.\#
M`0`O````'@0!`"P```!.!`$`$P```'L$`0`,````CP0!``T```"<!`$`"```
M`*H$`0`7````LP0!``@```#+!`$`#````-0$`0`K````X00!`"$````-!0$`
M&@```"\%`0`)````2@4!`$4```!4!0$`00```)H%`0`/````W`4!``0```#L
M!0$`$P```/$%`0`.````!08!`!,````4!@$`&````"@&`0`&````008!``D`
M``!(!@$`"@```%(&`0`/````708!`!````!M!@$`!P```'X&`0`.````A@8!
M``4```"5!@$`&P```)L&`0`&````MP8!``@```"^!@$`!@```,<&`0`4````
MS@8!`!$```#C!@$`#@```/4&`0`X````!`<!``(````]!P$`!@```$`'`0`.
M````1P<!``4```!6!P$`!P```%P'`0`.````9`<!``8```!S!P$`*````'H'
M`0`,````HP<!`!P```"P!P$`!````,T'`0`I````T@<!`!<```#\!P$`'P``
M`!0(`0!<````-`@!`!0```"1"`$`/@```*8(`0`?````Y0@!`!`````%"0$`
M%````!8)`0`'````*PD!``X````S"0$`#````$()`0`,````3PD!`!,```!<
M"0$`"@```'`)`0`=````>PD!`!D```"9"0$`!0```+,)`0`1````N0D!`!$`
M``#+"0$`)````-T)`0`2`````@H!`!4````5"@$`$@```"L*`0`.````/@H!
M`!D```!-"@$`"````&<*`0`)````<`H!``T```!Z"@$`!P```(@*`0`*````
MD`H!``<```";"@$`#P```*,*`0`&````LPH!``L```"Z"@$`&@```,8*`0`*
M````X0H!``<```#L"@$`"````/0*`0`%````_0H!`!\````#"P$`!@```",+
M`0`0````*@L!``@````["P$`#0```$0+`0`(````4@L!`!X```!;"P$`$@``
M`'H+`0`L````C0L!`!H```"Z"P$`"0```-4+`0`*````WPL!`!4```#J"P$`
M!0`````,`0`4````!@P!``0````;#`$`$````"`,`0`&````,0P!``<````X
M#`$`'@```$`,`0`H````7PP!``H```"(#`$`'````),,`0`1````L`P!``L`
M``#"#`$`&@```,X,`0`4````Z0P!``0```#^#`$`!`````,-`0`+````"`T!
M``4````4#0$`!@```!H-`0`(````(0T!``8````J#0$`"@```#$-`0`;````
M/`T!`#0```!8#0$`-````(T-`0`@````P@T!`"D```#C#0$`(`````T.`0!!
M````+@X!`!H```!P#@$`*````(L.`0`I````M`X!`%$```#>#@$`4````#`/
M`0!7````@0\!`"P```#9#P$`(@````80`0`&````*1`!``@````P$`$`!0``
M`#D0`0`(````/Q`!`!D```!($`$`&0```&(0`0`J````?!`!``@```"G$`$`
M(P```+`0`0`9````U!`!`"X```#N$`$`-````!T1`0`(````4A$!`!<```!;
M$0$`"@```',1`0`'````?A$!`"$```"&$0$`$````*@1`0`.````N1$!``L`
M``#($0$`!P```-01`0`3````W!$!``@```#P$0$`"P```/D1`0`*````!1(!
M`!0````0$@$`#P```"42`0`R````-1(!``L```!H$@$`#@```'02`0`%````
M@Q(!``4```")$@$`!0```(\2`0`7````E1(!``\```"M$@$`!````+T2`0`*
M````PA(!``D```#-$@$`"P```-<2`0`-````XQ(!``P```#Q$@$`#@```/X2
M`0`%````#1,!``0````3$P$`#0```!@3`0`R````)A,!`$4```!9$P$`%P``
M`)\3`0`'````MQ,!`!X```"_$P$`%````-X3`0`%````\Q,!`!0```#Y$P$`
M!@````X4`0`'````%10!`",````=%`$`#@```$$4`0`J````4!0!``8```![
M%`$`#````((4`0`-````CQ0!`!$```"=%`$`%P```*\4`0`+````QQ0!`#8`
M``#3%`$`"@````H5`0`B````%14!``L````X%0$`#P```$05`0`+````5!4!
M`"````!@%0$`)P```($5`0`K````J14!``D```#5%0$`,@```-\5`0`E````
M$A8!`#`````X%@$`,0```&D6`0`M````FQ8!``X```#)%@$`%````-@6`0`%
M````[18!``X```#S%@$`$P````(7`0`2````%A<!``<````I%P$`$0```#$7
M`0`3````0Q<!``<```!7%P$`%````%\7`0`8````=!<!``<```"-%P$`!0``
M`)47`0`,````FQ<!``P```"H%P$`$@```+47`0`$````R!<!``<```#-%P$`
M"@```-47`0`+````X!<!``P```#L%P$`#@```/D7`0`.````"!@!``4````7
M&`$`!0```!T8`0`N````(Q@!`"8```!2&`$`(P```'D8`0`#````G1@!`!(`
M``"A&`$`!@```+08`0`>````NQ@!`!@```#:&`$`)0```/,8`0`-````&1D!
M``D````G&0$`'P```#$9`0`#````41D!``<```!5&0$`"@```%T9`0`"````
M:!D!``P```!K&0$`%0```'@9`0`+````CAD!`!D```":&0$`(````+09`0`2
M````U1D!``4```#H&0$`"@```.X9`0`5````^1D!`!(````/&@$`#````"(:
M`0`$````+QH!``D````T&@$`!P```#X:`0`,````1AH!`%(```!3&@$`%P``
M`*8:`0`D````OAH!`!(```#C&@$`!P```/8:`0`&````_AH!``X````%&P$`
M#````!0;`0`-````(1L!`!4````O&P$`$@```$4;`0`/````6!L!`!0```!H
M&P$`"@```'T;`0`;````B!L!`!````"D&P$`"P```+4;`0!I````P1L!`!H`
M```K'`$`%P```$8<`0`G````7AP!`!H```"&'`$`%P```*$<`0`;````N1P!
M`!D```#5'`$`'P```.\<`0`7````#QT!`!,````G'0$`"````#L=`0`'````
M1!T!``@```!,'0$`"0```%4=`0`5````7QT!``T```!U'0$`(P```(,=`0`-
M````IQT!`!,```"U'0$`"````,D=`0`#````TAT!`$8```#6'0$`/P```!T>
M`0`W````71X!`%<```"5'@$`!0```.T>`0`?````\QX!`"\````3'P$`"@``
M`$,?`0`(````3A\!``T```!7'P$`+0```&4?`0`$````DQ\!`$\```"8'P$`
M)0```.@?`0`<````#B`!``L````K(`$`'P```#<@`0`=````5R`!`"4```!U
M(`$`(````)L@`0`D````O"`!`"````#A(`$`"P````(A`0`'````#B$!``T`
M```6(0$`#````"0A`0`7````,2$!``8```!)(0$`.0```%`A`0`,````BB$!
M``<```"7(0$`"0```)\A`0`3````J2$!``<```"](0$`"0```,4A`0`$````
MSR$!`!````#4(0$`"````.4A`0`(````[B$!``0```#W(0$`"P```/PA`0`,
M````""(!`!(````5(@$`$0```"@B`0`,````.B(!`!H```!'(@$`#P```&(B
M`0`'````<B(!``T```!Z(@$`%````(@B`0`.````G2(!``P```"L(@$`+```
M`+DB`0`3````YB(!`!P```#Z(@$`*````!<C`0`&````0",!``<```!'(P$`
M$P```$\C`0`%````8R,!``0```!I(P$`%P```&XC`0`*````AB,!``P```"1
M(P$`"0```)XC`0`&````J",!``D```"O(P$`"````+DC`0`)````PB,!``4`
M``#,(P$`"@```-(C`0`1````W2,!``8```#O(P$`#@```/8C`0`.````!20!
M``T````4)`$`"P```"(D`0`=````+B0!``L```!,)`$``@```%@D`0`<````
M6R0!``<```!X)`$`!@```(`D`0!D````AR0!``D```#L)`$`!P```/8D`0`F
M````_B0!`#@````E)0$`&@```%XE`0`J````>24!`#L```"D)0$`*````.`E
M`0`T````"28!`!D````^)@$`%0```%@F`0`%````;B8!``<```!T)@$`"```
M`'PF`0`'````A28!``4```"-)@$`!P```),F`0`.````FR8!``D```"J)@$`
M!@```+0F`0`(````NR8!``L```#$)@$`!P```-`F`0`(````V"8!``<```#A
M)@$`%@```.DF`0`)`````"<!``8````*)P$`"P```!$G`0`0````'2<!``8`
M```N)P$`'````#4G`0`4````4B<!``<```!G)P$`$0```&\G`0`(````@2<!
M``X```"*)P$`"````)DG`0`%````HB<!`!````"H)P$`"0```+DG`0`0````
MPR<!``8```#4)P$`&0```-LG`0`*````]2<!`!P`````*`$`!P```!TH`0`%
M````)2@!``0````K*`$`$````#`H`0`4````02@!``L```!6*`$`#0```&(H
M`0`H````<"@!`!@```"9*`$`%P```+(H`0`:````RB@!`!0```#E*`$`!```
M`/HH`0`)````_R@!``H````)*0$`!P```!0I`0`"````'"D!``X````?*0$`
M"````"XI`0`?````-RD!`",```!7*0$`(P```'LI`0`?````GRD!`#@```"_
M*0$`)@```/@I`0`Q````'RH!`"<```!1*@$`9````'DJ`0`4````WBH!`!P`
M``#S*@$`50```!`K`0`X````9BL!`$H```"?*P$`6P```.HK`0`H````1BP!
M`#@```!O+`$`*@```*@L`0`H````TRP!`"P```#\+`$`)P```"DM`0`F````
M42T!`!L```!X+0$`/@```)0M`0`C````TRT!`!<```#W+0$`&0````\N`0!(
M````*2X!`(4```!R+@$`,````/@N`0`E````*2\!`$$```!/+P$`6P```)$O
M`0!)````[2\!`#$````W,`$`'0```&DP`0`8````AS`!`"L```"@,`$`(0``
M`,PP`0`?````[C`!`"L````.,0$`)@```#HQ`0`A````83$!`"D```"#,0$`
M)P```*TQ`0`Z````U3$!`!T````0,@$`$0```"XR`0`S````0#(!`"4```!T
M,@$`.````)HR`0`G````TS(!`"````#[,@$`'P```!PS`0`P````/#,!`&D`
M``!M,P$`,0```-<S`0!!````"30!`#,```!+-`$`)0```'\T`0`]````I30!
M`&4```#C-`$`30```$DU`0`O````ES4!`"X```#'-0$`*P```/8U`0`P````
M(C8!`"H```!3-@$`/@```'XV`0!4````O38!`%H````2-P$`2````&TW`0!*
M````MC<!`#(````!.`$`'0```#0X`0`C````4C@!`"\```!V.`$`+````*8X
M`0`M````TS@!`'$````!.0$`9@```',Y`0!O````VCD!`+,```!*.@$`%P``
M`/XZ`0`E````%CL!`#(````\.P$`*0```&\[`0`^````F3L!`"(```#8.P$`
M4@```/L[`0`E````3CP!``L```!T/`$`10```(`\`0`A````QCP!`#````#H
M/`$`)0```!D]`0`<````/ST!`#$```!</0$`!P```(X]`0`'````ECT!``0`
M``">/0$`#0```*,]`0`+````L3T!``X```"]/0$`"P```,P]`0`%````V#T!
M`!````#>/0$``@```.\]`0!9````\CT!``4```!,/@$`$@```%(^`0`$````
M93X!``<```!J/@$`"````'(^`0`%````>SX!``,```"!/@$`$````(4^`0`,
M````ECX!`!,```"C/@$`#0```+<^`0`"````Q3X!``<```#(/@$`!@```-`^
M`0`4````USX!``P```#L/@$`&````/D^`0`&````$C\!`!(````9/P$`#```
M`"P_`0`#````.3\!`"H````]/P$`!````&@_`0`&````;3\!``<```!T/P$`
M'P```'P_`0`U````G#\!`"X```#2/P$`+P````%``0`7````,4`!`!\```!)
M0`$`(@```&E``0`E````C$`!`"````"R0`$`&P```--``0`8````[T`!`"0`
M```(00$`'P```"U!`0`:````34$!`"$```!H00$`(````(I!`0`:````JT$!
M`#(```#&00$`&@```/E!`0`O````%$(!`"L```!$0@$`'P```'!"`0`C````
MD$(!`!\```"T0@$`&@```-1"`0`A````[T(!`"4````10P$`)@```#=#`0`E
M````7D,!`"0```"$0P$`&````*E#`0`=````PD,!`"0```#@0P$`&`````5$
M`0`B````'D0!`"P```!!1`$`+P```&Y$`0`5````GD0!`"4```"T1`$`/```
M`-I$`0`?````%T4!`",````W10$`'P```%M%`0`@````>T4!`!H```"<10$`
M&````+=%`0`F````T$4!`!X```#W10$`*0```!9&`0`>````0$8!`#$```!?
M1@$`"0```)%&`0`,````FT8!`!<```"H1@$`+P```,!&`0`D````\$8!``<`
M```51P$`'P```!U'`0`/````/4<!`!0```!-1P$`#@```&)'`0`-````<4<!
M`"0```!_1P$`!0```*1'`0`'````JD<!`"(```"R1P$`)0```-5'`0`:````
M^T<!`!T````62`$`&@```#1(`0`'````3T@!`,<```!72`$`"P```!])`0`5
M````*TD!``8```!!20$`"0```$A)`0`8````4DD!``L```!K20$`#0```'=)
M`0`7````A4D!``8```"=20$`,P```*1)`0`3````V$D!`!,```#L20$`!P``
M``!*`0`/````"$H!``<````82@$`,@```"!*`0`$````4TH!`"$```!82@$`
M$P```'I*`0`,````CDH!`!$```";2@$`,@```*U*`0`6````X$H!``@```#W
M2@$`'0````!+`0`)````'DL!``H````H2P$`%````#-+`0`*````2$L!`!T`
M``!32P$`"````'%+`0`?````>DL!``@```":2P$`&@```*-+`0`G````ODL!
M``8```#F2P$`%0```.U+`0`'`````TP!``@````+3`$`"0```!1,`0`_````
M'DP!``<```!>3`$`#P```&9,`0`.````=DP!`!````"%3`$`"0```)9,`0`)
M````H$P!``@```"J3`$`$P```+-,`0`'````QTP!`!D```#/3`$`"@```.E,
M`0`*````]$P!``D```#_3`$`%P````E-`0`4````(4T!``H````V30$`#```
M`$%-`0`7````3DT!``0```!F30$`*@```&M-`0`,````EDT!`!$```"C30$`
M!P```+5-`0`"````O4T!`!````#`30$`&````-%-`0`+````ZDT!``,```#V
M30$`"````/I-`0`3`````TX!`!<````73@$`!@```"].`0`'````-DX!``T`
M```^3@$`"P```$Q.`0`4````6$X!`!4```!M3@$`#@```(-.`0`O````DDX!
M`"````#"3@$`'````.-.`0`5`````$\!``P````63P$`,0```"-/`0`%````
M54\!`!(```!;3P$`/P```&Y/`0`2````KD\!``H```#!3P$`!@```,Q/`0`$
M````TT\!``0```#83P$`"@```-U/`0`3````Z$\!``4```#\3P$`!@````)0
M`0`&````"5`!``@````04`$`!````!E0`0`,````'E`!``H````K4`$`.0``
M`#90`0`N````<%`!`"D```"?4`$`!0```,E0`0`9````SU`!`!$```#I4`$`
M`@```/M0`0`$````_E`!``H````#40$`!@````Y1`0`%````%5$!``,````;
M40$`#````!]1`0!%````+%$!`#(```!R40$`&@```*51`0`U````P%$!`#0`
M``#V40$`*````"M2`0`9````5%(!`'(```!N4@$`(````.%2`0`U`````E,!
M`"$````X4P$`10```%I3`0`P````H%,!`"@```#14P$`*0```/I3`0`F````
M)%0!`"4```!+5`$`*````'%4`0`H````FE0!`"(```##5`$`*P```.94`0`P
M````$E4!`!(```!#50$`$P```%95`0`0````:E4!`'D```![50$`"0```/55
M`0"A````_U4!`',```"A5@$`?````!57`0`K````DE<!`%0```"^5P$`%P``
M`!-8`0`G````*U@!`!8```!36`$`#P```&I8`0`7````>E@!`!\```"26`$`
M0````+)8`0`?````\U@!`!P````360$`40```#!9`0`:````@ED!`!0```"=
M60$`"@```+)9`0`%````O5D!``8```##60$`"````,I9`0`%````TUD!`!(`
M``#960$`$````.Q9`0`3````_5D!`!T````16@$`#P```"]:`0`/````/UH!
M``0```!/6@$`"0```%1:`0`+````7EH!``<```!J6@$`!0```'):`0`4````
M>%H!``<```"-6@$`"````)5:`0`/````GEH!``@```"N6@$`#````+=:`0`/
M````Q%H!``8```#46@$`%````-M:`0`&````\%H!``P```#W6@$`$0````1;
M`0`(````%EL!``0````?6P$`&0```"1;`0`1````/EL!``H```!06P$`!0``
M`%M;`0`8````85L!`!,```!Z6P$`'````(Y;`0`1````JUL!``0```"]6P$`
M#P```,);`0`'````TEL!``0```#:6P$`&0```-];`0`'````^5L!``(````!
M7`$``@````1<`0`1````!UP!``D````97`$`!@```"-<`0`2````*EP!`!<`
M```]7`$`!@```%5<`0`G````7%P!``(```"$7`$`!````(=<`0`/````C%P!
M`!,```"<7`$`!P```+!<`0`'````N%P!`!$```#`7`$`!@```-)<`0`8````
MV5P!``8```#R7`$`$P```/E<`0`0````#5T!`!(````>70$``@```#%=`0`&
M````-%T!``P````[70$`"0```$A=`0`1````4ET!`"(```!D70$`!P```(==
M`0`'````CUT!``L```"770$`!0```*-=`0`"````J5T!``L```"L70$`8@$`
M`+A=`0!,````&U\!`!$```!H7P$`$@```'I?`0`/````C5\!``X```"=7P$`
M!P```*Q?`0`*````M%\!``<```"_7P$`!````,=?`0`8````S%\!`!T```#E
M7P$`+`````-@`0`=````,&`!`"````!.8`$`)@```&]@`0`7````EF`!`"@`
M``"N8`$`#````-=@`0`K````Y&`!``X````080$`$0```!]A`0`2````,6$!
M``4```!$80$`(P```$IA`0`(````;F$!``H```!W80$`$P```()A`0`/````
MEF$!``L```"F80$`%0```+)A`0!#````R&$!`"(````,8@$`,0```"]B`0!O
M````86(!``@```#18@$`"@```-IB`0`*````Y6(!`#<```#P8@$`(@```"AC
M`0`0````2V,!`!L```!<8P$`(````'AC`0`P````F6,!`!````#*8P$`#P``
M`-MC`0`3````ZV,!`!````#_8P$`!@```!!D`0")````%V0!``L```"A9`$`
M$0```*UD`0`=````OV0!``H```#=9`$`$````.AD`0`0````^60!``D````*
M90$`"P```!1E`0`L````(&4!`!P```!-90$`.P```&IE`0!%````IF4!`%8`
M``#L90$`4P```$-F`0!9````EV8!`%8```#Q9@$`/@```$AG`0`.````AV<!
M`!,```"69P$`#@```*IG`0`0````N6<!`!@```#*9P$`!0```.-G`0`&````
MZ6<!``H```#P9P$`!0```/MG`0`&`````6@!``8````(:`$`$0````]H`0`*
M````(6@!`"4````L:`$`)````%)H`0`0````=V@!`!(```"(:`$`#````)MH
M`0`&````J&@!``@```"O:`$`"0```+AH`0`,````PF@!`!0```#/:`$`&0``
M`.1H`0`.````_F@!`!(````-:0$`%P```"!I`0`>````.&D!`",```!7:0$`
M&@```'MI`0`0````EFD!`!<```"G:0$`#0```+]I`0`J````S6D!`!@```#X
M:0$`%@```!%J`0`9````*&H!`!,```!":@$`3P```%9J`0`Q````IFH!`"0`
M``#8:@$`!@```/UJ`0`)````!&L!`#0````.:P$`#@```$-K`0`&````4FL!
M``H```!9:P$`"````&1K`0`(````;6L!``4```!V:P$`!P```'QK`0`*````
MA&L!``0```"/:P$`'````)1K`0`,````L6L!`!$```"^:P$`#P```-!K`0`5
M````X&L!`"8```#V:P$`"P```!UL`0`:````*6P!`!T```!$;`$`(0```&)L
M`0`8````A&P!``\```"=;`$`$````*UL`0`1````OFP!`"\```#0;`$`&P``
M``!M`0`;````'&T!``<````X;0$`!@```$!M`0`(````1VT!``P```!0;0$`
M!````%UM`0`)````8FT!`!,```!L;0$`"P```(!M`0`1````C&T!`!8```">
M;0$`'P```+5M`0`'````U6T!`!(```#=;0$`!0```/!M`0`6````]FT!``\`
M```-;@$`#````!UN`0`Q````*FX!`$(```!<;@$`"0```)]N`0`(````J6X!
M`!0```"R;@$`!0```,=N`0`%````S6X!`!````#3;@$`"P```.1N`0`9````
M\&X!`#L````*;P$`$@```$9O`0!&````66\!`"\```"@;P$`-````-!O`0`N
M````!7`!`"T````T<`$`"0```&)P`0`(````;'`!``<```!U<`$`"@```'UP
M`0`)````B'`!`",```"2<`$`-````+9P`0`B````ZW`!`$8````.<0$`(0``
M`%5Q`0`A````=W$!`$,```"9<0$`0@```-UQ`0`?````('(!`$````!`<@$`
M)P```(%R`0`J````J7(!`$,```#4<@$`(0```!AS`0`G````.G,!`"P```!B
M<P$`&@```(]S`0`>````JG,!`"H```#)<P$`*P```/1S`0`K````('0!`!(`
M``!,=`$`#@```%]T`0`*````;G0!``<```!Y=`$`#0```(%T`0`(````CW0!
M``T```"8=`$`'P```*9T`0`C````QG0!``<```#J=`$`!P```/)T`0`5````
M^G0!``H````0=0$`!@```!MU`0`&````(G4!``@````I=0$`!@```#)U`0`I
M````.74!``@```!C=0$`"P```&QU`0`'````>'4!``8```"`=0$`!0```(=U
M`0`'````C74!``8```"5=0$`"@```)QU`0`G````IW4!`!(```#/=0$`"```
M`.)U`0`(````ZW4!``X```#T=0$``P````-V`0`'````!W8!``D````/=@$`
M`P```!EV`0`)````'78!``4````G=@$`%P```"UV`0`$````178!``@```!*
M=@$`!@```%-V`0`-````6G8!``D```!H=@$`)P```')V`0`$````FG8!``8`
M``"?=@$`"0```*9V`0`*````L'8!``P```"[=@$`#````,AV`0`'````U78!
M``,```#==@$``P```.%V`0`7````Y78!`!8```#]=@$`)````!1W`0`(````
M.7<!``4```!"=P$`"````$AW`0`'````47<!``H```!9=P$`10```&1W`0`=
M````JG<!`#@```#(=P$`(@````%X`0`7````)'@!``8````\>`$`!@```$-X
M`0`5````2G@!`!4```!@>`$`'P```'9X`0`K````EG@!`!H```#">`$`(P``
M`-UX`0`Q`````7D!``D````S>0$`!@```#UY`0`(````1'D!`!<```!->0$`
M#@```&5Y`0`,````='D!`!$```"!>0$`#@```)-Y`0`1````HGD!``X```"T
M>0$`#````,-Y`0`5````T'D!``D```#F>0$`'````/!Y`0`=````#7H!`!(`
M```K>@$`#P```#YZ`0`2````3GH!``4```!A>@$`"@```&=Z`0`%````<GH!
M`!,```!X>@$`%P```(QZ`0!5````I'H!`&(```#Z>@$``P```%U[`0`3````
M87L!`"D```!U>P$`!0```)][`0`$````I7L!`!P```"J>P$`'@```,=[`0`1
M````YGL!``T```#X>P$`$0````9\`0`,````&'P!`!L````E?`$`)````$%\
M`0`%````9GP!`!X```!L?`$`!0```(M\`0`5````D7P!``L```"G?`$`$P``
M`+-\`0`/````QWP!`!(```#7?`$`$P```.I\`0`8````_GP!`!,````7?0$`
M#0```"M]`0`$````.7T!``L````^?0$`"````$I]`0`7````4WT!`!4```!K
M?0$`$@```(%]`0`(````E'T!``0```"=?0$`#0```*)]`0`'````L'T!``D`
M``"X?0$`#P```,)]`0`+````TGT!``@```#>?0$`#P```.=]`0`)````]WT!
M``0````!?@$`!P````9^`0`'````#GX!``@````6?@$`%0```!]^`0`'````
M-7X!``4````]?@$`!0```$-^`0`8````27X!`%````!B?@$`(0```+-^`0`.
M````U7X!`!$```#D?@$`!0```/9^`0`%````_'X!`!D````"?P$`&@```!Q_
M`0`L````-W\!`#0```!D?P$`*````)E_`0`)````PG\!`"4```#,?P$`(@``
M`/)_`0`/````%8`!``@````E@`$`#````"Z``0`&````.X`!``<```!"@`$`
M&@```$J``0`1````98`!``H```!W@`$`"P```(*``0`*````CH`!``\```"9
M@`$`(0```*F``0`B````RX`!`"````#N@`$`(0````^!`0`D````,8$!`",`
M``!6@0$`'P```'J!`0`F````FH$!`"$```#!@0$`)````..!`0`I````"((!
M`"4````R@@$`'0```%B"`0`>````=H(!`"````"5@@$`&P```+:"`0`F````
MTH(!`"T```#Y@@$`*P```">#`0`B````4X,!`"L```!V@P$`-P```**#`0`=
M````VH,!`!T```#X@P$`&0```!:$`0`9````,(0!`#````!*A`$`(0```'N$
M`0`2````G80!`"$```"PA`$`*````-*$`0`:````^X0!`!@````6A0$`'@``
M`"^%`0`1````3H4!`+8```!@A0$`$@```!>&`0`<````*H8!`"4```!'A@$`
M)@```&V&`0`@````E(8!`"0```"UA@$`&@```-J&`0`:````]88!`"0````0
MAP$`)````#6'`0`K````6H<!`"P```"&AP$`)P```+.'`0",````VX<!`!\`
M``!HB`$`%0```(B(`0`5````GH@!`!X```"TB`$`*0```-.(`0`I````_8@!
M`$0````GB0$`1````&R)`0`+````L8D!``0```"]B0$`!@```,*)`0`%````
MR8D!``H```#/B0$`"````-J)`0`/````XXD!`!8```#SB0$`$0````J*`0`(
M````'(H!``0````EB@$`$````"J*`0`/````.XH!``L```!+B@$`#@```%>*
M`0`0````9HH!``X```!WB@$`$@```(:*`0`,````F8H!`#8```"FB@$`"```
M`-V*`0`+````YHH!``8```#RB@$`$@```/F*`0`8````#(L!`!L````EBP$`
M"````$&+`0`"````2HL!``8```!-BP$`$@```%2+`0`.````9XL!``4```!V
MBP$`#@```'R+`0`(````BXL!``,```"4BP$`#@```)B+`0`(````IXL!``D`
M``"PBP$`!@```+J+`0`-````P8L!``<```#/BP$`#````->+`0`1````Y(L!
M``P```#VBP$`#`````.,`0`1````$(P!``D````BC`$`!@```"R,`0`+````
M,XP!``P````_C`$`"P```$R,`0`1````6(P!`!P```!JC`$`"P```(>,`0`-
M````DXP!`!\```"AC`$`%````,&,`0`:````UHP!`#$```#QC`$`"@```".-
M`0`5````+HT!`!(```!$C0$`%0```%>-`0`2````;8T!`!4```"`C0$`)```
M`):-`0`+````NXT!``<```#'C0$`#0```,^-`0`K````W8T!`!$````)C@$`
M"P```!N.`0`B````)XX!`"\```!*C@$`"@```'J.`0`)````A8X!`!X```"/
MC@$`"P```*Z.`0`;````NHX!`!L```#6C@$`!P```/*.`0`7````^HX!`!4`
M```2CP$`'````"B/`0`7````18\!``X```!=CP$`"@```&R/`0`(````=X\!
M``L```"`CP$`(@```(R/`0`Y````KX\!`!<```#ICP$`(P````&0`0`%````
M)9`!``@````KD`$`+0```#20`0`*````8I`!``8```!MD`$`!@```'20`0!6
M````>Y`!``,```#2D`$`!P```-:0`0`%````WI`!``L```#DD`$`"P```/"0
M`0`0````_)`!`!(````-D0$`&0```""1`0`8````.I$!`!L```!3D0$`&P``
M`&^1`0`*````BY$!``<```"6D0$`"P```)Z1`0`*````JI$!``(```"UD0$`
M!@```+B1`0`,````OY$!`"4```#,D0$`(````/*1`0`6````$Y(!``P````J
MD@$`$````#>2`0`.````2)(!`!````!7D@$`!````&B2`0`'````;9(!``\`
M``!UD@$`(0```(62`0`8````IY(!``,```#`D@$`'0```,22`0`L````XI(!
M`"L````/DP$`'````#N3`0`I````6),!`",```""DP$`%P```*:3`0`:````
MOI,!``<```#9DP$`"````.&3`0`&````ZI,!``8```#QDP$`#@```/B3`0`.
M````!Y0!``\````6E`$`#0```":4`0`0````-)0!``\```!%E`$`"P```%64
M`0`2````890!``,```!TE`$`"0```'B4`0`2````@I0!``X```"5E`$`+P``
M`*24`0`-````U)0!``@```#BE`$`#0```.N4`0`@````^90!`"4````:E0$`
M)@```$"5`0`E````9Y4!`",```"-E0$`(P```+&5`0`K````U94!`"(````!
ME@$`&@```"26`0`#````/Y8!``X```!#E@$`"````%*6`0`+````6Y8!``,`
M``!GE@$`!0```&N6`0`(````<98!``D```!ZE@$`"P```(26`0`/````D)8!
M`!(```"@E@$`"@```+.6`0`.````OI8!``X```#-E@$`!````-R6`0`#````
MX98!`!,```#EE@$`%0```/F6`0`,````#Y<!``<````<EP$`!@```"27`0`.
M````*Y<!`!H````ZEP$`!@```%67`0`'````7)<!``T```!DEP$`#@```'*7
M`0`7````@9<!``@```"9EP$``P```**7`0`E````II<!``T```#,EP$`3@``
M`-J7`0`4````*9@!``@````^F`$`"@```$>8`0`1````4I@!``H```!DF`$`
M#````&^8`0`%````?)@!``X```""F`$``@```)&8`0`%````E)@!``D```":
MF`$`$P```*28`0`:````N)@!`!,```#3F`$`&````.>8`0`@`````)D!``X`
M```AF0$`$@```#"9`0`9````0YD!``0```!=F0$`"0```&*9`0`7````;)D!
M``@```"$F0$`$0```(V9`0`%````GYD!`!@```"EF0$`"````+Z9`0`&````
MQYD!`!T```#.F0$`#0```.R9`0`(````^ID!``@````#F@$`!0````R:`0`)
M````$IH!``<````<F@$`%0```"2:`0`"````.IH!``8````]F@$`#````$2:
M`0`-````49H!``@```!?F@$`%````&B:`0`$````?9H!``@```""F@$`!P``
M`(N:`0`#````DYH!`!,```"7F@$`/0```*N:`0`F````Z9H!`"D````0FP$`
M!P```#J;`0`$````0IL!``D```!'FP$`"````%&;`0`0````6IL!`!,```!K
MFP$`!P```'^;`0`&````AYL!``T```".FP$`!@```)R;`0`$````HYL!`#$`
M``"HFP$`-@```-J;`0`S````$9P!`!H```!%G`$`!0```&"<`0`,````9IP!
M``4```!SG`$`!@```'F<`0`(````@)P!`!@```")G`$`$@```**<`0`7````
MM9P!``0```#-G`$`#0```-*<`0`%````X)P!`!$```#FG`$`#0```/B<`0`(
M````!IT!`!<````/G0$``P```">=`0`$````*YT!``,````PG0$`"P```#2=
M`0`*````0)T!``P```!+G0$`"````%B=`0`)````89T!``4```!KG0$`/0``
M`'&=`0`Q````KYT!`#\```#AG0$`'0```"&>`0!!````/YX!`#<```"!G@$`
M*````+F>`0`Y````XIX!`"X````<GP$`,@```$N?`0`A````?I\!`!$```"@
MGP$`%0```+*?`0`,````R)\!`"\```#5GP$`)`````6@`0`D````*J`!`",`
M``!/H`$`"0```'.@`0`*````?:`!``H```"(H`$`!@```).@`0`E````FJ`!
M`"8```#`H`$`,````.>@`0`)````&*$!`!X````BH0$`*@```$&A`0`:````
M;*$!`!````"'H0$`!@```)BA`0`-````GZ$!``T```"MH0$`#P```+NA`0`2
M````RZ$!`#L```#>H0$`D0```!JB`0!D````K*(!`!4````1HP$`"@```">C
M`0`+````,J,!`!$````^HP$`$@```%"C`0`.````8Z,!``8```!RHP$`$@``
M`'FC`0`4````C*,!`!$```"AHP$`"````+.C`0`1````O*,!`"0```#.HP$`
M*@```/.C`0!N````'J0!``H```"-I`$`!@```)BD`0`6````GZ0!``H```"V
MI`$`!````,&D`0`+````QJ0!`"<```#2I`$`%````/JD`0`+````#Z4!``T`
M```;I0$`#P```"FE`0`3````.:4!`"4```!-I0$`)````'.E`0`<````F*4!
M`!X```"UI0$`(0```-2E`0`@````]J4!`!8````7I@$`$0```"ZF`0`0````
M0*8!`!,```!1I@$`$@```&6F`0`2````>*8!`!4```"+I@$`%````*&F`0`0
M````MJ8!``\```#'I@$`*0```->F`0`1`````:<!`!$````3IP$`.P```"6G
M`0`4````8:<!``8```!VIP$`#````'VG`0`G````BJ<!`"$```"RIP$`%@``
M`-2G`0`5````ZZ<!`!(````!J`$`%@```!2H`0`<````*Z@!`!,```!(J`$`
M%0```%RH`0`:````<J@!`!@```"-J`$`'0```*:H`0`A````Q*@!`"$```#F
MJ`$`%0````BI`0`4````'JD!`!0````SJ0$`&````$BI`0`:````8:D!`!@`
M``!\J0$`%@```)6I`0`+````K*D!``\```"XJ0$`!````,BI`0`$````S:D!
M``8```#2J0$`"P```-FI`0`1````Y:D!``8```#WJ0$`"P```/ZI`0`&````
M"JH!``<````1J@$`!P```!FJ`0`'````(:H!``4````IJ@$`%0```"^J`0`&
M````1:H!``D```!,J@$`!````%:J`0`$````6ZH!``<```!@J@$`#0```&BJ
M`0`,````=JH!``X```"#J@$`#````)*J`0`%````GZH!`"D```"EJ@$`#0``
M`,^J`0`+````W:H!``L```#IJ@$`"0```/6J`0`0````_ZH!`#`````0JP$`
M!````$&K`0`(````1JL!``4```!/JP$`"0```%6K`0`(````7ZL!`!$```!H
MJP$`!@```'JK`0`)````@:L!``<```"+JP$`!0```).K`0`$````F:L!``P`
M``">JP$`$0```*NK`0`/````O:L!`!(```#-JP$`%@```."K`0`>````]ZL!
M`!H````6K`$`"````#&L`0`(````.JP!``,```!#K`$`!@```$>L`0`E````
M3JP!``<```!TK`$`!P```'RL`0`-````A*P!``T```"2K`$`!P```*"L`0`$
M````J*P!``<```"MK`$`!@```+6L`0`-````O*P!``<```#*K`$`"````-*L
M`0`)````VZP!`!,```#EK`$`%0```/FL`0`-````#ZT!`!(````=K0$`"```
M`#"M`0`,````.:T!``@```!&K0$`!````$^M`0`0````5*T!`$(```!EK0$`
M!@```*BM`0`$````KZT!`!\```"TK0$`#@```-2M`0`/````XZT!``X```#S
MK0$`#`````*N`0`)````#ZX!``<````9K@$`"@```"&N`0`)````+*X!``X`
M```VK@$`$````$6N`0`E````5JX!`"4```!\K@$`(@```**N`0`*````Q:X!
M``<```#0K@$`"0```-BN`0`+````XJX!``D```#NK@$`!0```/BN`0`(````
M_JX!``@````'KP$`!0```!"O`0`0````%J\!`$X````GKP$`&````':O`0`)
M````CZ\!``8```"9KP$``P```*"O`0`0````I*\!`!````"UKP$`%````,:O
M`0`&````VZ\!``H```#BKP$`"0```.VO`0`"````]Z\!``0```#ZKP$`(P``
M`/^O`0`#````([`!``4````GL`$`"@```"VP`0`*````.+`!``8```!#L`$`
M!@```$JP`0`+````4;`!``T```!=L`$`!@```&NP`0`(````<K`!``H```![
ML`$`!````(:P`0`%````B[`!`'8```"1L`$`"P````BQ`0`.````%+$!`!<`
M```CL0$`!````#NQ`0`(````0+$!`!4```!)L0$`+P```%^Q`0`-````C[$!
M``H```"=L0$`#@```*BQ`0`+````M[$!``D```##L0$`%````,VQ`0`S````
MXK$!`"@````6L@$`)P```#^R`0`:````9[(!``T```""L@$``P```)"R`0`'
M````E+(!``<```"<L@$`"P```*2R`0`0````L+(!``X```#!L@$`"0```-"R
M`0`0````VK(!`!L```#KL@$`"0````>S`0`)````$;,!``\````;LP$`"@``
M`"NS`0!-````-K,!`!X```"$LP$`#0```*.S`0`*````L;,!`"$```"\LP$`
M3````-ZS`0`9````*[0!``4```!%M`$`'P```$NT`0`N````:[0!``<```":
MM`$`!@```**T`0`+````J;0!``8```"UM`$`!P```+RT`0`G````Q+0!`"8`
M``#LM`$`*@```!.U`0`&````/K4!``<```!%M0$`+P```$VU`0!5````?;4!
M`!4```#3M0$`)P```.FU`0`3````$;8!``(````EM@$`#````"BV`0`(````
M-;8!``P````^M@$`"@```$NV`0`'````5K8!``D```!>M@$`!@```&BV`0`)
M````;[8!``P```!YM@$`"````(:V`0`)````C[8!``@```"9M@$`,@```**V
M`0`'````U;8!``\```#=M@$`$0```.VV`0`0````_[8!``H````0MP$`#@``
M`!NW`0`,````*K<!``H````WMP$`"@```$*W`0`*````3;<!``H```!8MP$`
M!P```&.W`0`.````:[<!`!P```!ZMP$`!P```)>W`0`*````G[<!`!0```"J
MMP$`"@```+^W`0`0````RK<!``<```#;MP$`&````..W`0`$````_+<!``<`
M```!N`$`!0````FX`0`$````#[@!``X````4N`$`!0```".X`0`-````*;@!
M`!<````WN`$`#P```$^X`0`6````7[@!`!D```!VN`$`%P```)"X`0`<````
MJ+@!`!8```#%N`$`!P```-RX`0`&````Y+@!``X```#KN`$`"P```/JX`0`7
M````!KD!``8````>N0$`'````"6Y`0`+````0KD!``T```!.N0$`(@```%RY
M`0`:````?[D!`!4```":N0$`!P```+"Y`0`-````N+D!``4```#&N0$`$```
M`,RY`0`3````W;D!``8```#QN0$`"0```/BY`0`%`````KH!``<````(N@$`
M!````!"Z`0`$````%;H!``,````:N@$`.P```!ZZ`0`S````6KH!`!(```".
MN@$`+P```*&Z`0`R````T;H!``X````$NP$`/````!.[`0`O````4+L!`#0`
M``"`NP$`-````+6[`0`X````ZKL!`!(````CO`$`$P```#:\`0`8````2KP!
M`!,```!CO`$`%0```'>\`0`2````C;P!`!(```"@O`$`&P```+.\`0`3````
MS[P!`!4```#CO`$`&@```/F\`0`N````%+T!`"X```!#O0$`,@```'*]`0`O
M````I;T!`#````#5O0$`+0````:^`0`=````-+X!`!,```!2O@$`%````&:^
M`0`+````>[X!`!D```"'O@$`"@```*&^`0`/````K+X!`"P```"\O@$`+@``
M`.F^`0`B````&+\!``L````[OP$`50```$>_`0!&````G;\!``X```#DOP$`
M!0```/._`0`<````^;\!``P````6P`$`$````"/``0`2````-,`!``4```!'
MP`$`"@```$W``0`)````6,`!``\```!BP`$`$0```'+``0`*````A,`!``L`
M``"/P`$`#````)O``0`@````J,`!``,```#)P`$`"````,W``0`&````UL`!
M``P```#=P`$`#@```.K``0`+````^<`!`$(````%P0$``@```$C!`0`&````
M2\$!``T```!2P0$`!0```&#!`0`'````9L$!`!D```!NP0$`!@```(C!`0`N
M````C\$!`!````"^P0$`'0```,_!`0`$````[<$!`"H```#RP0$`'````!W"
M`0`@````.L(!`%D```!;P@$`%````+7"`0!'````RL(!`!D````2PP$`#@``
M`"S#`0`<````.\,!``T```!8PP$`%````&;#`0`.````>\,!``P```"*PP$`
M$@```)?#`0`*````JL,!`!P```"UPP$`&0```-+#`0`%````[,,!`!,```#R
MPP$`$`````;$`0`F````%\0!`!,````^Q`$`%0```%+$`0`2````:,0!`!$`
M``![Q`$`&0```(W$`0`'````I\0!``@```"OQ`$`$P```+C$`0`.````S,0!
M`!(```#;Q`$`#P```.[$`0`:````_L0!``\````9Q0$`&@```"G%`0`4````
M1,4!``D```!9Q0$`"@```&/%`0`(````;L4!``4```!WQ0$`"0```'W%`0`&
M````A\4!`!````".Q0$`"````)_%`0`.````J,4!``@```"WQ0$`$@```,#%
M`0`2````T\4!`"@```#FQ0$`&`````_&`0`)````*,8!``H````RQ@$`&0``
M`#W&`0`*````5\8!`"(```!BQ@$`!@```(7&`0`8````C,8!``D```"EQ@$`
M!P```*_&`0`:````M\8!`"L```#2Q@$`"@```/[&`0`?````"<<!``T````I
MQP$`#````#?'`0`9````1,<!`!4```!>QP$`!````'3'`0`'````><<!``P`
M``"!QP$`!P```(['`0`%````EL<!``@```"<QP$`!@```*7'`0`(````K,<!
M`!@```"UQP$`)@```,['`0`M````]<<!`!H````CR`$`(````#[(`0`?````
M7\@!`$0```!_R`$`'````,3(`0`=````X<@!`"0```#_R`$`6P```"3)`0!;
M````@,D!`$H```#<R0$`(@```"?*`0`7````2LH!``4```!BR@$`!P```&C*
M`0`.````<,H!``@```!_R@$`%P```(C*`0`9````H,H!`"X```"ZR@$`"```
M`.G*`0`B````\LH!`!@````5RP$`'P```"[+`0`[````3LL!``4```"*RP$`
M%0```)#+`0`+````ILL!``\```"RRP$`(P```,++`0`8````YLL!`!$```#_
MRP$`#@```!',`0`'````(,P!`!(````HS`$`!P```#O,`0`$````0\P!``T`
M``!(S`$`%0```%;,`0`8````;,P!`"\```"%S`$`"P```+7,`0`1````P<P!
M``4```#3S`$`!0```-G,`0`%````W\P!`!P```#ES`$`"P````+-`0`$````
M#LT!``L````3S0$`"0```!_-`0`*````*<T!``P````TS0$`#0```$'-`0`7
M````3\T!``L```!GS0$``P```'/-`0`/````=\T!`#D```"'S0$`2@```,'-
M`0`<````#,X!``D````IS@$`(````#/.`0`3````5,X!``4```!HS@$`$0``
M`&[.`0`(````@,X!``L```")S@$`)P```)7.`0`,````O<X!`",```#*S@$`
M!P```.[.`0`-````]LX!``X````$SP$`$P```!//`0`9````)\\!``L```!!
MSP$`,P```$W/`0`'````@<\!`"````")SP$`$0```*K/`0`5````O,\!``T`
M``#2SP$`'````.#/`0!!````_<\!`#,````_T`$`"````'/0`0`P````?-`!
M`"P```"MT`$`-@```-K0`0`W````$=$!`#````!)T0$`$P```'K1`0`6````
MCM$!``D```"ET0$`$@```*_1`0`2````PM$!`!@```#5T0$`"````.[1`0`;
M````]]$!`!(````3T@$`!P```";2`0`7````+M(!`"(```!&T@$`!0```&G2
M`0`%````;](!``L```!UT@$`"P```('2`0`4````C=(!``0```"BT@$`"```
M`*?2`0`*````L-(!``X```"[T@$`#````,K2`0`0````U](!`!````#HT@$`
M!@```/G2`0`&`````-,!`"L````'TP$`(P```#/3`0`@````5],!``,```!X
MTP$`"````'S3`0`&````A=,!``\```",TP$`&P```)S3`0`G````N-,!``\`
M``#@TP$`"````/#3`0`A````^=,!``,````;U`$`!@```!_4`0`)````)M0!
M``(````PU`$`#````#/4`0`5````0-0!``L```!6U`$`&0```&+4`0`>````
M?-0!`!$```";U`$`!0```*W4`0`*````L]0!`!4```"^U`$`$@```-34`0`,
M````Y]0!``4```#TU`$`"@```/K4`0`(````!=4!`!,````.U0$`3````"+5
M`0`=````;]4!`"4```"-U0$`$0```+/5`0`)````Q=4!``,```#/U0$`"@``
M`-/5`0`*````WM4!``X```#IU0$`&0```/C5`0`-````$M8!``L````@U@$`
M'0```"S6`0`)````2M8!`!8```!4U@$`#P```&O6`0`*````>]8!`&````"&
MU@$`&@```.?6`0`1`````M<!`!T````4UP$`&````#+7`0`0````2]<!`!@`
M``!<UP$`%0```'77`0`9````B]<!`!P```"EUP$`%0```,+7`0`*````V-<!
M``<```#CUP$`"````.O7`0`)````]-<!`!8```#^UP$`"P```!78`0`S````
M(=@!`!8```!5V`$`&````&S8`0`)````A=@!``0```"/V`$`20```)38`0`^
M````WM@!`#D````=V0$`6P```%?9`0`%````L]D!`#0```"YV0$`)0```.[9
M`0`,````%-H!``8````AV@$`#@```"C:`0`V````-]H!``0```!NV@$`3```
M`'/:`0`K````P-H!`"D```#LV@$`"P```!;;`0`A````(ML!`!X```!$VP$`
M%P```&/;`0`3````>]L!`!,```"/VP$`(@```*/;`0`0````QML!``8```#7
MVP$`#0```-[;`0`+````[-L!`!$```#XVP$`"0````K<`0`O````%-P!``P`
M``!$W`$`"@```%'<`0`(````7-P!`!````!EW`$`!P```';<`0`)````?MP!
M``<```"(W`$`$````)#<`0`)````H=P!``D```"KW`$``P```+7<`0`'````
MN=P!``D```#!W`$`$````,O<`0`.````W-P!``D```#KW`$`&@```/7<`0`,
M````$-T!``<````=W0$`$0```"7=`0`6````-]T!``H```!.W0$`"0```%G=
M`0`B````8]T!`!````"&W0$`(P```)?=`0`K````N]T!``D```#GW0$`"0``
M`/'=`0`7````^]T!``<````3W@$`!````!O>`0`=````(-X!``D````^W@$`
M"P```$C>`0`(````5-X!``<```!=W@$`"0```&7>`0`(````;]X!``D```!X
MW@$`!0```(+>`0`'````B-X!`!$```"0W@$`!@```*+>`0`.````J=X!``H`
M``"XW@$`#````,/>`0`+````T-X!`!L```#<W@$`"@```/C>`0`"`````]\!
M`"$````&WP$`!@```"C?`0`&````+]\!`',````VWP$`"````*K?`0`&````
ML]\!`!L```"ZWP$`)P```-;?`0`/````_M\!`!T````.X`$`2````"S@`0`<
M````=>`!`!\```"2X`$`$@```++@`0`(````Q>`!``4```#.X`$`#P```-3@
M`0`*````Y.`!``H```#OX`$`!@```/K@`0`*`````>$!`!(````,X0$`#```
M`!_A`0`*````+.$!``P````WX0$`!P```$3A`0`'````3.$!``@```!4X0$`
M"0```%WA`0`6````9^$!``D```!^X0$`!P```(CA`0`'````D.$!`!H```"8
MX0$`!@```+/A`0`7````NN$!``8```#2X0$`!P```-GA`0`5````X>$!``D`
M``#WX0$`$`````'B`0`'````$N(!``8````:X@$`$P```"'B`0`1````->(!
M`!,```!'X@$`!@```%OB`0`&````8N(!``H```!IX@$`"````'3B`0`$````
M?>(!``D```""X@$`!````(SB`0`-````D>(!`"(```"?X@$`"@```,+B`0`,
M````S>(!`"D```#:X@$`%P````3C`0`6````'.,!`!L````SXP$`%@```$_C
M`0`$````9N,!``L```!KXP$`#0```'?C`0`'````A>,!``(```"-XP$`#@``
M`)#C`0`(````G^,!`"(```"HXP$`'P```,OC`0`C````Z^,!`"`````/Y`$`
M-0```##D`0`A````9N0!`"<```"(Y`$`*P```+#D`0!D````W.0!`!(```!!
MY0$`(0```%3E`0`^````=N4!`",```"UY0$`3P```-GE`0!(````*>8!`"8`
M``!RY@$`/P```)GF`0`A````V>8!`"\```#[Y@$`+@```"OG`0`G````6N<!
M`"<```""YP$`(0```*KG`0`V````S.<!`!L````#Z`$`$0```!_H`0`6````
M,>@!`$L```!(Z`$`<````)3H`0`X````!>D!`"H````^Z0$`-0```&GI`0!B
M````G^D!`%0````"Z@$`*P```%?J`0`<````@^H!``\```"@Z@$`(0```+#J
M`0`6````TNH!`!4```#IZ@$`+0```/_J`0`<````+>L!`!L```!*ZP$`+0``
M`&;K`0`=````E.L!`#T```"RZP$`&0```/#K`0`-````"NP!`"X````8[`$`
M)P```$?L`0`V````;^P!`"D```"F[`$`'````-#L`0`@````[>P!`#8````.
M[0$`4````$7M`0`Q````ENT!`$,```#([0$`+`````SN`0`C````.>X!`#<`
M``!=[@$`8P```)7N`0!,````^>X!`#,```!&[P$`'@```'KO`0`@````F>\!
M`"$```"Z[P$`(````-SO`0`T````_>\!`%\````R\`$`40```)+P`0`\````
MY/`!`#\````A\0$`*@```&'Q`0`:````C/$!`"@```"G\0$`+0```-#Q`0`M
M````_O$!`!4````L\@$`@P```$+R`0!W````QO(!`(`````^\P$`R````+_S
M`0`9````B/0!`",```"B]`$`+@```,;T`0`G````]?0!`$<````=]0$`(@``
M`&7U`0!0````B/4!`"0```#9]0$`#@```/[U`0!!````#?8!`"0```!/]@$`
M+@```'3V`0`G````H_8!`"0```#+]@$`.@```/#V`0`$````*_<!``<````P
M]P$``P```#CW`0`/````//<!``H```!,]P$`!P```%?W`0`(````7_<!``8`
M``!H]P$`$0```&_W`0`$````@?<!`%L```"&]P$`!````.+W`0`/````Y_<!
M``0```#W]P$`!P```/SW`0`'````!/@!``4````,^`$``P```!+X`0`0````
M%O@!``X````G^`$`$P```#;X`0`1````2O@!``(```!<^`$`"````%_X`0`'
M````:/@!`!0```!P^`$`#````(7X`0`6````DO@!``8```"I^`$`#P```+#X
M`0`*````P/@!``,```#+^`$`*````,_X`0`$````^/@!``8```#]^`$`!P``
M``3Y`0`7````#/D!`$@````D^0$`*0```&WY`0`L````E_D!`!<```#$^0$`
M)0```-SY`0`F`````OH!`"D````I^@$`'0```%/Z`0`:````<?H!`!D```",
M^@$`&P```*;Z`0`8````POH!`!<```#;^@$`'0```//Z`0`;````$?L!`!@`
M```M^P$`)P```$;[`0`8````;OL!`"<```"'^P$`(P```*_[`0`9````T_L!
M`!T```#M^P$`&P````O\`0`8````)_P!`!X```!`_`$`(@```%_\`0`=````
M@OP!`"8```"@_`$`(@```,?\`0`8````ZOP!`!H````#_0$`)0```![]`0`7
M````1/T!`"$```!<_0$`,````'[]`0`S````K_T!`!,```#C_0$`)@```/?]
M`0`^````'OX!`!\```!=_@$`(P```'W^`0`A````H?X!`"0```##_@$`'@``
M`.C^`0`8````!_\!`"$````@_P$`(````$+_`0`S````8_\!`"(```"7_P$`
M-P```+K_`0`,````\O\!``\```#__P$`&0````\``@`I````*0`"`!\```!3
M``(`$````',``@`B````A``"``\```"G``(`%0```+<``@`.````S0`"`!``
M``#<``(`&P```.T``@`'````"0$"``4````1`0(`*0```!<!`@`D````00$"
M`!<```!F`0(`(@```'X!`@`D````H0$"``<```#&`0(`U````,X!`@`,````
MHP("`!0```"P`@(`"0```,4"`@`,````SP("`!P```#<`@(`$P```/D"`@`1
M````#0,"`!L````?`P(`"0```#L#`@`R````10,"``@```!X`P(`$````($#
M`@`'````D@,"`!(```":`P(`"@```*T#`@`V````N`,"``D```#O`P(`)```
M`/D#`@`6````'@0"`!4````U!`(`%````$L$`@`F````8`0"`!P```"'!`(`
M#````*0$`@`<````L00"``T```#.!`(`#@```-P$`@`5````ZP0"``H````!
M!0(`&`````P%`@`(````)04"`"D````N!0(`"0```%@%`@`/````8@4"`"H`
M``!R!0(`!@```)T%`@`5````I`4"``<```"Z!0(`"````,(%`@`)````RP4"
M`#L```#5!0(`!P```!$&`@`0````&08"`!(````J!@(`$@```#T&`@`)````
M4`8"``L```!:!@(`!P```&8&`@`5````;@8"``<```"$!@(`%P```(P&`@`+
M````I`8"``T```"P!@(`#````+X&`@`7````RP8"`!D```#C!@(`!````/T&
M`@`%`````@<"`!D````(!P(`!````"('`@`L````)P<"``P```!4!P(`$0``
M`&$'`@`'````<P<"``(```![!P(`#````'X'`@`.````BP<"``L```":!P(`
M!````*8'`@`)````JP<"`!,```"U!P(`%@```,D'`@`(````X`<"``D```#I
M!P(`$0```/,'`@`-````!0@"`!D````3"`(`&@```"T(`@`-````2`@"`#(`
M``!6"`(`'@```(D(`@`C````J`@"`!<```#,"`(`"P```.0(`@`S````\`@"
M``4````D"0(`$0```"H)`@!"````/`D"``L```!_"0(`"@```(L)`@`&````
ME@D"``0```"="0(`!````*()`@`*````IPD"`!0```"R"0(`!0```,<)`@`&
M````S0D"``8```#4"0(`"@```-L)`@`&````Y@D"``X```#M"0(`#P```/P)
M`@`T````#`H"`"H```!!"@(`)P```&P*`@`%````E`H"`!X```":"@(`#@``
M`+D*`@`"````R`H"``0```#+"@(`"@```-`*`@`%````VPH"``4```#A"@(`
M`@```.<*`@`1````Z@H"`$,```#\"@(`+@```$`+`@`8````;PL"`",```"(
M"P(`(P```*P+`@`F````T`L"``\```#W"P(`7@````<,`@`@````9@P"`$<`
M``"'#`(`)````,\,`@!!````]`P"`"@````V#0(`*@```%\-`@`P````B@T"
M`#$```"[#0(`-0```.T-`@`T````(PX"`"H```!8#@(`)````(,.`@`J````
MJ`X"`#(```#3#@(`$`````8/`@`1````%P\"``\````I#P(`;````#D/`@`)
M````I@\"`*D```"P#P(`7P```%H0`@!W````NA`"`"X````R$0(`6````&$1
M`@`5````NA$"`",```#0$0(`%P```/01`@`7````#!("`!L````D$@(`'P``
M`$`2`@`Y````8!("`",```":$@(`(P```+X2`@!8````XA("`!H````[$P(`
M$@```%83`@`+````:1,"``4```!U$P(`!@```'L3`@`(````@A,"``4```"+
M$P(`$@```)$3`@`,````I!,"`!0```"Q$P(`'@```,83`@`.````Y1,"``\`
M``#T$P(`!`````04`@`)````"10"``L````3%`(`"````!\4`@`&````*!0"
M`!4````O%`(`"0```$44`@`)````3Q0"``X```!9%`(`#@```&@4`@`-````
M=Q0"`!````"%%`(`!@```)84`@`7````G10"``H```"U%`(`"0```,`4`@`/
M````RA0"``@```#:%`(`!0```.,4`@`4````Z10"`!4```#^%`(`"@```!05
M`@`&````'Q4"``\````F%0(`$0```#85`@`8````2!4"``T```!A%0(`!0``
M`&\5`@`8````=14"``@```".%0(``P```)<5`@`9````FQ4"``D```"U%0(`
M`@```+\5`@`"````PA4"``\```#%%0(`!@```-45`@`&````W!4"``\```#C
M%0(`%P```/,5`@`&````"Q8"`!8````2%@(``@```"D6`@`$````+!8"`!(`
M```Q%@(`$@```$06`@`0````5Q8"``<```!H%@(`#0```'`6`@`&````?A8"
M``P```"%%@(`"````)(6`@`:````FQ8"``\```"V%@(`$@```,86`@`"````
MV18"``<```#<%@(`"0```.06`@`-````[A8"``\```#\%@(`*P````P7`@`$
M````.!<"``<````]%P(`"P```$47`@`%````41<"``(```!7%P(`"P```%H7
M`@`!````;0,````````2!````````&@&``!<`P``K0(``&T'``"[`0``8P,`
M`+T```#$!0````````````"+`@``_`8`````````````!P```+T!```<!0``
MQ@,``-P"``#C````;@```/8````J!0```08```````#0`P``T`0``"8"``"%
M````_@(``*4#``#5`0```````+0$``!'`0``,P8``,\%``!A!P``1`0``-0!
M````````V@$``!X```#\`0``4@(```````#0````4`(````````=!0``-@,`
M``D```"-!@```````,(#````````*`,``!0```"!`0``/0,`````````````
MJ`4``*X!```4`0``U@0``(D'``#@!P````````````#_`0````````````"$
M!```KP0``,L!``#"!@```````.4%````````]`(```````"#!@```````#`&
M``!X!P``4`<``!\"``!E!````````(P&``!G`0```````&\````'!P``W00`
M`*X&````````C@<``*L!``"M!P``G04```````#.`P``6P```&L&``!M!0``
M@P$``#4`````````5@<```````#[!```B`8`````````````5@4````````B
M!```Z0$````````^!@``*@,``.,$````````-P$``,$$````````$P$`````
M````````=0,``*P!```(`@```````&X%``!\!P``G0$``,,&````````<@``
M``````"]`@``&@<``.X"``#6!@```````-D$``!&!0``\`(``"X%``#N````
M%@(``(H!``!S`P``F@```'P%``"K!P````````````#'!@```````-D"```U
M!P``6@(``-,```!(`0```````&,`````````+0<``'`#```A!```````````
M```\!0````````8#``#>!@```````(H$``"'!0``,`<``/\&````````````
M`&P!``#P!@```````+D'````````-0,``*8!``#D!0```````&@!```+!P``
M````````````````X@8````````3`@``M`4```````"`!@``<0<````````I
M`@``!P$```P%`````````````-\"``!%!P``$@$``),'``#M`@``[00``%P"
M``!9````ZP8``-,$``!M`0````4``-$!````````TP8```````#V!0``P`,`
M``````"2!0``/`0``"`&````````,P0``-T%``"R`````````$`#````````
MF@0``*<$``#M!@``,0(````````9!P``/P,``&$```"-!P``E@(``%<!````
M``````````H$````````T`4``'L#``"9`0``\P0```````!H````W@0``'($
M``!?!P``=P```+\&``!3!```/@(``!$&````````50(``!$```"A!0``````
M`&(&``!<!0````````````#8````6`4``"<"``#+````PP$`````````````
M$`4```````#>````P08```````!$!0```````(,"``"D````^P8``)`%````
M````'08``-H%``!%!0``DP8``*$'``!P!0``^00``.8$``"W!P``````````
M````````5@(``$\'`````````````&4"``!)`P``(P8``$,%``#Q!@``O```
M`.$#``````````````<"``!-`@``V@,``#L#````````9`<``(`%````````
M9P0``"\$``"C!P```````&T"``!Z!@``)@$``$<#````````N`(``+X#``!F
M`@``?`8``,0$``"%`0``0@0```4"``"5`@``A````%P$````````@@```"$`
M``"G!P``J@4``(`#``#6`0``M@8```H#````````S`(``/L"``"6`0``N```
M``$#``"<`0``,P$```X&```9`P``R`$``$<"``!*!0```````,`%``!-!P``
MD@<``"D%``#(`@``````````````````8@,``!D!``#Q`@``<`````````#E
M`0``K@,``$L```"I`@``.P$``"X#``!#`P``OP$````````T`0``L0,``$D%
M``#]````"`,``(D&``!(`P``]@$``-P!````````T@$```````"9!```````
M`*('``#.!P`````````````[!0``200``),$````````4P<```````"'`0``
M&@$``",$```\`0``'0<``/X$``#*!P``L08``(\````>!0``\04``!H#````
M````S0```*L%```E`P``@````/P%````````X08````````O!0``Q04``(,%
M````````+0,``&X!``#2!P``Q0(``-T```#+!`````````````"G````'@(`
M`"L!``````````````````"O````H`8``#@$``!6!@``;@,``/0$```8!P``
MR````*0'``#"``````````4'```]!```L`8```('``"-`P``.08``.8````T
M`@``1P```!`#``"P!0```````*@"```G!0``-P0```````!A`P``W@<``&D%
M````````L`<```````"7!0```````(D"``#<!```9P8``"<'````!P``M0(`
M`#T!``"Y!0```````#D$```)`@``G0<```````"X`P``!@```,X&```\````
M7@$``%T%``"``0``UP,``-`!``!.`````````&D&``!3!@``&P4``$$"``")
M````KP8``!\``````````````,\$``"$`0``R0```!L#``#Y!@```````,0`
M````````L0$```````#O`@``50,```````!(!P```````$('``"8!@``Q`,`
M```````0!```5`<``````````````P<```````##`````````,T$````````
MD@8``,P#````````FP8``.X!``"(`@``8`4``&H"``"7!@``(P,`````````
M````N00``"\'```+!0``J`<``.<$``"4`0```````.H!``"F`@``"P(``-$`
M```$`0``RP,```````#G`P``.`<``,````#M`0``:`0`````````````$@``
M`'(!``!3`@```````)(```````````````````#.`@``H`(```````"O!0``
M!0````````#A`0```````#P&``!.`P``5`0``+4'````````4P4``"0'````
M```````````````_!P``#00```````!:!0```````"<#``"8`P``.0(``",'
M```3!P``D````%L!``!&!@``V@<``````````````````'H$````````DP``
M`$P$``#N!0````````````"4`@```````.D%``#$`@``.````#T&``!Q`0``
ME0,```````#!``````````H&``">`0``208``)D%``"^!P````````8!````
M````>`(```````!0`0``N0(``%4%``"+!@``G`4``%D$``#7!P``+`(``,P%
M````````#`<``*$!``#6!P```````#L"``!,`P``C`(``,`$````````````
M`/L#````````3@$``*<"``!6`0``=0$``#\&`````````````%H#``#@!0``
M`````$<%``"D!0``VP<``*(!``!J!P``3`8``)@"`````````````&L!```L
M!P``&`4```X#``"I!P``J@0```````";`0``J@(``/0&````````0@8`````
M``!-!@``G`0``,D!```S!P```````,P!``#*!@``2`4`````````````3@<`
M`-T#```0!P``@@8``-(#``!$`P```````$,'```P!`````````````#!`0``
MR`4```````"S!````````'D$``#U!```(0<``*,$```Z!P``S0$``,,'``#2
M!````````.T```")!``````````````Q!0``50<`````````````V`0``'X$
M``!Y!P``C00``.@````2`P```````*(```"T!@``*P<```````"V`P``_P(`
M`$H!``#I````8@<``'@&````````A0<````````_`@``30$``(,'``"P`@``
M`````"(#``!O`0``U0```'T%``!M!@``-00```8'```2`@``(@8``(4%````
M````,`(``+P"```L!0``6`(```(%````````M08``!8'```*!0``@@$`````
M````````K@4``$P"``"@`0``8@````P````V`@``90````````"Z!```````
M`,\````C`````````&P%`````````````(@$````````_08``'4$````````
MHP$```````"_!```WP,``!8%``![!P```````+P&``#P`0```````-T'``"$
M!@``Z`4``.X#````````404``&L#``"J`````````"('``#E!@``-P,``-0#
M```Q!@```````$T%``"K`````````&<"````````,0$```,$``!8`0``;`8`
M````````````'P4``$`"``"'`P```````&D'``!-`P````````````"+!0``
M!`4``)L'``#1!0``0@$``!4"```O!@````````````!@!```=P0``-\```#+
M!@````````````````````````````````````````````#A!```+0$``/<"
M```_````HP8``&P'```^`P``GP4``&<'````````L@,``#(%```_!0``````
M```````_!```L`$```````#D`````````%<'``#'`````````%D&``#]!0``
M`````&T````8!@```````"X!```2!0``60<``/L```!P!```?P```(@!``#E
M!```T@```.@&``!]`P``B@8````````U!@```````.D$``!S!0``BP,``$`$
M``#,!@``'00```````##!```?0$``-X%`````````````.$```"[!@``$P8`
M`%\%``!_!@``5P(``,($```Z!0``#`(``%\$````````$`(``$L"``"Y!@``
M[P4``.L$``"%!@``Z`(``,X$``!A!@``1@,```````!>!P``6@```!<&``!R
M`@``Z`$``.D#```W````G0(``(X!```#`0``4`,```````"!!P```````,`!
M``"4!```]`,`````````````(@4``#H&````````BP0``/(&````````L@(`
M`)H&``#@`P````````\!```-!P````````````#.`0``OP,``/X%``#J!0``
M`````&@%``#P!```H@4``!````"2!```?@4``#4%``!L`````````"T$``!!
M!0````````````![````4@8```````"V!````````&@"``"G!@``@`0``&,"
M``";`@```````!@!```@!```6`<``%H&``!O!@``K`<``&0&``"2`P``X`$`
M````````````N`8``"H"``!V`@``3@4```````!J!@``Y@,``&L`````````
M'P<``"D`````````-P<```````!(`@``%@0`````````````)@,``-,!```4
M`@``Q0$``-L````N!@```````!,$````````=P4``.H#``">!P``(`4```T"
M```P`0``LP4``+P%```7`P``M00```X```"<````)P$``/$$````````.P<`
M`%P````C`0``'0```.@#``"C`P``)0$``$$````'!0``;P,```````"Z!P``
MD@$``"`'```'`P``,`4``"H!```F!@``M`,``*D%````````6P8``-0&``#(
M!P``=08```@```#0!P````````````#%`P``G0````X"``!T!````````$D'
M````````XP4``%\&```R!@``2@8``&\$`````````````(@'```F````R@``
M`/H$```&!0``FP4``/<%``!Q!@```````````````````````#0#``"$`@``
M`````)D"``!#!```````````````````XP,```````".!@``R@$``&`!``!&
M`0``40,``,4$``#G`0``=@0```\$``"?!P``?@(``````````````````/<!
M```/!0```````'H!``!`!P``````````````````I`0``%H'````````````
M``$%``#F`@```````+4```#_!`````````````#L`P``+`$``!0&````````
M9@,``)@'``#B!0```````'X'``#B````_`(``)4!````````O04``.L#````
M````/@0```````#%`````````&8'``"8`0``)00``&H$```W`@``(@(``'<!
M````````8@(``/<$``"A`@``70,``"H&``"*`P``%00``#X```"^````QP<`
M```````U`0``X`8``#L```#N!@````````T`````````@`(``+P#``"P`P``
MV@8``'\!````````.`$``*4```"_!0````````````#C!@``<@<``)P"``"(
M!0``_`0``/H"``!F!0```````%8#``!5````+@<``(,#``#0`@``)@4``*("
M```)`P``U`0```4%``"\!P```````.P&``"7`P```````)4%````````I0(`
M``,"````````U`4``!<!```.!0``R@,``!,#````````J@,``&`'``",!```
M)@0```````"&!`````````````!D````90,``+8%```9`````````&0!``"T
M!P`````````````&`@``G00``%T```#S`P``VP4``&D`````````)0<`````
M``"S!P``]`$`````````````Q`$``/$#``!!`P``'`$``(P!``#B`@``7@0`
M`/D%``````````````````!4`P````````````#Q````.@$``-(&``"Z`P``
MFP```/D"``#5!@``NP(``*P$``!&!```&P<``&0$````````F0````````#X
M!```@00``#D`````````&@8``/D#````````Z0(``$H```"1!```````````
M``!^`P``0`$``%H!```$!@``%0,``#8!``!>`````P,``)<'``!!!```)P``
M````````````TP(``/P```!'!```C04``',$````````CP4``"T&``"_````
M`````'@!``#:`@```````.,"``"&!@``7P,``*T&``````````````````!,
M`0`````````````H`0``!P8``/`%``"R!P```````*8%````````````````
M```]`@``J@8```P#````````M@$```````!"`@``]`4``-D#``!Q!```:P<`
M`%8$``#?!```"00``,\!``"W!0``MP0``',```"W`P``800````````'!```
M`````)X`````````5P```&4%``"4`P``D0```!X!``!>!0``V`$``-$#``"&
M````\P(``%(%````````.`(``(H'```/`P```````)0%``!C!````````$T$
M````````VP,``)8$`````````````*0!```V!P``R0,``"<&```;!@``=`8`
M`(<$``"[````S0(``,\&``"5!@``@08``&(!``!!!P``(0$``/D!```<!```
M`````+X"``"T`0``]0,``/\#``"H`0`````````````,`0``1@(``'(#``!"
M`````````"4"``#P````(P4``!X'```/!@``G@,``%\"``!I`0```````)H%
M```I!@``TP4``#T'```)!P```````#@&```D`@``A@(``.\&```\`P``N`$`
M`#H#``!;`@```````'$#``":`P``3P$```````"%`P```````$$!```L````
M'`(``.,'````````C`,````````+````QP0``+8"``"S`@```````%T&``"^
M!```2P4``$````#B`P````````$"```?!````````*8#``!K!0``I`,``%D"
M````````HP(``%$'````````,@(``/8#`````````````'P!``">`@``$P4`
M``````#5!P``'`,``+4!``#+!0``H`0``#(````(`0``,@,``/T#````````
M````````````````I04```````"Z`0``L@8``$X&```K`@```0$``'8!``#&
M!```:0(``!D%``!*!```Y`8``"T"```R!P``MP$``.,!```E````V04``'0#
M``!+!@```````'\#```D`P````````````!P!P``+`8`````````````````
M```!``"-````R`,``)$!``#E`@```````&0"```P````C`4```8&````````
MEP$```H`````````6P<``+,```#%!P``%`0``*L&``!N`@``Q08``.L```!3
M`0``3`4``,0'````````R0<``-$'``#*!```?@$``!@"``#2`@``3P8`````
M``#^!@```````(L'````````K0$``/<&```9!```+`,`````````````T@4`
M`($#```)!0``\@(``!0%``!]`@``G`<```````"Q`@``*`(`````````````
M^````-T!``"F````L00``)$#``"`!P``A@$``#0```#:!```6`8`````````
M`````P8`````````````Y0````````"L!@``<@4``!`&```*`0```````%$`
M```O`0``````````````````A`4```````"E!```@@<``-L$``":`@``````
M````````````'@,``((#```-!0``8@4``)X&``!Y````UP0``%\!``#O`0``
M``8``'@%``#D`@``E`8``"(````E!0``T08``&,!``#5!0``````````````
M````+P(``-D'``#D!```*0<``(@#```H!```+P```%(!``!D!0```````*P#
M```A!@``-@4``#@#``#E`P``YP(``$X$```A`P``,P,```````"Z!0``*P8`
M`/T"```,!```2P,``%$$``!!!@``=`$``+<"``":`0``X0(``&\"``#$!@``
M````````````````I`8``)$%``"H!```;@8``-@#``"Y`0``L@4```````"J
M!P``!08``$`&``!K`@``WP8``,('``#L`0``<`8```````#`!@``DP4``!4&
M``#\`P``VP$``!X$```!!```7`<````````D`0```````*8'```/`@``UP(`
M``````!$!P``7`$``$4$``#D`P``804``*($``"&!0```````!L```""!```
M`````!H`````````:@,``!8&````````*P0``),"```R!````````.L"``#1
M`@``[````'<'`````````````'H"`````````````'0`````````````````
M````````R@4``&X'````````Y`$``)<`````````S0<```````"S`0``]08`
M``$'``#7!@```````)<$``#)!@```````/X```#T````L`0``,@&````````
M<P8``*,`````````#P<``-D```!G`P``PP(``#$$``"*`@``4@0``*\#``#<
M!P```````$(%``#Z!@``,P(``"D!``#<!0``X04```````!5!```?0```(\&
M``"?!@``$0,``'4```"=!@``4@,`````````````Q@$``,P'``",````4`8`
M`+(!``"^!0``JP0```````"E!@``JP,``'<#``!>`P``9P````````!F!```
M``````````!I`P``Z@8```````"@!P``D0<``"````!#`0``/@$``/X!````
M````$@<```````!%`0``%P0``'@#``#!!P``X`0```@$```K`P``[`4``$<'
M``#3!P``604``!$"``"/`P```````$4```!N!```=@4``!,`````````90$`
M`"X```"*!0```````$\"``````````````````"Y````,@$``%D!````````
M:`,``+8'``#X`@``?0<``*\'``!^````+04``(H`````````Z@0``%<#``#)
M`@````````````![`@``;P4``($%``#M!0```````'0"```Y!0```````',!
M```6````X@0``-P#``!V````_0$``#<%````````U0(``/4!``#X`P``K0,`
M`(\'````````W@$``*8$``#`!P``````````````````IP,```(#````````
M`````-4$``!H!P``.`4```````"K`@``E@4``"`"````````]P,``(8'````
M`````````'0%``"[!0``U0,``'8&```\!P``T00``(\$``">!0``U````"<$
M``#8!@```````!T!``"E!P``R04``,X``````````````)4```!W`@``^@4`
M``````"Q````"`4```````".`P``3P0``!<```")`P``\`,``'D%``!4!@``
MD`$````````D!@``*0,``(P'``"T````````````````````T`8```````#*
M`@````````````"'`@``D`<```@&``"]!```W`8```0"``#6`@``<@8``#8`
M``"E`0``$`$``+T&``"I!@``(`$``&,'``!;`P``#0,``-@'```9`@``=P8`
M`.8&````````S```````````````QP,``/($``#J````P0,``$L$``!#````
MZP4```L$````````!0,``.L!``!0!```5````)`#````````,0,````"``"@
M!0``D@(``+@$``#O!```_00``!$!````````*@<```````#/`P``4@<`````
M``#!`@```````/H!``"L````60,``/8"``#S!0``P04``-T"``"4!P``"P$`
M`)8&````````;`(``+H&``!?``````````D!```H!@``D`0```````!/````
MOP<```T!```6`0```````,8'````````A`,``"L```!'!@```````*$$```Z
M`@``;`0```````##!0``C@0``'8#``".!0````````````#6!0````````("
M```.!```>P0`````````````,`,```````">!```[`0`````````````W08`
M``````"Q!P``:@$````````<!@``BP$```0```"]!P```````,L'``"U!0``
M'0(``&L$```_`0``O@8``)@````E!@``N@```,X%```Y`P``4P,``-\%``#B
M!P```````&8&`````````````'X&``"B!@``_P4``/,&````````````````
M```O`P``?`,``/(#````````508```````#9!@``*00```````!J!0``A0(`
M`/$!``##`P``[P```'4"``"I`````````)@$``#_`````````-\!````````
M6```````````````O@$``$X"``#>`@``V`(``&$!````````#@$``($```#7
M`0``=04``$\#``!=!```<0```*`#``````````````````"H!@``50$``-8`
M````````AP8``/<````(!P``70(``)8```!Y!@``MP8``*$#``"M!```O`$`
M````````````1@````````!L`P``C@(````````W!@```````%L%``!Y`P``
MZ08``$H'``!/!0``YP```$(#`````````````'L%``#7````%0$``*\!``#S
M`0``!`0``)@%```T!0``-0(``.8%````````Z@(``","``"I`0``VP(``#P"
M``!O!P``4``````````?`0```````'P`````````U`(``,8"``!S!P``LP,`
M````````````[`(```````!_!0``3````*T%``#O`P``2@,```8$```T!P``
M'@8``!<"``#'`@``7@(``!@```!Q!0``N0,``"$"``#R`````````#H$````
M`P```````+````#&!0````````\```#H!```$@8``#$```"0!@````````0'
M````````2P$``(("``!&!P```P```'D"````````&`,```````"1!@``1```
M`#0$````````,0<``/D```!3````UP4```P&````````5P8``$@$````````
M?00``'@`````````O`0```````"I`P``^@,``"X$``"]`P```````'H'````
M````@P```'\$``![`0``^`$````````F!P```````#,%````````````````
M``"C!0``+0````````"H````8P4``%$!```J!```9P4``+($``"L`@``B```
M`"(!```<````L04`````````````<0(``,8````+!@``S0,`````````````
MN`<``'\'```Y!P``/@<``)L#````````CP(``)4'``"#!```_@,```H"``#Z
M````M0,``%@$``"I!```\@$``#X%``"[`P````````````!@`P``J`,``$0"
M``#+`@``W@,``&4'```-!@``Q@8```````#9`0``[0,``*T```!V!P``LP8`
M`$4&````````OP(``!L$``!I!````````+L'````````0`4``)8#```S````
MK@<````````]````?08```````#<````3`<````````V!@``K@````````#G
M!@```````-8#````````H``````````````````````````L!````````*X$
M``!\`@``K@(``&8!``#B`0``^`8``-0'```1!P``8@0``(X```#)!```=0<`
M``````!)````+@(``*$&`````````@8```````!0!0``>`0``$@&``":!P``
M`````%P&``#[!0``C0(```````";!```)`0``%T!``"9!P``%`<``!$$``"J
M`0``908``,(%````````#@<``$0&``!4`0``VP8```````#@````GP(``)\#
M```T!@````````````!(````8`8``$0!``#F`0``)`4``#L$```;`@``&@(`
M``````!6````AP<``*0"``!@`@```````#L&``")`0```@$``,P$``"V````
M;00```````"[!```BP```)P#``")!0``````````````````5P4```````"1
M`@``"P,```````"O`@``MP``````````````>P8``,`"````````$04`````
M````````R`0``)8'``!%`P```````)\$````````%0````4$``"G!0``````
M`!H%```"!````````-,#````````40(``!0#```D`````````/L!``#U!0``
M20$``(0'``#/`@``4@```,<!````````&`0``#H```!4`@``AP````0#``#8
M!0````````H'```;`0```````/8$``!>!@``E````&H```!_`@``H0```!4%
M``"5!```]0```'`!```H!0```````*(#``!@````5P0``'P$``!:!```````
M````````````D`(``.<%````````9@````````"9`P``&@0``/8&```<!P``
M`````"`#`````````````!<'``!A`@``GP$``,("``#A!P``10(````````6
M`P``SP<``)<"``"3`P```````"$%```%`0``F08```````!#!@``6`,`````
M````````6P0``)P&``"F!@``*@```!4'``"-`0``^`4```````"Z`@``G0,`
M`/4"``#D!P```````%0%````````S04``,T&``#'!0```````#D!``!*`@``
M@@4``!<%``!Z````<P(``,(!``"G`0``8P8``!D&```H!P```````!\#``"T
M`@``9`,``.X$``!+!P``K`4````$``!Y`0``0P(```D&``#S````N`4`````
M``#R!0``*`````````"!`@``-@0```(`````````>@,```,%``!Z!0``/04`
M`'0'``"%!`````````````"?````'P8``(8#``#@`@``30````````#:````
M`````-\'```K!0``DP$```````!)`@``70<`````````````<`(``!T#``!1
M!@```````(\!```````````````@)B,Q-3$[("5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H4F5A9"!O;FQY
M*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R
M9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO
M="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T
M:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U
M;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B
M('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A
M<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO
M=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@
M<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E
M`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M
M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S
M`"5S(&AA<R!C86YC96QL960@)7,N`"5S(&AA<R!R97!L:65D('1O(&$@9G)E
M92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L:65D('1O('1H92!I;G9I=&%T
M:6]N('1O("5S+@`E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N+@`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E
M<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@<F5Q
M=65S=',@>6]U<B!P<F5S96YC92!A="`E<RX`)7,@=&\@)7,@;V8@)7,`)7,@
M=VES:&5S('1O(&%D9"!T;R`E<RX`)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W
M87)E(&]F("5S+@`E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN
M9F]R;6%T:6]N(&%B;W5T("5S+@`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A
M;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@
M5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T
M;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@
M;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF
M;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B
M;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`
M,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI
M9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!
M32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T
M=&]M`$%B<VUI9&1L90!!8V-E<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N
M="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!8W1I;VYS
M`$%D9`!!9&0@)7,`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S
M:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO
M;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI
M<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@
M;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;R!A
M9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`
M061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A
M9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T
M<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`
M06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`
M06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL
M;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E
M9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO
M9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S
M97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP
M;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&5R<F]R
M(&]C8W5R<F5D(&9O;&QO=VEN9R!T:&ES(&QI;FLZ("5S`$%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C
M=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY
M`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC
M871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`
M07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ
M90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I
M>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B
M80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G
M:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T86-H960@
M:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S
M96YT`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E;F1E97,`
M071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C
M:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!
M=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@
M24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@
M9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!!
M>F5R8F%I:F%N`$%Z=7(`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R
M;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O
M<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM
M,3,I`$)A;F=L861E<V@`0F%R(%1I;64`0F%R('1I;64`0F%R8F%D;W,`0F%R
M8FEE`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"
M87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`
M0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S
M(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0FQU92!-
M;V]N`$)L=64@86YD(%=H:71E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R
M9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z
M96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R
M87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)O=VX`0G)U
M;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA
M($9A<V\`0G5R;G0@3W)A;F=E`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@
M=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M
M97)O;VX`0V%M;W5F;&%G90!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T
M('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A
M;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O
M8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD
M<F5N(&5X:7-T+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@
M;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S
M(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R
M;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S
M<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W
M;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA:7(@4&5R<V]N`$-H
M86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@9&5F875L="!I9&5N
M=&ET>0!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`
M0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H96-K('1H92!B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC
M871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H
M;V]S92!A;B!A8W1I;VXZ`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`
M0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H
M<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE
M87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L
M96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@
M2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL
M87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L
M;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM
M86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S
M`$-O;7!A;GD`0V]M<&QE=&5D`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U
M=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3
M;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T
M:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O
M;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N
M=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O
M<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<FYF;&]W97(`
M0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N
M;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E
M<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N
M`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@
M;&]A9"!S=')A=&5G>2`G)7,G+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U
M;&0@;F]T(&UK9&ER("<E<R<N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R
M('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B`G
M)7,G(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`
M0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N`$-O=6QD(&YO="!R96%C
M:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N
M;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N
M(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#
M;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V
M92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T(')M
M9&ER("<E<R<N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U;FQI;FL@)R5S)RX`0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@
M9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F
M;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#
M<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S
M=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E
M<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S
M97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E
M;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M
M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R
M;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E
M('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA
M;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E
M9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E
M9FEN:71I;VYS`$1E;&5G871E('!O<VET:6]N`$1E;&5G871E9`!$96QE=&4`
M1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E
M<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L
M;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT
M:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@;&EN:P!$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I
M;64`1&5N;6%R:P!$96YY(')E<75E<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E
M+V)U<WD@:6YF;W)M871I;VX`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I
M<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I
M;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I=FED
M97(`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O
M;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@
M=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R
M=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D
M;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N
M`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I
M="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D
M;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D
M9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%
M;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`
M16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YD`$5N9"!Y96%R
M`$5N;&%R9V4@161I=&]R`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SH`17)R;W(`17)R;W(@8W)E871I;F<@8FQO
M8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D
M96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E
M<P!%<G)O<B!S96YD:6YG(')E<&QY.B`E<RX`17)R;W(@=7!D871I;F<@<&%S
M<W=O<F0Z("5S`$5R<F]R('=R:71I;F<@(B5S(BX`17)R;W(@=W)I=&EN9R`G
M)7,G+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD
M(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q
M=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'
M($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@
M8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO
M=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R
M<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME
M.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`
M1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U
M;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R
M`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA
M;&8`1FER<W0@475A<G1E<@!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N
M="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA
M="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@
M;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@
M=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U
M;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O
M<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`
M1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O0G5S>2!297!L>0!&<F5E+T)U
M<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS90!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-
M;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'
M96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-
M87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E;@!'<F5E
M;FQA;F0`1W)E;F%D80!'<F5Y`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E
M(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@
M)7,`1W)O=7!S`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI
M<W-I;VYS`$=U97-T(%-E<G9I8V5S`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S
M`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T
M;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5I9VAT("AI;B!P
M:7AE;',I`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE
M<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO
M7VUE`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO
M;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E
M<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R
M:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED
M:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D
M<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T
M('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA
M=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)
M8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF
M('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E
M('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),
M.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G
M92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W
M($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!)
M;F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S
M:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS
M97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O
M<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A
M9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T90!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`
M26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E
M<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R
M86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F
M;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y
M($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!)
M;G1E9V5R(&QI<W0`26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@
M8V]M<&]N96YT+@!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!)
M;G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@
M8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED
M(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A
M;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A
M;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R
M;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@
M8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E
M<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S
M<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L
M96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD
M`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`
M271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H
M25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`
M2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T
M:69Y(%)I9VAT`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@
M3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]L86(`
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L
M(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A
M;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E
M<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U
M87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN
M.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,879E;F1E
M<@!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO
M;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`
M3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`
M3&EG:'0@0FQU90!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I
M;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG
M:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H
M;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E
M;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y
M:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T
M(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/
M=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB
M90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F
M86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U
M<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A
M;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!4
M87-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N
M`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R
M(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,;WEO;&$`3&]Y
M;VQA($)L=64`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC
M`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I
M80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA
M<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N
M9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R
M:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA
M<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`
M36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365E=&EN9R!#
M86YC96QL871I;VX`365E=&EN9R!);F9O<FUA=&EO;@!-965T:6YG(%!R;W!O
M<V%L`$UE971I;F<@4F5P;'D`365E=&EN9R!5<&1A=&4`365E=&EN9R!5<&1A
M=&4@4F5Q=65S=`!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S
M<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I
M9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S
M<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H
M;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A
M;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M
M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C
M96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`
M36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I
M="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI
M<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-
M;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD
M;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE
M87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C
M8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO
M=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W
M;@!-;W9E('5P`$UO>F%M8FEQ=64`36]Z:6QL80!-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO
M;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L
M`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`
M3F%M90!.86UI8FEA`$YA=7)U`$YE6%0`3F5E9',@06-T:6]N`$YE<&%L`$YE
M=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@
M55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@
M55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I
M8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R
M:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@365S<V%G
M92!T;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@
M6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W
M("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`
M3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI
M9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R
M961I="!L969T+@!.;R!D97-C<FEP=&EO;B!F;W5N9`!.;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`
M3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@
M;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E
M<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E=`!.;R!Q=6]T82!S
M970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S
M`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;B!0
M87)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9F]L:R!)
M<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES
M;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C
M=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`
M3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EC90!.;W9E
M;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O
M;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B
M:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F
M:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`
M3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA
M;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S
M(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS
M(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T
M:6YG(%-Y<W1E;0!/<'1I;VYA;"!087)T:6-I<&%N=`!/<'1I;VYS`$]P=&EO
M;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T
M:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@
M26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@
M1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L
M:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0
M(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N
M;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E
M>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T
M86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA
M;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A
M<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R
M9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H
M96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O
M<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A
M<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P
M;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S
M:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$
M96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`
M4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H
M;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@
M=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R979I
M97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T
M(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T
M(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+@!0;&5A<V4@='EP92!T
M:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0
M;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I`%!O<W1N=6ME`%!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E
M.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`
M4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0
M<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E
M>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y
M($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`
M475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L
M96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`
M4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T
M:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W
M.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!2
M96UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!296UO=&4@4V5R
M=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F
M;W)M871T:6YG`%)E;6]V92!F<F]M(&UY(&-A;&5N9&%R`%)E;6]V92!P86ER
M`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<&QY
M(%-E;G0N`%)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E`%)E<&QY
M('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+@!297!L>2!W:71H
M(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E<&QY.B`E<P!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E
M<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"!&:65L9`!297%U:7)E9"!087)T:6-I<&%N=`!2
M97-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O
M<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP
M92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H
M96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O
M;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W
M(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T
M:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T
M871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H
M96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I
M;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M
M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E
M(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S
M`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I
M96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C
M="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O
M=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L
M96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N
M(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!,
M871E<W0@26YF;W)M871I;VX`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--
M4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E
M;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@
M879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`
M4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E
M="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P
M(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@
M>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM
M97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L
M:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O
M=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R
M:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET
M:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3
M=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A
M<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I
M;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R
M90!3:6=N871U<F4@06QG;W)I=&AM`%-I;7!L97@`4VEN9V%P;W)E`%-I>F4`
M4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@
M4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3
M:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`
M4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R
M:6-A`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C
M96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`
M4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET
M(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3
M=&%R(%1R96L`4W1A<G0`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR
M;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`
M4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O
M<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE
M`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E
M<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI
M<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S
M:W,`5&5A;`!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@
M`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH
M)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N
M9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5N=&%T:79E;'D@06-C97!T
M(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5X=`!497AT($]N;'D`
M5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD
M`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE("5S(&QI;FL@
M=&\@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE($944"!E>'1E;G-I;VX@:7,@
M;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D
M+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@
M<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%
M>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C
M86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&5V96YT(&AA<R!B965N
M(&%D9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I
M960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L
M;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R
M,B!M97-S86=E+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D
M+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&EN:R!H87,@8F5E;B!R
M96UO=F5D`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N
M(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S
M<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D
M(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A
M8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O
M=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I
M9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@
M*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N
M;W0@97AI<W0N`%1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S
M:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T
M+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT
M(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T
M('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N`%1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N`%1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N
M`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T
M(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ
M(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@
M<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA
M>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P
M87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W
M87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@
M8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N`%1H
M:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#
M;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL
M("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR
M96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K
M971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C
M=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O
M9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`
M5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI
M9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME
M>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD
M($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6
M+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H
M86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92`E<R\E<P!5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E
M;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE
M('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E
M<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B
M;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA
M=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ
M("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A
M;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@
M9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`
M56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I
M;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF
M:6QE9`!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S`%5N:6-O9&4@
M*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5
M;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA
M;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T
M960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E(')E<W!O;F1E
M;G0@<W1A='5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S
M8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO
M;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T
M97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@
M)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@
M9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5
M<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD
M`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N
M86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T
M86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L
M:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I
M;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M
M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!6
M86YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D
M("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`
M5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC
M86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N
M86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P
M86=E`%9I97<@87,@)7,`5FEE=R!E=F5N=`!6:65W('1A<VL`5FER9VEN($ES
M;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET
M>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.
M('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE
M<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC
M;VT`5V5B`%=E8B!3:71E`%=E8F)P;&%T<V5N("T@4V]B97(`5V5B8G!L871S
M96X@+2!3;V)E<B!.15<`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!7
M96QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M
M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7
M:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I
M;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`
M5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O
M9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@
M16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M
M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@
M9FEL92X`6"U2968`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@
M97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE
M<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE
M(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N
M`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@
M=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!C86YN
M;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I
M;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX
M+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S
M8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O
M8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C
M;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO
M=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A
M;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S
M`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT
M:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N
M=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@
M>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@
M;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V
M:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!4
M97AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!
M9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O
M=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O
M=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M
M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R
M<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L
M;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T
M`&-L:6-K(&AE<F4`8VQO8VL`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O
M;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL
M:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z
M`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O
M;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M
M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O
M<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W
M(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES
M=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U
M<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E
M<G-I;VXZ($AO<F1E(#,N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ-2`Q
M,3HR,2LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,38@,#`Z,C8K
M,#$P,`I,87-T+51R86YS;&%T;W(Z($IO87%U:6T@2&]M<FEG:&%U<V5N(#QJ
M;VAO0'=E8F)P;&%T<V5N+G-E/@I,86YG=6%G92U496%M.B!3=V5D:7-H(#QI
M,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("8C,34Q.R`E<R!K;VUM97(@
M871T('5T9O9R82!D92!U;F1E<FCE;&QS86MT:79I=&5T97)N82!S;VT@;6%R
M:V5R871S(&YE9&%N+@`@*"5S(&1A9V%R('-E9&%N*0`@*'-N86)B=&%N9V5N
M="`E<RD`("A3:W)I=G-K>61D860I`"`H;VT@)7,@9&%G87(I`"`H:61A9RD`
M("AI;6]R9V]N*0`@*&EGY7(I`"!K;"``)R5S)R#D<B!I;G1E(&5N(&MA=&%L
M;V<N`"<E<R<@Y'(@:6YT92!E='0@9V]D:^1N="!V86PN`"<E<R<@Y'(@:6YT
M92!K;VYF:6=U<F5R870@:2!(;W)D97)E9VES=')E<G0N`%1RY&1H86YT97)A
M<F5N(&;V<B`E<R!S86MN87,N`"<E<R<@;&%D97,@=&EL;"!I(&=R=7!P<WES
M=&5M970N`"<E<R<@;&%D97,@=&EL;"!I(&)E:/9R:6=H971S<WES=&5M970N
M`"<E<R<@<VMA<&%D97,@:6YT93H@)7,N`"4N,F9-0B!A;G;D;G0@878@)2XR
M9DU"('1I;&SE=&5T("@E,F8E)2D`)60@)7,@;V-H("5S`$1I='0@;/9S96YO
M<F0@=7!P:/9R(&%T="!GY&QL82!O;2`E9"!D86=A<BX`)60M9&%G<W!R;V=N
M;W,`)7,@+2!&]G(@:^1N;F5D;VT`1FEN9V5R<')I;G0@9O9R("5S`"5S($M"
M`"5S(%5N9&5R:.5L;'-F=6YK=&EO;B`M($)E:W+D9G1E;'-E`"5S(%-E='5P
M`"5S(&%N;>1L86X`5&KD;G-T96%V=&%L(&;V<B`E<P`E<R!F:6YN<R!R961A
M;BX`)7,@:VP@)7,@)7,`)7,@:&%R(&%N;G5L;&5R870@)7,N`"5S(&AA<B!S
M=F%R870@<.4@96X@8F5GY')A;B!O;2!I;F9O<FUA=&EO;B!A;F?E96YD92!L
M961I9R]U<'!T86=E;BX`)7,@:&%R('-V87)A="!PY2!I;F)J=61A;B!T:6QL
M("5S+@`E<R!H87(@<VMI8VMA="!D:6<@:6YF;W)M871I;VX@;VT@;&5D:6<O
M=7!P=&%G96XN`"5S(&MO;6UE<B!A='0@=71F]G)A(&1E('5N9&5R:.5L;'-A
M:W1I=FET971E<FYA('-O;2!M87)K97)A=',@;F5D86XN($UA<FME<F$@9&4@
M86MT:79I=&5T97(@<V]M(&1U('9I;&P@=71F]G)A+@`E<R!K<N1V<P`E<R!M
M:6YU=&5R`"5S('-A:VYA<RX`)7,@969T97)F<N5G87(@:6YF;W)M871I;VX@
M;VT@;N1R(&1U(.1R(&QE9&EG+W5P<'1A9V5N+@`E<R!E9G1E<F9RY6=A<B!D
M:6X@;N1R=F%R;R!V:60@)7,N`"5S('1I;&P@)7,@878@)7,`)7,@=FEL;"!L
MY&=G82!T:6QL('1I;&P@)7,N`"5S('9I;&P@9_9R82!D:6<@;65D=F5T96X@
M;VT@)7,N`"5S('9I;&P@97)HY6QL82!D96X@<V5N87-T92!I;F9O<FUA=&EO
M;F5N(&]M("5S+@!!9')E<W-B;VL@9O9R("5S`$MA;&5N9&5R(&;V<B`E<P!!
M;G1E8VMN:6YG87(@9O9R("5S`%5P<&=I9G1E<B!F]G(@)7,`)7,Z("5S`"5S
M.B!-961D96QA;F1E="!K86YS:V4@:6YT92#D<B!F<N5N(&1E;B!S;VT@9&5T
M('9E<FMA<BX@5F%R(&;V<G-I:W1I9R!M960@871T(&;V;&IA(&SD;FMA<B!E
M;&QE<B!S:VEC:V$@879SY&YD87)E;B!P97)S;VYL:6<@:6YF;W)M871I;VXN
M`"P@<W1O<FUB>6%R`"P@<W1O<FUB>6%R("5S("5S`"P@=F%R:65R86YD92!M
M96QL86X@)7,@;V-H("5S`"TM(';D;&H@+2T`,3(M=&EM;6%R<V9O<FUA=``R
M-"UT:6UM87)S9F]R;6%T`#(T('1I;6UA<@`\1O9R96?E96YD90!%;B!D871A
M8F%S:V]P<&QI;F<@:W+D=G,@9O9R(&%K='5E;&QT(&)L;V-K+@!%='0@9F%T
M86QT(&9E;"!H87(@:6YT<N1F9F%T`$5N('!U8FQI:R!01U`M;GEC:V5L(&MR
MY'9S(&;V<B!A='0@:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N`$5N('!U8FQI
M:R!01U`M;GEC:V5L(&MRY'9S(&;V<B!A='0@=F5R:69I97)A(&5T="!S:6=N
M97)A="!M961D96QA;F1E+@!%;B!P=6)L:6L@;V-H('!R:79A="!01U`M;GEC
M:V5L('-A;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T="!D96MR>7!T97)A(&5T
M="!M961D96QA;F1E+@!%;B!P=6)L:6L@;V-H('!R:79A="!01U`M;GEC:V5L
M('-A;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T="!S:6=N97)A(&5T="!M961D
M96QA;F1E+@!%;B!P=6)L:6L@;V-H('!R:79A="!3+TU)344M;GEC:V5L('-A
M;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T="!D96MR>7!T97)A(&5T="!M961D
M96QA;F1E+@!%;B!P=6)L:6L@;V-H('!R:79A="!3+TU)344M;GEC:V5L('-A
M;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T="!S:6=N97)A(&5T="!M961D96QA
M;F1E+@!%;B!P=6)L:6L@4R]-24U%+6YY8VME;"!K<N1V<R!F]G(@871T(&MR
M>7!T97)A(&5T="!M961D96QA;F1E+@!&]G)M:61D86=S;6]L;@!,Y'1T(&;V
M<FUI9&1A9W-R96=N`$;V<FUI9&1A9W-R96=N`$;V<FUI9&1A9W-S:W5R87(`
M1O9R;6ED9&%G<W-K=7)A<B!M960@<V[V`$%-+U!-`$%022!)1`!/;2!E9&ET
M;W)N`$]M+BXN`$)O='1E;@!-:71T96X`06-C97!T97)A(&)E9^1R86X`06-C
M97!T97)A9`!"96CV<FEG:&5T('-A:VYA<R!A='0@<VMA<&$@5D93+6UA<'`N
M`$)E:/9R:6=H970@<V%K;F%S(&%T="!S:V%P82!61E,M9FEL+@!+;VYT;VEN
M9F]R;6%T:6]N`$SV<V5N;W)D(&;V<B!K;VYT;P!+;VYT;W0@9G)Y<W0`0G5D
M9V5T`,5T9^1R9&5R`$SD9V<@=&EL;`!,Y&=G('1I;&P@)7,`3.1G9R!T:6QL
M('5N9&5R9W)U<'``;.1G9R!T:6QL('5N9&5R8F5H]G)I9VAE=`!,Y&=G('1I
M;&P@:.1R.@!,Y&=G('1I;&P@;GD@9W)U<'``3.1G9R!T:6QL(&YY(&)E:/9R
M:6=H970`3.1G9R!T:6QL('5N9&5R9W)U<'`@=&EL;"`G)7,G`$SD9V<@=&EL
M;"!U;F1E<F)E:/9R:6=H970@=&EL;"`G)7,G`$SD9V<@=&EL;"!E;B!N>2!A
M;G;D;F1A<F4Z`$SD9V<@=&EL;"!K;VQU;6X`3.1G9R!T:6QL(&YY82!M961L
M96UM87(`3.1G9R!T:6QL('!A<@!,Y&=G('1I;&P@;65N>6X@9O9R("5S('-O
M;2!-;WII;&QA(%-I9&5B87(`3.1G9R!T:6QL(&D@;6EN(&MA;&5N9&5R`$SD
M9V<@=&EL;"!I(&%D<F5S<V)O:SH`3.1G9R!T:6QL(&D@;6EN(&%D<F5S<V)O
M:P!,Y&=G('1I;&P@86YVY&YD87)E`$QA9&4@=&EL;"`G)7,G('1I;&P@<WES
M=&5M970L(&UE;B!K=6YD92!I;G1E(&SD9V=A('1I;&P@97AT<F$@(&EN9F]R
M;6%T:6]N.B`E<RX`3&%D92!T:6QL("<E<R<@=&EL;"!S>7-T96UE="X@1'4@
M:V%N(&QO9V=A(&EN(&YU+@!5<'!LY&=G(&%V(&%N=N1N9&%R92#D<B!I;F%K
M=&EV97)A="X`061R97-S`$%D<F5S<V)O:P!!9&UI;FES=')A=&EO;B`M(&%N
M9V4@8F5H]G)I9VAE="!F]G(@86YD<F$@86YVY&YD87)E`$%D;6EN:7-T<F%T
M:6]N`%)E:VQA;0!!9F=A;FES=&%N`$%L8F%N:65N`$%L9V5R:65T`$%L:6%S
M`$IU<W1E<F$`2G5S=&5R:6YG.@!!;&QA`$%L;&$@875T96YT:7-E<F%D92!A
M;G;D;F1A<F4`06QL82!G<G5P<&5R`$%L;&$@8F5H]G)I9VAE=&5R`$%L;&$@
M9GER82!S:61O<@!4:6QLY70@9FQE<F$@861R97-S97(`5&EL;.5T(&EN<W3D
M;&QN:6YG(&;V<B!S;W)T97)A9"!L:7-T83\`1FEN;G,@<F5D86X`06QT97)N
M871I=B!)35-0+6EN;&]G9VYI;F<`06QT97)N871I=G0@;/9S96YO<F0@9O9R
M($E-4U``06QT97)N871I=G0@86YVY&YD87)N86UN(&;V<B!)35-0`$%L=&5R
M;F%T:78@92UP;W-T(&%D<F5S<P!!;'1E<FYA=&EV(&UA;&P`06QT97)N871I
M=B!T97AT.@!!;65R:6MA;G-K82!386UO80!%='0@9F5L('5P<'-T;V0@;N1R
M(&SD;FME;B`H)7,I('-K=6QL92!A;G;D;F1A<P!%='0@9F5L86MT:6=T(';D
M<F1E(&%N9V%V<RX`171T(&]KY&YT(&9E;"!H87(@:6YT<N1F9F%T`$%N9&]R
M<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;2!P<F]X>0!3=F%R`$%N=&%R:W1I
M<P!!;G1I9W5A(&]C:"!"87)B=61A`$%P<&QI:V%T:6]N`$%P<&QI:V%T:6]N
M<VQI<W1A`$%P<&QI:V%T:6]N96X@Y'(@:VQA<BX`5F5R:W-TY&QL('1I;&P@
M=6YD97)U=&1E;&YI;F=A<@!';V1KY&YN`%5N9V5FY')L:6<@<W1O<FQE:P!A
M<')I;`!!<F%B:7-K("A7:6YD;W=S+3$R-38I`$%R:VEV9FEL<W1O<FQE:P!!
M<FMI=F9I;&YA;6X`Q'(@9&5T('/D:V5R="!A='0@9'4@=FEL;"!T82!B;W)T
M(&)E9^1R86X@9O9R("5S/P#$<B!D970@<^1K97)T(&%T="!D=2!V:6QL(')A
M9&5R82`G)7,G(&]C:"!E=F5N='5E;&QA('5N9&5R9W)U<'!E<C\`07)G96YT
M:6YA`$%R;6%N:65N`$%R;65N:7-K("A!4DU30TE)+3@I`$MO;G-T`$%R=6)A
M`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@:V]N<W0`07-I96XO4W1I;&QA(&AA
M=G-R96=I;VYE;@!&<N5G82!E9G1E<B!B96MRY&9T96QS92!I;FYA;B!U;F1E
M<FCE;&QS86MT:79I=&5T97(@=71F]G)S/P!4:6QL9&5L;FEN9W-K;VQU;6X`
M0FEF;V=A9"#D<B!E;B!I0V%L96YD97(@9FEL(&UE9"!E='0@<W9A<B!PY2!E
M;B!B96?D<F%N('-O;2!D=2!S:VEC:V%T+`!&]G)S]FL@=&EL;"!A='0@<F%D
M97)A(&5N(&=R=7!P('-O;2!I;G1E(&9I;FYS+@!&]G)S]FL@=&EL;"!A='0@
M<F%D97)A(&5N(&)E:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N`$;V<G/V:R!A
M='0@Y&YD<F$@96X@8F5H]G)I9VAE="!S;VT@:6YT92!F:6YN<RX`1O9R<_9K
M(&%T="#D;F1R82!E;B!U=&1E;&YI;F<@<V]M(&EN=&4@9FEN;G,N`$1E;'1A
M9V%R90!!='1R:6)U=`!A=6=U<W1I`$%U<W1R86QI96X`UG-T97)R:6ME`$%U
M=&A?8WER<W%L.B!)34%0+65X=&5N<VEO;B!S86MN87,N`$%U=&A?8WER<W%L
M.B!+;W!P;&EN9V5N('-A:VYA<B!F=6YK=&EO;F5R('-O;2!K<N1V<RX`075T
M:%]C>7)U<SH@24U!4"UE>'1E;G-I;VX@<V%K;F%S+@!!=71H7V9T<#H@1E10
M+71I;&SD9V<@<V%K;F%S+B!+;VUP:6QE<F$@4$A0(&UE9"!S=VET8VAE;B`M
M+65N86)L92UF='`N`$%U=&A?:6UA<#H@24U!4"UE>'1E;G-I;VX@<V%K;F%S
M+@!!=71H7VMR8C4Z(&MR8C4M97AT96YS:6]N('-A:VYA<RX`075T:%]L9&%P
M.B!$970@9^5R(&EN=&4@871T(&SD9V=A('1I;&P@86YVY&YD87)E(&D@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($1E="!GY7(@:6YT92!A='0@<F%D
M97)A(&%N=N1N9&%R92!F<N5N($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!,1$%0+71I;&SD9V<@<V%K;F%S+@!!=71H7VQD87`Z($MA;B!I;G1E(&SD
M9V=A('1I;&P@86YVY&YD87)E("<E<R<N(%-E<G9E<FX@<W9A<F%D93H@`$%U
M=&A?;&1A<#H@2V%N(&EN=&4@<F%D97)A(&%N=N1N9&%R92`E<P!!=71H7VQD
M87`Z($MA;B!I;G1E('5P<&1A=&5R82!A;G;D;F1A<F4@)7,`075T:%]L9&%P
M.B!$970@9^5R(&EN=&4@871T('5P<&1A=&5R82!A;G;D;F1A<F4@:2!!8W1I
M=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ($U#04PM97AT96YS:6]N('-A:VYA
M<RX`075T:%]S;6)A=71H.B!S;6)A=71H+65X=&5N<VEO;B!S86MN87,N`$%U
M=&5N=&ES97)I;F<@=&EL;"!)34%0+7-E<G9E<B!M:7-S;'EC:V%D97,N`$%U
M=&5N=&ES97)I;F<@;6ES<VQY8VMA9&5S`$%U=&5N=&ES97)I;F<@;6ES<VQY
M8VMA9&5S+B`E<P!!=71E;G1I<V5R:6YG(&%V=FES861E<R!A=B!2041)55,M
M<V5R=F5R;BX`075T96YT:7-E<FEN9R!T:6QL($944"US97)V97(@;6ES<VQY
M8VMA9&5S+@!!=71E;G1I<V5R:6YG('1I;&P@4TU"+7-E<G9E<B!M:7-S;'EC
M:V%D97,N`%1I;&QGY&YG;&EG82!FY&QT.@!6Y&YT87(@<.4@<W9A<@!!>F5R
M8F%I:F%N`$%Z=7)B;.4`0D]&2"UU<G/D:W1E<@!"86MG<G5N9`!"86MG<G5N
M9'-FY')G`$9E;&%K=&EG="!L]G-E;F]R9"!F]G(@2V5R8F5R;W,`1F5L86MT
M:6=T(&%N=N1N9&%R;F%M;B!F]G(@2V5R8F5R;W,`0F%H86UA<P!"86AR86EN
M`$)A;'1I<VL@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<G1I9`!2861T
M:60`0F%R8F%D;W,`0F%R8FEE`$)A<VMA=&%L;V<@)R5S)R!F]G(@8FEL9&5R
M(&AI='1A9&5S(&EN=&4N`$)A<VQI;FIE`%9I=')Y<W-L86YD`$)E;&=I96X`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$;V9&5L<V5D86<`0FQO8VL@
M)R5S)R!F]G(@87!P;&EK871I;VX@)R5S)R!S86MN87,N`$)L;V-K:6YS=.1L
M;&YI;F=A<@!";&]C:W1Y<`!";.4@;>5N90!";.5T="!O8V@@=FET=`!&970`
M0F]L:79I80!";VMMY')K96X`4F%M`%)A;6)R961D.@!286UA<@!";W-N:65N
M(&]C:"!(97)Z96=O=FEN80!"Y61A`$)O='-W86YA`$)O='1E;@!";W5V970@
M27-L86YD`$)R87-I;&EE;@!"<FET=&ES:V$@=&5R<FET;W)I970@:2!);F1I
M<VMA(&]C96%N96X`0G)U;@!"<G5N96D`0G5L9V%R:65N`%!U;FMT;&ES=&$`
M0G5R:VEN82!&87-O`$)RY&YD($]R86YG90!"=7)U;F1I`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@:6YS=.1L;&YI;F=A<BXN+@!#
M86-H96EN:71I97)I;F<@Y'(@:6YT92!F=6QL<W3D;F1I9RX`2V%L96YD97(`
M3'5G;G0`2V%M8F]D:F$`2V%M97)U;@!+86UO=69L86=E`$MA;B!I;G1E(&YO
M;&QS=.1L;&$@;/9S96YO<F0@875T;VUA=&ES:W0L(&MO;G1A:W1A(&1I;B!A
M9&UI;FES=')A=/9R+@!+86X@:6YT92!S:W)I=F$@=&EL;"!F:6P@)R5S)P!$
M970@9^5R(&EN=&4@871T(&%D;6EN:7-T<F5R82!E>'1E<FYA('-E<W-I;VYS
M:&%N=&5R87)E+@!+86X@:6YT92!K;VYT86MT82!)34%0+7-E<G9E<FXZ("5S
M`$MA;B!I;G1E(/9P<&YA(&9I;"`G)7,G`$MA;F%D80!!=F)R>70`079B<GET
M('!R;V)L96UR87!P;W)T`$MA;B!I;G1E(')A9&5R82`G)7,G+@!+86X@:6YT
M92!H:71T82!E;B!T96UP<N1R(&UA<'`N`$MA;B!I;G1E(&9O<G1SY'1T82!U
M=&%N("=MY6QF:6PG+7!A<F%M971E<BX`2V%N(&EN=&4@<F%D97)A(&UA<'`@
M)R5S)RX`2V%N(&EN=&4@<F%D97)A.R`E9"!B87)N(&5X:7-T97)A<BX`2V%N
M(&EN=&4@9&ER:6=E<F$@;65D9&5L86YD92!T:6QL(&%N9VEV970@;G5M;65R
M+@!+87`@5F5R9&4`4G5B<FEK`$]P97)A=/9R`$MA=&5G;W)I97(@;V-H(')U
M8G)I:V5R`$-A>6UA;B!)<VQA;F1S`$UO8FEL=&5L969O;@!#96QL:6YS=.1L
M;&YI;F=A<@!#96QL=71F>6QL;F%D.@!#96QL:6YS=.1L;&YI;F=A<@!#96QL
M;65L;&%N<G5M.@!-;V)I;'1E;&5F;VX`0V5L=&ES:R`H25-/+3@X-3DM,30I
M`$-E;G1R97)A9`!#96YT<F%L869R:6MA;G-K82!R97!U8FQI:V5N`$-E;G1R
M86QE=7)O<&5I<VL@*$E33RTX.#4Y+3(I`$-E<G1I9FEK871D971A;&IE<@!#
M97)T:69I:V%TY&=A<F4`0V5R=&EF:6MA='!O;&EC:65S`%1C:&%D`$]R9&;V
M<F%N9&4`Q&YD<F$`Q&YD<F$@9&ET="!L]G-E;F]R9`#$;F1R82!F]G)V86QD
M(&ED96YT:71E=`#$;F1R82!N86UN(&]C:"!A9')E<W,@<V]M(&UO='1A9V%R
M;F$@<V5R(&[D<B!D92!LY'-E<B!O8V@@<W9A<F%R('#E(&1I;F$@;65D9&5L
M86YD96XN`$%T="!B>71A(&SV<V5N;W)D('-T]F1S(&EN=&4@;65D(&1E;B!N
M=79A<F%N9&4@:V]N9FEG=7)A=&EO;F5N+B`@5F%R(&=O9"!K;VYT86MT82!A
M9&UI;FES=')A=/9R96XN`%1K;@!+;VYT<F]L;&5R82!LY&YK+BXN`$UA<FME
M<F$@9&4@86MT:79I=&5T97(@9'4@=FEL;"!U=&;V<F$@;G4N`$-H:6QE`$MI
M;F$`2VEN97-I<VMT(&;V<F5N:VQA="`H1T(R,S$R*0!+:6YE<VES:W0@=')A
M9&ET:6]N96QL="`H0FEG-2D`5N1L:B!A<'!L:6MA=&EO;CH`5N1L:B!L]G-E
M;F]R9`!6Y&QJ(&%N=N1N9&%R;F%M;@!6Y&QJ(.5T9^1R9#H`5N1L:B!H=7(@
M9&%T=6T@<VMA;&P@=FES87,Z`%;D;&H@;&ES='-T:6P@*&;V<B!S;W)T97)A
M9&4@;&ES=&]R*0!*=6SV;@!+;&%S<V1E9FEN:71I;VX@9O9R("5S('-A:VYA
M<RX`4F5N<V$`4F5N<V$@35-/9F9I8V4M=&%G9V%R`%)E;G-A(&9RY6=A`%)E
M;G-A(&%N=N1N9&%R93H@)7,`4F5N<V$@86YVY&1N87)E`%)E;G-A(&%N=N1N
M9&%R9&%T80!396YA<F4@=7!P:VQA<FYA;F1E`$ML:6-K82!F]G(@871T(&9O
M<G1SY'1T80!#;&EC:V%T96QL('9I82!(5%10`%-TY&YG(&;V;G-T97(`36]L
M;@!4:61I9V$@;6]L;@!-;VQN:6YG=`!#;V-O<R`H2V5E;&EN9RD@27-L86YD
M<P!+;VUP<FEM97)A('-I9&]FY&QT970`2V]M<')I;65R861E(')A;6%R`$MO
M;&]M8FEA`$;D<F<`1N1R9VAA;G1E<F%R90!&Y')G=F%L`$MO;'5M;F5R.@!+
M;VQU;6X@<G5B<FEK97(`3'5S=&EG:&5T97(`2V]M;6%N9&\`2V]M;6%N9&]F
M]FYS=&5R`$MO;6UE;G1A<@!.86UN`$-O;6]R;W,`1O9R971A9P!3;'5T9O9R
M9`!3:W)I=B!M961D96QA;F1E("@E<RD`1&%T;W)E<@!6Y&1E<@!6Y&1E<@!+
M;VYF:6=U<F%T:6]N<W-K:6QL;F%D97(`26YS=.1L;&YI;F=A<B!F]G(@871T
M('-Y;FMR;VYI<V5R82!M960@:&%N9&1A=&]R97(L('-M87)T82!T96QE9F]N
M97(@;V-H($]U=&QO;VL`2V]N9FEG=7)A=&EO;B!B96CV=F5R('5P<&1A=&5R
M87,N`$MO;F9I9W5R97)A("5S`$)E:W+D9G1A(&SV<V5N;W)D`$MO;F=O`$MO
M;F=O`$;V<F)I;F1E;'-E(&UI<W-L>6-K861E<RX`1O9R8FEN9&5L<V4@;6ES
M<VQY8VMA9&5S.B``1O9R8FEN9&5L<V4@;65D('!U8FQI:R!N>6-K96QS97)V
M97(@;F5K861E<RX`1O9R8FEN9&5L<V4@;65D('!U8FQI:R!N>6-K96QS97)V
M97(@;F5K861E<SH@)7,@*"5S*0!&]G)B:6YD96QS92!M960@1E10+7-E<G9E
M<B!M:7-S;'EC:V%D97,N`$MO;G1A:W1E<@!+;VYT86MT97(@;&%D97,@=&EL
M;"!I(&1I;B!A9')E<W-B;VLN`$EN;F5HY6QL<W1Y<"!F]G(@:V]M<')I;65R
M860@9FEL.B``26YN96CE;&P@:2`G)7,G`$9O<G1SY'1T`$-O;VL@27-L86YD
M<P!#;V]K:64`2V]P:65R80!+;W!I97)I;F<@;6ES<VQY8VMA9&5S.B`E<P!+
M;W!I97)A(&UA<FME<FEN9P!-86IS8FQO;6UA`$MO<W1N861S+4E$`$-O<W1A
M(%)I8V$`16QF96YB96YS:W5S=&5N`$MA;B!I;G1E(%!'4"UK<GEP=&5R82!M
M961D96QA;F1E+@!+86X@:6YT92!01U`M:W)Y<'1E<F$@;65D9&5L86YD93H@
M`$MA;B!I;G1E(%!'4"US:6=N97)A(&UE9&1E;&%N9&4N`$MA;B!I;G1E(%!'
M4"US:6=N97)A(&UE9&1E;&%N9&4Z(`!+86X@:6YT92!3+TU)344M:W)Y<'1E
M<F$@;65D9&5L86YD92X`2V%N(&EN=&4@4R]-24U%+7-I9VYE<F$@;65D9&5L
M86YD92X`2V%N(&EN=&4@;.1G9V$@=&EL;"!K;VYT86MT+B`E<P!-:7-S;'EC
M:V%D97,@871T(&MO;G1A:W1A($Q$05`@<V5R=F5R+@!+86X@:6YT92!V97)I
M9FEE<F$@:V]N=&]S86QD;RX@)7,`2W5N9&4@:6YT92!A;G-L=71A('1I;&P@
M3$1!4"US97)V97(N`$MA;B!I;G1E(&MO;G1A:W1A('-E<G9E<B`G)7,G('9I
M82!&5%`Z("5S`$MA;B!I;G1E('-K87!A(&1I<W1R:6)U=&EO;G-L:7-T82X@
M)7,`2V%N(&EN=&4@9&5K<GEP=&5R82!01U`M9&%T82X`2V%N(&EN=&4@9&5K
M<GEP=&5R82!01U`M9&%T83H@`$MA;B!I;G1E(&1E:W)Y<'1E<F$@4R]-24U%
M+61A=&$N`$MA;B!I;G1E(')A9&5R82!K;VYT86MT+B`E<P!+86X@:6YT92!R
M861E<F$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<P!+86X@:6YT92!R861E<F$@
M=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RX`2V%N(&EN=&4@8F5S=.1M
M;6$@;6]T=&%G87)E;G,@95!O<W0M861R97-S+@!+86X@:6YT92!HY&UT82!K
M;VUP;&5T="!A9')E<W-B;VLN`$MA;B!I;G1E(&CD;71A(&MO;7!L971T(&1I
M<W1R:6)U=&EO;G-L:7-T82X`2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@;&ES
M=&$@]G9E<B!D:7-T<FEB=71I;VYS;&ES=&]R+@!+86X@:6YT92!L861D82!S
M=')A=&5G:2`G)7,G+@!+86X@:6YT92!L861D82!S=')A=&5G:2`G)7,G+@!+
M86X@:6YT92!S:V%P82!M87!P("<E<R<N`$MA;B!I;G1E('-K87!A(&UA<'`@
M)R5S)RX`2V%N(&EN=&4@:.1M=&$@<'5B;&EK(&YY8VME;"!F<N5N(&YY8VME
M;'-E<G9E<FXN`$MA;B!I;G1E(/9P<&YA("<E<R<@9O9R('-K<FEV:6YG+@!+
M86X@:6YT92#V<'!N82`E<RX`2V%N(&EN=&4@]G!P;F$@)R5S)R!F]G(@<VMR
M:79I;F<N`$MA;B!I;G1E(/9P<&YA($UA:6YT96YA;F-E7U1A<VL@;6]D=6P@
M)7,`2V%N(&EN=&4@]G!P;F$@;6%P<&5N("<E<R<`2V%N(&EN=&4@]G!P;F$@
M;6%P<"`G)7,G`$MA;B!I;G1E(&MO;G1A:W1A($Q$05`@<V5R=F5R+@!+86X@
M:6YT92!LY'-A("5S+@!$970@9VEC:R!I;G1E(&%T="#E=&5R<W3D;&QA(&SV
M<V5N;W)D970@9O9R(&1E;B!A;F=I=FYA(&%N=N1N9&%R96XN($[E9V]N(&5L
M;&5R(&[E9W)A(&%V('5P<&=I9G1E<FYA(.1R(&EN=&4@:V]R<F5K=&$N($;V
M<G/V:R!I9V5N(&5L;&5R(&MO;G1A:W1A(&%D;6EN:7-T<F%T]G)E;B!O;2!D
M=2!B96CV=F5R(&AJY&QP+@!+86X@:6YT92!HY&UT82!!0TP`2V%N(&EN=&4@
M:.1M=&$@861R97-S8F]K+B`E<P!+86X@:6YT92!HY&UT82!D:7-T<FEB=71I
M;VYS;&ES=&$N("5S`$MA;B!I;G1E(&CD;71A(&1I<W1R:6)U=&EO;G-L:7-T
M;W(N("5S`$MA;B!I;G1E(&CD;71A(&1S97)V97)F=6YK=&EO;F5R`$MA;B!I
M;G1E(.5T97)S=.1L;&$@:V]N9FEG=7)A=&EO;F5N+@!+86X@:6YT92!R861E
M<F$@;6%P<"`G)7,G+@!+86X@:6YT92!R861E<F$@;6%P<"`G)7,G+@!+86X@
M:6YT92!S<&%R82!K;VYF:6=U<F%T:6]N(&;V<B`E<RX`2V%N(&EN=&4@<W!A
M<F$@8F%C:W5P+6MO;F9I9W5R871I;VXN`$MA;B!I;G1E('-P87)A(&5N(&)A
M8VMU<"UK;VYF:6=U<F%T:6]N.B`E<RX`2V%N(&EN=&4@<W!A<F$@=7!P9W)A
M9&5R:6YG<W-C<FEP="!T:6QL.B`E<RX`2V%N(&EN=&4@<W!A<F$@8F%C:W5P
M+6MO;F9I9W5R871I;VX@)7,N`$MA;B!I;G1E('-P87)A(&MO;F9I9W5R871I
M;VYS9FEL96X@)7,N($1U(&MA;B!A;G1I;F=E;B!A;G;D;F1A(&5N(&%V(&%L
M=&5R;F%T:79E;B!A='0@<W!A<F$@:V]D96X@=&EL;"`E<R!E;&QE<B!K;W!I
M97)A(&MO9&5N(&YE9&%N('1I;&P@)7,N`$MA;B!I;G1E('/V:V$@:2!,1$%0
M+6MA=&%L;V=E;BX`2V%N(&EN=&4@<F%D97)A("<E<R<N`$MA;B!I;G1E(')A
M9&5R82`G)7,G+@!+86X@:6YT92!U<'!D871E<F$@:V]N=&%K="X@)7,`2V%N
M(&EN=&4@=7!P9&%T97)A(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,`2V%N(&EN
M=&$@<W!A<F$@:V]N9FEG=7)A=&EO;B!F]G(@)R5S)SH@)7,`2V%N(&EN=&4@
M:&ET=&$@36]Z:6QL87,@<VED;V;D;'0N(%9E<FEF:65R82!A='0@<VED;V;D
M;'1E="#D<B#V<'!E="X`2V%N(&EN=&4@9V4@86YVY&YD87)E;B`G)7,G(&%N
M9VEV;F$@<N1T=&EG:&5T97(@=&EL;"!M87!P96X@)R5S)SH@)7,`4N1K;F%D
M('1E>'0`3&%N9`!+=7)S97(`4VMA<&$`4VMA<&$@;.1N:P!3:V%P82!N>0!3
M:V%P82!U;F1E<FUA<'``0F5H]G)I9VAE=&5R(&;V<B#D9V%R80!+<F5D:71K
M;W)T<VYU;6UE<@!+<F]A=&EE;@!+=6)A`$%K='5E;&QA(#0@9F%S97(`06MT
M=65L;"!S97-S:6]N`$%K='5E;&P@=&ED`$%K='5E;&P@55),(.1R`$%K=&EV
M82!A;G;D;F1A<F4`06MT=65L;'0@=N1D97(`06MT=65L;&$@=FEL;&MO<CH@
M`$%K='5E;&P@<W1I;`!3:W+D9&1A<G-Y(&%K=&EV:71E=&5R('-O;2!K]G)S
M('9I9"!I;FQO9VYI;F<@=&EL;"`E<RX`2VQI<'`@=70`2VQI<'`@=7)V86P`
M0WEP97)N`$MY<FEL;&ES:R`H2T])."U2*0!+>7)I;&QI<VL@*%=I;F1O=W,M
M,3(U,2D`2WER:6QL:7-K+U5K<F%I;G-K("A+3TDX+54I`%1J96-K:65N`$1$
M`$1A9VQI9P!$871A5')E92!B;.1D9')A<F4`1&%T86)A<W5P<'-L86<`1&%T
M=6T`1&%T=6T@;6]T=&%G970`1&%T=6UV86P`1&%G`%]2861E<F$@:V]L=6UN
M`&1E8V5M8F5R`$1E8VEM86QE<@!!=F+V:G0`36EN<VMA(&EN9')A9P!&]G)V
M86QT`$;V<G9A;&0@9N1R9P!&]G)V86QD(&ED96YT:71E=`!&]G)V86QT('-K
M86P`1&5F:6YI=&EO;F5R`$1E;&5G97)A('!O<VET:6]N`$1E;&5G97)A9`!2
M861E<F$`4F%D97)A(&-E;&P`4F%D97)A(&=R=7!P`%)A9&5R82!L;V=G`%)A
M9&5R82!B96CV<FEG:&5T`%)A9&5R82!O8V@@<F5N<V$@;65D9&5L86YD96X`
M4F%D97)A(&-E;&P`4F%D97)A(&MO;'5M;@!2861E<F$@8F5F:6YT;&EG(&%L
M=&5R;F%T:79M86QL`%)A9&5R861E(&UE9&1E;&%N9&5N`%)A9&5R82!B96CV
M<FEG:&5T(&;V<B`G)7,G`%)A9&5R82!B96CV<FEG:&5T(&;V<B`G)7,G(&]C
M:"!U;F1E<F)E:/9R:6=H971E<C\`4F%D97)A(')A9`!2861E<F$@=F%L9"!I
M9&5N=&ET970`4F%D97)A('5N9&5R;6%P<&%R`%)A9&5R82!A:W1U96QL(&MO
M;'5M;@!2861E<F$@86MT=65L;"!R860`4F%D97)A(&1E;B!HY'(@;.1N:V5N
M`%)A9&5R861E('5P<&=R861E<FEN9W-S8W)I<'1E="`G)7,G+@!,979E<F%N
M<W1I9`!$86YM87)K`$%V<VSE(&)E9^1R86X`079S;.4@8F5GY')A;B!O;2!L
M961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;@!"97-K<FEV('!R;V)L96UE=`!"
M97-K<FEV;FEN9P!$971A;&IE<B`H;V-K<^4@:2!(;W)D97,@;&]G9V9I;"DZ
M`$1E=&%L:F5R(&AA<B!L;V=G871S(&;V<B!S>7-T96UA9&UI;FES=')A=/9R
M96XN`%5T=F5C:VQI;F<`1&%G9W!U;FMT`$1A9V=P=6YK="!F]G(@<V5N87-T
M92!T:6UM96XZ(`!$86=G<'5N:W0Z(`!2:6MT;FEN9R!VY&YS=&5R('1I;&P@
M:/9G97(`4FEK=&YI;F<@:/9G97(@=&EL;"!VY&YS=&5R`$MA=&%L;V<`5FES
M82`R-"UT:6UM87)S(&ML;V-K83\`5FES;FEN9W-I;G-TY&QL;FEN9V%R`%9I
M<V$@9&5T86QJ97)A9"!F]G)U='/D9V5L<V4`5FES82!F]G)U='/D9V5L<V4@
M*%1!1BD`5FES;FEN9W-F;W)M870`079S:VEL:F%R90!$:FEB;W5T:0!2861E
M<F$@:6YT90!!;G;D;F0@:6YT92!M86EN=&5N86YC92YP:'`@9&ER96MT`$EN
M;F5HY6QL97(@9O9R<W1A(')A9&5N(&;D;'1N86UN96X_($]M("=J82<L(&UA
M<FME<F$@:.1R.@!$;VUI;FEK86YS:V$@<F5P=6)L:6ME;@!(87(@9'4@:6YG
M970@:V]N=&\_(%)E9VES=')E<F$@9&EG+@!(Y&UT80!(Y&UT82`E<P!(Y&UT
M82!G96YE<F5R860@:V]N9FEG=7)A=&EO;B!S;VT@4$A0+7-K<FEP="X`1')O
M<'!L:7-T80!$<F]G97(`12UP;W-T`$1R:79R=71I;B!F]G(@12UP;W-T('1I
M;&P@4TU3+6)R>6=G83L@9O9R(&]P97)A=/9R97(@<V]M('1I;&QH86YD86CE
M;&QE<B!D96YN82!T:N1N<W0N`$9%3`!%:W5A9&]R`,1N9')A`,1N9')A(&)L
M;V-K`,1N9')A(&=R=7!P`,1N9')A(&)E:/9R:6=H970`Q&YD<F$@8F5H]G)I
M9VAE=&5R`,1N9')A(&)E:/9R:6=H971E<B!F]G(@)7,`Q&YD<F$@:6YS=.1L
M;&YI;F=A<B!F]G(Z`,1N9')A(&)E:/9R:6=H971E<B!F]G(@)R5S)P#$;F1R
M82!B96CV<FEG:&5T97(@9O9R("<E<R<`571B:6QD;FEN9P!%9WEP=&5N`$5L
M(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`12UP;W-T`$4M<&]S=&%D<F5S<P!%
M+7!O<W1A9')E<W-E<B!MY7-T92!S=.1M;6$@]G9E<G)E;G,N`$4M<&]S=&UE
M9&1E;&%N9&4@;65D(&)E:W+D9G1E;'-E`$4M<&]S="!T:6QL(%--4RUB<GEG
M9V$`2^1N<VQO:6MO;F5R`%1O;70@;65D9&5L86YD92X`5&]M="!R97-U;'1A
M="X`5&]M="!S]FMK<FET97)I80!3;'5T`%-L=70@Y7(`1O9R<W1O<F$@961I
M=&]R`$%N9V4@<_9K=N1G("A54DPI('1I;&P@8FEL9&5N(&CD<@!32W)I=B!B
M;VMS=.1V97)N82!N961A;CH`1F5L`$9E;"!V:60@<VMA<&%N9&4@878@8FQO
M8VLZ("5S`$9E;"!V:60@<F%D97)I;F<@878@<WEN:W)O;FES97)I;F=S;>1R
M:V4Z("5S`$9E;"!V:60@<F%D97)I;F<@878@<WEN:W)O;FES97)I;F=S;&]G
M9SH@)7,`1F5L(&[D<B!I;FYE:.5L(&CD;71A9&5S.B`E<P!&96P@=6YD97(@
M<^1N9&YI;F<@878@<W9A<G-M961D96QA;F1E.B`E<P!&96P@=FED('5P<&1A
M=&5R:6YG(&%V(&SV<V5N;W)D.B`E<P!&96P@=FED('-K<FEV;FEN9R`G)7,G
M+@!&96P@=FED('-K<FEV;FEN9R!A=B`G)7,G+@!%<W1L86YD`$5T:6]P:65N
M`$5T;FES:P!%=7)O<&$`5F%R(#$U.F4@;6EN=70`5F%R86YN86X@;6EN=70`
M5F%R(#,P.F4@<V5K=6YD`%9A<B`U.F4@;6EN=70`5F%R:F4@:6YL;V=G;FEN
M9P!687)J92!H86QV=&EM;64`5F%R:F4@;6EN=70`17AE;7!E;"!PY2!VY')D
M96XZ`$OV<@!%>'!A;F1E<F$`17AP86YD97)A('-I9&]FY&QT`$;V<G;D;G1A
M9&4@)RDG`$;V<G;D;G1A9&4@96YS:VEL="!O<F0@96QL97(@8VET97)A="!S
M]FMB96=R97!P`$;V<F9A;&QO9&%T=6T`17AP;VYE;G0`1O9R9W)U;F1S9N1R
M9P!,861D82!U<'`@:V]N9FEG=7)A=&EO;B!V:6$@1E10+@!-:7-S;'EC:V%D
M97,@871T(&CD;71A(&EN<W3D;&QN:6YG87(N`$UI<W-L>6-K861E<R!A='0@
M:V]N=&%K=&$@3$1!4"!S97)V97(N`$UI<W-L>6-K861E<R!A='0@:V]N=&%K
M=&$@4TU"('-E<G9E<BX`36ES<VQY8VMA9&5S(&%T="!K;W!I97)A(&9RY6X@
M)R5S)RX`36ES<VQY8VMA9&5S(&%T="!K;W!I97)A('1I;&P@)R5S)RX`36ES
M<VQY8VMA9&5S(&%T="!S:V%P82!N>2!305-,+6;V<F)I;F1E;'-E+@!-:7-S
M;'EC:V%D97,@871T(&9L>71T82!T:6QL("<E<R<N`$UI<W-L>6-K861E<R!A
M='0@:.1M=&$Z("5S`$)R80!&86QK;&%N9'/V87)N80!&Y'+V87)N80!&871A
M;'0@9F5L.@!&87@`1F%X87(`9F5B<G5A<FD`2^1N;G,@<V]M`$OD;FYS('-O
M;3H@`$;E=&%L:6=A('-K=7)A<@!&Y71A;&EG82!S;O9S:W5R87(`1N1L=&UA
M=')I<P!&:6=L970@0T%05$-(00!&:6=L971T>7!S;FET=`!&:6II`$9I;`!!
M;G1A;"!F:6QE<CH@)7,@9FEL`$%N=&%L(&9I;&5R.B`E<R!F:6QE<@!&:6QH
M86YT97)A<F4`1FEL;F%M;@!&:6QV86P`1FEL=7!P;&%D9&YI;F<`1FEL=7!P
M;&%D9&YI;F<@<W3V9',@:6YT92X`1FEL=&5R`$9I;FQA;F0`1O9R<W1A(&AA
M;'9A;@!&]G)S=&$@:W9A<G1E;@!-87!P("5S(&5X:7-T97)A<B!I;G1E+@!&
M;VYT9N1R9P!-870`1O9R('=E8F)LY'-A<F4@<V]M(&EN=&4@<W3V9&5R(&)I
M;&1E<@!0<F]G;F]S("A4048I`$%N=&%L(&1A9V%R(&;V<B!P<F]G;F]S("AV
M87)J92!D86<@8F5T>61E<B!E;B!P<F]G;F]S(&;V<B!D86<@;V-H(&5N(&;V
M<B!N871T*0!';/9M="!D:71T(&SV<V5N;W)D/P!&;W)M=6SD<@!6:7-H971S
M;W)D`%1Y<"!A=B!V:7-H971S;W)D`%9I<VAE='-O<F0`5FES:&5T<V]R9"`R
M`$9O<G5M`%9I9&%R8F5F;W)D<F%R`$9R`%)A;6%R`$9R86YK<FEK90!&<F%N
M:W)I:V4L($UE=')O<&]L`$QE9&EG+U5P<'1A9V5N(&EN9F]R;6%T:6]N`$QE
M9&EG+U5P<'1A9V5N('-V87(`3&5D:6<O=7!P=&%G96XM9O9R9G+E9V%N`%-V
M87(@<.4@;&5D:6<O=7!P=&%G96XM9O9R9G+E9V%N`$9R86YS:V$@1W5I86YA
M`$9R86YS:V$@4&]L>6YE<VEE;@!&<F%N<VMA('/V9')A('1E<G)I=&]R:65R
M`$9RY6X`1G+E;B!D96X@`$9U;&QS=.1N9&EG(&)E<VMR:79N:6YG`$9U;&QM
MY6YE`$9U;&QS=.1N9&EG="!N86UN`$=A8F]N`$=A;&QE<FD@871T('1A(&)I
M;&0@9G+E;@!'86QL97)I.@!'86UB:6$`1V5N97)E<F$@:V]N9FEG=7)A=&EO
M;B!F]G(@)7,`1V5N97)E<F%D(&MO9`!'96]R9VEE;@!4>7-K;&%N9`!':&%N
M80!':6)R86QT87(`1O9R;F%M;@!';&]B86QA(&EN<W3D;&QN:6YG87(`3TL`
M1V]E9&5L`$=O;V=L96MA<G1O<@!';V]G;&5S]FMN:6YG`$=RY7-K86QA`$=R
M96MI<VL@*$E33RTX.#4Y+3<I`$=R]FX`1W+V;FQA;F0`1W)A;F%D80!'<N4`
M1W)U<'!A9&UI;FES=')A=&EO;@!'<F]U<%]L9&%P.B!+86X@:6YT92!LY&=G
M82!T:6QL(&=R=7!P("<E<R<N(%-E<G9E<FX@<W9A<F%D93H@`$=R;W5P7VQD
M87`Z($MA;B!I;G1E(')A9&5R82!G<G5P<"`G)7,G`$=R;W5P7VQD87`Z($MA
M;B!I;G1E('5P<&1A=&5R82!G<G5P<"`G)7,G`$=R=7!P97(`1W5A;0!'=6%T
M96UA;&$`1W5E<FYS97D`1^1S=&)E:/9R:6=H971E<@!4:N1N<W1E<B!F]G(@
M9^1S=&5R`$?D<W1B;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5I;F5A`$A4
M34P`2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@<VES=&$@8V5L;&5N(&D@
M96X@<F%D+@!(5$U,07)E82!VY&=R87(@871T(')A9&5R82!S:7-T82!K;VQU
M;6YE;B!I(&5N('1A8F5L;"X`2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@
M<VES=&$@<F%D96X@:2!E;B!T86)E;&PN`$A45%`@075T96YT:7-E<FEN9R!S
M86MN87,N`$AA:71I`$AA<VAA;&=O<FET;0!$:6UM80!2=6)R:6L`4G5B<FEK
M97(`2&5A<F0M(&]C:"!-8T1O;F%L9/9A<FYA`$MR869T:6=A(.5S:W-K=7)A
M<@!(96)R96ES:R`H25-/+3@X-3DM."U)*0!(]FID`$CV:F0@*'!I>&QA<BD`
M2&KD;'``2&KD;'`@;65D(&5D:71O<FX`2&KD;'!F=6YK=&EO;@!(96UI<V;D
M<@!(Y'(@Y'(@8O9R:F%N(&%V(&9I;&5N.@!(]F<`2&5?;0!(96T`061R97-S
M+"!H96T`2&5M:V%T86QO9P!496QE9F]N+"!H96T`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!/9VEL=&EG="`E<R!834PM9&%T82!P
MY71RY&9F861E<R!I(&UE9&1E;&%N9&4@)7,`2&]R9&4O2V]L86(Z($EN9V5T
M(&UE9&1E;&%N9&4@;6%T8VAA<B!O8FIE:W1E="`E<P!(;W)D92]+;VQA;CH@
M26YG970@;V)J96MT(&%V('1Y<&5N("5S(&AI='1A9&5S(&D@;65D9&5L86YD
M970@)7,`2&]R9&4O2V]L86(Z(%)A9&5R861E("5S("<E<R<`2&]R9&4O2V]L
M86(Z($EN=&5G<F%T:6]N<VUO=&]R;B!K<N1V97(@)V1O;7AM;"<M=&EL;.1G
M9V5T(&;V<B!02%``2&]R9&4O2V]L86(Z($MA;B!I;G1E('-K87!A(&YY='0@
M6$U,+71RY&0@9O9R(&]B:F5K="`E<P!(;W)D92]+;VQA8CH@2V%N(&EN=&4@
M<F%D97)A("5S("<E<R<Z("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!HY&UT
M82!-24U$12U)1"!F]G(@9&5L96X@;65D('1Y<"`E<P!(;W)D92]+;VQA8CH@
M2V%N(&EN=&4@<WEN:W)O;FES97)A("5S("<E<R<Z("5S`$AO<F1E+TMO;&%B
M.B!+86X@:6YT92!S>6YK<F]N:7-E<F$@=71D96QN:6YG87(Z("5S`$AO<F1E
M+TMO;&%B.B!/:^1N9"!U=&1E;&YI;F<@)R5S)P!(;W)I<V]N=&5L;"!L:6YJ
M90!(;W)I<V]N=&5L;"!U=&9Y;&QN860`2&]R:7-O;G1E;&PZ`$AU<B!H86UN
M861E(&1U(&CD<C\@*%9A<B!G;V0@<F%P<&]R=&5R82!D971T82$I`$AU<B!M
MY6YG82!K;VQU;6YE<B!V:6QL(&1U('-LY2!I:&]P/P!(=7(@;>5N9V$@9N1L
M="`H:V]L=6UN97(I(&9I;FYS(&1E=#\`2'5R(&WE;F=A(')A9&5R('9I;&P@
M9'4@<VSE('-A;6UA;C\`1G5K=&EG:&5T`$9U:W1I9VAE=#H`2'5M;W)I<W1E
M<@!5;F=E<FX`4VMA<&%N9&4@878@24U!4"UM87!P(&UI<W-L>6-K861E.B`E
M<P!2861E<FEN9R!A=B!)34%0+6UA<'`@;6ES<VQY8VMA9&5S.B`E<P!3:V%P
M86YD92!A=B!Q=6]T82!F]G(@24U!4"UM87!P(&UI<W-L>6-K861E<SH@)7,`
M25`M861R97-S`$E0+6%D<F5S<R#D<B!I;G1E('1I;&QGY&YG;&EG+@!)4"UA
M9')E<W,@Y'(@:6YT92!I;F]M(&=O9&OD;G0@0TE$4BUB;&]C:RX`1O9R<_9K
M(&%T="!K<FEN9V?E($E0+6SE<RX`25]N9F]G82!R860@9O9R90!)<VQA;F0`
M16YB87)T(&EK;VYE<@!):V]N97(@9O9R("5S`$EK;VYE<B!M960@=&5X=`!)
M9&5N=&ET971E;G,@;F%M;CH`3VT@9&5T(&EN=&4@=FES87,@:V]R<F5K="P@
M)7,@9O9R(&%T="#V<'!N82!I(&YY='0@9O9N<W1E<BX`3VT@9'4@:6YT92!S
M97(@;N5G<F$@:6MO;F5R(&[D<B!D=2!A;G;D;F1E<B!);G1E<FYE="!%>'!L
M;W)E<BP@<^4@:V%N(&1U(&)E:/9V82!M87)K97)A(&1E;FYA(')U=&$@9O9R
M(&%T="!S=.1N9V$@878@9V5N;VUS:VEN;&EG82!03D<M8FEL9&9I;&5R+@!/
M;2!D=2!S97(@9&5N;F$@=&5X="!M96X@:6YG96X@8FEL9"P@<^4@:V%N(&EN
M=&4@9&EN('=E8F)LY'-A<F4@=FES82!D96X@8FEL9"!D=2!F]G)S]FME<B!L
M861D82!U<'`N`$;V<FAA;F1S9W)A;G-K82!B:6QD.@!":6QD861R97-S`$)I
M;&1A9')E<W,Z`$)I;&0@9G+E;B!G86QL97)I`$)I;&0@9G+E;B!G86QL97)I
M.@!,861D82!U<'`@8FEL9`!":6QD97(`26UP;W)T97)A+"!S=&5G("5D`$EM
M<&]R=&5R861E(&;D;'0Z("5S`$EM<&]R=&5R861E(&;D;'0Z`%#E9^5E;F1E
M`$EN7V9O9V$@<F%D(&5F=&5R`$9E;&%K=&EV(&%K=&EV:71E='-K;V0@<W!E
M8VEF:6-E<F%D+@!&96QA:W1I9W0@86YVY&YD87)N86UN(&]C:"]E;&QE<B!L
M]G-E;F]R9"X`3V=I;'1I9W0@86YVY&YD87)N86UN(&5L;&5R(&%L=&5R;F%T
M:78@861R97-S+B!&]G)S]FL@:6=E;B!E;&QE<B!K;VYT86MT82!A9&UI;FES
M=')A=/9R96X@;VT@9'4@8F5H]G9E<B!H:N1L<"X`UFMA(&EN9')A9P!);F1I
M96X`26YD:79I9'5E;&QA(&%N=N1N9&%R90!);F1O;F5S:65N`$EN9F\`26YF
M;W)M871I;VX`26YF;W)M871I;VX@Y'(@:6YT92!T:6QL9^1N9VQI9R!LY&YG
M<F4N`$EN9F]G82!K7V]L=6UN(&5F=&5R`$EN9F]G82!B:6QD`$EN9F]G82!T
M86)E;&P`26YF;V=A('=E8F)LY&YK`$EN9F]G82!?:V]L=6UN(&;V<F4`26YF
M;V=A(&YY(&MO;'5M;B!E9G1E<B!A:W1U96QL(&MO;'5M;@!);F9O9V$@;GD@
M:V]L=6UN(&;V<F4@86MT=65L;"!K;VQU;6X`26YF;V=A(')A9"!E9G1E<B!A
M:W1U96QL(')A9`!);F9O9V$@;GD@<F%D(&;V<F4@96MT=65L;"!R860`26YF
M;V=A('!A<F%G<F%F(&5F=&5R(&%K='5E;&P@;F]D`$EN9F]G82!P87)A9W)A
M9B!F]G)E(&%K='5E;&P@;F]D`$EN9F]G82!A;'1E<FYA=&EV(&UA;&P`26YF
M;V=A(&-E;&P@969T97(`26YF;V=A(&-E;&P@9O9R90!);F9O9V$@:V]L=6UN
M(&5F=&5R`$EN9F]G82!K;VQU;6X@9O9R90!);F9O9V$@;65D9&5L86YD96X`
M26YF;V=A('!A<F%G<F%F(&5F=&5R`$EN9F]G82!P87)A9W)A9B!F]G)E`$EN
M9F]G82!R860@969T97(`26YF;V=A(')A9"!F]G)E`$%N9V4@97)F;W)D<F%T
M('-V87(@=&EL;"!SY&ME<FAE='-F<N5G86XZ`$EN9F]G82_$;F1R82!B:6QD
M`$EN9F]G82_$;F1R82!LY&YK`$]T:6QL<N1C:VQI9R!K<F5D:70@9O9R(&%T
M="!S:VEC:V$@=&EL;"!D:7-T<FEB=71I;VYS;&ES=&$N`$]T:6QL<N1C:VQI
M9R!K<F5D:70N`$AE;'1A;`!(96QT86QS;&ES=&$`3V=I;'1I9R#E=&?D<F0@
M9O9R(&1E;B!HY'(@:V]M<&]N96YT96XN`$]G:6QT:6<@541(("@G=7-E<B!D
M871A(&AE861E<B<I+@!/9VEL=&EG="!:25`M87)K:79D871A`$9E;&%K=&EG
M(&%P<&QI:V%T:6]N+@!&96QA:W1I9W0@8F%T8V@M240`1F5L86MT:6<@9&%T
M82!S:VEC:V%D+@!&96QA:W1I9R!D97-T:6YA=&EO;G-A9')E<W,N`$9E;&%K
M=&EG="!F:6QF;W)M870`3V=I;'1I9R!L:6-E;G-N>6-K96PN`$9E;&%K=&EG
M(&]R="!S<&5C:69I8V5R860N`$9E;&%K=&EG(&UE9&1E;&%N9&5?='EP+@!&
M96QA:W1I9R!E;&QE<B!S86MN860@87!I7VED+@!&96QA:W1I9W0@96QL97(@
M<V%K;F%D('!A<F%M971E<BX`1F5L86MT:6<@]G9E<FQI9V=A;F1E(&)E:/9R
M:6=H970N`$9E;&%K=&EG="!P87)T;F5R+6ED+@!&96QA:W1I9R!P<F]D=6MT
M:V]D+@!&96QA:W1I9W0@<')O=&]K;VQL+@!&96QA:W1I9R!M;W1T86=A<F4Z
M("<E<R<`1F5L86MT:6=T('5T9&5L;FEN9W-O8FIE:W0`1F5L86MT:6<@879S
MY&YD87)A9')E<W,N`$9E;&%K=&EG="!U;FEC;V1E+61A=&$`26YV96YT87)I
M97(`26YV97)T97)A('5R=F%L`$ER86X`27)A:P!)<FQA;F0`27-L92!O9B!-
M86X`16YS=&%K82#E<VMS:W5R87(`27-R865L`%5T9N1R9&%T(&%V`$MU<G-I
M=@!)=&%L:65N`$IA;6%I8V$`:F%N=6%R:0!*87!A;@!*87!A;G-K("A)4T\M
M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE;@!J=6QI`&IU;FD`2G5S=&5R80!#
M96YT97)J=7-T97)A`$IU<W1E<F$@:N1M=`!6Y&YS=&5R:G5S=&5R80!(]F=E
M<FIU<W1E<F$`2V5N>6$`2V5R8F5R;W-S97)V97)N(&%V=FES861E(&%U=&5N
M=&ES97)I;F=E;BX`3GEC:V5L('-K87!A9`!&:6YG97)P<FEN=`!.>6-K96QL
MY&YG9`!.>6-K96QT>7``3GEC:V5L86YVY&YD86YD90!.>6-K96P@9FEN;G,@
M<F5D86X@<.4@9&5N('!U8FQI:V$@;GEC:V5L<V5R=F5R;BX`0F%R;@!+:7)I
M8F%T:0!+;VQA8@!.;W)D:V]R96$`4WED:V]R96$`2V]R96%N<VL@*$550RU+
M4BD`2W5W86ET`$MI<F=I<W1A;@!,85]Y;W5T`%-P<N5K`$QA;W,`4VES=&$@
M:&%L=F%N`$SV<V5N;W)D(.1N9')A9&5S`%-I<W1A(&MV87)T86QE=`!396YA
M<W0@=7!P9&%T97)A9#H`4V5N87-T92!I;FQO9V=N:6YG.B`E<P!396YA<W1E
M(&EN;&]G9VYI;F<Z("5S(&9RY6X@)7,`4V5N87-T92!I;FQO9V=N:6YG.B!!
M;&1R:6<`3&5T=&QA;F0`3&%V96YD97(`3&%G`$QA>6]U=`!,Y&UN82!T;VT@
M9O9R(&%T="!S=.1N9V$@878@:V%N=&QI;FIE`$QI8F%N;VX`5N1N<W1E<@!6
MY&YS=&5R<G5B<FEK`%;D;G-T97)VY')D96X`3&5S;W1H;P!.:7;E`$QI8F5R
M:6$`3&EB>65N`$QI96-H=&5N<W1E:6X`3&IU<V)LY0!$=6=G<F5G;@!,Y'1T
M(')E9VX`3.1T="!F]G)M:61D86=S<F5G;@!,Y'1T(&5F=&5R;6ED9&%G<W)E
M9VX`3.1T="!R96=N<VMU<@!,Y'1T(')E9VX@;65D(.5S:V$`3.1T="!S;O8`
M3.1T="!S;O9S:W5R`$QI;65R:6-K`$SD;FL`3.1N:V5N('!E:V%R('#E.@!,
MY&YK82!E+7!O<W1A9')E<W-E;B!T:6QL(&9U;FMT:6]N96X@9O9R(&%T="!S
M:V%P82!N>71T(&UE9&1E;&%N9&4`3.1N:V%R`$MA:V$`3&ES=&$@+2!A;G;D
M;F1A<F4@:V%N('-E(&UA<'!E;@!6:7-A(&1A=&%B87-E<@!6:7-A(&AJY&QP
MY&UN96X`3&ES=&$@=&%B96QL97(`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,
M:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI
M<W0M56YS=6)S8W)I8F4`1&5T(&=I8VL@:6YT92!A='0@;&ES=&$@<V5S<VEO
M;F5R.B`E<P!$970@9VEC:R!I;G1E(&%T="!L:7-T82!A;G;D;F1A<F4Z("5S
M`$QI<W1N:6YG(&%V(&%N=N1N9&%R92!A=F%K=&EV97)A9"X`3&ET=&5R871U
M<@!,:71A=65N`$QA9&1A<BXN+@!,;VMA;"!T:60Z(`!296=I;VYA;'0`4&QA
M=',`3&]G9V$@:6X`3&]G9V$@=70`3&]G:6X`3&]G:6YA:W1I=FET971E<@!)
M;FQO9V=N:6YG(&UI<W-L>6-K861E<RX@5')O;&EG='9I<R!V87(@86YVY&YD
M87)N86UN(&5L;&5R(&SV<V5N;W)D(&9E;&%K=&EG="X`26YL;V=G;FEN9R!M
M:7-S;'EC:V%D97,N`$SE;F<@=&5X=`!+Y')L96L`3.5G`$=R96MI<VMA(&=E
M;65N97(`3&%T:6YS:V$@9V5M96YE<@!3;>4@<F]M97)S:V$@<VEF9G)O<@!,
M;WEO;&$`3&]Y;VQA($)LY0!,=7AE;6)U<F<`34T`34]41`!-4RU43D5&(&)I
M;&%G82!I;FYE:/9L;"!I;F=E;B!D871A+@!-4T<`36%C86\`36%C961O;FEE
M;@!-86=A9V%S:V%R`$UA9VES:P!%+7!O<W0`12UP;W-T861M:6X`4VMA<&$@
M;.1N:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97)N80!-86QI`$UA;'1A
M`%5N9&5R:.5L;"!L:7-T86X@;65D(&MA=&5G;W)I97(@9'4@86YVY&YD97(@
M9O9R(&%T="!K871E9V]R:7-E<F$@<&]S=&5R(&UE9"!O8V@@9N1R9V5R;F$@
M<V]M('1I;&QH]G(@9&5S<V$@:V%T96=O<FEE<BX`36%P,C0M:V%R=&$`36%P
M475E<W0M:V%R=&$`UG9E<G/D='1N:6YG87(@<W!A<F%D92X`;6%R<P!-87)G
M:6YA;`!&;&%G9V$@<V]M(&SD<W0O;VSD<W0`1FQA9V=A(&UE9"!A;FYA;B!S
M=&%T=7,@*'0@97@@=FEK=&EG="]B97-V87)A="D`36%R<VAA;&SV87)N80!-
M87)T:6YI<75E`$UA=&-H86YD92!FY&QT`$UA=7)I=&%N:65N`$UA=7)I=&EU
M<P!-87@@=&EL;.5T96X@:W)E9&ET+@!'<N1N<R!F]G(@;6%X(&%N=&%L(&1E
M;&%R(&D@;65D9&5L86YD92#V=F5R<VMR:61E;BX`2/9G<W1A('1E;7!E<F%T
M=7)E('-E;F%S=&4@,C0@=&EM;6%R;F$Z(`!(]F=S=&$@=&5M<&5R871U<F4@
M<V5N87-T92`V('1I;6UA<FYA.B``36%X:6UA;'0@86YT86P@<&]R=&%L8FQO
M8VL`36%X:6UA;"!LY&YG9`!M86H`36%Y;W1T90!-961I8VEN`$%V8F]K82!M
M]G1E`$WV=&5S:6YF;W)M871I;VX`3?9T97-F]G)F<N5G86X`3?9T97-S=F%R
M`$WV=&5S=7!P9&%T97)I;F<`57!P9&%T97)I;F=S8F5GY')A;B!O;2!M]G1E
M`$UE9&QE;6UA<@!-96YY;.1G93H`4VSE(&EH;W`@8V5L;&5R`$UE9&1E;&%N
M9&4`365D9&5L86YD970@=F5R:69I97)A9&5S(&UE;B!D96X@<VEG;F5R861E
M<R!C97)T:69I:V%T(&MU;F1E(&EN=&4@=F5R:69I97)A<RX`365D9&5L86YD
M92!GY&QL97(@:6YT92!LY&YG<F4N`$UE9&1E;&%N9&5T>7``365T87)VY&1E
M<@!-971A<F)L;V-K970@Y'(@:6YT92!T:6QL9^1N9VQI="X`365T87(M8FQO
M8VL@96H@=&EL;&?D;F=L:6=T+B!$971A;&IE<B!H87(@;&]G9V%T<R!F]G(@
M<WES=&5M861M:6YI<W1R873V<F5N+@!-971A<D1"(.1R(&EN=&4@86YS;'5T
M96XN`$UE=&]D`$UE=&]D96X@)R5S)R#D<B!I;G1E(&1E9FEN:65R860`365T
M;V1E;B!H87(@:6YT92!D969I;F5R871S+B!!;G)O<&%D(&UE=&]D.B`E<P!-
M971R:7-K`$UE>&EK;P!-:6MR;VYE<VEE;@!-:71T96X`36EM971Y<`!,Y&=S
M=&$@=&5M<&5R871U<B!S96YA<W1E(#(T('1I;6UA<FYA.B``3.1G<W1A('1E
M;7!E<F%T=7(@<V5N87-T92`V('1I;6UA<FYA.B``36EN<W1A(&SV<V5N;W)D
M<^5L9&5R(&AA<B!I;G1E('5P<&[E='1S(.1N`%-P96=L80!$:79E<G-E`$]B
M;&EG871O<FES:W0@<&%K970@<V%K;F%S("A014%2($A45%!?4F5Q=65S="DN
M`$MO;F9I9W5R871I;VX@<V%K;F%S+B!$=2!MY7-T92!S:V%P82!D96X@;G4@
M;VT@9'4@=FEL;"!A;G;D;F1A(&1E;B!HY'(@87!P;&EK871I;VYE;BX`4V%K
M;F%R(&UE9&1E;&%N9&4M240N`$]B;&EG871O<FES:W0@<&%K970@<V%K;F%S
M("A014%2($UA:6PI+@!386MN87(@<V5S<VEO;G,M240N`$WE`$UO8FEL(&4M
M<&]S=`!-;V1E<F5R80#$;F1R860@9&%T=6T`Q&YD<F$@;.1N:P!-;V1U;'5S
M`$UO;&1A=FEE;@!-;VYA8V\`36]N9V]L:65T`$WE;F%D(&]C:"#E<@!-Y6YA
M=&QI9P!-;W1S97)R870`3>5N9F%S97(`1FQE<B!FY&QT(&AI='1A9&5S('#E
M(')A9"`E9"#D;B!D970@9O9R=N1N=&%D92`E9"X`36%R;V-K;P!-97-T861E
M;',@:VQA<G0`365S=&%D96QS(&UO;&YI9W0`365S=&%D96QS('-O;&EG=`!&
M;'ET=&$@;F5D`$9L>71T82!VY&YS=&5R`$9L>71T82!H]F=E<@!&;'ET=&$@
M=7!P`$9L>71T82!N960`1FQY='1A('5P<`!-;^=A;6)I<75E`$UO>FEL;&$`
M1FQE<FYI=N5S;&ES=&$`375L=&EM87`@4W1O<F)R:71A;FYI96YK87)T80!&
M;&5R=F%L`$UI='0@:V]N=&\`36EN(&MO;G1O:6YF;W)M871I;VX`36EN('!O
M<G1A;`!-:6X@<&]R=&%L;&%Y;W5T`$UY86YM87(`3D5*+"!*86<@86-C97!T
M97)A<B!I;G1E`$YA;6X`3F%M:6)I80!.875R=0!.95A4`$)E:/9V97(@Y71G
MY')D`$YE<&%L`$YE9&5R;.1N9&5R;F$`3F5D97)LY&YD<VMA($%N=&EL;&5R
M;F$`3F5S8V%P92!B87,M55),`$YE='-C87!E(&;V<FYY96QS92U54DP`3F5T
M<V-A<&4@Y71E<FMA;&QE;'-E+5523`!.971S8V%P92!34TPM<V5R=F5R;F%M
M;@!.971S87!E(&-E<G1I9FEK871S:V]M;65N=&%R`$YE='-A<&4@8V5R=&EF
M:6MA='-T>7``3N1T=F5R:P!!;&1R:6<`3GEA($MA;&5D;VYI96X`3GD@:V%T
M96=O<FD`3GET="!M961D96QA;F1E('1I;&P@)7,`3GEMY6YE`$YY='0@86YV
MY&YD87)N86UN("AV86QF<FET="D`3GEA(%IE96QA;F0`3GET="!L]G-E;F]R
M9`!.>71T(&SV<V5N;W)D(&MO;6UE<B!A='0@9^4@=70@)7@N`$SV<V5N;W)D
M(&WE<W1E('9A<F$@<V%M;6$N`$YY='0@9O9N<W1E<B`H7V)L86YK*0!.>6AE
M=&5R`$YY:&5T<V=R=7!P97(`3N1S=&$`2V]M;6%N9&4@-"!F87-E<@!.Y'-T
M82!I;G-TY&QL;FEN9V%R`$[D<W1A/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I
M80!.871T`$YI=64`3F5J`$1E="!F:6YN<R!I;F=E="!K;VYF:6=U<F%T:6]N
M<V1A=&$@871T('9I<V$@<VMI;&QN861E<B!F]G(N`$EN9V5N('1I;&QGY&YG
M;&EG('-T<F%T96=I(&;V<B!A='0@<VMA<&$@25-/+6EM86=E+@!);G1E(&5N
M(&)A=&-H;6%L;"X`1&5T(&9I;FYS(&EN9V5T(&)L;V-K('#E(&1E;B!B96?D
M<F1A('!O<VET:6]N96X`26YG970@:V%L96YD97)N86UN(&;V<B!-0T%,(&%U
M=&5N=&ES97)I;F<@86YG:79E="X`26YG96X@Y&YD<FEN9RX`26YG82!U;F1E
M<F)E:/9R:6=H971E<B!K86X@;.1G9V%S('1I;&P@9&5N(&CD<B!B96CV<FEG
M:&5T96XN`$EN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG:79E
M;B!F]G(@)7,N`$EN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG
M:79E;B!F]G(@1E10(%9&4RX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA
M=&EO;B!A;F=I=F5N(&;V<B!344P@5D93+@!);F=E;B!K;VYF:6=U<F5R:6YG
M<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R(%-13"UF:6P@5D93+@!);F=E;B!K
M<F5D:70@:W9A<BX`0F5S:W)I=FYI;F<@<V%K;F%S+@!);F=E;B!M;W1T86=A
M<F4@86YG:79E;BX`26YG96X@9FEL('5P<&QA9&1A9`!);F=A(&EK;VYE<B!H
M:71T861E<RX`26YG96X@;W)T(&%N9VEV96XN`$EN9V5N(&]R="!A;F=I=F5N
M+@!);F=E="!M961D96QA;F1E(&)I9F]G861E<RX`26YG970@;F%M;B!A;F=I
M=F5T+@!);F=E;B!N=6UM97(@86YG:79E="X`26YG82!O9O9R<VOD;61A('9I
M<VAE='-O<F0`26YG970@;/9S96YO<F0@9O9R($A45%`M875T96YT:7-E<FEN
M9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@24U!4"UA=71E;G1I<V5R
M:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!+97)B97)O<RUA=71E
M;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!,;V=I;BUA
M=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!005-3
M5T0M875T96YT:7-E<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@
M4TU"+6%U=&5N=&ES97)I;F<@86YG:79E="X`26YG82!VY&YT86YD92!R96=I
M<W1R97)I;F=A<BX`26YG96X@:W9O=&$@86YG:79E;@!);F=E;B!K=F]T82!A
M;F=I=F5N+@!);F=A(')E9VQE<@!);F=E;B!A=F=RY&YS87)E(&%N9VEV96XN
M`$EN9V$@<VED;W(`26YG96X@<^5D86X@9FEL`$EN9V5N('1E;7!O<N1R:V%T
M86QO9R!T:6QL9^1N9VQI9R!F]G(@8V%C:&4N`$EN9V5T(&%N=N1N9&%R;F%M
M;B!O8V@O96QL97(@;/9S96YO<F0@<VMI8VMA="X`26YG970@9VEL=&EG(%A-
M3"UD871A(')E='5R;F5R861E<P!);F=A(';D<F1E;@!);F=E;B!V97)S:6]N
M(&AI='1A9&5S(&D@9&5N('5R<W!R=6YG;&EG82!K;VYF:6=U<F%T:6]N96XN
M(,5T97)S:V%P82!K;VYF:6=U<F%T:6]N96XN`$EN9V5N('9E<G-I;VX@:&ET
M=&%D97,@:2!D:6X@:V]N9FEG=7)A=&EO;BX@Q71E<G-K87!A(&MO;F9I9W5R
M871I;VYE;BX`26-K92UD96QT86=A<F4`26YG96X`26YG96X@*&%N=N1N9"!U
M;F1E<F;V<G-TY61D*0!.;W)F;VQK]F%R;F$`3F]R<F$@:&5M:7-FY')E;@!.
M;W)R82!-87)I86YA]F%R;F$`3F]R9V4`26YT92!E9G1E<@!);G1E(&;V<F4`
M26YT92!E;B!K871A;&]G`$5J(&EM<&QE;65N=&5R860N`$5J(&%N9VEV96X`
M4W3V9',@:6YT92X`06YT96-K;FEN9V%R`$EN9V5N=&EN9R!A='0@=FES82P@
M9^4@=&EL;&)A:V$N`$]"4P!N;W9E;6)E<@!.=6UM97(`06YT86P@=&5C:V5N
M`$%N=&%L(&MO;'5M;F5R`$%N=&%L(')A9&5R`$YU;6UE<B!I;G1E('-P96-I
M9FEC97)A9&4@9O9R(&%T="!U<'!D871E<F$@:2!D:7-T<FEB=71I;VYS;&ES
M=&%N+@!/2P!/8FIE:W0`3V)J96MT<VMA<&%R90!/:W1A;`!O:W1O8F5R`$9I
M;'1E<B!F]G(@;V;V<G-KY&UD:&5T97(`2V]N=&]R`$=A;6UA;'0@;V-H(&YY
M='0@;/9S96YO<F0@9N5R(&EN=&4@=F%R82!S86UM82X`1V%M;6%L="!L]G-E
M;F]R9`!'86UM86QT(&SV<V5N;W)D(.1R(&9E;&%K=&EG=`!/;6%N`$1E;&%D
M92!M87!P87(@<W3V9',@96YB87)T(&%V($E-05`M<V5R=G)A<@!%;F)A<G0@
M;V;V<G-KY&UD82!V:7-H971S;W)D`$5N9&%S="!E;B!E+7!O<W1A9')E<W,@
M=&EL;.5T96XN`$5N9&%S="#D9V%R92!E;&QE<B!S>7-T96UA9&UI;FES=')A
M=/9R(&MA;B#D;F1R82#D9V%R92!E;&QE<B!B96CV<FEG:&5T97(@<.4@96X@
M=71D96QN:6YG`-9P<&YA(&D@;GET="!F]FYS=&5R`$]P96Y34TPM9F5L.B!$
M970@9VEC:R!I;G1E(&%T="!E>'1R86AE<F$@9&%T82!F<N5N('-I9VYE<F%D
M(%,O34E-12UD96PN`-9P<&YA(&SD;FL@:2!N>71T(&;V;G-T97(`3W!E<F%T
M:79S>7-T96T`26-K92!O8FQI9V%T;W)I<VMA(&1E;'1A9V%R90!);G-TY&QL
M;FEN9V%R`$EN<W3D;&QN:6YG87(@9O9R("5S`%-O<G1E<F%D(&QI<W1A`$]R
M9V%N:7-A=&EO;@!/<F=A;FES871I;VYS96YH970`3W)G86YI<V5R80!5<G-P
M<G5N9VQI9R!A<'!L:6MA=&EO;G-M86QL`%5R<W!R=6YG;&EG82!M86QL87(@
M:2`E<SH`06YN86X`06YD<F$@:6YS=.1L;&YI;F=A<@#$9V%R8F5H]G)I9VAE
M=&5R`%!!32U!=71E;G1I<V5R:6YG(.1R(&EN=&4@=&EL;&?D;F=L:6<N`%!%
M05(Z.DUA:6PM:V]P<&QI;F<`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%
M;F-R>7!T960@1&%T80!0=6)L:6L@4$=0+6YY8VME;`!01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A`%!(4"UK;V0`4$A0+7-K86P`3.1T="!F]G)M:61D86=S
M<F5G;@!&]G)M:61D86=S<F5G;@!%9G1E<FUI9&1A9W-S:W5R87(`169T97)M
M:61D86=S<V[V`$5F=&5R;6ED9&%G<W-K=7)A<B!M960@<V[V`$5F=&5R;6ED
M9&%G<W-O;`#%<VMS:W5R87(@<.4@969T97)M:61D86=E;@!03U-)6"UT:6QL
MY&=G('-A:VYA<P!07TA0+7-K86P`571F>6QL;F%D.@!086MI<W1A;@!086QA
M=0!086QE<W1I;F$`4&%N86UA`%!A<'5A+4YY82!'=6EN96$`4&%R86=U87D`
M1&5L=FES(&UO;&YI9W0`3/9S96YO<F0`3/9S96YO<F0@Y&YD<F%D97,N`$SV
M<V5N;W)D(&9E;&%K=&EG=`!,]G-E;F]R9"!K<N1V<R!F]G(@4D%$2553(&%U
M=&5N=&ES97)I;F<N`$SV<V5N;W)D(&UE9"!B96MRY&9T96QS90!,]G-E;F]R
M9#H`3/9S96YO<F0Z(`!,]G-E;F]R9"!MY7-T92!V87)A(&QI:V$N`$ML:7-T
M<F$@:6X`2VQI<W1R82!I;B!F<N5N('5R:VQI<'!S:&%N=&5R87)E;@!3]FMV
MY&<`5N1N=&%N9&4@<F5G:7-T<F5R:6YG87(Z`$WD;FYI<VMO<@!0<F]C96YT
M`%5T9O9R('5N9&5R:.5L;'-F=6YK=&EO;F5R`%5T9O9R('5N9&5R:.5L;'-A
M:W1I=FET971E<B!V:60@:6YL;V=G;FEN9S\`0F5H]G)I9VAE=`!"96CV<FEG
M:&5T("<E<R<@<F%D97)A9&5S(&EN=&4N`,5T:V]M<W0@;F5K860`8F5H]G)I
M9VAE=&5R`$)E:/9R:6=H971S861M:6YI<W1R871I;VX`4&5R<V]N;&EG(&EN
M9F]R;6%T:6]N`%!E<G4`2'5S9&IU<@!&:6QI<'!I;F5R;F$`5&5L969O;@!&
M;W1O;@!0:71C86ER;@!0:7AL87(`2VQI8VCI97(`5F%R(&=O9"!K;&EC:V$@
M:2!E;B!C96QL`$)E:W+D9G1A(&%T="!D=2!V:6QL(')A9&5R82!V86QD('!O
M<W0_`$)E:W+D9G1A(&%T="!D=2!V:6QL(')A9&5R82!A:W1U96QL="!E;&5M
M96YT+@!687(@9V]D(&%N9V4@;>5N860@;V-H(.5R+@!687(@9V]D(&%N9V4@
M;F%M;B!F]G(@:V%T96=O<FEN.@!687(@9V]D(&%N9V4@9V]D:^1N9"!)4"UA
M9')E<W,N`%9A<B!G;V0@86YG92!E='0@9VEL=&EG="!D871U;3L@:V]N=')O
M;&QE<F$@86YT86QE="!D86=A<B!I(&WE;F%D96XN`%9A<B!G;V0@86YG92!E
M;B!G;V1KY&YD('1I9"X`5F%R(&=O9"!S=6UM97)A(&1I='0@<')O8FQE;2X`
M06YG92!D:71T(&%N=N1N9&%R;F%M;B!O8V@@;/9S96YO<F0N`%9A<B!G;V0@
M;.1S(&EG96YO;2!F]FQJ86YD92!T97AT+B!$=2!-Q5-412!S86UT>6-K82!M
M960@=FEL;&MO<F5N(&;V<B!A='0@86YVY&YD82!S>7-T96UE="X`5F%R(&=O
M9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E>'0N($1U($W%4U1%('-A;71Y8VMA
M(&UE9"!V:6QL:V]R96X@9O9R(&%T="!A;G;D;F1A('-Y<W1E;65T+@!+;VYT
M<F]L;&5R82!F]FQJ86YD92!I;F9O<FUA=&EO;B!O8V@@=N1L:B!S961A;B!E
M;B!H86YD;&EN9R!I(&UE;GEN"FYE9&%N+@!6Y&QJ(&5N(&AA;F1L:6YG(&9R
MY6X@;65N>6X@;F5D86XN`$%N9V4@;GET="!K871E9V]R:6YA;6XZ`%!O;&5N
M`%!O;&ET:6L`56YD97)S]FMN:6YG87(`4&]R='5G86P`4&]S:71I;VYE<FEN
M9R!A=B!B:6QD96X`4&]S:71I;VYE<FEN9R!A=B!T86)E;&QE;@!3:W)I=B!T
M:6QL(&1E;B!HY'(@;6%P<&5N("AE:B!T=FEN9V%T(&%V($E-05`I`%!O<W1N
M=6ME`$YE9&5R8O9R9"!D92!S96YA<W1E("5S('1I;6UA<FYA.B``0VAA;G,@
M=&EL;#QB<B\^;F5D97)B]G)D`$%U=&A?;&1A<#H@3$1!4"UT:6QLY&=G('-A
M:VYA<RX`4')E9G-?<V5S<VEO;CH@3V)L:6=A=&]R:7-K="!S97-S:6]N<W1I
M;&SD9V<@:&ET=&%D97,@:6YT92X`5')Y8VL`3'5F='1R>6-K('9I9"!H879E
M=#H@`$QU9G1T<GEC:SH@`$;V<FAA;F1S=FES;FEN9P!&]G)H86YD<V=R86YS
M:V$@8FEL9"!I(&YY='0@9O9N<W1E<@!&]G)E9^5E;F1E(&EN<W3D;&QN:6YG
M87(`4VMR:78@=70@9&]K=6UE;G0`4')I=F%T82!N>6-K96P`4')O8FQE;0!0
M<F]B;&5M8F5S:W)I=FYI;F<`4')O:F5K=`!497AT`%!U8FQI:R!N>6-K96P`
M4'5B;&EK(&YY8VME;&%L9V]R:71M`%!U8FQI:R!N>6-K96QI;F9O<FUA=&EO
M;@!&96P@=FED(&=E;F5R97)I;F<@878@<'5B;&EK="]P<FEV870@;GEC:V5L
M<&%R+@!0=65R=&\@4FEC;P!296YS82!M961D96QA;F1E;@!1871A<@!&<N5G
M80!+=F]T80!0=6)L:6L@4E-!+6YY8VME;"`H)60@8FET87(I`$5N<VMI;'0@
M=F%L`%)E9VX`5&ED:6=T(')E9VX`4V5N="!R96=N`%)E9VYS:W5R87(`4F5G
M;B!O8V@@<V[V`%)E9VX@=&EL;"!S;O8`4VQU;7!MY'-S:6=T('9I<VAE='-O
M<F0`1O9R:.5L;&%N9&4`3.1S`$SD<R!M961D96QA;F1E;@!3Y&ME<G0@871T
M(&1U('9I;&P@<F%D97)A("5S/R!2861E<FEN9V5N(&MA;B!I;G1E(.5N9W)A
M<RX`4^1K97)T(&%T="!D=2!V:6QL(')A9&5R82!A;G;D;F1A<F1A=&$@9O9R
M("5S/R!2861E<FEN9V5N(&MA;B!I;G1E(.5N9W)A<RX`1_9R(&]M(&1I;B!S
M96YA<W1E(&EN;6%T;FEN9P!5<'!D871E<F$`57!P9&%T97)A(&1Y;F%M:7-K
M82!M96YY96QE;65N=#H`57!P9&%T97)A('!O<G1A;'9Y.@!296=E>`!6:7-A
M(&;V<FCE;&QA;F1E;@!,861D82!O;0!+;VUM96YT87)E<@!+;VT@:6CE9R!I
M;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;BX`1FKD<G)S97)V<F%R`%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%1A(&)O<G0`5&$@
M8F]R="!B;&]C:P!482!B;W)T(&MO;'5M;@!482!B;W)T(&9O<FUA=&5R:6YG
M`%1A(&)O<G0@9G+E;B!M:6X@:V%L96YD97(`5&$@8F]R="!P87(`4F%D97)A
M('-P87)A="!S:W)I<'0@9G+E;B!S97)V97)N<R!T96UP;W+D<FMA=&%L;V<N
M`%1A(&)O<G0`4F%D97)A(&1E;FYA(&YO9"!F<N5N(&1O:W5M96YT970`5&$@
M8F]R="!A;G;D;F1A<F4`5&$@8F]R="!A;G;D;F1A<F4Z("5S`%-V87(@<VMI
M8VMA="X`4W9A<F$@871T(&)E9^1R86X@:6YT92!S=/9D<P!3=F%R82!M960@
M:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96X@9O9R(&MO;6UA;F1E('1V
MY2!MY6YA9&5R+@!3=F%R82!M960@9&5N(&)E9^1R9&$@;&5D:6<O=7!P=&%G
M96XM:6YF;W)M871I;VYE;BX`4W9A<CH@)7,`0F5GY')A;B!K=6YD92!I;G1E
M(&)E<W9A<F%S+B!2971U<FYE<F%D(&9E;&MO9#H@`$1E;B!E9G1E<F9RY6=A
M9&4@=&KD;G-T96X@:W5N9&4@:6YT92!H:71T87,N`$5R9F]D<F%D("<E<R<@
MY'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)A=&EO;F5N(&%V("5S+@!%<F9O
M9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R97)I;F=E;B!A
M=B!61E,N`$5R9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG
M=7)E<FEN9V5N+@!/8FQI9V%T;W)I<VMT="!FY&QT`$]B;&EG871O<FES:R!D
M96QT86=A<F4`Q71E<G-TY&QL`,5T97)S=.1L;"!L]G-E;F]R9`#%=&5R<W3D
M;&P@;/9S96YO<F0`Q7-T97)TY&QL('-E;F%S=&4@9G+E9V%N`%)E<W5L=&%T
M`,5T97)VY&YD('1I;&P@:6YS=.1L;&YI;F=A<@!!;F=E(&YY='0@;/9S96YO
M<F0`4NEU;FEO;@#%=&5R<W3D;&P@:V]N9FEG=7)A=&EO;@!);G-TY&QL;FEN
M9V%R(&;V<B!2:6-H(%1E>'0@161I=&]R`$?E=&]R`$CV9V5R`$CV9V5R<G5B
M<FEK`$CV9V5R=N1R9&5N`%)A7V1I;G-TY&QL;FEN9V%R+BXN`%)O;&P`4G5M
MY&YI96X`4F]T97)A(#$X,`!2;W1E<F$@=N1N<W1E<@!2;W1E<F$@:/9G97(`
M4F%D:6YS=.1L;&YI;F=A<@!2861I;G-TY&QL;FEN9V%R`%)A9&5R.@!,:6YJ
M97(`3&EN:F5R('9I<V%S(&UE;&QA;B!A;&QA(')A9&5R(&]C:"!K;VQU;6YE
M<@!,:6YJ97(@=FES87,@96YB87)T(&UE;&QA;B!K;VQU;6YE<@!,:6YJ97(@
M=FES87,@96YB87)T(&UE;&QA;B!R861E<@!+]G(`4GES<VQA;F0`4G=A;F1A
M`%,O34E-12!S:6=N871U<@!3+TU)344M:W)Y<'1E<F%T(&UE9&1E;&%N9&4`
M4T%33"UA=71E;G1I<V5R:6YG(.1R(&EN=&4@=&EL;&?D;F=L:6<N`%--4R!M
M961D96QA;F1E;@!344PM<VMA;`!344PM<V5K=F5N<R!F]G(@=7!P<VQA9R!A
M=B!VY')D96X`4U-(`$Q90TM!5`!37U%,+7-K86P`3/8`4V%I;G0@2&5L96YA
M`%-A:6YT($MI='1S(&]C:"!.979I<P!386EN="!,=6-I80!386EN="U0:65R
M<F4@;V-H($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@;V-H($=R96YA9&EN97)N
M80!386UM82!R86T@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&]C:"!0<FEN8VEP90!3871T96QI=&QE=F5R86YT]G(`4V%U9&EA<F%B:65N
M`%-P87)A`%-P87)A("<E<R<`4W!A<F$@)7,`4W!A<F$@:6YS=.1L;&YI;F=A
M<@!3<&%R82!G96YE<F5R860@:V]N9FEG=7)A=&EO;B!S;VT@4$A0+7-K<FEP
M="!T:6QL(&1I;B!S97)V97)S("!T96UP+6MA=&%L;V<N`%-P87)A9&4@:V]N
M9FEG=7)A=&EO;B!F]G(@)7,N`%-P87)A9&4@=7!P9W)A9&5R:6YG<W-C<FEP
M="!T:6QL.B`E<RX`4W!R:61D82#E<VMS:W5R87(`5F5T96YS:V%P`%/V:P!3
M]FMM;W1O<F5R`%;D;&H@9FEL97(`5N1L:B!E='0@9&%T=6T`5N1L:B!G<G5P
M<"!A='0@;.1G9V$@=&EL;`!6Y&QJ(&YY(.1G87)E`%;D;&H@<V5R=F5R`%;D
M;&H@86YVY&YD87)E(&%T="!LY&=G82!T:6QL`%;D;&H@86QL80!6Y&QJ(&1A
M='5M:V]M<&]N96YT97(N`%;D;&H@971T(&]B:F5K=`!6Y&QJ(&EN9V5N`$%N
M9V4@9&4@=&5C:V5N(&1U(&)E:/9V97(@:2!R=71O<FYA(&YE9&%N+B!$=2!K
M86X@<V5D86X@:V]P:65R82!O8V@@:VQI<W1R82!I;B!D96T@:2!T97AT87)U
M=&%N+@!6Y&QJ(&%V9W+D;G-A<F4@9O9R(&1A='5M.@!6Y&QJ(&1A='5M9F]R
M;6%T.@!6Y&QJ(&ED96YT:71E="!D=2!V:6QL(.1N9')A.@!6Y&QJ(&%V9W+D
M;G-A<F4@9O9R('1I9#H`5N1L:B!T:61S9F]R;6%T.@!6Y&QJ('1VY2!M871C
M:&%N9&4@9N1L=#H`5N1L:B!D:71T(&;D<F=S8VAE;6$N`$%N9V4@9&ET="!F
M]G)V86QD82!S<'+E:SH`4VMI8VMA('-E;F%S=&4@:6YF;W)M871I;VYE;@!3
M:VEC:V$@<')O8FQE;7)A<'!O<G0`4VMI8VMA(%--4P!396YE9V%L`%-E;G-O
M<CH@`'-E<'1E;6)E<@!397)B:65N(&]C:"!-;VYT96YE9W)O`%-E<FEE;G5M
M;65R`%-E<G9E<FEN<W3D;&QN:6YG87(@9F5L86MT:6=A(&5L;&5R(&EN86MT
M:78@<V5R=F5R+@!397-S:6]N<V%D;6EN:7-T<F%T:6]N`%-E<W-I;VYS+4E$
M(&AA<B!GY71T('5T+@!397-S:6]N97(`4^1T=`!+;VYF:6=U<F5R82!A;'1E
M<FYA=&EV('-O;2!M]FIL:6=G]G(@Y71E<G-TY&QL;FEN9R!A=B!B;W)T9VSV
M;70@;/9S96YO<F0N`$MO;F9I9W5R97)A(&9JY')R<V5R=G)A<B!S;VT@9'4@
M=FEL;"!K;VUM82#E="!F<N5N(&1I;B!P;W)T86PN`$%N9V4@9&ET="!F]G)V
M86QD82!S<'+E:RP@=&ED<WIO;B!C;V@@9&%T=6UI;G-TY&QL;FEN9V%R+@!3
MY'1T(&1I='0@:6YI=&EA;&$@87!P;&EK871I;VXL(&;D<F=S8VAE;6$L('-I
M9'5P<&1A=&5R:6YG(&]C:"!A;F1R82!V:7-N:6YG<VEN<W3D;&QN:6YG87(N
M`%-E='5P`$MO;F9I9W5R871I;VYS=7!P9W)A9&5R:6YG<W-K<FEP="!F:6YN
M<R!T:6QL9^1N9VQI9V$`1&5T(&9I;FYS(&9L97)A(&]R=&5R(&UE9"!P87)A
M;65T97)N.@!397EC:&5L;&5R;F$`2&%N9&5L`$MO<G0@<W5M;65R:6YG`%-K
M86QL(&=E;G;D9W-T86YG96YT97(@9&5F:6YE<F%S(&;V<B!D92!F;&5S=&$@
M;.1N:V%R/P!6:7-A`%9I<V$@<VMI;&QN861E<B!M96QL86X@9&5N(&%K='5E
M;&QA(&]C:"!D96X@;GEL:6=E;B!S:V%P861E(&MO;F9I9W5R871I;VYE;BX`
M5FES82!S96YA<W1E(&EN;&]G9VYI;F=S=&ED('9I9"!I;FQO9V=N:6YG/P!6
M:7-A(&EN<W3D;&QN:6YG(&;V<B!A='0@8F5HY6QL82!O<FEG:6YA;`!6:7-A
M('!A;&5T=`!6:7-A("=T86)E;&QA:W1I=FET971E<B<@:2!M96YY;C\`5FES
M82!M96YY(&;V<B`E<R!T:6QL(';D;G-T97(_`%1A8F5L;&-E;&QI;G-TY&QL
M;FEN9V%R`%1A8F5L;&EN<W3D;&QN:6YG87(`5&%B96QL:6YS=.1L;&YI;F=A
M<@!6:7-A(&1I86QO9W)U=&$@9O9R(&)I;&1E9V5N<VMA<&5R`%9I<V$@=7!P
M;&%D9&YI;F<`4VMU<F%R`%1I9&EG82!S:W5R87(`4V5N82!S:W5R87(`4VMU
M<F%R(&D@;N1R:&5T96X`1O9R;6EN<VMA`$MR>6UP(&5L;&5R(&9L>71T82!B
M;W)T(&[D<FQI9V=A;F1E(&)L;V-K(&;V<G-T`%-I97)R82!,96]N90!296=I
M<W1R97)A`%-I9VYA='5R`%-I9VYA='5R86QG;W)I=&T`4VEM<&QE>`!3:6YG
M87!O<F4`4W1O<FQE:P!!=F)R>70@=6YD97)HY6QL`%-L;W9A:VEE;@!3;&]V
M96YI96X`4V[V`%-N]G-K=7(`4V[V<VMU<F%R`%1I9&EG82!S;O9S:W5R87(`
M4V5N82!S;O9S:W5R87(`4V[V9&IU<#H@`$UO='-V87)A;F1E('-N]B!I('9A
M='1E;CH@`%-A;&]M;V[V87)N80!3;VUA;&EA`%/E;F=E<B!O8V@@9&EK=&5R
M`%-O<G1E<FEN9W-I;W)D;FEN9W-V86P`:^1L;&%D<F5S<P!3>61A9G)I:V$`
M4_9D<F$@1V5O<F=I82!O8V@@4WES<V%N9'=I8VCV87)N80!3Y&1R82!H96UI
M<V;D<F5N`%5T<GEM;64@;65L;&%N(&EN=&EL;&EG9V%N9&4@8V5L;&5R`%5T
M<GEM;64@;65L;&%N(&EN;F5HY6QL(&]C:"!K86YT96X@:2!C96QL96X`365L
M;&%N<G5M`$UE;&QA;G)U;0!-96QL86YR=6T@;V-H('5T:N1M;FEN9P!3<&%N
M:65N`%-P86T`26YM871N:6YG(&%V('-P96-I96QL82!T96-K96X`1&5L82!C
M96QL`$1E;&$@:V]L=6UN`$1E;&$@<F%D`%-P;W)T97(`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!3=&%R=`!3=&%R=.5R`%-T870@96QL97(@<F5G
M:6]N`%-T871U<P!,86=R:6YG<V9O<FUA=`!'871U861R97-S`$=E;F]M<W1R
M=6ME;@!3='+D;F=L:7-T80!482!B;W)T(&1O;>1N(&9RY6X@861R97-S96X`
M4W1I;"!;0U-370!3]@!+86X@:6YT92!H:71T82!U;F1E<FMA=&%L;V<@)R5S
M)RX`Q')E;F1E`%-K:6-K80!$:6X@8F5GY')A;B!A='0@;.1G9V$@=&EL;"`B
M)7,B('1I;&P@<WES=&5M970@:&%R('-K:6-K871S+B!$=2!K86X@:6YT92!L
M;V=G82!I;B!I;FYA;B!D:6X@8F5GY')A;B!H87(@86-C97!T97)A=',N`$YE
M9'/D;FMT`$QY8VMA=``G)7,G(&QA9&5S('1I;&P@:2!S>7-T96UE="X`4F%D
M97)A9&4@:6YF;W)M871I;VX@;VT@86YVY&YD87)E("<E<R<N`"<E<R<@<F%D
M97)A9&5S+@`G)7,G('1O9W,@8F]R="!F<N5N('-Y<W1E;65T+@!+;VYF:6=U
M<F%T:6]N96X@:&%R(.5T97)S=.1L;'1S+B!,861D82!O;2!S:61A;B!F]G(@
M871T('-E(&;V<N1N9')I;F=A<BX`4W!A<F%D92!B86-K=7!K;VYF:6=U<F%T
M:6]N+@!3<&%R861E(&)A8VMU<&MO;F9I9W5R871I;VX@)7,N`"<E<R<@=7!P
M9&%T97)A9&5S+@!3:W)E=B`E<P!3=61A;@!386UM86YS=.1L;&YI;F<`4V]L
M=7!P9^5N9P!3;VQN961GY6YG`%-O;&EG=`!3;VQU<'!GY6YG`%-O;'5P<&?E
M;F<O;F5D9^5N9P!3;VQU<'!GY6YG.B``4V]L;F5D9^5N9P!3;VQN961GY6YG
M.B``57!P:/9J9`!3=7!P;W)T`%-U<FEN86UE`$5F=&5R;F%M;@!3=F%L8F%R
M9"!O8V@@2F%N($UA>65N`%-W87II;&%N9`!3=F5R:6=E`%-C:'=E:7H`4WEK
M<F]N:7-E<FEN9W-L;V=G(')A9&5R860`4WEN8TU,`%-Y;G1A>&9E;"!I('/V
M:VMR:71E<FEA`%-Y<FEE;@#%<VMS:W5R`,5S:W-K=7)A<B!O8V@@8FSE<VEG
M=`#%<VMS:W5R87(`5&ED:6=A(.5S:W-K=7)A<@!44U8M9FEL`%1A8F5L;`!4
M86)E;&QI;G-TY&QL;FEN9V%R`%1A8F5L;'5P<'/D='1N:6YG`%1A8F5L;&EN
M<W3D;&QN:6YG87(`5&%I=V%N`%1A:7=A;@!486II:VES=&%N`%1A;GIA;FEA
M`$WE;#H`57!P9VEF=&5R`%1E86P`5&5L969O;FYU;6UE<@!(]F=S=&$@=&5M
M<&5R871U<B!S96YA<W1E('1I;6UE;CH@`%1E;7!E<F%T=7(`5&5M<&5R871U
M<CH@`%1E;7!E<F%T=7(\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S
M`$MA;B!I;G1E(&AI='1A(&UA;&P@)7,N`$%N=N1N9&%R861M:6YI<W1R871I
M;VX`1V]D:^1N;B!B96?D<F%N('!R96QI;6ENY')T`%!R96QI;6ENY')T(&%C
M8V5P=&5R870`5&5X=`!%;F)A<G0@=&5X=`!497AT:G5S=&5R:6YG`%1E>'1T
M;W``5&\`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&%C:R!F]G(@871T(&1U
M(&%N=N1N9&5R('-Y<W1E;65T+@!,Y&YK96X@)7,@=&EL;"`E<R!H87(@<F%D
M97)A=',N`$944"UT:6QLY&=G970@Y'(@:6YT92!T:6QL9^1N9VQI9W0N`$AI
M<W1O<FEK<WES=&5M970@Y'(@879A:W1I=F5R870N`$AO<F1E+TMO;&%B+6EN
M=&5G<F%T:6]N<V=RY&YS<VYI='1E="!S=/9D97(@:6YT92`B)7,B`$E-4U`M
M;&]G9V5N(&MU;F1E(&EN=&4@:6YI=&EE<F%S+@!+;&%S<V5N($UA:6YT96YA
M;F-E.CH@:W5N9&4@:6YT92!L861D87,`26YS=.1L;&YI;F=S9O9N<W1R970@
M:&%R('-TY&YG=',N($%V<VQU=&%R+@!!9&UI;FES=')A=/9R96X@;>5S=&4@
M:V]N9FEG=7)E<F$@96X@<&5R;6%N96YT($)E:/9R:6=H971S+6MO<'!L:6YG
M(&]M(&1U('9I;&P@86YVY&YD82!"96CV<FEG:&5T97(N`$5N8F%R="!N961R
M92!S:61A;@!+86QE;F1E<FEN9F]R;6%T:6]N96X@Y'(@9F5L86MT:6<`2V]N
M=&%K=&5N<R!)1"!A;F=A=G,@:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI='1A
M<R!I(&1A=&%B87-E;BX`2V]N=&%K=&5N(&QA9&5S('1I;&P@:2!A9')E<W-B
M;VME;BX`1&5N(&SV<V=J;W)D82!01U`M<VEG;F%T=7)E;B!K<N1V<R!F]G(@
M871T('9E<FEF:65R82!D970@<VEG;F5R861E(&UE9&1E;&%N9&5T+@!$:7-T
M<FEB=71I;VYS;&ES=&%N<R!)1"!A;F=A=G,@:6YT92!E;&QE<B!K=6YD92!I
M;G1E(&AI='1A<R!I(&1A=&%B87-E;BX`1&ES=')I8G5T:6]N<VQI<W1A;B!H
M87(@:6YT92!A;F=I=FET<RX`2W)Y<'1E<FEN9W-F=6YK=&EO;F5R;F$@:W+D
M=F5R(&5N('/D:V5R('=E8F;V<F)I;F1E;'-E("A(5%104RDN`$CD;F1E;'-E
M;B!L861E<R!T:6QL(&D@:V%L96YD97)N+@!&:6QE;B`E<R!S:V%L;"!I;FYE
M:.5L;&$@96X@:6YS=.1L;&YI;F<@9O9R("5S+@!&:6QE;B`E<R!S:V%L;"!I
M;FYE:.5L;&$@:6YS=.1L;&YI;F=A<B!F]G(@)7,N`$9I;&5N(&MA;B!I;G1E
M(&MO<&EE<F%S('1I;&P@<VEG('-JY&QV+@!&:6QE;B!K86X@:6YT92!K;W!I
M97)A<R!T:6QL('-I9R!S:N1L=BX`1FEL96X@:6YN96CV;&P@:6YG96X@:6YF
M;W)M871I;VXN`$AU=G5D9N1L="!F]G(@9&5T=&$@;65D9&5L86YD92]R9F,X
M,C)M961D96QA;F1E(&;V;&IE<@!)9&5N=&ET971E;B`G)7,G(')A9&5R861E
M<RX`0F%R82!VY&YS=&5R('-I9&$`3.1N:V5N(&AA<B!T86=I=',@8F]R=`!3
M]FMVY&=E;B!T:6QL($=N=5!'+7!R;V=R86UM970@;>5S=&4@=F%R82!A;F=I
M=F5N('1I;&P@:VQA<W-E;B!#<GEP=%]P9W`Z.BX`365D9&5L86YD970@<VMI
M8VMA="`E<R!T:6QL("5S(&UE9"#D<F5N9&4@(B5S(B!H87(@=FES871S+@I$
M971T82#D<B!I;F=E;B!G87)A;G1I(&;V<B!A='0@;65D9&5L86YD970@:&%R
M(&SD<W1S+@!.86UN970@<V]M('-K86QL(&%N=N1N9&%S(&;V<B!A='0@;.1N
M:V$@=&EL;"!S:V%P82US:61A;@!!;G1A;"!FY&QT(&WE<W1E('9A<F$@971T
M(&YU;65R:7-K="!VY')D92X`36]D=6QE;B!O<&5N<W-L(&MRY'9S(&%V(&ML
M87-S96X@2&]R9&5?0W)Y<'1?<VUI;64Z.BX`26YS=.1L;&YI;F=E;B`B)7,B
M(&MU;F1E(&EN=&4@<W!A<F%S('#E(&=R=6YD(&%V(&%T="!D871A;>1N9V1E
M;B#V=F5R<VMR:79E<B!D96X@;6%X:6UA;'0@=&EL;.5T;F$`4')O9W)A;6UE
M="!S;VT@86YVY&YD<R!F]G(@871T('9I<V$@9&5N(&CD<B!M961D96QA;F1E
M='EP96X@*"5S*2!S86MN87,@<.4@<WES=&5M970N`%1E8VMN970@9O9R(&-I
M=&5R:6YG(&WE<W1E('9A<F$@971T('1E8VME;BX`0F%R82!H]F=E<B!O8V@@
M=N1N<W1E<B!S:61O<@!"87)A(&CV9V5R('-I9&$`4V5P87)A=&]R;B!MY7-T
M92!V87)A(&5T="!T96-K96XN`%-E<G9E<B`G)7,G(')A9&5R861E<RX`4V5R
M=F5R("<E<R<@<W!A<F%D97,N`%!R96YU;65R871I;VYS8F5GY')A;B!F]G(@
M)7,@:&%R('1A9VET<R!B;W)T+@!!;F=I=F5N(')A9"`H)60I(&9I;FYS(&EN
M=&4N`$%N9VEV96X@<F%D(&5X:7-T97)A<B!I;G1E+@!5<'!G:69T96X@:&%R
M(&QA9W1S('1I;&P@:2!D:6X@=7!P9VEF='-L:7-T82X`5&5M<&]RY'(@9FEL
M("<E<R<@9FEN;G,@:6YT92X`5&5X=&5N(&1U(&UA=&%T(&EN('-TY&UM97(@
M:6YT92#V=F5R96YS(&UE9"!T97AT96X@<.4@<VOD<FUE;@!"87)A('1O<'`@
M;V-H(&)O='1E;B!S:61A`$)A<F$@=&]P<'-I9&$`57!P;&%D9&%T(&1A=&$@
M9O9R<W9A;FX@<V5D86X@9O9R96?E96YD92!S=&5G+@!$96X@=7!P;&%D9&%D
M92!F:6QE;B!K=6YD92!I;G1E('-P87)A<RX`3&5D:6<O=7!P=&%G96XM:6YF
M;W)M871I;VX@9O9R(&%N=N1N9&%R96X@:&%R('-P87)A=',N`%=E871H97(N
M8V]M+6)L;V-K970@Y'(@:6YT92!T:6QL9^1N9VQI9W0N`%1E;6%K871A;&]G
M("<E<R<@9FEN;G,@:6YT92X`26YG82!I;G-TY&QL;FEN9V%R('1I;&QGY&YG
M;&EG82X`1&5T(&9I;FYS(&EN9V$@86QT97)N871I=F$@9&5L87(@<V]M(&MA
M;B!V:7-A<R!I;FQI;F4N`$;V<B!MY6YG82!T96-K96X@:2!FY&QT970N($1U
M(&AA<B!A;F=E='0@)7,@=&5C:V5N.R!M87AI;6%L="!A;G1A;"!T96-K96X@
MY'(@)7,N`%!R;V)L96T@;65D(&%T="!LY&=G82!T:6QL("<E<R<@=&EL;"!S
M>7-T96UE=#H@)7,`4')O8FQE;2!M960@871T(')E;G-A(&EN9F]R;6%T:6]N
M(&]M(&%N=N1N9&%R92`G)7,G(&9RY6X@<WES=&5M970Z(`!0<F]B;&5M(&UE
M9"!A='0@=&$@8F]R="`G)7,G(&9RY6X@<WES=&5M970Z(`!0<F]B;&5M('9I
M9"!U<'!D871E<FEN9R!A=B`G)7,G.B`E<P!0<F]B;&5M('9I9"!U<'!L861D
M;FEN9R!A=B!F:6QE;BX@26YG82`E<R!L861D861E<R!U<'`N`$1E="!U<'!S
M=&]D('!R;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N.B`E<R#D<B!S
M=/9R<F4@Y&X@;6%X:6UA;'0@=&EL;.5T96X@<W1O<FQE:R`H)60@8GET97,I
M+@!$970@=7!P<W1O9"!P<F]B;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE
M;CH@)7,@;&%D9&%D97,@96YB87)T('5P<"!D96QV:7,N`$1E="!U<'!S=&]D
M(&5T="!F96P@=FED('9I<VYI;F<@878@;65D9&5L86YD961E;&5N+@!&96P@
M=FED(&EM<&]R="!A=B!K;VYT86MT9&%T82X`1F5L('9I9"!I;7!O<G0@878@
M:.1N9&5L<V5N.B`E<RX`1F5L('9I9"!I;7!O<G0@878@:4-A;&5N9&%R(&1A
M=&$N`$9E;"!V:60@:6UP;W)T(&%V('5P<&=I9G1E;CH@)7,N`$9E;"!V:60@
M:6UP;W)T(&%V(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N.B`E<RX`
M171T(&9E;"!PY71RY&9F861E<R!I(&9O<FUU;.1R970N($MO;G1R;VQL97)A
M(&%T="!D=2!I;G1E(&=L]FUT(&9Y;&QA(&D@971T(&]B;&EG871O<FES:W0@
M9N1L="X`1&5T(&=I8VL@:6YT92!A='0@=71F]G)A(&1E;B!B96?D<F1A(&%D
M<F5S<V)O:W-F=6YK=&EO;F5N+B!687(@9V]D(&;V<G/V:R!S96YA<F4N`$9E
M;"!V:60@=7!P9&%T97)I;F<@878@:V]N=&%K='5P<&=I9G1E<BX@1O9R<_9K
M(&EG96X@<V5N87)E+@!&96P@=FED('5P<&1A=&5R:6YG(&%V(&1I<W1R:6)U
M=&EO;G-L:7-T86XN($;V<G/V:R!I9V5N('-E;F%R92X`1&EN($E-05`M<V5R
M=F5R('-T]F1E<B!I;G1E(&1E;&%D92!M87!P87(N`$1E;FYA(&AA;F1L:6YG
M('-T]F1S(&EN=&4N`$1E;FYA(&9U;FMT:6]N(.1R(&EN=&4@:6UP;&5M96YT
M97)A9"#D;BX`1FEL96X@=F5R:V%R(&EN=&4@=F%R82!E='0@9VEL=&EG="!2
M05(M87)K:78N`$9I;&5N('9E<FMA<B!I;G1E('9A<F$@971T(&=I;'1I9W0@
M6DE0+6%R:VEV+@!&96QA:W1I9W0@:V]R=&YU;6UE<BX`1&5N;F$@9')I=G)U
M=&EN(&?V<B!D970@;?9J;&EG="!A='0@<VMI8VMA(&UE9&1E;&%N9&5N('9I
M82!#;&EC:V%T96QL+6)R>6=G86X@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V5N;VT@871T(&%N=N1N9&$@2%144"!!4$DZ="X`1&5N;F$@9')I=G)U=&EN
M(&?V<B!D970@;?9J;&EG="!A='0@<VMI8VMA(&UE9&1E;&%N9&5N('9I82!7
M24XM8G)Y9V=A;B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=E;F]M(&%T="!A;G;D
M;F1A($A45%`@05!).G0`1&5N;F$@9')I=G)U=&EN(&?V<B!D970@;?9J;&EG
M="!A='0@<VMI8VMA(&UE9&1E;&%N9&5N('9I82!S;7,R96UA:6PM8G)Y9V=A
M;B`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=E;F]M(&%T="!A;G;D;F1A($A4
M5%`@05!).G0`1&5N;F$@9')I=G)U=&EN(&?V<B!D970@;?9J;&EG="!A='0@
M<VMI8VMA(&UE9&1E;&%N9&5N('9I82!33510(&=E;F]M(%9O9&%F;VYE($ET
M86QI96XM8G)Y9V=A;B`H96YB87)T('1I;&P@5F]D869O;FYU;6UE<BDN($1R
M:79R=71I;F5N(&MRY'9E<B!E='0@92UP;W-T:V]N=&\@:&]S(%9O9&%F;VYE
M($ET86QI96X@*&AT='`Z+R]W=W<N,3DP+FET*2X`1N1L=&5T(&WE<W1E('9A
M<F$@:69Y;&QT+@!&Y&QT970@9N5R(&5N8F%R="!I;FYE:.5L;&$@:&5L=&%L
M+@!&Y&QT970@9N5R(&5N8F%R="!I;FYE:.5L;&$@<VEF9G)O<B!O8V@@:V]L
M;VXN`$;D;'1E="!FY7(@96YB87)T(&EN;F5HY6QL82!O:W1A;&$@=&%L+@!&
MY&QT970@<VMA;&P@=F%R82!E;B!K;VUM82T@96QL97(@;65L;&%N<VQA9W-S
M97!A<F%R860@;&ES=&$@;65D(&AE;'1A;`!&Y&QT970@;>5S=&4@=F%R82!E
M='0@9V]D:^1N="!T86PN`$1E='1A(&;D;'0@;>5S=&4@:6YN96CE;&QA(&5N
M(%)'0BUFY')G:V]D(&D@:&5X861E8VEM86QT(&9O<FUA="P@="!E>"`G(S$R
M,S1A9B<N`$1E='1A(&9O<FUU;.1R(&AA<B!R961A;B!B96%R8F5T871S+@!$
M970@:.1R(.1R("5S+@!-961D96QA;F1E="!S:W)E=G,@:2!E;B!A;FYA;B!T
M96-K96YU<'!SY'1T;FEN9R`H)7,I(.1N(&1I;B!E9V5N+@!$970@:.1R(&YU
M;7)E="!MY7-T92!V87)A(&UI;G-T(&5T="X`4V5R=F5R;B!K86X@:6YT92!P
M86-K82!U<'`@>FEP(&]C:"!G>FEP(&9I;&5R+@!3>7-T96UE="#D<B!F]G(@
M=&EL;&;D;&QE="!A=F%K=&EV97)A="X`1&5T(&CD<B!VY')D970@;>5S=&4@
M=F%R82!N=6UE<FES:W0N`$1E='1A(&;V;G-T97(@;>5S=&4@86YR;W!A<R!F
M<N5N(&5T="!K;VYF:6=U<F%T:6]N<V;V;G-T97(`Q7-K80#$<F5N9&5N`%1I
M9`!4:61S<F5D;W9I<VYI;F<`5&ED<V9O<FUA=`!4:61S=F%L`-9S='1I;6]R
M`%)U8G)I:P!2=6)R:6L@*'1O;VQT:7`I.@!4:6QL`$;V<B!A='0@;6%R:V5R
M82!F;&5R82!V86PL(&CE;&P@;F5D($-T<FP@*%!#*2!E;&QE<B!#;VUM86YD
M("A-86,I('1A;F=E;G1E;B!NY'(@9'4@:VQI8VMA<BX`261A9P!6:7-A($A4
M34PM:^1L;&$`5&]G;P!4;VME;&%U`$EM;W)G;VX`5&]N9V$`5&]P`%1O<"!F
M<F%M92`H7W1O<"D`UG9E<G/D='1N:6YG87(`5')I;FED860@;V-H(%1O8F%G
M;P!386YT(&5L;&5R(&9A;'-K=`!4:0!4=6YI<VEE;@!4=7)K:65T`%1U<FMI
M<VL@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<RT@;V-H($-A:6-O
M<_9A<FYA`%1U=F%L=0!!;F=E(&1I='0@=F%L.B``558M:6YD97@Z(`!54DP`
M55),(&;V<B!D:71T(&QE=F5R86YS<F%P<&]R=&5R:6YG<W-K<FEP=`!54DPZ
M`%5G86YD80!5:W)A:6YA`$MA;B!I;G1E(&SD<V$@5D93+6UA<'`N`$1E="!G
M:6-K(&EN=&4@871T(&SD9V=A('1I;&P@=73V:V%D(&%N=N1N9&%R:6YF;W)M
M871I;VX@=FED(')E9VES=&5R:6YG+@!+86X@:6YT92#D;F1R82!B96CV<FEG
M:&5T(&;V<B!61E,M9FEL("5S+@!+86X@:6YT92#D;F1R82!B96CV<FEG:&5T
M(&;V<B!61E,M9FEL("5S+R5S+@!+86X@:6YT92#D;F1R82!T:6QL("5S+@!+
M86X@:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R;&5K("5S+R5S`$MA;B!I;G1E
M(&MO;G1R;VQL97)A(&9I;'-T;W)L96L@<.4@)7,N`$MA;B!I;G1E(&MO;G1R
M;VQL97)A(&9I;'-T;W)L96L@<.4@)7,O)7,N`$MA;B!I;G1E(&MO;G1A:W1A
M(%-13"US97)V97(N`$MA;B!I;G1E(&MO;G1A:W1A('9I82!34TPN`$MA;B!I
M;G1E(&MO<&EE<F$@5D93+69I;"X`2V%N(&EN=&4@<VMA<&$@5D93+6UA<'`@
M)7,N`$MA;B!I;G1E('-K87!A(%9&4RUM87!P+@!+86X@:6YT92!S:V%P82!6
M1E,M9FEL+@!+86X@:6YT92!S:V%P82!61E,M;6%P<"`G)7,G+@!+86X@:6YT
M92!S:V%P82!T;VT@5D93+69I;"X`2V%N(&EN=&4@<&%C:V$@=7!P(&1A=&$N
M`$MA;B!I;G1E(')A9&5R82`E<RP@;6%P<&5N(.1R(&EN=&4@=&]M+@!+86X@
M:6YT92!R861E<F$@)R5S)SH@)7,`2V%N(&EN=&4@<F%D97)A("5S+"!M87!P
M96X@Y'(@:6YT92!T;VTN`$MA;B!I;G1E(')A9&5R82!61E,M;6%P<"!R96MU
M<G-I=G0N`$MA;B!I;G1E(')A9&5R82!61E,M;6%P<"X`2V%N(&EN=&4@<F%D
M97)A(%9&4RUM87!P.B`E<RX`2V%N(&EN=&4@<F%D97)A(%9&4RUF:6P@)7,N
M`$MA;B!I;G1E(')A9&5R82!61E,M9FEL+@!+86X@:6YT92!R861E<F$@5D93
M+6UA<'`@)R5S)RX`2V%N(&EN=&4@<F%D97)A(%9&4R!R96MU<G-I=G0Z("5S
M+@!+86X@:6YT92!A=F?V<F$@86MT=65L;"!M87!P+@!+86X@:6YT92!E>'1R
M86AE<F$@0V5R=&EF:6MA='-D971A;&IE<@!+86X@:6YT92!L861D82!D969I
M;FET:6]N96X@878@)7,N`$MA;B!I;G1E(&9L>71T82!61E,M9FEL+@!+86X@
M:6YT92#V<'!N82!61E,M9FEL("5S+@!+86X@:6YT92#V<'!N82!61E,M9FEL
M(&;V<B!S:W)I=FYI;F<N`$MA;B!I;G1E(/9P<&YA(%9&4RUF:6PN`$MA;B!I
M;G1E(/9P<&YA(&MO;7!R:6UE<F%T(&%R:VEV+@!+86X@:6YT92!LY'-A(%9&
M4RUF:6P@*&9I;&5S:7IE*"D@;6ES<VQY8VMA9&5S*2X`2V%N(&EN=&4@;.1S
M82!61E,M9FEL("AG971&:6QE4VEZ92@I(&UI<W-L>6-K861E<RDN`$MA;B!I
M;G1E(&SD<V$@9FEL.B``2V%N(&EN=&4@;.1S82!K871A;&]G96X@9O9R("=V
M9G-R;V]T)RX`2V%N(&EN=&4@8GET82!N86UN('#E("5S('1I;&P@)7,Z(&1E
M<W1I;F%T:6]N<VUA<'`@9FEN;G,@<F5D86X`2V%N(&EN=&4@8GET82!N86UN
M('#E(%9&4RUM87!P+@!+86X@:6YT92!B>71A(&YA;6X@<.4@5D93+6UA<'`Z
M("5S+@!+86X@:6YT92!B>71A(&YA;6X@<.4@5D93+69I;"`E<RX`2V%N(&EN
M=&4@8GET82!N86UN('#E(%9&4RUF:6P@)7,O)7,N`$MA;B!I;G1E(&)Y=&$@
M;F%M;B!PY2!61E,M9FEL+@!+86X@:6YT92!K]G)A("=M:VES;V9S)RX`2V%N
M(&EN=&4@]G9E<G/D='1A(%=O<F1D;VMU;65N=&5T`$MA;B!I;G1E('-K<FEV
M82!T:6QL(%9&4RUF:6P@)7,N`$MA;B!I;G1E('-K<FEV82!T:6QL(%9&4RUF
M:6P@*&-O<'DH*2!M:7-S;'EC:V%D97,I+@!+86X@:6YT92!S:W)I=F$@9&%T
M82!T:6QL(%9&4RUF:6PN`$MA;B!I;G1E('-K<FEV82!T:6QL(%9&4RUF:6PL
M(&MV;W1A('-K=6QL92#V=F5R<VMR:61A<RX`56YD97)S=')U:V5N`,5N9W)A
M(.1N9')I;F=A<@#%;F=R87(@9&EN('-E;F%S=&4@Y71GY')D`$]VY&YT870@
M<W9A<B!F<N5N('-E<G9E<B!PY2!F]G)B:6YD96QS93H@`$]VY&YT870@<W9A
M<B!F<N5N('-E<G9E<B!T:6QL.B``16H@:V%T96=O<FES97)A9`!)8VME(&AA
M;G1E<F%D(&MO;7!O;F5N="!A=B!T>7`Z("5S`%5N:6-O9&4@*%541BTX*0!&
M]G)E;F%D92!!<F%B96UI<F%T96X`4W1O<F)R:71A;FYI96X`1O9R96YT82!3
M=&%T97)N80!!;65R:6MA;G-K82!3=&EL;&%H879S]F%R;F$`16YH971E<@!/
M:^1N9`!/:^1N="!G<N1N<W-N:71T<VUE9&1E;&%N9&5I9"`H87!I;7-G:60I
M+@!/:^1N="!K;&EE;G1M961D96QA;F1E:60@*&-L:6US9VED*2X`3VOD;F0@
M;W)T('-P96-I9FEC97)A9"X`3VOD;G0@86YVY&YD87)N86UN(&5L;&5R(&SV
M<V5N;W)D+@!482!B;W)T(&SD;FME;B!F<N5N(&YU=G)A;F1E(&5L96UE;G0`
M3F%M;FSV<P!)8VME+7!R:79I;&EG97)A9&4@<VMR:7!T(&MA;B!I;G1E(&MO
M;6UA(.5T($ML:7!P('5T+TMO<&EE<F$O2VQI<W1R82UF=6YK=&EO;F5R;F$@
M878@<^1K97)H971S<VOD;"X@2VQI8VMA($]+(&;V<B!A='0@<V4@96X@=&5K
M;FES:R!B97-K<FEV;FEN9R!F<N5N(&UO>FEL;&$N;W)G(&]M(&AU<B!D=2!K
M86X@=&EL;.5T82!A='0@<VMR:7!T(&MO;6UE<B#E="!U<FML:7!P+@!482!B
M;W)T(&;D<F<`5&EL;.1G9V5T('-T]F1S(&EN=&4`57!P9&%T97)A`%5P<&1A
M=&5R82`E<P!5<'!D871E<F$@<W1A='5S('#E('-V87)A;F1E`%5P<&1A=&5R
M82!A;G;D;F1A<F4`57!P9&%T97)A9&4@)R5S)RX`57!P9&%T97)I;F=S<V-R
M:7!T(')A9&5R870N`$QA9&1A('5P<`!,861D861E('5P<"!A;&QA(&MO;F9I
M9W5R871I;VYS9FEL97(@=&EL;"!S97)V97)N+@!697)S86QE<@!2;VUE<G-K
M82!S:69F<F]R`%5R=6=U87D`06YVY&YD(&%K='5E;&PZ("5S`$%N=N1N9"!3
M4TP`06YVY&YD(&]M(&YA;6XO;/9S96YO<F0@Y'(@86YN;W)L=6YD82!F]G(@
M24U34"US97)V97(N`$%N=N1N9&%R90!!;G;D;F1A<F4@)7,@Y'(@:6YT92!B
M96CV<FEG(&;V<B`E<RX`06YVY&YD87)A9&UI;FES=')A=&EO;@!!;G;D;F1A
M<FEN<W3D;&QN:6YG87(`06YVY&YD87)R96=I<W1R97)I;F<`06YVY&YD87)R
M96=I<W1R97)I;F<@:&%R(&%V86MT:79E<F%T<RX`06YVY&YD87)K;VYT;W0@
M:&ET=&%D97,@:6YT90!!;G;D;F1A<FYA;6X`06YVY&YD87)N86UN("5S(&9I
M;FYS(')E9&%N+@!!;G;D;F1A<FYA;6XZ`$%N=N1N9&%R;F%M;CH@`$%N=N1N
M9&%R92!I('-Y<W1E;65T.@!5>F)E:VES=&%N`%9&4RUM87!P(&5X:7-T97)A
M<B!I;G1E+@!396UE<W1E<@!':6QT:6=A('!L871S97(@<V]M(&AI='1A9&5S
M(&EN:VQU9&5R87(Z(`!':6QT:6=H970`36EN=71E<B!F<N5N(&YU`%;D<F1E
M="#V=F5R<W1I9V5R(&1E="!H]F=S=&$@=&EL;.5T;F$@*"5S*0!6Y')D96X`
M5N1R9&5N(&%T="!VY&QJ82!F<N5N`%9A;G5T874`5F%R:6%B96P`5F5N97IU
M96QA`%9E<FEF:65R:6YG(&UI<W-L>6-K861E<R`M(&UE9&1E;&%N9&5T(&MA
M;B!H82!M86YI<'5L97)A=',N`%9E<G-I;VX`5F5R<VEO;FAA;G1E<FEN9P!6
M97)T:6MA;"!J=7-T97)I;F<`5F5R=&EK86P@=71F>6QL;F%D`%9E<G1I:V%L
M.@!6Y&QD:6=T(&CV9P!6:65T;F%M`%9I971N86UE<VES:R`H5DE30TE)*0!6
M:7-A("5S`%9I<V$@96X@97AT97)N('=E8F)S:61A`%9I<V$@<V]M("5S`%9I
M<V$@:.1N9&5L<V4`5FES82!U<'!G:69T`$IU;F=F<G7V87)N82P@0G)I='1I
M<VMA`$IU;F=F<G7V87)N82P@06UE<FEK86YS:V$`4VEK=`!3:6MT.@!6;V1A
M9F]N92!)=&%L:65N('9I82!33510`%9!4DX`5D%23DE.1R$A(2!2041%4D$@
M4TM225!4150@34%.545,3%0@1E+%3B`E<RX`5TE.('9I82!(5%10`%=A;&QI
M<R!O8V@@1G5T=6YA`%9A<FYI;F<`3VX`5N1D97)P<F]G;F]S`%;D9&5R9&%T
M82!F<N5N`'=E871H97(N8V]M`%=E8F(`5V5B8G!L871S`%=E8F)P;&%T<V5N
M("T@4V]B97(`5V5B8G!L871S96X@+2!3;V)E<B!.60!696-K;W9I<P!6Y&QK
M;VUM96X`5N1L:V]M;65N('1I;&P@)7,`5N1L:V]M;65N+"`E<P!6Y'-T97)L
MY&YD<VL@*$E33RTX.#4Y+3$I`%;D<W1E<FSD;F1S:R`H25-/+3@X-3DM,34I
M`%;D<W1R82!386AA<F$`5FEL:V5N(&%P<&QI:V%T:6]N('-K86QL("5S('9I
M<V$@969T97(@:6YL;V=G;FEN9S\`5FEL:V5N(.1R(&%V9W+D;G-N:6YG<W1E
M8VMN970_`%9I;&ME="#D<B!T96-K;F5T(&;V<B!C:71E<F%D('1E>'0_`%=H
M97)E:7,@075S=')A;&EE;FMA<G1A`%9I;&MA(&9A<V5R`%9I;&MA('!L=6=I
M;B!S:V%L;"!A:W1I=F5R87,@9O9R(%)I8V@@5&5X="!E9&ET;W)N+@!"<F5D
M9`!"<F5D9"!I($-34RUU;FET<P!"<F5D9"!PY2!M96YY;B!F]G(@)R5S)R!T
M:6QL(';D;G-T97(@*&?D;&QE<B!F<N5N(&[D<W1A(&EN;&]G9VYI;F<`5&%B
M96QL8G)E9&0`0G)E9&1E;FAE=`!"<F5D9#H`5VEK:0!6:6YD`%1I9&EG('9I
M;F0`5FEN9&AA<W1I9VAE="!I(&MN;W``5FEN9#H`5FEN9#H@`%9I<V1O;0#6
M;G-K96QI<W1A`$%R8F5T90!!9')E<W,L(&%R8F5T90!496QE9F]N+"!A<F)E
M=&4`1F5L(&%N=&%L(&;D;'0@<.4@<F%D("5D+B!&]G)VY&YT861E("5D+"!H
M:71T861E("5D+@!&96P@86YT86P@9N1L="X@1O9R=N1N=&%D92`E9"P@:&ET
M=&%D92`E9"X`1F5L('!O<VET:6]N("5D('9I9"!LY'-N:6YG(&%V(%9&4RUF
M:6PN`%@M4F5F`%@U,#E6,R!5=/9K860@;GEC:V5L86YVY&YD;FEN9P!8-3`Y
M5C,M=&EL;.1G9P!960!965E9`%EA:&]O(2!M87``Q7)L:6<`665M96X`2F$`
M2F$L(&IA9R!S86UT>6-K97(`1'4@:&%R(&%K=&EV97)A="!T97AT;.1G92X@
M06YVY&YD(%L\/ET@9O9R(&%T="#E=&5R9^4@=&EL;"!765-)5UE'+@!$=2!H
M87(@:6YT92!B96CV<FEG:&5T('-K87!A(&9L97(@Y&X@)60@8FQO8VLN`$1U
M(.1R(&EN=&4@875T96YT:7-E<F%D+@!$=2!K86X@:6YT92!A;G;D;F1A("=<
M)R!I(&1I='0@;F%M;@!$=2!K86X@:6YT92!A;G;D;F1A("=<)R!I(&1I='0@
M;F%M;@!$=2!A;F=A=B!I;G1E(&5N(&=O9&OD;F0@92UP;W-T861R97-S+@!$
M=2#D<B!U=&QO9V=A9"X`1'4@;>5S=&4@86YG92!E='0@9VEL=&EG="!M;V)I
M;&YU;6UE<CL@96YB87)T('-I9F9R;W(@;V-H(&5T="`G*R<@9O9R92!I;G1E
M<FYA=&EO;F5L;'0@<')E9FEX+@!$=2!A;F=A=B!I;G1E(&5T="!G;V1KY&YT
M(';D<F1E+@!$=2!MY7-T92!K;VYF:6=U<F5R82!E;B!$871A5'+D9',M:V]P
M<&QI;F<@9O9R(&%T="!A;G;D;F1A(')E9VES=')E<FEN9P!$=2!MY7-T92!K
M;VYF:6=U<F5R82!E;B!61E,M:V]P<&QI;F<`1'4@;>5S=&4@8F5S:W)I=F$@
M<')O8FQE;65N+"!I;FYA;B!D=2!K86X@<F%P<&]R=&5R82!E='0@<')O8FQE
M;2X`1'4@;>5S=&4@86YG92!E;B!54DP@<V]M(&SD;FME;B!P96MA<B!PY0!$
M=2!MY7-T92!A;F=E(&5N('-E<G9E<B!S;VT@<VMA;&P@<F%D97)A<RX`1'4@
M;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L;"!R96YS87,N
M`$1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@<F%D
M97)A<RX`1'4@;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L
M;"!LY&=G87,@=&EL;"X`1'4@;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN
M('-O;2!S:V%L;"!U<'!D871E<F%S+@!$=2!MY7-T92!A;F=E(&5N(.5T9^1R
M9"!S;VT@<VMA;&P@=71F]G)A<RX`1'4@;>5S=&4@86YG92!E='0@;GET="!K
M871E9V]R:6YA;6XN`$1U(&WE<W1E(&%N9V4@971T(&ET86QI96YS:W0@=&5L
M969O;FYU;6UE<@!$:6X@)7,@<V5S<VEO;B!H87(@=7!P:/9R="X@5F%R(&=O
M9"!L;V=G82!I;B!I9V5N+@!$:6X@92UP;W-T861R97-S`$1I;B!&<N5N.B!A
M9')E<W,Z`$1I;B!I;F9O<FUA=&EO;@!$:6X@:6YT97)N971A9')E<W,@:&%R
M(.1N9')A=',@969T97(@871T(&1U(&QO9V=A="!I;B!T:6QL("<E<R<N($;V
M<B!A='0@<VMY9&1A(&1I9RP@;>5S=&4@9'4@;&]G9V$@:6X@:6=E;BX`1&ET
M="!N86UN`$1I;B!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E<B!I;G1E
M('5P<&SD9V<@878@86YVY&YD87)E+B!/;2!D=2!V:6QL(&%N=N1N9&$@2&]R
M9&4@9O9R(&%T="!A9&UI;FES=')E<F$@86YVY&YD87)E('/E(&WE<W1E(&1U
M(&%N=N1N9&$@96X@86YN86X@875T96YT:7-E<FEN9W-K;W!P;&EN9RX`1&ET
M="!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E<B!I;G1E(&QI<W1N:6YG
M(&%V(&%N=N1N9&%R92P@96QL97(@<^4@Y'(@9G5N:W1I;VYE;B!A=G-TY&YG
M9"X`1&EN('=E8F)LY'-A<F4O:6YT97)N971A9')E<W,@:&%R(.1N9')A=',@
M969T97(@871T(&1U(&QO9V=A="!I;B!T:6QL("<E<R<N($;V<B!A='0@<VMY
M9&1A(&1I9RP@;>5S=&4@9'4@;&]G9V$@:6X@:6=E;BX`1&EN('=E8F)LY'-A
M<F4@<W3V9&5R(&EN=&4@9&5N(&CD<B!F=6YK=&EO;F5N+@!$:6X@=V5B8FSD
M<V%R92!S=/9D97(@:6YT92!U='-K<FEF='-F=6YK=&EO;F5N+B!4<GEC:R!#
M=')L+T]P=&EO;B`K(%`@9O9R(&%T="!S:W)I=F$@=70N`$1I;B!A:W1U96QL
M82!T:61S>F]N.@!$:6X@9O9R=F%L9&$@:61E;G1I=&5T(&AA<B#D;F1R871S
M+@!$:6X@9O9R=F%L9&$@:61E;G1I=&5T.@!$:71T(&9U;&QS=.1N9&EG82!N
M86UN.@!$:6X@:6YL;V=G;FEN9R!H87(@9^5T="!U="X`1&ET="!N>6$@;/9S
M96YO<F0@9O9R("5S(.1R.B`E<P!$:6YA(&EN<W3D;&QN:6YG87(@:&%R('5P
M<&1A=&5R871S(&;V<B!D96X@:.1R('-E<W-I;VYE;BX`1&EN82!I;G-TY&QL
M;FEN9V%R(&AA<B!U<'!D871E<F%T<RX`1&ET="!L]G-E;F]R9"!H87(@8FQI
M=FET(.5T97)S=.1L;'0`1&ET="!L]G-N;W)D(&AA<B#E=&5R<W3D;&QT<RP@
M:V]N=')O;&QE<F$@9&EN(&4M<&]S="!O8V@@;&]G9V$@:6X@;65D(&1I='0@
M;GEA(&SV<V5N;W)D+@!$:71T(&SV<V5N;W)D(&AA<B!GY71T('5T+@!$:6YA
M(&9JY')R<V5R=G)A<CH`2G5G;W-L879I96X`6F%I<F4`6F%M8FEA`%II;6)A
M8G=E`%II<'!Y`%M']FT@8VET97)A9"!T97AT70!;1F5L<F%P<&]R=%T`6U9I
M<V$@8VET97)A9"!T97AT("T`6U9I<V$@8VET97)A9"!T97AT("T@)7,@<F%D
M97)=`%MR860@)7,@878@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A
M5'+D9`!?4F%D97)A(')A9`!?1W)U<'!E<@!?2&KD;'``7T)I;&1I;G-TY&QL
M;FEN9V%R+BXN`%],;V=G82!I;@!?3&]G9V$@=70`Q%]N9')A(&SD;FLN+BX`
M7TEN<W3D;&QN:6YG87(`7T)E:/9R:6=H971E<@!?5&$@8F]R="!LY&YK+BXN
M`%]3971U<`!?5&%B96QL:6YS=.1L;&YI;F=A<BXN+@!?06YVY&YD87)E`&%D
M<F5S<V)O:P!O:^1N9"!M;W1T86=A<F4`:V%L96YD97(`;'5G;G0`:V%N(&EN
M=&4@<VMA<&$@=71F:6P`:V%N(&EN=&4@]G!P;F$@:6YD871A`&ML:6-K82!H
MY'(`:VQO8VMA`&MO;6UA;F1O<F%D<V9E;`!K;VYF:6=U<F%T:6]N<V9E;`!K
M<FET:7-K('-Y<W1E;69I;"!S86MN87,`9&%T869O<FUA=&9E;`#D;F1R80!P
M;W-T96X@:W5N9&4@:6YT92!H:71T87,`9F%L;&%N9&4`9FEL`&9RY6X@9&5N
M("5S("@E<RD@:VP@)7,@)7,`<W1O<FUB>6%R`&@Z`&AH`&]KY&YD(';D<F1D
M871O<@!G96YA<W0`:6YL:6YE`&)E87)B971N:6YG<V9E;`!);G1E<FYT(&%P
M<&QI:V%T:6]N<V9E;`!R861E<ET`9F5L:V]D("5D(&9RY6X@;6MI<V]F<P!M
M;0!N86UN`&EN=&4@:6UP;&5M96YT97)A9`!I;G1E(&EM<&QE;65N=&5R860`
M86YT96-K;FEN9W-B;&]C:P!P<F]C96YT`.5T:V]M<W0@;F5K860`<&EX;&%R
M`'!R;W1O:V]L;&9E;`!S=&EG86YD90!4:N1N<W1E;B#D<B!E:B!T:6QL9^1N
M9VQI9P!V:7-A('-K:6QL;F%D97(`<VUS,F5M86EL('9I82!(5%10`'-S`'-T
M861I9W0`<WES=&5M9F5L`'5P<&=I9G1S;&ES=&$`=&EL;&;D;&QI9W0@9F5L
M`&%N9V4@;/9S96YO<F1E="!T=N4@9^5N9V5R(&;V<B!A='0@8F5K<N1F=&$`
M96YA9`!N86UN;/9S`&%N=N1N9&%R=F%L`'9#87)D`'<Z`'=E871H97(N8V]M
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]S=E]312]H96QP+GAM;```````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`T,3<S-C(W-S<`,#(P,S4U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_>&UL('9E
M<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+W-V7U-%
M+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,3(@:F%N($5X<"`D
M("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B
M/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H
M:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L
M;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@
M:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO
M=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO
M=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D
M;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN
M("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC
M:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O
M;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A
M;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@
M(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI
M>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y
M;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@
M<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@
M87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V
M8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I
M9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD
M('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I
M9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I
M9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T
M=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E
M('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)
M9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T
M:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O=')?5%(O````````````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`Q`#`Q-C<P,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]T<E]44B],0U]-15-304=%4R\`````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#$`
M,#(P-#8U`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W1R7U12+TQ#
M7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,S
M-C$P,``Q,#0Q-S,V,S`P,0`P,C(Q,C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````WA($E0````":!@``'````.PT``#;"```
MO&D````````HC0``#@```"F-```/````.(T```T```!(C0``"````%:-```+
M````7XT```P```!KC0``!````'B-```,````?8T```\```"*C0``"P```)J-
M```.````IHT```4```"UC0``*````+N-```(````Y(T```H```#MC0``%0``
M`/B-```2````#HX```L````AC@``#@```"V.```*````/(X```T```!'C@``
M#@```%6.```1````9(X```T```!VC@``#````(2.```-````D8X```8```"?
MC@``#P```*:.```8````MHX```P```#/C@``#@```-R.```.````ZXX```@`
M``#ZC@``+@````./```:````,H\``#(```!-CP``.````("/``!4````N8\`
M`%$````.D```6@```&"0``!7````NY```#0````3D0``!P```$B1```*````
M4)$```\```!;D0``!0```&N1```&````<9$``!$```!XD0``"````(J1```)
M````DY$```D```"=D0``)0```*>1```@````S9$``!````#ND0``#P```/^1
M```*````#Y(```,````:D@``#P```!Z2```4````+I(```D```!#D@``#0``
M`$V2```2````6Y(```\```!ND@``"@```'Z2```/````B9(```@```"9D@``
M)````**2```4````QY(``!8```#<D@``"````/.2```9````_)(```<````6
MDP``#````!Z3```L````*Y,```X```!8DP```P```&>3```+````:Y,```<`
M``!WDP``!P```'^3```%````AY,```4```"-DP``"@```).3```#````GI,`
M`!<```"BDP``"@```+J3```/````Q9,```X```#5DP``&````.23```C````
M_9,```X````AE```%````#"4```7````190``!<```!=E```%P```'64```3
M````C90```\```"AE```#@```+&4```?````P)0```<```#@E```!@```.B4
M```(````[Y0```\```#XE```!@````B5```*````#Y4``!,````:E0``"P``
M`"Z5```0````.I4``!4```!+E0``%0```&&5```'````=Y4``!````!_E0``
M!0```)"5```5````EI4``!$```"LE0``#````+Z5```[````RY4```D````'
ME@``!P```!&6```4````&98```,````NE@``!0```#*6```0````.)8```D`
M``!)E@``$P```%.6```Y````9Y8``!(```"AE@``)P```+26```L````W)8`
M`"H````)EP``)0```#27```*````6I<```8```!EEP``"0```&R7```'````
M=I<``"\```!^EP``-P```*Z7```N````YI<``%4````5F```+0```&N8```M
M````F9@``"T```#'F```0````/68```C````-ID``",```!:F0``+0```'Z9
M```S````K)D``!4```#@F0``&0```/:9```I````$)H``"0````ZF@``$0``
M`%^:```*````<9H```P```!\F@``"@```(F:```0````E)H``!8```"EF@``
M%@```+R:```'````TYH```<```#;F@``%````..:```*````^)H```@````#
MFP``"`````R;```'````%9L```<````=FP``!@```"6;```%````+)L```<`
M```RFP``!@```#J;```(````09L``"D```!*FP``#@```'2;```*````@YL`
M``0```".FP``!P```).;```)````FYL```8```"EFP``$0```*R;```'````
MOIL``!8```#&FP``!````-V;```(````XIL```8```#KFP``#0```/*;```&
M`````)P``!X````'G```$0```":<```(````.)P```T```!!G```#````$^<
M```'````7)P```,```!DG````P```&B<```7````;)P``!,```"$G```"```
M`)B<```$````H9P```@```"FG```"````*^<``!!````N)P``"````#ZG```
M!@```!N=```&````(IT``!4````IG0``&````#^=```B````6)T``"X```![
MG0``'0```*J=```A````R)T``%0```#JG0``*0```#^>```*````:9X```<`
M``!TG@``%0```'R>```.````DIX```H```"AG@``#P```*R>```-````O)X`
M``\```#*G@``#0```-J>```)````Z)X``!0```#RG@``!@````>?```8````
M#I\``!T````GGP``$P```$6?```4````69\```0```!NGP``!@```'.?``!4
M````>I\```0```#/GP``#@```-2?```%````XY\```4```#IGP``&P```.^?
M```:````"Z```!$````FH```$0```#B@```<````2J```"H```!GH```$```
M`)*@```A````HZ````4```#%H```$P```,N@```2````WZ````H```#RH```
M#P```/V@```1````#:$``!,````?H0``#````#.A```&````0*$```8```!'
MH0``%P```$ZA```0````9J$``!$```!WH0``"````(FA```%````DJ$```P`
M``"8H0``$````*6A```%````MJ$```T```"\H0``!@```,JA```'````T:$`
M``T```#9H0``!P```.>A```+````[Z$```<```#[H0``!P````.B```)````
M"Z(```H````5H@``&0```""B```,````.J(``!````!'H@``!0```%BB```E
M````7J(``!(```"$H@``$P```)>B```K````JZ(``#L```#7H@``(````!.C
M```V````-*,```@```!KHP``#````'2C```&````@:,```0```"(HP``#@``
M`(VC```*````G*,```T```"GHP``'@```+6C```;````U*,``"$```#PHP``
M'@```!*D```9````,:0``!X```!+I```&P```&JD```F````AJ0``!L```"M
MI```'@```,FD```<````Z*0``"8````%I0``,P```"RE```F````8*4``"L`
M``"'I0``.````+.E```O````[*4``!(````<I@``*0```"^F```2````6:8`
M`*(```!LI@``%@````^G```C````)J<``"@```!*IP``*0```'.G```H````
MG:<``!\```#&IP``(````.:G```E````!Z@``"@````MJ```,````%:H``"2
M````AZ@``"$````:J0``'````#RI```F````6:D``$$```"`J0``#````,*I
M```'````SZD```<```#7J0``!@```-^I```-````YJD``!````#TJ0``$@``
M``6J```3````&*H``!(````LJ@``!P```#^J```$````1ZH```P```!,J@``
M#@```%FJ```/````:*H``!,```!XJ@``#0```(RJ```H````FJH```,```##
MJ@``#0```,>J```&````U:H``!$```#<J@``%P```.ZJ```;````!JL```X`
M```BJP```@```#&K```%````-*L``!`````ZJP``!````$NK```-````4*L`
M``X```!>JP```P```&VK```.````<:L```@```"`JP``#P```(FK```/````
MF:L```<```"IJP``#0```+&K```0````OZL```L```#0JP``!@```-RK```,
M````XZL``!$```#PJP``&0````*L```+````'*P```T````HK```(@```#:L
M```*````6:P``!@```!DK```&0```'VL```6````EZP```T```"NK```!P``
M`+RL```4````Q*P```L```#9K```(@```.6L```O````"*T```L````XK0``
M"0```$2M```9````3JT```L```!HK0``%P```'2M```7````C*T```D```"D
MK0``%@```*ZM```/````Q:T``!8```#5K0``#@```.RM```8````^ZT```@`
M```4K@``#0```!VN```F````*ZX``$,```!2K@``"````):N```2````GZX`
M``@```"RK@``"P```+NN```O````QZX```X```#WK@``!0````:O```&````
M#*\```,````3KP``!P```!>O```$````'Z\```H````DKP``"@```"^O```/
M````.J\``!````!*KP``%P```%NO```1````<Z\``!<```"%KP``"0```)VO
M```%````IZ\```L```"MKP``"@```+FO```"````Q*\```4```#'KP``#0``
M`,VO```;````VZ\``!<```#WKP``"0````^P```.````&;````T````HL```
M$@```#:P```X````2;```"````""L```"````*.P```.````K+```'L```"[
ML```&````#>Q```1````4+$```<```!BL0``!0```&JQ```9````<+$```<`
M``"*L0``"````)*Q```&````F[$```8```"BL0``$````*FQ```/````NK$`
M`!````#*L0``#P```-NQ```+````Z[$```\```#WL0``#`````>R```/````
M%+(```<````DL@``!@```"RR```.````,[(```P```!"L@``*````$^R```/
M````>+(```@```"(L@``"````)&R```3````FK(``!X```"NL@``(0```,VR
M```@````[[(``!D````0LP``%P```"JS```E````0K,``!<```!HLP``!```
M`("S```;````A;,```T```"ALP``#````*^S```#````O+,```@```#`LP``
M"@```,FS```,````U+,```L```#ALP``$````.VS```,````_K,```0````+
MM```$P```!"T```4````)+0```P````YM```"0```$:T```.````4+0```L`
M``!?M```&P```&NT```'````A[0```<```"/M```"@```)>T```-````HK0`
M``D```"PM```!````+JT```%````O[0```,```#%M```&````,FT```*````
MXK0```0```#MM```)@```/*T```.````&;4``'P````HM0``%0```*6U```%
M````N[4```<```#!M0``#````,FU```(````UK4```H```#?M0``!@```.JU
M```(````\;4```(```#ZM0``!@```/VU```&````!+8``!0````+M@``#0``
M`""V```0````+K8``!L````_M@``!````%NV```)````8+8``!````!JM@``
M"0```'NV```)````A;8```4```"/M@``&@```)6V```(````L+8```8```"Y
MM@``&0```,"V```.````VK8```<```#IM@``!P```/&V```%````^;8```D`
M``#_M@``"@````FW```"````%+<```8````7MP``#0```!ZW```)````++<`
M``8````VMP``$@```#VW```)````4+<```<```!:MP``%````&*W```=````
M=[<```8```"5MP``"@```)RW```$````I[<```D```"LMP``"````+:W```1
M````O[<```D```#1MP``!@```-NW```-````XK<```8```#PMP``!````/>W
M```Y````_+<``#T````VN```.@```'2X```>````K[@```4```#.N```#@``
M`-2X```$````X[@```8```#HN```(0```.^X```5````$;D```8````GN0``
M!````"ZY```1````,[D```8```!%N0``"@```$RY```B````5[D```0```!Z
MN0``!0```'^Y```=````A;D```0```"CN0``#````*BY```*````M;D```@`
M``#`N0``"0```,FY```%````T[D``#H```#9N0``,````!2Z```U````1;H`
M`"D```![N@``1P```*6Z```X````[;H``"D````FNP``/P```%"[```N````
MD+L``"T```"_NP``'P```.V[```/````#;P``!(````=O```"P```#"\```F
M````/+P``"D```!CO```)````(V\```F````LKP```@```#9O```"@```.*\
M```)````[;P```<```#WO```(````/^\```@````(+T``"8```!!O0``"@``
M`&B]```9````<[T``"D```"-O0``%@```+>]```2````SKT```<```#AO0``
M"@```.F]```,````]+T```\````!O@``$````!&^``!`````(KX``'````!C
MO@``9@```-2^```.````.[\```D```!*OP``"@```%2_```2````7[\``!,`
M``!ROP``#````(:_```&````D[\```\```":OP``$@```*J_```0````O;\`
M`!$```#.OP``'````."_```C````_;\``&H````AP```#P```(S````%````
MG,```!````"BP```"0```+/````$````O<````L```#"P```%````,[````,
M````X\````P```#PP```#P```/W````5````#<$``"D````CP0``*@```$W!
M```F````>,$``"<```"?P0``*0```,?!```J````\<$``!D````<P@``0@``
M`#;"```1````><(``!(```"+P@``$P```)["```4````LL(```\```#'P@``
M%@```-?"```7````[L(``!`````&PP``$0```!?#```T````*<,``!,```!>
MPP``$@```'+#```U````A<,``!0```"[PP``!P```-##```,````V,,``"``
M``#EPP``%`````;$```1````&\0``!<````MQ```'````$7$```3````8L0`
M`!$```!VQ```&@```(C$```>````H\0``!H```#"Q```$0```-W$```4````
M[\0``!<````$Q0``%0```!S%```)````,L4``!D````\Q0``!````%;%```'
M````6\4```L```!CQ0``$0```&_%```&````@<4```8```"(Q0``!@```(_%
M```%````EL4```<```"<Q0``!P```*3%```%````K,4``!8```"RQ0``!@``
M`,G%```&````T,4```0```#7Q0``!````-S%```'````X<4```X```#IQ0``
M#````/C%```,````!<8```T````2Q@``"@```"#&```.````*\8```4````Z
MQ@``*````$#&```.````:<8```P```!XQ@``#P```(7&```*````E<8```@`
M``"@Q@``"0```*G&```K````L\8```0```#?Q@``"````.3&```F````[<8`
M`!(````4QP``#P```"?'```&````-\<```H````^QP``!P```$G'```(````
M4<<``"````!:QP``"0```'O'```,````A<<```T```"2QP``#@```*#'```6
M````K\<``!$```#&QP``!@```-C'```#````W\<```8```#CQP``&0```.K'
M```'````!,@```0````,R```"P```!'(```+````'<@```<````IR```!P``
M`#'(```6````.<@```T```!0R```#0```%[(```*````;,@``!````!WR```
M#P```(C(```1````F,@``!<```"JR```"@```,+(```1````S<@```@```#?
MR```!````.C(```/````[<@``#H```#]R```!0```#C)```,````/LD``!X`
M``!+R0``#@```&K)```0````><D```L```"*R0``#````);)```)````H\D`
M``<```"MR0``"@```+7)```)````P,D```X```#*R0``$````-G)```:````
MZLD```H````%R@``"0```!#*```*````&LH```P````ER@``#P```#+*```(
M````0LH```8```!+R@``!P```%+*```+````6LH``$<```!FR@``#0```*[*
M```)````O,H```0```#&R@```P```,O*```3````S\H``!,```#CR@``$P``
M`/?*```*````"\L```(````6RP``!````!G+```E````'LL```,```!$RP``
M!0```$C+```J````3LL```H```!YRP``!0```(3+```$````BLL```H```"/
MRP``#0```)K+```&````J,L```@```"ORP``"````+C+```$````P<L```4`
M``#&RP``:````,S+```)````-<P```P````_S```!0```$S,```&````4LP`
M`!L```!9S```+P```'7,```0````I<P```H```"VS```#P```,',```*````
MT<P```D```#<S```$P```.;,```;````^LP``!@````6S0``%P```"_-```.
M````1\T```,```!6S0``!P```%K-```(````8LT```<```!KS0``"@```'/-
M```+````?LT```<```"*S0``40```)+-```0````Y,T```P```#US0``#0``
M``+.```:````$,X``$H````KS@``!@```';.```&````?<X```8```"$S@``
M'P```(O.```&````J\X```D```"RS@``&````+S.```7````U<X```8```#M
MS@``#0```/3.```B`````L\``%<````ESP``$P```'W/```C````D<\``!,`
M``"USP```@```,G/```+````S,\```@```#8SP``#0```.'/```*````[\\`
M``<```#ZSP``%`````+0```&````%]````@````>T```#@```"?0```'````
M-M````H````^T```"P```$G0```'````5=````P```!=T```#0```&K0```,
M````>-````D```"%T```"0```(_0```*````F=````<```"DT```"0```*S0
M```'````MM````H```"^T```&P```,G0```2````Y=````H```#XT```"0``
M``/1```0````#=$```<````>T0``$@```";1```$````.=$```<````^T0``
M!0```$;1```%````3-$```L```!2T0``%````%[1```1````<]$``!H```"%
MT0``%@```*#1```4````M]$``!<```#,T0``&````.31```<````_=$``!D`
M```:T@``!P```#32```%````/-(```T```!"T@``#````%#2```(````7=(`
M`!<```!FT@``"P```'[2```3````BM(```0```">T@``"@```*/2```$````
MKM(```P```"ST@``"0```,#2```%````RM(```<```#0T@``!0```-C2```$
M````WM(```(```#CT@``.````.;2```L````'],``!(```!,TP``*0```%_3
M```R````B=,```H```"\TP``+````,?3```N````]-,``#,````CU```,P``
M`%?4```X````B]0```\```#$U```&````-34```0````[=0```\```#^U```
M$P````[5```4````(M4``!(````WU0``%````$K5```5````7]4``"T```!U
MU0``+0```*/5```Q````T=4``"X````#U@``+P```#+6```L````8M8``&(`
M``"/U@``$P```/+6```(````!M<```@````/UP``*P```!C7```A````1-<`
M`!H```!FUP``"0```('7``!%````B]<``$$```#1UP``!````!/8```3````
M&-@``!0````LV```#@```$'8```3````4-@``!@```!DV```!@```'W8```)
M````A-@```H```".V```#P```)G8```0````J=@```<```"ZV```#@```,+8
M```%````T=@``!L```#7V```"````//8```&````_-@``!0````#V0``$0``
M`!C9```.````*MD``#@````YV0```@```'+9```&````==D```X```!\V0``
M!0```(O9```'````D=D```X```"9V0``!@```*C9```$````K]D``"D```"T
MV0``%P```-[9```?````]MD``%P````6V@``%````'/:```^````B-H``!\`
M``#'V@``$````.?:```'````^-H```X`````VP``#`````_;```,````'-L`
M`!,````IVP``"@```#W;```=````2-L``!D```!FVP``!0```(#;```1````
MAML``!$```"8VP``)````*K;```5````S]L``!(```#EVP``#@```/C;```9
M````!]P```@````AW```"0```"K<```-````--P```H```!"W```!P```$W<
M```/````5=P```L```!EW```"@```''<```'````?-P```@```"$W```!0``
M`(W<```?````D]P```8```"SW```$````+K<```(````R]P```T```#4W```
M"````.+<```2````Z]P``"P```#^W```&@```"O=```)````1MT```H```!0
MW0``%0```%O=```%````<=T``!0```!WW0``!````(S=```0````D=T```8`
M``"BW0``!P```*G=```>````L=T``"@```#0W0``"@```/G=```:````!-X`
M`!0````?W@``!````#3>```$````.=X```L````^W@``!0```$K>```&````
M4-X```@```!7W@``!@```&#>```*````9]X``!L```!RW@``-````([>```T
M````P]X``"````#XW@``*0```!G?```@````0]\``$$```!DWP``&@```*;?
M```H````P=\``"D```#JWP``(@```!3@```&````-^````@````^X```!0``
M`$?@```(````3>```!D```!6X```&0```'#@```J````BN```",```"UX```
M+@```-G@```T````".$```@````]X0``%P```$;A```*````7N$```<```!I
MX0``(0```''A```0````D^$```X```"DX0``"P```+/A```'````O^$``!,`
M``#'X0``"````-OA```+````Y.$```H```#PX0``%````/OA```R````$.(`
M``L```!#X@``!0```$_B```%````5>(``!<```!;X@``#P```'/B```$````
M@^(```H```"(X@``"0```)/B```+````G>(```T```"IX@``#````+?B```.
M````Q.(```4```#3X@``!````-GB```-````WN(``#(```#LX@``10```!_C
M```7````9>,``!X```!]XP``%````)SC```%````L>,``!0```"WXP``!P``
M`,SC```.````U.,``"H```#CXP``!@````[D```,````%>0```T````BY```
M$0```##D```+````0N0``#8```!.Y```"@```(7D```B````D.0```L```"S
MY```#P```+_D```R````S^0```X````"Y0``!0```!'E```.````%^4``!,`
M```FY0``!P```#KE```1````0N4```<```!4Y0``%````%SE```8````<>4`
M``<```"*Y0``!0```)+E```,````F.4```P```"EY0``$@```++E```$````
MQ>4```<```#*Y0``"@```-+E```+````W>4```P```#IY0``#@```/;E```.
M````!>8```4````4Y@``!0```!KF```N````(.8``"8```!/Y@``(P```';F
M```#````FN8``!(```">Y@``!@```+'F```>````N.8``!@```#7Y@``)0``
M`/#F```-````%N<```D````DYP```P```"[G```'````,N<```H````ZYP``
M`@```$7G```,````2.<``!4```!5YP``"P```&OG```9````=^<``"````"1
MYP``$@```++G```%````Q><```H```#+YP``%0```-;G```2````[.<```P`
M``#_YP``!`````SH```'````$>@```P````9Z```4@```";H```7````>>@`
M``<```"1Z```!@```)GH```.````H.@```P```"OZ```#0```+SH```5````
MRN@``!(```#@Z```#P```//H```4`````^D``!L````8Z0``$````#3I``!I
M````1>D``!H```"OZ0``%P```,KI```G````XND``!H````*Z@``%P```"7J
M```;````/>H``!D```!9Z@``'P```'/J```3````D^H```@```"GZ@``!P``
M`+#J```(````N.H```D```#!Z@``%0```,OJ```-````X>H``!,```#OZ@``
M`P````/K``!&````!^L``#\```!.ZP``-P```([K``!7````QNL```4````>
M[```'P```"3L```O````1.P```H```!T[```"````'_L```-````B.P``"T`
M``"6[```!````,3L``!/````R>P``"4````9[0``'````#_M```+````7.T`
M`!\```!H[0``'0```(CM```E````INT``"````#,[0``)````.WM```@````
M$NX```L````S[@``!P```#_N```-````1^X```P```!5[@``%P```&+N```&
M````>NX``#D```"![@``#````+ON```'````R.X```D```#0[@``$P```-KN
M```)````[NX```0```#X[@``$````/WN```(````#N\```@````7[P``!```
M`"#O```+````)>\```P````Q[P``$@```#[O```1````4>\```P```!C[P``
M&@```'#O```/````B^\```<```";[P``#0```*/O```4````L>\```X```#&
M[P``#````-7O```;````XN\``"P```#^[P``$P```"OP```<````/_```"@`
M``!<\```!@```(7P```'````C/```!,```"4\```!0```*CP```$````KO``
M`!<```"S\```"@```,OP```,````UO````D```#C\```!@```.WP```)````
M]/````@```#^\```"0````?Q```*````$?$``!$````<\0``!@```"[Q```.
M````-?$```X```!$\0``#0```%/Q```+````8?$``!T```!M\0``"P```(OQ
M```"````E_$```<```":\0``!@```*+Q```)````J?$```<```"S\0``.P``
M`+OQ```H````]_$``#0````@\@``%0```%7R```%````:_(```<```!Q\@``
M"````'GR```'````@O(```4```"*\@``!P```)#R```.````F/(```D```"G
M\@``!@```+'R```(````N/(```L```#!\@``!P```,WR```(````U?(```<`
M``#>\@``%@```.;R```)````_?(```8````'\P``"P````[S```<````&O,`
M`!0````W\P``!P```$SS```(````5/,```@```!=\P``!0```&;S```0````
M;/,``!````!]\P``!@```([S```9````E?,```H```"O\P``'````+KS```'
M````U_,```4```#?\P``$````.7S```4````]O,```L````+]```#0```!?T
M```7````)?0```0````]]```"0```$+T```*````3/0```<```!7]````@``
M`%_T```.````8O0```@```!Q]```'P```'KT```C````FO0``#@```"^]```
M,0```/?T```G````*?4``&0```!1]0``%````+;U``!5````R_4``#@````A
M]@``2@```%KV``!;````I?8``"@````!]P``.````"KW```H````8_<``"P`
M``",]P``)P```+GW```;````X?<``#X```#]]P``J0$``#SX```C````YOD`
M`!<````*^@``2````"+Z``"%````:_H``#````#Q^@``00```"+[``!;````
M9/L``$D```#`^P``'0````K\```8````*/P``"$```!!_```'P```&/\```K
M````@_P``"$```"O_```)P```-'\```=````^?P``!$````7_0``,P```"G]
M```E````7?T``"<```"#_0``'P```*O]```P````R_T``&D```#\_0``/0``
M`&;^``!E````I/X``$T````*_P``+P```%C_```N````B/\``#````"W_P``
M5````.C_``!:````/0`!`$@```"8``$`2@```.$``0`R````+`$!`"\```!?
M`0$`+````(\!`0`M````O`$!`'$```#J`0$`;P```%P"`0"S````S`(!`!<`
M``"``P$`)0```)@#`0`R````O@,!`"D```#Q`P$`/@```!L$`0`B````6@0!
M`%(```!]!`$`)0```-`$`0`+````]@0!`+$````"!0$`10```+0%`0`A````
M^@4!`#`````<!@$`)0```$T&`0`<````<P8!`#$```"0!@$`!P```,(&`0`'
M````R@8!``0```#2!@$`#0```-<&`0`+````Y08!``X```#Q!@$`"P`````'
M`0`%````#`<!`!`````2!P$``@```",'`0!9````)@<!``4```"`!P$`$@``
M`(8'`0`$````F0<!``<```">!P$`"````*8'`0`%````KP<!``,```"U!P$`
M$````+D'`0`,````R@<!`!,```#7!P$`#0```.L'`0`"````^0<!``<```#\
M!P$`!@````0(`0`4````"P@!``P````@"`$`&````"T(`0`&````1@@!`!(`
M``!-"`$`#````&`(`0`#````;0@!`"H```!Q"`$`!````)P(`0`&````H0@!
M``<```"H"`$`'P```+`(`0`U````T`@!`"X````&"0$`+P```#4)`0`7````
M90D!`"````!]"0$`&P```)X)`0`8````N@D!`"0```#3"0$`'P```/@)`0`:
M````&`H!`"`````S"@$`&@```%0*`0`R````;PH!`"\```"B"@$`*P```-(*
M`0`?````_@H!`",````>"P$`'P```$(+`0`:````8@L!`"4```!]"P$`)@``
M`*,+`0`E````R@L!`"0```#P"P$`&````!4,`0`=````+@P!`"0```!,#`$`
M&````'$,`0`B````B@P!`"4```"M#`$`/````-,,`0`?````$`T!`",````P
M#0$`'P```%0-`0`@````=`T!`!H```"5#0$`&````+`-`0`F````R0T!`!X`
M``#P#0$`*0````\.`0`>````.0X!``D```!8#@$`#````&(.`0`7````;PX!
M`"\```"'#@$`)````+<.`0`'````W`X!``\```#D#@$`%````/0.`0`.````
M"0\!``T````8#P$`)````"8/`0`%````2P\!``<```!1#P$`(@```%D/`0`E
M````?`\!`!T```"B#P$`&@```,`/`0`'````VP\!`,<```#C#P$`"P```*L0
M`0`5````MQ`!``8```#-$`$`"0```-00`0`+````WA`!`!<```#J$`$`!@``
M``(1`0`S````"1$!`!,````]$0$`$P```%$1`0`'````91$!``\```!M$0$`
M!P```'T1`0`R````A1$!`"$```"X$0$`$P```-H1`0`,````[A$!`!$```#[
M$0$`,@````T2`0`(````0!(!``D```!)$@$`"@```%,2`0`4````7A(!``H`
M``!S$@$`'0```'X2`0`(````G!(!`!\```"E$@$`"````,42`0`:````SA(!
M``8```#I$@$`%0```/`2`0`'````!A,!``@````.$P$`"0```!<3`0`_````
M(1,!``<```!A$P$`#P```&D3`0`.````>1,!`!````"($P$`"0```)D3`0`)
M````HQ,!``@```"M$P$`$P```+83`0`'````RA,!`!D```#2$P$`"@```.P3
M`0`7````]Q,!`!0````/%`$`"@```"04`0`,````+Q0!`!<````\%`$`!```
M`%04`0`J````610!`!$```"$%`$`!P```)84`0`"````GA0!`!````"A%`$`
M&````+(4`0`+````RQ0!``,```#7%`$`"````-L4`0`&````Y!0!``<```#K
M%`$`#0```/,4`0`+`````14!`!0````-%0$`%0```"(5`0`.````.!4!`"\`
M``!'%0$`(````'<5`0`<````F!4!``P```"U%0$`,0```,(5`0`%````]!4!
M`!(```#Z%0$`/P````T6`0`2````318!``H```!@%@$`!@```&L6`0`$````
M<A8!``0```!W%@$`"@```'P6`0`3````AQ8!``4```";%@$`!@```*$6`0`&
M````J!8!``0```"O%@$`#````+06`0`*````P18!``4```#,%@$`&````-(6
M`0`9````ZQ8!`!\````%%P$`'0```"47`0`1````0Q<!``(```!5%P$`!```
M`%@7`0`*````71<!``8```!H%P$`!0```&\7`0`#````=1<!``P```!Y%P$`
M10```(87`0`:````S!<!`#4```#G%P$`*````!T8`0!3````1A@!`!D```":
M&`$`<@```+08`0`@````)QD!`#4```!(&0$`(0```'X9`0!%````H!D!`#``
M``#F&0$`*````!<:`0`I````0!H!`"8```!J&@$`)0```)$:`0`H````MQH!
M`"@```#@&@$`(@````D;`0`P````+!L!`!(```!=&P$`$P```'`;`0`0````
MA!L!`'D```"5&P$`"0````\<`0!S````&1P!`'P```"-'`$`*P````H=`0`7
M````-AT!`!8```!.'0$`#P```&4=`0`?````=1T!`$````"5'0$`'P```-8=
M`0`<````]AT!`%$````3'@$`%````&4>`0`*````>AX!``4```"%'@$`!@``
M`(L>`0`(````DAX!``4```";'@$`$@```*$>`0`0````M!X!`!,```#%'@$`
M'0```-D>`0`/````]QX!``\````''P$`!````!<?`0`)````'!\!``L````F
M'P$`!P```#(?`0`%````.A\!`!0```!`'P$`!P```%4?`0`(````71\!``\`
M``!F'P$`"````'8?`0`,````?Q\!``\```",'P$`!@```)P?`0`4````HQ\!
M``8```"X'P$`#````+\?`0`(````S!\!``0```#5'P$`"@```-H?`0`'````
MY1\!``0```#M'P$`&0```/(?`0`"````#"`!``D````/(`$`!@```!D@`0`&
M````("`!`"<````G(`$`!````$\@`0`/````5"`!`!,```!D(`$`!P```'@@
M`0`'````@"`!``8```"((`$`!@```(\@`0`0````EB`!`!(```"G(`$`!@``
M`+H@`0`)````P2`!`"(```#+(`$`!P```.X@`0`'````]B`!``L```#^(`$`
M!0````HA`0`"````$"$!``L````3(0$`:P$``!\A`0`.````BR(!`!0```":
M(@$`"P```*\B`0`(````NR(!``@```#$(@$`!@```,TB`0`(````U"(!``L`
M``#=(@$`%@```.DB`0`-`````",!``T````.(P$`!0```!PC`0`=````(B,!
M``H```!`(P$`"````$LC`0`4````5",!``T```!I(P$`"P```'<C`0`1````
M@R,!``D```"5(P$`#@```)\C`0`-````KB,!`!````"\(P$`"0```,TC`0`.
M````UR,!`!````#F(P$`!@```/<C`0`1````_B,!`!(````0)`$`"0```",D
M`0`7````+20!`!<```!%)`$`!P```%TD`0`S````920!`!<```"9)`$`/0``
M`+$D`0!-````[R0!`&0````])0$`7````*(E`0!K````_R4!`&,```!K)@$`
M/P```,\F`0`)````#R<!``D````9)P$`#````",G`0`%````,"<!``8````V
M)P$`%````#TG`0`,````4B<!``4```!?)P$`!@```&4G`0`H````;"<!`"H`
M``"5)P$`#@```,`G`0`1````SR<!``P```#A)P$`!````.XG`0`-````\R<!
M``T````!*`$`#`````\H`0`.````'"@!``X````K*`$`%````#HH`0`*````
M3R@!``T```!:*`$`"@```&@H`0`L````<R@!`!4```"@*`$`%````+8H`0`.
M````RR@!`",```#:*`$`!0```/XH`0`-````!"D!`#(````2*0$`!P```$4I
M`0`#````32D!``H```!1*0$`"@```%PI`0`'````9RD!``@```!O*0$`!@``
M`'@I`0`*````?RD!``0```"**0$`'````(\I`0`+````K"D!``L```"X*0$`
M#````,0I`0`8````T2D!`#0```#J*0$`"0```!\J`0`1````*2H!`!,````[
M*@$`&````$\J`0`=````:"H!``\```"&*@$`#````)8J`0`.````HRH!`!H`
M``"R*@$`!@```,TJ`0`&````U"H!``@```#;*@$`#````.0J`0`%````\2H!
M``D```#W*@$`$@````$K`0`(````%"L!`!`````=*P$`#@```"XK`0`7````
M/2L!``8```!5*P$`#@```%PK`0`%````:RL!`!4```!Q*P$`%0```(<K`0`,
M````G2L!`#H```"J*P$`"````.4K`0`*````[BL!`!0```#Y*P$`!0````XL
M`0`%````%"P!`!$````:+`$`#````"PL`0`4````.2P!`"\```!.+`$`#P``
M`'XL`0`E````CBP!`"0```"T+`$`*0```-DL`0`M`````RT!``P````Q+0$`
M!P```#XM`0`+````1BT!``D```!2+0$`+P```%PM`0`L````C"T!`"T```"Y
M+0$`7P```.<M`0`L````1RX!`"P```!T+@$`+````*$N`0`N````SBX!`"0`
M``#]+@$`*````"(O`0`L````2R\!`#(```!X+P$`&0```*LO`0`<````Q2\!
M`#,```#B+P$`*````!8P`0`3````/S`!``H```!3,`$`$0```%XP`0`'````
M<#`!``T```!X,`$`%P```(8P`0`<````GC`!``D```"[,`$`!P```,4P`0`4
M````S3`!``D```#B,`$`"````.PP`0`-````]3`!``L````#,0$`!P````\Q
M`0`&````%S$!``4````>,0$`!P```"0Q`0`&````+#$!``D````S,0$`,0``
M`#TQ`0`-````;S$!``D```!],0$`!````(<Q`0`'````C#$!``H```"4,0$`
M!0```)\Q`0`0````I3$!``@```"V,0$`#````+\Q`0`)````S#$!``@```#6
M,0$``P```-\Q`0`.````XS$!``@```#R,0$`'@```/LQ`0`&````&C(!``L`
M```A,@$`$````"TR`0`,````/C(!``<```!+,@$``P```%,R`0`#````5S(!
M`!4```!;,@$`%0```'$R`0`&````AS(!``8```".,@$`"````)4R`0`'````
MGC(!`$P```"F,@$`'P```/,R`0`&````$S,!``4````:,P$`%P```"`S`0`8
M````.#,!`!@```!1,P$`,0```&HS`0`:````G#,!`!\```"W,P$`=P```-<S
M`0`L````3S0!``H```!\-`$`!@```(<T`0`8````CC0!``X```"G-`$`#```
M`+8T`0`1````PS0!`!,```#5-`$`$0```.DT`0`1````^S0!``P````--0$`
M%````!HU`0`$````+S4!`!<````T-0$`&````$PU`0`8````934!`!8```!^
M-0$``P```)4U`0`(````F34!`&L```"B-0$`"`````XV`0`6````%S8!``0`
M```N-@$``P```#,V`0`?````-S8!`!<```!7-@$`#````&\V`0`3````?#8!
M`"<```"0-@$`,P```+@V`0`1````[#8!`!H```#^-@$`!P```!DW`0`?````
M(3<!`!<```!!-P$`$0```%DW`0`8````:S<!`!D```"$-P$`%P```)XW`0`/
M````MC<!``@```#&-P$`!P```,\W`0`-````US<!`!4```#E-P$`%````/LW
M`0`)````$#@!``0````:.`$`"P```!\X`0`+````*S@!``D````W.`$`$```
M`$$X`0`%````4C@!``4```!8.`$`#````%XX`0`(````:S@!``D```!T.`$`
M!P```'XX`0`&````AC@!``T```"-.`$`"````)LX`0`5````I#@!``T```"Z
M.`$`$````,@X`0`%````V3@!`!P```#?.`$`&````/PX`0`8````%3D!`"P`
M```N.0$`.P```%LY`0`E````ESD!`#<```"].0$`!0```/4Y`0`,````^SD!
M``4````(.@$`!P````XZ`0`.````%CH!``H````E.@$`#0```#`Z`0`<````
M/CH!`!L```!;.@$`'P```'<Z`0`>````ESH!`!\```"V.@$`'@```-8Z`0`8
M````]3H!`"`````..P$`(0```"\[`0`D````43L!`!\```!V.P$`'@```)8[
M`0`O````M3L!`",```#E.P$`)0````D\`0`Q````+SP!`"X```!A/`$`#0``
M`)`\`0`E````GCP!``T```#$/`$`F0```-(\`0`0````;#T!`!\```!]/0$`
M(0```)T]`0`C````OST!`"0```#C/0$`(0````@^`0`>````*CX!`"4```!)
M/@$`*````&\^`0`L````F#X!`*,```#%/@$`&````&D_`0`C````@C\!`"(`
M``"F/P$`2P```,D_`0`.````%4`!``0````D0`$`!P```"E``0`%````,4`!
M``X````W0`$`"@```$9``0`/````44`!`!$```!A0`$`$P```'-``0`+````
MAT`!``0```"30`$`#P```)A``0`-````J$`!`!4```"V0`$`$@```,Q``0`2
M````WT`!`#````#R0`$``P```"-!`0`3````)T$!``8````[00$`#@```$)!
M`0`4````44$!`!8```!F00$`#P```'U!`0`"````C4$!``8```"000$`%0``
M`)=!`0`%````K4$!``P```"S00$`#````,!!`0`#````S4$!``L```#100$`
M!@```-U!`0`/````Y$$!``\```#T00$`"@````1"`0`/````#T(!`!$````?
M0@$`"````#%"`0`#````.D(!``@````^0@$`"````$="`0`8````4$(!``D`
M``!I0@$`"0```'-"`0`9````?4(!``H```"70@$`%````*)"`0`4````MT(!
M`!0```#,0@$`#0```.%"`0`)````[T(!`!$```#Y0@$`"`````M#`0`\````
M%$,!`#(```!10P$`!P```(1#`0`+````C$,!`!H```"80P$`#0```+-#`0`1
M````P4,!`!$```#30P$`!0```.5#`0`@````ZT,!`!<````,1`$`'@```"1$
M`0`2````0T0!``\```!61`$`!@```&9$`0`(````;40!`"T```!V1`$`/@``
M`*1$`0`'````XT0!`!,```#K1`$`!0```/]$`0`(````!44!`#,````.10$`
M$@```$)%`0`'````544!``<```!=10$``P```&5%`0`'````:44!``<```!Q
M10$`#````'E%`0`,````AD4!``P```"310$`$````*!%`0`8````L44!`!0`
M``#*10$`&````-]%`0`&````^$4!``4```#_10$`"P````5&`0`&````$48!
M``(````81@$`$````!M&`0`7````+$8!`"4```!$1@$`%P```&I&`0`0````
M@D8!``H```"31@$`"@```)Y&`0`3````J48!`$X```"]1@$`*@````Q'`0`*
M````-T<!`!8```!"1P$`<@```%E'`0`=````S$<!``X```#J1P$`!@```/E'
M`0`$`````$@!`"`````%2`$`!P```"9(`0`(````+D@!``4````W2`$`!@``
M`#U(`0`-````1$@!``P```!22`$`#0```%](`0`,````;4@!``L```!Z2`$`
M#@```(9(`0`*````E4@!``\```"@2`$`"````+!(`0`(````N4@!`!<```#"
M2`$`#@```-I(`0`O````Z4@!`!4````920$``P```"])`0`-````,TD!`!H`
M``!!20$`(````%Q)`0`C````?4D!`"(```"A20$`)````,1)`0`B````Z4D!
M`"0````,2@$`'P```#%*`0`*````44H!`!H```!<2@$`#0```'=*`0`-````
MA4H!``0```"32@$`!0```)A*`0`,````GDH!``X```"K2@$`#0```+I*`0`2
M````R$H!``P```#;2@$`!````.A*`0`6````[4H!`!8````$2P$`$````!M+
M`0`)````+$L!``P````V2P$`#0```$-+`0`=````44L!``D```!O2P$`"@``
M`'E+`0`(````A$L!``H```"-2P$`#0```)A+`0`%````IDL!``4```"L2P$`
M`P```+)+`0`-````MDL!``H```#$2P$`!0```,]+`0`J````U4L!``P`````
M3`$`>P````U,`0`7````B4P!``<```"A3`$`!0```*E,`0`*````KTP!``@`
M``"Z3`$`"@```,-,`0`(````SDP!``X```#73`$``@```.9,`0`*````Z4P!
M``8```#T3`$`%````/M,`0`0````$$T!`!,````A30$`%0```#5-`0`&````
M2TT!``8```!230$`#0```%E-`0`'````9TT!``<```!O30$`!0```'=-`0`=
M````?4T!``<```";30$`!P```*--`0`;````JTT!``\```#'30$`"0```-=-
M`0`'````X4T!``0```#I30$`"P```.Y-`0`*````^DT!``,````%3@$`!@``
M``E.`0`,````$$X!``L````=3@$`"@```"E.`0`4````-$X!``@```!)3@$`
M!P```%).`0`-````6DX!`!P```!H3@$`!P```(5.`0`(````C4X!``0```"6
M3@$`"0```)M.`0`(````I4X!``X```"N3@$`#0```+U.`0`$````RTX!``P`
M``#03@$`!@```-U.`0`$````Y$X!`#(```#I3@$`,P```!Q/`0`S````4$\!
M`"````"$3P$`!0```*5/`0`0````JT\!``D```"\3P$`!@```,9/`0`?````
MS4\!`!<```#M3P$`"0````50`0`&````#U`!`!L````64`$`"````#)0`0`(
M````.U`!`!4```!$4`$`!@```%I0`0`)````85`!``<```!K4`$`"````'-0
M`0`)````?%`!``L```"&4`$`"````))0`0`)````FU`!``4```"E4`$`2```
M`*M0`0`W````]%`!`#L````L40$`)P```&A1`0!)````D%$!`#L```#:40$`
M(P```!92`0`W````.E(!`",```!R4@$`&@```)92`0`8````L5(!``L```#*
M4@$`$````-92`0`&````YU(!`"L```#N4@$`*@```!I3`0`5````15,!`"H`
M``!;4P$``P```(93`0`%````BE,!``H```"04P$`"@```)M3`0`D````IE,!
M`"````#+4P$`*P```.Q3`0`)````&%0!`!@````B5`$`+P```#M4`0`4````
M:U0!`!<```"`5`$`!P```)A4`0`/````H%0!`!````"P5`$`&P```,%4`0`-
M````W50!`$4```#K5`$`:@```#%5`0"!````G%4!`!`````>5@$`"P```"]6
M`0`,````.U8!`!````!(5@$`$0```%E6`0`0````:U8!``H```!\5@$`%```
M`(=6`0`8````G%8!`!@```"U5@$`$P```,Y6`0`:````XE8!`"0```#]5@$`
M:````")7`0`0````BU<!``D```"<5P$`%0```*97`0`)````O%<!``4```#&
M5P$`!0```,Q7`0`3````TE<!`!$```#F5P$`$0```/A7`0`8````"E@!`!(`
M```C6`$`+@```#98`0`O````95@!`#````"56`$`+P```,98`0`S````]E@!
M`#(````J60$`%@```%U9`0!#````=%D!`!L```"X60$`&@```-19`0`:````
M[UD!`!D````*6@$`"0```"1:`0`=````+EH!`!P```!,6@$`&@```&E:`0`9
M````A%H!`!H```">6@$`'````+E:`0`;````UEH!`"X```#R6@$`#@```"%;
M`0`'````,%L!``\````X6P$`+0```$A;`0`2````=EL!`!<```")6P$`&0``
M`*%;`0`6````NUL!`!4```#26P$`$0```.A;`0`=````^EL!`"0````87`$`
M$@```#U<`0`;````4%P!`!D```!L7`$`%P```(9<`0`8````GEP!``0```"W
M7`$`%@```+Q<`0`$````TUP!``<```#87`$`#P```.!<`0`@````\%P!``8`
M```170$`!P```!A=`0`&````(%T!``8````G70$`!P```"Y=`0`$````-ET!
M``<````[70$`%0```$-=`0`&````65T!``4```!@70$`!@```&9=`0`'````
M;5T!``4```!U70$`#````'M=`0`-````B%T!``H```"670$`"@```*%=`0`*
M````K%T!`!@```"W70$`!0```-!=`0`E````UET!`!(```#\70$`#0````]>
M`0`1````'5X!`!`````O7@$`#````$!>`0`1````35X!`"L```!?7@$`"```
M`(M>`0`(````E%X!``H```"=7@$`"@```*A>`0`/````LUX!``8```##7@$`
M"P```,I>`0`-````UEX!``,```#D7@$`'P```.A>`0`*````"%\!``D````3
M7P$`#P```!U?`0`-````+5\!`!H````[7P$`#P```%9?`0`'````9E\!``0`
M``!N7P$`!0```'-?`0`=````>5\!``8```"77P$``P```)Y?`0`2````HE\!
M`!````"U7P$`!P```,9?`0`'````SE\!``4```#67P$`#0```-Q?`0`)````
MZE\!``P```#T7P$`'`````%@`0`:````'F`!`!4````Y8`$`&@```$]@`0`)
M````:F`!`!(```!T8`$`#````(=@`0`(````E&`!`!$```"=8`$`00```*]@
M`0`+````\6`!``P```#]8`$`)`````IA`0`8````+V$!`!D```!(80$`$P``
M`&)A`0`-````=F$!``X```"$80$`"@```)-A`0`-````GF$!`!H```"L80$`
M%0```,=A`0`=````W6$!`"8```#[80$`"````")B`0`(````*V(!``T````T
M8@$`#````$)B`0`,````3V(!``,```!<8@$`!0```&!B`0`%````9F(!``\`
M``!L8@$`0P```'QB`0`5````P&(!``H```#68@$``P```.%B`0`%````Y6(!
M`!0```#K8@$`%`````!C`0`4````%6,!``H````J8P$``@```#5C`0`$````
M.&,!`"`````]8P$``P```%YC`0`%````8F,!``D```!H8P$`"@```')C`0`$
M````?6,!``4```""8P$`$````(AC`0`2````F6,!``8```"L8P$`!P```+-C
M`0`)````NV,!``0```#%8P$`!0```,IC`0!C````T&,!``X````T9`$`$0``
M`$-D`0`$````560!``T```!:9`$`(0```&AD`0`_````BF0!`!````#*9`$`
M"````-MD`0`/````Y&0!``D```#T9`$`"````/YD`0`=````!V4!`"8````E
M90$`)````$QE`0`C````<64!`!$```"590$`!0```*=E`0`'````K64!``,`
M``"U90$`!@```+EE`0`*````P&4!`!,```#+90$`!0```-]E`0!(````Y64!
M`!4````N9@$`"@```$1F`0`+````3V8!`"<```!;9@$`3````(-F`0`&````
MT&8!``8```#79@$`!P```-YF`0`*````YF8!``0```#Q9@$`"0```/9F`0`C
M`````&<!`"(````D9P$`!0```$=G`0`(````36<!`"8```!69P$`8````'UG
M`0`2````WF<!`"<```#Q9P$`&````!EH`0`#````,F@!``P````V:`$`!0``
M`$-H`0`.````26@!``P```!8:`$`"@```&5H`0`(````<&@!``8```!Y:`$`
M"@```(!H`0`)````BV@!``4```"5:`$`"@```)MH`0`+````IF@!``,```"R
M:`$`#P```+9H`0`2````QF@!`!(```#9:`$`"@```.QH`0`)````]V@!``D`
M```!:0$`"P````MI`0`*````%VD!``L````B:0$`"````"YI`0`A````-VD!
M``L```!9:0$`!P```&5I`0`(````;6D!``X```!V:0$`!P```(5I`0`/````
MC6D!``(```"=:0$`!P```*!I`0`%````J&D!``4```"N:0$`"````+1I`0`2
M````O6D!`!(```#0:0$`%0```.-I`0`5````^6D!`!0````/:@$`$@```"1J
M`0`7````-VH!`"````!/:@$`&@```'!J`0`"````BVH!``0```".:@$`#@``
M`)-J`0`-````HFH!``<```"P:@$`'````+AJ`0`-````U6H!`!,```#C:@$`
M"````/=J`0`.`````&L!``<````/:P$`$@```!=K`0`)````*FL!``<````T
M:P$`!P```#QK`0`$````1&L!``0```!):P$`!0```$YK`0!#````5&L!`#H`
M``"8:P$`$@```--K`0`K````YFL!`#@````2;`$`#@```$ML`0`I````6FP!
M`#$```"$;`$`-@```+9L`0`V````[6P!`#L````D;0$`"@```&!M`0`G````
M:VT!`!@```"3;0$`&````*QM`0`8````Q6T!`!@```#>;0$`$````/=M`0`4
M````"&X!`!@````=;@$`)P```#9N`0`G````7FX!`"L```"&;@$`*````+)N
M`0`I````VVX!`"8````%;P$`8````"QO`0`<````C6\!``D```"J;P$`!P``
M`+1O`0`F````O&\!`"H```#C;P$`(`````YP`0`)````+W`!`$,````Y<`$`
M1@```'UP`0`'````Q'`!`!D```#,<`$`'````.9P`0`-`````W$!``\````1
M<0$`%0```"%Q`0`&````-W$!`!`````^<0$`#P```$]Q`0`+````7W$!`!,`
M``!K<0$`#0```']Q`0`/````C7$!``8```"=<0$`)````*1Q`0`%````R7$!
M``0```#/<0$`#P```-1Q`0`,````Y'$!``P```#Q<0$`0````/YQ`0`$````
M/W(!``4```!$<@$`$````$IR`0`/````6W(!``0```!K<@$`%````'!R`0`$
M````A7(!``4```"*<@$`/0```)!R`0`9````SG(!`#@```#H<@$`70```"%S
M`0`1````?W,!`$4```"1<P$`'P```-=S`0`/````]W,!``H````'=`$`$@``
M`!)T`0`0````)70!``<````V=`$`#@```#YT`0`)````370!`!8```!7=`$`
M'````&YT`0`%````BW0!``X```"1=`$`#@```*!T`0`=````KW0!`!````#-
M=`$`%````-YT`0`1````\W0!`",````%=0$`"````"EU`0`*````,G4!``\`
M```]=0$`#@```$UU`0`&````7'4!`!(```!C=0$`&````'9U`0`+````CW4!
M``H```";=0$`"````*9U`0`%````KW4!`!X```"U=0$`!@```-1U`0`/````
MVW4!``@```#K=0$`#@```/1U`0`&`````W8!``T````*=@$`+0```!AV`0`-
M````1G8!``<```!4=@$`!P```%QV`0`>````9'8!``@```"#=@$`$````(QV
M`0`#````G78!`!,```"A=@$`"````+5V`0`%````OG8!`!X```#$=@$`+0``
M`.-V`0`$````$7<!``T````6=P$`$````"1W`0`$````-7<!``\````Z=P$`
M"@```$IW`0`'````57<!``L```!==P$`"````&EW`0`,````<G<!``T```!_
M=P$`'@```(UW`0`Q````K'<!`#8```#>=P$`'P```!5X`0`D````-7@!`",`
M``!:>`$`/P```'YX`0`?````OG@!`"$```#>>`$`*`````!Y`0`A````*7D!
M``<```!+>0$`"````%-Y`0`)````7'D!``@```!F>0$`&0```&]Y`0`9````
MB7D!`#,```"C>0$`*@```-=Y`0`M`````GH!`#(````P>@$`!@```&-Z`0`;
M````:GH!``<```"&>@$`"````(YZ`0`?````EWH!`!$```"W>@$`#@```,EZ
M`0`,````V'H!``4```#E>@$`$0```.MZ`0`(````_7H!`!(````&>P$`#```
M`!E[`0`8````)GL!`#$````_>P$`"@```'%[`0`%````?'L!``4```"">P$`
M&@```(A[`0`,````HWL!``8```"P>P$`%@```+=[`0`4````SGL!``T```#C
M>P$`#0```/%[`0`5````_WL!``X````5?`$`!````"1\`0`%````*7P!``T`
M```O?`$`2````#U\`0!C````AGP!`!,```#J?`$`'P```/Y\`0`9````'GT!
M``T````X?0$`#P```$9]`0`+````5GT!`!(```!B?0$`+````'5]`0`#````
MHGT!``D```"F?0$`"@```+!]`0`/````NWT!``L```#+?0$`,@```-=]`0`#
M````"GX!`!H````.?@$`#0```"E^`0`3````-WX!`"<```!+?@$`#````'-^
M`0`'````@'X!`!````"(?@$`%0```)E^`0`(````KWX!`!$```"X?@$`!P``
M`,I^`0`:````TGX!`"8```#M?@$`"@```!1_`0`#````'W\!`!(````C?P$`
M#@```#9_`0`5````17\!``4```!;?P$`!P```&%_`0`1````:7\!``L```![
M?P$`"P```(=_`0`1````DW\!`!$```"E?P$`"0```+=_`0`(````P7\!`#0`
M``#*?P$`+@```/]_`0`N````+H`!``@```!=@`$`$0```&:``0`&````>(`!
M`!<```!_@`$`'````)>``0`>````M(`!``X```#3@`$`"@```.*``0`#````
M[8`!``@```#Q@`$`"P```/J``0`#````!H$!``P````*@0$`%````!>!`0`+
M````+($!`!@````X@0$`&P```%&!`0`7````;8$!``4```"%@0$`"@```(N!
M`0`4````EH$!``X```"K@0$`#P```+J!`0`&````RH$!``D```#1@0$`$@``
M`-N!`0!.````[H$!`!T````]@@$`!0```%N"`0`%````88(!``\```!G@@$`
M#0```'>"`0`/````A8(!`!L```"5@@$`$0```+&"`0`0````PX(!`"````#4
M@@$`'P```/6"`0`/````%8,!`&X````E@P$`'````)2#`0`5````L8,!`"8`
M``#'@P$`&P```.Z#`0`4````"H0!`!@````?A`$`%@```#B$`0`<````3X0!
M`!,```!LA`$`"@```("$`0`'````BX0!``L```"3A`$`!0```)^$`0`7````
MI80!``T```"]A`$`'P```,N$`0`&````ZX0!`$H```#RA`$`,0```#V%`0!$
M````;X4!`&,```"TA0$`!P```!B&`0`T````((8!`"@```!5A@$`!@```'Z&
M`0`*````A88!``D```"0A@$`,@```)J&`0`&````S88!`%L```#4A@$`*P``
M`#"'`0`E````7(<!``\```""AP$`,````)*'`0`?````PX<!`"<```#CAP$`
M(0````N(`0`G````+8@!`",```!5B`$`$````'F(`0`'````BH@!`!<```"2
MB`$`%0```*J(`0`/````P(@!``8```#0B`$`+P```->(`0`,````!XD!``8`
M```4B0$`!````!N)`0`0````((D!``@````QB0$`!0```#J)`0`+````0(D!
M``@```!,B0$`"````%6)`0`#````7HD!``P```!BB0$`#P```&^)`0`?````
M?XD!`!T```"?B0$`#P```+V)`0`6````S8D!``\```#DB0$`!@```/2)`0`2
M````^XD!`!8````.B@$`#0```"6*`0`,````,XH!`!D```!`B@$`)P```%J*
M`0`/````@HH!`"(```"2B@$`*P```+6*`0`1````X8H!``X```#SB@$`'```
M``*+`0`'````'XL!`!`````GBP$`%````#B+`0`+````38L!``H```!9BP$`
M"@```&2+`0`'````;XL!``D```!WBP$`"````(&+`0`)````BHL!``X```"4
MBP$`#@```*.+`0`%````LHL!``\```"XBP$`#````,B+`0`,````U8L!``T`
M``#BBP$`&@```/"+`0`+````"XP!``,````7C`$`!````!N,`0`&````((P!
M``@````GC`$`!@```#",`0!4````-XP!`"@```",C`$`,P```+6,`0`5````
MZ8P!``4```#_C`$`!`````6-`0`*````"HT!``H````5C0$`!P```""-`0`*
M````*(T!`!4````SC0$`#````$F-`0`*````5HT!``P```!AC0$`"````&Z-
M`0`&````=XT!``<```!^C0$`!@```(:-`0`5````C8T!``D```"CC0$`!0``
M`*V-`0`'````LXT!`"(```"[C0$`!@```-Z-`0`5````Y8T!`!@```#[C0$`
M"P```!2.`0`'````((X!`!,````HC@$`$P```#R.`0`&````4(X!`!,```!7
MC@$`"@```&N.`0`(````=HX!``8```!_C@$`"````(:.`0`0````CXX!`!@`
M``"@C@$`"````+F.`0`*````PHX!``\```#-C@$`!0```-V.`0`,````XXX!
M`!````#PC@$`"P````&/`0`#````#8\!``T````1CP$`!P```!^/`0`L````
M)X\!`"H```!4CP$`.0```'^/`0`D````N8\!`"T```#>CP$`7P````R0`0`0
M````;)`!`%<```!]D`$`-0```-60`0!:````"Y$!`%,```!FD0$`'@```+J1
M`0!"````V9$!`"`````<D@$`(P```#V2`0`A````89(!`!4```"#D@$`/P``
M`)F2`0#2`0``V9(!`!0```"LE`$`$````,&4`0!!````TI0!`'D````4E0$`
M,0```(Z5`0`\````P)4!`%,```#]E0$`3P```%&6`0`:````H98!`!````"\
ME@$`%@```,V6`0`9````Y)8!`",```#^E@$`(0```"*7`0`B````1)<!`!H`
M``!GEP$`$````(*7`0`S````DY<!`!T```#'EP$`(0```.67`0`<````!Y@!
M`"X````DF`$`70```%.8`0`Y````L9@!`%L```#KF`$`1````$>9`0`R````
MC)D!`#X```"_F0$`,@```/Z9`0!0````,9H!`&\```""F@$`70```/*:`0!1
M````4)L!`#0```"BFP$`(````->;`0`A````^)L!`",````:G`$`;P```#Z<
M`0!I````KIP!`+\````8G0$`%P```-B=`0`@````\)T!`#P````1G@$`/```
M`$Z>`0`[````BYX!`"4```#'G@$`10```.V>`0`6````,Y\!``8```!*GP$`
MQ0```%&?`0!!````%Z`!`",```!9H`$`,````'V@`0`B````KJ`!`!P```#1
MH`$`,@```.Z@`0`-````(:$!``@````OH0$`!0```#BA`0`,````/J$!``P`
M``!+H0$`#````%BA`0`+````9:$!``8```!QH0$`$@```'BA`0`$````BZ$!
M`$X```"0H0$`!0```-^A`0`4````Y:$!``0```#ZH0$`!P```/^A`0`%````
M!Z(!``4````-H@$``P```!.B`0`2````%Z(!``D````JH@$`$@```#2B`0`1
M````1Z(!``(```!9H@$`!0```%RB`0`'````8J(!`!,```!JH@$`#````'ZB
M`0`7````BZ(!``8```"CH@$`$0```*JB`0`-````O*(!``,```#*H@$`,@``
M`,ZB`0`$`````:,!``8````&HP$`!P````VC`0`<````%:,!`"T````RHP$`
M+@```&"C`0`O````CZ,!`!,```"_HP$`'@```-.C`0`7````\J,!`!L````*
MI`$`'@```":D`0`9````1:0!`!H```!?I`$`'@```'JD`0`6````F:0!`"D`
M``"PI`$`'P```-JD`0`G````^J0!`!<````BI0$`&P```#JE`0`=````5J4!
M`!@```!TI0$`)````(VE`0`F````LJ4!`"<```#9I0$`%P````&F`0`8````
M&:8!`!P````RI@$`(@```$^F`0`7````<J8!`!X```"*I@$`&@```*FF`0`^
M````Q*8!`"0````#IP$`)P```"BG`0`J````4*<!`"L```![IP$`)0```*>G
M`0`;````S:<!`"````#IIP$`'0````JH`0`P````**@!`!T```!9J`$`"@``
M`'>H`0`6````@J@!`!(```"9J`$`*````*RH`0`=````U:@!``T```#SJ`$`
M#P````&I`0`9````$:D!`!`````KJ0$`&P```#RI`0`Q````6*D!``@```"*
MJ0$`"@```).I`0`B````GJD!`"8```#!J0$`)0```.BI`0`9````#JH!``<`
M```HJ@$`P@```#"J`0`:````\ZH!`!4````.JP$`"````"2K`0`,````+:L!
M`!0````ZJP$`&@```$^K`0`%````:JL!`#4```!PJP$`%````*:K`0`4````
MNZL!``<```#0JP$`"@```-BK`0`*````XZL!`$````#NJP$`)0```"^L`0`2
M````5:P!`!4```!HK`$`#P```'ZL`0`R````CJP!``T```#!K`$`#@```,^L
M`0`/````WJP!`!@```#NK`$`"@````>M`0`/````$JT!``4````BK0$`'P``
M`"BM`0`*````2*T!`!\```!3K0$`"````'.M`0`5````?*T!``<```"2K0$`
M"````)JM`0`*````HZT!`#L```"NK0$`!0```.JM`0`-````\*T!``H```#^
MK0$`$`````FN`0`&````&JX!``H````AK@$`!P```"RN`0`2````-*X!``P`
M``!'K@$`'0```%2N`0`3````<JX!`!X```"&K@$`,@```*6N`0`%````V*X!
M``8```#>K@$`'````.6N`0`$`````J\!`"H````'KP$`$````#*O`0`%````
M0Z\!``,```!)KP$`#````$VO`0`7````6J\!``L```!RKP$``P```'ZO`0`*
M````@J\!``@```"-KP$`"P```):O`0`.````HJ\!``\```"QKP$`$0```,&O
M`0`2````TZ\!``H```#FKP$`,````/&O`0`;````(K`!`!@````^L`$`"@``
M`%>P`0!(````8K`!``@```"KL`$`%@```+2P`0!"````R[`!`!0````.L0$`
M#P```".Q`0`)````,[$!``0````]L0$`!@```$*Q`0`6````2;$!`!H```!@
ML0$`!P```'NQ`0`(````@[$!``@```",L0$``@```)6Q`0`)````F+$!``L`
M``"BL0$`!0```*ZQ`0`:````M+$!`"8```#/L0$`%0```/:Q`0`>````#+(!
M`!$````KL@$``@```#VR`0`$````0+(!``\```!%L@$`!@```%6R`0`%````
M7+(!``0```!BL@$`%````&>R`0!)````?+(!`!$```#&L@$`)0```-BR`0`O
M````_K(!`%@````NLP$`$0```(>S`0!I````F;,!`!\````#M`$`/````".T
M`0`F````8+0!`#D```"'M`$`+@```,&T`0`G````\+0!`#4````8M0$`,0``
M`$ZU`0`Q````@+4!`#4```"RM0$`+0```.BU`0`?````%K8!`#8````VM@$`
M&@```&VV`0`.````B+8!``P```"7M@$`<P```*2V`0`&````&+<!`'4````?
MMP$`:@```)6W`0`K`````+@!`!`````LN`$`%@```#VX`0`+````5+@!`!H`
M``!@N`$`-0```'NX`0`;````L;@!`!4```#-N`$`5P```..X`0`7````.[D!
M``H```!3N0$`!0```%ZY`0`&````9+D!``@```!KN0$`!0```'2Y`0`4````
M>KD!`!````"/N0$`%@```*"Y`0`@````M[D!``L```#8N0$`"````.2Y`0`$
M````[;D!``H```#RN0$`"P```/VY`0`(````";H!``<````2N@$`%P```!JZ
M`0`&````,KH!``8````YN@$`%P```$"Z`0`+````6+H!``<```!DN@$`$@``
M`&RZ`0`(````?[H!`!<```"(N@$`#0```*"Z`0`-````KKH!``8```"\N@$`
M!@```,.Z`0`/````RKH!``<```#:N@$`!0```.*Z`0`4````Z+H!``(```#]
MN@$`!`````"[`0`,````!;L!``D````2NP$`(@```!R[`0`"````/[L!`!(`
M``!"NP$`&````%6[`0`+````;KL!``4```!ZNP$`#````("[`0`*````C;L!
M``\```"8NP$`%@```*B[`0`%````O[L!``T```#%NP$`)P```-.[`0`.````
M^[L!``\````*O`$`$````!J\`0`%````*[P!``(````QO`$`"P```#2\`0`!
M````XP```*D!``!;````4`$``+@"```A!0``-P8```T#``!0`P``]04`````
M```^!@``[P4``%P``````````````&D#```@!```5@4``+L%``!)`0``*@$`
M````````````G`(``*8%````````]P```-8%``!W!````````-P$``#"!0``
ML````!<!```Y!```VP0``#4````:!@``D````$4!```8`0``B@$``%`%``"5
M!```HP``````````````,@$````````N`@````````````!S`0``````````
M``!C!@`````````````````````````````R````>@4``%($````````````
M`&H!```\!```)P0```````!;`0``<04````````N!@``[`4``&$&``#W`0``
M<0$```````````````````\!``!W`@``P`$``&L#```````````````````N
M!0```````&L$```N````]@0``%,#``"/````:P4`````````````)`,``!8"
M````````D0```$,!``!5`0``^@$``````````````````%$"``"-!0``I0,`
M``````#Q````;0(``%D&``!_`@```````%H#``"(`P``-@8``,P!````````
M`````(L"````````)P```(@!```:`P``H`(``$L!``!P````<@0``&\!````
M````M@,````````H`0``^@4``!D!``"L`0```````%@#``!9`P``6@4``-8$
M```U!0``#@```'`$``!,`@```````"L!```%!0``PP(``$H&```S`P``1P``
M`-L!``!:`0``^P0``$X```#F````9@8````!````````UP(``,(#```F!0``
M8P(``&D$``"(!0````````````#U`@``_`0``,,#```:`@```````'H$```6
M!0``&P```%\$```L````A04``,D$``#/`0``,@8``)@&``#0`@```````+\`
M`````````````"D"````````>0(``*,$````````<0````````"_`@``EP``
M```````Z````>@8``&0```"7!0```````)@%````````!`0``)L%```O````
M!@,```````"*````X`4``,@```!-```````````````A`@``O@0`````````
M````@@$``)\!````````O@````\"``#$`@````````X"``"6!@```00```(&
M````````7`(``$0&````````5`,```4````E`0``.P$```````!H`P``UP4`
M```````^`````````$T!``!E`P```````,@%````````J`,```````"W!```
M"P0``````````````````$\$``"$`@``2P,````````^`0```````%T$``!P
M`0``L00```````!\`0``-0,```````#[`@``\`(``/<$``#(`@``G0````$&
M````````*`,``+D```#$!0``SP(``.X!``#>`0``+0,``,`%``!O````````
M`*L$``!2!@``Q`0``!D````X!0```````,`#```@`@``-0(```````!'`@``
M<00```````"=`P``#04``$8$``!:!```J00````````%`P``H@(``&,#``!]
M`@``900``'<#````````>`,``!0#``#*`@``L@0``'P&```F`0``V@(``"@%
M``"Z!0``7`0`````````````P0```)X```!E`0```````.H"``!!!@``NP(`
M``````"[`0``5`````,$``#.`0```````"<"``!'!0``Z00```````#<`0``
M````````````````3@(```````#T````0`0````````V`0``=@(``'T&````
M````Q@$`````````````&`0``%L%``"7`0``T@$``'@`````````'````#L#
M``#A`0``G00``#`%``````````````````#H`@``0P8````````%!```````
M`&0&``#8`0```````(X#````````%0,`````````````=00``'T```!K`@``
MH00``,(````0!@``A00``(H$````````B`8``#\!````````60$```````"`
M`@``X`$``(4!``#V`0```P(``'0#``"N!0``K`,``.<!``#6````#`(``-D$
M``!#`````````(D#``!-`P``S`(``(`#```"!```%04``"4%``"1!```````
M``````"6`@``UP,``*L"``#<!0``E`8``&````"D`@``P`0``$,#``"J!```
M`````!<#````````$`$``*L#``!Y````"0```)H%`````````````(``````
M````)P4``#T%``!;`@``H04``+`!``!$````*P```#H"``!7`@``904``/$$
M``"_!0``:@4``,4```!N`P``"P(``$8&````````#@0``#H$``#G````````
M`/4#``",`P````````0!`````````0(``#<%````````J0```%@&```2!0``
M`````"T&``!B!0```````&H```#4````^P4```````"%`P``&08```@#````
M````````````````````B08``-,!```4````T`0`````````````?P4``&H$
M``#W`P``^P,```````"'!```S`4``!$!```^!0```````'\!````````+`(`
M`"$&```3````[@0``%(%``"N!```F@(``+0!```O!@```````-T%```B````
M+`,``%P#``!.!````````,0#```<!````````"8```#7!````````(P&````
M````O0```)($``!+`@``+@,```````#V`P``?P,``(0%``"@!0``:P8``.`#
M``!^`P``&0,```````#T`@``Y@4``,L"````````4P(````````'!0``@@0`
M`"$#```7!0``*08``%0&````````IP````````#I`@``MP$``)$"``"1!0``
M`````-H```!A````%`8````&``!J`@``#@$``-,"``#B````_00``$P```#A
M````,`(```````"=`@```````.$"``!P!@``)0(``-L````U!```C@8``!$#
M``"W!0``>P```+`$````````^P$``.0$``#%`@``5`(```````";`0``?`(`
M`.L"````````Z`,`````````````#`8```````````````````````"T!0``
M(00`````````````2P````````#X!```#@,`````````````.04``*(#```7
M!```S@4``.P$``#=````R`$```````#5!```,@4``(T```!6!```@`$``,@$
M``"!`0``3@$``&X!``#X`0``GP4``!\#````````A````%\```!T`0``300`
M`#$&``#J!````````"(%``#S!`````````<#``!]`P``R@,``+,$````````
M6`(``+,```#-`0``9@0``#8"```'`@``<P8``/8%``#0`P``4@,`````````
M````A`0```````!9````7P8```````!@!0``````````````````^P```#@!
M```?!@``.P8``$4%``#'!0``H0$```L&``"B`0``,P(``!L%````````J@``
M`#D&``#P`P``)@,``.,"`````````````)P%``#&`P``U`,``((%```3`P``
M\0$``$`%``#*!0``EP0````````L`0``30(``#4!``!+!@``,0(`````````
M````I@0``/$"``!J`P``V0(``'P%``"N````FP0``+(%````````'@0``'P#
M``"B!```C00```````"<`0```````',"``#M`P``0``````````P`P``V04`
M`)D#````````3P```(8"```,````/08``#,!````````3`0``)T%``#*````
M;@0``'(!``#4`@``>P$```0#``!@`@``2`0``-8#``#,!```+P$```````#L
M`````````$0%``!H!@``E08``,($``#P!```+0$``-\%````````;`0`````
M```\`P```````#,%``#F!```W@```-\"``!1!0``0@0``)@`````````Z@,`
M`"H"``#T`0```````'T%``!F`@``G@4``"@"``"D!0```````$0"``",`0``
MA`$``%X"``"\!```%`(```0&``!]!```<`(``.X%``"6!```AP(```````#R
M!0`````````````L!````````"H&```]!```8`0``'(%```:````_@,``.8!
M`````````````````````````````%4$````````$@0``&P!``"&!@``&@4`
M``````#5!0``O@4`````````````1`0``#8$``"+````GP```,0!````````
M"08``!<````*!0```````-X#``!0`@``-P(``*L!``#1!```_0(``,,$```*
M!@``9P8``#T!```;!@```````#L$``````````````````"U`0``$`(`````
M```"````800```````#_!```R04```````"/`@``;08``$(&``"E!```B0``
M```#``".`0````````````#S````DP0``)(%``!B`@````````````!F!0``
M(P8``/\`````````M`(``#8````Y`0``C@0```````!'!```````````````
M``````````````"Z!```W@(``(X`````````U0$``$4#```'````````````
M``"-`P``'0$``"`#```M````D`,```````#+`P``?P```#\&``"V!```8`$`
M`)H#``!Z`P``A@4``(<```"(`````````+4#``"0!```8`8````````Z`0``
M``````````"0`@``20,``),&```1!0````````````!V````G@(``)0```!D
M`0``^@```-0$```+`P```P```,("``"0!0``N`$```P#``!*`````````'X"
M`````````````&@$``!T`````````'L"```E!````````%L&``#A`P``'08`
M``````!=!@``%08``'0$``#2!```P0$``!8&``!N!0``[`,``)\#``#9`0``
M`````&0"``!E````,0,``!X!``"9`0``[@(``/("````````.P4```````"I
M`P``?@8``#L"``!+!0``Z`0```````!3!@```````&<$```(`0``3P,``'X$
M``"O`@```````%<!```^`P``#0(```````#/!0``9@$``#$%````````_@(`
M`&($``!E!@```````%4`````````WP0``#0```!!````40,`````````````
M=`(``$<#``#J````C0$``/@#````````$`4``````````````````-$````W
M`0``)`4``)`!``#5````<0,``&D&``#3!```%00```````"O!0``0@4`````
M``#K`0``&`4``+\!``"9!@```````'\&``"5!0``ZP`````````"`0``'P0`
M`.<$``!U`0``J`0`````````````9`0```4!```=`@```````'4#``"R````
M`````($"````````4P```.\!``!$`0``@P(``'4&``!(`@``KP0``,X#```@
M`0````````````"]!```^00````````D`@``^`4```````#C!0``8P$``(L%
M``#N````Z@$``+\$```I!0``$@(```4&``"W`P```````(T&``!L!@``F04`
M`(H"```,!0```````/T#````````L0```&@%````````O````,@#````````
M`````+D%````````W0(``+$%``#+!````````"L$``!G!0``P00``",%````
M````;@```!<"`````````````%H```#I`````````/(```"R`0``0`$``!T$
M`````````````(8#``#@````.P```*@"``#`````Q``````````Y````````
M`!,%``"@`P``'@4``/@``````````````*`$````````7@$``"X$``#)`P``
M,0$``&(````_!0``$@```&(&````````U@(``$P&``#@!```70,````````1
M````/````$H$``#3`P```````*<%`````````````'<%``#A!0```````'D&
M```Y`@```````%T```!M!0```````&T```#6`0```````-0!``#E!```````
M````````````!P$```````#E````5P4``(4`````````*@,``%<`````````
M_@4``)4"``#Y`P````````````!1!@``(`4``.@```"\`@``I`$``+4%```*
M````G@0``-`!````````K`(```````"[`P``]`,``#<#`````````````%L#
M``#G`@``VP,``&0#```I`P``-`4``.("``"U!```_`$``"`````R!```N`4`
M`/8```"L````CP$``'`%````````#P4`````````````&04``!,"````````
M4````*<"````````704`````````````P0(``'L$``#O`@```````*,!```9
M!```\P$````%``!U````DP```+P!````````D@,``#0$``"$!@```````!L!
M``#*!```PP$``",`````````J04``%(!````````2@4``!$$``"4!0``=04`
M````````````4`0``"L&```E!@``@P,``+\#```-!```HP4```````"2!@``
M`````.0"``"F`0``K00```````!X!@``M`0``)0"```#!0``#0```$$"```T
M!@`````````````D````90(``)H&````````:04``(X%``""`@``'P(``!,&
M````````R@$``````````````````(`&``!U`@``5P8``*\#``#-!0``>@$`
M`'8%````````:0(``((#``"#`````````*$#````````KP````````"\!0``
MQ0,```````#_!0``EP8```H"````````10(```````"^`P``;@8``.4"```&
M!0```````)(!``#J!0``,`0```L```"8`@```````/````"+`P``1@,``(H%
M````````O04``%P&``"$`P```P,``-D#``!``@``"`````````"8`P``````
M`*T"```$`@``O`,``````````````````&<`````````*0$``&@!``#,`P``
M`````#$```#=`0``3`4``!X`````````;0,``)(```!5!@``.````!@"``!7
M!```"0(``'("````````````````````````+P0``*H%``#K!0``C`(`````
M````````304``%$$```W````&P,``$D&````````*P,``$\%```;`@``K0,`
M`$,"``!O!```70$``'8&``"Z`@``=@,```$!``!\!```````````````````
MW@0`````````````<@8``!4``````````````+$#```3`0````````@%````
M``````````````"6!0``D08``)L"``#'`@``S@(``"H%``#3!0```````.@%
M``!&`0``>`(``+0```#+`0``UP$``,<```"S`P``7P(``&<"``#_`@``:@8`
M`(\$```J!```B04``&`#````````M@````````"D`P``\P,``"H```"U````
M(`8``"4````+`0``)`8``%X%``!>!@```````+H#````````*P(``/T!```;
M!```Q0$```````"G!```>`4``(H#````````.@4```\&``"/!@``M`,`````
M````````/P0```````!%!````````!8!``!^`````````,`"``#D!0``GP0`
M`',%``#O````@`4``&<!```B`0``C`4``$D`````````@00``'8!``"]`0``
MQ@0```````"H`````P$``*$`````````%0$````````S!@````````@"````
M````/`$``````````````````*$"``"?`@``+04``,(!``!A`0```````),!
M``"^`@``>04```````````````````8```!S!```&@$```````#C`P``````
M`"(#``![`P``L0$``!(&`````````````'(```!A!0``C````/P"``"F````
M'P4``-@%`````````````!$"`````````````)4````<`P``R0$```\```!)
M!```3P8``#@#``!B`0``A0(``$(#``!L`P``BP$``#,```!T!0``7@,``#\`
M```Z!@```````/H"``"X`P``2P0``%8#``#-````40$``$`#````````?```
M`'8$``#<`P`````````````)!```L`,``.D%``#+``````````````"B````
M`````"\%``"E`0````````````"8!```T`4``',#``#'`0``%`4``+`%``"Y
M`0``X@0```````!N`@``0@(`````````````T@```#("``#M!0``.`(``$D%
M``!(`0``00$``$@```":````5P,``!4"``!?`0``Q@4``*X#``"3`P``````
M`+,!``!Y`0````````(#``#<`@``K0```.4!``!B`P``"@,```X%``"@````
M_`4```````"V`@``WP```#8%`````````````&$#```0`P``[0$``"$!````
M````T````(,!``"W`@``'04```````"1`0``F00``"0!``!<!0``2`,``%("
M``#5`P```````-("`````````````#4&``"I`@```````%0$``!O`P``````
M`"0$``#M!````````,X```!%!@``0@```/X!``"F`P```````)$#``#G`P``
M5@8``)0#``#1`0``&`````````!<`0``%P8``"<#```)`P``F`$``-\#```,
M!````````)0!``!"`0```````$<!````````-P0``-H!```?`0``0P0``",!
M``"U`@```````&,$``#C`0``3P(```(%``#-`P```````/\#````````U`4`
M`(D!```=`P``Y@(``-@#``!8!0``F0```$$$``"K!0```````+D"``!.`P``
M004``+T#``!/`0``F@$``$@&``"L!0``9P,`````````````^0(``*<!````
M````"`0``)4#```?`````````(D$``#\``````````````"6````80(``/$#
M``#]````0P4``'D#``!K`0``'`8``,$%``#1!0````````<&``"9`@``C`0`
M`(\#````````DP(``'<```"#!@``>@(``%D"```P````.@,``($```"[````
M>P8``/X$```_`P```````%$```#R`0``V@0``#T````S!```<`,``/@"````
M`````````(@$``!I````7P4``+<```!8!````````)L#````````D@(``%8`
M``![!0``6P0```````"X!```(0```.0!`````````````'$&```(!@``70(`
M`%@```#S`@``!P0``*4%``#/````2`4``-@"````````%`$``*0`````````
MG@,``'$"```)!0``ZP0``&8```"E`````@(``*T!````````;P8````````\
M!@``B`(``%`&``"#!````````!P%``#-`@``_`,``-,`````````WP$`````
M``#&````N0,`````````````E@$``#`!``!*`@``8P4```8!``"&````5`$`
M`)0$````````1P8``*L````L!@``'`$```````!L````#08``-(%```B!@``
M`````.D!``#K`P``!`4``&\%``!2````X@$``.(#``````````````````!_
M!````````&T!````````?@$``&0%``"F`@````````````#P`0```````,8"
M``#B!0``!@0```````!&`@```````$`&``"S`@``=`8``,\$````````/0(`
M`%0%```L!0``4P0``)<#````````(P,``"($```F!@``RP4``)L`````````
MJ`$``/`%```G!@``[@,``%4%``"=`0```````)P```#D`P``'@8``"X!``!-
M!@``AP8``+H!``"V`0```````/4!`````@``%@,``````````````````*H#
M``"Q`@``)P$``(<!`````````````/4```````````````````"J`@``````
M`!(!```T`@`````````````8`P``V`````````!M!```2@,``'<!``"V!0``
M*`8``.T````X!@``'@(```T!``#E!0``W````$X%```!`P```````#8#``##
M``````````````"3!0``(@(``"T"````````>`0```````":!````````(H&
M```.!@``!`````8"``#)``````````L%``!X`0``6`$``%\#``"R`@``E@,`
M````````````Z`$```D!``#9````\@,``.\#```P!@``4P$```````#_`0``
M^@0`````````````+00``.4#``````````````````"]`@``$P0``&P%```6
M`````````/X```#'!````````!H$```Y`P````````````"<!````````/D!
M``#2`P``Q00```H!``#G!0``G@$````````H!```AP4``*4"``"^`0``+P(`
M````````````'@,``/<%``"&!````````.P"````````-`$``'X%````````
MI`0`````````!````````(T"``!H`@``7@```'(#``#;!0``$`0``%4"```1
M!@``#P,``-T$``"#!0``6@(``.8#``!L`@``,@,``"8$``"C`@``````````
M``"O`0```````.,$```C`@``V@4`````````````!0(``(4&``#Y!0``PP4`
M```````^!```U0(``(L&``"[!```R0(```````"!!0``\04````````Q!```
M*P4``%H&``"P`@````````````````````````````#W`@``_04`````````
M````7@0``%8!```I`````````((```!.!@``!@8``/4$``!K````T0(``$8%
M```#!@``C@(``!D"```_`@```````&D!``"<`P``%@0````````X!```IP,`
M`*@%````````&`8`````````````@0,``,P```!*`0``1`,`````````````
M@`0``!P"``!,`0``<P````````"5`0``B0(`````````````T0,```````"J
M`0``=P8``%D%``#.!```X`(``-H#``"L!````````*`!``""!@``"@0``-@$
M```/!````````/($```=````N`````````!]`0````````````!!`P``]`4`
M``````"+!```-`,``&8#``#O!```$@,``+D$````````5@(``)<"``"M!0``
M````````````````50,```````"/!0``A@$``%D$``"!!@``)0,``,$#```I
M!```10```/,%`````````````/8"``#T!```:````,\#``#=`P``UP```%,%
M````````Z0,```````#'`P``VP(````````\!0```````&\"``#Z`P``/0,`
M`#P"```F`@``LP4```````#A!```>00``(<#``!Z````%`0``#X"``"B!0``
M#`$```````#>!0``20(``+(#````````*````,T$```0````N@```)`&````
M````(P0``/D```!C````Q04``"\#``#L`0````````````"N`0``[0(``*X"
M``#D````3`,``$8```"C`P```04````@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@
M*'EE<W1E<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60M9&%Y(&9O<F5C87-T
M`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG
M;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N
M`"5S(&%T("5S("5S`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T
M(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S
M($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L
M(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E
M;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R
M<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-
M(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$
M`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D
M;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D
M`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O
M=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O
M=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L
M=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D
M('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N
M`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`
M06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R
M;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L
M=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE
M`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`
M06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO
M;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A
M<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO
M;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P
M<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B
M80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G
M:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R
M86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U
M:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT
M:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD
M<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O
M=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S
M('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN90!"96QA<G5S`$)E;&=I
M=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K
M("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E
M='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D
M97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE
M9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A
M>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R
M=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@
M4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N
M`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E
M=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S
M(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@
M;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I
M;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN
M+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO
M;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR
M:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N
M9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R
M`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O
M;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`
M0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT
M86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@
M<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@
M4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@
M8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@
M9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S
M(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M.B`E<P!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`
M0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L
M9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#
M<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E
M;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`
M0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T
M90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O
M;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT
M`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9FEN
M:71I;VYS`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&EV97)Y
M('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO
M;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L
M;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E
M=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R
M:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L
M87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI
M8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W
M;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO
M8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N
M<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L
M=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T
M>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!5
M4DP@:&5R90!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R
M('=I=&@@96UA:6P@;65S<V%G92X`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`
M175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y
M(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y
M(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U
M=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E
M9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@
M1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E
M<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P
M>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I
M;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A
M>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R
M<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@0V]U
M;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R
M`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA
M;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&
M*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y
M;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T
M=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A
M;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H
M(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&
M<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE
M`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A
M;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E
M`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!'
M;P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K
M("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES
M=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`
M1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M
M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA
M`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A
M8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S
M:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O
M;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L
M<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES
M('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3
M964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M
M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`
M2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/
M;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G
M92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ
M`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R
M`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S
M92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF
M;P!);F9O<FUA=&EO;@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA
M9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M
M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC
M:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E
M;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T
M97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R
M="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS
M97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E
M<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R
M="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N
M="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN
M<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I
M;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!S
M:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U
M;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M
M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`
M2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU
M;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*
M=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I
M9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG
M97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER
M:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`
M2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER
M9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A
M=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A
M=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA
M<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@
M=F%L=65S`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA
M`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT
M(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R
M`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO
M=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI
M<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S
M8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,
M:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4
M:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT
M`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T
M=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A
M;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`
M36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN
M+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L
M86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD
M<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I
M=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X
M8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S
M="`V(&AO=7)S.B``36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I
M;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP
M:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M365T:&]D`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N
M96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I
M;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W
M(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG
M(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A
M=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@
M4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO
M;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#
M;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V
M92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-
M;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L
M92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`
M3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`
M3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.
M971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA
M;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T
M:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@
M0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W
M(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`
M3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG
M:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O
M('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@
M8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`
M3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P
M97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E
M9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P
M;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO
M(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB
M97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H
M92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S
M:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E
M(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N
M9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD
M<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y
M`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E
M<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;6%N`$]N
M;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@
M;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@
M4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R
M9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I
M9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S
M:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0
M($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B
M;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(
M4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3
M;F]W(%-H;W=E<G,`4$T@5"U3=&]R;7,`4%](4"!3:&5L;`!0861D:6YG`%!A
M:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`
M4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D
M>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N
M9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE
M<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE
M87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT
M97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`
M4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E
M`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T
M:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME
M>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A
M<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I
M;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN
M(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-
M96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA
M=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`
M4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`
M4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E
M<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B``4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O
M<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/<'1I
M;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT
M('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T
M92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S
M`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@
M4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!3
M86EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!3
M86UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI
M=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E($]P
M=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+@!38VEE;F-E`%-E87)C:`!396%R8V@@
M16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G
M<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E
M<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N
M96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N
M9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E
M<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!3
M97-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I
M;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME
M<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`
M4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC
M:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U
M<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ
M90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO
M=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W
M(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN
M('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M
M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!
M9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G
M:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE
M;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C
M:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H
M87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R
M;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@
M>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`
M4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I
M<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)J
M96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I
M<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I
M<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I
M;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD
M`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;7,`5%-6
M(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S
M`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E
M;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U
M<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S
M(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S
M<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N
M(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+
M(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I
M=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H
M92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y
M(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG
M=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D
M(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E
M8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@
M<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T
M96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T
M:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N
M=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G
M97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@
M=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@
M=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@
M82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L
M;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C
M,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D
M+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C
M="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL
M(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@
M9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A
M<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA
M<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U
M;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@
M8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N
M=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T
M:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN
M9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L
M90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C
M90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H
M7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O
M<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY
M*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L
M=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N
M9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET
M:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S
M<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA
M8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD
M;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N
M:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@=7-E
M<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U
M<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E
M<@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL
M(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R
M(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S
M92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T
M:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R;F%M90!5<V5R;F%M
M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N
M`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED
M(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O
M;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I
M;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET
M:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R
M=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I
M971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E
M8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER
M9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D
M869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!3
M0U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R
M;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E
M9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ
M*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E
M;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I
M;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T
M86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7
M:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7
M;W)K($%D9')E<W,`5V]R:R!0:&]N90!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N
M<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N
M=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!9
M96%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N
M;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@
M9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@
M=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L
M;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G
M*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E
M;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O
M=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C
M:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N
M97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D
M+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R
M($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`
M66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y
M.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@
M<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;
M;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E
M`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N
M+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`
M7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86QM
M`&-L:6-K(&AE<F4`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@
M)7,@)7,`:#H`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O
M<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N
M=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L
M<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``
M<W1E861Y`'1A<VL@;&ES=`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C
M;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W
M96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E=C,N,"XT"E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-2TP-BTR."`Q-#HT."LP,S`P"DQA<W0M5')A;G-L871O
M<CH@075T;VUA=&EC86QL>2!G96YE<F%T960*3&%N9W5A9V4M5&5A;3H@:3$X
M;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3D*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS
M/3$[('!L=7)A;#TP.PH`("@E<R!G_&X@]FYC92D`*$5R:?YI;2!!;F%H=&%R
M_2`E<RD`("@E<R!G_&YD92D`("AB=6?\;BD`("AY87+];BD`("AD_&XI`"!D
M92AD82D@`"5D("5S('9E("5S`"5D+6?\;FS\:R!H879A('1A:&UI;FD`)7,@
M+2!":6QD:7)I;0`E<R!087)M86L@W7II`"5S($M"`"5S($)A:_UM(-W^;&5M
M;&5R:2`M($]N87EL86UA`"5S($%Y87)L87(`)7,@1VER:?X`)7,@06YL8?YM
M82!+;_YU;&QA<OT`)7,@>F%T96X@=F%R+@`E<R!D92`E<R`E<P`E<R!I<W1E
M;FUE:W1E9&ER+@`E<R!D86MI:V$`)7,@8G5L=6YA;6%D_2X`)7,@+2`E<R`O
M("5S(``E<R!!9')E<R!$969T97)I`"5S(%1A:W9I;0`E<R!.;W0@1&5F=&5R
M:0`E<R!']G)E=B!,:7-T97-I`"5S.B`E<P`L(&;]<G3];F%L_2`E<R`E<P`L
M(&1E\&G^:6T@)7,@+3X@)7,`+2T@4V7G("TM`#$R(%-A871L:6L@6F%M86X@
M0FGG:6UI`#(T(%-A871L:6L@6F%M86X@0FGG:6UI`#(T('-A870`0G4@]F)E
M:R!IYVEN('9E<FET86)A;OT@<V]N('5Z86YT_7/](&=E<F5K;65K=&5D:7(N
M`$]N=6QM87H@8FER(&AA=&$@;VQU_G1U`-UL971I>6D@_FEF<F5L97EE8FEL
M;65K(&GG:6X@4$=0(&'G_6L@86YA:'1A<OT@9V5R96MM96MT961I<BX`W6UZ
M86QA;FW]_B!I;&5T:7EI(&1O\')U;'7P=6YU('-A\&QA;6%K(&GG:6X@4$=0
M(&'G_6L@86YA:'1A<OT@9V5R96MM96MT961I<BX`W6QE=&EN:6X@_FEF<F5S
M:6YI(.?V>FUE:R!IYVEN(&'G_6L@4$=0(&%N86AT87+]+/9Z96P@4$=0(&%N
M86AT87+]('9E(&=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=;&5T
M:7EI(&EM>F%L86UA:R!IYVEN(&'G_6L@4$=0(&%N86AT87+]+/9Z96P@4$=0
M(&%N86AT87+]('9E(&=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=
M;&5T:6YI;B#^:69R97-I;FD@Y_9Z;65K(&GG:6X@8>?]:R!3+TU)344@86YA
M:'1A<OTL(/9Z96P@4R]-24U%(&%N86AT87+]('9E(&=EYVG^('3\;6-E8VGP
M:2!G97)E:VUE:W1E9&ER+@#=;&5T:7EI(&EM>F%L86UA:R!IYVEN(&'G_6L@
M4R]-24U%(&%N86AT87+]+"#V>F5L(%,O34E-12!A;F%H=&%R_2!V92!G9>=I
M_B!T_&UC96-I\&D@9V5R96MM96MT961I<BX`W6QE=&EY:2#^:69R96QE>65B
M:6QM96L@:>=I;B!AY_UK(%--24U%(&%N86AT87+](&=E<F5K;65K=&5D:7(N
M`-;6(%EA\&UU<@#6UB!38?!N86L`UM8@2&%F:68@2V%R`-;6+]93`$%022!)
M1`!$_'IE;FQE>6EC:2!H86MK_6YD80!(86MK_6YD82XN+BX`16YA;'0`3W)T
M87EA`%9&4R!D:7II;FD@>6%R873]<FME;B!E<FG^:6T@96YG96QL96YD:2X`
M5D93(&1I>FEN:2!Y87)A=/UL_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN`$AE
M<V%P(%!A<F%L;W/]`$AE<V%P($1O;F1U<G5L9'4N`$AE<V%P;&%N_7EO<@!%
M:VQE`$%L="!'<G5P($5+;&4`06QT(-UZ:6X@14ML90!"=7)A>6$@16ML93H`
M665N:2!'<G5P($5K;&4`665N:2#=>FEN($5K;&4`665N:2!K=6QL86[]8_T@
M96ML93H`2V]L;VX@16ML90!996YI(/QY92!E:VQE`-UK:6QI($5K;&4`)7,@
M365N_'/\;OP@36]Z:6QL82!+96YA<B#'=6)U\'4@3VQA<F%K($5K;&4`061R
M97,@9&5F=&5R:6YE(&5K;&4Z`$%D<F5S(&1E9G1E<FEM92!E:VQE`$MU;&QA
M;OUC_2!%:VQE`$MU;&QA;OUC_2!E:VQE;64@<V7G:6QE;65Z(&O];/UN9/TN
M`$%D<F5S`$%D<F5S($1E9G1E<FD`6?9N971I;2TM1&GP97(@:W5L;&%N_6QA
M<B!IYVEN(&EZ:6YL97)I(&)E;&ER;&5Y:6X`6?9N971I;0!!9',`069G86YI
M<W1A;@!!<FYA=G5T;'5K`$-E>F%Y:7(`UG1E:VD@860`2&EZ86QA`$AI>F%L
M86UA:SH`5/QM_`!4_&T@1&_P<G5L86YM_?X@2W5L;&%N_6/];&%R`%3\;2!'
M<G5P;&%R`%3\;2#=>FEN;&5R`%3\;2!D]G)T('G\>@#';VML=2!A9')E<VQE
M<F4@:7II;B!V97(`4_UR86QA;FW]_B!L:7-T92!T_'+\;OP@87EA<FQA;6%Y
M82!I>FEN('9E<FEL<VEN(&UI/P!:871E;B!V87(`UG1E:VD@24U34"!':7)I
M_FD`UG1E:VD@24U34"!087)O;&%S_0#6=&5K:2!)35-0($MU;&QA;OUC_2!!
M9/T`UG1E:VD@96QE:W1R;VYI:R!P;W-T82!A9')E<VD`UG1E:VD@=&%S;&%K
M;&%R`-9T96MI(&UE=&EN.@!!;65R:6MA;B!386UO80!'9>=E<G-I>B!D9?!E
M<B!B96QI<G1I;&1I+@!!;F1O<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;2!0
M<F]X>0!#979A<`!!;G1A<G1I:V$`06YT:6=U82!V92!"87)B=61A`%5Y9W5L
M86UA`%5Y9W5L86UA($QI<W1E<VD`57EG=6QA;6$@2&%Z_7(`06QT('!A>6QA
M_OUM;&%R82!U>6=U;&$`3VYA>6QA`%EA:VQA_OUK($)O>75T`$YI<V%N`$%R
M87#G82`H5VEN9&]W<RTQ,C4V*0!"96QG96QI:R!$;W-Y82!"=7EU='4`0F5L
M9V5L:6L@063]`"5S(&GG:6X@9VER:?X@:7-T9?!I;FD@:V%L9/UR;6%K(&ES
M=&5D:?!I;GIE(&5M:6X@;6ES:6YI>C\`07)J86YT:6X`17)M96YI<W1A;@!%
M<FUE;FEC92`H05)-4T-)22TX*0!386YA=`!!<G5B80!!<V-E;G-I;VX@061A
M;&%R_0!!<V-I:2!386YA=/T`07-Y82]087-I9FEK($+V;&=E<VD`0F%K_6T@
M:?YL96UL97)I;F1E;B#V;F-E(&1O\')U;&%M82!S;W)U;'-U;B!M=3\`071A
M;6$@2V]L;VYL87+]`%9A<B!O;&UA>6%N(&)I<B!G<G5B=2!S:6QM92!G:7)I
M_FEM:2X`5F%R(&]L;6%Y86X@8FER(&EZ;FD@<VEL;64@9VER:?YI;6DN`%9A
M<B!O;&UA>6%N(&)I<B!G<G5B=2!D_'IE;FQE;64@9VER:?YI;6DN`%9A<B!O
M;&UA>6%N(&)I<B!P87EL8?[];?T@9/QZ96YL96UE(&=I<FG^:6UI+@#6>FYI
M=&5L:6ML97(`0?!U<W1O<P!!=G5S='5R86QY80!!=G5S='5R>6$`075T:%]C
M>7)S<6PZ(-US=&5N96X@:6UA<"!U>F%T873]<_T@8G5L=6YA;6%D_2X`075T
M:%]C>7)U<SH@W7-T96YE;B!Y971E;F5K;&5R92!S86AI<"!D9?!I;"X`075T
M:%]C>7)U<SH@W7-T96YE;B!I;6%P('5Z86YT_7/](&)U;'5N86UA9/TN`$%U
M=&A?9G1P.B#=<W1E;F5N($944"!U>F%N=/US_2!B=6QU;F%M863]+B!02%`G
M>6D@+2UE;F%B;&4M9G1P('-W:71C:"!D9?!I_G1I<F=E<VEY;&4@9&5R;&5Y
M:6XN`$%U=&A?:6UA<#H@W7-T96YE;B!)34%0('5Z86YT_7/](&)U;'5N86UA
M9/TN`$%U=&A?:W)B-3H@W7-T96YE;B!K<F(U('5Z86YT_7/](&)U;'5N86UA
M9/TN`$%U=&A?;&1A<#H@W7-T96YE;B!,1$%0('5Z86YT_7/](&)U;'5N86UA
M9/TN`$%U=&A?:6UA<#H@)7,@:W5L;&%N_6/]<_T@96ML96YE;65D:2X@4W5N
M=6-U.B``075T:%]L9&%P.B`E<R!K=6QL86[]8_US_2!S:6QI;F5M961I`$%U
M=&A?;&1A<#H@)7,@:W5L;&%N_6/]<_T@9_QN8V5L;&5N96UE9&D`075T:%]M
M8V%L.B#=<W1E;F5N($U#04P@=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]S
M;6)A=71H.B#=<W1E;F5N('-M8F%U=&@@=7IA;G3]<_T@8G5L=6YA;6%D_2X`
M1&_P<G5L86UA(&)A_F%R_7/]>B!O;&1U+@!$;_!R=6QA;6$@8F'^87+]<_UZ
M(&]L9'4N("5S`$1O\')U;&%M82!2041)55,@<W5N=6-U<W4@=&%R86;];F1A
M;B!G97)I(.=E=G)I;&1I+@!&5%`@<W5N=6-U<W5N82!D;_!R=6QA;6$@8F'^
M87+]<_UZ(&]L9'4N`$MU;&QA;OUL_7(@86QA;FQA<CH`07IE<F)A>6-A;@!"
M3T9(($'G_6ML86UA;&%R_0!!<G1A;&%N`$%R=&%L86X@4F5N9VD`2_9T_"!K
M97)B97)O<R!P87)O;&%S_2X`2_9T_"!K97)B97)O<R!K=6QL86[]8_T@863]
M+@!"86AA;6%L87(`0F%H<F5Y;@!"86QT_6L@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D9?X`0F%R8F%D;W,`5&%B86X@YVEZ9VES:0!"97EA>B!2=7-Y80!"96SG
M:6MA`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!$;_!U;6?\;OP`57EG
M=6QA;6$@(B5S(B!S86AI<"!O;&1U\'4@(B5S(B#V8F7P:2!B=6QU;F%M863]
M+@#68F5K($%Y87)L87+]`-9B96L@5/QR_`!+;WEU`$)O;&EV>6$`665R(-UM
M;&5R:0!3_6[]<@!3_6[]<B!+86S];FS]\/TZ`%/];OUR;&%R`$)O<VYA($AE
M<G-E:P!(97(@26MI<VD`0F]T<W9A;F$`06QT`$)O=79E="!!9&%L87+]`$)R
M97II;'EA`$)R:71A;GEA($AI;G0@3VMY86YU<W4@0O9L9V5S:0!"<G5N96D`
M0G5L9V%R:7-T86X`36%D9&4@W6UL:2!,:7-T90!"=7)K:6YA($9A<V\`0G5R
M=6YD:0!#35,`0U)3`$-23"!$8?#]=/UM($YO:W1A;&%R_0!?2/QC<F4@UGIE
M;&QI:VQE<FDN+BX`5&%K=FEM`$1U<F=U;@!+86UB;^=Y80!+86UE<G5N`%!A
M<F]L82#V>F1E=FEN:6UL:2!O;&%R86L@<_UF_7)L86YA;6%M86MT863]<BP@
M;/QT9F5N('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BX`24U!4"!S=6YU8W5S=6YA
M(&)A\&QA;OUL863].B`E<P!+86YA9&$`W7!T86P`4V]R=6X@4F%P;W)U;G4@
MW7!T86P@170`(B5S(B!D;W-Y87/]('-I;&EN96UE9&DN`$=EYVEC:2!D:7II
M;B!B=6QU;F%M863]+@`G=&%R9V5T1FEL92<@9&7P:?YT:7)G97-I(&]L;6%D
M86X@9&5V86T@961I;&5M97HN`"(E<R(@9&EZ:6YI(&MA;&3]<OUL86UA9/TN
M`$MA;&3]<OUL86UA9/T@+"5D(&%L="!Y87#]('9A<BX`665N:61E;B!D_'IE
M;FQE;65D:2P@>65N:61E;B!D_'IE;FQE;64@:>=I;B!S8?!L86YA;B!K87G]
M=&QA<OUN('-A>?US_2!I;&4@9&5P;VQA;FW]_B!O;&%N;&%R_6X@<V%Y_7/]
M(&7^;&7^;65M96MT961I<BX`0F5L:7)T:6QM:?X@;G5M87)A>6$@:6QE=&D@
M>?9N;&5N9&ER:6QE;65D:2X`0V%P92!697)D90!"8?YL_6L`2V%T96=O<FEL
M97(@=F4@171I:V5T;&5R`$-A>6UA;B!!9&%L87+]`$-E<"!496QE9F]N=0!(
M_&-R92#6>F5L;&EK;&5R:0!(_&-R92!Y87-T_6ML86UA<_TZ`$C\8W)E(-9Z
M96QL:6ML97)I`$C\8W)E($)O_FQU:VQA<OTZ`$-E<"!496QE9F]N=0!+96QT
M:6L@*$E33RTX.#4Y+3$T*0!/<G1A`$]R=&$@069R:6MA($-U;6AU<FEY971I
M`$]R=&$@079R=7!A("A)4T\M.#@U.2TR*0!/;F%Y($)E;&=E<VD@07ER_6YT
M_6QA<OT`3VYA>2!"96QG97-I($MU<F%L;&%R_0#'860`1&7P:?YT:7(`W6YS
M86YL87+];B!S:7ID96X@9V5L96X@96QE:W1R;VYI:R!P;W-T86QA<OT@;VMU
M<FME;B!V92!C979A<&QA<FME;B!G]G)D_&ML97)I(&%D('9E(&%D<F5S:6YI
M>FD@9&7P:?YT:7)I;BX`2V%R86MT97(`0F'P;&%N=/UY_2!$95]N971L92XN
M+@#>:6QI`,=I;@!"87-I=&QE_G1I<FEL;6G^(,=I;F-E("A'0C(S,3(I`$=E
M;&5N96MS96P@QVEN8V4@*$)I9S4I`%!A<F]L82!S9>=I;@!+=6QL86[]8_T@
M863]('-EYVEN`%1A<FEH;&5R:6X@;F%S_6P@9_9S=&5R:6QE8V7P:6YI('-E
MYVEN.@!,:7-T92!":>=E;2!4_'+\;OP@4V7G:6X@*'/]<F%L86YM_?X@;&ES
M=&5L97(@:>=I;BD`0VAR:7-T;6%S($%D86QA<_T`4_UN_68@=&%N_6W](&)U
M;'5N86UA9/TZ)7,`5&5M:7IL90!-4T]F9FEC92!B:>=I;2!I;6QE<FEN:2!T
M96UI>FQE`$MU;&QA;OUC_7G]('1E;6EZ;&4Z("5S`$MU;&QA;OUC_2!T96UI
M>FQE`$MU;&QA;OUC_2!V97)I<VD@=&5M:7IL90!$979A;2!E=&UE:R!IYVEN
M('3]:VQA>?UN`$A45%`@>6]L=7EL82!#;&EC:V%T96QL`%!E;F-E<F5Y:2!+
M87!A=`!"=6QU=&QA<@!"=6QU=&QU`$-O8V]S($%D86QA<OT`2V5N87(@QW5B
M=?!U;G4@1&%R86QT`$1A<F%L=/UL;?W^(%/];OUR;&%R`$MO;&]M8FEY80!2
M96YK`%)E;FL@4V7G:6-I`%)E;FL@4V7G:6UI`$MO;&]N;&%R.@!+;VQO;B!"
M8?YL_6ML87+]`$MO;6EK`$MO;75T`$MO;75T($MA8G7P=0!!Y_UK;&%M80!/
M<G1A:R!!9/T`0V]M;W)O<P#>:7)K970`0FEL9VES87EA<FQA<@!+;_YU;&QA
M<@!987#];&%N9/UR;6$@1F%R:VQA<OT`66%P_6QA;F3]<CHE<P!087)A;&]Y
M_2!$;_!R=6QA`$MO;F=O`$1E;6]K<F%T:6L@2V]N9V\@0W5M:'5R:7EE=&D`
M0F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4N`$)A\&QA;G3](&)A_F%R_7/]>B!O
M;&1U.@!!Y_UK(&%N86AT87(@<W5N=6-U<W5N82!B8?!L86YT_2!R961D961I
M;&1I+@!!Y_UK(&%N86AT87(@<W5N=6-U<W5N82!B8?!L86YT_2!R961D961I
M;&1I+B!396)E8CH@)7,@*"5S*0!&5%`@<W5N=6-U;F$@8F'P;&%N=/T@8F'^
M87+]<_UZ(&]L9'4N`-UL971I_FEM(&YO:W1A;&%R_2!B8?YA<OUY;&$@861R
M97,@9&5F=&5R:6YI>F4@96ML96YD:2X`1&5V86T`0V]O:R!!9&%L87+]`,=E
M<F5Z`$MO<'EA;&$`4V7G:6UI($MO<'EA;&$`2V]S=&$@4FEK80!#;W1E(&0G
M279O:7)E`-UL971I(%!'4"!I;&4@_FEF<F5L96YE;65D:2X`W6QE=&D@4$=0
M(&EL92!I;7IA;&%N86UA9/TN`-UL971I(%,O34E-12!I;&4@<VEF<F5L96YE
M;65D:2X`W6QE=&D@4R]-24U%(&EL92!I;7IA;&%N86UA9/TN`-UL971I_FEM
M(&YO:W1A<_T@96ML96YE;65D:2X@)7,`3$1!4"!S=6YU8W5S=6YA(&)A\&QA
M;OUL86UA9/TN`$)A:VEY92!D96YE=&QE;F5M961I+B`E<P!$8?#]=/UM(&QI
M<W1E<VD@>6%R873];&%M863]+B`E<P!01U`@=F5R:7-I;FEN(/YI9G)E<VD@
MY_9Z_&QE;65D:2X`4R]-24U%('9E<FES:6YI;B#^:69R97-I(.?V>OQL96UE
M9&DN`-UL971I_FEM(&YO:W1A<_T@<VEL:6YE;65D:2X@)7,`1&'P_73];2!L
M:7-T97-I('-I;&EN96UE9&DN("5S`$%L_6/];OUN(&5L96MT<F]N:6L@<&]S
M=&$@861R97-I(&)E;&ER;&5N96UE9&DN`$%D<F5S(&1E9G1E<FD@=&%M86UE
M;B!G971I<FEL96UE9&DN`$1A\/UT_6T@;&ES=&5S:2!T86UA;65N(&=E=&ER
M:6QE;65D:2X`1&'P_73];2!L:7-T96QE<FEN:6X@;&ES=&5S:2!T86UA;65N
M(&=E=&ER;&5M961I+@!!;F%H=&%R('-U;G5C=7-U;F1A;B!AY_UK(&%N86AT
M87(@961I;FEL96UE9&DN`"5S(&'G_6QA;6%D_2X`36%I;G1E;F%N8V5?5&%S
M:R!B:7)I;6D@)7,@8>?];&%M863]+@`E<R!O:W5N86UA9/TN`-US=&5N96X@
M:W5L;&%N8_T@:>=I;B!P87)O;&$@<_UF_7)L86YA;6%D_2X@0F%Z_2!Y861A
M('3\;2!A>7+];G3];&%R(&1O\')U(&1E\&EL+B!996YI9&5N(&1E;F5Y:6X@
M>6%D82!D86AA(&9A>FQA('EA<F3];2!IYVEN('-I<W1E;2!Y]FYE=&EN:7IL
M92!G]G+\_OQN+@!!0TP@97)I_FEL96UE9&DN`$%D<F5S(&1E9G1E<FEN92!E
M<FG^:6QE;65D:2X@)7,`1&'P_73];2!L:7-T97-I;F4@97)I_FEL96UE9&DN
M("5S`$1A\/UT_6T@;&ES=&5L97)I;F4@97)I_FEL96UE9&DN("5S`%-U;G5C
M=6YU;B!Y971E;F5K;&5R:6YE(&5R:?YI;&5M961I+@!987#];&%N9/UR;6$@
M9V5R:2!D]FYD_'+\;&5M961I+BX`)7,@>6%P_6QA;F3]<FUA(&MA>61E9&EL
M96UE9&DN`%EE9&5K(&)I<B!Y87#];&%N9/UR;6$@:V%Y9&5D:6QE;65D:2X`
M665D96L@8FER('EA</UL86YD_7)M82!K87ED961I;&5M961I.B`E<P!9961E
M:R!Y87#];&%N9/UR;6$@9&]S>6%S_2`E<R!K87ED961I;&5M961I+@!987#]
M;&%N9/UR;6$@9&]S>6%S_2`E<R!K87ED961I;&5M961I+B!"=2!D=7)U;61A
M+"!K;V1U('1E:W)A<B`E<R!IYVEN92!K87ED971M96L@>6%D82!T86MI<"!E
M9&5N(&MO9'4@96P@:6QE("5S(&GG:6YE(&MO<'EA;&%M86LL('-EYV5N96ML
M97)I;FD@:W5L;&%N86)I;&ER<VEN:7HN`$Q$05`@<W5N=6-U<W4@87)A;F%M
M863]+@#=;&5T:?YI;2!N;VMT87/](&?\;F-E;&QE;F5M961I+B`E<P!$8?#]
M=/UM(&QI<W1E<VD@9_QN8V5L;&5N96UE9&DN("5S`$UO>FEL;&$@:V5N87(@
MYW5B=?!U(&)U;'5N86UA9/TN($ME;F%R(.=U8G7P=6YU;B!AY_UK(&]L9'7P
M=6YD86X@96UI;B!O;'5N+@!387G];&W]_B!M971I;@#<;&ME`$1E<G-L97(`
M66%R870`0F'P;&%N=/T@>6%R870`665N:2!987)A=`!!;'0@9&EZ:6X@>6%R
M870`66%R873]8_T@W7II;FQE<FD`2W)E9&D@:V%R="!N=6UA<F%S_0!(_7)V
M871I<W1A;@!+_&)A`-YU($%N9&%K:2!:86UA;@#>=2!A;F1A:VD@55),`-YU
M($%N9&%K:2!(879A($1U<G5M=0#>=2!!;F1A:VD@WF%R=&QA<CH`6?QR_')L
M_&MT96MI('-I=&EL`"5S(&4@9VER:?YT92#G86S]_F%C86L@9_9R979L97)I
M(&MI_FES96QL9?YT:7)I;@!+97,`WF7G:6QI(&]L86YL87+](&ME<P!+_6)R
M_7,`2VER:6P@*$M/23@M4BD`2VER:6P@*%=I;F1O=W,M,3(U,2D`2VER:6PO
M56MR87EN82`H2T])."U5*0#'96L@0W5M:'5R:7EE=&D`1T<`1_QN;/QK`%9E
M<FD@0?!A8_T@5&%R87G]8_US_0!487)I:`!'96QI_B!487)I:&D`5&%R:6@@
M4V7G:6UI`$?\;@!+7V]L;VYU(%-I;`!!<F%L_6L`3VYD86S]:R!S87G];&%R
M`$=I<FEN=&EY:2!!>F%L=`#6;B!T86[];6S]`-9N(%1A;OUM;/T@4F5N:P#6
M;B!486[];6S]($MI;6QI:P!486[];6QA<@!3:6P`1W)U<"!3:6P`W7II;B!3
M:6P`W6QE=&EL97)I('-I;"!V92!T96UI>FQE`$C\8W)E(%-I;`!+;VQO;B!3
M:6P`5F%R;VQA;B#V=&5K:2!T87-L8?#]('-I;`!3873]<OT@<VEL`%-EYVEL
M;6G^(&MI;6QI\&D@<VEL`-YU(&%N9&%K:2!K;VQO;G4@<VEL`-YU(&%N9&%K
M:2!S873]<OT@<VEL`%1E<VQI;2!Z86UA;OT`1&%N:6UA<FMA`%-O<G5N=2!4
M86[];6QA>?UN`$'G_6ML86UA`$%Y<OUN=/UL87(@*$%Y;OT@>F%M86YD82!(
M;W)D92=U;B!G_&YL_&L@9&]S>6%S_6[];B!IYVEN9&4I.@!!>7+];G3];&%R
M('GV;F5T:6-I(&GG:6X@9_QN;/QK(&]L87)A:R!K87ED961I;&1I+@!'96QI
M_FEM`$YE;2!-:6MT87+]`%-O;B!S86%T=&5K:2!N96T@;6EK=&%R_3H@`$YE
M;2!M:6MT87+].B``4V]L9&%N('-A\&$@>?9N;/P`4V'P9&%N('-O;&$@>?9N
M;/P`1&EZ:6X`,C0@<V%A=&QI:R!Z86UA;B!M_2!G]G-T97)I;'-I;C\`1_9R
M_&YT_&QE;64@4V7G96YE:VQE<FD`2&%V82!T86AM:6YI;FD@9_9R_&YT_&QE
M("A4048I`$?V<OQN=/QL96UE($)IYVEM:0!$_'IE;B!":6QD:7)I;6D`0VEB
M=71I`%-I;&UE>6EN`&UA:6YT96YA;F-E+G!H<"!D;W-Y87/];F$@9&_P<G5D
M86X@97)I_FUE>6EN+@#=;&L@<V%T_7(@86QA;B!A9&QA<OUN_2!IYV5R:7EO
M<B!M=3\@179E="!I<V4@8G4@:W5T=7EU('-EYVEN.@!$;VUI;FEK`$1O;6EN
M:6L@0W5M:'5R:7EE=&D`W6YD:7(`)7,@W6YD:7(`3VQU_G1U<G5L86X@>6%P
M_6QA;F3]<FUA>?T@4$A0(&)E=&GP:2!O;&%R86L@:6YD:7(N`$'^8?#](&'G
M_6S]<B!L:7-T90#=;&'G;&%R`$4M4&]S=&$`15)2`$5K=F%T;W(`1/QZ96YL
M90!";&]K($3\>F5N;&4`1W)U<"!$_'IE;FQE`-UZ:6X@1/QZ96YL90#=>FEN
M;&5R:2!$_'IE;FQE`"5S(-WG:6X@W7II;FQE<FD@1/QZ96YL90!39>=E;F5K
M;&5R:2!D_'IE;FQE.@`E<R!IYVEN(&EZ:6YL97)I(&3\>F5N;&4`1?!I=&EM
M`$W]<_UR`$5L(%-A;'9A9&]R`-;P92XN+@!%;0!%;&5K=')O;FEK(%!O<W1A
M`$5L96MT<F]N:6L@4&]S=&$@061R97-I`$5L96MT<F]N:6L@<&]S=&$@87-R
M97-L97)I(&7^;&7^;65L:2X`3VYA>6S](&5L96MT<F]N:6L@<&]S=&$`1'5Y
M9W4@<VEM9V5R;&5R:0!";_X@:6QE=&DN`$)O_B!S;VYUYRX`0F_^(&%R86UA
M('1E<FEM;&5R:0!&;W1O\')A9B!'86QE<FES:6YD96X@;65T:6YL97)I;B!I
MYV5R:7-I;F4@9_9R_&YT_"!E:VQE;64@971K:6YL9?YT:7)I;'-I;B!M:3\`
M4V'P('3]:R!IYV5R:6L@;65N_'/\(&5T:VEN;&7^=&ER:6QS:6X@;6D_`$)I
M=&G^('G];/T`1/QZ96YL97EI8VEY:2!'96YI_FQE=`!087)O;&%N_7K]('/]
M9OUR;&%M86L@:7-T961I\&EN:7ID92!S;W)U;&UA:R#\>F5R92!B:7(@9_QV
M96YL:6L@<V]R=7-U(&=I<FEN+"#6<BX@)T5V8VEL(&AA>79A;OUN_7K];B!A
M9/T@;F5D:7(_)SH`1_9R_&YT_"!A9')E<VEN:2!B=7)A>6$@9VER:6X`16MV
M871O<B!':6YE<VD`17)I=')E`$AA=&$`16QE=')O;FEK('!O<W1A(&3V;F1E
M<FUE9&4@:&%T82X`17-T;VYY80!%=&EY;W!Y80!%=&YI:P!!=G)U<&$`2&5R
M(#$U(&1A:VEK80!(97(@,B!D86MI:V$`2&5R(#,P('-A;FEY90!(97(@-2!D
M86MI:V$`2&5R($=I<FG^=&4`2&5R('EA<OUM('-A870`2&5R(&1A:VEK80#6
M<FYE:R!D9?!E<FQE<CH`QV%L_?YT_7(`1V5N:?YL970`2V5N87(@QW5B=?!U
M;G4@1V5N:?YL970`)RDG($)E:VQE;FEY;W(`4V%D92!K96QI;64@=F5Y82!A
M;/UN=/T@87)A;6$@=&5R:6UI(&)E:VQE;FEY;W(`1V7G97)L:6QI:R!3;VX@
M5&%R:6AI`-QS=`#6;B!!;&%N(%)E;F=I`$%Y87)L87(@:>=I;B!&5%`@>?QK
M;&5M97-I`%1E<F-I:&QE<FEN(&=E=&EL;65S:2!B8?YA<OUS_7HN`$Q$05`@
M<W5N=6-U<W5N82!B8?!L86YT_2!B8?YA<OUS_7HN`%--0B!S=6YU8W5S=6YA
M(&)A\&QA;G3](&)A_F%R_7/]>BX`(B5S(B!K;VYU;75N9&%N(&MO<'EA;&%M
M82!B8?YA<OUS_7HN`"(E<R(@:V]N=6UU;F$@:V]P>6%L86UA(&)A_F%R_7/]
M>BX`665N:2!305-,(&)A\&QA;G3]<_T@;VQU_G1U<G5L86UA9/TN`"(E<R(@
M:V]N=6UU;F$@=&'^_6UA(&)A_F%R_7/]>BX`57EG=6X@2&%V80!&86QK;&%N
M9"!!9&%L87+]("A-86QV:6YA*0!&87)O92!!9&%L87+]`$]N=6QM87H@2&%T
M83H`1F%K<P#>=6)A=`!(:7-S961I;&EY;W(`2&ES<V5D:6QI>6]R.B``2&%F
M:68@4V'P86YA:P!(869I9B!+87(@4V'P86YA\/T`06QA;B!M871R:7-I`$9I
M:FD`1&]S>6$@4V%Y_7/].B`E<R!D;W-Y80!$;W-Y82!387G]<_TZ("5S(&1O
M<WEA`$1O<WEA(%GV;F5T:6-I<VD`1&]S>6$@063]`$1O<WEA('-EYVEM:0!$
M;W-Y82!Y_&ML96UE`$1O<WEA('G\:VQE;64@9&5S=&5K;&5N;6EY;W(N`%/\
M>F=EYVQE<@!&:6YL86YD:7EA`-UL:R!987+]`-UL:R#'97ER96L`3W)A;OT@
M<V%B:71L90#'979I<@!+87EA;@!3:7,`)7,@9&EZ:6YI('EO:P!987K](%)E
M;F=I`%EE;65K`$?V<OQN=/QL97)I(&1E<W1E:VQE;65Y96X@=&%R87G]8_UL
M87(@:>=I;@!486AM:6X@*%1!1BD`5&%H;6EN($?\;FQE<FD@*$YO=#H@1V5R
M:2!D]F[\;&5C96ML97(@:&5M(&?\;B!H96T@9V5C92!O;&%R86L@9/9N_&QE
M8V5K.R`I8OQY_&L@8FER('-A>?T@9V5N:?X@8FER(/9B96ML92!S;VYUYVQA
M;F%C86MT_7(I`%!A<F]L86[]>OT@;?T@=6YT='5N=7H_`$9O<FUL87(`1&5Y
M:?X`1&5Y:?X@=/QR_`!$97EI_FQE<@!$97EI_FQE<B`R`$9O<G5M;&%R`%GV
M;FQE;F1I<FUE;&5R`$-U`,=E<N=E=F5L97(`1G)A;G-A`$9R86YS82P@365R
M=&]P;VQI=&%N`$9R86YS_7H@1W5Y86YA<_T`1G)A;G/]>B!0;VQI;F5Z>6%S
M_0!&<F%N<_UZ($?\;F5Y($+V;&=E<VD`2VEM9&5N`$MI;61E;@!486T@0F5T
M:6UL96UE`$1O;'5N87D`0>?]:R!!9`!'86)O;@!']G+\;G3\;&5R:6X@86S]
M;F%C8?#](&=A;&5R:0!'86QE<FDZ`$=A;6)I>6$`)7,@66%P_6QA;F3]<FUA
M<_UN_2!/;'7^='5R`$]L=?YT=7)U;&%N($MO9`!'_')C:7-T86X`06QM86YY
M80!'86YA`$-E8F5L:71A<OUK`%9E<FEL96X@060`1VET`$=O961E;`!';V]G
M;&4@07)A;6$`4VEY86@@0F5Y87H`675N86YI<W1A;@!9=6YA;F-A("A)4T\M
M.#@U.2TW*0!'<O9N;&%N9`!'<F5N861A`$=R=7`@6?9N971I;6D`1W)U<"!I
M<VEM;&5R:2!D;VQU(&]L;6%L_63]<@!'<G5P;&%R`$=U861A;'5P`$=U86T`
M1W5A=&5M86QA`$=U97)N<V5Y`$MO;G5K(-UZ:6YL97)I`$MO;G5K($1E9G1E
M<FD`1VEN90!'=6EN92!":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@<V%T
M_7)D86MI('-O;B!H_&-R97EI('-I;&UE>6D@<F5D9&5D:7EO<BX`2%1-3$%R
M96$@YVEZ96QG961E:VD@<V]N(&MO;&]N=2!S:6QM97EI(')E9&1E9&EY;W(N
M`$A434Q!<F5A(.=I>F5L9V5D96MI('-O;B!S873]<OT@<VEL;65Y:2!R961D
M961I>6]R+@!(5%10($MI;6QI:R!$96YE=&EM:2!B=6QA;F%M863]+@!(86ET
M:0!(87-H($%L9V]R:71M87/]`$AA9FEF(%-I<P!"8?YL_6L`2&5A<F0@061A
M<_T@=F4@36-$;VYA;&0@061A;&%R_0#=8G)A;FEC92`H25-/+3@X-3DM."U)
M*0!9_&MS96ML:6L`66%R9/UM`$3\>F5N;&5Y:6-I(&MU;&QA<F%K('EA<F3]
M;0!987)D_6UC_0!987+]:_QR90!$;W-Y86[];B!B8?YL86YG_6/].B``6?QK
M<V5K`%]!;F%S87EF80!6871I:V%N`$%N87-A>69A`$5V($%D<F5S:0!%=B!4
M96QE9F]N=0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M($)U(&UE<V%J(&GG:6YD92!G9>=E<G-I>B`E<R!834P@=F5R:7-I(&EL92!K
M87+^_6QA_OUL9/TZ("5S`$AO<F1E+TMO;&%B.B`E<R!N97-N97-I(&EL92!I
M;&=I;&D@8FER(&EL971I(&)U;'5N86UA9/T`2&]R9&4O2V]L86(Z("5S('3\
M<OQN9&4@:&GG(&)I<B!N97-N92`E<R!M97-A:OT@:>=I;F1E('EO:RX`2&]R
M9&4O2V]L86(Z("5S("(E<R(@8F'^87+](&EL92!S:6QI;F1I`$AO<F1E+TMO
M;&%B.B!"_'3\;FQE;64@;6]T;W)U("=D;VUX;6PG(%!(4"!U>F%N=/US_6YA
M(&EH=&EY8><@9'5Y;6%K=&%D_7(`2&]R9&4O2V]L86(Z("5S(&YE<VYE<VD@
M:>=I;B!Y96YI(%A-3"!A\&%C_2!O;'7^='5R=6QA;?UY;W(`2&]R9&4O2V]L
M86(Z(%-I;&EN96UE9&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z("5S('3\
M<OQN9&5K:2!K_7/];2!IYVEN($U)344@240@8G5L=6YA;6%D_0!(;W)D92]+
M;VQA8CH@1?YL96YE;65D:2`E<R`B)7,B.B`E<P!087EL8?[];6QA<B!E_FQE
M;F5M961I.B`E<P!":6QI;FUE>65N('!A>6QA_OUM("(E<R(`66%T87D@QVEZ
M9VD`66%T87D@>6%S=/UK;&%M80!9871A>3H`0G5R87EA(&YA<_UL(&=E;&1I
M;FEZ/R`H3/QT9F5N(')A<&]R(&5D:6XA*0!+8><@861E="!K;VQO;G4@8FER
M;&7^=&ER;65K(&ES=&EY;W)S=6YU>C\`2V'G(&%L86X@*&MO;&]N*2!V87(_
M`$MAYR!A9&5T('-A=/UR_2!B:7)L9?YT:7)M96L@:7-T:7EO<G-U;G5Z/P!.
M96T`3F5M.B``36EZ86CG_6QA<@!-86-A<FES=&%N`$E-05`@<&]S=&$@:W5T
M=7-U(&]L=?YT=7)U;&%M863].B`E<P!)34%0('!O<W1A(&MU='5S=2!S:6QI
M;F5M961I.B`E<P!)34%0('!O<W1A(&MU='5S=2!K;W1A<_T@;VQU_G1U<G5L
M86UA9/TZ("5S`$E0($%D<F5S:0!)4"!A9')E<VD@;65V8W5T(&1E\&EL+B``
M25`@061R97-I(&EZ:6X@=F5R:6QE;B!#2412(&)L;_!U(&GG:6YD92!D9?!I
M;"X`25`@:VEL:71L96UE(&EH;&%L:2X`UFY?8V5Y92!3873]<B!997)L9?YT
M:7(`W7IL86YD80!3861E8V4@4VEM9V5L97(`)7,@:>=I;B!S:6UG96QE<@!-
M971I;B!I;&4@8FER;&EK=&4@<VEM9V5L97(`2VEM;&GP:6X@863].@!%\&5R
M(&1O\')U(&?V<OQN=/QL96YE;6EY;W)S82P@>65N:2!P96YC97)E9&4@8>=M
M86L@:>=I;B!T_6ML87G];B`E<RX`1?!E<B!);G1E<FYE="!%>'!L;W)E<B!I
M;&4@<VEM9V5L97)I(&?V<F5M:7EO<G-A;OUZ(&)U(&MU='5Y=2!S9>=E<F5K
M(%!.1R!S87ED86UL_?#];OT@:V%P871M86[]>B!G97)E:VER+@!']G+\;G3\
M;&5R:2!G]G)E;6EY;W(@9F%K870@8G4@;65S86K](&?V<F5B:6QI<GEO<G-A
M;OUZ+"!Y_&ML96UE:R!I<W1E9&GP:6YI>B!G]G+\;G3\('1A<F%Y_6/];OUZ
M('1A<F%F_6YD86X@9_9S=&5R:6QE;65M96MT961I<BX`1_9R_&YT_"#6;FEZ
M;&5M90!']G+\;G3\(%523`!']G+\;G3\(%523#H`4V5R9VED96X@9_9R_&YT
M_`!397)G:61E;B!G]G+\;G3\.@!']G+\;G3\('G\:VQE;65K`$?V<OQN=/QL
M97(`W>=E<FD@06MT87(L($%D_6T@)60`W>=E<FD@86MT87+];&%N(&%L86XZ
M("5S`-WG97)I(&%K=&%R_6QA;B!A;&%N;&%R.@!3;VY?<F%Y82!3873]<B!%
M:VQE`%EA;FS]_B!E>6QE;2!K;V1U(&=I<FEL9&DN`%EA;FS]_B!K=6QL86[]
M8_T@863]('9E+W9E>6$@<&%R;VQA+@!986YL_?X@:W5L;&%N_6/](&%D_2!V
M97EA(/9T96MI(&%D<F5S+EEE;FED96X@9&5N97EI;B!V97EA(&1A:&$@9F%Z
M;&$@>6%R9/UM(&GG:6X@>?9N971I8VEN:7IL92!G]G+\_OQN+@!':7)I;G1I
M>6D@07)T=/UR`$AI;F1I<W1A;@!":7)E>7-E;"!+=6QL86[]8_UL87(`16YD
M;VYE>GEA`$)I;&=I`$)I;&=I`%-O;G)A>6$@2V]?;&]N($5K;&4`1_9R_&YT
M_"!997)L9?YT:7(`QVEZ96QG92!997)L9?YT:7(`5V5B($)A\&QA;G3]<_T@
M665R;&7^=&ER`-9N8V5Y92!+;VQO7VX@16ML90!996YI(&MO;&]N=2#^=2!A
M;F1A:VD@:V]L;VYD86X@<V]N<F$@>65R;&7^=&ER`%EE;FD@:V]L;VYU(/YU
M(&%N9&%K:2!K;VQO;F1A;B#V;F-E>64@>65R;&7^=&ER`%EE;FD@<V%T_7+]
M(/YU(&%N9&%K:2!S873]<F1A;B!S;VYR87EA('EE<FQE_G1I<@!996YI('-A
M=/UR_2#^=2!A;F1A:VD@<V%T_7)D86X@]FYC97EE('EE<FQE_G1I<@!996YI
M('!A<F%G<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@<V]N<F%Y82!Y97)L9?YT
M:7(`665N:2!P87)A9W)A9OT@_G4@86YD86MI(&3\\/QM9&5N(/9N8V5Y92!Y
M97)L9?YT:7(`UG1E:VD@=&%S;&%K('EE<FQE_G1I<@!996YI(&)I<B!P87)A
M;&]Y_2!A;&%B:6QE8V7P:6YI>B!B:7(@96QE:W1R;VYI:R!P;W-T82!A9')E
M<VD@9VER:6XZ`$C\8W)E>6D@<V]N<F%S_6YA('EE<FQE_G1I<@!(_&-R97EI
M(/9N8V5S:6YE('EE<FQE_G1I<@!+;VQO;G4@<V]N<F%S_6YA('EE<FQE_G1I
M<@!+;VQO;G4@]FYC97-I;F4@>65R;&7^=&ER`$UE<V%J(&=I<@!087)A9W)A
M9OT@<V]N<F%S_6YA('EE<FQE_G1I<@!087)A9W)A9OT@]FYC97-I;F4@>65R
M;&7^=&ER`%-A=/UR_2!S;VYR87/];F$@>65R;&7^=&ER`%-A=/UR_2#V;F-E
M<VEN92!Y97)L9?YT:7(`1_QV96YL:6L@<V]R=7-U;G5N(&-E=F%B_3H`1_9R
M_&YT_'G\(%EE<FQE_G1I<B]$9?!I_G1I<@!"8?!L86YT_2!997)L9?YT:7(O
M1&7P:?YT:7(`1&'P_73];2!L:7-T97-I(&?V;F1E<FUE:R!IYVEN('EE=&5R
M<VEZ(&MR961I+@!9971E<G-I>B!K<F5D:0!486US87G]`%1A;7-A>?T@;&ES
M=&5S:0!'9>=E<G-I>B!51$@N("A+=6QL86[]8_T@5F5R:2!"8?YL_6L@0FEL
M9VES:2D`1V7G97)S:7H@=7EG=6QA;6$N`$=EYV5R<VEZ('G]\/UN(&MI;6QI
M\&DN`$=EYV5R<VEZ('9E<FD@9_9N9&5R:6QD:2X`1V7G97)S:7H@=&5S;&EM
M(&%D<F5S:0!'9>=E<G-I>B!D;W-Y82!B:>=I;6D`1V7G97)S:7H@;7-G7W1Y
M<&4`1V7G97)S:7H@>6%D82!A=&QA;FW]_B!A<&E?:60`1V7G97)S:7H@>6%D
M82!A=&QA;FW]_B!D9?!I_G1I<F=E;&5R`$=EYV5R<VEZ(/QS="!I>FEN+@!'
M9>=E<G-I>B!I;&5T:?YI;2!K=7)A;&QA<OT`1V7G97)S:7H@<&%Y;&'^_6QA
M;B!N97-N90!'9>=E<G-I>B!K87EN86L@861R97-I+@!'9>=E<G-I>B!U;FEC
M;V1E('9E<FES:2X`4W1O:P#=<F%N(-US;&%M($-U;6AU<FEY971I`$ER86L`
MW7)L86YD80!-86X@061A($1E=FQE=&D`66%L_73];&W]_B!G]FL@9_QR_&QT
M_&S\(&;]<G3];F$`W7-R86EL`,?]:V%R86X`W71A;&EK`-UT86QY80!*86UA
M:6MA`$]C86L`2F%P;VYY80!*87!O;F-A("A)4T\M,C`R,BU*4"D`2F5R<V5Y
M`-QR9/QN`%1E;6UU>@!(87II<F%N`%EA<VQA`$]R=&%Y82!987-L80!486UA
M;65N(%EA<VQA`%-O;&$@66%S;&$`4V'P82!987-L80!+87IA:VES=&%N`-9Z
M9_QN(&]L86X@<V%K;&%N<_UN(&W]/P!+96YY80!+97)B97)O<R!S=6YU8W4@
M9&_P<G5L86UA>?T@<F5D9&5T=&DN`,=E:VER9&5K($%C96UI;&5R:0!!;F%H
M=&%R(%EA<F%T`$%N86AT87(@4&%R;6%K:7II`$%N86AT87(@57IU;FQU\'4`
M06YA:'1A<B!4:7!I`$%N86AT87(@2W5L;&%N_6W]`$'G_6L@86YA:'1A<B!S
M=6YU8W5S=6YD82!A;F%H=&%R('IA=&5N('9A<BX`QV]C=6ML87(`2VER:6)A
M=&D`2W5Z97D@2V]R90!'_&YE>2!+;W)E`$MO<F5C92`H975C+4M2*0!+=79E
M>70`2_UR9_UZ:7-T86X`4V%Y9F$@7T3\>F5N:0!$:6P`3&%O($1E;6]K<F%T
M:6,@2&%L:R!#=6UH=7)I>65T:0!3;VX@1/9R9/QN`-YI_FMI;B!!>0!3;VX@
M1_QN8V5L;&5M93H`4V]N($=I<FG^.B`E<P!3;VX@1VER:?XZ("5S(/QZ97)I
M;F1E;B`E<P!3;VX@1VER:?XZ($%S;&$`3&5T;VYY80!987-A`$3\>F5N`$AI
MYV)I<B!S_6[]<B!IYVEN(&)O_B!B_7)A:VUA`$S\8FYA;@!3;VP`4V]L(&)A
M_FS]:R!B:6QG:7-I`%-O;&1A:VD@9&7P97)L97(`3&5S;W1H;P!,:6)E<GEA
M`$QI8GEA`$QI96-H=&5N<W1E:6X`QVES96QI>6]R`$AA9FEF(%EA\&UU<@!%
M<FME;B!386%T;&5R9&4@2&%F:68@66'P;75R`$=EYR!386%T;&5R9&4@2&%F
M:68@66'P;75R`$AA9FEF(%EA\&UU<B!38?!A;F'P_0!']FL@9_QR_&QT_&S\
M(&AA9FEF('EA\&UU<@!(869I9B!+87(`2&%F:68@2V%R(%-A\&%N8?#]`$[\
M:W1E;&D@WFEI<@!"8?!L86YT_0!"8?!L86YT_2!N;VMT87/].@!']G+\;G3\
M;&5R:V5N(&5L96MT<F]N:6L@<&]S=&$@861R97-I;FD@;VQU_G1U<FUA('-A
M>69A<_UN82!B8?!L80!"8?!L86YT_6QA<@!,:6YU>"#'97)E>FD`3&ES=&5L
M92`M(&MU;&QA;OUC_2!D:7II;FD@9_9R96)I;&ER`%9E<FD@5&%B86YL87+]
M;OT@3&ES=&5L90!987)D_6T@2V]N=6QA<OUN_2!,:7-T96QE`,=I>F5L9V5L
M97)I($QI<W1E;&4`3&ES=&5L92U!<OYI=@!,:7-T96QE+5EA<F3];0!,:7-T
M96QE+4ED`$QI<W1E;&4M4V%H:7``3&ES=&5L92U']FYD97)I;&UI_B#6\&5L
M97(`3&ES=&5L92U3_')D_'+\;6/\;&5R`$QI<W1E;&4M4_QR9/QR_&UC_"!/
M;&UA>6%N;&%R`$MU;&QA;OUC_2!L:7-T96QE;64@<V7G:6QE;65Z(&O];/UN
M9/TN`$5D96)I>6%T`$QI='9A;GEA`%G\:VQE;FEY;W(N+BX`665R96P@>F%M
M86XZ`%EE<B!V92!:86UA;@!997(`1VER:?X`Q_UK_?X`1VER:?X@1_9R979L
M97)I`$MU;&QA;OUC_2!A9/T@=F5Y82!P;W)O;&$@9&_P<G4@;VQM863]\/T@
M:>=I;B!G:7)I_B!B8?YA<OUS_7H@;VQD=2X`1VER:?X@8F'^87+]<_UZ(&]L
M9'4N`%5Z=6X@;65T:6X`0?YK`$3\_OQK`$O\Y_QK('EU;F%N(&AA<F9L97)I
M`$O\Y_QK(&QA=&EN(&AA<F9L97)I`$O\Y_QK(')O;6$@<F%K86UL87+]`$S\
M:W-E;6)U<F<`04$`34]41`!-4RU43D5&($5K:2!V97)I(&GG97)M96UE:W1E
M9&ER+@!-4T<`36%C86\`36%K961O;GEA`$UA9&%G87-K87(`0OQY_`!0;W-T
M80!0;W-T82!9]FYE=&EC:7-I`$)A\&QA7VYT_2!987)A="XN+@!-86QA=FD`
M36%L97IY80!-86QD:79L97(`36%L:0!-86QT80#6\&5L97)I(&5T:6ME=&QE
M>65C9?!I;FEZ(&MA=&5G;W)I(&QI<W1E<VEN:2!V92!K871E9V]R:6QE<FD@
M:6QI_FMI;&5N9&ER96-E\&EN:7H@<F5N:VQE<FD@>?9N971I;BX`36%P,C0@
M:&%R:71A<_T`36%P475E<W0@:&%R:71A<_T`36%R=`!+96YA<B!B;_YL=?!U
M`$]K=6YM=?XO3VMU;FUA;?W^(&]L87)A:R!I_F%R971L90!$:?!E<B!I;&5T
M:2!I_F%R971L97)I>6QE(&G^87)E=&QE("CV<FYE:SH@UFYE;6QI+T-E=F%P
M;&%N;?W^*2``36%R<VAA;&P@061A;&%R_0!-87)T:6YI:P!%_FQE;&5N(&%L
M86YL87(`36]R:71A;GEA`$UA=7)I='5S`-UZ:6X@=F5R:6QE;B!E;B!Y_&MS
M96L@:W)E9&DN`$5N('G\:W-E:R!M97-A:B!P87+G87/]('-A>?US_2!A_OUL
M9/TN`%-O;B`R-"!S86%T=&5K:2!E;B!Y_&MS96L@<_UC86ML_6LZ(`!3;VX@
M-B!S86%T=&5K:2!E;B!Y_&MS96L@<_UC86ML_6LZ(`!%;B!Y_&MS96L@=7IU
M;FQU:P!-87G]<P!-87EO='1E`%3]<`#<>65L97(`365N_"!+:7!I.@!(_&-R
M96QE<FD@8FER;&7^=&ER`-UL971I`-UL97)I(&)A_F%R_7EL82!D;_!R=6QA
M;F3](&%M82!I;7IA;&%Y_6/];OUN(&]N87D@8F5L9V5S:2!D;_!R=6QA;F%M
M863]+@!-97-A:OUN('/\<F5S:2!B:71T:2X`365S86H@=&EP:0!(879A(%)A
M<&]R=0!(879A(')A<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I;"X`
M2&%V82!R87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN($%Y<OUN
M=/UL87(@>?9N971I8VD@:>=I;B!G_&YL_&ML96YD:0!9]FYT96T`365T<FEK
M`$UE:W-I:V$`36EK<F]N97-Y80!/<G1A`$UI;64@5/QR_`!3;VX@,C0@<V%A
M='1E:VD@96X@9/S^_&L@<_UC86ML_6LZ(`!3;VX@-B!S86%T=&5K:2!E;B!D
M_/[\:R!S_6-A:VS]:SH@`%EA;G/]`$UU:'1E;&EF`$)U;'5N86UA>6%N(%!%
M05(@<&%K971I.B!(5%107U)E<75E<W0N`$%T;&%N;?W^('EA</UL86YD_7)M
M82X@0G4@=7EG=6QA;6%Y_2!K=6QL86YM86L@:7-T:7EO<G-A;OUZ('EA</UL
M86YD_7)M87G](/QR971M96L@>F]R=6YD87/];OUZ+@!!=&QA;FW]_B!M97-A
M:B!)1"X`071L86YM_?X@;VQA;B!G97)E:VQI(%!%05(@<&%K971I($UA:6PN
M`$%T;&%N;?W^(&]T=7)U;6$@86ET($E$+@!0>G0`1V5Z:6-I(%!O<W1A`%-A
M:VEN`$1E\&G^:6T@5&%R:6AI`$1E\&G^=&ER.E523`!-;V0@5&%B86[]`$UO
M;&1O=GEA`$UO;F%C;P!-;_!O;&ES=&%N`$%Y('9E('G];`!!>6S]:P!-;VYT
M<V5R<F%T`$%Y($5V<F5L97)I`$9A<P!'96YE;&QI:VQE($'G_6L`1V5N96QL
M:6ML92!"=6QU=&QU`$=E;F5L;&EK;&4@1_QN9?YL:0!!_F'P_2!48?[]`%-O
M;&$@5&'^_0!38?!A(%1A_OT`675K87+](%1A_OT`0?YA\/T@=&'^_0!9=6MA
M<OT@=&'^_0!-;WIA;6)I:P#';VML=2!D_'IE>2!A_F'P_2!AY_UL_7(@;&ES
M=&5L97(`QV]K;'4@4V7G:6T`2&5S86+];0!0;W)T86S];0!0;W)T86P@1/QZ
M96YI;0!->6%N;6%R`$MA8G5L($5434E93U)530!!9`!.86UI8GEA`$YA=7)U
M`$YE<&%L`$AO;&QA;F1A`$AO;&QA;F1A($%N=&EL;&5R:0!.971S8V%P92!4
M86)A;B!54DP`3F5T<V-A<&4@0T$@W7!T86P@55),`$YE='-C87!E($-!(&MU
M<F%L(%523`!.971S8V%P92!996YI;&5M92!23`!.971S8V%P92#=<'1A;"!5
M4DP`3F5T<V-A<&4@4U-,('-U;G5C=2!A9/T`3F5T<V-A<&4@;VYA>2!B96QG
M97-I(&'G_6ML86UA<_T`3F5T<V-A<&4@;VYA>2!B96QG97-I('3\<OP`0?``
M07-L80!996YI($MA;&5D;VYY80!996YI($MA=&5G;W)I`%EE;FD@07D`665N
M:2!+=6QL86[]8_T@063]("A39>=I;6QI*0!996YI(%IE;&QA;F1A`%EE;FD@
M4&5N8V5R92`H7V)O_BD`2&%B97)L97(`2&%B97(@1W)U<&QA<OT`4V]N<F%K
M:0!3;VYR86MI(%-EYV5N96ML97(`3FEK87)A9W5A`$YI:F5R>6$`3FEJ97)Y
M80!'96-E`$YI=64`2&%Y_7(`1F%R:VQA<OUN(&?V<W1E<FEL96)I;&5C9?!I
M(&MU;&QA;OUL86)I;&ER('EA</UL86YD_7)M82!V97)I<VD@>6]K+@!)4T\@
M:6UA:FQA<OT@;W7^='5R;6%K(&GG:6X@:W5L;&%N_6QA8FEL:7(@8FER('GV
M;G1E;2!Y;VLN`%G]\/UN('1A<VQA\/T@>6]K+@#=<W1E;F5N(&MO;G5M9&$@
M:&GG8FER(/9B96L@8G5L=6YM86UA:W1A9/UR`$U#04P@9&_P<G5L86UA<_T@
M:>=I;B!H:>=B:7(@=&%K=FEM(&%D_2!S8?!L86YM86W]_G3]<BX@`$1E\&G^
M:6ML:6L@66]K`$)U(&EZ;F4@:&GG8FER(&%L="!I>FEN(&5K;&5N96UE>65C
M96MT:7(N`"5S(&GG:6X@:&GG8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E
M;&ER=&EL;65D:2X`1E10(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@
M8FEL9VES:2!B96QI<G1I;&UE9&DN`%-13"!61E,@:>=I;B!H:>=B:7(@>6%P
M_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+@!344PM1FEL92!61E,@
M:>=I;B!H:>=B:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I
M+@!+<F5D:2!Y;VLN`$AIYV)I<B!T97-L:6T@;F]K=&%S_2!B96QI<G1I;&UE
M;6G^=&ER+@!(:>=B:7(@9&]S>6$@>?QK;&5N96UE9&D`2&GG8FER('-I;6=E
M(&)U;'5N86UA9/TN`$AIYV)I<B!Y97(@8F5L:7)T:6QM961I+@!(:>=B:7(@
M;65S86H@<V'P;&%N;6%D_2X`060@8F5L:7)T:6QM961I+@!.=6UA<F$@8F5L
M:7)T:6QM961I+@!386QD_7)G86X@9&5Y:?X@:W5L;&%N;6$`2%144"!D;_!R
M=6QA;6%S_2!IYVEN('!A<F]L82!G:7)I;&UE9&DN`$E-05`@9&_P<G5L86UA
M<_T@:>=I;B!P87)O;&$@9VER:6QM961I+@!+97)B97)O<R!D;_!R=6QA;6%S
M_2!IYVEN('!A<F]L82!G:7)I;&UE9&DN`$QO9VEN(&1O\')U;&%M87/](&GG
M:6X@<&%R;VQA(&=I<FEL;65D:2X`4$%34U=$(&1O\')U;&%M87/](&GG:6X@
M<&%R;VQA(&=I<FEL;65D:2X`4TU"(&1O\')U;&%M87/](&GG:6X@<&%R;VQA
M(&=I<FEL;65D:2X`3W!E;E-33"!I:VEL:7-I;F4@:&GG8FER('EO;"!B=6QU
M;F%M863]+D]P96Y34TP@:6MI;&ES:2!02T-3(#$R('9E<FES:7EL92!C86S]
M_FUA:R!IYVEN(&=E<F5K;&DN`-QY92!O;&UA:R!IYVEN(&)E:VQE>65N('EO
M:RX`2W5R86P@>6]K`%EA;B!Y;VL`UFYB96QL96L@:>=I;B!G9>=I8VD@9&EZ
M:6X@8G5L=6YA;6%D_2X`2W5L;&%N_6/](&%D_2!V92]V97EA('!A<F]L82!G
M]FYD97)I;&UE9&DN`$=EYV5R;&D@6$U,('9E<FES:2!G97)I(&3V;FUE9&DN
M`$1E\&5R('EO:P#6>F?\;B!Y87#];&%N9/UR;6%D82!S_'+\;2!B=6QU;F%M
M863]+EEA</UL86YD_7)M87G]('1E:W)A<B#\<F5T:6XN`-9Z9_QN('EA</UL
M86YD_7)M86[]>F1A('/\<OQM(&)U;'5N86UA9/TN66%P_6QA;F3]<FUA>?T@
M=&5K<F%R(/QR971I;BX`2&GG8FER:0!(:>=B:7)I("C6<G3\;/P@:W5L;&%N
M_6XI`$MU>F5Y($%V<G5P86S]("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!!9&%S
M_0!+=7IE>2!987+];6O\<F4`2W5Z97D@36%R:6%N82!!9&%L87+]`$YO<G9E
MYP!3;VYR87/];F1A($1E\&EL`-9N8V5S:6YD92!$9?!I;`!$:7II;B!D9?!I
M;`!'97+G96ML9?YT:7)I;&UE;6G^`$)E;&ER=&EL;65M:?X`1&5S=&5K;&5N
M;6EY;W(N`$YO=&QA<@!']GH@873];&%C86L@8FER_F5Y('EO:RP@9V5R:2!D
M]F[\;BX`2V%S_6T`4V%Y_0!+87)A:W1E<B!S87G]<_T`2V]L;VX@<V%Y_7/]
M`%-A=/UR('-A>?US_0!$8?#]=/UM(&QI<W1E;&5R:6YI;B!G_&YC96QL96YM
M97-I(&GG:6X@;G5M87)A;&%R(&)E;&ER=&EL;65M:?XN`$5V970`3F5S;F4`
M3F5S;F4@66%R873]8_US_0!396MI>FQI:R!3:7-T96T`16MI;0!386QD_7)G
M86YL_6L@<_QZ9V5C:0!/9FES`%5M;6%N`%-A9&5C92!)34%0('-U;G5C=6QA
M<OT@<&%Y;&'^_6QA;B!D:7II;FQE<FD@9&5S=&5K;&5M96MT961I<BX`4V%D
M96-E('-A;&3]<F=A;B!D97EI_FQE<@!3861E8V4@8FER(&5L96MT<F]N:6L@
M<&]S=&$@861R97-I;F4@:7II;B!V97)I;&UE:W1E9&ER+@!":7(@<&%Y;&'^
M_6W];B!S86AI<&QI\&EN:2!V97EA('-A:&EB:6YI('-A9&5C92!S:7-Y96T@
M>?9N971I8VES:2!V97EA('-A:&EB:2!D9?!I_G1I<F5B:6QI<BX`665N:2!P
M96YC97)E9&4@8><`3W!E;E-33"!H871A<_TZW6UZ86QA;FW]_B!3+TU)344@
M<&%RYV%S_6YD86X@=F5R:2!S9>=I<"#G_6MA=/UL86UA9/TN`$)U(&)A\&QA
M;G3]>?T@>65N:2!P96YC97)E9&4@8><`W?YL971I;2!3:7-T96UI`%-EYV5N
M96ML97(`)7,@:>=I;B!S9>=E;F5K;&5R`%/]<F%L86YM_?X@3&ES=&4`2W5R
M=6QU_@!+=7)U;7-A;"!":7)I;0!$_'IE;FQE;64`UGIG_&X@=7EG=6QA;6$@
M=&%S;&'P_0`E<R!IYVEN9&5K:2#V>F?\;B!T87-L86ML87(Z`$1I\&5R`$1I
M\&5R($)I;&=I;&5R`%-A:&EP(&EZ:6YL97)I`%!!32!D;_!R=6QA;6%S_2!M
M979C=70@9&7P:6PN`%!'4"!387G]<V%L(-UM>F$`4$=0(-YI9G)E;&5N;6G^
M(%9E<FD`4$=0($'G_6L@06YA:'1A<OT`4$=0(&EL92#=;7IA;&%N;?W^+]YI
M9G)E;&5N;6G^(%9E<FD`4$A0($MO9'4`4$A0($MA8G7P=0#64R!(869I9B!9
M8?!M=7(`UE,@4V'P86YA:VQA<OT`UE,@2V%R`-93($MA<B!38?!A;F%K;&%R
M_0#64R!']FL@9_QR_&QT_&S\(&;]<G3];F$`4%](4"!+86)U\'4`66%S=/UK
M;&%M80!086MI<W1A;@!086QA=0#=_F=A;"!%9&EL;6G^($9I;&ES=&EN($+V
M;&=E<VD`4&%N86UA`%!A<'5A(%EE;FD@1VEN90!087)A9W5A>0!+_7-M96X@
M0G5L=71L=0!087)O;&$`66%N;/W^('!A<F]L80!2041)55,@9&_P<G5L86UA
M<_T@:>=I;B!P87)O;&$@9V5R96MM96MT961I<BX`3VYA>6S](%!A<F]L80!0
M87)O;&$Z`%!A<F]L83H`4&%R;VQA;&%R(&7^;&7^;65K('IO<G5N9&%D_7(N
M`%EA</W^=/UR`%!A;F]D86X@>6%P_?YT_7(`66]L`$)E:VQE>65N(-QY96QI
M:VQE<CH`W6YS86YL87(`6?QZ9&4`0F%K_6T@W?YL96UL97)I;FD@1V5RYV5K
M;&7^=&ER`$)A:_UM(&G^;&5M;&5R:2!G:7)I_G1E(&=E<N=E:VQE_G1I<FEL
M<VEN(&UI/P#=>FEN`-UZ:6X@6?9N971I;6D`2VG^:7-E;"!":6QG:6QE<@!0
M97)U`$5V8VEL($AA>79A;FQA<@!&:6QI<&EN;&5R`%1E;&5F;VX`1F]T;_!R
M869L87(`4&ET8V%I<FX`4F5S:6T@0FER:6UI`$)E>6QI:R!3]GIL97(`3/QT
M9F5N(&)I<FMAYR!H_&-R97EE('3]:VQA>?UN`$S\=&9E;B!B=2#V\&5Y:2#G
M_6MA<FUA:R!I<W1E9&GP:6YI>FD@9&_P<G5L87G];CH`3/QT9F5N(&)U(/;P
M96YI;B!B8?#];OT@Y_9Z;65K(&ES=&5D:?!I;FEZ(&1O\')U;&%Y_6XN`$S\
M=&9E;B!B:7(@87D@=F4@8FER('G];"!G:7)I;BX`3/QT9F5N('EE;FD@:V%T
M96=O<FEN:6X@863];OT@9VER:6XZ`$S\=&9E;B!G9>=E<FQI(&)I<B!)4"!A
M9')E<VD@9VER:6XN`$S\=&9E;B!G9>=E<FQI(&)I<B!G_&X@9VER:6XL(&%Y
M9&%K:2!G_&X@<V%Y_7/];OT@:V]N=')O;"!E9&EN+@!,_'1F96X@9V7G97)L
M:2!B:7(@>F%M86X@9VER:6XN`$S\=&9E;B!S;W)U;G5N(&)I<B#V>F5T:6YI
M('EA</UN+@!,_'1F96X@:W5L;&%N_6/](&%D_2!V92!P87)O;&%N_7K](&=I
M<FEN`$S\=&9E;B!Y96YI(&MA=&5G;W)I;FD@863](&=I<FEN.@!0;VQO;GEA
M`%!O;&ET:6MA`$]Y;&%M86QA<@!0;W)T96MI>@!']G+\;G3\(&MO;G5M;&%N
M9/UR_6S]>6]R`,=I>F5L9V4@:V]N=6UL86YD_7+];/UY;W(`0G4@9&EZ:6YE
M(&?V;F1E<B`H24U!4"!T87)A9OUN9&%N('IO<FQA;FUA;6%K=&%D_7(I`%-O
M;B`E<R!S86%T=&4@9/S^96X@>6'P;75R('9E(&MA<B!M:6MT87+].@!0<F5F
M<U]L9&%P.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`4')E
M9G-?<V5S<VEO;CH@W7-T96YE;B!O='5R=6T@=7IA;G3]<_T@8G5L=6YA;6%D
M_2X`0F%S_6[G`$1E;FEZ('-E=FEY97-I;F1E:VD@8F%S_6[G.@!"87/];N<Z
M`-9N:7IL96UE`$?V<OQN=/QY_"!Y96YI('!E;F-E<F5D92#V;FEZ;&4`UFYC
M96MI('-EYV5N96ML97(`0F5L9V5Y:2!Y87ID_7(`UGIE;"!!;F%H=&%R`%-O
M<G5N`%-O<G5N(%1A;OUM;&%M87/]`%!R;VIE;&5R`$UE=&EN(&)I;&=I(&ES
M=&5M:0!!Y_UK($%N86AT87(`0>?]:R!!;F%H=&%R(&%L9V]R:71M87/]`$'G
M_6LOUGIE;"!A;F%H=&%R(&EK:6QI<VD@8F'^87+]>6QA('EA<F%T_6QA;6%D
M_2X`4&]R=&\@4FEK;P!+871A<@!3;W)G=0!24T$@0>?]:R!!;F%H=&%R_2`H
M)60@8FET*0!2861Y;R!39>=I;6D`66'P;75R`$5R:V5N(%-A871L97)D92!9
M8?!M=7(`1V7G(%-A871L97)D92!98?!M=7(`4V'P86YA:R!98?#]_@!98?!M
M=7(@=F4@2V%R`$MA<F$@9/9N_/YE8V5K('EA\&UU<@!287-T9V5L92!$97EI
M_@!/<F%N`$]K=6UA`-UL971I;&5R:2!/:W4`4VEL;65K(&ES=&5D:?!I;FEZ
M92!G97+G96MT96X@96UI;B!M:7-I;FEZ/RA"=2!I_FQE;2!G97)I(.=E=G)I
M;&5M97HI.B5S`$MU;&QA;OUC_2`E<R!E(&%I="!K=6QL86[]8_T@=F5R:6QE
M<FEN:2!S:6QM96L@:7-T961I\&EN:7IE(&5M:6X@;6ES:6YI>BX@0G4@:?YL
M96T@9V5R:2#G979R:6QE;65Z+@!3;VX@97EL96UI('1E:W)A<FQA`$1E=FEN
M9V5N($UE;OP@UO!E;&5R:6YI(%1A>F5L93H`4&]R=&%L($?V<OQN_&W\;OP@
M5&%Z96QE.@!$_'IE;FQI(-UF861E`-UL:?YK:2!487)A>?UC_0!!Y_UK;&%M
M86QA<@!5>F%K=&%K:2!3=6YU8W5L87(`57IA:W1A:VD@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4VEL`-9B9?!I(%-I;`!+;VQO;G4@
M4VEL`$)IYVEM;&5M97EI(%-I;`!):VEL:7EI(%-I;`!+87ED961I;&UI_B!B
M971I\&D@<W5N=6-U;G4@9V7G:6-I(&1I>FEN:6YD96X@<VEL+@!3:6P`0G4@
M<&%RYV%Y_2!B96QG961E;B#G_6MA<G0`2W5L;&%N_6/](%-I;`!+=6QL86[]
M8_UY_2!S:6PZ("5S`-US=&5K(&-E=F%P;&%N86UA9/TN1/9N_&QE;B!H871A
M(&MO9'4Z(`!'97)E:V5N($%L86X`5&5M:7IL90!087)O;&%Y_2!S_6;]<FQA
M`%!A<F]L86[]>OT@<_UF_7)L87G];@!3;VYUYVQA<@!39>=E;F5K;&5R92!$
M]F[\;@!2975N:6]N`%EA</UL86YD_7)M87G]($=E<FD@1/9N9/QR`%IE;F=I
M;B!-971I;B!$_'IE;FQE>6EC:7-I(%-EYV5N96ML97)I`$)I;&UE8V5L97(`
M4V'P`%-A\"!B8?YL_6L@8FEL9VES:0!$;_!R=2!D9?!E<FQE<@!385]T_7(@
MUGIE;&QI:VQE<FDN+BX`1_9R978`4F]M86YY80`Q.#`@9&5R96-E(&3V;F3\
M<@!3;VQA($3V;F3\<@!38?!A($3V;F3\<@!3873]<B#6>F5L;&EK;&5R:0!3
M873]<B#V>F5L;&EK;&5R:0!3873]<FQA<CH`QVEZ9VEL97(`QVEZ9VEL97(@
M=/QM('-A=/UR('9E(&MO;&]N;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<@#'
M:7IG:6QE<B!S861E8V4@:V]L;VYL87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER
M`,=I>F=I;&5R('-A9&5C92!S873]<FQA<B!A<F%S_6YD82!B96QI<F5C96MT
M:7(`QV%L_?YT_7(`4G5S>6$@1F5D97)A<WEO;G4`4G5A;F1A`%,O34E-12#>
M:69R96QE;64@W6UZ87/]`%,O34E-12!I;&4@WFEF<F5L96YM:?X@W6QE=&D`
M4T%33"!D;_!R=6QA;6%S_2!M979C=70@9&7P:6PN`%--4R!-97-A:FQA_FUA
M`%-13"!+86)U\'4`4U-(`$)!WD%224Q)`%-?44P@2V%B=?!U`$-T<P!386EN
M="!(96QE;F$`4V%I;G0@2VET=',@=F4@3F5V:7,`4V%I;G0@3'5C:6$`4V%I
M;G0@4&EE<G)E('9E($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@=F4@1W)E;F%D
M:6YE<P!!>6[](.=E<N=E=F4@*&ME;E]D:7-I*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE('9E(%!R:6YC:7!E`%5Y9'4@4V'P;&%Y_6/]`%-U=61I($%R
M86)I<W1A;@!+87ED970`2V%Y9&5T("5S`%-EYV5N96ML97)I($MA>61E=`!/
M;'7^='5R=6QA;B!Y87#];&%N9/UR;6%Y_2!02%`@8F5T:?!I(&]L87)A:R!S
M=6YU8W5N=6X@9V7G:6-I(&1I>FEN:6YE(&MA>61E="X`)7,@>6%P_6QA;F3]
M<FUA<_T@:V%Y9&5D:6QD:2X`0FEL:6T`07)A;6$`07)A;6$@36]T;W)L87+]
M`$1O<WEA;&%R_2!39><`0FER('1A<FEH('-EYVEN`$5K;&5M96L@:>=I;B!B
M:7(@9W)U<"!S9>=I;@!996YI('-A:&EB:2!S9>=I;@!":7(@<W5N=6-U('-E
MYVEN`$5K;&5M96L@:>=I;B!B:7(@:W5L;&%N_6/]('-EYVEN`$+\=/QN('1A
M<FEH(&)I;&7^96YL97)I;FD@<V7G:6X`0FER(&YE<VYE('-EYVEN`-US=&5D
M:?!N:7H@:V%R86MT97)L97)I(&'^8?#]9&%K:2!K=71U;&%R9&%N('-EYVEN
M+B!$86AA('-O;G)A(&UE=&EN(&%L86[];F1A;B!K;W!Y86QA>?UP('EA</W^
M=/UR86)I;&ER<VEN:7HN`%1A<FEH('/];OUR;&%Y_6/]<_UN_2!S9>?];CH`
M5&%R:6@@8FGG:6UI;FD@<V7G:6XZ`$1E\&G^=&ER;65K(&ES=&5D:?!I;FEZ
M(&MI;6QI\&D@<V7G:6XZ`%-A870@<_UN_7)L87G]8_US_6[]('-EYVEN.@!3
M86%T(&)IYVEM:6YI('-EYVEN.@!%_FQE_F5N(&EK:2!A;&%N_2!S9>=I;BX`
M4F5N:R!D_'IE;FEN:7II('-EYVEN+@!497)C:6@@971T:?!I;FEZ(&1I;&D@
M<V7G:6XZ`%-O<G5N(%)A<&]R=2!']FYD97(`4TU3($?V;F1E<@!396YE9V%L
M`$%L9_UL87G]8_TZ`$5Y;/QL`%/]<F)I<W1A;B!V92!-;VYT96YE9W)O`%-E
M<FD@3G5M87)A<_T`3W1U<G5M(&MI;6QI\&EN:6X@<_QR97-I(&1O;&1U+@!"
M96QI<G0`4&%R;VQA;OUZ_6[]('5N=71U<G-A;OUZ('/]9OUR;&%M86[]>F$@
M:7II;B!V97)E8V5K('-EYV5N96ML97)I(&)E;&ER=&EN+B``56QA_FUA:R!I
M<W1E\&EN:7H@=7IA:W1A:VD@<W5N=6-U;&%R_2!B96QI<FQE>6EN+@!497)C
M:6@@971T:?!I;FEZ(&1I;"P@<V%A="!D:6QI;6D@=F4@=&%R:6@@<V7G96YE
M:VQE<FEN:2!B96QI<FQE>6EN+@!"8?YL86YG_><@=7EG=6QA;6%N_7K]+"!R
M96YK(&3\>F5N:6YI>FDL('-A>69A('1A>F5L96UE+"!V92!D:?!E<B!G]G+\
M;G3\('-EYV5N96ML97)I;FD@8F5L:7)L97EI;BX`07EA<FQA<@!+=7)U;'5M
M(&?\;F-E;&QE;64@8F5T:6ML97)I(&MU;&QA;OUL86)I;&ER(&1U<G5M9&$N
M`$1E\&G^=&ER9V4@:6QE(&)I<F1E;B!F87IL82!Y97(@;?QM:_QN.B``4V5Y
M_F5L`$%L_?X@=F5R:?X`2_US82#6>F5T`,=O\'4@8F'P;&%N=/T@:>=I;B!E
M<FG^:6T@86YA:'1A<OT@=&%N_6UL86YS_6X@;?T_`$?V<W1E<@!(86QE;B!K
M87G]=&S](&]L86X@>6%P_6QA;F3]<FUA(&EL92!Y96YI('EA<F%T_6QA;B!Y
M87#];&%N9/UR;6$@87)A<_UN9&%K:2!F87)K;&%R_2!G]G-T97(N`$=I<FG^
M=&4@96X@<V]N(&=I<FG^('1A<FEH:2!G]G-T97)I;'-I;B!M:3\`UGIG_&X@
M;VQA;OT@<V%K;&%M82!S9>=E;F7P:6YI(&?V<W1E<@!39>=I8VEY:2!G]G-T
M97(`QVEZ96QG92!I_FQE;6QE<FD@;65N_"#G=6)U\'5N9&$@9_9S=&5R:6QS
M:6X@;6D_`"5S($UE;OQS_"!S;VQD82!G]G-T97)I;'-I;B!M:3\`5&%B;&\@
M2/QC<F4@UGIE;&QI:VQE<FD@2W5T=7-U;G4@9_9S=&5R`%1A8FQO(-9Z96QL
M:6ML97)I($MU='5S=6YU(&?V<W1E<@!486)L;R!3873]<B#6>F5L;&EK;&5R
M:2!+=71U<W5N=2!G]G-T97(`1_9R_&YT_"#V>F5L;&EK;&5R:2!K=71U<W5N
M=2!G]G-T97(`6?QK;&5M97EI(&?V<W1E<@!38?!A;F%K`$5R:V5N(%-A871L
M97)D92!38?!A;F%K`$=EYR!386%T;&5R9&4@4V'P86YA:P#'979R961E(%-A
M\&%N86L`2_SG_&QT`-UL:R!O;&%R86L@:V]M_G4@]O!E;&5R(&O\Y_QL='/\
M;B!Y861A('1A_OUN<_UN`%-I97)R82!,96]N90#<>64@;VP`W6UZ80#=;7IA
M($%L9V]R:71M87/]`%-I;F=A<'5R`$)O>75T`$)A:_UM_2!!=&QA`%-L;W9A
M:WEA`%-L;W9E;GEA`$MA<@!+87(@4V'P86YA\/T`2V%R(%-A\&%N86ML87+]
M`$5R:V5N(%-A871L97)D92!+87(@4V'P86YA:VQA<OT`1V7G(%-A871L97)D
M92!+87(@4V'P86YA:VQA<OT`2V%R($1E<FEN;&GP:3H@`%EA\&%N(&MA<OUN
M('-U(&7^:71I.B``4V]L;VUO;B!!9&%L87+]`%-O;6%L:0#>87)K_6QA<B`F
M(-YI:7)L97(`4_UR86QA;6$@9/QZ96YI('-EYVEM:0!+87EN86L@861R97-I
M`$?\;F5Y($%F<FEK80!'_&YE>2!!=G)U<&$@*$E33RTX.#4Y+3,I`$?\;F5Y
M($=E;W)G:6$@=F4@1_QN97D@4V%N9'=I8V@@061A;&%R_0!'_&YE>2!987+]
M;6O\<F4`0FET:?YI:R!H_&-R96QE<B!A<F%S_6YD86MI(&)O_FQU:P!(_&-R
M961E:VD@<_UN_7(@=F4@:>=E<FEK(&%R87/];F1A:VD@8F_^;'5K`$)O_FQU
M:R!!>6%R;&%Y_6/]`$%R86S]:R!B_7)A:VUA`$%R86S]:R!B_7)A:VUA('9E
M('EA<W3]:VQA;6$`W7-P86YY80#=<W1E;FUE>65N(-UL971I`-9Z96P@2V%R
M86MT97(@1VER:?YI`$C\8W)E>6D@8O9L`$MO;&]N=2!B]FP`4V%T_7+](&+V
M;`!3<&]R;&%R`%-R:2!,86YK80!3=&%N9&%R=`!5>F%Y(%EO;'4`0F'^;&%N
M9_WG('G];/T`17EA;&5T('9E>6$@W6P`1'5R=6T`1&5P;VQA;6$@8FGG:6UI
M`%-O:V%K($%D<F5S:0#<<W3\(.=I>F=I;&D`1&EZ9VD@;&ES=&5S:0!!9')E
M<W1E;B!A;&%N(&%D_6[](.?]:V%R=`!3:71I;"!;0U-370!0>G(`2V]N=0!'
M]FYD97(`06QT<VEM9V4`0F'^87+]`%EA</UL86YD_7)M82!B8?YA<OUY;&$@
M9V5R:2!D]FYD_'+\;&3\+B!$9?!I_FEK;&EK;&5R:2!G]G)M96L@:>=I;B!Y
M96YI9&5N('G\:VQE>6EN+@!9961E:R!Y87#];&%N9/UR;6$@8F'^87+]>6QA
M(&MA>61E9&EL9&DN`%EE9&5K('EA</UL86YD_7)M82!D;W-Y87/]("5S(&)A
M_F%R_7EL82!K87ED961I;&1I+@`E<R!B8?YA<OUY;&$@>6%Z_6QD_2X`4W5D
M86X`UGIE=`!'_&X@1&_P=6UU`$?\;B!B873];?T`1_QN9?YL:0!'_&X@9&_P
M=6UU`$?\;B!D;_!U;74O1_QN(&)A=/UM_0!'_&X@9&_P=6UU.B``1_QN(&)A
M=/UM_0!'_&X@8F%T_6W].B``W'-T<VEM9V4`1&5S=&5K`%-U<FEN86T`4V]Y
M863]`%-V86QB87)D('9E($IA;B!-87EE;@!3=F%Z:6QA;F0`W7-V9><`W7-V
M:>=R90!!<F%M82!T97)I;6QE<FEN9&4@<_9Z9&EZ:6T@:&%T87/]`%-U<FEY
M90!']FL@9_QR_&QT_&S\(&;]<G3];F$`1_9K(&?\<OQL=/QL_"!F_7)T_6YA
M;&%R`%135B!D;W-Y87/]`,=I>F5L9V4`QTEZ96QG92#6>F5L;&EK;&5R:0#'
M:7IE;&=E(/9Z96QL:6ML97)I`%1A>79A;@!487EV86XL(,=I;B!E>6%L971I
M`%1A8VEK:7-T86X`5&%N>F%N>6$`2&5D968Z`$?V<F5V;&5R`%1E;&5F;VX@
M3G5M87)A<_T`4V]N('-A870@:>=I;B!S_6-A:VS]:SH@`%/]8V%K;/UK`%/]
M8V%K;/UK.B``5&%S;&%K(%GV;F5T:6UI`$UE=&EN`%-A9&5C92!-971I;@!-
M971I;B!H:7IA;&%M87/]`$UE=&YI;B#<<W3\`%!R_@!486D@*%1)4RTV,C`I
M`%1A>6QA;F0`4VES=&5M:2!K=6QL86[]9/WP_6[]>B!IYVEN('1E_F5K:_QR
M(&5D97)I>BX`1E10('5Z86YT_7/](&MU;&QA;OUL86)I;&ER(&1U<G5M9&$@
M9&7P:6PN`$AO<F1E+TMO;&%B(&+\=/QN;&7^=&ER;64@;6]T;W)U(&1E<W1E
M:VQE;65M96MT961I<CH@(B5S(@!"86O];3HZ('/];OUF(&)A_F%R_7EL82!Y
M_&ML96YE;65D:2X`WF7G96YE:VQE<B!P96YC97)E<VD@:V%P86YD_2['_6O]
M_B!Y87#];/UY;W(N`$7P97(@:7II;FQE<FD@:W5L;&%N;6%K(&ES=&EY;W)S
M86[]>B!Y]FYE=&EC:6YI>FEN(-UZ:6X@<VES=&5M:6YI('EA</UL86YD_7)M
M87/](&=E<F5K;65K=&5D:7(N`%-A9&5C92!A;'0@=&%R868`W6QE=&G^:6T@
M;F]K=&%S_6[];B!)1"=S:2!B96QI<FQE;F5M961I+"!B;_X@8OUR86O];&W]
M_B!V97EA('9E<FD@=&%B86[];F1A(&)U;'5N86UA9/TN`-UL971I_FEM(&YO
M:W1A<_T@8F'^87+]>6QA(&%D<F5S(&1E9G1E<FEN:7IE(&5K;&5N9&DN`,?]
M:V%R=/UL;?W^(%!'4"!I;7IA(/9B9?!I(&EM>F%L86YM_?X@:6QE=&EN:6X@
M9&_P<G5L=?!U;G5N('-A\&QA;FUA<_T@:>=I;B!G97)E:VUE:W1E9&ER+@!$
M8?#]=/UM(&QI<W1E<VD@240G<VD@8F5L:7)L96YE;65D:2P@8F_^(&+]<F%K
M_6QM_?X@=F5Y82!V97)I('1A8F%N_6YD82!B=6QU;F%M863]+@!$8?#]=/UM
M(&QI<W1E<VD@8F5L:7)L96YE;65D:2X`WFEF<F5L96UE(/9Z96QL:6ML97)I
M(&?\=F5N;&D@8FER('=E8B!B8?!L86YT_7/](&=E<F5K=&ER;65K=&5D:7(N
M`"5S(&1O<WEA<_T@)7,@87EA<OT@:>=E<FUE;&ED:7(N`"5S(&1O<WEA<_T@
M)7,@87EA<FQA<OT@:>=E<FUE;&ED:7(N`$1O<WEA(&ME;F1I(/QZ97)I;F4@
M:V]P>6%L86YA;6%Z+@!$;W-Y82!V97)I(&GG97)M:7EO<BX`5&%K:7`@961E
M;FQE<B!B=2!I;&5T:2]R9F,X,C(@:6QE=&ES:2!IYVEN(&)A_FS]:R!B:6QG
M:6QE<FED:7(N`$'^86UA9/WP_6W]>B!T87)A>?UC_2!H871A;&%R_2!S96)E
M8FEY;&4@=&%M(&5K<F%N(&MI<&EN:6X@26YT97)N970@17AP;&]R97(G;&$@
M8FER;&EK=&4@<V]R=6X@Y_UK87)D_?#](&)I;&EN;65K=&5D:7(N($%N;&%M
M<_UZ(&?V<OQN=/QL97)L92P@YV%L_?YM87EA;B!M971I;B!D_'IE;FQE>6EC
M:2!I_FQE<FEY;&4@=F4O=F5Y82!T87)A>?UC_6[];B!R87-T9V5L92#G]FMM
M97-I>6QE(&MA<O[];&'^86)I;&ER<VEN:7HN($7P97(@<VES=&5M:6YI>B!7
M:6YD;W=S(#EX(&ES92!Y_&MS96L@:6AT:6UA;"`G1V5N97)A;"!0<F]T96-T
M:6]N($9A=6QT)R!H871A<_T@86S]<"!S:7-T96UI('EE;FED96X@8F'^;&%T
M;6%N_7H@9V5R96ME8V5K+EQN7&Y"=2!B:7(@=7EA<OUY9/TN($7P97(@:&%L
M82!T86T@96MR86X@;65T:6X@9/QZ96YL97EI8VES:6YI(&1E;F5M96L@:7-T
M:7EO<G-A;OUZ($5V970G:2!T_6ML87G];BX`2VEM;&EK("(E<R(@<VEL:6YD
M:2X`4V%D96-E('-O;"!T87)A9@!#<GEP=%]P9W`Z.B!S_6[]9OUN82!';G50
M1R!I:VEL:7-I;FEN(&MO;G5M=2!V97)I;&UE:R!Z;W)U;F1A9/UR+@`E<R!T
M87)I:&EN9&4@)7,@92!G]FYD97)I;&5N("(E<R(@:V]N=6QU(&EL971I(&?V
M<OQN=/QL96YD:2X*0G4@:6QE=&EN:6X@;VMU;F1U\'4@=F5Y82!A;FQA_OUL
M9/WP_6[](&=A<F%N=&EL96UE;65K=&5D:7(N`$]L=?YT=7(@<&5N8V5R97-I
M;F4@8F'P;&%N_7)K96X@:W5L;&%N_6QA8V%K(&ES:6T`2&]R9&5?0W)Y<'1?
M<VEM93HZ('/];OUF_2!O<&5N<W-L(&)I<FEM:2!IYVEN(&=E<F5K;65K=&5D
M:7(N`"(E<R(@=&5R8VEH:2!V97)I<VD@:7II;B!V97)I;&5N(&5N('G\:W-E
M:R!B;WEU='4@9V7G=&GP:2!IYVEN(&MA>61E9&EL96UE;65K=&5D:7(N`$)U
M('9E<FD@>6%P<_UN_2@E<RD@9_9S=&5R;65K(&GG:6X@:W5L;&%N_6QA;B!P
M<F]G<F%M('-I<W1E;61E(&)U;'5N;6%M86MT863]<BX`4V%D96-E('-O;"!V
M92!S8?`@=&%R869L87(`4V%D96-E('-A\"!T87)A9@`B)7,B('-U;G5C=7-U
M('-I;&EN9&DN`"(E<R(@<W5N=6-U<W4@:V%Y9&5D:6QD:2X`)7,@:>=I;B!O
M;&%N(/QY96QI:R!I<W1E\&D@<VEL:6YD:2X`0F5L:7)T:6QE;B!S873]<B!B
M=6QU;FUA;6%K=&%D_7(N`$=EYVEC:2!D;W-Y82`B)7,B(&)U;'5N;6%M86MT
M863]<BX`4V%D96-E(/QS="!V92!A;'0@=&%R869L87(`4V%D96-E(/QS="!T
M87)A9@!":7(@]FYC96MI(&%D_6T@<_UR87/];F1A('G\:VQE;F5N('9E<FD@
M:V%Y8F5D:6QD:2X`6?QK;&5N96X@9&]S>6$@:V%Y9&5D:6QE;65D:2X`=V5A
M=&AE<BYC;VT@:W5L;&%N_6QA8FEL:7(@9&7P:6PN`$AIYV)I<B!S9>=E;F5K
M(&UE=F-U="!D9?!I;"X`365T;F4@9_9M_&S\(&]L87)A:R!G]G-T97)I;&5B
M:6QE8V5K(&O]<_UM('EO:P!"=2!A;&%N9&$@YV]K(&9A>FQA(&MA<F%K=&5R
M('9A<BXE<R!T86YE(&MA<F%K=&5R(&=I<F1I;FEZ.R`E<R!T86YE9&5N(&%Z
M(&=I<FUE;FEZ(&=E<F5K:7)D:2X`1&]S>6$@*&MA<O[]9&%N*2!Y_&ML96YM
M97-I;F1E('-O<G5N('9A<CH@)7,@>?QK;&5N96UE9&DN`$1O<WEA('G\:VQE
M;FER:V5N(&)I<B!S;W)U;B!O;'7^='4Z("5S(&5N(&+\>?QK(&EZ:6X@=F5R
M:6QE;B!B;WEU='1A;B`H)60@8GET92D@9&%H82!B_'G\:RX`1&]S>6$@>?QK
M;&5N:7)K96X@8FER('-O<G5N(&]L=?YT=3H@)7,@<V%D96-E(&O]<VUI(&]L
M87)A:R!Y_&ML96YD:2X`26QE=&EN:6X@8G4@:_US;?UN_2!G]G+\;G3\;&5N
M;65S:6YD92!H871A(&]L=?YT=2X`W6QE=&G^:6T@;F]K=&%S_6[];B!V97)I
M;&5R:2`H:>=E<FDI(&%K=&%R_6S]<FME;B!H871A(&]L=?YT=2X`:4-A;&5N
M9&%R('9E<FES:2`H:>=E<FDI(&%K=&%R_6S]<FME;B!H871A(&]L=?YT=2X`
M66%P_6QA;F3]<FUA(&9O<FUU;F1A(&)I<B!H871A('9A<BX@1V5R96ML:2!B
M:7(@86QA;OT@9&]L9'5R;6%M_?X@;VQA8FEL:7)S:6YI>BX`0F5L:7)T:6QE
M;B!A9')E<R!D969T97)I(&G^;&5V:6YI;B!G97+G96ML9?YT:7)I;&UE<VD@
M<_UR87/];F1A('-O<G5N(&]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K
M<F%R(&1E;F5Y:6XN`-UL971I_FEM(&YO:W1A<_UN_6X@87ER_6YT_6QA<OUN
M_2!G_&YC96QL97)K96X@:&%T82!O;'7^='4N($S\=&9E;B!D86AA('-O;G)A
M('1E:W)A<B!D96YE>6EN+@!$8?#]=/UM(&QI<W1E<VEN:2!G_&YC96QL97)K
M96X@8FER(&AA=&$@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@
M9&5N97EI;BX`0G4@24U!4"!S=6YU8W5S=2!P87EL8?[];&%N(&1I>FEN;&5R
M:2!D97-T96ML96UI>6]R+@!"=2!G9>=E<FQI(&)I<B!R87(@87+^:79I(&1E
M\&EL+@!"=2!G9>=E<FQI(&)I<B!Z:7`@9&]S>6%S_2!D9?!I;"X`0G4@9V7G
M97)L:2!B:7(@:V%R="!N=6UA<F%S_2!D9?!I;"X`0G4@<_QR_&/\($-L:6-K
M871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@8?`@9V7G:61I(/QZ97)I
M;F1E;B!(5%10($%022!K=6QL86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ:6X@
M=F5R:7(N`$)U('/\<OQC_"!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PI
M(&'P(&=EYVED:2#\>F5R:6YD96X@2%144"!!4$D@:W5L;&%N87)A:R!M97-A
M:B!A=&UA;OUZ82!I>FEN('9E<FER+@!"=2!S_'+\8_P@4TU44"!Y;VQU>6QA
M(%9O9&%F;VYE($ET86QY(&'P(&=EYVED:2#\>F5R:6YD96XL('-A9&5C92!6
M;V1E9F]N92!N=6UA<F%L87+];F$@;65S86H@871M86[]>F$@:7II;B!V97)I
M<BX@5F]D969O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!E;&5K=')O
M;FEK('!O<W1A(&%D<F5S:2!G97)E:W1I<FUE:W1E9&ER+@!"=2!G97)E:VQI
M(&)I<B!A;&%N9/UR+@!"=2!A;&%N('-A9&5C92!S87G](&GG97)M96QI9&ER
M+@!"=2!A;&%N('-A9&5C92!S87G]('9E(&EK:2!N;VMT82#\<W3\<W1E(&G^
M87)E=&D@:>=E<F5B:6QI<BX`0G4@86QA;B!S861E8V4@<V5K:7IL:6L@<V%Y
M_2!S:7-T96UI;F1E;B!D9?!E<FQE(&GG97)E8FEL:7(N`$)U(&%L86X@=FER
M9_QL('9E>6$@8F_^;'5K;&$@87ER_6QM_?X@<V%Y_2!L:7-T92!O;&UA;/UD
M_7(N`$)U(&%L86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L_63]<BX`0G4@
M86QA;B!21T(@2&5X(&)IYVEM:6YD92!B:7(@<F5N:R!K;V1U(&GG97)M96QI
M9&ER+"#V<FYE:SH@)R,Q,C,T868G`$)U(&9O<FT@>F%T96X@:?YL96YD:2X`
M0G4@)7,N`$)U(&)I<B!+;VQA8B!'<F]U<'=A<F4@;F5S;F5S:61I<BX@0G4@
M;F5S;F5Y:2!G]G)E8FEL;65K(&GG:6X@2V]L86(@1W)O=7!W87)E(&)IYVEM
M:6YI(&%N;&%Y86)I;&5N(&)I<B!E;&5K=')O;FEK('!O<W1A(&ES=&5M8VES
M:6YE(&=E<F5K('9A<BY"=2!E;&5K=')O;FEK(&ES=&5M8VD@;&ES=&5S:2!I
MYVEN("5S(&%D<F5S:6YE('7P<F%Y_6XN`$)U(&EL971I('-I>FEN(&MA<F%K
M=&5R(&O\;65N:7ID96X@9F%R:VS](&]L87)A:R@E<RD@>6%Z_6QM_?YT_7(N
M`$)U(&YU;6%R82!E;B!A>OUN9&%N(&)I<B!O;&UA;/UD_7(N`$)U('-U;G5C
M=2!Z:7`@=F4@9WII<"!D;W-Y86QA<OUN_2!AYV%M86UA:W1A9/UR+@!3:7-T
M96UI;B!E=&MI;FQI\&D@:V%L9/UR_6QM_?YT_7(N`$)U(&1E\&5R(&)I<B!S
M87G](&]L;6%L_63]<BX`0G4@<&5N8V5R92!39>=E;F5K;&5R('!E;F-E<F5S
M:6YD96X@YV'P<OUL;6%L_63]<BX`1_9K(&?\<OQL=/QS_`!":6QE=&QE<@!:
M86UA;@!:86UA;B#=>FQE;64`6F%M86X@0FGG:6UI`%IA;6%N(%-EYVEM:0!4
M:6UO<BU,97-T90!"8?YL_6L`0F'^;/UK("AAY_UK;&%M82DZ`$MI;64`QV]K
M;'4@]O!E('-EYVEM:2!IYVEN+"!T_6ML87)K96X@0V]N=')O;"`H4$,I('9E
M>6$@0V]M;6%N9"`H36%C*2!T=?YU;F$@8F%S_6XN`$)U9_QN`$A434P@2V%Y
M;F'P_6YA($=EYVEN`%1O9V\`5&]K96QA=0!987+];@!4;VYG80#<<W0`W'-T
M(,=E<N=E=F4@*-Q?<W0I`,=E=FER:6QE<@!4<FEN:61A9"!V92!4;V)A9V\`
M1&_P<G4@=F5Y82!986YL_?X`4V$`5'5N=7,`5/QR:VEY90!4_')KYV4@*$E3
M3RTX.#4Y+3DI`%3\<FMM96YI<W1A;@!4=7)K<R!V92!#86EC;W,@061A;&%R
M_0!4=79A;'4`4V7G:6UI;FEZ:2!G:7)I;CH`52Y6+B!E;F1E:W,Z(`!54DP`
M0F5T:6ML97)I;B!D=7)U;2!R87!O<FQA<OUN_6X@=&5S;&EM(&5D:6QE8V7P
M:2!54DP`55),.@!59V%N9&$`56MR87EN80!61E,@9&EZ:6YI;F4@97)I_FEL
M96UE;6EY;W(N`-QY92!O;'5R:V5N(&5K(&MU;&QA;OUC_2!B:6QG:7-I(&5K
M;&5N96UI>6]R+@`B)7,B(%9&4R!D;W-Y87/];OUN(&EZ:6YL97)I(&1E\&G^
M=&ER:6QE;6EY;W(N`"5S+R5S(%9&4R!D;W-Y87/];OUN(&EZ:6YL97)I(&1E
M\&G^=&ER:6QE;6EY;W(N`"5S(&1E\&G^=&ER:6QE;65D:2X`4U%,('-U;G5C
M=7-U;F$@8F'P;&%N_6QA;?UY;W(N`%-33"!I;&4@8F'P;&%N_6QA;?UY;W(N
M`%9&4R!D;W-Y87/](&MO<'EA;&%N86W]>6]R+@`B)7,B(%9&4R!D:7II;FD@
M>6%R873];&%M_7EO<BX`5D93(&1I>FEN:2!Y87)A=/UL86W]>6]R+@!61E,@
M9&]S>6%S_2!Y87)A=/UL86W]>6]R+@!";_X@5D93(&1O<WEA<_T@>6%R873]
M;&%M_7EO<BX`5F5R:2!S_6O]_G3]<OUL86W]>6]R+@`B)7,B(&1I>FEN:2!S
M:6QI;F5M:7EO<BP@9&EZ:6X@8F_^(&1E\&EL+@`E<R!S:6QI;F5M:7EO<BP@
M9&EZ:6X@8F_^(&1E\&EL`%9&4R!D:7II;FD@]GIY:6YE;&D@;VQA<F%K('-I
M;&EN96UI>6]R+@!61E,@9&EZ:6YI('-I;&EN96UI>6]R+@!61E,@9&EZ:6YI
M('-I;&EN96UI>6]R.B`E<RX`5D93(&1O<WEA<_T@(B5S(B!S:6QI;F5M:7EO
M<BX`5D93(&1O<WEA<_T@<VEL:6YE;6EY;W(N`%9&4R#V>GEI;F5L:2!O;&%R
M86L@<VEL:6YE;6EY;W(Z("5S+@!9_'+\<FS\:W1E:VD@9&EZ:6YE(&MA<F%R
M('9E<FEL96UI>6]R+@!/;F%Y(&)E;&=E<VD@87ER_6YT_6QA<OT@Y_UK87)T
M_6QA;?UY;W(`5&%N_6W]('G\:VQE;F5M:7EO<CH@)7,`5D93(&1O<WEA<_T@
M=&'^_6YA;?UY;W(N`%9&4R!D;W-Y87/]("(E<R(@8>?];&%M_7EO<BX`5D93
M(&1O<WEA<_T@>6%M86L@:>=I;B!AY_UL86W]>6]R+@!61E,@9&]S>6%S_2!A
MY_UL86W]>6]R+@!3_6O]_G3];/UM_?X@87+^:78@8>?];&%M_7EO<BX`5F9S
M<F]O="!D:7II;FD@;VMU;F%M_7EO<BX`)7,M/B5S(&]L87)A:R!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(Z(&AE9&5F(&1I>FEN('IA=&5N('9A<BX`5D93
M(&1I>FEN:2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N`%9&4R!D:7II;FD@
M>65N:61E;B!A9&QA;F3]<OUL86W]>6]R.B`E<P!61E,@9&]S>6%S_2`B)7,B
M('EE;FED96X@861L86YD_7+];&%M_7EO<BX`)7,O)7,@5D93(&1O<WEA<_T@
M>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+@!61E,@9&]S>6%S_2!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(N`"=M:VES;V9S)R#G86S]_G3]<OUL86W]>6]R
M+@!"=2!7;W)D(&)E;&=E<VD@YV5V:7)I;&EL96UI>6]R+@!61E,@9&]S>6%S
M_2`B)7,B('EA>OUL86W]>6]R+@!61E,@9&]S>6%S_2!Y87K];&%M_7EO<B`H
M8V]P>2@I(&)A_F%R_7/]>B!O;&1U*2X`5D93(&1O<WEA('9E<FES:2!Y87K]
M;&%M_7EO<BX`06QT_6[](.=I>@!$9?!I_FEK;&EK;&5R:2!'97)I($%L`%-O
M;B!E>6QE;6D@9V5R:2!A;`!"8?!L86YT_61A('-U;G5C=61A;B!B96ML96YM
M97EE;B!Y86[]=#H@`%-U;G5C=61A;B!B96ML96YM97EE;B!Y86[]=#H@`$1O
M;&1U<G5L;6%M_?X`56YI8V]D92`H551&+3@I`$)I<FQE_FEK($%R87`@16UI
M<FQI:VQE<FD`0FER;&7^:6L@2W)A;&S]:P!!;65R:6MA($)I<FQE_FEK($1E
M=FQE=&QE<FD`06UE<FEK82!":7)L9?YI:R!$979L971L97)I;FEN($O\Y_QK
M(%5Z86L@061A;&%R_0!":7)I;6QE<@!":6QI;FUE>65N`$)I;&EN;65Y96X@
M87!I;7-G:60@*$%022!-97-A:B!)1"D`0FEL:6YM97EE;B!C;&EM<V=I9"`H
MW7-T96UC:2!M97-A:B!)1"D`0FEL:6YM97EE;B!K=6QL86[]8_T@863]('9E
M>6$@<&%R;VQA+@#>=2!A;FMI(/;P96YI;B!B8?#];OT@Y_9Z`-US:6US:7H`
M07ER_6-A;/UK<_UZ(&)E=&EK;&5R('!R;V=R86US86P@;VQA<F%K($ME<R]+
M;W!Y86QA+UEA</W^=/UR)V$@9_QV96YL:6L@;F5D96YI>6QE(&5R:?YE;65Z
M;&5R+B!"971I:VQE<FEN('!A;F]Y82!N87/];"!U;&'^86-A\/UN_2!G]G-T
M97)E;B!M;WII;&QA+F]R9R!T96MN:6L@;F]T=6YU(&?V<FUE:R!IYVEN($56
M150@:2!T_6ML87G];BX`0F5L:7)T:6QM:?X@<F5N:W1E;B!V87IG9><`1&5S
M=&5K;&5N;65Y96X@57IA;G3]`$?\;F-E;&QE`$?\;F-E;&QE.B`E<P!+=6QL
M86[]8_UY_2!G_&YC96QL90!9_&MS96QT;64@8F5T:?!I('-I;&EL;F1I+@!9
M_&ML90!"_'3\;B!U>6=U;&%M86QA<OUN(&%Y87(@9&]S>6%L87+]('-U;G5C
M=7EA('G\:VQE;F1I+@!"_'G\:R!L871I;B!H87)F;&5R:0!"_'G\:R!R;VUA
M(')A:V%M;&%R_0!5<G5G=6%Y`$MU;&QA;CH@)7,`4U-,(&MU;&QA;@!+=6QL
M86[]8_T@863];OUZ+W!A<F]L86[]>B!)35-0('-U;G5C=2!IYVEN(&9A<FML
M_2!I<V4@:W5L;&%N_6XN`"5S(&MU;&QA;OUC_7/]("5S(&GG:6X@9&_P<G5L
M86YA;6%D_2X`2W5L;&%N_6/](%GV;F5T:6UI`$MU;&QA;OUC_2!39>=E;F5K
M;&5R:0!+=6QL86[]8_T@2V%Y_70`0G4@<VET92!IYVEN(&MU;&QA;OUC_2!K
M87ED_2!S9>=I;&UE>B!K_6S];FW]_G3]<BX`2W5L;&%N_6/]($%D_0!+=6QL
M86[]8_T@063].@!+=6QL86[]8_T@863].B``4VES=&5M9&5K:2!K=6QL86[]
M8_UL87(Z`-9Z8F5K:7-T86X`5D93(&1I>FEN:2!Y;VLN`%1A=&EL`$=EYV5R
M;&D@:V]N=6UL87+];B!IYV5R9&EK;&5R:3H`1V7G97)L:6QI:P#>=2!A;F1A
M;B!I=&EB87)E;B!D86MI:V$@9&7P97)I`$1E\&5R;&5R`$1E\&5R;&5R:6X@
M<V7G:6QE8V7P:0!686YU871U`$1E\&G^:V5N`%9E;F5Z=65L;&$`1&_P<G5L
M86UA(&)A_F%R_7/]>B!O;&1U("T@8G4@:6QE=&D@:W5R8V%L86YM_?X@;VQA
M8FEL:7(N("``4_QR_&T`4_QR_&T@2V]N=&]L_`!$_/YE>2!(:7IA`$3\_F5Y
M('EA<W3]:VQA;6$`1/S^97DZ`,=O:R!9_&MS96L`5FEE=&YA;0!6:65T;F%M
M8V$@*%9)4T-)22D`1_9R_&YT_&QE("5S`$)I<B!D_?X@=V5B('-A>69A<_T@
M9_9R_&YT_&QE`"5S(&]L87)A:R!G]G+\;G3\;&4`0G)I=&%N>6$G>6$@86ET
M(%9I<F=I;B!!9&%L87+]`$%M97)I:V$@0FER;&5R_FEK($1E=FQE=&QE<FDG
M;F4@86ET(%9I<F=I;B!!9&%L87+]`$?V<OS^`$?V<OS^.@!33510('EO;'5Y
M;&$@5F]D869O;F4@W71A;'EA`%=!4DX`55E!4DDA(2$E<R#=Q]U.1$5.($)%
M5-W0W2!%3"#=3$4@QTE+05)424XN`%=A;&QI<R!V92!&=71U;F$`57EA<OT`
MQW+^`$AA=F$@5&%H;6EN:0!(879A('9E<FES:2!S8?!L87G]8_US_0!796%T
M:&5R+F-O;0!796(`5V5B(%-I=&5S:0!(869T86S]:P!(;_YG96QD:6YI>@`E
M<R!(;_YG96QD:6YI>@!(;_YG96QD:6YI>BP@)7,`0F%T_2`H25-/+3@X-3DM
M,2D`0F%T_2`H25-/+3@X-3DM,34I`$)A=/T@4V%H<F$`)7,@9VER:?YT96X@
M<V]N<F$@:&%N9VD@=7EG=6QA;6%Y_2!G]G+\;G3\;&5S:6X_`%/];OUR;&%Y
M_6/](&MA<F%K=&5R(&YE9&ER/P!!:W1A<OUM(&MA<F%K=&5R:2!N961I<C\`
M2&%N9VD@179R90!:96YG:6X@365T:6X@9/QZ96YL97EI8VES:2!IYVEN(&AA
M;F=I('5Y=6UL=2!E:VQE<B!S9>=I;&5B:6QI<B!K_6S];G/];BX`1V5N:?YL
M:6L`0U-3(&)I<FEM:7EL92!G96YI_FQI:P!3;VQD86MI("5S(&UE;OQS_&[\
M;B!G96YI_FQI\&D@*&)I<B!S;VYR86MI(&=I<FG^=&4@971K:6X@;VQA8V%K
M*3H`QVEZ96QG96YI;B!G96YI_FQI\&D`1V5N:?YL:6L@8FER:6UI`$=E;FG^
M;&EK.@!7:6MI`%+\>F=A<@!%<FME;B!386%T;&5R9&4@4OQZ9V%R`$MN;W0@
M8FER:6UI;F1E('+\>F=A<B!H_7K]`%+\>F=A<CH`4OQZ9V%R.B``0FEL9V5L
M:6L`W?X`W?X@061R97-I`-W^(%1E;&5F;VYU`%@M4F5F`%@U,#EV,R!496UE
M;"!+_7/]=&QA;6%L87+]`%@U,#EV,R!'96YI_FQE=&EL;6G^($%N86AT87(@
M2W5L;&%N_6W]`%@U,#EV,R#6=&5K:2!+;VYU($%D_0!8-3`Y=C,@2V]N=2!!
M;F%H=&%R(%1A;OUT_6/]<_T`6#4P.78S('5Z86YT_6QA<OT`65D`65E960!9
M86AO;R$@:&%R:71A<_T`6?UL;/UK`%EE;65N`$5V970`179E="P@2V%B=6P@
M161I>6]R=6T`3454W4X@34]$54Y$05-)3DE:+B!;/#Y=(&3\\&UE;&5R:6YI
M(&MU;&QA;F%R86L@5UE325=91R!G]G+\;OQM_&YE(&3V;OQN+@!$;_!R=6QA
M;F%M863];OUZ+@`G7"<@:V%R86MT97)I('1A;2!A9/UN_7ID82!B=6QU;F%M
M87HN`$=EYV5R;&D@8FER(&5L96MT<F]N:6L@<&]S=&$@861R97-I(&=I<FUE
M9&EN:7HN`"5S(&GG:6YD92!K87+^_6S]:R!G96QE;B!A;&%N;&%R;&$@*&GG
M97)I*2!A:W1A<OUL86X@9&]S>6%D86MI(&%L86YL87+](&7^;&7^=&ER;65D
M:6YI>BX`Q_UK_?X@>6%P;6%D_6[]>BX`1V7G97)L:2!B:7(@8V5P('1E;&5F
M;VYU(&YU;6%R87/](&=I<FUE;&ES:6YI>BP@<V%Y_6QA<B!V92!S9>=E;F5K
M;&D@;VQA<F%K('5L=7-L87)A<F%S_2!A<F%M82#V;F5K:2`G*R<@`$=EYV5R
M;&D@8FER(&1E\&5R(&=I<FUE;&ES:6YI>BX`W'EE(&MA>63]('EA<&%B:6QM
M96L@:>=I;B!B:7(@5F5R:4'P86/]('EA</UL86YD_7)M86S]<_UN_7HN`%9&
M4R!S;VX@8?YA;6%S_6[]('EA</UL86YD_7)M86S]<_UN_7HN`%!R;V)L96T@
M<F%P;W)U(&?V;F1E<FUE9&5N(/9N8V4@<V]R=6YU('1A<F9I(&5T;65L:7-I
M;FEZ+@!"=2!B8?!L86YT_6[];B!G]G-T97)D:?!I(&)I<B!54DP@9VER;65L
M:7-I;FEZ`%-I;&EN;65S:2!IYVEN(&)I<B!S=6YU8W4@<V7G;65L:7-I;FEZ
M+@!496UI>FQE;FUE<VEN(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T
M;65L:7-I;FEZ+@!3:6QI;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B
M96QI<G1M96QI<VEN:7HN`$5K;&5N;65S:2!IYVEN(&)I<B!K=6QL86[]8_T@
M863](&)E;&ER=&UE;&ES:6YI>BX`1_QN8V5L;&5N;65S:2!IYVEN(&)I<B!K
M=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BX`1V5RYV5K;&7^=&ER:6QE
M8V5K(&)I<B!E>6QE;2!B96QI<G1M96QI<VEN:7HN`%EE;FD@:V%T96=O<GD@
M863](&=I<FUE;&ES:6YI>BX`)7,@;W1U<G5M=6YU;B!S_')E<VD@9&]L9'4N
M($S\=&9E;B!T96MR87(@9VER:?X@>6%P_6XN`$5L96MT<F]N:6L@4&]S=&$@
M061R97-I;FEZ`$MI;61E;CH@861R97,Z`$)I;&=I;&5R:6YI>@`E<R!O='5R
M=6UU;G5Z=6X@8F'^;&%N9_UC_6YD82#=;G1E<FYE="!!9')E<VEN:6YI>B!D
M9?!I_G1I+B!'_'9E;FQI\&EN:7II(&MO<G5M86L@:>=I;BP@>65N:61E;B!G
M:7)I_B!Y87!M86S]<_UN_7HN`$%D_6[]>@!+:6UL:6L@9&5N971I;6EN:7H@
M:W5L;&%N_6/](&QI<W1E;&5M97EI(&1E<W1E:VQE;65M96MT961I<B!V97EA
M(&)U(/9Z96QL:6L@8FER(&YE9&5N('G\>OQN9&5N('-EYVEL96UE>B!K_6S]
M;FW]_G3]<BX`)7,@;W1U<G5M=6YU>G5N(&)A_FQA;F?]8_UN9&$@=&%R87G]
M8_UN_7H@9&7P:?YT:2X@1_QV96YL:?!I;FEZ:2!K;W)U;6%K(&GG:6XL('EE
M;FED96X@9VER:?X@>6%P;6%L_7/];OUZ+@!487)A>?UC_6[]>B!B=2#V>F5L
M;&GP:2!D97-T96ML96UE;65K=&5D:7(N`%IA;6%N($1I;&EM:6YI>CH`UFX@
M=&%N_6UL_2!K:6UL:?!I;FEZ.@!486T@063];OUZ.@`E<R!IYVEN('EE;FD@
M<&%R;VQA;OUZ.B`E<P!39>=E;F5K;&5R:6YI>B!B=2!O='5R=6UU;B!S_')E
M<VD@:>=I;F1E(&?\;F-E;&QE;F1I+@!39>=E;F5K;&5R:6YI>B!G_&YC96QL
M96YD:2X`4&%R;VQA;OUZ('/]9OUR;&%N9/TN`%!A<F]L86[]>B!S_6;]<FQA
M;F3]+"!E;&5K=')O;FEK('!O<W1A;OUZ_2!K;VYT;VP@961I;B!V92!Y96YI
M('!A<F]L86[]>FQA(&=I<FG^('EA</UN+@!5>F%K=&%K:2!S=6YU8W5L87+]
M;OUZ.@!9=6=O<VQA=GEA`%IA:7)E`%IA;6)I80!::6UB86)V90!(_7IL_0!;
M06S];G3]($UE=&YI(%-A:VQA70!;4')O8FQE;2!287!O<G5=`%M!;/UN=/T@
M365T;FD@1_9S=&5R("T`6T%L_6YT_2!-971N:2!']G-T97(@+2`E<R!S873]
M<ET`)7,O)7,@<V%T_7(`7UGV;F5T:6T`7T-,20!?5F5R:4'P86/]`%-A=/UR
M_2!?4VEL`%]'<G5P;&%R`%EA<E]D_6T`1_9R_&YT_"#67WIE;&QI:VQE<FDN
M+BX`1VE?<FG^`,?]7VO]_@!?0F'P;&%N=/UY_2!$9?!I_G1I<BXN+@!?4V7G
M96YE:VQE<@!?2&%K;&%R`$)A\&QA7VYT_7G](%-I;"XN+@!?07EA<FQA<@#'
M:7IE7VQG92#6>F5L;&EK;&5R:2XN+@!+7W5L;&%N_6/];&%R`&%D<F5S(&1E
M9G1E<FD`=&%K=FEM`/UL_6UL_0!B=7)A>6$@=/UK;&%Y_6X`9/S^_'EO<@!D
M;W-Y80`E<R`H)7,I(&1E;B`E<R`E<R!D90!H.@!!8VEL`$UE=&YE(&?V;?QL
M_`!S873]<FQA<ET`;6MI<V]F<R!)4T\@>6%P87)K96X@:&%T82!K;V1U.B5D
M+@!A9`!G97+G96ML9?YT:7)I;&UE9&D`:&5N_'H@9V5RYV5K;&7^=&ER:6QM
M961I`&YO="!D969T97)I`'G\>F1E`')E<VEM(&)I<FEM:0!Y_&MS96QI>6]R
M`&9A<FML87+](&?V<W1E<@!(5%10('EO;'5Y;&$@<VUS,F5M86EL`'-A8FET
M`&?V<F5V(&QI<W1E<VD`<&%R;VQA>?T@9&_P<G5L86UA:R!IYVEN(&EK:2!D
M969A(&=I<FEN`&)I<FQE_G1I<FEL;6G^`&%D;&%N9/UR_6QM86W]_@!K=6QL
M86[]8_T@<V7G:6UI`'9#87)D`'<Z`'=E871H97(N8V]M````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]T<E]44B]H96QP+GAM;```````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V,C``,3`T,3<S-C,P,#$`
M,#(P,S4S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3DB
M/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]T<E]44B]H96QP+GAM;"QV
M(#$N,2XR+C$@,C`P-2\Q,"\Q."`Q,3HS,SHT-B!J86X@17AP("0@+2T^"CQH
M96QP/@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G-U;6UA<GDB
M/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H
M:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L
M;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@
M:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO
M=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO
M=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D
M;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN
M("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC
M:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O
M;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A
M;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@
M(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI
M>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y
M;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@
M<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@
M87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@HM+3X*/&5N=')Y(&ED/2)S
M=6UM87)Y(B!M9#4](C8X8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U
M(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^1VER:?X@4V%Y9F%S_3PO=&ET
M;&4^"CQP87)A/@I':7)I_B!S87EF87/]('-I>F4@]FYE;6QI(&)I;&=I;&5R
M:6YI>FEN(&O]<V$@]GIE=&EN:2!V97)I<BX@UG)N9?!I;BP@9V5L96X@:W5T
M=6YU>F1A(&MAYR!T86YE('EE;FD@96QE:W1R;VYI:R!P;W-T82!O;&1U\'5N
M=2P@=&%K=FEM:6YI>F1E:VD@>6%K;&'^86X@;VQA>6QA<OTL('EA</UL86-A
M:VQA<B!L:7-T97-I;F1E:VD@:?YL97)I;FEZ:2P@<V7G:6QI(&AA8F5R('-E
M<G9I<VEN9&5K:2!B8?YL_6ML87+]('9S+B!G]G-T97)I<BX@0G4@]GIE=&QE
M<FEN(.=O\'4@9V5N96P@9F]N:W-I>6]N;&%R(&GG:6X@:_US87EO;&QA<B!I
MYV5R96-E:W1I<BP@('EE;FD@<&]S=&$@;VQU_G1U<FUA:RP@>65N:2!T86MV
M:6T@;VQA>?T@>6$@9&$@:?YI(&]L=?YT=7)M86L@9VEB:2X*/"]P87)A/@H\
M<&%R83X*1VER:?X@<V%Y9F%S_6[];B!IYV5R:?!I(&3\>F5N;&5M92!T=?YU
M(&EL92!I<W1E\&4@=7EA<FQA;F%B:6QI<BX@(M9R;F7P:6XL(&=I<FG^('-A
M>69A<_UN_6X@:&%N9VD@]O!E;&5R:2!IYV5R96-E\&EN:6X@>6%N_6YD82!B
M=2#V\&5L97)I;B!G]G-T97)I;&UE('/]<F%L87+](&1A('-EYVEL96)I;&ER
M+@H\+W!A<F$^"CPO96YT<GD^"@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT
M<GD@:60](FYA=F)A<B(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A
M=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S
M:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A
M=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A
M=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E
M96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT
M<GD^"BTM/@H*/&5N=')Y(&ED/2)N879B87(B(&UD-3TB8CAC9C!A93$Y934W
M9&9A,&,R8CDV,F4U,38W.#)F-#<B('-T871E/2)U<'1O9&%T92(^"CQT:71L
M93Y5>6=U;&%M82!$;VQA_OUM(,=U8G7P=3PO=&ET;&4^"CQP87)A/@I5>6=U
M;&%M82!D;VQA_OUM(.=U8G7P=2!W96(@<V%Y9F%S_6[];B!S;VP@:V5N87+]
M9/UR+B!-979C=70@=7EG=6QA;6%L87(@87)A<_UN9&$@(&C]>FS]('9E(&MO
M;&%Y8V$@9V5Z:6YE8FEL;65K(&GG:6X@=6QA_OUM(.=U8G7P=6YD86MI('-I
M;6=E;&5R:2!T_6ML87G];OUZ+@H\+W!A<F$^"CPO96YT<GD^"@H*/"$M+2!%
M;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA
M:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD
M(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*+2T^
M"@H\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!M9#4](F1D.35D
M9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(B!S=&%T93TB=7!T;V1A=&4B
M/@H\=&ET;&4^5&5R8VEH;&5R.B!"86O];3H@0F%K_6T@66%P;6$\+W1I=&QE
M/@H\<&%R83X*4VES=&5M92!G:7)E<FME;B!B86O];2!I_FQE;6QE<FD@>6%P
M;6%K(&ES=&5R<V5N:7H@8G4@:W5T=7EU(&G^87)E=&QE>6EN:7HN"CPO<&%R
M83X*/"]E;G1R>3X*"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)P
M<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M
M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C
M:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N
M86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P
M97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC
M96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"BTM/@H*/&5N=')Y
M(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!M9#4](F$R,3$V,F-D
M9F8S8C%D.&9A96%D8C<R.38R-#`P,S9E(B!S=&%T93TB=7!T;V1A=&4B/@H\
M=&ET;&4^5&5R8VEH;&5R.B!"86O];3H@0F%K_6T@1&_P<G5L86UA/"]T:71L
M93X*/'!A<F$^"D)A:_UM(&?V<F5V;&5R:6YI(.=A;/W^;6%Y82!B8?YL86UA
M9&%N(/9N8V4@9&_P<G5L86UA:R!I<W1I>6]R<V%N_7H@8G4@:W5T=7EU(&G^
M87)E=&QE>6EN:7HN($7P97(@:W5T=2!I_F%R971L96YM96UI_B!I<V4@YV%L
M_?YM87/](&=E<F5K96X@8OQT_&X@8F%K_6T@:?YL96UL97)I;FEZ('-I<W1E
M;64@9VER97)K96X@+&EP=&%L(&5T;64@_F%N<_UN_7H@;VQM861A;B!O=&]M
M871I:R!O;&%R86L@9V5RYV5K;&7^96-E:W1I<BX*/"]P87)A/@H\+V5N=')Y
M/@H*/"]H96QP/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O=6M?54$O````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`Q
M`#`Q-C8U,@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]U:U]502],
M0U]-15-304=%4R\`````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C,P,#$`,#(P-#,W`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+W5K7U5!+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,3$Q,``Q,#0Q-S,V,S`P,0`P,C(P-C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````WA($E0``
M``!0````'````)P"``!K````'`4```````#(!@``*````,D&```(````\@8`
M``\```#[!@``"`````L'```(````%`<``!D````=!P``!P```#<'```.````
M/P<```4```!.!P``$0```%0'```(````9@<``!4```!O!P``"@```(4'```,
M````D`<```<```"=!P``$````*4'```"````M@<```4```"Y!P``$````+\'
M```&````T`<``!0```#7!P``!0```.P'```-````\@<```4`````"```"P``
M``8(```/````$@@```,````B"```!````"8(```,````*P@```H````X"```
M!0```$,(```2````20@``!````!<"```$````&T(```:````?@@```8```"9
M"```!P```*`(```"````J`@```0```"K"```#P```+`(```'````P`@```<`
M``#("```!````-`(```%````U0@```@```#;"```%0```.0(```>````^@@`
M``4````9"0``*````!\)```I````2`D``!,```!R"0``"P```(8)```%````
MD@D``!$```"8"0``!````*H)```,````KPD``!H```"\"0``%P```-<)```7
M````[PD``!,````'"@``$````!L*```7````+`H```<```!$"@``!0```$P*
M```#````4@H```P```!6"@``"````&,*```4````;`H```<```"!"@``!@``
M`(D*```+````D`H```P```"<"@``"@```*D*```"````M`H```8```"W"@``
M10```+X*```F````!`L``"4````K"P``$````%$+``!G`0``8@L``#H```#*
M#```"0````4-```:````#PT```L````J#0``$@```#8-```B````20T```8`
M``!L#0``#P```',-```)````@PT```X```"-#0``#P```)P-```?````K`T`
M`!0```#,#0``#0```.$-```(````[PT``!0```#X#0```@````T.```'````
M$`X``!`````8#@``!P```"D.```0````,0X```<```!"#@``$P```$H.```'
M````7@X```T```!F#@``$@```'0.```$````APX```@```",#@``#@```)4.
M```0````I`X```4```"U#@``%````+L.```1````T`X``!D```#B#@``*0``
M`/P.```&````)@\```4````M#P```@```#,/```*````-@\```\```!!#P``
M!````%$/```(````5@\```0```!?#P``!P```&0/```&````;`\``!@```!S
M#P``'P```(P/```'````K`\``"D```"T#P``+@```-X/```-````#1````P`
M```;$```"````"@0```4````,1````0```!&$```#@```$L0```9````6A``
M`!4```!T$```%0```(H0```C````H!```!<```#$$```&0```-P0```'````
M]A````4```#^$````P````01```/````"!$``!$````8$0``%@```"H1```%
M````01$```<```!'$0``#0```$\1```-````71$```\```!K$0```@```'L1
M```'````?A$``$4```"&$0``,0```,P1```Q````_A$``!<````P$@```0``
M``````!-````'0```$4````5````"````"(````Y```````````````<````
M1P`````````4````+@`````````[````-@```$D````F````,0``````````
M`````````"<````>````+0````T`````````*0`````````"`````````$\`
M```E````0@```$P``````````````"@````^````&````!\````6````&P``
M`",````)````,````#4````$````"P````4````,````#P```"\```!`````
M&@```$8```!+````3@```#(```!#````/0````8````K```````````````_
M````2````#@````*````````````````````/``````````.`````````!,`
M```1````(````!`````A````2@`````````#````4````!(````T````````
M`````````````````!<```!!````,P```!D````J`````````"0`````````
M!P```#<```!$````.@```"P`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`R-"!H;W5R<P!!9&0@82!N97<@=7-E<CH`061D
M('!A:7(`061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R
M97-S`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%V86EL86)L92!F:65L9',Z`$)I
M<G1H9&%Y`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E
M(%=I;F1O=P!#;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`1$0`1&%I;'D`1&5F
M875L="!)9&5N=&ET>0!$96QE=&4`1&5S8W)I8F4@=&AE(%!R;V)L96T`16UA
M:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2!,;V=I;@!%>&%M<&QE('9A
M;'5E<SH`1F%X`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&ES="!(96QP
M(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G
M(&]U=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-97-S86=E`$UO;G1H;'D`
M3F%M90!.;W1E<P!087-S=V]R9`!087-S=V]R9',@;75S="!M871C:"X`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!H;VYE`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4')O8FQE;2!$97-C<FEP=&EO
M;@!296UO=F4@<&%I<@!297-E=`!2971U<FX@=&\@3W!T:6]N<P!2;VQE`%-A
M=F4@3W!T:6]N<P!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396YD
M(%!R;V)L96T@4F5P;W)T`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W5C8V5S<P!4:71L90!54DP`56YD;R!#:&%N9V5S`%5S
M97)N86UE`%5S97)S(&EN('1H92!S>7-T96TZ`%=A<FYI;F<`5V5E:VQY`%=E
M;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+@!;4')O8FQE;2!297!O<G1=`%!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@=C(N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ
M,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#$M,#4@,38Z,34K,#(P
M,`I,87-T+51R86YS;&%T;W(Z($%N9')I>2!+;W!Y<W1Y86YS:WD@/&%N<FE`
M<&]L>6YE="YL=FEV+G5A/@I,86YG=6%G92U496%M.B!5:W)A:6YI86X@/'=E
M8FUA<W1E<D!P;VQY;F5T+FQV:78N=6$^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U+3TDX+54*0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`._0Q=+!PZ;1(-#2S\:FS,'+
MU,G>SL_'SR#/PM/,U<?/U]77P<[.T2`E<R`M(/"FQ-37Q=+$UL7.SM$`,C0@
MQ\_$R<[)`.3/Q,'4R2#.S]?/Q\\@R\_2R=/4U=?!WL$Z`.3/Q,'4R2#0P=+5
M`.3/Q,'4R2#+S]+)T]35U\'>P0#DS\3!U\'.SM$@R\_2R=/4U=?!WJ;7(-K!
MPL_2S\[%SL4N`.'$TL73P0#AQ,VFSJ;3U-+5U\'.SM$`\-/%U\3/SJ;-`.3/
MT]35T,ZF(-#/S-$Z`.3%SM@@SL'2S\36Q<[.T0#WIL3-IL[)U,D@T,_7IL3/
MS<S%SL[1(-#2S\+,Q<W)`//4ILS8SLG+S]?)RB#4Q<S%QL_.`/K!R]+)U,D@
MUZ;+SL\`Z\_-T,'.IM$`\*;$U-?%TL36Q<[.T2#0P=+/S,``Y.0`_<_$Q<[.
MSP#OT\[/U\[!(*;0S]/4P=/8`/?)U,72U,D`[]#)VZ;4V"#0TL_"S,7-U0#E
M+=#/V]3!`/#/TL_6SJ;*(-+%VM7,V-3!U"X`\,_-R<S+P0#KS];.S\?/(-?(
MS\35`.3!SJ8@Q,S1(-#2R<O,P<35.@#FP<O3`.3/T,_-S\?!`.3/S<';SM$@
MP<32Q=/!`.3/S<';SJ;*(-3%S,7&S\X`2&]R9&4`MLW0S]+4S]?!SL4@T,_,
MQ3H@)7,`MLW0S]+4S]?!SJ8@T,_,T3H`\,72Q<RFRR#2S]K$ILRFUR#DS]#/
MS<_'R0#PQ=+%Q\S1Q"#3T,G3R]4@R\_2R=/4U=?!WJ;7(-K!PL_2S\[%SLG*
M+@#WUZ;*U,D`]\G*U,D`[>T`24U0+=#/TM3!S`#WIL30S]>FQ,ZF(-#/S-$`
M[,G3U`#]S\VFT]'#T0"VS6#1`.[/U,'4R\D`\,'2S\S8`/#!TL_,V"#-U=/)
MU-@@T]"FU]#!T]3)+@#WR<O/SL'4R2#0TL_&ILS!R]3)WLZF(,_0Q=+!PZ:G
M`/3%S,7&S\X`XM7$V"W,P=/+P2P@Q,'*U,4@R\_2S]3+R<H@S]#)TR#0TL_"
MS,7-R2X`XM7$V"W,P=/+P2P@U\O!UJ;4V"#.P=K7U2#+S]+)T]35U\'>P2"F
M(-#!TL_,V`#OT,G3(-#2S\+,Q<W)`/?)U,72U,D@T,'2U0#OWLG3U,G4R0#P
MS]?%TL[5U,G3T2#$SR#OT,.FR@#RS\S8`/K"Q=+%Q]3)(,_0PZ:G`/?)PL72
MIM38(-+/VL2FS,#7P=X@Q,'4R3H`]\G"Q=*FU-@@QL_2S<'4(,3!U,DZ`/?)
MPL72IM38(,;/TLW!U"#>P=/5.@#WIL2FT\S!U,D@T,_7IL3/S<S%SL[1(-#2
MSR#0TL_"S,7-U0#PTL_0U=/4R=3)(-#2S\:FS,'+U,G+U0#WUZ;$(//0Q<.F
MP<S8SLG((-/)S=?/S*;7`/73T*;;SL\`],G4U<P`55),`//+P=/5U\'4R2#:
MS:;.R0#NP=K7P2#+S]+)T]35U\'>P0#KS]+)T]35U\'>IB#7(-/)T]3%S:8Z
M`/77P<?!`/W/U,G6SM$`]Z;4P<`@]\'3+"`E<P#RS\+/WL$@P<32Q=/!`/+/
MPL_>R<H@U,7,Q<;/S@#R\@#]S]*FWL[/`/?)(-#/U\G.SJ8@S]#)T\'4R2#0
MTL_"S,7-U2P@T,72VR#.IM8@UZ;$T\G,P=3)(-#/UZ;$S\W,Q<[.T2#0TL\@
MSL6G+@#WP<T@T\RFQ"#7R\':P=3)(,[!VM?5(,O/TLG3U-77P=[!(,3,T2#7
MR<3!S,7.SM$N`/?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@
MQ,S1(,3/Q,'7P<[.T2X`6_#/UZ;$S\W,Q<[.T2#PTL_"S,7-R5T`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]U:U]502]H96QP+GAM;```````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`T,3<S-C,P,#$`,#(P
M,S$W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C
M86QE+W5K7U5!+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,3(@
M:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T
M871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP
M87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM
M87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@
M97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE
M<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E
M;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L
M:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A
M;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N
M=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C
M:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG
M(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*
M(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R
M92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E
M>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E
M(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R
M9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A
M=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@
M;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A
M=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@
M=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I
M=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA
M;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E
M;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-
M86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA
M:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H
M:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE
M9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L
M;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O:F%?2E`O````````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`Q`#`Q-C8S,0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]J85]*4"],0U]-15-304=%
M4R\`````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C,P,#$`,#(P-#$V`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+VIA7TI0+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#,Q,#$W-P`Q,#0Q-S,V,S`P,0`P,C(P-C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````"I!0``'```
M`&0M``"-!P``K%H```````#@>```#@```.%X```/````\'@```T`````>0``
M"`````YY```+````%WD```P````C>0``&````#!Y```;````27D``"T```!E
M>0``'0```)-Y```D````L7D``"D```#6>0``&0````!Z```F````&GH```P`
M``!!>@``)````$YZ```+````<WH```X```!_>@``!0```(YZ```H````E'H`
M``@```"]>@``"@```,9Z```5````T7H``!(```#G>@``A0```/IZ```.````
M@'L```H```"/>P``#0```)I[```.````J'L``!$```"W>P``#0```,E[```,
M````UWL```T```#D>P``!@```/)[``"4````^7L```P```".?```#@```)M\
M```.````JGP```@```"Y?```"0```,)\```N````S'P``!H```#[?```,@``
M`!9]```X````27T``%0```""?0``40```-=]``!:````*7X``%<```"$?@``
M-````-Q^```%````$7\``!$````7?P``)0```"E_```@````3W\``!,```!P
M?P``$````(1_```/````E7\```H```"E?P```P```+!_```/````M'\``!0`
M``#$?P``"0```-E_```-````XW\``!(```#Q?P``&0````2````>````'H``
M``\````]@```"@```$V````/````6(````@```!H@```)````'&````4````
MEH```!8```"K@```"````,*```!.````RX```"T````:@0``&0```$B!```'
M````8H$```P```!J@0``+````'>!```.````I($```,```"S@0``"P```+>!
M```'````PX$```<```#+@0``!0```-.!```*````V8$```,```#D@0``%P``
M`.B!```*`````((```\````+@@``&````!N"```C````-((```X```!8@@``
M%````&>"```7````?((``!<```"4@@``%P```*R"```3````Q((```\```#8
M@@``#@```.B"```?````]X(``!T````7@P``!P```#6#```&````/8,```@`
M``!$@P``#P```$V#```&````78,```H```!D@P``$P```&^#```+````@X,`
M`!````"/@P``%0```*"#```5````MH,```<```#,@P``$````-2#```%````
MY8,``!$```#K@P``#````/V#```[````"H0``#@```!&A```"0```'^$```'
M````B80```4```"1A```$````)>$```3````J(0``#D```"\A```)P```/:$
M```L````'H4``"H```!+A0``)0```':%```*````G(4```8```"GA0``"0``
M`*Z%```'````N(4``"\```#`A0``-P```/"%```N````*(8``%4```!7A@``
M+0```*V&```M````VX8``#T````)AP``/P```$>'```M````AX<``$````"U
MAP``(P```/:'```C````&H@``$`````^B```+0```'^(```S````K8@``"4`
M``#AB```%0````>)```9````'8D``"D````WB0``)````&&)```H````AHD`
M`!$```"OB0``"@```,&)```*````S(D``!````#7B0``%@```.B)```6````
M_XD```<````6B@``!P```!Z*```*````)HH```@````QB@``)P```#J*```(
M````8HH```<```!KB@``!P```'.*```&````>XH```4```""B@``!P```(B*
M```&````D(H```@```"7B@``*0```*"*```.````RHH```H```#9B@``!```
M`.2*```'````Z8H```D```#QB@``!@```/N*```1`````HL```<````4BP``
M%@```!R+```(````,XL```T````\BP``!@```$J+```>````48L``!$```!P
MBP``"````(*+```-````BXL```P```"9BP``!P```*:+```#````KHL```,`
M``"RBP``%P```+:+```3````SHL``!T```#BBP``"`````",```(````"8P`
M``@````2C```00```!N,```:````78P``"L```!XC```(````*2,```5````
MQ8P```8```#;C```!@```.*,```5````Z8P``!@```#_C```(@```!B-```N
M````.XT``!T```!JC0``(0```(B-``!4````JHT``"D```#_C0``"@```"F.
M```'````-(X```<````\C@``%0```$2.```.````6HX```H```!IC@``#P``
M`'2.```-````A(X```\```"2C@``#0```**.```)````L(X```8```"ZC@``
M&````,&.```3````VHX``!$```#NC@``%`````"/```$````%8\```8````:
MCP``%````"&/``!4````-H\``&0```"+CP``#@```/"/```%````_X\```4`
M```%D```$P````N0```1````'Y```!$````QD```'````$.0```0````8)``
M`"$```!QD```$P```).0```+````IY```!(```"SD```"@```,:0```/````
MT9```!$```#AD```#````/.0```7`````)$``!`````8D0``"````"F1```%
M````,I$```P````XD0``$````$61```%````5I$```T```!<D0``!@```&J1
M```'````<9$```T```!YD0``!P```(>1```+````CY$```<```";D0``!P``
M`*.1```9````JY$``#T```#%D0``'0````.2```,````(9(``!`````ND@``
M!0```#^2```E````19(``!(```!KD@``$P```'Z2```K````DI(``#L```"^
MD@``(````/J2```(````&Y,``#8````DDP``(0```%N3```0````?9,```@`
M``".DP``#````)>3```$````I),```\```"IDP``#@```+F3```*````R),`
M``T```#3DP``'P```.&3```<`````90``"$````>E```'@```$"4```9````
M7Y0``!X```!YE```&P```)B4```A````M)0``"X```#6E```)@````65```<
M````+)4``!X```!)E0``'````&B5```F````A94``"L```"LE0``,P```-B5
M```F````#)8``"L````SE@``.````%^6```=````F)8``!4```"VE@``+P``
M`,R6```@````_)8``!(````=EP``*0```#"7```>````6I<``"````!YEP``
M$@```)J7``"B````K9<``!8```!0F```(P```&>8```H````BY@``"D```"T
MF```*````-Z8```?````!YD``!4````GF0``(````#V9```E````7ID``"@`
M``"$F0``+0```*V9```P````VYD``)(````,F@``(0```)^:```6````P9H`
M`!P```#8F@``)@```/6:```J````')L``$$```!'FP``!P```(F;```&````
MD9L``!````"8FP``$@```*F;```3````O)L``!(```#0FP``!P```..;```$
M````ZYL``!````#PFP``#`````&<```.````#IP```T````=G```*````"N<
M```#````5)P```T```!8G```!@```&:<```.````;9P```(```!\G```!0``
M`'^<```0````A9P```\```"6G```!````*:<```-````JYP```X```"YG```
M#@```,B<```(````UYP```\```#@G```#P```/"<```'`````)T```T````(
MG0``$````!:=```-````)YT```8````UG0``"P```#R=```,````2)T```H`
M``!5G0``$0```&"=```+````<IT```T```!^G0``(@```(R=```/````KYT`
M`!L```"_G0``-````-N=```*````$)X``!@````;G@``$@```#2>```9````
M1YX``!8```!AG@``(@```'B>```-````FYX```<```"IG@``%````+&>```+
M````QIX``"(```#2G@``+P```/6>```+````)9\``!<````QGP``%P```$F?
M```6````89\```\```!XGP``"````(B?```-````D9\``"8```"?GP``0P``
M`,:?```(````"J```!(````3H```'P```":@```(````1J````L```!/H```
M+P```%N@```&````BZ````<```"2H```!````)J@```*````GZ````H```"J
MH```#P```+6@```0````Q:```!<```#6H```$0```.Z@```9`````*$``!<`
M```:H0``!0```#*A```+````.*$```4```!$H0``#0```$JA```;````6*$`
M`!<```!TH0``#@```(RA```-````FZ$``!(```"IH0``.````+RA```@````
M]:$```X````6H@``>P```"6B```8````H:(``!$```"ZH@``!P```,RB```%
M````U*(``!@```#:H@``&P```/.B```9````#Z,``!L````IHP``&0```$6C
M```3````7Z,```<```!SHP``"````'NC```&````A*,``!````"+HP``#P``
M`)RC```0````K*,```\```"]HP``"P```,VC```/````V:,```P```#IHP``
M#P```/:C```'````!J0```8````.I```#@```!6D```,````)*0```\````Q
MI```"````$&D```(````2J0``!,```!3I```'@```&>D```A````AJ0``"``
M``"HI```&0```,FD```7````XZ0``"4```#[I```%P```"&E```6````.:4`
M`!L```!0I0``#0```&RE```,````>J4```,```"'I0``!0```(NE```(````
MD:4```0```":I0``!````)^E```3````I*4``!0```"XI0``#````,VE```)
M````VJ4```X```#DI0``"P```/.E```;````_Z4```<````;I@``!P```".F
M```-````*Z8``!@````YI@``"@```%*F```F````7:8``!4```"$I@``!0``
M`)JF```&````H*8```(```"GI@``!@```*JF```&````L:8``!0```"XI@``
M#0```,VF```0````VZ8``!L```#LI@``$`````BG```)````&:<```D````C
MIP``!0```"VG```:````,Z<```@```!.IP``!@```%>G```9````7J<```X`
M``!XIP``!P```(>G```'````CZ<```4```"7IP``"0```)VG```*````IZ<`
M``X```"RIP``"P```,&G```-````S:<```8```#;IP``"0```.*G```'````
M[*<``!0```#TIP``'0````FH``!"````)Z@``"4```!JJ```)0```)"H```&
M````MJ@```H```"]J```!````,BH```)````S:@```@```#7J```$0```."H
M```)````\J@```8```#\J```#0````.I```&````$:D``!X````8J0``!0``
M`#>I```.````/:D```8```!,J0``!P```%.I```A````6ZD```8```!]J0``
M!````(2I```*````B:D```4```"4J0``'0```)JI```$````N*D```P```"]
MJ0``#@```,JI```*````V:D```@```#DJ0``"0```.VI```%````]ZD``#H`
M``#]J0``,````#BJ```U````::H``"D```"?J@``1P```,FJ```X````$:L`
M`"D```!*JP``/P```'2K```N````M*L``"T```#CJP``'P```!&L```/````
M,:P``"D```!!K```)````&NL```F````D*P```<```"WK```(````+^L```@
M````X*P``"8````!K0``"@```"BM```9````,ZT``"D```!-K0``%@```'>M
M```'````CJT```H```"6K0``#````*&M```/````KJT``!````"^K0``0```
M`,^M``!P````$*X```X```"!K@``"0```)"N```*````FJX```8```"EK@``
M#P```*RN```2````O*X``!````#/K@``'````."N```C````_:X``&H````A
MKP``#P```(RO```%````G*\``!````"BKP``"0```+.O```$````O:\```L`
M``#"KP``%````,ZO```,````XZ\```P```#PKP``#P```/VO```5````#;``
M`"D````CL```*@```$VP```F````>+```"<```"?L```*0```,>P```J````
M\;```!D````<L0``0@```#:Q```1````>;$``!(```"+L0``$P```)ZQ```4
M````LK$```\```#'L0``%@```->Q```7````[K$``!`````&L@``$0```!>R
M```T````*;(``!,```!>L@``$@```'*R```U````A;(``!0```"[L@``$```
M`-"R```4````X;(``!<```#VL@``'`````ZS```4````*[,``!H```!`LP``
M&@```%NS```3````=K,``!4```"*LP``$0```*"S```7````LK,``!0```#*
MLP``%P```-^S```5````][,``!`````-M```&0```!ZT```$````.+0```<`
M```]M```"P```$6T```&````4;0```8```!8M```!@```%^T```%````9K0`
M``<```!LM```!P```'2T```%````?+0```8```""M```!@```(FT```$````
MD+0```0```"5M```!P```)JT```.````HK0```P```"QM```#````+ZT```-
M````R[0```H```#9M```#@```.2T```%````\[0``"@```#YM```#````"*U
M```/````+[4```H````_M0``"````$JU```K````4[4```@```!_M0``)@``
M`(BU```2````K[4```8```#"M0``"@```,FU```'````U+4```@```#<M0``
M(````.6U```,````!K8```X````3M@``%@```"*V```1````.;8```8```!+
MM@``!@```%*V```'````6;8```0```!AM@``!P```&:V```'````;K8``!8`
M``!VM@``#0```(VV```$````F[8``#H```"@M@``#@```-NV```0````ZK8`
M``L```#[M@``&P````>W```8````([<``!H````\MP``"0```%>W```*````
M8;<```P```!LMP``#P```'FW```(````B;<```8```"2MP``!P```)FW```%
M````H;<```L```"GMP``1P```+.W```-````^[<``!,````)N```$P```!VX
M```3````,;@```H```!%N````@```%"X```E````4[@```4```!YN```*@``
M`'^X```*````JK@```0```"UN```!@```+JX```(````P;@```@```#*N```
M!````-.X```%````V+@``&@```#>N```!0```$>Y```0````3;D```H```!>
MN0``#P```&FY```*````>;D```D```"$N0```P```(ZY```'````DKD```<`
M``":N0``"@```**Y```+````K;D```<```"YN0``40```,&Y```&````$[H`
M`!H````:N@``!@```#6Z```?````/+H```D```!<N@``(@```&:Z``!7````
MB;H``!,```#AN@``(P```/6Z```3````&;L```(````MNP``"P```#"[```-
M````/+L``!0```!*NP``!@```%^[```(````9KL```<```!ONP``"@```'>[
M```+````@KL```<```".NP``"0```):[```)````H+L```H```"JNP``!P``
M`+6[```)````O;L```<```#'NP``"@```,^[```*````VKL``!8```#ENP``
M!P```/R[```2````!+P```0````7O```!P```!R\```%````)+P```4````J
MO```"P```#"\```4````/+P```<```!1O```!0```%F\```-````7[P```P`
M``!MO```"````'J\```7````@[P```L```";O```#````*>\```?````M+P`
M`!H```#4O```!````.^\```*````]+P```0```#_O```#`````2]```%````
M$;T```D````7O0``!0```"&]```'````)[T```0````OO0``.````#2]```*
M````;;T``"P```!XO0``+@```*6]```S````U+T``#,````(O@``.````#R^
M```/````=;X``!@```"%O@``$````)Z^```/````K[X``!4```"_O@``%```
M`-6^```2````ZKX``!0```#]O@``+0```!*_```M````0+\``#$```!NOP``
M+@```*"_```O````S[\``"P```#_OP``8@```"S````3````C\````T```"C
MP```%P```+'````,````R<```"$```#6P```&@```/C````)````$\$``$4`
M```=P0``00```&/!```$````I<$```X```"JP0``$P```+G!```8````S<$`
M``8```#FP0``"0```.W!```*````]\$```\````"P@``$````!+"```.````
M(\(```4````RP@``"````#C"```&````0<(``!0```!(P@``$0```%W"```.
M````;\(``#@```!^P@```@```+?"```&````NL(```X```#!P@``!P```-#"
M```&````V,(```P```#?P@``'````.S"```$````"<,``"D````.PP``'P``
M`#C#``!<````6,,``!0```"UPP``/@```,K#```'````"<0```X````1Q```
M#````"#$```,````+<0``!,````ZQ```"@```$[$```=````6<0``!$```!W
MQ```$0```(G$```D````F\0``!4```#`Q```$@```-;$```.````Z<0``!D`
M``#XQ```"````!+%```)````&\4``!H````EQ0``!P```$#%```(````2,4`
M``4```!1Q0``'P```%?%```&````=\4``!````!^Q0``"````(_%```(````
MF,4``!X```"AQ0``$@```,#%```L````T\4``!H`````Q@``"0```!O&```*
M````)<8``!4````PQ@``!0```$;&```4````3,8```0```!AQ@``$````&;&
M```'````=\8``!X```!_Q@``*````)[&```*````Q\8``!P```#2Q@``$0``
M`._&```+`````<<``!H````-QP``%````"C'```$````/<<```L```!"QP``
M!0```$['```(````5,<```8```!=QP``(````&3'```I````A<<``$$```"O
MQP``*````/''```I````&L@``%````!$R```!@```)7(```%````G,@```@`
M``"BR```+@```*O(```T````VL@```<````/R0``(0```!?)```0````.<D`
M``X```!*R0``"P```%G)```'````9<D``!,```!MR0``"@```(')```4````
MC,D```\```"AR0``,@```+')```+````Y,D```X```#PR0``!0```/_)```%
M````!<H```4````+R@``%P```!'*```%````*<H```0````OR@``,@```#3*
M``!%````9\H``!<```"MR@``'@```,7*```4````Y,H```8```#YR@``#@``
M``#+```J````#\L```8````ZRP``#````$'+```1````3LL```L```!@RP``
M-@```&S+```*````H\L``"(```"NRP``"P```-'+```/````W<L``#(```#M
MRP``,````"#,```Q````4<P``"T```"#S```!0```+',```.````M\P``!,`
M``#&S```!P```-K,```1````XLP``!,```#TS```%`````C-```8````'<T`
M``4````VS0``!````#S-```'````0<T```H```!)S0``"P```%3-```,````
M8,T```X```!MS0``#@```'S-```%````B\T```4```"1S0``+@```)?-```F
M````QLT``",```#MS0```P```!'.```2````%<X```8````HS@``'@```"_.
M```8````3LX``"4```!GS@``"0```(W.```#````E\X```<```";S@```@``
M`*/.```,````ILX``!4```"SS@``"P```,G.```9````U<X``"````#OS@``
M!0```!#/```*````%L\``!4````ASP``#````#?/```$````1,\```D```!)
MSP``!P```%//```,````6\\``%(```!HSP``%P```+O/```D````T\\```8`
M``#XSP``#@```/_/```,````#M````T````;T```%0```"G0```2````/]``
M``\```!2T```%````&+0```*````=]```&D```""T```&@```.S0```7````
M!]$``"<````?T0``&@```$?1```7````8M$``!L```!ZT0``&0```);1```?
M````L-$``!,```#0T0``"````.31```'````[=$```D```#UT0``%0```/_1
M```-````%=(```T````CT@``"````#'2``!&````.M(``#\```"!T@``-P``
M`,'2``!7````^=(```4```!1TP``'P```%?3```*````=],```T```""TP``
M+0```)#3```$````OM,``$\```##TP``)0```!/4```?````.=0``!T```!9
MU```)0```'?4```@````G=0``"0```"^U```(````./4```&````!-4``#D`
M```+U0``#````$75```'````4M4```D```!:U0``$P```&35```)````>-4`
M``0```""U0``$````(?5```(````F-4```@```"AU0``#P```*K5```'````
MNM4``!0```#"U0``#@```-?5```,````YM4``"P```#SU0``$P```"#6```<
M````--8``"@```!1U@``!P```'K6```3````@M8```4```"6U@``%P```)S6
M```*````M-8```P```"_U@``"0```,S6```)````UM8``!$```#@U@``!@``
M`/+6```.````^=8```T````(UP``"P```!;7```"````(M<``!P````EUP``
M!@```$+7```)````2=<```<```!3UP``)@```%O7```X````@M<``!H```"[
MUP``*@```-;7```[`````=@``"@````]V```-````&;8```9````F]@``!4`
M``"UV```!0```,O8```'````T=@```@```#9V```!P```.+8```.````ZM@`
M``D```#YV```!@````/9```(````"MD```L````3V0``!P```!_9```(````
M)]D```<````PV0``%@```#C9```)````3]D```8```!9V0``"P```&#9```4
M````;-D```@```"!V0``$````(K9```0````F]D```8```"LV0``&0```+/9
M```*````S=D``!P```#8V0``!0```/79```0````^]D``!@````,V@``%P``
M`"7:```)````/=H```H```!'V@``!P```%+:```"````6MH```@```!=V@``
M(P```&;:```?````BMH``#$```"JV@``)P```-S:``!D````!-L``%4```!I
MVP``.````+_;``!*````^-L``%L```!#W```*````)_<```X````R-P``"@`
M```!W0``+````"K=```F````5]T``!L```!^W0``/@```)K=``"I`0``V=T`
M`",```"#WP``2````*??```E````\-\``$$````6X```6P```%C@``!)````
MM.```#$```#^X```*P```##A```A````7.$``!\```!^X0``)@```)[A```G
M````Q>$``#,```#MX0``)0```"'B```@````1^(``!\```!HX@``,````(CB
M``!I````N>(``#$````CXP``00```%7C```S````E^,``"4```#+XP``/0``
M`/'C``!E````+^0``$T```"5Y```+P```./D```N````$^4``#````!"Y0``
M5````'/E``!:````R.4``$@````CY@``2@```&SF```R````M^8``"\```#J
MY@``+````!KG```M````1^<``!<```!UYP``)0```(WG```R````L^<``"D`
M``#FYP``/@```!#H```B````3^@``%(```!RZ```)0```,7H``!%````Z^@`
M`"$````QZ0``,````%/I```E````A.D``!P```"JZ0``,0```,?I```$````
M^>D```T```#^Z0``"P````SJ```+````&.H```4````DZ@``60```"KJ```2
M````A.H```0```"7Z@``!P```)SJ```%````I.H``#````"JZ@``$P```-OJ
M```"````[^H```<```#RZ@``!@```/KJ```,`````>L``!@````.ZP``!@``
M`"?K```2````+NL```,```!!ZP``!@```$7K```'````3.L``!\```!4ZP``
M+@```'3K```O````H^L``!<```#3ZP``(@```.OK```E````#NP``"`````T
M[```&P```%7L```8````<>P``"0```"*[```'P```*_L```:````S^P``"$`
M``#J[```(`````SM```:````+>T``#(```!([0``&@```'OM```O````ENT`
M`"L```#&[0``'P```/+M```C````$NX``!\````V[@``&@```%;N```A````
M<>X``"4```"3[@``)@```+GN```E````X.X``"0````&[P``&````"OO```=
M````1.\``"0```!B[P``&````(?O```B````H.\``"P```##[P``+P```/#O
M```5````(/```"4````V\```/````%SP```?````F?```",```"Y\```'P``
M`-WP```@````_?```!H````>\0``)@```#GQ```>````8/$``"D```!_\0``
M'@```*GQ```Q````R/$```D```#Z\0``#`````3R```7````$?(``"\````I
M\@``)````%GR```'````?O(``!0```"&\@``#@```)OR```-````JO(``"0`
M``"X\@``!P```-WR```=````Y?(```<````#\P``QP````OS```5````T_,`
M``8```#I\P``"0```/#S```+````^O,```T````&]```%P```!3T```&````
M+/0``#,````S]```$P```&?T```3````>_0```<```"/]```#P```)?T```'
M````I_0``#(```"O]```!````.+T```A````Y_0``!,````)]0``#````!WU
M```1````*O4``#(````\]0``%@```&_U```(````AO4``!T```"/]0``"0``
M`*WU```*````M_4``!0```#"]0``"@```-?U```(````XO4```@```#K]0``
M!P```/3U```)````_/4``#\````&]@``!P```$;V```/````3O8```X```!>
M]@``"````&WV```'````=O8``!D```!^]@``%P```)CV```4````L/8``!$`
M``#%]@``!P```-?V```"````W_8```8```#B]@``!P```.GV```-````\?8`
M``L```#_]@``#@````OW```O````&O<``"````!*]P``'````&OW```Q````
MB/<```4```"Z]P``/P```,#W```2`````/@```H````3^```!@```![X```(
M````)?@```P````N^```"@```#OX```Y````1O@``"X```"`^```*0```*_X
M```8````V?@``!D```#R^```'P````SY```=````+/D``!$```!*^0```@``
M`%SY```$````7_D```8```!D^0``!0```&OY```#````<?D```P```!U^0``
M10```(+Y```R````R/D``!H```#[^0``-````!;Z```H````2_H``%,```!T
M^@``&0```,CZ``!R````XOH``"````!5^P``-0```';[```A````K/L``$4`
M``#.^P``,````!3\```H````1?P``"D```!N_```)@```)C\```E````O_P`
M`"@```#E_```*`````[]```B````-_T``#````!:_0``$@```(O]```3````
MGOT``!````"R_0``>0```,/]```)````/?X``*$```!'_@``<P```.G^``!\
M````7?\``"L```#:_P``5`````8``0`7````6P`!`"<```!S``$`%@```)L`
M`0`/````L@`!`!<```#"``$`'P```-H``0!`````^@`!`!\````[`0$`'```
M`%L!`0!1````>`$!`!H```#*`0$`%````.4!`0`*````^@$!``4````%`@$`
M!@````L"`0`(````$@(!`!`````;`@$`#P```"P"`0`/````/`(!``L```!,
M`@$`!P```%@"`0`%````8`(!`!0```!F`@$`!P```'L"`0`(````@P(!``\`
M``",`@$`"````)P"`0`,````I0(!``\```"R`@$`!@```,("`0`4````R0(!
M``8```#>`@$`#````.4"`0`1````\@(!``@````$`P$`&0````T#`0`1````
M)P,!``H````Y`P$`&````$0#`0`3````70,!`!P```!Q`P$`$0```(X#`0`$
M````H`,!``\```"E`P$`!````+4#`0`1````N@,!`!(```#,`P$`%P```-\#
M`0`$````]P,!``\```#\`P$`$P````P$`0`'````(`0!``<````H!`$`$0``
M`#`$`0`&````0@0!`!@```!)!`$`$P```&($`0`0````=@0!``P```"'!`$`
M"0```)0$`0`1````G@0!`"(```"P!`$`!P```-,$`0`%````VP0!`#H!``#A
M!`$`"@```!P&`0`/````)P8!``\````W!@$`!P```$<&`0`(````3P8!``<`
M``!8!@$`)0```&`&`0`A````A@8!`"T```"H!@$`)0```-8&`0`I````_`8!
M`"H````F!P$`(````%$'`0`J````<@<!``L```"=!P$`(````*D'`0`)````
MR@<!``L```#4!P$`!0```.`'`0`1````Y@<!``D```#X!P$`#P````((`0`+
M````$@@!`!4````>"`$`:P```#0(`0`-````H`@!``4```"N"`$`$0```+0(
M`0`3````Q@@!``\```#:"`$`"P```.H(`0`+````]@@!`!$````""0$`!@``
M`!0)`0"2````&PD!``H```"N"0$`"@```+D)`0`*````Q`D!``<```#/"0$`
M"P```-<)`0`H````XPD!`!P````,"@$`*0```"D*`0`Q````4PH!`$H```"%
M"@$`1````-`*`0!0````%0L!`$H```!F"P$`+````+$+`0`%````W@L!`!8`
M``#D"P$`+P```/L+`0`K````*PP!``X```!7#`$`%@```&8,`0`>````?0P!
M``H```"<#`$`!````*<,`0`2````K`P!`!0```"_#`$`"P```-0,`0`4````
MX`P!`!@```#U#`$`&@````X-`0`<````*0T!`!(```!&#0$`"````%D-`0`2
M````8@T!``H```!U#0$`+````(`-`0`1````K0T!`!8```"_#0$`#````-8-
M`0!.````XPT!`#8````R#@$`)@```&D.`0`$````D`X!``H```"5#@$`'0``
M`*`.`0`$````O@X!``,```###@$`#@```,<.`0`*````U@X!``P```#A#@$`
M!````.X.`0`*````\PX!``0```#^#@$`#`````,/`0`.````$`\!`!`````?
M#P$`%````#`/`0`J````10\!``X```!P#P$`%````'\/`0`6````E`\!`!0`
M``"K#P$`%````,`/`0`2````U0\!``X```#H#P$`$````/</`0`:````"!`!
M`!X````C$`$`"````$(0`0`.````2Q`!``H```!:$`$`#@```&40`0`$````
M=!`!``P```!Y$`$`&````(80`0`0````GQ`!`!0```"P$`$`%@```,40`0`0
M````W!`!``0```#M$`$`$````/(0`0`$`````Q$!`!@````($0$`#````"$1
M`0`Q````+A$!`#,```!@$0$`$@```)01`0`0````IQ$!``8```"X$0$`#@``
M`+\1`0`2````SA$!`"X```#A$0$`*@```!`2`0`L````.Q(!`"P```!H$@$`
M)@```)42`0`$````O!(!``0```#!$@$`#@```,82`0`2````U1(!`#$```#H
M$@$`-@```!H3`0`N````41,!`&H```"`$P$`*0```.L3`0`I````%10!`$(`
M```_%`$`0@```((4`0`I````Q10!`#4```#O%`$`)0```"45`0`E````2Q4!
M`$(```!Q%0$`*0```+05`0`O````WA4!`"(````.%@$`$@```#$6`0`6````
M1!8!`"@```!;%@$`'P```(06`0`?````I!8!`!8```#$%@$`%@```-L6`0`$
M````\A8!``8```#W%@$`(````/X6`0`>````'Q<!``8````^%P$`"@```$47
M`0`8````4!<!``H```!I%P$`-````'07`0`&````J1<!`!````"P%P$`"```
M`,$7`0`(````RA<!``P```#3%P$`$@```.`7`0`,````\Q<!``8`````&`$`
M-`````<8`0`,````/!@!``X```!)&`$`!````%@8`0`.````71@!``P```!L
M&`$``@```'D8`0`*````?!@!``(```"'&`$`&````(H8`0`.````HQ@!``@`
M``"R&`$`"````+L8`0`.````Q!@!`!8```#3&`$`"@```.H8`0`(````]1@!
M``X```#^&`$`#@````T9`0`#````'!D!``,````@&0$`$````"09`0`-````
M-1D!`"@```!#&0$`!@```&P9`0`*````<QD!`!````!^&0$`0````(\9`0`<
M````T!D!`"P```#M&0$`)0```!H:`0`<````0!H!``8```!=&@$`"@```&0:
M`0`8````;QH!`"````"(&@$`(@```*D:`0`O````S!H!`"8```#\&@$`)@``
M`",;`0!(````2AL!`#(```"3&P$`$@```,8;`0`$````V1L!``@```#>&P$`
M#````.<;`0`,````]!L!``@````!'`$`"`````H<`0`*````$QP!``@````>
M'`$`"@```"<<`0`(````,AP!``0````['`$`$@```$`<`0`,````4QP!``X`
M``!@'`$`#@```&\<`0`,````?AP!``0```"+'`$`$````)`<`0`P````H1P!
M`$X```#2'`$`%0```"$=`0`*````-QT!``X```!"'0$`%@```%$=`0`0````
M:!T!``X```!Y'0$`#@```(@=`0`,````EQT!`"````"D'0$`&0```,4=`0`(
M````WQT!`!````#H'0$`"@```/D=`0`0````!!X!`!(````5'@$`$@```"@>
M`0`*````.QX!`!````!&'@$`$````%<>`0`"````:!X!``8```!K'@$`!@``
M`'(>`0`$````>1X!``H```!^'@$`"@```(D>`0`(````E!X!``X```"='@$`
M"````*P>`0`&````M1X!``H```"\'@$`!````,<>`0`*````S!X!`#(```#7
M'@$`&`````H?`0`-````(Q\!`!`````Q'P$`#````$(?`0`0````3Q\!``H`
M``!@'P$`"@```&L?`0`F````=A\!`#,```"='P$`(0```-$?`0`&````\Q\!
M`"0```#Z'P$`(````!\@`0`+````0"`!``0```!,(`$`"@```%$@`0`&````
M7"`!``X```!C(`$`$````'(@`0`0````@R`!`!8```"4(`$`*P```*L@`0`I
M````UR`!`"X````!(0$`+````#`A`0`@````72$!`"<```!^(0$`'@```*8A
M`0`C````Q2$!`"P```#I(0$`)@```!8B`0`E````/2(!`"D```!C(@$`(```
M`(TB`0`F````KB(!`#(```#5(@$`,@````@C`0`J````.R,!`"P```!F(P$`
M+````),C`0`L````P",!`!L```#M(P$`*@````DD`0`M````-"0!`!\```!B
M)`$`*@```((D`0`H````K20!`!T```#6)`$`%0```/0D`0",````"B4!`!H`
M``"7)0$`)````+(E`0`F````UR4!`"8```#^)0$`)@```"4F`0`<````3"8!
M`"4```!I)@$`'P```(\F`0`J````KR8!`"P```#:)@$`-`````<G`0`V````
M/"<!`'T```!S)P$`'0```/$G`0`E````#R@!`"`````U*`$`)@```%8H`0`?
M````?2@!`$````"=*`$``@```-XH`0`$````X2@!``@```#F*`$`$@```.\H
M`0`2`````BD!`!0````5*0$`$````"HI`0`.````.RD!`!````!**0$`"@``
M`%LI`0`-````9BD!``X```!T*0$`+P```(,I`0`(````LRD!`!(```"\*0$`
M#@```,\I`0`,````WBD!``(```#K*0$`!````.XI`0`-````\RD!`!`````!
M*@$`!````!(J`0`*````%RH!``@````B*@$`"@```"LJ`0`$````-BH!``8`
M```[*@$`#````$(J`0`*````3RH!``P```!:*@$`#0```&<J`0`0````=2H!
M``0```"&*@$`"````(LJ`0`.````E"H!``H```"C*@$`$````*XJ`0`(````
MORH!``@```#(*@$`%@```-$J`0`0````Z"H!`!<```#Y*@$`.0```!$K`0`(
M````2RL!`!````!4*P$`$@```&4K`0`2````>"L!`!(```"+*P$`*@```)XK
M`0`(````R2L!``H```#2*P$`#@```-TK`0`$````["L!`",```#Q*P$`)```
M`!4L`0`$````.BP!``H````_+`$`"@```$HL`0`*````52P!``X```!@+`$`
M#````&\L`0`*````?"P!`"X```"'+`$`1@```+8L`0`(````_2P!``X````&
M+0$`(@```!4M`0`,````."T!`!$```!%+0$`.0```%<M`0`*````D2T!`!``
M``"<+0$`!````*TM`0`.````LBT!``X```#!+0$`$````-`M`0`0````X2T!
M`!4```#R+0$`$@````@N`0`7````&RX!`!4````S+@$`%@```$DN`0`4````
M8"X!``H```!U+@$`#P```(`N`0`K````D"X!`!,```"\+@$`$@```-`N`0`4
M````XRX!``H```#X+@$`+@````,O`0`D````,B\!`!8```!7+P$`6@```&XO
M`0`/````R2\!`!````#9+P$`"@```.HO`0`&````]2\!`!<```#\+P$`&0``
M`!0P`0`3````+C`!`!D```!",`$`'````%PP`0`;````>3`!`!````"5,`$`
M"@```*8P`0`*````L3`!``8```"\,`$`!0```,,P`0`&````R3`!``4```#0
M,`$`"@```-8P`0`&````X3`!``4```#H,`$`"@```.XP`0`$````^3`!``0`
M``#^,`$`$`````,Q`0`*````%#$!``@````?,0$`!````"@Q`0`&````+3$!
M`!T````T,0$`)````%(Q`0`C````=S$!`"(```";,0$`(0```+XQ`0`?````
MX#$!`"``````,@$`'0```"$R`0`6````/S(!`"0```!6,@$`#````'LR`0`.
M````B#(!``,```"7,@$``P```)LR`0`$````GS(!`!(```"D,@$`"````+<R
M`0`7````P#(!`!<```#8,@$`$@```/`R`0`*`````S,!``P````.,P$`%```
M`!LS`0`N````,#,!``@```!?,P$`$@```&@S`0`(````>S,!`!H```"$,P$`
M!@```)\S`0`>````IC,!`"(```#%,P$`"````.@S`0`*````\3,!``(```#\
M,P$``@```/\S`0`.`````C0!`!`````1-`$`$````"(T`0`4````,S0!`!(`
M``!(-`$`"@```%LT`0`$````9C0!``0```!K-`$`#````'`T`0`8````?30!
M``P```"6-`$`#@```*,T`0`5````LC0!`!````#(-`$`#@```-DT`0`0````
MZ#0!``P```#Y-`$`#`````8U`0`"````$S4!``X````6-0$`#0```"4U`0`+
M````,S4!``X````_-0$`#@```$XU`0`(````734!``P```!F-0$`'````',U
M`0`X````D#4!`"@```#)-0$`*````/(U`0`(````&S8!``X````D-@$`"```
M`#,V`0`0````/#8!``P```!--@$`$````%HV`0`,````:S8!``P```!X-@$`
M$@```(4V`0`2````F#8!`!L```"K-@$`#````,<V`0`4````U#8!``8```#I
M-@$`!@```/`V`0`8````]S8!``0````0-P$`!@```!4W`0`$````'#<!``8`
M```A-P$`'````"@W`0`&````13<!``H```!,-P$`%````%<W`0`.````;#<!
M`!(```![-P$`!````(XW`0`%````DS<!`$(```"9-P$`/0```-PW`0`]````
M&C@!`"4```!8.`$`*0```'XX`0`Z````J#@!`"D```#C.`$`*P````TY`0`I
M````.3D!`!\```!C.0$`(@```(,Y`0`&````ICD!`!H```"M.0$`(@```,@Y
M`0`:````ZSD!`!`````&.@$`*P```!<Z`0`K````0SH!`#,```!O.@$`"P``
M`*,Z`0`9````KSH!`#(```#).@$`$````/PZ`0`2````#3L!``P````@.P$`
M#0```"T[`0`2````.SL!``@```!..P$`10```%<[`0!9````G3L!``X```#W
M.P$`"`````8\`0`)````#SP!``0````9/`$`%P```!X\`0`?````-CP!`!P`
M``!6/`$`+````',\`0`H````H#P!`%0```#)/`$`#````!X]`0`&````*ST!
M``H````R/0$`$@```#T]`0`$````4#T!`!(```!5/0$`$````&@]`0`*````
M>3T!``@```"$/0$`#````(T]`0`.````FCT!`!@```"I/0$`%@```,(]`0`8
M````V3T!`!8```#R/0$`&@````D^`0`8````)#X!`!8````]/@$`,````%0^
M`0`0````A3X!``X```"6/@$`#@```*4^`0`.````M#X!`!````##/@$`$```
M`-0^`0`.````Y3X!``X```#T/@$`#`````,_`0`>````$#\!`!`````O/P$`
M$@```$`_`0`H````4S\!`!````!\/P$`%P```(T_`0`<````I3\!`!T```#"
M/P$`'````.`_`0`:````_3\!`!P````80`$`'````#5``0`8````4D`!`!8`
M``!K0`$`%@```()``0`6````F4`!`!8```"P0`$`&@```,=``0`9````XD`!
M``H```#\0`$`%@````=!`0`,````'D$!``P````K00$`!@```#A!`0`*````
M/T$!``8```!*00$`!````%%!`0`.````5D$!``H```!E00$`!````'!!`0`$
M````=4$!``P```!Z00$`"````(=!`0`$````D$$!``0```"500$`!@```)I!
M`0`(````H4$!``@```"J00$`!@```+-!`0`&````ND$!`!(```#!00$`$@``
M`-1!`0`,````YT$!`",```#T00$`"````!A"`0`&````(4(!``0````H0@$`
M!@```"U"`0`H````-$(!``X```!=0@$`%@```&Q"`0`(````@T(!``H```",
M0@$`#@```)="`0`,````ID(!``0```"S0@$`%````+A"`0`(````S4(!`!(`
M``#60@$`'@```.E"`0`4````"$,!``X````=0P$`!````"Q#`0`.````,4,!
M``(```!`0P$`"@```$-#`0`.````3D,!`"P```!=0P$`%@```(I#`0`&````
MH4,!`"@```"H0P$`$````-%#`0`4````XD,!``@```#W0P$`'@````!$`0`:
M````'T0!`"0````Z1`$`$````%]$`0`+````<$0!``H```!\1`$`"@```(=$
M`0`$````DD0!``@```"71`$`"@```*!$`0`(````JT0!``\```"T1`$`/@``
M`,1$`0`8`````T4!`!8````<10$`%````#-%`0`4````2$4!`!0```!=10$`
M`@```')%`0`M````=44!``8```"C10$`(````*I%`0`2````RT4!``H```#>
M10$`#@```.E%`0`*````^$4!`!`````#1@$`"@```!1&`0`,````'T8!`#``
M```L1@$`!````%U&`0`4````8D8!``X```!W1@$`'````(9&`0`<````HT8!
M`!(```#`1@$`!````--&`0`,````V$8!``8```#E1@$`#@```.Q&`0`(````
M^T8!``0````$1P$`0@````E'`0`(````3$<!`"````!51P$`#@```'9'`0`0
M````A4<!``D```"61P$`,0```*!'`0!8````TD<!`"`````K2`$`*0```$Q(
M`0`@````=D@!``(```"72`$`"@```)I(`0`&````I4@!``X```"L2`$`"@``
M`+M(`0`(````QD@!``0```#/2`$`#@```-1(`0`$````XT@!``P```#H2`$`
M!````/5(`0`$````^D@!``0```#_2`$`!`````1)`0`$````"4D!``0````.
M20$`$@```!-)`0`*````)DD!``X````Q20$`#@```$!)`0`,````3TD!``0`
M``!<20$`#@```&%)`0`,````<$D!``P```!]20$`#````(I)`0`8````ETD!
M``P```"P20$`!````+U)`0`:````PDD!``@```#=20$`!````.9)`0`4````
MZTD!`!``````2@$`$````!%*`0`L````(DH!`"````!/2@$`"````'!*`0`0
M````>4H!``(```"*2@$`#@```(U*`0`+````G$H!`!````"H2@$`$````+E*
M`0`6````RDH!``@```#A2@$`)@```.I*`0`*````$4L!`#(````<2P$`(P``
M`$]+`0`H````<TL!`"@```"<2P$`+````,5+`0`2````\DL!`!P````%3`$`
M)````"),`0`6````1TP!`!H```!>3`$`(````'E,`0`:````FDP!`!H```"U
M3`$`(P```-!,`0`C````]$P!`"<````830$`)P```$!-`0`E````:$T!`"@`
M``".30$`70```+=-`0`8````%4X!`!X````N3@$`(````$U.`0`0````;DX!
M`"H```!_3@$`&P```*I.`0`&````QDX!`$8```#-3@$`1@```!1/`0`$````
M6T\!``X```!@3P$`!@```&]/`0`.````=D\!``X```"%3P$`"@```)1/`0`*
M````GT\!`!H```"J3P$`%````,5/`0`8````VD\!``0```#S3P$`!````/A/
M`0`"````_4\!``8`````4`$`!`````=0`0`$````#%`!`#0````14`$``@``
M`$90`0`,````25`!`!(```!64`$`!````&E0`0`(````;E`!``X```!W4`$`
M(````(90`0`(````IU`!`#(```"P4`$`*0```.-0`0!"````#5$!`!0```!0
M40$`20```&51`0`*````KU$!``T```"Z40$`#@```,A1`0`$````UU$!``0`
M``#<40$`!````.%1`0`@````YE$!`!8````'4@$`$@```!Y2`0`:````,5(!
M``P```!,4@$`"@```%E2`0`*````9%(!`!<```!O4@$`"0```(=2`0`)````
MD5(!`!H```";4@$`!````+92`0`:````NU(!``P```#64@$`$````.-2`0`,
M````]%(!`!@````!4P$`$````!I3`0`*````*U,!`"(````V4P$`'````%E3
M`0`C````=E,!`!````":4P$`"P```*M3`0`,````MU,!`!H```#$4P$`"```
M`-]3`0`:````Z%,!``0````#5`$`%@````A4`0`*````'U0!`!(````J5`$`
M)````#U4`0`*````8E0!`"@```!M5`$`&````)94`0`*````KU0!`!````"Z
M5`$`"````,M4`0`,````U%0!`!````#A5`$`!````/)4`0`,````]U0!``@`
M```$50$`&@````U5`0`A````*%4!`#X```!*50$`(@```(E5`0`H````K%4!
M`%@```#550$`$````"Y6`0`&````/U8!`!````!&5@$`,````%=6`0`S````
MB%8!``H```"\5@$`'````,=6`0`.````Y%8!``0```#S5@$`!@```/A6`0`$
M````_U8!``X````$5P$`!@```!-7`0`2````&E<!``H````M5P$`)0```#A7
M`0`,````7E<!`!(```!K5P$`"````'Y7`0`(````AU<!``@```"05P$`$P``
M`)E7`0`"````K5<!``0```"P5P$`-````+57`0!#````ZE<!`!0````N6`$`
M&0```$-8`0`0````75@!``@```!N6`$`$````'=8`0`L````B%@!``0```"U
M6`$`#@```+I8`0`*````R5@!``H```#46`$`,@```-]8`0`&````$ED!`"``
M```960$`#````#I9`0`0````1UD!`!8```!860$`,@```&]9`0`Q````HED!
M`"P```#460$`"`````%:`0`4````"EH!`!P````?6@$`!````#Q:`0`0````
M05H!`!(```!26@$`#@```&5:`0`>````=%H!``(```"36@$`!````)9:`0`*
M````FUH!``D```"F6@$`"````+!:`0`(````N5H!``8```#"6@$`!@```,E:
M`0`$````T%H!``0```#56@$`'````-I:`0`2````]UH!`!(````*6P$`!```
M`!U;`0`*````(EL!``@````M6P$`#P```#9;`0`-````1EL!`!L```!46P$`
M"@```'!;`0`#````>UL!``0```!_6P$``@```(1;`0`.````AUL!`!@```"6
M6P$`#````*];`0`8````O%L!`"@```#56P$`#````/Y;`0`0````"UP!`!X`
M```<7`$`$@```#M<`0`$````3EP!``L```!37`$`"0```%]<`0`0````:5P!
M`$D```!Z7`$`%P```,1<`0`J````W%P!``0````'70$`#`````Q=`0`.````
M&5T!`!@````H70$`(@```$%=`0`>````9%T!`!@```"#70$`(````)Q=`0`(
M````O5T!`%(```#&70$`)````!E>`0`>````/EX!`!,```!=7@$`)````'%>
M`0`>````EEX!`"H```"U7@$`%P```.!>`0`7````^%X!`!8````07P$`"```
M`"=?`0`.````,%\!``0````_7P$`%@```$1?`0`$````6U\!``X```!@7P$`
M"@```&]?`0`V````>E\!`#(```"Q7P$`(````.1?`0!7````!6`!``0```!=
M8`$`$@```&)@`0`0````=6`!``P```"&8`$`/````)-@`0`$````T&`!`#0`
M``#58`$`+@````IA`0`>````.6$!`"0```!880$`'````'UA`0`6````FF$!
M`!H```"Q80$`&@```,QA`0`$````YV$!`#(```#L80$`$@```!]B`0`,````
M,F(!``@````_8@$`%````$AB`0`2````76(!``8```!P8@$`$@```'=B`0`0
M````BF(!`!````";8@$`#````*QB`0`2````N6(!``P```#,8@$`#@```-EB
M`0`0````Z&(!`"(```#Y8@$`!@```!QC`0`0````(V,!`!(````T8P$`!```
M`$=C`0`*````3&,!``@```!78P$`#@```&!C`0`(````;V,!``8```!X8P$`
M!@```']C`0`<````AF,!``H```"C8P$`!````*YC`0`(````LV,!``@```"\
M8P$`#@```,5C`0`"````U&,!`"0```#78P$`!````/QC`0`&`````60!``0`
M```(9`$`(0````UD`0`C````+V0!`!<```!39`$`(P```&MD`0`T````CV0!
M`"H```#$9`$`-@```.]D`0`;````)F4!`!L```!"90$`#@```%YE`0`$````
M;64!``8```!R90$`"````'EE`0`/````@F4!``@```"290$`!````)ME`0`&
M````H&4!``8```"G90$`"````*YE`0`.````MV4!``(```#&90$`(````,EE
M`0`0````ZF4!`!````#[90$`"@````QF`0`4````%V8!``L````L9@$`!@``
M`#AF`0`&````/V8!``0```!&9@$`$@```$MF`0`2````7F8!`!0```!Q9@$`
M!@```(9F`0`(````C68!`"````"69@$`$@```+=F`0`,````RF8!``@```#7
M9@$`"````.!F`0`"````Z68!``@```#L9@$`%@```/5F`0`B````#&<!`#(`
M```O9P$`+@```&)G`0!,````D6<!`%P```#>9P$`+````#MH`0`\````:&@!
M`%P```"E:`$`)`````)I`0`F````)VD!`"8```!.:0$`)@```'5I`0`F````
MG&D!`"(```##:0$`+````.9I`0#C````$VH!`!H```#W:@$`1P```!)K`0`J
M````6FL!`#@```"%:P$`1P```+YK`0!*````!FP!`"0```!1;`$`)@```'9L
M`0`>````G6P!`!X```"\;`$`'@```-ML`0`@````^FP!`#(````;;0$`*@``
M`$YM`0`H````>6T!`"(```"B;0$`)@```,5M`0!>````[&T!`"\```!+;@$`
M/0```'MN`0`N````N6X!`"4```#H;@$`2P````YO`0!?````6F\!`$\```"Z
M;P$`*`````IP`0`R````,W`!`"\```!F<`$`3````)9P`0!.````XW`!`$8`
M```R<0$`1@```'EQ`0`V````P'$!`"T```#W<0$`*P```"5R`0`H````47(!
M`!H```!Z<@$`*@```)5R`0`R````P'(!`"L```#S<@$`3@```!]S`0`J````
M;G,!`$8```"9<P$`)````.!S`0!,````!70!`"D```!2=`$`,0```'QT`0`J
M````KG0!`"(```#9=`$`0@```/QT`0`$````/W4!``P```!$=0$`"````%%U
M`0`6````6G4!``@```!Q=0$`6P```'IU`0`2````UG4!``P```#I=0$`#```
M`/9U`0`*`````W8!`"P````.=@$`&@```#MV`0`"````5G8!`!````!9=@$`
M#````&IV`0`0````=W8!`!8```"(=@$`!@```)]V`0`&````IG8!``,```"M
M=@$`#@```+%V`0`*````P'8!`"8```#+=@$`,````/)V`0`Q````(W<!`!4`
M``!5=P$`*@```&MW`0`O````EG<!`!P```#&=P$`%@```.-W`0`@````^G<!
M`"@````;>`$`(@```$1X`0`>````9W@!`"@```"&>`$`(P```*]X`0`8````
MTW@!`#8```#L>`$`&0```"-Y`0`T````/7D!`"H```!R>0$`(@```)UY`0`D
M````P'D!`"0```#E>0$`'@````IZ`0`H````*7H!`"````!2>@$`)@```'-Z
M`0`<````FGH!`!T```"W>@$`'@```-5Z`0`@````]'H!`"8````5>P$`&@``
M`#Q[`0`>````5WL!`"\```!V>P$`,@```*9[`0`:````V7L!`"(```#T>P$`
M.@```!=\`0`J````4GP!`"P```!]?`$`*@```*I\`0`K````U7P!`"0````!
M?0$`(````"9]`0`@````1WT!`"@```!H?0$`&@```)%]`0`T````K'T!``0`
M``#A?0$`#@```.9]`0`4````]7T!`"8````*?@$`'@```#%^`0`&````4'X!
M`!````!7?@$`!````&A^`0`$````;7X!``X```!R?@$`!````(%^`0`@````
MAGX!``0```"G?@$`O````*Q^`0`<````:7\!``0```"&?P$`#P```(M_`0`0
M````FW\!`!4```"L?P$`'@```,)_`0`,````X7\!`$0```#N?P$`%````#.`
M`0`4````2(`!`!0```!=@`$`$@```'*``0`*````A8`!`#L```"0@`$`!@``
M`,R``0`F````TX`!``H```#Z@`$`$`````6!`0`*````%H$!`"X````A@0$`
M(@```%"!`0`(````<X$!`!X```!\@0$`"0```)N!`0`*````I8$!`!0```"P
M@0$`%````,6!`0`$````VH$!``8```#?@0$`#@```.:!`0`:````]8$!`#,`
M```0@@$``@```$2"`0`.````1X(!``8```!6@@$`%@```%V"`0`)````=((!
M`!<```!^@@$`$````):"`0`0````IX(!`!@```"X@@$`!````-&"`0`"````
MUH(!``0```#9@@$`"````-Z"`0`-````YX(!`!$```#U@@$`"`````>#`0`P
M````$(,!`!8```!!@P$`%````%B#`0`L````;8,!``(```":@P$`,0```)V#
M`0`&````SX,!``@```#6@P$`!````-^#`0`.````Y(,!``P```#S@P$`$```
M``"$`0`Y````$80!`#````!+A`$`/P```'R$`0`/````O(0!``\```#,A`$`
M$P```-R$`0`7````\(0!``\````(A0$``@```!B%`0`"````&X4!``0````>
MA0$`#@```".%`0`$````,H4!``H````WA0$`/0```$*%`0`U````@(4!`!P`
M``"VA0$`)P```-.%`0`H````^X4!`%$````DA@$`$P```':&`0!H````BH8!
M`!H```#SA@$`3@````Z'`0`J````78<!`#H```"(AP$`(P```,.'`0`B````
MYX<!`"0````*B`$`)````"^(`0`D````5(@!`"0```!YB`$`)@```)Z(`0`>
M````Q8@!`$$```#DB`$`$@```":)`0`7````.8D!`!H```!1B0$`:````&R)
M`0`,````U8D!`)4```#BB0$`=@```'B*`0!N````[XH!`#(```!>BP$`8@``
M`)&+`0`.````](L!`"8````#C`$`%0```"J,`0`,````0(P!`!@```!-C`$`
M'````&:,`0`X````@XP!`!@```"\C`$`(````-6,`0!.````]HP!`!H```!%
MC0$`#P```&"-`0`.````<(T!`"(```!_C0$`#@```**-`0`0````L8T!``P`
M``#"C0$`"@```,^-`0`&````VHT!``H```#AC0$`"@```.R-`0`(````]XT!
M`!,`````C@$`"@```!2.`0`,````'XX!``P````LC@$`#````#F.`0`,````
M1HX!``P```!3C@$`#@```&".`0`(````;XX!``@```!XC@$`"@```(&.`0`.
M````C(X!``8```";C@$`'````**.`0`8````OXX!``X```#8C@$`%@```.>.
M`0`*````_HX!`!P````)CP$`$````":/`0`$````-X\!`!`````\CP$`"```
M`$V/`0`.````5H\!``P```!ECP$`&````'*/`0`$````BX\!`!(```"0CP$`
M%@```*./`0`&````NH\!``H```#!CP$`&````,R/`0`(````Y8\!`!P```#N
MCP$`#`````N0`0`*````&)`!``X````CD`$`#````#*0`0`.````/Y`!`"4`
M``!.D`$`!````'20`0`%````>9`!``$```"V`0``4@`````````*`0``-0$`
M`,@#``#D````)0$``````````````````/<"``#8!```[P0``+P!````````
MXP$``.X#````````'@```,$!```O!```D0````\"````````0`(``*<#```Y
M!0``[@0``)P%```4```````````````J`P```````#4```"/!````````%$$
M```4`0``S0(``'<"``!:!````````(4!````````I`$``+D$``!]!0``````
M````````````>@0```````"``P``V0(`````````````[`0``.X!```4`@``
MM0$``!H#``#^!````P(``)P$``#U````^P,``"<"``"P````=P$``%4$``!T
M!0``P@```'\$```Q`@``R````/L"``!K`````@$```````"\````E00`````
M`````````````(T"```%`0``(````+8#``!L`P``"P,``$\%``##`0``^@$`
M``````!6`P``P0,``+L$````````?@(```8```#*`@````````````"$`@``
M"P(``/H"``!,!```,@````````#/!```80$``,8```!&`````````"D"``#W
M`````````-8#````````W@(``*H```"&!0``M@```*0#```Z`P``/`0`````
M``"?````F0(```````!'!````````*(`````````;P(``)D!``"@!0``3@0`
M`$@%```````````````````%!0```````#4"``#X`P``X````#\!``""!0``
M]P,``$T#``!D`````````$P%````````!`,``!P!``"L`0``C0```,8"``"#
M`@``K@,``,P#````````]`$```````!N!```RP0`````````````)0,`````
M``#9!```Y0,``-P"````````]````)\%``#.`````````'4`````````````
M`/L!``#5`@`````````````H`0``LP$``)X%``#B!```F04``&X"``"H`0``
M9P(``-D!```-!```V`(``*4"````````<P0``%L#````````CP$``*<```!M
M`P````````````"U`@``4`,```````!G````?0$``$(#```P````I@0``#$%
M``".`@``U`(``&4``````````````%$"``!3`0```````"P#``#^````20``
M``````````````````````"5````+@$``#D`````````#P4``-P```!'`0``
M`````.8```!8!0``#P$``(D#````````BP$```````"G`@``#0(``#@$````
M````'@(``,$"```P`P``\0$``#,$``!D!0``L@0``,\```#;`0```````&@%
M``!R!```=00``#4%```H`@```````,X"```D`P``]0$``'P"````````C@0`
M`#<"```^`P``&00``'0````*`@``#````+<!``"]`P``]00```````!!````
M)P$``#0#``#$`P``F`0``(("``!P`P``!`4``%$#``!/`P``_P(```````"J
M`0``$@$```````!8`@```````'D!`````````````(4$````````O@(``&(`
M```&`0``K````%H#```I`P``CP4``*@$````````;0$```````!(`0``$`4`
M``````"M`0```````#T`````````?P(``($$```&!0``%P````````#T`P``
ME@```/@"````````VP,```````"8`P```````)8$```N`@```````),"``!J
M`0```````+T$``!Q`0```````"L#```$````WP$``.,```"X````^00``%4`
M``!'````0@``````````````4`0```````"@`P``=`$`````````````T`$`
M`!\$``#_````@@0``'8$```#!0```````"H%`````````````%0%````````
MT`0`````````````0@$``'8`````````MP,```````#R`````````"@$``!-
M`@```````%(#````````40````````"8`@``5`(``'`"``#3!```J0$``*4$
M``#3`0``)@$``*(%``!-`0``2@(```````#>!```+P,``,,$````````)@,`
M`-T#``#L`@``#`,```$"``#@`P```````(X```!&`@``IP0``$("``#H`0``
M5`$``*P"``"X`@``[@(```````#@`0``UP```"4"```6!```.@```.8$``#]
M`0``5@4```\#``"K`````````#P"``!5`@``0@0```@%``#J`P```````-`#
M``#+`@``NP,```````!N````PP,```````"'`0``2`,``$$$```B`P``A0,`
M````````````:@0``!H!``!7````$P$``,X$``",`0```````,,"``"1!```
M\@$``.(!``#B`P``:0```"\%``!T`P``RP$``!X#`````````````%(%````
M````9P4``.L#``!@!```'0````````!C`P``8`$``-0```"*`0``'P4``$,%
M``"_`P``"0(``",$````````0P0```````#=`0``*P(``(0```!:````_P$`
M``````![`P``G@```&$$``!Q`@``=04``(`%``#S````)@4```````!I`0``
M`````'<#``#5!```%@$``"X```!N`P``UP$``%@#```Y`0```````.,#``#*
M`0```````%L`````````20(``,\!`````````````$<"``!0`@``/P,``#$!
M``!C`@````````(%````````+0```)T"````````Y0(``)P"````````^0$`
M`$`!``"#`````````$0$``````````````````#\`0``+P```)X$``!9````
M_0,``*0%``!<`````````(\#``!K`@``;P```)X#``!:`@``YP0```````"\
M!```\`,``%`!````````F0,``"L```!3!0```P````````"P`0``R0,``#`%
M```D`@```````!8"````````.`(``*`!```5````D@4``&T$``"@````)00`
M`/,!````````F`4``*($``!V!0``&`4``(0!``"0`````````"0$``!^!0``
MP````,0!`````````````%P!``",`@``?@0``````````````````*\$````
M````N0,``"L%``!L`@`````````````*!```$0$``"@```#5`0``````````
M``"P`@``FP0```````!%`P``F@4```````#"!````````-````#X!```&0$`
M``,!```F`@``X00````````.!0``10$`````````````1`,``#T"``#=!```
M``````````"]````C`,`````````````>@,``(L#`````````````(,!``!X
M!0```````*$$```1`@``VP0```````"Y`0``+P(``(@"``#,!````````#("
M````````.P4``",#````````KP$``!$#```"`@```````)T#````````'0,`
M``````"\`@``W`0``+H$``";`@``S`(``+D````1````C0$``*D$``!P`0``
M``````````!N!0``HP(``*,%``"3``````````````#.`0``.@(```````#0
M`@``5@`````````;!```Q@$``%D"```^`0``!00``.<!``!8`0```````$D#
M``"X`P````````````!,`P```````)L!```&!````````(8#````````X`0`
M`*(#````````V`$``)\!``!)!0````````````!3`@``%P(``'\#``!<`@``
M1`(````````A````G0$````$``!O`P````````<#```2!```U0```+X#``"-
M!```-P,```````#U`P``[`$``%8"``#O`@```````$$#```H`P``<@$``&,!
M``!'`P``K0(``"T!`````````````*T#``!2!```&`,````````'!```V@(`
M```````P!```M@0``````````````````$0``````````````%D!````````
M&@(```T#`````````````!,%``"6`P```````",!``"P!```4@$``!`"```?
M````'P,``'(`````````;@$```````#_!```/P(``-(!``!B!0``I`0``/T"
M``````````````````!S````"P```)<!``!I!```.`$``)H"``!O!0``````
M`,4!`````````````/<!``!4!`````````````#?!````````!4%```+`0``
M]`(``/P```!E!````````'<$```)!0```````'(#``"%````0P,``#P!``"Q
M`@``>```````````````"P4``````````````````$`````D!0``>P(``($"
M``!5`0```````#,"``"-`P``KP,``)H#``!%!````````%,`````````@0,`
M`$4```#6`@``"0````````#&`P``F@0````````&`@```````)`"``!*!0``
M>P$``!T"````````_00`````````````ZP$``&\!``#'`P``M````!$$``!:
M!0``*00``+T!``"K`0```````-($``!:`0``Y`,```````#$`@``)P``````
M````````5`,```@!````````````````````````@@```*8"``#6!```;P0`
M`%X#``!5!0``OP(```````!*`P``0`4``)($````````N@```&`#``#:`P``
M`````",```#+````Y0```#L"``"J`P``T@```*X"``"I```````````````Q
M`P``9P,````"````````CP(``.T#``#T!```B@,``/$#``#Z`````````$@"
M``"<````\@0``"`"```[`````````'$%``#:`0```````$<%``!>`@``_0``
M`"D%```V!```2P```#@#``#7!````@0``',%```;````G@$``"$!``!.`0``
M?0(``!4"``!H!```LP```"`%```2!0`````````%```V!0``W@$``!`#``!B
M`P``E@$``!H%``#G````X0$``(0$``#(`@``E0,```H#`````````````'H%
M``"E`P``V@0``'H"``#/`@``I0$``!D```#B`@``HP0``"("````````````
M`$\$``"I!0``FP4``(@#``#'````5P,```````"\`P``J0(``!T%````````
MU@```'D$``"N!```#0```!<!``!P!0```@```*X```!6!````````$@```!F
M!```QP$``#8```!-````Z0(``#T!```I`0``!`0``&0$``!#`0``Q`0``#P%
M``!Y!0```````!L"``#Y`P````````8#````````(0,``+H!``"4`0``;04`
M``````"7`@``V0```&<$```8`0``'`4``-\"``!W`````````!,#````````
M;`$```````#``P``(@````````#M`0```````'$````N`P``#04``+\!``!X
M`0````````````#7`P``L00```$#``"A`P``PP```!<%`````````````)P#
M`````````````',"``!>!```6`````````#G`@``H0$``+4`````````````
M`"<%````````7`,``)D$````````G0```'L$``"]`@``6P(``$0%```R!```
M5P4```````#R`@``7@$```````#O`0```````!<#``#J`@``2P$``-@#``#?
M````?@```#X$``#C!```.`4```````"L`P``R00``)0```"*!0``O@$``#<!
M``!&`0``B`````````"+`@``8@0``+,$``!7`0``>0,``/,"``!/`@``<0,`
M`.8"``!U`@``C@,``,0```"C`0``'@$``+<"``"7`P``90$````````?`0``
M=`0``-,#`````````````.<#````````W`$``.0!``!F````X0(``&8#``#D
M!```L@(```````!F`0``40$``,@$``"F!0``Z@```(L%````````'`,`````
M````````R@`````````>!````````$X"```]!0``T0````````#,`0``_P,`
M`'(%```,!0``````````````````6`0````````.!```:`,``.\#````````
M(@4```````#X`````````!,"```M!```E`4``(P```!^`P``B0(``-4#```W
M!0``%`4``$L%```<!```1@0```````#V!```70```($%``!]!```````````
M``#2`P``Y`(``+L```!_`0``I@$``)0"``"0!```,`(````````_!0``"0$`
M``````!?````M`0```````!-!0``,P,``,T!``#;````$P```!D"``!=!0``
M>@````````#P`0``IP4```H```!=`P``D04``+L"``!\!````````*T`````
M````?0,``!H$``#\`@``A0(``!T!````````I0```&0"````````+`$``*H"
M``"U`P``KP(``,X#``#-`````````````````0``?@$``!(```#H`@``````
M`"`#```^````80(````````T`@``9`$``,\#``!4````````````````````
ME`,``%X```!%`@``(`$``)D```#Q`@```````(D!```+!```U@$``%D$```0
M`````````-L"`````````````)`#``#3````[`,``(0#``#<`P``2@0``%T$
M```]`P``E@4````````7!```P`$`````````````R0(``+`#``"Y`@``````
M`-,"```%````@P,``&`%``""`0``"````&P````A!0``2P,```H%```3!```
M90(``(<"``#I`P``Y@,``'L%``#(`0```````*`$```.`P``.@$```D#````
M``````````````"D````'@4``/,$``"1`@``&P,``!`$``!@`@``CP```+0"
M````````:`(``!(#``!.`P``U`$``%L!``!%!0``FP,``(H$``!=`0``````
M`!0#```H!0``<P,``#P```````````````(#``"2`@``L@$``(@%``!X`@``
MUP(```@$```#!````````#X%````````%@,``$@$```Z!```200``#0````[
M`P``#P```!4#``"O````?`$``&$```"S`@``]@$``$\```#M!```^P```!P"
M```'`@``:P$``"8```"2`P```````"H!```D`0``JP,``&@`````````````
M`)$#``!#````X0,``(L````)!```1`$``&D#``"3!```-P````````#C`@``
M]@,``,("````````-`$````````M`@``7P$``$D!````````L@,``/(#``!L
M!0``(P4``!@"````````K@$```````#&!````````-D#``"Q`P``^P0``$$"
M```(`P```````'8!``#-!````````(H"```X````^0``````````````.P0`
M`(D$``!F!0``$`$``(X%``#Z`P``70(``($```"&`0``*0````````#H````
M?P4``(P$```Z!0``5@$``-X```"8`0```````&H#``#%!```Q0(``%$%```M
M`P``>`0`````````````7P0``(P%`````````````(8$````````!P4``-0$
M````````DP,``%<"`````````````$H!``!J````J`4``)\#```;!0``<`0`
M`+8"``!.````'P(``````````````````%L$```_````E@(`````````````
M``````````"B`0``MP```"P%``#P`````````'$$``!_`````````&L#```8
M!```=P4``#\$````````I@```"H$``"?!```P@$``+@!``"7!```M00``(8`
M````````!0,``(D```!#`@``<P$``)4"``"*````)P,``)0$``"Q`0``\0``
M``````";````L0```-@```#:`````````.D`````````IP$``+\````$`0``
M:@4```````#W!```^@0``!("``"H`@```````.L"````````MP0``/P#```1
M!0``````````````````D@$```````#*`P``+04``$P````9`P```````$P!
M``#M````QP0``/$$``!!!0``90,``#8#```C`@```````-$$```@!```````
M`'0"``#P!```00$``,(#```K!````````!4!``"'!```M`$```````#V`@``
M`````(L$````````9`,``&$#````````D0$``&8"``!-!```804```````!U
M`0``JP0`````````````@P0```T!````````N`0``$`#```S````X0```'("
M``!2`@``P0```(8"``!Y`@``1@4``*8#``![````6P4``#D$````````S```
M```#``!I`@``WP,``#D"````````X@````<``````````00````````J`@``
MC04```````#E`0```````(<%```J```````````````B!```5P0```````"H
M````S0,``)@```":`0``7`4``-("``#K````T0,``)(```"A`````````&T`
M``!`!```&P$```````"J!```9P$````````=!```,@$````````R`P``````
M`'4#```D````@`(``),!````````-`4``$\!``!Y````#P0``%\%```%`@``
M`````/X#````````[@`````````<````)04``````````````````(D%````
M``````````````"=!````````'T```"C````#@````````".`0``W0(`````
M``!C!```?````&4%``!3`P```04``#$```#4`P``\P,``.D!```8````B`0`
M`)P!``"(`0``,00``%`%```6````7P(``*("````````=@,``#,%```6!0``
MRP,``%D%````````(0(``/`"```4!```0@4``!H````9!0``NP$``#4$``"'
M`P``/@(`````````````:@(``&(!```,`@``8P4```````#%`````````(0%
M```B`0`````````````W!````````*L"```$`@```````/X"````````K00`
M`%D#``"Z`@``A04`````````````K`0```````!,`@``[0(``(`````.`@``
M+`0``/8```!5`P``D`4``*,#``````````````````"?`@``Z00```<!````
M`````````-$!``#X`0``-@$``#(%````````:P4``)<%```G!```(00`````
M``#H`P```````((#````````[````%,$`````````````$L$``#1`@``*P$`
M`"8$````````Y@$``'H!````````````````````````O@0``*0"````````
M`````*@#``!C`````````#0$`````````````),%```\`P``ZP0```````#J
M`0`````````````V`@``3@4``'P#``#)`````````)H```"E!0``EP```&D%
M``#``@```````'P%``!X`P```````(`$``"A!0```````,D!``!V`@``AP``
M`%P$```L`@``+@0``#L!```O`0``1@,``*`"``#^`0``Z`0``&("``"``0``
M`````+X````Y`P```````%````"!`0```````&P$``#\!```)0```,4#````
M````#`$``)T%````````[P```%\#``"R````D`$``+0#``#'`@``#@$```,#
M``#`!```W0```)X"`````````````)4%``!H`0``X`(``/4"``#J!```2P(`
M`#4#```L`````````#T$````````,`$``'````"A`@``R@0``!4$```(`@``
M`````#,!``"I`P``;0(``+,#``#E!````````,$$`````````````&L$``"5
M`0```0$```P$``#>`P```````+H#```N!0``^0(`````````````OP0``&``
M``!*````@P4``%X%````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I
M`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D
M87DI`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A
M;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@
M8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E
M+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O
M<F0@97AP:7)E<RX`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`
M)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3
M971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E
M861Y(&5X:7-T<RX`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F
M;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#
M86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z
M(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@
M=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R
M(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN
M9F]R;6%T:6]N+@`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U
M<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`06)O=70@=&AI<R!E9&ET
M;W(`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T
M:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I
M;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!
M9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D
M(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI
M80!!;&=E<FEA`$%L:6%S`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A
M=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!
M;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M
M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S
M`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R
M960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!
M;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T
M:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P
M<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`
M07!R:6P`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A
M;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R=6)A`$%S
M8V5N<VEO;B!)<VQA;F0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`
M075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T
M:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5
M<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R
M(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A
M:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"86-K9W)O=6YD`$)A8VMG<F]U
M;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@
M=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86YG;&%D97-H`$)A<F)A9&]S
M`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E
M;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU
M=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N
M;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI
M=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O='-W86YA`$)O=79E="!)<VQA
M;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N
M96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@
M1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`
M0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE
M=&5D+@!#86QE;F1A<@!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T
M('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI
M;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#
M86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L
M971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A
M;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R
M96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M
M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@
M;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@
M<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`
M0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO
M;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T
M:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;G1E<@!#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T
M92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N
M9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P
M<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#
M:&EN80!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H
M;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`
M0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F
M;W5N9"X`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O
M=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@
M=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-O8V]S("A+965L:6YG*2!)<VQA
M;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC
M:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI
M8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`
M0V]M;W)O<P!#;VUP86YY`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N
M9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S
M(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#
M;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE
M($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D
M+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O
M;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B
M)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;W!Y`$-O<'D@9F%I;&5D.B`E
M<P!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E
M+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D
M9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@
M(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B
M)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@
M8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B
M+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L
M:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S
M(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N
M(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P
M87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O
M9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U
M;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S
M`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT<GD`0W)E871E`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO
M;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%-E
M<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S
M97)S`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`
M0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Z96-H(%)E<'5B;&EC`$1$`$1A
M:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T
M92!296-E:79E9`!$871E('-E;&5C=&EO;@!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`
M1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`
M1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E
M;&5T92!097)M:7-S:6]N`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G
M97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E
M(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD
M97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R
M96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E
M;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$1E=F5L;W!M96YT`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO
M;B!R:6=H="!T;R!L969T`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA
M>2!/<'1I;VYS`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C
M=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A
M;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N
M;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!%
M+4UA:6P`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET
M(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS
M(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O
M<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5G>7!T`$5L(%-A;'9A
M9&]R`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M<'1Y(&UE<W-A9V4N
M`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N;&%R9V4@161I
M=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%
M<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P
M90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP:7)A=&EO;B!$
M871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I
M;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R
M=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y
M('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E
M.B`E<P!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD
M<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9I:FD`1FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@
M36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&
M:7)S="!1=6%R=&5R`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O
M;&]R`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O
M<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)U;7,`1G(`1G)A;65S`$9R
M86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC
M:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9U;&P@
M1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA
M;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`
M1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F5E8V4`1W)E96YL86YD`$=R
M96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U
M871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`
M1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(96%D97(`2&5A
M9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5I9VAT
M`$AE;'``2&5M:7-P:&5R90!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y
M(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE
M(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@
M:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V
M960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`
M26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E
M>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O
M<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO
M=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R
M+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2X`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM
M86=E(%523#H`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F-O<G)E8W0@86-T:6]N(&-O9&4@
M9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U
M86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YS97)T($-?
M;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@
M5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU
M;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E
M9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E
M`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R
M="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O
M=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-
M;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G9A
M;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@9&%T
M82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV
M86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`
M26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED
M+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV
M86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV
M86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN
M=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q
M`$ER96QA;F0`27-L92!O9B!-86X`27-R865L`$ES<W5E<@!)=&%L:6,`271A
M;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IE<G-E>0!*;W)D86X`2G5L>0!*
M=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I
M9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA
M;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+@!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`
M2V5Y(%1Y<&4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!2
M97!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2W5W86ET`$MY<F=Y>G-T
M86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8P!,87-T(%%U87)T97(`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%Y;W5T
M`$QE8F%N;VX`3&5F=`!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M
M86AI<FEY80!,:65C:'1E;G-T96EN`$QI;FL`3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:7-T
M($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET:'5A;FEA`$QO861I
M;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO=V5R(&=R965K(&QE='1E
M<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU
M>&5M8F]U<F<`34T`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+@!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8`36%D86=A<V-A<@!-86EL`$UA;&%W:0!-86QA>7-I80!-86QD
M:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S
M;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<F-H`$UA<G-H86QL
M($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI
M80!-875R:71I=7,`36%Y`$UA>6]T=&4`365M8F5R<P!-96YU(&UO9&4Z`$UE
M<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M=F5R:69I960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-
M97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:6UE(%1Y
M<&4`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG
M(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I
M9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M
M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL
M+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&EF:65D
M($1A=&4`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO
M;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO=F4@1&]W
M;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E
M('5P`$UO>F%M8FEQ=64`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T
M:6]N`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.
M875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.
M971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-
M;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P
M87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE
M>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:75E
M`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL
M92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE
M9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I
M;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E
M8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y3
M4TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D
M871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<V5P
M87)A=&]R('-P96-I9FEE9"X`3F\@<W5C:"!F:6QE`$YO('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE
M9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO;F4`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M
M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!
M9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT
M960N`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=F5M8F5R`$YU;6)E<@!.=6UB
M97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@
M<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T
M;V)E<@!/9F9I8V4`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+@!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO
M="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES
M<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'
M4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U
M8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!0
M2%`@4VAE;&P`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4&%D9&EN9P!0
M86MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<W-W;W)D`%!A
M<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E
M8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!097)C96YT`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B
M)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N
M<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)U`%!H:6QI<'!I;F5S`%!H;VYE`%!I=&-A:7)N`%!I>&5L<P!0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V
M86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO
M;G1H+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@
M=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!O;&%N9`!0;VQL
M<P!0;W)T=6=A;`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@
M97AT96YS:6]N(&YO="!F;W5N9"X`4')E=FEE=P!0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U
M;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN
M9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`475E
M<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%T:6\`4F5A9`!2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E
M<V@@4&]R=&%L(%9I97<Z`%)E;&]A9`!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A
M=&EO;BX`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R
M9`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O
M<F0`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS`%)I9VAT`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T
M`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2
M;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U
M;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!344P@4VAE;&P`4U-(
M`%-50T-%4U,`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I
M<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=61I($%R86)I80!3879E`%-A=F4@
M(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A
M=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!396%R8V@`4V5A
M<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T
M(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S
M97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE
M9V%L`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU
M;6)E<@!397-S:6]N($%D;6EN`%-E<W-I;VYS`%-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5Y8VAE;&QE<P!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE
M<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET
M:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3
M;&]V96YI80!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;W)T(&]R9&5R('-E
M;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@1V5O
M<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@
M2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E
M(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8VEN9P!3
M<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<FD@3&%N
M:V$`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T<F5E="!!9&1R97-S`%-T
M<FEK971H<F]U9V@`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@
M;F]T(&9O=6YD+@!3=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U
M;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C
M97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3
M=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N<FES92]3=6YS970`
M4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T
M`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z
M:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y<FEA;B!!<F%B(%)E<'5B;&EC
M`%135B!F:6QE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!4
M86EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%S:W,`5&5L97!H;VYE($YU
M;6)E<@!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI
M<W1R871I;VX`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I
M;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@
M2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL
M92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E
M<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N
M8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E
M;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E
M<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE
M('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T
M97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T
M+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE
M;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P
M=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A
M8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R
M86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A
M<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@
M9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN
M9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA
M<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I
M+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:6UE`%1I;64@5')A
M8VMI;F<`5&EM92!F;W)M870`5&EM;W(M3&5S=&4`5&ET;&4`5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]G9VQE($A4
M34P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VYG80!4;V\@;6%N>2!I;G9A;&ED
M(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5')I;FED860@86YD
M(%1O8F%G;P!4=0!4=6YI<VEA`%1U<FME>0!4=7)K;65N:7-T86X`5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``
M55),`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@
M(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T
M92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E
M=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A
M9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD
M97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E
M(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z(`!5;F9I;&5D`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+
M:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S`%5N:VYO=VX`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"X`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@
M82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<W5P<&]R=&5D
M($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T
M960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U
M9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T
M:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R
M(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR
M96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H
M92!S>7-T96TZ`%5Z8F5K:7-T86X`5F%C871I;VX`5F%L:61I='D`5F%N=6%T
M=0!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO
M;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9I970@3F%M`%9I97<@)7,`5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:`!6:7)G:6X@27-L86YD<RP@52Y3+@!786QL:7,@86YD($9U='5N80!787)N
M:6YG`%=E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I
M9'1H`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED
M=&@@=6YI=`!7:61T:#H`5VES:&QI<W0`5V]R:R!!9&1R97-S`%=O<FL@4&AO
M;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I
M;F<@82!61E,@9FEL92X`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@
M97AT96YS:6]N<P!960!965E9`%EE87)L>0!996UE;@!997,`665S+"!)($%G
M<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET
M<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT
M+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I
M='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9
M;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P
M87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO
M=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`
M6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T
M:6]N`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I
M97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO
M;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE
M(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@
M=6YK;F]W;@!C86QE;F1A<@!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A
M;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I
M;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F
M;W5N9`!F:6QE`&AO<W0@;F%M92!U;FMN;W=N`&EN<'5T+V]U='!U="!E<G)O
M<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!N86UE`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S
M:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`'-E
M<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S>7-T96T@97)R
M;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FT`=6YN86UE9`!V0V%R9`!0<F]J96-T+4ED
M+59E<G-I;VXZ($AO<F1E(#,N,2XP"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V
M+3`S+3`V(#$R.C0W*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,RTR
M,B`Q,CHP,"LP.3`P"DQA<W0M5')A;G-L871O<CH@2&ER;VUI($MI;75R82`\
M:&ER;VUI0'1A8RYT<W5K=6)A+F%C+FIP/@I,86YG=6%G92U496%M.B!*87!A
M;F5S92`\=6YK;F]W;D!U;FMN;W=N+F1O;6%I;CX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/5-(24947TI)
M4PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*"5S()/ZD4\I
M`(-!@TZ#6H-8@TR#0R`E<P"!:25S()/Z@LR3X(+)@6H`("B-H9/Z*0"!:9:^
MD_J!:@`@*(WPD_HI`"<E<R<@@LV#9H-"@XR#3H-G@XJ!6X+%@LV"H(+H@MR"
MN8+Q@4(`(B5S(B""S9"S@K6"HI%)D?""Q8+-@J""Z(+<@KF"\8%"`"(E<R(@
M@LT@2&]R9&4@@XR#5X-8@V>#BH+)D-V2Z(*S@NJ"Q(*B@MR"N8+Q+@`B)7,B
M((-C@XJ!6Y5<CJ:+0)1<@JJ,J95T@JF"Z(+<@KF"\8%"`"(E<R(@@JJ#3X.+
M@5N#=H-6@UB#98.`@LF2QXG!@K."ZH+<@K6"O8%"`"(E<R(@@JJ#08-.@UJ#
M6(R@@U:#6(-E@X""R9+'B<&"LX+J@MR"M8*]+@`B)7,B((+-C>R0K(*S@NJ"
MW(*Y@O&"Q8*U@KTZ("5S+@"799?*("4R)"XR9DU"()*&@LP@)3$D+C)F34(@
MCF>7<"@E,R0N,F8E)2D`)60@)7,@@L8@)7,`@W"#6(./@5N#:(+-@J""QB`E
M9""3^I=,C/B"Q8*W@4(`DLJ2;2`M("5S`"5S()-DCG&.=Y;D`"5S($M"`"5S
M()7;CN>1@(WL@LR*;91&`"5S((+,D-V2Z``E<R"#5(-#@Y.#08-B@W8`)7,@
MDZ^(TX_PC8``)7,@@LV*^8+)D;:-W8*U@MR"MX%"`"5S((+-CI^"R8YWDNB"
MLX+J@L2"HH+IE=N.YY&`C>R"\([`C7."MX+ICX"4]8*JD*Z"HH+<@K6"O8%"
MCL"-<X*U@KV"HI&`C>R"S(-[@V*#3H-8@O"#8(-&@V*#3H*U@L2"K8*^@K."
MHH%"`"5S((*JE4N7=H+%@K<`)7,@E:H`)7,@@JJ"H(+H@MR"N8+Q@4(`)7,@
M@JF"YR`E<X%!C8>,=B`E<P`E<R""S(-!@VB#C(-8DJ``)7,@@LR77)+HE5P`
M)7,@@LR#@8."DJ``)7,@@LR#7H-8@TZ#BH-8@V<`)7,Z("5S`"5S.B""L8+,
M@X&#8H-:@5N#5X+-CJ:"LX+J@L2"HH+ID9>038[2@JF"YX+,@N""S(+%@LV"
MR(*B@L:.=H+M@NJ"W(*W@4*"NX+,DH:"S(.*@Y.#3H+P@TZ#BH-B@TZ"M8*]
M@NB!08S"D&R/[I7Q@O"1EY!-@K>"Z8+,@LV/7)6J@LF2C8C3@K6"Q(FZ@K."
MHH%"`"TM()%)D?`@+2T`,3*.GHK4C&".K@`R-(Z>BM2,8(ZN`#(T((Z>BM0`
M/)%/@LR#>8%;@U<`@K&"S(-U@XV#8H-.@LF"S8-F@5N#7H-X@5N#6(*JE4N7
M=H+%@K>!0@"2=I:]DTF"R(-'@XF!6X*JE*V0MH*U@MR"M8*]`%!'4(SVBDJ,
MKH*J@X&#8H-:@5N#5X+,B,.-AHF[@LF52Y=V@L6"MX%"`%!'4(SVBDJ,KH*J
MCY"6O(*S@NJ"O8.!@V*#6H%;@U>"S(R?C]B"R95+EW:"Q8*W@4(`4$=0C/:*
M2HRN@4%01U"4Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JHC#C8:)NX.!@V*#
M6H%;@U>"S)6<C8:"R95+EW:"Q8*W@4(`4$=0C/:*2HRN@4%01U"4Z9:GC*Z"
MJ(+F@M&#<(-8@W2#C(%;@UF"JH.!@V*#6H%;@U>"S(^0EKR"R95+EW:"Q8*W
M@4(`4R]-24U%C/:*2HRN@4%3+TU)3464Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;
M@UF"JHC#C8:)NX.!@V*#6H%;@U>"S)6<C8:"R95+EW:"Q8*W@4(`4R]-24U%
MC/:*2HRN@4%3+TU)3464Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JH.!@V*#
M6H%;@U>"S(^0EKR"R95+EW:"Q8*W@4(`4R]-24U%C/:*2HRN@JJ#@8-B@UJ!
M6X-7@LR(PXV&B;N"R95+EW:"Q8*W@4(`04TO4$T`@K&"S(-'@V:#0H->@5N"
MR8+"@J*"Q`!61E.#9H-"@XR#3H-G@XJ"S(WLD*R"S8-!@TZ#6H-8BY&4VX*S
M@NJ"W(*U@KV!0@!61E.#=(-`@T.#BX+,C>R0K(+-@T&#3H-:@UB+D93;@K."
MZH+<@K6"O8%"`(-!@TJ#18.3@V>/[I7Q`(-!@TJ#18.3@V>"S(-P@UB#CX%;
M@V@`@T&#2H-%@Y.#9X+-DX",BX*S@NJ"Q(*B@MR"MX%"`(-!@TJ#18.3@V<`
MDL>)P0"#5(-U@T^#BX%;@W:"\)+'B<$`@U2#=8-!@TZ#6H-8C*""\)+'B<$`
M@K&"L8+)DL>)P3H`D%:"M8*B@T^#BX%;@W:"\)+'B<$`D%:"M8*B@O"#08-.
M@UJ#6(R@@O"2QXG!`(-4@W6#3X.+@5N#=H+P("(E<R(@@LF2QXG!`(-4@W6#
M08-.@UJ#6(R@@O`@(B5S(B""R9+'B<$`D%:+2X.&@5N#58+PDL>)P8%&`)?Q
M@O"2QXG!`)!6BTN#@8.3@V^"\)+'B<&!1@"#>8-!@O"2QXG!`"5S((.!@VJ#
MA8%;@O`@36]Z:6QL82""S(-4@T.#:(-O@5N"R9+'B<&"MX+I`(-!@VB#C(-8
MDJ""R9+'B<$Z`(Z$@LR"S(-!@VB#C(-8DJ""R9+'B<$`@X:!6X-5@O"2QXG!
M`(-6@UB#98.`@LD@(B5S(B""\)+'B<&"M8+<@K6"O8*J@4&#5(-#@Y.#08-B
M@W:"S(_NE?&"JI+'B<&"Q8*K@MR"N8+Q@L6"M8*]@48E<P"#5H-8@V6#@(+)
M("(E<R(@@O"2QXG!@K6"W(*U@KV"S(+%@4&#C8-/@T.#DX+%@JN"W(*W@4(`
M@X:!6X-5@LR2QXG!CXB7G8+-EK.,^(+)@LB"P8+$@J*"W(*W@4(`CUJ/B@"#
M08-H@XR#6)*@`(K'EYT@+2"1O(+,@X:!6X-5@LR#08-.@UJ#6(R@`(K'EYT`
M061S`(-!@W2#2X-J@UB#7H.3`(-!@XN#;X-J@T$`@T&#BX-7@T:#BH-!`)7*
MEKP`B,J2=9&U@J:!1@"14Y64`)%3E$:/V(.&@5N#50"14X+$@LR#3X.+@5N#
M=@"14X+$@LR#08-.@UJ#6(R@`)6AD)2"S(-!@VB#C(-8@O"+EHG"`)34C8:5
M=(*K@XJ#6(-G@O"0W9+H@L6"JX+I@N:"I(+)@K6"W(*W@JF!2`"*^8+)D;:-
MW8*U@MR"MP"1XY'6@LP@24U34""#C8-/@T.#DP"1XY'6@LP@24U34""#<(-8
M@X^!6X-H`)'CD=:"S"!)35-0((.&@5N#59:\`)'CD=:"S(.!@5N#BX-!@VB#
MC(-8`)'CD=:"S(-E@Y.#=H.,@5N#9P"1XY'6@V6#3(-8@V>!1@"#08.!@XJ#
M2I?,@U2#@H-!`)5SD+."R))L@JJ.=Y+H@K."ZH+$@J*"W(*W`)=<BOJ"M8+(
M@J*#1X.)@5N"JI2MD+:"M8+<@K6"O0"#08.3@VB#B0"#08.3@U.#B8NDF&&-
MD0"#08.3@T^#0H.)`).]EKR#=H.-@TR#5H%;`).:@J8`D^R+R8%ID>67I(%J
M`(-!@Y.#98-"@T^#08%%@V^!6X-U@5N#7P"#08-V@XJ#4(%;@U:#AX.3`(-!
M@W:#BH-0@5N#5H.'@Y.(ZI>7`(-!@W:#BH-0@5N#5H.'@Y..9Y=PB<(`B;J(
MRH+,BZ273(+)DTN7<`"/LY1&`(*H@JB"YH*[@LR#5(-#@UD`@E.,C@"#08%;
M@TJ#0X-U@W2#0(-#@XN#5(-#@UD`@T&!6X-*@T.#=9:\`"5S((+,@U2#0X.3
M@T&#8H-VEW:+@8+PEGN3EH+)C>V/G(*U@L2"HH*B@L6"MX*I@4@`EGN3EH+)
M("(E<R(@@L:#5(-U@T^#BX%;@W:14X+$@O"-[8^<@K6"Q(*B@J*"Q8*W@JD_
M`(-!@XN#6X.3@V"#DXNDF&&-D0"#08.+@X&#:H-!BZ2888V1`(-!@XN#;P"#
M08-:@Y.#5H.'@Y.3AP"#08-7@T&!7I&^E;V7;9)NB.8`E=N.YXWLB\:"S([`
MC7.13X+)BFV41H+PBX&"WX+I@N:"I(+)@K6"W(*W@JF!2`"1MHW=@K6"R(*B
M@T^#BX%;@W:"\(WMCYR"M8+F@J2"QH*U@MR"M8*]@4(`D;:-W8*U@LB"HH-!
M@TZ#6H-8C*""\(WMCYR"M8+F@J2"QH*U@MR"M8*]@4(`D;:-W8*U@LB"HH-!
M@TZ#6H-8C*""\)72CU>"M8+F@J2"QH*U@MR"M8*]@4(`D;:-W8*U@LB"HHND
METR"\)72CU>"M8+F@J2"QH*U@MR"M8*]@4(`D:Z0JP""5XR.`(-)@5N#6(-G
M@XF#BH-!`(-)@5N#6(-G@XJ#08NDF&&-D0!!=71H7V-Y<G-Q;#H@E4N7=H+(
M24U!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?8WER=7,Z((-O
M@V*#3H-'@Y.#:(+-E4N7=H+(E%R7S8+PETR"M8+$@J*"W(*Y@O&!0@!!=71H
M7V-Y<G5S.B"7=HN!@K>"Z6EM87"*9Y*C@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U
M=&A?9G1P.B!&5%"*9Y*CBT"47(*J@MV"PH*I@NB"W(*Y@O$N(%!(4(+P("TM
M96YA8FQE+69T<""#28-V@U:#AX.3@O""PH*O@L2#4H.3@W"#0X.+@K6"R(*H
M@K6"Q(*M@KZ"LX*B@4(`075T:%]I;6%P.B!)34%0BF>2HXM`E%R"JHRI@L*"
MJ8+H@MR"N8+Q@4(`075T:%]K<F(U.B!K<F(UBF>2HXM`E%R"JHRI@L*"J8+H
M@MR"N8+Q@4(`075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y((+%@LR#AH%;
M@U62QXG!@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q`$%U=&A?;&1A<#H@06-T
M:79E($1I<F5C=&]R>2""Q8+,@X:!6X-5C>V/G(+-@U2#?(%;@V>"LX+J@L2"
MHH+<@KF"\0!!=71H7VQD87`Z($Q$05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y
M@O&!0@!!=71H7VQD87`Z((.&@5N#52`E<R""\)+'B<&"Q8*K@MR"N8+Q@4*#
M5(%;@V^"S(F>DYHZ(`!!=71H7VQD87`Z((.&@5N#52`E<R""\(WMCYR"Q8*K
M@MR"N8+Q`$%U=&A?;&1A<#H@@X:!6X-5("5S((+PC5B05H+%@JN"W(*Y@O$`
M075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y((+%@LR#AH%;@U6-6)!6@LV#
M5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q`$%U=&A?;6-A;#H@34-!4(IGDJ.+0)1<
M@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?<VUB875T:#H@<VUB875T:(IGDJ.+
M0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$E-05"#5(%;@V^"Q8+,E$:/V(+)CKB4
M<X*U@MR"M8*]@4(`E$:/V(+)CKB4<X*U@MR"M8*]`)1&C]B"R8ZXE'."M8+<
M@K6"O8%")7,`4D%$2553@U2!6X-O@LF"YH+HE$:/V(*JBY&4VX*S@NJ"W(*U
M@KV!0@!&5%"#5(%;@V^"S)1&C]B"R8ZXE'."M8+<@K6"O8%"`%--0H-4@5N#
M;X+,E$:/V(+)CKB4<X*U@MR"M8*]@4(`CF>7<(G"E%R"R(-T@T*!6X.+@VB!
M1@"#08-;@XN#;X-#@U>#@X.3BZ2888V1`)1WC&D`E'>,:9!&`$ME<F]B97)O
M<R"#<(-8@X^!6X-H@JJ6LXSX@L6"MX%"`$ME<F]B97)O<R"#AH%;@U66O(*J
MEK.,^(+%@K>!0@"#;X-N@WT`@V^!6X.,@5N#DP"#;X.3@T^#B8-F@U:#A9!L
MEJ^+I)AAC9$`@V^#BX-O@VB#6`"*[I9[@T^#B8-T@T*#3H-8@LR#9H-"@XR#
M3H-G@XJ!6R`B)7,B((*J@J""Z(+<@KF"\8%"`(KNCX"0_`"#>(.)@XN!6X-6
MBZ2888V1`(-X@XN#38%;`(-X@XJ!6X-9`(-X@VF#DXNDF&&-D0"#;X-^@X6!
M6X-?@6F/E).'@6H`@W6!6X->@Y.)I(V1`))AD+:3^@"#=8.-@V*#3B`B)7,B
M((+,@T&#=H.*@U"!6X-6@X>#DR`B)7,B((*J@J""Z(+<@KF"\8%"`(-U@XV#
M8H-.D-V2Z`"#=8.-@V*#3H->@T.#=@"1OHZ:`(-[@XJ#<H-!BZ2888V1`(-U
M@V*#3H-]@5N#3@")CP")CX+,D;Z"LX%&`(F/`(-[@UB#:H-!@46#=X.+@V.#
M1H-3@W*#:0"#>X-C@X^#:8NDF&&-D0"#=8%;@WB3AP"#=8.)@U>#BP")<)?,
M@T.#DX-HCY23AP"#=8.+@VR#0X%%@U^#BX-4@XF!6X.``(-U@XN#2X.*@T$`
MB=./\(^1@JL`@W6#BX-,@VF#=(-`@UP`@W6#BX.3@U>+I)AAC9$`0TU3`$-2
M0P!#4DP@E'J5>H-\@T.#DX-G`%]%@UJ#BY&ND*LN+BX`@TR#@X-B@U:#A8+,
MCXF*^HF[@JJ*KI>Y@K6"W(*Y@O&"Q8*U@KV!0@"77)+HE5P`@TJ#DX-[@U>#
M00"#2H.!@XN!6X.3BZ2888V1`(-P@UB#CX%;@VB"S8ZIDZZ"Q8+-@XJ#6H-B
M@V>"Q8*K@MR"N8+Q@4**QY>=CM*"R9A!EXV"M8+$B;J"LX*B@4(`@W2#0(-#
M@XL@(B5S(B""R8^1@J^"W(*Y@O&!0@"*3Y64@LR#6H-B@U:#AX.3@VZ#DX-H
M@XF!6X+-BL>7G8+%@JN"W(*Y@O&!0@!)34%0((-4@5N#;X+)D-J1L8+%@JN"
MW(*Y@O&"Q8*U@KTZ("5S`(-T@T"#0X.+("(E<R(@@JJ*2H*O@MR"N8+Q@4(`
M@TJ#:8-?`(-,@X.#DX-:@XL`C^&*497QC9""\(-,@X.#DX-:@XN"MX+I`(-T
M@T"#0X.+("(E<R(@@O"-[8^<@L6"JX+<@KF"\8%"`(WLB\:#9H-"@XR#3H-G
M@XJ"JHRIE72"J8+H@MR"N8+Q@4(`)W1A<F=E=$9I;&4G((-P@XF#@8%;@UZ"
MR(*U@L6"S9&QC7."Q8*K@MR"N8+Q@4(`@V:#0H.,@TZ#9X.*@5L@(B5S(B""
M\(WMCYR"Q8*K@MR"N8+Q@4(`C>V/G(+%@JN"W(*Y@O&!0HYQD;>"JB`E9""1
MMHW=@K6"W(*W@4(`E<""UY'6@J:"S)'.C]N"S)"4@JJ5VY&V@K."ZH+$@J*"
MZ9"4@L:-AX+M@LB"HH+,@L65P(+7D=:"IH*J@L6"JX+<@KF"\8%"`(YWDNB"
MLX+J@KV4U(V&@LF#@8-B@UJ!6X-7@O"4>I&7@L6"JX+<@KF"\8+%@K6"O8%"
M`(-*@5N#?(-X@XN#9HNDF&&-D0"57)'H`(-,@X.#BH-!`)6JE]Z"QH.)@WB#
MBP"#4(-#@WV#DX^4DX<`C&>1T9-DF&(`@UJ#BY&ND*L`@UJ#BY:$D9"!1@"#
M6H.+D:Z0JP"#6H.+EUV4DH%&`(QGD=&39)AB`)*&B9L`DH:)FX-!@W2#BH-*
MBZ2888V1`(_8EKZ/D8+,C]J-UP"/V):^CY&"S(^*ETR.T@"/V):^CY&#?(.*
M@U:!6P"#8(.#@VB+I)AAC9$`E<^-6`"#<(-8@X^!6X-H@O"5SXU8`)-DCG&#
M@8-#@XN"R8YGEW""MX+IEKR13X+&@T&#:(.,@UB"\)7/C5B"M8+<@K>!0@",
MNXW=@LR0W9+H@L6"S8-P@UB#CX%;@VB"S)7/C5B"\(-4@WR!6X-G@K6"Q(*B
M@MR"N8+Q@4**QY>=CM*"R9A!EXV"M8+$B;J"LX*B@4(`7TN#BH.3@TZ"\(-@
M@T:#8H-.+BXN`(-@@XJ+I)AAC9$`DH:)V)!LEJ^+I)AAC9$`@T&#=H.*@U"!
M6X-6@X>#DY%)D?"!1@"#<(-8@X^!6X-H@O"129'P`(.&@5N#59:\@O"129'P
M`)/ZE7257(ZFC&".KH%&`(-.@XJ#6(-]@UB3AP"#3H.)@UB2Z(M@("5S((*J
MC*F5=(*I@NB"W(*Y@O&!0@!-4RU/9F9I8V6"S(->@T^"\([F@NB/G(*M`(R?
MC?6/P8N.`(.&@5N#58+,D=Z+CH%&)7,`@X:!6X-5C\&+C@"#AH%;@U6#9H%;
M@UZ/P8N.`(-.@XJ#8H-.@K>"Z8+&CI^"U@"#18-"@Y.#:(-%@O"5PH*V@ND`
M@U*#4H-8CY23AP"#5(-#@VB#;X%;@O"/](+>`(-2@XV#DX-R@T&+I)AAC9$`
MD$8`D$:129'P`)!&D4F1\`"7\8%&`)?Q@UZ#0X-G@XL`@U*#?H-B@TZ#6`"#
M4H-]@Y.#:`"#4H-]@Y.#:(-6@T:#BP"#4H.!@Y.#9P"+I)+*EKP`@U*#@H.-
MF$&-AP")[X[0`)#=DNB"S(VWE:H`4$1!@4&#6(-]@5N#9X-T@TB#DX%!3W5T
M;&]O:X+&@LR3KXKZ@O"0W9+H@K6"W(*W@4(`D-V2Z(+-C]R6H8KZC,"0V(+J
M@L6"MX%"`"5S((+PD-V2Z(*W@ND`@W"#6(./@5N#:(+PBFV41@"#4H.3@U.+
MI)AAC9$`@U*#DX-3EJ^.Y8NDF&&-D0"0VI&QCKB4<X%"`)#:D;&.N)1S@48`
MC/:/3XRN@U2!6X-O@M:"S)#:D;&"JHN1E-N"LX+J@MR"M8*]@4(`C/:*2HRN
M@U2!6X-O@M:"S)#:D;&"JHN1E-N"LX+J@MR"M8*]@4*7G9=2@48E<R`H)7,I
M`$944(-4@5N#;X+6@LR0VI&Q@LF.N)1S@K6"W(*U@KV!0@"809>-D.8`F$&7
MC9#F@LV#08-H@XR#6)*@@LF2QXG!@K."ZH+<@K6"O8%"`(BSCVN#=(-`@T.#
MBX+,@U*#DX-E@Y.#8X->@T.#=H%&`"(E<R(@@LR3X)=E`)&Q@JT`@TZ#8H-.
MCY23AP"#4H-S@5L`@U*#<X%;CKB4<X%&)7,`D4F1\)3-B,V"\(-2@W.!6P"#
M4H-8@UZ#BH-*BZ2888V1`(-2@5N#9X-7@WN#CX%;@XN+I)AAC9$`@X&#8H-:
M@5N#5X+,(%!'4""(PXV&B;N"JH+%@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!
M6X-7@LP@4$=0((^0EKR"JH+%@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7
M@LP@4R]-24U%((C#C8:)NX*J@L6"JX+<@KF"\8+%@K6"O8%"`(.!@V*#6H%;
M@U>"S"!3+TU)344@CY"6O(*J@L6"JX+<@KF"\8+%@K6"O8%"`)A!EXV0YH+P
MDL>)P8+%@JN"W(*Y@O&"Q8*U@KV!0B5S`$Q$05`@@U2!6X-O@LF#;X-#@Y.#
M:(+%@JN"W(*Y@O&"Q8*U@KV!0@".8XV"@JJ*;91&@L6"JX+<@KF"\8+%@K6"
MO8%")7,`3$1!4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"M8*]@4(`1E10
M((+%@U2!6X-O("(E<R(@@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O3H@)7,`D9>0
M39#F@XJ#6(-G@JJ-[)"L@L6"JX+<@KF"\8+%@K6"O8%")7,`4$=0((-F@5N#
M7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*].@!3+TU)344@@V:!6X->@LR5
MG(V&B;N"JH+%@JN"W(*Y@O&"Q8*U@KV!0@"809>-D.:"JHWMCYR"Q8*K@MR"
MN8+Q@L6"M8*]@4(E<P"1EY!-D.:#BH-8@V>"JHWMCYR"Q8*K@MR"N8+Q@L6"
MM8*]@4(E<P"0W9+HC5B05I=P@UB#3H.*@W:#9R`B)7,B((+PC>V/G(+%@JN"
MW(*Y@O&"Q8*U@KV!0@".\Y!-CM*"S)-DCG&#@8%;@XN#08-H@XR#6(*JBFV2
MZ(+%@JN"W(*Y@O&"Q8*U@KV!0@"#08-H@XR#6)*@@JJ*KI%3@LF"S8[FD[Z"
MQ8*K@MR"N8+Q@L6"M8*]@4(`D9>039#F@XJ#6(-G@JJ*KI%3@LF"S8[FD[Z"
MQ8*K@MR"N8+Q@L6"M8*]@4(`D9>039#F@XJ#6(-G@JJ*KI%3@LF"S8[FD[Z"
MQ8*K@MR"N8+Q@L6"M8*]@4(`@UB#9X.)@V6#5X%;("(E<R(@@O"#C8%;@VB"
MQ8*K@MR"N8+Q@L6"M8*]@4(`36MD:7(@(B5S(B""R8ZXE'."M8+<@K6"O8%"
M`(SVBDJ,KH+PC*Z#5(%;@V^"J8+GCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0@`B
M)7,B((+PCY&"JXV>@MV7<(+)@TF!6X-V@Y."Q8*K@MR"N8+Q@L6"M8*]@4(`
M)7,@@O"#28%;@W:#DX+%@JN"W(*Y@O&"Q8*U@KV!0@"5VX[GC>R+QH."@U>#
MA8%;@XL@)7,@@O"*2H*O@MR"N8+Q@L6"M8*]@4(`@V:#0H.,@TZ#9X.*@5L@
M(B5S(B""JHI*@J^"W(*Y@O&"Q8*U@KV!0@!,1$%0((-4@5N#;X+)D-J1L8+%
M@JN"W(*Y@O&!0@`E<R""JI/'@MV/;X*Y@MR"N8+Q@4(`EW:+@8*S@NJ"O8.&
M@5N#58+,@W"#6(./@5N#:(+P@XJ#6H-B@V>"Q8*K@MR"N8+Q@L6"M8*]@4*"
MHH*M@L*"J8*@@NF"HH+-D5."Q(+,C^Z5\8+-BM2(X8+!@L2"HH+<@K>!0HW$
MDWB.CH*U@L2"W8+I@JF*QY>=CM*"R9A!EXV"M8+$B;J"LX*B@4(`04-,((+P
MCN:3OH+%@JN"W(*Y@O&"Q8*U@KT`@T&#:(.,@UB2H(+PCN:3OH+%@JN"W(*Y
M@O&"Q8*U@KV!0B5S`)&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U
M@KV!0B5S`)&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S
M`(-4@5N#;X+,BT"47(CJEY>"\([FD[Z"Q8*K@MR"N8+Q@L6"M8*]`)#=DNB"
M\(RS@LF6WX*Y@MR"N8+Q@L6"M8*]@4(`(B5S(B"#9H-"@XR#3H-G@XJ!6X*J
MC>V/G(+%@JN"W(*Y@O&!0@`E<R"0W9+H@O"5VY&V@L6"JX+<@KF"\8+%@K6"
MO8%"`)#=DNB"S(-O@V*#3H-!@V*#=H+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!
M0@"0W9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@48E
M<P"0W9+HC5B05I=P@UB#3H.*@W:#9X+P("(E<R(@@LF5VY&V@L6"JX+<@KF"
M\8+%@K6"O8%"`)#=DNB"S(-O@V*#3H-!@V*#=H-T@T"#0X.+("5S((+PE=N1
MMH+%@JN"W(*Y@O&"Q8*U@KV!0@"0W9+H@W2#0(-#@XL@)7,@@LF5VY&V@L6"
MJX+<@KF"\8+%@K6"O8%")7,@@LF6WX+!@L25VY&V@TF#=H-6@X>#DX+PCL"-
M<X*W@NF"J8%!CNB"Q8*Q@LR)YI;*@LR#4H%;@VB"\"`E<R""R8-2@W.!6X*U
M@L2)NH*S@J*!0@!,1$%0((-4@5N#;X*JC)^-]8+%@JN"W(*Y@O&!0@`B)7,B
M((+PC>V/G"AU;FQI;FLI@L6"JX+<@KF"\8+%@K6"O8%"`)A!EXV0YH+PC5B0
M5H+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7D$V0YH.*@UB#9X+PC5B05H+%@JN"
MW(*Y@O&"Q8*U@KV!0B5S`"(E<R(@@LR0W9+H@JJ/D8*KC9Z"WX+<@KF"\8%&
M)7,`36]Z:6QL82""S(-4@T.#:(-O@5N"JHRIE72"J8+H@MR"N8+Q@4*#5(-#
M@VB#;X%;@O"*2H*B@L2)NH*S@J*!0@"-D0"-[)"L`)!6BTN-[)"L`(-4@W6#
M=(-(@XN#7X+PC>R0K`"-[)"LCM*"S(-!@TZ#6H-8C*``@TZ#C(-7@V*#9X-*
M@5N#:)34C88`@TZ#C8-!@V"#08NDF&&-D0"#3(.%@5N#;XNDF&&-D0",NXW=
M@LR#6H-B@U:#AX.3`(R[C=V"S(Z>BM0`C+N-W8+,(%523"""S0",NXW=@LR#
MAH%;@U6!6P`E<R""UH+,@XV#3X-)@Y..GH+)CL"-<X*W@NF#7H-8@TZ"\)#=
MDNB"M8+<@K>!0@"0V(+HCN:"Z`"129'PE,V(S8+PD-B"Z([F@N@`@TR#=H.-
M@UB+I)AAC9$`@V"#1H-2BZ2888V1`)/Z`):(D_H`1&%T851R964@B7N7EP"#
M9H%;@UZ#>(%;@UB.48_&`)/ZE70`@V:!6X->CO.030"3^I5TD4F1\`!?3)?Q
M@LR-[8^<`#$RC(X`CUR0:9"4`))IB;J"L(+PD/."K0"#9H-T@TB#BX-G`(-F
M@W2#2(.+@V>01@"#9H-T@TB#BX-G($E$`(-F@W2#2(.+@V<@<VAE;&P`C>V/
MG`"#6H.+C>V/G`"#3X.+@5N#=H+PC>V/G`"#C8-/@LR-[8^<`(-!@TZ#6H-8
MC*""\(WMCYP`@UJ#BXWMCYP`E_&"S(WMCYP`D>.1UH-E@Y.#=H.,@5N#9X+,
MC>V/G`"#@8-B@UJ!6X-7@O"-[8^<`"(E<R(@@LR#08-.@UJ#6(R@@O"-[8^<
M`"(E<R(@@LR#08-.@UJ#6(R@@L:"NX+,@U2#=8-!@TZ#6H-8C*""\)%3@L2-
M[8^<@K6"W(*W@JF!2`"-<X+,C>V/G`"129'P@K6"O4E$@O"-[8^<`(-4@W6#
M=(-(@XN#7X+PC>V/G`",NXW=B,J2=8+,E_&"\(WMCYP`C+N-W8C*DG6"S(US
M@O"-[8^<`)#=DNB-6)!6EW"#6(-.@XJ#=H-G("(E<R(@@O"-[8^<@K6"W(*U
M@KV!0@"4>I&7CIZ*U`"#9H.3@WV!6X-.`(_ABE&3X)=E@LR0X):^`)#@EKX`
MC]J-UX%I2&]R9&6"S(.-@T^#=(-`@T.#BX+@CE&/QH%J@48`C]J-UX+-BL>7
MG8[2@LR"O8+?@LF+3)A>@K."ZH+<@K6"O8%"`(I*E*T`C;:"J8+GB46"U@")
M18*I@N>-MH+6`#(TCIZ*U)5<CJ8`E5R.IH-)@W:#5H.'@Y,`@U>#=8-@BZ28
M88V1`(WMCYR"M8+(@J(`;6%I;G1E;F%N8V4N<&AP((+)DKR0VH-!@TZ#6H-8
M@K6"R(*B@L6"K8*^@K."H@"-Q8^)@LR7\8*J@W2#0H%;@XN#:):\@O"*W(+Q
M@L6"HH+<@K>"J3\@@KN"I(+(@N>#8(-&@V*#3H*U@L2"K8*^@K."HH%&`(-H
M@WZ#:H-*`(-H@WZ#:H-*BZ2888V1`(-!@TJ#18.3@V>"JI5+EW:"R(+G@U2#
M0X.3@T&#8H-V@4(`@U^#18.3@XV!6X-H`"5S((+,@U^#18.3@XV!6X-H`)"V
MD*R"LX+J@KV0W9+H@O`@4$A0((-8@TZ#BH-V@V>"\(+&@K6"Q(-?@T6#DX.-
M@5N#:(*W@NF!0@"39(YQ@X&!6X.+`(-'@TZ#08-H@XN+I)AAC9$`E=*/5P"#
M=8.-@V*#3H+,E=*/5P"#3X.+@5N#=H+,E=*/5P"#08-.@UJ#6(R@@LR5TH]7
M`(-!@TZ#6H-8C*""S)72CU<`)7,@@LR#08-.@UJ#6(R@@LR5TH]7`(-)@W:#
M5H.'@Y."S)72CU>!1@`B)7,B((+,@T&#3H-:@UB,H(+,E=*/5P`E<R""S(-!
M@TZ#6H-8C*""S)72CU<`@T>#5X-V@V>!18-!@XF#=8NDF&&-D0"#1X.+@U2#
MBX-O@VB#BXNDF&&-D0"39(YQ@X&!6X.+`$6#@8%;@XN#08-H@XR#6`!%@X&!
M6X.+@T&#:(.,@UB"JHCJDG:"M8+(@J^"ZH+.@J*"KX+<@KF"\8%"`$6#@8%;
M@XN#08-H@XR#6(IME$8`B_.#@8-B@UJ!6X-7@L6"MX%"`(F]@N",J8+"@JF"
MZ(+<@KF"\8%"`(OS@LR,GXWUC.H`@TV#@X.)@XJ!6X*I@N>)YI&<@O"1?9/\
M@L6"JX+I@N:"I(+)@K6"W(*W@JF!2`")18-.@XJ#8H-.@L6#@8-J@X6!6X+P
ME5R.IH*U@MR"MX*I@4@`@T>#9H-"@UZ!6XGFELJ"\)'E@JN"K0""H(+(@KV"
MS(-P@UB#CX%;@VB"\(.*@UJ#8H-G@K>"Z8Z>@LR7<)!3@LR"O8+?@LR.OY;B
M@O"3_)?-@4*7X8*F@LZ!08%U@WF#8H-G@LR6O)%/@LV!2(%V@48`B>:1G(+,
M55),@O"3_)?-`)#4D[F#38-J@T&+I)AAC9$`@T>#BH-G@XJ#00"#1X.)@5L`
M@W6#C8-B@TZ-[)"L@T>#B8%;.B`E<RX`DZ^*^H.-@T^"S(WMCYR#1X.)@5LZ
M("5S+@"3X)=ECN:3OH-'@XF!6SH@)7,N`(-P@UB#CX%;@VB-6)!6@T>#B8%;
M.B`E<RX`@X&!6X.+@T&#:(.,@UB"S(-'@XF!6X+%@K>!0@`B)7,B((+,CY&"
MJXV>@MV#1X.)@5N"Q8*W@4(`@T>#6(-G@VJ#08NDF&&-D0"#1X-@@TF#<X-!
M`(.(@5N#C8-B@W``,365JI:(`#*5JI:(`#,PE:J6B``UE:J6B`"#C8-/@T.#
MDY:(`#,PE:J6B``QE:J6B`".=Y+HDFR"S)?A`([`C7,`DU>*2@"#5(-#@VB#
M;X%;@O"35XI*`"<I)R""\)-7BDH`ETR,^(KZC,``CG>0E`"13XQID$8`D-V2
MZ(+P($944"""Q8-!@V*#=H.-@5N#:(*W@ND`@W:#C(-T@T"#C(.3@UB0W9+H
M@O".YI.^@L6"JX+<@KF"\8%"`$Q$05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"
M\8+%@K6"O8%"`%--0B"#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"M8*]@4(`
M(B5S(B""J8+G@LR#4H-S@5N"R8ZXE'."M8+<@K6"O8%"`"(E<R(@@M:"S(-2
M@W.!6X+)CKB4<X*U@MR"M8*]@4(`D%:+2X+,(%-!4TP@D-J1L8+)CKB4<X*U
M@MR"M8*]@4(`(B5S(B""UH+,B-J3KH+)CKB4<X*U@MR"M8*]@4(`CN:3OH+)
MCKB4<X*U@MR"M8*]@48E<P"#=(-(@5N#3H.)@Y.#:(^4DX>!:8-]@XN#<H-I
M@UB/E).'@6H`@W2#1H.-@5N/E).'`))VEKV328-'@XF!6X%&`$9!6`!&05@`
M@E&,C@"#=(-"@U>!6X^4DX>+I)AAC9$`@W2#0(-#@XL`@W2#0(-#@XN0E#H@
M)7,@@W2#0(-#@XL`@W2#0(-#@XN0E#H@)7,@@W2#0(-#@XL`@W2#0(-#@XN#
M?8-L@5N#5X.#`(-T@T"#0X.+EKP`@W2#0(-#@XN129'P`(-T@T"#0X.+@T&#
M8H-V@XV!6X-H`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LV#5(-\@5N#9X*S@NJ"
MQ(*B@MR"N8+Q@4(`@W2#0H.+@UX`@W2#0H.3@XF#DX-HBZ2888V1`(_CC+>"
MS(R.`(-T@TB#BX-?@5L@)7,@@JJ"H(+H@MR"N8+Q`)6VCIJ01@")YI&<@O"#
M5(-\@5N#9X*U@LB"HH-U@XF#18-5EW``@W"#6(./@5N#:(+PEEF"ZH+$@K6"
MW(*B@MR"M8*]@JF!2`"#=(-(@5N#@`"#=(-(@5N#B8.``(O@`)AG`(-T@XF#
MDX-8BZ2888V1`(-T@XF#DX-8@6F6>XV1@6H`@W2#B8.3@UB7S(--@T&#:0"#
M=(.)@Y.#6)?,@WR#BH-L@U:#00"#=(.)@Y.#6)?,B\F3[(^4DX<`C]J"M8*B
MD."6O@"6GHR.`(Z!EKP`@TN#>X.3BZ2888V1`(GFD9R"\([F@NB/;X*W@TV#
M@X.)@XJ!6P"#38.#@XF#BH%;@48`@TN#DX-R@T&+I)AAC9$`)7,@C5R0K(_N
ME?&"\)"VD*R"MX+I`)"VD*R"LX+J@KV#4H%;@V@`@T^#BX-7@T&+I)AAC9$`
M@VB#0X-CF$&638NDF&&-D0"#2X%;@VF+I)AAC9$`@U>#=8.)@XN#7H.+`)"I
M`(NDDLJ#28-V@U:#AX.3`$=O;V=L92"#?8-B@W8`1V]O9VQE((R?C?4`@TV#
MBH-6@X.+I)AAC9$`@T^#BH%;@Y.#B8.3@V@`@T^#C(-I@U\`@T^#BX%;@W:*
MQY>=`(-/@XN!6X-VEKR"S8OSE)*"Q8+-@LB"HH*Q@L8`1W)O=7!?;&1A<#H@
M@T^#BX%;@W8@)7,@@O"2QXG!@L6"JX+<@KF"\8%"@U2!6X-O@LR)GI.:.B``
M1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@@O"-[8^<@L6"JX+<@KF"\0!'<F]U
M<%]L9&%P.B"#3X.+@5N#=B`E<R""\(U8D%:"Q8*K@MR"N8+Q`(-/@XN!6X-V
M`(-/@T&#:(.+@5N#=I.'`(-/@T&#@).'`(-/@T&#98-]@XF+I)AAC9$`@TN!
M6X.3@U>!6Y.'`(-1@UB#9X-!@TZ#6H-8C*``@U&#6(-G@W6#8H-.`(--@VJ#
M08NDF&&-D0"#38-J@T&#<H-4@T6+I)AAC9$`@TN#0X-!@VF+I).OBZ2888V1
M`$A45%`@E$:/V(*J@MV"PH*I@NB"W(*Y@O&!0@"#;H-#@V"+I)AAC9$`@VZ#
M8H-6@X6#08.+@U.#BH-9@X``@W>#8H-?`(-W@V*#7P"#;H%;@VB!18-]@TZ#
M:(-I@XN#:(^4DX<`C8*"LP"#=X.+@W8`E+R+A0"#>H%;@X``@XV!6X-]ED")
MI)*A@6F#;X-@@TJ#DXYSC9&!:@"#>H%;@X``CJF1[H+,CUJ/B@"#>H%;@X"#
M9H-"@XR#3H-G@XJ!6P".J9'N@LR39)ABE-2-A@"#>H.3@U>#A8.)@UB+I)AA
MC9$`C8&-8`!(;W)D90!(;W)D92]+;VQA8CH@E7.0LX+((%A-3""#9H%;@UX@
M)7,@@JJ#@8-B@UJ!6X-7("5S((+%C)^/;X*S@NJ"W(*U@KT`2&]R9&4O2V]L
M86(Z((-)@W6#5X-&@TZ#9R`E<R""R9'.B9Z"MX+I@X&#8H-:@5N#5X+-@J""
MZ(+<@KF"\0!(;W)D92]+;VQA8CH@@TF#=8-7@T:#3H-GC%X@)7,@@LV#@8-B
M@UJ!6X-7("5S((+)@LV"H(+H@MR"N8+Q`$AO<F1E+TMO;&%B.B`E<R""S8WM
MCYR"LX+J@MR"M8*]("(E<R(`2&]R9&4O2V]L86(Z(%!(4""*9Y*C("=D;VUX
M;6PG((*JE4N7=H+%@K<`2&]R9&4O2V]L86(Z((-)@W6#5X-&@TZ#9R`E<R""
MS"!834P@@V.#BH%;@JJ-[)"L@L6"JX+<@KF"\0!(;W)D92]+;VQA8CH@)7,@
M@JJ-[8^<@L6"JX+<@KF"\2`B)7,B.B`E<P!(;W)D92]+;VQA8CH@)7,@@LP@
M34E-12!)1"""JH[FD[Z"Q8*K@MR"N8+Q`$AO<F1E+TMO;&%B.B`E<R""QI.O
MBOJ"Q8*K@MR"N8+Q("(E<R(Z("5S`$AO<F1E+TMO;&%B.B"3KXKZ@L6"JX+<
M@KF"\8%&)7,`2&]R9&4O2V]L86(Z("(E<R(@@LV5<Y:^@LB+I)=,@L6"MP"0
MA96]D/P`@J*"K8+"@LR7\8+PC(N-AX*U@MR"MX*I@4@`@W2#0H%;@XN#:"B-
M<RF"S)"4@LV"HH*M@L*"Q8*W@JF!2`""HH*M@L*"S(US@O",BXV'@K6"W(*W
M@JF!2`"#;H.3@TN#BH%;BZ2888V1`$E-05`@@X&!6X.+@WN#8H-.@UB"S(WL
MD*R"R8ZXE'."M8+<@K6"O3H@)7,`24U!4""#@8%;@XN#>X-B@TZ#6(+,C>V/
MG(+)CKB4<X*U@MR"M8*].B`E<P!)34%0((.!@5N#BX-[@V*#3H-8@TZ#2(%;
M@UZ"S(WLD*R"R8ZXE'."M8+<@K6"O3H@)7,`25`@@T&#:(.,@U@`25`@@T&#
M:(.,@UB"JH*@@NB"W(*Y@O&!0@!)4(-!@VB#C(-8@JJ+EHG"@K."ZH*]0TE$
M4H-U@XV#8H-.D^""R8*@@NB"W(*Y@O&!0@!)4)65C;V(X92]@L6"MX%"`(-!
M@T.#6(.)@Y.#:(NDF&&-D0"#08-#@U*#DX+,@MT`)7,@@LR#08-#@U*#DP"#
M08-#@U*#DX+&@V6#3(-8@V<`242"S):\D4\`@N""M8+@D+."M8*ME5R.IH*S
M@NJ"R(*B@LB"YX%!)7,@@K6"Q)!6@K6"HH-%@T.#DX-H@5N"\(I*@J*"Q(FZ
M@K."HH%"`(+@@K6"X"!);G1E<FYE="!%>'!L;W)E<B""\(YG@L&"Q(*B@L2!
M08-!@T.#4H.3@JJ57(ZF@K."ZH+(@J*"R(+G@4&"L8*Q@O"129'P@K6"Q(FZ
M@K."HH%"`(GFD9R#=H.,@W*#A8%;`(GFD9P@55),`(GFD9P@55),.@")YI&<
M`(-#@Y.#?(%;@V>!08-8@V6#8H-V("5D`(-#@Y.#?(%;@V>"LX+J@KV#=(-"
M@5N#BX-H@48@)7,`@T.#DX-\@5N#9X*S@NJ"O8-T@T*!6X.+@VB!1@"*U(CA
M@L&"O8-!@TZ#5H.'@Y.#4H%;@VB"JI=>@J:"YX+J@L2"HH+<@K>!0@"#AH%;
M@U66O(*I@W"#6(./@5N#:(*JD+."M8*M@J""Z(+<@KF"\8%"`(.&@5N#59:\
M@JF1XY'6@T&#:(.,@UB"JI"S@K6"K8*@@NB"W(*Y@O&!0HW$DWB.CH*U@L2"
MW8+I@JF!08K'EYV.TH+)F$&7C8*U@L2)NH*S@J*!0@"2:8FZ@K""\)!;@JT`
M@T.#DX-H`(S"E<J#AH%;@U4`@T.#DX-H@VR#5H-!BZ2888V1`(_NE?$`@T.#
MDX-T@TB#@8%;@U:#AX.3`%]/C.."ZX+)E_&"\)%]D_P`B>:1G(+PD7V3_`"5
M7(+PD7V3_`"#BH.3@TZ"\)%]D_P`7T.13X+)E_&"\)%]D_P`C+N-W8C*DG6"
MS(SC@NN"R9?Q@O"1?9/\`(R[C=V(RI)U@LR13X+)E_&"\)%]D_P`C+N-W8C*
MDG6"S(SC@NN"R8US@O"1?9/\`(R[C=V(RI)U@LR13X+)C7."\)%]D_P`C+N-
MW8C*DG6"S(SC@NN"R9)IEXZ"\)%]D_P`C+N-W8C*DG6"S)%/@LF2:9>.@O"1
M?9/\`)'CD=:#98.3@W:#C(%;@V>"S)%]D_P`D%:"M8*B@W"#6(./@5N#:(+P
MCO."KX[F@NF#@8%;@XN#08-H@XR#6(+PD_R7S8%&`(SC@NN"R8-:@XN"\)%]
MD_P`D4^"R8-:@XN"\)%]D_P`C.."ZX+)E_&"\)%]D_P`D4^"R8-:@XN"\)%]
MD_P`@X&#8H-:@5N#5X+PD7V3_`",XX+K@LF2:9>.@O"1?9/\`)%/@LF2:9>.
M@O"1?9/\`(SC@NN"R8US@O"1?9/\`)%/@LF-<X+PD7V3_`"7<)!3@LR"O8+?
M@LR.OY;B@LR3FH*F@O"3_)?-@48`B>:1G(+,D7V3_(%>E<^-6`"#BH.3@TZ"
MS)%]D_R!7I7/C5@`D9>039#F@LF1EX+I@KV"WX+,CF.-@H*JE7.1JX*U@L2"
MHH+<@K>!0@".8XV"@JJ5<Y&K@L6"MX%"`)5SD+."R"!::7`@@V:!6X->@L6"
MMX%"`)5SD+."R(-!@W:#BH-0@5N#5H.'@Y."Q8*W@4(`EK.,^(+(@V:!6X->
M@JJ2\8]O@K."ZH+<@K6"O2X`D9>"Z)#F@LR#08-H@XR#6(*JE7.0LX+%@K>!
M0@"5<Y"S@LB#B8-#@UJ#DX-8@TR#0X+%@K>!0@"5<Y"S@LB/ZH^*@JJ.=Y+H
M@K."ZH+<@K6"O8%"`(_CB,J"S(-!@TZ#6H-8C*""JI5SD+."Q8*W@4(`E7.0
MLX+(@W"!6X-G@VF!6TE$@L6"MX%"`)5SD+."R)"[E6F#4H%;@VB"Q8*W@4(`
ME7.0LX+(@W:#C8-G@U*#BX+%@K>!0@"5<Y"S@LB.\Y!-CM*"Q8*W@48B)7,B
M`)5SD+."R(NDETR#28-U@U>#1H-.@V<`E7.0LX+(E*V038RS@T&#:(.,@UB"
MQ8*W@4(`E7.0LX+(=6YI8V]D98-F@5N#7H+%@K>!0@"129'P@O"4O9-=`(-#
M@XF#DX%%@T.#6(.)@X"+I)AAC9$`@T.#B8-.BZ2888V1`(-!@T.#BX.)@Y.#
M:`"#?8.3DX<`@T.#6(.)@T>#BP"4K8USCM(`CLZ1S`"#0X->@XJ#08NDF&&-
MD0"#5X.#@WV#0X-*`()0C(X`D_J6>P"#5X.#@5N#5X%;DX<`@XB#BX-?@Y,`
M@E:,C@""58R.`)&U@J:"Z0"2AHF;D;6"I@"7O));D;6"I@"-MI&U@J8`B461
MM8*F`(-*@U6#=(-8@UZ#DXNDF&&-D0"#28.*@U>#:8.+@O"5VY&V@4@`@U"#
M:H-!BZ2888V1`$ME<F)E<F]S((-4@5N#;X*JE$:/V(N1E-N"M8+<@K6"O8%"
M`(RNC>R0K)/Z`(RNCG>6Y`",KI*W`(RNCNV7W@"39(YQC*Z"JH*W@L6"R8SV
MCT^,KH-4@5N#;X+)D;:-W8*U@MR"MX%"`(-,@XJ#;X-8BZ2888V1`)*ID4Z6
MKX[ECN6+8)!LEJ^+I)AAC9$`D>6*V):OC9$`@TZ#18-&@5N#9P"#3(.+@TV#
M6(NDF&&-D0!?68.,@T.#08-%@V<`C+Z,Z@"#B8-)@UB0;):OEJ^.Y8NDF&&-
MD0")NHRW@LR,C@"13XGQ@LR#C8-/@T.#DSH@)7,`D4^)\8+,@XV#3X-#@Y,Z
M("4R)',@@JF"YR`E,21S`)%/B?&"S(.-@T^#0X.3.B""R(*U`(.)@V>#<H-!
MBZ2888V1`)1ZDG4`@XR#;X-M@Y.+I)AAC9$`C;8`@XR#7(-GB:2-D0"#BH-X
M@XJ#08NDF&&-D0"1Y8.*@W*#08%%@T&#B8-UCM")[X[EBV"0;):O@U>#@X-]
M@5N#<8.*@5N#A`"#BH-Q@V6#DX-6@X6#7H-#@Y.,]HV1`(.*@Y.#3@"#@8%;
M@XN-[)"LEW""R8.!@5N#BX-!@VB#C(-8@LF#BH.3@TZ"MX+I`(-F@5N#7H-X
M@5N#6(CJEY<`@W>#BX-VC8"6VH+PE5R.IH*W@ND`E5R"S(CJEY<`@UJ#8H-6
M@X>#DX+,B.J7EXWLD*R"R8ZXE'.!1B5S`(.&@5N#58+,B.J7EXWLD*R"R8ZX
ME'.!1B5S`(.&@5N#58+,@XJ#6(-G@LV6LXSX@LF"R(+!@L2"HH+<@K>!0@"#
MBH-G@T&#:H-!BZ2888V1`(.-@5N#:)*&+BXN`(R[DFZ.GHK4@48`DFZ(YH+&
MCIZ*U`"/ZH^*`(.-@T^#0X.3`(.-@T^#08-%@V<`@XV#3X-#@Y,`@XV#3X-#
M@Y,@@UZ#6(-.`(.&@5N#59:\@JF#<(-8@X^!6X-H@JJ0LX*U@JV"R(*B@KV"
MWX+)@XV#3X-#@Y."R8ZXE'."M8+<@K6"O8%"`(.-@T^#0X.3@LF.N)1S@K6"
MW(*U@KV!0@"#38.*@U:#@Y6VCIJ!:8^LE;:.FH%J`(.)@V6#DY6VCIJ!:8^L
ME;:.FH%J`(.-@5N#?9"4CIJ!:8^LE;:.FH%J`(.+@TZ#6H.3@W6#BX-.D>6,
M]HV1`(R.`)-9E72"LX+J@KT@35,M5$Y%1B""S8-F@5N#7H+PBMR"\8+%@J*"
MW(*Y@O&!0@"#?8-*@TD`@WV#4(-H@VJ#08N,@X:!6X-3@UB#B8-R@T&+I)AA
MC9$`@WV#7X-+@UB#2H.+BZ2888V1`)-DCG&#@8%;@XL`@WV#B8-%@T.+I)AA
MC9$`@WV#C(%;@U:#00"#@H.+@V:#0H-UBZ2888V1`)-DCG&#@8%;@XL`@WV#
MBX->BZ2888V1`)!&E72"KX*S@NJ"O8.)@WB#BX+PD<Z)GH*S@KF"Q)6JE]Z"
M\(K'EYV"M8+<@K>!0@""4HR.`(-]@5N#5H.#@XN/E).'BZ2888V1`(-]@XN#
M98-"@VJ#3I.'`(-T@T*!6X.+@VB"\(CJDG:"LX*Y@L2"HH+<@K<`@X*!6X.*
M@UZ#:H-!@46#0X-8@XF#@(NDF&&-D0"#@H%;@XJ#5H.#@UB+I)AAC9$`@E2,
MC@"#?8-#@XB#8H-GDX<`@X&#DX-O`(.!@VJ#A8%;@X*!6X-H`(-:@XN,BXV'
M`)9[E;8`@X&#8H-:@5N#5X+-C)^/V(+%@JN"W(*U@KV"JH%!CY"6O([2@LR0
M9XRS@LV,GX_8@L6"JX+<@KF"\8+%@K6"O8%"`(.!@UR#8H-H`(.!@UR#8H-H
M("(E<R(@@LV2Z(M@@K."ZH+$@MR"N8+Q`(.!@TR#5H-2C8>/3XV1`(-^@TZ#
MC8-L@U:#09A!EDT`36EM92!4>7!E`%!%05(@@W"#8H-0@5N#5X+,($A45%!?
M4F5Q=65S="""JHRIDY:"O8+H@MR"N8+Q@4(`EJ*0W9+H@L6"MX%"@K&"S(-!
M@W:#BH-0@5N#5H.'@Y."\(YGEW""MX+I@KV"WX+)@LV0W9+H@W2#0(-#@XN"
M\(WLD*R"MX+IE4N7=H*J@J""Z(+<@K>!0@"#@8-B@UJ!6X-7($E$((*JC*F3
MEH*]@NB"W(*Y@O&!0@!014%2((-P@V*#4(%;@U>"S"!-86EL((*JC*F3EH*]
M@NB"W(*Y@O&!0@"#6H-B@U:#AX.3($E$((*JC*F3EH*]@NB"W(*Y@O&!0@",
MC@",9Y'1@X&!6X.+`(]#D+.3^@"#@H.+@VB#;XNDF&&-D0"#@H-I@U*,]HV1
M`(."@Y.#4X.+`):(C(X`@X*#DX-G@UJ#B8-GDX<`C(Z7[@"#@H.-@V*#4HFD
MC9$`B;J"U@"-MH+6`(E%@M8`C^."U@")NH+6`(_C@M8`@X*#58.3@W*!6X-.
MBZ2888V1`(-!@TJ#18.3@V<`@T&#2H-%@Y.#9X_NE?$`@WZ#@X.3@WV!6YA!
MEDT`DZ^(TX*U@MR"N8+Q`):\D4\`@VF#?H-R@T&+I)AAC9$`@VF#18.+BZ28
M88V1`(-L@W"!6X.+B:2-D0"#28.)@Y.#7XFDC9$`@TF#B8.3@U^7S(-!@Y.#
M98-"@XN/E).'`(-L@V*#9X./@5N#3@""R(*U`(-T@XF#DX-8E\R#:H.%@5N#
M2H.,@VB#:H-!`)!6BTN5JI?>`)!6C(X`D%:"M8*B@X:!6X-5EKPHE$.(TRD`
M@VJ#A8%;@U>!6X.)@Y.#:`"05H*U@J*#<(-8@X^!6X-H`)!6@K6"HH-P@UB#
MCX%;@VB"S2`E>"""R8KZC,"0V(+J@LF"R(+H@MR"MX%"`)!6@K6"HH-P@UB#
MCX%;@VB"JHCJDG:"M8+<@KF"\8%"`(-J@X6!6X-8`(-J@X6!6X-8@T^#BX%;
M@W8`CI\`CI^"S(-)@W:#5H.'@Y,`CI^"S(-Y@5N#5SX`@VJ#2H.)@T^#08ND
MF&&-D0"#:H-7@T:!6X.+BZ2888V1`(-I@T.#5X-&@XJ#09A!EDV+I)AAC9$`
M@VJ#18-'DX<`C;>5JH+PE5R.IH*W@NF"O8+?@LR0W9+H@JJ"H(+H@MR"N8+Q
M@4(`E<^-6(+(@K6!0@""L8+,@T&#3H-:@UB,H(+)@LV#5(-U@T&#3H-:@UB,
MH(+-DL>)P8+%@JN"W(*Y@O&!0@`E<R""S)#=DNB/[I7Q@JJ.=Y+H@K."ZH+$
M@J*"W(*Y@O&!0@!&5%`@5D93((+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<
M@KF"\8%"`%-13"!61E,@@LR-7)"LC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q
M@4(`4U%,((-*@V6#4X.*@LR-7)"LC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q
M@4(`CF.-@H*J@J""Z(+<@KF"\8%"`)&7D$V0YH*JCG>2Z(*S@NJ"Q(*B@MR"
MN8+Q@4(`@W2#0(-#@XN"JH-!@V*#=H.-@5N#:(*S@NJ"Q(*B@MR"N8+Q`(-!
M@T.#4H.3@JJ"H(+H@MR"N8+Q@4(`C^J/BH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q
M@4(`@X&#8H-:@5N#5X*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`EKR13X*JCG>2
MZ(*S@NJ"Q(*B@MR"N8+Q@4(`E-2-AH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`
M2%144""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(`24U!4""41H_8
M@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(`2V5R8F5R;W,@E$:/V(+,@W"#
M6(./@5N#:(*J@J""Z(+<@KF"\8%"`(.-@T^#0X.3()1&C]B"S(-P@UB#CX%;
M@VB"JH*@@NB"W(*Y@O&!0@!005-35T0@E$:/V(+,@W"#6(./@5N#:(*J@J""
MZ(+<@KF"\8%"`%--0B"41H_8@LR-7)"LC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"
MN8+Q@4(`3W!E;E-33""#=H.-@T^#B8.`@LR#<(-8@JJ.=Y+H@K."ZH+$@J*"
MW(*Y@O&!0D]P96Y34TP@@LT@4$M#4R`Q,B""S(-F@5N#7H+PB+6"I(+,@LF5
M2Y=V@L6"MX%"`)7;EZ^"S(-4@T.#DX-!@V*#=H+(@K6!0@"#3H-(@5N#7H*J
MD-V2Z(*S@NJ"Q(*B@MR"N8+Q@4(`@UJ#<(.,@5N#7H*JCG>2Z(*S@NJ"Q(*B
M@MR"N8+Q@4(`BEF3EH-T@T"#0X.+@LB"M0"#AH%;@U66O(*I@W"#6(./@5N#
M:(*JD9>"YX+J@MR"N8+Q@L6"M8*]@4(`EK.,^(+,6$U,@V:!6X->@JJ5U(+H
M@MR"M8*]`))L@LB"M0"#28.*@U>#:8.+@LR0W9+H@W2#0(-#@XN"R8-O@5N#
M5X.'@Y."JH*@@NB"W(*Y@O&!0I#=DNB"\(W$D+:0K(*U@MR"MX%"`)#=DNB#
M=(-`@T.#BX+)@V^!6X-7@X>#DX*J@J""Z(+<@KF"\8%"D-V2Z(-T@T"#0X.+
M@O"-[(+HDKR"M8+$B;J"LX*B@4(`@LB"M0"#;8%;@W2#2(%;@TZ3AP"6:Y2\
MBX4`EFN#?8.*@T&#:8^4DX<`@VV#BX-%@T:!6XFDC9$`@K&"ZH+F@NB13P""
ML8+J@N:"Z(SC`(-F@T*#C(-.@V>#BH+%@LV"H(+H@MR"N8+Q`([`D96"LX+J
M@L2"HH+<@KF"\8%"`(-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!0@"#@8."`#$Q
MC(X`D)0`E;:.FI"4`)?QD)0`C7.0E`"1EY!-D.:#BH-8@V>"\(U8D%:"O8+?
M@LR4U(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"O8%"`$]+`(-)@W6#5X-&@TZ#
M9P"#28-U@U>#1H-.@V>-[)"LCM(`,3",C@"#28-T@T*#6`",PX*B@W"#6(./
M@5N#:`",PX*B@W"#6(./@5N#:(*JD+."M8*M@J""Z(+<@KF"\0"#28-]@5N#
MDP"+I)=,@W2#2(.+@U^"S2!)34%0((-4@5N#;X*^@J^"JH-4@WR!6X-G@L6"
MJX+<@K>!0@"39(YQ@X&!6X.+@T&#:(.,@UB"S3&"PH*^@J^.=Y+H@L6"JX+<
M@K>!0@"/BI=,CM*"J8-6@UB#98.`BL>7G8[2@KZ"KX*JBZ273(+,CXJ73(R@
M@L:#08-.@UJ#6(R@@O"5SXU8@L6"JX+<@K<`D%:+2X-%@T.#DX-H@5N"R95<
MCJ8`3W!E;E-33""#1X.)@5N!1E,O34E-12"/D):\@K."ZH*]@W"!6X-G@JF"
MYX-F@5N#7H+PCN:"Z(]O@KF"W(*Y@O&"Q8*U@KV!0@"#28-V@U:#AX.3`"5S
M((-)@W:#5H.'@Y,`E-2-AI5TB=./\(^1@JL`D6>01`"5E(^0`)"NEYT`C+."
MS(-!@W:#BH-0@5N#5H.'@Y.#98.3@W:#C(%;@V<`D;R"S(-#@Y.#=(-(@X&!
M6X-6@X>#DP"/BI=,CM*"S(-!@TZ#6H-8C*``4$%-()1&C]B"S8YGEW""Q8*K
M@MR"N8+Q@4(`4$=0()-DCG&/D):\`%!'4""(PXV&E;8`4$=0((SVBDJ,K@!0
M1U`@CY"6O(W/+XC#C8:)NX-F@5N#7@!02%"#4H%;@V@`4$A0@U:#1H.+`%!/
M4TE8((IGDJ."JHRIDY:"O8+H@MR"N8+Q`):$D9``@W"#3(-8@UZ#DX%%@T.#
M6(.)@X"+I)AAC9$`@W"#B8-)BZ2888V1`(-P@XR#6(-@@VF.J8ZAB^8`@W"#
M:8-]BZ2888V1`(-P@W:#08-J@X6!6X--@VJ#09/&EZ>-D0"#<(.)@T^#08-#
MBZ2888V1`(-P@UB#CX%;@V@`@W"#6(./@5N#:(+-D+./[8+)E<^-6(*S@NJ"
MW(*U@KV!0@"#<(-8@X^!6X-H@JJ0LX*U@JV"H(+H@MR"N8+Q`%)!1$E54R"4
M1H_8@LR#<(-8@X^!6X-H@JJ52Y=V@L6"MX%"`(-P@UB#CX%;@VB"S(IME$8`
M@W"#6(./@5N#:#H`@W"#6(./@5N#:#H@`(-P@UB#CX%;@VB"JHCJDG:"M8+<
M@KF"\8%"`)-<@NB5=(*O`(-.@XJ#8H-V@WN!6X-H@JF"YY-<@NB5=(*O`(-P
M@U@`E=N7KY*&@LR#5(-#@Y.#08-B@W:!1@"#<(%;@UJ#DX-G`)7;CN>1@(WL
M@O".P(US@K>"Z0"#C8-/@T.#DXZ>@LF5VX[GD8"-[(+PCL"-<X*U@MR"MX*I
M@4@`@T&#3H-:@UB,H`"#08-.@UJ#6(R@("(E<R(@@LV-[8^<@K."ZH+<@KF"
M\8+%@K6"O8%"`(-!@TZ#6H-8@LV+D93;@K."ZH+<@K6"O0"#08-.@UJ#6(R@
M`(-!@TZ#6H-8C*""S(K'EYT`C,*0;(_NE?$`@WF#BX%;BZ2888V1`(-T@T*#
MBH-S@Y.+I)AAC9$`DV288@"#<X-G@U"#08.3DX<`@W.#3H-:@XL`C(Z"QI1.
M@O"3_)?-@K6"Q(*M@KZ"LX*B@4(`D%:"M8*BE:J7WH+,EKR13X+PD_R7S8*U
M@L2)NH*S@J(Z`)"S@K6"HI/ZE72"\)/\E\V"M8+$@JV"OH*S@J(N((R.@LR3
M^I"4@O"#8(-&@V*#3H*U@L2"K8*^@K."HH%"`(_ABE&3X)=E@O"7=I;Q@K6"
MQ(*RBTR3_(*M@KZ"LX*B@4(`@X:!6X-5EKR"QH-P@UB#CX%;@VB"\)/\E\V"
MM8+$@JV"OH*S@J*!0@".GX+,E;:/D8+PD\>"\8+%@JV"OH*S@J(N((*Q@LR#
M5H-8@V6#@(+PCF>7<(*W@NF"O8+?@LR+2Y+HCI:-@(+)DZ^(TX*W@NF52Y=V
M@JJ"H(+H@MR"MX%"`(-\@5N#B8.3@VB+I)AAC9$`DXJ56Y"4`(-\@XN#9X-+
M@XN+I)AAC9$`4')E9G-?;&1A<#H@E4N7=H+(3$1!4(IGDJ.+0)1<@JJ,J8+"
M@JF"Z(+<@KF"\8%"`%!R969S7VQD87`Z()5+EW:"R'-E<W-I;VZ*9Y*CBT"4
M7(*JC*F"PH*I@NB"W(*Y@O&!0@"#=H.,@W*#A8%;`)!6@K6"HH-%@T.#DX-H
M@5N"R8GFD9R"\)5<CJ8`D4^"S(-)@W:#5H.'@Y,`B/.-_`"4Z9:GC*X`C^&*
M40"/X8I1D^"798+,D."6O@",]HI*C*X`C/:/3XRN@T&#BX-3@XJ#68.``(SV
MBDJ,KH_NE?$`C/:/3XRN+Y3IEJ>,KH*JD+:0K(+%@JN"W(*Y@O&"Q8*U@KV!
M0@"#=H-'@XN#9X.*@U(`@X&#8H-:@5N#5X+P@W"!6X-7`(-*@UZ!6X.+`(-.
M@T>#BH%;`(-*@UZ!6X.+`%)308SVCT^,KB@E9(-R@V*#9RD`E.0`D\>"W@"6
M>Y.6@LD@)7,@@O"-[8^<@K6"W(*W@JD_((*Q@LR1@(WL@LV,LX+)EM^"N8+<
M@KF"\8%"`)9[DY:"R8.&@5N#52`E<R""S(-F@5N#7H+PC>V/G(*U@MR"MX*I
M@4@@@K&"S)&`C>R"S8[F@NB/P8*Y@MR"N8+Q@4(`C<6,XX+,D8"-[(+P@N*"
MZ)*\@K<`DZZ328.!@VJ#A8%;@LR-Q)5<CJ:*U(IU.@"#?(%;@UZ#BX+,C<25
M7(ZF`(.*@XV!6X-H`(.*@X*!6X-G@U2!6X-R@U@`@XJ#@H%;@V=54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B``C>V/G`"#=8.-@V*#3H+P
MC>V/G`"/D8ZN@O"-[8^<`(-Y@T&"\(WMCYP`E=N1MH*U@KV#6(-.@XJ#=H-G
M@O"-[(O&@V:#0H.,@TZ#9X.*@JF"YXWMCYR"MX+I@4(`C>V/G(%&`(*Q@LR#
M;8%;@VB"\(-H@TR#A8.!@Y.#9X*I@N>-[8^<`(.&@5N#58+PC>V/G`"#AH%;
M@U6"\(WMCYPZ("5S`)=VBX&"R974DYJ"Q8*K@MR"N8+Q.B``EW:+@8*S@NJ"
MO2`B)7,B((+-("5S((+,D-V2Z(+)CG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`EW:+
M@8*S@NJ"O2`B)7,B((+-(%9&4R"0W9+H@LF.=Y+H@K."ZH+$@J*"W(*Y@O&!
M0@"7=HN!@K."ZH*]("(E<R(@@LV0W9+H@LF.=Y+H@K."ZH+$@J*"W(*Y@O&!
M0@"#BH-:@V*#9P"#<(-8@X^!6X-H@O"#BH-:@V*#9P""H(+(@KV"S(-P@UB#
MCX%;@VB"\(.*@UJ#8H-G`(R+B<H`@TF#=H-6@X>#DX+)EM^"Z0"#<(-8@X^!
M6X-H@O"-Q)/\E\T`C+."S(U<D*R"R9;?@K<`@V6#3(-8@V>#1X-F@T*#7H%;
M@LR#28-V@U:#AX.3`(E%`);PBH0`@XN!6X-]@VJ#00`Q.#"3>(GQDUT`C;:"
MR8GQDUT`B46"R8GQDUT`C7.1KI"K`(USD:Z0JP"-<X%&`(QRD/P`D5."Q(+,
MC7."QI?Q@LR*U(+)C'*0_(+PB/B"K0"-<X+,BM2"R8QRD/R"\(CX@JT`E_&"
MS(K4@LF,<I#\@O"(^(*M`([`C7,`@XV#5H-!F$&630"#BX./@Y.#7P!3+TU)
M344@B,.-AH^0EKP`4R]-24U%((C#C8:5M@!305-,()1&C]B"S8YGEW""Q8*K
M@MR"N8+Q@4(`4U%,((-6@T:#BP!34T@`D*R,]P"3>0"#6H.3@V>#=X.,@VF3
MAP"#6H.3@V>#3(-B@V.!E8-L@5N#E(-"@U@`@UJ#DX-G@XN#5H-!`(-4@Y.#
M<X-'@5N#BX%%@WZ#3H.-@Y.3AP"#6H.3@V>#<X.3@UJ#DX-G@JB"YH+1@T^#
MC(-I@V:#0H%;@Y./E).'`(-4@X*#09/&EZ>-D0"#5(.3@WV#BH-MBZ2888V1
M`(-4@Y.#9X.!@46#=H.*@Y.#5H-YEJ^.Y8NDF&&-D0"#5(-%@U>#08.)@W*#
M08FDC9$`E=N1M@`B)7,B((+PE=N1M@`E<R""\)7;D;8`@TF#=H-6@X>#DX+P
ME=N1M@"0MI"L@K."ZH*]D-V2Z(+P(%!(4""#6(-.@XJ#=H-G@L:"M8+$@U2!
M6X-O@LR-[(O&@V:#0H.,@TZ#9X.*@LF5VY&V@K>"Z8%"`"5S()#=DNB"\)7;
MD;:"M8+<@K6"O8%"`)#=DNB-6)!6EW"#6(-.@XJ#=H-G("(E<R(@@O"5VY&V
M@K6"W(*U@KV!0@",GXWU`(R?C?6#1X.3@U>#DP"#=(-`@T.#BX+PD4F1\`"3
M^I5T@O".=Y+H@K6"Q(*M@KZ"LX*B@48`DL>)P8*W@NF#3X.+@5N#=H+PD4F1
M\(*U@L2"K8*^@K."H@"05H*U@J*/BHZ=CM*"\)%)D?""M8+$@JV"OH*S@J(`
M@U2!6X-O@O"129'P@K6"Q(*M@KZ"LX*B`)+'B<&"MX+I@X:!6X-5@O"129'P
M@K6"Q(*M@KZ"LX*B`)%3@L2129'P`)5+EW:"R)6VCIJ"\(FZ@LR#>X-B@TZ#
M6(*I@N>128+Q@L6#4H-S@5N"MX+I@L:!08-E@TR#6(-G@T>#BH-!@M:#>8%;
M@UB#9X+%@JN"W(*W@4(`D_J5=(+,B^:0V(+HE;:.FH+PCG>2Z(*U@L2"K8*^
M@K."HH%&`)/ZE72"S(Q@CJZ"\(YWDNB"M8+$@JV"OH*S@J*!1@"5SXU8@K6"
MO8*B242"\)%)D?`Z`(Z>C8^"S(OFD-B"Z)6VCIJ"\(YWDNB"M8+$@JV"OH*S
M@J*!1@".GHV/@LR,8(ZN@O".=Y+H@K6"Q(*M@KZ"LX*B@48`B.J2=H*W@NF"
M48+"@LR#=(-"@5N#BX-H@O"128+Q@L6"K8*^@K."HH%"`)!&DK*"\)%)D?""
MM8+$@JV"OH*S@J(N`(R^C.J"\)%)D?""M8+$@JV"OH*S@J(Z`(_ABE&#C(-\
M@5N#9X+PD9>038*W@ND`4TU3()&7D$T`@UJ#;(-+@XN+I)AAC9$`@EB,C@"#
M6H.+@W*#08%%@X*#DX-E@VR#3X.-`)+*E-0`@UJ#8H-6@X>#DXK'EYT`@UJ#
M8H-6@X>#DP"668+J@L2"M8+<@L&"O8-P@UB#CX%;@VB"\(.*@UJ#8H-G@L6"
MJX+I@N:"I(+)@K6"W(*W@4(`@WR!6X->@XN"Q8-!@TZ#6H-8@K>"Z8.*@X*!
M6X-G@U2!6X-O@O"0W9+H@K6"W(*W@4(`C+Z,ZH%!CIZ*U)'1@4&3^I5T@O"0
MW9+H@K6"W(*W@4(`BDJ.;HZ>@LR#08-V@XJ#4(%;@U:#AX.3@4&01I*R@4&#
M>8%;@U>-Q)5<CJ:!08*[@LR1O(+,E5R.IH-)@W:#5H.'@Y."\)%)D?""M8+$
M@JV"OH*S@J(N`)#=DN@`D-V2Z(U8D%:#6(-.@XJ#=H-G`(-:@5N#5H-&@XN+
MI)AAC9$`BLB24(+(EW:6\8%&`(%I@X&#:H.%@5N"R(+'@L6!:H-6@X>!6X-G
M@TJ#8H-G@TR!6X*JCF>"IH+I@N:"I(+)@K6"W(*W@JF!2`"57(ZF`(R[C=V"
MS)#=DNB"QI!6@K6"K9"VD*R"LX+J@KV0W9+H@L:"S(VWE:J"\)5<CJ:"MX+I
M@4(`@XV#3X-#@Y..GH+)D4^)\8+,@XV#3X-#@Y..GHK4@O"57(ZF@K6"W(*W
M@JF!2`"57)&`C>R#@8-J@X6!6X+PE5R.IH*U@MR"MX*I@4@`B>:6RHVV@LD@
M)7,@@X&#:H.%@5N"\)5<CJ:"M8+<@K>"J8%(`)5<@LR#6H.+D:Z0JX-?@T.#
M08.-@T^"\)5<CJ8`E5R1KI"K@U^#0X-!@XV#3X+PE5R.I@"57(+,E_&1KI"K
M@U^#0X-!@XV#3X+PE5R.I@"57(+,C7.1KI"K@U^#0X-!@XV#3X+PE5R.I@"/
M:X^L`(+<@KB7UX+H@LR#=8.-@V*#3H+PCVN/K(+<@KV"S8C:DZZ"LX*Y@L2"
MK8*^@K."HH%"`(-6@T>#B8.,@TF#;(NDF&&-D0"#5(-#@Y.#08-B@W8`DV2.
M<8^0EKP`DV2.<8^0EKR#08.+@U.#BH-9@X``@U:#DX-+@WR!6X.+BZ2888V1
M`(-4@T.#60"5VX[G@O"#6(-,@V*#=H*W@ND`@UB#C8-O@TR#08NDF&&-D0"#
M6(.-@WB#:H-!BZ2888V1`(-<@XV#@H.3CY23AP"#7(-]@XJ#09:OCN6+I)AA
MC9$`E<""T8^'@LR129'P`)&7D$V,LX-!@VB#C(-8`)/L@T&#=(.*@TJ+I)AA
MC9$`D^R#5X.'@5N#5X-!DX>!19/L@U2#DX-H@T.#8H-@CY23AP"3[)2\BX4`
ME]>"S(-:@XN"QH+,EUV4D@"#6H.+@L:+JXI%@L:"S)==E)(`EUV4D@"77922
M@L:6A)&0`(-8@WF#0X.3`)/!CNJ5MHZ:@LR3_)?-`(-:@XN5JHJ$`)?QE:J*
MA`"-<Y6JBH0`@UB#BH.)@Y.#2I:OCN6.T(GOCN6+8(NDF&&-D0"/0H+<@KV"
MS8RG`(_SD=0`CUJ/BI34DFX`CN:/P8*UD/P`@UB#7H-#@XL@6T-34UT`D_H`
M@U2#=8-F@T*#C(-.@V>#BB`B)7,B((*J@J""Z(+<@KF"\8%"`([`C7,`B;J5
M=(*K`)"LC/<`(B5S(B""S8-6@UB#98.`@LF2QXG!@K."ZH+<@K6"O8%"`"(E
M<R(@@JJ#5H-8@V6#@(*I@N>-[8^<@K."ZH+<@K6"O8%"`"(E<R(@@JJ-[8^<
M@K."ZH+<@K6"O8%"`"(E<R(@@JJ#5H-8@V6#@(*I@N>-[8^<@K."ZH+<@K6"
MO8%"`)#=DNB"S9"SC^V"R9;?@K."ZH+<@K6"O8%"@XJ#C8%;@VB"M8+$BFV4
M1H+%@JN"W(*W@4(`D-V2Z(+,@V^#8H-.@T&#8H-V@LV0LX_M@LF5VY&V@K."
MZH+<@K6"O8%"`)#=DNB#=(-`@T.#BX+,@V^#8H-.@T&#8H-V("5S((+-D+./
M[8+)E=N1MH*S@NJ"W(*U@KV!0@`B)7,B((+-D+./[8+)C5B05H*S@NJ"W(*U
M@KT`)7,@@LV0LX_M@LF/D8*KC9Z"W(+J@MR"M8*]`(-8@5N#7X.3BZ2888V1
M`(I4EW8`D_J"S(]O`)/Z@LR3_(+H`)/Z@LR/;R^3^H+,D_R"Z`"3^H+,CV^!
M1@"3^I9V`)/ZEG:!1@"/XY5T@JL`@U2#?(%;@V<`@UB#BH-I@X"+I)AAC9$`
MD*D`@UB#E(-`@5N#BX-O@XN!08.$@Y.#?8-#@T>#DX^4DX<`@UB#CX-7@XF#
MDX-HB:2-D0"#6(-%@T:!6X-F@Y.)I(V1`(-8@T.#6)A!EDT`@U:#BH-!@46#
M08.)@W6+I)AAC9$`5%-6@W2#0(-#@XL`E5R1KI"K`)5<D:Z0JP"1Y)AP`)'D
MF'"!:9*&C9&"S(CJE92!:@"#7H-7@TR#6(->@Y.+I)AAC9$`@UZ#DX-5@VJ#
M09A!EDV+I)AAC9$`@UZ#6(-.`)-DF&*4U(V&`(-E@Y.#=H.,@5N#9R`B)7,B
M((*J@J""Z(+<@KF"\8%"`(-E@Y.#=H.,@5N#9X+,BL>7G0"#98-,@UB#9X+,
M@MT`E;:.FI1ZDG4`E;:.FH+,C^,`EM@`@UZ#0XFDC9$`1E10((IGDJ."JH*@
M@NB"W(*Y@O&!0@"7FI?P@U:#6(-E@X""S9:SC/B"R8+(@L&"Q(*B@MR"MX%"
M`$UA:6YT96YA;F-E((-.@XF#6(+,D\>-GH+=@JJ0LX_M@LF-<X*F@MR"N8+Q
M@L6"M8*]`(-)@W:#5H.'@Y.#18-"@Y.#:(-%@O"5PH*V@MR"M8*]@4*/29>Y
M@K6"W(*W@4(`@T&#3H-:@UB,H(+PETR,^(+)@K>"Z8+)@LV*QY>=CM*"JH*[
M@LR#;X-B@TZ#1X.3@VB"\)#=DNB"MX+I@K&"QH*JE4N7=H+%@K>!0@"809>-
MD.9)1)34C8:"JHYWDNB"LX+J@LB"J8+!@KV"J8%!B_."OH+!@KV"J8%!@J""
MZ8*B@LV#9H%;@UZ#>(%;@UB2AH+)C*F5=(*I@NB"W(*Y@O&"Q8*U@KV!0@"8
M09>-D.:"S8*@@LB"O8+,@T&#:(.,@UB2H(+)DL>)P8*S@NJ"W(*U@KV!0@"3
M9(YQCY"6O(*S@NJ"O8.!@V*#6H%;@U>"\(R?C]B"MX+I@LF"S8%!4$=0((^0
MEKR"JI5+EW:"Q8*W@4(`D9>039#F2424U(V&@JJ.=Y+H@K."ZH+(@JF"P8*]
M@JF!08OS@KZ"P8*]@JF!08*@@NF"HH+-@V:!6X->@WB!6X-8DH:"R8RIE72"
MJ8+H@MR"N8+Q@L6"M8*]@4(`D9>039#F2424U(V&@JJ.=Y+H@K."ZH+<@KF"
M\8+%@K6"O8%"`(C#C8:)NX+)@LV(P)%3@LB#18-&@W60VI&Q@JJ52Y=V@L6"
MMX%"`(-T@T"#0X.+("5S((+)@LT@)7,@@LR0W9+H@JJ52Y![@L6"MX%"`(-T
M@T"#0X.+("5S((+)@LT@)7,@@LR0W9+H@JJ52Y![@L6"MX%"`(-T@T"#0X.+
M@LV.J96JCJF09X+)@U*#<X%;@L6"JX+<@KF"\8%"`(-T@T"#0X.+@JJ#9H%;
M@UZ"\(K<@O&"Q8*B@MR"N8+Q@4(`B,B)NH+-@K&"S(.!@V*#6H%;@U>!:5)&
M0S@R,H%J@LR#=X-B@U^"Q8*W@4(`DHV(TX%)((-T@XN#6(-.@XJ!6X.3@X*!
M6X-H@LT@26YT97)N970@17AP;&]R97(@@L6"S9;BD>B"JI2MD+:"MX+I@K&"
MQH*J@J""Z(+<@K>!:8-U@XF#18-5@LR#;X-/@L6"MX%J@4*)YI;*@LF#4X-^
M@JJ57(ZF@K."ZH*]@NB!05=I;F1O=W,@@JJ#3H.)@V*#5H.%@K6"O8+H@K>"
MZ8*I@N""M8+J@MR"N8+Q@4(*@W2#BX-8@TZ#BH%;@Y.#@H%;@VB"R8*W@NF"
MR(+G($]+((+PB9^"M8+$B;J"LX*B@4(`240@(B5S(B""S8WMCYR"LX+J@MR"
MM8*]@4(`1VYU4$<@@V^#0X-I@XJ"S(-P@UB"JB!#<GEP=%]P9W`@@TZ#B8-8
M@LF0W9+H@K."ZH+$@J*"Z95+EW:"JH*@@NB"W(*W@4(`@K&"S(-T@T*!6X.+
M@VB"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"`$AO<F1E7T-R>7!T7W-M
M:6UE@TZ#B8-8@LF"S6]P96YS<VR#@H-7@X6!6X.+@JJ52Y=V@L6"MX%"`(-V
M@XR#=(-`@XR#DX-8(B5S(H+-@V:!6X->@JJ#5(-#@UF0IXS`@O")>H*F@KV"
MO8+?E=N1MH+%@JN"W(*Y@O&"Q8*U@KTN`(*Q@LR#9H%;@UZ,7B@E<RF"\)5<
MCJ:"MX+I@KV"WX+,@W:#C8-/@XF#@(*J@K&"S(-6@UB#98.`@LF"W8+"@JF"
MZ(+<@KF"\8%"`(CXEW"5A(+-@E"5MHZ:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!
M0@"+YI#8@NB5A(+-@E"5MHZ:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0@"#5(%;
M@V\@(B5S(B""S8WMCYR"LX+J@MR"M8*]@4(`@U2!6X-O("(E<R(@@LV5VY&V
M@K."ZH+<@K6"O8%"`(YWDNB"M8*]E_&!:25D@6J"JH*@@NB"W(*Y@O&!0@"(
MZHZ>@W2#0(-#@XL@(B5S(B""JH*@@NB"W(*Y@O&!0@"#08-B@W:#C8%;@VB#
M9H%;@UZ"JI*\D4^"S(-8@V6#8H-V@L6/P8ZX@K6"W(*U@KV!0@"#08-B@W:#
MC8%;@VB#9H%;@UZ"\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(`@V6!6X-]@V:#
M0H.,@TZ#9X.*@5L@(B5S(B""JH*@@NB"W(*Y@O&!0@".=Y+H@L6"JX+I@TF#
M=H-6@X>#DX+-@J""Z(+<@KF"\8%"`(-#@Y.#B8-#@Y.57(ZF@L6"JX+IE925
MJH+-@J""Z(+<@KF"\8%"`)6VCIJ0E(*J@K&"S(-T@T*!6X.+@VB"R9&]B=^"
MK(+<@K<N("5S((+,E;:.FH*JD_R7S8*S@NJ"Q(*B@MR"MRX@)7,@B,B)NH+%
M@LB"K8+$@LV"HH*O@MR"N8+Q@4(`(B5S(B""\(-6@UB#98.`@M:2QXG!DH:"
MR9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,`@X:!6X-5("(E<R(@@LR#9H%;@UZ"
M\(-6@UB#98.`@JF"YX_!BXZ2AH+)EN*1Z(*JE*V0MH*U@MR"M8*].@`B)7,B
M((+P@U:#6(-E@X""J8+GC>V/G)*&@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ`"(E
M<R(@@O"-6)!6DH:"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,`@W2#0(-#@XN#
M08-B@W:#C8%;@VB"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,@@LV#08-B@W:#
MC8%;@VB"LX+J@L2"HH+<@KF"\8%"`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6
MXI'H@JJ4K9"V@K6"W(*U@KTZ("5S((+-@W2#0(-#@XN"S(-4@T.#69"GC,"2
M;"@E9(-O@T.#9RF"\(EZ@J:"Q(*B@MR"MX%"`(-T@T"#0X.+@T&#8H-V@XV!
M6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S((+-B.J5E(+,@MV#08-B@W:#
MC8%;@VB"LX+J@MR"M8*]@4(`@K&"S(-P@5N#9X+PE5R.II*&@LF#1X.)@5N"
MJI2MD+:"M8+<@K6"O0"809>-D.:#9H%;@UZ"S(-#@Y.#?(%;@V>2AH+)@T>#
MB8%;@JJ4K9"V@K6"W(*U@KV!0@!I0V%L96YD87(@@LR#0X.3@WR!6X-GDH:"
MR8-'@XF!6X*JE*V0MH*U@MR"M8*]+@"0W9+H@W2#2(%;@X"2AH+)@T>#B8%;
M@JJ"H(+H@MR"M8*]@4*"O8+4@O&!095+D'N-@);:@JJ+\Y22@KZ"P8*]@LR"
MQ8*U@N6"I(%"`(YWDNB"LX+J@KV#08-H@XR#6)*@@LR1@(WLDH:"R8-'@XF!
M6X*JE*V0MH*U@MR"M8*]@4*,XX+%C<23>([`C7."M8+$@JV"OH*S@J*!0@"8
M09>-D.:"S(_:C=>"\(U8D%:2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0HSC
M@L6-Q)-XCL"-<X*U@L2"K8*^@K."HH%"`)&7D$V0YH.*@UB#9X+,C5B05I*&
M@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"C.."Q8W$DWB.P(US@K6"Q(*M@KZ"
MLX*B@4(`@K&"S"!)34%0((-4@5N#;X+-BZ273(-T@TB#BX-?@O"#5(-\@5N#
M9X*U@L2"HH+<@KF"\8%"`(*Q@NJ"S9=,C/B"R"!R87(@@T&!6X-*@T.#=8+%
M@LV"R(*B@N:"I(+%@K>!0@""L8+J@LV73(SX@L@@>FEP((-T@T"#0X.+@L6"
MS8+(@J*"YH*D@L6"MX%"`(*Q@NJ"S9=,C/B"R(-*@5N#:)34C8:"Q8+-@LB"
MHH+F@J2"Q8*W@4(`@K&"S(-T@T*!6X.+@VB"S95+D'N"Q8*W@4(`@K&"S(-T
M@T*!6X.+@VB"S9"ND)2"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"
M@5N#BX-H@LV0E(Z:@L:#4H.-@Y."Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q
M@LR#=(-"@5N#BX-H@LTXD&F0E(+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(`@K&"
MS(-T@T*!6X.+@VB"S8-2@Y.#?8+<@KV"S8OSE)*"Q8OFD-B"YX+J@KV0KI"4
M@LR#BH-8@V>"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H
M@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0@""L8+,@W2#0H%;@XN#:(+-
M,3:0:5)'0I5<BTR"S)!&@U*!6X-H@LB"K8+$@LV"HH*O@MR"N8+Q@4*7X3HG
M(S$R,S1A9B<N`(*Q@LR#=(-(@5N#@(+-BOF"R8^(EYV"LX+J@L2"HH+<@K>!
M0@""L8+,@X&#8H-:@5N#5X+-@J""R(*]@JJ.9Y=P@K>"Z8+,@L:(V8+(@NF5
MMHZ:@UJ#8H-G@6DE<X%J@L6/D8*I@NJ"Q(*B@MR"MX%"`(*Q@LR4U(V&@LV-
MQ8^L@L6"X#&"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q@LR#5(%;@V^"Q8+-
M>FEP@L9G>FEP@W2#0(-#@XN"\)-7BDJ"Q8*K@MR"N8+Q@4(`@K&"S(-6@UB#
M98.`@LV(ZHZ>DTF"R9:SC/B"R8+(@L&"Q(*B@MR"MX%"`(*Q@LR2;(+-D)2.
MFH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(`@K&"S(-%@T*#DX-H@T6"S8-)@W:#
M5H.'@Y.#18-"@Y.#:(-%@JF"YXS$CV^"LX+J@NF52Y=V@JJ"H(+H@MR"MX%"
M`(Z>BM0`@UZ#0X.`@U:!6X-G`(Z>BM2/D8ZN`).,@V6#0H."@5N#BY:OCN6+
MI)AAC9$`@UZ#0X-G@XL`E:&0E(+,C8"6VH+PD4F1\(*W@NF"R8+-@4%00X+%
M@LU#;VYT<F]L@TR#0X%!36%C@LB"YT-O;6UA;F2#3(-#@O")GX*U@LB"JH+G
M@TZ#BH-B@TZ"M8+<@K>!0@!(5$U,@UR!6X-8E5R.II#8D=8`@V>!6X-3BZ28
M88V1`(-G@U"#B8-%CY23AP"#9X.3@TN)I(V1`(*Q@LR0E)6JBM2"R8F]DWB"
MX(.-@T^#0X.3@JJ.CHUS@K."ZH+<@K6"O8%"`(-G@XJ#:H-?@5N#:(%%@V>#
M;X-3BZ2888V1`(G.`(-@@X6#:H-7@T&+I)AAC9$`@V>#BX-2BZ2888V1`(-G
M@XN#3H.!@VJ#6(->@Y,`@UZ!6X-.@UB!18-*@T.#4H-8CY23AP"#8X-O@XL`
MD4F1\(%&`%523`"#18-+@Y.#7XNDF&&-D0"#18-.@XF#0X-I`%9&4R"#9H-"
M@XR#3H-G@XJ"R8-!@TZ#6H-8@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BR`B
M)7,B((+,@T&#3H-:@UB,H(+-E<^-6(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#
M@XL@)7,O)7,@@LR#08-.@UJ#6(R@@LV5SXU8@L6"JX+<@KF"\8%"`"5S((+)
ME<^-6(+%@JN"W(*Y@O&!0@"#=(-`@T.#BR`B)7,B((+,@U2#0X-9@JJ#8(-&
M@V*#3H*K@MR"N8+Q@4(`@W2#0(-#@XL@(B5S+R5S(B""S(-4@T.#68*J@V"#
M1H-B@TZ"Q8*K@MR"N8+Q@4(`4U%,((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!
M0@!34TP@@L60VI&Q@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+P@U*#<X%;
M@L6"JX+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XH@(B5S(B""\(WLD*R"Q8*K
M@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#BH+PC>R0K(+%@JN"W(*Y@O&!0@!6
M1E,@@W2#0(-#@XN"\(WLD*R"Q8*K@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#
MBB`B)7,B((+PC>R0K(+%@JN"W(*Y@O&!0@"+\X+,(%9&4R"#=(-`@T.#BX+P
MC>R0K(+%@JN"W(*Y@O&!0@"#9H%;@UZ"\(BSCVN"Q8*K@MR"N8+Q@4(`(B5S
M(H+PC>V/G(+%@JN"W(*Y@O$N((-F@T*#C(-.@V>#BH*JB_."Q8+-@J""Z(+<
M@KF"\8%"`"(E<R*"\(WMCYR"Q8*K@MR"N8+Q.B`E<RX`)7."\(WMCYR"Q8*K
M@MR"N8+Q+B"#9H-"@XR#3H-G@XJ"JHOS@L6"S8*@@NB"W(*Y@O&!0@!61E,@
M@V:#0H.,@TZ#9X.*@O"-Q(M!DTF"R8WMCYR"Q8*K@MR"N8+Q@4(`5D93((-F
M@T*#C(-.@V>#BH+PC>V/G(+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*
M@O"-[8^<@L6"JX+<@KF"\8%&)7,`5D93((-T@T"#0X.+("(E<R(@@O"-[8^<
M@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+PC>V/G(+%@JN"W(*Y@O&!0@!6
M1E,@@V:#0H.,@TZ#9X.*("(E<R(@@O"-[8^<@L6"JX+<@KF"\8%"`%9&4R""
M\(W$BT&328+)C>V/G(+%@JN"W(*Y@O&!1B5S`(R[C=V"S(-F@T*#C(-.@V>#
MBH%;@JJ3P9+H@L6"JX+<@KF"\8%"`(_8EKZ/D8+,C]J-UX*JCN:"Z(]O@KF"
MW(*Y@O$`)7,@@LR2Z(M@@JJ#C8%;@VB"Q8*K@MR"N8+Q@4(`5D93((-T@T"#
M0X.+@JJ(VI.N@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BR`B)7,B((*JBDJ"
MKX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+PCY&"JXV>@MV7<(+)BDJ"KX+<@KF"
M\8%"`%9&4R"#=(-`@T.#BX*JBDJ"KX+<@KF"\8%"`(BSCVN/D8S)@W2#0(-#
M@XN"\(I*@J^"W(*Y@O&!0@!61E,@@W2#0(-#@XN"JI/'@M^"W(*Y@O&!:69I
M;&5S:7IE*"D@@T>#B8%;@6J!0@!61E,@@W2#0(-#@XN"JI/'@M^"W(*Y@O&!
M:6=E=$9I;&53:7IE*"D@@T>#B8%;@6J!0@!61E,@@W2#0(-#@XN"JI/'@M^"
MW(*Y@O&!0@!V9G-R;V]T((-F@T*#C(-.@V>#BH+PD\>"WX+<@KF"\8%"`):\
MD4\@)7,@@O`@)7,@@LF5SXU8@L6"JX+<@KF"\8%&@W2#2(.+@U^!6X+-BOF"
MR9&VC=V"M8+<@K<`5D93((-F@T*#C(-.@V>#BH%;@LR6O)%/@O"5SXU8@L6"
MJX+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XJ!6X+,EKR13X+PE<^-6(+%@JN"
MW(*Y@O&!1B5S`%9&4R"#=(-`@T.#BR`B)7,B((+,EKR13X+PE<^-6(+%@JN"
MW(*Y@O&!0@!61E,@@W2#0(-#@XL@)7,O)7,@@LR6O)%/@O"5SXU8@L6"JX+<
M@KF"\8%"`%9&4R"#=(-`@T.#BX+,EKR13X+PE<^-6(+%@JN"W(*Y@O&!0@""
ML8+,(%=O<F0@E;:/D8+PEGR6\X+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XL@
M(B5S(B""R8^1@J^"W(*Y@O&!0@!61E,@@W2#0(-#@XN"R8^1@J^"W(*Y@O&!
M:6-O<'DH*8ZXE'.!:H%"`%9&4R"#=(-`@T.#BX+)CY&"KX+<@KF"\8%"`%9&
M4R"#=(-`@T.#BX+)CY&"KX+<@KF"\8%"<75O=&$@@O"2M(G?@K6"O8+F@J2"
MQ8*W@4(`B;J0_`"5SXU8@O".YH+HC\&"MP"-Q8SC@LR1@(WL@O",LX+)EM^"
MMP"0VI&QCIZ"S(-4@5N#;X%;@JF"YX+,EUR*^H*U@LB"HHF>DYJ!1@"#5(%;
M@V^!6X*I@N>"S)=<BOJ"M8+(@J*)GI.:@48`EJ*0KI>=`(-!@XF#=8[QDK>-
MD9A!EDT`B7"-D0"5Q(V1`)7$E\R1OI6]EVV/E).'`)5SEKX`@X:!6X-5EKR"
MJ8-P@UB#CX%;@VB"JI5SEKZ"Q8*W@4(`EK.6O`"#6H-,@X6#BH-E@T*!6X_C
M@LR7G9=2@JF"YY/!C*""S):S@J*#6(-.@XJ#=H-G@LT@0W5T+T-O<'DO4&%S
M=&4@@L6"JX+<@KF"\8%"3TL@@O"#3H.*@V*#3H*W@NF"QH%!@L>"I(+B@L&"
MQ(-.@XJ#8H-V@WN!6X-H@LF#08-.@UJ#6(*W@NF"J8+&@J*"I"!M;WII;&QA
M+F]R9R""S(M:CW"5MH^1@O",J8+I@K&"QH*J@L6"JX+<@K>!0@"#5(-\@5N#
M9X*U@L2"HH+(@J**9Y*CCG&"Q8*W`(U8D%8`)7,@@O"-6)!6@K>"Z8%"`(.&
M@5N#58+PC5B05H*W@ND`(B5S(B""\(U8D%:"M8+<@K6"O8%"`(U8D%:#6(-.
M@XJ#=H-G@O"-[8^<@K6"W(*U@KV!0@"#08-B@W:#C8%;@V@`D5."Q(+,@T&#
M=H.*@U"!6X-6@X>#DX+,D-V2Z(-T@T"#0X.+@O"#5(%;@V^"R8-!@V*#=H.-
M@5N#:(*U@MR"M8*]@4(`@XF#98.3E;:.FH%ID>65MHZ:@6H`@XV!6X-]D)2.
MFH%ID>65MHZ:@6H`@T6#BX-/@T&#0Y.,E?N+I)AAC9$`C+N-W8+,DFR"\(YG
MEW"!1B5S`%-33"""\(YGEW``24U34""#5(%;@V^"S(.&@5N#59:\@5Z#<(-8
M@X^!6X-H@JJ(V8+(@NF/ZHV'@LF.9Y=P@K6"W(*W@4(`@X:!6X-5`(.&@5N#
M52`E<R""S2`E<R""Q91&C]B"LX+J@L2"HH+<@KF"\8%"`(.&@5N#58K'EYT`
M@X:!6X-5@TF#=H-6@X>#DP"#AH%;@U63;YA>`(.&@5N#58+,DV^87H+-@K&"
MS(-4@T.#9X+%@LV+UHY^@K."ZH+$@J*"W(*W@4(`@X:!6X-5@5N#08-*@T6#
MDX-G@JJ"H(+H@MR"N8+Q@4*!0@"#AH%;@U66O`"#AH%;@U66O"`B)7,B((+-
MBOF"R8*@@NB"W(*W@4(`@X:!6X-5EKPZ`(.&@5N#59:\.B``@U:#6(-E@X"2
MAH+,@X:!6X-5@48`@T6#68-X@TR#6(->@Y.+I)AAC9$`BWB)R0"73(SXD*L`
M@V^#:X-!@V.+I)AAC9$`@WB#;(-9@T>#B8%%@WN#BH-O@XN+I)AAC9$`C)^/
MV(ZXE',@+2""L8+,@X&#8H-:@5N#5X+-B?SB@H*S@NJ"Q(*B@NF"YH*D@L6"
MMX%"`)3%`(-O@5N#5X.'@Y.*QY>=`(]CB,J2=0"#>(-G@VF#@([0B>^.Y8M@
MBZ2888V1`"5S((+PC*F"Z0"*3Y64@LP@=V5B((-Y@5N#5X+PE5R.I@")<)?,
M@V^!6X-7@Y./E).'`)7$E\R#;X%;@U>#DX^4DX<`@T6#2(.*@UB!18-T@V>#
M1(%;@VF/E).'`(QXC9``D(4`EHB/5`""YH*D@K&"NP`E<R""R8+F@J2"L8*[
M`"5S((*S@O&!08+F@J2"L8*[`)"\@U2#;H.)`"5S@XV#3X-#@Y.,XX+'@LR#
M08-V@XJ#4(%;@U:#AX.3@O"57(ZF@K6"W(*W@JF!2`"+YI#8@NB5MHZ:@LV)
MO8+%@K>"J8%(`(CXEW"5MHZ:@LV)O8+%@K>"J8%(`(-E@TR#6(-G@T>#9H-"
M@UZ!6X+,@W:#B8-/@T.#DX+PD4F1\(*U@MR"MX%"`)6=`(VV@LF2=8*M)7.#
M@8-J@X6!6X+,E9V!:8Z?B?&"S(.-@T^#0X.3@JF"YY=,C/B!:CH`E5R"S)6=
M`)6=@LR24(C*`)6=@48`EWZ"M8*B@N""S(CJEY<`B\Z6L9#F@LR/6H^*`(O.
MEK&0YH+,DV288I34C88`)60@C7.6VH+%BM2(X8+!@KV-@);:D)2!0I"S@K6"
MK8+-("5D@4&.=Y+H@K."ZH*]@LR"S2`E9(%"`(K4B.&"P8*]C8"6VI"4@4*0
MLX*U@JV"S2`E9(%!CG>2Z(*S@NJ"O8+,@LT@)62!0@!61E.#=(-`@T.#BX+,
MD\>"W8]O@K62AH+)E7.0LX+(@TF#=(-:@V*#9R`E9"""JHYWDNB"LX+J@MR"
MM8*]@4(`6#4P.78S((KNEGN0IXS``%@U,#EV,R",KHYGEW"60`!8-3`Y=C,@
MCN61S([2@LR5RI:\`%@U,#EV,R".Y9',CM*"S(RNCJ^5RHYQ`%@U,#EV,R"*
M9Y*CBT"47`"43@"43@"6B)1.`(-#@T>#@8.3BZ2888V1`(+-@J(`DZ^(TX*U
M@MR"MP"-H8+-@V6#3(-8@V>#@H%;@VB"Q8*W@4);/#Y=@WN#7H.3@L5765-)
M5UE'@X*!6X-H@LF6WX+H@MR"MX%"`"5D((C(C^."S(-U@XV#8H-.@O"-[)"L
M@K>"Z8*Q@L:"S8N6B<*"LX+J@L2"HH+<@KF"\8%"`(*@@LB"O8+-E$:/V(*S
M@NJ"Q(*B@MR"N8+Q@4(`EKR13X+,DH:"R2`G7"<@@L:"HH*DE;:.FH+-CF>"
MIH+<@KF"\8%"`)=,C/B"R)-DCG&#@8%;@XN#08-H@XR#6(+%@LV"H(+H@MR"
MN8+Q@4(`@T.#DX-\@5N#9X*S@NJ"O8-T@T"#0X.+@LR#=(-"@5N#BX-H@O`E
M<Y/@@LR1SHF>@K>"Z8-T@T*!6X.+@VB"R8-]@V*#=H*U@L2"W(*Y@O$N`(.-
M@T^#08-%@V>"M8+<@K6"O2X`D+."M8*BDV288I34C8:"\)/\E\V"MX+I@N:"
MI(+)DHV(TX*U@L2)NH*S@J*!0I"4CIJ"OH*O@JJ.9Y=P@L6"JX+<@K>"JH%!
MC9&-VY-DF&*"R(+GD.:3JH+)@7N"\)5T@J^"W(*W@4(`D+."M8*BDFR"\)/\
ME\V"M8+$B;J"LX*B@4(`@U2#0X.3@T&#8H-V@O"7F)=P@K>"Z8*]@M^"R8+-
M($1A=&%4<F5E((-O@V*#3H-'@Y.#:(+PD-V2Z(*W@NF52Y=V@JJ"H(+H@MR"
MMX%"`%9&4R"#;X-B@TZ#1X.3@VB"\)#=DNB"MX+IE4N7=H*J@J""Z(+<@K>!
M0@"/X8I1@LR3X)=E@O"+3(]Q@K6"Q(*I@N>!08_ABE&#C(-\@5N#9X+PD9>0
M38*U@L2"K8*^@K."HH%"`(*Q@K&"R8.*@Y.#3H*W@NE54DR"\)/\E\V"M8+$
MB;J"LX*B`(WMCYR"MX+I@U2!6X-O@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`C\&+
MCH*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"`(WMCYR"MX+I@X:!
M6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0@"2QXG!@K>"Z8.&@5N#59:\@O".
M=Y+H@K6"Q(*M@KZ"LX*B@4(`C5B05H*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"
MK8*^@K."HH%"`([`C7."MX+I@T&#3H-6@X>#DX+PCG>2Z(*U@L2"K8*^@K."
MHH%"`)!6@K6"HI6JE]Z6O(+PD_R7S8*U@L2)NH*S@J*!0@`E<R"#6H-B@U:#
MAX.3@LR73(SXBOJ,P(*JD-B"ZH+$@J*"W(*W@4*#C8-/@T.#DX*UDKR"M8+$
M@JV"OH*S@J*!0@"39(YQ@X&!6X.+@T&#:(.,@U@`@J""R(*]@LP@1G)O;3H@
M@T&#:(.,@U@`@J""R(*]@LR#0X.3@W2#2(.!@5N#5H.'@Y,`@UJ#8H-6@X>#
MDR`E<R""S(K4@LF"H(+(@KV"S(-!@VB#C(-8@JJ5SXU8@K."ZH+<@K6"O8%"
M@UJ#3(.%@XJ#98-"@5N5VXSL@LR"O8+?@LF#C8-/@T.#DX*UDKR"MX+7@JN"
MQ8*W@4(`@J""R(*]@LR6O)%/`(*Q@LR41H_8@V^#8H-.@T>#DX-H@L6"S8%!
M@X:!6X-5@LR2QXG!@JJ#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q@4*"X(*U($AO
M<F1E((+%@X:!6X-5@T&#2H-%@Y.#9X+PBL>7G8*U@KV"HH+,@LB"YX%!D;R"
MS)1&C]B#;X-B@TZ#1X.3@VB"\(YG@J2"UX*K@L6"MX%"`(*Q@LR41H_8@V^#
M8H-.@T>#DX-H@L6"S8%!@X:!6X-5@LR#BH-8@V>"JH-4@WR!6X-G@K."ZH+$
M@J*"R(*B@JF!08*@@NF"HH+-B;V"YX*I@LR7G9=2@L6"L8+,BT"47(*JEK.,
M^(+)@LB"P8+$@J*"W(*W@4(`@UJ#8H-6@X>#DR`E<R""S(K4@LF"H(+(@KV"
MS(-U@XF#18-5@JJ5SXU8@K."ZH*]@N:"I(+(@LR"Q8%!@UJ#3(.%@XJ#98-"
M@5N5VXSL@LR"O8+?@LF#C8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(`@JB.9X*B
M@LR#=8.)@T6#58+-@K&"S(M`E%R"\(-4@WR!6X-G@K6"Q(*B@MR"N8+Q@4(`
M@JB.9X*B@LR#=8.)@T6#58+-@K&"S(CSC?R#28-V@U:#AX.3@O"#5(-\@5N#
M9X*U@L2"HH+<@KF"\8%"0V]N=')O;"]#;VUM86YD("L@4"""Q8CSC?R"M8+$
MB;J"LX*B@4(`@UZ#0X.`@UV!6X.3@48`@J""R(*]@LR#9H-T@TB#BX-G242"
MS97/C5B"LX+J@MR"M8*]@4(`@J""R(*]@LR#9H-T@TB#BX-G240Z`(*@@LB"
MO8+,CH&6O`"#C8-/@T.#DX+-BOJ,P)#8@NJ"Q8*W@4(`D%:"M8*B("5S()=P
M@LR#<(-8@X^!6X-H@48E<P""H(+(@KV"S(-)@W:#5H.'@Y."S8R[C=V"S(-:
M@V*#5H.'@Y.2AH+)E<^-6(*S@NJ"W(*U@KV!0@"#28-V@U:#AX.3@O"-6)!6
M@K6"W(*U@KT`@W"#6(./@5N#:(+-@XJ#6H-B@V>"LX+J@MR"M8*]@4(`@W"#
M6(./@5N#:(+-@XJ#6H-B@V>"LX+J@MR"M8*]@LR"Q8%!D%:"M8*B@W"#6(./
M@5N#:(+%@XV#3X-#@Y."M8+$@MV"Q(FZ@K."HH%"`(-P@UB#CX%;@VB"JHKZ
MC,"0V(+J@L6"MX%"`(.*@X*!6X-G@U2!6X-O.@"#AH%;@U.#6(.)@W*#00"#
M58-#@5N#BXNDF&&-D8%I@U*#DX-3EJ^.Y8NDF&&-D8%J`(-5@Y.#<H-!BZ28
M88V1`(-7@Y.#;X-U@T>+I)AAC9$`@6V/X8I1E?&-D(%N`%N-<SHE<R\E<UT`
M7T&*QY>=`%]$C7."\(WMCYP`7T>#3X.+@5N#=@!?2(-W@XN#=@!?28GFD9R#
M=H.-@W"#98-"+BXN`%],@XV#3X-#@Y,`7TR#C8-/@T&#18-G`%]-@XJ#DX-.
ME<^-6`!?3X-)@W:#5H.'@Y,`7U"#08-.@UJ#6(R@`%]2@XJ#DX-.C>V/G`!?
M4X-:@V*#9X-!@V*#=@!?5)5<D:Z0JP!?58.&@5N#50"#08-H@XR#6)*@`)5S
MEKZ"R(-!@VB#C(-8`)=<DNB57`"/;Y?-@W2#0(-#@XN"JHWLD*R"Q8*K@MR"
MN8+Q`)/\E\V#=(-`@T.#BX*JBDJ"KX+<@KF"\0""L8*Q@O"#3H.*@V*#3@"#
M4H-]@Y.#:(USCF>7<(+,@T>#B8%;`)#=DNB#1X.)@5L`CV27=H+(@U:#6(-E
M@X"#=(-`@T.#BX+,C(>7C@"#9H%;@UZ,8(ZN@T>#B8%;`)72CU<`C8"6VH*J
M@J""Z(+<@KF"\0"#=(-`@T.#BP"#>H-8@V>6O(*JE7.6O@"3_(]OE\V#1X.)
M@5L`@UR#=(-G@T6#1H-!D^"5E(+,@T>#B8%;`):\D4\`CL"1E8*S@NJ"Q(*B
M@MR"N8+Q`(+<@KZ.P)&5@K."ZH+$@J*"W(*Y@O$`@X&#@I*@`(-P@5N#6H.3
M@V<`@T&#3H-:@UB"S8N1E-N"LX+J@MR"M8*]`(-S@TZ#6H.+`(.*@X*!6X-G
M@L6"S(-V@XV#9X-2@XN#1X.)@5L`@U2!6X-R@UB5<Y1<`(VWE:J"\)5<CJ8`
M@U:#6(-E@X"#1X.)@5L`@UZ#6(-.@XJ#6(-G`(CJCIZ328+(@T>#B8%;`(IM
ME$:"S(*]@M^#<(-8@X^!6X-H,I-XD_R7S8*U@L2)NH*S@J(`EK.6O`!V0V%R
M9```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O:F%?2E`O:&5L<"YX;6P`````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-#$W,S8S,#`Q`#`R,#(W
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L
M92]J85]*4"]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$T(&IA
M;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T
M93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R
M83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R
M>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X
M86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S
M86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT
M<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES
M="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD
M('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A
M:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@
M87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A
M(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\
M<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@
M8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA
M;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O
M;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E
M<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I
M;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE
M9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I
M;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H
M:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C
M:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC
M92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA
M;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN
M=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES
M(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R
M871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@
M875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G
M:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+RYH=&%C8V5S<P``````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`Q-@`Q,#0Q-S,V,S`P,0`P,3<T,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1&5N>2!F
M<F]M(&%L;`H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+P``````
M````````````````````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C,P,#,`,#$U,#(W`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&\O+FAT86-C97-S````````````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`Q-@`Q,#0Q-S,V,S`P,0`P,38V
M,34`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1&5N>2!F<F]M(&%L;`H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O
M+U)%041-10``````````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C`T-3(`,3`T,3<S-C,P,#$`,#$U-S`U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#T]/3T]/3T]/3T]
M/3T]/3T]/3T*(%1R86YS;&%T:6]N($=U:61E(`H]/3T]/3T]/3T]/3T]/3T]
M/3T]"@HZ1&%T93H@("`@("1$871E.B`R,#`T+S$R+S`S(#$R.C$U.C`R("0*
M.E)E=FES:6]N.B`D4F5V:7-I;VXZ(#$N,CD@)`HZ075T:&]R<SH@($IA;B!3
M8VAN96ED97(*.D-O;G1A8W0Z("!I,3AN0&QI<W1S+FAO<F1E+F]R9PH*+BX@
M8V]N=&5N=',Z.@HN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I4<F%N<VQA=&EO
M;B!4;V]L"CT]/3T]/3T]/3T]/3T]/3T*"F!@=')A;G-L871I;VXN<&AP8&`@
M:7,@82!S;6%L;"!02%`@<V-R:7!T('1H870@<VAO=6QD(&AE;'`@=')A;G-L
M871O<G,@9&]I;F<*=&AE:7(@=V]R:RX*06YY(&9E961B86-K+"!B=6<@<F5P
M;W)T<R!A;F0@9F5A='5R92!R97%U97-T<R!S:&]U;&0@8F4@<V5N9"!T;R!T
M:&4@8&DQ.&X*;6%I;&EN9R!L:7-T8%\N(%1H:7,@:7,@86QS;R!T:&4@<FEG
M:'0@<&QA8V4@9F]R(&YE=R!T<F%N<VQA=&EO;G,@86YD(&=E;F5R86P*9&ES
M8W5S<VEO;G,@;V8@:3$X;B!A;F0@;#$P;B!Q=65S=&EO;G,@86YD('!R;V)L
M96US+@H*1F]R(&$@;&ES="!O9B!A=F%I;&%B;&4@8V]M;6%N9',@<G5N.CH*
M"B`@+B]T<F%N<VQA=&EO;BYP:'`@:&5L<`H*1F]R(&1E=&%I;&5D(&AE;'`@
M;VX@82!C97)T86EN(&-O;6UA;F0@<G5N.CH*"B`@+B]T<F%N<VQA=&EO;BYP
M:'`@:&5L<"!C;VUM86YD"@I!9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&%B;W5T
M(&-R96%T:6YG('1R86YS;&%T:6]N<R!A;F0@9FEX:6YG('!R;V)L96US(&-A
M;B!B90IF;W5N9"!I;B!T:&4@9FEL92!@8&AO<F1E+V1O8W,O5%)!3E-,051)
M3TY@8"X*"BXN(%]I,3AN(&UA:6QI;F<@;&ES=#H@:'1T<#HO+VAO<F1E+F]R
M9R]M86EL+PH*4')E<F5Q=6ES:71E<PI^?GY^?GY^?GY^?GY^"@I4;R!R=6X@
M=&AI<R!S8W)I<'0@>6]U)VQL(&YE960@82!02%`@97AE8W5T86)L92!L:6ME
M('1H92!#3$D@;W(@=&AE($-'22!V97)S:6]N"G=I=&@@8&=E='1E>'0@<W5P
M<&]R=&!?(&-O;7!I;&5D(&EN(&%N9"!T:&4@8F%S:6,@8%!%05)@7R!L:6)R
M87)I97,N(%1H90IS8W)I<'0@97AP96-T<R!Y;W5R(%!(4"!E>&5C=71A8FQE
M('1O(&)E(&%T(&!@+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<&!@+B!)
M9B!Y;W5R"F5X96-U=&%B;&4@:7,@870@86YO=&AE<B!P;&%C92P@96ET:&5R
M(&5D:70@=&AE(&9I<G-T(&QI;F4@;V8*8&!T<F%N<VQA=&EO;BYP:'!@8"!T
M;R!R969L96-T('EO=7(@;&]C871I;VX@;W(@8V%L;"!T:&4@<V-R:7!T(&QI
M:V4Z.@H*("`O=7-R+VQO8V%L+W!S82]A9&UI;B]B:6XO<&AP("UF('1R86YS
M;&%T:6]N+G!H<"X*"EEO=2=L;"!N965D(&!G971T97AT8%\@,"XQ,2!O<B!G
M<F5A=&5R+"!B=70@=F5R<VEO;B`P+C$R(&]R(&=R96%T97(@:7,@<W1R;VYG
M;'D*<F5C;VUM96YD960@87,@=&AI<R!I<R!T:&4@9FER<W0@=F5R<VEO;B!T
M:&%T('-U<'!O<G1S(%!(4"!N871I=F5L>2X@3VQD97(*=F5R<VEO;G,@;6%Y
M(&YO="!E>'1R86-T(&%L;"!T<F%N<VQA=&5A8FQE('-T<FEN9W,@8V]R<F5C
M=&QY+@I!('=I;F1O=W,@=F5R<VEO;B!O9B!T:&4@9V5T=&5X="!B:6YA<FEE
M<R!C86X@8F4@9F]U;F0@;VX@979E<GD@8$=.52!F='`*;6ER<F]R8%\@87,@
M;V8@=F5R<VEO;B`P+C$R+@H*66]U)VQL(&YE960@=&AE(%!%05(@<&%C:V%G
M97,@8$-O;G-O;&5?1V5T;W!T8%\@,"XQ,2!O<B!G<F5A=&5R+`I@0V]N<V]L
M95]486)L96!?(&%N9"!@1FEL95]&:6YD8%\N(%1O(&EN<W1A;&P@86QL(&YE
M961E9"!P86-K86=E<RP@<G5N.CH*"B`@<&5A<B!U<&=R861E(%!%05(@0V]N
M<V]L95]'971O<'0*("!P96%R(&EN<W1A;&P@0V]N<V]L95]486)L92!&:6QE
M7T9I;F0*"F]R(&1O=VYL;V%D('1H92!N97=E<W0@<&%C:V%G92!F<F]M('1H
M92!@4$5!4F!?('-E<G9E<B!A;F0@:6YS=&%L;"!T:&5M"FUA;G5A;&QY(&EN
M('EO=7(@4$5!4B!D:7)E8W1O<GDN"@HN+B!?9V5T=&5X=#H@:'1T<#HO+W=W
M=RYG;G4N;W)G+W-O9G1W87)E+V=E='1E>'0O"BXN(%]G971T97AT('-U<'!O
M<G0Z(&AT='`Z+R]W=W<N<&AP+FYE="]G971T97AT+PHN+B!?1TY5(&9T<"!M
M:7)R;W(Z(&AT='`Z+R]W=W<N9VYU+F]R9R]P<F5P+V9T<"YH=&UL"BXN(%]0
M14%2.B!H='1P.B\O<&5A<BYP:'`N;F5T+PHN+B!?0V]N<V]L95]'971O<'0Z
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]#;VYS;VQE7T=E=&]P="\*
M+BX@7T-O;G-O;&5?5&%B;&4Z(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]#;VYS;VQE7U1A8FQE+PHN+B!?1FEL95]&:6YD.B!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O1FEL95]&:6YD+PH*0W)E871I;F<@82!N97<@=')A
M;G-L871I;VX*?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GX*"E1O(&-R96%T
M92!A(&YE=R!T<F%N<VQA=&EO;B!Y;W4@9FER<W0@:&%V92!T;R!E>'1R86-T
M(&%L;"!G971T97AT(&UE<W-A9V5S(&9R;VT*=&AE(%!(4"!S;W5R8V5S+B!4
M:&5R92!A<F4@86QR96%D>2!T96UP;&%T92!F:6QE<R!W:71H('1H92!@8"YP
M;W1@8"!S=69F:7@@:6X*=&AE(&!@<&]@8"!D:7)E8W1O<FEE<R!T:&%T('EO
M=2!C86X@=7-E(&EF('EO=2!H879E('1R;W5B;&5S(&5X=')A8W1I;F<@=&AE
M"FUE<W-A9V5S(&)U="!T:&5Y(&UI9VAT(&)E(&]U=&1A=&5D+@I2=6XZ.@H*
M("`N+W1R86YS;&%T:6]N+G!H<"!E>'1R86-T"@I9;W4@;F]W(&AA=F4@=&\@
M8W)E871E(&$@;F5W(%!/(&9I;&4@9F]R('EO=7(@;&]C86QE+B!!(&QO8V%L
M92!H87,@=&AE(&9O<FT*8&!L;%]#0V!@('=H97)E(&!@;&Q@8"!I<R!T:&4@
M='=O(&QE='1E<B!@25-/(#8S.6!?(&-O9&4@;V8@=&AE(&QA;F=U86=E(&%N
M9`I@8$-#8&`@=&AE('1W;R!L971T97(@8$E33R`S,38V8%\@8V]D92!O9B!T
M:&4@8V]U;G1R>2P@92YG+B!@8&1E7T1%8&`L"F!@96Y?55-@8"!O<B!@8'!T
M7T)28&`N"F!@=')A;G-L871I;VXN<&AP8&`@:7,@86)L92!T;R!G=65S<R!T
M:&4@;&]C86QE(&9R;VT@=&AE(&!@3$%.1V!@(&5N=FER;VYM96YT"G9A<FEA
M8FQE(&)U="!I="!I<R!S869E<B!T;R!S<&5C:69Y('1H92!L;V-A;&4@=VET
M:"!T:&4@8&`M;&!@('!A<F%M971E<BX*5&\@8W)E871E('1H92!03R!F:6QE
M(')U;CHZ"@H@("XO=')A;G-L871I;VXN<&AP(&EN:70@+6P@;&Q?0T,*"DYO
M=R!Y;W4@8V%N('-T87)T('1H92!T<F%N<VQA=&EO;B!B>2!E9&ET:6YG('1H
M92!C<F5A=&5D(&!@;&Q?0T,N<&]@8`IF:6QE<RX@270@:7,@:6UP;W)T86YT
M('1O('-E="!T:&4@8V]R<F5C="!C:&%R<V5T(&9O<B!T:&4@;&]C86QE(&EN
M('1H90I@8$-O;G1E;G0M5'EP93I@8"!H96%D97(N"EEO=2!S:&]U;&0@9FEL
M;"!O=70@=&AE('1H92!C;VUP;&5T92!H96%D97(@;V8@=&AE(&-R96%T960@
M8&!L;%]#0RYP;V!@(&9I;&4L"F4N9RXZ.@H*("`C($1U=&-H('1R86YS;&%T
M:6]N(&9O<B!(;W)D92X*("`C($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0
M<F]J96-T"B`@(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*("`C($IO<FES
M($)R86%K;6%N(#QJ8G)A86MM86Y`>6%H;V\N8V]M/BP@,C`P-"X*("`C"B`@
M;7-G:60@(B(*("!M<V=S='(@(B(*("`B4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D92`R+C-<;B(*("`B4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F=<;B(*("`B4$]4+4-R96%T:6]N+41A=&4Z(#(P,#0M,#0M
M,30@,3`Z,S`K,#(P,%QN(@H@(")03RU2979I<VEO;BU$871E.B`R,#`T+3`T
M+3$T(#$W.C$W*S`R.C`P7&XB"B`@(DQA<W0M5')A;G-L871O<CH@2F]R:7,@
M0G)A86MM86X@/&IB<F%A:VUA;D!Y86AO;RYC;VT^7&XB"B`@(DQA;F=U86=E
M+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B`@(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B`@(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ7&XB"B`@(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#@M8FET7&XB"@I4;R!C;VUP:6QE('1H92!T<F%N<VQA=&EO;G,@=&\@82!B
M:6YA<GD@9F]R;6%T(')U;CHZ"@H@("XO=')A;G-L871I;VXN<&AP(&UA:V4*
M"D%F=&5R('EO=2!C<F5A=&5D('1H92!N97<@=')A;G-L871I;VX@>6]U(&AA
M=F4@=&\@861D(&5N=')I97,@9F]R('1H:7,@;&]C86QE"FEN('1H92!C;VYF
M:6=U<F%T:6]N(&9I;&4@:&]R9&4O8V]N9FEG+VYL<RYP:'`N"@I43T1/.B!F
M:6QL:6YG(&YE=R!P;R!F:6QE<R!W:71H('-T<FEN9W,@9G)O;2!T:&4@8V]M
M<&5N9&EU;2X*"BXN(%])4T\@-C,Y.B!H='1P.B\O=W=W+FQO8RYG;W8O<W1A
M;F1A<F1S+VES;S8S.2TR+PHN+B!?25-/(#,Q-C8Z(&AT='`Z+R]W=W<N:7-O
M+F-H+VES;R]E;B]P<F]D<RUS97)V:6-E<R]I<V\S,38V;6$O:6YD97@N:'1M
M;`H*36%I;G1A:6YI;F<@=')A;G-L871I;VYS"GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?@H*5&AI<R!T;V]L(&ES(&1E<VEG;F5D('1O(&AE;'`@>6]U('1R
M86YS;&%T;W)S(&1O:6YG('EO=7(@9W)E870@=V]R:RX@270@8VAA;F=E<PIA
M(&QO="!C;VUP87)E9"!T;R!T:&4@;VQD(&UE=&AO9',@8W)E871I;F<@86YD
M(&UA:6YT86EN:6<@>6]U<B!T<F%N<VQA=&EO;G,N(%1O"FUA:V4@=&AE('1R
M86YS:71I;VX@=&\@=&AE('1O;VP@87,@<VUO;W1H(&%S('!O<W-I8FQE('EO
M=2!S:&]U;&0@<F5A9"!C:&%P=&5R"C,N,2!B969O<F4@=7-I;F<@=&AI<R!T
M;V]L('1H92!F:7)S="!T:6UE+@H*1FER<W0@=&EM92!U<V4@;V8@=')A;G-L
M871I;VXN<&AP"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*
M5&AI<R!T;V]L(&EN=')O9'5C97,@82!N:6-E(&9E871U<F4@;V8@9V5T=&5X
M=#H@8V]M<&5N9&EU;2!F:6QE<RX@02!C;VUP96YD:75M"FES(&$@<W!E8VEA
M;"!03R!F:6QE(&-O;G1A:6YI;F<@82!S970@;V8@=')A;G-L871I;VYS(')E
M8W5R<FEN9R!I;B!M86YY"F1I9F9E<F5N="!P86-K86=E<RX@5&AE<V4@8V]M
M<&5N9&EA('=I;&P@8F4@=7-E9"!I;B!T:&4@8F%C:V=R;W5N9"!W:71H;W5T
M(&UU8V@*9F]R('EO=2!T;R!C87)E(&%B;W5T+B!"=70@>6]U(&AA=F4@=&\@
M8W)E871E(&%N9"!E9&ET(&$@8V]M<&5N9&EU;2!B969O<F4@>6]U"F-A;B!U
M<V4@:70N"@I4;R!C<F5A=&4@82!C;VUP96YD:75M(&]F(&%L;"!Y;W5R(&5X
M:7-T:6YG('1R86YS;&%T:6]N<R!R=6XZ.@H*("`N+W1R86YS;&%T:6]N+G!H
M<"!C;VUP96YD:75M("UL(&QL7T-#"@I4:&4@8&!C;VUP96YD:75M+G!O8&`@
M8F5I;F<@8W)E871E9"!W:6QL(&-O;G1A:6X@86QL(&UO9'5L97,G('1R86YS
M;&%T:6]N<R!O9@IT:&ES(&QO8V%L92!M97)G960@:6YT;R!A('-I;F=L92!F
M:6QE+B!9;W4@<VAO=6QD('1A:V4@82!C;&]S97(@;&]O:R!A="!T:&ES"F9I
M;&4@8F5C875S92!Y;W4@;6%Y(&9I;F0@82!L;W0@;V8@<W!E8VEA;"!M87)K
M960@;&EN97,@=VAE<F4@>6]U('1R86YS;&%T960*8V5R=&%I;B!S=')I;F=S
M(&1I9F9E<F5N=&QY(&EN('1H92!V87)I;W5S(&UO9'5L97,N($ET)W,@82!G
M;V]D(&ED96$@=&\@9FEX"G1H92!M;V1U;&5S)R!T<F%N<VQA=&EO;G,@;F]W
M('-O('1H870@86QL(&UO9'5L97,@=7-E('1H92!S86UE('1R86YS;&%T:6]N
M(&9O<@IT:&4@<V%M92!S=')I;F<N(%EO=2!C86X@86QW87ES(')E8W)E871E
M('EO=7(@8V]M<&5N9&EU;2!W:71H('1H92!A8F]V90IC;VUM86YD+@H*268@
M>6]U)W)E(&UA:6YT86EN:6YG('1R86YS;&%T:6]N<R!F;W(@9&EF9F5R96YT
M(&!B<F%N8VAE<V!?(&%N9"!A<W-U;65D('1H870*>6]U(&AA=F4@86QL(&UO
M9'5L97,@;V8@=&AE(&!@2$5!1&!@(&)R86YC:&5S(&EN(&]N92!D:7)E8W1O
M<GD@86YD(&%L;"!O9B!T:&4*8&!214Q%3D=?*F!@(&)R86YC:&5S(&EN(&%N
M;W1H97(L('EO=2!P<F]B86)L>2!W86YT('1O('-H87)E(&$@8V]M<&5N9&EU
M;0IB971W965N('1H97-E(&1I<F5C=&]R:65S+@H*66]U('-H;W5L9"!F:7)S
M="!C<F5A=&4@82!C;VUP96YD:75M(&EN('1H92!@8%)%3$5.1U\J8&`@8G)A
M;F-H+"!R979I97<@:70@86YD"F9I>"!A;&P@=')A;G-L871I;VYS('5N=&EL
M('EO=2=R92!H87!P>2!W:71H('1H92!R97-U;'0N(%1H96X@8W)E871E(&$@
M<V5C;VYD"F-O;7!E;F1I=6T@:6X@=&AE(&!@2$5!1&!@(&)R86YC:"!A;F0@
M:6YC;'5D92!Y;W5R(&9I<G-T(&]N92!W:71H('1H92`M+6%D9`IO<'1I;VXN
M"DYO=R!F:7@@=&AE('1R86YS;&%T:6]N<R!I;B!T:&ES(&)R86YC:"X@268@
M>6]U)W)E(')E861Y('EO=2!C86X@<F5M;W9E('1H90IF:7)S="!C;VUP96YD
M:75M(&%N9"!F;W(@;F]W(&]N('5S92!T:&4@8V]M<&5N9&EU;2!I;B!T:&4@
M8&!(14%$8&`@8G)A;F-H(&9O<@IB;W1H(&)R86YC:&5S+B!4;R!D;R!S;R!U
M<V4@=&AE(&!@+2UC;VUP96YD:75M8&`@;W!T:6]N('1O('-P96-I9GD@82!P
M871H('1O"GEO=7(@8V]M<&5N9&EU;2X*"BXN(%]B<F%N8VAE<SH@:'1T<#HO
M+W=W=RYH;W)D92YO<F<O<V]U<F-E+PH*57!D871I;F<@=')A;G-L871I;VYS
M"BTM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5&AE('!R;V-E<W,@;V8@=7!D871I
M;F<@=')A;G-L871I;VYS(&ES(&$@8WEC;&4@=VAE<F4@>6]U(&5X=')A8W0@
M;F5W(&=E='1E>'0*<W1R:6YG<R!F<F]M('1H92!S;W5R8V5S+"!T<F%N<VQA
M=&4@=&AO<V4@;F5W('-T<FEN9W,@;W(@=7!D871E('1H92!A;')E861Y"G1R
M86YS;&%T960@<W1R:6YG<R!A;F0@8V]M<&EL92!T:&5M(&%F=&5R+@H*5&\@
M=7!D871E('1H92!T<F%N<VQA=&EO;B!F;W(@82!M;V1U;&4L(')U;CHZ"@H@
M("XO=')A;G-L871I;VXN<&AP('5P9&%T92`M;2!M;V1U;&5N86UE("UL(&QL
M7T-#"@I4:&ES(&5X=')A8W1S('1H92!N97<@<W1R:6YG<R!F<F]M('1H92!S
M;W5R8V5S(&%N9"!T<FEE<R!T;R!U<&1A=&4@=&AE;2!F<F]M"F%L<F5A9'D@
M97AI<W1I;F<@=')A;G-L871I;VYS(&EN('1H92!C;VUP96YD:75M+B!9;W4@
M:G5S="!H879E('1O('1R86YS;&%T90IA;&P@=6YS=')A;G-L871E9"!S=')I
M;F=S(&EN('1H92!@8&QL7T-#+G!O8&`@9FEL92!I;B!T:&4@8&!P;V!@(&1I
M<F5C=&]R>2!O9@IT:&4@;6]D=6QE('EO=2!U<&1A=&5D+@H*3VYC92!T:&ES
M(&ES(&1O;F4L('EO=2!C86X@8V]M<&EL92!T:&4@=')A;G-L871I;VX@8GD@
M8V%L;&EN9SHZ"@H@("XO=')A;G-L871I;VXN<&AP(&UA:V4@+6T@;6]D=6QE
M;F%M92`M;"!L;%]#0PH*06-C97-S($ME>7,*/3T]/3T]/3T]/3T*"D%C8V5S
M<R!K97ES+"!A;'-O(&MN;W=N(&%S('-H;W)T8W5T(&ME>7,L(&%L;&]W(&5A
M<WD@86-C97-S('1O(&EM<&]R=&%N=`IF=6YC=&EO;G,L(&YO<FUA;&QY(&)Y
M(&AI='1I;F<@=&AE($%L="]-971A(&ME>2!I;B!C;VUB:6YA=&EO;B!W:71H
M(&%N;W1H97(*:V5Y+B!4:&ES(&ME>2!I<R!M87)K960@:6X@;6]S="!U<V5R
M(&EN=&5R9F%C97,@8GD@8F5I;F<@=6YD97)L:6YE9"X*"D%S('1H92!A8V-E
M<W,@:V5Y(&ES('!A<G0@;V8@=&AE('=O<F0@<F5P<F5S96YT:6YG('1H92!A
M8W1I;VX@8F5I;F<@97AE8W5T960L"FET(&ES(&EN('1H92!T<F%N<VQA=&]R
M<R!R97-P;VYS:6)I;&ET>2!T;R!S96QE8W0@86X@86-C97-S(&ME>2!W:&5N
M(&AE"G1R86YS;&%T97,@=&AE<V4@=V]R9',N(%1H92!A8W1I;VX@:7,@86QW
M87ES(&$@;&EN:R!I;B!(;W)D92X@5&AE(&%C8V5S<R!K97D*;V8@82!L:6YK
M(&ES('-E;&5C=&5D(&)Y('!R969I>&EN9R!I="!W:71H(&%N('5N9&5R<V-O
M<F4N"@I4:&4@:&5L<"!L:6YK(&EN('1H92!M96YU(&9O<B!E>&%M<&QE(&ES
M(&%L=V%Y<R`B7TAE;'`B+B!4:&ES(&UE86YS('1H870@=&AE"B)((B!O9B!T
M:&4@;&EN:R!W:6QL(&)E('5N9&5R;&EN960@86YD('1H92!H96QP(&-A;B!B
M92!O<&5N960@8GD@:&ET=&EN9PI!;'0K2"X@26X@=&AE(%!/(&9I;&4@=&AI
M<R!S=')I;F<@=VEL;"!A<'!E87(@87,Z.@H*("`C.B!T96UP;&%T97,O;65N
M=2]M96YU+FEN8SHU,PH@(&US9VED(")?2&5L<"(*("!M<V=S='(@(B(*"D$@
M4W!A;FES:"!T<F%N<VQA=&]R(&UI9VAT('=A;G0@=&\@=')A;G-L871E('1H
M:7,@=&\Z.@H*("`C.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHU,PH@(&US
M9VED(")?2&5L<"(*("!M<V=S='(@(E]!>75D82(*"E1R86YS;&%T;W)S(&]F
M(&UU;'1I8GET92!L86YG=6%G97,@;F5E9"!T;R!D;R!T:&ES(&$@8FET(&1I
M9F9E<F5N=&QY(&%S(&]N;'D*05-#24D@8VAA<F%C=&5R<R!A<F4@86QL;W=E
M9"!F;W(@86-C97-S(&ME>7,N($$@5')A9&ET:6]N86P@0VAI;F5S92!T<F%N
M<VQA=&]R"FUI9VAT('=A;G0@=&\@=7-E.CH*"B`@(SH@=&5M<&QA=&5S+VUE
M;G4O;65N=2YI;F,Z-3,*("!M<V=I9"`B7TAE;'`B"B`@;7-G<W1R(")?2.BJ
MJN:8CB(*"E1H:7,@<F5N9&5R<R!T;R`BZ*JJYIB.*$@I(B!I;B!T:&4@:6YT
M97)F86-E(&%N9"!Y;W4@8V%N"F%C8V5S<R!T:&ES(&QI;FL@=VET:"`B2"(@
M87,@=&AE(&%C8V5S<R!K97DN"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V%R7U-9+G!O
M````````````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`V,38Q-3<`,3`T,3<S-C,P,#$`,#$V-#$W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@2$]21$4@07)A8FEC('1R86YS
M;&%T:6]N"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S
M86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@0V]P>7)I9VAT
M("A#*2`R,#`S(%!L871I;G5M($EN8RX@/'!L0'1I;G5M+FEN9F\^"B,@0W5S
M=&]M(%=E8B!!<'!L:6-A=&EO;G,@/&AT='`Z+R]P;&%T:6YU;2US>2YC;VT^
M"B,@4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;2`\9&5V=&5A;4!P;&%T:6YU
M;2US>2YN970^"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($A/4D1%('8R+C`N,%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#,M,#0M,S`@,3(Z,#`K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!0;&%T
M:6YU;2!$979E;&]P;65N="!496%M(#QD979T96%M0'!L871I;G5M+7-Y+FYE
M=#Y<;B(*(DQA;F=U86=E+51E86TZ($%R86)I8R`\:3$X;D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+VAT;6P[(&-H87)S970]0U`Q,C4V7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E
M92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@
M861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"
M('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO
M=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M
M($YO=&EC92(*;7-G<W1R("+*Y,CMY2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I
M;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(LKDW>W0(-KCX>W'RB#'X=7MQ^3)(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92XB"FUS9W-T<B`BUMH@VN''X\D@W>T@X]'(VB#'X=KCX>W)("C'X=KCX>W'
MRBD@Q^'*[2#*T>W/(,KDW>W0Y<<@S<?AQ_`N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R
M97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G
M<W1R("+?X2`U(,_>[=[)(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C$R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+;[=$@X^;,YL\B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R(");Q^'3V-$@)7,@X^0@
M)7-=(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S
M='(@(L_=RM$@VN3'YNWD(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD
M87(B"FUS9W-T<B`BP\SDS\DB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R
M;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@
M(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B
M;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM
M<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3D*(RP@9G5Z>GD*;7-G:60@(C(T($AO=7(@
M1F]R;6%T(@IM<V=S='(@(LCMQ^3'RM\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(-/'VLDB
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E
M=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*
M;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D(@IM<V=S='(@(CQB/B#-U>$@SMC#.B`B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@
M<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I
M9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R("+DY<?1Q_`OX>WAQ_`B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES
M(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T
M=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O
M=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(LCMQ^3'RM\Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A
M<W-W;W)D(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O
M=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,S,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R
M("+*Y-WMT#HB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D%D
M9"(*;7-G<W1R("+'X=KDYL?D(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@
M861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T
M<B`BQ^':Y.;'Y"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A
M(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE
M;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BP];=(,ODQ\;M(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G
M<W1R("+/W<K1(-KDQ^;MY"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D
M9')E<W,@8F]O:R(*;7-G<W1R("+/W<K1(-KDQ^;MY"(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("+#
MUMT@R^3'QNTB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O
M=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*
M(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS
M9VED(")!9&1R97-S(@IM<V=S='(@(L?AVN3FQ^0B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`BS]W*T2#:Y,?F[>0B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD
M97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G
M:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R
M("+'X=KDYL?D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@
M(D%L:6%S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U
M<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M
M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED
M(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@
M24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F
M=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B
MVN3FQ^0@R-'MS]\@Q^'%X=_*T>;D[3HB"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(LKC(,K-S^W/(-[MX\D@V^W1
M(./>R.;AR2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*
M(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N
M(@IM<V=S='(@(LW5X2#.V,,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO
M;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC
M871I;VXB"FUS9W-T<B`BQ^'*V,CMWL?*(,?AX^;,YL_).B`E<R(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC
M871I;VX@3&ES="(*;7-G<W1R("+'X<K8R.W>Q\H@Q^'CYLSFS\DZ("5S(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I
M;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R
M-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q
M"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#
M24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X
M"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U
M8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@
M(LK#W^W/(,?AV.'((-[(X2#'X<C/P2#(VN/A[<?*(,?AU>W'Y,F_(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N
M="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*
M;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM
M<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU
M,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM
M<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S
M-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E
M<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*
M;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5
M<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC
M86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I
M<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I
M;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("+*XR#1W=8@Q^'*S=[>(./D(,?A
MY>;MR2#CY"#>R.$@Q^'CSL_C(-''S^WFTRXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@U,0HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(LW5X2#.V,,@SN''
MX2#'X<7*U<?A(,CCSL_C(,?AW"!&5%`N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+-U>$@SMC#(,[A
MQ^$@Q^'%RM7'X2#(X\[/XR#'X=P@1E10+B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S
M='(@(L?AS=[FX2#'X>/*YMW1R3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@
M(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(M_A
MX\D@X]'FT2#;R-$@X][(YN')("C?[='([='FTRDB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E
M<FYA;64N(@IM<V=S='(@(L?3XR#'X>/3RL[/XR#;R-$@X][(YN$@*-_MT<CM
MT>;3*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ
M,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(NWFXR#'X>/MX<?/(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI
M8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(N'C(.W:R]$@VN'L
M(,?AX]/*X]H@)7,N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R("+EYM'/[2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G
M:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z
M>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`BY>;1S^TB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z
M>GD*;7-G:60@(D)R87II;"(*;7-G<W1R("+'X<C1[<\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0T-`HC+"!F=7IZ>0IM<V=I9"`B0TU3(@IM<V=S='(@(D-6
M4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*
M;7-G:60@(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN
M=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R
M("+#S.3/R2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*
M;7-G:60@(D-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A
M;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P
M"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN
M:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(N''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@3$1!4"XB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(L/,Y,_)
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+%X=O'P2#'X<CAQ]L@VN0@
MX]3?X<DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C
M;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(L7DU,?!(,?AX\SASR`E<R(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S
M<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@
M(D-A<'1I;VXB"FUS9W-T<B`BSNW'T<?*(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B
M0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL
M(%!H;VYE(@IM<V=S='(@(L?AY<?*W2#'X<SFQ^$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY
M"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BQ^'EQ\K=(,?AS.;'
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G
M:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S
M<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C<T"B,L(&9U>GIY"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BQ^'E
MQ\K=(,?AS.;'X2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED
M(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED
M(")#96YT97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM
M<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC
M871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ
M>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G<W1R("+*T<?,VB#:
MY"#'X<K;[>W1Q\HB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB
M0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED
M(")#:&%R(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@
M3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED
M(")#:&EL92(*;7-G<W1R("+'X>'>R"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H
M:6YA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS
M9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B
M0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(N'C(.W:R]$@VN'L(,?AX]/*X]H@)7,N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@
M(D-L96%R(@IM<V=S='(@(L/,Y,_)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS
M9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A
M<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED
M(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA
M=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R
M("+%V^''WB#'X>3'W=#)(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*
M;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM
M<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P
M<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@
M8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R
M-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L
M;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*
M;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S
M(@IM<V=S='(@(M'3YN/'RB(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC
M+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("+'X</FQ^/1.B(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N
M9"!3:&5L;"(*;7-G<W1R("+'X</FQ^/1.B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;65N="(*
M;7-G<W1R("+'X</FQ^/1.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("+1
MT^;CQ\HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(L?AU-'?R2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@
M9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("+*Y-WMT"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y
M;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FER;2!0
M87-S=V]R9"(*;7-G<W1R("+?X>/)(,?AX]'FT2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(D-O;F=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F
M=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(LW5X2#.
MV,,@SN''X2#'X<7*U<?A(,CCSL_C(,?AW"!&5%`N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q^'%
MRM7'X2#(X\[/XR#'X=P@1E10+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<Y,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+-U>$@SMC#
M(,[AQ^$@Q^'%RM7'X2#(X\[/XR#'X=P@1E10+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@T-0HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?AQ<K5
MQ^$@R./.S^,@Q^'<($944"XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<
M(B(*;7-G<W1R("+CS<KF[<?*("<E<R<B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*
M;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`BQ^'4T=_)(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("+'X<W>YN$@Q^'CT\KF
MT<_).B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#
M;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I
M8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V
M-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(N''(,7CW\?D[<D@X>33SB`E
M<R#%X>P@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C($Q$05`N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!C
M;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*
MU<?A(,C'X>/.S^,@4TU"+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S
M97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(N''Q>/?Q^3MR2#AQ>34Q\$@
MX\SASR#CS>'M("AL;V-A;"D@X^0@P\SA(./AW2#'X>';R2`E<SHB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`BX<<@
MQ>/?Q^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`BX<<@Q>/?
MQ^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T
M(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG
M+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S(@IM<V=S='(@(N''Q>/?Q^3MR2#AW<K-($UA:6YT96YA;F-E
M7U1A<VL@X>'(T>WCS"`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A["`E
M<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BX<?%X]_'
MY.W)(.'AQ<K5Q^$@R,?AX\[/XR!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+T]B:F5C="YP:'`Z,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.
M("5S(,7A["`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U
M"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A
M:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`BX<?%X]_'Y.W)(.'%Y-3'
MP2#CS.'/(./-X>T@*&QO8V%L*2#CY"##S.$@X^'=(,?AX=O)("5S.B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G
M<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+AXR#MRN,@Q=K/Q\\@Y>;1S^T@R-3?
MX2#5S>W-(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("+AXR#MVLO1(-KA["`G<&]R="<@W>T@Q=K/Q\_'RB!61E,N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@
M;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E
M:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'X2#(
MQ^'CSL_C($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@
M)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E
M<UPB.B`E<R(*;7-G<W1R("+AQ\7CW\?D[<D@X<7DU,?!(./,X<\@X\WA[2`H
M;&]C86PI(./D(,/,X2#CX=T@Q^'AV\D@)7,Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@
M=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD
M97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@
M(D-O=6YT<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*
M;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T
M92!A(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT
M:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A
M=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E
M;G0@4V5S<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E
M;G0@57-E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N
M9&ET:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$
M(@IM<V=S='(@(NWFXR`M(-'>X^WD(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("+MYN/M(@H*
M(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W
M<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB
M"FUS9W-T<B`B[>;C[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*
M;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R
M96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0B"FUS9W-T<B`BQ^'*S=[>(,?AQ]W*T<?6[2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U
M>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(L?3RL[/XR#'X=[M
MXR#'X<7=RM''UNW)(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("+'X<K-
MWMX@Q^''W<K1Q];M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L
M(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(L?ARLW>WB#'
MX<?=RM''UNTB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@
M(D1E9FEN:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED
M(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N
M>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E
M;&5T92!R;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T
M96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y(@IM<V=S='(@(L?ARLW>WB#'X<?=RM''UNTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R
M>2!T:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(M31S2#'
MX>/4W^')(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@
M9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(L?AU-'-(,?ARMW5
M[>'M.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED
M(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("+*XR#-W=D@Q^'*W<?5[>$@X>//[=$@Q^'DV<?C(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE
M;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G
M:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS
M9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE
M<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS
M9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BSNW'T<?*(,?AVM'6(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(L[MQ]''
MRB#'X=K1UB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I
M<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F
M;W)M870B"FUS9W-T<B`BSNW'T<?*(,?AVM'6(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`BX<<@RL_.X2#CR,?4
MT<GP(,7A["#'X>/AW2!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@
M:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL
M;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO
M860@)7,B"FUS9W-T<B`BP^/1(-OMT2#CVM'FW2`E<SHB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@
M;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*
M;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S
M='(@(L?AR-'MSR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV
M97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO
M961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D
M:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED
M(")%9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM
M<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H
M92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM
M<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I
M;"(*;7-G<W1R("+'X<C1[<\@Q^'%X=_*T>;D[2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R
M("+:Y.;'Y"#(T>W/WR#'X<7AW\K1YN3M.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*
M;7-G<W1R("+CVN'FX\?*(,+.T>PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A
M=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM
M<V=S='(@(L[MQ]''RB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S
M<V%G92XB"FUS9W-T<B`BX<?*YLS/(.3*Q\;,+B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y
M(')E<W5L="XB"FUS9W-T<B`BX<?*YLS/(.3*Q\;,+B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C
M:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G
M:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I
M;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!5
M4DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B
M96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA
M;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("+.V,,B"@HC
M.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A
M=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN
M9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%
M=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G
M<W1R("+?X2`Q-2#/WNW>R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#D*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("+?
MX2`U(,_>[=[)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S
M(@IM<V=S='(@(M_A(#,P(,_>[=[)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R
M>2`U(&UI;G5T97,B"FUS9W-T<B`BW^$@-2#/WNW>R2(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y
M($QO9VEN(@IM<V=S='(@(M_A(,_.YN$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BW^$@
MY-7=(-/'VLDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R("+?X2#/WNW>R2(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BP^/+X<D@VN'L
M(,?AWNWC.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S
M:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PHC+"!F=7IZ>0IM
M<V=I9"`B17AE8W5T92(*;7-G<W1R("+*Y-WMT#HB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS
M9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I
M9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I
M9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>':R^;1
M(-KA["#'X<K=UNWAQ\HN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C($Q$05`N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N
M;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'
MX2#(Q^'CSL_C(%--0BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@
MR,?AX\[/XR!334(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C(%--0BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("+A
MQ\7CW\?D[<D@X>':R^;1(-KA["#'X<K=UNWAQ\HN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H
M36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(LW5
MX2#.V,,Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(MW'W],B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*
M;7-G<W1R("+=Q]_3(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G
M:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@
M;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY
M"FUS9VED(")&:6QE(@IM<V=S='(@(L?AX=[((@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R("+'X<?3XR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B
M1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I
M9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@
M<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R
M9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O
M<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(N/AQ\W9
MQ\HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U
M;F5S(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*
M;7-G:60@(D9R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R
M86UE<R(*;7-G<W1R("+'X<?3XR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(L?AU-'-(,?ARMW5[>'M.B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS
M9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*
M(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("+'T^/?.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM
M<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")'
M;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G
M:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B
M1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N
M;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U
M<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E
M;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@
M=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ
M-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS
M9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS
M9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L
M<"(*;7-G<W1R("+'X>/3Q]K/R2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*
M(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R("+'X>/3Q]K/R2(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M
M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G
M:60@(DAO7VUE(@IM<V=S='(@(L?AR,_'[<DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS
M9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G:60@(DAO
M;64B"FUS9W-T<B`BQ^'(S\?MR2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S
M='(@(MKDYL?D(,?AX^32X2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R("+EQ\K=(,?AX^32X2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R("+EYM'/[2(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@
M='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I
M9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI
M9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))
M4"!!9&1R97-S(@IM<V=S='(@(L?AVN3FQ^0B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@
M;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@
M(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("+#[=[FY,?*
M(-W>V"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM
M<V=S='(@(L/MWN;DQ\H@X]H@Y-7FU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H
M<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C
M=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))
M9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G
M92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y
M('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("))
M;6%G92!0<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!5
M4DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL
M97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU
M-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`BQ^'-WN;A
M(,?AX]/*YM'/R3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B
M"FUS9W-T<B`BQ^'-WN;A(,?AX]/*YM'/R3H@)7,B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM
M<V=S='(@(L?AS=[FX2#'X>/3RN;1S\DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I
M;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@
M(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@
M(L[8PR#=[2#'T^,@Q^'CT\K.S^,@YB_#YB#?X>/)(,?AT]$N(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C
M="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@
M57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED
M("));F1O;F5S:6$B"FUS9W-T<B`BRN,@R.3,Q\TB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@
M9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(LCMQ^3'RM\Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF
M;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED
M("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@
M0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P
M"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A
M;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@
M;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@
M8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L
M;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M
M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN
M(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O
M('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@
M(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT
M96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0
M(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS
M-`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T
M<B`BQ^'*V,CMWL?*(,?AX^;,YL_).B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI
M9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N
M<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("))
M;G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("));G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G
M7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R
M(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<S"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@
M(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@
M(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN
M=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED
M("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M("))<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D
M(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R
M865L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L
M:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))
M=&%L>2(*;7-G<W1R("+MYN/M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA
M:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*
M;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U
M<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y
M:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*
M=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME
M97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("+'X>/.S^,@W^W1R.W1YM,@T=W6(,?ARLW>
MWB#CY"#'X>7F[<DN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS
M9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B
M2V5Y(%5S86=E(@IM<V=S='(@(LW,XR#'X<?3RL[/Q^,Z(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"B,L(&9U>GIY"FUS9VED
M("),85]Y;W5T(@IM<V=S='(@(L[1YLPB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R("+'X>';R2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M
M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G
M:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T
M=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM
M<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(L[1YLPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@
M8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`BP^/+X<D@
MVN'L(,?AWNWC.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@
M9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@(L/(S\?P(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@
M(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT
M(%)A:6XB"FUS9W-T<B`BS\[FX2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@
M(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN
M('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U
M>GIY"FUS9VED("),:6YK(@IM<V=S='(@(L_.YN$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@
M(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S
M('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT
M+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V
M"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$
M871A8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BWL?&X\D@
MVN3'YNWD(,?AX]/'VL_)(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM
M<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(M['QN/)
M(-KDQ^;MY"#'X>/3Q]K/R2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T
M+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI
M<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI
M<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S
M"B,L(&9U>GIY"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(LK-X^WA(,?A
MX]_*R,?*+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S
M='(@(L_.YN$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*
M;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B
M3&]G(&]U="(*;7-G<W1R("+.T>;,(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("+/SN;A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PHC+"!F=7IZ>0IM<V=I9"`B
M3&]G:6X@5&%S:W,B"FUS9W-T<B`BQ^'CY>/'RB(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDY-@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HBS=7A(,[8PR#AT\C((./'(,/+
MY,?!(,?AS\[FX2X@VN'L(,?AP]',S2##Y"#'T^,@Q^'CT\K.S^,@P^8@W^'C
MR2#'X>/1YM'A[=/*("(*(M7-[<W)(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3DR"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(MW4X2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@
M9G5Z>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("+.T>;,(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS
M9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E
M96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`BU.71("T@T=[C[>0B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS
M9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(L?AR-'M
MSR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I
M;"(*;7-G<W1R("+'X<C1[<\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM
M<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R("+'X<C1[<\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`BQ^'(T>W/
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG
M<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`BRN3([>4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I
M9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T
M:6YI<75E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`BX]C'R-[)
M(,?AS=[FX2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM
M=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I
M9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B365M8F5R<R(*;7-G<W1R("+CT-_1Q\HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO
M9&4Z(@IM<V=S='(@(N;6VB#'X>/0W]''RCHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G
M92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G
M<W1R("+1T\?AR2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B
M"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")-
M97-S86=E(&5X<&ER960N(@IM<V=S='(@(M'3Q^')(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V
M,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(M'3Q^')
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T
M:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G
M:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+*XR#-W=D@
MQ^'*W<?5[>$@X>//[=$@Q^'DV<?C(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO
M="!D969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E
M<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F
M:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z
M-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*
M(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R("+'X<C1[<\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B
M36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G
M92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G
M:60@(DUI<G)O<B(*;7-G<W1R("+.V,,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P
M"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@
M(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)
M1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@
M4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO
M8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I
M960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BU.71[<?P(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B
M36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE
M("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#
M;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM
M<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V
M92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA
M<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C
M8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X
M"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(LCMQ^3'RM\Z(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU
M-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T
M<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").
M971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS
M9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T
M:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I
M9"`B3F5V97(B"FUS9W-T<B`BP\C/Q_`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E
M9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE
M=R!-97-S86=E('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N
M86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*
M;7-G<W1R("+?X>/)(,?AX]'FT2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D
M('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N
M)W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N
M:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR.#D*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`BX^''S=G'
MRB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE
M=W-G<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").
M97AT(&]P=&EO;G,B"FUS9W-T<B`BVN;/R2#%X>P@Q^'.[<?1Q\HB"@HC.B!F
M<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G
M<W1R("+#R,_'\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS
M9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*
M;7-G:60@(DYI=64B"FUS9W-T<B`BRN3([>4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R
M("+AQR(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM
M<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X
M:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(N''RN;,SR#?X>/)(./1YM$@X>'*S=[>(%--
M0CXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@8VAA;F=E+B(*;7-G<W1R("+*T<?,VB#:Y"#'X<K;[>W1Q\HB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM
M<V=S='(@(N''RN;,SR#CVN'FX\?*(,WFX2#%VL_'S\?*(,?AW"!344P@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RXB"FUS9W-T<B`BX<?*YLS/(./:X>;CQ\H@S>;A(,7:S\?/Q\H@Q^'<
M($944"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344P@5D93+B(*;7-G<W1R("+AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/
MQ\_'RB#'X=P@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S$W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("+AQ\KF
MS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#CX=W'RB!344P@5D93+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM
M<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P
M;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW
M,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L
M;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R("+AXR#MRN,@RLW/[<\@X=O)(./-X>W)+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,S"B,L(&9U>GIY"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G
M<W1R("+AXR#MRN,@RLW/[<\@X=O)(./-X>W)+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,L(&9U>GIY"FUS
M9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`BX>,@[<KC(,K-S^W/
M(.';R2#CS>'MR2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M8F5R('-P
M96-I9FEE9"XB"FUS9W-T<B`BX>,@[<KC(,K-S^W/(.';R2#CS>'MR2XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV
M92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VAT='`N<&AP.CDQ"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/
M(-_AX\D@X]'FT2#AX<K-WMX@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEM87`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''
MRN;,SR#?X>/)(./1YM$@X>'*S=[>($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KF
MS,\@W^'CR2#CT>;1(.'ARLW>WB#?[='([='FTR(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I
M;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,L
M(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''RN;,SR#?X>/)(./1YM$@X>'*
MS=[>($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP
M.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/(-_AX\D@
MX]'FT2#AX<K-WMX@4TU"/B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-
MWMX@4TU"/B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N
M9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS
M9W-T<B`BX^''S=G'RB(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0T.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB
M"FUS9W-T<B`BX>,@[<KC(,K-S^W/(.';R2#CS>'MR2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U
M>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R("+CX<?-V<?*(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F
M;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BSMC#(-WM(,?3
MXR#'X>/3RL[/XR#F+\/F(-_AX\D@Q^'3T2XB"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R("+*XR#(Y,S'S2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G
M:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA
M;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO
M<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@
M0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S
M='(@(L7DU,?!(,?AX\SASR`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*
M;7-G:60@(DYO="!S970B"FUS9W-T<B`BX^''S=G'RB(*"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S
M='(@(N/AQ\W9Q\HB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z
M,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-0HC+"!F=7IZ>0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BP\C/Q_`B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED
M(").=6UB97(B"FUS9W-T<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-`HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS
M9W-T<B`BVL_/(,?AP]KCS\D@W>T@Q^'CX<[5.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("+CYL?=WB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*
M;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X
M"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E
M;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(M_A
MX\D@Q^'CT>;1(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V
M"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N
M(@IM<V=S='(@(L[8PR#=[2#'T^,@Q^'CT\K.S^,@YB_#YB#?X>/)(,?AT]$N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N
M;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G
M:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS
M(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I
M9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M
M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED
M(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG
M(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(L[MQ]''RB(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@
M)7,B"FUS9W-T<B`BSNW'T<?*(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W
M"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO
M;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I
M;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM
M<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`BX]KAYN/'RB#"SM'L
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N
M97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL
M(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@
M4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$
M871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F
M=7IZ>0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`BY>;1S^TB"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM
M<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@
M4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*
M;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S
M:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](
M4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@
M(E!A;F%M82(*;7-G<W1R("+'X<?3XR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R("+?X>/)(,?AX]'F
MT2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B
M4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ
M>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(M_AX\D@Q^'C
MT>;1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@HC
M+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-
MWMX@T<?/[>;3+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*
M;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A
M<W-W;W)D.B`B"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R
M9',@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A
M<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G
M:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T
M<B`BQ^'/YM$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(LKDW>W0
M(-KCX>W'RB#'X=7MQ^3)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P
M-@HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R("+*Y-WMT"#:X^'MQ\H@Q^'5[<?DR2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")0
M97)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@
M;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E
M>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8U"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!)
M;F9O<FUA=&EO;B(*;7-G<W1R("+CVN'FX\?*(,+.T>PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B
M"FUS9W-T<B`BY<?*W2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA
M=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE
M;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED(")0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R
M>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P
M,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E
M<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("+'X=',Q\$@RM+F[<_DQR#CX<[5
M(,?AX]3?X<DN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("+'X=',
MQ\$@RM+F[<_DQR#(Q]/C(,?AX]/*SL_C(.;?X>/)(,?AT]$N(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM
M<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*
M;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@
M(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B
M4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS
M9W-T<B`BVN;/R2#%X>P@Q^'.[<?1Q\HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@
M(E!R;V)L96TB"FUS9W-T<B`B6\K>T>W1(,?AX]3?X<E=(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N
M(@IM<V=S='(@(M31S2#'X>/4W^')(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G
M:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM
M<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI
M8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED
M(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B
M4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G
M<W1R("+1T\?AR2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T
M-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I
M9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@
M(E)E;6]V92(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!"
M;&]C:R(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L
M=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T
M:6YG(@IM<V=S='(@(L72X<D@Q^'+Y,?&[2(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+%
MTN')(,?AR^3'QNTB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS
M9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@=&AE(@IM<V=S='(@(L72X<D@Q^'+Y,?&[2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("+%TN')
M(,?AR^3'QNTB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E
M<R(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A
M;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B4F5Q=65S
M=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BX>,@[=K+T2#:X>P@)W!O<G0G(-WM(,7:S\?/Q\H@
M5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("+AXR#MVLO1(-KA["`G<&]R="<@W>T@Q=K/Q\_'
MRB!61E,N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+AXR#MVLO1(-KA
M["`G<&]R="<@W>T@Q=K/Q\_'RB!61E,N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S
M970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(M_A
MX\D@Q^'CT>;1(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*
M;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")2
M97-U;'1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T
M=7)N('1O($]P=&EO;G,B"FUS9W-T<B`BVN;/R2#%X>P@Q^'.[<?1Q\HB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP
M92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R
M="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<R(*;7-G<W1R("+:YL_)(,7A["#'X<[MQ]''RB(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2
M:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("+'
MX<_FT2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@
M3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O
M=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM
M<V=S='(@(L?AS^;1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG
M(@IM<V=S='(@(M'3Q^')(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS
M9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD
M($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@
M3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B
M4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("+-W=D@Q^'.[<?1Q\HB"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B
M"FUS9W-T<B`BS=W9(,?ASNW'T<?*(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@
M(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E
M<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I
M;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@82!D871E(@IM<V=S='(@(L?.RM$@RN33[=X@Q^'*Q]'M
MSCHB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B
M4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E
M<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B
MQ\[*T2#*Y-/MWB#'X<K'T>W..B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`BS<_/(,?AS='FW2_'X='CYM(@
MQ^'*[2#*T>W/Y<<@P\_DQ^4N(.;CY"#+XR#MX]_D(.33SN7'YN'5WN7'(-;C
MY"#'X>35+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+'SLK1(,?A
MW>;'U>$@X>'*Q]'MSCHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`BQ\[*
MT2#*Y-/MWB#'X<K'T>W..B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE
M(&1E;&EM:71E<CHB"FUS9W-T<B`BQ\[*T2#'X=WFQ]7A(.'ARL?1[<XZ(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(L?.RM$@RN33[=X@Q^'FWLHZ(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(L7.RM$@S=[A[>0@X\KC
MQ\OA[>0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(L7.RM$@X=O*WR#'X>/=UN').B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")3
M96YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(L/1T^$@RM[1[=''\"#(X]3?
MX<D@S=7ARB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I
M9"`B4V5P=&5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G
M<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E
M<W-I;VYS(@IM<V=S='(@(LW=V2#'X<[MQ]''RB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O
M(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R
M(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+B(*;7-G<W1R("+'SLK1(,K-S^W+(,?AU=W-R2#FSNW'T<?*
M(,?AU,?4R2#'X</.T>PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX
M"B,L(&9U>GIY"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`BQ\[*T2#*S<_MRR#'X=7=
MS<D@YL[MQ]''RB#'X=3'U,D@Q^'#SM'L+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C
M871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO
M<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T
M<B`BQ^'DRNW,R2#'X>/.RM71R3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@
M;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N
M('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@
M(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@
M5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@
M(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I
M9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS
M9VED(")3:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E
M(@IM<V=S='(@(L7EX^$@Q^'5[<?DR2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3
M;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@
M(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R
M9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS
M9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+:Y.;'Y"#'X=KCX2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*
M;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN
M9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS
M9W-T<B`BQ<_.Q]$@S='FW2#.Q]7)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S
M(@IM<V=S='(@(L?3RNW1Q\\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,
M86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B
M4W1A;F1A<F0B"FUS9W-T<B`BP\SDS\DB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E
M(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I
M9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I
M9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`BVN3FQ^0@Q^':X^$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED
M(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G
M:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@
M(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(N'C(.W:R]$@VN'L(,?AX]/*X]H@)7,N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B
M:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED
M(")3=6)M:70B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*
M;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`BRN,@R.3,Q\TB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E
M9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K
M=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('=R;W1E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U
M9&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`BQ^'.X<?5R2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3
M=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I
M9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@
M(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3
M=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S<X"B,L(&9U>GIY"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(L?3
MRNW1Q\\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M
M92(*;7-G<W1R("+'X<?3XR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@
M(L?AQ]/C(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA
M;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z
M:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM
M<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P
M"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7
M:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@
M(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM
M<V=S='(@(L?AX=[((@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ
M,S0*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(L?AX=[((@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")4
M86)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M86EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A
M<F=E=#HB"FUS9W-T<B`BS<SC(,?AQ]/*SL_'XSHB"@HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*
M;7-G:60@(E1A<VMS(@IM<V=S='(@(L?AX^7CQ\HB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU
M;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM
M<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G
M:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED
M(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,S8*(RP@9G5Z>GD*;7-G:60@(E1E>'0B"FUS9W-T<B`BY-4@W=[8
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/
M;FQY(@IM<V=S='(@(N35(-W>V"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E
M>'0@86QI9VXB"FUS9W-T<B`BY-4@W=[8(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(LKC(,?A
MSM'FS"#(Y,S'S2X@/&)R("\^(-3?T<?P(.''T\K.S\?CW^,@Y=#'(,?AY-G'
MXRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@
M24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S
M"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G
M:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED
M("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A
M<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B
M(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*
M(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@
M=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L
M92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R
M8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R
M(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I
M<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T
M(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*
M(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4
M:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB
M)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A
M;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S
M=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T
M:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O
M9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("+MS,@@P^0@RM_F
MY"#ET.4@Q^'>[>/)(-'>XRXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T
M;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"B+AXR#MRN,@Q^':R^;1(-KA["#'X<C1
MY,?CS"#'X>/3RL[/XR#AQ=GEQ]$@Q^'1T\?&X2#CY"#DYMH@*"5S*2#6X^0@
MY-G'X]\N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R
M;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("+%Y"#CX=W'RB!03R#AX=O)("5S(-OMT2#CYLSFS\DB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y
M;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E
M96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@
M<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN
M8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T
M(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L
M;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED
M(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(N''
MRN;,SR##[<D@RMW6[>''RBXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N
M<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES
M=&5M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN
M9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@
M)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E
M<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R
M;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE
M87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D
M971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS
M9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,30U"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@
M82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B[<S((,/D(,K?YN0@Y=#E
M(,?AWNWCR2#1WN,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL
M("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P
M-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U
M>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M(@IM<V=S='(@(NW,R"##Y"#*W^;D(.70Y2#'X=[MX\D@T=[C+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92XB"FUS9W-T<B`B[<S((,/D(.W?YN0@Y=#'(,?AT=[C(,/?R-$@X^0@
MQ^'5W=$B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP
M:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP
M(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+MS,@@P^0@RM_FY"#ET.4@
MQ^'>[>/)(-'>XRXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G
M:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@
M9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`BQ^'AWL@B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM
M92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`BQ^'A
MWL@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@
M(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4;V=O(@IM<V=S='(@
M(L[1YLPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@
M(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O
M;F=A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G
M:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS
M9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M
M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K
M;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R
M:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I
M9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R("+:Y.;'Y"#'X<7DRM'D[<HB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T
M,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T
M<B`BVN3FQ^0@Q^'%Y,K1Y.W*(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A
M;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@
M(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I
M9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S@X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#ARMOM[=$@Q^'3X\?-[<?*(.'CX=T@5D93("5S
M+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N(@IM<V=S='(@(N''(,7CW\?D[<D@X<K;[>W1(,?AT^/'S>W'RB#A
MX^'=(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!T;R`E<RXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AX<7*U<?A(,CCSL_C
M(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM
M[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@
MX<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AX<7*U<?A
M(,CCSL_C(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S
M.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(N''(,7CW\?D[<D@X>'%RM7'X2#(X\[/XR!344PN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(N''
M(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V
M9G-R;V]T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BX<<@Q>/?Q^3M
MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9I;&4N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@
MQ]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BX<<@
MRN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T
M<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S
M+R5S+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP
M.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW
M.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2XB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V
M9G-R;V]T+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("+AQR#*YLS/(,7C
MW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#A
MWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,U,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!
MR2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-#0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V
M9G-R;V]T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S
M+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=
M(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`BX<<@RN;,
MSR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=
M(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`BX<<@RN;,SR#%
MX]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R
M("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T
M;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G
M<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@
M)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@
MQ]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./A
MW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7C
MW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G
M<W1R("+AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.S^,@4U%,+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@
M(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F
M86EL960I+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@
MX^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`BX<<@RN;,SR#%X]_'
MY.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E
M860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)
M(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,CDS"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@
M=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*
MV^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S0S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)
M(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#A
MRMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D
M[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T
M<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S
M+R5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O
M8W5M96YT(@IM<V=S='(@(MOMT2#>Q\_1(-KA["#*T<SCR2#CT\KDSR#'X>;1
MSR#ET,<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'
MT^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*
M;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!6
M1E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#
M:&%N9V5S(@IM<V=S='(@(LK1Q\S:(-KD(,?ARMOM[=''RB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8Q"B,L(&9U>GIY"FUS9VED(")5;F9I;&5D(@IM<V=S='(@
M(MW4X2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC
M;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N
M:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*(RP@9G5Z
M>GD*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(L[8PR#=[2#'T^,@Q^'CT\K.S^,@YB_#YB#?X>/)(,?AT]$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC
M+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+'X<?3XR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@
M(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S
M;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z
M:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C
M<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G
M:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B
M57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S
M92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED
M(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(L?3
MXR#'X>/3RL[/XR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T
M(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@
M(E5S97(@3W!T:6]N<R(*;7-G<W1R("+.[<?1Q\H@Q^'CT\K.S^,B"@HC.B!S
M:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO
M;B(*;7-G<W1R("+.[<?1Q\H@Q^'CT\K.S^,B"@HC.B!S:6=N=7`N<&AP.C(R
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM
M<V=S='(@(L?3XR#'X>/3RL[/XR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N
M86UE.B(*;7-G<W1R("+'T^,@Q^'CT\K.S^,B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHX"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM
M<V=S='(@(L?3XR#'X>/3RL[/XR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R
M>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")6
M97)S:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T
M:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N
M86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@
M87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I
M9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A
M9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I
M9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z
M,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*
M;7-G<W1R("+*Y,CMY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E
M8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")7
M96%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(E=E96ML>2(*;7-G<W1R("+#T\CFVNW'\"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM
M<V=S='(@(L/EX<<@YM/EX<<@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+#Y>''(,C?
MXR#%X>P@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`BP^7AQR#FT^7AQR`E<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/R(*;7-G<W1R("+CQR#'X<C1Y,?CS"#'X>/*T=8@VM'6Y2#C
MY"#EYM'/[2#(VL\@Q^'/SN;AOR(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA
M<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*
M;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I
M9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@
M=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*
M;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M,@HC+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(LKDR.WE.B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@
M(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S
M<R(*;7-G<W1R("+:Y.;'Y"#'X=KCX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS
M9W-T<B`BY<?*W2#'X=KCX2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE
M("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@
M=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM
M<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X
M=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(EE9(@IM<V=S='(@(M/DR2`M(-?7(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")9
M65E9(@IM<V=S='(@(M/DR2`M(-?7(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(M/DYNW'\"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*
M;7-G<W1R("+DVN,B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*
M;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(LKC(,K-S^W+(,?A
MSNW'T<?*(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I
M9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@
M=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT
M-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ
M,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(NW,
MR"#4T<T@Q^'CU-_AR2#>R.$@Q]'3Q^$@RM[1[=''\"#(Y<<N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU
M<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW
M,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(L?DRN7*
M(-7AQ\WMR2#'X<?*U<?A("5S+B#'X=',Q\$@Q=K'S\D@Q^'/SN;A+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U>GIY"FUS
M9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`BVN3FQ^0@R-'MS]\@
MQ^'%X=_*T>;D[3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"B,L
M(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(MKD
MYL?D(,C1[<_?(,?AQ>'?RM'FY.TZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED
M(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(LCMQ^3'RM\Z(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("+'T^/?.B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI
M<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O
M('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M("+*XR#*S<_MRR#'X<[MQ]''RB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB
M"FUS9W-T<B`BQ^'*S=[>(,?AQ]W*T<?6[2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*
M;7-G<W1R("+'T^/?.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P
M,#`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM
M<V=S='(@(LKC(,K-S^W+(,?ASNW'T<?*(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@
M<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("+*XR#*S<_MRR#'X<[MQ]''RB(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(LKC(,K-
MS^W+(,?ASNW'T<?*(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R
M96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M
M(%)E<&]R=%TB"FUS9W-T<B`B6\K>T>W1(,?AX]3?X<E=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B
M6\?AT]C1("5S(./D("5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34W
M"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM
M<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED
M(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@
M(L?AX]/'VL_)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(L_.YN$B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U
M>GIY"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("+.T>;,(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS
M9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P
M=&EO;G,B"FUS9W-T<B`BSNW'T<?*(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS
M9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY
M"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`BQ=+AR2#'X<ODQ\;M
M(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ
M>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(L_=RM$@VN3'YNWD(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R("+#S.3/R2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A
M;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI
M8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED
M(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D
M871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(MOMT2#CYLSFSR(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U
M-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R("+=U.$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L
M:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*
M;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM
M<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I
M9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI
M;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I
M9"`B;F%M92(*;7-G<W1R("+'X<?3XR(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@
M(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO
M;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P
M"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@
M9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R("+*Y,CMY2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E
M('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED
M(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F
M(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B
M=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F
M=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(M_A(,_.YN$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")U;FEF:65D
M(@IM<V=S='(@(MW4X2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP
M:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(G5N;F%M960B"FUS9W-T<B`BQ^''T^,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B
M=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE
M<BYC;VTB"FUS9W-T<B`B(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O8F=?
M0D<N<&\`````````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#8T,S<Q,0`Q,#0Q-S,V,S`P,0`P,38S,S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!"=6QG87)I86X@=')A
M;G-L871I;VYS(&9O<B!(;W)D92!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@
M,C`P,B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D
M('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N
M"B,@36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^+"`R,#`R
M+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D92`S+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTQ,2TQ
M.2`R,#HT-"TP-3`P7&XB"B),87-T+51R86YS;&%T;W(Z($UI<F]S;&%V(%!E
M;F1E=B`\;6ER;T!C>6)E<G-H861E+G5S/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0U`Q,C4Q7&XB
M"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@Y.WH(.W@Y^#D*2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*"5S(.3MZ"#MX.?@Y"DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O
M9&%Y*2(*;7-G<W1R("(@*.3MY?$I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D
M87DI(@IM<V=S='(@(B`HXO?E\.`I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A
M="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN
M(@IM<V=S='(@(B<E<R<@[>4@Y2#J[NWTZ./S\.CPX.T@XB!(;W)D92!296=I
M<W1R>2XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,GX>7XY2#D[N'@XN7MX"#J^NP@
MX_#S[^CRY2XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#AY?CE(.3N
MX>#BY>T@ZOKL(/'H\?+E[.#RX"#GX"#O\.#BX"#MX"#O[O+PY>'H\N7KZ/+E
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S)^WE(.'E^.4@\?KG
MY.#DY>TZ("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2#'X.'EZ^7F
MZN`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(,[A
M\>OSYN+@^>@@[N_E\.#VZ.@@+2#/[O+B^O#FY.7MZ.4B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!4
M97)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@T_'K[N+H_R#O[B#1[^[P
MX.?S[.7MZ.7R[B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BR.?AY?#E\N4@[N_E\.#V
MZ.CRY2P@ZN[I\NX@Z/'JX/+E(.3@(.CGXOKP^.CRY2#QY>/@+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@[>7NX?7NY.CL(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`BPO'EZN@@-2#LZ.WS\N@B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(NWE(.'E^.4@[>#LY?#E[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O
M("5S(&]F("5S(@IM<V=S='(@(EOKZ.WH_R`E<R#N\B`E<UTB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`BP.3PY?'E[2#A
MY>OEYNWHZB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S
M='(@(LK@Z^7MY.#P(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*
M;7-G<W1R("(E<R`M(,?@X>7KY>;JX"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S[>#LY?#E[3HE<R`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA
M>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F
M(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T
M:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L
M(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M
M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q
M,B!(;W5R($9O<FUA="(*;7-G<W1R("+([?3N\.S@]NC_(.?@(,+@\2(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U
M<B!&;W)M870B"FUS9W-T<B`BR.WT[O#LX/;H_R#GX"#"X/$B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T
M<B`B,C0@]^#QX"(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*
M;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B/&(^S>7O\.7NY.[KZ.S@(./P
MY?CJX#H\+V(^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+'X"#DX"#J\.CO\NCPX/+E(._H
M\>SN(.4@[>7NX?7NY.CL(._SX>OH]^7M(%!'4"#JZ_[W+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(L?@(.3@(._P[N+E\.CRY2#O[N3OZ/'@[>X@[^CQ[.X@
MY2#MY>[A]>[DZ.P@4$=0(.KK_O<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(L?@(.3@(.3E
MZO#H[_+H\.#RY2#OZ/'L[B#QX"#MY>[A]>[DZ.SH.B#O\^'KZ/?E[2#JZ_[W
M+"#KZ/?E[2#JZ_[W(.@@ZNO^]^[BX"`B"B+T\.#GX"XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB
MQ^`@Y.`@[^[D[^CXY?+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M
M(.KK_O<L(.OH]^7M(.KK_O<@Z"#JZ_[W[N+@("(*(O3PX.?@+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"B,L(&9U>GIY"FUS
M9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B(@HBQ^`@Y.`@Y.7J\.CO\NCPX/+E(._H
M\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(%--24U%(.KK_O<L(.OH]^7M
M(%--24U%("(*(NKK_O<@Z"#JZ_[W[N+@(/3PX.?@+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"B,L(&9U>GIY"FUS9VED("(B
M"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G
M92XB"FUS9W-T<B`B(@HBQ^`@Y.`@[^[D[^CXY?+E(._H\>SN(/'@(.WE[N'U
M[N3H[.@Z(._SX>OH]^7M(%--24U%(.KK_O<L(.OH]^7M(%--24U%(.KK_O<@
MZ"`B"B+JZ_[W[N+@(/3PX.?@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(L?@(.3@
M(.KPZ._RZ/#@\N4@[^CQ[.X@Y2#MY>[A]>[DZ.P@[_/AZ^CWY>T@4TU)344@
MZNO^]RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@
M(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N
M+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G
M:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(LCM].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(L_N\N+Z\.3E\N4@[^#P[NO@\N`B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U
M;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,S"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@
M(LSN__+@(,_N^>`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@
M(D%D9"(*;7-G<W1R("+$[N'@XNKH(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*(RP@9G5Z>GD*;7-G:60@(D%D9"!#
M:&EL9"!'<F]U<"(*;7-G<W1R("+$[N'@XO_MY2#MX"#M[N+@(./P\^_@(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDY"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI
M;&0@4&5R;6ES<VEO;B(*;7-G<W1R("+$[N'@XO_MY2#MX"#M[N+H(._PX.+@
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!(97)E.B(*;7-G<W1R("+`Y/#E\2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W
M($=R;W5P(@IM<V=S='(@(L3NX>#B_^WE(.W@(.WNXN`@X_#S[^`B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*
M;7-G<W1R("+$[N'@XO_MY2#MX"#M[N+H(._PX.+@(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S
M='(@(L3NX>#BZ"#MX/'KY>3E[>`@X_#S[^`@ZOKL("<E<R<B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B
M"FUS9W-T<B`BQ.[AX.+H(.W@\>OEY.7MZ"#O\.#BX"#J^NP@)R5S)R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS
M9W-T<B`BQ.[AX.+H(.WNXB#O[O+PY>'H\N7K.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU
M;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(L3NX>#BZ"#M[N(@]^OE[2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z.34*(RP@9G5Z>GD*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(L3N
MX>#BZ"#PY>?^[.4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A
M9&1R97-S(&)O;VLZ(@IM<V=S='(@(L3NX>#BZ"#J^NP@[.[_\N`@X.3PY?'M
MX"#J[>CCX#HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`BQ.[AX.+H(.KZ["#L[O_RX"#@Y/#E\>W@(.KMZ./@.B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")!9&0@=7-E
M<B(*;7-G<W1R("+$[N'@XN@@[>[B(._N\O#EX>CRY>LZ(@H*(SH@861M:6XO
M=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E
M<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@
M<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I
M9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+$[N'@XO_M
MY?+N(.W@(._N\O#EX>CRY>OH(.4@Y^#A\.#MY>WN+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(L#D\.7Q
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(L#D\.7QY>T@X>7KY>;MZ.HB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,B"FUS9W-T<B`BT.7DX.KVZ/\@[>`@[_#@XN#RX"#GX"`G)7,G(@H*
M(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L#D[.CM
MZ/'R\.CPX.WE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM
M<V=I9"`B061S(@IM<V=S='(@(L3NX>#BZN@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY
M"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*(RP@9G5Z>GD*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`BS_'EXN3N[>CL
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M-PIM<V=I9"`B06QI87,B"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F
M=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B
M06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(L+QZ/?JZ"#C\//OZ"(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(L+QZ/?JZ"#O\.#BX"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F
M;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*
M;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D
M<F5S<R(*;7-G<W1R("+"X/CH_R!%;6%I;"#@Y/#E\3HB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(L+ZXN7DY>W@
M\N`@\?+NZ>WN\?(@[>4@Y2#D[N_S\?+H[.`N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B[>7O\.7NY.[KZ.S@(./P
MY?CJX#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*
M;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG
M=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HV"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R
M("+"X.K@[?;H_R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@HC+"!F
M=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("+-X.SE\.7M
MZ"#O\.CK[N;E[>C_.B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@
M=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM
M<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@
M(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B
M"FUS9W-T<B`BT.#G[.7P(.W@(.#P]>CB[>C_(/3@Z>LB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S
M='(@(LCLY2#MX"#@\/7HXN`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C$P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("+1Z./S\.WH(.OH(/'RY2P@]^4@
MZ/'JX/+E(.3@(.CG\O#HY?+E("<E<R<@Z"#B\>CWZN@@[^[D[_#@XN`_(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B
MT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQZN#RY2#DX"#HY_+PZ.7RY2`G)7,G(.@@
MXO'H]^KH(._NY./P\^_H/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE
M;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\B"FUS9W-T<B`BQ.`@\>4@Z/'JX"#KZ"#O[O+B^O#FY.7MZ.4@[_#EY.@@
M[N'QZ_/FXN#YZ/+E(.[OY?#@]NCH/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`BP_#E^.K@
M(._PZ"#HY_+PZ.+@[>4@[>`@[>7Q^OGE\?+B\^+@^>`@X_#S[^`N(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BP_#E
M^.K@(._PZ"#HY_+PZ.+@[>4@[>4@[>7Q^OGE\?+B\^+@^>@@[_#@XN`N(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(/#EY.#J\NCPX.WE(.W@(.WE\?KYY?'RXO/BX/GH(._PX.+@+B(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PHC+"!F=7IZ>0IM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G
M<W1R("+#\.7XZN`@[_#H(/#EY.#J\NCPX.WE(.W@(.WE\?KYY?'RXO/BX/GH
M(._PX.+@+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED
M(")!='1R:6)U=&5S(@IM<V=S='(@(L#R\.CA\_+H(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@
M(D%U9W5S="(*;7-G<W1R("+!^N/NXN4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS
M9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P
M+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L
M92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED
M(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*
M;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.3E[?+H].CJX/;H_R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960N("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.3E[?+H].CJX/;H
M_R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N
M(@IM<V=S='(@(LCDY>WRZ/3HZN#VZ/_RX"#AY?CE(.[R]>+Z\.OE[>`@[O(@
M4D%$2553(/'Z\.+Z\.`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-3$*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CDY>WRZ/3HZN#V
MZ/\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY
M"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(L+P^N?JX/+@(/'Z\2!&5%`@\?KPXOKPX"#QY2#O\.[B
MX.OH+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@
M(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(LW@Z^CW[>@@[^[KY?+@.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S
M"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O
M<R!P87-S=V]R9"XB"FUS9W-T<B`BS>7BX.OHY.W@(&ME<F)E<F]S("#OX/#N
MZ^`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I
M9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("+-Y>+@Z^CD[>X@
M:V5R8F5R;W,@[^[R\.7AZ/+EZ_'J[B#H[.4N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS
M9VED(")"86AR86EN(@IM<V=S='(@(D)A<F)I92(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U
M>GIY"FUS9VED(")"96QI>F4B"FUS9W-T<B`BT.#G[.7P(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`BT.[FY.7M(.3E
M[2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O
M9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+1Z_/X
MX/+EZ__R("5S(.WE(.4@[>#LY?#E[2XB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B
M0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`BT^3E
MX>7KY>WH(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K
M;6%R:W,B"FUS9W-T<B`BSO+LY?+JZ"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@
M(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE
M<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD
M($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L
M(&9U>GIY"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")"<F]W;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM
M<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM
M<V=I9"`B0G)A>FEL(@IM<V=S='(@(L_N^>`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*(RP@
M9G5Z>GD*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`BS^[D\.7DY>T@
M\>_H\?KJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM
M<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L
M;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C
M;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX
M-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE
M;F1A<B(*;7-G<W1R("+*X.OE[>3@\"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#8*(RP@9G5Z>GD*;7-G:60@(D-A;&TB"FUS9W-T<B`B
MSO+JX.;H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W
M<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#QXOKP
MY^+@[>4@\2#LY>GK(/'Z\.+Z\#H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E
M;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(LK@Z^7MY.#P(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BSO+JX.;H(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0
M<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L
M971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#
M86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#E[.#UXN#M
MY3L@*"5S*2#BY??E(/'Z^>7Q\N+SXN`B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HV.#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(._PY>S@]>+@[>4[("@E<RD@XN7WY2#Q^OGE\?+B\^+@(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED
M("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G
M92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*
M;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BSN_VZ.@B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G
M:60@(D-A<G)I97(B"FUS9W-T<B`B0F%R8FEE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`BS.[AZ.OE[2#R
MY>OE].[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S
M(@IM<V=S='(@(LSNX>CKY>T@\N7KY?3N[2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I
M;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"B,L(&9U>GIY"FUS9VED
M(")#96QL<&AO;F4B"FUS9W-T<B`BS.[AZ.OE[2#RY>OE].[M(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM
M,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D-E;G1E<B(*
M;7-G<W1R("+6Y>WR\.CPX.TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y
M+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS
M9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A
M=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY
M"FUS9VED(")#:&%D(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D]R86YG92(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM
M<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BS^[RXOKPY.7R
MY2#OX/#NZ^#RX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*
M(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W
M"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U
M"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R("+TX.GK(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I
M9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM
M<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BS^[RXOKPY.7RY2#O
MX/#NZ^#RX"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO
M;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(M'K\_C@\N7K__(@)7,@[>4@Y2#MX.SE\.7M+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED
M(")#;&5A<B(*;7-G<W1R("+*X.OE[>3@\"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F
M:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("+/\.7LX/7MZ"#O
M[O+PY>'H\N7K.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B
M0VQE87(@=7-E<B!D871A(@IM<V=S='(@(LCGX>7PZ"#O[O+PY>'H\N7K(.?@
M(.3NX>#B_^WE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G
M:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B
M0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K
M97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*
M(RP@9G5Z>GD*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+'X/+B[O#H
M(._P[N?N\.7V(%PBS^[L[OE<(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(LKN
M[^CPX.DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS
M9VED(")#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`BR.?AZ/#@
M[>4@[>`@]N+_\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*
M;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O
M;',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@
M(LKN[.CJ\>@B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*
M;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`BRN[LX.WDZ#HB"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`BRN[LX.WDZ#HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B
MRN[LX.WDZ#HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*(RP@9G5Z>GD*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`BRN[LZ.KQZ"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*
M;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"B,L(&9U>GIY
M"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D-O;F1I
M=&EO;G,B"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF
M9F5R96YC97,B"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN
M8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"B,L(&9U>GIY
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R
M("+*[NWTZ./S\.#VZ/\B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS
M9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M("+/[O+B^O#DY?+E(._@\.[KX/+@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N
M9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BPO#ZY^K@\N`@\?KQ
M($944"#Q^O#B^O#@(/'E(._P[N+@Z^@N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960Z("(*;7-G<W1R("+"\/KGZN#RX"#Q^O$@1E10(/'Z\.+Z
M\.`@\>4@[_#NXN#KZ"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BQ.[Q\OKOX"#D[B#O\^'KZ/?MZ/\@
M\?KPXOKP(.'E^.4@[O+JX.?@[2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A
M<V]N.B`E<R`H)7,I(@IM<V=S='(@(L3N\?+Z[^`@Y.X@[_/AZ^CW[>C_(/'Z
M\.+Z\"#AY?CE(.[RZN#GX.TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-#4*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(L+P^N?JX/+@(/'Z\2!&5%`@\?KPXOKP
MX"#QY2#O\.[BX.OH+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T
M"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D-O
M;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R("(B"B+2Y>?H(.3@[>WH(.?@(.KN[?+@ZO(@X?_U
MX"#S\>_E^.WN(.3NX>#BY>WH(.KZ["#"X/C@\N`@[_#NX_#@[.`N(,KKZ.KM
MY?+E(._N+2(*(N3NZ_,@Y^`@Y.`@XNCDZ/+E.B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`BT?KD^O#FX.WHY2#MX"`G)7,G
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(LKN[^CP
MX.DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@
M(LCL[^[P\NCPX.WN(._NZ^4Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R
M>7!T(&UE<W-A9V4N(@IM<V=S='(@(L/PY?CJX"#O\.@@4$=0(.KPZ._RZ/#@
M[>7R[B#MX"#OZ/'L[BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB
M"FUS9W-T<B`BP_#E^.K@(._PZ"!01U`@[^[D[^CQXN#MY?+N(.W@(._H\>SN
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92XB"FUS9W-T<B`BP_#E^.K@(._PZ"!334E-12#J\.CO\NCPX.WE\NX@[>`@
M[^CQ[.XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT
M-C<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+B(*;7-G<W1R("+#\.7XZN`@[_#H(%--24U%(._NY._H\>+@[>7R[B#M
MX"#OZ/'L[BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@
MY.`@\>4@ZN[OZ/#@("5S(/+N("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C$R,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#N\?KYY?'RXN@@
MXO#ZY^K@(/$@3$1!4"#Q^O#B^O`N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A
M<"!S97)V97(B"FUS9W-T<B`BP_#E^.K@(._PZ"#O[NOS]^#BX.WE\NX@[>`@
M[_/AZ^CW[>C_(.KK_O<@[O(@ZNO^]RWQ^O#B^O#@+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N
M8V4N("5S(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@
M\NX@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS
M9W-T<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(%--0B#Q^O#B^O`N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB
M('5S:6YG($944#H@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@
M\2!24$,@\?KPXOKP.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("+#\.7XZN`@[_#H(/'ZY^3@XN#MY2#MX"#K[NK@Z^W@(.3H\.7J
M\N[PZ/\@Y^`@Z^[JX.OHY^#VZ/\@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T82XB"FUS9W-T<B`BP_#E^.K@(._PZ"#DY>KPZ._RZ/#@[>7R[B#M
MX"!01U`@Y.#M[>@N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU,C(*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+B(*;7-G<W1R("+#\.7XZN`@[_#H(.3EZO#H[_+H\.#MY?+N
M(.W@(%--24U%(.3@[>WH+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(LWE
MXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@\NX@)7,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S
M971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@
M(LWEZN[PY>KRY>T@96UA:6P@X.3PY?$@[>`@[^[K\_?@\N7K_RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`BS>7J[O#EZO+E[2!E;6%I;"#@Y/#E\2#MX"#O
M[NOS]^#RY>O_+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T
M:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(LWEXOKG[.[F
M[>[Q\B#DX"#QY2#J[N_H\.`@)7,@\NX@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+B(*;7-G<W1R("+#\.7XZN`@[_#H(._NZ_/WX.+@[>7R[B#MX"#O\^'KZ/?M
MZ/\@ZNO^]R#N\B#JZ_[W+?'Z\.+Z\.`N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@
MY.`@\>4@ZN[OZ/#@("5S(/+N("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(LWEXOKG
M[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@\NX@)7,N(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,B"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.[RXN[PZ"#.X?'K
M\^;BX/GH7^?@Y.#WZ"#L[N3SZR`E<R`B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#Q
MY2#J[N_H\.`@)7,@\NX@)7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@[O'Z^>7Q\N+H(.+P^N?J
MX"#Q($Q$05`@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C
M="YP:'`Z,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5A9"`E<RXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.KN[^CP
MX"`E<R#R[B`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX
M-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@
M=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(LWEZN[PY>KRY>T@96UA
M:6P@X.3PY?$@[>`@[^[K\_?@\N7K_RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B2&]R9&4@[>4@Y2#J[NWTZ./S\.CPX.T@ZN[PY>KR[>XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(LWE[N'U
M[N3H[.C_("=P;W)T)R#MY2#E(.?@Y.#DY>T@XOKB(%9&4R#J[NWTZ./S\.#V
MZ/_RX"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T
M('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(LWEXOKG[.[F[>[Q
M\B#DX"#QY2#N\?KYY?'RXN@@XO#ZY^K@(/$@3$1!4"#Q^O#B^O`N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._P
MZ"!01U`@[^[D[^CQXN#MY?+N(.W@(._H\>SN+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S
M(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@\NX@)7,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*
M;7-G<W1R("+#\.7XZN`@[_#H(/'ZY^3@XN#MY2#MX"#K[NK@Z^W@(.3H\.7J
M\N[PZ/\@Y^`@Z^[JX.OHY^#VZ/\@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R
M(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0HC+"!F=7IZ>0IM
M<V=I9"`B0V]U;G1R>2(*;7-G<W1R("+HY_#EYN@B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM
M<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"B,L(&9U>GIY"FUS9VED(")#
M<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(LCGX>7PY?+E(.WNXB#O\.CRY>;@
M\N7K(.W@(./P\^_@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("+/\.#B
MX"#O[B#O[N3PX.?AZ/#@[>4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#=7)R
M96YT(%-E<W-I;VYS(@IM<V=S='(@(L_PX.+@(.?@(./N\?+H(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED
M(")#=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R
M96YT(%523"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`BPN#X
MZ/+E(/'Z\.+Z\.@Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I
M9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`BZ.?P
MY>;H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$
M(@IM<V=S='(@(L3$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("+%YN7D[>7B[>XB"@HC.B!A
M9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM
M<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Y.0HC+"!F=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R
M("+$X.WMZ"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM
M<V=I9"`B1&%Y(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC+"!F=7IZ
M>0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`BR.?AY?#E\N4@ZN[K
M[NWH.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<V"B,L(&9U>GIY"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("+7Z^7M[N+E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*
M(RP@9G5Z>GD*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("+-X.S@
MZ^@@\^7D[>#JXO_BX.WE\NXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5F875L="(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F
M875L="!#;VQO<B(*;7-G<W1R("+(Y^_NZ^?BX.D@[^[D\.#GX>CPX/G@\N`@
M\>4@\?+NZ>WN\?(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(LCDY>WR
MZ/?M[O'R(._N(._NY/#@Y^'H\.#MY2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R
M("+(Y.7M\NCW[>[Q\B#O[B#O[N3PX.?AZ/#@[>4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G
M:60@(D1E;&5T92(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(LCG\O#HZ2(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`BR.?R\.CI(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@3&]G(@IM<V=S='(@(LCG\O#HZ2(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S
M='(@(L_PX.+@(._N(._NY/#@Y^'H\.#MY2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!C96QL(@IM<V=S='(@(LCG\O#HZ2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`BR.?AY?#E\N4@ZN[K[NWH
M.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*
M;7-G<W1R("+0Y>3@ZO;H_R#MX"#O\.#BX/+@(.?@("<E<R<B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(M'HX_/P[>@@Z^@@\?+E
M+"#WY2#H\>K@\N4@Y.`@Z.?R\.CE\N4@)R5S)R#H(.+QZ/?JZ"#O[N3O\.#B
MX#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@
M(LCG\O#HZ2(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI
M;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R("+(Y.7M\NCW[>[Q\B#O[B#O[N3PX.?AZ/#@[>4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED
M(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(LCG\O#HZ2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P
M"B,L(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("+/^NOM[B#N
M[^CQX.WHY3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM
M<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I
M9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`BQ.7RX.GKZ/+E(.'_]>`@\.7CZ/'R\.CPX.WH(.?@
M(.#D[.CMZ/'R\.#R[O#@+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN
M="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED
M(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM
M<V=S='(@(L3H\>_KY>D@SN_VZ.@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0B"FUS9W-T<B`BQ.CQ[^OEZ2#.[_;HZ"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`BQ.CQ[^OE
MZ2#.[_;HZ"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*
M;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B
M1&\@;F]T(&1E;&5T92(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H
M879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO
M860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R(*;7-G<W1R("+-Y>CGXN7Q\NW@(.KN[.#MY.`Z("5S(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D
M;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,T"B,L(&9U>GIY"FUS9VED(")$<G5G<R(*;7-G<W1R("+!^N/NXN4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*
M;7-G:60@(D4M36%I;"(*;7-G<W1R("+/[OG@(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O
M+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I
M9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T
M"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U
M861O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G
M<W1R("+0Y>3@ZO;H_R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP
M:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I
M="!";&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A
M9&UI;B]G<F]U<',N<&AP.C(R-@HC+"!F=7IZ>0IM<V=I9"`B161I="!'<F]U
M<"(*;7-G<W1R("+#\//OZ"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*(RP@
M9G5Z>GD*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("+/\.#BX"(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*(RP@9G5Z>GD*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+0Y>3@
MZO;H_R#MX"#O\.#BX/+@(.?@("<E<R<B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHU"B,L(&9U>GIY"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*
M;7-G<W1R("+0Y>3@ZO;H_R#MX"#O\.#BX/+@(.?@("<E<R<B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(M#EY.#J]NC_(.W@(._PX.+@\N`@Y^`@)R5S)R(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(M#EY.#J]NC_
M(.W@(._PX.+@\N`@Y^`@)R5S)R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-0HC+"!F=7IZ>0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(L+@ZN#M
M]NC_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B
M87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I
M9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*
M;7-G<W1R("+/Z/'L[B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B
M16UA:6P@061D<F5S<R(*;7-G<W1R("+%;6%I;"#@Y/#E\2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%;6%I;"#@Y/#E\>CRY2#R\/_AXN`@
MY.`@\?KB[^#DX/(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX
M.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS
M9W-T<B`BQ/#SX^`@Z.WT[O#LX/;H_R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@
M1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,CDX"B,L(&9U>GIY"FUS9VED(")%;6]T:6-O;G,B
M"FUS9W-T<B`BSN_VZ.@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE
M<W-A9V4N(@IM<V=S='(@(L_PX.?E[2#PY>?SZ_+@\BXB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%
M;7!T>2!R97-U;'0N(@IM<V=S='(@(L_PX.?E[2#PY>?SZ_+@\BXB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T
M>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT
M(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E
M($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C(Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H
M('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@
M(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@
M:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE
M='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q
M=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B
MP_#E^.K@(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ
M("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@
M86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM
M<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI
M;G5T97,B"FUS9W-T<B`BPO'EZN@@,34@[.CM\_+H(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU
M=&5S(@IM<V=S='(@(L+QY>KH(#4@[.CM\_+H(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED
M(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(L+QY>KH(#,P(/'EZO/MY.@B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("+"
M\>7JZ"`U(.SH[?/RZ"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(L+Q
M_^KN(.ONX^+@[>4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS
M9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BS>`@XO'EZN@@[^[K[N+H
M[2#WX/$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R
M("+"\?_JX"#LZ.WS\N`B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(L_PZ.SE\.WH
M(/'R[NGM[O'RZ#HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO
M8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*(RP@9G5Z
M>GD*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`BR.?O^NOM_^+@[>4@[>`Z(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED
M(")%>'!A;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E
M8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B
M17AP96-T960@)RDG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G
M:60@(D9'($-O;&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B
M"FUS9W-T<B`BR.?O\.#YX.WE\NX@[>`@].#IZ^[BY2#MY2#QY2#O[N3D^O#F
MX"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G
M:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("+-
MY>+ZY^SNYNWN\?(@Y.`@\>4@Y^#PY>3_\B#O\.7TY?#E[?;HZ/+E+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E
M(.[Q^OGE\?+BZ"#B\/KGZN`@\2!,1$%0(/'Z\.+Z\"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(L/PY?CJX"#O\.@@\>+Z\.?B
MX.WE(/'Z\2!334(@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C8Y,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(/'B
M^O#GXN#MY2#Q^O$@4TU"(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T
M;R!<(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@\>+Z\.?BX.WE(/'Z\2!3
M34(@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE
M=F4Z("5S(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#GX/#EY/_R(._P
MY?3E\.7M]NCH\N4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I
M9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(L/PY?CJX"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*
M;7-G<W1R("+4X.KQ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS9W-T<B`BU.#J\2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&
M96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@
M4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@
M0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R
M("+TX.GK(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("+!
M\.[I(/3@Z>ONXN4Z("5S(/3@Z>LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE<R(*;7-G<W1R("+!\.[I(/3@Z>ONXN4Z("5S(/3@Z>O@(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R
M(@IM<V=S='(@(M3@Z>L@[.7MX.;E\"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@U"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`BR.SE(.W@(/3@
MZ>LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&
M:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#@V"B,L(&9U>GIY"FUS9VED(")&:6QE('5P;&]A9"(*;7-G
M<W1R("+([.4@[>`@].#IZR(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(LCG[_#@^>#MY?+N(.W@(/3@Z>ONXN4@[>4@\>4@[^[DY/KP
MYN`N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&
M:6QT97)S(@IM<V=S='(@(M3HZ_+Z\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I
M;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM
M<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1
M=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q
M"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D
M;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B
M"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED
M(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0V,@HC+"!F=7IZ>0IM<V=I9"`B1F]R;7,B
M"FUS9W-T<B`BU.[P\^SH(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q
M"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(M3N\//LZ"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F
M=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BU.[P\^SH(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE
M<R`R(@IM<V=S='(@(M3N\//LZ"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("+4[O#S[.@B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"B,L(&9U>GIY"FUS9VED(")&
M;W)W87)D<R(*;7-G<W1R("+/\.7O\.#YX.WH_R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R("+4
M[O#S[.@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")&<F%N8V4B"FUS
M9W-T<B`B3W)A;F=E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D9R;VTB"FUS9W-T<B`B
MU.[P\^SH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F
M=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("+/^NOM[B#N
M[^CQX.WHY3HB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`BR.SE
M(.W@(/3@Z>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
MRN[M].CC\_#@]NC_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I
M9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")':&%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT
M87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S4*(RP@9G5Z>GD*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B
MR.SE(.W@(/3@Z>LB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM
M<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-
M87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*
M;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C
M86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")'
M<F5E8V4B"FUS9W-T<B`B1W)E96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'
M<F5E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D=R96YA9&$B"FUS
M9W-T<B`B1W)E96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4@
M[>`@X_#S[^@B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W
M"FUS9VED(")'<F]U<',B"FUS9W-T<B`BP_#S[^@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA
M;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,@HC+"!F=7IZ>0IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W)E>2(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(L_PX.+@(.?@(./N\?+H(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0W,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P
M+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")(5%10(.CDY>WRZ/3HZN#VZ/\@[>4@Y2#MX.SE\.7MX"XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DAA:71I(@IM<V=S='(@
M(LKNY?3H]NCE[?(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(
M87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"B,L(&9U>GIY"FUS9VED
M(")(96%D97(B"FUS9W-T<B`BQ^#CZ^#BZ/\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")(
M96%D97)S(@IM<V=S='(@(L?@X^O@XNC_(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED
M(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*
M;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(
M96QP(@IM<V=S='(@(L_N[.[Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC
M+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(L_N[.[Y(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`BS>#WX.ON(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS9VED(")(;VUE(@IM
M<V=S='(@(LW@]^#K[B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(L3N
M[.#XY>T@X.3PY?$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G
M:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO
M;F4B"FUS9W-T<B`BQ.[LX/CE[2#RY>OE].[M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS
M9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T
M>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@7"(E<UPB(@IM<V=S='(@(M/Q[^7X[>X@[_#E[.#U[>#R("<E<R<@[O(@
M\>CQ\N7LX/+@+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*
M;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET
M>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM
M<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(/'ZY^3@XN#MY2#M
MX"!)34%0(._N^>7M\>K@(.KS\NC_.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CB
MX.WE(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BP_#E^.K@
M(._N\.#DZ"#JXN[RX"#O\.@@\?KGY.#BX.WE(.W@($E-05`@[^[YY>WQZN`@
MZO/RZ/\Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC
M+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("+`Y/#E\2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*(RP@9G5Z>GD*
M;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@
MX.3PY?'@(.WE(.4@XB#O[N?B[NOE[>C_($-)1%(@X>ONZBXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))
M4"#@Y/#E\>`@[>4@Y2#B(._NY^+NZ^7MZ/\@0TE$4B#AZ^[J+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM
M<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,CD*(RP@9G5Z>GD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R
M("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC
M96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("+1X.SN(.CJ[NWH(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`BR.KN
M[>@@\2#RY>KQ\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G
M:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O
M<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E
M92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@
M;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H
M:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T
M;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("))
M;6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`BR.SO[O#RZ/#@[>X@[^[KY3H@
M)7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BR.SO
M[O#RZ/#@[>X@[^[KY3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(LCL[^[P
M\NCPX.WH(._NZ^7RX#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(DEN7W-E
M<G0@4F]W($%F=&5R(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I
M9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"XB"FUS9W-T<B`BS>7J[O#EZO+MX"#OX/#NZ^`@Z.OH(._N\O#E
MX>CRY>OQZNX@Z.SE(2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("+3XN7K
MZ/?@XN#MY2#MX"#SY>3MX.KB_^+@[>7R[B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G
M:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"B,L(&9U>GIY"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`BS>#O\.#BY>WN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G
M<W1R("+([?3N\.S@]NC_(.?@(,+@\2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH
M\N7K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED("));G-E<G0@26UA9V4B
M"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("+"[/KJ
M[>@@[^[D\.#B[>CRY>LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*
M;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@
M;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM
M<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@
M96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE
M=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM
M<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*(RP@9G5Z>GD*;7-G
M:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`BPNSZZNWH(._NY/#@
MXNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-O;'5M;B!B
M969O<F4B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R
M="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"B,L(&9U>GIY
M"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(L+L^NKMZ"#O[N3P
MX.+MZ/+EZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@8F5F
M;W)E(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM
M<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("))
M;G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U
M"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C$P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S
M='(@(LCG[_#@\N7MZ/+E(.3@[>WH(/'@(.WEXN#KZ.3MZ"XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,T"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M(&%P<&QI8V%T:6]N+B(*;7-G<W1R("+-X.SE\.7MZ"#O\.CK[N;E[>C_.B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS
M9W-T<B`BR.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A
M('-U8FUI='1E9"XB"FUS9W-T<B`BR.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7B
MX.OHY.WH+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(LCG[_#@\N7MZ/+E(.3@
M[>WH(/'@(.WEXN#KZ.3MZ"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@;7-G7W1Y<&4N(@IM<V=S='(@(LCG[_#@\N7MZ/+E(.3@[>WH(/'@(.WE
MXN#KZ.3MZ"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M("+(Y^_PX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D
M=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T
M;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS
M9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G
M:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM
M<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE
M(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G
M:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("+-
MX.KK[NWE[>@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY
M(@IM<V=S='(@(LW@ZNON[>7MZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M
M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P
M"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO
M=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA
M>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(R"B,L(&9U>GIY"FUS9VED(")*97)S97DB"FUS9W-T
M<B`B1W)E>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q
M"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S@*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`BZ__B[B#O
M[N3PX.+M_^+@[>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-0HC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF>2!#
M96YT97(B"FUS9W-T<B`BZ__B[B#O[N3PX.+M_^+@[>4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I
M9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(N_ZZ^WN(._NY/#@XNW_XN#MY2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BZ__B[B#O[N3P
MX.+M_^+@[>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R
M("+D__'M[B#O[N3PX.+M_^+@[>4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA
M>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"B,L(&9U>GIY"FUS9VED(")+96YY82(*
M;7-G<W1R("+'X.'PX.WH(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R#Q^O#B^O#@(.[R]>+Z\.OH
M(.CDY>WRZ/3HZN#VZ/_RX"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y
M($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3$*(RP@9G5Z>GD*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@
M(DUI;64@\NCO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("+(Y^_N
MZ^?BX.WE.CHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`BRNO^]^`@XN7WY2#Q^OGE\?+B\^+@(.(@[_/A
MZ^CW[>C_(.KK_O?Q^O#B^O`N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I
M9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+
M;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B
M2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER
M9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C@*(RP@9G5Z>GD*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`BR.?U[N0B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG
M=6%G92(*;7-G<W1R("+%Y^CJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("+/X/#NZ^`Z("(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B3&%S="!5<&1A=&5D
M.B(*;7-G<W1R("+.[_#E\>WH(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B
M3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"B,L
M(&9U>GIY"FUS9VED("),871V:6$B"FUS9W-T<B`BQ.#M[>@B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-SD*(RP@9G5Z>GD*;7-G:60@(DQA>6]U="(*;7-G<W1R("+(Y_7NY"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G
M:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I
M9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),969T
M('9A;'5E<R(*;7-G<W1R("+-_^S@(/'R[NGM[O'RZ"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`HC+"!F=7IZ>0IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("+,Y?+NY"(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5V96PB"FUS9W-T<B`BS>CJ[N/@(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@
M(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B3&EG:'0@0FQU92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS
M9VED("),:6=H="!286EN(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I
M;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B3&EG:'0@0FQU92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H
M="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB
M"FUS9W-T<B`BPO7NY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*
M;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B
M3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V
M"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES
M="!(96QP(%1O<&EC<R(*;7-G<W1R("+/[NSN^2#RY>SH(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G
M:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(
M96QP(@IM<V=S='(@(L_N[.[Y(/+E[.@B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I
M9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS
M9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C
M<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("+1[^CQ^NK@(/$@[^[R\.7AZ/+EZ^@@Y2#GX.'P
MX.WE[2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G
M<W1R("+1[^CQ^NK@(/$@[^[R\.7AZ/+EZ^@@Y2#GX.'PX.WE[2XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(M'OZ/'ZZN`@\2#O[O+P
MY>'H\N7KZ"#E(.?@X?#@[>7M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"B,L(&9U>GIY"FUS9VED
M("),;V%D:6YG+BXN(@IM<V=S='(@(N?@\.7FY.#MY2#MX"#AZ.'KZ.[RY>KH
M\N4N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS
M9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"B,L(&9U>GIY"FUS
M9VED("),;V-A=&EO;B(*;7-G<W1R("+"X.K@[?;H_R(*"B,Z(&QO9VEN+G!H
M<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R("+"]>[D(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BR.?U[N0B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM
M<V=S='(@(L+U[N0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"B,L
M(&9U>GIY"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("+'X.3@]^@B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A
M:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N
M=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDY,@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D
M+B(*;7-G<W1R("+O\.[BX.OE[>XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B
MR.?U[N0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*(RP@9G5Z>GD*
M;7-G:60@(DQO=F4B"FUS9W-T<B`BS_#E[.#U[>@B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM
M<V=S='(@(LS,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM
M<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&(._PZ.KPY>_E
M[>C_\B#TX.GK(.WE(/'ZY/KPYN#XY2#DX.WMZ"XB"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,W"B,L(&9U>GIY"FUS9VED(")-4T<B"FUS9W-T<B`B0TU3(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86-A;R(*;7-G<W1R("+"X.K@[?;H
M_R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@
M(L_N^>`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@
M(DUA:6PB"FUS9W-T<B`BS^[YX"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q
M"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(L_N^>`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(L_N^>`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(L_N^>`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*
M(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED
M(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@
M(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I
M;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("+1^N+OX.3@
M^>@@[^[KY?+@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B
M36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U
M<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS
M9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(M?KY>WNXN4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM
M<V=S='(@(L+HY"#MX"#LY>W^\NXZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B
MS^CQ[.XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M-@HC+"!F=7IZ>0IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S
M9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@
M8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(L_H\>SN\NX@X>7XY2#O\.[B
MY?#E[>X@\_'OY?CM[BP@[>X@\>7P\NCTZ.K@\N`@[>`@[^[D[^CQX"#MY2#A
MY?CE(._N\N+Z\.3E[2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@
M97AP:7)E9"XB"FUS9W-T<B`BS^CQ[.XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U
M>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`BS^CQ[.XB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(L3E\N#IZ^CRY2#A__7@
M(/#EX^CQ\O#H\.#MZ"#GX"#@Y.SH[>CQ\O#@\N[PX"XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO
M="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(LSE\N[D(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO
M4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`BS.7R
M[N0@)R5S)R#MY2#E(.3E].CMZ/#@[2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@
M9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R("+TX.GK(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DUI;64@5'EP92(*;7-G<W1R(")-:6UE(/+H[R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@
M(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A
M<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*(RP@
M9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R("+#\.7XZN`B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%10
M7U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I
M;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED
M(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"B,L(&9U>GIY"FUS9VED
M(")-;V1E<F%T92(*;7-G<W1R("+$X/+@(.W@(._P[NSE[?_MY2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E
M(@IM<V=S='(@(L3@\N`@[>`@[_#N[.7M_^WE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-
M;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@
M>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(LSE\>7W
M[>XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O
M=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I
M9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"B,L(&9U>GIY
M"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B[_#E[.7Q\N@@[>`@Y.[K\R_D
M__'M[B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q
M,PHC+"!F=7IZ>0IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(N_PY>SE\?+H
M(.W@(./N\.4OZ__B[B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C4Q-PHC+"!F=7IZ>0IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R
M("+O\.7LY?'RZ"#MX"#D[NOS+^3_\>WN(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3`U"B,L(&9U>GIY"FUS9VED(")-;W9E(%5P
M(@IM<V=S='(@(N_PY>SE\?+H(.W@(./N\.4OZ__B[B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G
M:60@(DUO=F4@9&]W;B(*;7-G<W1R("+O\.7LY?'RZ"#MX"#D[NOS+^3_\>WN
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T
M"B,L(&9U>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@(N_PY>SE\?+H(.W@
M(./N\.4OZ__B[B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS
M9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*
M;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("+,[O_RX"#/[OG@(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!
M8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@PN#Q
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@
M4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").
M3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BR.SE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE
M=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H
M97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V
M97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS
M9VED(").971W;W)K(@IM<V=S='(@(LSPY>;@(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B
M"FUS9W-T<B`BS>CJ[N/@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L
M961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G
M92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*
M;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T
M:6]N86PI(@IM<V=S='(@(LWNXNX@[^[R\.7AZ/+EZ_'J[B#H[.4@*.[O]NCN
M[>#K[>XI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@
M9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+/X/#NZ^`B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M
M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"B,L
M(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G
M<W1R("+-Y>KN\.7J\NW@(._@\.[KX"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?
M8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS9VED(").97=S(@IM<V=S='(@(L'E
MZ^7FZN@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"B,L(&9U
M>GIY"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(L/P\^_H(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT
M(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V
M"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`BSN_VZ.@B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X
M=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E
M<B(*;7-G<W1R("+-Z.KNX^`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L
M(&9U>GIY"FUS9VED(").:75E(@IM<V=S='(@(M'Z[N'YY>WHY2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@
M(DYO(@IM<V=S='(@(LWE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I
M9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I
M9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#O
MX/#NZ^`@Y^`@24U!4"#HY.7M\NCTZ.K@]NC_+B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS
M9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S
M:6]N+B(*;7-G<W1R("(G)7,G(.'E^.4@Y.[AX.+E[2#J^NP@\>CQ\N7LX/+@
M(.?@(._PX.+@(.W@(._N\O#EX>CRY>OH\N4N(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@ZN[M
M].CC\_#@]NC_(.?@(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("+-_^S@(.?@Y.#D
MY>W@(.KN[?3HX_/PX/;H_R#GX"!&5%`@5D93+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BS?_L
MX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,(%9&4RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!3
M44PM1FEL92!61E,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R
M."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(LW_[.`@
MY^#DX.3E[>`@Z^[JX.OHY^#VZ/\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G:60@(DYO
M(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@Z^[J
MX.OHY^#VZ/\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF
M:65D+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(.ONZN#KZ.?@]NC_+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W
M"B,L(&9U>GIY"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R
M("+-_^S@(.?@Y.#DY>W@(.ONZN#KZ.?@]NC_+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(._@\.[K
MX"#GX"!)34%0(.CDY>WRZ/3HZN#VZ/\N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-_^S@(.?@Y.#D
MY>W@(._@\.[KX"#GX"!)34%0(.CDY>WRZ/3HZN#VZ/\N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("+-_^S@(.?@Y.#DY>W@(._@\.[KX"#GX"!+97)B97)O<R#HY.7M\NCTZ.K@
M]NC_+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A
M;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(LW_[.`@ZN[M].CC\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@3$1!4"#HY.7M
M\NCTZ.K@]NC_+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@ZN[M].CC
M\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@4TU"(.CDY>WRZ/3HZN#VZ/\N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("+-_^S@(.KN[?3HX_/PX/;H[NWMX"#H[?3N\.S@]NC_(.?@(%--0B#H
MY.7M\NCTZ.K@]NC_+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B
M3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A
M('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L
M97,B"FUS9W-T<B`BS?_LX"#Q\N[I[>[Q\N@B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(DYO('-E<&%R871O
M<B!S<&5C:69I960N(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@Z^[JX.OHY^#V
MZ/\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B
MP>7KY>;JZ"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS
M9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C
M=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM
M<V=S='(@(LWEZN[PY>KR[>`@[^#P[NO@(.CKZ"#O[O+PY>'H\N7K\>KN(.CL
MY2$B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I
M9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`BPOKP[>#R
MZ/+E(.3@[>WH(.WE(/'@(%A-3"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B
MS?_LX"#Q\N[I[>[Q\N@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P
M"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT
M:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R
M("+-X._PX.+E[>XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D
M:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*(RP@9G5Z>GD*;7-G:60@(DYO="!A
M(&1I<F5C=&]R>2(*;7-G<W1R("+1^N?DX.+@[>4@[>`@Y.CPY>KR[O#H_R`E
M<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M
M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS
M9W-T<B`BP>7KY>;JZ"(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V
M-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-C8U"B,L(&9U>GIY"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M("+(Y^_PX/G@[>7R[B#MX"#TX.GK[N+E(.WE(/'E(._NY.3Z\.;@+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`BP>7KY>;JZ"(*"B,Z
M('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L(&9U>GIY"FUS9VED
M(").;W9E;6)E<B(*;7-G<W1R("+7Z^7M[N+E(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S
M='(@(M?KY>WNXN4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U
M"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I
M9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E
M<B!O9B!R;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S
M<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(L[*(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q
M"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM
M<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*(RP@9G5Z>GD*;7-G:60@
M(D]F9FEC92(*;7-G<W1R("+(Y^KK+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU
M<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R
M9"(*;7-G<W1R("+/X/#NZ^`B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="XB"FUS9W-T<B`BS>7J[O#EZO+MX"#OX/#NZ^`@Z.OH(._N\O#E
MX>CRY>OQZNX@Z.SE(2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B
M3VUA;B(*;7-G<W1R("+"ZNLN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#
M;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P
M=&EO;G,B"FUS9W-T<B`BSN_VZ.@B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z
M,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(L[O]NCH(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM
M<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(L_NY/#EY.7M(/'OZ/'ZZB(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"B,L(&9U
M>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@
M[>4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM
M<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")/<F=A
M;FEZ:6YG(@IM<V=S='(@(D]R86YG92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R("+$\//CX"#H[?3N\.S@]NC_(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BS_#@XN`@[>`@[_#H\N7FX/+EZ_\B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@
M8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q
M.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0
M=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U
M>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!'
M4"!3:&5L;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")0
M32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@
M(E!-(%-U;B(*;7-G<W1R(")3=6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]3
M25@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Y"B,L(&9U>GIY"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@
M(E!'4"!3:&5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")086MI<W1A;B(*;7-G<W1R
M("+"[/KJ[>@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@
M3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R("+/X/#NZ^`B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A
M<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("+/X/#NZ^`Z("(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@
M(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(LW_[.`@ZN[M].CC\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@
M4D%$2553(.CDY>WRZ/3HZN#VZ/\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP
M"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`BS^#P[NO@.B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM
M<V=S='(@(L_@\.[KX#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(LWEZN[PY>KR[>`@[^#P[NO@+B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("+"[/KJ[>@B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W
M"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"B,L(&9U
M>GIY"FUS9VED(")0871H(@IM<V=S='(@(L+L^NKMZ"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(M#NZ_\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R
M8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HT.0HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(L3@(/'E(.CGXOKP^.+@\B#K
MZ"#NX?'K\^;BX/GH\N4@[N_E\.#VZ.@@[_#H(,+U[N0_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("+$X"#QY2#HY^+Z\/CB
MX/(@Z^@@[N'QZ_/FXN#YZ/+E(.[OY?#@]NCH(._PZ"#"]>[D/R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED
M(")097)M:7-S:6]N(@IM<V=S='(@(L_PX.+@(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N
M(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I
M;VX@1&5N:65D(@IM<V=S='(@(L_PX.+@(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(L_PX.+@(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4@[>`@[_#@XN#RX"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0HC+"!F=7IZ>0IM<V=I9"`B4&5R
M<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`BQ/#SX^`@Z.WT[O#LX/;H_R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS
M9VED(")0:&]N92(*;7-G<W1R("+2Y>OE].[M(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED
M(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@
M(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M(@IM<V=S='(@(LSNZ_\L(.+ZXN7DY?+E(.SE\>7V(.@@X^[DZ.W@+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"B,L
M(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.B(*;7-G<W1R("+,[NO_+"#B^N+EY.7RY2#LY?'E]B#H(./N
MY.CMX"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"B,L(&9U
M>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*
M;7-G<W1R("+,[NO_+"#B^N+EY.7RY2#LY?'E]B#H(./NY.CMX"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@
M=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+B(*;7-G<W1R("+,[NO_+"#B^N+EY.7RY2#LY?'E]B#H(./NY.CM
MX"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED
M(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B
M"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G
M<W1R("(B"B+,[NO_+"#O\.[WY?+E\N4@\>OEY.WH__(@\N7J\?(N("#"Z.4@
MTM#?P<+`(.3@(/'E(/'ZX^O@\>CRY2#Q(//QZ^[BZ/_RX"#GX"`B"B+HY^_N
MZ^?BX.WE(.W@(/'H\?+E[.#RX"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@
M=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*(RP@9G5Z>GD*;7-G:60@(E!O;&%N9"(*;7-G<W1R("+3Y.7AY>OE[>@B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*
M;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@
M(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B
M4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*(RP@9G5Z>GD*
M;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`BS^#P[NO@.B`B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@
M(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E
M=FEO=7,@;W!T:6]N<R(*;7-G<W1R("+/\.7GY>WRX/;HZ"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R
M:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F
M=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("+/\.[AZ^7L/R(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C$R-@HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE
M;2!$97-C<FEP=&EO;B(*;7-G<W1R("+/^NOM[B#N[^CQX.WHY3HB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`BRNO^]^[BX"#DXN[IZN`@[_/AZ^CWY>TO]^#Q\N7M(.KK_O<@
M[>4@X>7XY2#CY>WE\.CPX.W@+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U
M97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*
M;7-G:60@(E%A=&%R(@IM<V=S='(@(L3@[>WH(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF
M;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B(*
M;7-G<W1R("+*[N7TZ/;HY>WR(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*
M;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@
M(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*
M;7-G<W1R("+*[N7TZ/;HY>WR(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`BU^7RY>WE(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@
M9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`BS^CQ[.XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`BR/'JX/+E(.3@(.CG\O#HY?+E
M("5S(.OH/R#2X.?H(.[OY?#@]NC_(.WE(.SNYN4@Y.`@\>4@XOKP[>4@[>#G
MX.0N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D
M871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+B(*;7-G<W1R("+(\>K@\N4@Y.`@Z.?R\.CE\N4@)7,@Z^@_(-+@Y^@@
M[N_E\.#VZ/\@[>4@[.[FY2#DX"#QY2#B^O#MY2#MX.?@Y"XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2
M961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM
M<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC
M+"!F=7IZ>0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B
MSN_PY?'MZ"#0Y>?^[.4@Z.?CZ^7DX#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED
M(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`BU^7R
MY>WE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*(RP@9G5Z>GD*;7-G
M:60@(E)E;6%R:W,B"FUS9W-T<B`BSO+LY?+JZ"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,30*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!397)V97)S
M(@IM<V=S='(@(L+@^.CRY2#Q^O#B^O#H.B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(L#D\.7Q(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`BS_#E[.#U[>@B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("+/\.7LX/7MZ"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`BS_#E[.#U[>@@\.7G
M_NSE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T
M<B`BR.WT[O#LX/;H_R#GX"#"X/$B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$R.`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T
M<B`BS_#E[.#U[>@@\.7G_NSE(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("+/\.7LX/7MZ"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("+/
M\.7LX/7MZ"#O[O+PY>'H\N7K.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@
M=7-E<CH@)7,B"FUS9W-T<B`BS_#E[.#U[>@@[^[R\.7AZ/+EZSH@)7,B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`HC+"!F=7IZ>0IM
M<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B`B"FUS9W-T<B`BS>`@Y^#OZ/+BX.WE\NX@[>4@X>7XY2#N
M\N/NXN[PY>WN.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34W"B,L(&9U>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N
M;W0@8F4@9F]U;F0N(@IM<V=S='(@(LW@(.?@[^CRXN#MY?+N(.WE(.'E^.4@
M[O+C[N+N\.7M[CH@(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(LWE[N'U[N3H[.C_("=P
M;W)T)R#MY2#E(.?@Y.#DY>T@XOKB(%9&4R#J[NWTZ./S\.#VZ/_RX"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BS>7NX?7NY.CLZ/\@)W!O<G0G(.WE(.4@Y^#DX.3E[2#B^N(@
M5D93(.KN[?3HX_/PX/;H__+@+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN
M<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`BS>7NX?7NY.CLZ/\@)W!O<G0G(.WE(.4@Y^#DX.3E[2#B^N(@5D93(.KN
M[?3HX_/PX/;H__+@+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY
M"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("+/X/#NZ^`B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("+/[O+B^O#DY?+E(._@\.[K
MX/+@(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R
M92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP
M.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W
M('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E
M=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")2
M979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B1$A434P@4FEC:"!4
M97AT(/#EY.#J\N[P(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS
M9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I
M9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3<*(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R("),:6=H="!";'5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("+0[NO_
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS
M9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS
M9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T
M<B`BT.[K_R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4G5N(@IM<V=S='(@(E-U;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")2=V%N9&$B"FUS9W-T
M<B`BU^7RY>WE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,R,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(L/PY?CJX"#O\.@@4TU)344@ZO#H[_+H\.#MY?+N(.W@(._H
M\>SN+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*(RP@
M9G5Z>GD*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY.7M\NCTZ.K@]NC_(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B
M4TU3($UE<W-A9VEN9R(*;7-G<W1R("+/Z/'L[B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!3:&5L
M;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-1
M3"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S
M='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"B,L(&9U>GIY"FUS9VED(")3
M7U%,(%-H96QL(@IM<V=S='(@(E-13"!3:&5L;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.
M979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU
M8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM
M<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A
M=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`BSN_PY?'MZ"`E<R(*"B,Z('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(E-A=F4@3W!T
M:6]N<R(*;7-G<W1R("+.[_;HZ"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*
M(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@
M(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM
M<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDW,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I
M;&5S(@IM<V=S='(@(LCGX>7PZ"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A
M(&1A=&4B"FUS9W-T<B`BR.?AY?#E\N4@\?KPXOKP(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O
M(&%D9"(*;7-G<W1R("+(Y^'E\.7RY2#C\//OX"#GX"#D[N'@XO_MY2(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A
M(&YE=R!O=VYE<B(*;7-G<W1R("+(Y^'E\.7RY2#M[N(@[_#H\N7FX/+EZR#M
MX"#C\//OX"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM
M<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(LCGX>7PY?+E(/'Z\.+Z
M\"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")3
M96QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("+(Y^'E\.@@[^[R\.7AZ/+E
MZR#GX"#D[N'@XO_MY2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&PB"FUS
M9W-T<B`BR.?AY?#H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M(@IM<V=S='(@(LCGX>7PY?+E(/3N\.S@\B#GX"#$X/+@\N`Z(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("+(Y^'E\.7RY2#M
M[N(@[_#H\N7FX/+EZR#MX"#C\//OX"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(LCGX>7PY?+E(.WNXB#O\.CRY>;@\N7K(.W@(./P
M\^_@(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS
M9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T
M:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HBR.?AY?#E
M\N4@[>7NX?7NY.CLZ/+E(,+H(/'H[.+NZ^@N(-'KY>0@\N[BX"#CZ"#J[N_H
M\.#I\N4@[O(@\N7J\?+NXN[R[B#O[NOE+B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.B(*;7-G<W1R("+(Y^'E\.7RY2#$X/+@(/#@Y^3EZ^CRY>LZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(LCGX>7PY?+E(/3N\.S@\B#GX"#$X/+@\N`Z
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM
M<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G
M<W1R("+(Y^'E\.7RY2#$X/+@(/#@Y^3EZ^CRY>LZ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M
M870Z(@IM<V=S='(@(LCGX>7PY?+E(/3N\.S@\B#GX"#7X/'@.B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+(Y^'E\.7RY2#DXN4@\?KB[^#D
MX/GH(._NZ^7RX#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS
M9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(LCGX>7P
MY?+E(.+@^.#RX"#Q]>7LX"#GX"#VXN7R[N+E\N4N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.B(*;7-G<W1R("+(Y^'E\.7RY2#O\.7D[^[WZ/+@[>C_\B#N
M\B#"X/$@Y>?HZCHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM
M<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@
M(E-E<'1E;6)E<B(*;7-G<W1R("+7Z^7M[N+E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N
M=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E
M<W-I;VX@061M:6XB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4@[>`@[_#@XN#R
MX"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS
M(@IM<V=S='(@(L_PX.+@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Q-`HC+"!F=7IZ>0IM<V=I9"`B4V5T(@IM<V=S='(@(LCGX>7PZ"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@
M=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V
M97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y
M;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED
M(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N(@IM<V=S='(@(LCGX>7PY?+E(._PY>3O[O?H\N#MZ/_R
M(.[R(,+@\2#EY^CJ.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM
M<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y
M(&]P=&EO;G,N(@IM<V=S='(@(B(*(L?@Y.#I\N4@PN#XY?+N(.W@]^#K[>X@
M[_#HZ^[FY>WHY2P@\?7E[.`@Y^`@]N+E\N[BY2P@[N_PY?'M_^+@[>4@[>`@
M(@HB\?+PX.WH]N#RX"#H(.3P\^/H(.[O]NCH(.?@(.3H\>_KY?\N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*
M;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I
M9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE
M;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@
M4W5M;6%R>2(*;7-G<W1R("+*\.#RZNX@\.7G_NSE.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*
M;7-G<W1R("+/[NK@Y^+@[>4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"B,L(&9U>GIY
M"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("+(Y^'H\.#MY2#MX"#VXO_R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@
M(E-H;W=E<G,B"FUS9W-T<B`BS^[JX.?BX.WE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I
M9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I
M;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S
M-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B
M4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3
M:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(M#@Y^SE\"(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R
M"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")3
M;F]W(@IM<V=S='(@(L_NZN#GXN#MY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W
M(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS
M9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I
M9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D
M<F5S<R(*;7-G<W1R("+!Z.?MY?$@X.3PY?$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G
M:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G
M:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*
M;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U
M"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A
M;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G
M:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(L+ZXN7FY.#M
MY2#MX"#Q[^7VZ.#K[>@@\>CLXN[KZ"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-@HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V]L
M=6UN(@IM<V=S='(@(LCGX>7PY?+E(.KNZ^[MZ#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3
M<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*(RP@9G5Z
M>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(B5S(-'RX.WDX/#R(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A
M='5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,34*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(LCM
M].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(L'HY^WE\2#@Y/#E\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I
M9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D
M9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,@HC+"!F=7IZ>0IM<V=I9"`B4W4B"FUS9W-T<B`B4W5N(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`BT>OS^.#RY>O_\B`E<R#MY2#E(.W@[.7PY>TN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PHC+"!F=7IZ>0IM<V=I
M9"`B4W5B:F5C="(*;7-G<W1R("+(Y^'E\.@B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`BR.?O\.#RZ"(*"B,Z('-I
M9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I<'0B
M"FUS9W-T<B`BR.?O\.#RZ"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+3\>_E
M]2(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(M/Q[^7X[>X@Y.[AX.+E[2`G)7,G(.KZ["#QZ/'RY>S@
M\N`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(M/Q[^7X[>X@[_#E
M[.#U[>#R("<E<R<@[O(@\>CQ\N7LX/+@+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*
M;7-G<W1R("+3\>_E^.WN(.CG\O#H\B`G)7,G+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
MT_'OY?CM[B#O\.7LX/7MX/(@)R5S)R#N\B#QZ/'RY>S@\N`N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB
M)7-<(B(*;7-G<W1R("+3\>_E^.WN(.'E^.4@[N'M[N+E[2`G)7,G+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@=W)O=&4@)7,B"FUS9W-T<B`BT_'OY?CM[B#AY?CE(.[A[>[BY>T@)R5S
M)RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3=61A;B(*;7-G
M<W1R(")3=6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S
M='(@(LKPX/+J[B#PY>?^[.4Z(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E-U;B!3970B"FUS9W-T
M<B`B4W5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-U;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*(RP@9G5Z>GD*;7-G
M:60@(E-U;G)I<V4B"FUS9W-T<B`B4W5N(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR
M:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I
M9"`B4W5N<V5T(@IM<V=S='(@(E-U;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G
M:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B
MX>7G(.CLY2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(N'EYR#H[.4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3
M>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E
M<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@
M(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R
M;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M].#IZR(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U
M>GIY"FUS9VED(")486)L92(*;7-G<W1R("+$Z_KF[>[Q\B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G
M:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@
M4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDU"B,L(&9U>GIY"FUS9VED(")487)G970Z
M(@IM<V=S='(@(LCG[^[KY^+@[>4Z.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B
M5&%S:W,B"FUS9W-T<B`BQ^#DX/?H(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E
M;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")496UP
M97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I
M9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+P
MZ/#@[>4@[>`@[^[R\.7AZ/+EZ^CRY2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@HC+"!F
M=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R("+1X.SN(/+EZO'R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S
M='(@(M'@[.X@\N7J\?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED(")497AT(&%L
M:6=N(@IM<V=S='(@(M'@[.X@\N7J\?(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO=2!F
M;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-
M4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO
M="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/
M<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI
M<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I
M9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@
M240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A
M<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*(RP@
M9G5Z>GD*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*(M+EY^@@Y.#M
M[>@@Y^`@ZN[M\N#J\B#A__7@(//Q[^7X[>X@Y.[AX.+E[>@@ZOKL(,+@^.#R
MX"#O\.[C\.#LX"X@RNOHZNWE\N4@[^XM(@HBY.[K\R#GX"#DX"#BZ.3H\N4Z
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@HBS_#HZO#E[^7MZ/_R(%!'4"#O[N3OZ/$@Y2#MY>[A]>[DZ.P@Y^`@Y.`@
M\>4@[_#NXN7PZ"#O[N3OZ/'@[>[R[B#OZ/'L[BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B
M87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`BRO#H[_+H\.#MY?+N(.CGZ/'JXN`@ZO#H[_+H\.#MX"!W96(@XO#Z
MY^K@+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,C@P"B,L(&9U>GIY"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B35,M5$Y%1B#O\.CJ\.7OY>WH__(@].#IZR#MY2#Q^N3Z
M\.;@^.4@Y.#M[>@N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B+,Y?'R[N_NZ^[FY>WHY?+N(.W@
M($=N=5!'(/3@Z>O@(/+P_^'BX"#DX"#A^N3E(.3@Y.7M;R#MX"!#<GEP=%]P
M9W`Z.B!C;&%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N
M("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA
M>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G
M92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@
M9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M
M97)I8RXB"FUS9W-T<B`BTN#GZ"#Q\N[I[>[Q\B#R\/_AXN`@Y.`@Y2#WZ/'K
M[BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*
M(RP@9G5Z>GD*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E
M9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@
M(LSNY//K^O(@3W!E;E-33"#E(.WE[N'U[N3H["#GX"!#<GEP=%]S;6EM93HZ
M(&-L87-S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*(L_P[N/PX.S@\N`L(.KN__+N(/'K\^;H(.?@(._N
MZN#GXN#MY2#MX"#R[N?H(/+H[R#DX.WMZ"`H)7,I(.WE(.'E^.4@[O+J\.CR
MX"`B"B+B(/'H\?+E[.#RX"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X
M"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@
M<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S
M<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B2&]R9&4@4$\@].#IZR#GX"#K[NK@Z^CGX/;H
M_R`E<R#MY2#Q^OGE\?+B\^+@.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@
M;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@
M=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E
M<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP
M.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92XB"FUS9W-T<B`BS?_LX"#DXN[IZN@L(.KNZ/+N(.3@
M(.'ZY.#R(._NZN#GX.WH(.(@Z^CMZ/_RX"XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("+-
M_^S@(.3B[NGJZ"P@ZN[H\NX@Y.`@X?KDX/(@[^[JX.?@[>@@XB#KZ.WH__+@
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*
M(LCLX"#RXOKPY.4@[.WNX^X@\>CLXN[KZ"#B(/+NXN`@[^[KY2X@POKBY>OH
M(/'RY2`E<R#QZ.SB[NO@.R#R\/_AXN`@Y.`@(@HBXOKBY>3E\N4@[^XM[.#K
MZNX@[O(@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Y.[AX.+_[>4@[>`@)R5S)R#J^NP@\>CQ\N7LX/+@+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("+#\.7XZN`@
M[_#H(._PY>S@]>+@[>7R[B#MX"`G)7,G(.[R(/'H\?+E[.#RX"XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;3H@(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#E[.#UXN#MY?+N(.W@
M("<E<R<@[O(@\>CQ\N7LX/+@+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@[N_P
MY?'M_^+@[>4@[>`@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@
MZ>O@.B`E<R#MY2#AY?CE(.CG[_#@\N7M+B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ
M92`H)60@8GET97,I+B(*;7-G<W1R("(B"B+([.#XY2#O\.[AZ^7L(._PZ"#H
MY^_PX/G@[>7R[B#MX"#TX.GKX"X@)7,@Y2#O[BWC[NO_["#N\B#LX.KQZ.S@
MZ^WN("(*(N3N[_/Q\NCLZ/\@\.#G[.7P("@E9"#AX.GRX"DN(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`N("5S(.'E
M^.4@\>#L[B#N\O?@\?+H(.CG[_#@\N7M+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#NXN7PZN#RX"#MX"#R[N+@(._H\>SN
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82XB"FUS9W-T<B`BP_#E^.K@(._PZ"#H[._N\/(@[>`@Y.#M[>@@
MY^`@ZN[M\N#J\N@N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP
M.C,Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`BP_#E^.K@(._PZ"#H
M[._N\/+H\.#MY2#MX"#HY^'PX.WH\N4@Y.#M[>@@Y^`@ZN#KY>WDX/`N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN
M9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E
M("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N
M=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J[NWRX.KRZ"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@HC
M+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#H[._N\/(@[>`@Y.#M[>@@Y^`@ZN[M
M\N#J\N@N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R
M("+2[N+@(.WE(.4@XN#KZ.3E[2!R87(@X/#UZ.(N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B
MTN[BX"#MY2#E(.+@Z^CDY>T@>FEP(/3@Z>LN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(M+N
MXN`@[>4@Y2#BX.OHY.7M(')A<B#@\/7HXBXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@
M;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I
M;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X
M,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`BTN[BX"#O[NOE(.4@[>7NX?7N
MY.CL[BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S
M='(@(M+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KPYN`@\>#L[B#VY>OH(/?H\>O@
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN(@IM<V=S='(@(M+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KPYN`@\>#L[B#W
MZ/'KX"#H(.3B[N7R[O?HY2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#DT"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("+2[N+@(._NZ^4@[.[FY2#D
MX"#Q^N3Z\.;@(/'@[.X@[>[LY?#@+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA
M(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@
M(M+NXN`@[^[KY2#R\/_AXN`@Y.`@Y2#GX._E\N#_(.CKZ"#H[?+E\.+@ZR#P
MX.?DY>OE[2#Q[^CQ^NH@[_#N[.7MZ^CBZ"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("+2X.?H(/'R[NGM[O'R(/+P
M_^'BX"#DX"#E(/?H\>ON+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L
M;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*
M(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N(@IM<V=S='(@(M+@Y^@@].[P[.`@XN7WY2#AY?CE(.[A\.#A
M[O+E[>`N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E
M('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("+2[N+@(/?H\>ON(/+P_^'BX"#D
MX"#E(._N[>4@Y>3H[>CVX"XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N
M8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("+2[N?H(/'Z
M\.+Z\"#MY2#L[N;E(.3@(.3EZN[L[_#E\>CPX"!Z:7`@Z"!G>FEP(/3@Z>ON
MXN4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS
M9W-T<B`BTN#GZ"#Q\N[I[>[Q\B#R\/_AXN`@Y.`@Y2#WZ/'K[BXB"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B
M"FUS9W-T<B`BQ.OZYNWN\?(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(L_P[O'KY>3_
MXN#MY2#MY2#B\.7LY2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I
M9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T
M<B`BQ.OZYNWN\?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*(RP@9G5Z
M>GD*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B`HY.WE\2DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G
M;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0HC+"!F
M=7IZ>0IM<V=I9"`B5&]G;R(*;7-G<W1R("+(Y_7NY"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W
M"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@
M9G5Z>GD*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("+/\.7GY>WRX/;H
MZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM
M<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1U<FME>2(*;7-G
M<W1R(")'<F5Y(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@
M(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C
M:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U
M<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G
M<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*
M;7-G<W1R("+/[N3WY?#RX.WH(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-#$R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@
M=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O
M<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R
M(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG
M\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q
M;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@(/$@4U%,(/'Z
M\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S
M='(@(LWEXOKG[.[F[>[Q\B#GX"#B\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("+-
MY>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@(/$@4U%,(/'Z\.+Z\"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@
M[^K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR-38*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BP_#E^.K@(._PZ"#W
MY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@
M[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`BS>7B^N?L[N;M[O'R
M(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("+#\.7XZN`@[_#H(.[RXN#P
M_^WE\NX@[>`@ZN[L[_#E\>CPX.T@X/#UZ.(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T
M<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!<(B5S7"(Z("5S+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G
M)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G
M<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HT,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,Y,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O
M;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E
M=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N
M<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#H
MXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#GX"#B\/KG
MZN`@\2!344P@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HY.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG
M\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB
M"FUS9W-T<B`BP_#E^.K@(._PZ"#N\N+@\/_MY?+N(.W@(.KN[._PY?'H\.#M
M(.#P]>CB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("+#\.7XZN`@[_#H(.[RXN#P_^WE
M\NX@[>`@ZN[L[_#E\>CPX.T@X/#UZ.(N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("+#\.7XZN`@[_#H(.[RXN#P
M_^WE\NX@[>`@ZN[L[_#E\>CPX.T@X/#UZ.(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I
M;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP
M.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS
M9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(L/PY?CJX"#O
M\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E
M[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,S(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG
M\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F
M<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@
M[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`BP_#E^.K@(._PZ"#O\.7B[N3@(.W@
M(/+NY^@@5V]R9"#D[NKS[.7M\B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X
M,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G
M:60@(E5N9&5R;&EN92(*;7-G<W1R("+/[N3WY?#RX.WH(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*
M(RP@9G5Z>GD*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(LWEXN#KZ.3E[2#N\N/NXN[P
M(.[R(/'Z\.+Z\.`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#0*(RP@9G5Z>GD*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z("(*;7-G<W1R("+-Y>+@Z^CDY>T@[O+C[N+N\"#N\B#Q
M^O#B^O#@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*(RP@9G5Z>GD*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B
M[_#NXN#KY>WN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@
M(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B
M56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC
M+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB
M"FUS9W-T<B`BS>7J[O#EZO+MX"#OX/#NZ^`@Z.OH(._N\O#EX>CRY>OQZNX@
MZ.SE(2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BX>7G
M(.CLY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T
M;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,@HC+"!F=7IZ>0IM<V=I9"`B56YS970@8V]L;W(B"FUS
M9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S
M='(@(L[O\.7Q[>@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M("+.[_#E\>WH("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B
MSN_PY?'MZ"`E<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB
M"FUS9W-T<B`BSN_PY?'MY>UA("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L
M;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*
M;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E
M<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P
M<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S
M92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G
M<W1R("+/[O+PY>'H\N7KZ"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`BP.3LZ.WH\?+PZ/#@[>4@[>`@[^[R\.7AZ/+EZ^CRY2(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"B,L(&9U>GIY"FUS9VED
M(")5<V5R($]P=&EO;G,B"FUS9W-T<B`BSN_VZ.@B"@HC.B!S:6=N=7`N<&AP
M.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R
M("+`Y.SH[>CQ\O#H\.#MY2#MX"#O[O+PY>'H\N7KZ/+E(@H*(SH@<VEG;G5P
M+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R("+([.4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB
M)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`BR.SE.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G
M:60@(E5S97)N86UE.B`B"FUS9W-T<B`BR.SE.B`B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES
M=&5M.B(*;7-G<W1R("+/[O+PY>'H\N7KZ"#B(/'H\?+E[.#RX#HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(L+@ZN#M]NC_(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M
M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3D*(RP@9G5Z>GD*;7-G:60@(E9A;'5E<R(*;7-G<W1R("+-_^S@(/'R[NGM
M[O'RZ"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C
M="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A
M='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"XB"FUS9W-T<B`BP_#E^.K@(._PZ"#O\.[BY?#JX/+@("T@\N[BX"#O
MZ/'L[B#L[N;E(.3@(.4@X>CK[B#O[N3O\.#BY>WN+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"B,L(&9U>GIY"FUS9VED(")6
M97)S:6]N(@IM<V=S='(@(L_PX.+@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@
M(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`BR.SE
M(.W@(/3@Z>LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B
M5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y
M"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS
M9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS
M9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T
M<B`BT>7D[.CW[>XB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("+$[N'PY2#D[OCK
MZ"P@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5V5L8V]M92!T;R`E<R(*;7-G<W1R("+$[N'PY2#$[OCKZ"#B("5S(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S
M(@IM<V=S='(@(L3NX?#E(.3N^.OH+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(LCGX>7PY?+E(._PZ.ONYN7MZ.7R[BP@ZN[E\NX@)7,@Y.`@[^[JX.;E(/'K
MY>0@XO7NY"XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM
M<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@
M(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G
M:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN
M($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7
M:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*
M;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*(RP@9G5Z>GD*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R("+"[>CLX.WHY3H@(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS
M9VED(")7;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S
M='(@(L'HY^WE\2#@Y/#E\2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B
MP>CG[>7Q(/+EZ^7T[NTB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E
M9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G
M:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")962(*;7-G<W1R("+#PR(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G
M<W1R("+#PR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@
M(EEE87)L>2(*;7-G<W1R("+#[N3H^.WN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F
M=7IZ>0IM<V=I9"`B665M96XB"FUS9W-T<B`B1W)E96XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B
M"FUS9W-T<B`BQ.`B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*
M;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("+-Y2#B^N+EY.[U\N4@XN#KZ.3E[2!E;6%I
M;"#@Y/#E\2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!B965N
M(&QO9V=E9"!O=70N(@IM<V=S='(@(L+@^.CRY2#J[NWTZ./S\.#VZ.[M[>@@
M[N_VZ.@@X?_UX"#NX>WNXN7MZ"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X
M.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V
M86QU92XB"FUS9W-T<B`BS>4@XOKBY>3N]?+E(.+@Z^CDY>T@96UA:6P@X.3P
MY?$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS
M9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O
M('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O
M8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R
M92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S
M="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(M+P
M_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(M+P
M_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(M+P_^'BX"#DX"#GX.3@
MY.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS
M9W-T<B`BTO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@Y.[AX.+_
M[>4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(M+P_^'B
MX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.[O\.7Q[?_BX.WE+B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+B(*;7-G<W1R("+2\/_AXN`@Y.`@Y^#DX.3E\N4@[^[R\.7AZ/+E
MZR#GX"#HY_+PZ.+@[>4N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`BTO#_X>+@(.3@
M(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@Z.?R\.CBX.WE+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS
M9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M
M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("+"X/CH_R!%;6%I;"#@Y/#E
M\3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS
M9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(L+@^.C_($5M86EL
M(.#D\.7Q.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R("+([?3N\.S@]NC_(.?@(,+@\2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"B,L(&9U>GIY
M"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`BPN#XY?+N(.CLY3HB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T
M<B`B(@HBPN#XZ/_R(.CDY>WRZ/3HZN#VZ.[MY>T@Y/#@Z>+E\"#MY2#O[N3D
M^O#FX"#D[N'@XO_MY2#MX"#O[O+PY>'H\N7KZ"P@Z.OH("(*(O+@Y^@@XOKG
M[.[F[>[Q\B#E(.?@X?#@[>7MX"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BXB"FUS9W-T<B`B(@HBPN#XZ/_R(.CDY>WRZ/3HZN#VZ.[MY>T@
MY/#@Z>+E\"#MY2#O[N3D^O#FX"#Q[^CQ^NH@[>`@[^[R\.7AZ/+EZ^CRY2P@
MZ.OH("(*(O+@Y^@@XOKG[.[F[>[Q\B#E(.?@X?#@[>7MX"XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@
M<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@
M(L+@^.CRY2#J[NWTZ./S\.#VZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED
M(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(LCDY>WRZ/?M[O'R
M(._N(._NY/#@Y^'H\.#MY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("+"
MX/CE\NX@Z.SE.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S
M='(@(L+@^.CRY2#J[NWTZ./S\.#VZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7M
MZ"XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S
M='(@(L+@^.CRY2#J[NWTZ./S\.#VZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7M
MZ"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("+"
MX/CH\N4@ZN[M].CC\_#@]NCN[>WH(.[O]NCH(.'_]>`@[N'M[N+E[>@N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB
M"FUS9W-T<B`BPN#XZ/+E(/'Z\.+Z\.@Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M
M(%)E<&]R=%TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6^OH[>C_("5S(.[R("5S
M72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")?061M:6YI
M<W1R871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4B"@HC.B!L:6(O87!I
M+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Q"B,L(&9U>GIY"FUS9VED(")?1&%T851R964B"FUS9W-T<B`BQ.#M
M[>@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S
M='(@(LCG\O#HZ2(*"B,Z(&QI8B]A<&DN<&AP.C$S,PHC+"!F=7IZ>0IM<V=I
M9"`B7T=R;W5P<R(*;7-G<W1R("+#\//OZ"(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM
M<V=S='(@(L_N[.[Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(L+U
M[N0B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L
M(&9U>GIY"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("+(Y_7NY"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@
M(E]/<'1I;VYS(@IM<V=S='(@(L[O]NCH(@H*(SH@;&EB+V%P:2YP:'`Z,3,W
M"B,L(&9U>GIY"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$R.0HC+"!F=7IZ>0IM<V=I9"`B7U5S97)S(@IM
M<V=S='(@(L_N\O#EX>CRY>OH(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R
M("+`Y/#E\>7M(.'EZ^7F[>CJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U
M>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("+*X.OE[>3@\"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X
M"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO
M="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N
M(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B
M8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED
M(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED
M(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D
M871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(NWE(.'E^.4@[>#LY?#E[2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R("+TX.GK(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS
M9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G
M:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I
M9"`B:6YL:6YE(@IM<V=S='(@(L_NY/?E\/+@[>@B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B;&EN97-=(@IM<V=S='(@(L?@X^O@
MXNC_(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED
M(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@
M(FYA;64B"FUS9W-T<B`BR.SE(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP
M.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T
M('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M
M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("+/\.#BX"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I
M>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BPNWH[.#M
MZ.4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM
M<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T
M96%D>2(*;7-G<W1R("+7Y?+E[>4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P
M"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A
M9V%I;B(*;7-G<W1R("+"\?_J[B#K[N/BX.WE(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I
M9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("+O
M\.[BX.OE[>XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W
M"FUS9VED(")U;FYA;65D(@IM<V=S='(@(N'EYR#H[.4B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G
M:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T
M<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T
M<B`B(@H`````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]B
M<U]"02YP;P``````````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P-C4P-C,Q`#$P-#$W,S8S,#`Q`#`Q-C,T,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````C('1R86YS;&%T:6]N
M(&]F(&AO<F1E+6)S+G!O('1O($)O<VYI86X*(R!";W-N:6%N('1R86YS;&%T
M:6]N<R!F;W(@:6UP('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`S($AO
M<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@
M=&AE('-A;64@;&EC96YS92!A<R!T:&4@:6UP('!A8VMA9V4N"B,@075T;VUA
M=&EC86QL>2!G96YE<F%T960L(#(P,#,N"B,@06QE;B!387)K:6YO=FEC(#QA
M;&5N0&QI;G5X+F]R9RYB83XL(#(P,#0N"B,@5F5D<F%N($QJ=6)O=FEC(#QV
M;&IU8F]V:6-`<VUA<G1N970N8F$^+"`R,#`U+@HC"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!H;W)D92UB<UQN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#4M,#<M,#$@,3,Z,S$K,#(P,%QN(@HB3&%S="U4
M<F%N<VQA=&]R.B!6961R86X@3&IU8F]V:6,@/'9L:G5B;W9I8T!S;6%R=&YE
M="YB83Y<;B(*(DQA;F=U86=E+51E86TZ($)O<VYI86X@/&QO:V%L0&QI;G5X
M+F]R9RYB83Y<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,EQN(@HB0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB6"U'96YE<F%T;W(Z($M"
M86)E;"`Q+C$P7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@
M(B`H<')I:F4@)7,@9&%N82DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@
M*'IA("5S(&1A;F$I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AD86YA<RDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R("(@*'-U=')A*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*&IUZ&4I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B('4@(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@
M(E!R879A8R!S;W)T:7)A;FIA(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R!N:6IE(&1O>G9O;&IE
M;B!I>F)O<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@
M(B<E<R<@;FEJ92!P;V1EN65N('4@<F5G:7-T<GDM:G4@87!L:6MA8VEJ92XB
M"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"XB"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S
M7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S87(B"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO
M="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&D@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@
M>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I
M8V4B"FUS9W-T<B`B)7,@+2!.87!O;65N82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T
M<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!397)V:7-N92!O<&5R86-I:F4@
M+2!P;W1V<F1A(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-E='5P(@IM<V=S='(@(B5S('!O9&6Y879A;FIE(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S('!R:6IA=F$B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S('5S;&]V:2!U9V]V;W)A
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S
M('9EYB!P;W-T;VII+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI
M8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S
M='(@(B5S('4@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y
M('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME
M9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS
M*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B
M("8C,34Q.R`E<R#F92!S861A(&EZ=G*Y:71I('-E<G9I<VYE(&]P97)A8VEJ
M92!N879E9&5N92!I<W!O9"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71A(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S
M(&YI:F4@<')O;F'P96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*
M;7-G<W1R("(E<R!Z82`E<R!O9"`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(R"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S
M<R!";V]K(@IM<V=S='(@(B5S(&%D<F5S87(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A
M;&5N9&%R(@IM<V=S='(@(B5S(&MA;&5N9&%R(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.
M;W1E<&%D(@IM<V=S='(@(B5S(&)I;&IEOFYI8V$B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M(%1A<VML:7-T(@IM<V=S='(@(B5S('IA9&%C:2(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA
M>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F
M(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T
M:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B5S('4@)7,@)7,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E
M;&5C="`M+2(*;7-G<W1R("(M+2!I>F%B97)I=&4@+2TB"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@
M(C$R+7-A=&YI(&9O<FUA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM
M<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0M<V%T;FD@9F]R;6%T
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO
M=7)S(@IM<V=S='(@(C(T('-A=&$B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B
M4')E=&AO9&YA('-T<F%N82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y
M"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*
M;7-G<W1R(")$;[EL;R!J92!D;R!F871A;&YE(&=R9;EK92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V
M-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G
M:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B04T@0VQO=61S
M(@IM<V=S='(@(DMO<&ER86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,0HC+"!F=7IZ>0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")5<&]Z;W)E;FIE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*
M;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%0
M22!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G
M<W1R(")/(&]V;VT@961I=&]R=2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")/('!R;V=R86UU+BXN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-`HC+"!F=7IZ>0IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(D1N;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G
M:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(E9AN64@:6YF;W)M86-I:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`BJ6EF
M<F$@:V]R:7-N:>AK;V<@;F%L;V=A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R
M;WIE;BXB"FUS9W-T<B`B3F%L;V<@:F4@>F%M<GIN=70N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G
M<W1R(")28>AU;F]V;V1S='9O(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!
M9&0B"FUS9W-T<B`B1&]D86HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A
M9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0HC+"!F=7IZ>0IM<V=I
M9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B27IM:6IE;FD@9&]Z
M=F]L=2(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!
M9&0@2&5R93HB"FUS9W-T<B`B1&]D86H@;W9D:F4Z(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3F5W<RUG<G5P92(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B061D($YE=R!097)M
M:7-S:6]N(@IM<V=S='(@(DEZ;6EJ96YI(&1O>G9O;'4B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T
M;R!<(B5S7"(B"FUS9W-T<B`B27IM:6IE;FD@9&]Z=F]L92!Z82`E<R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS
M9W-T<B`B1&]D86H@;F]V;V<@:V]R:7-N:6MA.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU
M;6XB"FUS9W-T<B`B1&]D86H@:V]L;VYU(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(D1O9&%J(&YO=F]G(&MO<FES;FEK83HB"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<B(*;7-G<W1R(")$;V1A:B`E<R!M96YI('4@36]Z:6QL82!3:61E
M8F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")$;V1A
M:B!U(&%D<F5S87(Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S
M<R!B;V]K(@IM<V=S='(@(D1O9&%J('4@:6UE;FEK("@E<RDB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B061D('5S97(B"FUS9W-T
M<B`B1&]D86H@;W9D:F4Z(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL
M(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T
M:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T,0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")/9"!A9')E
M<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`B26UE;FEK(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D
M;6EN:7-T<FER86YJ92`M('!O9&6Y879A;FIE(&1O>G9O;&$@9')U9VEH(&MO
M<FES;FEK82(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")?061M:6YI<W1R86-I:F$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!9',B"FUS9W-T
M<B`B1&]D86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G
M<W1R(")!9F=A;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*
M;7-G<W1R(")!;&)A;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B
M"FUS9W-T<B`B06R^:7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3`W"B,L(&9U>GIY"FUS9VED(")!;&EA<R(*;7-G<W1R
M(")!;+YI<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@
M(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B4W9E(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E
M<G,B"FUS9W-T<B`B57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"B,L(&9U>GIY
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E]'<G5P92(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+V1A=&%T<F5E+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B06QL(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(E]$;WIV;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O
M=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L
M;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(D1O
M>G9O;&D@<')A=FQJ96YJ92!N=6UE<FES86YI:"!L:7-T:3\B"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*(RP@9G5Z>GD*
M;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B5S('9EYB!P;W-T;VII
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R
M;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T:79N:2!)35-0(&QO
M9VEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT
M97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871I=FYA($E-
M4U`@N6EF<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED
M(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=&EV
M;F\@24U34"!K;W)I<VYIZ&MO(&EM92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@
M861D<F5S<R(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A
M9')E<VDN(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*(RP@9G5Z>GD*
M;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B3F5D;WIV;VQJ
M96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B
M06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB
M"FUS9W-T<B`B56YEN65N82!J92!I;&5G86QN82!V<FEJ961N;W-T+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G
M:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(D1O
MN6QO(&IE(&1O(&9A=&%L;F4@9W)EN6ME(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I
M9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")!;G-W97(B"FUS
M9W-T<B`B3V1G;W9O<F5N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I
M8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@
M0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T
M(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C8*(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%K8VEJ
M82(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@HC+"!F=7IZ>0IM<V=I
M9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R(")!:V-I:F$B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,30P"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A
M=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B06MC:6IA(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H
M87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O
M>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P
M<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I
M8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("));64@9&%T;W1E:V4B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G
M<W1R(")$82!L:2!S=&4@<VEG=7)N:2!D82"^96QI=&4@:7-P<F%Z;FET:2!F
M;VQD97(@:V]R<&$_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R
M;W5P<S\B"FUS9W-T<B`B1&$@;&D@<W1E('-I9W5R;FD@9&$@OF5L:71E(&]B
M<FES871I(&]V92!P;W)U:V4_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`HC+"!F=7IZ>0IM<V=I
M9"`B07)G96YT:6YA(@IM<V=S='(@(D%LOFER(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM
M<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(E!I=&%J('!R:6IE(&]B879L
M:F%N:F$@<V5R=FES;FEH(&]P97)A8VEJ83\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U
M=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B075G=7-T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@
M(D%U9W5S="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D%U<W1R:6$B
M"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"
M86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R
M,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?
M:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM
M<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!2
M96UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(").:6IE('5S<&5L;R!S
M<&&Y879A;FIE(&YE>F%V<KEE;F4@<&]R=6ME+B!/=F\@:F4@<&]R=6MA('-E
M<G9E<F$Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT.3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@
M(DYI:F4@=7-P96QO('-P8;EA=F%N:F4@;F5Z879RN65N92!P;W)U:V4N($]V
M;R!J92!P;W)U:V$@<V5R=F5R83H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V
M"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"B,L(&9U
M>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B57-M
M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R
M(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"B,L(&9U>GIY"FUS9VED(")!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B57-M
M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T
M:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ
M92!U<W!E;&\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0HC
M+"!F=7IZ>0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B3F$@
M<F%S<&]L86=A;FIU('-U('-L:F5D9>9I(&EM96YI8VDZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A
M8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"<F%Z:6PB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)
M4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&GH:VD@*$E33RTX.#4Y+3$S*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@
M9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B5F5L
M:>AI;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B
M5F5L:>AI;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B5F5L:>AI;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED
M(")"96YI;B(*;7-G<W1R(")2975N:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@
M(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5G)S=&$@8FQO:V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B
M"FUS9W-T<B`B36%S;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM
M<V=S='(@(D)O;&EV:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(EIA8FEL:F6Y:V4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B4G5B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R
M('1H:6-K;F5S<SHB"FUS9W-T<B`B1&5B;&II;F$@<G5B;W9A.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*
M;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B4G5B;W9I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N82!I
M($AE<F-E9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS
M9VED(")";W1H(@IM<V=S='(@(D]B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M='-W86YA(@IM<V=S='(@(D)O8W9A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*
M;7-G<W1R(")$;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD
M(@IM<V=S='(@(D)O=79E="!O<W1R=F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M<F%Z:6PB"FUS9W-T<B`B0G)A>FEL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET86YS
M:V$@26YD:6IS:V\M3VME86YS:V$@5&5R:71O<FEJ82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U
M<W-A;&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B
M0G5G87)S:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(DQI<W1A
M('-A('1AZ&MA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*
M;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(D]S;V)I;F4@YE]E;&EJ92XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#8*(RP@9G5Z>GD*;7-G:60@(D-A;&TB"FUS9W-T<B`B3V1U
M<W1A;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B
M2V%M8F_P82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@
M(DMA;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM
M<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES
M=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DYE
M(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E<CH@)7,B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D]D=7-T86YI(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E
M;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")/9'5S=&%N:2!O9"!P<FEJ879E
M('!R;V)L96UA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M
M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@
M;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED
M(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B
M3W!C:6IE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B
M96QS(@IM<V=S='(@(DMA=&5G;W)I:F4@:2!O>FYA:V4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@HC+"!F=7IZ>0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B36%R
MN6%L;W9A(&]S=')V82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4&AO;F4B"FUS
M9W-T<B`B5&5L969O;B`H:W7F:2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#
M96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B3W-O8FEN92#F7V5L:6IE+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*
M;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0HC+"!F=7IZ
M>0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(D]S;V)I;F4@YE]E
M;&EJ92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B2V5L='-K:2`H25-/
M+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B0V5N=&5R(@IM<V=S
M='(@(DMR96ER86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,B"FUS9W-T<B`B0V5N=')A;&YO+4%F<FGH:V$@4F5P=6)L
M:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D-E;G1R86QN;RUE
M=G)O<'-K:2`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E
M<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC
M+"!F=7IZ>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")4;VL@=&5M92(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")0<F]M:F5N
M:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ
M>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O
M<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G
M<W1R("(B"B)0<F]M:6IE;FET92!I;64@:2!A9')E<W4@:V]J92!V:61E(&1R
M=6=I(&MA9&$@Z&ET86IU(&D@;V1G;W9A<F%J=2!N82!V8;EE("(*(G!O<G5K
M92XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@
M(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM
M<V=I9"`B0VAA<B(*;7-G<W1R(")4;VL@=&5M92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0HC+"!F=7IZ
M>0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B7TEZ;6EJ96YI(&QI
M;FLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R("+(:6QE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B2VEN82(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BDB"FUS9W-T<B`B2VEN97-K:2!P;VIE9&YO<W1A=FQJ
M96YI("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G
M:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(DMI;F5S
M:VD@=')A9&EC:6]N86QN:2`H0FEG-2DB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*
M;7-G<W1R("))>F%B97)I=&4@N6EF<G4B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R("))>F%B97)I=&4@:V]R:7-N:>AK;R!I;64B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z(@IM<V=S='(@(DEZ86)E<FET92!K86MO('-E('!R:6MA>G5J
M92!D871U;3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B27IA8F5R:71E('9R
M<W1U('-T:6QA("AZ82!N=6UE<FES86YE(&QI<W1E*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B57-K<KEN:F4@;W-T
M<G9O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@
M(D-L96%R(@IM<V=S='(@(D_H:7-T:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E
M('1A9W,B"FUS9W-T<B`B3^AI<W1I($U33V9F:6-E('1A9V]V92(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R(%%U
M97)Y(@IM<V=S='(@(D_H:7-T:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U
M<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S97(B"FUS9W-T
M<B`B3^AI<W1I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S0*(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")/
M9&%B97)I(&MO9&YI(')A<W!O<F5D('-L;W9A.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*(RP@9G5Z>GD*;7-G
M:60@(D-L;W5D<R(*;7-G<W1R(")+;W!I<F%J(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L
M;W5D<R!%87)L>2(*;7-G<W1R(")+;W!I<F%J(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(D-L
M;W5D>2(*;7-G<W1R(")+;W!I<F%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B0V]L;&%P
M<V4@4VED96)A<B(*;7-G<W1R(")3:W5P:2!F;VQD97(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"B,L(&9U
M>GIY"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")3:W5P:2!F
M;VQD97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#;VQO;6)I82(*
M;7-G<W1R(")+86UB;_!A(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*(RP@9G5Z>GD*;7-G:60@(D-O
M;&]R(@IM<V=S='(@(DMO;6]R:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L
M96-T:6]N(@IM<V=S='(@(DEZ8F]R(&)O:F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I
M9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8T"B,L(&9U>GIY"FUS9VED(")#;VUI8W,B"FUS9W-T
M<B`B3F]V82!P;W)U:V$B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@
M9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B2V]M<&%N:6IA(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;65N="(*;7-G<W1R("):879RN65N;R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"B,L(&9U
M>GIY"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(")68;EE(&EM92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(DMO;6]R:2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G
M:60@(D-O;7!A;GDB"FUS9W-T<B`B2V]M<&%N:6IA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#;VUP=71E<G,B"FUS
M9W-T<B`B3F]V82!P;W)U:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B
M3W!C:6IE(&YA<F5D8F4Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*
M(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B3W!C:6IE(&YA
M<F5D8F4Z(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@
M<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M
M(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@HC+"!F
M=7IZ>0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B6F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"B,L
M(&9U>GIY"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE(@IM<V=S='(@(DQA;R!.87)O9&YA($1E;6]K<F%T<VMA(%)E<'5B
M;&EK82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R
M(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B57-M:F5R96YJ92!N:6IE('5S<&5L
M;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"B,L
M(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3,*(RP@9G5Z>GD*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")<(B5S7"(@
M:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S87(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O
M9B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED
M(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"B,L(&9U>GIY"FUS
M9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0F]U=F5T(&]S=')V;R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B0V]O
M:VEE(@IM<V=S='(@(DYO=F$@<&]R=6MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y
M(@IM<V=S='(@(DMO<&ER86HB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL
M960Z("5S(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E;&\N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I
M9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P:7)A:B!I>F%B<F%N;R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED
M(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A
M(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV
M;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*
M;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE(&UO9W4@<V4@<W!O:FET
M:2!N82!)34%0('-E<G9E<CH@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R
M(").92!M;V=U('-E('-P;VII=&D@;F$@24U!4"!S97)V97(Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G
M=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S
M(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D
M("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").
M:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C
M<FEP="!<(B5S7"(N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A
M=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDU,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@
M<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DYE9&]Z=F]L
M:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3FEJ92!B:6QO(&UO
M9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D
M:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@
M;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B3FEJ
M92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<
M(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3FEJ
M92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?
M5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y
M.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S
M+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O
M9"`E<SH@)7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM
M<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T
M<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M
M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R
M:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W1S+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O
M<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G
M=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@
M;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O
M8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D
M("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B
M<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HY-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS
M9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z
M("5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@
M;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E
M:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E
M<UPB+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K
M92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(").:6IE(&)I
M;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O
M8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R
M(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I
M9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*(RP@9G5Z>GD*;7-G:60@
M(D-O=6YT960@=&5X="(*;7-G<W1R("))<W!R879L:F5N('1E:W-T(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*(RP@9G5Z>GD*
M;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B3F]V82!P;W)U:V$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"B,L(&9U>GIY"FUS9VED(")#;W5R
M<V5S(@IM<V=S='(@(DYO=F$@<&]R=6MA(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B2W)E:7)A:B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E
M(&$@;&EN:R(*;7-G<W1R(").87!R879I(&QI;FLB"@HC.B!T96UP;&%T97,O
M<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N
M97<@;VYE(@IM<V=S='(@(DYA<')A=FD@;F]V:2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B
M(&9O;&1E<G,B"FUS9W-T<B`B4')A=FQJ96YJ92!P;V0M9F]L9&5R82(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"B,L(&9U>GIY"FUS
M9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D1E9F%U;'0@9&]Z
M=F]L92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*(RP@9G5Z
M>GD*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R(")$96-E;6)A
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")#<F]A=&EA(@IM<V=S
M='(@(DMR96ER86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B
M0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("))<W!R879L:F5N('1E:W-T(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#=7)R
M96YT(%-E<W-I;VYS(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*(RP@
M9G5Z>GD*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("))<W!R879L:F5N
M('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4T"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%523"!I
M<R(*;7-G<W1R("))<W!R879L:F5N('1E:W-T(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S
M='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B
M27-P<F%V;&IE;B!T96MS="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("))<W!R
M879L:F5N('1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!O9&5S:71E('IA9&%T:V4@:V]J
M:2#F92!S92!I>G9RN6%V871I(&YA:V]N('!R:6IA=F4@;F$@)7,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0HC+"!F=7IZ>0IM<V=I9"`B0W5T
M('-E;&5C=&EO;B(*;7-G<W1R("))>F)O<B!B;VIE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")#>F5C:"!297!U
M8FQI8R(*;7-G<W1R(")#96YT<F%L;F\M069R:>AK82!297!U8FQI:V$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A
M:6QY(@IM<V=S='(@(D1N979N;R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV
M-0HC+"!F=7IZ>0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")?
M1&%T851R964B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS
M9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(D1A='5M(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*(RP@9G5Z
M>GD*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B4')I;6QJ96YA(&YA
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PHC+"!F=7IZ>0IM
M<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B5G)E;65N<VMA('IO;F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*
M;7-G<W1R(")-86HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G:60@(D1E7VQE=&4@
M0V]L=6UN(@IM<V=S='(@(D]B<FFY:2!F;VQD97(H92DB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB
M97(B"FUS9W-T<B`B1&5C96UB87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED
M(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5C96UB87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$
M96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E
M9F%U;'0B"FUS9W-T<B`B4W1A;F1A<F1N;R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(E-T86YD87)D;F$@8F]J82(*"B,Z(&9R86UE=V]R:R])
M9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I
M='DB"FUS9W-T<B`B1&5F875L="!I9&5N=&ET970B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB
M"FUS9W-T<B`B4W1A;F1A<F1N;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6YI8VEJ92(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G
M:60@(D1E;&5T92(*;7-G<W1R(")/8G)IN6DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(D]B<FFY:2(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B3V)R:;EI(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@3&]G(@IM<V=S='(@(D]B<FFY:2(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S
M='(@(D]B<FFY:2!P;W)U:V4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S
M86=E<R(*;7-G<W1R(")"<FES86YJ92!I(&EZ8F%C:79A;FIE('!O<G5K82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(D]B
M<FFY:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS
M9W-T<B`B3V)R:;EI(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G
M:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(DEZ;6EJ96YI(&1O>G9O;&4@>F$@)7,B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@
M86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PHC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")/8G)IN6DB"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE
M=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B3V)R:;EI(&EZ86)R86YI
M(&ED96YT:71E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('1H
M92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")0;V1E<VD@=G)E;65N<VMU('IO
M;G4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W(@IM<V=S='(@(E!O9&5S:2!V<F5M96YS:W4@>F]N=2XB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D
M("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV
M97)Y('1I;64B"FUS9W-T<B`B3V)R:;EI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T
M<B`B3W!IN6ET92!P<F]B;&5M92!U(')A9'4@<V$@=V5B;6%I;&]M(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T
M:6]N(@IM<V=S='(@(D]P:7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I
M;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$Y.0HC+"!F=7IZ>0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B3W9A('!O<G5K82!J
M92!P<FEJ879L:F5N82!K86\@<W!A;2!P;W)U:V$@861M:6YI<W1R871O<G4@
M<VES=&5M82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS
M9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA
M<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G
M:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@
M(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B
M1&ER96MT;W)I:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G
M:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B4')I:V&^:2!V
M<FEJ96UE('4@,C0M<V%T;F]M(&9O<FUA='4_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B
M3W!C:6IE('!R:6MA>F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0B"FUS9W-T<B`B4')I:V&^:2!P<F]G;F]Z=2`H5$%&*2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`B4')I:V&^:2!P<F]G;F]Z=2`H5$%&*2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L
M87D@9F]R;6%T(@IM<V=S='(@(E!R:6MAOFDB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,C(*(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B56YD
M96QE=&4B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@
M(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN
M:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D1O
M;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")#96YT<F%L;F\M069R:>AK82!2
M97!U8FQI:V$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM
M<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B1&]W;FQO860B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B1&]W;FQO860@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P
M(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL
M(@IM<V=S='(@(E-A;F1U8V4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W
M87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E
M<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D52
M4B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O
M<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(DEZ;6EJ
M96YI(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(V"B,L(&9U>GIY"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@
M(D]B<FFY:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;B(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQU(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S
M:6]N<R(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQE(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQE
M('IA("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B
M161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B27IM:6IE;FET92!O<&-I:F4@
M>F$Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQE('IA("5S(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M27IM:6IE;FD@9&]Z=F]L92!Z82`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(D%K
M8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*
M;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@
M8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G
M:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0HC+"!F=7IZ>0IM<V=I
M9"`B16UA:6PB"FUS9W-T<B`B4V%N9'5C92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%;6%I;"!A9')E
M<V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B
M16UA:6P@861R97-A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX
M.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS
M9W-T<B`B3W-T86QE(&EN9F]R;6%C:6IE(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--
M4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R
M(")3;6%J;&EJ:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G
M92XB"FUS9W-T<B`B5F&^;F4@<&]R=6ME(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`HC+"!F=7IZ>0IM<V=I9"`B
M16UP='D@<F5S=6QT+B(*;7-G<W1R("))<W!R87IN:2!K;W)P=2(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G
M:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("))<W!R87IN:2!F;VQD
M97(@:V]R<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED
M(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/R(*;7-G<W1R(")!:W1I=FER86H@:V]N=&5K<W0@;65N:2!N82!D97-N
M;VT@:VQI:W4_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"B,L(&9U>GIY"FUS9VED(")%
M;F0@>65A<B(*;7-G<W1R(")0<F^Y:7)I(&9O;&1E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R
M9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H
M92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B16MV871O<FEJ86QN82!'=FEN
M96IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET
M<F5J82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E
M>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(D=R9;EK82(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N
M=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R(")%<W1O;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA
M(@IM<V=S='(@(D5T:6]P:6IA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B171N:>AK:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S
M='(@(D5V<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G
M:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B4W9A:VEH(#$U(&UI;G5T
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y
M(#(@;6EN=71E<R(*;7-G<W1R(")3=F%K:6@@,B!M:6YU=&4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B4W9A:VEH(#,P
M('-E:W5N9&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R(")3=F%K:6@@-2!M:6YU=&$B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*
M;7-G<W1R(")+;V0@<W9A:V4@<')I:F%V92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")3
M=F%K:6@@<&]L82!S871A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`B4W9A:VD@;6EN=70B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@
M(E9R:6IE9&YO<W1I('!R:6UJ97)I.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP
M.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*(RP@9G5Z>GD*;7-G:60@(D5X
M<&%N9"(*;7-G<W1R(")0<F^Y:7)I('-V92(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"!3:61E
M8F%R(@IM<V=S='(@(E!R;[EI<FD@9F]L9&5R(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@
M(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(").92!M;V=U('-E('-P;VII=&D@;F$@
M24U!4"!S97)V97(Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.CDX"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+B(*;7-G<W1R(").92!M;V=U('-E('-P;VII=&D@;F$@24U!
M4"!S97)V97(Z("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3@*(RP@9G5Z>GD*;7-G:60@(D9A:7(B"FUS9W-T<B`B6F%I<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")&87)O92!)
M<VQA;F1S(@IM<V=S='(@(D)O=79E="!O<W1R=F\B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB
M"FUS9W-T<B`B1W)EN6MA.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B
M1F%X97,B"FUS9W-T<B`B26UE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E
M8G)U87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E
M;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*
M;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6QT97)I(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`W"B,L(&9U>GIY"FUS9VED(")&:6QE($UA;F%G
M97(B"FUS9W-T<B`B26UE(&1A=&]T96ME(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R
M("));64@9&%T;W1E:V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3DU"B,L(&9U>GIY"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")N
M:6IE9&YO('!R879I;&\@;FEJ92!O9&%B<F%N;R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T.#8*(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D
M(@IM<V=S='(@(E!O;&IE(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS
M9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1E<FDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L
M(&9U>GIY"FUS9VED(")&:6YL86YD(@IM<V=S='(@(E1R8;YI(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@2&%L
M9B(*;7-G<W1R(")0<G9A(%-T<F%N82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(D9I
M<G-T(%%U87)T97(B"FUS9W-T<B`B4')V82!3=')A;F$B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@
M<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R
M"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*(RP@9G5Z>GD*;7-G
M:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B4W1A;F1A<F1N82!B;VIA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B1F]R(&)R;W=S97)S('1H
M870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B5F&Y(&)R;W=S97(@
M;F4@<&]D<KYA=F$@;W9U(&UO9W7F;F]S="XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,S-`HC+"!F=7IZ>0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`B4')I:V&^:2!P<F]G;F]Z=2`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H
M;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@
M9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R
M97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$P,@HC+"!F=7IZ>0IM<V=I9"`B1F]R9V]T
M('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(DEZ86)E<FET92"Y:69R=2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*(RP@9G5Z>GD*;7-G:60@
M(D9O<FUS(@IM<V=S='(@(D]D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Q"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D9O;&1E<FDB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@
M='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*
M(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D9O;&1E<FDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(D9O
M<G1U;F5S(#(B"FUS9W-T<B`B1F]L9&5R:2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-3,*(RP@9G5Z>GD*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M(")&;VQD97)I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0HC
M+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4')O<VQI:F5D:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*
M(RP@9G5Z>GD*;7-G:60@(D9R(@IM<V=S='(@(D]D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ
M>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(DEM92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*(RP@
M9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R("));64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P
M;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'
M=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O
M;2(*;7-G<W1R(")/9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"B,L(&9U>GIY"FUS9VED(")&
M<F]M('1H92`B"FUS9W-T<B`B3V0B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R
M(")$971A;&IA;B!O<&ES(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.
M86UE(@IM<V=S='(@(DEM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'86UB
M:6$B"FUS9W-T<B`B6F%M8FEJ82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S
M($-O;F9I9W5R871I;VXB"FUS9W-T<B`B5G)A=&D@<W1A<G4@:V]N9FEG=7)A
M8VEJ=2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX
M"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B2VEN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I
M8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I9"`B1VEV96X@3F%M92(*;7-G
M<W1R("));64@9&%T;W1E:V4B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B2W)E;FDB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`HC+"!F
M=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE('!R971R
M86=A(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O
M9VQE(%-E87)C:"(*;7-G<W1R(")';V]G;&4@<')E=')A9V$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'
M<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I
M9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=RZ&MI("A)4T\M.#@U
M.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=R965N;&%N9"(*
M;7-G<W1R(")4;VL@=&5M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@
M(D=R96YA9&$B"FUS9W-T<B`B5&]K('1E;64B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B)7,@861M:6YI<W1R86-I:F$B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("(*;7-G<W1R(").:6IE('5S<&5L;R!S<&&Y879A;FIE(&YE>F%V
M<KEE;F4@<&]R=6ME+B!/=F\@:F4@<&]R=6MA('-E<G9E<F$Z("5S(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$W-PHC+"!F=7IZ>0IM<V=I9"`B1W)O=7!S(@IM<V=S='(@(E]'
M<G5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*(RP@9G5Z>GD*;7-G:60@(D=U86TB"FUS9W-T<B`B
M2G5N:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E
M<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`HC+"!F=7IZ
M>0IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B27IM:6IE;FD@
M9&]Z=F]L92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G
M:60@(D=U97-T8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`B2G5N:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`HC
M+"!F=7IZ>0IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")*=6YI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M2G5N:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B
M2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"B,L(&9U>GIY"FUS
M9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G
M:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*
M;7-G:60@(DAE861E<B(*;7-G<W1R(")0;VUOYB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@
M(DAE861E<G,B"FUS9W-T<B`B4&]M;^8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@
M(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM
M<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM
M<V=S='(@(DAE8G)E:G-K:2`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*(RP@9G5Z
M>GD*;7-G:60@(DAE:6=H="(*;7-G<W1R(").;^8B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T
M<B`B4&]M;^8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS
M9VED(")(96QP97(B"FUS9W-T<B`B4&]M;^8B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B
M4&]M;^8B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0HC+"!F=7IZ>0IM<V=I
M9"`B2&EG:"(*;7-G<W1R(").;^8B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*
M;7-G:60@(DAO7VUE(@IM<V=S='(@(E!OZ%]E=&%K(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS9VED
M(")(;VUE(@IM<V=S='(@(E!OZ&5T86LB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*
M;7-G<W1R(")!9')E<V$@*&MUYFDI(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8T"B,L(&9U>GIY"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R
M(")$:7)E:W1O<FEJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE
M9F]N("AK=>9I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`B2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N
M9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T
M>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@7"(E<UPB(@IM<V=S='(@(DEM92!F;VQD97)A(%PB)7-<(B!J92!U<W!J
M9;EN;R!P<F]M:F5N:F5N;R!U(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E
M9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E
M;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DEM92!F;VQD97)A(%PB
M)7-<(B!J92!U<W!J9;EN;R!P<F]M:F5N:F5N;R!U(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B57-P:F6Y;F\@<W1E('!R:6IA=FQJ96YI
M(&YA(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(E5S<&IE
MN6YO('-T92!P<FEJ879L:F5N:2!N82!<(B5S7"(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I
M9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT
M86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(
M;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M
M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))
M4"!A9')E<V$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP
M.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DE0(&%D<F5S82!N:6IE(&1O<W1U<&YA+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0(&%D<F5S82!N
M:6IE(&1O>G9O;&IE;F$@=6YU=&%R($-)1%(@8FQO:V$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED
M("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0HC
M+"!F=7IZ>0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(E!R
M:6UL:F5N82!P<FEJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*
M;7-G<W1R("))<VQA;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V
M"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E-A;6\@:6MO;F4B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26-O;G,@9F]R("5S(@IM<V=S='(@(DEK;VYE('IA("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM
M<V=S='(@(DEK;VYE('-A('1E:W-T;VTB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DEM
M92!I9&5N=&ET971A.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO
M(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E
M("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T
M<B`B4')E=&AO9&YA('-T<F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*
M(RP@9G5Z>GD*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")0;VQJ92(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I
M96QD<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!
M9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C
M="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYI:F4@<&]S
M;&%N;R!K;W)I<VYIZ&MO(&EM92!I+VEL:2"Y:69R82XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"B,L(&9U>GIY"FUS9VED("));F1I82(*
M;7-G<W1R(")N;VYE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN
M9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U
M>GIY"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B;F]N92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*(RP@9G5Z>GD*
M;7-G:60@(DEN9F\B"FUS9W-T<B`B26=N;W)IN6DB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO
M;B(*;7-G<W1R(")097)S;VYA;&YE(&EN9F]R;6%C:6IE(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`HC+"!F=7IZ>0IM<V=I9"`B26YF
M;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B3F5M82!D
M;W-T=7!N:6@@;W!C:6IA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU
M;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED
M("));G-E<G0@26UA9V4B"FUS9W-T<B`B3V1G;W9O<F5N92!P;W)U:V4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B3V1G;W9O<F5N
M92!P;W)U:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,T"B,L(&9U>GIY"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B
M"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*(RP@9G5Z>GD*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(E!O9&5S:2!V<F5M96YS:W4@>F]N=2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED
M("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")0<FEM;&IE;F$@<')I:F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y
M"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B
M4')I;6QJ96YA('!R:6IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")0<FEM;&IE;F$@<')I:F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U
M"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R
M(")0<FEM;&IE;F$@<')I:F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S
M='(@(D1O9&%V86YJ92!P;W)U:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"B,L(&9U>GIY"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R(")0<FEM;&IE
M;F$@<')I:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@<F]W(&%F
M=&5R(@IM<V=S='(@(D]D9V]V;W)E;F4@<&]R=6ME(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B4')I;6QJ96YA
M('!R:6IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED("));G-E<G0O36]D
M:69Y($EM86=E(@IM<V=S='(@(D]D9V]V;W)E;F4@<&]R=6ME(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(E])>FUI:F5N
M:2!L:6YK+BXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@
M<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U
M"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G
M:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED("));G9A
M;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN
M(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D
M871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DYE9&]Z
M=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PHC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA
M('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M
M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA
M:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M
M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V
M82!U(&5M86EL(&%D<F5S:2XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S
M:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DYE9&]Z
M=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@
M96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P
M<F]T;V-O;"XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@
M861R97-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@HC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3F5D;WIV;VQJ
M96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B3F5D;WIV;VQJ
M96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(DYE9&]Z=F]L:F5N
M82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0HC+"!F
M=7IZ>0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R(")6<F5M96YS
M:V$@>F]N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER
M87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("))
M<F5L86YD(@IM<V=S='(@(E1O:R!T96UE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS
M9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*(RP@9G5Z>GD*;7-G:60@(DES<F%E;"(*;7-G<W1R(")4;VL@=&5M92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED
M("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R(")$
M;F5V;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DIA;6%I8V$B
M"FUS9W-T<B`B6F%M8FEJ82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA;G5A
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M
M,C`R,BU*4"DB"FUS9W-T<B`B2F%P86YS:VD@*$E33RTR,#(R+4I0*2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A
M<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@
M=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R
M"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L:2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS
M9VED(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*
M;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I
M9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*
M;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y
M($-R96%T:6]N(@IM<V=S='(@(D]P8VEJ92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*(RP@9G5Z>GD*;7-G:60@(DME>2!4
M>7!E(@IM<V=S='(@(DUI;64@=&EP(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*
M;7-G<W1R(")0;W)U:V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"B,L
M(&9U>GIY"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U
M8FQI8R!O9B(*;7-G<W1R("),86\@3F%R;V1N82!$96UO:W)A='-K82!297!U
M8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I
M9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM
M<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B4F%?<W!O<F5D(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`B2F5Z:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!0
M96]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;R!.87)O
M9&YA($1E;6]K<F%T<VMA(%)E<'5B;&EK82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")0
M<G9A(%-T<F%N82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@HC+"!F
M=7IZ>0IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B4&%S
M<W=O<F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@X"B,L(&9U>GIY"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T
M<B`B4')V82!3=')A;F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM
M<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("):861N:F$@:7IM:F5N83HB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B6F%D;FIA('!R:6IA
M=F$Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T
M<B`B6F%D;FIA('!R:6IA=F$Z("5S('-A(&%D<F5S93H@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE
M=F5R(@IM<V=S='(@(EIA9&YJ82!P<FEJ879A.B!.:6MA9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQA='9I:F$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("):86MO
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(E)A<W!O<F5D(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I
M9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3&EB86XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*
M(RP@9G5Z>GD*;7-G:60@(DQE9G0B"FUS9W-T<B`B4')E8F%C:2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*
M(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(EIA9&YJ82!S
M=')A;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B
M3&5S;W1O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L
M(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(").:6MA9&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T
M<B`B3&EB:6IS:V$@07)A<'-K82!$OF%M86AI<FEJ82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:6AT96ZY=&%J;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS
M9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),
M:6=H="!286EN(@IM<V=S='(@(E!R:6IA=FD@<V4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I
M;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT
M(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0HC+"!F=7IZ>0IM
M<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EB97)I:F$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM
M<V=S='(@(DQI;FMO=FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U
M"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@
M(DQI;FMS(@IM<V=S='(@(DQI;FMO=FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R
M(").;W9A('!O<G5K82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F
M;VQD97(B"FUS9W-T<B`B3&ES=&%N:F4@+2!K;W)I<VYI:R!M;[YE('9I9&IE
M=&D@9F]L9&5R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PHC+"!F=7IZ
M>0IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B6F%D;FIA('-T<F%N
M82(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"B,L(&9U>GIY"FUS
M9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(E!O;6_F(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="!486)L
M97,B"FUS9W-T<B`B6F%D;FIA('-T<F%N82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DT"B,L(&9U>GIY"FUS9VED("),:7-T+4%R
M8VAI=F4B"FUS9W-T<B`B4V%K<FEJ(&YE=7!I<V%N92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),
M:7-T+4AE;'`B"FUS9W-T<B`B4&]M;^8B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-@HC+"!F=7IZ>0IM<V=I9"`B3&ES="U)9"(*
M;7-G<W1R(")0;VUOYB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DR"B,L(&9U>GIY"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@
M(E!O;6_F(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0HC+"!F=7IZ>0IM<V=I9"`B3&ES
M="U3=6)S8W)I8F4B"FUS9W-T<B`B4V%K<FEJ(&YE=7!I<V%N92(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"B,L(&9U>GIY"FUS
M9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(E-A:W)I:B!N975P:7-A
M;F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G
M<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*
M(RP@9G5Z>GD*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B5F&Y('!O='!I
M<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),
M:71V82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B5>AI=&%V86TN+BXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),
M;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K86QN;R!V<FEJ96UE.B`B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM
M92(*;7-G<W1R("),;VMA;&YE('!O<W1A=FME(&D@=G)I:F5M92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B3&]K86-I:F$B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B
M4')I:F%V:2!S92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED
M("),;V<@;W5T(@IM<V=S='(@(DEZ;&%Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R(")0<FEJ
M879I('-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B
M3&]G:6X@5&%S:W,B"FUS9W-T<B`B6F%D86-I('!R:6IA=F4B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B
M96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@
M:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(E!R:6IA=F$@;FEJ92!U<W!J96QA
M+B!.86IV97)O=F%T;FEJ92!J92!P;V=R9;EN;R!U;F5S96YO(&MO<FES;FGH
M:V\@:6UE(&EL:2`B"B*Y:69R82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B4')I:F%V
M82!N:6IE('5S<&IE;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(D1U9VD@=&5K<W0B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(DQO
M=F4B"FUS9W-T<B`B3F%S=&%V:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8W"B,L(&9U>GIY"FUS9VED("),;W<B"FUS9W-T
M<B`B6F%K;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B3&]W97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R(")$96-E;6)A<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=6MS96UB=7)G(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*(RP@9G5Z>GD*;7-G
M:60@(DU31R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*
M;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA<G0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U
M>GIY"FUS9VED(")-86=I8R(*;7-G<W1R(")-87)T(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C@Q"B,L(&9U>GIY"FUS9VED(")-86EL(@IM<V=S
M='(@(E-A;F1U8V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R
M"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B
M36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z
M>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")386YD=6-E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M(RP@9G5Z>GD*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(D9I;'1E<FD@<&^Y
M=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T
M<B`B4V%N9'5C92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L
M=&$B"FUS9W-T<B`B4V%N9'5C92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB
M3F%P<F%V:71E(&MA=&5G;W)I:F4@<W1A=FMI(&D@>F$@<W9A:W4@;V0@;FII
M:"!O9')E9&ET92!O9&=O=F%R86IUYG4@8F]J=2XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-
M87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R
M(")-87)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@
M(E5P;WIO<F5N:F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M(@IM<V=S='(@(D]Z;F'H879A;FIE(&MA;R!P<F_H:71A;F\O;F5P<F_H:71A
M;F\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"DB"FUS9W-T<B`B3WIN8>AA=F%N:F4@9')U9VEM(&]Z;F%K
M86UA("AN<'(N('9AOFYO(&EL:2!O9&=O=F]R96YO*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87*Y86QO=F$@
M;W-T<G9A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S
M='(@(DUA<G1I;FEK(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")/9&=O=F%R86IU
MYF$@<&]L:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS
M9W-T<B`B36%U<FET86YI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I
M=&EU<R(*;7-G<W1R(")-875R:6-I:G5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL
M;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`HC+"!F=7IZ>0IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(E!O;&IA('!O
M<G5K92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@
M(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B
M36%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B36%Y;W1T92(*
M;7-G<W1R(")-86HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*(RP@
M9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(D]B<FES86YA(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M
M8F5R<R(*;7-G<W1R("+(;&%N;W9I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")6<G-T82!M96YI
M:F$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B4W!O:FD@
M<&]L:F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")0;W)U:V$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I
M9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E>'!I
M<F5D+B(*;7-G<W1R(")0;VQJ82!P;W)U:V4B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B1&%T=6T@<&]R
M=6ME(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!7
M96%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(DYE;6$@9&]S='5P;FEH(&]P8VEJ82XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B(@HB365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B3W9A('!O<G5K82!J92!P<FEJ
M879L:F5N82!K86\@<W!A;2!P;W)U:V$@861M:6YI<W1R871O<G4@<VES=&5M
M82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED
M(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(DQE<V]T;R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E
M9FEN960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP
M:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM
M<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F
M=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(E!R96)A8VDB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM
M92!4>7!E(@IM<V=S='(@(DUI;64@=&EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN
M('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O
M<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ
M>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(D=R9;EK82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB
M87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`HC+"!F=7IZ>0IM<V=I9"`B
M36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")/=F$@<&]R=6MA('4B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDT"B,L(&9U>GIY"FUS9VED(")-:7-S:6YG('-E
M<W-I;VX@240N(@IM<V=S='(@(D]V82!P;W)U:V$@=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*(RP@9G5Z>GD*;7-G
M:60@(DUO(@IM<V=S='(@(E!R96)A8VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-S0*(RP@9G5Z>GD*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S
M='(@(DYO=F$@<&^Y=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A
M=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")-;V1I9GD@
M55),(@IM<V=S='(@(E])>FUI:F5N:2!L:6YK+BXN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*(RP@9G5Z>GD*;7-G:60@(DUO
M9'5L=7,B"FUS9W-T<B`B4')E8F%C:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"B,L(&9U>GIY"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36%R="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-:F5S9>AN;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*
M;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@
M:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-
M;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!#
M;&]U9'DB"FUS9W-T<B`B2V]P:7)A:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y"B,L(&9U>GIY"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B<&]M:F5R
M:2!N:;YE(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3$S"B,L(&9U>GIY"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B4')E8F%C
M:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PHC
M+"!F=7IZ>0IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")0<F5B86-I(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"B,L(&9U
M>GIY"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E!R96)A8VDB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"B,L(&9U>GIY
M"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B<&]M:F5R:2!N:;YE(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"B,L(&9U
M>GIY"FUS9VED(")-;W9E('5P(@IM<V=S='(@(G!O;6IE<FD@=FFY92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R
M(")-87)T:6YI:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*
M;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U
M-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*(RP@9G5Z>GD*;7-G:60@(DUU;'1I
M<&QE('-E;&5C=&EO;B(*;7-G<W1R(")N:6IE9&YO('!R879I;&\@;FEJ92!O
M9&%B<F%N;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*(RP@
M9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B4F'H=6YO=F]D<W1V
M;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I
M9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")68;EE(&EN9F]R
M;6%C:6IE(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(E)A<W!O<F5D(&UO9R!P
M;W)T86QA(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I
M9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")287-P;W)E9"!M;V<@<&]R
M=&%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@
M(DEM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B3F%M:6)I82(*
M;7-G<W1R("):86UB:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYE<&%L
M(@IM<V=S='(@(DYO=F$@<&^Y=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*
M;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYO=FD@6F5L86YD(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS
M9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O
M;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I
M9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B37)E
MOF$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R(").:6MA9&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F]V82!+86QE
M9&]N:6IA(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").;W9A
M(&MA=&5G;W)I:F$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R(").;W9A('!O<G5K82`H)7,I
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H
M<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*
M;7-G<W1R(").;W9I(&UJ97-E8R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI
M(@IM<V=S='(@(DYO=F\@:V]R:7-N:>AK;R!I;64@*&YI:F4@;V)A=F5Z;F\I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").
M;W9I(%IE;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(JEI9G)A
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").;W9I('!R
M;WIO<B`H7W!R87IA;BDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(X.0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W9O<W1I(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P
M<R(*;7-G<W1R(").97=S+6=R=7!E(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B1&%L:F4B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@
M-"!0:&%S97,B"FUS9W-T<B`B4VQJ961EYF$@9F%Z82(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,S<V"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B4VQJ
M961EYF4@;W!C:6IE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ
M,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S='(@(D1A;&IE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEK87)A9W9A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEJ
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@
M(DYI9VAT(@IM<V=S='(@(DYOYB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU
M92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B3F4B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V
M86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E
M<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G
M:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE
M(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@8VAA;F=E+B(*;7-G<W1R(")0<F]M:F5N:2(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T
M"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*(RP@9G5Z
M>GD*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").
M;W9E('!O<G5K92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@W-PHC+"!F=7IZ>0IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R
M(")0;VQJ92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B5S(&YI:F4@<')O
M;F'P96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYI:F5D86X@
M9F]L9&5R(&YI:F4@<W!E8VEF:6-I<F%N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DYO=F4@<&]R=6ME(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R
M(")N:6MA:V%V('1E:W-T(&YI:F4@<W!E8VEF:6-I<F%N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*(RP@9G5Z
M>GD*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(FYI:V%K
M878@=&5K<W0@;FEJ92!S<&5C:69I8VER86XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P
M+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U
M=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C@V"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P
M<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B
M"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD
M:6YG('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HW-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A
M('-E="XB"FUS9W-T<B`B3F4@:7IB<FES86YA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM
M<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B3FEJ961N82(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B;FEK86MA=B!T96MS="!N:6IE
M('-P96-I9FEC:7)A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S
M(@IM<V=S='(@(DYE(&EZ8G)I<V%N82(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N(@IM<V=S='(@(DYI:F4@<&]S;&%N;R!K;W)I<VYIZ&MO(&EM92!I+VEL
M:2"Y:69R82XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T
M,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW
M,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*
M;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I
M;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G
M<W1R(").:6IE9&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R
M9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3F]R9&EJ<VMI("A)4T\M.#@U
M.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYO<F9O;&L@
M27-L86YD(@IM<V=S='(@(DUA<KEA;&]V82!O<W1R=F$B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").
M;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PHC
M+"!F=7IZ>0IM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S
M='(@(DUA<KEA;&]V82!O<W1R=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*
M;7-G:60@(DYO<G=A>2(*;7-G<W1R(")0<F]S;&EJ961I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@
M(DYO="!!9G1E<B(*;7-G<W1R(").;W0@1')A9G0B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0HC+"!F=7IZ>0IM<V=I9"`B3F]T
M($)E9F]R92(*;7-G<W1R(").;W0@1')A9G0B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HT,#@*(RP@9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C
M=&]R>2(*;7-G<W1R(")0<F%V86,@<V]R=&ER86YJ82(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"B,L(&9U>GIY"FUS9VED(").;W0@:6UP;&5M96YT960N
M(@IM<V=S='(@(DYE(&EZ8G)I<V%N82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S
M970B"FUS9W-T<B`B3F4@:7IB<FES86YA(@H*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HV-C4*(RP@9G5Z>GD*;7-G:60@(DYO="!S=7!P;W)T
M960N(@IM<V=S='(@(DYE(&EZ8G)I<V%N82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`HC+"!F
M=7IZ>0IM<V=I9"`B3F]T97,B"FUS9W-T<B`B3FEJ961N82(*"B,Z('-E<G9I
M8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B
M<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R(").;W9E;6)A<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(").;W9E;6)A<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E
M<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"B,L(&9U>GIY"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")P;VUJ97)I(&YIOF4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@HC+"!F
M=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B3F]V96UB87(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B5&5M
M82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"B,L(&9U>GIY
M"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")496UA(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3VMT;V)A<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I
M9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*
M;7-G<W1R("*I:69R82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R
M96-T+B(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M3VUA;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*(RP@9G5Z>GD*;7-G:60@(D]N
M;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B3F5D;WIV
M;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D]P97)A=&EV
M;FD@<VES=&5M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U
M,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-I:F4B"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B3W!C
M:6IE('IA("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ.`HC+"!F=7IZ>0IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S
M='(@(DQI<W1A('-A('1AZ&MA;6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-PHC+"!F=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N
M(@IM<V=S='(@(E)E9VES=')A8VEJ82!K;W)I<VYI:V$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T
M:6]N86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@
M(E5P;WIO<F5N:F4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I
M9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B3W-T86QO(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M
M871I;VXB"FUS9W-T<B`B3W-T86QE(&EN9F]R;6%C:6IE(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B3W=N97(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B2V]R:7-N:>AK92!O<&-I:F4B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@
M(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I
M;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$R-S,*(RP@9G5Z>GD*;7-G:60@(E!'4"!$:6=I=&%L(%-I
M9VYA='5R92(*;7-G<W1R("):871A;6YI('!O='!I<V4_(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G
M:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D
M92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM
M<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")0
M32!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I
M9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"B,L(&9U>GIY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@
M(E!A;F%M82(*;7-G<W1R(")+86YA9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@HC
M+"!F=7IZ>0IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B3FEK87)A9W9A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*(RP@
M9G5Z>GD*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B2V]P:7)A:B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*
M;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(JEI9G)A(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U
M:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"B,L(&9U>GIY"FUS9VED
M(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")087-S=V]R
M9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ
M>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A
M<W-W;W)D.B`B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"B,L(&9U>GIY"FUS9VED(")0
M87-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B16UA:6P@861R97-A(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*(RP@9G5Z>GD*;7-G:60@
M(E!A<W1E(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP
M8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM<V=I9"`B4&%T:"(*;7-G<W1R
M(")$871U;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS
M9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(DQJ=61I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4')O8V5N870B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(DEZ=G*Y
M:2!S97)V:7-N92!O<&5R86-I:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(DEZ=G*Y:2!S97)V:7-N92!O<&5R86-I:F4@
M<')I;&EK;VT@;&]G:7)A;FIA/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(D1O>G9O
M;&4B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B1&]Z=F]L92!Z82(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R(")$;WIV;VQE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*
M(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E]$;WIV;VQE
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I:F$@9&]Z=F]L82`H
M<')I=FEL96=I:F$I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS
M9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("),:>AN92!I;F9O
M<FUA8VEJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")0:&]N92(*;7-G<W1R(")N;VYE(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U-S$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(DUO;&EM('1E('!O
M<')A=FD@9'9O<VUI<VQE;F4@;V1N;W-N;R!I;G9A;&ED;F4@861R97-E+B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R
M"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A
M9&1R97-S+B(*;7-G<W1R(")-;VQI;2!T92!P;W!R879I(&1V;W-M:7-L96YE
M(&]D;F]S;F\@:6YV86QI9&YE(&%D<F5S92XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"B,L
M(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G
M<W1R(")-;VQI;2!T92!P;W!R879I(&1V;W-M:7-L96YE(&]D;F]S;F\@:6YV
M86QI9&YE(&%D<F5S92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN(@IM<V=S='(@(DUO;&EM;R!D86IT92!K<F%T86L@;W!I<R!V
M8;EE9R!P<F]B;&5M82!S82!W96)M86EL;VTN(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9"(*;7-G<W1R(").:6IE('!O<VQA;F\@:V]R:7-N:>AK
M;R!I;64@:2]I;&D@N6EF<F$N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@
M(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@
M=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*(RP@9G5Z>GD*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")4<F&^:2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I
M9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R
M='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B4VQA;FIE
M('4@;W9A:B!F;VQD97(@*&YI:F4@<')I;G7P96YO(&]D('-T<F%N92!)34%0
M82DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N
M(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N
M/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"B,L(&9U
M>GIY"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C,*(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS9W-T<B`B4')E=&AO
M9&YA('-T<F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(E!R
M971H;V1N92!O<&-I:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B
M4')O8FQE;3\B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B3W!I<R!P<F]B;&5M82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE
M8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@U"B,L(&9U>GIY"FUS9VED(")0<F]M<'0@=&5X
M="(*;7-G<W1R("))<W!R879L:F5N('1E:W-T(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U
M"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I
M<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B46%T87(B"FUS9W-T<B`B1&%T
M=6TB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B
M475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(V-`HC+"!F=7IZ>0IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#,*(RP@9G5Z>GD*;7-G:60@(E)A:6XB"FUS
M9W-T<B`B57!O>F]R96YJ92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS
M9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")2
M86EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B
M4F%T:6\B"FUS9W-T<B`B3W!C:6IE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#`*(RP@9G5Z>GD*;7-G:60@(E)E860B"FUS9W-T
M<B`B3F4@<')OZ&ET86YE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
MR&ET86YJ92!P;W)U:V$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(DEN9F]R;6%C:6IE('-E<G9I<V$B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I
M9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB
M"FUS9W-T<B`B0;YU<FER86H@9&EN86UIZ&ME(&5L96UE;G1E(&UE;FEJ83HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2969R97-H
M(%!O<G1A;"!6:65W.B(*;7-G<W1R(")!OG5R:7)A:B!P;^AE=&YU('-T<F%N
M:6-U.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,S4*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@(E!O;FFY
M=&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`B3F4@<')O
MZ&ET86YE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*(RP@9G5Z>GD*
M;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B6F%B:6QJ9;EK92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM
M<V=S='(@(E5D86QJ96YI('-E<G9E<FDB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")59&%L:F5N:2!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@
M(DYA<W1A=FDB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")5:VQO;FD@
M;V1A8G)A;FDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34W"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S
M='(@(G!O;6IE<FD@;FF^92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M
M871T:6YG(@IM<V=S='(@(DEN9F]R;6%C:6IE('-E<G9I<V$B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`HC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`B<&]M:F5R:2!V:;EE(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F
M<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")5
M:VQO;FD@;V1A8G)A;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO
M9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W9E('5S97(B"FUS9W-T<B`B:7IB86-I(&EZ=F]R(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B:7IB86-I(&EZ=F]R
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@
M(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B
M92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@
M(E!O;FFY=&DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O
M<F0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")087-S=V]R
M9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@
M3&%S="!1=65R>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M-@HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")297IU;'1A=&D@
M<')E=')A9V4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/
M<'1I;VYS(@IM<V=S='(@(DYA>F%D(&YA(&]P8VEJ92(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T>7!E
M(&YE=R!P87-S=V]R9"(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B5G)A=&D@
M<W1A<G4@:V]N9FEG=7)A8VEJ=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S(*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R
M(")/<&-I:F4@961I=&]R82!T96MS=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"B,L(&9U
M>GIY"FUS9VED(")2:6=H="(*;7-G<W1R(").;^8B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PHC+"!F=7IZ
M>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(EIA9&YJ82!S=')A;F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")/<V]B:6YE(.9?96QI:F4N+BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")2
M;VQE(@IM<V=S='(@(DYA<W1A=FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2
M;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C4*(RP@9G5Z>GD*;7-G:60@(E)O=&%T92`Q.#`B
M"FUS9W-T<B`B3&ES=&$@:V]N=&%K=&$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"B,L(&9U>GIY"FUS9VED(")2;W1A
M=&4@3&5F="(*;7-G<W1R("),:7-T82!K;VYT86MT82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*(RP@9G5Z>GD*;7-G
M:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("),:7-T82!K;VYT86MT82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#D*(RP@9G5Z>GD*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(D]S
M;V)I;F4@YE]E;&EJ92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(E)O=R!P
M<F]P97)T:65S(@IM<V=S='(@(D]S;V)I;F4@YE]E;&EJ92XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED
M(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE
M<R(*;7-G<W1R(")297IU;'1A=&D@<')E=')A9V4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E)U
M;B(*;7-G<W1R(")2975N:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S
M<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@
M9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G<W1R(")+86YA9&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX,0HC+"!F=7IZ>0IM<V=I9"`B4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")5<VUJ97)E
M;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B
M4')E9VQE9&%V86YJ92!P;W)U:V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"B,L(&9U>GIY
M"FUS9VED(")382(*;7-G<W1R(")38>AU=F%J(&MA;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N
M="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F
M<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z
M>GD*;7-G:60@(E-A;6]A(@IM<V=S='(@(DMA;6)O\&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V"B,L(&9U>GIY"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E5P;WIO
M<F5N:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I
M;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*(RP@9G5Z>GD*
M;7-G:60@(E-A=F4B"FUS9W-T<B`B4V'H=79A:B!K86\B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")38>AU=F%J(&MA;R(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E-AZ'5V86H@:V%O
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/
M<'1I;VYS(@IM<V=S='(@(E-AZ'5V86H@;W!C:6IE(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HW,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5G)A=&D@<W1A
M<G4@:V]N9FEG=7)A8VEJ=2(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(").:6IE(&)I;&\@
M;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E
M<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E1R8;YI(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`HC+"!F=7IZ>0IM<V=I
M9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B4F5Z=6QT871I('!R971R86=E
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(D]D86)E<FD@<W9E(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")/9&%B97)I(&ED
M96YT:71E="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B
M3V1A8F5R:2!K;V1N:2!R87-P;W)E9"!S;&]V83HB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!N
M97<@;W=N97(B"FUS9W-T<B`B3V1A8F5R:2!N;VYE(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B
M"FUS9W-T<B`B27IA8F5R:71E('-E<G9E<B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!U<V5R
M('1O(&%D9"(*;7-G<W1R(")/9&%B97)I(&MO9&YI(')A<W!O<F5D('-L;W9A
M.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B3V1A8F5R
M:2!S=F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T
M<B`B4')I;&]G(&IE(&]B<FES86XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&%N(&]B:F5C="(*;7-G<W1R(")/9&%B97)I(&YO;F4B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@;F]N92(*;7-G<W1R(")/9&%B97)I(&YO;F4B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHS-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CHB"FUS9W-T<B`B3V1A8F5R:2!K;V1N:2!R87-P;W)E9"!S;&]V83HB"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B3V1A8F5R:2!K;V1N
M:2!R87-P;W)E9"!S;&]V83HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO
M=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B27IA8F5R:71E(&ED96YT:71E
M="!K;VII(+YE;&ET92!P<F]M:6IE;FET:3HB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE
M(&1E;&EM:71E<CHB"FUS9W-T<B`B3V1A8F5R:2!K;V1N:2!R87-P;W)E9"!S
M;&]V83HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B3V1A
M8F5R:2!K;V1N:2!R87-P;W)E9"!S;&]V83HB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4W"B,L(&9U>GIY"FUS9VED(")396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B3V1G;W9A<F%J=>9A('!O;&IA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("))>F%B97)I=&4@N65M=2!B;VIA
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B27IA8F5R:71E
M(+YE;&IE;FD@:F5Z:6LZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B
M4&^Y86QJ:2!P<FEJ879U('!R;V)L96UA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM
M<V=S='(@(E!ON6%L:FD@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N
M96=A;"(*;7-G<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;GIO<CH@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@
M(E-E<'1E;6)E<B(*;7-G<W1R(")397!T96UB87(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(@IM<V=S='(@(E-R8FEJ82!I($-R;F$@1V]R82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(E-E<FEJ<VMI(&)R;VHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").96UA
M(&1O<W1U<&YI:"!O<&-I:F$N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W
M"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(D%D;6EN
M:7-T<F%C:6IA(&1O>G9O;&$@*'!R:79I;&5G:6IA*2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B
M4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("))1"!S97-I:F4@:F4@:7-T
M96MA;RXB"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E
M<W-I;VYS(@IM<V=S='(@(E]$;WIV;VQE(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(D]D86)E<FDB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB4&]D97-I=&4@;W!C:6IE(&MO
M:F4@=F%M(&]M;V=UYG5J=2!D82!P;VYIN71I=&4@N6EF<G4@86MO(&IE('IA
M8F]R879I=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I
M9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*(E!O9&5S:71E('5D
M86QJ96YE('-E<G9E<F4@:V]J:6UA(+YE;&ET92!P<FES='5P:71I('!U=&5M
M('9AN65G('!O<G1A;&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T
M"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(D]D86)E<FET92"^96QJ96YI
M(&IE>FEK+"!V<F5M96YS:W4@>F]N=2!I('!O<W1A=FME('IA(&1A='5M+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(B(*(E!O9&5S:71E('-T87)T;G4@:V]M<&]N96YT=2P@N65M=2!B;VIA
M+"!O<W9J9;YA=F%N:F4@<W1R86YI8V4@:2!D<G5G92!O<&-I:F4@(@HB:V]J
M92!S92!T:>AU('!R:6MA>F$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B4&]S=&%V:V4B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@
M=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@
M(E-E:KEE;&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS
M9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R
M(")+<F%T86L@;W!I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*
M;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(*;7-G<W1R(")$82!L:2!D969I;FES871I('!R:7-T=7!N92!T
M:7!K92!Z82!L:6YK;W9E/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(E!R:6MAOFDB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B4')I:V&^:2!V
M<FEJ96UE('IA9&YJ92!P<FEJ879E(&YA:V]N(&QO9VER86YJ83\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO
M;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B4')I:V&^:2!M
M96YI('IA(&UA;FEP=6QA8VEJ92!T86)E;&%M83\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE
M("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(E!R:6MAOFD@)7,@;65N
M:2!L:6IE=F\_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`HC+"!F=7IZ
M>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B4')I:V&^:2!M96YI('IA(&UA;FEP=6QA8VEJ92!T86)E;&%M83\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=7!L
M;V%D(@IM<V=S='(@(D1O=VYL;V%D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,B
M"FUS9W-T<B`B4')I:V&^:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")3:&]W97)S($5A<FQY
M(@IM<V=S='(@(DMR871A:R!O<&ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS
M9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE
M:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M-0HC+"!F=7IZ>0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(E<R!P<FEJ879A
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*(RP@
M9G5Z>GD*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")68;D@<&]T<&ES.B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"B,L(&9U
M>GIY"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(E9AN2!P
M;W1P:7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4VEN9V%P
M;W)E(@IM<V=S='(@(E9AN2!P;W1P:7,Z(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")696QIZ&EN82(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R
M"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(E!R97-K;^AI('-E
M<G9I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"B,L
M(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(E!R:6MAOFDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO
M=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3
M;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S
M='(@(B!496UA.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I
M9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*
M(RP@9G5Z>GD*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@
M(E!R879A8R!S;W)T:7)A;FIA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B
M4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B5F&Y82!E+6UA:6P@861R97-A.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R
M;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(DIUOFYO+65V<F]P<VMI("A)
M4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*
M(RP@9G5Z>GD*;7-G:60@(E-P86-E<B(*;7-G<W1R(")38>AU=F%J(&MA;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3
M<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")3<&5C:6%L($-H87)A
M8W1E<B!);G!U="(*;7-G<W1R(")3<&5C:6IA;&YI(&MA<F%K=&5R:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C(*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B3V1A8F5R
M:2!S=F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8V"B,L(&9U>GIY"FUS9VED(")3<&QI="!C;VQU;6XB"FUS
M9W-T<B`B3V1A8F5R:2!S=F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Q"B,L(&9U>GIY"FUS9VED(")3<&QI
M="!R;W<B"FUS9W-T<B`B3V1A8F5R:2!S=F4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B2V%L96YD87(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE
M87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED
M(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T
M<B`B26YF;W)M86-I:F4@<V5R=FES82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E970@061D
M<F5S<R(*;7-G<W1R(")/9"!A9')E<V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*
M(RP@9G5Z>GD*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(FQI<W1A('IA
M9&%T86MA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I
M9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B
M"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3
M=6)J96-T(@IM<V=S='(@(E1E;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W
M"B,L(&9U>GIY"FUS9VED(")3=6)M:70B"FUS9W-T<B`B5&5M82(*"B,Z('-I
M9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I<'0B
M"FUS9W-T<B`B5&5M82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")5<W!J9;EN
M;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(EPB)7-<(B!J92!U<W!E<VYO(&1O9&%N('4@861R97-A
M<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@:F4@=7-P
M97-N;R!D;V1A;B!U(&%D<F5S87(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T
M<B`B26UE(&9O;&1E<F$@7"(E<UPB(&IE('5S<&IEN6YO('!R;VUJ96YJ96YO
M('4@7"(E<UPB+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&IE('5S<&5S;F\@
M9&]D86X@=2!A9')E<V%R(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN
M(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("));64@9F]L
M9&5R82!<(B5S7"(@:F4@=7-P:F6Y;F\@<')O;6IE;FIE;F\@=2!<(B5S7"(N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("));64@9F]L9&5R82!<(B5S7"(@
M:F4@=7-P:F6Y;F\@<')O;6IE;FIE;F\@=2!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM
M<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")+<F%T86L@;W!I<R(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B4W5N(%)I<V4B
M"FUS9W-T<B`B5&5M82(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`HC
M+"!F=7IZ>0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")496UA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U
M;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,38*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B5&5M82(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T
M<B`B5&5M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*
M(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(@5&5M83H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0HC+"!F=7IZ>0IM
M<V=I9"`B4W5N<V5T(@IM<V=S='(@(E1E;6$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$X"B,L(&9U>GIY"FUS9VED(")3=6YS970Z("(*
M;7-G<W1R("(@5&5M83H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4W5P97)S8W)I<'0B
M"FUS9W-T<B`B5&5M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC
M+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B26UE(&1A=&]T96ME
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@
M9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B57-E<FYA;64B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R(")4<F&^:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G
M:60@(E-W961E;B(*;7-G<W1R(")6:61J96YA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO9R!D96QE
M=&5D(@IM<V=S='(@(E5N9&5L971E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B4WEN
M=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("))<W!R87IN:2!F
M;VQD97(@:V]R<&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"B,L(&9U>GIY"FUS9VED(")3
M>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")#96YT<F%L;F\M069R:>AK
M82!297!U8FQI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3
M=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E0M4W1O
M<FUS(@IM<V=S='(@(D]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@
M(E135B!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]486)L
M92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R("):861N
M:F$@<W1R86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R(")/<V]B:6YE(%]T86)E;&4N+BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L
M92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@
M<')O<&5R=&EE<R(*;7-G<W1R(")/<V]B:6YE(%]T86)E;&4N+BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B4&]R=6MA
M(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3@W"B,L(&9U>GIY"FUS9VED(")487-K<R(*;7-G<W1R
M("),;V=I;B!Z861A8VDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,PHC+"!F=7IZ>0IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*
M;7-G<W1R(")397)I:G-K:2!B<F]J(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C8X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B5&5M
M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B)7,@861M:6YI<W1R86-I
M:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5K
M<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"B,L(&9U>GIY"FUS
M9VED(")497AT($]N;'DB"FUS9W-T<B`B5&5K<W0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"B,L(&9U>GIY
M"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(E-L:F5D96-A('-T<F%N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*
M(RP@9G5Z>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5K<W0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0HC+"!F=7IZ>0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5')AOFDB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO
M=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B2'9A;&$@N71O(&MO
M<FES=&ET92!%;F5R9V]D871A('=E8FUA:6PN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,C`*(RP@9G5Z>GD*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0(&%D<F5S82!N
M:6IE(&1O<W1U<&YA+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E
M9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y
M,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q
M"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@
M<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")0<F]Z;W(@>F$@;W!C:6IE
M('-E('IA='9O<FEO+B!)>FQA>FEM+B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y
M"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB
M9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B7"(E<UPB(&IE('5S<&5S;F\@9&]D86X@=2!A9')E<V%R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@
M:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L
M;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@
M86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB
M9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD
M+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@
M=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L
M;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET970@7"(E
M<UPB(&IE(&]B<FES86XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN
M<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S
M96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@
M9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@
M8F4@;G5M97)I8RXB"FUS9W-T<B`B3W9A('9R:6IE9&YO<W0@;6]R82!B:71I
M(&)R;VHN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM
M=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@
M(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<(B!J92!O8G)I<V%N+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB
M"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<(B!J92!S8>AU=F%N+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*
M;7-G<W1R("))9&5N=&ET970@7"(E<UPB(&IE('-AZ'5V86XN(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q
M,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T
M:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED
M(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R
M86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*(RP@9G5Z
M>GD*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(").96UA(&1O<W1U<&YI:"!O<&-I:F$N(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H
M97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3F5M82!D
M;W-T=7!N:6@@;W!C:6IA+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C,T,@HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DYE
M;6$@9&]S='5P;FEH(&]P8VEJ82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S
M97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B
M"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!S;&%N:F$@<&]R=6ME
M.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!S;&%N
M:F$@<&]R=6ME.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A
M=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K
M;VT@<VQA;FIA('!O<G5K93H@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@HB2F%V:6\@<V4@<')O8FQE;2!S
M82!D;V1A=F%N:F$@9&%T;W1E:V4N($UO9W7F:2!P<F]B;&5M+"!D871O=&5K
M82!J92!V9>9A(&]D("(*(FUA>"!D;WIV;VQJ96YI:"!-0BXB"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM
M=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(DIA
M=FEO('-E('!R;V)L96T@<V$@9&]D879A;FIE;2!D871O=&5K92X@36]G=>9I
M('!R;V)L96TL('9E;&GH:6YA(&1A=&]T96ME("(*(FIE('9EYF$@;V0@;6%X
M+B!D;WIV;VQJ96YI:"`H)60@34(I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@Y,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B
M(@HB2F%V:6\@<V4@<')O8FQE;2!S82!D;V1A=F%N:F$@9&%T;W1E:V4N($UO
M9W7F:2!P<F]B;&5M+"!D871O=&5K82!J92!V9>9A(&]D("(*(FUA>"!D;WIV
M;VQJ96YI:"!-0BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")$97-I;&$@<V4@9W)E
MN6MA('1O:V]M('!R:6MA>F$@;W9O9R!D:6IE;&$@<&]R=6ME(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C
M="!D871A+B(*;7-G<W1R(")$97-I;&$@<V4@9W)EN6MA('1O:V]M('-P8;EA
M=F%N:F$@;F5Z879RN65N92!P;W)U:V4N(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]I;6,N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B
M1&5S:6QA('-E(&=R9;EK82!T;VMO;2!S<&&Y879A;FIA(&YE>F%V<KEE;F4@
M<&]R=6ME+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*(RP@9G5Z
M>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG
M=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I
M<F5D(&9I96QD+B(*;7-G<W1R(")$97-I;&$@<V4@9W)EN6MA('1O:V]M(.AI
M=&%N:F$@;V1A8G)A;F4@<&]R=6ME+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"B,L(&9U>GIY"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2#H:71A;FIA
M(&]D86)R86YE('!O<G5K92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(D1E<VEL82!S92!G
M<F6Y:V$@=&]K;VT@<')I:V%Z82!O=F]G(&1I:F5L82!P;W)U:V4B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@HC+"!F
M=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2#H:71A;FIA(&]D86)R
M86YE('!O<G5K92XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(E9A
MN2!B<F]W<V5R(&YE('!O9'*^879A(&]V=2!M;V=UYFYO<W0N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`HC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92XB"FUS9W-T<B`B)7,@;F4@:7IG;&5D82!K86\@9&]Z=F]L:F5N
M('1I<"!S86YD=6-E=&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B)7,@;F4@
M:7IG;&5D82!K86\@9&]Z=F]L:F5N('1I<"!S86YD=6-E=&$N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM
M<V=S='(@(B5S(&YE(&EZ9VQE9&$@:V%O(&1O>G9O;&IE;B!T:7`@<V%N9'5C
M971A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A
M9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@
M(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R
M(")/=F$@=G)I:F5D;F]S="!M;W)A(&)I=&D@8G)O:BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU
M<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T
M+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A
M;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F
M('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M(@IM<V=S='(@(E9R:6IE9&YO<W0@;W9O9R!B<F]J82!M;W)A(&YA:FUA;FIE
M(&EZ;F]S:71I(#$N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B3W9A('9R:6IE
M9&YO<W0@;6]R82!B:71I(&)R;VHN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")/=F%J('!R
M;WIO<B!S92!S;6EJ92!P;WII=F%T:2!S86UO(&EZ('!R;WIO<F$@3W!C:6IE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*
M;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R(")6
M<F5M96YS:V$@>F]N82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$W"B,L(&9U>GIY"FUS9VED(")4:6UE(&9O<FUA="(*
M;7-G<W1R(")6<F5M96YS:V$@>F]N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U,SD*(RP@9G5Z>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM
M<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,`HC+"!F=7IZ>0IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5G)E;65N<VMA('IO
M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@
M(E1O(@IM<V=S='(@(EIA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I
M9"`B5&]D87DB"FUS9W-T<B`B5&EJ96QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@
M4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G
M:60@(E1O9V\B"FUS9W-T<B`B6F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,3,*(RP@9G5Z>GD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B`H
M<W5T<F$I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&]N9V$B
M"FUS9W-T<B`B6F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S<*(RP@9G5Z>GD*;7-G:60@(E1O<"(*;7-G<W1R
M("):82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N
M<VQA=&EO;G,B"FUS9W-T<B`B06MC:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)S
M:VD@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE
M;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@
M(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@
M>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW
M"FUS9VED(")54DPZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z
M>GD*;7-G:60@(E5G86YD82(*;7-G<W1R(")+86YA9&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(E5N9&5L971E
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"FUS9VED(")5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HT,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N(@IM<V=S='(@(DYE(&UO9W4@<V4@<W!O:FET:2!N82!)
M34%0('-E<G9E<CH@)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@
M=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S
M-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S
M"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O
M<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO
M;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"B,L
M(&9U>GIY"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B56YD96QE=&4B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`B4&]N:;ET:2!I>FUJ96YE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO
M=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3F5K871E9V]R:7-A;F\B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H
M551&+3@I(@IM<V=S='(@(E5N:6MO9"`H551&+3@I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(E5J961I;FIE
M;FD@07)A<'-K:2!%;6ER871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET
M960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"B,L(&9U>GIY
M"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(E5J961I;FIE;FD@07)A
M<'-K:2!%;6ER871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N
M<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM
M<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R
M('!A<W-W;W)D+B(*;7-G<W1R(").97!O>FYA=&\@:V]R:7-N:>AK;R!I;64@
M:6QI(+EI9G)A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B4&]D97-I('9R96UE;G-K=2!Z
M;VYU+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(D)E>FEM96YI(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"B,L
M(&9U>GIY"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")0<FEM;&IE;F$@
M<')I:F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X
M-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P
M;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,S"B,L(&9U>GIY"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B1&%T=6TB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B1&%T
M=6TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"B,L
M(&9U>GIY"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")$871U;2(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P
M,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B1&%T=6TB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ.`HC+"!F=7IZ>0IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R(")$96-E;6)A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R
M=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@
M(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N(@IM<V=S='(@(DMO<FES=&ET92!O=F\@86MO('-E(&EM92^Y:69R
M82!R87IL:6MU:G4@>F$@24U34"!S97)V97(N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*
M;7-G<W1R(")5<V5R;F%M92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R(")+;W)I<VYI:R`E
M<R!N96UA(&1O>G9O;'4@>F$@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"B,L(&9U>GIY"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B5S(&%D;6EN:7-T<F%C:6IA(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")+;W)I
M<VYIZ&ME(&]P8VEJ92(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@
M4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E9VES=')A8VEJ82!K;W)I<VYI:V$B
M"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"B,L(&9U>GIY"FUS9VED(")5
M<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B5S(&YI:F4@<')O;F'P
M96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS
M9W-T<B`B2V]R:7-N:>AK;R!I;64B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D9O;&1E
M<B!<(B5S7"(@=F7F('!O<W1O:FDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M(")5<V5R;F%M92(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*
M(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B57-E<FYA;64B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5
M<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*(RP@
M9G5Z>GD*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%K8VEJ82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I
M;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@
M;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y
M"FUS9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS
M9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*
M;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`HC+"!F=7IZ>0IM<V=I
M9"`B5F5R<VEO;B(*;7-G<W1R("),:>AN;R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C8*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VX@0V]N=')O
M;"(*;7-G<W1R("),:>AN;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E<G1I
M8V%L(&%L:6=N(@IM<V=S='(@(E-L:F5D96-A('-T<F%N82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E
M<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B26UE(&1A
M=&]T96ME(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I
M971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@)7,B"FUS9W-T<B`B4')I:V%Z("5S(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B
M"FUS9W-T<B`B4')I:V%Z("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM
M<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6
M;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A
M(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM
M<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R(")5<&]Z;W)E;FIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T
M:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*
M(RP@9G5Z>GD*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N
M8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS
M9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T
M<B`B4V5D;6GH;F\B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")$;V)R;R!D;[EL:2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S
M(@IM<V=S='(@(D1O8G)O(&1ON6QI(&YA("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D1O
M8G)O(&1ON6QI+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS
M9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("):87!A9&YI("A)
M4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B6F%P861N:2`H25-/
M+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A
M(@IM<V=S='(@(EIA<&%D;F$@4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")+
M;VIU(&MO;7!O;F5N='4@YF4@)7,@<')I:V%Z871I(&YA:V]N('5L87IA/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I
M<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B
M2V]J92!D;V1A=&ME(+YE;&ET92!A:W1I=FER871I('IA(&5D:71O<B!F;W)M
M871I<F%N;V<@*')I8V@I('1E:W-T82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"B,L(&9U>GIY"FUS9VED
M(")7:61T:"(*;7-G<W1R(")4<F&^:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M
M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"B*I:7)I
M;F$@)7,@;65N:6IA('-A(&QI:F5V92!S=')A;FEC92`H<W1U<&$@;F$@<VYA
M9W4@:V]D('-L:F5D9>9E('!R:6IA=F4I.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T
M:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3`*(RP@9G5Z>GD*;7-G:60@(E=I9'1H('5N
M:70B"FUS9W-T<B`B3&ET=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-0HC+"!F=7IZ>0IM<V=I9"`B5VED=&@Z(@IM
M<V=S='(@(E1R8;YI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q
M,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7:6YD(@IM<V=S='(@(E1R8;YI
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*
M(RP@9G5Z>GD*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5')AOFDB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN
M(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V
M"B,L(&9U>GIY"FUS9VED(")7:6YD.B(*;7-G<W1R(")4<F&^:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*(RP@9G5Z>GD*;7-G:60@
M(E=I;F0Z("(*;7-G<W1R(")4<F&^:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E1R8;YI
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES
M:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U
M"B,L(&9U>GIY"FUS9VED(")7;W)K(@IM<V=S='(@(FEL:2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`HC+"!F=7IZ>0IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D]D(&%D<F5S92(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*(RP@9G5Z
M>GD*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5L969O;B`H:W7F:2DB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!6
M1E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME
M>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-34*;7-G:60@(EE965DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(D=O9&FY;FIE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B665M96XB"FUS9W-T<B`B
M5FED:F5N82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R(")$82(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L
M($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO
M="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB
M"FUS9W-T<B`B3F4@;6^^92!S861ROF%V871I("=<7"<@:V%R86MT97(@=2!T
M=F]M('!U;F]M(&EM96YU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G
M<W1R(")/9&IA=FQJ:79A;FIE(&IE('5S<&IEN6YO(&EZ=G*Y96YO+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA
M=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(").961O>G9O;&IE
M;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@
M82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U
M(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU
M<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N(@IM<V=S='(@(DUO<F%T92!O9&%B<F%T:2!I9&5N=&ET970@
M:V]J:2"^96QI=&4@8G)I<V%T:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N(@IM<V=S='(@(DUO<F%T92!O9&%B<F%T:2!I9&5N=&ET
M970@:V]J:2"^96QI=&4@8G)I<V%T:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N(@IM<V=S='(@(DUO<F%T92!O9&%B<F%T:2!I9&5N=&ET
M970@:V]J:2"^96QI=&4@8G)I<V%T:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV
M,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB
M"FUS9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET
M92!B<FES871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+B(*;7-G<W1R(")-;W)A=&4@;V1A8G)A=&D@:61E;G1I=&5T(&MO:FD@OF5L
M:71E(&)R:7-A=&DN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DUO<F%T92!O9&%B
M<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T:2XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE
M+B(*;7-G<W1R(")-;W)A=&4@;V1A8G)A=&D@:61E;G1I=&5T(&MO:FD@OF5L
M:71E(&)R:7-A=&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I
M9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(@)7,@<V5S:6IA(&IE(&ES=&5K;&$N($UO;&EM;R!D
M82!S92!P;VYO=F\@<')I:F%V:71E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS
M9W-T<B`B5F&Y82!E+6UA:6P@861R97-A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Q,@IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R
M(")68;EA($9R;VTZ(&%D<F5S83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B5F&Y92!I;F9O<FUA8VEJ92(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*
M(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*(E9AN6$@26YT97)N970@861R97-A(&IE('!R;VUI:F5N
M:F5N82!N86MO;B!P<FEJ879L:FEV86YJ82!N82`E<RX@1&$@8FD@=F&Y82`B
M"B)S:6=U<FYO<W0@8FEL82!S8>AU=F%N82P@;6]R871E('-E('!O;F]V;R!P
M<FEJ879I=&DN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")68;EE(&EM92(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI
M<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*
M(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*(E9AN6$@26YT97)N970@861R97-A(&IE('!R;VUI
M:F5N:F5N82!N86MO;B!P<FEJ879L:FEV86YJ82!N82`E<RX@1&$@8FD@=F&Y
M82`B"B)S:6=U<FYO<W0@8FEL82!S8>AU=F%N82P@;6]R871E('-E('!O;F]V
M;R!P<FEJ879I=&DN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G
M:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92XB"FUS9W-T<B`B5F&Y(&)R;W=S97(@;F4@<&]D<KYA=F$@;W9U(&UO9W7F
M;F]S="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC
M+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(E9AN2!B<F]W<V5R(&YE('!O
M9'*^879A(&]P8VEJ=2"Y=&%M<&%N:F$N(%!R:71I<VYI=&4@=&EP:V4@0V]N
M=')O;"M0(&EL:2`B"B)/<'1I;VXK4"!Z82"Y=&%M<&%N:F4N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I
M;64@>F]N93HB"FUS9W-T<B`B5')E;G5T;F$@=G)E;65N<VMA('IO;F$Z(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R
M(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B
M5F&Y(&1E9F%U;'0@:61E;G1I=&5T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T
M<B`B5F&Y(&1E9F%U;'0@:61E;G1I=&5T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,#$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")6
M8;EE(&EM92!I('!R97II;64Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B3W!C:6IE('-U('-AZ'5V86YE+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B5F&Y82!N
M;W9A(+EI9G)A('IA("5S(&IE.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM
M<V=S='(@(E9AN64@;W!C:6IE('-U('-AZ'5V86YE('1O:V]M('1R86IA;FIA
M(&]V92!S97-I:F4N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB
M"FUS9W-T<B`B3W!C:6IE('-U('-AZ'5V86YE+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T(@IM<V=S='(@(E9AN6$@N6EF<F$@:F4@<&]N:;ET96YA(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R
M("(B"B)68;EA(+EI9G)A(&IE('!O;FFY=&5N82P@<')O=FIE<FET92!V8;D@
M92UM86EL(&D@<')I:F%V:71E('-E('-A(&YO=F]M("(*(KEI9G)O;2XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E9AN6$@N6EF
M<F$@:F4@<&]N:;ET96YA(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")6
M8;EI('5D86QJ96YI('-E<G9E<FDZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O<VQA=FEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM
M<V=S='(@(EIA:7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B6F%M8FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E
M(@IM<V=S='(@(EII;6)A8G9E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8V"FUS9VED(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G
M:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");4V%K<FEJ(&-I=&ER
M86YI('1E:W-T72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED
M(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM0<FEJ879A('!R;V)L96UA
M72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM0<FEK8;YI
M(&-I=&ER86YI('1E:W-T("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*
M;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@
M(EM0<FEK8;YI(&-I=&ER86YI('1E:W-T("T@)7,@<F5D;W9A72(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G
M:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");<F5D("5S(&]D("5S72(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B7T%D;6EN:7-T<F%C:6IA(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS
M9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]/8G)IN6D@<F5D(@H*(SH@
M;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P
M92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G
M:60@(E](96QP(@IM<V=S='(@(E]0;VUOYB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM
M86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7T]S;V)I;F4@<VQI:V4N+BXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED
M(")?3&]G(&EN(@IM<V=S='(@(E]0<FEJ879I('-E(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS
M9W-T<B`B7TEZ;&%Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`B7TEZ;6EJ96YI(&QI;FLN+BXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R
M(")?3W!C:6IE(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B7T1O>G9O;&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO
M=F4@3&EN:RXN+B(*;7-G<W1R(")?56ML;VYI(&QI;FLN+BXB"@HC.B!L:6(O
M87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?4&]D97-I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")/
M<V]B:6YE(%]T86)E;&4N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@
M(E]5<V5R<R(*;7-G<W1R(")?2V]R:7-N:6-I(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,C$*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R
M(")I;65N:6LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S-`HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T
M<B`B:6UE;FEK(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*
M(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&%R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B
M8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T
M(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS
M9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z>GD*
M;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B5G)A=&D@<W1A
M<G4@:V]N9FEG=7)A8VEJ=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F
M=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B5S(&YI:F4@
M<')O;F'P96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"B,L(&9U>GIY"FUS9VED(")F
M:6QE(@IM<V=S='(@(DYE:V%T96=O<FES86YO(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B)7,@=2`E<R`E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*(RP@9G5Z>GD*
M;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B
M;F]N92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R
M"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R
M;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"B,L(&9U>GIY"FUS9VED(")L
M:6YE<UTB"FUS9W-T<B`B;F]N92(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R
M"B,L(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@(DEM92(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(FYO="!I;7!L
M96UE;G1E9"(*;7-G<W1R(").92!I>F)R:7-A;F$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*(RP@9G5Z>GD*;7-G:60@(FYO
M="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B3F4@:7IB<FES86YA(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*(RP@9G5Z>GD*;7-G:60@
M(FYO=&5P860B"FUS9W-T<B`B3F4@<')OZ&ET86YE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`HC+"!F=7IZ
M>0IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")0<F]C96YA="(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED
M(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")$;WIV;VQE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM
M<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O
M=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R
M(")5<&]Z;W)E;FIE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D
M:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I
M82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"B,L(&9U>GIY
M"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B3F4@<')OZ&ET86YE(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@
M:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T
M87-K(&QI<W0B"FUS9W-T<B`B;&ES=&$@>F%D871A:V$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y
M(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R(")+
M;V0@<W9A:V4@<')I:F%V92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE
M('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M(RP@9G5Z>GD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B3F5K871E9V]R:7-A
M;F\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED
M(")U;FYA;65D(@IM<V=S='(@(F)E>B!I;65N82(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC+"!F=7IZ
M>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B27IB;W(@8F]J92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I
M9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"B,L(&9U>GIY"FUS9VED(")W.B(*
M;7-G<W1R(")&=V0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]C85]%
M4RYP;P``````````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P-C$S,#(R`#$P-#$W,S8S,#`Q`#`Q-C,T,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C($AO<F1E($-A=&%L86X@
M=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`S($%N9V5L<R!'=6EM
M97+@"B,@06YG96QS($=U:6UE<N`@/$%N9V5L<RY'=6EM97)A0'5A8BYE<SXL
M(#(P,#,N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#(N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#(M
M,3@@,#DZ,SDK,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!!;F=E;',@1W5I
M;65RX"`\06YG96QS+D=U:6UE<F%`=6%B+F5S/EQN(@HB3&%N9W5A9V4M5&5A
M;3H@0V%T86QA;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R
M<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q
M"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*
M;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@;F\@97-TX"!C;VYF:6=U<F%T(&5N
M(&5L(%)E9VES=')E(&1E($AO<F1E+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R
M964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A
M>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R(")/
M<&5R86-I;VYS(&1E($UA;G1E;FEM96YT("5S("T@0V]N9FER;6%C:?,B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+B(*;7-G<W1R("(B"B)-87)Q=65U(&$@;&$@8V%S96QL82!D92!S96QE8V-I
M\R!L)V]P97)A8VGS(&\@;W!E<F%C:6]N<R!Q=64@9&5S:71J974@(@HB97AE
M8W5T87(@96X@87%U97-T82!O8V%S:?,N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U
M:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R
M(")#861A(#4@;6EN=71S(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S
M(&]F("5S(@IM<V=S='(@(EML[6YI82`E<R!D92`E<UTB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B3&QI8G)E=&$@9"=A
M9')E8V5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T
M<B`B0V%L96YD87)I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z
M,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@
M;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@
M;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I
M;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U
M<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@
M(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(DQA('9O<W1R82!);F9O<FUA8VGS
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R
M-"!(;W5R($9O<FUA="(*;7-G<W1R("),82!V;W-T<F$@26YF;W)M86-I\R(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R
M<R(*;7-G<W1R("(R-"!H;W)E<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B/&(^2&$@<W5C
M8V7O="!U;B!E<G)O<B!F871A;#H@/"]B/B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I
M9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!
M32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R
M"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!
M4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@
M(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R("),82!V;W-T<F$@26YF;W)M86-I\R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!0
M87-S=V]R9"(*;7-G<W1R(")#;VYT<F%S96YY82(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C
M;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O
M<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!9&0B"FUS9W-T<B`B061R
M9>=A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H
M<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"B,L
M(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B061R9>=A(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*
M;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@
M<&%I<B(*;7-G<W1R(")!9F5G:7(@<&%R96QL(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S
M($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY
M"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("),;&EB<F5T
M82!D)V%D<F5C97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B3&QI8G)E=&$@9"=A9')E8V5S(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@
M(D%F96=I<B!P87)E;&PB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F7G82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*(RP@9G5Z>GD*;7-G:60@(D%D9')E
M<W,@0F]O:R(*;7-G<W1R("),;&EB<F5T82!D)V%D<F5C97,B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z
M>GD*;7-G:60@(D%D<R(*;7-G<W1R(")!9')EYV$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U
M>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L:65S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&EE<R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(D%L:65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B06QI9VXB"FUS9W-T<B`B06QI97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B
M06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L
M;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U
M"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S
M<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*
M;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-
M4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N
M871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E
M;6%I;"!A9&1R97-S(@IM<V=S='(@(D-O<G)E=2!%;&5C='+R;FEC.B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M
M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E
M('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N
M(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G
M:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B
M4R=H82!E<W!E8VEF:6-A="!U;B!V86QO<B!I;+=L96=A;"XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(\8CY(82!S
M=6-C9>]T('5N(&5R<F]R(&9A=&%L.B`\+V(^(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O
M;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM
M<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN
M<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC
M871I;VXB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R
M"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E
M861Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED
M(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B
M07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D
M96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B
M07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@
M(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A
M8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT
M(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM
M<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G
M:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS
M9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C
M>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U
M"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM
M<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U
M-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E
M<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P
M9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A
M;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL
M960N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--
M0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G
M<W1R(")#86UP<R!D:7-P;VYI8FQE<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G
M:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#
M;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@
M(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B06YI=F5R<V%R:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA('1R;V)A="!A9V5N="!D92!N;W1I
M9FEC86-I\R`E<RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ
M>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D-O<G)E=2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM
M<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@
M(D-A;&5N9&%R:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R
M;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D
M;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M(@IM<V=S='(@(D5R<F%D82!A;"!C;VYN96-T87(@86UB(&5L('-E<G9I9&]R
M($Q$05`N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(D-A;F%D82(*
M;7-G<W1R(")#86QE;F1A<FDB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M
M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A
M;F-E;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@
M(D-A;F-E;+=L87(@26YF;W)M92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT
M-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO
M="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@
M8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!6
M97)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")#87!T:6]N
M(@IM<V=S='(@(D]P8VEO;G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R
M:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B
M"FUS9W-T<B`B5&5LZ&9O;B!#96RW;'5L87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS
M9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B5&5LZ&9O;B!#96RW;'5L
M87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS
M9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@
M<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E
M;.AF;VX@0V5LMVQU;&%R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*
M;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*
M;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R
M=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L
M(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D1E
M<V9E<B!#86YV:7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB
M0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED
M(")#:&%R(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@
M3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED
M(")#:&EL92(*;7-G<W1R(")4[71O;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H
M:6YA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS
M9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B
M0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(DYO(',G:&$@=')O8F%T(&%G96YT(&1E(&YO=&EF:6-A8VGS("5S
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T
M"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G<W1R(")#86QE;F1A<FDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS
M9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@
M(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI
M8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T
M96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B
M0VQO<V4@5VEN9&]W(@IM<V=S='(@(E1A;F-A<B!&:6YE<W1R82(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*
M;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A
M<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*
M;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU
M;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T
M<B`B0V]M<&%N>6EA(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED
M(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I
M9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@
M(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")#
M;VUP86YY:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@
M(D-O;7!U=&5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CDW"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@
M<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M
M(%!A<W-W;W)D(@IM<V=S='(@(D-O;G1R87-E;GEA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM
M<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N
M9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#
M;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F
M(%PB)7-<(B(*;7-G<W1R(")#;VYT:6YG=70@9&4@)R5S)R(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;VUP86YY
M:6$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@
M(D-A;7`@:6UP;W)T870Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD
M('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")%<G)A9&$@86P@8V]N;F5C=&%R
M(&%M8B!E;"!S97)V:61O<B!,1$%0+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B17)R861A(&%L(&-O
M;FYE8W1A<B!A;6(@96P@<V5R=FED;W(@3$1!4"XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B
M0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D
M9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP
M;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D
M:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M
M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L
M:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!O8G)I<B!E;"!M\F1U;"`E<R!-86EN=&5N86YC95]487-K(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").;R!S
M)VAA('!O9W5T(&]B<FER(&5L(&WR9'5L("5S($UA:6YT96YA;F-E7U1A<VLB
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D5R<F%D82!A
M;"!C;VYN96-T87(@86UB(&5L('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R
M=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E
M<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@;F\@97-TX"!C;VYF
M:6=U<F%T(&-O<G)E8W1A;65N="XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T
M:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU
M86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")%
M<G)A9&$@86P@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O<B!,1$%0+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#
M;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I
M9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U
M8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@
M(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I
M9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP
M.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS
M9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T
M:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM
M<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y
M<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S
M92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*
M;7-G<W1R(")$:>!R:6%M96YT(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U
M"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G
M:60@(D1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R
M"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`B1&G@<FEA;65N="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E
M8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M
M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB
M+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T
M<B`B261E;G1I=&%T(%!R961E=&5R;6EN861A(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@
M(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B571I;&ET>F%R(%9A;&]R('!E<B!$
M969E8W1E(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY
M,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("))9&5N=&ET870@
M4')E9&5T97)M:6YA9&$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*
M(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B261E;G1I
M=&%T(%!R961E=&5R;6EN861A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP
M.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE
M=&4@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G
M92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE
M=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("))9&5N=&ET870@4')E
M9&5T97)M:6YA9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B
M;&5M(@IM<V=S='(@(D1E<V-R:7!C:?,@9&5L(%!R;V)L96UA(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E
M<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!C:?,@0V]M<&QE=&$Z(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(D5L<R!D971A;&QS(&AA;B!E<W1A="!R96=I<W1R871S('!E<B!A(&PG861M
M:6YI<W1R861O<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y
M"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R
M(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*
M;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G
M:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES
M<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M(")/<&-I;VYS(&1E(%9I<W5A;&EZ86-I\R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R(")/<&-I;VYS(&1E(%9I<W5A;&EZ86-I
M\R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@
M9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B
M"FUS9W-T<B`B3W!C:6]N<R!D92!6:7-U86QI>F%C:?,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II
M8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").;R!A8V-E
M9&EU(&1I<F5C=&%M96YT(&$@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O
M;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$
M;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@
M)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM
M<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@
M9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")#;W)R974B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%
M9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP
M:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I
M="!";&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A
M9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F
M;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B
M;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N
M.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV
M861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D
M9')E<W,B"FUS9W-T<B`B0V]R<F5U($5L96-T<O)N:6,Z(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@8V]N9FER
M;6%T:6]N(@IM<V=S='(@(D%L=')A($EN9F]R;6%C:?,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA
M:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B
M16UO=&EC;VYS(@IM<V=S='(@(D]P8VEO;G,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G
M:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E)E<W5L=&%T(&)U:70N(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U
M,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")297-U;'1A="!B=6ET
M+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G
M:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F
M(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B
M;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@
M(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*
M;7-G<W1R(")%<G)O<B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,34@;6EN=71S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ>0IM<V=I9"`B179E<GD@
M,B!M:6YU=&5S(@IM<V=S='(@(D-A9&$@-2!M:6YU=',B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=O
M;G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R
M(")#861A(#4@;6EN=71S(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B
M0V%D82!);FEC:2!D92!397-S:?,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B0V%D82!M
M:71J82!H;W)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`B0V%D82!M:6YU="(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B17AE;7!L
M92!D92!V86QO<G,Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED
M(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N
M9"!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED
M(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L
M;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E
M9F5R96YC97,N(@IM<V=S='(@(D5R<F%D82!A;"!R96-U<&5R87(@;&5S('!R
M969E<NAN8VEE<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D5R
M<F%D82!A;"!C;VYN96-T87(@86UB(&5L('-E<G9I9&]R($Q$05`N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L(&9U>GIY"FUS9VED
M(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")%
M<G)A9&$@86P@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O<B!,1$%0+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*
M;7-G<W1R(")%<G)A9&$@86P@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O<B!,
M1$%0+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*(RP@
M9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B17)R861A(&$@;"=I;G1E;G1A<B!O8G)I<B!L82!C
M;VYN97AI\R!,1$%0(&$@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<
M(BXB"FUS9W-T<B`B17)R861A(&%L(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED
M;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E
M.B`E<R(*;7-G<W1R(")%<G)A9&$@86QR96-U<&5R87(@1$X@9&4@;"=U<W5A
M<FDZ(%LE9%T@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED
M(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R861A(&0G26UP;W)T86-I\SH@
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X
M-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@
M(D9A>"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L
M<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P
M"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS
M9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B
M1FEL92(*;7-G<W1R(")4[71O;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I
M9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T
M<B`B3F]M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I
M9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED
M(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L
M9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L
M;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&
M;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR
M,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM
M<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES
M("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T
M:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD
M(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P
M87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F
M=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B3F]T97,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B
M1F]R=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R
M(").;VTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N
M8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*
M;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R
M;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*
M;7-G<W1R(")$97-C<FEP8VGS($-O;7!L971A.B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL
M($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*
M;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")%;"!V;W-T<F4@3F]M.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM
M<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")'
M;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G
M:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B
M1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N
M;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U
M<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W,`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DQL:6)R
M971A(&0G861R96-E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*
M;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED
M(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I
M9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O
M:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")!:G5D82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*
M;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E
M<B(*;7-G<W1R(")!:G5D82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM
M<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D
M97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAO<F1E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-3,U"B,L(&9U>GIY"FUS9VED(")(;VUE(@IM<V=S='(@(DAO<F1E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U
M"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B061R9>=A(%!A<G1I8W5L
M87(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T
M<B`B5&5LZ&9O;B!087)T:6-U;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(
M;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S
M(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G
M:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I
M9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED
M(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E
M<W,B"FUS9W-T<B`B061R9>=A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N
M<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N
M('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T
M(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O
M<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W
M"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L
M87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS
M9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*
M;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G
M92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D
M:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G
M:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM
M86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F
M<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G
M92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G
M<W1R(")#86UP(&EM<&]R=&%T.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I
M96QD.B`E<R(*;7-G<W1R(")#86UP(&EM<&]R=&%T.B`E<R(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD
M<SHB"FUS9W-T<B`B0V%M<',@:6UP;W)T871S.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B
M26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@
M86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS
M9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G
M<W1R(")3:2!U<R!P;&%U+"!P<F]P;W)C:6]N974@96P@=F]S=')E(&YO;2!D
M)W5S=6%R:2!I(&-O;G1R87-E;GEA(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B
M"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM
M<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M("),82!V;W-T<F$@26YF;W)M86-I\R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?
M;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G
M:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@
M(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y
M"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G
M:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM
M<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("))
M;G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U
M"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C$P"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P
M;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C
M:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z
M,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R
M,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A;&ED
M(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P
M:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<S"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN=F%L
M:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L
M:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@
M<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E
M;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I
M9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O
M<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*
M;7-G<W1R(")$:>!R:6%M96YT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA
M:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*
M;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U
M<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y
M:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*
M=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME
M97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R
M96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B
M2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY
M"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B36ES<V%T9V4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX
M,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B261I;VUA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),
M87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X
M"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B"FUS9W-T
M<B`B4V]R=&ER(&1E('-E<W-I\R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A
M;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$U"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")%>&5M
M<&QE(&1E('9A;&]R<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(")-86DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I
M9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG
M:'0@4F%I;B(*;7-G<W1R(")%;G1R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS
M9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC
M+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R(")%;G1R87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*
M;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M
M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B
M3&ES="!$871A8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B
M3&QI<W1A<B!496UE<R!D)T%J=61A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C
M:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@
M(DQL:7-T87(@5&5M97,@9"=!:G5D82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED
M("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G
M:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R
M:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF
M;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G
M:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z
M("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G
M:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")%;G1R87(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")3
M;W)T:7(@9&4@<V5S<VGS(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R(")%;G1R87(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"B,L(&9U>GIY"FUS9VED("),;V=I
M;B!487-K<R(*;7-G<W1R(")&96EN97,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.38*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A
M=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC
M;W)R96-T;'DN(@IM<V=S='(@(B(*(E!E<B!A;&=U;F$@<F'S(&YO(',G:&$@
M86-O;G-E9W5I="!O8G)I<B!L82!S97-S:?,N(%!R;V)A8FQE;65N="!E;"!V
M;W-T<F4@(@HB;F]M(&0G=7-U<V%R:2!O(&-O;G1R87-E;GEA(&AA(&5S=&%T
M(&EN=')O9'7O="!I;F-O<G)E8W1A;65N="XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM
M<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(E-O<G1I<B!D92!S97-S:?,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E
M<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO
M=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@
M(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B0V]R<F5U(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM
M<V=S='(@(D-O<G)E=2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED
M(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F
M=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(D-O<G)E=2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@
M9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B0V]R<F5U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")#;W)R974B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*
M(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")!=NUS(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA
M<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P
M,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D-A;7!S($-O<G)E
M<W!O;F5N=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G
M:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B365M;W+@
M;F1U;7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-
M96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUI
M<W-A=&=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A
M9V4@97AP:7)E9"XB"FUS9W-T<B`B36ES<V%T9V4B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P
M"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B36ES<V%T
M9V4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E
M871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM
M<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*
M(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D5L<R!D
M971A;&QS(&AA;B!E<W1A="!R96=I<W1R871S('!E<B!A(&PG861M:6YI<W1R
M861O<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS
M9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T
M:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T
M960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B
M36ED9&QE(@IM<V=S='(@(D-O<G)E=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S
M='(@(D5R<F]R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED
M(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN
M9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-
M86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)
M1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-
M;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG
M;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-
M;VYT:&QY(@IM<V=S='(@(DUE;G-U86QM96YT(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I
M9"`B36]V92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*
M;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM
M<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY
M"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DQA('9O
M<W1R82!);F9O<FUA8VGS(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS
M9W-T<B`B3F]M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B
M3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM
M<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE
M='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G
M:60@(DYE=F5R(@IM<V=S='(@(DUA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA
M;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM
M<V=S='(@(D-O;G1R87-E;GEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@
M=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG
M="!M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W1E<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT
M(&]P=&EO;G,B"FUS9W-T<B`B5&]R;F%R(&$@3W!C:6]N<R(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@
M(DUA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").
M:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N
M9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N
M<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C
M:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@
M<R=H82!E<W!E8VEF:6-A="!L82!I;F9O<FUA8VGS('!E<B!A(&PG875T96YT
M:6-A8VGS('!E<B!344PN(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*
M(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B1&5S9F5R($-A
M;G9I<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS
M9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RXB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!L82!I;F9O<FUA
M8VGS('!E<B!A(&QE<R!#871E9V]R:65S(%-13"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@R-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM
M<V=S='(@(DYO(',G:&$@97-P96-I9FEC870@:6YF;W)M86-I\R!P97(@82!L
M97,@4')E9F5RZ&YC:65S($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").
M;R!S)VAA(&5S<&5C:69I8V%T(&QA(&EN9F]R;6%C:?,@<&5R(&$@;&5S($-A
M=&5G;W)I97,@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,3<*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@
M(DYO(',G:&$@97-P96-I9FEC870@;&$@:6YF;W)M86-I\R!P97(@82!L97,@
M0V%T96=O<FEE<R!344PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0IM<V=I
M9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED
M(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B
M3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N
M=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P
M+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U
M=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO(',G:&$@
M97-P96-I9FEC870@;&$@:6YF;W)M86-I\R!P97(@82!L)V%U=&5N=&EC86-I
M\R!P97(@4U%,+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO(',G:&$@97-P
M96-I9FEC870@;&$@:6YF;W)M86-I\R!P97(@82!L)V%U=&5N=&EC86-I\R!P
M97(@4U%,+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!L
M82!I;F9O<FUA8VGS('!E<B!A(&PG875T96YT:6-A8VGS('!E<B!344PN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").;W1E
M<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B
M3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B3F]T97,B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")3:2!U<R!P;&%U
M+"!P<F]P;W)C:6]N974@96P@=F]S=')E(&YO;2!D)W5S=6%R:2!I(&-O;G1R
M87-E;GEA(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*
M;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS
M9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO
M;F4B"FUS9W-T<B`B5&5LZ&9O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I
M="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G
M:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I
M9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T
M($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@
M9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*
M;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F]T97,B"@HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X
M,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT
M,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R
M(").;W1E<R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM
M<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L
M(&9U>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(")-86DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB
M97(B"FUS9W-T<B`B3F]M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*
M;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").
M=6UB97(@;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N
M;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE
M8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")#
M;VYT<F%S96YY82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT
M-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@
M(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM
M<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS
M9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R
M;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G
M:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I
M;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N<R(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B3W!C:6]N<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES
M871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@
M(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%L=')A($EN
M9F]R;6%C:?,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS
M9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")0
M32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N
M(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS
M9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@
M3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")#;VYT<F%S96YY82(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O
M<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I
M9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(D-O;G1R87-E;GEA(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM
M<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS
M9VED(")087-S=V]R9#HB"FUS9W-T<B`B0V]N=')A<V5N>6$B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S
M<W=O<F0Z("(*;7-G<W1R(")#;VYT<F%S96YY82(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S
M=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I
M9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R
M(")&=6YC:?,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(E)E86QI
M='IA<B!/<&5R86-I;VYS(&1E($UA;G1E;FEM96YT(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0P-@HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")296%L:71Z
M87(@3W!E<F%C:6]N<R!D92!-86YT96YI;65N="(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8U"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G
M<W1R(")!;'1R82!);F9O<FUA8VGS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")0
M97)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM
M<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E
M;.AF;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED
M(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2XB"FUS9W-T<B`B4VD@=7,@<&QA=2P@<')O<&]R8VEO;F5U('5N
M(')E<W5M(&1E;"!P<F]B;&5M82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(E-I('5S('!L874L('!R;W!O<F-I;VYE=2!E;"!V;W-T<F4@;F]M
M(&0G=7-U87)I(&D@8V]N=')A<V5N>6$B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E
M('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@
M='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN
M;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R
M*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*
M;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E
M<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F
M=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")4;W)N87(@
M82!/<&-I;VYS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S
M='(@(EM);F9O<FUE(&1E;"!0<F]B;&5M85TB"@HC.B!S97)V:6-E<R]P<F]B
M;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B1&5S8W)I<&-I\R!D96P@4')O8FQE;6$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B
M4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*
M;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I
M;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM
M<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS
M9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED
M(")296%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S
M(@IM<V=S='(@(DUI<W-A=&=E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE
M=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O
M<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5F<F5S:"!0;W)T
M86P@5FEE=SHB"FUS9W-T<B`B4F5F<F5S8V%R(%9I<W1A(&1E;"!297-U;3HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C,U"FUS9VED(")296=E>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@
M(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4B"FUS9W-T<B`B5')E=7)E('!A<F5L;"(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L
M;V-K(@IM<V=S='(@(E1R975R92!P87)E;&PB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L
M=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T
M:6YG(@IM<V=S='(@(E1R975R92!P87)E;&PB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B
M5')E=7)E('!A<F5L;"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*
M;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B5')E=7)E('!A<F5L;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")4
M<F5U<F4@<&%R96QL(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E
M<CH@)7,B"FUS9W-T<B`B5')E=7)E('!A<F5L;"(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(")2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(G=6ED)R!R97%U97)I="!N;R!E<W!E8VEF
M:6-A="!A(&QA(&-O;F9I9W5R86-I\R!D92!L87,@<')E9F5RZ&YC:65S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(G=6ED)R!R97%U97)I="!N;R!E<W!E8VEF:6-A="!A(&QA
M(&-O;F9I9W5R86-I\R!D92!L87,@<')E9F5RZ&YC:65S+B(*"B,Z(&9R86UE
M=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B)W5I9"<@<F5Q=65R:70@;F\@97-P96-I9FEC
M870@82!L82!C;VYF:6=U<F%C:?,@9&4@;&%S('!R969E<NAN8VEE<RXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@
M(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S
M<W=O<F0B"FUS9W-T<B`B0V]N=')A<V5N>6$B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")2
M97-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")4;W)N
M87(@82!/<&-I;VYS(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B5&]R;F%R(&$@3W!C
M:6]N<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED
M9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT
M(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X
M"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B
M4F]L92(*;7-G<W1R(")&=6YC:?,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2
M;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E
M(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY
M"FUS9VED(")2=6QE<R(*;7-G<W1R(")&=6YC:?,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U
M"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*
M;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G
M:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B36ES<V%T9V4B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@
M<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@
M*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N
M9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I
M9"`B4V%V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@
M(D1E<V%R($]P8VEO;G,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU
M"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B1&5S87(@3W!C:6]N<R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO
M=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E
M87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G
M<W1R(")396QE8V-I;VYE=2!E;"!F;W)M870@9&4@;&$@9&%T83HB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@
M9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@
M(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-C:6]N
M974@96P@9F]R;6%T(&1E(&QA(&1A=&$Z(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B
M:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)396QE8V-I;VYE
M=2!E;',@8V%RX&-T97)S('%U92!N96-E<W-I=&5U(&1E(&QE<R!C87-E;&QE
M<R!D92!S;W1A+B!0;V1E=2`B"B)C;W!I87(M;&]S(&D@96YG86YX87(M;&]S
M(&1E(&PGX')E82!D92!T97AT+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G
M<W1R(")396QE8V-I;VYE=2!E;"!D96QI;6ET861O<B!D92!L82!D871A.B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYE=2!E;"!F;W)M
M870@9&4@;&$@9&%T83HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W
M86YT('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z(@IM<V=S='(@(E-E;&5C8VEO;F5U(&5L(&1E;&EM:71A9&]R
M(&1E(&QA(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*
M;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E-E;&5C
M8VEO;F5U(&5L(&9O<FUA="!D92!L)VAO<F$Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N(@IM<V=S='(@(E-E;&5C8VEO;F5U(&1O<R!C86UP<R!Q=64@8V]I
M;F-I9&5I>&EN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G
M:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")396QE8V-I;VYE=2!E;"!V
M;W-T<F4@:61I;VUA('!R969E<FET.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(D5N=FEA<B!);F9O<FUE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I
M82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q
M"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E
M<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$
M(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F
M=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B1&5S87(@3W!C:6]N<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@
M(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC
M+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")%<W1A8FQE:7@@
M96P@<F5F<F5S8R!D92!PX&=I;F$@:2!A;'1R97,@;W!C:6]N<R!D92!V:7-U
M86QI='IA8VGS+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(D5S=&%B;&5I>"!E;"!R969R97-C
M(&1E('#@9VEN82!I(&%L=')E<R!O<&-I;VYS(&1E('9I<W5A;&ET>F%C:?,N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X
M-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@
M<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B
M4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")"<F5U(%)E<W5M.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO
M=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS
M9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G
M:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I
M9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I
M8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V
M"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM
M<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3
M:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L
M;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N
M('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA
M='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K
M:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3VUI=&ER($UA;G1E;FEM96YT(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N
M;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED
M(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@
M9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F
M(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S
M='(@(D%D<F7G82!D92!L82!&96EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM
M<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G
M:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B
M4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B16YT<F%D82!D92!#
M87+@8W1E<G,@17-P96-I86QS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM
M<V=S='(@(DEM<&]R=&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N
M:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T
M86YD87)D(@IM<V=S='(@(D-A;&5N9&%R:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A
M=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS
M9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("),82!V;W-T<F$@26YF;W)M
M86-I\R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R
M"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")!9')E
MYV$@9&4@;&$@1F5I;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T
M<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T
M(&%G96YT(&1E(&YO=&EF:6-A8VGS("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE
M=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET
M(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R
M97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3
M=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P
M-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(LAX
M:70B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO
M;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B16P@
M;65U(%)E<W5M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED
M(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*
M;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR
M:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R
M:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-S@*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B26UP;W)T87(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G
M<W1R(")5<W5A<FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")5<W5A
M<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3
M=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T
M<B`B5.UT;VPB"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC
M+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5.UT;VPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS
M9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE
M(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(D9E:6YE
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS
M9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B
M5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT
M($]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4
M:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED
M(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B2&5U('1A;F-A="!L82!S97-S:?,N($=R
MX&-I92!S<&5R('5T:6QI='IA<B!E;"!S:7-T96UA+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])
M35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA
M<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M
M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS
M9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR
M.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED
M("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q
M"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E
M(&YU;65R:6,N(@IM<V=S='(@(D%Q=65S="!V86QO<B!H82!D92!S97(@=6X@
M;OIM97)O+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI
M;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED
M(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R
M:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V
M960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B
M965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP
M;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T
M97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE
M('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@
M8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE
M('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$
M871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC
M;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T
M<B`B3F\@:&D@:&$@<')E9F5RZ&YC:65S(&1I<W!O;FEB;&5S+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE
M<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM
M<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R
M97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V
M97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G
M<W1R(")!<75E<W0@=F%L;W(@:&$@9&4@<V5R('5N(&[Z;65R;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM
M<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS
M9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A
M<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B07%U97-T('9A
M;&]R(&AA(&1E('-E<B!U;B!N^FUE<F\N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D
M>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE
M;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R
M;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@
M;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@
M2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M
M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C
M:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G
M:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R
M(")!<75E<W0@;OIM97)O(&AA(&1E('-E<B!C;VT@82!M[6YI;2!U;B`Q+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM
M<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R
M96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N(@IM<V=S='(@(D%Q=65S="!V86QO<B!H82!D92!S97(@
M=6X@;OIM97)O+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I
M9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F
M=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R(")4[71O;"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE
M(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4[71O
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B
M5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET
M96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-
M86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@
M*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F
M86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM
M<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")5
M4DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY
M"FUS9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5
M:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("));F-A<&'G(&1E(&-O;FYE8W1A<G-E(&%L
M('-E<G9I9&]R(&1E(%-13"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B26YC87!AYR!D
M92!C;VYN96-T87)S92!A;"!S97)V:61O<B!D92!344PN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B26YC87!A
MYR!D92!C;VYN96-T87)S92!A;"!S97)V:61O<B!D92!344PN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("));F-A<&'G(&1E
M(&-O;FYE8W1A<G-E(&%L('-E<G9I9&]R(&1E(%-13"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B26YC87!AYR!D
M92!C;VYN96-T87)S92!A;"!S97)V:61O<B!D92!344PN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("));F-A<&'G(&1E(&-O
M;FYE8W1A<G-E(&%L('-E<G9I9&]R(&1E(%-13"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("));F-A<&'G(&1E(&-O;FYE
M8W1A<G-E(&%L('-E<G9I9&]R(&1E(%-13"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DEN
M8V%P8><@9&4@8V]N;F5C=&%R<V4@86P@<V5R=FED;W(@9&4@4U%,+B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B
M56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B26YC87!AYR!D92!M
M;V1I9FEC87(@;&5S('!R969E<NAN8VEE<SH@6R5D72`E<R(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P8><@9&4@8V]N
M;F5C=&%R<V4@86P@<V5R=FED;W(@9&4@4U%,+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V
M-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("));F-A
M<&'G(&0G96YR96=I<W1R87(@<')E9F5RZ&YC:65S(&5N(&QA('-E<W-I\RXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I
M9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R
M86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("));F-A<&'G(&1E(&-O;FYE8W1A<G-E
M(&%L('-E<G9I9&]R(&1E(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P8><@9&4@8V]N
M;F5C=&%R<V4@86P@<V5R=FED;W(@9&4@4U%,+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B26YC
M87!AYR!D92!C;VYN96-T87)S92!A;"!S97)V:61O<B!D92!344PN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O
M(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O
M("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("));F-A<&'G(&1E(&-O;FYE8W1A<G-E(&%L('-E<G9I9&]R
M(&1E(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B3F\@Z7,@<&]S<VEB;&4@=')A9'5I
M<B!A<75E<W0@9&]C=6UE;G0@9&4@5V]R9"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*
M;7-G<W1R(")$97-F97(@0V%N=FES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S
M="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*
M;7-G:60@(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@
M(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*
M;7-G<W1R(")5<W5A<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U
M<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO
M;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM
M<V=I9"`B57-E<B(*;7-G<W1R(")5<W5A<FDB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N
M<R!D)U5S=6%R:2(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@
M(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(D]P8VEO;G,@9"=5<W5A<FDB
M"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U
M;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(E5S=6%R:2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*
M;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")5<W5A<FDB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(E5S=6%R:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R
M>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")6
M97)S:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T
M:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N
M86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@
M87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I
M9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A
M9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I
M9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z
M,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*
M;7-G<W1R(")!=NUS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C
M87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E
M871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I
M9"`B5V5E:VQY(@IM<V=S='(@(E-E=&UA;F%L;65N="(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(D)E;G9I;F=U="P@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")"96YV
M:6YG=71S(&$@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0F5N=FEN9W5T+"`E<R(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M
M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G
M:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@
M;&]G:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G
M:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT
M(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B
M5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B
M;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*
M;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G
M:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM
M<V=I9"`B5VEN9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')EYV$@
M9&4@;&$@1F5I;F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;.AF
M;VX@9&4@;&$@1F5I;F$B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E
M9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G
M:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")962(*;7-G<W1R(")!02(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G
M<W1R(")!02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@
M(EEE87)L>2(*;7-G<W1R(")!;G5A;&UE;G0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E
M(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H
M(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM
M<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@
M(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@
M(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+B(*;7-G<W1R("),97,@;W!C:6]N<R!H86X@97-T870@86-T
M=6%L:71Z861E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q
M"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N
M92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*
M(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME
M;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T
M<B`B2&5U(&1E(&1E<V-R:75R92!E;"!P<F]B;&5M82!A8F%N<R!D)V5N=FEA
M<B!L)VEN9F]R;64@9&5L('!R;V)L96UA+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R
M9F]R;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N
M97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B),82!V;W-T<F$@<V5S
M<VGS(&5N("5S(&AA(&5X<&ER870N(%-I('5S('!L874L(&EN:6-I974@=6YA
M(&YO=F$@<V5S<VGS+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS
M9W-T<B`B0V]R<F5U($5L96-T<O)N:6,Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S
M.B(*;7-G<W1R(")#;W)R974@16QE8W1R\FYI8SHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B3&$@=F]S=')A
M($EN9F]R;6%C:?,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM
M<V=S='(@(D5L('9O<W1R92!.;VTZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R
M97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(DQE<R!O<&-I;VYS(&AA
M;B!E<W1A="!A8W1U86QI='IA9&5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>3HB"FUS9W-T<B`B261E;G1I=&%T(%!R961E=&5R;6EN861A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F
M=6QL(&YA;64Z(@IM<V=S='(@(D5L('9O<W1R92!.;VTZ(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L
M;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B3&5S(&]P8VEO;G,@:&%N(&5S
M=&%T(&%C='5A;&ET>F%D97,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI
M<R!S97-S:6]N+B(*;7-G<W1R("),97,@;W!C:6]N<R!H86X@97-T870@86-T
M=6%L:71Z861E<RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R("),97,@;W!C:6]N<R!H86X@97-T870@86-T=6%L:71Z861E<RXB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G
M(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O
M<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G
M:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G
M<W1R(");26YF;W)M92!D96P@4')O8FQE;6%=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E
M9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6VSM;FEA
M("5S(&1E("5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T
M,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED
M(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B
M7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O
M=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@(D%J=61A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L
M(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(D5N=')A<B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G
M:60@(E],;V<@;W5T(@IM<V=S='(@(E-O<G1I<B!D92!S97-S:?,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED
M(")?3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS(@H*(SH@;&EB+V%P:2YP:'`Z
M,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L
M(&9U>GIY"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B5')E=7)E
M('!A<F5L;"(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*
M(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("),;&EB<F5T
M82!D)V%D<F5C97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G
M:60@(F-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R:2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H
M<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A
M=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N
M9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I
M9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U
M-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R(")4[71O;"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@
M(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S
M"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN
M;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS
M9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"B,L
M(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@(DYO;2(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B
M<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX
M96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")!=NUS(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@
M(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W
M:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y
M"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL
M=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`B0V%D82!)
M;FEC:2!D92!397-S:?,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D
M(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M
M(@IM<V=S='(@(B(*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V-S7T-:
M+G!O````````````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`W,C$Q-S$`,3`T,3<S-C,P,#$`,#$V,S<T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@0WIE8V@@=')A;G-L871I
M;VYS(&9O<B!(;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O
M:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M
M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC(%!A=F5L($-H>71I
M;"`\<&%V96Q`8VAY=&EL+G1K/BP@,C`P,2TR,#`T+@HC"FUS9VED("(B"FUS
M9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C!<;B(*(E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)0
M3U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)0
M3RU2979I<VEO;BU$871E.B`R,#`T+3`W+3(R(#$Q.C0Y+3`W,#!<;B(*(DQA
M<W0M5')A;G-L871O<CH@36EL;W,@5VEM;65R(#QW:6UM97)`>F-U+F-Z/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@0WIE8V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TR7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS
M/3,[('!L=7)A;#TH;B4Q,#T],2`F)B!N)3$P,"$],3$@/R`P(#H@;B4Q,#X]
M,B`F)B!N)2(*(C$P/#TT("8F("AN)3$P,#PQ,"!\?"!N)3$P,#X],C`I(#\@
M,2`Z(#(I.UQN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@
M*'#X960@)7,@9&YY*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3,W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS
M9W-T<B`B("A0^.US='5P;W;](&ML[>@@)7,I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S
M(&1A>7,I(@IM<V=S='(@(B`H=B`E<R!D;F5C:"DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@
M*&1N97,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I
M9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AZ[71R82DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS
M9W-T<B`B("AVZ&5R82DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G
M<W1R("(@<GEC:&QO<W0@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(DYE;NT@861R97/A^&5M(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T
M<B`B)7,@;F5L>F4@>G9O;&ET+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R
M>2XB"FUS9W-T<B`B)R5S)R!N96[M(&YA:V]N9FEG=7)O=N%N('8@<F5G:7-T
M<F5C:"!(;W)D92!S>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N
M<&AP.C$W,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(G)7,G('#X96ML861A
MZ"!N96)Y;"!N86QE>F5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B5S)R!B>6P@</AI9.%N(&1O
M('-Y<W3I;74@<VMU<&EN+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,G
M(&)Y;"!P^&EDX6X@9&\@<WES=.EM=2!P^.US='5P;W;]8V@@<'+A=BXB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E<R<@;F5B>6P@=GET=F_X96XZ
M("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G
M<W1R("(E9"`E<R!A("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS
M9W-T<B`B)60M9&5N;NT@</AE9'!O=NSO(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E
M(@IM<V=S='(@(B5S("T@;WINX6UE;NTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&
M:6YG97)P<FEN="(*;7-G<W1R("(E<R!O=&ES:R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B
M"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!O<&5R86-E(/ID<KYB
M>2`M('!O='9R>F5N[2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3971U<"(*;7-G<W1R("(E<R!N87-T879E;NTB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@<F5G:7-T<F%C92(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@<&]D;>UN:WD@
M<&]UONUVX6[M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B5S(&IIOB!E>&ES='5J92XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E
M<R`E<R(*;7-G<W1R("(E<R!N82`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+B(*;7-G<W1R(")/>FYAZ&ET('+A;67H96L@<')O(':Y96-H;GD@;W!E<F%C
M92P@:W1E<ND@8VAC971E('1E[R!P<F]VZ7-T+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B)7,@:F4@<&^^861O=N%N;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI
M;G5T97,B"FUS9W-T<B`B)7,@;6EN=70B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F5B>6QO(&YA;&5Z96YO+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@8;X@)7,@
M>B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S
M(&%D<F5SX?@B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S
M(&MA;&5N9.'X(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S
M('KA<&ES;NUK(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E
M<R!S97IN86T@^FMO;/DB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@
M=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB
M86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I
M=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,3`*(RP@9G5Z>GD*;7-G:60@(BP@9W5S=&EN9R`B
M"FUS9W-T<B`B+"!NX7)A>F]V_2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&[A<F%Z;W;]
M("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@
M(BP@<')O;>QN;N$@;V0@)7,@9&\@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S
M='(@(BTM(';]8NQR("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS
M9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,B!H;V1I;F]V_2!F;W)M
MX70B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@
M1F]R;6%T(@IM<V=S='(@(C(T(&AO9&EN;W;](&9O<FWA="(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R
M("(R-"!H;V1I;B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*
M(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R(")0^&5D8VAO>NT@
M<W1RX6YK82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(E!R;R!T96YT;R!B;&]K(&IE('9YOF%D;W;A;B!D871A8N%Z
M;W;]('ID<F]J+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P
M"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")6
M>7-K>71L82!S92!ZX79AOF[A(&-H>6)A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")0<F\@
M>F&Y:69R;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'
M4"!K;.WH+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(E!R;R!V97)I9FEK86-I
M('!O9&5P<V%NZ2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0
M(&ML[>@N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y
M-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*(E!R;R!D9;EI9G)O=N%N[2!Z<'+A=GD@
M:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'
M4"!K;.WH(&$@(@HB:&5S;&\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E!R;R!P;V1E<'/A;NT@
M>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+"!P<FEV
MX71N[2!01U`@:VSMZ"!A("(*(FAE<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@HB4')O(&1EN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X
M96IN_2!3+TU)344@:VSMZ"P@<')I=N%T;NT@4R]-24U%("(*(FML[>@@82!H
M97-L;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S
M,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B
M"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E!R;R!P;V1E<'/A;NT@>G!RX79Y
M(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEVX71N
M[2!3+TU)344@(@HB:VSMZ"!A(&AE<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(E!R;R!Z8;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J
M;OT@4R]-24U%(&ML[>@N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S
M='(@(EIA=&&^96YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS
M9W-T<B`B3V1P;VQE9&[M(&QE:&O](&3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R(")286YN[2!DZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B4F%N
M;NT@</AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E)A
M;F[M('-N[&AO=ND@</AE:.'R:WDB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G
M:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES
M(&5D:71O<B(*;7-G<W1R("));F9O<FUA8V4@;R!T;VUT;R!E9&ET;W)U(@H*
M(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN
M(@IM<V=S='(@(DEN9F]R;6%C92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G
M<W1R(")497AT(&1O;/D@9&\@;V)RX7IK=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*
M;7-G<W1R(")497AT(&1O<')O<W3X960@;V)RX7IK=2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5GET=F_X96[M(%9&
M4R!A9')A<^'X92!N96)Y;&\@<&]V;VQE;F\N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B5GET=F_X96[M(%9&4R!S;W5B;W)U
M(&YE8GEL;R!P;W9O;&5N;RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M(")68;EE(&EN9F]R;6%C92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")5OFEV871E;'-K
MZ2!H97-L;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@
M(E6^:79A=&5L:_T@^NAE="!B>6P@>F%B;&]K;W;A;BXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S
M='(@(E6^:79A=&5L:^D@^NAT>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B
M061D(@IM<V=S='(@(E9L;[XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A
M9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM
M<V=S='(@(E#X:61A="!P;V1S:W5P:6YU(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")0^&ED
M870@<&]D+7!RX79A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*
M;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")0^&ED870Z(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D
M9"!.97<@1W)O=7`B"FUS9W-T<B`B4/AI9&%T(&YO=F]U('-K=7!I;G4B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO
M;B(*;7-G<W1R(")0^&ED870@;F]VX2!P<N%V82(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R
M(")0^&ED870@<&]D<VMU<&EN=2!D;R`G)7,G(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@
M(E#X:61A="!P;V0M<'+A=F$@9&\@)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B4/AI9&%T(&YO
M=NEH;R!UOFEV871E;&4Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")0
M^&ED870@<VQO=7!E8R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")0^&ED
M870@;F]VZ2#H;&5N>2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E#X:61A="!PX7(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R
M(")0^&ED870@)7,@;65N=2!J86MO(&)OZ&[M('-L;W5P96,@36]Z:6QL>2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM
M<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B4/AI9&%T(&1O
M(&%D<F5SX?AE.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G
M<W1R(")0^&ED870@9&\@;>EH;R!A9')E<^'X92(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")0^&ED870@=;YI=F%T
M96QE(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M(@HB)7,N(@IM<V=S='(@(B(*(B<E<R<@8GEL;R!P^&EDX6YO(&1O('-Y<W3I
M;74L(&%L92!N96QZ92!P^&ED870@;N%S;&5D=6KM8^T@:6YF;W)M86-E.B`E
M<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+B(*;7-G<W1R("(G)7,G(&)Y;&\@</AI9.%N;R!D;R!S>7-TZ6UU
M+B!-^;YE=&4@<V4@;GEN[2!P^&EH;.%S:70@9&\@<WES=.EM=2XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG
M('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")0^&EDX7;A;NT@=;YI=F%T
M96SY(&IE('IA8FQO:V]VX6YO+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*
M;7-G<W1R(")!9')E<^'X(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES
M<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(B(*(E9Y:V]NX79A="!A
M9&UI;FES=')A8VD@+2!N87-T879E;NT@</CM<W1U<&]V_6-H('!RX78@<')O
M(&]S=&%T;NT@=;YI=F%T96QE(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@(D%D<R(*;7-G<W1R("));GIE<N%T
M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F
M9VCA;FES=.%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R
M(")!;&+A;FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R
M(")!;+[M<G-K;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(E#X97ID[79K82]!
M;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(EIA<F]V;F%T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM
M<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("):87)O=F[A;NTZ(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B5KEE
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T
M960@57-E<G,B"FUS9W-T<B`B5KEI8VAN:2!O=NSX96[M('6^:79A=&5LZ2(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*
M;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B5KEE8VAN>2!S:W5P:6YY(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B5KEE8VAN82!UOFEV871E;'-KX2!P<N%V82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(E:Y96-H;GD@Z'1Y
M^&D@<W1R86YY(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM
M<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E!O=F]L
M:70@=NUC92!A9')E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*
M;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM
M<V=S='(@(E!O=F]L:70@;F%S=&%V96[M('1Y<'4@<V5T^.UD[&[]('-E>FYA
M;3\B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU
M,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DIIOB!E>&ES='5J
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R
M;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T:79N[2!)35-0('#X
M:6ALX;EE;NT@9&\@<WES=.EM=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@
M(D%L=&5R;F%T:79N[2!)35-0(&AE<VQO(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B06QT97)N871I=F[M($E-4U`@=;YI=F%T96QS:^D@:FWI;F\B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N
M871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B06QT97)N871I=F[M(&4M;6%I
M;&]VX2!A9')E<V$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I
M9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")!;'1E<FYA=&EV;NT@
M=GIO<GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G
M<W1R(")!;'1E<FYA=&EV;NT@=&5X=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;65R:6-A;B!386UO82(*;7-G<W1R(")!;65R:6-KX2!386UO82(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"XB"FUS9W-T<B`B0GEL82!Z863A;F$@;F5P;W9O;&5NX2!H
M;V1N;W1A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*
M(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N
M(@IM<V=S='(@(FYA<W1A;&$@8VAY8F$Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M06YD;W)R82(*;7-G<W1R(")!;F1O<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T
M<B`B06YO;GEM;NT@<')O>'DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(D]D<&]V[.\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I:V$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S
M='(@(D%N=&EG=6$@82!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI:V%C92(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I
M;VX@3&ES="(*;7-G<W1R(")397IN86T@87!L:6MA8^TB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D
M>2XB"FUS9W-T<B`B07!L:6MA8V4@:F4@</AI<')A=F5N82(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL
M9"!3:&%R97,B"FUS9W-T<B`B4&]UONUT('!R;R!D[&1IZ&[I('-D[6QE;NTB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I
M9"`B07!P<F]V92(*;7-G<W1R(")38VAVX6QI="(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@
M4VEZ92(*;7-G<W1R(")0^&EB;&F^;N$@=F5L:6MO<W0B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`B1'5B96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM
M<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)S:WD@
M*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B5F5L:6MO<W0@
M87)C:&EV;W9A;NEH;R!S;W5B;W)U(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")*;>EN;R!A
M<F-H:79U(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*
M;7-G<W1R(")5<NAI=.P@8VAC971E('9Y;6%Z870@ON%D;W-T(&\@</AI:&SA
MN65N[2!D;R`E<S\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O
M=7!S/R(*;7-G<W1R(")5<NAI=.P@<VD@</AE:F5T92!V>6UA>F%T("<E<R<@
M82!P;V1S:W5P:6YY/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*
M;7-G<W1R(")!<F=E;G1I;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA
M(@IM<V=S='(@(D%R;>EN:64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)MZ6YS
M:_T@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*
M;7-G:60@(D%R="(*;7-G<W1R(")5;>QN[2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")!
M<V-E;G-I;VX@27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y
M"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@=6WL;NTB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C
M:69I8R!296=I;VXB"FUS9W-T<B`B07-I92]R96=I;VX@5&EC:.EH;R!O8V7A
M;G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\B"FUS9W-T<B`B4&^^X61A="!O('!O='9R>F5N[2!P^&5D('!R
M;W9E9&5N[6T@;W!E<F%C[2#Z9'*^8GD_(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S
M='(@(E-L;W5P8V4@<R#Z:V]L>2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*
M;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+B(*;7-G<W1R(")0;VMU<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC[2!S:W5P
M:6YY+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(E!O:W5S(&\@=GEM87KA;NT@;F5E>&ES='5J[6/M8V@@=;YI=F%T
M96QS:_UC:"!P<N%V+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J[6/M8V@@=;YI
M=F%T96QS:_UC:"!P<N%V+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+B(*;7-G<W1R(")0;VMU<R!O(/IP<F%V=2!N965X:7-T=6KM8^UH;R!S
M9.UL96[I:&\@;V)J96MT=2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R(")!=')I8G5T>2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED
M(")!=6=U<W0B"FUS9W-T<B`B4W)P96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<F%L:6$B"FUS9W-T<B`B075S='+A;&EE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')I82(*;7-G<W1R(")286MO=7-K;R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?8WER<W%L.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA
M('!R;R!I;6%P+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!:
M9')O:B!N96WA('!OOF%D;W9A;ND@<V-H;W!N;W-T:2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]C>7)U<SH@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N
M82!P<F\@:6UA<"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z
M,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB
M9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($YE8GEL82!N86QE
M>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&9T<"X@2V]M<&EL=6IT92!0
M2%`@<R`M+2(*(F5N86)L92UF='`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!.96)Y
M;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!)34%0+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?
M:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VMR8C4Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X
M[7!O;F$@<')O(&MR8C4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U
M=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P
M.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!,1$%0
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!
M=71H7VQD87`Z($YE;'IE('#X:61A="!UOFEV871E;&4@)7,N($ALX;EE;NT@
M<V5R=F5R=3H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.96QZ92!V>6UA
M>F%T('6^:79A=&5L92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5L
M>F4@86MT=6%L:7IO=F%T('6^:79A=&5L92`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($YE8GEL82!N86QE
M>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O($U#04PN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]S;6)A=71H.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P
M^.UP;VYA('!R;R!S;6)A=71H+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D(@IM<V=S='(@(D]V[/AE;NT@<V5L:&%L;R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B
M"FUS9W-T<B`B3W;L^&5N[2!S96QH86QO+B`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D]V[/AE;NT@
M8GEL;R!Z86WM=&YU=&\@4D%$2553('-E<G9E<F5M+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4V5L:&%L;R!O=NSX96[M
M($944"!S979E<F5M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-S`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4V5L:&%L;R!O=NSX96[M($944"!S
M979E<F5M+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G
M:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D1O<W1U<&[A('!O;&4Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R
M8F%J9+[A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B
M0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@=OUM;'5V>2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G
M:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B4&]Z863M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R
M;W5N9"!#;VQO<B(*;7-G<W1R(")"87)V82!P;WIA9.TB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@
M<&%S<W=O<F0N(@IM<V=S='(@(JEP871NZ2!H97-L;R!P<F\@:V5R8F5R;W,N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B
M0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("*I<&%T;ND@=;YI=F%T
M96QS:^D@:FWI;F\@<')O(&ME<F)E<F]S+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)A:&%M87,B"FUS9W-T<B`B0F%H86UY(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0F%H<F%I;B(*;7-G<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@
M(D)A;'1I8VOI("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M86YG;&%D97-H(@IM<V=S='(@(D)A;F=L863IN2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(").96)Y;"!N86QE>F5N(&%D<F5SX?@@)R5S)R!S(&=R869I:V%M:2XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(EKA:VQA9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B0NQL;W)U<VMO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:64B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D>2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)H=71A;B(*;7-G<W1R(")":/ITX6XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A
M>2(*;7-G<W1R(").87)O>F5N:6YY(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")"
M;&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B3F5L>F4@;F%LZ7IT(.CA<W0@7"(E<UPB(&%P;&EK86-E(%PB
M)7-<(BXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G
M:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(DYA<W1A=F5N[2!B;&]K=2(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO
M8VL@5'EP92(*;7-G<W1R(")4>7`@8FQO:W4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T
M<B`B5'7H;NPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@
M(D)O;.UV:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS
M9VED(")";V]K;6%R:W,B"FUS9W-T<B`B6N%L;[YK>2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@
M(D)O<F1E<B(*;7-G<W1R(")/:W)A:B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE
M<W,Z(@IM<V=S='(@(JGM^&MA(&]K<F%J93HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D
M97)S(@IM<V=S='(@(D]K<F%J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;F$@82!(97)C96=O=FEN
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*
M;7-G<W1R(")/8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G
M<W1R(")";W1S=V%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D1O
M;&[M(.CA<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM
M<V=S='(@(D)O=79E="!)<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z
M:6PB"FUS9W-T<B`B0G)A>NUL:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I
M=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71S:^$@
M=&5R:71O<FEA('8@26YD:6-KZ6T@;V-EX6[L(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L
M86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QH
M87)S:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(E-E>FYA;2!S
M(&]D<N&^:V%M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*
M;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U
M;F1I(@IM<V=S='(@(D)U<G5N9&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM
M<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R
M(")#4DP@9&ES=')I8G7H;NT@8F]D>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")6;&%S=&YO<W1I(&)?=?)K>2XN+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*(RP@9G5Z>GD*
M;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@
M(DYE8GEL('5V961E;B!D:7-T<FEB=>AN[2!S97IN86TN(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9.'X(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G
M<W1R(")"97IV['3X[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*
M;7-G<W1R(")+86UB;V2^82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N
M(@IM<V=S='(@(DMA;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@HB2&5S;&\@;F5L>F4@;F%S=&%V:70@875T;VUA=&EC:WDL('!R;W/M;2!K
M;VYT86MT=6IT92!68;EE:&\@<WES=.EM;W;I:&\@(@HB861M:6YI<W1RX71O
M<F$N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@
M7"(E<UPB(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@<V]U8F]R(%PB)7-<(BXB
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN
M:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B
M3F5L>F4@<V4@</AI<&]J:70@:R!)34%0('-E<G9E<G4Z("5S(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").
M96QZ92!V>6UA>F%T('-O=6)O<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM
M<V=I9"`B0V%N8V5L(@IM<V=S='(@(E-T;W)N;R(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!2
M97!O<G0B"FUS9W-T<B`B4W1O<FYO(&ALX;EE;NT@<')O8FSI;74B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").96QZ
M92!V>6UA>F%T('-O=6)O<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD
M(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5L>F4@;F%J[70@
M9&_H87-N_2!A9')E<^'X+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B3F5L>F4@<&]K
M<F'H;W9A="!B97H@<&%R86UE=')U("=T87)G971&:6QE)RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE
M;'IE('9Y;6%Z870@861R97/A^"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").96QZ92!V
M>6UA>F%T+"!P<F]T;[YE(&5X:7-T=6KM('!O9'-K=7!I;GD@)60N(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED
M("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E
M9"XB"FUS9W-T<B`B(@HB3F5L>F4@<')O=NES="!Z;>QN=2!U<W!O^.%DX6[M
M+"!P;^AE="!P;W-K>71N=73]8V@@<&]L;[YE:R!P<F\@;F]VZ2`B"B)U<W!O
M^.%DX6[M(&YE;V1P;W;M9.$@<&_H='4@=6QOOF5N_6-H('!O;&^^96LN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@
M;G5M8F5R+B(*;7-G<W1R(").96QZ92!Z87-L870@>G!RX79U(&YA('IA9&%N
MZ2#H[7-L;RX@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G
M<W1R(")#87!E(%9E<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R
M(")4:71U;&MY(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@
M3&%B96QS(@IM<V=S='(@(DMA=&5G;W)I92!A('IN8>AK>2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")+86IM86YS:^D@
M;W-T<F]V>2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6QN[2!T
M96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@
M(DUOOFYO<W1I(&)U\FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T
M<B`B3V1S='5P(&UE>FD@8G7R:V%M:3HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R
M;W!E<G1I97,B"FUS9W-T<B`B5FQA<W1N;W-T:2!B=?)K>2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#
M96QL('-P86-I;F<Z(@IM<V=S='(@(DUE>F5R>2!M97II(&)U\FMA;6DZ(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H
M;VYE(@IM<V=S='(@(DUO8FEL;NT@=&5L969O;B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G
M<W1R(")+96QT<VO]("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT
M97(B"FUS9W-T<B`B4W3X960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4W3X961O869R:6-KX2!R97!U
M8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N
M=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B4W3X961O979R
M;W!S:_T@*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS
M9W-T<B`B4&]D<F]B;F]S=&D@8V5R=&EF:6OA='4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0HC+"!F=7IZ>0IM<V=I9"`B0V5R
M=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B4&]D<F]B;F]S=&D@8V5R=&EF:6OA
M='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM
M<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]D;>UN:WD@
M8V5R=&EF:6OA='4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T
M<B`BR&%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(EIM[&YI="(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS
M9W-T<B`B5OUC:&]Z[2!N87-T879E;NT@5F&Y96AO(&AE<VQA(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB3F%S
M=&%V96[M(&IMZ6YA(&$@96UA:6QO=ND@861R97-Y+B!4>71O('!O;&^^:WD@
M;&EDZ2!U=FED[2P@:V1YOB!S:2#H=&]U("(*(FYE8F\@;V1P;W;M9&%J[2!N
M82!68;EE('IP<N%V>2XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B
M"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-PIM<V=I9"`B0VAA<B(*;7-G<W1R("):;F%K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#
M:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")::V]N=%]R;VQO=F%T(&]D:V%Z+BXN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("+([6YA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*2(*;7-G<W1R("+([6ZY=&EN82!Z:F5D;F]D=;EE;N$@*$="
M,C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B5')A9&GH;NT@Z.UN
MN71I;F$@*$)I9S4I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B6G9O
M;'1E(&AE<VQO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B6G9O;'1E
M('6^:79A=&5L<VOI(&IMZ6YO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G
M<W1R(")6>6)R870@>F]B<F%Z96[M(&1A='5M=3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED
M(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB
M"FUS9W-T<B`B5GEB<F%T('1Y<"!S='EL=2!S97IN86UU("AP<F\@^&%Z96[I
M('-E>FYA;7DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N
M9"(*;7-G<W1R(")6X6YOZ&[M(&]S=')O=B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(DYE8GEL82!N86QE>F5N82!D969I;FEC92!T^.UD
M>2`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B5GGH:7-T:70B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#
M;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(E9YZ&ES=&ET('IN8>AK>2!Z
M($U33V9F:6-E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ
M>0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B3V1S=')A;FET('6^:79A
M=&5L92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R
M(")/9'-T<F%N[&[M('6^:79A=&5L93H@)7,B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T
M<B`B3V1S=')A;FET('6^:79A=&5L92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T
M<B`B3V1S=')A;NQN[2#Z9&%J^2!O('6^:79A=&5L:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED
M(")#;&5A<FEN9R!,871E(@IM<V=S='(@(E!O>F1N[2!DZ;F[(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@
M(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML:6MN['1E('!R;R!P;VMR
M8>AO=N%N[2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G
M<W1R(")#;&EC:V%T96QL('#X97,@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I
M9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(EIA=OCM="!O:VYO(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("):
M871AOF5N;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B
M3V)L8>AN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B3V)L8>AN;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(DMO:V]S;W;I(&]S=')O=GDB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E-K
M;&%P;F]U="!B;^AN[2!L:;ET=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B
M;W)D97)S(@IM<V=S='(@(E-K;&%P;F]U="!O:W)A:F4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I92(*"B,Z(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y
M"FUS9VED(")#;VQO<B(*;7-G<W1R(")"87)V82(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R
M(")6_6+L<B!B87)E=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B4&%L971A(&)A
M<F5V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(E-L;W5P8V4Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE
M<R(*;7-G<W1R(").X7IV>2!S;&]U<&-E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(DMO;6EK<WDB
M"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS
M9W-T<B`B4/CM:V%Z(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED
M(")#;VUM86YD(%-H96QL(@IM<V=S='(@(E#X[6MA>F]VX2!K;VYZ;VQA(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#
M;VUM96YT(@IM<V=S='(@(E!O>F[A;6MA(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S
M='(@(D]B96-NZ2!J;>EN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(DMO;6]R;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D9I
M<FUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP
M=71E<G,B"FUS9W-T<B`B4&_H[71AZ&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS
M9W-T<B`B4&]D;>UN:WDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM
M<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")0;V1M[6YK>2(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S(@IM<V=S='(@(E)O>F3M;'D@=B!N87-T879E;NTB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O
M<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@
M9G5Z>GD*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM
M<V=S='(@(DIE('3X96)A(&%K='5A;&EZ;W9A="!N87-T879E;NTN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B3F%S=&%V:70@)7,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M
M(%!A<W-W;W)D(@IM<V=S='(@(E!O='9R9&ET(&AE<VQO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM
M<V=S='(@(DMO;F=O+"!$96UO:W)A=&EC:^$@<F5P=6)L:6MA(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960N(@IM<V=S='(@(E-P;VIE;NT@<V5L:&%L;RXB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED
M(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(E-P;VIE;NT@<V5L:&%L
M;SH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS
M9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(@IM<V=S='(@(D)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE:F[]
M;2!K;.WH;W;];2!S97)V97)E;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RDB"FUS9W-T<B`B0GEL;R!Z86WM=&YU=&\@<W!O:F5N[2!S('9E^&5J
M;OUM(&ML[>AO=OUM('-E<G9E<F5M+B!$^79O9"`Z("5S("@E<RDB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4V5L:&%L;R!S<&]J
M96[M(',@1E10('-E<G9E<F5M+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+B(*;7-G<W1R(")+;VYT86MT>2!B>6QY(/IS<.RY;NP@</AI9.%N>2!D
M;R!68;EE:&\@861R97/A^&4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F
M(%PB)7-<(B(*;7-G<W1R(")/8G-A:"!V("<E<R<B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(E!O:W)AZ&]V870B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:V]V
M>2!O<W1R;W9Y(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED
M(")#;V]K:64B"FUS9W-T<B`B2V]LX>AE:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P
M>2(*;7-G<W1R(")+;W#M<F]V870B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F
M86EL960Z("5S(@IM<V=S='(@(E-P;VIE;NT@<V5L:&%L;SH@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B
M0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P[7)O=F%T(';]8NQR(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O
M<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC
M82(*;7-G<W1R(")+;W-T87)I:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E
M(&0G279O:7)E(@IM<V=S='(@(E!O8OAEONT@<VQO;F]V:6YY(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B6G!RX79U(&YE;'IE
M(+EI9G)O=F%T('!O;6]C[2!01U`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4N(@IM<V=S='(@(EIP<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@
M4$=0+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`B6G!RX79U(&YE;'IE(+EI9G)O=F%T('!O;6]C[2!3+TU)344N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("):<'+A
M=G4@;F5L>F4@<&]D97!S870@<&]M;V/M(%,O34E-12XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S
M='(@(DYE;'IE('#X:61A="!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET(&L@3$1!4"!S97)V97)U
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE
M;'IE('-E('#X:7!O:FET(&L@3$1!4"!S97)V97)U+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B
M"FUS9W-T<B`B3F5L>F4@>FMO;G1R;VQO=F%T(/KH970N("5S(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3F5L>F4@<V4@
M</AI<&]J:70@:R!334(@<V5R=F5R=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G
M<W1R(").96QZ92!S92!P^&EP;VII="!K('-E<G9E<G4@)R5S)R!P;VUO8^T@
M1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;'IE('9Y
M='9O^&ET(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T82XB"FUS9W-T<B`B3F5L>F4@9&6Y:69R;W9A="!01U`@
M9&%T82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R
M,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(DYE;'IE(&1EN6EF<F]V870@4R]-24U%(&1A=&$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*
M;7-G<W1R(").96QZ92!S;6%Z870@:V]N=&%K="X@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").96QZ92!S;6%Z870@9&ES=')I8G7H;NT@<V5Z
M;F%M+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@<VUA>F%T
M(&YA<W1A=F]V86/M('-K<FEP="!P<F\@86MT=6%L:7IA8VD@)R5S)RXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D
M971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G
M<W1R(").96QZ92!Z:FES=&ET(&4M;6%I;&]V;W4@861R97-U('#X[6IE;6-E
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S
M<R!B;V]K+B(*;7-G<W1R(").96QZ92!Z[7-K870@^G!L;OT@861R97/A^"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R(").96QZ92!Z[7-K870@^G!L;OT@9&ES=')I
M8G7H;NT@<V5Z;F%M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R
M(").96QZ92!Z[7-K870@^G!L;OT@<V5Z;F%M(&1I<W1R:6)UZ&[M8V@@<V5Z
M;F%M^2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A
M=&5G>2!<(B5S7"(N(@IM<V=S='(@(E-T<F%T96=I92`G)7,G(&IE(&YE9&]S
M='5P;N$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I
M<F5C="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('IA;&^^:70@)R5S
M)RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(DYE;'IE('KM<VMA="!V9?AE:F[](&ML[>@@>B!K
M;.WH;W;I:&\@<V5R=F5R=2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S
M7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(DYE;'IE(&]T97;X[70@)R5S)R!K
M('KA<&ES=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(DYE;'IE(&]T97;X[70@)7,N(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F5L>F4@<')O=NES="!O<&5R86-E(/ID
M<KYB>2!P<F\@;6]D=6P@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE;'IE(&]T97;X[70@861R97/A^"`G
M)7,G+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5L
M>F4@:&QE9&%T('8@3$1!4"!S97)V97)U+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+T]B:F5C="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R96%D("5S+B(*;7-G<W1R(").96QZ92#H[7-T("5S+B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N
M;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N
M(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C
M="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3F5L>F4@
M<F5S971O=F%T(&AE<VQO('!R;R!D86[I:&\@=;YI=F%T96QE+B!6N65C:&YY
M(&YE8F\@;NQK=&5RZ2!Z("(*(G!O9')O8FYO<W3M(&YE8GEL>2!S<'+A=F[L
M('IA9.%N>2X@6FMU<W1E('1O('IN;W9U(&YE8F\@<&]K=60@<&]T^&5B=6IE
M=&4@(@HB<&]M;V,L(&MO;G1A:W1U:G1E('-P<N%V8V4@<WES=.EM=2XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DYE;'IE('KM<VMA="!!0TPB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").96QZ92!Z[7-K870@861R97/A
M^"X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;'IE('KM
M<VMA="!D:7-T<FEB=>AN[2!S97IN86TN("5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,B"FUS9W-T<B`B3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA
M;7DN("5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,B"FUS9W-T<B`B3F5L>F4@>NUS:V%T('-C:&]P;F]S=&D@<V5R=F5R
M=2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F5L>F4@</AE
M<&YO=70@:V]N9FEG=7)A8VDN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E
M<UPB+B(*;7-G<W1R(").96QZ92!O9'-T<F%N="`G)7,G+B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYE;'IE
M('5L;[YI="!K;VYF:6=U<F%C:2!P<F\@)7,N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(DYE;'IE('5L;[YI="!ZX6QOOF[M(&MO;F9I9W5R86-I+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R(").96QZ92!U;&^^:70@>N%L;[YN[2!K;VYF:6=U<F%C:2`E
M<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@=6QOOFET(&YA
M<W1A=F]V86/M('-C<FEP="!P<F\@86MT=6%L:7IA8VD@9&\Z("<E<R<N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B3F5L>F4@=6QOOFET('KA;&]H=2!K;VYF:6=U
M<F'H;NUH;R!S;W5B;W)U("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*(DYE;'IE('IA<'-A="X@3?F^971E('!O=;[M
M="!S:W)I<'0@<')O(&%K='5A;&EZ86-I(&YE8F\@<G7H;NP@>FMO<.UR;W9A
M="`B"B)N[;YE('5V961E;OT@:_-D(&1O("5S+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5L>F4@:&QE9&%T('8@3$1!
M4"!S97)V97)U+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM
M<V=S='(@(DYE;'IE(&]D<&]J:70@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(DYE;'IE(&%K='5A;&EZ;W9A="!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(DYE;'IE(&%K='5A;&EZ;W9A="!D:7-T<FEB=>AN
M[2!S97IN86TN("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N
M9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(").96QZ92!U;&^^
M:70@:V]N9FEG=7)A8VD@<')O("<E<R<Z("5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS
M9W-T<B`B(@HB3F5L>F4@;F%LZ7IT(&)OZ&[M(&QIN71U('!R;R!-;WII;&QU
M+B!0<F]S[6T@</AE<W;L9.AT92!S92P@OF4@:F4@;W1E=OAE;N$N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@
M7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B5;YI=F%T96QI("<E<R<@;F5L>F4@<&]S:WET
M;F]U="!NX7-L961U:NUC[2!P<N%V82!P<F\@<VQOOFMU("<E<R<Z("5S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E
M9"!T97AT(@IM<V=S='(@(D]D<&_H[71A;OT@=&5X="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM
M<V=S='(@(EIE;>PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S
M"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(E9Y=>AO=F%C[2!P^&5D;>QT>2(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(E9Y='9O^&ET(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(E9Y='9O^&ET
M(&]D:V%Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")6>71V;_AI
M="!N;W9O=2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B5GET
M=F_X:70@<&]D<VQOOFMY(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M5';Y<F-E('!RX78B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P
M"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BR.US;&\@:W)E
M9&ET;NT@:V%R='DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G
M<W1R(")#:&]R=F%T<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G
M<W1R(")+=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY
M"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(D%K='7A;&[M(&;A
M>F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@
M(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B5';Y<F-E('!RX78B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G
M:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")!:W1UX6QN[2#H87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D%K='7A;&[M(%52
M3"!J92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I
M9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")!:W1UX6QN[2!FX7IE(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R
M(@IM<V=S='(@(D%K='7A;&[M('!OZ&%S[2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B
M"FUS9W-T<B`B06MT=>%L;NT@<&]D;>UN:WDZ("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@
M<W1Y;&4B"FUS9W-T<B`B3GEN[&JY[2!S='EL(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(DYA<W1A
M=F5N[2#Z:V]L^2!P<F]VX63L;OUC:"!P^&D@</AI:&SAN65N[2!D;R`E<RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")6>7-T^&EH;F]U="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G
M:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B5GES=/AI:&YO=70@=OUB['(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B2WEP<B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])
M."U2*2(*;7-G<W1R(")!>F)U:V$@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB
M"FUS9W-T<B`B07IB=6MA("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*2(*;7-G<W1R(")!>F)U:V$O56MR86II;F$@*$M/23@M52DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("+(97-KX2!R
M97!U8FQI:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*
M;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*
M;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&5N;NPB"@HC.B!A9&UI;B]D
M871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T
M<B`B1&%T851R964@<')O:&SMOF7H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G
M<W1R(")$871U;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(E#X:6IA=&\@
M9&YE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B
M1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B5OUB['(@9&%T=6UU(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S(R"FUS9VED(")$87DB"FUS9W-T<B`B1&5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")3;6%?>F%T('-L
M;W5P96,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B4')O<VEN96,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`BR.US;&$@9&5S
M[71K;W;I('-O=7-T879Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S
M='(@(EIM96ZY:70@;V1S87IE;NTB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L
M="(*;7-G<W1R("));7!L:6-I=&[M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B
M"FUS9W-T<B`B26UP;&EC:71N[2!B87)V82(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB
M"FUS9W-T<B`B26UP;&EC:71N[2!I9&5N=&ET82(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*
M;7-G<W1R("));7!L:6-I=&[M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")$969I;FEC92(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@
M(D1E;&5T92(*;7-G<W1R(")3;6%Z870B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!#96QL(@IM<V=S='(@(E-M87IA="!B=?)K=2(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED
M(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B4VUA>F%T('-K=7!I;G4B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!,;V<B"FUS9W-T<B`B4VUA>F%T(/CA9&5K(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B4VUA>F%T('!RX79A(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B4VUA>F%T(&$@=GGH:7-T:70@>G!RX79Y(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM
M<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B4VUA>F%T(&)U\FMU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")3;6%Z870@<VQO=7!E
M8R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E-M87IA="!E
M>&ES='5J[6/M(&%L=&5R;F%T:79N[2!V>F]R(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E-M
M87IA="!P<N%V82!P<F\@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\B"FUS9W-T<B`B4VUA>F%T('!RX79A(&$@<&]D<'+A=F$@<')O("<E
M<R<_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")3;6%Z870@
M^.%D96LB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC
M.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M4VUA>F%T('9Y8G)A;F]U*.DI(&ED96YT:71U*'DI(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E-M87IA="!S
M;W7H87-N_2!S;&]U<&5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@<F]W(@IM<V=S='(@(E-M87IA="!S;W7H87-N_2#XX61E:R(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`B2V]N9FEG=7)AZ&[M('-C<FEP="!P<F\@86MT=6%L:7IA
M8VD@)R5S)R!B>6P@<VUA>N%N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E
M;&EV97)Y('1I;64B"FUS9W-T<B`BR&%S(&1O<G7H96[M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$X6YS:V\B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE
M(%!R;V)L96TB"FUS9W-T<B`B4&]P<V%T('!R;V)LZ6TB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4&]P:7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*
M;7-G<W1R(")0;V1R;V)N;W-T:2`H=&%KZ2!V(&QO9R!S;W5B;W)U($AO<F1E
M*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B4&]D<F]B;F]S=&D@8GEL>2!Z87IN86UE;N%N>2!D;R!L
M;V<@<V]U8F]R=2!P<F\@861M:6YI<W1RX71O<F$N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T
M<B`B5OUV;VHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B
M1&5W(%!O:6YT(@IM<V=S='(@(E)O<V[](&)O9"(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@
M(@IM<V=S='(@(E)O<V[](&)O9"!Z82!P;W-L961N[2!H;V1I;G4Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P
M;VEN=#H@(@IM<V=S='(@(E)O<V[](&)O9#H@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B4VWL<B!Z(&QE=F$@9&]P<F%V82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*
M;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(E-M['(@
M>B!P<F%V82!D;VQE=F$B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D%D<F5SX?@B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_(@IM<V=S='(@(EIO8G)A>FET(#(T+6AO9&EN;W;](.AA<S\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N
M<R(*;7-G<W1R(")-;[YN;W-T:2!Z;V)R87IE;NTB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@
M9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B6F]B<F%Z:70@</AE9'!O=NSO
M("A4048I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("):;V)R87II="!P^&5D<&]V
M[.\@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"FUS
M9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")&;W)MX70@>F]B<F%Z96[M
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D1I<W!O>FGH;NT@
M=7!O>F]R;NQN[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S
M='(@(D1J:6)O=71I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F5S;6%Z870B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DYE
M</AI<W1U<&]V870@</CM;6\@9&\@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN
M('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS
M9W-T<B`B(@HB3V)S86AU:F4@<')V;NT@^.%D96L@;N%Z978@<VQO=7!C^3\@
M4&]K=60@86YO+"!Z8;EK<G1N['1E('1E;G1O('+A;67H96LZ(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI:V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M
M:6YI:^%N<VOA(')E<'5B;&EK82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U
M<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R(")3=&&^96[M(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H
M<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(E-T8;YE;NT@
M)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N
M;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*
M;7-G<W1R(")3=&%H;F]U="!G96YE<F]V86YO=2!K;VYF:6=U<F%C:2!J86MO
M(%!(4"!S:W)I<'0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P
M-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B4F]L971O=OT@<V5Z
M;F%M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G
M<R(*;7-G<W1R(")$<F]G>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS
M9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R
M<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16MVX61O<B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N
M:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(E5P<F%V:70B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO
M961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B57!R879I
M="!B;&]K(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S
M+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B57!R879I="!S
M:W5P:6YU(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!0
M97)M:7-S:6]N(@IM<V=S='(@(E5P<F%V:70@<'+A=F$B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(E5P<F%V:70@<'+A=F$B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(E5P<F%V:70@<'+A=F$@<')O("5S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I
M;VYS(&9O<CHB"FUS9W-T<B`B57!R879I="!M;[YN;W-T:2!P<F\Z(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*
M;7-G<W1R(")5<')A=FET('!RX79A('!R;R`E<R(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B57!R879I="!P<N%V82!P<F\@
M)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A
M=&EO;B(*;7-G<W1R(")6_75K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T
M(@IM<V=S='(@(D5G>7!T(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T
M:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM
M<V=S='(@(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN
M(@IM<V=S='(@(E!R=F5K+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G
M<W1R(")%;6%I;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA
M:6P@061D<F5S<R(*;7-G<W1R(")%;6%I;&]VX2!A9')E<V$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"XB"FUS9W-T<B`B16UA:6QO=ND@861R97-Y('-E(&UU
M<^T@<VAO9&]V870N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX
M.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B16UA
M:6P@<R!P;W1V<GIE;NUM(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")):V]N:WD@
M<R!E;6]C96UI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R
M(")0<N%Z9&[A('IP<N%V82XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT
M.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM
M<V=S='(@(E!RX7ID;OT@=OUS;&5D96LN(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS
M(@IM<V=S='(@(E!RX7ID;OT@=&5R;>UN('!R;R!V>6AL963A=N%N[2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(E!O=F]L:70@=FMLX63A;NT@;V)R87IK^2!Z(&9O=&\@9V%L
M97)I[2!D;R!T97AT=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X
M"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G
M<W1R(")!:W1I=F]V870@<')A=ND@:VQI:VYU=.T@<')O(&MO;G1E>'1O=ND@
M;65N=3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S
M='(@(DMO;F5C(')O:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R
M("):=NQTN6ET(&5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B
M"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.B(*;7-G<W1R("(B"B):861E:G1E(&)E>G!EZ&YO<W1N[2!O=.%Z:W4L
M(&YA(&MT97)O=2!B=61E=&4@;75S970@;V1P;W;L9.QT('!O:W5D('-I("(*
M(F)U9&5T92!C:'3M="!R97-E=&]V870@<W;I(&AE<VQO+"!N87#X+B`G2F%K
MZ2!J92!J;>EN;R!68;EE:&\@<'-A/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%
M;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B6F1E('9L;[YI="!5
M4DP@;V)RX7IK=2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE
M82(*;7-G<W1R(")2;W9N[6MO=N$@1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5A(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B
M"FUS9W-T<B`B0VAY8F$B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI
M(&]D97/M;.%N[2!O9'!O=NQD:3H@)7,N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L
M971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B3F%S
M=&%L82!C:'EB82!P^&D@;V1E<^ULX6[M(&]D<&]V[&1I.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*
M;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!O9&5S[6SA;NT@;V1P;W;L9&DZ
M("5S+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O
M<F0Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&]D97/M;.%N[2!O
M9'!O=NQD:3H@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<R!P;[ET;W9N[2!Z<'+A
M=F]U+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")#
M:'EB82!P^&D@>N%P:7-U("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T
M;VYI82(*;7-G<W1R(")%<W1O;G-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(D5T:6]P:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI8VOI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B
M"FUS9W-T<B`B179R;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")+8;YD_6-H(#$U
M(&UI;G5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B
M179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(DMAOF3I(#(@;6EN=71Y(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DMAOF3]
M8V@@,S`@<V5K=6YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T
M97,B"FUS9W-T<B`B2V&^9/UC:"`U(&UI;G5T(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G
M:6XB"FUS9W-T<B`B2V&^9.D@</AI:&SAN65N[2!D;R!S>7-TZ6UU(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H
M;W5R(@IM<V=S='(@(DMAOF1O=2!P^6P@:&]D:6YU(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS
M9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2V&^9&]U(&UI;G5T=2(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE
M('9A;'5E<SHB"FUS9W-T<B`B5GIO<F]V_2!P^.UK;&%D(&AO9&YO=#HB"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T
M<B`B4')O=NES="(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(E)O>G9I;F]U="(*"B,Z
M('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N
M9"!3:61E8F%R(@IM<V=S='(@(E)O>F)A;&ET(&)OZ&[M(&QIN71U(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP
M96-T960@)RDG(@IM<V=S='(@(D_H96OA=N%N82`G*2<B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(D_H96OA
M=N%N;R!S86UO<W1A=&[I('-L;W9O(&YE8F\@:&QE9&%N_2!T97)M[6X@=B!U
M=F]Z;W9KX6-H(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T=6T@<')O
M(&MO;F5C('!L871N;W-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D)A<G9A('!O</AE
M9.TB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@
M=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(E#X96YO<R!K;VYF:6=U<F%C92!P
M;VUO8^T@1E10(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z
M,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS
M9W-T<B`B4V5L:&%L;R!Z[7-KX6[M(&UOOFYO<W3M+B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3F5L>F4@<V4@</AI<&]J:70@:R!,1$%0('-E
M<G9E<G4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R
M(").96QZ92!S92!P^&EP;VII="!K(%--0B!S97)V97)U+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")396QH86QO
M(&MO<.UR;W;A;NT@>B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HV.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")396QH86QO(&MO<.UR;W;A;NT@9&\@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B4V5L:&%L;R!Z86QOOF5N[2!N;W;I:&\@4T%33"!S<&]J96[M
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B4V5L:&%L;R!P^&5S
M=6YU=.T@9&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M<F5T<FEE=F4Z("5S(@IM<V=S='(@(E-E;&AA;&\@</AE<W5N=73M(&1O(%PB
M)7-<(BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")$;V)RZ2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&
M86QK;&%N9'-KZ2!O<W1R;W9Y("A-86QV:6YY*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G
M:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1F%R:6IS:^D@;W-T<F]V>2(*
M"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R
M<F]R.B(*;7-G<W1R("):X79AOF[A(&-H>6)A.B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G
M<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L
M(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R(")&87@B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A
M<GDB"FUS9W-T<B`BVFYO<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P
M"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(D/M=&ET('-E(&IA:V\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L
M<R!L:6ME.B`B"FUS9W-T<B`B0^UT:70@<V4@:F%K;SHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H
M;W=E<G,B"FUS9W-T<B`B1')O8F[I('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B1')O8F[I('-N[&AO=ND@</AE:.'R:WDB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B36%T:6-E('!O;&4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&
M:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II
M(@IM<V=S='(@(D9I:FDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B<V]U8F]R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")0;^AE="!S;W5B
M;W+Y.B`E<R!S;W5B;W(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*
M;7-G<W1R(")0;^AE="!S;W5B;W+Y.B`E<R!S;W5B;W+Y(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM
M<V=S='(@(E-P<N%V8V4@<V]U8F]R^2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@U"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B3N%Z978@<V]U
M8F]R=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@
M(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E;]8NQR('-O=6)O<G4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A
M9"(*;7-G<W1R(")0^&5NZ7-T('-O=6)O<B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S
M=7!P;W)T960N(@IM<V=S='(@(E#X96YO<R!S;W5B;W+Y(&YE;NT@<&]D<&]R
M;W;A;BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@
M(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')Y(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M1FEN;&%N9"(*;7-G<W1R(")&:6YS:V\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(E!R=F[M('!O;&]V
M:6YA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")0<G9N[2#H
M='9R=&EN82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")0979NZ2!M[/CM
M=&MO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R(")0^&5H;V1I="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G
M:60@(D9L;V%T(@IM<V=S='(@(E!L;W9O=6/M(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R
M(")-;&AA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B4VQOOFMA
M("5S(&YE97AI<W1U:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D)A
M<G9A('#M<VUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED
M(")&;V]D(@IM<V=S='(@(DKM9&QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")0
M<F\@<')O:&SMOF7H92!N97!O9'!O<G5J[6/M(&]B<N%Z:WDB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`B4/AE9'!O=NSO("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H
M870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD
M(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(E#X961P;W;L[R!P;^AA<^T@
M<')O(&1N>2`H<&]Z;N%M:V$Z('#X961P;W;L[R!J92!P<F\@9&YY(&D@;F]C
M:3L@=&]T;R!M^;YE("(*(G9Y='9O^&ET('!O;>QR;NP@;V)SX6AL_2!S97IN
M86TN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@
M(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("):87!O;6[L;&D@:G-T
M92!68;EE(&AE<VQO/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUU;.'X92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("*I
M=.QS=.TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O
M<G1U;F4@='EP92(*;7-G<W1R(")4>7`@N73L<W3M(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("*I=.QS
M=.TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U
M;F5S(#(B"FUS9W-T<B`BJ73L<W3M(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1O-R82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S
M(@IM<V=S='(@(E#X97!O<VSA;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")0X2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")2X6UY(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YC:64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P
M;VQI=&%N(@IM<V=S='(@(D9R86YC:64L(&UE=')O<&]L:71N[2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1G)A;F-O=7-K
MX2!'=6%IX6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S
M:6$B"FUS9W-T<B`B1G)A;F-O=7-KX2!0;VQY;NES:64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R
M(")&<F%N8V]U<VOA(&IIOF[M('1E<FET;W)I82(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS
M9W-T<B`B3V0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S
M='(@(D]D(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*
M;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&]D<F]B;OT@<&]P
M:7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(MIP;&[L:R(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B0V5L
MZ2!J;>EN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A
M8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R(")'86QE<FEE('!R;R!V_6+L<B!O8G+A>FOY(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FEE.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:64B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B5GET=F_X:70@
M)7,@:V]N9FEG=7)A8VDB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N
M9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B5GEG
M96YE<F]V86[](&OS9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS
M9W-T<B`B1W)U>NUN<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*
M;7-G<W1R(").[&UE8VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS
M9W-T<B`B1VAA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B2_AE<W1N
M[2!J;>EN;R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED
M(")';R(*;7-G<W1R(")*9&D@;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`HC+"!F=7IZ
M>0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B5GEH;&5DX7;A;NT@<&]M
M;V/M($=O;V=L=2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G
M:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B5GEH;&5DX7;A;NT@<&]M;V/M
M($=O;V=L=2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(")3='5P;NP@N65D
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`BV&5C:V\B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(MAE8VOI("A)4T\M.#@U.2TW*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<O-N<VMO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C92!P<F\@<VMU<&EN>2(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N
M;VXM96UP='DB"FUS9W-T<B`B375S[2!B_70@>F%DX6YO(&IMZ6YO('-K=7!I
M;GDB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B075T:%]L9&%P.B!.96QZ92!P^&ED870@=;YI=F%T96QE
M("5S+B!(;.&Y96[M('-E<G9E<G4Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5L
M>F4@86MT=6%L:7IO=F%T('6^:79A=&5L92`E<R(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C,W.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O
M=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")!
M=71H7VQD87`Z($YE;'IE(&%K='5A;&EZ;W9A="!UOFEV871E;&4@)7,B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(E-K=7!I;GDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@
M(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!RX79A(&AO<W3Y(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`IM<V=I9"`B1W5E<W1B;V]K
M(@IM<V=S='(@(DMN:6AA(&AO<W3Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I
M;F5A(@IM<V=S='(@(D=U:6YE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I
M;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN96$M0FES<V%U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA4
M34PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R
M96$@>F)A8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M(&)U\FMU(&YA(/CA
M9&MU+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B
M2%1-3$%R96$@>F)A8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M(&)U\FMU
M('9E('-L;W5P8VD@=&%B=6QK>2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B
M;&4N(@IM<V=S='(@(DA434Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P
M;W-L961N[2#XX61E:R!V('1A8G5L8V4N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")/=NSX;W;A;NT@<&]M;V/M($A45%`@;F5B
M>6QO(&YA;&5Z96YO+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS
M9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M86QG
M;W)I=&UU<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DUL:&%V;R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`B2&QA=FGH:V$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U
M>GIY"FUS9VED(")(96%D97)S(@IM<V=S='(@(DAL879IZ&MA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',B"FUS9W-T<B`B2&5A<F0@27-L86YD(&$@36-$;VYA;&0@27-L86YD<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"B,L
M(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(D)O=?AK82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E3
M3RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5JN71I;F$@*$E33RTX.#4Y+3@M
M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B5OVY:V$B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](
M;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE
M;'`B"FUS9W-T<B`B3N%P;W;L9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O
M<B(*;7-G<W1R(").X7!O=NQD82!P<F\@961I=&]R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(E!O
M;6]C;NUK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI
M<W!H97)E(@IM<V=S='(@(DAE;6ES9NER82(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P
M"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM
M<V=S='(@(EID92!J92!Z8>CA=&5K('-O=6)O<G4Z(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS
M9W-T<B`B5GES;VOA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV
M('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(
M;U]M92(*;7-G<W1R(")?2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")3=F%TZ2!-
M['-T;R`H5F%T:6OA;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@
M061D<F5S<R(*;7-G<W1R(")!9')E<V$@9&]M^2(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!$:7)E8W1O<GDB
M"FUS9W-T<B`B061R97/A^"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B
M5&5L969O;B!D;VWY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*
M;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+
M;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.97!L
M871NZ2`E<R!834P@9&%T82!V92!Z<'+A=NP@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(*[A9&[A('IP<N%V82!S92!N97-H;V1U
M:F4@<R!O8FIE:W1E;2`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O
M8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!.96)Y;"!N86QE>F5N(+[A9&[](&]B:F5K="!T>7!U
M("5S('9E('IP<N%V["`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B#:<W#LN6[I(&]D<W1R86[L;NT@)7,@7"(E<UPB(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4
M:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!0
M2%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);G1E9W)AZ&[M
M(&[A<W1R;VH@<&]T^&5B=6IE(%!(4"!P^.UP;VYU("=D;VUX;6PG(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;'IE
M('9Y='9O^&ET(&YO=OT@<W1R;VT@6$U,('!R;R!O8FIE:W0@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5L>F4@;V1S=')A;FET("5S
M(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z($YE;'IE('KM<VMA="!-24U%($E$('!R;R#H
MX7-T('1Y<'4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!.96QZ92!S>6YC:')O;FEZ;W9A="`E<R!<(B5S7"(Z("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5L>F4@<WEN8VAR;VYI
M>F]V870@<V3M;&5NZ2!O8FIE:W1Y.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@3F5Z;N%M_2!S9.UL96[](&]B:F5K="!<(B5S7"(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I
M>F]N=&%L(%)U;&4B"FUS9W-T<B`B5F]D;W)O=F[I('!R87;M=&MO(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DAO<FEZ;VYTX6QN[2!O
M9'-T=7`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N=.%L
M;NTZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*2(*;7-G<W1R(")*86L@:G-T92!S92!S96T@9&]S=&%L
M:3\@*%IAN6QE=&4@<')O<^UM('IP<N%V=2$I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B2V]L:6L@<VQO=7!C^2!C:&-E=&4@<W!O:FET/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B2V]L:6L@:F4@=&%M('!O
M;.T@*'-L;W5P8_DI/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(DMO;&EK(/CA9&OY(&-H
M8V5T92!S<&]J:70_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB
M"FUS9W-T<B`B5FQH:V]S="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B5FQH:V]S=#HB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T
M<R(*;7-G<W1R(")(=6UO<F[I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG
M87)Y(@IM<V=S='(@(DUA[V%R<VMO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B4V5L:&%L;R!V>71V;_AE;NT@24U!
M4&]VZ2!S8VARX6YK>3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R(")396QH86QO('-M87KA;NT@24U!4&]VZ2!S
M8VARX6YK>3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R(")396QH86QO(&YA<W1A=F5N[2!K=O-T>2!P
M<F\@24U!4&]V;W4@<V-H<N%N:W4Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!A
M9')E<V$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W
M"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0
M(&%D<F5S82!N96[M(&1O<W1U<&[A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0(&%D<F5S82!N96[M
M('8@<&]V;VQE;NEM($-)1%(@<F]Z<V%H=2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO
M8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B4&]R=;EE;NT@:6YT96=R:71Y
M($E0+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S
M='(@(E9?;&^^=&4@^.%D96L@</AE9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M26-E;&%N9"(*;7-G<W1R("))<VQA;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E!O=7IE(&EK
M;VYY(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N>2!P<F\@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W
M:71H('1E>'0B"FUS9W-T<B`B26MO;GD@<R!T97AT96TB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM
M<V=S='(@(D[A>F5V(&ED96YT:71Y.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(E!O:W5D('IO8G)A>F5N[2!N96[M
M('8@<&_XX61K=2P@)7,@;W1E=OCM="!V(&YO=NEM(&]K;NPN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@
M=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)0;VMU9"!P;W6^[7;A=&4@26YT
M97)N970@17AP;&]R97(@82!N979I9.UT92"^X61NZ2!I:V]N>2P@>OAE:FWL
M('!O=/AE8G5J971E("(*(F]Z;F'H:70@=&5N=&\@<N%M9>AE:R!P<F\@=GEP
M;G5T[2!03D<@=')A;G-P87)E;F-E+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W
M<V5R+B(*;7-G<W1R("(B"B)0;VMU9"!V:63M=&4@='5T;R!Z<'+A=G4@;>US
M=&\@;V)RX7IK=2P@;V)RX7IE:R!K=&5R_2!C:&-E=&4@</AE;NES="!N96QZ
M92`B"B)68;GM;2!P<F]H;.V^9>AE;2!Z;V)R87II="XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*
M;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(D[A:&QE9"!O8G+A>FMU
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")54DP@;V)RX7IK
M=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@
M;V)RX7IK=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>2(*;7-G<W1R(")/8G+A>F5K('H@9V%L97)I92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")/8G+A>F5K('H@9V%L
M97)I93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED
M("));6%G92!U<&QO860B"FUS9W-T<B`B4/AE;F]S(&]B<N%Z:W4B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@
M(D]B<N%Z:WDB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("))
M;7!O<G0L(&MR;VL@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B
M"FUS9W-T<B`B26UP;W)T;W9A;ND@<&]L93H@)7,B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM
M<V=S='(@(DEM<&]R=&]V86[A('!O;&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R(")6;&^^:70@^.%D:W4@>F$B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@
M(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B0GEL('IA
M9.%N(&YE<W!RX79N_2!A:^AN[2!K\V0N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C
M="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE<W!RX79N
M["!Z861A;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYE<W!RX79NZ2!UOFEV871E
M;'-KZ2!J;>EN;R!N96)O(&%L=&5R;F%T:79N[2!A9')E<V$N(%IK=7-T92!J
M9;ET["!J961N;W4@(@HB;F5B;R!K;VYT86MT=6IT92!68;EE:&\@<WES=.EM
M;W;I:&\@861M:6YI<W1RX71O<F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT
M(@IM<V=S='(@(EIV['2Y:70@;V1S87IE;NTB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DEN9&EA(@IM<V=S='(@(DEN9&EE(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B2F5D;F]T;&EV
M[2!UOFEV871E;.DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*
M;7-G<W1R("));F1O;NES:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R
M;6%C92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*;7-G:60@
M(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(J[A9&[I('H@
M;6^^;F]S=.T@;F5J<V]U(&1O<W1U<&[I+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS
M97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B5FQOOFET('-?;&]U<&5C('IA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B5FQO
MOFET(&]B<N%Z96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B5FQO
MOFET('1A8G5L:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B
M5FQOOFET('=E8F]V_2!O9&MA>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#
M;VQU;6X@0F5F;W)E(@IM<V=S='(@(E9L;[YI="!?<VQO=7!E8R!P^&5D("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B5FQOOFET(&YO=OT@<VQO=7!E8R!Z82!S
M;W7H87-N_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YI="!N;W;]('-L
M;W5P96,@</AE9"!S;W7H87-N_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B5FQOOFET
M(&YO=OT@^.%D96L@>F$@<V]UZ&%S;OTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R
M="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")6
M;&^^:70@;F]V_2#XX61E:R!P^&5D('-O=>AA<V[](@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED
M("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*
M;7-G<W1R(")6;&^^:70@;V1S=&%V96,@>F$@<V]UZ&%S;OT@=7IE;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E(@IM<V=S='(@(E9L;[YI="!O9'-T879E8R!P^&5D('-O=>AA
M<V[]('5Z96PB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")6;&^^:70@86QT
M97)N871I=F[M('9Z;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B5FQOOG1E
M(&5M86EL;W9O=2!A9')E<W4L(&YA(&MT97)O=2!O8F1RONUT92!N;W;I(&AE
M<VQO.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@
M(E9L;[YI="!B=?)K=2!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R(")6;&^^:70@8G7R:W4@</AE9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@
M(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B5FQOOFET('-L;W5P96,@
M>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R
M(")6;&^^:70@<VQO=7!E8R!P^&5D(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*
M;7-G<W1R(")6;&^^:70@>G!RX79Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(E9L;[YI="!O9'-T879E8R!Z82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T
M<B`B5FQOOFET(&]D<W1A=F5C('#X960B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(E9L;[YI="#XX61E:R!Z82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G
M:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(E9L;[YI="#XX61E:R!P
M^&5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS
M97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T
M:6]N.B(*;7-G<W1R(")6;&^^=&4@<&^^861O=F%N;W4@;V1P;W;L[R!N82!B
M97IP9>AN;W-T;NT@;W3A>FMU.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA
M9V4B"FUS9W-T<B`B5FQOOFET+W5P<F%V:70@;V)RX7IE:R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN
M<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R(")6;&^^:70O=7!R879I="!O9&MA
M>B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").961O<W1A=&7H;OT@
M:W)E9&ET(&L@;V1E<VSA;NT@>G!RX79Y(&YA(&1I<W1R:6)UZ&[M('-E>FYA
M;2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B
M3F5D;W-T871EZ&[](&MR961I="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(D-E;.D@Z.US;&\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E
M9V5R(&QI<W0B"FUS9W-T<B`B4V5Z;F%M(&-E;/UC:"#H[7-E;"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM
M<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T
M<B`B3F5S<'+A=F[I(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(DYE<&QA=&[A(&1A=&$@
M=6YI8V]D92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED
M("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(").97!L871NX2!A<&QI
M:V%C92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@
M(DYE<&QA=&[I(&ED96YT:69I:V'H;NT@Z.US;&\@*$E$*2!DX79K>2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@
M9&%T82!S=6)M:71T960N(@IM<V=S='(@(D)Y;&$@>F%DX6YA(&YE<&QA=&[A
M(&1A=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RXB"FUS9W-T<B`B3F5P;&%T;N$@861R97-A('#X[6IE;6-E+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L
M:60@9FEL92!F;W)M870B"FUS9W-T<B`B3F5P;&%T;OT@9F]R;>%T('-O=6)O
M<G4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(").97!L
M871NX2!A<&QI:V%C92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(").97!L871NX2!A<&QI:V%C92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@
M(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(DYE<&QA=&[](&US9U]T>7!E
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS
M9W-T<B`B3F5P;&%T;ND@;F5B;R!C:'EB[&KM8^T@87!I7VED+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(DYE<&QA=&[I(&YE8F\@8VAY8NQJ[6/M('!A<F%M971R>2XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE<&QA=&[A('9L87-T;FEC:^$@<'+A
M=F$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(").97!L
M871NX2!V;&%S=&YI8VOA('!RX79A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C
M="!C;V1E+B(*;7-G<W1R(").97!L871N_2!P<F]T;VMO;"XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G
M:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(DYE<&QA=&[]('!R;W1O
M:V]L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@
M7"(E<UPB(@IM<V=S='(@(DYE<&QA=&[]('#X[6IE;6-E.B`G)7,G(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B
M"FUS9W-T<B`B3F5P;&%T;OT@<V3M;&5N_2!O8FIE:W0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(DYE<&QA=&[A(&%D
M<F5S82!O9&5S[6QA=&5L92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R(").97!L871NX2!D871A('5N:6-O9&4N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y
M(@IM<V=S='(@(DEN=F5N=.'X(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.0HC+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E
M;&5C=&EO;B(*;7-G<W1R(")6>7-T^&EH;F]U="!V_6+L<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R
M("+-<N%N+"!)<VSA;7-KX2!R97!U8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DER87$B"FUS9W-T<B`B27+A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M27)E;&%N9"(*;7-G<W1R("))<G-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")/<W1R
M;W8@;76^92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")/:F5D
M:6[L;.D@8F]U^&MY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS
M9W-T<B`B27-R865L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R(")0;W-K>71O=F%T96PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*
M;7-G:60@(DET86QI8R(*;7-G<W1R(")+=7)Z[79A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))=&%L>2(*;7-G<W1R("))=.%L:64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86IK82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y
M(@IM<V=S='(@(DQE9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*
M;7-G<W1R(")*87!O;G-K;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W
M"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]N
MN71I;F$@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B
M;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@
M(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T
M<B`B5')I:V]T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T
M<B`B2F]R9.%N<VMO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`BR&5R=F5N96,B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I
M9"`B2G5N92(*;7-G<W1R("+(97)V96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y
M(@IM<V=S='(@(EIA<F]V;F%T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N
M=&5R(@IM<V=S='(@(EIA<F]V;F%T(&YA('-T^&5D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@
M(DIU<W1I9GD@1G5L;"(*;7-G<W1R("):87)O=FYA="!V>7!L;NQN[6TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(EIA<F]V;F%T(&1O
M;&5V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(EIA
M<F]V;F%T(&1O<')A=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T
M86XB"FUS9W-T<B`B2V%Z86-H<W3A;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_
M(@IM<V=S='(@(E5C:&]V870@;W)I9VENX6P_(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+96YY82(*;7-G<W1R(")+9?)A(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R!S97)V97(@
M>F%M[71N=6P@;W;L^&5N[2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DYO=N'H8VD@:V5R
M;F5L=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM
M<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(E9Y='9O^&5N[2!K;.WH92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B
M2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(E9Y='9O^&5N[2!O=&ES:W4@:VSM
MZ&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`B1.EL:V$@:VSMZ&4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E
M(@IM<V=S='(@(E1Y<"!K;.WH92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DX"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B5;YI
M=.T@:VSMZ&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B2VSMZ"!J:;X@97AI<W1U:F4@;F$@=F7X96IN
MZ6T@:VSMZ&]VZ6T@<V5R=F5R=2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B1.QT:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DM,1%(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO
M<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")+;W)E82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T
M<B`B2V]R96IS:WD@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU
M=V%I="(*;7-G<W1R(")+=79A:G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY
M<F=Y>G-T86XB"FUS9W-T<B`B2WER9VEZ<W3A;B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?4F]Z
M;&^^96[M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I
M9"`B3&%N9W5A9V4B"FUS9W-T<B`B2F%Z>6LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@
M(DQA;W,L($QI9&]V["!$96UO:W)A=&EC:V$@4F5P=6)L:6MA(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@
M(D1R=6CA('!O;&]V:6YA(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V
M"B,L(&9U>GIY"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R
M(")6_6-H;WKM(&YA<W1A=F5N[2!H97-L82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A
M<G1E<B(*;7-G<W1R(")0;W-L961N[2#H='9R=&EN82(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@
M(E!O<VQE9&[M(&%K='5A;&EZ86-E.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R(*;7-G<W1R(")0;W-L961N[2!P^&EH;.&Y96[M.B`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(E!O<VQE9&[M('#X:6AL
MX;EE;NTZ("5S('H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(E!O<VQE9&[M
M('#X:6ALX;EE;NTZ($YI:V1Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V
M:6$B"FUS9W-T<B`B3&ET=F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#0*;7-G:60@(DQA=R(*;7-G<W1R(")0<N%V;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(E)O>FQOOF5N[2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(B"FUS9W-T<B`B3F5C:&%T('!RX7ID;ND@8F5Z(&]K<F%J
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A
M;F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(D1O;&5V82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R
M(@IM<V=S='(@(DQE=N$@:&QA=FGH:V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$U"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")(;V1N
M;W1Y(&YA;&5V;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G
M<W1R("),97-O=&AO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R("),X7-K82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6+I<FEE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM
M<V=S='(@(DQI8FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T
M96EN(@IM<V=S='(@(DQI8VAT96ZY=&5J;G-K;R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(DQE:&OI(&UR:&]L96[M(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB
M"FUS9W-T<B`B3&5H:_T@9.FYNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM
M<V=S='(@(D)R>FO](&QE:&O](&3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E
M(@IM<V=S='(@(E!O>F3L:FD@;&5H:_T@9.FYNR(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN
M(%-H;W=E<B(*;7-G<W1R("),96AKZ2!D9;F[;W;I('-RX;YK>2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),
M:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("),96AK_2!DZ;F[(',@
M:/AM[&[M;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DQE:&OI('-N[+YE
M;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B3&5H:^D@<V[L
M:&]VZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM
M<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EM97)I8VLB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@(D]D
M:V%Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M3V1K87IY('5K87IU:NT@;F$Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"B)0;W6^
M[70@;V1K87IY(&YA(&5M86EL;W;I(&%D<F5S>2!P^&D@>F]B<F%Z;W;A;NT@
M<W1RX6YK>2!P<F\@<'-A;NT@>G!RX78B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*
M;7-G<W1R(")/9&MA>GDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*
M;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>&]VZ2!C;V]K:64B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM
M<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@
M(E-E>FYA;2`M('6^:79A=&5L(&WYOF4@=FED['0@<VQOOFMU(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS
M9W-T<B`B4V5Z;F%M(&1A=&%BX7KM(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B4V5Z
M;F%M('3I;6%T(&[A<&]V[&1Y(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B4V5Z;F%M('1A8G5L96LB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I
M9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(E-E>FYA;2U!<F-H:78B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES
M="U(96QP(@IM<V=S='(@(E-E>FYA;2U.X7!O=NQD82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM
M<V=S='(@(E-E>FYA;2U)9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(E-E>FYA
M;2U6;&%S=&[M:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B4V5Z;F%M+4]D97-L
MX6[M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*
M;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(E-E>FYA;2U0^&EH;.&Y
M96[M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*
M;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B4V5Z;F%M+4]D:&SA
MN65N[2(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM
M<V=S='(@(E;]<&ES('6^:79A=&5L^2!N96[M(&1O<W1U<&[]+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(E;]<&ES('6^
M:79A=&5L^2!N96[M(&1O<W1U<&[]+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B5OUP:7,@=;YI=F%T96SY(&YE;NT@9&]S='5P;OTN
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T
M=7)E(@IM<V=S='(@(DQI=&5R871U<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("),;W1YN7-K;R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N
M+BXB"FUS9W-T<B`B3F%H<N%VX6[M+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@
M(DWM<W1N[2#H87,Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM
M<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DQO8V%L92!A(.AA<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I
M;VXB"FUS9W-T<B`B3>US=&\B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T
M<B`B4/AI:&SA<VET('-E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*
M;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3V1H;.&Y96[M(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G
M<W1R(")0^&EH;.%S:70@<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`W"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("+::V]L>2!P<F]VX63L
M;ND@</AI('#X:6ALX;EE;NTB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S
M='(@(B(*(E-E;&AA;&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU+B!0<F%V9.QP
M;V1O8F[L(%9AN64@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O("(*(FAE<VQO
M(&YE8GEL;R!S<'+A=F[L('IA9.%N;RXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B4/AI
M:&SAN65N[2!S96QH86QO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")$;&]U:/T@=&5X="(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G
M<W1R("),X7-K82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B3NUZ:^$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q
M"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(DUA;.$@^&5C
M:^$@<.US;65N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`B36%LX2!T:7-K86/M('#M<VUE;F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS
M9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DUA;.D@^.UM<VOI
M(.CM<VQI8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS
M9W-T<B`B3'5C96UB=7)S:V\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("):<'+A=F$@9&YE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@
M(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B4/AI<&]J96[]('-O=6)O<B!-4RU.5$5&(&YE;V)S86AU:F4@ON%D;N$@
M9&%T82XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B
M35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86MA
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA:V5D;VYI92P@8OUV
M86SA(%)E<'5B;&EK82!*=6=O<VSA=FEE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-K87(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VEE
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL
M(@IM<V=S='(@(E!ON71A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")!9&UI;FES='+A=&]R
M('!ON71Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@
M(E9Y='9O^&ET(&]D7VMA>BXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L
M87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L
M87ES:6$B"FUS9W-T<B`B36%L86IS:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I=GDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*
M(E!R;R!U;6^^;NQN[2!O=FSA9.%N[2!K871E9V]R:>T@:F4@>F%P;W3X96+M
M(&]Z;F'H:70@<&]L;[YK>2!B87)V86UI+"!K=&5RZ2`B"B)J<V]U('#X:?AA
M>F5N>2!K('3L;71O(&MA=&5G;W)I[6TN(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*
M;7-G<W1R(")-87!A($UA<#(T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G
M<W1R(")-87!A($UA<%%U97-T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS
M9VED(")-87)C:"(*;7-G<W1R(")"^&5Z96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G
M:6XB"FUS9W-T<B`B3VMR86HB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(D]Z;F'H:70@>FYAZ&MO=2!0<F]H;.ED;G5T;R].
M97!R;VALZ61N=71O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG
M+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(D]Z;F'H:70@:FEN_6UI
M('IN8>AK86UI("AJ86MO($3Y;&6^:73I+T]D<&]V['IE;NDI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<KEA
M;'-KZ2!/<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E
M(@IM<V=S='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-H
M;V1U:NUC[2!S92!P;VQE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A
M;FEA(@IM<V=S='(@(DUA=7)E=.%N:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:6-I=7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA
M>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%X:6UA;&[M('!O=F]L96[]
M(&MR961I="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D
M960N(@IM<V=S='(@(D)Y;&$@</AE:W)OZ&5N82!M87AI;6%L;NT@9.EL:V$@
M>G!RX79Y+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B3F5J=GFYN>T@=&5P
M;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B`B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B
M"FUS9W-T<B`B3F5J=GFYN>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D
M:6XZ("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM
M=6T@;&5N9W1H(@IM<V=S='(@(DUA>&EMX6QN[2!DZ6QK82(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB
M"FUS9W-T<B`B2W;L=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T
M92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I8^UN82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E
M<G,B"FUS9W-T<B`BR&QE;F]VZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B3?-D>2!P<F\@;65N
M=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")3<&]J:70@
M8G7R:WDB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("):<'+A=F$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I
M9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(EIP<N%V82!B>6QA(&]V[/AE;F$@=B!P;_CA9&MU+"!A;&4@
M;F5L>F4@;W;L^&ET('!O9'!I<V]V_2!C97)T:69I:^%T+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I
M9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("):<'+A=F$@<')O<&%D;&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@
M(E1Y<"!Z<'+A=GDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@
M(DUE=&%R(%=E871H97(B"FUS9W-T<B`B4&_H87/M(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B0FQO:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)";&]K(&\@<&_H87/M
M(&YE;NT@9&]S='5P;OTN(%!O9')O8FYO<W1I(&)Y;'D@>F%Z;F%M96[A;GD@
M<')O('-Y<W3I;6]VZ6AO("(*(F%D;6EN:7-T<N%T;W)A(&1O(&QO9W4N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M(")-971O9&$B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q
M(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*
M;7-G<W1R(")-971O9&$@)R5S)R!N96[M(&1E9FEN;W;A;F$B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T
M<FEC:_TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-
M97AI:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;V[I<VEE+"!&961E<F%C92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(E5P<F]S=/AE9"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-
M:6UE(%1Y<&4B"FUS9W-T<B`B5'EP($UI;64B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(DYE:FYIOKGM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`R-"!H;V1I
M;CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DYE:FYIOKGM('1E<&QO=&$@
M>F$@<&]S;&5D;NUC:"`V(&AO9&EN.B`B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"FUS9VED(")-:7)R;W(B
M"FUS9W-T<B`B6G)C861L;W;L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(E+Y>F[I(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P
M"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM
M<V=S='(@(E!R;V=R86UO=OT@8F%L[6L@2%144%]297%U97-T(&-H>6+M('8@
M4$5!4BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B
M"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B(@HB0VAY8NQJ[6/M(&MO;F9I9W5R86-E+B!0;VMU9"!S
M:2!P^&5J971E('!O=;[M=F%T('1U=&\@87!L:6MA8VDL(&UU<^UT92`B"B)V
M>6=E;F5R;W9A="!K;VYF:6=U<F'H;NT@<V]U8F]R+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B
M36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")#:'EB[&KM8^T@240@>G!R
MX79Y("AI9&5N=&EF:6MAZ&[M(.CM<VQO*2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")0;[YA
M9&]V86[]('!R;V=R86UO=OT@8F%L[6L@36%I;"!C:'EB[2!V(%!%05(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D-H>6+L
M:NUC[2!)1"!P<F\@<F5L86-I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(E!O(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@
M36%I;"(*;7-G<W1R(")-;V)I;&[M('!ON71A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM
M<V=S='(@(DWM<F[](@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*
M;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&%T=6T@<&]S;&5D;NT@
M>FWL;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B6FWL
M\FET(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD
MX79I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO
M;F%K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B
M36]N9V]L<VMO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B3>QS[6,@82!R;VLB"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS
M9VED(")-;VYT:&QY(@IM<V=S='(@(DWL<^WH;NPB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N<V5R870B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@
M(DUO;VX@4&AA<V5S(@IM<V=S='(@(D;A>F4@3>QS[6-E(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F
M;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R
M;VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")0^&5VX;YN["!J87-N
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T
M"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(E#X97;AOF[L(&]B;&'H
M;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(E#X97;AOF[L('-L=6YE
MZ&YO(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y
M"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B4&]S=6YO=70@9&]L^2(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B
M36]V92!,969T(@IM<V=S='(@(E!O<W5N;W5T(&1O;&5V82(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2
M:6=H="(*;7-G<W1R(")0;W-U;F]U="!D;W!R879A(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM
M<V=S='(@(E!O<W5N;W5T(&YA:&]R=2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G
M<W1R(")0;W-U;F]U="!D;VSY(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(E!O
M<W5N;W5T(&YA:&]R=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U
M92(*;7-G<W1R(")-;W-A;6)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*
M;7-G<W1R(")6[6-E+?IR;W;R;W;I(')O;&5T;W;I('-E>FYA;7DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I
M9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*
M;7-G<W1R(")6[6-E;N%S;V)NX2!S96QE:V-E(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-
M^6H@^NAE="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ
M>0IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")68;EE
M(&EN9F]R;6%C92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*
M;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-^6H@<&]R=.%L(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA
M>6]U="(*;7-G<W1R(")-;VIE(')O>FQOOF5N[2!P;W)TX6QU(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I
M9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY%+"!.15-/54A,05/-
M32(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE
M(@IM<V=S='(@(DIMZ6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA
M(@IM<V=S='(@(DYA;6EB:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U
M(@IM<V=S='(@(DYA=7)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*
M;7-G<W1R(").97#A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N
M9',B"FUS9W-T<B`B3FEZ;WIE;>TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T
M:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B3FEZ;WIE;7-KZ2!!;G1I;'DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I
M9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0F%S92!5
M4DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM
M<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R(").971S8V%P92!#02!P;VQI8WD@55),(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C
M87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E(%)E;F5W86P@55),
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G
M:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E
M(%)E=F]C871I;VX@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*
M;7-G<W1R(")*;>EN;R!.971S8V%P92!34TP@<V5R=F5R=2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(E!O>F[A;6MA(&L@8V5R
M=&EF:6OA='4@3F5T<V-A<'4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP
M92(*;7-G<W1R(")4>7`@8V5R=&EF:6OA='4@3F5T<V-A<'4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S
M='(@(E/MNR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI:V1Y(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO=N$@
M2V%L961O;FEE(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").
M;W;A(&MA=&5G;W)I92(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(E9Y='9O^&ET('IP<N%V
M=2`H)7,I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M
M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@
M36]O;B(*;7-G<W1R(")-['/M8R!V('!R=F[M(.AT=G)T:6[L(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S
M97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F]VZ2!UOFEV871E;'-KZ2!J
M;>EN;R`H;F5P;W9I;F[I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE
M86QA;F0B"FUS9W-T<B`B3F]V_2!:Z6QA;F0B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R
M9"(*;7-G<W1R(")(97-L;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I
M;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R
M9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DAE<VQA('-E(&UU<^T@<VAO9&]V
M870N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").;W;I
M(&]K;F\@*%]P<N%Z9&[I*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@Y"FUS9VED(").97=S(@IM<V=S='(@(DYO=FEN:WDB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O
M=7!S(@IM<V=S='(@(DYE=W-G<F]U<',B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(")$86RY[2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X
M="`T(%!H87-E<R(*;7-G<W1R(")$86RY[2!FX7IE(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")$86RY
M[2!M;[YN;W-T:2(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S
M"B,L(&9U>GIY"FUS9VED(").97AT/B(*;7-G<W1R(")$86RY[2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=U82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEGZ7)I92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI
M9VAT(@IM<V=S='(@(DYO8R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*
M;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B3F4B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL
M86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F
M;W(N(@IM<V=S='(@(JYA9&[A(&MO;F9I9W5R8>AN[2!D871A(&YE:G-O=2!D
M;W-T=7!NX2!P<F\@>F]B<F%Z96[M(')O>F3M;/DN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S
M='(@(DYE;NT@9&]S='5P;N$@ON%D;N$@<W1R871E9VEE('!R;R!T=F]R8G4@
M25-/(&]B<F%Z^2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*
M;7-G<W1R(")"97H@9.%V:V]VZ6AO('9Z;W)U+B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N(@IM<V=S='(@(DYA('!OOF%D;W9A;ND@<&]Z:6-I
M(&YE97AI<W1U:F4@ON%D;OT@8FQO:R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED
M960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE8GEL;R!P
M;W-K>71N=71O(+[A9&[I(&IMZ6YO('!R;R!K86QE;F3A^"!P^&D@;W;L^&]V
MX6[M('!O;6]C[2!-0T%,+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T
M"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(D)E>B!Z;>QN>2XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI
M;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B3F5L>F4@</AI9&%T(+[A9&[A('!O9"UP<N%V82!K('3L;71O('!RX7;Y
M;2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL
M+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").96)Y
M;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(DYE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R
M8>AN[2!I;F9O<FUA8V4@<')O($944"!61E,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").96)Y
M;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R!3
M44P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW
M,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(DYE8GEL>2!U=F5D96YY
M(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O(%-13"U&:6QE(%9&
M4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(").96WA
M=&4@ON%D;OT@:W)E9&ET+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"XB"FUS9W-T<B`B3F5B>6P@<&]S:WET;G5T(+[A9&[](&/M;"XB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@
M(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`BKN%D;OT@<V]U8F]R(&YE8GEL
M('#X96YE<V5N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED
M(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B3F5B>6QY(&YA;&5Z96YY(+[A
M9&[I(&EK;VYY+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@
M(DYE8GEL;R!V>6)RX6YO(+[A9&[I(&WM<W1O+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(").96)Y;&\@=GEB<N%N;R"^X61NZ2!M
M[7-T;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T
M<B`B3F5B>6QY('!O<VMY=&YU='D@ON%D;ND@>G!RX79Y+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED
M(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3F5B>6QO('5V961E;F\@
MON%D;ND@:FWI;F\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N
M(@IM<V=S='(@(DYE8GEL;R!U=F5D96YO(+[A9&[I(.CM<VQO+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(D)E>B!N97-L=;EN_6-H(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE8GEL
M;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!(5%10+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@
M<&]M;V/M($E-05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y;&\@<&]S:WET;G5T;R!H
M97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@2V5R8F5R;W,N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H
M+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@
M<')O(&]V[/AE;NT@</AI:&SAN65N[2!S92!D;R!S>7-TZ6UU+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DYE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O
M;6]C[2!005-35T0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P
M<F\@;W;L^&5N[2!P;VUO8^T@4TU"+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@
M3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I
M<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS
M9W-T<B`B(@HB3F5B>6QA('!O<VMY=&YU=&$@8V5S=&$@:R!B:6[A<F[M;74@
M<V]U8F]R=2!/<&5N4U-,+B!":6[A<F[M('-O=6)O<B!/<&5N4U-,("(*(FIE
M('IA<&]T^&5B[2!P<F\@<'+A8VD@<R!02T-3(#$R(&1A='DN(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N
M9&EN9R!S:6=N=7!S+B(*;7-G<W1R("*NX61NZ2!N979Y^.UZ96[I(+[A9&]S
M=&D@;R!P^&EH;.&Y96[M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW
M-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB
M"FUS9W-T<B`B3F5N[2!N87-T879E;F\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE
M<R(*;7-G<W1R(")"97H@<')A=FED96PB"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(DYO('-E<&%R871O<B!S
M<&5C:69I960N(@IM<V=S='(@(DYE8GEL;R!U=F5D96YO(+[A9&[I(.CM<VQO
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(D)E>B!O:W)A:ODB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PHC+"!F=7IZ>0IM
M<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(D)E>B!O:W)A:ODB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP
M;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@
M(J[A9&[]('H@9&_H87-N_6-H(&%D<F5SX?CY(&YE;NT@9&]S='5P;OT@<')O
M(&-A8VAE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@
M<V5N="XB"FUS9W-T<B`B3F5B>6QO(&]D97-LX6YO(+[A9&[I('6^:79A=&5L
M<VOI(&IMZ6YO(&$O;F5B;R!H97-L;RXB"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960B"FUS9W-T<B`B3F5B>6QA(&YA=G+A8V5N82"^X61NX2!P;&%T;N$@
M6$U,(&1A=&$N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("*NX61NZ2!H;V1N
M;W1Y(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E8@;W)I9VENX6QN[2!K
M;VYF:6=U<F%C:2!N96)Y;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V=&4@:V]N
M9FEG=7)A8VDN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5F4@5F&Y[2!K;VYF
M:6=U<F%C:2!N96)Y;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V=&4@:V]N9FEG
M=7)A8VDN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M,PIM<V=I9"`B3F]N92(*;7-G<W1R("*NX61N_2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S
M92!I;7!L:6-I="DB"FUS9W-T<B`BKN%D;OT@*'!O=;YI:G1E(&EM<&QI8VET
M;NTI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(E-E=F5R<VO]("A)4T\M.#@U.2TQ
M,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S
M='(@(DYO<F9O;&MS:^D@;W-T<F]V>2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B4V5V97)N[2!P;VQO:V]U;&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R
M(")3979E<F[M($UA<FGA;G-KZ2!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").;W)W87DB"FUS9W-T<B`B3F]R<VMO(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G
M<W1R(").96[M('!O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B3F5N[2!P^&5D
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED(").
M;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B3F5N[2!A9')E<^'X96TB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R(").96[M(&EM<&QE;65N=&]VX6YO+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`B3F5N[2!N87-T879E;F\B"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B3F5N[2!P;V1P;W)O=N%N;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO
M=&5S(@IM<V=S='(@(E!O>F[A;6MA(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O
M:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RXB"FUS9W-T<B`B3FEC(&L@<')O:&SI9&YU=.TL(&+LOG1E('IP['0N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G
M:60@(DYO=F5M8F5R(@IM<V=S='(@(DQI<W1O<&%D(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(LCM
M<VQO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B
M3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B4&_H970@>FYA:_DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM
M<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B4&_H970@<VQO=7!C
M^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(")0;^AE="#XX61K
M^2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").96)Y;&$@>F%D
MX6YA(.CM<VQA('!R;R!A:W1U86QI>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA
M;74N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G
M<W1R(")/8FIE:W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B5';Y<F-E(&]B:F5K
M=/DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/
M8W1A;"(*;7-G<W1R(")/<VUIZ&MO=OTB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R
M("+8[6IE;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B
M3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=')O=F%T(&YE<VQUN6[I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E
M(@IM<V=S='(@(DMA;F-E;.'X(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B
M92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM
M<V=S='(@(DAE<VQO(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E
M8W0N(@IM<V=S='(@(DYE<W!RX79NZ2!H97-L;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3VUA;B(*;7-G<W1R(")/;>%N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E-D[6QE;ND@
M<VQOOFMY(&IS;W4@<&]S:WET;W;A;GD@<&]U>F4@24U!4"!S97)V97)Y+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B4&]U>F4@;F5S;'6Y;NDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B2F4@<&]V;VQE;F$@<&]U>F4@:F5D;F$@92UM86EL
M;W;A(&%D<F5S82XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*
M;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I
M;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(E!O=7IE('9L87-T;NUK(&YE
M8F\@<WES=.EM;W;](&%D;6EN:7-T<N%T;W(@;?F^92!M[&YI="!P<N%V82!P
M<F\@<V3M;&5N_2`B"B)O8FIE:W0N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]T
M97;X[70@=B!N;W;I;2!O:V[L+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G
M<W1R(")#:'EB82!/<&5N4U-,.B!.96QZ92!Z[7-K870@9&%T82!Z('!O9&5P
M<V%NZ2#HX7-T:2!3+TU)344N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]T97;X[70@=&5N=&\@
M;V1K87H@=B!N;W;I;2!O:V[L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D]P97)AZ&[M
M('-Y<W3I;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*
M;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B36^^;F]S=&DB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B36^^
M;F]S=&D@<')O("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E-E
M^&%Z96[]('-E>FYA;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI
M>F%C92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X
M"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(D]R9V%N:7IA
MZ&[M(&IE9&YO=&MA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S
M,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FEZ;W;A;NTB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B3W)I9VENX6QN[2!V>F]R('!R
M;R"^X61O<W0B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S
M='(@(D]R:6=I;N%L;NT@=GIO<B!V("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS
M9VED(")/=&AE<B(*;7-G<W1R(")/<W1A=&[M(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T
M<B`B3W-T871N[2!I;F9O<FUA8V4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")5
MOFEV871E;'-KX2!P<N%V82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M
M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(D]V[/AE;NT@<&]M;V/M(%!!32!N96[M(&1O<W1U
M<&[I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@
M(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")01U`@9&EG:73A;&[M
M('!O9'!I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@N6EF
M<F]V86[A(&1A=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")69?AE:F[]
M(%!'4"!K;.WH(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R
M(")$871A('!O9&5P<V%NX2^Y:69R;W9A;N$@<&]M;V/M(%!'4"(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B
M4$A0(&OS9"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0
M(%-H96QL(@IM<V=S='(@(E!(4"!K;VYZ;VQA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A
M:6XB"FUS9W-T<B`B3V1P;VQE9&[M(&QE:&O](&3IN;LB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO
M=V5R<R(*;7-G<W1R(")/9'!O;&5D;NT@</AE:.'R:WDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO
M=R(*;7-G<W1R(")/9'!O;&5D;NT@<V[LOF5N[2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B3V1P;VQE9&[M('-N[&AO=ND@</AE:.'R:WDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0HC+"!F
M=7IZ>0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(D]D<&]L961N[2!S;NR^96[M
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*
M;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(D]D<&]L961N[2!B;W7X:WDB
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E
M>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4%](4"!K;VYZ;VQA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")/9'-T=7!Y(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")0X6MI<W3A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/
M8V-U<&EE9"(*;7-G<W1R(")086QE<W1I;G-KZ2!T97)I=&]R:75M+"!O:W5P
M;W9A;NDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R(")0
M86YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B
M"FUS9W-T<B`B4&%P=6$@3F]VX2!'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@
M0VQO=61Y(@IM<V=S='(@(DWM<W1Y('IA=&&^96YO(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O
M<F0B"FUS9W-T<B`B2&5S;&\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$S,C(*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(").
M97-P<N%V;ND@:&5S;&\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU
M<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")0<F\@;W;L^&5N[2!P;VUO8^T@
M4D%$54E3(&IE(&YU=&YO('IA9&%T(&AE<VQO+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N(@IM<V=S='(@(DAE<VQO(',@<&]T=G)Z96[M;2(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM
M<V=S='(@(DAE<VQO.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DAE<VQO.B`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S
M-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED
M(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B2&5S;&$@<V4@;75S
M[2!S:&]D;W9A="XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM
M<V=I9"`B4&%S=&4B"FUS9W-T<B`B5FQOOFET(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O
M;2!C;&EP8F]A<F0B"FUS9W-T<B`B5FQOOFET('IE('-C:'+A;FMY(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R(")#97-T82(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@
M(J[A9&]S=&D@;R!P^&EH;.&Y96[M.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(DQI9.DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B
M4&5R8V5N="(*;7-G<W1R(")0<F]C96YT(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")0<F]VZ7-T(&]P97)A8V4@
M^F1ROF)Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G
M<W1R(")0<F]VZ7-T(&]P97)A8V4@^F1ROF)Y('#X:2!P^&EH;.&Y96[M(&1O
M('-Y<W3I;74_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4'+A=F$B"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B
M4'+A=F\@)R5S)R!N96)Y;&\@<VUA>N%N;RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`B4'+A=F$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!RX79A
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R8>AN[2!P<N%V82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF
M;W)M871I;VXB"FUS9W-T<B`B3W-O8F[M(&EN9F]R;6%C92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(D1O;>%C[2!Z
M=NWX871A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G
M<W1R(")&:6QI<.UN>2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T
M;W,B"FUS9W-T<B`B1F]T;V=R869I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*
M;7-G<W1R(")0:7AE;/DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*
M;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B1G+A>F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED
M(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B4')O<^UM
M(&ML:6MN['1E(&YA(&[L:F%K;W4@8G7R:W4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#HB"FUS9W-T<B`B4')O<^UM('!O='9R[W1E+""^92!S:2!P^&5J971E
M(&]D<W1R86YI="!T96YT;R!P<G9E:SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N
M="XB"FUS9W-T<B`B4')O<^UM('!O='9R[W1E+""^92!S:2!P^&5J971E(&]D
M<W1R86YI="!T96YT;R!P<G9E:RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+B(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!M['/M8R!A(')O:RXB"@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R
M>3HB"FUS9W-T<B`B4')O<^UM('IA9&5J=&4@;N%Z978@;F]VZ2!K871E9V]R
M:64Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B4')O
M<^UM('IA9&5J=&4@<W!RX79N;W4@25`@861R97-U+BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO
M;G1H+B(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!S<'+A=F[](&1A='5M(&$@
M>FMO;G1R;VQU:G1E('!OZ&5T(&1N[2!V(&WL<^UC:2XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!T:6UE+B(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!S<'+A=F[](.AA
M<RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED
M(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM
M<V=S='(@(E!R;W/M;2!U=F7O=&4@<VAR;G5T[2!68;EE:&\@<')O8FSI;74N
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")0<F]S[6T@>F%D96IT
M92!68;EE('6^:79A=&5L<VOI(&IMZ6YO(&$@:&5S;&\B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(B(*(E!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*
M(E!R;W/M;2!P^&7H=.QT92!S:2!NX7-L961U:NUC[2!T97AT+B!-55/-5$4@
M<V]U:&QA<VET(',@<&]D;>UN:V%M:2!P;W6^[7;A;NT@(@HB<WES=.EM=2XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.B(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!N;W;](&[A>F5V(&MA=&5G;W)I
M93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQS
M:V\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET
M:6-S(@IM<V=S='(@(E!O;&ET:6MA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B2&QA<V]VX6[M(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G
M86QS:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4B"FUS9W-T<B`B56WM<W3L;NT@=&]H;W1O(&]B<N%Z:W4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")5;>US=.QN
M[2!T86)U;&MY(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*2(*;7-G<W1R("):87-L870@9&\@=.ET;R!S;&^^:WD@
M*&YE;NT@<&]S:WET;G5T;R!)34%096TI(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B
M"FUS9W-T<B`B4W+AOFMY('IA('!O<VQE9&[M*&-H*2`E<R!H;V1I;BAU*3H@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B4')E9G-?;&1A<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM
M<&]N82!,1$%0+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N
M+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N
M.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('-E:V-E+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*
M;7-G<W1R(")"87)O;65T<FEC:_T@=&QA:R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G
M<W1R(")"87)O;65T<FEC:_T@=&QA:R!N82#Z<F]V;FD@;6_X93H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U
M<F4Z("(*;7-G<W1R(")"87)O;65T<FEC:_T@=&QA:SHB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4')E=FEE=R(*;7-G<W1R(").X6AL960B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G
M:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(").X6AL960@;V)RX7IK=2!V(&YO=NEM(&]K;NPB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0
M^&5D8VAO>NT@;6^^;F]S=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G
M<W1R(")4:7-K;F]U="!D;VMU;65N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B
M4')I=N%T;NT@:VSMZ"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4')O8FSI;2(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C
M<FEP=&EO;B(*;7-G<W1R(")0;W!I<R!P<F]B;.EM=2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@
M(E!R;VIE:W1Y(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E!R
M;VUP="!T97AT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(E9E^&5J;OT@:VSMZ"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;75S('!R
M;R!V9?AE:F[](&ML[>@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM
M<V=S='(@(E9E^&5J;OT@:VSMZ"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5F7X96IN_2]P
M<FEVX71N[2!K;.WH;W;]('#A<B!N96)Y;"#Z<W#LN6[L('9Y='9O^&5N+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!O
M<G1O<FEK;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@
M(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R
M>2(*;7-G<W1R(")6>6AL963A;NTB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMA=&%R(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T
M<B`B4E-!('9E^&5J;OT@:VSMZ"`H)60@8FET^2DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS
M9W-T<B`B4W#X8;YE;ND@=&QAZ.UT:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")$
MZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B0G)Z:_T@9.FYNR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")286EN($QA=&4B"FUS9W-T<B`B4&]Z9&[M(&3IN;LB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3
M:&]W97(B"FUS9W-T<B`B1&6YNV]VZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N
M9"!3;F]W(@IM<V=S='(@(D3IN;L@<V4@<V[L:&5M(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@
M4VYO=R(*;7-G<W1R(")$Z;F[(&&^('-N[6@B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B3N%H
M;V1N["!V>6)R86[I(+ET['-T[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B4&]M['(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A
M9"(*;7-G<W1R("+(=&5C[2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(E#X9>AT96[I('IP<N%V>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R
M(")/<')A=F1U('-M87IA="`E<S\@5&%T;R!O<&5R86-E(&IE(&YE=G)A=&[A
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U
M<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R("(B"B)/<')A=F1U('-M87IA="!UOFEV871E;'-KX2!D871A('!R;R!U
MOFEV871E;&4@)7,_(%1A=&\@;W!E<F%C92!J92!N979R871NX2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED
M(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")/<&%K;W9A="!P
M;W-L961N[2!A:V-I(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F
M<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D]B;F]V:70@
M9'EN86UI8VOI('!R=FMY(&UE;G4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B
M3V)N;W9A('IO8G)A>F5N[2!P;W)TX6QU.B`B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*
M;7-G<W1R(")296=E>"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(E!R;VAL
M[;YEZ"!V>G1A:/DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS
M9VED(")296QO860B"FUS9W-T<B`BR'1E8^TB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")(;V1N;W1Y(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E
M<G9E<G,B"FUS9W-T<B`B5GIDX6QE;ND@<V5R=F5R>2XB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")6>F3A;&5N
MX2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@
M(D]D<W1R86YI="(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ
M,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D]D<W1R86YI="!B;&]K
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")/9'-T<F%N:70@<VQO
M=7!E8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D]D<W1R
M86YI="!F;W)MX71O=N%N[2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")/9'-T<F%N:70@
M<.%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M
M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN(@IM<V=S='(@(D]D<W1R871I="!U;&^^96[]('-K<FEP="!Z(&1O
MZ&%S;NEH;R!A9')E<^'X92!N82!S97)V97)U+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B
M4F5M;W9E('1H92(*;7-G<W1R(")/9'-T<F%N:70B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@
M(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B
M3V1S=')A;FET('1U=&\@Z.%S="!D;VMU;65N='4B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*
M;7-G<W1R(")/9'-T<F%N:70@=;YI=F%T96QE(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M;6]V92!U<V5R.B`E<R(*;7-G<W1R(")/9'-T<F%N:70@=;YI=F%T96QE.B`E
M<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED
M(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z("(*;7-G<W1R(").96QZ92!O9'!O=NQD['0@;F$@<&^^861A=F5K
M+B!#:'EB;W;I(&ALX;EE;NTZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B4/AE;F5S96[]('-O=6)O
M<B!N96QZ92!U;&^^:70N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E!OOF%D;W9A;ND@
M)R5S)R!N96)Y;&\@=79E9&5N;R!V(&MO;F9I9W5R86-I('!R;R`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B4&^^861O=F%NZ2`G)7,G(&YE8GEL;R!U=F5D96YO('8@:V]N
M9FEG=7)A8VD@<')O(%9&4RXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(E!OOF%D;W9A;ND@)R5S)R!N96)Y;&\@=79E9&5N;R!V(&MO;F9I9W5R86-I
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM
M<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B4&^^861O=F%NZ2!P;VQE
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R
M,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S
M='(@(E;]8VAO>NT@;F%S=&%V96[M(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E;]
M8VAO>NT@;F%S=&%V96[M(&AE<VQA(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T
M<B`B5OUC:&]Z[2!N87-T879E;NT@5F&Y96AO(&AE<VQA(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T
M(%%U97)Y(@IM<V=S='(@(E!O<VQE9&[M(.AT=G)T:6YA(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B5OUS;&5D
M:WDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS
M(@IM<V=S='(@(D[A=G)A="!D;R!M;[YN;W-T[2(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R(")6_6-H;WKM(&YA<W1A=F5N[2!H97-L82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO
M;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B4/AE<&YO=70@:V]N9FEG=7)A8VDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,R"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B
M"FUS9W-T<B`B36^^;F]S=&D@4FEC:"!497AT(&5D:71O<G4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M2.%D86YK>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B1&]P<F%V82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT
M(&AE861E<B(*;7-G<W1R(")(;&%V:>AK82!N87!R879O(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L=65S(@IM
M<V=S='(@(DAO9&YO='D@;F%P<F%V;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E9L87-T;F]S=&D@^.%?9&MU(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I
M9"`B4F]L92(*;7-G<W1R("+:;&]H82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E)O;6%N:6$B"FUS9W-T<B`B4G5M=6YS:V\B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P
M(@IM<V=S='(@(D]T;^AI="!O(#$X,+`B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*
M;7-G<W1R(")/=&_H:70@9&]L979A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM
M<V=S='(@(D]T;^AI="!D;W!R879A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E
M<G1I97,B"FUS9W-T<B`B5FQA<W1N;W-T:2#XX61K=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@
M(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@^.%D:W4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM
M<V=I9"`B4F]W<SHB"FUS9W-T<B`BV.%D:WDZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L
M97,B"FUS9W-T<B`B4')A=FED;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@
M(E!R879I9&QA('-E('5P;&%T;NT@;65Z:2!VN65M:2#XX61K>2!A('-L;W5P
M8VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>2(*;7-G<W1R(")0<F%V:61L82!S92!U<&QA=&[M('!O=7IE
M(&UE>FD@<VQO=7!C:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(E!R879I9&QA('-E('5P;&%T
M;NT@<&]U>F4@;65Z:2#XX61K>2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C`*;7-G:60@(E)U;B(*;7-G<W1R(")0<F]VZ7-T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<VOA(&9E
M9&5R86-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@
M(E)W86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS
M9W-T<B`B4R]-24U%(+EI9G)O=F%N_2!P;V1P:7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E(@IM<V=S='(@(E,O34E-12"Y:69R;W9A;N$@>G!RX79A
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")/=NSX96[M('!O;6]C[2!305-,(&YE;NT@9&]S='5P;NDN(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`IM<V=I9"`B4TU3($UE<W-A9VEN
M9R(*;7-G<W1R(")335,@>G!RX79Y(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,(&MO;GIO;&$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R(")3
M4T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@
M(MI34,Q#2"(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L
M;"(*;7-G<W1R(")37U%,(&MO;GIO;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")3
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R
M(")3=F%TX2!(96QE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI
M='1S(&%N9"!.979I<R(*;7-G<W1R(")3=F%T_2!+:71T<R!A($YE=FES(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN
M="!,=6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A
M;F0@36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'
M<F5N861I;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@
M(E-T96IN_2!RX6T@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A
M;6]A(@IM<V=S='(@(E-A;6]A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N
M($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE
M(&%N9"!0<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")6;&%S
M=&[M:R!S871E;&ET=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R
M86)I82(*;7-G<W1R(")3875D<VOA($%RX6)I92(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R(")5;&^^
M:70B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R
M(")5;&^^:70@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E5L;[YI
M="`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A
M=F4@3W!T:6]N<R(*;7-G<W1R(")5;&^^96[M(&UOOFYO<W3M(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V
M97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)5;&^^
M:70@=GET=F_X96[](&MO;F9I9W5R8>AN[2!02%`@<VMR:7!T(&1O(&1OZ&%S
M;NEH;R!A9')E<^'X92!N82!S97)V97)U+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(DMO;F9I9W5R86-E("5S('5L;[YE;F$N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B!<(B5S7"(N(@IM<V=S='(@(DMO;F9I9W5R8>AN[2!S:W)I<'0@<')O(&%K
M='5A;&EZ86-I(&)Y;"!U;&^^96X@9&\Z("<E<R<N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@
M(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")/:F5D:6[L;.D@8F]U^&MY
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E
M(@IM<V=S='(@(E;L9&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(E9Y:&QE9&%T(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T
M<B`B5GEH;&5DX79A8^T@;N%S=')O:F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5GEB
M<F%T('-O=6)O<GDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#@T"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E9Y
M8G)A="!D871U;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX
M"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5GEB<F%T
M('-K=7!I;G4L(&MT97+A(&)U9&4@</AI9.%N82(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*
M;7-G<W1R(")6>6)R870@;F]VZ6AO('9L87-T;NUK82(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R
M(@IM<V=S='(@(E9Y8G)A="!S97)V97(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS
M9W-T<B`B5GEB<F%T('6^:79A=&5L92P@:W1E<OT@8G5D92!P^&EDX6XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E9Y8G)A="!S;W5B
M;W)Y(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PIM<V=I9"`B
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E9Y8G)A="!V
MN65C:&YY(.CA<W1I(&1A='5M=2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T
M(@IM<V=S='(@(E9Y8G)A="!O8FIE:W0B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@;F]N92(*;7-G<W1R(")6>6)R870@;F]VZ6AO('9L87-T;NUK82(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T
M97AT(&%R96$N(@IM<V=S='(@(B(*(E9Y8F5R=&4@<&]T^&5B;ND@>FYA:WD@
M>B!N[;YE('5V961E;OUC:"!B;WCY+B!0;W3I(&IE(&WYOF5T92!K;W#M<F]V
M870@82`B"B)V;&^^:70@>B!T97AT;W;I(&]B;&%S=&DN(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(E9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R
M;R!D871U;3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5GEB97)T92!F
M;W)MX70@9&%T=6UU.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")6>6)E<G1E(&ED96YT:71U+"!K=&5R
M;W4@<VD@</AE:F5T92!Z;>QN:70Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM
M<V=S='(@(E9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R#H87,Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!F;W)M870Z(@IM<V=S='(@(E9Y8F5R=&4@9F]R;>%T(.AA<W4Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E9Y8F5R=&4@9';L(&]D
M<&]V[61A:NUC[2!P;VQE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B
M5GEB97)T92!B87)E=F[](&UO=&EV+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93HB"FUS9W-T<B`B5GEB97)T92!6X6UI('!R969E<F]V86[](&IA>GEK.B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")3
M96YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E!O<VQA="!Z<'+A=G4@;R!P
M<F]B;.EM=2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R(")0;W-L870@4TU3
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE
M9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O
M<CH@(@IM<V=S='(@(E-E;G-O<CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@
M(EKA^.TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-R8G-K
M;R!A(,AE<F[A($AO<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")3Z7)I
M;W;I(.CM<VQO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,0HC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B0FQO:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]
M+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B
M4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")!9&UI;FES=')AZ&[M('!RX79A(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DE$('-E
M:V-E('IA;FEK;&\N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS
M9VED(")397-S:6]N<R(*;7-G<W1R(")?4'+A=F$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B3F%S=&%V
M:70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O
M<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF
M('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B3F%S=&%V:70@;6^^;F]S
M=&D@<')O('!O=F]L96[M(')E<V5T=2!H97-L82P@<&]K=60@:&\@>F%P;VUE
M;F5T92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B3F%S=&%V:70@=GIDX6QE;ND@
M<V5R=F5R>2!T86LL(+YE(&)U9&]U('#X[7-T=7!NZ2!Z('!O<G3A;'4N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N
M(@IM<V=S='(@(DYA<W1A=F5N[2!6X6UI('!R969E<F]V86[I:&\@:F%Z>6MA
M+"#H87-O=NEH;R!PX7-M82!A('1Y<'4@9&%T=6UU+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(DYA<W1A
M=F5N[2!P;^CA=&7H;NT@87!L:6MA8V4L(&)A<F5V;NEH;R!M;W1I=G4L(&]B
M;F]V;W;A;NT@<W1RX6YE:R!A(&1A;+GM8V@@(@HB;6^^;F]S=.T@>F]B<F%Z
M96[M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E
M='5P(@IM<V=S='(@(DYA<W1A=F5N[2(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE(@IM<V=S='(@(DYA<W1A=F]V86/M(&MO;F9I9W5R8>AN
M[2!S:W)I<'1Y('!R;R!A:W1U86QI>F%C:2!J<V]U(&1O<W1U<&[I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS
M9W-T<B`B3NQK=&5RX2!M[7-T82!L>F4@;F%S=&%V:70@<R!T[6UT;R!P87)A
M;65T<F5M.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM
M<V=S='(@(E-E>6-H96QL97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(").86MU<&]VX6[M(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H
M;W)T(%-U;6UA<GDB"FUS9W-T<B`B2W+A=&OI('-H<FYU=.TB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B3>QL>2!B
M>2!B_70@</CM<W1U<&]VZ2!K;.WH92!D969I;F]VX6YY('!R;R!V['2Y:6YU
M(&]D:V%Z^3\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("):;V)R87II="(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC
M97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE
M<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B6F]B<F%Z:70@<F]Z
M9.UL>2!M97II('-O=>AA<VYO=2!A('#X961C:&]Z[2!K;VYF:6=U<F%C[2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(EIO8G)A
M>FET(.AA<R!P;W-L961N[6AO('#X:6ALX;EE;NT@9&\@<WES=.EM=3\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(EIO8G)A>FET(&UOOFYO
M<W0@=61ROF5N[2!O<FEG:6[A;'4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("):;V)R87II
M="!S8NQR8>@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED
M(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(EIO
M8G)A>FET(&UE;G4@;W!E<F'H;NT@;&FY='4@<')O('1A8G5L:WD_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("):;V)R
M87II="`E<R!M96YU(&YA;&5V;S\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B6F]B<F%Z
M:70@9&EA;&]G('!R;R!V;&%S=&YO<W1I(&)U;NQK('8@=&%B=6QKX6-H(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("):;V)R87II="!D:6%L;V<@=FQA<W1N;W-T[2!T86)U;&5K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B6F]B<F%Z:70@9&EA;&]G('9L87-T;F]S=.T@
M^.%D96L@=&%B=6QE:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@
M<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B6F]B<F%Z:70@9&EA;&]G('9L
M87-T;F]S=.T@;V)RX7IK^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(EIO8G)A>FET('#X
M96YO<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(E#X96CA\FMY(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B0G)Z:^D@</AE:.'R:WDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO
M=V5R<R!,871E(@IM<V=S='(@(E!O>F1N[2!P^&5HX?)K>2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W
M97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")0^&5HX?)K>2!V(&]K;VSM
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS
M9VED(")3:')I;FLB"FUS9W-T<B`B6FUE;KEI="(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B6FUE;KEI="!N96)O('!O<W5N;W5T(&1O('-O=7-E9&[M
M:&\@8FQO:W4H^2DL('H@8V5S='D@<')V;NUM=2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3
M:6=N('5P(@IM<V=S='(@(E)E9VES=')O=F%T('-E(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*
M;7-G<W1R(")0;V1P:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R
M(")!;&=O<FET;75S('!R;R!P;V1P:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P=7(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(E9E;&EK
M;W-T(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B5GEN96-H
M870@^F1ROF)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS
M9W-T<B`B4VQO=F5N<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B4VQO=FEN<VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B4V[L
MOF5N[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")3;NQH;W;A('#X96CA
M\FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")3;NQH;W;I('#X96CA
M\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")286YN[2!S
M;NQH;W;I('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S
M='(@(E!O>F1N[2!S;NQH;W;I('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")3;NQH
M;W;A('!O:W+]=FMA.B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS
M9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")6;V1N
M[2!E:W9I=F%L96YT('!R;R!S;NUH.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`BJ6%L86UO=6YO=GD@;W-T<F]V
M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M
MX6QS:V\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O
M;F=S("8@4&]E;7,B"FUS9W-T<B`B4.US;NP@82!BX7-N["(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L
M96-T:6]N(@IM<V=S='(@(E-M['(@=/CM9.QN[2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@
M(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(EID<F]J;W;A(&%D<F5S82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")*:;YN
M[2!!9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(DII:&]E=G)O
M<'-K_2`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S
M='(@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")*
M:;YN[2!P;VQO:V]U;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<R(*;7-G<W1R(")0<F]S=&]R(&UE>FD@<V]U<V5D;NUM:2!B=?)K
M86UI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R
M(&EN(&-E;&PB"FUS9W-T<B`B4')O<W1O<B!M97II(&]B<V%H96T@82!H<F%N
M:6-E;6D@=B!B=?)C92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q
M-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(DUE>F5R;NUK(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED
M(")3<&%C:6YG(@IM<V=S='(@(DUE>F5R>2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B3V1S='5P>2!A(&UE>F5R>2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("*I<&%N[&QS:V\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS
M9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I
M9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B5G-T=7`@<')O
M('IV;.&Y=&[M('IN86MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G
M<W1R(")2;WID[&QI="!B=?)K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M
M;B(*;7-G<W1R(")2;WID[&QI="!S;&]U<&5C(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L
M:70@<F]W(@IM<V=S='(@(E)O>F3L;&ET(/CA9&5K(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@
M3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B
M4W1A;F1A<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@
M(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4F]K('IAZ.%T:W4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B
M4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B4W3A="#H:2!P<F]V:6YC:64B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I
M9"`B4W1A='5S(@IM<V=S='(@(E-T878B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$U"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")&
M;W)MX70@=6QOOF5N[2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<R"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")5;&EC
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B4/AEN6MR=&YU=/TB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I
M;F<@;&ES="(*;7-G<W1R(")397IN86T@^&5T['IC92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M
M('1H92!A9&1R97-S(@IM<V=S='(@(D]D<W1R86YI="!D;VWI;F]VZ2!J;>EN
M;R!Z(&%D<F5S>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@
M(E-T>6P@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(").92(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E!O
M9&%D<F5SX?@@)R5S)R!N96)Y;"!N86QE>F5N+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B
M"FUS9W-T<B`B4/AE9&WL="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G
M:60@(E-U8FUI="(*;7-G<W1R(")0;V1A="(*"B,Z('-I9VYU<"YP:'`Z-#D*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@
M;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"XB"FUS9W-T<B`B(@HB0GEL82!P;V3A;F$@ON%D;W-T(&\@</AI9.%N[2`G
M)7,G(&1O('-Y<W3I;74N($)U9&5T92!S92!M;V-I('#X:6ALX7-I="!AOB!P
M;R`B"B)K;&%D;NEM('9Y^.UZ96[M(%9AN>T@ON%D;W-T:2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3
M=6)S8W)I<'0B"FUS9W-T<B`B1&]L;NT@:6YD97@B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B
M"FUS9W-T<B`BVG-P[+EN["(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@8GEL*&$I(/IS<.RY
M;NP@</AI9.%N*&$I(&1O('-Y<W3I;74N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN
M(@IM<V=S='(@(D1A=&$@<')O('6^:79A=&5L92`E<R!B>6QA(/IS<.RY;NP@
M;V1S=')A;NQN82!Z92!S>7-TZ6UU+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G
M<W1R("+:<W#LN6[L(&]D<W1R86[L;F$@)R5S)RXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@
M(B<E<R<@^G-P[+EN["!O9'-T<F%N[&XH82D@>F4@<WES=.EM=2XB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+B(*;7-G<W1R(")+;VYF:6=U<F%C92!B>6QA(/IS<.RY;NP@>FWL;NQN82X@
M3V)N;W9T92!S='+A;FMU+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU
M.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+:<W#L
MN6[I('5L;[YE;NT@>N%L;[YN[2!K;VYF:6=U<F%C92XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RXB"FUS9W-T<B`BVG-P[+ENZ2!U;&^^96[M('KA;&]H>2!K;VYF:6=U<F'H
M;NUH;R!S;W5B;W)U("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M7"(E<UPB(@IM<V=S='(@(MIS<.RY;N$@86MT=6%L:7IA8V4@<')O("<E<R<B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=W)O=&4@)7,B"FUS9W-T<B`B)7,@8GEL;R#Z<W#LN6[L('IA<'/A;F\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=63A;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4VAR;G5T[2(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B
M4W;M=.%N[2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B
M4W5N(%-E="(*;7-G<W1R("):X7!A9"!3;'5N8V4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS
M9W-T<B`B4VQU;F7H;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(E;]8VAO9"!3;'5N8V4B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(E;]8VAO
M9"]ZX7!A9"!3;'5N8V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B5OUC:&]D(%-L=6YC
M93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I
M9"`B4W5N<V5T(@IM<V=S='(@(EKA<&%D(%-L=6YC92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S
M='(@(EKA<&%D(%-L=6YC93H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T
M<B`B2&]R;NT@:6YD97@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S<X"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E!O9'!O<F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")3
M=7)N86UE(@IM<V=S='(@(E#X[6IM96[M(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!A
M;F0@2F%N($UA>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD
M(@IM<V=S='(@(E-W87II;'-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W
M961E;B(*;7-G<W1R("*I=NED<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W
M:71Z97)L86YD(@IM<V=S='(@(JEV_6-A<G-K;R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO9R!D
M96QE=&5D(@IM<V=S='(@(DYE<VUA>F%T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")3>6YT87AO=N$@8VAY8F$@
M=B!H;&5D86[I;2!T97AT=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA
M;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E/]<FEE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB
M"FUS9W-T<B`B0F]U^&MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")";W7X:WDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PHC+"!F=7IZ>0IM
M<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B0G)Z:^D@</AE:.'R:WDB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")4
M4U8@9FEL92(*;7-G<W1R(")44U8@<V]U8F]R(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A8G5L
M:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E9L
M87-T;F]S=&D@=&%B=6QK>2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*
M;7-G<W1R(")486)U;&MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE
M<R(*;7-G<W1R(")6;&%S=&YO<W1I('1A8G5L:WDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&%I=V%N+"!P<F]V:6YC
M:64@R.UN>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`B5&%DOFEK:7-TX6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GKA;FEE+"!3
M<&]J96[A(')E<'5B;&EK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B0^UL
M.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`BVFMO;'DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I
M9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(")496QE9F]N;NT@Z.US;&\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@
M;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5P;&]T82!Z82!P;W-L961N[2!H;V1I
M;G4Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP
M97)A='5R92(*;7-G<W1R(")497!L;W1A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R
M(")497!L;W1A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S
M2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(E9Z;W(@)R5S)R!N96)Y;"!N86QE>F5N+B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")6>F]R('!R;R!A9&UI;FES=')A8VDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*
M;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")0;W5Z92!T
M97AT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("):87)O=F[A
M;NT@=&5X='4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E9R8V@@=&5X='4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y
M"FUS9VED(")4:"(*;7-G<W1R("+(="(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4:&%J<VMY
M("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM
M<V=S='(@(E1H86IS:V\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B1.QK=6IE;64@>F$@<&]UONUVX6[M('-Y<W3I;74N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E#X[7!O;F$@<')O
M($944"!N96[M(&1O<W1U<&[A+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B
M"FUS9W-T<B`B26YT96=R8>AN[2!A;&=O<FET;7D@=B!(;W)D92]+;VQA8B!N
M97!O9'!O<G5J[2!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]";V]K+G!H<#HQ,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L;V<@
M8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(")0^&5N97-E;OT@
M<V]U8F]R(&YE;'IE('5L;[YI="XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B3F7Z<W#LN6[I(&YAZ'1E
M;NT@=/CM9'D@36%I;G1E;F%N8V4Z.B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")">6QO('5Z87;X96YO(&]K
M;F\@<R!M;[YN;W-T;6DN(%5K;V[H96YO+B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*
M(D%D;6EN:7-T<NUT;W(@<&]T^&5B=6IE(&YA:V]N9FEG=7)O=F%T('1R=F%L
MX2!P<N%V82!V('-Y<W3I;74L('!O:W5D('-I("(*(G#X96IE=&4@<&]UONUT
M('!RX79A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM
M<V=S='(@(E!O=7IE('-P;V1N[2!S=')A;F$B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE
M(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G
M<W1R("(B"B).96)Y;&\@=79E9&5N;R!)1"!P<F\@:V]N=&%K="P@;F5B>6QO
M(&YA;&5Z96YO('8@9&%T86+A>FD@;F5B;R!B>6QO(/IP;&[L("(*(G9Y;F5C
M:.%N;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W0@8GEL
M(/IS<.RY;NP@</AI9.%N(&1O(%9AN65H;R!A9')E<^'X92XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(")+(&]V[/AE;NT@
M<&]D97!S86[I('IP<N%V>2!J92!T^&5B82!O9&3L;&5N_2!B;&]K(',@4$=0
M('!O9'!I<V5M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(DYE
M8GEL;R!U=F5D96YO($E$(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2P@;F5B>6QO
M(&YA;&5Z96YO('8@9&%T86+A>FD@;F5B;R`B"B)B>6QO(/IP;&[L('9Y;F5C
M:.%N;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+B(*;7-G<W1R(").96)Y;"!U=F5D96X@9&ES=')I8G7H
M;NT@<V5Z;F%M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S
M"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B*I:69R;W9A8^T@;6^^
M;F]S=&D@;'IE('9Y=;[M="!P;W5Z92!P^&D@8F5Z<&7H;NEM('-P;VIE;NT@
M<R!W96)E;2`H:'1T<',I+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RXB"FUS9W-T<B`B4V]U8F]R("5S(&)Y(&WL;"!O8G-A:&]V870@
M;F%S=&%V96[M("5S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@
M<V5T=&EN9W,N(@IM<V=S='(@(E-O=6)O<B`E<R!B>2!M[&P@;V)S86AO=F%T
M(&[L:W1E<N$@>B!N87-T879E;NT@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B4V]U8F]R(&YE;'IE(&MO<.UR
M;W9A="!SX6T@9&\@<V5B92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H
M<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R(")3;W5B;W(@;F5O8G-A:'5J92"^X61NX2!D871A+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H
M92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O
M<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(D[A<VQE9'5J[2!H;&%V:>AK>2!P
M<F\@;65S<V%G92]R9F,X,C(@>G!RX79U(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@
M<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!)
M;G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T
M('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X
M<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F
M=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B
M"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@
M=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R
M;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O
M('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)*92!Z
M;N%MZ2P@OF4@;?-D('#X97,@8V5L;W4@;V)R87IO=FMU('8@26YT97)N970@
M17AP;&]R97)U('#Y<V]B[2!P<F]B;.EM>2P@(@HB<')O=&^^92!S92!V(&[L
M;2!V>7-K>71U:F4@8VAY8F$L(&MT97+I('-E(&YE;'IE('9Y:&YO=70N($IA
M:V\@;N%S;&5D96L@;?F^92`B"B)B_70@;N%H;V1NZ2!Z:')O=6-E;NT@=&]H
M;W1O('!R;V=R86UU+"!C:'EB[&KM8^T@9G5N:V-E(&5D:71O<G4@;F5B;R`B
M"B)N97-P<N%V;ND@>F]B<F%Z;W;A;NTN(%!O:W5D(&IE(%;AN2!S>7-T96WI
M;2!7:6YO9'=S(#EX+"!J92!V96QM:2`B"B)P<F%V9.QP;V1O8F[I+""^92!S
M92!O8FIE=NT@8VAY8F]VZ2!H;.&Y96[M("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G(&$@(@HB8G5D971E(&UU<V5T(')E<W1A<G1O=F%T('!OZ.UT8>@N
M7%QN7%QN0GEL:2!J<W1E('9A<F]VX6YI+B!0<F]S[6T@<W1I<VMN['1E("(*
M(D]+('!O:W5D('-I('#X96IE=&4@<&]K<F'H;W9A="!V(&WS9'4@</AE<R!C
M96QO=2!O8G)A>F]V:W4N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&$@7"(E<UPB(&)Y;&$@<VUA
M>N%N82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R(")0;W5Z92!N82!L97;I('-T<F%N["(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N
M(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y
M<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(E5M[7-T[&[M(&)I;N%R;NUH;R!S
M;W5B;W)U($=N=5!'(&UU<^T@8OUT('IA9.%N;R!D;R!T^.UD>2!#<GEP=%]P
M9W`Z.BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N
M7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB6G!RX79A
M('IA<VQA;N$@=B`E<R!K("5S(',@</AE9&WL=&5M(%PB)7-<(B!B>6QA('IO
M8G)A>F5N82Y<;B(*(E1O=&\@;F5Z87)UZ'5J92P@OF4@>G!RX79A(&)Y;&$@
M</AEZ'1E;F$@;F5B;R"^92!J[2!A9')E<^%T*&MA*2!R;WIU;>QL*&$I+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N
M86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*
M;7-G<W1R(").X7IE=BP@:W1E<OT@8G5D92!P;W6^:70@</AI(&]D:V%Z;W;A
M;NT@;F$@<W1RX6YC92!T=F]R8GD@>G!RX78B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@
M;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B5&]T;R!P;VQE
M(&UU<^T@8OUT('!L871NZ2#H[7-L;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L
M92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA
M<W,N(@IM<V=S='(@(E3X[61A($AO<F1E7T-R>7!T7W-M:6UE.CH@=GF^861U
M:F4@;6]D=6P@;W!E;G-S;"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N
M<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC
M92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@
M97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T
M<B`B(@HB3F5L>F4@=6QOOFET(&YA<W1A=F5N[2!<(B5S7"(L('!R;W1OOF4@
M:F5H;R!V96QI:V]S="!P^&5SX6AL82!P;W9O;&5N_2!L:6UI="XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(@IM<V=S='(@(DYE8GEL82!N86QE>F5N82!A<&QI:V%C92!P<F\@Z'1E
M;NT@=&]H;W1O('1Y<'4@9&%T("@E<RDN(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*
M;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@
M(E!O=7IE(&YA('!R87;I(&$@;&5VZ2!S=')A;NPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F$@<')A
M=ND@<W1R86[L(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V
M"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E<G9E<B!<(B5S7"(@8GEL
M('9Y;6%ZX6XN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@<V%V960N(@IM<V=S='(@(E-E<G9E<B!<(B5S7"(@8GEL('5L;[YE;BXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*
M;7-G<W1R(")">6QA(&]D<W1R86[L;F$@ON%D;W-T(&\@</AI:&SAN65N[2!P
M<F\@)7,N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B4&^^861O=F%N_2#XX61E:R!N965X:7-T=6IE+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(D1OZ&%S;OT@<V]U8F]R(%PB)7-<(B!N965X:7-T=6IE+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T
M97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE
M('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@
M8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F%H;_AE(&$@9&]L
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E!O
M=7IE(&YA:&_X92(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM
M<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R
M979I;W5S('-T97`N(@IM<V=S='(@(EIT<F%T:6QA('-E('#X96YE<V5NX2!D
M871A('H@</AE9&-H;WKM:&\@:W)O:W4N(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V
M960N(@IM<V=S='(@(E#X96YE<V5N_2!S;W5B;W(@;F5L>F4@=6QOOFET+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS
M9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B0FQO:R!W96%T:&5R+F-O;2!N96[M(&1O<W1U<&[]+B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(").96)Y;"!N86QE>F5N(&%D<F5SX?@@<R!TZ6UA='D@)R5S)RXB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("*NX61N
MZ2!Z(&UOOFYO<W3M(&YE:G-O=2!D;W-T=7!NZ2XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N
M;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M(").96)Y;'D@;F%L97IE;GD@ON%D;ND@Z.%S=&DL(&MT97+I(&)Y(&)Y;&\@
M;6^^;F\@>F]B<F%Z:70@=B#XX61K=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S
M<R!T:&%N("5S+B(*;7-G<W1R("(B"B)0^.UL:;D@;6YO:&\@>FYA:_D@=B!P
M;VQI+B!:861A;&D@:G-T92`E<R!Z;F%K^3L@;75S[71E('IA9&%T(&WI;NP@
M;F6^("5S("(*(GIN86OY+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E
M<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*
M;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!P^&EDX7;A;NT@)R5S)R!D;R!S
M>7-TZ6UU.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN
M9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R(").87-T86QA(&-H>6)A('#X:2!O9'-T<F'R;W;A;NT@=;YI=F%T96QS
M:_UC:"!D870@)R5S)R!Z92!S>7-TZ6UU.B`B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&]D<W1R8?)O=N%N[2`G)7,G('IE
M('-Y<W3I;74Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R!<(B5S7"(Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&%K='5A
M;&EZ86-I("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"XB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U
M.B`E<R!N96)Y;"!P^&5N97-E;BXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2XB"FUS9W-T<B`B(@HB3F%S=&%L82!C:'EB82!P^&D@</AE;F]S
M=2!S;W5B;W)U+B`E<R!N96WYOF4@8OUT(';L=+GM(&YEOB!M87AI;>%L;NT@
M(@HB<&]V;VQE;N$@=F5L:6MO<W0@*"5D(&)Y=/DI+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R
M(").87-T86QA(&-H>6)A('#X:2!P^&5N;W-U('-O=6)O<G4Z(&)Y;&$@</AE
M;F5S96YA(&IE;B#HX7-T('-O=6)O<G4@)7,N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T
M<B`B1&^Y;&\@:R!C:'EB["!P^&D@>F]B<F%Z;W;A;NT@=.ET;R#HX7-T:2!Z
M<'+A=GDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&EM<&]R
M=&]VX6[M(&MO;G1A:W1U+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC
M+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E#X:2!I;7!O<G1O=N%N[2!I
M0V%L96YD87(@9&%T(&1ON6QO(&L@8VAY8NPN(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN
M('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T
M(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(D-H>6)A('8@:V]N
M9FEG=7)AZ&[M;2!F;W)M=6SA^&DN(%KX96IM["!J<W1E('9Y;F5C:&%L:2!P
M;[YA9&]V86[I('!O;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"B).87-T86QA(&-H>6)A('#X:2!P<F]VX63L;NT@>F%D86[I(&]P97)A8V4@
M=B!A9')E<^'X:2X@4')O<^UM('IK=7-T92!T;R`B"B)P;WID[&II+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O
M;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B3F%S=&%L82!C:'EB82!P^&D@86MT=6%L:7IA8VD@:V]N=&%K='4N(%!R
M;W/M;2!Z:W5S=&4@=&\@<&]Z9.QJ:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB3F%S=&%L82!C:'EB
M82!P^&D@86MT=6%L:7IA8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+B!0<F]S
M[6T@>FMU<W1E('1O("(*(G!O>F3L:FDN(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R
M=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R
M(")496YT;R!)34%0('-E<G9E<B!N97!O9'!O<G5J92!S9.UL96[M('-L;[YE
M:RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X
M"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A
M<B!A<F-H:79E+B(*;7-G<W1R(")4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[]
M(')A<B!A<F-H:78N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B5&]T;R!N979Y<&%DX2!J86MO
M('!L871N_2!Z:7`@<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")4;W1O(&YE=GEP863A(&IA:V\@
M<&QA=&[I(.CM<VQO(&MA<G1Y+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5&5N=&\@;W9L861AZ"!U
M;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO8^T@0VQI8VMA=&5L;"`H:'1T
M<#HO+V-L:6-K871E;&PN(@HB8V]M*2!B<N%N>2!P^&D@<&]UOFET[2!(5%10
M($%022(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,T"B,L(&9U>GIY"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@HB5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P
M;VUO8^T@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+B(*(F-O;2D@8G+A
M;GD@</AI('!O=;YI=.T@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E1E;G1O(&]V;&%D8>@@
M=6UOOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M('-M<S)E;6%I;"`H:'1T
M<#HO+W-M<S)E;6%I;"XB"B)C;VTI(&)RX6YY('#X:2!P;W6^:73M($A45%`@
M05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(E1E;G1O
M(&]V;&%D8>@@=6UOOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M(%--5%`@
M9&\@5F]D869O;F4@271A;'D@8G+A;GD@(@HB<&]U>F4@<')O(.CM<VQA('!O
M<VMY=&YU=.D@5F]D869O;F5M+B!-=7/M=&4@;>UT(&5M86EL;W;](/KH970@
M=2!6;V1A9F]N92`B"B))=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U
M-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(E1O=&\@<&]L92!J92!N=71NZ2!V>7!L;FET+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B5&]T;R!P;VQE(&WYOF4@
M;V)S86AO=F%T('!O=7IE(&-E;.$@Z.US;&$N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B5&]T;R!P
M;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&-E;.$@Z.US;&$@82!D=F]J=&7H
M:W4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS
M9W-T<B`B5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&]S;6GH:V]V
MZ2#H[7-L82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS
M9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A
M<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R(")4;W1O('!O;&4@;75S
M[2!B_70@<V5Z;F%M(&-E;/UC:"#H[7-E;"!O9&3L;&5N_6-H(.CA<FMO=2!N
M96)O(&UE>F5R;W4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*
M;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS
M9W-T<B`B5&]T;R!P;VQE(&UU<^T@8OUT('!L871NZ2#H[7-L;RXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I
M96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@
M9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*
M(E1O=&\@<&]L92!M=7/M('!B<V%H;W9A="!B87)E=F[](&OS9"!V(+EE<W1N
MX6-K;W;I;2!21T(@9F]R;>%T=2P@;F%P^"X@(@HB)R,Q,C,T868G+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")496YT;R!F
M;W)M=6SA^"!J:;X@8GEL('IP<F%C;W;A;BXB"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R(")4;W1O(&IE("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@
M82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T
M('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G
M<W1R("(B"B)4;W1O(&IE(&]B:F5K="!+;VQA8B!'<F]U<'=A<G4N($L@>FAL
MZ61N=73M('1O:&]T;R!O8FIE:W1U(&IE('IA<&]T^&5B[2!M[70@(@HB<&^Y
M=&]V;NUH;R!K;&EE;G1A+"!K=&5R_2!R;WIU;>T@9F]R;>%T=2!+;VQA8B!'
M<F]U<'=A<G4N(%!R;R!S97IN86T@(@HB=&%K;W;]8V@@:VQI96YT^2!P<F]S
M[6T@;F%VN71I=G1E("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G
M92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T
M:&%N('EO=7(@;W=N+B(*;7-G<W1R(")4871O('IP<N%V82!B>6QA(&YA<'/A
M;F$@=B!J:6[I('IN86MO=ND@<V%D["`H)7,I(&YEOB!68;GM+B`B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N
M=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E1O=&\@Z.US
M;&\@;75S[2!B_70@;F5J;>EN["!J961N82XB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R
M(")397)V97(@;F5M^;YE(')O>F)A;&ET('II<"!A(&=Z:7`@<V]U8F]R>2XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM
M<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*
M;7-G<W1R(")496YT;R!S>7-TZ6T@:F4@=B!S;W7H87-N;W-T:2!D96%K=&EV
M;W9A;OTN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*
M;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B
M5&%T;R!H;V1N;W1A(&UU<^T@8OUT(.CM<VQO+B(*"B,Z('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B
M5&]T;R!O:VYO(&UUOF4@8OUT('9O;.%N;R!P;W5Z92!Z(&]K;F$@;6^^;F]S
M=.TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")(^&WL;NTB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@
M(DSM<W1K>2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S
M='(@(LAA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G
M:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B4VQE9&]VX6[M(.AA<W4B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM
M<V=S='(@(D9O<FWA="#H87-U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B5OUB['(@
MZ&%S=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S
M='(@(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I
M9"`B5&ET;&4B"FUS9W-T<B`B5&ET=6PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I
M<"DZ(@IM<V=S='(@(E1I='5L("AT:7`I.B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@
M(DMO;74B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)0;VMU9"!S:2!P^&5J
M971E('9Y8G)A="!V[6-E('!O;&^^96LL('IMX>AK;NQT92!K;.%V97-U($-O
M;G1R;VP@*%!#*2!N96)O("(*(D-O;6UA;F0@*$UA8RD@82!K;&EK;NQT92!N
M82!P;VQOOFMU+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D1N97,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@
M2%1-3"!3;W5R8V4B"FUS9W-T<B`B4/AE<&YO=70@;F$@2%1-3"!Z9')O:B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O
M;6]R<F]W(@IM<V=S='(@(EKM=')A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R
M(")6<F-H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")(;W)N
M[2!RX6T@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS
M9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B4/AE:VQA9'DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R
M:6YI9&%D(&$@5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")3<'+A=F[L(&YE
M8F\@N7!A=&[L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`BVG0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;FES:V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R96-K;R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(*;7-G<W1R(")4=7)E8VMY("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T
MX6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',B"FUS9W-T<B`B5'5R:W,@82!#86EC;W,@;W-T<F]V>2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO
M:6-E.B`B"FUS9W-T<B`B3F%P:;ET92!68;EI('9O;&)U.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z
M("(*;7-G<W1R(")5+E8N(&EN9&5X.B`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R
M(")54DP@<')O('IP<N%V=2!O('-T879U('IA<VQA;NEH;R!S:W)I<'1U(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM
M<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86II;F$B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&%D<F5SX?@@:F4@;F5P^.US
M='5P;OTN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV
M"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R(")0^&D@<F5G:7-T<F%C:2!N96QZ
M92!P^&ED870@97AT<F$@=;YI=F%T96QS:^D@^F1A:F4N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(DYE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O
M<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B3F5L>F4@>FWL;FET('!RX79A('!R;R!6
M1E,@<V]U8F]R("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N(@IM<V=S='(@(DYE;'IE('IM[&YI="!N82`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(@IM<V=S='(@(DYE;'IE('#X97-U;F]U="!61E,@<V]U8F]R(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R
M(").96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R("5S+R5S+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*;7-G:60@(E5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYE;'IE('-E('#X
M:7!O:FET(&L@4U%,('-E<G9E<G4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+B(*;7-G<W1R(").96QZ92!S92!P^&EP;VII="!P;VUO8^T@4U-,+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@
M(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!K;W#M
M<F]V870@5D93('-O=6)O<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").96QZ92!V>71V;_AI
M="!61E,@861R97/A^"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").96QZ
M92!V>71V;_AI="!61E,@861R97/A^"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+B(*;7-G<W1R(").96QZ92!V>71V;_AI="!61E,@<V]U8F]R+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(").96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@
M(DYE;'IE('9Y='9O^&ET('!RX7ID;OT@5D93('-O=6)O<BXB"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DYE;'IE(')O>F)A;&ET
M(&1A=&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R(").96QZ92!V>6UA>F%T(%PB)7-<(BP@<')O
M=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB
M"FUS9W-T<B`B3F5L>F4@=GEM87IA="`G)7,G.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@)7,L('!R;W1O
MOF4@861R97/A^"!N96[M('!RX7ID;OTN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DYE;'IE(')E:W5R>FEV["!O9'-T
M<F%N:70@5D93(&%D<F5SX?@N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-#0*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3F5L>F4@=GEM87IA="!61E,@861R97/A^"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").96QZ92!V
M>6UA>F%T(%9&4R!A9')E<^'X.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@=GEM87IA
M="!61E,@<V]U8F]R(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!V>6UA
M>F%T(%9&4R!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('9Y;6%Z
M870@5D93('-O=6)O<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(").96QZ92!R96MU
M<GII=F[L(&]D<W1R86YI="!61E,Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#`S"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(").96QZ92!U<NAI="!A:W1UX6QN
M[2!A9')E<^'X+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS(@IM<V=S='(@(DYE;'IE('IJ:7-T:70@<&]D<F]B;F]S=&D@;R!C
M97)T:69I:^%T=2XB"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z
M-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO
M;B!O9B`E<RXB"FUS9W-T<B`B1&5F:6YI8V4@)7,@;F5N[2!D;W-T=7!NX2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$W,0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@
M(DYE;'IE('#X97-U;F]U="!61E,@<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('#X
M97-U;F]U="!61E,@<V]U8F]R(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB
M"FUS9W-T<B`B5D93('-O=6)O<B!N96QZ92!O=&5V^.UT('!R;R!ZX7!I<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB
M"FUS9W-T<B`B3F5L>F4@;W1E=OCM="!61E,@<V]U8F]R+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3F5L>F4@
M;W1E=OCM="!A<F-H:79O=F%N_2!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5L>F4@
M>F%P<V%T(&1A=&$@9&\@5D93('-O=6)O<G4@*'-E;&AA;&\@8V]P>2@I*2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+B(*;7-G<W1R(").96QZ92!Z87!S870@9&%T82!D;R!61E,@<V]U8F]R
M=2`H<V5L:&%L;R!C;W!Y*"DI+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(DYE;'IE('#X96IM
M96YO=F%T(%9&4R!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYE;'IE(.CM<W0@>B!V9G-R;V]T(&%D<F5S
MX?AE+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B3F5L
M>F4@</AE:FUE;F]V870@)7,@;F$@)7,Z(&/M;&]VX2!S;&^^:V$@:FF^(&5X
M:7-T=6IE(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y
M,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(")61E,@861R97/A^"!N96QZ92!P^&5J;65N;W9A="XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M(")61E,@861R97/A^"!N96QZ92!P^&5J;65N;W9A=#H@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('#X96IM96YO
M=F%T(%9&4R!S;W5B;W(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(DYE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B
M;W(@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T
M<B`B3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<BXB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G
M:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(").96QZ92!P
M<F]VZ7-T("=M:VES;V9S)RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")496YT;R!D;VMU;65N="!7
M;W)D(&YE;'IE('#X96QOOFET(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3F5L>F4@>F%P<V%T(&1O(%9&4R!S;W5B;W)U(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM
M<V=S='(@(DYE;'IE('IA<'-A="!D871A(&1O(%9&4R!S;W5B;W)U("AS96QH
M86QO(&-O<'DH*2DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DYE;'IE('IA<'-A
M="!D871A(&1O(%9&4R!S;W5B;W)U(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C@T,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(").96QZ92!Z
M87!S870@9&%T82!D;R!61E,@<V]U8F]R=2`H<V5L:&%L;R!C;W!Y*"DI+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*
M;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")0;V1T<FAN=73I(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM
M<V=S='(@(E-T;W)N;R!Z;>QN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A
M8W1I;VXB"FUS9W-T<B`B4W1O<FYO=F%T('!O<VQE;NT@86MC:2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M(@IM<V=S='(@(DYE;^AE:^%V86[A(&]D<&]V[.\@<V5R=F5R=2!N82!S<&]J
M96[M.B`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*
M;7-G<W1R(").96_H96OA=F%NX2!O9'!O=NSO('-E<G9E<G4Z("(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS
M9VED(")5;F9I;&5D(@IM<V=S='(@(DYE=GEP;&[L;F\B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S
M='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET
M960@07)A8B!%;6ER871E<R(*;7-G<W1R(")3<&]J96[I($%R86)S:^D@16UI
M<N%T>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS
M9W-T<B`B5F5L:^$@0G)I=.%N:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M;FET960@4W1A=&5S(@IM<V=S='(@(E-P;VIE;ND@4W3A='D@06UE<FEC:^DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B4W!O:F5NZ2!3=.%T>2!-96ZY:6YO
M=OUC:"!O<W1R;W;Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S
M='(@(DIE9&YO=&MY(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I
M9"`B56YK;F]W;B(*;7-G<W1R(").97INX6WI(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(DYE>F[A
M;>D@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N
M:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B
M3F5Z;N%MZ2!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE8GEL;R!V
M>6)RX6YO(+[A9&[I(&WM<W1O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R
M;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F5Z;N%MZ2!UOFEV871E;'-K
MZ2!J;>EN;R!N96)O(&AE<VQO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B3V1P;VII="!S;W7H87-N_2!P
M<G9E:R(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(D)E>F4@:FWI;F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B
M"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(DYE<')I
M=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6]H;W4@=GEUONUV870@9G5N:V-A(%9Y
M:FUO=70O2V]P[7)O=F%T+U9L;[X@>B`B"B)B97IP9>AN;W-T;NUC:"!D^79O
M9/DN($ML:6MN['1E(&YA($]+(&%B>7-T92!V:63L;&D@=&5C:&YI8VMO=2!Z
M<'+A=G4@>B`B"B)M;WII;&QA+F]R9RP@:W1E<N$@=GES=NQT;'5J92P@:F%K
M(&YA<W1A=FET('-K<FEP="!P<F\@</CM<W1U<"!K92!S8VARX6YC92XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(").96YA<W1A=F5NX2!B
M87)V82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O
M<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B3F5P;V1P;W)O=F%NX2!P^.UP;VYA
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G
M<W1R(")!:W1U86QI>F]V870B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*
M;7-G<W1R(")!:W1U86QI>F]V870@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M(")!:W1U86QI>F]V870@=;YI=F%T96QE(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T960@7"(E<UPB+B(*;7-G<W1R(")!:W1U86QI>F]VX6YY("<E<R<N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@
M<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(E-K<FEP="!P<F\@86MT=6%L:7IA
M8VD@8GEL('9Y;6%ZX6XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS
M9VED(")5<&QO860B"FUS9W-T<B`B4/AE;F]S(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(E:Y96-H;GD@
M<V]U8F]R>2!P<F\@;F%S=&%V96[M(&%P;&EK86/M(&)Y;'D@</AE;F5S96YY
M(&YA('-E<G9E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(E9E;&OA('1I<VMA8^T@<.US;65N82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*
M;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B5F5L:^D@^.UM
M<VOI(.CM<VQI8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM
M<V=S='(@(E5R=6=U87DB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@
M0W5R<F5N=#H@)7,B"FUS9W-T<B`B4&]UONUT(&%K='7A;&[M.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X
M"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(E!O=;[M="!34TPB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")0
M;W6^[70@<&]K=60@:FWI;F\O:&5S;&\@:G-O=2!J:6[I(&YEOB!P<F\@24U3
M4"!S97)V97(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R(")5OFEV871E;.DB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RXB"FUS9W-T<B`B5;YI=F%T96P@)7,@;F5N[2!O<'+A=F[L;B!K
M('!O=;[M=N%N[2`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@
M(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-E('6^
M:79A=&5L^2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q
M"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B5;YI=F%T96QS:^D@;6^^
M;F]S=&DB"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B(*;7-G<W1R(")296=I<W1R86-E('6^:79A=&5L^2(*"B,Z('-I9VYU
M<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(DYA('1O;71O('-E<G9E
M<G4@;F5N[2!M;[YNX2!R96=I<W1R86-E('6^:79A=&5L^2XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#8Y"B,L(&9U>GIY"FUS9VED(")5<V5R(&%C
M8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B5S(&YE8GEL;R!N86QE>F5N;RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R
M(")5OFEV871E;'-KZ2!J;>EN;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S
M97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B5;YI=F%T
M96QS:^D@:FWI;F\@)R5S)R!J:;X@97AI<W1U:F4N(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`B5;YI=F%T96QS:^D@:FWI;F\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")5OFEV871E
M;'-KZ2!J;>EN;SH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B4V5Z
M;F%M('6^:79A=&5L^3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES
M=&%N(@IM<V=S='(@(E5Z8F5K:7-TX6XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U
M"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M(")61E,@861R97/A^"!N965X:7-T=6IE+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D1O=F]L
M96[A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")6
M86QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(DYA;&5Z
M96[A('!L871NX2!M[7-T82!Z86AR;G5J[3H@(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S
M='(@(E!L871N;W-T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S
M(&9R;VT@;F]W+B(*;7-G<W1R(")(;V1N;W1A('8@;6EN=73A8V@N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E
M<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S
M='(@(DAO9&YO='DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T
M;R!S96QE8W0@9G)O;2(*;7-G<W1R(")6>6)R86[I(&AO9&YO='D@>B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(E!R;VWL;F[I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I
M;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R
M960@=VET:"XB"FUS9W-T<B`B4V5L:&%L82!V97)I9FEK86-E("T@=&%T;R!Z
M<'+A=F$@;6]H;&$@8OUT('IF86RY;W;A;F$N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T
M<B`B5F5R>F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS
M9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEO;B!#;VYT<F]L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B5F5R=&EK
MX6QN[2!Z87)O=F[A;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S
M='(@(E9E<G1I:^%L;NT@;V1S='5P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S
M='(@(E9E<G1I:^%L;NTZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")696QM
M:2!V>7-O:^$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G
M<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G
M:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;7-K>2`H
M5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(EIO
M8G)A>FET("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B
M5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("):;V)R87II="!E
M>'1E<F[M('=E8G-T<N%N:W4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E
M<R(*;7-G<W1R("):;V)R87II="!J86MO("5S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B4&%N;F5N
M<VOI($]S=')O=GDL($)R:71S:^DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6
M:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")086YN96YS:^D@3W-T<F]V
M>2P@52Y3+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6
M:7-I8FEL:71Y(@IM<V=S='(@(E9I9&ET96QN;W-T(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM
M<V=S='(@(E9I9&ET96QN;W-T.B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)
M=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L>2!P^&5S(%--
M5%`B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(E50
M3UI/4DY)5"(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+B(*;7-G<W1R(")54$]:3U).S$[-(2$A($]$4U120=)4
M12!32U))4%0@4E7(3LP@6B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B5TE.('9I82!(
M5%10(@IM<V=S='(@(G-M<S)E;6%I;"!Z82!P;W6^:73M($A45%`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")7
M86QL:7,@86YD($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")5<&]Z;W)N
M[&[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B4W0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS
M9W-T<B`B4/AE9'!O=NSO('!OZ&%S[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B
M>2(*;7-G<W1R(")$871A(&\@<&_H87/M('!O<VMY='5J92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS
M9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8B!S
M97)V97(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B5/UD;NPB"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G
M<W1R(")6[71E:G1E(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*
M;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5NUT96IT92!V("5S(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L
M("5S(@IM<V=S='(@(E;M=&5J=&4L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@
M(EKA<&%D;NT@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("):
MX7!A9&[M("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S
M=&5R;B!386AA<F$B"FUS9W-T<B`B6N%P861N[2!386AA<F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M(@IM<V=S='(@(DMT97)O=2!A<&QI:V%C:2!MX2`E<R!Z;V)R87II="!P;R!P
M^&EH;.&Y96[M(&1O('-Y<W3I;74_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_(@IM<V=S='(@(DIA:_T@:F4@;V1D[&QO=F%C[2!Z;F%K/R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(DIA:_T@:F4@>FYA:R!P
M<F\@8VET86-I/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#8Q"B,L(&9U>GIY"FUS9VED(")7:&5R96ES($%U<W1R86QI
M82!M87`B"FUS9W-T<B`B075S='+A;&EE(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B2W1E<ND@9N%Z
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H
M('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB
M"FUS9W-T<B`B5F]L8F$@<F]ZN>WX96[M('!R;R!2:6-H(%1E>'0@961I=&]R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(JGM^&MA(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3
M('5N:71S(@IM<V=S='(@(JGM^&MA('8@0U-3(&IE9&YO=&OA8V@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("*I[?AK82`E<R!M96YU('9L
M979O("AZ;>QN82!S92!O8FIE=NT@</AI(&1A;+GM;2!P^&EH;.&Y96[M*3HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(JGM^&MA('1A
M8G5L:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")*961N;W1K82"Y
M[?AK>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`BJ>WX:V$Z(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R
M(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B
M5VEN9"(*;7-G<W1R(")6[71R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B
M4F%N;NT@=NUT<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@
M(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B4GEC:&QO<W0@=NQT<G4@
M=B!U>FQE8V@B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B
M5VEN9#HB"FUS9W-T<B`B5NUT<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5NUT<CH@(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS
M9W-T<B`B36]U9')O<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3DV"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")397IN86T@
M</CA;NTB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O
M<FLB"FUS9W-T<B`B4'+A8V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R
M(")!9')E<V$@9&\@>F%M['-T;N%N[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS
M9W-T<B`B5&5L969O;B!D;R!Z86WL<W1NX6[M(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*
M;7-G<W1R(")6>71V;_AE;NT@5D93('-O=6)O<G4@;F5B>6QO('!O=F]L96YO
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<R(*;7-G<W1R(")8-3`Y=C,@>N%K;&%D;NT@;VUE>F5N[2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R!R;WJY[?AE;ND@
M<&]UOFET[2!K;.WH92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.
M86UE(@IM<V=S='(@(E@U,#EV,R!A;'1E<FYA=&EV;NT@:FWI;F\@;W-O8GDB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I
M9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P
M.78S(&ED96YT:69I:^%T;W(@:VSMZ&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B
M"FUS9W-T<B`B6#4P.78S(')O>KGM^&5N[2(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")24B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*;7-G
M<W1R(")24E)2(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B36%P82!9
M86AO;R$B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B4F_H;NPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R(")*96UE;B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE
M<R(*;7-G<W1R(")!;F\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@
M(D%N;RP@<V]U:&QA<^UM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N(@IM<V=S='(@(B(*(DIS=&4@=B!415A43U;)32!-TT15+B!0;W6^:6IT
M92!;/#Y=('1L8>CM=&MA(&L@>G#L=&[I;74@</AE<&YU=.T@9&\@5UE325=9
M1RXB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+B(*;7-G<W1R(").96)Y;&D@:G-T92!S<'+A=F[L(&]V[/AE;FDN
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G
M:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+B(*;7-G<W1R("):;F%K("=<7"<@;F5M^;YE(&+]="!S
M;W7HX7-T[2!68;EE:&\@:FWI;F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED
M(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM
M<V=S='(@(D)Y;&$@>F%DX6YA(&YE<&QA=&[A(&4M;6%I;&]VX2!A9')E<V$N
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*(DYE;6%P;W9A;&D@:G-T92"^X61NX2!P
M;VQE('H@:6UP;W)T;W9A;NEH;R!S;W5B;W)U(&L@;V1P;W;M9&%J[6/M;2!P
M;VSM;2!V("4B"B)S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX
M.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")"
M>6QI(&IS=&4@;V1H;.&Y96YI('IE('-Y<W3I;74N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA
M;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E9L;[YT92#H[7-L;R!M;V)I;&[M
M:&\@=&5L969O;G4L('!O=;YI:G1E(&IE;B#H[7-L:6,@;F5B;R!P^.UP861N
M["`G*R<@<')O("(*(FUE>FENX7)O9&[M(.AI<VQA+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(DUU<^UT92!Z861A="!P;&%T;F]U
M(&AO9&YO='4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K
M96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"B)-=7/M=&4@:V]N9FEG
M=7)O=F%T(&1A=&%BX7II(&1A="P@<&]K=60@<VD@</AE:F5T92!P;W6^[79A
M="!296=I<W1R86-E+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB
M"FUS9W-T<B`B375S[71E(&MO;F9I9W5R;W9A="!61E,@8F%C:V5N9"XB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(DUU<^UT92!N96ID^.UV
M92!P;W!S870@<')O8FSI;2!A('!O=.D@:&\@;V1E<VQA="XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9
M;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@
M=&\B"FUS9W-T<B`B375S[71E('IA9&%T(%523"!N82!K=&5RZ2!B=61E('1E
M;G1O(&]D:V%Z('5K87IO=F%T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@
M8F4@9&5L971E9"XB"FUS9W-T<B`B375S[71E('9Y8G)A="!S97)V97(L(&MT
M97+](&)U9&4@<VUA>N%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB
M"FUS9W-T<B`B375S[71E('9Y8G)A="!UOFEV871E;'-KZ2!J;>EN;RP@:W1E
M<ND@8G5D92!S;6%ZX6YO+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS
M9W-T<B`B375S[71E('IA9&%T('6^:79A=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B
M=61E(&]D<W1R86[L;F\N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DYE=79E9&QI
M(&IS=&4@=;YI=F%T96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@</AI9.%N;RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B3F5U=F5D;&D@
M:G-T92!UOFEV871E;'-KZ2!J;>EN;R!P<F\@86MT=6%L:7IA8VDN(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM
M<V=S='(@(DUU<^UT92!Z861A="!A:V-I+"!K=&5RX2!B=61E('!R;W9E9&5N
M82XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")-=7/M=&4@>F%D870@:FWI;F\@;F]VZ2!K871E9V]R
M:64N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A
M;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G
M<W1R(")68;EE("5S(')E;&%C92!B>6QA('5K;V[H96YA+B!/<.QT('-E('#X
M:6AL8;ET92P@<')O<^UM+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B
M5F&Y92!E;6%I;&]VX2!A9')E<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C$R"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E9A
MN64@3V0M:V]H;SH@861R97-A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B
M66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")68;EE(&EN9F]R;6%C92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*(E8@<F5L86-I("5S('-E('IM[&YI;&$@5F&Y92!I;G1E<FYE
M=&]VX2!A9')E<V$N(%H@8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y('-E("(*(FUU
M<^UT92!O<.QT('#X:6ALX7-I="XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E9AN64@
M:FWI;F\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC
M+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C
M:V5N9"XB"FUS9W-T<B`B(@HB5N&Y(&]V[/AO=F%C[2!S>7-TZ6T@;F5P;V1P
M;W)U:F4@</AI9.%VX6[M('6^:79A=&5L^2!A;F5B;R!T871O(&UOOFYO<W0@
M;F5N[2`B"B)P^.US='5P;N$@>B!J:6[]8V@@9/EV;V3Y+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)6X;D@;W;L^&]V
M86/M('-Y<W3I;2!N97!O9'!O<G5J92!V_7!I<R!UOFEV871E;/D@86YE8F\@
M=&%T;R!M;[YN;W-T(&YE;NT@(@HB</CM<W1U<&[A('H@:FEN_6-H(&3Y=F]D
M^2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+B(*;7-G<W1R("(B"B):9.$@<V4L(+YE('8@<'+Y8NQH=2!R96QA
M8V4@)7,@<V4@>FWL;FEL(%;AN2!P<F]H;.V^9>@N(%H@8F5Z<&7H;F]S=&[M
M8V@@(@HB9/EV;V3Y('-E(&UU<^UT92!O<.QT('#X:6ALX7-I="XB"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")6X;D@<')O
M:&SMOF7H(&YE<&]D<&]R=6IE('1U=&\@;6^^;F]S="XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B(@HB
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I
M;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM
M<V=S='(@(B(*(E;AN2!P<F]H;.V^9>@@;F5U;6^^\G5J92!T:7-K('3M;71O
M('IP^7-O8F5M+B!0<F]V961E;NUM('-T:7-K;G5T[2!#=')L+R(*(D]P=&EO
M;B`K(%`@<W!U<W3M=&4@=&ES:RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R
M(")68;EE('-O=>AA<V[I(.AA<V]VZ2!PX7-M;SHB"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N
M=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")68;EE(&EM<&QI8VET
M;NT@:61E;G1I=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS
M9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E9AN64@:6UP
M;&EC:71N[2!I9&5N=&ET82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")68;EE(/IP;&[I
M(&IMZ6YO.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@
M(E9AN64@;F%S=&%V96[M(&)Y;&\@86MT=6%L:7IO=N%N;RXB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E9A
MN64@;F]VZ2!H97-L;R!P<F\@)7,@:F4Z("5S(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BXB"FUS9W-T<B`B5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI>F]VX6YO
M('!R;R!T<G;A;NT@=.ET;R!R96QA8V4N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"XB"FUS9W-T<B`B5F&Y92!N87-T879E;NT@8GEL;R!A:W1U
M86QI>F]VX6YO+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U
M"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@
M(E9AN64@:&5S;&\@8GEL;R!R97-E=&]VX6YO+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB5F&Y92!H97-L
M;R!B>6QO(')E<V5T;W;A;F\L('IK;VYT<F]L=6IT92!S:2!Z<'+A=GD@96QE
M:W1R;VYI8VOI('!ON71Y(&$@(@HB</AI:&QAN71E('-E(',@5F&Y[6T@;F]V
M_6T@:&5S;&5M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B5F&Y92!H97-L;R!B>6QO(')E<V5T;W;A;F\N(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S
M97)V97)S.B(*;7-G<W1R(")68;EE('9Z9.%L96[I('-E<G9E<GDZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*
M=6=O<VSA=FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)V92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP
M<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H
M='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T
M<B`B6U5K<OUT(&-I=&]V86[]('1E>'1=(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6TAL
MX;EE;NT@<')O8FSI;75=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS
M9W-T<B`B6UIO8G)A>FET(&-I=&]V86[]('1E>'0@+2(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L
M:6YE<UTB"FUS9W-T<B`B6UIO8G)A>FET(&-I=&]V86[]('1E>'0@+2`E<R#X
MX61K^5TB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6_CA
M9&5K("5S('H@)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R86-E(@H*(SH@;&EB+V%P
M:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O
M87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R
M964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]3;6%Z
M870@^.%D96LB"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B
M"FUS9W-T<B`B7U-K=7!I;GDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")?3N%P;W;L9&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E]6;&%S=&YO<W1I(&]B<N%Z:W4N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E]0
M^&EH;.&Y96[M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7T]D:&SAN65N[2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]-;V1I9FEK
M;W9A="!O9&MA>BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]-;[YN;W-T:2(*
M"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S
M='(@(E]0<N%V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM
M<V=S='(@(E]/9'-T<F%N:70@;V1K87HN+BXB"@HC.B!L:6(O87!I+G!H<#HQ
M,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?3F%S=&%V96[M(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S
M"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?5FQA<W1N
M;W-T:2!T86)U;&MY+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?
M57-E<G,B"FUS9W-T<B`B7U6^:79A=&5LZ2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(Q"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B
M861R97/A^"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,T"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R
M(")A9')E<^'X(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*
M;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(FMA;&5N9.'X(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")B97IV['3X[2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@
M;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B
M:VQI:VYO=70@>F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R
M(")2;WID[6QY('8@;F%S=&%V96[M(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE
M(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R
M"B,L(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B;F5N
M86QE>F5N;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(G-RX;YK>2(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*
M;7-G<W1R(")S;W5B;W(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S(@IM<V=S='(@(GH@)7,@*"5S*2!R>6-H;&]S=.T@)7,@)7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"B,L(&9U>GIY"FUS9VED
M(")G=7-T:6YG(@IM<V=S='(@(BP@;N%R87IO=OT@)7,@)7,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H
M.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA
M;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T
M92(*;7-G<W1R(")O:V%MOFET["(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS
M9W-T<B`B=B#X863L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I
M9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI
M;F5S72(*;7-G<W1R("+XX61K^5TB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N
M(@IM<V=S='(@(F-H>6)O=OT@:_-D(&UK:7-O9G,@)60@</AI('9Y=';A^&5N
M[2!)4T\N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS
M9VED(")N86UE(@IM<V=S='(@(FIMZ6YO(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYE
M;NT@:6UP;&5M96YT;W;A;F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS
M9W-T<B`B;F5N[2!D;W-U9"!I;7!L96UE;G1O=N%N;R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@
M(GKA<&ES;NUK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P<F]C
M96YT(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*
M(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(E!R
MX79A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L^2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN
M9R(*;7-G<W1R(")S=&]U<&%J[6/M(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B0FQO:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@
M9&EF9F5R96YC97,B"FUS9W-T<B`B>F]B<F%Z:70@<F]Z9.UL>2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS
M9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('IA
M('!O=;YI=.T@2%144"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A
M9'DB"FUS9W-T<B`B=GET<G9A;.DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P
M"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R
M(")S97IN86T@^FMO;/DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*
M;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R(")+8;YDZ2!P^&EH;.&Y96[M(&1O
M('-Y<W3I;74B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R
M9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(G!R;R!P;W1V<GIE;NT@;F%P
M:;ET92!H97-L;R!D=F%K<N%T(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS
M9W-T<B`B<VIE9&YO8V5N_2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R
M="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B8F5Z(&[A>G9U(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")V>6)R870@=;YI
M=F%T96QE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z
M(@IM<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P;R]D85]$2RYP;P``````````````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`Q,3`Q,C0Q`#$P-#$W,S8S,#`Q`#`Q
M-C,R-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C($1A;FES:"!T<F%N<VQA=&EO;G,@9F]R($AO<F1E('!A8VMA9V4*(R!$
M86YS:V4@;W9E<G/F='1E;'-E<B!F;W(@<&%K:V4@2&]R9&4N"B,@0V]P>7)I
M9VAT("A#*2`R,#`Q($UA<G1I;B!,:7-T+5!E=&5R<V5N+@HC($-O<'ER:6=H
M="`H0RD@,C`P-2TR,#`V($)R:6%N(%1R=65L<V5N+@HC(%1H:7,@9FEL92!I
M<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(
M;W)D92!P86-K86=E+@HC($UA<G1I;B!,:7-T+5!E=&5R<V5N(#QM87)T:6Y`
M;&ES="UP971E<G-E;BYD:SXL(#(P,#$N"B,@0G)I86X@5')U96QS96X@/&AO
M<F1E*VDQ.&Y`8G)I86YT<G5E;'-E;BYD:SXL(#(P,#4M,C`P-BX*(PIM<V=I
M9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ
M+C$M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#,M,3$@,3(Z
M,SDK,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,RTQ,2`Q-CHU
M,BLP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($)R:6%N(%1R=65L<V5N(#QH
M;W)D92MI,3AN0&)R:6%N=')U96QS96XN9&L^7&XB"B),86YG=6%G92U496%M
M.B!$86YI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A
M/2`Q*3M<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E
M<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E<R!D86=E('-I9&5N*2(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,X,R!L:6(O2&]R9&4N<&AP.C$S
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S
M='(@(B`H06-C97-S:V5Y("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&]M("5S(&1A9V4I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AI(&1A
M9RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@
M*&D@;6]R9V5N*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*
M;7-G<W1R("(@*&D@9^5R*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM
M<V=S='(@(B!M960@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,3D@;&EB+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@97(@
M:6MK92!E="!K871A;&]G+B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M-S(@;&EB+TAO<F1E+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<
M(B!E<B!I;G1E="!G>6QD:6=T('9A;&<N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ,#DX(&QI8B](;W)D92]296=I<W1R>2YP:'`Z
M-S$P"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO
M<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@97(@:6MK92!K;VYF:6=U
M<F5R970@:2!(;W)D97,@9F]R=&5G;F5L<V4N(@H*(SH@9G)A;65W;W)K+U1R
M964O5')E92YP:'`Z,3<Q(&QI8B](;W)D92]4<F5E+G!H<#HQ-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")<(B5S7"(@='+F+6]P8GEG9V5R(&EK:V4@9G5N9&5T+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T
M<B`B7"(E<UPB(&)L978@=&EL9OAJ970@:2!G<G5P<&4M<WES=&5M970N(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y
M<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&)L978@=&EL9OAJ970@=&EL;&%D96QS
M97,M<WES=&5M970N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!B;&5V
M(&EK:V4@9&%N;F5T.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"(&)R=6=T('5D(&%F
M("4N,F9-0B!T:6QL861T("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A
M;F0@)7,B"FUS9W-T<B`B)60@)7,@;V<@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C(V."!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR
M-C@*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB
M"FUS9W-T<B`B)60@9&%G92!T:6P@9&ET(&MO9&5O<F0@=61L^&)E<BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UD86=S('5D
M<VEG="(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($YO=&ET
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(&9I;F=E<F%F=')Y:R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@T,B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@
M(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@5F5D;&EG96AO;&1E;'-E("T@0F5K
M<N9F=&5L<V4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M4V5T=7`B"FUS9W-T<B`B)7,@;W!SYG1N:6YG(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V-"!L:6(O2&]R9&4O075T:"]3:6=N=7`N
M<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S
M='(@(B5S(&]P<VMR:79N:6YG(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E
M;65N="(*;7-G<W1R("(E<R!B<G5G<V)E=&EN9V5L<V5R(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW-3`*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(SH@;&EB+U9&4R]F='`N<&AP
M.C8X,B!L:6(O5D93+V9T<"YP:'`Z-S4P(&QI8B]61E,O<VUB+G!H<#HT,S(*
M(SH@;&EB+U9&4R]S;6(N<&AP.C0Y-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@96MS:7-T97)E<B!A;&QE
M<F5D92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!V
M960@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T
M:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C
M:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R!E<B!P87)A
M="!T:6P@870@=61F^')E(&1E('9E9&QI9V5H;VQD96QS97-H86YD;&EN9V5R
M+"!S;VT@97(@;6%R:V5R970@(@HB;F5D96YF;W(N("!3YG0@:&%K('5D(&9O
M<B!D92!H86YD;&EN9V5R+"!S;VT@9'4@^&YS:V5R('5D9OAR="!N=2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P(&QI8B](;W)D92]&;W)M
M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D
M(@IM<V=S='(@(B5S(&MRYG9E="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDS"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B
M)7,@;6EN=71T97(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3,R(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("(E<R!I:VME(&9U;F1E="XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S
M(@IM<V=S='(@(B5S('1I;"`E<R!A9B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(V(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S
M<R!A9')E<W-E:V%R=&]T96LB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ."!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S<R!K86QE;F1E<B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$P(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A
M9"(*;7-G<W1R("(E<W,@;F]T97-B;&]K(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,S0@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E<W,@;W!G
M879E<B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@
M5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T
M;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@
M;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!$96YN92!B97-K960@97(@
M;75L:6=V:7,@:6MK92!F<F$@9&5N('!E<G-O;BP@<V]M(&1E;B!HYG9D97(@
M870@=N9R92`B"B)F<F$N("!6YG(@=F%R<V]M(&UE9"!A="!F^&QG92!H96YV
M:7-N:6YG97(@96QL97(@9F]R<WEN92!A9G-E;F1E<F5N(&UE9"`B"B)P97)S
M;VYL:6=E(&EN9F]R;6%T:6]N97(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY
M"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@9&ES970@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@
M(BP@8FSF<V5N9&4@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,B"FUS9W-T<B`B+"!S:W)I9G1E;F1E(&9R82`E<R!T:6P@)7,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0X(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-CD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R."!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`V.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$R."!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0X"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,CDT(&QI8B](;W)D92]097)M<R]522YP:'`Z,S0X
M"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=N9L9R`M+2(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B
M"FUS9W-T<B`B,3(M=&EM97)S(&9O<FUA="(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0M=&EM
M97)S(&9O<FUA="(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS
M9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!T:6UE<B(*"B,Z(&9R86UE=V]R
M:R]522]522]086=E<BYP:'`Z-CD@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV
M.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ&;W)E9^5E;F1E(&1A9R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!(&1A=&%B87-E
M(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@
M(D5N(&1A=&%B87-E+6)A8VME;F0@97(@:W+F=F5T(&9O<B!D96YN92!B;&]K
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<Q(&QI8B](;W)D
M92YP:'`Z,3<Q"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*
M;7-G<W1R(")$97(@97(@;W!S=.5E="!E;B!G<F%V97)E;F1E(&9E:FPB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%;B!O
M9F9E;G1L:6<@4$=0+6[X9VQE(&5R(&MRYG9E="!F;W(@870@:W)Y<'1E<F4@
M96X@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q-C@@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92XB"FUS9W-T<B`B16X@;V9F96YT;&EG(%!'4"UN^&=L92!E<B!K
M<N9V970@9F]R(&%T('9E<FEF:6-E<F4@96X@<VEG;F5R970@8F5S:V5D+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3D@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5N
M(&]F9F5N=&QI9R!01U`M;OAG;&4L('!R:79A="!01U`M;OAG;&4@;V<@970@
M;/AS96X@97(@:W+F=F5T(&9O<B!A="`B"B)D96MR>7!T97)E(&5N(&)E<VME
M9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)%
M;B!O9F9E;G1L:6<@4$=0+6[X9VQE+"!P<FEV870@4$=0+6[X9VQE(&]G(&5T
M(&SX<V5N(&5R(&MRYG9E="P@9F]R(&%T("(*(G-I9VYE<F4@96X@8F5S:V5D
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`V(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B(@HB16X@;V9F96YT;&EG(%,O34E-12UN^&=L92P@<')I=F%T(%,O
M34E-12UN^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V970L(&9O<B!A="`B"B)D
M96MR>7!T97)E(&5N(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C0S,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0S
M,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B
M"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!3+TU)344M
M;OAG;&4L('!E<G-O;FQI9R!3+TU)344M;OAG;&4@;V<@;/AS96X@97(@:W+F
M=F5T(&9O<B!A="`B"B)S:6=N97)E(&5N(&)E<VME9"XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-"!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E
M;G1L:6<@4R]-24U%+6[X9VQE(&5R(&MRYG9E="!F;W(@870@:W)Y<'1E<F4@
M96X@8F5S:V5D+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")&;W)M:61D86<@
M4VMY970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")&;W)M:61D86<@
M3&5T(%)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")&;W)M:61D86<@4F5G
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R
M"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D9O<FUI9&1A9R!">6=E<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS
M9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B1F]R;6ED9&%G(%-N96)Y
M9V5R(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)
M($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B3VT@9&5N
M;F4@<VMR:6)E;G0B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM
M<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B3VTN+BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T
M;VTB"FUS9W-T<B`B06)S8F]T=&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S
M='(@(D%B<VUI9&1L92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-S`@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D%D9V%N9R!N
MYF=T970@=F5D(&1A;FYE;'-E(&%F(%9&4RUK871A;&]G+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*
M;7-G<W1R(")!9&=A;F<@;N9G=&5T('9E9"!D86YN96QS92!A9B!61E,M9FEL
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(DMO;G1O+6EN9F]R;6%T:6]N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W
M;W)D(@IM<V=S='(@(DMO;G1O96YS(&MO9&5O<F0B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@
M9G)O>F5N+B(*;7-G<W1R(")+;VYT;R!I;F1E9G)O<W-E="XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG(@IM
M<V=S='(@(DMO;G1E<FEN9RXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$T."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T.`HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")4:6QF^&HB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R
M-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(E1I;&;X:B!U;F1E
M<F=R=7!P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.CDX(&QI8B](;W)D92]097)M<R]522YP:'`Z.3D*;7-G
M:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(E1I;&;X:B!U;F1E
M<F]R9&YE9&4@=&EL;&%D96QS92(*"B,Z('1E;7!L871E<R]P;W)T86PO861D
M+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B5&EL9OAJ(&AE<CHB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q
M.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")4:6QF^&H@;GD@9W)U
M<'!E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B
M061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(E1I;&;X:B!N>2!R971T:6=H
M960B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB
M)7-<(B(*;7-G<W1R(")4:6QF^&H@=6YD97)G<G5P<&4@=&EL(%PB)7-<(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A
M(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(E1I;&;X:B!E
M;B!U;F1E<G)E='1I9VAE9"!T:6P@7"(E<UPB(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")/<')E='1E
M(&5N(&YY(&)R=6=E<CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-34V"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B5&EL9OAJ
M(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B5&EL9OAJ(&YY
M92!M961L96UM97(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU
M"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")/<')E="!P87(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")4
M:6QF^&H@)7,M;65N=65N('-O;2!E;B!-;WII;&QA(%-I9&5B87(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D
M9')E<W,@8F]O:SHB"FUS9W-T<B`B5&EL9OAJ('1I;"!A9')E<W-E:V%R=&]T
M96LZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@
M(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B5&EL9OAJ('1I;"!M
M:70@861R97-S96MA<G1O=&5K(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G
M:60@(D%D9"!U<V5R(@IM<V=S='(@(D]P<F5T(&)R=6=E<B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(DAA
M<B!T:6QF^&IE="!<(B5S7"(@=&EL('-Y<W1E;65T+"!M96X@:W5N;F4@:6MK
M92!T:6QF^&IE(&5K<W1R82`B"B)O<'-K<FEV;FEN9W-I;F9O<FUA=&EO;CH@
M)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W
M+B(*;7-G<W1R(")4:6QF^&IE="!<(B5S7"(@=&EL('-Y<W1E;65T+B!$=2!K
M86X@;&]G9V4@:6YD(&YU+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(D]P<F5T=&5L<V4@868@8G)U9V5R92!E<B!S;.5E="!F<F$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30T,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B
M061D<F5S<R(*;7-G<W1R(")!9')E<W-E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D
M<F5S<V5K87)T;W1E:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDT"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S
M,30N<&AP.C4V(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM
M<V=S='(@(D%D;6EN:7-T<NER("T@:6YD<W1I;"!T:6QL861E;'-E<B!F;W(@
M86YD<F4@8G)U9V5R92(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R(")296ML86UE<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G:&%N:7-T
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QG97)I970B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!
M;&EA<R(*;7-G<W1R(")+86QD96YA=FXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*
M;7-G<W1R(")/<'-T:6QL:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R
M(")*=7-T97)I;F<Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS
M9VED(")!;&PB"FUS9W-T<B`B06QL92(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C`W(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`W"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H
M96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(D%L;&4@YF=T961E(&)R=6=E<F4B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(D%L;&4@9W)U<'!E<B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.CDQ(&QI8B](;W)D92]097)M<R]D871A=')E92YP:'`Z-S4*;7-G
M:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")!;&QE('1I;&QA9&5L<V5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B06QL92!F
M:7)E('-I9&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S(@IM<V=S='(@(E1I;&QA9"!M=6QT:7!L92!A9')E<W-E<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(E1I;&QA9"!A
M;F=I=F5L<V4@868@;W)D;F5T(&QI<W1E='EP93\B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0@;&EB+TAO<F1E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R
M(")%:W-I<W1E<F5R(&%L;&5R961E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B
M06QT97)N871I=B!)35-0+6QO9VEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T
M<B`B06QT97)N871I=B!)35-0+6MO9&5O<F0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*
M;7-G<W1R(")!;'1E<FYA=&EV($E-4U`M8G)U9V5R;F%V;B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA
M:6P@861D<F5S<R(*;7-G<W1R(")$:6X@92UM86EL+6%D<F5S<V4B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L
M871E<R(*;7-G<W1R(")!;'1E<FYA=&EV92!S:V%B96QO;F5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(R"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B06QT97)N871I
M=B!T96MS=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S
M='(@(D%M97)I:V%N<VL@4V%M;V$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U
M"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I
M9FEE9"XB"FUS9W-T<B`B1&5N(';F<F1I+"!D97(@8FQE=B!A;F=I=F5T+"!V
M87(@:6MK92!G>6QD:6<N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB
M"FUS9W-T<B`B1&5R(&5R(&]P<W3E970@96X@=6ME;F1T(&9E:FPN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N>6UI<V5R
M96YD92!P<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y
M"FUS9VED(")!;G-W97(B"FUS9W-T<B`B0F5S=F%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;G1A<F-T:6-A(@IM<V=S='(@(E-Y9'!O;&5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@86YD($)A
M<F)U9&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,S8@861M:6XO=&5M<&QA
M=&5S+G!H<#HW-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X
M(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T
M<B`B07!P;&EK871I;VXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*
M;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B07!P;&EK871I;VYS
M;&ES=&4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!
M<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B07!P;&EK871I;VX@97(@
M<&%R870N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G
M:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")0Y6;X<B!U;F1E
M<F1E;&EN9V5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B1V]D:V5N9"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.#0R"FUS9VED(")!<'!R;WAI;6%T92!3:7IE
M(@IM<V=S='(@(D-I<FMA<W3X<G)E;'-E(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I;"(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")!<F%B:6,@*%=I;F1O
M=W,M,3(U-BDB"FUS9W-T<B`B07)A8FES:R`H5VEN9&]W<RTQ,C4V*2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C4Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C<X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"FUS9VED
M(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")!<FMI=BUF:6QS=/AR<F5L
M<V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-2!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HU.`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HW-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-0IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D%R:VEV;F%V;B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B17(@
M9'4@<VEK:V5R('#E+"!A="!D=2!V:6P@<VQE='1E(&]P<VMR:79N:6YG<V%N
M;6]D;FEN9V5N(&9O<B`E<R`_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O
M=7!S/R(*;7-G<W1R(")%<B!D=2!S:6MK97(L(&%T(&1U(/AN<VME<B!A="!S
M;&5T=&4@7"(E<UPB(&]G(&5N:'9E<B!U;F1E<F=R=7!P93\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)M96YI96XB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB
M"FUS9W-T<B`B07)M96YS:R`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(DMU;G-T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(D%S8V5N<VEO;OAE
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(D%30TE)($%R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")!<VEA=&ES:R]S=&EL
M;&5H879S<F5G:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM
M<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(E-P^')G(&5F=&5R(&)E:W+F
M9G1E;'-E(&;X<B!U9&;X<F5L<V4@868@=F5D;&EG96AO;&1E;'-E<VAA;F1L
M:6YG97(_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S`Y-0IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS
M(@IM<V=S='(@(E1I;&1E;"!K;VQO;FYE<B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+B(*;7-G<W1R(")&;W)S^&<@<.4@870@<VQE='1E(&5N(&EK:V4M
M96MS:7-T97)E;F1E(&=R=7!P92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+B(*;7-G<W1R(")&;W)S^&<@<.4@870@<VQE='1E(&5N
M(&EK:V4M96MS:7-T97)E;F1E('1I;&QA9&5L<V4N(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")&;W)S^&<@<.4@870@YFYD
M<F4@96X@:6MK92UE:W-I<W1E<F5N9&4@=&EL;&%D96QS92XB"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B1F]R<_AG('#E(&%T
M(.9N9')E(&5N(&EK:V4M96MS:7-T97)E;F1E(&1E;&EN9RXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,2!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M,R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0IM<V=I9"`B071T
M<FEB=71E<R(*;7-G<W1R(")!='1R:6)U='1E<B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%U9W5S
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1R86QI
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`BV'-T<FEG(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V."!L:6(O2&]R
M9&4O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]C>7)S<6PZ($MRYG9E="!)34%0+75D=FED9&5L<V4@:6MK92!F=6YD970N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS
M9W-T<B`B075T:%]C>7)U<SH@0F%C:V5N9"!H87(@:6MK92!D92!N^&1V96YD
M:6=E(&5V;F5R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$R,B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?8WER=7,Z($MRYG9E="!)34%0+75D=FED9&5L<V4@:6MK
M92!F=6YD970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V
M(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P
M.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!0
M2%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B
M(@HB075T:%]F='`Z($MRYG9E="!&5%`M=61V:61D96QS92!I:VME(&9U;F1E
M="X@3W9E<G/F="!02%`@;65D("TM96YA8FQE+69T<"TB"B)F;&%G970N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-"!L:6(O2&]R9&4O
M075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@
M2W+F=F5T($E-05`M=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q(&QI8B](;W)D92]!=71H+VMR
M8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!+<N9V970@
M2U)"-2UU9'9I9&1E;'-E(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S`R(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H
M7VQD87`Z(%1I;&;X:F5L<V4@8G)U9V5R92!E<B!I:VME('5N9&5R<W3X='1E
M="!F;W(@06-T:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S4W(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,U-PIM
M<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A
M<#H@4VQE=&YI;F<@868@8G)U9V5R92!E<B!I:VME('5N9&5R<W3X='1E="!V
M960@06-T:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-C,@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@
M(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VQD87`Z($MRYG9E="!,1$%0+75D=FED9&5L<V4@
M:6MK92!F=6YD970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS,SD@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L
M9&%P.B!+=6YN92!I:VME('1I;&;X:F4@8G)U9V5R("5S+B!397)V97)E;B!S
M86=D93H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S
M='(@(D%U=&A?;&1A<#H@2V%N(&EK:V4@<VQE='1E(&)R=6=E<B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD
M87`Z($MA;B!I:VME(&]P9&%T97)E(&)R=6=E<B`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B
M"B)!=71H7VQD87`Z($]P9&%T97)I;F<@868@8G)U9V5R92!E<B!I:VME('5N
M9&5R<W3X='1E="!V960@06-T:79E($1I<F5C=&]R>2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VUC86PN<&AP.C0V(&QI8B](;W)D92]!=71H+VUC86PN
M<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!+<N9V970@34-!
M3"UU9'9I9&1E;'-E(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<#HV,"!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P"FUS
M9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!+<N9V970@4TU"
M05542"UU9'9I9&1E;'-E(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O061M:6XN<&AP.C$P-B!L:6(O2&]R9&4O24U!4"]!9&UI;BYP
M:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(L9G=&YI;F<@=F5D($E-05`M<V5R=F5R(&9E:FQE
M9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDP"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BQF=T
M;FEN9R!F96IL961E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-S8*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,B"FUS9W-T<B`BQF=T;FEN9R!F96IL961E+B`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8@;&EB+TAO<F1E+T%U=&@O
M<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(L9G=&YI;F<@869V:7-T(&%F
M(%)!1$E54RUS97)V97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX.#(@;&EB+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(L9G=&YI;F<@;W9E
M<F9O<B!&5%`M<V5R=F5R(&9E:FQE9&4N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HW,"!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
MQF=T;FEN9R!O=F5R9F]R(%--0BUS97)V97(@9F5J;&5D92XB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE
M;&1S.B(*;7-G<W1R(")&96QT97(@=&EL('+E9&EG:&5D.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!<V5R8F%I9&IA;B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM
M<V=S='(@(D)/1D@M=6YD<VMY;&1N:6YG97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K
M9W)O=6YD(@IM<V=S='(@(D)A8VMG<F]U;F0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD
M($-O;&]R(@IM<V=S='(@(D)A9V=R=6YD<V9A<G9E(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,2!L:6(O2&]R9&4O075T:"]K<F(U+G!H
M<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")$
MY7)L:6=T(&ME<F)E<F]S+6MO9&5O<F0N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,R!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM
M<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")$Y7)L:6=T
M(&ME<F)E<F]S+6)R=6=E<FYA=FXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C0U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S
M(@IM<V=S='(@(D)A:&%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS."!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G
M<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I:W5M("A)
M4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T
M<B`B0F%N9VQA9&5S:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T
M<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0F%S:7,@9W)A9FEK:V%T86QO9R!<
M(B5S7"(@:6MK92!F=6YD970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"FUS9VED(")"87-E;&EN92(*;7-G
M<W1R(")"87-I<VQI;FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S
M='(@(DAV:61E<G5S;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G
M<W1R(")"96QG:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B
M0F5L:7IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB
M"FUS9W-T<B`B1OAD<V5L<V1A9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS-C<@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@
M;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0FQO
M:R!<(B5S7"(@868@87!P;&EK871I;VX@7"(E<UPB(&EK:V4@9G5N9&5T+B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO
M8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO:RUE9V5N<VMA8F5R(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E
M(@IM<V=S='(@(D)L;VMT>7!E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(D9E9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VQI=FEE;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K
M<R(*;7-G<W1R(")";V=MYG)K97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS
M9W-T<B`B4F%N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@
M(E)A;6UE='EK:V5L<V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R
M(")286YD92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN
M82(*;7-G<W1R(")";W-N:65N(&]G($AE<GIE9V]V:6YA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D)E9V=E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0X(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=F%N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,@IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)U;F0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T^&5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL:65N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R
M(")"<FET:7-K+4EN9&EE;B!/8V5A;F]M<N5D92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEE;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*
M;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B4'5N:W1L:7-T92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM
M<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S4@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G
M:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y."!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y
M.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),
M(&1I<W1R:6)U=&EO;G-S=&5D97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B0V5L;&4M96=E;G-K86)E<BXN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE
M(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DEN:71I86QI<V5R
M:6YG(&%F(&UI9&QE<G1I9&EG="!L86=E<B!I:VME(&;F<F1I9V=J;W)T+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,38*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,38@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,"!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+
M86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*
M;7-G:60@(D-A;&TB"FUS9W-T<B`B5FEN9'-T:6QL92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;V1I82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V%M97)O;VXB"FUS9W-T<B`B0V%M97)O=6XB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B2V%N(&EK:V4@;G5L<W1I;&QE(&MO9&5O<F0@875T;VUA
M=&ES:SL@:V]N=&%K="!D:6X@861M:6YI<W1R871O<BXB"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`@;&EB+T9I;&4O0U-6+G!H<#HS-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB
M)7-<(B(*;7-G<W1R(")+86X@:6MK92!S:W)I=F4@=&EL(&9I;"!<(B5S7"(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN
M:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B2V%N
M(&EK:V4@:.5N9'1E<F4@96MS=&5R;F4@<V5S<VEO;G-HY6YD=&%G+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G-Q;"YP:'`Z,S$Y(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,B"FUS9W-T<B`B2V%N(&EK:V4@9F]R8FEN9&4@=&EL($E-05`@<V5R
M=F5R+B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-B!L
M:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92#E8FYE(&9I
M;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B0V%N
M861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$Q"FUS9VED(")#86YC96PB"FUS9W-T<B`B06YN
M=6QL97(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM
M<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%F8G)Y9"!R
M97!O<G1E<FEN9R!A9B!P<F]B;&5M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,C,@;&EB+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+
M86X@:6MK92!S;&5T=&4@9FEL(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C4R"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*;7-G
M:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B2V%N(&EK:V4@9FEN9&4@970@;6ED;&5R=&ED:6=T(&MA=&%L;V<N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,2!L
M:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B2V%N
M(&EK:V4@9F]R='/F='1E('5D96X@)W1A<F=E=$9I;&4G+7!A<F%M971R96XN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3D@;&EB+U9&4R]F
M='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(&9J97)N92!K
M871A;&]G(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HV.#`*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,C@@;&EB+TAO<F1E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")+86X@
M:6MK92!F:F5R;F4L("5D(&+X<FX@96MS:7-T97)E<BXB"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@@;&EB+TAO<F1E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB2V%N(&EK
M:V4@;VUF;W)D96QE.R!A;G1A;&QE="!A9B!P=6YK=&5R(&%N9VEV970@=&EL
M(&]M9F]R9&5L:6YG('-V87)E<B!I:VME("(*(G1I;"!D970@;W!B979A<F5D
M92!A;G1A;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#D*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N(@IM<V=S='(@(DMA;B!I:VME(&1I<FEG97)E(&)E<VME
M9"!T:6P@86YG:79N92!N=6UM97(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E
M<F1E(@IM<V=S='(@(DMA<"!697)D92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB
M"FUS9W-T<B`B0FEL;&5D=&5K<W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#0@;&EB+TYE="]335,O9V5N97)I8U]S
M;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B561B>61E<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE
M<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G;W)I97(@;V<@3>9R:V5R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(D-A>6UA
M;OAE<FYE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")-;V)I;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G
M:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")#96QL92UE9V5N<VMA8F5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B0V5L;&5F;W)R:6YG
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")#96QL
M92UE9V5N<VMA8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B
M0V5L;&4M;65L;&5M<G5M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-S0@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N
M92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B
M2V5L=&ES:R`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM
M<V=S='(@(D-E;G1RZ7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A
M;B!297!U8FQI8R(*;7-G<W1R(")$96X@8V5N=')A;&%F<FEK86YS:V4@4F5P
M=6)L:6LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N
M=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B0V5N=')A;"UE
M=7)O<.9I<VL@*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW
M,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B0V5R=&EF
M:6MA="UD971A;&IE<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C$R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED
M(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")#97)T:69I:V%T+65J97(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-R!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@
M4&]L:6-I97,B"FUS9W-T<B`B0V5R=&EF:6MA="UP;VQI=&EK:V5R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")48VAA9"(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("+&;F1R92(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E
M(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BQFYD<F4@9&ET(&MO9&5O<F0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B
M"B)(97(@:V%N(&1U(.9N9')E(&1E="!N879N(&]G(&1E;B!A9')E<W-E+"!S
M;VT@86YD<F4@<V5R+"!NY7(@9&4@;.9S97(@;V<@(@HB<W9A<F5R('#E(&1I
M;F4@92UM86EL+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR
M-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P
M<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)+;V1E;W)D
M<^9N9')I;F<@97(@:6MK92!U;F1E<G-T^'1T970@868@9&5N(&YU=N9R96YD
M92!O<'/F=&YI;F<N("!+;VYT86MT("(*(F1I;B!A9&UI;FES=')A=&]R+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B5&5G;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I
M9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B2&%K(&QI;FL@868N+BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EN82(*;7-G<W1R(")+:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#,*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*
M;7-G<W1R(")3:6UP;&EF:6-E<F5T(&MI;F5S:7-K("A'0C(S,3(I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I(@IM<V=S='(@(E1R861I=&EO;F5L="!K:6YE<VES:R`H
M0FEG-2DB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#
M:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(E;F;&<@87!P;&EK871I;VXZ
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,"!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S
M<W=O<F0B"FUS9W-T<B`B5N9L9R!E="!K;V1E;W)D(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.2!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B
M5N9L9R!E="!B<G5G97)N879N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G
M<W1R(")6YFQG(&AV;W)D86X@9&%T;V5R('-K86P@=FES97,Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I(@IM<V=S='(@(E;F;&<@;&ES=&4M<W1I;"`H9F]R(&]R9&YE9&4@
M;&ES=&5R*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G
M<W1R(")*=6QE^&5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDQ-"!F
M<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!L:6(O5D93+G!H<#HY,30*
M(SH@;&EB+TYE="]335,N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B2VQA
M<W-E9&5F:6YI=&EO;B!A9B`E<R!I:VME(&9U;F1E="XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B
M"FUS9W-T<B`B2VQA<G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM
M<V=S='(@(D9J97)N($U33V9F:6-E+6]P;>9R:VYI;F=E<B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@
M(DYU;'-T:6P@9F]R97-P^')G<V5L(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T
M('5S97(Z("5S(@IM<V=S='(@(E)E;G,@8G)U9V5R('5D.B`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@
M=7-E<B(*;7-G<W1R(").=6QS=&EL(&)R=6=E<B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B
M"FUS9W-T<B`B5FES:R!B<G5G97)D871A('5D(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA
M=&4B"FUS9W-T<B`B4V5N(&]P:VQA<FEN9R(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#
M;VYT:6YU92(*;7-G<W1R(")+;&EK(&9O<B!A="!F;W)T<^9T=&4B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@
M(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!V:6$@
M2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S
M='(@(DQU:R!V:6YD=64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM
M<V=I9"`B0VQO=61S(@IM<V=S='(@(E-K>65R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L
M>2(*;7-G<W1R(")3:WEE<B!T:61L:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R
M(")3:WEE="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',B"FUS9W-T<B`B0V]C;W,@*$ME96QI;F<I(-AE<FYE(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED
M96)A<B(*;7-G<W1R(")&;VQD('-I9&5P86YE;"!S86UM96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS
M9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")386UM96YF;VQD961E
M(')A;F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8R(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU
M;6)I96XB"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B1F%R=F4B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S@*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S(&QI8B](
M;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S@*(SH@;&EB+TAO<F1E+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C,S.2!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B1F%R
M=F5VYFQG97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X(&QI
M8B](;W)D92]&;W)M+G!H<#HR.#(X"FUS9VED(")#;VQO=7(@<V5L96-T:6]N
M(@IM<V=S='(@(D9A<G9E=F%L9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")+
M;VQS.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T
M<B`B2V]L;VYN971I=&QE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")496=N97-E<FEE<B(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R
M(")+;VUM86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B
M0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")+;VUM86YD;VQI;FEE(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUM96YT
M87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-R!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B0V]M;6]N($YA;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M
M;W)O<R(*;7-G<W1R(")#;VUO<F5R;F4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D9I
M<FUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP
M=71E<G,B"FUS9W-T<B`B0V]M<'5T97)E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(D9O
M<FAO;&0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U-@IM<V=I9"`B0V]N
M9&ET:6]N<R(*;7-G<W1R(")"971I;F=E;'-E<B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M(@IM<V=S='(@(DMO;F9I9W5R871I;VYS9F]R<VME;&QE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@
M<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*
M;7-G<W1R(")+;VYF:6=U<F%T:6]N('1I;"!S>6YK<F]N:7-E<FEN9R!M960@
M4$1!97(L(%-M87)T<&AO;F5S(&]G($]U=&QO;VLN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92XB"FUS9W-T<B`B2V]N9FEG=7)A=&EO;F5N(&5R(&9O<N9L9&5T
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(DMO;F9I9W5RZ7(@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED
M(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D)E:W+F9G0@:V]D96]R9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B
M"FUS9W-T<B`B2V]N9V\L($1E;B!D96UO:W)A=&ES:V4@<F5P=6)L:6LB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960N(@IM<V=S='(@(D9O<F)I;F1E;'-E(&UI<VQY:VME9&5S+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@
M(@IM<V=S='(@(D9O<F)I;F1E;'-E(&UI<VQY:VME9&5S.B`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D9O<F)I;F1E;'-E('1I;"!O
M9F9E;G1L:6<@;OAG;&5S97)V97(@;N9G=&5T+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS
M9W-T<B`B1F]R8FEN9&5L<V4@=&EL(&]F9F5N=&QI9R!N^&=L97-E<G9E<B!N
MYF=T970N(,5R<V%G.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX-S8@;&EB+U9&4R]F='`N<&AP.C@W-@IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1F]R8FEN9&5L
M<V4@=&EL($944"US97)V97(@;6ES;'EK:V5D97,N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,C0@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C0*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S
M(@IM<V=S='(@(DMO;G1A:W1E<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HU,R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K=&5R
M(&)L978@=&EL9OAJ970@=&EL(&1I="!A9')E<W-E:V%R=&]T96ME="(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP
M92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("));F1H;VQD<W1Y<&4@
M868@:V]M<')I;65R970@9FEL.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU-@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW-2!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT
M96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B26YD:&]L9"!A9B!<(B5S7"(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(D9O
M<G1SYG0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#
M;V]K($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G
M:60@(D-O;VMI92(*;7-G<W1R(")3;>5K86=E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#
M;W!Y(@IM<V=S='(@(DMO<&EE<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#<R(&QI8B]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(DMO<&EE<FEN9R!M:7-L
M>6MK961E<SH@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+
M;W!IZ7(@;6%R:V5R:6YG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ.34@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM
M<V=S='(@(D=E8GER($E$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM
M<V=S='(@(D-O<W1A(%)I8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I
M<F4B"FUS9W-T<B`B16QF96YB96YS:WES=&5N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z.3<W(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*
M;7-G<W1R(")+=6YN92!I:VME(%!'4"UK<GEP=.ER92!B97-K960Z("(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4Z("(*;7-G<W1R(")+=6YN92!I:VME(%!'4"US:6=NZ7)E(&)E
M<VME9#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.3,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(")+=6YN92!I
M:VME(%,O34E-12UK<GEP=&5R92!B97-K960N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E
M+B(*;7-G<W1R(")+=6YN92!I:VME(%,O34E-12US:6=NZ7)E(&)E<VME9"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B2W5N;F4@:6MK92!T:6QF^&IE(&MO;G1A:W0N("5S(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HY-B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0X,@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@:V]B;&4@=&EL($Q$
M05`M<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$W,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$U-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA
M;F-E+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&MO;G1R;VQL97(@8F%L86YC
M92X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8V"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N
M;F4@:6MK92!F;W)B:6YD92!T:6P@3$1!4"US97)V97(N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*
M;7-G<W1R(")+=6YN92!I:VME(&9O<F)I;F1E('1I;"!S97)V97(@7"(E<UPB
M('9E9"!B<G5G(&%F($944#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMU
M;FYE(&EK:V4@;W!R971T92!D:7-T<FEB=71I;VYS;&ES=&4N("5S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R."!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T83H@(@IM<V=S='(@(DMU;FYE(&EK:V4@9&5K<GEP=&5R92!01U`M
M9&%T83H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M,C,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(")+=6YN92!I:VME
M(&1E:W)Y<'1E<F4@4R]-24U%+61A=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMU;FYE(&EK
M:V4@<VQE='1E(&MO;G1A:W0N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+
M=6YN92!I:VME('-L971T92!D:7-T<FEB=71I;VYS;&ES=&4N("5S(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S
M7"(N(@IM<V=S='(@(DMU;FYE(&EK:V4@<VQE='1E(#QE;3YS8W)I<'0\+V5M
M/B!<(B5S7"(@=&EL(&]P9W)A9&5R:6YG(&%F(&]P<^9T;FEN9RXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HS.#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED
M(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!B97-T96UM92!M;V1T86=E
M<F5N<R!E+6UA:6PM861R97-S92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E
M(&AE;&4@861R97-S96MA<G1O=&5K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B2W5N;F4@:6MK
M92!H96YT92!H96QE(&1I<W1R:6)U=&EO;G-L:7-T92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E(&9U;&1S=.9N9&EG(&9O
M<G1E9VYE;'-E(&]V97(@9&ES=')I8G5T:6]N<VQI<W1E<BXB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T
M<B`B2W5N;F4@:6MK92!H96YT92!S=')A=&5G:2!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP
M:'`Z,S`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M
M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:V4@;6MD:7(@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.2!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@:&5N=&4@;V9F96YT;&EG(&[X9VQE(&9R82!N^&=L97-E<G9E
M<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N
M(@IM<V=S='(@(DMU;FYE(&EK:V4@Y6)N92!<(B5S7"(@9F]R('-K<FEV;FEN
M9RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-C(@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-2!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(")+=6YN92!I:VME(.5B;F4@)7,N
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT
M,C`@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92#E8FYE(&UO9'5L('1I;"!V961L
M:6=E:&]L9&5L<V4@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92#E8FYE(&MA=&%L;V<@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-#0*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HU
M,38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV
M.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@;N4@3$1!4"US97)V97)E;BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T,"!L:6(O5D93+T]B:F5C="YP
M:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S
M+B(*;7-G<W1R(")+=6YN92!I:VME(&SF<V4@)7,N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)+=6YN92!I:VME(&YU
M;'-T:6QL92!K;V1E;W)D970@9F]R(&1E;B!A;FUO9&5D92!B<G5G97(N("!.
M;V=L92!E;&QE<B!A;&QE("(*(F1E=&%L:F5R(&5R('5K;W)R96MT92X@4'+X
M=B!I9V5N(&5L;&5R(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(L(&AV:7,@
M9'4@(@HB:&%R(&)E:&]V(&9O<B!Y9&5R;&EG97)E(&AJYFQP+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<U"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S,X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-S4*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@04-,
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR-S0*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S
M<R!B;V]K+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E(&%D<F5S<V5K
M87)T;W1E:V5T+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#@T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+=6YN92!I
M:VME(&AE;G1E(&1I<W1R:6)U=&EO;G-L:7-T92X@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N
M("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@9&ES=')I8G5T:6]N<VQI
M<W1E<BX@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R,2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")+=6YN92!I:VME
M(&AE;G1E('-E<G9E<G,@979N97(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(DMU;FYE(&EK:V4@9V5N9&%N;F4@:V]N9FEG=7)A=&EO;BXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!R;61I<B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!G96UM92`E<RUK
M;VYF:6=U<F%T:6]N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@
M9V5M;64@96X@8F%C:W5P+6MO;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B2W5N
M;F4@:6MK92!G96UM92!E;B!B86-K=7`M:V]N9FEG=7)A=&EO;CH@)7,B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(&=E;6UE('-C<FEP="!T:6P@
M;W!G<F%D97)I;F<@868@;W!SYG1N:6YG('1I;#H@7"(E<UPB+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@9V5M;64@8F%C:W5P+6MO;F9I9W5R
M871I;VYS9FEL96X@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"B)+=6YN92!I:VME(&=E;6UE(&MO;F9I9W5R871I;VYS9FEL96X@
M)7,N($1U(&MA;B!E;G1E;B!A;G9E;F1E(&5N(&%F("(*(FUU;&EG:&5D97)N
M92!F;W(@870@9V5M;64@:V]D96X@=&EL8F%G92!PY2`E<R!E;&QE<B!M86YU
M96QT(&MO<&EE<F4@:V]D96X@(@HB;F5D96YF;W(@=&EL("5S+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@<_AG92!,1$%0+7-E<G9E
M<F5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B
M2W5N;F4@:6MK92`\96T^=6YL:6YK/"]E;3X@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R
M(")+=6YN92!I:VME(&]P9&%T97)E(&MO;G1A:W0N("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(")+=6YN92!I:VME(&]P9&%T97)E(&1I<W1R:6)U=&EO;G-L
M:7-T92X@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!S:W)I=F4@:V]N
M9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S
M='(@(DMU;FYE(&EK:V4@9FEN9&4@36]Z:6QL82!3:61E8F%R+B!&;W)V:7,@
M9&EG(&]M(&%T('-I9&5B87)E;B!E<B#E8F5N+B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-"!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O
M=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@
M9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B)+=6YN92!I
M:VME(&=I=F4@8G)U9V5R(%PB)7-<(B!F^&QG96YD92!R971T:6=H961E<B!T
M:6P@;6%P<&5N(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N
M=&5D('1E>'0B"FUS9W-T<B`B3W!T86QT('1E:W-T(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B3&%N9"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S97,B
M"FUS9W-T<B`B2W5R<V5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS
M9W-T<B`B3W!R970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS
M9W-T<B`B3W!R970@96X@:&5N=FES;FEN9R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O
M;F4B"FUS9W-T<B`B3W!R970@96X@;GDB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU,B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3(*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR
M"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B3W!R970@=6YD
M97)M87!P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E-K86)E<G,@<F5T=&EG:&5D97(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C$R(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C$R"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B2W)E
M9&ET:V]R="UN=6UM97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G
M<W1R(")+<F]A=&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")#
M=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT
M(#0@4&AA<V5S(@IM<V=S='(@(DYU=N9R96YD92`T(&9A<V5R(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM
M<V=S='(@(DEN9&5VYG)E;F1E('-E<W-I;VXB"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@
M5&EM92(*;7-G<W1R(")!:W1U96P@=&ED(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R
M96YT(%523"!I<R(*;7-G<W1R(").=7;F<F5N9&4@55),(&5R(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S
M='(@(DYU=N9R96YD92!B<G5G97)E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(D%K='5E;'0@
M=F5J<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G
M:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B3G5VYG)E;F1E('9E
M:G(Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B06MT=65L('-T
M:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RXB"FUS9W-T<B`B5&EL<&%S(&]P9V%V97(L(&1E<B!B;&EV97(@=61F
M^')T+"!NY7(@9'4@;&]G9V5R(&EN9"!I("5S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B
M0W5T(@IM<V=S='(@(DML:7`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S
M='(@(DML:7`@=F%L9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@
M(D-Y<&5R;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#
M>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+>7)I;&QI<VL@*$M/23@M4BDB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@
M*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B2WER:6QL:7-K("A7:6YD;W=S+3$R
M-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")+>7)I;&QI<VLO56MR
M86EN<VL@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC
M(@IM<V=S='(@(E1J96MK:65T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-S(@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S(*;7-G:60@(B(*(D133B`H
M<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.("AS964@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S
M92YD8BYI;G1R;RUD<VXN<&AP*2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3D@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&%G;&EG(@H*(SH@861M:6XO
M9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S
M='(@(D1A=&%4<F5E('-T:69I;F1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R-S`@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S`*;7-G:60@(D1A
M=&%B87-E($QO;VMU<"(*;7-G<W1R(")$871A8F%S92UO<'-L86<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3@*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S.3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G
M:60@(D1A=&4B"FUS9W-T<B`B1&%T;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S
M='(@(DUO9'1A9V5L<V5S9&%T;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(W.#D@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.#D*;7-G:60@(D1A=&4@
M<V5L96-T:6]N(@IM<V=S='(@(D1A=&]V86QG(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B1&%G(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED
M(")$95]L971E($-O;'5M;B(*;7-G<W1R(")3;&5T(&MO;&]N;F4B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,R!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM
M<V=S='(@(D1E8V5M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB
M97)S(@IM<V=S='(@(D1E8VEM86QT86PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E
M;G0B"FUS9W-T<B`B36EN9'-K(&EN9')Y:VYI;F<B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PIM<V=I9"`B1&5F875L="(*;7-G
M<W1R(")3=&%N9&%R9"(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@
M(E-T86YD87)D9F%R=F4B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.CDV(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E
M9F%U;'0@261E;G1I='DB"FUS9W-T<B`B4W1A;F1A<F0M:61E;G1I=&5T(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<U"FUS9VED(")$969A=6QT(%-H
M96QL(@IM<V=S='(@(E-T86YD87)D+7-K86PB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN
M:71I;VYE<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HT,C(*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY."!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS,0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*
M;7-G:60@(D1E;&5T92(*;7-G<W1R(")3;&5T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$
M96QE=&4@0V5L;"(*;7-G<W1R(")3;&5T(&-E;&QE(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T
M92!'<F]U<"(*;7-G<W1R(")3;&5T(&=R=7!P92(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R
M(")3;&5T(&QO9V)O9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4VQE="!T
M:6QL861E;'-E<B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDS(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM
M<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")&:F5R
M;B!O9R!U9'-L970@8F5S:V5D97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L
M;"(*;7-G<W1R(")3;&5T(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O
M;'5M;B(*;7-G<W1R(")3;&5T(&MO;&]N;F4B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R(")3;&5T(&5K<VES=&5R96YD92P@86QT97)N871I
M=F4@<VMA8F5L;VXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HU-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*
M;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R(")3;&5T(&)E<VME9&5R
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B4VQE="!T:6QL
M861E;'-E<B!F;W(@7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C0@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E-L970@=&EL;&%D
M96QS97(@9F]R(%PB)7-<(B!O9R!A;&QE('5N9&5R;W)D;F5D92!T:6QL861E
M;'-E<C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(E-L970@
M<N9K:V4B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC
M.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M4VQE="!V86QG=&4@:61E;G1I=&5T(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3,@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S
M,30N<&AP.C4S"FUS9VED(")$96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B
M4VQE="!U;F1E<FUA<'!E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;B(*;7-G<W1R(")3;&5T(&1E;B!A:W1U96QL92!K;VQO
M;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM
M<V=S='(@(E-L970@9&5N(&%K='5E;&QE('+F:VME(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(D]P9W)A
M9&5R:6YG<W-C<FEP="!<(B5S7"(@<VQE='1E="XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("),
M979E<FEN9W-T:61S<'5N:W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS
M9W-T<B`B1&%N;6%R:R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")"
M97-K<FEV('!R;V)L96UE="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDS."!L:6(O2&]R9&4O1F]R;2YP:'`Z.3,X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R
M:7!T:6]N(@IM<V=S='(@(D)E<VMR:79E;'-E(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HR,#8@;&EB+TAO<F1E+G!H<#HR,#8*;7-G:60@(D1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T
M86QJ97(@*&]G<^4@:2!(;W)D92=S(&QO9V9I;"DZ(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HR,3`@;&EB+TAO<F1E+G!H<#HR,3`*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(D1E=&%L:F5R(&5R('-K<F5V970@=&EL(&QO9V)O9V5N
M(&%F(&AE;G-Y;B!T:6P@861M:6YI<W1R871O<F5N+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S
M='(@(E5D=FEK;&EN9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS
M9VED(")$97<@4&]I;G0B"FUS9W-T<B`B1'5G<'5N:W0B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO
M=7(Z("(*;7-G<W1R(")$=6=P=6YK="!F;W(@<VED<W1E('1I;64Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E=R!P
M;VEN=#H@(@IM<V=S='(@(D1U9W!U;FMT.B`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H="(*;7-G<W1R(")2971N:6YG('9E;G-T<F4@=&EL(&CX
M:G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B
M4F5T;FEN9R!H^&IR92!T:6P@=F5N<W1R92(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B5FES('1I9"!M960@,C0@=&EM97(_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA
M>2!/<'1I;VYS(@IM<V=S='(@(DEN9'-T:6QL:6YG97(@9F]R('9I<VYI;F<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B5FES('5D9'EB96YD
M92!V96IR=61S:6=T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I
M9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")6:7,@=F5J<G5D
M<VEG="`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3D@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3D*;7-G:60@(D1I<W!L87D@9F]R;6%T
M(@IM<V=S='(@(E9I<VYI;F=S9F]R;6%T(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-1$XN<&AP.C$Y,2!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,0IM
M<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D]V97)D
M<F%G96QS97-N;W1I=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S
M='(@(D1J:6)O=71I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO
M="!D96QE=&4B"FUS9W-T<B`B1F]R=')Y9"!S;&5T;FEN9R(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B1'4@;>4@:6MK92!K
M86QD92!M86EN=&5N86YC92YP:'`@9&ER96MT92(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(DEN
M9&5H;VQD97(@9&5N(&;X<G-T92!RYFMK92!F96QT;F%V;F4_($AV:7,@:F$L
M(&UA<FOI<B!D96YN92!B;VMS.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B
M"FUS9W-T<B`B1&5N(&1O;6EN:6MA;G-K92!297!U8FQI:R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1E;B!D;VUI;FEK
M86YS:V4@4F5P=6)L:6LB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM
M<V=S='(@(DAA<B!D=2!I:VME(&YO9V5N(&MO;G1O/R!-96QD(&1I9R!T:6PN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4S(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3,*;7-G:60@(D1O=VYL;V%D
M(@IM<V=S='(@(DAE;G0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-3,@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R(")(96YT
M("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB
M"FUS9W-T<B`B2&5N="!G96YE<F5R970@:V]N9FEG=7)A=&EO;B!N960@<V]M
M(%!(4"US8W)I<'0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P
M-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI
M<W0B"FUS9W-T<B`B4G5L;&5G87)D:6XM;&ES=&4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(DUE9&EK86UE
M;G1E<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,R!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G
M<W1R(")%+6UA:6PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDR
M"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R
M:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@HB
M14UA:6PM=&EL+5--4R!G871E=V%Y+61R:79E<BP@9F]R(&]P97)A=/AR97(L
M('-O;2!U9&)Y9&5R(&1E;FYE('-E<G9I8V4N(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5C=6%D;W(B"FUS9W-T<B`B17%U861O<B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(U(&QI8B](;W)D92]097)M<RYP:'`Z,S(U"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I
M="(*;7-G<W1R(")2961I9V5R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU,"!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P"FUS9VED(")%
M9&ET($)L;V-K(@IM<V=S='(@(L9N9')E(&)L;VLB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'
M<F]U<"(*;7-G<W1R("+&;F1R92!G<G5P<&4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,3`P"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S8@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G
M<W1R("+&;F1R92!T:6QL861E;'-E(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("+&
M;F1R92!T:6QL861E;'-E<B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`BQFYD<F4@=&EL;&%D96QS97(@9F]R("5S(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS
M(&9O<CHB"FUS9W-T<B`BQFYD<F4@=F%L9R!F;W(Z(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(L9N9')E('1I;&QA9&5L<V5R(&9O<B!<(B5S
M7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@
M(L9N9')E('1I;&QA9&5L<V5R(&9O<B`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(E5D9&%N;F5L
M<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW
M,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(L9G>7!T96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV
M861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M
M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#8Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#8Y(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I
M;"(*;7-G<W1R(")E36%I;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R(")E+6UA:6PM861R97-S92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C,*;7-G:60@
M(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%+6UA:6PM
M861R97-S97(@<VMA;"!P87-S92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3@Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%+6UA:6P@;65D(&)E:W+F
M9G1E;'-E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3$@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B16UA:6PM=&\M4TU3
M($=A=&5W87DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,CDY"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")3;6EL97ES(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")4;VT@8F5S:V5D+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T,PHC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-#@T(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<P-2!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B26YT
M970@<F5S=6QT870N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$Q,R!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@
M(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")4;VUT('5D=')Y:R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(D%K=&EVZ7(@:6YD<^9T=&5L<V4@868@8FEL;&5D97(@9G)A
M($9O=&]G86QL97)I97(@:2!T96MS=#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/R(*;7-G<W1R(")!:W1I=NER(&CX:G)E+6ML:6L@8V]N=&5X="UM96YU
M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C<Y,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X
M."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,PIM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B4VQU="WE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(D9O<G-T^'(@961I=&5R:6YG<W;F<FMT^&HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB26YD=&%S="!E="!S:6MK97)H
M961S<W#X<F=S;>5L+"!S;VT@9'4@=FEL(&)L:79E('-P=7)G="P@;N5R(&1U
M(&AA<B!B<G5G(&9O<B`B"B)A="#F;F1R92!D:70@:V]D96]R9"P@9G@@)VAV
M860@97(@9&ET(&OF;&5D>7)S(&YA=FX_)SHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*;7-G:60@
M(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("));F1T87-T(%52
M3"!T:6P@8FEL;&5D(&AE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX.3(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z
M(@IM<V=S='(@(DEN9'1A<W0@8F]G<W1A=F5R(&YE9&5N9F]R.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`BQFMV871O<FEA
M;"!'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`BQG)I
M=')E82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]6:65W+G!H<#HY-`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`IM<V=I9"`B17)R;W(B
M"FUS9W-T<B`B1F5J;"(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-#8S(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R
M(")&96IL('9E9"!D86YN96QS92!A9B!B;&]K.B`E<R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")&96IL('5N
M9&5R('-L971N:6YG(&%F('-Y;F,M:.9G=&4Z("5S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(D9E:FP@=6YD97(@
M<VQE=&YI;F<@868@<WEN8R!L;V<Z("5S(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HT-C@@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<R(*;7-G<W1R(")&96IL('5N9&5R(&AE;G1N:6YG(&%F(&EN9&AO;&0Z
M("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*
M;7-G<W1R(")&96IL('5N9&5R(&]P9&%T97)I;F<@868@:V]D96]R9#H@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#4*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*
M;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B1F5J
M;"!F;W)B=6YD970@;65D(&4M<&]S="!B97-K960N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$T,@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D9E:FP@=6YD97(@<VMR:79N:6YG
M(&%F(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HW-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S8@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B
M17-T;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`BQG1I
M;W!I96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T
M:&YI8R(*;7-G<W1R(")%=&YI<VLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D5U<F]P92(*;7-G<W1R(")%=7)O<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DAV
M97(@:W9A<G1E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")(=F5R="`R+B!M:6YU="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")(
M=F5R(&AA;'9E(&UI;G5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI
M;G5T97,B"FUS9W-T<B`B2'9E<B`U+B!M:6YU="(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`@;&EB+TAO<F1E+TUA:6YT
M96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B06QT
M:60@=F5D(&QO9VEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM
M<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(DAV97(@:&%L=F4@=&EM
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(DAV
M97(@;6EN=70B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM
M<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(D5K<V5M<&5L=N9R9&EE
M<CHB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M:6XO<&AP<VAE;&PN
M<&AP.C@R(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B
M"FUS9W-T<B`B561F^'(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8Q-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HT-S4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")59'9I9"(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R
M(@IM<V=S='(@(D9O;&0@<VED97!A;F5L('5D(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$V."!L:6(O2&]R9&4O4U%,+TME>7=O<F1S
M+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")&;W)V96YT
M961E("<I)R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-S4@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(D9O<G9E;G1E9&4@<F5N="!O<F0@96QL97(@8VET97)E="!S^&=E=&5R;2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*
M;7-G<W1R(")&;W+F;&1E;'-E<V1A=&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8W-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B16MS<&]N96YT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B1D<M9F%R=F4B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E
M='5P(@IM<V=S='(@(D944"UL86=R:6YG(&%F(&]P<^9T;FEN9R(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(R,"!L:6(O2&]R9&4O4')E
M9G,O<W%L+G!H<#HR,C`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+B(*;7-G<W1R(")+=6YN92!I:VME(.9N9')E(&EN9'-T:6QL:6YG
M97)N92XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3@*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(")+=6YN92!I:VME(&;E(&9O<F)I;F1E;'-E('1I;"!,1$%0('-E<G9E
M<F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY."!L:6(O
M2&]R9&4O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&9O<F)I;F1E
M('1I;"!334(M<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S$W(&QI8B]61E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D9E:FP@
M=6YD97(@:V]P:65R:6YG(&9R82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW,C(@;&EB+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S
M='(@(DMU;FYE(&EK:V4@:V]P:65R92!T:6P@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<@;&EB+TAO<F1E+T%U=&@O<V%S
M;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!E=&%B;&5R92!N>2!305-,
M+69O<F)I;F1E;'-E+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S4U(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3`Q"B,Z(&QI8B]61E,O
M9G1P+G!H<#HW-34@;&EB+U9&4R]S;6(N<&AP.C4P,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@9FQY='1E('1I;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT-C4@;&EB+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@
M(DMU;FYE(&EK:V4@:&5N=&4Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B4VUU
M:W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S
M*2(*;7-G<W1R(")&86QK;&%N9'/X97)N92`H36%L=FEN87,I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D;F<OAE<FYE(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S."!L:6(O2&]R9&4O0TQ)+G!H<#HR
M,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")$^&1E;&EG(&9E:FPZ
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X
M-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I
M9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A:W-I;6EL97(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y
M(@IM<V=S='(@(D9E8G)U87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")&^&QE<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z
M("(*;7-G<W1R(")&^&QE<SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@
M(D;E(&)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B1N4@
M<VYE8GEG97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS
M9W-T<B`B1F5L=&UA=')I8V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S(U(&QI8B](;W)D92]&;W)M+G!H<#HS,S(U"FUS9VED(")&:6=L970@
M0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%05$-(02(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,CD*
M;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(D9I9VQE="!S:W)I9G1S='EP
M;V=R869I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B
M"FUS9W-T<B`B1FEL(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@
M)7,@9FEL92(*;7-G<W1R(")!;G1A;"!F:6QE<CH@)7,@9FEL(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-SD@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B06YT
M86P@9FEL97(Z("5S(&9I;&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D9I;&CE;F1T
M97)I;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,"!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HX,B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW,`IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D9I;&YA=FXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<W(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3<W"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")&:6QV86QG
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B1FEL
M;&%G<FEN9R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP
M,B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1FEL;&%G<FEN9R!I:VME('5N
M9&5R<W3X='1E="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*
M;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")&:6YL86YD(@IM<V=S='(@(D9I;FQA;F0B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(D;X<G-T92!H
M86QV9&5L(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")&^')S
M=&4@:W9A<G1A;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-3<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(D9I:W/I<B!S=/AR
M<F5L<V5S9F]R:&]L9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R(")&;&EP(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM
M<V=I9"`B1FQO870B"FUS9W-T<B`B1FQY9&5N9&4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S
M='(@(E3E9V4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W"B,Z(&QI8B]61E,O;75S
M<6PN<&AP.C$P-R!L:6(O5D93+W-Q;"YP:'`Z,C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R(")-87!P
M92`E<R!E:W-I<W1E<F5R(&EK:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S
M='(@(E1Y<&]G<F%F:69A<G9E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(DUA9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PIM<V=I
M9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS
M9W-T<B`B1F]R('=E8G!R;V=R86UM97(L('-O;2!I:VME('5N9&5R<W3X='1E
M<B!B:6QL961E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED
M(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")696IR=61S:6=T("A4048I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&
M;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T
M(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@
M(B(*(E5D<VEG='-D86=E("AB96WF<FL@870@9&5N(')E='5R;F5R92!V96IR
M=61S:6=T('9E9'+X<F5R(&+E9&4@9&%G(&]G(&YA=#L@970@(@HB<W1O<G0@
M86YT86P@:&5R(&MA;B!R97-U;'1E<F4@:2!E;B!M96=E="!B<F5D(&)L;VLI
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")';&5M="!D:70@:V]D96]R
M9#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&
M;W)M<R(*;7-G<W1R(")&;W)M=6QA<F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D]R9'-P<F]G(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y
M<&4B"FUS9W-T<B`B17!I9W)A;71Y<&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D5P:6=R86UM97(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S
M(#(B"FUS9W-T<B`B17!I9W)A;6UE<B`R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<F$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D
M<R(*;7-G<W1R(")6:61E<F5S96YD96QS92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@
M(D9R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")286UM97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N:W)I9R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T
M<B`B1G)A;FMR:6<L($UE=')O<&]L:71A;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R(")&<F%N<VL@1W5Y86YA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B1G)A;G-K(%!O;'EN
M97-I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,B"FUS9W-T<B`B1G)A;G-K92!S>61L:6=E(%1E<G)I=&]R:65R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I
M9"`B1G)O;2(*;7-G<W1R(")&<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O
M;2!T:&4@(@IM<V=S='(@(D9R82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@
M(D9U;&0@8F5S:W)I=F5L<V4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S
M='(@(D9U;&1MY6YE(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8U('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@
M3F%M92(*;7-G<W1R(")&=6QD="!N879N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O
M;B(*;7-G<W1R(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L;&5R:2!H=F]R9G)A(&)I
M;&QE9&4@<VMA;"!T86=E<R!F<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE
M<GDZ(@IM<V=S='(@(D=A;&QE<FDZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDV(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B
M"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T
M:6]N(@IM<V=S='(@(D=E;F5RZ7(@)7,M:V]N9FEG=7)A=&EO;B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE
M<F%T960@0V]D92(*;7-G<W1R(")'96YE<F5R970@:V]D92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'96]R9VEE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1V5R;6%N>2(*;7-G<W1R(")4>7-K;&%N9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A
M<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W
M-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")&;W)N879N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I
M9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B1W)U;F1LYF=G96YD92!I;F1S
M=&EL;&EN9V5R(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G
M:60@(D=O(@IM<V=S='(@(E5D9OAR(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B1_9D96PB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O
M9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE($UA<',B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@
M(D=O;V=L92US^&=N:6YG(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B1W+E=&]N
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=RYFME;FQA
M;F0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B1W)E96L@
M*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=RYG-K("A)4T\M.#@U.2TW*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R^&YL86YD(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B1W)U<'!E+6%D;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,38Y"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z-3D@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='DB"FUS9W-T<B`B1W)U<'!E;F%V;F4@;>4@:6MK92!VYG)E
M('1O;6UE(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P
M-R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")'<F]U<%]L
M9&%P.B!+86X@:6MK92!T:6QF^&IE(&=R=7!P92`E<RX@4V5R=F5R96X@;65L
M9&5R.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q."!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,3$X"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,C0@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM
M<V=S='(@(D=R;W5P7VQD87`Z($MA;B!I:VME('-L971T92!G<G5P<&4@)7,B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@2V%N(&EK:V4@
M;W!D871E<F4@9W)U<'!E("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HS,30@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,30*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,S@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P<&5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T86UA;&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDR(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(R-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS
M9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")'YG-T971I;&QA9&5L
M<V5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B
M1W5E<W1B;V]K(@IM<V=S='(@(D?F<W1E8F]G(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDW(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I
M;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN96$M0FES<V%U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U>6%N82(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDV,"!L:6(O2&]R9&4O1F]R;2YP:'`Z.38P"FUS
M9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@;N9G=&5R('#E(&9E:B!V:7,@870@
M<VQE='1E(&1E;B!S:61S=&4@8V5L;&4@:2!RYFMK92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&[F9W1E<B!P
MY2!F96H@=FES(&%T('-L971T92!D96X@<VED<W1E(&MO;&]N;F4@:2!T86)E
M;"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!
M<F5A(&[F9W1E<B!PY2!F96H@=FES(&%T('-L971T92!D96X@<VED<W1E('+F
M:VME(&D@=&%B96PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HQ-3<@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B2%144"WF9W1N
M:6YG(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM
M<V=S='(@(DAA[W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$S(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`B2&%S:"UA;&=O<FET;64B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z
M92(*;7-G<W1R(")$:7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ-`HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.3$Y(&QI8B](;W)D92]&;W)M+G!H<#HR.3$T"FUS9VED(")(
M96%D97(B"FUS9W-T<B`B5&]P=&5K<W0B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,Z(&QI8B](;W)D92]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(D]V
M97)S:W)I9G1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R
M(")+<F%F=&EG('1O<F1E;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y
M"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F%I
M<VL@*$E33RTX.#4Y+3@M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B2/AJ9&4B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D92](
M;W)D92](96QP+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-"!L
M:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C$W"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP
M(@IM<V=S='(@(DAJYFQP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS
M9W-T<B`B2&KF;'`@=&EL(')E9&EG97)I;F=S=N9R:W3X:B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")(:N9L<&5R(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(DAE
M;6ES9N9R92(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H
M92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(DAE<B!E<B!S=&%R
M=&5N(&%F(&9I;&5N.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H(@IM<V=S='(@(DCX:B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M
M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&IE;2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92DB"FUS9W-T<B`B2&5L;&EG<_@@*%9A=&EK86YS=&%T96XI(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30X(&QI8B](;W)D92YP:'`Z
M,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R(")(:F5M(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B
M4')I=F%T+6%D<F5S<V4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*
M;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(DAJ96UM96MA=&%L;V<B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED
M(")(;VUE(%!H;VYE(@IM<V=S='(@(E!R:79A="UT96QE9F]N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#4R(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%5G>6QD
M:6<@)7,@6$U,(&1A=&$@<.5T<G5F9F5T(&D@8F5S:V5D("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE
M<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!);F=E;B!B97-K960@<W9A<F5R('1I;"!O8FIE:W0@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T-2!L:6(O2&]R9&4O2V]L
M86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26YT970@;V)J96MT(&%F('1Y<&4@)7,@9G5N
M9&5T(&D@8F5S:V5D("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,C4Q(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@
M7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!3;&5T=&5D92`E<R!<(B5S
M7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,R!L:6(O2&]R
M9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E
M9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E
M;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN=&5G<F%T:6]N<VUA<VMI
M;F5N(&MRYG9E<B!02%`M=61V:61D96QS92`G9&]M>&UL)R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3$R(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-3$R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!+86X@:6MK92!D86YN92!N>70@6$U,+71RYB!F;W(@
M;V)J96MT("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0X
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6MK92!S;&5T=&4@)7,@7"(E
M<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#@S(&QI
M8B](;W)D92]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&EK
M:V4@:6YD:&5N=&4@34E-12U)1"!F;W(@9&5L96X@868@='EP92`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y-R!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!+86X@:6MK92!S>6YK<F]N:7-E<F4@)7,@7"(E<UPB
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-R!L:6(O
M2&]R9&4O2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6MK92!S>6YK<F]N:7-E<F4@9&5L
M:6YG97(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!5:V5N9'0@9&5L:6YG(%PB)7-<(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ
M;VYT86P@4G5L92(*;7-G<W1R(")686YD<F5T('-T<F5G(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R
M:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(E9A;F1R970@9F]R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B
M2&]R:7IO;G1A;#HB"FUS9W-T<B`B5F%N9')E=#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(DAV;W)D86X@8F%R(&1U(&1I9R!A9"!M960@870@:&%V;F4@:&5R/R`H
M26YD<F%P<&]R=.ER(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(=F]R(&UA;F=E
M(&MO;&]N;F5R(/AN<VME<B!D=2!A="!S86UM96YLYF=G93\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE
M;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DAV;W(@;6%N9V4@
M9F5L=&5R("AK;VQO;FYE<BD@97(@9&5R/R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M
M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(DAV
M;W(@;6%N9V4@<N9K:V5R(/AN<VME<B!D=2!A="!S86UM96YLYF=G93\B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@Y"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")&=6=T:6=H
M960B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED
M(")(=6UI9&ET>3H@(@IM<V=S='(@(D9U9W1I9VAE9#H@(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B
M2'5M;W)I<W1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3$@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T
M<B`B56YG87)N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(*(SH@;&EB
M+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")/<')E='1E;'-E(&%F($E-
M05`M;6%P<&4@9F5J;&5D93H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,CDU(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C(Q-`HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(Y-2!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,C$T"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-L971N
M:6YG(&%F($E-05`M;6%P<&4@9F5J;&5D93H@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T
M,B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(D1E9FEN97)I;F<@868@:W9O=&4@9F]R($E-05`M;6%P<&4@
M9F5J;&5D93H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM
M<V=S='(@(DE0+6%D<F5S<V4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP
M8F%S:6,N<&AP.C<W(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C<W"FUS
M9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0+6%D
M<F5S<V4@:6MK92!T:6QGYFYG96QI9V4N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I<&)A<VEC+G!H<#HX.2!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H
M<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RXB"FUS9W-T<B`B25`M861R97-S92!I:VME(&EN9&5N9F]R($-)
M1%(M8FQO:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T
M<B`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N
M<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DEN9'/F="!RYFMK92!F^'(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB
M"FUS9W-T<B`B2W5N(&EK;VYE<B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T
M<B`B26MO;F5R(&9O<B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")):V]N97(@;65D
M('1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R("))9&5N=&ET971S;F%V;CHB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E
M;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(DAV:7,@9&5N(&EK:V4@
M=FES="!K;W)R96MT+"`E<R!F;W(@870@Y6)N92!D96X@:2!E="!N>70@=FEN
M9'5E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*
M(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@
M='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB2'9I<R!D
M=2!I:VME('-E<B!N;V=E;B!I:V]N97(@=F5D(&)R=6<@868@26YT97)N970@
M17AP;&]R97(@<VMA;"!D=2!MY7-K92`B"B)H86MK92!D96YN92!B;VMS(&%F
M(&9O<B!A="!S;.4@4$Y'+71R86YS<&%R96YS(&9R82XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)(=FES(&1U('-E<B!D96YN92!B97-K
M960@:2!S=&5D970@9F]R(&5T(&)I;&QE9&4L('/E('9I;"!D=2!I:VME(&MU
M;FYE('-E("(*(F1E="!I(&1I;B!N970M;.9S97(@969T97(@;W!LYF=N:6YG
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R-0IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B
M0FEL;&5D+69O<FCE;F1S=FES;FEN9SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!5
M4DPB"FUS9W-T<B`B0FEL;&5D+5523"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`IM<V=I9"`B26UA
M9V4@55),.B(*;7-G<W1R(")":6QL960M55),.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(D)I;&QE9&4@9G)A(&=A
M;&QE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB
M"FUS9W-T<B`B0FEL;&5D92!F<F$@9V%L;&5R:3HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8Q"FUS
M9VED("));6%G92!U<&QO860B"FUS9W-T<B`B0FEL;&5D+6]P;.9G;FEN9R(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B0FEL;&5D97(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHW('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z-R!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G
M<W1R("));7!O<G1E<FEN9RP@=')I;B`E9"(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D
M(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1E<F5D92!F96QT97(Z("5S(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T
M960@9FEE;&1S.B(*;7-G<W1R("));7!O<G1E<F5D92!F96QT97(Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("));F1SYG0@
M<N9K:V4@969T97(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ,S0@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D9E
M:FQA9W1I9R!H86YD;&EN9W-K;V1E(&%N9VEV970N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B56MO<G)E:W0@
M8G)U9V5R;F%V;B!O9R]E;&QE<B!K;V1E;W)D+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*(E5K;W)R96MT(&)R=6=E<FYA=FX@96QL97(@86QT
M97)N871I=B!A9')E<W-E+B!0<OAV(&EG96X@96QL97(@:V]N=&%K="!D:6X@
M(@HB861M:6YI<W1R871O<BP@:'9I<R!D=2!H87(@8G)U9R!F;W(@>61E<FQI
M9V5R92!H:N9L<"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B
M1F]R^&<@:6YD<GEK;FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM
M<V=S='(@(DEN9&EE;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C4T(&QI8B](;W)D92]097)M<R]522YP:'`Z,C4T"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S
M(@IM<V=S='(@(DEN9&EV:61U96QL92!B<G5G97)E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N97-I96XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y
M"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA=&EO;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R;6%T
M:6]N(&EK:V4@;.9N9V5R92!T:6QGYFYG96QI9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B
M26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B26YD<^9T(&MO;&]N;F4@
M969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3<*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R
M("));F1SYG0@8FEL;&5D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M("));F1SYG0@=&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T
M<B`B26YD<^9T('=E8BUH96YV:7-N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E
M<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B26YD<^9T(&MO;&]N;F4@9OAR
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("));F1SYG0@96X@;GD@:V]L;VYN92!E
M9G1E<B!D96X@86MT=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));F1S
MYG0@96X@;GD@:V]L;VYN92!F^'(@9&5N(&%K='5E;&QE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS
M9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("));F1SYG0@96X@;GD@<N9K:V4@969T97(@9&5N(&%K='5E;&QE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B26YD<^9T(&5N(&YY('+F:VME(&;X<B!D
M96X@86MT=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN9'/F="!E;B!P
M87)A9W)A9B!E9G1E<B!D970@86MT=65L;&4@<'5N:W0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R("));F1SYG0@96X@<&%R86=R868@9OAR(&1E="!A:W1U96QL
M92!P=6YK="(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("))
M;G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DEN9'/F="!A;'1E
M<FYA=&EV('-K86)E;&]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T
M,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(DEN9'1A
M<W0@96X@92UM86EL+6%D<F5S<V4L(&AV;W)T:6P@9'4@:V%N(&UO9'1A9V4@
M9&5T(&YY92!K;V1E;W)D.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F
M=&5R(@IM<V=S='(@(DEN9'/F="!C96QL92!E9G1E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@
M(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("));F1SYG0@8V5L;&4@9OAR
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("))
M;F1SYG0@:V]L;VYN92!E9G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU
M;6X@8F5F;W)E(@IM<V=S='(@(DEN9'/F="!K;VQO;FYE(&;X<B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P(&QI8B](;W)D92])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R
M("));F1SYG0@8F5S:V5D97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@869T97(B"FUS9W-T<B`B26YD<^9T('!A<F%G<F%F(&5F=&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R
M("));F1SYG0@<&%R86=R868@969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(DEN9'/F="!RYFMK92!E9G1E<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*
M;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(DEN9'/F="!RYFMK
M92!F^'(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("))
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ(@IM<V=S='(@(DEN9'1A<W0@9&5T(&MRYG9E9&4@<W9A<B!T:6P@
M<VEK:V5R:&5D<W-P^')G<VWE;&5T.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@
M26UA9V4B"FUS9W-T<B`B26YD<^9T+^9N9')E(&)I;&QE9&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("))
M;G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YD<^9T+^9N9')E(&AE;G9I
M<VYI;F<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")5=&EL<W1RYFMK96QI9R!K
M<F5D:70@=&EL(&%T('-E;F1E('1I;"!D:7-T<FEB=71I;VYS;&ES=&5N+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,U"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(E5T:6QS='+F:VME
M;&EG92!K<F5D:70N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G
M<W1R(")(96QT86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B
M"FUS9W-T<B`B2&5L=&%L<VQI<W1E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")59WEL9&EG(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,C$R(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ.30@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S
M='(@(E5G>6QD:6=E(%I)4"UD871A(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B
M56=Y;&1I9W0@87!P;&EK871I;VXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$
M+B(*;7-G<W1R(")59WEL9&EG="!S:W)I<'0M240N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C,W(&QI8B](;W)D92]&;W)M+G!H<#HR,#@W"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,34X(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C,R(&QI8B](;W)D92]&;W)M+G!H<#HR,CDY"B,Z(&QI8B](;W)D92]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+B(*;7-G<W1R(")59WEL9&EG92!D871A(&%F<V5N9'0N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED
M("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(E5G>6QD
M:6<@9&5S=&EN871I;VXN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HR-#$@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$S.2!L:6(O2&]R9&4O0V]M
M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B
M"FUS9W-T<B`B56=Y;&1I9W0@9FEL9F]R;6%T(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME
M>2XB"FUS9W-T<B`B56=Y;&1I9R!L:6-E;G-N^&=L92XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")59WEL9&EG('!L86-E<FEN9R!A;F=I
M=F5T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B56=Y;&1I
M9R!M<V=?='EP92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M(@IM<V=S='(@(E5G>6QD:6<@96QL97(@;6%N9VQE;B!A<&E?:60N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED
M("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B56=Y
M;&1I9V4@96QL97(@;6%N9VQE;F1E('!A<F%M971R92XB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(E5G>6QD:6=E(&9O<N9L9')E+71I;&QA9&5L
M<V5R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G
M:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B56=Y;&1I9R!P87)T
M;F5R+6ED+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*
M;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")59WEL9&EG
M('!R;V1U:W0M:V]D92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#8*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S
M='(@(E5G>6QD:6<@<')O=&]K;VPN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z.#`*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW,0HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV
M86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(")59WEL9&EG(&UO9'1A
M9V5R.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P
M.#`@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8S"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3`X,"!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-C,*;7-G
M:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(E5G>6QD:6=T(&1E
M;&EN9W-O8FIE:W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#$*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM
M<V=S='(@(E5G>6QD:6<@;W!R:6YD96QS97-A9')E<W-E+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV
M86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(E5G>6QD:6<@=6YI8V]D92UD
M871A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@
M(DEN=F5N=&]R>2(*;7-G<W1R("));F1B;R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-S@*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T('-E;&5C=&EO
M;B(*;7-G<W1R("));G9E<G3I<B!M87)K97)I;F<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER86XL
M($1E;B!I<VQA;6ES:R!R97!U8FQI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER
M87$B"FUS9W-T<B`B27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B
M"FUS9W-T<B`B27)L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O
M9B!-86XB"FUS9W-T<B`B36%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM
M<V=S='(@(E-T961V:7,@=&]R9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R
M865L(@IM<V=S='(@(DES<F%E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C(V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(V
M"FUS9VED("))<W-U97(B"FUS9W-T<B`B561S=&5D97(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI
M8R(*;7-G<W1R("))=&%L:65N<VLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L
M>2(*;7-G<W1R("))=&%L:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC
M82(*;7-G<W1R(")*86UA:6-A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA;G5A<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&%N(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*
M4"DB"FUS9W-T<B`B2F%P86YS:R`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D96XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P."!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L
M:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N
M92(*;7-G<W1R(")*=6YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R
M(")*=7-TZ7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T
M<B`B0V5N='+I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T
M<B`B3&EG92!M87)G96YE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B
M"FUS9W-T<B`B5F5N<W1R96IU<W1E<F5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I
M9GD@4FEG:'0B"FUS9W-T<B`B2/AJ<F5J=7-T97)E="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%S86MH<W1A;B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C4*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E
M<"!O<FEG:6YA;#\B"FUS9W-T<B`B0F5V87(@;W)I9VEN86P_(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N>6$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C@U(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S('-E<G9E<B!A9G9I<W1E(&=O
M9&ME;F1E;'-E(&%F(&ED96YT:71E="XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE
M+3QE;3Y.97=B:65S/"]E;3XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@0W)E871I;VXB"FUS9W-T<B`B3OAG;&4M<VMA8F5L<V4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B3OAG;&4M9FEN9V5R869T<GEK(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM
M<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(").^&=L96SF;F=D92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(D[X9VQE
M='EP92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A
M9V4B"FUS9W-T<B`B3OAG;&5A;G9E;F1E;'-E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-S0P(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R(").^&=L92!E:W-I<W1E<F5R(&%L;&5R961E
M('#E(&1E;B!O9F9E;G1L:6=E(&[X9VQE<V5R=F5R+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(")"^')N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9B(*;7-G<W1R(")3>61K;W)E82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(").;W)D:V]R96$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%
M54,M2U(I(@IM<V=S='(@(FMO<F5A;G-K("A%54,M2U(I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=V%I="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER9VES:7-T86XB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS
M9W-T<B`B561F;W)M;FEN9R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<F]G(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B
M"FUS9W-T<B`B3&%O<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G
M:60@(DQA<W0@2&%L9B(*;7-G<W1R(")3:61S=&4@:&%L=F1E;"(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM<V=I9"`B3&%S="!087-S=V]R9"!#
M:&%N9V4B"FUS9W-T<B`B4VED<W1E(&MO9&5O<F1SYFYD<FEN9R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G
M:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")3:61S=&4@:W9A<G1A;"(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,34X"FUS9VED("),87-T(%5P9&%T960Z
M(@IM<V=S='(@(E-I9'-T(&]P9&%T97)E=#HB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3<@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")3:61S=&4@
M;&]G:6XZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y(&QI
M8B](;W)D92]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S
M="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")3:61S=&4@:6YD;&]G;FEN
M9SH@)7,@9G)A("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T
M(&QI8B](;W)D92]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE
M=F5R(@IM<V=S='(@(E-I9'-T92!L;V=I;CH@06QD<FEG(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQE=&QA;F0B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("),;W8B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("),87EO=70B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(E1O;2!V960@:6YG96X@
M<F%M;65R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),
M:6)A;F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0P"FUS9VED("),969T(@IM<V=S='(@(E9E;G-T<F4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`Q(&QI8B](;W)D92]&;W)M
M+G!H<#HS,3`Q"FUS9VED("),969T(&AE861E<B(*;7-G<W1R(")696YS=')E
M('1O<'1E:W-T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y-PIM<V=I9"`B3&5F="!V86QU97,B"FUS
M9W-T<B`B5F5N<W1R92!VYG)D:65R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S
M;W1H;R(*;7-G<W1R("),97-O=&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(DYI=F5A=2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S
M='(@(DQI8GEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB
M"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM
M<V=S='(@(E-T^'9R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B3&5T
M(')E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("),970@<F5G
M;B!T:61L:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("),970@
M<F5G;B!S96YT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DQE
M="!B>6=E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@
M(DQE="!B>6=E(&UE9"!T;W)D96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R
M("),970@<VYE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(DQE
M="!S;F4@8GEG92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I
M9"`B3&EM97)I8VLB"FUS9W-T<B`B5FET=&EG:&5D(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@Q-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q-`IM
M<V=I9"`B3&EN:R(*;7-G<W1R(")(96YV:7-N:6YG(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED
M("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B1F]R8FEN9"!P=6YK=&5R('1I
M;#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S
M('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@
M(D9O<F)I;F0@92UM86EL+6%D<F5S<V5N(&UE9"!I;F1S:W)I=FYI;F=S<VED
M96X@=F5D(&9R96UV:7-N:6YG(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@HC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@
M(DAE;G9I<VYI;F=E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X+6MI:W,B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(B"FUS9W-T<B`B3&ES=&4@+2!B<G5G97(@:V%N('-E(&UA<'!E
M;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T
M86)A<V5S(@IM<V=S='(@(DQI<W0@9&%T86)A<V5R(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS
M9W-T<B`B3W!L:7-T;FEN9R!A9B!H:N9L<&5E;6YE<B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(DQI
M<W0@=&%B96QL97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y-"!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@
M(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T92U!<F-H:79E(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B
M3&ES="U(96QP(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.38@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),
M:7-T+4ED(@IM<V=S='(@(DQI<W0M260B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES="U/=VYE<B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS(&QI8B](
M;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM
M<V=S='(@(DQI<W0M4&]S="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DQ(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,0IM
M<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B3&ES="U3=6)S8W)I8F4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,"!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S
M8W)I8F4B"FUS9W-T<B`B3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E
M<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B3&ES=&YI;F<@868@<V5S<VEO
M;G,@9F5J;&5D93H@)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM
M<V=S='(@(DQI<W1N:6YG(&%F(&)R=6=E<F4@9F5J;&5D93H@)7,B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(E9I<VYI;F<@868@8G)U
M9V5R92!E<B!S;.5E="!F<F$N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI='1E<F%T=7(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET875E;B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@
M(DQO861I;F<N+BXB"FUS9W-T<B`B2&5N=&5R+BXN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM
M<V=S='(@(DQO:V%L('1I9#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R(")296=I;VYA;&1A
M=&$@;V<@=&ED(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S(@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW,B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R(")3=&5D(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,C`P('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.3`*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,R!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@
M(DQO9R!I;F0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*
M;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B
M3&]G(&%F('1I9&QI9V5R92!S>6YK<F]N:7-E<FEN9W-S97-S:6]N97(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@
M;W5T(@IM<V=S='(@(DQO9R!U9"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV,0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B3&]G(&EN9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S
M='(@(DQO9VEN+6]P9V%V97(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.34@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB3&]G(&EN9"!F96IL961E
M(&9O<F1I(&1I="!B<G5G97)N879N(&5L;&5R(&MO9&5O<F0@8FQE=B!A;F=I
M=F5T(&9O<FME<G0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DQ
M(&QI8B](;W)D92]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`B3&]G:6YD(&UI<VQY:VME9&5S+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-C4*;7-G
M:60@(DQO;F<@=&5X="(*;7-G<W1R("),86YG('1E:W-T(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(DOF<FQI
M9VAE9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B3&%V(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B
M3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")3;>4@9W+F<VME('1E9VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@
M(E-MY2!L871I;G-K92!T96=N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R(")3;>4@<F]M97)T86PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8F]R9R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.
M148M8FEL86<@:6YD:&]L9'0@:6YG96X@9&%T82XB"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,W"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I
M9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DUA:V5D;VYI96XL($1E;B!T:61L:6=E<F4@:G5G;W-L879I
M<VME(')E<'5B;&EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*
M;7-G<W1R(")-861A9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-86=I(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@(D4M;6%I
M;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G:60@(DUA
M:6P@061M:6XB"FUS9W-T<B`B12UM86EL+6%D;6EN:7-T<F%T;W(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B1&%N(&AE;G9I<VYI
M;F<N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L
M87=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L
M87ES:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-
M86QD:79E<FYE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-
M86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(DCE;F1TZ7(@;&ES=&5N(&%F(&MA
M=&5G;W)I97(L('-O;2!D=2!S:V%L(&UA<FME<F4@96UN97(@;65D+"!O9R!F
M87)V97)N92P@(@HB9&5R('-K86P@:VYY='1E<R!T:6P@9&ES<V4@:V%T96=O
M<FEE<BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$U-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T+6MO<G0B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T+6MO<G0B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B2V]R=&SF9VYI;F<@9V5M="XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA
M<G1S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA<F=E;B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0X(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<R(*;7-G<W1R(")-87)KZ7(@;65D(%-E="]5<V5T+69L86<B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-87)KZ7(@
M;65D(&%N9')E(&9L86<@*&9X(%9I9W1I9R]"97-V87)E="DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL
M^&5R;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@
M(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P
M,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D]V97)E;G-P87-S
M96YD92!F96QT97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(DUA=7)I=&%N:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET
M:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R(")-87@@=&EL;&%D="!K<F5D:70N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@
M;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B36%K<VEM=6T@8F5S
M:V5D+61E;&4@;W9E<G-K<F5D970N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,3,*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R
M(")-86MS+B!T96UP+B!S:61S="`R-"!T:6UE<CH@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(DUA:W,N('1E;7`N('-I9'-T92`V('1I;65R.B`B"@HC.B!L
M:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L
M($)L;V-K<R(*;7-G<W1R(")-86MS:6UU;2!A;G1A;"!A9B!P;W)T86QB;&]K
M:V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,Y(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R,3<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA
M>&EM=6T@;&5N9W1H(@IM<V=S='(@(DUA:W-I;75M;.9N9V1E(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B
M36%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA
M>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE
M9&EC:6YE(@IM<V=S='(@(DUE9&EC:6XB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE
M9&QE;6UE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@
M(DUE;G4@;6]D93HB"FUS9W-T<B`B365N=2UT:6QS=&%N9#HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS
M9VED(")-97)G92!C96QL<R(*;7-G<W1R(")&;W+I;B!C96QL97(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C,P"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B0F5S:V5D(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)"97-K960@<W5C
M8V5S9G5L9'0@=F5R:69I8V5R970@;65D('5N9&5R<VMR:79E<F5N<R!C97)T
M:69I:V%T(&MU;FYE(&EK:V4@(@HB=F5R:69I8V5R97,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S
M86=E(&5X<&ER960N(@IM<V=S='(@(D)E<VME9"!U9&SX8F5T+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,#(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS
M9W-T<B`B0F5S:V5D='EP92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM
M<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")-971A<B!796%T:&5R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T87)B;&]K(&EK:V4@=&EL9^9N
M9V5L:6<N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*
M(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DUE
M=&%R8FQO:R!I:VME('1I;&?F;F=E;&EG+B!$971A;&IE<B!E<B!B;&5V970@
M;F]T97)E="!T:6P@8G)U9R!F;W(@(@HB861M:6YI<W1R871O<F5N+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B365T87)$0B!E<B!I:VME
M(&9O<F)U;F1E="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S0*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G
M<W1R(")-971O9&4B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ
M,3<@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,0HC.B!L:6(O2&]R
M9&4O4E!#+WAM;')P8RYP:'`Z.#$@;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@
M9&5F:6YE9"(*;7-G<W1R(")-971O9&4@7"(E<UPB(&5R(&EK:V4@9&5F:6YE
M<F5T(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(@;&EB+TAO
M<F1E+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H
M;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(DUE
M=&]D92!I:VME(&1E9FEN960N($UE=&]D92!K86QD=#H@)7,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C@R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV-PIM<V=I9"`B365T<FEC(@IM<V=S='(@(DWE;&5E;FAE9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI8V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G
M<W1R(")-:6MR;VYE<VEE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@IM<V=I9"`B36ED9&QE(@IM<V=S='(@
M(DUI9'0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS."!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DUI;64@5'EP92(*;7-G<W1R(")-24U%+71Y<&4B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@
M(@IM<V=S='(@(DUI;BX@=&5M<"X@<VED<W1E(#(T('1I;65R.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B36EN+B!T96UP+B!S:61S=&4@-B!T:6UE<CH@
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D
M(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(DUI;FEM=6T@:V]D
M96]R9'-A;&1E<B!E<B!E;F1N=2!I:VME('5D<W3E970B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*
M;7-G<W1R(")3<&5J;&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*
M;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B1F]R<VME;&QI9W0B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M-3`@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,"!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N(@IM<V=S='(@(DUA;F=L97(@4$5!4BUP86MK92!(5%10
M7U)E<75E<W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I
M9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE
M<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC
M871I;VXN(@IM<V=S='(@(B(*(DMO;F9I9W5R871I;VX@;6%N9VQE<BX@1'4@
M8FQI=F5R(&[X9'0@=&EL(&%T(&=E;F5R97)E(&1E;B!N=2P@:'9I<R!D=2#X
M;G-K97(@(@HB870@8G)U9V4@9&5N;F4@87!P;&EK871I;VXN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-
M:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(DUA;F=L97(@8F5S:V5D+6ED
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C4X"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN(@IM<V=S='(@(DUA;F=L97(@:W+F=F5T(%!%05(M<&%K:V4@36%I;"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.30*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*
M;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B36%N9VQE<B!S
M97-S:6]N+4E$+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DUA;B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS
M9W-T<B`B36]B:6P@12UP;W-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DKF
M=FXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,R!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HX-2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M,PIM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("+&;F1R:6YG<V1A=&\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`BQFYD<F4@55),
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS
M9W-T<B`B36]D=6QU<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-;VYA8V\B"FUS9W-T<B`B36]N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L:65N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4X-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X-`IM<V=I
M9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B3>5N960@;V<@Y7(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W(&QI8B](
M;W)D92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T
M<B`B3>5N961L:6<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM
M<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S
M='(@(DWE;F5F87-E<B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C$Y-B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.#`*(SH@;&EB+T9I
M;&4O0U-6+G!H<#HQ.38@;&EB+T9I;&4O0U-6+G!H<#HR.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N
M('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B1FQE<F4@9F5L=&5R(&9U;F1E
M="!I(&QI;FEE("5D(&5N9"!D970@9F]R=F5N=&5D92`E9"XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30X(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<F]K:V\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S
M=&QY($-L96%R(@IM<V=S='(@(DUE<W0@<VMY9G)I="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@
M0VQO=61Y(@IM<V=S='(@(DUE<W0@<VMY970B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY($-L;W5D
M>2!A;F0@5VEN9'DB"FUS9W-T<B`B365S="!S:WEE="!O9R!B;.9S96YD92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS
M9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B365S="!S;VPB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T."!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,#D*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G
M<W1R(")&;'ET(&YE9"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-C4R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C4Q,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U
M,@IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(D9L>70@=&EL('9E;G-T<F4B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8U-B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3<*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`B36]D(&CX:G)E(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-3`U"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(D9L>70@;W`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G
M:60@(DUO=F4@9&]W;B(*;7-G<W1R(")&;'ET(&YE9"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C4*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(U(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
M1FQY="!O<"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T
M<B`B36]C86UB:7%U92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R(")-=6QT:2UN:79E874@<G5L;&5G
M87)D:6YS;&ES=&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")-
M=6QT:6UA<"!52R!K;W)T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@
M<V5L96-T:6]N(@IM<V=S='(@(DUU;'1I<&QE('9A;&<B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S
M='(@(DUI;B!K;VYT;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM
M<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")-:6YE(&MO
M;G1O+6EN9F]R;6%T:6]N97(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N
M<&AP.C0T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B36EN(%!O<G1A;"(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,@IM<V=I9"`B37D@4&]R
M=&%L($QA>6]U="(*;7-G<W1R(")-:6X@4&]R=&%L+75D9F]R;6YI;F<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM
M<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY%2BP@:F5G(&5R
M($E+2T4@96YI9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,#(@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS."!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3$*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%V;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-CD@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").971H97)L86YD<R(*;7-G<W1R(").961E<FQA;F1E;F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B2&]L
M;&%N9'-K92!!;G1I;&QE<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS
M9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R(").971S8V%P92!"87-E
M(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P
M92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92!#02!2979O
M8V%T:6]N(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").
M971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C87!E($-!('!O
M;&EC>2!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T<V-A<&4@4F5N97=A;"!5
M4DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,R!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-R!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"!S97)V97(@
M;F%M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(DYE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P
M92!C97)T:69I8W1E('1Y<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(DYE=';F<FLB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T
M<B`B06QD<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*
M;7-G<W1R(").>2!+86QE9&]N:65N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@;&EB+TAO<F1E+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*
M;7-G<W1R(").>2!K871E9V]R:2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W
M-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3GEMY6YE(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N
M86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3GET(&)R=6=E<FYA=FX@*'9A;&=F
M<FET*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@
M(DYE=R!:96%L86YD(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B3GET(&MO9&5O<F0B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W(&QI8B](;W)D
M92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P
M87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B3GET(&MO9&5O
M<F0@=FEL('5D;/AB92!D96X@)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H
M+B(*;7-G<W1R(").>64@:V]D96]R9"!E<B!I:VME(&5N<RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").
M97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYY="!V:6YD=64@*%]B;&%N
M:RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z-#`*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM
M<V=I9"`B3F5W<R(*;7-G<W1R(").>6AE9&5R(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(").
M>6AE9'-G<G5P<&5R(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,C4@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z-#$@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,34*;7-G:60@(DYE>'0B"FUS9W-T<B`B3N9S=&4B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B
M3N9S=&4@-"!F87-E<B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,S8V(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B3N9S=&4@=&EL
M=F%L9R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S(&QI8B](
M;W)D92]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(").
MYG-T93XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B
M3FEC87)A9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B
M3FEG97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI
M9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS
M9VED(").:6=H="(*;7-G<W1R(").870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38V"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(DYE:B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BXB"FUS9W-T<B`B26YG96X@=&EL9^9N9V5L:6=E(&MO;F9I9W5R871I
M;VYD871A(&%T('9I<V4@9F]R<VME;&QE(&9O<BXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-B!L:6(O5D93+TE33U=R
M:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R
M(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("));F=E;B!T:6QGYFYG96QI
M9R!S=')A=&5G:2!T:6P@870@;&%V92!)4T\M8FEL;&5D97(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").
M;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B26YG96X@<VMR:7!T+7-K86)E
M;&]N+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,S@U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-#`W(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(T-2!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HR-C<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HS.#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N(@IM<V=S='(@(D1E<B!E:W-I<W1E<F5R(&EK:V4@
M;F]G96X@8FQO:R!PY2!D96X@9F]R97-P=7)G=&4@<&]S:71I;VXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P(&QI8B](;W)D92]!=71H
M+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D
M(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K86QE
M;F1E<B!A;F=I=F5T('1I;"!-0T%,+>9G=&YI;F<N(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B26YG
M96X@YFYD<FEN9RXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$U-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI
M;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B1&5R(&MA;B!I:VME('1I;&;X:F5S(&+X<FX@=&EL(&1E;FYE('1I;&QA
M9&5L<V4N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S8X(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3<X"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3$W(&QI8B](;W)D92YP:'`Z,3<X(&QI8B](;W)D92YP:'`Z
M-3$W"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%T:6]N+6EN9F]R;6%T
M:6]N(&%N9VEV970@9F]R("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#4U(&QI8B]61E,O9G1P+G!H<#HX-34*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*
M;7-G<W1R("));F=E;B!K;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV
M970@9F]R($944"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-S(@;&EB+U9&4R]S<6PN<&AP.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S
M='(@(DEN9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E="!F
M;W(@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A=&EO;BUI;F9O<FUA=&EO
M;B!A;F=I=F5T(&9O<B!344PM1FEL92!61E,N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@
M;&5F="XB"FUS9W-T<B`B2W)E9&ET('5D=/AM="XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B26YT970@8F5S=&5M;65L<V5S<W1E
M9"!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDR,"!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(P"FUS9VED(").;R!F:6QE
M('5P;&]A9&5D(@IM<V=S='(@(DEN9V5N(&9I;"!S96YD="(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM
M<V=S='(@(D9A;F1T(&EN9V5N(&EK;VYE<BXB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$S,"!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-@IM<V=I9"`B3F\@;&]C871I;VX@
M:7,@<V5T+B(*;7-G<W1R("));G1E="!S=&5D(&EN9'-T:6QL970N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(DEN=&5T('-T960@86YG:79E="XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS
M9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("));F=E;B!B97-K
M960@86YG:79E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B
M26YT970@;F%V;B!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N
M(@IM<V=S='(@(DEN=&5T(&YU;6UE<B!A;F=I=F5T+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(DEN9V5N(&%N<W3X9&5L:6=E(&5P:6=R86UM97(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ(&QI8B](;W)D92]!=71H
M+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YT970@:V]D96]R9"!A
M;F=I=F5T('1I;"!B<G5G(&9O<B!(5%10+>9G=&YI;F<N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@@;&EB+TAO<F1E+T%U=&@O:6UA
M<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YT970@:V]D96]R9"!A;F=I
M=F5T('1I;"!B<G5G(&9O<B!)34%0+>9G=&YI;F<N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HW,B!L:6(O2&]R9&4O075T:"]K<F(U+G!H
M<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));G1E="!K;V1E;W)D(&%N9VEV
M970@=&EL(&)R=6<@9F]R($ME<F)E<F]S+>9G=&YI;F<N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M-S<@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&QI8B](;W)D92]!
M=71H+W!A;2YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z-S<*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B26YT970@:V]D96]R9"!A;F=I=F5T(&9O<B!,;V=I
M;F0MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP
M:'`Z,3,U(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("));G1E="!K;V1E;W)D(&%N9VEV971T('1I;"!005-35T0M
MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0@
M;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YT
M970@:V]D96]R9"!A;F=I=F5T(&9O<B!334(MYF=T;FEN9RXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G
M<W1R("(B"B)3=&D@=&EL($]P96Y34TPM8FEB;&EO=&5K970@;6%N9VQE<BX@
M($]P96Y34TPM8FEB;&EO=&5K970@97(@;OAD=F5N9&EG="!F;W(@(@HB870@
M:.5N9'1E<F4@4$M#4S$R+61A=&$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*
M;7-G<W1R("));F=E;B!V96YT96YD92!O<'-K<FEV;FEN9V5R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HW-C8@;&EB+U9&4RYP:'`Z-S8V"FUS9VED
M(").;R!Q=6]T82!S970N(@IM<V=S='(@(DMV;W1E(&EK:V4@:6YD<W1I;&QE
M="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("));F=E;B!S=')E
M9V5R(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R(&QI8B]&
M:6QE+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D
M+B(*;7-G<W1R("));F=E;B!S:VEL;&5T96=N(&%N9VEV970N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B26YG96X@<VED97(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-R!L:6(O5D93+W-M8BYP:'`Z-3@W
M"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B26YG96X@<^5D86X@9FEL
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*
M;7-G<W1R(")$97(@;6%N9VQE<B!E="!M:61L97)T:61I9W0@:V%T86QO9R!T
M:6P@;65L;&5M;&%G97(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR,C$@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED
M(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B
M26YT970@8G)U9V5R;F%V;B!O9R]E;&QE<B!K;V1E;W)D('-E;F1T+B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P(&QI8B](;W)D92]2
M4$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D(@IM<V=S='(@(DEN9V5N(&=Y;&1I9V4@6$U,+61A=&$@<F5T=7)N
M97)E="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-S0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDX-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3DU"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#$R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-S0@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU
M97,B"FUS9W-T<B`B26YG96X@=N9R9&EE<B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B)/<FEG:6YA;"!K;VYF:6=U<F%T:6]N(&UA;F=L97(@=F5R
M<VEO;G-N=6UM97(N(%)E9V5N97+I<B!K;VYF:6=U<F%T:6]N+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(D1I;B!K;VYF:6=U<F%T:6]N(&UA;F=L97(@=F5R
M<VEO;G-N=6UM97(N(%)E9V5N97+I<B!K;VYF:6=U<F%T:6]N+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-R!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0U"FUS9VED(").;VYE(@IM<V=S='(@(DEN9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM
M<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("));F=E;B`H8G)U
M9R!I;7!L:6-I="DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I
M9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3F]R9&ES:R`H25-/
M+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B
M"FUS9W-T<B`B3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE
M<F4B"FUS9W-T<B`B3F]R9&QI9V4@:&%L=FMU9VQE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DYO<F1L
M:6=E($UA<FEA;F'X97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS
M9W-T<B`B3F]R9V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B
M3F]T($%F=&5R(@IM<V=S='(@(DEK:V4@<V5N97)E(&5N9"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DEK
M:V4@9OAR(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$U(&QI
M8B]61E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS
M9W-T<B`B26MK92!N;V=E="!K871A;&]G(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z-3D*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.34*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").
M;W0@:6UP;&5M96YT960N(@IM<V=S='(@(DEK:V4@:6UP;&5M96YT97)E="XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X
M"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DEK:V4@:6YD<W1I;&QE="(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR-3(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V
M.2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S,S(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M-C8*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-3`U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C4Y,0HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-C8Y(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V(&QI8B]61E,N<&AP
M.C$Y,PHC.B!L:6(O5D93+G!H<#HR,#@@;&EB+U9&4RYP:'`Z,C,T(&QI8B]6
M1E,N<&AP.C(U,B!L:6(O5D93+G!H<#HR-CD*(SH@;&EB+U9&4RYP:'`Z,C@U
M(&QI8B]61E,N<&AP.C,P,2!L:6(O5D93+G!H<#HS,38@;&EB+U9&4RYP:'`Z
M,S,S"B,Z(&QI8B]61E,N<&AP.C,V-B!L:6(O5D93+G!H<#HT,C8@;&EB+U9&
M4RYP:'`Z-3`U(&QI8B]61E,N<&AP.C4W-`HC.B!L:6(O5D93+G!H<#HU.3$@
M;&EB+U9&4RYP:'`Z-C8Y(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z
M,30U"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,38P(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&QI8B](;W)D92]397-S
M:6]N2&%N9&QE<BYP:'`Z,3@Y(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")):VME('5N
M9&5R<W3X='1E="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0T(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`X"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`X(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM
M<V=S='(@(DYO=&5R(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP
M.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T
M<B`B26YT970@870@8G)O=W-E+"!V96YD('1I;&)A9V4N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R
M(").;W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R
M(")486PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R(")!;G1A;"!T96=N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S-CD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C,@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@
M(D%N=&%L(&MO;&]N;F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-C<*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D%N=&%L('+F
M:VME<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(E1A;"!I:VME(&%N9VEV
M970@9F]R(&]P9&%T97)I;F<@:2!D:7-T<FEB=71I;VYS;&ES=&4N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED
M(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX-S,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5K="(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE
M8W0@0W)E871O<B(*;7-G<W1R(")/8FIE:W1D86YN97(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3`T(&QI8B](;W)D92]&;W)M+G!H<#HQ,3`T
M"FUS9VED(")/8W1A;"(*;7-G<W1R(")/:W1A;"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/:W1O
M8F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E
M;G-E(&9I;'1E<B(*;7-G<W1R(")!;G-T^&1E;F1E(&9I;'1E<B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G
M<W1R(")+;VYT;W(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E
M<F5N="XB"FUS9W-T<B`B1V%M;65L="!O9R!N>70@:V]D96]R9"!S:V%L(';F
M<F4@9F]R<VME;&QI9V4N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B1V%M;65L="!K
M;V1E;W)D(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS
M9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(D=A
M;6UE;'0@:V]D96]R9"!E<B!I:VME(&MO<G)E:W0N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")$96QT92!M87!P97(@=6YD97)S
M=/AT=&5S(&MU;B!A9B!)34%0+7-E<G9E<F4N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*
M;7-G<W1R(")+=6X@86YS=/AD96QI9V4@97!I9W)A;6UE<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DW,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U,2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+B(*;7-G<W1R(")+=6X@Z6X@92UP;W-T+6%D<F5S<V4@=&EL;&%D
M="XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*
M(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C
M:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A
M('-H87)E(@IM<V=S='(@(B(*(D5N(&1E;&EN9W,@96IE<G-K86(@;V<@96IE
M<G1I;&QA9&5L<V5R(&WE(&MU;B#F;F1R92!A9B!E;B`B"B)S>7-T96UA9&UI
M;FES=')A=&]R(&5L;&5R(&5J97)E;B!S96QV(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-#$@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P
M96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(L5B96X@:2!E="!N>70@=FEN
M9'5E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(@IM<V=S='(@(D]P96Y34TPM9F5J;#H@1&%T82!K=6YN92!I
M:VME('5D9')A9V5S(&9R82!S:6=N97)E="!3+TU)344M9&5L+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("+%8F5N(&1E;FYE(&AE;G9I<VYI;F<@:2!E="!N>70@=FEN9'5E(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@
M4WES=&5M(@IM<V=S='(@(D]P97)A=&EV<WES=&5M(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R
M("));F1S=&EL;&EN9V5R(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(DEN9'-T:6QL:6YG97(@9F]R("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(D]R9&YE="!L:7-T92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB
M"FUS9W-T<B`B3W)G86YI<V%T:6]N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-CD@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B3W)G86YI
M<V%T;W)I<VL@96YH960B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7-E<FEN9R(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")/<')I;F1E;&EG(&%P<&QI
M:V%T:6]N<W-K86)E;&]N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.B(*;7-G<W1R(")/<')I;F1E;&EG92!S:V%B96QO;F5R(&D@)7,Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3D*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-R!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED
M(")/=&AE<B(*;7-G<W1R(")!;F1E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%N
M9&5N(&EN9F]R;6%T:6]N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B16IE<G)E
M='1I9VAE9&5R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y
M(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")004TMYF=T;FEN
M9R!E<B!I:VME('1I;&?F;F=E;&EG92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4@;&EB+TYE="]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G
M<W1R(")014%2.CI-86EL+6UO=&]R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3(W-B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0(&1I
M9VET86P@<VEG;F%T=7(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,S(R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@
M(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`M:W)Y<'1E<F5T(&1A
M=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(D]F9F5N=&QI9R!01U`M;OAG;&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B
M"FUS9W-T<B`B4$=0+7-I9VYE<F5T+VMR>7!T97)E="!D871A(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")0
M2%`M:V]D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0
M(%-H96QL(@IM<V=S='(@(E!(4"US:V%L(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-($QI9VAT(%)A:6XB
M"FUS9W-T<B`B169T;2X@;&5T(')E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R
M(")%9G1M+B!R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B169T;2X@
M8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")%9G1M+B!S;F4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B
M4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D5F=&TN('-N96)Y9V5R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@
M(E!-(%-U;B(*;7-G<W1R(")%9G1M+B!S;VPB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4$T@5"U3=&]R;7,B
M"FUS9W-T<B`B169T+B!T;W)D96XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C@V"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G
M<W1R(")03U-)6"UU9'9I9&1E;'-E(&UA;F=L97(B"@HC.B!L:6(O87!I+G!H
M<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4$A0+7-K86PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(D9O<G)I;F<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B
M"FUS9W-T<B`B4&%LYG-T:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA
M(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE
M=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$@3GD@1W5I;F5A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")0
M87)T;'D@0VQO=61Y(@IM<V=S='(@(D1E;'9I<W0@<VMY970B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.3D*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$U,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O
M<F0B"FUS9W-T<B`B2V]D96]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(DMO9&5O<F0@YFYD<F5T+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,R!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R
M(")+;V1E;W)D(&9O<FME<G0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,34R(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"FUS
M9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")+;V1E;W)D(&MRYG9E="!V960@4D%$2553+>9G=&YI
M;F<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B2V]D96]R9"!M960@8F5K<N9F=&5L<V4B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R(")+;V1E;W)D.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DMO9&5O<F0Z
M("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#,T(&QI8B](;W)D92]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R(")+;V1E;W)D96YE('-K86P@=N9R92!E;G,N
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E
M(@IM<V=S='(@(DEN9'/F="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D
M(@IM<V=S='(@(DEN9'/F="!F<F$@=61K;&EP<VAO;&1E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A
M=&@B"FUS9W-T<B`B4W1I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B5F5N=&5N
M9&4@;W!S:W)I=FYI;F=E<CHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")&;VQK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E
M;G0B"FUS9W-T<B`B4')O8V5N="(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B561F^'(@=F5D;&EG96AO;&1E;'-E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")5
M9&;X<B!V961L:6=E:&]L9&5L<V4@=F5D(&QO9R!I;F0_(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B5&EL;&%D96QS
M97(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G
M<W1R(")4:6QL861E;'-E(%PB)7-<(B!I:VME('-L971T970N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.3`@;&EB+U9&4R]S;6(N<&AP.C4Y
M,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B5&EL;&%D96QS
M92!NYF=T970B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$V,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V
M-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&EL;&%D96QS97(B"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HU.`HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO
M<&5R;7,O:6YD97@N<&AP.C(R"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")4:6QL861E;'-E<RUA9&UI;FES=')A=&EO;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@
M26YF;W)M871I;VXB"FUS9W-T<B`B4')O9FEL97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B2^9L961Y<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP<&EN97)N
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.38*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G
M:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A
M:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0<FEK:V5R(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S
M='(@(D)A;F%L:71E=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL(@IM<V=S='(@(DML:6L@:2!E;B!C96QL92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")"96MRYF9T(&%T(&1U(/AN<VME
M<B!A="!S;&5T=&4@9&5T=&4@96QE;65N=#HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE
M;65N="XB"FUS9W-T<B`B0F5K<N9F="!A="!D=2#X;G-K97(@870@869LYFYK
M92!D971T92!E;&5M96YT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(U-C(*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(DEN9'1A<W0@96X@
M;>5N960@;V<@970@Y7)S=&%L+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("));F1T87-T(&5T
M(&YA=FX@=&EL(&1E;B!N>64@:V%T96=O<FDZ(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,P,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P,0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B
M26YD=&%S="!E;B!G>6QD:6<@25`M861R97-S92XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C0P(&QI8B](;W)D92]&;W)M+G!H<#HR-C0P"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("));F1T87-T(&5N
M(&=Y;&1I9R!D871O+"!T:F5K(&%N=&%L;&5T(&%F(&1A9V4@:2!MY6YE9&5N
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#<@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(T-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N(@IM<V=S='(@(DEN9'1A<W0@96X@9WEL9&EG('1I9'-A;F=I=F5L<V4N
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B
M4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G
M<W1R(")3:W)I=B!V96YL:6=S="P@:'9A9"!P<F]B;&5M970@9^5R('5D('#E
M(&]G(&AV860@9&5R('-K97(N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G
M<W1R("));F1T87-T('9E;FQI9W-T(&)R=6=E<FYA=FX@;V<@:V]D96]R9"(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@HB3.9S(&;X;&=E;F1E('1E:W-T+B!$=2!32T%,(';F<F4@96YI9R!I(&)E
M=&EN9V5L<V5R;F4@9F]R(&%T(&)R=6=E('-Y<W1E;65T+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"B,Z(&QI
M8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0
M;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(DEN
M9'1A<W0@9&5T(&YY92!K871E9V]R:6YA=FXZ(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&]L86YD(@IM<V=S='(@(E!O;&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI=&EK(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B
M"FUS9W-T<B`B365N:6YG<VWE;&EN9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`IM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;&%C97)I
M;F<@868@8FEL;&5D970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T
M86)L92(*;7-G<W1R(")0;&%C97)I;F<@868@9&5N;F4@=&%B96PB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,2!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN
M;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B4V5N9"!T:6P@9&5N;F4@
M;6%P<&4@*&EK:V4@9V5N;F5M='9U;F=E="!A9B!)34%0*2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L
M('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@(@IM<V=S='(@(DYE9&+X<B!G96YN96T@<V5N97-T("5S('1I
M;65R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS
M9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(DYE9&+X
M<CQB<B`O/F-H86YC92(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P
M+G!H<#HY."!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R
M969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B4')E9G-?;&1A<#H@2W+F=F5T($Q$05`M=61V:61D96P@:6MK
M92!F=6YD970N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN
M<&AP.C,S(&QI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B
M4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!+<N9V970@<V5S<VEO
M;BUU9'9I9&1E;'-E(&EK:V4@9G5N9&5T+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C,R"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")4<GEK(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E
M82!L979E;#H@(@IM<V=S='(@(E1R>6L@=F5D(&]V97)F;&%D96XZ("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S
M=7)E.B`B"FUS9W-T<B`B5')Y:SH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`IM<V=I9"`B4')E=FEE=R(*
M;7-G<W1R(")';&EM="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0IM<V=I9"`B4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D)E=')A9W0@8FEL;&5D
M970@:2!E="!N>70@=FEN9'5E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-38@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C`*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-38@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B
M1F]R<FEG92!T:6QV86QG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T
M<B`B561S:W)I=B!D;VMU;65N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R,R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E!R:79A="!N^&=L92(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E
M<V-R:7!T:6]N(@IM<V=S='(@(E!R;V)L96UB97-K<FEV96QS92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM
M<V=S='(@(E!R;VIE:W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,C<V(&QI8B](;W)D92]&;W)M+G!H<#HR,3$Q
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C<V"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")3=&EK;W)D<W1E
M:W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*
M;7-G<W1R(")/9F9E;G1L:6=E(&[X9VQE(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D]F
M9F5N=&QI9RUN^&=L92UA;&=O<FET;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(D]F9F5N=&QI
M9R!N^&=L92!I;F9O<FUA=&EO;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C(T,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G
M:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(D]F9F5N=&QI9R]P<FEV870M;OAG;&5SYG0M
M9V5N97)E<FEN9R!M:7-L>6MK961E<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*
M;7-G<W1R(")59')E;G,@8F5S:V5D97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E%A=&%R(@IM<V=S='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C8T"FUS9VED(")1=65R>2(*;7-G<W1R(")&;W)E<W#X<F=S96PB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*;7-G:60@(E%U;W1A(@IM<V=S='(@
M(DMV;W1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-C0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B3V9F
M96YT;&EG(%)302UN^&=L92`H)60@8FET*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C0@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C0*;7-G:60@
M(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")%;FME;'1V:7,@=F%L9R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")286EN(@IM<V=S='(@(E)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R
M(")296=N('1I9&QI9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(E)E9VX@
M<V5N="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0X"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")296=N8GEG97(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I
M9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")296=N(&]G('-N92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")2
M86EN('1O(%-N;W<B"FUS9W-T<B`B4VQU9"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")4:6QF
MYFQD:6=T(&5P:6=R86TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM
M<V=S='(@(D9O<FAO;&0B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A
M9"(*;7-G<W1R("),YG,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HT-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")2
M96%D(&UE<W-A9V5S(@IM<V=S='(@(DSF<R!B97-K961E<B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+B(*;7-G<W1R(")6:7)K96QI9R!S;&5T=&4@)7,_($1E;FYE
M(&]P97)A=&EO;B!K86X@:6MK92!B;&EV92!O;6=J;W)T+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)6:7)K
M96QI9R!S;&5T=&4@9&%T82!F;W(@8G)U9V5R("5S/R!$96YN92!O<&5R871I
M;VX@:V%N(&EK:V4@8FQI=F4@;VUG:F]R="XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R(")/;6?X<B!D:6X@<VED<W1E(&AA;F1L
M:6YG(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B3W!D871E
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")/<&9R:7-K(&1Y
M;F%M:7-K92!M96YU+65L96UE;G1E<CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R
M(")'96YO<&9R:7-K('!O<G1A;'9I<VYI;F<Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.#DT(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$S"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R(")296=U;.9R
M="!U9'1R>6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,Q(&QI
M8B](;W)D92]&;W)M+G!H<#HS,C,Q"FUS9VED(")296QA=&EO;G-H:7`@0G)O
M=W-E<B(*;7-G<W1R(")296QA=&EO;G-LYG-E<B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")'96YO<&9R:7-K(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B"FUS9W-T
M<B`B3F]T97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED
M(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")&:F5R;F4@<V5R=F5R92(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@
M(D9J97)N(%523"`H:'1T<#HO+W=W=RYE:W-E;7!E;"YD:R]H;W)D92DZ(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,R!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R"FUS9VED(")296UO=F4B"FUS
M9W-T<B`B4VQE="(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ
M,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E-L970@8FQO:R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3D*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B
M4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")&:F5R;B!K;VQO;FYE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B
M4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B4VQE="!F;W)M871E<FEN9R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO
M=F4@<&%I<B(*;7-G<W1R(")3;&5T('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")&:F5R;B!L
M86=R970@<VMR:7!T(&9R82!S97)V97)S(&UI9&QE<G1I9&EG92!K871A;&]G
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")&:F5R;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N="(*;7-G<W1R(")&:F5R;B!D971T92!P=6YK="!F<F$@9&]K=6UE;G1E
M="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G
M:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(E-L970@8G)U9V5R(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")3;&5T(&)R=6=E<CH@
M)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S."!L:6(O
M2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M(")!;FUO9&YI;F<@:W5N;F4@:6MK92!B97-V87)E<RX@4F5T=7)N97)E="!F
M96IL:V]D93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD
M+B(*;7-G<W1R(")!;FUO9&5T('1J96YE<W1E(&MU;FYE(&EK:V4@9FEN9&5S
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@U(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3(W"B,Z(&QI8B](;W)D92YP:'`Z,3@U(&QI
M8B](;W)D92YP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D
M(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(DMRYG9E9&4@)R5S)R!E<B!I:VME(&%N9VEV970@:2`E<RUK;VYF
M:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<X"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW,S$@;&EB+U9&4R]F='`N<&AP.C@V,2!L
M:6(O5D93+W-Q;"YP:'`Z-C<X"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<S
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2W+F=F5T
M(%PB)7-<(B!E<B!I:VME(&%N9VEV970@:2!61E,@:V]N9FEG=7)A=&EO;BXB
M"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S8@;&EB+TAO<F1E+U5T
M:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+
M<N9V961E(%PB)7-<(B!E<B!I:VME(&%N9VEV970@:2!K;VYF:6=U<F%T:6]N
M96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,V
M(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,S8*;7-G:60@(E)E<75I
M<F5D($9I96QD(@IM<V=S='(@(DMRYG9E="!F96QT(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S$@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(Q"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,SD@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M,`HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S(Q('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B3G5L<W1I
M;"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")2
M97-E="!087-S=V]R9"(*;7-G<W1R(").=6QS=&EL(&MO9&5O<F0B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U
M<B!087-S=V]R9"(*;7-G<W1R(").=6QS=&EL(&1I="!K;V1E;W)D(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,87-T(%%U
M97)Y(@IM<V=S='(@(D=E;G-K86(@<VED<W1E(&9O<F5S</AR9W-E;"(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]P:'!S:&5L;"YP:'`Z-S(@
M861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM<V=S='(@
M(E)E<W5L=&%T97(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T
M;R!/<'1I;VYS(@IM<V=S='(@(E1I;&)A9V4@=&EL(&EN9'-T:6QL:6YG97)N
M92(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B
M4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")'96YT87-T(&YY="!K;V1E
M;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)E
M=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(D=E;F1A;B!K;VYF:6=U<F%T:6]N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS(@IM<V=S='(@(DEN9'-T:6QL:6YG97(@9F]R(%)I8V@@5&5X="UR961I
M9V5R:6YG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2
M:61D;&5S(@IM<V=S='(@(D?E9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"FUS9VED(")2:6=H="(*;7-G
M<W1R(")(^&IR92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT(&AE861E<B(*
M;7-G<W1R(")(^&IR92!T;W!T96MS="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,P.3D@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3D*;7-G:60@(E)I
M9VAT('9A;'5E<R(*;7-G<W1R(")(^&IR92!VYG)D:65R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS
M9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4N9K:V4M96=E;G-K
M86)E<BXN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F5G96PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4G5MYFYI96XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q
M.#`B"FUS9W-T<B`B4F]TZ7(@,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R
M(")2;W3I<B!V96YS=')E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B4F]T
MZ7(@:/AJ<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R
M(")2YFMK92UE9V5N<VMA8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I
M97,B"FUS9W-T<B`B4N9K:V4M96=E;G-K86)E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*
M;7-G<W1R(")2YFMK97(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B
M4W1R96=E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B4W1R96=E<B!V:6P@
M;W!T<N9D92!M96QL96T@<N9K:V5R(&]G(&MO;&]N;F5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS
M9W-T<B`B4W1R96=E<B!V:6P@:W5N(&]P='+F9&4@;65L;&5M(&MO;&]N;F5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`B4W1R96=E<B!V:6P@:W5N(&]P='+F9&4@;65L;&5M
M('+F:VME<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U
M;B(*;7-G<W1R(")59&;X<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DY(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA
M;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<VQA;F0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E)W86YD82(*;7-G<W1R(")2=V%N9&$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-2!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T
M=7)E(@IM<V=S='(@(DMR>7!T;V=R869I<VL@4R]-24U%+7-I9VYA='5R(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T
M960@365S<V%G92(*;7-G<W1R(")3+TU)344M<VEG;F5R970@8F5S:V5D(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,2!L:6(O2&]R9&4O
M075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,+>9G=&YI;F<@97(@:6MK
M92!T:6QGYFYG96QI9RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@
M(E-13"UF;W)T;VQK97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C<T(&QI8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")344P@<W1A=&5M
M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-13"UU9'1R>6L@9F]R
M(&]P<VQA9R!A9B!VYG)D:65R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S4*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(E-50T-%4R(*"B,Z
M(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")3
M44PM9F]R=&]L:V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B3/AR(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4VMT+B!(96QE
M;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B4VMT+B!+:71T<R!O9R!.979I<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-K="X@3'5C:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T
M<B`B4VMT+B!0:65R<F4@;V<@36EQ=65L;VXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@
M(E-K="X@5FEN8V5N="!O9R!'<F5N861I;F5R;F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`B4V%M;64@<F%M;64@*%]S96QF*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E
M(@IM<V=S='(@(E-O82!4;VUE(&]G(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")3871E
M;&ET=61B>61E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA
M(@IM<V=S='(@(E-A=61I87)A8FEE;B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")'96TB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(D=E;2!<(B5S7"(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E("5S(@IM<V=S='(@(D=E;2!<(B5S7"(B"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS
M9W-T<B`B1V5M;64@26YD<W1I;&QI;F=E<B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB1V5M(&=E;F5R97)E="!K
M;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T(&D@9&EN('-E<G9E<G,@;6ED
M;&5R=&ED:6=E("(*(FMA=&%L;V<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B1V5M="`E<RUK;VYF:6=U<F%T:6]N+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(D=E;71E('-K<FEP="!F;W(@;W!G<F%D97)I;F<@868@;W!SYG1N
M:6YG('1I;#H@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS
M9W-T<B`B4W!R961T('1O<F1E;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")6:61E;G-K86(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E/X
M9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E
M87)C:"!%;F=I;F5S(@IM<V=S='(@(E/X9V5M87-K:6YE<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-34@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y
M-34*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")6YFQG(&9I;&5R(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(E;F;&<@96X@9&%T;R(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B5N9L9R!E;B!G<G5P<&4@870@=&EL9OAJ
M92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E
M;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")6YFQG(&5N(&YY(&5J97(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C
M="!A('-E<G9E<B(*;7-G<W1R(")6YFQG(&5N('-E<G9E<B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R
M('1O(&%D9"(*;7-G<W1R(")6YFQG(&5N(&)R=6=E<B!A="!T:6QF^&IE(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED
M(")396QE8W0@86QL(@IM<V=S='(@(E;F;&<@86QL92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#,*
M;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")6
MYFQG(&%L;&4@9&%T;RUK;VUP;VYE;G1E<BXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE
M8W0B"FUS9W-T<B`B5N9L9R!E="!O8FIE:W0B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM
M<V=S='(@(E;F;&<@:6YG96XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F
M<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*
M(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)6
MYFQG(&1E('1E9VX@9'4@:&%R(&)R=6<@9F]R(&9R82!K87-S97)N92!N961E
M;F9O<BX@1&4@:V%N('/E(&ML:7!P97,@;V<@(@HB:V]P:65R97,@9G)A('1E
M>'1F96QT970N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E;F;&<@
M9&%T;RUA9'-K:6QL97)E;CHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B
M5N9L9R!D871O9F]R;6%T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")6YFQG(&1E;B!I9&5N=&ET970L
M('-O;2!D=2!V:6P@YFYD<F4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(E;F;&<@=&ED<RUA9'-K:6QL97)E;CHB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB
M"FUS9W-T<B`B5N9L9R!T:61S9F]R;6%T.B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+B(*;7-G<W1R(")6YFQG('1O(&9E;'1E<BP@9&5R('-V87)E<B!T:6P@
M:&EN86YD96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I
M9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")6YFQG(&1I
M;B!F87)V97-A;6UE;G/F=&YI;F<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R(")6YFQG(&1I="!F;W)E=')U:VYE('-P<F]G.B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R
M;V)L96T@4F5P;W)T(@IM<V=S='(@(E-E;F0@<')O8FQE;6)E<VMR:79E;'-E
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-#(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*
M;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E-E;F0@4TU3(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B
M1OAL97(Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I
M9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*
M;7-G<W1R(")397)B:65N(&]G($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")397)I
M96YU;6UE<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*
M;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(E-E<G9E<BUD871A(&9O<FME<G0@96QL97(@:6MK92!T:6QGYFYG
M96QI9RXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I
M;VX@061M:6XB"FUS9W-T<B`B4V5S<VEO;G-A9&UI;FES=')A=&]R(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED
M(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(E-E<W-I;VXM240@=61L
M^&)E="XB"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM
M<V=S='(@(E-E<W-I;VYE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,30@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G
M<W1R(")-YFYG9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G
M:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB26YD
M<W1I;&QI;F=E<B!D97(@=&EL;&%D97(@9&EG(&%T(&YU;'-T:6QL92!D:70@
M:V]D96]R9"P@:'9I<R!D=2!N;V=E;G-I;F1E("(*(G-K=6QL92!G;&5M;64@
M9&5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("));F1S=&EL(&9J97)N92!S97)V
M97)E+"!S;VT@9'4@^&YS:V5R(&%T('1I;&?E(&9R82!D:6X@<&]R=&%L+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+B(*;7-G<W1R("));F1S=&EL(&1I;B!F;W)E=')U:VYE('-P<F]G+2P@=&ED
M<WIO;F4M(&]G(&1A=&]V86QG+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB
M9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B));F1S=&EL(&1I;F4@;W!S
M=&%R='-A<'!L:6MA=&EO;F5R+"!F87)V97-A;6UE;G/F=&YI;F<L('-I9&5O
M<&9R:7-K;FEN(&]G("(*(F%N9')E('9I<VYI;F=S=&EL=F%L9RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R
M("));F1S=&EL;&EN9R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE(@IM<V=S='(@(E-K<FEP=',@=&EL(&]P9W)A9&5R:6YG(&%F(&]P<^9T
M;FEN9R!T:6QGYFYG96QI9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W
M:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")&;&5R92!S=&5D97(@;75L
M:6<@;65D('!A<F%M971E<F5N.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E
M>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE<FYE(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M4VAO<'!I;F<B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")+;W)T(&]P<W5M;65R
M:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM
M<V=S='(@(E-K86P@:'5R=&EG+71A<W1E<B!D969I;F5R97,@9F]R(&1E(&9L
M97-T92!H96YV:7-N:6YG97(_("CW*2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(S(&QI8B](;W)D92]097)M<RYP:'`Z,S(S"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$S"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS
M9VED(")3:&]W(@IM<V=S='(@(E9I<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C
M=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB5FES(&9O<G-K96QL96YE(&UE;&QE
M;2!D96X@9V5M=&4@;V<@9&5N(&YY;&EG="!G96YE<F5R961E(&MO;F9I9W5R
M871I;VXN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R
M(")6:7,@=&ED<W!U;FMT(&9O<B!S96YE<W1E('1I;&=A;F<@=F5D('#E;&]G
M;FEN9S\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P
M(&]R:6=I;F%L(@IM<V=S='(@(E9I<R!M=6QI9VAE9"!F;W(@870@8F5H;VQD
M92!O<')I;F1E;&EG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B4VAO=R!P:6-K97(B
M"FUS9W-T<B`B5FES('-N=7!P97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M(@IM<V=S='(@(E9I<R!486)E;&]P97)A=&EO;F5R+6MN87!P96X@:2!M96YU
M96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G
M<W1R(")6:7,@)7,M;65N=65N('1I;"!V96YS=')E/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R(")6:7,@9&EA;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!T86)E
M;&-E;&QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B5FES(&1I86QO9W9I;F1U92!M960@96=E
M;G-K86)E<B!F;W(@=&%B96QL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")6:7,@9&EA
M;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!T86)E;'+F:VME;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B5FES(&1I86QO9W9I;F1U92!M960@96=E;G-K86)E<B!F;W(@
M8FEL;&5D970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G
M<W1R(")6:7,@869S96YD=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")">6=E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S
M"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(D)Y9V5R('1I9&QI9W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM
M<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(D)Y9V5R('-E;G0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B
M4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B0GEG97(@:2!NYG)H
M961E;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C$Y(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0X,`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B
M4VAR:6YK(@IM<V=S='(@(E-K<G5M<"(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R
M,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,C@U"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<W-"!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z.3(R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.CDX-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z,3$Q-B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ
M,30Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B"FUS9W-T<B`B4VMR=6UP(&5L;&5R(&9L>70@;F%B;V)L;VMK92!A
M9B!V96IE;B!F^')S="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B4VMR:78@:6YD(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3,@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R
M(")5;F1E<G-K<FEF="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED
M(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(E-I9VYA='5R86QG;W)I
M=&UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B
M4VEN9V%P;W)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@T
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.#DV(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C0V(&QI8B](;W)D92]&;W)M+G!H<#HR.3$R"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3`U(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8U
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"FUS9VED(")3:7IE(@IM<V=S='(@
M(E-T^')R96QS92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@
M(E-P<FEN9R!V961L:6=E:&]L9&5L<V4@;W9E<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=F%K:65T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]V96YI96XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B
M4VYO=R(*;7-G<W1R(")3;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M4VYE8GEG92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4VYE8GEG97(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM
M<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(E-N96)Y9V5R('1I
M9&QI9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B4VYE8GEG
M97(@<V5N="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED(")3
M;F]W(&1E<'1H.B`B"FUS9W-T<B`B4VYE9'EB9&4Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z("(*;7-G<W1R(")3;F7F:W9I=F%L96YT(&D@=F%N9#H@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B4V%L;VUO
M;OAE<FYE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@
M(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@
M(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B4V%N9V4@;V<@<&]E<VDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`X(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3`X"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3
M;W)T97)I;F=S=F%L9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ.#D@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3@Y(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B069S96YD
M97)A9')E<W-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B
M"FUS9W-T<B`B4WED869R:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R
M(")3>61E=7)O<.9I<VL@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',B"FUS9W-T<B`B4WED($=E;W)G:6$@;V<@1&4@<WED;&EG92!386YD=VEC
M:/AE<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B
M4WED;&EG92!H86QV:W5G;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<R(*;7-G<W1R("),=69T(&UE;&QE;2!N86)O8V5L;&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*
M;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&PB"FUS9W-T<B`B3'5F="!M96QL96T@:6YD:&]L9"!O9R!R86UM92!I(&-E
M;&QE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U(&QI8B](;W)D
M92]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R(")-96QL96UR
M=6US=&%N9V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4U"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(DUE;&QE
M;7)U;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T
M<B`B3'5F="!O9R!F;W)R:6YG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM
M<V=S='(@(E-P86YI96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-K:61T<&]S="(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@
M26YP=70B"FUS9W-T<B`B26YD=&%S=&YI;F<@9F]R('-P96-I86QK87)A:W1E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B1&5L(&-E;&QE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(D1E;"!K;VQO
M;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(D1E;"!RYFMK
M92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S
M(@IM<V=S='(@(E-P;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA
M(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V"FUS9VED(")3=&%N
M9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#8@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C<Y,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X-B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G
M<W1R(")"96=Y;F1E;'-E<^5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$*
M;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(D1E;'-T870@96QL
M97(@<')O=FEN<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A='5S(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C<Y-PIM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B3&%G<FEN9W-F
M;W)M870B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T
M($%D9')E<W,B"FUS9W-T<B`B5F5J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*
M;7-G<W1R(")'96YN96US=')E9VYI;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,S"FUS9VED(")3
M=')I;F<@;&ES="(*;7-G<W1R("),:7-T92!A9B!S=')E;F=E(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS
M9W-T<B`B1FIE<FX@9&]MYFYE(&9R82!A9')E<W-E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@
M(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T:6P@6T-34UTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*
M;7-G<W1R(")3^&XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E5N9&5R:V%T86QO9R!<(B5S7"(@:6MK92!F=6YD970N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I
M9"`B4W5B:F5C="(*;7-G<W1R(")%;6YE(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP
M.C,Q.`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M
M+U)E;F1E<F5R+G!H<#HS,3@*;7-G:60@(E-U8FUI="(*;7-G<W1R(")';V1K
M96YD(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB06YM;V1N:6YG(&]M(&%T
M('1I;&;X:F4@7"(E<UPB('1I;"!S>7-T96T@869S96YD="X@($1U(&MA;B!I
M:VME(&QO9V=E('#E(&;X<B`B"B)D:6X@86YM;V1N:6YG(&5R(&)L979E="!A
M;F5R:V5N9'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(DQA=B!S:W)I
M9G0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,C@*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E5D9OAR="(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPB(&)L978@=&EL9OAJ970@=&EL('-Y<W1E;65T+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN
M(@IM<V=S='(@(D1A=&$@9F]R(&)R=6=E<B!<(B5S7"(@8FQE=B!S;&5T=&5T
M(&9R82!S>7-T96UE="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@<VQE
M='1E="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B7"(E<UPB('-L971T970@9G)A('-Y<W1E;65T+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N(@IM<V=S='(@(DMO;F9I9W5R871I;VX@=&EL8F%G96;X<G0N($=E
M;FEN9&SF<R!F;W(@870@<V4@YFYD<FEN9V5R;F4N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E)E<V5R=F5K;VYF:6=U<F%T:6]N(&=E;70N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(E)E<V5R=F5K;VYF:6=U<F%T:6]N9FEL("5S(&=E
M;70N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S
M7"(@;W!D871E<F5T+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R(")<(B5S7"(@<VMR979E
M="XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("));F1H;VQD(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G
M<W1R(")3;VQO<&=A;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*
M;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4V]L;F5D9V%N9R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")3=6YN
M>2(*;7-G<W1R(")3;VQR:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")3;VQO<&=A;F<B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(E-O;&]P
M9V%N9R]S;VQN961G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(E-O;&]P9V%N9SH@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B
M4W5N<V5T(@IM<V=S='(@(E-O;&YE9&=A;F<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")3
M;VQN961G86YG.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")(YG9E
M="!S:W)I9G0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"FUS
M9VED(")3=7!P;W)T(@IM<V=S='(@(DAJYFQP(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B169T97)N879N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N
M(@IM<V=S='(@(E-V86QB87)D(&]G($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W87II;&%N9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-V97)I9V4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4V-H=V5I>B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO
M9R!D96QE=&5D(@IM<V=S='(@(E-Y;F,@;&]G('-L971T970B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B
M4WEN8TU,(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW
M(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(E-Y;G1A:W-F96IL(&D@
M<_AG96QE9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P
M=6)L:6,B"FUS9W-T<B`B4WER:65N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B
M5&]R9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C,*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(E1O<F1E
M;B!O9R!V:6YD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(E1O<F1E;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED
M(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R(")4;W)D96X@=&ED;&EG="(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8@;&EB+TAO<F1E+T1A
M=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135BUF
M:6PB"@HC.B!L:6(O2&]R9&4O54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B
M;&4B"FUS9W-T<B`B5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T
M:65S(@IM<V=S='(@(E1A8F5L+65G96YS:V%B97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"B,Z(&QI8B](;W)D92]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS
M9W-T<B`B5&%B96QMYFYG9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T
M:65S(@IM<V=S='(@(E1A8F5L+65G96YS:V%B97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I
M=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N
M+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XL($1E;B!K:6YE
M<VES:V4@<')O=FEN<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A
M;B(*;7-G<W1R(")4861J:6MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ86YI
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B3>5L.B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,R(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,R
M"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(D]P9V%V97(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-"!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU
M;6)E<B(*;7-G<W1R(")496QE9F]N;G5M;65R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(E1E;7`N('-I9'-T92!T:6UE.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@
M(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R871U<CH@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S
M(@IM<V=S='(@(E1E;7!E<F%T=7(\8G(@+SXH)7-(^&HE<R\E<TQA=B5S*2`F
M9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV
M.34@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4VMA
M8F5L;VX@7"(E<UPB(&EK:V4@9G5N9&5T+B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")3:V%B96QO;BUA9&UI;FES=')A=&EO;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R
M-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S,R-PIM<V=I9"`B5&5X="(*;7-G<W1R(")496MS="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R
M(")296X@=&5K<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@
M(E1E:W-T+6IU<W1E<FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5K
M<W0M=&]P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B5&]R(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@
M(E1H86D@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N
M9"(*;7-G<W1R(")4:&%I;&%N9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#4Q(&QI8B]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H92!&5%`@
M97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D944"UU9'9I
M9&1E;'-E;B!E<B!I:VME('1I;&?F;F=E;&EG+B(*"B,Z(&9R86UE=V]R:R](
M:7-T;W)Y+TAI<W1O<GDN<&AP.C4U(&QI8B](;W)D92](:7-T;W)Y+G!H<#HU
M-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G
M<W1R(")(:7-T;W)I:RUS>7-T96UE="!E<B!S;.5E="!F<F$N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S@@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G
M<W1R(")(;W)D92]+;VQA8BUI;G1E9W)A=&EO;G-M;W1O<F5N('5N9&5R<W3X
M='1E<B!I:VME(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0
M+T)O;VLN<&AP.C$R.3@@;&EB+TYE="])35-0+T)O;VLN<&AP.C$R.3@*;7-G
M:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM
M<V=S='(@(DE-4U`M;&]G9V5N(&MU;FYE(&EK:V4@:VQA<F?X<F5S+B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G
M<W1R(")-86EN=&5N86YC93HZ+6ML87-S96X@8FQE=B!I:VME(&EN9&SF<W0B
M"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED
M(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS
M9W-T<B`B5&EL=F%L9W-V:6YD=65T(&5R(&)L979E="!L=6MK970N($%F<VQU
M='1E<BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PHC.B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,"!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R
M,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(U,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B
M"B)!9&UI;FES=')A=&]R96X@8FQI=F5R(&[X9'0@=&EL(&%T(&MO;F9I9W5R
M97)E(&5N('!E<FUA;F5N="!4:6QL861E;'-E<RTB"B)B86-K96YD+"!H=FES
M(&1U('9I;"!A;G9E;F1E(%1I;&QA9&5L<V5R+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H
M92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(DMU;B!U;F1E<G-I9&5N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,SD*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I
M9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B
M87-E+B(*;7-G<W1R("(B"B)+;VYT86MT+4E$+6YU;6UE<F5T(&)L978@:6MK
M92!A;F=I=F5T+"!E9G1E<FQA9'0@=&]M="!E;&QE<B!B;&5V(&EK:V4@9G5N
M9&5T("(*(FD@9&%T86)A<V5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HU,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT
M96X@8FQE=B!T:6QF^&IE="!T:6P@9&ET(&%D<F5S<V5K87)T;W1E:V5T+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB1&5N(&SX<V=J;W)T92!0
M1U`M<VEG;F%T=7(M8FQO:R!E<B!K<N9V970@9F]R(&%T(&MU;FYE('9E<FEF
M:6-E<F4@9&5N("(*(G-I9VYE<F5D92!B97-K960N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*
M;7-G<W1R("(B"B)$:7-T<FEB=71I;VYS;&ES=&4M240@97(@96YT96X@:6MK
M92!A;F=I=F5T+"!T;VUT(&5L;&5R(&EK:V4@9G5N9&5T(&D@(@HB9&%T86)A
M<V5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"XB"FUS9W-T<B`B1&ES=')I8G5T:6]N<VQI<W1E;B!I:VME(&%N9VEV
M970N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38@;&EB+TAO
M<F1E+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(DMR>7!T97)I;F=S9F%C:6QI=&5T97)N92!K<N9V97(@96X@<VEK:V5R('=E
M8BUF;W)B:6YD96QS92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$X-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R.`HC.B!L:6(O2&]R
M9&4N<&AP.C$X-B!L:6(O2&]R9&4N<&AP.C4R.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M(@IM<V=S='(@(D9I;&5N("5S(&+X<B!I;F1E:&]L9&4@96X@)7,M:6YD<W1I
M;&QI;F<N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-SD@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3@*(SH@;&EB+TAO<F1E+G!H<#HQ
M-SD@;&EB+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS
M9W-T<B`B1FEL96X@)7,@8OAR(&EN9&5H;VQD92!N;V=L92`E<RUI;F1S=&EL
M;&EN9V5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-B!L
M:6(O5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B1FEL96X@:V%N(&EK:V4@
M:V]P:65R97,@;W9E;G#E('-I9W-E;'8N(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,C@P(&QI8B](;W)D92]$871A+G!H<#HR.#`*;7-G:60@(E1H
M92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")&:6QE;B!I;F1E
M:&]L9'0@:6YG96X@9&%T82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R
M(")&^&QG96YD92!E<B!H;W9E9&5R;F4@9G)A(&1E;FYE(&UE<W-A9V4O<F9C
M.#(R+6)E<VME9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I
M<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO
M<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M
M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G
M970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T
M;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D9U;&1S:^9R;7-T:6QS=&%N
M9"!V:61E<R!A="!V;VQD92!P<F]B;&5M97(@:2!);G1E<FYE="!%>'!L;W)E
M<B!G<G5N9&5T("(*(F)R;W=S97(M9F5J;"P@<V]M('9I(&EK:V4@:&%R(&MU
M;FYE="!O;6?E+B!$=2!V:6P@;75L:6=V:7,@;W!L979E("(*(F9O<G9A;G-K
M961E('9I<VYI;F=E<BP@;6%N9V5L('#E(&5D:71E<FEN9W-F=6YK=&EO;F5R
M(&]G+V5L;&5R('1I;&;F;&1I9V4@(@HB8G)O=W-E<BUN961B<G5D+B!(=FES
M(&1I="!S>7-T96T@97(@5VEN9&]W<R9N8G-P.SEX('9I;"!D=2!M960@:/AJ
M("(*(G-A;F1S>6YL:6=H960@;W!L979E("='96YE<F5L(&)E<VMY='1E;'-E
M<V9E:FPG(&]G('9I;"!B;&EV92!N^&1T('1I;"!A="`B"B)G96YS=&%R=&4@
M;6%S:VEN96XN7%QN7%QN1'4@97(@;G4@861V87)E="X@(%1R>6L@3TL@:'9I
M<R!D=2!S=&%D:6<@^&YS:V5R(&%T("(*(G!R^'9E="!F=6QD<VOF<FUS<F5D
M:6=E<FEN9RXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@7"(E<UPB(&5R('-L971T970N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B2W5N('9E;G-T<F4@<VED92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ-3<@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,34W"FUS
M9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B
M4&QA8V5R:6YG96X@868@1VYU4$<M<')O9W)A;6UE="!S:V%L(&=I=F5S('1I
M;"!#<GEP=%]P9W`Z.BUK;&%S<V5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HR,#(@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<
M;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)"97-K961E
M;BP@<V]M(&5R('-E;F1T(&1E;B`E<R!T:6P@)7,@;65D(&5M;F5T(%PB)7-<
M(B!E<B!B;&5V970@=FES="Y<;B(*(D1E='1E(&5R(&EN9V5N(&=A<F%N=&D@
M9F]R+"!A="!B97-K961E;B!R96YT(&9A:W1I<VL@97(@8FQE=F5T(&SF<W0@
M96QL97(@(@HB9F]R<W3E970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM
M<V=S='(@(DYA=FYE="P@9&5R('-K86P@8G)U9V4L(&[E<B!D97(@:&5N=FES
M97,@=&EL('-K<FEV97-I9&5N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#<T(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(D%N=&%L
M;&5T(&%F(&9E;'1E<B!S:V%L(';F<F4@970@=&%L+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM
M<V=S='(@(F]P96YS<VPM;6]D=6QE="!E<B!K<N9V970@868@2&]R9&5?0W)Y
M<'1?<VUI;64Z.BUK;&%S<V5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<RYP:'`Z,CDU(&QI8B](;W)D92]0<F5F<RYP:'`Z,CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X
M:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)0<N9F97)E;F-E;B!<
M(B5S7"(@:W5N;F4@:6MK92!G96UM97,@9F]R9&D@9&5N<R!D871A(&]V97)S
M:W)I9&5R(&1E;B`B"B)M86MS:6UA;'0@=&EL;&%D=&4@<W3X<G)E;'-E(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-2!L:6(O2&]R9&4O34E-12]6
M:65W97(O;7-E>&-E;"YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z
M,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS
M-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*(E!R;V=R86UM970L(&1E<B!B<G5G97,@=&EL(&%T
M(&)E=')A9W1E(&1E;FYE(&1A=&%T>7!E("@E<RDL(&)L979E="!I:VME("(*
M(F9U;F1E="!PY2!S>7-T96UE="XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT.#<@;&EB+T9I;&4O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q
M=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB
M"FUS9W-T<B`B0VET871I;VYS=&5G;F5T('-K86P@=N9R92!E="!E;FME;'0@
M=&5G;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@
M;VYL>2(*;7-G<W1R(")+=6X@:/AJ<F4@;V<@=F5N<W1R92!S:61E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DMU
M;B!S:61E;B!T:6P@:/AJ<F4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-SD@;&EB+T9I;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A
M<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B
M061S:VEL;&5L<V5S=&5G;F5T('-K86P@=N9R92!E="!E;FME;'0@=&5G;BXB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R(")397)V97)E;B!<(B5S7"(@97(@<VQE='1E="XB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`B4V5R=F5R96X@7"(E<UPB(&5R(&=E;70N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B3W!S:W)I=FYI
M;F=S86YM;V1N:6YG96X@9F]R("5S(&5R('-L971T970N(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B1&5N(&%N9VEV;F4@<N9K:V4@*"5D*2!E:W-I<W1E
M<F5R(&EK:V4N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,S,P
M"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B1&5N(&%N9VEV;F4@<N9K:V4@96MS:7-T97)E<B!I:VME+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<Y(&QI8B]61E,O<W%L+G!H
M<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE
M(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&5N(&UI9&QE<G1I
M9&EG92!F:6P@7"(E<UPB(&9I;F1E<R!I:VME+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#(*;7-G
M:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E
M>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B1&5N('1E:W-T+"!S;VT@9'4@
M:6YD=&%S=&5D92P@<&%S<V5R(&EK:V4@=&EL('1E:W-T96X@<.4@<VOF<FUE
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>2(*;7-G<W1R(")+=6X@=&]P(&]G(&)U;F0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@
M=&]P('-I9&4@;VYL>2(*;7-G<W1R(")+=6X@=&]P(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,S(W(&QI8B](;W)D92]$871A+G!H<#HS,C<*;7-G
M:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V
M:6]U<R!S=&5P+B(*;7-G<W1R(")$96X@869S96YD=&4@:6YF;W)M871I;VX@
M97(@=&%B="!S:61E;B!S:61S=&4@=')I;BXB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-S(*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-S(@;&EB+TAO<F1E
M+T1A=&$O8W-V+G!H<#HR-C(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B1&5N(&]V97)F^')T92!F:6P@
M:W5N;F4@:6MK92!G96UM97,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G
M:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")W96%T:&5R+F-O;2UB;&]K:V5N(&5R(&EK:V4@=&EL9^9N9V5L
M:6<N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B5&5M82UK871A;&]G970@7"(E<UPB(&EK:V4@9G5N9&5T+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9V5N('1I;'9A;&<@=&EL('+E9&EG
M:&5D+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,U
M,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S4P"FUS9VED(")4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB
M"FUS9W-T<B`B1&5R(&9O<F5F:6YD97,@:6YG96X@9&5L92P@<V]M(&MA;B!V
M:7-E<R!I;F1L96IR970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30P,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES
M(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB1&5R(&5R
M(&9O<B!M86YG92!T96=N(&D@9&5T=&4@9F5L="X@1'4@:&%R(&EN9'1A<W1E
M="`E<R!T96=N.R!D=2!S:V%L("(*(FEN9'1A<W1E(&UI;F1R92!E;F0@)7,N
M(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S
M7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B1&5R(&]P<W1O9"!E="!P
M<F]B;&5M('5N9&5R('1I;&;X:F5L<V5N(&%F("<E<R<@=&EL('-Y<W1E;65T
M.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(D1E<B!O
M<'-T;V0@970@<')O8FQE;2!U;F1E<B!F:F5R;F5L<V4@868@9&%T82!F;W(@
M8G)U9V5R(%PB)7-<(B!F<F$@(@HB<WES=&5M970Z("(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R(")$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@<VQE=&YI;F<@868@
M7"(E<UPB(&9R82!S>7-T96UE=#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D
M871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")$97(@;W!S=&]D(&5T('!R;V)L
M96T@=6YD97(@;W!D871E<FEN9R!A9B!<(B5S7"(Z("5S(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(W(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+B(*;7-G<W1R(")$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@9FEL;W9E
M<F;X<G-L96XZ($EN9V5N("5S(&)L978@;W9E<F;X<G0N(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,R(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G
M97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S
M*2XB"FUS9W-T<B`B(@HB1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9I
M;&]V97)F^')S;&5N.B`E<R!V87(@<W3X<G)E(&5N9"!D96X@;6%K<VEM86QT
M("(*(G1I;&QA9'1E('-T^')R96QS92`H)60@8GET97,I+B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS-"!L:6(O2&]R9&4O0G)O=W-E
M<BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL
M>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(D1E<B!O<'-T;V0@
M970@<')O8FQE;2!U;F1E<B!F:6QO=F5R9OAR<VQE;CH@)7,@8FQE=B!K=6X@
M9&5L=FES="!O=F5R9OAR="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")$97(@;W!S=&]D(&5N
M(&9E:FP@=6YD97(@=FES;FEN9R!A9B!D96YN92!B97-K961D96PB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")$97(@;W!S
M=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T97)I;F=E;B!A9B!K;VYT86MT:6YF
M;W)M871I;VXN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q
M(&QI8B](;W)D92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R
M(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T97)I;F=E;B!A9B!I
M0V%L96YD87(@9&%T82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R
M871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E
M9"!F:65L9"XB"FUS9W-T<B`B(@HB1&5R(&]P<W1O9"!E;B!F96IL(&D@:V]N
M9FEG=7)A=&EO;G-F;W)M=6QA<F5N+B!.=6QI9W9I<R!H87(@9'4@=61E;&%D
M="!E="`B"B)K<N9V970@9F5L="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R('5D9OAR96QS92!A9B!D96X@
M86YG:79N92`B"B)A9')E<W-E:V%R=&]T96MS9G5N:W1I;VXN(%!R^'8@:6=E
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O
M;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&]P9&%T97)I;F<@868@:V]N
M=&%K="UD971A;&IE<FYE+B!0<OAV(&EG96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@;W!D871E<FEN
M9R!A9B!D:7-T<FEB=71I;VYS;&ES=&5N+B!0<OAV(&EG96XN(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S
M='(@(D1E;FYE($E-05`M<V5R=F5R('5N9&5R<W3X='1E<B!I:VME(&1E;&EN
M9R!A9B!M87!P97(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HT."!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HT.`IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92XB"FUS9W-T<B`B1&5T=&4@='ED97(@:6MK92!PY2!A="!VYG)E
M(&5T(&=Y;&1I9W0@<F%R+6%R:VEV+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-3(@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII
M<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(D1E;FYE('1Y9&5R(&EK:V4@<.4@
M870@=N9R92!E;B!G>6QD:6<@>FEP+69I;"XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3(W(&QI8B](;W)D92]&;W)M+G!H<#HS,3(W"FUS9VED
M(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E
M<BXB"FUS9W-T<B`B1&5T=&4@='ED97(@:6MK92!PY2!A="!VYG)E(&5T(&=Y
M;&1I9W0@:V]R=&YU;6UE<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*(D1E;FYE(&1R:79E<B!T:6QL861E<B!A
M9G-E;F1E;'-E(&%F(&)E<VME9&5R(&EG96YN96T@0VQI8VMA=&5L;"`H:'1T
M<#HO+R(*(F-L:6-K871E;&PN8V]M*2!A9&=A;F=S<'5N:W1E="!V960@8G)U
M9R!A9B!(5%10($%022(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,T(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)$96YN92!D<FEV
M97(@=&EL;&%D97(@869S96YD96QS92!A9B!B97-K961E<B!I9V5N;F5M(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F%D9V%N9W-P=6YK=&5T('9E9"!B
M<G5G(&%F($A45%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,34*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*(D1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E;F1E
M;'-E(&%F(&)E<VME9&5R(&EG96YN96T@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@861G86YG<W!U;FMT970@=F5D(&)R=6<@868@2%14
M4"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-0HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET
M(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)$96YN92!D
M<FEV97(@=&EL;&%D97(@869S96YD96QS92!A9B!B97-K961E<B!V:6$@4TU4
M4"!I9V5N;F5M(%9O9&%F;VYE("(*(DET86QI96X@861G86YG<W!U;FMT970L
M(&1O9R!K=6X@=&EL(%9O9&%F;VYE+6YU;7)E+B!$96X@:W+F=F5R(&5N(&4M
M(@HB;6%I;&MO;G1O(&AO<R!6;V1A9F]N92!)=&%L:65N("AH='1P.B\O=W=W
M+C$Y,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,#@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0U,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3`*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,CDW"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,#4@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3<X(&QI8B](;W)D92]&;W)M+G!H<#HQ,#4W(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#@V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$U(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,C4V"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S`U(&QI8B](;W)D92]&;W)M+G!H<#HQ,SDX(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-34W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#,Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.34X(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#`U"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#(Y(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#<X(&QI8B](;W)D92]&;W)M+G!H<#HR,30Y"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C(Q(&QI8B](;W)D92]&;W)M+G!H<#HR-#`X(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#4P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C,W(&QI8B](;W)D92]&;W)M+G!H<#HR.#$P(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3$Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,CDW(&QI8B](;W)D92]&
M;W)M+G!H<#HS.#`U(&QI8B](;W)D92]&;W)M+G!H<#HS.#$S"FUS9VED(")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")$971T92!F96QT(&5R
M(&MRYG9E="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(D1E='1E(&9E;'0@;>4@
M:W5N(&EN9&5H;VQD92!H96QT86PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0Q-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q-@IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BXB"FUS9W-T<B`B1&5T=&4@9F5L="!MY2!K=6X@:6YD96AO;&1E(&YU;7)E
M(&]G(&MO;&]N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D1E='1E(&9E
M;'0@;>4@:W5N(&EN9&5H;VQD92!O:W1A;&4@=N9R9&EE<BXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)$971T
M92!F96QT('-K86P@=N9R92!E;B!K;VUM82T@96QL97(@;65L;&5M<G5M<V%D
M<VMI;&1T(&QI<W1E(&%F(&AE;'1A;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDX.2!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D1E='1E
M(&9E;'0@<VMA;"!VYG)E(&5T(&=Y;&1I9W0@;G5M;65R+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3@@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,3@*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C
M,3(S-&%F)RXB"FUS9W-T<B`B1&5T=&4@9F5L="!S:V%L(&EN9&5H;VQD92!E
M;B!F87)V96MO9&4@:2!21T(@:&5X+69O<FUA="P@9G@@)R,Q,C,T868G+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N(@IM<V=S='(@(D1E;FYE(&9O<FUU;&%R(&5R(&%L;&5R961E
M('!R;V-E<W-E<F5T+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(D1E
M='1E(&5R("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#8Y
M(&QI8B](;W)D92]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W
M('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT
M('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N
M($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V
M:7-I="`E<R(*;7-G<W1R("(B"B)$971T92!E<B!E="!+;VQA8B!'<F]U<'=A
M<F4M;V)J96MT+B!&;W(@870@<V4@9&5T=&4@;V)J96MT(&AA<B!D=2!B<G5G
M(&9O<B`B"B)E;B!E+6UA:6PM:VQI96YT+"!S;VT@9F]R<W3E<B!+;VQA8B!'
M<F]U<'=A<F4M9F]R;6%T970N($)E<_AG("5S(&9O<B!E;B`B"B)L:7-T92!A
M9B!K;&EE;G1E<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HU.3D@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B1&5N;F4@8F5S:V5D(&5R('-K<F5V970@;65D(&5T(&%N9&5T('1E
M9VYSYG0@*"5S*2!E;F0@9&ET(&5G970N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*
M;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G
M<W1R(")486QL970@<VMA;"!VYG)E(&UI;BX@,2XB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4@;&EB+TAO<F1E+T-O;7!R
M97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O
M;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B1&5N;F4@<V5R
M=F5R(&MA;B!I:VME(&1E:V]M<')I;65R92!Z:7`M(&]G(&=Z:7`M9FEL97(N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D@
M;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M
M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B1&5T=&4@<WES
M=&5M(&5R(&1E86MT:79E<F5T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(T(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D1E;FYE
M(';F<F1I('-K86P@=N9R92!E="!T86PN(@H*(SH@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")$971T
M92!V:6YD=64@<VMA;"!K86QD97,@9G)A(&5T(%1I;'9A;&=S=FEN9'5E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`B5&]R9&5N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")386=E
M<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C4@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(T,C4*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(E1I9"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T
M<B`B5&ED<V]P9_AR96QS92(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM
M<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B5&ED<V9O<FUA="(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,S$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(U,S$*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E1I9'-V86QG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4
M:6UO<BU,97-T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM
M<V=S='(@(E1I=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R
M(")4:71L92`H=&]O;'1I<"DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B5&EL(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4
M;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG
M+B(*;7-G<W1R("(B"B)&;W(@870@=N9L9V4@;75L=&EP;&4@:6YD9V%N9V4@
M<VMA;"!#=')L+2`H4$,I(&5L;&5R($-O;6UA;F0@*$UA8RDM=&%S=&5N("(*
M(FAO;&1E<R!N961E(&UE9&5N<R!D97(@:VQI:VME<RXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R
M("))($1A9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")3
M:VEF="!(5$U,+6MI;&1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM
M<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS
M9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DD@;6]R9V5N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:V]L86(N<&AP.C$P-"!L:6(O2&]R9&4O075T
M:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN
M<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RXB"FUS9W-T<B`B1F]R(&UA;F=E
M('5G>6QD:6=E(&QO9VEN9"UF;W)S^&<@:2!L^&)E="!A9B!D92!S:61S=&4@
M;6EN=71T97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Q"FUS9VED(")4;W`B"FUS9W-T<B`B5&]P(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")4;W`@9G)A;64@*%]T;W`I
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA
M=&EO;G,B"FUS9W-T<B`B3W9E<G/F='1E;'-E<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"!O
M9R!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM
M<V=S='(@(E-A;F0@96QL97(@9F%L<VLB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")4
M:7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N
M97-I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4
M>7)K:65T(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U
M<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1Y<FMI<VL@*$E33RTX.#4Y
M+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T
M<B`B5'5R:VUE;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,@;V<@0V%I8V]S(-AE
M<FYE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S,@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V
M86QU(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-"!L:6(O2&]R9&4O
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M(")3:W)I=B!D:70@=F%L9SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E4N5BXM
M:6YD96MS.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T
M<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-#$*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T(@IM<V=S='(@(E523"!F;W(@<VMR:7!T('1I;"!M;V1T86=E
M;'-E(&%F('-T871U<R!R87!P;W)T96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@
M(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R(")5
M9V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B
M56MR86EN92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q.2!L
M:6(O5D93+V9I;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+=6YN92!I:VME('1I;&?E(%9&4RUK
M871A;&]G+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY
M-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+B(*;7-G<W1R(")+86X@:6MK92!T:6QF^&IE(&5K<W1R82!B<G5G97(@:6YF
M;W)M871I;VX@=6YD97(@;W!S:W)I=FYI;F<N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS.3,@;&EB+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@YFYD<F4@=&EL
M;&%D96QS97(@9F]R(%9&4RUF:6P@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,Y,B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#8X"B,Z(&QI8B]61E,O9FEL92YP:'`Z,SDR(&QI8B]61E,O;75S<6PN
M<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")+86X@
M:6MK92#F;F1R92!T:6QL861E;'-E<B!F;W(@5D93+69I;"`E<R\E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X-B!L:6(O5D93+V9T<"YP
M:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N(@IM<V=S='(@(DMA;B!I:VME('-K:69T92!T:6P@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<@;&EB+U9&4R]F='`N<&AP
M.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@=&IE:VME(&9I
M;'-T^')R96QS96X@868@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8Y-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,C@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@U,"!L:6(O5D93
M+V9I;&4N<&AP.C8Y-0HC.B!L:6(O5D93+W-Q;"YP:'`Z,3`R."!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HX-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(DMA
M;B!I:VME('1J96MK92!F:6QS=/AR<F5L<V5N(&%F(%PB)7,O)7-<(BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,Y(&QI8B](;W)D92]!
M=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&;E(&9O<F)I;F1E;'-E
M('1I;"!344P@<V5R=F5R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-S`@;&EB+U9&4R]F='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DMA;B!I:VME(&;E(&9O<F)I
M;F1E;'-E(&UE9"!34TPN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C,R(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S-PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`T(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(Q-R!L:6(O5D93+V9I;&4N<&AP.C(S,@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C(S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#0@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C`Y"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q
M-PIM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DMA
M;B!I:VME(&MO<&EE<F4@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,W,"!L:6(O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S
M7"(N(@IM<V=S='(@(DMA;B!I:VME(&1A;FYE(%9&4RUK871A;&]G(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C$@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C8T(&QI8B]61E,O9FEL92YP:'`Z,S8Q"B,Z(&QI
M8B]61E,O;75S<6PN<&AP.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-C0*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B2V%N(&EK:V4@9&%N;F4@5D93+6MA=&%L;V<N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$R-"!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DMA
M;B!I:VME(&QA=F4@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Y,"!L:6(O5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(DMA;B!I:VME(&]P<F5T=&4@5D93+6UA<'!E(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S(@;&EB+U9&4R]F:6QE
M+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N(@IM<V=S='(@(DMA;B!I:VME(&QA=F4@=&]M(%9&4RUF:6PN(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V(&QI8B](;W)D
M92]#;VUP<F5S<R]G>FEP+G!H<#HW.0HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M=&%R+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB
M"FUS9W-T<B`B2V%N(&EK:V4@9&5K;VUP<FEM97)E(&1A=&$N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,C@*(SH@;&EB+U9&4R]F='`N<&AP.C,P,R!L:6(O5D93+W-M
M8BYP:'`Z,C(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T
M<B`B2V%N(&EK:V4@<VQE='1E(%PB)7-<(CL@:V%T86QO9V5T(&5R(&EK:V4@
M=&]M="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@7"(E
M<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S@@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y-2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S0R"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,X(&QI8B]61E,O;75S
M<6PN<&AP.C,Q,2!L:6(O5D93+W-Q;"YP:'`Z,SDU"B,Z(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R
M(")+86X@:6MK92!S;&5T=&4@)7,[(&MA=&%L;V=E="!E<B!I:VME('1O;70B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-C`*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S4V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*
M;7-G<W1R(")+86X@:6MK92!S;&5T=&4@5D93+6MA=&%L;V=E="!R96MU<G-I
M=G0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0T(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(@;&EB
M+U9&4R]F:6QE+G!H<#HS-#0*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI
M8B]61E,O;75S<6PN<&AP.C,S-2!L:6(O5D93+VUU<W%L+G!H<#HS-#,*(SH@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VME('-L971T92!6
M1E,M:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R
M,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC.B!L:6(O5D93+W-Q
M;"YP:'`Z-#(P(&QI8B]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS
M9W-T<B`B2V%N(&EK:V4@<VQE='1E(%9&4RUK871A;&]G.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Q,B!L:6(O5D93+V9T<"YP:'`Z
M,C$R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@5D93+69I
M;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$P
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$X,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,CDQ(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y.2!L:6(O5D93+V9I;&4N<&AP.C,Q
M,`HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ-C<@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3@P(&QI8B]61E,O;75S<6PN<&AP.C$X-PHC.B!L:6(O5D93+W-Q;"YP:'`Z
M,CDQ(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y,2!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM
M<V=S='(@(DMA;B!I:VME('-L971T92!61E,M9FEL+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C0X(&QI8B]61E,O<VUB+G!H<#HR-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(%9&4RUM87!P92!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#D@;&EB
M+U9&4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DMA;B!I
M:VME('-L971T92!61E,@<F5K=7)S:79T.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@S-"!L:6(O5D93+V9T<"YP:'`Z.#,T"FUS9VED
M(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G
M<W1R(")+86X@:6MK92!B97-T96UM92!A:W1U96QT(&MA=&%L;V<N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B2V%N(&EK:V4@=61D<F%G
M92!C97)T:69I:V%T+61E=&%L:F5R(@H*(SH@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H
M<#HQ,C,*(SH@;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U
M=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:6YD
M;.9S92!D969I;FET:6]N96X@868@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<T(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR,#,@;&EB+U9&4R]F:6QE+G!H<#HR,#@@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&9L
M>71T92!61E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.3@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C$P-B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C8U,@HC.B!L:6(O5D93+V9T<"YP:'`Z.3@@;&EB+U9&4R]S;6(N<&AP.CDS
M(&QI8B]61E,O<VUB+G!H<#HQ,#8*(SH@;&EB+U9&4R]S;6(N<&AP.C8U,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(.5B;F4@5D93+69I;"!<(B5S7"(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@T(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$T,2!L:6(O5D93+V9I;&4N<&AP.C(X-`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B2V%N(&EK:V4@Y6)N92!61E,M9FEL('1I;"!S:W)I=FYI
M;F<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#,@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,W"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW-B!L:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]61E,O
M9FEL92YP:'`Z,3,W"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@
MY6)N92!61E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-#4@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*
M;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS
M9W-T<B`B2V%N(&EK:V4@Y6)N92!K;VUP<FEM97)E="!A<FMI=BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#4V(&QI8B]61E,N<&AP.C@U-@IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B2V%N(&EK:V4@;.9S92!61E,M9FEL("AF:6QE<VEZ92@I
M(&9E:FQE9&4I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.#<@;&EB
M+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R(")+86X@:6MK92!LYG-E
M(%9&4RUF:6P@*&=E=$9I;&53:7IE*"D@9F5J;&5D92DN(@H*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X
M"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I
M9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(DMA;B!I:VME(&SF
M<V4@9FEL.B`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-S8@
M;&EB+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T;R!R96%D('1H
M92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@;.9S92!V
M9G-R;V]T+6MA=&%L;V=E="XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$Q,#D@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3`Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(")+86X@:6MK92!O
M;63X8F4@)7,@=&EL("5S.B!MY6QM87!P96X@9FEN9&5S(&%L;&5R961E(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,2!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@;VUD^&)E(%9&4RUK871A
M;&]G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,R(&QI8B]6
M1E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@
M;VUD^&)E(%9&4RUK871A;&]G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(W,0HC
M.B!L:6(O5D93+V9T<"YP:'`Z,S0X(&QI8B]61E,O<VUB+G!H<#HR-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(&]M9/AB92!61E,M9FEL(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3<@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC.B!L:6(O5D93+V9I;&4N<&AP
M.C8Q-R!L:6(O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
M2V%N(&EK:V4@;VUD^&)E(%9&4RUF:6P@)7,O)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(Q,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z-#4R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(V(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P.2!L:6(O5D93+VUU<W%L+G!H<#HR
M,3,*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R(&QI8B]61E,O<W%L+G!H<#HS
M,C8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB
M"FUS9W-T<B`B2V%N(&EK:V4@;VUD^&)E(%9&4RUF:6PN(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B2V%N(&EK:V4@869V:6ML
M92`G;6MI<V]F<R<N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HU.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0B"FUS9W-T<B`B2W5N;F4@:6MK92!O=F5R<^9T=&4@9&5T=&4@
M5V]R9"!D;VMU;65N="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,34T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W"B,Z(&QI8B]61E,O
M9G1P+G!H<#HQ-30@;&EB+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(")+86X@:6MK92!S:W)I=F4@5D93+69I;"!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3@V(&QI8B]61E,O9FEL92YP:'`Z
M,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+B(*;7-G<W1R(")+86X@:6MK92!S:W)I=F4@5D93+69I;"`H8V]P
M>2@I(&9E:FQE9&4I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(X."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30V"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-3$@;&EB+U9&4R]F:6QE
M+G!H<#HR.#@*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30V(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(&1A=&$N(@IM<V=S='(@(DMA;B!I:VME('-K<FEV92!61E,M9FEL9&%T
M82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8R(&QI8B]61E,N<&AP
M.C@V,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W
M:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(")+86X@:6MK92!S:W)I=F4@5D93
M+69I;#L@:W9O=&5N('9I;"!B;&EV92!O=F5R<VMR961E="XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5
M;F1E<FQI;F4B"FUS9W-T<B`B56YD97)L:6YI97)E="(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R
M(")&;W)T<GED(.9N9')I;F=E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(D]M9_AR(&1I;B!S:61S=&4@:&%N9&QI;F<B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B579E
M;G1E="!R96%K=&EO;B!F<F$@<V5R=F5R('#E(&9O<F)I;F1E;'-E;CH@(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,S.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<V"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M("(*;7-G<W1R(")5=F5N=&5T(')E86MT:6]N(&9R82!S97)V97(@<.4Z("(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C4W"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q
M"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DEK:V4@86YB<F%G="(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB
M"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N
M:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(D9O<F5N961E($%R86)I<VME
M($5M:7)A=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S."!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB
M"FUS9W-T<B`B4W1O<F)R:71T86YI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B55-!(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS
M9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS
M9W-T<B`B55-!<R!U;F1E<F]R9&YE9&4@^&5R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(*;7-G
M:60@(E5N:71S(@IM<V=S='(@(D5N:&5D97(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C4X(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R.0HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,S`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")5:V5N9'0B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@
M(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B
M56ME;F1T(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(E5K
M96YD="!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(E5K96YD="!S=&5D(&%N9VEV970N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDQ"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ
M"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R
M(")5:V5N9'0@8G)U9V5R;F%V;B!E;&QE<B!K;V1E;W)D+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM
M<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B2.9G
M="!A:W1U96QT(&5L96UE;G0@868N(@H*(SH@9G)A;65W;W)K+TED96YT:71Y
M+TED96YT:71Y+G!H<#HS,#(@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*
M;7-G:60@(E5N;F%M960B"FUS9W-T<B`B26MK92!N879N9VEV970B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED
M("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(E5P
M<FEV:6QI9V5R961E('-K<FEP=&5R(&MA;B!I:VME('1I;&?E(&ML:7!P92]K
M;W!I+VEN9'/F="!P<F]G<F%M;>9S<VEG="!A9B`B"B)S:6MK97)H961SY7)S
M86=E<BX@($ML:6L@3TL@9F]R(&%T('-E(&5N('1E:VYI<VL@;F]T92!H;W,@
M;6]Z:6QL82YO<F<L('-O;2`B"B)V:7-E<B!D:6<L(&AV;W)D86X@9'4@:V%N
M('1I;&QA9&4@970@<VMR:7!T(&%T('1I;&?E('5D:VQI<'-H;VQD97)E;BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")&87)V92!I:VME
M(&EN9'-T:6QL970B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,R!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8X-PHC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.CDR-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(E5D=FED9&5L<V4@
M:6MK92!U;F1E<G-T^'1T970B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$Y-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-PHC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM
M<V=S='(@(D]P9&%TZ7(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G
M<W1R(")/<&1A=.ER("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B3W!D873I
M<B!B<G5G97(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B
M7"(E<UPB(&]P9&%T97)E="XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B
M3W!G<F%D97)I;F=S+69O<F5S:W)I9G0@<VQE='1E="XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(E5P;&]A9"(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L
M;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G
M<W1R(")/<'/F=&YI;F=S9FEL97(@=&EL(&%L;&4@87!P;&EK871I;VYE<B!L
M86=T(&]P('#E('-E<G9E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(E-T;W)E(&QA=&EN<VME(&)O9W-T879E<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M4W1O<F4@<F]M97)T86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB
M"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C0U"B,Z(&QI8B](;W)D92]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#
M=7)R96YT.B`E<R(*;7-G<W1R(")!;G9E;F0@;G5VYG)E;F1E.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@
M(E5S92!34TPB"FUS9W-T<B`B0G)U9R!34TPB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")"<G5G(&AV:7,@
M;F%V;B]K;V1E;W)D(&5R(&9O<G-K96QL:6<@9F]R($E-4U`M<V5R=F5R+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@
M(E5S97(B"FUS9W-T<B`B0G)U9V5R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HW-S0@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N(@IM<V=S='(@(D)R=6=E<B`E<R!I:VME(&)E;7EN9&EG
M970@=&EL("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E
M<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")"<G5G97(M861M:6YI<W1R871I
M;VXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T-2!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM
M<V=S='(@(D)R=6=E<FEN9'-T:6QL:6YG97(B"@HC.B!S:6=N=7`N<&AP.C8R
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")"<G5G97(M<F5G
M:7-T<F5R:6YG(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS
M9W-T<B`B0G)U9V5R+7)E9VES=')E<FEN9R!E<B!B;&5V970@<VSE970@9G)A
M('#E(&1E='1E('=E8G-T960N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0Y-`IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R(")"
M<G5G97)K;VYT;R!I:VME(&9U;F1E="(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@;&EB+TYE="]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HY."!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.`HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34P
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(D)R=6=E<FYA=FXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B0G)U
M9V5R;F%V;B!<(B5S7"(@9FEN9&5S(&%L;&5R961E+B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S
M='(@(D)R=6=E<FYA=FXZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")"<G5G97)N879N.B`B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5
M<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")"<G5G97)E(&D@<WES=&5M
M970Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@
M(E5S8F5K:7-T86XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,3<P(&QI8B]61E,O9FEL92YP:'`Z,C8R"FUS9VED(")61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")61E,M:V%T86QO
M9R!E:W-I<W1E<F5R(&EK:V4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B1F5R:64B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*
M;7-G<W1R(")'>6QD:6=E(&9U;F1E="!S=&5D97(@:6YK;'5D97)E<CHB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.2!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T
M<B`B1WEL9&EG:&5D(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C4U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S
M='(@(E;F<F1I(&5R(&UI;G5T=&5R(&9R82!N=2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W
M-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#4V(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE
M(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")6YG)D:2!E<B!M97)E
M(&5N9"!D96X@;6%K<VEM86QE(&SF;F=D92!A9B`E<RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3$P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#0*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C8@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S,38@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3`*(SH@;&EB+TAO<F1E+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R
M(")6YG)D:65R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3`Y(&QI8B](;W)D92]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU
M97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5N9R9&EE<BP@9&5R(&MA;B!V
MYFQG97,@:6)L86YD="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*
M;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B4VMI9G1E;F1E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N97IU
M96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+B(*;7-G<W1R(")%9G1E<G!R^'9N:6YG(&9E:FQE9&4@+2!D
M97(@97(@8FQE=F5T('!I;&QE="!V960@9&5N;F4@8F5S:V5D+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E
M<G-I;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED
M(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEO;G-K;VYT<F]L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B3&]D<F5T(&]P
M<W1I;&QI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(DQO
M9')E="!F;W)R:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(DQO9')E
M=#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(DUE9V5T(&CX:B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A6
M25-#24DI(@IM<V=S='(@(E9I971N86UE<VES:R`H5DE30TE)*2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDW,2!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.3<Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B5FES("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R
M(")392!PY2!E:W-T97)N('=E8G-I9&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C@S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S
M='(@(E9I<R!S;VT@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)
M<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(DIO;69R=?AE<BP@0G)I=&ES:V4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM
M<V=S='(@(DIO;69R=?AE<BP@06UE<FEK86YS:V4B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")3>6YL
M:6=H960B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS
M9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B4WEN;&EG:&5D.B`B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N
M92!)=&%L:65N('9I82!33510(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@HC.B!L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G
M:60@(E=!4DXB"FUS9W-T<B`B5T%23B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")!1%9!4E-%
M3"$A(2!&2D523B!30U))4%0@34%.545,5"!&4D$@)7,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@
M(E=)3B!V:6$@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N
M9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES(&]G($9U='5N82(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,3(W"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z
M,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HY-0IM<V=I9"`B5V%R;FEN9R(*
M;7-G<W1R(")!9'9A<G-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(D]N<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE
M<B!&;W)E8V%S="(*;7-G<W1R(")696IR=61S:6=T(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y(@IM<V=S='(@(E9E:G)I;F9O<FUA=&EO;B!S=&EL;&5T('1I
M;'+E9&EG:&5D(&%F(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR
M(&QI8B](;W)D92]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM
M<V=S='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*;7-G<W1R(")796)S
M:71E(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU."!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K
M;'DB"FUS9W-T<B`B56=E;G1L:6<B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")696QK;VUM96XB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M
M92!T;R`E<R(*;7-G<W1R(")696QK;VUM96X@=&EL("5S(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S
M='(@(E9E;&MO;6UE;BP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B5F5S=&QI
M9R`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(E9E<W1L:6<@
M*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R
M82(*;7-G<W1R(")697-T<V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")(=FEL
M:V5N(&%P<&QI:V%T:6]N('-K86P@)7,@=FES92!E9G1E<B!L;V=I;F0_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@
M:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(DAV860@97(@
M<V5P87)A=&]R=&5G;F5T/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM
M<V=S='(@(DAV860@97(@8VET871I;VYS=&5G;F5T/R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES
M($%U<W1R86QI82!M87`B"FUS9W-T<B`B5VAE<F5I<R!!=7-T<F%L:65N+6MO
M<G0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H
M87-E<R(*;7-G<W1R(")(=FEL:V4@9F%S97(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DAV:6QK92!P;'5G
M:6YS('-K86P@86MT:79E<F5S(&9O<B!2:6-H(%1E>'0M=N9R:W3X:F5T+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(D)R961D92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#<@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,#<*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R(")"<F5D9&4@
M:2!#4U,M96YH961E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(D)R961D92!A9B`E<RUM96YU96X@=&EL('9E;G-T<F4@*&)L:79E<B!A
M:W1I=F5R970@=F5D(&[F<W1E(&QO9VEN9"DZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F
M('1H92!T86)L92(*;7-G<W1R(")"<F5D9&4@868@=&%B96QL96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I
M9"`B5VED=&@@=6YI="(*;7-G<W1R(")"<F5D9&4M96YH960B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B
M5VED=&@Z(@IM<V=S='(@(D)R961D93HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")7:6YD(@IM<V=S='(@
M(E9I;F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")";.9S="!T:61L:6=T
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S<&5E
M9"!I;B!K;F]T<R(*;7-G<W1R(")6:6YD:&%S=&EG:&5D(&D@:VYO8B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R
M(")6:6YD.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R(")6:6YD.B`B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")6:7-D;VTB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H
M;&ES="(*;7-G<W1R("+8;G-K96QI<W1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(D%R8F5J9&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*
M;7-G<W1R(")!9')E<W-E("AA<F)E:F1E*2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T
M<B`B5&5L969O;B`H87)B96ID92DB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,Z
M(&QI8B]&:6QE+T-35BYP:'`Z,3DS(&QI8B]&:6QE+T-35BYP:'`Z,CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@
M;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(")&;W)K
M97)T(&%N=&%L(&9E;'1E<B!I(&QI;FEE("5D+B!&;W)V96YT961E("5D+"!F
M86YD="`E9"XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(@
M;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*
M;7-G<W1R(")&;W)K97)T(&%N=&%L(&9E;'1E<BX@1F]R=F5N=&5D92`E9"P@
M9F%N9'0@)60N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(Q
M(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S
M='(@(D9O<FME<G0@9F]R<VMY9&YI;F<@)60@=6YD97(@:6YD;.9S;FEN9R!A
M9B!E;B!61E,M9FEL+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*
M;7-G<W1R(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,R!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M92(*;7-G<W1R(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DV(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C@S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@S
M"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@=61V
M:61D96QS97(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB
M"FUS9W-T<B`BQ<4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-38*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V
M"FUS9VED(")965E9(@IM<V=S='(@(L7%Q<4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*
M;7-G<W1R(")986AO;R$M:V]R="(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-38@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(L5R;&EG(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")996UE;B(*;7-G<W1R(")996UE;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM<V=S
M='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")*82P@:F5G
M(&5R(&5N:6<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T
M:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS
M9W-T<B`B(@HB1'4@8F5F:6YD97(@9&EG(&D@5$5+4U0@34]$55,N("!"<G5G
M(%L\/ETM:VYA<'!E;B!T:6P@870@<VMI9G1E('1I;&)A9V4@=&EL("(*(E=9
M4TE764<N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HR,S8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B
M1'4@:&%R(&EK:V4@=&EL;&%D96QS92!T:6P@870@;W!R971T92!M97)E(&5N
M9"`E9"!B;&]K:V4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-#(T(&QI8B](;W)D92YP:'`Z,30R-`IM<V=I9"`B66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"XB"FUS9W-T<B`B1'4@97(@:6MK92#F9W1E="XB"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P."!L:6(O2&]R9&4O
M261E;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G
M7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B1'4@
M:V%N(&EK:V4@:&%V92`G7%PG+71E9VYE="!I(&1I="!F=6QD92!N879N+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT
M97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")$=2!I;F1T87-T
M961E(&EK:V4@96X@9WEL9&EG(&4M<&]S="UA9')E<W-E+B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(Y,"!L:6(O2&]R9&4O1&%T82YP:'`Z,CDP
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(D9O<B!A="!I;7!O
M<G1E<F4@<VMA;"!D=2!T:6QO<F1N92!F96QT97(@9G)A(&1E;B!F:6P@9'4@
M:6UP;W)T97)E<B!T:6P@9&4@(@HB=&EL<W9A<F5N9&4@9F5L=&5R(&D@)7,N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W(&QI8B](;W)D92]!
M=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB
M"FUS9W-T<B`B1'4@97(@8FQE=F5T(&QO9V=E="!U9"XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8Q
M"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N
M92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*
M(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T
M<B`B(@HB1'4@<VMA;"!I;F1T87-T92!E="!F=6YG97)E;F1E(&UO8FEL;G5M
M;65R.R!K=6X@8VEF<F4@;65D(&5T('9A;&=F<FD@)RLG(&9O<B`B"B)D96X@
M:6YT97)N871I;VYA;"!R971N:6YG<VMO9&4N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X.`IM<V=I
M9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B
M1'4@<VMA;"!I;F1T87-T92!E;B!G>6QD:6<@=N9R9&DN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(D1U('-K
M86P@:V]N9FEG=7)E<F4@96X@1&%T851R964M8F%C:V5N9"!F;W(@870@:W5N
M;F4@86YV96YD92!/<'-K<FEV;FEN9V5R+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-#<Q(&QI8B](;W)D92YP:'`Z-#<Q"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B1'4@<VMA
M;"!K;VYF:6=U<F5R92!E;F0@5D93+6)A8VME;F0N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+B(*;7-G<W1R("(B"B)$=2!B;&EV97(@;OAD('1I;"!A="!L
M879E(&5N('!R;V)L96UB97-K<FEV96QS92P@9OAR(&1U(&MA;B!S96YD92!D
M96X@:6YD+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")$=2!S:V%L(&EN9'1A<W1E
M(&1E;B!54DP@:'9O<G1I;"!D96YN92!HYF=T92!S:V%L(&AE;G9I<V4B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")$
M=2!S:V%L(';F;&=E(&1E;B!S97)V97(L('-O;2!S:V%L('-L971T97,N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")$=2!S:V%L(&%N
M9VEV92!B<G5G97)N879N970L('-O;2!D=2!V:6P@9FIE<FYE+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B1'4@<VMA;"!A;F=I=F4@8G)U
M9V5R;F%V;F5T+"!S;VT@9'4@=FEL(&9J97)N92XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS
M9W-T<B`B1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@9'4@=FEL
M('1I;&;X:F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(D1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!O<&1A
M=&5R92XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S@@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S
M='(@(D1U('-K86P@86YG:79E(&1E;B!H86YD;&EN9RP@<V]M('-K86P@=61F
M^')E<RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,0HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")$=2!S:V%L(&%N9VEV92!E="!N>70@:V%T96=O<FEN
M879N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C<S"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA
M;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B1'4@8FQI=F5R(&[X9'0@=&EL(&%T
M(&%N9VEV92!E="!I=&%L:65N<VME('1E;&5F;VYN=6UM97(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY-S4@;&EB+TAO<F1E+T%U=&@N<&AP.CDW
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B1&EN("5S('-E
M<W-I;VX@97(@=61L^&)E="X@3&]G('9E;FQI9W-T(&EN9"!I9V5N+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R
M($5M86EL($%D9')E<W,B"FUS9W-T<B`B1&EN(&4M<&]S="UA9')E<W-E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M
M.B!A9&1R97-S.B(*;7-G<W1R(")$:6X@1G)O;3H@861R97-S93HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B
M1&EN92!I;F9O<FUA=&EO;F5R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3<Y(&QI8B](;W)D92]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(B"B)$:6X@26YT97)N970M861R97-S92!E<B!S:VEF=&5T('-I
M9&5N(&)E9WEN9&5L<V5N(&%F(&1I;B`E<RUS97-S:6]N+B!&;W(@870@(@HB
M8F5S:WET=&4@9&EN('-I:VME<FAE9"!B;&EV97(@9'4@;OAD="!T:6P@870@
M;&]G9V4@:6YD(&EG96XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")$:70@;F%V;B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B
M"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T
M;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I
M9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B
M"B)$:6X@YF=T;FEN9W,M8F%C:V5N9"!U;F1E<G-T^'1T97(@:6MK92!T:6QF
M^&IE;'-E;B!A9B!B<G5G97)E+B!(=FES(&1U("(*(OAN<VME<B!A="!B<G5G
M92!(;W)D92!T:6P@870@861M:6YI<W1R97)E(&)R=6=E<FMO;G1I+"!B;&EV
M97(@9'4@;OAD="!T:6P@870@(@HB8G)U9V4@96X@86YD96X@YF=T;FEN9W,M
M8F%C:V5N9"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*
M(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS
M9W-T<B`B(@HB1&EN(&%U=&]R:7-A=&EO;G,M8F%C:V5N9"!U;F1E<G-T^'1T
M97(@:6MK92!O<&QI<W1N:6YG96X@868@8G)U9V5R92!E;&QE<B!E<B`B"B)D
M96X@9G5N:W1I;VX@868@96X@96QL97(@86YD96X@9W)U;F0@8FQE=F5T('-L
MY65T(&9R82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#,@;&EB
M+TAO<F1E+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B(*(D1I;B!B<F]W<V5R('-Y;F5S(&%T(';F<F4@<VMI9G1E="!S:61E;B!B
M96=Y;F1E;'-E;B!A9B!D:6X@)7,M<V5S<VEO;BX@1F]R("(*(F%T(&)E<VMY
M='1E(&1I;B!S:6MK97)H960L('-K86P@9'4@;&]G9V4@:6YD(&EG96XN(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3<*;7-G:60@(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B1&EN
M(&)R;W=S97(@=6YD97)S=/AT=&5R(&EK:V4@9&5N;F4@9G5N:W1I;VYA;&ET
M970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R
M:6YT+B(*;7-G<W1R("(B"B)$:6X@8G)O=W-E<B!U;F1E<G-T^'1T97(@:6MK
M92!D96YN92!P<FEN="UM=6QI9VAE9"X@5')Y:R!#=')L+T-O;6UA;F0@*R!0
M("(*(F9O<B!A="!P<FEN=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B
M1&EN(&%K='5E;&QE('1I9'-Z;VYE.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R(")$:6X@9F]R=F%L9W1E(&ED96YT:71E="!E<B#F
M;F1R970N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B
M66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")$:6X@<W1A;F1A<F0M
M:61E;G1I=&5T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G
M:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")$:70@9G5L9&4@;F%V;CHB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B1&ET(&QO9VEN9"!E<B!U9&SX8F5T+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B1&ET(&YY92!K
M;V1E;W)D(&9O<B`E<R!E<CH@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-"!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")$:6YE('1I;'9A;&<@
M97(@8FQE=F5T(&]P9&%T97)E="!F;W(@=F%R:6=H961E;B!A9B!D96YN92!S
M97-S:6]N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(D1I;F4@=&EL=F%L9R!E
M<B!O<&1A=&5R970N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`B1&ET(&MO9&5O<F0@97(@8FQE=F5T(&YU;'-T:6QL970B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G
M(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(D1I
M="!K;V1E;W)D(&5R(&)L979E="!N=6QS=&EL;&4[(&MO;G1R;VQLZ7(@9&EN
M(&EN9&)A:VME(&]G(&QO9R!I;F0@;65D(&1I="`B"B)N>64@:V]D96]R9"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,@;&EB+TAO<F1E+T%U
M=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B1&ET(&MO9&5O<F0@97(@=61L^&)E="XB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E
M<G9E<G,Z(@IM<V=S='(@(D1I;F4@9FIE<FYE('-E<G9E<F4Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R(")*=6=O<VQA=FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M("):86ER92(*;7-G<W1R("):8>]R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6F%M8FEA(@IM<V=S='(@(EIA;6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C$W-`HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O
M=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");
M4VMJ=6P@8VET97)E="!T96MS=%TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O8FQE
M;6)E<VMR:79E;'-E72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S
M='(@(EM6:7,@8VET97)E="!T96MS="`M(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!L:6(O
M2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B6U9I<R!C:71E<F5T('1E:W-T("T@)7,@;&EN:65R72(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`T(&QI8B](;W)D92YP
M:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*
M;7-G<W1R(");;&EN:64@)7,@=60@868@)7-=(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-34T(&QI8B](;W)D92YP:'`Z,34U-`HC.B!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VXB"@HC.B!L:6(O87!I+G!H<#HQ
M-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z
M,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B1&%T851R964B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E-L970@<N9K:V4B"@HC
M.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B1W)U
M<'!E<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4@
M;&EB+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B
M2&KF;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(D)I;&QE9"UE9V5N<VMA8F5R+BXN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-"!L:6(O2&]R9&4O365N=2YP:'`Z,3DT
M"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(DQO9R!I;F0B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP(&QI8B](;W)D92]-96YU+G!H
M<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(DQO9R!U9"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(L9N9')I;F<@:&5N
M=FES;FEN9RXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-C0@;&EB+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B
M"FUS9W-T<B`B26YD<W1I;&QI;F=E<B(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM
M<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E1I;&QA9&5L<V5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B4VQE="!H96YV
M:7-N:6YG+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B
M"FUS9W-T<B`B3W!SYG1N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")486)E;"UE9V5N<VMA8F5R+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B0G)U9V5R
M92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(U(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B
M861R97-S96MA<G1O=&5K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S0@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T"FUS
M9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")A9')E<W-E;G0@=6ME
M;F1T(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3<@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(FMA
M;&5N9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G
M<W1R(")V:6YD<W1I;&QE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-3@@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34X"FUS
M9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(FMA;B!I
M:VME(&1A;FYE('5D9&%T82UF:6PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$S,"!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(FMA;B!I:VME
M(.5B;F4@:6YD9&%T82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C8P,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-C`P"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(FML:6L@:&5R(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(B"FUS9W-T<B`B9F5J;"!V960@86YV96YD96QS92!A9B!K;VUM86YD;RUL
M:6YI92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG
M=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")K;VYF:6=U<F%T:6]N<V9E:FPB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-"!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E
M;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B;6%N9VQE<B!K<FET:7-K('-Y<W1E
M;69I;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F
M;W)M870@97)R;W(B"FUS9W-T<B`B9F5J;"!I(&1A=&%F;W)M870B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S
M='(@(G)E9&EG97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$X,B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@
M(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")I;F1G86YG(&EK:V4@9G5N9&5T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*
M;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B9F%L9&5N9&4B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3@@;&EB+TAO<F1E+T)R;W=S97(N
M<&AP.C@Y.`IM<V=I9"`B9FEL92(*;7-G<W1R(")F:6PB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M
M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(F9R82`E<R`H)7,I(&UE
M9"`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*
M;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B<W1O<FUF=6QD(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G
M<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S."!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(G5K
M96YD="!M87-K:6YN879N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("+X:F5B;&EK:V5L
M:6=T(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")I;F1L96IR970B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U
M="!E<G)O<B(*;7-G<W1R(")I;F1D871A+W5D9&%T82UF96IL(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<B(*;7-G<W1R(")I;G1E<FX@<V]F='=A<F4M9F5J;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE
M<UTB"FUS9W-T<B`B;&EN:65R72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC.B!L:6(O5D93+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B
M;6MI<V]F<R!F96IL:V]D92`E9"!U;F1E<B!D86YN96QS92!A9B!)4T\N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED
M(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,C@U(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C@U"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R(")N879N(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,N<&AP.C$R-"!L:6(O2&]R9&4O4E!#+G!H<#HQ
M,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")I:VME(&EM<&QE
M;65N=&5R970B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$R,C`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N
M;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(F5N9&YU(&EK:V4@:6UP;&5M
M96YT97)E="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`Y(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S='(@
M(FYO=&5S8FQO:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<')O
M8V5N="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B=&EL;&%D96QS92!NYF=T970B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y
M"FUS9VED(")P:7AE;',B"FUS9W-T<B`B<')I:VME<B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P(&QI8B](;W)D92]-24U%+TUE
M<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L
M(@IM<V=S='(@(F9E:FP@:2!P<F]T;VMO;"!F<F$@9FIE<FX@<VED92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<U"FUS9VED
M(")R:7-I;F<B"FUS9W-T<B`B<W1I9V5N9&4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$T,B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B
M=&IE;F5S=&4@=71I;&?F;F=E;&EG(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B=FES
M(&9O<G-K96QL92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S
M;7,R96UA:6P@=FEA($A45%`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@W"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G-T
M96%D>2(*;7-G<W1R(")S=&%B:6QT(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-3`@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B<WES=&5M9F5J;"(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,S(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B;W!G879E
M;&ES=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V
M-B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O
M<F%R>2!F86EL=7)E(@IM<V=S='(@(FUI9&QE<G1I9&EG(&9E:FQT:6QS=&%N
M9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-S`*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR
M-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB
M"FUS9W-T<B`B:6YD=&%S="!K;V1E;W)D970@=&\@9V%N9V4@9F]R(&%T(&)E
M:W+F9G1E(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B<V%M;65N
M<VUE;'1E="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<@
M;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS
M9W-T<B`B=6YA=FYG:79E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")B<G5G97)V
M86QG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@
M(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R
M+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M;R]D95]$12YP;P``````````````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P-S0U-C<T`#$P-#$W,S8S,#`Q`#`Q-C,U,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C($=E<FUA;B!T
M<F%N<VQA=&EO;G,@9F]R($AO<F1E('!A8VMA9V4*(R!'97)M86X@;65S<V%G
M97,@9F]R($AO<F1E+@HC($-O<'ER:6=H="`H0RD@,C`P,2TR,#`V($AO<F1E
M(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/BP@,C`P,2TR,#`V+@HC"B,@;6%R9VEN
M.B!!==]E;F%B<W1A;F0*(R!P861D:6YG.B!);FYE;F%B<W1A;F0*(R!(:7-T
M;W)Y.B!#:')O;FEK"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U6
M97)S:6]N.B!(;W)D92`S+C$M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#8M,#,M,#8@,3(Z-#<K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-BTP,RTP-B`Q,CHU,"LP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^7&XB"B),86YG=6%G92U496%M
M.B!'97)M86X@/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I
M;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M
M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8V"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H=F]R
M("5S(%1A9V5N*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,X
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B("A:=6=R:69F<W1A<W1E("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES
M*2(*;7-G<W1R("(@*&EN("5S(%1A9V5N*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S`*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H:&5U
M=&4I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,@IM<V=I9"`B
M("AT;VUO<G)O=RDB"FUS9W-T<B`B("AM;W)G96XI(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,V.`IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S
M='(@(B`H9V5S=&5R;BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G
M<W1R("(@;6ET("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O
M<GDN(@IM<V=S='(@(EPB)7-<(B!I<W0@:V5I;B!697)Z96EC:&YI<RXB"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB
M)7-<(B!I<W0@:V5I;F4@9_QL=&EG92!!=7-W86AL+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@:7-T(&EN(&1E<B!(;W)D92!296=I
M<W1R>2!N:6-H="!K;VYF:6=U<FEE<G0N(@H*(SH@9G)A;65W;W)K+U1R964O
M5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B1&5R($)A=6TM4F5N9&5R
M97(@9OQR(%PB)7-<(B!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B!W=7)D92!Z=6T@1W)U<'!E;G-Y<W1E;2!H:6YZ=6=E9OQG="XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@>G5M(%)E8VAT97-Y<W1E;2!H:6YZ
M=6=E9OQG="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB('=U<F1E(&YI
M8VAT(&5R<W1E;&QT.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"("@E,R0N,F8E)2D@
M=F]N("4R)"XR9DU"(&5R;&%U8G1E;B!V97)B<F%U8VAT(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@=6YD("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL
M('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B26X@)60@5&%G96X@
M=VER9"!):'(@4&%S<W=O<G0@=6YG_&QT:6<N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD
M87D@9F]R96-A<W0B"FUS9W-T<B`B)60M5&%G92U6;W)H97)S86=E(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@2&EN=V5I<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S($9I;F=E<F%B
M9')U8VLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-#`@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B)7,@5V%R='5N9W-A<F)E:71E;B`M($)E<W3D=&EG=6YG(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@
M(B5S+4MO;F9I9W5R871I;VXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B
M"FUS9W-T<B`B)7,@4F5G:7-T<FEE<G5N9R(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O
M9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@3G5T>G5N9W-B961I;F=U;F=E;B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,R(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#DT"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C@R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!E
M>&ES=&EE<G0@8F5R96ET<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V
M-B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(T-@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*
M;7-G<W1R("(E<R!M:70@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B
M"B(E<R!W:7)D(&1I92!787)T=6YG<V%R8F5I=&5N(&1U<F-H9OQH<F5N+"!D
M:64@=6YT96X@;6%R:VEE<G0@<VEN9"X@36%R:VEE<F5N("(*(E-I92!A;&QE
M($%U9F=A8F5N+"!D:64@:F5T>G0@9'5R8VAG96;\:')T('=E<F1E;B!S;VQL
M96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!I<W0@
M;F]T=V5N9&EG(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!-:6YU=&5N
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(B5S(&YI8VAT(&=E9G5N9&5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@
M)7,B"FUS9W-T<B`B)7,@8FES("5S('9O;B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M061D<F5S<R!";V]K(@IM<V=S='(@(B5S<R!!9')E<W-B=6-H(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<W,@2V%L96YD97(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7-S($YO=&EZ8FQO8VLB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S<R!!=69G86)E;FQI
M<W1E(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA
M:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I
M;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S
M;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z($1I97-E($YA8VAR
M:6-H="!S=&%M;70@=6YT97(@56US=.1N9&5N(&YI8VAT('9O;B!D96T@86YG
M96=E8F5N96X@(@HB06)S96YD97(N($9O;&=E;B!3:64@:V5I;F5N($QI;FMS
M(&EN(&1I97-E<B!.86-H<FEC:'0@=6YD(&C\=&5N(%-I92!S:6-H("(*(F1A
M=F]R+"!D96T@06)S96YD97(@<&5R<_9N;&EC:&4@1&%T96X@<')E:7-Z=6=E
M8F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG
M("(*;7-G<W1R("(L(&+V:6<@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M.34@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@8FEG("5S("5S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@<V-H=V%N:V5N
M9"!V;VX@)7,@8FES("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HW-#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!!
M=7-WY&AL96X@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@
M(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R+5-T=6YD96XM1F]R;6%T(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA
M="(*;7-G<W1R("(R-"U3='5N9&5N+49O<FUA="(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!3
M='5N9&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I
M9"`B/%!R979I;W5S(@IM<V=S='(@(CQ:=7+\8VLB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E
M<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")&<B!D:65S96X@0FQO
M8VL@=VER9"!E:6YE($1A=&5N8F%N:R!B96YT:6=T+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3<Q"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9"(*;7-G<W1R(")%:6X@<V-H=V5R97(@1F5H;&5R(&ES="!A
M=69G971R971E;CHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E;G1L:6-H
M97(@4$=0+5-C:&S\<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG
M(&5I;F5R($YA8VAR:6-H="`B"B)B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("(B"B)%:6X@]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P@=VER
M9"!F_'(@9&EE(-QB97)P<OQF=6YG(&5I;F5R("(*(G5N=&5R>F5I8VAN971E
M;B!.86-H<FEC:'0@8F5N]G1I9W0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E
M;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!01U`M4V-H;/QS<V5L('-O=VEE
M(&5I;B!087-S=V]R="!W:7)D(&;\<B`B"B)D:64@16YT<V-H;/QS<V5L=6YG
M(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB16EN(/9F
M9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%!'4"U38VAL_'-S96P@<V]W
M:64@96EN(%!A<W-W;W)T('=I<F0@9OQR("(*(F1I92!5;G1E<GIE:6-H;G5N
M9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("(B"B)%:6X@]F9F96YT;&EC:&5R('5N9"!E:6X@<')I=F%T97(@4R]-24U%
M+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O<G0@=VER9"`B"B)F_'(@9&EE
M($5N='-C:&S\<W-E;'5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S
M86=E+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT;&EC:&5R('5N9"!E:6X@<')I
M=F%T97(@4R]-24U%+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O<G0@=VER
M9"`B"B)F_'(@9&EE(%5N=&5R>F5I8VAN=6YG(&5I;F5R($YA8VAR:6-H="!B
M96[V=&EG="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT;&EC
M:&5R(%,O34E-12U38VAL_'-S96P@=VER9"!F_'(@9&EE(%9E<G-C:&S\<W-E
M;'5N9R!E:6YE<B`B"B).86-H<FEC:'0@8F5N]G1I9W0N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO
M=61S(@IM<V=S='(@(E9O<FUI='1A9W,@5V]L:V5N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B5F]R;6ET=&%G<R!L96EC:'1E<B!296=E;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED
M(")!32!286EN(@IM<V=S='(@(E9O<FUI='1A9W,@4F5G96XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R(")6;W)M:71T86=S(%-C:&%U97(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@
M4VYO=R!3:&]W97)S(@IM<V=S='(@(E9O<FUI='1A9W,@4V-H;F5E<V-H875E
M<B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]0
M32(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@
M(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(MQB
M97(@9&EE<V5N($5D:71O<B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("));F9O+BXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(D%B<V]L=70@56YT96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`B06)S;VQU="!-:71T92(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B6G5G<FEF9B!V97)W96EG
M97)T(&)E:6T@06YL96=E;B!D97,@5D93+59E<GIE:6-H;FES<V5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(EIU9W)I9F8@
M=F5R=V5I9V5R="!B96EM($%N;&5G96X@9&5R(%9&4RU$871E:2XB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R(")+;VYT;VEN9F]R;6%T:6]N96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS
M9W-T<B`B2V]N=&]P87-S=V]R="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z
M96XN(@IM<V=S='(@(DMO;G1O(&5I;F=E9G)O<F5N+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T
M<B`B0G5C:&AA;'1U;F<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*
M;7-G<W1R(")(:6YZ=6;\9V5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@
M861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*
M;7-G<W1R(").975E(%5N=&5R9W)U<'!E(&AI;GIU9OQG96XB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM
M<V=S='(@(DYE=64@56YT97)R96-H=&4@:&EN>G5F_&=E;B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T
M<B`B2&EE<B!H:6YZ=6;\9V5N.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM
M<V=S='(@(DYE=64@1W)U<'!E(&AI;GIU9OQG96XB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(").
M975E(%)E8VAT92!H:6YZ=6;\9V5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B56YT97)G<G5P<&4@
M>G4@7"(E<UPB(&AI;GIU9OQG96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")5;G1E<G)E8VAT92!Z
M=2!<(B5S7"(@:&EN>G5F_&=E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS
M9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B1OQG96X@4VEE(&5I;F5N
M(&YE=65N($)E;G5T>F5R(&AI;GIU.B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`B4W!A;'1E(&AI;GIU9OQG96XB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS
M9W-T<B`B3F5U92!-:71G;&EE9&5R(&AI;GIU9OQG96XB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R
M(")086%R(&AI;GIU9OQG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")$87,@)7,M365N_"!Z=7(@36]Z
M:6QL82!3:61E8F%R(&AI;GIU9OQG96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S
M(&)O;VLZ(@IM<V=S='(@(EIU;2!!9')E<W-B=6-H(&AI;GIU9OQG96XZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(EIU(&UE:6YE
M;2!!9')E<W-B=6-H(&AI;GIU9OQG96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B0F5N=71Z97(@:&EN>G5F_&=E
M;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T
M(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM
M<V=S='(@(B(*(EPB)7-<(B!W=7)D92!Z=6T@4WES=&5M(&AI;GIU9V5F_&=T
M+"!A8F5R(&1I92!Z=7/D='IL:6-H96X@(@HB4F5G:7-T<FEE<G5N9W-I;F9O
M<FUA=&EO;F5N(&MO;FYT96X@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N.B`E
M<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N
M(@IM<V=S='(@(EPB)7-<(B!W=7)D92!Z=6T@4WES=&5M(&AI;GIU9V5F_&=T
M+B!3:64@:_9N;F5N('-I8V@@:F5T>G0@86YM96QD96XN(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B1&%S($AI;GIU9OQG96X@=F]N($)E
M;G5T>F5R;B!I<W0@;FEC:'0@;?9G;&EC:"XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30S.`IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")!9')E<W-E(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S
M<R!";V]K(@IM<V=S='(@(D%D<F5S<V)U8V@B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E
M="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B5F5R=V%L
M=&5N("T@4F5C:'1E(&;\<B!A;F1E<F4@0F5N=71Z97(@9F5S=&QE9V5N(@H*
M(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN
M:7-T<F%T:6]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM
M<V=I9"`B061S(@IM<V=S='(@(E=E<F)U;F<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=H86YI<W1A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L9V5R:65N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B
M06QI87,B"FUS9W-T<B`B4W!I='IN86UE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`B075S<FEC:'1U;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S
M='(@(D%U<W)I8VAT=6YG.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX
M-PIM<V=I9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")!
M;F=E;65L9&5T92!"96YU='IE<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@
M861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T
M<B`B06QL92!'<G5P<&5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U
M"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B06QL92!296-H=&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")!;&QE('9I
M97(@4V5I=&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.`IM
M<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(DUE:')E
M<F4@061R97-S96X@97)L875B96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T
M>7!E/R(*;7-G<W1R(")&;W)M870@=F]N(&YU;6UE<FEE<G1E;B!,:7-T96X@
MY&YD97)N/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B17AI<W1I
M97)T(&)E<F5I=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS
M9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=&EV
M92!)35-0+4%N;65L9'5N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(D%L
M=&5R;F%T:79E<R!)35-0+5!A<W-W;W)T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B06QT97)N871I=F5R($E-4U`M0F5N=71Z97)N86UE(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E
M;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L=&5R;F%T:79E($5M86EL861R97-S
M92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:79E(%9O<FQA9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B06QT
M97)N871I=F5R(%1E>'0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@
M4V%M;V$B"FUS9W-T<B`B06UE<FEK86YI<V-H+5-A;6]A(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+B(*;7-G<W1R(")%<R!W=7)D92!E:6X@=6YG_&QT:6=E<B!797)T
M(&%N9V5G96)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G
M<W1R(")%:6X@=6YB96MA;FYT97(@1F5H;&5R(&ES="!A=69G971R971E;BXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!
M;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;GEM97(@4')O>'DB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM
M<V=S='(@(D%N='=O<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A
M(@IM<V=S='(@(D%N=&%R:W1I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG
M=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!U;F0@0F%R8G5D82(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP
M.C,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I
M;VXB"FUS9W-T<B`B06YW96YD=6YG(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(D%N=V5N
M9'5N9W-L:7-T92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G
M:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!;G=E;F1U;F<@
M:7-T(&)E<F5I="XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%U9B!5
M;G1E<G)E8VAT92!A;G=E;F1E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(D)E<W3D
M=&EG96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-#`*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B56YG96;D:')E
M($=R]M]E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V
M*2(*;7-G<W1R(")!<F%B:7-C:"`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E($9I;&4@4VEZ
M92(*;7-G<W1R(")!<F-H:79G<O;?92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B07)C:&EV
M;F%M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS
M9W-T<B`B(@HB4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D:64@4F5G:7-T
M<FEE<G5N9W-A;F9R86=E('9O;B`E<R!L]G-C:&5N(&WV8VAT96X_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"B)3:6YD(%-I
M92!S:6-H97(L(&1A<W,@4VEE(%PB)7-<(B!U;F0@86QL92!5;G1E<F=R=7!P
M96X@;/9S8VAE;B!M]F-H=&5N/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N
M=&EN82(*;7-G<W1R(")!<F=E;G1I;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%R;65N:6$B"FUS9W-T<B`B07)M96YI96XB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T
M<B`B07)M96YI<V-H("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B2W5N<W0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B
M"FUS9W-T<B`B07-C96YS:6]N+4EN<V5L;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%30TE)+4MU
M;G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(D%S:65N+U!A>FEF:7-C
M:&4@4F5G:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I
M9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(D%N<W1E:&5N9&4@5V%R='5N9W-A
M<F)E:71E;B!B97-TY'1I9V5N(&QA<W-E;C\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,#DR"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS
M9W-T<B`B6G5O<F1N=6YG<V9E;&1E<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+B(*;7-G<W1R(")%<R!W=7)D92!V97)S=6-H="P@96EN92!N:6-H="!E
M>&ES=&EE<F5N9&4@1W)U<'!E('IU(&SV<V-H96XN(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B17,@=W5R9&4@=F5R
M<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&SV<V-H
M96XN(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M(")%<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T:65R96YD97,@
M4F5C:'0@>G4@8F5A<F)E:71E;BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92XB"FUS9W-T<B`B17,@=W5R9&4@=F5R<W5C:'0L(&5I;B!N:6-H
M="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E87)B96ET96XN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS
M9W-T<B`B071T<FEB=71E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!=6=U<W0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A
M;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`BUG-T
M97)R96EC:"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ
M-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!$:64@8F5N]G1I
M9W1E($E-05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z($1A<R!"86-K96YD(&AA
M="!N:6-H="!D:64@8F5N]G1I9W1E;B!&Y&AI9VME:71E;BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]C>7)U<SH@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG
M('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($94
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M
M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@
M1&EE(&)E;O9T:6=T92!&5%`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F
M=6YD96XN($MO;7!I;&EE<F5N("(*(E-I92!02%`@;6ET(&1E;2`M+65N86)L
M92UF='`@4&%R86UE=&5R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA
M<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($1I92!B96[V
M=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]K<F(U.B!$:64@8F5N]G1I9W1E($ME<F)E<F]S+45R
M=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@1&%S($AI;GIU9OQG96X@=F]N
M($)E;G5T>F5R;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT("(*
M(G5N=&5R<W3\='IT(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!
M=71H7VQD87`Z($1A<R!,]G-C:&5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@
M06-T:79E($1I<F5C=&]R>2!N:6-H="`B"B)U;G1E<G-T_'1Z="(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VQD87`Z($1I92!B96[V=&EG=&4@3$1!4"U%<G=E:71E<G5N9R!W
M=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@1&5R($)E;G5T>F5R
M("5S(&MO;FYT92!N:6-H="!H:6YZ=6=E9OQG="!W97)D96XN($UE;&1U;F<@
M9&5S("(*(E-E<G9E<G,Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@0F5N
M=71Z97(@)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM
M<V=S='(@(D%U=&A?;&1A<#H@0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&%K
M='5A;&ES:65R="!W97)D96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R
M("(B"B)!=71H7VQD87`Z($1A<R!!:W1U86QI<VEE<F5N('9O;B!"96YU='IE
M<FX@=VER9"!F_'(@06-T:79E($1I<F5C=&]R>2!N:6-H="`B"B)U;G1E<G-T
M_'1Z="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS
M9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!$:64@8F5N]G1I9W1E($U#04PM
M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]S;6)A=71H.B!$:64@8F5N]G1I9W1E(%-A;6)A+45R=V5I=&5R
M=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@
M24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!;FUE;&1U;F<@8F5I;2!)
M34%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")!=71H96YT:69I>FEE<G5N9R!F
M96AL9V5S8VAL86=E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B06YM96QD=6YG(&9E
M:&QG97-C:&QA9V5N+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D1I92!!=71H96YT:69I>FEE<G5N
M9R!W=7)D92!V;VT@4D%$2553+5-E<G9E<B!Z=7+\8VMG97=I97-E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%N;65L
M9'5N9R!B96EM($944"U397)V97(@9F5H;&=E<V-H;&%G96XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!;FUE;&1U
M;F<@8F5I;2!334(M4V5R=F5R(&9E:&QG97-C:&QA9V5N+B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L
M9',Z(@IM<V=S='(@(E9E<F;\9V)A<F4@1F5L9&5R.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07-E<F)A:61S8VAA;B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(D)/1D@M075S<F5D96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(DAI;G1E<F=R=6YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#
M;VQO<B(*;7-G<W1R(")(:6YT97)G<G5N9&9A<F)E(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+B(*;7-G<W1R(")&86QS8VAE<R!+97)B97)O<RU087-S=V]R="XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"
M860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(D9A;'-C:&5R($ME<F)E
M<F]S+4)E;G5T>F5R;F%M92XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S
M(@IM<V=S='(@(D)A:&%M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN
M(@IM<V=S='(@(D)A:')E:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&ES
M8V@@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E
M<V@B"FUS9W-T<B`B0F%N9VQA9&5S8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")"87-I<RU"
M:6QD97(M5F5R>F5I8VAN:7,@7"(E<UPB(&YI8VAT(&=E9G5N9&5N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B1W)U;F1L:6YI92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B5V5IWW)U;&%N9"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER
M=&AD87DB"FUS9W-T<B`B1V5B=7)T<W1A9R(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D)L;V-K(%PB)7-<(B!D97(@06YW96YD=6YG(%PB)7-<
M(B!N:6-H="!G969U;F1E;BXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;V-K
M96EN<W1E;&QU;F=E;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")";&]C:W1Y<"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I
M9"`B0F]L9"(*;7-G<W1R(")&971T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L
M:79I82(*;7-G<W1R(")";VQI=FEE;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("),97-E>F5I
M8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")286YD(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4F%H;65N9&EC:V4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")2Y&YD97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O
M<VYI96XM2&5R>F5G;W=I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B0F5I9&5S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@
M(D)O='1O;2(*;7-G<W1R(")5;G1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T:6YS96PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL:65N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R(")"<FET:7-C:&5S(%1E<G)I=&]R:75M(&EM($EN9&ES8VAE;B!/>F5A
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S
M='(@(D)R=6YE:2!$87)U<W-A;&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L
M9V%R:6$B"FUS9W-T<B`B0G5L9V%R:65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES
M="(*;7-G<W1R(")5;FYU;6UE<FEE<G1E($QI<W1E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G
M<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23"!$:7-T<FEB=71I;VYS<W1E;&QE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E]:96QL96YE:6=E;G-C:&%F=&5N+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"XB"FUS9W-T<B`B1&5R(%IW:7-C:&5N<W!E:6-H97(@:V]N;G1E
M(&YI8VAT(&EN:71I86QI<VEE<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$V(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#4*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(E=I;F1S=&EL;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;V1S8VAA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U
M;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)087-S=V]R="!K86YN
M(&YI8VAT(&%U=&]M871I<V-H('IU<OQC:V=E<V5T>G0@=V5R9&5N+"!B:71T
M92!W96YD96X@4VEE('-I8V@@(@HB86X@26AR96X@061M:6YI<W1R871O<BXB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G
M<W1R(")$:64@1&%T96D@7"(E<UPB(&MA;FX@;FEC:'0@9V5S<&5I8VAE<G0@
M=V5R9&5N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S
M='(@(D5X=&5R;F4@4V5S<VEO;BU(86YD;&5R(&OV;FYE;B!N:6-H="!A9&UI
M;FES=')I97)T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@
M<V5R=F5R.B`E<R(*;7-G<W1R(")697)B:6YD=6YG('IU;2!)34%0+5-E<G9E
M<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;CH@)7,B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B1&EE($1A=&5I
M(%PB)7-<(B!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E;BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B06)B<F5C:&5N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E
M;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")0<F]B;&5M8F5R:6-H="!A8F)R
M96-H96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")$:64@1&%T96D@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H
M="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B2V5I;B!T96UP;W+D<F5S(%9E<GIE:6-H;FES
M(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B1F]R='-E='IU;F<@;VAN
M92!<(G1A<F=E=$9I;&5<(BU087)A;65T97(@;FEC:'0@;?9G;&EC:"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(D1A<R!697)Z96EC:&YI<R!<(B5S7"(@:V]N;G1E(&YI8VAT(&5N=&9E
M<FYT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N
M<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N(@IM<V=S='(@(DMO;FYT92!N:6-H="!E;G1F97)N="!W
M97)D96XL("5D($MI;F1E<B!E>&ES=&EE<F5N+B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@
M(B(*(E5M<V]R=&EE<F5N(&YI8VAT(&WV9VQI8V@N($1I92!!;GIA:&P@9&5R
M($5I;G1RY&=E+"!D:64@=6US;W)T:65R="!W97)D96X@(@HB<V]L;&5N+"!S
M=&EM;70@;FEC:'0@;6ET(&1E<B!!;GIA:&P@9&5R(&=E<W!E:6-H97)T96X@
M16EN='+D9V4@_&)E<F5I;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*(D1I92!.
M86-H<FEC:'0@:V]N;G1E(&YI8VAT(&%N(&1I92!A;F=E9V5B92!.=6UM97(@
M=V5I=&5R9V5L96ET970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A
M<&4@5F5R9&4B"FUS9W-T<B`B2V%P(%9E<F1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R("+<8F5R<V-H<FEF="(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*
M;7-G<W1R(")0<F]V:61E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G
M;W)I96X@=6YD($)E<V-H<FEF='5N9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(D-A>6UA;BU);G-E;&XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL=&5L969O;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G
M:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("):96QL96YE:6=E;G-C:&%F
M=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B26YN96YA8G-T
M86YD.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("):
M96QL96YE:6=E;G-C:&%F=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS
M9W-T<B`B6F5L;&5N86)S=&%N9#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C<Q"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36]B:6QT96QE
M9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I
M8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1I<V-H("A)4T\M.#@U.2TQ
M-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B6F5N=')I97)T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(EIE;G1R86QA9G)I:V%N:7-C:&4@4F5P=6)L:6LB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BDB"FUS9W-T<B`B36ET=&5L975R;W#D:7-C:"`H25-/+3@X
M-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("):97)T:69I
M:V%T9&5T86EL<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("):97)T
M:69I:V%T8F5S:71Z97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T
M<B`B6F5R=&EF:6MA=')I8VAT;&EN:65N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")#:&%D(@IM<V=S='(@(E1S8VAA9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M;7-G:60@(D-H86YG92(*;7-G<W1R("+$;F1E<FXB"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W
M;W)D(@IM<V=S='(@(L1N9&5R;B!3:64@26AR(%!A<W-W;W)T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HBQ&YD
M97)N(%-I92!D96X@3F%M96X@;V1E<B!D:64@16UA:6QA9')E<W-E+"!D:64@
M9&EE($5M<&;D;F=E<B!):')E<B!%;6%I;',@(@HB<V5H96XL('=E;FX@9&EE
M<V4@26AR92!%;6%I;',@;&5S96X@;V1E<B!D87)A=68@86YW;W)T96XN(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#
M:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D1A<R#$;F1E<FX@26AR97,@4&%S
M<W=O<G1S('=I<F0@=F]N(&1I97-E;2!3>7-T96T@>G5R(%IE:70@;FEC:'0@
M(@HB=6YT97)S=/QT>G0N($)I='1E('=E;F1E;B!3:64@<VEC:"!A;B!):')E
M;B!!9&UI;FES=')A=&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B
M6F5I8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T
M<B`B3&EN:R#\8F5R7W!R_&9E;BXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H
M:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B
M"FUS9W-T<B`B0VAI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM
M<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(D-H
M:6YE<VES8V@@=F5R96EN9F%C:'0@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG
M-2DB"FUS9W-T<B`B0VAI;F5S:7-C:"!T<F%D:71I;VYE;&P@*$)I9S4I(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P
M<&QI8V%T:6]N.B(*;7-G<W1R(")!;G=E;F1U;F<@875S=^1H;&5N.B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H
M;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E?D:&QE;B!3:64@96EN(%!A<W-W
M;W)T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM
M<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B5^1H;&5N(%-I92!E
M:6YE;B!"96YU='IE<FYA;65N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G
M<W1R("),96=E;B!3:64@9F5S="P@=VEE(&1A<R!$871U;2!A;F=E>F5I9W0@
M=V5R9&5N('-O;&PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(DQI<W1E;F9O
M<FUA="!A=7-WY&AL96X@*&;\<B!N=6UM97)I97)T92!,:7-T96XI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")796EH
M;F%C:'1S:6YS96PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y
M-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M(")+;&%S<V5N9&5F:6YI=&EO;B!F_'(@)7,@;FEC:'0@9V5F=6YD96XN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G
M:60@(D-L96%R(@IM<V=S='(@(DAE:71E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F
M:6-E('1A9W,B"FUS9W-T<B`B35,M3V9F:6-E+51A9W,@96YT9F5R;F5N(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E<GDB
M"FUS9W-T<B`B06)F<F%G92!Z=7+\8VMS971Z96XB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B0F5N=71Z97)D871E;B!L]G-C
M:&5N.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ
M,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")"96YU='IE<F1A=&5N(&SV
M<V-H96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM
M<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D)E;G5T>F5R9&%T96X@
M;/9S8VAE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(E-PY'1E<B!!
M=69K;&%R96YD(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@
M(D9O<G1F86AR96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B
M"FUS9W-T<B`B0VQI8VMA=&5L;"!P97(@2%144"(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM
M<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(D9E;G-T97(@<V-H;&EEWV5N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*
M;7-G<W1R(")7;VQK96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(D9R
M_&@@5V]L:V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")"97?V;&MT(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T
M<B`B2V]K;W-I;G-E;&XB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(DUE;OP@
M96EN9F%H<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS
M9W-T<B`B6G5S86UM96YHY&YG96YD92!286AM96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I96XB"@HC.B!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM
M<V=I9"`B0V]L;W(B"FUS9W-T<B`B1F%R8F4B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,U"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S8*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,R!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B
M1F%R8F%U<W=A:&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(U
M"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(D9A<F)W86AL(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*
M;7-G:60@(D-O;',Z(@IM<V=S='(@(E-P86QT96XZ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DT,PIM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G
M<W1R(")3<&%L=&5N_&)E<G-C:')I9G1E;B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")#;VUI8W,B
M"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C8*;7-G:60@(D-O;6UA;F0B"FUS
M9W-T<B`B0F5F96AL(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED
M(")#;VUM86YD(%-H96QL(@IM<V=S='(@(D)E9F5H;'-Z96EL92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N
M="(*;7-G<W1R(")+;VUM96YT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B
M16EN9&5U=&EG97(@3F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(DMO;6]R96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D9I
M<FUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP
M=71E<G,B"FUS9W-T<B`B0V]M<'5T97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B0F5D
M:6YG=6YG96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U-@IM<V=I9"`B
M0V]N9&ET:6]N<R(*;7-G<W1R(")"961I;F=U;F=E;B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S(@IM<V=S='(@(DMO;F9I9W5R871I;VYS=6YT97)S8VAI961E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L
M;V]K+B(*;7-G<W1R(")+;VYF:6=U<F%T:6]N(&1E<B!3>6YC:')O;FEZ871I
M;VX@;6ET(%!$07,L(%-M87)T<&AO;F5S('5N9"!/=71L;V]K+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(D1I92!+;VYF:6=U<F%T:6]N(&UU
M<W,@86MT=6%L:7-I97)T('=E<F1E;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*
M;7-G<W1R("(E<R!K;VYF:6=U<FEE<F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*
M;7-G<W1R(")087-S=V]R="!B97-TY'1I9V5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(D1E;6]K<F%T:7-C:&4@4F5P=6)L:6,@2V]N9V\B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9"XB"FUS9W-T<B`B5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E;BXB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(E9E<F)I;F1U;F<@
M9F5H;&=E<V-H;&%G96XZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2#V9F9E
M;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E(&%B9V5W:65S96XN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*(E9E<F)I
M;F1U;F<@>G5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(@=W5R9&4@
M86)G97=I97-E;BX@1W)U;F0Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@W-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@1E10+5-E<G9E
M<B!F96AL9V5S8VAL86=E;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT
M86-T<R(*;7-G<W1R(")+;VYT86MT92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(D1I92!+;VYT86MT92!W=7)D96X@97)F;VQG<F5I8V@@26AR96T@061R
M97-S8G5C:"!H:6YZ=6=E9OQG="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M
M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B26YH86QT<W1Y<"!D97(@:V]M<')I
M;6EE<G1E;B!$871E:3H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM
M<V=S='(@(DEN:&%L="!V;VX@7"(E<UPB(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S
M"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")796ET97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:RU);G-E;&XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G
M<W1R(")#;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P
M:65R96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P
M:65R96X@9F5H;&=E<V-H;&%G96XZ("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I
M;VXB"FUS9W-T<B`B075S=V%H;"!K;W!I97)E;B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S
M='(@(DMO<W1E;BU)1"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B
M"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@
M9"=)=F]I<F4B"FUS9W-T<B`B16QF96YB96EN:_QS=&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!0
M1U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B1&EE($YA8VAR:6-H="!K
M;VYN=&4@;FEC:'0@;6ET(%!'4"!V97)S8VAL_'-S96QT('=E<F1E;CH@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R(")$:64@3F%C
M:')I8VAT(&MO;FYT92!N:6-H="!M:70@4$=0('5N=&5R>F5I8VAN970@=V5R
M9&5N.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y
M,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM
M<V=S='(@(D1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!3+TU)344@
M=F5R<V-H;/QS<V5L="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG
M;B!M97-S86=E+B(*;7-G<W1R(")$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H
M="!M:70@4R]-24U%('5N=&5R>F5I8VAN970@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B2V]N=&%K="!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N
M+B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@3$1!4"U397)V97(@
M9F5H;&=E<V-H;&%G96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")+;VYT;W-T
M86YD(&MO;FYT92!N:6-H="#\8F5R<'+\9G0@=V5R9&5N+B`E<R(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2!,
M1$%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@
M(D944"U697)B:6YD=6YG('IU;2!397)V97(@7"(E<UPB(&MO;FYT92!N:6-H
M="!H97)G97-T96QL="!W97)D96XZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&5R<W1E;&QT
M('=E<F1E;BX@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM
M<V=S='(@(E!'4"U$871E;B!K;VYN=&5N(&YI8VAT(&5N='-C:&S\<W-E;'0@
M=V5R9&5N.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM
M<V=S='(@(E,O34E-12U$871E;B!K;VYN=&5N(&YI8VAT(&5N='-C:&S\<W-E
M;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V]N=&%K="!K;VYN=&4@
M;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(E9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!G96SV<V-H
M="!W97)D96XN("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(D1A<R!!:W1U86QI<VEE
M<G5N9W-S:W)I<'0@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D
M96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RXB"FUS9W-T<B`B1&EE($5M86EL861R97-S92!D97,@16UP9N1N9V5R<R!K
M;VYN=&4@;FEC:'0@97)M:71T96QT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI8VAT(&MO;7!L971T(&=E;&5S96X@
M=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(E9E<G1E:6QE<FQI<W1E(&MO
M;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RXB"FUS9W-T<B`B3&ES=&4@9&5R(%9E<G1E:6QE<FQI<W1E
M;B!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(D1I
M92!3=')A=&5G:64@7"(E<UPB(&MO;FYT92!N:6-H="!G96QA9&5N('=E<F1E
M;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T
M+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@
M7"(E<UPB+B(*;7-G<W1R(")$87,@5F5R>F5I8VAN:7,@7"(E<UPB(&MO;FYT
M92!N:6-H="!A;F=E;&5G="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U
M8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("+69F9E;G1L
M:6-H97(@4V-H;/QS<V5L(&MO;FYT92!N:6-H="!V;VT@4V-H;/QS<V5L<V5R
M=F5R(&=E:&]L="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R
M('=R:71I;F<N(@IM<V=S='(@(EPB)7-<(B!K;VYN=&4@;FEC:'0@>G5M(%-C
M:')E:6)E;B!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(E<R!K;VYN=&4@
M;FEC:'0@9V5L97-E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS
M9W-T<B`B1&%S($UA:6YT96YA;F-E7U1A<VL@36]D=6P@)7,@:V]N;G1E(&YI
M8VAT(&=E]F9F;F5T('=E<F1E;B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R(")697)Z96EC:&YI<R!<(B5S7"(@:V]N;G1E(&YI
M8VAT(&=E]F9F;F5T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*
M;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(E9E<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&MO;FYT92!N:6-H="!H
M97)G97-T96QL="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J
M96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M860@)7,N(@IM<V=S='(@(B5S(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E
M;BXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B
M(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(D1A<R!087-S=V]R="!F_'(@9&5N(&%N9V5G96)E;F5N($)E;G5T>F5R
M(&MO;FYT92!N:6-H="!Z=7+\8VMG97-E='IT('=E<F1E;BP@(@HB=V5I;"!E
M:6YI9V4@06YG86)E;B!N:6-H="!R:6-H=&EG('=A<F5N+B!697)S=6-H96X@
M4VEE(&5S(&5R;F5U="!O9&5R('=E;F1E;B`B"B)3:64@<VEC:"!A;B!):')E
M;B!!9&UI;FES=')A=&]R+"!W96YN(%-I92!W96ET97)E($AI;&9E(&)E;O9T
M:6=E;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S,X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M-0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(D%#3"!K;VYN
M=&4@;FEC:'0@9V5L97-E;B!W97)D96XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G
M<W1R(")$87,@061R97-S8G5C:"!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D
M96XN("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")697)T96EL
M97)L:7-T92!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN("5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B5F5R=&5I;&5R;&ES=&5N
M(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")$
M:64@4V5R=F5R9N1H:6=K96ET96X@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N
M('=E<F1E;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@
M(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N
M9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S971Z="!W97)D96XN
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(E9E<GIE:6-H;FES
M(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B5S
M+4MO;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E
M;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B0F%C:W5P(&1E<B!+;VYF:6=U<F%T
M:6]N(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T
M<B`B0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P
M96EC:&5R="!W97)D96XZ("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B1&%S($%K
M='5A;&ES:65R=6YG<W-K<FEP="!K;VYN=&4@;FEC:'0@;F%C:"!<(B5S7"(@
M9V5S<&5I8VAE<G0@=V5R9&5N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(D)A8VMU
M<"!D97(@2V]N9FEG=7)A=&EO;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE
M<G0@=V5R9&5N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B
M(@HB1&EE($MO;F9I9W5R871I;VX@)7,@:V]N;G1E(&YI8VAT(&=E<W!E:6-H
M97)T('=E<F1E;BX@4VEE(&OV;FYE;B!E;G1W961E<B`B"B)E:6YE(&1E<B!-
M]F=L:6-H:V5I=&5N('5N=&5R("5S('9E<G=E;F1E;BP@=6T@9&5N($-O9&4@
M>G4@<W!E:6-H97)N+"!O9&5R("(*(F1E;B!U;G1E;G-T96AE;F1E;B!#;V1E
M(&UA;G5E;&P@;F%C:"`E<R!K;W!I97)E;BXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D1E<B!,1$%0+5-E<G9E<B!K;VYN
M=&4@;FEC:'0@9'5R8VAS=6-H="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@
M7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(D1E<B!+;VYT86MT(&MO;FYT
M92!N:6-H="!G97-P96EC:&5R="!W97)D96XN("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&%K
M='5A;&ES:65R="!W97)D96XN("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(D1I92!+;VYF
M:6=U<F%T:6]N(&;\<B!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T
M('=E<F1E;CH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS
M9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B)$:64@36]Z
M:6QL82!3:61E8F%R(&MO;FYT92!N:6-H="!G969U;F1E;B!W97)D96XN(%-T
M96QL96X@4VEE('-I8VAE<BP@9&%S<R`B"B)D:64@4VED96)A<B!G9?9F9FYE
M="!I<W0N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@
M=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD
M97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B)$96T@0F5N=71Z97(@7"(E<UPB
M(&MO;FYT96X@9&EE(&9O;&=E;F1E(%)E8VAT92!F_'(@9&5N($]R9&YE<B!<
M(B5S7"(@;FEC:'0@(@HB>G5G97=I97-E;B!W97)D96XZ("5S(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q-@IM<V=I9"`B0V]U;G1E9"!T97AT
M(@IM<V=S='(@(D=E>N1H;'1E<B!497AT(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B
M3&%N9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@
M(D-O=7)S97,B"FUS9W-T<B`B2W5R<V4B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R
M96%T92(*;7-G<W1R(")%<G-T96QL96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T
M92!A(&QI;FLB"FUS9W-T<B`B3&EN:R!E<G-T96QL96XB"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@
M82!N97<@;VYE(@IM<V=S='(@(DYE=64@261E;G1I=.1T(&%N;&5G96XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B
M0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(E5N=&5R;W)D;F5R(&5R<W1E
M;&QE;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS
M9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D5R<W1E;&QE<G)E
M8VAT92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,#D*;7-G:60@
M(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R(")+<F5D:71K87)T96YN=6UM
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F]A
M=&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H
M87-E<R(*;7-G<W1R(")!:W1U96QL92`T(%!H87-E;B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R
M(")!:W1U96QL92!397-S:6]N<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS
M(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM
M<V=S='(@(D%K='5E;&QE(%IE:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@
M55),(&ES(@IM<V=S='(@(D%K='5E;&QE(%523"!I<W0B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B
M06MT=65L;&4@0F5N=71Z97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B06MT=65L;&5S(%=E
M='1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G
M:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B1&5R>F5I=&EG92!"
M961I;F=U;F=E;CH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")!
M:W1U96QL97(@4W1I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"B),96=E;B!3:64@9F5S="P@
M=V5L8VAE($%U9F=A8F5N(&YA8V@@9&5R($%N;65L9'5N9R!B96D@)7,@97)L
M961I9W0@=V5R9&5N("(*(G-O;&QE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*
M;7-G<W1R(")!=7-S8VAN96ED96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM
M<V=S='(@(D%U<W=A:&P@875S<V-H;F5I9&5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0WEP<G5S(@IM<V=S='(@(EIY<&5R;B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+
M>7)I;&QI<V-H("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(DMY
M<FEL;&ES8V@@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM
M<V=S='(@(DMY<FEL;&ES8V@O56MR86EN:7-C:"`H2T])."U5*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E1S8VAE8VAI
M<V-H92!297!U8FQI:R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3(@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(D1$(@IM<V=S='(@(E14(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(V.0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*
M;7-G<W1R("(B"B)$4TX@*'-I96AE(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS
M9VED(")$86EL>2(*;7-G<W1R(")4Y&=L:6-H(@H*(SH@861M:6XO9&%T871R
M964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1A
M=&%4<F5E($)R;W=S97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C8W"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B1&%T96YB86YK
M86)F<F%G92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y-0IM<V=I9"`B
M1&%T92(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@
M(D5M<&9A;F=S9&%T=6TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-S@V"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")$871U;7-A=7-W
M86AL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T
M<B`B5&%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R
M(")3<&%L=&4@7VSV<V-H96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5Z
M96UB97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T
M<B`B6F%H;&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(D5I
M;GIU9R!V97)R:6YG97)N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`B4W1A;F1A<F0B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R
M(")3=&%N9&%R9&9A<F)E(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")3
M=&%N9&%R9&ED96YT:73D="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")3=&%N9&%R9'-H96QL
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET
M:6]N<R(*;7-G<W1R(")$969I;FET:6]N96XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T
M<B`B3/9S8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T
M<B`B6F5L;&4@;/9S8VAE;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T
M<B`B1W)U<'!E(&SV<V-H96XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B3&]G(&SV<V-H
M96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R
M;6ES<VEO;B(*;7-G<W1R(")296-H=&4@;/9S8VAE;B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(DYA8VAR:6-H=&5N(&SV<V-H
M96X@=6YD(&5N=&9E<FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM
M<V=S='(@(EIE;&QE(&SV<V-H96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L
M=6UN(@IM<V=S='(@(E-P86QT92!L]G-C:&5N(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`B0F5S=&5H96YD92!A;'1E<FYA=&EV92!6;W)L
M86=E(&SV<V-H96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(DYA
M8VAR:6-H=&5N(&SV<V-H96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")296-H=&4@9OQR(%PB)7-<(B!L
M]G-C:&5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E)E8VAT
M92!F_'(@7"(E<UPB('5N9"!A;&QE(%5N=&5R<F5C:'1E(&SV<V-H96X_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R("):96EL92!L]G-C:&5N
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM
M<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(D%U<V=E
M=^1H;'1E($ED96YT:73D="!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L
M9&5R<R(*;7-G<W1R(")5;G1E<F]R9&YE<B!L]G-C:&5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(D1I92!A
M:W1U96QL92!3<&%L=&4@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")$:64@86MT=65L;&4@6F5I;&4@
M;/9S8VAE;B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R(")$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T(%PB
M)7-<(B!W=7)D92!G96SV<V-H="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$
M96QI=F5R>2!T:6UE(@IM<V=S='(@(D%U<VQI969E<G5N9W-Z96ET(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$Y&YE;6%R:R(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C
M<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")"97-C:')E:6)E;B!3:64@9&%S
M(%!R;V)L96TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S4@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM
M<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B0F5S8VAR96EB=6YG(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#8*;7-G:60@(D1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T86EL<R`H
M875C:"!I;B!(;W)D97,@3&]G9&%T96DI.B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971A:6QS('=U
M<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET9V5L;V=G="XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N
M="(*;7-G<W1R(")%;G1W:6-K;'5N9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B5&%U<'5N:W0B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z("(*;7-G<W1R(")4875P=6YK="!D97(@;&5T>G1E;B!3
M='5N9&4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*
M;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(E1A=7!U;FMT.B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED
M(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")6;VX@;&EN:W,@
M;F%C:"!R96-H=',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*
M;7-G<W1R(")6;VX@<F5C:'1S(&YA8V@@;&EN:W,B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(E9E<GIE
M:6-H;FES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B
M1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("):96ET(&EM(#(T+5-T
M=6YD96XM1F]R;6%T(&%N>F5I9V5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")!;GIE
M:6=E+45I;G-T96QL=6YG96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS
M9W-T<B`B1&5T86EL:65R=&4@5F]R:&5R<V%G92!A;GIE:6=E;B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@
M*%1!1BDB"FUS9W-T<B`B5F]R:&5R<V%G92`H5$%&*2!A;GIE:6=E;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.38*;7-G:60@(D1I<W!L87D@
M9F]R;6%T(@IM<V=S='(@(D%N>F5I9V5F;W)M870B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I
M9FEC871I;VXB"FUS9W-T<B`B16UP9F%N9W-B97-TY'1I9W5N9R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1S8VAI8G5T:2(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(DYI8VAT(&SV<V-H96XB"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(D=R96EF96X@4VEE(&YI
M8VAT(&1I<F5K="!A=68@;6%I;G1E;F%N8V4N<&AP('IU(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T
M<B`B(@HB16YT:.1L="!D:64@97)S=&4@6F5I;&4@9&EE($9E;&1N86UE;C\@
M5V5N;B!J82P@9&EE<V5S($%U<W=A:&QKY'-T8VAE;B`B"B)M87)K:65R96XZ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI
M8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B1&]M:6YI:V%N:7-C:&4@4F5P=6)L:6LB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U
M;G0_(%-I9VX@=7`N(@IM<V=S='(@(DYO8V@@:V5I;F5N(%IU9V%N9S\@2&EE
M<B!A;FUE;&1E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-3$*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(DAE<G5N=&5R;&%D
M96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B)7,@
M2&5R=6YT97)L861E;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*
M;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N(@IM<V=S='(@(D5R>F5U9W1E($MO;F9I9W5R871I;VX@86QS
M(%!(4"U3:W)I<'0@:&5R=6YT97)L861E;BXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3`T"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R
M(")!=7-W86AL;&ES=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*
M;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=E;B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@
M(D5M86EL(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@
M9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G
M<W1R("(B"B)%;6%I;"UN86-H+5--4RUG871E=V%Y(&;\<B!0<F]V:61E<BP@
M9&EE(&5I;F5N('-O;&-H96X@1&EE;G-T('5N=&5R<W3\='IE;BXB"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B1D5(3$52(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%8W5A9&]R(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(D)E
M87)B96ET96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P
M"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(D)L;V-K(&)E87)B96ET96XB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R
M-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")'<G5P<&4@8F5A<F)E:71E
M;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;B(*;7-G<W1R(")296-H=&4@8F5A<F)E:71E;B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B4F5C:'1E(&)E87)B96ET96XB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E)E8VAT92!F_'(@)R5S)R!B96%R
M8F5I=&5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B
M161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B16EN<W1E;&QU;F=E;B!B96%R
M8F5I=&5N(&;\<CHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B4F5C:'1E(&;\<B!<(B5S7"(@8F5A<F)E:71E
M;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M4F5C:'1E(&;\<B`E<R!B96%R8F5I=&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B0FEL9'5N9R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(L1G>7!T96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A
M;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L
M96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-C8*;7-G:60@(D5M86EL(@IM<V=S='(@(D5M86EL
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S
M(@IM<V=S='(@(D5M86EL861R97-S92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-C`*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R(")$:64@16UA:6QA9')E<W-E;B!M_'-S96X@9VQE:6-H('-E
M:6XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX-@IM<V=I9"`B
M16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B16UA:6P@;6ET($)E
M<W3D=&EG=6YG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S
M='(@(D5M86EL+6YA8V@M4TU3+4=A=&5W87DB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED(")%;6]T:6-O;G,B
M"FUS9W-T<B`B4VUI;&5Y<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB
M"FUS9W-T<B`B3&5E<F4@3F%C:')I8VAT+B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E
M<W5L="XB"FUS9W-T<B`B3&5E<F5S($5R9V5B;FES+B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C
M:"!T97)M<R(*;7-G<W1R(")3=6-H8F5G<FEF9F4@;/9S8VAE;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM
M<V=S='(@(D5I;F;\9V5N('9O;B!":6QD97)N(&%U<R!&;W1O9V%L97)I96X@
M:6X@9&5N(%1E>'0@97)L875B96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`B2V]N=&5X=&UE;OP@8F5I(%)E8VAT<VML:6-K(&%K=&EV
M:65R96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDP"FUS9VED(")%;F0@>65A<B(*;7-G
M<W1R(")%;F1J86AR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B
M161I=&]R('9E<F=R]M]E<FXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H
M('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@
M(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SHB"FUS9W-T<B`B(@HB1V5B96X@4VEE(&5I;F4@4VEC:&5R:&5I='-F
M<F%G92!E:6XL(&1I92!):&YE;B!G97-T96QL="!W:7)D+"!W96YN(%-I92!)
M:'(@(@HB4&%S<W=O<G0@>G5R_&-K<V5T>F5N(&WV8VAT96XL('HN($(N(%PB
M5VEE(&QA=71E="!D97(@3F%M92!):')E<R!(875S=&EE<G,_(@HB7"(Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS
M9W-T<B`B2&EE<B!D:64@0FEL9"U54DP@86YG96)E;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R
M('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R(")'96)E;B!S:64@9&EE($)U
M8VAS=&%B96X@=6YT96X@96EN.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T
M;W)I86P@1W5I;F5A(@IM<V=S='(@(L1Q=6%T;W)I86PM1W5I;F5A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5A(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS9VED(")%<G)O<B(*;7-G<W1R
M(")&96AL97(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C
M:SH@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@17)S=&5L;&5N(&5I;F5S($)L
M;V-K<SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO
M<CH@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR
M;VYI<V%T:6]N<V%N:V5R<SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@3/9S8VAE;B!D
M97,@4WEN8VAR;VYI<V%T:6]N<VQO9W,Z("5S(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")&96AL97(@8F5I
M;2!%<GIE=6=E;B!D97,@26YH86QT<SH@)7,B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D9E:&QE<B!B96EM(,1N
M9&5R;B!D97,@4&%S<W=O<G1S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")&96AL97(@:6X@9&5R($5M86EL
M;F%C:')I8VAT+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D9E
M:&QE<B!B96EM(%-C:')E:6)E;B!V;VX@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T;&%N9"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(L1T:&EO<&EE;B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T
M;FES8VAE<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T
M<B`B06QL92`Q-2!-:6YU=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(D%L;&4@,B!-
M:6YU=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM
M<V=S='(@(D%L;&4@,S`@4V5K=6YD96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V
M97)Y(#4@;6EN=71E<R(*;7-G<W1R(")!;&QE(#4@36EN=71E;B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@
M(D5V97)Y($QO9VEN(@IM<V=S='(@(D)E:2!J961E<B!!;FUE;&1U;F<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF
M(&AO=7(B"FUS9W-T<B`B06QL92!H86QB92!3='5N9&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*
M;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")!;&QE(#8P(%-E:W5N9&5N
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X
M86UP;&4@=F%L=65S.B(*;7-G<W1R(")"96ES<&EE;'=E<G1E.B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M
M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")!
M=7-F_&AR96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(E9E<F=R]M]E
M<FXB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED
M(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")-96[\(&%U<V9A:')E;B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X
M<&5C=&5D("<I)R(*;7-G<W1R("(G*2<@97)W87)T970B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(D5I;GIE
M;&YE<R!7;W)T(&]D97(@4W5C:&)E9W)I9F8@:6X@06YF_&AR=6YG<WIE:6-H
M96X@97)W87)T970B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")697)F86QL
M<V1A='5M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5X<&]N96YT(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM
M<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B5F]R9&5R9W)U;F1F87)B92(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@
M;V8@<V5T=7`B"FUS9W-T<B`B2&]C:&QA9&5N(&1E<B!+;VYF:6=U<F%T:6]N
M('!E<B!&5%`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR
M,C`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G
M<W1R(")"96YU='IE<F5I;G-T96QL=6YG96X@:V]N;G1E;B!N:6-H="!G96QA
M9&5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E9E
M<F)I;F1U;F<@>G5M($Q$05`@4V5R=F5R(&=E<V-H96ET97)T+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O
M(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z
M=6T@4TU"+5-E<G9E<B!G97-C:&5I=&5R="XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B17,@:V]N;G1E(&ME:6YE
M($MO<&EE('9O;B!<(B5S7"(@97)S=&5L;'0@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B17,@:V]N;G1E
M(&YI8VAT(&YA8V@@7"(E<UPB(&MO<&EE<G0@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B075F8F%U(&5I
M;F5N(&YE=65N(%-!4TPM5F5R8FEN9'5N9R!I<W0@9F5H;&=E<V-H;&%G96XN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU,#$@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")%<R!K;VYN=&4@;FEC
M:'0@;F%C:"!<(B5S7"(@=F5R<V-H;V)E;B!W97)D96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")&96AL97(@8F5I;2!,
M97-E;CH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")(96ET97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T
M<B`B1F%L:VQA;F1I;G-E;&XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)
M<VQA;F1S(@IM<V=S='(@(D9A<O9E<B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")38VAW97)E
M<B!&96AL97(Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@
M(D9A>&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S
M='(@(D=E9OQH;'1E(%1E;7!E<F%T=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B
M1V5F_&AL=&4@5&5M<&5R871U<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S
M='(@(E9E<F5I;GIE;'1E(%-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R(")697)E:6YZ96QT92!38VAN965S8VAA=65R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT,0IM<V=I9"`B1FEE;&0@;6%T<FEX
M(@IM<V=S='(@(D9E;&1M871R:7@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S(R"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L
M970@0T%05$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C8*
M;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(D9I9VQE="U&;VYT(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:61S8VAI(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S
M='(@(D1A=&5I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R
M(")!;GIA:&PZ("5S($1A=&5I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL
M97,B"FUS9W-T<B`B06YZ86AL.B`E<R!$871E:65N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S
M='(@(D1A=&5I;6%N86=E<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B1&%T96EN86UE(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW-`IM<V=I9"`B1FEL92!S96QE
M8W1I;VXB"FUS9W-T<B`B1&%T96EA=7-W86AL(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30X,PIM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B
M1&%T96DM2&]C:&QA9&5N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B1&%S($AO8VAL861E;B!V;VX@1&%T96EE;B!W:7)D(&YI8VAT
M('5N=&5R<W3\='IT+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FYL86YD(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")%
M<G-T92!(Y&QF=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L
M;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@
M(D5R<W1E<R!6:65R=&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(E9E
M<FCD;'1N:7,@>G5R_&-K<V5T>F5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R(")5
M;61R96AE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(E1E>'1F;'7?
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*
M;7-G:60@(D9O9R(*;7-G<W1R(").96)E;"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,C,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(D1A<R!697)Z96EC:&YI<R`E<R!E>&ES=&EE<G0@;FEC
M:'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(E-C:')I9G1F87)B92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G
M<W1R(")%<W-E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H
M870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B1OQR($)R;W=S97(L
M(&1I92!K96EN92!":6QD97(@=6YT97)S=/QT>F5N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@
M(E9O<FAE<G-A9V4@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@
M=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB5F]R:&5R9V5S86=T92!486=E("A6
M;W)H97)S86=E;B!E;G1H86QT96X@5&%G92!U;F0@3N1C:'1E+"!E:6X@:&]H
M97(@5V5R="`B"B)K86YN('IU(&5I;F5M('-E:'(@9W)OWV5N($)L;V-K(&;\
M:')E;BDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I
M9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(E!A<W-W;W)T('9E
M<F=E<W-E;C\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS
M9VED(")&;W)M<R(*;7-G<W1R(")&;W)M=6QA<F4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1VS\8VMS
M:V5K<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R
M='5N92!T>7!E(@IM<V=S='(@(D=L_&-K<VME:W-T>7`B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D=L
M_&-K<VME:W-E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(D=L_&-K<VME:W-E(#(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T
M<B`B1F]R96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS
M9VED(")&;W)W87)D<R(*;7-G<W1R(")796ET97)L96ET=6YG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B
M1G(B"FUS9W-T<B`B1G(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B
M4F%H;65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R
M86YK<F5I8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(D5U<F]PY&ES
M8VAE<R!&<F%N:W)E:6-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U
M:6%N82(*;7-G<W1R(")&<F%N>O9S:7-C:"U'=6%Y86YA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B1G)A;GKV<VES
M8V@M4&]L>6YE<VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YZ]G-I<V-H92!'96)I
M971E(&EM('/\9&QI8VAE;B!);F1I<V-H96X@3WIE86XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M
M(@IM<V=S='(@(E9O;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B
M"FUS9W-T<B`B075S("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E9O;&QS
M=.1N9&EG92!"97-C:')E:6)U;F<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM
M<V=S='(@(E9O;&QM;VYD(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U
M;&P@3F%M92(*;7-G<W1R(")6;VQL<W3D;F1I9V5R($YA;64B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)U;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM
M<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B0FEL
M9&5R(&%U<R!D:65S97(@1V%L97)I92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L
M;&5R>3HB"FUS9W-T<B`B1V%L97)I93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(B5S+4MO;F9I9W5R871I;VX@97)Z975G96XB
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I
M9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B17)Z975G=&5R($-O9&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G:65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")$975T<V-H;&%N
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H86YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A
M<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V"FUS
M9VED(")':79E;B!.86UE(@IM<V=S='(@(E9O<FYA;64B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")'
M;&]B86P@3W!T:6]N<R(*;7-G<W1R(")!;&QG96UE:6YE($5I;G-T96QL=6YG
M96XB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B
M"FUS9W-T<B`B3&]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS
M9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-
M87!S(@IM<V=S='(@(D=O;V=L92!-87!S(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")';V]G
M;&4@4W5C:&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B1W)A=7-T=69E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B1W)I96-H
M96YL86YD(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D=R
M965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<FEE8VAI<V-H("A)4T\M.#@U
M.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'
M<O9N;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B
M1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U
M<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P<&5N=F5R=V%L='5N9R(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S
M="!B92!N;VXM96UP='DB"FUS9W-T<B`B1W)U<'!E;FYA;65N(&3\<F9E;B!N
M:6-H="!L965R('-E:6XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("(*;7-G<W1R("(B"B)'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S
M(&MO;FYT92!N:6-H="!H:6YZ=6=E9OQG="!W97)D96XN($UE;&1U;F<@9&5S
M("(*(E-E<G9E<G,Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN
M=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@
M1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC:'0@86MT=6%L:7-I97)T('=E<F1E
M;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<'!E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&5L;W5P92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N
M<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM
M<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1V%S=')E8VAT92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T
M8F]O:R(*;7-G<W1R(")'Y'-T96)U8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82U":7-S874B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-3<*;7-G:60@(DA434PB"FUS9W-T<B`B
M2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")$97(@
M161I=&]R(&MA;FX@9&EE(&QE='IT92!:96QL92!E:6YE<B!:96EL92!N:6-H
M="!L]G-C:&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS
M9W-T<B`B1&5R($5D:71O<B!K86YN(&1I92!L971Z=&4@4W!A;'1E(&5I;F5R
M(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N(@IM<V=S='(@(D1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%IE
M:6QE(&5I;F5R(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(DA45%`M075T:&5N=&EF:7II
M97)U;F<@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B
M2&%S:"U!;&=O<FET:&UU<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(D1I97-I9R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3$Q"FUS9VED(")(96%D97(B"FUS9W-T<B`BW&)E<G-C
M:')I9G0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(DMO<&9E:6YT<N1G92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D+2!U;F0@36-$;VYA;&1I;G-E;&XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM
M<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")38VAW97)E($=E=VET=&5R
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H
M25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)RY&ES8V@@*$E33RTX.#4Y+3@M
M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG
M:'0B"FUS9W-T<B`B2/9H92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](
M96QP+G!H<#HQ.#0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X
M-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L
M<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R(")(:6QF92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G
M:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D5D:71O<FAI;&9E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.`IM<V=I9"`B2&5L<&5R
M(@IM<V=S='(@(DAI;&9E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS
M9VED(")(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES<&AE<F4B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.B(*;7-G<W1R(")$:65S(&ES="!D97(@0F5G:6YN(&1E<B!$871E
M:3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,0IM<V=I9"`B2&EG:"(*;7-G<W1R(")(;V-H(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R
M+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")?4W1A<G1S96ET92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(E9A=&EK86YS=&%D="(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R(")3=&%R='-E
M:71E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B061R97-S92!P<FEV
M870B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@
M1&ER96-T;W)Y(@IM<V=S='(@(DAE:6UV97)Z96EC:&YI<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO
M;64@4&AO;F4B"FUS9W-T<B`B5&5L969O;B!P<FEV870B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(%5N9_QL=&EG92`E<RU834PM1&%T96X@:6X@3F%C
M:')I8VAT("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@
M8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!%<R!P87-S="!K96EN92!.86-H<FEC:'0@>G5M($]B:F5K="`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+96EN($]B
M:F5K="!V;VT@5'EP("5S(&EN($YA8VAR:6-H="`E<R!G969U;F1E;B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@
M7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!<(B5S7"(@=W5R9&4@
M97)F;VQG<F5I8V@@96YT9F5R;G0B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB
M"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($1I92!);G1E9W)A=&EO;G-F=6YK
M=&EO;F5N(&)E;O9T:6=E;B!D:64@7")D;VUX;6Q<(B!02%`M(@HB17)W96ET
M97)U;F<B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4Q,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"B)(;W)D
M92]+;VQA8CH@1OQR(&1A<R!/8FIE:W0@)7,@:V]N;G1E(&ME:6X@;F5U97(@
M6$U,+4)A=6T@97)Z975G="!W97)D96XB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@)7,@7"(E<UPB(&MO;FYT92!N:6-H="!E;G1F97)N="!W
M97)D96XZ("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S
M='(@(B(*(DAO<F1E+TMO;&%B.B!$:64@34E-12U)1"!D97,@06)S8VAN:71T
M<R!V;VT@5'EP("5S(&MO;FYT92!N:6-H="`B"B)H97)A=7-G969U;F1E;B!W
M97)D96XN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M)7,@7"(E<UPB(&MO;FYT92!N:6-H="!S>6YC:')O;FES:65R="!W97)D96XZ
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,W"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@1&EE
M(&=E;65I;G-A;65N($]B:F5K=&4@:V]N;G1E;B!N:6-H="!S>6YC:')O;FES
M:65R="!W97)D96XZ("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!5;F)E:V%N
M;G1E<R!G96UE:6YS86UE<R!/8FIE:W0@7"(E<UPB(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO
M;G1A;"!2=6QE(@IM<V=S='(@(DAO<FEZ;VYT86QE($QI;FEE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B
M2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DAO<FEZ;VYT86QE<B!);FYE
M;F%B<W1A;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N
M=&%L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0
M;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B5VEE('-I;F0@4VEE(&AI97)H97)G
M96QA;F=T/R!":71T92!A;B!D:64@16YT=VEC:VQE<B!Z=7+\8VMM96QD96XA
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_(@IM<V=S='(@(E=I92!V:65L92!3<&%L=&5N('-O;&QE
M;B!Z=7-A;6UE;F=E9OQG="!W97)D96X_(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/R(*;7-G<W1R(")7:65V:65L92!&96QD97(@*%-P86QT
M96XI(&=I8G0@97,_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B5VEE('9I96QE(%IE:6QE
M;B!S;VQL96X@>G5S86UM96YG96;\9W0@=V5R9&5N/R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S<*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(DQU9G1F975C:'1I9VME:70B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(
M=6UI9&ET>3H@(@IM<V=S='(@(DQU9G1F975C:'1I9VME:70Z("(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S
M='(@(DMO;6EK97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS
M9W-T<B`B56YG87)N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B06YL96=E;B!D97,@24U!4"U0;W-T9F%C:',@:7-T
M(&9E:&QG97-C:&QA9V5N.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(DSV<V-H96X@9&5S($E-05`M4&]S=&9A
M8VAS(&ES="!F96AL9V5S8VAL86=E;CH@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")&97-T;&5G96X@
M9&5R($E-05`M4&]S=&9A8V@M475O=&$@:7-T(&9E:&QG97-C:&QA9V5N.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,3,*;7-G:60@(DE0
M($%D9')E<W,B"FUS9W-T<B`B25`M061R97-S92(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B25`M061R97-S92!N:6-H="!V97)F_&=B
M87(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM
M<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C
M:RXB"FUS9W-T<B`B25`M061R97-S92!N:6-H="!I;2!E<FQA=6)T96X@0TE$
M4BU";&]C:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB
M"FUS9W-T<B`B5F5R;&5T>G5N9R!D97(@9F5S=&=E;&5G=&5N($E0+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(EIE:6QE
M(&5I;F;\9V5N(%]V;W(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B
M"FUS9W-T<B`B27-L86YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(").=7(@0FEL9&5R(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DEC;VYS(&9O<B`E<R(*;7-G<W1R("))8V]N<R!F_'(@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B
M"FUS9W-T<B`B0FEL9&5R('5N9"!497AT(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(")"
M97IE:6-H;G5N9R!D97(@261E;G1I=.1T(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(DEF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@HB5V5N;B!S:64@;FEC:'0@
M:V]R<F5K="!A;F=E>F5I9W0@=VER9"P@)7,L('5M('-I92!I;B!E:6YE;2!N
M975E;B!&96YS=&5R("(*(F%N9V5Z96EG="!Z=2!B96MO;6UE;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N
M)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U
M(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(E=E;FX@4VEE(&UI="!D96T@
M26YT97)N970@17AP;&]R97(@:V5I;F4@4WEM8F]L92!S96AE;BP@;?QS<V5N
M(%-I92!D:65S97,@(@HB2^1S=&-H96X@;6%R:VEE<F5N+"!U;2!03D<M5')A
M;G!A<F5N>B!A=7-Z=7-T96QL96XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T
M:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@
M=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S
M97(N(@IM<V=S='(@(B(*(E=E;FX@4VEE(&1I97-E($YA8VAR:6-H="!A;B!3
M=&5L;&4@96EN92!":6QD97,@<V5H96XL(&MA;FX@26AR($)R;W=S97(@9&%S
M("(*(D)I;&0L(&1A<R!3:64@:&]C:&QA9&5N(&WV8VAT96X@;FEC:'0@86YZ
M96EG96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G
M<W1R(")":6QD=F]R<V-H874Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM
M<V=S='(@(D)I;&0M55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ
M(@IM<V=S='(@(D)I;&0M55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@
M9G)O;2!G86QL97)Y(@IM<V=S='(@(D)I;&0@=F]N($=A;&5R:64B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B0FEL
M9"!V;VX@1V%L97)I93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S4X"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B0FEL9"U(;V-H;&%D
M96XB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S
M(@IM<V=S='(@(D)I;&1E<B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM
M<V=S='(@(DEM<&]R=&EE<F5N+"!38VAR:71T("5D(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R=&EE<G1E<R!&96QD.B`E
M<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM
M<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T:65R=&4@1F5L9&5R.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B6F5I
M;&4@96EN9OQG96X@7VYA8V@B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BXB"FUS9W-T<B`B56YG_&QT:6=E($%K=&EO;B!A;F=E9V5B96XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(E5N9_QL=&EG97(@0F5N=71Z97)N86UE('5N9"]O9&5R
M(%!A<W-W;W)T+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q
M"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(D9A
M;'-C:&5R($)E;G5T>F5R;F%M92!O9&5R($5M86EL861R97-S92X@5F5R<W5C
M:&5N(%-I92!E<R!E<FYE=70@;V1E<B!W96YD96X@(@HB4VEE('-I8V@@86X@
M26AR96X@4WES=&5M861M:6YI<W1R871O<BP@=V5N;B!3:64@=V5I=&5R92!(
M:6QF92!B96[V=&EG96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S
M='(@(D5I;GIU9R!V97)G<O;?97)N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M;F1I82(*;7-G<W1R("));F1I96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")%:6YZ96QN92!"96YU
M='IE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(DEN9&]N97-I96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R;6%T:6]N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B26YF
M;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I;VYE;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R;6%T:6]N96X@;FEC
M:'0@;65H<B!V97)F_&=B87(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O
M;'5M;B!!9G1E<B(*;7-G<W1R(")?4W!A;'1E(&1A=F]R(&5I;F;\9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B0FEL9"!H
M:6YZ=6;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(E1A8F5L
M;&4@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B
M3&EN:R!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@
M0F5F;W)E(@IM<V=S='(@(E-?<&%L=&4@9&%N86-H(&5I;F;\9V5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R(")%:6YE(&YE=64@4W!A;'1E(&YA8V@@9&5R(&%K
M='5E;&QE;B!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5I;F4@
M;F5U92!3<&%L=&4@=F]R(&1E<B!A:W1U96QL96X@96EN9OQG96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(D5I;F4@;F5U92!:96EL92!N86-H(&1E<B!A:W1U96QL
M96X@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")%:6YE(&YE=64@6F5I
M;&4@=F]R(&1E<B!A:W1U96QL96X@96EN9OQG96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@
M(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM
M<V=S='(@(D5I;F5N(&YE=65N($%B<V%T>B!N86-H(&1E;2!A:W1U96QL96X@
M16QE;65N="!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(D5I;F5N
M(&YE=65N($%B<V%T>B!V;W(@9&5M(&%K='5E;&QE;B!%;&5M96YT(&5I;F;\
M9V5N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R
M="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B06QT97)N871I=F4@5F]R
M;&%G92!E:6YF_&=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*
M;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"B)'96)E
M;B!3:64@96EN92!%;6%I;&%D<F5S<V4@86XL(&%N(&1I92!D87,@;F5U92!0
M87-S=V]R="!G97-C:&EC:W0@=V5R9&5N("(*(G-O;&PZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I
M9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B6F5L;&4@9&%N86-H(&5I
M;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S
M='(@(EIE;&QE(&1A=F]R(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T
M(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")3<&%L=&4@9&%N86-H(&5I;F;\9V5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B
M4W!A;'1E(&1A=F]R(&5I;F;\9V5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G
M<W1R(").86-H<FEC:'1E;B!H:6YZ=6;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(D%B<V%T>B!D86YA8V@@
M96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(D%B<V%T>B!D879O<B!E:6YF_&=E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B6F5I;&4@9&%N86-H(&5I
M;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T
M<B`B6F5I;&4@9&%V;W(@96EN9OQG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(D=E8F5N(%-I92!D
M:64@06YT=V]R="!A=68@9&EE(%-I8VAE<FAE:71S9G)A9V4@96EN.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G
M:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B0FEL9"!E:6YF_&=E
M;B]B96%R8F5I=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S
M='(@(DQI;FL@96EN9OQG96XO8F5A<F)E:71E;B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R("):=2!W96YI9R!'=71H86)E;BP@=6T@86X@9&EE(%9E
M<G1E:6QE<FQI<W1E('IU('9E<G-C:&EC:V5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("):=2!W96YI9R!'=71H86)E;BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<R"FUS9VED("));G1E
M9V5R(@IM<V=S='(@(D=A;GIZ86AL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$S,`IM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(DQI<W1E
M('9O;B!'86YZ>F%H;&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")5;F?\;'1I9V5R(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@
M(E5N9_QL=&EG92!:25`M1&%T96XN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B
M56YG_&QT:6=E($%N=V5N9'5N9RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T
M8V@@240N(@IM<V=S='(@(E5N9_QL=&EG92!"871C:"U)1"XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q-34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S
M=6)M:71T960N(@IM<V=S='(@(E5N9_QL=&EG92!$871E;B!E:6YG96)E;BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS
M9W-T<B`B56YG_&QT:6=E(%II96QA9')E<W-E+B(*"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@
M9F]R;6%T(@IM<V=S='(@(E5N9_QL=&EG97,@1&%T96EF;W)M870B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED
M(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")5;F?\;'1I9V5R($QI>F5N>G-C:&S\
M<W-E;"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS
M9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")5;F?\
M;'1I9V5R($]R="!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US
M9U]T>7!E+B(*;7-G<W1R(")5;F?\;'1I9V5R(&US9U]T>7!E+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B56YG
M_&QT:6=E(&]D97(@9F5H;&5N9&4@87!I7VED+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(E5N9_QL=&EG
M92!O9&5R(&9E:&QE;F1E(%!A<F%M971E<BXB"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(E5N9_QL=&EG97,@W&)E<G)E8VAT+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R
M=&YE<B!I9"XB"FUS9W-T<B`B56YG_&QT:6=E(%!A<G1N97(M240N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI
M9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(E5N9_QL=&EG97(@4')O9'5K=&-O
M9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")5
M;F?\;'1I9V5S(%!R;W1O:V]L;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E
M8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(E5N9_QL=&EG97(@16UP9N1N9V5R
M.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P.#`@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8S"FUS9VED("));G9A;&ED
M('-H87)E(&]B:F5C="(*;7-G<W1R(")5;F?\;'1I9V5S(&=E;65I;G-A;65S
M($]B:F5K="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB
M"FUS9W-T<B`B56YG_&QT:6=E(%5R<W!R=6YG<V%D<F5S<V4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS
M9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B56YG_&QT:6=E
M(%5N:6-O9&4M1&%T96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&%R(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I
M9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R(")!=7-W86AL('5M:V5H<F5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(DES;&%M:7-C:&4@4F5P=6)L:6L@27)A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*
M;7-G<W1R("))<VQE(&]F($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*
M;7-G<W1R(")697)E:6YZ96QT92!'97=I='1E<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B27-R865L(@IM<V=S='(@(DES<F%E;"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U97(B"FUS9W-T
M<B`B075S<W1E;&QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DMU<G-I=B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EE;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6MA
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*
M;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=6%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!A;B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM
M<V=S='(@(DIA<&%N:7-C:"`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*
M97)S97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*
M;W)D86YI96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B
M"FUS9W-T<B`B2G5N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B
M0FQO8VMS871Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S
M='(@(EIE;G1R:65R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM
M<V=S='(@(D)L;V-K<V%T>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B
M"FUS9W-T<B`B3&EN:W,@875S<FEC:'1E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T
M:69Y(%)I9VAT(@IM<V=S='(@(E)E8VAT<R!A=7-R:6-H=&5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA<V%C:'-T86XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U
M"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")/<FEG:6YA;"!B96EB
M96AA;'1E;C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@
M(DME;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM
M<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")+97)B97)O<RU397)V97(@:&%T($%U=&AE;G1I9FEZ:65R
M=6YG('IU<OQC:V=E=VEE<V5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R;F5L+4YE
M=6QI;F=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B4V-H;/QS<V5L97)Z975G
M=6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS
M9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B1FEN9V5R86)D<G5C:R!D
M97,@4V-H;/QS<V5L<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")38VAL_'-S96QL
MY&YG92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM
M<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B4V-H;/QS<V5L='EP(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5
M<V%G92(*;7-G<W1R(")38VAL_'-S96QZ=V5C:R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"B)$97(@
M4V-H;/QS<V5L(&)E9FEN9&5T('-I8V@@8F5R96ET<R!A=68@9&5M(/9F9F5N
M=&QI8VAE;B!38VAL_'-S96QS97)V97(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(DMI;F1E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(D1E;6]K<F%T:7-C:&4@5F]L:W-R97!U
M8FQI8R!+;W)E82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E)E<'5B;&EK($MO<F5A(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R
M(")+;W)E86YI<V-H("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+
M=7=A:70B"FUS9W-T<B`B2W5W86ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=I<VES=&%N(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(D%N
M7W!A<W-E;B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G
M:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<F%C:&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*
M;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S
M='(@(DQA;W,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),
M87-T($AA;&8B"FUS9W-T<B`B3&5T>G1E($CD;&9T92(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B
M"FUS9W-T<B`B3&5T>G1E(%!A<W-W;W)TY&YD97)U;F<B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),
M87-T(%%U87)T97(B"FUS9W-T<B`B3&5T>G1E<R!6:65R=&5L(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`B3&5T>G1E($%K='5A;&ES:65R=6YG.B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R(*;7-G<W1R("),971Z=&4@06YM96QD=6YG.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(DQE='IT92!!;FUE
M;&1U;F<Z("5S('9O;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B3&5T>G1E
M($%N;65L9'5N9SH@3F]C:"!N:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA
M='9I82(*;7-G<W1R("),971T;&%N9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(D=E<V5T>B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I
M9"`B3&%Y;W5T(@IM<V=S='(@(D9O<FUA="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B3&5E<B!L87-S96X@9OQR(&ME:6YE
M;B!286AM96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T
M<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("),:6YK<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3@*;7-G:60@(DQE9G0@
M:&5A9&5R(@IM<V=S='(@(DQI;FME(-QB97)S8VAR:69T(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-`IM<V=I9"`B3&5F="!V86QU97,B"FUS
M9W-T<B`B3&EN:V4@5V5R=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T
M:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B16)E;F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G
M<W1R("),:6)Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E
M:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE
M(@IM<V=S='(@(E-P<OQH<F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R
M("),96EC:'1E<B!296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S
M='(@(D9R_&@@;&5I8VAT97(@4F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E
M(@IM<V=S='(@(E-PY'1E<B!,96EC:'1E<B!296=E;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!2
M86EN(%-H;W=E<B(*;7-G<W1R("),96EC:'1E(%)E9V5N<V-H875E<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED
M("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("),96EC:'1E<B!2
M96=E;B!M:70@1V5W:71T97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("),
M96EC:'1E<B!38VAN965F86QL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM
M<V=S='(@(DQE:6-H=&4@4V-H;F5E<V-H875E<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EM97)I
M8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$Q"FUS9VED("),
M:6YK(@IM<V=S='(@(DQI;FLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S
M('1O.B(*;7-G<W1R("),:6YK('9E<G=E:7-T(&%U9CHB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<R"FUS9VED("),:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM
M<V=S='(@(D5M86EL861R97-S92!V97)L:6YK96X_(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B
M3&EN:W,B"FUS9W-T<B`B3&EN:W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"U';/QC
M:W-K96MS92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C0V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS
M9W-T<B`B3&ES="`M($)E;G5T>F5R(&MA;FX@9&5N($]R9&YE<B!S96AE;B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A
M<V5S(@IM<V=S='(@(D1A=&5N8F%N:V5N(&%N>F5I9V5N(@H*(SH@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B
M"FUS9W-T<B`B2&EL9F5E:6YT<N1G92!A;GIE:6=E;B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(E1A
M8F5L;&5N(&%N>F5I9V5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T
M96XM07)C:&EV(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T96XM2&EL9F4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I
M9"`B3&ES="U)9"(*;7-G<W1R("),:7-T96XM260B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*
M;7-G<W1R("),:7-T96XM0F5S:71Z97(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@
M(DQI<W1E;BU!9')E<W-E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI
M<W1E;BU!;FUE;&1U;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("),
M:7-T96XM06)M96QD=6YG(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E
M<R(*;7-G<W1R(")$87,@06YZ96EG96X@9&5R(%-E<W-I;VYS(&ES="!F96AL
M9V5S8VAL86=E;CH@)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM
M<V=S='(@(D1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@:7-T(&9E:&QG97-C
M:&QA9V5N.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI
M;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B1&%S($%N>F5I9V5N(&1E<B!"96YU='IE<B!I<W0@;FEC:'0@;?9G;&EC
M:"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R
M871U<F4B"FUS9W-T<B`B3&ET97)A='5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),:71H=6%N:6$B"FUS9W-T<B`B3&ET875E;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N
M+BXB"FUS9W-T<B`B3&%D92XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("),;VMA
M;&4@56AR>F5I=#H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS
M9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B4W!R86-H92!U;F0@6F5I
M="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@IM<V=I9"`B3&]C
M871I;VXB"FUS9W-T<B`B3W)T(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S
M='(@(D%N;65L9&5N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S
M='(@(DQO9R!D97(@;&5T>G1E;B!3>6YC:')O;FES871I;VXN(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*
M;7-G<W1R(")!8FUE;&1E;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B06YM96QD96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R
M(")!;FUE;&1E875F9V%B96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S
M='(@(B(*(D1I92!!;FUE;&1U;F<@:7-T(&9E:&QG97-C:&QA9V5N+"!W96EL
M(%-I92!):')E;B!"96YU='IE<FYA;65N(&]D97(@26AR("(*(E!A<W-W;W)T
M(&9A;'-C:"!E:6YG96=E8F5N(&AA8F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")!
M;FUE;&1U;F<@9F5H;&=E<V-H;&%G96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,V,@IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DQA;F=E
M<B!497AT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),
M;W9E(@IM<V=S='(@(DQI96)E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R(").:65D<FEG
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R
M(")+;"X@9W)I96-H:7-C:&4@0G5C:'-T86)E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B2VPN(&QA=&5I;FES8VAE
M($)U8VAS=&%B96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(DML+B!R]FUI<V-H92!:86AL96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS
M9W-T<B`B34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D
M(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.148M06YH86YG(&5N=&AI96QT(&ME
M:6YE($1A=&5N+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G
M<W1R(")(24Y714E3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G
M<W1R(")-86-A;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(D1I92!E
M:&5M86QI9V4@2G5G;W-L87=I<V-H92!297!U8FQI:R!-87IE9&]N:65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G
M87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA
M9VEC(@IM<V=S='(@(DUA9VEE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@(E=E8FUA:6PB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM
M<V=S='(@(D5M86EL($%D;6EN:7-T<F%T:6]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-
M86ME(&QI;E]K+BXN(@IM<V=S='(@(DQI;FL@7V%N;&5G96XN+BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=VDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&%Y<VEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QI9&EV
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N(@IM<V=S='(@(B(*(E9E<G=A;'1E;B!3:64@9&EE($MA=&5G
M;W)I96XL(&UI="!D96YE;B!3:64@16QE;65N=&4@=6YD($5I;G1RY&=E("(*
M(FME;FYZ96EC:&YE;B!K]FYN96XL('-O=VEE(&1I92!Z=6=E:/9R:6=E;B!&
M87)B96XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87`R-"U+87)T
M92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#@W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P475E<W0M2V%R
M=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@
M(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B6G5O<F1N=6YG96X@9V5S<&5I
M8VAE<G0N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DWD<GHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED
M(")-87)G:6XB"FUS9W-T<B`B077?96YA8G-T86YD(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3
M965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-:70@1V5L97-E;BTO56YG96QE
M<V5N+5-T871U<R!V97)S96AE;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C0Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-:70@86YD97)E
M;2!3=&%T=7,@=F5R<V5H96X@*'HN0BX@5VEC:'1I9R]"96%N=V]R=&5T*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R
M(")-87)S:&%L;&EN<V5L;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN
M:7%U92(*;7-G<W1R(")-87)T:6YI<75E(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R
M("):=6=E;W)D;F5T92!&96QD97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA
M=7)I=&%N:6$B"FUS9W-T<B`B36%U<F5T86YI96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:71I=7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G
M:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%X:6UA;"!E<FQA
M=6)T97(@2W)E9&ET+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N(@IM<V=S='(@(DUA>&EM86QE($YA8VAT:6-H=&5N=&5I;&4@
M_&)E<G-C:')I='1E;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM
M<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DCV8VAS
M='1E;7!E<F%T=7(@9&5R(&QE='IT96X@,C0@4W1U;F1E;CH@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(DCV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT96X@
M-B!3='5N9&5N.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")-87AI;6%L92!!
M;GIA:&P@86X@4&]R=&%L8FSV8VME;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$T"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S8*;7-G:60@(DUA>&EM=6T@;&5N
M9W1H(@IM<V=S='(@(DUA>&EM86QE($SD;F=E(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R
M(")-86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@
M(DUA>6]T=&4@27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P
M"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I>FEN(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*
M;7-G<W1R(")-:71G;&EE9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96[\;6]D=7,Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B6F5L;&5N('IU<V%M
M;65N9OQG96XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(").86-H
M<FEC:'0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R
M:69I960N(@IM<V=S='(@(B(*(D1I92!.86-H<FEC:'0@:V]N;G1E(&5R9F]L
M9W)E:6-H(/QB97)P<OQF="!W97)D96X@86)E<B!N:6-H="!D87,@6F5R=&EF
M:6MA="`B"B)D97,@06)S96YD97)S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R(").86-H<FEC:'0@;FEC:'0@;65H<B!G_&QT:6<N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@
M(DYA8VAR:6-H=&5N='EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS
M9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(DUE=&%R(%=E='1E<B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(DUE=&%R8FQO8VL@;FEC:'0@=F5R9OQG
M8F%R+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-971A
M<F)L;V-K(&YI8VAT('9E<F;\9V)A<BX@1&5T86EL<R!W=7)D96X@9OQR(&1E
M;B!!9&UI;FES=')A=&]R(&UI=&=E;&]G9W0N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(*;7-G<W1R(")+96EN92!697)B:6YD=6YG('IU<B!-971A<D1"
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(DUE=&AO9&4B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D
M969I;F5D(@IM<V=S='(@(D1I92!-971H;V1E(%PB)7-<(B!I<W0@;FEC:'0@
M9&5F:6YI97)T(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<R(*;7-G<W1R(")-971H;V1E(&YI8VAT(&1E9FEN:65R
M="X@075F9V5R=69E;F4@365T:&]D93H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I
M9"`B365T<FEC(@IM<V=S='(@(DUE=')I<V-H(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-97AI8V\B"FUS9W-T<B`B365X:6MO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B
M1O9D97)I97)T92!3=&%A=&5N('9O;B!-:6MR;VYE<VEE;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(DUI='1E(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G
M<W1R(")-:6UE='EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G
M:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")4:65F<W1T
M96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T=6YD96XZ("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z("(*;7-G<W1R(")4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#8@
M4W1U;F1E;CH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960B"FUS9W-T<B`B1&%S(&UI;FEM86QE(%!A<W-W;W)T86QT97(@:7-T
M(&YO8V@@;FEC:'0@86)G96QA=69E;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R
M(")3<&EE9V5L;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I
M9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")697)S8VAI961E;F5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P
M"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM
M<V=S='(@(E!%05(M4&%K970@2%144%]297%U97-T(&9E:&QT+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B
M"B)&96AL96YD92!+;VYF:6=U<F%T:6]N+B!3:64@;?QS<V5N(&1I97-E(&IE
M='IT(&5R>F5U9V5N+"!W96YN(%-I92!D:64@(@HB06YW96YD=6YG('9E<G=E
M;F1E;B!M]F-H=&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$
M+B(*;7-G<W1R(")&96AL96YD92!.86-H<FEC:'1E;BU)1"XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM
M<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS
M9W-T<B`B4$5!4BU086ME="!-86EL(&9E:&QT+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")&96AL96YD92!3:71Z=6YG<RU)
M1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4V"FUS9VED(")-;R(*;7-G<W1R(")-;R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B16UA
M:6P@36]B:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B3>3?:6<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@1&%T
M92(*;7-G<W1R("+$;F1E<G5N9W-D871U;2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R(")54DP@8F5A<F)E:71E;B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(DUO9'5L=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E<'5B;&EK($UO;&1A=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%C;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L96DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@Q"FUS9VED(")-;VYT:"!A
M;F0@>65A<B(*;7-G<W1R(")-;VYA="!U;F0@2F%H<B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H
M;'DB"FUS9W-T<B`B36]N871L:6-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@
M4&AA<V5S(@IM<V=S='(@(DUO;F1P:&%S96XB"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN
M(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(DUE:'(@
M1F5L9&5R(&EN(%IE:6QE("5D(&%L<R!D:64@97)W87)T971E;B`E9"!G969U
M;F1E;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B
M36%R;VMK;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`BW&)E<G=I96=E
M;F0@:&5I=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`BW&)E<G=I
M96=E;F0@0F5W]FQK="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*
M;7-G<W1R("+<8F5R=VEE9V5N9"!"97?V;&MT('5N9"!7:6YD:6<B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B
M36]S=&QY(%-U;FYY(@IM<V=S='(@(MQB97)W:65G96YD(%-O;FYI9R(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X
M"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B3F%C:"!U;G1E;B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS
M9VED(")-;W9E($QE9G0B"FUS9W-T<B`B3F%C:"!L:6YK<R(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED
M(")-;W9E(%)I9VAT(@IM<V=S='(@(DYA8V@@<F5C:'1S(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@
M(DUO=F4@57`B"FUS9W-T<B`B3F%C:"!O8F5N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(DYA8V@@=6YT96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(U"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
M3F%C:"!O8F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM
M<V=S='(@(DUO<V%M8FEK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X,0IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S
M='(@(D%U<W=A:&QL:7-T92!I;B!M96AR97)E;B!%8F5N96XB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.0IM<V=I9"`B
M375L=&EM87`@54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P+55++4MA<G1E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S.0IM<V=I9"`B375L=&EP
M;&4@<V5L96-T:6]N(@IM<V=S='(@(DUE:')F86-H875S=V%H;"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`B365I;B!+;VYT;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")-
M96EN($MO;G1O(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HT-0IM
M<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUE:6X@4&]R=&%L(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED(")->2!0;W)T86P@3&%Y
M;W5T(@IM<V=S='(@(DUE:6X@4&]R=&%L;&%Y;W5T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")->6%N;6%R(@IM<V=S='(@(D)U<FUA(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)
M($1O($Y/5"!!9W)E92(*;7-G<W1R(").14E.+"!I8V@@<W1I;6UE($Y)0TA4
M('IU(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA
M;64B"FUS9W-T<B`B3F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I
M82(*;7-G<W1R(").86UI8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R
M=2(*;7-G<W1R(").875R=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB
M"FUS9W-T<B`B3F5P86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA
M;F1S(@IM<V=S='(@(DYI961E<FQA;F1E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(DYI961E<FSD;F1I<V-H
M92!!;G1I;&QE;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R(").971S
M8V%P92U"87-I<RU54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4M0T$M4W!E<G)U;F=S+5523"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P
M92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C87!E+4-!+5)I8VAT;&EN
M:65N+5523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(").971S
M8V%P92U:971I9FEK871S97)N975E<G5N9W,M55),(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E+5-P97)R=6YG<RU54DPB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I
M9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E
M+5-33"U397)V97)N86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0B"FUS9W-T<B`B3F5T<V-A<&4M2V]M;65N=&%R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4M6F5R=&EF:6MA='1Y
M<"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE
M='=O<FLB"FUS9W-T<B`B3F5T>G=E<FLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G
M<W1R(").:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B
M"FUS9W-T<B`B3F5U:V%L961O;FEE;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O
M<GDB"FUS9W-T<B`B3F5U92!+871E9V]R:64B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYE=6UO;F0B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").
M97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R(").975E<B!"96YU='IE
M<FYA;64@*&]P=&EO;F%L*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE
M86QA;F0B"FUS9W-T<B`B3F5U<V5E;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@
M(DYE=65S(%!A<W-W;W)T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(D1A<R!N975E(%!A<W-W;W)D('=I
M<F0@86T@)7@@86)L875F96XN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*
M;7-G<W1R(")$:64@;F5U96X@4&%S<W?V<G1E<B!S=&EM;65N(&YI8VAT(/QB
M97)E:6XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").
M975E<R!&96YS=&5R("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F%C:')I
M8VAT96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED
M(").97=S9W)O=7!S(@IM<V=S='(@(DYE=W-G<G5P<&5N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B5V5I=&5R(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").
M97AT(#0@4&AA<V5S(@IM<V=S='(@(D[D8VAS=&4@-"!0:&%S96XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S
M='(@(D[D8VAS=&4@16EN<W1E;&QU;F=E;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")796ET97(^
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC
M87)A9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").
M:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").
M:6=E<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM
M<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F%C:'1S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").
M96EN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS
M9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@
M9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R(")+96EN92!+;VYF:6=U<F%T:6]N
M<V1A=&5N('9E<F;\9V)A<BP@=6T@56YT97)S8VAI961E(&%N>G5Z96EG96XN
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ
M,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N(@IM<V=S='(@(DME:6YE(%-T<F%T96=I92!Z=6T@17)S=&5L
M;&5N('9O;B!)4T\M06)B:6QD97)N('9E<F;\9V)A<BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@
M(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(")+96EN92!"871C:"U6;W)L
M86=E+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,S@U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE
M(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(")%<R!E>&ES=&EE<G0@:V5I
M;B!";&]C:R!A;B!D97(@86YG96=E8F5N96X@4&]S:71I;VXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")+96EN($MA;&5N9&5R;F%M92!F_'(@9&EE($U#04PM075T:&5N=&EF
M:7II97)U;F<@86YG96=E8F5N+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(DME:6YE(,1N9&5R=6YG
M96XN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*(E5N=&5R:&%L8B!D:65S97(@16)E;F4@:_9N;F5N
M(&ME:6YE('=E:71E<F5N(%5N=&5R<F5C:'1E(&AI;GIU9V5F_&=T('=E<F1E
M;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W."!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q-PHC.B!F<F%M97=O<FLO571I;"]5=&EL
M+G!H<#HW-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")&_'(@
M)7,@=W5R9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A
M;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!&5%`@5D93+B(*;7-G<W1R("(B"B)&_'(@9&5N($944"U61E,M5')E
M:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N
M(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W
M,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*(D;\<B!D96X@4U%,+59&4RU4
M<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN9F]R;6%T:6]N
M96X@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*(D;\<B!D
M96X@4U%,+41A=&5I+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U
M<F%T:6]N<VEN9F]R;6%T:6]N96X@(@HB86YG96=E8F5N+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I
M9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DME:6X@2W)E9&ET(&UE:'(@
M_&)R:6<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*
M;7-G<W1R(")+96EN($5M<&;D;F=E<B!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(P"FUS9VED(").;R!F:6QE('5P
M;&]A9&5D(@IM<V=S='(@(DME:6YE($1A=&5I(&AO8VAG96QA9&5N(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N
M9"XB"FUS9W-T<B`B2V5I;F4@26-O;G,@9V5F=6YD96XN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S`*;7-G:60@(DYO(&QO
M8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B17,@=W5R9&4@:V5I;B!/<G0@9F5S
M=&=E;&5G="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W
M"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B2V5I;B!/
M<G0@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R(")+96EN92!.86-H<FEC:'0@86YG96=E8F5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS
M9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B2V5I;B!.86UE(&%N
M9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS
M9W-T<B`B2V5I;F4@3G5M;65R(&%N9V5G96)E;BXB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*
M;7-G<W1R(")+96EN92!A;G-T]M]I9V5N($=L_&-K<VME:W-E(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DME:6X@4&%S<W=O<G0@9OQR(&1I92!(5%10+4%U=&AE;G1I9FEZ:65R=6YG
M(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DME:6X@4&%S<W=O<G0@9OQR(&1I92!)
M34%0+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DME:6X@4&%S<W=O<G0@9OQR(&1I92!+97)B97)O<RU!=71H96YT:69I>FEE
M<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B2V5I;B!087-S=V]R="!F_'(@9&EE($QO9VEN+4%U=&AE;G1I9FEZ:65R
M=6YG(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W
M9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN(%!A<W-W;W)T(&;\
M<B!D:64@4$%34U=$+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DME:6X@4&%S<W=O<G0@9OQR(&1I92!334(M075T:&5N=&EF:7II97)U
M;F<@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB
M2V5I;B!09F%D('IU;2!/<&5N4U-,+5!R;V=R86UM(&%N9V5G96)E;BX@1&%S
M($]P96Y34TPM4')O9W)A;6T@=VER9"`B"B)B96[V=&EG="P@=6T@4$M#4RTQ
M,BU$871E;B!V97)A<F)E:71E;B!Z=2!K]FYN96XN(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S
M:6=N=7!S+B(*;7-G<W1R(")+96EN92!A=7-S=&5H96YD96X@4F5G:7-T<FEE
M<G5N9V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-C8*;7-G:60@
M(DYO('%U;W1A('-E="XB"FUS9W-T<B`B2V5I;B!3<&5I8VAE<G!L871Z+4MO
M;G1I;F=E;G0@9F5S=&=E;&5G="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*
M;7-G<W1R(")+96EN92!286AM96XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM
M<V=S='(@(DME:6X@5')E;FYZ96EC:&5N(&%N9V5G96)E;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS
M9VED(").;R!S:61E<R(*;7-G<W1R(")+96EN92!396ET96XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE
M(@IM<V=S='(@(D1A=&5I(&YI8VAT(&=E9G5N9&5N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")+96EN92!T
M96UP;W+D<F5S(%9E<GIE:6-H;FES(&;\<B!D96X@0V%C:&4@9V5F=6YD96XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*
M;7-G<W1R(")+96EN($)E;G5T>F5R;F%M92!U;F0O;V1E<B!087-S=V]R="!A
M;F=E8F5N+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P
M"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(")%
M<R!W=7)D96X@:V5I;F4@9_QL=&EG96X@6$U,+41A=&5N('IU<OQC:V=E9V5B
M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q
M,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(DME:6YE(%=E<G1E(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DME:6YE(%9E<G-I;VYS;G5M;65R
M(&EN(&1E<B!/<FEG:6YA;&MO;F9I9W5R871I;VX@9V5F=6YD96XN($5R;F5U
M97)N(%-I92`B"B)):')E($MO;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@HB2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@26AR97(@2V]N
M9FEG=7)A=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE($EH<F4@(@HB2V]N
M9FEG=7)A=&EO;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(DME:6YE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N
M92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")+96EN<R`H4W1A;F1A<F0@8F5N
M=71Z96XI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO
M<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(DYO<F1I<V-H("A)4T\M.#@U
M.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(DYO<F9O;&MI;G-E;"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B3O9R9&QI8VAE($AE;6ES<&AE<F4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R
M(").]G)D;&EC:&4@36%R:6%N96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO
M<G=A>2(*;7-G<W1R(").;W)W96=E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M1_QL=&EG(&)I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(D?\;'1I9R!A8B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q-0IM<V=I9"`B3F]T
M(&$@9&ER96-T;W)Y(@IM<V=S='(@(DME:6X@5F5R>F5I8VAN:7,B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R(").:6-H="!I;7!L96UE;G1I97)T+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`B3FEC:'0@9F5S=&=E;&5G="(*"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,C,V(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(P."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C,T"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-3(@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(V.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@U(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS,#$*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,Q-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S,S"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HS-C8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`U(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HU-S0*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4Y,2!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-C8Y"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R(").:6-H="!U;G1E<G-T_'1Z="XB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDP."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0T"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@
M(DYO=&EZ96XB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*
M;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").
M:6-H=',@86YZ=7IE:6=E;BP@8FET=&4@>G5R_&-K9V5H96XN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO
M=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`T,PIM<V=I9"`B3G5M8F5R(@IM<V=S='(@(EIA:&PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(R"FUS9VED(").=6UB97(@
M;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")!;GIA:&P@9&5R(%IE:6-H96XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM
M<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B06YZ86AL(&1E<B!3
M<&%L=&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D%N>F%H
M;"!D97(@6F5I;&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE
M9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(DME:6YE($YU;6UE<FX@9OQR(&1I92!697)T96EL97)L:7-T92!A;F=E9V5B
M96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G
M<W1R(")/8FIE:W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B3V)J96MT97)S=&5L
M;&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P,0IM<V=I9"`B
M3V-T86PB"FUS9W-T<B`B3VMT86QZ86AL(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T
M<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R(&;\<B!A;G-T]M]I
M9V4@26YH86QT92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*
M;7-G:60@(D]F9FEC92(*;7-G<W1R(")"_')O(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R
M9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(DEH<B!N975E<R!087-S
M=V]R="!M=7-S('-I8V@@=F]N($EH<F5M(&%L=&5N('5N=&5R<V-H96ED96XN
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/
M;&0@<&%S<W=O<F0B"FUS9W-T<B`B06QT97,@4&%S<W=O<G0B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B1F%L<V-H97,@86QT97,@4&%S
M<W=O<G0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]M
M86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW
M,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RXB"FUS9W-T<B`B3G5R($E-05`M4V5R=F5R('5N=&5R<W3\='IE;B!G
M96UE:6YS86UE($]R9&YE<BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYU
M<B!A;G-T]M]I9V4@1VS\8VMS:V5K<V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C@*;7-G
M:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B
M3G5R(&5I;F4@16UA:6PM061R97-S92!E<FQA=6)T+B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B
M(@HB3G5R(&1E<B!"97-I='IE<B!O9&5R(&1E<B!3>7-T96UA9&UI;FES=')A
M=&]R(&MA;FX@9&5N($)E<VET>F5R(&]D97(@9&EE("(*(D)E<VET>F5R<F5C
M:'1E(.1N9&5R;B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C0R"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R("));B!N975E;2!&96YS=&5R(/9F9FYE;B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,
M(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O
M34E-12!P87)T+B(*;7-G<W1R("(B"B)/<&5N4U-,+49E:&QE<CH@4VEG;FEE
M<G1E(%,O34E-12U$871E;B!K;VYN=&5N(&YI8VAT(&5X=')A:&EE<G0@=V5R
M9&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R(")$:65S96X@3&EN:R!I;B!E:6YE;2!N975E;2!&
M96YS=&5R(/9F9FYE;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM
M<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")"971R:65B<WES=&5M
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B
M3W!T:6]N<R(*;7-G<W1R(")%:6YS=&5L;'5N9V5N(@H*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D5I;G-T
M96QL=6YG96X@9OQR("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@
M(DYU;6UE<FEE<G1E($QI<W1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/
M<F=A;FES871I;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")/
M<F=A;FES871I;VYS86)T96EL=6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FES
M:65R96XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I
M9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B3W)I9VEN86QV
M;W)L86=E(&1E<B!!;G=E;F1U;F<B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(D]R:6=I;F%L=F]R;&%G92!I;B`E<SHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B4V]N<W1I9V4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O
M<FUA=&EO;B(*;7-G<W1R(")!;F1E<F4@26YF;W)M871I;VYE;B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(D)E<VET>F5R<F5C:'1E(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-+4%U=&AE;G1I9FEZ
M:65R=6YG(&ES="!N:6-H="!V97)F_&=B87(N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-
M86EL(&)A8VME;F0B"FUS9W-T<B`B4$5!4CHZ36%I;"U"86-K96YD(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0
M($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D1I9VET86QE(%!'4"U5;G1E
M<G-C:')I9G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0+79E
M<G-C:&S\<W-E;'1E($1A=&5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B
MUF9F96YT;&EC:&5R(%!'4"U38VAL_'-S96PB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(DUI="!01U`@=6YT97)Z96EC:&YE=&4O=F5R
M<V-H;/QS<V5L=&4@1&%T96XB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*
M;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!#;V1E(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0
M(%-H96QL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S@*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B5F]R;6ET=&%G
M<R!L96EC:'1E<B!296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!286EN(@IM<V=S='(@(DYA8VAM
M:71T86=S(%)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B3F%C:&UI
M='1A9W,@4V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(@IM<V=S='(@(DYA8VAM:71T
M86=S(%-C:&YE92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0R"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B3F%C
M:&UI='1A9W,@4V-H;F5E<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B
M3F%C:&UI='1A9W,@4V]N;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B
M3F%C:&UI='1A9W,@1V5W:71T97(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G
M<W1R(")$:64@4$]325@M17)W96ET97)U;F<@9F5H;'0B"@HC.B!L:6(O87!I
M+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B7U!(4"!3:&5L
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B26YN96YA8G-T86YD
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI
M<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A
M;&%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")"97-E='IT92!086SD<W1I;F5N<VES
M8VAE($=E8FEE=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G
M<W1R(")086YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'
M=6EN96$B"FUS9W-T<B`B4&%P=6$M3F5U9W5I;F5A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U87DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R(")496EL=V5I<V4@0F5W]FQK="(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,34*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@
M(E!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)T(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&%S<W=O<G0@97)F;VQG<F5I8V@@9V7D
M;F1E<G0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B1F%L<V-H
M97,@4&%S<W=O<G0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN(%!A<W-W;W)T(&;\<B!D:64@
M4D%$2553+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4P"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")087-S=V]R="!M:70@0F5S=.1T:6=U
M;F<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@
M(E!A<W-W;W)D.B(*;7-G<W1R(")087-S=V]R=#HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M(")087-S=V]R=#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,S$*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D1I92!087-S=_9R=&5R(&W\<W-E;B!G;&5I8V@@<V5I;BXB"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS
M9W-T<B`B16EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*
M;7-G<W1R(")6;VX@9&5R(%IW:7-C:&5N86)L86=E(&5I;F;\9V5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R(")09F%D(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B
M075S<W1E:&5N9&4@4F5G:7-T<FEE<G5N9V5N.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(E!E<G-O;F5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4')O>F5N="(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B5V%R='5N
M9W-A<F)E:71E;B!D=7)C:&;\:')E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\B"FUS9W-T<B`B5V%R='5N9W-A<F)E:71E;B!N86-H(&1E
M<B!!;FUE;&1U;F<@9'5R8VAF_&AR96X_(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M4F5C:'1E(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB
M"FUS9W-T<B`B4F5C:'0@7"(E<UPB('=U<F1E(&YI8VAT(&=E;/9S8VAT+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")097)M
M:7-S:6]N($1E;FEE9"(*;7-G<W1R("):=6=R:69F('9E<G=E:6=E<G0B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4F5C:'1E(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E
M>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B4F5C:'1E=F5R=V%L
M='5N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R
M<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B4&5R<_9N;&EC:&4@06YG86)E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S
M='(@(DAA=7-T:65R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN
M97,B"FUS9W-T<B`B4&AI;&EP<&EN96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R
M(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(E!I>&5L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(E!L871T:&5I=&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S
M='(@(D)I='1E(&ML:6-K96X@4VEE(&EN(&5I;F4@6F5L;&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#HB"FUS9W-T<B`B0FET=&4@8F5S=.1T:6=E;B!3:64L
M(&1A<W,@4VEE(&1I97-E<R!%;&5M96YT(&SV<V-H96X@;?9C:'1E;CHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@HB0FET=&4@8F5TY'1I
M9V5N(%-I92P@9&%S<R!3:64@9&5N($QI;FL@=F]N(&1I97-E;2!%;&5M96YT
M(&5N=&9E<FYE;B!M]F-H=&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U-3D*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE
M87(N(@IM<V=S='(@(D)I='1E(&5I;F5N($UO;F%T('5N9"!E:6X@2F%H<B!A
M;F=E8F5N+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")":71T92!G96)E;B!3:64@96EN96X@
M3F%M96X@9OQR(&1I92!N975E($MA=&5G;W)I92!A;CHB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,CDX"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")":71T92!E:6YE(&?\;'1I9V4@
M25`M061R97-S92!E:6YG96)E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C,W"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R
M("(B"B)":71T92!G96)E;B!3:64@96EN(&?\;'1I9V5S($1A='5M(&%N.R#\
M8F5R<'+\9F5N(%-I92!D:64@6F%H;"!D97(@5&%G92!I;B`B"B)D96T@36]N
M870N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-`IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B0FET=&4@96EN
M96X@9_QL=&EG96X@6F5I='=E<G0@96EN9V5B96XN(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")":71T92!G96)E
M;B!3:64@96EN92!:=7-A;6UE;F9A<W-U;F<@26AR97,@4')O8FQE;7,@86XN
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")":71T92!G96)E;B!3
M:64@26AR96X@0F5N=71Z97)N86UE;B!U;F0@26AR(%!A<W-W;W)T(&%N(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B
M"B)":71T92!L97-E;B!3:64@<VEC:"!D96X@9F]L9V5N9&5N(%1E>'0@<V]R
M9V;D;'1I9R!D=7)C:"X@4VEE($W<4U-%3B!D:65S96X@(@HB0F5D:6YG=6YG
M96X@>G5S=&EM;65N+"!W96YN(%-I92!D:65S97,@4WES=&5M(&)E;G5T>F5N
M(&WV8VAT96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T
M96=O<GD@;F%M93HB"FUS9W-T<B`B0FET=&4@9&5N(&YE=65N($MA=&5G;W)I
M96YA;65N(&5I;F=E8F5N.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD
M(@IM<V=S='(@(E!O;&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W
M"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI=&EK(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B
M56UF<F%G96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G
M<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-I=&EO;FEE<G5N9R!D:65S92!"
M:6QD97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R(")0;W-I=&EO;FEE<G5N9R!D:65S97(@5&%B96QL92(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B
M4V5N9&5N(&%N(&1I97-E;B!/<F1N97(@*&YI8VAT(&1U<F-H($E-05`I(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B3FEE9&5R<V-H;&%G(&EN(&1E
M;B!L971Z=&5N("5S(%-T=6YD92AN*3H@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC92(*;7-G<W1R(").:65D97)S8VAL86=S+3QB<B`O/G=A:')S8VAE:6YL
M:6-H:V5I="(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY
M.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!$:64@8F5N]G1I9W1E
M($Q$05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ($1I92!B96[V=&EG=&4@
M4V5S<VEO;BU%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS
M9W-T<B`B3'5F=&1R=6-K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8*
M;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(DQU9G1D
M<G5C:R!A=68@4V5E:/9H93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("),=69T9')U
M8VLZ("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E9O<G-C
M:&%U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B16EN92!6;W)S8VAA=2!D97,@0FEL9&5S
M(&EN(&5I;F5M(&YE=65M($9E;G-T97(@86YZ96EG96XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R
M(")6;VAE<FEG92!%:6YS=&5L;'5N9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE
M;G0B"FUS9W-T<B`B1&]K=6UE;G0@9')U8VME;B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS
M9W-T<B`B4')I=F%T97(@4V-H;/QS<V5L(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0
M<F]B;&5M92(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B
M4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")0<F]B;&5M8F5S8VAR96EB
M=6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B
M4')O:F5C=',B"FUS9W-T<B`B4')O:F5K=&4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3`X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#4*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,PIM<V=I9"`B4')O;7!T
M('1E>'0B"FUS9W-T<B`B3F%C:&9R86=E=&5X="(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G
M<W1R("+69F9E;G1L:6-H97(@4V-H;/QS<V5L(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG
M;W)I=&AM(@IM<V=S='(@(D%L9V]R:71H;75S(&1E<R#V9F9E;G1L:6-H96X@
M4V-H;/QS<V5L<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B26YF;W)M
M871I;VYE;B!Z=6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E;"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B1&%S(/9F9F5N=&QI8VAE+W!R:79A=&4@4V-H;/QS<V5L<&%A<B!K
M;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*
M;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@
M(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(DYA8VAR:6-H=&5N(&5N9&?\;'1I
M9R!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T
M<B`B2V%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E%U
M97)Y(@IM<V=S='(@(D%B9G)A9V4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(E-P96EC:&5R<&QA='HM2V]N
M=&EN9V5N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B
M:70I(@IM<V=S='(@(M9F9F5N=&QI8VAE<B!24T$@4V-H;/QS<V5L("@E9"!"
M:70I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,0IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(D%U<W=A:&QK;F]P9B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")2
M86EN(@IM<V=S='(@(E)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B
M1G+\:"!296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0W"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B4W#D=&5R(%)E
M9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#@*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(E)E9V5N<V-H875E<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS
M9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(E-C:&YE97)E9V5N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@
M(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")296=E;B!I;B!38VAN964@_&)E<F=E
M:&5N9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD
M;VT@1F]R='5N92(*;7-G<W1R(")';/QC:W-K96MS(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")6
M97)HY&QT;FES(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3&5S96XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S
M86=E<R(*;7-G<W1R(").86-H<FEC:'1E;B!L97-E;B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("(B"B(E<R!W:7)K;&EC:"!L]G-C:&5N/R!$:65S
M97(@5F]R9V%N9R!K86YN(&YI8VAT('+\8VMGY&YG:6<@9V5M86-H="!W97)D
M96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(B(*(D1A=&5N(&1E<R!"96YU='IE<G,@)7,@=VER:VQI8V@@;/9S
M8VAE;C\@1&EE<V5R(%9O<F=A;F<@:V%N;B!N:6-H="`B"B)R_&-K9^1N9VEG
M(&=E;6%C:'0@=V5R9&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(D;\:')T(&QE='IT92!!:W1I;VX@97)N975T(&%U<R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(D%K='5A;&ES:65R
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")$>6YA;6ES8VAE
M($UE;OQE;&5M96YT92!A:W1U86QI<VEE<F5N.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(E!O<G1A;&%N<VEC:'0@86MT=6%L:7-I97)E;CHB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,R"FUS9VED
M(")296=E>"(*;7-G<W1R(")296=U;.1R97(@075S9')U8VLB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C(X"FUS9VED(")296QA=&EO;G-H:7`@
M0G)O=W-E<B(*;7-G<W1R(")697)B:6YD=6YG<RU"<F]W<V5R(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(D%K='5A;&ES
M:65R96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM<V=I9"`B4F5M
M87)K<R(*;7-G<W1R(")"96UE<FMU;F=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D5N
M=&9E<FYT92!397)V97(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.B(*;7-G<W1R(")397)V97)A9')E<W-E("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")%;G1F97)N96XB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!"
M;&]C:R(*;7-G<W1R(")";&]C:R!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O
M;'5M;B(*;7-G<W1R(")3<&%L=&4@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F
M;W)M871T:6YG(@IM<V=S='(@(D9O<FUA=&EE<G5N9R!E;G1F97)N96XB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E
M('!A:7(B"FUS9W-T<B`B4&%A<B!L]G-C:&5N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(D=E<W!E
M:6-H97)T97,@4VMR:7!T(&%U<R!D96T@=&5M<&]RY')E;B!697)Z96EC:&YI
M<R!E;G1F97)N96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S
M='(@(D5N=&9E<FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D1I97-E<R!%;&5M96YT(&%U
M<R!D96T@1&]K=6UE;G0@96YT9F5R;F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T
M<B`B0F5N=71Z97(@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E
M<CH@)7,B"FUS9W-T<B`B0F5N=71Z97(@;/9S8VAE;CH@)7,B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B06YF<F%G92!K;VYN=&4@;FEC:'0@8F5A;G1W;W)T970@=V5R9&5N
M+B!:=7+\8VMG96=E8F5N97(@1F5H;&5R8V]D93H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I
M8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(")$97(@9V5W_&YS8VAT
M92!$:65N<W0@:V]N;G1E(&YI8VAT(&=E9G5N9&5N('=E<F1E;BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X-2!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")<(B5S7"(@=W5R9&4@:6X@9&5R($MO;F9I9W5R871I;VX@9OQR("5S
M(&YI8VAT(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@:6X@9&5R(%9&
M4RU+;VYF:6=U<F%T:6]N(&YI8VAT(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B7"(E<UPB('=U<F1E(&EN(&1E<B!+;VYF:6=U<F%T:6]N(&YI
M8VAT(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(DYO
M='=E;F1I9V5S($9E;&0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]2
M96YD97)E<BYP:'`Z,S(P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED
M(")297-E="(*;7-G<W1R("):=7+\8VMS971Z96XB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS
M9W-T<B`B4&%S<W=O<G0@>G5R_&-K<V5T>F5N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B
M"FUS9W-T<B`B4V5T>F5N(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,87-T(%%U
M97)Y(@IM<V=S='(@(DQE='IT92!!8F9R86=E(&5I;F;\9V5N(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI
M;B]S<6QS:&5L;"YP:'`Z-C<*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B17)G
M96)N:7-S92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P
M=&EO;G,B"FUS9W-T<B`B6G5R_&-K('IU($5I;G-T96QL=6YG96XB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N
M97<@<&%S<W=O<F0B"FUS9W-T<B`B3F5U97,@4&%S<W=O<G0@97)N975T(&5I
M;F=E8F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R
M(")2Z75N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")+;VYF:6=U<F%T:6]N('IU<OQC:W-E='IE;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")765-)5UE'+45D:71O<B!%:6YS=&5L
M;'5N9V5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2
M:61D;&5S(@IM<V=S='(@(E+D='-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS
M9W-T<B`B4F5C:'1S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P
M,`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(E)E8VAT92#<8F5R<V-H
M<FEF="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.38*;7-G:60@
M(E)I9VAT('9A;'5E<R(*;7-G<W1R(")296-H=&4@5V5R=&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*
M;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?6F5I;&5N96EG
M96YS8VAA9G1E;BXN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L;&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)U;>1N:65N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")5;2`Q.#"P(&1R96AE;B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*
M;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(DYA8V@@;&EN:W,@9')E:&5N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(DYA8V@@<F5C:'1S(&1R
M96AE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(EIE
M:6QE;F5I9V5N<V-H869T96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE
M<R(*;7-G<W1R("):96EL96YE:6=E;G-C:&%F=&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z
M(@IM<V=S='(@(EIE:6QE;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R
M(")296=E;&XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(E)A:&UE;B!Z=VES
M8VAE;B!A;&QE;B!:96EL96X@=6YD(%-P86QT96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R
M(")286AM96X@;G5R('IW:7-C:&5N(%-P86QT96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")2
M86AM96X@;G5R('IW:7-C:&5N(%IE:6QE;B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R(")3=&%R=&5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U
M<W-I<V-H92!&]G)D97)A=&EO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W
M86YD82(*;7-G<W1R(")2=6%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12!K<GET;V=R87!H:7-C:&4@56YT
M97)S8VAR:69T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R
M(")-:70@4R]-24U%('9E<G-C:&S\<W-E;'1E($YA8VAR:6-H="(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"U!
M=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I
M;F<B"FUS9W-T<B`B4TU3+59E<G-A;F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")344P@4VAE;&PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Q"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-13"U!;G=E:7-U
M;F<@>G5R($%B9G)A9V4@9&5R(%=E<G1E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B15)&3TQ'(@H*
M(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@
M(E-?44P@4VAE;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")382(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE
M;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I
M<R(*;7-G<W1R(")386EN="!+:71T<R!U;F0@3F5V:7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R(")386EN="!0:65R<F4@=6YD($UI<75E;&]N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="!U;F0@9&EE($=R96YA9&EN96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR
M"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B1VQE:6-H97(@
M4F%H;65N("A?<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*
M;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!U;F0@
M4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QL:71E
M;G!R;W9I9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA
M(@IM<V=S='(@(E-A=61I+4%R86)I96XB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B4W!E:6-H97)N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@
M<W!E:6-H97)N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(E<R!S<&5I
M8VAE<FXB"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3
M879E($]P=&EO;G,B"FUS9W-T<B`B16EN<W1E;&QU;F=E;B!S<&5I8VAE<FXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*(D5R>F5U9W1E($MO;F9I9W5R871I;VX@86QS(%!(4"U3:W)I<'0@:6T@
M=&5M<&]RY')E;B!697)Z96EC:&YI<R!):')E<R`B"B)397)V97)S('-P96EC
M:&5R;BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(E<RU+;VYF:6=U<F%T:6]N(&=E<W!E:6-H97)T+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D1A
M<R!!:W1U86QI<VEE<G5N9W-S:W)I<'0@=W5R9&4@:6X@7"(E<UPB(&=E<W!E
M:6-H97)T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4Q"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B5F5R
M96EN>F5L=&4@1V5W:71T97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B5VES<V5N<V-H869T(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")3
M=6-H92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@
M(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E-U8VAM87-C:&EN96XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.34R"FUS9VED(")396QE8W0@1FEL
M97,B"FUS9W-T<B`B1&%T96EE;B!A=7-WY&AL96XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@
M82!D871E(@IM<V=S='(@(D1A='5M(&%U<W?D:&QE;B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T
M;R!A9&0B"FUS9W-T<B`B2&EN>G5Z=6;\9V5N9&4@1W)U<'!E;B!A=7-WY&AL
M96XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")3
M96QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B3F5U96X@0F5S:71Z97(@875S
M=^1H;&5N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS
M9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B4V5R=F5R(&%U<W?D:&QE
M;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")3
M96QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")(:6YZ=7IU9OQG96YD96X@
M0F5N=71Z97(@875S=^1H;&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R
M(")!;&QE(&%U<W?D:&QE;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V-#`*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G
M<W1R("),96=E;B!3:64@86QL92!$871U;7-K;VUP;VYE;G1E;B!F97-T+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*
M;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B3V)J96MT(&%U<W?D
M:&QE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(DME:6YE;B!A=7-W
MY&AL96XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*
M(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)7Y&AL96X@4VEE(&1I
M92!B96[V=&EG=&5N(%IE:6-H96X@875S(&1E;B!J97=E:6QI9V5N($9E;&1E
M<FX@875S+B!$86YN("(*(FOV;FYE;B!3:64@9&EE<V4@875S(&1E;2!497AT
M9F5L9"!K;W!I97)E;B!U;F0@:6X@26AR92!.86-H<FEC:'0@96EN9OQG96XN
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C
M="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E?D:&QE;B!3:64@9&%S
M($1A='5M<W1R96YN>F5I8VAE;CHB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T
M<B`B5^1H;&5N(%-I92!D87,@1&%T=6US9F]R;6%T.B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")7Y&AL
M96X@4VEE(&1I92!)9&5N=&ETY'0L(&1I92!3:64@Y&YD97)N(&WV8VAT96XZ
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E?D:&QE;B!3:64@9&%S
M(%IE:71T<F5N;GIE:6-H96XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@
M(E?D:&QE;B!3:64@9&%S(%IE:71F;W)M870Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N(@IM<V=S='(@(E?D:&QE;B!3:64@>G=E:2!Z=7-A;6UE;F=E:/9R
M:6=E($9E;&1E<B!A=7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q
M,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")7
MY&AL96X@4VEE(&5I;B!&87)B<V-H96UA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93HB"FUS9W-T<B`B5^1H;&5N(%-I92!):')E(&)E=F]R>G5G=&4@4W!R
M86-H93HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM
M<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")0<F]B;&5M8F5R
M:6-H="!A8G-C:&EC:V5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E--
M4R!V97)S8VAI8VME;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB
M"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(S
M"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YS;W(Z("(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T
M96UB97(B"FUS9W-T<B`B4V5P=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N
M96=R;R(*;7-G<W1R(")397)B:65N('5N9"!-;VYT96YE9W)O(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA
M;"!.=6UB97(B"FUS9W-T<B`B4V5R:65N;G5M;65R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4V5R=F5R9&%T96X@=6YG
M_&QT:6<@;V1E<B!N:6-H="!V97)F_&=B87(N(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(E-E<W-S
M:6]N=F5R=V%L='5N9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D
M+B(*;7-G<W1R(")397-S:6]N+4E$(&%B9V5L875F96XN(@H*(SH@;&EB+V%P
M:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")3:71Z=6YG96XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$Q"FUS9VED(")3970B
M"FUS9W-T<B`B075S=V%H;"U3871Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S
M='(@(B(*(DQE9V5N(%-I92!D:64@16EN<W1E;&QU;F=E;B!F97-T+"!D:64@
M97,@26AN96X@97)L875B96X@26AR(%!A<W-W;W)T("(*(GIU<OQC:WIU<V5T
M>F5N+"!F86QL<R!S:64@97,@96EN;6%L('9E<F=E<W-E;B!S;VQL=&5N+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+B(*;7-G<W1R("(B"B),96=E;B!3:64@96YT9F5R;G1E(%-E
M<G9E<B!F97-T+"!A=68@9&EE(%-I92!V;VX@26AR96T@4&]R=&%L(&%U<R!Z
M=6=R96EF96X@(@HB;?9C:'1E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM
M97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B5^1H;&5N(%-I92!)
M:')E(&)E=F]R>G5G=&4@4W!R86-H92P@6F5I='IO;F4@=6YD($1A='5M<V5I
M;G-T96QL=6YG96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM
M<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y
M(&]P=&EO;G,N(@IM<V=S='(@(B(*(DQE9V5N(%-I92!D87,@9&EE(%-T87)T
M86YW96YD=6YG+"!D87,@1F%R8G-C:&5M82P@9&EE(%-E:71E;F%K='5A;&ES
M:65R=6YG("(*(G5N9"!A;F1E<F4@06YZ96EG965I;G-T96QL=6YG96X@9F5S
M="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U
M<"(*;7-G<W1R(")+;VYF:6=U<F%T:6]N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R
M:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B06MT=6%L:7-I97)U;F=S<VMR:7!T
M92!S:6YD('9E<F;\9V)A<B(*"B,@365H<F5R92!P87-S96YD92!/<G1E(&UI
M="!D:65S96T@4&%R86UE=&5R.B`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B365H<F5R92!P87-S96YD
M92!/<G1E(&UI="!D:65S96T@4&%R86UE=&5R.B`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL96XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*
M;7-G<W1R(")%:6YK875F(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2W5R>F4@
M6G5S86UM96YF87-S=6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U
M,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(E-O;&QE;B!487-T96YK;VUB:6YA=&EO;F5N
M(&;\<B!D:64@;65I<W1E;B!,:6YK<R!A:W1I=FEE<G0@=V5R9&5N/R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3
M:&]W(@IM<V=S='(@(EIE:6=E;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HB56YT97)S8VAI961E('IW:7-C:&5N(&1E
M<B!A:W1U96QL96X@=6YD(&1E<B!G97)A9&4@97)Z975G=&5N($MO;F9I9W5R
M871I;VX@(@HB86YZ96EG96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG
M(&EN/R(*;7-G<W1R(")!;GIE:6=E;BP@=V%N;B!D:64@;&5T>G1E($%N;65L
M9'5N9R!E<F9O;&=T(&ES=#\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S8R"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM
M<V=S='(@(D5R:&%L=&5N(&1E<R!/<FEG:6YA;',@97)M]F=L:6-H96XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDR"FUS9VED(")3:&]W('!I
M8VME<B(*;7-G<W1R(")!=7-WY&AL97(@86YZ96EG96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_(@IM<V=S='(@(E=E<FMZ975G;&5I<W1E(&;\<B!486)E
M;&QE;B!A;GIE:6=E;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_(@IM<V=S='(@(D1A<R`E<RU-96[\(&%U9B!D97(@;&EN:V5N(%-E
M:71E(&%N>F5I9V5N/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")$:6%L;V<@9OQR(%1A
M8F5L;&5N>F5L;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B1&EA;&]G(&;\<B!486)E;&QE;F5I9V5N<V-H869T96X@86YZ96EG96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R(")$:6%L;V<@9OQR(%1A8F5L;&5N>F5I;&5N96EG
M96YS8VAA9G1E;B!A;GIE:6=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@
M:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B1&EA;&]G(&;\<B!"
M:6QD96EG96YS8VAA9G1E;B!A;GIE:6=E;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C`*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(DAO
M8VAL861E;B!E<FWV9VQI8VAE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM<V=S='(@(E-C
M:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")&<OQH(%-C:&%U
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(E-PY'1E<B!38VAA=65R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*
M;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(E-C:&%U
M97(@:6X@9&5R(%5M9V5B=6YG(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R
M(")697)K;&5I;F5R;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U
M"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B5F5R:VQE:6YE<FX@;V1E
M<B!V97)S8VAI96)E;B!3:64@97)S="!D:64@8F5N86-H8F%R=&5N($)L]F-K
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R
M(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(E)E9VES=')I97)E
M;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$S"FUS
M9VED(")3:6=N871U<F4B"FUS9W-T<B`B4VEG;F%T=7(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E
M($%L9V]R:71H;2(*;7-G<W1R(")3:6=N871U<F%L9V]R:71H;75S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<'5R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DS"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,#D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,@IM<V=I9"`B4VEZ
M92(*;7-G<W1R(")'<O;?92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM
M<V=S='(@(E=A<G1U;F=S87)B96ET96X@_&)E<G-P<FEN9V5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=V%K96DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]W96YI
M96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-@IM<V=I9"`B4VYO=R(*;7-G<W1R(")38VAN964B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W
M97(B"FUS9W-T<B`B4V-H;F5E<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B4V-H;F5E<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B1G+\:"!38VAN965S8VAA=65R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO
M=V5R<R!,871E(@IM<V=S='(@(E-PY'1E<B!38VAN965S8VAA=65R(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*
M;7-G<W1R(")38VAN965H]FAE.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T
M<B`B4V-H;F5E;65N9V4@86QS(%=A<W-E<CH@(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O;&]M;VYI;G-E;&XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L
M:65N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG
M<R`F(%!O96US(@IM<V=S='(@(DQI961E<B`F($=E9&EC:'1E(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDP-0IM<V=I9"`B4V]R="!O<F1E<B!S
M96QE8W1I;VXB"FUS9W-T<B`B075S=V%H;"!D97(@4V]R=&EE<G)E:6AE;F9O
M;&=E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B
M57)S<')U;F=S861R97-S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H
M($%F<FEC82(*;7-G<W1R(")3_&1A9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M(@IM<V=S='(@(E/\9&5U<F]PY&ES8V@@*$E33RTX.#4Y+3,I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<R(*;7-G<W1R(")3_&1G96]R9VEE;B!U;F0@9&EE(%/\
M9&QI8VAE;B!386YD=VEC:&EN<V5L;B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B4_QD;&EC:&4@2&5M:7-P:&5R92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(D%B<W1A
M;F0@>G=I<V-H96X@875F96EN86YD97(@9F]L9V5N9&5N(%IE;&QE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS
M9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M(@IM<V=S='(@(D%B<W1A;F0@>G=I<V-H96X@26YH86QT('5N9"!286AM96X@
M=F]N(%IE;&QE;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q,@IM
M<V=I9"`B4W!A8V5R(@IM<V=S='(@(D%B<W1A;F1H86QT97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G
M:60@(E-P86-I;F<B"FUS9W-T<B`B06)S=&%N9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P
M86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B06)S=.1N9&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B4W!A;FEE;B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B
M4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E
M8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B4V]N9&5R>F5I8VAE;BU%
M:6YG86)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("):96QL
M92!T96EL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B
M4W!A;'1E('1E:6QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M("):96EL92!T96EL96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*
M;7-G:60@(E-P;W)T<R(*;7-G<W1R(")3<&]R="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@Q"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S
M='(@(E-T87(@5')E:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M.#,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<X.`IM<V=I9"`B4W1A<G0@
M>65A<B(*;7-G<W1R(")3=&%R=&IA:'(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B
M"FUS9W-T<B`B0G5N9&5S<W1A870@;V1E<B!0<F]V:6YZ(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*
M;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-SDT"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")3<&5I8VAE<F9O
M<FUA="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S
M"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")3=')AWV4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED
M(")3=')I:V5T:')O=6=H(@IM<V=S='(@(D1U<F-H9V5S=')I8VAE;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S`*;7-G:60@(E-T<FEN9R!L
M:7-T(@IM<V=S='(@(EIE:6-H96YL:7-T92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S`*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S(@IM<V=S='(@(D1O;6%I;B!A=7,@9&5R($%D<F5S<V4@96YT9F5R
M;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I;"!;
M0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(E-O(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")5;G1E<G9E<GIE:6-H;FES
M(%PB)7-<(B!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S
M='(@(D)E=')E9F8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3
M=6)M:70B"FUS9W-T<B`B06)S8VAI8VME;B(*"B,Z('-I9VYU<"YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@
M861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U
M;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S
M='(@(B(*(D1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@9OQR(%PB)7-<(B!W
M=7)D92!A8F=E<V-H:6-K="X@4VEE(&OV;FYE;B!S:6-H(&YO8V@@(@HB;FEC
M:'0@86YM96QD96XL('-O;&%N9V4@9&EE($%N9G)A9V4@;F]C:"!N:6-H="!B
M97-TY'1I9W0@=W5R9&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(E1I
M969G97-T96QL="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")%<F9O;&<B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B!W=7)D92!E<F9O;&=R96EC:"!H:6YZ=6=E9OQG="XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M+B(*;7-G<W1R(")$871E;B!D97,@0F5N=71Z97)S(%PB)7-<(B!W
M=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R
M(")<(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*
M;7-G<W1R("(B"B)+;VYF:6=U<F%T:6]N(&5R9F]L9W)E:6-H('IU<OQC:V=E
M<V5T>G0N(%-E:71E(&YE=2!L861E;BP@=6T@9&EE(,1N9&5R=6YG96X@(@HB
M86YZ=7IE:6=E;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0F%C:W5P(&1E
M<B!+;VYF:6=U<F%T:6]N(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R(")"86-K=7`@9&5R($MO;F9I9W5R871I;VX@
M)7,@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A
M=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@
M86MT=6%L:7-I97)T(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S('=U<F1E(&5R9F]L
M9W)E:6-H(&=E<W!E:6-H97)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D
M86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S
M='(@(EIU<V%M;65N9F%S<W5N9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B4V]N;F5N875F9V%N9R(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*
M;7-G<W1R(")3;VYN96YU;G1E<F=A;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B
M4V]N;FEG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM
M<V=I9"`B4W5N<FES92(*;7-G<W1R(")3;VYN96YA=69G86YG(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V
M"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")3;VYN96YA=68O=6YT
M97)G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM
M<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(E-O;FYE;F%U9F=A;F<Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E
M="(*;7-G<W1R(")3;VYN96YU;G1E<F=A;F<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")3
M;VYN96YU;G1E<F=A;F<Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@
M(DAO8VAG97-T96QL="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B4W5P<&]R="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R
M;F%M92(*;7-G<W1R(").86-H;F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@=6YD
M($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R(")3=V%S:6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D
M96XB"FUS9W-T<B`B4V-H=V5D96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I
M='IE<FQA;F0B"FUS9W-T<B`B4V-H=V5I>B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S
M='(@(E-Y;F-H<F]N:7IA=&EO;G-L;V<@9V5L]G-C:'0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B4WEN
M8TU,(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS
M9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D9O
M<FUA=&9E:&QE<B!I;B!3=6-H8F5G<FEF9F5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B07)A8FES8VAE
M(%)E<'5B;&EK(%-Y<FEE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D=E=VET
M=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C,*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(D=E=VET=&5R
M('5N9"!7:6YD:6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B1V5W:71T97(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM
M<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B1G+\:"!'97=I='1E<B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E13
M5B!F:6QE(@IM<V=S='(@(E135BU$871E:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE
M(%!R;W!E<G1I97,B"FUS9W-T<B`B5&%B96QL96YE:6=E;G-C:&%F=&5N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM
M<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(E1A8F5L;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED
M(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E1A8F5L;&5N96EG96YS8VAA
M9G1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G
M<W1R(")486EW86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G
M<W1R(")486EW86XL(&-H:6YE<VES8VAE(%!R;W9I;GHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9'-C:&EK:7-T86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E9E<F5I;FEG=&4@4F5P=6)L:6L@5&%N<V%N:6$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"FUS9VED(")487)G970Z(@IM<V=S='(@(EII96PZ(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,S(@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M-#D*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S
M:W,B"FUS9W-T<B`B075F9V%B96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G
M<W1R(")496QE9F]N;G5M;65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7!E
M<F%T=7(@9&5R(&QE='IT96X@4W1U;F1E.B`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R
M871U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G
M:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R871U<CH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(E1E;7!E<F%T=7(\8G(@+SXH)7--87@E<R\E<TUI;B5S
M*2`F9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B5F]R;&%G92!<(B5S7"(@;FEC:'0@9V5F=6YD
M96XN(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L
M871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E9O<FQA9V5N=F5R=V%L='5N
M9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,#@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,R-`IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/
M;FQY(@IM<V=S='(@(DYU<B!497AT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG
M;B(*;7-G<W1R(")!=7-R:6-H='5N9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T
M<B`B5&5X="!/8F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B1&\B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS
M9W-T<B`B5&AA:6SD;F1I<V-H("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1H86EL86YD(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H92!&5%`@97AT96YS
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1I92!&5%`M17AT96YS
M:6]N(&ES="!N:6-H="!V97)F_&=B87(N(@H*(SH@9G)A;65W;W)K+TAI<W1O
M<GDO2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B1&EE($-H<F]N:6L@<W1E:'0@;FEC:'0@
M>G5R(%9E<F;\9W5N9RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S
M='(@(D1I92!(;W)D92]+;VQA8B!);G1E9W)A=&EO;G-F=6YK=&EO;F5N('5N
M=&5R<W3\='IE;B!<(B5S7"(@;FEC:'0B"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(")$:64@24U34"U,;V=D
M871E:2!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N+B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E
M.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")$
M:64@36%I;G1E;F%N8V4Z.B!+;&%S<V4@:V]N;G1E(&YI8VAT(&=E;&%D96X@
M=V5R9&5N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR
M.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N(@IM<V=S='(@(D1A<R!%:6YS=&5L;'5N9V5N+49E;G-T97(@:7-T(&=E
M<V-H;&]S<V5N('=O<F1E;BX@06)B<G5C:"XB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B
M"B)$97(@061M:6YI<W1R871O<B!M=7-S(&5I;B!P97)M86YE;G1E<R!296-H
M=&4M0F%C:V5N9"!E:6YR:6-H=&5N+"!W96YN(%-I92`B"B)D:64@4F5C:'1E
M=F5R=V%L='5N9R!N=71Z96X@;?9C:'1E;BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@
M8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(").=7(@=6YT96XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I
M9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B
M87-E+B(*;7-G<W1R("(B"B)$:64@240M3G5M;65R(&1E<R!+;VYT86MT<R!W
M=7)D92!N:6-H="!A;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92!I;B!D
M97(@(@HB1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N('=E<F1E;BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@
M(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(D1E<B!+;VYT86MT('=U<F1E(&5R9F]L
M9W)E:6-H($EH<F5M($%D<F5S<V)U8V@@:&EN>G5G96;\9W0N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB1&5R(%!'
M4"U3:6=N871U<F)L;V-K('=I<F0@8F5N]G1I9W0L('5M(&1I92!U;G1E<GIE
M:6-H;F5T92!.86-H<FEC:'0@>G4@(@HB_&)E<G!R_&9E;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I
M9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE
M(&1A=&%B87-E+B(*;7-G<W1R("(B"B)$:64@240M3G5M;65R(&1E<B!697)T
M96EL97)L:7-T92!W=7)D92!N:6-H="!A;F=E8F5N+"!W87(@;&5E<B!O9&5R
M(&MO;FYT92`B"B)I;B!D97(@1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N('=E
M<F1E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+B(*;7-G<W1R(")$:64@5F5R=&5I;&5R;&ES=&4@=W5R
M9&4@;FEC:'0@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B)$:64@
M5F5R<V-H;/QS<V5L=6YG<V9U;FMT:6]N96X@8F5N]G1I9V5N(&5I;F4@<VEC
M:&5R92!397)V97)V97)B:6YD=6YG+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3@V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B1&EE($1A=&5I("5S('-O;&QT92!E
M:6YE;B`E<R!%:6YT<F%G(&5N=&AA;'1E;BXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")$:64@1&%T96D@)7,@
M<V]L;'1E(&5I;FEG92`E<R!%:6YT<N1G92!E;G1H86QT96XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C
M86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")$:64@1&%T
M96D@:V%N;B!N:6-H="!A=68@<VEC:"!S96QB<W0@:V]P:65R="!W97)D96XN
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B1&EE($1A=&5I(&5N
M=&AI96QT(&ME:6YE($1A=&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M(@IM<V=S='(@(DAI97(@<VEN9"!D:64@2V]P9F5I;G1RY&=E(&;\<B!D:65S
M92!M97-S86=E+W)F8S@R,B!.86-H<FEC:'0N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U
M;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET
M:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)$
M97(@5F]L;&)I;&1M;V1U<R!V97)U<G-A8VAT(&%U9B!'<G5N9"!V;VX@1F5H
M;&5R;B!I;2!);G1E<FYE="!%>'!L;W)E<B`B"B)B96MA;FYT97)M8=]E;B!0
M<F]B;&5M92!M:70@9&EE<V5M($)R;W=S97(L(&1I92!W:7(@;FEC:'0@=6UG
M96AE;B!K]FYN96XN("(*(E5N=&5R(%5M<W3D;F1E;B!E<FAA;'1E;B!3:64@
M96EN92!F96AL97)H869T92!!;GIE:6=E+"!F96AL96X@(@HB161I=&]R9G5N
M:W1I;VYE;BP@;V1E<B!D97(@0G)O=W-E<B!S=/QR>G0@86(N($%U9B!E:6YE
M;2!7:6YD;W<@.7@@4WES=&5M("(*(G=E<F1E;B!3:64@=F5R;75T;&EC:"!E
M:6YE("=!;&QG96UE:6YE(%-C:'5T>G9E<FQE='IU;F<G(&5R:&%L=&5N('5N
M9"!M_'-S96X@(@HB9&5N(%)E8VAN97(@;F5U('-T87)T96XN7%QN7%QN4VEE
M('=U<F1E;B!G97=A<FYT+B!":71T92!D<OQC:V5N(%-I92!A=68@3TLL("(*
M(G=E;FX@4VEE(&YO8V@@:6UM97(@9&5N(%9O;&QB:6QD;6]D=7,@=F5R=V5N
M9&5N(&WV8VAT96XN(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(D1I92!)9&5N=&ETY'0@7"(E<UPB('=U<F1E
M(&=E;/9S8VAT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O
M;FQY(@IM<V=S='(@(DYU<B!L:6YK<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H
M92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P
M.CH@8VQA<W,N(@IM<V=S='(@(B(*(D1E<B!/<G0@9&5S($=N=5!'+5!R;V=R
M86UM<R!M=7-S(&1E<B!#<GEP=%]P9W`Z.B!+;&%S<V4@_&)E<F=E8F5N('=E
M<F1E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N
M7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB1&EE($YA
M8VAR:6-H="!M:70@9&5M($)E=')E9F8@7"(E,R1S7"(L(&1I92!A;2`E,21S
M(&%N("4R)',@9V5S8VAI8VMT('=U<F1E+"`B"B)I<W0@86YG97IE:6=T('=O
M<F1E;BY<;B(*(D1A<R!H96G?="!N:6-H="P@9&%S<R!D:64@3F%C:')I8VAT
M(&%U8V@@9V5L97-E;B!O9&5R('9E<G-T86YD96X@=W5R9&4N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-`IM<V=I9"`B5&AE(&YA;64@=&\@
M=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@
M(DYA;64@9OQR(&1E;B!,:6YK('IU<B!.86-H<FEC:'1E;F5R<W1E;&QU;F<B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@(E1H
M92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B
M1&EE($%N>F%H;"!D97(@1F5L9&5R(&UU<W,@86QS(%IA:&P@86YG96=E8F5N
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F
M;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(D1A
M<R!/<&5N4U-,+4UO9'5L('=I<F0@9OQR(&1I92!(;W)D95]#<GEP=%]S;6EM
M93HZ($ML87-S92!B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R
M96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A
M=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS
M9W-T<B`B(@HB1&EE($)E;G5T>F5R96EN<W1E;&QU;F<@7"(E<UPB(&MO;FYT
M92!N:6-H="!G97-P96EC:&5R="!W97)D96XL('=E:6P@:6AR92`B"B)$871E
M;B!D:64@;6%X:6UA;"!E<FQA=6)T92!'<O;?92#\8F5R<V-H<F5I=&5N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V
M:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@
M<WES=&5M+B(*;7-G<W1R("(B"B)$87,@4')O9W)A;6T@9OQR(&1I92!!;GIE
M:6=E(&1I97-E<R!$871E:71Y<',@*"5S*2!W=7)D92!N:6-H="!G969U;F1E
M;BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#<*;7-G:60@
M(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BXB"FUS9W-T<B`B1&%S($%N9OQH<G5N9W-Z96EC:&5N(&UU<W,@86QS
M(&5I;GIE;&YE<R!:96EC:&5N(&%N9V5G96)E;B!W97)D96XN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM
M<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B
M3G5R(&QI;FMS('5N9"!R96-H=',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M
M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B3G5R(')E8VAT<R(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")$87,@
M5')E;FYZ96EC:&5N(&UU<W,@86QS(&5I;GIE;&YE<R!:96EC:&5N(&%N9V5G
M96)E;B!W97)D96XN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B1&5R(%-E<G9E<B!<(B5S7"(@=W5R
M9&4@96YT9F5R;G0N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(D1E<B!397)V97(@7"(E<UPB('=U<F1E
M(&=E<W!E:6-H97)T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B
M965N(')E;6]V960N(@IM<V=S='(@(D1I92!296=I<W1R:65R=6YG<V%N9G)A
M9V4@=F]N("5S('=U<F1E(&5N=&9E<FYT+B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(D1I92!A;F=E9V5B96YE(%IE:6QE("@E9"D@97AI<W1I97)T
M(&YI8VAT+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1I92!T96UP;W+D<F4@1&%T96D@
M7"(E<UPB(&5X:7-T:65R="!N:6-H="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,CDY"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*
M(D1E<B!497AT+"!D96X@4VEE(&%N9V5G96)E;B!H86)E;BP@96YT<W!R:6-H
M="!N:6-H="!D96T@5&5X="!A=68@9&5M("(*(D)I;&1S8VAI<FTN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T
M<B`B3G5R(&]B96X@=6YD('5N=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S
M:61E(&]N;'DB"FUS9W-T<B`B3G5R(&]B96XB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"B)$:64@
M:&]C:&=E;&%D96YE;B!$871E;B!S:6YD(&YA8V@@9&5M(&QE='IT96X@4V-H
M<FET="!V97)L;W)E;B!G96=A;F=E;BXB"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ
M-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E
M9"XB"FUS9W-T<B`B1&EE(&AO8VAG96QA9&5N92!$871E:2!K;VYN=&4@;FEC
M:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B1&5R('=E871H97(N8V]M($)L;V-K(&ES="!N:6-H="!V
M97)F_&=B87(N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B5&AE;65N+59E<GIE:6-H;FES(%PB)7-<(B!N:6-H
M="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*
M;7-G<W1R(")%<R!S:6YD(&ME:6YE($5I;G-T96QL=6YG96X@=F5R9OQG8F%R
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T.`IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(D5S(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@
M3F%C:')I8VAT96YT96EL92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,SDX"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N
M("5S+B(*;7-G<W1R("(B"B)$:65S97,@1F5L9"!E;G1HY&QT('IU('9I96QE
M(%IE:6-H96XN(%-I92!H86)E;B`E<R!:96EC:&5N(&%N9V5G96)E;CL@4VEE
M("(*(FW\<W-E;B!W96YI9V5R(&%L<R`E<R!A;F=E8F5N+B(*"B,Z('-I9VYU
M<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S
M>7-T96TZ("5S(@IM<V=S='(@(D)E:6T@2&EN>G5F_&=E;B!V;VX@7"(E<UPB
M('IU;2!3>7-T96T@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B`E<R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(D)E:6T@3/9S8VAE
M;B!D97(@1&%T96X@=F]N($)E;G5T>F5R(%PB)7-<(B!I<W0@96EN(%!R;V)L
M96T@875F9V5T<F5T96XZ("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")"96EM($SV<V-H
M96X@=F]N(%PB)7-<(B!A=7,@9&5M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@
M875F9V5T<F5T96XZ("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B0F5I;2!!:W1U86QI<VEE<F5N('9O;B!<(B5S
M7"(@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B`E<R(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*(D)E:6T@2&]C:&QA
M9&5N(&1E<B!$871E:2!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@)7,@
M=W5R9&4@;FEC:'0@(@HB:&]C:&=E;&%D96XN(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(D)E:6T@2&]C:&QA9&5N(&1E
M<B!$871E:2!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@)7,@=V%R(&=R
M]M]E<B!A;',@9&EE("(*(FUA>&EM86P@97)L875B=&4@1W+VWV4@*"5D($)Y
M=&5S*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB0F5I;2!(;V-H;&%D96X@9&5R($1A
M=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W=7)D92!N=7(@
M=&5I;'=E:7-E("(*(FAO8VAG96QA9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@
M(D)E:6T@06YZ96EG96X@9&EE<V5S($YA8VAR:6-H=&5N=&5I;',@:7-T(&5I
M;B!&96AL97(@875F9V5T<F5T96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")"96EM($EM
M<&]R=&EE<F5N(&1E<B!+;VYT86MT9&%T96X@:7-T(&5I;B!&96AL97(@875F
M9V5T<F5T96XN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82XB"FUS9W-T<B`B0F5I;2!);7!O<G1I97)E;B!D97(@:4-A
M;&5N9&%R($1A=&5N(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B
M"B)$87,@2V]N9FEG=7)A=&EO;G,M1F]R;75L87(@96YT:&EE;'0@96EN96X@
M1F5H;&5R+B!6:65L;&5I8VAT(&AA8F5N(%-I92!E:6X@(@HB4&9L:6-H=&9E
M;&0@;&5E<B!G96QA<W-E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*(D)E:6T@075S9OQH<F5N(&1E<B!A;F=E9V5B96YE;B!!9')E<W-B=6-H
M9G5N:W1I;VX@:7-T(&5I;B!&96AL97(@(@HB875F9V5T<F5T96XN($)I='1E
M('9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A
M8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M(@HB0F5I(&1E<B!!:W1U86QI<VEE<G5N9R!D97(@2V]N=&%K=&1E=&%I;',@
M:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($)I='1E("(*(G9E<G-U8VAE
M;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)"96D@9&5R
M($%K='5A;&ES:65R=6YG(&1E<B!697)T96EL97)L:7-T92!I<W0@96EN($9E
M:&QE<B!A=69G971R971E;BX@0FET=&4@(@HB=F5R<W5C:&5N(%-I92!E<R!S
M<.1T97(@;F]C:"!E:6YM86PN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$:65S
M97(@24U!4"U397)V97(@=6YT97)S=/QT>G0@:V5I;F4@9V5M96EN<V%M96X@
M3W)D;F5R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(D1I97,@<V-H96EN="!K96EN(&?\
M;'1I9V5S(%)!4BU!<F-H:78@>G4@<V5I;BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")$:65S
M('-C:&5I;G0@:V5I;B!G_&QT:6=E<R!:25`M07)C:&EV('IU('-E:6XN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-`IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(D1I97,@<V-H96EN="!K96EN92!G_&QT:6=E($MA<G1E;FYU;6UE<B!Z
M=2!S96EN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T
M<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@HB1&EE<V5R(%1R96EB97(@97)L875B="!D87,@
M5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!#;&EC:V%T
M96QL+2(*(D=A=&5W87D@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@;6ET($AI
M;&9E(&1E<B!(5%10+4%022XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*(D1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC
M:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D96X@5TE.+4=A=&5W87D@(@HB
M*&AT='`Z+R]W:6YP;&,N8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@HB1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@
M=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!S;7,R;6%I;"TB"B)'871E=V%Y
M("AH='1P.B\O<VUS,FUA:6PN8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET
M(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)$:65S97(@
M5')E:6)E<B!E<FQA=6)T(&1A<R!697)S8VAI8VME;B!V;VX@3F%C:')I8VAT
M96X@<&5R(%--5%`@9'5R8V@@9&5N("(*(E9O9&%F;VYE+4ET86QI96XM1V%T
M97=A>2!A=7-S8VAL:67?;&EC:"!A;B!6;V1A9F]N92U.=6UM97)N+B!$86;\
M<B!W:7)D(&5I;B`B"B)%;6%I;&MO;G1O(&)E:2!6;V1A9F]N92!)=&%L:65N
M("AH='1P.B\O=W=W+C$Y,"YI="D@8F5N]G1I9W0N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3<U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X,R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3$R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q-SD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S.34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#,V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P,@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-S4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C$X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C,T(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDT"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q,`IM
M<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B1&EE<V5S
M($9E;&0@:7-T(&YO='=E;F1I9RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#8R"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M:6YT96=E<G,N(@IM<V=S='(@(D1I97-E<R!&96QD(&1A<F8@;G5R(&=A;GIE
M(%IA:&QE;B!E;G1H86QT96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q,PIM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B1&EE<V5S($9E;&0@9&%R
M9B!N=7(@6F%H;&5N('5N9"!E:6YE;B!0=6YK="!E;G1H86QT96XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y,0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B1&EE
M<V5S($9E;&0@9&%R9B!N=7(@3VMT86QZ86AL96X@96YT:&%L=&5N+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C`*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S(@IM<V=S='(@(B(*(D1I97-E<R!&96QD(&UU<W,@96EN92!K
M;VUM82T@;V1E<B!L965R>F5I8VAE;F=E=')E;FYT92!,:7-T92!V;VX@9V%N
M>F5N("(*(EIA:&QE;B!E;G1H86QT96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY.#8*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BXB"FUS9W-T<B`B1&EE<V5S($9E;&0@;75S<R!E:6YE(&?\;'1I
M9V4@6F%H;"!E;G1H86QT96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q-0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C
M;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@
M(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B)$:65S97,@1F5L9"!M=7-S(&5I
M;F5N($9A<F)W97)T(&EM(&AE>&%D97II;6%L96X@4D="+49O<FUA="!E;G1H
M86QT96XL('HN($(N("(*(B<C,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HU-3@*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"XB"FUS9W-T<B`B1&EE<V5S($9O<FUU;&%R('=U<F1E
M(&)E<F5I=',@=F5R87)B96ET970N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O
M=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS
M9W-T<B`B1&EE<R!I<W0@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@
M(B(*(D1I92!I<W0@96EN($MO;&%B+4=R;W5P=V%R92U/8FIE:W0N(%5M(&1I
M97-E<R!/8FIE:W0@86YZ=7IE:6=E;BP@8F5N]G1I9V5N("(*(E-I92!E:6X@
M16UA:6QP<F]G<F%M;2P@9&%S(&1A<R!+;VQA8BU'<F]U<'=A<F4M1F]R;6%T
M('5N=&5R<W3\='IT+B!%:6YE("(*(DQI<W1E('-O;&-H97(@4')O9W)A;6UE
M(&9I;F1E;B!3:64@=6YT97(@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(D1I97-E($YA8VAR:6-H
M="!W=7)D92!I;B!E:6YE;2!:96EC:&5N<V%T>B`H)7,I(&5R<W1E;&QT+"!D
M97(@;FEC:'0@26AR96T@(@HB96EG96YE;B!E;G1S<')I8VAT+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B1&EE<V4@6F%H
M;"!M=7-S(#$@;V1E<B!G<O;?97(@<V5I;BXB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R
M(")$:65S97(@4V5R=F5R(&MA;FX@6DE0+2!U;F0@1UI)4"U$871E:6X@;FEC
M:'0@96YT<&%C:V5N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@
M9&5A8W1I=F%T960N(@IM<V=S='(@(D1I97-E<R!3>7-T96T@:7-T('IU<B!:
M96ET(&1E86MT:79I97)T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M(@IM<V=S='(@(D1I97-E<B!797)T(&UU<W,@96EN92!:86AL('-E:6XN(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=R(*;7-G<W1R(")$:65S97,@1F5N<W1E<B!M=7-S('9O;B!E:6YE;2!%
M:6YS=&5L;'5N9V5N+49E;G-T97(@9V7V9F9N970@=V5R9&5N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E1H
M=6YD97(B"FUS9W-T<B`B1&]N;F5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")4:6-K971S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R,B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B6F5I="(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@
M5')A8VMI;F<B"FUS9W-T<B`B6F5I=&5R9F%S<W5N9R(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B6F5I
M=&9O<FUA="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,C@*;7-G
M:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(EIE:71A=7-W86AL(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M
M3&5S=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*
M;7-G<W1R(")4:71E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T
M<B`B5&ET96P@*%1O;VQT:7`I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(D%N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB2&%L=&5N(%-I92!B96EM($ML:6-K
M96X@4W1R9R!B>G<N("A00RD@0V]M;6%N9"`H36%C*2!G961R_&-K="P@=6T@
M;65H<F5R92`B"B)%:6YT<N1G92!A=7-Z=7?D:&QE;BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R
M(")(975T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("):
M=2!(5$U,+5%U96QL8V]D92!U;7-C:&%L=&5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B
M36]R9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B
M5&]N9V$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0*
M;7-G:60@(E1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S
M="!M:6YU=&5S+B(*;7-G<W1R("):=2!V:65L92!U;F?\;'1I9V4@06YM96QD
M979E<G-U8VAE(&EN(&1E;B!L971Z=&5N($UI;G5T96XN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED
M(")4;W`B"FUS9W-T<B`B3V)E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB
M"FUS9W-T<B`BQ'7?97)S=&5R(%)A:&UE;B`H7W1O<"DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R
M("+<8F5R<V5T>G5N9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED
M860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"!U;F0@5&]B86=O(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<X-PIM<V=I9"`B5')U92!O
M<B!F86QS92(*;7-G<W1R(")786AR(&]D97(@9F%L<V-H(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B
M"FUS9W-T<B`B1&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM
M<V=S='(@(E1U;F5S:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y
M(@IM<V=S='(@(E3\<FME:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU
M"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4_')K:7-C
M:"`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N
M:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM
M<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS
M+2!U;F0@0V%I8V]S:6YS96QN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V
M86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R(")):')E
M($%U<W=A:&PZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R(")55BU);F1E>#H@(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(DAO
M;65P86=E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@26AR97,@4VMR:7!T<R!F
M_'(@9&5N(%9E<G-A;F1S=&%T=7-B97)I8VAT(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G
M<W1R(")!9')E<W-E.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*
M;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(E5K<F%I;F4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B075F(&1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI
M8VAT('IU9V5G<FEF9F5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*
M(D1I92!Z=7/D='IL:6-H96X@0F5N=71Z97)I;F9O<FUA=&EO;F5N(&MO;FYT
M96X@8F5I(&1E<B!296=I<W1R:65R=6YG(&YI8VAT("(*(FAI;GIU9OQG="!W
M97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*(D1I92!:=6=R:69F
M<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2!<(B5S7"(@:V]N;G1E;B!N:6-H
M="!G9>1N9&5R="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,SDR(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@HB1&EE(%IU9W)I9F9S
M<F5C:'1E(&;\<B!D:64@5D93+41A=&5I("5S+R5S(&MO;FYT96X@;FEC:'0@
M9V7D;F1E<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N(@IM<V=S='(@(D5S(&MA;FX@;FEC:'0@:6X@5F5R>F5I8VAN:7,@
M)7,@9V5W96-H<V5L="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(D1I92!'<O;?92!V
M;VX@7"(E<UPB(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDU(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,3`R.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z.#4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(")$:64@1W+VWV4@
M=F]N(%PB)7,O)7-<(B!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(E9E<F)I
M;F1U;F<@>G5M(%-13"!397)V97(@:V%N;B!N:6-H="!H97)G97-T96QL="!W
M97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S`*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")34TPM
M5F5R8FEN9'5N9R!K;VYN=&4@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(P-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C`Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,3<*;7-G
M:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(")$:64@5D93
M+41A=&5I(&MO;FYT92!N:6-H="!K;W!I97)T('=E<F1E;BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(")$87,@5D93+59E<GIE:6-H;FES(%PB)7-<(B!K;VYN=&4@;FEC:'0@
M86YG96QE9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,V,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&%S(%9&4RU6
M97)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(D1I92!61E,M1&%T96D@
M:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")$87,@
M5D93+59E<GIE:6-H;FES(%PB)7-<(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@
M=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W,@IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T
M<B`B3&5E<F4@5D93+41A=&5I(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D
M96XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z
M-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")$
M:64@1&%T96X@:V]N;G1E;B!N:6-H="!D96MO;7!R:6UI97)T('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R."!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(EPB)7-<(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N+"!D87,@5F5R>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`B7"(E<UPB(&MA;FX@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S@@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.34*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B5S(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I
M<W0@;FEC:'0@;&5E<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,V,`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+B(*;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H
M="!R96MU<G-I=B!G96SV<V-H="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S0T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&%S(%9&4RU697)Z96EC:&YI<R!K
M;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@
M:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D1I
M92!61E,M1&%T96D@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D
M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$P(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,CDQ"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92XB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN
M:7,@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*
M;7-G<W1R(")$87,@5D93(&MO;FYT92!N:6-H="!R96MU<G-I=B!G96SV<V-H
M="!W97)D96XZ("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#,T"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T
M;W)Y+B(*;7-G<W1R(")$87,@86MT=65L;&4@5F5R>F5I8VAN:7,@:V]N;G1E
M(&YI8VAT(&)E<W1I;6UT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(")$:64@6F5R=&EF:6MA=&1E
M=&%I;',@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N('=E<F1E;B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")$
M97(@)7,M5')E:6)E<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3<T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")$
M:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!V97)S8VAO8F5N('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,3`V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-C4R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")$:64@5D93+41A=&5I(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V7V
M9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(X-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")$:64@
M5D93+41A=&5I(&MO;FYT92!N:6-H="!Z=6T@0F5S8VAR96EB96X@9V7V9F9N
M970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@S
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+B(*;7-G<W1R(")$:64@5D93+41A=&5I(&MO;FYT92!N:6-H
M="!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+B(*;7-G<W1R(")$87,@07)C:&EV(&MO;FYT92!N:6-H
M="!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@U-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V5L97-E;B!W97)D96X@*&9I;&5S:7IE*"D@9F5H;&=E<V-H;&%G96XI
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM
M<V=S='(@(B(*(D1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@
M=V5R9&5N("AG971&:6QE4VEZ92@I(&9E:&QG97-C:&QA9V5N*2XB"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP
M:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")$
M:64@1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N.B`B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&%S('9F
M<W)O;W0M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T
M:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@HB)7,@
M:V]N;G1E(&YI8VAT(&YA8V@@)7,@=6UB96YA;FYT('=E<F1E;CH@1&%S(%II
M96QV97)Z96EC:&YI<R!E>&ES=&EE<G0@(@HB8F5R96ET<R(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&%S(%9&4RU697)Z
M96EC:&YI<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G
M<W1R(")$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!U;6)E;F%N
M;G0@=V5R9&5N.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(W,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B1&EE(%9&4RU$871E:2!<(B5S7"(@:V]N;G1E(&YI8VAT('5M
M8F5N86YN="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C$W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B1&EE(%9&4RU$871E:2`E<R\E<R!K;VYN=&4@;FEC:'0@
M=6UB96YA;FYT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(Y,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(*;7-G<W1R(")$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!U;6)E;F%N
M;G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI
M<V]F<R<N(@IM<V=S='(@(EPB;6MI<V]F<UPB(&MO;FYT92!N:6-H="!A=7-G
M96;\:')T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")$:65S97,@5V]R9"U$;VMU;65N
M="!LY'-S="!S:6-H(&YI8VAT(&%N>F5I9V5N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!<(B5S7"(@:V]N
M;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(D1I92!61E,M1&%T
M96D@:V]N;G1E(&YI8VAT(&=E<V-H<FEE8F5N('=E<F1E;B`H8V]P>2@I(&9E
M:&QG97-C:&QA9V5N*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T-@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B1&EE(%9&4RU$
M871E;B!K;VYN=&5N(&YI8VAT(&=E<V-H<FEE8F5N('=E<F1E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@
M(B(*(D1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E<V-H<FEE8F5N('=E
M<F1E;BP@9&%S(%-P96EC:&5R<&QA='HM2V]N=&EN9V5N="`B"B)W_')D92#\
M8F5R<V-H<FET=&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")5;G1E
M<G-T<FEC:&5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I
M9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(L1N9&5R=6YG96X@<OQC:V?D;F=I
M9R!M86-H96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R(")-86-H="!D:64@;&5T>G1E($%K=&EO;B!R_&-K9^1N9VEG(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B`B"FUS9W-T<B`B56YG_&QT:6=E(%+\8VMM96QD=6YG('9O;2!397)V97(@
M8F5I;2!(97)S=&5L;&5N(&1E<B!697)B:6YD=6YG.B`B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")5;F5R=V%R=&5T
M92!!;G1W;W)T(&1E<R!397)V97)S(&%U9CH@(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL
M960B"FUS9W-T<B`B3FEC:'0@>G5G96]R9&YE="(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B
M56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!
M<F%B($5M:7)A=&5S(@IM<V=S='(@(E9E<F5I;FEG=&4@07)A8FES8VAE($5M
M:7)A=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM
M<V=S='(@(E9E<F5I;FEG=&5S($OV;FEG<F5I8V@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(E9E<F5I;FEG=&4@4W1A
M871E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")+;&5I;F5R92!!;65R:6MA
M;FES8VAE(-QB97)S965I;G-E;&XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B56YI
M=',B"FUS9W-T<B`B16EN:&5I=&5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0S,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X
M"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(E5N8F5K86YN="(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I
M9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R
M(")5;F)E:V%N;G1E(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY
M"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M(@IM<V=S='(@(E5N8F5K86YN=&4@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS
M9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")%<R!W
M=7)D92!E:6X@=6YB96MA;FYT97(@3W)T(&%N9V5G96)E;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G
M:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5N
M8F5K86YN=&5R($)E;G5T>F5R;F%M92!O9&5R(%!A<W-W;W)T+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B
M3&EN:R!V;VT@86MT=65L;&5N($5L96UE;G0@96YT9F5R;F5N(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`B56YB96YA;FYT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B
M"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)!=7,@4VEC:&5R:&5I='-G<OQN
M9&5N(&3\<F9E;B!U;F%U=&]R:7-I97)T92!3:W)I<'1E(&YI8VAT(&%U<V-H
M;F5I9&5N+"`B"B)K;W!I97)E;B!U;F0@96EN9OQG96XN($ML:6-K96X@4VEE
M(&%U9B!/2RP@=6T@96EN96X@2&EN=V5I<R!A=68@;6]Z:6QL82YO<F<@(@HB
M86YG97IE:6=T('IU(&)E:V]M;65N+"!D97(@8F5S8VAR96EB="P@=VEE(%-I
M92!E:6YE;2!3:W)I<'0@9&5N(%IU9W)I9F8@875F("(*(F1I92!:=VES8VAE
M;F%B;&%G92!E<FQA=6)E;B!K]FYN96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@
M8V]L;W(B"FUS9W-T<B`B1F%R8F4@>G5R_&-K<V5T>F5N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*
M;7-G<W1R(")%<G=E:71E<G5N9R!N:6-H="!U;G1E<G-T_'1Z="(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B06MT
M=6%L:7-I97)U;F<B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M("(E<R!A:W1U86QI<VEE<F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B0F5N
M=71Z97(@86MT=6%L:7-I97)E;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB
M+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@86MT=6%L:7-I97)T+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP
M="!D96QE=&5D+B(*;7-G<W1R(")!:W1U86QI<VEE<G5N9W-S:W)I<'0@9V5L
M]G-C:'0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO
M860B"FUS9W-T<B`B2&]C:&QA9&5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P
M(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*(D1I92!+;VYF:6=U
M<F%T:6]N<V1A=&5I96X@86QL97(@06YW96YD=6YG96X@=W5R9&5N(&%U9B!D
M96X@4V5R=F5R("(*(FAO8VAG96QA9&5N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P
M<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B1W(N(&QA=&5I;FES8VAE($)U
M8VAS=&%B96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(D=R+B!R]FUI<V-H92!:86AL96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B06MT=65L
M;&4@8F5N=71Z96XZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
M4U-,(&)E;G5T>F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM
M<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BXB"FUS9W-T<B`B(@HB0FET=&4@875S9OQL;&5N+"!W96YN
M(%-I92!E:6YE;B!A;F1E<F5N($)E;G5T>F5R;F%M96XO4&%S<W=O<G0@9OQR
M(&1E;B!)35-0+2(*(E-E<G9E<B!H86)E;BXB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(D)E
M;G5T>F5R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(D)E;G5T>F5R("5S(&ES="!F_'(@
M)7,@;FEC:'0@875T;W)I<VEE<G0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D)E;G5T>F5R
M=F5R=V%L='5N9R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B0F5N=71Z97)E:6YS
M=&5L;'5N9V5N(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VXB"FUS9W-T<B`B0F5N=71Z97)R96=I<W1R:65R=6YG(@H*(SH@
M<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B1&EE($)E;G5T
M>F5R<F5G:7-T<FEE<G5N9R!W=7)D92!A=68@9&EE<V5M(%-Y<W1E;2!D96%K
M=&EV:65R="XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED
M(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(D)E;G5T>F5R:V]N
M=&\@;FEC:'0@9V5F=6YD96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED
M(")5<V5R;F%M92(*;7-G<W1R(")"96YU='IE<FYA;64B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M1&5R($)E;G5T>F5R;F%M92!<(B5S7"(@97AI<W1I97)T(&)E<F5I=',N(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R
M;F%M93HB"FUS9W-T<B`B0F5N=71Z97)N86UE.B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B
M0F5N=71Z97)N86UE.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")"
M96YU='IE<B!D97,@4WES=&5M<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5
M>F)E:VES=&%N(@IM<V=S='(@(E5S8F5K:7-T86XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C8R"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES(&5X:7-T:65R="!N:6-H="XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A
M=&EO;B(*;7-G<W1R(")!8G=E<V5N:&5I="(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@V,PIM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z("(*;7-G<W1R(")087-S96YD92!G969U;F1E;F4@3W)T93H@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@
M(E9A;&ED:71Y(@IM<V=S='(@(D?\;'1I9VME:70B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@
M(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(E=E<G0@:6X@
M36EN=71E;B!V;VX@:F5T>G0@86XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#4S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N(@IM<V=S='(@(D1E<B!797)T(&ES="#\8F5R(&1E<B!M87AI
M;6%L96X@3.1N9V4@=F]N("5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$S(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E=E<G1E(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3@S"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T
M<B`B5V5R=&4L(&%U<R!D96YE;B!A=7-G97?D:&QT('=E<F1E;B!K86YN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B
M5F%R:6%B;&4B"FUS9W-T<B`B1')E:&5N9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(B(*(MQB97)P<OQF=6YG(&9E:&QG97-C:&QA
M9V5N("T@9&EE<V4@3F%C:')I8VAT(&OV;FYT92!M86YI<'5L:65R="!W;W)D
M96X@<V5I;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:6]N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(E9E<G-I;VYS:V]N=')O;&QE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B
M5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B075S<FEC:'1U;F<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")6
M97)T:6-A;"!P861D:6YG(@IM<V=S='(@(E9E<G1I:V%L97(@26YN96YA8G-T
M86YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I:V%L.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED
M(")697)Y($AI9V@B"FUS9W-T<B`B4V5H<B!(;V-H(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#24DI
M(@IM<V=S='(@(E9I971N86UE<VES8V@@*%9)4T-)22DB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(E<R!A;GIE:6=E;B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B
M('!A9V4B"FUS9W-T<B`B16EN92!E>'1E<FYE(%=E8G-E:71E(&%N>F5I9V5N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B06YZ96EG
M96X@86QS("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L($)R:71I<V@B"FUS9W-T<B`B0G)I=&ES8VAE($IU;F=F97)N:6YS96QN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B06UE<FEK86YI<V-H92!*=6YG9F5R;FEN<V5L;B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S
M='(@(E-I8VAT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E-I8VAT.B`B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D
M869O;F4@271A;&EE;B!P97(@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G
M:60@(E=!4DXB"FUS9W-T<B`B5T%23E5.1R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")705).
M54Y'(2$A($S64T-(14X@4TE%($1!4R!32U))4%0@34%.545,3"!!55,@)7,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*
M;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@_&)E<B!(5%10(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T
M<B`B5V%L;&ES('5N9"!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B5V%R
M;G5N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(DUI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(E=E='1E<G9O<FAE<G-A9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@
M8GDB"FUS9W-T<B`B5V5T=&5R9&%T96X@=F]N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#@Y"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")7
M96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED
M(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5V5B<VET92(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(E=E96ML>2(*;7-G<W1R(")7]F-H96YT;&EC:"(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@
M(E=I;&QK;VUM96XB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")7:6QL:V]M;65N(&)E:2`E
M<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE+"`E<R(*;7-G<W1R(")7:6QL:V]M;65N+"`E<R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*
M;7-G<W1R(")797-T975R;W#D:7-C:"`H25-/+3@X-3DM,2DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,34I(@IM<V=S='(@(E=E<W1E=7)O<.1I<V-H("A)4T\M.#@U.2TQ-2DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B5V5S
M='-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B5V5L8VAE($%N=V5N9'5N9R!S
M;VQL("5S(&YA8V@@9&5M($%N;65L9&5N(&%N9V5Z96EG96X_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(E=E;&-H97,@5')E;FYZ
M96EC:&5N('=I<F0@=F5R=V5N9&5T/R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T
M97(_(@IM<V=S='(@(E=E;&-H92!!;F;\:')U;F=S>F5I8VAE;B!W97)D96X@
M=F5R=V5N9&5T/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS
M9W-T<B`B5VAE<F5I<RU!=7-T<F%L:6$M2V%R=&4B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")796QC
M:&4@4&AA<V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I
M9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+B(*;7-G<W1R(")796QC:&4@4&QU9VEN<R!F_'(@9&5N(%=94TE7
M64<M161I=&]R('-O;&QE;B!A:W1I=FEE<G0@=V5R9&5N/R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G
M:60@(E=I9'1H(@IM<V=S='(@(D)R96ET92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,#0*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G
M<W1R(")"<F5I=&4@:6X@0U-3+45I;FAE:71E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ(@IM<V=S='(@(D)R96ET92!D97,@)7,M365N_',@;&EN:W,@
M*'=I<FMS86T@;F%C:"!D97(@;N1C:'-T96X@06YM96QD=6YG*3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I
M9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(E1A8F5L;&5N8G)E:71E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B16EN:&5I="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED
M(")7:61T:#HB"FUS9W-T<B`B0G)E:71E.B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0B"FUS9W-T
M<B`B5VEN9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8X"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(D9R_&@@5VEN9"(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B5VEN9&=E<V-H=VEN9&EG=&ME:70@:6X@2VYO
M=&5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(E=I;F0Z
M(@IM<V=S='(@(E=I;F0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E=I;F0Z("(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@
M(E=E:7-H96ET(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM
M<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B5W5N<V-H>F5T=&5L(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(D%R
M8F5I="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@9V5S
M8VCD9G1L:6-H(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N
M(&=E<V-HY&9T;&EC:"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C$Y,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D9A;'-C:&4@06YZ
M86AL(&%N($9E;&1E<FX@:6X@6F5I;&4@)60N("5D(&5R=V%R=&5T+"`E9"!G
M969U;F1E;BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@
M17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(")&86QS8VAE($%N>F%H
M;"!A;B!&96QD97)N+B`E9"!E<G=A<G1E="P@)60@9V5F=6YD96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I
M;&4N(@IM<V=S='(@(E5N9_QL=&EG97(@3V9F<V5T("5D(&)E:6T@3&5S96X@
M9&5R(%9&4RU$871E:2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R(")1=65R=F5R=V5I<V4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!'96YE<F5L
M;&4@16EN<V-H<N1N:W5N9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E
M(@IM<V=S='(@(E@U,#EV,R!%<G=E:71E<G1E<B!38VAL_'-S96QZ=V5C:R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED
M(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U
M,#EV,R!!;'1E<FYA=&EV97(@3F%M92!D97,@6F5R=&EF:6MA=&EN:&%B97)S
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U
M,#EV,R!)9&5N=&ETY'0@9&5S(%IE<G1I9FEK871S8VAL_'-S96QS(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U
M,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!%<G=E:71E<G5N9V5N
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@
M(DI*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4V"FUS9VED(")965E9(@IM<V=S='(@(DI*2DHB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A
M(&UA<"(*;7-G<W1R(")986AO;R$@2V%R=&4B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS
M9W-T<B`B2N1H<FQI8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*
M;7-G<W1R(")*96UE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")*82(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED
M(")997,L($D@06=R964B"FUS9W-T<B`B2F$L(&EC:"!S=&EM;64@>G4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS
M9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB4VEE
M(&)E9FEN9&5N('-I8V@@:6T@5&5X=&UO9'5S+B!"96YU='IE;B!3:64@9&5N
M(%L\/ET@2VYO<&8L('5M(&EN(&1E;B`B"B)765-)5TE'+4UO9'5S('IU('=E
M8VAS96QN+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S
M='(@(E-I92!D_')F96X@;FEC:'0@;65H<B!A;',@)60@0FSV8VME(&5R<W1E
M;&QE;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C0*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(E-I92!S
M:6YD(&YI8VAT(&%N9V5M96QD970N(@H*(SH@9G)A;65W;W)K+TED96YT:71Y
M+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E-I
M92!D_')F96X@9&%S(%IE:6-H96X@)UQ<)R!N:6-H="!I;B!):')E;2!.86UE
M;B!V97)W96YD96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<R"FUS9VED(")9;W4@9&ED
M(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(E-I
M92!H86)E;B!K96EN92!G_&QT:6=E($5M86EL861R97-S92!A;F=E9V5B96XN
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*(E-I92!H86)E;B!K96EN92!&96QD97(@
M875S(&1E;B!I;7!O<G1I97)T96X@1&%T96X@9&5N(&5N='-P<F5C:&5N9&5N
M($9E;&1E<FX@(@HB:6X@)7,@>G5G96]R9&YE="XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D
M(&]U="XB"FUS9W-T<B`B4VEE('=U<F1E;B!A8F=E;65L9&5T+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-3@*;7-G:60@(B(*(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N
M;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)3:64@;?QS<V5N(&5I
M;F4@9_QL=&EG92!-;V)I;'1E;&5F;VYN=6UM97(@86YG96)E;BP@;G5R(&%U
M<R!:86AL96X@=6YD(&=G9BX@(@HB96EN96T@7"(K7"(@9OQR(&EN=&5R;F%T
M:6]N86QE(%9O<G=A:&QE;B!B97-T96AE;F0N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X-0IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E:6YE;B!G_&QT:6=E
M;B!797)T(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(E-I92!M
M_'-S96X@96EN($1A=&%4<F5E+4)A8VME;F0@:V]N9FEG=7)I97)E;BP@=6T@
M4F5G:7-T<FEE<G5N9V5N('9E<G=E;F1E;B`B"B)Z=2!K]FYN96XN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S$*;7-G:60@(EEO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")3:64@;?QS<V5N
M(&5I;B!61E,M0F%C:V5N9"!K;VYF:6=U<FEE<F5N+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C
M<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B
M;&5M(')E<&]R="XB"FUS9W-T<B`B4VEE(&W\<W-E;B!D87,@4')O8FQE;2!B
M97-C:')E:6)E;BP@=6T@9&5N($)E<FEC:'0@86)Z=7-C:&EC:V5N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G
M:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;R(*;7-G<W1R(")3:64@;?QS<V5N(&1I92!54DP@86YG96)E;BP@
M875F(&1I92!D:65S97(@3&EN:R!V97)W96ES96X@<V]L;"(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E-I92!M_'-S
M96X@97)S="!D96X@>G4@96YT9F5R;F5N9&5N(%-E<G9E<B!A=7-WY&AL96XN
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B"B)3:64@
M;?QS<V5N(&5I;F5N($)E;G5T>F5R;F%M96X@86YG96)E;BP@9&5S<V5N($1A
M=&5N(&=E;/9S8VAT('=E<F1E;B!S;VQL96XN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;F5N('IU(&SV<V-H96YD
M96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R
M(")3:64@;?QS<V5N(&5I;F5N(&AI;GIU>G5F_&=E;F1E;B!"96YU='IE<FYA
M;65N(&%N9V5B96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S
M='(@(E-I92!M_'-S96X@9&5N('IU(&%K='5A;&ES:65R96YD96X@0F5N=71Z
M97)N86UE;B!A;F=E8F5N+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;F4@
M06MT:6]N(&%N9V5B96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N
M97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E:6YE;B!N
M975E;B!+871E9V]R:65N86UE;B!A;F=E8F5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM
M<V=S='(@(E-I92!M_'-S96X@96EN92!)=&%L:65N:7-C:&4@5&5L969O;FYU
M;6UE<B!A;F=E8F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")):')E("5S+5-E
M<W-I;VX@:7-T(&%B9V5L875F96XN($)I='1E(&UE;&1E;B!3:64@<VEC:"!E
M<FYE=70@86XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")):')E($5M
M86EL+4%D<F5S<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS
M9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(DEH<F4@5F]N.B!!
M9')E<W-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")):')E($%N9V%B96XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)):')E
M($EN=&5R;F5T861R97-S92!H870@<VEC:"!G9>1N9&5R="P@<V5I="!3:64@
M9&EE("5S+5-I='IU;F<@8F5G;VYN96X@(@HB:&%B96XN(%IU;2!38VAU='H@
M26AR97(@4VEC:&5R:&5I="!M_'-S96X@4VEE('-I8V@@;F5U(&%N;65L9&5N
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED
M(")9;W5R($YA;64B"FUS9W-T<B`B26AR($YA;64B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U
M<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T
M:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB26AR($%U=&AE;G1I
M9FEZ:65R=6YG<W-Y<W1E;2!E<FQA=6)T(&ME:6X@2&EN>G5F_&=E;B!V;VX@
M;F5U96X@0F5N=71Z97)N+B`B"B)796YN(%-I92!(;W)D92!B96YU='IE;B!M
M]F-H=&5N+"!U;2!):')E($)E;G5T>F5R('IU('9E<G=A;'1E;BP@;?QS<V5N
M(%-I92`B"B)E:6YE;B!A;F1E<F5N($%U=&AE;G1I9FEZ:65R=6YG<W1R96EB
M97(@8F5N=71Z96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(B(*(DEH<B!!=71H96YT:69I>FEE<G5N9W-S>7-T96T@97)L
M875B="!D87,@06YZ96EG96X@9&5R($)E;G5T>F5R(&YI8VAT+"!O9&5R("(*
M(F1I97-E($WV9VQI8VAK96ET('=U<F1E(&%U<V=E<V-H86QT970N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@HB26AR($)R;W=S97(@:&%T('-I8V@@86YS8VAE:6YE;F0@
M9V7D;F1E<G0@<V5I="!3:64@9&EE("5S+5-I='IU;F<@8F5G;VYN96X@(@HB
M:&%B96XN(%IU;2!38VAU='H@26AR97(@4VEC:&5R:&5I="!M_'-S96X@4VEE
M('-I8V@@;F5U(&%N;65L9&5N+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C4W"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N(@IM<V=S='(@(DEH<B!"<F]W<V5R('5N=&5R<W3\='IT(&1I
M97-E($9U;FMT:6]N(&YI8VAT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB26AR($)R;W=S97(@
M=6YT97)S=/QT>G0@9&EE<V4@1')U8VMF=6YK=&EO;B!N:6-H="X@0FET=&4@
M9'+\8VME;B!3:64@4W1R9R\B"B)+;VUM86YD;R`K(%`@=6T@>G4@9')U8VME
M;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")):')E(&%K='5E;&QE(%IE
M:71Z;VYE.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M(")):')E(%-T86YD87)D:61E;G1I=.1T('=U<F1E(&=EY&YD97)T+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>3HB"FUS9W-T<B`B26AR92!3=&%N9&%R9&ED96YT:73D=#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U
M;&P@;F%M93HB"FUS9W-T<B`B26AR('9O;&QS=.1N9&EG97(@3F%M93HB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G
M:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(DEH<B!:=6=A;F<@:7-T(&%B9V5L
M875F96XN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<R(*;7-G<W1R(")):'(@;F5U97,@4&%S<W=O<G0@9OQR("5S(&QA=71E
M=#H@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")):')E($5I;G-T
M96QL=6YG96X@=W5R9&5N(&;\<B!D:64@1&%U97(@9&EE<V5R(%-I='IU;F<@
M9V5S<&5I8VAE<G0N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB
M"FUS9W-T<B`B26AR92!%:6YS=&5L;'5N9V5N('=U<F1E;B!G97-P96EC:&5R
M="XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")):'(@4&%S
M<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z="(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB26AR(%!A<W-W;W)T
M('=U<F1E('IU<OQC:V=E<V5T>G0N(%)U9F5N(%-I92!):')E($5M86EL<R!A
M8B!U;F0@;65L9&5N(%-I92`B"B)S:6-H(&UI="!):')E;2!N975E;B!087-S
M=V]R="!A;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(DEH<B!0
M87-S=V]R="!I<W0@86)G96QA=69E;BXB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM
M<V=S='(@(DEH<F4@4V5R=F5R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L87=I96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G
M<W1R("):86ER92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G
M<W1R(")386UB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*
M;7-G<W1R(")3:6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED
M(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6UII=&%T=&5X="!V97)S
M=&5C:V5N72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");
M4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM0<F]B;&5M8F5R:6-H=%TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");6FET871T97AT(&%N
M>F5I9V5N("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM::71A='1E
M>'0@86YZ96EG96X@+2`E<R!:96EL96Y=(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@
M;V8@)7-=(@IM<V=S='(@(EM:96EL92`E<R!V;VX@)7-=(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-34T('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M
M:6YI<W1R871I;VXB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB
M"FUS9W-T<B`B0F5?9F5H;'-Z96EL92(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM
M<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM
M<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B6F5I;&4@7VSV<V-H96XB"@HC
M.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R
M=7!P96XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U
M"FUS9VED(")?2&5L<"(*;7-G<W1R(")?2&EL9F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@
M(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]":6QD96EG96YS8VAA
M9G1E;BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B06Y?;65L9&5N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B06)?;65L9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y
M($QI;FLN+BXB"FUS9W-T<B`B3&EN:R!?8F5A<F)E:71E;BXN+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I
M;VYS(@IM<V=S='(@(E]%:6YS=&5L;'5N9V5N(@H*(SH@;&EB+V%P:2YP:'`Z
M,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U)E8VAT92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(DQI;FL@7V5N
M=&9E<FYE;BXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P
M(@IM<V=S='(@(E]+;VYF:6=U<F%T:6]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B
M;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?5&%B96QL96YE:6=E;G-C:&%F
M=&5N+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS
M9W-T<B`B7T)E;G5T>F5R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")!9')E<W-B=6-H
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G
M:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(D%D<F5S<V%T('5N8F5K
M86YN="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$W"FUS9VED
M(")C86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF
M;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B=VEN9'-T:6QL(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO
M="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B075S9V%B961A=&5I(&MO
M;FYT92!N:6-H="!E<G-T96QL="!W97)D96XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP
M=70B"FUS9W-T<B`B16EN9V%B92!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.`IM
M<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R(")K;&EC:V5N(%-I92!H:65R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@
M(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")5;F?\;'1I9V4@
M0F5N=71Z=6YG(&1E<B!+;VUM86YD;WIE:6QE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@
M97)R;W(B"FUS9W-T<B`B2V]N9FEG=7)A=&EO;G-F96AL97(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")+<FET:7-C:&4@4WES
M=&5M9&%T96D@9F5H;'0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B
M1&%T96YF;W)M871F96AL97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N
M:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(F)E87)B96ET96XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT
M<GD@;F]T(&9O=6YD(@IM<V=S='(@(D5I;G1R86<@;FEC:'0@9V5F=6YD96XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM
M<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")F86QL96YD(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S='(@
M(D1A=&5I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G
M<W1R(")A=7,@)7,@*"5S*2!M:70@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(F+V
M:6<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C4P"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@
M(FAH(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*
M;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(DAO<W1N86UE('5N
M8F5K86YN="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(G-O
M9F]R="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B26YL:6YE(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@
M(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")%:6XM+T%U<V=A8F5F96AL
M97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM
M<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B26YT97)N
M97(@4V]F='=A<F5F96AL97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(EIE:6QE
M;ETB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O
M<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,M
M1F5H;&5R8V]D92`E9"!B96D@9&5R($5R<W1E;&QU;F<@9&5S($E33RU!8F)I
M;&1E<RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,0IM
M<V=I9"`B;F%M92(*;7-G<W1R(").86UE(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYI
M8VAT(&EM<&QE;65N=&EE<G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS
M9W-T<B`B3F]C:"!N:6-H="!I;7!L96UE;G1I97)T(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B
M3F]T:7IB;&]C:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B4')O
M>F5N="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T
M"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("):=6=R:69F('9E
M<G=E:6=E<G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B4&EX96PB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(E)E;6]T969E
M:&QE<B!I;2!0<F]T;VMO;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(G-T96EG
M96YD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*
M;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B4V5R=FEC92!N
M:6-H="!V97)F_&=B87(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P
M,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")5;G1E<G-C:&EE
M9&4@86YZ96EG96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM
M<V=S='(@(G-M<S)E;6%I;"#\8F5R($A45%`B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R
M(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B9VQE:6-H8FQE:6)E;F0B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(E-Y<W1E;69E:&QE<B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS
M9W-T<B`B075F9V%B96YL:7-T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G
M<W1R(")6;W+\8F5R9V5H96YD97(@1F5H;&5R(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I
M9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R
M(")G96)E;B!3:64@9&%S(%!A<W-W;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@
M0F5S=.1T:6=U;F<@96EN(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`B=6YI9FEE9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z
M,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B=6YB96YA;FYT(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S
M"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")B96YU='IE<F1E9FEN:65R
M="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G
M<W1R(")B.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS
M9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O
M+V5L7T=2+G!O````````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`U-C`V-S$`,3`T,3<S-C,P,#$`,#$V,S<Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@2&]R9&4@1W)E
M96L@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`R(%-T969A;F]S
M($DN($1I;6ET<FEO=2X*(R!3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-U<'!O
M<G1?=V5B;6%I;$!T96EA=&@N9W(^+"`R,#`R+@HC(%-I;&QI9V%R9&]S(%AR
M:7-T;V9O<F]S+"`R,#`R+@HC($%N86=N;W-T;W!O=6QO<R!!<&]S=&]L:7,L
M(#(P,#(N"B,@36EL;W-I<R!#+B!+;VYS=&%N=&EN;W,L(#(P,#4N"B,*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E.B`S
M+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#(M,3$M,#<@,3(Z
M,#8K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-"TR-B`Q,3HQ
M,RLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($MO;G-T86YT:6YO<R!#+B!-
M:6QO<VES(#QK;6EL;W-I<T!Y86AO;RYC;VT^7&XB"B),86YG=6%G92U496%M
M.B!'<F5E:R`\9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M:7-O+3@X-3DM-UQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB
M:71<;B(*"B,L(&,M9F]R;6%T"FUS9VED("(B"B(@)B,Q-3$[("5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RXB"FUS9W-T<B`B(@HB("8C,34Q.R`E<R#%W^WAZ2#G(//T
MZ>/LWB#MX2#CW^WO]>T@[^D@Z^7I]._U\>/?Y?(@\_7M]-[QY_/G\B#P[_4@
MY=_MX>D@(@HBY?#IZ^7C[-WMY?(@\.'QX>K<]/DN(@H*;7-G:60@(B`@5&AE
M(&UA:6QB;W@@=')A<V@@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B("#'
M(./QX>SLX?3OZ/7QW^3A("?JW.3O\B<@Y=_MX>D@WN3G(-SDY>GA+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-3$*;7-G:60@(B`H)7,@9&%Y
M<R!A9V\I(@IM<V=S='(@(B`H\/'I[2#A\/P@)7,@Y^S=\>7R*2(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3(W-PIM<V=I9"`B("A!8V-E<W-K
M97D@)7,I(@IM<V=S='(@(B`HRNOEZ>3?(/#Q_//BX?/G\B`E<RDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S4Y"FUS9VED("(@*&EN("5S(&1A
M>7,I(@IM<V=S='(@(B`H\^4@)7,@Y^S=\>7R*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-34*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H
M\][LY?'A*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-3<*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`HX?WQZ>\I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,U,PIM<V=I9"`B("AY97-T97)D87DI(@IM
M<V=S='(@(B`H]^CE\BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`P"FUS9VED("(@870@(@IM<V=S='(@(B#S].GR("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(B5D("5S(&%N9"`E
M<R(*;7-G<W1R("(E9"`E<R#JX>D@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(W"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T
M<B`B)60M[.7QYR#P\?SBZ^7XYR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]N;W1I8V5?=&]P+FEN8SHT"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R
M("(E<R`M(-/G[.7?^?/G(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH
M96%D97(N:6YC.C(Y"FUS9VED("(E<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("(E<RW$Z>'WY=_QZ?/G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,C@*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S
M(,3AZO3UZ^GJ_"#A\._T_?#Y[.$B"@HC+"!C+69O<FUA=`IM<V=I9"`B)7,@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R
M("(E<R#+Y>GT[_7QX]_E\B#3]>WTWO'G\^?R("T@Q?#IXN7BX=_Y\^<B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,#D*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S+=#A\>'LY?3Q
M[_#OW^?SYR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-S8*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@Q>/C\>'VWB(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHT"FUS
M9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@S_'OZ2#W
M\=[SY_(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C4Y-B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C8V-@IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(B5S(-[DYR#U\-SQ]^7I+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34W(&QI8B]";&]C:R]M971A<BYP:'`Z,38S(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,W"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0S
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Y"FUS9VED("(E<R!A="`E<R`E<R(*
M;7-G<W1R("(E<R#SY2`E<R`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3,P"FUS9VED("(E<R!H87,@8V%N8V5L
M;&5D("5S+B(*;7-G<W1R("(E<R#AZO7Q_NCGZN4@)7,N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C8*;7-G:60@
M(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S
M='(@(B5S(.'PW.WTY_/E(//E(.7Q_O3G[.$@Y.GAZ.7SZ>S\].?TX?(N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M,C0*;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O
M("5S+B(*;7-G<W1R("(E<R#A\-SM].?SY2#S].?M(/#Q_//JZ^?SYR#CZ>$@
M)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT,38*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN(@IM<V=S='(@(B5S(//A\B#=\_3EZ>OE(/#KY_'O]N_QW^7R
M(.3IX>CE\^GL_/3G].'R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,C$*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(.7?[>'I
M(.'PX>GT[_WLY>WO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#0*;7-G
M:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@Z^7P]-PB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R,0IM<V=I9"`B
M)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B5S(//A\B#FWO3G\^4@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,#@*;7-G:60@(B5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N
M(@IM<V=S='(@(B5S(.;>].?SY2#TY^T@\.'Q[_7SW^$@\^'R(//TZ?(@)7,N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-@IM<V=I9"`B
M)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@^?(@)7,@X?#\("5S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3,*
M;7-G:60@(B5S('=I<VAE<R!T;R!A9&0@=&\@)7,N(@IM<V=S='(@(B5S(.7P
MZ>CU[.7?(/3G[2#P\>_SZ-[JYR#S].\@)7,N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#(*;7-G:60@(B5S('=I
M<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RXB"FUS9W-T<B`B)7,@Y?#I
MZ/7LY=\@[>$@\^'R(.7MY^SE\?[SY>D@X^GA("5S+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$X"FUS9VED("(E
M<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B
M;W5T("5S+B(*;7-G<W1R("(E<R#E\.GH]>SEWR#MX2#KW.+EZ2#TZ?(@].7K
MY?7TX=_E\B#PZ^?Q[_;O\=_E\B#CZ>$@)7,N(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,3(*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM
M<V=S='(@(B5S)W,@Q.GE]>CU[?/I[^/QW/;O\B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S
M='(@(B5S)W,@Q^SE\>_K_./I[R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.#DV"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7-S(-/G
M[.7I^>SA]-SQZ>\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M,`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E<W,@R]_S].$@Q?'C
MX?/I_NTB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<P"FUS9VED("(G
M)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R#DY>T@
MY=_MX>D@W>/J]?'G(.7PZ>OOX]XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HU.#(*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HY.#(*;7-G:60@(B<E<R<@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(.3E[2#=
M]^7I(/'UZ.SI\_3EWR#S].\@<F5G:7-T<GD@].?R(.7VX?'L[^/>\B!(;W)D
M92(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$V,`IM<V=I9"`B)R5S
M)R!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@X>WA\.'Q
MX?/TW/3G\B#DY>WD\>GJWO(@Y._LWO(@Y.7M(.+QW>CGZN4N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-PIM<V=I9"`B)R5S)R!W87,@861D960@=&\@=&AE
M(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@\/'O\_3=Z.?JY2#S].GR
M(._LW.3E\B#S]?/TWNSA]._R+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HX-0IM<V=I9"`B)R5S)R!W87,@861D960@=&\@=&AE('!E<FUI<W-I
M;VYS('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#P\>_S]-WHY^KE(//TZ?(@W.3E
MZ>7R(/3O]2#S]?/TWNSA]._R+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@S"FUS9VED("(G)7,G('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E<R<@Y.7M(.3G[.GO]?'CWNCG
MZN4Z("5S+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@V(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3DQ"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T
M<B`B+"!G=7-T:6YG("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M.3D*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L
M(.SE].'BZ^?TWB#A\/P@)7,@\^4@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8Y,0IM<V=I
M9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(.7PZ>OOX]X@+2TB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM
M<V=S='(@(C$R^?'G(.SO\?;>(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y
M"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-/GQYR#L[_'VWB(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R
M<R(*;7-G<W1R("(R-"#^\>7R(@H*;7-G:60@(CQB/D$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D.CPO8CXB"FUS9W-T<B`B/&(^T.'Q[_7SZ=SS].?JY2#=
M[>$@\^_BX?'\(.O<Z._R.CPO8CXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$V-@IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`BT.'Q[_7SZ=SSZ.?JY2#J\=_SZ>SO(.O<Z._R(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.30Q"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("+!\.'I].7?].'I(.3G[/SSZ>\@ZNOEZ>3?(%!'4"#CZ>$@].?M
M(.KQ]?#T[^/QW/;G\^<@Y>W\\B#LY^W][.'T[_(N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-PIM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B(@HBP?#AZ?3EW_3AZ2#DY^S\\^GO(.KKY>GDWR!01U`@X^GA
M(.7PZ>+EXN'?^?/G(.7M_/(@]?#OX^7C\>'L[-WM[_4@[.?M_>SA]._R+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3@*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"B+!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!0
M1U`@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA("(*(N'P[^KQ]?#T
M[^/QX?;>\^7TY2#=[>$@[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B+!\.'I].7?].'I
M(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!01U`@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ
M_/(@X^GA(.WA(/7P[^/QW/CE].4@(@HB^.?VZ>'JW"#=[>$@[-[M]>SA+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B(@HBP?#AZ?3EW_3AZ2#DY^S\\^GO+"#P\>_S
M^?#IZOP@4R]-24U%(.KKY>GDWR#JX>D@Z]WNYRWJ^>3IZOSR(./IX2#MX2`B
M"B+A\._J\?7P]._C\>'VWO/E].4@W>WA(.S>[?7LX2XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0T.0IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*(L'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%,O34E-12#J
MZ^7IY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@(@HB]?#OX_'<^.7TY2#X
MY_;IX>K<(-WMX2#LWNWU[.$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS.#(*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BP?#AZ?3E
MW_3AZ2#DY^S\\^GO(.KKY>GDWR!3+TU)344@X^GA(/3G[2#J\?7P]._C\=SV
MY_/G(.7M_/(@[.?M_>SA]._R+B(*"FUS9VED(")!32]032(*;7-G<W1R("+P
M["_L["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(M#E\=\@
MX?7T[_T@]._U(,KEZ>SE[>_C\=SV[_4B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`BT.7QWRXN+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*
M;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("+!\/SK]?3O(/3=Z^_R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I
M9"`B06)S;6ED9&QE(@IM<V=S='(@(L'P_.OU].<@S-WSYR(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0P"FUS9VED
M(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R("+!\._D[_?>(.'I]-[LX?3O\B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-C@Q"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R("+%X^GMY2#A\._DY>KT_"(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR.#4*;7-G:60@(D%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
MQR#P\?SSXN'SYR#A\._Q\=_VZ.?JY2#JX?3<(/3G(.3G[.GO]?'CW^$@5D93
M(.KA].'K_./O]2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3,X"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*
M;7-G<W1R("+'(/#Q_//BX?/G(.'P[_'QW_;HY^KE(.KA]-P@].<@Y.?LZ>_U
M\>/?X2!61E,@X?'WY=_O]2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`BROGDZ>K\\B#+
M[^/A\>GA\^SO_2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S
M='(@(L\@Z^_CX?'IX?/L_/(@\-SC^?/E+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C`*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`BRN'T
MX>/QX?;>(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT-3$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV,C4*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`BQ>W=\>/E
MZ>7R(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4T(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3,V"B,Z('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHQ-"!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN
M8SHQ-@IM<V=I9"`B061D(@IM<V=S='(@(M#Q[_/HWNKG(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HR,30@861M:6XO9W)O=7!S+G!H<#HR,34*;7-G:60@(D%D
M9"!#:&EL9"!'<F]U<"(*;7-G<W1R("+0\>_SZ-[JYR#U\._O[-SDX?(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@Q(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#(*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S
M:6]N(@IM<V=S='(@(M#Q[_/HWNKG(-SDY>GA\B#U\._O[-SDX?(@*&-H:6QD
M('!E<FUI<W-I;VXI(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*
M;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("+0\>_SZ-[JYR#EY/XZ(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,#@@861M:6XO9W)O=7!S+G!H<#HR,#D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`BT/'O\^C>ZN<@S=WA\B#/[-SD
MX?(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<P(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S$*;7-G:60@(D%D9"!.97<@4&5R
M;6ES<VEO;B(*;7-G<W1R("+0\>_SZ-[JYR#MW>'R(-SDY>GA\B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.CD*;7-G:60@(D%D
M9"!A(&-H:6QD(&=R;W5P('1O("<E<R<B"FUS9W-T<B`BT/'O\^C>ZN<@]?#O
M[^S<Y.'R(//T[R`G)7,G(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C4S(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3,U"FUS9VED(")!
M9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("<E<R<B"FUS9W-T<B`BT/'O\^C>
MZN<@W.3EZ>'R("AP97)M:7-S:6]N*2#U\._O[-SDX?(@\_3O("<E<R<B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM
M<V=S='(@(M#Q[_/HWNKG(.W=[_4@]_'>\_3G.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*;7-G:60@(D%D9"!C;VQU
M;6XB"FUS9W-T<B`BT/'O\^C>ZN<@\_3>Z^?R(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B061D(&YE=R!M96UB97)S
M(@IM<V=S='(@(M#Q[_/HWNKG(.W=[_4@[-WK[_7R(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@
M(M#Q[_/HWNKG(.;E_>/O]?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S4Q"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(B"FUS9W-T<B`BT/'O\^C>ZN<@]._U("5S(//T[R#LY>WO_2#T[_4@36]Z
M:6QL82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-C,Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C,W"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(*
M;7-G<W1R("+0\>_SZ-[JYR#A]?3O_2#S].\@Y^SE\>_K_./I_"#L[_4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S0*;7-G
M:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(M#Q[_/HWNKG(//T
M[R#$Z>7UZ/7M\^GOX_'<]N\Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C@Q"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B
M;V]K(@IM<V=S='(@(M#Q[_/HWNKG(//T[R#$Z>7UZ/7M\^GOX_'<]N\@[._U
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S
M='(@(M#Q[_/HWNKG(/?QWO/TYR(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"FUS
M9VED("(B"B)!9&1E9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N
M;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E(@HB<RXB
M"FUS9W-T<B`B(@HBT/'O\_3=Z.?JY2`G)7,G(//T[R#S_?/TY^SA+"#AZ^O<
M(.3E[2#L\/SQY?/A(.WA(/#Q[_/HW?/Y(//U[/#KY_'Y[.'TZ>K=\B`B"B+P
MZ^?Q[_;O\=_E\B(*"B,Z('-I9VYU<"YP:'`Z-#8*;7-G:60@(D%D9&5D("<E
M<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R
M("+0\>_S]-WHY^KE("<E<R<@\_3O(//]\_3G[.$N(,SP[_'EW_3E(.WA(//U
M[>3EZ.7?].4@]/[QX2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D
M9"YI;F,Z-`IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G
M<W1R("+'(/#Q[_/HWNKG(/?QY_/T_NT@W??EZ2#A\.7MY?'C[_#OZ>?HY=\N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S<*;7-G:60@(D%D9')E<W,B
M"FUS9W-T<B`BQ.GE_>CU[?/G(@H*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R("+$Z>7UZ/7M\^GOX_'<]N_R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3<*;7-G:60@(D%D;6EN:7-T97(@+2!S970@
M<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(L3IX??EW_'I
M\^<@+2#$_O/TY2#DZ>KAZ?[LX?3A(//E(-SKZ^_U\B#W\=[S].7R(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I
M\^<B"@IM<V=I9"`B06MT:6]N($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WM
MX?(@P>KTW^_U(@H*;7-G:60@(D%L97AA;F1R;W5P;VQI($%I<G!O<G0B"FUS
M9W-T<B`BP>7Q[^OI[-[M(,'KY>[A[>3Q[_WP[^OG\B(*"FUS9VED(")!;&EA
M<R(*;7-G<W1R("+8Y?7D_NWU[.\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G
M<W1R("+%]>CUX_'<[.SI\^4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(L7UZ/7C\=SL[.GSYSHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*
M;7-G:60@(D%L;"(*;7-G<W1R("+/Z^$B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,3@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,0IM<V=I9"`B
M06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`BS^OOZ2#OZ2#=X^KU
M\>_I(/?QWO/TY?(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(L_KY?(@
M[^D@S^S<Y.7R(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S0*;7-G:60@(D%L;"!097)M
M:7-S:6]N<R(*;7-G<W1R("+/Z^$@].$@Y.GJX>G^[.'TX2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G
M:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(LKAZ2#OZ2#TW?/SY?'I\B`H
M-"D@\.OE]?'=\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-30*
M;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("+-X2#E
M\.GT\=WP[^WTX>D@\._KZ^'PZ]WR(.3IY?7H_>WSY>GR(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q-PIM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`BS>$@Y?#I]/'=\._M].'I(/'U
MZ.S?\^7I\B#TX>[I[>_LZ>S=[?GM(.OI\_3^[3LB"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HT,#$*;7-G:60@(D%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(L?DYR#U\-SQ]^7I(@H*;7-G:60@(D%L=&5R;F%T
M92!)35-0($QO9VEN(@IM<V=S='(@(L7MX>OKX>KTZ>K>($E-4U`@Q=_S[^3O
M\B(*"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("+%
M[>'KZ^'J].GJ_/(@24U34"#*^>3IZOSR(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0X,@IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`BQ>WAZ^OAZO3IZOP@24U34""\[>_LX2#7\=[S].<B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M
M86EL(&%D9')E<W,B"FUS9W-T<B`BQ>WAZ^OAZO3IZMX@Y.GE_>CU[?/G(&5M
M86EL(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R
M;F%T92!T96UP;&%T97,B"FUS9W-T<B`BQ>WAZ^OAZO3IZMP@\/'\]/7PX2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(L7M
MX>OKX>KTZ>K\(.KEW^SE[>\Z(@H*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"XB"FUS9W-T<B`BS_'?\_3GZN4@[-_A(.SG(.7PZ?3Q
MY?#\[.7MYR#TZ>S>+B(*"FUS9VED(")!;F-H:6%L;W,@06ER<&]R="(*;7-G
M<W1R("+!Y?'OZ^GLW>WA\B#!X_??X>OO]2XB"@IM<V=I9"`B06YD<F%V:61A
M($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@P>WD\>'BW^3A\BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3(P"FUS9VED(")!;F]N
M>6UO=7,@4')O>'DB"FUS9W-T<B`BP>W^[?7L[_(@Q.GA[.SE\^_KX>+G]-[R
M("A0<F]X>2DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM
M<V=I9"`B06YS=V5R(@IM<V=S='(@(L'PW.WTY_/G(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S`*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU.2!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("+%
M]N'Q[._CWB(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B
M07!P;&EC871I;VX@3&ES="(*;7-G<W1R("++W_/TX2#%]N'Q[._CWO(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,P"FUS9VED(")!<'!L:6-A=&EO
M;B!I<R!R96%D>2XB"FUS9W-T<B`BQR#E]N'Q[._CWB#EW^WAZ2#=]._I[.<N
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,C0*;7-G:60@(D%P
M<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("+%]N'Q[._CWB#JX>D@\_3A
M(.7NX?'T_NSE[>$@ZN_I[?SW\>?S].$B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHS,PIM<V=I9"`B07!P<F]V92(*;7-G<W1R("+%
MX^KQW^WY(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,W-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(L'P\=_KZ>_R(@H*;7-G:60@
M(D%R87AO<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,'QW.[O]2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C(@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R("+,W>/EZ._R(.'Q]^7?[_4@X?'WY>GOZ-WT
MY_/G\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`BS^WO[.$@X?'WY=_O]2#A\??EZ>C=].?S
MY_(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.CD*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(L7?\_3E(//?X^_U
M\><@X^GA(/3G(.3IX>/QX?;>(/3G\B#AW_3G\^?R(/7P[^/QX?;>\B#CZ>$@
M)7,@/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("<E<R<@
M86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+%W_/TY2#SW^/O]?'OZ2#\
M].D@Z-WKY?3E(.WA(.3IX>/QW/CE].4@)R5S)R#JX>D@_.OE\B#TZ?(@]?#O
M[^S<Y.7R/R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B
M07)T(@IM<V=S='(@(M3=]^WG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B05-#24D@U-WW[><B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`Y"FUS9VED(")!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\B"FUS9W-T<B`BS>$@YN?TY=_TY2#E\.GBY>+AW_GSYR#P\=_M(.'P_"#J
MW.CE(.7MW?'CY>GA(.3IX??EW_'I\^?R.R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,P.3<*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G
M<W1R("+![=SHY?/G(//TY^O^[2(*"FUS9VED(")!=&AI;F%I($%I<G!O<G0B
M"FUS9W-T<B`BP>7Q[^OI[-WMX?(@P>CG[?[M(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ-C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR-#D*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS,3@*;7-G:60@
M(D%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY('1O(&$@<F5Q
M=65S="!Y;W4@<V5N="(*;7-G<W1R("+4[R#S]>WG[.S=[>\@Y=_MX>D@W>WA
M(.'Q]^7?[R#G[.7Q[^OOX]_O]2#SY2#A\-SM].?SYR#AZ?3>[.'T_/(@\^'R
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-0IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(M#Q[_/PW.CE
MZ>$@Y.GAX_'A]M[R(.SG(/7PX?'J]-[R(._LW.3A\BXB"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C,X"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+0\>_S\-SHY>GA
M(.3IX>/QX?;>\B#LYR#U\.'QZO3O_2#DZ>KAZ?[LX?3O\BXB"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HY.`IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(M#Q[_/PW.CEZ>$@
MY?#E[N7QX^'SW^'R(.SG(/7PX?'J]._](.3IZN'I_NSA]._R+B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("+0\>_S\-SHY>GA
M(.7PY>[E\>/A\]_A\B#LYR#U\.'QZO3O_2#DZ>'L[^GQX?/LW>WO]2XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4W
M-PIM<V=I9"`B071T96YD965S(@IM<V=S='(@(M#A\>7U\>GSZOSLY>WOZ2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U
M=&5S(@IM<V=S='(@(LGDZ?STY_3E\B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B
MP?WC[_7S]._R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B
M"FUS9W-T<B`BQR#A]>CE[?3IZN_P[]_G\^<@X?#=]/7WY2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<X"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(L<@X?7H
MY>WTZ>KO\._?Y_/G(.'PW?3U]^4N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]R861I=7,N<&AP.C$X,0IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`BQR#A]>CE[?3IZN_P
M[]_G\^<@X?#O\?'?]NCGZN4@X?#\(/3O[2!2041)55,@<V5R=F5R+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`P"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BQR#A]>CE
M[?3IZN_P[]_G\^<@\_3O[2!&5%`M4V5R=F5R(.'PW?3U]^4N(@H*;7-G:60@
M(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(L3IX>C=\^GLX2#0Y>3?X3HB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C8Q-`IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`BP>WA[-WM
M[^WTX?(@X?#<[?3G\^<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S
M='(@(M7P_.+AZ/'O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R
M("+7\?[LX2#U\/SBX>CQ[_4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S
M='(@(LO<Z._R($ME<F)E<F]S+>KYY.GJ_/(N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R("++W.CO\B!+97)B97)O<RV\[>_LX2#7\=[S].<N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y,@IM<V=I9"`B0F%R92(*
M;7-G<W1R("+!Y.7I[R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0IM
M<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N
M(@IM<V=S='(@(L\@ZOWQZ>_R(.KA]-SK[^/O\B#C\>'VZ>K^[2`G)7,G(.3E
M[2#B\=WHY^KE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`BPN'S
MZ>K>(./QX>SLWB(*"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("+#Y>W=Z.OI
MX2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B
M0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`BT?7H[-_SY>GR(/3LWNSA]._R(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C
M:R!4>7!E(@IM<V=S='(@(M3]\._R(/3LWNSA]._R(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-@IM<V=I9"`B0FQO8VL@
M7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(M3O(/3LWNSA(%PB)7-<(B#TY_(@Y?;A\>SOX][R(%PB)7-<(B#DY>T@
MXO'=Z.?JY2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`BN.WT[^WA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM
M<V=I9"`B0F]R9&5R<R(*;7-G<W1R("*\\>GA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(LKAZ2#TX2#D_>\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("+*X?3^].'T[R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@
M(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`BR]_S].$@[.4@].7KY=_E\B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(Q"FUS9VED(")#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("+3Y^SEW^$@Y.GA[>_L
MWO(@0U),(@H*;7-G:60@(D-64R(*;7-G<W1R("+!\??EW^\@ZN7I[-WM[_4@
M]_GQZ?/LW>WO(.SE(.K\[.SA("A#5E,I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L
M;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(LGDZ?STY_3E\B#*Y>OI_NTN+BXB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#,*;7-G:60@(D-A;&5N9&%R
M(@IM<V=S='(@(L?LY?'OZ_SCZ>\B"@IM<V=I9"`B0V%L96YD87(Z(@IM<V=S
M='(@(L?LY?'OZ_SCZ>\Z(@H*;7-G:60@(D-A;&5N9&%R(%-U;6UA<GDB"FUS
M9W-T<B`BT.7QW^OG^.<@Q^SE\>_K_./I[_4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3DU"FUS9VED(")#86QM(@IM<V=S='(@(L?QY>S?
MX2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+!Y/WMX?3G(.<@X?'W
MZ>KO\._?Y_/G(/3O]2#J^>3IZN_](.'U]/SLX?3A+"#E\.GJ[^GM^>W>\_3E
M(.SE(/3O(.3IX??EZ?'I\_3>(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,C0Q(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS
M,3(*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(L'D_>WA].<@YR#S_>WDY?/G(.SE(/3O[2!)34%0+5-E<G9E<CH@
M)7,B"@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(L'J_?'Y\^<B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R
M;V)L96T@4F5P;W)T(@IM<V=S='(@(L'J_?'Y\^<@P>WA]N_QW/(@T/'OXNO>
M[.'T[_(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(V.0IM<V=I
M9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BP>3][>'T
MYR#G(.3IX>/QX?;>(/3O]2#A\??EW^_U(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-#<*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,PIM<V=I9"`B0V%N
M;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("+$Y2#B
M\=_SZOD@\/'O\_GQZ>W\(/;<ZN7K[R`H=&5M<"!D:7(I+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3<*;7-G:60@(D-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB
M"FUS9W-T<B`BP>3][>'TYR#G(//U[=WWY>GA(/?Y\=_R(/3G[2#PX?'<[.7T
M\>\@7")T87)G971&:6QE7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR-C4*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(/3O]2#VX>K=Z^_U(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$Q
M,B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU-S8*;7-G
M:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R
M("+!Y/WMX?3G(.<@Y.GAX_'A]MXL("5D(/7P]MSJY>OO\B#U\-SQ]^7I+B(*
M"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P,@IM
M<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U
M<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S
M=&]R960N(@IM<V=S='(@(B(*(L'D_>WA].<@YR#E\.'MX?3A[NGM_.SG\^<L
M(.\@X?'IZ.S\\B#T^>T@Y>/C\>'V_NT@\._U(.3^\^'TY2#CZ>$@(@HBY?#A
M[>'TX>[I[?SLY_/G+"#DY>T@].'I\>G<YN7I(.SE(/3O[2#A\>GH[/P@]/GM
M(.'P[^CGZN7U[-WM^>TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$X"FUS9VED(")#86YN;W0@<F]U=&4@;65S
M<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("+$Y2#L\._Q_B#M
MX2#D\>_L[^OOX][S^2#LWNWU[.$@\_3O[2#A\>GH[/P@\._U(._QW_/A].4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+%\.GJY?;AZ]_DX2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE
M<R!A;F0@3&%B96QS(@IM<V=S='(@(LKA].?C[_'?Y?(@ZN'I(,7TZ>K=].7R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-PIM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("+*Z>WG]/P@U.?KW?;Y[>\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BR>3I_/3G
M].7R(,KEZ^GO_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(L/=
M[.GS[.$@RN7KZ>_].B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R("+)Y.G\].?TY?(@RN7KZ>_](@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN
M9SHB"FUS9W-T<B`BQ.G<ZN7M[R#*Y>OI_NTZ(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(V-0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(LKI
M[>?T_"#4Y^O=]OGM[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("+*
MW>WT\>\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<R
M,PIM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("++Y?#T[^S=
M\>7IY?(@T.GS]._P[^GG].GJ[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8R,`IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B
M"FUS9W-T<B`BT._KZ?3IZMX@T.GS]._P[^GG].GJ[_TB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Y-B`_/S\*;7-G
M:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R("+0\?SEY/'O\B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3<*;7-G:60@(D-H86YG92(*;7-G<W1R("+!Z^OAX]XB"@IM
M<V=I9"`B0VAA;F=E(%!A<W-W;W)D(@IM<V=S='(@(L'KZ^'CWB#J^>3IZN_]
M(@H*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M(@HB96UA:6QS+B(*;7-G<W1R("(B"B+!Z^O<[O3E(/3O(/SM[^SA(.KAZ2#T
MYR#DZ>7]Z/7M\^<@\._U(.CA(.+KW?#O]>T@_/3A[2#DZ>'BW.;O]>T@WB#A
M\.'M]._][2`B"B+SY2#LY^W][.'TW"#SX?(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R
M(@IM<V=S='(@(M?A\>'J]-[QX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,
M:6YK+BXN(@IM<V=S='(@(KCKY>/W[_(@\_WMY.7SY_(N+BXB"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B+3Y^SEZ?[S].4@
M].\@].7T\>'C^>W?Y.GO(./IX2#O\._IX>3>\._TY2#E\>/A\]_A*.7R*2#H
MW>OE].4@[>$@Y>KTY>OE\_3O_>T@(@HBX?7TWB#TYR#S].GC[-XN(@H*;7-G
M:60@(D-H:6]S($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@U]_O]2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!
M<'!L:6-A=&EO;CHB"FUS9W-T<B`BQ?#IZ]WN].4@Q?;A\>SOX]XZ(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(X,@IM<V=I9"`B0VAO
M;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BQ?#IZ]WN].4@ZOGDZ>K\(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(X,0IM<V=I9"`B0VAO
M;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`BQ?#IZ]WN].4@_.WO[.$@]_'>\_3G
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HT-3(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HV,C8*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(L7P
MZ>O=[O3E(.SIX2#E[=WQX^7IX3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C@R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM
M<V=S='(@(L7PZ>O=[O3E(/#Y\B#HX2#E[/;A[=_F[^WTX>D@[^D@Y^SE\>_L
MY^W?Y?(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(L7PZ>O=[O3E(/3]\.\@
MZ]_S].'R("CCZ>$@].'NZ>WO[.?LW>WE\B#KW_/TY?(I(@H*;7-G:60@(D-H
M<GES;W5P;VQI($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@U_'U\^_]
M\._KY_(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C,Q,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-C4U"FUS9VED(")#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BQ.7M(.+QW>CGZN4@[_'I\^S\
M\B#JZ]SSY_(@]._U("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,30*;7-G:60@(D-L96%R(@IM<V=S='(@(LKAZ-SQZ?/E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I
M9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("+*X>CA\>GS[/SR(.7T
MZ>KE]/[M("AT86=S*2!-4RU/9F9I8V4B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z-PIM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM
M<V=S='(@(B?!Y.7IX?/LX2<@U_'>\_3G.B`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHQ-@IM<V=I9"`B0VQE87(@=7-E<B(*;7-G
M<W1R("+*X>CA\>GS[/SR(-?QWO/TYR(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,W"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T
M<B`BRN'HX?'I\^S\\B#DY>3O[-WM^>T@]_'>\_3G(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VYO=&EC95]B;W1T;VTN:6YC.C8*;7-G:60@(D-L:6-K
M('1O($-O;G1I;G5E(@IM<V=S='(@(LK<[?3E(.KKZ>H@X^GA(//U[=WWY>GA
M(@H*;7-G:60@(D-L;W-E($AE;'`@5VEN9&]W(@IM<V=S='(@(LKKY=_SZ>SO
M(-#A\=SH]?'O]2#"[][HY>GA\B(*"FUS9VED(")#;&]S92!(96QP(@IM<V=S
M='(@(LKKY=_SZ>SO(,+OWNCEZ>'R(@H*;7-G:60@(D-L;W-E(%=I;F1O=R(*
M;7-G<W1R("+*Z^7?\^GL[R#0X?'<Z/7Q[_4B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC.C0*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS
M9W-T<B`BP>WAY-_PZ_GSYR#0Z^7U\>GJWO(@S/#<\>'R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I
M9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`BP>WAY.GPZ_GLW>WA(-#E
M\>GH_O'IX2(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K
M+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("+7\?[L
MX2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HR
M.3<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y
M.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#<R
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3$*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3(*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C@*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-CD*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#8*;7-G:60@(D-O
M;&]R(%!I8VME<B(*;7-G<W1R("+%\.GKW>KTY_(@U_'^[.'T[_(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,T"FUS9VED(")#;VQO=7(@<V5L
M96-T:6]N(@IM<V=S='(@(L7PZ>OOX]X@U_'^[.'T[_(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L
M<SHB"FUS9W-T<B`BT_3>Z^7R.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y,CD*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`BU-_TZ^_I
M(-/TY^O^[2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G
M:60@(D-O;6EC<R(*;7-G<W1R(")#;VUI8W,B"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`BQ>WT[^O>(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM
M<V=S='(@(LK=Z_7V[_(@Q>WT[^O^[2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C,Y.0IM<V=I9"`B0V]M;65N="(*;7-G<W1R("+3]_SK
MZ>\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,`IM
M<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`BRN_I[?P@O.WO[.$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0R"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(L7TX>GQY=_A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.3<*;7-G:60@(D-O;7!L
M971E9"(*;7-G<W1R("+/Z^_JZ^?Q_NCGZN4B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"FUS9VED(")#;VUP
M;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R("+3_>WHY?/G(,SG[?WLX?3O\B`H
M)7,I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP
M=71E<G,B"FUS9W-T<B`BU?#OZ^_CZ?/TW?(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(T-PIM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("+3]>WHWNKE
M\B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C@Y"FUS9VED(")#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(L3IX?;O\=WR(-#A\>'LY?3Q
M[_#OW^?SY_(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(L7PZ>OOX]WR(./IX2#S]>/W
M\>_MZ?/L_"#LY2!01$%S+"#=[O7P[>$@U.?KW?;Y[>$@ZN'I($]U=&QO;VLN
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B1&EE($MO;F9I9W5R
M871I;VX@;75S<R!A:W1U86QI<VEE<G0@=V5R9&5N+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,C4*;7-G:60@(D-O;F9I9W5R871I;VX@;F5E9',@
M=7!D871I;F<N(@IM<V=S='(@(L<@\.'QX>SE]/'O\._?Y_/G(/?QY>G<YN7T
MX>D@Y>WG[-WQ^?/G+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HY.0IM
M<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(M#A\>'LY?3Q[_#OW^?SYR`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S<*;7-G
M:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`BQ?#IXN7BX=_Y\^<@ROGD
MZ>KO_2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(P-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3D*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("+'(//][>3E
M\^<@X?#=]/7WY2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,#8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$Y"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@
M(L<@\_WMY.7SYR#A\-WT]??E.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3,*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BP?'MY_/G(//][>3E\^?R
M(.'P_"#T[R#DY^S\\^GO(.7N]?#G\>7TY_3>(.KKY>GDZ?[M+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y-0IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ
M("5S("@E<RDB"FUS9W-T<B`BP?'MY_/G(//][>3E\^?R(.'P_"#T[R#DY^S\
M\^GO(.7N]?#G\>7TY_3>(.KKY>GDZ?[M+B#+_./O\B`Z("5S("@E<RDB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Y-`IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BQR#S_>WDY?/G
M(.SE(/3O($944"U397)V97(@X?#=]/7WY2XB"@IM<V=I9"`B0V]N=&%C="!3
M96%R8V@B"FUS9W-T<B`BP>WAYM[TY_/G(,7PX?;>\B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU-@IM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(L_I(.7PX?;=\B#P\>_S]-WHY^KA[2#E\.GT]??^\B#S
M].\@Q.GE]>CU[?/I[^/QW/;O(//A\BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.`IM<V=I9"`B0V]N=&5N=',@;V8@)R5S)R(*;7-G<W1R("+0
MY?'IY??\[.7MX2#T[_4@)R5S)R(*"FUS9VED(")#;VYT96YT<R!O9B!T:&4@
M4D%2(&%R8VAI=F4B"FUS9W-T<B`BT.7QZ>7W_.SE[>$@]/GM(.'Q]^7?^>T@
M4D%2(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@
M(D-O;G1I;G5E(@IM<V=S='(@(M/U[=WWY>GA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#
M;W!Y(@IM<V=S='(@(L'M].GC\>'VWB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N
M(@IM<V=S='(@(L'M].GC\>'VWB#%\.GK[^/>\B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(L'D_>WA].<@YR#J\?7P]._C\=SV
MY_/G(/3O]2#LY^W][.'T[_(@[.4@4$=0+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG
M;B!M97-S86=E+B(*;7-G<W1R("+!Y/WMX?3G(.<@]?#OX_'A]MX@]._U(.SG
M[?WLX?3O\B#LY2!01U`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT,3$*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R("+!Y/WMX?3G(.<@ZO'U\/3OX_'<]N?SYR#T[_4@
M[.?M_>SA]._R(.SE(%,O34E-12XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C0X-0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N
M(&UE<W-A9V4N(@IM<V=S='(@(L'D_>WA].<@YR#U\._C\>'VWB#T[_4@[.?M
M_>SA]._R(.SE(%,O34E-12XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$X-`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<R(*;7-G<W1R("+$Y>T@[/#\\>7SX2#MX2#P\>_SZ-WS^2#T
MY^T@Y?#A]MXN("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HQ,3,*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("+!Y/WMX?3G(.<@\_WMY.7SYR#LY2#T[R!,1$%0+5-E<G9E<BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$U-`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ-S,*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*
M;7-G<W1R("+!Y/WMX?3O\B#O(-WKY>/O\B#U\._K[]_P[_4N("5S(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(L'D
M_>WA].<@YR#S_>WDY?/G(//T[^T@Y>[U\.?QY?3G]-X@)R5S)R#W\>?SZ>SP
M[^G^[?3A\B!&5%`Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HS,CD*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L'D_>WA].<@YR#DY^SI
M[_7QX]_A(.O?\_3A\R#DZ>'M[^S>\BX@)7,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,3(V"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T82XB"FUS9W-T<B`BP>3][>'TYR#G(.'P[^KQ]?#T[^/QW/;G
M\^<@4$=0(.3EY._LW>WY[2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4T,`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N(@IM<V=S='(@(L'D_>WA].<@YR#A\._J\?7P]._C\=SVY_/G(%,O
M34E-12#DY>3O[-WM^>TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-3`*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M8V]N=&%C="X@)7,B"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(.7PX?;>
M\BX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,V-0IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(.O?\_3A
M\B#DZ>'M[^S>\BX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M-PIM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP
M="`G)7,G+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@)R5S)R`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS.3D@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.34Y"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@Y.GE]>KQ
MZ>W>\_D@].<@Y.GE_>CU[?/G(/3O]2#PX?'AZ][P].<N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#@*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(L'D_>WA].<@YR#PZ][QY_(@\/'\\^+A\^<@]._U(,3IY?7H]>WSZ>_C
M\=SV[_4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,3`*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BP>3][>'TYR#G(/#KWO'G\B#P
M\?SSXN'SYR#TY_(@Z]_S].'R(.3IX>WO[-[R+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#8Q"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+B(*;7-G<W1R("+!Y/WMX?3G(.<@\.O>\>?R(/#Q_//BX?/G(.O?
M\_3A\B#A\/P@Z]_S].7R(.3IX>WO[-[R+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8Y
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z.#4*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y("<E<R<N(@IM<V=S='(@(L'D_>WA].\@].\@]OSQ]/GLX2#S]/'A].?C
MZ>K>\B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,0HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+V1I<F5C="YP:'`Z,S$*;7-G:60@(D-O=6QD(&YO="!M:V1I<B`G)7,G
M+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2#VX>K=Z^_U(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,C`*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(L'D_>WA].<@YR#A[=SJ].?SYR#DY^S\\^GO]2#J
MZ^7IY.GO_2#A\/P@]._M(.7N]?#G\>7TY_3>(,3G["[*Z^7IY.G^[2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C<P
M,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS-30*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("+!Y/WM
MX?3O(/3O(-SM[^GC[.$@)7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@)R5S)R!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`BP>3][>'T[R#T[R#<[>_IX^SA(%PB)7-<(B#CZ>$@Y>/C\>'VWBXB"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q-2!C
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,B"FUS9W-T<B`BP>3][>'T[R#T[R#<[>_IX^SA(/3O]2#L
MW?'O]?(@Q.GA]^7?\>GSY_(@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S$*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+B(*;7-G<W1R
M("+$Y>T@[/#O\?X@[>$@X>WOW^[Y(/3O(/;<ZN7K[R!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-S`*;7-G:60@(D-O=6QD
M(&YO="!R96%D("5S+B(*;7-G<W1R("+$Y>T@[/#O\?X@[>$@Y.GAXMSS^2`E
M<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B
M(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(L'D_>WA].<@YR#A\??IZN_P[]_G\^<@]._U(.KYY.GJ[_T@X^GA(/3O
M[2#AZ?3O_>SE[>\@]_'>\_3G+B#*W/#OZ>$@WB#\Z^7R("(*(N_I(.OE\/3O
M[-WQY>GE\B#DY>T@Y=_MX>D@\_GS]-WR+B#.X>WAY._JZ>S<\_3E(-X@Y?#I
MZN_I[?GMWO/TY2#LY2#T[R#DZ>'WY>DM(@HB\>GS]-X@X>T@]_'EZ=SSY?/H
MY2#PY?'I\_/\].7QYR#B[][HY>GA+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q.`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Y,@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.3@*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB
M"FUS9W-T<B`BP>3][>'TYR#G(.'MW.KTY_/G(,O?\_3A\B#*X>W\[?GM(-#Q
M_//BX?/G\B`H04-,*2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C<Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("+!Y/WMX?3G(.<@X>W<ZO3G\^<@
MQ.GE]>CU[?/I[^/QW/;O]2X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4P,0IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+!Y/WMX?3G
M(.<@X>W<ZO3G\^<@R]_S].'R(,3IX>WO[-[R+B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#4R"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G
M<W1R("+!Y/WMX?3G(.<@X>W<ZO3G\^<@R^GS]/[M(,3IX>WO[-[R+B`E<R(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R-@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,S`*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B
M"FUS9W-T<B`BP>3][>'TYR#G(.'MW.KTY_/G(/3Y[2#IY.GO]-[T^>T@]._U
M(.7N]?#G\>7TY_3>(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM
M<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("+!Y/WMX?3G(.<@Y?#A[>'V[_'<(/'UZ.S?\^7Y[2XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.34*;7-G:60@(D-O=6QD(&YO="!R;61I<B`G)7,G+B(*;7-G
M<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@]N'JW>OO]2`H<FUD:7(I(%PB)7-<
M(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ.4@[/#O
M\?X@[>$@X?#OZ.?JY?WS^2`E<R#Q]>CLW_/EZ?(N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM
M<V=S='(@(L3E(.SP[_'^(.WA(.K<[?D@Y?;EY/'IZOP@X>WTW^/QX?;O(/3Y
M[2#Q]>CLW_/E^>TN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M(@IM<V=S='(@(L3E(.SP[_'^(.WA(.K<[?D@Y?;EY/'IZOP@X>WTW^/QX?;O
M(/3Y[2#Q]>CLW_/E^>TZ("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.3(*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`G)7,G+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y
M(/#Q_./QX>SLX2#E[>?LW?'Y\^?R(//T[R`G)7,G+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C0*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("+$Y2#L\._Q
M_B#MX2#A\._HY^KE_?/Y(.7VY>3QZ>K\(.'Q]^7?[R#Q]>CLW_/E^>T@)7,N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`IM<V=I9"`B(@HB0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HBQ.4@[/#O\?X@[>$@X?#OZ.?JY?WS
M^2#T[R#A\??EW^\@\?7H[-_SY?GM("5S+B#,\._QY=_TY2#EW_3E(.WA(/?Q
MY_/I[._P[^G>+2(*(O/E].4@[.GA(.'P_"#TZ?(@Y?#IZ^_CW?(@X^GA(.WA
M(.'P[^CGZN7]\^7TY2#PW_/Y(//T[R`E<R#>(.'M].GC\=SX].4@[.4@].\@
M(@HB]]WQZ2#T[^T@ZO[DZ>KA(/#?\_D@\_3O("5S+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(S"FUS9VED(")#;W5L9"!N;W0@<V5A
M<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BP>3][>'TYR#G(.'MX>;>
M].?SYR#S]._M(.7N]?#G\>7TY_3>($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C@W"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK("<E<R<N(@IM<V=S='(@
M(L3E(.SP[_'^(.WA(.'P[_/U[>3=\_D@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C(Q"FUS9VED(")#
M;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(L3E(.SP[_'^
M(.WA(.7MY^SE\?[S^2#TY^T@Y?#A]MXN("5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,#D*;7-G:60@(D-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L3E
M(.SP[_'^(.WA(.7MY^SE\?[S^2#TYR#+W_/TX2#$Z>'M[^S>\BX@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*;7-G:60@(D-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`G)7,G.B`E<R(*;7-G<W1R("+$Y2#L
M\._Q_B#MX2#C\=SX^2#TZ?(@\?7LW_/EZ?(@X^GA("<E<R<Z("5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,`IM<V=I9"`B0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BXB"FUS9W-T<B`B(@HBQ.4@[/#O\?X@[>$@XO'^(/3G(/#KY?7Q
MZ>K>(.SPW/'A(/3O]2!-;WII;&QA+B#"Y>+AZ?GHY=_TX>D@_/3I(.7?[>'I
M("(*(N'M[^GJ]-XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,34Y"FUS9VED(")#;W5L9&XG="!G:79E('5S97(@)R5S)R!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`G)7,G.B`E<R(*
M;7-G<W1R("(B"B+$Y2#L\._Q_B#MX2#D_O/Y(//T[R#W\=[S].<@)R5S)R#T
MX2#PX?'AZMST^2#DZ>KAZ?[LX?3A(//T[R#VW.KEZ^\@)R5S)SH@)7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$U"FUS9VED(")#;W5N=&5D
M('1E>'0B"FUS9W-T<B`BS.7T\>?LW>WO(.KEW^SE[>\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B0V]U;G1R>2(*
M;7-G<W1R("+7_O'A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W
M,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("+0[_'EW^7R(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BQ.?LZ>_U\>/?X2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM
M<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("+$Y^SI[_7QX]_A(.7M_/(@
M\_7MY-WS[._U(@H*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B
MQ.?LZ>_U\>/?X2#LZ>'R(.W=X?(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY-0IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S
M(@IM<V=S='(@(L3G[.GO]?'CW^$@]?#O]N'JW>OY[2(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$S-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(R,@IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("+%[N_U
M\^GOY._TWO/EZ?(@Q.?LZ>_U\>/O_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R,30*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R
M("+!\>GH[/SR(-#I\_3Y].GJWO(@RMSQ].'R(@H*;7-G:60@(D-R961I=',B
M"FUS9W-T<B`BQ?7WX?'I\_3?Y?(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C8*;7-G:60@(D-U<G)E;G0@4&AA<V4B"FUS9W-T<B`BU/'=]^_U\^$@UMSS
MYR(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H
M<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(M3QW??O]?/A(/[Q
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,PIM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`BU.\@
M]/'=]^_M(%523"#EW^WAZ2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*
M;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("+4\=WW[^T@RN'I\?SR
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("+4\=WW[_7SX2#S]>WHWNKG
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(M3QW??Y[2#S]/WK
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`IM<V=I9"`B0W5S=&]M
M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("+0
MX?'A[.7T\>_P[]_G\^<@Y.GAY.GJX?/I_NT@\._U(.7J].7K[_WM].'I(.KA
M]-P@].?M(.7?\^_D[R`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R
M("+!\._J[_#>(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("+!\._J
M[_#>(.7PZ>OOX][R(@H*;7-G:60@(D1$(@IM<V=S='(@(LS,(@H*;7-G:60@
M(D1A:6QY(@IM<V=S='(@(L?LY?'>\^GA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0R,PIM<V=I9"`B1&%T82(*;7-G<W1R("+$Y>3O[-WMX2(*
M"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O
M=W-E<B(*;7-G<W1R("+%[/;<[>GSYR`H0G)O=W-E<BD@1&%T851R964B"@IM
M<V=I9"`B1&%T86)A<V4@<75E<GD@9F%I;&5D+B(*;7-G<W1R("+'(.'MX>;>
M].?SYR#S].<@PMSSYR#$Y>3O[-WM^>T@X?#=]/7WY2XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S.#$*;7-G:60@(D1A=&4B"FUS9W-T<B`BQ^SE\>_L
MY^W?X2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R
M"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(L?LY?'O[.?MW^$@\.'Q
MX>OAXM[R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-0IM<V=I
M9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BQ?#IZ^_CWB#'[.7Q[^SG[=_A
M\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@
M(D1A>2(*;7-G<W1R("+'[-WQX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B1&5?;&5T92!#
M;VQU;6XB"FUS9W-T<B`BQ.GAX_'A]MX@T_3>Z^?R(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R
M(@IM<V=S='(@(L3EZMWLXO'I[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`BQ.7JX>3IZN_?(.'QZ>CL[]\B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X-0IM<V=I
M9"`B1&5C;&EN960B"FUS9W-T<B`BN/?O]>T@X?'MY^CEWR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E
M8W)E87-E($EN9&5N="(*;7-G<W1R("+,Y=_Y\^<@T.7QZ>CY\=_O]2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3DR(&QI8B]P<F5F<RYP
M:'`Z,3`X"FUS9VED(")$969A=6QT(@IM<V=S='(@(M#Q[^KAZ._QZ?/LW>WO
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-#<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#$*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`BT/'OY?#IZ^7C[-WM
M[R#7\?[LX2(*"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(M#Q
M[^7PZ>OEX^S=[><@U.'U]/STY_3A(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3$Y(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`T"FUS9VED
M(")$969A=6QT(%!E<FUI<W-I;VYS(@IM<V=S='(@(M#Q[^KAZ._QZ?/LW>WE
M\B#%[N_U\^GOY._TWO/EZ?(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(P-0IM<V=I9"`B1&5F875L="!P97)M:7-S:6]N<R(*;7-G<W1R
M("+0\>_JX>CO\>GS[-WMY?(@Q>[O]?/I[^3O]-[SY>GR(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R
M("+/\>GS[._?(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV-#,*;7-G:60@(D1E;&5G871E('!O<VET:6]N(@IM<V=S
M='(@(LC=\^<@X>WTZ?#Q[_/^\._U(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.3,*;7-G:60@(D1E;&5G871E9"(*
M;7-G<W1R("+![?3I\/'O\_GPY^S=[>\B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HU,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Y-R!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,R-PHC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,T-R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C0R"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$R,B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T-0HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X."!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDY('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,PHC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B1&5L971E
M(@IM<V=S='(@(L3IX>/QX?;>(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#D@
M861M:6XO9W)O=7!S+G!H<#HR,3<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G
M<W1R("+$Z>'C\>'VWB#/[-SDX?(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C8P(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#0*
M;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(L3IX>/QX?;>(,7N
M[_7SZ>_D_/3G\^?R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.38*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B
M"FUS9W-T<B`BQ.GAX_'A]MX@ZN'I(.7JZMWM^?/G(.SG[?7LW/3Y[2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(L3IX>/QX?;>(.KEZ^GO
M_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`BQ.GAX_'A
M]MX@T_3>Z^?R(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@
M(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B
MQ.GAX_'A]MX@]?#<\??O[?3O\B#E[>'KZ^'J].GJ[_T@\/'O]/WP[_4B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4P(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S(V"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M("<E<R<B"FUS9W-T<B`BQ.GAX_'A]MX@Y>[O]?/I[^3O]-[SY?GM(./IX2`G
M)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,CD*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\B"FUS9W-T<B`BQ.GAX_'A]MX@Y>[O]?/I[^3O]-[SY?GM
M(./IX2`G)7,G(.KAZ2#JW.CE(/7P[RWE[N_U\^GOY/STY_/G.R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*
M;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`BQ.GAX_'A]MX@\_3>Z^?R(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I
M9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(M#Q[^7PZ>OE
MX^S=[><@U.'U]/STY_3A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN(@IM<V=S='(@(L3IX>/QX?;>(/3QW??O]?/A\B#S]-[K
MY_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C(*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS
M9W-T<B`BQ.GAX_'A]MX@]/'=]^_U\^'R(./QX>SLWO(B"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0X"FUS9VED(")$96QE=&4@=&AI<R!P97)M:7-S
M:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("+$Z>'C\>'V
MWB#A]?3>\B#TY_(@Y>[O]?/I[^3\].?SY_(@ZN'I(.K<Z.4@]?#O+>7N[_7S
MZ>_D_/3G\^?R.R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,U"FUS
M9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S
M='(@(L3IX>/QW/;GZN4@].\@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4X-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8Q.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C8Q"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@
M(K_QX2#<]NGNY_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8T,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@
M(L'Q[>?SYR#AZ?3>[.'T[_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C0W,0IM<V=I9"`B1&5N>2!R97%U97-T(&9O
M<B!F<F5E+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T<B`BP?'MY_/G(.'I]-[L
MX?3O\B#CZ>$@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(B"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HY-2!S97)V:6-E<R]P<F]B;&5M+G!H<#HY.2!S
M97)V:6-E<R]P<F]B;&5M+G!H<#HQ,#D*;7-G:60@(D1E<V-R:6)E('1H92!0
M<F]B;&5M(@IM<V=S='(@(M#E\>GC\>'VWB#T[_4@T/'OXNO>[.'T[_(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S
M8W)I<'1I;VXB"FUS9W-T<B`BT.7QZ>/QX?;>(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`BR^7P]._LW?'EZ>7R("CE\-_SY_(@
MZN'I(//T[R#A\??EW^\@ZN'TX>/QX?;>\B#T[_4@2&]R9&4I.B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`U"FUS9VED(")$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("+/Z2#KY?#T[^S=\>7IY?(@W??O]>T@ZN'TX>/QX?;EWR#CZ>$@]._M(.3I
MX??EZ?'I\_3>+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3,*
M;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(L'MW/#T]>[G(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,34*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R
M("+3Y^SEW^\@Q/'O\^G<\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S8*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(M/G[.7?[R#$
M\>_SZ=SR.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,@IM<V=I9"`B
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("+3Y^SEW^\@Q/'O
M\^G<\B#CZ>$@].?M(/3EZ^7U].'?X2#^\>$Z("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO
M;B!L969T('1O(')I9VAT(@IM<V=S='(@(LKA].7]Z/7M\^<@X?#\(.'QZ?/T
MY?'<(/#Q[_(@].$@Y.7NZ=PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F="(*;7-G<W1R("+*X?3E_>CU[?/G(.'P_"#TX2#DY>[IW"#P\>_R(/3A
M(.'QZ?/TY?'<(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@
M(D1I<F5C=&]R>2(*;7-G<W1R("+*X?3<Z^_C[_(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C4P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M(@IM<V=S='(@(L7L]MSMZ?/G(/[QX?(@\^4@,C3Y\><@[._Q]MX[(@H*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+%\.GK[^/=\B#%[/;<[>GS
MY_(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS9VED(")$:7-P;&%Y
M(&9O<F5C87-T("A4048I(@IM<V=S='(@(L7L]MSMZ?/G(/#Q[^+KW?CE^>T@
M*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`U"FUS9VED
M(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+,[_'VWB#%[/;<[>GSY_(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`S"FUS9VED(")$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`BQ>WG[-WQ^?/G(,3IW/3A
M[N?R(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,R-PIM<V=I9"`B1&\@;F]T(&1E;&5T92(*
M;7-G<W1R("+,YR#DZ>'C\=SVY>GR(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C(T"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<"(*;7-G<W1R("+,Y^T@Y?#I]^7I\=[SY?3E(.WA(.'M[]_N
MY?3E(.'PY?7HY=_A\B#T[R#A\??EW^\@;6%I;G1E;F%N8V4N<&AP(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3D@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3D*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB
M"FUS9W-T<B`BT.7QZ=WWY>D@YR#P\?[TYR#C\>'L[-X@[^W\[.'TX2#PY>3?
M^>T[(,'M(.WAZ2#T\^7JW/'E].4@X?7T_#HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-C8*;7-G:60@(D1O=VYL;V%D(@IM<V=S
M='(@(LKA]-WBX?/LX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@V-@IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`BRN'TW>+A
M\^SA("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-@IM<V=I9"`B
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="XB"FUS9W-T<B`BRN'TW>+A\^SA(/3O]2#A\??EW^_U(/#A\>'LW?3Q^>T@
M\^'M(%!(4"US8W)I<'0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`Y,`IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`BR]_S].$@RN'T
MX?'<ZO3G\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B
M1')U9W,B"FUS9W-T<B`BUMSQ[.'JX2WMX?'J^?3IZMPB"@IM<V=I9"`B161I
M="(*;7-G<W1R("+%\.7NY?'CX?/?X2(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]522YP:'`Z-3$@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM
M<V=I9"`B161I="!";&]C:R(*;7-G<W1R("+%\.7NY?'CX?/?X2!";&]C:R(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@X(&%D;6EN+V=R;W5P<RYP:'`Z,C$V
M"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(L7PY>[E\>/A\]_A(,_LW.3A
M\B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-3D@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX,PIM<V=I9"`B161I="!097)M:7-S
M:6]N(@IM<V=S='(@(L7PY>[E\>/A\]_A(,7N[_7SZ>_D_/3G\^?R(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R("+%\.7NY?'CX?/?X2#%[N_U\^GOY._TWO/E^>TB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+%\.7NY?'CX?/?X2#%[N_U
M\^GOY._TWO/E^>T@X^GA("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z.0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BQ?#E[N7Q
MX^'SW^$@Y?#IZ^_C_NT@X^GA.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,30*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(L7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y[2#CZ>$@)7,B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HR,#0@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR.#@*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<B
M"FUS9W-T<B`BQ?#E[N7QX^'SW^$@Q>[O]?/I[^3O]-[SY?GM(./IX2`G)7,G
M(@H*;7-G:60@(D5L969S:7,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA
M\B#%Z^7U\]_MX?(B"@IM<V=I9"`B2&5R86ML:6]N($%I<G!O<G0B"FUS9W-T
M<B`BP>7Q[^OI[-WMX?(@Q_'AZNOEW^_U(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")%;&5M
M96YT+BXN(@IM<V=S='(@(M/T[^GWY=_O+BXN(@H*;7-G:60@(D5M86EL(@IM
M<V=S='(@(L'KZ^?K[^/QX?;?X2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@Y('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,`IM
M<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("+$Z>7]Z/7M\^<@16UA:6PB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")%;6%I
M;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`BQR#DZ>7]Z/7M\^<@
M16UA:6P@\/'=\.7I(.WA(/3AZ?'IW.;EZ2XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3<R"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("+,WNWU[.$@[.4@\?7H[-_SY>GR(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X,`IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(L'I\^C>[.'TX2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B16UP='D@;65S
M<V%G92XB"FUS9W-T<B`BRN7M_"#LWNWU[.$N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ,S$*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS
M9W-T<B`BQ.7M(.7PZ?/T\=SVY^KA[2#!\._TY>O=\^SA].$N(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q-`IM<V=I9"`B16UP='D@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(L'DY>GE\B#S]>WHWNKE\B#A[>'FWO3G
M\^?R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B16YA
M8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@
M:6X@=&5X=#\B"FUS9W-T<B`BQ>WE\>/O\._?Y_/G(.7I\^'C^>/>\B#EZ>K\
M[?GM(.'P[R!0:&]T;R!#86QL97)I97<@\_3O(.KEW^SE[>\[(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4P,0IM<V=I9"`B16YA8FQE(')I9VAT(&-L
M:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`BS>$@Y>WE\>/O\._IY^CEWR#T
M[R#LY>WO_2#LY2#DY>[?(.KKZ>H[(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-#@*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-3,*;7-G:60@(D5N9"(*;7-G
M<W1R("+4W>OO\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y.0IM<V=I9"`B16YD('EE87(B
M"FUS9W-T<B`BN/3O\B#4W>OO]?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*
M;7-G<W1R("+,Y>/=[>CU\^<@RN7I[.7M[^/QW/;O]2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,#4*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B+$_O/TY2#LZ>$@Y?'^
M].?SYR#A\_;AZ^7?X?(L(.<@[_#OW^$@Z.$@\^'R(.;G].?HY=\@X>T@]_'E
MZ>'SZ.7?(.WA(.'KZ]SNY2TB"B+TY2#T[^T@ZOGDZ>K\(//A\BP@\"[W+B`G
MT._I_"#EW^WAZ2#T[R#\[>_LX2#T[_4@ZN'T[^GJZ>3?[_4@\^'R.R<Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS
M9W-T<B`BQ/[S].4@].<@\_WMY.7SYR#TY_(@Y>GJ_.WA\B#EY/XB"@IM<V=I
M9"`B17)R;W(B"FUS9W-T<B`BR]SH[_(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Y-0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(W.`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T-PIM<V=I9"`B17)R
M;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(LO<Z._R(.'P[_/TW>OK
M[^WTX?(@X?#<[?3G\^<Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(")%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N(@IM<V=S='(@(LO<Z._R(.SE(.S>[?7LX2!E;6%I;"XB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,30S"FUS9VED(")%<G)O<B!W<FET:6YG
M("<E<R<N(@IM<V=S='(@(LO<Z._R(./QW/;O[?3A\B!<(B5S7"(N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T
M<B`BQ>CMZ>K\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")%=7)O<&4B"FUS9W-T<B`BQ?7Q_O#G(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,R,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G
M<W1R("+*W.CE(#$U(.OE\/3<(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(LK<Z.4@,B#+
MY?#TW"(*"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(LK<Z.4@
M,S`@Y.7U].7Q_.OE\/3A(@H*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G
M<W1R("+*W.CE(#4@Z^7P]-PB"@IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`BRMSHY2#V[_'<(/#O]2#L\.'?[>7TY2#S].?M(/7PY_'E\]_A(@H*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+*W.CE(.SI\]X@_O'A(@H*
M;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("+*W.CE(.OE\/3\(@H*;7-G
M:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("+0X?'AY.7IX^SA].GJW?(@
M].GLW?(Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<V(&%D;6EN+V-M9'-H
M96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,V"FUS9VED(")%>&5C
M=71E(@IM<V=S='(@(L7J]-WKY?/G(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,S@V"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BQ?#=
MZO3A\^<B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS
M9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("+%\-WJ].'SYR#0Z^7U\>GJ
MWO(@S/#<\>'R(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$V.0IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(L'MX>S=[>_M].'M
M("<I)R(*"B,Z(&,M9F]R;6%T"FUS9VED(")%>'!E8W1E9"!<(D)%1TE.7"(@
M:6X@=&AE(&QI;F4@)60N(@IM<V=S='(@(L'MX>SE[?SLY>WO(%PB0D5'24Y<
M(B#S].<@X_'A[.S>("5D+B(*"B,Z(&,M9F]R;6%T"FUS9VED(")%>'!E8W1E
M9"!<(D5.1#HE<UPB(&EN(&QI;F4@)60N(@IM<V=S='(@(L'MX>SE[?SLY>WO
M(%PB14Y$.B5S7"(@\_3G(./QX>SLWB`E9"XB"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z,3<V"FUS9VED(")%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(L'MX>S=[>_M].'M
M(.'PZ]X@Z]WNYR#>(//U[>C>ZN<@X>WAYM[TY_/G\B#SY2#EZ?/AX_GCZ>K<
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDX"FUS9VED
M(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`BQ^SE\>_LY^W?X2#+WN[G\B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED
M(")%>'!O;F5N="(*;7-G<W1R("+%ZNC=].?R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@
M0V]L;W(B"FUS9W-T<B`BU_'^[.$@\/'O\^K>[>GO]2(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S$*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B
M"FUS9W-T<B`BT?7H[-_SY>GR(./IX2!&5%`@=7!L;V%D(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C0P"FUS9VED(")&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BP?#O]/7WW^$@ZN'TW"#T
MY^T@\/'O\_#<Z.7IX2#A[=SJ].?SY_(@]/GM(/#Q[_3I[-[SY?GM+B(*"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`BP?#O]/7WW^$@\_WMY.7SY_(@\_3O[2#DZ>'J[^SI\_3>(,KA].'K_./O
M]2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z,3`S"FUS9VED
M(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("+!
M\._T]???X2#S_>WDY?/G\B#S]._M(%--0BU397)V97(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HV,S$*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R("+!\._T]???X2#A[?3IX_'A]M[R(.'P
M_"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV,S8*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BP?#O
M]/7WW^$@X>WTZ>/QX?;>\B#SY2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HY,@IM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("+!\._T]???X2#DY^SI[_7Q
MX]_A\B#S_>WDY?/G\B!305-,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-C<Q"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM
M<V=S='(@(L'P[_3U]]_A(.SE].'V[_'<\B#SY2!<(B5S7"(N(@H*;7-G:60@
M(D9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@9F]R('5S97(@)7,@9G)O
M;2!C;&EE;G0@)7,L(')E87-O;B`E<R(*;7-G<W1R("(B"B+!\._T]???X2#J
MX?3<(/3G[2#AZ^OAX]X@ZOGDZ>KO_2#CZ>$@]._M(/?QWO/TYR`E<R#A\/P@
M].\@\_3AZ.S\("5S+"#K_./O\B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,38*;7-G:60@(D9A:7(B"FUS9W-T<B`BP=_H\>GO\B(*
M"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S4*;7-G:60@(D9A=&%L($5R
M<F]R.B(*;7-G<W1R("+0[^O](//OXN'Q_"#+W.CO\CHB"@IM<V=I9"`B1F%X
M(@IM<V=S='(@(M;!SB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-S4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("+6Y>+Q[_7<
M\>GO\B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$X"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(L3IW.CE\^<@X^GA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S
M='(@(L3IW.CE\^<@X^GA.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S$W"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("++W^/E\B#B
M\>_WW?(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$X"FUS
M9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(LO?X^7R(/?I[^WO\/3^
M\^7I\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y,C<*;7-G:60@
M(D9I96QD(&UA=')I>"(*;7-G<W1R("+0W^WAZN'R(-#EY-_O]2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE(@IM<V=S='(@(L'QZ>CL_/(@X?'WY=_O]3H@)7,@X?'WY=_O(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&5S(@IM<V=S='(@(L'QZ>CL_/(@X?'WY=_O]3H@)7,@X?'W
MY=_A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0IM<V=I9"`B
M1FEL92!-86YA9V5R(@IM<V=S='(@(L3IX??EZ?'I\_3>\B#!\??EW_GM(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R("*\[>_LX2#!\??EW^_U(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDW.0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B
MQ?#IZ^_CWB#!\??EW^_U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30X,@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B)\'MW>+A\^SA)R#!
M\??EW^_U(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<T
M"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
M)\'MW>+A\^SA)R#!\??EW^_U(.3E[2#U\._S].?QW^;E].'I+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX-@IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R("+6W^OT\>$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Q"FUS9VED
M(")&:7)S="!(86QF(@IM<V=S='(@(M#Q_O3O(,SI\_PB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&
M:7)S="!1=6%R=&5R(@IM<V=S='(@(M#Q_O3O(-3=].'Q].\B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Y"FUS9VED(")&
M:7@@<F%T:6\B"FUS9W-T<B`BT_3AZ.7Q_/(@Z_SC[_(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$T"FUS9VED(")&;&EP
M(@IM<V=S='(@(D9L:7`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")&
M;&]A="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G
M:60@(D9O9R(*;7-G<W1R("+/[-_WZ^<B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`X
M"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`BSR#V
MW.KEZ^_R("5S(.3E[2#U\-SQ]^7I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G
M<W1R("+7\?[LX2#C\=SL[.'T[_(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`BU/'O]MXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*
M;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M(@IM<V=S='(@(L/IX2!"<F]W<V5R<RP@\._U(.3E[2#U\._S].?QW^;O]>T@
MY>GJ_.WE\B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.34*;7-G
M:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("+.Y??<\^'TY2#T
M[^T@ZOGDZ>K\(//A\CLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#,Q"FUS9VED(")&;W)M<R(*;7-G<W1R("+6_/'LY?(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`BT/'\
MXNOE^.<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O
M<G1U;F4@='EP92(*;7-G<W1R("+4_?#O\B#0\?SBZ^7XY_(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@
M(M#Q[^+KW?CEZ?(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G
M:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`BT/'OXNO=^.7I\B`R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Q-`IM<V=I9"`B1F]R=6US(@IM<V=S
M='(@(D9O<G5M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3@*
M;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(M#Q[_GHWO/EZ?(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&
M<B(*;7-G<W1R("+0X2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R("+0
MZ^'?\^GA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT,3<*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G
M<W1R("+0Z^?Q[_;O\=_E\B#$Z>'HY?/I[/STY_3A\B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(W"FUS9VED(")&
M<F5E+T)U<WD@4F5P;'DB"FUS9W-T<B`BP?#<[?3G\^<@Q.GAZ.7SZ>S\].?T
MX?(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0R,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`BP=_T
MY^SA(,3IX>CE\^GL_/3G].'R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HR-S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#$*;7-G:60@(D9R964O0G5S>2!2
M97%U97-T(%)E<W!O;G-E(@IM<V=S='(@(L'PW.WTY_/G(//E(.'?].?LX2#$
MZ>'HY?/I[/STY_3A\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-SD*;7-G:60@(D9R;VTB"FUS9W-T<B`BP?#\(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y-PIM<V=I9"`B1G)O;2!T
M:&4@(@IM<V=S='(@(L'P_"#T[R`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R
M("+![>'K]?3IZMX@T.7QZ>/QX?;>(@H*;7-G:60@(D9U;&P@1&5S8W)I<'1I
M;VXZ(@IM<V=S='(@(L'MX>OU].GJWB#0Y?'IX_'A]MXZ(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@R(&QI8B]";&]C:R]M;V]N+G!H<#HQ.#$*;7-G:60@
M(D9U;&P@36]O;B(*;7-G<W1R("+0Z][QY_(@T^7KWNWG(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS.0IM<V=I9"`B1G5L;"!.86UE
M(@IM<V=S='(@(M#KWO'E\B"\[>_LX2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L;&5R>2#A\/P@
M].?M(._P[]_A(.CA(/#AW_'M[^WTX>D@[^D@Y>GJ_.WE\B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L;&5R>3HB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R("+,Z>KQ_""\[>_LX2(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/
M<'1I;VYS(@IM<V=S='(@(L/E[>GJW?(@Q?#IZ^_CW?(B"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ-@IM<V=I9"`B1V\B"FUS9W-T<B`BS.7TW.+A
M\^<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W)E96-E(@IM<V=S='(@(L7KZ]SD
MX2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")'<F5E:R`H
M25-/+3@X-3DM-RDB"FUS9W-T<B`BQ>OKY^WIZMP@*$E33RTX.#4Y+3<I(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ-S`*;7-G:60@(D=R;W5P($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I\^<@S^S<Y/GM(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+G!H<#HU-PIM<V=I9"`B1W)O=7`@;F%M97,@;75S
M="!B92!N;VXM96UP='DB"FUS9W-T<B`BU.$@[^W\[.'TX2#T^>T@[^S<Y/GM
M(.3E[2#P\=WPY>D@[>$@Y=_MX>D@ZN7MW"(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C(P,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(X-0IM
M<V=I9"`B1W)O=7`@<&5R;6ES<VEO;G,B"FUS9W-T<B`BQ>[O]?/I[^3O]-[S
MY>GR(,_LW.3Y[2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W-B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U.`HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,PIM<V=I
M9"`B1W)O=7!S(@IM<V=S='(@(L_LW.3E\B(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$R-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Q,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDT"FUS9VED(")'=65S="!0
M97)M:7-S:6]N<R(*;7-G<W1R("+)Y.G\].?TY?(@1W5E<W0B"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,C@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR,30*;7-G:60@(D=U97-T('!E<FUI<W-I;VYS(@IM<V=S='(@(LGD
MZ?STY_3E\B!'=65S="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,SD*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R(")'=65S=&)O;VLB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$V-`IM<V=I9"`B2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(M3O(//]\_3G[.$@
MX?7HY>WTZ>KO\._?Y_/G\B!(5%10(.3E(.+QW>CGZN4N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I
M9"`B2&5I9VAT(@IM<V=S='(@(K[X[_(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BPN_>
MZ.7IX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(L+OWNCE
MZ>$@X^GA(/3G(/?QWO/G(/3O]2#JY>GLY>WOX_'<]N_U(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-PIM<V=I9"`B2&5L<&5R(@IM<V=S='(@
M(L+OY^C\\B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M
M:7-P:&5R92(*;7-G<W1R("+'[.GS]N'?\>GO(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3<*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB
M"FUS9W-T<B`BQ>3^(.7?[>'I(.<@X?'WWB#T[_4@X?'WY=_O]3HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"FUS9VED(")(:6=H(@IM
M<V=S='(@(MCGZ]PB"@HC.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H
M<#HS,C(*;7-G:60@(DAI<W1O<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM
M96UP='DB"FUS9W-T<B`BQR#EX^/QX?;>(.GS]._QZ>KO_2#DY>T@\/'=\.7I
M(.WA(.7?[>'I(.KE[=XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C0*;7-G:60@
M(DAO7VUE(@IM<V=S='(@(L'Q]^GJWB#3Y>O?Y.$B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$T-C`*;7-G:60@(DAO;64B"FUS9W-T<B`BP?'W
MZ>K>(-/EZ]_DX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U.`IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(L3IY?WH
M]>WSYR#3\.GTZ>_](@H*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BU.?K
MW?;Y[>\@T_#I].GO_2(*"FUS9VED(")(;W)D92(*;7-G<W1R("+!\??IZMX@
MT^7KW^3A(@H*;7-G:60@(DAO<F1E($QO9VEN(@IM<V=S='(@(L7?\^_D[_(@
M\_3G[2#5\.?QY?/?X2#'R^7J]/'O[>GJ[_T@U.'W]>3Q[^SEW^_U(@H*;7-G
M:60@(DAO<F1E(%-Y<W1E;2(*;7-G<W1R("+3_?/TY^SA("=(;W)D92<B"@IM
M<V=I9"`B2&]R9&4@5VER96QE<W,B"FUS9W-T<B`B)TAO<F1E)R#!\_WQ[.'T
MYR(*"FUS9VED(")(;W)D92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*
M;7-G<W1R("+4[R#P\?SC\>'L[.$@)TAO<F1E)R#DY>T@W??EZ2#Q]>CLZ?/T
MY=\@\_GS]-PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BS_'I
MYOSM].GO\B#*X>W\[>'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM
M<V=S='(@(L_QZ>;\[?3I[R`GX]WLZ?/LX2<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L
M.B(*;7-G<W1R("+/\>GF_.WTZ>\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("+0^?(@
M]NC<\^'TY2#EY/X[("CPX?'AZN'K_B#MX2#T[R#A[>'VW?'E].4@\_3O(.3I
MX??EZ?'I\_3>(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("+0_//E\B#S]-[KY?(@
MZ-WKY?3E(.WA(.7M[_#OZ=[SY?3E.R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(X"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\B"FUS9W-T<B`BT/SSX2#PY>3?X2`H\_3>Z^7R*2#EW^WA
MZ2#EZN7?.R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(M#\\^7R(./QX>SLW?(@Z-WKY?3E
M(.WA(.7M[_#OZ=[SY?3E.R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(X
M"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("+5X_'A\]_A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,PIM<V=I9"`B2'5M:61I='DZ("(*
M;7-G<W1R("+5X_'A\]_A.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(M?I[_7L[_'?\_3A\B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W-B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C(S"FUS9VED("))34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+'(,3G[.GO]?'CW^$@X_'A
M[.SA]._H]?'?Y.'R($E-05`@X?#=]/7WY3H@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HR,C`@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(X.`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`BQR#DZ>'C\>'VWB#C\>'L[.'T[^CU\=_DX?(@
M24U!4"#A\-WT]??E.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$X,R!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,P
M"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("+'(,3G[.GO]?'CW^$@\.7I\>_QZ?/L_NT@*'%U;W1A*2#C
M\>'L[.'T[^CU\=_DX?(@24U!4"#A\-WT]??E.B`E<R(*"FUS9VED("))3D)/
M6"(*;7-G<W1R("+%Z?/E\??\[.7MX2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S,3$*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`MQ.GE
M_>CU[?/G(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX
M,@IM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))
M4"W$Z>7]Z/7M\^<@Y.7M(.7?[>'I(.3IX>C=\^GLYRXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.CDT"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"W$
MZ>7]Z/7M\^<@[.<@Y?#I]/'E\/3>(.S=\^$@\^4@0TE$4BU";&]C:RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#0*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`BRNOE
MW^3Y[.$MT.'QX>+?X?/G($E0+B(*"FUS9VED("))7VYB;W@B"FUS9W-T<B`B
MQ>GSY?'W_.SE[>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R
M92(*;7-G<W1R("+%Z?/AX_GCWB##\>'L[-[R(-#QZ>TB"@IM<V=I9"`B26-O
M;G,@3VYL>2(*;7-G<W1R("+,_.WO(,7IZN_MW^3IX2(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HT.0IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@
M(L7IZN_MW^3IX2#CZ>$@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S8Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`BQ>GJ[^W?Y.GA
M(.KAZ2#*Y=_LY>WO(@H*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T
M<B`BS^WO[.$@].'U]/STY_3A\CHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HV,#@*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y
M960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB
M"FUS9W-T<B`BP>T@Y.7M(.7L]N'MW^;E].'I(//Y\_3<+"`E<R#CZ>$@[>$@
MX>WOW^[EZ2#SY2#MW>\@\.'QW.CU\>\N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0S.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+B(*;7-G<W1R("(B"B+![2#DY2#BZ]WPY?3E(.KA[=WMX2#EZ>KO[=_DZ>\@
M]_'G\^GL[_#OZ?[M].'R(/3O[2!);G1E<FYE="!%>'!L;W)E<BP@W_/Y\B`B
M"B+P\=WPY>D@[>$@]//EZMSQY?3E(.7D_B#CZ>$@[>$@X?#E[>7QX^_P[^G>
M\^7TY2#TYR#DZ>'VW.WEZ>$@4$Y'+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ-3@*;7-G:60@(B(*(DEF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W
M<V5R+B(*;7-G<W1R("(B"B+![2#BZ]WPY?3E(.'U]/P@].\@[-[M]>SA(/?Y
M\=_R(.7IZOSMX2P@YR#EZ>K\[>$@\._U(.C=Z^7TY2#MX2#JX?3EXMSSY?3E
M(.3E("(*(NSP[_'EWR#MX2#E[/;A[>GSZ.7?(.'P_"#T[^T@8G)O=W-E<B#S
MX?(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R
M("+0\>_E\.GSZOSPZ?/G(,7IZOSMX?(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@
M55),(@IM<V=S='(@(E523"#%Z>K\[>'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`BQ>GJ_.WA(.'P_"!'86QL97)Y
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S
M='(@(L7IZOSMX2#A\/P@1V%L;&5R>3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S0X"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`BP?#O
M\_3OZ]X@Q>GJ_.WA\B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS
M9VED("));6%G97,B"FUS9W-T<B`BQ>GJ_.WE\B(*"FUS9VED("));7!O<G0B
M"FUS9W-T<B`BQ>GSX>/YX]XB"@IM<V=I9"`B26UP;W)T($5R<F]R.B`B"FUS
M9W-T<B`BR]SH[_(@ZN'TW"#TY^T@Q>GSX>/YX]XZ("(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C$P"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DEM<&]R="P@4W1E<"`E
M9"(*;7-G<W1R("+%Z?/AX_GCWBP@PM[LX2`E9"(*"B,@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z,C`L(&,M9F]R;6%T"B,Z('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C(P"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS
M9W-T<B`BT.7DW^\@\._U(.7I\][WZ.<Z("5S(@H*;7-G:60@(DEM<&]R=&5D
M(&9I96QD<SHB"FUS9W-T<B`BT.7DW^$@\._U(.7I\][WZ.?SX>TZ(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#$*
M;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T<B`BT^4@Q?#E[N7QX^'SW^$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(L7I\^'C
M^>/>(,/QX>SLWO(@S.7TW"(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$T,0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E
M(&=I=F5N+B(*;7-G<W1R("+$_.CGZN4@Z]SH[_(@ZOGDZ>K\\B#E[=WQX^7I
MX?(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-3<*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(LO<Z._R(/SM[^SA(/?QWO/TYR#>+^KAZ2#J^>3I
MZOSR+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED
M("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(LO<Z._R(/SM
M[^SA(/?QWO/TYR#>(.7MX>OKX>KTZ>K>(.3IY?WH]>WSYRX@SN'MX>3OZNGL
MW//TY2#>(.7PZ>KOZ>WY[=[S].4@[.4@(@HB].\@Y.GA]^7I\>GS]-X@X^GA
M(/#E\>'I]-WQ^2#B[][HY>GA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*
M;7-G<W1R("+!_>[G\^<@T.7QZ>CY\=_O]2(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$T,2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T,`IM<V=I
M9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("+)Y.GAW_3E\>_I(-?QWO/T
MY?(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<R"FUS9VED("));F9O(@IM<V=S='(@(M#KY_'O]N_QW^7R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T.0IM<V=I9"`B26YF;W)M871I;VXB
M"FUS9W-T<B`BT.OG\>_V[_'?Y?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!#
M7V]L=6UN($%F=&5R(@IM<V=S='(@(L7I\^'C^>/>(-/TWNOG\B#,Y?3<(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`BQ>GSX>/Y
MX]X@Q>GJ_.WA\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("+%Z?/A
MX_GCWB#0W^WAZN$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B
MQ>GSX>/YX]X@\_WMY.7SY_(@5V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED("));G-E<G0@
M7T-O;'5M;B!"969O<F4B"FUS9W-T<B`BQ>GSX>/YX]X@T_3>Z^?R(-#QZ>TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(L7I\^'C^>/>(.W=X?(@\_3>Z^?R(.SE
M]-P@].?M(/3QW??O]?/A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BQ>GSX>/Y
MX]X@[=WA\B#S]-[KY_(@\/'I[2#A\/P@].?M(/3QW??O]?/A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("+%Z?/AX_GCWB#MW>'R(./QX>SLWO(@[.7TW"#TY^T@]/'=
M]^_U\^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C`*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+%Z?/AX_GCWB#MW>'R(./QX>SL
MWO(@[.7TW"#TY^T@]/'=]^_U\^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(L7I
MX>/YX]X@\.'QX>/QW/;O]2#LY?3<(/3O[2#T\=WW[^WTX2#J_.SB[R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV.`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E(@IM<V=S='(@(L7I\^'C^>/>(/#A\>'C\=SV[_4@\/'I[2#T
M[^T@]/'=]^_M].$@ZOSLXN\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U
M,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("+%
MZ?/AX_GCWB#E[>'KZ^'J].GJ[_T@\/'O]/WP[_4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C(S"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S
M<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB
M"FUS9W-T<B`B(@HBQ/[S].4@96UA:6P@Y.GE_>CU[?/G(//TY^T@[_#OW^$@
MY?#IZ/7LY=_TY2#MX2#PX?'AZ]SBY?3E(/3O(.W=[R#SX?(@ZOGDZ>K\.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(L7I\^'C
M^>/>(.KEZ^GO_2#LY?3<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F
M;W)E(@IM<V=S='(@(L7I\^'C^>/>(.KEZ^GO_2#P\>GM(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I
M9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("+%Z?/AX_GCWB#S]-[K
MY_(@[.7TW"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM
M<V=S='(@(L7I\^'C^>/>(//TWNOG\B#P\>GM(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(DEN<V5R="!M97-S
M86=E<R(*;7-G<W1R("+%Z?/AX_GCWB#LY^W][.'T[_(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`BQ>GSX>/YX]X@
M\.'QX>/QW/;O]2#LY?3<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED("));G-E<G0@<&%R86=R
M87!H(&)E9F]R92(*;7-G<W1R("+%Z?/AX_GCWB#PX?'AX_'<]N_U(/#QZ>TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(L7I\^'C
M^>/>(./QX>SLWO(@[.7TW"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F
M;W)E(@IM<V=S='(@(L7I\^'C^>/>(./QX>SLWO(@\/'I[2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,30*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B
MQ>GSX>/YX]X@].?R(.'PX>GT[_WLY>WG\B#A\-SM].?SY_(@\_3G[2#E\?[T
MY_/G(.'S]N'KY=_A\CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM
M<V=S='(@(L7I\^'C^>/>+\3I_/'H^?/G(,7IZOSMX?(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`BQ>GSX>/YX]XOQ.G\\>CY\^<@T_WM
MY.7SY_(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8V.`IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD
M('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BS.<@Y?#A\>K=
M\B#U\/SK[^GP[R#CZ>$@X?#O\_3OZ]X@\_3G(.O?\_3A(.3IX>WO[-[R+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C8P"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("+,YR#E
M\.'QZMWR(/7P_.OOZ?#O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-CD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`BP>K=\>'I[_(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(W"FUS9VED("));G1E9V5R(&QI
M<W0B"FUS9W-T<B`BR]_S].$@P>KE\>'?^>TB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(X,PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,U,@IM<V=I9"`B26YV
M86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*;7-G
M<W1R("+%\.GKW>[A].4@R]SH[_(@Q>W=\>/EZ>$@X^DG(.'U]/P@].\@\_7S
M].'TZ>K\+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2XB"FUS9W-T<B`BP>KU\>\@541(+B`H57-E<B!$871A($AE861E
M<BDN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV
M86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`BS.<@W>/J]?'G(.7VX?'L[^/>
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,R,0IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`BP>KU
M\>\@0F%T8V@M240N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Q"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(X
M,`IM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`BT_3<
MZ^CGZN'M(.O<Z._R(.3EY._LW>WA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("+!ZO7QYR#DZ>7]Z/7M\^<@
M\/'O[_'I\^SO_2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HX-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HQ,#,*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,C(S"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(LSG
M(-WCZO7QYR#L[_'VWB#A\??EW^_U(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$V"FUS9VED("));G9A;&ED(&US
M9U]T>7!E+B(*;7-G<W1R("+,YR#=X^KU\>\@;7-G7W1Y<&4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("+,YR#=
MX^KU\>\@WB#KY=_PY>D@87!I7VED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(LSG(-WCZO7QY?(@WB#E
MZ^OI\.7?\B#PX?'<[.7T\>_I+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HT,PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(LSG(-WCZO7Q[R#P\?GT_.KO
MZ^OO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z.3$*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B`G)7,G(@IM<V=S
M='(@(LSG(-WCZO7Q[_(@\.'QX>O>\/3G\CH@)R5S)R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3`W,2!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-#@*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@
M(LSG(-WCZO7Q[R#J[^GM_/?QY_/T[R#A[?3IZN7?[.7M[R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I
M9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`BS.<@W>/J]?'G
M(.'Q]^GJWB#DZ>7]Z/7M\^<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(P"FUS9VED("));G9A;&ED('5N:6-O
M9&4@9&%T82XB"FUS9W-T<B`BS.<@W>/J]?'A(.3EY._LW>WA(%5N:6-O9&4N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B26YV
M96YT;W)Y(@IM<V=S='(@(LKA]-SK[^/O\B#5\.'Q]_SM]/GM(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))
M=&%L:6,B"FUS9W-T<B`BT.OAX^GA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,W-`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B
MR>'M[_7<\>GO\B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(LGO_>OI[_(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<Y"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,38*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B
M2G5N92(*;7-G<W1R("+)[_WMZ>_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*
M;7-G<W1R("+%]>CUX_'<[.SI\^<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#
M96YT97(B"FUS9W-T<B`BQ?7H]>/QW.SLZ?/G(//T[R#*W>WT\>\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(M#KWO'G\B#%]>CUX_'<
M[.SI\^<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(L7U
MZ/7C\=SL[.GSYR#!\>GS].7QW"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I
M9VAT(@IM<V=S='(@(L7UZ/7C\=SL[.GSYR#$Y>[IW"(*"FUS9VED(")+86QA
M;6%T82!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,KAZ^'LW/3A\B(*
M"FUS9VED(")+87)P871H;W,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA
M\B#*X?'PW.CO]2(*"FUS9VED(")+87-T;W)I82!!:7)P;W)T(@IM<V=S='(@
M(L'E\>_KZ>S=[>'R(,KA\_3O\>G<\B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME97`@;W)I9VEN86P_
M(@IM<V=S='(@(LWA(.KQX?3>\_D@].\@X?7HY>WTZ>K\.R(*"FUS9VED(")+
M969A;&AN:6$@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#*Y?;AZ^_M
MZ=SR(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-PIM<V=I
M9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")+97)B97)O<RU397)V97(@X?'MWNCGZN4@].?M(.'UZ.7M].GJ
M[_#OW^?SYRXB"@IM<V=I9"`B2V5R:WER82!!:7)P;W)T(@IM<V=S='(@(L'E
M\>_KZ>S=[>'R(,K=\>KU\>'R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("+-W>$@X?#\($ME
M<FYE;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y-PIM
M<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(L3G[.GO]?'CW^$@RNOEZ>3I
M[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G
M:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("+!\._T_?#Y[.$@RNOEZ>3I
M[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3@*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`BS-[J[_(@RNOEZ>3I[_TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3<*;7-G:60@(DME>2!4
M>7!E(@IM<V=S='(@(M3]\._R(,KKY>GDZ>_](@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C(*;7-G:60@(DME>2!5<V%G92(*;7-G
M<W1R("+7\=[SYR#*Z^7IY.GO_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<T,PIM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+4[R#JZ^7IY-\@]?#<\??E
MZ2#>Y.<@\_3O[2#E[O7PY_'E].?TWB#DY^S\\^GY[2#JZ^7IY.G^[2XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T
M<B`BT.'IY.G<(@H*;7-G:60@(DMO<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_K
MZ>S=[>'R(,KY(@H*;7-G:60@(DMO>F%N:2!!:7)P;W)T(@IM<V=S='(@(L'E
M\>_KZ>S=[>'R(,KOYMSMY_(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`BQ.G<].'NYR(*"FUS9VED
M("),87)I<V$@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#+W/'I\^'R
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3&%S="!(86QF
M(@IM<V=S='(@(M3EZ^7U].'?[R#,Z?/\(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@X(&QI8B]";&]C:R]M;V]N+G!H<#HY,`IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(M3EZ^7U].'?[R#4W?3A\?3O(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-#D*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B
MU.7KY?7TX=_A(,7MY^S=\?GSYSHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HV.3$*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(M3EZ^7U
M].'?X2#%W_/OY._R(//TY^T@]?#G\>7SW^$Z("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-CDS"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M
M("5S(@IM<V=S='(@(M3EZ^7U].'?X2#%W_/OY._R(//TY^T@]?#G\>7SW^$Z
M("5S(.'P_"`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C8X.`IM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`BU.7KY?7TX=_A(,7?
M\^_D[_(@\_3G[2#U\.?QY?/?X3H@T._TW2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(LW\[._R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS
M9VED("),87EO=70B"FUS9W-T<B`BQ.G<].'NYR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`BP?;>\_3E(.KE[?P@X^GA(.WA
M(.SG[2#U\-SQ]^_U[2#PY?'IZ/[QZ>$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS
M9W-T<B`BP?'I\_3E\=PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3`S"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("+!\>GS].7QWB#%\.GJ
MY?;AZ]_DX2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3D*;7-G
M:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(L'QZ?/TY?'=\B#4Z>S=\B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS
M9W-T<B`BT.7M]-SS].GW[R(*"FUS9VED("),:6UN;W,@06ER<&]R="(*;7-G
M<W1R("+!Y?'OZ^GLW>WA\B#+WNSM[_4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#`Q"FUS9VED("),:6YK(@IM<V=S='(@(M/][>3E\^<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-38*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("+3_>WDY?/G
M(/#O]2#DY=_W[>7I(//E.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-3@*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`BT_WMY.7SYR#T
MY_(@Y.GE_>CU[?/G(./IX2#<[>_IX^SA(/#A\>'H_?'O]2#S_>WHY?/G\CLB
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP
M:'`Z,38R"FUS9VED("),:6YK<R(*;7-G<W1R("+3]>WDW?/EZ?(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*
M;7-G<W1R("),:6YU>"U#;V]K:64B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W0@+2#/(/?QWO/TY_(@[/#O\>7?
M(.WA(.3EWR#T[R#VW.KEZ^\B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,X
M"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("++W_/TX2#"W//E^>T@
MQ.7D[^S=[?GM(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G
M:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BR]_S].$@Z.7LW/3Y[2#"
M[][HY>GA\B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S<*;7-G:60@(DQI
M<W0@5&%B;&5S(@IM<V=S='(@(LO?\_3A(-#I[=SJ^>TB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C0*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(L<@Y.?LZ>_U\>/?X2#KW_/TX?(@
M]_'G\_3^[2#=]^7I(.'PY>WE\>/O\._IY^CEWRXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@V"FUS9VED("),;V%D:6YG
M+BXN(@IM<V=S='(@(M;\\?3Y\^<N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B
MU._PZ>K>(+_QX3H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS
M9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`BU/SP[_(@ZN'I(/[QX2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<P(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU,`HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV,PIM<V=I9"`B3&]C
M871I;VXB"FUS9W-T<B`BU/SP[^CE\]_A(@H*;7-G:60@(DQO9R!I;B(*;7-G
M<W1R("+%W_/OY._R(@H*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BN.[OY._R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@
M5&%S:W,B"FUS9W-T<B`BQ.GE\>/A\]_E\B#EZ?/\Y._U(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.34R"FUS9VED("(B"B),;V=I;B!F86EL960@
M9F]R('-O;64@<F5A<V]N+B!-;W-T(&QI:V5L>2!Y;W5R('5S97)N86UE(&]R
M('!A<W-W;W)D('=A<R`B"B)E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"B+'(.7?\^_D[_(@P?#=]/7WY2X@T.GHX>W\].'TX2#D_.CGZN4@Z]SH
M[_(@].\@O.WO[.$@U_'>\_3G(-X@[R#*^>3IZOSR+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDT.`IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G
M<W1R("+%W_/OY._R(,'PW?3U]^4N(@H*;7-G:60@(DQO9V]U="(*;7-G<W1R
M("*X[N_D[_(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Q"FUS
M9VED("),;VYG('1E>'0B"FUS9W-T<B`BS.7CW.OO(,KEW^SE[>\B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B
MP>/<\.<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4Y"FUS
M9VED("),;W<B"FUS9W-T<B`BU^'LY^O\(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W
M97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("+,Z>KQW"#%Z^OG[>GJW"#C\=SL
M[.'TX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS
M9W-T<B`BS.GJ\=P@Z^'TZ>WIZMP@X_'<[.SA].$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED
M("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(LSIZO'<(-'Y[.'ZZMX@
MP?'?Z.SG\^<B"@IM<V=I9"`B34TB"FUS9W-T<B`BS,PB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(LSAX^GJ
M_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW,0IM<V=I9"`B36%I
M;"(*;7-G<W1R("+!Z^OGZ^_C\>'VW^$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3$T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(L3IX??E
MW_'I\^<@16UA:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#`*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS
M9W-T<B`BQ.?LZ>_U\>/?X2#3_>WDY?/G\BXN+B(*"FUS9VED("(B"B)-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+B(*;7-G<W1R("+$Z>'WY=_QZ?/G(.KA].?C[_'I_NT@
MZN'I(/?Q^>S<]/GM(/#O]2#HX2#E[/;A[=_F[^WTX>D@X?7TW?(N(@H*;7-G
M:60@(DUA;G5A;"(*;7-G<W1R("+%X_?EZ?'?Y.GO(@H*;7-G:60@(DUA<"!$
M871E(&%N9"!4:6UE($9I96QD<R(*;7-G<W1R("+0Y>3?X2#'[.7Q[^SG[=_A
M\B#JX>D@O_'A\B(*"FUS9VED(")-87`@26UP;W)T($9I96QD<R(*;7-G<W1R
M("+0Y>3?X2#EZ?/AX_GCWO(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S<V"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`BS-SQ].GO
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R("*\\>GO(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(DUA
M<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("+,X?'JW/'I\^SA
M(.SE(-WMY.7I[N<@P>WAX^WY\^S=[>_U+\SG(.'MX>/M^?/LW>WO]2(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R("+,X?'JW/'I\^SA(.SE(-SKZ^<@W>WDY>GNYR`H\"[W
M+B#3Y^SA[?3IZOPOP?#A[?3G[-WM[RDB"@IM<V=I9"`B36%T8VAI;F<@9FEE
M;&1S(@IM<V=S='(@(M#EY-_A(/#O]2#TX>GQZ=SF[_7M(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(T"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(LS=X^GS].<@Y?#I]/'E
M\/3>(/#?\_3Y\^<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$W"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"XB"FUS9W-T<B`BU?#=\>+A\^<@[_'?[_4@[.?M_>SA]._R+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`T"FUS9VED(")-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`BS-WCZ?/TYR#HY?'L[^KQX?/?X2#T
MY>OE]?3AW_GM(#(T(/GQ_NTZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDV"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("+,
MW>/I\_3G(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@-B#Y\?[M.B`B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(P.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,P"FUS
M9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("+,W>/I\_3O(.S>ZN_R(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G
M:60@(DUA>2(*;7-G<W1R("+,W.GO\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3,Q"FUS9VED(")-965T:6YG($-A
M;F-E;&QA=&EO;B(*;7-G<W1R("+!ZOWQ^?/G(-/U[=SM].?SY_(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,PIM
M<V=I9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R("+0Z^?Q[_;O\=_E
M\B#3]>W<[?3G\^?R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU,#D*;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS
M9W-T<B`BT/'\].'SYR#CZ>$@T_7MW.WTY_/G(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,C4*;7-G:60@(DUE971I
M;F<@4F5P;'DB"FUS9W-T<B`BP?#<[?3G\^<@X^GA(-/U[=SM].?SYR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$T
M"FUS9VED(")-965T:6YG(%5P9&%T92(*;7-G<W1R("+%[>?LW?'Y\^<@X^GA
M(-/U[=SM].?SYR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3$Y"FUS9VED(")-965T:6YG(%5P9&%T92!297%U97-T
M(@IM<V=S='(@(L'?].?LX2#E[>?LW?'Y\^?R(./IX2#3]>W<[?3G\^<B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$Y"FUS9VED(")-
M96UB97)S(@IM<V=S='(@(LS=Z^<B"@IM<V=I9"`B365M;W,B"FUS9W-T<B`B
MT^?LY>G^\^7I\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C(*;7-G
M:60@(DUE;G4@;6]D93HB"FUS9W-T<B`BRN'TW//TX?/G(,SE[>_].B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(M/UX_?^[>7U\^<@ZN7K
MZ?[M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HS,@IM<V=I9"`B365S<V%G92(*;7-G<W1R
M("+,WNWU[.$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(R-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@
M8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB
M=F5R:69I960N(@IM<V=S='(@(B(*(M3O(.S>[?7LX2#E\.GBY>+AZ?[HY^KE
M(.7PZ?3U]_[R+"#AZ^O<(/3O(/#I\_3O\._IY_3IZOP@]._U(/7P[^/QW/;O
M[?3A(.3E("(*(NSP[_'EWR#MX2#E\.GBY>+AZ?GHY=\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Y"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(M3O(.S>[?7LX2#=Z^?NY2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8R-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,S,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C8X"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B
MU/WP[_(@[.?M_>SA]._R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS
M9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(LKAZ?'\\B#A\/P@365T87(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$P"FUS9VED("(B
M"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-S`@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(LS=
MZ._D[_(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@R(&9R
M86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PIM<V=I9"`B365T:&]D("<E
M<R<@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`BQR#,W>COY._R("<E<R<@Y.7M
M(._QW_/HY^KE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S,*;7-G:60@(DUE=')I8R(*;7-G<W1R
M("+,Y?3QZ>K\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`BS.7SX=_O
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z-#$*
M;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-:6UE(%1Y<&4B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P.`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(LSIZO'\].7QYR#HY?'L[^KQX?/?X2#TY>OE]?3A
MW_GM(#(T(/GQ_NTZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`P"FUS
M9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("+,Z>KQ_/3E
M\><@Z.7Q[._J\>'SW^$@].7KY?7TX=_Y[2`V(/GQ_NTZ("(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,3<*;7-G:60@(DUI
M<G)O<B(*;7-G<W1R("+*X>CQW?#TY_(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`BQ.G<]N_Q
MX2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-CDW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T.0IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+B(*;7-G<W1R(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E
M<75E<W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P-0IM<V=I9"`B
M(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I
M;VXN(@IM<V=S='(@(B(*(LOEW_#EZ2#T[R!C;VYF:6=U<F%T:6]N+B#0\=WP
MY>D@[>$@].\@Y.?LZ>_U\>/>\^7TY2#A[2#HW>OE].4@[>$@]_'G\^DM(@HB
M[._P[^G>\^7TY2#A]?3>(/3G[2#E]N'Q[._CWBXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DUI
M<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`BR^7?\.7I(/3O($E$(/3O]2#L
MY^W][.'T[_(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-3<*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN(@IM<V=S='(@(DUI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED(")-:7-S:6YG('-E<W-I;VX@
M240N(@IM<V=S='(@(LOEW_#EZ2#T[R!)1"#TY_(@\_WMY.7SY_(N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I
M9"`B36\B"FUS9W-T<B`BQ.4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3(R"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")%;6%I;"#*Z>WG
M]-[R(-3GZ^7V^>W?X?(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("+,W?3QZ>_R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV.2!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A
M=&4B"FUS9W-T<B`BQ^SE\>_LY^W?X2#T\>_P[_#OW^?SY_(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*
M;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`BU/'O\._P[]_G\^<@55),(@H*
M;7-G:60@(DUO;G1H(%9I97<B"FUS9W-T<B`BQ>SVW.WI\^<@S-[MX2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#8*;7-G:60@(DUO;G1H(&%N
M9"!Y96%R(@IM<V=S='(@(LS>[>'R(.KAZ2#=]._R(@H*;7-G:60@(DUO;G1H
M;'D@179E;G1S($QI<W0B"FUS9W-T<B`BS.?MZ>'?X2#+W_/TX2##Y>/O[?ST
M^>TB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C,V"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(LSG[>GAW^$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@
M(DUO;VX@4&AA<V5S(@IM<V=S='(@(M;<\^7I\B#3Y>O>[>?R(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#(P"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`BRM_MY_/G(.K<]/DB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HT,C0*;7-G:60@(DUO=F4@3&5F="(*;7-G
M<W1R("+*W^WG\^<@X?'I\_3E\=PB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HT,C@*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B
MRM_MY_/G(.3E[NG<(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-#$V"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(LK?[>?SYR#PW.WY
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y
M-PIM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(LK?[>?SYR#JW/3Y(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DW"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(LK?[>?SYR#PW.WY(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$V-PIM<V=I9"`B375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S(@IM<V=S='(@(M#OZ^OA\.O=\B#KW_/TY?(@Y?#IZ^_CWO(@
M*.KA].'Q\=SJ].7R*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,C4*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("+0[^OKX?#K
MWB#E\.GK[^/>(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-"!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")->2!!8V-O=6YT
M(@IM<V=S='(@(L\@R^_CX?'IX?/L_/(@[._U(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VEN9&5X+G!H<#HU,0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(L\@
MZ?/T_/3O\/SR(.SO]2`H<&]R=&%L*2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E
M9&ET+G!H<#HQ,C0*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B
MQR#E[/;<[>GSYR#T[_4@Z?/T_/3O\._](.SO]2`H<&]R=&%L*2(*"FUS9VED
M(")->2!3=6UM87)Y(@IM<V=S='(@(L<@T.7QW^OG^.<@[._U.B(*"FUS9VED
M(")->71I;&EN:2!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,SU].?K
MWNWG\B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T
M=&]M+FEN8SHW"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B
MS]?)+"#$Q2#S]>SV^>W^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,SDW(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z
M-#$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU.#,*;7-G:60@(DYA;64B"FUS9W-T<B`BO.WO[.$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<P-@IM<V=I9"`B
M3F5E9',@06-T:6]N(@IM<V=S='(@(L'PX>GTY=_TX>D@Y>W=\>/EZ>$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0R"FUS9VED(").971W;W)K
M(@IM<V=S='(@(L3?ZO3U[R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$Y"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(DYE=F5R(@IM<V=S='(@(M#O
M]-TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHR-PIM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(LW=X2#*X?3G
MX^_QW^$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO
M;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-SD*;7-G:60@(DYE=R!-
M;V]N(@IM<V=S='(@(LW=X2#3Y>O>[><B"@IM<V=I9"`B3F5W(%!A<W-W;W)D
M(@IM<V=S='(@(LW=[_(@ROGDZ>K\\B(*"FUS9VED(").97<@4&%S<W=O<F0@
M*&%G86EN*2(*;7-G<W1R("+-W>_R(,KYY.GJ_/(@*.[A[=PI(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S
M97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`BS=WO(/SM[^SA(-?QWO/TYR`H
M\/'OX>GQY?3IZOPI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G
M<W1R("+-W>\@\.'QW.CU\>\@*.KE[?PI(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(DYE=W,B"FUS9W-T<B`BS=WA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-@IM<V=I9"`B3F5W
M<V=R;W5P<R(*;7-G<W1R("+/[-SDY?(@X^GA(.W=X2`H;F5W<V=R;W5P<RDB
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHR,2!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHT-@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$S-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHS,@IM<V=I9"`B
M3F5X="(*;7-G<W1R("+%\/SLY>WO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A
M9V5R+G!H<#HQ,34@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,38*;7-G
M:60@(DYE>'0@4&%G92(*;7-G<W1R("+%\/SLY>WG(-/EZ]_DX2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="!0:&%S92(*;7-G<W1R
M("+%\/SLY>WG(-;<\^<B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,V-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,`IM<V=I
M9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(L7P_.SE[>7R(,7PZ>OOX]WR(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X.`IM
M<V=I9"`B3F\B"FUS9W-T<B`BS_?I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+V1I9F8N:'1M;#HQ-@IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B
MQ.7M(/7PW/'WY>D@Y.GAZ-WSZ>SO(&-O;F9I9W5R871I;VX@X^GA(.WA(.3E
MW^[Y(.3IX?;O\=WR+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z,3$Q"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("+$Y>T@]?#<\??EZ2#D
MZ>'HW?/I[.<@\_3QX?3GX^GJWB#CZ>$@Y.?LZ>_U\>/?X2!)4T\@:6UA9V5S
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,R,@IM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(L3E
M[2#U\-SQ]^7I(/#Q_/3U\.\@X^GA($)A=&-H+B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<X(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HR-#8*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N(@IM<V=S='(@(L3E[2#U\-SQ]^7I($)L;V-K(//T
MY^T@X>GT[_WLY>WG(.C=\^<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC
M86PN<&AP.C4T"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+$Y2#D_.CGZN4@_.WO
M[.$@X^GA(.'UZ.7M].GJ[_#OW^?SYR!-0T%,+B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C4U"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(L3E[2#U
M\-SQ]^_U[2#AZ^OAX]WR+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,30T"FUS9VED(").;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@
M8F4@861D960@8F5L;W<@=&AI<R!L979E;"XB"FUS9W-T<B`BQ.4@[/#O\>_]
M[2#MX2#P\>_S].7H[_WM(.7N[_7SZ>_D[_3>\^7I\B#JW/3Y(.'P)R#A]?3\
M(/3O(.7PW_#EY.\N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8Q
M"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M
M:7-S:6]N+B(*;7-G<W1R("+$Y>T@[/#O\>_][2#MX2#P\>_S].7H[_WM(/7P
M[^KA].?C[_'?Y?(@\^4@X?7TWB#TY^T@Y>[O]?/I[^3\].?SYRXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,R!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C0Y,PHC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-3,*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RXB"FUS9W-T<B`BQ.7M(._QW_/HY^KA[2#PZ^?Q[_;O\=_E\B#Q
M]>CLW_/E^>T@X^GA("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S<S"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`BQ.7M(._QW_/HY^KA[2#P
MZ^?Q[_;O\=_E\B#Q]>CLW_/E^>T@X^GA($944"!61E,N(@H*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!,1$%0
M(%!R969E<F5N8V5S+B(*;7-G<W1R("+$Y>T@W??O]>T@\?7H[.GS].7?(._I
M(/#KY_'O]N_QW^7R(./IX2#TY^T@]?#G\>7SW^$@RN'TX>O\X^_U+B(*"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,($-A=&5G;W)I97,N(@IM<V=S='(@(L3E[2#=]^_U[2#Q]>CLZ?/T
MY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3I\B#JX?3GX^_QW^7R(/3G\B!344PN
M(@H*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@4')E9F5R96YC97,N(@IM<V=S='(@(L3E[2#=]^_U[2#Q
M]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3I\B#P\>_TZ>S>\^7I\B#T
MY_(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-3DU"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,(%9&4RXB"FUS9W-T<B`BQ.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#P
MZ^?Q[_;O\=_E\B#CZ>$@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z-S0Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R
M("+$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2!344PM
M1FEL92!61E,N(@H*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(L3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3G[2#A
M]>CE[?3IZN_P[]_G\^<@\_3G[2!344PN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(S"FUS9VED(").;R!C<F5D
M:70@;&5F="XB"FUS9W-T<B`BQ.7M(-WLY>GMY2#PW_/T^?/G+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C4Y"FUS
M9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`BQ.4@Y/[S
MX?3E(/#Q[^_QZ?/L_"XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX.3(*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`BQ.4@
M]N_Q]/[HY^KA[2#A\??EW^$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("+$Y2#B\=WHY^KA
M[2#EZ>KO[=_DZ>$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$P,B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,C$*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T
M<B`BQ.7M(._QW_/HY^KE(/3O\._HY?/?X2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U.`IM<V=I9"`B3F\@;65S
M<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`BQ.4@Y/[SX?3E(.S>[?7LX2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V
M,0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(L3E[2#O\=_S
MZ.?JY2#\[>_LX2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8V,@IM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB
M"FUS9W-T<B`BQ.7M(._QW_/HY^KE(.'QZ>CL_/(N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`BQ.7M(/7PW/'W[_7M(.3U\]SQY?/TY?(@\/'OXNO=^.7I\B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$Y"FUS9VED
M(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(L3E[2#EZNKQY>SO_>T@
MY=_S[^3OZ2XB"@IM<V=I9"`B3F\@<')E9F5R96YC97,@87)E(&%V86EL86)L
M92XB"FUS9W-T<B`BS^D@\/'O].GLWO/EZ?(@Y.7M(.7?[>'I(.3IX>C=\^GL
MY?(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`BQ.7M(/7PW/'W
M[_7M(.KA[?SMY?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R("+$
MY>T@]?#<\??O]>T@\.OE]?'=\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,3(*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A
M:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`BQ.7M(/7PW/'WY>D@\/'O\_GQ
MZ>W\\B#W_O'O\B#CZ>$@[.W>[.<@8V%C:&4N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-38*;7-G:60@(DYO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("+$Y>T@Y/SH
MY^KE(/SM[^SA(/?QWO/TYR#>+^KAZ2#J^>3IZOSR+B(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,30Q"FUS9VED(").;R!V86QI9"!834P@
M9&%T82!R971U<FYE9"(*;7-G<W1R("+$Y>T@Y?#I\_3QW/;GZN'M(-WCX_7Q
MX2!834P@Y.7D[^S=[>$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDQ-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3,T"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`BQ.7M(/7P
MW/'W[_7M(/3I[-WR(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q,`IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L3E(.+Q
MW>CGZN4@W>KD[_/G(//T[R#A\??IZOP@8V]N9FEG=7)A=&EO;BX@SN'MX>3G
M[.GO]?'CWO/TY2#T[RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$X
M"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+$Y2#B\=WH
MY^KE(-WJY._SYR#S].\@X?'WZ>K\(//A\B!C;VYF:6=U<F%T:6]N+B#.X>WA
MY.?LZ>_U\>/>\_3E(/3O+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C`T"FUS9VED(").;VX@4&%R=&EC:7!A;G0B
M"FUS9W-T<B`BRN'MW>WA\B#3]>SLY?3=]_GM(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHX.`IM<V=I9"`B3F]N92(*;7-G<W1R
M("+*X>SLW^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@
M(LKA[=WMX2`HU_'>\^<@\/'OZN'H[_'I\^S=[>_U*2(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO
M<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`BPOSQY>GO(,?LZ?/VX=_QZ>\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`IM<V=I
M9"`B3F]T($%F=&5R(@IM<V=S='(@(KSWZ2#,Y?3<(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*;7-G:60@(DYO="!"969O<F4B
M"FUS9W-T<B`BO/?I(-#QZ>TB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS-3<*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("+$Y>T@
MY=_MX>D@ZN'TW.OOX^_R(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HV-PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HY-0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C0Y"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-C`*;7-G
M:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`BQ.7M(-WWY>D@[^OOZNOG
M\?GHY=\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R("+$Y>T@W??IY2#TY>CE
MWR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.#0@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(P,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C(Q(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR,S@*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(U-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C<Q"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR.#D@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R-0HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S@X(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HT-S(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4T-"!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-38R"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R("+$Y>T@]?#O\_3G\=_FY?3E+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#<@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$U.0IM<V=I9"`B3F]T97,B"FUS9W-T<B`BT^?LY>G^\^7I\B(*"FUS
M9VED(").;W1E<SHB"FUS9W-T<B`BT^?LY>G^\^7I\CHB"@IM<V=I9"`B3F]T
M97,@4W5M;6%R>2(*;7-G<W1R("+3Y^SEZ?[SY>GR("T@T.7QW^OG^.<B"@IM
M<V=I9"`B(@HB3F]T97,@:7,@86X@87!P;&EC871I;VX@=VAI8V@@86QL;W=S
M('EO=2!T;R!C<F5A=&4@=&AE(&-O;7!U=&5R(&5Q=6EV86QE;G0@(@HB;V8@
M<W1I8VMY(&YO=&5S+B!.;W1E<R!C86X@8F4@8W)E871E9"P@;6]D:69I960L
M(&1E;&5T960L(&%N9"!P<FEN=&5D+B!9;W4@(@HB8V%N(&%L<V\@<V5A<F-H
M(&]N('EO=7(@;F]T97,@=&\@;&]C871E(&EN9F]R;6%T:6]N+B!3=7!P;W)T
M(&9O<B!I;7!O<G1I;F<@(@HB86YD(&5X<&]R=&EN9R!N;W1E<R!I<R!A;'-O
M(&%V86EL86)L92XB"FUS9W-T<B`B(@HBS^D@\^?LY>G^\^7I\B#EW^WAZ2#L
MZ>$@Y?;A\>SOX]X@\._U(//A\B#E\.GT\=WPY>D@[>$@Y.?LZ>_U\>/>\^7T
MY2#T[R`B"B+A[?3?\_3OZ??O(/3Y[2#JW_3QZ>WY[2#LZ>KQ_NT@]^'Q].G^
M[2#S]._M(/7P[^OOX^GS]-XN(,SP[_'EW_3E(.WA("(*(N3G[.GO]?'CWO/E
M].4L(.WA(/3Q[_#O\._IWO/E].4L(.WA(.3IX>/QW/CE].4@ZN'I(.WA(/3U
M\/[SY?3E+B#,\._QY=_TY2`B"B+E\-_SY_(@[>$@^-SNY?3E(//TZ?(@\^?L
MY=_Y\^7I\B#SX?(@X^GA(.WA(.7M]._PW_/E].4@[.GA(/#KY_'O]N_QW^$N
M("(*(M7P[_/TY_'?YN7TX>D@ZN'I(.7I\^'C^>/>("T@Y>[AX_GCWB#T^>T@
M\^?LY>G^\^7Y[2XB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z
M,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R
M("+4W_#O].$@X^GA(.7L]MSMZ?/G+"#E\.GS]/'O]MXN(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`IM<V=I9"`B3F]T
M:6-E(@IM<V=S='(@(L'MX>KOZ>W^\^7I\B(*"B,L(&,M9F]R;6%T"FUS9VED
M(").;W1I9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("+4[R#P\?SC\>'L[.$@\._U(.3IX??EZ?'?YN7TX>D@].GR(.7IY._P[^G>
M\^7I\B`E<R#DY>T@XO'=Z.?JY2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B
MS>_=[.+QZ>_R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T,`IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(L'QZ>CL_/(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(Q"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R("+!\>GH[/SR(/?A\>'J]-[Q^>TB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`BP?'IZ.S\\B#S].?K_NTB"@IM<V=I9"`B
M3G5M8F5R(&]F(&-O;'5M;G,@:6X@=&AE('-U;6UA<GD@=FEE=SHB"FUS9W-T
M<B`BP?'IZ.S\\B#S].?K_NT@\_3G[2#E[/;<[>GSYR#TY_(@\.7QW^OG^.?R
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#,Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("+!\>GH[/SR(./Q
MX>SL_NTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8V.0IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BQ.7M(._Q
MW_/HY^KE(.'QZ>CL_/(@X^GA(.7MY^S=\?GSYR#T^>T@Z^GS]/[M(.3IX>WO
M[-[R+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HX,30*;7-G:60@(D]B:F5C="(*;7-G<W1R("+![?3IZN7?[.7M[R(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$W"FUS9VED(")/8FIE8W0@
M0W)E871O<B(*;7-G<W1R("+$Y^SI[_7QX_SR(,'M].GJY>GLW>WO]2(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-R!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(R,PIM<V=I9"`B3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO
M;G,B"FUS9W-T<B`BQ>[O]?/I[^3O]-[SY>GR(,3G[.GO]?'C[_T@P>WTZ>KE
MZ>S=[>_U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y.`IM<V=I
M9"`B3V-T86PB"FUS9W-T<B`BS^KTX>3IZOSR(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`BS^KT_N+QZ>_R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR
M"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("+6W^OT\>\@\/'O\^+O
MZ_[M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-`IM<V=I9"`B
M3V9F:6-E(@IM<V=S='(@(L/QX?;EW^\B"@IM<V=I9"`B3VQD(%!A<W-W;W)D
M(@IM<V=S='(@(M#AZ^G\\B#*^>3IZOSR(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S8*;7-G:60@(D]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(LS\[>\@24U!
M4"U397)V97)S(/7P[_/TY_'?YN_U[2#J[_7M_/?QY_/T[_7R(/;AZMWKZ^_U
M\BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@
M;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(LS\[>\@Y/7SW/'E\_3E\B#P
M\>_BZ]WXY>GR(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34T"FUS9VED(")/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(LS\[>\@[.GA($5M86EL
M(.3IY?WH]>WSYR#E\.GT\=WPY?3AZ2XB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(LS\[>\@
M[R#IY.GOZO3>].?R(-X@[R#DZ>'WY>GQZ?/TWO(@\_7S]-[LX?3O\B#L\._Q
MY=\@[>$@X>OKW.[EZ2#TY^T@(@HBZ>3I[^KTY_/?X2#>(/3I\B#E[N_U\^GO
MY._TWO/EZ?(@]._U(.GDZ>_J]-[TYR#CZ>$@ZN_I[=X@]_'>\^<N(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(L'M[^GC[.$@\^4@[=WO(/#A\=SH]?'O(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-3<*;7-G:60@(D]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*(D]P96Y34TPMR]SH[_(Z(,3E
M[2#L\._Q_B#MX2#BX]SK^2#DY>3O[-WMX2#A\/P@4R]-24U%(/7P[^/EX_'A
M[.S=[>\@[-WQ[_(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(L'M[^GC[.$@X?7TWO(@].?R(//]
M[>3E\^?R(//E(.W=[R#PX?'<Z/7Q[R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("++Y>GT
M[_7QX^GJ_"#3_?/TY^SA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HV,#`*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP
M86YT(@IM<V=S='(@(M#Q[^7QX>GTZ>K\\B#3]>SLY?3=]_GM(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*
M;7-G<W1R("+%\.GK[^/=\B(*"FUS9VED(")/<'1I;VYS(&9O<B(*;7-G<W1R
M("+%\.GK[^/=\B#CZ>$B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,CD@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z-`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B
M"FUS9W-T<B`BQ?#IZ^_CW?(@X^GA("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T
M(@IM<V=S='(@(M3A[NGM[^SG[-WMYR#+W_/TX2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DQ"FUS9VED(")/<F=A;FES871I;VXB
M"FUS9W-T<B`BS_'CX>WI\^S\\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DR"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM
M<V=S='(@(M3LWNSA(,_QX^'MZ?/L[_TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3(W"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(L_QX]SM
M^?/G(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(L'UZ.7M].GJ_"#P
M\?ST]?#O(.7VX?'L[^/>\B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W
M"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(L'U
MZ.7M].GJW"#P\?ST]?#A(/-E("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,C`@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED
M(")/=&AE<B(*;7-G<W1R("+!Z^OO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,CD*;7-G:60@(D]T:&5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(L'KZ^7R(-#KY_'O]N_QW^7R(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-PIM<V=I9"`B3W=N97(@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`BQ>[O]?/I[^3O]-[SY>GR(,GDZ>_J]-[TYR(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HX,PIM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L<@P?7HY>WT
MZ>KO\._?Y_/G(%!!32#DY>T@Y=_MX>D@Y.GAZ-WSZ>SG+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-SD*;7-G:60@(E!'4"!$:6=I
M=&%L(%-I9VYA='5R92(*;7-G<W1R("+8Y_;IX>K>(-7P[^/QX?;>(%!'4"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C@*;7-G:60@
M(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("+*\?7P]._C\>'VY^S=[>$@
MY.7D[^S=[>$@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3,X-PIM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`BQ.?L_//I
M[R#*Z^7IY-\@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3,V-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G
M<W1R("+5\._CY>/QX>SLW>WA+\KQ]?#T[^/QX?;G[-WMX2!01U`@Y.7D[^S=
M[>$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C,*;7-G:60@(E!(4"!#;V1E
M(@IM<V=S='(@(E!(4"#*_N3IZN'R(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0(,K=Z_7V[_(B"@HC
M.B!L:6(O87!I+G!H<#HQ,C8*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B
M4$A0(,K=Z_7V[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(L/=
M[.GS[.$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<T"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-34W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(P,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`Q
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S`@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHS-@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S8W"FUS9VED(")087-S=V]R9"(*;7-G<W1R("+*^>3IZOSR(@H*
M;7-G:60@(E!A<W-W;W)D(&-H86YG960@9F]R('5S97(@)7,@9G)O;2!C;&EE
M;G0@)7,B"FUS9W-T<B`BSR#J^>3IZOSR(-SKZ^'NY2#CZ>$@]._M(/?QWO/T
MYR`E<R#A\/P@].\@\_3AZ.S\("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,S4T"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B
M"FUS9W-T<B`BR]SH[_(@ZOGDZ>K\\B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-3<*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L'PX>GTY=_TX>D@
MZOGDZ>K\\B#CZ>$@X?7HY>WTZ>KO\._?Y_/G(%)!1$E54RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,V"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+*^>3IZOSR(.SE(.7PZ>+EXN'?^?/G
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")0
M87-S=V]R9#HB"FUS9W-T<B`BROGDZ>K\\CHB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+*
M^>3IZOSR.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`Q-PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T
M<B`BSR#J^>3IZOSR(/#QW?#EZ2#MX2#TX>GQZ=SFY>DN(@H*;7-G:60@(E!A
M<W0@179E;G1S($QI<W0B"FUS9W-T<B`BR]_S].$@T.7QX?/LW>WY[2#CY>/O
M[?ST^>TB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B
M4&%S=&4B"FUS9W-T<B`BQ?#IZOSKZ^?SYR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@
M8VQI<&)O87)D(@IM<V=S='(@(L7PZ>K\Z^OG\^<@X?#\(/3O(&-L:7!B;V%R
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`BQ.GAY/'O[-XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHT('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,Z-`IM<V=I9"`B4&5N9&EN9R!3:6=N=7!S
M.B(*;7-G<W1R("+%W_/OY._I(/#O]2#EZNKQY>SO_>TZ(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`BP>WH
M\?GP[^DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("+0[_/O\_3\(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHV"FUS
M9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B
MQ>KTW>OE\^<@R^7I]._U\>/I_NT@T_7M]-[QY_/G\B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BQ>KTW>OE\^<@R^7I]._U
M\>/I_NT@T_7M]-[QY_/G\B#JX?3<(/3G[2#EW_/OY.\[(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8Q(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HV-`HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C<*;7-G:60@(E!E
M<FUI<W-I;VXB"FUS9W-T<B`BQ>[O]?/I[^3\].?SYR(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-C@*;7-G:60@(E!E<FUI<W-I;VX@)R5S)R!N;W0@
M9&5L971E9"XB"FUS9W-T<B`BQ>[O]?/I[^3\].?SYR#CZ>$@)R5S)R#DY2#D
MZ>'C\=SVY^KE+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(R-"!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO<&5R;7,O:6YD97@N
M<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*;7-G:60@(E!E<FUI
M<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I\^<@Q>[O
M]?/I[^3O]-[SY?GM(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-3(*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I
M;VYS(&9O<B(*;7-G<W1R("+%[N_U\^GOY._TWO/EZ?(@X^GA(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA
M=&EO;B(*;7-G<W1R("+0\>_S^?#IZMWR(/#KY_'O]N_QW^7R(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(LKA
M]._IZM_DZ>$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DY"FUS9VED(")0:&]N92(*;7-G<W1R("+4Y^O=]OGM[R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#<*;7-G:60@(E!H;W1O<R(*
M;7-G<W1R("+6^?3OX_'A]M_E\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B
MQ>GJ[^WO\_3OZ??EW^$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*
M;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`BRN_I[>_T]?#?Y?(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W
M"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B
MT.'QX>KAZ_X@ZMSM].4@ZNOIZB#SY2#JW/#OZ>\@ZN7KWR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.`IM
M<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AI<R!E;&5M96YT.B(*;7-G<W1R("+0X?'AZN'K_B#E\.GBY>+AZ?[S].4@
M_/3I(.C=Z^7TY2#MX2#DZ>'C\=SXY?3E(.'U]/P@].\@\_3OZ??EW^\Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4U"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(M#A\>'JX>O^(.7PZ>+E
MXN'I_O/TY2#\].D@Z-WKY?3E(.WA(.'P[_/U[>3=\^7TY2#A]?3\(/3O(//T
M[^GWY=_O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-34*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@
M(M#A\>'JX>O^(.3^\_3E(.S>[>$@ZN'I(-WT[_(N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@
M(M#A\>'JX>O^(.3^\_3E(-WMX2#\[>_LX2#CZ>$@].<@[=WA(.KA].?C[_'?
MX3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,CDX"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("+0X?'A
MZN'K_B#D_O/TY2#LZ>$@W>/J]?'G($E0(.3IY?WH]>WSYRXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4Q"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+B(*;7-G<W1R("(B"B+0X?'AZN'K_B#D_O/TY2#LZ>$@W>/J]?'G
M(.?LY?'O[.?MW^$L(.7KW>[TY2#T[^T@X?'IZ.S\(/3Y[2#G[.7Q_NT@]._U
M(.S>[>$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0S,PIM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`BT.'QX>KA
MZ_X@Y/[S].4@W>/J]?'G(/[QX2XB"@IM<V=I9"`B4&QE87-E('!R;W9I9&4@
M82!N97<@<&%S<W=O<F0B"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@].\@[=WO
M(.KYY.GJ_"#SX?(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R
M;V)L96TN(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(.SIX2#PY?'?Z^?XYR#T
M[_4@\/'OXNO>[.'T[_(N(@H*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@
M<&%S<W=O<F0B"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@]._M(.KYY.GJ_"#S
MX?(B"@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92(*;7-G
M<W1R("+0X?'AZN'K_B#D_O/TY2#T[R"\[>_LX2#7\=[S].<B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$X('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C(*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(/3O(/SM[^SA
M(.KAZ2#T[^T@ZOGDZ>K\(//A\B(*"FUS9VED(")0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE('=I=&@@0&1O;6%I;B(*;7-G<W1R("+3]>SPZ^?Q_O/T
MY2#T[R#\[>_LX2#W\=[S].<@[.4@]._M(/3O[-WA("A`97)M:7,N>61T*2(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ
M,@IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S
M>7-T96TN(@IM<V=S='(@(B(*(M#A\>'JX>O^(.3IX>+<\_3E(/3O(.'J_.OO
M]>CO(.KEW^SE[^TN(-#QW?#EZ2#MX2#S]>SV^>WEW_3E(.SE(/3O]?(@_/'O
M]?(@(@HBX^GA(.WA(/?QY_/I[._P[^G>\^7TY2#A]?3\(/3O(//]\_3G[.$N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU-#`*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I
M;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H
M92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"B+0X?'AZN'K_B#DY=_TY2#T
MZ?(@X>K\Z^_UZ.7R(/#KY_'O]N_QW^7R(.KAZ2#E\.GKW>[TY2#LZ>$@Y>W=
M\>/EZ>$@X?#\(/3O("(*(O#A\>'JW/3Y(.SE[>_]+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#,U"FUS9VED(")0
M;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*
M;7-G<W1R("+0X?'AZN'K_B#E\.GKW>[TY2#LZ>$@Y>W=\>/EZ>$@X?#\(/3O
M(/#A\>'JW/3Y(.SE[>_]+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<R"FUS9VED(")0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(/3O
M(/SM[^SA(/3G\B#MW>'R(.KA].?C[_'?X?(Z(@H*;7-G:60@(E!L96%S92!V
M97)I9GD@>6]U<B!N97<@<&%S<W=O<F0B"FUS9W-T<B`BT.'QX>KAZ_X@Y?#I
MXN7BX>G^\_3E(/3O(.W=[R#J^>3IZOP@\^'R(@H*;7-G:60@(E!R96-E9&4@
M>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`B
MS>$@\/'O]-SS\^_M].'I(.3][R#PX?WKY?(@\/'?[2#TY^T@]?#OX_'A]MX@
M\^'R("@G+2TG*3LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4B"FUS9W-T<B`BR-WSYR#A]?3>\B#TY_(@Y>GJ_.WA\B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(M3O
M\._HY?3^[?3A\B#A]?3\(/3O[2#PW^WAZN$B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(L'P[_/T
M[^O>(//E(.'U]/P@].\@]MSJY>OO("CDY>T@]?#O\_3G\=_FY?3AZ2#A\/P@
M].\@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C(V.0IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B`B"FUS9W-T<B`BRN'TX>KQWNSMZ?/G(./IX2#TZ?(@
M].7KY?7TX=_E\B`E<R#^\>$HY?(I.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O;&1A<"YP:'`Z.3D*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A
M<#H@Q.4@XO'=Z.?JY2#G(.'PX>GT[_WLY>WG(.7PW>KTX?/G($Q$05`N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,V"FUS9VED
M(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ(,3E(.+QW>CGZN4@
MYR#A\.'I]._][.7MYR#E\-WJ].'SYR#S]>WEY/'?X?(N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(Y.`IM<V=I9"`B4')E<V5N=&%T:6]N<R(*
M;7-G<W1R("+0X?'O]?/IW//EZ?(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(R,PIM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`BT-_E\^<B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U-PIM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE
M=F5L.B`B"FUS9W-T<B`BT-_E\^<@\_3O(.7PW_#EY.\@].?R(.C<Z^'S\^'R
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@T"FUS9VED
M(")0<F5S<W5R93H@(@IM<V=S='(@(M#?Y?/G.B`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R("+0\>_E\.GSZOSPZ?/G(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T
M"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`BT/'OY?#I\^K\\.GSYR#TY_(@Y>GJ_.WOX?(@\^4@[=WO(/#A\=SH
M]?'O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HW,2!F<F%M97=O
M<FLO54DO54DO4&%G97(N<&AP.C<R"FUS9VED(")0<F5V:6]U<R!086=E(@IM
M<V=S='(@(M#Q[^?C[_WLY>WG(-/EZ]_DX2(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(M#Q[^?C
M[_WLY>WE\B#%\.GK[^/=\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S
M='(@(L7J]/WP^?/G(.7CX_'<]N_U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#`Y"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("+0
M\>_S^?#IZOP@RNOEZ>3?(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$W-0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("+0\?SBZ^?LX2(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q,@IM<V=I9"`B4')O8FQE;2!$
M97-C<FEP=&EO;B(*;7-G<W1R("+0Y?'IX_'A]MX@T/'OXNO>[.'T[_(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$V"FUS9VED(")0<F]J96-T
M<R(*;7-G<W1R("*X\>/O("AP<F]J96-T*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$W,0IM
M<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`BRN7?[.7M[R#P\>_T\>_PWO(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#D*;7-G:60@
M(E!U8FQI8R!+97DB"FUS9W-T<B`BQ.?L_//I[R#*Z^7IY-\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V.0IM<V=I9"`B4'5B;&EC
M($ME>2!!;&=O<FET:&TB"FUS9W-T<B`BP>OC_/'IZ.SO\B#$Y^S\\^GO]2#*
MZ^7IY.GO_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(R
M,PIM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BU.\@YN7]X^_R(,3G[/SSZ>_U+]#Q
M[_/Y\.GJ[_T@ZNOEZ>3I[_T@Y.4@Y.?LZ>_U\>/>Z.?JY2#E\.GT]??^\BXB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-S`*;7-G:60@(E%U97)Y(@IM<V=S
M='(@(L7Q_O3G\^<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X-PIM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T
M<B`BQ.?L_//I[R#*Z^7IY-\@4E-!("@E9"!":70I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(T-PIM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(L7PZ>OOX]\@Y>W\\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("+4]??AW^$@T/'\
MXNOE^.<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C<Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G
M:60@(E)A=&EO(@IM<V=S='(@(LO\X^_R(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR.34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<T('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,C`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-#,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#8*;7-G:60@(E)E860B"FUS9W-T<B`BP>W<
MX^WY\^<B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,`IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("+![=SC[?GSYR#L
MY^W][.'T[_(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$R"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("+%W_/TY2#BW>+AZ>_R(./IX2#T
MYR#DZ>'C\>'VWB`E<SL@P?7T_"#DY>T@[/#O\>7?(.WA(.7PX>W=Z^CEZ2XB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*;7-G:60@
M(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B+%W_/TY2#S
MW^/O]?'O\B#CZ>$@].<@Y.GAX_'A]MX@]/GM(.3EY._LW>WY[2#T[_4@]_'>
M\_3G("5S.R#!]?3\(.3E[2#L\._QY=\@(@HB[>$@Y?#A[=WKZ.7I+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G
M:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(L7PX>WEZO3=
MZ^7SYR#TY_(@].7KY?7TX=_A\B#E\>/A\]_A\B#SX?(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SHB"FUS9W-T<B`BP>WA[=WY\^<@]/GM(.3U[>'LZ>K^[2#S
M]._I]^7?^>T@]._U(,SE[>_].B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,C4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(L'M
MX>W=^?/G(/3G\B#E[/;<[>GSY_(@]._U(%!O<G1A;#HB"@IM<V=I9"`B4F5F
M<F5S:"!3=6UM87)Y(%9I97<Z(@IM<V=S='(@(L'MX>W=^?/G(/3G\B#0\>_B
M[^O>\B#0Y?'?Z^?XY_(Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#@X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,#0*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(R-@IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G
M97@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,S"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("+%[/;<[>GSYR#3]]WSY?GM
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C0*;7-G:60@(E)E;6%R:W,B
M"FUS9W-T<B`BT_?\Z^GA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT-3<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-S8*;7-G:60@(E)E;65M8F5R('1H92!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(L'P[^SMY^S\[>7U\^<@
M\.OG\>_V[_'I_NT@Y.GAZ.7SZ>S\].?TX?(N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B
MP?#O[.'J\?7S[-WM[^D@Q>[U\.?QY?3G]-WR(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`BP?#O[.'J\?7S[-WM
MYR#DZ>7]Z/7M\^<@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-#`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ-0IM<V=I9"`B4F5M;W9E(@IM
M<V=S='(@(L'VX=_QY?/G(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`BP?;AW_'E\^<@
MS/#K_.HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3,R"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(L'VX=_QY?/G
M(-/TWNOG\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(L'V
MX=_QY?/G(.SO\?;O\._?Y_/G\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C4X"FUS9VED(")296UO=F4@9G)O;2!M
M>2!C86QE;F1A<B(*;7-G<W1R("+!]N'?\>7SYR#A\/P@].\@Y^SE\>_K_./I
M_"#L[_4B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$S-@IM<V=I
M9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BP?;AW_'E\^<@YN7]X^_U\B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.38*;7-G:60@(E)E;6]V92!S879E
M9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"B+!]N'?\>7SYR#A\._HY^KE]>S=[>_U('-C<FEP="#A\/P@
M]._M(/#Q[_/Y\>GM_"#JX?3<Z^_C[R#T[_4@Y>[U\.?QY?3G]-XN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(L'VX=_QY?/G(/3O]2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT.0IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N="(*;7-G<W1R("+!]N'?\>7SYR#A]?3O_2#T[_4@ZOSLXN_U(.'P_"#T
M[R#=X^/QX?;O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHQ-@IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`BQ.GAX_'A]MX@]_'>
M\_3G(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHW"FUS
M9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`BQ.GAX_'A]MX@U_'>\_3G
M.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z,C@P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,S0Y"FUS9VED(")297!L>2!396YT+B(*;7-G<W1R("+3
M]-SKZ.?JY2#!\-SM].?SYRXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C0U.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C0V.`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0W.`IM<V=I9"`B4F5P;'D@=VET
M:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`BP?#<[?3G\^<@[.4@
MS,<@]?#O\_3G\>GF_.SE[>\@[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#8V"FUS9VED(")297!L>2!W
M:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`BP?#<
M[?3G\^<@[.4@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(@X^GA(/3O]?(@
MY?#\[.7M[_7R(.3][R#LWNWE\BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C0V-0IM<V=I9"`B4F5P;'D@=VET:"!R
M97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("+!\-SM
M].?SYR#LY2#TZ?(@YN?T[_WLY>WE\B#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/ST
MY_3A\BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C$X.0IM<V=I9"`B4F5P;'DZ("5S(@IM<V=S='(@(L'PW.WTY_/G
M.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,Y"FUS
M9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E
M<G)O<F-O9&4Z("(*;7-G<W1R("+4[R#AW_3G[.$@Y.4@[/#O\>7?(.WA(.'P
MX>WTY^CEWRX@Q?#I\_3QY?;\[.7M[_(@ZOGDZ>K\\B#KW.CO]?(Z("(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@P(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3`S"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C
M:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BU.\@X?#AZ?3O
M_>SE[>\@)R5S)R#DY>T@ZN'H[_'?\^CGZN4@\_3O("5S(&-O;F9I9W5R871I
M;VXN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV,#$@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-SD*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<U-0IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+4[R#A\.'I
M]._][.7M[R`G)7,G(.3E[2#JX>CO\=_SZ.?JY2#S].\@5D93(&-O;F9I9W5R
M871I;VXN(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S8Q"FUS9VED
M(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`BU.\@X?#AZ?3O_>SE[>\@)R5S)R#DY>T@ZN'H[_'?\^CG
MZN4@\_3O(&-O;F9I9W5R871I;VXN(@H*;7-G:60@(E)E<75I<F5D("=B87-E
M9&XG(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)V)A<V5D;B<@Y.7M
M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G
M\^?R+B(*"FUS9VED(")297%U:7)E9"`G8F%S961N)R!N;W0@<W!E8VEF:65D
M(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O
M(.'PX>GT[_WLY>WO("=B87-E9&XG(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I
M\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+B(*"FUS9VED(")297%U:7)E
M9"`G9&%T86)A<V4G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)V1A
M=&%B87-E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR("(*
M(N'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G:60@(E)E<75I<F5D("=D871A8F%S
M92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=D871A8F%S92<@Y.7M(-WW
MY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+B(*"FUS
M9VED(")297%U:7)E9"`G9&%T86)A<V4G(&YO="!S<&5C:69I960@:6X@<')E
M9F5R96YC97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O
M_>SE[>\@)V1A=&%B87-E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2XB"@IM<V=I9"`B4F5Q=6ER960@)VAO
M<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=H;W-T<W!E
M8R<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B`B"B+A]>CE
M[?3IZN_P[]_G\^?R+B(*"FUS9VED(")297%U:7)E9"`G:&]S='-P96,G(&YO
M="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B+4[R#A\.'I]._][.7M[R`G:&]S='-P96,G(.3E[2#=]^7I(.KA
MZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2XB"@IM<V=I9"`B
M4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N
M8V5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO
M("=H;W-T<W!E8R<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I
M\B#T^>T@\/'O].GLWO/E^>TN(@H*;7-G:60@(E)E<75I<F5D("=P87-S=V]R
M9"<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G<&%S<W=O<F0G(.3E
M[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@(@HBX?7HY>WTZ>KO
M\._?Y_/G\BXB"@IM<V=I9"`B4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E
M8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@HBU.\@X?#AZ?3O_>SE[>\@)W!A<W-W;W)D)R#DY>T@W??EZ2#JX>CO\>GS
M].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN(@H*;7-G:60@(E)E<75I
M<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G<&%S
M<W=O<F0G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM
M(/#Q[_3I[-[SY?GM+B(*"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T
M('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G<&AP='EP92<@Y.7M(-WWY>D@
MZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+B(*
M"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!C
M871E9V]R:65S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT
M[_WLY>WO("=P:'!T>7!E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(.KA].?C[_'I_NTN(@H*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E
M)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=P:'!T>7!E)R#DY>T@W??E
MZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2XB
M"@IM<V=I9"`B4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN(&%U
M=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'P
MX>GT[_WLY>WO("=T86)L92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'U
MZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+B(*"FUS9VED(")297%U:7)E9"`G
M=&%B;&4G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("+4[R#A\.'I]._][.7M[R`G=&%B;&4G(.3E[2#=]^7I
M(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2XB"@IM<V=I
M9"`B4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N
M8V5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO
M("=T86)L92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T
M^>T@\/'O].GLWO/E^>TN(@H*;7-G:60@(E)E<75I<F5D("=U:60G(&YO="!S
M<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W5I9"<@Y.7M(-WWY>D@ZN'H[_'I
M\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+B(*"FUS9VED
M(")297%U:7)E9"`G=6ED)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=U
M:60G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q
M[_3I[-[SY?GM+B(*"FUS9VED(")297%U:7)E9"`G=7-E<FYA;64G(&YO="!S
M<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W5S97)N86UE)R#DY>T@W??EZ2#J
MX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR("(*(N'UZ.7M].GJ[_#OW^?SY_(N
M(@H*;7-G:60@(E)E<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE9"!I
M;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'P
MX>GT[_WLY>WO("=U<V5R;F%M92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR
M(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+B(*"FUS9VED(")297%U:7)E9"`G=7-E
M<FYA;64G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W5S97)N86UE)R#D
MY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>
M\^7Y[2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,C@*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(L'PX>GT[_WLY>WO
M(-#EY-_O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU.3(*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S
M='(@(L'PX>GT[_WLY>WO\B#3]>SLY?3=]_GM(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-2!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`Q"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-#0*;7-G:60@(E)E<V5T(@IM<V=S='(@(L7PX>WA]N_QW"(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!0
M87-S=V]R9"(*;7-G<W1R("+!Z^OAX]X@ROGDZ>KO_2(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W
M;W)D(@IM<V=S='(@(L'KZ]SN].4@]._M(,KYY.GJ_"#SX?(B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z-C8@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN
M+W-Q;'-H96QL+G!H<#HW,PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R("+!\._T
MY>O=\^SA].$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`R
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/
M<'1I;VYS(@IM<V=S='(@(L7PZ?/T\>_VWB#S].GR(,7PZ>OOX]WR(@H*;7-G
M:60@(E)E='5R;B!T;R!M86EL(@IM<V=S='(@(L7PZ?/T\>_VWB#S].?M(.'K
MZ^?K[^/QX?;?X2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)E=6YI;VXB"FUS
M9W-T<B`BQ?#A[=WM^?/G(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N
M9FEG=7)A=&EO;B(*;7-G<W1R("+%\.'MX?;O\=P@0V]N9FEG=7)A=&EO;B(*
M"FUS9VED(")2:&]D97,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#1
M_.3O]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S`*;7-G:60@(E)I
M8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("+%\.GK[^/=\B#E\.7N
MY?'CX?/TWB#E[/#K[_7TZ?/LW>WO]2#JY>GLW>WO]2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("+!Z>W?
MX^SA].$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(L3E[NG<(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-0IM<V=I9"`B4FEG:'0@:&5A
M9&5R(@IM<V=S='(@(L3E[NG<(.7PZ>KE]N'KW^3A(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$P,0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S
M='(@(L3E[NG=\B#TZ>S=\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(LGDZ?STY_3E\B#C\>'L[-[R+BXN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PIM<V=I
M9"`B4F]L92(*;7-G<W1R("+1_.OO\B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,#@*;7-G:60@(E)O=&%T92`Q.#`B"FUS
M9W-T<B`BT.7QZ?/T\>_VWB`Q.#"P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0IM<V=I9"`B4F]T871E($QE9G0B"FUS
M9W-T<B`BT.7QZ?/T\>_VWB#!\>GS].7QW"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,3$*;7-G:60@(E)O=&%T92!2:6=H
M="(*;7-G<W1R("+0Y?'I\_3Q[_;>(,3E[NG<(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W
M(%!R;W!E<G1I97,B"FUS9W-T<B`BR>3I_/3G].7R(,/QX>SLWO(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P
M"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("+)Y.G\].?TY?(@P_'A
M[.S>\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("+#\>'L[-WR.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*
M;7-G:60@(E)U;&5S(@IM<V=S='(@(LKA[?SMY?(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M(@IM<V=S='(@(L_I(.KA[?SMY?(@Z.$@Y>SVX>W?YN_M].'I(.SE].'N_2#\
MZ_GM(/3Y[2#C\>'L[/[M(.KAZ2#T^>T@\_3GZ_[M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`BS^D@ZN'M_.WE\B#HX2#E[/;A[=_F[^WTX>D@[.7TX>[](/3Y[2#S].?K
M_NT@[/SM[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY(@IM<V=S='(@(L_I(.KA[?SMY?(@Z.$@Y>SVX>W?YN_M
M].'I(.SE].'N_2#T^>T@X_'A[.S^[2#L_.WO(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R.0IM<V=I9"`B4G5N(@IM<V=S='(@(L7J]-WKY?/G(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,#`*;7-G:60@(E,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("+5\._C\>'V
MWB#*\?7P]._C\=SVY_/G\B!3+TU)344B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C,T,0IM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E(@IM<V=S='(@(LKQ]?#T[^/QX?;G[-WM[R#LWNWU[.$@4R]-24U%
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-@IM<V=I9"`B
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("+'(.'UZ.7M].GJ[_#OW^?SYR!305-,(.3E[2#EW^WAZ2#DZ>'HW?/I[.<N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,0IM<V=I9"`B4TU3
M($UE<W-A9VEN9R(*;7-G<W1R("+,Y^W][.'TX2!335,B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")344P@
MRMWK]?;O\B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S@*;7-G:60@(E-50T-%4U,B"FUS
M9W-T<B`BQ=#)U-77V=,B"@HC.B!L:6(O87!I+G!H<#HQ,S`*;7-G:60@(E-?
M44P@4VAE;&PB"FUS9W-T<B`B4U]13"#*W>OU]N_R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS
M9W-T<B`BT^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B
MNN3I[R#PZ^'?\^GO("A?<V5L9BDB"@IM<V=I9"`B4V%M;W,@06ER<&]R="(*
M;7-G<W1R("+!Y?'OZ^GLW>WA\B#3W.SO]2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,C`*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*
M;7-G<W1R("+0W/'O]^_R(,3O\?7V_/'O]2(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("+!\._HWNKE
M]?/G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,C(*;7-G:60@
M(E-A=F4@)7,B"FUS9W-T<B`BP?#OZ-[JY?7SYR`E<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#D*;7-G:60@(E-A=F4@)R5S)R(*
M;7-G<W1R("+!\._HWNKE]?/G("<E<R<B"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BP?#OZ-[J
MY?7SYR#%\.GK[^/^[2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C$*
M;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!0
M2%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@HBP?#OZ-[JY?7SYR#T[_4@8V]N9FEG=7)A=&EO
M;B#P[_4@Y.?LZ>_U\>/>Z.?JY2#SX>T@4$A0(%-C<FEP="#S]._M(/#Q[_/Y
M\>GM_"`B"B+JX?3<Z^_C[R#T[_4@Y>[U\.?QY?3G]-XN(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-CD*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(L'P[^CGZN7U[-WM[R`E<R!C;VYF:6=U<F%T:6]N
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDP"FUS9VED(")3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RXB"FUS9W-T<B`BU.\@
M<V-R:7!T(.7MY^S=\?GSY_(@].\@<V5T=7`@X?#OZ.?JY?WHY^KE(//T[SH@
M)R5S)RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C
M:65N8V4B"FUS9W-T<B`BQ?#I\_3>[.<B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-2!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-PIM<V=I9"`B4V5A<F-H(@IM<V=S='(@(L'MX>;>].?SYR(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(E-E87)C:"!%;F=I
M;F5S(@IM<V=S='(@(LSG]^'MW?(@P>WAYM[TY_/G\B(*"FUS9VED(")396%R
M8V@@36%I;"(*;7-G<W1R("+![>'FWO3G\^<@S.?M]>S<]/GM(@H*;7-G:60@
M(E-E87)C:"!297-U;'1S(@IM<V=S='(@(L'P[_3EZ]WS[.'TX2#![>'FWO3G
M\^?R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDU-PIM<V=I9"`B
M4V5L96-T($9I;&5S(@IM<V=S='(@(L7PZ>OOX]X@P?'WY=_Y[2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BQ?#IZ]WN].4@[.GA(.?LY?'O[.?M
MW^$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(P-`IM<V=I9"`B
M4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(L7PZ>O=[O3E(._LW.3A
M(./IX2#P\>_SZ-[JYR(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-#D*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("+%\.GKW>[T
MY2#MW>\@R>3I[^KTWO3G(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`BQ?#IZ]WN
M].4@Y>[U\.?QY?3G]-XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$V,@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`BQ?#I
MZ]WN].4@]_'>\_3G(./IX2#P\>_SZ-[JYR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V-30*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+B(*;7-G<W1R("+%\.GK[^/>(/SK^>T@]/GM(.?LY?'O[.?MZ?[M+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX,30*
M;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`BQ?#IZ^_CWB#E[?SR
M(.'M].GJY>GLW>WO]2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM
M<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@
M=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT87)E82XB"FUS9W-T<B`B(@HBQ?#IZ]WN
M].4@]._U\B#WX?'AZO3>\>7R(/#O]2#HW>OE].4@X?#\(/3I\B#PX?'AZMST
M^2#KW_/TY?(N(,KA]/SPZ>WL\._QY=_TY2`B"B+MX2#TX2#A[?3IX_'<^.7T
MY2#JX>D@[>$@].$@Y?#IZN_KZ][SY?3E(//T[R#LWNWU[.$@\^'R+B(*"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+%\.GK
M[^/>(/3O]2#DZ>'W^?'I\_3>(.?LY?'O[.?MW^'R.B(*"FUS9VED(")396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("+%\.GK[^/>(/3G\B#L[_'V
MWO(@\._U(.CA(-WWY>D@YR#G[.7Q[^SG[=_A.B(*"FUS9VED(")396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`BQ?#I
MZ]WN].4@].<@].'U]/STY_3A(/#O]2#HW>OE].4@[>$@X>OKW.[E].4Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(L7PZ>O=[O3E(/3O(.3IX??Y
M\>GS]-X@_O'A\CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`BQ?#IZ]WN
M].4@].<@[._Q]MX@\._U(.CA(-WWY>D@YR#^\>$Z(@H*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+%\.GKW>[TY2#D_>\@
M\.7DW^$@\._U(/3AZ?'IW.;O]>TN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Y,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G
M<W1R("+%\.GKW>[TY2#T[R#W\?GLX?3IZOP@)_/WWNSA)RXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,R"FUS9VED(")396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(L7PZ>O=[O3E(/3G(./K_O/SX2#S
MX?(Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HV-3,*;7-G:60@(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S
M='(@(L'P[_/T[^O>(/3Y[2#PZ>\@\/'\\_;A]/GM(/#KY_'O]N_QZ?[M(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E
M;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BP?#O\_3OZ]X@P>WA]N_QW/(@
MT/'OXNO>[.'T[_(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.38T"FUS9VED(")396YD(%--4R(*;7-G<W1R("+!\._S]._K
MWB!335,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-`IM<V=I9"`B4V5N
M<V]R.B`B"FUS9W-T<B`BP>GSZ.?TWO'A\CH@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*
M;7-G<W1R("+3Y?#TW>SB\>GO\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S(U"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@
M(M/EZ?'IX>K\\B#!\>GH[/SR(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED(")397-S:6]N($E$(&5X
M<&ER960N(@IM<V=S='(@(M3O($E$(/3G\B#S_>WDY?/G\B#=Z^?NY2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDU"FUS9VED(")3970B"FUS
M9W-T<B`BR-WSY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I
M9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B+(W?/T
MY2#E\.GK[^/=\B#P[_4@Z.$@\^'R(.7PZ?3QW?#O]>T@[>$@X>OKW.;E].4@
M]._M(.KYY.GJ_"#SX?(L(.'J_.SG(.KAZ2`B"B+A[2#T[^T@W??E].4@[N7W
MW//EZ2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`BT.'QX>SE]/'O\._?Y_/G(.'P
M[^SAZO'U\^S=[?GM(.7N]?#G\>7TY_3^[2#P[_4@Z-WKY?3E(/#Q_//BX?/G
M+B(*"FUS9VED(")3970@>6]U<B!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE
M<B!D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(M'UZ.S?\_3E(.3IW/;O
M\>7R(.7PZ>OOX]WR(.7L]MSMZ?/G\B#JX>D@].\@]_'\[>\@X>WA[=WY\^?R
M(/3Y[2#SY>O?Y/GM+B(*"FUS9VED(")3970@>6]U<B!P<F5F97)R960@9&ES
M<&QA>2!L86YG=6%G92XB"FUS9W-T<B`BQ?#IZ^_CWB#TY_(@\/'O].GL[_WL
MY>WG\B#CZ_[S\^'R+B(*"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(LKA
MZ._QW_/TY2#TY^T@\/'O].GL_NSE[><@X^O^\_/A+"#F_NWG(/[QX?(@ZN'I
M(.SO\?;>(.?LY?'O[.?MW^'R+B(*"FUS9VED("(B"B)3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB
MRN'H[_'?\_3E(/3G[2#E]N'Q[._CWB#EZNK?[>?SY_(L(/3A(/#Q[_3I[/[L
MY>WA(/?Q_NSA].$L(/3G(/#E\=_OY.\@(@HBX>WA[=WY\^?R(/3G\B#SY>O?
MY.'R(.KAZ2#<Z^OE\B#E\.GK[^/=\B#E[/;<[>GSY_(N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-`IM<V=I9"`B4V5T=7`B"FUS9W-T<B`BT?WH
M[.GSYR(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,X
M"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S
M='(@(L7?[>'I(.3IX>C=\^GLX2!38W)I<'1S(.7MY^S=\?GSY_(@\?7H[-_S
MY?GM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S-0IM<V=I
M9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B"FUS9W-T<B`BT._KZ]WR(/3O\._HY?/?Y?(@Y=_MX>D@\.GHX>W=
M\B#LY2#A]?3>(/3G(/#A\=SLY?3Q[SH@(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0W,PIM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`BP>/O\=WR
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@
M(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BT_WM]._LYR#0Y?'?Z^?XYR(*"FUS
M9VED(")3:&]R="!3=6UM87)Y.B(*;7-G<W1R("+3_>WT[^SG(-#E\=_KY_CG
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S`*;7-G:60@(E-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G
M<W1R("+0\=WPY>D@].\@ZNOEZ>3?(/#Q_//BX?/G\B#MX2#O\>GSZ.7?(./I
MX2#PY?'I\_/\].7QY?(@\_7MY-WSY>GR.R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,CDT('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,SD*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDV"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30R"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@U"FUS9VED(")3:&]W(@IM<V=S='(@(L7L
M]MSMZ?/G(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T.0IM<V=I9"`B
M(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B+%[/;<[>GSYR#DZ>'V[_'^[2#LY?3A[OT@]._U(.'P[^CGZN7U
M[-WM[_4@ZN'I(/3O]2#DY^SI[_7QX^?HW>WT[_(@(@HB8V]N9FEG=7)A=&EO
M;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#<T"FUS9VED(")3:&]W
M(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(L7L
M]MSMZ?/G(/3G\B#^\>'R(/3EZ^7U].'?X?(@Y>GS_.3O]2#\].'M(.SPX=_M
M[_7LY2#S].\@\_WS].?LX3LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S4R"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM
M<V=S='(@(L7L]MSMZ?/G(.7PZ>OOX][R(./IX2#A\._HWNKE]?/G(/3O]2#A
M]>CE[?3IZN_](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P,0IM
M<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`BQ>SVW.WI\^<@\_7KZ]WJ].<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`Y"FUS9VED(")3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(LWA(.7L]N'MW^;E
M].'I(/3O(.SE[>_](.SE(.7QX^'SW^7R(/#?[>'JX3LB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,S"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/R(*;7-G<W1R("+%[/;<[>GSYR#T[_4@)7,@S.7M[_T@\_3A
M(.'QZ?/TY?'<.R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+%[/;<[>GSYR#T[_4@Y.GA
MZ_SC[_4@R>3I[_3>]/GM(,KEZ^G^[2#0W^WAZN$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(L7L
M]MSMZ?/G(/3O]2#DZ>'K_./O]2#)Y.GO]-[T^>T@T-_MX>KA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y
M"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`BQ>SVW.WI\^<@]._U(.3IX>O\X^_U(,GDZ>_TWO3Y[2##\>'L
M[/[M(-#?[>'JX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQ>SVW.WI\^<@]._U(.3IX>O\X^_U
M(,GDZ>_TWO3Y[2#%Z>K\[>'R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<U,`IM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`BQ>SVW.WI\^<@
M]OSQ]/GSY_(@*'5P;&]A9"DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HS.3$*;7-G:60@(E-H<FEN:R(*;7-G<W1R("+3]?'QW^KM
M^?/G(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-C@T
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<T-@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,#0@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#8V"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.CDP,2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HY,S@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z.38V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDY-@IM
M<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(M#Q_O3A(//U\?'?ZNWY\^<@
MWB#LY?3AZM_MY_/G(./EZ?3O[>GJ_NT@].SG[-ST^>TB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<X"FUS9VED(")3:6=N('5P(@IM
M<V=S='(@(L7?\^_D[_(MU?#OX_'A]MXB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C@Y"FUS9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D
M(@IM<V=S='(@(L<@Q=_S[^3O\BW5\._C\>'VWB#DY>T@W??EZ2#JX?3A]_GQ
MY^CEWRXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<S
M-@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(M7P[^/QX?;>(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,S4*;7-G:60@(E-I9VYA
M='5R92!!;&=O<FET:&TB"FUS9W-T<B`BP>OC_/'IZ.SO\B#5\._C\>'VWO(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(P
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`W"FUS9VED(")3:7IE
M(@IM<V=S='(@(LS=X^7H[_(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M8V]N9FER;5]B;W1T;VTN:6YC.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B
M"FUS9W-T<B`BP>K]\?GSYR#3]>WTWO'G\^?R(@H*;7-G:60@(E-O;64@;V8@
M2&]R9&4G<R!C;VYF:6=U<F%T:6]N(&9I;&5S(&%R92!M:7-S:6YG.B(*;7-G
M<W1R("+,Y?'IZMP@X?#\(/3A(.'Q]^7?X2#DZ>'WY=_QZ?/G\B#T[_4@2&]R
M9&4@W??O]>T@]^'HY=\Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDQ-`IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`BQ?#I
MZ^_CWB#JX?3E_>CU[?/G\B#TX>[I[?SLY_/G\B(*"FUS9VED(")3;W5D82!!
M:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-/O_>3A\B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Q"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C$S"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-34*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(L3IY?WH]>WS
MYR#0Y^/>\B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`BS?STZ>\@Q^SI\_;AW_'I[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS(@IM<V=S='(@(L3IW//TY^SA(.SE].'N_2#CY>GT[^WI
MZO[M(.KEZ^G^[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD
M(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(L3IW//TY^SA(.SE].'N_2#PY?'I
MY??O[-WM[_4@ZN'I(./QX>SLWO(@ZN7KZ?[M(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#$T"FUS9VED(")3<&%C97(B"FUS9W-T<B`BT.O>ZO3Q
M[R#$Z>'S]-[LX?3O\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("+!
M\>'?^?/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G
M<W1R("+!\>'?^?/G(.KAZ2#CW>SI\^SA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.CDU"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R($EN<'5T(@IM<V=S='(@(L7I\^'C^>/>(,7IY.GJ_NT@U^'QX>KTWO'Y
M[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`BQ.GAW_'E\^<@
MZN7KZ>_](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(L3I
MX=_QY?/G(//TWNOG\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M("+$Z>'?\>7SYR#C\>'L[-[R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`BP>CKWNSA].$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0T,PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T.`IM
M<V=I9"`B4W1A<G0B"FUS9W-T<B`BN.WA\>[G(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4X."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDW
M"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(KCT[_(@N.WA\>[G\B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("+0[^OI].7?X2#>(,7PX?'WW^$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C4X,PHC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(LKA]-SS].'SYR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#,*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM
M<V=S='(@(LSO\?;>(.'P[^C>ZN7U\^?R(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(L3IY?WH]>WSYRW/Y/SR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*
M;7-G<W1R("+$Z>'C\>'L[.GS[-WMX2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,C0*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(LO?\_3A
M(.O=[N7Y[2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-38*;7-G
M:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(L'V
MX=_QY?/G(/3O]2!D;VUA:6X@X?#\(/3G(.3IY?WH]>WSYR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G
M:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(M/T_>L@6T-34UTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3
M=2(*;7-G<W1R("+*]2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PIM
M<V=I9"`B4W5B9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R("+/
M(/7P[_;<ZN7K[_(@)R5S)R#DY2#B\=WHY^KE+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S@*;7-G:60@(E-U8FIE8W0B"FUS9W-T
M<B`BR-WLX2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C8X"FUS9VED(")3=6)J96-T(%!U8FQI8R!+97D@26YF;R(*;7-G<W1R("+(
MW>SA("?0Z^?Q[_;O\=_E\B#$Y^S\\^GO]2#*Z^7IY.GO_2<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]2
M96YD97)E<BYP:'`Z,S$R"FUS9VED(")3=6)M:70B"FUS9W-T<B`BP?#O\_3O
MZ]XB"@HC.B!S:6=N=7`N<&AP.C4P"FUS9VED("(B"B)3=6)M:71T960@<F5Q
M=65S="!T;R!A9&0@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L
M;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D
M+B(*;7-G<W1R("(B"B+4[R#AW_3G[.$@X^GA(/#Q[_/HWNKG("<E<R<@\_3O
M(//]\_3G[.$@X?#E\_3<Z^<N(,3E(.SP[_'EW_3E(.WA(.[A[>'L\.7?].4@
M(@HB[-WW\>D@[>$@Y>/J\>GHY=\@].\@X=_TY^S<(//A\BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3
M=6)S8W)I<'0B"FUS9W-T<B`BU?#OY.7?ZO3G\B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`IM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R("+%\.GT]???X2(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"FUS9VED
M(")3=6-C97-S9G5L;'D@861D960@)R5S)R!T;R!T:&4@<WES=&5M+B(*;7-G
M<W1R("+%\.GT]??>\B#P\>_SZ-[JYR`G)7,G(//T[R#S_?/TY^SA+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$R-`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R
M960@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`BU.$@Y.7D[^S=[>$@]._U(/?QWO/TYR`G)7,G(.3IX>/QW/;GZN'M(.7P
MZ?3U]_[R(.'P_"#T[R#S_?/TY^SA+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M.#$@861M:6XO<&5R;7,O9&5L971E+G!H<#HV,0IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&1E;&5T960@)R5S)RXB"FUS9W-T<B`BQ?#I]/7WWO(@Y.GAX_'A]MX@
M)R5S)RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("+%
M\.GT]??>\B#DZ>'C\>'VWB`G)7,G(.'P_"#T[R#S_?/TY^SA+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M(@IM<V=S='(@(B(*(L_I(/'UZ.S?\^7I\B#E\.'MX?;=\>CGZN'M(.7PZ?3U
M]_[R+B#*W.WTY2#E\.'MX?;\\?3Y\^<@X^GA(.WA(.3EW_3E(/3I\B`B"B+A
MZ^OAX]WR+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU-0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+%\.GT]??>\B#E\._H
MWNKE]?/G(.7VY>3QZ>KO_2!C;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C(*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`BQ?#I
M]/7WWO(@X?#OZ-[JY?7SYR#T[_4@Y?;EY/'IZN_](.'Q]^7?[_4@8V]N9FEG
M=7)A=&EO;B`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*;7-G:60@(E-U
M8V-E<W-F=6QL>2!U<&1A=&5D("<E<R<B"FUS9W-T<B`BQ?#I]/7WWO(@Y>WG
M[-WQ^?/G("<E<R<B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HW,@IM<V=I9"`B4W5C8V5S<V9U;&QY('=R
M;W1E("5S(@IM<V=S='(@(L7PZ?3U]][R(.7CX_'A]MX@)7,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4U.`HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(M/][>_XYR`M(-#E\=_KY_CG
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8V"FUS9VED(")3=6X@4FES
M92(*;7-G<W1R("+![>'T[^O>(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C<Q"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(L3]\^<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")3=6YR:7-E(@IM<V=S
M='(@(L'MX?3OZ]XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM
M<V=S='(@(L'MX?3OZ]XOQ/WSYR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("+![>'T[^O>
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38X"FUS9VED
M(")3=6YS970B"FUS9W-T<B`BQ/WSYR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(L3]\^<Z
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(M7PY?'DY=_J].7R(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-0IM<V=I9"`B4W5P<&]R
M="(*;7-G<W1R("+5\._S]-[QZ>[G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BQ?#?
MZ.7T[R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(M3O(.'Q]^7?[R#JX?3AX_'A
M]M[R(//UX_?Q[^WI\^SO_2#DZ>'C\=SVY^KE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(E-Y;F--3"(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY.`IM<V=I9"`B
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("++W.CO\B#S
M_>WTX>[G\B#S]._U\B#\\>_U\B#A[>'FWO3G\^?R(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U1A8FQE+G!H<#HQ,S4*;7-G:60@(E1A8FQE(@IM<V=S='(@(M#?
M[>'JX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@
M(LGDZ?STY_3E\B#0W^WAZN$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T
M:65S(@IM<V=S='(@(LGDZ?STY_3E\B#0W^WAZN$B"@IM<V=I9"`B5&%N86=R
M82!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-3A[=SC\>'R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I
M9"`B5&%R9V5T.B(*;7-G<W1R("+3]/SW[_(Z(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$V.`IM<V=I9"`B5&%S:W,B"FUS9W-T<B`BQ?'CX?/?
MY?(B"@IM<V=I9"`B5&%T;VD@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA
M\B#4X?3O^N_U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3<*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`BP?'IZ.S\
M\B#4Y^OE]O[M[_4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.`IM<V=I
M9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`BR.7Q[._J\>'SW^$@
M].?M(/3EZ^7U].'?X2#^\>$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$R"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("+(Y?'L[^KQX?/?X2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S(*;7-G:60@(E1E
M;7!E<F%T=7)E.B`B"FUS9W-T<B`BR.7Q[._J\>'SW^$Z("(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z,C$Q"FUS9VED(")496UP;&%T
M92`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`BU.\@\/'\]/7P[R`G)7,G(.3E
M(.+QW>CGZN4N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@
M(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I\^<@
MT/'O]/WP[_4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C8T,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T(')E<75E
M<W0B"FUS9W-T<B`BT/'O\_GQZ>W>(,'P[^3O]]X@X>GTWNSA]._R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#D*
M;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@(M#Q[_/Y\>GM
MW"#!\._DY>KT_"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,#(*
M;7-G:60@(E1E>'0B"FUS9W-T<B`BRN7?[.7M[R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-3D*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("+,_.WO
M(,KEW^SE[>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(M/T
M[]_WY_/G(.KEZ>S=[>_U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("+*[_'U
M]MX@ZN7I[-WM[_4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("+4Y2(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDT-`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U
M<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("+%]??A\>GS]._][.4@\._U(/?Q
MY_/I[._P[^G>\^'TY2#T[R#3_?/TY^S<(.SA\BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<V.0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BQR#E\-WJ].'SYR!&5%`@Y.7M
M(.7?[>'I(.'J_.SG(.3IX>C=\^GLYRXB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR-`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T
M:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("+4
M[R#S_?/TY^SA($AO<F1E+TMO;&%B(.3E[2#U\._S].?QW^;EZ2!<(B5S7"(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,CD*;7-G:60@(E1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB
M"FUS9W-T<B`BQ.GA]^7?\>GSYSHZ(,<@ZNO<\^<@Y.4@]N_Q]/[HY^KE(.7P
MZ?3U]_[R(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR
M.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N(@IM<V=S='(@(M3O(/#A\=SH]?'O(.7PZ>OOX_[M(-WJZ^7I\^4N(+CN
M[^3O\BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$V,"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$W,0HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C$X,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$Y-`HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P-2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(S-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(W-`IM<V=I9"`B(@HB
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B+/(.3IX??EZ?'I\_3>\B#P\=WP
MY>D@[>$@\?7H[-_SY>D@W>WA(.S\[>GL[R#PZ^'?\^GO(,7N[_7SZ>_D[_3>
M\^7Y[2P@X^GA(.WA("(*(NSP[_'EW_3E(.WA(/?QY_/I[._P[^G>\^7TY2#E
M[N_U\^GOY._TWO/EZ?(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E
M(&]N;'DB"FUS9W-T<B`BQR#JW/3Y(/#KY?7QW"#L_.WO(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT.0IM<V=I9"`B
M5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R("+4X2#DY>3O
M[-WMX2#G[.7Q[^OOX]_O]2#DY>T@Y=_MX>D@W>/J]?'A(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C0*;7-G:60@
M(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S
M92XB"FUS9W-T<B`B(@HBU.\@240@].?R(.7PX?;>\B#DY>T@ZN'H[_'?\^CG
MZN4L(-[TX>T@ZN7M_"#>(.3E(.+QW>CGZN4@\_3G(.+<\^<@Y.7D[^S=[?GM
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M-`IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BQR#E\.'VWB#P\>_S]-WH
MY^KE(.7PZ?3U]_[R(//T[R#$Z>7UZ/7M\^GOX_'<]N\@\^'R+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S$*;7-G:60@(B(*(E1H
M92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O
M('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(M3O(/3L
MWNSA(%!'4"#P[_4@X?#O\_#<\^CGZN4@X?#AZ?3EW_3O(./IX2#TY^T@Y?#A
MZ][HY?7SYR#T[_4@]?#OX^7C\>'L[-WM[_4@(@HB[.?MWNSA]._R+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8V
M"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE
M<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I
M;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(M3O($E$(/3G\B#KW_/TX?(@
MY.GA[>_LWO(@Y.7M(._QW_/HY^KE+"#>].'M(.KE[?P@WB#DY2#B\=WHY^KE
M(//TYR#BW//G("(*(N3EY._LW>WY[2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V-PIM<V=I9"`B5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("+'(.O?
M\_3A(.3IX>WO[-[R(.3E[2#JX>CO\=_SZ.?JY2XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0N<&AP.C$R-PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`BS^D@Y/7MX?3\].?TY?(@ZO'U\/3OX_'<]N?SY_(@X?#AZ?3O_>T@X?/V
MX>O>(//][>3E\^<@5T5"+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-S@*;7-G:60@(E1H92!E=F5N="!H87,@8F5E
M;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G<W1R("+4[R#CY>/O[?SR
M(/#Q[_/TW>CGZN4@\_3O(.?LY?'OZ_SCZ?P@\^'R+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3@Q(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3`T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S
M('-E='1I;F<N(@IM<V=S='(@(M3O(.'Q]^7?[R`E<R#P\=WPY>D@[>$@\.7Q
MZ=WWY>D@[.GA("5S(/']Z.SI\^<N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT.30*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN
M9W,N(@IM<V=S='(@(M3O(.'Q]^7?[R`E<R#P\=WPY>D@[>$@\.7QZ=WWY>D@
MZMSP[^GE\B`E<R#Q]>CLW_/EZ?(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,38U"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`BU.\@X?'WY=_O(.3E(.SP[_'EWR#M
MX2#A[?3IX_'A]N7?(//T[^T@Y>'U]/P@]._U+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$N<&AP.C(V-`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(M3O(.'Q]^7?[R#DY>T@\.7QZ=WWY>D@Y.7D[^S=
M[>$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,@IM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`BU.$@\.'Q
MX>K<]/D@Y=_MX>D@Y?#IZN7VX>O?Y.7R(./IX2#A]?3\(/3O(.S>[?7LX2]R
M9F,X,C(@[-[M]>SA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T
M(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*
M(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N
M9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T
M96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL
M(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S
M92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U
M;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HBQR#JX?3<\_3A\^<@\.O>
M\>_U\B#OZ/SMY_(@Y=_MX>D@X^WY\_3\(/STZ2#DY^SI[_7QX^7?(/#Q_.+K
MY^SA(.SE(/3O[2`B"B));G1E<FYE="!%>'!L;W)E<BP@Y>[AZ?3?X?(@\/'O
MXNOG[-ST^>T@*&)U9W,I(/3O]2!B<F]W<V5R+"#TX2#O\._?X2#DY>T@(@HB
MY=_AZ2#D]>WA]/P@[>$@[N7PY?'A\^CO_>TN(,SP[_'EWR#MX2#DY=_TY2`G
M\^KO]?#?Y.GA)R#S].?M(._H_.WG+"`B"B+P\>_BZ][LX?3A(//TYR#KY>GT
M[_7QX]_A(/3O]2!B<F]W<V5R(-X@ZN'I(.K\Z^?LW"#T[_4N(,'M(/3O(//]
M\_3G[-P@\^'R("(*(N7?[>'I(%=I;F1O=R`Y>"#EW^WAZ2#P[^O](/#IZ.'M
M_"#MX2#DY=_TY2`GP^7MZ>K>(,'P[_3U]]_A(-#Q[_/TX?/?X?(G(.KAZ2`B
M"B+MX2#P\=WPY>D@[>$@Y?#A[>7JZNGMWO/E].4@*')E8F]O="DN7%QN7%S!
M]?3>(.7?[>'I(/#Q[^7IY._P[]_G\^<N(-#A]-[S].4@(@HBS\H@X>T@Z-WK
MY?3E(.'J_.SG(.WA(.3O]>O=^.7TY2#SY2#JX?3<\_3A\^<@\.O>\>_U\B#O
MZ/SMY_(N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C@X"FUS9VED(")4:&4@
M:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(L<@
M].'U]/STY_3A(%PB)7-<(B#DZ>'C\=SVY^KE+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H
M92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(L<@X?'I\_3E\=X@\.OE
M]?'<(.S\[>\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S8*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G
M<W1R("(B"B+'(.C=\^<@]._U(/#Q[^/QW.SLX?3O\B!';G501R#P\=WPY>D@
M[>$@Y._HY=\@X^GA(/3G($-R>7!T7W!G<#HZ(.KKW//G+B(*"FUS9VED(")4
M:&4@;6%I;&)O>"!T<F%S:"!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R("+'
M(./QX>SLX?3OZ/7QW^3A("?JW.3O\B<@Y=_MX>D@WN3G(-SDY>GA+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,30*;7-G:60@(B(*(E1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<
M(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"XB"FUS9W-T<B`B(@HBU.\@[-[M]>SA(/#O]2#S]-SKZ.?JY2#S].GR("5S
M(//T[^T@)7,@[.4@Z-WLX2`E<R#E[/;A[=_SZ.?JY2Y<;B(*(L'U]/P@Y.7M
M(.'P[_3EZ^7?(.7PZ>+EXN'?^?/G(/STZ2#DZ>'BW//HY^KE(.KAZ2#=X^GM
MY2#JX?3A[>_G]/PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V
M,`IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@
M8V]M<&]S92!P86=E(@IM<V=S='(@(M3O(/SM[^SA(/#O]2#HX2#W\>?SZ>SO
M\._IY=_TX>D@_/3A[2#S]>WDW>7S].4@\_3G(//EZ]_DX2#S_>WHY?/G\BXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R-3D*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(L<@XNGBZ^GOZ-[J
MYR!/<&5N4U-,(.'PX>GTY=_TX>D@X^GA($AO<F1E7T-R>7!T7W-M:6UE.CH@
MZNO<\^<N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3$*;7-G
M:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B+'(/#Q[_3?[.?SYR!<(B5S7"(@
MY.7M(.SP_/'E\^4@[>$@X?#OZ.?JY?7HY=\@X^GA]-\@].$@Y.7D[^S=[>$@
M].?R("(*(O7PY?'BX=_M[_7M(/3O(.S=X^GS].\@Y?#I]/'E\/3\(.S=X^7H
M[_(B"@HC(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP
M.C,U+"!C+69O<FUA=`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D
M96(N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R
M:7!T+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O
M=V5R<&]I;G0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<G!M+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C0P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI
M9VAL:71E+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<V5X8V5L+G!H<#HS-0IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V
M:65W('1H:7,@;65S<V%G92!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"B+4[R#P\?SC\>'L[.$@\._U(/?QY_/I
M[._P[^GEW_3E(./IX2#TY^T@Y>SVW.WI\^<@X?7T[_T@]._U(.7?Y._U\B#L
MY^WU[-ST^>T@(@HB*"5S*2#DY>T@XO'=Z.?JY2#S].\@\_WS].?LX2XB"@IM
M<V=I9"`B(@HB5&AE(')E9VES=')Y(&ES(&AO=R!(;W)D92!A<'!L:6-A=&EO
M;G,@9FEN9"!O=70@:&]W('1O('1A;&L@=&\@96%C:"!O=&AE<BX@(@HB66]U
M('-H;W5L9"!L:7-T(&%N>2!I;G-T86QL960@2&]R9&4@87!P;&EC871I;VYS
M('1H870@>6]U(&AA=F4@:&5R92XB"FUS9W-T<B`B(@HBQR!R96=I<W1R>2#E
MW^WAZ2#O(/3Q_/#O\B#LY2#T[^T@[_#OW^\@[^D@Y?;A\>SOX]WR(/3O]2!(
M;W)D92#E\.GJ[^GM^>WO_>TN("(*(NSE].'N_2#T[_7R+B#%Y/X@\/'=\.7I
M(.WA(./QW/CE].4@_/3I(.7VX?'L[^/=\B#T[_4@2&]R9&4@W??E].4@(@HB
MY>/JX?3A\_3>\^7I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F
M="!S:61E<R!O;FQY(@IM<V=S='(@(L<@X?'I\_3E\=X@ZN'I(.3E[NG<(/#K
MY?7QW?(@[/SM[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@
M;VYL>2(*;7-G<W1R("+'(.3E[NG<(/#KY?7QW"#L_.WO(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(L\@Y>[U\.?QY?3G]-[R
M(%PB)7-<(B#DZ>'C\=SGZN4N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-#D*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A
M=F5D+B(*;7-G<W1R("+/(.7N]?#G\>7TWO(@7"(E<UPB(.'P[^CGZN7]Z.?J
MY2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*;7-G:60@(E1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`BU.\@
MX=_TY^SA(.7I\_SD[_4@X^GA("5S(.3IX>/QW/;GZN4N(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C@T"FUS9VED(")4:&4@<W!E
M8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BQR#C\>'L[-X@
M\._U(._QW_/A].4@Y.7M(/7PW/'WY>DN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,#@*;7-G:60@(E1H92!T87-K
M(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(L<@
MY?'CX?/?X2#P\>_S]-WHY^KE(//TYR#KW_/TX2#E\>/A\^G^[2#SX?(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,3$*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(M3O(/#Q[_/Y\>GM_"#A\??EW^\@7"(E<UPB(.3E[2#U\-SQ]^7I+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S
M='(@(L<@\-SM^2#JX>D@ZMST^2#PZ^7U\=WR(.S\[>\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED
M(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("+'(/#<[?D@\.OE]?'<(.S\
M[>\B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,3$*;7-G:60@(E1H
M92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S
M=&5P+B(*;7-G<W1R("+4X2#DY>3O[-WMX2#P[_4@\_3=Z^WA].4@]]SHY^KA
M[2#A\/P@].\@\/'OY^/O_>SE[>\@XM[LX2XB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+V-S=BYP:'`Z,C4P(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-S<*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"XB"FUS9W-T<B`BU.\@X?'WY=_O(/#O]2#S].7?Z^'TY2#DY2#L\/SQ
MY?/E(.WA(//YZ.7?+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z.3,*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@
M(L_I(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R(.'P[^CGZN7]Z.?JX>T@
MY?#I]/7W_O(N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"FUS9VED
M(")4:&5M97,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R("+/
M(.KA]-SK[^/O\B#HY>S<]/GM("<E<R<@Y.4@XO'=Z.?JY2XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X,PIM<V=I9"`B5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("+$Y>T@]?#<\??O]>T@
MQ?#IZ^_CW?(@Y.GAZ-WSZ>SE\BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HS-#`*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("+$Y>T@]?#<
M\??O]>T@].S>[.'TX2#P[_4@Y.4@[/#O\>_][2#MX2#E[/;A[>GSZ._][2#E
M[?/Y[.'T^>S=[>$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y
M-PIM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B
M"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(M7P
MW/'W[_7M(/#OZ^OOWR#WX?'AZO3>\>7R(//E(.'U]/P@].\@\.7DW^\N(,7I
M\^'CW./A].4@)7,@]^'QX>KTWO'E\BP@(@HB\/'=\.7I(.WA(/7PW/'W[_7M
M(.OIX_STY?'OZ2#A\/P@)7,N(@H*(SH@<VEG;G5P+G!H<#HU-0IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M
M+B`E<RXB"FUS9W-T<B`BT/'\XNOG[.$@ZN'TW"#TY^T@\/'O\^C>ZN<@)R5S
M)R#S].\@\_WS].?LX2X@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z-S,*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y
M<W1E;3H@)7,B"FUS9W-T<B`BT/'\XNOG[.$@ZN'TW"#TY^T@\/'O\^C>ZN<@
M)R5S)R#S].\@\_WS].?LX3H@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("+0\?SBZ^?L
MX2#JX?3<(/3G(.3IX>/QX?;>(.3EY._LW>WY[2#T[_4@]_'>\_3G("<E<R<@
MX?#\(/3O(//]\_3G[.$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PIM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE
M('-Y<W1E;3H@(@IM<V=S='(@(M#Q_.+KY^SA(.KA]-P@].<@Y.GAX_'A]MX@
M)R5S)R#A\/P@].\@\_WS].?LX3H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("<E<R<Z("5S
M(@IM<V=S='(@(M#Q_.+KY^SA(.KA]-P@].?M(.7MY^S=\?GSYR`G)7,G.B`E
M<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y.0IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("+0\?SBZ^?LX2#JX?3<(/3G
M[2#A\._S]._KWB#A\??EW^_U.B#$Y>T@\_3<Z^CGZN4@)7,N(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H
M)60@8GET97,I+B(*;7-G<W1R("(B"B+0X?'O]?/IW//HY^KE(/#Q_.+KY^SA
M(.KA]-P@].?M(.'P[_/T[^O>(/3O]2#A\??EW^_U.B#4[R`E<R#EW^WAZ2#L
MY>/AZ_WTY?'O("(*(N'P_"#T[R#LW>/I\_3O(.7PZ?3QY?#\[.7M[R#LW>/E
MZ._R("@E9"!">71E<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3`V"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+B(*;7-G<W1R("(B"B+0X?'O]?/IW//HY^KE(/#Q_.+KY^SA(.KA
M]-P@].?M(.'P[_/T[^O>(/3O]2#A\??EW^_U.B#3]-SKZ.?JY2#L_.WO(-WM
MX2`B"B+T[-[LX2#T[_4@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HS.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@HBT.'Q
M[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>SVW.WI\^<@X?7T[_T@]._U
M(/3LWNSA]._R(/3O]2#LY^W][.'T[_(N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C0R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("+0X?'O
M]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#DY>3O[-WM^>T@
MQ.GE]>CU[?/I[^/QW/;O]2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C<U"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(M#A\>_U\^G<
M\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(/3O]2#CY>/O[>_T[_(Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,@IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N(@IM<V=S='(@(M#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M
M(.7I\^'C^>/>(.3EY._LW>WY[2#G[.7Q[^OOX]_O]2XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P-0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM
M<V=S='(@(M#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>
M(/3G\B#E\>/A\]_A\CH@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HY,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E
M<RXB"FUS9W-T<B`BT.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GS
MX>/YX]X@\.OG\>_V[_'I_NT@Y.GAZ.7SZ>S\].?TX?(Z("5S+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-SD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B+0
MX?'O]?/IW//HY^KE(//VW.OLX2#S].<@]OSQ[.$@\?7H[-_SY?GM+B"Z\_GR
M(.'VWO/A].4@ZN7M_"#JW/#OZ>\@(@HBX?#AZ?3O_>SE[>\@\.7DW^\N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-C,*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H
M92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B+0X?'O]?/IW//HY^KE(//V
MW.OLX2#S].?M(.7J]-WKY?/G(/3G\B#JX>CO\>GS[-WMY_(@Z^7I]._U\>/?
MX?(@]._U("(*(L3IY?7H]>WSZ>_C\=SV[_4N(-#A\>'JX>O^(.3OZNGLW//T
MY2#A\>/\].7QX2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8V-0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*(D)E:2!D97(@06MT=6%L:7-I97)U;F<@
M9&5R($MO;G1A:W1D971A:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N
M+B!":71T92`B"B)V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA
M;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HBT.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@
MY>WG[-WQ^?/G(/3G\B#KW_/TX?(@Y.GA[>_LWO(N(-#A\>'JX>O^("(*(N3O
MZNGLW//TY2#A\>/\].7QX2XB"@IM<V=I9"`B5&AE<W-A;&]N:6MI($%I<G!O
M<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@R.7S\^'K[^W?ZN?R(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34S"FUS9VED(")4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+B(*;7-G<W1R("+/(.7N]?#G\>7TY_3>\B!)34%0(.3E[2#U\._S].?Q
MW^;EZ2#J[^GM_/?QY_/T[_7R(/;AZMWK[_7R+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.#(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HY-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Q,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(P,`IM<V=I
M9"`B5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BP?7T
MWB#G(.7MW?'CY>GA(.3E[2#U\._S].?QW^;E].'I+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3$X"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S4Y"FUS9VED
M(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+B(*;7-G<W1R
M("+!]?3>(.<@Z^7I]._U\>/?X2#DY>T@W??EZ2#OZ^_JZ^?Q^>CEWR#AZOSL
MYRXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Q
M"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A
M<B!A<F-H:79E+B(*;7-G<W1R("+!]?3\(.3E(/;AW^WE].'I(.WA(.7?[>'I
M(-WCZO7Q[R#A\??EW^\@<F%R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-34*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(L'U]/P@Y.4@]N'?
M[>7TX>D@[>$@Y=_MX>D@W>/J]?'O(.'Q]^7?[R!Z:7`N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$R.0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S
M965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(L'U]/P@
MY.4@]N'?[>7TX>D@[>$@Y=_MX>D@W>/J]?'O\B#A\>GH[/SR(.K<\?3A\BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#<*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*(L'U]/SR(.\@[^3GX_SR(//A\B#E\.GT\=WPY>D@[>$@\_3=
MZ^WE].4@[.?M_>SA].$@[-WS^2!#;&EC:V%T96QL+2AH='1P.B\O(@HB8VQI
M8VMA=&5L;"YC;VTI(.S=\_D@2%144"U!4$DN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S0*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B+!]?3\\B#O(._D
MY^/\\B#SX?(@Y?#I]/'=\.7I(.WA(//TW>OMY?3E(.SG[?WLX?3A(.S=\_D@
M<VUS,F5M86EL+2AH='1P.B\O(@HB<VUS,FUA:6PN8V]M*2#LW?/Y($A45%`M
M05!)+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@R"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B+!]?3\
M\B#O(._DY^/\\B#SX?(@Y?#I]/'=\.7I(.WA(//TW>OMY?3E(.SG[?WLX?3A
M(.S=\_D@4TU44"`@ZN'I(/3G\B`B"B)6;V1A9F]N92U)=&%L>2#L_.WO(//E
M(.'QZ>CL[_WR(%9O9&%F;VYE+B#!\.'I].7?(-WMX2#K[^/A\>GA\^S\(&5M
M86EL(//TYR`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(T-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C@Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.30*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,34T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#(V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#$R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-C$*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$S,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C`T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0S-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,38*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S@V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.30*
M;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(M3O(/#E
MY-_O(.'U]/P@X?#AZ?3EW_3AZ2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#4Y"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M:6YT96=E<G,N(@IM<V=S='(@(M3O(/#EY-_O(.'U]/P@[/#O\>7?(.WA(-WW
MY>D@[/SM[R#AZMWQX>GO]?(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0P,`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@HBP?7T_"#T[R#PY>3?
M[_4@[/#O\>7?(.WA(/#E\>G=]^7I(.S\[>\@X?'IZ.SO_?(@ZN'I(-SM^2#J
MW/3Y(/3EZ^7?X2`H.BDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`X.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RXB"FUS9W-T<B`BP?7T_"#T[R#PY>3?[R#L\._QY=\@[>$@\.7Q
MZ=WWY>D@[/SM[R#OZO3AY.GJW?(@].GLW?(N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$Q-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS
M9W-T<B`B(@HBP?7T_"#T[R#PY>3?[R#L\._QY=\@[>$@\.7QZ=WWY>D@[/SM
M[R#KW_/TX2#A\>GH[/[M(/?Y\>GS[-WM^>T@[.4@ZN7M_"#>("(*(N7KZ^?M
MZ>K\(.7Q^?3G[.'TZ>K\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3@S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M(@IM<V=S='(@(L'U]/P@].\@\.7DW^\@\/'=\.7I(.WA(.7?[>'I(-WMX?(@
MW>/J]?'O\B#A\>GH[/SR+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,C0*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L
M;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*
M(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HBP?7T_"#T[R#PY>3?[R#P\=WPY>D@
M[>$@\.7QZ=WWY>D@ZOGDZ>K\(/?Q_NSA]._R(//E(%)'0B#DY>KAY>[AY.GJ
MWB#L[_'VWBP@\"XB"B+W+B`G(S$R,S1A9B<N(@H*;7-G:60@(B(*(E1H:7,@
M9FEL92!C;VYT<F]L<R!T:&4@9VQO8F%L('-E="!O9B!-24U%(&1R:79E<G,@
M9F]R('1H92!(;W)D92!F<F%M97=O<FLL("(*(F%L;&]W:6YG(&%P<&QI8V%T
M:6]N<R!T;R!M86ME('5S92!O9B!P<F]G<F%M<R!S=6-H(&%S(&5N<V-R:7!T
M(&]R(&US=V]R9'9I97<@(@HB=&\@<F5N9&5R(&-O;G1E;G0@:6YT;R!(5$U,
M(&9O<B!V:65W:6YG(&EN(&$@8G)O=W-E<BXB"FUS9W-T<B`B(@HBP?7T_"#T
M[R#A\??EW^\@\.7QZ=WWY>D@]._U\B!-24U%(&1R:79E<G,@\._U(/?QY_/I
M[._P[^GO_>WTX>D@X?#\(/3G[2`B"B+U\.?QY?/?X2#E\.GT\=WP[^WTX?(@
MY.G<]N_QX2#P\>_C\=SL[.'TX2#MX2#DZ>'WY>GQW^;O[?3AZ2#TX2#PY?'I
MY??\[.7MX2`B"B+T^>T@96UA:6P@ZN'I(.WA(/3A(.7L]N'MW^;O]>T@[.4@
M]._M(.KA]-SKZ^?K[R#T\?SP[RXB"@IM<V=I9"`B(@HB5&AI<R!F:6QE(&-O
M;G1R;VQS('1H92!S='EL97-H965T('1H870@:7,@=7-E9"!T;R!S970@8V]L
M;W)S(&%N9"!F;VYT<R!F;W(@(@HB=&AE($AO<F1E(&9R86UE=V]R:R!A;F0@
M86QL(&%P<&QI8V%T:6]N<R!T:&%T(&1O(&YO="!P<F]V:61E('1H96ER(&]W
M;B`B"B)S971T:6YG<RXB"FUS9W-T<B`B(@HBP?7T_"#T[R#A\??EW^\@Y>O=
MX_?EZ2#TZ?(@\?7H[-_SY>GR(/3Y[2#W\?GLW/3Y[2#JX>D@]/GM(./QX>SL
MX?3O\^7I\?[M(./IX2`B"B+\Z^$@].\@\/'\X_'A[.SA(/3O]2!(;W)D92P@
MZN'I(./IX2#TZ?(@Y?;A\>SOX]WR(/#O]2#EW^WAZ2#EX^KA].7S].?LW>WE
M\B`B"B+SY2#A]?3\(.KAZ2#DY>T@\.'QW??O]>T@Y.GJW?(@]._U\B#E\.GK
M[^/=\B#CZ>$@X?7TW?(@].GR(/'UZ.S?\^7I\BXB"@IM<V=I9"`B(@HB5&AI
M<R!F:6QE(&UA<',@9FEL92!E>'1E;G-I;VYS('1O(&QO9VEC86P@34E-12!T
M>7!E<RP@96YA8FQI;F<@2&]R9&4@(@HB87!P;&EC871I;VYS('1O(&9I9W5R
M92!O=70@:&]W('1O(&AA;F1L92!S;VUE(&-O;G1E;G0@<W5C:"!A<R!E;6%I
M;"`B"B)A='1A8VAM96YT<R!O<B!#5E,@8VAE8VMO=71S+B(*;7-G<W1R("(B
M"B+!]?3\(/3O(.'Q]^7?[R#JX?3AX_'<]N7I(/3I\B#E\.7J]-SSY>GR(/3Y
M[2#T_?#Y[2#,R<S%+"#^\_3E(/3A(/#E\>GE]_SLY>WA("(*(N_QZ?/LW>WY
M[2!M86EL(.WA(.7L]N'MW^;O[?3AZ2#LY2#T[^T@ZN'TW.OKY^OO(/3Q_/#O
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,@IM<V=I9"`B5&AI
M<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("+!
M]?3>(.<@]OSQ[.$@W??EZ2#>Y.<@Y?#E[N7QX^'SZ.7?+B(*"B,Z('1E;7!L
M871E<R]H96QP+V%B;W5T+FEN8SHQ"FUS9VED(")4:&ES(&ES("5S+B(*;7-G
M<W1R("+!]?3\(.7?[>'I("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z-#,W"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N
M(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'
M<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB
M8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HBP?7T_"#EW^WA
MZ2!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B##Z>$@[>$@Y.7?].4@].\@X>WT
MZ>KEW^SE[>\@X?7T_"`B"B+W\>7IW.;E\^CE(-WMX2#P\?SC\>'L[.$@96UA
M:6P@\._U(.KA].'KX>+AW^WEZ2#A]?3>(/3G(.SO\?;>+B##Z>$@Z]_S].$@
M(@HB]-WT[^GY[2#P\>_C\>'L[-ST^>T@[/#O\>7?].4@[>$@Y?#I\^KE]>CE
MW_3E(/3O("5S(@H*;7-G:60@(B(*(E1H:7,@:7,@=&AE(&UA:6X@2&]R9&4@
M8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P871H<R!A;F0@8F%S
M:6,@:71E;7,@(@HB=&AA="!A<'!L>2!T;R!T:&4@8V]R92!F<F%M97=O<FL@
M86YD(&%L;"!(;W)D92!A<'!L:6-A=&EO;G,N(@IM<V=S='(@(B(*(L'U]/P@
MY=_MX>D@].\@XN'SZ>K\(.'Q]^7?[R#Q]>CLW_/E^>T@]._U(/#Q[^/QW.SL
MX?3O\B`G2&]R9&4G+B#0Y?'IW??EZ2#TX2`B"B+L[^WO\-STZ>$@ZN'I(/3A
M(.+A\^GJW"#LW?'G(/#O]2#W\>?SZ>SO\._I[_WM].'I(.'P_"#T[^T@\/7Q
MWNWA(.KAZ2#TZ?(@(@HBY?;A\>SOX]WR(/3O]2#S]?/TWNSA]._R+B`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#<*;7-G:60@
M(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B+4[R#LWNWU
M[.$@X?7T_"#C\=SVZ.?JY2#LY2#J^>3IZN_SY>O?Y.$@*"5S*2#DZ>'V[_'E
M].GJWB#A\/P@].<@Y.GJWB#SX?(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,CD*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+B(*;7-G<W1R("+!]?3\\B#O(.'QZ>CL_/(@\/'=\.7I(.WA
M(.7?[>'I(/3O]>O<]^GS]._M(-WMX2XB"@IM<V=I9"`B(@HB5&AI<R!P<F]B
M;&5M(')E<&]R="!W87,@<F5C96EV960@9G)O;2`E<RX@5&AE('5S97(@8VQI
M8VME9"!T:&4@<')O8FQE;2`B"B)R97!O<G0@;&EN:R!F<F]M('1H92!F;VQL
M;W=I;F<@;&]C871I;VXZ)7,@86YD(&ES('5S:6YG('1H92!F;VQL;W=I;F<@
M(@HB8G)O=W-E<CHE<R(*;7-G<W1R("(B"B+4[R#P\?SBZ^?LX2#A]?3\(.'M
MX?;=\>CGZN4@X?#\("5S+B#/(/?QWO/TY_(@ZMSKY?/E(/3G[3QB<B\^X>WA
M]N_QW"`B"B+P\>_BZ][LX?3O\B#A\/P@].\@\.'QX>K<]/D@55),.CQB<B\^
M)7,@ZN'I(/?QY_/I[._P[^GEWR#T[^T@X>K\Z^_UZ.\@(@HB8G)O=W-E<CH\
M8G(O/B5S(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N
M<&AP.C0X"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`BP?7T_/(@[R#E[O7PY_'E].?T
MWO(@Y.4@[/#O\>7?(.WA(.'P[_/U[/#IW?/EZ2!Z:7`@ZN'I(&=Z:7`@X?'W
MY=_A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M,30W"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T
M960N(@IM<V=S='(@(M3O(//]\_3G[.$@X?7T_"#=]^7I(.'PY>WE\>/O\._I
MY^CEWRXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-PIM
M<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+!
M]?3>(.<@].GLWB#P\=WPY>D@[>$@Y=_MX>D@X?'IZ.S\\BXB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(U"FUS9VED(")4:6-K971S(@IM<V=S
M='(@(L7I\^GTWO'IX2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,3`*;7-G:60@(E1I;64B"FUS9W-T<B`BV?'A(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,Q,0IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M("+)]^WGZ^'T_NWTX?(@].?M(/[QX2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`BS._Q]MX@_O'A\B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,C$*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(L7PZ>OOX]X@_O'A\B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S(@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(M3?].OO\B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`BU-_TZ^_R("A4;V]L=&EP
M*3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C@P"FUS9VED(")4;R(*;7-G<W1R("+0\?SR(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R.0IM<V=I9"`B(@HB5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS
M9W-T<B`B(@HBP^GA(.WA(.KQX?3>\^7TY2#P[^OKX?#KW"#A[?3IZN7?[.7M
MX2P@ZO'A]-[S].4@\.'TY^S<[>\@].\@0V]N=')O;"`H4$,I(-X@(@HB].\@
M0V]M;6%N9"`H36%C*2#PZ][J]/'O+"#E[?X@ZMSMY?3E(.KKZ>HN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PIM<V=I9"`B5&]D87DB
M"FUS9W-T<B`BT][LY?'A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM
M<V=S='(@(L7MX>OKX>/>(//E(/#GX^'?[R!(5$U,(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T
M<B`BP?WQZ>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("+*[_'U]MXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS
M9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(M#<[?D@\.OAW_/I[R`H
M7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R
M86YS;&%T:6]N<R(*;7-G<W1R("+,Y?3A]O'<\^7I\B(*"FUS9VED(")4<FEP
M;VQI<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-3QW_#OZ^?R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W-PIM<V=I9"`B5')U92!O
M<B!F86QS92(*;7-G<W1R("+!Z^?HW?(@WB#XY?7DW?(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*
M;7-G<W1R("+4\2(*"FUS9VED(")4>7!E(&UI<VUA=&-H+B(*;7-G<W1R("++
MX>WHX?/LW>WO\B#T_?#O\B#DY>3O[-WM^>TN(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(V,@IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S
M='(@(M#KY^KT\>_K[^/>\_3E(/3G[2#E\.GK[^/>(//A\CH@(@H*;7-G:60@
M(E523"(*;7-G<W1R("+'Z^7J]/'O[>GJWB#$Z>7]Z/7M\^<B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,0IM<V=I
M9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M(@IM<V=S='(@(B(*(L?KY>KT\>_MZ>K>(,3IY?WH]>WSYR#CZ>$@Y?#I\_3Q
M[_;>(.'MX?;O\=SR(.KA]-SS].'SY_(@]._U(/#Q[^/QW.SLX?3\\B#SX?(B
M"@IM<V=I9"`B55),.B(*;7-G<W1R("+'Z^7J]/'O[>GJWB#$Z>7]Z/7M\^<Z
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8Q"FUS9VED(")5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L'D_>WA
M].<@YR#P\?SSXN'SYR#S]._M(%9&4R#JX?3<Z^_C[RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3`P"FUS9VED(")5;F%B;&4@=&\@
M861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*
M;7-G<W1R("+!Y/WMX?3G(.<@\/'O\^C>ZN4@Y?#I\.O=[^T@\.OG\>_V[_'I
M_NT@ZN'TW"#TY^T@Y=_S[^3O(/3O]2#W\=[S].<N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-#8*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+!Y/WM
MX?3G(.<@X>OKX>/>(.7N[_7SZ>_D[_3>\^7Y[2#CZ>$@].\@5D93(.'Q]^7?
M[R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HU,#(*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(L'D_>WA].<@YR#AZ^OAX]X@Y>[O]?/I[^3O]-[SY?GM(./IX2#T
M[R!61E,@X?'WY=_O("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S`T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R("+!Y/WMX?3G(.<@X>OKX>/>(/3O]2`E<RXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-Q;"YP:'`Z,S<U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("+$Y>T@Y=_MX>D@Y/7MX?3>(.<@
M\_WMY.7SYR#S].\@Y.GAZN_LZ?/TWB!344PN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW.#@*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+B(*;7-G<W1R("+$Y>T@Y=_MX>D@Y/7MX?3>(.<@\_WMY.7SYR#L
MY2!34TPN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Q(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W-@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@
M(L'D_>WA].<@YR#A[?3IX_'A]MX@5D93(.'Q]^7?[_4N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,C`*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(L'D_>WA].<@YR#D
MY^SI[_7QX]_A(.KA].'K_./O]2!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(Y-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C<S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M-CD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`BP>3][>'TYR#G(.3G[.GO]?'CW^$@ZN'TX>O\X^_U(%9&4RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(V"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.?L
MZ>_U\>/?X2!61E,@X?'WY=_O]2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,3,*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(L'D_>WA].<@YR#DY^SI[_7QX]_A(.KE[>_](%9&
M4R#A\??EW^_U+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T
M87(N<&AP.C<Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP
M+G!H<#HX,@IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS
M9W-T<B`BP>3][>'TYR#G(.'P[_/U[/#?Y?/G(.3EY._LW>WY[2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(T.0IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*
M;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@7"(E<UPB+"#O(/;<ZN7K[_(@
MY.7M(.7?[>'I(.KE[?SR+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(W,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-C$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(L'D_>WA].<@
MYR#DZ>'C\>'VWB`E<RP@[R#VW.KEZ^_R(.3E[2#EW^WAZ2#JY>W\\B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-SD@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RXB"FUS9W-T<B`B
MP>3][>'TYR#G(.3IX>/QX?;>("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,X,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A
M]MX@ZN'TX>O\X^_U(%9&4R#E\.'MX>OLXN'M_.SE[>$@*')E8W5R<VEV96QY
M*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T.`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S8Q(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M-CD*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,W,PIM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+!
MY/WMX?3G(.<@Y.GAX_'A]MX@ZN'TX>O\X^_U(%9&4RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M.B`E<RXB"FUS9W-T<B`B1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC
M:'0@9V5L]G-C:'0@=V5R9&5N.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB#T[_4@5D93
M(.'Q]^7?[_4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(T,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(Q,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3<S(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ.#8*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$Y,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#$Q"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C
M\>'VWB#T[_4@5D93(.'Q]^7?[_4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS,S<*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RXB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(%9&4R#E
M\.'MX>OA[.+A[?SLY>WA("AR96-U<G-I=F5L>2DZ("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4R"FUS9VED(")5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("+$Y2#L\._Q_B#M
MX2#P\>_SY.GO\=_S^2#T[^T@]/'=]^_M].$@ZN'TW.OOX^\N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C<*;7-G:60@(E5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`BQ.4@
M[/#O\?X@[>$@Y>[<X_D@\.OG\>_V[_'?Y?(@\.GS]._P[^GG].GJ[_TB"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#8P(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$Q.0IM<V=I9"`B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(L'D_>WA].<@YR#V
M_/'T^?/G(._QZ?/L[_T@]._U("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$T,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-#4*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-"!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38Y"FUS9VED(")5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92XB"FUS9W-T<B`BP>3][>'TYR#G(.SE].'JW^WG\^<@
M]._U(%9&4R#A\???[_4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW.0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("+!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(%9&4R#A\??EW^_U(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C`@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$R-PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`BP>3][>'T[R#T[R#<
M[>_IX^SA(/3O]2!61E,@X?'WY=_O]2#CZ>$@X_'<^.GL[RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HW-"!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+B(*;7-G<W1R("+!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(%9&4R#A\??EW^_U
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#<*
M;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS
M9W-T<B`BQ.4@[/#O\?X@[>$@X>WOW^[Y(/3O(//U[/#IY?/LW>WO(.'Q]^7?
M[RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,C,*;7-G:60@
M(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T
M<B`BQ.4@[/#O\?X@[>$@Y.GAXMSS^2#T[^T@ZOWQZ>\@ZN'TW.OOX^\@5D93
M("AV9G-R;V]T*2XB"@IM<V=I9"`B56YA8FQE('1O(')E9VES=&5R('!R969E
M<F5N8V5S(&EN('-E<W-I;VXN(@IM<V=S='(@(L3E[2#EW^WAZ2#D]>WA]/SM
M(.WA(.KA].'W^?'GZ._][2#OZ2#P\>_TZ>S>\^7I\B#CZ>$@X?7TWB#TY^T@
M\_WMY.7SYRXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P.34*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N
M(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("+!Y/WMX?3G(.<@[.7T
M[^WO[.'SW^$@]._U("5S(//E("5S.B#O(/;<ZN7KZ^_R(/7PW/'WY>D@WN3G
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Q-0IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+!
MY/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#JX?3AZ_SC[_4N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR-34*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(L'D_>WA].<@
MYR#LY?3O[>_LX?/?X2#T[_4@5D93(.KA].'K_./O]3H@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.38*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+!Y/WMX?3G(.<@[.7T
M[^WO[.'SW^$@]._U(%9&4R#A\??EW^_U(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HU-C0@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(T,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E
M<R\E<RXB"FUS9W-T<B`BP>3][>'TYR#G(.SE]._M[^SA\]_A(/3O]2!61E,@
MX?'WY=_O]2`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C(T.2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(R"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT.#4@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,P-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S(V"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*
M;7-G<W1R("+!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#A\??EW^_U
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,0IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM
M<V=S='(@(L'D_>WA].<@YR#EZO3=Z^7SYR#T[_4@7")M:VES;V9S7"(N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HV,@IM
M<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B
M"FUS9W-T<B`BQ.7M(.SP_/'E\^4@[>$@[.7TX?;QX?/TY=\@X?7T_"#T[R#=
MX^/QX?;O(%=O<F0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$R
M-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$S,`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BQ.4@[/#O\?X@
M[>$@X_'<^/D@\_3O(%9&4R#A\??EW^\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$R,0IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`BQ.4@[/#O\?X@
M[>$@X_'<^.<@\_3O(%9&4R#A\??EW^\@*&-O<'DH*2#A\-WT]??E*2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C0@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$S-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82XB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@X_'<^/D@Y.7D[^S=[>$@
M]._U(%9&4R#A\??EW^_U+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("+5
M\._C\>'L[.GS[-WMX2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*
M;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+!ZOWQ^?/G(,'KZ^'C_NTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S
M"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+!ZO7Q
M_NWEZ2#TYR#TY>OE]?3AW^$@\^'R(.7MW?'CY>GA(@H*;7-G:60@(E5N97AP
M96-T960@96YD(&]F(&9I;&4N(@IM<V=S='(@(LSG(.'MX>SE[?SLY>WO(/3=
MZ^_R(/3O]2#A\??EW^_U+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(S,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.3D*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(LSG(.'MX>SE[?SL
MY>WG(.'PW.WTY_/G(.'P_"#T[^T@Y>[U\.?QY?3G]-X@\_3G(//][>3E\^<Z
M("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-3`*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,PIM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S
M='(@(LSG(.'MX>SE[?SLY>WG(.'PW.WTY_/G(.'P_"#T[^T@Y>[U\.?QY?3G
M]-X@\_3O.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU.`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV-`IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("+,YR#!\??E
MZ>_HY?3G[-WM[R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,S@T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F
M('1Y<&4Z("5S(@IM<V=S='(@(LSG(/?EZ?'IYOSLY>WO(//T[^GWY=_O(/3]
M\._U.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-2!L
M:6(O0FQO8VLO;65T87(N<&AP.C8Y"FUS9VED(")5;FET<R(*;7-G<W1R("+,
M[^W<Y.7R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$U
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-@IM<V=I9"`B56YK
M;F]W;B(*;7-G<W1R("+!X^WY\_3O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED(")5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(E5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(E5N:VYO=VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`BP>/M^?/T
M[R#\[>_LX2#W\=[S].<@WB#J^>3IZOSR+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B56YL
M:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`BP?#O\_WMY.7SYR#T
M\=WW[^WT[_(@\_3OZ??EW^_U(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED
M96YT:71Y+G!H<#HR.3@*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BP>W^[?7L
M[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E
M<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U
M<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO
M=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T
M<B`B(@HBS.<@Y>[O]?/I[^3O].?LW>WA(/#Q[^/QW.SLX?3A(.3E(.SP[_'O
M_>T@[>$@W??O]>T@\/'\\^+A\^<@\^4@Z^7I]._U\>/?Y?(@(@HBX?#OZN_P
MWO(OX>WTZ>/QX?;>\B_E\.GJ_.OG\^?R(./IX2#K_./O]?(@X?/VX>OEW^'R
M+B#0X?3>\_3E(,_*(./IX2#MX2#DY=_TY2`B"B+TY??MZ>K=\B#SY^SEZ?[S
MY>GR(//T[R!M;WII;&QA+F]R9R#P[_4@\^'R(.3EW_?M[_7M(/#Y\B#MX2#E
M\.GT\=WXY?3E(//E("(*(O#Q[^/QW.SLX?3A(/3G(/#Q_//BX?/G(//T[R!C
M;&EP8F]A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("+,
MYR#O\>GS[-WM[R#W\?[LX2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$P(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M.34R"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.34X"FUS
M9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`BS.<@]?#O\_3G
M\>GF_.SE[><@Y?#=ZO3A\^<B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,#8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3$*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S8*;7-G:60@(E5P9&%T92(*;7-G
M<W1R("+%[>?LW?'Y\^<B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,Q"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`BQ>WG[-WQ^?/G
M("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HV-#@*;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G
M<W1R("+%[>?LW?'Y\^<@ZN'TW//TX?/G\B#A\.'M].?LW>WO]2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*;7-G:60@(E5P9&%T
M92!U<V5R(@IM<V=S='(@(L7MY^S=\?GSYR#W\=[S].<B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$S-R!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,3<@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S,`IM<V=I9"`B57!D871E9"`G)7,G+B(*
M;7-G<W1R("(G)7,G(,7MY^SE\?[HY^KE+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@Q"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*
M;7-G<W1R("+4[R#P\?SC\>'L[.$@X>WAXMSH[.GSY_(@Y.GAX_'<]N?JY2XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<R(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ.#(*;7-G:60@(E5P;&]A9"(*;7-G
M<W1R("+!\._S]._KWB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*
M;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+B(*;7-G<W1R("+!\._S]._KWB#\Z_GM(/3Y[2#A\??E
MW_GM(/'UZ.S?\^7Y[2#S]._M(.7N]?#G\>7TY_3>+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G
M:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`BRN7VX>OAW^$@Z^'T
MZ>WIZMP@X_'<[.SA].$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N
M=6UB97)S(@IM<V=S='(@(M'Y[.'ZZN_?(.'QZ>CL[]\MRN7VX>OAW^$B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT
M-@IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(M?QWO/G(/3QW??O
M[?3O\CH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("+7\=[SYR!3
M4TPB"@IM<V=I9"`B57-E($1E9F%U;'0@5F%L=64B"FUS9W-T<B`BS>$@]_'G
M\^GL[_#OZ>?HY=\@YR#P\>_E\.GKY>/LW>WG(/3I[-XB"@IM<V=I9"`B57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BXB"FUS9W-T<B`BU_'G\^GL[_#OZ>7?].'I(.'M(/3O(/SM[^SA+^KYY.GJ
M_/(@Y=_MX>D@Y.GA]N_QY?3IZMPN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HV-3$*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+B(*;7-G<W1R("+/(/?QWO/TY_(@)7,@Y.7M(.7?
M[>'I(.7N[_7SZ>_D[_3G[-WM[_(@X^GA("5S+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C(P-`IM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+$
MZ>'WY=_QZ?/G(-?QY_/T_NTB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(L7PZ>OO
MX]WR(-?QWO/TYR(*"B,Z('-I9VYU<"YP:'`Z-C0*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(@IM<V=S='(@(L7CX_'A]MX@U_'>\_3G(@H*(SH@<VEG;G5P
M+G!H<#HQ.0IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`BQR#EX^/QX?;>(/?QWO/T
MYR#=]^7I(.'PY>WE\>/O\._IY^CEWR#CZ2<@X?7T_"#T[R!S:71E+B(*"FUS
M9VED(")5<V5R('!A<W-W;W)D(&-H86YG92(*;7-G<W1R("+!Z^OAX]X@ZOGD
MZ>KO_2#W\=[S].<B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-S(@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30*;7-G:60@(E5S97(@<&5R
M;6ES<VEO;G,B"FUS9W-T<B`BQ>[O]?/I[^3O]-[SY>GR(-?QWO/TYR(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P
M,B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$Q"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("*\[>_LX2#7\=[S
M].<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3,Q"FUS
M9VED(")5<V5R;F%M92`G)7,G(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("+4
M[R#\[>_LX2#W\=[S].<@)R5S)R#U\-SQ]^7I(-[DYRXB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G
M<W1R("*\[>_LX2#7\=[S].<Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("*\[>_LX2#7\=[S
M].<Z("(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(W"FUS
M9VED(")5<V5R<R(*;7-G<W1R("+7\=[S].7R(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z-`IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E
M;3HB"FUS9W-T<B`BU_'>\_3E\B#S].\@T_WS].?LX3HB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ,3`@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C`S"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("+/(.KA]-SK[^/O\B!61E,@Y.7M(/7PW/'WY>DN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,PIM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`BQ.GAZN_PW?(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-C`*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B
M"FUS9W-T<B`BN./J]?'E\B#T[_#OZ.7SW^7R(/#O]2#B\=WHY^KA[2#S]>SP
MY?'IZ^'LXMSM[^WTX>DZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8R"FUS9VED(")686QI9&ET>2(*;7-G<W1R("+%X^KU\?ST
MY_3A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C8S"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+B(*;7-G<W1R("+4Z>S>(//E(.OE\/3<(.'P_"#T_O'A+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDW(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,38*;7-G:60@(E9A;'5E<R(*;7-G<W1R
M("+4Z>S=\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.3(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$V.0IM<V=I9"`B5F%L=65S('1O('-E
M;&5C="!F<F]M(@IM<V=S='(@(L3^\_3E(/3I[-WR(./IX2#MX2#E\.GKW>[Y
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y,PIM<V=I9"`B
M5F%R:6%B;&4B"FUS9W-T<B`BS.7TX>+KY_3>(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR,C@*;7-G:60@(E9E<FEF:6-A=&EO;B!F
M86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W
M:71H+B(*;7-G<W1R("+'(.7PZ>+EXN'?^?/G(.'PW?3U]^4@+2#A]?3\(/3O
M(.S>[?7LX2#L\._QY=\@[>$@W.OKX>[E(.SE+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S(T"FUS9VED(")697)S:6]N(@IM<V=S
M='(@(KCJY._SYR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#`*
M;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("*XZ^7C]^_R(+CJY._S
MY_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("+*W.CE
M].<@Q?7H]>/QW.SLZ?/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G
M<W1R("+*W.CE].\@X]WLZ?/LX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R
M("+*W.CE].$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(M#OZ_T@^.?KWB(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDY,@IM<V=I9"`B5FEE
M=R`E<R(*;7-G<W1R("+%[/;<[>GSYR`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS
M9W-T<B`BQ>SVW.WI\^<@Y>[Y].7QZ>K>\B#I\_3O\^7KW^3A\B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-0IM<V=I9"`B5FEE
M=R!A<R`E<R(*;7-G<W1R("+%[/;<[>GSYR#SX>T@)7,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<Y"FUS9VED(")6
M:65W(&5V96YT(@IM<V=S='(@(L7L]MSMZ?/G(./EX^_M_/3O\B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`Y"FUS
M9VED(")6:65W('1A<VLB"FUS9W-T<B`BQ>SVW.WI\^<@Y?'CX?/?X?(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P-PIM<V=I9"`B5FES:6)I;&ET>2(*
M;7-G<W1R("+/\>'T_/3G].$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`W"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`BS_'A]/ST
MY_3A.B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@Q"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*
M;7-G<W1R(")6;V1A9F]N92#)].'KW^'R(.S=\_D@4TU44"(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,SD*;7-G:60@(E=!4DXB"FUS9W-T<B`BT-'/T\_7QR(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`BT-'/T\_7
MQR$A(2#!UL')T<73U,4@U,\@T-'/P]'!S,S!(,S/S<_)(-/!TR#!T,\@)7,N
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HS,0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+0
M\>_EZ>3O\._?Y_/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`BU.4B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C,W"FUS9VED(")7
M965K;'DB"FUS9W-T<B`BQ>+D[^SAY.GAW^$B"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("+*X>OY
M\][KZ.'TY2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU,`IM<V=I9"`B5V5L8V]M92!T;R`E
M<R(*;7-G<W1R("+*X>OY\][KZ.'TY2#S].\@)7,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C(*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(LKAZ_GSWNOHX?3E+"`E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C$*;7-G:60@(E=H870@
M87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM
M<V=S='(@(M#OZ=P@Y?;A\>SOX]X@Z.$@Y>SVX>S?YN7I(/3O("5S(.'V[_T@
M\_7MY.7HY=_TY2#S].?M(/7PY_'E\]_A.R(*"FUS9VED(")7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"!(;W)D92!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G
M<W1R("+0[^GA(.7VX?'L[^/>(.WA(.7L]N'MW^;E].'I(.'V[_T@\_7MY.7H
MY=_TY2#S].?M(/7PY_'E\]_A.R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(Q"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/R(*;7-G<W1R("+0[^G\\B#EW^WAZ2#O(.3IX??Y\>GS].GJ_/(@]^'Q
MX>KTWO'A\CLB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-`IM
M<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("+0
M[^G\\B#EW^WAZ2#O(/?A\>'J]-[QX?(@Y>GSX>/YX^GJ_NT[(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T
M<B`BT._IW?(@UMSSY>GR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M,0IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+B(*;7-G<W1R("(B"B+*X>CO\=_S].4@\._IW"#P\?SS
MZ.7TX2#HX2#E[>7QX^_P[^GGZ._][2#S]._M(.7PY>[E\>/A\_3>(.7L\.OO
M]?3I\^S=[>_U("(*(NKEZ>S=[>_U+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM
M<V=S='(@(M#KW/3O\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,#D*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("+0Z]ST[_(@
M\^4@[._MW.3E\B!#4U,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q
M"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K
M97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`BT.O<]._R(/3O
M]2`E<R#LY>WO_2#S].$@X?'I\_3E\=P@*.CA(.7VX?'L[_/HY=\@\_3G[2#E
M\/SLY>WG(.7?\^_D[RDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*
M;7-G<W1R("+0Z]ST[_(@]._U(/#?[>'JX2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET
M(@IM<V=S='(@(LSO[=SDX2#PZ]ST[_7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R("+0Z]ST[_(Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I
M9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("*X[?3A\^<@X>W=[._U
M(//E(.K\[.+O]?(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-`IM<V=I
M9"`B5VEN9#HB"FUS9W-T<B`BP>WE[._R.B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ.3$*;7-G:60@(E=I;F0Z("(*;7-G<W1R("+![>7L
M[_(Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES
M9&]M(@IM<V=S='(@(M/O]M_A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$W-PIM<V=I9"`B5VES:&QI<W1S(@IM<V=S='(@(LO?\_3A(.7PZ>CU
M[.G^[2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R
M:R(*;7-G<W1R("+%\>/A\]_A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,38W"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T
M<B`BQ.GE_>CU[?/G(,7QX^'SW^'R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-0IM<V=I9"`B5V]R:R!0:&]N92(*;7-G
M<W1R("+4Y^O=]OGM[R#%\>/A\]_A\B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,S0*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3<*;7-G:60@(E@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@PN'SZ>KO
MWR#0Y?'I[_'I\^SOWR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C$V"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM
M<V=S='(@(E@U,#EV,R#7\=[SYR#E\.7J].'LW>WO]2#JZ^7IY.GO_2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$X"FUS9VED(")8
M-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U,#EV
M,R#%[>'KX>KTZ>K\(+SM[^SA(,C=[.'T[_(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8Q.0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S(,'MX>/M^?'I\_3IZOP@
MRNOEZ>3?(,C=[.'T[_(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P-@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M6#4P.78S(,7PY>KTW//EZ?(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B65DB"FUS9W-T<B`BQ<4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@V"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,C<*;7-G:60@(EE965DB"FUS9W-T<B`BQ<7%
MQ2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M,S4*;7-G:60@(EEE87)L>2(*;7-G<W1R("+%]-[SZ>$B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@X"FUS9VED(")997,B
M"FUS9W-T<B`BS>'?(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E
M;65N=%]B;W1T;VTN:6YC.C8*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M("+-X>DL(-/U[/;Y[?XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RXB"FUS9W-T<B`B(@HBQ=_S].4@\^4@ZN'TW//TX?/G(,K%R<S%S<_5+B#7
M\>?SZ>SO\._IY=_S].4@].\@6SP^72#PZ][J]/'O(./IX2#MX2`B"B+E\.GS
M]/'=^.7TY2#SY2#JX?3<\_3A\^<@5UE325=)1RXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$S,C`*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N(@IM<V=S='(@(L3E[2#=]^7TY2#A]>CE[?3IZN_P[^GGZ.7?
M+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`T"FUS
M9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`BQ.7M(.7PZ?3QW?#E].'I(.WA(-WW
MY?3E(/3O(/?A\>'J]-[QX2`G7%PG(//T[R"\[>_LW"#SX?(N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.34X"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N(@IM<V=S='(@(L3E(.3^\^'TY2#=X^/U\><@Y.GE_>CU
M[?/G(&5M86EL+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(W-`IM
M<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I
M;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I
M;B`E<RXB"FUS9W-T<B`B(@HBQ.7M(.'M].GS]._I]]_SX?3E(.KA[=WMX2#P
MY>3?[R#A\/P@].\@X?'WY=_O(.7I\^'C^>/>\B#SY2#A[?3?\_3OZ??A(/#E
MY-_A("(*(O/T[R`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M-#0*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B
MN/?E].4@X?#O\_7MY.7HY=\N(@H*;7-G:60@(EEO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X\8G(@+SY4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN
M(@IM<V=S='(@(KCWY?3E(.'P[_/U[>3EZ.7?+CQB<B`O/L7U]^'QZ?/T[_WL
MY2#P[_4@]_'G\^GL[_#OZ=[SX?3E(/3G[2#U\.?QY?/?X2XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<Y"FUS9VED(")9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("+0\=WPY>D@[>$@Y/[SY?3E
M(.SIX2#=X^KU\><@].GLWBXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,S@*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(M#QW?#EZ2#M
MX2#Q]>CLW_/E].4@].\@1&%T851R964@X^GA(.WA(/?QY_/I[._P[^GEW_3E
M(%-I9VYU<',N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-#<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G
M<W1R("+0\=WPY>D@[>$@\?7H[-_SY?3E(/3O(%9&4RU"86-K96YD+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`BT/'=\.7I(.WA(/#E\>GC
M\=SXY?3E(/3O(/#Q_.+KY^SA(/#QZ>T@\_3EW^OE].4@X>WA]N_QW"#CZ>$@
MX?7T_"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`BT/'=\.7I(.WA(//U[/#KY_'^
M\^7TY2#T[R!54DP@\._U(.3EW_?MY>D@X?7TWB#G(//][>3E\^<B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+0\=WP
MY>D@[>$@Y?#IZ]WNY?3E(/3O[2#E[O7PY_'E].?TWB#CZ>$@Y.GAX_'A]MXN
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("+0\=WPY>D@
M[>$@[_'?\^7TY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#DZ>'C\>'VWBXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(M#QW?#EZ2#MX2#O\=_S
MY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA(.3IX>/QX?;>+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+B(*;7-G<W1R("+0\=WPY>D@[>$@[_'?\^7TY2#=[>$@_.WO[.$@]_'>\_3G
M(./IX2#P\>_SZ-[JYRXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS
M9W-T<B`BT/'=\.7I(.WA(._QW_/E].4@W>WA(/SM[^SA(/?QWO/TYR#CZ>$@
MY>WG[-WQ^?/G+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$T-`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+B(*;7-G<W1R("+0\=WPY>D@[>$@[_'?\^7TY2#LZ>$@
MY>W=\>/EZ>$@X^GA(.7J]-WKY?/G+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<S"FUS9VED(")9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(M#QW?#EZ2#MX2#D
M_O/E].4@W>WA(/SM[^SA(./IX2#TYR#MW>$@ZN'TY^/O\=_A+B(*"B,@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3,R+"!C+69O<FUA=`HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY,S(*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("+'(//]
M[>3E\^<@\^'R("5S(.3IX>K\\.?JY2X@T.'QX>KAZ_X@Y._JZ>S<\_3E(.WA
M(.[A[>'S]>WDY>CEW_3E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B
MQR#'Z^7J]/'O[>GJWB#SX?(@Q.GE_>CU[?/G(@H*;7-G:60@(EEO=7(@16UA
M:6P@061D<F5S<SHB"FUS9W-T<B`BQR#'Z^7J]/'O[>GJWB#SX?(@Q.GE_>CU
M[?/G.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.38*;7-G:60@(EEO
M=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`BQR#!\/PZ(,3IY?WH]>WSYSHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS
M9W-T<B`BS^D@T.OG\>_V[_'?Y?(@\^'R(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3,V"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(L<@26YT97)N970@Y.GE_>CU[?/>
M(//A\B#<Z^OA[N4@X?#\(/3G[2#=[>'Q[N<@].?R("5S(//][>3E\][R(//A
M\BX@P^GA(/3G[2`B"B+P\>_S].'SW^$@].?R(.'S]MSKY>GA\B#P\=WPY>D@
M[>$@[N'MX?/U[>3EZ.7?].4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("+4[R#\[>_L
MW"#SX?(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z.0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@
M(B(*(M3O(//]\_3G[.$@X?7HY>WTZ>KO\._?Y_/G\B#DY>T@]?#O\_3G\=_F
MY>D@\/'O\^C>ZN<@]_'G\_3^[2P@WB#G(.OEZ?3O]?'CW^$@(@HBX?7TWB#=
M]^7I(.'PY>WE\>/O\._IY^CEWR#CZ>$@ZMSP[^GO(.O\X^\N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHY"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(M3O(//]\_3G
M[.$@X?7HY>WTZ>KO\._?Y_/G\B#DY>T@]?#O\_3G\=_FY>D@Z]_S].$@]_'G
M\_3^[2P@WB#G(.OEZ?3O]?'CW^$@(@HBX?7TWB#=]^7I(.'PY>WE\>/O\._I
MY^CEWR#CZ>$@ZMSP[^GO(.O\X^\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.30P"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(L\@0G)O=W-E<B#SX?(@]N'?[>7T
MX>D@[>$@W??EZ2#AZ^O<[N7I(.'P_"#TY^T@W>WA\>[G(/3G\B`E<R#S_>WD
MY?/>\B#SX?(N("(*(L/IX2#TY^T@\/'O\_3A\]_A(/3G\B#A\_;<Z^7IX?(L
M(.CA(/#QW?#EZ2#MX2#NX>WA\_7MY.7HY=_TY2XB"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("+/($)R;W=S97(@\^'R(.3E
M[2#U\._S].?QW^;EZ2#A]?3>(/3G(.OEZ?3O]?'CW^$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z,C<*;7-G:60@(B(*(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S
M<R!#;VYT<F]L+T]P=&EO;B`K(%`@=&\@(@HB<')I;G0N(@IM<V=S='(@(B(*
M(L\@0G)O=W-E<B#SX?(@Y.7M(/7P[_/TY_'?YN7I(.'U]-X@].?M(.7PZ>OO
MX]X@Y>KT_?#Y\^?R+B#0X?3>\_3E($-O;G1R;VPO(@HB3W!T:6]N("L@4"#C
MZ>$@Y>KT_?#Y\^<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,0IM
M<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`BQR#T\=WW
M[_7SX2#F_NWG(/[QX?(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("+'(/#Q
M[^KAZ._QZ?/LW>WG(//A\B#TX?7T_/3G].$Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$X-PIM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@
M(M3O(/#KWO'E\B#\[>_LW"#SX?(Z(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S8*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,B"FUS9W-T<B`BSR#MW>_R(//A\B#J^>3IZOSR(./IX2`E<R#EW^WA
MZ3H@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-PIM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("+/Z2#E\.GK[^/=
M\B#SX?(@W??O]>T@Y>WG[.7Q^>CEWR#CZ>$@].<@Y.G<\>KEZ>$@X?7TWO(@
M].?R(//][>3E\^?R+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,34Y"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M(@IM<V=S='(@(L_I(.7PZ>OOX]WR(//A\B#=]^_U[2#E[>?LY?'YZ.7?+B(*
M"FUS9VED(")9;W5R('!A<W-W;W)D<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`B
MS^D@[=WOZ2#J^>3IZN_?(.3E[2#TX>GQZ=SF[_7M(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970B"FUS9W-T<B`BSR#J^>3IZOSR(//A\B#<Z^OA[N4B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@
M(B(*(L\@ZOGDZ>K\\B#SX?(@W.OKX>[E+"#EZ]WC[O3E(/3A(.SG[?WLX?3<
M(//A\B#JX>D@ZMSM].4@Y=_S[^3O(.SE(/3O(.W=[R#SX?(@(@HBZOGDZ>K\
M+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B
M66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BS^D@X?#O[.'J\?7S[-WM
M[^D@\^'R(.7N]?#G\>7TY_3=\CHB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1
M=6]T960@5&5X=%TB"FUS9W-T<B`B6\'P_.KQ]?CG(.KEZ>S=[>_U(//E(.7I
M\^'C^>/IZMQ=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z-38*;7-G:60@
M(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6\'MX?;O\=P@T/'OXNO>[.'T
M[_)=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6\7L]MSM
MZ?/G(.KEZ>S=[>_U(//E(.7I\^'C^>/IZMP@+2(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EO%
M[/;<[>GSYR#JY>GLW>WO]2#SY2#EZ?/AX_GCZ>K<("T@)7,@X_'A[.S=\ETB
M"@HC(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY+"!C+69O<FUA=`HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B6VQI;F4@
M)7,@;V8@)7-=(@IM<V=S='(@(EOC\>'L[-X@)7,@X?#\("5S72(*"FUS9VED
M(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`BQ.GA]^7?\>GSYR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`BQ.GAX_'A]MX@P_'A[.S>
M\B(*"B,Z(&QI8B]A<&DN<&AP.C$Q-`IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R
M("+/[-SDY?(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3@Q"FUS9VED(")?2&5L<"(*;7-G<W1R("+"[][HY>GA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS
M9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+)Y.G\].?TY?(@
MQ>GJ_.WA\BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HR,#`*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BQ=_S[^3O\B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.38*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(L7N[^3O\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(M3Q[_#O\._?Y_/G(-/][>3E\^SO]2XN+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S`*;7-G:60@(E]/
M<'1I;VYS(@IM<V=S='(@(L7PZ>OOX]WR(@H*(SH@;&EB+V%P:2YP:'`Z,3$X
M"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ>[O]?/I[^3O]-[SY>GR
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`BQ.GA
MX_'A]MX@T_7MY-WS[._U+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3`V"FUS9VED
M(")?4V5T=7`B"FUS9W-T<B`BT?7H[-_SY>GR(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")?
M5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+)Y.G\].?TY?(@T-_MX>KA
M+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3$P"FUS9VED(")?57-E<G,B"FUS9W-T
M<B`BU_'>\_3E\B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$Q
M"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`BQ.GE]>CU[?/I[^/QW/;O
M\B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`S"FUS9VED(")C
M86QE;F1A<B(*;7-G<W1R("+'[.7Q[^O\X^GO(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-S`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-38*;7-G:60@(F-A
M;&TB"FUS9W-T<B`BY_'E[-_A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-C`X"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(O#A
M]-[S].4@Y>3^(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#<P"FUS9VED(")F:6QE(@IM<V=S='(@(N'Q]^7?[R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S@T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S(@IM<V=S='(@(N'P_"#T[R`E<R`H)7,I(//TZ?(@)7,@)7,B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS
M9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R.0IM<V=I9"`B:6UM961I871E
M(@IM<V=S='(@(MSLY?/A(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C@@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-S8*;7-G:60@(FEN;&EN92(*;7-G<W1R
M("+E[?/Y[.'T^>S=[>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(N/QX>SLW?)=
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@
M;6%K:6YG($E33RXB"FUS9W-T<B`B;6MI<V]F<RWJ^>3IZOSR(.O<Z._U\B`E
M9"#JX?3<(/3G(.3G[.GO]?'CW^$@25-/+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,C@X('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HR,#8*;7-G:60@(FYA;64B"FUS9W-T<B`B_.WO[.$B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00RYP:'`Z,3(R"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS
M9W-T<B`BY.7M(-WWY>D@Y>/JX?3A\_3AZ.7?(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C0U"FUS9VED(")N;W0@>65T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(N3E[2#=]^7I(.7CZN'TX?/TX>CEWR#AZOSLYR(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.#DU"FUS9VED(")N;W1E
M<&%D(@IM<V=S='(@(O/G[.7I^>SA]-SQZ>\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C
M96YT(@IM<V=S='(@(O3OZ?(@Y>KA]/PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B
M"FUS9W-T<B`BY>GJ[^WO\_3OZ??EW^$B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.CDX"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(N7L
M]MSMZ?/G(.3IX?;O\?[M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S,*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%14
M4"(*;7-G<W1R(")S;7,@\^4@96UA:6P@[-WS^2!(5%10(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-`IM<V=I9"`B<W1E861Y(@IM<V=S
M='(@(O/TX>CE\?SR(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,3D*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("+KW_/TX2#E\>/A\^G^[2(*
M"FUS9VED(")T<F%S:"(*;7-G<W1R("+JW.3O\B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR.#(*;7-G
M:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T
M<B`BP_'<^/3E(/3O[2#J^>3IZOP@Y/WO(/;O\=WR(./IX2#E\.GBY>+AW_GS
MYR(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8X(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<V"FUS9VED(")U;FEF:65D(@IM<V=S='(@(N7M[_#OZ>?LW>WA
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HQ-PIM<V=I9"`B
M=6YN86UE9"(*;7-G<W1R("+A[?[M]>SA(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Y"FUS9VED(")U<V5R
M('-E;&5C="(*;7-G<W1R("+E\.GK[^/>(/?QWO/TYR(*"FUS9VED(")V0V%R
M9"(*;7-G<W1R("+8Y_;IX>K>(,K<\?3A(@H`````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O97-?15,N<&\`
M````````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#<Q-30T-0`Q,#0Q-S,V,S`P,0`P,38T,#``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!3<&%N:7-H('1R86YS;&%T:6]N
M<R!F;W(@:&]R9&4@<&%C:V%G90HC(%1R861U8V-I;VYE<R!A;"!E<W!A\6]L
M('!A<F$@96P@<&%Q=65T92!H;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@
M2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E
M<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K86=E+@HC($%U
M=&]M871I8V%L;'D@9V5N97)A=&5D+"`R,#`T+@HC"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,34@,3<Z,C0K,#$P,%QN(@HB
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-2`Q-SHR-"LP,3`P7&XB"B),
M87-T+51R86YS;&%T;W(Z($UA;G5E;"!0+B!!>6%L82`\;6%Y86QA0'5N97@N
M97,^7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN
M(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([
M('!L=7)A;#TH;B`A/2`Q*3M<;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,S<S"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S
M='(@(B`H:&%C92`E<R!D[6%S*2(*"B,Z(&QI8B](;W)D92YP:'`Z,3,W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B
M("A!8V-E9&EE;F1O(&$@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R
M("(@*&5N("5S(&3M87,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*
M;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H:&]Y*2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@
M*&UA\6%N82DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0IM<V=I9"`B
M("AY97-T97)D87DI(@IM<V=S='(@(B`H87EE<BDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM
M<V=I9"`B(&%T("(*;7-G<W1R(")E;B`B"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E
M8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!N;R!E<R!U;B!D:7)E8W1O<FEO+B(*
M"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S
M7"(@;F\@97,@=6YA(&5L96-C:?-N(';A;&ED82XB"@HC.B!L:6(O2&]R9&4O
M4F5G:7-T<GDN<&AP.C<Q,"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B3F\@<V4@:&$@8V]N
M9FEG=7)A9&\@7"(E<UPB(&5N(&5L(')E9VES=')O(&1E($AO<F1E+B(*"B,Z
M(&QI8B](;W)D92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S
M92!E;F-O;G1R\R!E;"!G96YE<F%D;W(@9&4@X7)B;VQE<R!D92!<(B5S7"(N
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G
M<W1R(")392!H82!A\6%D:61O(%PB)7-<(B!A;"!S:7-T96UA(&1E(&=R=7!O
M<RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO
M;G,@<WES=&5M+B(*;7-G<W1R(")392!H82!A\6%D:61O(%PB)7-<(B!A;"!S
M:7-T96UA(&1E('!R:79I;&5G:6]S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(").
M;R!S92!H82!C<F5A9&\@7"(E<UPB.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@
M;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B57-A9&]S("4N
M,F9-0B!D92`E+C)F34(@<&5R;6ET:61O<R`H)2XR9B4E*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S('D@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@
M<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B475E9&%N("5D(&3M87,@:&%S
M=&$@<75E(&5X<&ER92!L82!C;VYT<F%S9?%A+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M
M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D('!R;V[S<W1I8V]S(&1I87)I;W,B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!!=FES;R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(DAU96QL82!D:6=I=&%L
M(&1E("5S(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,2!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@
M;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;R`M($-O;F9I<FUA8VGS;B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G
M<W1R(")#;VYF:6=U<F%C:?-N(&1E("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5
M<"(*;7-G<W1R(")&:7)M82!D92`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!
M9W)E96UE;G0B"FUS9W-T<B`B06-U97)D;W,@9&4@;&EC96YC:6$@9&4@)7,B
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#,R(&QI8B]61E,O<VUB+G!H<#HT.30@
M;&EB+U9&4R]F='`N<&AP.C8X,@HC.B!L:6(O5D93+V9T<"YP:'`Z-S4P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R
M(")982!E>&ES=&4@)7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS
M9W-T<B`B)7,@82!L87,@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B
M"B(E<R!E<W3A('!R97!A<F%D;R!P87)A(')E86QI>F%R(&QA<R!O<&5R86-I
M;VYE<R!D92!M86YT96YI;6EE;G1O("(*(G-E;&5C8VEO;F%D87,N06-T:79E
M(&QA<R!C87-I;&QA<R!D92!L87,@;W!E<F%C:6]N97,@<75E(&1E<V5A(&5J
M96-U=&%R(&5N("(*(F5S=&$@;V-A<VGS;BXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E
M9"(*;7-G<W1R(")(86-E(&9A;'1A("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G
M<W1R("(E<R!M:6YU=&]S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(DYO('-E(&AA(&5N8V]N=')A9&\@)7,N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!A;"`E<R!D92`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D1I<F5C8VEO;F5S(&1E("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$@9&4@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($YO=&5P860B"FUS9W-T<B`B3&EB<F5T82!D92!N;W1A<R!D92`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B5&%R96%S(&1E("5S(@H*
M(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@
M)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@HB)7,Z($5S=&4@;65N<V%J92!P=65D92!Q=64@;F\@<')O8V5D82!D
M92!Q=6EE;B!P87)E8V4@<V5R+B!%=FET92!S96=U:7(@(@HB8W5A;'%U:65R
M(';M;F-U;&\@:6YC;'7M9&\@;R!S=6UI;FES=')A<B!C=6%L<75I97(@:6YF
M;W)M86-I\VX@<&5R<V]N86P@86P@(@HB<F5M:71E;G1E+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L('9E
M;G1O<V\@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG
M("5S("5S(@IM<V=S='(@(BP@=F5N=&]S;R`E<R`E<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B
M;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FEA8FQE(&1E("5S(&$@
M)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W,R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$S,B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C,T."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B
M+2T@<V5L96-C:6]N87(@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*
M;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@,3(@
M:&]R87,B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO
M=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@,C0@:&]R87,B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS
M9W-T<B`B,C0@:&]R87,B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y
M"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/$%N=&5R:6]R(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B4&%R82!E
M<W1E(&)L;W%U92!H86-E(&9A;'1A('5N(&UO=&]R(&1E(&)A<V4@9&4@9&%T
M;W,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C(*;7-G:60@(D$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(E-E(&AA('!R;V1U8VED;R!U;B!E
M<G)O<B!I<G)E<&%R86)L92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B2&%C92!F86QT82!U;F$@8VQA
M=F4@4$=0('#Z8FQI8V$@<&%R82!C:69R87(@=6X@;65N<V%J92XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R(")(86-E(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82!P
M87)A(&-O;7!R;V)A<B!U;B!M96YS86IE(&9I<FUA9&\N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DAA
M8V5N(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'
M4"!P<FEV861A('D@=6YA(&9R87-E(&-L879E("(*(G!A<F$@9&5S8VEF<F%R
M('5N(&UE;G-A:F4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q
M-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*(DAA8V5N(&9A;'1A('5N82!C;&%V92!01U`@
M</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R87-E(&-L
M879E("(*(G!A<F$@9FER;6%R('5N(&UE;G-A:F4N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B
M"B)(86-E;B!F86QT82!U;F$@8VQA=F4@4R]-24U%('#Z8FQI8V$L('5N82!C
M;&%V92!3+TU)344@<')I=F%D82!Y('5N82!F<F%S92`B"B)C;&%V92!P87)A
M(&1E<V-I9G)A<B!U;B!M96YS86IE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB2&%C96X@9F%L
M=&$@=6YA(&-L879E(%,O34E-12!P^F)L:6-A+"!U;F$@8VQA=F4@4R]-24U%
M('!R:79A9&$@>2!U;F$@9G)A<V4@(@HB8VQA=F4@<&%R82!F:7)M87(@=6X@
M;65N<V%J92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM
M<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R(")(86-E(&9A;'1A('5N82!C;&%V92!3
M34E-12!P^F)L:6-A('!A<F$@8VEF<F%R('5N(&UE;G-A:F4N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(DYU8F5S(&UA=&EN86QE<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H
M="!286EN(@IM<V=S='(@(DQI9V5R82!L;'5V:6$@;6%T:6YA;"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!
M32!286EN(@IM<V=S='(@(DQL=79I82!M871I;F%L(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E
M<G,B"FUS9W-T<B`B06=U86-E<F]S(&UA=&EN86QE<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B06=U86-E<F\@;6%T:6YA;"!D92!N:65V92(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*
M;7-G<W1R(")!32]032(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B240@9&4@05!)(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM
M<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B06-E<F-A(&1E;"!E
M9&ET;W(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B
M06)O=70N+BXB"FUS9W-T<B`B06-E<F-A(&1E+BXN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T
M=&]M(@IM<V=S='(@(DEN9F5R:6]R($%B<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B
M"FUS9W-T<B`B16X@;65D:6\@06)S+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(")392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E
M87(@96P@9&ER96-T;W)I;R!61E,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*
M;7-G<W1R(")392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@96P@
M87)C:&EV;R!61E,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G
M:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B261E;G1I9&%D(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U
M;G0@4&%S<W=O<F0B"FUS9W-T<B`B0V]N=')A<V7Q82!D92!A8V-E<V\B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B
M06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(DED96YT:61A9"!B;&]Q=65A9&$N
M(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED
M(")!8V-O=6YT:6YG(@IM<V=S='(@(D-O;G1A8FEL:61A9"(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ
M,0IM<V=I9"`B061D(@IM<V=S='(@(D'Q861I<B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI
M;&0@1W)O=7`B"FUS9W-T<B`B0?%A9&ER(&=R=7!O(&1E<V-E;F1I96YT92(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B0?%A9&ER('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R
M(")!\6%D:7(@87%U[3HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI
M;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R
M(")!\6%D:7(@9W)U<&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W
M(&QI8B](;W)D92]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R
M;6ES<VEO;B(*;7-G<W1R(")!\6%D:7(@<')I=FEL96=I;R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@
M(D'Q861I<B!A(%PB)7-<(B!U;B!G<G5P;R!D97-C96YD:65N=&4B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")!
M\6%D:7(@82!<(B5S7"(@=6X@<')I=FEL96=I;R!D97-C96YD:65N=&4B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM
M<V=S='(@(D'Q861I<B!U;B!U<W5A<FEO.B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`B0?%A9&ER(&-O;'5M;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T
M<B`B0?%A9&ER(&UI96UB<F]S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B0?%A9&ER('!A<B(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(B"FUS9W-T<B`B0?%A9&ER(&5L(&UE;OH@)7,@8V]M;R!P86YE;"!L871E
M<F%L(&1E($UO>FEL;&$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R
M(")!\6%D:7(@82!L87,@9&ER96-C:6]N97,Z(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E
M<W,@8F]O:R(*;7-G<W1R(")!\6%D:7(@82!L87,@9&ER96-C:6]N97,Z(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@
M(D'Q861I<B!U<W5A<FEO(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL
M(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T
M:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB4V4@:&$@8?%A9&ED;R!<(B5S7"(@
M86P@<VES=&5M82P@<&5R;R!N;R!S92!P=65D92!A\6%D:7(@;&$@:6YF;W)M
M86-I\VX@(@HB861I8VEO;F%L(&1E(&%L=&$Z("5S+B(*"B,Z('-I9VYU<"YP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B4V4@:&$@
M8?%A9&ED;R!<(B5S7"(@86P@<VES=&5M82X@66$@<'5E9&4@:6YI8VEA<B!L
M82!S97-I\VXN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC
M.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B
M3&$@861I8VGS;B!D92!U<W5A<FEO<R!E<W3A(&1E<VAA8FEL:71A9&$N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N
M(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED
M(")!9&1R97-S($)O;VLB"FUS9W-T<B`B1&ER96-C:6]N97,B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')A
M9&]R("T@9&5F:6YE('!R:79I;&5G:6]S(&1E(&]T<F]S('5S=6%R:6]S(@H*
M(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN
M:7-T<F%C:?-N(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z
M,S0S"FUS9VED(")!9',B"FUS9W-T<B`B06YU;F-I;W,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H
M86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=.%N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*
M;7-G<W1R(")!;&)A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!<F=E
M;&EA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*
M;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI
M9VXB"FUS9W-T<B`B06QI;F5A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T
M<B`B06QI;F5A8VGS;CHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*
M;7-G:60@(D%L;"(*;7-G<W1R(")4;V1O<R(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G
M:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E1O9&]S(&QO
M<R!U<W5A<FEO<R!A=71E;G1I9FEC861O<R(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B
M"FUS9W-T<B`B5&]D;W,@;&]S(&=R=7!O<R(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM
M<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1O9&]S(&QO<R!P<FEV
M:6QE9VEO<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(E1O9&]S(&QO<R!L861O<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<U
M"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B4&5R
M;6ET:7(@=F%R:6%S(&1I<F5C8VEO;F5S(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/R(*;7-G<W1R("*_4&5R;6ET:7(@8V]N9FEG=7)A8VGS
M;B!D92!T:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_(@H*(SH@;&EB+TAO<F1E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*
M;7-G<W1R(")982!E>&ES=&4B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@
M(D%C8V5S;R!)35-0(&%L=&5R;F%T:79O(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R
M9"(*;7-G<W1R(")#;&%V92!)35-0(&%L=&5R;F%T:79A(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M92(*;7-G<W1R(")5<W5A<FEO($E-4%,@86QT97)N871I=F\B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT
M97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N(&5L96-T
M<O-N:6-A(&%L=&5R;F%T:79A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B4&QA;G1I
M;&QA<R!A;'1E<FYA=&EV87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T
M92!T97AT.B(*;7-G<W1R(")497AT;R!A;'1E<FYA=&EV;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M
M97)I8V%N(%-A;6]A(@IM<V=S='(@(E-A;6]A($%M97)I8V%N82(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB
M"FUS9W-T<B`B4V4@:&$@:6YD:6-A9&\@=6X@=F%L;W(@:6QE9V%L+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(E-E(&AA('!R;V1U
M8VED;R!U;B!E<G)O<B!D97-C;VYO8VED;RXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM
M<V=S='(@(D%N9&]R<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY
M(@IM<V=S='(@(E!R;WAY(&%N\VYI;6\B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E)E<W!U97-T
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YTX7)T:61A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A('D@0F%R
M8F%D;W,B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H
M96QL+G!H<#HS-2!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T
M:6]N(@IM<V=S='(@(D%P;&EC86-I\VXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B3&ES
M=&$@9&4@87!L:6-A8VEO;F5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(DQA
M(&%P;&EC86-I\VX@97-TX2!L:7-T82XB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM
M<V=S='(@(D%P;&EC87(@82!R96-U<G-O<R!C;VUP87)T:61O<R!D97-C96YD
M:65N=&5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B07!R;V)A<B(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#$*;7-G:60@(D%P<')O>&EM871E
M(%-I>F4B"FUS9W-T<B`B5&%M8?%O(&%P<F]X:6UA9&\B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B
M06)R:6PB"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED
M(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07+A8FEG;R`H5VEN
M9&]W<RTQ,C4V*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C4Y(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E($9I
M;&4@4VEZ92(*;7-G<W1R(")486UA\6\@9&5L(&%R8VAI=F\B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DYO;6)R92!D
M96P@87)C:&EV;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(#\B"FUS9W-T<B`BOT5S=&$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA
M<B!L82!S;VQI8VET=60@9&4@86QT82!D92`E<S\B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@
M86YY('-U8BUG<F]U<',_(@IM<V=S='(@(K]%<W3A('-E9W5R;R!D92!Q=64@
M9&5S96$@96QI;6EN87(@7"(E<UPB('D@=&]D;W,@<W5S('-U8F=R=7!O<S\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M07)M96YI82(*;7-G<W1R(")!<FUE;FEA(@H*(SH@8V]N9FEG+RYB86LO;FQS
M+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS
M9W-T<B`B07)M96YI;R`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(D%R=&4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("))<VQA($%S
M8V5N<VGS;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B
M07-C:6D@07)T(@IM<V=S='(@(D=RX69I8V]S($%S8VEI(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I
M;VXB"FUS9W-T<B`B4F5G:?-N(&1E($%S:6$O4&%C[69I8V\B"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/R(*;7-G<W1R("(B"B*_4V]L:6-I=&%R(&-O;F9I<FUA8VGS;B!A;G1E<R!D
M92!R96%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O/R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,#DY"FUS9VED(")!<W-I9VYM96YT(&-O
M;'5M;G,B"FUS9W-T<B`B0V]L=6UN87,@9&4@87-I9VYA8VGS;B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("));G1E;G1A(&5L:6UI;F%R
M('5N(&=R=7!O(&EN97AI<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DEN=&5N=&$@96QI;6EN87(@=6X@
M<')I=FEL96=I;R!I;F5X:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(DEN=&5N=&$@;6]D:69I8V%R('5N('!R
M:79I;&5G:6\@:6YE>&ES=&5N=&4N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N(@IM<V=S='(@(DEN=&5N=&$@;6]D:69I8V%R('5N(')E8W5R
M<V\@8V]M<&%R=&ED;R!I;F5X:7-T96YT92XB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HW,0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM
M<V=I9"`B071T<FEB=71E<R(*;7-G<W1R(")!=')I8G5T;W,B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S
M='(@(D%G;W-T;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%L
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(D%U<W1R:6$B"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]C>7)S<6PZ($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!I;6%P
M(&YE8V5S87)I82XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U
M"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z($5L(&UO
M=&]R(&-A<F5C92!D92!L87,@8V%P86-I9&%D97,@;F5C97-A<FEA<RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?8WER=7,Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!I
M;6%P(&YE8V5S87)I82XB"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V
M"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T
M<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!.;R!S92!E;F-O;G1R
M\R!L82!E>'1E;G-I\VX@1E10(&YE8V5S87)I82X@0V]M<&EL92!02%`@8V]N
M(&QA("(*(F]P8VGS;B`M+65N86)L92UF='`N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($YO
M('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!)34%0(&YE8V5S87)I82XB"@HC
M.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?:W)B-3H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&MR8C4@
M;F5C97-A<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM
M<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z
M($YO(&5S=.$@<V]P;W)T861A(&QA(&%D:6-I\VX@9&4@=7-U87)I;W,@9&4@
M06-T:79E($1I<F5C=&]R>2(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U
M=&A?;&1A<#H@3F\@97-TX2!S;W!O<G1A9&$@;&$@96QI;6EN86-I\VX@9&4@
M=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>2(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!.
M;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@3$1!4"!N96-E<V%R:6$N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L
M9&%P.B!.;R!S92!P=65D92!A\6%D:7(@96P@=7-U87)I;R`E<RX@R7-T;R!E
M<R!L;R!Q=64@9&EJ;R!E;"`B"B)S97)V:61O<CH@(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?
M;&1A<#H@26YC87!A>B!D92!E;&EM:6YA<B!E;"!U<W5A<FEO("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S
M='(@(D%U=&A?;&1A<#H@26YC87!A>B!D92!A8W1U86QI>F%R(&5L('5S=6%R
M:6\@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@
M(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!.
M;R!E<W3A('-O<&]R=&%D82!L82!A8W1U86QI>F%C:?-N(&1E('5S=6%R:6]S
M(&1E($%C=&EV92!$:7)E8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L
M+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@3F\@<V4@96YC
M;VYT<O,@;&$@97AT96YS:?-N($U#04P@;F5C97-A<FEA+B(*"B,Z(&QI8B](
M;W)D92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q
M=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7W-M8F%U=&@Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!S;6)A
M=71H(&YE8V5S87)I82XB"@HC.B!L:6(O2&]R9&4O24U!4"]!9&UI;BYP:'`Z
M,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(D9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@
M<V5R=FED;W(@24U!4"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S
M='(@(D9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A
M=&EO;B!F86EL960N("5S(@IM<V=S='(@(D9A;&SS(&QA(&%U=&5N=&EF:6-A
M8VGS;BX@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BXB"FUS9W-T<B`B16P@<V5R=FED;W(@4D%$2553(&AA(')E8VAA>F%D;R!L
M82!A=71E;G1I9FEC86-I\VXN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@X,@IM
M<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(D9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@<V5R=FED
M;W(@1E10+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&
M86QL\R!L82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R(%--0BXB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I
M;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#86UP;W,@9&ES<&]N:6)L97,Z(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I:F%N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS
M9W-T<B`B17AC=7-A<R!"3T9((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*
M;7-G<W1R(")&;VYD;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T
M<B`B0V]L;W(@9&4@9F]N9&\B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H
M<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")#
M;VYT<F%S9?%A(&ME<F)E<F]S(&EN8V]R<F5C=&$N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B3F]M8G)E(&1E('5S=6%R:6\@:V5R8F5R;W,@:6YC;W)R
M96-T;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M87,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O+F)A:R]N
M;',N<&AP+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*
M;7-G<W1R(")"X6QT:6-O("A)4T\M.#@U.2TQ,RDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D
M97-H(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G
M<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!D
M:7)E8W1O<FEO(&)A<V4@9&4@:6WA9V5N97,@7"(E<UPB+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I
M9"`B0F%S96QI;F4B"FUS9W-T<B`B3.UN96$@8F%S92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R
M=7,B"FUS9W-T<B`B0F5L87)U<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B
M0NEL9VEC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T
M<B`B0F5R;75D87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@
M(D)I<G1H9&%Y(@IM<V=S='(@(D-U;7!L96'Q;W,B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8P"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!B;&]Q=64@7"(E<UPB(&1E
M(&QA(&%P;&EC86-I\VX@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M3W!C:6]N97,@9&4@8FQO<75E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1I<&\@9&4@
M8FQO<75E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(DYE9W)I=&$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M;VQI=FEA(@IM<V=S='(@(D)O;&EV:6$B"@HC.B!C;VYF:6<O+F)A:R]R96=I
M<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")-
M87)C861O<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(D)O<F1E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B1W)O<V]R(&1E
M;"!B;W)D93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(D)O<F1E
M<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S
M;FEA($AE<GIE9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV
M"FUS9VED(")";W1H(@IM<V=S='(@(D%M8F]S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B
M"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R
M("));F9E<FEO<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B27-L
M82!D92!";W5V970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R
M(")497)R:71O<FEO(&]C9>%N:6-O(&1E(&QA($EN9&EA(&)R:73A;FEC82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U
M<W-A;&%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS
M9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(DQI<W1A(&1E<V]R9&5N861A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R\N
M8F%K+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@
M(D--4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS
M9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM
M<V=S='(@(E!U;G1O<R!D92!D:7-T<FEB=6-I\VX@0U)#(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS
M9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!I961A9&5S
M(&1E(%]C96QD82XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM
M<V=S='(@(DYO('-E(&AA(&9I;F%L:7IA9&\@96P@:6YI8VEO(&1E(&QA(&-A
M8VCI+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M.#4@8V]N9FEG+RYB86LO:&]O:W,N<&AP+F1I<W0Z,3`T,`HC.B!C;VYF:6<O
M+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM
M<V=S='(@(D%G96YD82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B0V%L;6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M
M8F]D:6$B"FUS9W-T<B`B0V%M8F]Y82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S
M='(@(D-A;65R^FXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3F\@
M<V4@<'5E9&4@<F5A:G5S=&%R(&QA(&-L879E(&%U=&]MX71I8V%M96YT92P@
M</-N9V%S92!E;B!C;VYT86-T;R!C;VX@96P@(@HB861M:6YI<W1R861O<B!D
M96P@<VES=&5M82XB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,U,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM
M<V=S='(@(DYO('-E('!U961E(&5S8W)I8FER(&5N(&5L(&%R8VAI=F\@7"(E
M<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@
M(DYO('-E('!U961E;B!A9&UI;FES=')A<B!M86YE:F%D;W)E<R!D92!S97-I
M\VX@97AT97)N;W,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(S
M-2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G
M<W1R(").;R!S92!P=65D92!C;VYE8W1A<B!A;"!S97)V:61O<B!)34%0.B`E
M<R(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYO('-E('!U
M961E(&%B<FER(&5L(&%R8VAI=F\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*
M;7-G<W1R(")#86YA9.$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO
M=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E
M;"(*;7-G<W1R(")#86YC96QA<B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`B0V%N8V5L87(@:6YF;W)M92!D92!P<F]B;&5M87,B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D
M96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYO('-E('!U961E(&5L:6UI
M;F%R(&5L(&%R8VAI=F\@7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").
M;R!S92!E;F-U96YT<F$@=6X@9&ER96-T;W)I;R!T96UP;W)A;"XB"@HC.B!L
M:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B3F\@
M<V4@<'5E9&4@8V]N=&EN=6%R('-I;B!E;"!P87+A;65T<F\@)W1A<F=E=$9I
M;&4G+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R
M(").;R!S92!P=65D92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%PB)7-<(BXB
M"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$R."!L:6(O2&]R9&4O1&%T
M851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DYO('-E('!U
M961E(&5L:6UI;F%R+"!T:65N92`E9"!D97-C96YD:65N=&5S+B(*"B,Z(&QI
M8B](;W)D92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@
M(B(*(DYO('-E('!U961E(')E;W)D96YA<BP@96P@;OIM97)O(&1E(&5N=')A
M9&%S('%U92!S92!D97-E82!O<F1E;F%R(&YO("(*(F-O:6YC:61E(&-O;B!L
M87,@86QM86-E;F%D87,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DYO('-E('!U961E(&1I<FEG:7(@
M96P@;65N<V%J92!A;"!N^FUE<F\@97-P96-I9FEC861O+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A
M<&4@5F5R9&4B"FUS9W-T<B`B0V%B;R!697)D92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A
M<'1I;VXB"FUS9W-T<B`B4W5B=.UT=6QO(@H*(SH@;&EB+TYE="]335,O9V5N
M97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B4')O
M=F5E9&]R(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3,*;7-G
M:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")#871E9V]R[6%S
M('D@971I<75E=&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@
M(DES;&%S($-A:6WA;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(E1E;.EF;VYO
M(&WS=FEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!I961A9&5S(&1E(&-E;&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B36%R9V5N(&1E(&-E;&1A.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@
M<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P:65D861E<R!D92!C96QD82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS
M9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(D5S<&%C:6%D;R!D92!C96QD
M83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H
M;VYE(@IM<V=S='(@(E1E;.EF;VYO(&WS=FEL(@H*(SH@8V]N9FEG+RYB86LO
M;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB
M"FUS9W-T<B`B0^EL=&EC;R`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B
M0V5N=&5R(@IM<V=S='(@(D-E;G1R87(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($-E;G1R;V%F<FEC86YA
M(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N
M=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B175R;W!A($-E
M;G1R86P@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
M1&5T86QL97,@9&5L(&-E<G1I9FEC861O(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S
M='(@(E!R;W!I971A<FEO(&1E;"!C97)T:69I8V%D;R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI
M8VEE<R(*;7-G<W1R(")0;VSM=&EC87,@9&5L(&-E<G1I9FEC861O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")#:&%D(@IM<V=S='(@(D-H860B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B0V%M8FEA<B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`B0V%M8FEE(&QA(&-O;G1R87-E\6$B"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*
M(D-A;6)I82!E;"!N;VUB<F4@>2!L82!D:7)E8V-I\VX@96QE8W1R\VYI8V$@
M=FES:6)L97,@86P@;&5E<B!O(')E<W!O;F1E<B!A("(*(G-U<R!M96YS86IE
M<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@
M(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3&$@8V]N9FEG=7)A8VGS
M;B!A8W1U86P@;F\@<V]P;W)T82!E;"!C86UB:6\@9&4@8V]N=')A<V7Q87,N
M(%#S;F=A<V4@96X@(@HB8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@
M9&5L('-I<W1E;6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")'<N%F
M:6-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")6
M97)I9FEC87(@7W;M;F-U;&\N+BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")#
M:&EL92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(D-H:6YA(@H*(SH@8V]N9FEG
M+RYB86LO;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF
M:65D("A'0C(S,3(I(@IM<V=S='(@(D-H:6YO('-I;7!L:69I8V%D;R`H1T(R
M,S$R*2(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(D-H:6YO('1R
M861I8VEO;F%L("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B07!L:6-A
M8VGS;CHB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I
M9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B16QI:F$@=6YA(&-O;G1R
M87-E\6$B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I
M9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B16QI:F$@=6X@;F]M8G)E
M(&1E('5S=6%R:6\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS
M,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T
M<B`B16QI:F$@8_-M;R!M;W-T<F%R(&QA<R!F96-H87,Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM
M<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I(@IM<V=S='(@(E-E;&5C8VEO;F%R('1I<&\@9&4@97-T:6QO(&1E(&QI
M<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D87,I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S
M($ES;&%N9"(*;7-G<W1R("))<VQA(&1E(%!A<V-U82(*"B,Z(&QI8B]61E,N
M<&AP.CDQ-"!L:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M(").;R!S92!E;F-O;G1R\R!L82!D969I;FEC:?-N(&1E(&-L87-E(&1E("5S
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T
M"FUS9VED(")#;&5A<B(*;7-G<W1R("),:6UP:6%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@
M35-/9F9I8V4@=&%G<R(*;7-G<W1R(")%;&EM:6YA<B!E=&EQ=65T87,@35-/
M9F9I8V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A
M<B!1=65R>2(*;7-G<W1R(")";W)R87(@8V]N<W5L=&$B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B0F]R<F%R('5S=6%R:6\Z
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS
M9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D)O<G)A<B!U<W5A<FEO(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R(")";W)R87(@9&%T;W,@9&5L('5S=6%R:6\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM
M<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")$97-P96IA9&\@=&%R9.UO
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DAA9V$@8VQI
M8VL@<&%R82!S96=U:7(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R
M(")#;&EC:V%T96QL('!O<B!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#
M;&]S92!7:6YD;W<B"FUS9W-T<B`B0V5R<F%R('9E;G1A;F$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(DYU
M8F5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(").=6)E<R!T96UP<F%N
M87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(FYU8F]S;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S
M("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DES;&%S(&1E(&-O8V]S("A+
M965L:6YG*2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*
M;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B3V-U;'1A<B!B87)R
M82!L871E<F%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS
M9W-T<B`B0V]L87!S87(@8F]R9&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T
M<B`B0V]L;VUB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B
M0V]L;W(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Q
M(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S(*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,R!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS
M9W-T<B`B4V5L96-T;W(@9&4@8V]L;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@S,@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")396QE
M8V-I\VX@9&4@8V]L;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B0V]L=6UN
M87,Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M
M;B!T:71L97,B"FUS9W-T<B`B5.UT=6QO<R!D92!L87,@8V]L=6UN87,B"@HC
M.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O
M;6EC<R(*;7-G<W1R(")#\VUI8W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M86YD;R(*"B,Z(&%D;6EN
M+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R
M("));G3I<G!R+B!C;VUA;F1O<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")#;VUE;G1A<FEO(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO
M;B!.86UE(@IM<V=S='(@(DYO;6)R92!C;VWZ;B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(D-O;6]R;W,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")#;VUP8?'M
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T
M97)S(@IM<V=S='(@(D]R9&5N861O<F5S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(D-O
M;F1I8VGS;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(D-O;F1I8VEO;F5S(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC
M97,B"FUS9W-T<B`B1&EF97)E;F-I87,@9&4@;&$@8V]N9FEG=7)A8VGS;B(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S
M(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"B)#;VYF:6=U<F%C:?-N('!A<F$@
M<VEN8W)O;FEZ86-I\VX@8V]N(%!$07,L($WS=FEL97,@8V]N(&%G96YD82!Y
M($]U=&QO;VLN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B3&$@
M8V]N9FEG=7)A8VGS;B!E<W3A(&1E<V%C='5A;&EZ861A+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M9FEG=7)E("5S(@IM<V=S='(@(D-O;F9I9W5R87(@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A
M<W-W;W)D(@IM<V=S='(@(D-O;F9I<FUA<B!C;VYT<F%S9?%A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]N9V\B"FUS9W-T<B`B0V]N9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(D-O;F=O+"!297#Z8FQI
M8V$@1&5M;V-RX71I8V$@9&5L(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B1F%L;/,@
M;&$@8V]N97AI\VXN(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(D9A;&SS(&QA(&-O
M;F5X:?-N.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B4V4@:&$@<F5C:&%Z861O(&QA(&-O;F5X:?-N(&%L('-E
M<G9I9&]R(&1E(&-L879E<R!P^F)L:6-O+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@
M*"5S*2(*;7-G<W1R("(B"B)392!H82!R96-H87IA9&\@;&$@8V]N97AI\VX@
M86P@<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N($UO=&EV;SH@)7,@*"5S
M*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(DAA(&9A;&QA9&\@;&$@
M8V]N97AI\VX@86P@<V5R=FED;W(@1E10+B(*"B,Z(&-O;F9I9R\N8F%K+VAO
M;VMS+G!H<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(D-O
M;G1A8W1O<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")392!H86X@8?%A9&ED;R!C
M;W)R96-T86UE;G1E(&QO<R!C;VYT86-T;W,@82!S=7,@9&ER96-C:6]N97,B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B
M0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(E1I
M<&\@9&4@8V]N=&5N:61O(&1E;"!A<F-H:79O(&-O;7!R:6UI9&\Z("(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F
M(%PB)7-<(B(*;7-G<W1R(")#;VYT96YI9&\@9&4@7"(E<UPB(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")#;VYT:6YU
M87(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B27-L87,@0V]O:R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM
M<V=S='(@(D-O;VMI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#
M;W!I87(B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")&86QL\R!L82!C;W!I
M83H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")#;W!I87(@
M<V5L96-C:?-N(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$W,"!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM
M<V=S='(@(DE$(&1E(&-O<W1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R
M(")#;W-T82!2:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")#
M;W-T82!D92!-87)F:6PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY
M-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS
M9W-T<B`B3F\@<V4@<'5E9&4@8VEF<F%R(&5L(&UE;G-A:F4@;65D:6%N=&4@
M4$=0.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED
M(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(DYO('-E
M('!U961E(&9I<FUA<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").;R!S92!P=65D
M92!C:69R87(@96P@;65N<V%J92!M961I86YT92!3+TU)344B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYO('-E('!U961E(&9I<FUA
M<B!E;"!M96YS86IE(&UE9&EA;G1E("!3+TU)344B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@8?%A9&ER(&5L(&-O;G1A8W1O+B`E<R(*"B,Z(&QI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C$*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYO('-E('!U961E(&5N;&%Z
M87(@86P@<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!C;VUP<F]B87(@96P@
M<V%L9&\N("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I
M9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(DYO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($Q$05`N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10
M.B`E<R(*;7-G<W1R(").;R!S92!P=65D92!C;VYE8W1A<B!A;"!S97)V:61O
M<B!<(B5S7"(@;65D:6%N=&4@1E10.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M3F\@<V4@<'5E9&4@8W)E87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E
M<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B3F\@<V4@<'5E
M9&5N(&1E<V-I9G)A<B!L;W,@9&%T;W,@4$=0.B`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N(@IM<V=S='(@(DYO('-E('!U961E;B!D97-C:69R87(@
M;&]S(&1A=&]S(%,O34E-12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@96QI;6EN
M87(@96P@8V]N=&%C=&\N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").;R!S92!P
M=65D92!E;&EM:6YA<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN("5S(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*(DYO('-E('!U961E(&5L:6UI;F%R(&5L(&=U
M:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!<(B5S7"(N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#$@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F\@
M<V4@<'5E9&4@9&5T97)M:6YA<F$@;&$@9&ER96-C:?-N(&1E(&-O<G)E;R!D
M96P@9&5S=&EN871A<FEO+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(DYO('-E('!U961E('1R865R(&QA(&QI
M8G)E=&$@9&4@9&ER96-C:6]N97,@8V]M<&QE=&$N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").;R!S
M92!P=65D92!T<F%E<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VX@8V]M<&QE
M=&$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@=')A97(@
M;&$@;&ES=&$@8V]M<&QE=&$@9&4@;&ES=&%S(&1E(&1I<W1R:6)U8VGS;BXB
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A
M=&5G>2!<(B5S7"(N(@IM<V=S='(@(DYO('-E('!U961E(&-A<F=A<B!L82!E
M<W1R871E9VEA(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B
M3F\@<V4@<'5E9&4@8W)E87(@96P@9&ER96-T;W)I;R!<(B5S7"(N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@
M;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R
M(").;R!S92!P=65D92!O8G1E;F5R(&QA(&-L879E('#Z8FQI8V$@9&5L('-E
M<G9I9&]R(&1E(&-L879E<RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R
M(").;R!S92!P=65D92!A8G)I<B!<(B5S7"(@<&%R82!E<V-R:6)I<BXB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(DYO('-E('!U961E(&%B<FER("5S+B(*"B,Z
M(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S(@IM<V=S='(@(DYO('-E('!U961E(&%B<FER(&5L(&WS9'5L;R!D92!T
M87)E87,@9&4@;6%N=&5N:6UI96YT;R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(DYO('-E('!U961E(&%B<FER(&5L(&1I<F5C=&]R:6\@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-38@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@;&]C86QI
M>F%R(&5L('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP
M.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB
M"FUS9W-T<B`B3F\@<V4@<'5E9&4@;&5E<B`E<RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYO('-E('!U961E(')E
M<W1A8FQE8V5R(&QA(&-O;G1R87-E\6$@9&5L('5S=6%R:6\@<V]L:6-I=&%D
M;RX@4&%R=&4@9&4@;&]S("(*(F1E=&%L;&5S(&\@=&]D;W,L('-O;B!I;F-O
M<G)E8W1O<RX@4')U96)E(&]T<F$@=F5Z(&\@</-N9V%S92!E;B!C;VYT86-T
M;R!C;VX@(@HB96P@861M:6YI<W1R861O<B!D96P@<VES=&5M82!P87)A(&WA
M<R!I;F9O<FUA8VGS;BXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S`W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!!0TPB"FUS9W-T<B`B3F\@<V4@<'5E9&4@;V)T96YE<B!L82!!0TPN(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!O8G1E;F5R(&QA(&QI8G)E=&$@
M9&4@9&ER96-C:6]N97,N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYO('-E
M('!U961E(&]B=&5N97(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T<RX@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S
M(&QI<W1A<R!D92!D:7-T<FEB=6-I\VXN("5S(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$W"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C$*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,B"FUS9W-T<B`B3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S(&-A
M<&%C:61A9&5S(&1E;"!S97)V:61O<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@<F5S=&%U<F%R(&QA(&-O;F9I9W5R
M86-I\VXN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@96QI;6EN87(@
M96P@9&ER96-T;W)I;R!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@9W5A<F1A
M<B!L82!C;VYF:6=U<F%C:?-N(&1E("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R
M(").;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C;VYF:6=U
M<F%C:?-N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXZ("5S(@IM<V=S='(@(DYO('-E('!U961E(&=U87)D87(@=6YA(&-O
M<&EA(&1E(&QA(&-O;F9I9W5R86-I\VXZ("5S(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B(@HB3F\@<V4@<'5E9&4@9W5A<F1A<B!E;"!G=6GS;B!D92!A8W1U86QI
M>F%C:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX@96XZ(%PB)7-<(BXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R(").;R!S92!P=65D92!G=6%R9&%R(&QA(&-O<&EA("5S
M(&1E(&QA(&-O;F9I9W5R86-I\VXN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C
M:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S
M+B(*;7-G<W1R("(B"B).;R!S92!P=65D92!G=6%R9&%R(&5L(&%R8VAI=F\@
M)7,@9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@=71I;&EZ87(@=6YA(&1E("(*
M(FQA<R!O<&-I;VYE<R!P87)A(')E<W1A=7)A<B!E;"!C\V1I9V\@9&4@)7,@
M;R!C;W!I87(@;6%N=6%L;65N=&4@82`E<R!E;"`B"B)C\V1I9V\@<VEG=6EE
M;G1E+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B
M0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYO
M('-E('!U961E(&)U<V-A<B!E;B!E;"!S97)V:61O<B!,1$%0+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB
M+B(*;7-G<W1R(").;R!S92!P=65D92!D97-V:6YC=6QA<B!<(B5S7"(N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(DYO('-E('!U961E(&%C='5A;&EZ87(@96P@8V]N=&%C=&\N("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!A8W1U86QI>F%R(&QA
M(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R
M:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F\@
M<V4@<'5E9&4@97-C<FEB:7(@;&$@8V]N9FEG=7)A8VGS;B!D92!<(B5S7"(Z
M("5S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED
M(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).;R!S92!P=65D
M92!L;V-A;&EZ87(@96P@<&%N96P@;&%T97)A;"!D92!-;WII;&QA+B!#;VUP
M<G5E8F4@<75E(&5S=.D@(@HB86)I97)T;RXB"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B).;R!S
M92!P=65D96X@;W1O<F=A<B!A;"!U<W5A<FEO(%PB)7-<(B!L;W,@<VEG=6EE
M;G1E<R!D97)E8VAO<R!P87)A(&QA("(*(F-A<G!E=&$@7"(E<UPB.B`E<R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(S"FUS9VED(")#;W5N=&5D('1E
M>'0B"FUS9W-T<B`B5&5X=&\@8V]N=&%D;R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(E!A[7,B
M"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@
M(D-O=7)S97,B"FUS9W-T<B`B0W5R<V]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B0W)E87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A
M(&QI;FLB"FUS9W-T<B`B0W)E82!U;B!V[6YC=6QO(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@
M;F5W(&]N92(*;7-G<W1R(")#<F5A<B(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU,B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")#<F5A
M<B!S=6)C87)P971A<R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P
M"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!R:79I;&5G
M:6]S(&1E(&-R96%D;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q-@IM
M<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!T
M87)J971A(&1E(&-RZ61I=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")#
M<F]A8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")#=6)A(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S
M='(@(C0@1F%S97,@86-T=6%L97,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B4V5S:6]N97,@
M86-T=6%L97,B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO
M=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")(;W)A
M(&%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T
M<B`B55),(&%C='5A;"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I
M9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")5<W5A<FEO<R!A8W1U86QE<R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A
M=&AE<B(*;7-G<W1R(")4:65M<&\@86-T=6%L(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ
M("(*;7-G<W1R(")#;VYD:6-I\VX@86-T=6%L.B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT
M('-T>6QE(@IM<V=S='(@(D5S=&EL;R!A8W1U86PB"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M(")097)S;VYA;&EZ82!L87,@=&%R96%S(&$@96IE8W5T87(@86P@:6YI8VEA
M<B!S97-I\VX@96X@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B
M0V]R=&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")#;W)T87(@
M<V5L96-C:?-N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-H:7!R92(*"B,Z
M(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC
M("A+3TDX+5(I(@IM<V=S='(@(D-I<NUL:6-O("A+3TDX+5(I(@H*(SH@8V]N
M9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2DB"FUS9W-T<B`B0VER[6QI8V\@*%=I;F1O=W,M,3(U,2DB
M"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0VER[6QI8V\O56-R
M86YI86YO("A+3TDX+54I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T
M<B`B4F5P^F)L:6-A($-H96-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W
M-@IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G
M<W1R("(B"B)$4TX@*'9E82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E
M<R]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*(SH@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T
M<B`B1&EA<FEA;65N=&4B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G
M:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`BP7)?8F]L(&1A=&]S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*;7-G:60@(D1A=&%B87-E($QO
M;VMU<"(*;7-G<W1R(")#;VYS=6QT82!D92!L82!B87-E(&1E(&1A=&]S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#(@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`B1F5C:&$B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I
M9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")392!H82!R96-I8FED;R!L82!F
M96-H82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDS"FUS9VED(")$871E
M('-E;&5C=&EO;B(*;7-G<W1R(")396QE8V-I\VX@9&4@9F5C:&$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")$[6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(D5?;&EM:6YA
M<B!C;VQU;6YA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*
M;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1I8VEE;6)R92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*
M;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S(&1E8VEM
M86QE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")2961U8VER
M('-A;F=R861O(@H*(SH@;&EB+W!R969S+G!H<#HQ,3<@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ.#<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4&]R(&]M
M:7-I\VXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")#;VQO<B!P
M;W(@;VUI<VGS;B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.38*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E;G1I9&%D('!O<B!O
M;6ES:?-N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$
M969A=6QT(%-H96QL(@IM<V=S='(@(E-H96QL('!O<B!O;6ES:?-N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*
M;7-G<W1R(")$969I;FEC:6]N97,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q
M(&QI8B](;W)D92]097)M<RYP:'`Z,S(V(&QI8B](;W)D92]097)M<R]522YP
M:'`Z-#(R"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#,Y('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3@@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q
M"FUS9VED(")$96QE=&4B"FUS9W-T<B`B)FYB<W`[16QI;6EN87(F;F)S<#LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(D5L:6UI;F%R
M(&-E;&1A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S
M+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")%;&EM:6YA
M<B!G<G5P;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM
M<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")%;&EM:6YA<B!R96=I<W1R;R(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@
M(D5L:6UI;F%R('!R:79I;&5G:6\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B16QI;6EN87(@>2!V86-I87(@;65N<V%J97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W
M"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")%;&EM:6YA<B!C96QD82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B16QI;6EN87(@
M8V]L=6UN82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$
M96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(D5L
M:6UI;F%R('!L86YT:6QL87,@86QT97)N871I=F%S(&5X:7-T96YT97,B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E
M;&5T92!M97-S86=E<R(*;7-G<W1R(")%;&EM:6YA<B!M96YS86IE<R(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5L
M:6UI;F%R('!R:79I;&5G:6]S(&1E(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/R(*;7-G<W1R("*_16QI;6EN87(@<')I=FEL96=I;W,@<&%R82!<(B5S7"(@
M>2!C=6%L<75I97(@<')I=FEL96=I;R!D97-C96YD:65N=&4_(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")%;&EM:6YA<B!F:6QA(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(D5L:6UI;F%R(&ED
M96YT:61A9"!S96QE8V-I;VYA9&$B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R<R(*;7-G
M<W1R(")%;&EM:6YA<B!S=6)C87)P971A<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")%;&EM:6YA(&QA(&-O
M;'5M;F$@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W(@IM<V=S='(@(D5L:6UI;F$@;&$@9FEL82!A8W1U86PB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T
M<B`B4V4@:&$@96QI;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@
M9&4@;&$@8V]N9FEG=7)A8VGS;B!<(B5S7"(N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS
M9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(DAO<F$@9&4@96YT<F5G83HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$96YM87)K(@IM<V=S='(@(D1I;F%M87)C82(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T
M:&4@4')O8FQE;2(*;7-G<W1R(")$97-C<FEB82!E;"!P<F]B;&5M82(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B1&5S8W)I<&-I\VXB"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-PIM
M<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G
M<W1R(")$971A;&QE<R`H=&%M8FGI;B!E;B!E;"!A<F-H:79O(&1E(')E9VES
M=')O(&1E($AO<F1E*3HB"@HC.B!L:6(O2&]R9&4N<&AP.C(P,0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B4V4@:&%N(')E9VES=')A9&\@;&]S(&1E=&%L;&5S('!A
M<F$@96P@861M:6YI<W1R861O<BXB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D1E
M<V%R<F]L;&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B
M1&5W(%!O:6YT(@IM<V=S='(@(E!U;G1O(&1E(&-O;F1E;G-A8VGS;B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q"FUS9VED(")$97<@4&]I;G0@9F]R
M(&QA<W0@:&]U<CH@(@IM<V=S='(@(E!U;G1O(&1E(&-O;F1E;G-A8VGS;B!D
M92!L82#Z;'1I;6$@:&]R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B4'5N=&\@
M9&4@8V]N9&5N<V%C:?-N.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H="(*;7-G<W1R(")$92!I>G%U:65R9&$@82!D97)E8VAA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B
M1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B1&4@9&5R96-H82!A
M(&EZ<75I97)D82(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED
M(")$:7)E8W1O<GDB"FUS9W-T<B`B1&ER96-T;W)I;R(*"B,Z(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R
M('1I;65S/R(*;7-G<W1R("*_36]S=')A<B!E;B!F;W)M871O(&1E(#(T+6AO
M<F%S/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I
M9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S(&1E(%9I<W5A
M;&EZ86-I\VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*
M;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B36]S
M=')A<B!P<F]N\W-T:6-O(&1E=&%L;&%D;R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T
M<B`B36]S=')A<B!P<F]N\W-T:6-O("A4048I(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(X,#,*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D9O
M<FUA=&\@9&4@=FES=7IA;&EZ86-I\VXB"@HC.B!L:6(O2&]R9&4O34E-12]-
M1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM
M<V=S='(@(DYO=&EF:6-A8VGS;B!D92!C;VYS=6QT82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O
M=71I(@IM<V=S='(@(D1J:6)O=71I(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F\@96QI
M;6EN87(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@
M(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S
M='(@(DYO(&%C8V5D97(@9&ER96-T86UE;G1E(&$@;6%I;G1E;F%N8V4N<&AP
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#HB"FUS9W-T<B`B(@HBOT-O;G1I96YE(&QA('!R:6UE<F$@9FEL82!L
M;W,@;F]M8G)E<R!D92!L;W,@8V%M<&]S/R!3:2!E<R!A<^TL('-E;&5C8VEO
M;F4@(@HB97-T82!C87-I;&QA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@
M(D1O;6EN:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(E)E</IB;&EC82!$;VUI;FEC86YA(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+B(*;7-G<W1R("*_3F\@9&ES<&]N92!D92!C=65N=&$_(%-O;&EC[71E
M;&$N(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,@IM<V=I
M9"`B1&]W;FQO860B"FUS9W-T<B`B1&5S8V%R9V%R(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M;W=N;&]A9"`E<R(*;7-G<W1R(")$97-C87)G87(@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")$97-C87)G
M87(@;&$@8V]N9FEG=7)A8VGS;B!G96YE<F%D82!C;VUO('5N(&=U:?-N(%!(
M4"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,0IM<V=I9"`B1')O<"!D
M;W=N(&QI<W0B"FUS9W-T<B`B3&ES=&$@9&5S<&QE9V%B;&4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R
M;V=A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M12U-86EL(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&QI8B].970O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+B(*;7-G<W1R("(B"B)#;VYT<F]L861O<B!D92!P87-A<F5L82!#;W)R96\M
M82U335,@<&%R82!P<F]V965D;W)E<R!Q=64@<')O<&]R8VEO;F5N(&5S=&4@
M(@HB<V5R=FEC:6\N(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B16-U861O<B(*;7-G<W1R(")%8W5A9&]R(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(B9N8G-P.TUO9&EF:6-A<B9N
M8G-P.R(*"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D
M:70@0FQO8VLB"FUS9W-T<B`B36]D:69I8V%R(&)L;W%U92(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%
M9&ET($=R;W5P(@IM<V=S='(@(DUO9&EF:6-A<B!G<G5P;R(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")-;V1I9FEC87(@
M<')I=FEL96=I;R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B36]D:69I8V%R('!R
M:79I;&5G:6]S(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R(")-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R
M.B(*;7-G<W1R(")-;V1I9FEC87(@;W!C:6]N97,@9&4Z(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(DUO9&EF:6-A<B!P
M<FEV:6QE9VEO<R!D92!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S(@IM<V=S='(@(DUO9&EF:6-A<B!P<FEV:6QE9VEO<R!D92`E
M<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T
M:6]N(@IM<V=S='(@(D5D=6-A8VGS;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@
M(D5G:7!T;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L
M=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE
M;65N=&\N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3@W,R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B0V]R<F5O(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D1I<F5C
M8VGS;B!D92!C;W)R96\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV-PIM
M<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(DQA
M<R!D:7)E8V-I;VYE<R!D92!C;W)R96\@=&EE;F5N('%U92!C;VEN8VED:7(N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.3,*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D-O<G)E;R!C;VX@8V]N9FER;6%C
M:?-N(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B4&%S87)E;&$@0V]R
M<F5O+6$M4TU3(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(D5M;W1I8V]N97,B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I
M9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B365N<V%J92!E;B!B;&%N8V\B
M"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C8V,B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G
M<W1R(")297-U;'1A9&\@96X@8FQA;F-O+B(*"B,Z(&QI8B](;W)D92]344PO
M2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(DQI;7!I87(@=.ER;6EN;W,@9&4@8OIS<75E9&$B"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(K]097)M:71I<B!I;G-E<F-I\VX@9&4@:6WA9V5N97,@9&4@
M;&%S($=A;&5R[6%S(&1E(&9O=&]S/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\B"FUS9W-T<B`BOU!E<FUI=&ER(&UE;OH@9&4@8V]N=&5X=&\@
M9&5L(&)O=/-N(&1E<F5C:&\@9&5L(')A=/-N/R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-3DR(&QI8B](;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")%
M;F0@>65A<B(*;7-G<W1R(")!\6\@9&4@=&5R;6EN86-I\VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%
M;FQA<F=E($5D:71O<B(*;7-G<W1R(")!9W)A;F1A<B!E9&ET;W(B"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R
M(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@
M:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B))
M;G1R;V1U>F-A('5N82!P<F5G=6YT82!D92!S96=U<FED860@<75E('-E(&QE
M(&9O<FUU;&%RX2!S:2!P<F5C:7-A("(*(G)E86IU<W1A<B!L82!C;VYT<F%S
M9?%A+"!P+F4N(">_0W7A;"!E<R!E;"!N;VUB<F4@9&4@<W4@;6%S8V]T83\G
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E
M(@IM<V=S='(@(DEN=')O9'5Z8V$@87%U[2!L82!54DP@9&4@;&$@:6UA9V5N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(DEN=')O
M9'5Z8V$@;&%S(&QE=')A<R!D92!D96)A:F\Z(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA
M;"!'=6EN96$B"FUS9W-T<B`B1W5I;F5A($5C=6%T;W)I86PB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M<FET<F5A(@IM<V=S='(@(D5R:71R96$B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#@*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B17)R;W(B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP
M.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C
M:SH@)7,B"FUS9W-T<B`B17)R;W(@86P@8W)E87(@96P@8FQO<75E.B`E<R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G
M<W1R(")%<G)O<B!A;"!E;&EM:6YA<B!A;F-L82!D92!S:6YC<F]N:7IA8VGS
M;CH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B
M"FUS9W-T<B`B17)R;W(@86P@96QI;6EN87(@96P@<F5G:7-T<F\@9&4@<VEN
M8W)O;FEZ86-I\VXZ("5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<R(*;7-G<W1R(")%<G)O<B!A;"!O8G1E;F5R(&-O;G1E;FED;W,Z("5S
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G
M<W1R(")%<G)O<B!A;"!A8W1U86QI>F%R(&QA(&-O;G1R87-E\6$Z("5S(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@
M(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B17)R;W(@8V]N
M(&5L(&UE;G-A:F4@9&4@8V]R<F5O+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B17)R;W(@
M86P@97-C<FEB:7(@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B
M17-T;VYI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:6]P[6$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G
M<W1R("+)=&YI8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R(")#861A(#$U(&UI;G5T;W,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R
M(")#861A(#(@;6EN=71O<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C,T,"!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@
M(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=U;F1O<R(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R(")#861A(#4@;6EN=71O<R(*"B,Z(&QI8B](;W)D92]-86EN=&5N
M86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D-A9&$@
M:6YI8VEO(&1E('-E<VGS;B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D-A9&$@
M;65D:6$@:&]R82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,T
M,2!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y
M(&UI;G5T92(*;7-G<W1R(")#861A(&UI;G5T;R(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS
M9W-T<B`B5F%L;W)E<R!D92!E:F5M<&QO.B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN
M<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R(")%:F5C=71A<B(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED
M(")%>'!A;F0B"FUS9W-T<B`B17AP86YD:7(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G
M<W1R(")-;W-T<F%R(&)A<G)A(&QA=&5R86PB"@HC.B!L:6(O2&]R9&4O4U%,
M+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R
M(")S92!E<W!E<F%B82`G*2<B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S
M+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FTB"FUS9W-T<B`B4V4@97-P97)A8F$@=6YA(/IN:6-A('!A
M;&%B<F$@;R!U;B!TZ7)M:6YO(&1E(&+Z<W%U961A(&5N=')E8V]M:6QL861O
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I
M<F%T:6]N($1A=&4B"FUS9W-T<B`B1F5C:&$@9&4@=F5N8VEM:65N=&\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B17AP;VYE;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B
M"FUS9W-T<B`B0V]L;W(@9&4@;&5T<F$B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@
M(D-A<F=A<B!L82!C;VYF:6=U<F%C:?-N('!O<B!&5%`B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R(")&86QL;R!A;"!T<F%E<B!L87,@<')E
M9F5R96YC:6%S+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW-2!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DEN8V%P87H@9&4@8V]N
M96-T87)S92!A;"!S97)V:61O<B!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S
M97)V97(N(@IM<V=S='(@(DEN8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V
M:61O<B!334(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T
M<B`B1F%L;&\@86P@8V]P:6%R(&1E(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M('1O(%PB)7-<(BXB"FUS9W-T<B`B1F%L;&\@86P@8V]P:6%R(&$@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(D9A
M;&QO(&%L(&-R96%R('5N82!C;VYE>&GS;B!305-,(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C4P,2!L:6(O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B1F%L
M;&\@86P@=')A<VQA9&%R(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@
M)7,B"FUS9W-T<B`B1F%L;&\@86P@<F5C=7!E<F%R.B`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER
M(@IM<V=S='(@(D1E<W!E:F%D;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R("))<VQA<R!-86QV:6YA<R`H1F%L:VQA;F0I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("))<VQA<R!&87)O92(*
M"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z
M(@IM<V=S='(@(D5R<F]R(&ER<F5C=7!E<F%B;&4Z(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R
M(")&87@B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*
M;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A>&5S(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E
M8G)E<F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E
M;',@3&EK92(*;7-G<W1R(")392!S:65N=&4@8V]M;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*
M;7-G<W1R(")392!S:65N=&4@8V]M;SH@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM
M<V=S='(@(E!O8V%S(&QL=79I87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R(")%<V-A<V\@86=U86-E<F\@9&4@;FEE=F4B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3DT.`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@
M(DUA=')I>B!D92!C86UP;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R
M.0IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B0T%05$-(02!D92!&
M:6=L970B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,S,PIM<V=I9"`B1FEG
M;&5T(&9O;G0B"FUS9W-T<B`B3&5T<F$@9&4@1FEG;&5T(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ
M:2(*;7-G<W1R(")&:6II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S='(@(D%R8VAI=F\B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE(@IM<V=S='(@(DZZ(&1E(&%R8VAI=F]S.B`E<R!A<F-H:79O(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@
M)7,@9FEL97,B"FUS9W-T<B`B3KH@9&4@87)C:&EV;W,Z("5S(&%R8VAI=F]S
M(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED
M(")&:6QE($UA;F%G97(B"FUS9W-T<B`B07)C:&EV;W,B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYO;6)R92!D92!A<F-H
M:79O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.#$*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS;B!D92!A<F-H:79O(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T.3`*;7-G:60@(D9I;&4@=7!L;V%D(@IM
M<V=S='(@(D-A<F=A<B!A<F-H:79O(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N
M<&AP.CDP,@IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(DQA(&-A<F=A(&1E(&%R8VAI=F]S(&YO(&5S=.$@<V]P;W)T861A
M+B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED
M(")&:6QT97)S(@IM<V=S='(@(D9I;'1R;W,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM
M<V=S='(@(D9I;FQA;F1I82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*
M;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B0W5A<G1O(&-R96-I96YT92(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B0W5A<G1O(&-R96-I
M96YT92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")287KS;B!F:6IA(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B
M1FQI<"(*;7-G<W1R(")6;VQT96%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS
M9W-T<B`B1&ES<&]S:6-I\VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(DYI96)L82(*
M"B,Z(&QI8B]61E,O<W%L+G!H<#HR,S<@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W
M"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(*;7-G<W1R("),82!C87)P971A("5S(&YO(&5X:7-T92XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&
M;VYT($-O;&]R(@IM<V=S='(@(D-O;&]R(&1E(&QE=')A(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(D-O;6ED
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@
M<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B4&%R82!N879E9V%D;W)E<R!Q=64@
M;F\@861M:71A;B!I;>%G96YE<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<F]N\W-T:6-O
M("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS
M9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D
M(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M(@IM<V=S='(@(B(*(D3M87,@9&5L('!R;V[S<W1I8V\@*'1E;F=A(&5N(&-U
M96YT82!Q=64@96P@<')O;O-S=&EC;R!F86-I;&ET861O(&EN8VQU>64@(@HB
M=&%N=&\@96P@9.UA(&-O;6\@;&$@;F]C:&4[('5N(&[Z;65R;R!G<F%N9&4@
M<V4@=')A9'5C:7+A(&5N('5N(&)L;W%U92!M=7D@(@HB86YC:&\I(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y
M;W5R('!A<W-W;W)D/R(*;7-G<W1R("*_2&$@;VQV:61A9&\@;&$@8V]N=')A
M<V7Q83\B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*
M;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUU;&%R:6]S(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D9O
M<G1U;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O
M<G1U;F4@='EP92(*;7-G<W1R(")4:7!O(&1E(&9O<G1U;F$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@
M(D9O<G1U;F%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(D9O<G1U;F%S(#(B"@HC.B!C;VYF:6<O
M+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G
M<W1R(")&;W)O<R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T
M.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4F5E;G;M;W,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED
M(")&<B(*;7-G<W1R(")6:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T
M<B`B1G)A;65S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YC:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-
M971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-I82P@365T<F]P;VQI=&%N82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1W5A>6%N82!F<F%N8V5S
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!O;&EN97-I
M82!F<F%N8V5S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@IM<V=S='(@(E1E<G)I=&]R:6]S(&9R86YC97-E<R!D96P@<W5R(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@
M(D9R;VTB"FUS9W-T<B`B1&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T
M:&4@(@IM<V=S='(@(D1E;"`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$
M97-C<FEP8VGS;B!C;VUP;&5T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS
M9W-T<B`B3'5N82!L;&5N82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&
M=6QL($YA;64B"FUS9W-T<B`B3F]M8G)E(&-O;7!L971O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B
M;VXB"FUS9W-T<B`B1V%B\VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&5R[6$@9&4@;&$@<75E
M(&]B=&5N97(@;&$@:6UA9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y
M.B(*;7-G<W1R(")'86QE<NUA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'
M86UB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF
M;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T
M<B`B1V5N97)A<B!C;VYF:6=U<F%C:?-N(&1E("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#
M;V1E(@IM<V=S='(@(D/S9&EG;R!G96YE<F%D;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B
M"FUS9W-T<B`B1V5O<F=I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B06QE
M;6%N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I
M8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(").
M;VUB<F4@:6YD:6-A9&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G
M<W1R(")/<&-I;VYE<R!G;&]B86QE<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R("))<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E
M;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3,Q
M"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")-87!A<R!D92!';V]G;&4B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@
M4V5A<F-H(@IM<V=S='(@(D+Z<W%U961A(&5N($=O;V=L92(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES
M8V%L92(*;7-G<W1R(")%<V-A;&$@9&4@9W)I<V5S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C
M92(*;7-G<W1R(")'<F5C:6$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I
M<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)I
M96=O("A)4T\M.#@U.2TW*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'
M<F]E;FQA;F1I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)A;F%D82(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VGS;B!D92!G<G5P;W,B"@HC
M.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M(@IM<V=S='(@(DQO<R!N;VUB<F5S(&1E(&=R=7!O(&YO('!U961E;B!D96IA
M<G-E(&5N(&)L86YC;R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M(@IM<V=S='(@(B(*(D=R;W5P7VQD87`Z($YO('-E('!U961E(&'Q861I<B!E
M;"!G<G5P;R`E<RX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<CH@
M(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!);F-A
M<&%Z(&1E(&5L:6UI;F%R(&5L(&=R=7!O("5S(@H*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@26YC87!A>B!D
M92!A8W1U86QI>F%R(&5L(&=R=7!O("5S(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R
M(")'<G5P;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861A;'5P
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M
M86QA(@IM<V=S='(@(D=U871E;6%L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYE<V5Y(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B4')I=FEL96=I;W,@9&4@:6YV:71A9&\B"@HC.B!C;VYF:6<O+F)A:R]R
M96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R
M("),+B!I;G9I=&%D;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82U":7-S
M874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=6%Y86YA(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434P@<V4@
M;FEE9V$@8V]B87)D96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA(&-E;&1A
M(&1E(&QA(&9I;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*
M;7-G<W1R("(B"B)(5$U,07)E82!S92!N:65G82!C;V)A<F1E;65N=&4@82!E
M;&EM:6YA<B!L82#Z;'1I;6$@8V]L=6UN82!D92!L82!T86)L82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434P@<V4@;FEE9V$@
M8V]B87)D96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA(&9I;&$@9&4@;&$@
M=&%B;&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@
M<V4@96YC;VYT<O,@;&$@875T96YT:69I8V%C:?-N($A45%`N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED
M(")(86ET:2(*;7-G<W1R(")(86ET[2(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B06QG
M;W)I;6\@2&%S:"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DYE8FQI;F$B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.3(S(&QI8B](;W)D92]&;W)M+G!H<#HR.3$X
M"FUS9VED(")(96%D97(B"FUS9W-T<B`B0V%B96-E<F$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*
M;7-G<W1R(")#86)E8V5R87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@
M36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("))<VQA($AE87)D(&4@27-L87,@
M36-$;VYA;&0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")4;W)M96YT
M82!T<F]P:6-A;"!I;G1E;G-A(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD
M:7-T.C$X.0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@
M(DAE8G)E;R`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*
M;7-G<W1R(")!;'1U<F$B"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI
M8B](;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B
M"FUS9W-T<B`B07EU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G
M<W1R(")!>75D82!D96P@961I=&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S-S4*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")!>75D86YT92(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R
M(")(96UI<V9E<FEO(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B07%U[2!T
M:65N92!E;"!C;VUI96YZ;R!D96P@87)C:&EV;SHB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B2&EG:"(*;7-G
M<W1R(")!;'1A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E
M;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M
M92(*;7-G<W1R(")?26YI8VEO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92DB"FUS9W-T<B`B4V%N=&$@4V5D92`H0VEU9&%D+45S
M=&%D;R!D96P@5F%T:6-A;F\I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-3,Y"FUS
M9VED(")(;VUE(@IM<V=S='(@(DEN:6-I;R(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B1&]M
M:6-I;&EO(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(
M;VUE($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E8W1O<FEO('!E<G-O;F%L(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@
M(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@<&%R=&EC=6QA<B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO
M;F<@2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O+F)A:R]R
M96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R
M9&4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O
M=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B
M.B!392!H86X@96YC;VYT<F%D;R!D871O<R!834P@)7,@;F\@=N%L:61O<R!E
M;B!E;"!M96YS86IE("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@
M8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!.:6YG^FX@;65N<V%J92!C;W)R97-P;VYD92!A;"!O8FIE=&\@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F\@<V4@96YC;VYT
M<O,@=6X@;V)J971O(&1E('1I<&\@)7,@96X@96P@;65N<V%J92`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!392!H82!E;&EM:6YA9&\@8V]R<F5C
M=&%M96YT92`E<R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(R
M,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B
M(@HB2&]R9&4O2V]L86(Z($5L(&UO=&]R(&1E(&EN=&5G<F%C:?-N('!R96-I
M<V$@9&4@;&$@97AT96YS:?-N(%!(4"`G9&]M>&UL)R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F-A<&%Z(&1E(&-R96%R(&YU
M979O(.%R8F]L(%A-3"!D96P@;V)J971O("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,C0X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($EN8V%P87H@9&4@96QI;6EN87(@)7,@7"(E<UPB.B`E<R(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M26YC87!A>B!D92!O8G1E;F5R($E$($U)344@9&4@;&$@<&%R=&4@9&4@=&EP
M;R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN8V%P87H@
M9&4@<VEN8W)O;FEZ87(@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN8W)O;FEZ87(@96QE;65N=&]S
M(&-O;7!A<G1I9&]S.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,S0P
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@16QE;65N=&\@8V]M
M<&%R=&ED;R!D97-C;VYO8VED;R!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L
M(%)U;&4B"FUS9W-T<B`B3.UN96$@:&]R:7IO;G1A;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R(")-87)G96X@:&]R:7IO;G1A;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G
M:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FEZ;VYT86PZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R("*_0_-M;R!L;&5G\R!H87-T82!A<77M/R`HH4-O;75N[7%U
M96QO+"!P;W(@9F%V;W(A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M
M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(K]#=6%N=&%S
M(&-O;'5M;F%S(&1E<V5A(&-O;6)I;F%R/R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`BOT-UX6YT;W,@8V%M<&]S("AC;VQU
M;6YA<RD@:&%Y/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(K]#=6%N=&%S(&9I;&%S(&1E
M<V5A(&-O;6)I;F%R/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G:60@(DAU;6ED:71Y
M(@IM<V=S='(@(DAU;65D860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(DAU;65D860Z
M("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I
M<W1S(@IM<V=S='(@(DAU;6]R:7-T87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS
M9W-T<B`B2'5N9W+M82(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ
M-S(@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B2&$@9F%L;&%D;R!L82!C<F5A8VGS;B!D96P@8G5Z\VX@24U!4#H@
M)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C$T(&QI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DAA(&9A
M;&QA9&\@;&$@96QI;6EN86-I\VX@9&5L(&)U>O-N($E-05`Z("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C
M>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")(82!F86QL
M861O(&QA(&-R96%C:?-N(&1E(&5S<&%C:6\@87-I9VYA9&\@9&5L(&)U>O-N
M($E-05`Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,C`*;7-G:60@
M(DE0($%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N($E0(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B3&$@9&ER96-C:?-N($E0(&YO(&5S=.$@
M9&ES<&]N:6)L92XB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX
M.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`B3&$@9&ER96-C:?-N($E0(&YO(&5S=.$@96YT<F4@
M8FQO<75E<R!#2412('!E<FUI=&ED;W,N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA
M=&EO;BXB"FUS9W-T<B`B5FEO;&%C:?-N(&QO8VMD;W=N($E0+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DE?;G-E<G1A
M<B!F:6QA(&5N8VEM82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA
M;F1I82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I
M9"`B26-O;G,@3VYL>2(*;7-G<W1R(")3\VQO(&EC;VYO<R(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N
M<R!F;W(@)7,B"FUS9W-T<B`B26-O;F]S(&1E("5S(@H*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B
M"FUS9W-T<B`B26-O;F]S(&-O;B!T97AT;R(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G
M<W1R(").;VUB<F4@9&4@;&$@:61E;G1I9&%D.B(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")3:2!N;R!S92!M=65S=')A(&-O
M<G)E8W1A;65N=&4L("5S('!A<F$@86)R:7)L;R!E;B!U;F$@=F5N=&%N82!N
M=65V82XB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G
M:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB
M4VD@;F\@=F4@;FEN9_IN(&EC;VYO(&UE9&EA;G1E($EN=&5R;F5T($5X<&QO
M<F5R+"!P=65D92!T96YE<B!Q=64@86-T:79A<B`B"B)E<W1A(&-A<VEL;&$@
M<&%R82!D97-A8W1I=F%R(&QA('1R86YS<&%R96YC:6$@4$Y'+B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*
M(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@
M8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)3:2!V92!E<W1E(&UE;G-A
M:F4@<VEN(&YI;F=U;F$@:6UA9V5N+"!L82!I;6%G96X@<75E('%U:65R92!C
M87)G87(@;F\@<V4@(@HB<'5E9&4@;6]S=')A<B!E;B!S=2!N879E9V%D;W(N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")6
M:7-T82!P<F5V:6$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@
M(E523"!D92!L82!I;6%G96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%52
M3#HB"FUS9W-T<B`B55),(&1E(&QA(&EM86=E;CHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("));6%G96X@9&4@;&$@
M9V%L97+M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M.B(*;7-G<W1R("));6%G96X@9&4@;&$@9V%L97+M83HB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@
M(E-E(&AA(&-A<F=A9&\@;&$@:6UA9V5N(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("));>%G96YE<R(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&%R+"!P87-O
M("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-A
M;7!O(&EM<&]R=&%D;SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(D-A;7!O
M<R!I;7!O<G1A9&]S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T
M97(B"FUS9W-T<B`B26Y?<V5R=&%R(&9I;&$@9&5B86IO(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(E-E(&AA(&EN9&EC861O('5N(&/S
M9&EG;R!D92!A8V-I\VX@:6YC;W)R96-T;RXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(").;VUB<F4@9&4@=7-U87)I
M;R!Y+V\@8V]N=')A<V7Q82!I;F-O<G)E8W1O<RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"B).;VUB<F4@9&4@=7-U87)I;R!O(&1I<F5C8VGS
M;B!A;'1E<FYA=&EV82!I;F-O<G)E8W1O<RX@5G5E;'9A(&$@:6YT96YT87)L
M;R!O("(*(G#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D
M;W(@9&4@<VES=&5M87,@<&%R82!MX7,@:6YF;W)M86-I\VXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B
M26YC<F5A<V4@26YD96YT(@IM<V=S='(@(D%U;65N=&%R('-A;F=R861O(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED("));F1I82(*;7-G<W1R("));F1I82(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T
M"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E5S=6%R:6]S(&EN
M9&EV:61U86QE<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N
M97-I82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R;6%C:?-N(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO
M;B(*;7-G<W1R("));F9O<FUA8VGS;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N(@IM<V=S='(@(DQA(&EN9F]R;6%C:?-N('EA(&YO(&5S=.$@
M9&ES<&]N:6)L92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F
M=&5R(@IM<V=S='(@(DEN<V5R=&%R(&-?;VQU;6YA(&1E='+A<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(DEN<V5R=&%R(&EM
M86=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("));G-E<G1A<B!T
M86)L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("));G-E<G1A
M<B!V[6YC=6QO(%=E8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@
M0F5F;W)E(@IM<V=S='(@(DEN<V5R=&%R(%]C;VQU;6YA(&1E;&%N=&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R=&$@=6YA(&YU979A(&-O;'5M;F$@
M9&5T<N%S(&1E(&QA(&%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN
M<V5R=&$@=6YA(&YU979A(&-O;'5M;F$@9&5L86YT92!D92!L82!A8W1U86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R=&$@=6YA(&9I;&$@;G5E=F$@9&5B
M86IO(&1E(&QA(&%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R=&$@
M=6YA(&9I;&$@;G5E=F$@96YC:6UA(&1E(&QA(&%C='5A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM
M<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B26YS97)T82!U;B!PX7)R869O('1R87,@96P@;F]D;R!A
M8W1U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G-E<G1A('5N('#A<G)A
M9F\@86YT97,@9&5L(&YO9&\@86-T=6%L(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B26YS97)T87(@<&QA;G1I;&QA(&%L=&5R;F%T:79A(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@
M96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE
M=R!P87-S=V]R9#HB"FUS9W-T<B`B26YS97)T87(@=6YA(&1I<F5C8VGS;B!D
M92!C;W)R96\@96X@;&$@<75E(')E8VEB:7(@;&$@8V]N=')A<V7Q83HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("));G-E<G1A
M<B!C96QD82!D971RX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O
M<F4B"FUS9W-T<B`B26YS97)T87(@8V5L9&$@86YT97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED
M("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DEN<V5R=&%R(&-O;'5M
M;F$@9&5T<N%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B
M"FUS9W-T<B`B26YS97)T87(@8V]L=6UN82!A;G1E<R(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,"!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R
M("));G-E<G1A<B!M96YS86IE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!A9G1E<B(*;7-G<W1R("));G-E<G1A<B!PX7)R869O(&1E='+A
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS
M9W-T<B`B26YS97)T87(@<.%R<F%F;R!A;G1E<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN
M<V5R="!R;W<@869T97(B"FUS9W-T<B`B26YS97)T87(@9FEL82!D96)A:F\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("));G-E
M<G1A<B!F:6QA(&5N8VEM82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@
M=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("));G-E<G1A<B!L82!R
M97-P=65S=&$@;F5C97-A<FEA(&$@;&$@<')E9W5N=&$@9&4@<V5G=7)I9&%D
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B26YS97)T
M87(O36]D:69I8V%R(&EM86=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN
M:R(*;7-G<W1R("));G-E<G1A<B]-;V1I9FEC87(@=NUN8W5L;R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(E-A;&1O(&EN<W5F:6-I96YT92!P87)A(&5N=FEA<B!A
M(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET+B(*;7-G<W1R(")386QD;R!I;G-U9FEC:65N=&4N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B16YT
M97)O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S<*;7-G:60@(DEN=&5G
M97(@;&ES="(*;7-G<W1R("),:7-T82!D92!E;G1E<F]S(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(E5$2"`H0V%B96-E
M<F$@9&4@1&%T;W,@9&4@57-U87)I;RD@;F\@=N%L:61A+B(*"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$V-R!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ.30*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R
M"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(D1A=&]S(%I)4"!N
M;R!VX6QI9&]S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I
M9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B07!L:6-A8VGS;B!N
M;R!VX6QI9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DE$(&1E
M(&QO=&4@;F\@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#DQ
M(&QI8B](;W)D92]&;W)M+G!H<#HR,38R(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C,V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S`S(&QI8B](;W)D92]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+B(*;7-G<W1R(")392!H86X@96YV:6%D;R!D871O<R!N;R!VX6QI
M9&]S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P
M"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@
M(D1I<F5C8VGS;B!D92!C;W)R96\@;F\@=N%L:61A+B(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C$P.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X
M+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS
M9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@
M87)C:&EV;R!N;R!VX6QI9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R
M(")#;&%V92!D92!L:6-E;F-I82!N;R!VX6QI9&$N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B4V4@:&$@:6YD:6-A9&\@=6YA('5B:6-A
M8VGS;B!N;R!VX6QI9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@
M(FUS9U]T>7!E(&YO(';A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P
M:5]I9"XB"FUS9W-T<B`B87!I7VED(&YO(';A;&ED;R!O(&1E<V%P87)E8VED
M;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(E!A<N%M971R;W,@;F\@=N%L:61O<R!O(&1E<V%P87)E8VED;W,N(@H*(SH@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0<FEV:6QE9VEO(&1E;"!P861R
M92!N;R!VX6QI9&]S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B240@
M9&4@87-O8VEA9&\@;F\@=N%L:61O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*
M;7-G<W1R(")#\V1I9V\@9&4@<')O9'5C=&\@;F\@=N%L:61O+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A
M;&ED('!R;W1O8V]L+B(*;7-G<W1R(")0<F]T;V-O;&\@;F\@=N%L:61O+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,R!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT
M.B!<(B5S7"(B"FUS9W-T<B`B1&5S=&EN871A<FEO(&YO(';A;&ED;SH@7"(E
M<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#@P(&QI8B](;W)D92]+
M;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS
M9W-T<B`B3V)J971O(&-O;7!A<G1I9&\@;F\@=N%L:61O+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED
M('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")$:7)E8V-I\VX@9&5L(')E;6ET
M96YT92!N;R!VX6QI9&$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S
M='(@(D1A=&]S('5N:6-O9&4@;F\@=N%L:61O<RXB"@HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G
M<W1R("));G9E;G1A<FEO(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R
M("));G9E<G1I<B!S96QE8V-I\VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B27+A;BP@4F5P^F)L:6-A($ES;.%M:6-A
M(&1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER87$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER
M96QA;F0B"FUS9W-T<B`B27)L86YD82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(DES;&$@9&4@
M36%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(D)O<G)A<V-A
M<R!A:7-L861A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,30@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES<F%E;"(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U
M97(B"FUS9W-T<B`B16UI<V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B0W5R
M<VEV82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED
M(")*86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")%;F5R
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P\VXB"@HC.B!C;VYF:6<O
M+F)A:R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P
M,C(M2E`I(@IM<V=S='(@(DIA<&]NZ7,@*$E33RTR,#(R+4I0*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R
M(")*97)S97DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)DX6XB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R(")*=6QI;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FEO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B
M2G5S=&EF>2(*;7-G<W1R(")*=7-T:69I8V%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU
M<W1I9GD@0V5N=&5R(@IM<V=S='(@(D%L:6YE87(@86P@8V5N=')O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")*=7-T:69I8V%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")!;&EN96%R(&$@
M;&$@:7IQ=6EE<F1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`B06QI;F5A<B!A(&QA(&1E<F5C:&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T
M86XB"FUS9W-T<B`B2V%Z86MH<W1A;B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM
M<V=S='(@(K]#;VYS97)V87(@96P@;W)I9VEN86P_(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY
M82(*;7-G<W1R(")+96YY82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP
M.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(D5L('-E<G9I9&]R($ME<F)E<F]S(&AA(')E8VAA
M>F%D;R!L82!A=71E;G1I9FEC86-I\VXN(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(").;W9A
M=&]S(&1E;"!+97)N96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")#<F5A8VGS;B!D92!C
M;&%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B
M2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(DAU96QL82!D:6=I=&%L(&1E(&QA
M(&-L879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED
M(")+97D@3&5N9W1H(@IM<V=S='(@(E1A;6'Q;R!D92!C;&%V92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS
M9W-T<B`B5&EP;R!D92!C;&%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B57-O(&1E(&QA
M(&-L879E.B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I
M9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("),82!C;&%V92!Y82!E>&ES=&4@96X@96P@<V5R=FED;W(@
M9&4@8VQA=F5S('#Z8FQI8V\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0S"FUS9VED(")+:61S(@IM<V=S='(@(DYI\6]S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I
M8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]R96$L(%)E
M</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A(&1E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]R96$L(%)E</IB;&EC82!D92(*
M"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A
M;B`H155#+4M2*2(*;7-G<W1R(")#;W)E86YO("A%54,M2U(I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED
M(")+=7=A:70B"FUS9W-T<B`B2W5W86ET(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N
M(@IM<V=S='(@(DMY<F=Y>G-T86XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B7T1I<W1R:6)U8VGS
M;B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA
M;F=U86=E(@IM<V=S='(@(DED:6]M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O+"!297#Z8FQI8V$@
M1&5M;V-RX71I8V$@4&]P=6QA<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")#=6%R=&\@;65N9W5A;G1E
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A
M<W-W;W)D($-H86YG92(*;7-G<W1R("+:;'1I;6\@8V%M8FEO(&1E(&-O;G1R
M87-E\6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B0W5A<G1O
M(&UE;F=U86YT92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34X"FUS9VED
M("),87-T(%5P9&%T960Z(@IM<V=S='(@(MIL=&EM82!A8W1U86QI>F%C:?-N
M.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`BVFQT:6UA('-E<VGS;CH@
M)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BVFQT:6UA
M('-E<VGS;CH@)7,@9&5S9&4@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("+:;'1I;6$@
M<V5S:?-N.B!.=6YC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQA='9I
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM
M<V=S='(@(DQE>65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B1&ES
M=')I8G5C:?-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*
M;7-G<W1R(")$96IA<B!E;B!B;&%N8V\@<&%R82!E;&EM:6YA<B!E;"!B;W)D
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),96)A;F]N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS
M9VED("),969T(@IM<V=S='(@(DEZ<75I97)D82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3`U"FUS9VED("),969T(&AE861E<B(*;7-G<W1R(")#86)E
M8V5R82!I>G%U:65R9&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,0IM
M<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B5F%L;W)E<R!D92!L82!I>G%U
M:65R9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB
M"FUS9W-T<B`B3FEV96PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB
M97)I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R
M("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T
M96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL
M92(*;7-G<W1R("),:6=E<F$@;&QO=FEZ;F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*
M;7-G<W1R("),;'5V:6$@;&EG97)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB
M"FUS9W-T<B`B3&QU=FEA(&QI9V5R82!M871U=&EN82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!2
M86EN($QA=&4B"FUS9W-T<B`B3&QU=FEA(&QI9V5R82!V97-P97)T:6YA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G
M:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(D%G=6%C97)O(&QI9V5R
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P
M"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("),;'5V
M:6%S('D@=')U96YO<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DYE=F%D
M82!S=6%V92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("),:6=E
M<F\@86=U86-E<F\@9&4@;FEE=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(D-H87-C87)R:6QL;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$X"FUS9VED("),:6YK(@IM<V=S
M='(@(E;M;F-U;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*
M;7-G<W1R(")%;"!V[6YC=6QO(&%P=6YT82!A.B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(E9I
M;F-U;&%R(&1I<F5C8VGS;B!D92!C;W)R96\@82!L82!PX6=I;F$@9&4@8V]M
M<&]S:6-I\VX@86P@;6]S=')A<B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E
M<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B5NUN
M8W5L;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI
M;G5X($-O;VMI92(*;7-G<W1R(")#;V]K:64@3&EN=7@B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(B"FUS9W-T<B`B3&ES=&%R("T@96P@=7-U87)I;R!P=65D92!E
M>&%M:6YA<B!L82!C87)P971A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B3&ES=&%R(&)A<V5S
M(&1E(&1A=&]S(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G
M:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B3&ES=&%R('1E;6%S(&1E
M(&%Y=61A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES
M="!486)L97,B"FUS9W-T<B`B3&ES=&%R('1A8FQA<R(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM
M<V=S='(@(DQI<W0M07)C:&EV92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E
M<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W0M2&5L
M<"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B
M3&ES="U)9"(*;7-G<W1R("),:7-T+4ED(@H*(SH@;&EB+TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DQI
M<W0M3W=N97(B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3,*
M;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:7-T+5!O<W0B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R
M:6)E(@IM<V=S='(@(DQI<W0M4W5B<V-R:6)E(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM
M<V=S='(@(DQI<W0M56YS=6)S8W)I8F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F
M86EL960Z("5S(@IM<V=S='(@(DAA(&9A;&QA9&\@96P@;&ES=&%D;R!D92!L
M87,@<V5S:6]N97,Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*
M;7-G<W1R(")(82!F86QL861O(&5L(&QI<W1A9&\@9&4@=7-U87)I;W,Z("5S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED
M("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")%;"!L:7-T
M861O(&1E('5S=6%R:6]S(&5S=.$@9&5S:&%B:6QI=&%D;RXB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T
M<B`B3&ET97)A='5R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI
M='5A;FEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3&5Y96YD;RXN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO8V%L
M('1I;64Z("(*;7-G<W1R(")(;W)A(&QO8V%L.B`B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM
M<V=S='(@(DED:6]M82!Y(&AO<F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z
M-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E5B:6-A8VGS;B(*"B,Z(&QO
M9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*
M;7-G:60@(DQO9R!I;B(*;7-G<W1R("));FEC:6%R('-E<VGS;B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R(")296=I<W1R;R!D92!L87,@
M<V5S:6]N97,@9&4@<VEN8W)O;FEZ86-I\VX@86YT97)I;W)E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`B4V%L:7(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*
M;7-G:60@(DQO9VEN(@IM<V=S='(@(DEN:6-I87(@<V5S:?-N(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K
M<R(*;7-G<W1R(")487)E87,@9&4@:6YI8VEO(&1E('-E<VGS;B(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A
M=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC
M;W)R96-T;'DN(@IM<V=S='(@(B(*(D9A;&SS(&5L(&EN:6-I;R!D92!S97-I
M\VX@<&]R<75E(&EN=')O9'5J;R!I;F-O<G)E8W1A;65N=&4@<W4@;F]M8G)E
M(&1E("(*(G5S=6%R:6\@;R!C;VYT<F%S9?%A+B(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B1F%L
M;/,@96P@:6YI8VEO(&1E('-E<VGS;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(E1E>'1O(&-O;7!L
M971O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E
M(@IM<V=S='(@(D%M;W(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM<V=S='(@(D)A:F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(D%L9F%B
M971O(&=R:65G;R!E;B!M:6[Z<V,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@
M;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")!;&9A8F5T;R!L871I;F\@96X@;6EN
M^G-C+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B3OIM97)O<R!R;VUA;F]S(&5N(&UI;OIS8RXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU
M>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G;R(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R
M>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M
M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")%
M;"!A9&IU;G1O($U3+51.148@;F\@8V]N=&5N[6$@9&%T;W,N(@H*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS
M9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R
M(")-86-A;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D;VYI82P@06YT:6=U82!2
M97#Z8FQI8V$@675G;W-L879A(&1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM
M<V=S='(@(DUA9&%G87-C87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VEA(@H*(SH@8V]N9FEG+RYB
M86LO<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T<B`B
M0V]R<F5O(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-3(T
M"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(D%D;2X@8V]R<F5O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(D-R96%R(%]V[6YC
M=6QO+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA<VEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD
M:79E<R(*;7-G<W1R(")-86QD:79A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R
M(")-86QI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C
M871E9V]R:65S+B(*;7-G<W1R("(B"B)'97-T:6]N82!L82!L:7-T82!D92!C
M871E9V]R[6%S(&-O;B!L82!Q=64@971I<75E=&%R(&5L96UE;G1O<R!Y(&QO
M<R!C;VQO<F5S("(*(F%S;V-I861O<R!A(&1I8VAA<R!C871E9V]R[6%S+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"FUS
M9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P82!M87`R-"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S
M="!M87`B"FUS9W-T<B`B36%P82!M87!Q=65S="(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*
M;7-G<W1R(")#;W)R97-P;VYD96YC:6%S(&%L;6%C96YA9&%S+B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G
M<W1R(")-87)Z;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G
M96XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I
M=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B36%R8V%R(&-O;B!L87,@
M8F%N9&5R87,@9&4@3&7M9&\O4VEN(&QE97(B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@
M26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-87)C87(@8V]N(&]T<F%R
M(&)A;F1E<F%S("AP+F4N($EM<&]R=&%N=&4O4F5S<&]N9&ED;RDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B27-L87,@36%R<VAA;&PB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6-A(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG
M(&9I96QD<R(*;7-G<W1R(")#86UP;W,@8V]I;F-I9&5N=&5S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I=&%N:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA
M=7)I=&EU<R(*;7-G<W1R(")-875R:6-I;R(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D
M:70N(@IM<V=S='(@(E-A;&1O(&WA>&EM;R!P97)M:71I9&\N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")392!H82!S;V)R97!A
M<V%D;R!E;"!N^FUE<F\@;>%X:6UO(&1E('!A<G1E<R!D92!M96YS86IE+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M<"X@;>%X:6UA(/IL=&EM87,@
M,C0@:&]R87,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED
M(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UP+B!MX7AI
M;6$@^FQT:6UA<R`V(&AO<F%S.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I
M9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(").
M^FUE<F\@;>%X:6UO(&1E(&)L;W%U97,@9&5L('!O<G1A;"(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HY,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,C$@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM
M<V=S='(@(DQO;F=I='5D(&WA>&EM82(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%Y;R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D:6-I
M;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS
M9VED(")-96UB97)S(@IM<V=S='(@(DUI96UB<F]S(@H*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S
M='(@(D9O<FUA=&\@9&5L(&UE;OHZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`B0V]M8FEN87(@8V5L9&%S(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R
M(")-96YS86IE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*
M;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF
M:65D+B(*;7-G<W1R("(B"B)392!H82!C;VUP<F]B861O(&-O<G)E8W1A;65N
M=&4@96P@;65N<V%J92!P97)O(&YO('-E('!U961E('9E<FEF:6-A<B!E;"`B
M"B)C97)T:69I8V%D;R!D96P@9FER;6%N=&4N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E
M9"XB"FUS9W-T<B`B365N<V%J92!C861U8V%D;RXB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*
M;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4:7!O(&1E(&UE;G-A:F4B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H
M97(B"FUS9W-T<B`B5&EE;7!O(&1E($UE=&%R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B0FQO<75E($UE=&%R(&YO(&1I<W!O;FEB;&4N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D)L;W%U92!-971A<B!N;R!D
M:7-P;VYI8FQE+B!392!H86X@<F5G:7-T<F%D;R!L;W,@9&5T86QL97,@<&%R
M82!E;"`B"B)A9&UI;FES=')A9&]R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"XB"FUS9W-T<B`B3F\@97-TX2!C;VYE8W1A9&$@;&$@365T87)$0B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B
M3>ET;V1O(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q(&QI8B](
M;W)D92]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B16P@;>ET;V1O
M(%PB)7-<(B!N;R!E<W3A(&1E9FEN:61O(@H*(SH@;&EB+TAO<F1E+U)00R]R
M97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E
M9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(DWI=&]D;R!N;R!D
M969I;FED;RX@3>ET;V1O(&QL86UA9&\Z("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z.#(*;7-G
M:60@(DUE=')I8R(*;7-G<W1R(")-Z71R:6-O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B
M"FUS9W-T<B`B3>EJ:6-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E
M9"!3=&%T97,@;V8B"FUS9W-T<B`B36EC<F]N97-I82P@17-T861O<R!&961E
M<F%D;W,@9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")%;B!M961I
M;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I
M9"`B36EM92!4>7!E(@IM<V=S='(@(E1I<&\@36EM92(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$W"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B`B"FUS9W-T<B`B5&5M<"X@;>UN+B!L87,@^FQT:6UA<R`R-"!H;W)A<SH@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@(DUI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7`N(&WM;BX@;&%S(/IL=&EM
M87,@-B!H;W)A<SH@(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y
M"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I
M<F5D(@IM<V=S='(@(E1O9&%V[6$@;F\@:&$@97AP:7)A9&\@;&$@86YT:6?\
M961A9"!M[6YI;6$@9&4@;&$@8V]N=')A<V7Q82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G
M<W1R(")2969L96IA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")-:7-C96SA;F5A(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%10
M7U)E<75E<W0N(@IM<V=S='(@(E!A<75E=&4@4$5!4B!(5%107U)E<75E<W0@
M9&5S87!A<F5C:61O+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*
M;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@
M9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P
M<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)&86QT82!L82!C;VYF:6=U<F%C:?-N
M+B!4:65N92!Q=64@9V5N97)A<FQA(&%H;W)A('-I(&1E<V5A('5T:6QI>F%R
M(&5S=&$@(@HB87!L:6-A8VGS;BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*
M;7-G<W1R("))1"!D92!M96YS86IE(&1E<V%P87)E8VED;RXB"@HC.B!L:6(O
M3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")087%U
M971E(%!%05(@36%I;"!D97-A<&%R96-I9&\N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO
M;B!)1"XB"FUS9W-T<B`B240@9&4@<V5S:?-N(&1E<V%P87)E8VED;RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS
M9VED(")-;R(*;7-G<W1R("),=6XB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R
M>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B0V]R
M<F5O(&WS=FEL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-CD*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DUO9&5R861O(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B
M4V4@:&$@;6]D:69I8V%D;R!L82!F96-H82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R(")-;V1I9FEC87(@55),(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B
M3?-D=6QO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R
M(")-;VQD879I82P@4F5P^F)L:6-A(&1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS
M9W-T<B`B3?-N86-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG
M;VQI82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3@X"FUS9VED(")-;VYT
M:"!A;F0@>65A<B(*;7-G<W1R(")-97,@>2!A\6\B"@HC.B!L:6(O2&]R9&4O
M36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DUE
M;G-U86QM96YT92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT
M<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")&87-E<R!D
M92!L82!L=6YA(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.38@;&EB+T9I;&4O
M0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@
M9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T
M<B`B4V4@:&%N(&5N8V]N=')A9&\@;>%S(&-A;7!O<R!E;B!L82!L[6YE82`E
M9"!Q=64@;&]S("5D(&5S<&5R861O<RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS
M9W-T<B`B36%R<G5E8V]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")&
M=6YD86UE;G1A;&UE;G1E(&1E<W!E:F%D;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y
M(@IM<V=S='(@(D9U;F1A;65N=&%L;65N=&4@;G5B;W-O(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L
M>2!3=6YN>2(*;7-G<W1R(")&=6YD86UE;G1A;&UE;G1E('-O;&5A9&\B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I
M9"`B36]V92!$;W=N(@IM<V=S='(@(D1E<W!L87IA<B!H86-I82!A8F%J;R(*
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS
M9VED(")-;W9E($QE9G0B"FUS9W-T<B`B1&5S<&QA>F%R(&$@;&$@:7IQ=6EE
M<F1A(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B1&5S<&QA>F%R(&$@;&$@
M9&5R96-H82(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(D1E<W!L87IA<B!H86-I
M82!A<G)I8F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1&5S<&QA>F%R(&AA
M8VEA(&%B86IO(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V
M"FUS9VED(")-;W9E('5P(@IM<V=S='(@(D1E<W!L87IA<B!H86-I82!A<G)I
M8F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:7%U92(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL979E
M;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B3&ES=&%S(&1E<W!L96=A8FQE
M<R!M=6QT:2UN:79E;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#4X"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B
M36%P82!52R!M^FQT:7!L92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V
M"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96-C:?-N
M(&WZ;'1I<&QE(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DED96YT:61A9"(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")-:2!I9&5N=&ED860B"@HC.B!S97)V:6-E
M<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS9VED(")->2!0;W)T86PB"FUS9W-T
M<B`B36D@<&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S
M"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(D1I<W1R:6)U8VGS
M;B!D92!M:2!P;W)T86PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B37EA
M;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D\L
M($Y/(&5S=&]Y(&1E(&%C=65R9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,3$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").
M86UE(@IM<V=S='(@(DYO;6)R92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R
M(").86UI8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA
M;F1S(@IM<V=S='(@(DAO;&%N9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT
M:6QL97,B"FUS9W-T<B`B06YT:6QL87,@2&]L86YD97-A<R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E
M(%523"(*;7-G<W1R(")54DP@8F%S92!D92!.971S8V%P92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2
M979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@9&4@86YU;&%C:?-N(&1E($-!
M(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B55),
M(&1E('!O;.UT:6-A<R!D92!#02!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L
M(%523"(*;7-G<W1R(")54DP@9&4@<F5N;W9A8VGS;B!D92!.971S8V%P92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S
M8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@9&4@86YU;&%C:?-N
M(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").
M;VUB<F4@9&4@<V5R=FED;W(@4U-,(&1E($YE='-C87!E(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B0V]M96YT87)I;R!D96P@8V5R=&EF
M:6-A9&\@9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G
M<W1R(")4:7!O(&1E(&-E<G1I9FEC861O(&1E($YE='-C87!E(@H*(SH@8V]N
M9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K
M(@IM<V=S='(@(E)E9"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R(").
M=6YC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").=65V82!#
M86QE9&]N:6$B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYU979A(&-A
M=&5G;W+M82(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP
M.C@Q(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI
M8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R(")%;G9I87(@;65N<V%J92!A
M("5S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N
M+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O
M;B(*;7-G<W1R("),=6YA(&YU979A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA
M;"DB"FUS9W-T<B`B3G5E=F\@;F]M8G)E(&1E('5S=6%R:6\@*&]P8VEO;F%L
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3G5E=F$@6F5L86YD
M82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B
M3F5W('!A<W-W;W)D(@IM<V=S='(@(D-O;G1R87-E\6$@;G5E=F$B"@HC.B!L
M:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(DQA
M(&YU979A(&-O;G1R87-E\6$@97AP:7)A<N$@96P@)7@N(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R("),87,@8V]N=')A<V7Q87,@;F\@8V]I
M;F-I9&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B
M3G5E=F$@=F5N=&%N82`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B
M3F]T:6-I87,B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS
M,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B1RX@9&4@;F]T:6-I87,B
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B
M3F5X="(*;7-G<W1R(")3:6=U:65N=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B4'+S>&EM87,@
M-"!F87-E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS
M9W-T<B`B3W!C:6]N97,@<VEG=6EE;G1E<R(*"B,Z(&QI8B](;W)D92]522]0
M86=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")3:6=U:65N=&4^
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87)A9W5A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*
M;7-G<W1R(").:6=E<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F]C:&4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(DYO(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+B(*;7-G<W1R(").;R!H87D@9&%T;W,@9&4@8V]N9FEG=7)A8VGS
M;B!P87)A(&UO<W1R87(@9&EF97)E;F-I87,N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O
M<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B3F\@<V4@9&ES<&]N92!D
M92!E<W1R871E9VEA(&1E(&5L86)O<F%C:?-N(&1E(&EMX6=E;F5S($E33RXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I
M9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(DYO(&AA>2!P;&%N=&EL
M;&$@9&4@;&]T97,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$P,0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C,X-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VXB"FUS9W-T<B`B3F\@:&%Y(&)L;W%U97,@96X@;&$@<&]S:6-I
M\VX@:6YD:6-A9&$B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM
M<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@
M;F]M8G)E(&1E(&%G96YD82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!-0T%,
M+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N
M9V4N(@IM<V=S='(@(E-I;B!C86UB:6]S+B(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(").;R!S92!P=65D96X@8?%A
M9&ER(&1E<V-E;F1I96YT97,@82!E<W1E('!R:79I;&5G:6\N(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H<#HU,#@@;&EB+TAO<F1E+U5T
M:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(DYO
M('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C
M:?-N('!A<F$@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(DYO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA
M8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!&5%`N(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(DYO
M('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C
M:?-N('!A<F$@5D93('!O<B!344PN(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"B).;R!S92!H
M82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P
M87)A(%9&4R!P;W(@87)C:&EV;R!344PN(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R(").;R!Q=65D82!S86QD;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P
M;&EE9"XB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@96P@9&5S=&EN
M;RXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(P"FUS9VED(").;R!F
M:6QE('5P;&]A9&5D(@IM<V=S='(@(DYO('-E(&AA(&-A<F=A9&\@;FEN9_IN
M(&%R8VAI=F\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@
M(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(").;R!S92!H86X@96YC;VYT<F%D
M;R!I8V]N;W,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q
M-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,S`*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B
M3F\@<V4@:&$@9&5F:6YI9&\@;&$@=6)I8V%C:?-N+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(").;R!S92!H82!D969I;FED;R!L82!U8FEC86-I
M\VXN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM
M<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F\@<V4@:&$@
M:6YT<F]D=6-I9&\@=6X@;65N<V%J92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB
M"FUS9W-T<B`B3F\@<V4@:&$@97-P96-I9FEC861O('5N(&YO;6)R92XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").
M;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF
M:6-A9&\@=6X@;OIM97)O+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYO(&]F
M96YS:79A<R(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E
M\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@2%144"XB"@HC.B!L:6(O2&]R
M9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S92!H
M82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF
M:6-A8VGS;B!)34%0+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O('5N
M82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N($ME<F)E<F]S
M+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C<W(&QI8B](;W)D92]!
M=71H+VQO9VEN+G!H<#HX-`HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<U
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O('5N82!C
M;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N(&1E(&EN:6-I;RXB
M"@HC.B!L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@
M<&%R82!L82!A=71E;G1I9FEC86-I\VX@4$%34U=$+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&EN
M=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C
M:?-N(%--0BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#<*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(DYO('-E(&AA(&EN
M9&EC861O(';M82!D92!A8V-E<V\@82!L;W,@8FEN87)I;W,@3W!E;E-33"X@
M4&%R82!T<F%B86IA<B!C;VX@(@HB9&%T;W,@4$M#4R`Q,B!H86-E;B!F86QT
M82!L;W,@8FEN87)I;W,@3W!E;E-33"XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N
M(@IM<V=S='(@(E-I;B!A;'1A<R!P96YD:65N=&5S+B(*"B,Z(&QI8B]61E,N
M<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")#87)E8V4@
M9&4@<75O=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B4VEN
M(')A>6%S(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E
M<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DYO('-E(&AA(&5S<&5C:69I
M8V%D;R!U;B!S97!A<F%D;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS
M9W-T<B`B3FEN9W5N;R(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU.#<*;7-G:60@
M(DYO('-U8V@@9FEL92(*;7-G<W1R(").;R!E>&ES=&4@96P@87)C:&EV;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS
M9W-T<B`B3F\@<V4@9&ES<&]N92!D92!U;B!D:7)E8W1O<FEO(&1E(&%L;6%C
M96YA;6EE;G1O('1E;7!O<F%L+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S$@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,0IM
M<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S
M='(@(DYO('-E(&AA(&5N=FEA9&\@96P@;F]M8G)E(&1E('5S=6%R:6\@>2]O
M(&QA(&-O;G1R87-E\6$N(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B3F\@<V4@:&%N(&1E=G5E;'1O(&1A=&]S(%A-3"!VX6QI9&]S(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-"!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G
M<W1R(")3:6X@=F%L;W)E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B).;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N(&QA(&-O;F9I9W5R86-I
M\VX@;W)I9VEN86PN(%)E9V5N97)A<B!L82`B"B)C;VYF:6=U<F%C:?-N+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DYO('-E(&5N8V]N='+S(&QA('9E
M<G-I\VX@96X@;&$@8V]N9FEG=7)A8VGS;BX@4F5G96YE<F%R(&QA(&-O;F9I
M9W5R86-I\VXN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I
M9"`B3F]N92(*;7-G<W1R(").:6YG=6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM
M<&QI8VET*2(*;7-G<W1R(").:6YG=6YO("AU<V\@:6UP;.UC:71O*2(*"B,Z
M(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H
M25-/+3@X-3DM,3`I(@IM<V=S='(@(D[S<F1I8V\@*$E33RTX.#4Y+3$P*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B27-L82!D92!.;W)F
M;VQK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")(
M96UI<V9E<FEO(&YO<G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B27-L87,@36%R:6%N87,@9&5L($YO<G1E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").;W)W87DB"FUS9W-T<B`B3F]R=65G82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M3F\@9&5S<'7I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P
M"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DYO(&%N=&5S(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HT,34*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G
M<W1R(").;R!E<R!U;B!D:7)E8W1O<FEO(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@
M(E-I;B!D97-A<G)O;&QA<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(E-I
M;B!E<W1A8FQE8V5R(@H*(SH@;&EB+U9&4RYP:'`Z,3DS(&QI8B]61E,N<&AP
M.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP:'`Z,C4R"B,Z(&QI8B]6
M1E,N<&AP.C(V.2!L:6(O5D93+G!H<#HR.#4@;&EB+U9&4RYP:'`Z,S`Q(&QI
M8B]61E,N<&AP.C,Q-@HC.B!L:6(O5D93+G!H<#HS,S,@;&EB+U9&4RYP:'`Z
M,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H<#HU,#4*(SH@;&EB+U9&
M4RYP:'`Z-3<T(&QI8B]61E,N<&AP.C4Y,2!L:6(O5D93+G!H<#HV-CD*(SH@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*
M(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*;7-G:60@(DYO
M="!S=7!P;W)T960N(@IM<V=S='(@(DYO(&5S=.$@<V]P;W)T861O+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R\N
M8F%K+VAO;VMS+G!H<"YD:7-T.C$P-3@*(SH@8V]N9FEG+RYB86LO<F5G:7-T
M<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1A<R(*
M"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYO(&AA>2!N861A
M('9I<W5A;&EZ86)L92P@<F5T<F]C961A+B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9I
M96UB<F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U,`IM<V=I9"`B3G5M
M8F5R(@IM<V=S='(@(D[Z;65R;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#(Y"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(").^FUE
M<F\@9&4@8V%R86-T97)E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<S
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(W(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(").^FUE<F\@
M9&4@8V]L=6UN87,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM
M<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B3OIM97)O(&1E(&9I;&%S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I
M9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@HB3F\@<V4@:&%N(&5S<&5C:69I
M8V%D;R!N^FUE<F]S(&$@86-T=6%L:7IA<B!E;B!L82!L:7-T82!D92!D:7-T
M<FEB=6-I\VXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")!8V5P=&%R(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J
M96-T(@IM<V=S='(@(D]B:F5T;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")#<F5A
M9&]R(&1E(&]B:F5T;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$P.`IM
M<V=I9"`B3V-T86PB"FUS9W-T<B`B3V-T86PB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/8W1U
M8G)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E
M;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT<F%R(&]F96YS87,B"@HC.B!C;VYF
M:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*
M;7-G<W1R(")/9FEC:6YA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N(@IM<V=S='(@(DQA(&-O;G1R87-E\6$@86YT:6=U82!Y(&QA
M(&YU979A(&1E8F5N('-E<B!D:7-T:6YT87,N(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T
M<B`B0V]N=')A<V7Q82!A;G1I9W5A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E
M8W0N(@IM<V=S='(@(DQA(&-O;G1R87-E\6$@86YT:6=U82!N;R!E<R!C;W)R
M96-T82XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VWA;B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0
M('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B4_-L
M;R!L;W,@<V5R=FED;W)E<R!)34%0('-O<&]R=&%N(&QA<R!C87)P971A<R!C
M;VUP87)T:61A<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E/S;&\@;V9E
M;G-I=F%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@
M86QL;W=E9"XB"FUS9W-T<B`B4_-L;R!S92!P97)M:71E('5N82!D:7)E8V-I
M\VX@9&4@8V]R<F5O+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV
M-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB4_-L;R!E;"!P<F]P:65T
M87)I;R!O('5N(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<'5E9&4@8V%M
M8FEA<B!L82`B"B)P<F]P:65D860@;R!L;W,@<')I=FEL96=I;W,@9&4@<')O
M<&EE=&%R:6\@9&4@=6X@<F5C=7)S;R!C;VUP87)T:61O(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G
M:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%B<FER(&5N('5N
M82!N=65V82!V96YT86YA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T
M(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(D5R<F]R
M($]P96Y34TPZ($YO('-E('!U961E;B!E>'1R865R(&1A=&]S(&1E(&QA('!A
M<G1E(%,O34E-12!F:7)M861A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!8G)I<B!E<W1E(';M
M;F-U;&\@96X@=6YA('9E;G1A;F$@;G5E=F$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B
M4VES=&5M82!O<&5R871I=F\B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM
M<V=S='(@(D]P8VEO;F5S(&1E("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM
M<V=S='(@(DQI<W1A(&]R9&5N861A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A
M;FEZ86-I\VXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM
M<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")5;FED860@;W)G
M86YI>F%T:79A(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z
M,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7IA8VGS;B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")0;&%N=&EL;&$@9&4@87!L
M:6-A8VGS;B!O<FEG:6YA;"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SHB"FUS9W-T<B`B4&QA;G1I;&QA<R!O<FEG:6YA;&5S(&5N("5S.B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D]T<F\B"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3$V
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")/=')A
M(&EN9F]R;6%C:?-N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4')I=FEL96=I
M;W,@9&5L('!R;W!I971A<FEO(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H
M<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(DQA(&%U=&5N=&EF:6-A8VGS;B!004T@;F\@97-TX2!D
M:7-P;VYI8FQE+B(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B4$5!4CHZ
M36]T;W(@9&4@8V]R<F5O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D9I
M<FUA(&1I9VET86P@4$=0(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(D1A=&]S
M(&-I9G)A9&]S(&-O;B!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")#;&%V92!0
M1U`@</IB;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-38*
M;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%T
M;W,@9FER;6%D;W,O8VEF<F%D;W,@8V]N(%!'4"(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B0_-D:6=O(%!(
M4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL
M(@IM<V=S='(@(DEN=.ER<'(N(%!(4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM
M<V=S='(@(DQL;W9I>FYA('9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4F%I;B(*;7-G
M<W1R("),;'5V:6$@=F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3:&]W97)S(@IM<V=S
M='(@(D-H87!A<G)O;F5S('9E<W!E<G1I;F]S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<B"FUS
M9W-T<B`B3FEE=F4@=F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B06=U86-E<F\@9&4@;FEE=F4@=F5S<&5R=&EN;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")0
M32!3=6XB"FUS9W-T<B`B4V]L('9E<W!E<G1I;F\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@5"U3=&]R
M;7,B"FUS9W-T<B`B0F]R<F%S8V%S('9E<W!E<G1I;F%S(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<B"FUS9W-T<B`B3F\@<V4@96YC=65N=')A(&QA(&5X=&5N<VGS
M;B!03U-)6"(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L
M;"(*;7-G<W1R("));G3I<G!R+B!07TA0(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN
M9R(*;7-G<W1R(")-87)G96XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@
M(E!A:VES=.%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S
M='(@(E!A;&5S=&EN;W,L(%1E<G)I=&]R:6]S($]C=7!A9&]S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")086YA;6$B"FUS9W-T<B`B4&%N86WA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@
M1W5I;F5A(@IM<V=S='(@(E!A</IA($YU979A($=U:6YE82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U
M9'DB"FUS9W-T<B`B4&%R8VEA;&UE;G1E(&YU8F]S;R(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P,C(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-S<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHT,R!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G
M:60@(E!A<W-W;W)D(@IM<V=S='(@(D-O;G1R87-E\6$B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("),82!C;VYT<F%S9?%A('-E(&-A
M;6)I861O(&-O<G)E8W1A;65N=&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T
M<B`B0V]N=')A<V7Q82!I;F-O<G)E8W1A(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DAA>2!Q=64@:6YT<F]D
M=6-I<B!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!2
M041)55,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3<*;7-G:60@(E!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D-O;G1R87-E\6$@
M8V]N(&-O;F9I<FUA8VGS;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(D-O;G1R87-E\6$Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A
M<W-W;W)D.B`B"FUS9W-T<B`B0V]N=')A<V7Q83H@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H<#HR,#,X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R("),87,@8V]N=')A<V7Q87,@=&EE;F5N('%U
M92!C;VEN8VED:7(N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*
M;7-G:60@(E!A<W1E(@IM<V=S='(@(E!E9V%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O
M;2!C;&EP8F]A<F0B"FUS9W-T<B`B4&5G87(@9&5L('!O<G1A<&%P96QE<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*
M;7-G:60@(E!A=&@B"FUS9W-T<B`B5NUA(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T
M<B`B06QT87,@<&5N9&EE;G1E<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")'96YT92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")0
M97)C96YT(@IM<V=S='(@(E!O<F-E;G1A:F4B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(E)E86QI>F%R(&]P97)A
M8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BOU)E86QI>F%R(&]P97)A8VEO
M;F5S(&1E(&UA;G1E;FEM:65N=&\@86P@:6YI8VEA<B!S97-I\VX_(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB
M"FUS9W-T<B`B4')I=FEL96=I;R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@
M;F]T(&1E;&5T960N(@IM<V=S='(@(DYO('-E(&AA(&5L:6UI;F%D;R!E;"!P
M<FEV:6QE9VEO(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3DP"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")0<FEV:6QE9VEO(&1E
M;F5G861O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C$@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S
M='(@(E!R:79I;&5G:6]S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I
M;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B
M4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R
M86-I\VX@9&4@<')I=FEL96=I;W,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T
M<B`B26YF;W)M86-I\VX@<&5R<V]N86PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T
M<B`B4&5R^B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B
M4&5T<R(*;7-G<W1R(")-87-C;W1A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B
M"FUS9W-T<B`B1FEL:7!I;F%S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;.EF;VYO
M(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED
M(")0:&]T;W,B"FUS9W-T<B`B1F]T;V=R86;M87,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C
M86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T
M<B`B4.UX96QE<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I
M9"`B4&QA=&ET=61E<R(*;7-G<W1R(")4\W!I8V]S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(E!U;'-E(&5N
M('5N82!C96QD82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")#
M;VYF:7)M92!Q=64@9&5S96$@96QI;6EN87(@97-T92!E;&5M96YT;SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B0V]N9FER;64@<75E(&1E
M<V5A(&5L:6UI;F%R(&5L(';M;F-U;&\@82!E<W1E(&5L96UE;G1O+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-38V"FUS9VED(")0;&5A<V4@96YT97(@
M82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("));G1R;V1U>F-A('5N(&UE
M<R!Y('5N(&'Q;RXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@
M=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B26YT<F]D=7IC82!E;"!N;VUB
M<F4@9&4@;&$@;G5E=F$@8V%T96=O<NUA.B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S`U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+B(*;7-G<W1R("));G1R;V1U>F-A('5N82!D:7)E8V-I\VX@25`@=N%L
M:61A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0T"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A
M>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("));G1R;V1U>F-A('5N82!F96-H
M82!VX6QI9&$L(&-O;7!R=65B92!E;"!N^FUE<F\@9&4@9.UA<R!D96P@;65S
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("));G1R;V1U>F-A('5N82!H
M;W)A(';A;&ED82XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R
M;V)L96TN(@IM<V=S='(@(E!R;W!O<F-I;VYE('5N(')E<W5M96X@9&5L('!R
M;V)L96UA+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B26YT<F]D
M=7IC82!S=2!N;VUB<F4@9&4@=7-U87)I;R!Y(&-O;G1R87-E\6$N(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B),
M96$@96P@=&5X=&\@<VEG=6EE;G1E+B!$14)%(&%C97!T87(@;&]S('3I<FUI
M;F]S('-I('%U:65R92!U<V%R(&5L('-I<W1E;6$N(@H*(SH@;&EB+TAO<F1E
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T
M>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B26YT<F]D=7IC
M82!E;"!N=65V;R!N;VUB<F4@9&4@8V%T96=O<NUA.B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L
M86YD(@IM<V=S='(@(E!O;&]N:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;.UT:6-A(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL
M<R(*;7-G<W1R(")%;F-U97-T87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G
M<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-I8VGS;B!D92!L82!I;6%G96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")0
M;W-I8VGS;B!D92!L82!T86)L82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,T,S$T+G!H<#HU,2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*2(*;7-G<W1R(")%;G9I87(@82!E<W1A(&-A<G!E=&$@*&YO(&]B
M;&EG861O('!O<B!)34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@
M(E!R96-I<&ET86-I;VYE<R!D92!L82AS*2#Z;'1I;6$H<RD@)7,@:&]R82AS
M*3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I
M9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")0<F]B86)I
M;&ED860\8G(@+SYD92!P<F5C:7!I=&%C:?-N(@H*(SH@;&EB+TAO<F1E+U!R
M969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z
M(&YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!,1$%0(')E<75E<FED82XB
M"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@;F\@<V4@96YC;VYT<O,@
M;&$@97AT96YS:?-N(&1E('-E<VGS;B!R97%U97)I9&$N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(E!R
M97-I\VXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E
M<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')E<VGS;B!A;"!N:79E
M;"!D96P@;6%R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(T"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E!R97-I\VXZ("(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E9I<W1A('!R979I82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(E9I<W1A('!R979I82!D92!L82!I;6%G96X@96X@=6YA
M(&YU979A('9E;G1A;F$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,U
M-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@
M;W!T:6]N<R(*;7-G<W1R(")/<&-I;VYE<R!A;G1E<FEO<F5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B
M4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B26UP<FEM:7(@9&]C=6UE;G1O(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E
M($ME>2(*;7-G<W1R(")#;&%V92!P<FEV861A(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("*_4')O8FQE;6%S
M/R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE
M;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP8VGS;B!D96P@<')O8FQE
M;6$B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G
M:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;WEE8W1O<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3$U(&QI8B](;W)D92]&;W)M+G!H<#HR,3DR(&QI8B](
M;W)D92]&;W)M+G!H<#HS,C@P"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R
M(")497AT;R!D96P@:6YD=6-T;W(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B0VQA=F4@4$=0
M('#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM
M<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO
M(&1E(&-L879E('#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R
M;6%C:?-N(&1E(&-L879E('#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DYO('-E(&=E;F5R
M87)O;B!C;W)R96-T86UE;G1E(&QA<R!C;&%V97,@4/IB;&EC82]0<FEV861A
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED
M(")0=7)G92!M97-S86=E<R(*;7-G<W1R("),:6UP:6%R(&UE;G-A:F5S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B46%T87(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(D-O;G-U;'1A(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G
M<W1R(")1=6]T82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(D-L879E(%)302!P^F)L:6-A("@E9"!B:70I(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R-C@*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*
M;7-G<W1R(")";W3S;B!D92!O<&-I\VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B(*;7-G<W1R("),
M;'5V:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("),;'5V:6$@;6%T=71I
M;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(DQL=79I82!V97-P97)T:6YA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*
M;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(D%G=6%C97)O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A
M:6X@86YD(%-N;W<B"FUS9W-T<B`B3&QU=FEA('D@3FEE=F4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I
M;B!T;R!3;F]W(@IM<V=S='(@(DQL=79I82!A($YI979E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S
M='(@(E)U961A(&1E(&QA(&9O<G1U;F$B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B4F%Z\VXB"@HC.B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("(F
M;F)S<#M,965R)FYB<W`[(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S
M,30N<&AP.C0W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM
M<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("),965R(&UE;G-A:F5S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(K]%;&EM:6YA<B!R96%L;65N
M=&4@)7,_($5S=&$@;W!E<F%C:?-N(&YO('-E('!U961E(&1E<VAA8V5R+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R
M("(B"B*_16QI;6EN87(@<F5A;&UE;G1E(&QO<R!D871O<R!D96P@=7-U87)I
M;R`E<S\@17-T82!O<&5R86-I\VX@;F\@<V4@<'5E9&4@(@HB9&5S:&%C97(N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5G5E
M;'9E(&$@<F5A;&EZ87(@;&$@^FQT:6UA(&%C8VGS;B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS
M9VED(")2969R97-H(@IM<V=S='(@(D%C='5A;&EZ87(B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")!8W1U86QI>F%R(&5L96UE;G1O
M<R!D92!M96[Z(&1I;N%M:6-O<SHB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S
M='(@(D%C='5A;&EZ87(@=FES=&$@9&5L('!O<G1A;"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E9V5X
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,S4*;7-G:60@(E)E;&%T:6]N
M<VAI<"!"<F]W<V5R(@IM<V=S='(@(DYA=F5G861O<B!D92!R96QA8VEO;F5S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(E)E9G)E<V-A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED
M(")296UA<FMS(@IM<V=S='(@(D]B<V5R=F%C:6]N97,B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S
M(@IM<V=S='(@(E-E<G9I9&]R97,@<F5M;W1O<R(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E523"!R96UO=&$@
M*&AT='`Z+R]W=W<N96IE;7!L;RYC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(E%U:71A
M<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B
M4F5M;W9E($)L;V-K(@IM<V=S='(@(E%U:71A<B!B;&]Q=64B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO
M=F4@8V]L=6UN(@IM<V=S='(@(E%U:71A<B!C;VQU;6YA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M
M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B16QI;6EN87(@9F]R;6%T;R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@
M<&%I<B(*;7-G<W1R(")1=6ET87(@<&%R(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(D5L:6UI;F%R
M(&=U:?-N(&=U87)D861O(&1E;"!D:7)E8W1O<FEO('1E;7!O<F%L(&1E;"!S
M97)V:61O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B
M16QI;6EN87(@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R
M;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D5L:6UI;F%R(&5S=&4@;F]D;R!D
M96P@9&]C=6UE;G1O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B16QI;6EN87(@
M=7-U87)I;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T
M<B`B16QI;6EN87(@=7-U87)I;SH@)7,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM
M;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(").;R!S92!P=65D
M92!R97-P;VYD97(@82!L82!S;VQI8VET=60N($/S9&EG;R!D92!E<G)O<B!D
M979U96QT;SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD
M+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!S97)V:6-I;R!S;VQI8VET
M861O+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<V(&QI8B](;W)D92YP:'`Z-3$X
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYO('-E(&AA
M(&5S<&5C:69I8V%D;R!E;"!<(B5S7"(@<F5Q=65R:61O(&5N(&QA(&-O;F9I
M9W5R86-I\VX@9&4@)7,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8W."!L:6(O
M5D93+V9T<"YP:'`Z.#8Q(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@97-P
M96-I9FEC861O(&5L(%PB)7-<(B!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A
M8VGS;B!D92!61E,N(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF
M:6-A9&\@96P@7"(E<UPB(')E<75E<FED;R!E;B!L82!C;VYF:6=U<F%C:?-N
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@
M(E)E<75I<F5D($9I96QD(@IM<V=S='(@(D-A;7!O(&YE8V5S87)I;R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS-#,@;&EB
M+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B3&EM<&EA<B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R
M9"(*;7-G<W1R("),:6UP:6%R(&-O;G1R87-E\6$B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R("),:6UP:6%R(&-O;G1R87-E\6$B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T
M<B`B4F5S=&%U<F%R(/IL=&EM82!C;VYS=6QT82(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE
M;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(E)E<W5L=&%D;W,B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM
M<V=S='(@(E)E9W)E<V%R(&$@;W!C:6]N97,B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B
M"FUS9W-T<B`B4F5E<V-R:6)I<B!C;VYT<F%S9?%A(&YU979A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:?-N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED
M(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")297-T875R87(@8V]N
M9FEG=7)A8VGS;B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$S
M-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D]P
M8VEO;F5S(&1E(&5D:6-I\VX@9&4@=&5X=&\@96YR:7%U96-I9&\B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T
M<B`B0W)I8F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")$97)E8VAA
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#<*;7-G:60@(E)I9VAT(&AE
M861E<B(*;7-G<W1R(")#86)E8V5R82!D97)E8VAA(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")6
M86QO<F5S(&1E(&QA(&1E<F5C:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P:65D861E<R!D92!?9FEL82XN+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED
M(")2;VQE(@IM<V=S='(@(D9U;F-I\VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM
M<V=S='(@(E)U;6%N[6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D=I<F%R
M(#$X,"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(D=I<F%R(&$@;&$@:7IQ
M=6EE<F1A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(D=I<F%R(&$@;&$@
M9&5R96-H82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!I961A9&5S(&1E(&9I;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R
M=&EE<R(*;7-G<W1R(")0<F]P:65D861E<R!D92!F:6QA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O
M=W,Z(@IM<V=S='(@(D9I;&%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(E)A>6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")!<&%R96-E<N%N
M(')A>6%S(&5N=')E('1O9&%S(&QA<R!F:6QA<R!Y(&-O;'5M;F%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'DB"FUS9W-T<B`B07!A<F5C97+A;B!R87EA<R!S\VQO(&5N=')E(&QA<R!C
M;VQU;6YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY(@IM<V=S='(@(D%P87)E8V5RX6X@<F%Y87,@<_-L;R!E
M;G1R92!L87,@9FEL87,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS
M9VED(")2=6XB"FUS9W-T<B`B16IE8W5T87(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N
M($9E9&5R871I;VXB"FUS9W-T<B`B1F5D97)A8VGS;B!2=7-A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4G=A;F1A(@IM<V=S='(@(E)U86YD82(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B1FER;6$@8W)I<'1O9W+A9FEC82!3+TU)344B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(DUE;G-A:F4@8VEF<F%D
M;R!E;B!3+TU)344B"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM
M<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(").;R!E<W3A(&1I<W!O;FEB;&4@;&$@875T96YT:69I8V%C:?-N
M(%-!4TPN(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-3`V
M"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(DUE;G,N(%--4R(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S
M='(@(DEN=.ER<'(N(%-13"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<X
M"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S
M='(@(E-E;G1E;F-I82!344P@<&%R82!C;VYS=6QT87,@9&4@=F%L;W)E<R(*
M"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B
M4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R
M("+)6$E43R(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L
M;"(*;7-G<W1R("));G3I<G!R+B!37U%,(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B
M4V%B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A;G1A($AE
M;&5N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@
M(E-A:6YT($MI='1S('D@3F5V:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM
M<V=S='(@(E-A;G1A($QU8^UA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;B(*;7-G<W1R(")386EN="!0:65R<F4@>2!-:7%U96QO;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM
M<V=S='(@(E-A;B!6:6-E;G1E('D@1W)A;F%D:6YA<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@
M9G)A;64@*%]S96QF*2(*;7-G<W1R(")-:7-M;R!F<F%M92`H7W-E;&8I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@
M36%R:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M
M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%N=&\@5&]MX7,@>2!0<NUN8VEP
M92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T
M96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E!R;W9E961O<B!D92!S873I;&ET
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")!<F%B:6$@4V%U
M9&ET82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I
M9"`B4V%V92(*;7-G<W1R(")'=6%R9&%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M(%PB)7-<(B(*;7-G<W1R(")'=6%R9&%R(%PB)7-<(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@)7,B"FUS9W-T<B`B1W5A<F1A<B`E<R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")'=6%R
M9&%R(&]P8VEO;F5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM
M<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"B)'=6%R9&%R(&QA(&-O;F9I9W5R86-I\VX@9V5N
M97)A9&$@8V]M;R!U;B!G=6GS;B!02%`@96X@96P@9&ER96-T;W)I;R`B"B)T
M96UP;W)A;"!D92!S=2!S97)V:61O<BXB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")392!H82!G=6%R9&%D;R!L82!C;VYF:6=U
M<F%C:?-N(&1E("5S+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D=U87)D87(@9W5I\VX@9&4@86-T
M=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N(&5N.B!<(B5S7"(N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G
M:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")";W)R87-C87,@86ES
M;&%D87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C
M:65N8V4B"FUS9W-T<B`B0VEE;F-I82(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B0G5S8V%R(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R(")-+B!B^G-Q=65D82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.34Y"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B4V5L96-C
M:6]N87(@87)C:&EV;W,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E-E
M;&5C8VEO;F4@=6YA(&9E8VAA(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R
M(")396QE8V-I;VYE(&5L(&=R=7!O(&$@8?%A9&ER(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R
M(@IM<V=S='(@(E-E;&5C8VEO;F4@=6X@;G5E=F\@<')O<&EE=&%R:6\B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C
M="!A('-E<G9E<B(*;7-G<W1R(")396QE8V-I;VYE('5N('-E<G9I9&]R(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C
M="!A('5S97(@=&\@861D(@IM<V=S='(@(E-E;&5C8VEO;F4@96P@=7-U87)I
M;R!A(&'Q861I<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B4V5L96-C:6]N
M87(@=&]D;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0W"FUS9VED(")3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-C:6]N
M92!T;V1O<R!L;W,@8V]M<&]N96YT97,@9&4@;&$@9F5C:&$N(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L
M96-T(&%N(&]B:F5C="(*;7-G<W1R(")396QE8V-I;VYA<B!U;B!O8FIE=&\B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS
M9VED(")396QE8W0@;F]N92(*;7-G<W1R(")3:6X@<V5L96-C:?-N(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82XB"FUS9W-T<B`B(@HB4V5L96-C:6]N92!L;W,@8V%RX6-T97)E
M<R!Q=64@;F5C97-I=&4@9&4@;&%S(&-A<VEL;&%S(&1E(&%B86IO+B!0=65D
M92`B"B)C;W!I87)L;W,@>2!P96=A<FQO<R!D96P@X7)E82!D92!T97AT;RXB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-C:6]N92!E;"!D
M96QI;6ET861O<B!D92!F96-H87,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S
M='(@(E-E;&5C8VEO;F4@96P@9F]R;6%T;R!D92!F96-H87,Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@
M(E-E;&5C8VEO;F4@;&$@:61E;G1I9&%D('%U92!Q=6EE<F$@8V%M8FEA<CHB
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T
M('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-C:6]N92!E;"!D
M96QI;6ET861O<B!D92!H;W)A<SHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T
M<B`B4V5L96-C:6]N92!E;"!F;W)M871O(&1E(&AO<F%S.B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")396QE8V-I;VYE(&1O<R!C86UP;W,@
M8V]I;F-I9&5N=&5S+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R
M(")396QE8V-I;VYE('-U(&-O;6)I;F%C:?-N(&1E(&-O;&]R97,N(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5C8VEO;F4@
M<W4@:61I;VUA('!R969E<FED;SHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G
M<W1R(")%;G9I87(@:6YF;W)M92!D92!P<F]B;&5M87,B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`B16YV:6%R(%--4R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS
M9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(S"FUS
M9VED(")396YS;W(Z("(*;7-G<W1R(")396YS;W(Z("(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`B4V5P=&EE;6)R92(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")3
M97)B:6$@>2!-;VYT96YE9W)O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B3OIM97)O
M(&1E('-E<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B1&%T;W,@9&5L('-E<G9I9&]R(&5R<O-N96]S(&\@;F\@9&ES
M<&]N:6)L97,N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")3
M97-S:6]N($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%C:?-N(&1E('-E<VGS
M;B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS
M9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DAA(&-A9'5C861O
M(&5L($E$(&1E('-E<VGS;BXB"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@
M(E-E<W-I;VYS(@IM<V=S='(@(E-E<VEO;F5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S,3@*;7-G:60@(E-E="(*;7-G<W1R(")%<W1A8FQE8V5R(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O
M<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF
M('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB17-T86)L96-E(&]P
M8VEO;F5S('%U92!L92!P97)M:71E;B!R96%J=7-T87(@<W4@8V]N=')A<V7Q
M82!S:2!L;&5G87)A(&$@(@HB;VQV:61A<FQA+B(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M(@IM<V=S='(@(D-O;F9I9W5R82!S97)V:61O<F5S(')E;6]T;W,@82!L;W,@
M<75E(&1E<V5E(&%C8V5D97(@9&5S9&4@96P@<&]R=&%L+B(*"B,Z(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM
M<V=S='(@(D1E9FEN92!L87,@;W!C:6]N97,@<')E9F5R:61A<R!D92!I9&EO
M;6$L('IO;F$@:&]R87)I82!Y(&9E8VAA<RXB"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)$969I
M;F4@;&$@87!L:6-A8VGS;B!D92!I;FEC:6\L(&QA(&-O;6)I;F%C:?-N(&1E
M(&-O;&]R97,L(&QA(&%C='5A;&EZ86-I\VX@(@HB9&4@<.%G:6YA('D@;W1R
M87,@;W!C:6]N97,@9&4@=FES=6%L:7IA8VGS;BXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")#;VYF:6=U
M<F%C:?-N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS
M9W-T<B`B2&%Y(&=U:6]N97,@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF
M:6=U<F%C:?-N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@
M<&%R86UE=&5R.B`B"FUS9W-T<B`B5F%R:6%S('5B:6-A8VEO;F5S(&1I<W!O
M;FEB;&5S(&-O;B!E;"!P87+A;65T<F\Z("(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL
M97,B"FUS9W-T<B`B4V5Y8VAE;&QE<R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B0V]M
M<')A<R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS
M9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(E)E<W5M96X@8V]R=&\B"@HC
M.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G
M<W1R("*_1&5F:6YI<B!C;&%V97,@9&4@86-C97-O('!A<F$@;&$@;6%Y;W+M
M82!D92!L;W,@=NUN8W5L;W,_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS
M,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B)FYB<W`[36]S=')A<B9N
M8G-P.R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*
M(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B375E<W1R82!L87,@9&EF97)E;F-I87,@96YT<F4@;&$@;G5E=F$@8V]N
M9FEG=7)A8VGS;B!Y(&QA(&%L;6%C96YA9&$B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`BOTUO<W1R87(@:&]R82!D92!L
M82#Z;'1I;6$@<V5S:?-N(&%L(&EN:6-I87(_(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$W-CD*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN
M86PB"FUS9W-T<B`B36]S=')A<B!O<&-I\VX@9&4@8V]N<V5R=F%R(&5L(&]R
M:6=I;F%L(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3D*;7-G:60@(E-H
M;W<@<&EC:V5R(@IM<V=S='(@(DUO<W1R87(@<V5L96-T;W(B"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BOTUO<W1R87(@;&$@8F%R
M<F$@9&4@;65N^B!D92!O<&5R86-I;VYE<R!D92!T86)L83\B"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`BOTUO
M<W1R87(@96P@;65N^B`E<R!A(&QA(&EZ<75I97)D83\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G
M:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E(&-E
M;&1A(&1E('1A8FQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")-=65S=')A(&5L(&1IX6QO9V\@
M9&4@<')O<&EE9&%D97,@9&4@=&%B;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")-=65S
M=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@9FEL82!D92!T86)L
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A
M9&5S(&1E(&EM86=E;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8W"FUS
M9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")-;W-T<F%R(&-A<F=A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@
M(E-H;W=E<G,B"FUS9W-T<B`B06=U86-E<F]S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B3&QU=FEA<R!M871U=&EN87,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!,
M871E(@IM<V=S='(@(DQL=79I87,@=F5S<&5R=&EN87,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R
M<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B06=U86-E<F]S(&5N(&QA('9E
M8VEN9&%D(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")2961U8VER(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE
M:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G
M<W1R(")0<FEM97)O(')E9'5Z8V$@;R!Q=6ET92!D92!E;FUE9&EO(&QO<R!B
M;&]Q=65S(&-E<F-A;F]S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S
M='(@(E-I97)R82!,96]N82(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(D%L=&$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM
M<V=S='(@(D9I<FUA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW
M,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I
M=&UO(&1E(&9I<FUA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I
M;F=A<'5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDP,"!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(Q.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,0HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$P.0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-`IM<V=I9"`B
M4VEZ92(*;7-G<W1R(")486UA\6\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC
M92(*;7-G<W1R(")/;6ET:7(@;6%N=&5N:6UI96YT;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9A:VEA(@IM<V=S='(@(D5S;&]V87%U:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI
M82(*;7-G<W1R(")%<VQO=F5N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R(*;7-G<W1R(").:65V
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V
M"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")!9W5A8V5R;R!D92!N:65V
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B06=U86-E<F\@9&4@;FEE
M=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.`IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(D%G=6%C97)O
M(&1E(&YI979E(&UA='5T:6YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM
M<V=S='(@(D%G=6%C97)O(&1E(&YI979E('9E<W!E<G1I;F\B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S
M='(@(D5S<&5S;W(@9&4@;&$@;FEE=F4Z("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*
M;7-G<W1R(")%<75I=F%L96YT92!D92!L82!N:65V92!E;B!A9W5A.B`B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B27-L87,@4V%L;VWS
M;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*
M;7-G<W1R(")#86YC:6]N97,@)B!0;V5M87,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDQ,@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T
M<B`B4V5L96-C:?-N(&1E;"!S96YT:61O(&1E(&QA(&-L87-I9FEC86-I\VXB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-#<*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V
M-B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@
M861D<F5S<R(*;7-G<W1R(")296UI=&5N=&4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!
M9G)I8V$B"FUS9W-T<B`B4W5DX69R:6-A(@H*(SH@8V]N9FEG+RYB86LO;FQS
M+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y
M+3,I(@IM<V=S='(@(D5U<F]P82!D96P@<W5R("A)4T\M.#@U.2TS*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',B"FUS9W-T<B`B1V5O<F=I82!D96P@4W5R(&4@27-L87,@4V%N9'=I
M8V@@9&5L(%-U<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B2&5M:7-F97)I;R!S=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<R(*;7-G<W1R(")%<W!A8VEA9&\@96YT<F4@8V5L9&%S
M(&%D>6%C96YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")%<W!A8VEA9&\@96YT<F4@96P@
M8V]N=&5N:61O('D@96P@8F]R9&4@9&4@=6YA(&-E;&1A(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(E-E<&%R
M861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")%<W!A8VEA9&\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(D5S
M<&%C:6%D;R!Y(&UA<F=E;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")%<W!A
M\6$B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G
M:60@(E-P86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`B17-C<FET=7)A(&1E(&-A<F%C=&5R97,@97-P96-I86QE<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*
M;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B1&EV:61I<B!C96QD82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")$:79I9&ER(&-O;'5M
M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B1&EV:61I<B!F
M:6QA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R
M=',B"FUS9W-T<B`B1&5P;W)T97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G
M<W1R(")3<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,0IM<V=I9"`B4W1A;F1A<F0B
M"FUS9W-T<B`B17-TX6YD87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y
M-0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!\6\@9&4@:6YI8VEO(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E
M(&]R(%!R;W9I;F-E(@IM<V=S='(@(D5S=&%D;R!O('!R;W9I;F-I82(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3
M=&%T=7,B"FUS9W-T<B`B17-T861O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(X,#$*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@
M9&4@86QM86-E;F%M:65N=&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B1&ER96-C
M:?-N(&1E(&QA(&-A;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R
M(")486-H861A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S<*;7-G:60@
M(E-T<FEN9R!L:7-T(@IM<V=S='(@(DQI<W1A(&1E(&-A9&5N87,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B16QI;6EN87(@9&]M:6YI;R!D92!L
M82!D:7)E8V-I\VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R
M(")%<W1I;&\@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")$;VTB"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E
M(&5N8V]N='+S(&5L('-U8F1I<F5C=&]R:6\@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T
M(@IM<V=S='(@(D%S=6YT;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S8@
M;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET
M(@IM<V=S='(@(D5N=FEA<B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(E-E
M(&AA(&5N=FEA9&\@=6YA('-O;&EC:71U9"!D92!A;'1A(&1E(%PB)7-<(B!E
M;B!E;"!S:7-T96UA+B!.;R!P;V1RX2`B"B)I;FEC:6%R('-E<VGS;B!H87-T
M82!Q=64@<V4@:&%Y82!A<')O8F%D;R!L82!S;VQI8VET=60N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B
M4W5B<V-R:7!T(@IM<V=S='(@(E-U8NUN9&EC92(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,#0@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(LEX:71O(@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R
M(")392!H82!A\6%D:61O(&-O<G)E8W1A;65N=&4@7"(E<UPB(&%L('-I<W1E
M;6$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB4V4@:&%N(&5L:6UI;F%D
M;R!C;W)R96-T86UE;G1E(&QO<R!D871O<R!D96P@=7-U87)I;R!<(B5S7"(@
M9&5L('-I<W1E;6$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B4V4@:&$@96QI;6EN
M861O(&-O<G)E8W1A;65N=&4@7"(E<UPB+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E
M9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")392!H82!E;&EM
M:6YA9&\@8V]R<F5C=&%M96YT92!<(B5S7"(@9&5L('-I<W1E;6$N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E
M<RXB"FUS9W-T<B`B(@HB4V4@:&$@<F5S=&%U<F%D;R!C;W)R96-T86UE;G1E
M(&QA(&-O;F9I9W5R86-I\VXN(%)E9G)E<W%U92!P87)A('9E<B!L;W,@(@HB
M8V%M8FEO<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4V4@:&$@9W5A<F1A
M9&\@8V]R<F5C=&%M96YT82!L82!C;W!I82!D92!L82!C;VYF:6=U<F%C:?-N
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")392!H82!G=6%R9&%D;R!C;W)R
M96-T86UE;G1E(&QA(&-O<&EA("5S(&1E(&QA(&-O;F9I9W5R86-I\VXN(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")392!H82!A8W1U
M86QI>F%D;R!C;W)R96-T86UE;G1E(%PB)7-<(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R
M(")392!H82!E<V-R:71O(&-O<G)E8W1A;65N=&4@)R5S)R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-U9&%N(@IM<V=S='(@(E-U9.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*
M;7-G<W1R(")297-U;65N(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U
M"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")!;6%N96-E<B(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")!
M=&%R9&5C97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,`IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4V]L96%D;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B
M"FUS9W-T<B`B06UA;F5C97(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N
M<V5T(@IM<V=S='(@(D%M86YE8V5R+T%T87)D96-E<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G
M<W1R(")!;6%N96-E<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(D%T87)D96-E<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E
M=#H@(@IM<V=S='(@(D%T87)D96-E<CH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B
M"FUS9W-T<B`B4W5P97+M;F1I8V4B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R
M>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B4V]P;W)T
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86TB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*
M;7-G<W1R(")!<&5L;&ED;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@
M36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@>2!*86X@36%Y96XB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEL86YD:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M=V5D96XB"FUS9W-T<B`B4W5E8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM
M<V=S='(@(E-U:7IA(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B4F5G:7-T<F\@
M9&4@<VEN8W)O;FEZ86-I\VX@96QI;6EN861O(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B4WEN
M8TU,(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@
M(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B17)R;W(@
M9&4@<VEN=&%X:7,@96X@;&]S('3I<FUI;F]S(&1E(&+Z<W%U961A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A
M(,%R86)E(&1E(%-I<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B0VAU8F%S
M8V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B0F]R<F%S8V]S
M;R!Y('9E;G1O<V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B0F]R<F%S8V%S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*
M;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(D)O<G)A<V-A<R!M871U
M=&EN87,B"@HC.B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B
M5%-6(&9I;&4B"FUS9W-T<B`B07)C:&EV;R!44U8B"@HC.B!L:6(O2&]R9&4O
M54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5&%B;&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!I
M961A9&5S(&1E('1A8FQA(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R(")486)L82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE
M9&%D97,@9&4@=&%B;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM
M<V=S='(@(E1A:7?A;B(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T
M<B`B5&%I=^%N+"!0<F]V:6YC:6$@9&4@0VAI;F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II
M:VES=&%N(@IM<V=S='(@(E1A>6EK:7-TX6XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GIA;FEA+"!297#Z
M8FQI8V$@56YI9&$@9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(D1E<W1I
M;F\Z(@H*(SH@8V]N9FEG+RYB86LO:&]O:W,N<&AP+F1I<W0Z,3`T.2!C;VYF
M:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM
M<V=S='(@(E1A<F5A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D
M92!T96SI9F]N;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDW"FUS9VED
M(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")496UP97)A='5R82!D
M=7)A;G1E(&QA(/IL=&EM82!H;W)A.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U
M<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED
M(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T=7)A.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,B"FUS9W-T<B`B5&5M<&5R871U<F$\8G(@+SXH)7--X7@E<R\E<TWM;B5S
M*2`F9&5G.R5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV.34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@;&$@<&QA;G1I;&QA(%PB)7-<(BXB
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I\VX@9&4@<&QA
M;G1I;&QA<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S,Q"FUS9VED(")497AT(@IM<V=S='(@(E1E>'1O(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT
M($]N;'DB"FUS9W-T<B`B4_-L;R!T97AT;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@
M86QI9VXB"FUS9W-T<B`B06QI;F5A8VGS;B!D92!T97AT;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E
M>'1T;W`B"FUS9W-T<B`B0F]R9&4@<W5P97)I;W(@9&5L('1E>'1O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I
M9"`B5&@B"FUS9W-T<B`B2G5E(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD
M:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&%I;&%N
M9.ES("A425,M-C(P*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A
M:6QA;F1I82(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYO(&5S
M=.$@9&ES<&]N:6)L92!L82!E>'1E;G-I\VX@1E10+B(*"B,Z(&QI8B](;W)D
M92](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R(")%;"!S:7-T96UA(&AI<W3S<FEC;R!E<W3A
M(&1E<VAA8FEL:71A9&\N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T
M:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")%
M;"!M;W1O<B!D92!I;G1E9W)A8VGS;B!(;W)D92]+;VQA8B!N;R!S;W!O<G1A
M(%PB)7-<(B(*"B,Z(&QI8B].970O24U34"]";V]K+G!H<#HQ,CDX"FUS9VED
M(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G
M<W1R(").;R!S92!P=65D92!I;FEC:6%R(&5L(')E9VES=')O(&1E($E-4U`N
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M(@IM<V=S='(@(DYO('-E(&AA(&-A<F=A9&\@8V]R<F5C=&%M96YT92!L82!C
M;&%S92!-86EN=&5N86YC93HZ(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N(@IM<V=S='(@(E-E(&AA(&-E<G)A9&\@;&$@=F5N
M=&%N82!D92!O<&-I;VYE<RX@4V%L:65N9&\N(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,C,@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-3(*
M(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB4VD@
M9&5S96$@=71I;&EZ87(@<&5R;6ES;W,L(&5L(&%D;6EN:7-T<F%D;W(@=&EE
M;F4@<75E(&-O;F9I9W5R87(@=6X@<V]P;W)T92`B"B)D92!P97)M:7-O<R!P
M97)M86YE;G1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY
M(@IM<V=S='(@(E/S;&\@96P@8F]R9&4@:6YF97)I;W(B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*(D5L($E$(&1E;"!C;VYT86-T;R!N;R!S92!E<W!E8VEF:6/S+"!S92!D
M96KS(&5N(&)L86YC;R!O(&YO('-E(&5N8V]N='+S(&5N("(*(FQA(&)A<V4@
M9&4@9&%T;W,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B4V4@:&$@8?%A9&ED
M;R!C;W)R96-T86UE;G1E(&5L(&-O;G1A8W1O(&$@<W5S(&1I<F5C8VEO;F5S
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*
M(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D
M('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(E!A
M<F$@8V]M<')O8F%R(&5L(&UE;G-A:F4@9FER;6%D;R!H86-E(&9A;'1A(&5L
M(&)L;W%U92!D92!F:7)M82!S97!A<F%D;RXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@
M(B(*(D5L($E$(&1E(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;B!N;R!S92!E
M<W!E8VEF:6/S+"!S92!D96KS(&5N(&)L86YC;R!O(&YO("(*(G-E(&5N8V]N
M='+S(&5N(&QA(&)A<V4@9&4@9&%T;W,N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(").;R!S92!E<W!E8VEF
M:6/S(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3&%S
M(&-A<F%C=&5R[7-T:6-A<R!D92!C:69R861O(&YE8V5S:71A;B!U;F$@8V]N
M97AI\VX@=V5B('-E9W5R82XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-R!L:6(O
M2&]R9&4N<&AP.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D5L(&%R
M8VAI=F\@)7,@=&5N9'+M82!Q=64@8V]N=&5N97(@=6YA(&]P8VGS;B`E<RXB
M"@HC.B!L:6(O2&]R9&4N<&AP.C$W,"!L:6(O2&]R9&4N<&AP.C4P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")%;"!A<F-H:79O("5S('1E;F1R
M[6$@<75E(&-O;G1E;F5R(&%L9W5N87,@;W!C:6]N97,@)7,N(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HR,C8*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C
M;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(DYO('-E('!U961E(&-O<&EA
M<B!E;"!A<F-H:79O('-O8G)E('/M(&UI<VUO+B(*"B,Z(&QI8B](;W)D92]$
M871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R(")%;"!A<F-H:79O(&YO(&-O;G1I96YE(&1A=&]S+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")!(&-O;G1I;G5A8VGS;B!T:65N
M92!L87,@8V%B96-E<F%S(&1E(&5S=&4@;65N<V%J92!M97-S86=E+W)F8S@R
M,BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T
M;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@
M(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I
M<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M
M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O
M=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N
M97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@
M3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E
M9&ET;W(N(@IM<V=S='(@(B(*(E-E('-A8F4@<75E(&5L(&UO9&\@9&4@<&%N
M=&%L;&$@8V]M<&QE=&$@9&$@<')O8FQE;6%S(&-O;B!);G1E<FYE="!%>'!L
M;W)E<B`B"B)D96)I9&\@82!F86QL;W,@9&5L(&YA=F5G861O<B!Q=64@;F\@
M:&5M;W,@<&]D:61O('-O<VQA>6%R+B!0=65D92!S=69R:7(@(@HB=FES=6%L
M:7IA8VGS;B!D92!B87-U<F$L('#I<F1I9&$@9&4@9G5N8VEO;F5S(&1E;"!E
M9&ET;W(@>2]O(&-U96QG=65S("(*(F%L96%T;W)I;W,@9&5L(&YA=F5G861O
M<BX@4VD@<W4@<VES=&5M82!O<&5R871I=F\@97,@5VEN9&]W<R`Y>"P@97,@
M;75Y("(*(G!R;V)A8FQE('%U92!S=69R82!U;B!F86QL;R!D92!P<F]T96-C
M:?-N(&=E;F5R86P@>2!T96YG82!Q=64@<F5I;FEC:6%R(&5L("(*(F5Q=6EP
M;RY<7&Y<7&Y982!E<W3A(&%V:7-A9&\N(%!U;'-E($%C97!T87(@<VD@8?IN
M(&1E<V5A('!R;V)A<B!E;"!E9&ET;W(@96X@(@HB;6]D;R!D92!P86YT86QL
M82!C;VUP;&5T82XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&QA(&ED96YT:61A
M9"!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B4_-L;R!E;"!B;W)D92!I>G%U:65R9&\B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B)(87D@<75E(&EN9&EC87)L
M92!A(&QA(&-L87-E($-R>7!T7W!G<#HZ(&QA('5B:6-A8VGS;B!D92!L;W,@
M8FEN87)I;W,@1VYU4$<N(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HR
M,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O
M;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L
M87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A
M9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)3
M92!H82!M;W-T<F%D;R!E;"!M96YS86IE(&5N=FEA9&\@96P@)7,@82`E<R!C
M;VX@96P@87-U;G1O(%PB)7-<(BY<;B(*(LES=&\@;F\@9V%R86YT:7IA('%U
M92!E;"!M96YS86IE(&AA>6$@<VED;R!L96ED;R!O(&-O;7!R96YD:61O+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T
M<B`B3F]M8G)E('5T:6QI>F%D;R!A;"!V:6YC=6QA<B!A(&QA('#A9VEN82!D
M92!C;VUP;W-I8VGS;B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED
M(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S
M='(@(D5L(&[Z;65R;R!D92!C86UP;W,@=&EE;F4@<75E('-E<B!U;B!N^FUE
M<F\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED
M(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")(86-E(&9A;'1A(&5L
M(&WS9'5L;R!O<&5N<W-L('!A<F$@;&$@8VQA<V4@2&]R9&5?0W)Y<'1?<VUI
M;64Z.BXB"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA
M>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4@
M9W5A<F1A<B!L82!P<F5F97)E;F-I82!<(B5S7"(@<&]R<75E('-U<R!D871O
M<R!S;V)R97!A<V%N(&5L("(*(G1A;6'Q;R!MX7AI;6\@<&5R;6ET:61O(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H
M<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP
M.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*(DYO('-E(&5N8V]N='+S(&5N(&5L('-I<W1E
M;6$@96P@<')O9W)A;6$@<&%R82!V97(@97-T92!T:7!O(&1E(&1A=&]S("@E
M<RDN(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS
M9W-T<B`B16P@8V%RX6-T97(@9&4@8VET82!D96)E('-E<B!S97(@<_-L;R!U
M;F\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'DB"FUS9W-T<B`B4_-L;R!L;W,@;&%D;W,@:7IQ=6EE<F1O('D@9&5R96-H
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R(")3\VQO(&5L(&QA9&\@9&5R96-H;R(*"B,Z(&QI8B]&:6QE+T-35BYP
M:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(D5L('-E<&%R861O<B!D96)E('-E<B!S
M\VQO('5N;RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@96P@<V5R=FED
M;W(@7"(E<UPB+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N('-A=F5D+B(*;7-G<W1R(")392!H82!G=6%R9&%D;R!E;"!S97)V:61O
M<B!<(B5S7"(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"XB"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&QA('-O;&EC:71U
M9"!D92!A;'1A(&1E("5S+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C
M:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DQA(&9I
M;&$@97-P96-I9FEC861A("@E9"D@;F\@97AI<W1E+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R
M>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B16P@87)C
M:&EV;R!T96UP;W)A;"!<(B5S7"(@;F\@97AI<W1E+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S`V"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@
M(D5L('1E>'1O('%U92!H82!I;G1R;V1U8VED;R!N;R!C;VEN8VED92!C;VX@
M96P@9&4@;&$@<&%N=&%L;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@
M8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B4_-L;R!L;W,@;&%D;W,@<W5P
M97)I;W(@92!I;F9E<FEO<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O
M;FQY(@IM<V=S='(@(E/S;&\@96P@;&%D;R!S=7!E<FEO<B(*"B,Z(&QI8B](
M;W)D92]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")392!P
M97)D:65R;VX@;&]S(&1A=&]S(&-A<F=A9&]S(&1E<V1E(&5L('!A<V\@86YT
M97)I;W(N(@H*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-C(@;&EB+TAO
M<F1E+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B3F\@<V4@<'5D;R!G=6%R
M9&%R(&5L(&%R8VAI=F\@8V%R9V%D;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q
M,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(DYO(&5S=.$@9&ES<&]N:6)L92!E;"!B;&]Q=64@9&4@
M=V5A=&AE<BYC;VTN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@96P@9&ER96-T;W)I
M;R!D92!496UA<R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB
M"FUS9W-T<B`B3F\@<V4@9&ES<&]N92!D92!O<&-I;VYE<RXB"@HC.B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B3F\@:&%Y('!A<G1E<R!Q=64@<V4@<'5E9&%N(&UO<W1R87(@96X@;.UN
M96$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B
M"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(D5N
M(&5S=&4@8V%M<&\@:&%Y(&1E;6%S:6%D;W,@8V%R86-T97)E<RX@2&$@:6YT
M<F]D=6-I9&\@)7,@8V%R86-T97)E<R!Y("(*(G1I96YE('%U92!I;G1R;V1U
M8VER(&UE;F]S(&1E("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E
M<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@
M(E-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A9&ER(&$@7"(E<UPB(&%L
M('-I<W1E;6$Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B
M(@HB4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!B;W)R87(@;&]S(&1A=&]S
M(&1E;"!U<W5A<FEO(%PB)7-<(B!D96P@<VES=&5M83H@(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(E-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@96QI;6EN87(@82!<
M(B5S7"(@9&5L('-I<W1E;6$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!P<F]B;&5M
M82!A;"!A8W1U86QI>F%R(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O0G)O
M=W-E<BYP:'`Z.3(W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"XB"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!P<F]B;&5M82!C;VX@;&$@
M8V%R9V$@9&5L(&%R8VAI=F\Z($YO('-E(&-A<F?S("5S+B(*"B,Z(&QI8B](
M;W)D92]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB4V4@<')O9'5J;R!U;B!P<F]B
M;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N($5L("5S(&5R82!MX7,@
M9W)A;F1E('%U92!E;"`B"B)T86UA\6\@;>%X:6UO('!E<FUI=&ED;R`H)60@
M8GET97,I+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"XB"FUS9W-T<B`B(@HB4V4@<')O9'5J;R!U;B!P<F]B;&5M82!C;VX@
M;&$@8V%R9V$@9&5L(&%R8VAI=F\N(%/S;&\@<V4@8V%R9_,@<&%R8VEA;&UE
M;G1E("(*(F5L("5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")392!P<F]D=6IO('5N(&5R
M<F]R(&%L(&UO<W1R87(@97-T82!P87)T92!D96P@;65N<V%J92(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")392!P
M<F]D=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QO<R!D871O<R!D96P@8V]N
M=&%C=&\N(@H*(SH@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@
M;&]S(&1A=&]S(&E#86QE;F1A<BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R
M97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB4V4@<')O9'5J;R!U;B!E<G)O
M<B!E;B!E;"!F;W)M=6QA<FEO(&1E(&-O;F9I9W5R86-I\VXN(%!U961E('%U
M92!H87EA("(*(F]L=FED861O(')E;&QE;F%R('5N(&-A;7!O(&YE8V5S87)I
M;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E
M8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB4V4@<')O9'5J;R!U;B!E<G)O<B!A
M;"!E:F5C=71A<B!L82!F=6YC:?-N(&5S<&5C:69I8V%D82!D92!L82!L:6)R
M971A(&1E("(*(F1I<F5C8VEO;F5S+B!6=65L=F$@82!P<F]B87(@;>%S(&%D
M96QA;G1E+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"B)392!P<F]D=6IO('5N(&5R<F]R(&%L(&%C='5A;&EZ87(@;&]S
M(&1E=&%L;&5S(&1E;"!C;VYT86-T;RX@5G5E;'9A(&$@<')O8F%R("(*(FWA
M<R!A9&5L86YT92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0U(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(E-E
M('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L:7IA<B!L82!L:7-T82!D92!D
M:7-T<FEB=6-I\VXN(%9U96QV82!A('!R;V)A<B`B"B)MX7,@861E;&%N=&4N
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I
M9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RXB"FUS9W-T<B`B17-T92!S97)V:61O<B!)34%0(&YO('-O<&]R
M=&$@;&%S(&-A<G!E=&%S(&-O;7!A<G1I9&%S+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("+)<W1E
M(&YO('!A<F5C92!S97(@=6X@87)C:&EV;R!R87(@=N%L:61O+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R
M("+)<W1E(&YO('!A<F5C92!S97(@=6X@87)C:&EV;R!Z:7`@=N%L:61O+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3,Q"FUS9VED(")4:&ES(&1O97,@
M;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B
MR7-T92!N;R!P87)E8V4@<V5R('5N(&[Z;65R;R!D92!T87)J971A(';A;&ED
M;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E
M;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@HB17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!A
M('1R87;I<R!D92!L82!P87-A<F5L82!#;&EC:V%T96QL("(*(BAH='1P.B\O
M8VQI8VMA=&5L;"YC;VTI+"!M961I86YT92!L82!!4$D@2%144"(*"B,Z(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"B)%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@
M96YV:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA(%=)3B`H
M:'1T<#HO+R(*(G=I;G!L8RYC;VTI+"!M961I86YT92!L82!!4$D@2%144"(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%<W1E
M(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S(&$@=')A=NES
M(&1E(&QA('!A<V%R96QA('-M<S)E;6%I;"`B"B(H:'1T<#HO+W-M<S)E;6%I
M;"YC;VTI+"!M961I86YT92!L82!!4$D@2%144"(*"B,Z(&QI8B].970O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U
M9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D
M869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W
M:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM
M<V=S='(@(B(*(D5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I87(@;65N
M<V%J97,@=FEA(%--5%`@82!T<F%VZ7,@9&4@;&$@<&%S87)E;&$@9&4@(@HB
M5F]D869O;F4@9&4@271A;&EA+"!S\VQO(&$@;OIM97)O<R!6;V1A9F]N92X@
M2&%C92!F86QT82!U;F$@8W5E;G1A(&1E(&-O<G)E;R`B"B)D92!6;V1A9F]N
M92!D92!)=&%L:6$@*&AT='`Z+R]W=W<N,3DP+FET*2XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.3@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Q(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#DP"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$Y
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@V(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,C8P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`Y(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#`R(&QI8B](;W)D92]&;W)M+G!H<#HQ-38Q"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#0S(&QI8B](;W)D92]&;W)M+G!H<#HQ.38R(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#`Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,S
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#@R(&QI8B](;W)D92]&;W)M+G!H<#HR
M,34S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C(U(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#$R(&QI8B](;W)D92]&;W)M+G!H<#HR-#4T"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-C0Q(&QI8B](;W)D92]&;W)M+G!H<#HR.#$T(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3(S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`Q
M(&QI8B](;W)D92]&;W)M+G!H<#HS.#`Y(&QI8B](;W)D92]&;W)M+G!H<#HS
M.#$W"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")(
M86-E(&9A;'1A(&5S=&4@8V%M<&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$P-CD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E
M9V5R<RXB"FUS9W-T<B`B17-T92!C86UP;R!S\VQO('!U961E(&-O;G1E;F5R
M(&5N=&5R;W,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,C`*;7-G:60@
M(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN(@IM<V=S='(@(D5S=&4@8V%M<&\@<_-L;R!P=65D92!C;VYT96YE
M<B!N^FUE<F]S('D@;&]S(&1O<R!P=6YT;W,N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D5S=&4@8V%M<&\@<_-L;R!P=65D
M92!C;VYT96YE<B!V86QO<F5S(&]C=&%L97,N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA
M(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@
M(B(*(D5S=&4@8V%M<&\@=&EE;F4@<75E('-E<B!U;F$@;&ES=&$@9&4@96YT
M97)O<R!S97!A<F%D;W,@<&]R(&-O;6%S(&\@97-P86-I;W,N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")%<W1E(&-A;7!O('1I96YE('%U
M92!S97(@=6X@;OIM97)O(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@R,@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C
M;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@
M(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B)%<W1E(&-A;7!O('1I96YE('%U
M92!C;VYT96YE<B!U;B!C\V1I9F\@9&4@8V]L;W(@96X@9F]R;6%T;R!21T(@
M2&5X861E8VEM86PL("(*(G!O<B!E:F5M<&QO("<C,3(S-&%F)RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(EEA('-E(&AA('!R;V-E
M<V%D;R!E<W1E(&9O<FUU;&%R:6\N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O
M=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS
M9W-T<B`B17-T;R!E<R`E<RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0V
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HBR7-T
M;R!E<R!U;B!O8FIE=&\@9&4@2V]L86(@1W)O=7!W87)E+B!087)A('9E<FQO
M(&YE8V5S:71A('5N(&-L:65N=&4@9&4@(@HB8V]R<F5O("!Q=64@96YT:65N
M9&$@96P@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=F5R('5N82!L
M:7-T82!D92`B"B)D:6-H;W,@8VQI96YT97,@=FES:71E("5S(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@HB17-T
M92!M96YS86IE('-E(&5S8W)I8FGS(&-O;B!U;B!J=65G;R!D92!C87)A8W1E
M<F5S("@E<RD@9&ES=&EN=&\@86P@<W5Y;RXB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L
M96%S="!O;F4N(@IM<V=S='(@(D5S=&4@;OIM97)O(&1E8F4@<V5R('!O<B!L
M;R!M96YO<R!U;B!U;F\N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N
M<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B17-T92!S97)V:61O<B!N;R!P
M=65D92!D97-C;VUP<FEM:7(@87)C:&EV;W,@>FEP('D@9WII<"XB"@HC.B!L
M:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")%<W1E('-I<W1E
M;6$@86-T=6%L;65N=&4@97-TX2!D97-A8W1I=F%D;RXB"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+B(*;7-G<W1R(")%<W1E('9A;&]R('1I96YE('%U92!S97(@
M=6X@;OIM97)O+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B17-T82!V96YT86YA('/S;&\@
M<'5E9&4@86)R:7)S92!D97-D92!U;F$@=F5N=&%N82!D92!O<&-I;VYE<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS
M9VED(")4:'5N9&5R(@IM<V=S='(@(E1R=65N;R(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R
M("));F-I9&5N8VEA<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(Y('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G
M<W1R(")(;W)A(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z
M,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(D,N('1I96UP;W,B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T
M(@IM<V=S='(@(D9O<FUA=&\@:&]R87)I;R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-3,U"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")396QE
M8V-I\VX@9&4@:&]R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@
M(E1I;6]R+4QE<W1E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE
M(@IM<V=S='(@(E3M='5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS
M9W-T<B`B5.UT=6QO("AC;VYS96IO*3HB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B4&%R82(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G
M:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@
M8VQI8VMI;F<N(@IM<V=S='(@(B(*(E!A<F$@<V5L96-C:6]N87(@=F%R:6]S
M(&-A;7!O<RP@;6%N=&5N9V$@<'5L<V%D82!L82!T96-L82!#;VYT<F]L("A0
M0RD@;R`B"B)#;VUA;F1O("A-86,I(&%L(&AA8V5R(&-L:6-K+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM
M<V=S='(@(DAO>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R
M(")#;VYM=71A<B!O<FEG96X@2%1-3"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T
M<B`B5&]G;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O
M;6]R<F]W(@IM<V=S='(@(DUA\6%N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S
M='(@(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B4W5P97)I;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS
M"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(D9R86UE('-U<&5R
M:6]R("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(E1R861U8V-I;VYE<R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED860@>2!4
M;V)A9V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U
M92!O<B!F86QS92(*;7-G<W1R(")697)D861E<F\@;R!F86QS;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@
M(E1U(@IM<V=S='(@(DUA<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M5/IN97HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R<77M82(*"B,Z
M(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@
M*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<F-O("A)4T\M.#@U.2TY*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-TX6XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B27-L
M87,@5'5R:W,@>2!#86EC;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B
M5'5V86QU(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E
M('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B17-C<FEB82!S=2!E;&5C8VGS;CH@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(LUN9&EC92!5+E8N.B`B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R
M86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@
M>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")5
M4DP@9&4@<W4@:6YF;W)M92!D92!E<W1A9&\@9&4@96YV[6\@9&5L(&=U:?-N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A
M(@IM<V=S='(@(E5G86YD82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B
M56-R86YI82(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B
M;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@
M9&4@86-C961E<B!A;"!D:7)E8W1O<FEO(%9&4RXB"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B
M"B));F-A<&%Z(&1E(&'Q861I<B!I;F9O<FUA8VGS;B!D92!U<W5A<FEO(&%D
M:6-I;VYA;"!A;"!R96%L:7IA<B!E;"!A;'1A+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEN
M8V%P87H@9&4@8V%M8FEA<B!L;W,@<')I=FEL96=I;W,@9&5L(&%R8VAI=F\@
M5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,Y,B!L:6(O5D93
M+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B26YC87!A>B!D92!C86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C
M:&EV;R!61E,@)7,O)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<X-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R("));F-A<&%Z(&1E(&-A;6)I87(@82`E<RXB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&-O
M;7!R;V)A<B!E;"!T86UA\6\@9&4@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z-CDU(&QI8B]61E,O<W%L+G!H<#HQ,#(X(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C@U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D
M92!C;VUP<F]B87(@96P@=&%M8?%O(&1E(%PB)7,O)7-<(BXB"@HC.B!L:6(O
M2&]R9&4O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B26YC87!A>B!D92!C;VYE8W1A
M<G-E(&%L('-E<G9I9&]R(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#<P
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B
M26YC87!A>B!D92!C;VYE8W1A<B!C;VX@4U-,+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,C,R(&QI8B]61E,O9FEL92YP:'`Z,C,W(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C(P-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB"FUS9W-T<B`B26YC87!A>B!D92!C;W!I87(@96P@87)C:&EV;R!6
M1E,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("));F-A<&%Z(&1E(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,V,2!L:6(O5D93+VUU<W%L
M+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@
M9&4@8W)E87(@96P@9&ER96-T;W)I;R!61E,N(@H*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R("));F-A<&%Z(&1E(&-R96%R(&5L(&%R8VAI=F\@5D93+B(*"B,Z
M(&QI8B]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26YC
M87!A>B!D92!C<F5A<B!L82!C87)P971A(%9&4R!<(B5S7"(B"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T
M>2!61E,@9FEL92XB"FUS9W-T<B`B26YC87!A>B!D92!C<F5A<B!U;B!A<F-H
M:79O(%9&4R!V86/M;RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H
M<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DEN8V%P87H@9&4@
M9&5S8V]M<')I;6ER(&QO<R!D871O<RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M,C(X(&QI8B]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R(%PB)7-<(BP@
M96P@9&ER96-T;W)I;R!N;R!E<W3A('9A8^UO+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S
M='(@(DEN8V%P87H@9&4@96QI;6EN87(@7"(E<UPB.B`E<RXB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C,S."!L:6(O5D93+W-Q;"YP:'`Z,SDU(&QI8B]61E,O
M;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B26YC87!A>B!D92!E;&EM
M:6YA<B`E<RP@96P@9&ER96-T;W)I;R!N;R!E<W3A('9A8^UO(@H*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,V
M,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C
M=&]R:6\@5D93(&1E(&9O<FUA(')E8W5R<VEV82XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C,T-"!L:6(O5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP.C,T,R!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B26YC87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E
M8W1O<FEO(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-#(P(&QI8B]61E,O
M<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B26YC87!A>B!D92!E
M;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!E;&EM
M:6YA<B!E;"!A<F-H:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HS,3`@;&EB+U9&4R]S<6PN<&AP.C(Y,2!L:6(O5D93+VUU<W%L+G!H
M<#HQ-C<*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P(&QI8B]61E,O;75S<6PN
M<&AP.C$X-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&%R8VAI=F\@
M5D93+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B26YC87!A>B!D92!E;&EM:6YA<B!L82!C87)P971A(%9&4R!<(B5S
M7"(N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM
M<V=S='(@(DEN8V%P87H@9&4@96QI;6EN87(@96P@5D93(&1E(&9O<FUA(')E
M8W5R<VEV83H@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B26YC87!A>B!D92!D971E<FUI;F%R(&5L(&1I<F5C=&]R:6\@86-T=6%L
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5
M;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@
M(DEN8V%P87H@9&4@97AT<F%E<B!L;W,@9&5T86QL97,@9&5L(&-E<G1I9FEC
M861O+B(*"B,Z(&QI8B].970O24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!
M=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEN8V%P87H@9&4@
M8V%R9V%R(&QA(&1E9FEN:6-I\VX@9&4@)7,N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR,#,@;&EB+U9&4R]F:6QE+G!H<#HR,#@@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P87H@9&4@
M=')A<VQA9&%R(&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HY,R!L:6(O5D93+W-M8BYP:'`Z,3`V(&QI8B]61E,O<VUB+G!H<#HV-3(*
M(SH@;&EB+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A
M>B!D92!A8G)I<B!E;"!A<F-H:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HR.#0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(DEN8V%P87H@9&4@86)R:7(@
M96P@87)C:&EV;R!61E,@<&%R82!E<V-R:6)I<BXB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C@S(&QI8B]61E,O9FEL92YP:'`Z,3,W(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS
M9W-T<B`B26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("));F-A<&%Z
M(&1E(&%B<FER(&5L(&%R8VAI=F\@8V]M<')I;6ED;RXB"@HC.B!L:6(O5D93
M+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE
M<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DEN8V%P87H@9&4@;&5E<B!U;B!A
M<F-H:79O(%9&4R`H:&$@9F%L;&%D;R!F:6QE<VEZ92@I*2XB"@HC.B!L:6(O
M5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DEN8V%P87H@9&4@;&5E
M<B!U;B!A<F-H:79O(%9&4R`H:&$@9F%L;&%D;R!G971&:6QE4VEZ92@I*2XB
M"@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G
M:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("));F-A<&%Z(&1E
M(&QE97(@=6X@87)C:&EV;SH@(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV-S8*
M;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B26YC87!A>B!D92!L965R(&5L(&1I<F5C=&]R:6\@=F9S<F]O
M="XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q,#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DEN8V%P87H@9&4@
M<F5N;VUB<F%R("5S(&-O;6\@)7,Z(&QA(&-A<G!E=&$@9&5S=&EN;R!Y82!E
M>&ES=&4B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26YC87!A
M>B!D92!R96YO;6)R87(@96P@9&ER96-T;W)I;R!61E,N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("));F-A<&%Z(&1E
M(')E;F]M8G)A<B!E;"!D:7)E8W1O<FEO(%9&4SH@)7,N(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(W,2!L:6(O5D93+V9T<"YP:'`Z,S0X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("));F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4R!<
M(B5S7"(B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Q-R!L:6(O5D93+VUU<W%L
M+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B26YC87!A>B!D92!R96YO;6)R
M87(@96P@87)C:&EV;R!61E,@)7,O)7,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP
M.C,R-B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z
M-#4R"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,R!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M(@IM<V=S='(@(DEN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&%R8VAI=F\@5D93
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B26YC87!A>B!D
M92!E:F5C=71A<B`G;6MI<V]F<R<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DYO('-E('!U961E('1R861U
M8VER(&5S=&4@9&]C=6UE;G1O(&1E(%=O<F0B"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M26YC87!A>B!D92!E<V-R:6)I<B!E;"!A<F-H:79O(%9&4R!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DEN8V%P87H@
M9&4@97-C<FEB:7(@=6X@87)C:&EV;R!61E,@*&AA(&9A;&QA9&\@8V]P>2@I
M*2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X."!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B26YC87!A>B!D
M92!E<V-R:6)I<B!L;W,@9&%T;W,@9&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI
M8B]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("));F-A<&%Z(&1E
M(&5S8W)I8FER('5N(&%R8VAI=F\@5D93+"!S92!S=7!E<F%RX2!L82!Q=6]T
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B4W5B<F%Y861A(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S
M(@IM<V=S='(@(D1E<VAA8V5R(&-A;6)I;W,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R(")$97-H86-E(&QA(/IL=&EM82!A8V-I
M\VXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM
M<V=S='(@(E)E<W!U97-T82!I;F5S<&5R861A(&1E;"!S97)V:61O<B!E;B!L
M82!C;VYE>&GS;CH@(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(Q-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(E)E<W!U97-T82!I
M;F5S<&5R861A(&1E;"!S97)V:61O<B!A.B`B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G
M<W1R(")3:6X@8V%T96=O<NUA(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD
M:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O
M9&4@*%541BTX*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G
M<W1R(")%;6ER871O<R#!<F%B97,@56YI9&]S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@
M2VEN9V1O;2(*;7-G<W1R("));F=L871E<G)A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D
M(%-T871E<R(*;7-G<W1R(")%<W1A9&]S(%5N:61O<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")%
M<W1A9&]S(%5N:61O<R!M96YO<R!L87,@:7-L87,@<&5R:6;I<FEC87,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW.`IM<V=I9"`B56YI=',B"FUS9W-T<B`B56YI9&%D97,B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,CD@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#,P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(D1E<V-O;F]C:61O(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B07!I
M;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E(&UE;G-A:F4@9&4@;&$@05!)*2XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I
M9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G
M<W1R(")#;&EM<V=I9"!D97-C;VYO8VED;R`H240@9&4@;65N<V%J92!D96P@
M8VQI96YT92DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
M4V4@:&$@9&5F:6YI9&\@=6YA('5B:6-A8VGS;B!D97-C;VYO8VED82XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B57-U87)I
M;R!O(&-O;G1R87-E\6$@9&5S8V]N;V-I9&]S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B16QI;6EN87(@
M=NUN8W5L;R!D96P@96QE;65N=&\@86-T=6%L(@H*(SH@;&EB+TAO<F1E+TED
M96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B4VEN(&YO
M;6)R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T
M;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS
M9W-T<B`B(@HB3&]S(&=U:6]N97,@<VEN('!R:79I;&5G:6]S(&YO('!U961E
M;B!A8V-E9&5R(&1E(&9O<FUA('!R;V=R86WA=&EC82!A($-O<G1A<B\B"B)#
M;W!I87(O4&5G87(@<&]R(')A>F]N97,@9&4@<V5G=7)I9&%D+B!0=6QS92!!
M8V5P=&%R('!A<F$@=F5R(&5N(&UO>FEL;&$N;W)G("(*(G5N82!N;W1A('3I
M8VYI8V$@<75E(&QE(&UU97-T<F4@8_-M;R!P97)M:71I<B!Q=64@=6X@9W5I
M\VX@86-C961A(&%L("(*(G!O<G1A<&%P96QE<RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5
M;G-E="!C;VQO<B(*;7-G<W1R(")!;G5L87(@8V]L;W(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.CDR-PHC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(D5X=&5N<VGS;B!N
M;R!S;W!O<G1A9&$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(D%C='5A;&EZ87(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E
M<R(*;7-G<W1R(")!8W1U86QI>F%R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T
M<B`B06-T=6%L:7IA<B!U<W5A<FEO(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S
M7"(N(@IM<V=S='(@(E-E(&AA(&%C='5A;&EZ861O(%PB)7-<(BXB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I
M<'0@9&5L971E9"XB"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&5L(&=U:?-N
M(&1E(&%C='5A;&EZ86-I\VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS
M9VED(")5<&QO860B"FUS9W-T<B`B0V%R9V%R(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*(E-E(&AA
M;B!C87)G861O(&5N(&5L('-E<G9I9&]R('1O9&]S(&QO<R!A<F-H:79O<R!D
M92!C;VYF:6=U<F%C:?-N(&1E("(*(F%P;&EC86-I;VYE<RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P
M"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(D%L9F%B971O
M(&QA=&EN;R!E;B!M87GZ<V,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S(')O;6%N;W,@96X@;6%Y^G-C
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")5<V%R(&%C
M='5A;#H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(E5S87(@4U-,(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M
M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G
M<W1R(")392!U<V$@<VD@96P@=7-U87)I;R]C;VYT<F%S9?%A('-O;B!D:7-T
M:6YT;W,@96X@96P@<V5R=FED;W(@24U34"XB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(E5S
M=6%R:6\B"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E
M<RXB"FUS9W-T<B`B16P@=7-U87)I;R`E<R!C87)E8V4@9&4@875T;W)I>F%C
M:?-N('!A<F$@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5
M<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:?-N(&1E
M('5S=6%R:6]S(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-#4*;7-G
M:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYE<R!D92!U<W5A<FEO
M(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB
M"FUS9W-T<B`B4F5G:7-T<F\@9&4@=7-U87)I;W,B"@HC.B!S:6=N=7`N<&AP
M.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")%<W1A('-E9&4@=&EE;F4@9&5S
M86-T:79A9&\@96P@<F5G:7-T<F\@9&4@=7-U87)I;W,N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F
M;W5N9"(*;7-G<W1R(").;R!S92!H82!E;F-O;G1R861O(&QA(&ED96YT:61A
M9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS
M9W-T<B`B57-U87)I;R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B66$@97AI<W1E(&5L(&YO;6)R92!D92!U
M<W5A<FEO(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")5<W5A<FEO.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE
M.B`B"FUS9W-T<B`B57-U87)I;SH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS
M9W-T<B`B57-U87)I;W,@96X@96P@<VES=&5M83HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E
M:VES=&%N(@IM<V=S='(@(E5Z8F5K:7-TX6XB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C$W,"!L:6(O5D93+V9I;&4N<&AP.C(V,@IM<V=I9"`B5D93(&1I<F5C
M=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3F\@97AI<W1E(&5L(&1I
M<F5C=&]R:6\@5D93+B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD
M:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B075S96YC:6$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#<P"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(DQA<R!U8FEC86-I;VYE<R!V
MX6QI9&%S(&5N8V]N=')A9&%S(&EN8VQU>65N.B`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B
M5F%L:61E>B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@
M(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(E9A;&]R(&5N
M(&UI;G5T;W,@82!P87)T:7(@9&4@86AO<F$N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C@V,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O
M9B`E<RXB"FUS9W-T<B`B16P@=F%L;W(@97AC961E(&5L('1A;6'Q;R!MX7AI
M;6\@9&4@)7,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#@@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(R-S`@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,C`*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,30@;&EB+TAO<F1E+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")686QO<F5S
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q.3`*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R
M(")686QO<F5S(&$@<V5L96-C:6]N87(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM
M<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R(")687)I86)L92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*
M;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N(@IM<V=S='(@(DAA(&9A;&QA9&\@;&$@8V]M<')O8F%C:?-N("T@
M97-T92!M96YS86IE('!U961E(&AA8F5R<V4@9F]R>F%D;RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G
M<W1R(")697)S:?-N(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B0RX@=F5R
M<VEO;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B
M06QI;F5A8VGS;B!V97)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B
M"FUS9W-T<B`B36%R9V5N('9E<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM
M<V=S='(@(E9E<G1I8V%L.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B375Y
M(&%L=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M(@H*
M(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA
M;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M:71A("A625-#24DI(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9E<B`E<R(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B
M('!A9V4B"FUS9W-T<B`B5F5R('5N82!PX6=I;F$@=V5B(&5X=&5R;F$B"@HC
M.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5F5R(&-O;6\@)7,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("))<VQA
M<R!6[7)G96YE<RP@0G)I=.%N:6-A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!5+E,N(@IM<V=S='(@(DES;&%S(%;M<F=E;F5S+"!5+E,N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*;7-G:60@(E9I<VEB:6QI='DB"FUS
M9W-T<B`B5FES:6)I;&ED860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES:6)I
M;&ED860Z("(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@
M(E9O9&%F;VYE(&1E($ET86QI82!M961I86YT92!33510(@H*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED
M(")705).(@IM<V=S='(@(D%625-/(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(J&AH4%$5D52
M5$5.0TE!(2$A($5,24U)3D4@34%.54%,345.5$4@14P@1U5)TTX@1$4@)7,N
M(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.
M('9I82!(5%10(@IM<V=S='(@(E=)3B!P;W(@2%144"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A
M;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!Y($9U='5N82(*"B,Z
M(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!
M9'9E<G1E;F-I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(DUI92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E
M8V%S="(*;7-G<W1R(")0<F5V:7-I\VX@9&5L('1I96UP;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T
M82!P<F]V:61E9"!B>2(*;7-G<W1R(")$871O<R!D96P@=&EE;7!O('-U;6EN
M:7-T<F%D;W,@<&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-@IM<V=I
M9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*
M"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B
M5V5B(%-I=&4B"FUS9W-T<B`B4V5D92!796(B"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B4V5M86YA
M;&UE;G1E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G
M:60@(E=E;&-O;64B"FUS9W-T<B`B0FEE;G9E;FED;R(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(D)I96YV96YI9&]S(&$@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0FEE;G9E;FED
M;RP@)7,B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")/97-T92`H25-/+3@X
M-3DM,2DB"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3V5S=&4@*$E33RTX
M.#4Y+3$U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R(")3X6AA
M<F$@3V-C:61E;G1A;"(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("*_477I(&%P
M;&EC86-I\VX@9&5B97+M82!M;W-T<F%R("5S(&%L(&EN:6-I87(@;&$@<V5S
M:?-N/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED
M(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("*_
M0W7A;"!E<R!E;"!C87+A8W1E<B!D96QI;6ET861O<C\B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/R(*;7-G<W1R("*_0W7A;"!E<R!E;"!C87+A8W1E<B!D
M92!C:71A9&\_(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-C0*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R
M(")-87!A(&1E(&QO8V%L:7IA8VGS;B!D92!!=7-T<F%L:6$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R
M(")1=>D@9F%S97,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ
M,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BXB"FUS9W-T<B`B4&QU9VEN<R!H86)I;&ET861O<R!D
M96P@961I=&]R(&1E('1E>'1O(&5N<FEQ=65C:61O+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(D%N8VAU<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$Q,0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(D%N
M8VAU<F$@96X@=6YI9&%D97,@0U-3(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R(")!;F-H=7)A(&1E;"!M96[Z("5S(&EZ<75I97)D
M;R`H9&ES<&]N:6)L92!E;B!L82!P<O-X:6UA('-E<VGS;BDZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@
M(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R(")!;F-H=7)A(&1E(&QA('1A
M8FQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B56YI9&%D97,@9&4@
M86YC:'5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B06YC:'5R83HB"@HC
M.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I
M:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C8*;7-G:60@(E=I;F0B"FUS9W-T<B`B5FEE;G1O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0@16%R
M;'DB"FUS9W-T<B`B5FEE;G1O(&UA='5T:6YA(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M(")696QO8VED860@9&5L('9I96YT;R!E;B!N=61O<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R(")6:65N=&\Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B
M5VEN9#H@(@IM<V=S='(@(E9I96YT;SH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B4V%B:61U<NUA(@H*
M(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7
M:7-H;&ES="(*;7-G<W1R(")$97-E;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B16UP;&5O(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*
M;7-G<W1R(")$:7)E8V-I\VX@9&5L('1R86)A:F\B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*
M;7-G<W1R(")496SI9F]N;R!D96P@=')A8F%J;R(*"B,Z(&QI8B]&:6QE+T-3
M5BYP:'`Z,3DS(&QI8B]&:6QE+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP
M96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").^FUE<F\@97)R\VYE;R!D
M92!C86UP;W,@96X@;&$@;.UN96$@)60N(%-E(&5S<&5R86)A;B`E9"!Y(&AA
M>2`E9"XB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(D[Z;65R;R!E<G+S;F5O(&1E(&-A;7!O<RX@
M4V4@97-P97)A8F%N("5D('D@:&%Y("5D+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W
M:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(D]F9G-E="`E9"!E
M<G+S;F5O(&%L(&QE97(@=6X@87)C:&EV;R!61E,N(@H*(SH@8V]N9FEG+RYB
M86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R
M(")8+5)E9B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DT"FUS
M9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B3&EM:71A
M8VEO;F5S(&+A<VEC87,@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B
M"FUS9W-T<B`B57-O(&1E(&-L879E(&5X=&5N9&ED82!8-3`Y=C,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(").;VUB<F4@86QT97)N
M871I=F\@9&4@87-U;G1O(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<B(*;7-G<W1R("))9&5N=&EF:6-A9&]R(&1E(&-L879E(&1E(&%S=6YT
M;R!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM
M<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B17AT96YS:6]N97,@
M6#4P.78S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM
M<V=S='(@(D%!(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V
M"FUS9VED(")965E9(@IM<V=S='(@(D%!04$B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*
M;7-G<W1R("*A36%P82!D92!986AO;R$B"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B06YU86QM96YT
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(EEE;65N(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM
M<V=S='(@(E/M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")3[2P@
M;&\@86-E<'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@
M=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM
M<V=S='(@(B(*(D5S=.$@96X@34]$3R!415A43RX@571I;&EC92!E;"!B;W3S
M;B!;/#Y=('!A<F$@<F5G<F5S87(@86P@;6]D;R!765-)5UE'+B(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(DYO(&1I<W!O;F4@9&4@<')I
M=FEL96=I;W,@<&%R82!C<F5A<B!MX7,@9&4@)60@8FQO<75E<RXB"@HC.B!L
M:6(O2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I
M8V%T960N(@IM<V=S='(@(DYO(&5S=.$@875T96YT:69I8V%D;RXB"@HC.B!L
M:6(O2&]R9&4O261E;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H
M879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS
M9W-T<B`B3F\@<'5E9&4@:6YC;'5I<B!E;"!C87+A8W1E<B!<(EQ<7"(@96X@
M96P@;F]M8G)E(&-O;7!L971O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#4Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Y"FUS9VED(")9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DYO(&EN
M=')O9'5J;R!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;R!VX6QI9&$N(@H*(SH@
M;&EB+TAO<F1E+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*
M;7-G<W1R("(B"B).;R!A<V]C:?,@;FEN9W5N;R!D92!L;W,@8V%M<&]S(&1E
M;"!A<F-H:79O(&EM<&]R=&%D;R!A(&QO<R!C86UP;W,@(@HB8V]R<F5S<&]N
M9&EE;G1E<R!D92`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@W"FUS
M9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(DAA('-A
M;&ED;R!D92!L82!S97-I\VXN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H
M;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@
M(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G
M<W1R("(B"B)4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N^FUE<F\@9&4@=&5L
MZ69O;F\@;?-V:6P@=N%L:61O+"!S\VQO(&3M9VET;W,@8V]N('5N("(*(B<K
M)R!O<&-I;VYA;"!P87)A(&5L('!R969I:F\@9&4@;&QA;6%D82!I;G1E<FYA
M8VEO;F%L+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3DR"FUS9VED(")9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")4:65N
M92!Q=64@:6YT<F]D=6-I<B!U;B!V86QO<B!VX6QI9&\N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG
M=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T
M<B`B4&%R82!U<V%R($%L=&%S('1I96YE('%U92!C;VYF:6=U<F%R('5N(&UO
M=&]R(&1E($1A=&%4<F5E+B(*"B,Z(&QI8B](;W)D92YP:'`Z-#8R"FUS9VED
M(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B
M5&EE;F4@<75E(&-O;F9I9W5R87(@=6X@;6]T;W(@5D93+B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B1&5B92!D97-C<FEB:7(@96P@<')O
M8FQE;6$@86YT97,@9&4@96YV:6%R(&5L(&EN9F]R;64N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(E1I96YE('%U92!I;G1R;V1U8VER(&QA(%523"!A(&QA('%U
M92!A<'5N=&$@97-T92!V[6YC=6QO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@
M=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B5&EE;F4@<75E('-E;&5C8VEO;F%R
M('5N('-E<G9I9&]R(&$@96QI;6EN87(N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+B(*;7-G<W1R(")4:65N92!Q=64@97-P96-I9FEC87(@=6X@=7-U
M87)I;R!A(&5L:6UI;F%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS
M9W-T<B`B5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S=6%R:6\@82!E;&EM
M:6YA<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B5&EE;F4@<75E(&5S<&5C:69I
M8V%R(&5L('5S=6%R:6\@82!A\6%D:7(N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N(@IM<V=S='(@(E1I96YE('%U92!E<W!E8VEF:6-A<B!E;"!U<W5A
M<FEO(&$@86-T=6%L:7IA<BXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2XB"FUS9W-T<B`B5&EE;F4@<75E(&5S<&5C:69I8V%R('%U
MZ2!A8V-I\VX@<V4@96IE8W5T87+A+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(E1I96YE('%U92!I;G1R;V1U
M8VER('5N(&YU979O(&YO;6)R92!D92!C871E9V]R[6$N(@H*(SH@;&EB+TYE
M="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R
M(")4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N^FUE<F\@9&4@=&5LZ69O;F\@
M:71A;&EA;F\B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<U"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")(82!E>'!I<F%D;R!S=2!S97-I
M\VX@)7,N(%9U96QV82!A(&EN:6-I87(@<V5S:?-N+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D
M9')E<W,B"FUS9W-T<B`B4W4@9&ER96-C:?-N(&1E(&-O<G)E;R(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M
M.B!A9&1R97-S.B(*;7-G<W1R(")$:7)E8V-I\VX@1&4Z(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z-S<*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#4@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M
M871I;VXB"FUS9W-T<B`B4W4@:6YF;W)M86-I\VXB"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB2&$@8V%M
M8FEA9&\@<W4@9&ER96-C:?-N(&1E($EN=&5R;F5T(&1E<V1E(&5L(&-O;6EE
M;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R("(*(G)A>F]N97,@9&4@<V5G=7)I
M9&%D('1I96YE('%U92!V;VQV97(@82!I;FEC:6%R(&QA('-E<VGS;BXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(E-U(&YO;6)R92(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF
M('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@
M86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT
M:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)3=2!M;W1O<B!D92!A=71E
M;G1I9FEC86-I\VX@;F\@<&5R;6ET92!A\6%D:7(@=7-U87)I;W,N(%-I('%U
M:7-I97)A('5S87(@(@HB2&]R9&4@<&%R82!A9&UI;FES=')A<B!C=65N=&%S
M(&1E('5S=6%R:6\L('1E;F1RX2!Q=64@=71I;&EZ87(@=6X@;6]T;W(@9&4@
M(@HB875T96YT:69I8V%C:?-N(&1I<W1I;G1O+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)3=2!M;W1O<B!D92!A=71E
M;G1I9FEC86-I\VX@;F\@<&5R;6ET92!L:7-T87(@=7-U87)I;W,L(&\@<V4@
M:&$@(@HB9&5S:&%B:6QI=&%D;R!L82!C87)A8W1E<NUS=&EC82!P;W(@86QG
M^FX@;6]T:79O+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B)087)E8V4@<75E(&AA(&-A;6)I861O
M('-U(&YA=F5G861O<B!D97-D92!E;"!C;VUI96YZ;R!D92!S=2!S97-I\VX@
M)7,N(%!O<B`B"B)R87IO;F5S(&1E('-E9W5R:61A9"!T:65N92!Q=64@=F]L
M=F5R(&$@:6YI8VEA<B!L82!S97-I\VXN(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92XB"FUS9W-T<B`B4W4@;F%V96=A9&]R(&YO(&%D;6ET
M92!E<W1A(&-A<F%C=&5R[7-T:6-A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#
M;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB16P@;F%V96=A
M9&]R(&YO(&%D;6ET92!E<W1A(&]P8VGS;B!D92!I;7!R97-I\VXN(%!R97-I
M;VYE($-O;G1R;VPO0V]M86YD;R`K("(*(E`@<&%R82!I;7!R:6UI<BXB"@HC
M.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(EIO;F$@:&]R87)I82!A8W1U
M86PZ(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(E-E
M(&AA(&-A;6)I861O('-U(&ED96YT:61A9"!P;W(@;VUI<VGS;BXB"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`B261E;G1I9&%D('!O<B!O;6ES:?-N
M.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B
M66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(DYO;6)R92!C;VUP;&5T;SHB"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")392!H82!A9V]T861O('-U('1I96UP;R!D
M92!C;VYE>&GS;BXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S(@IM<V=S='(@(DQA(&YU979A(&-O;G1R87-E\6$@<&%R82`E
M<R!E<SH@)7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")392!H86X@86-T=6%L
M:7IA9&\@<W5S(&]P8VEO;F5S('/S;&\@<&]R(&QA(&1U<F%C:?-N(&1E(&QA
M('-E<VGS;BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")3
M92!H86X@86-T=6%L:7IA9&\@<W5S(&]P8VEO;F5S+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T(@IM<V=S='(@(E-E(&AA(')E86IU<W1A9&\@<W4@8V]N
M=')A<V7Q82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS
M9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R
M9"XB"FUS9W-T<B`B(@HB4V4@:&$@<F5A:G5S=&%D;R!S=2!C;VYT<F%S9?%A
M+"!C;VUP<G5E8F4@96P@8V]R<F5O(&4@:6YI8VEE('-E<VGS;B!C;VX@<W4@
M(@HB;G5E=F$@8V]N=')A<V7Q82XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M("),82!C;VYT<F%S9?%A(&AA(&5X<&ER861O+B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R
M<SHB"FUS9W-T<B`B4V5R=FED;W)E<R!R96UO=&]S.B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(EEU9V]S;&%V:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S
M='(@(EIA:7)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("):
M:7!P>2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM/
M8W5L=&%R('1E>'1O(&-I=&%D;UTB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");26YF;W)M
M92!D92!P<F]B;&5M85TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G
M<W1R(");36]S=')A<B!T97AT;R!C:71A9&\@+2(*"B,Z(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G
M<W1R(");36]S=')A<B!T97AT;R!C:71A9&\@+2`E<R!L[6YE87-=(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@
M)7,@;V8@)7-=(@IM<V=S='(@(EML[6YE82`E<R!D92`E<UTB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$U-#4@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM
M<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI;FES=')A8VGS
M;B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R(")?
M0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS
M9W-T<B`BP7)?8F]L(&1A=&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O
M=R(*;7-G<W1R(")%7VQI;6EN87(@9FEL82(*"B,Z(&QI8B]A<&DN<&AP.C$S
M,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<&]S(@H*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B05]Y=61A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")0<F]P:65D861E<R!D92!?:6UA9V5N+BXN(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?26YI8VEA<B!S
M97-I\VXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G
M(&]U="(*;7-G<W1R(")?4V%L:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@
M3&EN:RXN+B(*;7-G<W1R(")-;V1I9FEC87(@7W;M;F-U;&\N+BXB"@HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R
M(")?3W!C:6]N97,B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M
M:7-S:6]N<R(*;7-G<W1R(")?4')I=FEL96=I;W,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@
M(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?16QI;6EN87(@=NUN8W5L;RXN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@
M(D-O;E]F:6=U<F%C+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B4')O<&EE9&%D97,@9&4@7W1A8FQA+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7U5S=6%R
M:6]S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E
M<W,@8F]O:R(*;7-G<W1R(")D:7)E8V-I;VYE<R(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB
M"FUS9W-T<B`B9&5S=&EN871A<FEO(&1E<V-O;F]C:61O(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(F%G
M96YD82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T
M<B`B8V%L;6$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3@*
M;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B;F\@
M<V4@<'5E9&4@8W)E87(@96P@87)C:&EV;R!D92!D97-T:6YO(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E
M;B!I;G!U="(*;7-G<W1R(")N;R!S92!P=65D92!A8G)I<B!E;"!O<FEG96XB
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"FUS9VED(")C
M;&EC:R!H97)E(@IM<V=S='(@(G!U;'-E(&%Q=>TB"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G
M92!E<G)O<B(*;7-G<W1R(")E<G)O<B!D92!L[6YE82!D92!C;VUA;F1O(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF
M:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(F5R<F]R(&1E(&-O;F9I9W5R86-I
M\VXB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@
M(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B9F%L=&$@
M=6X@87)C:&EV;R!C<NUT:6-O(&1E;"!S:7-T96UA(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O
M<B(*;7-G<W1R(")E<G)O<B!D92!F;W)M871O(&1E(&1A=&]S(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R
M(")M;V1I9FEC87(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")E;G1R861A(&YO
M(&5N8V]N=')A9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")D97-C96YS;R(*
M"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.3@*;7-G:60@(F9I;&4B"FUS
M9W-T<B`B87)C:&EV;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`B9&5L("5S("@E<RD@82!L87,@)7,@)7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM
M<V=S='(@(G9E;G1O<V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH(@IM
M<V=S='(@(FAH(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,X
M"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R(")N;VUB<F4@9&4@
M86YF:71R:?-N(&1E<V-O;F]C:61O(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(FEN;65D:6%T86UE
M;G1E(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")E;B!L[6YE82(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP
M=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(F5R<F]R(&1E(&5N=')A9&$O<V%L
M:61A(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED
M(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R(")E<G)O<B!D92!S
M;V9T=V%R92!I;G1E<FYO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")L[6YE87-=
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA
M:VEN9R!)4T\N(@IM<V=S='(@(F/S9&EG;R!D92!E<G)O<B!M:VES;V9S("5D
M(&%L(')E86QI>F%R($E33RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T
M,0IM<V=I9"`B;F%M92(*;7-G<W1R(")N;VUB<F4B"@HC.B!L:6(O2&]R9&4O
M4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")S
M:6X@9&5S87)R;VQL87(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B8?IN
M(&YO('-E(&AA(&1E<V%R<F]L;&%D;R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(FYO=&%S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM
M<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P;W)C96YT86IE(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E
M;FEE9"(*;7-G<W1R(")P<FEV:6QE9VEO(&1E;F5G861O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I
M9"`B<&EX96QS(@IM<V=S='(@(G#M>&5L97,B"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;"(*;7-G<W1R(")E<G)O<B!R96UO=&\@9&4@<')O=&]C;VQO(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@
M(G)I<VEN9R(*;7-G<W1R(")E;B!A=6UE;G1O(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE
M(@IM<V=S='(@(G-E<G9I8VEO(&YO(&1I<W!O;FEB;&4N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B;6]S=')A<B!D:69E<F5N8VEA<R(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@
M2%144"(*;7-G<W1R(")S;7,R96UA:6P@<&]R($A45%`B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G
M<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<S"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B97-T86)L92(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R
M<F]R(@IM<V=S='(@(F5R<F]R(&1E;"!S:7-T96UA(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")T87)E
M87,B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@
M(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(F9A;&QO('1E;7!O<F%L(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FTB"FUS9W-T<B`B97-C<FEB82!D;W,@=F5C97,@;&$@8V]N=')A<V7Q82!P
M87)A(&-O;F9I<FUA<FQA(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`B=6YI9FEC861O(@H*(SH@;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*
M;7-G:60@(G5N;F%M960B"FUS9W-T<B`B<VEN(&YO;6)R92(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S
M='(@(G5S=6%R:6\@<V5L96-C:6]N861O(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A
M<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R
M"FUS9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T
M:&5R+F-O;2(*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]E=%]%12YP;P``````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C$W
M,S4P`#$P-#$W,S8S,#`Q`#`Q-C,U-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````C($A/4D1%($535$].24%.(%1204Y33$%4
M24].(`HC"B,@5&]O;6%S($%A<R`\=&]O;6%S+F%A<T!M86EL+F5E/BP@,C`P
M,B`*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#8M
M,#(@,3`Z-#DK,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!4;V]M87,@06%S
M(#QT;V]M87,N86%S0&UA:6PN964^7&XB"B),86YG=6%G92U496%M.B!%<W1O
M;FEA;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@
M,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/
M+3@X-3DM,3-<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<
M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@
M)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I
M9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED
M("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A
M;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES
M=')Y+B(*;7-G<W1R("(G)7,G(&5I(&]L92!(;W)D92!R96=I<W1R:7,@:.3D
M;&5S=&%T=60N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!L:7-A=&D@9W)U<'!I
M9&4@<_QS=&5E;6DN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@;&ES
M871I(&QO87/\<W1E96UI+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M)R5S)R!E:2!L;V]D=60Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F
M34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E
M>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S
M="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!(;V]L9'5S
M=/;V9"`M(&MI;FYI='5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS
M,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG
M;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B3>1R9VD@:_5I:R!T]O9D
M(&UI9&$@<V]O=FED('!R865G=2!T96AA+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q
M=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T
M<B`B26=A(#4@;6EN=71I('1A9V%N="(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!T;R`E<R!O9B`E<R(*;7-G<W1R(");<FED82`E<R`E<RUS=%TB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B06%D<F5S
M<VED(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B
M2V%L96YD97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@
M;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F
M;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T
M:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN
M9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G
M=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E
M<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B,3(@
M2&]U<B!&;W)M870B"FUS9W-T<B`B4VEN=2!I;F9O(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(;W5R($9O<FUA="(*
M;7-G<W1R(")3:6YU(&EN9F\B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@='5N9&DB"@HC.B!F
M<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@
M(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D
M(@IM<V=S='(@(CQB/DIU:'1U<R!K;VAU=&%V('9I9V$Z/"]B/B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G
M:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*
M;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!2
M86EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED
M(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D5,+U!,(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI
M<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O
M='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")3:6YU(&EN9F\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`B2VEN;FET82!S86QA<_5N82(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I
M9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA
M=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B3&ES82(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U
M"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B3&ES
M82!A;&%M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"B,L(&9U>GIY"FUS9VED
M(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("),:7-A(&%L86UL=6)A
M("<E<R<M;&4B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0HC+"!F
M=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(DQI<V$@:V%S=71A:F$B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q
M.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO
M;B(*;7-G<W1R("),;V%D(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(DQI<V$@86QA;6=R
M=7!P("<E<R<M;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B3&ES82!A;&%M;'5B82`G
M)7,G+6QE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE
M=R!U<V5R.B(*;7-G<W1R("),:7-A('5U<R!K87-U=&%J83HB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!
M9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M8F5R
M<R(*;7-G<W1R("),:7-A('5U<R!L:6EG92(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(DQI<V$@
M<&%A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@
M8F]O:SHB"FUS9W-T<B`B06%D<F5S<VED(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@
M=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%A9')E<W-I9"(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("),:7-A
M(&MA<W5T86IA(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C
M;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B
M"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R(")+87-U=&%J871E(&QI<V%M:6YE('!O;&4@;'5B871U
M9"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S
M<R(*;7-G<W1R(")!861R97-S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$S.0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@
M(D%A9')E<W-I9"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")-=75D82`E<R!L
M=6)A<VED(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(DAA;&1U<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*
M(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R("),:7-A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PHC
M+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&EA<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QI87,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W
M"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*(RP@9G5Z>GD*
M;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT
M.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G
M:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED
M(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"B,L(&9U>GIY
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(D=R=7!I9"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+V1A=&%T<F5E+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B06QL(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(DQO860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S
M:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED
M(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!
M;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B
M"FUS9W-T<B`B4VEN=2!E+6UA:6QI(&%A9')E<W,Z(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")3:7-E<W1A=&D@
M;'5B86UA='4@=N3D<G1U<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA
M<R!O8V-U<F5D+B(*;7-G<W1R("(\8CY*=6AT=7,@:V]H=71A=B!V:6=A.CPO
M8CXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G
M:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A
M<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@
M86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I
M9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL
M9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!
M<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC
M("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C
M:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D]L960@<V$@:VEN9&5L(&5T
M('-O;W9I9"`G)7,G(&MU<W1U=&%D83\B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD
M(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")/;&5D('-A(&MI;F1E;"!E="!S
M;V]V:60@)R5S)R!K=7-T=71A9&$_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G
M96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@
M(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!
M<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(DMA='-E(&MU<W1U
M=&%D82!O;&5M871U="!G<G5P<&DN(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B2V%T<V4@:W5S='5T861A(&]L96UA
M='5T(&QU8F$N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")+871S92!M=75T82!O;&5M871U="!L=6)A+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")+871S
M92!M=75T82!O;&5M871U="!L=6)A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"B,L(&9U>GIY
M"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B2V%L860B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($94
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M
M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R
M"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM
M<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G
M:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(DMA<W5T871A=F%D(';D
M;&IA9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X
M8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K
M97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H
M25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A
M;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D
M;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")3_&YN:7#D
M978B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@
M;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3>1R
M9W5A;FYE=&4@:W5U;&%J870@)7,@96D@;&5I='5D+B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T
M"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM
M87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@
M(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O
M=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*
M;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM
M<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B4')U=6XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O
M='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R
M87II;"(*;7-G<W1R("))35`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE
M=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN
M82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`HC
M+"!F=7IZ>0IM<V=I9"`B0TU3(@IM<V=S='(@(D-64R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*(RP@9G5Z>GD*;7-G
M:60@(D-A;&TB"FUS9W-T<B`B3&]O8G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O
M;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B
M"FUS9W-T<B`B16D@<V%A;G5D(/QH96YD=7-T($Q$05`@<V5R=F5R:6=A+B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T<B`B
M2V%L96YD97(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP
M:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G
M<W1R("),;V]B=2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B3&]O
M8G4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")(Y.1L97-T
M=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6EL
M=&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE
M<R(*;7-G<W1R(")-;V)I:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN
M9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@
M(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I:6QT96QE9F]N(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T
M:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G<W1R
M(")4_&AI<W1A(&UU=71U<V5D(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R
M9"(*;7-G<W1R(")+:6YN:71A('-A;&%S]6YA(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D
M9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L
M>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R(")096%L:VER:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@
M*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*(RP@
M9G5Z>GD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(DMI;FYI
M=&$@<V%L87/U;F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@
M(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*
M;7-G<W1R(")-Y')G=6%N;F5T92!K=75L86IA="`E<R!E:2!L96ET=60N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@
M9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B
M0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A
M<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G
M:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O
M($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V
M:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E
M(%=I;F1O=R(*;7-G<W1R(")3=6QE(&%K96XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U
M9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS
M9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@
M(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R
M"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS
M9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D9I<FUA(@H*
M(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@
M(D-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@
M4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@
M;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B2VEN;FET82!S
M86QA<_5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I
M9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A
M8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B)R5S)R!S
M:7-U(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K
M:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM
M<V=S='(@(D9I<FUA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E
M<R(*;7-G<W1R("));7!O<F1I='5D(';D;&DZ("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")%:2!S86%N
M=60@_&AE;F1U<W0@3$1!4"!S97)V97)I9V$N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S
M97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")%:2!S86%N
M=60@_&AE;F1U<W0@3$1!4"!S97)V97)I9V$N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R
M>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X
M,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O
M=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R
M97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER
M96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD
M:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC
M(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(D5I('-U=61A(&OD:79I
M=&%D82!H;V]L9'5S=/;V(&UO;V1U;&ET("5S(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")%:2!S=75D82!KY&EV
M:71A9&$@:&]O;&1U<W3V]B!M;V]D=6QI="`E<R(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B16D@<V%A;G5D(/QH96YD=7-T($Q$05`@
M<V5R=F5R:6=A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z
M,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A
M9"`E<RXB"FUS9W-T<B`B)R5S)R!E:2!L;V]D=60Z("5S+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@
M<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O
M;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R
M979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@96D@;VQE(&MO
M<G)A;&EK=6QT(&CDY&QE<W1A='5D(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P
M=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N
M=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED
M(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M16D@<V%A;G5D(/QH96YD=7-T($Q$05`@<V5R=F5R:6=A+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N
M)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I
M9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R
M:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D
M('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E
M871E(&$@;F5W(&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(DQO860B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P
M"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E
M;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U
M="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP
M<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS
M9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G
M:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")04"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B
M1&%I;'DB"FUS9W-T<B`B26=A('#D978B"@HC.B!A9&UI;B]D871A=')E92YP
M:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@
M3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y
M.0HC+"!F=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R(")+=7-T=71A(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A
M=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB"FUS
M9W-T<B`B26=A('#D978B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G:60@(D1E7VQE
M=&4@0V]L=6UN(@IM<V=S='(@(DMU<W1U=&$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B1&5C
M96UB97(B"FUS9W-T<B`B3&EI:VUE9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM
M86P@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B
M"FUS9W-T<B`B2W5S='5T82(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(DMA<W5T82!V86EK97;DY')T=7-T(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)
M9&5N=&ET>2(*;7-G<W1R(")686EK96ED96YT:71E970B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE
M;&PB"FUS9W-T<B`B5F%I:V5I9&5N=&ET965T(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW
M,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED
M(")$96QE=&4B"FUS9W-T<B`B2W5S='5T82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B2W5S='5T82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B2W5S='5T82(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E($QO9R(*;7-G<W1R(")+=7-T=71A(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B3&]A9"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM
M<V=S='(@(DMU<W1U=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M8V]L=6UN(@IM<V=S='(@(DMU<W1U=&$B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP
M;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B375U9&$@)7,@;'5B87-I
M9"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(DMU<W1U=&$B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M5F%I:V5I9&5N=&ET965T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(')O=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E
M='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M(")+=7-T=71A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I
M9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B2VER:F5L9&$@<')O
M8FQE96UI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@
M9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(DMI<FIE;&1U<SHB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`BW&MS:6MA<VIA9"!L;V=I=&D@861M:6YI<W1R86%T;W)I(&IA;VMS
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E
M=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D5K<F%A;FD@
M<V5A9&5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L
M(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S
M='(@(D5K<F%A;FD@<V5A9&5D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED
M(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")%:W)A86YI('-E861E9"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T
M92(*;7-G<W1R(")+=7-T=71A(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R("+$<F$@_')I=&$@;6%I;G1E;F%N8V4N<&AP(&9A
M:6QI(&]T<V4@:^1I=FET861A(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@
M(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")$<G5G<R(*;7-G<W1R(")+86QA
M9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F
M=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S='(@(DE-4"(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I
M;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P
M<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R
M"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B
M"FUS9W-T<B`B375U9&$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN
M<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D
M:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@
M861M:6XO9W)O=7!S+G!H<#HR,C8*(RP@9G5Z>GD*;7-G:60@(D5D:70@1W)O
M=7`B"FUS9W-T<B`B1W)U<&ED(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`HC
M+"!F=7IZ>0IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(DQO860B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"B,L(&9U>GIY"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(DQO860B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")-=75D
M82`E<R!L=6)A<VED(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0HC
M+"!F=7IZ>0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B375U
M9&$@)7,@;'5B87-I9"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B375U9&$@)7,@;'5B87-I9"(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(DUU=61A("5S(&QU8F%S:60B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA
M8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO
M;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L
M=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M;6%I;"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R(")3:6YU(&4M;6%I;&D@86%D<F5S<SHB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U>GIY"FUS9VED(")%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B4V%L87/U;F%D
M('!E879A9"!K;&%P<&EM82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")-=74@:6YF;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T
M97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,CDX"B,L(&9U>GIY"FUS9VED(")%;6]T:6-O;G,B"FUS
M9W-T<B`B2.3D;&5S='5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M
M97-S86=E+B(*;7-G<W1R(")4=6QE;75S(&]N('3\:&DN(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P
M-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B
M16UP='D@<F5S=6QT+B(*;7-G<W1R(")4=6QE;75S(&]N('3\:&DN(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP
M='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H
M="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G
M92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC
M:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R
M("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@
M<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE
M(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L
M971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%
M<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@
M(E9I9V$B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A
M;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS
M9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H
M:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V
M"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN
M=71E<R(*;7-G<W1R("))9V$@,34@;6EN=71I('1A9V%N="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@
M;6EN=71E<R(*;7-G<W1R("))9V$@-2!M:6YU=&D@=&%G86YT(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DEG82`S,"!S
M96MU;F1I('1A9V%N="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(DEG82`U(&UI;G5T:2!T86=A;G0B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R
M>2!,;V=I;B(*;7-G<W1R("))9V%L('-I<W-E;&]G:6UI<V5L(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(DEG82!P;V]L92!T=6YN:2!T86=A;G0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*
M;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")+;W)D(&UI;G5T:7,B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L
M92!V86QU97,Z(@IM<V=S='(@(D[D:61I<W;DY')T=7-E9"(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO
M<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%
M>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I
M9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@
M(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D5I('-A86YU9"#\:&5N9'5S
M="!,1$%0('-E<G9E<FEG82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N(@IM<V=S='(@(D5I('-A86YU9"#\:&5N9'5S="!,1$%0
M('-E<G9E<FEG82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B16D@<V%A;G5D(/QH96YD=7-T($Q$
M05`@<V5R=F5R:6=A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B16D@<V%A;G5D($Q$05`@_&AE;F1U
M<W0@)7,G9V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`B16D@<V%A;G5D(/QH96YD=7-T($Q$05`@<V5R=F5R:6=A+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(D5I
M('-A86YU9"!KY'1T92!K87-U=&%J82!$3B=I.B!;)61=("5S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A
M:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(E9I9V$@:6UP;W)D:6PZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&86MS
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%K<R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E
M;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*
M;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R(")096%L:VER:2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S
M='(@(D9A:6QI:&%L9'5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")&86EL:6AA
M;&1U<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@
M(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V
M"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*
M;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G
M:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H
M;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@
M9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R
M97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S
M<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z
M>GD*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(DWD<FMM960B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B
M1F]R=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R
M(").:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;F-E(@IM
M<V=S='(@(DQO;V)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L
M;"!$97-C<FEP=&EO;B(*;7-G<W1R(")+:7)J96QD=7,Z(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@
M(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F
M=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(E-I;G4@;FEM:3HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*
M;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B
M1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS
M9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@
M(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")'<F5E8V4B
M"FUS9W-T<B`B4F]H96QI;F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")2;VAE
M;&EN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D=R96YA9&$B"FUS
M9W-T<B`B4F]H96QI;F4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I
M9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!I9&4@:&%L
M9'5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@
M(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")%:2!S
M86$@:W5S='5T861A("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'
M<F]U<',B"FUS9W-T<B`B1W)U<&ED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A
M9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*(RP@9G5Z
M>GD*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(DAA;&PB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C@X"B,L(&9U>GIY"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*
M;7-G<W1R("),;V%D(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W
M,`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D%A9')E<W-I
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA
M:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@
M(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*;7-G
M:60@(DAE861E<B(*;7-G<W1R(")096%L:VER:F%D(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I
M9"`B2&5A9&5R<R(*;7-G<W1R(")096%L:VER:F%D(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM
M."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS
M9VED(")(96QP(@IM<V=S='(@(D%B:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I
M=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")!8FDB"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L
M871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED
M(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM<V=I
M9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM
M<V=S='(@(DMO9'5N92!A861R97-S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED
M(")(;VUE(%!H;VYE(@IM<V=S='(@(DMO9'5N92!T96QE9F]N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@
M96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B
M:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(B5S(&]N('/\<W1E96UI<W0@
M965M86QD871U9"XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R
M,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q
M"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I
M='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*
M;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@
M061D<F5S<R(*;7-G<W1R(")!861R97-S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP
M8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO
M8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))
M7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC
M;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N
M86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T
M(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@
M=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN
M9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*
M(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G
M:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA
M9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E
M9"(*;7-G<W1R("));7!O<F1I='5D(';D;&DZ("5S(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R9&ET=60@=N1L:3H@)7,B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O
M<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R9&ET=60@=N1L:F%D.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED
M("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+B(*;7-G<W1R(")3:7-E<W1A(&]M82!K87-U=&%J86YI;6D@:F$@
M<V%L87/U;F$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM
M<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@
M9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(E-I;G4@:6YF;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN
M9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I
M9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@
M3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN
M($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U
M,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T
M(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E
M;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU
M;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M
M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@
M(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T
M;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN
M=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)
M4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@
M<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O
M<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<W"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("))
M;G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G
M:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"FUS9VED("));G9A;&ED('!A<G1N
M97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S4*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R
M92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C
M92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI
M8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B
M26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*
M;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L
M(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R("))9V$@<.1E=B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A
M;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B
M965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA
M>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"B,L(&9U>GIY"FUS
M9VED(")*97)S97DB"FUS9W-T<B`B2&%L;"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED
M(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*
M;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B
M2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"B,L(&9U>GIY"FUS9VED(")+96YY
M82(*;7-G<W1R("),_&MK82!T86=A<VDB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T
M960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R
M"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*
M(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")496%D92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A
M=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B
M3&%?>6]U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")+965L(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED
M("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),
M87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B"FUS
M9W-T<B`B3&]G:2!VY&QJ82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U
M"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(").Y&ED:7-V
MY.1R='5S960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U
M>GIY"FUS9VED("),979E;"(*;7-G<W1R(")-:71T92!K=6YA9VDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0HC
M+"!F=7IZ>0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")(96QE<VEN
M:6YE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B3&]G:2!S
M:7-S92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),
M:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(")(
M96QE<VEN:6YE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC
M+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("),;V=I('-I<W-E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA
M:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L
M9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G
M:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S
M='(@(D%B:6EN9F\@=&5E;6%D92!N:6UE:VER:2(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),
M:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*
M;7-G<W1R(")!8FEI;F9O('1E96UA9&4@;FEM96MI<FDB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES
M="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S
M<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")+87-U=&%J871E(&YI;65K:7)J
M82!P;VQE(&QU8F%T=60@;N1H82XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M9F%I;&5D.B`E<R(*;7-G<W1R(")+87-U=&%J871E(&YI;65K:7)J82!P;VQE
M(&QU8F%T=60@;N1H82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(DMA<W5T86IA=&4@;FEM96MI<FIA('!O;&4@;'5B871U9"!NY&AA
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A
M='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L
M('1I;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R("),;V=I('-I<W-E
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`B3&]G:2!VY&QJ82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B3&]G:2!S:7-S
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(E3V]F0B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.38*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(DUI;&QE9VEPY')A<W0@<VES
M<V5L;V=I;6EN92!E8F'U;FYE<W1U<RX@2_5I9V4@=/5E;N1O;&ES96UA;'0@
M<VES97-T87-I9"`B"B)V86QE(&MA<W5T86IA;FEM92!V]6D@<V%L87/U;F$N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I
M;B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S-C4*(RP@9G5Z>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),
M;V=I(';D;&IA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"B,L(&9U
M>GIY"FUS9VED("),;W9E(@IM<V=S='(@(D5E;6%L9&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-
M(@IM<V=S='(@(DM+(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X
M,0IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS
M9VED(")-86=I8R(*;7-G<W1R("))35`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B24U0(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS
M9W-T<B`B24U0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R
M("))35`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM
M<V=S='(@(DE-4"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I
M9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA
M<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I
M9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@
M(DAO:6%T=7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS
M9W-T<B`B4V]B:79A9"!VY&QJ860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA
M=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R
M:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D
M:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP
M(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V
M"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED
M(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G
M:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B3&EI
M:VUE9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G:60@(DUE
M;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B5&5A
M9&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R(")496%D92(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z
M>GD*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")496%D92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B(@HB365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`BW&MS:6MA<VIA9"!L;V=I
M=&D@861M:6YI<W1R86%T;W)I(&IA;VMS+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P
M+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<
M(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B365E=&]D("<E<R<@96D@
M;VQE(&1E9FEN965R:71U9"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*
M;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@
M9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R("))35`B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4
M>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS
M9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@
M-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@
M;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI
M<G)O<B(*;7-G<W1R(")6:6=A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I
M9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-
M:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET
M(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@
M<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@
M36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A
M=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W
M"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DMO<F0@:W5U<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO
M;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E
M9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE
M87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G
M:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@
M9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@
M54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O
M=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC
M+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M(")3:6YU(&EN9F\B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T
M"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R
M(").:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T
M<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I
M9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C
M87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(E;U<FLB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS
M9VED(").979E<B(*;7-G<W1R(")-:71T92!K=6YA9VDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@
M(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B
M3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P
M87-S=V]R9"(*;7-G<W1R(")386QA<_5N82(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A
M<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(E-A;&%S]6YA9"!P
M96%V860@:VQA<'!I;6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R(")-Y')K;65D(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0HC+"!F=7IZ>0IM<V=I
M9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P:60B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z
M>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")486=A<VD@:.3D;&5S
M='5S<V4B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A
M<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED
M(").:6=E<B(*;7-G<W1R(")-:71T92!K=6YA9VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ
M.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*
M;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"!A=71E;G1I;6ES92!HY.1L97-T
M=7-I;F9O('!U=61U8BXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")4_&AI<W1A(&UU
M=71U<V5D(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M(RP@9G5Z>GD*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B<E<R<@;&ES871I(&QO87/\<W1E
M96UI+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T
M:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G
M<W1R(")344P@:V%T96=O;W)I871E(&CDY&QE<W1U<VEN9F\@<'5U9'5B+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"B,L(&9U>GIY"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`B3$1!4"!HY.1L97-T=7-I;F9O('!U=61U
M8BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N(@IM<V=S='(@(E-13"!K871E9V]O<FEA=&4@:.3D
M;&5S='5S:6YF;R!P=75D=6(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<Q-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS
M9W-T<B`B4U%,(&MA=&5G;V]R:6%T92!HY.1L97-T=7-I;F9O('!U=61U8BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM
M<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I
M9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"FUS9VED(").;R!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P
M<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I
M9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H
M<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(RP@9G5Z
M>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(&%U=&5N=&EM:7-E(&CDY&QE<W1U
M<VEN9F\@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D
M+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"!A=71E
M;G1I;6ES92!HY.1L97-T=7-I;F9O('!U=61U8BXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(E-13"!A=71E;G1I;6ES92!HY.1L97-T=7-I;F9O('!U=61U8BXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*
M(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!0
M2T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DWD<FMM960B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO
M('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z
M>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DWD<FMM960B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")3:7-E<W1A(&]M
M82!K87-U=&%J86YI;6D@:F$@<V%L87/U;F$B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960B"FUS9W-T<B`B16D@=&%G87-T871U9"!K;W)R96MT<V5I9"!8
M34P@86YD;65I9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z
M>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@
M*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM
M<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3>1R:VUE9"(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@
M(DYO=&5S(@IM<V=S='(@(DWD<FMM960B"@HC.B!S97)V:6-E<R]O8G)O=W-E
M<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B
M86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM<V=I9"`B3F]V96UB97(B"FUS9W-T
M<B`B3&EI:VUE9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*
M(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R("),:6EK;65D(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F
M(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A
M=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/
M2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A
M=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F
M96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@
M(D]L9"!P87-S=V]R9"(*;7-G<W1R(")386QA<_5N82(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES
M(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@
M82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO
M;G,B"FUS9W-T<B`B2.3D;&5S='5S(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")(Y.1L97-T
M=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@
M(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")(86QD=7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N
M86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS
M9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")-=74@:6YF;R(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(DQO860B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")0
M32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N
M(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS
M9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@
M3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")386QA<_5N82(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@
M8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B
M4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E-A;&%S]6YA(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")0
M87-S=V]R9#HB"FUS9W-T<B`B4V%L87/U;F$B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*
M;7-G<W1R(")386QA<_5N82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R(")386QA<_5N860@<&5A=F%D(&ML87!P:6UA+B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS
M9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(E)O;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM
M<V=S='(@(DOD:79I=&$@:&]O;&1U<W3V]F0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(DOD:79I=&$@:&]O
M;&1U<W3V]F0B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("),;V%D(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z>GD*
M;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(DQO860B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B3&]A9"(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(DQU8F%D92!H86QD=7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*(RP@9G5Z>GD*;7-G:60@(E!E
M<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DUU=2!I;F9O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H
M;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G
M:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E
M(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B2VER:F5L9&$@<')O
M8FQE96UI+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4VES97-T
M82!O;6$@:V%S=71A:F%N:6UI(&IA('-A;&%S]6YA(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@
M(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U
M9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N
M8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N
M<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G
M:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B
M17-I=&QU<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S
M='(@(EM(;W)D92!P<F]B;&5E;5TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O
M8FQE96UI(&MI<FIE;&1U<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0
M<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@
M(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y
M($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D
M:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS
M9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN
M(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O
M;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS
M9W-T<B`B3&]E(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T
M<B`B5&5A9&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*
M;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*
M;7-G<W1R(")6Y')S:V5N9&$@_&QE=F%A9&4Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM
M<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(DQO92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA
M<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D5E;6%L
M9&$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@
M(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@
M(E)E;6]V92(*;7-G<W1R(")%96UA;&1A(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@0FQO8VLB
M"FUS9W-T<B`B165M86QD82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-3<*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU
M;6XB"FUS9W-T<B`B165M86QD82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F
M;W)M871T:6YG(@IM<V=S='(@(D5E;6%L9&$@<&%A<B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G
M<W1R(")%96UA;&1A('!A87(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U
M>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D5E;6%L9&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B165M
M86QD82!P86%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@
M)7,B"FUS9W-T<B`B165M86QD82!P86%R(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S
M='(@(E#D<FEN9W5L92!P;VQN=60@=O5I;6%L:6L@=F%S=&%T82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G:60@
M(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T
M<B`B4.1R:6YG=6QE('!O;&YU9"!V]6EM86QI:R!V87-T871A(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E-E861E=&4@:.3D;&5S='5S97,@<'5U9'5B('9A:F%L:6L@
M)W5I9"<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E-E861E=&4@:.3D;&5S='5S97,@<'5U9'5B
M('9A:F%L:6L@)W5I9"<N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z
M-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")3
M96%D971E(&CDY&QE<W1U<V5S('!U=61U8B!V86IA;&EK("=U:60G+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S
M=V]R9"(*;7-G<W1R(")386QA<_5N82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R(%!A<W-W
M;W)D(@IM<V=S='(@(DMI;FYI=&$@<V%L87/U;F$B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL
M+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@
M3W!T:6]N<R(*;7-G<W1R(")486=A<VD@:.3D;&5S='5S<V4B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@
M<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U
M;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N
M<R(*;7-G<W1R(")486=A<VD@:.3D;&5S='5S<V4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P
M"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PHC+"!F=7IZ>0IM<V=I
M9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(DAE;&5S:6YI;F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*
M;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2
M;VQE(@IM<V=S='(@(E)O;&PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA
M;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM
M<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I
M9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS
M9VED(")2=6QE<R(*;7-G<W1R(")2;VQL(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)W86YD82(*
M;7-G<W1R("),;V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I
M9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U
M>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E1E861E(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B
M4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA
M<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M
M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*
M(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`B4V%L=F5S=&$@)R5S)R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E-A
M;'9E<W1A("<E<R<B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R
M(")386QV97-T82`G)7,G(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E-A;'9E<W1A(&CDY&QE
M<W1U<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*
M(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T
M('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C
M:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G
M:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@
M1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R(")686QI(&MU=7#D979A(&9O<FUA870Z(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P
M('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE
M8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E9A;&D@:W5U<.1E=F$@
M9F]R;6%A=#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*
M;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B(@HB4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N(@IM<V=S='(@(E9A;&D@=F%J86QI:W5D(&WD<F=I9"!K87-T:61E
M<W0N(%-I:7,@<V%A9"!N965D(&MO<&5E<FED82!K:7)J82!S:7-S92XB"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5F%L:2!K=75PY&5V82!E<F%L
M9&%J83HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5F%L:2!K=75PY&5V
M82!F;W)M86%T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CHB"FUS9W-T<B`B5F%L:2!K=75PY&5V82!E<F%L9&%J83HB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`B5F%L:2!K96QL86%J82!F;W)M86%T.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")686QI(&MA:W,@<V]B
M:79A="!VY&QJ82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS
M9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E9A;&D@
M=N1R=FES:V5E;2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS
M9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@
M(E9A;&D@;VUA(&QE;6UI:VME96PZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`B4V%A9&$@<')O8FQE96UI(&MI<FIE;&1U<R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD
M(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED
M(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B4V5P=&5M8F5R
M(@IM<V=S='(@(DQI:6MM960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI
M;B(*;7-G<W1R("),=6)A9&4@:&%L9'5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N
M($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC
M+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B3&]A9"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O
M<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF
M('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ
M>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")686QI(&]M82!L96UM:6MK
M965L.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`HC+"!F=7IZ>0IM
M<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y
M(&]P=&EO;G,N(@IM<V=S='(@(E9A;&D@;VUA(';D<G9I<VME96UI+"!L96AE
M:_QL:F4@=N1R<VME;F1A;6ES92!J82!M=75D(&5S:71U<V4@<V5A9&5D+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*
M;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E
M>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-H
M;W)T(%-U;6UA<GDB"FUS9W-T<B`B3/QH:6MO:VMU=O5T93HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H
M;W<B"FUS9W-T<B`B3N1I=&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#
M96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(").Y&ET82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS
M9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")*
MY'1A(&AO;VQD=7,@=F%H96QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E-N;W<B"FUS9W-T<B`B3N1I
M=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I
M9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V
M-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0HC
M+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B5/;V:V]H
M82!A861R97-S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED
M(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@
M4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W
M965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T
M"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A
M8W1E<B!);G!U="(*;7-G<W1R(")%<FEMY')K:61E('-I<V5S='5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3
M<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I
M9"`B4W!O<G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I
M($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B
M4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY
M"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")3:6YU(&EN9F\B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@HC+"!F=7IZ
M>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B5/;V:V]H82!A861R
M97-S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS
M9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3
M=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(")-Y')G=6%N;F5T92!K=75L86IA="`E<R!E
M:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]2
M96YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B(@H*(SH@
M<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T
M960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@
M87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B3.1K<R!K;W)D82(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S
M='(@(B5S(&]N('/\<W1E96UI(&QI<V%T=60N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(B5S(&]N('/\<W1E96UI<W0@965M86QD871U9"XB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D
M96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B)7,@;VX@:W5S='5T871U9"XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(B5S(&]N('/\<W1E96UI<W0@965M86QD871U9"XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T
M960@7"(E<UPB(@IM<V=S='(@(B5S(&]N(&MU<W1U=&%T=60N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W
M<F]T92`E<R(*;7-G<W1R("(E<R!O;B!K=7-T=71A='5D+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*
M;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B2V]K:W5V]71E.B(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B
M4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN
M86UE(@IM<V=S='(@(DMA<W5T86IA;FEM:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE
M(@IM<V=S='(@(DMA<W5T86IA;FEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN
M8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I
M9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS
M9VED(")44U8@9FEL92(*;7-G<W1R(")096%L:VER:2(*"B,Z(&9R86UE=V]R
M:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*
M;7-G<W1R(")096%L:VER:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW
M86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B5&%S:W,B"FUS9W-T<B`B5/;V9"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED
M(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B
M5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*(RP@9G5Z>GD*
M;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(DMA<W5T
M86IA:&%L9'5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E
M>'0@3VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@
M(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN
M9R!T:&4@<WES=&5M+B(*;7-G<W1R(")3:6YD(&QO9VET:2!VY&QJ82XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L
M;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM
M<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED
M("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H
M92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4
M:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G
M:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H
M92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R
M>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H
M87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM
M<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M
M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L
M9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")396QL92!K;VAA('!E86P@
M<&5A8B!O;&5M82!A<G8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I
M9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R
M871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF
M:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I
M9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X
M="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS
M9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R
M:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+B(*;7-G<W1R(")(Y.1L97-T=7-I;F9O(&5I(&]L92!KY'1T97-A861A=BXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G
M:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N
M("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N
M<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS
M9W-T<B`B)7,@;&ES86UI<V5L('/\<W1E96UI('1E:VMI<R!P<F]B;&5E;2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@
M=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B)7,@965M
M86QD86UI<V5L('/\<W1E96UI<W0@=&5K:VES('!R;V)L965M+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B)7,@965M86QD86UI<V5L('/\<W1E96UI<W0@
M=&5K:VES('!R;V)L965M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U
M<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(B5S(&QI<V%M:7-E;"!S_'-T
M965M:2!T96MK:7,@<')O8FQE96TN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U
M<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I
M9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0HC+"!F
M=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N(@IM<V=S='(@(E-E;&QE(&MO:&$@<&5A;"!P96%B(&]L
M96UA(&%R=BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W
M:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO
M+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@
M5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N
M=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@
M=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*(RP@9G5Z>GD*
M;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS
M9W-T<B`B4V5L;&4@:V]H82!P96%L('!E86(@;VQE;6$@87)V+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92XB"FUS9W-T<B`B4V5E(&%R=B!P96%B(&]L96UA(';D:&5M86QT(/QK
M<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z
M-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N
M9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@
M8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")396QL92!K;VAA('!E86P@<&5A
M8B!O;&5M82!A<G8N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS
M9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L
M(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(E!E86QK:7)I(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@
M(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(E!E86QK:7)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U
M"FUS9VED(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4
M;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R
M<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T
M<B`B17-I=&QU<V5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@
M86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G
M:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B
M5'5R:V5Y(@IM<V=S='(@(DAA;&PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B
M5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")%
M:2!S86$@_&AE;F1U<W0@4U%,('-E<G9E<FEG82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T
M<B`B16D@<V%A(/QH96YD=7-T(%-13"!S97)V97)I9V$N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*
M;7-G<W1R(")%:2!S86$@:W5S='5T861A("<E<R<Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C@S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(D5I('-A82!K
M=7-T=71A9&$@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BXB"FUS9W-T<B`B16D@<V%A(/QH96YD=7-T(%-13"!S97)V97)I9V$N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")%
M:2!S86$@_&AE;F1U<W0@4U%,('-E<G9E<FEG82XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B16D@<V%A(/QH96YD
M=7-T(%-13"!S97)V97)I9V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(")%:2!S86$@_&AE;F1U<W0@4U%,('-E<G9E<FEG
M82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R
M(")%:2!S86$@_&AE;F1U<W0@4U%,('-E<G9E<FEG82XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B16D@<V%A(&MU<W1U=&%D82`G)7,G.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(D5I('-A82#\
M:&5N9'5S="!344P@<V5R=F5R:6=A+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B16D@<V%A(&MU<W1U=&%D82`G
M)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G
M<W1R(")%:2!S86$@:W5S='5T861A("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@
M)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@)R5S)SH@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")%:2!S86$@:W5S='5T861A("<E<R<Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS.3$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@)R5S)SH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@)R5S)SH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`B16D@<V%A(&MU<W1U=&%D82`G)7,G.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B16D@<W5U9&$@:.3D;&5S='5S="!R96=I<W1R965R:61A+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED
M(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO
M;B!O9B`E<RXB"FUS9W-T<B`B16D@<V%A(&MU<W1U=&%D82`G)7,G.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M(@IM<V=S='(@(D5I('-A82#\:&5N9'5S="!344P@<V5R=F5R:6=A+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV
M-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")%:2!S86$@:W5S='5T861A("<E<R<Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O
M<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B16D@<V%A
M(/QH96YD=7-T(%-13"!S97)V97)I9V$N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")%:2!S86$@
M_&AE;F1U<W0@4U%,('-E<G9E<FEG82XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL
M97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R
M(")%:2!S86$@:W5S='5T861A("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B16D@<V%A(/QH96YD=7-T
M(%-13"!S97)V97)I9V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")%:2!S86$@:W5S='5T861A("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI
M<V]F<R<N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@)R5S)SH@)7,N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM
M<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B
M"FUS9W-T<B`B4V5D82!7;W)D:2!D;VMU;65N=&D@;VX@=O5I;6%T=2!T]6QG
M96YD861A(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(D5I('-A82!K=7-T=71A9&$@)R5S)SH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T
M,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL
M(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B
M56YD;R!#:&%N9V5S(@IM<V=S='(@(E3\:&ES=&$@;75U='5S960B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED
M(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"B,L(&9U>GIY"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ("(*;7-G<W1R(")6:6=A;F4@=F%S='5S('-E<G9E<FEL="(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`HC+"!F=7IZ>0IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(E9I9V%N92!V87-T=7,@<V5R=F5R:6QT(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N
M9FEL960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*
M;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM
M<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@
M87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS
M9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*
M;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")+
M87-U=&%J86YI;6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O
M<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92(*;7-G<W1R(")5=65N9&%T
M=60@)R5S)RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS
M9W-T<B`B575E;F1A='5D("<E<R<N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`B575E;F1A='5D("<E<R<N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T960@7"(E<UPB+B(*;7-G<W1R(")5=65N9&%T=60@)R5S)RXB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I
M<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS
M9VED(")5<V5R(@IM<V=S='(@(DMA<W5T86IA9"(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B2V%S=71A:F%H86QD=7,B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS
M(@IM<V=S='(@(DMA<W5T86IA(&CDY&QE<W1U<R(*"B,Z('-I9VYU<"YP:'`Z
M-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(DMA<W5T86IA:&%L9'5S(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM
M<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")+87-U
M=&%J86YI;6DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`B2V%S=71A:F%N:6UI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")+87-U
M=&%J86YI;6DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR
M"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")+87-U=&%J
M860@<_QS=&5E;6ES.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED
M(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@
M(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E
M;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P
M"B,L(&9U>GIY"FUS9VED(")697)S:6]N(@IM<V=S='(@(DQO860B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O
M;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE
M=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS
M"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5
M+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS
M9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@
M1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B2&]I871U<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@
M(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R
M(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@
M(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")+
M;W)D(&[D9&%L87,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")497)E('1U;&5M
M87-T+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE('1O("5S(@IM<V=S='(@(E1E<F4@='5L96UA<W0@)7,M:2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE
M+"`E<R(*;7-G<W1R(")497)E('1U;&5M87-T+"`E<R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@
M87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS
M9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B
M5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I
M9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H
M('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@
M0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE
M;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I
M9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM
M<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN
M9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM
M<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*
M;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")4]O9K;VAA(&%A9')E<W,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR
M"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E3V]G1E;&5F;VXB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU
M;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T
M,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS
M=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")!02(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0HC
M+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R(")!02(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO
M;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")+;W)D
M(&%A<W1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(EEE;65N
M(@IM<V=S='(@(E)O:&5L:6YE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS
M9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9
M;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@;&]G
M9V5D(&]U="XB"FUS9W-T<B`B4VEN=2!M=75D871U<V5D(&]N('-A;'9E<W1A
M='5D+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@
M(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T
M(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V
M"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*
M;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")%;FYE
M('-A871M:7-T(&]L96MS('1A<FL@<')O8FQE96UI(&MI<FIE;&1A9&$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM
M<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E!E860@;>3D<F%M82!K
M87-U=&%J86YI;64@;6ED82!E96UA;&1A9&$N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")096%D(&WDY')A;6$@:V%S
M=71A:F%N:6UE(&UI9&$@965M86QD861A+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92XB"FUS9W-T<B`B4&5A9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A
M(&5E;6%L9&%D82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B4&5A9"!MY.1R86UA
M(&MA<W5T86IA;FEM92!M:61A(&QI<V%D82XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B4&5A9"!MY.1R86UA(&MA<W5T
M86IA;FEM92!M:61A(&QI<V%D82XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B4&5A
M9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&5E;6%L9&%D82XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")096%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@
M965M86QD861A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E
M(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B4VEN=2`E<R!S97-S:6]O;B!O;B!A96=U;G5D+B!086QU
M;B!L;V=I('5U97-T:2!S:7-S92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(E-I;G4@92UM86EL:2!A861R97-S.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@1G)O
M;3H@861D<F5S<SHB"FUS9W-T<B`B4VEN=2!E+6UA:6QI(&%A9')E<W,Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(E-I;G4@:6YF;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E
M<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,S"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B
M"FUS9W-T<B`B4VEN=2!N:6UI.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H
M96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)3:6YU(&%U=&5N=&EM
M:7-S_'-T965M(&5I(';U:6UA;&1A(&MA<W5T86IA:60@;&ES861A+"!V]6D@
M;VX@<V5E(';U:6UA;'5S("(*(FUI;F=I;"!M=75L('#U:&IU<V5L(';D;&IA
M(&S\;&ET871U9"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB
M"FUS9W-T<B`B(@HB4VEN=2!A=71E;G1I;6ES<_QS=&5E;2!E:2!V]6EM86QD
M82!K87-U=&%J871E(&YI;65K:7)J82!NY&AA+"!V]6D@;VX@<V5E("(*(G;U
M:6UA;'5S(&UI;F=I;"!M=75L('#U:&IU<V5L(';D;&IA(&S\;&ET871U9"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B
M"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM
M<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN
M="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M(@IM<V=S='(@(E-I;G4@;75U9&%T=7-E9"!O;B!S86QV97-T871U9"XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E9A:6ME:61E;G1I=&5E
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")3:6YU(&YI;6DZ(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B4VEN=2!M=75D871U
M<V5D(&]N('-A;'9E<W1A='5D+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B4VEN=2!M=75D871U<V5D(&]N('-A;'9E
M<W1A='5D+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S
M='(@(E-I;G4@;75U9&%T=7-E9"!O;B!S86QV97-T871U9"XB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@
M>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB
M86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*
M;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E
M(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");2&]R
M9&4@<')O8FQE96U=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG
M:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");
M;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)I9&$@)7,@)7,M<W1=(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E]!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")(86QD=7,B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@
M(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?
M1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED(")?
M1&5L971E(%)O=R(*;7-G<W1R(")+=7-T=71A(@H*(SH@;&EB+V%P:2YP:'`Z
M,3,S"B,L(&9U>GIY"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(D=R=7!I9"(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z
M>GD*;7-G:60@(E](96QP(@IM<V=S='(@(D%B:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B
M7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO
M9R!I;B(*;7-G<W1R("),;V=I('-I<W-E(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B
M"FUS9W-T<B`B3&]G:2!VY&QJ82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-
M96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@
M(DCDY&QE<W1U<R(*"B,Z(&QI8B]A<&DN<&AP.C$S-PHC+"!F=7IZ>0IM<V=I
M9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(DQO860B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z
M>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")%96UA;&1A('!A
M87(B"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0HC+"!F=7IZ>0IM<V=I9"`B7U5S
M97)S(@IM<V=S='(@(DMA<W5T86IA9"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B06%D<F5S<VED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY
M"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L
M('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN
M<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M
M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T
M:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M
M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM
M<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R(")096%L:VER:2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*
M;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S
M=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G
M:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PHC
M+"!F=7IZ>0IM<V=I9"`B;&EN97-=(@IM<V=S='(@(E!E86QK:7)J860B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*
M;7-G<W1R(").:6UI(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM
M<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I
M;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS
M9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N
M(&1E;FEE9"(*;7-G<W1R("),;V%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*
M(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")(;VEA='5S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E
M<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*
M;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")S=&5A9'DB"FUS
M9W-T<B`B3&]E(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*
M;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES
M=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O
M<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T
M<B`B26=A;"!S:7-S96QO9VEM:7-E;"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I
M9"`B=D-A<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N
M8V]M(@IM<V=S='(@(B(*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&\O9F%?25(N<&\`````````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,3`P-3,P,P`Q,#0Q-S,V,S`P,0`P,38S-#0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R!(
M;W)D92!097)S:6%N('1R86YS;&%T:6]N<RX*(R!4:&ES(&9I;&4@:7,@9&ES
M=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@
M<&%C:V%G92X*(R`*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&EG:"!#;VYC:6P@
M;V8@26YF;W)M871I8W,@*'=W=RYS:&-I+FER*0HC(%!R;W9I9&5D(&)Y("!!
M;6ER:V%B:7(@365T86YE='=O<FMI;F<@3'1D+"`R,#`T(#QP97)S:6%N+6AO
M<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*(R!-;VAS96X@3F%D97(M0F%D<B`@
M("`@("`\;F%D97)I0&UE=&%N971W;W)K:6YG+F-O;3X*(R!#:&%C:V%M96@@
M36]R=&5Z86YI82`@("`\;6]R=&5Z86YI84!M971A;F5T=V]R:VEN9RYC;VT^
M"B,@4V%L;6%N($YI:W-E9F%T("`@("`@("`@/&YI:W-E9F%T0&UE=&%N971W
M;W)K:6YG+F-O;3X*(R!(86UE9"!':&5Y8FD@("`@("`@("`@("`\9VAE>6)I
M0&UE=&%N971W;W)K:6YG+F-O;3X*(R!686AI9"!':&%F87)P;W5R("`@("`@
M("`\9VAA9F%R<&]U<D!M971A;F5T=V]R:VEN9RYC;VT^"B,@6F%H<F$@06AM
M861I("`@("`@("`@("`@/&%H;6%D:4!M971A;F5T=V]R:VEN9RYC;VT^"B,@
M"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D
M92`S(%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R
M*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#<M,#@@,34Z,C<K
M,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.D%M:7)K86)I<B!-971A;F5T=V]R
M:VEN9R!L=&0N(#QP97)S:6%N+6AO<F1E0&UE=&%N971W;W)K:6YG+B(*(F-O
M;3Y<;B(*(DQA;F=U86=E+51E86TZ(%!E<G-I86X@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#U55$8M.%QN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O
M*2(*;7-G<W1R("(@*-BQV8C8LB#9@MBHV80@)7,I(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(HVJG9A-N,V*\@V*_8L]BJ
MV+'8L]N,("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(H
MV*_8L2`E<R#8L=F(V+(I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("C8I]F%V+'9B-BR*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M
M;W)R;W<I(@IM<V=S='(@(B`HV8'8L=BOV*<I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@
M(B`HV*_;C-BQV8C8LBDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G
M<W1R("(@V*_8L2`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BVXS:J2#8M-BGV*[9AR#9AMN,V+/8JB(*
M"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM
M<V=S='(@(B<E<R<@V*?9AMBJV*[8I]BH(-F%V+G8JMBHV+';C"#9AMN,V+/8
MJB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R#8
MK]BQ(-BQV*S;C-BSV*K8L2#9A]F(V+'8KR#9OMN,VJG8L=BHV8;8K]N,(-F&
MV+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N
M9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(G)7,G(-BGV*S8L=BG(-JIV8;9
MAMBOV8<@V*_8L=BNV*H@V;[;C-BOV*<@V8;8M-BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S
M7"(@V*C9AR#:K]BQV8C9A^*`C-F'V*?;C"#8L]BGV878I]F&V8<@V*?8MMBG
MV8'9AR#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(-BHV8<@
MV+/8I]F%V*?9AMF'(-F%V*S9B-BRXH",V8?8IR#8I]BVV*?9@=F'(-BTV*\B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB(-BGVXS8K-BGV*\@
MV8;8M-BOV8<@V*C9B-BO.B`E<RXB"@HC(`HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@
M)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"(-BGV+/8
MJMF!V*?8K]F'(-BTV*_9AR#8I]BR("4N,F9-0B#9A=BLV*?8LB`H)2XR9DU"
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(-F(
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B
MV*?8L]F%(-BQV878LB#8M-F%V*<@)60@V+'9B-BR(-BOVXS:K]BQ(-F%V+G8
MJMBHV+$@V*?8L]BJ+B(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C
M87-T(@IM<V=S='(@(MF^VXS8M,*MV*C;C-F&VXP@)60MV+'9B-BRV8<B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2#8JMF(V*S9
MAR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(MBG
MV*O8L2#8I]F&VJ_8M-BJ("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("+:
MJ=N,V839B-BHV*?;C-BJ("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@V+G9
MA=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,("T@V*K8H]N,VXS8KR(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(@
MV+'8I]F')B-X,C`P8SO8I]F&V*_8I]BRVXP@)7,@(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(-BKV*C8JB#9AMBGV84B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(MBTV+'9
MB-BW(-BJV8C8I]F!V8(@)7,B"@HC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B)7,@V*?8LB#9@MBHV80@V879B-BLV8C8KR#8
MI]BSV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R
M("(E<R#8K]BQ("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@
MV*+9A=BGV*_9AR#8I]BLV+'8I]N,(-BYV879A-N,V*?8JB#9AMJOV8?8K]BG
MV+';C"#8I]F&V*K8KMBGV*@@V+38K]F'(-BGV+/8JBX@V*S8N=BHV8<@V8?8
ML2#8N=F%V83;C-BGV*K;C"#8L=BG(-JIV8<@V8?9A2#8I]JIV8;9B-F&("(*
M(MF%VXSB@(S8KMF(V*?9A]N,V*\@V*?8K-BQV*<@VJG9AMN,V*\@V+G9A-BG
MV878JB#8J-BRV8;;C-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G
M<W1R("(E<R#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*HB"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!M:6YU=&5S(@IM<V=S='(@(B5S(-BOV8+;C-F"V8<B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@V;[;C-BOV*<@
MV8;8M-BO(@H*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R
M("(E<R#8J-F'("5S(-BGV+(@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@
M0F]O:R(*;7-G<W1R("+:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`BV*K9@MF(VXS9A2`E<R(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R=S($YO
M=&5P860B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(MF!V8?8
ML=BSV*H@V8C8N-BGVXS9@2`E<R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG
M("(*;7-G<W1R("+8C"#8J-BGV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`BV(P@V*C8I]BO
M("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@
M(MB,(-F%V*K8NMN,VXS8L2#8I]BR("5S(-BHV8<@)7,B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T
M("TM(@IM<V=S='(@(B#8I]F&V*K8KMBGV*@@(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("+9@MBG
MV838J"#;L=NR(-BSV*?8N=BJVXPB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(MF"V*?9A-BH(-NR
MV[0@V+/8I]BYV*K;C"(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X
M"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("+;LMNT(-BSV*?8N=BJV8<B"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED
M("(\4')E=FEO=7,B"FUS9W-T<B`BV+79@=BMV8<@V8+8J-F$VXPB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("+;C-JI
M(-F^V+38JMN,V*C8I]F&(-BOV*?8K]JOV*?9AB#8J-BQV*?;C"#8I]N,V88@
MV*C9A-BGVJD@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D(@IM<V=S='(@(MN,VJD@V*[8M]BGVXP@V*S8K]N,(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+;C-JI(-JIV83;
MC-BO(-BYV879B-F%VXP@4$=0(-BHV+'8I]N,(-BQV878LMBHV8;8K]N,(-N,
MVJD@V;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*HB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+B(*;7-G<W1R("+;C-JI(-JIV83;C-BO(-BYV879B-F%VXP@4$=0
M(-BHV+'8I]N,(-BHV*?8LMBHVXS9AMN,(-N,VJD@V;[;C-BZV*?9A2#8I]F%
MV+;8I]BA(-BTV*_9AR#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*HB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS
M9W-T<B`B(@HBVXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,V(P@VXS:J2#:J=F$
MVXS8KR#8KMBUV8C8M=N,(%!'4"#9B"#;C-JI(-BYV*C8I]BQV*H@VJ_8L-BQ
M(-BHV+'8I]N,(-BQV878LMJOV+38I]N,VXP@VXS:J2#9OMN,V+K8I]F%(-F%
MV8C8L=BO("(*(MF&VXS8I]BR(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B+;C-JI(-JI
MV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@
M4$=0(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V*?9A=BV
MV*?8H2#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@(@HBV8;;C-BGV+(@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B+;C-JI(-JIV83;C-BO(-BYV879
MB-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@4R]-24U%(-F((-N,
MVJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V+'9A=BRVJ_8M-BGVXS;
MC"#9OMN,V+K8I]F%(-F%V8C8L=BO("(*(MF&VXS8I]BR(-BGV+/8JB(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B
M"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G
M92XB"FUS9W-T<B`B(@HBVXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,V(P@VXS:
MJ2#:J=F$VXS8KR#8KMBUV8C8M=N,(%,O34E-12#9B"#;C-JI(-BYV*C8I]BQ
MV*H@VJ_8L-BQ(-BHV+'8I]N,(-BGV878MMBGV*$@VXS:J2#9OMN,V+K8I]F%
M(-F%V8C8L=BO("(*(MF&VXS8I]BR(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(MN,VJD@VJG9A-N,V*\@V+G9A=F(V87;C"!3+TU)344@V*C8L=BGVXP@
MV+'9A=BRV*C9AMBOVXP@V;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,V*?8LB#8
MI]BSV*HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`BV*?8J-BQ
MV8?8IR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(MBHV*?8L=BGV88@
MV+/8J-JI(-BUV*C8K=JOV*?9A]N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B
MV*C8I]BQV*?9AB#8M=BHV*W:K]BGV8?;C"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM
M<V=S='(@(MBQVJ_8J-BGV+$@V+78J-BMVJ_8I]F'VXPB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(MBJVJ_8L=JO(-BUV*C8K=JOV*?9A]N,(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM
M<V=S='(@(MBUV*C8K2_8N=BUV+$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("+8K]BQ
MV*C8I]BQV8<@V*?;C-F&(-F(VXS8L=BGV+/8JMBGV+$B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B
MV*_8L=BHV*?8L=F'+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(MF^
MV*?;C-N,V88@V878M]F$V8(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B
MV8C8L]BW(-F%V+?9A-F"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("+8I]N,V*S8I]BO(-BTV*?8KMF'(%9&4R#9A=BL
MV8C8LB#8K]BSV*K8L=BSVXP@V8;8K]BGV+'8KR(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N(@IM<V=S='(@(MBGVXS8K-BGV*\@V;[8L=F(V8;8
MK]F'(%9&4R#9A=BLV8C8LB#8K]BSV*K8L=BSVXP@V8;8K]BGV+'8KR(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ(-BMV+/8I]BH(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W
M;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*W8L]BGV*@B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G
M:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("+8K=BSV*?8J"#9A=BSV*_9
MB-BO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B
M06-C;W5N=&EN9R(*;7-G<W1R("+8K=BSV*?8J-BOV*?8L=N,(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQ
MV*_9AB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`BV*?8MMBG
MV8'9AR#:J=BQV*_9AB#:K]BQV8C9AR#9@=BQV+G;C"(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T
M<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BLV8C8LB#9@=BQV+G;C.*`C"(*
M"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R
M93HB"FUS9W-T<B`BV*?;C-F&V*S8IR#8I]BVV*?9@=F'(-JIV88Z(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9
MAB#:K]BQV8C9AR#8K-BOVXS8KR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM
M<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(MBGV+;8I]F!V8<@
MVJG8L=BOV88@V878K-F(V+(@V*S8K]N,V*\B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B
MV*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI(-JOV+'9B-F'(-F!V+'8N=N,(-BH
MV8<@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@7"(E<UPB(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@VXS:J2#9
MA=BLV8C8LB#9@=BQV+G;C"#8J-F'(%PB)7-<(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`BV*?8MMBG
MV8'9AR#:J=BQV*_9AB#;C-JI(-JIV*?8L=BHV+$@V*S8K]N,V*\Z(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I
M9"`B061D(&-O;'5M;B(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(-BS
MV*K9B-F&(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS
M-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(MBGV+;8I]F!V8<@
MVJG8L=BOV88@V*?8N=BVV*?;C"#8K-BOVXS8KR(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(MBG
MV+;8I]F!V8<@VJG8L=BOV88@V++9B-BL(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(-BGV+;8I]F!V8<@
MVJG8L=BOV88@VJ_8LMN,V8;:K]BGV88@)7,@V*C8N=F&V8C8I]F&(-F&V8C8
MI]BQ(-BLV*?9AMBHVXP@V879B-BRVXS9A-BG(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D
M<F5S<R!B;V]K.B(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(-BHV8<@
MVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,Z(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D
M<F5S<R!B;V]K(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@V*C9AR#:
MJ=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#9A=F&(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(MBGV+;8I]F!V8<@V8/8
ML=BOV88@VJG8I]BQV*C8L2(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C<Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"B(G)7,G(-BH
MV8<@V+/8I]F%V*?9AMF'(-BGV+;8I]F!V8<@V+38K]B,(-BGV878IR#9AMF%
MVXSB@(S8JMF(V*?9AB#8I]BWV838I]BYV*?8JB#8K]N,VJ_8L2#8I]F!V*K8
MJMBGV*T@V*W8L]BGV*@@V+'8IR#8I]BVV*?9@=F'(-JIV+'8KR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z('-I9VYU<"YP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N
M;W<N(@IM<V=S='(@(B<E<R<@V*C9AR#8L]BGV878I]F&V8<@V*?8MMBGV8'9
MAR#8M-BO+B#8I]JIV8;9B-F&(-BTV878IR#9A=N,XH",V*K9B-BGV8;;C-BO
M(-F(V*?8L=BO(-BTV8C;C-BO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQV*?9AB#9
M@=BYV*?9A"#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q
M"FUS9VED(")!9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM
M<V=S='(@(MJIV*K8I]BHVH;9A]F4(-BBV*_8L=BS("(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!
M9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*
M;7-G<W1R("+8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'+2#8JMBYVXS;C-F&
M(-F%V*S9B-BRV8?8I]N,(-JIV*?8L=BHV+'8I]F&(-BOVXS:K]BQ(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(MBSV+'9OMBQ
MV+/8JMN,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I
M9"`B061S(@IM<V=S='(@(MBJV*C9A-N,V+K8I]BJ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@HC
M+"!F=7IZ>0IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`BV+/8I]BRV878
MI]F&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*;7-G
M<W1R("+9A=BYV*?8K]F$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B
M06QG97)I82(*;7-G<W1R("+9A=BYV*?8K]F$(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS
M9W-T<B`BV878N=BGV*_9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@
M(MBJV+'8I]BR(-JIV+'8K]F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R
M("+8JMBQV*?8LCHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G
M:60@(D%L;"(*;7-G<W1R("+9A]F%V8<B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U
M"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("+8JMF%
MV*?9A=N,(-JIV*?8L=BHV+'8I]F&(-BJV*/;C-N,V*\@V+79A-BGV*W;C-BJ
M(-BTV*_9AR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S
M+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`BV8?9A=F'(-JO
MV+'9B-F'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM
M<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(MF'V879AR#9A=BLV8C8
MLN*`C-F'V*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R
M("+9A]F%V8?9E"#:AMF'V*?8L2#8L]F%V*HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,B"FUS9W-T<B`BV*?8K-BGV++9AR#:AMF&V*\@V*+8K]BQV+/;C"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(MBBVXS8IR#8I]BL
MV*?8LMF'(-BJV8;8N-N,V84@V8;9B-BY(-F!V8?8L=BSV*H@V878L=BJV*@@
MV*_8I]BOV8<@V+39B-BOV)\B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S
M='(@(MBGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G
M:6XB"FUS9W-T<B`BV8C8L=F(V*\@24U34"#8K-BGVXS:K]BRVXS9AB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@24U34"#8K-BG
MVXS:K]BRVXS9AB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(MF&V*?9A2#:
MJ=BGV+'8J-BQVXP@24U34"#8K-BGVXS:K]BRVXS9AB(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@
M861D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(
MV8;;C-JI(-BLV*?;C-JOV++;C-F&(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`BV*?9
MA-JOV8CB@(S9A]BGVXP@V*S8I]N,VJ_8LMN,V88B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("+9A=BJV88@V*S8I]N,VJ_8
MLMN,V88Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("+;C-JI(-F%V8+8
MK]BGV+$@V8;8I]BOV+'8L]BJ(-BJV+G;C-N,V88@V+38K]F'(-BHV8C8KR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@
M(MN,VJD@V*[8M]BGVXP@V*S8K]N,(-BQV*X@V*_8I]BOV8<@V*?8L]BJ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@
M(MF^VXS8M-JIV*?8L2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`BV;[8I]BSV*XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G
M<W1R("+8J-BQV8;8I]F%V8?9E.*`C"#:J=BGV+'8J-BQV*_;C"(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES
M="(*;7-G<W1R("+9@=F'V+'8L]BJ(-BHV+'9AMBGV879A^*`C-F'V*?;C"#:
MJ=BGV+'8J-BQV*_;C"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*
M;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("+8J-BQV8;8
MI]F%V8<@V*+9A=BGV*_9AR#8I]BSV*HB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM
M<V=S='(@(MBGV+G9A=BGV80@V*C8L2#8L=F(VXP@V*?8M-BJV+'8I]JIV8?8
MI]N,(-F!V+'8N=N,(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`BV*K8M=F(VXS8J"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I
M9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("+8I]F&V*_8I]BRV8<@V*K9
M@MBQVXS8J-N,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(MBBV8C8L=N,V80B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD
M;W=S+3$R-38I(@IM<V=S='(@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I
M;&4@4VEZ92(*;7-G<W1R("+8I]F&V*_8I]BRV8<@V;[8L=F(V8;8K]F'(-BB
MV+'8M-N,V8@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I
M9"`B07)C:&EV92!.86UE(@IM<V=S='(@(MF&V*?9A2#8HMBQV+3;C-F((@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("+8
MHMN,V*<@V+39A=BG(-F%V+?9A=BFV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8
MI]F'VXS8KR#8I]BWV838I]BYV*?8JB#8I]F!V*K8JMBGV*T@V*W8L]BGV*@@
M)7,@V+'8IR#9OMBGVJD@VJG9AMN,V*_8GR(*"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB
M)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(MBBVXS8IR#8M-F%
MV*<@V878M]F%V*;9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO("<E
M<R<@V8@@V*K9A=BGV84@V++;C-BQ(-JOV+'9B-F'XH",V8?8I]N,V+0@V+'8
MIR#8K=BPV8$@VJG9AMN,V*_8GR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N
M=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;FEA;B`H05)-4T-)
M22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T
M(@IM<V=S='(@(MF'V8;8L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G
M:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA
M+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("+8HMN,
MV*<@V8+8J-F$(-BGV+(@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(-BH
MV+'8I]N,(-BJV*/;C-N,V*\@V*+9AB#8L]BFV8C8I]F$(-BTV8C8K]B?("(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG
M;FUE;G0@8V]L=6UN<R(*;7-G<W1R("+8I]F&V*K8L]BGV*@@V+/8JMF(V8;9
MA]BG(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(MBSV+G;
MC"#8K]BQ(-BMV+#9@2#:K]BQV8C9A]N,(-BTV*_9AR#8I]BSV*H@VJG9AR#9
MA=F(V*S9B-BO(-F&VXS8L]BJ(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`BV+/8N=N,(-BOV+$@V*W8L-F!(-F%V*S9
MB-BRVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BSV*HB
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(MBS
MV+G;C"#8K]BQ(-F(VXS8L=BGVXS8M"#9A=BLV8C8LMN,(-BTV*_9AR#8I]BS
MV*H@VJG9AR#9A=F(V*S9B-BO(-F&VXS8L]BJ(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(MBSV+G;C"#8K]BQ(-F(VXS8L=BG
MVXS8M"#8I]BTV*K8L=BGVJG;C"#8M-BOV8<@V*?8L]BJ(-JIV8<@V879B-BL
MV8C8KR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V
M"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(N*`C-F(VXS:F-JOVXS9A]BG
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*
M;7-G:60@(D%U9W5S="(*;7-G<W1R("+8HMJOV8C8L]BJ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*(RP@
M9G5Z>GD*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`BV*+:K]F(V+/8JB(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?8WER<W%L.B#8J-BSV+<@V879B-BQV*\@V8;;C-BG
MV+(@24U!4"#9OMN,V*_8IR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B
M075T:%]C>7)S<6PZ(-BSV*?9A=BGV8;9AR#9OMBTV*K;C-BHV*?9AB#9@MBG
MV*C9A-N,V*K9A]BGVXP@V879B-BQV*\@V8;;C-BGV+(@V+'8IR#9AMBOV*?8
ML=BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS
M9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&AI;7`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,
MV*?8LB!)34%0(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R(")!=71H7V9T<#H@
MV*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($944"#9OMN,V*_8IR#9AMBTV*\B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]I;7`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!)
M34%0(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z(-BHV+/8
MMR#9A=F(V+'8KR#9AMN,V*?8LB!K<F(U(-F^VXS8K]BG(-F&V+38KR(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H
M7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM
M<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@V*C8L]BW(-F%V8C8L=BO(-F&
MVXS8I]BR($Q$05`@V;[;C-BOV*<@V8;8M-BO(@H*(R`*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"B)!=71H7VQD87`ZV*?8
MMMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8
ML]BJ+B#8I]N,V88@VH;;C-BRVXP@V*?8L]BJ(-JIV8<@VJG8I]BQV+/8I]BR
M(-JOV8'8JMF'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#K8K=BP
MV8$@VJG8I]BQV*C8L2`E<R#9A=F%VJG9AB#9AMN,V+/8JB`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G
M<W1R(")!=71H7VQD87`ZV*C8L=F(V++8L=BSV*?9AMN,(-JIV*?8L=BHV+$@
M)7,@V879A=JIV88@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS
M9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B#8J-BSV+<@V879B-BQV*\@V8;;
MC-BGV+(@34-!3"#9OMN,V*_8IR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7W-M8F%U=&@Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!S;6)A=71H(-F^
MVXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I
M;&5D(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,V9'8JB#9AMBGV879B-F!
MV9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9
MB-N,V9'8JB#9AMBGV879B-F!V9'9@B#8J-F(V*\N("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`BV*K8
MM=BOVXS9@B#9A]F(VXS9D=BJ(-BGV+(@V+?8L=F!(-JIV*?8L=BSV*?8LB!2
M041)55,@V+'8KR#8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("+8JMBUV*_;C-F"(-F'V8C;C-F1V*H@
MV*_8L2#:J=BGV+'8L]BGV+(@1E10(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR`B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,V9'8JB#8K]BQ(-JIV*?8L=BS
MV*?8LB!&5%`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO("(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z
M(@IM<V=S='(@(MF!VXS9A-BOV8?8I]N,(-F"V*?8J-F$(-BOV+/8JMBQV+/;
MC#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U
M<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T
M<B`BV;[8L^*`C-BRV87;C-F&V8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R
M(@IM<V=S='(@(MBQV8;:KR#9OMBSXH",V++9A=N,V8;9AR(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O
M<R!P87-S=V]R9"XB"FUS9W-T<B`BV*?8L]F%(-BQV878LB#9AMBGV*_8L=BS
MV*H@:V5R8F5R;W,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(MF&
MV*?9A2#:J=BGV+'8J-BQ(-F&V*?8K]BQV+/8JB!K97)B97)O<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC
M+"!F=7IZ>0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("+8K=BGV+3;C-F'(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/
M+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(MBTV*?8KMF'(-JOV+'8I]F!VXS:J=N,(-F%V*C9AMBGVXP@)R5S)R#;
MC-BGV8'8JB#9AMBTV*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@
M(MBNV+<@V878J-F&V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F5L:7IE(@IM<V=S='(@
M(MBNV+<@V878J-F&V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"
M96YI;B(*;7-G<W1R("+:K]BQV*_9A]F%V*?;C-N,(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M:'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I
M;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BV*C9A-F(VJD@7"(E<UPB
M(-BGV+(@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@7"(E<UPB(-N,
MV*?9@=BJ(-F&V+38KR(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`BV*K9AMBXVXS9
MA=BGV*H@V*C9A-F(VJDB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`BV8;9B-BY(-BHV839
MB-JI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX"FUS9VED(")";VQD(@IM<V=S='(@(MBSVXS8I]F'(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`BVH;9
MB-BH(-BGV839@2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R("+9A-BH
MV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("+9OMF'V8;8
MI]N,(-F$V*C9ASHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(MF$
MV*C9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE
M<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("+9A]BQ(-BOV8@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O
M='1O;2(*;7-G<W1R("+9OMBGVXS;C-F&(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY
M"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`BV8;8I]F%V8<@V*?9A-JIV*K8L=F(
MV8;;C-JIVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B
M"FUS9W-T<B`BV83;C-BSV*H@V*C9B-F$V*KB@(S8K]BGV+$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B
M0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*
M;7-G<W1R("+9AMF"V*?8MR#8JMF(V++;C-BY($-23"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I
M9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+8KMBUV8C8M=N,V*?8
MJB#8L]F$V8C9A"XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C,*(RP@9G5Z>GD*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP
M;&5T960N(@IM<V=S='(@(MF!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-F%V+38
MKMBU(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX
M-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE
M;F1A<B(*;7-G<W1R("+8JMF"V8C;C-F%(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R("+8HMBQV*?9
MA2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("+9
MA=BOVXS8L2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS
M9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+9AMF%VXSB
M@(S8JMF(V*?9AB#8I]BSV84@V+'9A=BR(-BQV*<@V*C8M]F(V+$@V*[9B-BO
MVJG8I]BQ(-BOV8C8J-BGV+'9AR#8J-BGV++9AMBTV*?9AMBOV(P@V*C8IR#8
ML]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BNV8C8KR#8JMF%V*?8LR`B"B+8
MJ-JOVXS8L=N,V*\B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE
M(%PB)7-<(B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9
MB-F&V*_9AR!<(B5S7"(@V8;9B-BTV*HB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO
M;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*C9
MAR#:J=BGV+'8L]BGV+(@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#9A=BJ
MV+79A"#8M-BO.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@
M7"(E<UPB(-BQV*<@V*C8I]BR(-JIV+'8KR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z
M>GD*;7-G:60@(D-A;F%D82(*;7-G<W1R("+8JMF"V8C;C-F%(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BV*?9AMBUV+'8I]F!
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+8I]F&V+78L=BGV8$@
MV*?8LB#8I]BQV+/8I]F$(-JOV++8I]BQV+0B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#9OMBQV8C9AMBOV8<@7"(E<UPB(-BQV*<@V*W8L-F!(-JIV+'8KR`@(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*
M;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@VXS:J2#8M-BGV*[9AR#9A=F(V8+8
MJB#9OMN,V*_8IR#:J=BQV*\B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-BHV*_9B-F&(-F^V*?8L=BGV878JMBQ("?9OMBQV8C9AMBO
MV8<@V879@MBUV*\G(-BGV*_8I]F%V8<@V*_8I]BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!<(B5S7"+8L=BG(-BMV+#9@2#:
MJ=BQV*\@(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ
M,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K=BPV8$@V8;9
MA=F(V*_8C"`E9"#9@=BQV++9AMBO(-F%V8C8K-F(V*\@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED
M("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E
M9"XB"FUS9W-T<B`B(@HBV8;9A=N,XH",V*K9B-BGV88@V*_9B-BHV*?8L=F'
M(-F%V+'8JMBH(-F&V879B-BOV(P@V*C8L=BNVXP@V*?8LB#9B-BQV8C8K]N,
MV8?8I]N,(-F!V+'8I]F'V84@V+38K]F'(-BHV+'8I]N,(-F%V+'8JMBH(-BS
MV*?8LMN,(-BHV*<@(@HBV+39A=BGV+'9A^*`C-F'V*?;C"#8L-BNVXS8L=F'
M(-BTV*_9A]B,(-BSV*?8LMJOV*?8L2#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-BZV*?9A2#8L=BG(-BHV8<@
MV+39A=BGV+'9AR#8JMBYVXS;C-F&(-BTV*_9AR#:K]BPV+$@V*_8I]BO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(MBYV8;9B-BGV88B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@
M(D-A<G)I97(B"FUS9W-T<B`BV*W8I]F%V80B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G
M<W1R("+:K]BQV8C9A^*`C-F'V*<@V8@@V*C8L=J&V+/8J-F'V*<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I
M9"`B0V5L;"!0:&]N92(*;7-G<W1R("+9A=F(V*C8I]N,V80B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS
M9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BV*[8M=F(V+7;C-BGV*H@
MV+/9A-F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("+9@=BG
MV+79A-F'(-BSV839B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S
M(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BSV839B-F$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E
M;&P@<W!A8VEN9SHB"FUS9W-T<B`BV8'8I]BUV839A^*`C-JOV+#8I]BQVXP@
MV+/9A-F(V80B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"FUS
M9VED(")#96QL<&AO;F4B"FUS9W-T<B`BV879B-BHV*?;C-F$(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM
M,30I(@IM<V=S='(@(D-E;'1I8R`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I
M9"`B0V5N=&5R(@IM<V=S='(@(MF%V+':J=BR(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I
M9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N
M("A)4T\M.#@U.2TR*2(*;7-G<W1R(")#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(MBLV++8
MIMN,V*?8JB#:K]F(V*?9A]N,("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C$Q"B,L(&9U>GIY"FUS9VED(")#97)T:69I8V%T92!/
M=VYE<B(*;7-G<W1R("+8K-BRV*;;C-BGV*H@VJ_9B-BGV8?;C"`B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R
M=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`BV+/;C-BGV+/8JMF'V*?;C"#:
MK]F(V*?9A]N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D
M(@IM<V=S='(@(MF&V8C;C-BSV8<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS
M9VED(")#:&%N9V4B"FUS9W-T<B`BV*K8NMN,VXS8L2`B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A
M<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*[9B-BO(-BQV*<@V*K8
MNMN,VXS8L2#8K]F'VXS8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@
M<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B
M"B)E;6%I;',N(@IM<V=S='(@(B(*(MBJV+K;C-N,V+'8K]BGV*_9AB#9AMBG
MV84@V8@@V*+8K]BQV+/;C"#:J=F'(-BGV8'8L=BGV*\@V8?9AMJOV*?9A2#8
MKMF(V*?9AMBOV88@V8@@V;[8I]BSV*X@V*_8I]BOV88@V*C9AR#9AMBGV879
MA]F4(-BTV878IR#8KMF(V*?9A]F&V*\@(@HBV*_;C-BO("(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@
M>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E
M;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"B+8JMBZVXS;C-BQV*_8I]BOV88@V*?8L]F%(-BQ
MV878LB#8M-F%V*<@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-F!V+G9A-N,(-F^
MV+38JMN,V*C8I]F&VXP@V8;9A=N,XH",V+39B-BO+B#8J-BG(-BSV+'9OMBQ
MV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO("(*(MBJV878I]BS(-BHVJ_;C-BQ
MVXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`BV8;9B-N,V+/9AR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`BV*C8L=BQ
MV+/;C"#9OMN,V8C9AMBO+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B
M"FUS9W-T<B`BXH",(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`BV8;9B-N,V+/9AR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS
M9W-T<B`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I(@IM<V=S='(@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B
M0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@
MV*?8L]F%(-BQV878LB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(MBG
MV8;8JMBNV*?8J"#;C-JI(-F&V*?9A2#:J=BGV+'8J-BQVXPB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I
M<W!L87D@9&%T97,Z(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#:AMJOV8C9AMJO
MVXP@V8;9A=BGVXS8M"#8JMBGV+';C-BN.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G
M<W1R("+8I]F&V*K8KMBGV*@@V8;9B-BY(-BSV*C:J2#9@=F'V+'8L]BJ("C8
MJ-BQV*?;C"#9@=F'V+'8L]BJV8?8I]N,(-F%V+'8JMBH*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BV*K8N=BQVXS9@2#:J=F$V*?8
MLR`E<R#;C-BGV8'8JB#9AMBTV*\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`BV+78
MI]F!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("+9OMBG
MVJD@VJG8L=BOV88@V*K:K]F'V*?;C"!-4T]F9FEC92(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM
M<V=S='(@(MF^V*?:J2#:J=BQV*_9AB#:J=BGV+'8J-BQ(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(MF^V*?:J2#:
MJ=BQV*_9AB#:J=BGV+'8J-BQ(#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B
MV;[8I]JI(-JIV+'8K]F&(-JIV*?8L=BHV+$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM
M<V=S='(@(MF^V*?:J2#:J=BQV*_9AB#8K]BGV*_9A]F4(-JIV*?8L=BHV+$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0HC
M+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("+8J-BGV+'8
MI]F&(-BOVXS8L=F'V8;:K]BGV84B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN
M=64B"FUS9W-T<B`BV*C8L=BGVXP@V*?8K]BGV879A]B,(-JIV83;C-JI(-JI
MV8;;C-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S
M='(@(D-L:6-K871E;&P@V*?8LB#8M]BQVXS9@B!(5%10(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`BV*C8L]BJV88@V;[9
MAMBLV+'9AR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#
M;&]U9',B"FUS9W-T<B`BV*?8J-BQV8?8IR(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"B,L(&9U>GIY"FUS9VED(")#;&]U
M9',@16%R;'DB"FUS9W-T<B`BV*?8J-BQVXPB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S
M='(@(MBGV*C8L=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI
M;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R
M("+8K-F%V+D@V+38K]F&(-F&V8C8I]BQ(-JIV8;8I]BQVXPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS
M9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("+:AMF%V+D@V+38K]F&
M(-F$V*C9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#
M;VQO;6)I82(*;7-G<W1R("+8L=F&VJ\B"@HC.B!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L
M;W(B"FUS9W-T<B`BV+'9AMJO(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(MBGV8;8JMBN
MV*?8J"#:J=F&V8;8K]F'(-BQV8;:KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B
MV*?9AMBJV*[8I]BH(-BQV8;:KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("+8
ML]BJV8C9AMF'V*<Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT
M-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("+8N=F&V*?9B-N,V88@
MV+/8JMF(V8;9A]BG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V
M-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(MF%V+;8K=JI(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(MF!V+'9
MA=BGV88B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA
M;F0@4VAE;&PB"FUS9W-T<B`BV;[9B-BSV*K9AR#9@=BQV878I]F&(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM
M96YT(@IM<V=S='(@(MBJV8C8MMN,V*TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T
M<B`BV8;8I]F%(-BYV879B-F%VXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ>0IM
M<V=I9"`B0V]M;W)O<R(*;7-G<W1R("+9@=BQV*_8IR(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A
M;GDB"FUS9W-T<B`BV+38L=JIV*HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("+8L=BGVXS8I]F&V8?B
M@(S9A]BG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM
M<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(MBTV+'8MR(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(MBT
MV+'8I]N,V+<B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("+8JMF!V*?9B-BJ
MV8?8I]N,(-F^VXS:J=BQV*C9AMBOVXPB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I
M=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@
M(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(MF^VXS:
MJ=BQV*C9AMBOVXP@V*C9AR#8J-BQV8C8LMBQV+/8I]F&VXP@V8;;C-BGV+(@
MV*_8I]BQV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("+9
MOMN,VJG8L=BHV8;8K]N,("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M("+8JMBCVXS;C-BO(-BGV+/9A2#8L=F%V+(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"B,L(&9U
M>GIY"FUS9VED(")#;VYG;R(*;7-G<W1R("+8L=F&VJ\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U
M"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("+8
MI]BJV+78I]F$(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I
M;VX@9F%I;&5D.B`B"FUS9W-T<B`BV*?8JMBUV*?9A"#9AMBGV879B-F!V9'9
M@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`BV*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8
MLB#:J=F$VXS8KR#8N=F%V8C9A=N,(-BQV*\@V+38KR(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("+8I]BJV+78I]F$(-BHV8<@VJG8
MI]BQV+/8I]BR(-JIV83;C-BO(-BYV879B-F%VXP@V+'8KR#8M-BO+B#8K]F$
MVXS9A#H@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#0U"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("+8I]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR($944"#9AMBG
MV879B-F!V9'9@B#8J-F(V*\B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`BV8;9A=BGV+/9A]BG(@H*
M(R`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S
M"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BV*K9A=BGV+/9A]BG(-BHV*<@
MV879B-F!V9'9@MN,V9'8JB#8J-F'(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS
M(-BTV878IR#8I]BVV*?9@=F'(-BTV*_9AR#8J-F(V*\B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(MF%V*W8JMF(V*?;C"`G
M)7,G("(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS
M9W-T<B`BV*?8K]BGV879AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*
M;7-G:60@(D-O;VMI92(*;7-G<W1R("+:J=F(VJG;C"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I
M9"`B0V]P>2(*;7-G<W1R("+8L=F(V8;9B-BTV*HB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(MBGV*K8M=BGV80@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T
M<B`BV+'9B-F&V8C8M-BJ(-BHV+'8K]BGV+38JMF&(-BGV+(@V*C8KMBT(-BG
MV8;8JMBNV*?8J-N,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&V*\@
MV;[;C-BZV*?9A2#8L=BG(-BQV878LMBHV8;8K]N,(-JIV8;8KR!01U`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V*?9A=BVV*?8H2#:J=F&V*\@
M4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8L=F%
MV++8J-F&V*_;C"#:J=F&V*\@4R]-24U%(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AMBO(-F^
MVXS8NMBGV84@V+'8IR#8I]F%V+;8I]BA(-JIV8;8KR!3+TU)344B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A
M8W0N("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BJV878I]BSV8?8
MIR#8L=BG(-BGV+;8I]F!V8<@VJG8L=BO("5S(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BG
MV+(@3$1!4"#9OMN,V8C8L]BJ("(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR(&QD
M87`@V;[;C-F(V+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`BV8;9
MA=N,XH",V*K9B-BGV88@V*C8I]F$V*?9AMBS(-BQV*<@VH;:J2#:J=BQV*\@
M)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("+9AMF%VXSB
M@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!L9&%P(-F%V*K8M=F$(-BT
MV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E
M<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#8J-BG(-BGV+/8JMF!V*?8K]F'(-BGV+(@1E10(-BHV8<@VJG8
MI]BQV+/8I]BR("<E<R<@V8C8M=F$(-BTV*\Z("5S(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V8'9A]BQ
MV+/8JB#8JMF(V++;C-BYVXP@V*?;C-BLV*?8KR#:J=BQV*\N("5S(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I
M9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(MF&V87;
MC.*`C-BJV8C8I]F&(-BOV*?8K]F'(%!'4"#8L=BG(-BQV878LMJOV+38I]N,
MVXP@V8;9A=F(V*\@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A
M+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR!3+TU)344@
MV+'8IR#8L=F%V++:K]BTV*?;C-N,(-F&V879B-BO("(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*K9A=BGV+,@V+'8IR#8
MK=BPV8$@V8;9A=F(V*\N("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;
MC-BYVXP@V+'8IR#8K=BPV8$@V8;9A=F(V*\N("5S(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8I]BSVJG8L=N,
MV;[8JB#8J-BQV8C8LMBQV+/8I]F&VXP@V+'8I]F'XH",V*?9AMBOV*?8LMN,
M(-BQV*<@V*W8L-F!(-F&V879B-BO("<E<R<N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V*+8K]BQV+,@VJ_;C-BQV8;8K]F'(-F&V*?9A=F'V90@V*?9
MA-JIV*K8L=F(V8;;C-JIVXP@V+'8IR#8JMBTV*[;C-BU(-BOV*?8KR(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#:J=F$(-JIV*K8I]BHVH;9
MA]F4(-BBV*_8L=BS(-BQV*<@V8C8I]JIV+3;C"#9AMF%V8C8KR(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-JIV80@V8'9A]BQV+/8
MJB#8JMF(V++;C-BYVXP@V+'8IR#9B-BGVJG8M-N,(-F&V879B-BO(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D
M:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F!V8?8L=BSV*H@VJG8I]F%V80@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@
MV+'8IR#9B-BGVJG8M-N,(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#8I]BSV*K8L=BGV*K:F-N,(-BQV*<@V*C8
MI]BQ(-JIV+'8KR`G)7,G(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-BTV*?8KMF'("<E<R?8I]N,V*S8I]BO(-JIV+'8KR`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-JIV83;C-BO(-BYV879B-F%
MVXP@V+'8IR#8I]BR(-JIV*?8L=BSV*?8LB#:J=F$VXS8KR#8J-BOV+/8JB#8
MHMF(V+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F
M;W(@=W)I=&EN9RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@)R5S)R#8
ML=BG(-BHV+'8I]N,(-F&V8C8M-BJV88@V*C8I]BR(-JIV+'8KR`B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*C8I]BR(-JI
MV+'8KR(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-F%V*_9B-F$(-F(V+C8I]N,V8$@V8;:K]F'V*_8I]BQVXP@)7,@
MV+'8IR#8J-BGV+(@V8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-BTV*?8KMF'("<E<R<@V+'8IR#8J-BGV+(@V8;9A=F(V*\B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R
M96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-JIV*?8L=BSV*?8LB!,1$%0(-BQV*<@V*S8L]BJV*S9B"#:J=BQV*\B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8KMF(V*?9AMBO(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B+9AMF%
MVXSB@(S8JMF(V*?9AB#8I]BSV84@V+'9A=BR(-BQV*<@V*C8L=BGVXP@VJG8
MI]BQV*C8L2#9A=F(V+'8KR#9AMBXV+$@V*C8I]BRV8;8M-BGV8;8KRX@V*C8
MN=BVVXP@VXS8IR#9A]F%V8<@V*S8LMBFVXS8I]BJ(-F%V+'8J-F(V+<@V*C9
MAR`B"B+8HMF&(-F&V*?8K]BQV+/8JB#9A=N,XH",V*C8I]BTV*\N(-BOV8C8
MJ-BGV+'9AR#8L]BYVXP@VJG9AMN,V*\@VXS8IR#8J-BQV*?;C"#:J=F%VJD@
MV*C;C-BTV*K8L2#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*[9
MB-BO("(*(MBJV878I]BS(-BHVJ_;C-BQVXS8KR(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!!0TPB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@04-,(-BQV*<@V*_9
MB-BHV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO(@H*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O
M:RX@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@VJG8JMBGV*C:AMF'
MV90@V*+8K]BQV+,@V+'8IR#8K]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQ
MV*\N("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG
M(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-BOV8C8J-BGV+'9AR#8
MJ-BOV+/8JB#8HMF(V+'8KRX@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E
M<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#9@MBGV*C9A-N,V*K9A]BGVXP@VJG8I]BQV+/8I]BR(-BQV*<@V*_9B-BH
MV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8
ML=BHV8;8K]N,(-BQV*<@V*C8I]BRVJ_8L=BOV*?9AMBO(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#8M-BGV*[9AR`G)7,G(-BQV*<@V*W8L-F!(-F&V879B-BO("XB"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,("5S(-BQ
MV*<@V*_8KMN,V+'9AR#:J=BQV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-JIV+'8J-F&V*_;C"#9OMBTV*K;
MC-BHV*?9AB#8L=BG(-BMV8'8N"#:J=BQV*\B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-F^V+38JMN,V*C8
MI]F&(-BQV*<@V*W9@=BX(-JIV+'8KSH@)7,@(@H*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BGV+/:J=BQVXS9
MOMBJ(-BHV+'9B-BRV+'8L]BGV8;;C"#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@
MV+'8IR#8K=F!V+@@V8;9A=F(V*\Z("<E<R<N(@H*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(-F^V+38
MJMN,V*C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8IR#8K=F!V+@@VJG8
ML=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H
M92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B
M"B+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@V;[;C-JIV+'8J-F&
MV*_;C"`E<R#8L=BG(-BMV8'8N"#9AMF%V8C8KRX@V+39A=BG(-F%VXP@V*K9
MB-BGV8;;C-BO(-BGV+(@VXS:J=N,(-BGV+(@VJ_8LMN,V8;9A^*`C-F'V*<@
MV*C8L=BGVXP@(@HBV*W9@=BX(-JIV*\@V*C8L2#8L=F(VXP@)7,@V*?8L]BJ
MV8'8I]BOV8<@V8;9A=BGVXS;C-BO(-F((-N,V*<@V*?;C-F&VJG9AR#8I]BR
M(-JIV*\@V*C9AR#8M=F(V+'8JB#8K]BSV*K;C"#8K]BQ)7,@V+'9B-F&V8C8
MM-BJ("(*(MBJV8?;C-F'(-F&V878I]N,VXS8KR(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
MVJG8I]BQV+/8I]BR($Q$05`@V+'8IR#8K-BSV*K8K-F((-JIV+'8KR(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-F^VXS9B-F&V*\@)R5S)R#8L=BG(-F"V+?8N2#:J=BQV*\B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BJ
MV878I]BS("#8L=BG(-BHV+'9B-BRV+'8L]BGV8;;C"#:J=BQV*\N("5S(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9
MB-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8J-BQV8C8LMBQ
MV+/8I]F&VXP@VJG8L=BO+B`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-JIV+'8J-F&V*_;C"#8L=BG(-BH
MV+'8I]N,("<E<R<@V8;9B-BTV*HZ("5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3
M:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T
M<B`B(@HBV8;9A=N,XH",V*K9B-BGV88@V8;9B-BGV+$@V*S8I]F&V*C;C"#9
MA=F(V++;C-F$V*<@V+'8IR#9OMN,V*_8IR#:J=BQV*\N(-F%V+?9A=BFV88@
MV+39B-N,V*\@VJG9AR#9AMF(V*?8L2#8K-BGV8;8J-N,(-BHV*?8LB#8I]BS
MV*HB"@HC(`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T
M(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#8J-F'(-JIV*?8L=BHV+$@)R5S)R#8K]BSV*K8L=BSVXS9A]BGVXP@V++;
MC-BQ(-BHV+'8I]N,(-F^V8C8M-F'("<E<R<@V*_8I]BO.B`E<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X
M="(*;7-G<W1R("+9A=BJV88@V+39A=BGV+'8M"#8M-BOV8<B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R
M>2(*;7-G<W1R("+:J=BTV8C8L2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`BV*_9B-BQV8?B@(S9
MA]BG(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BV*?;C-BL
MV*?8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("+8
MI]N,V*S8I]BO(-N,VJD@V;[;C-F(V8;8KR(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O
M;F4B"FUS9W-T<B`BV*?;C-BLV*?8KR#;C-JIVXP@V*S8K]N,V*\B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B
M0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(MBGVXS8K-BGV*\@V++;C-BQ
MV;[9B-BTV8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
MV878K-F(V++9A]BGVXP@V*?;C-BLV*?8KR#:J=F&V8;8K]F'(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@
M;G5M8F5R(@IM<V=S='(@(MBTV878I]BQV8<@VJG8I]BQV*H@V*?8N=BJV*C8
MI]BQVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B0W)O871I82(*
M;7-G<W1R("+8I]N,V*S8I]BO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`BV8'8I]BR(-F!V+G9
MA-N,(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED
M(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(MF%V*S9B-BRV8?8I]N,(-BG
MVXS8K-BGV*\@VJG9AMF&V*_9AR(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS
M(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM
M<V=S='(@(MBSV*?8N=BJ(-F!V+G9A-N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R
M96YT(%523"!I<R(*;7-G<W1R(")54DP@V8'8N=F$VXP@V8?8L]BJ(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT
M(%5S97)S(@IM<V=S='(@(MF!V*?8LB#9@=BYV83;C"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R
M("+8HMBH(-F((-F'V8C8I]N,(-F!V+G9A-N,(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ
M("(*;7-G<W1R("+8M-BQV*?;C-BW(-F!V+G9A-N,.B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R
M96YT('-T>6QE(@IM<V=S='(@(MBSV*C:J2#9@=BYV83;C"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M("+8L]F!V*?8L=BTVXP@VJG8L=BOV88@V8C8N-BGVXS9@2#9A]F&VJ_8I]F%
M(-F(V+'9B-BO(-BHV8<@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R
M("+8J-BQVXS8K]F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("+8
MJ-BQVXS8K]F&(-BGV8;8JMBNV*?8J"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y
M<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM
M<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B0WER:6QL:6,@*$M/
M23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER
M:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B0WER:6QL:6,@*%=I;F1O
M=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(D-Y<FEL;&EC
M+U5K<F%I;FEA;B`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("+8L=F(V++8
MI]F&V8<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4
M<F5E($)R;W=S97(B"FUS9W-T<B`BV878L=F(V+':K]BQ(-BOV+'8KMBJ(-BO
MV*?8K]F'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I
M9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R("+8JMBGV+';C-BN
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G
M:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`BV*K8I]BQVXS8KB#8K]BQVXS8
MI]F!V*H@V+38K]F'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P
M-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BV*K8I]BQVXS8KB#8
MI]F&V*K8KMBGV*@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A
M>2(*;7-G<W1R("+8L=F(V+(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L
M=6UN(@IM<V=S='(@(MBMV+#9@2#8L]BJV8C9AB(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*
M;7-G<W1R("+8K]BSV*?9A=BHV+$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`BV*?8N=BOV*?8KR#8K]F'V*_9A]N,(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I
M9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(MJIV84@VJG8L=BOV88@V*K9
MB-BQV8'8JMJOVXPB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R
M("+9OMN,V+0@V8'8L=BV(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T
M<B`BV+'9AMJO(-F^VXS8M"#9@=BQV+8B"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM
M<V=S='(@(MF'V8C;C-F1V*H@V;[;C-BT(-F!V+'8MB(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R
M("+9OMF(V+/8JMF'V90@V;[;C-BT(-F!V+'8MB(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`BV*K8
MN=BGV+';C-F!(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(MBMV+#9@2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`BV*W8L-F!
M(-BSV839B-F$(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O
M=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("+8K=BP
MV8$@VJ_8L=F(V8<B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`BV*W8L-F!
M(-BSV+?8L2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T
M92!097)M:7-S:6]N(@IM<V=S='(@(MBMV+#9@2#9A=BLV8C8LB(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(MBMV+#9@2#9B"#9
MOMBGVJG8L]BGV++;C"#9OMN,V+K8I]F%V8?8IR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E
M;&5T92!C96QL(@IM<V=S='(@(MBMV+#9@2#8L]F$V8C9A"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G
M:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`BV*W8L-F!(-BSV*K9B-F&(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES
M=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BV*W8L-F!(-BGV83:
MK]F(VXP@V*S8I]N,VJ_8LMN,V88@V879B-BLV8C8KR(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@
M(MBMV+#9@2#9A=BLV8C8LMF'V*<@V*C8L=BGVXP@(%PB)7-<(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("+8HMN,V*<@V878K-F(V++9A]BG
M(-F((-BRVXS8L=F%V*S9B-BRV8?8IR#8J-BQV*?;C"!<(B5S7"(@V*W8L-F!
M(-BTV8C8K]B?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R("+8
MK=BPV8$@V+/8M]BQ(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT
M:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM
M<V=S='(@(MBMV+#9@2#9A]F(VXS9D=BJ(-BGV8;8JMBNV*?8J"#8M-BOV8<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS
M9W-T<B`BV*W8L-F!(-BSV*K9B-F&(-F!V+G9A-N,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(MBMV+#9@2#8L]BW
MV+$@V8'8N=F$VXPB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U
M<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(MBGV+/:J=BQVXS9
MOMBJ(-BMV+#9@2#8M-BOV8?9E"#8J-BQV8C8LMBQV+/8I]F&VXP@V*K9AMBX
MVXS9A=BGV*H@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R
M>2!T:6UE(@IM<V=S='(@(MBRV878I]F&(-BGV+'8L]BGV80B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"B,L(&9U>GIY"FUS9VED(")$96YM87)K(@IM<V=S='(@(MBJV8C8MMN,
MV*W8I]BJ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*
M;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(MBTV+'8K2#9
MA=BTVJG9A"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS
M9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("+8JMF(V+;;C-BM(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L
M<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`BV*S8LMF0V*;;C-BG
MV*HZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B#8K-BRV*;;C-BGV*H@V*C8L=BGVXP@V+/8L=F^V+'8
ML]BJ(-BSV*?9A=BGV8;9AR#8J]BHV*H@V+38K]F'(-BGV+/8JB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT
M(@IM<V=S='(@(MJOV+/8JMBQV+0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(MF&V8+8M]F'(-BTV*C9
MAMF%(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`BV8;9@MBWV8<@V+38J-F&
MV84@V*C8L=BGVXP@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B
M"FUS9W-T<B`BV8;9@MBWV8<@V+38J-F&V84Z("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO
M;B!L969T('1O(')I9VAT(@IM<V=S='(@(MBLV8?8JB#8I]BR(-J&V;X@V*C9
MAR#8L=BGV+/8JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM
M<V=S='(@(MBLV8?8JB#8I]BR(-BQV*?8L]BJ(-BHV8<@VH;9OB(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`BV+38I]BNV8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS
M9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(MBBVXS8IR#8
MLMF%V*?9AB`R-"#8L]BGV+G8JMF'(-F&V878I]N,V+0@V*_8I]BOV8<@V+39
MB-BOV)\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-F&
MV878I]N,V+0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*
M;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`BV8;9
MA=BGVXS8M"#8K-BRV*;;C-BGV*H@V;[;C-BTPJW8J-N,V8;;C"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@
M*%1!1BDB"FUS9W-T<B`BV8;9A=BGVXS8M"#9OMN,V+3"K=BHVXS9AMN,(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES<&QA
M>2!F;W)M870B"FUS9W-T<B`BV8;9A=BGVXS8M"#9@MBGV838J"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("+8K=BGV838JB#8JMBPVJG8L2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@
M9&5L971E(@IM<V=S='(@(MBMV+#9@2#9AMBTV8C8KR(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`BV*_8L]BJV+'8L]N,(-F%
MV+/8JMF"VXS9A2#8J-F'(&UA:6YT96YA;F-E+G!H<"#9A=F%VJG9AB#9AMN,
MV+/8JB(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z(@IM<V=S='(@(B(*(MBBVXS8IR#8L]BWV+$@V*?9B-F$(-BT
MV*?9A=F$(-F!VXS9A-BO(-F&V*?9A2#9A=N,XH",V*C8I]BTV*_8GR#8I]JO
MV+$@VH;9AMN,V88@V*?8L]BJV(P@V*?;C-F&(-BLV+G8J-F'(-BQV*<@V+G9
MA-BGV878JB#8J-BRV8;;C-BO.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN
M:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BV*?8L]BJV8+8L=BG
MV+$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`BV*?8
ML]BJV8+8L=BGV+$@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R
M"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+B(*;7-G<W1R("+8I]BSV*K9@MBQV*?8L2#9OMN,VJG8L=BH
MV8;8K]N,(-BJV8C9A-N,V*\@V+38K]F'(-BHV+G9AMF(V*?9AB#8K]BSV*H@
MV8;9B-N,V+,@4$A0(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P
M-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`BV8'9A]BQV+/8JB#9
MOMBGVXS;C-F&XH",V;[8L2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`BV*_8I]BQV8C9A]BG(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB
M"FUS9W-T<B`BV8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;C-JIVXPB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I
M9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@
M=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS
M9VED(")%9&ET(@IM<V=S='(@(MF(VXS8L=BGVXS8M"(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("+9B-N,V+'8I]N,
MV+0@V*C9A-F(VJDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G
M<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("+9B-N,
MV+'8I]N,V+0@VJ_8L=F(V8<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BV8C;C-BQV*?;C-BT(-F%
MV*S9B-BR(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I
M9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("+9B-N,V+'8I]N,V+0@V878
MK-F(V++9A]BG(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R("+9B-N,V+'8I]N,V+0@V878K-F(V++9A]BG(-BHV+'8
MI]N,("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B
M161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;
MC"#9B-N,V+'8I]N,V+0Z(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#9A=BL
MV8C8LN*`C-F'V*<@V*C8L=BGVXP@7"(E<UPB(@H*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+9B-N,V+'8I]N,V+0@
MV878K-F(V++B@(S9A]BG(-BHV+'8I]N,("5S(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`BV*K8K=BU
MVXS9A-BGV*HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@
M=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S
M"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(MBYV8;8M=BQ+BXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G
M:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R("+9AMBGV879AR#8I]F$VJG8JMBQ
MV8C9AMN,VJG;C"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA
M:6P@061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#9AMBGV879A]F4(-BGV83:
MJ=BJV+'9B-F&VXS:J=N,(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(MBBV*_8L=BSV8?8I]N,(-F&V*?9A=F'XH",V8?8I]N,(-BGV83:J=BJ
MV+'9B-F&VXS:J=N,(-BHV*?;C-BO(-F%V8;8M]BHV8(@V*C8I]BTV*\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+9AMBGV879A]F4(-BGV83:J=BJ
MV+'9B-F&VXS:J=N,(-BHV*<@V*K8H]N,VXS8KR(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT
M;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B"FUS
M9W-T<B`BV*?8K=BSV*?8L]BGV*HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A
M9V4N(@IM<V=S='(@(MBNV*?9A-N,(-JIV+'8K]F&(-F^VXS8NMBGV84@(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U
M,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("+8KMBGV83;C"#:J=BQ
MV*_9AB#9AMBJVXS8K-F'(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@
M(MBNV*?9A-N,(-JIV+'8K]F&(-F%V8C8I]BQV*\@V*S8L]BJV*S9B"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(MBBVXS8IR#8K]BQV*P@V*K8M=BGV8C;C-BQ(-BGV+(@VJ_8
MI]F$V+';C-F'V*?;C"#8N=JIV+,@V*_8L2#9A=BJV88@V8'8N=BGV80@V+39
MB-BOV)\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%
M;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("+8HMN,
MV*<@VJ_8LMN,V8;:K]BGV88@V++9A=N,V8;9AR#8L=F(VXP@VJG9A-N,VJD@
MV+'8I]BSV*H@V8'8N=BGV80@V+39B-BOV)\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*
M;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(MBGV8;8JMF'V*?;C"#8L]BGV80B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y
M"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("+8J-BRV+':KR#:J=BQ
MV*_9AB#9B-N,V+'8I]BSV*K8I]BQ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z(@IM<V=S='(@(B(*(MN,VJD@V+/8IMF(V*?9A"#8I]F%V8;;
MC-BJVXP@V*C8L=BGVXP@V;[8L=BSV+0@V*?8LB#8M-F%V*<@V*C9AR#9A]F&
MVJ_8I]F%(-BHV*?8LMF&V+38I]F&V*_9AB#8I]BSV84@V+'9A=BR(-F(V*?8
ML=BO(-JIV8;;C-BOV(P@V878J]F$V*?9DB`B"B(GV8;8I]F%(-BMVXS9B-BG
MV88@V*[8I]F&VJ_;C"#8M-F%V*<@VH;;C-BSV*K8GR<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*
M;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R(")54DP@
MV*K8M=F(VXS8L2#8L=BG(-BGVXS9AMBLV*<@V8C8I]BQV*\@VJG9AMN,V*\B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ
M"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS
M9VED(")%<G)O<B(*;7-G<W1R("+8KMBWV*<B"@HC(`HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`BV*C9A-F(VJD@
MV*?;C-BLV*?8KR#8KMBWV*<Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("+8KMBWV*<@V*_8
ML2#8J-BQV8C8LMBQV+/8I]F&VXP@V*?8L]F%(-BQV878LB`Z("5S(@H*(R`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*
M;7-G<W1R("+8J-F$V8C:J2#8I]N,V*S8I]BO(-BNV+?8ISH@)7,B"@HC(`HC
M.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S
M='(@(MBNV+?8IR#8K]BQ(-JIV+/8J"#9A=BMV*K9B-BG.B5S(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("+8KMBW
MV*<@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V*?8L]F%(-BQV878LB`Z("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S
M='(@(MBNV+?8IR#8J-BG(-F^VXS8NMBGV84@V8;8I]F%V8?9E"#8I]F$VJG8
MJMBQV8C9AMN,VJG;C"(*"B,@"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB
M+B(*;7-G<W1R("+8KMBWV*?;C"#9AMF(V+38JMF&("<E<R<@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`HC+"!F=7IZ>0IM<V=I9"`B17-T;VYI82(*;7-G<W1R("+8N=BJVXS9
M@MF'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS
M9W-T<B`BV+G8JMN,V8+9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(MBGV+'9B-F^V*<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M
M:6YU=&5S(@IM<V=S='(@(MF'V+$@V;[8I]F&V++8K]F'(-BOV8+;C-F"V8<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"FUS9VED(")%=F5R>2`R
M(&UI;G5T97,B"FUS9W-T<B`BV8?8L2#8K]F((-BOV8+;C-F"V8<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BV8?8L2#8
ML]N,(-BOV8+;C-F"V8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN
M=71E<R(*;7-G<W1R("+9A]BQ(-F^V8;8K"#8K]F"VXS9@MF'(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B
M179E<GD@3&]G:6XB"FUS9W-T<B`BV*_8L2#9A]BQ(-F(V+'9B-BO(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H
M;W5R(@IM<V=S='(@(MF'V+$@V8;;C-F%(-BSV*?8N=BJ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X
M"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BV8?8L2#8K]F"VXS9@MF'
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X
M86UP;&4@=F%L=65S.B(*;7-G<W1R("+9A=F"V*?8K]N,V+$@V878J]BGV80Z
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H
M<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM
M<V=S='(@(MBGV*S8L=BG(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BV*C8I]BR(-JI
MV+'8K]F&(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM
M<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`BV*C8I]BRVJG8L=BOV88@
MV8;9B-BGV+$@VJG9AMBGV+';C"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("+8
MI]F&V*K8N-BGV+$@V*C8L=BGVXP@)R@G(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D
M(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@
M1&%T92(*;7-G<W1R("+8JMBGV+';C-BN(-BGV8;9@MBVV*?8H2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O
M;F5N="(*;7-G<W1R("+9AMF%V*?;C-F&V*_9AR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'
M($-O;&]R(@IM<V=S='(@(MBQV8;:KR#9OMN,V+3B@(S8LMF%VXS9AMF'(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A
M9"!O9B!S971U<"(*;7-G<W1R(")&5%`@=7!L;V%D(&]F('-E='5P(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B(-BHV*?8LMN,
MV*?8J-N,(-BJV8+8K]F%V*?8JB#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B#8I]BJV+78I]F$(-BHV8<@
MVJG8I]BQV+/8I]BR($Q$05`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("(@V*?8JMBUV*?9
MA"#8J-F'(-JIV*?8L=BSV*?8LB!334(@V8;8I]F%V8C9@=F1V8(@V*C9B-BO
M("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G
M<W1R("(@V*K9A]N,V8<@V+'9B-F&V8C8M-BJ(-BGV+(@7"(E<UPB(-F&V*?9
MA=F(V8'9D=F"(-BHV8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BV*?;C-BLV*?8KR#8L=F(V8;9B-BT
MV*H@V*_8L2!<(B5S7"(@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(@V*?;C-BL
MV*?8KR#;C-JI(-BGV*K8M=BGV80@V*S8K]N,V*\@4T%33"#9AMBGV879B-F!
MV9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y
M-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(B#8
MI]F&V*K9@MBGV80@V*C9AR!<(B5S7"(@V8;8I]F%V8C9@=F1V8(@V*C9B-BO
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS
M9W-T<B`B(-BGV8;8JMF"V*?9A"#8J-F'(%PB)7-<(B#9AMBGV879B-F!V9'9
M@B#8J-F(V*\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("+9A-BWVXS9@2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A
M=&%L($5R<F]R.B(*;7-G<W1R("+8KMBWV*?;C"#8K-BOVXPZ("(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@
M(D9A>"(*;7-G<W1R("+9@=JIV+,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("+9@=JI
MV+,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`BV8'9B-BQVXS9AR(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G
M:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B
M"FUS9W-T<B`BV+':K]BHV*?8L2#8KMF!VXS9@2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(MJIV87;C"#8JMJOV+':KR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED
M(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M92(*;7-G<W1R("+9OMBQV8C9AMBOV8<B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE(@IM<V=S='(@(MBTV878I]BQV+0@V;[8L=F(V8;8K]F'.B`E<R#9
MOMBQV8C9AMBOV8<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G
M<W1R("+8M-F%V*?8L=BT(-F^V+'9B-F&V*_9ASH@)7,@V;[8L=F(V8;8K]F'
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL
M92!-86YA9V5R(@IM<V=S='(@(MF%V*_;C-BQ(-F^V+'9B-F&V*_9AR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")&:6QE($YA;64B
M"FUS9W-T<B`BV8;8I]F%(-F^V+'9B-F&V*_9AR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(MBGV8;8JMBNV*?8J"#9OMBQV8C9AMBOV8<B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R
M("+8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S
M=7!P;W)T960N(@IM<V=S='(@(MBGV+'8L]BGV80@V;[8L=F(V8;8K]F'(-F^
MV+38JMN,V*C8I]F&VXP@V8;9A=N,XH",V+39B-BO+BXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B
MV8';C-F$V*K8L=F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")&
M:6YL86YD(@IM<V=S='(@(MBOV+'8KMBW(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("+9AMN,V879AR#8
MI]F(V80B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(MBQV*C8
MN2#8I]F(V80B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`BV8;8L]BHV*H@
MV*O8I]BHV*HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@
M(D9L;V%T(@IM<V=S='(@(MBGV+G8M-BGV+';C"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T
M<B`BV879A^*`C-BBV839B-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS
M9W-T<B`BV;[9B-BTV8<@)7,@V879B-BLV8C8KR#9AMN,V+/8JB`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED
M(")&;VYT($-O;&]R(@IM<V=S='(@(MBQV8;:KR#9@MF$V84B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`BV+K8
ML-BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("+8J-BQV*?;C"#9A=BQV8C8L=JO
MV+'9A]BGVXS;C"#:J=F'(-BJV+78I]F(VXS8L2#8L=BG(-F^V+38JMN,V*C8
MI]F&VXP@V8;9A=N,XH",VJG9AMF&V*\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`BV;[;C-BT
MPJW8J-N,V8;;C"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW
M.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B
M"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(MBG
MV+/9A2#8L=F%V+(@V*[9B-BO(-BQV*<@V8'8L=BGV879B-BT(-JIV+'8K]F'
MXH",V*?B@(S;C-BOV)\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("+9@=BQV879A]BG(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@
M(MBWV*?9A-BY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED
M(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`BV8;9B-BY(-BWV*?9A-BY(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G
M<W1R("+8M]BGV838N=F'V*<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`BV+?8I]F$V+G9A]BG(-NR
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(MBGV8;8K-F%V8;9A]BG(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`BV*?8
ML=BLV*?8N=F'V*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("+8K-F%V+G9AR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R("+:AMBGV+':AMF(V*C9A]BG(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;F-E(@IM<V=S='(@(MJ&
MV*?8L=J&V8C8J-F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET
M;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("+8I]BR(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("+8I]BR("(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&
M=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(MBTV+'8K2#:J=BGV879A"(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V
M"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`BV878I]F'(-JIV*?9A=F$(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("+9
MAMBGV84@VJG8I]F%V80B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M(@IM<V=S='(@(MJOV*?9A-BQVXP@V*C8L=BGVXP@V*_8L=N,V*?9
M@=BJ(-BJV+79B-N,V+$@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*
M;7-G<W1R("+:K]BGV838L=N,.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I
M82(*;7-G<W1R("(B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`BV*K9B-F$VXS8KR#9OMN,VJG8L=BHV8;8K]N,("5S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G
M:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(MJIV*\@V*K9B-F$VXS8KR#8
MM-BOV8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@
M(MF&V*?9A2#8K]BGV*_9AR#8M-BOV8<B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`BV*C8L=F((@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M,C@*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(MBLV+/9
MAMBLV8C;C"#:K]F(VJ_9A"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`BV*S8L]F&V*S9B-N,
M(-JOV8C:K]F$(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(MBOV+'8K-F'
M(-BNV*?:J=BSV*K8L=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B
M1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R965K("A)4T\M.#@U.2TW
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("+8L]BQV;[8L=BSV*K;C"#:K]BQV8C9AR(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB"FUS9W-T<B`BV8;8I]F%(-JOV+'9B-F'(-F&V*C8I]N,V*\@V*[8I]F$
MVXP@V*C8I]BTV*\B"@HC(`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L9&%P.MBGV+;8I]F!
MV8<@VJG8L=BOV88@VJG8I]BQV*C8L2`E<R#9A=F%VJG9AB#9AMN,V+/8JBX@
MV*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JIV*?8L=BSV*?8LB#:K]F!
MV*K9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T
M92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`ZV*C8L=F(V++8L=BSV*?9
MAMN,(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BSV*HB"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B075T:%]L9&%P.MBHV+'9B-BRV+'8L]BGV8;;C"#:J=BGV+'8J-BQ
M("5S(-F%V87:J=F&(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G
M<W1R("+:K]BQV8C9AR8C>#(P,&,[V8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U
M86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"B,L
M(&9U>GIY"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("+8LMN,V+'9OMN,V+'8
MI]F'V8;;C"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(MF%V*S9B-BRV8?8I]N,(-F%V8?9A=BGV88B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S
M=&)O;VLB"FUS9W-T<B`BVJG8JMBGV*C:AMF'V90@VXS8I]BOV*C9B-BO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(MJ8
MV8C8IMF&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-
M3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM
M<V=S='(@(DA434Q!<F5A(-BMV+#9@2#8HMBNV+';C-F&(-BSV839B-F$(-BQ
MV*<@V*_8L2#8L=BOVXS9@2#8L=BO(-F%VXSB@(S:J=F&V*\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(-BMV+#9
M@2#8HMBNV+';C-F&(-BSV*K9B-F&(-BQV*<@V*_8L2#8K-BOV8C9A"#8L=BO
M(-F%VXSB@(S:J=F&V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM
M<V=S='(@(DA434Q!<F5A(-BMV+#9@2#8HMBNV+';C-F&(-BQV*_;C-F!(-BQ
MV*<@V*_8L2#8K-BOV8C9A"#8L=BO(-F%VXSB@(S:J=F&V*\B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9
MB-N,V9'8JB!(5%10(-N,V*?9@=BJV8<@V8;8M-BO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"B,L(&9U>GIY"FUS9VED(")(86ET:2(*;7-G<W1R("+9AMBSV*C8JB(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`BV*?9A-JOV8C8L=N,V*K9A2!(87-H(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G
M:60@(DAA>F4B"FUS9W-T<B`BV879A^*`C-BBV839B-BO(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("+8L]BQV*+9A=BO(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F
M=7IZ>0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("+8L]BQV*+9A=BO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@(DAE879Y(%0M4W1O<FTB
M"FUS9W-T<B`B5"U3=&]R;7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R
M("+8J-F$V8;8K]N,(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N
M<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN
M9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(MBQV*?9A]F&V878IR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*
M;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(MBQV*?9A]F&V878
MI]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V8C;C-BQV*?;C-BTVJ_8L2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*
M;7-G<W1R("+:J=F%VJD@VJG9AMF&V*_9AR(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("+9AMN,V87B@(S:
MJ=BQV8<B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("+8I]N,V8;8K-BG(-BG
MV*C8JMBOV*?;C"#9OMBQV8C9AMBOV8?B@(P@V87;C.*`C-BHV*?8M-BO.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS
M9VED(")(:6=H(@IM<V=S='(@(MBHV*?9A-BG(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R
M+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R("+8KMBGV8;9AR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S
M-0IM<V=I9"`B2&]M92(*;7-G<W1R("+8KMBGV8;9AR(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!
M9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-BNV*?9AMF'(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G
M<W1R("+8M-BGV*[9A]F4(-BGV+79A-N,(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*
M;7-G<W1R("+8M-F%V*?8L=F'(-BJV839@=F&(-F%V8;8LMF$(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(MF'V8C8
ML=BO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@)7,@V*C8IR#8K]BGV*_9AR#9AMBGV*_8L=BSV*H@6$U,(-BOV+$@
MV;[;C-BZV*?9A2`E<R#9A=F(V*?8K-F'(-BTV*_9AR#8I]BSV*HB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(-F'VXS:AB#9OMN,V+K8
MI]F%VXP@V878M]BGV*C9@MBJ(-BHV*<@V+3;C-BA("5S(-F&V*_8I]BQV*\B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@V8?;
MC-J&(-BTVXS8IMN,(-BGV+(@V8;9B-BY("5S(-BOV+$@V;[;C-BZV*?9A2`E
M<R#;C-BGV8'8JB#9AMBTV*\B"@HC(`HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ("5S(%PB)7-<(B#8K=BP
MV8$@V+38KR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS
M9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U
M:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@V*K9
MB-F$VXS8KR#;C-JI(-BOV+'8KMBJ(-BLV*_;C-BO(%A-3"#8J-BQV*?;C"#8
MM-N,V*$@)7,@V879@MBOV8C8L2#9AMN,V+/8JB`B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@V*W8L-F!("5S(%PB)7-<(CHE<R#9A=F"V*_9
MB-BQ(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B#8J-BGV++;C-BGV*C;C"`@34E-12!)1"#8
MJ-BQV*?;C"#9@MBSV878JMN,(-BGV+(@V8;9B-BY("5S(-F%V8+8K]F(V+$@
MV8;;C-BSV*H@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@V+/9AMJIV+'9B-F&(-JIV+'8K]F&("5S(%PB)7-<(CH@)7,@V879@MBO
MV8C8L2#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(-BSV8;:J=BQV8C9AB#:J=BQV*_9AB#8I]BTV*K8L=BGVJG9A]BG(-F%
MV8+8K]F(V+$@V8;;C-BSV*HZ("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#8
MI]BTV*K8L=BGVJD@V8;8I]BTV8;8I]BNV*K9AR!<(B5S7"(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(
M;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BV8+8I]F&V8C9AB#8I]F!V8+;C"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*
M;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("+9@=BGV+79A-F'
MXH",VJ_8L-BGV+';C"#8I]F!V8+;C"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(CK8I]F!V8+;C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@
M9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`BVH;:K]F(V8;9
MAR#8J-BG(-BGVXS9AMBLV*<@V*+8M-F&V*<@V+38K]N,V*_8GR`HV838M]F!
MV*?9BR#:K]BRV*?8L=BT(-BOV8?;C-BO*2$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R
M("+:AMF&V*\@V+/8JMF(V88@V+'8IR#9A=N,XH",V*[9B-BGV8?;C-BO(-BG
MV*_8NMBGV84@VJG9AMN,V*_8GR(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R
M92!T:&5R93\B"FUS9W-T<B`BVH;9AMBO(-F!VXS9A-BO("C8L]BJV8C9ABD@
MV8C8K-F(V*\@V*_8I]BQV*_8GR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(MJ&V8;8KR#8
ML]BWV+$@V+'8IR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV*_8NMBGV84@VJG9
MAMN,V*_8GR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S
M='(@(MBQV+?9B-BHV*HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(MBQV+?9B-BHV*HZ
M("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I
M<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("+8I]N,V*S8I]BO(-F&V*?9A=F'XH",V*_8I]F&($E-05`@
MV8;8I]F%V8C9@=F1V8(@V*C9B-BO.B`@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+8K=BPV8$@V8;8I]F%V8?B
M@(S8K]BGV88@24U!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\@.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(MBGVXS8K-BGV*\@V878K=BOV8C8K]N,V9'8JB#9AMBGV879A^*`C-BO
MV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR`Z("5S(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*
M;7-G<W1R("+8HMBOV+'8LR!)4"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`BV*+8K]BQV+,@25`@V8+8I]BHV80@V*_8L]BJV+'8L]N,
M(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H
M<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RXB"FUS9W-T<B`BV*+8K]BQV+,@25`@V*_8L2#8K]BGV*[9A"#8
MJ-F$V8C:J2!#2412(-BGV*S8I]BRV8<@V*_8I]BOV8<@V8;9A=N,XH",V+39
MB-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S
M='(@(MBGV*C8JMBOV*<@V+/8M]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*
M;7-G<W1R("+9@=F"V+<@V*+;C-JIV8C9AMF'V*<B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O
M;G,@9F]R("5S(@IM<V=S='(@(MBBVXS:J=F(V8;9A]BG(-BHV+'8I]N,("5S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@
M=VET:"!T97AT(@IM<V=S='(@(MBBVXS:J=F(V8;9A]BG(-BHV*<@V878JMF&
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I
M='DG<R!N86UE.B(*;7-G<W1R("+9AMBGV84@V8?9B-N,V9'8JCHB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL
M("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("+8I]JO
MV+$@V*+9AB#8J-F'(-BOV+'8L]BJVXP@V8;9A=BGVXS8M"#8K]BGV*_9AR#9
MAMBTV*_8C"`E<R`@V*C8L=BGVXP@V*C8I]BR(-JIV+'8K]F&(-BBV88@V*_8
ML2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I
M8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O
M(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N
M8WDN(@IM<V=S='(@(B(*(MBGVJ_8L2#8M-F%V*<@V8?;C-J&(-BBVXS:J=F(
MV8;;C"#8L=BG(-BOV+$@V878L=F(V+':K]BQ(-F&V*C;C-F&VXS8K]B,(-F%
MV87:J=F&(-BGV+/8JB#9A-BGV++9A2#8J-BGV+38KR#:J=F'(%!.1R`B"B)4
M<F%N<W!A<F5N8WD@V+'8IR#8KMBGV879B-BT(-JIV8;;C-BO(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B
M(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(MBGVJ_8L2#8M-F%V*<@
MV*?;C-F&(-F^VXS8NMBGV84@V+'8IR#9A=BTV*?9A]BOV8<@VJG9AMN,V*\@
MV*?9A=BG(-BJV+79B-N,V+';C"#8L=BG(-F%V+38I]F'V*_9AR#9AMJIV8;;
MC-BOV(P@V*?;C-F&(-BHV8<@V*?;C-F&(-BYV838JB`B"B+8KMF(V*?9A]BO
M(-BHV8C8KR#:J=F'(-F%V+'9B-BQVJ_8L2#8M-F%V*<@V8'8I]BOV+$@V*C9
MAR#9AMF%V*?;C-BT(-BJV+79B-N,V+$@V8;;C-BSV*H@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X
M"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("+9OMN,V+3B@(S9AMF%
MV*?;C"#8JMBUV8C;C-BQ.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G
M<W1R(")54DP@V*K8M=F(VXS8L2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@
M55),.B(*;7-G<W1R(")54DP@V*K8M=F(VXS8L3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("+8JMBUV8C;C-BQ(-BG
MV+(@VJ_8I]F$V+';C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y.B(*;7-G<W1R("+8JMBUV8C;C-BQ(-BGV+(@VJ_8I]F$V+';C#HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G
M92!U<&QO860B"FUS9W-T<B`BV*?8L=BSV*?9A"#8JMBUV8C;C-BQ(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R
M("+8JMBUV*?9B-N,V+$B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E
M9"(*;7-G<W1R("+8K]BQV8C9AN*`C-BHV+'8K]B,(-JOV*?9A2`E9"(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("+9@=N,
MV838KR#8K]BQV8C9AN*`C-BHV+'8KR#8M-BOV8<Z("5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S
M.B(*;7-G<W1R("+9@=N,V838K^*`C-F'V*?;C"#8K]BQV8C9AN*`C-BHV+'8
MKR#8M-BOV8<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*
M;7-G<W1R("+8J-BYV*_8I]F+(-BSV+?8L2#8L=BG(-F(V*?8L=BO(-JIV8;;
MC-BO(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S
M='(@(MJIV*\@V+G9A=F$VJG8L=BO(-F&V*?8K]BQV+/8JB#8K]BGV*_9AR#8
MM-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(B#9AMBGV84@VJG8I]BQV*C8L2_8
MI]BSV84@V+'9A=BR("#9AMBGV*_8L=BSV*H@V*?8L]BJ(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U
M<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@HBV8;8I]F%(-JIV*?8L=BHV+$@VXS8IR#8
MHMBOV+'8LR#8K-BGVXS:K]BRVXS9AB#9AMBGV*_8L=BSV*H@V87;C.*`C-BH
MV*?8M-BO+B#9A-BWV8'8IR#9A=BLV*_8K]BGV9(@V+/8N=N,(-JIV8;;C-BO
M(-F((-N,V*<@V*_8L2#8M=F(V+'8JB`B"B+9AMN,V*?8LB#8J-F'(-JIV87:
MJ2#8J-N,V+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8
MJMF%V*?8LR#8J-JOVXS8L=N,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B
M"FUS9W-T<B`BV*?9@=BRV*?;C-BT(-BJV8C8L=F!V*K:K]N,(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("+:J=BG
MV+'8J-BQV*?9AB#8KMBGV+4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N
M97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(MBGV+?9A-BG
MV+G8I]BJ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PIM<V=I
M9"`B26YF;W)M871I;VXB"FUS9W-T<B`BV*?8M]F$V*?8N=BGV*HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("));F9O<FUA
M=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("+8I]BWV838I]BY
MV*?8JB#8K]N,VJ_8L2#8K]BQ(-BOV+/8JMBQV+,@V8;;C-BSV*HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(MBOV+'8
MK"#8L]BJV8C9AB#8J-BYV*\@V*?8LB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS
M97)T($EM86=E(@IM<V=S='(@(MBOV+'8K"#8JMBUV8C;C-BQ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(MBOV+'8K"#8K-BOV8C9A"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@
M(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("+8K]BQV*P@V;[;C-F(V8;8KR#9
MB-BH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS
M9W-T<B`BV*?8J-BJV*_8IR#8L]BJV8C9AB#8L=BG(-BOV+'8K"#:J=F&VXS8
MKR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BVXS:J2#8L]BJV8C9AB#8K-BOVXS8
MKR#8J-BYV*\@V*?8LB#8L]BJV8C9AB#9@=BYV83;C"#8K]BQV*P@VJG9AMN,
MV*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+;C-JI(-BSV*K9B-F&(-BLV*_;
MC-BO(-F"V*C9A"#8I]BR(-BSV*K9B-F&(-F!V+G9A-N,(-BOV+'8K"#:J=F&
MVXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BVXS:J2#8L]BWV+$@V*S8K]N,V*\@
MV*C8N=BO(-BGV+(@V+/8M]BQ(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(MN,VJD@V+/8M]BQ(-BLV*_;C-BO(-F"V*C9
MA"#8I]BR(-BSV+?8L2#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(MN,VJD@V;[8I]BQV*?:K]BQV*?9@2#8J-BYV*\@
MV*?8LB#:K]BQV8<@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y
M"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`BVXS:J2#9OMBGV+'8I]JOV+'8I]F!(-F"V*C9A"#8
MI]BR(-JOV+'9AR#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R("+8K]BQV*P@V*?9A-JOV8C;C"#8K-BGVXS:K]BR
MVXS9AB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN
M<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV
M92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("+;C-JI(-BBV*_8L=BS(-F^
MV+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V*C8L=BGVXP@V*_8L=N,V*?9@=BJ
M(-BGV+/9A2#8L=F%V+(@(-BLV*_;C-BO(-BOV+'8K"#:J=F&VXS8KR`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("+8K]BQV*P@
MV+/9A-F(V80@V*C8N=BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F
M;W)E(@IM<V=S='(@(MBOV+'8K"#8L]F$V8C9A"#9@MBHV80B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS
M9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(MBOV+'8K"#8L]BJ
MV8C9AB#8J-BYV*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R
M92(*;7-G<W1R("+8K]BQV*P@V+/8JMF(V88@V8+8J-F$(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R
M="!M97-S86=E<R(*;7-G<W1R("+8K]BQV*P@V;[;C-BZV*?9A2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("+8K]BQ
MV*P@V;[8I]BQV*?:K]BQV*?9@2#8J-BYV*\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN
M<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(MBOV+'8K"#9OMBGV+'8
MI]JOV+'8I]F!(-F"V*C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T
M97(B"FUS9W-T<B`BV*_8L=BL(-BSV+?8L2#8J-BYV*\@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I
M9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BV*_8L=BL(-BSV+?8L2#9
M@MBHV80B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("))
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ(@IM<V=S='(@(MF^V*?8L]BN(-F%V8C8L=BO(-F&VXS8I]BR(-BQ
MV*<@V*C8L=BGVXP@V+/8IMF(V*?9A"#8I]F%V8;;C-BJVXP@V*_8L=BL(-JI
MV8;;C-BO.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B
MV*_8L=BL+]BJV+K;C-N,V+$@V*K8M=F(VXS8L2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-
M;V1I9GD@3&EN:R(*;7-G<W1R("+8K]BQV*POV*K8NMN,VXS8L2#9OMN,V8C9
MAMBO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T
M;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(MBGV+G8JMBHV*?8
ML2#9AMBGVJG8I]F!VXP@V*C8L=BGVXP@V*?8L=BSV*?9A"#8J-F'(-F!V8?8
ML=BSV*H@V*K9B-BRVXS8N=N,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70N(@IM<V=S='(@(MBGV+G8JMBHV*?8L2#9AMBGVJG8I]F!VXPB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R
M(@IM<V=S='(@(MBYV*_8KR#8M=BMVXS8K2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("+9
M@=F'V+'8L]BJ(-BYV*_8KR#8M=BMVXS8K2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B541((-F&V*?9
MA=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T
M<B`BV*_8I]BOV8<@VXS9B-F&VXS:J=BO(-F&V*?9A=BYV*K8J-BQ("(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P
M;&EC871I;VXN(@IM<V=S='(@(MBHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8
MK]N,(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H
M($E$+B(*;7-G<W1R("+8K]BSV*K9AR!)1"#9AMBGV878N=BJV*C8L2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D
M871A('-U8FUI='1E9"XB"FUS9W-T<B`BV*_8I]BOV8?9E"#9AMBGV878N=BJ
MV*C8L2#8I]BQV*?8IMF'(-BTV*_9AR(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("+8HMBOV+'8LR#9A=F"V+78
MKR#9AMBGV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T
M<B`BV8+8I]F$V*@@V;[8L=F(V8;8K]F'V90@V8;8I]F%V+G8JMBHV+$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("+8J-BQV8;8I]F%
MV8?9E"#:J=BGV+'8J-BQV*_;C"#9AMBGV878N=BJV*C8L2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(MBHV+'9AMBGV879
MA]F4(-JIV*?8L=BHV+'8K]N,(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("+9AMF(V+D@V;[;C-BZV*?9
MA2#9AMBGV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`B87!I7VED(-F&V*?9A=BYV*K8J-BQ(-BG
MV+/8JB#9B"#;C-BG(-BGV+(@V*C;C-F&(-BQV8'8JMF'(-BGV+/8JB(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S
M='(@(MF^V*?8L=BGV878JMBQ(-F&V*?9A=BYV*K8J-BQ(-F((-N,V*<@V*?8
MLB#8J-N,V88@V+'9@=BJV8<B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(MF%V*S9B-BR(-F^V*_8L2#9AMBGV878N=BJV*C8L2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`BV878K-F(V+(@V;[8K]BQ(-F&
MV*?9A=BYV*K8J-BQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM
M<V=S='(@(MF^V+'9B-BJVJG9A"#9AMBGV878N=BJV*C8L2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I
M9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`BV;[8L=F(V*K:J=F$(-F&
MV*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z
M(%PB)7-<(B(*;7-G<W1R("+:K]N,V+'9AMBOV8?9E"#9AMBGV878N=BJV*C8
ML3H@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI
M9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`BV+3;C-BA(-BHV8<@V*?8M-BJV+'8
MI]JI(-JOV+#8I]BTV*K9AR#8M-BOV8?9E"#9AMBGV878N=BJV*C8L2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`BV*+8
MK]BQV+,@V+/8L=J&V+39A=F'(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED
M("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`BV*_8I]BOV8<@VXS9
MB-F&VXS:J=BO(-F&V*?9A=BYV*K8J-BQ("(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("+9A=F(
MV*S9B-BOVXPB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(MBH
MV+':K]BQV*_8I]F&V*_9AB#8I]F&V*K8KMBGV*@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(E0M4W1O<FUS
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES
M<W5E<B(*;7-G<W1R("+9A=F&V*K8M-BQ(-JIV8;9AMBOV8<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET
M86QI8R(*;7-G<W1R("+8K=BQV8C9@2#:J=BL(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L
M(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R("+8K=BQV8C9@2#:J=BL(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*
M86YU87)Y(@IM<V=S='(@(MJ8V*?9AMF(VXS9AR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B
M2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I
M<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@
M8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS
M9W-T<B`BV++;C-BQV;[;C-BQV*?9A]F&VXPB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("+:F-F(
MV*;;C-F'(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`BVIC9B-BFV88B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS
M9VED(")*=7-T:69Y(@IM<V=S='(@(MF'V87B@(S8JMBQV*?8LB#:J=BQV*_9
MAB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("+9A]F%
MXH",V*K8L=BGV++;C"#9B-BSV+<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&
M=6QL(@IM<V=S='(@(MF'V87B@(S8JMBQV*?8LMN,(-JIV*?9A=F$(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("+9A]F%XH",V*K8L=BG
MV++;C"#:AMF^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T
M<B`BV8?9A>*`C-BJV+'8I]BRVXP@V+'8I]BSV*H@(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I
M9VEN86P_(@IM<V=S='(@(MBGV+79A-N,(-F&VJ_9AR#8K]BGV+38JMF'(-BT
MV8C8K]B?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(MJIV*?8L=BSV*?8LB!K97)B97)O<V4@V*K8M=BOVXS9@B#9A]F(VXS9
MD=BJ(-BQV*<@V+'8KR#:J=BQV*\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R
M96%T:6]N(@IM<V=S='(@(MBGVXS8K-BGV*\@VJG9A-N,V*\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG
M97)P<FEN="(*;7-G<W1R("+8I]BKV+$@V*?9AMJOV+38JB#:J=F$VXS8KR(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B
M2V5Y($QE;F=T:"(*;7-G<W1R("+8M]F(V80@VJG9A-N,V*\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E
M(@IM<V=S='(@(MF&V8C8N2#:J=F$VXS8KR(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")+97D@57-A9V4B"FUS9W-T
M<B`BVJG8I]BQV*C8L=BO(-JIV83;C-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(MJIV83;C-BO(-F"
MV*C9A-BGV8L@V*_8L2#:J=BGV+'8L]BGV+(@V+G9A=F(V87;C"#:J=F$VXS8
MKR#9A=F(V*S9B-BO(-BGV+/8JB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("+B@(S8J-J&V8?B@(S9A]BG(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R
M96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B2V]R
M96%N("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B
M3&%?>6]U="(*;7-G<W1R("+8K-BGV8;9A=BGVXS;C"(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(MBRV*C8I]F&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`BV8;;C-F%
MV8?9E"#8HMBNV+$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G
M:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(MBJV+K;C-N,V+$@
MV*+8KMBQVXS9AB#8I]BSV84@V+'9A=BR(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(MBQV*C8N2#8HMBNV+$B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("+8HMBN
MV+';C-F&(-BHV+'9B-BRV+'8L]BGV8;;C#HB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,B"FUS9W-T<B`BV*+8KMBQVXS9AB#9B-BQV8C8KSH@)7,B"@HC(`HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("+8HMBNV+';
MC-F&(-F(V+'9B-BO(#H@)7,@V*?8LB`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T
M<B`BV*+8KMBQVXS9AB#9B-BQV8C8KSH@V8?8L=JOV+(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*(RP@9G5Z>GD*;7-G:60@(DQA='9I82(*;7-G<W1R("+8K]BGV*_9AR(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S
M='(@(MBMV8+9B-F"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`BV*S8
MI]F&V878I]N,VXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`BVH;9OB(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R
M(@IM<V=S='(@(MBSV+'8HMF%V*\@VH;9OB(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,34*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(MF%
MV8+8I]BOVXS8L2#:AMF^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"B,L(&9U>GIY"FUS9VED
M("),97-O=&AO(@IM<V=S='(@(MBQV8C8M"(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T
M<B`BV+G8M-F"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI
M<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N
M<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B
MV8;9A>*`C-F&V84@V*C8I]BQV*?9AB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S
M='(@(MBHV*?8L=F&V*_:K]N,(-BSV*C:J2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A
M<FQY(@IM<V=S='(@(MBHV*?8L=F&V*_:K]N,(-BSV*C:J2#8LMF(V*_9A]F&
MVJ_8I]F%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("+8J-BGV+'9
MAMBOVJ_;C"#8L]BHVJD@V*_;C-BQV8?9AMJOV*?9A2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!2
M86EN(%-H;W=E<B(*;7-G<W1R("+8J-BGV+'9AMBOVJ_;C"#9B"#8L=JOV*C8
MI]BQ(-BSV*C:J2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G
M<W1R("+8J-BGV+'8I]F&(-BSV*C:J2#8J-F'(-F'V878L=BGV8<@V+'8N=BO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*
M;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`BV*C8L=F!(-BSV*C:J2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED
M("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("+8J-BQV8$@V8@@V+':K]BH
MV*?8L2#8L]BHVJDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G
M:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T<B`BV;[;C-F(V8;8KR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(MF&V8+8
MI]BW(-F^VXS9B-F&V*\@V*C9ASHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H
M92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(MBBV*_8
ML=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V+'8IR#8J-F'(-BUV8'8
MK=F'(-BGVXS8K-BGV*\@V;[;C-BZV*?9A=B,(-BHV8<@V8?9AMJOV*?9A2#9
MA=BTV*?9A]BOV8?8C"#9OMN,V8C9AMBO(-BOV8?;C-BO(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I
M9"`B3&EN:W,B"FUS9W-T<B`BV;[;C-F(V8;8K^*`C-F'V*<B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G
M<W1R("+:J=F(VJG;C"#9A-N,V8;9B-JIV+,B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(MF!V8?8L=BSV*H@+2#:J=BG
MV+'8J-BQ(-F%VXSB@(S8JMF(V*?9AMBO(-F^V8C8M-F'(-BQV*<@V*C8J-N,
MV8;8KR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@
M1&%T86)A<V5S(@IM<V=S='(@(MF!V8?8L=BSV*H@V*_8I]BOVJ_8I]F&V8?8
MI^*`C"(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),
M:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(MF!V8?8L=BSV*H@V+G9AMBGV8C;
MC-F&(-BQV*?9A]F&V878IR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*
M;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(MF!V8?8L=BSV*H@V*S8K]BG
MV8C9A"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT
M"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`BV8'9A]BQV+/8JB#8HMBQ
MV+3;C-F((@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("+9@=F'V+'8L]BJ(-BQV*?9
MA]F&V878IR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(MF!V8?8L=BSV*H@260B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B
M3&ES="U/=VYE<B(*;7-G<W1R("+9@=F'V+'8L]BJ(-F%V*?9A-JI(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI
M<W0M4&]S="(*;7-G<W1R("+9@=F'V+'8L]BJ(-F^V+/8JMN,(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M
M4W5B<V-R:6)E(@IM<V=S='(@(MF!V8?8L=BSV*H@V+G8MMF(VXS9D=BJ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@
M(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`BV8'9A]BQV+/8JB#8N=BOV84@
MV+G8MMF(VXS9D=BJ(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE
M9#H@)7,B"FUS9W-T<B`BV8'9A]BQV+/8JB#:J=BGV+'8J-BQV*?9AB#9@=BY
MV*?9A"#9AMF%VXSB@(S8J-BGV+38KR(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!F86EL960Z("5S(@IM<V=S='(@(MF!V8?8L=BSV*H@VJG8I]BQV*C8L=BG
MV88@V8'8N=BGV80@V8;9A=N,XH",V*C8I]BTV*\B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(MF!V8?8L=BSV*H@VJG8I]BQV*C8L=BG
MV88@V8'8N=BGV80@V8;9A=N,XH",V*C8I]BTV*\B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`BV*?8
MK]BHVXS8I]BJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("),:71H
M=6%N:6$B"FUS9W-T<B`BV8C8I]BMV*\@V;[9A]F&V*<B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(MBHV*?8L=JIV+'8K]F&+BXN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@
M(@IM<V=S='(@(MBSV*?8N=BJ(-F%V*W9A-N,.B`B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R
M("+9A=BMV83;C-F1V*H@V8@@V+/8I]BYV*HB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C
M:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(MF%V8C9
M@MBYVXS8JB(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R("+9B-BQV8C8
MKR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T
M(@IM<V=S='(@(MBNV+'9B-BL(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("+9B-BQV8C8KR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S
M='(@(MF(V+C8I]N,V8$@V8C8L=F(V*\B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M(@IM<V=S='(@(MF(V+'9B-BO(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR#8LMN,
MV+'8IR#9AMBGV84@VJG8I]BQV*C8L2#9B"#;C-BG(-BGV+/9A2#8L=F%V+(@
MV8C8I]BQV*\@V+38K]F'(-BGV+38JMBHV*?9AR#8J-F(V*\@(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N
M(@IM<V=S='(@(MF(V+'9B-BO(-F&V*?9A=F(V8'9D=F"(-BHV8C8KRXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E
M>'0B"FUS9W-T<B`BV878JMF&(-BHV839AMBO(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(MBYV+39@B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED
M("),;W<B"FUS9W-T<B`BV;[8I]N,VXS9AB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO
M=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`BV*W8L=F(V8$@VJG9B-J&VJD@
MVXS9B-F&V*?9AMN,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T
M=&5R<R(*;7-G<W1R("+8K=BQV8C9@2#:J=F(VH;:J2#9A-BGV*K;C-F&(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("+8
MI]BYV*_8I]BO(-JIV8C:AMJI(-N,V8C9AMBGV8;;C"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("+9OMN,
MV+K8I]F%(-BQV8C8LB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(MF^VXS9B-BSV*H@35,M5$Y%1B#8M-BG
MV879A"#9A]N,VH8@V*_8I]BOV8?B@(S8I^*`C-N,VXP@V8;;C-BSV*HB"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86-A;R(*;7-G<W1R("+8JMBY
MV+?;C-F$V*?8JB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@
M(MBLV*?8K]F((@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS
M9VED(")-86EL(@IM<V=S='(@(MF&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:
MJ=N,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R("+8L]BQV;[8L=BSV*H@V8;8I]F%V8<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`BV+/8I]BNV*K9
MAB#9OMN,V8C9AMBO+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`BV8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;C-JI
MVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(MF&V*?9
MA=F'(-BGV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U
M>GIY"FUS9VED(")-86QT82(*;7-G<W1R("+9AMBGV879AR#8I]F$VJG8JMBQ
MV8C9AMN,VJG;C"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I
M9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`BV878K]N,V+';C-BJ
M(-F((-BJV+G;C-N,V88@V+'9AMJO(-BOV+/8JMF'XH",V8?8I]N,VXP@VJG9
MAR#8M-F%V*<@V879B-BGV+'8KR#8L=BG(-BHV*<@V*+9AMF'V*<@V8;8I]F%
MXH",VJ_8L-BGV+';C"#9A=N,XH",VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(DUA<#(T(&UA<"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B
M"FUS9W-T<B`B36%P475E<W0@;6%P(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W
M"FUS9VED(")-87)C:"(*;7-G<W1R("+9A=BGV+'8LR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA<F=I;B(*;7-G<W1R("+8K=BGV+3;C-F'(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3
M965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("+8N=F$V*?9A=BJ(-JOV+#8I]BQ
MVXP@V*C8IR#9OMBQVH;9A2#9A=BTV*?9A]BOV8<@V+38K]F'+R#9A=BTV*?9
MA]BOV8<@V8;8M-BOV8<B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(-BYV838I]F%V*H@
MVJ_8L-BGV+';C"#8J-BG(-BYV838I]BFV84@V*_;C-JOV+$@*-F%V*?9AMF&
MV*\@V879A]F%+]F^V*?8L]BN(-BOV*?8K]F'(-BTV*_9ARDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@
M(MBMV*?8M-N,V8<B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P
M,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(MF!VXS9A-BOXH",
MV8?8I]N,(-BGV8;8M]BHV*?9@B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM
M<V=I9"`B36%U<FET86YI82(*;7-G<W1R("+8K=BGV+3;C-F'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(MBHVXS8M-N,V8;9AR#8
MI]BYV*K8J-BGV+$@V878K-BGV+(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E
M('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("+8JMBNV+?;C"#8I]BR(-BHVXS8
MM-N,V8;9AR#9@MBSV878JMF'V*?;C"#9OMN,V+K8I]F%(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R("+8J-N,V+3;C-F&V8<@V*_9A=BG(-BOV+$@V[+;M"#8
ML]BGV+G8JB#:K]BPV+38JMF'.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
MV*C;C-BTVXS9AMF'(-BOV878IR#8K]BQ(-NV(-BSV*?8N=BJ(-JOV+#8M-BJ
MV8<Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM
M=6T@;&5N9W1H(@IM<V=S='(@(MBHVXS8M-N,V8;9AR#8M]F(V80B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B
M36%Y(@IM<V=S='(@(MF%VXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS
M9VED(")-87EO='1E(@IM<V=S='(@(MBLV*?9AMF%V*?;C-N,(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R
M("+9OMBRV+3:J=N,(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R("+8I]BYV+;8I]BA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E
M.B(*;7-G<W1R("+9A=BO(-JOV++;C-F&VJ_8I]F&VXPZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I
M9"`B365R9V4@8V5L;',B"FUS9W-T<B`BV*?8K]BZV*?9A2#8L]F$V8C9A-F'
MV*<B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+9OMN,V+K8I]F%
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G
M:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@
M<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D
M+B(*;7-G<W1R("+9OMN,V+K8I]F%(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8
MJ-BGV++8J-N,V8;;C"#8M-BO(-BGV878IR#:K]F(V*?9A]N,(-BGV878MMBG
MV*$@VJG9AMF&V*_9AR#9AMF%VXSB@(S8JMF(V*?9AMBO(-BHV*?8LMBHVXS9
MAMN,(-BTV8C8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G
M<W1R("+9OMN,V+K8I]F%(-F%V8;9@MBVVXP@V+38KR(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("+9AMF(V+D@V;[;C-BZ
MV*?9A2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@
M5V5A=&AE<B(*;7-G<W1R("+8HMBH(-F((-F'V8C8I]N,($UE=&%R(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`BV*C9A-F(VJD@365T87(@V8+8I]BHV80@
MV*_8L]BJV+'8LR#9AMN,V+/8JB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("+8J-F$V8C:J2!-971A<B#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&
MVXS8L]BJ+B#8K-BRV*;;C-BGV*H@V*C8L=BGVXP@V+/8L=F^V+'8L]BJ(-BS
MV*?9A=BGV8;9AR#8J]BHV*H@V+38K]F'(-BGV+/8JB(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*(RP@9G5Z>GD*;7-G:60@(DUE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`BV*?8L]F%(-BQV878LB`@
MV8+8K]N,V87;C"#9AMBGV*_8L=BSV*H@V*?8L]BJ(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B
MV+'9B-BT(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F
M<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS
M9W-T<B`BV+'9B-BT("<E<R<@V*K8N=BQVXS9@2#9AMBTV*_9AR#8I]BSV*HB
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS
M9W-T<B`BV*?9AMBOV*?8LMF'XH",V*?;C"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F
M=7IZ>0IM<V=I9"`B365X:6-O(@IM<V=S='(@(MBGV8;8K]BGV++9A^*`C-BG
MVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G
M<W1R("+9B-BSV+<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(MF&V8C8N2!-
M:6UE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(@VJG9A=N,V8;9AR#8K]F%
MV*?;C"#;LMNT(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R("(@VJG9A=N,V8;9AR#8K]F%V*?;C"#;MB#8L]BGV+G8JB#:
MK]BPV+38JMF'.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0S.0HC+"!F=7IZ>0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#8M-F%
MV*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`IM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(MBBVXS9AMF'(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q
M"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(MF%V*K9@=BQV8+9AR(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS
M9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B(@HBV;[;C-JIV+'8J-F&V*_;C"#9A=F(V*S9
MB-BO(-F&VXS8L]BJ+B#8M-F%V*<@V*?:K]BQ(-F%VXSB@(S8KMF(V*?9A]N,
MV*\@V*?8LB#8I]N,V88@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@
MV*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\@(@HBV*C8I]N,V*\@V*+9AMBQV*<@
MV*K9B-F$VXS8KR#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S
M86=E($E$+B(*;7-G<W1R("+8I]BR(-BHVXS9AB#8L=F!V*K9AB!)1"#9OMN,
MV+K8I]F%(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S
M97-S:6]N($E$+B(*;7-G<W1R("+8I]BR(-BHVXS9AB#8L=F!V*K9AB!)1"#9
MAMBTV+/8JB`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("+8K]F(V+39AMBHV8<B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-
M86EL(@IM<V=S='(@(MF^V+/8JB#8L]F$V8C9A-N,(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E
M(@IM<V=S='(@(MF%V+G8JMBOV80@VJG8L=BOV88B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M("+8JMBGV+';C-BN(-BJV+K;C-N,V+$@VXS8I]F!V*K9AR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM
M<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("+8JMBZVXS;C-BQ(%523"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-
M;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG
M;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("+9A=BGV8<@V8@@
MV+/8I]F$(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("+9A=BGV8?8I]F&V8<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUO;G1S97)R870B"FUS
M9W-T<B`BV878N=BJV*_9A"#:J=BQV*_9AB(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S
M97,B"FUS9W-T<B`BV8'8I]BRV8?8I]N,(-F%V*?9AR(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED
M(")-;W-T;'D@0VQE87(B"FUS9W-T<B`BV*C;C-BTV*K8L2#8M=BGV8$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I
M9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("+8J-N,V+38JMBQ(-BGV*C8L=N,
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*
M;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("+8J-N,V+38JMBQ(-BBV8'8
MJMBGV*C;C"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(MBGV8;8JMF"V*?9A"#8
MJ-F'(-F^V*?;C-N,V88B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("+8I]F&V*K9
M@MBGV80@V*C9AR#8J-BGV838IR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("+8
MI]F&V*K9@MBGV80@V*C9AR#8L=BGV+/8JB(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M("+8I]F&V*K9@MBGV80@V*C9AR#8J-BGV838IR(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R("+8I]F&V*K9@MBGV80@V*C9AR#9OMBGVXS;C-F&(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(MBGV8;8JMF"V*?9A"#8J-F'(-BHV*?9A-BG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I
M+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("+9@=F'V+'8L]BJ(-F^
MV*?;C-N,V8;B@(S9OMBQ(-J&V8;8KR#8L]BWV*W;C"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT
M:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@
M(MJ&V8;8KR#8I]F&V*K8KMBGV*C;C"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`BV*W8L]BG
MV*@@V879AB(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B
M37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("+8I]BWV838I]BYV*?8
MJB#8K=BSV*?8J"#9A=F&(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(MBOV+':K]BGV8<@V879
MAB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY
M(%!O<G1A;"!,87EO=70B"FUS9W-T<B`BV*S8I]F&V878I]N,VXP@V*_8L=JO
MV*?9AR#9A=F&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`BV8;9
MA]B,(-F%V88@V879B-BGV8'9@B#9AMN,V+/8JMF%(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BV8;8I]F%
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@
M0F%S92!54DPB"FUS9W-T<B`B55),(-F^V*?;C-F'($YE='-C87!E(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE
M='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E($-!
M(%)E=F]C871I;VX@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS
M9W-T<B`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE
M=V%L(%523"(*;7-G<W1R(").971S8V%P92!296YE=V%L(%523"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S
M8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92!2979O8V%T
M:6]N(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`BV*K9
MB-BVVXS8K2#:K]F(V*?9A]N,($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E('1Y<&4B"FUS9W-T<B`BV8;9B-BY(-JOV8C8I]F'VXP@3F5T<V-A
M<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").
M971W;W)K(@IM<V=S='(@(MBTV*C:J=F'(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS
M9W-T<B`BV8?8L=JOV+(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`BV*_8L]BJV8<@V*S8K]N,V*\B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR
M-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(MBOV+/8JMF'(-BLV*_;
MC-BO(@H*(R`*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BV*?;C-BLV*?8KR#9OMN,V+K8I]F%
M("@E<RDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO
M;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-
M;V]N(@IM<V=S='(@(MF%V*?9AR#9AMF((@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I
M;VYA;"DB"FUS9W-T<B`BV8;8I]F%(-JIV*?8L=BHV+';C"#8K-BOVXS8KR`H
MV*?8KMBJVXS8I]BQVXPI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A
M;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9
MA=BR(-BLV*_;C-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP
M.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E
M>'!I<F4@;VX@)7@N(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V838NMF((-BN
MV8C8I]F'V*\@V+38KR#8K]BQ("5X("(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"XB"FUS9W-T<B`BV*?8L]F%(-BQV878LMF'V*?;C"#8K-BOVXS8KR#8JMBW
MV*?8J-F"(-F&V*_8I]BQV*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI
M(@IM<V=S='(@(MF^V8;8K-BQV8<@V*S8K]N,V*\@*-BNV*?9A-N,*2(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(").
M97=S(@IM<V=S='(@(MBGV*[8J-BGV+$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(MJOV+'9
MB-F'XH",V8?8I]N,(-BNV*C8L=N,(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`BV*C8N=BOVXPB
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE
M>'0@-"!0:&%S97,B"FUS9W-T<B`BV8'8I]BR(-BHV+G8K]N,(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R
M("+:K]BRVXS9AMF'XH",V8?8I]N,(-BHV+G8K]N,(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(MBHV+G8K]N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G
M=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").
M:6=E<B(*;7-G<W1R("+8M-BH(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E
M<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(MBTV*@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*(RP@9G5Z>GD*;7-G:60@(DYI=64B"FUS9W-T<B`BV+G8K]BO(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I
M9"`B3F\B"FUS9W-T<B`BV8;9AR(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I
M;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`BV*_8
MI]BOV8<@V;[;C-JIV+'8J-F&V*_;C"#8K]BQ(-BOV+/8JMBQV+/;C"#8J-BQ
MV*?;C"#9AMBTV*?9AB#8K]BGV*_9AB#8JMF!V*?9B-BJV8?8IR#9B-BLV8C8
MKR#9AMBOV*?8L=BO(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(DE33R#9AMN,V+/8JB#8
MI]BSV*K8L=BGV*K:F-N,(-BOV+$@V*_8L]BJV+'8L]N,(-BHV+'8I]N,(-BS
MV*?8KMBJV88@V*K8M=F(VXS8L2`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E
M;7!L871E+B(*;7-G<W1R("+8I]F$VJ_9B-N,(-BOV+/8JMF'XH",V*?;C-N,
M(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`BV*C9A-BGVJG;C"#8K]BQ(-F%V8C9@MBYVXS8JB#8K]BQV*[9B-BG
MV+/8JB#8M-BOV8<@V879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA
M;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(MF'VXS:AB#9AMBGV84@V*K9@MF(VXS9A=N,(-BHV+'8I]N,(-BJV+78K]N,
MV8(@V8?9B-N,V9'8JB!-0T%,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG
M92XB"FUS9W-T<B`BV*C8K]F(V88@V*K8NMN,VXS8L2(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("+9A]N,
MVH8@V878K-F(V+(@V8'8L=BYVXSB@(S8I]N,(-F&V87;C.*`C-BJV8C8I]F&
MV*\@V*C9AR#8I]N,V88@V878K-F(V+(@V*?8MMBGV8'9AR#8M-F(V*\B"@HC
M(`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("+9A]N,VH8@
MV*?8M]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;C"`E<R#9
MA=BTV*[8M2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N(@IM<V=S='(@(MF'VXS:AB#8I]BWV838I]BY
MV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,($944"!61E,@V878M-BN
MV+4@V8;8M-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344P@5D93+B(*;7-G<W1R("+9A]N,VH8@V*?8M]F$V*?8N=BGV*H@
MV;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;C"!344P@5D93(-F%V+38KMBU(-F&
MV+38KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(MF'VXS:AB#8I]BWV838I]BY
MV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,(%-13"U&:6QE(%9&4R#9
MA=BTV*[8M2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R("+9A]N,VH8@V*?8N=BJV*C8I]BQVXP@V*C8I]F"VXP@V8;9A=BG
MV8;8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS
M9W-T<B`BV8?;C-J&(-F%V8+8M=BOVXP@V8'8L=BGV8?9A2#9AMBTV*\B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO
M(&9I;&4@=7!L;V%D960B"FUS9W-T<B`BV8?;C-J&(-F^V+'9B-F&V*_9A^*`
MC-BGVXS;C"#8I]BQV+/8I]F$(-F&V+38KR(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(MF'
MVXS:AB#8HMN,VJG9B-F&VXSB@(P@V;[;C-BOV*<@V8;8M-BO(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO
M(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`BV8?;C-J&(-F%VJG8I]F&VXP@
MV*K9AMBXVXS9A2#9AMBTV*_9AR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("+9A]N,VH8@V87:J=BGV8;;C"#8JMF&V+C;C-F%(-F&
MV+38K]F'(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S
M='(@(MF'VXS:AB#9OMN,V+K8I]F%VXP@V8'8L=BGV8?9A2#9AMBTV*\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(MF'VXS:AB#9
MAMBGV87;C"#9A=BTV*[8M2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R
M('-P96-I9FEE9"XB"FUS9W-T<B`BV8?;C-J&(-BTV878I]BQV8?B@(S8I^*`
MC-N,VXP@V878M-BNV+4@V8;8M-BO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B
MV*+;C-F&V*_9AR#9AMBGV878M]BHV8C8N=N,(-F&VXS8L]BJ(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(MBHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!(5%10(-BGV+/9A2#8
ML=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
MV*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($E-05`@V*?8L]F%(-BQ
MV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("+8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@2V5R8F5R;W,@V*?8
ML]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T
M:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BV*C8L=BGVXP@V*K8M=BOVXS9
M@B#9A]F(VXS9D=BJ(-F(V+'9B-BO(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9
MA]F%(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(MBHV+'8I]N,(-BJ
MV+78K]N,V8(@V8?9B-N,V9'8JB!005-35T0@V*?8L]F%(-BQV878LMN,(-F!
MV+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+8J-BQV*?;C"#8JMBU
MV*_;C-F"(-F'V8C;C-F1V*H@4TU"(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9
MA]F%(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM
M<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("+8JMF"V*?8MMBG
MVXP@V*O8J-BJ(-F&V*?9A=N,(-BOV+$@V*?9AMBJV+C8I]BQ(-BJV*/;C-N,
MV*\@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S
M='(@(MBJV8;8N-N,V84@V8;8M-BOV8<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE
M<R(*;7-G<W1R("+8J-BOV8C9AB#9@MF(V*?8N=BO(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS9VED(").;R!S97!A<F%T;W(@<W!E
M8VEF:65D+B(*;7-G<W1R("+9A]N,VH8@V*S8K]BGVJG9AMF&V*_9A^*`C-BG
MXH",VXS;C"#9A=BTV*[8M2#9AMBTV*\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E
M<R(*;7-G<W1R("+8J-BOV8C9AB#8L]F%V*HB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<W5C:"!F:6QE
M(@IM<V=S='(@(MBHV*_9B-F&(-BSV878JB(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O
M<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`BV+38I]BNV8<@V879
MB-F"V*K;C"#8J-BQV*?;C"#:J=BGV+39AR#9A=F(V*S9B-BO(-F&VXS8L]BJ
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*
M;7-G<W1R("+9A]N,VH8@V8;8I]F%(-JIV*?8L=BHV+';C"#9B"#;C-BG(-BG
MV+/9A2#8L=F%V++;C"#8I]BQV+/8I]F$(-F&V+38KR(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@
M9&%T82!R971U<FYE9"(*;7-G<W1R("+9A]N,VH8@V*_8I]BOV8<@6$U,(-F%
MV+G8JMBHV+';C"#8J-BGV++:K]BQV*_8I]F&V*_9AR#9AMBTV*_9AR#8I]BS
MV*HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY
M,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P
M.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(MBHV*_9B-F&(-F%V8+8K]BG
MV+$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BV8;8L]BNV8?B@(P@V*_8
ML2#9OMN,VJG8L=BHV8;8K]N,(-BGV+79A-N,(-F^VXS8K]BG(-F&V+38KRX@
MV;[;C-JIV+'8J-F&V*_;C"#8L=BG(-BOV8C8J-BGV+'9AR#8JMF(V83;C-BO
M(-JIV8;;C-BO(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BV8;8L]BNV8?B@(P@
MV*_8L2#9OMN,VJG8L=BHV8;8K]N,(-BTV878IR#9OMN,V*_8IR#9AMBTV*_9
MAR#8I]BSV*HN(-F^VXS:J=BQV*C9AMBOVXP@V+'8IR#8K]F(V*C8I]BQV8<@
MV*K9B-F$VXS8KR#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`BV8?;C-J&XH",
MVJG8K]BGV84B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@
M(MF'VXS:AN*`C-JIV*_8I]F%("C8MMF%V8;;C"#8I]BSV*K9@=BGV*_9AR#:
MJ=F&VXS8KRDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B
M3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3F]R9&EC("A)4T\M.#@U
M.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`BV8;;C-F%(-JIV+'9AR#8M-F%V*?9A-N,(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E
M<B(*;7-G<W1R("+9AMF'(-BHV+G8KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@
M(MF&V8<@V8+8J-F$(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`BVXS:J2#8M-BG
MV*[9AR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED
M(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(MF^VXS8I]BOV8?B@(S8L]BG
MV++;C"#9AMBTV*_9AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`BV*K9AMBX
MVXS9A2#9AMBTV*_9AR(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V
M-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+9OMBTV*K;
MC-BHV*?9AMN,(-F&V+38K]F'(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P
M-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E
M<R(*;7-G<W1R("+;C-BGV*_8K]BGV+38JMF'V*<B"@HC.B!S97)V:6-E<R]O
M8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+B(*;7-G<W1R("+:AMN,V++;C"#8J-BQV*?;C"#9A=BQV8C8
ML2#9AMN,V+/8JMB,(-BHV8<@V+G9@MBH(-BHV+':K]BQV*\B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V
M96UB97(B"FUS9W-T<B`BV8;9B-BGV878J-BQ(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(MBYV*_8
MKR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU
M;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(MBJV+G8K]BGV*\@V8;9B-N,
MV+/9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T
M<B`BV*K8N=BOV*?8KR#8L]BJV8C9AMF'V*<B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F
M(')O=W,B"FUS9W-T<B`BV*K8N=BOV*?8KR#8L]BWV+'9A]BG(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G
M:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(MBGV+G8K]BGV*\@V*C8L=BGVXP@
MV*C8L=F(V++8L=BSV*?9AMN,(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-F%
MV+38KMBU(-F&V+38K]F&V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(MBJV*/;C-N,
MV*\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`BV+3;C-BA(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R
M(@IM<V=S='(@(MBGVXS8K-BGV*\@VJG9AMF&V*_9AR#8M-N,V*$B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A
M;"(*;7-G<W1R("+9A]BTV*K8I]N,VXPB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R
M("+8I]JIV*K8J-BQ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS
M9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("+9@=N,V838JMBQ(-BHVXSB
M@(S8K=BQV878JMN,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(MBOV8'8JMBQ(-JIV*?8L2(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("+8
MI]BSV84@V+'9A=BR(-BLV*_;C-BO(-F((-BGV+/9A2#8L=F%V+(@V8'8N=F$
MVXP@V*C8I]N,V*\@V878JMF!V*?9B-BJ(-BHV*?8M-F&V*\B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R
M9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-F"V*_;C-F%VXPB"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`BV*?8L]F%(-BQV878LB`@V8+8
MK]N,V87;C"#9AMBGV*_8L=BSV*H@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S
M=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("+8JMF&V8?8IR#:J=BG
MV+'8L]BGV++9A]BGVXP@24U!4-F^V8C8M-F'XH",V8?8I]N,(-F%V+38JMBQ
MVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F%VXSB@(S:J=F&V8;8KR`B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS
M:79E(&9O<G1U;F5S(@IM<V=S='(@(MF!V8+8MR#8HMN,V8;8K]F'(-F&V*?9
MA=BWV*C9B-BY(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(MBJV8;9A]BG(-N,VJD@
MV*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J=N,(-F%V*S8I]BR
M(-BGV+/8JB(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I
M9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@
M9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HBV*K9AMF'V*<@V878I]F$VJD@VXS8
MIR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-F%VXSB@(S8JMF(V*?9AMBO
M(-F%V*?9A-JIVXS8JB#;C-BG(-F%V*S9B-BRV8?8I]N,(-F%V*?9A-JI(-BQ
MV*<@V*C8L=BGVXP@VXS:J2#8I]BTV*K8L=BGVJD@(@HBV*K8NMN,VXS8L2#8
MK]F'V*\B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E
M;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BV*_8L2#;C-JI(-F^V8;8K-BQ
MV8<@V*S8K]N,V*\@V*C8I]BR(-BTV8C8KR(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#
M;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BV*?;C-F&(-F^VXS9B-F&V*\@V*_8
ML2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@V*C8I]BR(-BTV8C8KR(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y
M<W1E;2(*;7-G<W1R("+8L]N,V+/8JMF%(-BYV*?9A=F$(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G
M<W1R("+:K]BRVXS9AMF')B-X,C`P8SO9A]BG(@H*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(MJO
MV++;C-F&V8?B@(S9A]BGVXP@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS
M9W-T<B`BV83;C-BSV*H@V878L=BJV*@@V+38K]F'(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO
M;B(*;7-G<W1R("+8L]BGV++9A=BGV88B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI
M="(*;7-G<W1R("+9B-BGV*W8KR#8L]BGV++9A=BGV8;;C"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS
M9W-T<B`BV+/8I]BRV878I]F&V*_9A]N,(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E
M(@IM<V=S='(@(MBGV83:K]F(VXP@V*?8M=F$VXP@V*C8L=F&V*?9A=F'V90@
MVJG8I]BQV*C8L=BOVXPB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(MBGV83:K]F(V8?8I]N,(-BGV+79A-N,(-BOV+$@
M)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(MBO
MVXS:K]BQ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B
M3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`BV*?8M]F$V*?8N=BGV*H@V*_;
MC-JOV+$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED
M(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("+9A=BLV8C8LN*`C-F'V*?;
MC"#9A=BGV83:J2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW
M.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,V9'8JB!004T@V8+8I]BHV80@
MV*_8L]BJV+'8L]N,(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A
M8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(MBGV878MMBGV*'B@(P@V*_;C-BLVXS8JMBGV83;C"!01U`B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@
M16YC<GEP=&5D($1A=&$B"FUS9W-T<B`BV;[;C-BZV*?9A2#8L=F%V++8J-F&
MV*_;C"#8M-BOV8?9E"!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(@
MVJG9A-N,V*\@V+G9A=F(V87;C"!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(MF^VXS8NMBGV84@V+'9A=BRV*C9AMBOVXP@V+38
MK]F'+]BGV878MMBGV*$@V+38K]F'(%!'4"(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`BVJG8KR!02%`B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G
M<W1R("+9OMF(V+/8JMF'(%!(4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S
M='(@(MBHV*?8L=F&V*_:K]N,(-BSV*C:J2#8N=BUV+':K]BGV8?;C"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED
M(")032!3:&]W97)S(@IM<V=S='(@(MBQVJ_8J-BGV+$@V+G8M=BQVJ_8I]F'
MVXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("+8J-BQV8$@V+G8M=BQVJ_8I]F'
MVXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(MBJVJ_8L=JO(-BY
MV+78L=JOV*?9A]N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@(E!-(%-U;B(*;7-G<W1R("+8
MJ-BQV8$@V+G8M=BQVJ_8I]F'VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B5"U3=&]R;7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS
M9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("+8J-BS
MV+<@4$]325@@V*?8LB#8J-N,V88@V+'9@=BJV8<@XH",V*?8L]BJ(@H*(SH@
M;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(MF^
MV8C8L]BJV8<@4$A0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("+9
M@=BGV+79A-F'XH",VJ_8L-BGV+';C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ
M>0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`BVH;8L]BHV*?9AMBOV88B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N
M86UA(@IM<V=S='(@(MF&V*?9A2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P
M=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G
M<W1R("+9@MBSV878JMN,(-BGV*C8L=N,(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS
M9W-T<B`BV*?8L]F%(-BQV878LB`B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BHV*<@V879B-F!V9'9@MN,
MV9'8JB#8JMBZVXS;C-BQ(-N,V*?9@=BJ+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3,R,@IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R
M96-T(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@(-F&V*?8K]BQV+/8JB#8I]BS
MV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS
M9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#8J-F'(-BJV+78K]N,V8(@
MV8?9B-N,V9'8JB!2041)55,@V8;;C-BGV+(@V*_8I]BQV*\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#8J-BG(-BJ
MV*/;C-N,V*\B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*
M;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("+8I]BSV84@V+'9A=BR(#HB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O
M<F0Z("(*;7-G<W1R("+8I]BSV84@V+'9A=BR(#H@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O
M<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(MBGV+/9A2#8L=F%V++B@(S9A]BG
M(-BHV*?;C-BO(-F%V8;8M]BHV8(@V*C8I]BTV8;8KR(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("+:AMBS
MV*C8I]F&V*_9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S
M='(@(MJ&V+/8J-BGV8;8K]F&(-BGV+(@V*K8KMBJV8<@V+'8L]F%(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R("+9A=BSVXS8L2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S
M='(@(MBKV*C8JB#9AMBGV879A]BGVXP@V8;8I]F%V+G9A-F(V84B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R
M("+9A=BQV*_9A2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(MBOV+'8M=BO
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R("+8I]BLV+'8I]N,(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*;7-G:60@(E!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BV*+;
MC-BG(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C"#8K]BQ(-F$V*W8N-F'
M(-F(V+'9B-BO(-BGV*S8L=BG(-BTV8C8K]B?(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T
M<B`BV878K-F(V+(B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO
M="!D96QE=&5D+B(*;7-G<W1R("+9A=BLV8C8LB`@7"(E<UPB(-BMV+#9@2#9
MAMBTV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-@HC+"!F
M=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`BV878K-F(
MV+(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO
M;G,B"FUS9W-T<B`BV878K-F(V++9A]BG(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI
M;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MV+/8L=F^V+'8L]BJVXP@V878K-F(V++9A]BG(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G
M<W1R("+8I]BWV838I]BYV*?8JB#8M-BNV+7;C"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`BV*W;C-F(V*?9AMBGV*H@V*[8
MI]F&VJ_;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`BV*K9A-F!V88B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS
M9W-T<B`BV+G:J=BSV8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A
M:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`BV;[;C-JI
MV+/9A-F'V*<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@
M(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L
M:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(MF$V+?9@=BGV8L@V*_8I]BN
MV80@VH;9AMBO(-BSV839B-F$(-JIV83;C-JI(-JIV8;;C-BO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y
M"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(MF$V+?9@=BGV8L@V*K8H]N,VXS8
MKR#:J=F&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?;C-F&(-BY
MV8;8M=BQ(-BQV*<@V*W8L-F!(-JIV8;;C-BO.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+B(*;7-G<W1R("+9A-BWV8'8I]F+(-BJV*/;C-N,V*\@VJG9AMN,
MV*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-F^VXS9B-F&V*\@V*?;C-F&
M(-BYV8;8M=BQV8?8IR#8L=BG(-F"V+?8N2#:J=F&VXS8KR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(MF$V+?9@=BGV8L@VXS:J2#9
MA=BGV8<@V8@@VXS:J2#8L]BGV80@V8C8I]BQV*\@VJG9AMN,V*\N(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M(@IM<V=S='(@(MF$V+?9@=BGV8L@V8;8I]F%VXP@V*C8L=BGVXP@V*_8L]BJ
MV8<@V*S8K]N,V*\@V8C8I]BQV*\@VJG9AMN,V*\Z(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RXB"FUS9W-T<B`BV838M]F!V*?9BR#8HMBOV+'8LR!)
M4"#9A=BYV*K8J-BQVXP@V8C8I]BQV*\@VJG9AMN,V*\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO
M;G1H+B(*;7-G<W1R("+9A-BWV8'8I]F+(-N,VJD@V*K8I]BQVXS8KB#9A=BY
MV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BOV(P@V*K8N=BOV*?8KR#8L=F(V++9
MA]BG(-BOV+$@V878I]F'(-BQV*<@VJG9AMBJV+'9A"#:J=F&VXS8KR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(MF$V+?9@=BGV8L@VXS:J2#8
MLMF%V*?9AB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BO(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("+9A-BW
MV8'8I]F+(-BNV838I]BUV8?B@(S8I^*`C-N,VXP@V*?8LB#9A=BTVJG9A"#8
ML=BG(-BHV8;9B-N,V+/;C-BO(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G
M<W1R("+9A-BWV8'8I]F+(-F&V*?9A2#:J=BGV+'8J-BQ(-F((-BGV+/9A2#8
ML=F%V+(@(-BNV8C8KR#8L=BG(-BBV878I]BOV8<@VJG9AMN,V*\B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@
M=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@
M(B(*(MF$V+?9@=BGV8L@V878JMF&(-BRVXS8L2#8L=BG(-BHV*[9B-BGV8;;
MC-BO+B#8M-F%V*<@V*C8L=BGVXP@V*?8L]BJV8'8I]BOV8<@V*?8LB#8L]BG
MV878I]F&V8<@V*C8I]N,V*\@V+38L=F(V+<@V+'8IR#9@MBHV8C9A"#:J=F&
MVXS8KR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z(@IM<V=S='(@(MF$V+?9@=BGV8L@V8;8I]F%(-BOV+/8JMF'(-BL
MV*_;C-BO(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"B,L(&9U>GIY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`BV8'8L=F%V*?9AB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B
M"FUS9W-T<B`BV+/;C-BGV+/8JMF'V*<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R("+8HMBQV*?8H2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(E!O<G1U9V%L(@IM<V=S
M='(@(MBOV+':K]BGV8<@V879AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("+9A=BMV80@V8+8L=BGV+':
MK]BQV8'8JMF&(-BGVXS9AB#8JMBUV8C;C-BQ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`BV878K=F$(-F"V+'8I]BQVJ_8
ML=F!V*K9AB#8I]N,V88@V*S8K]F(V80B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(MF^V+/8JB#8
MJ-F'(-BGVXS9AB#9OMF(V+39AR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S
M='(@(MBOV+'8M=BO(-BQV+?9B-BHV*H@V*_8L2`E<R#8L]BGV+G8JB#9@MBH
MV80Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I
M9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4')E9G-?;&1A<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($Q$
M05`@V;[;C-BOV*<@V8;8M-BO(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7W-E<W-I;VXZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!S97-S:6]N(-F^
MVXS8K]BG(-F&V+38KR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS
M9VED(")0<F5S<W5R92(*;7-G<W1R("+9@=BTV*?8L2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ
M("(*;7-G<W1R("+9@=BTV*?8L2#8K]BQ(-BSV+?8K2#8K]BQVXS8ISH@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E
M<W-U<F4Z("(*;7-G<W1R("+9@=BTV*?8L3H@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`BV;[;C-BTXH",V8;9A=BGVXS8M"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(MF^VXS8M.*`C-F&V878I]N,V+0@V*K8M=F(VXS8L2#8K]BQ
M(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8KR`B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("+:K]BR
MVXS9AMF'XH",V8?8I]N,(-F"V*C9A-N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE
M;G0B"FUS9W-T<B`BVH;8I]F^(-BSV8;8KR(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T
M<B`BVJG9A-N,V*\@V+38KMBUVXPB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(MF%V+3:
MJ=F$(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B
M;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(MBJV8C8MMN,V*T@V878M-JIV80B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J
M96-T<R(*;7-G<W1R("+9OMBQV8C:F-F'XH",V8?8IR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0
M<F]M<'0@=&5X="(*;7-G<W1R("+9A=BJV88@V*?8N=F$V*?9AB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R("+:J=F$VXS8KR#8N=F%V8C9A=N,(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+
M97D@06QG;W)I=&AM(@IM<V=S='(@(MBGV83:K]F(V+';C-BJV84@VJG9A-N,
MV*\@V+G9A=F(V87;C"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS
M9W-T<B`BVJG9A-N,V*\@V+G9A=F(V87;C"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BV*S9
M@=BJ(-JIV83;C-BO(-BYV879B-F%VXPOV*[8M=F(V+7;C"#8J-BG(-F%V8C9
M@=F1V8+;C-F1V*H@V*K9B-F$VXS8KR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"B,L(&9U>GIY"FUS9VED(")1871A<B(*;7-G<W1R("+8K]BGV*_9AR(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B
MV;[8L=BSXH",V8C8K-F((@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"FUS9VED(")1=6]T82(*;7-G<W1R("+8L]F'V87;C-F'(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(-JIV83;
MC-BO(-BYV879B-F%VXP@4E-!("@E9"#8J-N,V*HI(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(MBGV8;8JMBNV*?8J"#8L=BGV*_;C-F((@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS
M9W-T<B`BV*C8I]BQV*?9AB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(MBH
MV*?8L=BGV88@V++9B-BOV8?9AMJOV*?9A2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`BV*C8I]BQV*?9AB#8K]N,V+'9A]F&VJ_8I]F%(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@
M4VAO=V5R(@IM<V=S='(@(MBHV*?8L=BGV88@V8@@V+':K]BHV*?8L2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED
M(")286EN(&%N9"!3;F]W(@IM<V=S='(@(MBHV*?8L=BGV88@V8@@V*C8L=F!
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*
M;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("+8J-BGV+'8I]F&(-BHV8<@
MV*C8L=F!(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A
M;F1O;2!&;W)T=6YE(@IM<V=S='(@(MBWV*?9A-BY(-BJV+78I]BOV8';C"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T
M:6\B"FUS9W-T<B`BV8;8L]BHV*HB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("+8KMF(V*?9
MAMBOV88B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("+8KMF(V*?9AMBO
MV88@V;[;C-BZV*?9A=F'V*<@(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(MF(V*?9@MBYV*?9DB`E<R#8K=BPV8$@V+39B-BOV)\@V*?;
MC-F&(-BYV879A"#9@MBGV*C9A"#9B-BGVJ_8L=BO(-F&VXS8L]BJ(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(MF(V*?9@MBYV*?9BR#8K]BGV*_9A]F4(-JIV*?8L=BHV+';C"#8J-BQ
MV*?;C"#:J=BGV+'8J-BQ("5S(-BMV+#9@2#8M-F(V*_8GR#8I]N,V88@V+G9
MA=F$(-F"V*?8J-F$(-F(V*?:K]BQV*\@V8;;C-BSV*HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O
M97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+8I]F&V*S8I]F%(-BBV*[8
ML=N,V88@V+G9A=F$(-BTV878IR#8I]BR(-F&V8@B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I
M9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB
M"FUS9W-T<B`BV*C8I]BRV*+9B-BQVXP@V+G9AMBGV+78L2#:K]BRVXS9AMJO
MV*?9AB#8K]N,V8;8I]F%VXS:J=N,.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@
M(MBHV*?8LMBBV8C8L=N,(-F&V878I]N,(-BOV+':K]BGV8<Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0HC+"!F
M=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`BV*C8I]BRV8;8M-BGV8;;C"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T
M:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(MF%V+'9B-BQVJ_8L2#8L=BGV*C8
MM]F'XH",V*?B@(S;C-N,(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC+"!F=7IZ
M>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(MBNV8C8I]F&V*_9AB(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@
M(MBJV8C8MMN,V*W8I]BJ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`BVJG8I]BQV+/8I]BR
MV8?8I]N,(-BQV*?9A^*`C-BOV8C8L2(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E523"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(MBMV+#9
M@2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B
M4F5M;W9E($)L;V-K(@IM<V=S='(@(MBMV+#9@2#8J-F$V8C:J2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@
M(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`BV*W8L-F!(-BSV*K9B-F&(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I
M9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BV*W8L-F!(-F"V*?9A-BH
M(-BHV8;8K]N,(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*
M;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(MBMV+#9@2#8LMF(V*PB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`BV*W8L-F!(-BOV+/8JB#B@(S9AMF(VXS8L]F'V*?;C"#8K=F!
MV+@@V+38K]F'(-BOV+$@V+38I]BNV8<@V879B-F"V*H@VJG8I]BQV+/8I]BR
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(MBMV+#9@2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N="(*;7-G<W1R("+8K=BPV8$@V*?;C-F&(-JOV+'9AR#8I]BR(-BSV8;8
MKR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G
M:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(MBMV+#9@2#:J=BGV+'8J-BQ(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("+8
MK=BPV8$@VJG8I]BQV*C8L3H@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`BV*K9@MBGV+;8
MIR#9@MBGV*C9A"#9OMBGV+/8KMJOV8C;C-N,(-F&VXS8L]BJ+B#:J=BO(-BN
MV+?8I]N,(-BHV+':K]BQV*_8I]F&V*_9AR#8M-BOV8<Z(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("+9
MOMBQV8C9AMBOV8<@V*?8L=BSV*?9A"#8M-BOV8<@V8;9A=N,XH",V*K9B-BG
MV8;8KR#8K=F!V+@@V+39B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B<E
M<R<@V879B-BQV*\@V8;;C-BGV+(@V*_8L2#9OMN,VJG8L=BHV8;8K]N,("5S
M(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G
M)7,G(-F%V8C8L=BO(-F&VXS8I]BR(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"!6
M1E,@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ(@H*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W
M;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(G)7,G(-F%V8C8L=BO(-F&VXS8I]BR(-BOV+$@
MV;[;C-JIV+'8J-F&V*_;C"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@
M(E)E<75I<F5D($9I96QD(@IM<V=S='(@(MF!VXS9A-BOV8?8I]N,(-F%V8C8
ML=BO(-F&VXS8I]BR(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@
M(E)E<V5T(@IM<V=S='(@(MBHV*?8LMF&V+38I]F&VXPB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B
M"FUS9W-T<B`BV*C8I]BRV8;8M-BGV8;;C"#8I]BSV84@V+'9A=BR(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8KMF(V*\@V+'8
MIR#8J-BGV++9AMBTV*?9AMN,(-JIV8;;C-BO(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y
M(@IM<V=S='(@(MBQV*C8N2#8HMBNV+$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R("+9AMBJV*?;C-BL(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R
M("+8J-BGV++:K]BTV*H@V*C9AR#:K]BRVXS9AMF'XH",V8?8IR(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R("+8JMBGVXS9OB#8K]F(V*C8I]BQV8<@V*?8
ML]F%(-BQV878LB`@V*S8K]N,V*\@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B
M4F5U;FEO;B(*;7-G<W1R("+:K]BQV*_9A]F%V*?;C-N,(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("+8
MJ-BGV++:K]BQV*_8I]F&V*_9AB#9OMN,VJG8L=BHV8;8K]N,(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9A]BGVXP@V8C;C-BQ
MV*?;C-BTVJ_8L2#9A=BJV88B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`BV878N=F%V*?9A]BG(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P
M"FUS9VED(")2:6=H="(*;7-G<W1R("+8L=BGV+/8JB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G
M<W1R("+8L]BQV*+9A=BO(-BQV*?8L]BJ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(MF%
MV8+8I]BOVXS8L2#8L=BGV+/8JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BSV+?8L2XN+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*
M;7-G:60@(E)O;&4B"FUS9W-T<B`BV8;9@MBT(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM
M<V=S='(@(MJ&V+'8KMBT(-NQV[C;L"#8K]BQV*S9AR(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T
M92!,969T(@IM<V=S='(@(MJ&V+'8KMBT(-BHV8<@VH;9OB(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O
M=&%T92!2:6=H="(*;7-G<W1R("+:AMBQV*[8M"#8J-F'(-BQV*?8L]BJ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`BV*[8M=F(V+7;
MC-BGV*H@V+/8M]BQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS
M9W-T<B`BV*[8M=F(V+7;C-BGV*H@V+/8M]BQ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM
M<V=S='(@(MBSV+?8L=F'V*<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T
M<B`BV8+9B-BGV+G8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BV8+9B-BG
MV+G8KR#8J-N,V88@V*K9A=BGV84@V+/8M]BQV8?8IR#9B"#8L]BJV8C9AMF'
MV*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@V+38KR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S
M='(@(MF"V8C8I]BYV*\@V8'9@MBW(-BHVXS9AB#8JMF%V*?9A2#8L]BJV8C9
MAMF'V*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@V+38KR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S
M='(@(MF"V8C8I]BYV*\@V8'9@MBW(-BHVXS9AB#8JMF%V*?9A2#8L]BWV+'9
MA]BG(-F&V878I]N,V*?9AB#8KMF(V*?9A]BO(-BTV*\B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`BV*?8K-BQV*<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4G=A;F1A
M(@IM<V=S='(@(MBNV8C8I]F&V*_9AB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI
M8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S
M<V%G92(*;7-G<W1R("+9OMN,V+K8I]F%(-BQV878LMBHV8;8K]N,("#8M-BO
MV8?9E"!3+TU)344@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R("+8JMBUV*_;C-F"(-F'V8C;C-F1V*H@4T%33"#9@MBG
MV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*HB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@
M(MF^VXS8NMBGV84@4TU3(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS
M9VED(")344P@4VAE;&PB"FUS9W-T<B`BV;[9B-BSV*K9AR!344PB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M
M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R(")34T@B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(MF%
MV8C9@=F1V8+;C-F1V*HB"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?
M44P@4VAE;&PB"FUS9W-T<B`BV;[9B-BSV*K9AR!344PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*
M;7-G<W1R("+8M-F&V*C9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT
M($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT
M($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*(RP@
M9G5Z>GD*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(MBHV*?8L=BGV88@
MV*_;C-BQV8?9AMJOV*?9A2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(MF'
MV878I]F&(-J&V*?8L=J&V8C8J"`HV*[9B-BOV+0I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PHC+"!F=7IZ>0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`BV8?8L=BRV8;8I]F%
MV8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")386X@36%R:6YO
M(@IM<V=S='(@(MBMV*?8M-N,V8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(MF(V+;8N=N,V*H@V*W9B-BRV8?B@(S9
MA]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I
M9"`B4V%V92(*;7-G<W1R("+8K=F!V+@@VJG8L=BOV88B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("+8K=F!V+@@
MVJG8L=BOV88@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@
M(MBMV8'8N"#:J=BQV*_9AB`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("+8K=F!V+@@VJ_8
MLMN,V8;9A^*`C-F'V*<B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W
M"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E
M8W1O<GDN(@IM<V=S='(@(MF^VXS:J=BQV*C9AMBOVXP@V*K9B-F$VXS8KR#8
MM-BOV8<@V*C8N=F&V8C8I]F&(-BOV+/8JB#B@(S9AMF(VXS8LR!02%`@V*_8
ML2#8M-BGV*[9A]F4(-F%V8C9@MBJ(-JIV*?8L=BSV*?8LB#8M-F%V*<@V*W9
M@=BX(-BTV8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(MF^VXS:J=BQV*C9AMBOVXP@)7,@V*W9@=BX(-BTV*\B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BV*_8L]BJ(.*`C-F&V8C;C-BS(-BH
MV+'9B-BRV+'8L]BGV8;;C"#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@V*W9@=BX
M(-BTV*\@V*_8L2`Z)R5S)R`N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(E-C871T97)E9"!4
M+5-T;W)M<R(*;7-G<W1R(")4+5-T;W)M<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("+8N=F$V84B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@
M(MBLV+/8JN*`C-F(V*S9B"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(MBLV8C;C-BT
MVJ_8L=F'V*<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS
M9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F^V+'9
MB-F&V*_9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@T"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(MBGV8;8JMBNV*?8J"#;C-JI(-BJV*?8L=N,V*XB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@
M861D(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-JOV+'9B-F'(-BHV+'8
MI]N,(-BGV+;8I]F!V8<@VJG8L=BOV88B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T
M<B`BV*?9AMBJV*[8I]BH(-N,VJD@V878I]F$VJD@V*S8K]N,V*\B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A
M('-E<G9E<B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#:J=BGV+'8L]BG
MV+(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B
M4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,
MVJD@VJG8I]BQV*C8L2#8J-BQV*?;C"#8I]BVV*?9@=F'(-JIV+'8K]F&(@H*
M(R`C+2,M(RTC+2,@(&9A7TE2+G!O("A4=7)B82`Q+C(N,BD@(",M(RTC+2,M
M(PHC(&US9VED(")396%R8V@@4F5S=6QT<R(*(R!M<V=S='(@(MF&V*K8I]N,
MV*P@V*S8L]BJV*S9B"(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("+8I]F&
MV*K8KMBGV*@@V8?9A=F'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8V,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S
M='(@(MBGV8;8JMBNV*?8J"#8JMF%V*?9A2#9A=BDV839@=F'XH",V8?8I]N,
M(-BJV*?8L=N,V*XB"@HC(",M(RTC+2,M(R`@9F%?25(N<&\@*%1U<F)A(#$N
M,BXR*2`@(RTC+2,M(RTC"B,@;7-G:60@(E-E87)C:"!297-U;'1S(@HC(&US
M9W-T<B`BV8;8JMBGVXS8K"#8K-BSV*K8K-F((@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@
M;V)J96-T(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-BTV*8B"@HC(",M
M(RTC+2,M(R`@9F%?25(N<&\@*%1U<F)A(#$N,BXR*2`@(RTC+2,M(RTC"B,@
M;7-G:60@(E-E87)C:"!297-U;'1S(@HC(&US9W-T<B`BV8;8JMBGVXS8K"#8
MK-BSV*K8K-F((@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("+8I]F&V*K8
MKMBGV*@@V8?;C-J&XH",VJG8K]BGV84B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R
M("(B"B+9AMF(VXS8L]F'XH",V8?8I]N,VXP@VJG9AR#9A-BGV++9A2#8K]BG
MV+';C-BO(-BQV*<@V*?8LB#8K-BYV*C9AR#8LMN,V+$@V*?9AMBJV*[8I]BH
M(-JIV8;;C-BO+B#8L]F^V+,@V+39A=BG(-F%VXSB@(S8JMF(V*?9AMN,V*\@
MV*?8LB#8HMF&V8?8IR`B"B+8K]BQ(-F%V8;8M]F"V8<@V878JMF&(-F&V+/8
MKMF'XH",V*C8L=BOV*?8L=N,(-JIV+'8K]F'(-F((-BOV+$@V878K=F$(-BO
MVXS:K]BQ(-BHVH;8L]BHV*?9AMN,V*\B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB
M"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F%V*W8K]F(V*_9AR#8JMBGV+';C-BN
M.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8+8
MI]F$V*@@V*K8I]BQVXS8KCHB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO
M=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F'V8C;
MC-F1V*K;C"#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*K8NMN,VXS8L2#8
MK]F'VXS8KSHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I
M9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`BV*?9AMBJ
MV*[8I]BH(-F%V*W8K]F(V*_9A]F4(-BRV878I]F&.B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R
M;6%T.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8+8I]F$V*@@V++9A=BGV88Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(MBGV8;8JMBNV*?8
MJ"#8K]F((-F!VXS9A-BO(-F%V8;8M]BHV8(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#8M]BQV*T@V+'9AMJO(-BTV878IR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`BV*?9AMBJV*[8I]BH
M(-BRV*C8I]F&(-F%V8C8L=BO(-F&V+C8L2#8M-F%V*<Z(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`BV*?8L=BSV*?9A"#:K]BRV*?8L=BT(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G
M:60@(E-E;F0@4TU3(@IM<V=S='(@(MBGV+'8L]BGV80@4TU3(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`BV*W8
ML]JOV+$Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`BV+/9OMBJV*?9A=BH
MV+$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM
M<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(MBGV+G8K]BGV*\@V*K8L=BJVXS8J-N,(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM
M<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`BV*C9A-F(VJD@365T87(@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,
MV+/8JB(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I
M9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("+8L]BQV;[8L=BSV*K;C"#9A=BL
MV8C8LMF'V*<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS
M9W-T<B`B240@V8;8M-BSV*H@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ(@H*
M(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*
M;7-G<W1R("+9A=BLV8C8LMF'V*<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`BV*K9AMBXVXS9A2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@
M=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V
M97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B+8JMF&V+C;C-F%(-JOV++;C-F&
MV8?B@(S9A]BG(-BHV+'8I]N,(-BGV*S8I]BRV8<@V*_8I]BOV88@V*C9AR#8
MM-F%V*<@V*C8L=BGVXP@V*C8I]BRV8;8M-BGV8;;C"#8I]BSV84@V+'9A=BR
M(-BHV8<@V8?9AMJOV*?9A2#9@=BQV*?9A=F(V+3;C"`B"B+8HMF&("(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+B(*;7-G<W1R("(B"B+8JMF&V+C;C-F%(-JIV*?8L=BSV*?8LMF'
MV*?;C"#8L=BGV8<@V*_9B-BQVXP@VJG9AR#8M-F%V*<@V87;C.*`C-BNV8C8
MI]F'VXS8KR#8I]BR(-BOV+':K]BGV8<@V*[9B-BO(-BHV8<@V*+9AB#8K]BS
MV*K8L=BSVXP@V*_8I]BTV*K9AR`B"B+8J-BGV+3;C-BO(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@
M(MBGV8;8JMBNV*?8J"#8LMBHV*?9AB#9A=F(V+'8KR#9AMBXV+'8C"#8L]BG
MV+G8JB#9B"#:K]BRVXS9AMF'XH",V8?8I]N,(-BJV*?8L=N,V*XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("+8
MI]F&V*K8KMBGV*@@V*C8L=F&V*?9A=F'(-BRV878I]F&(-BTV+'9B-BYV(P@
MV+?8L=BM(-BQV8;:K]B,(-BHV*?8LMBBV8C8L=N,(-BUV8'8K=F'(-F((-BH
MV8+;C-F'(-JOV++;C-F&V8?B@(S9A]BGVXP@V8;9A=BGVXS8M"(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@
M(MBQV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,(@H*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P
M9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`BV*_8L]BJ(.*`C-F&
MV8C;C-BS("#8J-BQV8C8LMBQV+/8I]F&VXP@V+'8I]F'XH",V*?9AMBOV*?8
MLMN,(-BOV+$@V*_8L]BJV+'8LR#8I]BSV*HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P
M;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("+:AMF&V*_;
MC-F&(-F%V8C9@MBYVXS9D=BJ(-BHV*<@V;[8I]BQV*?9A=BJV+$@V879A=JI
MV88@V*?8L]BJ.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM
M<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`BV*[8L=N,V*\B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R
M>2(*;7-G<W1R("+8KMF$V*?8M=F'(-JIV8C8JMBGV8<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@
M8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`BV*+;C-BG(-JI
MV83;C-BOV8?8I]N,(-BOV+/8JMBQV+/;C"#8J-BGVXS8KR#8J-BQV*?;C"#8
MJ-N,V+38JMBQ(-F^VXS9B-F&V*_9A]BG(-BJV+G8L=N,V8$@V+39B-F&V*_8
MGR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS
M9VED(")3:&]W(@IM<V=S='(@(MF&V878I]N,V+0B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B#9AMF%V*?;C-BT(-BJV8'8
MI]F(V*K9A]BGVXP@V87;C-BGV88@V;[;C-JIV+'8J-F&V*_;C"#8K=F!V+@@
MV+38K]F'(-F!V+G9A-N,(-F((-BJV8C9A-N,V*\@V+38K]F'(-BLV*_;C-BO
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("+8HMN,
MV*<@V++9A=BGV88@V*+8KMBQVXS9AB#9B-BQV8C8KR#8J-F'(-F'V8;:K]BG
MV84@V8C8L=F(V*\@V8;8M-BGV88@V*_8I]BOV8<@V+39B-BOV)\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO
M;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(MF&V878I]N,V+0@VJ_8LMN,
MV8;9A^*`C-F'V*<@V*C8L=BGVXP@V8;:K]F'V*_8I]BQVXP@V*?8M=F$(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P
M:6-K97(B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F#V8;9AMBOV8<@V8;9A=BG
MVXS8M"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BV*+;C-BG
M(-F%VXS9A-F'(-JOV++;C-F&VJ_8I]F&(-BYV879A-N,V*?8JB#8K-BOV8C9
MA.*`C"#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("+8HMN,
MV*<@VJ_8LMN,V8;:K]BGV88@)7,@V+/9A=BJ(-BQV*?8L]BJ(-F&V+38I]F&
M(-BOV*?8K]F'(-BTV8C8K]B?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(MF&V878I]N,
MV+0@VJ_9@=BJXH",V8C:K]F(VXP@V*[8M=F(V+7;C-BGV*H@V+/9A-F(V80@
MV*S8K]F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(MF&V878I]N,V+0@VJ_9@=BJVJ_9B-N,
M(-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BV8;9
MA=BGVXS8M"#:K]F!V*K:K]F(VXP@V*[8M=F(V+7;C-BGV*H@V+/8M]BQ(-BL
MV*_9B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("+9AMF%V*?;C-BT(-JOV8'8JMJOV8C;C"#8
MKMBUV8C8M=N,V*?8JB#8JMBUV8C;C-BQ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`BV8;9
MA=BGVXS8M"#8I]BQV+/8I]F$(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`BV*K:
MK]BQVJ\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("+8L=JOV*C8I]BQ
M(-BRV8C8K]F'V8;:K]BGV84B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@
M(MBQVJ_8J-BGV+$@V*_;C-BQV8?9AMJOV*?9A2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN
M('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("+8
MK-F%V+D@V+38K]F&(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S
M-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("+8K-F%
MV+D@V+38K]F&(-N,V*<@V*?9AMBJV8+8I]F$(-BHV839B-JIV8?8I]N,(-F%
MV*S8I]F(V+$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("+8J]BHV*H@V8;8I]F%(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@
M(E-I9VYA='5R92(*;7-G<W1R("+8I]F%V+;8I]BA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!
M;&=O<FET:&TB"FUS9W-T<B`BV*?9A-JOV8C8L=N,V*K9A2#8I]F%V+;8I]BA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4VEN9V%P;W)E(@IM
M<V=S='(@(MBGV878MMBGV*$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(MBGV8;8K]BGV++9AR(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS
M9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(MBUV+'9@=F&V+C8L2#8
MI]BR(-F&VJ_9A]BOV*?8L=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`BV*C8L=F!(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@
M(E-N;W<@4VAO=V5R(@IM<V=S='(@(MBJVJ_8L=JO(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO
M=V5R<R(*;7-G<W1R("+8JMJOV+':KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`BV+':K]BHV*?8L2#8LMF(V*_9A]F&VJ_8I]F%(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@
M(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(MBQVJ_8J-BGV+$@V*_;C-BQ
MV8?9AMJOV*?9A2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED
M(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`BV+G9A=F"(-BHV+'9@3H@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N
M="!I;B!W871E<CH@(@IM<V=S='(@(MF%V+G8I]BOV80@V*C8L=F!(-BOV+$@
MV*+8J#H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3
M;VYG<R`F(%!O96US(@IM<V=S='(@(MBTV+G8L=F'V*<@V8@@V*+9B-BGV++9
MA]BG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I9"`B
M4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BL
MV8?8JB#9A=BQV*K8J"#8L]BGV++;C"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C
M92!A9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-BSV+':AMBTV879AR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(E-O=71H($5U<F]P96%N("A)4T\M
M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM
M<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("+9AMN,V84@VJG8
ML=F'(-BLV8;9B-BHVXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<R(*;7-G<W1R("+9@=BGV+79A-F'V90@V*C;C-F&(-BSV839B-F$
MV8?8I]N,(-F%V*S8I]F(V+$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("+9@=BGV+79A-F'V90@
MV*C;C-F&(-F%V*W8JMF(V*<@V8@@V838J-F'(-BOV+$@V+/9A-F(V80B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*
M;7-G<W1R("+9@=BGV+79A-F'XH",VJ_8L-BGV+$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P
M86-I;F<B"FUS9W-T<B`BV8'8I]BUV839AR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`BV8'8I]BUV839A^*`C-JOV+#8I]BQ
MVXP@V8@@V*_8L=BRVJ_8L-BGV+';C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY
M"FUS9VED(")3<&%I;B(*;7-G<W1R("+9@=BGV+79A-F'(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(MF'
MV+'8LMF&V*?9A=F'(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS
M9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("+:J=BGV+'8
MI]JIV*K8L2#8KMBGV+4@V8C8I]BQV*\@V+38KR(*"B,@(RTC+2,M(RTC("!F
M85])4BYP;R`H5'5R8F$@,2XR+C(I("`C+2,M(RTC+2,*(R!M<V=I9"`B4V5A
M<F-H(%)E<W5L=',B"B,@;7-G<W1R("+9AMBJV*?;C-BL(-BLV+/8JMBLV8@B
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`BV*K9@MBSVXS9A2#8
ML]F$V8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("+8
MJMF"V+/;C-F%(-BSV*K9B-F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM
M<V=S='(@(MBJV8+8L]N,V84@V+/8M]BQ(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`BV8C8L=BRV+3;C"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S
M='(@(MBLV878N2#8M-BOV88B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A
M<F0B"FUS9W-T<B`BV*?8L]BJV*?9AMBOV*?8L=BO(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`BV+/8
MJMBGV+'9AR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*
M;7-G<W1R("+8L]BGV80@V+38L=F(V+DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B
M"FUS9W-T<B`BV8C8MMBYVXS8JB#8K=F(V++9A^*`C-F'V*<B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(MF(V+;8N=N,V*KB@(PB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$U"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("+9
M@MBGV838J"#8L-BNVXS8L=F'(-BSV*?8LMN,(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S
M(@IM<V=S='(@(MBBV*_8L=BS(-BNVXS8I]BHV*?9AB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK
M971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BV8'9A]BQV+/8
MJB#8L=BTV*K9AR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*
M;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(MBTVXS9B-F'
M(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`BVXS:J=BTV8;8J-F'(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(-BRVXS8L=BTV*?8KMF'("<E<R<@V;[;C-BOV*<@V8;8M-BO+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G
M:60@(E-U8FIE8W0B"FUS9W-T<B`BV+G9AMF(V*?9AB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("+8I]BQV+/8I]F$
M(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U
M97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B+8JMF"V*?8MMBG
MVXP@V*?8MMBGV8'9AR#8M-BOV88@)R5S)R#8J-F'(-BSV*?9A=BGV8;9AR#8
MI]BQV*?8IMF'(-BTV*\N(-BJV*<@V8?9AMJOV*?9A=N,(-JIV8<@V*K9@MBG
MV+;8I]N,(-BTV878IR#8JMBCVXS;C-BO("(*(MF&VJ_8L=BOV*\@V8;9A=N,
MXH",V*K9B-BGV8;;C-BO(-BHV8<@V+/8I]F%V*?9AMF'(-F(V*?8L=BO(-BT
MV8C;C-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(MBRVXS8L=F&V8C;
MC-BS(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(MF%V8C9@=F1V8+;C-F1V*HB
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B(*;7-G<W1R("(G)7,G(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8
MJ-F'(-BSV*?9A=BGV8;9AR#8I]BVV*?9@=F'(-BTV*\B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(-BOV*?8K]F'V90@VJG8I]BQV*C8
ML2`G)7,GV*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BGV+(@V+/8I]F%V*?9AMF'
M(-F^V*?:J2#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB
M(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=BPV8$@V+38KR(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B)R5S)R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*?8LB#8
ML]BGV878I]F&V8<@V;[8I]JI(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R
M("(B"B+9OMN,VJG8L=BHV8;8K]N,(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8
MJ-BGV++:K]BQV*_8I]F&V*_9AR#8M-BO+B#8J-BQV*?;C"#9A=BTV*?9A]BO
MV8<@V*K8NMN,VXS8L=BGV*H@V878K-BOV*_8I]F2(-BBV8;8L=BG(-BHV*?8
ML2#9AMF%V*?;C-N,V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
MV;[;C-JIV+'8J-F&V*_;C"#9OMBTV*K;C-BHV*?9AB#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*W9@=BX(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS
M9W-T<B`BV;[8L=F(V8;8K]F'(-F^V+38JMN,V*C8I]F&(-F^VXS:J=BQV*C9
MAMBOVXP@)7,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BMV8'8N"#8M-BO(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T
M<B`B)R5S)R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C9AR#8L=F(V+(@V+38
MKR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R#8J-BG(-F%V8C9@=F1V8+;
MC-F1V*H@V8;9B-BTV*K9AR#8M-BO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ
M>0IM<V=I9"`B4W5D86XB"FUS9W-T<B`BV*+9@=BJV*?8J-N,(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM
M<V=I9"`B4W5M;6%R>2(*;7-G<W1R("+8KMF$V*?8M=F'(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("+8
MM]F$V8C8N2#8HMF!V*K8I]BH(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(MBZV+'9B-BH(-BBV8'8JMBG
MV*@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`BV*+9@=BJV*?8J-N,(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*
M;7-G<W1R("+8M]F$V8C8N2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS
M970B"FUS9W-T<B`BV+?9A-F(V+DOV+K8L=F(V*@B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T
M<B`BV+?9A-F(V+DZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("+8NMBQV8C8J"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@
M(@IM<V=S='(@(MBZV+'9B-BH.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G
M<W1R("+8J-BGV838I]F&V8C;C-BS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,W.`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("+9OMBTV*K;C-BH
MV*?9AMN,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA
M;64B"FUS9W-T<B`BV8;8I]F%(-BNV*?9AMF(V*?8K]JOVXPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B4W5R;F%M
M92(*;7-G<W1R("+9AMBGV84@V*[8I]F&V8C8I]BOVJ_;C"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(E-Y
M;F,@;&]G(&1E;&5T960B"FUS9W-T<B`BV*W8L-F!(-F&V+39B-BO(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM
M<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("+8
MKMBWV*?;C"#9AMBMV8C;C"#8K]BQ(-F%V8C8I]BQV*\@V*S8L]BJV*S9B"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(E0M4W1O<FUS(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@
M(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*
M;7-G<W1R(")4+5-T;W)M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L
M>2(*;7-G<W1R("+8L=JOV*C8I]BQ(-BRV8C8K]F'V8;:K]BGV84B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL
M92(*;7-G<W1R("+9OMBQV8C9AMBOV8<@5%-6(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(MBLV*_9
MB-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("+8
MKMBUV8C8M=N,V*?8JB#8K-BOV8C9A"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE
M(%-E="(*;7-G<W1R("+8K-BOV8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R
M;W!E<G1I97,B"FUS9W-T<B`BV*[8M=F(V+7;C-BGV*H@V*S8K]F(V80B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Q"B,L(&9U>GIY"FUS9VED(")486EW86XB"FUS
M9W-T<B`BV*C8I]BQV*?9AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM
M<V=S='(@(MF'V*_9@3HB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM
M<V=S='(@(MF(V+C8I]N,V8$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R
M("+8M-F%V*?8L=F'(-BJV839@=F&(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(MBO
MV878I]N,(-BSV*?8N=BJ(-BGV*[;C-BQ.B`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`BV*_8L=BL
MV8<@V*W8L=BGV+'8JB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`BV*_8L=BLV8<@
MV*W8L=BGV+'8JCH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(@*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,@V*_9A=BG(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B#8I]F$
MVJ_9B-N,("<E<R?9OMN,V*_8IR#9AMBTV*\B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`BV*?9A-JOV8C;C"#8L]BQV;[8L=BSV*K;C"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("+9A=BJV88B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
MV8'9@MBW(-F%V*K9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T
M<B`BV*K8L=BGV+(@V878JMF&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("+8
MJ-BGV838I]N,(-F%V*K9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(MF^V8;8K-BT
MV8;8J-F'(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H
M86D@*%1)4RTV,C`I(@IM<V=S='(@(E1H86D@*%1)4RTV,C`I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S
M:6YG('1H92!S>7-T96TN(@IM<V=S='(@(MBGV+(@V+39A=BG(-BHV8<@V*[8
MI]BWV+$@V*?8L]BJV8'8I]BOV8<@V*?8LB#8L]BGV878I]F&V8<@V878JMBT
MVJG8L=N,V84B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`BV*C8L]BW($944"#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"B,L(&9U>GIY"FUS
M9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*
M;7-G<W1R("+9OMBQV8C9AMBOV8<@V*?8L=BSV*?9A"#8M-BOV8<@V8;9A=N,
MXH",V*K9B-BGV8;8KR#8K=F!V+@@V+39B-BO(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(MF&VJ_9A]BO
MV*?8L=N,.CH@VJG9A-BGV+,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV*?8
ML2#9AMBTV*\B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI
M=&EN9RXB"FUS9W-T<B`BV;[9AMBLV+'9A]F4(-JOV++;C-F&V8?B@(S9A]BG
M(-BHV+/8JMF'(-BTV*\N(-BNV+'9B-BL(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB
MV+/8L=F^V+'8L]BJ(-BHV*?;C-BO(-N,VJD@V;[8M-BJVXS8J-BGV88@V878
MK-F(V++9A]BG(-BQV*?8C"`@V*_8L2#8M=F(V+'8JB#8JMF%V*?;C-F$(-BT
MV878IR#8J-F'(-BGV+/8JMF!V*?8K]F'(-BGV+(@V878K-F(V++9A]BGV(P@
M(@HBV;[;C-JIV+'8J-F&V*_;C"#:J=F&V*\N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE
M(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`BV*K9AMF'V*<@V+/9A=BJ(-F^
MV*?;C-N,V88B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("+8M-F%V*?8L=F'($E$
M(-BJV878I]BS(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JMB,(-BGVXS9AB#8
MM-F%V*?8L=F'(-BOV+$@V*_8I]BOVJ_8I]F&(-N,V*?9@=BJ(-F&V+38KR(*
M"B,@"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BV*K9A=BGV+,@("5S(-BH
MV*<@V879B-F!V9'9@MN,V9'8JB#8J-F'(-JIV*K8I]BHVH;9AR#8HMBOV+'8
MLR#8M-F%V*<@V*?8MMBGV8'9AR#8M-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'
M4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S
M:6=N960@;65S<V%G92XB"FUS9W-T<B`BVXS:J2#8J-F$V8C:J2#8I]F%V+;8
MI]N,(%!'4"#8J-BQV*?;C"#8J-BGV++8J-N,V8;;C"#;C-JI(-F^VXS8NMBG
MV84@V*?9A=BVV*?8H2#8M-BOV8<@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B240@V8'9A]BQV+/8JB#8
MJMF(V++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ(-F((-N,V*<@
MV*_8L2#8K]BGV*_:K]BGV88@V879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS
M9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M(@IM<V=S='(@(MF!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-F%V+38KMBU(-F&
MV+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z
M,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("+9A=BTV*[8M=F'XH",
MXH",V8?8I]N,(-BQV878LMBHV8;8K]N,(-F&VXS8I]BRV879AMBO(-N,VJD@
MV*?8L=BJV+78I]F$(-BGV879AB#9B-BH(-F%VXSB@(S8J-BGV+39AMBO(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("+9
MOMBQV8C9AMBOV8<@)7,@V*C8I]N,V*\@V*_8I]BQV*?;C"#8JMF&V+C;C-F%
M("5S(-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RXB"FUS9W-T<B`BV;[8L=F(V8;8K]F'("5S(-BHV*?;C-BO(-BM
MV*?9B-N,(-BJV8;8N-N,V878I]BJ("5S(-BHV*?8M-BO(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@
M;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`BV;[8L=F(V8;8
MK]F'(-BHV+$@V+'9B-N,(-BNV8C8K]BT(-F&V87;C.*`C-BJV8C8I]F&V*\@
MV+'9B-F&V8C8M-BJ(-BTV8C8KR(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(MF^V+'9B-F&V*_9AR#8K=BGV8C;C"#8K]BGV*_9A^*`C-BGXH",
MVXS;C"#9AMN,V+/8JB`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E
M<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E
M;B!E9&ET;W(N(@IM<V=S='(@(B(*(MF%V*\@V*K9A=BGV84@V+79@=BMV8<@
MV*C8IR!)12#9A=BTVJG9A"#8K]BGV+'8KR#9B"#8I]N,V88@V*?8LB#9A=BT
MVJG9A-BGV*H@V878L=F(V+':K]BQ(-F%VXSB@(S8J-BGV+38KRX@V*?:K]BQ
M(-F'V8;9B-BR("(*(MF%VXSB@(S8KMF(V*?9A]N,V*\@V*W8I]F$V*H@V8C;
MC-BQV*?;C-BTVJ_8L2#8JMF%V*?9A2#8M=F!V*W9AR#8L=BG(-BGV878JMBM
MV*?9AB#:J=F&VXS8K]B,(-F$V+?9@=BGV8L@VJG9A-N,V*\@V*K8H]N,VXS8
MKR#8L=BG(-F!V+38I]BQ("(*(MBOV8?;C-BO("(*"B,@"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I
M='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(MF'V8C;C-F1
MV*H@7"(E<UPB(-BMV+#9@2#8M-BOV8<@V*?8L]BJ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`BV*K9AMF'V*<@V+/9
MA=BJ(-J&V;XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N
M7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HBV;[;C-BZ
MV*?9A2#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V+'9B-N,("5S(-BHV8<@)7,@
MV*C8IR#9A=F(V+;9B-BY(%PB)7-<(B#9AMF%V*?;C-BT(-BOV*?8K]F'(-BT
MV*_9AR#8I]BSV*HN7&XB"B+8JMBVV87;C-F&VXP@V*C8L=BGVXP@V*[9B-BG
MV8;8K]F'(-BTV*_9AB#9B"#;C-BG(-BOV+':J2#8HMF&(-F(V*S9B-BO(-F&
MV*_8I]BQV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS
M9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP
M;W-E('!A9V4B"FUS9W-T<B`BV8;8I]F%VXP@VJG9AR#8J-F'(-F'V8;:K]BG
MV84@V;[;C-F(V8;8K]BOV8?;C"#8J-F'(-BUV8'8K=F'(-BGVXS8K-BGV*\@
MV8;8I]F%V8<@V*?8L]BJV8'8I]BOV8<@V87;C.*`C-BTV8C8KR(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0IM<V=I9"`B5&AE(&YU;6)E
M<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("+8JMBYV*_8
MI]BO(-F!VXS9A-BOXH",V8?8IR#8J-BGVXS8KR#;C-JI(-BYV*_8KR#8J-BG
MV+38KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S
M,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M
M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(MBGV8C9A-F(VXS8JB!<(B5S
M7"(@V8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!V+@@VJ_8L=BOV*\@V++;C-BQ
MV*<@V879@MBOV*?8L2#8K]BGV*_9AR#8HMF&(-BGV+(@V*W8KR#9A=BLV*?8
MLB#8J-N,V+38JMBQ(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HBV*C8
ML=F&V*?9A=F'XH",V*?B@(S;C-N,(-JIV8<@V*C8L=BGVXP@V878M-BGV8?8
MK]F'(-BGVXS9AB#9AMF(V+D@V*_8I]BOV8<@*"5S*2#9@MBHV838I]F+(-F%
MV8C8L=BO(-BGV+/8JMF!V*?8K]F'(-F"V+'8I]BQ(-F%VXSB@(S:K]BQV8'8
MJMB,(-BOV+$@(@HBV+/8I]F%V*?9AMF'(-F%V8C8K-F(V*\@V8;;C-BSV*HB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*(RP@9G5Z>GD*
M;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`BV*S8K]BG(-JIV8;9AMBOV8<@V*C8I]N,
MV*\@VXS:J2#9AMF(VXS8L]F'(-BHV*?8M-BO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`BV*K9AMF'V*<@
MV+/9A=BJ(-BQV*?8L]BJ(-F((-J&V;XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`BV*K9AMF'V*<@V+/9A=BJ(-BQ
MV*?8L]BJ(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS
M9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N(@IM<V=S='(@(MBLV*_8IR#:J=F&V8;8K]F'(-BHV*?;C-BO(-N,VJD@
MV8;9B-N,V+/9AR#8J-BGV+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V
M97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(MJIV*?8L=BS
MV*?8LB!<(B5S7"(@V*W8L-F!(-BTV*_9AR#8I]BSV*HB"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`BVJG8I]BQV+/8I]BR(%PB)7-<(B#8K=F!V+@@V+38K]F'(-BGV+/8JB(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N(@IM<V=S='(@(MBOV+'8KMF(V*?8L]BJ(-BGV8'8JMBJV*?8K2#8K=BS
MV*?8J"#8J-BQV*?;C"`E<R#8K=BPV8$@V+38K]F'(-BGV+/8JB(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE
M('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(MBQV*_;
MC-F!(-F%V+38KMBU(-BTV*_9AR#9B-BLV8C8KR#9AMBOV*?8L=BO(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`BV;[8L=F(V8;8K]F'(-F%V8C9@MBJVXP@(%PB)7-<(MF%
MV8C8K-F(V*\@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA
M=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*
M;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@
M(MBJV8;9A]BG(-BSV878JB#8J-BGV838IR#9B"#9OMBGVXS;C-F&(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`BV*K9AMF'V*<@
MV+/9A=BJ(-BHV*?9A-BG(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`BV*_8I]BOV8?9E"#8I]BQV+/8
MI]F$(-BTV*_9AR#8I]BR(-JOV*?9A2#9@MBHV83;C"#8I]BR(-BOV+/8JB#8
ML=F!V*K9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP
M:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@
M(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T
M<B`BV;[8L=F(V8;8K]F'(-BGV+'8L]BGV80@V+38K]F'(-F&V87;C.*`C-BJ
MV8C8I]F&V*\@V*W9@=BX(-BTV8C8KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@
M8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BV*C9A-F(VJD@=V5A
M=&AE<BYC;VT@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,V+/8JB(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("+8M-BGV*[9AR#8JMF%("<E<R<@VXS8I]F!V*H@V8;8M-BO(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E
M(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`BVJ_8LMN,V8;9
MA^*`C-BGXH",XH",VXS;C"#8K]BQ(-BOV+/8JMBQV+,@V8;;C-BSV*HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@
M(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+B(*;7-G<W1R("+8J-BNV+3;C"#:J=F'(-BHV*K9B-BGV8;8KR#8J-BQ
MV*[8MR#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8KR#9A=F(V*S9B-BO(-F&
MVXS8L]BJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`B(@HBV8;9B-N,V+/9A^*`C-F'V*?;C"#8LMN,V*?8K]N,(-BOV+$@V*?;
MC-F&(-F!VXS9A-BO(-F"V+'8I]BQ(-BOV*?8L=BO+B#8M-F%V*<@)7,@V8;9
MB-N,V+/9AR#9B-BGV+'8KR#:J=BQV*_9A^*`C-BGXH",VXS8KR#8K]BQ(-BM
MV*?9A-N,(-JIV8<@(@HBV+39A=BG(-BHV*?;C-BO(-JIV878JMBQ(-BGV+(@
M)7,@V8;9B-N,V+/9AR#9B-BGV+'8KR#:J=F&VXS8KR(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-I
M9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<
M(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("+9A=BTVJG9A-N,(-BOV+$@
MV*?8MMBGV8'9AR#:J=BQV*_9AB`G)7,G(-BHV8<@V+/8I]F%V*?9AMF'(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N
M<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TZ("(*;7-G<W1R("+9A=BTVJG9A-N,(-BOV+$@V;[8I]JI
M(-JIV+'8K]F&(-BOV*?8K]F'V90@VJG8I]BQV*C8L2`G)7,G(-BGV+(@V+/8
MI]F%V*?9AMF'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;3H@(@IM<V=S='(@(MF%V+3:J=F$VXP@V*_8L2#8K=BPV8$@)R5S
M)R#8I]BR(-BSV*?9A=BGV8;9AR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<
M(CH@)7,B"FUS9W-T<B`BV878M-JIV83;C"#8K]BQ(-BHV+'9B-BRV+'8L]BG
MV8;;C"`G)7,G(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<R(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(MF%V+3:J=F$VXP@V*_8
ML2#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#8L=BN(-BOV*?8K]F'(-BGV+/8
MJCH@)7,@V*?8L=BSV*?9A"#9AMBTV*\B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HBV878M-JIV83;C"#8K]BQ(-BGV+'8
ML]BGV80@V;[8L=F(V8;8K]F'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B#8I]F&
MV*_8I]BRV8<@)7,@V*C;C-BTV*K8L2#8I]BR(-BMV*\@V878K-BGV+(@V*C9
MB-BOV8<@V*?8L]BJ("@@)60@(@HBV*C8I]N,V*HI+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R
M("(B"B+9A=BTVJG9A-N,(-BOV+$@V*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<@
MV8C8K-F(V*\@V*_8I]BTV*K9AR#8I]BSV*HZ("`E<R#8J-F'(-BUV8C8L=BJ
M(-BJVJG9A^*`C-BGXH",VXS;C"#8I]BQV+/8I]F$(-BTV*_9AR#8I]BSV*H@
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS
M-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0B"FUS9W-T<B`BV*[8M]BGVXS;C"#8K]BQ(-F&V878I]N,
MV+0@V*?;C-F&(-BHV*[8M"#9OMN,V+K8I]F%(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT
M.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N
M=&%C="!D871A+B(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@V*_8L=F(V8;B
M@(S8J-BQV*\@VJG8L=BOV88@V*_8I]BOV8<@V*K9A=BGV+,@V+'8KB#8K]BG
MV*_9AR#8I]BSV*HB"@HC(`HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP
M:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@V*_8
ML=F(V8;B@(S8J-BQV*\@VJG8L=BOV88@V*_8I]BOV8?9E"#8JMF"V8C;C-F%
M(-BQV*X@V*_8I]BOV8<@V*?8L]BJ(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB
M<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(MBNV+?8I]N,VXP@V*_8L2#9
MOMN,VJG8L=BHV8;8K]N,(-F!V+'9A2#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@
MV+38I]N,V*\@V8';C-F$V*\@V879B-BQV*\@V8;;C-BGV++;C"#8L=BG(-BL
MV*<@V*?9AMBOV*?8KMBJV8?B@(S8I^*`C-N,V*\B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A
M9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(MBNV+?8I]N,VXP@V*_8L2#8I]BLV+'8IR#:J=BQ
MV*_9AB#8N=F%V83;C-BGV*H@V878M-BNV+4@V+38K]F'V90@VJG8JMBGV*C:
MAMF'(-BBV*_8L=BS(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#9A-BWV8'8I]F+
M(-BOV8C8J-BGV+'9AR#8L]BYVXP@(@HBVJG9AMN,V*\B"@HC(`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(MBN
MV+?8I]N,VXP@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V*S8LMBFVXS8I]BJ
M(-BJV878I]BS(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#9A-BWV8'8I]F+(-BO
MV8C8J-BGV+'9AR#8L]BYVXP@VJG9AMN,V*\B"@HC(`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BV*[8M]BGVXS;
MC"#8K]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#9@=F'V+'8L]BJ(-BJV8C8LMN,
MV+G;C"#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8
MI]BQV8<@V+/8N=N,(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(@
MVJG8I]BQV+/8I]BR($E-05#9OMF(V+39A^*`C-F'V*?;C"#9A=BTV*K8L=JI
M(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V*\B"@HC(`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+B(*;7-G<W1R("(@V*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JI
MV8<@V*+8L=BTVXS9B"!R87(@V878N=BJV*C8L=N,(-BHV*?8M-BO(@H*(R`*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92XB"FUS9W-T<B`B(-BHV8<@V8;8N-BQ(-F&V87;C.*`C-BQV+/8KR#:J=F'
M(-F^V+'9B-F&V*_9AR!Z:7`@V878N=BJV*C8L=N,(-BHV*?8M-BO(@H*(R`*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(MBHV8<@V8;8N-BQ(-F&V87;C.*`C-BQV+/8KR#:J=F'(-BTV878I]BQ
MV8<@VJG8I]BQV*H@V878N=BJV*C8L=N,(-BHV*?8M-BO(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@
M(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(MBGVXS9AB#9@=N,
MV838KR#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(MBGVXS9AB#9@=N,V838KR#9
MA=F%VJG9AB#8I]BSV*H@V+38I]F%V80@V*?8N=BOV*?8KR#8M=BMVXS8K2#8
MJ-BGV+38KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T
M:&4@8V]L;VXN(@IM<V=S='(@(MBGVXS9AB#9@=N,V838KR#9A=F%VJG9AB#8
MI]BSV*H@V+38I]F%V80@V*?8N=BOV*?8KR#9B"#9B-N,V+':K]F(V80@V*C8
MI]BTV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*
M;7-G<W1R("+8I]N,V88@V8';C-F$V*\@V879A=JIV88@V*?8L]BJ(-BTV*?9
MA=F$(-F%V8+8I]BOVXS8L2#9A]BTV*H@V8?8M-BJVXP@V*C8I]BTV*\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<R(*;7-G<W1R("(B"B+8I]N,V88@V8';C-F$V*\@V*C8I]N,
MV*\@V*W8I]F(VXP@VJG8I]F%V*<@V8@@VXS8IR#9@=F'V+'8L]BJVXP@V*?8
MLB#8I]BYV*_8I]BO(-BUV*W;C-BM(-BLV*_8IR#8M-BOV8<@V*C8IR#9AMF(
MVXS8L]F'(-BNV*?9A-N,(-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N(@IM<V=S='(@(MBGVXS9AB#9@=N,V838KR#8J-BGVXS8KR#;
MC-JI(-BYV*_8KR#9A=BYV*K8J-BQ(-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T
M(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@
M9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@
M86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`BV*?;C-F&("5S(-F%VXSB@(S8J-BG
MV+38KR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@
M96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R
M;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C
M;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(MBG
MVXS9AB#9OMN,V+K8I]F%(-BHV*<@V878K-F%V8C8N=F'(-JIV*?8L=BGVJG8
MJMBQ("5S(-F&V8C8M-BJV8<@V+38K]F'(-BGV+/8JB#:J=F'(-BHV*<@V878
MK-F%V8C8N=F'(-JIV*?8L=BGVJG8JMBQ(-BTV878IR#9A=BJV8'8I]F(V*H@
M(@HBV*?8L]BJ(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*
M;7-G<W1R("+8I]N,V88@V+G8K]BO(-BMV*_8I]F"V80@V*C8I]N,V*\@VXS:
MJ2#8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G
M>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(MBGVXS9AB#:J=BGV+'8
ML]BGV+(@V;[8L=F(V8;8K]F'XH",V8?8I]N,('II<"#9B"!G>FEP(-BQV*<@
MV*C8I]BR(-F&V87;C.*`C-JIV8;8KR(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(MBGVXS9AB#8L]BGV878
MI]F&V8<@V*_8L2#8K=BGV80@V*W8I]BVV+$@V+K;C-BQ(-F!V+G8I]F$(-BG
MV+/8JB(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS
M9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(MBG
MVXS9AB#9A=F"V*_8I]BQ(-BHV*?;C-BO(-BYV*_8KR#8J-BGV+38KR(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<B"FUS9W-T<B`BV*?;C-F&(-F^V8;8K-BQV8<@V*C8I]N,V*\@V*?8LB#9
MOMF&V*S8L=F'V90@VJ_8LMN,V8;9A^*`C.*`C-F'V*<@V8'8L=BGV*[9B-BG
MV8;;C"#8M-F(V*\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("+8L=BYV*\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S
M(@IM<V=S='(@(MBHV83;C-BWV8?8IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS
M9VED(")4:6UE(@IM<V=S='(@(MBRV878I]F&(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M("+8L=BOVXS8I]BHVXP@V++9A=BGV88B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(MF"V*?9A-BH(-BR
MV878I]F&(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I
M9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B(-BGV8;8JMBNV*?8J"#8LMF%
MV*?9AB`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*
M;7-G<W1R("+8N=F&V8C8I]F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*
M;7-G<W1R("+8N=F&V8C8I]F&("C8L=BGV8?9AMF%V*?;C"#8HMF&VXPI.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*
M;7-G:60@(E1O(@IM<V=S='(@(MBHV8<B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@
M;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R
M("(B"B+8J-BQV*?;C"#8I]F&V*K8KMBGV*@@VH;9AMBO(-F!VXS9A-BOV(P@
MV*_:J=F%V8<@0W1R;"#8L=F(VXP@*%!#*2#;C-BG($-O;6UA;F0@V+'9B-N,
M("A-86,I(-BQV*<@V*_8L2#9A=BOV*H@VJG9A-N,VJD@(@HBVJG8L=BOV88@
MV8;:K]F'V*_8I]BQVXS8KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(MBGV878L=F(V+(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS
M9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G<W1R("+8J-F'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*
M;7-G<W1R("+9@=BQV*_8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G
M:60@(E1O;F=A(@IM<V=S='(@(MBGV878L=F(V+(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O
M<"(*;7-G<W1R("+8J-BGV838IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB
M"FUS9W-T<B`BVH;8I]BQVH;9B-BH(-BHV*?9A-BG("C8J-BGV838IRDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N
M<R(*;7-G<W1R("+8JMBQV*S9A=F'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS
M92(*;7-G<W1R("+8K]BQV+/8JB#9B"#;C-BG(-F&V*?8K]BQV+/8JB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G
M:60@(E1U(@IM<V=S='(@(MBSV8<@V+39AMBHV8<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R
M:VES:"`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K
M;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R
M:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T
M<B`BV*?9AMBJV*[8I]BH(-BNV8C8KR#8L=BG(-BJV*?;C-F^(-JIV8;;C-BO
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@
M(E4N5BX@:6YD97@Z("(*;7-G<W1R("+8M-BGV*[8M2!5+E8N(#H@(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U
M<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B
MV++;C-BQV*[8M^*`C-BOV*?8L2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C0Q,@IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("+8I]F%VJG8I]F&(-BOV+/8JMBQV+/;C"#8J-F'(-BT
MV*?8KMF'(%9&4R#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R
M(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`BV*?9A=JI
MV*?9AB#8I]BVV*?9@=F'(-JIV+'8K]F&(-BGV+?9A-BGV+G8I]BJ(-BGV+;8
MI]F!VXP@VJG8I]BQV*C8L2#8J-F'(-F'V8;:K]BGV84@V*O8J-BJ(-F&V*?9
MA2#9AMN,V+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+9AMF%
MVXSB@(S8JMF(V*?9AB#9A=BLV8C8LMF'V*<@V+'8IR#8J-BQV*?;C"#9OMBQ
MV8C9AMBOV8<@7"(E<UPB(-BJV+K;C-N,V+$@V*_8I]BO(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
MV8;9A=N,XH",V*K9B-BGV88@V878K-F(V++9A]BG(-BQV*<@V*C8L=BGVXP@
MV;[8L=F(V8;8K]F'("5S+R5S(%9&4R`@V*K8NMN,VXS8L2#8K]BGV*\B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ("5S(-BJV+K;C-N,V+$@V*_8I]BO
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9
MOMBQV8C9AMBOV8<@5D93(%PB)7-<(B#8L=BG(-BHV*?8LB#9AMF%V8C8KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@)7,O
M)7,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#8J-F'(-JIV*?8L=BSV*?8LB!344S9A=BJV+79A"#8M-BO(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8
MJ-BG(%-33"#9A=BJV+79A"#8M-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93
M(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BGV+(@V;[8L=F(
MV8;8K]F'(%9&4R#8L=F(V8;9B-BTV*H@V*K9A]N,V8<@V8;9A=F(V*\B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@7"(E
M<UPB(-BQV*<@V*?;C-BLV*?8KR#9AMF%V8C8KR(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*?;C-BL
MV*?8KR#9AMF%V8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@
MV+'8IR#8I]N,V*S8I]BO(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@7"(E<UPB(-BQV*<@
MV*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9
MAMBOV8<@V*[8I]F$VXP@5D93("#8I]N,V*S8I]BO(-F&V879B-BO(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5
M;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#8K]BGV*_9AR#8L=BG(-BHV*?8LB#:J=BQV*\@(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G
M<W1R("+8K=BPV8$@7"(E<UPB(-F%V87:J=F&(-F&VXS8L]BJV(P@V+38I]BN
MV8<@V*[8I]F$VXP@V8;;C-BSV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB!<(B5S7"(@V+'8IR#8K=BPV8$@VJG8L=BO
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(MBMV+#9
M@2`E<R#9A=F%VJG9AB#9AMN,V+/8JMB,(-BTV*?8KMF'(-BNV*?9A-N,(-F&
MVXS8L]BJ(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T
M."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BH
MV8<@V+79B-BQV*H@V*K9B"#8K]BQ(-BJV8@@V*W8L-F!(-F&V879B-BO(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
MV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*W8L-F!(-F&
MV879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT
M,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@
MV*W8L-F!(-F&V879B-BO.B`E<RXB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R!<(B5S7"(@V+'8IR#8K=BPV8$@
MV8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*W8L-F!(-F&V879B-BO(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&
MV*_9AR!61E,@7"(E<UPB(-BQV*<@V*W8L-F!(-F&V879B-BO(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S
M+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB!61E,@V+'8IR#8J-F'(-BU
MV8C8L=BJ(-BJV8@@V*_8L2#8JMF((-BMV+#9@2#9AMF%V8C8KSH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L
M92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'V90@V8'8N=F$VXP@V+'8IR#8JMBT
MV*[;C-BU(-BOV*?8KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BLV++8IMN,
MV*?8JB#:K]F(V*?9A]N,(-BQV*<@V*?8L]BJV*[8L=BGV*P@V8;9A=F(V*\B
M"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R
M:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*K8N=BQVXS9@2`E<R`@V+'8IR#8
MJ-BGV+$@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9
MAR!61E,@V+'8IR#8I]F&V*K9@MBGV80@V*_8I]BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
MV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R!<(B5S7"(@V+'8
MIR#8J-BGV+(@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B
MV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BHV+'8
MI]N,(-F&V8C8M-BJV88@V*C8I]BR(-JIV+'8KR(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("+9AMF%VXSB
M@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*C8I]BR(-F&V879
MB-BO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8HMBQV+3;C-F((-F!V+38L=BO
MV8<@V+'8IR#8J-BGV+(@VJG8L=BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I
M;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(-F&V87;C.*`C-BJ
MV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'(%9&4R#9AMF(V+38JBXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*
M;7-G<W1R("(@V8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@
M5D93(-F&V8C8M-BJ+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BG
MV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@
M(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@=F9S<F]O="#8L=BG(-BN
MV8C8I]F&V*\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E
M<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*C9AR`E<R`@V*K8NMN,VXS8
ML2#9AMBGV84@V*_8I]BO.B#9OMF(V+39AR#9A=F"V+78KR#8I]BR(-F"V*C9
MA"#9A=F(V*S9B-BO(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@
M5D93(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
MV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*K8NMN,VXS8
ML2#9AMBGV84@V*_8I]BO.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'
M(%9&4R!<(B5S7"(@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93("5S+R5S(-BQV*<@
MV*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8
MK]F'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S
M='(@(MF&V87;C.*`C-BJV8C8I]F&("=M:VES;V9S)R#8L=BG(-BGV*S8L=BG
M(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W
M;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*?;C-F&
M(-BSV8;8KR!7;W)D(-BQV*<@V*K8L=BLV879AR#9AMF%V8C8KR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B#9AMF%VXSB
M@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!<(B5S7"(@5D93("#9AMF(
MV+38JB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB
M"FUS9W-T<B`B(-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'
M(%9&4R#9AMF(V+38JBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8?9E"#8K]BGV*_9AR!61E,@V8;9
MB-BTV*HB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@
M8F4@97AC965D960N(@IM<V=S='(@(B#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ
M(-F^V+'9B-F&V*_9AR!61E,@V8;9B-BTV*HN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE
M(@IM<V=S='(@(MBRVXS8L=BNV+?B@(S8K]BGV+$B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B
MV8C8I]JOV+'8K]BGV8;8K]F&(-BJV+K;C-N,V+'8I]BJ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BV8C8I]JOV+'8K]BGV8;8
MK]F&(-BBV*[8L=N,V88@V+G9A=F$(-BTV878IR(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@
M(MF^V*?8L]BN(-BZVXS8L2#9A=F&V*K8N-BQV8<@V*?8LB#:J=BGV+'8L]BG
MV+(@V*C8L2#8L=F(VXP@V*?8JMBUV*?9A#HB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("+9OMBGV+/8KB#8NMN,V+$@
MV879AMBJV+C8L=F'(-BGV+(@VJG8I]BQV+/8I]BR(-BHV8<Z(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G
M:60@(E5N9FEL960B"FUS9W-T<B`BV+K;C-BQ(-BMV8C8LMF'(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*
M;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B
M56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS
M9W-T<B`BV8C8I]BMV*_9A]BG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S
M,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("+8K]BGV*_9AR#9AMBGV+39AMBG
MV*[8JMF'(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5
M;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+9A]N,VH8@V87:
MJ=BGV8;;C"#8JMF&V+C;C-F%(-F&V+38K]F'(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN
M;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("+9AMBGV84@VJG8
MI]BQV*C8L2#9B"#;C-BG(-BGV+/9A2#8L=F%V+(@V8;8I]BTV8;8I]BNV*K9
MAR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B
M"FUS9W-T<B`BV8+8M]BY(-F^VXS9B-F&V*\@V+G9AMBUV+$@V8'8N=F$VXPB
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@IM<V=I
M9"`B56YN86UE9"(*;7-G<W1R("+8J-N,(-F&V*?9A2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HBV*_8L]BJ(.*`
MC-F&V8C;C-BSV8?8I]N,(-BHV*_9B-F&(-BGV878JMN,V*?8LB#8J-F'(-BO
MV83;C-F$(-BGV879AMN,V*K;C"#9AMF%VXSB@(S8JMF(V*?9AMF&V*\@V*?8
MLB#8M]BQVXS9@B#8J-BQV8;8I]F%V8<@V8;9B-N,V+/;C"#8J-BQVXS8K]F'
M+R(*(MBQV8C9AMF(V+38JB#:K]BQV8'8JMF'+]J&V+/8J-N,V*_9AR#8M-F(
MV8;8KRX@VJG9A-N,V*\@V*K8H]N,VXS8KR#8L=BG(-F!V+38I]BQ(-BOV8?;
MC-BO(-BJV*<@V878JMF&(-F!V8;;C.*`C-BGXH",VXS;C"#8L=BG(-BOV+$@
M(@HB;6]Z:6QL82YO<F<@V*C8IR#8N=F&V8C8I]F&(-J&VJ_9B-F&VJ_;C"#8
MK]BSV*K8L=BSVXP@VXS:J2#8K]BSV*H@XH",V8;9B-N,V+,@V*C9AR#8JMBN
MV*K9A]F4(-BQV+/9A2#8L=BG(-F%V+38I]F'V*_9AR#:J=F&VXS8KR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(MBQV8;:KR#8JMF&V+C;
MC-F%(-F&V+38K]F'(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@
M(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("+8J-BSV+<@V*C8K]F(
MV88@V;[8M-BJVXS8J-BGV8;;C"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S
M"FUS9VED(")5<&1A=&4B"FUS9W-T<B`BV*C8L=F(V++8L=BSV*?9AMN,(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`BV*C8L=F(
MV++8L=BSV*?9AMN,("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`BV*C8L=F(
MV++8L=BSV*?9AMN,(-JIV*?8L=BHV+$B"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(-BHV+'9B-BRV+'8L]BGV8;;
MC"#8M-BO(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(MBOV+/8JN*`C"#9
MAMF(VXS8LR#8J-F'VXS9AMF'XH",V+/8I]BRVXP@V*W8L-F!(-BTV*\B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R
M("+8I]BQV+/8I]F$(-JIV+'8K]F&(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P
M(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(MBJV878I]F%(-F^V+'9
MB-F&V*_9A^*`C.*`C-F'V*?;C"#8JMF&V+C;C-F%(-BHV+'9AMBGV879A^*`
MC-F'V*?;C"#:J=BGV+'8J-BQV*_;C"#8J-F'(-JIV*?8L=BSV*?8LB#8I]BQ
MV+/8I]F$(-BTV*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(MBMV+'9B-F!(-BHV++8L=JO(-F$V*?8JMN,V88B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(MBG
MV+G8K]BGV*\@VXS9B-F&V*?9AMN,(-BHV++8L=JO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(-BGV+/8JMF!V*?8
MK]F'(-F!V+G9A-N,.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@
M(MBGV+/8JMF!V*?8K]F'(-BGV+(@4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF
M9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`BV*?:K]BQ(-F&V*?9
MA2_8I]BSV84@V+'9A=BR(-BHV+'8I]N,(-JIV*?8L=BSV*?8LB!)35-0(-F%
MV*K9@=BGV8C8JB#8I]BSV*K8C"#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KR(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z
M>GD*;7-G:60@(E5S97(B"FUS9W-T<B`BVJG8I]BQV*C8L=BGV88B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E
M<RXB"FUS9W-T<B`BVJG8I]BQV*C8L2`E<R`@V*C8L=BGVXP@)7,@V*?8K=BQ
MV*?8LB#9A]F(VXS9D=BJ(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("+8L]BQV;[8L=BSV*K;C"#:J=BGV+'8J-BQ(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G
M<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-JIV*?8L=BHV+$B"@HC.B!S:6=N
M=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("+8
MJ]BHV*H@V8;8I]F%(-JIV*?8L=BHV+$B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R("+8J]BHV*H@VJG8I]BQV*C8L2#8J-BQV*?;
MC"#8I]N,V88@V;[8I]N,VJ_8I]F'(-BZVXS8L2#9@=BYV*?9A"#8M-BOV8<@
MV*?8L]BJ(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B
M57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("+8K=BSV*?8J"#:J=BG
MV+'8J-BQ(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQ(@H*
M(R`*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R("+9AMBGV84@VJG8I]BQV*C8L2`G)7,G(-BG
MV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B
MV8;8I]F%(-JIV*?8L=BHV+$Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("+9AMBGV84@VJG8
MI]BQV*C8L3H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`BVJG8I]BQ
MV*C8L=BGV88@V+/8I]F%V*?9AMF'.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM
M<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
MV+38I]BNV8<@5D93(-F(V*S9B-BO(-F&V*_8I]BQV*\B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R
M("+8JMBYV+?;C-F$V*?8JB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*
M;7-G<W1R("+9A=F(V8+8N=N,V*K9A]BGVXP@V878N=BJV*C8L2#;C-BGV8'8
MJMF'(-BTV*_9AR#8N=BHV*?8L=BJV8;8KR#8I]BR.B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*
M;7-G<W1R("+8I]BYV*K8J-BGV+$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(MF%V8+8K]BGV+$@V*C9AR#8
MK]F"VXS9@MF'(-BGV+(@V*W8I]F$V*<B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE
M;F=T:"!O9B`E<RXB"FUS9W-T<B`BV879@MBOV*?8L2#8I]BR(-BHVXS8M-N,
MV8;9AR#8M]F(V80@V878K-BGV+(@)7,@V*C;C-BTV*K8L2#8I]BSV*HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*
M;7-G<W1R("+9A=F"V*?8K]N,V+$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@
M(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("+9A=F"V*?8K]N,V+$@
MV*C8L=BGVXP@V*?9AMBJV*[8I]BH(-BGV+(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(MF%V*K8
MNMN,VXS8L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M
M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S
M:6]N(@IM<V=S='(@(MF&V+/8KMF'(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(MJI
MV8;8JMBQV80@V8;8L]BNV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG
M;B(*;7-G<W1R("+8JMBQV*?8LB#8N=F%V8C8K]N,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC
M86P@<&%D9&EN9R(*;7-G<W1R("+9@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8
MN=F%V8C8K]N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(MBYV879B-BO
MVXPZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("+8KMN,V83;C"#8J-BGV838
MIR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,38*(RP@9G5Z>GD*;7-G:60@(E9I970@3F%M(@IM
M<V=S='(@(MF&V*?9A2#9OMBQV8C9AMBOV8<B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R
M(")6:65T;F%M97-E("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@
M)7,B"FUS9W-T<B`BV8;9A=BGVXP@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S
M='(@(MF&V878I]N,(-N,VJD@V+79@=BMV8<@V8C8J"#8KMBGV+'8K-N,(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(-F&V878IR#8
MJ-F'(-BYV8;9B-BGV88@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G
M:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G
M<W1R("+9@MBGV*C9A-N,V*H@V878M-BGV8?8K]F'(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM
M<V=S='(@(MF"V*?8J-F$VXS8JB#9A=BTV*?9A]BOV8<Z("(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S
M+B(*;7-G<W1R("+8I]BNV+?8I]BQ(2$A(-BOV+/8JB#B@(S9AMF(VXS8LR#8
ML=BG(-BHV+?9B-BQ(-BOV+/8JMN,(-BGV+(@)7,@V*W8L-F!(-JIV8;;C-BO
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*
M;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`BV*?8KMBWV*?8L3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B
MVH;9A]BGV+'8M-F&V*C9AR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("+9OMN,
MV+3B@(S8J-N,V8;;C"#9A]F(V*<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB
M"FUS9W-T<B`BV*_8I]BOV8<@V*+8J"#9B"#9A]F(V*?;C-N,(-F!V+'8I]F'
MV84@V+38K]F'(-BHV8<@V8C8L]N,V839AR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A
M=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B
M5V5B(@IM<V=S='(@(MF(V*@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R("+9B-BHXH",VJ_8I]F'
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(MF'V8'8JMJOVXPB"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G
M<W1R("+8KMF(V+0@V*+9A=BOVXS8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,@(RTC+2,M(RTC
M("!F85])4BYP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G
M<W1R("+8J-F'("5S(-BNV8C8M"#8HMF%V*_;C-BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM
M<V=S='(@(B5SV(P@V*[9B-BT(-BBV878K]N,V*\B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS
M9W-T<B`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S
M='(@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@
M87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM
M<V=S='(@(MJ&V8<@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@V+'8
MIR`E<R#8J-BGVXS8KR#8J-BYV*\@V*?8LB#9B-BQV8C8KR#9AMBTV*?9AB#8
MK]F'V*_8GR(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS
M9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R
M("+9AMF(VXS8L]F'V93B@(P@V*W8I]BFV80@VH;;C-BSV*K8GR(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(MF&V8C;C-BSV8?B@(S;C"#9
MAMF"V80@V8+9B-F$(-J&VXS8L]BJV)\B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T
M<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(MJIV*_8I]F%(-F!V*?8
MLB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H
M('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB
M"FUS9W-T<B`BVJG8K]BGV84@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-F%V*K8
MM=F$XH",VJG9AMF&V*_9AR#B@(S8J-BQV*?;C"#9B-N,V+'8I]N,V+3:K]BQ
M(-F%V*K9AB#9@=BYV*?9A"#8J-BGV+39AMBO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED
M=&@B"FUS9W-T<B`BV+G8L=BV(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B#9
MOMF'V8;8IR#8K]BQ(-F(V*?8K=BO($-34R`B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R("+9OMF'V8;8I]N,(-JOV++;C-F&VJ_8I]F&("5S
M(-BOV+$@V+'8I]BSV*H@*-BOV+$@V8C8L=F(V*\@V*C8N=BOVXP@V879B-BK
MV+$@V87;C.*`C-JOV+'8K]BO*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A
M8FQE(@IM<V=S='(@(MF^V8?9AMBGVXP@V*S8K]F(V80B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED
M=&@@=6YI="(*;7-G<W1R("+9B-BGV*W8KR#9OMF'V8;8IR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7
M:61T:#HB"FUS9W-T<B`BV;[9A]F&V*<Z(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R
M("+8J-BGV*\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`BV*C8I]BO(-BR
MV8C8K]F'V8;:K]BGV84Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*
M;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`BV+/8L=BYV*H@
MV*C8I]BO(-BHV+'8K=BSV*@@V8'9B-BJ(-BHV+$@V+/8I]BYV*HB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B
MV*C8I]BO.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R("+8J-BGV*\Z("(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(MBYV8+9
MA"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*(RP@9G5Z>GD*
M;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(MF$VXS8L]BJ(-BBV+'8LMF(V8?8
MIR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*
M;7-G<W1R("+:J=BGV+$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+8
MHMBOV+'8LR#9A=BMV80@VJG8I]BQ(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G
M<W1R("+8JMF$V8'9AB#9A=BMV80@VJG8I]BQ(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*
M;7-G<W1R("+8I]N,V*S8I]BO(-F^V+'9B-F&V*_9AR!61E,@V878K-F(V+(@
MV*_8L]BJV+'8L]N,(-F&V*_8I]BQV*\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM
M<V=S='(@(N*`C%E9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4U"FUS9VED(")965E9(@IM<V=S='(@(EE965DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I
M9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T
M<B`BV+/8I]F$V*?9AMF'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(MBBV+';C"(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED
M(")997,L($D@06=R964B"FUS9W-T<B`BV*C9A-F'V(P@V879B-BGV8'9@MF%
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(MBT
MV878IR#8K]BQ(-F%V*\@V878JMF&(-F'V+/8JMN,V*\N(-BGV+(@V*_:J=F%
MV8<@(%L\/ET@V*C8L=BGVXP@V*C8L=JOV+38JMF&(-BHV8<@5UE325=91R#8
MI]BSV*K9@=BGV*_9AR#:J=F&VXS8KR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E
M9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(MBTV878IR#8
MJMBUV*_;C-F"(-F'V8C;C-F1V*H@V8;8M-BOVXS8KR(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO
M="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB
M"FUS9W-T<B`BV+39A=BG(-F&V87;C.*`C-BJV8C8I]F&VXS8KR#9AMF(VXS8
ML]F'("=<7"<@V+'8IR#8K]BQ(-F&V*?9A2#:J=BGV879A"#8KMF(V*\@V*_8
MI]BTV*K9AR#8J-BGV+3;C-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S
M='(@(MBTV878IR#8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI
M(-F%V+G8JMBHV+';C"#9B-BGV+'8KR#9AMJIV+'8K]F'XH",V*?;C-BO(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB
M:6X@)7,N(@IM<V=S='(@(B(*(MBTV878IR#9A]N,VH8@V8';C-F$V*_;C"#8
ML=BG(-BOV+$@V;[8L=F(V8;8K]F'(-BOV+'9B-F&XH",V*C8L=BO(-BTV*_9
MAR#8J-F'(-F!VXS9A-BO(-F%V*K9@MBGV*C9A-N,(-BOV+$@)7,@V8;:K]BG
MV+38JB#9AMJIV+'8K]F'XH",V*?;C-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N
M(@IM<V=S='(@(MBTV878IR#8KMBGV+'8K"#8M-BOVXS8KR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@
M=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L
M(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B+8M-F%V*<@V878K-BHV8C8
ML2#9A]BSV*K;C-BO(-N,VJD@V+39A=BGV+'9AR#8JMF$V8'9AB#9A=BYV*K8
MJ-BQ(-F(V*?8L=BO(-JIV8;;C-BOV(P@V*?8LB#8N=F$V*?9A=BJ("<K)R#8
MJ-BQV*?;C"#8M-F%V*?8L=F'XH",V8?8I]N,("(*(MBHVXS9AB#8I]F$V879
MA-F$VXP@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED('9A;'5E+B(*;7-G<W1R("+8M-F%V*<@V878K-BHV8C8L2#9A]BS
MV*K;C-BO(-N,VJD@V879@MBOV*?8L2#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JI
MV8;;C-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B
M86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,
MV*\@VXS:J2#9OMBTV*K;C-BHV*?9AB#8K]BQV*[8JB#8K]BGV*_9AR#8J-BQ
MV*?;C"#8I]BSV*K9@=BGV*_9AR#8I]BR(-BKV*C8JB#9AMBGV84@V;[;C-JI
MV+'8J-F&V*_;C"#:J=F&VXS8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-N,VJD@V+/8
MI]F%V*?9AMF'(-F^V+38JMN,V*C8I]F&(%9&4R#8L=BG(-F^VXS:J=BQV*C9
MAMBOVXP@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S
M='(@(MF"V*C9A"#8I]BR(-BGV+'8L]BGV80@VJ_8LMBGV+'8M-B,(-BHV*?;
MC-BO(-F%V+3:J=F$(-BQV*<@V+38L=BM(-BOV8?;C-BO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR!54DS8I]N,(-JIV8<@V*?;C-F&
M(-F^VXS9B-F&V*\@V*C9AR#8HMF&(-BGV+38I]BQV8<@V87;C.*`C-JIV8;8
MKR#8L=BG(-F(V*?8L=BO(-JIV8;;C-BO(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V
M97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-N,
MVJD@VJG8I]BQV+/8I]BRV(P@V*C8L=BGVXP@V*W8L-F!(-JIV+'8K]F&(-BG
MV8;8JMBNV*?8J"#:J=F&VXS8KR(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-N,VJD@V8;8I]F%(-JIV*?8
ML=BHV+'8C"#8J-BQV*?;C"#8K=BPV8$@VJG8L=BOV88@V878M-BNV+4@VJG9
MAMN,V*\B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(MBTV878
MIR#8J-BGVXS8KR#;C-JI(-F&V*?9A2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@
MV*W8L-F!(-BTV*_9AB#9A=BTV*[8M2#:J=F&VXS8KR(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*
M;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@VXS:J2#9AMBGV84@VJG8I]BQV*C8
ML=B,(-BHV+'8I]N,(-BGV+;8I]F!V8<@VJG8L=BOV88@V878M-BNV+4@VJG9
MAMN,V*\B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`BV+39
MA=BG(-BHV*?;C-BO(-N,VJD@V+39AMBGV+/9AR#:J=BGV+'8J-BQV(P@V*C8
ML=BGVXP@V*C8L=F(V++8L=BSV*?9AMN,(-BGV8;8JMBNV*?8J"#:J=F&VXS8
MKR(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F
M;W)M+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@V878M-BNV+4@VJG9AMN,
MV*\@VJG9AR#:AMF'(-BYV879A-N,(-BHV*?;C-BO(-BGV8;8K-BGV84@VJ_;
MC-BQV*\B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@V8;8I]F%(-BLV*_;
MC-BO(-BOV+/8JMF'(-BQV*<@V*K8I]N,V;X@VJG9AMN,V*\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM
M<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU
M;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(MF&V+38L]BJ
M("5S(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9AR#8I]BSV*HN(-F$V+?9@=BG
MV8L@V*_9B-BHV*?8L=F'(-F(V*?8L=BO(-BTV8C;C-BO(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@
M061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#8I]F$VJG8JMBQV8C9AMN,VJG;
MC"#8M-F%V*<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS9VED
M(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(MBBV*_8L=BS(-F!V+'8
ML]BJV8;8K]F'.B#8M-F%V*<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9
M;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ(-BTV878
MIR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*(MBBV*_8L=BS(-BGVXS9AMBJV+'9AMBJVXP@V+39
MA=BG(-F&V+/8J-BJ(-BHV8<@V*?8J-BJV*_8I]N,(-F&V+38L]BJ("5S(-BT
MV878IR#8JMBZVXS;C-BQ(-JIV+'8K]F'(-BGV+/8JB[8J-BQV*?;C"#8L=BY
MV*?;C-BJ(-F%V+/8I]BFV80@(@HBV*?9A=F&VXS8JMN,(-BHV*?;C-BO(-BO
MV8C8J-BGV+'9AR#9B-BGV+'8KR#8M-F(VXS8KR(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`BV8;8I]F%(-BTV878IR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF
M('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@
M86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT
M:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B+8L]BGV878I]F&V8<@V;[8
MM-BJVXS8J-BGV88@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BTV878IR#8I]BV
MV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-BQV*<@V;[8M-BJVXS8
MJ-BGV8;;C"#9AMF%VXSB@(S:J=F&V*_8C"#;C-BG(-BTV*?;C-BO("(*(MBH
MV8;8IR#8J-F'(-BOV83;C-F$(-BOVXS:K]BQVXP@V*?;C-F&(-JIV*?8L2#8
MI]F&V*S8I]F%(-F&V87;C.*`C-BTV8C8KR(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B+8L]BGV878I]F&V8<@V;[8M-BJ
MVXS8J-BGV88@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BTV878IR#9@=F'V+'8
ML]BJ(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-BQV*<@V;[8M-BJVXS8J-BG
MV8;;C"#9AMF%VXSB@(S:J=F&V*_8C"#;C-BG(-BTV*?;C-BO("(*(MBHV8;8
MIR#8J-F'(-BOV83;C-F$(-BOVXS:K]BQVXP@V*?;C-F&(-JIV*?8L2#8I]F&
MV*S8I]F%(-F&V87;C.*`C-BTV8C8KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(MBXV*?9
MA]BQ(-F%V+'9B-BQVJ_8L2#8M-F%V*<@V8;8L]BHV*H@V*C9AR#8I]BHV*K8
MK]BGVXP@V8;8M-BSV*H@)7,@V+39A=BG(-BJV+K;C-N,V+$@VJG8L=BOV8<@
MV*?8L]BJ+MBHV+'8I]N,(-BQV+G8I]N,V*H@V878L]BGV*;9A"`B"B+8I]F%
MV8;;C-BJVXP@V*C8I]N,V*\@V*_9B-BHV*?8L=F'(-F(V*?8L=BO(-BTV8C;
MC-BO(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T
M<B`BV878L=F(V+':K]BQ(-BTV878IR#8I]N,V88@V878M-BNV+79AR#8L=BG
M(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9AMBO+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB
M"FUS9W-T<B`B(@HBV878L=F(V+':K]BQ(-BTV878IR#8I]N,V88@VJ_8LMN,
MV8;9A]F4XH",(-J&V*?9OB#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,
MXH",VJG9AMBO+B!#;VYT<F]L+T]P=&EO;B`K(%`@V+'8IR#8J-BQV*?;C"#:
MAMBGV;X@(@HBV8'8M-BGV+$@V*_9A]N,V*\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*
M;7-G<W1R("+8LMF%V*?9AB#9@=BYV83;C"#9A=F&V+?9@MF'(-BLV+K8L=BG
MV8';C-BGVXS;C"#8M-F%V*<Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"XB"FUS9W-T<B`BV8?9B-N,V9'8JB#9OMN,V+0@V8'8L=BV
M(-BTV878ISHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED
M(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(MF'V8C;C-F1V*H@
MV;[;C-BT(-F!V+'8MB#8M-F%V*<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(MF&V*?9
MA2#:J=BGV879A"#8M-F%V*<Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z,3`P,`IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T
M<B`BV8C8L=F(V*\@V+39A=BG(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8JB(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS
M9W-T<B`BV*?8L]F%(-BQV878LB`@V*S8K]N,V*\@V+39A=BG(-BHV+'8I]N,
M("5S(-F'V+/8JCH@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("+:
MK]BRVXS9AMF'XH",V8?8I]N,(-BTV878IR#8J-BQV*?;C"#8M]F(V80@V*?;
MC-F&(-F&V+38L]BJ(-BHV+'9B-BRV+'8L]BGV8;;C"#8M-BOV8<@V*?8L]BJ
M("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED
M(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(MJO
MV++;C-F&V8?B@(S9A]BGVXP@V+39A=BG(-BHV+'9B-BRV+'8L]BGV8;;C"#8
MM-BOV8<@V*?8L]BJ(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`BV*?8L]F%(-BQV878LB`@V+39A=BG(-BHV*?8LMF&V+38I]F&VXP@V+38
MK]F'(-BGV+/8JB(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y
M"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C
M:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S
M=V]R9"XB"FUS9W-T<B`B(@HBV*?8L]F%(-BQV878LB#8M-F%V*<@V*C8I]BR
MV8;8M-BGV8;;C"#8M-BOV8<@V*?8L]BJV(P@V;[8L]BJ(-BGV83:J=BJV+'9
MB-F&VXS:J2#8KMF(V*\@V+'8IR#:AMJI(-JIV8;;C-BO(-F((-BHV*<@V*?8
ML]F%(-BQV878LB#8K-BOVXS8KR`B"B+8KMF(V*\@V8C8I]BQV*\@V+39B-N,
MV*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO
M=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(MBGV+/9A2#8L=F%
MV+(@(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9AR#8I]BSV*HB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E
M('-E<G9E<G,Z(@IM<V=S='(@(MJIV*?8L=BSV*?8LN*`C-F'V*?;C"#8L=BG
MV8?B@(S8K]F(V+$@V+39A=BG.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B6F%I<F4B"FUS9W-T
M<B`BV838M]N,V8$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X
M=%TB"FUS9W-T<B`B6]F^V8;9A]BGV88@VJG8L=BOV88@V878JMF&(-F&V8+9
MA"#9@MF(V80@V+38K]F'72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X
M"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EO:K]BRV*?8L=BT
M(-F%V+3:J=F$72`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R
M(");V8;9A=BGVXS8M"#9A=BJV88@V8;9@MF$(-F"V8C9A"#8M-BOV8<@+2(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O
M=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`BV8;9A=BGVXS8M"#9A=BJV88@
MV8;9@MF$(-F"V8C9A"#8M-BOV8=;("T@)7,@V*[8MUTB"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6]BNV+<@)7,@V*?8LB`E
M<R!=("(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BV+/8L=F^V+'8L]BJVXPB"@HC.B!L:6(O87!I+G!H<#HQ
M-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z
M,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`BV*_8L=BNV*H@V*_8I]BO
MV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(MBMV+#9
M@2#8L]BWV+$B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B
M"FUS9W-T<B`BVJ_8L=F(V8<F(W@R,#!C.]F'V*<B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R
M("+8L=BGV8?9AMF%V*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BJV+79B-N,V+$N+BXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED
M(")?3&]G(&EN(@IM<V=S='(@(MF(V+'9B-BO(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T
M<B`BV*[8L=F(V*PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*
M;7-G<W1R("+8JMBZVXS;C-BQ(-F^VXS9B-F&V*\N+BXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*
M;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8IR(*"B,Z(&QI8B]A<&DN<&AP.C$S
M-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(MF%V*S9B-BRV8?8IR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(MBMV+#9
M@2#9OMN,V8C9AMBO+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?
M4V5T=7`B"FUS9W-T<B`BV+'8I]F')B-X,C`P8SO8I]F&V*_8I]BRVXPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(MBN
MV+79B-BUVXS8I]BJ(-BLV*_9B-F$+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`BVJG8I]BQV*C8L=BGV88B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0IM<V=I9"`B861D<F5S<R!B
M;V]K(@IM<V=S='(@(MJIV*K8I]BHVH;9A]F4(-BBV*_8L=BS("(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"B,L(&9U>GIY"FUS
M9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("+:J=BJV*?8J-J&V8?9
ME"#8HMBOV+'8LR`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`BV*K9@MF(VXS9A2(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`BV*+8
ML=BGV84B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U
M.`HC+"!F=7IZ>0IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!<
M(B5S7"(@V8;9B-BTV*HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(MBGVXS9AMBLV*<@V+'8IR#9@=BT
MV*?8L2#8K]F'VXS8KR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S@*(RP@9G5Z>GD*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T
M<B`BV*K9@=BGV8C8JMF'V*?;C"#9OMN,VJG8L=BHV8;8K]N,(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I
M8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R
M;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U
M;F0B"FUS9W-T<B`B)7,@V;[;C-BOV*<@V8;8M-BO(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#4U"FUS9VED(")F:6QE(@IM<V=S='(@(MF^V+'9B-F&V*_9AR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*
M;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`BV*?8
MLB`E<R`H)7,I(-BOV+$@)7,@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(MBH
MV*?8KR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*
M;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM
M<V=I9"`B:6UM961I871E(@IM<V=S='(@(MF!V8C8L=BGV8LB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM
M<V=I9"`B:6YL:6YE(@IM<V=S='(@(MBOV+'8KMBW(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U
M="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("+8KMBWV8C8MUTB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B;F%M92(*;7-G<W1R("+9
MAMBGV84B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N
M;W0@:6UP;&5M96YT960B"FUS9W-T<B`BV;[;C-BGV*_9AR#8L]BGV++;C"#9
MAMBTV*_9AR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("+9A]F&
MV8C8LB#9OMN,V*?8K]F'(-BSV*?8LMN,(-F&V+38K]F'(-BGV+/8JB(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D
M(@IM<V=S='(@(FYO=&5P860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S
M='(@(MBOV+'8M=BO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM
M<V=S='(@(MF%V*S9B-BR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@
M(MF^VXS:J=BSV839A]BG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(MBWV839B-BY(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*
M;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`BV*C9A-F(VJD@
M365T87(@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,V+/8JB(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`BV8;9A=BGVXS8M"#8JMF!V*?9B-BJV8?8IR(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED
M(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("+9OMN,XH",V*_8L=F^VXPB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I
M=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*
M;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("+9@=F'V+'8L]BJ(-F(V+C;C-F!
MV8<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A
M9V%I;B(*;7-G<W1R("+8K]BQ(-F'V+$@V8C8L=F(V*\B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y
M"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM
M<V=S='(@(MBGV+/9A2#8L=F%V+(@V+'8IR#8J-BQV*?;C"#8JMBCVXS;C-BO
M(-BOV8C8J-BGV+$@V8C8I]BQV*\@VJG9AMN,V*\B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M=6YI9FEE9"(*;7-G<W1R("+;C-JOV*?9AMF'(-BTV*_9AR(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS
M9W-T<B`BV*C;C"#9AMBGV84B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#:J=BGV+'8J-BQ(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R
M9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(G<Z(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N
M8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&\O9FE?1DDN<&\`````````````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<S,C(P,``Q,#0Q-S,V,S`P,0`P,38S
M-#(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R!&:6YN:7-H('1R86YS;&%T:6]N(&9O<B!(;W)D92X*(R!#;W!Y<FEG:'0@
M*$,I"B,@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3XL(#(P,#$M,C`P-BX*
M(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R
M9&4@,RXQ+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3(W
M(#$Y.C4Q*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,C0@
M,3(Z-3DK,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!,965N82!(96EN;R`\
M;&EI;G5`=71A+F9I/EQN(@HB3&%N9W5A9V4M5&5A;3H@1FEN;FES:"`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@<.1I=N3D('-I='1E
M;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H4&EK
M86[D<'#D:6X@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,X
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@
M(B`H)7,@<.1I=N1S<^0I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W-PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("ATY&[DY&XI(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O
M=RDB"FUS9W-T<B`B("AH=6]M96YN82DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<U"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AE
M:6QE;BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M7"(E<UPB(&5I(&]L92!H86ME;6ES=&\B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!E:2!K96QP86$@=F%L
M:6YN86MS:2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C<Q,`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$P.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB
M(&5I(&]L92!A<V5N;F5T='4@2&]R9&5N(')E:VES=&5R:7-SY"XB"@HC.B!F
M<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(")<
M(B5S7"(@<'5I9&5N(&MU=F%A:F%A(&5I(&SV>71Y;GET+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB
M(&QI<^1T=&EI;B!R>6AMY&KD<FIE<W1E;&WDY&XN(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B7"(E<UPB(&QI<^1T=&EI;B!O:6ME=6MS:6EN+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*
M;7-G<W1R(")<(B5S7"(@96D@;'5O='4Z("5S+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@
M:^1Y=&5T='D@)2XR9DU"('-A;&QI='5S=&$@*"4N,F8E)2DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!J82`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I
M;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(E-A;&%S86YA<VD@
M=F%N:&5N='5U("5D('#D:7;D;B!PY.1S=.0N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD
M87D@9F]R96-A<W0B"FUS9W-T<B`B)60@<.1I=N1N(&5N;G5S='5S(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@26QM;VET=7,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!3;W)M96YJ
MY&QK:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T
M,"!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G
M<W1R("(E<R!9;&SD<&ET;W1O:6UE;G!I=&5E="`M(%9A<FUI<W1U<R(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R
M("(E<R!A<V5N;G5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S
M='(@(B5S(&MI<FIA=71U;6EN96XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R
M965M96YT(@IM<V=S='(@(B5S(&OD>71T]F5H9&]T(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW-3`*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&]N(&IO(&]L96UA<W-A
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S('-U=6YT
M82`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K
M('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&]N('9A;&UI
M<R!S=6]R:71T86UA86X@>6QLY'!I=&]T;VEM96YP:71E:73D+B!686QI='-E
M('9A;&EN=&%R=75D=6ES=&$@(@HB<W5O<FET971T879A="!T;VEM96YP:71E
M970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!O;B!P
M86MO;&QI;F5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=71T
M:6$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,3(Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T
M<B`B)7,@96D@;/9Y='EN>70N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E
M<R(*;7-G<W1R("(E<R`M("5S("\@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E
M<W,@0F]O:R(*;7-G<W1R("(E<SIN(&]S;VET96MI<FIA(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<SIN(&MA;&5N=&5R:2(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<SIN(&UU:7-T:6QI<W1A(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E<SIN('1E:'3D=N1L
M:7-T82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L
M86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@
M:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R
M<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S(#H@5.1MY"!V:65S
M=&D@96D@;VQE(';D;'1TY&WD='3D('-I;'3D(&SD:&5T=.1JY&QTY"P@:F]K
M82!O;B!M97)K:71T>2`B"B)LY&AE='3D:N1K<VDN(%-U:'1A=61U('9A<F%U
M:W-E;&QA('9I97-T:7-SY"!O;&5V:6EN(&QI;FMK96EH:6X@:F$@=F%R;R`B
M"B)A;G1A;6%S=&$@;.1H971TY&KD;&QE(&UI=.3D;B!Y:W-I;/9I=FGD('1I
M971O:F$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I
M;F<@(@IM<V=S='(@(BP@<'5U<VMI='1A:7-T82(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF
M;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L('!U=7-K
M:71T86ES=&$@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B
M"FUS9W-T<B`B+"!V86EH=&5L979A82`E<R`M("5S(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T."!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(Y-`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C,T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<S"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,S(*;7-G:60@(BTM('-E;&5C="`M
M+2(*;7-G<W1R("(M+2!V86QI='-E("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUT=6YN
M:6X@:N1R:F5S=&5L;>0B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G
M:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T+71U;FYI;B!JY')J97-T
M96QMY"(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R
M-"!H;W5R<R(*;7-G<W1R("(R-"!T=6YT:6$B"@HC.B!F<F%M97=O<FLO54DO
M54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/$5D
M96QL:6YE;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(E1I971O:V%N=&%T875S=&%JY')J97-T96QMY.0@96D@;VQE
M(&WDY')I=&5L='D@=.1L;&4@;W-I;VQL92(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R(")487!A:'1U:2!V86MA=F$@=FER:&4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(E9I97-T:6X@<V%L875K<V5E;B!T87)V:71A86X@:G5L:VEN96X@
M4$=0+6%V86EN+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(D%L;&5K:7)J;VET
M971U;B!V:65S=&EN('1A<FMI<W1U:W-E96X@=&%R=FET86%N(&IU;&MI;F5N
M(%!'4"UA=F%I;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB4V%L871U;B!V:65S=&EN(&%V
M86%M:7-E96X@=&%R=FET86%N(&IU;&MI;F5N(%!'4"UA=F%I;BP@<V%L86EN
M96X@4$=0+6%V86EN("(*(FIA('-A;&%S86YA=&5K<W1I+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"B)6:65S=&EN(&%L;&5K:7)J;VET=&%M:7-E:W-I('1A<G9I=&%A;B!J=6QK
M:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'4"TB"B)A=F%I;B!J82!S86QA
M<V%N871E:W-T:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E9I97-T:6X@879A
M86UI<V5E;B!T87)V:71A86X@:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA
M:6YE;B!3+TU)344M879A:6X@:F$@(@HB<V%L87-A;F%T96MS=&DN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E
M+B(*;7-G<W1R("(B"B)6:65S=&EN(&%L;&5K:7)J;VET=&%M:7-E:W-I('1A
M<G9I=&%A;B!J=6QK:6YE;B!3+TU)344M879A:6XL('-A;&%I;F5N(%,O(@HB
M34E-12UA=F%I;B!J82!S86QA<V%N871E:W-T:2XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)
M344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R(")6:65S=&EN('-A;&%U:W-E96X@=&%R=FET86%N(&IU;&MI;F5N(%--
M24U%+6%V86EN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")!32!0:6QV:>0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM
M<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")!32!K979Y='3D('-A9&5T
M=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")!32!S861E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H
M;W=E<G,B"FUS9W-T<B`B04T@<V%T96ET82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B04T@;'5M:7-A=&5I=&$B"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U
M="!T:&ES(&5D:71O<B(*;7-G<W1R(")4:65T;VIA(&5D:71O<FES=&$B"@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB
M"FUS9W-T<B`B5&EE=&]J82XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R
M(")!8G,N(&%L:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B06)S+B!K
M97-K96QLY"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B4VEN=6QL82!E:2!O;&4@;VEK975K<VEA(&QU;V1A(%9&4RUH
M86ME;6ES=&]A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM
M<V=S='(@(E-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!L=6]D82!61E,M=&EE
M9&]S=&]A+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!
M8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DOD>71TY&KD='5N;G5K<V5N
M('1I961O="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B
M06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")+Y'ET=.1JY'1U;FYU:W-E;B!S
M86QA<V%N82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@
M(DOD>71TY&KD=&EL:2!S=6QJ971T=2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DMI<FIA
M;G!I=&\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("),
M:7/DY"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B3&ESY.0@
M86QI<GEH;>0B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(DQI<^3D(&%L:6]I:V5U<R(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B3&ESY.0@=.1HY&XZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B
M"FUS9W-T<B`B3&ESY.0@=75S:2!R>6AMY"(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(DQI<^3D
M('5U<VD@;VEK975S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B3&ESY.0@86QI<GEH;>0@<GEH;>3D
M;B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O(%PB)7-<(B(*;7-G<W1R("),:7/DY"!A;&EO:6ME=61E="!<(B5S7"(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z
M(@IM<V=S='(@(DQI<^3D('5U<VD@:^1Y='3D:N0Z(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D(&-O
M;'5M;B(*;7-G<W1R("),:7/DY"!S87)A:V4B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`B3&ESY.0@=75S:6$@:N1S96YIY"(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(DQI
M<^3D('!A<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<B(*;7-G<W1R("),:7/DY"`E<R!V86QI:VMO($UO>FEL;&%N(%-I
M9&5B87(@;W-I;V]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G
M<W1R("),:7/DY"!O<V]I=&5K:7)J86%N.B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D
M9')E<W,@8F]O:R(*;7-G<W1R("),:7/DY"!O<V]I=&5K:7)J86%N:3HB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B
M3&ESY.0@:^1Y='3D:N0B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("(*(B5S+B(*;7-G<W1R("(B"B),:7/D='1I:6X@7"(E<UPB(&KD<FIE
M<W1E;&WDY&XL(&UU='1A(&5I('9O:2!L:7/D=.0@<VESY.1N:VER:F%U='5M
M:7-P>7EN;O9N("(*(FQI<^1T:65T;VIA.B`E<RXB"@HC.B!S:6=N=7`N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(DQI<^1T=&EI
M;B!<(B5S7"(@:N1R:F5S=&5L;>3D;BX@5F]I="!N>70@:VER:F%U='5A('-I
M<^3D;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM
M<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")+Y'ET
M=.1J:65N(&QI<^3D;6EN96X@;VX@97-T971T>2XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30T-0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")/<V]I=&4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R
M97-S($)O;VLB"FUS9W-T<B`B3W-O:71E:VER:F$B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-0IM<V=I9"`B061M:6YI<W1E<B`M
M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B5F]I
M(&%S971T86$@=&%I(&WDY')I=&5L;.0@;VEK975K<VEA('1O:7-I;&QE(&OD
M>71TY&II;&QE(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(EEL;.1P:71O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(DUA:6YO:W-E="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N:6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<T"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L9V5R:6$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS
M9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N
M(@IM<V=S='(@(E1A<V%A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R(")4
M87-A=7,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!
M;&PB"FUS9W-T<B`B2V%I:VMI(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I
M9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B2V%I:VMI(&%U
M=&5N=&EK;VED=70@:^1Y='3D:N1T(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS
M,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G
M<W1R(")+86EK:VD@<GEH;>1T(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+V1A=&%T<F5E+G!H<#HW-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDQ"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B2V%I:VMI(&]I
M:V5U9&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B
M2V%I:VEL=&$@;F5L:N1L=.0@<VEV=6QT82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S4*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E
M<R(*;7-G<W1R(")386QL:2!M;VYE="!O<V]I='1E970B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R
M9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")386QL:2!JY')J97-T971Y;B!L
M:7-T86X@='EY<&EN(&%S971U<RXB"@HC.B!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(D]N(&IO(&]L96UA<W-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B
M5F%I:'1O96AT;VEN96X@24U34"US:7/DY&YK:7)J875T=6UI;F5N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-
M4U`@4&%S<W=O<F0B"FUS9W-T<B`B5F%I:'1O96AT;VEN96X@24U34"US86QA
M<V%N82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L
M=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(E9A:6AT;V5H=&]I;F5N
M($E-4U`M:^1Y='3D:N1T=6YN=7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS
M9W-T<B`B5F%I:'1O96AT;VES970@<^1H:_9P;W-T:6]S;VET=&5E="(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M
M<&QA=&5S(@IM<V=S='(@(E9A:6AT;V5H=&]I<V5T(&UA;&QI="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E9A:6AT;V5H
M=&]I;F5N('1E:W-T:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W"FUS9VED(")!;65R:6-A;B!3
M86UO82(*;7-G<W1R(")9:&1Y<W9A;'1A:6X@4V%M;V$B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N(@IM<V=S='(@(D%N;F5T='4@87)V;R!E:2!K96QP86$N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B=&%P86AT=6D@='5N
M=&5M871O;B!V:7)H92XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V"FUS9VED(")!;F1O<G)A(@IM
M<V=S='(@(D%N9&]R<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T"FUS9VED(")!;F=O;&$B"FUS
M9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,`IM<V=I9"`B06YG=6EL;&$B"FUS
M9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;GEY
M;6D@<')O>'DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM
M<V=I9"`B06YS=V5R(@IM<V=S='(@(E9A<W1A=7,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U"FUS
M9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3D*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U
M82!J82!"87)B=61A(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C,V(&%D;6EN
M+W1E;7!L871E<RYP:'`Z-S0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS
M9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")/:&IE;&UA(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM
M<V=S='(@(D]H:F5L;6%L:7-T82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")/
M:&IE;&UA(&]N('9A;&UI<RXB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(DQA:71A(&OD>71T]O9N(&MA:6MK:2!A;&EJ86MO:6AI;B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E
M(@IM<V=S='(@(DAY=N1K<WDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#`*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T
M<B`B07)V:6]I='4@:V]K;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")H=6AT:6MU
M=2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")!<F%B:6,@
M*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A8FEA("A7:6YD;W=S+3$R-38I
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*;7-G:60@(D%R8VAI
M=F4@1FEL92!3:7IE(@IM<V=S='(@(E!A:V5T:6X@:V]K;R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED(")!<F-H:79E($YA;64B"FUS
M9W-T<B`B4&%K971I;B!N:6UI(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@/R(*;7-G<W1R(")/;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T
M('!O:7-T86$@<VESY.1N:VER:F%U='5M:7-P>7EN;O9N("5S(#\B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB
M)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D]L971K;R!V87)M
M82P@971TY"!H86QU870@<&]I<W1A82!<(B5S7"(@:F$@:V%I:VMI('-E;B!A
M;&ER>6AMY'0_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-@IM<V=I9"`B07)G96YT:6YA(@IM<V=S
M='(@(D%G96YT:6EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(*;7-G:60@(D%R;65N:6$B"FUS
M9W-T<B`B07)M96YI82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS
M9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;FEA("A!
M4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`B5&%I9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P"FUS9VED(")!<G5B
M82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B07-C96YS
M:6]N('-A87)E="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I
M9"`B07-C:6D@07)T(@IM<V=S='(@(D%S8VEI+71A:61E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@
M4F5G:6]N(@IM<V=S='(@(D%S:6%N+U1Y>6YE;FUE<F5N(&%L=64B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B
M"FUS9W-T<B`B2WES>2!V87)M:7-T=7,@96YN96X@:W5I;B!T96ADY.1N('EL
M;.1P:71O=&]I;65N<&ET965T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,P.3D*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")4
M96ATY';D<V%R86MK965T(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM
M<V=S='(@(EER:71E='1I:6X@<&]I<W1A82!O;&5M871O;G1A(')Y:&WDY"XB
M"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M(")9<FET971T:6EN('!O:7-T86$@;VQE;6%T;VYT82!O:6ME=71T82XB"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(EER:71E
M='1I:6X@;75O:V%T82!O;&5M871O;G1A(&]I:V5U='1A+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")9<FET971T:6EN(&UU
M;VMA=&$@;VQE;6%T;VYT82!J86MO82XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,0IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("),:7/D;>3D
M<FET>6MS970B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(F5L;VMU=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,CD*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%L:6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(X"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(DETY'9A;'1A(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ(%1A<G9I='1A=F%A($E-05`M;&%A
M:F5N;G5S=&$@96D@;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U
M=&A?8WER=7,Z(%1A=7-T86KD<FIE<W1E;&WD(&5I('1U92!T87)V:71T879I
M82!O;6EN86ES=75K<VEA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!487)V
M:71T879A82!)34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F
M='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE
M(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R
M("(B"B)!=71H7V9T<#H@=&%R=FET=&%V86$@1E10+6QA86IE;FYU<W1A(&5I
M(&SV>71Y;GET+B!+Y.1N;N0@4$A0(&OD>71TY&5N("TM(@HB96YA8FQE+69T
M<"!A<V5T=7-T82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!487)V:71T879A82!)
M34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR
M8C4Z(%1A<G9I='1A=F%A(&MR8C4M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@
M(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!KY'ET=.1J
M:65N(&QI<^3D;6EN96X@06-T:79E($1I<F5C=&]R>7EN(&5I(&]L92!T=65T
M='4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I
M9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@2^1Y
M='3D:FEE;B!P;VES=&%M:65N;B!!8W1I=F4@1&ER96-T;W)Y<W3D(&5I(&]L
M92!T=65T='4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S
M"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!487)V:71T879A82!,1$%0
M+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L9&%P.B!%:2!V;VED
M82!L:7/D=.0@:^1Y='3D:N3D("5S+B!086QV96QI;65N('9I<FAE:6QM;VET
M=7,@;VQI.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R
M96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($5I('9O:61A('!O
M:7-T86$@:^1Y='3D:N3D("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!%
M:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D
M871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2XB"FUS9W-T<B`B075T:%]L9&%P.B!+Y'ET=.1J:65N('#D:79I='3D
M;6EN96X@06-T:79E($1I<F5C=&]R>7EN(&5I(&]L92!T=65T='4N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?;6-A;#H@5&%R=FET=&%V86$@34-!3"UL86%J96YN=7-T82!E
M:2!L]GET>6YY="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z(%1A<G9I
M='1A=F%A('-M8F%U=&@M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H
M96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U
M=&5N=&EK;VEN=&D@24U!4"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B075T
M96YT:6MO:6YT:2!E<.1O;FYI<W1U:2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B075T
M96YT:6MO:6YT:2!E<.1O;FYI<W1U:2X@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!=71E;G1I:V]I
M;G1I(%)!1$E54RUP86QV96QI;65L=&$@97#D;VYN:7-T=6DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I:V]I
M;G1I($944"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I:V]I
M;G1I(%--0BUP86QV96QI;65L;&4@97#D;VYN:7-T=6DN(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD
M<SHB"FUS9W-T<B`B2^1Y=&5T=.1V:7-SY&]L979A="!K96YTY'0Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I>F1A
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%
M>&-U<V5S(@IM<V=S='(@(D)/1D@@<V5L:71Y:W-E="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@
M(D)A8VMG<F]U;F0B"FUS9W-T<B`B5&%U<W1A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N
M9"!#;VQO<B(*;7-G<W1R(")4875S=&%VY')I(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+B(*;7-G<W1R(")6Y.1RY"!K97)B97)O<R!S86QA<V%N82XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R
M8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(E;DY'+D(&ME<F)E<F]S(&OD>71T
MY&KD='5N;G5S+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4*;7-G:60@(D)A:&%M87,B"FUS9W-T
M<B`B0F%H86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS.`IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R
M(")"86AR86EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@
M(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I82`H25-/+3@X
M-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R
M(")"86YG;&%D97-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,PIM<V=I9"`B0F%R8F%D;W,B"FUS
M9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B1W)A9FEI:V]I9&5N('!E<G5S
M:&%K96UI<W1O82!<(B5S7"(@96D@;/9Y='EN>70N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"FUS9VED(")"
M87-E;&EN92(*;7-G<W1R(")097)U<W9I:79A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.0IM<V=I
M9"`B0F5L87)U<R(*;7-G<W1R(")686QK;RU696[D:N0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U
M"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`*
M;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P"FUS
M9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$*;7-G:60@
M(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8*;7-G:60@
M(D)H=71A;B(*;7-G<W1R(")":'5T86XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G
M<W1R(")3>6YT>6WD<.1I=N0B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S8T"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K
M(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")/<VEO=&$@7"(E<UPB(&]H:F5L;6%L;&4@7"(E<UPB(&5I(&SV>71Y
M;GET+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I
M9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B3W-I;VX@87-E='5K<V5T(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C
M:R!4>7!E(@IM<V=S='(@(D]S:6]N('1Y>7!P:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G
M<W1R("),:6AA=F]I='4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S"FUS9VED(")";VQI=FEA(@IM
M<V=S='(@(D)O;&EV:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B2VER:F%N;65R:VET(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(E)E=6YA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R
M9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4F5U;F%N('9A:'9U=7,Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")2975N870B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R
M"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI
M82!(97)Z96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM
M<V=I9"`B0F]T:"(*;7-G<W1R(")-;VQE;6UA="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@*;7-G
M:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"FUS9VED(")"
M;W1T;VTB"FUS9W-T<B`B06QI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<*;7-G:60@(D)O=79E
M="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T('-A87)E="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0*
M;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%S:6QI82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W
M"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T
M<B`B0G)I=&%N;FEA;B!);G1I86X@=F%L=&%M97)E;B!T97)R:71O<FEO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B
M0G)U;F5I($1A<G5S86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<*;7-G:60@(D)U;&=A<FEA
M(@IM<V=S='(@(D)U;&=A<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R(")086QL=6MK86QI<W1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-@IM<V=I9"`B0G5R:VEN
M82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD*;7-G
M:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED
M(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@IM<V=S='(@(D-23"UJ86ME;'5O<V]I='1E970B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@
M(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4U]O;'5N('1I961O="XN
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@
M(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(E;D;&EM
M=6ES=&EN(&%L=7-T=7,@96D@=F%L;6ES='5N=70N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-2!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDQ-@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,34W(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0P"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")+86QE;G1E<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(E1Y>6YI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C@*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;7!U='-E82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C`*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N
M(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B4V%L87-A;F%A(&5I('9O:2!T
M>6AJ96YTY.0@875T;VUA871T:7-E<W1I+"!O=&$@>6AT97ET=.0@>6QLY'!I
M=.1JY.1N+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(D5I('9O:2!K:7)J;VET=&%A('1I961O<W1O;VX@7"(E
M<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@
M(E5L:V]I<VEA(&ES='5N=&]KY'-I='1E;&EJ]FETY"!E:2!O;&4@;6%H9&]L
M;&ES=&$@:&%L;&ET82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,S$Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<R(*;7-G<W1R("))34%0+7!A;'9E;&EM965N(&5I('-A871U('EH
M=&5Y='3D.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")%:2!V;VD@879A=&$@=&EE9&]S=&]A(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4Q"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$Q"FUS9VED(")#86YC96PB"FUS9W-T<B`B4&5R=2(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@
M4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4&5R=2!O;F=E;&UA=FEE<W1I(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M16D@=F]I9&$@<&]I<W1A82!T:65D;W-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-3(*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"FUS9VED(")#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(E;D
M;&EA:6MA:7-H86ME;6ES=&]A(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO
M="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS
M9W-T<B`B16D@=F]I9&$@:F%T:V%A(&EL;6%N("=T87)G971&:6QE)R`M<&%R
M86UE=')I82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(D5I('9O:61A('!O:7-T86$@:&%K96UI<W1O82!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ
M,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A+"`E9"!A;&ET87-O
M:F$@;VQE;6%S<V$N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB16D@=F]I('5U9&5L
M;&5E;FKD<FIE<W3DY"P@86YN971T=6IE;B!T:65T=65I9&5N(&WDY'+D(&5I
M('9A<W1A82`B"B)T86QL971E='1U:F5N('1I971U96ED96X@;>3D<N3D+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BXB"FUS9W-T<B`B16D@=F]I(&]H:F%T82!V:65S=&GD(&%N;F5T
M='5U;B!N=6UE<F]O;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U"FUS9VED(")#87!E(%9E<F1E
M(@IM<V=S='(@(DMA<"!697)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS
M9W-T<B`B2W5V871E:W-T:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R(")0
M86QV96QU;G1A<FIO86IA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS
M"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O
M<FEA="!J82!O='-I:V]T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4*;7-G:60@(D-A>6UA;B!)
M<VQA;F1S(@IM<V=S='(@(D-A>6UA;B!S86%R970B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H
M;VYE(@IM<V=S='(@(E!U:&5L:6XH1U--*2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@
M4')O<&5R=&EE<R(*;7-G<W1R(")3;VQU;B!T:65D;W0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L
M;"!P861D:6YG.B(*;7-G<W1R(")3;VQU;B!TY'ET93HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED
M(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B4V]L=6X@=&EE9&]T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G
M:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B4V]L=6X@=N1L>7,Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H;VYE
M(@IM<V=S='(@(DUA=&MA<'5H96QI;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")+
M96QT=&D@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G
M<W1R(")+97-K:71E='1Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-`IM<V=I9"`B0V5N=')A;"!!
M9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(DME<VMI+4%F<FEK86X@=&%S879A
M;'1A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(DME<VMI+45U<F]O
M<'!A("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S
M='(@(E9A<FUE;G1E96X@=&EE9&]T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM
M<V=S='(@(E9A<FUE;G1E96X@;VUI<W1A:F$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L
M:6-I97,B"FUS9W-T<B`B5F%R;65N=&5E;B!P;VQI=&EI:V%T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Q"FUS9VED(")#:&%D(@IM<V=S='(@(E1S860B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B375U=&$B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(E9A:6AD82!S86QA<V%N87-I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB
M5F]I="!M=75T=&%A(&SD:&5T=.1M:7-SY'-I('/D:&OV<&]S=&5I<W-A(&[D
M:WEV:>0@;FEM:2T@=&%I(&]S;VET971I971O:F$N(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(E-A;&%S86YA;B!V86EH=&\@96D@;VQE(&OD>73V<W/D
M(&YY:WEI<VEL;.0@87-E='5K<VEL;&$N($]T82!Y:'1E>71TY"`B"B)Y;&SD
M<&ETY&II:6XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")-97)K:VDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E1A<FMI
M<W1?82!L:6YK:VDN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y"FUS9VED(")#:&EL92(*;7-G
M<W1R(")#:&EL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(DMI:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")+:6EN82!Y:W-I
M;FME<G1A:7-T971T=2`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G
M<W1R(")+:6EN82!P97)I;G1E:6YE;B`H0FEG-2DB"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM
M<V=S='(@(E9A;&ET<V4@;VAJ96QM82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM
M<V=S='(@(E9A;&ET<V4@<V%L87-A;F$B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R(")686QI='-E(&OD>71TY&KD='5N;G5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.B(*;7-G<W1R(")686QI='-E('#D:7;D;>3D<FEE;B!E<VET>7-A
M<W4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E9A;&ET<V4@;&ES=&%N('1Y
M>7!P:2`H:N1R:F5S=&5T>6EL;&4@;&ES=&]I;&QE*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8*
M;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B2F]U;'5S86%R970B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T(&9R86UE=V]R:R].971?
M4TU3+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("),=6]K:V%MY.1R
M:71Y<W3D("5S(&5I(&SV>71Y;GET+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")3
M96QK9>0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(E!O
M:7-T82!-4T]F9FEC92!T86=I="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(E!O:7-T82!K>7-E;'DB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B4&]I
M<W1A(&OD>71TY&KD.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")0;VES=&$@
M:^1Y='3D:N0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(E!O:7-T82!KY'ET
M=.1JY&X@=&EE9&]T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B4V5L
M:V5N97;DY"!M>?9HY.1N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM
M<V=S='(@(DYA<'-A=71A(&IA=&MA86MS97-I(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC
M:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6MA=&5L;"!(5%10.FX@:V%U
M='1A(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T
M<B`B4W5L:F4@:6MK=6YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*
M;7-G:60@(D-L;W5D<R(*;7-G<W1R(")0:6QV:>0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A
M<FQY(@IM<V=S='(@(E!I;'9I;F5N(&%I:V%I<VEN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*
M;7-G<W1R(")0:6QV:6YE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(*;7-G:60@(D-O8V]S("A+
M965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DMO;VMO<R`H2V5E;&EN9RD@<V%A
M<F5T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I
M9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")0:65N96YNY"!S:79U=F%L
M:6MK;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@
M(E!I96YE;FYE='ET(')E=6YA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(*;7-G:60@(D-O;&]M
M8FEA(@IM<V=S='(@(DMO;'5M8FEA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R
M(@IM<V=S='(@(E;D<FDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3`S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,S-B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B5N1R:79A;&ET<VEN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S,@IM<V=I9"`B0V]L
M;W5R('-E;&5C=&EO;B(*;7-G<W1R(")6Y')I=F%L:6YT82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#
M;VQS.B(*;7-G<W1R(")387)A:SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(E-A<F%K
M:V5I9&5N(&]T<VEK;W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B4V%R:F%K=79A="(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")+
M;VUE;G1O(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM
M86YD(%-H96QL(@IM<V=S='(@(DMO;65N=&]T=6QK:VDB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS
M9W-T<B`B2V]M;65N='1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(EEL96EN
M96X@;FEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,P"FUS9VED(")#;VUO<F]S(@IM<V=S='(@
M(DMO;6]R:70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(EER:71Y<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM
M<V=S='(@(E1I971O:V]N965T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(D]L;W-U:&1E
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@(D-O;F1I=&EO
M;G,B"FUS9W-T<B`B3VQO<W5H=&5E="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(D%S971U:W-I96X@97)O="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!0
M1$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B07-E='5K
M<V5T(%!$02UL86ET=&5I9&5N+"#D;'EP=6AE;&EM:65N(&IA($]U=&QO;VMI
M;B!S>6YK<F]N;VET:6EN+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S
M='(@(D%S971U:W-I82!P:73DY"!PY&EV:71TY.0N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U
M<F4@)7,B"FUS9W-T<B`B07-E=&$@87-E='5K<V5T("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!0
M87-S=V]R9"(*;7-G<W1R(")686AV:7-T82!K:7)J;VET=&%M86QL82!S86QA
M<V%N82!U=61E<W1A86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U"FUS9VED(")#;VYG;R(*;7-G
M<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O+"!4:&4@1&5M
M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B2V]N9V]N(&1E;6]K
M<F%A='1I;F5N('1A<V%V86QT82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,#D*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*
M;7-G<W1R(")9:'1E>7,@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DX"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0IM<V=I9"`B0V]N;F5C=&EO;B!F
M86EL960Z("(*;7-G<W1R(")9:'1E>7,@97#D;VYN:7-T=6DZ("(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M(")9:'1E>7,@:G5L:VES=&5N(&%V86EN=&5N('!A;'9E;&EM96QL92!E<.1O
M;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T
M<B`B66AT97ES(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L;&4@97#D
M;VYN:7-T=6DN(%9I<FAE.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(EEH=&5Y<R!F='`M<&%L=F5L:6UE;&QE(&5P
MY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(T
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*
M;7-G<W1R(")9:'1E>7-T:65D;W0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R
M(")9:'1E>7-T:65D;W0@;&ESY'1T:6EN(&]S;VET96MI<FIA87-I+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@
M(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")4
M:6EV:7-T971Y;B!T:65D;W-T;VX@='EY<'!I.B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HW-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S
M(&]F(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(Z;B!S:7/D;'3V(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")*871K82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3@*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K
M('-A87)E="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B
M0V]O:VEE(@IM<V=S='(@(D5VY'-T92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*
M;7-G<W1R(")+;W!I;VDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B2V]P:6]I;G1I(&5PY&]N;FES='5I.B`E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@
M<V5L96-T:6]N(@IM<V=S='(@(DMO<&EO:2!V86QI;G1A(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B
M"FUS9W-T<B`B0V]S="!)1"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,*;7-G:60@(D-O<W1A(%)I
M8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<*;7-G:60@(D-O
M=&4@9"=)=F]I<F4B"FUS9W-T<B`B3F]R<W5N;'5U<F%N;FEK:V\B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B5FEE<W1I;B!0
M1U`M<V%L875S=&$@96D@=F]I='4@=&5H9.0Z("(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B5FEE<W1I:6X@96D@=F]I='4@;75O
M9&]S=&%A(%!'4"UA;&QE:VER:F]I='5S=&$Z("(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B5FEE<W1I;B!3+TU)344M
M<V%L875S=&$@96D@=F]I='4@=&5H9.0N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+B(*;7-G<W1R(")6:65S=&EI;B!E:2!V;VET=2!M=6]D
M;W-T86$@4R]-24U%+6%L;&5K:7)J;VET=7-T82XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@
M(D5I('9O:71U(&]T=&%A('EH=&5Y='3D+B`E<R(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED
M(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3&1A
M<"UP86QV96QI;65E;B!E:2!S86%T=2!A=71O<FES;VET=6$@>6AT97ET=.0N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,34V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R(")%:2!V;VET=2!T87)K:7-T86$@<V%L
M9&]A+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("),
M1$%0+7!A;'9E;&EM965N(&5I('-A871U('EH=&5Y='3D+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B
M"FUS9W-T<B`B16D@=F]I='4@;W1T86$@>6AT97ET=.0@<&%L=F5L:6UE96X@
M7"(E<UPB(&OD>71TY&5N($944#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(")%:2!V;VET=2!L=6]D82!J86ME;'5L:7-T86$N("5S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R(")01U`M<V%L871T
M=6$@=&EE=&]A(&5I('9O:71U(&%U:V%I<W1A.B`B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(E,O34E-12US86QA='1U82!T
M:65T;V$@96D@=F]I='4@875K86ES=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")%
M:2!V;VET=2!P;VES=&%A('EH=&5Y<W1I971O82X@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(")%:2!V;VET=2!P;VES=&%A(&IA:V5L=6QI<W1A
M82X@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@
M<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I='4@<&]I<W1A82!PY&EV
M:71Y<W-K<FEP=&GD(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(")6:65S=&EN(&SD:&5T=.1J
MY&X@<^1H:_9P;W-T:6]S;VET971T82!E:2!P>7-T>71T>2!MY.1R:71T96QE
M;>3D;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B16D@=F]I='4@:&%K96$@:V]K;R!O<V]I
M=&5K:7)J86$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B16D@=F]I='4@:&%K96$@
M:V]K;R!J86ME;'5L:7-T86$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM
M<V=S='(@(D5I('9O:71U(&AA:V5A(&MO:V\@;&ES=&%A(&IA:V5L=6QI<W1O
M:7-T82XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB
M)7-<(BXB"FUS9W-T<B`B16D@=F]I='4@;'5K96$@<W1R871E9VEA82!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER
M(%PB)7-<(BXB"FUS9W-T<B`B2V]M96YT;R!M:V1I<B!<(B5S7"(@97#D;VYN
M:7-T=6DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y
M"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@
M:V5Y<V5R=F5R+B(*;7-G<W1R(")*=6QK:7-T96X@879A:6YT96X@<&%L=F5L
M:6UE;'1A(&5I('-A871U(&IU;&MI<W1A(&%V86EN=&$N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(E1I961O<W1O;VX@
M7"(E<UPB(&5I('9O:2!K:7)J;VET=&%A+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B16D@=F]I='4@
M875K86ES=&$@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B66QL
MY'!I=&]M;V1U=6QI;B`E<R!A=6MA:7-U(&5PY&]N;FES='5I(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D5I('9O:2!A=6MA
M:7-T82!H86ME;6ES=&]A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S
M-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DQ$05`M<&%L=F5L:6UE;'1A(&5I(&]L92!M86AD;VQL:7-T82!E
M='-IY"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`B)7,ZY.0@96D@=F]I='4@;'5K96$N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)+Y'ET=.1JY&X@<V%L87-A;F%A
M(&5I('9O:71U(&YO;&QA=&$N($IO=&MU="!T87)V:71T879A="!T:65D;W0@
M;W9A="!VY.1R:6XN("(*(EER:73D('5U9&5S=&%A;B!T86D@;W1A('EH=&5Y
M='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E="!L:7/DY"!A<'5A+B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B16D@=F]I='4@:&%K96$@04-,
M+71I971O:F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")%:2!V;VET=2!H
M86ME82!O<V]I=&5K:7)J86$N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(")%:2!V;VET=2!H86ME82!J86ME;'5L:7-T86$N("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B16D@=F]I='4@:&%K96$@:F%K
M96QU;&ES=&]J82X@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,@IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")%:2!V;VET=2!H86ME82!T:65T;VIA
M('!A;'9E;&EM96X@=&]I;6EN;F]I<W1A(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")%:2!V;VET=2!P86QA=71T86$@87-E='5K<VEA+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(")+;VUE;G1O(')M9&ER
M(%PB)7-<(B!E<.1O;FYI<W1U:2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%:2!V;VET=2!T86QL971T86$@
M)7,@87-E='5K<VEA+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,PIM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")%:2!V;VET=2!T
M86QL971T86$@87-E='5S=&5N('9A<FUU=7-K;W!I;W1A+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@
M(D5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R;75U<VMO<&EO=&$@
M)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VET=2!T86QL971T86$@87-E
M='5S<.1I=FET>7-S:W)I<'1IY#H@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S
M='(@(D5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R;75U<VMO<&EO
M=&$@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B
M"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y
M(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B)!
M<V5T=7-T:65D;W-T;VX@)7,@=&%L;&5T=7,@97#D;VYN:7-T=6DN(%9O:70@
M:^1Y='3DY"!J;W1A:VEN(&%S971U<W1A("(*(G1A;&QE='1A86MS97-I(&MO
M;V1I;B!T86MA:7-I;B`E<R!T86D@=&%I(&MO<&EO:61A(&OD<VEN(&%L;&$@
M;VQE=F%N(&MO;V1I;B`B"B)T:65D;W-T;V]N("5S+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A
M<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4"UP86QV96QI;65L
M=&$@96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK
M(%PB)7-<(BXB"FUS9W-T<B`B2V]M96YT;R!U;FQI;FL@7"(E<UPB(&5PY&]N
M;FES='5I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B16D@=F]I='4@<.1I=FET=.3D
M('EH=&5Y<W1I971O:F$N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B16D@=F]I='4@<.1I=FET=.3D(&IA:V5L=6QI<W1A82X@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B5FEE<W1E:N0@96D@=F]I='4@<&]I<W1A82!K86YS:6]S=&$@
M7"(E<UPB.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(DUO>FEL;&$@4VED
M96)A<B!E:2!L]GET>6YY="X@5F%R;6ES=&$@971TY"!3:61E8F%R(&]S:6\@
M;VX@875K:2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV
M92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O
M;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*(DOD>71TY&KD;&QE(%PB)7-<
M(B!E:2!V;VET=2!A;G1A82!S975R86%V:6$@;VEK975S:6$@:V%N<VEO;VX@
M7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*
M;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("),87-K971T=2!T96MS=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I
M9"`B0V]U;G1R>2(*;7-G<W1R(")-86$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU<G-S:70B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("),=6\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B3'5O('5U<VD@;&EN
M:VMI(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("),=6\@=75S:2(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED
M(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B5F]I(&QU;V1A('5U<VEA
M(&MA;G-I;VET82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D]I:V5U
M9&5T('1E:VEJY&QLY"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M,38*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("),=6]T=&]K
M;W)T:6YN=6UE<F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.0IM<V=I9"`B0W)O871I82(*;7-G
M<W1R(")+<F]A=&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-`IM<V=I9"`B0W5B82(*;7-G<W1R
M(")+=75B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R
M<F5N="`T(%!H87-E<R(*;7-G<W1R(")4Y&WD;FAE=&MI;F5N(#0@=F%I:&5T
M=&$B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@
M4V5S<VEO;G,B"FUS9W-T<B`B5.1MY&YH971K:7-E="!I<W1U;FYO="(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM
M<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(DME;&QO;F%I:V$@=.1L;.0@
M:&5T:V5L;.0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S
M='(@(E3D;>1N:&5T:VEN96X@55),(&]N(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(E3D;>1N:&5T
M:VES970@:^1Y='3D:N1T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM
M<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(E3D;>1N:&5T:VEN96X@
M<^3D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I
M9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")4Y&WD;FAE=&MI;F5N
M('1I;&$Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B5.1MY&YH
M971K:6YE;B!T>7EL:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"B)6;VET(&UU;VMA=&$@=&5H
M=.1V:>0L(&IO=&MA('-U;W)I=&5T86%N(&MU;B!K:7)J875D=71A86X@<VES
MY.1N(&]H:F5L;6%A;B`E(@HB<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G
M<W1R("),96EK:V%A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("),
M96EK:V%A('9A;&ET='4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W"FUS9VED(")#>7!R=7,B"FUS
M9W-T<B`B2WEP<F]S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G
M:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(DMY<FEL;&EN96X@*$M/
M23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER
M:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B2WER:6QL:6YE;B`H5VEN
M9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B2WER:6QL
M:6YE;B]5:W)A:6YA("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.`IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`B5'-E:VEN('1A<V%V86QT82(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(E!0(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W-@IM<V=I9"`B(@HB1%-.("AS
M964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"B)$4TX@*&QI<^1T
M:65T;V$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN(@HB<&AP*2(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM
M<V=S='(@(E#D:79I='3D:6XB"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*
M;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964M<V5L
M86EN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W-`IM<V=I9"`B
M1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(E1I971O:V%N=&%H86MU(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`R"FUS9VED(")$871E(@IM<V=S='(@
M(E#D:7;D>7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")0Y&EVY&WDY'+D
M('9A<W1A86YO=&5T='4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-SDS"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")0Y&EVY&WDY'+D
M;B!V86QI;G1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$87DB
M"FUS9W-T<B`B4.1I=N0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN
M(@IM<V=S='(@(E!O7VES=&$@<V%R86ME(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S
M='(@(FIO=6QU:W5U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S
M(@IM<V=S='(@(D1E<VEM86%L:6YU;65R;W0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!)
M;F1E;G0B"FUS9W-T<B`B4&EE;F5N;N0@<VES96YN>7-TY"(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(D]L971U<R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A
M=6QT($-O;&]R(@IM<V=S='(@(D]L971U<W;D<FDB"@HC.B!F<F%M97=O<FLO
M261E;G1I='DO261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT
M:71Y(@IM<V=S='(@(D]L971U<W!R;V9I:6QI(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(D]L
M971U<R!K;VUE;G1O='5L:VMI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")-Y.1R:71E;&WD="(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS,2!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*;7-G
M:60@(D1E;&5T92(*;7-G<W1R(")0;VES=&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E
M;&5T92!#96QL(@IM<V=S='(@(E!O:7-T82!S;VQU(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T
M92!'<F]U<"(*;7-G<W1R(")0;VES=&$@<GEH;>0B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T
M<B`B4&]I<W1A(&QO:VDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED
M(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")0;VES=&$@;VEK975S(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G
M:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B5F]I('!O
M:7-T86$@:F$@='5H;W1A('!O:7-T971T=6IA('9I97-T96KD(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM
M<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B4&]I<W1A('-O;'4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S
M"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E!O:7-T82!S87)A:V4B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")0;VES=&$@;VQE
M;6%S<V$@;VQE=F%T('9A:6AT;V5H=&]I;F5N(&UA;&QI(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T
M92!M97-S86=E<R(*;7-G<W1R(")6;VD@<&]I<W1A82!V:65S=&5JY"(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(E!O:7-T82!<(B5S7"(Z;B!O:6ME=6MS:6$B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\B"FUS9W-T<B`B3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!P
M;VES=&%A(%PB)7-<(B!J82!K86EK:VD@<V5N(&%L:6]I:V5U9&5T/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B4&]I<W1A(')I=FDB"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED
M(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B4&]I<W1A('9A
M;&ET='4@<')O9FEI;&DB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S
M='(@(E9O:2!L=6]D82!U=7-I82!K86YS:6]I=&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B4&]I<W1A('9A
M;&ET='4@<V%R86ME(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W(@IM<V=S='(@(E!O:7-T82!V86QI='1U(')I=FDB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M4&]I<W1E='1U('#D:79I='ES<VMR:7!T:2!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R(")4;VEM:71U<V%I
M:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<Q"FUS9VED(")$96YM87)K(@IM<V=S='(@(E1A;G-K
M82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED
M(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")/;F=E;&UA;B!K=79A
M=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B2W5V875S(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B5&%R:V5M;6%T('1I961O="`H;/9Y
M='EVY'0@;7GV<R!(;W)D93IN(&QO:VET:65D;W-T;W-T82DZ(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(E1A<FME;6UA="!T:65D;W0@;VX@=&%L;&5T971T=2!Y;&SD<&ED;VX@:^1S
M:71E;'3D=N1K<VDN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B2V5H:71Y<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T
M<B`B2V]S=&5U<W!I<W1E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*
M;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B161E
M;&QI<V5N('1U;FYI;B!K;W-T975S<&ES=&4Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(DMO<W1E=7-P:7-T93H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0B"FUS9W-T<B`B4W5U;G1A('9A<V5M;6%L=&$@;VEK96%L;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS
M9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")3=75N=&$@
M;VEK96%L=&$@=F%S96UM86QL92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B2&%K96UI<W1O(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(*;7-G<W1R(")+Y'ETY"`R-"UT=6YN:6X@86EK865S:71Y
M<W3D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R(").Y&MY;>1N(&%S971U:W-E="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA
M>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")%<VET>7-T87!A('EK<VET
M>6ES:V]H=&%I;F5N(&5N;G5S=&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(D5S
M:71Y<W1A<&$@96YN=7-T965L;&4@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#`S"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R
M(")%<VET>7-T87!A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP
M.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@
M(E!E<FEL;&5M96YO:6QM;VET=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P"FUS9VED(")$:FEB
M;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@
M(D5I('-A82!P;VES=&%A(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<"(*;7-G<W1R("+$;.0@:^1Y=.0@<W5O<F%A;B!M86EN=&5N86YC92YP
M:'`Z=.0B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER
M<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K
M('1H:7,@8F]X.B(*;7-G<W1R(")*;W,@96YS:6UMY&EN96X@<FEV:2!S:7/D
M;'3DY"!S87)A:VME:61E;B!O='-I:V]T+"!N:6EN('9A;&ET<V4Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,@IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI:V%A;FEN
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<S"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B1&]M:6YI:V%A;FEN96X@=&%S879A;'1A(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O
M=6YT/R!3:6=N('5P+B(*;7-G<W1R(")%:6OV(&]L92!KY'ET=.1JY'1U;FYU
M<W1A/R!+:7)J875D=2!KY'ET=.1JY&MS:2XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G:60@(D1O=VYL;V%D(@IM<V=S
M='(@(E1A;&QE;FYA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#4Q"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM
M<V=S='(@(E1A;&QE;FYA("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="XB"FUS9W-T<B`B5&%L;&5N;F$@;'5O='4@87-E='5S
M(%!(4"US:W)I<'1I;N0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$Q,0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B06QA<W9E=&]V
M86QI:VMO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$
M<G5G<R(*;7-G<W1R(")(=75M965T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B4^1H:_9P
M;W-T:6]S;VET92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV
M97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB
M"FUS9W-T<B`B(@HB14UA:6PM=&\M4TU3(&=A=&5W87D@86IU<FDL(&YI:6QL
M92!P86QV96QU;G1A<FIO86II;&QE+"!J;W1K82!T87)J;V%V870@=.1TY"`B
M"B)P86QV96QU82XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B5DE22$4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U"FUS9VED(")%8W5A9&]R(@IM<V=S
M='(@(D5C=6%D;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@
M(D5D:70B"FUS9W-T<B`B375O:VMA82(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B375O
M:VMA82!O<VEO=&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G
M<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")-=6]K
M:V%A(')Y:&WDY"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;B(*;7-G<W1R(")-=6]K:V%A(&]I:V5U='1A(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R(")-=6]K:V%A(&]I:V5U:W-I82(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B375O:VMA82`G)7,G
M.FX@;VEK975K<VEA(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM
M<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B375O:VMA82!A<V5T
M=6MS:6$Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(DUU;VMK86$@7"(E<UPB.FX@;VEK975K<VEA(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")-=6]K:V%A
M("5S.FX@;VEK975K<VEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U
M"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B2V]U;'5T=7,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<W"FUS9VED(")%9WEP="(*;7-G<W1R(")%9WEP=&DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A;'9A9&]R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE;G1T:2XN
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W,PIM<V=I9"`B16UA:6PB"FUS9W-T<B`B4^1H:_9P;W-T:2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R(")3Y&AK]G!O<W1I;W-O:71E(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DV-PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T
M8V@N(@IM<V=S='(@(E/D:&OV<&]S=&EO<V]I='1E:61E;B!P:73DY"!O;&QA
M('-A;6%T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.3,*;7-G
M:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E/D:&OV<&]S
M=&D@=F%R;6ES='5K<V5L;&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W
M87DB"FUS9W-T<B`B16UA:6PM=&\M4TU3($=A=&5W87DB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED(")%;6]T
M:6-O;G,B"FUS9W-T<B`B2'EM:?9T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S
M86=E+B(*;7-G<W1R(")4>6AJY"!V:65S=&DN(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@
M<F5S=6QT+B(*;7-G<W1R(")4>6AJY"!V87-T875S+B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C
M:"!T97)M<R(*;7-G<W1R(")4>6AJY"!H86MU=&5R;6DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F
M(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R
M(")386QL:2!K=79I96X@;&%I='1A;6EN96X@:W5V86=A;&QE<FEA<W1A('1E
M:W-T:6X@:F]U:VMO;VXN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R
M,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS
M9W-T<B`B3&%I=&$@<.3D;&QE(&]I:V5A;B!P86EN:6MK965N(&MO;G1E:W-T
M:6UE;G4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDW"FUS9VED(")%;F0@>65A<B(*;7-G
M<W1R(")0Y.1T='EM:7-V=6]S:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM
M<V=S='(@(E-U=7)E;FYA(&5D:71O<FEA(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(D%N;F$@:WES>6UY<R!J;VMA(&MY
M<WETY.1N+"!J;W,@<V%L87-A;F%S:2!J;W5D=71A86X@;F]L;&%A;6%A;B!E
M<VEM97)K:6MS:2`B"B(G;6EKY"!O;B!L96UM:6MK:7-I(&YI;6D_)SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G
M<W1R("),86ET82!K=79A(%523"!TY&CD;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H92!L
M971T97)S(&)E;&]W.B(*;7-G<W1R(")!;FYA(&MI<FIA:6UE="!A;&QE.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3D*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@
M(D5K=F%T;W)I86%L:6YE;B!'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y"FUS9VED(")%
M<FET<F5A(@IM<V=S='(@(D5R:71R96$B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#@*;7-G:60@(D5R<F]R(@IM<V=S='(@(E9I<FAE(@H*(SH@9G)A
M;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(E9I
M<FAE('#D:79I=&5T=.1E<W/D(&]S:6]T83H@)7,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B5FER:&4@<.1I
M=FET971TY&5S<^0@<WEN8R!A;F-H;W(@+71I971O83H@)7,B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B5FER:&4@
M<&]I<W1E='1A97-S82!S>6YC(&QO:VEA.B`E<R(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B5FER:&4@:&%E
M='1A97-S82!S:7/D;'3VY#H@)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")6:7)H92!PY&EV:71E='3D97-S
MY"!S86QA<V%N86$Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N(@IM<V=S='(@(E9I<FAE('/D:&OV<&]S=&EV:65S=&ES<^0N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B5FER:&4@:VER:F]I
M=&5T=&%E<W-A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V"FUS9VED(")%<W1O;FEA
M(@IM<V=S='(@(D5E<W1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,0IM<V=I9"`B171H:6]P:6$B
M"FUS9W-T<B`B171I;W!I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T;FEN96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R
M(")%=7)O;W!P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G
M:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B,34@;6EN=75T:6X@=N1L
M96EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E
M<GD@,B!M:6YU=&5S(@IM<V=S='(@(C(@;6EN=75T:6X@=N1L96EN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(C,P('-E
M:W5N;FEN(';D;&5I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(C4@;6EN=75T:6X@=N1L96EN(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@
M3&]G:6XB"FUS9W-T<B`B2F]K86ES96QL82!S:7/DY&YK:7)J875T=6UI<V5L
M;&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R
M>2!H86QF(&AO=7(B"FUS9W-T<B`B4'5O;&5N('1U;FYI;B!VY&QE:6XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")-:6YU=71I
M;B!VY&QE:6XB"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM
M<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(D5S:6UE<FMK:6%R=F]T
M.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HU,2!A9&UI;B]P:'!S:&5L;"YP
M:'`Z.#(@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*
M;7-G<W1R(")3=6]R:71A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R("),
M86%J96YN82(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*
M;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(DQA86IE;FYA('-I=G5V
M86QI:VMO(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V
M.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(D]D;W1E='1I:6X@;65R
M:VMIY"`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C
M:"!T97)M(@IM<V=S='(@(E-A;F$@<V5L;&%I<V5N86%N('1A:2!H86MU=&5R
M;6D@;&%I;F%U<VUE<FME:7-SY"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@
M(DQO<'!U<.1I=N1MY.1RY"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%:W-P;VYE
M;G1T:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D9'(';D<FDB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L
M;V%D(&]F('-E='5P(@IM<V=S='(@(D%S971U<W1I961O<W1O:F5N('1U;VYT
M:2!&5%`Z;&SD(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z
M,C(U"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS
M9W-T<B`B07-E='5S=&5N(&AA:W4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")9:'1E>7,@3$1!4"UP86QV96QI;65E;B!E
M<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM
M<V=S='(@(EEH=&5Y<R!334(M<&%L=F5L:6UE96X@97#D;VYN:7-T=6DN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(DMO<&EO:6YT:2!<(B5S7"(Z;'3D(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B2V]P:6]I;G1I
M(%PB)7-<(CIL;&4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")5=61E;B!305-,+7EH=&5Y9&5N
M(&QU;VUI;F5N(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S4U(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB
M"FUS9W-T<B`B4VEI<G1O(%PB)7-<(CKDY&X@97#D;VYN:7-T=6DN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")3:6ER=&\@
M97#D;VYN:7-T=6DZ("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B2V%U;FES(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-`IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I
M(@IM<V=S='(@(D9A;&ML86YD:6X@<V%A<F5T("A-86QV:6YA<RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@V"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D;D<B!S86%R
M970B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"FUS9VED(")&871A
M;"!%<G)O<CHB"FUS9W-T<B`B5F%K879A('9I<FAE.B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*
M;7-G<W1R(")&86MS:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A:W-I="(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R(")H96QM:6MU=2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(E1U;G1U=2!K=6EN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E
M;',@;&EK93H@(@IM<V=S='(@(E1U;G1U=2!K=6EN.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H
M;W=E<G,B"FUS9W-T<B`B375U=&%M:6$@<V%T96ET82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(DUU=71A;6EA(&QU;6ES871E:71A(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT.`IM<V=I9"`B1FEE;&0@;6%T
M<FEX(@IM<V=S='(@(DME;G1TY&UA=')I:7-I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,R.0IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T
M<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S,S"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R(")&:6=L970@:VER
M:F%S:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@S"FUS9VED(")&:6II(@IM<V=S='(@(D9I9'II
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&
M:6QE(@IM<V=S='(@(E1I961O<W1O(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL92(*;7-G<W1R(")4:65D;W-T;VIE;B!L=6MU;>3D<N0Z("5S('1I961O
M<W1O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B5&EE
M9&]S=&]J96X@;'5K=6WDY'+D.B`E<R!T:65D;W-T;V$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS
M9W-T<B`B5&EE9&]S=&]J96X@:^1S:71T96QY(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S`*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")4:65D
M;W-T;VX@;FEM:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.#$*
M;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E1I961O<W1O;B!V86QI
M;G1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Y,`IM<V=I9"`B
M1FEL92!U<&QO860B"FUS9W-T<B`B5&EE9&]S=&]N('1U;VYT:2(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP,@IM<V=I9"`B1FEL92!U
M<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(E1I961O<W1O:F5N('1U
M;VYT:2!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B4W5O9&%T
M=&EM970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@R"FUS9VED(")&:6YL86YD(@IM<V=S='(@(E-U
M;VUI(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@
M2&%L9B(*;7-G<W1R(")%;G-I;6WD:6YE;B!P=6]L:7-K;R(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@
M(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B16YS:6UMY&EN96X@;F5L:N1N;F5S
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U
M-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(DMO<FIA82!S=6AD92(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G
M:60@(D9L:7`B"FUS9W-T<B`B2^3D;F[D('EM<.1R:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@
M(D9L;V%T(@IM<V=S='(@(DME;&QU=F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(E-U
M;74B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R(")+86YS:6]T82`E
M<R!E:2!O;&4@;VQE;6%S<V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R
M(")+:7)J87-I;65N(';D<FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B4G5O:V$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G
M:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM
M<V=S='(@(E-E;&%I;6EL;&4L(&IO=&MA(&5I=N1T('1U92!K=79I82(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")%;FYU<W1E("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(D5N;G5S=&5T=&%V870@
M=G5O<F]K875D970@*$AU;VUA871H86X@971TY"!E;FYU<W1U:W-E<W-A(&]N
M('1I961O="!S96OD("(*(G#D:79I<W3D(&5T=.0@]FES=.0L(&IO=&5N('-U
M=7)I(&WDY'+D('#D:79IY"!A:6AE=71T86$@;&EI86X@;&5V9>1N(&]S:6]N
M*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&
M;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B56YO:&1I=&MO('-A;&%S
M86YA<VD_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I
M9"`B1F]R;7,B"FUS9W-T<B`B3&]M86MK965T(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(DUI971E;&%U
M<V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U
M;F4@='EP92(*;7-G<W1R(")-:65T96QA=7-E96X@='EY<'!I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R
M(")-:65T96QA=7-E970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*
M;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B36EE=&5L875S965T(#(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B
M"FUS9W-T<B`B1F]O<G5M:70B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")5=61E;&QE96YO:&IA
M=6MS970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")P92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R
M86UE<R(*;7-G<W1R(")+96AY:W-E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<*;7-G:60@(D9R
M86YC92(*;7-G<W1R(")286YS:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S
M='(@(E)A;G-K82P@365T<F]P;VQI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,0IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R(")286YS:V%N($=U>6%N82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@T"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E)A;G-K86X@
M4&]L>6YE<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R"FUS9VED(")&<F5N8V@@4V]U=&AE
M<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B4F%N<VMA;B!E=&5LY&ES970@=&5R
M<FET;W)I;W0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(DSD:&5T=.1JY"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B4W5U;FYA<W1A
M("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED
M(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E!I9&5M<&D@:W5V875S.B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B5.1Y<VEK=74B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DMO:V\@
M;FEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#@*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;2(*;7-G<W1R(")'86QL97)I82P@:F]S=&$@:W5V82!O=&5T86%N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QL97)I83HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDV"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E1E92`E<R!A
M<V5T=6MS970B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT
M;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N97)O:71U
M(&MO;V1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'
M96]R9VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")3
M86MS82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3,*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H86YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A
M;'1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(D5T=6YI;6DB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED
M(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")9;&5I<V5T(&%S971U:W-E="(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G
M<W1R(")-96YE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED
M(")';V5D96PB"FUS9W-T<B`B1_9D96PB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B
M"FUS9W-T<B`B1V]O9VQE($MA<G1A="(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B1V]O9VQE
M(&AA:W4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B2&%R;6%A<^1V>2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`P"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B2W)E:6MK82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/
M+3@X-3DM-RDB"FUS9W-T<B`B2W)E:6MK82`H25-/+3@X-3DM-RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDU"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W+V;FQA;G1I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX.0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(E)Y:&WD;B!Y;&SD<&ET;R(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB"FUS9W-T<B`B4GEH;6EE;B!N:6UE="!E:7;D="!S86$@;VQL82!T>6AJ
M:>0B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G
M<W1R("(B"B)'<F]U<%]L9&%P.B!%:2!V;VED82!L:7/D=.0@:^1Y='3D:N3D
M("5S+B!086QV96QI;65N('9I<FAE:6QM;VET=7,@;VQI.B`B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD
M87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET=.1JY.0@)7,B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O
M=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'
M<F]U<%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D("5S(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")2>6AMY'0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#(*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@
M(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E9I97)A:6QI:F%N(&]I:V5U
M9&5T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B
M1W5E<W1B;V]K(@IM<V=S='(@(E9I97)A<VMI<FIA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-PIM
M<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-`IM
M<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN96$M0FES<V%U(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`U"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y86YA(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM
M<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T
M<B`B2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET>7D@<&]I<W1A
M;6%S=&$@<FEV:6X@=FEI;65I<W3D('-O;'5A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@HB2%1-3$%R96$@<&5L:W5R:6UA
M:7-E<W1I(&MI96QTY'ET>7D@<&]I<W1A;6%S=&$@=FEI;65I<W3D('-A<F%K
M971T82`B"B)T875L=6MO<W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L
M92XB"FUS9W-T<B`B(@HB2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QT
MY'ET>7D@<&]I<W1A;6%S=&$@=FEI;65I<W3D(')I=FGD('1A=6QU:V]S=&$N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10
M+6%U=&5N=&EK;VEN=&EA(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,`IM
M<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM
M<V=S='(@(DAA<V@M86QG;W)I=&UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B57-V
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDR,R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3$X"FUS9VED(")(96%D97(B"FUS9W-T<B`B3W1S
M86ME(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")/='-A:V4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#<*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<R(*;7-G<W1R(")(96%R9"!J82!-8T1O;F%L9"!S86%R970B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A
M=GD@5"U3=&]R;2(*;7-G<W1R(")6;VEM86MA<R!U:VMO<VUY<G-K>2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX
M.#4Y+3@M22DB"FUS9W-T<B`B2&5P<F5A("A)4T\M.#@U.2TX+4DI(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S
M='(@(DMO<FME=7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP
M:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD
M97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B3VAJ92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE
M;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D%P=6$@961I=&]R:6X@:^1Y='3V
M]FXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<U"FUS9VED(")(
M96QP97(B"FUS9W-T<B`B3VAJ92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")086QL;VYP=6]L:7-K;SHB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN
M:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")4Y'-SY"!O;B!T:65D;W-T;VX@
M86QK=6]S83HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,0IM<V=I9"`B2&EG:"(*;7-G<W1R(")+;W)K96$B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO
M;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(DMO7W1I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,PIM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92DB"FUS9W-T<B`B4'EHY"!I<W1U:6X@*%9A=&EK86%N:6X@:V%U<'5N
M:VEV86QT:6\I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q
M"FUS9VED(")(;VUE(@IM<V=S='(@(DMO=&DB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S
M<R(*;7-G<W1R(")+;W1I;W-O:71E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")+;W1I:&%K
M96UI<W1O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")0=6AE;&EN("AK
M;W1I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P.`IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B
M2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8*;7-G:60@(DAO;F<@2V]N9R(*;7-G
M<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@17#D:V5L<&]A("5S
M(%A-3"UD871A82!V:65S=&ES<^0@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(%EK<VEKY.1N('9I97-T:2!E:2!V87-T86$@;V)J
M96MT:6$@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@66ATY&ODY&X@;V)J96MT:6$@)7,@96D@;/9Y='EN>70@=FEE<W1I
M<W3D("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%!O:7-T
M971T:6EN("5S(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G
M<W1R("(B"B)(;W)D92]+;VQA8CH@26YT96=R86%T:6]K;VYE('9A871I:2!T
M;VEM:6%K<V5E;B`G9&]M>&UL)R!02%`M;&%A:F5N;G5K<V5N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5I('9O:61A
M(&QU;V1A('5U='1A(%A-3"UP=75T82!O8FIE:W1I;&QE("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5I('9O:71U('!O:7-T86$@)7,@
M7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#@S
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@16D@=F]I9&$@:&%K96$@34E-12!)1#KD(&]S
M:6]L;&4@='EY<'!IY"`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($5I('9O:2!S>6MR;VYO:61A("5S(%PB)7-<(CH@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S
M:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%:2!V;VED82!S>6YK
M<F]N;VED82!J86MO:F$Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!4=6YT
M96UA=&]N(&IA:V\@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM
M<V=S='(@(E9A86MA<W5O<F$@<^3D;G3V(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P
M861D:6YG(@IM<V=S='(@(E9A86MA<W5O<F$@=.1Y=&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I
M>F]N=&%L.B(*;7-G<W1R(")686%K87-U;W)A.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T
M<B`B36ET96X@='5L:70@=.1N;F4_("A287!O<G1O:2!K:6ET;W,A*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(DMU:6YK82!M;VYT82!S87)A:V5T=&$@:&%L=6%T
M('EH9&ES=.3D/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B
M"FUS9W-T<B`B2V5N='1I96X@*'-A<F%K:V5I9&5N*2!L=6MU;>3D<N0N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B2W5I;FMA(&UO;G1A(')I=FGD(&AA;'5A="!Y:&1I
M<W3DY#\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S-R!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R
M(")+;W-T975S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")+;W-T975S.B`B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G
M<W1R(")(=6UO<FES=&ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q"FUS9VED(")(=6YG87)Y
M(@IM<V=S='(@(E5N:V%R:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(DE-05`M<&]S=&EL86%T:6MO;B!L=6]N=&D@
M97#D;VYN:7-T=6DZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(Y-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B24U!4"UP;W-T:6QA871I:V]N('!O:7-T;R!E
M<.1O;FYI<W1U:3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0+7!O<W1I;&%A=&EK;VX@:VEI
M;G1I]FX@;'5O;G1I(&5PY&]N;FES='5I.B`E<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B
M25`M;W-O:71E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H
M<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("))4"UO<V]I=&4@96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`M
M;W-O:71E(&5I(&]L92!S86QL:71U;B!#2412+6)L;VMI;B!S:7/D;&SD(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(DE0
M+7/DY&YN]G-T]FX@<FEK:V]M=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@
M4F]W($)E9F]R92(*;7-G<W1R("),7V%I=&$@<FEV:2!E;FYE;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,`IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA;G1I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*
M;7-G<W1R(")686EN(&EK;VYI="(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T
M<B`B26MO;FET("5S.FQL92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")):V]N:70@:F$@
M=&5K<W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R(")0<F]F:6EL:6X@;FEM:3HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")*
M;W,@<VEV=2!E:2!NY'D@:W5N;F]L;&$L(&YI:6X@875K86ES92`E<R!E<FEL
M;&ES97-SY"!I:VMU;F%S<V$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B
M"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G
M<W1R("(B"B)*;W,@970@;N1E(&EK;VYE:71A(&OD>71TY&5S<^1S:2!);G1E
M<FYE="!%>'!L;W)E<B!S96QA:6YT82P@;FEI;B!S:6YU;B`B"B)P:73DY"!O
M='1A82!P;VES('#DY&QTY"!03D<@;.1P:6[D:WEV>7ES(')A<W1I='1A;6%L
M;&$@=.1MY"!L86%T:6MK;RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB
M"FUS9W-T<B`B(@HB2F]S(&[D970@=.1MY&X@=FEE<W1I;BP@;75T=&$@970@
M:W5V86$L(&YI:6X@='5O;6%A<VD@:W5V86$@96D@=F]I(&[D>71TY.0@(@HB
M:^1Y='3D;>1S<^1S:2!S96QA:6UE<W-A+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B2W5V:65N(&5S:6MA='-E;'4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B2W5V82!54DPB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B2W5V82!54DPZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B
M2W5V82!G86QL97)I87-T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y.B(*;7-G<W1R(")+=79A(&=A;&QE<FEA<W1A.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(DEM86=E('5P;&]A
M9"(*;7-G<W1R(")+=79A;B!V:65N=&DB"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DMU=F%T(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B5'5O;G1I+"!A<VME;"`E9"(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")4=6]T=2!K
M96YT=.0Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM
M<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")4=6]D=70@:V5N=.1T
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B
M3&%?:71A(')I=FD@:N1L:V5E;B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+B(*;7-G<W1R(")6Y.1RY"!T;VEM:6YT;VMO;V1I(&%N;F5T
M='4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(DOD>71TY&KD='5N;G5S('1A:2!S86QA<V%N82!O
M;B!VY.1R:6XN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*
M;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB5N3D
M<N0@:^1Y='3D:N1T=6YN=7,@=&%I('9A:6AT;V5H=&]I;F5N(&]S;VET92X@
M67)I=.0@=75D97-T86%N(&IA(&]T82`B"B)Y:'1E>71TY"!Y;&SD<&ET;V]N
M(&IO<R!T87)V:71S970@;&ESY.0@87!U82XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!)
M;F1E;G0B"FUS9W-T<B`B3&ESY.0@<VES96YN>7-TY"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-@IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YT:6$B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")9:W-I
M='3D:7-E="!KY'ET=.1JY'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(*;7-G:60@(DEN9&]N
M97-I82(*;7-G<W1R("));F1O;F5S:6$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@
M(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED
M("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA871I;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(E1I971O82!E:2!O;&4@
M96[DY"!S86%T879I;&QA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU
M;6X@069T97(B"FUS9W-T<B`B3&%I=&$@<U]A<F%K92!JY&QK965N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B3&%I=&$@:W5V
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("),86ET82!T875L=6MK
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("),86ET82!W=W<M
M;&EN:VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B
M"FUS9W-T<B`B3&%I=&$@7W-A<F%K92!E;FYE;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B3&%I=&$@=75S:2!S87)A:V4@;GEK>6ES96X@:N1L:V5E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(DQA:71A('5U<VD@<V%R86ME(&5N;F5N(&YY
M:WEI<W3D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("),86ET82!U=7-I(')I=FD@;GEK
M>6ES96X@:N1L:V5E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DQA:71A('5U<VD@
M<FEV:2!E;FYE;B!N>6MY:7-TY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B3&%I
M=&$@:V%P<&%L92!N>6MY:7-E;B!N;V1E;B!JY&QK965N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B3&%I=&$@:V%P<&%L92!E;FYE;B!N>6MY:7-TY"!N;V1E
M82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@
M86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DQA:71A('9A:6AT;V5H=&]I
M;F5N(&UA;&QI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I
M9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(D%N;F$@<^1H:_9P
M;W-T:6]S;VET92!J;VAO;B!U=7-I('-A;&%S86YA(&SD:&5T973DY&XZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B3&%I=&$@
M<V]L=2!JY&QK965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E
M(@IM<V=S='(@(DQA:71A('-O;'4@96YN96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E
M<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DQA:71A('-O;'4@:N1L:V5E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DQA
M:71A('-A<F%K92!E;FYE;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDQ"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B
M5F]I(&QA:71T86$@=FEE<W1E:N0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B3&%I=&$@:V%P<&%L92!JY&QK965N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G
M<W1R("),86ET82!K87!P86QE(&5N;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T
M(')O=R!A9G1E<B(*;7-G<W1R("),86ET82!R:79I(&5N;F5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM
M<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B3&%I=&$@<FEV:2!J
MY&QK965N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.B(*;7-G<W1R(")!;FYA('9A861I='1A=F$@=F%S=&%U<R!T=7)V
M86MY<WEM>6MS965N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS
M9W-T<B`B3&EI=.0O375O:VMA82!K=79I82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I
M9GD@3&EN:R(*;7-G<W1R("),:6ETY"]-=6]K:V%A(&QI;FMK:>0B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@HB4VEN=6QL82!E:2!O;&4@=&%R
M<&5E:W-I(&MR961I:71T96KD(&SD:&5T=.3D:W-E<VD@=FEE<W1I;B!J86ME
M;'5L:7-T86QL92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB
M"FUS9W-T<B`B4FEI='3D;>1T=/9MY'-T:2!K<F5D:6ET=&5JY"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN=&5G97(B"FUS
M9W-T<B`B2V]K;VYA:7-L=6MU(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(DMO:V]N86ES
M;'5K=6QI<W1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+B(*;7-G<W1R(")%<.1K96QP;R`@541(("A5<V5R($1A=&$@
M2&5A9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R(")%<.1K96QP
M;V$@6DE0+71I971O82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")%<.1K96QP
M;R!O:&IE;&UA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS
M9W-T<B`B17#D:V5L<&\@8F%T8V@@240N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`Y,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,38R"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,P,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R("),Y&AE=&5T=&EI;B!E<.1K96QP;V$@=&EE=&]A+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM
M<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(")%
M<.1K96QP;R!V87-T86%N;W1T86IA;B!O<V]I=&4N(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL
M92!F;W)M870B"FUS9W-T<B`B17#D:V5L<&\@=&EE9&]S=&]M=6]T;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L
M:60@;&EC96YS92!K97DN(@IM<V=S='(@(D5PY&ME;'!O(&QI<V5N<W-I879A
M:6XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I
M9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B17#D:V5L
M<&\@<&%I:VMA=&EE=&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E
M+B(*;7-G<W1R(")%<.1K96QP;R!M<V=?='EP92`N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("))
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(")%<.1K96QP;R!T
M86D@<'5U='1U=F$@87!I7VED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M
M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(D5PY&ME;'!O('1A:2!P=75T
M='5V82!P87)A;65T<FDN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M(")%<.1K96QV;W0@;VEK975D970@>6QE;6WD;&SD('1A<V]L;&$N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI
M9"!P87)T;F5R(&ED+B(*;7-G<W1R(")%<.1K96QP;R!P87)N97(@:60N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV
M86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(D5PY&ME;'!O('1U;W1E:V]O
M9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")%
M<.1K96QP;R!P<F]T;VMO;&QA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C
M:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B17#D:V5L<&\@=F%S=&%A;F]T=&%J
M83H@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#@P
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI
M9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B17#D:V5L<&\@:F%K;RUO8FIE:W1I
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R
M(")%<.1K96QP;R!LY&AD96]S;VET92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@
M=6YI8V]D92!D871A+B(*;7-G<W1R(")%<.1K96QP;V$@=6YI8V]D92UT:65T
M;V$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B
M26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&%A<FEO(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T
M('-E;&5C=&EO;B(*;7-G<W1R(")+Y.1N;N0@=F%L:6YT82!KY.1N=&5I<V5K
M<VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3D*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B27)A;BP@27-L86UI;&%I;F5N('1A<V%V86QT82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q.`IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$S"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N=&DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O
M9B!-86XB"FUS9W-T<B`B36%N+7-A87)I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O
M<FUS(@IM<V=S='(@(D5R:6QL:7-IY"!5:VMO<VUY<G-K>6KD(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$T"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R865L(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E
M<B(*;7-G<W1R("),:6EK:V5E;&QE;&%S:VEJ82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM
M<V=S='(@(DMU<G-I=F]I='4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$*;7-G:60@(DET86QY
M(@IM<V=S='(@(DET86QI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,PIM<V=I9"`B2F%M86EC
M82(*;7-G<W1R(")*86UA:6MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B=&%M
M;6EK=74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C4*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA
M<&%N:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A
M;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&%N:2`H25-/+3(P,C(M
M2E`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@
M(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0*;7-G:60@
M(DIO<F1A;B(*;7-G<W1R(")*;W)D86YI82(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@
M(FAE:6[D:W5U(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B:V5SY&MU=2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*
M;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B2V5S:VETY"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"FUS9VED
M(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")+97-K:73D(&ME<VME;&QE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#`*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")+97-K:73D('3D
M>7-I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,30*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,W"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B2V5S
M:VETY"!V87-E;6UA;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*;7-G:60@(DIU<W1I9GD@4FEG:'0B
M"FUS9W-T<B`B2V5S:VETY"!O:6ME86QL92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-@IM<V=I
M9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA:W-T86XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R(")3Y&EL>73D(&%L:W5P97+D:6YE;C\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C8*;7-G:60@(DME;GEA(@IM<V=S='(@(DME;FEA(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!
M=71E;G1I:V]I;G1I(&5PY&]N;FES='5I($ME<F)E<F]S+7!A;'9E;&EM96QL
M92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE
M;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"!A;&]I='1E;&EJ870B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#
M<F5A=&EO;B(*;7-G<W1R(")!=F%I;65N(&QU;VYT:2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R
M:6YT(@IM<V=S='(@(D%V86EM96X@='5N;FES=&4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS
M9W-T<B`B079A:6UE;B!P:71U=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(D%V86EM
M96X@='EY<'!I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")!=F%I;65N(&OD>71T
M]B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I
M9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R(")!=F%I;B!O;B!J;R!J=6QK:7-T96X@879A:6YT96X@<&%L
M=F5L:6UE;&QA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED
M(")+:61S(@IM<V=S='(@(DQA<'-E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.0IM<V=I9"`B
M2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(*;7-G
M:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DMO<F5A+"!D96UO:W)A871T:6YE;B!K86YS86YT87-A=F%L=&$@
M*%!O:&IO:7,M2V]R96$I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S"FUS9VED(")+;W)E82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]R96$L('1A<V%V86QT82`H171E;.0M
M2V]R96$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO
M<F5A;B`H155#+4M2*2(*;7-G<W1R(")+;W)E82`H155#+4M2*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-`IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=V%I="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:7-T86XB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`B07-?971T96QU(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B2VEE;&DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E
M<'5B;&EC(@IM<V=S='(@(DQA;W,L(&1E;6]K<F%A='1I;F5N(&MA;G-A;G1A
M<V%V86QT82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA
M<W0@2&%L9B(*;7-G<W1R(")*Y&QK:6UMY&EN96X@<'5O;&ES:V\B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@
M0VAA;F=E(@IM<V=S='(@(D5D96QL:6YE;B!S86QA<V%N86YV86EH=&\B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X
M"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B2N1L:VEM;>1I;F5N(&YE
M;&KD;FYE<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34X"FUS9VED("),
M87-T(%5P9&%T960Z(@IM<V=S='(@(E#D:79I=&5T='D@=FEI;65K<VDZ(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(D5D96QL:6YE;B!S:7/D
MY&YK:7)J875T=6UI;F5N.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F
M<F]M("5S(@IM<V=S='(@(D5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI;F5N
M.B`E<RP@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*;7-G
M:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(D5D96QL:6YE;B!S:7/D
MY&YK:7)J875T=6UI;F5N.B!%:2!M:6QL;VEN:V%A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-@IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQA='9I82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DQA:VDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")!<V5T=&5L=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE
M879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B2N1TY"!T>6AJY&MS
M:2!J;W,@96D@<F5U;F]J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.`IM<V=I9"`B3&5B86YO
M;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0P"FUS9VED("),969T(@IM<V=S='(@
M(E9A<V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-0IM<V=I
M9"`B3&5F="!H96%D97(B"FUS9W-T<B`B5F%S96X@;W1S86ME(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,0IM<V=I9"`B3&5F="!V86QU97,B
M"FUS9W-T<B`B5F%S96X@87)V;W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,*;7-G:60@(DQE
M<V]T:&\B"FUS9W-T<B`B3&5S;W1O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R(")487-O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30R"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R:6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#<*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS
M9W-T<B`B3&EB>6$@07)A8B!*86UA:&ER:7EA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P"FUS
M9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI8VAT96YS=&%I;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED
M("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(DME=GET=.0@<N1N=.3D(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@
M(DQI9VAT(%)A:6XB"FUS9W-T<B`B2VER:F%U9'4@<VESY.1N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI
M9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B2V5V>71TY"!S861E='1A(&%I:V%I
M<VEN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")+979Y='3D('-A
M9&5T=&$@;7GV:&5M;6EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S
M='(@(DME=GEI=.0@<V%D96MU=7)O:F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(B"FUS9W-T<B`B2V5V>71TY"!S861E='1A(&IA(&UY<G-K>6ES
M=.0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(")+979Y='3D(&QU;6ES861E
M='1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(DME=GEI=.0@
M;'5M:6MU=7)O:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G
M:60@(DQI;65R:6-K(@IM<V=S='(@(DQI;65R:6MI="(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X,3@*;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EN
M:VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M3&EN:VMI(&]S;VET=&%A.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B3&EN:VETY"!S
MY&AK]G!O<W1I;W-O:71E(&MI<FIO:71A('5U<VD@=FEE<W1I('-I=G5L;&4@
M;N1K>6WD<W/D(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3&EN:VET
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#
M;V]K:64B"FUS9W-T<B`B3&EN=7@@<&EP87)E:71A(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(DQI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R(")6;VD@;&ES=&%U:W-E<W-A
M(&[D:&3D(&MA;G-I;VXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,T"FUS
M9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(").Y'ETY"!T:65T;VMA;FYA
M="(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T
M($AE;'`@5&]P:6-S(@IM<V=S='(@(D[D>73D(&]H:F5I9&5N(&%I:&5E="(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@5&%B;&5S
M(@IM<V=S='(@(D[D>73D('1A=6QU="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T
M<B`B3&ES=&%N+4%R:VES=&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1A
M;BU/:&IE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES=&%N+4ED(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M
M3W=N97(B"FUS9W-T<B`B3&ES=&%N+4]M:7-T86IA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*
M;7-G<W1R("),:7-T82UV:65S=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T
M<B`B3&ES=&%N+51I;&%U<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@
M(DQI<W1A;BU4:6QA=6MS96XM;&]P971T86UI;F5N(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S
M<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("))<W1U;G1O:F5N(&QI<W1A=7,@
M97#D;VYN:7-T=6DZ("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*
M;7-G<W1R(")+Y'ET=.1J:65N(&QI<W1A=7,@97#D;VYN:7-T=6DZ("5S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")+Y'ET=.1JY'1I
M971O:F5N(&[D>71TY&UI;F5N(&]N(&5S=&5T='DN(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DMI
M<FIA;&QI<W5U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-`IM<V=I9"`B3&ET:'5A;FEA(@IM
M<V=S='(@(DQI971T=6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(DQA
M9&%T86%N+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(E!A:6MA;&QI<W1A(&%I
M:V%A.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO
M8V%L92!A;F0@5&EM92(*;7-G<W1R("),;VMA;&ES86%T:6\@:F$@86EK82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-S(*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PIM<V=I9"`B3&]C871I
M;VXB"FUS9W-T<B`B4&%I:VMA(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S
M='(@(DMI<FIA=61U('-I<^3D;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO
M;B(*;7-G<W1R(")%9&5L;&ES96X@<WEN:W)O;F]I;G1I<V5S<VEO;B!L;VMI
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B
M3&]G(&]U="(*;7-G<W1R(")+:7)J875D=2!U;&]S(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R(")+:7)J875D
M=2!S:7/DY&XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED
M("),;V=I;B!487-K<R(*;7-G<W1R(")496ATY';D="!S:7/DY&YK:7)J875T
M=6UI<V5S<V$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G
M:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(E-I
M<^3D;FMI<FIA=71U;6ES97-I(&5PY&]N;FES='5I+B!4;V1E;F[D:_9I<V5S
M=&D@:VER:F]I=&ET(';DY')I;B`B"B)KY'ET=.1JY'1U;FYU:W-E<VD@=&%I
M('-A;&%S86YA<VDN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DQ
M"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(E-I<^3D;FMI<FIA=71U
M;6EN96X@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(E!I=&OD('1E:W-T
M:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*
M;7-G<W1R(")286MK875S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R(")-871A;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(E!I
M96YE="!K<F5I:VMA;&%I<V5T(&MI<FIA:6UE="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B4&EE;F5T(&QA=&EN86QA
M:7-E="!K:7)J86EM970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N
M=6UB97)S(@IM<V=S='(@(E!I96YE="!R;V]M86QA:7-E="!N=6UE<F]T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30U"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M
M8G5R9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0S.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T
M<B`B2TLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED
M(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&(&QI:71E=&EE
M9&]S=&\@;VQI('1Y:&KD+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU3
M1R(*;7-G<W1R(")624535$DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<*;7-G:60@(DUA8V%O
M(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S"FUS9VED(")-86-E9&]N
M:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M36%K961O;FEA+"!%;G1I;F5N($IU9V]S;&%V:6%N('1A<V%V86QL86XN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34Q"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G
M87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA
M9VEC(@IM<V=S='(@(E1A:6MU=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T<B`B4^1H:_9P;W-T:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G:60@(DUA:6P@061M
M:6XB"FUS9W-T<B`B4&]S=&EN('EL;.1P:71O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-
M86ME(&QI;E]K+BXN(@IM<V=S='(@(E1E92!L:6YK7VMI+BXN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38U"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38W"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QE<VEA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38T"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QE9&EI=FET
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34T"FUS9VED(")-86QI(@IM<V=S='(@(E!O<W1I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38R"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@HB5F]I="!H86QL:6YN;VED82!L:7-T86$@
M:V%T96=O<FEO:7-T82P@:F]I9&5N(&%V=6QL82!V;VET(&QI:71TY.0@87-I
M;VET82`B"B)Y:'1E96X@<V%M;VIE;B!O='-A:VME:61E;B!A;&QE(&IA(&QI
M:71TY.0@;FEI:&EN(';D<F5JY"XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S
M='(@(DUA<#(T(&MA<G1T82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T
M<B`B36%P475E<W0@:V%R='1A(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(E9A
M<W1A879U=61E="!T86QL971E='1U+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")M
M86%L:7-K=74B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B36%R9VEN
M86%L:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C0X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y
M"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B
M5F]I(&UE<FMI=.0@5F%N:&$O575S:2!T:65T;VIA(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DUA<FL@=VET:"!O
M=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@
M(E9O:2!M97)K:73D('9I97-T96KD("AE<VEM+B!4Y')K9>0O5F%S=&%T='4I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34R"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S
M='(@(DUA<G-H86QL('-A87)E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.0IM<V=I9"`B36%R
M=&EN:7%U92(*;7-G<W1R(")-87)T:6YI<75E(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G
M<W1R(")4Y'-MY.1VY'0@:V5N=.1T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P"FUS9VED(")-
M875R:71A;FEA(@IM<V=S='(@(DUA=7)I=&%N:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,*
M;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:71I=7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G
M:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B4W5U<FEN('-A;&QI
M='1Y(&MR961I:71T:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+B(*;7-G<W1R(")3=75R:6X@<V%L;&ET='4@=FEE<W1I;W-I
M;VWDY'+D('EL:71E='1Y+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S
M"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B161E
M;&QI<V5N(#(T('1U;FYI;B!K;W)K96EN(&SD;7#V=&EL83H@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(D5D96QL:7-E;B`V('1U;FYI;B!K;W)K96EN(&SD
M;7#V=&EL83H@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@
M3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B4&]R=&%A;&EO<VEO
M:61E;B!E;FEM;>1I<VWDY'+D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3`R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B
M"FUS9W-T<B`B4W5U<FEN('-A;&QI='1U('!I='5U<R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS
M9W-T<B`B=&]U:V]K=74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S"FUS9VED(")-87EO='1E
M(@IM<V=S='(@(DUA>6]N971T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B3.3D:V5T:65D92(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE
M;6)E<G,B"FUS9W-T<B`B2N1S96YE="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N=6X@;75O
M=&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B66AD:7-T
MY"!S;VQU="(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(E9I97-T
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS
M9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@HB5FEE<W1I;B!T87)K:7-T=7,@;VYN:7-T=6DL(&UU
M='1A(&%L;&5K:7)J;VET=&%J86X@=F%R;65N;F5T=&$@96D@=F]I='4@(@HB
M=&%R:VES=&%A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G
M<W1R(")6:65S=&D@=F%N:&5N:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"FUS9VED(")-
M97-S86=E('1Y<&4B"FUS9W-T<B`B5FEE<W1I;B!T>7EP<&DB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T
M<B`B365T87(@<^3D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I
M9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T87(M
M;W-I;R!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@HB365T87(M;W-I;R!E:2!O;&4@:^1Y=&5T=.1V
M:7-SY"X@5&%R:V5M;6%T('1I961O="!O;B!T86QL971E='1U('EL;.1P:61O
M;B`B"B)KY'-I=&5L=.1VY&MS:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N
M(@IM<V=S='(@(DUE=&%R1$(@96D@;VQE('EH9&ES=&5T='DN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS
M9W-T<B`B365T;V1I(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z
M,3$W(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R(")-971O9&EA(%PB)7-<(B!E:2!O;&4@;>3D<FET96QT>2(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS
M9W-T<B`B365T;V1I82!E:2!O;&4@;>3D<FET96QT>2X@2W5T<W5V82!M971O
M9&DZ("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C<*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-
M971R:6YE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-@IM<V=I9"`B365X:6-O(@IM<V=S='(@
M(DUE:W-I:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-0IM<V=I9"`B36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;VYE<VEA+"!9:&1I<W1Y
M;F5E="!V86QT:6]T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0R"FUS9VED(")-:61D;&4B"FUS9W-T<B`B2V5S
M:V5L;.0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;64M='EY<'!I(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")%9&5L;&ES96X@,C0@='5N;FEN(&UA
M=&%L:6X@;.1M</9T:6QA.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M.0IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B161E
M;&QI<V5N(#8@='5N;FEN(&UA=&%L:6X@;.1M</9T:6QA.B`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")386QA
M<V%N82!E:2!O;&4@=FEE;.0@=&%R<&5E:W-I('9A;FAA(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER
M<F]R(@IM<V=S='(@(E!E:6QI:W5V82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")396MA;&%I
M<V5T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E
M<75E<W0N(@IM<V=S='(@(E!%05(M<&%K971T:2!(5%107U)E<75E<W0@<'5U
M='1U=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B
M"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B(@HB4'5U='1U=F%T(&%S971U<W1I961O<W1O+B!3:6YU
M;B!P:73DY"!T96ADY"!A<V5T=7-T:65D;W-T;R!J;W,@:&%L=6%T("(*(FOD
M>71TY.0@=.1TY"!O:&IE;&UA82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S
M<V%G92!)1"XB"FUS9W-T<B`B4'5U='1U=F$@;65S<V%G92!)1"XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU
M.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB
M"FUS9W-T<B`B5N1L='3D;>1T]FX@4$5!4BUP86ME='1I($UA:6P@<'5U='1U
M=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B
M4'5U='1U=F$@<V5S<VEO;B!)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")M82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE
M($UA:6PB"FUS9W-T<B`B36]B:6EL:7/D:&OV<&]S=&DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B36]D97)A
M=&4B"FUS9W-T<B`B2V]H=&%L86EN96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,PIM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")-=6]K
M:V%U:W-E;B!PY&EVY&WDY'+D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),
M(@IM<V=S='(@(DUU;VMK86$@55),.FEA(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B
M2V5R<F]I;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B36]L9&]V82P@=&%S879A;'1A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30Y"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86-O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34V"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQI82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#@*;7-G:60@(DUO;G1H(&%N9"!Y
M96%R(@IM<V=S='(@(FMU=6MA=7-I(&IA('9U;W-I(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL
M>2(*;7-G<W1R(")+=75K875S:71T86EN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q"FUS9VED
M(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO
M;VX@4&AA<V5S(@IM<V=S='(@(DMU=6X@=F%I:&5E="(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B
M4FEV:6QTY"`E9"!L]GET>6D@96YE;6WD;B!K96YT=&GD(&MU:6X@;V1O=&5T
M='4@)60N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30X"FUS9VED(")-;W)O8V-O(@IM<V=S='(@
M(DUA<F]K:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(D5N:6UMY&MS
M:2!S96QK9>3D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B16YI;6WD
M:W-I('!I;'9I<W3D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM
M<V=S='(@(D5N:6UMY&MS965N('!I;'9I<W3D(&IA('1U=6QI<W1A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@
M(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")%;FEM;>1K<V5E;B!A=7)I;FMO:7-T
M82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B4VEI<G+D(&%L87-P
MY&EN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")3:6ER<N0@=F%S
M96UM86QL92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(E-I:7)R
MY"!O:6ME86QL92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E-I:7)R
MY"!Y;/9S<.1I;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")3:6ER<N0@
M86QA<W#D:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B4VEI<G+D('EL]G-P
MY&EN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38X"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@
M(DUO<V%M8FEK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`IM
M<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(DUO
M;FET87-O:6YE;B!A;&%S=F5T;W9A;&EK:V\B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.`IM<V=I9"`B375L=&EM87`@
M54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P($ES;RU"<FET86YN:6%N(&MA<G1T
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8*;7-G:60@(DUU
M;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")-;VYI=F%L:6YT82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`B2^1Y='3D:N1T=6YN=6MS96YI(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(D]M86X@:^1Y='3D:N1T=6YN=6MS96X@=&EE9&]T(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HT-0IM<V=I9"`B37D@4&]R=&%L(@IM
M<V=S='(@(D]M82!P;W)T86%L:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")/;6%N
M('!O<G1A86QI;B!A<V5T=&5L=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-0IM<V=I9"`B37EA
M;FUA<B(*;7-G<W1R(")->6%N;6%R("A"=7)M82DB"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@
M1&\@3D]4($%G<F5E(@IM<V=S='(@(D5)+"!%3B!S=6]S='4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B3F%M92(*;7-G<W1R(").
M:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38Y"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA
M;6EB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S@*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA
M=7)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<W"FUS9VED(").97!A;"(*;7-G<W1R(").97!A
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-0IM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B
M06QA;FMO;6%A="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S"FUS9VED(").971H97)L86YD<R!!
M;G1I;&QE<R(*;7-G<W1R(")!;&%N:V]M86ED96X@06YT:6QL:70B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T
M<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0F%S92!54DPB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B
M3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*
M;7-G<W1R(").971S8V%P92!#02!P;VQI8WD@55),(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E
M;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E(%)E;F5W86P@55),(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE
M='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(%)E=F]C
M871I;VX@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R
M(").971S8V%P92!34TPM<&%L=F5L:6UE;B!O<V]I=&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S8V%P92!V87)M96YT
M965N(&MO;6UE;G1T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM
M<V=S='(@(DYE='-C87!E('9A<FUE;G1E96X@='EY<'!I(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R
M(")697)K:V\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R(")%:2!K;W-K86%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<P"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@
M(E5U<VDM2V%L961O;FEA(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G
M<W1R(")5=7-I(&QU;VMI='5S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V
M(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T
M"FUS9VED(").97<@36]O;B(*;7-G<W1R(")5=7-I:W5U(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N
M86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B575S:2!KY'ET=.1JY'1U;FYU<R`H
M=F%P86%E:'1O:6YE;BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`*;7-G:60@(DYE=R!:96%L
M86YD(@IM<V=S='(@(E5U<VDM4V5E;&%N=&DB"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R
M(")5=7-I('-A;&%S86YA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(E5U<VD@<V%L87-A;F$@=F%N:&5N
M964@)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS
M9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(")!;G1A
M;6%S:2!U=61E="!S86QA<V%N870@96EVY'0@=.1S;>3D+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE
M=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B575S:2!I:VMU;F$@*%]B;&%N
M:RDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM
M<V=I9"`B3F5W<R(*;7-G<W1R(")5=71I<V5T(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")+
M97-K=7-T96QU<GEH;>1T(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,34*;7-G:60@(DYE>'0B"FUS9W-T<B`B4V5U<F%A=F$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS
M9W-T<B`B4V5U<F%A=F%T(#0@=F%I:&5T=&$B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E-E=7)A879A
M="!A<V5T=6MS970B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P
M,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4V5U<F%A=F$^(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<T"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87)A9W5A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<Q"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,PIM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B3FEG:'0B
M"FUS9W-T<B`B6?8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD*;7-G:60@(DYI=64B"FUS9W-T
M<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(D5I(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*
M;7-G<W1R(")!<V5T=7-T:65T;VIA(&5I(&]L92!S86%T879I;&QA+"!J;W-T
M82!V;VES:2!NY'ET=.3D(&5R;V%V86ES=75K<VEA+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A
M=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G
M<W1R(")%:2!O;&4@<V%A=&%V:6QL82!S=75N;FET96QM86$@25-/(&QE=GEK
M=79A=&EE9&]S=&]J96X@=&5K96UI<V5K<VDN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`B16D@97+D;6%L;&EA+B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-#`W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P
M;W-I=&EO;B(*;7-G<W1R(")/<VEO=&$@96D@;VQE('!Y>61E='ES<^0@<&%I
M:V%S<V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM
M<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B2V%L96YT97)I;B!N:6UEY"!E:2!O;&4@
M86YN971T=2!-0T%,+6%U=&5N=&EK;VEN;FEL;&4N(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B16D@
M;75U=&]S=&$N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN(@IM<V=S='(@(D%L:71A<V]J82!E:2!V;VD@;&ESY'3D('3D
M;&QE(&]I:V5U9&5L;&4N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z
M-S8X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38Y"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3`X"B,L('!H<"UF;W)M870*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB
M"FUS9W-T<B`B07-E='5K<VEA(&5I(&SV>71Y;GET("5S.FQL92XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM
M<V=S='(@(D%S971U:W-I82!E:2!L]GET>6YY="!&5%`@5D93.FQL92XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W,@IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M(@IM<V=S='(@(D%S971U:W-I82!E:2!L]GET>6YY="!344P@5D93.FQL92XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+B(*;7-G<W1R(")!<V5T=6MS:6$@96D@;/9Y='EN>70@
M4U%,+49I;&4@5D93.FQL92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T
M+B(*;7-G<W1R(")+<F5D:6ET:70@;&]P<'4N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E
M<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(")+;VAD971T82!E:2!A;FYE
M='1U+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR,`IM
M<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(")%:2!T=6]T=2!A:6YU
M='1A:V%A;B!T:65D;W-T;V$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(")):V]N96ET82!E
M:2!L]GET>6YY="XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,"!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q-@IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R
M(")086EK:V%A(&5I(&]L92!A<V5T971T=2XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B4&%I:VMA82!E:2!O;&4@86YN971T=2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I
M9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B16D@86YN971T=2!V
M:65S=&GD+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T
M<B`B3FEM9>0@96D@;VQL=70@86YN971T=2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M
M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3'5K=6WDY'+DY"!E:2!O;&QU="!A
M;FYE='1U+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B
M3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(D5I(&QO=6MK86%V870@
M;6EE=&5L875S965T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(E-A;&%S86YA82!E:2!O;&4@86YN971T
M=2!(5%10+6%U=&5N=&EK;VEN;FES<V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA<V%N86$@
M96D@;VQE(&%N;F5T='4@24U!4"UA=71E;G1I:V]I;FYI<W-A+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($ME<F)E<F]S+6%U=&5N
M=&EK;VEN;FES<V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP
M:'`Z.#0@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($QO9VEN(&%U=&5N=&EK;VEN;FES
M<V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B4V%L87-A;F%A(&5I(&]L92!A;FYE='1U(%!!
M4U-71"UA=71E;G1I:V]I;FYI<W-A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4V%L87-A;F%A(&5I(&]L
M92!A;FYE='1U(%--0BUA=71E;G1I:V]I;FYI<W-A+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82XB"FUS9W-T<B`B(@HB4&]L:W5A($]P96Y34TP@:V]M96YT;V]N(&5I
M(&]L92!MY.1R:71E;'1Y+B!/<&5N4U-,('!I=.3D(&]L;&$@:^1Y=&5T=.1V
M:7-SY"`B"B)J;W,@:^1S:71E;&SDY&X@4$M#4R`Q,B!D871A82XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P
M96YD:6YG('-I9VYU<',N(@IM<V=S='(@(D5I('-I<^3D;FMI<FIA=71U;6ES
M<'EY;G3V:N0@:F]N;W-S82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-S8V"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(DMI:6YT:?9TY"!E
M:2!O;&4@87-E=&5T='4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R
M(")%:2!SY.1N=/9JY"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B
M17)O=&EN=&$@96D@;VQE(&WDY')I=&5L='DN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@
M<VED97,B"FUS9W-T<B`B16D@<F5U;F]J82(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B
M16D@;/9Y='EN>70@=&EE9&]S=&]A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")6Y&QI;75I<W1I;&QE(&5I
M(&]L92!VY&QI86EK86ES:&%K96UI<W1O82XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DOD>71TY&KD='5N
M;G5S=&$@=&%I('-A;&%S86YA82!E:2!LY&AE=&5T='DN(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D(@IM<V=S='(@(DMA:6MK:2!P86QA=71U;G5T(%A-
M3"UD871A(&]L:2!E<.1K96QP;V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@
M(D5I(&%R=F]J82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G
M:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)697)S
M:6]T:65T;VIA(&5I(&SV>71Y;GET(&%L:W5P97+D:7-I=.0@87-E='5K<VES
M=&$N(%-I;G5N('!I=.3D('1E:&3D("(*(F%S971U:W-E="!U=61E<W1A86XN
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB5F5R<VEO=&EE=&]J82!E:2!L
M]GET>6YY="!A<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5K
M<V5T('5U9&5S=&%A;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C<@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0U"FUS9VED(").;VYE(@IM<V=S='(@(D5I(&UI=.3D;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@
M(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B16D@;6ETY.1N("A+Y'ET
MY"!I;7!L:7-I:71T:7-TY"DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3&%P<&DO
M4&]H:F]I<VUA870O17-K:6UO("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S(*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&L@<V%A
M<F5T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")0
M;VAJ;VEN96X@<&%L;&]N<'5O;&ES:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@*;7-G:60@
M(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R(")0;VAJ;VES970@
M36%R:6%A;FEE;B!S86%R970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8*;7-G:60@(DYO<G=A
M>2(*;7-G<W1R(").;W)J82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B16D@:N1L
M:V5E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P
M"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(D5I(&5N;F5N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E
M8W1O<GDB"FUS9W-T<B`B16D@;VQE(&AA:V5M:7-T;R(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.CDU"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@
M(D5I(&]L92!T;W1E=71E='1U+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B
M16D@87-E=&5T='4B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR-CD@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X-0HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`Q(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS,38*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,S,R!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S8V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HT
M,C8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P-0HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-3<T(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.3$*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C8V.2!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B16D@='5E='1U
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M-#0@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#@*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$X,"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U
M.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B375I<W1I:6YP86YO="(*"B,Z('-E
M<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(D5I(&UI=.3D;B!S96QA='1A
M=F%A+"!P86QA82!T86MA:7-I;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B
M;6%R<F%S:W5U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U,`IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(DQU:W5MY.1RY"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T
M97)S(@IM<V=S='(@(DUE<FMK:65N(&QU:W5MY.1RY"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Y('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB
M97(@;V8@8V]L=6UN<R(*;7-G<W1R(")387)A:VME:61E;B!L=6MU;>3D<N0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B4FEV:65N(&QU:W5M
MY.1RY"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")*86ME;'5L
M:7-T86X@;G5M97)O:71A(&5I(&]L92!MY.1R:71E;'1Y('#D:79I=&5T=.1V
MY&MS:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM
M<V=S='(@(D]B:F5K=&DB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B3V)J96MT:6X@
M;'5O:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`X"FUS9VED
M(")/8W1A;"(*;7-G<W1R(")/:W1A86QI(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T
M<B`B;&]K86MU=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B3&]U:VMA879U=7-S=6]D871I
M;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F
M9FEC92(*;7-G<W1R(")4;VEM:7-T;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU
M<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")5=7-I('-A;&%S86YA(&5I('-A
M82!O;&QA('-A;6$@:W5I;B!N>6MY:6YE;B!S86QA<V%N87-I+B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W
M;W)D(@IM<V=S='(@(E9A;FAA('-A;&%S86YA(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T
M(&-O<G)E8W0N(@IM<V=S='(@(E9A;FAA('-A;&%S86YA(&]N(';DY')I;BXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#$*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED
M(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*
M;7-G<W1R(")686EN($E-05`M<&%L=F5L:6UE="!T=6ME=F%T(&IA971T=6IA
M(&MA;G-I;VET82XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E9A:6X@;&]U
M:VMA879A="!M:65T96QA=7-E970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@
M(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B5F]I
M="!L86ET=&%A('9A:6X@>6AD96X@<^1H:_9P;W-T:6]S;VET=&5E;BXB"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@
M=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@
M;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M(@IM<V=S='(@(B(*(E9A:6X@;VUI<W1A:F$@=&%I(&KD<FIE<W1E;&WD;B!Y
M;&SD<&ETY&KD('9O:2!M=75T=&%A(&IA:V]J96X@;VUI<W1A:FEA('1A:2`B
M"B)O:6ME=6MS:6$B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B079A82!U=61E<W-A(&EK:W5N87-S82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,
M(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O
M34E-12!P87)T+B(*;7-G<W1R("(B"B)/<&5N4U-,('9I<FAE.B!4:65T;VIA
M(&5I('-A871U(&5S:6QL92!A;&QE:VER:F]I=&5T=7-T82!3+TU)344M;W-A
M<W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R(")!=F%A('3D;>1N(&QI;FMI;B!U=61E<W-A(&EK
M:W5N87-S82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B
M3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")+Y'ET=/9JY')J97-T96QMY"(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P
M=&EO;G,B"FUS9W-T<B`B07-E='5K<V5T(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D%S971U:W-E="`E
M<SIL;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B2N1R:F5S=&5T
M='D@;&ES=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-A871I
M;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS
M9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(D]R9V%N:7-A871I
M;WEK<VEK:_8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS
M9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7-O:6YT:2(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A
M=&EO;B!T96UP;&%T92(*;7-G<W1R(")!;&MU<&5RY&EN96X@;VAJ96QM86X@
M;6%L;&DB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@
M(D%L:W5P97+D:7-E="!M86QL:70@)7,Z<W/D.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT
M"FUS9VED(")/=&AE<B(*;7-G<W1R(")-=74B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R
M(")-=75T('1I961O="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D]M:7-T86IA
M;B!O:6ME=61E="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW
M.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(E!!32UA=71E;G1I:V]I;G1I82!E:2!O;&4@:^1Y=&5T=.1V
M:7-SY"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")0
M14%2.CI-86EL('1A=7-T86KD<FIE<W1E;&WD(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG
M;F%T=7)E(@IM<V=S='(@(D1I9VET86%L:6YE;B!01U`M86QL96MI<FIO:71U
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(*;7-G
M:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`M<V%L871T=6$@
M=&EE=&]A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W
M-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B2G5L:VEN96X@4$=0
M+6%V86EN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U
M-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")0
M1U`M86QL96MI<FIO:71E='1U82!J82!S86QA='1U82!T:65T;V$B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-CD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@
M(E!(4"UK;V]D:2(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B
M4$A0(%-H96QL(@IM<V=S='(@(E!(4"UK;VUE;G1O='5L:VMI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-
M($QI9VAT(%)A:6XB"FUS9W-T<B`B4$T@:V5V>71TY"!S861E='1A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@
M(E!-(%)A:6XB"FUS9W-T<B`B4$T@<V%D92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3:&]W97)S(@IM
M<V=S='(@(E!-(&MU=7)O:F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")032!L
M=6UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")032!L=6UI<V%T
M96ET82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B4$T@;'5M:2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")032!4
M+5-T;W)M<R(*;7-G<W1R(")032!U:VMO<VUY<G-K>6KD(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<B"FUS9W-T<B`B4$]325@M;&%A:F5N;G5K<V5T('!U=71T=79A
M="(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G
M<W1R(")07TA0+6MO;65N=&]T=6QK:VDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG
M(@IM<V=S='(@(E3D>71E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W"FUS9VED(")086MI<W1A
M;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30*;7-G:60@(E!A
M;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,@IM<V=I9"`B4&%L
M97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I
M:6YA("AM:65H:71E='1Y(&%L=64I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R"FUS9VED(")0
M86YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U"FUS9VED(")0
M87!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A(%5U<VDM1W5I;F5A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-0IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U
M87DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-PIM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")/<VET=&%I;B!P:6QV
M:7-TY"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C(*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E-A;&%S86YA(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4V%L87-A;F%N('9A
M:6AT;R!O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R
M(")6Y.1RY"!S86QA<V%N82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-A;&%S86YA82!T87)V:71A
M86X@4D%$2553+6%U=&5N=&EK;VEN=&EI;BXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#4W"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")386QA<V%N82!V87)M:7-T=6MS96QL82(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z
M(@IM<V=S='(@(E-A;&%S86YA.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E-A;&%S86YA
M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`S.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B4V%L
M87-A;F]J96X@<&ETY.0@;VQL82!S86UA="XB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B3&EI=.0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS
M9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("),:6ETY"!L96EK
M97#V>63D;'3D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")0;VQK=2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I
M9VYU<',Z(@IM<V=S='(@(DIO;F]S<V$@;VQE=F%T('-I<^3D;FMI<FIA=71U
M;6ES<'EY;F[V=#HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G
M:60@(E!E;W!L92(*;7-G<W1R(")):&UI<V5T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B
M"FUS9W-T<B`B4')O<V5N='1I(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")3=6]R:71A('EL;.1P:71O=&]I;65N
M<&ET965T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G
M<W1R(")3=6]R:71A('EL;.1P:71O=&]I;65N<&ET965T('-I<^3D;FMI<FIA
M=71U;6ES96X@>6AT97ED97-SY"XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")/:6ME
M=7,B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G
M<W1R(")/:6ME=71T82!<(B5S7"(@96D@<&]I<W1E='1U+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")097)M:7-S:6]N($1E
M;FEE9"(*;7-G<W1R(")+Y'ET=/8@:VEE;&QE='1Y(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(D]I:V5U
M9&5T(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-3@*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y
M(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,@IM<V=I9"`B4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B3VEK975K<VEE;B!Y;&SD<&ET;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@
M26YF;W)M871I;VXB"FUS9W-T<B`B3VUA="!T:65D;W0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#,*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("),96UM:6MI="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-@IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL
M:7!P:6EN:70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")0=6AE;&EN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM
M<V=S='(@(E9A;&]K=79A="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`*;7-G:60@(E!I=&-A
M:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R
M(")0:6MS96QI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED
M(")0;&%T:71U9&5S(@IM<V=S='(@(DML:7-E970B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0
M;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B3F%P<V%U=&$@
M:F]T86EN('-O;'5A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@
M(E9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T86$@=.1MY&X@96QE;65N=&EN
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")687)M:7-T82!E
M='3D(&AA;'5A="!P;VES=&%A(&QI;FMI='EK<V5N('3D:.1N(&5L96UE;G1T
M:6EN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-C8*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(D%N
M;F$@:W5U:V%U<VD@:F$@=G5O<VDN(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(D%N;F$@;FEM
M:2!U=61E;&QE(&QU;VMI='5K<V5L;&4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RXB"FUS9W-T<B`B06YN82!O:6ME82!)4"UO<V]I=&4N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T-`IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN
M('1H92!M;VYT:"XB"FUS9W-T<B`B06YN82!O:6ME82!PY&EVY&WDY'+D.R!4
M87)K:7-T82!PY&EV:65N(&QU:W5MY.1RY"!K=75K875D97-S82XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")!;FYA(&%I:V$@;VEK96%S<V$@
M;75O9&]S<V$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+B(*;7-G<W1R(")!;FYA(&QY:'ET(&MU=F%U<R!O;F=E;&UA<W1A+B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B06YN82!KY'ET=.1JY'1U
M;FYU:W-E<VD@:F$@<V%L87-A;F%S:2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN
M9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@
M=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3'5E('-E=7)A879A('1E:W-T
M:2X@4VEN=6X@4$E4Q,0@<W5O<W1U82!KY'ET=/9E:'1O:6AI;B!V;VED86MS
M97-I(&OD>71TY.0@(@HB:N1R:F5S=&5L;>3D+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A
M<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(D%N;F$@
M;FEM:2!U=61E;&QE(&QU;VMI='5K<V5L;&4Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X"FUS
M9VED(")0;VQA;F0B"FUS9W-T<B`B4'5O;&$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;&ET:6EK
M:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0
M;VQL<R(*;7-G<W1R(")+>7-E;'ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,PIM<V=I9"`B
M4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86QI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E3D;>1N(&MU
M=F%N('!A:6MK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M(@IM<V=S='(@(E3D;>1N('1A=6QU:V]N('!A:6MK82(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B5F]I
M(&SD:&5T=.3D('9I97-T96KD(&MA;G-I;V]N("AE:2!K;W-K92!)34%0('EH
M=&5Y:W-IY"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")3861E;>3D
M<N0@961E;&QI<VEL;&4@)7,@='5N;FEL;&4Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B2&%I:'1U=G5U<R`\8G(@+SYT;V1E;F[D:_9I
M<WEY<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM
M<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!487)V:71T879A82!,1$%0
M+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<F5F<U]S97-S:6]N.B!487)V:71T879A82!S97-S:6]N+6QA86IE;FYU
M<W1A(&5I(&SV>71Y;GET(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*
M;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(DEL;6%N<&%I;F4B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE
M=F5L.B`B"FUS9W-T<B`B26QM86YP86EN92!M97)E;G!I;FYA<W-A.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S
M<W5R93H@(@IM<V=S='(@(DEL;6%N<&%I;F4Z("(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED
M(")0<F5V:65W(@IM<V=S='(@(D5S:6MA='-E;'4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G
M:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(")%<VEK871S96QE(&MU=F$@=75D97-S82!I:VMU;F%S<V$B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G
M<W1R(")%9&5L;&ES970@87-E='5K<V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE
M;G0B"FUS9W-T<B`B5'5L;W-T82!D;VMU;65N='1I(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*
M;7-G<W1R(")386QA:6YE;B!A=F%I;B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B3VYG
M96QM82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O
M8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")/;F=E;&UA;B!K=79A=7,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T
M<R(*;7-G<W1R(")0<F]J96MT:70B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.3(*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,`IM<V=I9"`B4')O;7!T('1E>'0B
M"FUS9W-T<B`B2V5H;W1T965N('1E:W-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R
M(")*=6QK:6YE;B!A=F%I;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G
M<W1R(")*=6QK:7-E;B!A=F%I;65N(&%L9V]R:71M:2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y
M($EN9F\B"FUS9W-T<B`B2G5L:VES96X@879A:6UE;B!T:65D;W0B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI
M8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(DIU;&MI<V5N+W-A;&%I<V5N(&%V86EN<&%R:6X@;'5O;G1I
M(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$*;7-G:60@(E!U97)T;R!2
M:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S
M(@IM<V=S='(@(E9O:2!T=6AO=&$@<&]I<W1E='1U:F$@=FEE<W1E:N0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DV"FUS9VED(")1871A<B(*;7-G<W1R(")1871A<B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV-`IM<V=I9"`B475E<GDB"FUS9W-T<B`B
M2WES96QE(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1
M=6]T82(*;7-G<W1R(")+:6EN=&GV(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!($IU;&MI;F5N(&%V86EN
M("@E9"!B:71T:>0I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V
M.`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E)A9&EO<&%I;FEK
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U
M"FUS9VED(")286EN(@IM<V=S='(@(E-A9&4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!%87)L>2(*
M;7-G<W1R(")3861E='1A(&%I:V%I<VEN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G
M<W1R(")3861E='1A(&UY]FCDY&XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T
M<B`B4V%D96MU=7)O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B5F5S
M:2!J82!L=6UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")6961E<W3D
M(&QU;65E;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")2
M86YD;VT@1F]R='5N92(*;7-G<W1R(")3871U;FYA:6YE;B!M:65T96QA=7-E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2
M871I;R(*;7-G<W1R(")3=6AD92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQU:W4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B
M4F5A9"!M97-S86=E<R(*;7-G<W1R(")6;VD@;'5K96$@=FEE<W1E:N0B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B4&]I<W1E=&%A;FMO("5S/R!4
MY'3D('1O:6UI;G1O82!E:2!V;VD@<&5R=75T=&%A+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")0;VES=&5T86%N
M:V\@=&EE9&]T(&OD>71TY&KD<W3D("5S/R!4Y'3D('1O:6UI;G1O82!E:2!V
M;VD@<&5R=75T=&%A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(E1E92!M=75T;VMS970@=75D97-T86%N(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*
M;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B4.1I=FETY"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.B(*;7-G<W1R(")0Y&EVY'0@9'EN86%M:7-E="!V86QI:VMO
M96QE;65N=&ET.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G
M:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E#D:79I=.0@<&]R
M=&%A;&ENY&MY;>3D.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E9V5X(@IM<V=S='(@(E/DY&YN
M]FQL:6YE;B!L875S96ME(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(S-0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B4F5L
M86%T:6]S96QA:6XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO
M860B"FUS9W-T<B`B3&%T86$@=75D96QL965N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B375I<W1I:6YP
M86YO="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E
M;6]T92!397)V97)S(@IM<V=S='(@(D5TY'!A;'9E;&EM970B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")%=.1P
M86QV96QU;B!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,@IM<V=I9"`B4F5M;W9E(@IM
M<V=S='(@(E!O:7-T82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E!O:7-T82!O<VEO
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")0;VES=&$@<V%R86ME
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B4&]I<W1A(&UU
M;W1O:6QU(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G
M:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E!O:7-T82!P87)I(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(E!O:7-T82!T86QL971E='1U('-K<FEP=&D@<&%L=F5L:6UE;B!VY&QI
M86EK86ES:&%K96UI<W1O<W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H
M92(*;7-G<W1R(")0;VES=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B4&]I<W1A('3D;>0@
M;F]O9&D@9&]K=6UE;G1I<W1A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B4&]I
M<W1A(&OD>71TY&KD(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*
M;7-G<W1R(")0;VES=&$@:^1Y='3D:N0Z("5S(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@
M8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(E!Y
M>6YT]O9N(&5I('9O:71U('9A<W1A=&$N(%9I<FAE:V]O9&DZ("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B4'EY9&5T
M='GD('!A;'9E;'5A(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3<V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$X
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1A<G9I='1A
M=F%A(%PB)7-<(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2`E<R!A<V5T
M=6MS:7-S82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C<X"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")487)V:71T879A82!<(B5S7"(M=&EE=&]A(&5I(&]L
M;'5T(&WDY')I=&5L='D@5D93(&%S971U:W-I<W-A+B(*"B,Z(&9R86UE=V]R
M:R]5=&EL+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")487)V:71T879A82!<(B5S7"(M=&EE=&]A(&5I(&]L;'5T(&WD
MY')I=&5L='D@87-E='5K<VES<V$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G
M<W1R(")086MO;&QI;F5N(&ME;G1TY"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S0S(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*
M;7-G:60@(E)E<V5T(@IM<V=S='(@(E1Y:&IE;F[D(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM
M<V=S='(@(E1Y:&IE;F[D('-A;&%S86YA(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS
M9W-T<B`B5'EH:F5N;N0@<V%L87-A;F%S:2(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S$*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")0
M86QA=71A(&5D96QL:6YE;B!K>7-E;'DB"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z,CD@861M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV-PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")4=6QO:W-E="(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
M4&%L86$@87-E='5K<VEI;B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")6
M86AV:7-T82!U=7-I('-A;&%S86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-PIM<V=I9"`B
M4F5U;FEO;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2
M979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")086QA=71A(&%S971U:W-E
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")2:6-H(%1E>'0@161I=&]R
M:6X@87-E='5K<V5T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS
M9VED(")2:61D;&5S(@IM<V=S='(@(D%R=F]I='5K<V5T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"FUS9VED
M(")2:6=H="(*;7-G<W1R(")/:6ME82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,#<*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")/:6ME
M82!O='-A:V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`S"FUS
M9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B3VEK96$@87)V;W0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")2:79I7VX@
M=&EE9&]T+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;V]L:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3@*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4F]M86YI82(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C8*;7-G
M:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B2^3D;F[D(#$X,"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O
M=&%T92!,969T(@IM<V=S='(@(DODY&YNY"!V87-T87#D:7;DY&XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED
M(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B2^3D;F[D(&UY]G3D<.1I=N3D;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E)I=FEN('1I
M961O="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E)I
M=FEN('1I961O="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")2:79I=#HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")6:6EV;VET:6XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C
M;VQU;6YS(@IM<V=S='(@(E9I:79O:71I;B!NY&MY>2!K86EK:VEE;B!R:79I
M96X@:F$@<V%R86MK96ED96X@=N1L:6QLY"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(E9I
M:79O:71I;B!NY&MY>2!V86EN('-A<F%K:V5I9&5N(';D;&EL;.0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*
M;7-G<W1R(")6:6EV;VET:6X@;N1K>7D@=F%I;B!R:79I96X@=N1L:6QLY"(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R
M(")3=6]R:71A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.0IM<V=I9"`B4G5S<VEA;B!&961E
M<F%T:6]N(@IM<V=S='(@(E9E;N1JY&X@1F5D97)A=&EI=FEN96X@=&%S879A
M;'1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,`IM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U
M86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U
M"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T
M<B`B4R]-24U%(&MR>7!T;V=R86%F:6YE;B!A;&QE:VER:F]I='5S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O
M34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")3+TU)344@<V%L871T
M=2!V:65S=&DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q
M"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(E-!4TPM875T96YT:6MO:6YT:2!E:2!O;&4@:^1Y=&5T=.1V
M:7-SY"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED
M(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R!496MS=&EV:65S=&ET(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS
M9W-T<B`B4U%,+6MO;65N=&]T=6QK:VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C<X"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L
M;V]K=7!S(@IM<V=S='(@(E-13"UL875S92!A<G9O:F5N(&AA:V5M:7-E96XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B
M"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T53
M4R(*;7-G<W1R(")/3DY)4U1522(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I
M9"`B4U]13"!3:&5L;"(*;7-G<W1R(")37U%,+6MO;65N=&]T=6QK:VDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS
M9VED(")382(*;7-G<W1R(")L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<*;7-G:60@(E-A
M:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S$*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN
M="!+:71T<R!J82!.979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.0IM<V=I9"`B4V%I;G0@
M3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y"FUS
M9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT
M(%!I97)R92!J82!-:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0*;7-G:60@(E-A
M:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT
M(%9I;F-E;G0@:F$@1W)E;F%D:6EN:70B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?
M<V5L9BDB"FUS9W-T<B`B4V%M86%N(&ME:'EK<V5E;B`H7W-E;&8I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$R"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I
M;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$V"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I
M<&4B"FUS9W-T<B`B4V%O(%1O;64@:F$@4')I;F-I<&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O
M=FED97(B"FUS9W-T<B`B4V%T96QL:6ET=&D@<&%L=F5L=6YT87)J;V%J82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#$*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")3
M875D:6$@07)A8FEA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDY"FUS9VED(")3879E(@IM<V=S='(@(E1A;&QE=&$B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E1A;&QE=&$@7"(E<UPB(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92`E<R(*;7-G<W1R(")486QL971A("5S(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(E1A;&QE=&$@87-E='5K<V5T(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@
M(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)486QL971A(&QU;V1U="!A<V5T
M=6MS970@4$A0+7-K<FEP=&ENY"!P86QV96QI;65S:2!VY&QI86EK86ES:&%K
M96UI<W1O;VXN("(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(E1A;&QE=&5T=&EI;B`E<SIN(&%S971U:W-E="XB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M(")!<V5T=7-T96X@<.1I=FET>7-S:W)I<'1I(&]N('1A;&QE=&5T='4@<&%I
M:VMA86XZ(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S
M='(@(DAA:F%N86ES:6$@=6MK;W-M>7)S:WEJY"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")4:65D92(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T
M<B`B2&%K=2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G
M:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(DAA:W5K;VYE970B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.34Y"FUS9VED(")396QE8W0@1FEL
M97,B"FUS9W-T<B`B5F%L:71S92!T:65D;W-T;W0B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@
M82!D871E(@IM<V=S='(@(E9A;&ET<V4@<.1I=N1MY.1RY"(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U
M<"!T;R!A9&0B"FUS9W-T<B`B5F%L:71S92!L:7/D='3D=N0@<GEH;>0B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@
M82!N97<@;W=N97(B"FUS9W-T<B`B5F%L:71S92!U=7-I(&]M:7-T86IA(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE
M8W0@82!S97)V97(B"FUS9W-T<B`B5F%L:71S92!P86QV96QI;B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U
M<V5R('1O(&%D9"(*;7-G<W1R(")686QI='-E(&QI<^1T=.1VY"!KY'ET=.1J
MY"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5F%L:71S92!K86EK:VDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0W"FUS9VED(")396QE
M8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B5F%L:71S92!K86EK
M:VD@<.1I=N1MY.1RY&MO;7!O;F5N=&ET(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B
M:F5C="(*;7-G<W1R(")686QI='-E(&]B:F5K=&DB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@
M;F]N92(*;7-G<W1R(")4>6AJ96YNY"!V86QI;G1A(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB
M"FUS9W-T<B`B(@HB5F%L:71S92!T87)V:71T879A="!M97)K:70@86QL82!O
M;&5V:7-T82!V86QI:V]I<W1A+B!6;VET('-E;B!JY&QK965N("(*(FMO<&EO
M:61A(&IA(&QI:71TY.0@;65R:VET('1E:W-T:6ES:2XB"@HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CHB"FUS9W-T<B`B5F%L:71S92!PY&EVY'EK<V5N(&5R;W1I;FUE
M<FMK:3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5F%L:71S92!PY&EV
MY'EK<V5N(&5S:71Y<W1A<&$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT
M:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E9A;&ET<V4@;75U=&5T=&%V
M82!P<F]F:6EL:3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5F%L
M:71S92!K96QL;VYA:F%N(&5R;W1I;FUE<FMK:3HB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA
M=#HB"FUS9W-T<B`B5F%L:71S92!A:F%N(&5S:71Y<W1A<&$Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E9A;&ET<V4@:V%K<VD@>6AT965N
M<V]P:79A82!K96YT=.3D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B
M5F%L:71S92!VY')I=&5E;6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*
M;7-G<W1R(")686QI='-E(&OD>71E='3D=N0@:VEE;&DZ(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B3.1H973D(&]N9V5L;6%V:65S=&DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I
M9"`B4V5N9"!335,B"FUS9W-T<B`B3.1H973D(%--4R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3,*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")4
M=6YN:7-T:6XZ("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B<WEY<VMU=2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED
M(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEA(&IA($UO
M;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")387)J86YU;65R
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@
M(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(E!A;'9E;&EM96X@=&EE9&]T(&]V870@=N3D<FGD('1A:2!E:7;D="!O;&4@
M:^1Y=&5T=.1V:7-SY"XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G
M:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B27-T=6YT;VIE;B!H86QL:6YT
M82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")3
M97-S:6]N($E$(&]N('9A;FAE;G1U;G5T+B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B27-T=6YN;W0B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$X"FUS9VED(")3970B"FUS9W-T<B`B
M07-E=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E
M="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D
M(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB4V%L87-A;F%N
M(')E<V5T;VEN=&EI;B!L:6ET='EV:>0@87-E='5K<VEA+"!J;W,@:F]S:W5S
M('5N;VAD870@<V%L87-A;F%S:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HB
M5F]I="!A<V5T=&%A('5L:V]I<W1E;B!P86QV96QI;6EE;B!A<V5T=6MS970L
M(&IO:71A(&AA;'5A="!KY'ET=.3D("(*(G!O<G1A86QI<W-A+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G
M<W1R("(B"B)6;VET(&%S971T86$@:^1Y=&5T=.1VY&X@:VEE;&5N+"!A:6MA
M=GGV:'EK:V5E;B!J82!M=6ET82!PY&EVY&WDY'+D87-E='5K<VEA+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R
M("(B"B)6;VET(&%S971T86$@86QO:71U<V]H:F5L;6%N+"!VY')I=&5E;6%N
M+"!NY&MY;>1N('#D:79I='EK<V5N(&IA(&UU:71A("(*(F[D:WEMY.1N(&QI
M:71T>79IY"!A<V5T=6MS:6$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`B07-E;FYU<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(D%S96YN=6MS96X@
M<.1I=FET>7-S:W)I<'1I(&]N('-A871A=FEL;&$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N
M<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")5<V5A
M="!P86EK870@<V]P:79A="!A;FYE='1U=6X@<&%R86UE=')I:6XZ("(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#,*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE
M;&QI="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@
M(E-H;W!P:6YG(@IM<V=S='(@(D]S=&]K<V5T(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS
M9W-T<B`B3'EH>70@:W5V875S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")!<V5T971A('!I:V%V86QI;G1A;N1P
M<.1I;65T('5S96EM;6EL;&4@;&EN:V5I;&QE+B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@
M(D[D>73D(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B
M(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B).Y'ETY"!E<F]A=F%I<W5U9&5T(&%S971U:W-I96X@=&%L;&5T
M971U<W-A(&IA('5U9&5S<V$@:G5U<FD@;75O:V%T=7-S82`B"B)V97)S:6]S
M<V$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(").
MY'ETY"!E9&5L;&ES96X@<VESY.1N:VER:F%U='5M:7-E;B!PY&EVY'ES+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-CD*;7-G:60@(E-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B3N1Y=.0@87-E='5S
M('!I=.3D:W-E<VD@86QK=7!E<N1I<V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C<Y.0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B3N1Y
M=.0@=F%L:71S:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS
M9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@
M(D[D>73D('1A=6QU:VMO=&]I;6EN;F]T('9A;&EK:V\N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(").Y'ETY"!V87-E
M;6UA;&QA("5S('9A;&EK:V\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D[D>73D('1A
M=6QU:V]N('-O;'5N('1I961O="!D:6%L;V=I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Y'ET
MY"!T875L=6MO;B!T:65D;W0@9&EA;&]G:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D[D
M>73D('1A=6QU:V]N(')I=FEN('1I961O="!D:6%L;V=I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M(").Y'ETY"!K=79A;B!T:65D;W0@9&EA;&]G:2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C<*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@
M(D[D>73D('1U;VYT:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM<V=S='(@(E-A=&5I=&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM
M<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")3871E:71A(&%I:V%I<VEN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*
M;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")3871E:71A(&UY]FAE;6UI
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U
M"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")3871E
M:71A(&SD:&5T='EV:6QL82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B
M4&EE;F5N;N0B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I
M9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E!I96YE;F[D('1A:2!S:6ER<N0@
M=FEE<F5I<VGD(&]S:6]I=&$L(&IO='1A(&YE(&5I=N1T(&]L92!T:65L;.0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$Q"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B
M4VEE<G)A($QE;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")+:7)J875D=2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3
M:6=N871U<F4B"FUS9W-T<B`B06QL96MI<FIO:71U<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@
M06QG;W)I=&AM(@IM<V=S='(@(D%L;&5K:7)J;VET=6MS96X@86QG;W)I=&UI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-@IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I
M;F=A<&]R92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDP,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-#$*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3$V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#D*;7-G
M:60@(E-I>F4B"FUS9W-T<B`B2V]K;R(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA
M;F-E(@IM<V=S='(@(D]H:71A('EL;.1P:71O=&5H=.1VY'0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$P"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")3;&]V86MI82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#@*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9E;FEA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*
M;7-G:60@(E-N;W<B"FUS9W-T<B`B3'5M:2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<B(*
M;7-G<W1R("),=6UI<V%D971T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B3'5M:7-A=&5I=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S
M='(@(DQU;6ES871E:71A(&%I:V%I<VEN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R<R!,
M871E(@IM<V=S='(@(DQU;6ES871E:71A(&UY]FCDY&XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@
M(DQU;65N('-Y=GEY<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#D*
M;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(DQU
M;65N(&WDY'+D('9E=&5NY#H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,@IM<V=I9"`B4V]L
M;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-A;&]M;VX@<V%A<F5T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-`IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA;&EA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US
M(@IM<V=S='(@(DQA=6QU="!J82!2=6YO=7,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3$R"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*
M;7-G<W1R(")*Y')J97-T>6MS96X@<W5U;FYA;B!V86QI;G1A(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X
M.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B3.1H9&5O<V]I=&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B
M171E;.0M069R:6MK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS
M9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B171E
M;.0M175R;V]P<&$@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q"FUS9VED
M(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD
M<R(*;7-G<W1R(")%=&5LY"U'96]R9VEA(&IA(&5T96SD:7-E="!386YD=VEC
M:"!S86%R970B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(D5T96SD:6YE;B!P86QL;VYP=6]L:7-K;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(E;D;&D@=FEE<F5I<V5T
M('-O;'5J96X@=N1L:7-SY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(E;D;&D@<V]L=6X@;&5I
M<.1T96MS=&EN(&IA(')E=6YA;B!VY&QI<W/D("(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(E;D;&DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-34*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B5N1L:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G
M:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B5N1L:2!J82!TY'ET
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@P"FUS9VED(")3<&%I;B(*;7-G<W1R(")%<W!A;FIA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A
M;2(*;7-G<W1R(")2;W-K87!O<W1I(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R
M(")%<FEK;VES;65R:VMI96X@<WGV='3V(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@
M8V5L;"(*;7-G<W1R(")*86$@<V]L=2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O
M;'5M;B(*;7-G<W1R(")*86$@<V%R86ME(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(DIA82!R:79I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B57)H96EL=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#$@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8V"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R
M9&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@
M5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DP(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.34*;7-G
M:60@(E-T87)T('EE87(B"FUS9W-T<B`B06QK86UI<W9U;W-I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E
M(&]R(%!R;W9I;F-E(@IM<V=S='(@(DSDY&YI('1A:2!A;'5E(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U
M<R(*;7-G<W1R(")4:6QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@P,0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B5&%L;&5N;G5S
M;75O=&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B2V%T=6]S;VET92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*
M;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B3.1P:6QY]FYT:2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*;7-G:60@(E-T<FEN9R!L
M:7-T(@IM<V=S='(@(DUE<FMK:6IO;F]L:7-T82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H
M92!A9&1R97-S(@IM<V=S='(@(E!O:7-T82!T;VEM:6%L=64@;W-O:71T965S
M=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")4>7EL:2!;
M0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(G-U(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")!;&EH86ME;6ES=&]A(%PB
M)7-<(B!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D]T
M<VEK:V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S8@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B3.1H973D(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB3.1H
M971E='1I:6X@7"(E<UPB.FX@;&ESY'ES<'EY;G3V+B!%="!V;VD@:VER:F%U
M='5A('-I<^3D;B!E;FYE;B!K=6EN("(*(G!Y>6YT]G-I(&]N(&OD<VET96QT
M>2!J82!H>7;D:W-Y='1Y+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")!
M;&EK:7)J;VET=7,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B3VYN:7-T=6DB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S
M='(@(EPB)7-<(CH@;&ESY.1M:6YE;B!JY')J97-T96QMY.1N(&]N;FES='5I
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(DOD>71TY&KD;B!<(B5S7"(@:^1Y
M='3D:N1T:65T;VIE;B!P;VES=&%M:6YE;B!JY')J97-T96QMY'-TY"!O;FYI
M<W1U:2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@<&]I<W1E='1I:6X@
M;VYN:7-T=6YE97-T:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB.B!O;FYI<W1U='1I:6X@
M<&]I<W1A;6%A;B!JY')J97-T96QMY'-TY"XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N
M9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B
M"B)086QA='1I:6X@;VYN:7-T=6YE97-T:2!V86YH;VEH:6X@87-E='5K<VEI
M;BX@3&%T86$@<VEV=2!U=61E<W1A86X@(@HB;N1H9.1K<V5S:2!M=75T;VMS
M970N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C
M:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1A;&QE;FYE='1I:6X@87-E
M='5K<VEE;B!V87)M=75S:V]P:6\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(E1A;&QE;FYE='1I:6X@87-E='5K<VEE;B!V87)M=75S:V]P:6\@)7,N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G.B!PY&EV
M:71Y<R!O;FYI<W1U:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,Z;B!K:7)J;VET
M=&%M:6YE;B!O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T"FUS9VED(")3=61A
M;B(*;7-G<W1R(")3=61A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B66AT965N=F5T;R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM
M<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B075R:6YG;VYN;W5S=2(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R
M(")!=7)I;F=O;FQA<VMU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@(D%U<FEN:V]I
M;F5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I
M9"`B4W5N<FES92(*;7-G<W1R(")!=7)I;F=O;FYO=7-U(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS
M9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")!=7)I;FMO(&YO=7-E92]L
M87-K964B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS
M9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B075R:6YG;VYN;W5S=3H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T
M(@IM<V=S='(@(D%U<FEN9V]N;&%S:W4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")!=7)I
M;F=O;FQA<VMU.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")0Y.1L
M;&5K:7)J;VET=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P
M"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E1U:VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U
M"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B
M"FUS9W-T<B`B4W5K=6YI;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y"FUS9VED(")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(DAU:7!P=79U;W)E="!J82!*
M86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y"FUS9VED(")3=V%Z:6QA;F0B"FUS
M9W-T<B`B4W=A>FEM86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U"FUS9VED(")3=V5D96XB
M"FUS9W-T<B`B4G5O='-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38*;7-G:60@(E-W:71Z97)L
M86YD(@IM<V=S='(@(E-V96ET<VDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3
M>6YC(&QO:VD@<&]I<W1E='1U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(E-Y;F--3"(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")3>6YT86MS:79I<FAE(&AA
M:W5T97)M96ES<^0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X"FUS9VED(")3>7)I86X@07)A
M8B!297!U8FQI8R(*;7-G<W1R(")3>7ER:6$L(&%R86)I=&%S879A;'1A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B56MK;W-M>7)S:WDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R
M;2!A;F0@5VEN9'DB"FUS9W-T<B`B56MK;W-M>7)S:WEJY"!J82!T=75L:7-T
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T
M"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")5:VMO<VUY<G-K>70B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B
M5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B56MK;W-M>7)S:WEJY"!A:6MA:7-I
M;B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@
M(E135B!F:6QE(@IM<V=S='(@(E135BUT:65D;W-T;R(*"B,Z(&9R86UE=V]R
M:R]522]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R(")4
M875L=6MK;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T
M<B`B5&%U;'5K;VX@=&EE9&]T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@
M(E1A=6QU:V]N(&%S971U:W-E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E
M<G1I97,B"FUS9W-T<B`B5&%U;'5K;VX@=&EE9&]T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-`IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW
M86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A:7=A;BP@2VEI;F%N
M(&UA86MU;G1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-0IM<V=I9"`B5&%J:6MI<W1A;B(*
M;7-G<W1R(")4861Z:6MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4*;7-G:60@(E1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>F%N:6$L
M(%EH9&ES='EN>70@=&%S879A;'1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M(")+;VAD93HB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#0Y"FUS9VED(")487-K<R(*;7-G<W1R(")496ATY';D="(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED
M(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E!U:&5L:6YN=6UE<F\B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B3.1M</9T:6QA(&5D96QL:7-E;&QE('1U;FYI
M;&QE.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5&5M
M<&5R871U<F4B"FUS9W-T<B`B3.1M</9T:6QA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G
M<W1R("),Y&UP]G1I;&$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@
M+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("),Y&UP]G1I;&$\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DUA;&QI82!<
M(B5S7"(@96D@;/9Y='EN>70N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(DUA
M;&QI96X@:&%L;&EN=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S$*;7-G:60@(E1E>'0B
M"FUS9W-T<B`B5&5K<W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E9A:6X@=&5K<W1I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")496MS=&EN('1A<V%U<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*
M;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5K<W1I=&]P(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B
M"FUS9W-T<B`B=&\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I
M9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&AA:2`H5$E3+38R,"DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(T"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")4:&%I;6%A
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D94
M4"UL:7/D=&]I;6EN=&\@96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@9G)A
M;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T
M;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B2&ES=&]R>2!JY')J
M97-T96QMY"!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B(&EN=&5G<F]I;G1I;6]O
M='1O<FD@96D@='5E(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])
M35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-4U`@;&]K:6$@96D@=F]I
M='4@86QU<W1A82XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*
M;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'DB"FUS9W-T<B`B36%I;G1E;F%N8V4Z.B`M;'5O:V%N(&QA
M=&%A;6EN96X@97#D;VYN:7-T=6DB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B07-E='5K<V5T(&EK:W5N82!O
M;B!S=6QJ971T=2X@4&]I<W1U=&%A;BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@
M8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@
M>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)9
M;&SD<&ED;VX@<&ETY.0@;W1T86$@:^1Y='3V]FX@<'ES>7;D('1A;&QE='5S
M='EY<'!I(%!E<FUI<W-I;VXL(&IO<R!H86QU870@(@HB:^1Y='3DY"!N:6ET
MY"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R
M(")686EN(&%L87!U;VQI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$
M(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@
M;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB0V]N
M=&%C="!I9"!N=6UE<F]A(&5I(&]L92!MY.1R:71E;'1Y+"!O;B!T>6AJY"!T
M86D@96D@;/9Y='EN>70@=&EE=&]K86YN87-T82XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT
M86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(EEH=&5Y<W1I961O="!L:7/D='1I:6X@;VYN:7-T=6YE
M97-T:2!O<V]I=&5K:7)J86%S:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"B)6:65S=&EN(&%L;&5K:7)J;VET=6MS
M96X@=&%R:VES=&%M:7-E96X@=&%R=FET86%N(&5R:6QL:6YE;B!01U`M(@HB
M86QL96MI<FIO:71U<VQO:&MO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S
M='(@(B(*(DIA:V5L=6QI<W1A;B!)1"!E:2!O;&QU="!MY.1R:71E;'1Y+"!O
M;B!T>6AJY"!T86D@96D@;/9Y='EN>70@=&EE=&]K86YN87-T82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM
M<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+B(*;7-G<W1R(")*86ME;'5L:7-T86$@96D@;VQL=70@;>3D<FET96QT>2XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B4V%L875S=&]I;6EN;F]N(&OD>71T]B!V86%T
M:2!S86QA='1U82!75U<M>6AT97ET=.0N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-S<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")4:65D;W-T;W-S82`E<R!P:73D
M:7-I(&]L;&$@)7,@87-E='5S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<P(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O
M;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(E1I961O<W1O<W-A("5S('!I=.1I
M<VD@;VQL82!J;VET86MI;B`E<R!A<V5T=6MS:6$N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C86YN;W0@
M8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")4:65D;W-T;V$@96D@
M=F]I9&$@:V]P:6]I9&$@:71S96YSY"!PY.1L;&4N(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B5&EE9&]S=&\@;VQI('1Y:&KD+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(E-E=7)A879A<W-A(&]N(&]T
M<VEK:V]T:65D;W0@=.1S=.0@;65S<V%G92]R9F,X,C(@+79I97-T:7-TY"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V
M"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C
M875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB
M=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA
M<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN
M7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N(@IM<V=S='(@(B(*(DMO:V]R=75D=6X@;N1Y='3V=&EL82!A:6AE=71T
M86$@;VYG96QM:6$@:F]I;&QA:VEN($EN=&5R;F5T($5X<&QO<F5R("(*(G-E
M;&%I;65N(&OD>71TY&II;&SD+B!686QI=&5T=&%V87-T:2!K>7-E:6YE;B!S
M96QA:6X@<VESY&QTY.0@<&EI<G1E:73D(&IA("(*(G9I<FAE:73D(&IO:6AI
M;B!E:2!O;&4@;/9Y='EN>70@:V]R:F%U<W1A('1A:2!K96EN;V$@:VEE<G3D
MY"!O;F=E;&UA+B`B"B)(=6]M86%T:&%N(&5T=.0@:F]S(&OD>73D="!TY'3D
M(&[D>71T]G1I;&%A(&IA($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;G1A+"`B
M"B)N:6EN(&[D>71T]B!S86%T=&%A(&UE;F[D('-E:V%I<VEN+"!J;W1K=70@
M=&]I;6EN;F]T(&5I=N1T('1O:6UI('1A:2!S96QA:6X@(@HB<V%A='1A82!K
M86%T=6$N($IO<R!KY'ETY'0@5VEN9&]W<R`Y>"!T86D@344@=F5R<VEO=&$L
M(&YI:6X@;VX@;6%H9&]L;&ES=&$@(@HB971TY"!KY'ET=/9JY')J97-T96QM
MY"!K86%T=74@;G,N("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G("UV:7)H
M965S965N(&IA("(*(G-I;G5N('!I=.3D(&OD>6YN:7-TY.0@:V]N92!U=61E
M<W1A86XN7%QN7%QN($UU:7-T82!E='3D('-I;G5A(&]N("(*(G9A<F]I=&5T
M='4N($YA<'-A=71A($]++6YA<'!U;&%A(&IO<R!H86QU870@:V]K96EL;&4@
M961I=&]R:6X@:V]K;W)U=71U("(*(F[D>71T]G1I;&%A+B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED
M96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")0;VES
M=&5T=&EI;B!P<F]F:6EL:2!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B5F%I;B!V87-E;B!P=6]L:2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B
M(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(D=N=5!'
M(&]H:F5L;6%N('-I:F%I;G1I('!I=.3D(&WDY')I=&5L;.0@0W)Y<'1?<&=P
M.CH@+6QU;VMA<W-A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H
M<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"B)6:65S=&D@;.1H971E='1Y("5S('9A<W1A86YO='1A:F%L;&4@)7,@;W1S
M:6MK;VYA(%PB)7-<(B!O;B!NY'ET971T>2Y<;B(*(D5I(&]L92!M:73DY&X@
M=&%K96ET82!S:6ETY"!E='3D('9I97-T:2!O;B!L=65T='4@=&%I('EM;>1R
M<F5T='DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X,0IM<V=I
M9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E(@IM<V=S='(@(DYI;6D@:F]T82!KY'ET973DY&X@;&EN:VET971T
MY&5S<V$@;'5O('-I=G5L;&4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@
M;G5M97)I8RXB"FUS9W-T<B`B2V5N='1I96X@;>3D<N0@<&ETY.0@86YT86$@
M;G5M97)O:6YA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M36]D=75L:2!O<&5N<W-L('1A<G9I=&%A;B!(;W)D95]#<GEP=%]S;6EM93HZ
M("UL=6]K86X@:^1Y='3D;6ES96MS:2XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E
M9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S
M(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B
M"FUS9W-T<B`B(@HB07-E='5S=&$@7"(E<UPB(&MO<VMA('-E;B!T:65D;W0@
M>6QI='1I=N1T('1A;&QE='5S=&%V86X@<W5U<FEM;6%N('-A;&QI='5N("(*
M(G)A:F%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I
M;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R
M:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X
M8V5L+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI
M=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P
M<"YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)/:&IE;&UA82P@:F]L;&$@
M=F]I(&MA='-O82!V:65S=&ET>7EP<&GD("@E<RDL(&5I(&SV>71Y;GET(&KD
M<FIE<W1E;&WD<W3D+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("),86EN875S;65R:VMI('!I=.3D
M(&]L;&$@>6MS:71TY&EN96X@;65R:VMI+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R
M:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(E9A:6X@;VEK96$@
M:F$@=F%S96X@<'5O;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B5F%I;B!O:6ME82!P=6]L:2(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")%<F]T
M:6X@<&ETY.0@;VQL82!Y:W-I='3D:6YE;B!M97)K:VDN(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M4&%L=F5L:6X@7"(E<UPB(&]N('!O:7-T971T=2XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4&%L=F5L
M:6X@7"(E<UPB(&]N('1A;&QE=&5T='4N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B4VESY.1N:VER:F%U
M='5M:7-P>7EN=/8@)7,@;VX@<&]I<W1E='1U+B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(DWDY')I=&5L='GD(')I=FGD("@E9"D@96D@;VQE(&]L
M96UA<W-A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9A;&GD86EK86ES=&EE9&]S=&]A
M(%PB)7-<(B!E:2!O;&4@;VQE;6%S<V$N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,P-@IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED
M(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R(")+
M:7)J;VET=&%M87-I('1E:W-T:2!E:2!V87-T86$@=&5K<W1IY"!R=75D=6QL
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>2(*;7-G<W1R(")686EN('ELY'!U;VQI(&IA(&%L87!U;VQI(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM
M<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B5F%I;B!Y;.1P=6]L
M:2(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N(@IM<V=S='(@(E1U;W1U('1I971O(&CD=FES:2!E9&5L;&ES96X@:V]H
M9&%N(&%I:V%N82XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z
M,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H
M92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B
M5'5O='5A('1I961O<W1O82!E:2!V;VET=2!T86QL971T86$N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/<VEO=&$@=V5A=&AE<BYC;VT@
M96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B5&5E;6%H86ME;6ES=&]A(%PB
M)7-<(B!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA
M8FQE+B(*;7-G<W1R(")!<V5T=6MS:6$@96D@;VQE('-A871A=FEL;&$N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0X"FUS9VED
M(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92XB"FUS9W-T<B`B16D@;VQE(&]S:6]I=&$L(&IO=&MA('9O:61A86X@
M;N1Y='3DY"!V:65S=&EE;B!Y:'1E>61E<W/D+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(E3D<W/D(&ME;G3D<W/D(&]N
M(&QI:6%N(&UO;G1A(&UE<FMK:>0N($%N;F]I="`E<R!M97)K:VGD.R!S:6YU
M;B!P:73DY"!A;G1A82`B"B)VY&AE;6WD;B!K=6EN("5S(&UE<FMK:>0N(@H*
M(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@
M=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B2F]I=&%K:6X@;VYG96QM:6$@
M7"(E<UPB(&QI<^3D;6ES97-SY"!JY')J97-T96QMY.1N.B`E<R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(DOD>71TY&KD;B!<(B5S7"(@
M:^1Y='3D:N1T:65T;VIE;B!P;VES=&%M:7-E<W-A(&KD<FIE<W1E;&WD<W/D
M(&]L:2!O;F=E;&UI83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(DIO:71A:VEN(&]N
M9V5L;6EA(%PB)7-<(B!P;VES=&%M:7-E<W-A(&KD<FIE<W1E;&WD<W3D.B`B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S
M='(@(DIO:71A:VEN(&]N9V5L;6EA(%PB)7-<(B!PY&EV:71Y:W-E<W/D.B`E
M<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(E1I
M961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L;6EA+B!9:'3DY&X@)7,Z82!E
M:2!T=6]T=2(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N
M('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G
M<W1R("(B"B)4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O;F=E;&UI82X@)7,@
M:V]K;R!O;&D@<W5U<F5M<&D@:W5I;B!S=75R:6X@<V%L;&ET='4@(@HB:V]K
M;R`H)60@=&%V=6$I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R(")4:65D;W-T;VX@='5O;FYI
M<W-A(&]L:2!O;F=E;&UI82X@)7,@;&%T875T=6D@=F%I;B!O<V%K<VDN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B5&%P86AT=6D@=FER:&4@;N1Y=&5T=.1E<W/D
M('9I97-T:6X@=.1TY"!O<VEO=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(EEH=&5Y<W1I
M971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")I
M0V%L96YD87(M=&EE=&]J96X@='5O;FYI<W-A('1A<&%H='5I('9I<FAE+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R
M("(B"B)!<V5T=7-T:65T;VQO;6%K:V5E<W-A(&]N(&IO:VEN('9I<FAE+B!%
M:&OD(&KD=&ET(&IO;FMU;B!P86MO;&QI<V5N(&MO:&1A;B`B"B)TY'ET=.1M
MY'1TY"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(E1A<&%H='5I
M('9I<FAE('ER:71E='3D97-SY"!S=6]R:71T86$@;W-O:71E:VER:F%T;VEM
M:6YT;V$N(%ER:73D(&UY]FAE;6UI;B`B"B)U=61E<W1A86XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C
M="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"B)9:'1E>7-T:65T;VIE;B!PY&EV:71Y:W-E<W/D('1A<&%H='5I('9I<FAE
M+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")*86ME;'5L:7-T
M86X@<.1I=FET>6MS97-SY"!T87!A:'1U:2!V:7)H92X@67)I=.0@;7GV:&5M
M;6EN('5U9&5S=&%A;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-#D*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(E3D;>0@24U!
M4"!P86QV96QI;B!E:2!T=64@:V%N<VEO:61E;B!J86MA;6ES=&$N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92XB"FUS9W-T<B`B5.1MY"!T:65D;W-T;R!E:2!V86EK=71A(')A<BUT:65D
M;W-T;VQT82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+B(*;7-G<W1R(")4Y&WD('1I961O<W1O(&5I('9A:6MU
M=&$@>FEP+71I961O<W1O;'1A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,S$*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")4Y&WD(&5I('9A:6MU=&$@;VEK
M96%L=&$@:V]R='1I;G5M97)O;'1A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5.1L;.0@86IU<FEL
M;&$@=F]I(&SD:&5T=.3D('9I97-T96KD($-L:6-K871E;&QI;B`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2`B"B)G871E=V%Y('!A;'9E;'5A($A45%`@05!)
M.FQL82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@
M(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E3D
M;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2!G871E=V%Y("(*(G!A;'9E;'5N(&MA=71T82!(5%10
M($%023IL;&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T
M<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%022(*;7-G<W1R("(B"B)4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@
M=FEE<W1E:N0@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@(@HB
M9V%T97=A>2!P86QV96QU;B!K875T=&$@2%144"!!4$DZ;&QA+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)4Y&QLY"!A:G5R:6QL82!V
M;VD@;.1H971TY.0@=FEE<W1E:N0@5F]D869O;F5N(&YU;65R;VEH:6X@4TU4
M4#IL;.0@:^1Y='3D96X@(@HB5F]D869O;F4@271A;'D@9V%T97=A>2!P86QV
M96QU82X@5.1TY"!P86QV96QU82!V;VD@:^1Y='3DY"!V86EN(%9O9&%F;VYE
M("(*(DET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@='5N;G5K<VEL;&$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$Y"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V
M,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,#(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,34V,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0S"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-C(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`P.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,S(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P.#(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$U,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(U"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,30*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`Q"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,#D@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S@Q-PIM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS
M9W-T<B`B5.1MY"!K96YT=.0@;VX@<&%K;VQL:6YE;BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(E3D<W/D(&ME;G3D<W/D
M('!I=.3D(&]L;&$@=F%I;B!K;VMO;F%I<VQU:W5J82XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")4
MY'-SY"!K96YTY'-SY"!P:73DY"!O;&QA(&YU;65R;VET82!J82!P:6QK:W4M
M;65R:VME:N0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y.`IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RXB"FUS9W-T<B`B5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!O:W1A86QI
M;'5K=6IA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C<*;7-G
M:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R
M871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*(E3D<W/D(&ME;G3D
M<W/D('!I=.3D(&]L;&$@;&ES=&$@:V]K;VYA:7-L=6MU:F$L(&IO=&MA('!I
M=.3D(&]L;&$@97)O=&5T='4@(@HB<&EL:W5L;&$@=&%I(';D;&EL>?9N;FEL
M;.0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.3,*;7-G:60@(E1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B07)V
M;VX@<&ETY.0@;VQL82!N=6UE<F\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@R,@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B)4Y'-SY"!K96YTY'-SY"!O
M;B!VY')I;>3D<FET>7,L(&IO;FMA('!I=.3D(&]L;&$@4D="($AE>"!M=6]D
M;W-S+"`B"B)E<VEM97)K:6MS:2`G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(E3D;>0@;&]M86ME(&]N(&IO
M(&OD<VET96QT>2XB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")4Y&WD
M(&]N("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A
M<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@
M86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B
M"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B)4Y&WD(&]N
M($MO;&%B($=R;W5P=V%R92!O8FIE:W1I+B!+871S;V%K<V5S:2!TY&WD;B!O
M8FIE:W1I;B!S:6YU;&QA('!I=.3D("(*(F]L;&$@<^1H:_9P;W-T:6]H:F5L
M;6$L(&IO:V$@>6UMY')TY.0@2V]L86(@1W)O=7!W87)E(&9O<FUA871T:6$N
M($QI<W1A("(*(GEH=&5E;G-O<&EV:7-T82!SY&AK]G!O<W1I;VAJ96QM:7-T
M82!L]GET>7D@;W-O:71T965S=&$@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(E3D;>0@=FEE<W1I
M(&]N(&MI<FIO:71E='1U(&5R:2!M97)K:7-T]FQLY"`H)7,I(&MU:6X@;6EK
MY"!S:6YU;&QA(&]N("(*(FOD>73V<W/D+B`B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N(@IM<V=S='(@(DYU;65R;VX@<&ETY.0@;VQL82!V
MY&AI;G3DY&X@>6MS:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")4Y&QLY"!P86QV
M96QI;65L;&$@96D@=F]I(&%U:V%I<W1A('II<"T@=&%I(&=Z:7`M=&EE9&]S
M=&]J82XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+B(*;7-G<W1R(")4Y&WD(&KD<FIE<W1E;&WD(&]N('!O:7,@<.3D;'3D
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D%R=F]N
M('!I=.3D(&]L;&$@;G5M97)O+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B5.1MY&X@:6MK
M=6YA;B!V;VD@875K86ES=&$@=F%I;B!!<V5T=6MS970@:6MK=6YA<W1A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`B37ER<VMY(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")4:6ME
M=&ET(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R.2!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B
M06EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@
M(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B06IA;G-E=7)A;G1A(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R
M(")!:F%N(&5S:71Y<VUU;W1O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4S-0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B06IA;B!V
M86QI;G1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS
M9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS
M9VED(")4:71L92(*;7-G<W1R(")4:71T96QI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O
M;VQT:7`I.B(*;7-G<W1R(")/='-I:VMO("AT;V]L=&EP*3HB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4
M;R(*;7-G<W1R(")687-T86%N;W1T86IA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T
M<B`B(@HB5F]I9&%K<V5S:2!V86QI=&$@=7-E86UP:6$@=F%I:'1O96AT;VIA
M+"!P:63D($-O;G1R;VPM("A00RD@=&%I($-O;6UA;F0M("(*(BA-86,I(&[D
M<'#D:6YTY"!P;VAJ87-S82!K=6X@;F%P<V%U=&%T(&AI:7)E;B!P86EN:6ME
M='1A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G
M:60@(E1O9&%Y(@IM<V=S='(@(E3D;N3D;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,
M(%-O=7)C92(*;7-G<W1R(").Y'ETY"!(5$U,+6SD:&1E:V]O9&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(S"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(V"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O
M=R(*;7-G<W1R(")(=6]M96YN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD*;7-G:60@(E1O
M;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M;VQA8BYP:'`Z,3`T"FUS9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D
M=7)I;F<@=&AE(&QA<W0@;6EN=71E<RXB"FUS9W-T<B`B(@HB3&EI86X@;6]N
M=&$@97#D;VYN:7-T=6YU='1A(&MI<FIA=71U;6ES>7)I='ES=.0@=FEI;65I
M<VEM<&EE;B!M:6YU=71T:65N("(*(FMU;'5E<W-A+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I9"`B
M5&]P(@IM<V=S='(@(EEL]G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM
M<V=S='(@(EEL:6UPY.1N(&ME:'EK<V5E;B`H7W1O<"DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R
M(")+Y.1N;O9K<V5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,@IM<V=I9"`B5')I;FED860@
M86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"!J82!4;V)A9V\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A
M;'-E(@IM<V=S='(@(E1O<VD@=F%I(&5PY'1O<VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G
M<W1R(")T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@*;7-G:60@(E1U;FES:6$B"FUS9W-T
M<B`B5'5N:7-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$*;7-G:60@(E1U<FME>2(*;7-G
M<W1R(")4=7)K:VDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I
M9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R:VMI("A)4T\M
M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<*;7-G:60@(E1U<FMM96YI<W1A;B(*
M;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P"FUS9VED(")4
M=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,@:F$@0V%I
M8V]S('-A87)E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,*;7-G:60@(E1U=F%L=2(*;7-G
M<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS
M9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B2VER:F]I=&$@=F%L
M:6YT87-I.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X
M"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B52Y6+B`M:6YD96MS:3H@
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T
M.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@
M(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y
M('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),(&IO:&]N('!A;&%U=&5T86%N
M('-K<FEP=&EN('-T871U<R!R87!O<G1T:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T
M<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<*;7-G:60@(E5G86YD82(*;7-G<W1R
M(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V"FUS9VED(")5:W)A:6YE(@IM<V=S
M='(@(E5K<F%I;F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT
M,3D*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B5D93+6AA:V5M:7-T;V$@96D@=F]I='4@;'5K96$N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+B(*;7-G<W1R(")+Y'ET=.1JY&X@;&ESY'1I971O:F5N(&QI<^1Y<R!E:2!O
M;FYI<W1U;G5T(&MI<FIA=71U;6ES97-S82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B16D@=F]I('9A:6AT86$@;VEK975K<VEA(%9&4RUT:65D;W-T;VQL
M92!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,SDR
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B16D@=F]I('9A:6AT86$@;VEK975K<VEA
M(%9&4RUT:65D;W-T;VQL92`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+B(*;7-G<W1R(")%:2!V;VED82!V86EH=&%A("5S.FXN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M7"(N(@IM<V=S='(@(E1I961O<W1O;B!<(B5S7"(@:V]K;V$@96D@=F]I='4@
M=&%R:VES=&%A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y
M-2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`R.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS
M9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A
M(%PB)7,O)7-<(BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*
M;7-G<W1R(")344PM<&%L=F5L:6UE96X@96D@<V%A9&$@>6AT97ET=.0N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")9:'1E>71TY"!E:2!V
M;VED82!M=6]D;W-T86$@4U-,+7-A;&%T='5N82XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,S(@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#0@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B5D93+71I961O<W1O82!E:2!V;VED
M82!K;W!I;VED82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!L=6]D82!61E,M
M:&%K96UI<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S8Q(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")%:2!V;VED
M82!L=6]D82!61E,M:&%K96UI<W1O82XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+B(*;7-G<W1R(")%:2!V;VET=2!L=6]D82!61E,M=&EE9&]S=&]A(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M:V%N<VEO
M=&$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W
M,@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS
M9W-T<B`B16D@=F]I='4@;'5O9&$@='EH:N3D(%9&4RUT:65D;W-T;V$N(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"FUS9VED
M(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")4:65T;V$@
M96D@=F]I9&$@;&%A:F5N=&%A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B16D@=F]I9&$@<&]I
M<W1A82!<(B5S7"(L(&AA:V5M:7-T;R!E:2!O;&4@='EH:N0N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A82!<(B5S7"(Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S."!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-#(@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A
M82`E<RP@:&%K96UI<W1O(&5I(&]L92!T>6AJY"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A
M82!61E,M:&%K96UI<W1O82!R96MU<G-I:79I<V5S=&DN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0T(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S
M-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A
M82!61E,M:&%K96UI<W1O82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C0R,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ
M("5S+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Q,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,3`@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y
M,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDY"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,CDQ"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%9&4RUT
M:65D;W-T;V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L
M9&5R(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A82!61E,M:V%N
M<VEO=&$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A82!6
M1E,ZY.0@<F5K=7)S:6EV:7-E<W1I.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C
M=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3GEK>6ES=.0@:&%K96UI<W1O
M82!E:2!V;VET=2!S96QV:71TY.0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B5F%R;65N=&5E;B!T:65T;VIA
M(&5I('9O:61A(&5X=')A:W1O:61A(@H*(SH@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H
M<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DWDY')I='EK<V5N("5S(&QU
M:V5M:6YE;B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,#,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S0@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N(@IM<V=S='(@(D5I('9O:61A('-I:7)TY.0@5D93+71I
M961O<W1O82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HQ,#8@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%9&4RUT:65D;W-T
M;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X
M-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")%:2!V;VED
M82!A=F%T82!61E,M=&EE9&]S=&]A(&MI<FIO:71U<W1A('9A<G1E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS
M9W-T<B`B16D@=F]I9&$@879A=&$@5D93+71I961O<W1O82XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(E1I:79I
M<W1E='EN('1I961O<W1O;B!A=6MA:7-U(&5PY&]N;FES='5I+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D
M(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(D5I('9O
M:71U(&QU:V5A(%9&4RUT:65D;W-T;V$@*&9I;&5S:7IE*"D@97#D;VYN:7-T
M=6DI+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.#<*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(D5I('9O:61A(&QU:V5A(%9&4RUT:65D;W-T;V$@*&=E=$9I
M;&53:7IE*"D@97#D;VYN:7-T=6DI+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA
M8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(D5I('9O:71U(&QU:V5A('1I
M961O<W1O83H@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C<V
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN
M(@IM<V=S='(@(G9F<W)O;W0@:G5U<FEH86ME;6ES=&]A(&5I('9O:71U(&QU
M:V5A+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@HB
M575D96QL965N;FEM9>1M:6YE;B`E<R`E<SIK<VD@97#D;VYN:7-T=6D@:V]S
M:V$@:V]H9&5H86ME;6ES=&\@;VX@:F\@;VQE;6%S<V$B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D5I('9O:61A(&YI;65T
MY"!U=61E;&QE96X@5D93+6AA:V5M:7-T;V$N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B16D@=F]I
M9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O83H@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('9O:61A(&YI
M;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$W(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B16D@=F]I9&$@;FEM
M973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0U,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,CDS(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#D*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C8*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(D5I('9O:71U(&YI;65TY"!U
M=61E;&QE96X@5D93+71I961O<W1O82XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L
M92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(")%:2!V;VED82!S=6]R:71T
M86$@:V]M96YT;V$@)VUK:7-O9G,G+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(E=O<F0M9&]K=6UE
M;G1T:6$@96D@=F]I='4@:^3D;G3DY"(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(D5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O
M<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+B(*;7-G<W1R(")%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D
M;W-T;V]N("AC;W!Y*"D@97#D;VYN:7-T=6DI+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(X."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G
M<W1R(")%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T;VX@=&EE=&]J
M82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N
M(@IM<V=S='(@(D5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O<W1O82P@
M:VEI;G1I]B!O;B!TY'EN;N0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@
M(D%L;&5V:6EV871T=2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*
M;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")097)U(&UU=71O:W-E="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*
M;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E!E<G5U
M='1A82!E9&5L;&ES96X@=&]I;65N<&ET965N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(R"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B
M5'5N=&5M871O;B!V87-T875S('!A;'9E;&EM96QT82!Y:'1E>71E96XZ(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$X"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"FUS9VED(")5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B
M5'5N=&5M871O;B!V87-T875S('!A;'9E;&EM96QT83H@(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@
M(E5N9FEL960B"FUS9W-T<B`B3'5O:VET=&5L96UA=&]N(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G
M<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-PIM<V=I9"`B56YI
M=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B66AD:7-T>6YE970@87)A8FEE
M;6ER86%T:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@*;7-G:60@(E5N:71E9"!+:6YG9&]M
M(@IM<V=S='(@(EEH9&ES='EN965T(&MU;FEN9V%S:W5N;F%T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,`IM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")9:&1Y<W9A
M;&QA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,SD*;7-G:60@(E5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")9:&1Y<W9A;'1O:F5N(%1Y
M>6YE;FUE<F5N(&5R:6QL:7-S86%R970B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C<X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,@IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B36ET=&%Y:W-I:_9T(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HU."!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,CD*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(E1U;G1E;6%T;VXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB
M"FUS9W-T<B`B5'5N=&5M871O;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R(")4=6YT96UA=&]N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`B06YN971T=2!P86EK:V%T:65T;R!O;B!T=6YT96UA=&]N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M5'5N=&5M871O;B!KY'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R
M(")0;VES=&$@;GEK>6ES96X@96QE;65N=&EN(&QI;FMI='ES(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`B3FEM973V;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@
M<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB5&EE=&]T=7)V87-Y:7-TY"!E:2UP
M<FEV:6QE96=I<V5T('-K<FEP=&ET(&5I=N1T('9O:2!K=71S=6$@3&5I:VMA
M82]+;W!I;VDO(@HB3&EI=.0@=&]I;6EN=&]J82X@3F%P<V%U=&$@3TLM;F%P
M<'5L86$@;N1H9.1K<V5S:2!M;WII;&QA+F]R9R!S:79U:6QL82`B"B)O;&5V
M86X@;VAJ965N+"!J;W-S82!N975V;W1A86X@;6ET96X@<VMR:7!T:7-I('9O
M:79A="!KY'ET=.3D(&QE:6ME</9Y=.3D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T
M(&-O;&]R(@IM<V=S='(@(E!O:7-T82!VY')I(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R
M(")%:2UT=65T='4@;&%A:F5N;G5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")0Y&EV:73D(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B4.1I=FETY"`E<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U
M<V5R(@IM<V=S='(@(E#D:79I=.0@:^1Y='3D:N0B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&5D(%PB)7-<(BXB"FUS9W-T<B`B4.1I=FET971T:6EN(%PB)7-<(BXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S
M8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4.1I=FET>7-S:W)I<'1I('!O:7-T
M971T:6EN+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L
M;V%D(@IM<V=S='(@(E1U;R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")T=6\@:V%I:VMI(&]H:F5L;6EE
M;B!A<V5N;G5S=&EE9&]S=&]T('!A;'9E;&EM96QL92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS
M9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(DES;W0@;&%T:6YA
M;&%I<V5T(&MI<FIA:6UE="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N
M(&YU;6)E<G,B"FUS9W-T<B`B27-O="!R;V]M86QA:7-E="!N=6UE<F]T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,0IM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM
M<V=S='(@(DOD>73D(&YY:WEI<W3D.B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,
M(@IM<V=S='(@(DOD>73D(%-33"US86QA=7-T82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(DOD>73D(&IO
M<R!T=6YN=7,O<V%L87-A;F$@;VX@97)I($E-4U`M<&%L=F5L:6UE;&QE+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@
M(E5S97(B"FUS9W-T<B`B2^1Y='3D:N0B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B2^1Y
M='3D:N1L;.0@)7,@96D@;VQE(&]I:V5U:W-I82!T96ADY"`E<RXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B2^1Y='3D:FEE;B!Y;&SD<&ET;R(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS
M9W-T<B`B2^1Y='3D:N1N(&%S971U:W-E="(*"B,Z('-I9VYU<"YP:'`Z-C(*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(DOD>71TY&KD;B!R
M96MI<W1E<O9I;6EN96XB"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+B(*;7-G<W1R(")4Y'-SY"!JY')J97-T96QMY'-SY"!E:2!V;VD@<F5K:7-T
M97+V:63D(&OD>71TY&IIY"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(DOD
M>71TY&KD='5N;G5S=&$@96D@;/9Y='EN>70N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B2^1Y='3D:N1T=6YN
M=7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X
M:7-T<RXB"FUS9W-T<B`B2^1Y='3D:N1T=6YN=7,@7"(E<UPB(&]N(&IO(&]L
M96UA<W-A+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM
M<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DOD>71TY&KD='5N;G5S.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE
M.B`B"FUS9W-T<B`B2^1Y='3D:N1T=6YN=7,Z("(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T
M96TZ(@IM<V=S='(@(DKD<FIE<W1E;&WD;B!KY'ET=.1JY'0Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,@IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R(")5>F)E:VES=&%N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<P(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(V,@IM<V=I9"`B5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B5D93+6AA:V5M:7-T;V$@96D@;VQE
M(&]L96UA<W-A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*
M;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(E!O:7-S86]L;W9I97-T:2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")086EK:V]J82!L]GET
M>6D@97-I;65R:VEK<VDZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")6;VEM87-S
M86]L;V%I:V$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.3<*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N(@IM<V=S='(@(D%R=F\@;6EN=75T96ES<V$@;GEK>6AE=&ME<W3D
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")!
M<G9O(&]N('EL:2!P:71U=61E;B!M86MS:6UI87)V;VX@)7,N/"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(W,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S(P(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,30*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S
M='(@(D%R=F]T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DP"FUS9VED(")686QU97,@=&\@
M<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L:71T879A="!A<G9O="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#D*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA
M8FQE(@IM<V=S='(@(E9A:6AT96QE=F%A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I
M;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R
M960@=VET:"XB"FUS9W-T<B`B5&%R:VES='5S(&5PY&]N;FES='5I("T@5.1T
MY"!V:65S=&GD(&]N('9O:71U(&OD<VET96QLY"XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G
M<W1R(")697)S:6\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X
M"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEO;FAA;&QI
M;G1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B4'ES
M='ES=6]R82!T87-A=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S
M='(@(E!Y<W1Y<W5O<F$@=.1Y=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T
M<B`B4'ES='ES=6]R83HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(D5R:71T
MY&EN(&MO<FME82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@*;7-G:60@(E9I970@3F%M(@IM
M<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM
M<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M("A6
M25-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.38Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B3N1Y
M=.0@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W
M(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(D[D>73D(&5R:6QL:7-E
M;N0@=W=W+7-I=G5N82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM
M<V=S='(@(D[D>73D("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B3F5I='-Y='-A87)E="P@0G)I
M='1I;.1I;F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-PIM<V=I9"`B5FER9VEN($ES;&%N
M9',L(%4N4RXB"FUS9W-T<B`B3F5I='-Y='-A87)E="P@66AD>7-V86QT86EN
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*;7-G:60@(E9I<VEB:6QI
M='DB"FUS9W-T<B`B3N1K>7;D:7-Y>7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B
M3N1K>7;D:7-Y>7,Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V
M:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L>2!33510.FX@879U;&QA
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")605)/
M25154R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+B(*;7-G<W1R(")605)/25154R$A(2!03TE35$$@4TM225!4
M22!+Y%-)3B!004Q614Q)345,5$$@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*
M;7-G<W1R(")724X@2%144#IN(&%V=6QL82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`*;7-G
M:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!J82!&=71U
M;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*
M;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B5F%R;VET=7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*
M;7-G<W1R(")K92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")3Y.1E;FYU<W1E
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(E/DY'1I961O="!O
M;B!T;VEM:71T86YU="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@
M(E=75R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@
M(E=E8B!3:71E(@IM<V=S='(@(E=75RUS:79U<W1O(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY
M(@IM<V=S='(@(E9I:6MO:71T86EN(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5&5R=F5T=6QO
M82(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(E1E<G9E='5L;V$@;VAJ96QM86%N("5S(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L
M("5S(@IM<V=S='(@(E1E<G9E='5L;V$L("5S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S
M='(@(DSD;G-I;6%I;F5N("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS
M9W-T<B`B3.1N<VEM86EN96XO175R;R`H25-/+3@X-3DM,34I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S@*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(DSD;G-I+5-A
M:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B36EN:^0@;VAJ96QM86X@)7,@:^1Y
M;FYI<W3DY"!S:7/DY&YK:7)J875T=6UI<V5N(&KD;&ME96XN(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(DUI=.0@;65R:VMIY"!K
MY'ET973DY&X@97)O='1I;65N83\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/R(*;7-G<W1R(")-:73D(&UE<FMK:>0@:^1Y=&5TY.1N(&QA:6YA=6MS965N
M/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#8T"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B5VAE
M<F5I<R!!=7-T<F%L:6%N(&MA<G1T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(DUI=&OD('9A:6AE
M970B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M(@IM<V=S='(@(E9O:70@;>3D<FET96QLY"!L:7/D=&]I;6EN=&]J82!L86ET
M971A86X@<.3D;&QE(%)I8V@@5&5X="!E9&ET;W)I<W-A+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G
M:60@(E=I9'1H(@IM<V=S='(@(DQE=F5Y<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3$*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G
M<W1R("),979E>7,@0U-3(&UI='1A>6MS:6MK]FENY"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(E9A<V5M;6%L;&$@;VQE=F%N("5S
M('9A;&EK;VX@;&5V97ES("AT=6QE92!V;VEM86%N('-E=7)A879A;&QA("(*
M(G-I<^3D;FMI<FIA=71U;6ES96QL82DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H
M92!T86)L92(*;7-G<W1R(")4875L=6MO;B!L979E>7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED
M=&@@=6YI="(*;7-G<W1R("),979E>61E;B!Y:W-I:VOV(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I
M9'1H.B(*;7-G<W1R("),979E>7,Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"(*;7-G<W1R(")4
M=75L:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8X"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E1U=6QI<W1A(&%I:V%I
M<VEN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S
M<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")4=75L96YN;W!E=7,@<V]L;75I<W-A
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(E=I;F0Z(@IM
M<V=S='(@(E1U=6QI.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")4=75L:3H@(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B
M5FEI<V%U<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G
M:60@(E=I<VAL:7-T(@IM<V=S='(@(E1O:79E;&ES=&%T(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(E1Y]B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D]S;VET92`H='GV*2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G
M:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B4'5H96QI;B`H='GV*2(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N(@IM<V=S='(@(E;DY'+D(&WDY'+D(&ME;G1T:>0@<FEV:6QLY"`E9"X@
M3V1O=&5T=&EI;B`E9"P@;/9Y='EI("5D+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S
M='(@(E;DY'+D(&WDY'+D(&ME;G1T:>0N($]D;W1E='1I:6X@)60L(&SV>71Y
M:2`E9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I
M;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5N3D<N0@<&]I:VME86UA("5D(&QU
M971T865S<V$@5D93+71I961O<W1O82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S('!E<G5S
M<F%J;VET=&5E="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S
M='(@(E@U,#EV,R!L:7/D=&]I;6EN;F]T(&%V86EM96X@:^1Y=/9L;&4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y
M=C,@2V]H=&5E;B!V86EH=&]E:'1O:6YE;B!N:6UI(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U,#EV,R!+;VAT965N(&%V
M86EM96X@='5N;FES=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M6#4P.78S+6QA86IE;FYU:W-E="(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")962(*;7-G<W1R(")65B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B65E962(*;7-G<W1R(")6
M5E96(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B66%H;V\A(&MA<G1T
M82(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")6=6]S:71T86EN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,@IM<V=I9"`B665M96XB"FUS9W-T<B`B2F5M96XB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")9
M97,B"FUS9W-T<B`B2WEL;.0B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S
M='(@(DMY;&SD+"!S=6]S='5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+B(*;7-G<W1R("(B"B)+Y'ETY'0@5$5+4U1)5$E,04$N($OD>73D
M(%L\/ET@;F%P<'5L86$@=F%I:'1A86MS97-I('1A:V%I<VEN(%=94TE764<M
M=&EL86%N+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S
M='(@(D5T('9O:2!T96ADY"!E;F5M<.3D(&MU:6X@)60@;W-I;W1A+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q-0IM<V=I9"`B66]U(&%R
M92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B170@;VQE(&%U=&5N=&EK
M;VET=6YU="XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B3FEM97-SY'-I(&5I('-A
M82!O;&QA("=<7"<M;65R:VMIY"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#4Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-SD*;7-G:60@
M(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B170@86YT86YU="!O:6ME86X@;75O=&]I<W1A('/D:&OV<&]S=&EO
M<V]I=&5T=&$N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(D5T(&WDY')I=&5L;'ET
M(&UI=&OD('1U;V1U;B!T:65D;W-T;VX@:V5N=.1T('9A<W1A879A="!M:73D
M:VEN(&ME;G1T:>0@)7,Z(@HB<W/D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*
M;7-G<W1R(")/;&5T(&MI<FIA=71U;G5T('5L;W,N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(V-0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA
M;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E-I;G5N('!I=.3D(&%N=&%A(&]I
M:V5A(&UA=&MA<'5H96QI;FYU;65R;RP@=F%I;B!N=6UE<F]I=&$@:F$@;6%H
M9&]L;&ES97-T:2`B"B(G*R<@:F]S(&OD>73D="!K86YS86EN=N1L:7-TY"!P
M=6AE;&EN;G5M97)O;75O=&]A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N(@IM<V=S='(@(E-I;G5N('3D>71Y>2!A;G1A82!O:6ME82!A<G9O+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RXB"FUS9W-T<B`B(@HB4VEN=6X@<&ETY.0@87-E;G1A82!$871A
M5')E92UT875S=&%JY')J97-T96QMY"!E;FYE;B!K=6EN('9O:70@:^1Y='3D
MY"`B"B)3:6=N=7`M=&]I;6EN=&]J82XB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N(@IM<V=S='(@(E-I;G5N('!I=.3D(&%S96YT86$@5D93+71A
M=7-T86KD<FIE<W1E;&WD+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS
M9W-T<B`B(@HB4VEN=6X@='5L964@:W5V86EL;&$@;VYG96QM871I;&%N;F5T
M=&$@96YN96X@:W5I;B!V;VET(&SD:&5T=.3D("(*(F]N9V5L;6%V:65S=&EN
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;R(*;7-G<W1R(")3:6YU;B!P:73DY"!A;G1A82!54DP@
M;6EH:6X@=.1MY"!L:6YK:VD@;W-O:71T86$B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E
M<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")3:6YU;B!P:73DY"!V86QI
M=&$@<&]I<W1E='1A=F$@<&%L=F5L:6XN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+B(*;7-G<W1R(")3:6YU;B!P:73DY"!A;G1A82!P;VES=&5T=&%V
M82!KY'ET=.1JY'1U;FYU<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM
M<V=S='(@(E-I;G5N('!I=.3D(&%N=&%A('!O:7-T971T879A(&OD>71TY&KD
M='5N;G5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")3:6YU;B!P:73DY"!A;G1A
M82!L:7/D='3D=N0@:^1Y='3D:N1T=6YN=7,N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(E-I;G5N('!I=.3D(&%N=&%A('#D:79I=&5T
M=.1VY"!KY'ET=.1JY'1U;FYU<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B4VEN=6X@<&ETY.0@
M=F%L:71A('-U;W)I=&5T=&%V82!T;VEM:6YT;RXB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")3:6YU
M;B!P:73DY"!A;G1A82!U=61E;B!K871E9V]R:6%N(&YI;6DN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*
M;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(B"FUS9W-T<B`B4VEN=6X@<&ETY.0@86YT86$@:71A;&EA;&%I;F5N
M('!U:&5L:6YN=6UE<F\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(DES='5N=&]S
M:2`E<R!O;B!V86YH96YT=6YU="X@2VER:F%U9'4@=75D96QL965N('-I<^3D
M;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I
M9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(E/D:&OV<&]S=&EO<V]I
M='1E97-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B
M66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")3:6YU;B!LY&AE='3D:N1O
M<V]I='1E97-I.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O
M<FUA=&EO;B(*;7-G<W1R(")/;6%T('1I971O<VDB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)3
M:6YU;B!T:65T;VMO;F5E<VD@:^1Y='3D;>0@=&EE=&]V97)K:V\M;W-O:71E
M(&]N(&UU=71T=6YU="!S96X@:N1L:V5E;B!K=6X@(@HB;VQE="!A;&]I='1A
M;G5T("5S(&ES='5N;F]N+B!4:65T;W1U<G9A<WEI<W3D('-I;G5N('!I=.3D
M(&MI<FIA=71U82`B"B)U=61E<W1A86X@:N1R:F5S=&5L;>3D;BXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.
M86UE(@IM<V=S='(@(DYI;65S:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W
M:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N
M=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO
M;B!B86-K96YD+B(*;7-G<W1R("(B"B)+Y'ET=.1MY'-I(&%U=&AE;G1I8V%T
M:6]N('1A=7-T86KD<FIE<W1E;&WD(&5I('1U92!KY'ET=.1J:65N(&QI<^3D
M;6ES=.0N("(*(DIO<R!H86QU870@:&%L;&EN;F]I9&$@:^1Y='3D:N1T=6YN
M=6MS:6$L('-I;G5N('!I=.3D(&OD>71TY.0@:F]T86MI;B!T;VES=&$@(@HB
M875T:&5N=&EC871I;VX@=&%U<W1A:N1R:F5S=&5L;>3D+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)+Y'ET=.1MY'-I
M(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WD(&5I('1U92!KY'ET
M=.1JY'1I971O:F5N("(*(F[D>71TY&UI<W3D('1A:2!TY&WD('!I:7)R92!E
M:2!O;&4@:F]S=&%K:6X@<WEY<W3D(&OD>71E='3D=FES<^0N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B(@HB4VEN=6X@:^1Y='3D;>1S:2!W=W<M<V5L86EN(&[D>71TY.0@
M;VQE=F%N(&UU=71T=6YU="!S96X@:N1L:V5E;B!K=6X@;VQE="`B"B)A;&]I
M='1A;G5T("5S(&ES='5N;F]N+B!4:65T;W1U<G9A<WEI<W3D('-I;G5N('!I
M=.3D(&MI<FIA=71U82`B"B)U=61E<W1A86YJY')J97-T96QMY.1N+B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C4W"FUS9VED(")9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E-E;&%I
M;65S:2!E:2!T=64@=.1TY"!T;VEM:6YT;V$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT
M<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)396QA
M:6UE<VD@96D@='5E('1A<G9I='1A=F%A('1U;&]S='5S=&]I;6EN=&]A+B!0
M86EN82!#;VYT<F]L+T]P=&EO;B`K(%`@(@HB='5L;W-T86%K<V5S:2XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")!:6MA=GGV:'EK:V5E<VDZ(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED
M96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(D]L971U<W!R;V9I
M:6QI<VD@;VX@;75U=&5T='4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$V,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")/
M;&5T=7-P<F]F:6EL:7-I.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(").:6UE<VDZ(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("))<W1U;G1O<VD@;VX@=F%N:&5N
M='5N=70N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<R(*;7-G<W1R(")3:6YU;B!S86QA<V%N87-I("5S.FQL92!O;CH@)7,B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I
M;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")!<V5T=6MS97-I(&]N('#D
M:79I=&5T='D@:F$@;F4@;W9A="!V;VEM87-S82!TY&WD;B!I<W1U;FYO;B!A
M:F%N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS
M9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@
M(D%S971U:W-E<VD@;VX@<.1I=FET971T>2XB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="(*;7-G<W1R(")386QA<V%N87-I(&]N(&YO;&QA='1U(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B
M"B)386QA<V%N87-I(&]N(&YO;&QA='1U+"!T87)K:7-T82!SY&AK]G!O<W1I
M<VD@:F$@:VER:F%U9'4@<VESY.1N('5U9&5L;&$@(@HB<V%L87-A;F%L;&%S
M:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO
M=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E-A;&%S86YA<VD@
M;VX@=F%N:&5N='5N=70N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")%
M=.1P86QV96QI;65S:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T"FUS9VED(")9
M=6=O<VQA=FEA(@IM<V=S='(@(DIU9V]S;&%V:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):
M86ER92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-38*;7-G:60@(EIA;6)I82(*;7-G<W1R(")3
M86UB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4W"FUS9VED(")::6UB86)W92(*;7-G<W1R
M(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I
M9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED
M92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6U!I:6QO=&$@;&%I;F%T='4@=&5K
M<W1I72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O
M8FQE;2!297!O<G1=(@IM<V=S='(@(EM/;F=E;&UA72(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M(@IM<V=S='(@(EM.Y'ETY"!L86EN871T=2!T96MS=&D@
M+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6T[D>73D(&QA:6YA='1U
M('1E:W-T:2`M("5S(')I=FGD72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S
M72(*;7-G<W1R(");<FEV:6QLY"`E<R\E<UTB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$U-#<@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ
M,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]9;&SD<&ET;R(*
M"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R(")?2V]M
M96YT;W1U;&MK:2(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4
M<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T
M92!2;W<B"FUS9W-T<B`B7U!O:7-T82!R:79I(@H*(SH@;&EB+V%P:2YP:'`Z
M,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]2>6AMY'0B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*
M;7-G<W1R(")?3VAJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B7TMU=F%N('1I961O="XN+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS
M9W-T<B`B7TMI<FIA=61U('-I<^3D;B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E]+
M:7)J875D=2!U;&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`B7TUU;VMK86$@;&EN:VMIY"(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@
M(E]!<V5T=6MS970B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M
M:7-S:6]N<R(*;7-G<W1R(")?3VEK975D970B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R(")0;VES=&$@;&EN:VMI+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7T%S96YN
M=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(E]4875L=6MO;B!T:65D;W0N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*
M;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?2^1Y='3D:N1T(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*
M;7-G<W1R(")O<V]I=&5K:7)J82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G
M<W1R(")V87-T86%N;W1T86IA('1U;G1E;6%T;VXB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B
M:V%L96YT97)I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*
M;7-G<W1R(")T>7EN=.0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*
M;7-G<W1R(")E:2!V;VD@;'5O9&$@='5L;W-T:65D;W-T;V$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T
M(&]P96X@:6YP=70B"FUS9W-T<B`B96D@=F]I(&%U:V%I<W1A(&SD:&1E='3D
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DX"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(FYA<'-A=71A('3D<W3D(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")V:7)H92!K;VUE;G1O
M<FEV:6QLY"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(F%S971U
M<W9I<FAE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T
M<B`B:W)I:71T:6YE;B!JY')J97-T96QMY'1I961O<W1O('!U=71T=74B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B
M9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B;75O=&]V:7)H92!T:65D;VES
M<V$B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED(")E
M9&ET(@IM<V=S='(@(FUU;VMK86$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S
M='(@(G1I971U971T82!E:2!L]GET>6YY="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")F86QL:6YG(@IM<V=S
M='(@(FQA<VME=F$B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX.3@*;7-G:60@(F9I;&4B"FUS9W-T<B`B=&EE9&]S=&\B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(G-U=6YN87-T82`E
M<R`H)7,I(&YO<&5U9&5L;&$@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(G!U=7-K
M:71T86EN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G
M<W1R(")H:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R(")T=6YT96UA
M=&]N('!A;'9E;&EM96X@;FEM:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B:6UM961I871E
M(@IM<V=S='(@(G;D;&ET=/9MY'-T:2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B
M"FUS9W-T<B`B:6YL:6YE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R
M(")I;RUV:7)H92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M(")O:&IE;&UI<W1O;B!S:7/D:6YE;B!V:7)H92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS
M9W-T<B`B<FEV:71=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK
M:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R
M(")M:VES;V9S('9I<FAE:V]O9&D@)60@25-/.F$@=&5H9&5S<^0N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM<V=I
M9"`B;6TB"FUS9W-T<B`B;6TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B
M"FUS9W-T<B`B;FEM:2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*
M;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")E:2!O;&4@=&]T975T
M971T=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(R
M,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")E:2!O;&4@
M=FEE;.0@=&]T975T971T=2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(FUU:7-T:6QI<W1A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P<F]S96YT=&DB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R
M;6ES<VEO;B!D96YI960B"FUS9W-T<B`B:^1Y='3V(&MI96QL971T>2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:6MS96QE:73D(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T
M92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")E=.1V:7)H92!P<F]T;VMO
M;&QA<W-A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")N;W5S979A(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I
M8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B<&%L=F5L=2!E:2!O;&4@:^1Y=&5T
M=.1V:7-SY"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q"FUS9VED
M(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(F[D>73D(&5R;W0B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM
M<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!(
M5%10.FX@879U;&QA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B<W1E
M861Y(@IM<V=S='(@(G9A:V%A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")J
MY')J97-T96QMY'9I<FAE(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")T96ATY';D;&ES=&$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I
M9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B=N1L:6%I:V%I;F5N('9I
M<FAE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;2(*;7-G<W1R(")V87)M:7-T86%K<V5S:2!K:7)J;VET
M82!S86QA<V%N82!K86AD97-T:2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM
M<V=S='(@(G5N:69I960B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N
M<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(FYI;65T]FXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(FOD>71TY&KD;B!V86QI
M;G1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM
M<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!O+V9R7T92+G!O````````````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`W,38S-S``,3`T,3<S-C,P,#$`,#$V,S<V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@2&]R9&4@
M,RXQ($9R96YC:"!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$M
M,C`P,B!4:&4@2&]R9&4@4')O:F5C="X*(R!0:65R<F4@3&%C:&%N8V4@/'!L
M0'!I97)R96QA8VAA;F-E+FYE=#X@970@0F5N;VET(%-T+4%N9'+I("AB96Y`
M8F5N;VET<W0M86YD<F4N;F5T*2P@,C`P,RP@,C`P-"X*(R!&<F5D97)I8R!4
M<G5D96%U(#QF=')U9&5A=4!C86TN;W)G/BP@,C`P,2X*(R!4:&EE<G)Y(%1H
M;VUA<R`\=&AI97)R>4!P;VUP;RYN970^+"`R,#`R+"`R,#`U+"`R,#`V+@HC
M($-O=6YT<GD@=')A;FQA=&EO;G,@9G)O;2!-:6=U96P@5')E;6)L87D@/&MB
M86)E;"YM:6=U96Q`<'1A9F8N8V$^+"`R,#`T+@HC($)E;F]I="!3="U!;F1R
MZ2`\8F5N0&)E;F]I='-T+6%N9')E+FYE=#XL(#(P,#0N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(&9R7T927&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#8M,#$M,#8@,38Z,S4K,#$P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-BTP,2TP-B`Q-CHT,"LP,3`P7&XB"B),87-T
M+51R86YS;&%T;W(Z(%1H:65R<GD@5&AO;6%S(#QT:&EE<G)Y0'!O;7!O+FYE
M=#Y<;B(*(DQA;F=U86=E+51E86TZ($9R96YC:"`\:3$X;D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A;"U&;W)M<SH@;G!L
M=7)A;',],CL@<&QU<F%L/2AN(#X@,2D[7&XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O
M*2(*;7-G<W1R("(@*&EL('D@82`E<R!J;W5R<RDB"@HC.B!L:6(O2&]R9&4N
M<&AP.C$S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I
M(@IM<V=S='(@(B`H5&]U8VAE(&0G86-CZ',@<F%P:61E("5S*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S@Q"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AD86YS("5S(&IO=7)S*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S<W"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R
M("(@*&%U:F]U<F0G:'5I*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Y
M"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&1E;6%I;BDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AY97-T97)D87DI(@IM
M<V=S='(@(B`H:&EE<BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G
M<W1R("(@X"`B"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@
M(JN@)7.@NR!N)V5S="!P87,@=6X@9&]S<VEE<B(*"B,Z(&QI8B](;W)D92]#
M3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("*KH"5SH+L@;B=E<W0@<&%S('5N
M(&-H;VEX('9A;&ED92XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C8U
M,B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!2
M96=I<W1R>2XB"FUS9W-T<B`BJZ`E<Z"[(&XG97-T('!A<R!C;VYF:6=U<ND@
M9&%N<R!L92!R96=I<W1R92!D92!(;W)D92XB"@HC.B!L:6(O2&]R9&4O5')E
M92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E
M;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B3"=I;G1E<G!RZ71E=7(@9"=A
M<F)R92"KH"5SH+L@;B=A('!A<R#I=.D@=')O=7;I+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`BJZ`E<Z"[(&$@
MZ73I(&%J;W5TZ2!A=2!S>7-TZ&UE(&1E<R!G<F]U<&5S+B(*"B,Z(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM
M<V=S='(@(JN@)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM92!D97,@<&5R
M;6ES<VEO;G,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(JN@)7.@NR!N)V$@<&%S
M(.ETZ2!C<NGIH#H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F:@36\@=71I;&ESZ7,@<W5R
M("4N,F:@36\@<&5R;6ES("@E+C)FH"4E*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S(&5T("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N(@IM<V=S='(@(B5D(&IO=7)S(&%V86YT(&PG97AP:7)A=&EO
M;B!D92!V;W1R92!M;W0@9&4@<&%S<V4N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@
M9F]R96-A<W0B"FUS9W-T<B`B)60M<'+I=FES:6]N(&1U(&IO=7(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!.;W1I8V4B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R(")%;7!R96EN=&4@4$=0(&1E("5S
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,"!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#0R"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($M"(@IM<V=S='(@(B5SH$MO(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@;W#I<F%T
M:6]N<R!D92!M86EN=&5N86YC92`F;F1A<V@[($-O;F9I<FUA=&EO;B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R
M(")#;VYF:6=U<F%T:6]N("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G
M<W1R("));G-C<FEP=&EO;B!D92`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!
M9W)E96UE;G0B"FUS9W-T<B`B0V]N9&ET:6]N<R!D)W5T:6QI<V%T:6]N(&1E
M("5S(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0S,B!L:6(O5D93+W-M8BYP:'`Z
M-#DT(&QI8B]61E,O9G1P+G!H<#HV-S$*(SH@;&EB+U9&4R]F='`N<&AP.C<S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS
M9W-T<B`B)7,@97AI<W1E(&3I:N`N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@
M)7,B"FUS9W-T<B`B("5SH.`@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N
M*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R
M("(B"B(E<R!E<W0@<'+J="#@(&5F9F5C='5E<B!L97,@;W#I<F%T:6]N<R!D
M92!M86EN=&5N86YC92!C;V-HZ65S(&-I+61E<W-O=7,N("(*(E/I;&5C=&EO
M;FYE>B!L82!O=2!L97,@;W#I<F%T:6]N*',I('%U92!V;W5S('9O=6QE>B!E
M9F9E8W1U97(@8V5T=&4@9F]I<RUC:2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*
M;7-G<W1R("(E<R!E<W0@;V)L:6=A=&]I<F4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM
M<V=S='(@(B5S(&UI;G5T97,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B)7,@;F]N('1R;W5VZ2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B)7.@X"`E<R!D92`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3(Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D
M<F5S<R!";V]K(@IM<V=S='(@(D-A<FYE="!D)V%D<F5S<V5S(&1E("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$@9&4@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`B0FQO8RUN;W1E<R!D92`E<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3(Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@5&%S:VQI<W0B"FUS9W-T<B`B3&ES=&4@9&4@=.)C:&5S(&1E("5S(@H*
M(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<Z`Z
M("5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N
M;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O
M;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H
M92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B(*(B5SH#H@;"?I;65T=&5U<B!D92!C92!M97-S86=E(&$@<'4@ZG1R
M92!F86QS:69IZ2X@071T96YT:6]N(&5N('-U:79A;G0@;&5S("(*(FQI96YS
M('%U)VEL(&-O;G1I96YT(&]U(&5N(&9O=7)N:7-S86YT(&1E<R!I;F9O<FUA
M=&EO;G,@<&5R<V]N;F5L;&5S(.`@(@HB;"?I;65T=&5U<BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!E
M;B!R869A;&4@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T
M:6YG("5S("5S(@IM<V=S='(@(G)A9F%L92`E<R`E<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B
M;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R(")V87)I86)L92!D=2`E<R!A=2`E
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#<S(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3,R(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,S0X(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HW-#4*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M
M+2!3Z6QE8W1I;VYN97(@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*
M;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA="`Q,B!H975R
M97,B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@
M1F]R;6%T(@IM<V=S='(@(D9O<FUA="`R-"!H975R97,B"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B
M,C0@:&5U<F5S(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I
M9"`B/%!R979I;W5S(@IM<V=S='(@(CQ0<NECZ61E;G0B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")5;F4@8F%S92!D
M92!D;VYNZ65S('!R:6YC:7!A;&4@*&)A8VME;F0I(&5S="!NZ6-E<W-A:7)E
M('!O=7(@8V4@8FQO8R(*"B,Z(&QI8B](;W)D92YP:'`Z,38R"FUS9VED(")!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")5;F4@97)R975R
M(&9A=&%L92!S)V5S="!P<F]D=6ET92(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B56YE(&-L968@<'5B
M;&EQ=64@4$=0(&5S="!NZ6-E<W-A:7)E('!O=7(@8VAI9F9R97(@=6X@;65S
M<V%G92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)5;F4@8VQE9B!P=6)L:7%U92!0
M1U`@97-T(&[I8V5S<V%I<F4@<&]U<B!VZ7)I9FEE<B!L82!S:6=N871U<F4@
M9"=U;B!M97-S86=E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P
M.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B
M"B)M97-S86=E+B(*;7-G<W1R("(B"B)5;F4@8VQE9B!P=6)L:7%U92!01U`L
M('5N92!C;&5F('!R:7;I92!01U`L(&5T('5N92!P:')A<V4@<V5C<NAT92!S
M;VYT("(*(F[I8V5S<V%I<F5S('!O=7(@9.EC:&EF9G)E<B!U;B!M97-S86=E
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*
M(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"B)5;F4@8VQE9B!P=6)L:7%U92!01U`L('5N92!C;&5F('!R:7;I
M92!01U`L(&5T('5N92!P:')A<V4@<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I
M<F5S('!O=7(@<VEG;F5R('5N(&UE<W-A9V4N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)5
M;F4@8VQE9B!P=6)L:7%U92!3+TU)344L('5N92!C;&5F('!R:7;I92!3+TU)
M344L(&5T('5N92!P:')A<V4@<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I<F5S
M('!O=7(@9.EC:&EF9G)E<B!U;B!M97-S86=E+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB56YE
M(&-L968@<'5B;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-24U%
M+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="`B"B)NZ6-E<W-A:7)E<R!P
M;W5R('-I9VYE<B!U;B!M97-S86=E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E5N92!C;&5F
M('!U8FQI<75E(%,O34E-12!E<W0@;NEC97-S86ER92!P;W5R(&-H:69F<F5R
M('5N(&UE<W-A9V4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(DYU86=E<R!L
M92!M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(E!L=6EE(&SI
M9^AR92!L92!M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(E!L=6EE(&QE
M(&UA=&EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B079E<G-E<R!L92!M
M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B0VAU=&5S(&1E
M(&YE:6=E(&QE(&UA=&EN(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R
M("+`('!R;W!O<R!D92!C970@Z61I=&5U<B(*"B,Z('-E<G9I8V5S+VAE;'`O
M:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("+`('!R;W!O
M<RXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")"87,@86)S;VQU(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM
M<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(DUI;&EE=2!A8G-O;'4B"@HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B06-CZ',@<F5F=7/I(&QO
M<G,@9&4@;&$@8W+I871I;VX@9&4@<NEP97)T;VER92!61E,@+B(*"B,Z(&QI
M8B]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B06-CZ',@<F5F=7/I(&QO<G,@9&4@
M;&$@8W+I871I;VX@9&4@9FEC:&EE<B!61E,N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B1&]N;NEE<R!P97)S;VYN96QL97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B36]T
M(&1E('!A<W-E(&1U(&-O;7!T92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T
M<B`B0V]M<'1E(&EN86-T:68B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(D-O;7!T97,B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")!:F]U=&5R(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@
M(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")!:F]U=&5R('5N('-O=7,M9W)O
M=7!E(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY."!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*
M;7-G<W1R(")!:F]U=&5R('5N92!N;W5V96QL92!S;W5S+7!E<FUI<W-I;VXB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE
M<F4Z(@IM<V=S='(@(D%J;W5T97(@:6-IH#HB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'
M<F]U<"(*;7-G<W1R(")!:F]U=&5R('5N(&YO=79E874@9W)O=7!E(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B06IO
M=71E<B!U;F4@;F]U=F5L;&4@<&5R;6ES<VEO;B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(D%J;W5T
M97(@=6X@9W)O=7!E(&9I;',@X""KH"5SH+LB"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")!:F]U=&5R('5N92!P
M97)M:7-S:6]N(&9I;&QE(.`@JZ`E<Z"[(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")!:F]U=&5R('5N
M(&YO=79E;"!U=&EL:7-A=&5U<J`Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4U,PIM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R
M(")!:F]U=&5R('5N92!C;VQO;FYE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(D%J;W5T97(@9&4@;F]U=F5A=7@@;65M8G)E<R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@
M(D%J;W5T97(@=6YE('!A:7)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@
M82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B06IO=71E<B!L92!M96YU("5S
M(.`@;&$@8F%R<F4@9&4@36]Z:6QL82(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ
M(@IM<V=S='(@(D%J;W5T97(@874@8V%R;F5T(&0G861R97-S97.@.B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D
M9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B06IO=71E<B#@(&UO;B!C
M87)N970@9"=A9')E<W-E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED
M(")!9&0@=7-E<B(*;7-G<W1R(")!:F]U=&5R('5N('5T:6QI<V%T975R(@H*
M(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D
M(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T
M<B`B(@HBJZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S>7-TZ&UE+"!M86ES(&PG
M86IO=70@9"=I;F9O<FUA=&EO;B!S=7!P;.EM96YT86ER97,@)2(*(G,@;B=E
M<W0@<&%S('!O<W-I8FQE+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`BJZ`E<Z"[(&$@Z73I(&%J;W5TZ2X@
M5F]U<R!P;W5V97H@=F]U<R!C;VYN96-T97(N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`B3&$@9F]N8W1I;VX@9"=A:F]U="!D)W5T:6QI
M<V%T975R<R!E<W0@9.ES86-T:7;I92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30T-2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B
M061D<F5S<R(*;7-G<W1R(")!9')E<W-E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D-A
M<FYE="!D)V%D<F5S<V5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS
M(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')A=&5U<B`M(&%J
M=7-T97(@;&5S('!E<FUI<W-I;VYS('!O=7(@9"=A=71R97,@=71I;&ES871E
M=7)S(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F%T:6]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(E!U8G,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI
M<W1A;B(*;7-G<W1R(")!9F=H86YI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS
M9W-T<B`B06QB86YI92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QGZ7)I
M92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS
M9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N
M(@IM<V=S='(@(D%L:6=N97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(D%L:6=N96UE;G2@.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(E1O=70B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED
M(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")4;W5S(&QE<R!P
M87)T:6-I<&%N=',@875T:&5N=&EF:>ES(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*
M;7-G<W1R(")4;W5S(&QE<R!G<F]U<&5S(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HY,2!L:6(O2&]R9&4O4&5R;7,O9&%T871R964N<&AP.C<U"FUS
M9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&]U=&5S(&QE<R!P97)M
M:7-S:6]N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(DQE<R!Q=6%T<F4@8_1TZ7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W
M-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E!E
M<FUE='1R92!D97,@861R97-S97,@9&4@8V]U<G)I96P@;75L=&EP;&5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T
M=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B075T;W)I<V5R
M(&QA(&UI<V4@96X@<&QA8V4@9&4@;&ES=&5S(&YU;>ER;W3I97.@/R(*"B,Z
M(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B17AI<W1E(&3I:N`B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*
M;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@
M24U34"!087-S=V]R9"(*;7-G<W1R(")-;W0@9&4@<&%S<V4@24U34"!A;'1E
M<FYA=&EF(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B
M06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B3F]M(&0G=71I;&ES
M871E=7(@24U34"!A;'1E<FYA=&EF(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM
M<V=S='(@(D%D<F5S<V4@9&4@8V]U<G)I96P@86QT97)N871I=F4B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L
M871E<R(*;7-G<W1R(")!=71R97,@;6]DZ&QE<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I
M9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E1E>'1E(&%L=&5R;F%T:6:@
M.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(E-A;6]A($%MZ7)I
M8V%I;B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"XB"FUS9W-T<B`B56YE('9A;&5U<B!I;&SI9V%L92!A(.ET
MZ2!S<.EC:69IZ64N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS
M9W-T<B`B56YE(&5R<F5U<B!I;F-O;FYU92!S)V5S="!P<F]D=6ET92XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B
M"FUS9W-T<B`B06YG;VQA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG
M=6EL;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")0<F]X>2!A;F]N>6UE(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*
M;7-G<W1R(")2Z7!O;G-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!
M;G1A<F-T:7%U92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T
M<B`B06YT:6=U82UE="U"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4@;&EB+TAO<F1E+T)L;V-K+U5)
M+G!H<#HU.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV
M"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<'!L:6-A=&EO;B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@
M3&ES="(*;7-G<W1R("),:7-T92!D)V%P<&QI8V%T:6]N<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E
M861Y+B(*;7-G<W1R("),)V%P<&QI8V%T:6]N(&5S="!P<NIT92(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#
M:&EL9"!3:&%R97,B"FUS9W-T<B`B07!P;&EQ=65R(&%U>"!P87)T86=E<R!F
M:6QS(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*
M;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B07!P<F]U=NDB"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#0P"FUS9VED(")!<'!R;WAI;6%T92!3
M:7IE(@IM<V=S='(@(E1A:6QL92!A<'!R;WAI;6%T:79E(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@
M(D%V<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S$*;7-G:60@(D%R
M86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B92`H5VEN9&]W<RTQ
M,C4V*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E($9I;&4@4VEZ
M92(*;7-G<W1R(")486EL;&4@9'4@9FEC:&EE<B!A<F-H:79E(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(").;VT@9&4@
M;"=A<F-H:79E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/R(*;7-G<W1R("(B"B+*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER('-U
M<'!R:6UE<B!C971T92!R97%UZG1E(&0G:6YS8W)I<'1I;VX@('!O=7(@)7.@
M/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D
M96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`BRG1E
M<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(*N@)7.@NR!E="!S
M97,@<V]U<RUG<F]U<&5SH#\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
M07)G96YT:6YE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FWI;FEE(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S(*;7-G:60@(D%R;65N:6%N("A!
M4DU30TE)+3@I(@IM<V=S='(@(D%R;>EN:65N("A!4DU30TE)+3@I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B
M07)T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS
M9W-T<B`B07-C96YS:6]N("C.;&4I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07)T($%30TE)(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C
M:69I8R!296=I;VXB"FUS9W-T<B`B4NEG:6]N($%S:64O4&%C:69I<75E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_(@IM<V=S='(@(B(*(D1E;6%N9&5R('5N92!C;VYF:7)M871I;VX@879A
M;G0@9&4@;&%N8V5R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-EH#\B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,@IM<V=I9"`B07-S:6=N;65N
M="!C;VQU;6YS(@IM<V=S='(@(D-O;&]N;F5S(&1E<R!TXF-H97,B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B5&5N=&%T:79E(&0G969F
M86-E;65N="!D)W5N(&=R;W5P92!I;F5X:7-T86YT+B(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E1E;G1A=&EV92`@
M9"=E9F9A8V5M96YT(&0G=6YE('!E<FUI<W-I;VX@:6YE>&ES=&%N=&4N(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")496YT
M871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6YE('!E<FUI<W-I;VX@:6YE>&ES
M=&%N=&4N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S
M='(@(E1E;G1A=&EV92!D92!M;V1I9FEC871I;VX@9"=U;B!P87)T86=E(&EN
M97AI<W1A;G0N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B
M"FUS9W-T<B`B4')O<')IZ73I<R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B06_[="(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%L:64B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA
M(@IM<V=S='(@(D%U=')I8VAE(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L
M+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7.@.B!%>'1E
M;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE+B(*"B,Z(&QI8B](;W)D
M92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T
M<B`B075T:%]C>7)U<Z`Z(&QE(&)A8VME;F0@;B=A('!A<R!L97,@8V%P86-I
M=.ES(')E<75I<V5S+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ
M,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<Z`Z(&5X=&5N<VEO;B!R
M97%U:7-E($E-05`@;F]N('1R;W5VZ64B"@HC.B!L:6(O2&]R9&4O075T:"]F
M='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1PH#H@97AT
M96YS:6]N(')E<75I<V4@1E10(&YO;B!T<F]U=NEE+B!);"!F875T(&-O;7!I
M;&5R(%!(4"!A=F5C("(*(FPG;W!T:6]N("TM96YA8FQE+69T<"XB"@HC.B!L
M:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!2
M97%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?:6UA<*`Z(&5X=&5N<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?
M:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VMR8C6@.B!E>'1E;G-I;VX@<F5Q=6ES92!K<F(U(&YO;B!T
M<F]U=NEE+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I
M9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87"@.B!L
M)V%J;W5T(&0G=71I;&ES871E=7)S(&XG97-T('!A<R!S=7!P;W)TZ2!A=F5C
M($%C=&EV92!$:7)E8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!
M=71H7VQD87"@.B!L92!R971R86ET(&0G=71I;&ES871E=7)S(&XG97-T('!A
M<R!S=7!P;W)TZ2!A=F5C($%C=&EV92`B"B)$:7)E8W1O<GDB"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M;&1A<*`Z(&5X=&5N<VEO;B!R97%U:7-E($Q$05`@;F]N('1R;W5VZ64N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L
M9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@;"=U=&EL:7-A=&5U<B`E<RX@
M0V5C:2!E<W0@;&$@<NEP;VYS92!D=2`B"B)S97)V975RH#H@(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(D%U=&A?;&1A<*`Z(&EM<&]S<VEB;&4@9&4@<W5P<')I;65R(&PG=71I;&ES
M871E=7(@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%PH#H@;6]D:69I8V%T:6]N(&EM
M<&]S<VEB;&4@9&4@;"=U=&EL:7-A=&5U<B`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*
M;7-G<W1R("(B"B)!=71H7VQD87"@.B!L82!M;V1I9FEC871I;VX@9&5S('5T
M:6QI<V%T975R<R!N)V5S="!P87,@<W5P<&]R=.EE(&%V96,@06-T:79E("(*
M(D1I<F5C=&]R>2XB"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM
M<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;*`Z(&5X=&5N<VEO;B!R97%U:7-E
M($U#04P@;F]N('1R;W5VZ64N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H
M<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:*`Z(&5X
M=&5N<VEO;B!R97%U:7-E('-M8F%U=&@@;F]N('1R;W5VZ64N(@H*(SH@;&EB
M+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I
M;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+)8VAE8R!D92!L
M)V%U=&AE;G1I9FEC871I;VX@874@<V5R=F5U<B!)34%0+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT
M:6-A=&EO;B!F86EL960B"FUS9W-T<B`BR6-H96,@9&4@;"=A=71H96YT:69I
M8V%T:6]N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T
M<B`BR6-H96,@9&4@;"=A=71H96YT:69I8V%T:6]N("5S(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(DQE('-E<G9E
M=7(@4D%$2553(&$@<F5J973I(&PG875T:&5N=&EF:6-A=&EO;BXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z.#<Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BR6-H96,@9&4@;"=A=71H96YT
M:69I8V%T:6]N(&%U('-E<G9E=7(@1E10+B(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R("+)8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX@
M874@<V5R=F5U<B!334(N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B0VAA;7!S
M(&1I<W!O;FEB;&5SH#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z
M97)B8>]D:F%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED
M(")"3T9(($5X8W5S97,B"FUS9W-T<B`B17AC=7-E<R!"3T9((@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM
M<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")#;W5L975R(&1E(&9O;F0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS
M9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D-O=6QE=7(@9&4@9F]N
M9"(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@
M:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(DUO="!D92!P87-S92!+97)B
M97)O<R!E<G)O;NDN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#,*
M;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B3F]M(&1E
M(&-O;FYE>&EO;B!+97)B97)O<R!E<G)O;NDN(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*
M;7-G<W1R(")"86AA;6%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR
M9>]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)A;'1I
M8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1E("A)4T\M.#@U.2TQ,RDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"87)B861O<R(*;7-G<W1R(")"87)B861E(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI
M8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E+I<&5R
M=&]I<F4@9&5S(&=R87!H:7%U97,@JZ`E<Z"[(&YO;B!T<F]U=NDN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S
M"FUS9VED(")"87-E;&EN92(*;7-G<W1R("),:6=N92!D92!B87-E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F5L87)U<R(*;7-G<W1R(")"Z6QA<G5S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*
M;7-G<W1R(")"96QG:7%U92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI
M>F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"Z6YI;B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU
M9&$B"FUS9W-T<B`B0F5R;75D97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B
M0FAO=71A;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")!;FYI=F5R<V%I<F4B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4T"B,L('!H<"UF
M;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")";&]C(*LE<R"[(&1E(&PG87!P;&EC
M871I;VX@JZ`E<Z"[(&EN8V]N;G4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(E!R
MZ6;I<F5N8V5S(&1E(&)L;V,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5'EP92!D92!B
M;&]C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX"FUS9VED(")";VQD(@IM<V=S='(@(D=R87,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA
M(@IM<V=S='(@(D)O;&EV:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B4VEG;F5T<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")";W)D=7)E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R
M9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`BR7!A:7-S975R(&1E(&QA(&)O<F1U
M<F6@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B0F]R9',B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI92U(
M97)ZZ6=O=FEN92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I
M9"`B0F]T:"(*;7-G<W1R("),97,@9&5U>"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B
M0F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V970B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"<F%Z:6PB"FUS9W-T<B`B0G+I<VEL(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")497)R:71O:7)E<R!B
M<FET86YN:7%U97,@9&4@;"=/8^EA;B!);F1I96XB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@
M1&%R=7-S86QA;2(*;7-G<W1R(")3=6QT86YA="!D=2!"<G5NZ6DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"=6QG87)I82(*;7-G<W1R(")"=6QG87)I92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`B3&ES=&4@X"!P=6-E<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@
M1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM
M<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#0V"FUS9VED(")#35,B"FUS9W-T<B`B1V5S=&EO;B!D92!C;VYT96YU(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-2
M0R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B
M1&ES=')I8G5T:6]N(&1E<R!P;VEN=',@3%)#("A,:7-T92!D92!RZ79O8V%T
M:6]N(&1E<R!C97)T:69I8V%T<RDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')IZ73I<R!D92!L82!#7V5L;'5L
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@
M(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DPG:6YI
M=&EA;&ES871I;VX@9'4@8V%C:&4@;F4@<R=E<W0@<&%S('1E<FUI;NEE+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#(@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM
M(@IM<V=S='(@(D-A;&UE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(D-A
M;6)O9&=E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B0V%M97)O=6XB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D92!RZ6EN
M:71I86QI<V5R(&QE(&UO="!D92!P87-S92!A=71O;6%T:7%U96UE;G0L(&-O
M;G1A8W1E>B!V;W1R92`B"B)A9&UI;FES=')A=&5U<B!S>7-TZ&UE+B(*"B,Z
M(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B26UP;W-S:6)L
M92!D92!S=7!P<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=A
M9&UI;FES=')E<B!D97,@9V5S=&EO;FYA:7)E<R!D92!S97-S:6]N(&5X=&5R
M;F5S+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BR6-H
M96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@24U!4*`Z("5S(@H*(SH@
M;&EB+T9I;&4O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D)V]U
M=G)I<B!L92!F:6-H:65R(*N@)7.@NRXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B0V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N
M<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS
M9W-T<B`B06YN=6QE<B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B
M06YN=6QE<B!L92!R87!P;W)T(&1U('!R;V)LZ&UE(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E('-U<'!R:6UE
M<B!L92!F:6-H:65R(*N@)7.@NRXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A
M;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP
M;W-S:6)L92!D92!T<F]U=F5R('5N('+I<&5R=&]I<F4@=&5M<&]R86ER92(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R
M("));7!O<W-I8FQE(&1E('!R;V/I9&5R('-A;G,@;&4@<&%R86WH=')E(*L@
M=&%R9V5T1FEL92"[(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<W5P<')I;65R(&QE('+I<&5R=&]I
M<F4@JZ`E<Z"[+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z,3(X(&QI
M8B](;W)D92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T
M<B`B4W5P<')E<W-I;VX@:6UP;W-S:6)L92P@:6P@>2!A("5D(&5N<F5G:7-T
M<F5M96YT<R!F:6QS+B(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP
M.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(DEM<&]S<VEB;&4@9&4@<NEO<F1O
M;FYE<BP@;&4@;F]M8G)E(&0GZ6SI;65N=',@X"!RZ6]R9&]N;F5R(&YE(&-O
M<G)E<W!O;F0@(@HB<&%S(&%U(&YO;6)R92!D)^ELZ6UE;G1S(&5N<F5G:7-T
M<NES+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y
M"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M
M8F5R+B(*;7-G<W1R(").92!P975T(&1I<FEG97(@;&4@;65S<V%G92!V97)S
M(&QE(&YO;6)R92!S<.EC:69IZ2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S
M='(@(D-A<"U697)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("),
MZ6=E;F1E(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*
M;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B5')A;G-P;W)T975R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,
M86)E;',B"FUS9W-T<B`B0V%TZ6=O<FEE<R!E="#)=&EQ=65T=&5S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(LYL97,@0V'O;6%N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E
M;&P@4&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE(&-E;&QU;&%I<F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U
M"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')IZ73I<R!D
M92!L82!C96QL=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B
M4F5M<&QI<W-A9V4@875T;W5R(&1E(&QA(&-E;&QU;&6@.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G
M:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FGI=.ES(&1E(&QA
M(&-E;&QU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")%<W!A
M8V5M96YT(&1E(&QA(&-E;&QU;&6@.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE(&-E
M;&QU;&%I<F4@(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G:60@
M(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(D-E;'1E("A)4T\M.#@U
M.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B0V5N=')E<B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")2Z7!U
M8FQI<75E(&-E;G1R869R:6-A:6YE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S4*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM
M<V=S='(@(D5U<F]PZ65N(&-E;G1R86P@*$E33RTX.#4Y+3(I(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E
M($1E=&%I;',B"FUS9W-T<B`B1.ET86EL<R!D=2!C97)T:69I8V%T(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC
M871E($]W;F5R(@IM<V=S='(@(E!R;W!R:>ET86ER92!D=2!C97)T:69I8V%T
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E
M<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E!O;&ET:7%U92!D92!C97)T
M:69I8V%T:6]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(E1C:&%D(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(DUO9&EF
M:65R(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED
M(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")-;V1I9FEE<B!V;W1R
M92!M;W0@9&4@<&%S<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*
M;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E
M;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB
M96UA:6QS+B(*;7-G<W1R("(B"B)#:&%N9V5R(&QE(&YO;2P@;"=A9')E<W-E
M(&5T(&QA('-I9VYA='5R92!Q=64@;&5S('!E<G-O;FYE<R!V;VEE;G0@<75A
M;F0@(@HB96QL97,@;&ES96YT(&5T('+I<&]N9&5N="#@('9O<R!M97-S86=E
M<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@
M(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3&$@;6]D:69I8V%T:6]N
M(&1E('9O=')E(&UO="!D92!P87-S92!N)V5S="!P87,@<W5P<&]R=.EE(&%V
M96,@;&$@(@HB8V]N9FEG=7)A=&EO;B!A8W1U96QL92X@0V]N=&%C=&5Z('9O
M=')E(&%D;6EN:7-T<F%T975R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T
M<B`B0VAA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T
M<B`B5NE?<FEF:65R(&QE(&QI96XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")#
M:&EL:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(D-H:6YE(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*2(*;7-G<W1R(")#:&EN;VES('-I;7!L:69IZ2`H1T(R,S$R*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")#:&EN;VES('1R861I=&EO;FYE
M;"`H0FEG-2DB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED
M(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(D-H;VES:7(@;"=A<'!L
M:6-A=&EO;J`Z(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*
M;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(D-H;VES:7(@=6X@
M;6]T(&1E('!A<W-E(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(D-H;VES:7(@
M=6X@;F]M(&1E(&-O;FYE>&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS
M9W-T<B`B0VAO:7-I<B!L92!M;V1E(&0G869F:6-H86=E(&1E<R!D871E<Z`Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I(@IM<V=S='(@(D-H;VES:7(@;&4@<W1Y;&4@9&4@
M;&ES=&4@*'!O=7(@;&5S(&QI<W1E<R!N=6WI<FEQ=65S*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H
M<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`BSFQE<R!#:')I<W1M87,B"@HC.B!L
M:6(O5D93+G!H<#HY,3,@;&EB+TYE="]335,N<&AP.C(Y-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`B1.EF:6YI=&EO;B!D92!L82!C;&%S<V4@9&4@)7,@;F]N('1R
M;W5VZ64N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(D5F9F%C97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#
M;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(DYE='1O>65R(&QE<R!B86QI
M<V5S($U3+4]F9FEC92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G
M:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(D5F9F%C97(@;&$@<F5Q=>IT92(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")2971I
M<F5R(&PG=71I;&ES871E=7(Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D5F
M9F%C97(@;"=U=&EL:7-A=&5U<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B
M169F86-E<B!L97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L
M96%R:6YG($QA=&4B"FUS9W-T<B`BR6-L86ER8VEE<R!T87)D(&1A;G,@;&$@
M:F]U<F[I92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")#
M;&EQ=65R('!O=7(@<&]U<G-U:79R92(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10
M(@IM<V=S='(@(D-L:6-K871E;&P@=FEA($A45%`B"@HC.B!S97)V:6-E<R]K
M97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*
M;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")&97)M97(@;&$@9F5NZG1R
M92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B
M"FUS9W-T<B`B3G5A9V5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(").
M=6%G97,@;6%T:6YA=7@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(DYU86=E=7@B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T
M"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("+.;&5S
M($-O8V]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")297!L:65R(&QA(&)A
M<G)E(&1E(&/T=.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*
M;7-G<W1R(")2Z61U:7)E(&QE<R!B;W)D<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM
M<V=S='(@(D-O;&]M8FEE(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S
M='(@(D-O=6QE=7(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3`P(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*
M(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K
M97(B"FUS9W-T<B`B4&%L971T92!D92!C;W5L975R<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#,U"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S
M='(@(E/I;&5C=&EO;B!D)W5N92!C;W5L975R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM
M<V=S='(@(D-O;'.@.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.34P"FUS
M9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(E1I=')E<R!D92!C;VQO;FYE
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M
M:6-S(@IM<V=S='(@(D(N1"XB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*
M;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M;6%N9&4B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B
M0V]M;6%N9&4@<VAE;&PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B0V]M;65N=&%I<F4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B3F]M('5S=65L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T
M<B`B0V]M;W)E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(E-O8VGI=.DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G
M<W1R(")/<F1I;F%T975R<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")#;VYD:71I;VXB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N
M<R(*;7-G<W1R(")#;VYD:71I;VYS(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T
M<B`B1&EF9NER96YC97,@9&4@8V]N9FEG=7)A=&EO;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y
M;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS
M9W-T<B`B(@HB4WEN8VAR;VYI<V%T:6]N(&1E<R!A<W-I<W1A;G1S('!E<G-O
M;FYE;',L(#Q)/G-M87)T<&AO;F5S/"])/B!E="!/=71L;V]K+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(DQA(&-O;F9I9W5R871I;VX@;B=E
M<W0@<&%S(.`@:F]U<BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")#
M;VYF:6=U<F5R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")#;VYF
M:7)M97(@;&4@;6]T(&1E('!A<W-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B
M0V]N9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE(@IM<V=S='(@(E+I<'5B;&EQ=64@9.EM;V-R871I<75E(&1U($-O
M;F=O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9#H@(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;J`Z
M("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G
M<W1R(")#;VYN97AI;VX@874@<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@<F5F
M=7/I92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B0V]N;F5X
M:6]N(&%U('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC(')E9G5SZ64N(%)A:7-O
M;J`Z("`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@V-0IM<V=I9"`B
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BR6-H
M96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@1E10(@H*(SH@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@
M(D-O;G1A8W1S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D-E<R!C;VYT86-T<R!O
M;G0@8FEE;B#I=.D@86IO=73I<R#@('9O=')E(&-A<FYE="!D)V%D<F5S<V5S
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED
M(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B
M5'EP92!D92!C;VYT96YU(&1U(&9I8VAI97(@8V]M<')E<W/IH#H@(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@
M7"(E<UPB(@IM<V=S='(@(D-O;G1E;G4@9&4@JZ`E<Z"[(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")0;W5R<W5I=G)E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(LYL97,@0V]O:R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S
M='(@(E3I;6]I;B`H8V]O:VEE*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G
M<W1R(")#;W!I97(B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("+)8VAE8R!D
M92!L82!C;W!I9:`Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T
M<B`B4^EL96-T:6]N(&0G=6YE(&-O<&EE(@H*(SH@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C$W,"!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS
M9VED(")#;W-T($E$(@IM<V=S='(@(DED+B!C;_MT(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@
M4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER
M92(*;7-G<W1R(")#]'1E(&0G279O:7)E(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G93H@(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8VAI9F9R97(@;&4@;65S
M<V%G9:`Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-34*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B4VEG
M;F%T=7)E(%!'4"!D=2!M97-S86=E(&EM<&]S<VEB;&6@.B`B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O
M34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@
M8VAI9F9R97(@;&4@;65S<V%G92!A=F5C(%,O34E-12XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(E-I9VYA='5R92!3+TU)344@9'4@
M;65S<V%G92!I;7!O<W-I8FQE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(")!:F]U="!D=2!C;VYT86-T("5S
M(&EM<&]S<VEB;&4N("(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HY
M-B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").92!P975T('-E(&-O
M;FYE8W1E<B!A=2!S97)V975R($Q$05`N(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V
M97(B"FUS9W-T<B`B3F4@<&5U="!S92!C;VYN96-T97(@874@<V5R=F5U<B!,
M1$%0(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T
M<B`B5NER:69I8V%T:6]N(&1E(&QA(&)A;&%N8V4@)7,@:6UP;W-S:6)L92X@
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`BR6-H96,@9&4@
M;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@3$1!4"(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T
M<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@JZ`E<Z"[('9I
M82!&5%"@.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B0W+I871I;VX@9&4@;&ES
M=&4@9&4@9&ES=')I8G5T:6]N(&EM<&]S<VEB;&4N("5S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$Z("(*;7-G<W1R("));7!O<W-I8FQE(&1E(&3I8VAI9F9R
M97(@;&5S(&1O;F[I97,@4$=0H#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D
M871A+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&3I8VAI9F9R97(@;&5S(&1O
M;F[I97,@4R]-24U%+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<R(*;7-G<W1R(").92!P975T('!A<R!S=7!P<FEM97(@
M;&4@8V]N=&%C="`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F4@<&5U="!P87,@
M<W5P<')I;65R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R(").92!P975T('!A<R!S=7!P<FEM97(@;&4@<V-R:7!T(&1E
M(&UI<V4@X"!J;W5R(*N@)7.@NRXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@
M(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+B(*;7-G<W1R(")$Z71E<FUI;F%T:6]N(&1E(&PG861R97-S92!D
M=2!D97-T:6YA=&%I<F4@:6UP;W-S:6)L92XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").92!P975T('+I8W5P
MZ7)E<B!T;W5T(&QE(&-A<FYE="!D)V%D<F5S<V4N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").92!P
M975T('+I8W5PZ7)E<B!T;W5T92!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R
M:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3B=A('!A<R!P=2!RZ6-U<.ER97(@
M;&$@;&ES=&4@8V]M<&SH=&4@9&4@;&ES=&5S(&1E(&1I<W1R:6)U=&EO;BXB
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A
M=&5G>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8VAA<F=E<B!L
M82!S=')A=.EG:64@JZ`E<Z"[+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R
M("));7!O<W-I8FQE(&1E(&-RZ65R(&QE('+I<&5R=&]I<F4@JZ`E<Z"[+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B26UP;W-S:6)L92!D)V]B=&5N:7(@;&$@8VQE9B!P=6)L:7%U92#@
M('!A<G1I<B!D=2!S97)V975R(&1E(&-L969S+B(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I
M;F<N(@IM<V=S='(@(D]U=F5R='5R92!D92"KH"5SH+L@:6UP;W-S:6)L92!E
M;B#I8W)I='5R92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(D]U=F5R='5R92!D
M92`E<R!I;7!O<W-I8FQE+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DEM<&]S<VEB;&4@
M9"=O=79R:7(@;&4@;6]D=6QE($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R(")/=79E<G1U<F4@9'4@9&]S<VEE<B"KH"5S
MH+L@:6UP;W-S:6)L92XB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HU,38@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DEM<&]S
M<VEB;&4@9"=A='1E:6YD<F4@;&4@<V5R=F5U<B!,1$%0+B(*"B,Z(&QI8B]6
M1E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E860@)7,N(@IM<V=S='(@(DQE8W1U<F4@9&4@)7,@:6UP;W-S:6)L
M92X@(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@
M(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"B).)V$@<'4@<F5M971T<F4@X"!ZZ7)O(&QE(&UO="!D92!P87-S92!P
M;W5R(&PG=71I;&ES871E=7(@9&5M86YDZ2X@0V5R=&%I;G,@(@HB*&]U('1O
M=7,I(&QE<R!DZ71A:6QS(&YE('-O;G0@<&%S(&-O<G)E8W1S+B!2Z65S<V%Y
M97H@;W4@8V]N=&%C=&5Z('9O=')E("(*(F%D;6EN:7-T<F%T975R('!O=7(@
M9&4@;"=A:61E+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,#D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#
M3"(*;7-G<W1R(")2Z6-U<.ER871I;VX@9&5S($%#3"!I;7!O<W-I8FQE(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<R(*;7-G<W1R(").92!P975T('+I8W5PZ7)E<B!L92!C87)N970@9"=A
M9')E<W-E<RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F4@<&5U="!RZ6-U
M<.ER97(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@
M)7,B"FUS9W-T<B`B3F4@<&5U="!RZ6-U<.ER97(@;&5S(&QI<W1E<R!D92!D
M:7-T<FEB=71I;VXN("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS
M9W-T<B`B3F4@<&5U="!RZ6-U<.ER97(@;&5S('!O<W-I8FEL:73I<R!D=2!S
M97)V975R(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").92!P
M975T('!A<R!R979E;FER(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E;G1E
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I
M<B!<(B5S7"(N(@IM<V=S='(@(D5F9F%C96UE;G0@9'4@9&]S<VEE<B"KH"5S
MH+L@:6UP;W-S:6)L92X@(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F4@<&5U="!P87,@96YR96=I<W1R97(@
M;&$@8V]N9FEG=7)A=&EO;B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(").92!P
M975T('!A<R!E;G)E9VES=')E<B!U;F4@<V%U=F5G87)D92!D92!L82!C;VYF
M:6=U<F%T:6]N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXZ("5S(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=E;G)E9VES=')E
M<B!U;F4@8V]P:64@9&4@;&$@8V]N9FEG=7)A=&EO;J`Z("5S(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R(&QE('-C<FEP
M="!D92!M:7-E(.`@:F]U<B!D86YSH#H@JZ`E<Z"[+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM
M<V=S='(@(DEM<&]S<VEB;&4@9"=E;G)E9VES=')E<B!U;F4@8V]P:64@9'4@
M9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@
M;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E
M:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RXB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R
M(&QE(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RX@5F]U<R!P;W5V97H@
M<V]I="`B"B)U=&EL:7-E<B!U;F4@9&5S(&]P=&EO;G,@<&]U<B!S875V97(@
M;&4@8V]D92!S=7(@)7,@<V]I="!C;W!I97(@;6%N=65L;&5M96YT("(*(FQE
M(&-O9&4@8VDM9&5S<V]U<R!D86YS("5S+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N(@IM<V=S='(@(DYE('!E=70@<&%S(')E8VAE<F-H97(@;&4@
M<V5R=F5U<B!,1$%0+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!D
M92"KH"5SH+L@:6UP;W-S:6)L92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B36ES92#@(&IO=7(@9'4@
M8V]N=&%C="!I;7!O<W-I8FQE+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F4@
M<&5U="!M971T<F4@X"!J;W5R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@
M)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B3F4@<&5U="!P87,@96YR96=I<W1R97(@;&$@
M8V]N9FEG=7)A=&EO;B!P;W5R(*N@)7.@NZ`Z("5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB
M"FUS9W-T<B`B3F4@<&5U="!T<F]U=F5R(&QA(&)A<G)E(&1E($UO>FEL;&$N
M("!!<W-U<F5Z+79O=7,@<74G96QL92!E<W0@86-T:79E+B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W
M:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@
M(B(*(DYE('!E=70@871T<FEB=65R(&-E<R!D<F]I=',@X"!L)W5T:6QI<V%T
M975R(*N@)7.@NR`@<W5R(&QE(&1O<W-I97(@JZ`E<Z"[H#H@(@HB)7,B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E9"!T97AT
M(@IM<V=S='(@(E1E>'1E(&-O;7!TZ2(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(E!A>7,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S
M(@IM<V=S='(@(D-O=7)S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS
M9W-T<B`B0W+I97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS
M9W-T<B`B0W+I97(@=6X@;&EE;B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`B0W+I97(@=6X@;F]U=F5A=2(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM
M<V=S='(@(D-RZ65R('5N('-O=7,M9&]S<VEE<B(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E!E<FUI<W-I;VYS($1E($-RZ6%T975R(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,R,3D*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G
M<W1R(").=6WI<F\@9&4@8V%R=&4@9&4@8W+I9&ET(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T
M:6$B"FUS9W-T<B`B0W)O871I92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B0W5B
M82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T
M(%!H87-E<R(*;7-G<W1R("(T('!H87-E<R!C;W5R86YT97,B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS
M9W-T<B`B4V5S<VEO;G,@96X@8V]U<G,B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM
M92(*;7-G<W1R(")(975R92!A8W1U96QL92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R
M<F5N="!54DP@:7,B"FUS9W-T<B`B3"=A9')E<W-E(%523"!A8W1U96QL92!E
M<W0B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@
M57-E<G,B"FUS9W-T<B`B571I;&ES871E=7)S(&%C='5E;',B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS
M9W-T<B`B3V)S97)V871I;VYS(&%C='5E;&QE<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B0V]N9&ET:6]N(&%C='5E;&QEH#H@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R
M<F5N="!S='EL92(*;7-G<W1R(")3='EL92!C;W5R86YT(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(D3I9FEN:7(@;&5S('3B8VAE<R#@(&5F9F5C='5E<B!L;W)S(&1E(&QA(&-O
M;FYE>&EO;B#@("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(D-O
M=7!E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B0V]U<&5R(&QA
M('/I;&5C=&EO;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#:'EP<F4B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0WER:6QL:6,@*$M/
M23@M4BDB"FUS9W-T<B`B0WER:6QL:7%U92`H2T])."U2*2(*"B,@8V]N9FEG
M+VYL<RYP:'`N9&ES=#H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G
M:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-Y<FEL;&EQ
M=64@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@
M(D-Y<FEL;&EQ=64O56MR86EN:65N("A+3TDX+54I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@
M4F5P=6)L:6,B"FUS9W-T<B`B4NEP=6)L:7%U92!48VCH<75E(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.2!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B2DHB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S(W,`IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"B)$4TX@*$-F+B!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM
M<V=I9"`B1&%I;'DB"FUS9W-T<B`B0VAA<75E(&IO=7(B"@HC.B!A9&UI;B]D
M871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T
M<B`B3F%V:6=A=&5U<B!D92!$871A5')E92(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,C8X"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B06QI
M87,@9&4@;&$@8F%S92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#`R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E
M(@IM<V=S='(@(D1A=&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")$871E
M(&1E('+I8V5P=&EO;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDV"FUS
M9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")3Z6QE8W1I;VX@9"=U;F4@
M9&%T92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S
M='(@(DIO=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S
M='(@(E-U<'!R:6UE<B!?;&$@8V]L;VYN92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$Z6-E
M;6)R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M(").;VUB<F5S(&3I8VEM875X(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM
M<V=S='(@(D1I;6EN=65R(&PG:6YD96YT871I;VXB"@HC.B!L:6(O<')E9G,N
M<&AP.C$Q-R!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PIM<V=I9"`B1&5F
M875L="(*;7-G<W1R(")$Z69A=70B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*
M;7-G<W1R(")#;W5L975R('!A<B!DZ69A=70B"@HC.B!L:6(O2&]R9&4O261E
M;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@
M(DED96YT:73I('!A<B!DZ69A=70B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B26YT97)P<NET
M975R(&1E(&-O;6UA;F1E('!A<B!DZ69A=70B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D3I9FEN
M:71I;VYS(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C,R-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C0S.2!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@R('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E
M(@IM<V=S='(@(D5F9F%C97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL
M(@IM<V=S='(@(D5F9F%C97(@;&$@8V5L;'5L92(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@
M1W)O=7`B"FUS9W-T<B`B4W5P<')I;65R('5N(&=R;W5P92(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*
M;7-G<W1R(")%9F9A8V5R(&QA('1R86-E(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B
M1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4W5P<')I;65R('5N92!P97)M
M:7-S:6]N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS
M"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E-U
M<'!R:6UE<B!E="!P=7)G97(@;&5S(&UE<W-A9V5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B
M1&5L971E(&-E;&PB"FUS9W-T<B`B169F86-E<B!L82!C96QL=6QE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")%9F9A8V5R(&QA(&-O
M;&]N;F4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")3=7!P
M<FEM97(@=6X@875T<F4@;6]DZ&QE(&5X:7-T86YT(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B4W5P<')I;65R(&QE
M<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NR(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*
M;7-G<W1R("+*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER(&5F9F%C97(@
MJZ`E<Z"[(&5T('-E<R!S;W5S+7!E<FUI<W-I;VYSH#\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@<F]W(@IM<V=S='(@(D5F9F%C97(@;&$@<F%N9^EE(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E-U<'!R:6UE<B!L
M)VED96YT:73I('/I;&5C=&EO;F[I92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")%9F9A8V5R(&QA(&-O;&]N
M;F4@86-T=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!R;W<B"FUS9W-T<B`B169F86-E<B!L82!R86YGZ64@86-T=65L;&4B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B4V-R:7!T(&1E(&-O;F9I9W5R871I;VX@9&4@;6ES92#@(&IO=7(@
M<W5P<')I;>D@JZ`E<Z"[+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y
M-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E
M<GD@=&EM92(*;7-G<W1R(")(975R92!D92!L:79R86ES;VXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$
M96YM87)K(@IM<V=S='(@(D1A;F5M87)K(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(D3I8W)I<F4@;&4@<')O8FSH;64B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.30R('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E
M<V-R:7!T:6]N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1.ET86EL
M<R`H875S<VD@9&%N<R!L92!F:6-H:65R(&1E('1R86-E<R!D92!(;W)D92F@
M.B(*"B,Z(&QI8B](;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("),
M97,@9.ET86EL<R!O;G0@Z73I(&-O;G-I9V[I<R!P;W5R(&PG861M:6YI<W1R
M871E=7(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I
M9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B1.EV96QO<'!E;65N="(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T
M<B`B4&]I;G0@9&4@<F]SZ64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")0
M;VEN="!D92!R;W/I92!P;W5R(&QA(&1E<FYIZ')E(&AE=7)EH#H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O
M:6YT.B`B"FUS9W-T<B`B4&]I;G0@9&4@<F]SZ66@.B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E
M8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")$92!G875C:&4@X"!D<F]I
M=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")$
M92!D<F]I=&4@X"!G875C:&4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(E+I<&5R=&]I<F4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_(@IM<V=S='(@(D%F9FEC:&5R('-U<B`R-"!H975R97.@/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@
M3W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS(&0G869F:6-H86=E(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E
M=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(D%F9FEC:&5R(&QA('!RZ79I<VEO
M;B!DZ71A:6QLZ64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED
M(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(D%F9FEC:&5R(&QA
M('!RZ79I<VEO;B`H5$%&*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`V
M"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")&;W)M870@9"=A9F9I
M8VAA9V4B"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D%V:7,@9&4@;&EV
M<F%I<V]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E
M;&5T92(*;7-G<W1R(").92!P87,@<W5P<')I;65R(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").92!P87,@86-CZ61E<B!D
M:7)E8W1E;65N="#@(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*
M(DQE('!R96UI97(@96YR96=I<W1R96UE;G0@8V]N=&EE;G0M:6P@;&4@;F]M
M(&1E<R!C:&%M<'.@/R!$86YS("(*(FPG869F:7)M871I=F4L(&-O8VAE>B!C
M971T92!B;^YT9:`Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI
M<75E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(E+I<'5B
M;&EQ=64@9&]M:6YI8V%I;F4B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(E9O=7,@;B=A=F5Z('!A<R!D92!C;VUP=&6@/R!%;G)E9VES
M=')E>BUV;W5S+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M-3$*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E3I;.EC:&%R9V5R(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R(")4Z6SI8VAA<F=E<B`E<R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S
M='(@(E3I;.EC:&%R9V5R(&QA(&-O;F9I9W5R871I;VX@9^ENZ7+I92!C;VUM
M92!U;B!S8W)I<'0@4$A0(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*
M;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(DQI<W1E(&3I<F]U;&%N
M=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S
M(@IM<V=S='(@(D1R;V=U97,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")#;W5R<FEE<B#I;&5C=')O
M;FEQ=64B"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS
M9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R
M<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@HB4&EL
M;W1E(&1E('!A<W-E<F5L;&4@8V]U<G)I97(@+R!335,L('!O=7(@;&5S(&9O
M=7)N:7-S975R<R!D92!C92!S97)V:6-E+B(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM
M<V=S='(@(D524B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`BR7%U871E=7(B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,0IM<V=I9"`B161I="(*;7-G<W1R(")-;V1I9FEE<B(*"B,Z(&QI
M8B](;W)D92]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("+)9&ET97(@;&4@
M8FQO8R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(LED:71E<B!U;B!G
M<F]U<&4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<V(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS
M9W-T<B`BR61I=&5R('5N92!P97)M:7-S:6]N(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G
M<W1R("+)9&ET97(@;&5S('!E<FUI<W-I;VYS(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+)9&ET97(@;&5S('!E<FUI<W-I
M;VYS('!O=7(@JZ`E<Z"[(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BR61I=&5R(&QE
M<R!O<'1I;VYS('!O=7*@.B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R("+)9&ET97(@;&5S('!E<FUI<W-I;VYS('!O=7(@
MJZ`E<Z"[(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("+)9&ET97(@;&5S('!E<FUI<W-I;VYS('!O=7(@)7,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R
M("+)9'5C871I;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("+)9WEP=&4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(E-A;'9A9&]R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S
M"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(LELZ6UE;G0N+BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I
M9"`B16TB"FUS9W-T<B`B16TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W
M,R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B
M16UA:6PB"FUS9W-T<B`B061R97-S92#I;&5C=')O;FEQ=64B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B061R97-S
M92#I;&5C=')O;FEQ=64B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV-PIM
M<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(DQE
M<R!A9')E<W-E<R#I;&5C=')O;FEQ=65S(&1O:79E;G0@8V]R<F5S<&]N9')E
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DS"FUS9VED(")%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")#;W5R<FEE<B!A=F5C(&-O;F9I
M<FUA=&EO;B(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*
M;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(E!A<W-E<F5L
M;&4@8V]U<G)I97(@+R!335,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,CDW"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BR6UO
M=&EC]&YE<R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")-97-S86=E('9I
M9&4N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HV-C(@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB
M"FUS9W-T<B`B4NES=6QT870@=FED92XB"@HC.B!L:6(O2&]R9&4O4U%,+TME
M>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G
M<W1R(")497)M97,@9&4@<F5C:&5R8VAE('9I9&4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")!
M8W1I=F5R(&PG:6YS97)T:6]N(&0G:6UA9V5S('9E;F%N="!D97,@86QB=6US
M('!H;W1O<R!D86YS(&QE('1E>'1EH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/R(*;7-G<W1R(")!8W1I=F5R(&QE(&UE;G4@8V]N=&5X='5E;"!A=F5C
M('5N(&-L:6,@9')O:72@/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DR
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#`P"FUS9VED(")%;F0@>65A<B(*;7-G
M<W1R(")&:6X@9&4@;"=A;F[I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM
M<V=S='(@(D%G<F%N9&ER(&PGZ61I=&5U<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B+)8W)I=F5Z('5N92!Q=65S=&EO
M;B!D92!SZ6-U<FETZ2!Q=2=O;B!V;W5S('!O<V5R82!S:2!V;W5S(&1E=F5Z
M(')E;65T=')E(.`@(@HB>NER;R!V;W1R92!M;W0@9&4@<&%S<V4L('!A<B!E
M>&5M<&QE(*L@475E;"!E<W0@;&4@;F]M(&1E('9O=')E(&%N:6UA;"`B"B)P
M<NEFZ7+IH#^@NZ`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4B"FUS9W-T<B`B26YS8W)I=F5Z(&PG861R97-S92!54DP@
M9&4@;"=I;6%G92!I8VDB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#@Y"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB
M"FUS9W-T<B`B16YT<F5Z(&QE<R!L971T<F5S(&-I+61E<W-O=7.@.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G
M:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D=U:6[I92#I<75A=&]R
M:6%L92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`BR7)Y=&ARZ64B"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM
M<V=I9"`B17)R;W(B"FUS9W-T<B`B17)R975R(@H*(SH@;&EB+TAO<F1E+U1E
M;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E
M871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(D5R<F5U<B!L;W)S(&1E(&QA(&-R
MZ6%T:6]N(&1U(&)L;V.@.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")%<G)E=7(@;&]R<R!D92!L82!S
M=7!P<F5S<VEO;B!D92!L)V%N8W)E(&1E('-Y;F-H<F]N:7-A=&EO;J`Z("5S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S
M='(@(D5R<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1U(&IO=7)N86P@
M9&4@<WEN8VAR;VYI<V%T:6]NH#H@)7,B"@HC.B!L:6(O2&]R9&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S(@IM<V=S='(@(D5R<F5U<B!L;W)S(&1E(&QA('+I8W5P
MZ7)A=&EO;B!D=2!C;VYT96YUH#H@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D
M871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D5R<F5U<B!L;W)S(&1E(&QA
M(&UI<V4@X"!J;W5R(&1U(&UO="!D92!P87-S9:`Z("5S(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B17)R975R(&%V96,@;&4@;65S
M<V%G92XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I
M=&EN9R!<(B5S7"(N(@IM<V=S='(@(D5R<F5U<B!L;W)S(&1E(&PG96YR96=I
M<W1R96UE;G0@9&4@JZ`E<Z"[+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B
M17-T;VYI92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(LET:&EO<&EE(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS
M9W-T<B`B171H;FEQ=64B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS
M9W-T<B`B5&]U<R!L97,@)F9R86,Q-#L@9"=H975R92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G
M<W1R(")4;W5T97,@;&5S(#(@;6EN=71E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B
M179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")4;W5T97,@;&5S(#,P('-E8V]N
M9&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T
M<B`B5&]U=&5S(&QE<R`U(&UI;G5T97,B"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("+`(&-H
M87%U92!C;VYN97AI;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T
M"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B5&]U=&5S(&QE<R`F
M9G)A8S$R.R!H975R97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R(")4;W5T97,@;&5S(&UI;G5T97,B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM
M<V=S='(@(D5X96UP;&4@9&4@=F%L975R<Z`Z(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<@861M:6XO<&AP<VAE
M;&PN<&AP.C@Q"FUS9VED(")%>&5C=71E(@IM<V=S='(@(D5XZ6-U=&5R(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B1.EV96QO<'!E<B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@
M(D3I<&QI97(@;&$@8F%R<F4@9&4@8_1TZ2(*"B,Z(&QI8B](;W)D92]344PO
M2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@
M(JL@*2"[(&%T=&5N9'5E(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP
M:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E
M87)C:"!T97)M(@IM<V=S='(@(E5N('-E=6P@;6]T(&]U(&5X<')E<W-I;VX@
M96YT<F4@9W5I;&QE;65T<R!A='1E;F1U<R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@
M(D1A=&4@9"=E>'!I<F%T:6]N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(E)E<'+I<V5N=&%N
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D-O=6QE=7(@9"=A
M=F%N="UP;&%N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I
M9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")4Z6SI8VAA<F=E;65N
M="!V97)S(&QE('-E<G9E=7(@9&4@;&$@8V]N9FEG=7)A=&EO;B!P87(@1E10
M(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B3&5C='5R92!D
M97,@<'+I9NER96YC97,@:6UP;W-S:6)L92XB"@HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3@*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("+)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!,1$%0+B(*"B,Z
M(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C
M;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O
M;FYE>&EO;B!A=2!S97)V975R(%--0BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M-S`V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@
M7"(E<UPB+B(*;7-G<W1R("+)8VAE8R!D92!L82!C;W!I92!D97!U:7,@JZ`E
M<Z"[+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("+)8VAE
M8R!D92!L82!C;W!I92!V97)S(""KH"5SH+LN(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!C<NEE<B!U
M;F4@;F]U=F5L;&4@8V]N;F5X:6]N(%-!4TPB"@HC.B!L:6(O5D93+W-M8BYP
M:'`Z-3`Q(&QI8B]61E,O9G1P+G!H<#HW-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("+)8VAE8R!D
M=2!DZ7!L86-E;65N="!V97)S(*N@)7.@NRXB"@HC.B!L:6(O5D93+W-M8BYP
M:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V
M93H@)7,B"FUS9W-T<B`BR6-H96,@;&]R<R!D92!L82!RZ6-U<.ER871I;VZ@
M.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$X"FUS9VED(")&86ER(@IM<V=S='(@(D)E874B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`BSFQE<R!&86QK;&%N9"`H
M36%L;W5I;F5S*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`BSFQE
M<R!&Z7)OZ2(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T
M86P@17)R;W(Z(@IM<V=S='(@(D5R<F5U<B!F871A;&6@.B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS
M9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`B5.ELZ6-O<&EE<R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R
M(")&Z79R:65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@
M(D9E96QS($QI:V4B"FUS9W-T<B`B5&5M<.ER871U<F4@<F5S<V5N=&EE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E
M;',@;&EK93H@(@IM<V=S='(@(E1E;7#I<F%T=7)E(')E<W-E;G1I9:`Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS
M9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")1=65L<75E<R!A=F5R<V5S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G
M:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B475E;'%U97,@8VAU=&5S
M(&1E(&YE:6=E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#@*;7-G:60@
M(D9I96QD(&UA=')I>"(*;7-G<W1R(")-871R:6-E(&1E<R!C:&%M<',B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R,PIM<V=I9"`B1FEG;&5T($-!4%1#
M2$$B"FUS9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S,R-PIM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B4&]L:6-E
M(&1E(&QA(#Q)/F9I9VQE=#PO23XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I
M9&II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M(")&:6QE(@IM<V=S='(@(D9I8VAI97(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@
M(DYO;6)R92!D92!F:6-H:65R<Z`Z("5S(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T
M<B`B3F]M8G)E(&1E(&9I8VAI97)SH#H@)7,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B
M1V5S=&EO;FYA:7)E(&1E(&9I8VAI97)S(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G
M:60@(D9I;&4@3F%M92(*;7-G<W1R(").;VT@9'4@9FEC:&EE<B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3@T"FUS9VED(")&:6QE('-E;&5C=&EO;B(*
M;7-G<W1R(")#:&]I>"!D92!F:6-H:65R(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T.3`*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E3I;.EC:&%R
M9V5M96YT(&1E(&9I8VAI97(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.#@U"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B3"=E;G9O:2!D92!F:6-H:65R<R!N)V5S="!P87,@<')I<R!E;B!C;VUP
M=&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&
M:6QT97)S(@IM<V=S='(@(D9I;'1R97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S
M='(@(D9I;FQA;F1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I
M9"`B1FER<W0@2&%L9B(*;7-G<W1R(")0<F5M:>AR92!D96UI92(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G
M:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B4')E;6EE<B!Q=6%R=&EE<B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-34*;7-G
M:60@(D9I>"!R871I;R(*;7-G<W1R(")&:7AE<B!L92!R871I;R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S`*;7-G:60@(D9L
M:7`B"FUS9W-T<B`B4F5T;W5R;F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS
M9W-T<B`B1FQO='1A;G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(D)R;W5I;&QA<F0B
M"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C,W(&QI8B]61E,O;75S<6PN<&AP.C$P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0B"FUS9W-T<B`B1&]S<VEE<B`E<R!I;F5X:7-T86YT+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O
M;G0@0V]L;W(B"FUS9W-T<B`B0V]U;&5U<B!D92!P;VQI8V4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B3F]U
M<G)I='5R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B4&]U<B!L97,@;F%V:6=A
M=&5U<G,@;F4@<W5P<&]R=&%N="!P87,@;&5S(&EM86=E<R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G
M<W1R(")0<NEV:7-I;VX@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA
M="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@
M;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN
M(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB2F]U<G,@9&4@<'+I=FES:6]N
M("AN;W1E>B!Q=64@;&5S('!RZ79I<VEO;G,@9F]U<FYI97,@9&]N;F5N="!L
M92!J;W5R(&5T(&QA("(*(FYU:72@.R!U;B!G<F%N9"!N;VUB<F4@:6-I('!E
M=70@9F%I<F4@=6X@8FQO8R!T<NAS(&QA<F=E(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D
M/R(*;7-G<W1R(")6;W5S(&%V97H@;W5B;&GI('9O=')E(&UO="!D92!P87-S
M9:`_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B
M1F]R;7,B"FUS9W-T<B`B1F]R;75L86ER97,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B0VET871I;VXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@
M='EP92(*;7-G<W1R(")4>7!E(&1E(&-I=&%T:6]N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")#:71A
M=&EO;G,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O
M<G1U;F5S(#(B"FUS9W-T<B`B0VET871I;VYS(#(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R
M=6US(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B
M1F]R=V%R9',B"FUS9W-T<B`B4F5D:7)E8W1I;VXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G
M<W1R(")692(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")#861R97,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N
M(@IM<V=S='(@(D9R86YC92!MZ71R;W!O;&ET86EN92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC
M:"!'=6EA;F$B"FUS9W-T<B`B1W5Y86YE(&9R86[G86ES92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&
M<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!O;'ENZ7-I92!F<F%NYV%I<V4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R
M(")497)R97,@875S=')A;&5S(&5T(&%N=&%R8W1I<75E<R!F<F%NYV%I<V5S
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G
M:60@(D9R;VTB"FUS9W-T<B`B1&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O
M;2!T:&4@(@IM<V=S='(@(D1U("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@
M(D1E<V-R:7!T:6]N(&-O;7!LZ'1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*
M;7-G<W1R(")0;&5I;F4@;'5N92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED
M(")&=6QL($YA;64B"FUS9W-T<B`B3F]M(&-O;7!L970B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O
M;B(*;7-G<W1R(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B06QB=6T@9"=O<FEG:6YE(&1E
M(&PG:6UA9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@
M(D%L8G5MH#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEE(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D?I;NER97(@
M;&$@8V]N9FEG=7)A=&EO;B!D92`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G
M<W1R(")#;V1E(&?I;NERZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1^EO
M<F=I92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B06QL96UA9VYE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B1VEB<F%L=&%R(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B4'+I;F]M(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@
M(D%L;&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")'
M;V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S
M='(@(D-A<G1E<R!';V]G;&4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(E)E8VAE<F-H92!'
M;V]G;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,V"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B3FEV96%U(&1E(&=R:7,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=RZ&-E(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G
M<W1R(")'<F5C("A)4T\M.#@U.2TW*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G
M<W1R(")'<F_K;FQA;F0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA
M9&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VX@9&5S(&=R;W5P
M97,B"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y(@IM<V=S='(@(DQE<R!N;VUS(&1E(&=R;W5P92!N92!P975V96YT
M('!A<R#J=')E('9I9&5S(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B(@HB1W)O=7!?;&1A<*`Z(&EM<&]S<VEB;&4@9"=A:F]U
M=&5R(&QE(&=R;W5P92`E<RX@0V5C:2!E<W0@;&$@<NEP;VYS92!D=2`B"B)S
M97)V975RH#HB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$X(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD
M87"@.B!S=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&=R;W5P92`E<R(*"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,S@@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD
M87"@.B!M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D=2!G<F]U<&4@)7,B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I
M9"`B1W)O=7!S(@IM<V=S='(@(D=R;W5P97,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E
M(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'
M=6%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM
M<V=S='(@(D=U97)N97-E>2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W-I;VYS(&1E<R!I;G9I=.ES
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E
M<W1B;V]K(@IM<V=S='(@(DQI=G)E(&0G;W(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS
M9W-T<B`B1W5I;NEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@
M(D=U:6[I92U":7-S874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA
M;F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM
M<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T
M<B`B2%1-3$%R96$@<F5F=7-E(&+J=&5M96YT(&1E('-U<'!R:6UE<B!L82!D
M97)N:>AR92!C96QL=6QE(&1E(&QA(')A;F?I92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@<F5F=7-E(&+J=&5M
M96YT(&1E('-U<'!R:6UE<B!L82!D97)N:>AR92!C;VQO;FYE(&1U('1A8FQE
M874B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!
M<F5A(')E9G5S92!BZG1E;65N="!D92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@
M<F%N9^EE(&1U('1A8FQE874B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H
M<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H96YT:69I8V%T:6]N($A45%`@;F]N('1R;W5VZ64N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R(")(8>]T:2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T
M<B`B06QG;W)I=&AM92!D92!H86-H86=E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B
M0G)U;64@<^AC:&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3(S(&QI8B](
M;W)D92]&;W)M+G!H<#HR.3(Q"FUS9VED(")(96%D97(B"FUS9W-T<B`B16XM
M=.IT92(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q
M"FUS9VED(")(96%D97)S(@IM<V=S='(@(D5N+73J=&5S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(
M96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`BSFQE
M<R!(96%R9"!E="!-8T1O;F%L9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S
M='(@(D]R86=E<R!V:6]L96YT<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@R"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2.EB
M<F5U("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S
M='(@(DAA=71E=7(B"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](
M;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*
M(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS
M9W-T<B`B06ED92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@
M(D%I9&4@<&]U<B!L)^ED:71E=7(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,W-0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%I9&4B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2.EM
M:7-P:.AR92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H
M92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(E9O:6-I(&QE(&3I
M8G5T(&1U(&9I8VAI97*@.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(DAA=71E(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI
M;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")!
M7V-C=65I;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(D-I=.D@9'4@5F%T:6-A;B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,34S.0IM<V=I9"`B2&]M92(*;7-G<W1R(")!8V-U96EL(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*
M;7-G<W1R(")!9')E<W-E('!E<G-O;FYE;&QE(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")2
MZ7!E<G1O:7)E('!E<G-O;FYE;"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E3I
M;.EP:&]N92!P97)S;VYN96PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@
M(DAO;F1U<F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+
M;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(
M;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86*@.B!D;VYNZ65S(%A-3"`E<R!I;G9A;&ED97,@<F5T
M<F]U=NEE<R!D86YS(&QE(&UE<W-A9V4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86*@.B!A=6-U;B!M97-S86=E(&YE(&-O<G)E<W!O;F0@874@
M<W5J970@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8J`Z
M('!A<R!D)V]B:F5T(&1E('1Y<&4@)7,@=')O=7;I(&1A;G,@;&4@;65S<V%G
M92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@)7,@<W5P<')I;>D@
MJZ`E<Z"[(&%V96,@<W5C8^AS(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR
M,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE
M(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@
M(B(*(DAO<F1E+TMO;&%BH#H@;&4@;6]T975R(&0G:6YTZ6=R871I;VX@;NEC
M97-S:71E(&PG97AT96YS:6]N("=D;VUX;6PG(&1E(%!(4"(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z-3`R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D92!C
M<NEE<B!U;B!N;W5V96P@87)B<F4@6$U,('!O=7(@;"=O8FIE="`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D)V5N;&5V97(@
M)7,@JZ`E<Z"[H#H@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T
M<B`B(@HB2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E('+I8W5PZ7)E<B!L
M)VED96YT:69I86YT($U)344@<&]U<B!L82!P87)T:64@9&4@(@HB='EP92`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE
M(&1E('-Y;F-H<F]N:7-E<B`E<R"KH"5SH+N@.B`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E('-Y;F-H<F]N:7-E<B!L
M97,@<&%R=&%G97.@.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,S0P
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8J`Z('!A<G1A9V4@:6YC
M;VYN=2"KH"5SH+LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B
M3&EG;F4@:&]R:7IO;G1A;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B
M"FUS9W-T<B`B4F5M<&QI<W-A9V4@:&]R:7IO;G1A;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ
M;VYT86PZ(@IM<V=S='(@(DAO<FEZ;VYT86R@.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T
M<B`B0V]M;65N="#J=&5S+79O=7,@87)R:7;I(&EC::`_("A35E`@<F%P<&]R
M=&5Z+6QEH"$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B0V]M8FEE;B!D92!C;VQO
M;FYE<R!V;W5L97HM=F]U<R!F=7-I;VYN97*@/R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B0V]M8FEE;B!D92!C:&%M<',@
M*&-O;&]N;F5S*2!Y(&$M="UI;*`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B0V]M8FEE
M;B!D92!R86YGZ65S('9O=6QE>BUV;W5S(&9U<VEO;FYE<J`_(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO;65T87(N
M<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B2'5M:61I=.DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI
M9&ET>3H@(@IM<V=S='(@(DAU;6ED:73IH#H@(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I
M<W1E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")(;VYG<FEE(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W,B!L:6(O2&]R9&4O075T:"]C
M>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+)8VAE8R!L;W)S(&1E
M(&QA(&-RZ6%T:6]N(&1E(&QA(&)O[G1E($E-05"@.B`E<R(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U=&@O8WER<W%L
M+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BR6-H96,@;&]R<R!D92!L82!S
M=7!P<F5S<VEO;B!D92!L82!B;^YT92!)34%0H#H@)7,B"@HC.B!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP
M:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(LEC:&5C(&QO<G,@9&4@
M;&$@8W+I871I;VX@9'4@<75O=&$@<W5R(&QA(&)O[G1E($E-05"@.B`E<R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S(P"FUS9VED("))4"!!9&1R97-S
M(@IM<V=S='(@(D%D<F5S<V4@25`B"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A
M<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")!9')E<W-E($E0(&YO;B!D:7-P;VYI8FQE+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R(")!9')E<W-E
M($E0(&AO<G,@9'4@8FQO8R!#2412(&%L;&]UZ2XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+B(*;7-G<W1R(")6:6]L871I;VX@9&4@8FQO8V%G92!)4"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("))
M7VYSZ7)E<B!R86YGZ64@879A;G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T
M<B`B27-L86YD92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G
M:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B26/T;F5S('-E=6QE;65N="(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26/T;F5S('!O=7(@)7,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E
M>'0B"FUS9W-T<B`B26/T;F5S('!L=7,@=&5X=&4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S
M='(@(DYO;2!D=2!C;VUP=&6@.B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T
M(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@
M=VEN9&]W+B(*;7-G<W1R("(B"B)3:2!L)V%F9FEC:&%G92!N)V5S="!P87,@
M8V]R<F5C="P@)7,@<&]U<B!L)V]U=G)I<B!D86YS('5N92!N;W5V96QL92!F
M96[J=')E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@
M(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T
M($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB4VD@
M=F]U<R!N92!V;WEE>B!A=6-U;B!I8_1N92!E;B!U=&EL:7-A;G0@26YT97)N
M970@17AP;&]R97(L('9O=7,@<&]U=F5Z("(*(F%V;VER(.`@8V]C:&5R(&-E
M='1E(&-A<V4@<&]U<B!DZ7-A8W1I=F5R(&QA('1R86YS<&%R96YC92!D97,@
M4$Y'+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I
M;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B
M"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)3:2!V
M;W5S('9O>65Z(&-E(&UE<W-A9V4@;6%I<R!A=6-U;F4@:6UA9V4L(&PG:6UA
M9V4@<75E('9O=7,@=F]U;&5Z(&5N=F]Y97(@(@HB;F4@<&5U="#J=')E(&%F
M9FEC:.EE('!A<B!V;W1R92!N879I9V%T975R+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I
M9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B07!E<N=U(&1E(&PG:6UA9V6@
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")!9')E<W-E(%52
M3"!D92!L)VEM86=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM
M<V=S='(@(D%D<F5S<V4@55),(&1E(&PG:6UA9V6@.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM
M<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DEM86=E(&1E(&PG
M86QB=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB
M"FUS9W-T<B`B26UA9V4@9&4@;"=A;&)U;:`Z(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$W-C4*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")4Z6SI
M8VAA<F=E;65N="!D)VEM86=E<R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B26UA9V5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T871I;VXL(.ET87!E("5D
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-H86UP
M(&EM<&]R=.F@.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0VAA;7!S(&EM
M<&]R=.ESH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(DEN7W/I<F5R(')A;F?I92!A<'+H<R(*"B,Z(&QI8B](;W)D92]#
M;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+B(*;7-G<W1R(")#;V1E(&0G86-T:6]N(&EN8V]R<F5C="XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED
M("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R
M(").;VT@9"=U=&EL:7-A=&5U<B!E="]O=2!V;W1R92!M;W0@9&4@<&%S<V4@
M:6YC;W)R96-T+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q
M"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYO
M;2!D)W5T:6QI<V%T975R(&]U(&%D<F5S<V4@86QT97)N871I=F4@:6YC;W)R
M96-T+B`@4NEE<W-A>65Z(&]U(&-O;G1A8W1E>B`B"B)V;W1R92!A9&UI;FES
M=')A=&5U<B!S>7-TZ&UE('!O=7(@9&4@;"=A:61E+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E
M87-E($EN9&5N="(*;7-G<W1R(")!=6=M96YT97(@;"=I;F1E;G1A=&EO;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD92(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T
M"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E5T:6QI<V%T975R
M<R!I;F1I=FED=65L<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN
M9&]NZ7-I92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M("));F9O<FUA=&EO;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+B(*;7-G<W1R("),)VEN9F]R;6%T:6]N(&XG97-T('!L=7,@9&ES<&]N:6)L
M92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S
M='(@(DEN<^ER97(@8U]O;&]N;F4@87!RZ',B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@
M(DEN<V5R="!);6%G92(*;7-G<W1R("));G/I<F5R(&EM86=E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(DEN<^ER97(@=6X@=&%B;&5A=2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("));G/I<F5R('5N(&QI96X@
M=V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS
M9W-T<B`B26YSZ7)E<B!?8V]L;VYN92!A=F%N="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YSZ7)E<B!U;F4@;F]U=F5L;&4@8V]L;VYN92!A<'+H<R!L82!C
M;VQO;FYE(&%C='5E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YSZ7)E
M<B!U;F4@;F]U=F5L;&4@8V]L;VYN92!A=F%N="!L82!C;VQO;FYE(&%C='5E
M;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("));G/I<F5R('5N92!N;W5V96QL92!R
M86YGZ64@87!RZ',@;&$@<F%N9^EE(&%C='5E;&QE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YSZ7)E<B!U;F4@;F]U=F5L;&4@<F%N9^EE(&%V86YT(&QA(')A
M;F?I92!A8W1U96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YSZ7)E<B!U
M;B!P87)A9W)A<&AE(&%P<NAS(&QE(&XF;V5L:6<[=60@86-T=65L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R
M96YT(&YO9&4B"FUS9W-T<B`B26YSZ7)E<B!U;B!P87)A9W)A<&AE(&%V86YT
M(&QE(&XF;V5L:6<[=60@86-T=65L(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`B26YSZ7)E<B!U;B!A=71R92!M;V3H;&4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B(@HB26YS8W)I=F5Z('5N92!A9')E<W-E(&1E(&-O=7)R:65R(.`@
M;&%Q=65L;&4@=F]U<R!R96-E=G)E>B!L92!N;W5V96%U(&UO="!D92`B"B)P
M87-S9:`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T
M<B`B26YSZ7)E<B!C96QL=6QE(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T
M(&-E;&P@8F5F;W)E(@IM<V=S='(@(DEN<^ER97(@8V5L;'5L92!A=F%N="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B26YS
MZ7)E<B!C;VQO;FYE(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M
M;B!B969O<F4B"FUS9W-T<B`B26YSZ7)E<B!C;VQO;FYE(&%V86YT(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E
M<G0@;65S<V%G97,B"FUS9W-T<B`B26YSZ7)E<B!L97,@;65S<V%G97,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B
M26YSZ7)E<B!P87)A9W)A<&AE(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("));G/I<F5R('!A<F%G<F%P
M:&4@879A;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S
M='(@(DEN<^ER97(@<F%N9^EE(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T
M(')O=R!B969O<F4B"FUS9W-T<B`B26YSZ7)E<B!R86YGZ64@879A;G0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM
M<V=S='(@(DEN<V-R:79E>B!L82!RZ7!O;G-E(.`@;&$@<75E<W1I;VX@9&4@
M<^EC=7)I=.F@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T
M<B`B26YSZ7)E<B]-;V1I9FEE<B!U;F4@:6UA9V4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O
M36]D:69Y($QI;FLB"FUS9W-T<B`B26YSZ7)E<B]-;V1I9FEE<B!U;B!L:65N
M('=E8B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*
M;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D-RZ61I="!I;G-U9F9I<V%N="!P
M;W5R(&5N=F]Y97(@X"!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B0W+I9&ET(&EN<W5F9FES86YT
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<Y"FUS9VED("));G1E9V5R
M(@IM<V=S='(@(D5N=&EE<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,W
M"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B3&ES=&4@8V]M<&SH=&4B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I
M9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B
M541(("A5<V5R($1A=&$@2&5A9&5R*2!I;G9A;&ED92(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]Z:7`N<&AP.C$V-R!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HQ.30*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS
M9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(D1O;F[I92!:25`@:6YV
M86QI9&4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B
M26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B07!P;&EC871I;VX@:6YV
M86QI9&4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(D=R;W5P92!)
M1"!I;G9A;&ED92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y,2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$V,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S-@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,P,R!L:6(O2&]R9&4O1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E
M9"XB"FUS9W-T<B`B16YV;VD@9&4@9&]N;NEE<R!I;G9A;&ED97,N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B061R97-S92!D
M92!D97-T:6YA=&EO;B!I;G9A;&ED92XB"@HC.B!L:6(O2&]R9&4O0V]M<')E
M<W,O9&)X+G!H<#HQ,#D@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV
M86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")&;W)M870@9&4@9FEC:&EE<B!I
M;G9A;&ED92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U
M"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")#;&5F(&1E
M(&QI8V5N8V4@:6YV86QI9&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B16UP;&%C96UE;G0@:6YD:7%UZ2!I;G9A;&ED92XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV
M86QI9"!M<V=?='EP92XB"FUS9W-T<B`BJVUS9U]T>7!ENR!I;G9A;&ED92XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`BJV%P:5]I
M9+L@:6YV86QI9&4@;W4@;6%N<75A;G0N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+B(*;7-G<W1R(")087)A;>AT<F5S(&EN=F%L:61E<R!O
M=2!M86YQ=6%N=',N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W
M"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0
M97)M:7-S:6]N(&EN=F%L:61E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T
M<B`B260N(&1E('!A<G1E;F%I<F4@:6YV86QI9&4N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T
M(&-O9&4N(@IM<V=S='(@(D-O9&4@9&4@<')O9'5I="!I;G9A;&ED92XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B
M26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B4')O=&]C;VQE(&EN=F%L:61E
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,R!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I
M96YT.B!<(B5S7"(B"FUS9W-T<B`B1&5S=&EN871A:7)E(&EN=F%L:61EH#H@
MJZ`E<Z"[(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#<U(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B
M"FUS9W-T<B`B3V)J970@9&4@<&%R=&%G92!I;G9A;&ED92(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED
M('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")!9')E<W-E('-O=7)C92!I;G9A
M;&ED92XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(D1O;F[I
M92!5;FEC;V1E(&EN=F%L:61E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1A:7)E
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-0IM
M<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("));G9E<G-E<B!L82!S
MZ6QE8W1I;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B27)A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N9&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R
M("+.;&4@9&4@36%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@
M(E1E;7#J=&5S(&ES;VSI97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("))
M<W)AZVPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I
M9"`B27-S=65R(@IM<V=S='(@(LEM971T975R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS
M9W-T<B`B271A;&EQ=64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(DET86QI
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA[W%U92(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.3D@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(DIA;G9I97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(DIA<&%N97-E
M("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P;VYA:7,@*$E33RTR,#(R+4I0
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E
M>2(*;7-G<W1R(")*97)S97DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*
M;W)D86YI92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS
M9VED(")*=6QY(@IM<V=S='(@(DIU:6QL970B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6EN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")*=7-T:69I97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B0V5N=')E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B2G5S=&EF:65R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")!;&EG;F5R(.`@
M9V%U8VAE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B
M06QI9VYE<B#@(&1R;VET92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R
M(")+87IA:VAS=&%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B1V%R
M9&5R(&PG;W)I9VEN86R@/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N
M>6$B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("),92!S97)V975R($ME<F)E<F]S(&$@<F5J973I(&PG875T:&5N=&EF:6-A
M=&EO;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME
M<FYE;"!.97=B:65S(@IM<V=S='(@(D3I8G5T86YT<R!D=2!N;WEA=2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T
M:6]N(@IM<V=S='(@(D-RZ6%T:6]N(&1E(&-L968B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G
M<W1R(")%;7!R96EN=&4@9&4@;&$@8VQE9B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("),;VYG
M=65U<B!D92!L82!C;&5F(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4>7!E(&1E(&-L968B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S
M86=E(@IM<V=S='(@(E5T:6QI<V%T:6]N(&1E(&QA(&-L968B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B3&$@8VQE
M9B!S92!T<F]U=F4@9.EJX"!S=7(@;&4@<V5R=F5U<B!D92!C;&5F<R!P=6)L
M:6,N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S
M(@IM<V=S='(@(D5N9F%N=',B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@
M(DMI<FEB871I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9B(*;7-G<W1R(")#;W+I92!D=2!.;W)D(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED
M(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]RZ64@9'4@4W5D(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DMO<F5A;B`H155#
M+4M2*2(*;7-G<W1R(")#;W+I96X@*$550RU+4BDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I
M="(*;7-G<W1R(")+;W=E[W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T
M<B`B2VER9VAI>FES=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(E!RZ5]S96YT871I;VXB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G
M92(*;7-G<W1R("),86YG=64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B1&5R;FGH
M<F4@9&5M:64B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@
M(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(D1E<FYIZ')E(&UO9&EF
M:6-A=&EO;B!D=2!M;W0@9&4@<&%S<V4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T
M97(B"FUS9W-T<B`B1&5R;FEE<B!Q=6%R=&EE<B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(D1E
M<FYIZ')E(&UI<V4@X"!J;W5RH#HB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S
M='(@(D1E<FYIZ')E(&-O;FYE>&EO;J`Z("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R!F<F]M("5S(@IM<V=S='(@(D1E<FYIZ')E(&-O;FYE>&EO;J`Z("5S(.`@
M<&%R=&ER(&1E("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-`IM<V=I
M9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B1&5R;FGH<F4@8V]N;F5X
M:6]NH#H@:F%M86ES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T=&]N
M:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*
M;7-G<W1R("),;VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")0<NES
M96YT871I;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM
M<V=S='(@(DQA:7-S97(@=FED92!P;W5R(&YE('!A<R!A=F]I<B!D92!B;W)D
M=7)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS
M9VED("),969T(@IM<V=S='(@(D=A=6-H92(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,3`X"FUS9VED("),969T(&AE861E<B(*;7-G<W1R(")%;G3J=&4@
M9V%U8VAE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#0*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(E9A;&5U<G,@9&4@9V%U8VAE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(DYI=F5A
M=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6+I<FEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8GEE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I
M9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")"<G5I;F4@;.EGZ')E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@
M(DQI9VAT(%)A:6XB"FUS9W-T<B`B4&QU:64@;.EGZ')E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT
M(%)A:6X@16%R;'DB"FUS9W-T<B`B4&QU:64@;.EGZ')E('3T="!D86YS(&QA
M(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(E!L=6EE
M(&SI9^AR92!T87)D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@
M(D%V97)S97,@;.EGZ')E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E
M<B(*;7-G<W1R(")0;'5I92!LZ6?H<F4@879E8R!T;VYN97)R92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),
M:6=H="!3;F]W(@IM<V=S='(@(DYE:6=E(&EN=&5R;6ET=&5N=&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B
M3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B079E<G-E(&1E(&YE:6=E(&SI
M9^AR92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM
M97)I8VLB"FUS9W-T<B`B4FEM97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("),:65N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED
M("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3&4@;&EE;B!P;VEN=&4@=F5R
M<Z`Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<B"FUS9W-T<B`B(@HB3&EE(&PG861R97-S92!D92!C;W5R<FEE
M;"#@(&QA('!A9V4@9&4@8V]M<&]S:71I;VX@9'4@;65S<V%G92!E;B!L)V%F
M9FEC:&%N="(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N
M<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3&EE;G,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G
M<W1R(")":7-C=6ET($QI;G5X(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F
M;VQD97(B"FUS9W-T<B`B3&ES=&4@+2!U=&EL:7-A=&5U<B!P975T('9O:7(@
M;&4@9&]S<VEE<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@
M(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(DQI<W1E(&1E<R!B87-E<R!D92!D
M;VYNZ65S(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@
M(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B26YD97@@9&4@;"=A:61E(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B
M"FUS9W-T<B`B069F:6-H97(@;&5S('1A8FQE<R(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(D%R8VAI=F5S(&1E(&QA(&QI<W1E(@H*(SH@;&EB+TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B06ED
M92!D92!L82!L:7-T92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP
M.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("))9"X@9&4@;&$@;&ES=&4B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI
M<W0M3W=N97(B"FUS9W-T<B`B4')O<')IZ71A:7)E(&1E(&QA(&QI<W1E(@H*
M(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T
M+5!O<W0B"FUS9W-T<B`B16YV;VD@X"!L82!L:7-T92(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B
M"FUS9W-T<B`B06)O;FYE;65N="#@(&QA(&QI<W1E(@H*(SH@;&EB+TAO<F1E
M+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E
M(@IM<V=S='(@(D3I<V%B;VYN96UE;G0@9&4@;&$@;&ES=&4B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(LEC:&5C(&1E(&QA(&QI
M<W1E(&1E<R!S97-S:6]N<Z`Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D
M.B`E<R(*;7-G<W1R("+)8VAE8R!D92!L82!L:7-T92!D97,@=71I;&ES871E
M=7)SH#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(DPG869F:6-H86=E(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G,@97-T
M(&3I<V%C=&EVZ2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G
M:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET=.ER871U<F4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("),:71U86YI92(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM
M<V=S='(@(D-H87)G96UE;G0N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B2&5U
M<F4@;&]C86QEH#H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS
M9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B2&5U<F4@970@;&]C86QE
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*
M;7-G<W1R("),:65U(@H*(SH@;&]G:6XN<&AP.C$X-B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D-O
M;FYE>&EO;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM
M<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R(")4
M<F%C92!D92!L82!D97)N:>AR92!S97-S:6]N(&1E('-Y;F-H<F]N:7-A=&EO
M;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@
M(DQO9R!O=70B"FUS9W-T<B`B1.EC;VYN97AI;VXB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(D-O;FYE>&EO
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN
M(%1A<VMS(@IM<V=S='(@(E3B8VAE<R!D92!C;VYN97AI;VXB"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960@8F5C875S
M92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R
M<F5C=&QY+B(*;7-G<W1R("(B"B),82!C;VYN97AI;VX@97-T(')E9G5SZ64N
M($EL(&5S="!P<F]B86)L92!Q=64@=F]T<F4@;F]M(&0G=71I;&ES871E=7(@
M;W4@(@HB=F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(&UA;"!S86ES:2(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY.#@*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`BR6-H96,@9&4@8V]N;F5X:6]N+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S8Y"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B5&5X=&4@
M;&]N9R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V
M92(*;7-G<W1R(")!;6]U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B1F%I8FQE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("),
M971T<F4@9W)E8W%U97,@;6EN=7-C=6QE<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO
M=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&5T=')E(&QA=&EN97,@;6EN
M=7-C=6QE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`B3F]M8G)E(')O;6%I;G,@;6EN=7-C=6QE<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)O=7)G(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y."!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#,V"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B365S<V%G92!D=2!J
M;W5R("A-3U1$*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R("),82!P:>AC92!J;VEN=&4@35,M5$Y%1B!N92!C;VYT
M96YA:70@875C=6YE(&1O;F[I92XB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M(")-4T<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B4NEP=6)L:7%U92!D92!-86/I9&]I;F4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA
M9&%G87-C87(B"FUS9W-T<B`B36%D86=A<V-A<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:64B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS
M9W-T<B`B0V]U<G)I97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N
M(&1U(&-O=7)R:65L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(D9A:7)E('5N(&QI95]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T
M<B`B36%L87=I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA:7-I
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EV97,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T
M<B`B36%L=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@
M(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W
M:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(D%D;6EN:7-T<F5Z
M(&QA(&QI<W1E(&1E(&-A=.EG;W)I97,@970@;&5S(&-O=6QE=7)S(&QIZ65S
M(.`@8V5S(&-A=.EG;W)I97,N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")#
M87)T92"K($UA<#(T(+LB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`X-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(D-A<G1E
M(*L@36%P<75E<W0@NR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")#;W)R97-P
M;VYD86YC97,@96YR96=I<W1RZ65S+B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-87)S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA<F=E(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B36%R<75E<B!A=F5C(&1E<R#I=&EQ
M=65T=&5S(%9U+TYO;B!V=2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N
M($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B36%R<75E<B!A=F5C(&0G
M875T<F5S(.ET:7%U971T97,@*&5X+CH@26UP;W)T86YT+U+I<&]N9'4I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ
M"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(LYL97,@36%R<VAA
M;&PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C
M:&EN9R!F:65L9',B"FUS9W-T<B`B0VAA;7!S(&%P<&%R96YTZ7,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%U<FET:75S(@IM<V=S='(@(LYL92!-875R:6-E(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D
M(&-R961I="XB"FUS9W-T<B`B0W+I9&ET(&UA>&EM=6T@86QL;W7I+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B3&EM:71E(&1U
M(&UE<W-A9V4@9.EP87-SZ64N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")4
M96UPZ7)A='5R92!M87AI;6%L92!D97,@,C0@9&5R;FGH<F5S(&AE=7)E<Z`Z
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UPZ7)A='5R92!M87AI;6%L
M92!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@(@H*(SH@;&EB+V%P:2YP:'`Z
M.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS
M9W-T<B`B3F]M8G)E(&UA>&EM=6T@9&4@8FQO8W,@9'4@<&]R=&%I;"(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HY,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM=6T@;&5N
M9W1H(@IM<V=S='(@(DQO;F=U975R(&UA>&EM=6TB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA:2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
M3>ED:6-A;65N="(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B365M8G)E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS
M9W-T<B`B5'EP92!D92!M96YUH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL
M<R(*;7-G<W1R(")&=7-I;VYN97(@;&5S(&-E;&QU;&5S(@H*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*
M;7-G<W1R(")-97-S86=E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*
M(G9E<FEF:65D+B(*;7-G<W1R("(B"B)6Z7)I9FEC871I;VX@9'4@;65S<V%G
M92!RZ75S<VEE+"!M86ES(&QE(&-E<G1I9FEC870@9'4@<VEG;F%T86ER92!N
M)V$@<&%S('!U("(*(NIT<F4@=NER:69IZ2XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D
M+B(*;7-G<W1R(")-97-S86=E(&5X<&ERZ2XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G
M:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4>7!E(&1E(&UE<W-A9V4B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B
M"FUS9W-T<B`B3>ETZ6\@365T87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("),92!B;&]C(*L@365T87(@NR!N)V5S="!P87,@9&ES<&]N:6)L92XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3&4@8FQO8R"K($UE
M=&%R(+L@;B=E<W0@<&%S(&1I<W!O;FEB;&4N("!,97,@9.ET86EL<R!O;G0@
MZ73I(&-O;G-I9V[I<R!P;W5R("(*(FPG861M:6YI<W1R871E=7(N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$
M0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R(")-971A<D1"(&XG97-T('!A
M<R!C;VYN96-TZ2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(DWI=&AO9&4B"@HC.B!L:6(O2&]R9&4O4E!#+WAM
M;')P8RYP:'`Z.#$@;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*
M;7-G<W1R("),82!MZ71H;V1E(*N@)7.@NR!N)V5S="!P87,@9.EF:6YI92(*
M"B,Z(&QI8B](;W)D92]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*
M;7-G<W1R(")-Z71H;V1E(&YO;B!DZ69I;FEE+B!-Z71H;V1E(&%P<&5LZ66@
M.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O
M0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B3>ET
M<FEQ=64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI<75E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B
MR71A=',@9NEDZ7+I<R!D92!-:6-R;V[I<VEE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D
M;&4B"FUS9W-T<B`B36EL:65U(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5'EP92!-
M24U%(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")496UPZ7)A='5R92!M:6YI
M;75M(&1E<R`R-"!D97)N:>AR97,@:&5U<F5SH#H@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(E1E;7#I<F%T=7)E(&UI;FEM=6T@9&5S(#8@9&5R;FGH<F5S
M(&AE=7)E<Z`Z("(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0S.0IM
M<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E
M9"(*;7-G<W1R("),82!D=7+I92!M:6YI;6%L92!D=2!M;W0@9&4@<&%S<V4@
M;B=A('!A<R!E;F-O<F4@97AP:7+I(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,PIM<V=I9"`B36ER<F]R(@IM<V=S='(@(DUI
M<F]I<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES
M8V5L;&%N96]U<R(*;7-G<W1R(")687)IZ7,B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<R(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S0P"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-3`*
M;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS
M9W-T<B`B3&4@<&%Q=65T86=E($A45%!?<F5Q=65S="!014%2(&5S="!M86YQ
M=6%N="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B
M"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A=&EO;B!I;F5X:7-T86YT92X@5F]U
M<R!D979E>B!L82!GZ6[I<F5R(&UA:6YT96YA;G0@<VD@=F]U<R!V;W5L97H@
M(@HB=71I;&ES97(@8V5T=&4@87!P;&EC871I;VXN(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S
M<V%G92!)1"XB"FUS9W-T<B`B240@9'4@;65S<V%G92!M86YQ=6%N="XB"@HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED
M(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R
M("),92!P87%U971A9V4@4$5!4B!-86EL(&5S="!M86YQ=6%N="XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("))1"!D92!S97-S:6]N(&UA;G%U
M86YT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DQU(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")#
M;W5R<FEE;"!S86YS(&9I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")-;V3I
M<NDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G
M<W1R(")$871E(&1E(&UO9&EF:6-A=&EO;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R(")-;V1I9FEE<B!L)U523"(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@
M(DUO9'5L;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B36]L9&%V:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA8V\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;&EE(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(U.#@*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM
M<V=S='(@(DUO:7,@970@86YNZ64B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DUE;G-U96QL96UE
M;G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B4&AA<V5S(&1E(&QA(&QU
M;F4B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#4U8N<&AP
M.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I
M;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R(")#:&%M
M<',@<W5P<&SI;65N=&%I<F5S('1R;W5VZ7,@X"!L82!L:6=N92`E9"`H871T
M96YD=7,@)60I+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O8R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS
M9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B1^ENZ7)A;&5M96YT(&5N<V]L
M96EL;.DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")'Z6[I<F%L96UE
M;G0@;G5A9V5U>"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B1^ENZ7)A
M;&5M96YT(&5N<V]L96EL;.DB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")697)S(&QE(&)A
M<R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B
M36]V92!,969T(@IM<V=S='(@(D3I<&QA8V5R(.`@9V%U8VAE(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(D3I<&QA8V5R(.`@9')O:71E(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E9E
M<G,@;&4@:&%U="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C,*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")697)S(&QE(&)A
M<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C(@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PIM<V=I9"`B
M36]V92!U<"(*;7-G<W1R(")697)S(&QE(&AA=70B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M
M8FEQ=64B"FUS9W-T<B`B36]Z86UB:7%U92(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B
M"FUS9W-T<B`B3&ES=&5S(&3I<F]U;&%N=&5S(&UU;'1I+6YI=F5A=7@B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I
M9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(D-A<G1E(*N@375L=&EM87`@
M54N@NR(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V"FUS9VED(")-=6QT
M:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B4^EL96-T:6]N(&UU;'1I<&QE(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C
M;W5N="(*;7-G<W1R(")087)A;>ET<F%G92!D=2!C;VUP=&4B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M
M871I;VXB"FUS9W-T<B`B365S(&1O;F[I97,@<&5R<V]N;F5L;&5S(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L
M(@IM<V=S='(@(DUO;B!P;W)T86EL(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D
M:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")0
M<NES96YT871I;VX@9&4@;6]N('!O<G1A:6PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B
M"FUS9W-T<B`B0FER;6%N:64B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(DY/3BP@:F4@;B=A8V-E<'1E('!A<R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0Q,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3F]M(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA
M(@IM<V=S='(@(DYA;6EB:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA
M=7)U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").Z7!A;"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F5T:&5R;&%N9',B"FUS9W-T<B`B4&%Y<RU"87,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R
M;&%N9',@06YT:6QL97,B"FUS9W-T<B`B06YT:6QL97,@;NEE<FQA;F1A:7-E
M<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").
M971S8V%P92!"87-E(%523"(*;7-G<W1R(")54DP@9&4@8F%S92!D92!.971S
M8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED
M(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@9&4@
M<NEV;V-A=&EO;B!D92!L)T$N0RX@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R(")54DP@9&4@;&$@<&]L:71I<75E(&0G02Y#+B!.971S
M8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(")54DP@9&4@<F5N;W5V
M96QL96UE;G0@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B55),(&1E('+I=F]C871I;VX@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE(@IM<V=S='(@(DYO;2!D=2!S97)V975R(%-33"!.971S8V%P92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(D-O;6UE;G1A:7)E
M(&1U(&-E<G1I9FEC870@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP
M92(*;7-G<W1R(")4>7!E(&1U(&-E<G1I9FEC870@3F5T<V-A<&4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM
M<V=S='(@(E+I<V5A=2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DIA;6%I<R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").;W5V96QL92U#86SI9&]N
M:64B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR
M-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=79E;&QE(&-A=.EG
M;W)I92(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q
M(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](
M;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT
M+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@365S<V%G92!T;R`E<R(*;7-G<W1R(").;W5V96%U(&UE<W-A9V4@X"`E
M<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB
M"FUS9W-T<B`B3F]U=F5L;&4@;'5N92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N
M86PI(@IM<V=S='(@(DYO=79E874@;F]M(&1E(&-O;FYE>&EO;B`H9F%C=6QT
M871I9BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO=79E;&QE
M+5KI;&%N9&4B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*
M;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(").;W5V96%U(&UO="!D92!P
M87-S92(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB
M"FUS9W-T<B`B3&4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@97AP:7)E<F$@;&4@
M)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED
M(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("),97,@;F]U
M=F5A=7@@;6]T<R!D92!P87-S92!D:69FZ')E;G0N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I
M;F1O=R`H7V)L86YK*2(*;7-G<W1R(").;W5V96QL92!F96[J=')E("A?8FQA
M;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*
M;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]U=F5L;&5S(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R
M(")&;W)U;7,B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR
M-0IM<V=I9"`B3F5X="(*;7-G<W1R(")3=6EV86YT(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(C0@
M<&AA<V5S('-U:79A;G1E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,S<R(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<V"FUS9VED(").97AT(&]P
M=&EO;G,B"FUS9W-T<B`B3W!T:6]N<R!S=6EV86YT97,B"@HC.B!L:6(O2&]R
M9&4O54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4W5I
M=F%N=#XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E
M<FEA(@IM<V=S='(@(DYI9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(").=6ET(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R(").;VXB
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*(E!A<R!D92!D;VYNZ65S(&1E(&-O
M;F9I9W5R871I;VX@<&]U<B!L97-Q=65L;&5S(&UO;G1R97(@;&5S(&1I9F;I
M<F5N8V5S+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@
M(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N
M(@IM<V=S='(@(E!A<R!D92!S=')A=.EG:64@9&ES<&]N:6)L92!P;W5R(&9A
M:7)E(&1E<R!I;6%G97,@25-/+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS
M9W-T<B`B4&%S(&1E(&=A8F%R:70@96X@=')A:71E;65N="!P87(@;&]T+B(*
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C(T-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N(@IM<V=S='(@(D%U8W5N(&)L;V,@;B=E>&ES=&4@X"!L
M82!P;W-I=&EO;B!D96UA;F3I92(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN
M<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-
M0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")087,@9&4@;F]M(&1E(&-A
M;&5N9')I97(@9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!-
M0T%,+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C
M:&%N9V4N(@IM<V=S='(@(DYO;B!M;V1I9FGI+B(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(")!=6-U;F4@<V]U<RUP
M97)M:7-S:6]N(&XG82!B97-O:6X@9"?J=')E(&%J;W5TZ64@<V]U<R!C92!N
M:79E874N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H<#HU
M,#@@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N(@IM<V=S='(@(D%U8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T
M:6]N('-PZ6-I9FGI92!P;W5R("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX
M-#0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(")!=6-U;F4@:6YF;W)M871I;VX@
M9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE('!O=7(@1E10(%9&4RXB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B075C
M=6YE(&EN9F]R;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R
M(%-13"!61E,N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+B(*;7-G<W1R(")!=6-U;F4@:6YF;W)M871I;VX@9&4@
M8V]N9FEG=7)A=&EO;B!F;W5R;FEE('!O=7(@4U%,+49I;&4@5D93+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").
M;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B075C=6X@8W+I9&ET(&1I<W!O;FEB
M;&4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM
M<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(D%U8W5N
M92!D97-T:6YA=&EO;B!T<F]U=NEE+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,#,*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B075C
M=6X@9FEC:&EE<B!E;G9O>>DB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(")!=6-U;B!I8_1N
M92!T<F]U=NDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q
M-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B
M075C=6X@;&EE=2!N)V5S="!SZ6QE8W1I;VYNZ2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(")!=6-U;B!E;7!L86-E;65N="!N)V5S="!I;F1I<77I
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G
M:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(D%U8W5N(&UE<W-A
M9V4@9F]U<FYI(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(D%U8W5N
M(&YO;2!S<.EC:69IZ2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R
M(")!=6-U;B!N;VUB<F4@<W#I8VEF:>DN(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T
M<B`B4&%S(&0G87!H;W)I<VUE<R!C:&]Q=6%N=',B"@HC.B!L:6(O2&]R9&4O
M075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D%U8W5N(&UO="!D
M92!P87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($A4
M5%`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T
M:&5N=&EF:6-A=&EO;B!P87(@24U!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]K
M<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME
M<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!=6-U;B!M;W0@9&4@
M<&%S<V4@9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!+97)B
M97)O<RXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-R!L:6(O2&]R
M9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H
M<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!=6-U;B!M;W0@9&4@<&%S<V4@<W#I
M8VEF:>D@<&]U<B!L)V%U=&AE;G1I9FEC871I;VXN(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D%U8W5N
M(&UO="!D92!P87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF:6-A=&EO
M;B!005-35T0N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B075C=6X@;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@
M;"=A=71H96YT:69I8V%T:6]N(%--0BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y3
M4TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C
M97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@
M(B(*(D%U8W5N(&-H96UI;B!V97)S(&QE(&)I;F%I<F4@3W!E;E-33"!F;W5R
M;FDN($QE(&)I;F%I<F4@9"=/<&5N4U-,(&5S="`B"B)NZ6-E<W-A:7)E('!O
M=7(@9F]N8W1I;VYN97(@879E8R!D97,@9&]N;NEE<R!02T-3(#$R+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO
M('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B075C=6YE(&-O;F9I<FUA=&EO
M;B!E;B!A='1E;G1E(@H*(SH@;&EB+U9&4RYP:'`Z-S8U"FUS9VED(").;R!Q
M=6]T82!S970N(@IM<V=S='(@(E!A<R!D92!Q=6]T82!P;W-I=&EO;F[I+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(E!A<R!D92!RZ&=L97,B
M"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R
M('-P96-I9FEE9"XB"FUS9W-T<B`B075C=6X@<^EP87)A=&5U<B!S<.EC:69I
MZ2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")087,@9&4@8_1T
MZ7,B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I
M;&4B"FUS9W-T<B`B1FEC:&EE<B!I;F5X:7-T86YT(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")!=6-U;B!R
MZ7!E<G1O:7)E('1E;7!O<F%I<F4@97-T(&1I<W!O;FEB;&4@<&]U<B!L82!C
M86-H92(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(D%U8W5N(&YO;2!D
M)W5T:6QI<V%T975R(&5T("]O=2!M;W0@9&4@<&%S<V4@96YV;WGI+B(*"B,Z
M(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED
M(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(D%U8W5N92!D;VYNZ64@6$U,
M('9A;&ED92!N)V$@Z73I(')E=&]U<F[I92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-S$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDX,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3DR"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B4&%S(&1E('9A
M;&5U<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)087,@9&4@=F5R
M<VEO;B!T<F]U=NEE(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B!O<FEG:6YA;&4N
M(%+I9^ENZ7)E>B!L82`B"B)C;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@
M>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*(E!A<R!D92!V97)S:6]N('1R;W5VZ64@9&%N<R!V;W1R
M92!C;VYF:6=U<F%T:6]N+B!2Z6?I;NER97H@;&$@8V]N9FEG=7)A=&EO;BXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM
M<V=S='(@(D%U8W5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G
M<W1R(")!=6-U;B`H=71I;&ES97(@:6UP;&EC:71E;65N="DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ
M,"DB"FUS9W-T<B`B3F]R9&EQ=64@*$E33RTX.#4Y+3$P*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B
M3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`BSFQE($YO<F9O;&LB"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED
M(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DCI;6ES<&CH<F4@3F]R
M9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@
M(LYL97,@36%R:6%N;F5S(&1U(&YO<F0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G
M<W1R(").;W)VZ&=E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")087,@87!RZ',B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R
M92(*;7-G<W1R(")087,@879A;G0B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C0Q
M,@IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(E!A<R!U;B!D;W-S
M:65R(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").
M;W0@:6UP;&5M96YT960N(@IM<V=S='(@(DYO;B!I;7!LZ6UE;G3I+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G
M:60@(DYO="!S970B"FUS9W-T<B`B26YA8W1I9B(*"B,Z(&QI8B]61E,N<&AP
M.C$Y,R!L:6(O5D93+G!H<#HR,#@@;&EB+U9&4RYP:'`Z,C,S(&QI8B]61E,N
M<&AP.C(U,0HC.B!L:6(O5D93+G!H<#HR-C@@;&EB+U9&4RYP:'`Z,C@T(&QI
M8B]61E,N<&AP.C,P,"!L:6(O5D93+G!H<#HS,34*(SH@;&EB+U9&4RYP:'`Z
M,S,R(&QI8B]61E,N<&AP.C,V-2!L:6(O5D93+G!H<#HT,C4@;&EB+U9&4RYP
M:'`Z-3`T"B,Z(&QI8B]61E,N<&AP.C4W,R!L:6(O5D93+G!H<#HU.3`@;&EB
M+U9&4RYP:'`Z-C8X"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z
M,30U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3<U(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,3@Y"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").;VX@<')I
M<R!E;B!C;VUP=&4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M3F]T97,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G
M:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(")2:65N
M(.`@;F%V:6=U97(L(')E=&]U<FYE>B!E;B!A<G)IZ')E+B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R(").;W9E;6)R92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#4P"FUS
M9VED(").=6UB97(B"FUS9W-T<B`B3F]M8G)E(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S
M='(@(DYO;6)R92!D92!C87)A8W3H<F5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C<@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@
M(DYO;6)R92!D92!C;VQO;FYE<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(").;VUB<F4@
M9&4@<F%N9^EE<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I
M;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYO;6)R92!N;VX@
M<W#I8VEF:>D@<&]U<B!L82!M:7-E(.`@:F]U<B!D92!L82!L:7-T92!D92!D
M:7-T<FEB=71I;VXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S`*;7-G:60@(D]B:F5C
M="(*;7-G<W1R(")/8FIE="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")#<NEA=&5U
M<B!D)V]B:F5T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,#@*;7-G:60@
M(D]C=&%L(@IM<V=S='(@(D]C=&%L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3V-T;V)R92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F
M:6QT97(B"FUS9W-T<B`B1FEL=')E(&%N=&DM;V9F96YS86YT(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S
M='(@(D)U<F5A=2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+B(*;7-G<W1R("),)V%N8VEE;B!E="!L92!N;W5V96%U(&UO=',@9&4@
M<&%S<V4@9&]I=F5N="#J=')E(&1I9F;I<F5N=',N(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS
M9W-T<B`B06YC:65N(&UO="!D92!P87-S92(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C
M;W)R96-T+B(*;7-G<W1R("),)V%N8VEE;B!M;W0@9&4@<&%S<V4@97-T(&EN
M8V]R<F5C="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")3
M975L(&QE<R!S97)V975R<R!)34%0('-U<'!O<G1E;G0@;&5S(&1O<W-I97)S
M('!A<G1A9^ES+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I
M9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B4V5U;&5M96YT
M(&QE<R"KH&9O<G1U;F5SH+L@;V9F96YS86YT97,B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B
M3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")5;F4@
M<V5U;&4@861R97-S92!D92!C;W5R<FEE;"!P97)M:7-E+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T
M<B`B(@HB4V5U;',@;&4@<')O<')IZ71A:7)E(&]U(&PG861M:6YI<W1R871E
M=7(@<WES=.AM92!P975T(&UO9&EF:65R(&QE<R`B"B)P97)M:7-S:6]N<R!D
M)W5N('!A<G1A9V4N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D]U=G)I<B!D86YS('5N92!N;W5V96QL92!F96[J=')E
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*(D5R<F5U<B!/<&5N4U-,H#H@
M:6UP;W-S:6)L92!D)V5X=')A:7)E(&QE<R!D;VYNZ65S(&1E(&QA('!A<G1I
M92!S:6=NZ64@4R]-24U%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]U=G)I<B!L97,@;&EE;G,@
M9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")3
M>7-TZ&UE(&0G97AP;&]I=&%T:6]N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S
M(@IM<V=S='(@(D]P=&EO;G,@<&]U<B`E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES
M="(*;7-G<W1R("),:7-T92!N=6WI<F]TZ64B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@
M(D]R9V%N:7-A=&EO;B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(E5N:73I
M(&]R9V%N:7-A=&EO;FYE;&QE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FES871I
M;VXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B36]DZ&QE(&]R:6=I
M;F%L(&0G87!P;&EC871I;VXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z(@IM<V=S='(@(DUO9.AL97,@;W)I9VEN875X(&1A;G,@)7.@.B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D%U=')E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M871I
M;VXB"FUS9W-T<B`B075T<F5S(&EN9F]R;6%T:6]N<R(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(E!E<FUI<W-I;VYS(&1U('!R;W!R:>ET86ER92(*"B,Z(&QI
M8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),)V%U=&AE;G1I9FEC
M871I;VX@4$%-(&XG97-T('!A<R!D:7-P;VYI8FQE+B(*"B,Z(&QI8B].970O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A
M8VME;F0B"FUS9W-T<B`B36]D=6QE(%!%05(Z.DUA:6PB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B4VEG;F%T=7)E(&YU;>ER:7%U92!01U`B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B1&]N;NEE<R!01U`@8VAI9F9RZ65S(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI
M8R!+97DB"FUS9W-T<B`B0VQE9B!P=6)L:7%U92!01U`B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(D1O;F[I97,@4$=0('-I9V[I97,O8VAI9F9R
MZ65S(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D
M92(*;7-G<W1R(")#;V1E(%!(4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR
M,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(DEN=&5R<'+I=&5U<B!02%`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM
M<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0;'5I92!LZ6?H<F4@;"=A
M<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B079E<G-E<R!L
M)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(").96EG92!L)V%P
M<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D-H=71E
M<R!D92!N96EG92!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(E-O;&5I;"!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B3W)A9V5S(&PG87!RZ',M;6ED:2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM
M<V=S='(@(D5X=&5N<VEO;B!03U-)6"!A8G-E;G1E(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(DEN=&5R<'+I=&5U
M<B!07TA0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")296UP;&ES
M<V%G92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QA=2(*;7-G<W1R(")"96QA=2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S
M=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-T:6YE
M("AT97)R:71O:7)E(&]C8W5PZ2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R
M(")086YA;6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B
M4&%P;W5A<VEE+4YO=79E;&QE+4=U:6[I92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y
M(@IM<V=S='(@(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T
M<B`B4&%R=&EE;&QE;65N="!N=6%G975X(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DY"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P,C(*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W
M;W)D(@IM<V=S='(@(DUO="!D92!P87-S92(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(D-H86YG96UE;G0@9'4@;6]T(&1E('!A<W-E
M(&5F9F5C='7I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R
M,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(DUO="!D92!P
M87-S92!I;F-O<G)E8W0B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP
M.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B36]T(&1E('!A<W-E(')E<75I<R!P;W5R
M(&PG875T:&5N=&EF:6-A=&EO;B!2041)55,N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P-3<*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M(@IM<V=S='(@(DUO="!D92!P87-S92!A=F5C(&-O;F9I<FUA=&EO;B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O
M<F0Z(@IM<V=S='(@(DUO="!D92!P87-S9:`Z(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B
M36]T(&1E('!A<W-EH#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#,X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R("),97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@:61E;G1I<75E
M<RXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S
M=&4B"FUS9W-T<B`B0V]L;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`B0V]L;&5R(&1E<'5I<R!L92!P<F5S<V4M<&%P:65R<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*
M;7-G:60@(E!A=&@B"FUS9W-T<B`B0VAE;6EN(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS
M9W-T<B`B0V]N9FER;6%T:6]N<R!E;B!A='1E;G1EH#HB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")097)S
M;VYN97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0;W5R8V5N=&%G92(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y
M"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T
M<B`B169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")%9F9E
M8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4@X"!L82!C;VYN
M97AI;VZ@/R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED
M(")097)M:7-S:6]N(@IM<V=S='(@(E!E<FUI<W-I;VXB"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI
M<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("),82!P97)M:7-S
M:6]N(*N@)7.@NR!N)V5S="!P87,@<W5P<')I;>EE+B(*"B,Z(&QI8B]61E,O
M<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@
M(E!E<FUI<W-I;VX@<F5F=7/I92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M
M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S:6]N<R(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@
M861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%T:6]N(&1E<R!P97)M:7-S:6]N<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I
M;VXB"FUS9W-T<B`B1&]N;NEE<R!P97)S;VYN96QL97,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E
M<G4B"FUS9W-T<B`B4.ER;W4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-34*;7-G:60@(E!E=',B"FUS9W-T<B`B06YI;6%U>"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI
M;&EP<&EN97,B"FUS9W-T<B`B4&AI;&EP<&EN97,B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T
M<B`B5.ELZ7!H;VYE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(E!H;W1O<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I
M=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G
M<W1R(")0:7AE;',B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G
M:60@(E!L871I='5D97,B"FUS9W-T<B`B4&QA=&ET=61E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G
M:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")35E`@
M8VQI<75E>B!D86YS('5N92!C96QL=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE
M;G0Z(@IM<V=S='(@(E-64"!C;VYF:7)M97H@;&$@<W5P<')E<W-I;VX@9&4@
M8V5T(.ELZ6UE;G2@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R
M(")35E`@8V]N9FER;65Z('%U92!V;W5S('9O=6QE>B!DZ6QI97(@8V5T(.EL
MZ6UE;G0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U-C8*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E9E=6EL
M;&5Z('-A:7-I<B!U;B!M;VES(&5T('5N92!A;F[I92XB"@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T
M<B`B5F5U:6QL97H@<V%I<VER('5N(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A
M=.EG;W)I9:`Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E9E
M=6EL;&5Z(&5N=')E<B!U;F4@861R97-S92!)4"!V86QI9&4N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(V-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N(@IM<V=S='(@(B(*(E9E=6EL;&5Z(&5N=')E<B!U;F4@9&%T92!V86QI
M9&6@.R!VZ7)I9FEE>B!L92!N;VUB<F4@9&4@:F]U<G,@9'4@;6]I<RX@(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E9E=6EL;&5Z(&5N=')E<B!U;F4@
M:&5U<F4@=F%L:61E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2XB"FUS9W-T<B`B5F5U:6QL97H@9F]U<FYI<B!U;B!RZ7-U;>D@
M9'4@<')O8FSH;64N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")6
M975I;&QE>B!F;W5R;FER('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&5T('9O
M=')E(&UO="!D92!P87-S92(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT
M+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*
M(G-Y<W1E;2XB"FUS9W-T<B`B(@HB5F5U:6QL97H@;&ER92!L92!T97AT92!S
M=6EV86YT+B!6;W5S(&1E=F5Z(&%C8V5P=&5R(&QE<R!C;VYD:71I;VYS('!O
M=7(@(@HB=71I;&ES97(@;&4@<WES=.AM92XB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@
M=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")6975I;&QE>B!E;G1R
M97(@;&4@;F]U=F5A=2!N;VV@9&4@;&$@8V%TZ6=O<FEEH#HB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!O;&%N9"(*;7-G<W1R(")0;VQO9VYE(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI=&EQ=64B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL
M<R(*;7-G<W1R(")38W)U=&EN<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S
M='(@(E!O<G1U9V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O
M9B!T:&ES(&EM86=E(@IM<V=S='(@(E!O<VET:6]N(&1E(&-E='1E(&EM86=E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B
M4&]S:71I;VX@9&4@8V4@=&%B;&5A=2(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H
M;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(D5N=F]Y97(@X"!C92!D
M;W-S:65R("AN;VX@87!P;&EQ=>D@<&%R($E-05`I(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R
M*',I.B`B"FUS9W-T<B`B4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@9&5R
M;FGH<F5S(&AE=7)E<Z`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS
M9W-T<B`B4')O8F%B:6QI=.D\8G(@+SYD92!P;'5I92(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L
M9&%PH#H@97AT96YS:6]N(')E<75I<V4@3$1!4"!N;VX@=')O=7;I92XB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;J`Z(&5X=&5N<VEO;B!R97%U:7-E
M(*N@<V5S<VEO;J"[(&YO;B!T<F]U=NEE+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")0<F5S<VEO;B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A
M="!S96$@;&5V96PZ("(*;7-G<W1R(")0<F5S<VEO;B!A=2!N:79E874@9&4@
M;&$@;65RH#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R(")0<F5S<VEO;J`Z("(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D%P97+G=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(D%P97+G=2!D92!L)VEM86=E(&1A;G,@=6YE(&YO=79E;&QE(&9E
M;NIT<F4B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*
M;7-G<W1R(")/<'1I;VYS('!RZ6/I9&5N=&5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C
M=6UE;G0B"FUS9W-T<B`B26UP<FEM97(@;&4@9&]C=6UE;G0B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM
M<V=S='(@(D-L968@<')I=NEE(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V
M.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;.AM92(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO
M;B(*;7-G<W1R(")$97-C<FEP=&EO;B!D=2!P<F]B;.AM92(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S
M='(@(E!R;VIE=',B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-`IM
M<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B5&5X=&4@8V]U<G0B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB
M"FUS9W-T<B`B0VQE9B!P=6)L:7%U92(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G
M<W1R(")!;&=O<FET:&UE(&1E(&-L968@<'5B;&EQ=64B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O
M(@IM<V=S='(@(DEN9F]R;6%T:6]N<R!S=7(@;&$@8VQE9B!P=6)L:7%U92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`BR6-H96,@9&4@;&$@9^ENZ7)A=&EO;B!D92!L82!P86ER92!D
M92!C;&5F<R!P=6)L:7%U92]P<FEVZ64N(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I
M8V\B"FUS9W-T<B`B4&]R=&\@4FEC;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S
M='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1
M=65R>2(*;7-G<W1R(")297%UZG1E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R(")1=6]T82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(D-L968@<'5B;&EQ
M=64@4E-!("@E9"!B:71S*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8X
M"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B4^EL96-T:6]N(')A
M9&EO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B4&QU:64B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L
M>2(*;7-G<W1R(")0;'5I92!T]'0@;&4@;6%T:6XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E
M(@IM<V=S='(@(E!L=6EE('1A<F0@9&%N<R!L82!J;W5R;NEE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A
M:6X@4VAO=V5R(@IM<V=S='(@(D%V97)S97,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO
M=R(*;7-G<W1R(")0;'5I92!E="!N96EG92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B
M"FUS9W-T<B`B4&QU:64@<'5I<R!N96EG92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")!<&AO
M<FES;64@874@:&%S87)D(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G
M:60@(E)A=&EO(@IM<V=S='(@(E1A=7@B"@HC.B!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),:7)E(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D
M(&UE<W-A9V5S(@IM<V=S='(@(DUE<W-A9V5S(&QU<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!DZ69I;FET:79E(&1E("5S
MH#\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@
M=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS
M9W-T<B`B(@HB4W5P<')E<W-I;VX@9.EF:6YI=&EV92!D97,@9&]N;NEE<R!P
M;W5R(&PG=71I;&ES871E=7(@)7.@/R!#971T92!O<.ER871I;VX@(@HB97-T
M(&3I9FEN:71I=F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB
M"FUS9W-T<B`B4F5P<F5N9')E('9O=')E(&1E<FYIZ')E(&%C=&EO;B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(E)A9G)A[F-H:7(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B4F%F<F'N8VAI<B!L97,@
MZ6SI;65N=',@9'4@;65N=2!D>6YA;6EQ=66@.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(E)A9G)A[F-H:7(@;"?I8W)A;B!D=2!S;VUM86ER9:`Z(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q
M-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T
M<B`B17AP<F5S<VEO;B!R871I;VYN96QL92(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,C,X"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R
M(").879I9V%T975R(')E;&%T:6]N;F5L(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P
M.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E)E8VAA<F=E<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(E)E
M;6%R<75E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@
M(E)E;6]T92!397)V97)S(@IM<V=S='(@(E-E<G9E=7)S(&1I<W1A;G1S(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T
M<B`B55),(&1I<W1A;G1E("AH='1P.B\O=W=W+F5X96UP;&4N8V]M+VAO<F1E
M+RF@.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M
M;W9E(@IM<V=S='(@(E)E=&ER97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")2971I
M<F5R(&QE(&)L;V,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34V"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E)E=&ER
M97(@;&$@8V]L;VYN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S
M='(@(E)E=&ER97(@;&4@9F]R;6%T86=E(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E)E
M=&ER97(@;&$@<&%I<F4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R
M"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B16YL979E<B!L92!S8W)I<'0@
M96YR96=I<W1RZ2!D=2!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@9'4@<V5R=F5U
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4F5T:7)E
M<B!L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N="(*;7-G<W1R(")2971I<F5R(&-E(&YO975D(&1U(&1O8W5M
M96YT(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM
M<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B4F5T:7)E<B!L)W5T:6QI<V%T
M975R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")2
M971I<F5R(&PG=71I;&ES871E=7*@.B`E<R(*"B,Z(&QI8B](;W)D92]24$,O
M>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS
M=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(D%U8W5N92!R
MZ7!O;G-E(.`@=F]T<F4@<F5Q=>IT92X@0V]D92!D)V5R<F5U<B!R971O=7)N
MZ:`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G
M:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS
M9W-T<B`B3&4@<V5R=FEC92!D96UA;F3I(&5S="!I;G1R;W5V86)L92XB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$W-B!L:6(O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B),92!P87)A;>AT<F4@
M;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA
M(&-O;F9I9W5R871I;VX@)7,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8W."!L
M:6(O5D93+V9T<"YP:'`Z.#4P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<S,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3&4@<&%R
M86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@
M9&%N<R!L82!C;VYF:6=U<F%T:6]N(&1U("(*(E9&4RXB"@HC.B!L:6(O2&]R
M9&4O571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D
M(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(DQE('!A<F%MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@;B=E<W0@
M<&%S('-PZ6-I9FGI(&1A;G,@;&$@8V]N9FEG=7)A=&EO;BXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&
M:65L9"(*;7-G<W1R(")#:&%M<"!O8FQI9V%T;VER92(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS-#,@;&EB+TAO<F1E+T9O
M<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*
M;7-G:60@(E)E<V5T(@IM<V=S='(@(E+`6B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R
M(")296UI<V4@X"!ZZ7)O(&1U(&UO="!D92!P87-S92(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W
M;W)D(@IM<V=S='(@(E)E;65T=')E(.`@>NER;R!V;W1R92!M;W0@9&4@<&%S
M<V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E
M($QA<W0@475E<GDB"FUS9W-T<B`B4F5V96YI<B#@(&QA(&1E<FYIZ')E(')E
M<77J=&4B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE
M;&PN<&AP.C8V(&%D;6EN+W!H<'-H96QL+G!H<#HW,0IM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R(")2Z7-U;'1A=',B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@
M(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E)E=F5N:7(@875X(&]P=&EO
M;G,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@
M(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B4NDM96YT<F5R(&QE(&YO
M=79E874@;6]T(&1E('!A<W-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R
M(")2Z75N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")2979E;FER(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NEC
MZ61E;G1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D]P=&EO;G,@9&4@
M;"?I9&ET975R(%)I8V@@5&5X="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")$979I;F5T=&5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P
M"FUS9VED(")2:6=H="(*;7-G<W1R(")$<F]I=&4B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$Q,`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(D5N
M=.IT92!D92!D<F]I=&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-@IM
M<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(E9A;&5U<G,@8V]R<F5C=&5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M4')O<')IZ73I<R!D92!L82!R86Y?9^EE("XN+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@
M(E+T;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)O=6UA;FEE(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-`IM<V=I
M9"`B4F]T871E(#$X,"(*;7-G<W1R(")0:79O=&5R(#$X,"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C$*;7-G:60@(E)O=&%T
M92!,969T(@IM<V=S='(@(E!I=F]T97(@X"!G875C:&4B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(W"FUS9VED(")2;W1A=&4@
M4FEG:'0B"FUS9W-T<B`B4&EV;W1E<B#@(&1R;VET92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@
M(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:>ETZ7,@9&4@;&$@<F%N
M9^EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4')O
M<')IZ73I<R!D92!L82!R86YGZ64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B
M4F%N9^EE<Z`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B4NAG;&5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")$97,@9FEL971S(&%P<&%R8>YT
M<F]N="!E;G1R92!T;W5T97,@;&5S(')A;F?I97,@970@;&5S(&-O;&]N;F5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU
M;6YS(&]N;'DB"FUS9W-T<B`B1&5S(&9I;&5T<R!A<'!A<F'N=')O;G0@96YT
M<F4@;&5S(&-O;&]N;F5S('-E=6QE;65N="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(D1E<R!F
M:6QE=',@87!P87)A[G1R;VYT(&5N=')E(&QE<R!R86YGZ65S('-E=6QE;65N
M="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G
M<W1R("),86YC97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS
M9W-T<B`B4G5S<VEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W86YD
M82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4VEG;F%T
M=7)E(.EL96-T<F]N:7%U92!3+TU)344B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(DUE<W-A9V4@8VAI9F9RZ2!3+TU)344B"@HC.B!L:6(O2&]R
M9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),)V%U=&AE;G1I9FEC871I
M;VX@4T%33"!N)V5S="!P87,@9&ES<&]N:6)L92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T
M<B`B365S<V%G97)I92!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*
M;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("));G1E<G!RZ71E=7(@4U%,(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S(*;7-G:60@(E-13"!S=&%T96UE
M;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B3W)D<F4@4U%,('!O=7(@
M<F5T;W5R;F5R(&QE<R!V86QE=7)S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI8B](
M;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I
M9"`B4U5#0T534R(*;7-G<W1R(")354-#R%,B"@HC.B!L:6(O87!I+G!H<#HQ
M-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B26YT97)P<NET975R(%-?
M44PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Q"FUS9VED(")382(*;7-G<W1R(")382(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE
M;&5N82(*;7-G<W1R(")386EN=&4M2.ELZ&YE(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+
M:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I;G0M0VAR:7-T;W!H92UE="U.
M:>EVZ',B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A:6YT92U,
M=6-I92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS
M9W-T<B`B4V%I;G0M4&EE<G)E(&5T($UI<75E;&]N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0M
M5FEN8V5N="UE="UL97,@1W)E;F%D:6YE<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@
M*%]S96QF*2(*;7-G<W1R(")-ZFUE(&-A9')E("A?<V5L9BDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")386UO82(*;7-G<W1R(")386UO82!O8V-I9&5N=&%L97,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")386X@36%R:6YO(@IM<V=S='(@(E-A:6YT+4UA<FEN(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;RU4;VWI+65T+5!R
M:6YC:7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B1F]U<FYI<W-E=7(@<V%T
M96QL:71E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(D%R86)I
M92!386]U9&ET92(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY
M.0IM<V=I9"`B4V%V92(*;7-G<W1R(")%;G)E9VES=')E<B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B16YR96=I<W1R97(@JZ`E<Z"[
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")%;G)E9VES=')E<B`E<R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T
M:6]N<R(*;7-G<W1R(")%;G)E9VES=')E<B!L97,@;W!T:6]N<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB16YR
M96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE(&-O;6UE('5N('-C
M<FEP="!02%`@9&%N<R!L92!RZ7!E<G1O:7)E("(*(G1E;7!O<F%I<F4@9&4@
M=F]T<F4@<V5R=F5U<BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")%;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N(&1E("5S
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B4V-R:7!T(&1E(&UI<V4@X"!J;W5R(&1E(&-O;F9I9W5R
M871I;VX@96YR96=I<W1RZ2!S;W5SH#H@JR`E<Z"[(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E
M9"!4+5-T;W)M<R(*;7-G<W1R(")/<F%G97,@:7-O;.ES(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(E-C
M:65N8V4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H
M(@IM<V=S='(@(E)E8VAE<F-H92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(DUO=&5U
M<G,@9&4@<F5C:&5R8VAE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-C(*
M;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")#:&]I<VES<V5Z(&QE<R!F
M:6-H:65R<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT.#(*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4^EL96-T:6]N
M;F5Z('5N92!D871E(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")3Z6QE
M8W1I;VYN97H@=6X@9W)O=7!E(.`@86IO=71E<B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*
M;7-G<W1R(")3Z6QE8W1I;VYN97H@=6X@;F]U=F5A=2!P<F]P<FGI=&%I<F4B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E
M;&5C="!A('-E<G9E<B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@=6X@<V5R=F5U
M<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")3
M96QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")3Z6QE8W1I;VYN97H@=6X@
M=71I;&ES871E=7(@X"!A:F]U=&5R(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W,PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R
M(")4;W5T('/I;&5C=&EO;FYE<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C4P"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T
M<B`B4^EL96-T:6]N;F5Z('1O=71E<R!L97,@8V]M<&]S86YT97,@9&4@;&$@
M9&%T92XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<P"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(D-H;VES:7-S
M97H@=6X@;V)J970B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<T"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(").92!SZ6QE
M8W1I;VYN97(@875C=6XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*
M;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A
M<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)3Z6QE
M8W1I;VYN97H@;&5S(&-A<F%C=.AR97,@9&]N="!V;W5S(&%V97H@8F5S;VEN
M(.`@;"=A:61E(&1E(&PG;W5T:6P@8VDM(@HB9&5S<V]U<RX@5F]U<R!P;W5V
M97H@96YS=6ET92!L97,@8V]P:65R(&5T(&QE<R!C;VQL97(@9&%N<R!V;W1R
M92!T97AT92XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4^EL96-T
M:6]N;F5Z(&QE(&3I;&EM:71E=7(@9&4@9&%T9:`Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M
M870Z(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@9&%T9:`Z
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM
M<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M(@IM<V=S='(@(E/I;&5C=&EO;FYE<B!L92!P<F]F:6P@<75E('9O=7,@9.ES
M:7)E>B!M;V1I9FEE<CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ
M-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B
M4^EL96-T:6]N;F5Z(&QE(&3I;&EM:71E=7(@9"=H975R9:`Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!F;W)M870Z(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@
M;"=H975R9:`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM
M<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E/I
M;&5C=&EO;FYE>B!D975X(&-H86UP<R!A<'!A<F5N=.ES+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B4^EL96-T:6]N;F5Z('9O=')E('1HZ&UE(&1E
M(&-O=6QE=7)S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G
M:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B
M4^EL96-T:6]N;F5Z('9O=')E(&QA;F=U92!P<NEFZ7+I9:`Z(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O
M8FQE;2!297!O<G0B"FUS9W-T<B`B16YV;WEE<B!L92!R87!P;W)T(&0G86YO
M;6%L:64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B16YV;WEE<B!335,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")396YE9V%L(@IM<V=S='(@(E/I;NEG86PB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V]N
M9&6@.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I
M9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)R92(*"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N
M=&5N96=R;R(*;7-G<W1R(")397)B:64@970@36]N=&5N96=R;R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M
M8F5R(@IM<V=S='(@(DYU;>ER;R!D92!SZ7)I92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DQE<R!D;VYNZ65S(&1U('-E
M<G9E=7(@<V]N="!F875S<V5S(&]U(&YO;B!D:7-P;VYI8FQE<RXB"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS
M9W-T<B`B061M:6YI<W1R871I;VX@9&5S('-E<W-I;VYS(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@
M240@97AP:7)E9"XB"FUS9W-T<B`B260N(&1E('-E<W-I;VX@97AP:7+I+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B
M4V5S<VEO;G,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q.`IM<V=I9"`B
M4V5T(@IM<V=S='(@(E/I;&5C=&EO;FYE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*
M;7-G<W1R("(B"B)#;VYF:6=U<F5R(&QE<R!O<'1I;VYS('!O=7(@=F]U<R!P
M97)M971T<F4@9&4@<F5M971T<F4@X"!ZZ7)O('9O=')E(&UO="!D92`B"B)P
M87-S92!S:2!J86UA:7,@=F]U<R!L)V]U8FQI97HN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM
M<V=S='(@(D-O;F9I9W5R97(@;&5S('-E<G9E=7)S(&1I<W1A;G1S(&%C8V5S
M<VEB;&5S(&1E<'5I<R!V;W1R92!P;W)T86EL+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("(B"B)3
MZ6QE8W1I;VYN97H@=F]T<F4@;&%N9W5E('!RZ6;I<NEE+"!F=7-E874@:&]R
M86ER92!E="!L97,@;W!T:6]N<R!D92!D871E+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)$Z69I;FES
M<V5Z(&QA('!R96UIZ')E(&%P<&QI8V%T:6]N(&QA;F/I92P@;&4@=&CH;64@
M9&4@8V]U;&5U<G,L(&QE("(*(G)A9G)A[F-H:7-S96UE;G0@9&5S('!A9V5S
M+"!E="!D)V%U=')E<R!O<'1I;VYS(&0G869F:6-H86=E+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(D-O
M;F9I9W5R871I;VXB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R(")38W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E(.`@
M:F]U<B!D:7-P;VYI8FQE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET
M:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B4&QU<VEE=7)S(&5N9')O:71S
M('!O<W-I8FQE<R!A=F5C(&QE('!A<F%MZ'1R9:`Z("(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E
M>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(D%C
M:&%T(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G
M:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B4NES=6WI(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(D1O:70M;VX@
M9.EF:6YI<B!D97,@=&]U8VAE<R!D92!R86-C;W5R8VES('!O=7(@;&$@<&QU
M<&%R="!D97,@;&EE;G.@/R(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(S
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(D%F9FEC:&5R(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E
M;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E
M;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)-;VYT<F5R
M(&QE<R!D:69FZ7)E;F-E<R!E;G1R92!L82!C;VYF:6=U<F%T:6]N(&5N<F5G
M:7-T<NEE(&%C='5E;&QE;65N="!E="`B"B)C96QL92!N;W5V96QL96UE;G0@
M9^ENZ7+I92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(DUO;G1R97(@;"=H975R92!D92!L82!D97)N:>AR92!C;VYN97AI;VX@
MX"!L)V5N='+I9:`_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-CD*;7-G
M:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B36]N
M=')E<B!L)V]P=&EO;B!D92!C;VYS97)V97(@;"=O<FEG:6YA;"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.#`R"FUS9VED(")3:&]W('!I8VME<B(*;7-G
M<W1R(")-;VYT<F5R(&QE('/I;&5C=&5U<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU
M(&)A<C\B"FUS9W-T<B`B069F:6-H97(@;&$@8F%R<F4@9&4@;65N=2!D92!T
M86)L96%U>*`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T
M/R(*;7-G<W1R(")!9F9I8VAE<B!L92!M96YU("5S(.`@9V%U8VAEH#\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@
M=&%B;&5A=2!C96QL=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L
M92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")!9F9I8VAE<B!L82!B;^YT
M92!D92!D:6%L;V=U92!D97,@<')O<')IZ73I<R!D=2!T86)L96%U(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S
M('!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE(&1U('1A8FQE874B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*
M;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(D%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P<F]P<FGI
M=.ES(&1E(&PG:6UA9V4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-PIM
M<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B069F:6-H97(@;"=E;G9O:2!D
M92!F:6-H:65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B079E<G-E<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED
M(")3:&]W97)S($5A<FQY(@IM<V=S='(@(D%V97)S97,@=/1T(&1A;G,@;&$@
M:F]U<F[I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B079E<G-E<R!T
M87)D(&5N(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB
M"FUS9W-T<B`B079E<G-E<R!A=7@@86QE;G1O=7)S(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B
M4F5S<V5R<F5R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S<T
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@S-@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HY,C(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z.3@T"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P-#<@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HQ,3$V(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")297-S97)R97(@
M;W4@9.EG86=E<B!D)V%B;W)D(&QE*',I(&)L;V,H<RD@=F]I<VEN*',I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N92(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N
M('5P(@IM<V=S='(@(E,G:6YS8W)I<F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(E-I9VYA
M='5R92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED
M(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71H;64@9&4@
M<VEG;F%T=7)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A
M<&]U<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#$*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3D@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,3(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*;7-G:60@(E-I
M>F4B"FUS9W-T<B`B5&%I;&QE(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B
M"FUS9W-T<B`B06YN=6QE<B!L82!M86EN=&5N86YC92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9A:VEA(@IM<V=S='(@(E-L;W9A<75I92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(E-L;W;I;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B3F5I9V4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM
M<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B079E<G-E(&1E(&YE:6=E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G
M:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")!=F5R<V5S(&1E(&YE:6=E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G
M:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")!=F5R<V5S(&1E(&YE
M:6=E('3T="!D86YS(&QA(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA
M=&4B"FUS9W-T<B`B079E<G-E<R!D92!N96EG92!T87)D(&5N(&IO=7)NZ64B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T
M:#H@(@IM<V=S='(@(DAA=71E=7(@9&4@;F5I9V6@.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A
M=&5R.B`B"FUS9W-T<B`B475A;G1I=.D@9"=E874@Z7%U:79A;&5N=&4@X"!L
M82!Q=6%N=&ETZ2!D92!N96EG9:`Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L
M86YD<R(*;7-G<W1R("+.;&5S(%-A;&]M;VXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(E-O;6%L:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B0VAA;G-O;G,@970@
M<&_H;65S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,34*;7-G:60@(E-O
M<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E/I;&5C=&EO;B!D92!L)V]R
M9')E(&1E('1R:2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,38V(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G
M:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@<V]U<F-E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(D%F<FEQ=64@9'4@<W5D
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(E-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R(")3=60M975R;W#I96X@*$E3
M3RTX.#4Y+3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")'Z6]R9VEE+61U+7-U9"!E
M="#N;&5S(%-A;F1W:6-H+61U+7-U9"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B2.EM:7-P:.AR92!3=60B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")%<W!A8V4@96YT
M<F4@8V5L;'5L97,@861J86-E;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N
M(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(D5S<&%C92!E
M;G1R92!L92!C;VYT96YU(&5T(&QA(&)O<F1U<F4@9&%N<R!U;F4@8V5L;'5L
M92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,3D*;7-G:60@(E-P86-E<B(*
M;7-G<W1R(")%<W!A8V5U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R
M(")%<W!A8V5M96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN
M9R(*;7-G<W1R(")%<W!A8V5M96YT(&5T(')E;7!L:7-S86=E(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E-P86EN(@IM<V=S='(@(D5S<&%G;F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E!O=7)R:65L(@H*
M(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H
M87)A8W1E<B!);G!U="(*;7-G<W1R(")#87)A8W3H<F5S('-PZ6-I875X(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")38VEN9&5R(&QA(&-E
M;&QU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B4V-I
M;F1E<B!L82!C;VQO;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S
M='(@(E-C:6YD97(@;&$@<F%N9^EE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G1S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED
M(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*
M;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD87)D(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B
M4W1A<B!4<F5K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(W.3@*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B
M06YNZ64@9&4@9.EB=70B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`BR71A="!O
M=2!P<F]V:6YC92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A='5T(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,#0*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM
M<V=S='(@(D9O<FUA="!D92!S875V96=A<F1E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S
M='(@(E)U92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B0F%R<NDB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI
M<W0B"FUS9W-T<B`B3&ES=&4@9&4@8VAA[FYE<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#<W"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D
M<F5S<R(*;7-G<W1R(")2971I<F5R(&QE(&1O;6%I;F4@9&4@;"=A9')E<W-E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1Y;&4@6T-3
M4UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8R"FUS9VED(")3=2(*;7-G<W1R(")$:2(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4V]U<RURZ7!E<G1O:7)E(*N@
M)7.@NR!N;VX@=')O=7;I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B4W5J970B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,V(&QI8B](;W)D92]&;W)M+U)E;F1E
M<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R(")%;G9O:2(*"B,Z
M('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@
M87!P<F]V960N(@IM<V=S='(@(B(*(DQA(&1E;6%N9&4@9"=A:F]U="!D92"K
MH"5SH+L@874@<WES=.AM92!A(.ETZ2!S;W5M:7-E+B!6;W5S(&YE('!O=7)R
M97H@<&%S("(*(G9O=7,@8V]N;F5C=&5R(&IU<W%U)^`@<V]N(&%P<')O8F%T
M:6]N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("));F1I8V4B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3`T(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R
M(")3=6-CZ',B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(JN@)7.@NR!A(&)I96X@Z73I(&%J;W5TZ2AE*2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M+B(*;7-G<W1R("),97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T
M975R(*N@)7.@NR!O;G0@8FEE;B#I=.D@<F5T:7+I97,@9'4@<WES=.AM92XN
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE
M=&5D(%PB)7-<(BXB"FUS9W-T<B`BJZ`E<Z"[(&$@8FEE;B#I=.D@<W5P<')I
M;>DH92DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(JN@)7.@NR!A(&)I96X@Z73I(')E=&ERZ2AE*2XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+B(*;7-G<W1R("(B"B)2971O=7(@X"!L82!C;VYF:6=U<F%T:6]N
M(&EN:71I86QE('+I=7-S:2X@(%)A9G)A[F-H:7(@;&$@<&%G92!P;W5R('9O
M:7(@;&5S("(*(FUO9&EF:6-A=&EO;G,N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(D5N<F5G:7-T<F5M96YT(&1E(&QA(&-O;F9I9W5R871I;VX@9&4@;&$@
M<V%U=F5G87)D92!RZ75S<VDN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*
M(D5N<F5G:7-T<F5M96YT('+I=7-S:2!D92!L82!C;W!I92!D92!S875V96=A
M<F1E(&1U(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E(@HB<RXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(JN@)7.@NR!A(&)I96X@
MZ73I(&UI<RAE*2#@(&IO=7(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(LEC<FET=7)E
M(&1E("5S('+I=7-S:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-O=61A
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4V]M;6%I<F4B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM
M<V=S='(@(DQE=F5R(&1U(%-O;&5I;"(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")#;W5C:&5R(&1U(%-O
M;&5I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R(")%;G-O;&5I;&SI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*
M;7-G<W1R("),979E<B!D=2!3;VQE:6PB"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I
M<V4O4W5N<V5T(@IM<V=S='(@(DQE=F5R+T-O=6-H97(@9'4@4V]L96EL(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N
M<FES93H@(@IM<V=S='(@(DQE=F5R(&1U(%-O;&5I;#H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S
M='(@(D-O=6-H97(@9'4@4V]L96EL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B0V]U8VAE
M<B!D=2!3;VQE:6R@.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")%
M>'!O<V%N="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G
M:60@(E-U<'!O<G0B"FUS9W-T<B`B07-S:7-T86YC92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U
M<FEN86UE(@IM<V=S='(@(E-U<FEN86T@;W4@1W5Y86YE(&AO;&QA;F1A:7-E
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U
M<FYA;64B"FUS9W-T<B`B3F]M(&1E(&9A;6EL;&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(LYL97,@4W9A;&)A<F0@970@
M2F%N($UA>65N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W87II
M;&%N9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")3=>AD92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=6ES<V4B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*
M;7-G<W1R(")*;W5R;F%L(&1E('-Y;F-H<F]N:7-A=&EO;B!S=7!P<FEMZ2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*
M;7-G<W1R(")3>6YC34PB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H
M<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G
M<W1R(")%<G)E=7(@9&4@<WEN=&%X92!D86YS(&QE<R!T97)M97,@9&4@<F5C
M:&5R8VAE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T
M<B`B4WER:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")/<F%G97,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B
M5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B3W)A9V4@970@=F5N="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED
M(")4+5-T;W)M<R(*;7-G<W1R(")/<F%G97,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R
M;'DB"FUS9W-T<B`B3W)A9V5S(&UA=&EN875X(@H*(SH@;&EB+TAO<F1E+T1A
M=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(D9I8VAI
M97(@5%-6(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@
M(E1A8FQE(@IM<V=S='(@(E1A8FQE874B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0
M<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:>ETZ7,@9'4@=&%B;&5A=2(*"B,Z
M(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")4
M86)L92!3970B"FUS9W-T<B`B5&%B;&5A=2!D92!V86QE=7)S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM
M<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FGI=.ES(&1U
M('1A8FQE874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@
M(E1A[W=A;B(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*
M;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&'O
M=V%N+"!P<F]V:6YC92!D92!#:&EN92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B5&%J:6MI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>F%N:64B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G
M970Z(@IM<V=S='(@(D-I8FQEH#HB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A
M<VMS(@IM<V=S='(@(E3B8VAE<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(DYU
M;>ER;R!D92!TZ6SI<&AO;F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<.ER
M871U<F4@<&]U<B!L82!D97)N:>AR92!H975R9:`Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")4
M96UPZ7)A='5R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<.ER871U<F6@
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO
M)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<.ER871U<F4\8G(@+SXH)7-(825S
M+R5S0F$E<RD@)F1E9SLE<R(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z
M-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R;V9I;""KH"5SH+L@;F]N('1R;W5VZ2(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B!D97,@;6]DZ&QE
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M
M+G!H<#HS,S(U"FUS9VED(")497AT(@IM<V=S='(@(E1E>'1E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S
M='(@(E1E>'1E('-E=6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S
M='(@(D%L:6=N96UE;G0@9'4@=&5X=&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S
M='(@(E1E>'1E(&5N(&AA=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")*92(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")4:&%I("A425,M-C(P
M*2(*;7-G<W1R(")4:&'O("A425,M-C(P*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD
M(@IM<V=S='(@(E1H8>]L86YD92(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-#`*
M;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(DPG97AT96YS:6]N($944"!N)V5S="!P87,@9&ES<&]N:6)L92XB
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DQE(&UO=&5U<B!D)VEN=.EG
M<F%T:6]N($AO<F1E+TMO;&%B(&YE('-U<'!O<G1E('!A<R"KH"5SH+LB"@HC
M.B!L:6(O3F5T+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@
M;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B3&4@:F]U
M<FYA;"!)35-0(&XG82!P87,@<'4@ZG1R92!I;FET:6%L:7/I+B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R
M("),82!C;&%S<V4@36%I;G1E;F%N8V4Z.B!N)V$@<&%S(.ETZ2!C:&%R9^EE
M(&-O<G)E8W1E;65N="(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D
M+B!%>&ET:6YG+B(*;7-G<W1R("),82!F96[J=')E(&1E<R!O<'1I;VYS(',G
M97-T(&9E<FWI92X@4V]R=&EE+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,3@Y(&QI8B](;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP
M:'`Z,C$Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]0
M97)M<RYP:'`Z,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](
M;W)D92]097)M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS
M9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(DPG861M:6YI<W1R
M871E=7(@9&]I="!C;VYF:6=U<F5R('5N(&)A8VME;F0@<&5R;6%N96YT('!O
M=7(@;&5S('!E<FUI<W-I;VYS("(*(G-I('9O=7,@=F]U;&5Z(&QE<R!E;7!L
M;WEE<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G
M<W1R("),82!B;W)D=7)E(&1U(&)A<R!S975L96UE;G0B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*(DPG240@9'4@8V]N=&%C="!N)V$@<&%S(.ETZ2!S<.EC:69IZ2P@;&%I
M<W/I('9I9&4@;W4@;B=A('!A<R#I=.D@=')O=7;I(&1A;G,@(@HB;&$@8F%S
M92!D92!D;VYNZ65S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D-E(&-O;G1A
M8W0@82!B:65N(.ETZ2!A:F]U=.D@X"!V;W1R92!C87)N970@9"=A9')E<W-E
M<RX@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B
M(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB
M3&4@8FQO8R!D92!S:6=N871U<F4@4$=0('/I<&%RZ2!E<W0@;NEC97-S86ER
M92!P;W5R(';I<FEF:65R(&QA('-I9VYA='5R92XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S
M='(@(B(*(DPG240@9&4@;&$@;&ES=&4@;B=A('!A<R#I=.D@<W#I8VEF:>DL
M(&QA:7-SZ2!V:61E(&]U(&YO;B!T<F]U=ND@9&%N<R!L82`B"B)B87-E(&1E
M(&1O;F[I97,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E
M8VEF:65D+B(*;7-G<W1R("),82!L:7-T92!D92!D:7-T<FEB=71I;VX@;B=A
M('!A<R#I=.D@<W#I8VEF:>EE+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z
M,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("),92!C:&EF9G)E;65N
M="!NZ6-E<W-I=&4@=6YE(&-O;FYE>&EO;B!SZ6-U<FESZ64N(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-S<@;&EB+TAO<F1E+G!H<#HU,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T
M:6YG+B(*;7-G<W1R("),92!F:6-H:65R("5S(&1O:70@8V]N=&5N:7(@;&5S
M(&]P=&EO;G,@)7,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S`@;&EB+TAO<F1E
M+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B3&4@9FEC
M:&EE<B`E<R!D;VET(&-O;G1E;FER(&-E<G1A:6YE<R!O<'1I;VYS("5S+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(S"FUS9VED(")4:&4@9FEL92!C86YN
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("),92!F:6-H:65R
M(&YE('!E=70@<&%S(.IT<F4@8V]P:>D@<W5R(&QU:2UMZFUE+B(*"B,Z(&QI
M8B](;W)D92]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+B(*;7-G<W1R("),92!F:6-H:65R(&YE(&-O;G1E;F%I="!A
M=6-U;F4@9&]N;NEE+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R
M<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")#
M92!Q=6D@<W5I="!S;VYT(&QE<R!E;BUTZG1E<R!P;W5R(&-E(&UE<W-A9V4@
M;65S<V%G92]21D,X,C(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y
M<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G
M;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE
M960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE
M87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@
M9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B),92!M;V1E('!L96EN
M(.EC<F%N(&-A=7-E(&1E<R!P<F]B;.AM97,@879E8R!);G1E<FYE="!%>'!L
M;W)E<B!D^R#@(&1E<R`B"B)B;V=U97,@9'4@;F%V:6=A=&5U<B!Q=6D@;B=O
M;G0@<'4@ZG1R92!C;VYT;W5R;NES+B!6;W5S('!O=79E>B#J=')E("(*(F-O
M;F9R;VYTZ7,@X"!D92!L)V%F9FEC:&%G92!D92!C87)A8W3H<F5S(.ET<F%N
M9V5S+"!A=2!N;VXM9F]N8W1I;VYN96UE;G0@(@HB9&5S(&-E<G1A:6YE<R!F
M;VYC=&EO;G,@970O;W4@874@<&QA;G1A9V4@86SI871O:7)E(&1U(&YA=FEG
M871E=7(N(%-I('9O=')E("(*(G-Y<W3H;64@97-T('5N(%=I;F1O=W,@.7@L
M(&EL(&5S="!T<NAS('!O<W-I8FQE('%U92!V;W5S(&%U<F5Z('5N92`G1F%U
M=&4@(@HB9^ENZ7)A;&4@9&4@<')O=&5C=&EO;B<@970@<75E('9O=7,@9&5V
M<F5Z(')E9.EM87)R97(@=F]T<F4@;W)D:6YA=&5U<BY<7&XB"B)<7&Y6;W5S
M(&%V97H@Z73I('!RZ79E;G5S+B!35E`@87!P=7EE>B!S=7(@3TL@<VD@=F]U
M<R!V;W5L97H@=&]U:F]U<G,@(@HB97-S87EE<B!L92!M;V1E('!L96EN(.EC
M<F%N(&1E(&PGZ61I=&5U<B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(DPG:61E;G1I=.D@JZ`E<Z"[("!A(.ET
MZ2!S=7!P<FEMZ64N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E
M(&]N;'DB"FUS9W-T<B`B3&4@8_1TZ2!G875C:&4@<V5U;&5M96YT(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C
M871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H
M92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB3"=E;7!L86-E;65N
M="!D=2!P<F]G<F%M;64@1VYU4$<@9&]I="#J=')E(&9O=7)N:2#@(&QA(&-L
M87-S92!#<GEP=%]P9W`Z.BXB"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP
M.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES
M<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S
M<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*
M(DQE(&UE<W-A9V4@96YV;WGI(&QE("5S(.`@)7,@879E8R!C;VUM92!S=6IE
M=""KH"5SH+L@82#I=.D@869F:6-HZ2X@7&XB"B));"!N)WD@82!A=6-U;F4@
M9V%R86YT:64@<75E(&-E(&UE<W-A9V4@82#I=.D@;'4@;W4@8V]M<')I<RXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@X,0IM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(DQE(&YO;2#@('5T:6QI<V5R(&5N(&QI86YT(.`@;&$@<&%G92!D92!C
M;VUP;W-I=&EO;B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED(")4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@
M(DQE(&YO;6)R92!D92!C:&%M<',@9&]I="#J=')E('5N(&YO;6)R92!V86QI
M9&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED
M(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("),92!M;V1U;&4@3W!E
M;E-33"!E<W0@<F5Q=6ES('!O=7(@;&$@8VQA<W-E($AO<F1E7T-R>7!T7W-M
M:6UE.CHN(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(DQA('!RZ6;I<F5N
M8V4@JZ`E<Z"[(&XG82!P87,@<'4@ZG1R92!E;G)E9VES='+I92!C87(@<V$@
M=&%I;&QE(&3I<&%S<V4@;&4@(@HB;6%X:6UU;2!A=71O<FESZ2(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D92]-24U%
M+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VUS=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP
M:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+B(*;7-G<W1R("(B"B),92!P<F]G<F%M;64@=71I;&ESZ2!P;W5R('9I<W5A
M;&ES97(@8V4@='EP92!D92!D;VYNZ65S("@E<RD@;B=A('!A<R#I=.D@(@HB
M=')O=7;I+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@
M<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M(@IM<V=S='(@(DQE(&-A<F%C=.AR92!D92!P<F]T96-T:6]N(&1O:70@ZG1R
M92!U;B!C87)A8W3H<F4@=6YI<75E+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(DQE<R!C]'3I<R!G875C
M:&4@970@9')O:70@<V5U;&5M96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DQE(&/T=.D@9')O:70@<V5U;&5M
M96YT(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A
M<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B
M3&4@<^EP87)A=&5U<B!D;VET(.IT<F4@=6X@8V%R86-TZ')E('5N:7%U92XB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("),92!S97)V975R(*N@)7.@NR!A(.ETZ2!S=7!P<FEMZ2XB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB
M"FUS9W-T<B`B3&4@<V5R=F5U<B"KH"5SH+L@82#I=.D@96YR96=I<W1RZ2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*
M;7-G<W1R("),82!R97%UZG1E(&0G96YR96=I<W1R96UE;G0@<&]U<B`E<R!A
M(.ETZ2!DZ7!L86/I92XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("),82!L:6=N92!D96UA;F3I92!N)V5X:7-T92!P87,N(@H*
M(SH@;&EB+U9&4R]S<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("),92!F:6-H:65R('1E;7!O<F%I<F4@JR`E<Z"[(&XG97AI<W1E('!A
M<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P,`IM<V=I9"`B5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+B(*;7-G<W1R("),92!T97AT92!E;G1RZ2!N92!C;W)R97-P;VYD
M('!A<R!A=2!T97AT92!S=7(@;"?I8W)A;BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("),92!H875T(&5T
M(&QE(&)A<R!S975L96UE;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@
M;VYL>2(*;7-G<W1R("),92!H875T('-E=6QE;65N="(*"B,Z(&QI8B](;W)D
M92]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"B),97,@
M9&]N;NEE<R!TZ6SI8VAA<F?I97,@=F5R<R!L92!S97)V975R(&]N="#I=.D@
M<&5R9'5E<R!D97!U:7,@;"?I=&%P92`B"B)P<NECZ61E;G1E+B`B"@HC.B!L
M:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(V,B!L:6(O2&]R9&4O1&%T82]T<W8N
M<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R("),92!F:6-H:65R(.EM:7,@;B=A('!A<R!P=2#J
M=')E(&5N<F5G:7-T<NDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@
M(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("),92!B;&]C(*N@=V5A=&AE<BYC;VV@NR!N)V5S="!P87,@9&ES<&]N
M:6)L92XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")2Z7!E<G1O:7)E(&1E<R!T:.AM97,@JZ`E<Z"[(&YO;B!T
M<F]U=NDB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("));"!N
M)WD@82!P87,@9"=O<'1I;VYS(&1I<W!O;FEB;&5S(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D%U
M8W5N92!P87)T:64@;F4@<&5U="#J=')E(&%F9FEC:.EE(&5N(&QI9VYE+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`U"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B));"!Y("!A
M('1R;W`@9&4@8V%R86-TZ')E<R!D86YS(&-E(&-H86UP+B!6;W5S(&5N(&%V
M97H@96YT<ND@)7.@.R!I;"!E;B!F875T("(*(FUO:6YS(&1E("5S+B(*"B,Z
M('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O
M('1H92!S>7-T96TZ("5S(@IM<V=S='(@(E5N('!R;V)LZ&UE(&5S="!A<'!A
M<G4@;&]R<R!D92!L)V%J;W5T(&1E(*N@)7.@NZ`Z("5S(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB56X@<')O8FSH;64@97-T(&%P<&%R
M=2!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E<R!D;VYNZ65S(&1E(&PG=71I
M;&ES871E=7(@(@HBJZ`E<Z"[H#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M
M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(E5N('!R
M;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D92"K
MH"5SH+N@.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(E5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L
M82!M:7-E(.`@:F]U<B!D92"KH"5SH+N@.B`E<R(*"B,Z(&QI8B](;W)D92]"
M<F]W<V5R+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+B(*;7-G<W1R("(B"B)5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO
M<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65RH#H@875C=6X@)7,@;B=A(.ETZ2`B
M"B)T<F%N<VUI<RXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*(E5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O:2!D
M=2!F:6-H:65RH#H@;&4@)7,@Z71A:70@<&QU<R!G<F]S("(*(G%U92!L92!M
M87AI;75M(&%U=&]R:7/I("@E9"!O8W1E=',I+B(*"B,Z(&QI8B](;W)D92]"
M<F]W<V5R+G!H<#HY,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB56YE(&5R
M<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@
M.B!L92`E<R!A(.ETZ2!T<F%N<VUI<R`B"B)P87)T:65L;&5M96YT+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M="(*;7-G<W1R("(B"B)5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@
M9&4@;"=A9F9I8VAA9V4@9&4@8V5T=&4@<&%R=&4@9'4@;65S<V%G92(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B
M"B)5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A
M=&EO;B!D97,@9&]N;NEE<R!D92!C92!C;VYT86-T+B(*"B,Z(&QI8B](;W)D
M92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("(B"B)5;F4@
M97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D
M92!C971T92!C87)T92!I0V%L96YD87(N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(DEL('D@879A:70@=6YE
M(&5R<F5U<B!D86YS(&QE(&9O<FUU;&%I<F4@9&4@8V]N9FEG=7)A=&EO;BX@
M4&5U="WJ=')E(&%V97HM(@HB=F]U<R!L86ES<^D@=6X@8VAA;7`@<F5Q=6ES
M('9I9&4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@<R=E<W0@
M<')O9'5I=&4@;&]R<R!D92!L)V5XZ6-U=&EO;B!D92!C971T92!F;VYC=&EO
M;B!D=2!C87)N970@(@HB9"=A9')E<W-E+B!35E`@97-S87EE<B#@(&YO=79E
M874@<&QU<R!T87)D+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"B));"!Y(&$@974@=6YE(&5R<F5U<B!L;W)S(&1E(&QA
M(&UI<V4@X"!J;W5R(&1E<R!I;F9O<FUA=&EO;G,@<W5R(&QE("(*(F-O;G1A
M8W0N("!6975I;&QE>B!E<W-A>65R(.`@;F]U=F5A=2XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*(DEL('D@82!E=2!U;F4@97)R975R(&QO<G,@
M9&4@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N
M+B`@(@HB5F5U:6QL97H@97-S87EE<B!D92!N;W5V96%U+B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!
M4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM
M<V=S='(@(DQE('!RZ7-E;G0@<V5R=F5U<B!)34%0(&YE('-U<'!O<G1E('!A
M<R!L92!P87)T86=E(&1E(&1O<W-I97)S+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("+'82!N92!S
M96UB;&4@<&%S(.IT<F4@=6YE(&%R8VAI=F4@4D%2('9A;&ED92XB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T
M<B`BQV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&9I8VAI97(@6DE0('9A;&ED
M92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S-`IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(L=A(&YE('-E;6)L92!P87,@ZG1R92!U;B!N=6WI<F\@9&4@8V%R=&4@
M=F%L:61E+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"B)#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G97,@
MX"!T<F%V97)S(&QA('!A<W-E<F5L;&4@0VQI8VMA=&5L;"`B"B(H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144"(*"B,Z
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"B)#92!P:6QO=&4@<&5R;65T(&PG96YV
M;VD@9&4@;65S<V%G97,@=FEA(&QA('!A<W-E<F5L;&4@5TE.("AH='1P.B\O
M=VEN<&QC+B(*(F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%`B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB0V4@<&EL;W1E
M('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S(.`@=')A=F5R<R!L82!P87-S
M97)E;&QE('-M<S)E;6%I;"`B"B(H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&5N
M('5T:6QI<V%N="!L)T%022!(5%10(@H*(SH@;&EB+TYE="]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@
M5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N
M=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B
M(@HB0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('!A<B!3
M3510(.`@=')A=F5R<R!L82!P87-S97)E;&QE("(*(E9O9&%F;VYE($ET86QI
M92P@<V5U;&5M96YT(&%U>"!N=6WI<F]S(%9O9&%F;VYE+B!#96QA(&[I8V5S
M<VET92!U;B!C;VUP=&4@9&4@(@HB8V]U<G)I96P@5F]D869O;F4@271A;&EE
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.CDX,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`Y,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$X-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V,`HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3,P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,34V,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@T,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV,B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`P.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U,PHC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C0U-`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C8T-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q-R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$R-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Y-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S@P,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@Q,0IM<V=I9"`B
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B0V4@8VAA;7`@97-T
M(&]B;&EG871O:7)E+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Y"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM
M<V=S='(@(D-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E<R!E;G1I
M97)S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(*;7-G<W1R(")#92!C:&%M<"!N92!D;VET(&-O;G1E;FER('%U92!D97,@
M;F]M8G)E<R!E="!L97,@9&5U>"UP;VEN=',N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D-E(&-H86UP(&YE(&1O:70@8V]N
M=&5N:7(@<75E(&1E<R!V86QE=7)S(&]C=&%L97,N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S
M='(@(B(*(D-E(&-H86UP(&1O:70@8V]N=&5N:7(@=6YE(&QI<W1E(&0G96YT
M:65R<R!SZ7!A<NES('!A<B!D97,@=FER9W5L97,@;W4@9&5S("(*(F5S<&%C
M97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3DS"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D-E(&-H86UP
M(&1O:70@ZG1R92!U;B!N;VUB<F4@=F%L:61E+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#(U"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D-E(&-H86UP(&1O:70@
M8V]N=&5N:7(@=6X@8V]D92!D92!C;W5L975R(&%U(&9O<FUA="!21T(@:&5X
M863I8VEM86PL('!A<B`B"B)E>&5M<&QE("<C,3(S-&%F)RXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D-E(&9O<FUU;&%I<F4@82!D
MZ6K@(.ETZ2!T<F%I=.DN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC
M.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B
M0R=E<W0@)7,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O
M8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E
M;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L
M:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(D-E8VD@97-T('5N
M(&]B:F5T($MO;&%B($=R;W5P=V%R92X@4&]U<B!V;VER(&-E="!O8FIE="P@
M=F]U<R!D979R97H@879O:7(@=6X@(@HB8VQI96YT(&1E(&-O=7)R:65L('%U
M:2!C;VUP<F5N9"!L92!F;W)M870@2V]L86(@1W)O=7!W87)E+B!0;W5R('5N
M92!L:7-T92!D92`B"B)C97,@8VQI96YT<R!D92!C;W5R<FEE;"P@=FES:71E
M>B`E<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM
M<V=S='(@(B(*(D-E(&UE<W-A9V4@82#I=.D@Z6-R:70@9&%N<R!U;B!C;V1E
M(&1E(&-A<F%C=.AR97,@*"5S*2!A=71R92!Q=64@;&4@=O1T<F4N(@H*(SH@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")#92!N;VUB<F4@9&]I
M="#J=')E('-U<.ER:65U<B#@('5N+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(D-E('-E<G9E=7(@
M;F4@<&5U="!P87,@9.EC;VUP<F5S<V5R(&QE<R!F:6-H:65R<R!:25`@970@
M9WII<"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X,@IM<V=I9"`B
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R
M(")#92!S>7-TZ&UE(&5S="!P<NES96YT96UE;G0@9.ES86-T:7;I+B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D-E='1E('9A;&5U<B!D;VET
M(.IT<F4@=6X@;F]M8G)E+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B0V5T=&4@9F5NZG1R
M92!D;VET(.IT<F4@87!P96SI92!D97!U:7,@=6YE(&9E;NIT<F4@9&5S(&]P
M=&EO;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")4;VYN97)R92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I8VME=',B"FUS
M9W-T<B`B5&EC:V5T<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(Y('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G
M<W1R(")(975R92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*
M;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B4W5I=FD@:&]R86ER92(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B
M"FUS9W-T<B`B1F]R;6%T(&0G:&5U<F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C4S-0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B4^EL96-T
M:6]N(&1E(&PG:&5U<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R
M(")4:6UO<B!O<FEE;G1A;"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4
M:71L92(*;7-G<W1R(")4:71R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB
M"FUS9W-T<B`B5&ET<F4@*&EN9F]B=6QL92F@.B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("+`
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,0IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&]U<B!SZ6QE8W1I;VYN97(@<&QU
M<VEE=7)S(&ET96US(.`@;&$@9F]I<RP@;6%I;G1E;F5Z(&5N9F]N8^D@;&4@
M8F]U=&]N("(*(JN@0W1R;*"[("A00RD@;W4@JZ!#;VUM86YD9:"[("A-86,I
M(&5N(&-L:7%U86YT+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D%U:F]U<F0G:'5I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I
M9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E9O:7(@;&$@<V]U<F-E
M($A434PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")$
M96UA:6XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM
M<V=I9"`B5&]P(@IM<V=S='(@(DAA=70B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T
M;W`I(@IM<V=S='(@(D-A9')E(&1U(&AA=70@*%]T;W`I(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T
M<B`B5')A9'5C=&EO;G,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O
M(@IM<V=S='(@(E1R:6YI=.DM970M5&]B86=O(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5G)A
M:2!O=2!F875X(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B36$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=6YI<VEA(@IM<V=S='(@(E1U;FES:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS
M9W-T<B`B5'5R<75I92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS
M9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)C("A)4T\M
M.#@U.2TY*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K
M;>EN:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B
M"FUS9W-T<B`BSFQE<R!4=7)Q=65S(&5T($-A[W%U97,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z
M,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B16YT<F5Z
M('9O=')E(&-H;VEXH#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(DEN9&EC92!5
M5J`Z("(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B
M55),(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM
M<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P
M;W)T(@IM<V=S='(@(E523"!P;W5R('9O=')E(')A<'!O<G0@9&4@;&EV<F%I
M<V]N(&1U('-C<FEP="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E5G86YD82(*;7-G<W1R(")/=6=A;F1A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR
M86EN92(*;7-G<W1R(")5:W)A:6YE(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT
M,38*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B26UP;W-S:6)L92!D)V%T=&5I;F1R92!L92!RZ7!E<G1O:7)E(%9&
M4RXB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+B(*;7-G<W1R("));7!O<W-I8FQE(&0G86IO=71E<B!D97,@:6YF
M;W)M871I;VYS(&-O;7!LZ6UE;G1A:7)E<R#@(&PG:6YS8W)I<'1I;VXN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!M;V1I9FEE<B!L97,@<&5R;6ES
M<VEO;G,@<&]U<B!L92!F:6-H:65R(%9&4R"KH"5SH+LN(@H*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z-#8X(&QI8B]61E,O9FEL92YP:'`Z,S@Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@;6]D:69I
M97(@;&5S('!E<FUI<W-I;VYS('!O=7(@;&4@9FEC:&EE<B!61E,@)7,O)7,N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<W-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("));7!O<W-I8FQE
M(&1E(&-H86YG97(@<&]U<B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,W
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I
M>F4@;V8@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(';I<FEF:65R
M(&QA('1A:6QL92!D=2!F:6-H:65R(&1E(*N@)7.@NRXB"@HC.B!L:6(O5D93
M+W-Q;"YP:'`Z,3`Q.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HX-#(@;&EB+U9&
M4R]F:6QE+G!H<#HV.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(DEM<&]S
M<VEB;&4@9&4@=NER:69I97(@;&$@=&%I;&QE(&1U(&9I8VAI97(@9&4@JR`E
M<R\E<R"[+B(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z-#,Y"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")#
M;VYN97AI;VX@:6UP;W-S:6)L92!A=2!S97)V975R(%-13"XB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z.#4Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"XB"FUS9W-T<B`B0V]N;F5X:6]N(&EM<&]S<VEB;&4@96X@4U-,(@H*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`T(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C(P.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,3<*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HR,CD@;&EB+U9&4R]F:6QE+G!H<#HR,S0*;7-G:60@(E5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&-O
M<&EE<B!U;B!F:6-H:65R(%9&4RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S<P
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8W+I97(@
M=6X@<NEP97)T;VER92!61E,@JZ`E<Z"[+B(*"B,Z(&QI8B]61E,O;75S<6PN
M<&AP.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-C0@;&EB+U9&4R]F:6QE
M+G!H<#HS-3@*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!C<NEE<B!U;B!RZ7!E<G1O:7)E
M(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@
M8W+I97(@;&4@9FEC:&EE<B!61E,N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Y
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&-RZ65R(&QE
M('+I<&5R=&]I<F4@5D93(*N@)7.@NRXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C(V.0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB
M"FUS9W-T<B`B26UP;W-S:6)L92!D92!C<NEE<B!U;B!F:6-H:65R(%9&4R!V
M:61E+B`B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-B!L:6(O
M2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D
M96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(D]U=F5R='5R92!I;7!O<W-I8FQE
M(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE+B`B"@HC.B!L:6(O5D93+W-M8BYP
M:'`Z,C(X(&QI8B]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E
M(*N@)7.@NRP@;&4@9&]S<VEE<B!N)V5S="!P87,@=FED92XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E(*N@)7.@NZ`Z
M("5S+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS.34@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,S$Q(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T,@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C,S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R(")3
M=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E("5S+"!L92!D;W-S:65R(&XG97-T
M('!A<R!V:61E(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(")3=7!P<F5S<VEO
M;B!RZ6-U<G-I=F4@9'4@9&]S<VEE<B!61E,@:6UP;W-S:6)L92XB"@HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U(&QI
M8B]61E,O;75S<6PN<&AP.C,T,PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-3(@;&EB+U9&4R]F:6QE+G!H<#HS-#$*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B4W5P<')E<W-I;VX@9'4@<NEP
M97)T;VER92!61E,@:6UP;W-S:6)L92XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M-#(P(&QI8B]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
M26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@<NEP97)T;VER92!61E.@.B`E
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&9I8VAI97(@5D93(*N@)7.@
MNRXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,CDQ(&QI8B]61E,O;75S<6PN<&AP
M.C$V-R!L:6(O5D93+VUU<W%L+G!H<#HQ.#`*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y,2!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS.3D*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,#<*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(E-U<'!R97-S:6]N
M(&EM<&]S<VEB;&4@9'4@9FEC:&EE<B!61E,N(@H*(SH@;&EB+U9&4R]S;6(N
M<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!I;7!O
M<W-I8FQE(&1U('+I<&5R=&]I<F4@5D93(*N@)7.@NRXB"@HC.B!L:6(O5D93
M+W-Q;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B4W5P<')E<W-I
M;VX@5D93('+I8W5R<VEV92!I;7!O<W-I8FQEH#H@)7,N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C@R,PIM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!DZ71E<FUI
M;F5R(&QE(&1O<W-I97(@8V]U<F%N="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(*;7-G<W1R("));7!O<W-I8FQE(&0G97AT<F%I<F4@
M;&5S(&3I=&%I;',@9'4@8V5R=&EF:6-A="(*"B,Z(&QI8B].970O24U34"YP
M:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8VAA<F=E<B!L82!DZ69I;FET:6]N
M(&1E("5S+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W-"!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ-SD@;&EB+U9&4R]F:6QE+G!H<#HR,#`*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HR,#4*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&3I<&QA8V5R(&QE(&9I8VAI
M97(@5D93+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP
M:'`Z,3`V(&QI8B]61E,O<VUB+G!H<#HV-3(*(SH@;&EB+U9&4R]F='`N<&AP
M.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D)V]U=G)I<B!L92!F
M:6-H:65R(%9&4R"KH"5SH+LN(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,3,X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T,2!L:6(O5D93+V9I;&4N<&AP
M.C(X,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=O=79R:7(@=6X@9FEC:&EE<B!6
M1E,@96X@Z6-R:71U<F4N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S8@
M;&EB+U9&4R]F:6QE+G!H<#HX,R!L:6(O5D93+V9I;&4N<&AP.C$S-`IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9"=O=79R:7(@=6X@9FEC:&EE<B!61E,N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3W5V97)T=7)E(&EM<&]S<VEB
M;&4@9&4@;"=A<F-H:79E(&-O;7!R97-SZ64N(@H*(SH@;&EB+U9&4RYP:'`Z
M.#4U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC
M:&EE<B!61E,@*.EC:&5C(&1E(&9I;&5S:7IE*"DI+B(*"B,Z(&QI8B]61E,N
M<&AP.C@X-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I
M;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!L:7)E
M(&QE(&9I8VAI97(@5D93("CI8VAE8R!D92!G971&:6QE4VEZ92@I*2XB"@HC
M.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@
M(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("));7!O<W-I8FQE(&1E
M(&QI<F4@;&4@9FEC:&EE<J`Z("(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C<S
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN
M(@IM<V=S='(@(DQE8W1U<F4@9'4@<NEP97)T;VER92!R86-I;F4@5D93(&EM
M<&]S<VEB;&4N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3`T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E
M<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("));7!O
M<W-I8FQE(&1E(')E;F]M;65R("5S(&5N("5SH#H@;&4@9&]S<VEE<B!C:6)L
M92!E>&ES=&4@9.EJX"(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P,0IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M("));7!O<W-I8FQE(&1E(')E;F]M;65R(&QE('+I<&5R=&]I<F4@5D93+B(*
M"B,Z(&QI8B]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
M26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z("5S
M+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-S$@;&EB+U9&4R]F='`N<&AP.C,T
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!R96YO;6UE<B!L
M92!F:6-H:65R(%9&4R"KH"5SH+LN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,C(Y(&QI8B]61E,O9FEL92YP:'`Z-C$T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEM
M<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@9FEC:&EE<B!61E,@)7,O)7,N(@H*
M(SH@;&EB+U9&4R]S<6PN<&AP.C,R-B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@
M;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C(Y,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<F5N
M;VUM97(@;&4@9FEC:&EE<B!61E,N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(*;7-G<W1R("));7!O<W-I8FQE(&0G97CI8W5T97(@)VUK:7-O9G,G+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED
M(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G
M<W1R("));7!O<W-I8FQE(&1E('1R861U:7)E(&-E(&1O8W5M96YT(%=O<F0N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L:6(O5D93+V9T<"YP:'`Z,34W
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"?I8W)I<F4@;&4@9FEC
M:&EE<B!61E,@JZ`E<Z"[+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3@S"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+B(*;7-G<W1R("));7!O<W-I8FQE(&0GZ6-R:7)E(&QE<R!D;VYNZ65S(&1U
M(&9I8VAI97(@5D93("AC;W!Y*"D@:6UP;W-S:6)L92DN(@H*(SH@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,30V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U,2!L
M:6(O5D93+V9I;&4N<&AP.C(X-0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"?I8W)I<F4@;&5S
M(&1O;F[I97,@9'4@9FEC:&EE<B!61E,N(@H*(SH@;&EB+U9&4RYP:'`Z.#8Q
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@
M8F4@97AC965D960N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"?I8W)I<F4@;&4@
M9FEC:&EE<B!61E,L(&QE('%U;W1A('-E<F%I="!DZ7!A<W/I+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@
M(E5N9&5R;&EN92(*;7-G<W1R(")3;W5L:6=N97(B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B
M06YN=6QE<B!L97,@8VAA;F=E;65N=',B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;B(*;7-G<W1R(")!;FYU;&4@=F]T<F4@9&5R;FGH<F4@86-T
M:6]N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,R!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*
M;7-G<W1R(")2Z7!O;G-E(&EN871T96YD=64@9'4@<V5R=F5U<B!L;W)S(&1E
M(&QA(&-O;FYE>&EO;J`Z("(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")2Z7!O;G-E
M(&EN871T96YD=64@9'4@<V5R=F5U<B#@H#H@(@H*(SH@;&EB+TAO<F1E+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`B2&]R<R!C873I9V]R:64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X.0IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@
M*%541BTX*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R
M("+);6ER871S($%R86)E<R!5;FES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O
M;2(*;7-G<W1R(")2;WEA=6UE+55N:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,B"FUS9W-T<B`BR71A=',M56YI<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("+.;&5S(&5X=.ER
M:65U<F5S(&1E<R#)=&%T<RU5;FES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8R(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N
M:71S(@IM<V=S='(@(E5N:73I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0R.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS
M9W-T<B`B26YC;VYN=2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(F%P:6US9VED(&EN8V]N;G4@*$%022!-97-S86=E
M($E$*2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+B(*;7-G<W1R(")C;&EM<V=I9"!I;F-O;FYU("A#;&EE;G0@365S<V%G92!)
M1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I
M9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B16UP;&%C
M96UE;G0@<^EL96-T:6]N;ND@:6YC;VYN=2XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F]M(&0G=71I;&ES871E=7(@;W4@
M;6]T(&1E('!A<W-E(&EN8V]N;G4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@
M=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")$Z6QI97(@;"?I;.EM96YT
M(&-O=7)A;G0B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P,0IM<V=I
M9"`B56YN86UE9"(*;7-G<W1R(")386YS(&YO;2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB3&5S('-C<FEP=',@
M;F]N+7!R:79I;.EG:>ES(&YE('!E=79E;G0@86-CZ61E<B!A=7@@9F]N8W1I
M;VYS(&-O=7!E<B]C;W!I97(O(@HB8V]L;&5R('!O=7(@9&5S(')A:7-O;G,@
M9&4@<^EC=7)I=.DN($%P<'5Y97H@<W5R($]+('!O=7(@=F]I<B!U;F4@;F]T
M92`B"B)T96-H;FEQ=64@<W5R(&UO>FEL;&$N;W)G('%U:2!V;W5S(&5X<&QI
M<75E<F$@8V]M;65N="!A=71O<FES97(@=6X@<V-R:7!T(.`@(@HB=71I;&ES
M97(@;&4@<')E<W-E+7!A<&EE<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO
M<B(*;7-G<W1R(")296UE='1R92!L82!C;W5L975R(.`@>NER;R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@W(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z.3(W"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,S
M"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B17AT96YS
M:6]N(&YO;B!P<FES92!E;B!C;VUP=&4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM
M<V=I9"`B57!D871E(@IM<V=S='(@(DUO9&EF:65R(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&4@)7,B"FUS9W-T<B`B36]D:69I97(@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E
M<B(*;7-G<W1R(")-;V1I9FEE<B!L)W5T:6QI<V%T975R(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57!D871E9"!<(B5S7"(N(@IM<V=S='(@(DUI<V4@X"!J;W5R(&1E(*N@)7.@
MNRXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G
M<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B3&4@<V-R:7!T(&1E(&UI
M<V4@X"!J;W5R(&5S="!S=7!P<FEMZ2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y
M.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(D-H87)G97(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@HB
M5&]U<R!L97,@9FEC:&EE<G,@9&4@8V]N9FEG=7)A=&EO;B!D97,@87!P;&EC
M871I;VYS(&]N="#I=.D@96YV;WGI<R!S=7(@;&4@(@HB<V5R=F5U<BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(DQE
M='1R97,@;&%T:6YE<R!M86IU<V-U;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P
M97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(").;VUB<F5S(')O;6%I;G,@;6%J
M=7-C=6QE<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")%
M;7!L;WGI(&%C='5E;&QE;65N=*`Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")5
M=&EL:7-E<B!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS
M9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-
M4U`@<V5R=F5R+B(*;7-G<W1R("(B"B)5=&EL:7-E<B!S:2!L92!N;VT@9"=U
M=&EL:7-A=&5U<B]M;W0@9&4@<&%S<V4@97-T(&1I9F;I<F5N="!D=2!S97)V
M975R($E-4U`N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")5=&EL:7-A=&5U<B(*"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z-S$V"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("),
M)W5T:6QI<V%T975R("5S(&XG82!P87,@;"=A=71O<FES871I;VX@<&]U<B`E
M<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VX@9&5S('5T:6QI<V%T
M975R<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5
M<V5R($]P=&EO;G,B"FUS9W-T<B`B4'+I9NER96YC97,@<&5R<V]N;F5L;&5S
M(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB
M"FUS9W-T<B`B16YR96=I<W1R96UE;G0@9&5S('5T:6QI<V%T975R<R(*"B,Z
M('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(DPG96YR96=I
M<W1R96UE;G0@9"=U=&EL:7-A=&5U<B!E<W0@9.ES86-T:7;I('-U<B!C92!S
M>7-TZ&UE+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@
M(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B0V]M<'1E('5T:6QI
M<V%T975R(&YO;B!T<F]U=NDB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S8@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HY.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y
M."!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34P"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,S('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G
M:60@(E5S97)N86UE(@IM<V=S='(@(DYO;2!D)W5T:6QI<V%T975R(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R
M("),92!N;VT@9&4@8V]N;F5X:6]N(*N@)7.@NR!E>&ES=&4@9.EJX"XB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N
M86UE.B(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<J`Z(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G
M<W1R(").;VT@9"=U=&EL:7-A=&5U<J`Z("(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ
M(@IM<V=S='(@(E5T:6QI<V%T975R<R!DZ69I;FESH#HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5
M>F)E:VES=&%N(@IM<V=S='(@(D]U>F+I:VES=&%N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HQ-C<@;&EB+U9&4R]F:6QE+G!H<#HR-3D*;7-G:60@(E9&4R!D
M:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E+I<&5R=&]I<F4@
M5D93(&EN97AI<W1A;G0N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B06)S96YC97,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.#<P"FUS9VED(")686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(DQE<R!E;7!L86-E;65N=',@=F%L
M:61E<R!T<F]U=NES(&EN8VQU96YTH#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(E9A;&ED
M:73I(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L
M=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B5F%L975R(&5N(&UI
M;G5T97,@X"!P87)T:7(@9&4@;6%I;G1E;F%N="XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.#8P(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+B(*;7-G<W1R(")686QE=7(@<W5PZ7)I975R92#@(&QA(&QO;F=U
M975R(&UA>&EM86QE(&1E("5S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C0X(&QI8B](;W)D92]&;W)M+G!H<#HR,C<P(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S(P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3$W(&QI8B](;W)D92]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T
M<B`B5F%L975R<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$S(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3DP"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R
M;VTB"FUS9W-T<B`B5F%L975R<R#@('/I;&5C=&EO;FYE<B!D92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@
M(E9A<FEA8FQE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E;I;NEZ
M=65L82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED
M(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`BR6-H96,@9&4@;&$@=NER
M:69I8V%T:6]N("9M9&%S:#L@8V4@;65S<V%G92!A('!E=70MZG1R92#I=.D@
M9F%L<VEF:>DN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEO;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*
M;7-G<W1R(")#;VYT<O1L92!D92!V97)S:6]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86P@86QI9VXB"FUS9W-T<B`B06QI9VYE;65N="!V97)T:6-A;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G
M:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B4F5M<&QI<W-A9V4@=F5R
M=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EC86R@.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS
M9VED(")697)Y($AI9V@B"FUS9W-T<B`B5'+H<R!H875T92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R
M(")6:>IT+6YA;6EE;B`H5DE30TE)*2(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HY-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*
M;7-G<W1R(")6;VER("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM
M<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")6;VER
M('5N92!P86=E('=E8B!E>'1E<FYE(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S
M(@IM<V=S='(@(E9O:7(@8V]M;64@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R("+.;&5S(%9I97)G97,@8G)I=&%N;FEQ
M=65S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B
MSFQE<R!6:65R9V5S(&1E<R#)=&%T<RU5;FES(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES:6)I
M;&ETZ2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G
M:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6:7-I8FEL:73IH#H@(@H*(SH@
M;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B
M5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O;F4@271A
M;'D@=FEA(%--5%`B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B3D]424-%
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N(@IM<V=S='(@(D%45$5.5$E/3B$A(2`@4U504%))3452($Q%(%-#
M4DE05"!-04Y514Q,14U%3E0@1$4@)7,B"@HC.B!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.
M('9I82!(5%10(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T
M<B`B5V%L;&ES(&5T($9U='5N82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(Y(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM
M<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!='1E;G1I;VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*
M;7-G<W1R(")-92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0<NEV:7-I;VYS
M(&WI=.EO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM
M<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D1O;F[I
M97,@;>ETZ6\@9F]U<FYI97,@<&%R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S
M='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G
M:60@(E=E8B!3:71E(@IM<V=S='(@(E-I=&4@=V5B(@H*(SH@;&EB+TAO<F1E
M+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(D-H
M87%U92!S96UA:6YE(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B0FEE;G9E;G5E(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B
M"FUS9W-T<B`B0FEE;G9E;G5E(.`@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0FEE;G9E
M;G5E+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")/8V-I9&5N=&%L("A)4T\M
M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3V-C:61E;G1A;"`H25-/
M+3@X-3DM,34I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E-A
M:&%R82!/8V-I9&5N=&%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")1=65L;&4@87!P
M;&EC871I;VX@)7,@9&]I="UI;"!P<NES96YT97(@87!RZ',@;&$@8V]N;F5X
M:6]NH#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I
M9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B
M475E;"!E<W0@;&4@8V%R86-TZ')E(&1E('/I<&%R871I;VZ@/R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(E%U96P@97-T(&QE(&-A<F%C
M=.AR92!D92!C:71A=&EO;J`_(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R(")#87)T92!7:&5R96ES($%U<W1R86QI92(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@
M(E%U96QL97,@<&AA<V5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+B(*;7-G<W1R(")1=65L;&5S(&5X=&5N<VEO;G,@86-T
M:79E<B!P;W5R(&PGZ61I=&5U<B!2:6-H(%1E>'0N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B
M5VED=&@B"FUS9W-T<B`B3&%R9V5U<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3$T"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B3&%R
M9V5U<B!E;B!U;FETZ7,@0U-3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB
M"FUS9W-T<B`B(@HB3&%R9V5U<B!D=2!M96YU(&1E(&=A=6-H92`E<R`@*&QA
M(&-O;F9I9W5R871I;VX@<')E;F1R82!E9F9E="#@(&QA('!R;V-H86EN92`B
M"B)C;VYN97AI;VXIH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM
M<V=S='(@(DQA<F=E=7(@9'4@=&%B;&5A=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET
M(@IM<V=S='(@(E5N:73I(&1E(&QA<F=E=7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM
M<V=S='(@(DQA<F=E=7*@.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B5F5N="(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS
M9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E9E;G0@=/1T(&QE(&UA=&EN(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I
M;B!K;F]T<R(*;7-G<W1R(")6:71E<W-E(&1U('9E;G0@96X@;B9O96QI9SMU
M9',B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB
M"FUS9W-T<B`B5F5N=*`Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9E;G2@.B`B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R
M(")386=E<W-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM
M<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B3&ES=&4@9&4@=B9O96QI9SMU>"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G
M<W1R(")4<F%V86EL(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*
M;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')E<W-E('!R;V9E<W-I
M;VYN96QL92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E3I;.EP:&]N92!P<F]F
M97-S:6]N;F5L(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB+T9I;&4O
M0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M(@IM<V=S='(@(DYO;6)R92!D92!C:&%M<',@:6YC;W)R96-T(.`@;&$@;&EG
M;F4@)60N("5D(&%T=&5N9'5S+"`E9"!T<F]U=NES+B(*"B,Z(&QI8B]&:6QE
M+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B
M3F]M8G)E(&1E(&-H86UP<R!I;F-O<G)E8W0N("5D(&%T=&5N9'5S+"`E9"!T
M<F]U=NES+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3$X"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(D3I8V%L86=E("5D(&EN8V]R<F5C="!L;W)S(&1E
M(&QA(&QE8W1U<F4@9&4@9FEC:&EE<B!61E,N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(D-O;G1R86EN=&5S(&)A
M<VEQ=65S(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@
M(E5T:6QI<V%T:6]N(&1E(&-LZ2#I=&5N9'5E(%@U,#EV,R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(D%U=')E(&YO;2!D=2!S=6IE
M="!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B
M261E;G1I9FEA;G0@9&4@8VSI(&1U('-U:F5T(%@U,#EV,R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS
M:6]N<R(*;7-G<W1R(")%>'1E;G-I;VYS(%@U,#EV,R(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")!02(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,PIM<V=I9"`B65E962(*;7-G<W1R
M(")!04%!(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B0V%R=&4@JZ!986AO
M;Z`AH+LB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`B06YN=65L;&5M96YT(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M
M96XB"FUS9W-T<B`B6>EM96XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B3W5I(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G
M:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")/=6DL(&HG86-C97!T92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G
M:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)6;W5S
M(.IT97,@96X@;6]D92"KH%1E>'1EH+LN(%5T:6QI<V5Z(&QE(&)O=71O;B!;
M/#Y=('!O=7(@<F5V96YI<B!A=2!M;V1E("(*(JN@5UE325=91Z"[+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@8FQO8VMS+B(*;7-G<W1R(")6;W5S(&XGZG1E<R!P87,@875T;W)I<^D@
MX"!C<NEE<B!P;'5S(&1E("5D(&)L;V-S+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T
M<B`B5F]U<R!N)^IT97,@<&%S(&%U=&AE;G1I9FGI+B(*"B,Z(&QI8B](;W)D
M92])9&5N=&ET>2YP:'`Z,S`W"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(")6
M;W5S(&YE('!O=79E>B!P87,@879O:7(@;&4@8V%R86-TZ')E(*M<7+L@9&%N
M<R!V;W1R92!N;VT@8V]M<&QE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@U.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N
M;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")6;W5S
M(&XG879E>B!P87,@<V%I<VD@=6YE(&%D<F5S<V4@Z6QE8W1R;VYI<75E('9A
M;&ED92XB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*(E9O=7,@;B=A=F5Z('!A<R!A<W-O8VGI
M(&QE<R!C:&%M<',@9'4@9FEC:&EE<B!I;7!O<G3I(&%U>"!C:&%M<',@(@HB
M8V]R<F5S<&]N9&%N=',@9&%N<R`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z.3@T"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S
M='(@(E9O=7,@879E>B#I=.D@9.EC;VYN96-TZ2XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(V-0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P
M<F5F:7@N(@IM<V=S='(@(B(*(E9O=7,@9&5V97H@:6YS8W)I<F4@=6X@;G5M
MZ7)O(&1E(&-E;&QU;&%I<F4@=F%L:61E+"!S975L<R!D97,@;F]M8G)E<R!E
M="!U;B`B"B*K*[L@;W!T:6]N;F5L('!O=7(@;&5S(&%P<&5L<R!I;G1E<FYA
M=&EO;F%U>"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B5F]U
M<R!N)V%V97H@<&%S('-A:7-I('5N92!E;G1RZ64@=F%L:61E+B(*"B,Z(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM
M<V=S='(@(B(*(E9O=7,@9&5V97H@8V]N9FEG=7)E<B!U;B!B86-K96YD($1A
M=&%4<F5E('!O=7(@=71I;&ES97(@;&5S(&EN<V-R:7!T:6]N<R(*"B,Z(&QI
M8B](;W)D92YP:'`Z-#8R"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"XB"FUS9W-T<B`B5F]U<R!D979E>B!C;VYF:6=U<F5R('5N
M(&UO9'5L92!61E,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M("(B"B)6;W5S(&1E=F5Z(&3I8W)I<F4@;&4@<')O8FSH;64@879A;G0@9&4@
M;F]U<R!F86ER92!P87)V96YI<B!L92!R87!P;W)T+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*
M;7-G<W1R(")6;W5S(&1E=F5Z(&5N=')E<B!U;F4@55),(&_Y('!O:6YT92!D
M92!L:65N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS
M9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M(@IM<V=S='(@(DEL(&9A=70@<^EL96-T:6]N;F5R('5N('-E<G9E=7(@X"!S
M=7!P<FEM97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R
M(")6;W5S(&1E=F5Z('-PZ6-I9FEE<B!U;B!U=&EL:7-A=&5U<B#@(')E=&ER
M97(N("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B5F]U<R!D
M979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+B(*;7-G<W1R(")6;W5S(&1E=F5Z('-PZ6-I9FEE<B!U;B!U=&EL
M:7-A=&5U<B#@(&%J;W5T97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M(@IM<V=S='(@(E9O=7,@9&5V97H@<W#I8VEF:65R(&QE(&YO;2!D92!L)W5T
M:6QI<V%T975R(.`@;6]D:69I97(N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S
M+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T
M:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(E9O=7,@9&5V97H@:6YD:7%U97(@
M<75E;&QE(&%C=&EO;B!A8V-O;7!L:7(N(@H*(SH@;&EB+TAO<F1E+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B5F]U<R!D979E>B#I8W)I
M<F4@=6X@;F]M('!O=7(@;&$@;F]U=F5L;&4@8V%TZ6=O<FEE+B(*"B,Z(&QI
M8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS
M9W-T<B`B5F]U<R!D979E>B!F;W5R;FER('5N(&ZP(&1E('3I;.EP:&]N92!I
M=&%L:65N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S
M92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B5F]T<F4@<V5S<VEO;B`E<R!A(&5X
M<&ERZ2X@5F5U:6QL97H@=F]U<R!R96-O;FYE8W1E<BXB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!
M9&1R97-S(@IM<V=S='(@(E9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96PB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ
M(&%D9')E<W,Z(@IM<V=S='(@(E9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96P@
MJR!$93H@NZ`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(E9O<R!D;VYNZ65S('!E<G-O;FYE;&QE<R(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("(B"B)6;W1R92!A9')E<W-E($EN=&5R;F5T(&$@8VAA;F?I(&1E<'5I<R!L
M)V]U=F5R='5R92!D92!V;W1R92!S97-S:6]N("5S+B`@(@HB4&]U<B!V;W1R
M92!SZ6-U<FETZ2P@=F]U<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`B5F]T<F4@;F]M(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(E9O=')E(&UO9'5L92!D)V%U
M=&AE;G1I9FEC871I;VX@;F4@<W5P<&]R=&4@<&%S(&PG86IO=70@9"=U=&EL
M:7-A=&5U<G,L(%-I("(*(G9O=7,@<V]U:&%I=&5Z('5T:6QI<V5Z($AO<F1E
M('!O=7(@861M:6YI<W1R97(@;&5S(&-O;7!T97,@=71I;&ES871E=7)S+"`B
M"B)V;W5S(&1E=F5Z('5T:6QI<V5R('5N(&%U=')E(&UO9'5L92!D)V%U=&AE
M;G1I9FEC871I;VXN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(B(*(E9O=')E(&UO9'5L92!D)V%U=&AE;G1I9FEC871I;VX@
M;B=E<W0@<&%S(&5N(&UE<W5R92!D)^ET86)L:7(@=6YE(&QI<W1E(&1E<R`B
M"B)U=&EL:7-A=&5U<G,L(&]U(&-E='1E(&9O;F-T:6]N(&$@Z73I(')E=&ER
MZ64@<&]U<B!U;F4@875T<F4@<F%I<V]N+B(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)6;W1R92!N
M879I9V%T975R('-E;6)L92!A=F]I<B!C:&%N9^D@9&5P=6ES(&QE(&3I8G5T
M(&1E('9O=')E('-E<W-I;VX@)7,N("`B"B)0;W5R('9O=')E('/I8W5R:73I
M+"!V;W5S(&1E=F5Z('9O=7,@<F5C;VYN96-T97(N(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B5F]T<F4@;F%V:6=A=&5U
M<B!N92!S=7!P;W)T92!P87,@8V5T=&4@;W!T:6]N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)6
M;W1R92!N879I9V%T975R(&YE('!R96YD('!A<R!E;B!C;VUP=&4@8V5T=&4@
M;W!T:6]N(&0G:6UP<F5S<VEO;BX@4')E<W-E>B`B"B)#;VYT<O1L92]#;VUM
M86YD92`K(%`@<&]U<B!I;7!R:6UE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S
M='(@(E9O=')E(&9U<V5A=2!H;W)A:7)E(&%C='5E;*`Z(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.CDX"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@
M:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B5F]T<F4@<')O9FEL('!A<B!D
MZ69A=70@82#I=.D@;6]D:69IZ2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@
M(E!R;V9I;"!P87(@9.EF875TH#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B5F]T<F4@
M;F]M(&-O;7!L972@.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.38*;7-G
M:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(E9O=')E(&-O
M;7!T92!A(&5X<&ERZ2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F
M;W(@)7,@:7,Z("5S(@IM<V=S='(@(E9O=')E(&YO=79E874@;6]T(&1E('!A
M<W-E('!O=7(@)7,@97-TH#HE<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@
M9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E9O
M<R!O<'1I;VYS(&]N="#I=.D@;6ES97,@X"!J;W5R('!O=7(@;&$@9'5RZ64@
M9&4@8V5T=&4@<V5S<VEO;BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R(")6;W,@;W!T:6]N<R!O;G0@Z73I(&UI<V5S(.`@:F]U<BXB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")6;W1R92!M;W0@9&4@
M<&%S<V4@82#I=.D@<F5M:7,@X"!ZZ7)O(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)6;W1R92!M;W0@9&4@
M<&%S<V4@82#I=.D@<F5M:7,@X"!ZZ7)O+"!VZ7)I9FEE<B!V;W1R92!C;W5R
M<FEE<B!E="!C;VYN96-T97HM(@HB=F]U<R!A=F5Z('9O=')E(&YO=79E874@
M;6]T(&1E('!A<W-E+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,S`*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E9O=')E
M(&UO="!D92!P87-S92!A(&5X<&ERZ2XB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM
M<V=S='(@(E9O<R!S97)V975R<R!D:7-T86YT<Z`Z(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B66]U9V]S;&%V:64B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S
M='(@(EIA[W)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("):
M:7!P>2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM#
M86-H97(@;&5S(&-I=&%T:6]N<UTB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4F%P<&]R
M="!D92!P<F]B;.AM95TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G
M<W1R(");069F:6-H97(@;&4@=&5X=&4@8VETZ2`M(@H*(SH@;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF
M;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM
M<V=S='(@(EM!9F9I8VAE<B!L92!T97AT92!C:73I("T@)7,@;&EG;F5S72(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML
M:6YE("5S(&]F("5S72(*;7-G<W1R(");;&EG;F4@)7,@9&4@)7-=(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R
M871I;VXB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B3&EG;F4@9&4@7V-O;6UA;F1E(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS
M9VED(")?1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS
M9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")3=7!P<FEM97(@;&$@7W)A;F?I
M92(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R
M(")?1W)O=7!E<R(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@
M(E](96QP(@IM<V=S='(@(E]!:61E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<E]IZ73I<R!D92!L)VEM86=E
M+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I
M;B(*;7-G<W1R(")?0V]N;F5X:6]N(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP
M.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7T3I8V]N;F5X:6]N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7TUO9&EF
M:65R('5N(&QI96X@=V5B+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V
M-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T]P=&EO;G,B"@HC.B!L:6(O
M87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?4&5R
M;6ES<VEO;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G
M<W1R(")?4F5T:7)E<B!U;B!L:65N(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS
M9VED(")?4V5T=7`B"FUS9W-T<B`B7T-O;F9I9W5R871I;VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*
M;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:>ET
MZ7,@9'4@7W1A8FQE874B"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5
M<V5R<R(*;7-G<W1R(")?571I;&ES871E=7)S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,C`*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")C87)N
M970@9"=A9')E<W-E<R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B9&5S=&EN
M871A:7)E(&EN8V]N;G4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ,@IM
M<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B86=E;F1A(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")C86QM92(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL92(*;7-G<W1R(")I;7!O<W-I8FQE(&1E(&-RZ65R(&QE
M(&9I8VAI97(@9&4@<V]R=&EE(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")I
M;7!O<W-I8FQE(&0G;W5V<FER(&PG96YT<NEE(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R
M(")C;&EQ=65Z(&EC:2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@
M(F5R<F5U<B!D)W5T:6QI<V%T:6]N(&1E(&QA(&QI9VYE(&1E(&-O;6UA;F1E
M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C
M;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(F5R<F5U<B!D92!C;VYF:6=U
M<F%T:6]N(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS
M9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(F%B
M<V5N8V4@8W)I=&EQ=64@9"=U;B!F:6-H:65R('-Y<W3H;64B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T
M(&5R<F]R(@IM<V=S='(@(F5R<F5U<B!D92!F;W)M870@9&4@9&]N;NEE(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B96YT<NEE(&YO;B!T<F]U=NDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B
M9F%L;&EN9R(*;7-G<W1R(")T;VUB86YT(@H*(SH@;&EB+TAO<F1E+T)R;W=S
M97(N<&AP.C@X,0IM<V=I9"`B9FEL92(*;7-G<W1R(")F:6-H:65R(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")D97!U:7,@
M;&4@)7,@*"5S*2#@("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")E;B!R869A;&4B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0X"FUS
M9VED(")H.B(*;7-G<W1R(")HH#HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S4W"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N
M86UE('5N:VYO=VXB"FUS9W-T<B`B;F]M(&0G:/1T92!I;F-O;FYU(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM
M<V=S='(@(FEM;>ED:6%T96UE;G0B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM
M<V=S='(@(FEN8V]R<&]RZ64B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")E
M<G)E=7(@9"=E;G1RZ64O<V]R=&EE(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*
M;7-G<W1R(")E<G)E=7(@;&]G:6-I96QL92!I;G1E<FYE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S
M72(*;7-G<W1R(")L:6=N97-=(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O
M<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(F5R<F5U<B!M
M:VES;V9S(&-O9&4@)60@96X@8W+I86YT(&PG25-/(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.`IM<V=I9"`B;6TB"FUS9W-T
M<B`B;6TB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`B;F]M(@H*(SH@
M;&EB+TAO<F1E+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B
M"FUS9W-T<B`B;F]N('!R:7,@96X@8V]M<'1E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(G!A<R!E;F-O<F4@<')I<R!E;B!C;VUP=&4B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDP-`IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")B
M;&]C+6YO=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P;W5R
M8V5N=&%G92(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W-`IM
M<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B<&5R;6ES<VEO;B!R
M969U<^EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L<R(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(F5R<F5U<B!D:7-T86YT
M92!D86YS(&QE('!R;W1O8V]L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B<R?I
M;&5V86YT(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R"FUS
M9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(G-E<G9I8V4@;F]N
M(&1I<W!O;FEB;&4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM
M<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")M;VYT<F5R(&QE<R!D
M:69FZ7)E;F-E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R
M96UA:6P@=FEA($A45%`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@T"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A
M9'DB"FUS9W-T<B`B9FEX92(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(F5R<F5U<B!S
M>7-TZ&UE(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C@*;7-G:60@(G1A
M<VL@;&ES="(*;7-G<W1R(")L:7-T92!D92!TXF-H97,B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL
M=7)E(@IM<V=S='(@(NEC:&5C('1E;7!O<F%I<F4B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")E
M;G1R97H@;&4@;6]T(&1E('!A<W-E(&1E=7@@9F]I<R!P;W5R(&-O;F9I<FUE
M<B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69IZ2(*"B,Z
M(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM
M<V=S='(@(G-A;G,@;F]M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B4^EL96-T:6]N(&0G=71I
M;&ES871E=7(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#`*;7-G:60@(G<Z(@IM<V=S
M='(@(FR@.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS
M9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P;R]G;%]%4RYP;P``````````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C$S-3,P`#$P-#$W,S8S,#`Q
M`#`Q-C,V,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C($AO<F1E(#(N,BXT($=A;&EC:6%N('1R86YS;&%T:6]N+@HC"B,@
M5F5R<VEO;B!I;FEC:6%L(&1E.@HC"B,@4F%F865L(%9A<F5L82`\<F%F865L
M+G9A<F5L84!U<V,N97,^"B,@1W5I;&QE<FUO($UE;F1E>B`\9W5I;&QE0'5S
M8RYE<SX*(R!397)V:6-I;R!D92!A=&5N8VEO;B!A('5S=6%R:6]S(&4@<VES
M=&5M87,*(R!5;FEV97)S:61A9&4@9&4@4V%N=&EA9V\@9&4@0V]M<&]S=&5L
M80HC"B,@4F5V:7-A9&$@>2!C;W)R96=I9&$@<&]R.@HC(`HC(%-E<G9I8VEO
M(&1E(&YO<FUA;&EZ86-I;VX@;&EN9W5I<W1I8V$@/'-N;'5S8T!U<V,N97,^
M"B,@56YI=F5R<VED861E(&1E(%-A;G1I86=O(&1E($-O;7!O<W1E;&$*(PIM
M<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@
M,BXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP."TQ.2`Q,SHS-4=-
M5"LQ7&XB"B),87-T+51R86YS;&%T;W(Z(%-E<G9I8VEO(&1E($YO<FUA;&EZ
M86-I;VX@3&EN9W5I<W1I8V$@/'-N;'5S8T!U<V,N97,^7&XB"B),86YG=6%G
M92U496%M.B!'86QE9V]<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB6"U'96YE<F%T
M;W(Z($M"86)E;"`P+CDN-5QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED
M("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@;F]N(&5S=.$@
M8V]N9FEG=7)A9&\@;F\@<F5X:7-T<F\@9&4@2&]R9&4N(@H*(SH@9G)A;65W
M;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U
M;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M
M($YO=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P
M<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M(@IM<V=S='(@(D]P97)A8VGS;G,@9&4@;6%N=&5M96YT;R`E<R`M($-O;F9I
M<FUA8VGS;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N(@IM<V=S='(@(B(*(DUA<G%U92!N82!C=6%D<NUC=6QA
M(&$@;W!E<F%C:?-N(&]U(&]P97)A8VGS;G,@<75E(&1E<V5X82!E>&5C=71A
M<B!A9V]R82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(D-A9&$@-2!M:6YU=&]S
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@
M(EML:?%A("5S(&1E("5S72(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")!>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B0V%L96YD87)I;R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O
M;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B
M"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@
M=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA
M="(*;7-G<W1R(")!('/Z82!I;F9O<FUA8VGS;B(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS
M9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:&]R87,B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E
M=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*
M;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D(@IM<V=S='(@(CQB/E!R;V1U8VEU<V4@=6X@97)R;R!G<F%V93H@
M/"]B/B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM
M<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q
M"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S
M='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I
M9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*
M;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W
M,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ
M>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")!('/Z82!I
M;F9O<FUA8VGS;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F
M=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")#:&%V92!D
M92!A8V-E<V\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!
M8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B061D(@IM<V=S='(@(D5N9&5R97IO(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#
M:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*
M;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@
M2&5R93HB"FUS9W-T<B`B16YD97)E>F\B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D
M9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W
M('5S97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I
M9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(D5N
M9V%D:7(@=6X@<&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII
M;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@
M861D<F5S<R!B;V]K.B(*;7-G<W1R(")!>&5N9&$@9&4@96YD97)E>F]S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L
M(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@
M(D%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0HC
M+"!F=7IZ>0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B16YG861I<B!U;B!P
M87(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*
M;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!
M9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$S.0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM
M<V=S='(@(D%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M
M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@
M(D%D<R(*;7-G<W1R(")%;F1E<F5Z;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F
M9VAA;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G
M:60@(D%L8F%N:6$B"FUS9W-T<B`B06QC=6UE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F
M=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&-U;64B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!
M;&EA<R(*;7-G<W1R(")!;&-U;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!
M;&EG;B(*;7-G<W1R(")!;&-U;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!
M=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS
M9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@
M3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E
M($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I
M;"!A9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1E(&-O<G)E;R!E;&5C='+S
M;FEC;SHB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT
M97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@
M(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M(@IM<V=S='(@(D\@=F%L;W(@<75E(&5S<&5C:69I8V]U(&YO;B#I(';A;&ED
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z
M>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S
M='(@(CQB/E!R;V1U8VEU<V4@=6X@97)R;R!G<F%V93H@/"]B/B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N
M9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN
M+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN
M<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G
M:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A
M=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E
M(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M
M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-
M4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B
M07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G
M=7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G
M:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?
M8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS
M9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S
M=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA
M<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A
M<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED
M(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T
M:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I
M96QD<SHB"FUS9W-T<B`B0V%M<&]S(&1I<W!O\6EB;&5S.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"
M86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R(")!;FEV97)S87)I;R(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO
M;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").;VX@<V4@871O<&]U(&\@
M87AE;G1E(&1E(&YO=&EF:6-A8VGS;B`E<RXB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I
M9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S
M='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED
M(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D-O<G)E
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!4
M97)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I
M($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L
M9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#
M35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?
M96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R:6\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL
M92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R
M"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N
M9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C
M;R!S97)V:61O<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED
M(")#86YA9&$B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O
M<G0B"FUS9W-T<B`B0V%N8V5L87(@;R!I;F9O<FUE(&1E('!R;V)L96UA<R(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O
M=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"B,L(&9U>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D]P8VGS;G,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*
M;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@;?-B
M:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS
M9W-T<B`B5&5LZ69O;F\@;?-B:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L
M;'!H;VYE(@IM<V=S='(@(E1E;.EF;VYO(&WS8FEL(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I
M8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(E1A
M<GAE=&$@9&4@=FES:71A("AV0V%R9"DB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"B,L(&9U>GIY"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B1&5S9F%C97(@;W,@
M8V%M8FEO<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM
M<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H
M87(B"FUS9W-T<B`B5&%R>&5T82!D92!V:7-I=&$@*'9#87)D*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM
M<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B
M0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA
M;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM
M<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F]N('-E(&%T;W!O=2!O(&%X96YT
M92!D92!N;W1I9FEC86-I\VX@)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM
M<V=S='(@(D-A;&5N9&%R:6\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@
M(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U
M="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L
M96%R('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E!E
M8VAA<B!A('AA;F5L82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS
M9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G
M:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E
M(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O
M<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R
M(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS
M9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*
M;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M<&'Q[6$B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(D-O;7!A\>UA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS
M9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@
M(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0HC+"!F
M=7IZ>0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")#:&%V92!D
M92!A8V-E<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P
M=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT
M86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D-O;G1I
M9&\@9&4@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN
M=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I
M9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B
M0V]P>2(*;7-G<W1R(")#;VUP8?'M82(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B0V%M<&\@:6UP;W)T861O.B`E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G
M:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@
M(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN
M9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S
M='(@(D9A;&QO=2#S(&-O;F5C=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(D9A
M;&QO(/,@86)R:7(@;R!M\V1U;&\@9&4@=&%R969A<R!D92!M86YT96UE;G1O
M("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R(")&86QL;R#S(&%B<FER(&\@;?-D=6QO(&1E('1A<F5F87,@9&4@
M;6%N=&5M96YT;R`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92!N;VX@
M<V4@8V]N9FEG=7)O=2!C;W)R96-T86UE;G1E(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O
M<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@
M(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B
M0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G
M:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S
M=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED
M(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G
M:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H
M<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM
M<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A
M=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*
M;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI
M>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#
M>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y
M<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB
M"FUS9W-T<B`B1&EA<FEA;65N=&4B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O
M:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM
M<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$
M871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")$:6%R:6%M96YT92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@
M(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@
M;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`B261E;G1I9&%D92!P<F5D971E<FUI;F%D82(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS
M9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(E5S87(@;R!V86QO<B!P;W(@
M9&5F96-T;R(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E;G1I9&%D
M92!P<F5D971E<FUI;F%D82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("))9&5N
M=&ED861E('!R961E=&5R;6EN861A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N
M<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$
M96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@
M8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$
M96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("))9&5N=&ED861E
M('!R961E=&5R;6EN861A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(')O=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E
M='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@
M4')O8FQE;2(*;7-G<W1R(")$97-C<FEC:?-N(&1O('!R;V)L96UA(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:6-I\VX@8V]M<&QE=&$Z(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(E)E>&ES='+A<F]N<V4@;W,@9&5T86QL97,@<&%R82!O(&%D;6EN:7-T
M<F%D;W(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I
M9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED
M(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!C
M:?-N<R!D92!V:7-U86QI>F%C:?-N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D
M(&9O<F5C87-T(@IM<V=S='(@(D]P8VGS;G,@9&4@=FES=6%L:7IA8VGS;B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS
M9W-T<B`B3W!C:?-N<R!D92!V:7-U86QI>F%C:?-N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O
M=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C
M=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3F]N(&%C8V5D
M82!D:7)E8W1A;65N=&4@82!<(FUA:6YT96YA;F-E+G!H<%PB(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN
M('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@
M(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED
M(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO
M860@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V
M,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")#;W)R96\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I
M9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@
M=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]5
M22YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B
M161I="!";&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y
M."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N
M<R!F;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E
M;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S
M:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!3
M86QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B0V]R<F5O
M(&5L96-T<O-N:6-O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1E(&-O
M<G)E;R!E;&5C='+S;FEC;SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0HC+"!F
M=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B
M3W5T<F$@:6YF;W)M86-I\VXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S
M='(@(D]P8VGS;G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A
M9V4N(@IM<V=S='(@(E-E;B!R97-U;'1A9&\N(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@
M<F5S=6QT+B(*;7-G<W1R(")396X@<F5S=6QT861O+B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C
M:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G
M:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I
M;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!5
M4DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B
M96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA
M;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)O(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO
M9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L
M871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN
M9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D
M871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R
M;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I
M;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O
M;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B
M171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS
M9W-T<B`B0V%D82`Q-2!M:6YU=&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X.0HC+"!F=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S
M='(@(D-A9&$@-2!M:6YU=&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S
M,"!S96-O;F1S(@IM<V=S='(@(D-A9&$@,S`@<V5G=6YD;W,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")#861A(#4@;6EN
M=71O<R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D-A9&$@:6YI8VEO
M(&1E('-E<VGS;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#861A(&UE9&EA(&AO<F$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")#861A
M(&UI;G5T;R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS
M9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B17AE;7!L;R!D92!V86QO
M<F5S.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L
M;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S
M971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R(")&86QL;W4@\R!R96-U<&5R87(@87,@<')E9F5R96YC:6%S
M+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B1F%L;&]U(/,@8V]N
M96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C=&%R
M(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@
M9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C
M=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S87-L+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")&86QL;W4@\R!A8G)I
M<B!A(&-O;F5X:?-N($Q$05`@82`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@
M7"(E<UPB+B(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O
M<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z
M("5S(@IM<V=S='(@(D9A;&QO=2#S(')E8W5P97)A<B!O($1.(&1O('5S=6%R
M:6\Z(%LE9%T@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED
M(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R;R!D92!I;7!O<G1A8VGS;CH@
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X
M-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@
M(D9A>"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L
M<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P
M"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS
M9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B
M1FEL92(*;7-G<W1R(")4[71U;&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G
M:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S
M='(@(DYO;64B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS
M9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G
M:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(
M86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@
M(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T
M"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R
M('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y
M<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L
M(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(").;W1A<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED
M(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S
M='(@(DYO;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&
M<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@
M(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO
M;B(*;7-G<W1R(")$97-C<FEC:?-N(&-O;7!L971A.B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&
M=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z
M>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").;VUE.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B
M1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O
M961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC
M+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D%X96YD82!D92!E
M;F1E<F5Z;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R
M"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED
M(")(96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B
M<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE
M:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L
M<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*
M(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O
M:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B07AU9&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED
M(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS
M9W-T<B`B07AU9&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@
M(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G
M:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO('!A<G1I8W5L87(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B
M5&5LZ69O;F\@<&%R=&EC=6QA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N
M9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO
M;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U
M"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO
M(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED
M(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E
M<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R
M964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@
M(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I
M9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B
M2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N
M9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S
M(@IM<V=S='(@(D5N9&5R97IO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N
M<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N
M('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T
M(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O
M<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W
M"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L
M87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS
M9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*
M;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G
M92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D
M:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G
M:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM
M86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F
M<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G
M92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G
M<W1R(")#86UP;R!I;7!O<G1A9&\Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@
M9FEE;&0Z("5S(@IM<V=S='(@(D-A;7!O(&EM<&]R=&%D;SH@)7,B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F
M:65L9',Z(@IM<V=S='(@(D-A;7!O<R!I;7!O<G1A9&]S.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM
M<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O
M<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U
M>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M+B(*;7-G<W1R(")!8VAE9W5E(&\@<V5U(&YO;64@9&4@=7-U87)I;R!E(&-H
M879E(&1E(&%C8V5S;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*
M;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN
M9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M-PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B02!S^F$@
M:6YF;W)M86-I\VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED
M("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("))
M;G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED
M("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B
M26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM
M<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*
M;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G
M:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED
M("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@
M(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@
M;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T
M('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS
M97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@
M<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T
M:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R
M="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF
M>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT
M96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED
M("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I
M9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B
M26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED
M("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN
M=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME
M>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR
M-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PIM<V=I9"`B
M26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U8W0@
M8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@
M(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B
M26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED
M("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@
M36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B
M27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B1&EA
M<FEA;65N=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB
M2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@
M86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C
M=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS
M9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I
M9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA
M;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS
M9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I
M9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T
M"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME
M>2!5<V%G92(*;7-G<W1R(")-96YS87AE(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA
M;F=U86=E(@IM<V=S='(@(DQI;F=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B
M3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S
M="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(E!E8VAA<B!A
M('-E<VGS;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")%>&5M<&QO(&1E('9A;&]R
M97,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM
M<V=I9"`B3&5V96PB"FUS9W-T<B`B3G5N8V$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@
M1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*
M;7-G<W1R(")%;G1R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H
M="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*
M;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM
M<V=I9"`B3&EN:R(*;7-G<W1R(")%;G1R87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS
M9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A
M8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B3&ES=&%R(&]S
M('1E;6%S(&1E(&%X=61A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM
M<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1A
M<B!O<R!T96UA<R!D92!A>'5D82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),
M:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@
M(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@
M(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@
M(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C
M:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y
M,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")%;G1R87(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U
M<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")096-H
M87(@82!S97-I\VXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@
M9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(D5N=')A<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(%1A
M<VMS(@IM<V=S='(@(E1A<F5F87,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.38*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN(@IM<V=S='(@(B(*(E!O<B!A;&=U;FAA(')A>O-N(&YO;B!S92!D
M974@:6YI8VEA9&\@82!S97-I\VXN(%!R;V)A8FQE;65N=&4@97-C<FEB:74@
M(@HB:6YC;W)R96-T86UE;G1E(&\@;F]M92!D92!U<W5A<FEO(&]U(&$@8VAA
M=F4@9&4@86-C97-O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY
M,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E
M>'0B"FUS9W-T<B`B4&5C:&%R(&$@<V5S:?-N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU
M;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O
M=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C
M:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*
M;7-G:60@(DUA9VEC(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")#;W)R96\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL
M($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA
M;&%W:2(*;7-G<W1R(")#;W)R96\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA
M;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-
M86QI(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B36%L=&$B"FUS9W-T<B`B0V]R<F5O(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-
M87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W
M"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS9VED
M(")-87)G:6XB"FUS9W-T<B`B079I<V\B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C
M:&EN9R!F:65L9',B"FUS9W-T<B`B0V%M<&]S(&-O<G)E<W!O;F1E;G1E<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*
M;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS
M9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA
M<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU
M;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@HC+"!F
M=7IZ>0IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-96UO<F%N9&]S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-96YS87AE(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*
M(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R
M)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB
M"FUS9W-T<B`B365N<V%X92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G
M:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")-96YS87AE(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")297AI<W1RX7)O;G-E(&]S(&1E
M=&%L;&5S('!A<F$@;R!A9&UI;FES=')A9&]R+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O
M;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S
M;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<
M(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@
M;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T
M87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`B0V]R<F5O
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*
M;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-
M:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S
M=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U
M>GIY"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B17)R;R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB
M87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M
M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R
M97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS
M9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM
M<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED
M(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE
M87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-96YS=6%L
M;65N=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM
M<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO
M=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED
M(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS
M9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS
M9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*
M;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@26YF
M;W)M871I;VXB"FUS9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC.B!S97)V
M:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I
M9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/
M5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(").;VUE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!
M;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*
M;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED
M(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P
M92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO
M;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W
M;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYU;F-A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY
M"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B0VAA=F4@9&4@86-C97-O
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0HC+"!F=7IZ>0IM
M<V=I9"`B3F5W<R(*;7-G<W1R(").;W1A<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE
M>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED
M(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B
M4F5G<F5S87(@X7,@;W!C:?-N<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYU;F-A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED
M(").;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF
M9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED
M(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").
M;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L
M(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-
M0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@
M82!C;VYF:6=U<F%C:?-N('!A<F$@82!A=71E;G1I9FEC86-I\VX@<&]R(%-1
M3"XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")$97-F86-E<B!O<R!C86UB:6]S(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*
M;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@
M87,@8V%T96=O<NUA<R!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,C0*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(").;VX@
M97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@87,@<')E9F5R96YC
M:6%S($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*
M(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").;VX@97-P96-I9FEC
M;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@87,@8V%T96=O<NUA<R!344PN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PHC+"!F=7IZ
M>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B3F]N(&5S<&5C:69I8V]U
M(&$@8V]N9FEG=7)A8VGS;B!P87)A(&%S(&-A=&5G;W+M87,@4U%,+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED
M(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE
M('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").
M;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").
M;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C
M:?-N('!A<F$@82!A=71E;G1I9FEC86-I\VX@<&]R(%-13"XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N
M('!A<F$@82!A=71E;G1I9FEC86-I\VX@<&]R(%-13"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DYO;B!E<W!E8VEF:6-O=2!A(&-O;F9I9W5R86-I\VX@<&%R82!A(&%U
M=&5N=&EF:6-A8VGS;B!P;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@
M3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I
M<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@
M(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I
M9"`B3F\@<G5L97,B"FUS9W-T<B`B3F]T87,B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S
M(@IM<V=S='(@(DYO=&%S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q
M"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@
M<V5N="XB"FUS9W-T<B`B06-H96=U92!O('-E=2!N;VUE(&1E('5S=6%R:6\@
M92!C:&%V92!D92!A8V-E<V\B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ
M>0IM<V=I9"`B3F]N92(*;7-G<W1R(")496SI9F]N;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@
M*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM
M<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F]T87,B"@HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").
M;W1E<R(*;7-G<W1R(").;W1A<R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN
M9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<U"B,L(&9U>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").
M=6YC82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z
M>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(").;VUE(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM
M<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@
M(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S
M=V]R9"(*;7-G<W1R(")#:&%V92!D92!A8V-E<V\B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N
M;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/
M;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@
M;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS
M(@IM<V=S='(@(D]P8VGS;G,B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P8VGS;G,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS
M9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ
M:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS
M9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO
M;B(*;7-G<W1R(")/=71R82!I;F9O<FUA8VGS;B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM
M<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M
M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G
M:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM
M<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#
M;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P
M"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@
M(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS
M9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@
M(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")0
M87)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S
M='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T
M(@IM<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM
M<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S
M='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C
M;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN
M9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R(")&=6YC:?-N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")296%L:7IA<B!O<&5R
M86-I\VYS(&1E(&UA;G1E;65N=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#`V"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E)E86QI>F%R(&]P97)A8VGS
M;G,@9&4@;6%N=&5M96YT;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC
M.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"B,L(&9U>GIY
M"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")/=71R82!I
M;F9O<FUA8VGS;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496SI9F]N;R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT
M:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I
M9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*
M;7-G<W1R(")!8VAE9W5E('5N(')E<W5M;R!D;R!P<F]B;&5M82XB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D(@IM<V=S='(@(D%C:&5G=64@;R!S974@;F]M92!D
M92!U<W5A<FEO(&4@8VAA=F4@9&4@86-C97-O(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L
M;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O
M('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE
M87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O
M;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@
M=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@
M=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E
M<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP
M.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q
M=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@
M(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*
M(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B4F5G
M<F5S87(@X7,@;W!C:?-N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM
M<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE
M;2(*;7-G<W1R(");26YF;W)M92!D;R!0<F]B;&5M85TB"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B1&5S8W)I8VGS;B!D;R!P<F]B;&5M82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+
M97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS
M9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T
M92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")2
M86EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN
M('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*
M;7-G:60@(E)E860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S
M<V%G97,B"FUS9W-T<B`B365N<V%X92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S
M:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(E)E9G)E<V@@
M4&]R=&%L(%9I97<Z(@IM<V=S='(@(D%C='5A;&EZ87(@82!V:7-T82!D;R!R
M97-U;6\Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R
M;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B
M4F5L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V
M"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M
M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO
M=F4@0FQO8VLB"FUS9W-T<B`B4V%C87(@;R!P87(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M
M871T:6YG(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@
M(E-A8V%R(&\@<&%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM
M<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")386-A<B!O('!A<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")386-A
M<B!O('!A<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S
M(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS
M=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(D\@8V%M<&\@<F5Q=6ER:61O("=U:60G(&YO;B!F
M;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R86-I\VX@9&%S("(*(G!R969E
M<F5N8VEA<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3R!C86UP;R!R97%U:7)I9&\@)W5I
M9"<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A8VGS;B!D87,@
M(@HB<')E9F5R96YC:6%S+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@HB3R!C86UP;R!R97%U:7)I9&\@)W5I9"<@;F]N(&9O:2!E<W!E8VEF:6-A
M9&\@;F$@8V]N9FEG=7)A8VGS;B!D87,@(@HB<')E9F5R96YC:6%S+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S
M=V]R9"(*;7-G<W1R(")#:&%V92!D92!A8V-E<V\B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED
M(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")2
M96=R97-A<B#A<R!O<&-I\VYS(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS
M9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B4F5G<F5S
M87(@X7,@;W!C:?-N<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM
M<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G
M:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S
M-`IM<V=I9"`B4F]L92(*;7-G<W1R(")&=6YC:?-N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G
M:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@
M4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`B1G5N8VGS;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B
M4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@
M1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA
M='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*
M;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC
M+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")-96YS87AE
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM
M<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")3
M4T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T53
M4R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U
M96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6
M:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")3
M86UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM
M<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I
M9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R
M86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E
M<R(*;7-G<W1R(")'87)D87(@87,@;W!C:?-N<R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")'
M87)D87(@87,@;W!C:?-N<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4
M+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS
M9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&$@9&%T92(*;7-G<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D
M82!D871A.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS
M9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W
M(&]W;F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@
M82!U<V5R('1O(&%D9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@86QL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G
M<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D82!D871A.B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E
M;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U
M>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B
M"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB
M4V5L96-C:6]N92!O<R!C87)A8W1E<F5S('%U92!N96-E<VET92!D87,@8W5A
M9'+M8W5L87,@<75E(&%T;W!A<N$@;6%I<R`B"B)A8F%I>&\N(%!O9&4@8V]P
M:6%L;W,@92!P96=A;&]S(&1E;F1E(&$@X7)E82!D92!T97AT;RXB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-C:6]N92!O(&1E;&EM:71A
M9&]R(&1A(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*
M;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E-E;&5C
M8VEO;F4@;R!F;W)M871O(&1A(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE8V-I;VYE(&\@9&5L
M:6UI=&%D;W(@9&$@9&%T83HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B
M4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@:&]R83HB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RXB"FUS9W-T<B`B4V5L96-C:6]N92!D;W5S(&-A;7!O<R!Q=64@
M8V]I;F-I9&%N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G
M:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")396QE8V-I;VYE(&$@;&EN
M9W5A.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS
M9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D5N=FEA<B!O(&EN
M9F]R;64@9&4@<')O8FQE;6%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A
M;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS
M9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I
M;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X
M<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ
M>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B1V%R9&%R(&%S(&]P8VGS;G,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED
M(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*
M(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@HB17-T86)L
M96-E(&$@9G)E8W5E;F-I82!D92!A8W1U86QI>F%C:?-N(&1A<R!PX7AI;F%S
M(&4@;W5T<F%S(&]P8VGS;G,@9&4@(@HB=FES=6%L:7IA8VGS;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(B(*(E-E
M="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*
M;7-G<W1R("(B"B)%<W1A8FQE8V4@82!F<F5C=65N8VEA(&1E(&%C='5A;&EZ
M86-I\VX@9&%S('#A>&EN87,@92!O=71R87,@;W!C:?-N<R!D92`B"B)V:7-U
M86QI>F%C:?-N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G
M:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z
M>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B4F5S=6UO(&)R979E
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@
M8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G
M9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS
M9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N
M=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W
M('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO
M=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G
M:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I
M9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U
M"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*
M;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3VUI=&ER(&\@
M;6%N=&5M96YT;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3
M;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R
M<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X
M"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA
M;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM
M<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@
M861D<F5S<R(*;7-G<W1R(")%;F1E<F5Z;R!D;R!T<F%B86QL;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G
M:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A
M:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX
M"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`B16YT<F%D82!D92!C87)A8W1E<F5S(&5S<&5C:6%I<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G
M:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*
M;7-G:60@(E-P;W)T<R(*;7-G<W1R("));7!O<G1A<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L
M(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")#86QE;F1A<FEO(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B
M4W1A='5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,34*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@
M(D$@<_IA(&EN9F]R;6%C:?-N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S
M(@IM<V=S='(@(D5N9&5R97IO(&1O('1R86)A;&QO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME
M=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL
M92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(").;VX@<V4@871O<&]U(&\@87AE;G1E(&1E(&YO=&EF:6-A8VGS;B`E<RXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S
M"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G
M(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B
M4W5C8V5S<R(*;7-G<W1R(")#;W)R96-T86UE;G1E(@H*(SH@861M:6XO=7-E
M<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S
M<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@
M8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY
M"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E)E<W5M;R(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N
M<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U>GIY"FUS9VED(")3=7!P
M;W)T(@IM<V=S='(@(DEM<&]R=&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ
M>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B57-U87)I;R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED
M(")3=7)N86UE(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@
M(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R
M;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R
M86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*
M;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T
M;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F=7IZ
M>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E1A8FQE
M(@IM<V=S='(@(E3M='5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW
M86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B5&%S:W,B"FUS9W-T<B`B5&%R969A<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M
M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS
M9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I
M9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E
M<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@
M(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT
M=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*(RP@9G5Z>GD*
M;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B1FEN86QI>F]U(&$@<V5S:?-N+CQB<B`O/D=R86-I87,@<&]R('5S87(@
M;R!S:7-T96UA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P
M"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I
M;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*;7-G
M:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I
M9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L
M;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B
M"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I
M9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM
M<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A
M;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O
M;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W
M:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N
M<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I
M='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*
M;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB
M5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E
M;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U
M8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")4:&4@
M;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(D\@
M=F%L;W(@9&5B92!S97(@=6X@;OIM97)O+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@
M7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP
M.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP
M.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G
M:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@
M(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B
M5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T
M8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM
M<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V
M,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS
M9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92XB"FUS9W-T<B`B3F]N(&AA:2!P<F5F97)E;F-I87,@9&ES
M<&_Q:6)L97,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@
M9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R
M(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A
M9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F
M;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U
M<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I
M9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0HC+"!F
M=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N(@IM<V=S='(@(D\@=F%L;W(@9&5B92!S97(@=6X@;OIM
M97)O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A
M9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@
M(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R
M(")/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R;RXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@
M8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F
M;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A
M;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES
M(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L
M86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@
M=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S
M('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U
M8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I
M;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM
M<V=S='(@(D\@;OIM97)O(&1E8F4@<V5R('!O;&\@;65N;W,@=6X@,2XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+B(*;7-G<W1R(")/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R
M;RXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS
M9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R
M."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G
M:60@(E1I;64B"FUS9W-T<B`B5.UT=6QO(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*
M;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E3M='5L;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*
M;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B
M5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS
M9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L
M:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED
M(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G
M86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q
M,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E
M<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE
M(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B3F]N(&9O:2!P;W-I
M8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@
M8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE
M(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N
M96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T
M87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DYO;B!F;VD@
M<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<
M(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&UO
M9&EF:6-A<B!A<R!P<F5F97)E;F-I87,Z(%LE9%T@)7,B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R
M,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@
M8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F]N(&9O
M:2!P;W-I8FQE(')E>&ES=')A<B!A<R!P<F5F97)E;F-I87,@;F$@<V5S:?-N
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS
M9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE
M8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B3F]N(&9O:2!P;W-I
M8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(").
M;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV
M-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R
M=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@=')A
M9'5C:7(@97-T92!D;V-U;65N=&\@9&4@5V]R9"(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T
M,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R(")$97-F86-E<B!O<R!C86UB:6]S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S
M('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED
M(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN
M9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@
M4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B
M56YN86UE9"(*;7-G<W1R(")5<W5A<FEO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E
M="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM
M<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S
M97(B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5
M<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE
M+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B57-U87)I;R(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G
M<W1R(")/<&-I\VYS(&1O('5S=6%R:6\B"@HC.B!S:6=N=7`N<&AP.C8R"B,L
M(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")/<&-I
M\VYS(&1O('5S=6%R:6\B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS
M9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(E5S=6%R
M:6\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X
M:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B57-U
M87)I;R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z
M>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B57-U87)I;R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN
M('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM
M<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@
M(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@
M=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@
M9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*
M;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M
M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G
M:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@
M(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX
M,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!=FES;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM
M<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@
M<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3
M:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")396UA;F%L
M;65N=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F
M=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")"96YV:61O+V$L("5S(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@
M=&\@)7,B"FUS9W-T<B`B0F5N=FED82!A("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D)E
M;G9I9&\O82P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I
M9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA
M<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H
M87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA
M(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G
M:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G
M:60@(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*
M;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME
M<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B
M5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U
M;FET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7
M:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@
M:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*
M;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7
M:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B
M"FUS9W-T<B`B16YD97)E>F\@9&\@=')A8F%L;&\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H
M;VYE(@IM<V=S='(@(E1E;.EF;VYO(&1O('1R86)A;&QO(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G
M:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R
M"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z
M>GD*;7-G:60@(EE965DB"FUS9W-T<B`B04$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B06YU86QM96YT
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G
M:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS
M9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D%C='5A
M;&EZX7)O;G-E(&%S('/Z87,@;W!C:?-N<RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG
M('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B
M86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="XB"FUS9W-T<B`B1&5S8W)I8F$@;R!P<F]B;&5M82!A;G1E<R!D
M92!E;G9I87(@;R!I;F9O<FUE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T
M96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D
M('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+B(*;7-G<W1R(")#861U8V]U(&$@<_IA('-E<VGS;B!E
M;B`E<R!E>'!I<F]U+B!);FEC:64@=6YH82!N;W9A('-E<VGS;BXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1E(&-O
M<G)E;R!E;&5C='+S;FEC;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S
M='(@(D5N9&5R97IO(&1E(&-O<G)E;R!E;&5C='+S;FEC;SHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B02!S
M^F$@:6YF;W)M86-I\VXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE
M(@IM<V=S='(@(DYO;64Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@
M=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@
M>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA
M<R!B965N(&-H86YG960N(@IM<V=S='(@(D%C='5A;&EZX7)O;G-E(&%S('/Z
M87,@;W!C:?-N<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@
M(DED96YT:61A9&4@<')E9&5T97)M:6YA9&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C`Q"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M93HB
M"FUS9W-T<B`B3F]M93HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ
M,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*
M;7-G<W1R(")!8W1U86QI>N%R;VYS92!A<R!S^F%S(&]P8VGS;G,N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")!8W1U
M86QI>N%R;VYS92!A<R!S^F%S(&]P8VGS;G,N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"XB"FUS9W-T<B`B06-T=6%L:7KA<F]N<V4@87,@<_IA
M<R!O<&-I\VYS+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U
M"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B
M"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M
M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M
M;W1E('-E<G9E<G,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!2
M97!O<G1=(@IM<V=S='(@(EM);F9O<FUE(&1O(%!R;V)L96UA72(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S
M='(@(EML:?%A("5S(&1E("5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED
M(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B
M7T1E;&5T92!2;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS
M9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S
M='(@(D%X=61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(D5N=')A
M<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@
M9G5Z>GD*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E!E8VAA<B!A('-E<VGS
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z
M>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(D]P8VGS;G,B"@HC.B!L:6(O
M87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R
M(")386-A<B!O('!A<B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E
M='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?
M57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")!
M>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U
M>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")#86QE;F1A<FEO(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N
M;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P
M96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED
M(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I
M9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F
M:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A
M;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#4U"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(E3M='5L
M;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M
M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B
M9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED
M(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@(DYO;64B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M
M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED
M(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*
M;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R
M;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T
M<B`B079I<V\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E
M<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A4
M5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P
M.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S
M>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M
M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G
M<W1R(")#861A(&EN:6-I;R!D92!S97-I\VXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*
M;7-G:60@(G9#87)D(@IM<V=S='(@(E1A<GAE=&$@9&4@=FES:71A("AV0V%R
M9"DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!O+VAE7TE,+G!O````````````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V,#(P-C0`,3`T,3<S-C,P,#$`
M,#$V,S4R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",@2&5B<F5W('1R86YS;&%T:6]N<R!F;W(@2&]R9&4@<&%C:V%G92X*
M(R!#;W!Y<FEG:'0@*$,I(#(P,#8@36%T="!396QS:WD@/'-E;'-K>4!C;VQU
M;6)I82YE9'4^"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H
M92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@075T;VUA
M=&EC86QL>2!G96YE<F%T960L(#(P,#8N"B,*;7-G:60@(B(*;7-G<W1R("(B
M"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,BUC=G-<;B(*(E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-BTP,BTP-R`P-#HP."TP-3`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`V+3`R+3`W(#`T.C`X+3`U,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@36%T="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^
M7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U55$8M.%QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S@Q"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@S"FUS9VED("(@*'1O;6]R
M<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<Y"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,"!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S4S"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M.3D*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<P,PHC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I
M<W1R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z
M,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H
M92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4S(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C
M<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,C8W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C
M87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#$@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@S.2!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@34(B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-CDP(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S0W"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#,T(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,2!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W-R!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U-R!L:6(O0FQO8VLO;65T87(N<&AP
M.C,V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@
M(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S0X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E
M<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@
M;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N
M($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F
M('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S4W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#(*;7-G
M:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R
M:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S4P(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,CDT"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$S-@IM<V=I9"`B+2T@<V5L96-T("TM
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR-0IM<V=I9"`B
M,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C(T"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I
M9"`B/%!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3,Q"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@
M9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!(&UE<W-A9V4@
M:&%S(&)E96X@<V5N="!T;R!<(B5S7"(@=&\@=F5R:69Y('1H870@=&AI<R!I
M<R!R96%L;'D@>6]U<B`B"B)A9&1R97-S+B!4:&4@;F5W(&5M86EL(&%D9')E
M<W,@:7,@86-T:79A=&5D(&%S('-O;VX@87,@>6]U(&-O;F9I<FT@=&AI<R`B
M"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG
M:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I
M9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS
M9VED(")!32]032(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@
M(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS
M9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ
M-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM
M<V=I9"`B061D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(R
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(S"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP.C<R"FUS9VED(")!9&0@0V]N=&5N="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE
M<F4Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$V(&%D;6EN
M+V=R;W5P<RYP:'`Z,C$W"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M
M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C(Y"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4U.`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W
M(&UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS
M9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D
M9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S`*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G
M:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#D*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T.`IM<V=I9"`B
M061D<F5S<R!";V]K(@IM<V=S='(@(M>AUZ37J"#7F]>JUY77D=>5UZHB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B
M061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q
M,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B061S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(M>0UZ37
MDM>@UYG7H=>JUY\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM<V=S
M='(@(M>0UYS7D=>@UYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0*;7-G:60@(D%L9V5R:6$B
M"FUS9W-T<B`BUY#7G->2UZC7F=>4(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM
M96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*
M;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS
M9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C,R(&%D;6EN+V=R;W5P<RYP:'`Z,C(P"FUS9VED
M(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E
M+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-SD*;7-G:60@(D%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,W"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T
M>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HU,3@*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R
M;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA
M:6P@861D<F5S<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T,0IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(W"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C`*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S
M(&]C8W5R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38*;7-G:60@(D%N9&]R
M<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-`IM<V=I9"`B06YG;VQA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N
M;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`BUYG7D=>IUZKB@)/7
MD->@UYC7D->HUZ?7F->9UZ?7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D*;7-G:60@(D%N=&EG
M=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C,S(&%D;6EN+W1E;7!L871E<RYP:'`Z-S,*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HT"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI
M<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM
M<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#
M:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,Y(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,0IM<V=I9"`B07!P<F]X
M:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D%R86)I8R`H5VEN
M9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-S@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-@IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*;7-G:60@(D%R8VAI=F4@
M3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P
M<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-@IM<V=I9"`B07)G96YT:6YA(@IM
M<V=S='(@(M>0UZC7DM>@UYC7F=>@UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!
M<FUE;FEA(@IM<V=S='(@(M>0UZC7GM>@UYG7E"(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@R"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D%R
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P"FUS9VED(")!<G5B82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!
M<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-`IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I
M9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-@IM<V=I9"`B07-S:6=N;65N="!C
M;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S,*;7-G
M:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(X"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-@IM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,@IM
M<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0IM<V=I
M9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,CD*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("+7D->5
MUZ'7F->HUYS7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.`IM<V=I9"`B075S=')I82(*;7-G
M<W1R("+7D->5UZ'7F->HUYG7E"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HS,38*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S,0IM<V=I9"`B075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S0*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]F='`N<&AP.C4V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@
M1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE
M("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`T"FUS9VED(")!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,PIM<V=I9"`B
M075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S`Q"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4V"FUS9VED(")!=71H7VQD
M87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HY,@IM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S
M97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HT,#0*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HV,@IM<V=I9"`B
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX
M-@IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@
M24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ.#(*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#8P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW
M,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Q"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I
M9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@R"FUS9VED(")"860@:V5R8F5R;W,@<&%S
M<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z.#0*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-0IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("+7D->9
MUYGB@)/7D=>4UY[7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@*;7-G:60@(D)A:')A:6XB"FUS
M9W-T<B`BUY'7E]>HUYG7F=>?(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#,*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S0*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`BUY'7H->2UYS7
MD]>I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,PIM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.0IM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT.0IM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,U"FUS9VED(")"96QG:75M(@IM<V=S='(@(M>1UYS7DM>9UY0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4P"FUS9VED(")"96QI>F4B"FUS9W-T<B`BUY'7G->9UY8B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0P"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q"FUS
M9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8*;7-G:60@(D)H
M=71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8U"B,L
M('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO
M;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW,@IM
M<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,PIM<V=I9"`B0F]L:79I82(*;7-G<W1R("+7D=>5
MUYS7F=>1UYG7E"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*
M;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,R"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HQ,#$*;7-G:60@(D)O=&@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B
MUY'7E=>FUY77E=>@UY0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C(*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0W"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#0*;7-G:60@(D)R87II;"(*;7-G<W1R("+7D=>HUY;7F=><
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3<*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R"FUS9VED(")"<G5N96D@
M1&%R=7-S86QA;2(*;7-G<W1R("+7D=>HUY77H->9UYDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W
M"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8*;7-G:60@(D)U<FMI;F$@1F%S
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y"FUS9VED(")"=7)U;F1I(@IM<V=S
M='(@(M>1UY77J->5UZ#7D]>9(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0V-PIM<V=I9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM
M<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-38*;7-G:60@(D-A8VAE
M(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#<@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P-3$*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$V-`IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T,`IM<V=I9"`B0V%L;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R.`IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`BUZ?7GM>1
MUY77D]>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8P"FUS9VED(")#86UE<F]O;B(*;7-G<W1R
M("+7I]>>UZC7E=>?(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,0IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S,P(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(T,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,0IM<V=I9"`B0V%N861A(@IM<V=S='(@(M>GUZ#7
MD]>4(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P(&%D;6EN+W5S97(N<&AP.C$Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$Q"FUS9VED(")#86YC96PB"FUS9W-T<B`BUZG7
MH->4(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3(*;7-G
M:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@IM<V=I
M9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP
M.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO
M=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,C(*;7-G
M:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C4*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`BUZ?7I->4(->5UZC7D]>4
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A
M<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS
M"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S4*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G
M:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-E
M;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E
M;G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T"FUS9VED(")#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`BUY37I]>4UYG7G->9UYG7E"#7E->>
MUZC7F]>6XH"3UY#7I->HUYG7I]>@UYG7JB(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I
M9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E
M(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,0IM<V=I9"`B0VAA
M9"(*;7-G<W1R("+7IM>3(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H
M87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y"FUS9VED(")#:&EL92(*;7-G<W1R("+7
MIM>9UYS7F2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C$*;7-G:60@(D-H:6YA(@IM<V=S='(@(M>A
MUYG7GR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,0IM<V=I9"`B0VAO
M;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I
M9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-@IM<V=I9"`B0VAR
M:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.3<Y(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`BUZG7GM>9UYT@
MUY'7E->9UZC7G2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R-@IM<V=I9"`B0VQE87(@
M475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E
M<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*
M;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM
M<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS
M9W-T<B`BUZG7GM>9UYT@UY[7HM>5UZ#7H->9UYTB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R"FUS
M9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(T"FUS9VED(")#;VQL87!S
M92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B
M;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(*;7-G:60@(D-O;&]M8FEA
M(@IM<V=S='(@(M>GUY77G->5UY[7D=>9UY0B"@HC.B!L:6(O0FQO8VLO8V]L
M;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B
M0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4P-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS,S<@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,SD*;7-G:60@(D-O;&]U<B!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-30*;7-G:60@(D-O;'5M;B!T:71L
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X
M,`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR,PIM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,3@*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-@IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3`*;7-G:60@(D-O;F1I=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V,0IM<V=I9"`B0V]N
M9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY
M-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U
M<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD
M($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3(*;7-G:60@(D-O;F9I
M<FT@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y
M+TED96YT:71Y+G!H<#HT,#<*;7-G:60@(D-O;F9I<FT@;F5W(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-0IM<V=I9"`B0V]N9V\B"FUS
M9W-T<B`BUZ?7E=>@UY+7E2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@U-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P.38*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D
M(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X"FUS9VED(")#;V]K($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED
M(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#4S"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS
M9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8S"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@
M(M>GUY77H=>8UY0@UZC7F=>GUY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W"FUS9VED(")#;W1E
M(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE
M<W-A9V4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS
M9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,34V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E
M<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T83H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q"FUS9VED(")#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@
M9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<
M(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS
M9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*
M(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3D@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@
M;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS
M9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P
M"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C<*
M;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDV"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A
M=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(R,PIM
M<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0*;7-G
M:60@(D-U8F$B"FUS9W-T<B`BUZ?7E=>1UY0B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]"
M;&]C:R]T:6UE+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`*;7-G:60@
M(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G
M:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-PIM<V=I
M9"`B0WEP<G5S(@IM<V=S='(@(M>GUZ37J->9UZ'7F=>?(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@*;7-G:60@(D-Z96-H(%)E
M<'5B;&EC(@IM<V=S='(@(M>FUYO7F=>4(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-"!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,PIM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]D871A=')E92YP:'`Z-C,*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M,0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0P-@IM<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B
M1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`P"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,30*;7-G:60@(D1A>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED
M(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W
M(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W
M"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E
M;G1I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W
M"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,Q('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`IM
M<V=I9"`B1&5L971E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E
M($-E;&PB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3<@861M
M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@
M(D1E;&5T92!,;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I
M9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M-PIM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U
M<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.34*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW,0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("+7D]>@UYG7E"(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(W"FUS9VED(")$97-C<FEB
M92!T:&4@4')O8FQE;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S4*;7-G:60@
M(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(Y"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R,0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.30*;7-G:60@(D1I<W!L
M87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HY-PIM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$P"FUS
M9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I
M9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,`IM<V=I9"`B1&II8F]U
M=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@
M=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<R"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<S"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`BUY37J->DUY77D=><UYG7I]>4(->4UY/7E=>>UYG7H->9UZ?7H->9UZHB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@X"FUS9VED(")$;VXG
M="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U-PIM<V=I9"`B1&]W
M;FQO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#4W"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G
M:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,34*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1')U9W,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")$>6YA
M;6EC($UA:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@
M(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H
M:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-0IM
M<V=I9"`B16-U861O<B(*;7-G<W1R("+7D->GUY77E=>3UY77J"(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET
M($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DV(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(T"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,V"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O
M<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0P"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-PIM
M<V=I9"`B16=Y<'0B"FUS9W-T<B`BUY[7IM>HUYG7G2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`BUY#7G.*`D]>AUYS7E=>5
MUY/7E=>H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y
M"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S<*;7-G:60@(D5M86EL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ,`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HT-3`*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!T;R!C;VYF:7)M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DY-PIM<V=I9"`B16UA:6P@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E
M=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS,#$*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW
M,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@
M(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-30*;7-G
M:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,C$*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-`IM<V=I9"`B16YD
M('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB
M16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A
M<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HX.30*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDY"FUS9VED(")%<75A=&]R:6%L($=U:6YE
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y"FUS9VED(")%<FET<F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-3,*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HT,0IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E
M+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@
M8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D
M96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<V"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$*;7-G
M:60@(D5T:&EO<&EA(@IM<V=S='(@(M>0UZK7F=>5UZ37F=>4(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%
M=7)O<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C$P,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS
M9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R
M>2`U(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C$P,PIM<V=I9"`B179E<GD@:&]U<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R
M>2!M:6YU=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z-#@@861M:6XO<&AP<VAE;&PN<&AP.C<Y
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C4*;7-G:60@(D5X96-U=&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A;F0@4VED96)A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S
M971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR-#4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HQ,#$*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S`S"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#D*;7-G:60@
M(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-3(@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0*;7-G:60@(D9A;&ML86YD($ES;&%N
M9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V"FUS9VED(")&
M87)O92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED
M(")&87@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,V-0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")&
M965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C4*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU
M,@IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(D9I9VQE="!#05!40TA!(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-#`*;7-G
M:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,*;7-G:60@
M(D9I:FDB"FUS9W-T<B`BUZ37F=>2UYDB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,P"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3@X
M"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#DT"FUS9VED(")&:6QE('5P;&]A9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#8*
M;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(D9I;'1E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,@IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R("+7I->9UZ#7G->@UY,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V
M"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T
M(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,S`*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("+7HM>HUZ37G"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HR-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S
M(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED
M(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#8*;7-G:60@(D9O<F5C87-T("A4048I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW
M-PIM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B
M"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDT"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-0IM<V=I9"`B1F]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(V"FUS9VED
M(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HQ,#0*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B1F]R='5N
M97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<V"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM
M<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#<*;7-G:60@(D9R86YC92(*;7-G<W1R("+7IM>H
MUZ37JB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,0IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C(*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,U,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDX"FUS
M9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#(*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHV,0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#@*;7-G:60@(D=A8F]N(@IM<V=S='(@(M>2UY'7E=>?(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.38*;7-G:60@(D=A;6)I82(*;7-G<W1R("+7DM>>UY'7F=>4
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HV"FUS9VED
M(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP"FUS9VED
M(")'96]R9VEA(@IM<V=S='(@(M>2UY77J->2UYG7E"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD*
M;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`BUY+7J->>UZ#7F=>4(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,PIM<V=I9"`B1VAA;F$B"FUS9W-T<B`BUY+7H->4(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G
M<W1R("+7G->:(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED
M(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,S,*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O
M;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B1W)A>7-C86QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`P"FUS9VED(")'<F5E8V4B"FUS9W-T<B`BUYG7
ME=>5UY\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B1W)E
M96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34*;7-G:60@
M(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y"FUS9VED(")'<F5N
M861A(@IM<V=S='(@(M>2UZC7H->3UY0B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$W.`IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS
M9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.`IM<V=I9"`B1W5A
M9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,PIM<V=I9"`B1W5A;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,@IM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(M>2UY77D->8UY[7G->4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y,PIM<V=I9"`B1W5E
M<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<*;7-G:60@(D=U:6YE82(*
M;7-G<W1R("+7DM>9UZ#7D->4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T"FUS9VED(")'=6EN
M96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-0IM<V=I9"`B1W5Y
M86YA(@IM<V=S='(@(M>2UYG7D->@UY0B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M
M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A
M8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N
M<&AP.C$U-`IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,`IM<V=I9"`B2&%I=&DB"FUS9W-T
M<B`BUY37D->9UYC7F2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-0IM<V=I9"`B(@HB2&%V92!A(&)U
M='1O;B!I;B!T:&4@=&]O;&)A<B!T:&%T('!O<',@=7`@82!W:6YD;W<@=VET
M:"!S<&5C:6%L(&-H87)A8W1E<G,_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDR,R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(U"FUS9VED(")(96%D97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<*
M;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("+7H=>5UZ37JN*`
MD]>HUZ+7GM>9UYT@UZ+7EM>4(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3(*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TAE;'`N<&AP.C$X,2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M2&5L<"YP:'`Z,3@R"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E
M;7!L871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@
M(M>BUY;7J->4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W.0IM<V=I9"`B2&5L
M<&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I
M9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM
M<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,`IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N
M=2]M96YU+FEN8SHW"FUS9VED(")(;U]M92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0S"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*
M;7-G<W1R("+7E=>8UYG7I]>?(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-34U"FUS9VED(")(;VUE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!
M9&1R97-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@*;7-G:60@(DAO;F1U
M<F%S(@IM<V=S='(@(M>4UY77H->3UY77J->A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V"FUS
M9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y
M<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R
M,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,S,R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q
M"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,R!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T,@IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`BUYS7E]>5
MUZHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4S"FUS9VED
M(")(=6UI9&ET>3H@(@IM<V=S='(@(CK7G->7UYG7JB(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,0IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("+7E->5UZ#7
MDM>HUYG7E"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR
M,S0@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<P"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR.38@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T"B,L('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HR-#$@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<W"B,L
M('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(P"FUS9VED("))8V5L86YD(@IM<V=S='(@(M>0UYG7H=><
MUZ#7DR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC
M;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N
M<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y
M;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E
M<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF
M('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E
M('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM
M86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%52
M3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-CD*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-`HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R
M;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$V"FUS9VED("));F1I82(*;7-G<W1R("+7E->5UY/7E2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(M>0UYG7H->3UY77H->6UYG7E"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B26YF;W)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,R,@IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!
M9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM
M<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I
M9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM
M<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30Y"FUS9VED("));G-E<G0@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y
M"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM
M<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T
M(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN
M<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T
M(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@
M=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E
M<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I
M9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN
M=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I
M9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G
M:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DU(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(T,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S`W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@
M(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I
M9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B
M26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<P"FUS9VED("));G9A;&ED(&QI8V5N<V4@
M:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38T"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C(V"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38V"FUS9VED
M("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C@*;7-G:60@(DEN=F%L:60@<')O9'5C
M="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C
M;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT
M.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,#<U(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U.`IM<V=I
M9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G
M:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<S"FUS9VED("));G9E;G1O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8X,`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3D*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`BUY#7F=>HUY\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@*;7-G:60@(DER87$B
M"FUS9W-T<B`BUZ+7F=>HUZ<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,*;7-G:60@(DER96QA
M;F0B"FUS9W-T<B`BUY#7F=>HUYS7H->3(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS
M9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,30*;7-G:60@(DES<F%E;"(*;7-G<W1R("+7F=>IUX'7J->0UYPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S
M=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,0IM<V=I9"`B271A;'DB"FUS9W-T<B`BUY#7F=>8UYS7F=>4(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(S"FUS9VED(")*86UA:6-A(@IM<V=S='(@(M>2UY[7F=>9
MUZ?7E"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-0IM
M<V=I9"`B2F%P86XB"FUS9W-T<B`BUYG7I->?(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3,*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G
M:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0*;7-G:60@(DIO
M<F1A;B(*;7-G<W1R("+7F=>HUY/7GR(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS
M9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0P"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0IM<V=I
M9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8*;7-G
M:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA
M;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V"FUS9VED(")+96YY82(*;7-G
M<W1R("+7I]>@UYG7E"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#8*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME
M>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#@*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(Y"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(*
M;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,PIM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT
M"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,T"FUS9VED(")+=7=A:70B"FUS9W-T<B`BUYO7E=>5UYG7F=>J(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(W"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S4*;7-G:60@(DQA;F=U86=E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#
M:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI
M8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED("),87-T
M(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*;7-G:60@
M(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-@IM
M<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.0IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X"FUS9VED("),96)A;F]N(@IM
M<V=S='(@(M><UY'7H->5UY\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*;7-G:60@(DQE9G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,@IM<V=I9"`B3&5F
M="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$P.`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30S"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30R"FUS9VED("),:6)E<FEA(@IM<V=S='(@(M><UYG7
MD=>HUYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-PIM<V=I9"`B3&EB>6%N($%R86(@2F%M
M86AI<FEY82(*;7-G<W1R("+7G->5UY$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`*;7-G:60@
M(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI
M9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*
M;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED
M("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G
M:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X,C(*;7-G:60@(DQI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS
M9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@X,PIM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR
M=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HT-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*;7-G:60@(DQI<W0@
M1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(DQI<W0@5&%B;&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3`Y"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,#0*;7-G:60@(DQI<W0M2&5L
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Q,0IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P-PIM<V=I9"`B3&ES="U/=VYE
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4P.`IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`V"FUS9VED("),:7-T+5-U
M8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4P-0IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG
M('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3(*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30T"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I
M9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`U"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@
M86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S<@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C(R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP
M:'`Z,3@X('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#`@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHX,@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHS('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U"FUS9VED
M("),;V<@:6XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G:60@
M(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<S
M"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4S"FUS9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED("),;W<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU
M;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U"FUS9VED("),=7AE;6)O
M=7)G(@IM<V=S='(@(M><UY77F]>AUY[7D=>5UZC7DB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,2!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Y-PIM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I
M9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34W"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3,*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$*;7-G:60@
M(DUA9&%G87-C87(B"FUS9W-T<B`BUY[7D]>2UZ'7I]>H(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")-86=I8R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3`*;7-G:60@(DUA:6PB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4T-0IM<V=I
M9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@
M;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U"FUS9VED(")-86QA
M=VDB"FUS9W-T<B`BUY[7G->5UY77F2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-PIM<V=I9"`B
M36%L87ES:6$B"FUS9W-T<B`BUY[7G->9UYG7EM>9UY0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C0*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(M>4UY#7F=>9UYT@UY37GM><
MUY/7F=>5UY77F=>9UYTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30*;7-G:60@(DUA;&DB"FUS
M9W-T<B`BUY[7G->9(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R"FUS9VED(")-86QT82(*;7-G
M<W1R("+7GM><UYC7E"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM
M<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3@*;7-G:60@
M(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`X.0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$W,PIM<V=I9"`B36%P475E<W0@;6%P(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM
M<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0X"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,@IM<V=I9"`B36%R<VAA;&P@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D*;7-G:60@(DUA<G1I;FEQ=64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*
M;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C`*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`BUY[7D->5UZC7F=>8UZ#7
MF=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38S"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B
MUY[7D->5UZC7F=>FUYG7E=>A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C
M<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R
M=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$X"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS
M9VED(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,PIM<V=I9"`B36%Y
M;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*
M;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M
M;V1E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB
M365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G
M<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C8P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C`R"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T
M:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-#(*;7-G
M:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3(T"FUS9VED("(B"B)-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34X"FUS9VED(")-971A<D1"(&ES(&YO="!C
M;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-R!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C@Q"B,Z(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HX
M."!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z.#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H
M;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")-971R:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V"FUS9VED(")-97AI8V\B"FUS9W-T
M<B`BUY[7F]>AUYG7I]>5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4*;7-G:60@(DUI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"FUS9VED
M(")-:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,@IM<V=I9"`B36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$T"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.`IM
M<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,S"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")-:7-C96QL86YE;W5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!M
M=7-T(&=E;F5R871E(&ET(&)E9F]R92!U<VEN9R!T:&ES(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN
M9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PIM<V=I9"`B36]D:69I960@
M1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P"FUS
M9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#D*;7-G:60@(DUO;F%C;R(*;7-G<W1R("+7GM>5UZ#7I]>5(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34V"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("+7GM>5UZ#7DM>5
MUYS7F=>4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y,@IM<V=I
M9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$*;7-G:60@(DUO;G1S97)R870B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE
M;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R
M("+7GM>HUY77I]>5(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I
M9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V
M92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(X"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(X"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.`IM<V=I9"`B36]Z86UB:7%U92(*
M;7-G<W1R("+7GM>5UY;7GM>1UYG7IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.3(*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`V,`IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3`*;7-G:60@(DUU
M;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N
M="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C8U"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C,U"FUS9VED(")->2!0;W)T86P@
M3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-0IM<V=I9"`B37EA;FUA
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,#(@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(").
M86UE(@IM<V=S='(@(M>IUYTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD*;7-G:60@(DYA;6EB
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X"FUS9VED(").875R=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S<*;7-G:60@(DYE<&%L(@IM<V=S='(@(M>@
MUZ37G"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-0IM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T
M<B`BUY37E=><UZ#7DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S"FUS9VED(").971H97)L86YD
M<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS
M9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S
M8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8W"FUS9VED(").
M971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R-2!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3<*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`*
M;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE
M=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z.#0*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@X"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,V"FUS9VED(").97<@
M57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`*
M;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(M>@UYG7E>*`D]>6UYG7G->@
MUY,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@
M(DYE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-Q;"YP:'`Z,C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S
M=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?
M8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,`HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S`U"FUS9VED(").97=S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,C$*;7-G:60@(DYE=W-G<F]U<',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z-#$@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S8V"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE
M>'0^(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-`IM<V=I9"`B3FEC87)A9W5A
M(@IM<V=S='(@(M>@UYG7I]>HUY+7E=>0UY0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$*;7-G
M:60@(DYI9V5R(@IM<V=S='(@(M>@UYG7EM>H(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S"FUS
M9VED(").:6=E<FEA(@IM<V=S='(@(M>@UYG7DM>HUYG7E"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-S(*;7-G:60@(DYI9VAT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W.0IM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38X"FUS
M9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N
M(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS
M9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA
M9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HV-PIM<V=I9"`B3F\@8V%L96YD
M87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO
M(&-H86YG92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C<V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#,S"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV.3@*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S0W
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO
M(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.CDR-`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*
M;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@
M(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3(Q(&QI8B]";&]C:R]M971A<BYP:'`Z,3,U"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`IM<V=I9"`B3F\@;&]C871I;VX@
M:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38R"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B3F\@;V9F96YS:79E
M(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM
M<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#$S"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@
M<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HU-C,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,Q"FUS9VED(").;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q
M"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`@
M9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C$W-0IM<V=I9"`B3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY.3<*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,30*;7-G:60@(DYO('9A;'5E
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS
M9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F
M;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(W('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-0IM<V=I9"`B3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE
M("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S(*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34X"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V"FUS9VED(").;W)W87DB"FUS
M9W-T<B`BUZ#7E=>HUY77E=>2UYG7E"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#0Q"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*;7-G:60@(DYO="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-CD@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,PHC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S@P(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,3,*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C0W,R!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-34R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HV,C$@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C8S.`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S$V
M(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HX,@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]H;W)D92YP:'`Z,3,Q(&9R86UE=V]R:R]61E,O5D93+VAO<F1E
M+G!H<#HQ-3$*(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$W,"!F
M<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VAO<F1E+G!H<#HR,#<@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N
M<&AP.C(R-PHC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,S,P"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#@Q"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(DYO=&5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM
M<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS
M9VED(").;W9E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S,PIM<V=I9"`B3G5M8F5R(&]F(&-H
M87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,W-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,Q"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-3,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S4@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#4Q('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#<U"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#@*
M;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-PIM<V=I9"`B3V9F96YS
M92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,T,@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S
M<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@Q"FUS9VED(")/;6%N(@IM<V=S='(@(M>BUY77
MGM>0UY\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C$P,`IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3<Y"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R
M97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HV-`IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#`*
M;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")/<&5R871I;F<@4WES=&5M
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`BUY#7I->IUZC7E=>9UY77JB(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS
M9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3,T"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R
M("+7D->7UZ@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED
M(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z.#`*
M;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS
M9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-38*
M;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C8V"FUS9VED(")02%`@0V]D92(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,3@*;7-G:60@(E!(4"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM
M<V=I9"`B4$T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,`IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@
M(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-PIM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`BUZ37I]>9
MUZ'7JM>?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-`IM<V=I9"`B4&%L874B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,@IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y
M+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(*;7-G:60@(E!A
M;F%M82(*;7-G<W1R("+7I->@UY[7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-0IM<V=I9"`B
M4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU"FUS
M9VED(")087)A9W5A>2(*;7-G<W1R("+7I->HUY+7E=>0UYG7F2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")0
M87)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,C8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV
M.2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0T"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(E!A<W-W;W)D(@IM<V=S
M='(@(M>AUYG7H=>>UY`B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34W"FUS9VED(")0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Q"FUS
M9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W
M;W)D.B(*;7-G<W1R("+7H=>9UZ'7GM>0.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(M>A
MUYG7H=>>UY`Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#0R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$W('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B
M4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S
M.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G
M:60@(E!E;W!L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@
M(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N
M(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU-C8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z-3D@861M:6XO<&5R;7,O9&5L971E+G!H<#HU-PHC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#@@861M:6XO<&5R;7,O:6YD97@N<&AP.C(Q"FUS
M9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,PIM<V=I9"`B4&5R
M=2(*;7-G<W1R("+7I->HUY4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V"FUS9VED
M(")0:&EL:7!P:6YE<R(*;7-G<W1R("+7I->9UYS7F=>DUYG7H->9UYG7G2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*
M;7-G:60@(E!H;VYE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,#$*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DP"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM
M<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<P
M"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE
M=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D
M<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN
M9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@
M=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T
M>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@X"FUS9VED(")0;VQA;F0B"FUS9W-T<B`BUZ37E=><UYG7GR(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4&]L:71I8W,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,`IM<V=I
M9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,PIM<V=I9"`B4&]R
M='5G86PB"FUS9W-T<B`BUZ37E=>HUYC7E=>2UYPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O
M<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W."!L:6(O0FQO8VLO
M;65T87(N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T
M:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDQ"FUS9VED(")0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]L9&%P+G!H<#HQ,S,*;7-G:60@(E!R969S7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G:60@(E!R97-S=7)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"FUS9VED(")0<F5S
M<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C(Y"FUS9VED(")0<F5S<W5R93H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S4R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V"FUS9VED
M(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O
M8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O
M8FQE;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*
M;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-0IM<V=I9"`B4')O:F5C=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#<*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B
M;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$*;7-G:60@(E!U97)T;R!2:6-O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DV"FUS9VED(")1871A<B(*;7-G<W1R("+7I]>8UZ@B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C$*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I
M="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(W
M,@IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0U"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")2
M86EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X
M"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN('1O
M(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*
M;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G
M:60@(E)E860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2
M961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM
M<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM
M<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDT"FUS9VED(")2969R97-H(')A
M=&4Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#(*;7-G:60@(E)E;&%T:6]N
M<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*
M;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,S.`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G
M:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M."!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*;7-G:60@(E)E;6]V92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-38Q"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@
M(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M
M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X(&9R86UE=V]R
M:R]24$,O4E!#+W!H<&=W+G!H<#HQ-S,*;7-G:60@(E)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3`*;7-G:60@
M(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S8@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,SD@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HW,#0*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<U,R!F<F%M97=O<FLO5D93+U9&
M4R]H;W)D92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S0*;7-G:60@(E)E<75I<F5D($9I
M96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,T,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,3D@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<X"FUS9VED
M(")297-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R.`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR-B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD@
M861M:6XO<W%L<VAE;&PN<&AP.C8T"FUS9VED(")297-U;'1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X
M"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3<*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X
M"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I
M=&]R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8S"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`IM<V=I9"`B
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$Q-`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3`*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3@*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`BUZC7E=>>UZ#7F=>4(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-`IM<V=I
M9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"FUS9VED(")2;W1A=&4@3&5F="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(W"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I
M9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD
M(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.`IM<V=I9"`B4G5N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D*;7-G:60@(E)U<W-I86X@1F5D
M97)A=&EO;B(*;7-G<W1R("+7J->5UZ'7F=>4(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,`IM
M<V=I9"`B4G=A;F1A(@IM<V=S='(@(M>HUY77D->@UY/7E"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@
M0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%
M;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C@R"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,C<*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Y"FUS9VED(")344P@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M-0IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4T"FUS9VED
M(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#
M0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?
M44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-PIM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,0IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S.0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X.0IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T"FUS9VED(")386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED
M(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M,0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,@IM<V=I
M9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$*;7-G:60@(E-A=61I
M($%R86)I82(*;7-G<W1R("+7HM>HUY$@UY37H=>BUY77D]>9UZHB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$U"FUS9VED(")3879E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,`IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B4V-I96YC
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B
M4V5A<F-H(@IM<V=S='(@(M>7UYG7I->5UZDB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S,V"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.38V"FUS9VED(")3
M96QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0X-PIM<V=I9"`B4V5L96-T(&$@9&%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM
M<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE
M=R!O=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T
M(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&%L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4T"FUS
M9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W-0IM
M<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED(")396QE
M8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F
M<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*
M(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3(*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@
M(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@
M(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3$*;7-G:60@(E-E
M;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#0*;7-G:60@(E-E;F0@4TU3
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,*;7-G:60@(E-E;F5G86PB"FUS
M9W-T<B`BUZ'7H->2UYPB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R.`IM
M<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")3
M97)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-30*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HR-@IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G
M:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S(R"FUS9VED(")3970B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T
M:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y
M;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@
M;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,U"FUS9VED(")3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#`*;7-G:60@(E-E=F5R86P@;&]C
M871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#,*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B
MUY#7F=>9XH"3UZ'7F=>9UZG7G"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,3D*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*
M;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<W,PIM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`V"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED
M(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!4
M86)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R
M"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S<Q"FUS9VED
M(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,@IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R
M<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M.3<R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3`U.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(M>GUYG7F=>HUY0@UYS7F=>0UY77GR(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C<*;7-G:60@(E-I9VX@=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E
M($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V"FUS9VED(")3
M:6YG87!O<F4B"FUS9W-T<B`BUZ'7F=>@UY+7I->5UZ@B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M,#`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C0Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$V"FUS9VED(")3:7IE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R
M"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3`*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#@*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4V"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")3;F]W(&1E<'1H.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@
M(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#(*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$T"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(M>AUY77GM><
MUYG7E"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B4V]N
M9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3$Y"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B
MUY/7J->5UYWB@)/7D->DUZC7F=>GUY0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-@IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,0IM<V=I9"`B4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM
M<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,3D*;7-G
M:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G:60@(E-P86-I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,`IM<V=I9"`B4W!A:6XB"FUS9W-T<B`BUZ'7
MI->HUY,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`W"FUS9VED
M(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED
M(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,0IM<V=I9"`B
M4W)I($QA;FMA(@IM<V=S='(@(M>AUZC7F2#7G->@UZ?7E"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,2!L:6(O0FQO8VLO;65T87(N<&AP
M.C@V"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C<*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#(*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C$P"FUS9VED(")3=&%T=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.`IM<V=I9"`B
M4W1O<F%G92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X
M,0IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I
M9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,38*;7-G:60@(E-U8FUI="(*;7-G<W1R
M("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA
M<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P,@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW.2!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4W(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.0IM<V=I9"`B4W5C
M8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,38W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A
M=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`BUZ'7E=>3UY\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$P"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.0IM<V=I9"`B4W5N<FES
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,3,*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")3=6YS970Z("(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,SDT"FUS9VED(")3=7!P;W)T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(M>A
MUY77J->9UZ#7G2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#D*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q.0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(M>AUY77
ME=>6UYG7G->@UY,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`BUZG7E=>5UY/7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38*;7-G:60@(E-W:71Z
M97)L86YD(@IM<V=S='(@(M>IUY77E=>9UZ4B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3
M>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@*;7-G:60@(E-Y<FEA;B!!<F%B
M(%)E<'5B;&EC(@IM<V=S='(@(M>AUY77J->9UY0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G
M:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M<R!%87)L>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V
M"FUS9VED(")44U8@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")4
M86)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T"FUS9VED(")4
M86EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-0IM<V=I9"`B5&%J:6MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U"FUS9VED(")486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(M>8UZ#7EM>@UYG7E"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@
M(E1A<F=E=#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P-C8@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5&%S
M:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(E1E;7`@9F]R(&QA
M<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C(V"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$W"FUS9VED(")496UP97)A='5R93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(
M:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$V.`IM<V=I9"`B5&5M<&QA=&4@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")4
M97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*
M;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT
M(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM
M<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3<*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C0*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(M>JUY#7F=><UZ#7DR(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(Y"FUS9VED(")4:&4@
M1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HV,PIM<V=I9"`B5&AE
M($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO
M9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS
M9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@
M(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O
M('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE
M(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I
M9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE
M(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@96UA:6P@861D<F5S<R`E<R!H87,@8F5E;B!A
M9&1E9"!T;R!Y;W5R(&ED96YT:71I97,N(%EO=2!C86X@8VQO<V4@=&AI<R`B
M"B)W:6YD;W<@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S<@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,"!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-#(*;7-G
M:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I
M9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G
M:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE
M<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H
M92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US
M('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U
M9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M
M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I
M;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B
M965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@
M=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE
M9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@U"FUS9VED(")4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$P,`IM<V=I9"`B5&AE(&YE
M=R!F<F]M(&%D9')E<W,@8V%N)W0@8F4@=F5R:69I960L('1R>2!A9V%I;B!L
M871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N
M=6UE<FEC+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS
M9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P
M87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I
M;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$S"FUS9VED(")4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-0IM<V=I
M9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z-#0T(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#0X
M"FUS9VED(")4:&5R92!A<F4@;F\@96UA:6P@861D<F5S<V5S('1O(&-O;F9I
M<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C,T-0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@
M861M:6XO=7-E<BYP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.CDS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@
M=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.CDS-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@
M8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H
M92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G
M:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S@*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E
M;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G
M:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A
M9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I
M=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`Y,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$Y"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(V,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,34V-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Y
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$S,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S`X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@R-`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G
M97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#(T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@
M82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.3,*;7-G
M:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.0IM<V=I9"`B
M(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C4*;7-G
M:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E
M('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X
M,@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U
M"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P
M=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3`*;7-G:60@(E1I
M8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0S,R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I
M;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,C(*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`*;7-G:60@(E1I
M;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*
M;7-G:60@(E1I=&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP
M*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-@IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN
M9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,P,PIM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A4
M34P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,*;7-G:60@(E1O
M9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-@IM<V=I9"`B5&]K96QA=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`U
M"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y"FUS
M9VED(")4;VYG82(*;7-G<W1R("+7I]>1UY77IM>JXH"3UY#7F=>9XH"3UYC7
ME=>@UY+7E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,0IM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8X"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,@IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R
M("+7F->HUYG7H->9UY/7DR#7E=>8UY77D=>2UY4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-SDX"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@*;7-G
M:60@(E1U;FES:6$B"FUS9W-T<B`BUYC7E=>@UYG7H=>9UY0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`BUYC7E=>HUZ?7F=>9UY0B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5'5R:VES:"`H
M25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-PIM<V=I9"`B
M5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`*;7-G:60@
M(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,S"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*
M;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`BUY#7JM>H(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G
M:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(M>0UZK7J#HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,W"FUS9VED(")59V%N9&$B"FUS9W-T<B`BUY#7E=>2UZ#7
MD]>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-@IM<V=I9"`B56MR86EN92(*;7-G<W1R("+7
MD->5UZ?7J->9UYG7H->4(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-#0U"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDS
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3@@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-S(Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`V,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#<R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T
M.`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U."!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-C,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(R-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C,Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,SD*
M;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M.#<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@V"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Y.`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@
M9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S<@861M:6XO<&5R;7,O9&5L971E+G!H<#HT
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,V-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$X(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,W
M."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@R"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,W,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S<T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#0S(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#4U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,S8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,30@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0Q,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#(Q"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#$R"FUS
M9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP
M:'`Z-#,W(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C$X(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3@U(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.3`*;7-G:60@(E5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.CDX(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HV,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z.#$@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#8*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,30P(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDP
M,PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.CDS-`IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53
M:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-S`R"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,R,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-C0S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(Q,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#4R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S0Y(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,34*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,S,0IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3@Y"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,30@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDP
M.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL
M(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B
M56YD;R!#:&%N9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q
M"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DY"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S
M='(@(M>4UY#7GM>9UZC7E=>9UY77JB#7E->>UY#7E=>7UY/7E=>J(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,X"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("+7E->>
MUY[7G->;UY0@UY37GM>0UY77E]>3UZHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P"FUS9VED
M(")5;FET960@4W1A=&5S(@IM<V=S='(@(M>0UZC7IM>5UZKB@)/7E->1UZC7
MF=>J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S.0IM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO
M<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS
M9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C4X(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R.0HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*
M;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM
M<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34R
M"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HS,3D*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B
M(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O
M;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII
M;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R
M"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I
M9"`B57!D871E('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-#,@861M:6XO<&5R;7,O961I="YP:'`Z,3`Q('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@Y"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G
M<W1R("+7E->BUYS7D->4(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P
M<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B
M57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q
M"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(M>0UY77J->5UY+7E=>5UYDB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B
M57-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C<V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,C`R"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS
M9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HV
M,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@<VEG
M;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F
M;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-"!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8T
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5
M<V5R;F%M92(*;7-G<W1R("+7I]>5UY,@UY;7F=>4UY77F2#7GM>IUZK7GM>I
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES
M=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I
M9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,@IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S,@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C@X"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(W
M"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX-S`*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-PIM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L
M=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(W-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L
M=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y-`IM<V=I9"`B5F%L=65S
M('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D*;7-G
M:60@(E9A;G5A='4B"FUS9W-T<B`BUY77H->5UY#7F->5(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.`IM<V=I9"`B5F%R:6%B;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S
M='(@(M>5UZ#7EM>5UY#7G->4(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T
M:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("+7DM>9UZC7H=>4(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,@IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM
M<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")697)Y($AI9V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.`IM<V=I9"`B5FEE="!.86TB"FUS9W-T
M<B`BUY77F=>9UYCB@)/7H->=(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HR
M,#`*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.3<U"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W"FUS9VED(")6:7)G
M:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R,0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4W"FUS9VED(")6:7-I8FEL
M:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY
M('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@
M(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-2
M25!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,`IM<V=I9"`B5V%L;&ES
M(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C$@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*
M;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-`IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$Y"FUS9VED(")7
M96%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"FUS9VED(")796%T:&5R+F-O;2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C`*
M;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I
M9"`B5V5L8V]M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C4W('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C<T('-E<G9I8V5S+W!O<G1A;"]M
M;V)I;&4N<&AP.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,C`Q"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C(P,@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X"FUS9VED(")797-T97)N(%-A:&%R
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA
M<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`V-@IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@
M;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I
M9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I
M9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$Q.`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7
M:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N
M:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3,V"FUS9VED(")7:6MI(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I
M;F0B"FUS9W-T<B`BUZC7E=>7(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B5VEN9"!S<&5E
M9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$V.`IM<V=I9"`B5VEN9#HB"FUS9W-T<B`BUZC7E=>7.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S8*;7-G:60@(E=I;F0Z("(*;7-G
M<W1R("+7J->5UY<Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV.0IM
M<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,3(*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HW,`IM<V=I9"`B5V]R:R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*
M;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H
M;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C$Y,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI
M;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED(")8+5)E9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I
M9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(EE9(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,38*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U.`IM<V=I9"`B65E962(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,PIM<V=I
M9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,@IM<V=I9"`B665M96XB"FUS9W-T<B`BUZK7
MF=>>UY\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.38X"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!
M9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(U
M"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,R-0IM<V=I
M9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R
M(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M<&AP9W<N<&AP.C$Q-PIM<V=I9"`B66]U(&1I9"!N;W0@875T:&5N=&EC871E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8S
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#,*;7-G:60@(EEO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB
M:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@:&%V92!R97%U97-T960@=&\@
M861D('1H92!E;6%I;"!A9&1R97-S(%PB)7-<(B!T;R!T:&4@;&ES="!O9B!Y
M;W5R("(*(G!E<G-O;F%L(&5M86EL(&%D9')E<W-E<RY<;B(*(EQN(@HB1V\@
M=&\@=&AE(&9O;&QO=VEN9R!L:6YK('1O(&-O;F9I<FT@=&AA="!T:&ES(&ES
M(')E86QL>2!Y;W5R(&%D9')E<W,Z7&XB"B(E<UQN(@HB7&XB"B))9B!Y;W4@
M9&]N)W0@:VYO=R!W:&%T('1H:7,@;65S<V%G92!M96%N<RP@>6]U(&-A;B!D
M96QE=&4@:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3DR
M"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-#<T"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3$X"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HY.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(')E;6]V92XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z-C$@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$T-0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I
M9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHS-`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O
M;3H@861D<F5S<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED
M(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,P"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@
M=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@
M>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HU-0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HQ,C0*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L
M;"!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R("+7F=>5UY+7E=>AUYS7D=>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4V"FUS9VED("):86UB:6$B"FUS9W-T<B`BUY;7GM>1UYG7
MF=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-PIM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B
MUY;7F=>>UY'7D=>5UY77E"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HW
M,0IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI
M9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34V
M,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R
M("+7HM>6UZC7E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*
M;7-G<W1R("+7E->JUZ#7JM>GUY77JB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF
M>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(M>0UZ37
MJ=>HUY77F=>5UZHB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M
M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN
M:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3
M971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B
M7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(P"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`BUZ'7I->H(->;
MUZK7E=>1UY77JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,@IM<V=I9"`B8V%L96YD
M87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#0@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DU"FUS9VED(")C;&EC
M:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@
M(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A
M=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y
M(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#(*;7-G:60@
M(F9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0T"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#@*;7-G:60@(F@Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-C$*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK
M;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G:60@(FEM;65D:6%T92(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U
M="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<R"FUS9VED(")M;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X,2!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS9W-T<B`BUZG7
MG2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I
M;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#0*
M;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@
M:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G)I<VEN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I
M9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C$P,@IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#D*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")S=&5A9'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*
M;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR.`IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<Q
M"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HR-SD*;7-G:60@(G5N:VYO
M=VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]0
M87)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*
M;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(T,`IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@
M(B(*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:&]R
M9&4N<&]T````````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#4W,S0U,P`Q,#0Q-S,V,S`P,0`P,38V-S``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!33TU%($1%4T-225!4
M259%(%1)5$Q%+@HC($-O<'ER:6=H="`H0RD@645!4B!(;W)D92!0<F]J96-T
M"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI
M8V5N<V4@87,@=&AE(%!!0TM!1T4@<&%C:V%G92X*(R!&25)35"!!551(3U(@
M/$5-04E,0$%$1%)%4U,^+"!914%2+@HC"B,L(&9U>GIY"FUS9VED("(B"FUS
M9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!004-+04=%(%9%4E-)3TY<
M;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT-RLP,3`P
M7&XB"B)03RU2979I<VEO;BU$871E.B!914%2+4U/+41!($A/.DU)*UI/3D5<
M;B(*(DQA<W0M5')A;G-L871O<CH@1E5,3"!.04U%(#Q%34%)3$!!1$1215-3
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@3$%.1U5!1T4@/$Q,0&QI+F]R9SY<;B(*
M(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]0TA!4E-%5%QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<P"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<R"FUS9VED("(@*'1O
M;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S8X"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q,`HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!2
M96=I<W1R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP
M:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO
M="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W
M;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O
M<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y-`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X,B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-3(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M
M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*
M(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W
M:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`V-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW
M-#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&
M;W)M870B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,0IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B
M"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM
M<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@
M(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS
M9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET
M;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*
M;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G
M:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B
M061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E
M.B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G
M<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES
M<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I
M9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@
M=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED
M(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#,X"FUS9VED(")!9&1R97-S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D
M9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*
M;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI
M9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U
M"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS
M9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-C@*;7-G:60@(D%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L
M=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@
M96UA:6P@861D<F5S<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@
M:&%S(&]C8W5R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N
M9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS
M-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I
M9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*
M;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P
M<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-#`*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*
M;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<X"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI
M=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E
M;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC
M(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y,@IM<V=I9"`B07-S:6=N;65N="!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B
M071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I
M9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@
M(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G
M:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT
M:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I
M=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X
M8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K
M97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I8R`H
M25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A
M;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D
M;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8T"B,L('!H
M<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I
M9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G
M:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@
M(D)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T
M;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@
M4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M-B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"B,Z
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0P(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W
M<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-A;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G
M:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S(S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B
M0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM
M<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL
M(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S$*;7-G:60@(D-E;&QP:&]N92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B
M0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B
M0V5N=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@
M069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G
M:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T
M92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H
M860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA
M;F=E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B
M"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET
M:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'
M0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T
M"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@
M07!P;&EC871I;VXZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO
M;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G
M:60@(D-L96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A
M9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I
M9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@
M;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B
M0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#
M;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME
M96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z
M,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S-0HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,#,@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C4*;7-G:60@
M(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#,*;7-G
M:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@
M3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@
M(D-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@
M4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@
M;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I
M9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<V"FUS9VED(")#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V
M-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL
M93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<U
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O
M;VMI92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@
M(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU
M,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B
M=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q
M-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E860@)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U
M<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S`W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,S.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S4*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X-PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(Q"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V
M92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O
M9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N
M9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N
M)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,38*;7-G:60@(D-O=6YT960@=&5X="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I
M9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@
M;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C4R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@
M(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(P.0IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B
M0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@
M5&EM92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B
M0W5R<F5N="!5<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N
M="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y
M<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P
M=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B1$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(V.0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]D
M871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(V-PIM<V=I9"`B
M1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,Y-0IM<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E
M:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-S@V"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*
M;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F
M<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$
M969A=6QT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$
M969A=6QT(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R
M-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ
M,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L
M971E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S
M+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,
M;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B
M1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E
M(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B
M1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM
M<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$
M96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E
M('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G
M:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,U('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G
M:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,C`V"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B1&5W
M(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q
M"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E
M=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O
M(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L
M969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS
M9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C
M87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G
M:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B1&ES<&QA>2!F;W)M
M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP
M.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@
M(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-`IM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F
M;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET
M($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O
M<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N
M+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@V-@IM<V=I9"`B16UA:6PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C`*;7-G
M:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@V"FUS9VED(")%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M
M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U
M,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4X-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDP"FUS
M9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I
M86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R
M96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS
M9VED(")%<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O
M5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C
M<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I
M9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I
M9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HX,B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M:6XO<W%L<VAE
M;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I
M9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS
M9VED(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(R,`IM<V=I
M9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E
M('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E
M=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"FUS9VED
M(")&871A;"!%<G)O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A
M>&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS
M9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#$*;7-G:60@(D9I96QD
M(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S(R"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(V"FUS9VED(")&:6=L970@9F]N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M1FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I
M;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S0*;7-G:60@(D9I;&4@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#,*
M;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.CDP,@IM<V=I9"`B1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM
M<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T
M:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS
M9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS
M9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4
M048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R
M='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M-`IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B
M1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@
M(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU
M.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U
M97-T8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDU-PIM<V=I9"`B
M2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDQ-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3$Q"FUS9VED(")(96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3
M=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM
M<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@T(&9R
M86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*
M;7-G:60@(DAE;'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M.`IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G
M:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@
M(DAO<F1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R
M<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T
M"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R
M:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G
M:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED
M(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S$S"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E
M<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@
M=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS
M9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@
M(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED
M96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(DEF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@
M:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T
M;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E
M;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S4X"FUS9VED("));6%G92!U
M<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*
M;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E
M<"`E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM
M<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G
M:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B
M26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*
M(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A
M<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN
M9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O
M<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN
M($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U
M"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS
M9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C
M;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM
M<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T
M"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*
M;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E
M<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B
M26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E
M<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN
M<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W,@IM<V=I9"`B
M26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3,P"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3DT
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM
M<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U-0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.38*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I
M9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED
M("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS
M92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G
M:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D
M=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T
M;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$P.#`@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8S"FUS
M9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G
M:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM
M<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE
M(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G
M:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A
M;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I
M9"`B2G5S=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#
M96YT97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED
M(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I
M9"`B2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG
M=6%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P
M;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S
M<W=O<F0@0VAA;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM<V=I
M9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T
M"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G
M:60@(DQA>6]U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@
M;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B
M86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.`IM<V=I9"`B3&5F="!H
M96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S`Y-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT
M(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG
M:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET
M:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R
M"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3$*;7-G:60@(DQI
M;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,@IM
M<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),
M:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*
M;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE
M;'`@5&]P:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI
M=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0
M;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B
M3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N
M<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@
M(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED
M("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),
M;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P
M"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8R"FUS9VED("),;VYG('1E>'0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),
M;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM
M<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y
M"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9
M=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I
M;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S
M,30N<&AP.C0X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A
M;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU
M;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S8*;7-G:60@(DUA
M>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P
M"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C
M97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N
M;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S
M<V%G92!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED
M(")-97-S86=E('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3$Y"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S
M"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T
M:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP
M:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I9"`B365T
M<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M.0IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI
M;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S
M="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM
M<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P
M;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S
M86=E($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED
M(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I
M9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DUO9&5R871E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")-
M;V1I9FEE9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,0IM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@
M)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L
M96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS
M9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B
M36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U
M-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V
M92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3@Q"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,Y"FUS9VED(")-=6QT
M:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HT-0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L($QA
M>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED
M(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC
M>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S
M"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM
M<V=I9"`B3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").
M97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O
M<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED
M(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W
M:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R
M;W5P<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM
M<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM
M<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B
M3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED
M(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P
M"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R
M96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S@@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,3<*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP
M:'`Z-S8X"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W,@IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T
M"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(P"FUS9VED(").
M;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P"FUS
M9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S
M=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF
M:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS
M9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN
M<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W
M9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S8V"FUS9VED
M(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U
M;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V
M"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@
M8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-S0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDX-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3DU"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*
M;7-G:60@(DYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI
M8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM
M<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS
M9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").
M;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@
M82!D:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HY-0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B
M3F]T('-E="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C(S-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR,#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S-`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4R(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X-2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,S,PHC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S8V(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C8*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<T
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.3$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C8V.0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#@@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-`HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`U."!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS
M9VED(").;W1E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I
M;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T,PIM<V=I9"`B3G5M8F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C(*;7-G:60@
M(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0R('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB
M97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S8T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,"!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O
M=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE
M9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/
M8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3`Q"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T
M;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*
M;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L
M9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED
M(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0X(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-C@*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O0FQO8VLO:69R86UE+G!H<#HT
M,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T
M96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I
M9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN
M9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I
M9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM
M<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")0
M14%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG
M;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS
M9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HV.0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@
M(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I
M9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)
M6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM
M<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A
M;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")087)T;'D@0VQO
M=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,34*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O
M<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O
M<F0@:6YC;W)R96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3`*;7-G:60@(E!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#,Q"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I
M9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N
M=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*
M;7-G:60@(E!E;W!L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S
M:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N
M:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN
M+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X
M"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L
M($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*
M;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T
M;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4U.0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.3@*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,S<*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T-#0*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*
M;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@
M=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B
M4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS
M9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E
M=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@
M2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*
M;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<S"FUS9VED(")0<F]M<'0@
M=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI
M8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8T"FUS9VED(")1=65R
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G
M:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L
M:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C$*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-0IM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM
M<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A
M=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A
M9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,S(*;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R,C@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E
M;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO
M=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X
M"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R
M;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM
M<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q
M"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E
M(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U
M97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<X
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8Q"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E
M<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN+V-M9'-H96QL
M+G!H<#HR.2!A9&UI;B]S<6QS:&5L;"YP:'`Z-C<*;7-G:60@(E)E<W5L=',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@
M3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P
M"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3`P"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-@IM<V=I9"`B4FEG:'0@
M=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2
M;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS
M9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2
M;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED(")2=6XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")3
M35,@365S<V%G:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R-S$*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R
M('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@
M(E-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE
M;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI
M='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-3(*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@
M82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I
M9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#`*;7-G:60@(E-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@
M86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I
M9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G
M:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@
M(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!
M9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S$Q"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@
M(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S
M<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E
M='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T
M(%-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO
M9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8R"FUS9VED(")3:&]W(&]P=&EO;B!T
M;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(W.3(*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C`*
M;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4S"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3
M:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R
M<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG
M;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX.3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,T"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-#,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDP.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`R"FUS9VED(")3
M:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS
M9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.`IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED
M(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.#D*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B
M4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3`U"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E
M;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#$R"FUS9VED(")3<&%C97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@
M(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!)
M;G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z.#$*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C<X.`IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I
M9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDT"FUS9VED
M(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,P"FUS9VED(")3=')I;F<@
M;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<P"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS
M9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP
M="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS
M9VED(")3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS
M9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ
M-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*
M;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS
M9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D
M(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I
M9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE
M<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM
M<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R
M;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U
M"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")4
M86)L92!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M86II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B
M5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDS,B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T.0HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I
M9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E
M;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C0*;7-G:60@(E1E>'0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/
M;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA
M:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B
M5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-3$*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O
M<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3,X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E
M9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y
M.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q
M"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@
M<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E
M9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME
M;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T
M('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L
M;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R
M"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z
M,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$X-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I
M;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I
M9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED
M("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S0*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE
M('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E
M;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S
M<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S
M(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C
M:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I
M9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y
M.0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T
M:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED
M(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R
M86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C
M:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#@*;7-G:60@(E1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T
M97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C
M=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R
M("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB
M)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX
M,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER
M960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(T"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*
M(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER
M97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH
M='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDW-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4T
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$Q,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3<Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-3,*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,P,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,SDU"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-30@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@S-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.34U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#(*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`R-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#<U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#8@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(Q.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8S-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,38@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y-`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS.#`R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,3`*;7-G
M:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C(*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,PIM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y,0IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,`IM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3@V"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@
M82!V86QI9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,34*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT
M86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E
M>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z-34X"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H
M96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@
M8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS
M9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP
M.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A
M;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES
M(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM
M<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C(@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4
M:6UE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3(X"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV
M"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4
M;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.#<*;7-G
M:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM
M96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED
M(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-PIM<V=I9"`B55),.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED
M(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR
M86EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,3D*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,SDR
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y-2!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C$P,C@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C@U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,S(@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,W"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#0@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S8Q(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(V-`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S(*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM
M<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C@@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS.34*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R
M,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0R,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S$P(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,CDQ"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS
M9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C$P-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8U
M,B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@T(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C@S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-38*;7-G:60@(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.#<*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@
M9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8W-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$Q,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR-S$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S(V(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U,0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@X"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,W-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE
M9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I
M9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV,B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")5;FET
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N
M:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5
M;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G
M:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS
M,#(*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5
M;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS
M,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E
M('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M
M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED
M(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A
M;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('-I
M9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N
M(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C
M;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ
M,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA
M;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y
M<W1E;3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI
M<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R"FUS9VED(")6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C,*;7-G
M:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@
M:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#4S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X
M:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V
M,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$X,PIM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I
M9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B
M5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@
M=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*
M;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)
M4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I
M;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*
M;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED
M(")787)N:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE
M<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#@Y"FUS
M9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T
M;R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G
M:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U"FUS9VED
M(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@
M<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`T"FUS9VED(")7:61T:"!I;B!#
M4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED
M=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS
M9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS
M9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,3DS(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL
M92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED
M(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS
M:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B65DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4V"FUS9VED(")965E9(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3$Q"FUS9VED
M(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS
M9VED(")997,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(T"FUS9VED(")9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A
M;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<R"FUS9VED(")9;W4@9&ED
M(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*
M(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U.`IM<V=I9"`B
M(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R
M+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#4*;7-G:60@(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S$*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM
M<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G
M:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O
M=70N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA
M="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P
M:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B
M66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E
M<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@
M(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E
M('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@
M9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B
M"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-PIM
M<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN
M="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R
M(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO
M=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I
M9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@
M(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E
M9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-34T('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B
M7TAE;'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM
M<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Y(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(F-A
M;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.`IM<V=I9"`B8VQI
M8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED
M(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D
M871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DX"FUS9VED
M(")F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z
M,SDS"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@
M)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N
M:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP
M=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R
M92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@
M)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM<V=I9"`B;6TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#4@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L
M96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#D*;7-G
M:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@
M<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B
M<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#<*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G
M:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED
M(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS
M9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W
M96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:'5?2%4N
M<&\`````````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#<Q-S(W-@`Q,#0Q-S,V,S`P,0`P,38T,38`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!(;W)D92!(=6YG87)I86X@
M=')A;G-L871I;VX@9FEL92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#(M,C`P-B!,
M87-Z;&\@3"X@5&]R;F]C:0HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U
M;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC
M($QA=&5S="!V97)S:6]N<SH@9G1P.B\O>&5N:6$N<V]T92YH=2]P=6(O;&EN
M=7@O:&]R9&4O"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($AO<F1E(#,N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V
M+3`R+3$W(#$P.C`P*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M
M,#(M,3<@,3`Z,S@K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!,87-Z;&\@
M3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS;W1E+FAU/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@2'5N9V%R:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*
M(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B
M("@E<R!N87!P86P@97IE;/5T="DB"@HC.B!L:6(O2&]R9&4N<&AP.C$S-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@
M(B`H06QT+6)I;&QE;G1Y^R`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,X,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S
M='(@(B`H)7,@;F%P(&WZ;'9A*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,S<W"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&UA*2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R
M("(@*&AO;&YA<"DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0IM<V=I
M9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H=&5G;F%P*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDV"FUS9VED("(@870@(@IM<V=S='(@(B`Z("(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&YE;2!A;&OV;GEV=.%R+B(*
M"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S
M7"(@;F5M(.ER=NEN>65S(';A;&%S>G3A<RXB"@HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C<Q,"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&YI;F-S(&MO
M;F9I9W5RX6QV82!A($AO<F1E(%)E9VES=')Y8F5N+B(*"B,Z(&QI8B](;W)D
M92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(")<(B5S7"(@9F%S=')U
M:W3Z<F$M;65G:F5L96[M=/4@;F5M('1A;.%L:&%T\RXB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@
M861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(BUT
M(&AO>GKA861T=6L@82!C<V]P;W)T;VMH;WHN(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB+70@:&]Z>N%A9'1U:R!A(&IO9V]S=6QT<^%G:2!R96YD<WIE<FAE
M>BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO
M="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB+70@;F5M(&AO>G1U:R!L
MZ71R93H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H
M<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D
M("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!F96QH87-Z;N%L="!A("4N,F9-
M0B!M96=E;F=E9&5T=&+U;"`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S(.ES("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N(@IM<V=S='(@(B5D(&YA<"!M^FQV82!L96KA<B!J96QS>F%V
MX6YA:R#I<G;I;GEE<W/I9V4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A
M<W0B"FUS9W-T<B`B)60@;F%P;W,@96SU<F5J96QZZ7,B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!&:6=Y96QM97IT973I<R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(&QE;GEO;6%T(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,2!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z.#0S"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(&MA<F)A;G1A<G3A<VD@9F5L
M861A=&]K("T@;65G97+U<^UTZ7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@8F7A;&SM=.%S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!L;V=I;B!NZ78@:6?I;GEL
MZ7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S
M('-Z;VQGX6QT873A<VD@9F5L=.ET96QE:R(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HT,S(@;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O5D93+V9T<"YP:'`Z-C@R
M"B,Z(&QI8B]61E,O9G1P+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D$@7"(E<UPB(&YE=OL@X6QL
M;VWA;GD@;>%R(&SI=&5Z:6LN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B
M"FUS9W-T<B`B)7,@.B`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*
M(D$H>BD@)7,@:^ES>F5N(.%L;"!A>B!A;.%B8FD@:V%R8F%N=&%R=.%S:2!F
M96QA9&%T;VL@96QVZ6=ZZ7/I<F4N2F5L]FQJ92!K:2`B"B)A>F]K870@82!F
M96QA9&%T;RAK82ET+"!A;6DH:V4I="!M;W-T(&5L(&OM=N%N(';I9V5Z;FDN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:VET]FQTZ7-E('-Z
M_&MSZ6=E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@<&5R8R(*"B,Z
M(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N96T@=&%L
MX6QH873S+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B
M)7,@+2`E<R`H]G-S>F5S96X@)7,I(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B)7,@8^UM:F5G>7KI:V4B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM
M<V=S='(@(B5S(&YA<'3A<F$B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B
M)7,@9F5L:F5G>7KI<V5I(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E
M<R!F96QA9&%T;&ES=.%J82(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M
M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@
M0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@
M<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B(*(B5S.B!,96AE='/I9V5S+"!H;V=Y(&5Z(&$@
M;&5VZ6P@=F%L\VKA8F%N(&YE;2!A(&UE9V%D;W1T(&9E;&%D\W3S;"`B"B)S
M>N%R;6%Z:6LN($=O;F1O;&IA(&UE9RP@;6EE;/5T="!RX6MA='1I;G0@=F%L
M86UI<F4L('9A9WD@<WIE;>EL>65S("(*(FEN9F]R;>%C:?-T(&%D(&UE9RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS
M9W-T<B`B+"!S>NEL;/9KZ7-E:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3DU(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G
M:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L("5S("5S+7,@<WKI;&SV
M:^ES96LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
M+"!VX6QT;WKS("5S(.ES("5S(&OV>O9T="(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#<S(&QI8B](;W)D92]&;W)M+G!H<#HR,3,R(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,CDT"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S0X
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HW-#@*;7-G:60@
M(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!VX6QA<W-Z;VX@+2TB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM
M<V=S='(@(C$R(/-RX7,@9F]R;>%T=6TB"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T(/-RX7,@
M9F]R;>%T=6TB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I
M9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@\W)A(@H*(SH@;&EB+TAO<F1E+U5)
M+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ%;/5Z
M]2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!(&1A=&%B
M87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S
M='(@(D5Z96X@8FQO:VL@:&%S>F[A;&%TX6AO>B!E9WD@861A=&+A>FES(&%L
M<F5N9'-Z97(@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38R"FUS
M9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")(96QY
M<F5H;WIH871A=&QA;B!H:6)A('3V<G3I;G0B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(D$@;&5VZ6P@
M=&ET:V]S[73A<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,@<WK\:W/I
M9V5S+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D$@9&EG:73A;&ES86X@86SA[7)T
M(&QE=NEL(&5L;&5N]7)ZZ7/I:&5Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S
M('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY
M"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@HB02!T:71K;W/M=&]T="!L97;I;"!D96OS
M9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S+"!E9WD@=&ET:V]S
M(%!'4"`B"B)K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z_&MSZ6=E<RXB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@HB02!L97;I;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y(&YY:6QVX6YO
M<R!01U`@:W5L8W,L(&5G>2!T:71K;W,@4$=0(&MU;&-S("(*(NES(&5G>2!J
M96QM;VYD870@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB02!T:71K;W/M
M=&]T="!L97;I;"!D96OS9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%
M(&MU;&-S+"!E9WD@=&ET:V]S(%,O(@HB34E-12!K=6QC<R#I<R!E9WD@:F5L
M;6]N9&%T('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D$@;&5VZ6P@9&EG:73A
M;&ES(&%LX>URX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU;&-S+"!E
M9WD@=&ET:V]S(%,O34E-12`B"B)K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z
M_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM
M<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R(")!(&QE=NEL('1I=&MO<^UTX7/A:&]Z
M(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU;&-S('-Z_&MSZ6=E<RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!
M32!#;&]U9',B"FUS9W-T<B`B1.EL96SU='0@8F]R=6QT(.EG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-
M($QI9VAT(%)A:6XB"FUS9W-T<B`B1.EL96SU='0@9WEE;F=E(&5S]2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED
M(")!32!286EN(@IM<V=S='(@(D3I;&5L]71T(&5S]2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W
M97)S(@IM<V=S='(@(D3I;&5L]71T:2!ZX7!O<F]K(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")$Z6QE;/5T="!H\WKA<&]R;VLB"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B
M9&4O9'4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P
M,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"`H82!P<F]G<F%M;WKA
M<VD@9F5L_&QE="!A>F]N;W/M=/-J82DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D
M:71O<B(*;7-G<W1R(")%<G+U;"!A>B!E9&ET;W)R\VPB"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B
M3NEV:F5G>2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")A8G-Z(&%L
M=6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B86)S>B!K]GKI<"(*"B,Z
M(&QI8B]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").:6YC<R!J;V=O<W5L
M='/A9V$@82!61E,@86QK]FYY=G3A<B!LZ71R96AO>N%SX6AO>BXB"@HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N(@IM<V=S='(@(DYI;F-S(&IO9V]S=6QT<^%G82!A
M(%9&4R!FX6IL(&SI=')E:&]ZX7/A:&]Z+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@
M(D)E:F5L96YT:V5ZZ7-I(&EN9F]R;>%C:?,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B
M2F5L<WKS(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")!(&IO9V]S=6QT
M<^%G(&9E;"!V86X@9OQG9V5S>G1V92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(E#I;GK\
M9WEE:R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30X('1E;7!L871E
M<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(D)E=FET96PB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R
M-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D%L8W-O<&]R="!L
MZ71R96AO>N%S82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3@@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B2F]G;W-U;'1SX6=I(&%L8W-O<&]R="!LZ71R96AO
M>N%S82(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!
M9&0@2&5R93HB"FUS9W-T<B`B061D:G5K(&AO>GKA(&ET=#HB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B
M061D($YE=R!'<F]U<"(*;7-G<W1R("+::B!C<V]P;W)T(&SI=')E:&]ZX7-A
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T
M<B`BVFH@:F]G;W-U;'1SX6<@;.ET<F5H;WKA<V$B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")!;&-S
M;W!O<G0@:&]Z>N%A9.%S82!<(B5S7"(M:&5Z(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B2F]G;W-U;'1SX6=I
M(&%L8W-O<&]R="!H;WIZX6%DX7-A(%PB)7-<(BUH97HB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(MIJ
M(&9E;&AA<WINX6SS(&SI=')E:&]ZX7-A.B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`BVFH@;W-Z;&]P(&AO>GKA863A<V$B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`BVFH@=&%G;VL@9F5L=NET96QE(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BVFH@
M<.%R(&AO>GKA863A<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<B(*;7-G<W1R(")!*'HI("5S(&UE;OQT(&%D:G5K(&AO
M>GKA(&$@36]Z:6QL82!M96[\<V]R:&]Z(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O
M:SHB"FUS9W-T<B`B061J=6L@:&]Z>N$@82!C[6UJ96=Y>NEK:&5Z.B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D
M9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B061J=6L@:&]Z>N$@82!C
M[6UJ96=Y>NEK96UH97HB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B
M061D('5S97(B"FUS9W-T<B`BVFH@9F5L:&%S>F[A;/,@:&]Z>N%A9.%S82(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S
M='(@(B(*(EPB)7-<(B!F96QH87-Z;N%L\W0@:&]Z>N%A9'1U:R!A(')E;F1S
M>F5R:&5Z+"!D92!N96T@<VEK97+\;'0@82!T]F)B:2`B"B)B96IE;&5N=&ME
M>NES:2!A9&%T('3A<F]LX7-A.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(EPB)7-<(B!F96QH87-Z
M;N%L\W0@9F5L=F5T=.EK(&$@<F5N9'-Z97)B92X@36]S="!MX7(@8F5J96QE
M;G1K97IH970N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC
M.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B
M02!R96YD<WIE<FAE>B!N96T@861H873S:R!H;WIZX2#Z:B!F96QH87-Z;N%L
M\VLN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B0^UM
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(D/M;6IE9WEZZ6LB"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES>G1RX6-I\R`M
M(&IO9V]S=6QT<^%G;VL@863A<V$@=&]VX6)B:2!F96QH87-Z;N%L\VMN86LB
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M
M:6YI<WIT<N%C:?,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S
M"FUS9VED(")!9',B"FUS9W-T<B`B2&ER9&5TZ7-E:R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA
M;FES=&%N(@IM<V=S='(@(D%F9V%N:7-Z=.%N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*
M;7-G<W1R(")!;&+A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&?I
M<FEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*
M;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI
M9VXB"FUS9W-T<B`B16QH96QY97KI<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS
M9W-T<B`B4F5N9&5ZZ7,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W
M"FUS9VED(")!;&PB"FUS9W-T<B`B87H@]G-S>F5S970B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")-
M:6YD96X@;F5M('9E;F3I9R!F96QH87-Z;N%L\R(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`B36EN9&5N(&-S;W!O<G0B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.CDQ(&QI8B](;W)D92]097)M<R]D871A=')E92YP:'`Z-S4*
M;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")-:6YD96X@:F]G;W-U
M;'1SX6<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")-
M:6YD(&$@;NEG>2!O;&1A;&]N(&QE9WEE;B!K97)E="(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#<U"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,B"FUS9W-T<B`B16YG961J_&YK(&UE9R!T]F)B(&/M;65T(&ES(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B02!S;W)S>N%M;W,@
M9F5L<V]R;VSA<R!T[7!U<V$@=N%L=&]Z=&%T:&%T\R!L96=Y96X_(@H*(SH@
M;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y
M(&5X:7-T<R(*;7-G<W1R(")-X7(@;.ET97II:R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM
M<V=S='(@(DE-4U`@8F5J96QE;G1K97KI<VD@<&%R86WI=&5R96LB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!087-S=V]R9"(*;7-G<W1R(")-X7-I:RP@24U34"!J96QS>O,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M92(*;7-G<W1R(")-X7-I:RP@24U34"!B96IE;&5N=&ME>NES
M:2!NZ78B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I
M9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B3>%S:6L@96UA
M:6P@8^UM(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L
M=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N873M=B!S86)L;VYO
M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@
M(D%L=&5R;F%T[78@<WKV=F5G.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM
M<V=S='(@(D%M97)I:V%I(%-Z86UO82(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B02!M96=A
M9&]T="#I<G3I:R!N96T@9F]G861H873S(&5L+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@
M:&%S(&]C8W5R960N(@IM<V=S='(@(DES;65R971L96X@:&EB82!T]G)TZ6YT
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N
M9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R
M(")!;F=U:6QL82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM
M<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYI;2!P<F]X>6X@
M:V5R97-Z=/QL:2!I;G1E<FYE="!E;.ERZ7,B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E;A;&%S
M>B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&ES>B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G
M:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82#I<R!"
M87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,S4@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU.`HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A
M=&EO;B(*;7-G<W1R(")!;&MA;&UA>N%S(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(D%L
M:V%L;6%ZX7-O:R!L:7-TX6IA(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(D%Z
M(&%L:V%L;6%ZX7,@:^ES>BXB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(D$@:_9Z]G,@=.%R=&5R_&QE="!A;&-S;W!O<G1J86ER82!I<R#I<G;I;GEE
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS
M9VED(")!<'!R;W9E(@IM<V=S='(@(DKS=N%H86=YX7,B"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q"FUS9VED(")!<'!R;WAI;6%T92!3
M:7IE(@IM<V=S='(@(DOV<OQL8F5L_&QI(&WI<F5T(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(N%P
M<FEL:7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B07)A
M8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(F%R86(@*%=I;F1O=W,M,3(U
M-BDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.2!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B
M"FUS9W-T<B`B02!T]FWV<NUT971T(.%L;&]MX6YY(&WI<F5T92(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B02!T]FWV
M<NUT971T(.%L;&]MX6YY(&YE=F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_(@IM<V=S='(@(D)I>G1O<R!B96YN92P@:&]G>2!T]G+V
M;&YI(&OM=N%N:F$@)7,@8F5J96QE;G1K97KI<VD@:6?I;GGI=#\B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB
M)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D)I>G1O<RP@:&]G
M>2!T]G+V;&YI(&%K87)J82!<(B5S7"(M="!A;&-S;W!O<G1J86EV86P@96=Y
M_'1T/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G3M;F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(")!<FUE;FEA(@IM<V=S='(@(M9R;>EN>6]R<WKA9R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX
M*2(*;7-G<W1R("+V<FWI;GD@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")-^W;I<WIE="(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@
M(E!O:&YP96DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@
M(D%S8VEI($%R="(*;7-G<W1R(")!<V-I:2!R86IZ;VLB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO
M;B(*;7-G<W1R("+!>G-I82]#<V5N9&5S+?-C9>%N:2!RZ6=I\R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*
M;7-G<W1R("(B"B)+Z7)J96X@82!R96YD<WIE<B!M96=E<O5S[73I<W0@82!K
M87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<V4@96SU='0_(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3D*;7-G:60@(D%S<VEG;FUE;G0@8V]L
M=6UN<R(*;7-G<W1R(")(;WIZX7)E;F1E;.ES:2!O<WIL;W!O:R(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(").96ULZ71E>O4@8W-O<&]R
M=&]T(&OM<^ER96QT(&UE9R!T]G+V;&YI+B(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE;6SI=&5Z]2!J;V=O<W5L
M='/A9V]T(&OM<^ER96QT(&UE9R!T]G+V;&YI+B(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5M;.ET97KU(&IO9V]S=6QT
M<^%G;W0@:^USZ7)E;'0@;65G(&UE9W;A;'1O>G1A=&YI+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(").96ULZ71E>O4@:_9Z
M]G,@=.%R=&5R_&QE=&5T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT871N:2XB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-"!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R(")4
M=6QA:F1O;G/A9V]K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")A=6=U<WIT=7,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<F%L:6$B"FUS9W-T<B`B075S>G1RX6QI82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B
M"FUS9W-T<B`B075S>G1R:6$B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN
M<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ(&$@<WK\
M:W/I9V5S(&EM87`@8O5V[73I<R!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS
M9W-T<B`B(@HB075T:%]C>7)U<SH@82!HX71TZ7)S>F]L9^%L=&%TX7,@;F5M
M(')E;F1E;&ME>FEK(&$@:^UVX6YT(&OI<&5S<^EG96MK96PN(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7V-Y<G5S.B!A('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L
M:&%T\RXB"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B
M"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N
M(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!A('-Z_&MSZ6=E<R!F='`@8O5V[73I
M<R!N96T@=&%LX6QH873S+B!&;W)D[71S82!L92!A(%!(4"UT(&%Z("TM(@HB
M96YA8FQE+69T<"!O<&-I\W9A;"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P
M+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@82!S>OQK<^EG
M97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z
M(&$@<WK\:W/I9V5S(&MR8C4@8O5V[73I<R!N96T@=&%LX6QH873S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z(&YE;2!H;WIH873S:R!LZ71R
M92#Z:B!F96QH87-Z;N%L\VL@06-T:79E($1I<F5C=&]R>2!E<V5TZ6XB"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A
M<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z(&9E;&AA<WINX6SS:R!N
M96T@=/9R]FQH973U:R!!8W1I=F4@1&ER96-T;W)Y(&5S973I;B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]L9&%P.B!A('-Z_&MSZ6=E<R!,1$%0(&+U=NUTZ7,@;F5M('1A;.%L:&%T
M\RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H
M7VQD87`Z("5S(&9E;&AA<WINX6SS(&AO>GKA863A<V$@;F5M('-I:V5R_&QT
M+B!!('-Z97)V97(@=N%L87-Z83H@(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@)7,@
M9F5L:&%S>F[A;/,@=/9R;.ES92!N96T@<VEK97+\;'0B"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T
M:%]L9&%P.B`E<R!F96QH87-Z;N%L\R!A9&%T86EN86L@;65G^FKM=.%S82!N
M96T@<VEK97+\;'0B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,#4*
M;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B075T:%]L9&%P
M.B!A(&9E;&AA<WINX6SS:R!N96T@;?-D;W/M=&AA=/-K($%C=&EV92!$:7)E
M8W1O<GD@97-E=.EN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*
M;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ(&$@<WK\:W/I9V5S($U#04P@
M8O5V[73I<R!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M
M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z
M(&$@<WK\:W/I9V5S('-M8F%U=&@@8O5V[73I<R!N96T@=&%LX6QH873S+B(*
M"B,Z(&QI8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B3F5M
M('-I:V5R_&QT(&%Z($E-05`@<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A
M>F]N;W/M=.%S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B
M02!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('-I:V5R_&QT+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D$@9F5L:&%S>F[A
M;/-A>F]N;W/M=.%S(&YE;2!S:6ME<OQL="X@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B02!F96QH87-Z;N%L
M\R!A>F]N;W/M=.%SX70@82!2041)55,@<WIE<G9E<B!E;'5T87/M=&]T=&$N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!A>B!&5%`@<WIE<G9E<FAE>B!V86SS(&9E;&AA<WINX6SS87IO;F]S[73A
M<RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B3F5M('-I
M:V5R_&QT(&%Z(%--0B!S>F5R=F5R96X@=F%L\R!F96QH87-Z;N%L\V%Z;VYO
M<^UTX7,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I
M9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B02!R96YD96QK97KI<W)E
M(.%L;/,@;65Z]6LZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R
M8F%J9'ISX6XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@
M(D)/1D@@17AC=7-E<R(*;7-G<W1R(")!(&=O;F]S>B!R96YD<WIE<F=A>F1A
M(&UE;G1SZ6=E:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B
M2.%T=.ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")(X71T
MZ7(@<WKM;B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED
M(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(DYE;2!M96=F96QE
M;/4@:V5R8F5R;W,@:F5L<WKS+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@
M(DYE;2!M96=F96QE;/4@:V5R8F5R;W,@9F5L:&%S>F[A;/-NZ78N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;>%K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R(")"86AR96EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*
M;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(F)A;'1I("A)
M4T\M.#@U.2TQ,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L
M861E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D$@9W)A9FEK=7,@X6QL;VWA;GEO:R!<(B5S7"(@86QK]FYY=G3A
M<F$@;F5M('1A;.%L:&%T\RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S
M='(@(F%L87!V;VYA;&]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")&96CI
M<F]R;W-Z;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:75M
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN
M(@IM<V=S='(@(D)E;FEN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M
M=61A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=73A;B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A
M>2(*;7-G<W1R(")3>OQL973I<VYA<"(*"B,Z(&QI8B](;W)D92]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@
M7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D$@7"(E<UPB(&)L;VMK(&$@7"(E<UPB('!R;V=R86UM86P@;F5M('1A
M;.%L:&%T\RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(DOI<&5R;GGU<NES>B!B
M9>%L;.UTX7,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*
M;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B2^EP97)N>?5RZ7-Z('3M<'5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M"FUS9VED(")";VQD(@IM<V=S='(@(F;I;&OV=NER(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I
M82(*;7-G<W1R(")";VSM=FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(DME9'9E;F,@=V5B
M8^UM96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B2V5R970B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS
M9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")+97)E='9A<W1A9W/A
M9SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(DME<F5T96LB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<WIN:6$M
M2&5R8V5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G
M:60@(D)O=&@B"FUS9W-T<B`B36EN9&ME='3U(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B
M"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R
M(")A;'5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V970M
M<WII9V5T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87KM;&EA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"
M<FET($EN9&EA:2WS8V7A;FD@5&5R_&QE="(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U
M<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L
M9V%R:6$B"FUS9W-T<B`B0G5L9^%R:6$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T
M(@IM<V=S='(@(D9E;'-O<F]LX7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS
M9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"
M=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B0TU3(@IM<V=S='(@(E=E8F]L9&%L(&MA<F)A;G1A<G3A<R(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS
M9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*
M;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D$@=&%N
M^G/M=';A;GEV:7-S>F%V;V[A<VD@;&ES=.%K("A#4DPI(&/M;65I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(D-E;&QA
M('1U;&%J9&]N<^%G;VLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*
M;7-G<W1R(")!(&-A8VAE(&EN:6-I86QI>N%LX7-A(&YE;2!F96IE>O5D]G1T
M(&)E+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M.#4@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B3F%P
M=.%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I
M9"`B0V%L;2(*;7-G<W1R(").>75G;V1T(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM
M<V=S='(@(DMA;6)O9'IS82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA
M;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I
M9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT
M(&$@:F5L<WKS="#A=.%L;.UT86YI+"!F;W)D=6QJ;VX@82!R96YD<WIE<F=A
M>F3A:&]Z+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T
M<B`B02AZ*2!<(B5S7"(@X6QL;VWA;GD@;F5M(.UR:&%T\RXB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT
M97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B02!K_&QS]2!F96QH
M87-Z;N%L\VMA<&-S;VQA="UK97IE;/5K(&YE;2!A9&UI;FES>G1RX6QH873S
M:RXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(D$@:_9V
M971K97KU($E-05`@<WIE<G9E<B!N96T@Z7)H973U(&5L.B`E<R(*"B,Z(&QI
M8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(.%L;&]M
MX6YY(&YE;2!N>6ET:&%T\R!M96<N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@
M(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H
M<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S
M='(@(DWI9W-E(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")-Z6=S
M92!K_&QD]FL@:&EB86IE;&5N=.ES="(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@X6QL;VWA;GD@;F5M('3V<O9L
M:&5T]2XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5M('1A;.%L:&%T\R!A>B!I
M9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7(N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S
M='(@(D$@)W1A<F=E=$9I;&4G('!A<F%MZ71E<B!M96=A9.%S82!NZ6QK_&P@
M;F5M(&9O;'ET871H871J=6LN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%L:_9N>79TX7(@;F5M('3V
M<O9L:&5T]2XB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$R."!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@
M(DYE;2!T]G+V;&AE=/4L("5D(&%L8W-O<&]R=&IA('9A;BXB"@HC.B!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B
M"B)!>B#Z:B!S;W)B87)E;F1E>NES(&YE;2!L96AE='/I9V5S+"!A(&UE9V%D
M;W1T(&%D871O:R!S>N%M82!N96T@96=Y97II:R!A("(*(G3A<F]L=&%KZ79A
M;"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM
M<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BXB"FUS9W-T<B`B02!M96=A9&]T="!S>N%M<F$@;F5M(&O\;&1H973U(&5L
M(&%Z(/QZ96YE="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(EKV;&0M
M9F]K:2US>FEG971E:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B
MP6)R87-Z]G9E9R(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(E-Z;VQGX6QT873S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N
M9"!,86)E;',B"FUS9W-T<B`B2V%T96?S<FGA:R#I<R!J96SV;.ES_&LB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM
M<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B2V%J;>%N+7-Z:6=E=&5K
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G
M:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6P@=&5L969O;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*
M;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")#96QL871U;&%J9&]N
M<^%G;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")#96QL82!B
M96QS]2!M87)G\SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS
M9W-T<B`B0V5L;&%T=6QA:F1O;G/A9V]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN
M9SHB"FUS9W-T<B`B0V5L;.%K(&OV>O9T=&D@<NES.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36]B
M:6P@=&5L969O;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED
M(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")K96QT82`H25-/+3@X
M-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(FOV>NEP(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(DOV>NEP
M+6%F<FEK86D@2_9Z=.%R<V%SX6<B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS
M9W-T<B`B:V5L970M975R\W!A:2`H25-/+3@X-3DM,BDB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T
M86EL<R(*;7-G<W1R(")!('1A;OIS[71VX6YY('+I<WIL971E:2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T
M92!/=VYE<B(*;7-G<W1R(")!('1A;OIS[71VX6YY('1U;&%J9&]N;W-A(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I
M9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E1A;OIS[71VX6YY(&9E;&AA<WIN
MX6SA<VD@:7+A;GEE;'9E:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")#<^%D
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@
M(E;A;'1O>G1A=.%S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")!(&IE
M;'-Z\R#A=.%L;.UTX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y
M"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*
M(F5M86EL<RXB"FUS9W-T<B`B07H@UFX@X6QT86P@96QK_&QD]G1T(&QE=F5L
M96ME;B!S>F5R97!L]2!NZ78@Z7,@8^UM(&UE9W;A;'1O>G1A=.%S82XB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H
M86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H
M92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB02!J96QE;B!K;VYF:6=U<N%C:?-B
M86X@;F5M(&QE:&5T<^EG97,@82!J96QS>F%V86L@;?-D;W/M=.%S82X@1F]R
M9'5L:F]N(&$@(@HB<F5N9'-Z97)G87IDX6AO>BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#
M:&%R(@IM<V=S='(@(DMA<F%K=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@
M3&EN:RXN+B(*;7-G<W1R("),:6Y?:V5L;&5N]7)ZZ7,N+BXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M:&EL92(*;7-G<W1R(")#:&EL92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(DOM
M;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(FOM;F%I+"!E9WES>F5R
M^W/M=&5T="`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T
M"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")K
M[6YA:2P@:&%G>6]MX6YY;W,@*$)I9S4I(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R
M(")6X6QA<W-Z;VX@:VD@96=Y(&%L:V%L;6%ZX7-T.B(*"B,Z(&QI8B](;W)D
M92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R
M9"(*;7-G<W1R(")6X6QA<W-Z;VX@:F5L<WKS="(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R(")6X6QA<W-Z;VX@96=Y(&9E;&AA<WINX6SS;F5V970B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@9.%T=6UO
M:R!M96=J96QE;NUTZ7-I(&9O<FWA:N%T.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G
M<W1R(")6X6QA<W-Z82!K:2!A(&9E;'-O<F]LX7,@=.UP=7/A="`H<WKA;6]Z
M;W1T(&QI<W3A:V[A;"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S
M='(@(DMA<N%C<V]N>2US>FEG971E:R(*"B,Z(&QI8B]61E,N<&AP.CDQ-"!L
M:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")!*'HI("5S
M(&-L87-S(&1E9FEN[6-I\VIA(&YE;2!T86SA;&AA=/,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R
M(@IM<V=S='(@(D1E<OQL="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B
M"FUS9W-T<B`B5/9R;&D@87H@35-/9F9I8V4@=&%G96ME="(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@
M(D$@;&5KZ7)D97KI<R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T
M('5S97(Z("5S(@IM<V=S='(@(B5S(&9E;&AA<WINX6SS('3V<FSI<V4B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L
M96%R('5S97(B"FUS9W-T<B`B02!F96QH87-Z;N%L\R!T]G)LZ7-E(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R(")!(&9E;&AA<WINX6SS(&%D871A:6YA:R!T
M]G)LZ7-E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B17-TZ7)E(&1E
M<OQL="#I9R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")!
M(&9O;'ET873A<VAO>B!K871T:6YT<V]N(&%Z(&5GZ7)R96PB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA
M=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('-Z;VQGX6QT873A
M<R!(5%10+6X@:V5R97-Z=/QL(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S
M92!7:6YD;W<B"FUS9W-T<B`B07H@86)L86L@8F5ZX7+A<V$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(D)O
M<G5L="#I9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B4F5G9V5L(&9E
M;&CU<R!I9/4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D9E;&CU<R!I9/4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS
M9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")+\VMU<WHM
M<WII9V5T96LB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E3\;G1E<W/\:R!E
M;"!A>B!O;&1A;'/S(&UE;OQT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O
M<F1E<G,B"FUS9W-T<B`BUG-S>F5ZX7)T(&ME<F5T96LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO
M;6)I82(*;7-G<W1R(")+;VQU;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO
M<B(*;7-G<W1R(")3>NUN(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,S,2!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,R
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,#,@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@
M4&EC:V5R(@IM<V=S='(@(E-Z[6YVX6QA<WIT\R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#,R"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(E-Z[6YVX6QA<WITX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B3W-Z;&]P
M;VLZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M
M;B!T:71L97,B"FUS9W-T<B`B07H@;W-Z;&]P;VL@8^UM96DB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T
M<B`B5FEC8V5K(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#
M;VUM86YD(@IM<V=S='(@(E!A<F%N8W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B4&%R86YC<^ER
M=&5L;65Z]2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B0V]M;65N="(*;7-G<W1R(")-96=J96=Y>NES(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S
M='(@(D[I=BP@96QN979E>NES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B
M0V]M;W)E+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B0^EG(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS
M9W-T<B`B4WKA;>UT\V?I<&5K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(DED]6KA<N%S
M:2!H96QY>F5T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@
M(D-O;F1I=&EO;G,B"FUS9W-T<B`B263U:N%RX7-I(&AE;'EZ970B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<R(*;7-G<W1R(")+_&SV;F)SZ6=E:R!A(&MO;F9I9W5RX6-I
M\V)A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O
M;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE
M<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB2^EZ:7-ZX6WM=/-GZ7!E:VME
M;"P@;VMO<W1E;&5F;VYO:VMA;"P@3W5T;&]O:VMA;"!V86SS(&%D871S>FEN
M:W)O;FEZX6SA<R`B"B)K;VYF:6=U<N%C:?-J82(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F
M(&1A=&4N(@IM<V=S='(@(D$@:V]N9FEG=7+A8VGS(&WA<B!N96T@Z7)VZ6YY
M97,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B)7,@:V]N9FEG=7+A
M8VGS:F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q
M"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D$@:F5L<WKS(&UE
M9V5R]7/M=.ES92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F?S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I
M9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G
M<W1R(")+;VYG\VD@1&5M;VMR871I:W5S($OV>G3A<G-A<^%G(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9"XB"FUS9W-T<B`B4VEK97)T96QE;B!A(&MA<&-S;VQA="XB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M.B`B"FUS9W-T<B`B4VEK97)T96QE;B!A(&MA<&-S;VQA=#H@(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D$@;GEI
M;';A;F]S(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA
M=&]T+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")!(&YY:6QV
MX6YO<R!K=6QC<V]K('-Z97)V97)E(&5L=71A<^UT:F$@82!K87!C<V]L871O
M="X@3VMA.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@W-@IM<V=I
M9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M4VEK97)T96QE;B!A>B!&5%`@<WIE<G9E<G)E;"!V86SS(&MA<&-S;VQA="XB
M"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`B4&%R=&YE<F5K(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D$@
M<&%R=&YE<F5K970@<VEK97)E<V5N(&AO>GKA861T=6L@82!C[6UJ96=Y>NEK
MZ6AE>BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM
M<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S
M='(@(D$@=/9M]G+M=&5T="#A;&QO;>%N>2!T[7!U<V$Z("(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<
M(B(*;7-G<W1R(")<(B5S7"(@=&%R=&%L;6$B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(D9O;'ET873A<R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K+7-Z:6=E=&5K(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B
M4_QT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")-X7-O;&IU:R#A
M="(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(D$@;>%S;VSA<R!N96T@<VEK
M97+\;'0Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B02!K
M:6IE;/9L="!RZ7-Z(&WA<V]LX7-A(@H*(SH@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C$W,"!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED
M(")#;W-T($E$(@IM<V=S='(@(E-ZX6ULX7KA<VD@87IO;F]S[73S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T
M92!D)TEV;VER92(*;7-G<W1R(")%;&5FX6YT8W-O;G1P87)T(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DYE;2!S:6ME<OQL="!01U`M
M=F5L('1I=&MO<^UT86YI(&$@;&5V96QE=#H@(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4Z("(*;7-G<W1R(")!(&QE=F5L970@;F5M('-I:V5R_&QT(%!'4"!A
M;.'M<N%S<V%L(&5L;.%T;FDZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`B02!L979E;&5T(&YE;2!S:6ME<OQL="!A>B!3+TU)
M344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&%N:2XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(D$@;&5V96QE="!N96T@<VEK97+\
M;'0@4R]-24U%(&%LX>URX7-S86P@96QLX71N:2XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B02!P87)T;F5R
M(&%D871A:70@;F5M('-I:V5R_&QT(&5L=.%R;VQN:2X@)7,B"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")!>B!,1$%0
M('-Z97)V97(@;F5M(.ER:&5T]2!E;"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@96QL96[U<FEZ
M;FD@82!S>N%M;.%JX6X@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9V5T+B`E
M<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").96T@<VEK
M97+\;'0@87H@3$1!4"!S>F5R=F5R:&5Z(&MA<&-S;VSS9&YI+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@
M)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&$H>BD@7"(E<UPB('-Z97)V97)R
M96P@1E10(&MA<&-S;VQA=&]T(&9E;'9E;FYI.B`E<R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@82!K]G)L97;I;&QI<W3A
M="X@)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(D%Z(&%D
M871O:R!01U`@=&ET:V]S[73A<V+S;"!T]G)TZ6[U(&1E:_-D;VSA<V$@;F5M
M('-I:V5R_&QT.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R
M,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(D%Z(&%D871O:R!3+TU)344@=&ET:V]S[73A<V+S;"!T]G)TZ6[U(&1E
M:_-D;VSA<V$@;F5M('-I:V5R_&QT+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")!('!A<G1N97(@=/9R
M;.ES92!N96T@<VEK97+\;'0N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")!(&OV
M<FQE=NEL;&ES=&$@=/9R;.ES92!N96T@<VEK97+\;'0N("5S(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(DYE;2!S:6ME<OQL="!T]G+V;&YI(&$H>BD@7"(E<UPB('-E
M='5P('5P9W)A9&4@<')O9W)A;6]T+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU,PIM<V=I
M9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL
M(&%D9')E<W,N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!M96?A;&QA<.UT86YI
M(&$@8^UM>F5T="!E;6%I;"!C[6WI="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").96T@<VEK97+\;'0@8F5O
M;'9A<VYI(&$@=&5L:F5S(&/M;6IE9WEZZ6ME="XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYE;2!S
M:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@:_9R;&5VZ6QL:7-TX70N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A
M(&OV<FQE=NEL;&ES=.%K('1E;&IE<R!F96QS;W)O;.%SX70N(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E
M<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!S=')A=.EG:6$@;F5M('1A;.%L
M:&%T\RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@
M86QK]FYY=G3A<B!N96T@:&]Z:&%T\R!LZ71R92XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(D$@;GEI;';A
M;F]S(&MU;&-S;W0@;F5M('-I:V5R_&QT(&UE9W-Z97)E>FYI(&$@:W5L8W-S
M>F5R=F5R<O5L+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(DYE;2!S
M:6ME<OQL="!<(B5S7"(M="#M<N%S:2!CZ6QL86P@;65G;GEI=&YI+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B`E<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT("5S+70@;65G;GEI=&YI
M+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S(@IM<V=S='(@(D$@)7,@:V%R8F%N=&%R=.%S:2!M;V1U;"!N
M96T@;GEI=&AA=/,@;65G(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B02AZ
M*2!<(B5S7"(@86QK]FYY=G3A<B!N96T@;GEI=&AA=/,@;65G+B(*"B,Z(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C,W(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-38@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B07H@3$1!4"!S>F5R=F5R(&YE;2#I<FAE=/4@
M96PN(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B)7,@;F5M(&]L
M=F%S:&%T\RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM
M<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*(DYE;2!S:6ME<OQL="!A(&OM=N%N="!F96QH87-Z;N%L\R!J
M96QS>F%VX70@X73A;&SM=&%N:2X@07H@;65G861O='0@861A=&]K("(*(FYE
M;2!V86=Y(&YE;2!T96QJ97-E;B!F96QE;&YE:R!M96<N(%!R\V+A;&IA(/IJ
M<F$L('9A9WD@:&$@=&]VX6)B:2`B"B)S96?M='/I9W)E('9A;B!S>OQK<^EG
M92P@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BXB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,S@*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W-2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3F5M('-I:V5R_&QT
M(&UE9VAA=.%R;WIN:2!A>B!E;.ERZ7-I(&IO9V]S=6QT<^%G;VMA="`H04-,
M*2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&/M
M;6IE9WEZZ6ME="X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5M('-I:V5R
M_&QT(&)E;VQV87-N:2!A(&OV<FQE=NEL;&ES=.%T+B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@
M)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV<FQE=NEL
M;&ES=.%K870N("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T
M<B`B3F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A('-Z97)V97(@:^EP97-S
MZ6=E:70B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#
M;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYE;2!S
M:6ME<OQL="!V:7-S>F'A;&SM=&%N:2!E>B!E<F5D971I(&MO;F9I9W5RX6-I
M\W0N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@86QK]FYY=G3A<B!N
M96T@=/9R]FQH973U+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DYE;2!S:6ME<OQL="!E;&UE;G1E;FD@)7,@
M:V]N9FEG=7+A8VGS="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F5M('-I:V5R
M_&QT(&5L;65N=&5N:2!A(&)A8VMU<"!K;VYF:6=U<N%C:?-T+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S
M='(@(DYE;2!S:6ME<OQL="!E;&UE;G1E;FD@82!B86-K=7`@:V]N9FEG=7+A
M8VGS=#H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(").96T@<VEK97+\;'0@96QM
M96YT96YI(&$H>BD@7"(E<UPB('-E='5P('5P9W)A9&4@<')O9W)A;6]T+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!E;&UE;G1E;FD@82AZ
M*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*(D$H>BD@)7,@:V]N9FEG=7+A8VGS<R#A;&QO
M;>%N>70@;F5M('-I:V5R_&QT(&5L;65N=&5N:2X@5F%G>2!H87-Z;N%L:F$@
M82`E<R`B"B)O;&1A;&]N(&QE=O4@;&5H973U<^EG96ME="P@=F%G>2!MX7-O
M;&IA(.%T(&%Z(&%LX6)B:2!K\V1O="!I9&4Z("5S+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D%Z($Q$05`@<WIE<G9E<F5N(&YE
M;2!S:6ME<OQL="!E;';I9V5Z;FD@82!K97)E<^ES="XB"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS
M9W-T<B`B7"(E<UPB(&YE;2!V;VQT('3V<O9L:&5T]2XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B02!P
M87)T;F5R(&%D871A:70@;F5M('-I:V5R_&QT(&WS9&]S[71A;FDN("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@82!K]G)L97;I;&QI<W1A
M(&WS9&]S[73A<V$N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYE;2!S:6ME<OQL="!E
M;&UE;G1E;FD@7"(E<UPB(&MO;F9I9W5RX6-I\VKA=#H@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+B(*;7-G<W1R(")!($UO>FEL;&$@;65N_'-O<B!N96T@=&%LX6QH873S
M+B!%;&QE;O5R:7IZ92P@:&]G>2!M96<@=F%N+64@;GEI='9A+B(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*(DYE;2!S:6ME<OQL="!<(B5S7"(@9F5L:&%S>F[A;/-N86L@:F]G
M;W-U;'1SX6=O="!A9&YI(&$H>BD@7"(E<UPB(&UA<'#A:&]Z.B`E(@HB<R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(S"FUS9VED(")#;W5N=&5D('1E
M>'0B"FUS9W-T<B`B2V]R;.%T;W,@<WKV=F5G(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B3W)S
M>N%G(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B
M0V]U<G-E<R(*;7-G<W1R(")4X79O:W1A=.%S(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED
M(")#<F5A=&4B"FUS9W-T<B`B3.ET<F5H;WKA<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B
M0W)E871E(&$@;&EN:R(*;7-G<W1R("),:6YK(&SI=')E:&]ZX7-A(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B
M0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("+::B!LZ71R96AO>N%S82(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L
M9&5R<R(*;7-G<W1R(")!;&UA<'#A:R!LZ71R96AO>N%S82(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(D%Z(&]B:F5K='5M(&SI=')E:&]Z\VKA;F%K(&IO9V]S
M=6QT<^%G86DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q-@IM<V=I9"`B
M0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DAI=&5L:^%R='EA<WKA;2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DAO<G;A=&]R<WKA9R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@
M(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")*96QE;FQE9VD@
M-"!FX7II<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R
M<F5N="!397-S:6]N<R(*;7-G<W1R(")!(&IE;&5N;&5G:2!F96QH87-Z;N%L
M\VMA<&-S;VQA=&]K(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L
M;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B
M4&]N=&]S(&ED]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B02!J96QE;FQE9VD@55),(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(DIE;&5N;&5G:2!F
M96QH87-Z;N%L\VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B2F5L96YL96=I(&ED]6KA<N%S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")!(&IE;&5N;&5G:2!I9/5J
MX7+A<VD@:&5L>7IE=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@
M(DIE;&5N;&5G:2!S=.UL=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@HB36EL>65N('!A<F%N
M8W-O:R!F=7-S86YA:R!L92!A=71O;6%T:6MU<V%N(&$@)7-B92!T]G)TZ6[U
M(&)E:F5L96YT:V5ZZ7-K;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T
M<B`B2VEVX6?A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B02!K
M:6IE;/9L="!RZ7-Z(&MI=N%GX7-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@
M(D-I<')U<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#
M>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")C:7)I;&P@*$M/23@M4BDB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2DB"FUS9W-T<B`B8VER:6QL("A7:6YD;W=S+3$R-3$I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")C:7)I;&PM=6MRX6X@*$M/23@M
M52DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")#<V5H($OV>G3A
M<G-A<^%G(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T
M<B`B1$0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-@IM<V=I9"`B(@HB
M1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"B)$4TX@
M*&%D871F;W)RX7-L9>UR\R`M(&SA<V0Z(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N(@HB9&(N:6YT<F\M9'-N+G!H
M<"DB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R(")N87!O;G1A(@H*(SH@861M:6XO9&%T871R964N<&AP
M.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1A=&%4<F5E
M(&+V;F?I<WKU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*;7-G:60@
M(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")!9&%T8N%Z:7-B86X@=F%L\R!K
M97)E<^ES(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#(@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T
M<B`B1.%T=6TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")!(&)EZ7)K97KI
M<R!N87!J82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDS"FUS9VED(")$
M871E('-E;&5C=&EO;B(*;7-G<W1R(")$X71U;2!K:7;A;&%S>G3A<V$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")N87!P
M86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(D]S
M>FQO<"!T]G)LZ7-E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E8V5M8F5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(G-ZX6UO:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G
M:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")"96ME>F3I<R!K:6IJ96)B
M(@H*(SH@;&EB+W!R969S+G!H<#HQ,3<@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ.#<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B06QA<.ER=&5L;65Z971T
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B07H@86QA<.ER=&5L
M;65ZZ7,@<WIE<FEN=&D@<WKM;B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP
M:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B06QA<.ER
M=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S[73S(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(D%L
M87#I<G1E;&UE>F5T="!S:&5L;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6[M8VGS:R(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@;&EB+TAO<F1E+U!E<FUS+G!H<#HS
M,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY."!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R
M(")4]G)LZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@
M(D$@8V5L;&$@=/9R;.ES92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T
M<B`B02!C<V]P;W)T('3V<FSI<V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B02!N87!L
M\^%L;&]MX6YY('3V<FSI<V4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C<W(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@
M4&5R;6ES<VEO;B(*;7-G<W1R(")!(&IO9V]S=6QT<^%G('3V<FSI<V4B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B3&5V96QE:R!T]G)L
MZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B02!C96QL
M82!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R
M(")!>B!O<WIL;W`@=/9R;.ES92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(E3V<O9L:OQK(&MI(&$@;65G;.EV]2!A;'1E<FYA=.UV('-A
M8FQO;G0B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*
M;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R(")!(&QE=F5L96L@=/9R
M;.ES92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM
M<V=S='(@(EPB)7-<(B!J;V=O<W5L='/A9V%I;F%K('3V<FSI<V4B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\B"FUS9W-T<B`B5/9R]FQJ_&L@7"(E<UPB(&IO9V]S=6QT
M<^%G86ET(.ES(&5N;F5K(&5S971L96=E<R!A;&-S;W!O<G1J86ET/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B02!S;W(@=/9R;.ES92(*
M"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G
M:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")!(&MI=N%L
M87-Z=&]T="!A>F]N;W/M=/,@=/9R;.ES92(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD97)S
M(@IM<V=S='(@(D%Z(&%L;6%P<.%K('3V<FSI<V4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B02!J96QE;FQE
M9VD@;W-Z;&]P('3V<FSI<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!R;W<B"FUS9W-T<B`B02!J96QE;FQE9VD@<V]R('3V<FSI<V4B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B5/9R]FQT_&L@82AZ*2!<(B5S7"(@<V5T=7`@=7!G<F%D92!P
M<F]G<F%M;W0N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE
M(@IM<V=S='(@(D$@:^EZ8F5S[73I<R!I9&5J92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B1.%N:6$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B
M061J;VX@;&7M<N%S="!A('!R;V)LZ6WA<O-L(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDT,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("),9>UR
MX7,B"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")2Z7-Z;&5T96L@*&$@
M2&]R9&4@;&]G9N%J;&)A;B!I<R!M96=T86SA;&AA=/,I.B(*"B,Z(&QI8B](
M;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")!('+I<WIL971E:R!A
M(')E;F1S>F5R9V%Z9&$@<WKA;>%R82!KZ7-Z_&SU(&YA<&SS9N%J;&)A(&ME
M<OQL=&5K+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G
M:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D9E:FQE<WITZ7,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@
M(DAA<FUA='!O;G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I
M9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")(87)M871P
M;VYT(&IE;&5N;&5G.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")(87)M871P;VYT
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")B
M86QR\VP@:F]B8G)A(.URX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F="(*;7-G<W1R(")J;V)B<O-L(&)A;')A(.URX7,B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D/M
M;73A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B07H@:63U<&]N=&]K870@
M,C0@\W+A<R!F;W)MX71U;6)A;B!J96QE;NUT<_QK(&UE9S\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B
M"FUS9W-T<B`B365G:F5L96[M=.ES:2!B9>%L;.UTX7-O:R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R(")!('+I<WIL971E<R!E;/5R96IE;'KI
M<R!M96=J96QE;NUTZ7-E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM
M<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")%;/5R96IE
M;'KI<R!M96=J96QE;NUTZ7-E("AR97#\;/5TZ7)I*2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#`S"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R
M(")-96=J96QE;NUTZ7-I(&9O<FWA='5M(@H*(SH@;&EB+TAO<F1E+TU)344O
M341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*
M;7-G<W1R("+)<G1E<^UTZ7,@82!KZ7IB97/M=&5T="!L97;I;"!S;W)SX7+S
M;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1Z<VEB=71I(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B
M"FUS9W-T<B`B3F4@=/9R]FQJ_&LB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP(@IM<V=S='(@(D$@;6%I;G1E;F%N8V4N<&AP(&YE;2#I<FAE
M=/4@96P@:_9Z=F5T;&5N_&PN(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@
M(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B07H@96QS]2!S;W(@
M82!M97KU:R!N979E:70@=&%R=&%L;6%Z>F$_($AA(&EG96XL(&IE;/9L:F4@
M:VD@97IT.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN:6MA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O;6EN:6MA:2!+
M]GITX7)S87/A9R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*
M;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T
M<B`B3FEN8W,@;>EG(&QO9VEN(&YE=F4_($EGZ6YY96QJ96X@96=Y970N(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,@IM<V=I9"`B1&]W
M;FQO860B"FUS9W-T<B`B3&5T]FQTZ7,B"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z.#4R"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D
M("5S(@IM<V=S='(@(E3V;'1S_&L@;&4@)7,M="(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(E3V;'1S_&L@;&4@
M4$A0('!R;V=R86T@9F]R;>%JX6)A;B!A>B!E;&OI<WK\;'0@:V]N9FEG=7+A
M8VGS="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,0IM<V=I9"`B1')O
M<"!D;W=N(&QI<W0B"FUS9W-T<B`B3&5G]G)D_&SU(&QI<W1A(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")+
MX6+M=/-S>F5R96LB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(D4M36%I;"(*;7-G<W1R(")E;6%I;"(*"B,Z(&QI8B].970O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+B(*;7-G<W1R("(B"B)%;6%I;&+U;"!335,M:_QL9/4@;65G:&%J
M=/,L(&AA(&$@=&5L969O;G3A<G-A<^%G(&)I>G1O<^UT:F$@97IT(&$@(@HB
M<WIO;&?A;'1A=.%S="XB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")(24)!
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%8W5A9&]R(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(DWS9&]S[73A<R(*"B,Z
M(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB
M"FUS9W-T<B`B0FQO:VL@;?-D;W/M=.%S(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B
M"FUS9W-T<B`B0W-O<&]R="!M\V1O<^UTX7,B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B2F]G;W-U;'1SX6<@;?-D;W/M
M=.%S(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B
M161I="!097)M:7-S:6]N<R(*;7-G<W1R(")*;V=O<W5L='/A9V]K(&WS9&]S
M[73A<V$B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(B5S(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S82(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z
M(@IM<V=S='(@(DUE;'EI:R!O<&-I\VMA="!VX6QT;WIT87-S=6LZ(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(EPB)7-<
M(B!J;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S(&IO9V]S=6QT<^%G86EN
M86L@;?-D;W/M=.%S82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM
M<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(D]K=&%TX7,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP
M="(*;7-G<W1R(")%9WEI<'1O;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS
M9W-T<B`B4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS
M9W-T<B`B16QE;2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")A>B`G;2<@8F5T
M^R!S>NEL97-SZ6=E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL
M(@IM<V=S='(@(D5M86EL(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D5M86EL(&/M;2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.38W"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"XB"FUS9W-T<B`B07H@96UA:6P@8^UM96MN96L@96=Y97IN:?QK(&ME;&PN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.3,*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D5M86EL('9I<W-Z86EG87IO;.%S
M<V%L(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B16UA:6PM4TU3(.%T
M:N%R\R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M.3D*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")(86YG=6QA=&EK;VYO:R(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+<<F5S(/QZ96YE="XB"@HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8V,B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(").
M:6YC<R!I;'EE;BXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ
M,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")4]G+V;&K\
M:R!K:2!A(&ME<F5SZ7-E:V5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B16YG961J_&L@;65G
M+"!H;V=Y(&OI<&5K970@:6QL97-S>OQN:R!A('-Z]G9E9V)E(&$@1F]T\V=A
M;.ER:>%K8O-L/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(DQE9WEE;B!J;V)B(&5GZ7)G;VUB8F%L(&5LZ7)H973U+"!K;VYT97AT=7-F
M_&=G]2!M96[\/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DR(&QI8B](
M;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")!
M>B!U=&]L<_,@Z78B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("+!
M=';A;'3A<R!K_&SV;B!A8FQA:W)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z(@IM<V=S='(@(B(*(D%D:F$@;65G(&%Z="!A(&)I>G1O;G/A
M9VD@:^ER9.ES="P@86UE;'ER92!M86ID(';A;&%S>F]L;FEA(&ME;&P@:F5L
M<WIA=N%N86L@(@HBX73A;&SM=.%SX6AO>BP@<&PN("=H;V=Y(&CM=FKA:R!A
M(&MU='GA:N%T/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4B"FUS9W-T<B`B061J82!M96<@82!KZ7`@55),+6KI="!I
M='0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR
M"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`BS7)J
M82!B92!A>B!A;.%B8FD@8F5T^VME=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U
M:6YE82(*;7-G<W1R(")%9WEE;FSM=/5I+4=U:6YE82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R
M96$B"FUS9W-T<B`B17)I=')E82(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS9VED(")%<G)O<B(*
M;7-G<W1R(")(:6)A(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S
M(@IM<V=S='(@(DAI8F$@=/9R=.EN="!A(&)L;VMK(&SI=')E:&]ZX7-A:V]R
M.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<R(*;7-G<W1R(")(:6)A('3V<G3I;G0@87H@861A='-Z:6YK<F]N:7KA8VGS
M<R!J96P@=/9R;.ES96MO<CH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B07H@861A='-Z:6YK<F]N:7KA8VGS
M<R!N87!L\^%L;&]MX6YY('3V<FSI<V4@;F5M('-I:V5R_&QT.B`E<R(*"B,Z
M(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B2&EB82!T
M]G)TZ6YT(&%Z(&%D871L96OI<NES8F5N.B`E<R(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B2&EB82!T]G)TZ6YT
M(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%S86MO<CH@)7,B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")(:6)A(&%Z(&5M86EL(/QZ96YE
M=&)E;BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I
M=&EN9R!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(.%L;&]MX6YY<F$@
M;F5M('-I:V5R_&QT(.UR;FDN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("+)
M<WIT;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I\W!I82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM
M<V=S='(@(DYE;7IE=&ESZ6=E:R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R\W!A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E
M<R(*;7-G<W1R("(Q-2!P97)C96YKZ6YT(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(C(@
M<&5R8V5N:^EN="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD
M<R(*;7-G<W1R("(S,"!MX7-O9'!E<F-E;FOI;G0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("(U('!E<F-E;FOI;G0B"@HC
M.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,
M;V=I;B(*;7-G<W1R(")M:6YD96X@8F5J96QE;G1K97KI<VMO<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R(")FZ6SS<N%N:^EN="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E
M<GD@;6EN=71E(@IM<V=S='(@(G!E<F-E;FOI;G0B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM
M<V=S='(@(E#I;&1A(.ER=.EK96LZ(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(E;I9W)E:&%J=.%S(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R(").>6ES<W5K('-ZZ70B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*
M;7-G<W1R(")*96QE;NUT<_QK(&UE9R!A>B!O;&1A;'/S(&UE;OQT(@H*(SH@
M;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E
M9"`G*2<B"FUS9W-T<B`B271T("<I)R!K96QL96YE(&OV=F5T:V5Z>F5N(@H*
M(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(B(*(DET="!C<W5P87-Z('-Z\VYA:R!V86=Y(&EDZ7KU:F5L8F5N(&QE=O4@
M:V5R97/I<VD@:VEF96IE>NES;F5K(&ME;&QE;F4@;&5N;FEE(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A
M=&4B"FUS9W-T<B`B07H@Z7)VZ6YY97-SZ6<@;&5JX7)A=&$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS
M9W-T<B`B2VET97;U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B
M4WKM;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D94
M4"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B02!K;VYF:6=U<N%C:?,@1E10
M+6X@X70@=F%L\R!F96QT]FQTZ7-E(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q
M;"YP:'`Z,C(U"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RXB"FUS9W-T<B`B02!S>F5MZ6QY97,@8F7A;&SM=.%S;VMA="!N96T@<VEK
M97+\;'0@8F5O;'9A<VYI+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HW-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D%Z($Q$05`@
M<WIE<G9E<B!N96T@Z7)H973U(&5L+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M
M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N(@IM<V=S='(@(D%Z(%--0B!S>F5R=F5R(&YE;2#I<FAE=/4@96PN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I:V5R
M_&QT(&$H>BD@7"(E<UPB+6+U;"!T]G)TZ6[U(&WA<V]LX7,N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A*'HI
M(%PB)7-<(BUB92!T]G)TZ6[U(&WA<V]LX7,N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(/IJ(%-!4TP@
M:V%P8W-O;&%T;W0@;.ET<F5H;WIN:2XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-3`Q(&QI8B]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(").96T@<VEK97+\
M;'0@82AZ*2!<(B5S7"(M8F4@=/9R=.EN]2#A=&AE;'EE>NES+B(*"B,Z(&QI
M8B]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(')E=')I979E.B`E<R(*;7-G<W1R("+!;&QO;>%N>6AO>GKA9NERZ7-I
M(&AI8F$Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B5&ES>G1A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD
M+7-Z:6=E=&5K("A-86QV:6YA<RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM
M<V=S='(@(D9A<F]E+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z
M,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B2&5L>7)E:&]Z:&%T
M871L86X@:&EB83HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A
M>"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&
M96)R=6%R>2(*;7-G<W1R(")F96)R=>%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B2/5MZ7)SZ6ML
M973I<GIE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*
M;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")(]6WI<G/I:VQE=.ER>F5T
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B16=Y+65G>2!ZX7!O<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS
M9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(E-Z\W)VX6YY;W-A;B!H
M\WKA<&]R;VLB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT.`IM<V=I9"`B
M1FEE;&0@;6%T<FEX(@IM<V=S='(@(DUE>O4@;>%T<FEX(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,CD*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S
M='(@(D9I9VQE="!#05!40TA!("AB973[:VER86OS(&AU;>%N=&5S>G0I(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,S,*;7-G:60@(D9I9VQE="!F;VYT
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FED>G-I(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM
M<V=S='(@(D;A:FPB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D$@9N%J;&]K('-Z
MX6UA.B`E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D$@9N%J;&]K('-ZX6UA
M.B`E<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@
M(D9I;&4@36%N86=E<B(*;7-G<W1R(")&X6IL(&UE;F5D>G-E<B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B1N%J;&[I=B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3@Q"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R(")&X6IL(&MI:F5L]FSI<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")&X6IL
M(&9E;'3V;'3I<V4B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`R"FUS
M9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1N%J
M;&]K(&9E;'3V;'3I<V4@;F5M(&QE:&5T<^EG97,N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S='(@(E-Z
M^W+U:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;F]R<WKA9R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS
M9W-T<B`B96QS]2!FZ6PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S
M='(@(F5L<_4@;F5G>65D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(E;A;'1O
M>F%T;&%N(&WI<F5T87+A;GDB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(E3\:W+V>NES
M("AF]FPO;&4I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@
M(D9O9R(*;7-G<W1R(")+]F0B"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C,W(&QI
M8B]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD
M97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B)7,@;6%P<&$@;F5M(&SI
M=&5Z:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D)E=/MS>NUN(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S
M='(@(LET96QE:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H
M870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B3VQY86X@8O9N9^ES
M>O5K('-ZX6WA<F$L(&%M:6L@;F5M(&IE;&5N[71I:R!M96<@82!KZ7!E:V5T
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T
M("A4048I(@IM<V=S='(@(D5L]7)E:F5L>NES("AR97#\;/5TZ7)I*2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B
M"B)!>B!E;/5R96IE;'KI<R!I9/5T87)T86UA(&YA<&]K8F%N("AA>B!E;/5R
M96IE;'KI<R!N87!P86QI(.ES(.EJ<WIA:V%I("(*(F%D871O:V%T('1A<G1A
M;&UA>BP@97KI<G0@82!N86=Y('-ZX6UO:R!S>NEL97,@8FQO:VMO="!E<F5D
M;>EN>65Z;F5K*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R
M"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B16QF96QE
M:G1E='1E(&$@:F5L<WIA=N%T/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(MMR;&%P:V5Z96SI<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*
M;7-G<W1R("))9.EZ970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*
M;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("))9.EZ970@9F%J=.%J82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B263I>F5T96LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B263I>F5T96L@,B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*
M;7-G<W1R(")&\W)U;6]K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5&]VX6)B[73A<V]K(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM
M<V=I9"`B1G(B"FUS9W-T<B`B4.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS
M9W-T<B`B1G)A;64M96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-I
M86]R<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N8VEA;W)S>N%G
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")&<F%N8VEA($=U>6%N
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R86YC:6$@
M4&]L:6[I>FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,B"FUS9W-T<B`B1G)A;F-I82!$Z6QI(%1E<OQL971E:R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM
M<V=S='(@(D9E;&%D\R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B
M"FUS9W-T<B`B27+A;GDZ("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E+I
M<WIL971E<R!L9>URX7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@
M(G1E;&EH;VQD(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M
M92(*;7-G<W1R(")496QJ97,@;NEV(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B
M1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M(@IM<V=S='(@(DUE;'EI:R!G86SI<FGA8O-L('9E9WG\:R!A(&OI
M<&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")+Z7!G
M86SI<FEA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B2&]Z>G5K(&SI
M=')E(&$H>BD@)7,@:V]N9FEG=7+A8VGS:N%T(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E
M(@IM<V=S='(@(D$@:V5L971K97IE='0@:_-D(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*
M;7-G<W1R(")'<OIZ:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(D[I;65T
M;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VCA;F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M:6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=.%R(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B
M2V5R97-Z=&[I=B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@
M(D=L;V+A;&ES(&)EX6QL[73A<V]K(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(DUE:&5T(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B1_9D
M96PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S
M,0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE('3I<FOI<"(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!3
M96%R8V@B"FUS9W-T<B`B1V]O9VQE(&ME<F5SZ7,B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B
M"FUS9W-T<B`B1F5K971E+V9E:.ER(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R
M(")']G+V9V]R<WKA9R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS
M9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B9_9R]F<@*$E33RTX
M.#4Y+3<I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R]FYL86YD(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D-S;W!O<G0@861M:6YI<WIT<N%C:?,B"@HC.B!L:6(O2&]R9&4O1W)O
M=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@
M(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(D$@8W-O
M<&]R=&[I=B!M87)A9&AA="#\<F5S96XB"@HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R(")'<F]U<%]L9&%P.B`E<R!C<V]P;W)T(&AO
M>GKA863A<V$@;F5M('-I:V5R_&QT+B!!('-Z97)V97(@=N%L87-Z83H@(@H*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B`E<R!C<V]P
M;W)T('3V<FSI<V4@;F5M('-I:V5R_&QT(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!A
M9&%T86EN86L@;65G^FKM=.%S82!N96T@<VEK97+\;'0B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S
M(@IM<V=S='(@(D-S;W!O<G1O:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T
M<B`B1W5A9&5L;W5P92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B
M1W5E<FYS97DB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S
M:6]N<R(*;7-G<W1R(")696YDZ6<@:F]G;W-U;'1SX6=O:R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R(")696YDZ6=K]FYY=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN
M96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B0FES<V%U+4=U
M:6YE82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U>6%N82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(&=Y
MX79A<^%G8O-L(&YE;2!H86IL86YD\R!A('-O<B!U=&]L<_,@8V5L;.%JX70@
M=/9R]FQN:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S
M='(@(DA434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A('3A8FSA
M>F%T('5T;VQS\R!O<WIL;W#A="!T]G+V;&YI+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O
M=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M
M(&AA:FQA;F3S(&$@=.%B;.%Z870@=71O;'/S('-O<N%T('3V<O9L;FDN(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B02!(5%10(&9E;&AA
M<WINX6SS87IO;F]S[73A<R!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I
M=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@@86QG
M;W)I=&UU<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DOV9"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3@*;7-G:60@
M(DAE861E<B(*;7-G<W1R(")&96ILZ6,B"@HC.B!L:6(O2&]R9&4O1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")&
M96ILZ6,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R(")(96%R9"T@Z7,@36-$;VYA;&0M<WII9V5T96LB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I
M9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")%<O5S('II=F%T87(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U
M.2TX+4DI(@IM<V=S='(@(FCI8F5R("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM
M<V=I9"`B2&5I9VAT(@IM<V=S='(@(DUA9V%S<^%G(@H*(SH@;&EB+TAO<F1E
M+TAE;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN
M8SHT"FUS9VED(")(96QP(@IM<V=S='(@(E-E9^UT<^EG(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L
M<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B4V5G[71SZ6<@82!S>F5R:V5S>G3U
M(&AA<WINX6QA=.%H;WHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W-0IM
M<V=I9"`B2&5L<&5R(@IM<V=S='(@(E-E9^UT<^EG(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(D;I;'1E
M:V4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")%>B!A(&;A:FP@96QE:F4Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*
M;7-G:60@(DAI9V@B"FUS9W-T<B`B;F%G>2(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI
M;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2V5Z9/5L87`B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")6871I
M:^%N=N%R;W,B"@HC.B!L:6(O2&]R9&4N<&AP.C$U,SD*;7-G:60@(DAO;64B
M"FUS9W-T<B`B2V5Z9/5L87`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D]T=&AO;FD@8^UM
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I
M<F5C=&]R>2(*;7-G<W1R(")3>F5MZ6QY97,@86QK]FYY=G3A<B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE
M(%!H;VYE(@IM<V=S='(@(D]T=&AO;FD@=&5L969O;B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N
M9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*
M;7-G<W1R(")(;VYG:V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!H:6+A<R`E<R!834P@861A
M="!V86X@82AZ*2`E<R#\>F5N971B96XB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(&YI;F-S(&$H>BD@)7,@;V)J96MT=6UN86L@;65G9F5L96SU
M(/QZ96YE="(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N
M:6YC<R`E<R!T[7!U<_H@;V)J96MT=6T@82AZ*2`E<R#\>F5N971B96XB"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<
M(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4VEK97)E<V5N('3V<O9L=/QK(&5Z
M=#H@)7,@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G
M:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!A>B!I;G1E9W+A;/,@<')O9W)A;6AO>B!S>OQK<^EG97,@82`G
M9&]M>&UL)R!02%`@8O5V[73I<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-3$R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!N96T@<VEK97+\;'0@^FH@6$U,(&;A="!LZ71R96AO
M>FYI(&$H>BD@)7,@;V)J96MT=6UH;WHB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@3F5M('-I:V5R_&QT('3V<O9L;FD@)7,M="!<(B5S7"(Z("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B
M.B!N96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&$@34E-12!)1"UJX70@82!K
M]G9E=&ME>O4@=.UP=7/Z("(*(FUE;&SI:VQE=&YE:SH@)7,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@<WII;FMR;VYI
M>N%L;FD@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@HB2&]R9&4O
M2V]L86(Z($YE;2!S:6ME<OQL="!A(&OV=F5T:V5Z]2!K]GKV<R!TX7)T97+\
M;&5T('-Z:6YK<F]N:7KA;.%S83H@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK
M;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&ES;65R
M971L96X@:_9Z]G,@=.%R=&5R_&QE="!<(B5S7"(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N
M=&%L(%)U;&4B"FUS9W-T<B`B5NUZ<WII;G1E<R!V;VYA;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO
M<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")6[7IS>FEN=&5S(&UA<F?S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM
M<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B5NUZ<WII;G1E<SHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I(@IM<V=S='(@(DAO9WD@:G5T;W1T(&ED93\@*$OI<FK\:R#M<FIA(&UE
M9R$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2.%N>2!O<WIL;W!O="!K[7;A;B#V
M<W-Z96]L=F%S>G1A;FD_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/R(*;7-G<W1R(")(X6YY(&UE>O4@*&]S>FQO<"D@=F%N/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*
M;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(DCA;GD@<V]R="!K[7;A;B#V<W-Z96]L=F%S>G1A;FD_(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S-PIM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B4.%R871A
M<G1A;&]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM
M<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")0X7)A=&%R=&%L;VTZ("(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM
M<V=S='(@(DAU;6]R:7-TX6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B
M36%G>6%R;W)S>N%G(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W
M,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R(")!>B!)34%0(&QE=NEL;.%D82!LZ71R96AO>N%S82!N96T@<VEK97+\
M;'0Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q-"!L:6(O
M2&]R9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")!
M>B!)34%0(&QE=NEL;.%D82!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H
M+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D%Z($E-
M05`@;&5VZ6QLX63A:&]Z('1A<G1O>O,@:W;S=&$@;.ET<F5H;WKA<V$@;F5M
M('-I:V5R_&QT.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S(P"FUS
M9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0(&/M;2(*"B,Z(&QI8B](;W)D
M92]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D%Z($E0(&/M;2!N96T@:&%TX7)O>FAA=/,@
M;65G+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED
M("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*
M;7-G<W1R(")!>B!)4"!C[6T@;FEN8W,@82!M96=E;F=E9&5T="!#2412('1A
M<G1O;>%N>6)A;BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R
M(")4:6QT;W1T+VUE9W;A;'1O>F]T="!)4"!C[6TN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED
M("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B4V]R(&)E:6QL97-Z=.ES
M92!E9O9LZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))>FQA;F0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY
M(@IM<V=S='(@(F-S86L@:6MO;F]K(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G
M<W1R("(E<R!I:V]N:F%I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(FEK;VYO:R#I<R!S
M>O9V96<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))
M9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(D%Z(&%Z;VYO<^UT\VAO>B!VX6QA
M<WIT;W1T(&5L;F5V97KI<SHB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D
M:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I
M;F1O=RXB"FUS9W-T<B`B2&$@82!M96=J96QE;NUTZ7,@;F5M(&UE9V9E;&5L
M]2P@)7,@96=Y(/IJ(&%B;&%K8F%N('9A;/,@;65G;GEI=.%S:&]Z+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D
M;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y
M;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB2&$@UFX@26YT97)N970@
M17AP;&]R97)T(&AA<WINX6PL(.ES(&YE;2!J96QE;FYE:R!M96<@87H@:6MO
M;F]K+"!A:VMO<B`B"B)VX6QA<W-Z82!E>G0@87H@;W!C:?-T+"!M96QL>65L
M(&MI:V%P8W-O;&IA(&$@4$Y'(&OI<&5K('1R86YS>G!A<F5N8VGA:N%T+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G
M:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@
M=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P
M;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)(82!LX71J82!E
M>G0@82!S>O9V96=E="P@9&4@82!KZ7!E="!N96TL(&%K:V]R(&+V;F?I<WKU
M<')O9W)A;6IA(&YE;2!KZ7!E<R`B"B)M96=J96QE;NUT96YI(&$@<WIE<G9E
M<G)E(&O\;&1E;F3U(&OI<&5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@
M4')E=FEE=SHB"FUS9W-T<B`B16SU>F5T97,@;NEZ970Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I
M9"`B26UA9V4@55),(@IM<V=S='(@(D$@:^EP(%523"UJ92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")!(&OI<"!54DPM:F4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B
M365L>6EK(&=A;.ER:>%B\VP@=F%N(&$@:^EP(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(DOI<"!E8F+U;"!A(&=A
M;.ER:>%B\VPZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*;7-G:60@
M(DEM86=E('5P;&]A9"(*;7-G<W1R(")+Z7`@9F5L=/9L=.ES92(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B
M2^EP96LB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O
M<G3A;.%S+"`E9"X@;.EPZ7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@
M)7,B"FUS9W-T<B`B07H@:6UP;W)TX6QT(&UE>O4Z("5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S
M.B(*;7-G<W1R(")!>B!I;7!O<G3A;'0@;65Z]6LZ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED
M("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")3;W(@8F5I;&QE<WITZ7-E
M(&5Z86SA(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(DAI
M8N%S('!A<F%N8W-P87)A;>ET97(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F5M(&UE9V9E;&5L]2!A(&)E:F5L
M96YT:V5ZZ7-I(&[I=B#I<R]V86=Y(&$@:F5L<WKS+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E
M<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N(@IM<V=S='(@(B(*(DYE;2!M96=F96QE;/4@82!F96QH87-Z;N%L
M\VD@;NEV('9A9WD@87H@86QT97)N873M=B!C[6TN(%!R\V+A;&IA(/IJ<F$@
M=F%G>2`B"B)F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+"!H82!T;W;A
M8F)I('-E9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E
M($EN9&5N="(*;7-G<W1R(")"96ME>F3I<R!B96QJ96)B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M;F1I82(*;7-G<W1R("));F1I82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("))
M;F1I=FED=6%L(%5S97)S(@IM<V=S='(@(D5G>65S(&9E;&AA<WINX6SS:R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]NZ7II82(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O
M(@IM<V=S='(@(DEN9F]R;>%C:?,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FWA
M8VGS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I
M9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B
M07H@:6YF;W)MX6-I\R!MX7(@;F5M(.%L;"!R96YD96QK97KI<W)E+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B3W-Z
M;&]P(&)E<WKZ<N%S82!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R
M="!);6%G92(*;7-G<W1R(")+Z7`@8F5I;&QE<WITZ7-E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS
M97)T(%1A8FQE(@IM<V=S='(@(E3A8FSA>F%T(&)E:6QL97-Z=.ES92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("),:6YK(&SI=')E:&]ZX7-A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T
M<B`B3W-Z;&]P(&)E<WKZ<N%S82!E>F5LZ2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R(")/<WIL;W`@8F5S>OIRX7-A(&5Z96SI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M(")3;W(@8F5S>OIRX7-A(&5Z86SA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4V]R
M(&)E<WKZ<N%S82!E9O9LZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B0F5K97ID
MZ7,@8F5I;&QE<WITZ7-E(&5Z=73A;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T
M(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@
M(D)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>F5LZ2(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(DAO>GIU;FL@;.ET<F4@86QT97)N873M=B!S86)L;VYT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z(@IM<V=S='(@(D%D:F]N(&UE9R!E9WD@96UA:6P@8^UM
M970L(&UE;'ER92!E;&O\;&1H973U(&%Z(-9N(/IJ(&IE;'-Z879A.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(D-E;&QA(&)E
M:6QL97-Z=.ES92!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B
M969O<F4B"FUS9W-T<B`B0V5L;&$@8F5I;&QE<WITZ7-E(&5Z96SI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")/<WIL;W`@
M8F5S>OIRX7-A(&5Z=73A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@
M8F5F;W)E(@IM<V=S='(@(D]S>FQO<"!B97-Z^G+A<V$@97IE;.DB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B
M"FUS9W-T<B`B3&5V96QE:R!B96WA<V]LX7-A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(D)E:V5Z9.ES(&)E:6QL
M97-Z=.ES92!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(D)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>F5L
MZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B4V]R
M(&)E<WKZ<N%S82!E>F%LX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F
M;W)E(@IM<V=S='(@(E-O<B!B97-Z^G+A<V$@96;V;.DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D
M(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(D%D
M:F$@;65G(&$@:^UVX6YT(';A;&%S>G0@82!B:7IT;VYSX6=I(&OI<F3I<W)E
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B2^EP(&)E
M:6QL97-Z=.ES92]M\V1O<^UTX7-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,
M:6YK(@IM<V=S='(@(DQI;FL@8F5I;&QE<WITZ7-E+VWS9&]S[73A<V$B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(")!('-ZX6ULX6KA;B!N:6YC<R!E;.EG(&9E9&5Z
M970@_'IE;F5T970@:_QL9&5N:2!A(&OV<FQE=NEL;&ES=.%R82XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")!('-ZX6ULX6KA;B!N:6YC<R!E
M;.EG(&9E9&5Z970N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-SD*;7-G
M:60@(DEN=&5G97(B"FUS9W-T<B`B16?I<WHB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(D5GZ7-Z
M('-ZX6UO:R!L:7-TX6IA(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!51$@@*%5S
M97(@1&%T82!(96%D97(I+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N
M<&AP.C$V-R!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)
M4"!D871A(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!:25`@=/9M
M]G+M=.ES(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B
M26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA
M=&%T;&%N(&%L:V%L;6%ZX7,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S
M='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!B871C:"!A>F]N;W/M=/,N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.3$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S8*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S,#,@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(D$@
M:_QL9/9T="!A9&%T(&AI8N%S+V5L9F]G861H871A=&QA;BXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D
M:&%T871L86X@8^UM>NES+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N
M<&AP.C$P.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I
M;&4@9F]R;6%T(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!FX6IL
M(&9O<FWA='5M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B2&EBX7,O
M96QF;V=A9&AA=&%T;&%N(&QI8V5N<WIK=6QC<RXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@=N%R
M;W,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*
M;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(DAI8N%S+V5L9F]G
M861H871A=&QA;B#\>F5N971T[7!U<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M(&%P:5]I9"XB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N('9A9WD@
M:&GA;GEZ\R!P<F]G<F%M;WKA<VEF96S\;&5T+6%Z;VYO<^UT\RXB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(DAI8N%S+V5L
M9F]G861H871A=&QA;B!P87)A;>ET97)E:RXB"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(DAI8N%S(&%Z(&]B:F5K='5M(&5LZ7+I<VD@:F]G;W-U
M;'1SX6=A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*
M;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B2&EBX7,O96QF
M;V=A9&AA=&%T;&%N('!A<G1N97)A>F]N;W/M=/,N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T
M(&-O9&4N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!T97)MZ6MK
M\V0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*
M;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(DAI8N%S+V5L9F]G
M861H871A=&QA;B!P<F]T;VMO;&PN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW,0HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(")(:6+A
M<R]E;&9O9V%D:&%T871L86X@8^UM>F5T=#H@7"(E<UPB(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,#@P(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(V,PIM
M<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B2&EBX7,O96QF
M;V=A9&AA=&%T;&%N(&UE9V]S>G1O='0@;V)J96MT=6TB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S
M;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N
M(&9E;&%D\VD@8^UM+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T
M<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N('5N:6-O9&4@861A="XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB
M"FUS9W-T<B`B3GEI;';A;G1A<G3A<R(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB
M"FUS9W-T<B`B02!K:6IE;/9LZ7,@:6YV97)TX6SA<V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27+A;FD@27-Z;.%M
M($OV>G3A<G-A<^%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER86LB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DER96QA;F0B"FUS9W-T<B`BS7)O<G-ZX6<B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R
M(")-86XM<WII9V5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@
M(E-Z\W)VX6YY;W,@>FEV871A<F]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T
M<B`B27IR865L(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*
M;7-G:60@(DES<W5E<B(*;7-G<W1R(")!('1A;OIS[71VX6YY(&MI863S:F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*
M;7-G:60@(DET86QI8R(*;7-G<W1R(")D]6QT(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*
M;7-G<W1R(")/;&%S>F]R<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R
M(")*86UA:6-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*
M;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B:F%N=>%R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A
M;B(*;7-G<W1R(")*87#A;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP
M"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(FIA<.%N
M("A)4T\M,C`R,BU*4"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R
M"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D
M86XB"FUS9W-T<B`B2F]R9.%N:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")J^FQI=7,B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G
M<W1R(")J^FYI=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(E-O
M<FMI>N%RX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T
M<B`B:_9ZZ7!R92!R96YD97KI<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U
M;&PB"FUS9W-T<B`B<V]R:VEZX7+A<R!M:6YD:^ET(&]L9&%L<F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(G-O<FMI>N%RX7,@8F%L
M<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")S;W)K
M:7KA<N%S(&IO8F)R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+
M87IA:'-Z=.%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B5&%R='-U
M:R!M96<@87H@97)E9&5T:70_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+
M96YY82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(D$@:V5R8F5R;W,@<WIE<G9E<B!E;'5T87/M=&]T=&$@82!F96QH87-Z
M;N%L\V%Z;VYO<^UTX7-T+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5Z9/4@:V5R;F5L
M9F5J;&5S>G3U:R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM
M<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(DMU;&-S(&SI=')E:&]ZX7-A
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@
M1FEN9V5R<')I;G0B"FUS9W-T<B`B02!K=6QC<R!L96YY;VUA=&$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B2W5L8W-H;W-S>OISX6<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(DMU;&-S('3M
M<'5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@
M(DME>2!5<V%G92(*;7-G<W1R(")!(&MU;&-S(&AA<WINX6QA=&$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B02!K
M=6QC<R!MX7(@;.ET97II:R!A(&YY:6QVX6YO<R!K=6QC<W-Z97)V97)E;BXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS
M9W-T<B`B1WEE<F5K96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI
M<FEB871I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!2
M97!U8FQI8R!O9B(*;7-G<W1R(")+;W)E86D@3NEP:2!$96UO:W)A=&EK=7,@
M2_9Z=.%R<V%SX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G
M<W1R(")+;W)E86D@2_9Z=.%R<V%SX6<B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(FMO<F5A
M:2`H155#+4M2*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=F%I="(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:7II<WITX6XB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B
M"FUS9W-T<B`B7U1E<G9E>NES(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B3GEE;'8B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@
M(DQA;W-Z:2!.Z7!I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R
M(")U=&]L<_,@9NEL(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")!>B!U=&]L<_,@
M:F5L<WKS=N%L=.%S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]"
M;&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@
M(G5T;VQS\R!N96=Y960B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM
M<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")5=&]L<_,@=N%L=&]Z=&%T
MX7,Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")5=&]L<_,@8F5J96QE
M;G1K97KI<SH@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T
M<B`B571O;'/S(&)E:F5L96YT:V5ZZ7,Z("5S+"`E<R!C[6UR]6PB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E
M<B(*;7-G<W1R(")5=&]L<_,@8F5J96QE;G1K97KI<SH@;>EG('-O:&$@;F5M
M('9O;'0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),971T;W)S>N%G(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T
M<B`B2F]G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B16QH96QY97KI
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B
M2&%G>6IA(/QR97-E;BP@:&$@;F5M(&%K87(@:V5R971E="(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM
M<V=S='(@(F)A;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`U"FUS9VED
M("),969T(&AE861E<B(*;7-G<W1R(")"86P@;VQD86QI(&9E:FSI8R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,3`Q"FUS9VED("),969T('9A;'5E<R(*
M;7-G<W1R(")"86P@;VQD86QI(.ER=.EK96LB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B
M"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B4WII;G0B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQI8F5R:6$B"FUS9W-T<B`B3&EBZ7)I82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R
M86(@2F%M86AI<FEY82(*;7-G<W1R("),[6)I86D@07)A8B!3>F]C:6%L:7-T
M82!.86=Y($[I<&D@2_9Z]G-SZ6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB
M"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM
M<V=S='(@(D=Y96YG92!S>FETX6SS(&5S]2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM
M<V=S='(@(D=Y96YG92!E<_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G
M<W1R(")$Z6QE;/5T="!G>65N9V4@97/U(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T
M92(*;7-G<W1R(")$Z6QU=.%N+V5S=&4@9WEE;F=E(&5S]2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H
M="!286EN(%-H;W=E<B(*;7-G<W1R(")'>65N9V4@>N%P;W(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG
M:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B1WEE;F=E('II=F%T87(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM
M<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(")'>65N9V4@:&%V87KA<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED
M("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(")'>65N9V4@:/-ZX7!O<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,3@*;7-G:60@
M(DQI;FLB"FUS9W-T<B`B3&EN:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN
M=',@=&\Z(@IM<V=S='(@(D$@;&EN:R!I9&4@;75T870Z(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T
M<B`B365G:F5L96[M=.ES:V]R(&UU=&%S<V]N(&5G>2!L:6YK(&$@;&5VZ6QC
M[6UR]6P@82!L97;I;.UR\R!A8FQA:VAO>B(*"B,Z(&QI8B](;W)D92]497AT
M+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T
M<B`B3&EN:V5K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED
M("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F
M;VQD97(B"FUS9W-T<B`B3&ES=.%ZX7,@+2!A(&9E;&AA<WINX6SS(&SA=&IA
M(&$@;6%P<.%T(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B
M3&ES="!$871A8F%S97,B"FUS9W-T<B`B07H@861A=&+A>FES;VL@;&ES=.%J
M82(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T
M($AE;'`@5&]P:6-S(@IM<V=S='(@(D%Z;VMN86L@82!TZ6WA:VYA:R!A(&QI
M<W3A:F$@86UI<O5L('-E9^UT<^EG(&MA<&AA=/,B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")!>B!A
M9&%T=.%B;.%K(&QI<W3A:F$B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T82!A
M<F-H[79U;2(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4X.0IM
M<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1A('-E9^UT<^EG:^ERZ7,B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI
M<W0M260B"FUS9W-T<B`B3&ES=&$@87IO;F]S[73S(@H*(SH@;&EB+TAO<F1E
M+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(DQI<W1A('1U;&%J9&]N;W,B"@HC.B!L:6(O2&]R9&4O34E-12](96%D
M97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:7-T82!L
M97;I;.URX7,B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3$*
M;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W1A(&9E;&ER871K
M;WKA<R`H<W5B<V-R:6)E*2(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("),:7-T
M82!L96ER871K;WKA<R`H=6YS=6)S8W)I8F4I(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO
M;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")!(&9E;&AA<WINX6SS:V%P8W-O;&%T
M;VL@:VEL:7-TX7KA<V$@;F5M('-I:V5R_&QT.B`E<R(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S
M97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!F96QH87-Z;N%L\VL@:VEL:7-T
MX7KA<V$@;F5M('-I:V5R_&QT.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B02!F96QH87-Z;N%L\VL@:VEL:7-TX7KA<V$@=&EL
M='9A('9A;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@
M(DQI=&5R871U<F4B"FUS9W-T<B`B27)O9&%L;VTB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU
M86YI82(*;7-G<W1R("),:71VX6YI82(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@
M(DQE=/9L=.ES+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(DAE;'EI(&ED]3H@
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@
M86YD(%1I;64B"FUS9W-T<B`B3GEE;'8L(&3A='5M+"!I9/4B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DAE
M;'DB"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B0F5J96QE;G1K97KI
M<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R(")!>B!E;/5Z
M]2!A9&%T<WII;FMR;VYI>N%C:?,@;F%P;//A;&QO;>%N>6$B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM
M<V=S='(@(DMI:F5L96YT:V5ZZ7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K
M<R(*;7-G<W1R(")"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA=&]S(&9E;&%D
M871O:R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(D$@8F5J96QE;G1K
M97KI<R!N96T@<VEK97+\;'0L(&UE<G0@<F]S<WH@9F5L:&%S>F[A;/-N979E
M="!V86=Y(&IE;'-Z\W0@861O='0@(@HB;65G+B(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B02!B
M96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DAO<W-Z^B!S
M>O9V96<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO
M=F4B"FUS9W-T<B`B4WIE<F5L96TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM<V=S='(@(F%L86-S
M;VYY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G
M<W1R(")G]G+V9R!K:7-B973[:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B;&%T:6X@:VES8F5T^VLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W
M"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(FMI<V)E=/MS
M('+S;6%I('-ZX6UO:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),
M=7AE;6)U<F<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]4
M1"(*;7-G<W1R(").87!I(/QZ96YE=&5K(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@
M8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D%Z($U3+51.148@;65L;.EK
M;&5T8F5N(&YI;F-S(&%D870N(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B
MW%I%3D54(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86MA\R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I
M9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DUA:V5D\VYI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G
M<W1R(")-861A9V%S>FOA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B5F%RX7IS;&%T(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@(DQE
M=F5L97KI<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G
M:60@(DUA:6P@061M:6XB"FUS9W-T<B`B16UA:6P@9&]M86EN(&ME>F5LZ7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B3&EN:R!K
MZ7-Z[73I<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=VDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&%J>FEA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QD:79E<R(*;7-G<W1R(")-86QD[78M<WII9V5T96LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA
M;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B3>%L
M=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H
M;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(D%D871A:70@:V%T96?S<FGA
M:V)A('-O<F]L:&%T:F$N($5Z96L@:71T(&1E9FEN:>%L:&%T\VLL(&WS9&]S
M[71H873S:RP@(@HB=&]VX6)BX2!S>NUN96L@<F5N9&5L:&5T]6L@:&]Z>N%J
M=6LN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87`R-"!TZ7)KZ7`B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T('3I<FOI<"(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@
M<W1O<F5D+B(*;7-G<W1R(")!(&AO>GKA<F5N9&5LZ7-E:V5T(&5L;65N=&5T
M=/QK+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED
M(")-87)C:"(*;7-G<W1R(")MX7)C:75S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(DUA<F?S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S
M,30N<&AP.C0X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM
M<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(D%Z
M($]L=F%S;W1T+T]L=F%S871L86X@:F5L>F5T96L@:&%S>F[A;&%T82(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT.2!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DWA
M<R!J96QZ971E:R`H<&PN($9O;G1O<R]-96=VX6QA<WIO;'0I(&AA<WINX6QA
M=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R<VAA
M;&PM<WII9V5T96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R
M=&EN:7%U92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS
M9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B16=Y;>%S;F%K(&UE9V9E
M;&5L]2!M97KU:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R
M:73A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET:75S
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G
M:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%X:6WA;&ES(')E
M;F1E;&ME>NES<F4@X6QL\R!S>N%M;&'V<W-Z96<N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E
M('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")!>B#\>F5N970@=/IL('-O:R!R
MZ7-Z8O5L(.%L;"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(D%Z(&5L;?IL
M="`R-"#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK;&5T93H@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(D%Z(&5L;?IL="`V(/-R82!M87AI;>%L:7,@:/5MZ7)S
MZ6ML971E.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.
M=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")!>B#V<W-Z96?U;VQD
M86P@8FQO:VMJ86EN86L@;6%X:6WA;&ES('-ZX6UA(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B36%X:6WA;&ES(&AO<W-Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")MX6IU<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B3W)V;W-T=61O
M;>%N>2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B5&%G;VLB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(D$@
M;65N_"!M96=J96QE;NES93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*
M;7-G<W1R(")#96QLX6L@96=Y8F5O;'9A<WITX7-A(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G
M<W1R("+<>F5N970B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q
M-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R
M:69I960N(@IM<V=S='(@(B(*(D$@9&EG:73A;&ES86X@86SA[7)T(/QZ96YE
M="!H:71E;&5S+"!D92!A>B!A;.'M<O,@=&%N^G/M=';A;GGA="!N96T@<VEK
M97+\;'0@(@HB96QL96[U<FEZ;FDN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS
M9W-T<B`B3&5JX7)T(&%Z(/QZ96YE="#I<G;I;GEE<W/I9V4N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B07H@_'IE;F5T
M('3M<'5S82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T
M87(@5V5A=&AE<B(*;7-G<W1R(")-971A<B!I9/5JX7+A<VIE;&5N=.ES(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B02!-971A<B!B;&]K:R!N96T@X6QL
M(')E;F1E;&ME>NES<F4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*
M;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(D$@365T87(@8FQO:VL@;F5M(.%L;"!R96YD96QK97KI<W)E+B!!
M('+I<WIL971E:R!A(')E;F1S>F5R9V%Z9&$@<WKA;>%R82`B"B)KZ7-Z_&SU
M(&YA<&SS9N%J;&)A(&ME<OQL=&5K+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"XB"FUS9W-T<B`B02!-971A<D1"(&YE;2#I<FAE=/4@96PN(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-\V1S
M>F5R(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q(&QI8B](;W)D
M92]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO
M9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B02AZ*2!<(B5S7"(@
M;?-D<WIE<B!D969I;FGA;&%T;&%N(@H*(SH@;&EB+TAO<F1E+U)00R]R97-T
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN
M960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(D$@;?-D<WIE<B!D969I
M;FGA;&%T;&%N+B!!(&UE9VCM=F]T="!M\V1S>F5R.B`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP
M.C@R"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FEK=7,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUE>&EC;R(*;7-G<W1R(")-97AI:_,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;V[I>FEA:2!3>O9V
M971SZ6=I(,%L;&%M;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")K
M]GKI<"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DU)344@=.UP=7,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(D%Z(&5L;?IL="`R-"#S<F$@;&5G86QA8W-O;GEA
M8F(@:/5MZ7)SZ6ML971E.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M.0IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B07H@
M96QM^FQT(#8@\W)A(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T93H@(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M
M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(DWI
M9R!N96T@=&5L="!E;"!A(&UI;FEMX6QI<R!I9/4@82!J96QS>O,@;65G=N%L
M=&]Z=&%TX7/A:&]Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(E3\:W+V>NES("AJ
M;V)B+V)A;"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B5F5G>65S(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T,`HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M(@IM<V=S='(@(DAIX6YY>FEK(&$@2%144%]297%U97-T(%!%05(@8W-O;6%G
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI
M<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@
M;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*
M;7-G<W1R("(B"B)+;VYF:6=U<N%C:?,@<WK\:W/I9V5S+B!%>G0@;6]S="!K
M96QL(&SI=')E:&]Z;FEA+"!H82!H87-Z;N%L;FD@86MA<FIA(&%Z("(*(F%L
M:V%L;6%ZX7-T+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(DAI
MX6YY>FEK(&%Z(/QZ96YE="!A>F]N;W/M=/-J82XB"@HC.B!L:6(O3F5T+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")(:>%N>7II:R!A
M($UA:6P@4$5!4B!C<V]M86<N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS
M9W-T<B`B2&GA;GEZ:6L@82!F96QH87-Z;N%L\VMA<&-S;VQA="!A>F]N;W/M
M=/-J82`H<V5S<VEO;B!)1"DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B2.DB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-
M86EL(@IM<V=S='(@(DQE=F5L97KI<R!M;V)I;'1E;&5F;VYR\VPB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B
M36]D97)A=&4B"FUS9W-T<B`B2_9Z97!E<R(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS
M9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(D$@;?-D;W/M=.%S(&3A='5M
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")!>B!54DP@
M;?-D;W/M=.%S82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<T
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L=7,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=F%I($OV>G3A<G-A
M<^%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86-O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-;VYG;VQI82(*;7-G<W1R(")-;VYG\VQI82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-3@X"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")(
M\VYA<"#I<R#I=B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3<*
M;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B:&%V;VYT82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N
M='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H
M87-E<R(*;7-G<W1R(")(;VQD9N%Z:7-O:R(*"B,Z(&QI8B]&:6QE+T-35BYP
M:'`Z,3DV(&QI8B]&:6QE+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N(@IM<V=S='(@(D$@)60N('-O<F)A;B!T]F)B(&UE>O4@=F]L
M="P@;6EN="!A(';A<G0@)60N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@
M(DUA<F]K:_,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(E3V8F)N>6ER
M92!D97+\;'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")4]F)B;GEI
M<F4@8F]R=6QT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")4]F)B;GEI
M<F4@;F%P;W,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(G9I9WG\:R!L92(*
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS
M9VED(")-;W9E($QE9G0B"FUS9W-T<B`B=FEG>?QK(&)A;')A(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO
M=F4@4FEG:'0B"FUS9W-T<B`B=FEG>?QK(&IO8F)R82(*"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P
M(@IM<V=S='(@(G9I9WG\:R!F]FPB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B
M=FEG>?QK(&QE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V
M"FUS9VED(")-;W9E('5P(@IM<V=S='(@(G9I9WG\:R!F]FPB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:6LB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI
M<W1S(@IM<V=S='(@(E3V8F)S>FEN=/L@;&5G]G)D_&SU(&QI<W3A:R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4X"FUS9VED
M(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B375L=&EM87`@3F%G>2U"<FET
M86YN:6$@=.ER:^EP(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8*;7-G
M:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")4]F)B<WKV<O9S(';A
M;&%S>G3A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G
M:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B0F5J96QE;G1K97KI<VD@8F7A;&SM
M=.%S;VLB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY
M($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B0F5J96QE;G1K97KI<VD@
M861A=&%I;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#4*;7-G
M:60@(DUY(%!O<G1A;"(*;7-G<W1R(")386KA="#V<W-Z96=Z]2!O;&1A;&%M
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED(")->2!0
M;W)T86P@3&%Y;W5T(@IM<V=S='(@(E-A:N%T(/9S<WIE9WKU(&]L9&%L86T@
M=&5R=F5ZZ7-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUI86YM87(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY%32P@;F5M
M(&5G>65Z96T@8F5L92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM
M<V=S='(@(D[I=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86WM8FEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P
M86PB"FUS9W-T<B`B3F5PX6PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S
M='(@(DAO;&QA;F1I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*
M;7-G<W1R(")(;VQL86YD($%N=&EL;.%K(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S
M='(@(DYE='-C87!E(&+A>FES+5523"(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%52
M3"(*;7-G<W1R(").971S8V%P92!T86[Z<^UT=N%N>6MI863A<VEJ;V<H0T$I
M+79I<W-Z879O;N%S:2!54DPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R
M(").971S8V%P92!T86[Z<^UT=N%N>69E;&AA<WINX6SA<VD@:7+A;GEE;'8@
M55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@
M(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E('1A;OIS
M[71VX6YY;65G^FKM=.%S:2!54DPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS
M9W-T<B`B3F5T<V-A<&4@=&%N^G/M=';A;GEV:7-S>F%V;V[A<VD@55),(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C
M87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").971S8V%P92!34TP@<WIE
M<G9E<F[I=B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@X"FUS
M9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(DYE
M='-C87!E('1A;OIS[71VX6YY(&UE9VIE9WEZZ7,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@='EP92(*;7-G<W1R(").971S8V%P92!T86[Z<^UT=N%N>73M<'5S(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R
M:R(*;7-G<W1R(")(X6SS>F%T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B<V]H82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("+::BU+86QE9/-N:6$B
M"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(MIJ(&MA=&5G\W)I82(*"B,Z
M(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D
M92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D92]497AT
M+T9I;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I;'1E<B]E
M;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G
M92!T;R`E<R(*;7-G<W1R("+::B!L97;I;"`E<R!C[6UR92(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B^FIH
M;VQD(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM
M<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`BVFH@9F5L
M:&%S>F[A;/-NZ78@*&]P8VEO;N%L:7,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N
M9"(*;7-G<W1R("+::BU:Z6QA;F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+::B!J
M96QS>O,B"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N
M(@IM<V=S='(@(D%Z(/IJ(&IE;'-Z\R#I<G;I;GEE<W/I9V4@96MK;W(@:N%R
M(&QE.B`E>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*
M;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(D$@
M;65G861O='0@^FH@:F5L<WIA=F%K(&YE;2!E9WEE>FYE:RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").
M97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(MIJ(&%B;&%K("C\<F5S*2(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED
M(").97=S(@IM<V=S='(@(DCM<F5K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")([7)C<V]P
M;W)T;VLB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM
M<V=I9"`B3F5X="(*;7-G<W1R(")+]G9E=&ME>O4B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B2_9V
M971K97KU(#0@9N%Z:7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V
M-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I
M;VYS(@IM<V=S='(@(DOV=F5T:V5Z]2!O<&-I\VLB"@HC.B!L:6(O2&]R9&4O
M54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B2_9V971K
M97KU/B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M:6$B"FUS9W-T<B`B3FEGZ7)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(NEJ<WIA:V$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(DYE
M;2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I
M9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@HB3FEN8W,@<F5N9&5L:V5ZZ7-R
M92#A;&SS(&MO;F9I9W5RX6-I\RP@86UI:&5Z(&OI<&5S="!A(&O\;/9N8G/I
M9V5K970@;65G("(*(FQE:&5T;F4@;75T871N:2XB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").:6YC<R!L96AE=/5S
MZ6<@25-/(.%L;&]MX6YY;VL@;.ET<F5H;WKA<^%R82XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@
M=&5M<&QA=&4N(@IM<V=S='(@(DAIX6YY>FEK(&$@:_9T96=E;'0@9F5L9&]L
M9V]ZX7-H;WH@<WK\:W/I9V5S(&UI;G1A("AB871C:"!T96UP;&%T92DN(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S
M='(@(D$@:^UVX6YT(&AE;'EE;B!N:6YC<R!B;&]K:R(*"B,Z(&QI8B](;W)D
M92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!>B!-
M0T%,(&9E;&AA<WINX6SS87IO;F]S[73A<VAO>B!N:6YC<R!M96=A9'9A(&$@
M;F%P=.%R(&YE=F4N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G
M:60@(DYO(&-H86YG92XB"FUS9W-T<B`B3FEN8W,@=N%L=&]ZX7,N(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(D5H
M:&5Z(&$@:F]G;W-U;'1SX6=H;WH@;F5M(&AO>FAA=/,@;.ET<F4@:F]G;W-U
M;'1SX6=I(&%L8W-O<&]R="XB"@HC.B!L:6(O2&]R9&4N<&AP.C$V.2!L:6(O
M2&]R9&4N<&AP.C4P."!L:6(O2&]R9&4O571I;"YP:'`Z-S8X"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B2&GA;GEO>FYA:R!A(&MO;F9I9W5R
MX6-I\W,@861A=&]K("5S+6AE>BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#4U
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B07H@1E10(%9&4R!N:6YC<R!K;VYF
M:6=U<N%L=F$N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8W,@IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!6
M1E,N(@IM<V=S='(@(D%Z(%-13"!61E,@;FEN8W,@:V]N9FEG=7+A;'9A+B(*
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RXB"FUS9W-T<B`B07H@4U%,+49I;&4@5D93(&YI;F-S(&MO;F9I9W5RX6QV
M82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM
M<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(D%Z(-9N('-ZX6ULX6KA
M;B!E;&9O9WEO='0@82!R96YD96QK97KI<W)E(.%L;/,@]G-S>F5G+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").:6YC<R!C[6UZZ7,N
M(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR,`IM<V=I9"`B3F\@9FEL
M92!U<&QO861E9"(*;7-G<W1R(")!('-Z97)V97)R92!N96T@=/9L=/5D]G1T
M(&9E;"!S96UM:6QY96X@X6QL;VWA;GDB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(")!>B!I
M:V]N;VL@;F5M('1A;.%L:&%T\VLN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,S`*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E
M="XB"FUS9W-T<B`B3FEN8W,@;65G861V82!A(&AE;'DN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(DYI;F-S(&UE9V%D=F$@82!H96QY+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO
M(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(D%Z(/QZ96YE="#\<F5S+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@
M(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").:6YC<R!M96=A9'9A(&$@
M;NEV+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*
M;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYI;F-S(&UE
M9V%D=F$@82!S>N%M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM
M<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYE(&QE9WEE
M;B!M96=B;W1RX6YK;WIT873S(&EDZ7IE="(*"B,Z(&QI8B](;W)D92]!=71H
M+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@:F5L<WKS(&UE
M9V%D=F$@82!(5%10(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DYI;F-S(&IE;'-Z\R!M96=A9'9A(&%Z($E-05`@86QA</H@9F5L
M:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@:F5L<WKS
M(&UE9V%D=F$@82!+97)B97)O<R!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S
M[73A<VAO>BXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-R!L:6(O
M2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M
M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").:6YC<R!J96QS>O,@;65G861V
M82!A($QO9VEN(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+B(*
M"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(").:6YC<R!J96QS>O,@;65G861V82!A(%!!4U-71"!A;&%P^B!F
M96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BXB"@HC.B!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").:6YC<R!J96QS>O,@;65G
M861V82!A>B!334(@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B
M"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE
M($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@
M4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B).:6YC<R!M96=A9'9A(&%Z($]P
M96Y34TP@<')O9W)A;2!E;.ERZ7-I(/IT=F]N86QA+B!!>B!/<&5N4U-,('!R
M;V=R86T@(@HB<WK\:W/I9V5S(&$@4$M#4R`Q,B!A9&%T;VL@:V5Z96SI<^EH
M97HN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM
M<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").:6YC<R#Z:B!B
M96IE;&5N=&ME>NES:2!I9^EN>2XB"@HC.B!L:6(O5D93+G!H<#HW-C8*;7-G
M:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B3FEN8W,@:W;S=&$@8F7A;&SM
M='9A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DYE(&QE9WEE
M;F5K('9O;F%L86L@<V5H;VPN(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#(*
M;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DYI;F-S
M(&1E9FEN:>%L=F$@96QVX6QA<WIT\R!K87)A:W1E<BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED
M(").;R!S:61E<R(*;7-G<W1R(").92!L96=Y96X@:V5R970B"@HC.B!L:6(O
M5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B
M3FEN8W,@:6QY96X@9N%J;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B3FEN8W,@:61E:6=L96YE<R#A;&QO
M;>%N>6]K('3A<F]LX7/A<F$@<WIO;&?A;/,@86QK]FYY=G3A<BXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+B(*;7-G<W1R(")(:>%N>7II:R!A(&9E;&AA<WINX6SS
M;NEV(.ES+W9A9WD@82!J96QS>O,N(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR
M<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B
M"FUS9W-T<B`B02!V:7-S>F%K87!O='0@861A=&]K(&YE;2#I<G;I;GEE<R!8
M34P@861A=&]K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDW-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@
M(DYO('9A;'5E<R(*;7-G<W1R(").:6YC<R!A9&%T(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O
M<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(DYI;F-S(&WI9R!K;VYF:6=U<N%C:?,L(&=E;F5RX6QJ
M;VX@96=Y970N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3FEN8W,@;>EG(&MO
M;F9I9W5RX6-I\VIA+"!G96YE<N%L:F]N(&5G>65T+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B;FEN8W,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP
M"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(FYI;F-S(&UE
M9V%D=F$@*&QE9WEE;B!A;&%PZ7)T96QM97IE='0I(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM
M<V=S='(@(FYO<F1I:W5S("A)4T\M.#@U.2TQ,"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O
M;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&LM<WII9V5T(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B
M3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("+)<WIA:VD@9NEL=&5K92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(LES
M>F%K:2U-87)I86YA+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T
M<B`B3F]R=NEG:6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T
M,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DYE;2!KZ7/U8F(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R
M92(*;7-G<W1R(").96T@:V]RX6)B86XB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C0Q-0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DYE;2!A;&OV
M;GEV=.%R(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED
M(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(D$@<')O9W)A;6YA:R!E>B!A
M('+I<WIE(&WI9R!N:6YC<R!M96=V86SS<^UT=F$N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E
M="(*;7-G<W1R(").:6YC<R!B9>%L;.UT=F$B"@HC.B!L:6(O5D93+G!H<#HQ
M.3,@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N<&AP.C(S-"!L:6(O5D93+G!H
M<#HR-3(*(SH@;&EB+U9&4RYP:'`Z,C8Y(&QI8B]61E,N<&AP.C(X-2!L:6(O
M5D93+G!H<#HS,#$@;&EB+U9&4RYP:'`Z,S$V"B,Z(&QI8B]61E,N<&AP.C,S
M,R!L:6(O5D93+G!H<#HS-C8@;&EB+U9&4RYP:'`Z-#(V(&QI8B]61E,N<&AP
M.C4P-0HC.B!L:6(O5D93+G!H<#HU-S0@;&EB+U9&4RYP:'`Z-3DQ(&QI8B]6
M1E,N<&AP.C8V.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M-2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W-2!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP.C$X.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3F5M('3A;6]G
M871O='0N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3@*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B1F5L:F5G
M>7KI<V5K(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS
M9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B3FEN
M8W,@8O9N9^ES>FAE=/4@861A="P@=.ER:F5N('9I<W-Z82XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS
M9W-T<B`B;F]V96UB97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U,`IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(E-ZX6TB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T
M<B`B2V%R86MT97)E:R!S>N%M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S<S(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(W(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")/<WIL
M;W!O:R!S>N%M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<Q(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS
M9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(")3;W)O:R!S>N%M82(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU
M;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T
M:6]N(&QI<W0N(@IM<V=S='(@(D$@:_9R;&5VZ6QL:7-T82!M\V1O<^UTX7/A
M:&]Z(&YE;2!A9&]T="!M96<@<WKA;6]K870N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R
M(")/2R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE:W1U;2(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O
M<B(*;7-G<W1R(")!>B!O8FIE:W1U;2!LZ71R96AO>O-J82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3`X"FUS9VED(")/8W1A;"(*;7-G<W1R(")/:W3A
M;&ES('-ZX6TB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM
M<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")O:W3S8F5R(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R
M(")3>OMRZ7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS
M9VED(")/9F9I8V4B"FUS9W-T<B`B2&EV871A;"]M=6YK86AE;'DB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B02!R
MZ6=I(.ES(&%Z(/IJ(&IE;'-Z\VYA:R!K_&SV;F+V>FYI92!K96QL+B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A
M<W-W;W)D(@IM<V=S='(@(D$@<NEG:2!J96QS>O,B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N
M;W0@8V]R<F5C="XB"FUS9W-T<B`B02!RZ6=I(&IE;'-Z\R!N96T@;65G9F5L
M96SU+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;>%N(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")#<V%K
M(&%Z($E-05`@<WIE<G9E<F5K('3A;6]G871JX6L@82!M87!PX6L@;65G;W-Z
M=.%SX70N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")#<V%K(&UE9V)O='+A
M;FMO>G1A=/,@:63I>F5T(&QE9WEE;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"FUS9VED(")/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(D-S86L@96=Y(&5M
M86EL(&/M;2!A9&AA=/,@;65G+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB0W-A:R!A('1U
M;&%J9&]N;W,@=F%G>2!A(')E;F1S>F5R9V%Z9&$@=N%L=&]Z=&%T:&%T:F$@
M;65G(&5G>2!K]GKV<R`B"B)TX7)T97+\;&5T('1U;&%J9&]N;W/A="!V86=Y
M(&5LZ7+I<VD@:F]G;W-U;'1SX6=A:70B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,`IM<V=I9"`B3W!E;B!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3GEI<W-U:R!M96<@^FH@86)L86MB
M86XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B
M3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I
M9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"!H:6)A.B!.
M96T@<VEK97+\;'0@:VEN>65R;FD@87H@861A=&]K870@87H@86SA[7)T(%,O
M34E-12!RZ7-Z8O5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(DYY:7-S=6L@;65G(&5Z="!A(&/M
M;65T(&5G>2#Z:B!A8FQA:V)A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5RX6-I
M\W,@<F5N9'-Z97(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P8VGS:R(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(E
M<R!B9>%L;.UTX7-A:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R(")3
M;W)S>N%M;W,@9F5L<V]R;VSA<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B4WIE<G9E
M>F5T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@
M(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B4WIE<G9E>F5T:2!E9WES
MZ6<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/
M<F=A;FEZ:6YG(@IM<V=S='(@(DUU;FMA<WIE<G9E>NES(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N
M('1E;7!L871E(@IM<V=S='(@(D%Z(&%L:V%L;6%ZX7,@97)E9&5T:2!S86)L
M;VYJ82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B
M)7,@97)E9&5T:2!S86)L;VYJ86DZ(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H
M97(B"FUS9W-T<B`B16=YZ6(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")%9WGI8B!I
M;F9O<FWA8VGS(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM
M<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B02!T=6QA:F1O;F]S
M(&IO9V]S=6QT<^%G86DB"@HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y
M"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B02!004T@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2#A;&P@
M<F5N9&5L:V5ZZ7-R92XB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%
M05(Z.DUA:6P@86QR96YD<WIE<B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R
M(")01U`@9&EG:73A;&ES(&%LX>URX7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T
M<B`B4$=0+79E;"!T:71K;W/M=&]T="!A9&%T(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T
M<B`B4$=0(&YY:6QVX6YO<R!K=6QC<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B
M"FUS9W-T<B`B4$=0+79E;"!A;.'M<G0O=&ET:V]S[71O='0@861A="(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T
M<B`B4$A0(&OS9"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B
M4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S
M='(@(D3I;'5TX6XO97-T92!G>65N9V4@97/U(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%)A:6XB"FUS
M9W-T<B`B1.EL=73A;B!E<_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")$
MZ6QU=.%N+V5S=&4@>N%P;W)O:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(@IM<V=S='(@(D3I
M;'5TX6XO97-T92!H879A>N%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R(")$Z6QU=.%N+V5S=&4@:/-ZX7!O<F]K(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-U;B(*;7-G
M<W1R(")$Z6QU=.%N(&YA<'/\=.ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S
M='(@(D3I;'5TX6XO97-T92!Z:79A=&%R;VLB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9R(*;7-G<W1R(")(:>%N>7II:R!A(%!/4TE8(&+U=NUTZ7,B"@HC.B!L:6(O
M87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")B96QS]2!M87)G\R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-Z=.%N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L
M874B"FUS9W-T<B`B4&%L874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S>G1I;B!497+\;&5T("AM
M96=S>N%L;'0I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E#A<'5A(-IJ+4=U
M:6YE82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G
M:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B3>ER<^EK96QT96X@8F]R=6QT
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R,@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DY"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3$@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-PHC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C0S(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DIE;'-Z\R(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@
M8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D$@:F5L<WKS="!S:6ME
M<F5S96X@;65G=N%L=&]Z=&%T='5K+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S
M='(@(DYE;2!M96=F96QE;/4@:F5L<WKS(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D$@4D%$2553(&9E;&AA
M<WINX6SS87IO;F]S[73A<VAO>B!J96QS>O,@<WK\:W/I9V5S+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#4W"FUS9VED(")087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")*96QS>O,@;65G97+U<^UTZ7-S96PB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W
M;W)D.B(*;7-G<W1R(")*96QS>O,Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B2F5L<WKS
M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P,S@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM
M<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D$@:F5L<WIA
M=F%K;F%K(&5G>65Z;FG\:R!K96QL+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")"96EL;&5S>G3I<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*
M;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(D)E:6QL97-Z
M=.%S(&$@=N%G\V%S>G1A;'+S;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`BVG1V
M;VYA;"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED
M(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(MIJ(&9E;&AA<WINX6SS;F%K
M(&)E:F5L96YT:V5Z971T96LZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B16UB97)E:R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")0
M97)C96YT(@IM<V=S='(@(G-ZX7IA;.EK(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")+87)B86YT87)TX7-I(&9E
M;&%D871O:R!VZ6=R96AA:G3A<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7-K;W(@:&%J='-U:R!V
MZ6=R92!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K870_(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T
M<B`B2F]G;W-U;'1SX6<B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R
M"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D
M96QE=&5D+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!J;V=O<W5L='/A9V]T(&YE
M;2!T]G+V;'3\:RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")0
M97)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("+6;FYE:R!N:6YC<R!E:&AE>B!E
M;&5G96YD]2!J;V=O<W5L='/A9V$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$V,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B2F]G;W-U;'1SX6=O:R(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*
M(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(DIO9V]S=6QT<^%G(&%D;6EN:7-Z='+A8VGS(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R(")3>F5MZ6QY97,@861A=&]K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM
M<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G
M:60@(E!E=',B"FUS9W-T<B`BP6QL871K961V96YC96LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(D;\;/9P+7-Z:6=E=&5K(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM
M<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1NEN>6OI<&=A;.ER:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0
M:7AE;',B"FUS9W-T<B`B<&EX96PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B2_9Z:&5L>65K(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S
M='(@(DMA='1I;G1S;VX@=F%L86UE;'EI:R!C96QLX7)A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z(@IM<V=S='(@(D)I>G1O<V%N('3V<O9L;FD@86MA<FIA
M(&5Z="!A>B!E;&5M970Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S
M='(@(DOI<F5M(&5R]7/M='-E(&UE9RP@:&]G>2!V86SS8F%N('3V<O9L;FD@
M:^UVX6YJ82!E>G0@87H@96QE;65T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-38V"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+B(*;7-G<W1R(")+Z7)E;2!A9&IO;B!M96<@96=Y(&CS;F%P;W0@Z7,@96=Y
M(.EV970N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ(@IM<V=S='(@(DOI<F5M(&%D:F$@;65G(&%Z(/IJ(&MA
M=&5G\W)I82!N97;I=#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T
M<B`B2^ER96T@=F%L\W,@25`@8^UM970@861J;VX@;65G+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-C0T"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+B(*;7-G<W1R(")+Z7)E;2!V86SS<R!DX71U;6]T(&%D:F]N(&UE9RP@96QL
M96[U<FEZ>F4@82!H\VYA<"!N87!J86ET+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R(")+Z7)E;2!V86SS<R!DX71U;6]T(&%D:F]N(&UE9RXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(DOI
M<F5M('+V=FED96X@[7)J82!L92!A('!R;V)LZ6UA(&SI;GEE9^ET+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B2^ER96T@861J82!M96<@82!B
M96IE;&5N=&ME>NES:2!N97;I="#I<R!J96QS>F%VX70B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H
M92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R
M;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DOI<F5M(&]L
M=F%S<V$@96P@82!K]G9E=&ME>O4@<WKV=F5G970N($$@<F5N9'-Z97(@:&%S
M>F[A;&%TX6YA:R!F96QTZ71E;&5I="`B"B)E;"!+14Q,(&9O9V%D;FEA+B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS
M9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S
M='(@(DOI<F5M(&%D:F$@;65G(&%Z(/IJ(&MA=&5G\W)I82!N97;I=#HB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*
M;7-G:60@(E!O;&%N9"(*;7-G<W1R("),96YG>65L;W)S>N%G(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R
M(")0;VQI=&EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*
M;7-G:60@(E!O;&QS(@IM<V=S='(@(E-Z879A>N%S;VLB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M;W)T=6=A;"(*;7-G<W1R(")0;W)T=6?A;&EA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(D$@:^EP(&5L
M:&5L>65ZZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B
M"FUS9W-T<B`B02!TX6)LX7IA="!E;&AE;'EE>NES92(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,2!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"B)+]GIV971L96X@;&5V
MZ6QK_&QDZ7,@96)B92!A(&UA<'#A8F$@*$E-05`@;F5M(&UI;F1I9R!V97-Z
M:2!F:6=Y96QE;6)E*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R
M96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(D%Z
M(&5L;?IL="`E<R#S<F$@8W-A<&%DZ6MM96YN>6ESZ6=E.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(D-S87!A9.EK/&)R("\^=F%L\W-Z
M[6[[<^EG(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX"FUS9VED
M(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E!R969S7VQD87`Z(&YE;2!T86SA;&AA=/,@82!S>OQK
M<^EG97,@3$1!4"!K:71E<FIE<WITZ7,N(@H*(SH@;&EB+TAO<F1E+U!R969S
M+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7W-E<W-I;VXZ(&YE;2!T86SA;&AA=/,@82!S>OQK<^EG97,@*'-E<W-I;VXI
M(&MI=&5R:F5S>G3I<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM
M<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B3.EG;GEO;>%S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E
M;#H@(@IM<V=S='(@(D$@=&5N9V5R<WII;G1N96L@;65G9F5L96SU(&SI9VYY
M;VWA<SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM
M<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("),Z6=N>6]MX7,Z("(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S
M"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D5L]7IE=&5S(&UE9W1E:VEN=.ES
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B02!KZ7`@96SU>F5T97,@;65G=&5K:6YTZ7-E
M(/IJ(&%B;&%K8F%N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-38@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P
M=&EO;G,B"FUS9W-T<B`B16SU>O4@;W!C:?-K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C
M=6UE;G0B"FUS9W-T<B`B02!D;VMU;65N='5M(&MI;GEO;71A=.%S82(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+
M97DB"FUS9W-T<B`B5&ET:V]S(&MU;&-S(@H*(SH@;&EB+TAO<F1E+TUE;G4N
M<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")(:6)A8F5J96QE;G3I
M<R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE
M;2!$97-C<FEP=&EO;B(*;7-G<W1R(")!(&AI8F$@;&7M<N%S82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM
M<V=S='(@(E!R;VIE:W0@:V5Z96SI<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3$U(&QI8B](;W)D92]&;W)M+G!H<#HR,3DR(&QI8B](;W)D92]&;W)M
M+G!H<#HS,C@P"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")!('!R;VUP
M="!S>O9V96=E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(DYY:6QVX6YO<R!K=6QC<R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(*;7-G<W1R(").>6EL=N%N;W,@:W5L8W/Z(&%L9V]R
M:71M=7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I
M9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DYY:6QVX6YO<R!K=6QC<R!I
M;F9O<FWA8VGS(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS
M9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R(")!(&YY:6QVX6YO<R]T:71K;W,@:W5L8W-P
MX7)T(&YE;2!S:6ME<OQL="!LZ71R96AO>FYI+B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T
M;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*
M;7-G<W1R(")!(&QE=F5L96L@=NEG;&5G97,@=/9R;.ES92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E%A=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")+97)E<_4O<&%R86YC<R!S=')I
M;F<B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A
M(@IM<V=S='(@(DMV\W1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="DB"FUS9W-T<B`B4E-!(&YY:6QVX6YO<R!K=6QC<R`H)60@8FET97,I
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C@*;7-G:60@(E)A9&EO('-E
M;&5C=&EO;B(*;7-G<W1R(")2X61I\V=O;6)O<R!K:7;A;&%S>G3A<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED
M(")286EN(@IM<V=S='(@(D5S]2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@
M(D5S]2!DZ6QE;/5T="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0V"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B17/U(&3I
M;'5TX6XO97-T92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0W"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("):X7!O<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS
M9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(D5S]2#I<R!H879A>N%S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G
M:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")(879A<V5S]2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G
M<W1R(")6Z6QE=&QE;B!I9.EZ970B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B07+A;GDB"@HC.B!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R(")/;'9A
M<^%S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0W(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M
M97-S86=E<R(*;7-G<W1R("),979E;&5K(&]L=F%SX7-A(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(B(*(E3I;GEL96<@=/9R]FQJ_&L@)7,@9F5L
M:&%S>F[A;/-T/R!%>B!A(';A;'1O>G1A=.%S(&YE;2!F;W)D[71H873S('9I
M<W-Z82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`B(@HB5.EN>6QE9R!T]G+V;&K\:R`E<R!F96QH87-Z;N%L\R!A
M9&%T86ET/R!%>B!A(';A;'1O>G1A=.%S(&YE;2!F;W)D[71H873S("(*(G9I
M<W-Z82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R
M("+::G)A(';I9W)E:&%J=&IA(&%Z('5T;VQS\R!VX6QT;WIT873A<W0B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")&<FES<^UTZ7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B02!M96[\(&1I;F%M:6MU
M<R!E;&5M96EN96L@9G)I<W/M=.ES:2!G>6%K;W)I<^%G83HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6
M:65W.B(*;7-G<W1R(")!>B#V<W-Z96=Z]6]L9&%L(&9R:7-S[73I<^EN96L@
M9WEA:V]R:7/A9V$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM
M<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,R,S4*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(D]B
M:F5K='5M(&+V;F?I<WKU(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B
M4F5L;V%D(@IM<V=S='(@(D9R:7-S[73I<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM<V=S='(@(DUE9VIE9WEZZ7-E
M:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T
M92!397)V97)S(@IM<V=S='(@(E3A=F]L:2!S>F5R=F5R96LB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")!('3A
M=F]L:2!54DP@*'!L+B!H='1P.B\O=W=W+G9A;&%M:2YH=2]M96=V86QA;6DI
M.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E
M(@IM<V=S='(@(E3V<FSI<R(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D)L;VMK('3V
M<FSI<V4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(D]S>FQO<"!T]G)L
MZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B02!F;W)M
M871TX6SA<R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(D$@<.%R('3V<FSI
M<V4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@HB5/9R]FQJ_&L@87H@96QM96YT971T('!R;V=R
M86UO="!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N>6]K870@=&%R=&%L
M;6%Z\R`B"B)A;&OV;GEV=.%RX6+S;"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V
M92!T:&4B"FUS9W-T<B`B5F5G>?QK(&MI("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")696=Y
M_&L@:VD@97IT(&$@<NES>G0@82!D;VMU;65N='5M8O-L(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S
M97(B"FUS9W-T<B`B02!F96QH87-Z;N%L\R!T]G)LZ7-E(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("(E<R!F96QH87-Z;N%L\R!T
M]G)LZ7-E(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I
M9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R
M;W)C;V1E.B`B"FUS9W-T<B`B02!KZ7+I<R!N96T@=&5L:F5S[71H973U+B!!
M(&MA<&]T="!H:6)A:_-D.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(@IM<V=S='(@(D$@:V5R97-E='0@<WIO;&?A;'1A=.%S(&YE
M;2!T86SA;&AA=/,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S8@;&EB+TAO<F1E
M+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M02!K]G1E;&5Z]65N(&UE9V%D86YD\R!<(B5S7"(@;F5M('-Z97)E<&5L("5S
M(&MO;F9I9W5RX6-I\VKA8F%N+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV-S@@
M;&EB+U9&4R]F='`N<&AP.C@V,2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D$@:_9T96QE
M>O5E;B!M96=A9&%N9/,@7"(E<UPB(&YE;2!S>F5R97!E;"!A(%9&4R!K;VYF
M:6=U<N%C:?-JX6)A;BXB"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S<V"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D$@:_9T96QE>O5E;B!M
M96=A9&%N9/,@7"(E<UPB(&YE;2!S>F5R97!E;"!A(&MO;F9I9W5RX6-I\V)A
M;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED
M(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")3>OQK<^EG97,@;65Z]2(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS-#,@;&EB
M+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B4F5S970B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B
M"FUS9W-T<B`B02!J96QS>O,@X73A;&SM=.%S82(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D
M(@IM<V=S='(@(D%Z(-9N(&IE;'-Z87;A;F%K(.%TX6QL[73A<V$B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E
M<GDB"FUS9W-T<B`B07H@=71O;'/S(&ME<F5SZ7,@=FES<WIAX6QL[73A<V$B
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP
M.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G
M<W1R(")%<F5D;>EN>2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N
M('1O($]P=&EO;G,B"FUS9W-T<B`B5FES<WIA(&%Z(&]P8VGS:VAO>B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E
M(&YE=R!P87-S=V]R9"(*;7-G<W1R(")!>B#Z:B!J96QS>O-T(.UR:F$@8F4@
M:7-MZ70B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DW(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(E+I=6YI;VXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@
M(L%L;.UT<W5K('9I<W-Z82!A(&MO;F9I9W5RX6-I\W0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,B"FUS9W-T<B`B4FEC:"!497AT($5D:71O<B!O<&-I\VLB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T
M<B`B5&%LX6SS<R!KZ7)DZ7-E:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T
M<B`B:F]B8B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`W"FUS9VED(")2
M:6=H="!H96%D97(B"FUS9W-T<B`B2F]B8B!O;&1A;&D@9F5J;.EC(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R(")*;V)B(&]L9&%L:2#I<G3I:V5K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2
M;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4V]R('1U;&%J9&]N<^%G;VLN
M+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM
M<V=I9"`B4F]L92(*;7-G<W1R(")3>F5R97`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA
M(@IM<V=S='(@(E)O;>%N:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D9O
M<F=A=.%S(#$X,"!F;VMK86PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")"
M86QR82!F;W)G873A<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")*;V)B
M<F$@9F]R9V%TX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G
M<W1R(")3;W(@='5L86ID;VYSX6=O:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P
M97)T:65S(@IM<V=S='(@(E-O<B!T=6QA:F1O;G/A9V]K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O
M=W,Z(@IM<V=S='(@(E-O<F]K.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(E9O;F%L86LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(DUI;F1E;B!S
M;W(@Z7,@;W-Z;&]P(&OV>O9T="!L96=Y96X@=F]N86PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G
M<W1R(")#<V%K(&%Z(&]S>FQO<&]K(&OV>O9T="!L96=Y96X@=F]N86PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>2(*;7-G<W1R(")#<V%K(&$@<V]R;VL@:_9Z]G1T(&QE9WEE;B!V;VYA;"(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R
M(")&=71T873A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G
M<W1R(")/<F]S>B!&]F1E<N%C:?,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T
M<B`B4G5A;F1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR.#4*
M;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R
M(")3+TU)344@9&EG:73A;&ES(&%LX>URX7,B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E(@IM<V=S='(@(E,O34E-12!S>F%B=N%N>2!S>F5R:6YT('1I=&MO<^UT
M;W1T(&QE=NEL(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#$*;7-G
M:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B4T%33"!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('1A;.%L:&%T
M\RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")3
M35,@365S<V%G:6YG(@IM<V=S='(@(E--4R!K_&QDZ7,B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W.`IM<V=I9"`B4U%,('-T871E;65N
M="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")344P@<&%R86YC<R!A(&ME
M<F5SZ7-H97HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS
M9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM
M<V=S='(@(E-)2T52W$Q4(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")3
M7U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(E-Z;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")3>F5N="!);&]N82US
M>FEG970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R
M(")386EN="!+:71T<R#I<R!.979I<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B
M"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@
M86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT(%!I97)R92#I<R!-:7%U96QO
M;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@Z7,@1W)E;F%D:6YE+7-Z:6=E=&5K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(E5G>6%N87H@
M82!F<F%M92`H7W-E;&8I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4WIA
M;6]A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A
M;R!4;VWI(.ES(%!R[6YC:7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B3?MH
M;VQD87,@:6YT97)N971E;.ERZ7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B
M"FUS9W-T<B`B4WIA^F0M07+A8FEA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(DUE;G3I<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB(&UE;G3I
M<V4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(B5S(&UE;G3I<V4B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO
M;G,B"FUS9W-T<B`B02!B9>%L;.UTX7-O:R!M96YTZ7-E(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G
M<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)-96YT<_QK
M(&5L(&%Z(&5L:^ES>OQL="!K;VYF:6=U<N%C:?-T(%!(4"!P<F]G<F%M(&9O
M<FWA:N%B86X@82!S>F5R=F5R("(*(FED96EG;&5N97,@X6QL;VWA;GEO:V%T
M('1A<G1A;&UA>O,@86QK]FYY=G3A<N%B86XN(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@:V]N9FEG=7+A8VGS:N%T(&5L
M;65N=&5T=/QK+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(D5L;65N=&5T=/QK(&$@<V5T=7`@=7!G
M<F%D92!P<F]G<F%M;W0@:61E.B!<(B5S7"(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4V-A='1E<F5D(%0M
M4W1O<FUS(@IM<V=S='(@(E-Z\W)VX6YY;W,@>FEV871A<F]K(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@
M(E1U9&]MX6YY(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E
M87)C:"(*;7-G<W1R(")+97)E<^ES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B2V5R
M97/I<VD@<WIO;&?A;'1A=.%S;VLB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDU.0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(L%L;&]MX6YY;VL@
M:VEVX6QA<WITX7-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")6X6QA
M<W-Z;VX@:VD@96=Y(&3A='5M;W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S
M='(@(DUE;'EI:R!C<V]P;W)T;W0@:^UVX6YJ82!H;WIZX6%D;FDB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N
M97<@;W=N97(B"FUS9W-T<B`B5N%L87-S>F$@:VD@87H@^FH@='5L86ID;VYO
M<W0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@
M(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")6X6QA<W-Z;VX@<WIE<G9E<G0B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L
M96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B365L>6EK(&9E;&AA<WINX6SS
M="!K[7;A;FIA(&AO>GKA861N:2(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B
M36EN9&5T(&MI:F5L]FQJ_&LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T
M-PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@
M(E;A;&%S<WIA(&MI(&%Z(/9S<WIE<R!DX71U;?9S<WIE=&5V]70N(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B
M4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")6X6QA<W-Z;VX@96=Y(&]B:F5K
M='5M;W0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<W"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")%9WD@<V4@;&5G>65N
M(&MI:F5L]FQV92(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I
M9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E;A;&%S<WIA
M(&MI(&$@:^UVX6YT(&MA<F%K=&5R*&5K92ET(&%Z(&%LX6)B:2!L96AE=/5S
MZ6=E:R!K]GK\;"X@17IU=.%N("(*(EPB8V]P>2]P87-T95PB(&WS9'-Z97)R
M96P@82!M96=F96QE;/4@:&5L>7)E(&WA<V]L:&%T:F$@]6ME="XB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5N%L87-S>F$@:VD@82!DX71U;65L
M=N%L87-Z=/,@:V%R86MT97)T.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R
M(")6X6QA<W-Z82!K:2!A(&3A='5M(&9O<FWA='5MX70Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E;A
M;&%S<WIA(&MI+"!M96QY:6L@87IO;F]S[73S:N%T(&OM=N%N:F$@;65G=N%L
M=&]Z=&%T;FDZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E;A;&%S
M<WIA(&MI(&%Z(&ED]65L=N%L87-Z=/,@:V%R86MT97)T.B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@
M9F]R;6%T.B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A>B!I9/4@9F]R;>%T=6WA
M=#HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B5N%L87-S>F]N
M(&MI(&OI="!E9WEMX7-N86L@;65G9F5L96SU(&UE>O5T+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B5N%L87-S>F$@:VD@82!K[7;A;G0@<WKM;F5G
M>?QT=&5S="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E;A
M;&%S<WIA(&MI(&%Z(-9N;F5K(&UE9V9E;&5L]2!N>65L=F5T.B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R
M;V)L96T@4F5P;W)T(@IM<V=S='(@(DAI8F%J96QE;G3I<R!K_&QDZ7-E(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G
M:60@(E-E;F0@4TU3(@IM<V=S='(@(E--4R!K_&QDZ7-E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V5N96=A;"(*;7-G<W1R(")3>F5N96?A;"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")3>F5N>F]R.B`B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P
M=&5M8F5R(@IM<V=S='(@(G-Z97!T96UB97(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G
M<F\B"FUS9W-T<B`B4WIE<F)I82#I<R!-;VYT96YE9W+S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B
M"FUS9W-T<B`B4V]R;WIA='-ZX6TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")!('-Z97)V97)T]6P@:V%P;W1T(&%D870@
M:&EBX7,L('9A9WD@;F5M(.%L;"!R96YD96QK97KI<W)E+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R
M(")!(&9E;&AA<WINX6SS:V%P8W-O;&%T;VL@861M:6YI<WIT<N%C:?-J82(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED
M(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DQE:N%R="!A(&9E;&AA
M<WINX6SS:V%P8W-O;&%T(&%Z;VYO<^UT\VIA("AS97-S:6]N($E$*2XB"@HC
M.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(D9E
M;&AA<WINX6SS:V%P8W-O;&%T;VLB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,Q.`IM<V=I9"`B4V5T(@IM<V=S='(@(DAA;&UA>B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@
M>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T
M(&ET+B(*;7-G<W1R("),96AE=/5SZ6<@:F5L<WIA=N%N86L@X73A;&SM=.%S
MX7)A+"!A8F)A;B!A>B!E<V5T8F5N+"!H82!E;&9E;&5J=&5NZ2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E
M('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O
M<G1A;"XB"FUS9W-T<B`B(@HB5.%V;VQI('-Z97)V97)E:R!E;.ERZ7-E(.%L
M;.UT:&%T\R!B92P@;65L>65K970@87H@:6YD=6SS;VQD86SA;B!K[7;A;B`B
M"B)M96=J96QE;NUT96YI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")!(&OM=N%N="!N>65L=BP@
M:63U>O-N82#I<R!DX71U;69O<FWA='5M(&)EX6QL[73A<V$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*
M(D)EX6QL[71H873S+"!H;V=Y(&UE;'EI:R!A;&MA;&UA>N%S(&IE;&5N:F5N
M(&UE9R!A(&)E:F5L96YT:V5ZZ7,@=73A;BP@(@HB;6EL>65N('-Z[6YE9WG\
M='1E<W0L(&]L9&%L9G)I<W/M=.ES:2!G>6%K;W)I<^%G;W0@:6QL+B!E9WGI
M8B!B9>%L;.UTX7-O:V%T("(*(G-Z97)E=&YE+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(D)EX6QL[73A
M<V]K(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*
M;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T
M<B`B02!B9>%L;.UTX7-O:V%T(&UE9_IJ[73S('!R;V=R86UO:R#A;&QN86L@
M<F5N9&5L:V5ZZ7-R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D$@;65G861O='0@<&%R86WI=&5R
M('3V8F(@:&5L>65T(&ES(&IE;&5N=&AE=#H@(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE
M;&QE<R(*;7-G<W1R(")397EC:&5L;&4M<WII9V5T96LB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R
M(")6X7/A<FSA<R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(E+V=FED(/9S<WIE
M9F]G;&%LX7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED
M(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\B"FUS9W-T<B`B16P@:^UVX6YJ82#I<FYI(&%Z(&5G>65S(&9U;FMC:?-K
M870@06QT+6)I;&QE;G1Y^RUK;VUB:6[A8VGS:VMA;"!I<S\B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R
M(")-96=J96QE;NUTZ7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U
M"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY
M('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(DUU=&%S<W5K(&UE9R!A(&O\;/9N8G/I9V5K970@
M87H@96QM96YT971T(.ES(&%Z(/IJ;VYN86X@;.ET<F5H;WIO='0@(@HB:V]N
M9FEG=7+A8VGS(&OV>O9T="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@
M:6X_(@IM<V=S='(@(B(*(DUI;F1E;B!B96IE;&5N=&ME>NES:V]R(.UR\V1J
MZ6L@:VD@82!K;W+A8F)I('5T;VQS\R!B96IE;&5N=&ME>NES(&ED96IE/R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8Y"FUS9VED(")3:&]W(&]P=&EO
M;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(E;A;&%S>G1H873S(&QE9WEE
M;B!A>B!E<F5D971I(&UE9W1A<G3A<V$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C<Y.0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B3&5G>65N(&3A
M='5M=N%L87-Z=/,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS
M9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@
M(DQE9WEE;B!E9WD@=.%B;.%Z871K97IE;/4@;65N_'-O<C\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(DUU=&%S<W5K
M(&$@)7,@;65N_'0@82!B86P@;VQD86QO;C\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M3NEZ>OQK(&UE9R!TX6)LX7IA="!C96QLX6EN86L@='5L86ID;VYSX6=A:70B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(D[I>GK\:R!M96<@=.%B;.%Z870@='5L86ID;VYSX6=A
M:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(").Z7IZ_&L@;65G('3A8FSA>F%T('-O<F%I
M;F%K('1U;&%J9&]N<^%G86ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Z7IZ_&L@;65G(&$@
M:^EP('1U;&%J9&]N<^%G86ET(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W
M-C<*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(DUU=&%S<W5K(&$@9F5L
M=/9L=.ES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4Q"FUS9VED(")3:&]W97)S(@IM<V=S='(@(EKA<&]R;VLB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B
M4VAO=V5R<R!%87)L>2(*;7-G<W1R("):X7!O<F]K(&3I;&5L]71T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@
M(E-H;W=E<G,@3&%T92(*;7-G<W1R("):X7!O<F]K(&3I;'5TX6XO97-T92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS
M9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")(96QY:2!Z
MX7!O<F]K(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")+:6-S:6YY[73I<R(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V
M92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B
M"FUS9W-T<B`B(@HB16SU<WKV<B!K:6-S:6YY[71E;FEE(&ME;&PL('9A9WD@
M96P@:V5L;"!M;WID[71A;FEA(&$@:&5L>65T(&5L9F]G;&%L\R`B"B)B;&]K
M:V]K870N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R
M82!,96]N92(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS
M9VED(")3:6=N('5P(@IM<V=S='(@(MIJ(&9E;&AA<WINX6SS:R!B96IE;&5N
M=&ME>NES92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S"FUS
M9VED(")3:6=N871U<F4B"FUS9W-T<B`B1&EG:73A;&ES(&%LX>URX7,B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T
M=7)E($%L9V]R:71H;2(*;7-G<W1R(")!(&1I9VETX6QI<R!A;.'M<N%S(&%L
M9V]R:71M=7-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-Z:6YG
M87#Z<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#$*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,38@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,#D*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*;7-G:60@(E-I
M>F4B"FUS9W-T<B`B3>ER970B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*
M;7-G<W1R(")!(&MA<F)A;G1A<G3A<R!K:6AA9WGA<V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M;&]V86MI82(*;7-G<W1R(")3>FQO=N%K:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI
M82(*;7-G<W1R(")3>FQO=NEN:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R(*;7-G<W1R(")(879A
M>N%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-38*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(DCS>N%P;W(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B
M4VYO=R!3:&]W97)S(@IM<V=S='(@(DCS>N%P;W)O:R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B2/-ZX7!O<F]K(&3I;&5L]71T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@
M(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(DOI<_4@9.EL=73A;FDO97-T
M:2!H\WKA<&]R;VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-0IM<V=I
M9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(D$@:/,@;>EL>7/I9V4Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE
M;G0@:6X@=V%T97(Z("(*;7-G<W1R(")(\R!V[7IM96YN>6ESZ6=E8F5N(&MI
M9F5J97IV93H@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@
M(E-A;&%M;VXM<WII9V5T96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@
M(E-Z;VWA;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED
M(")3;VYG<R`F(%!O96US(@IM<V=S='(@(D1A;&]K+"!V97)S96LB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ,@IM<V=I9"`B4V]R="!O<F1E<B!S96QE
M8W1I;VXB"FUS9W-T<B`B02!S;W)B87)E;F1E>NES(&ERX6YYX6YA:R!K:7;A
M;&%S>G3A<V$B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-34Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C$V-B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")&96QA9/-I(&/M;2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")$Z6PM069R:6MA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R(")DZ6PM975R\W!A:2`H25-/+3@X-3DM,RDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S(@IM<V=S='(@(D3I;&DM1V5O<F=I82#I<R!$Z6QI(%-A;F1W
M:6-H+7-Z:6=E=&5K(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*
M;7-G<W1R(")$Z6QI(&;I;'1E:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<R(*;7-G<W1R(")3>F]M<WKI9&]S(&-E;&SA:R!K]GKV
M='1I('3A=F]L<^%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B02!C96QL82!T87)T86QM82#I
M<R!K97)E=&4@:_9Z]G1T:2!TX79O;'/A9R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HX,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R(")(96QY:VET]FQT]2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")4X79O;'/A9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*
M;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B5.%V;VQSX6<@
MZ7,@8F5L<_4@;6%R9_,@8F7A;&SM=.%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S
M='(@(E-P86YY;VQO<G-ZX6<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86UA<W-A<W-I;F4@8F7A
M;&SM=.%S;VLB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@
M(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(E-P96-IX6QI<R!K
M87)A:W1E<B!B979I=&5L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS
M9W-T<B`B02!C96QL82!K971TZ6)O;G3A<V$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI
M="!C;VQU;6XB"FUS9W-T<B`B07H@;W-Z;&]P(&ME='3I8F]N=.%S82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R(")!('-O<B!K971TZ6)O;G3A
M<V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R(")3<&]R="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@
M(E-R[2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M-B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q"FUS9VED(")3=&%N9&%R9"(*;7-G
M<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM
M<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-3DP(&QI8B](;W)D92]&;W)M+G!H<#HR-SDU"FUS
M9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%Z(&5L<_4@Z78B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O
M=FEN8V4B"FUS9W-T<B`BP6QL86T@=F%G>2!T87)T;VWA;GDB"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(L%L;&%P;W0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P
M,0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B365N=.ES:2!F;W)M
MX71U;2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED
M(")3=')E970@061D<F5S<R(*;7-G<W1R(")#[6T@*'5T8V$I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B
M4W1R:6ME=&AR;W5G:"(*;7-G<W1R("+A=&CZ>F]T="(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R(")3
M=')I;F<@;&ES=&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I
M9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B5/9R
M]FQJ_&L@82!C[6UB]6P@82!`('5TX6YI('+I<WIT(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W3M;'5S(%M#4U-=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B
M"FUS9W-T<B`B5F$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%L:_9N>79TX7(@;F5M('1A;.%L
M:&%T\RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")4X7)G>2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S8@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q
M-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(DO\;&1J_&L@96PB"@HC.B!S:6=N
M=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R
M97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO
M="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O
M=F5D+B(*;7-G<W1R("(B"B)<(B5S7"(@^FH@9F5L:&%S>F[A;/,@8F5J96QE
M;G1K97KI<VD@:^ER96QMZ70@=&]VX6)B[71O='1U:RX@UFX@8W-A:R`B"B)K
MZ7)E;&WI;F5K(&5L9F]G863A<^%T(&OV=F5T]65N('1U9"!M86ID(&)E:F5L
M96YT:V5Z;FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(F%L<_,@:6YD
M97@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S
M<R(*;7-G<W1R(")3:6ME<OQL="(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4VEK97)E<V5N(&AO>GKA861T=6L@
M7"(E<UPB+70@82!R96YD<WIE<FAE>BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")<(B5S7"(@9F5L:&%S>F[A;/,@861A=&%I="!S:6ME<F5S96X@=/9R]FQT
M_&L@82!R96YD<WIE<F+U;"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")3:6ME<F5S
M96X@=/9R]FQT_&L@7"(E<UPB+70N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E-I:V5R97-E;B!E;'3A
M=F]L[71O='1U:R!<(B5S7"(M="!A(')E;F1S>F5R8O5L+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E
M<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM
M<V=S='(@(B(*(D$@:V]N9FEG=7+A8VGS="!S:6ME<F5S96X@=FES<WIAX6QL
M[71O='1U:RX@02!VX6QT;WKA<V]K(&UE9W1E:VEN=.ESZ6AE>B`B"B)F<FES
M<^UT<V4@87H@;VQD86QT+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU
M.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")!(&)A
M8VMU<"!K;VYF:6=U<N%C:?-T(&5L;65N=&5T=/QK+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R(")3:6ME<F5S96X@96QM96YT971T_&L@82AZ*2`E<R!B86-K
M=7`@:V]N9FEG=7+A8VGS="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB
M(@IM<V=S='(@(EPB)7-<(B!A9&%T86EN86L@;?-D;W/M=.%S82!S:6ME<F5S
M96X@;65G=/9R=.EN="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B4VEK97)E<V5N(&5L
M;65N=&5T=/QK(&$@)7,@X6QL;VWA;GET+B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM
M<V=S='(@(E-Z=63A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B
MUG-S>F5F;V=L86SA<R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM
M<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B3F%P:V5L=&4B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B3F%P
M;GEU9W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C`*;7-G:60@(E-U;FYY(@IM<V=S='(@(FYA<&]S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R(").87!K96QT92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B
M"FUS9W-T<B`B3F%P:V5L=&4O;F%P;GEU9W1A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@
M(DYA<&ME;'1E.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B3F%P;GEU9W1A(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`B3F%P;GEU9W1A.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G
M<W1R(")F96QS]2!I;F1E>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B3VYL:6YE(&MO;6UU;FEK
MX6-I\R`H8VAA="DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I
M;F%M92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED
M(")3=7)N86UE(@IM<V=S='(@(D-S86SA9&[I=B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB
M87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@Z7,@2F%N($UA
M>65N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-Z=N%Z:6;V;&0B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W;I9&]R<WKA9R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=N%J8R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM
M<V=S='(@(D%Z(&%D871S>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>70@
M=/9R]FQT_&LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED
M(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D
M<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`B4WII;G1A:W1I:V%I(&AI8F$@82!K97)E<_5K:69E:F5ZZ7-B
M96XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3
M>NUR:6%I($%R86(@2_9Z=.%R<V%SX6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R
M(")::79A=&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(EII
M=F%T87(L(&5R]7,@<WKI;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")::79A
M=&%R;VLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-`IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B2V]R86D@>FEV
M871A<F]K(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@
M(E135B!F:6QE(@IM<V=S='(@(E135B`H5$%"(&MA<F%K=&5R<F5L(&5L=N%L
M87-Z=&]T="#I<G3I:V5K*2#A;&QO;>%N>2(*"B,Z(&QI8B](;W)D92]522]4
M86)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R(")4X6)LX7IA="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B02!TX6)L
MX7IA="!T=6QA:F1O;G/A9V%I(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(D$@=.%B;.%Z
M870@='5L86ID;VYSX6=A:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB
M"FUS9W-T<B`B5&%J=F%N(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G
M<W1R(")486IV86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A
M9'IS:6MI<WITX6XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E1A;GKA;FEA:2!%9WEE<_QL="!+:7+A;'ESX6<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"FUS9VED(")487)G970Z(@IM<V=S='(@(D$@8^EL.B(*"B,Z(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#0Y(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(D9E;&%D871O:R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M
M8F5R(@IM<V=S='(@(E1E;&5F;VYS>N%M(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(D%Z(&5L;?IL="#S<F$@:/5MZ7)SZ6ML971E.B`B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B2/5M
MZ7)SZ6ML970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R
M"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(DCU;>ER<^EK;&5T.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,B"FUS9W-T<B`B2/5MZ7)SZ6ML970\8G(@+SXH)7--87@E<R\E
M<TUI;B5S*2`F9&5G.R5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B02AZ*2!<(B5S7"(@<V%B;&]N(&YE;2!T86SA;&AA
M=/,N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L
M871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E-A8FQO;F]K(&%D;6EN:7-Z
M=.%C:?-J82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S,Q"FUS9VED(")497AT(@IM<V=S='(@(E-Z]G9E9R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R(")C<V%K('-Z]G9E9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI
M9VXB"FUS9W-T<B`B4WKV=F5G96QH96QY97KI<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`B<WKV=F5G('1E=&5J92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(D-S
M_"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A4
M25,M-C(P*2(*;7-G<W1R(")T:&%I("A425,M-C(P*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H
M86EL86YD(@IM<V=S='(@(E1H86EF]FQD(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B07H@9G1P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC
M.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y
M('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B02!(:7-T;W)Y(')E;F1S
M>F5R(&W[:_9DZ7-E(&YI;F-S(&5N9V5DZ6QY97IV92XB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M7"(E<UPB(@IM<V=S='(@(D$@2&]R9&4O2V]L86(@:6YT96=RX6-I\R!E>G0@
M;F5M('3A;6]G871J83H@7"(E<UPB(@H*(SH@;&EB+TYE="])35-0+T)O;VLN
M<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI
M=&EA;&EZ960N(@IM<V=S='(@(D%Z($E-4U`@;F%P;/-ZX7-T(&YE;2!S:6ME
M<OQL="!M96=K97ID96YI+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")!($UA:6YT96YA;F-E.CH@;W-Z
M=.%L>2!B973V;'3I<V4@;F5M('-I:V5R_&QT(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(D%Z($]P8VGS(&%B
M;&%K(&)E>N%R;V1O='0N($MI;.EPZ7,@:_9V971K97II:RXB"@HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,"!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(R,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C(U,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E
M9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME
M;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R
M("(B"B)!($IO9V]S=6QT<^%G;VL@:&%S>F[A;&%TX6YA:R!E;/5F96QTZ71E
M;&4L(&AO9WD@82!R96YD<WIE<F=A>F1A("(*(FMO;F9I9W5RX6QJ;VX@96=Y
M(&$@:F]G;W-U;'1SX6=I(&%D871O:V%T('1A<G3S<V%N('3A<F]L;FD@:^EP
M97,@86QR96YD<WIE<G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E
M(&]N;'DB"FUS9W-T<B`B0W-A:R!A;'5L(&QE9WEE;B!K97)E="(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS
M9W-T<B`B(@HB02!P87)T;F5R(&%Z;VYO<^UT\W-ZX6UA(&YE;2!V;VQT(&UE
M9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871BX7II<V)A;B`B"B)N
M96T@=F]L="!M96=T86SA;&AA=/,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M02!P87)T;F5R(&%D871A:70@<VEK97)E<V5N(&AO>GKA861T=6L@82!C[6UJ
M96=Y>NEKZ6AE>BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3<R
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"B)+_&SV;N%L;/,@4$=0(&%LX>URX7-I(&)L;VMK('-Z_&MSZ6=E
M<R!A(&1I9VETX6QI<V%N(&%LX>UR="#\>F5N970@(@HB:&ET96QE<W/I9^EN
M96L@96QL96[U<GKI<^EH97HN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N
M;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)!(&OV
M<FQE=NEL;&ES=&$@87IO;F]S[73S<WKA;6$@;F5M('9O;'0@;65G861V82_\
M<F5S96X@;6%R861T('9A9WD@87H@(@HB861A=&+A>FES8F%N(&YE;2!V;VQT
M(&UE9W1A;.%L:&%T\RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO
M="!S<&5C:69I960N(@IM<V=S='(@(D$@:_9R;&5VZ6QL:7-T82!N96T@=F]L
M="!M96=A9'9A+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z,3$V"FUS9VED
M(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B)!('1I=&MO<^UTX7-I('-Z;VQG
MX6QT873A<V]K:&]Z(&)I>G1O;G/A9V]S("AT:71K;W/M=&]T="D@=V5B(&MA
M<&-S;VQA="!K96QL+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<W(&QI8B](;W)D
M92YP:'`Z-3$Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B02AZ*2`E<R#A
M;&QO;>%N>6)A;B!S>F5R97!E;&YI92!K96QL96YE(&5G>2`E<R!B9>%L;.UT
MX7-N86LN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S`@;&EB+TAO<F1E+G!H<#HU
M,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@HB02AZ*2`E<R#A
M;&QO;>%N>6)A;B!S>F5R97!E;&YI92!K96QL96YE('9A;&%M:6QY96X@)7,@
M8F7A;&SM=.%S*&]K*6YA:RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(R-@IM
M<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB
M"FUS9W-T<B`B02!FX6IL(&YE;2!MX7-O;&AA=/,@]FYM86?A<F$N(@H*(SH@
M;&EB+TAO<F1E+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(D$@9N%J;&)A;B!N96T@=F]L="!A9&%T
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")!>B#\>F5N970@9F5J
M;.EC<V]R86D@82!K]G9E=&ME>O5K+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB02!T96QJ
M97,@:^EP97)N>?5S(/QZ96UM\V0@<')O8FSI;>%K870@;VMO>FAA="!A>B!)
M;G1E<FYE="!%>'!L;W)E<B`B"B)H87-Z;N%L871A(&5S973I;BP@;65R="!E
M8F)E;B!O;'EA;B!P<F]G<F%M:&EBX6L@=F%N;F%K+"!A;6EK970@;F5M('1U
M9'1U;FL@(@HB;65G:V5R_&QN:2X@02!KZ7!E<FYY]6IE(&]L=F%S:&%T871L
M86YNX2!VX6QH870L(&)I>F]N>6]S(&5D:71O<B!F=6YK8VGS:R`B"B)H:>%N
M>6]Z:&%T;F%K(.ES+W9A9WD@=N%R871L86YU;"!L969A9WEH870@82!B]FYG
MZ7-Z]7!R;V=R86TN(%=I;F1O=W,@.7@@(@HB:&%S>F[A;&%T82!E<V5TZ6X@
M;F%G>6]N('9A;/-S>NUN^RP@:&]G>2`G1V5N97)A;"!P<F]T96-T:6]N(&9A
M=6QT)R!H:6)A("(*(FUI871T(/IJ<F$@:V5L;"!I;F3M=&%N:6$@;6%J9"!A
M(&?I<.ET+EQ<;EQ<;D9I9WEE;&UE>G1E='3\:R$@2V%T=&EN='-O;B!A>B`B
M"B)/2R!G;VUB<F$L(&AA(&WI9VES(&UE9R!K[7;A;FIA(&OM<^ER96QN:2!A
M('1E;&IE<R!KZ7!E<FYY]7,@_'IE;6WS9&]T+B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!(%PB)7-<(B!A
M>F]N;W/M=/-T(&MI=/9R]FQT_&LN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B0W-A:R!B86P@;VQD86QO;B!L96=Y
M96X@:V5R970B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G
M:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B
M"B)!($=N=5!'('!R;V=R86T@:&5L>>ET(&UE9R!K96QL(&%D;FD@82!#<GEP
M=%]P9W`Z.B!O<WITX6QY(&AA<WINX6QA=.%H;WHN(@H*(SH@;&EB+TAO<F1E
M+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB
M(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+B(*;7-G<W1R("(B"B)!(&QE=NEL+"!M96QY970@)7,@;F%P:N%N(&O\;&3V
M='0@)7,@8^UM>F5T=&YE:R!<(B5S7"(@=.%R9WEB86XL(&$@8^UM>F5T="`B
M"B)S>N%M[73S9^EPZ6X@;65G:F5L96YT+B!!<G)A(&YI;F-S(&=A<F%N8VEA
M+"!H;V=Y(&5L(&ES(&]L=F%S=.%K(&EL;"X@:&]G>2`B"B)M96?I<G1E='3I
M:RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@X,0IM<V=I9"`B5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM
M<V=S='(@(DUI(&QE9WEE;B!A(&QE=NEL[7+S(&%B;&%K:&]Z(&UU=&%T\R!L
M:6YK(&5L;F5V97KI<V4B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W-`IM<V=I
M9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G
M<W1R(")!(&UE>O5K('-ZX6UA(&-S86L@;G5M97)I:W5S(.ER=.EK(&QE:&5T
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB07H@;W!E;G-S;"!M
M;V1U;"!S>OQK<^EG97,@82!(;W)D95]#<GEP=%]S;6EM93HZ(&]S>G3A;'D@
M:&%S>F[A;&%TX6AO>BXB"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(X,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@
M8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@
M=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB02!<
M(B5S7"(@<WIE;>EL>65S(&)EX6QL[73A<R!N96T@;65N=&AE=/4@96PL(&UE
M<G0@;>ER971E(&UE9VAA;&%D:F$@82`B"B)M96=E;F=E9&5T="!M87AI;75M
M;W0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS,B!L:6(O
M2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET
M92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP
M.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB3F5M('1A;.%L:&%T\R!A>B!A('!R
M;V=R86T@82!S>F5R=F5R96XL(&%M:2!S>OQK<^EG97,@96YN96L@87H@861A
M='3M<'5S;F%K("(*(B@E<RD@82!M96=J96QE;NUTZ7/I:&5Z+B(*"B,Z(&QI
M8B]&:6QE+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(D%Z(&ED
MZ7KU:F5L(&MA<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT97(@;&5H970N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB
M"FUS9W-T<B`B2F]B8B#I<R!B86P@;VQD86QO;B!L96=Y96X@:V5R970B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B
M0W-A:R!J;V)B(&]L9&%L;VX@;&5G>65N(&ME<F5T(@H*(SH@;&EB+T9I;&4O
M0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@
M<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B07H@96QVX6QA<WIT\R!K87)A
M:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(D$H>BD@7"(E<UPB('-Z97)V97)T('3V<O9L=/QK+B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")!*'HI
M(%PB)7-<(B!S>F5R=F5R="!E;&UE;G1E='3\:RXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(E<R!B96IE
M;&5N=&ME>NES:2!KZ7)E;&WI="!T]G+V;'3\:RXB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")!(&UE9V%D;W1T('-O<B`H)60I(&YE;2!LZ71E>FEK+B(*"B,Z
M(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B02AZ*2!<(B5S7"(@:61E:6=L96YE<R!FX6IL(&YE;2!LZ71E>FEK+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`V"FUS9VED(")4:&4@=&5X="!Y
M;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E
M96XN(@IM<V=S='(@(D$@8F7M<G0@<WKV=F5G(&YE;2!E9WEE>FEK(&$@:^EP
M97)N>?5N(&QE=O5V96PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B06QU;"#I<R!F]FS\;"!L96=Y96X@
M:V5R970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R
M(")#<V%K(&9E;G0@;&5G>65N(&ME<F5T(@H*(SH@;&EB+TAO<F1E+T1A=&$N
M<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN
M8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(D$@9F5L=/9L=/9T="!A
M9&%T;VL@87H@96SU>O4@;.EPZ7,@\W1A(&5L=F5S>G1E:RXB"@HC.B!L:6(O
M2&]R9&4O1&%T82]C<W8N<&AP.C(V,B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP
M.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A
M=F5D+B(*;7-G<W1R(")!(&9E;'3V;'3V='0@9N%J;'0@;F5M('-I:V5R_&QT
M(&5L;65N=&5N:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(D$@=V5A=&AE<BYC;VT@8FQO:VL@;F5M(&AA<WINX6QH873S+B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D$@
M;65G:F5L96[I<VD@<W3M;'5S("AT:&5M97,I(&%L:_9N>79TX7(@7"(E<UPB
M(&YE;2!T86SA;&AA=/,N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ
M-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS
M9W-T<B`B3FEN8W-E;B!VX6QA<WIT:&%T\R!O<&-I\RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R92!A<F4@;F\@
M<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B
M3FEN8W,@82!L97;I;"!B96QS96KI8F5N(&UE9VIE;&5N[71H973U(&UE;&SI
M:VQE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB
M5/IL('-O:R!K87)A:W1E<B!V86X@96)B96X@82!M97KU8F5N+B#6;B`E<R!K
M87)A:W1E<G0@861O='0@;65G.R!A("(*(FUA>&EMX6QI<V%N(&UE9V%D:&%T
M\R!P961I9R!K979E<V5B8BP@;6EN="`E<RXB"@HC.B!S:6=N=7`N<&AP.C4S
M(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E
M<R(*;7-G<W1R(")<(B5S7"(@9F5L:&%S>F[A;/-N86L@82!R96YD<WIE<FAE
M>B!A9.%S86MO<B!H:6)A('3V<G3I;G0N("5S(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`B7"(E<UPB(&9E;&AA<WINX6SS(&%D871A:6YA:R!T
M]G)LZ7-E('-O<N%N(&AI8F$@;.EP971T(&9E;#H@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S
M='(@(EPB)7-<(B!R96YD<WIE<F+U;"!V86SS('3V<FSI<V5K;W(@:&EB82!L
MZ7!E='0@9F5L.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S
M7"(Z("5S(@IM<V=S='(@(EPB)7-<(B!M\V1O<^UTX7-A('-O<N%N(&AI8F$@
M;.EP971T(&9E;#H@)7,B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T
M<B`B(@HB07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F
M96QT]FQT96YI+B`E<R!N96T@=/9L=/5D]G1T(&9E;"XB"@HC.B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE
M("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(D%Z(.%L;&]MX6YY="!N96T@<VEK
M97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@)7,@;F%G>6]B8BP@;6EN
M="!A("(*(FUA>&EMX6QI<V%N(&UE9V5N9V5D971T(&WI<F5T("@E9"!BX6IT
M*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M(@IM<V=S='(@(B(*(D%Z(.%L;&]MX6YY="!N96T@<VEK97+\;'0@82!S>F5R
M=F5R<F4@9F5L=/9L=&5N:2X@02AZ*2`E<R!FX6IL;F%K(&-S86L@96=Y("(*
M(G+I<WIE('3V;'3U9/9T="!F]FPN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D$@;&5VZ6P@
M92!RZ7-ZZ6YE:R!M96=J96QE;NUTZ7-E:V]R(&AI8F$@=/9R=.EN="(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")!
M('!A<G1N97(@861A=&]K(&EM<&]R=.%LX7-A('-O<N%N(&AI8F$@=/9R=.EN
M="XB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB
M"FUS9W-T<B`B07H@:4-A;&5N9&%R(&%D871O:R!I;7!O<G3A;.%S82!S;W+A
M;B!H:6)A('3V<G3I;G0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX
M,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER
M960@9FEE;&0N(@IM<V=S='(@(B(*(DAI8N%S(&$@;65G861O='0@:V]N9FEG
M=7+A8VGS+B!,96AE="P@:&]G>2!N96T@=/9L=/9T="!K:2!E9WD@<WK\:W/I
M9V5S("(*(FUE>O5T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)!('!A<G1N97)J
M96=Y>NEK:V5L(&MA<&-S;VQA=&]S(&9E;&%D870@=NEG<F5H86ITX7-A('-O
M<N%N(&AI8F$@;.EP971T(&9E;"X@(@HB2^ER96T@<'+S8N%L:F$@;65G(&OI
M<_5B8BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O
M;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B(@HB2&EB82!T]G)TZ6YT(&$@<&%R=&YE<B!A9&%T86EN86L@9G)I<W/M
M=.ES92!S;W+A;BX@2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D$@:_9R;&5VZ6QL:7-T82!A9&%T
M86EN86L@9G)I<W/M=.ES92!S;W+A;B!H:6)A('3V<G3I;G0N($OI<F5M('!R
M\V+A;&IA(&UE9R`B"B)KZ7/U8F(N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@HB17H@
M87H@24U!4"!S>F5R=F5R(&YE;2!TX6UO9V%T:F$@82!M87!PX6MH;WH@=F%L
M\R!H;WIZX6;I<NES(&UE9V]S>G3A<^%T+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")%>B!N96T@
M=/MN:6L@<WIA8N%L>6]S(')A<B#A;&QO;>%N>6YA:RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B17H@
M;F5M('3[;FEK('-Z86+A;'EO<R!Z:7`@X6QL;VWA;GEN86LN(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,S$*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E
M;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")%>B!N96T@
M=/MN:6L@Z7)VZ6YY97,@:^%R='EA<WKA;6YA:RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB17H@82!M96=H86IT\R!L
M96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\
M;&1J_&YK(&$@(@HB0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!S>F]L9^%L=&%T\VX@X70N(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M(D5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@2%144"UK87!C
M<V]L871O;B!335,M="!K_&QD:OQN:R!A(%=)3B`B"B(H:'1T<#HO+W=I;G!L
M8RYC;VTI('-Z;VQGX6QT873S;B#A="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@
M*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@HB17H@82!M96=H86IT\R!L96AE=/5VZ2!T
M97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&%Z
M("(*(G-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI('-Z;VQGX6QT
M873S;B#A="XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L
M>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L
M>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)%>B!A(&UE9VAA
M:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y(%--5%`M:V%P8W-O;&%T;VX@4TU3
M+70@:_QL9&K\;FL@5F]D869O;F4@(@HB<WKA;6]K<F$@82!6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I('-Z;VQGX6QT873S;B#A="X@02`B
M"B)S>F]L9^%L=&%TX7,@:6?I;GEB97;I=&5LZ6AE>B!6;V1A9F]N92!)=&%L
M>2!E;6%I;"!C[6T@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C$@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$P.3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3D@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C`*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$U-C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$X-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P,#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S,@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3,*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,3(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(T-30*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(V-#$@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,30@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,C,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,X,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,3<*;7-G:60@
M(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(D5Z(&$@;65Z]2!N
M96T@;6%R861H870@_')E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V
M.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S
M+B(*;7-G<W1R(")%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@
MX6QL:&%T;F%K+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(P"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE
M(&-O;&]N+B(*;7-G<W1R(")%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S
M>N%M;VL@Z7,@:V5T=/5S<&]N="!L96AE="XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B16)B96X@82!M97KU8F5N(&-S86L@
M;VMTX6QI<R!S>N%M;VL@X6QL:&%T;F%K+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B
M"B)%>B!A(&UE>O4@8W-A:R!V97-S>O5V96P@=F%G>2!S>O-K]GIZ96P@96QV
MX6QA<WIT;W1T(&5GZ7-Z('-ZX6UO:V%T("(*(G1A<G1A;&UA>FAA="(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S
M="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B17H@87H@Z7)TZ6L@8W-A
M:R!S>N%M(&QE:&5T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#(R"FUS
M9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A
M9B<N(@IM<V=S='(@(D5B8F5N(&$@;65Z]6)E;B!H97AA9&5C:6WA;&ES(%)'
M0B!S>NUN:_-D(.%L;&AA="P@<&PN("<C,3(S-&%F)RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D5Z96X@861A=&]K:V%L(&MA<&-S
M;VQA=&]S(&9E;&%D871O:V%T(&$@<WIE<G9E<B!MX7(@96QVZ6=E>G1E+B(*
M"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(D5Z("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI
M<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O
M8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U
M;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@
M;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S
M(@IM<V=S='(@(B(*(D5Z(&5G>2!+;VQA8B!'<F]U<'=A<F4@;V)J96MT=6TN
M($%Z(&EL>65N(&]B:F5K='5M(&UE9VIE;&5N[73I<^EH97H@;VQY86X@(@HB
M96UA:6P@:VQI96YS<')O9W)A;2!S>OQK<^EG97,L(&%M96QY(&OI<&5S(&$@
M2V]L86(@1W)O=7!W87)E(&9O<FWA='5M("(*(FME>F5LZ7/I<F4N($EL>65N
M(&5M86EL(&ML:65N<V5K(&QI<W3A:F$@;.%T:&%T\R!I='0Z("5S(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T
M97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B17IT
M(&$@;&5V96QE="!MX7,@:V%R86MT97)KZ7-Z;&5T=&5L("@E<RD@[7)TX6LL
M(&UI;G0@86UI="#6;B!H87-Z;N%L+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92XB"FUS9W-T<B`B17H@82!S>N%M(&YE;2!L96AE="!E9WENZ6P@:VES
M96)B+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I
M9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@
M9FEL97,N(@IM<V=S='(@(D5Z(&$@<WIE<G9E<B!N96T@:^EP97,@:VEB;VYT
M86YI(&$@>FEP(&EL;"X@9WII<"#A;&QO;>%N>6]K870N(@H*(SH@;&EB+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B17H@82!R96YD<WIE<B!J
M96QE;FQE9R!I;F%K=&EVX6QV82!V86XN(@H*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E
M<BXB"FUS9W-T<B`B17H@87H@Z7)TZ6L@8W-A:R!S>N%M(&QE:&5T+B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<B"FUS9W-T<B`B17IT(&%Z(&%B;&%K(&-S86L@87H@3W!C:?-K(&%B;&%K
M8O-L(&CM=FAA=/,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-0IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")6:6QLX6ULX7,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K
M971S(@IM<V=S='(@(DAI8F%B96IE;&5N=.ES+6ME>F5LZ7,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B263U(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G
M<W1R(")-=6YK86ED]2UN>6EL=N%N=&%R=.%S(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("))9/4@9F]R
M;>%T=6TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S-0IM<V=I9"`B5&EM
M92!S96QE8W1I;VXB"FUS9W-T<B`B263U(';A;&%S>G3A<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1I;6]R+4QE<W1E(@IM<V=S='(@(DME;&5T+51I;6]R(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I='5L=7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED
M(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(D/M;2`H=&]O;'1I<"DB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B
M5&\B"FUS9W-T<B`B0^UM>F5T="(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L
M92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N
M9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(DAA
M('3V8F(@96QE;65T(&ES(&MI(&%K87(@:F5L]FQN:2P@=&%R='-A(&QE;GEO
M;79A(&$@0V]N=')O;"`H4$,I('9A9WD@82`B"B)#;VUM86YD("A-86,I(&)I
M;&QE;G1Y^W0@82!K871T:6YTX7,@:_9Z8F5N+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DUA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(DA434P@9F]R
M<N%S;NEZ970@:VDO8F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*
M;7-G<W1R(")(;VQN87`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(F;V;/QL(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P
M(&9R86UE("A?=&]P*2(*;7-G<W1R("),96=F96QS]2!F<F%M92`H7W1O<"DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T
M:6]N<R(*;7-G<W1R(")&;W)D[73A<V]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@
M86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"#I<R!4;V)A9V\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U92!O<B!F86QS92(*
M;7-G<W1R("))9V%Z('9A9WD@:&%M:7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")+
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5NZ7II82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U<FME>2(*;7-G<W1R(")4]G+V:V]R<WKA9R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*
M;7-G<W1R(")T]G+V:R`H25-/+3@X-3DM.2DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N
M:7-T86XB"FUS9W-T<B`B5/QR:VUE;FES>G3A;B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<RT@Z7,@0V%I8V]S
M+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*
M"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H
M;VEC93H@(@IM<V=S='(@(LUR:F$@8F4L(&UI="!VX6QA<WIT;W1T.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N
M(&EN9&5X.B`B"FUS9W-T<B`B558@:6YD97@Z("(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C
M<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*(E523"P@
M;65L>65N(&5G>2!P<F]G<F%M(&5L9F]G861J82!A('-Z;VQGX6QT873S(.%L
M=&%L(&O\;&3V='0@:_QL9/9T="`B"B)KZ7IB97/M=.ES:2!J96QE;G3I<W0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW
M"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B
M"FUS9W-T<B`B56=A;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5
M:W)A:FYA(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L
M92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5M('-I:V5R
M_&QT(&$@5D93(&%L:_9N>73A<F)A(&)E;.EP;FDN(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R
M82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B
M(@HB02!B96IE;&5N=&ME>NES:2!J;V=O<W5L='/A9R!I9^EN>6SI<V5K;W(@
M;F5M('-I:V5R_&QT(&%Z(&%D871O:R!E;'3A<F]LX7-A+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*(DYE;2!S:6ME<OQL="!A*'HI(%PB)7-<(B!61E,@9N%J;"!E;.ER
MZ7-I(&IO9V]S=6QT<^%G86ET(&UE9W;A;'1O>G1A=&YI+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,SDR(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"B).96T@<VEK97+\;'0@82AZ
M*2`E<R\E<R!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET(&UE9W;A
M;'1O>G1A=&YI+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B
M3F5M('-I:V5R_&QT(&$H>BD@)7,@86QK]FYY=G3A<F)A(&)E;.EP;FDN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B
M02AZ*2!<(B5S7"(@X6QL;VWA;GD@;>ER971E(&YE;2#A;&QA<.UT:&%T\R!M
M96<N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV.34@;&EB+U9&4R]S<6PN<&AP
M.C$P,C@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R(")!*'HI(%PB)7,O)7-<(B#A;&QO;>%N>2!MZ7)E=&4@;F5M
M(.%L;&%P[71H873S(&UE9RXB"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP
M.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB
M"FUS9W-T<B`B07H@4U%,('-Z97)V97(@;F5M(.ER:&5T]2!E;"XB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W
M:71H(%-33"XB"FUS9W-T<B`B07H@4U-,(&MA<&-S;VQA="!N96T@Z7#M=&AE
M=/4@9F5L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,R(&QI8B]61E,O9FEL
M92YP:'`Z,C,W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P-`HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B02!61E,@
M9N%J;"!N96T@;>%S;VQH873S(.%T+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&$H>BD@
M7"(E<UPB(%9&4R!A;&OV;GEV=.%R="!LZ71R96AO>FYI+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,S8Q(&QI8B]61E,O;75S<6PN<&AP.C(U."!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@
M82!61E,@86QK]FYY=G3A<G0N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(").
M96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(%9&4R!FX6IL="XB"@HC.B!L:6(O
M5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E
M<UPB(%9&4R!M87!P82!N96T@:&]Z:&%T\R!LZ71R92XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92XB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@_')E
M<R!61E,@9N%J;'0N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z
M-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")!('3V;?9R[71E='0@
MX6QL;VWA;GET(&YE;2!S:6ME<OQL="!K:6)O;G1A;FDN(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(R."!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B7"(E<UPB(&YE;2!T]G+V;&AE
M=/4L(&%Z(&%L:_9N>79TX7(@;F5M(/QR97,N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T
M<B`B7"(E<UPB('3V<FSI<V4@;F5M('-I:V5R_&QT.B`E<RXB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C,S."!L:6(O5D93+W-Q;"YP:'`Z,SDU(&QI8B]61E,O
M;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B)7,@;F5M('3V<O9L:&5T
M]2P@87H@86QK]FYY=G3A<B!N96T@_')E<RXB"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS-38@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(D$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2!R96MU<GKM
M=F%N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S0T(&QI8B]61E,O;75S<6PN
M<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")!(%9&4R!A
M;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N(@H*(SH@;&EB+U9&4R]S<6PN<&AP
M.C0R,"!L:6(O5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(D$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]3H@)7,N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S
M7"(@5D93(&;A:FP@;F5M('3V<O9L:&5T]2XB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C,Q,"!L:6(O5D93+W-Q;"YP:'`Z,CDQ(&QI8B]61E,O;75S<6PN<&AP
M.C$V-PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#`@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N(@IM<V=S='(@(D$@5D93(&;A:FP@;F5M('3V<O9L:&5T]2XB"@HC.B!L
M:6(O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D$H>BD@
M7"(E<UPB(%9&4R!M87!P82!N96T@=/9R]FQH973U+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(").96T@=NEG97IH
M973S(')E:W5R>NUV('3V<FSI<R!A(%9&4RUB96XZ("5S+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYE;2!H873A<F]Z:&%T\R!M96<@
M82!J96QE;FQE9R#I<G;I;GEE<R!A;&OV;GETX7(N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B02!T86[Z<^UT=N%N>2!R
MZ7-Z;&5T97,@861A=&%I(&YE;2!H873A<F]Z:&%T\VL@;65G(@H*(SH@;&EB
M+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U=&@N<&AP.C$R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N:2`E
M<R!D969I;NUC:?-JX70N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#,@;&EB
M+U9&4R]F:6QE+G!H<#HR,#@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<T"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N(@IM<V=S='(@(D$@5D93(&;A:FP@;F5M(&AE;'EE>FAE
M=/,@X70N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.CDS(&QI8B]61E,O<VUB+G!H
M<#HQ,#8@;&EB+U9&4R]S;6(N<&AP.C8U,@HC.B!L:6(O5D93+V9T<"YP:'`Z
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!61E,@9N%J;"!N96T@
M;GEI=&AA=/,@;65G+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C@T(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*
M;7-G<W1R(")!(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M96<@[7+A<VD@8^EL
M;&%L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z.#,@;&EB+U9&4R]F:6QE+G!H
M<#HQ,S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")!(%9&4R!FX6IL(&YE;2!N>6ET
M:&%T\R!M96<@+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N
M(@IM<V=S='(@(D$@=/9M]G+M=&5T="#A;&QO;>%N>2!N96T@;GEI=&AA=/,@
M;65G+B(*"B,Z(&QI8B]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B02!6
M1E,@9N%J;"!N96T@;VQV87-H873S("AA(&9I;&5S:7IE*"D@<VEK97)T96QE
M;B!V;VQT*2XB"@HC.B!L:6(O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S
M='(@(D$@5D93(&;A:FP@;F5M(&]L=F%S:&%T\R`H82!G971&:6QE4VEZ92@I
M('-I:V5R=&5L96X@=F]L="DN(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B
M"FUS9W-T<B`B17H@82!FX6IL(&YE;2!O;'9A<VAA=/,Z("(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z-C<V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(D$@=F9S<F]O="!A;&OV;GEV=.%R
M(&YE;2!O;'9A<VAA=/,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3`Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@
M)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R
M("(E<R!N96T@;F5V97IH973U(.%T("5S(&[I=G)E.B!MX7(@;.ET97II:R!I
M;'EE;B!N97;[(&UA<'!A(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(D$@5D93(&%L:_9N>79TX7(@;F5M(&YE=F5Z:&5T]2#A="XB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D$@5D93
M(&%L:_9N>79TX7(@;F5M(&YE=F5Z:&5T]2#A=#H@)7,N(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(W,2!L:6(O5D93+V9T<"YP:'`Z,S0X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")!*'HI(%PB)7-<(B!61E,@9N%J;"!N96T@;F5V97IH973U(.%T
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C$W(&QI8B]61E,O;75S<6PN<&AP
M.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R(")!*'HI("5S+R5S(%9&4R!FX6IL(&YE
M;2!N979E>FAE=/4@X70N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,R-B!L:6(O
M5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C(Y,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@
M(D$@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="XB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G
M;6MI<V]F<R<N(@IM<V=S='(@(D%Z("=M:VES;V9S)R!P<F]G<F%M(&YE;2!F
M=71T871H873S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N="(*;7-G<W1R(").96T@<VEK97+\;'0@;&5F;W)D[71A;FD@97IT
M(&$@5V]R9"!D;VMU;65N='5M;W0B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,34T
M(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<
M(B5S7"(@5D93(&;A:FP@;F5M(.UR:&%T\RXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B02!61E,@9N%J;"!N96T@[7)H873S("AA
M(&-O<'DH*2!S:6ME<G1E;&5N('9O;'0I+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,C@X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T-B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D
M871A+B(*;7-G<W1R(")!(%9&4R!FX6IL(&%D871A:2!N96T@[7)H873S:R!K
M:2XB"@HC.B!L:6(O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B
M02!61E,@9N%J;"#M<N%S82!K=O-T873Z;&SI<.ES(&UI871T(&YE;2!F96IE
M>FAE=/4@8F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(F%LX6CZ>F]T
M="(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@
M0VAA;F=E<R(*;7-G<W1R(")-Z6=S92!M96YT<_QK(&5L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5FES<WIA=F]N:F$@87H@
M=71O;'/S(';A;'1O>G1A=.%S="(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,C$@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X.`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O
M;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@HB02!K87!C<V]L870@9F5L=NET
M96SI="!K]G9E=/5E;B!VX7)A=&QA;B!VX6QA<WH@Z7)K97IE='0@82!S>F5R
M=F5R=/5L.B`B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B5N%R871L86X@=N%L87-Z
M(.ER:V5Z971T(&$@<WIE<G9E<G3U;"!E<G)E.B`B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*
M;7-G<W1R(")"97-O<F]L871L86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@
M*%541BTX*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R
M(")%9WEE<_QL="!!<F%B($5M[7)SZ6=E:R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI
M;F=D;VTB"FUS9W-T<B`B16=Y97/\;'0@2VERX6QY<^%G(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R(*;7-G<W1R(")%9WEE<_QL="#!;&QA;6]K(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM
M<V=S='(@(D5G>65S_&QT(,%L;&%M;VLL(&MI<V5B8B!K_&QS]2!S>FEG971E
M:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C<X"FUS9VED(")5;FET<R(*;7-G<W1R(")E9WESZ6<B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,CD@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#,P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(DES;65R971L96XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B
M56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("))
M<VUE<F5T;&5N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B27-M
M97)E=&QE;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D$@;65G861O='0@:&5L>2!I
M<VUE<F5T;&5N+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*
M;7-G<W1R("))<VUE<F5T;&5N(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!J96QS
M>O,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M="(*;7-G<W1R(")4X79O;.UT<W5K(&5L(&EN;F5N(&$@;&EN:V5T(@H*(SH@
M;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M960B"FUS
M9W-T<B`B3FEN8W,@96QN979E>G9E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B
M"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)":7IT;VYSX6=I(&]K;VMB\VP@
M82!F96QH87-Z;N%L\VD@<')O9W)A;6]K(&YE;2!H87-Z;N%L:&%T:N%K(&$@
M2VEVX6?A<R\B"B)-X7-O;.%S+T)E:6QL97-Z=.ES(&WS9'-Z97)T+B!+871T
M:6YT<V]N(&%Z($]+(&=O;6)R82P@:&$@82!M;WII;&QA+F]R9R`B"B)W96)O
M;&1A;&]N(&5L(&OM=N%N:F$@;VQV87-N:2!A('1E8VAN:6MA:2!L9>URX7-T
M(&UE;'D@;65G861J82P@:&]G>6%N(&QE:&5T("(*(F5Z="!MZ6=I<R!E;F=E
M9.EL>65Z;FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B
M02!S>NUN('9I<W-Z8>%L;.UTX7-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV.#<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R
M=&5D($5X=&5N<VEO;B(*;7-G<W1R(").96T@=.%M;V=A=&]T="!E>'1E;GII
M\R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B
M3?-D;W/M=.%S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B
M)7,@861A=&%I;F%K(&WS9&]S[73A<V$B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M(")!(&9E;&AA<WINX6SS(&%D871A:6YA:R!M\V1O<^UTX7-A(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!VX6QT;WKA<V%I
M="!E;&UE;G1E='3\:RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B07H@
M=7!G<F%D92!P<F]G<F%M;W0@=/9R]FQT_&LN(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$W."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B1F5L=/9L=.ES(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL
M(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S
M='(@(D%Z(/9S<WIE<R!A;&MA;&UA>N%S(&MO;F9I9W5RX6-I\VKA="!F96QT
M]FQT]G1T_&L@82!S>F5R=F5R<F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@
M;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")L871I;B!N86=Y8F5T^VLB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(FYA9WEB
M973[<R!R\VUA:2!S>N%M;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@
M(E5R=6=U87DB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B
M"FUS9W-T<B`B2&%S>F[A;&IU:R!A(&IE;&5N;&5G:70Z("5S(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-3
M3"(*;7-G<W1R(")(87-Z;N%L:G5N:R!34TPM="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*(D%K:V]R
M(&AA<WINX6QJ=6LL(&AA(&%Z($E-4U`@<WIE<G9E<F5N(&WA<R!A(&)E:F5L
M96YT:V5ZZ7-I(&YE=OQN:R\B"B)J96QS>F%V=6YK+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T
M<B`B1F5L:&%S>F[A;/-I(&[I=B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP
M:'`Z-S<T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(E<R!F96QH87-Z;N%L\R!N96T@
M:F]G;W-U;'0@)7,M<F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED
M(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D9E;&AA<WINX6SS:R!A
M9&UI;FES>G1RX6SA<V$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(T
M-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D9E;&AA<WINX6SS:2!B
M9>%L;.UTX7-O:R(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7,@:F]G;W-U;'1SX6<@
M:6?I;GELZ7-E(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS
M9W-T<B`B(@HB17IE;B!A(')E;F1S>F5R96X@;FEN8W,@96YG963I;'EE>G9E
M(&%Z(/IJ(&9E;&AA<WINX6SS:R!B96IE;&5N=&ME>NES:2`B"B)J;V=O<W5L
M='/A9^%N86L@:6?I;GELZ7-E+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B
M07H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UT\R!N96T@=&%LX6QH873S(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V(&QI8B].970O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C$U,`HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,R!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")&
M96QH87-Z;N%L\VD@;NEV(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!F96QH87-Z;N%L
M\VD@;NEV(&WA<B!LZ71E>FEK+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D9E;&AA<WIN
MX6SS:2!NZ78Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM
M<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")&96QH87-Z;N%L\VD@;NEV.B`B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5
M<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")!(')E;F1S>F5R(&9E;&AA
M<WINX6SS:3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(MQZ8F5G
M:7-Z=.%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-S`@;&EB+U9&4R]F:6QE
M+G!H<#HR-C(*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(D$@5D93(&%L:_9N>79TX7(@;F5M(&SI=&5Z:6LN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`B4WIA8F%D<^%G(&%L871T:2!A=71O;6%T:6MU<R!E;6%I;"UV
MX6QA<WHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#<P"FUS9VED(")686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(D$@:_9V971K
M97KU(&AE;'EE:V5T('1A;.%L='5K.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`BR7)VZ6YY
M97-SZ6<B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")!>B#I<G3I:V5K
M970@<&5R8V)E;B!A9&IU:R!M96<L(&UO<W1A;G3S;"!S>N%M[71V82XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8P(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA
M>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")!(.ER=.EK(&YA9WEO8F(L
M(&UI;G0@82!L96=N86=Y;V)B(&UE9V5N9V5D971T(&AO<W-Z^G/A9SH@)7,N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#@@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R-S`@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,C`*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Y,30@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("+)<G3I:V5K(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.3`*
M;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")6X6QA<WIT
M:&%T\R#I<G3I:V5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU
M871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I
M9"`B5F%R:6%B;&4B"FUS9W-T<B`B=N%L=&]Z\R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z
M=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(B(*(D$@:&ET96QE<^UTZ7,@;F5M('-I:V5R_&QT("T@;&5H970L(&AO
M9WD@82!L979E;&5T('9A;&%K:2!M96=VX6QT;WIT871T82XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G
M<W1R(")697)Z:?,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X
M"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R>FGS:_9V973I
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D;\9V<N
M(&5L:&5L>65ZZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@
M(D;\9V?U;&5G97,@8F5L<_4@;6%R9_,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS
M9W-T<B`B9OQG9_5L96=E<SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(FYA
M9WEO;B!M86=A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N
M86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA
M;65S92`H5DE30TE)*2(*;7-G<W1R(")V:65T;F%M:2`H5DE30TE)*2(*"B,Z
M(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(E<R!M96=T96MI;G3I<V4B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E(@IM<V=S='(@(DO\;'/U('=E8F]L9&%L(&UE9VIE;&5N
M[73I<V4B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B2F5L96[M
M='/\:R!M96<L(&UI;G0@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"(*;7-G<W1R(")"<FET(%9I<F=I;BUS>FEG971E:R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(D%M97)I:V%I(%9I
M<F=I;BUS>FEG971E:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS
M9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(DSA=/-TX79O;'/A9R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI
M='DZ("(*;7-G<W1R("),X73S=.%V;VQSX6<Z("(*"B,Z(&QI8B].970O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET
M86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE($ET86QY('-Z;VQGX6QT
M873A<R!33510+6X@:V5R97-Z=/QL(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S
M='(@(D9)1UE%3$U%6E1%5,E3(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(D9)1UE%3$U%6E1%
M5,E3(2!+R5I:14P@5,%63TS-5%-!($5,($$@4T-225!4150@)7,M4M5,+B(*
M"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V
M:6$@2%144"(*;7-G<W1R(")724X@<WIO;&?A;'1A=.%S($A45%`M;B#A="(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R#I
M<R!&=71U;F$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`B1FEG>65L;65Z=&5TZ7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R
M(")3>F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G
M:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B263U:N%RX7,@96SU<F5J
M96QZZ7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS
M9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B07H@:63U
M:N%RX7-I(&%D871O:R!F;W)RX7-A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET
M92(*;7-G<W1R(")796)H96QY96LB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B:&5T96YT92(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(MQD=O9Z]FQJ_&LB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+<9';V>O9L
M:OQK.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE+"`E<R(*;7-G<W1R("+<9';V>O9L:OQK+"`E<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R(")N>75G870M975R\W!A:2`H25-/+3@X-3DM,2DB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(FYY=6=A="UE=7+S<&%I("A)4T\M.#@U.2TQ
M-2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B3GEU9V%T+5-Z
M86AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_(@IM<V=S='(@(DUI;'EE;B!A;&MA;&UA>N%S="!M
M=71A<W-O;B`E<R!A(&)E:F5L96YT:V5ZZ7,@=73A;C\B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B36D@87H@96QVX6QA<WIT\R!K
M87)A:W1E<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM
M<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")-
M:2!A>B!I9.EZ971K87)A:W1E<C\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`V-`IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@
M;6%P(@IM<V=S='(@(E=H97)E:7,@075S>G1RX6QI82!TZ7)KZ7`B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G
M<W1R(")-96QY:6L@8VEK;'5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")-96QY:6L@;6]D=6QO:V%T(&%K
M=&EVX6QJ=6L@82!2:6-H(%1E>'0@961I=&]R8F%N/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(E-ZZ6QE<W/I9R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,3$Q"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B
M4WKI;&5S<^EG($-34R!E9WESZ6=B96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.B(*;7-G<W1R("(B"B)!("5S(&UE;OP@<WKI;&5S<^EG92!A(&)A;"!O
M;&1A;&]N("AA(&OV=F5T:V5Z]2!B96IE;&5N=&ME>NES="!K]G9E=/5E;B!L
M97-Z("(*(NER=NEN>65S*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B
M"FUS9W-T<B`B02!TX6)LX7IA="!S>NEL97-SZ6=E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H
M('5N:70B"FUS9W-T<B`B02!S>NEL97-SZ6<@;>ER=.EK96=Y<^EG92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS
M9VED(")7:61T:#HB"FUS9W-T<B`B4WKI;&5S<^EG.B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0B
M"FUS9W-T<B`B4WKI;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8W"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E-ZZ6P@
M82!R96=G96QI(/-RX6MB86XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W
M"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E-ZZ6QS96)E
M<W/I9R!C<V]M\V)A;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS
M9VED(")7:6YD.B(*;7-G<W1R(")3>NEL.B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")3>NEL
M.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O
M;2(*;7-G<W1R(")"]FQC<V5S<^EG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B2^UVX6YSX6=L
M:7-T82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R
M:R(*;7-G<W1R(")-=6YK82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B375N:V%H96QY:2!C
M[6TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM
M<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")-=6YK86AE;'EI('1E;&5F;VXB
M"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y,R!L:6(O1FEL92]#4U8N<&AP.C(Y
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B
M02`E9"X@<V]R8F%N(&YE;2!M96=F96QE;/4@82!M97KU:R!S>N%M82X@5N%R
M=#H@)60L('1A;.%L=#H@)60N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@
M17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").96T@;65G9F5L96SU
M(&$@;65Z]6L@<WKA;6$N(%;A<G0Z("5D+"!T86SA;'0Z("5D+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@
M(DAI8N%S(&]F9G-E="`H)60I(&$@5D93(&;A:FP@;VQV87/A<V%K;W(N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B
M"FUS9W-T<B`B3&EN=7@@9F]R<N%S:_-D(&ME<F5S>G)E9F5R96YC:6$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!A;&%P=F5T]2!K
M;W)LX71O>N%S;VLB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8
M-3`Y=C,@:VET97)J97-Z=&5T="!K=6QC<VAA<WINX6QA="(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U,#EV,R!T=6QA:F1O;F]S
M(&%L=&5R;F%T[78@;65G;F5V97KI<V4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(B"FUS9W-T<B`B6#4P.78S('1U;&%J9&]N;W,@:W5L8W-A>F]N;W/M
M=/,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B
M6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S(&MI=&5R:F5S>G3I
M<V5K(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S
M='(@(EE9(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS
M9VED(")965E9(@IM<V=S='(@(EE965DB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G
M<W1R(")986AO;R$@=.ER:^EP(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(NEV96YT92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM<V=S='(@(DEG
M96XB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(DEG96XL(&)E;&5G
M>65Z96TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE
M(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S
M='(@(B(*(DUO<W0@2%1-3"!415A4(&WS9&)A;B!V86XN($AA<WINX6QJ82!A
M(%L\/ET@9V]M8F]T+"!H82!V:7-S>F$@86MA<B!VX6QT86YI(&$@(@HB<WIO
M:^%S;W,@9W)A9FEK=7,@*%=94TE764<I(&UE9VIE;&5N[73I<W)E+B(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(DYE;2!H;WIH870@;.ET
M<F4@)60@8FQO:VMNX6P@=/9B8F5T+B(*"B,Z(&QI8B](;W)D92YP:'`Z,30Q
M-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B
M07H@UFX@9F5L:&%S>F[A;/-A>F]N;W/M=.%S82!N96T@=/9R=.EN="!M96<N
M(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C
M86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N(@IM<V=S='(@(D$@=&5L:F5S(&[I=F)E;B!N96T@<WIE<F5P96QH970@
M82`G7%PG(&MA<F%K=&5R+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4Y
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Y"FUS9VED(")9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DYE;2!A9&]T
M="!M96<@Z7)VZ6YY97,@96UA:6P@8^UM970N(@H*(SH@;&EB+TAO<F1E+T1A
M=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B).
M96T@861T82!M96<@82!M96=F96QE;'1E=.ES="!A>B!I;7!O<G3A;'0@9N%J
M;"#I<R!A*'HI("5S(&UE>O5I(&OV>O9T="XB"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM
M<V=S='(@(E-I:V5R97-E;B!K:6IE;&5N=&ME>F5T="XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(V-0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N
M(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N(@IM<V=S='(@(B(*(D5G>2!M;V)I;'1E;&5F;VYS>N%M;W0@
M:V5L;"!M96=A9&YI82P@8W-A:R!A('-ZX6UJ96=Y96ME="P@97-E=&QE9R!E
M9WD@)RLG("(*(FMA<F%K=&5R<F5L(&ME>F1V92P@:&$@;F5M>F5T:_9Z:2!T
MX7)C<^%ZX7-I(&WS9&]T(&OM=N%N(&AA<WINX6QN:2XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B16QF;V=A9&AA=/,@Z7)TZ6ME="!K96QL
M(&UE9V%D;FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(D$@1&%T851R964@86QR96YD
M<WIE<G0@8F4@:V5L;"#A;&SM=&%N:2!A(&)E:F5L96YT:V5ZZ7-I(&IO9V]S
M=6QT<^%G;VL@(@HB:6?I;GELZ7/I:&5Z+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M-#8R"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB
M"FUS9W-T<B`B02!61E,@86QR96YD<WIE<B!N:6YC<R!B9>%L;.UT=F$N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)%;/5B8B!L92!K
M96QL(.UR;FEA+"!H;V=Y(&UI;'EE;B!P<F]B;.EMX70@=&%P87-Z=&%L="P@
M;6EE;/5T="!E;&O\;&1I(&$@(@HB:&EB86IE;&5N=.ES="XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9
M;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@
M=&\B"FUS9W-T<B`B365G(&ME;&P@861N:2!E9WD@55),+70L(&%H;W9A(&5Z
M(&$@;&EN:R!M=71A="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(DMI(&ME;&P@=N%L87-Z=&%N:2!E9WD@=/9R;&5N
M9/4@<WIE<G9E<G0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G
M<W1R(")-96<@:V5L;"!A9&YI82P@:&]G>2!M96QY:6L@9F5L:&%S>F[A;/,@
M861A=&%I="!K[7;A;FIA('3V<O9L;FDN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+B(*;7-G<W1R(")-96<@:V5L;"!A9&YI82!A>B!E;'3A=F]L[71A;F3S
M(&9E;&AA<WINX6SS:2!N979E="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B365G
M(&ME;&P@861N:6$@82!H;WIZX6%D86YD\R!F96QH87-Z;N%L\R!N97;I="XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B365G(&ME;&P@
M861N:6$L(&AO9WD@;65L>6EK(&9E;&AA<WINX6SS(&%D871A:70@:^UVX6YJ
M82#A=.UR;FDN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(DUE9R!K96QL(&%D;FEA(&5G>2!P87)A;F-S;W0N(@H*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G
M:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T
M<B`B365G(&ME;&P@861N:6$@87H@^FH@:V%T96?S<FEA(&YE=NET+B(*"B,Z
M(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@
M(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B
M"FUS9W-T<B`B3VQA<WIO<G-ZX6=I('1E;&5F;VYS>N%M;W0@:V5L;"!M96=A
M9&YI82(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D%Z(-9N("5S(&MA<&-S;VQA=&$@
M:63U=/IL;.EPZ7,@;6EA='0@;65G<WIA:V%D="X@2^ER96T@:F5L96YT:V5Z
M>F5N(&)E(/IJ<F$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")!>B#6
M;B!E;6%I;"!C[6UE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM
M<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")!>B#6;B!F96QA
M9/-I("A&<F]M.BD@8^UM93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO
M=7(@26YF;W)M871I;VXB"FUS9W-T<B`B4WIE;>EL>65S(&EN9F]R;>%C:?,B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B(@HB07H@UFX@)7,@:V%P8W-O;&%TX6YA:R!K97ID971E(/-T82!M
M96=VX6QT;WIO='0@87H@:6YT97)N970@8^UM92X@(@HB0FEZ=&]N<^%GX6YA
M:R#I<F1E:^EB96X@:7-MZ70@8F4@:V5L;"!J96QE;G1K97IN:64N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@
M3F%M92(*;7-G<W1R(")!>B#6;B!N979E(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(D%Z(-9N(&9E;&AA<WINX6SS
M87IO;F]S[73S(&%L<F5N9'-Z97)E(&YE;2!T97-Z:2!L96AE=/5VZ2!A>B#Z
M:B!F96QH87-Z;N%L\VL@(@HB;.ET<F5H;WKA<^%T+B!(82!A($AO<F1E(')E
M;F1S>F5R<F5L(&OM=N%N:F$@:V5Z96QN:2!A(&9E;&AA<WINX6SS:2`B"B)A
M9&%T;VMA="P@86MK;W(@;>%S:6L@9F5L:&%S>F[A;/-A>F]N;W/M=/,@86QR
M96YD<WIE<G)E('9A;B!S>OQK<^EG92XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB07H@UFX@9F5L:&%S>F[A;/-A>F]N
M;W/M=/,@86QR96YD<WIE<F4@;F5M('1E<WII(&QE:&5T]7;I(&$@9F5L:&%S
M>F[A;/-K("(*(FQI<W3A>N%SX70L('9A9WD@=F%L86UI(&]K8O-L(&QE=&EL
M=&]T=.%K(&5Z="!A(&QE:&5T]7/I9V5T+B(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)!>B#6;B!B
M]FYGZ7-Z]7!R;V=R86UJ82!M96=VX6QT;WIO='0@87H@UFX@)7,@;75N:V%K
M87!C<V]L873A;F%K(&ME>F1E=&4@(@HB\W1A+B!":7IT;VYSX6=A(.ER9&5K
MZ6)E;B!I<VWI="!B92!K96QL(&IE;&5N=&ME>FYI92XB"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HU-0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")!>B#6;B!B]FYGZ7-Z
M]7!R;V=R86UJ82!N96T@=.%M;V=A=&IA(&5Z="!A(&QE:&5T]7/I9V5T+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB
M"FUS9W-T<B`B(@HB07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;F5M('3A;6]G
M871J82!E>G0@82!N>6]M=&%TX7-I(&]P8VGS="X@4'+S8N%L:F]N(&$@(@HB
M0W1R;"U0("AV86=Y($-O;6UA;F0M4"D@;&5N>6]MX7/A=F%L(&YY;VUT871N
M:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")!(&IE;&5N;&5G(.ER=NEN
M>65S(&ED]7KS;F$Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM
M<V=S='(@(D%Z(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT
M\VIA(&UE9W;A;'1O>F]T="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(D%Z
M(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\VIA.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N
M86UE.B(*;7-G<W1R(")!>B#6;B!T96QJ97,@;F5V93HB"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+B(*;7-G<W1R("),96KA<G0@82!B96IE;&5N=&ME>NES:2!J;V=O<W5L='/A
M9V$N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E
M<R(*;7-G<W1R(")!>B#6;B`E<RUR92!H87-Z;N%L="#Z:B!J96QS>F%V83H@
M)7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")!>B#6;B#Z:B!B9>%L;.UTX7-A
M:70@Z7)VZ6YY97/M=&5T=/QK(&$@;6]S=&%N:2!B96IE;&5N=&ME>NES(&ED
M96KI<F4N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B07H@
MUFX@^FH@8F7A;&SM=.%S86ET(&5L;65N=&5T=/QK+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T(@IM<V=S='(@(D%Z(-9N(&IE;'-Z87;A="#A=.%L;.UT
M;W1T=6LB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I
M9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N
M(@IM<V=S='(@(B(*(D%Z(-9N(&IE;'-Z87;A="#A=.%L;.UT;W1T=6LL(&[I
M>GIE(&UE9R!A(&QE=F5L96ET+"!M86ID(&IE;&5N=&ME>GIE;B!B92!A>B`B
M"B+Z:B!J96QS>O-V86PN(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<S,PIM
M<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B07H@
MUFX@:F5L<WIA=N%N86L@;&5JX7)T(&%Z(.ER=NEN>65S<^EG:2!I9&5J92XB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO
M=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(D%Z(-9N(.%L=&%L(&AA<WIN
MX6QT('3A=F]L:2!S>F5R=F5R96LZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU
M9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-Z;.%V:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@
M(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");3F4@;75T87-S=6L@82!B
M96EDZ7IE='0@<WKV=F5G971=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6TAI8F%J96QE
M;G3I<UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");375T
M87-S=6L@82!B96EDZ7IE='0@<WKV=F5G970@+2(*"B,Z(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G
M<W1R(");375T87-S=6L@82!B96EDZ7IE='0@<WKV=F5G970@+2`E<R!S;W)=
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(ELE<R\E<R!S;W)=(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*
M;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<WIT<N%C
M:?,B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M7U!A<F%N8W-S;W(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A
M5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM
M<V=S='(@(E-O<G3V<FSI<R(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B
M7T=R;W5P<R(*;7-G<W1R(")?0W-O<&]R=&]K(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B4V5?9^UT<^EG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")!
M(&OI<"!T=6QA:F1O;G/A9V%I+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP
M.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")"96IE;&5N=&ME>NES(@H*
M(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS
M9W-T<B`B7TMI:F5L96YT:V5ZZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@
M3&EN:RXN+B(*;7-G<W1R(")!(&QI;FL@;?-D;W/M=.%S82XN+B(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@
M(E]/<&-I\VLB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S
M:6]N<R(*;7-G<W1R(")?2F]G;W-U;'1SX6=O:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B
M7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(D$@;&EN:R!T]G)LZ7-E+BXN(@H*
M(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7T)E
MX6QL[73A<V]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")4X6)LX7IA="!T=6QA:F1O;G/A9V]K(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7T9E;&AA<WINX6SS
M:R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B8^UM:F5G>7KI:R(*"B,Z(&QI8B](;W)D92]-24U%
M+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS
M9W-T<B`B82!C[6UZ971T(&ES;65R971L96XB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDQ-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B;F%P=.%R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")N>75G
M;V1T(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED
M(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(F$@:VEM96YE
M=&D@X6QL;VWA;GD@;F5M(&AO>FAA=/,@;.ET<F4B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T
M(@IM<V=S='(@(F$@8F5M96[U(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"FUS9VED(")C
M;&EC:R!H97)E(@IM<V=S='(@(FMA='1I;G1S;VX@:61E(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(B"FUS9W-T<B`B<&%R86YC<W-O<FD@:&EB82(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A
M=&EO;B!E<G)O<B(*;7-G<W1R(")K;VYF:6=U<N%C:?-S(&AI8F$B"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B:&GA;GEZ:6L@96=Y(&9O
M;G1O<R!R96YD<WIE<N%L;&]MX6YY(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R
M(")A9&%T9F]R;>%T=6T@:&EB82(*"B,Z('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B;?-D;W/M=.%S(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N
M;W0@9F]U;F0B"FUS9W-T<B`B87H@861A="!N96T@=&%LX6QH873S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@
M(F9A;&QI;F<B"FUS9W-T<B`B8W/V:VME;B(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HX.3@*;7-G:60@(F9I;&4B"FUS9W-T<B`B9N%J;"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A<BYP:'`Z,S8W
M(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@
M(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B)7,@*"5S*2!I
M<N%N>6+S;"P@)7,@)7,@<V5B97-SZ6=G96PB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(G-Z
MZ6QL]FOI<V5K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B;3HB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@
M(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(F$@9^EP(&YE=F4@;F5M(&ES
M;65R="(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM
M;65D:6%T92(*;7-G<W1R(")A>F]N;F%L:2(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI
M;F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B:6YP=70O
M;W5T<'5T(&AI8F$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(F)E
M;'/U('!R;V=R86UH:6)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")S;W)=(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N(@IM<V=S='(@(B(*(D%Z(&UK<VEO9G,@<')O9W)A;2`E9"!H:6)A
M:_-D9&%L(&QEX6QL="!A>B!)4T\@X6QL;VWA;GD@:^ES>NUTZ7-E(&OV>F)E
M;BXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P
M"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS
M9W-T<B`B;NEV(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z,3(T"FUS9VED(")N
M;W0@:6UP;&5M96YT960B"FUS9W-T<B`B02!P<F]G<F%M;F%K(&5Z(&$@<NES
M>F4@;>EG(&YI;F-S(&UE9W9A;/-S[71V82XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B
M"FUS9W-T<B`B02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE
M9W9A;/-S[71V82XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP.0IM<V=I
M9"`B;F]T97!A9"(*;7-G<W1R(")J96=Y>F5T=/9M8B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@
M(G!E<F-E;G0B"FUS9W-T<B`B<WKA>F%LZ6LB"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM
M<V=S='(@(FYI;F-S(&UE9V9E;&5L]2!J;V=O<W5L='/A9V$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS
M9VED(")P:7AE;',B"FUS9W-T<B`B<&EX96PB"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;"(*;7-G<W1R(")A9&%TX71V:71E;&D@*'!R;W1O:V]L;"D@:&EB82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS
M9VED(")R:7-I;F<B"FUS9W-T<B`B96UE;&ME9&EK(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA
M8FQE(@IM<V=S='(@(F$@<WIO;&?A;'1A=.%S(&YE;2#A;&P@<F5N9&5L:V5Z
MZ7-R92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q"FUS9VED(")S
M:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(F[I>GK\:R!M96<@82!K_&SV;F)S
MZ6=E:V5T(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I
M;"!S>F]L9^%L=&%TX7,@2%144"UN(.%T(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G
M:60@(G-T96%D>2(*;7-G<W1R(")VX6QT;WIA=&QA;B(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM
M<V=S='(@(G)E;F1S>F5R:&EB82(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B9F5L861A=&QI<W1A(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP
M;W)A<GD@9F%I;'5R92(*;7-G<W1R("+A=&UE;F5T:2!H:6)A(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*
M;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS
M9W-T<B`B;65G97+U<^UTZ7-KZ6YT(&OI='-Z97(@[7)J82!B92!A(&IE;'-Z
M\W0B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R
M(")NZ78@;NEL:_QL(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM
M<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B82!F96QH87-Z;N%L\R#A;'1A
M;"!VX6QA<WIT:&%T\R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB
M"FUS9W-T<B`B<WHZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:61?240N<&\`````````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8W,#$S,P`Q,#0Q
M-S,V,S`P,0`P,38S-#0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!(;W)D92`M($EN9&]N97-I86X@3&%N9W5A9V4@5')A
M;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($IA;65S(#QJ86UE<T!A8W1I
M;VYM97-S86=E+F-O;3XL(#(P,#4N"B,*(RP@9G5Z>GD*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(#(P,#4M,#@M,#-<;B(*(E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)0
M3U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)0
M3RU2979I<VEO;BU$871E.B`R,#`U+3`X+3`T(#`Y.C$P*S`R,#!<;B(*(DQA
M<W0M5')A;G-L871O<CH@2F%M97,@/&IA;65S0&%C=&EO;FUE<W-A9V4N8V]M
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@:60@/&ED0&QI+F]R9SY<;B(*(DU)344M
M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]55,M05-#24E<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#=B:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,W,PHC+"!F=7IZ>0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B2&%R:2!);FDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U
M"B,L(&9U>GIY"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R(")"97-O:R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S
M=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*
M;7-G<W1R("(@<&%D82`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&)E;'5M(&1I8G5A=#H@
M)7,N(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U
M<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R
M(")<(B5S7"(@<W5D86@@9&ET86UB86AK86X@:V4@9&%L86T@<VES=&5M(&=R
M=7`N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I
M;VYS('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB('-U9&%H(&1I=&%M8F%H:V%N
M(&ME(&1A;&%M(&EZ:6X@<VES=&5M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<
M(B5S7"(@8F5L=6T@9&EB=6%T.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@
M)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"('-U9&%H
M(&1I9W5N86MA;B!D87)I("4N,F9-0B!Y86YG('-U9&%H(&1I:6II;FMA;B`H
M)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D
M("5S(&1A;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM
M<V=S='(@(B5D(&AA<FD@<V%M<&%I('-A;F1I(&%N9&$@:&%B:7,@;6%S82!B
M97)L86MU;GEA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S
M='(@(B5D+6AA<FD@<F%M86QA;B!C=6%C82(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC
M92(*;7-G<W1R("(E<R`M(%!E;6)E<FET86AU86XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(DMO;F9I<FUA<VD@+2!/<&5R87-I(%!E
M;65L:6AA<F%A;B`E<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3971U<"(*;7-G<W1R("(E<R!3971U<"(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R
M965M96YT(@IM<V=S='(@(B5S(%-Y87)A="US>6%R870@4&5R:F%N:FEA;B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!P861A("5S("5S
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*
M(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@<VEA<"!U;G1U:R!M96QA
M:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X@>6%N9R!S=61A:"!D:71A
M;F1A:2!D:2!B87=A:"`B"B)I;FDN($)E<FEL86@@=&%N9&$@<&%D82!K;W1A
M:R!T97)S96)U="!U;G1U:R!O<&5R87-I(&UA;F%P=6X@>6%N9R!A;F1A("(*
M(FEN9VEN:V%N('5N='5K(&1I;&%K<V%N86MA;B!P861A('=A:W1U(&EN:2XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI
M;G5T97,B"FUS9W-T<B`B)7,@;65N:70B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(E1I9&%K(&%D82!I:V]N
M('EA;F<@9&ET96UU:V%N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B
M"FUS9W-T<B`B)7,@=6YT=6L@)7,@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B0G5K=2!!;&%M870@(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S("T@4&5M
M8F5R:71A:'5A;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"B,L
M(&9U>GIY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@86YG:6X@:V5N
M8V%N9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E
M<R`E<R(*;7-G<W1R("(L(&%N9VEN(&ME;F-A;F<@)7,@)7,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A
M<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V87)I86)L92!D87)I
M("5S(&ME("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S
M='(@(D9O<FUA="`Q,B!*86TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*
M;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA="`R-"!*86TB
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U
M<G,B"FUS9W-T<B`B,C0@:F%M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R
M+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(DQI
M:&%T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS
M9W-T<B`B1&%T86)A<V4@8F%C:V5N9"!D:7!E<FQU:V%N('5N='5K(&%R96$@
M:6YI+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P"FUS9VED
M(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS
M9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T
M"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G
M<W1R(")!32!-96YD=6YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B
M04T@1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(D%-($AU:F%N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G
M:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B04T@1V5R:6UI<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B04T@1V5R:6UI<R!386QJ=2(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@
M(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(E1E;G1A;F<@961I=&]R(&EN
M:2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U
M="XN+B(*;7-G<W1R(")496YT86YG+BXN("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*
M;7-G<W1R(")*87)A:R!A;G1A<F$@8F%G:6%N(&)A=V%H(&)A<FES(&1E;F=A
M;B!B86=I86X@8F%W86@@9V%M8F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S
M='(@(DIA<F%K(&%N=&%R82!B86=I86X@=&5N9V%H(&)A<FES(&1E;F=A;B!B
M86=I86X@=&5N9V%H(&=A;6)A<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M87-I($%C8V]U;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G
M:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B4V%N9&D@06-C;W5N="(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@
M(DEN9F]R;6%S:2!!8V-O=6YT(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")!:W5N=&%N<VDB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")486UB86@B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R
M-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(E1A;6)A:"!'<G5P
M($%N86LB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(E5B86@@27II;B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B5&%M8F%H($1I<VEN:3HB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U
M<"(*;7-G<W1R(")486UB86@@1W)U<"!"87)U(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@X"B,L(&9U>GIY"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B56)A:"!)>FEN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(E1A;6)A:"!G<G5P
M(&%N86L@:V4@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")486UB86@@9W)U<"!A
M;F%K(&ME("<E<R<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D
M(&$@;F5W('5S97(Z(@IM<V=S='(@(E1A;6)A:"!P96YG9W5N82!B87)U.B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B4&ES86AK86X@
M:V]L;VTB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T
M"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B5&%M8F%H(&%N9V=O
M=&$@8F%R=2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G
M:60@(D%D9"!P86ER(@IM<V=S='(@(E1A;6)A:"!P87-A;F=A;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@
M(E1A;6)A:"!-96YU("5S('-E8F%G86D@4&%N96P@;F%V:6=A<VD@36]Z:6QL
M82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T
M<B`B0G5K=2!!;&%M870@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D
M<F5S<R!B;V]K(@IM<V=S='(@(D)U:W4@06QA;6%T("(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")486UB86@@<&5N
M9V=U;F$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U
M="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N
M.B`B"B(E<RXB"FUS9W-T<B`B(@HB("<E<R<@<W5D86@@9&ET86UB86AK86X@
M:V4@9&%L86T@<VES=&5M+"!T971A<&D@=&ED86L@9&%P870@;65N86UB86AK
M86X@(@HB:6YF;W)M87-I('!E;F1A9G1A<F%N('1A;6)A:&%N.B`E<RXB"@HC
M.B!S:6=N=7`N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W
M+B(*;7-G<W1R("(@)R5S)R`@<W5D86@@9&ET86UB86AK86X@:V4@9&%L86T@
M<VES=&5M+B!!;F1A(&1A<&%T(&QO9R!I;B!S96MA<F%N9RXB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")096YA;6)A:&%N('!E;F=G=6YA
M('1I9&%K(&1I86MT:69K86XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M-#$*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B0G5K=2!!;&%M
M870@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B
M061D<F5S<R!";V]K(@IM<V=S='(@(D)U:W4@06QA;6%T("(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"B,L(&9U>GIY"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R(")58F%H(&EZ:6X@=6YT=6L@)7,B"@HC.B!A9&UI;B]I
M;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM
M<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R87-I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I9"`B061S(@IM
M<V=S='(@(DEK;&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*(RP@
M9G5Z>GD*;7-G:60@(D%L:6%S(@IM<V=S='(@(E)A=&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED
M(")!;&EG;B(*;7-G<W1R(")2871A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G
M<W1R(")097)A=&%A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(E-E;75A(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B4V5M
M=6$@4&5N9V=U;F$@07-L:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M
M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B
M4V5M=6$@1W)U<"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0HC+"!F
M=7IZ>0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ:6XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")396UU82!E;7!A
M="!S:7-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(DEZ:6YK86X@<&5N9V%T
M=7)A;B!D87)I('1I<&4@9&%F=&%R(&YO;6]R(&)E<G5R=70_(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!
M;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R
M(")096YG9V%N=&D@3&]G:6X@24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S
M='(@(E!E;F=G86YT:2!386YD:2!)35-0(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B4&5N9V=A;G1I($YA;6$@4&5N9V=U;F$@24U34"(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA
M:6P@861D<F5S<R(*;7-G<W1R(")096YG9V%N=&D@86QA;6%T(&5M86EL(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T
M96UP;&%T97,B"FUS9W-T<B`B4&5N9V=A;G1I('1E;7!L871E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B4&5N9V=A;G1I
M('1E:W,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"FUS9VED(")!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N
M9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R
M(")*87=A8F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO
M<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP
M:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!L:6MA<VDB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS
M9W-T<B`B1&%F=&%R($%P;&EK87-I(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@
M(D%P;&EK87-I('-U9&%H('-I87`N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G
M<W1R(")$:6=U;F%K86X@=6YT=6L@0F%G:6%N($%N86LB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*
M;7-G<W1R(")$:7-E='5J=6DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*
M;7-G<W1R(")!<F%B("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/R(*;7-G<W1R("(B"B)!<&%K86@@86YD82!Y86MI;B!A
M;F1A(&EN9VEN(&UE;6EN9&%H:V%N('!E<FUO:&]N86X@<&5N9&%F=&%R86X@
M=6YT=6L@)7,_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P
M<S\B"FUS9W-T<B`B07!A:V%H(&%N9&$@>6%K:6X@86YD82!I;F=I;B!M96YG
M:&%P=7,@)R5S)R!D86X@<W5B+6=R=7`@;6%N87!U;C\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M
M96YI82`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M.`IM<V=I9"`B07)T(@IM<V=S='(@(E-E;FDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM
M<V=S='(@(DMO9&4@07-C:6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_(@IM<V=S='(@(DUE;6EN=&$@:V]N9FER;6%S:2!S96)E;'5M(&UE
M;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;C\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$S"B,L(&9U>GIY"FUS9VED(")!<W-I9VYM
M96YT(&-O;'5M;G,B"FUS9W-T<B`B4&ES86AK86X@:V]L;VTB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B365N8V]B82!U;G1U:R!M96YG
M:&%P=7,@9W)U<"!Y86YG('1I9&%K(&%D82XB"@HC.B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")-96YC;V)A('5N='5K(&UE
M;F=H87!U<R!I>FEN('EA;F<@=&ED86L@861A+B(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B365N8V]B82!U;G1U:R!M96YG
M=6)A:"!I>FEN('EA;F<@=&ED86L@861A+B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+B(*;7-G<W1R(")-96YC;V)A('5N='5K(&UE;F=U8F%H
M(&)A9VEA;B!Y86YG('1I9&%K(&%D82XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B
M075G=7-T(@IM<V=S='(@(D%G=7-T=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0HC+"!F=7IZ>0IM<V=I
M9"`B075S=')I82(*;7-G<W1R(")!9W5S='5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*
M;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B
M075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY
M"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*
M;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<R(*;7-G<W1R(")396UU82!096YG9W5N82!!<VQI(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL
M86)L92!F:65L9',Z(@IM<V=S='(@(DMO;&]M('EA;F<@=&5R<V5D:6$Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*
M;7-G<W1R(")!;&%S86X@0D]&2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B
M"FUS9W-T<B`B3&%T87(@0F5L86MA;F<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O
M;&]R(@IM<V=S='(@(E=A<FYA($QA=&%R($)E;&%K86YG(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R
M(")-87)G:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B
M0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&EC("A)4T\M.#@U
M.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B1&%S87(@9&ER96MT;W)I(&=R869I:R`G)7,G('1I
M9&%K(&1I=&5M=6MA;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@
M(DIA<F%K(&%N=&%R82!B86=I86X@8F%W86@@9V%M8F%R(&1E;F=A;B!G87)I
M<R!D87-A<B!B87)I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"96QI>F4B"FUS9W-T<B`B
M2F%R86L@86YT87)A(&)A9VEA;B!B87=A:"!G86UB87(@9&5N9V%N(&=A<FES
M(&1A<V%R(&)A<FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F5N
M:6XB"FUS9W-T<B`B2F%R86L@86YT87)A(&)A9VEA;B!B87=A:"!G86UB87(@
M9&5N9V%N(&=A<FES(&1A<V%R(&)A<FES(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R
M(")096YG871U<F%N($%R96$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5&EP92!!<F5A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M"FUS9VED(")";VQD(@IM<V=S='(@(DAU<G5F(%1E8F%L(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B4&5T
M=6YJ=6L@:&%L86UA;B!W96(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T
M<B`B0F]R9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B
M2V5T96)A;&%N($)O<F1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`B0F]R9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z
M96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B2V5D=6%N>6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O
M;2(*;7-G<W1R(")"87=A:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)
M<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B
M0G)A>FEL(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"
M=6QL971E9"!,:7-T(@IM<V=S='(@(D1A9G1A<B!"=6QL970B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B
M0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B4')O<&5R=&D@4U]E;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*
M;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B5&5N86YG(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D
M(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"B)4:61A:R!D87!A="!M96YG871U<B!U;&%N9R!S86YD:2!S
M96-A<F$@;W1O;6%T:7,L('-I;&%K86X@:'5B=6YG:2`B"B)A9&UI;FES=')A
M=&]R(&%N9&$N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS
M9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE
M<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!T97)H=6)U;F<@
M:V4@<V5R=F5R(&QD87`B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B
M0V%N861A(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS
M9VED(")#86YC96PB"FUS9W-T<B`B0F%T86PB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(D)A=&%L:V%N($QA<&]R86X@36%S86QA:"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM
M<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N
M<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&
M:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*
M;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB
M<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I
M9"`B0V%P=&EO;B(*;7-G<W1R(")*=61U;"!486)E;"(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R
M<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*
M;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R
M:2!D86X@3&%B96PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0:&]N92(*;7-G
M<W1R(")0<F]P97)T:2!396PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I
M97,B"FUS9W-T<B`B4')O<&5R=&D@4V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN
M9SHB"FUS9W-T<B`B2F%R86L@<W!A<VD@9&%R:2!B;W)D97(@9&5N9V%N('1E
M:W,@9&D@9&%L86T@<V5L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE
M<R(*;7-G<W1R(")P<F]P97)T:2!S96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG
M.B(*;7-G<W1R(")*87)A:R!S<&%S:2!A;G1A<B!S96PN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT
M:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#96QT:6,@*$E33RTX.#4Y+3$T
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")496YG86@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D5R;W!A(%1E;F=A
M:"`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM
M<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC
M871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ
M>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")+87)A:W1E<B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")58F%H(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U
M<B!087-S=V]R9"(*;7-G<W1R(")58F%H(%-A;F1I($%N9&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M
M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@
M86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B)58F%H
M(&YA;6$@9&%N(&%L86UA="!S96AI;F=G82!O<F%N9R!D87!A="!M96QI:&%T
M;GEA(&ME=&EK82!M97)E:V$@;65M8F%C82`B"B)D86X@;65M8F%L87,@:V4@
M96UA:6P@86YD82XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U
M<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB365N9W5B
M86@@<V%N9&D@86YD82!T:61A:R!D:61U:W5N9R!D96YG86X@:V]N9FEG=7)A
M<VD@>6%N9R!S96MA<F%N9RX@4VEL86MA;B`B"B)H=6)U;F=I(&%D;6EN:7-T
M<F%T;W(@86YD82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(DMA<F%K
M=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")0
M97)I:W-A($QI;FLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#
M:&EL92(*;7-G<W1R(")*=61U;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D-H:6YA(@IM<V=S='(@(DMA<F%K=&5R(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*2(*;7-G<W1R(")#:6YA(%-E9&5R:&%N82`H1T(R,S$R*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*2(*;7-G<W1R(")#:6YA(%1R861I<VEO;FEL("A":6<U*2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*(RP@9G5Z>GD*
M;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E-A;F1I($)A<G4B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED
M(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z(@IM<V=S='(@(E!I;&EH(&-A<F$@=6YT=6L@;65N86UP:6QK86X@
M=&%N9V=A;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B4&EL:6@@9&%F=&%R
M('1I<&4@9V%Y82`H=6YT=6L@9&%F=&%R(&YO;6]R(&)E<G5R=70I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B1&ER96MT
M;W)I($UO=&EF("<E<R<@=&ED86L@9&ET96UU:V%N+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*
M;7-G<W1R(")"97)S:6AK86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S
M(@IM<V=S='(@(D)E<G-I:&MA;B!T86<@35-/9F9I8V4B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A<B!1=65R>2(*
M;7-G<W1R(")"97)S:6AK86X@<&5N9V=U;F$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A
M<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B0F5R<VEH:V%N('!E;F=G=6YA.B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I
M9"`B0VQE87(@=7-E<B(*;7-G<W1R(")"97)S:6AK86X@<&5N9V=U;F$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE
M87(@=7-E<B!D871A(@IM<V=S='(@(D)E<G-I:&MA;B!D871A('!E;F=G=6YA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*
M;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B0V5R86@@8F5B97)A<&$@
M<V%A="!L86=I(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@
M(DML:6L@=6YT=6L@3&%N:G5T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I
M82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@
M5VEN9&]W(@IM<V=S='(@(E1U='5P($IE;F1E;&$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(DUE;F1U;F<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM
M<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DUE;F1U;F<@9&D@<&%G:2!H
M87)I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")"97)A=V%N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L
M;&%P<V4@4VED96)A<B(*;7-G<W1R(")097)B97-A<B!086YE;"!.879I9V%S
M:2`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")0
M97)B97-A<B!B;W)D97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#
M;VQO;6)I82(*;7-G<W1R(")787)N82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO
M<B(*;7-G<W1R(")787)N82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")096UI;&EH(%=A
M<FYA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@HC+"!F=7IZ
M>0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI
M:&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(DMO;&]M(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS
M9VED(")#;VUI8W,B"FUS9W-T<B`B0V]M:6-S(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D-O;6UA;F0B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B0V]M;6%N9"!3:&5L;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;65N="(*;7-G
M<W1R(")#;VUM86YD(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C8*(RP@9G5Z>GD*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@
M(DYA;6$@06YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"B,L(&9U>GIY"FUS9VED(")#;VUO
M<F]S(@IM<V=S='(@(D)E<V]K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S.0HC+"!F=7IZ>0IM<V=I9"`B0V]M<&%N>2(*
M;7-G<W1R(")386QI;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM
M<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(DMO;7!U=&5R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N(@IM
M<V=S='(@(DMO;F1I<VDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM
M<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")+;VYD:7-I(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,B"FUS9W-T<B`B4&5R8F5D86%N($MO;F9I9W5R87-I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F
M;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS
M9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")+
M;VYF:6=U<F%S:2!S=61A:"!H86)I<R!M87-A(&)E<FQA:W5N>6$N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B365N9V%T=7(@)7,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M
M(%!A<W-W;W)D(@IM<V=S='(@(DMO;F9I<FUA<VD@4V%N9&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"B,L(&9U>GIY"FUS9VED(")#;VYG;R(*;7-G<W1R(")787)N82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S
M(@IM<V=S='(@(DMO;G1A:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(DQA;FIU="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G
M<W1R(")#;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B4V%L
M:6XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@
M(DMO;&]M('EA;F<@9&EI;7!O<CH@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO
M;B(*;7-G<W1R(")386QI;B!0:6QI:&%N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I
M("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E1I
M9&%K(&1A<&%T('1E<FEK870@9&5N9V%N('-E<G9E<B!L9&%P(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B5&ED86L@9&%P870@=&5R:6MA="!D
M96YG86X@<V5R=F5R(&QD87`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R
M(")4:61A:R!D87!A="!T97)H=6)U;F<@:V4@<V5R=F5R(&QD87`B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")4:61A:R!D87!A="!T97)H
M=6)U;F<@:V4@<V5R=F5R(&QD87`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R
M(")4:61A:R!D87!A="!T97)H=6)U;F<@:V4@<V5R=F5R("<E<R<@9&5N9V%N
M(&UE;F=G=6YA:V%N($944#HE<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(")4:61A:R!D87!A="!M96YU;&ES(&MO;F9I9W5R87-I('5N
M='5K("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@
M:V5M8F%L:2!K92!K;VYF:6=U<F%S:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@;65N9VAA<'5S('-C<FEP="!S
M971U<"!U<&=R861E("<E<R<N("(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M5&ED86L@9&%P870@;65N9VAA<'5S('-C<FEP="!S971U<"!U<&=R861E("<E
M<R<N("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T
M92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E
M8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I
M<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B5&ED
M86L@9&%P870@=&5R:6MA="!D96YG86X@<V5R=F5R(&QD87`B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(E1I
M9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E<RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*
M;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B5&ED86L@9&%P870@=&5R:'5B=6YG(&ME
M('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H
M<#HR,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M96%D("5S+B(*;7-G<W1R(")<(B5S7"(@8F5L=6T@9&EB=6%T.B`E<RXB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O
M<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(E1I
M9&%K(&1A<&%T(&UE;F=A='5R('5L86YG('5N='5K('!E;F=G=6YA('EA;F<@
M9&EM:6YT82X@0F5B97)A<&$@871A=2!S96UU82`B"B)D971I;"!T:61A:R!B
M96YA<BX@0V]B82!L86=I(&%T874@<VEL86MA;B!H=6)U;F=I(&%D;6EN:7-T
M<F%T;W(@86YD82!J:6MA("(*(F%N9&$@;65M97)L=6MA;B!B86YT=6%N(&QE
M8FEH(&QA;FIU="XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A
M9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&ME;6)A;&D@:V4@:V]N
M9FEG=7)A<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S
M='(@(E1I9&%K(&1A<&%T(&ME;6)A;&D@:V4@:V]N9FEG=7)A<VDN(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")4:61A:R!D
M87!A="!K96UB86QI(&ME(&MO;F9I9W5R87-I+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@
M:V]N9FEG=7)A<VD@)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@
M(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2!B86-K=7`N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U
M<F%S:2!B86-K=7`Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(E1I
M9&%K(&1A<&%T(&UE;GEI;7!A;B!S8W)I<'0@<V5T=7`@=7!G<F%D92!K93HG
M)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A
M;B!F:6QE(&MO;F9I9W5R87-I(&)A8VMU<"`E<RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!F
M:6QE(&MO;F9I9W5R87-I("5S+B!!;F1A(&1A<&%T(&UE;F=G=6YA:V%N('-A
M;&%H('-A='4@(@HB9&%R:2!P:6QI:&%N('5N='5K(&UE;GEI;7!A;B!K;V1E
M('1E<G-E8G5T(&ME;6)A;&D@:V4@)7,@871A=7!U;B!M96YY86QI;B`B"B)K
M;V1E(&1I(&)A=V%H(&EN:2!S96-A<F$@;6%N=6%L(&ME("5S+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED
M(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M5&ED86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*
M;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS.38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(E1I9&%K(&1A
M<&%T(&UE;G5L:7,@:V]N9FEG=7)A<VD@=6YT=6L@)R5S)SH@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;G5L:7,@:V]N9FEG=7)A
M<VD@=6YT=6L@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B)4
M:61A:R!D87!A="!M96YE;75K86X@4&%N96P@3F%V:6=A<VD@36]Z:6QL82X@
M4&%S=&EK86X@<&%N96P@;F%V:6=A<VD@<W5D86@@(@HB=&5R8G5K82XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;G1R>2(*;7-G<W1R(")+;VUP=71E<B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B2W5R<W5S
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0G5A="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")"=6%T(&QI;FLB
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS
M9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D)U870@8F%R=2(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED
M(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T
M;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B27II;B!T86UU(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`HC+"!F=7IZ>0IM<V=I9"`B0W)E9&ET
M(&-A<F0@;G5M8F5R(@IM<V=S='(@(D%N9VMA($1E<VEM86PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0HC+"!F=7IZ>0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")"=6%T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S
M97,B"FUS9W-T<B`B1F%S92!396MA<F%N9R(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G
M<W1R("))>FEN('1A;74B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O
M0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R
M(")786MT=2!396MA<F%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@
M:7,B"FUS9W-T<B`B55),(%-E:V%R86YG(&%D86QA:"(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*
M;7-G<W1R(")&87-E(%-E:V%R86YG(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(D-U86-A(%-E
M:V%R86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM
M<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")+;VYD:7-I(%-E
M:V%R86YG.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B1V%Y82!3
M96MA<F%N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+B(*;7-G<W1R(")+;W-T=6UI<V%S:2!T=6=A<R!U;G1U:R!D
M:6IA;&%N:V%N('-E8F5L=6T@;&]G;VX@:V4@)7,N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED
M(")#=70B"FUS9W-T<B`B2&%P=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM
M<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R
M=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-Y<FEL;&EC("A+3TDX
M+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-Y<FEL;&EC("A7:6YD;W=S
M+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y
M<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H
M<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B
M2&%R:2(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R
M964@0G)O=W-E<B(*;7-G<W1R(")$871A5')E92!"<F]W<V5R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O
M:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0HC
M+"!F=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R(")386QI;B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E
M8V5I=F5D(@IM<V=S='(@(E1A;F=G86P@1&ET97)I;6$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`W"B,L(&9U>GIY"FUS9VED(")$871E('-E
M;&5C=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S(R"FUS9VED(")$87DB"FUS9W-T<B`B2&%R:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM
M<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B2&%P=7,@2V]L;VTB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I
M9"`B1&5C96UB97(B"FUS9W-T<B`B1&5S96UB97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED
M(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B06YG:V$@1&5S:6UA;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G
M:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")-96YG=7)A;F=I($EN9&5N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R
M969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B1&5F875L="(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W
M"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D1E9F%U;'0@5V%R;F$B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"B,L(&9U
M>GIY"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(D1E9F%U;'0@
M:61E;G1I=&%S(&%N9&$Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W
M"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(D1E9F%U;'0@4VAE;&PB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I
M;VYS(@IM<V=S='(@(D1E9FEN:7-I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(DAA
M<'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")(87!U
M<R!396PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N
M<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(DAA<'5S($=R
M=7`B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B2&%P=7,@8F%R:7,B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M4&5R;6ES<VEO;B(*;7-G<W1R("))>FEN('1A;74B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N
M9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE
M=&4@8V5L;"(*;7-G<W1R(")(87!U<R!S96PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@8V]L=6UN(@IM<V=S='(@(DAA<'5S(&MO;&]M(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B2&%P=7,@<&5N9V=A;G1I('1E;7!L871E
M('EA;F<@<W5D86@@861A(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E5B86@@:7II;B!U;G1U
M:R`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(DAA<'5S(&)A<FES(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(DAA<'5S(&ED96YT
M:71A<R!Y86YG('1E<G!I;&EH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(DAA<'5S(&MO;&]M('EA;F<@<V5K
M87)A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B
M"FUS9W-T<B`B2&%P=7,@8F%R:7,@>6%N9R!S96MA<F%N9R(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B2&%P=7,@<V-R:7!T('-E='5P('5P9W)A9&4@)R5S)RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S
M='(@(DAA<'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B1&5N;6%R
M:R(*;7-G<W1R(")$:71A;F1A:2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G
M<W1R(")*96QA<VMA;B!-87-A;&%H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<VMR
M:7!S:2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED
M(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"B,L(&9U>GIY
M"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R(")!<F5A($UE=&%R('1I9&%K(&1I<V5D:6%K
M86XN($1E=&EL('1E;&%H(&1I8V%T870@=6YT=6L@861M:6YI<W1R871O<BXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E
M;&]P;65N="(*;7-G<W1R(")097)K96UB86YG86XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(E1I=&EK
M($5M8G5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E
M=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&ET:6L@16UB=6X@
M=6YT=6L@:F%M('1E<F%K:&ER.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(E1I=&EK
M($5M8G5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T
M<B`B07)A:"!K:7)I(&ME(&MA;F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0B"FUS9W-T<B`B07)A:"!K86YA;B!K92!K:7)I(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R
M(")$:7)E:W1O<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS
M9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(E1A;7!I;&MA
M;B!W86MT=2`R-"!J86T_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW
M"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B5&%M<&EL:V%N(%!I
M;&EH86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*;7-G
M:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B5&%M<&EL
M:V%N(&1E=&EL(')A;6%L86X@8W5A8V$B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@
M(E1A;7!I;&MA;B!R86UA;&%N(&-U86-A("A4048I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F
M;W)M870B"FUS9W-T<B`B5&%M<&EL:V%N(')A;6%L86X@8W5A8V$@*%1!1BDB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D
M96QE=&4B"FUS9W-T<B`B2&%P=7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP(@IM<V=S='(@(DIA;F=A;B!L86YG<W5N9R!M96YG86MS97,@
M;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@HB07!A:V%H(&)A<FES
M('EA;F<@<&5R=&%M82!T97)D:7)I(&1A<FD@:V]L;VT@;F%M83\@:FEK82!Y
M82P@8F5R:2!T86YD82!P861A("(*(FMO=&%K(&EN:3HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O
M=6YT/R!3:6=N('5P+B(*;7-G<W1R(")4:61A:R!M96UI;&EK:2!A8V-O=6YT
M/R!3:6QA:V%N(&UE;F1A9G1A<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")$
M;W=N;&]A9"!K;VYF:6=U<F%S:2!Y86YG(&1I:&%S:6QK86X@<V5B86=A:2!S
M8W)I<'0@4$A0+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*
M;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B3V)A="UO
M8F%T86XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")3=7)A="(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED
M(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W
M:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@
M(D5D:70B"FUS9W-T<B`B56)A:"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I
M9"`B161I="!";&]C:R(*;7-G<W1R(")58F%H($)L;VMI<B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%
M9&ET($=R;W5P(@IM<V=S='(@(E5B86@@1W)U<"(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G
M<W1R(")58F%H($EZ:6XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E5B86@@27II
M;B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M56)A:"!)>FEN('5N='5K("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B56)A:"!P
M:6QI:&%N('5N='5K.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B56)A:"!I>FEN('5N='5K("5S
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")5
M8F%H(&EZ:6X@=6YT=6L@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")096YD:61I:V%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET
M:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,
M('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N
M="XN+B(*;7-G<W1R(")%;&5M96XN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B
M16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*(RP@9G5Z>GD*;7-G
M:60@(D5M86EL(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%L86UA="!%;6%I
M;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*(RP@9G5Z>GD*
M;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")3
M86YD:2!H87)U<R!C;V-O:RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")+;VYF:6=U<F%S:2`E<R!S=61A:"!D:7-I;7!A;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM
M<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ
M>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(DMO;F1I<VDB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G
M:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y
M(')E<W5L="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N
M86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S
M(&EN('1E>'0_(@IM<V=S='(@(D%K=&EF:V%N('!E;GEI<VEP86X@9V%M8F%R
M+6=A;6)A<B!D87)I($=A;&5R:2!&;W1O(&1I(&1A;&%M('1E:W,_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT
M(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B06MT:69K86X@:VQI:R!K
M86YA;B!M96YU(&MO;G1E:W,_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"B,L(&9U>GIY
M"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")097)B97-A<B!086YE;"!.879I
M9V%S:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(E!E<F)E<V%R
M($5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@
M(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R
M9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G
M<W1R("(B"B)-87-U:VMA;B!P97)T86YY86%N(&ME86UA;F%N(&1I;6%N82!A
M;F1A(&%K86X@9&ET86YY86MA;B!A<&%B:6QA(&%N9&$@<&5R;'4@(@HB=6YT
M=6L@;65N9V%T=7(@=6QA;F<@<V%N9&D@86YD82P@(&-O;G1O:"`G87!A:V%H
M(&YA;6$@8FEN871A;F<@:V5S87EA;F=A;B`B"B)A;F1A/R<Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B
M36%S=6MK86X@55),(&=A;6)A<B!D:7-I;FDB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V
M:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R
M(")+97-A;&%H86XB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C0V,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E
M871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(DME<V%L86AA;B!S86%T(&UE;7!E
M<F)A:&%R=6D@<V%N9&DZ("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")+97-A;&%H86X@<V%A
M="!M96UP97)B86AA<G5I('-A;F1I.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B2V5S86QA:&%N
M('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")+
M97-A;&%H86X@<V%A="!M96UP97)B86AA<G5I('-A;F1I.B`E<R(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B2V5S
M86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G
M:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F
M=7IZ>0IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")3=6MU(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B4W5K=2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G
M:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B4V5T:6%P(#$U(&UE;FET
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B179E<GD@
M,B!M:6YU=&5S(@IM<V=S='(@(E-E=&EA<"`R(&UE;FET(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W
M"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(E-E=&EA<"`S,"!D
M971I:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S
M='(@(E-E=&EA<"`U(&UE;FET(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@3&]G
M:6XB"FUS9W-T<B`B4V5T:6%P(&UE;FET(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(E-E
M=&EA<"!S971E;F=A:"!J86TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI
M;G5T92(*;7-G<W1R(")3971I87`@;65N:70B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S
M='(@(D-O;G1O:"!N:6QA:2UN:6QA:3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B2F%L86YK86XB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*(RP@9G5Z>GD*
M;7-G:60@(D5X<&%N9"(*;7-G<W1R(")097)B97-A<B!086YE;"!.879I9V%S
M:2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@
M(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(E!E<F)E<V%R(%!A;F5L($YA=FEG
M87-I(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`HC
M+"!F=7IZ>0IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(DIA;&%N:V%N
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I
M9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B
M5V%R;F$@1D<B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED
M(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D944"!U<&QO860@=6YT
M=6L@<V5T=7`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR
M,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`HC+"!F=7IZ>0IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(E1I9&%K(&1A<&%T('1E<FAU8G5N9R!K92!S97)V97(@;&1A<"(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B5&ED
M86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")4:61A:R!D87!A
M="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S
M='(@(D-E<F%H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A
M<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*(RP@9G5Z
M>GD*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")&87AE<R(*;7-G<W1R(")&87@B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I
M9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<FDB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")397!E
M<G1I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E-E<&5R=&DZ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3
M:&]W97)S(@IM<V=S='(@(D=E<FEM:7,@4V5B86=I86XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R(")'97)I;6ES(%-A;&IU(%-E8F%G:6%N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@
M;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY
M"FUS9VED(")&:6QE(@IM<V=S='(@(D9I;'1E<B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D9I;&4@36%N86=E
M<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS
M9VED(")&:6QE($YA;64B"FUS9W-T<B`B3F%M82!,96YG:V%P(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M92!S96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL:6AA;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U
M.0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(D944"!U<&QO860@=6YT=6L@<V5T=7`B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B
M1FEL=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B1FEN;&%N9"(*
M;7-G<W1R(")M87-I:"!D:2!D86QA;2!A;G1R:6%N(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")&87-E
M('!E<G1A;6$@9&%R:2!397!A<G5H($)U;&%N(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@
M475A<G1E<B(*;7-G<W1R(")&87-E('!E<G1A;6$@9&%R:2!397!A<G5H($)U
M;&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B1FQO870B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM
M<V=I9"`B1F]G(@IM<V=S='(@(D)E<FMA8G5T(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")7
M87)N82!4=6QI<V%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS
M9VED(")&;V]D(@IM<V=S='(@(DUA:V%N86XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@
M(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S
M='(@(E5N='5K(&)R;W=S97(@>6%N9R!T:61A:R!D87!A="!M96YD=6MU;F<@
M9V%M8F%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O
M<F5C87-T("A4048I(@IM<V=S='(@(E)A;6%L86X@8W5A8V$@*%1!1BDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B
M(@HB2&%R:2!286UA;&%N($-U86-A("AC871A=&%N(&)A:'=A(')A;6%L86X@
M8W5A8V$@>6%N9R!D:6ME;6)A;&EK86X@86MA;B`B"B)M96YG96UB86QI:V%N
M(&)A:6L@<VEA;F<@871A=2!M86QA;2!H87)I+"!S96IU;6QA:"!A;F=K82!D
M87!A="!D:6AA<VEL:V%N("(*(G!A9&$@87)E82!I;FDI(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A
M<W-W;W)D/R(*;7-G<W1R("),=7!A(&1E;F=A;B!S86YD:2!A;F1A/R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS(@IM
M<V=S='(@(D9O<FUU;&ER(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q
M"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(E)A;6%L86XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R
M(")4:7!E(%)A;6%L86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(E)A;6%L86XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M4F%M86QA;B`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM
M<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<G5M(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B1&ET
M97)U<VMA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(DIM="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@
M(D9R86UE<R(*;7-G<W1R(")&<F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*
M;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%M92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN
M97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"B,L(&9U>GIY"FUS9VED
M(")&<F]M(@IM<V=S='(@(DIM="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B1&%R:2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@
M(D1E<VMR:7!S:2!,96YG:V%P(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G
M<W1R(")"=6QA;B!0=7)N86UA(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@
M(D9U;&P@3F%M92(*;7-G<W1R(").86UA($QE;F=K87`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&5R:2!U;G1U
M:R!M96YG86UB:6P@9V%M8F%R(&1A<FDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A
M;&QE<GDZ(@IM<V=S='(@(D=A;&5R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A
M;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R
M"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I
M;VXB"FUS9W-T<B`B365N9VAA<VEL:V%N("5S($MO;F9I9W5R87-I("(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'
M96YE<F%T960@0V]D92(*;7-G<W1R(")+;V1E('EA;F<@9&EH87-I;&MA;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R
M86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@
M(DIA;&%N:V%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED
M(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(D=O
M;V=L92!-87!S(@IM<V=S='(@(E!E;F-A<FEA;B!';V]G;&4B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM
M<V=S='(@(E!E;F-A<FEA;B!';V]G;&4B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(EEU;F%N:2`H25-/+3@X-3DM-RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M061M:6YI<W1R87-I($=R=7`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N
M<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G
M:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U
M<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S
M(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U
M<"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R(")1=65R>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ:6X@=&%M=2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R(")"=6MU('1A;74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'
M=6EN96$B"FUS9W-T<B`B2G5N:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I
M;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M>6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N(@IM<V=S='(@(B(*(DA434Q!<F5A(&1E;F=A;B!R86=U(&UE;F]L
M86L@=6YT=6L@;65N9VAA<'5S('-E;"!Y86YG('1E<F%K:&ER(&1I(&1A;&%M
M("(*(F)A<FES+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS
M9W-T<B`B(@HB2%1-3$%R96$@9&5N9V%N(')A9W4@;65N;VQA:R!U;G1U:R!M
M96YG:&%P=7,@:V]L;VT@>6%N9R!T97)A:VAI<B!D:2!D86QA;2`B"B)T86)E
M;"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*(DA4
M34Q!<F5A(&1E;F=A;B!R86=U(&UE;F]L86L@=6YT=6L@;65N9VAA<'5S(&)A
M<FES('EA;F<@=&5R86MH:7(@9&D@9&%L86T@(@HB=&%B96PN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B0F5R:V%B=70B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDS,@HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(D)A8V$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q
M"FUS9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S
M"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(DAU:F%N
M('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!A;F=I;B!R:6)U="(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M
M22DB"FUS9W-T<B`B66%H=61I("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I
M9"`B2&5I9VAT(@IM<V=S='(@(E1I;F=G:2(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE
M;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP
M;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")"
M86YT=6%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B0F%N
M='5A;B!M96YG9W5N86MA;B!E9&ET;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B
M0F%N='5A;B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M
M:7-P:&5R92(*;7-G<W1R(")"96QA:&%N($)U;6DB"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.B(*;7-G<W1R("));FD@861A;&%H('!E<FUU;&%A;B!D87)I(&9I;&4Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G
M:60@(DAI9V@B"FUS9W-T<B`B5&EN9V=I(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")(;U]M92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0HC+"!F
M=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R(")(;U]M92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0HC+"!F=7IZ>0IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%L86UA="!%;6%I;"(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB
M"FUS9W-T<B`B1&ER96MT;W)I($AO;64B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D
M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R
M<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")<
M(B5S7")S=61A:"!B97)H87-I;"!D:6AA<'5S+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(D=A<FES($AO<FES;VYT86P@9&D@
M9&%L86T@2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R
M(")*87)A:R!G87)I<R!H;W)I>F]N=&%L(&1A<FD@8F]R9&5R(&1E;F=A;B!T
M96MS(&1I(&1A;&%M('-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@
M(DAO<FEZ;VYT86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@
M:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")"86=A:6UA;F$@8V%R
M82!A;F1A(&)I<V$@<V%M<&%I(&1I<VEN:3\@*%-I;&%K86X@;65L87!O<B$I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B0F5R87!A(&)A;GEA:R!K;VQO;2!Y86YG
M(&EN9VEN(&%N9&$@9V%B=6YG:V%N/R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\B"FUS9W-T<B`B0F5R87!A(&)A;GEA:R!K;VQO;2!Y86YG
M(&%D82!D:7-A;F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B0F5R87!A(&)A;GEA:R!B
M87)I<R!Y86YG(&EN9VEN(&%N9&$@9V%B=6YG:V%N/R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(DME;&5M8F%B86XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET
M>3H@(@IM<V=S='(@(DME;&5M8F%B86XZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B4&5L87=A:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L
M(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(D%L86UA="!%;6%I
M;"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*(RP@
M9G5Z>GD*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@
M;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")-87-U
M:VMA;B!"87)I<R!396)E;'5M;GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B2&%N>6$@:6MO;B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26MO;B!U;G1U:R`E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X
M="(*;7-G<W1R(")):V]N(&1E;F=A;B!T96MS(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R
M(").86UA($ED96YT:71A<SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U
M<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K
M("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM
M<V=S='(@(B(*(DII:V$@86YD82!T:61A:R!M96QI:&%T(&EK;VX@;6%N87!U
M;B!D96YG86X@;65N9V=U;F%K86X@26YT97)N970@17AP;&]R97(L("(*(F%N
M9&$@;75N9VMI;B!P97)L=2!U;G1U:R!M96YA;F1A:2!K;W1A:R!I;FD@=6YT
M=6L@;65N;VXM86MT:69K86X@:V5L96UA:&%N("(*(E!.1RXB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B
M"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED
M("));6%G92!0<F5V:65W.B(*;7-G<W1R("),:6AA="!'86UB87(Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E523"!'86UB87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B55),($=A;6)A<CHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M(")'86UB87(@9&%R:2!G86QE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E
M(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B1V%M8F%R(&1A<FD@9V%L97)I.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E
M('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D=A;6)A<BUG86UB87(B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<BP@3&%N9VMA:"`E
M9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")+;VQO
M;2!Y86YG(&1I:6UP;W(Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")+;VQO
M;2!Y86YG(&1I:6UP;W(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!
M9G1E<B(*;7-G<W1R(")-87-U:VMA;B!"87)I<R!"97)I:W5T;GEA(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED
M("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+B(*;7-G<W1R(")3:6QA:V%N(&UA<W5K:V%N(&YA;6$@<&5N9V=U
M;F$@9&%N('-A;F1I(&%N9&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R
M;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"B).86UA('!E;F=G=6YA(&%T874@86QA;6%T(&5M86EL('!E;F=G86YT
M:2!T:61A:R!B96YA<BX@0V]B82!L86=I(&%T874@(@HB<VEL86MA;B!H=6)U
M;F=I(&%D;6EN:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@;65M97)L=6MA;B!B
M86YT=6%N(&QE8FEH(&QA;FIU="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B
M"FUS9W-T<B`B365N86UB86@@26YD96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@
M(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED
M("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E!E;F=G=6YA(%!R:6)A9&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED("));F9O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-3<*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%S
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@
M(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN
M9F]R;6%S:2!S=61A:"!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I
M9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B36%S=6MK86X@2V]L
M;VT@0F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E
M(@IM<V=S='(@(DUA<W5K:V%N($=A;6)A<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L
M92(*;7-G<W1R(")-87-U:VMA;B!486)E;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@
M3&EN:R(*;7-G<W1R(")-87-U:VMA;B!796(@3&EN:R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I
M9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(DUA<W5K:V%N($MO
M;&]M(%-E8F5L=6UN>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DUA<W5K:V%N
M(&MO;&]M('EA;F<@8F%R=2!S971E;&%H(&MO;&]M('EA;F<@<V5K87)A;F<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R(")-87-U:VMA;B!K;VQO;2!Y86YG(&)A
M<G4@<V5B96QU;2!K;VQO;2!Y86YG('-E:V%R86YG(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R(")-87-U:VMA;B!B87)I<R!Y86YG(&)A<G4@<V5T96QA:"!B87)I<R!Y
M86YG('-E:V%R86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B36%S=6MK86X@8F%R
M:7,@>6%N9R!B87)U('-E8F5L=6T@:V]L;VT@>6%N9R!S96MA<F%N9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R
M96YT(&YO9&4B"FUS9W-T<B`B36%S=6MK86X@<&%R86=R868@<V5T96QA:"!P
M87)A9W)A9B!Y86YG('-E:V%R86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
M36%S=6MK86X@<&%R86=R868@<V5B96QU;2!P87)A9W)A9B!Y86YG('-E:V%R
M86YG(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R
M="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B36%S=6MK86X@=&5M<&QA
M=&4@<&5N9V=A;G1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM
M<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(DUA<W5K:V%N
M(&%L86UA="!E;6%I;"!D:6UA;F$@86YD82!D87!A="!M96YE<FEM82!S86YD
M:2!Y86YG(&)A<G4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B
M"FUS9W-T<B`B36%S=6MK86X@<V5L(&)E<FEK=71N>6$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED
M("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B36%S=6MK86X@<V5L('-E
M8F5L=6UN>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM
M<V=S='(@(DUA<W5K:V%N(&MO;&]M(&)E<FEK=71N>6$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED
M("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")-87-U:VMA;B!K;VQO
M;2!S96)E;'5M;GEA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M97-S86=E<R(*
M;7-G<W1R(")-87-U:VMA;B!'86UB87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B36%S=6MK86X@<&%R86=R868@
M8F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B
M969O<F4B"FUS9W-T<B`B36%S=6MK86X@<&%R86=R868@<V5B96QU;6YY82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B36%S=6MK
M86X@8F%R:7,@8F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@
M8F5F;W)E(@IM<V=S='(@(DUA<W5K:V%N(&)A<FES('-E8F5L=6UN>6$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM
M<V=S='(@(DUA<W5K:V%N(&IA=V%B86X@>6%N9R!D:7!E<FQU:V%N('5N='5K
M('!E<G1A;GEA86%N(&ME86UA;F%N.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@
M26UA9V4B"FUS9W-T<B`B36%S=6MK86XO56)A:"!'86UB87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("))
M;G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B36%S=6MK86XO56)A:"!,:6YK
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#<U"B,L(&9U>GIY"FUS9VED("));G1E9V5R(@IM
M<V=S='(@(E1E;F=A:"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@
M(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED
M("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM
M<V=S='(@(D%P;&EK87-I('1I9&%K('9A;&ED+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV
M86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RXB"FUS9W-T<B`B07!L:6MA<VD@=&ED86L@=F%L:60N
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")&;W)M
M870@5V%K='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R
M(")!<&QI:V%S:2!T:61A:R!V86QI9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!<&QI:V%S:2!T:61A:R!V86QI9"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB
M"FUS9W-T<B`B27II;B!I;F1U:R!T:61A:R!V86QI9"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G
M<W1R("))>FEN(&EN9'5K('1I9&%K('9A;&ED+B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B27II;B!I;F1U:R!T:61A:R!V86QI9"XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DEZ:6X@:6YD=6L@=&ED
M86L@=F%L:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S
M='(@(D%P;&EK87-I('1I9&%K('9A;&ED+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B07!L:6MA<VD@=&ED86L@
M=F%L:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P
M-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A
M;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(DEZ:6X@:6YD
M=6L@=&ED86L@=F%L:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B07!L:6MA<VD@=&ED86L@=F%L:60N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV
M96YT;W)Y(@IM<V=S='(@(DEN=F5N=&]R:7,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"B,L(&9U>GIY"FUS9VED("))
M;G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-
M86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@
M(DAU:F%N('!E=&ER(&1I<V5R=&%I(&%N9VEN(')I8G5T(&1I(&1A97)A:"!Y
M86YG('1E<G!E;F-I;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS
M9W-T<B`B2'5R=68@36ER:6YG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS
M9VED("))=&%L>2(*;7-G<W1R(")(=7)U9B!-:7)I;F<B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS
M9W-T<B`B2F%N=6%R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA
M<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F5P86YG("A)4T\M,C`R
M,BU*4"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I
M9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R
M;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@
M8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S
M='(@(DIU;&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I
M9"`B2G5S=&EF>2(*;7-G<W1R(")2871A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I
M9GD@0V5N=&5R(@IM<V=S='(@(E)A=&$@5&5N9V%H(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@
M(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")2871A($MI<FD@9&%N($MA;F%N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")2871A($MI<FDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")2871A($MA
M;F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S
M='(@(DME<FYE;"!.97=B:65S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@0W)E871I;VXB"FUS
M9W-T<B`B2G5D=6P@5&%B96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B
M2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B06YA:RUA;F%K
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B
M2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B
M2V]R96$@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED
M("),85]Y;W5T(@IM<V=S='(@(E1A;7!I;&%N(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B0F%H
M87-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B1F%S92!T97)A:VAI
M<B!D87)I(%-E<&%R=6@@0G5L86XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(E!E
M<G5B86AA;B!386YD:2!497)A:VAI<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E
M<B(*;7-G<W1R(")&87-E('1E<F%K:&ER(&1A<FD@4V5P87)U:"!"=6QA;B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T
M960Z(@IM<V=S='(@(E!E<G5B86AA;B!497)A:VER.B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B)7,@=6YT=6L@)7,@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ
M($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I
M9"`B3&%W(@IM<V=S='(@(DAU:W5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS
M9W-T<B`B5&%M<&EL86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R
M9&5R(@IM<V=S='(@(E1I;F=G86QK86X@:V]S;VYG('1A;G!A(&)O<F1E<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*
M;7-G:60@(DQE9G0B"FUS9W-T<B`B2VER:2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*;7-G
M:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(D1A9G1A<B!486)E;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L
M(@IM<V=S='(@(D-I;G1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"B,L(&9U>GIY"FUS9VED
M("),:6)E<FEA(@IM<V=S='(@(E!A;G1U;B!*96YA:V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS
M9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(D=E<FEM:7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG
M:'0@4F%I;B(*;7-G<W1R(")'97)I;6ES(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R
M;'DB"FUS9W-T<B`B1V5R:6UI<R!D:2!P86=I(&AA<FDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@
M4F%I;B!,871E(@IM<V=S='(@(D=E<FEM:7,@8F5B97)A<&$@<V%A="!L86=I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*
M;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(D=E<FEM:7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I
M9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B1V5R:6UI<R!D
M:7-E<G1A:2!P971I<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(D)E<G-A
M;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(D=E<FEM:7,@
M4V%L:G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI
M;65R:6-K(@IM<V=S='(@(E!A;G1U;B!*96YA:V$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S
M='(@(DQO9VEN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS
M9W-T<B`B3&EN:R!M96YU;FIU:R!K93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#,*(RP@9G5Z>GD*;7-G:60@(DQI;FMS(@IM<V=S='(@(E1U9V%S($QO
M9VEN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU
M>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@@0V]O:VEE(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R
M(")$869T87(@1&%T86)A<V4B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")$869T87(@
M5&]P:6L@0F%N='5A;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G
M:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(D1A9G1A<B!486)E;"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T
M+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G
M<W1R(")$869T87(@5&]P:6L@0F%N='5A;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS
M9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*
M(RP@9G5Z>GD*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(D%N9VMA
M+VAU<G5F+W-I;6)O;"!Y86YG(&1I='5L:7,@9&EB87=A:"!G87)I<R!B87)I
M<R!T96MS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B1&%F=&%R
M('!E;F=G=6YA(&1I;F]N+6%K=&EF:V%N+B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S(@IM<V=S='(@(D1A9G1A<B!P96YG9W5N82!D:6YO
M;BUA:W1I9FMA;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S
M='(@(D1A9G1A<B!P96YG9W5N82!D:6YO;BUA:W1I9FMA;BXB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T
M<B`B1&%F=&%R($)A8V%A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0HC+"!F=7IZ>0IM<V=I
M9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQE8F%R('5N:70B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")786MT=2!L
M;V-A;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO
M8V%L92!A;F0@5&EM92(*;7-G<W1R(")496UP870@4&5R:7-T:7=A(&1A;B!7
M86MT=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`B3&]K87-I(@H*(SH@;&]G:6XN<&AP.C$W,B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN
M(@IM<V=S='(@(DQO9VEN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*
M;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3&]G(&]U="(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B3&]G:6XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R(")4=6=A<R!,;V=I;B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR
M"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(E1I9&%K
M(&1I87)S:7!K86XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U
M"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B3&]G(&]U="(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G
M<W1R(")#:6YT82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B4F5N9&%H(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")3:6UB;VP@
M2'5R=68@:V5C:6P@>75N86YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R(")3:6UB;VP@2'5R=68@:V5C:6P@;&%T:6XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(E-I;6)O;"!(=7)U9B!K96-I;"!R;VUA=VDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED
M(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DU31R(*
M;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA
M8V%O(@IM<V=S='(@(DQI8G5R86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I
M8R(*;7-G<W1R(")3=6QA<"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")3=7)A="(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T
M<B`B4W5R870@061M:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB
M"FUS9W-T<B`B0G5A="!L:6YK+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY
M"FUS9VED(")-86QA=VDB"FUS9W-T<B`B4W5R870B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY
M"FUS9VED(")-86QI(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L
M(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")3=7)A="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T
M(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@
M86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RXB"FUS9W-T<B`B(@HB365N9V%T=7(@9&%F=&%R(&MA=&5G;W)I('EA;F<@
M:&%R=7,@9&EB97)I(&QA8F5L(&ET96TL(&1A;B!W87)N82!Y86YG("(*(F)E
M<FAU8G5N9V%N("!D96YG86X@:V%T96=O<FD@=&5R<V5B=70N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@
M(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM
M<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B
M"FUS9W-T<B`B36%R970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B
M36%R9VEN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PHC
M+"!F=7IZ>0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)G:6XB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI
M;F<@9FEE;&1S(@IM<V=S='(@(DUE;F-O8V]K:V%N(&MO;&]M(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA
M<F=I;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B!3=6AU(&UA:W-I;75M
M('EA;F<@8F5R;&%N9W-U;F<@<V5L86UA(#(T(&IA;3HB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B4W5H=2!M86MS:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E
M;&%M82`V(&IA;3HB"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")*=6UL86@@;6%K
M<VEM=6T@9&%R:2!P;W)T86P@>6%N9R!D:6)L;VMI<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA
M>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B365I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B36%Y;W1T92(*;7-G
M<W1R(")486UP:6QA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM
M<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B3V)A="UO8F%T86XB"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S
M(@IM<V=S='(@(D%N9V=O=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE;G4@;6]D93HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")'86)U;F=K86X@<V5L
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B4&5S
M86X@4TU3(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(@0W5A8V$@365T87(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")!<F5A($UE=&%R('1I9&%K(&1I<V5D:6%K
M86XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D%R96$@365T
M87(@=&ED86L@9&ES961I86MA;BX@1&5T:6P@=&5L86@@9&EC871A="!U;G1U
M:R!A9&UI;FES=')A=&]R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C4*(RP@9G5Z>GD*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"XB"FUS9W-T<B`B4V%N9&D@;&%M82!T:61A:R!B96YA<BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q
M(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*
M;7-G<W1R(")-971R:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@
M(DUE>&EC;R(*;7-G<W1R(")-971R:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")496YG86@B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4
M>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS
M9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B4W5H=2!M
M:6YI;75M('EA;F<@8F5R;&%N9W-U;F<@<V5L86UA(#(T(&IA;3HB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B4W5H=2!M:6YI;75M('EA;F<@8F5R;&%N9W-U
M;F<@<V5L86UA(#8@:F%M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T
M('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI<G)O
M<B(*;7-G<W1R(")+97-A;&%H86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B3&%I;BUL86EN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*
M;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@
M9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P
M<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)+;VYF:6=U<F%S:2!T:61A:R!D:71E
M;75K86XN($%N9&$@:&%R=7,@;65N9VAA<VEK86X@:V]N9FEG=7)A<VD@<V5K
M87)A;F<@(@HB:FEK82!A;F1A(&EN9VEN(&UE;F=G=6YA:V%N(&%P;&EK87-I
M(&EN:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K
M86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S
M:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")396XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-
M86EL(@IM<V=S='(@(DUO8FEL92!-86EL(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S
M='(@(E-E9&%N9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"B,L
M(&9U>GIY"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(E-E9&%N9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")58F%H(%523"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED
M(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L
M9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED
M(")-;VYT:&QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")3961A;F<B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO
M;VX@4&AA<V5S(@IM<V=S='(@(D9A<V4@0G5L86XB"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD
M(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B
M36]S=&QY($-L96%R(@IM<V=S='(@(E-E8F%G:6%N(&)E<V%R($-E<F%H(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G
M:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B4V5B86=I86X@8F5S87(@0F5R
M87=A;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B4V5B86=I86X@8F5S
M87(@0V5R86@B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(RP@9G5Z>GD*;7-G:60@
M(DUO=F4@3&5F="(*;7-G<W1R(")+:7)I(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3$W"B,L(&9U>GIY"FUS9VED(")-;W9E(%)I
M9VAT(@IM<V=S='(@(DMA;F%N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G
M:60@(DUO=F4@9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU
M;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B
M375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-#(*(RP@9G5Z>GD*;7-G:60@(DUU;'1I<&QE('-E;&5C
M=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")!
M8V-O=6YT+6MU(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED
M(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%S:2!!
M8V-O=6YT+6MU(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM
M<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(E!O<G1A;&MU(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U
M="(*;7-G<W1R(")486UP:6QA;B!0;W)T86QK=2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4
M($%G<F5E(@IM<V=S='(@(E1)1$%++"!387EA(%1)1$%+(%-E='5J=2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"B,L(&9U>GIY"FUS9VED(").
M86UE(@IM<V=S='(@(FYA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q
M"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!
M('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM
M<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").
M971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B
M3F5T=V]R:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(E1I9&%K('!E<FYA
M:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B3F5W($-A;&5D;VYI
M82(*;7-G<W1R(")+871E9V]R:2!"87)U(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E
M9V]R>2(*;7-G<W1R(")+871E9V]R:2!"87)U(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@
M(D)U;&%N($)A<G4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R
M(").86UA(%!E;F=G=6YA($)A<G4@*'!I;&EH86XI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G
M<W1R(")386YD:2!"87)U(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`B4V%N9&D@8F%R=2!T:61A:R!C;V-O:RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED
M(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(E=I;F1O=R!"87)U("A?
M8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M.#D*;7-G:60@(DYE=W,B"FUS9W-T<B`B0F5R:71A(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R
M(")'<G5P($)E<FET82(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(D)E<FEK=71N>6$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0
M:&%S97,B"FUS9W-T<B`B1F%S92!"97)I:W5T;GEA(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G
M<W1R(")+96UB86QI(&ME(%!I;&EH86XB"@HC.B!F<F%M97=O<FLO54DO54DO
M4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B
M0F5R:6MU=&YY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B
M"FUS9W-T<B`B36%L86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X
M,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B36%L86TB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PHC+"!F=7IZ>0IM<V=I9"`B3F\B"FUS
M9W-T<B`B5&ED86L@861A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I
M9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"B)4:61A
M:R!A9&$@9&%T82!K;VYF:6=U<F%S:2!Y86YG('1E<G-E9&EA('5N='5K(&UE
M;G5N:G5K:V%N('!E<F)E9&%A;B!U;G1U:RXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA
M8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@
M(DYO(&-H86YG92XB"FUS9W-T<B`B5&ED86L@861A('!E<G5B86AA;BXB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@HC+"!F=7IZ>0IM
M<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B7"(E<UPB('-U9&%H(&1I=&%M8F%H:V%N(&ME(&1A
M;&%M(&EZ:6X@<VES=&5M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE
M=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O
M=6YD+B(*;7-G<W1R(")4:61A:R!A9&$@:6MO;B!Y86YG(&1I=&5M=6MA;BXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM
M<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(")4:61A:R!A9&$@
M;&]K87-I('EA;F<@9&EA='5R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(")4:61A:R!A9&$@;&]K87-I('EA;F<@9&EA='5R+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS
M9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T
M=6YE<R(*;7-G<W1R(")4:61A:R!A9&$@<F%M86QA;B!Y86YG('1I9&%K('-O
M<&%N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP
M:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M
M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X
M-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O
M=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN
M9R!S:6=N=7!S+B(*;7-G<W1R(")4:61A:R!A9&$@<&5N9&%F=&%R86X@>6%N
M9R!D:71U;F1A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T
M<B`B0F5L=6T@9&EA='5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T
M<B`B5&ED86L@861A(&%T=7)A;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B5&ED86L@
M861A('-I<VDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PHC
M+"!F=7IZ>0IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(E1I9&%K(&%D
M82!S:7-I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM
M<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+B(*;7-G<W1R(")4:61A:R!A9&$@9&ER96MT;W)I('-E;65N=&%R82!Y
M86YG('1E<G-E9&EA('5N='5K(&-A8VAE(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")3:6QA
M:V%N(&UA<W5K:V%N(&YA;6$@<&5N9V=U;F$@9&%N('-A;F1I(&%N9&$B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@
M=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*(RP@9G5Z>GD*;7-G
M:60@(DYO('9A;'5E<R(*;7-G<W1R(")4:61A:R!A9&$@871U<F%N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E1I9&%K(&%D82!V97)S:2!Y86YG
M(&1I=&5M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!Y86YG(&%S;&DN($UE
M;F=H87-I;&MA;B`B"B)K;VYF:6=U<F%S:2!K96UB86QI+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(E1I9&%K(&%D82!V97)S:2!Y86YG(&1I=&5M=6MA
M;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!A;F1A+B!-96YG:&%S:6QK86X@(@HB
M:V]N9FEG=7)A<VD@:V5M8F%L:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(E1I9&%K(&%D
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B5&ED86L@
M861A("AD:6=U;F%K86X@<V5L96YG:V%P;GEA*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G
M<W1R(")38V%N9&EN879I82`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").
M;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(D)E;&%H86X@0G5M:2!5=&%R
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0P"B,L(&9U>GIY"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B0F5L=6T@
M9&EA='5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-#`X"B,L(&9U>GIY"FUS9VED(").;W0@82!D
M:7)E8W1O<GDB"FUS9W-T<B`B1&ER96MT;W)I($AO;64B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(D)E;'5M(&1I871U<B(*"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO
M=&5S(@IM<V=S='(@(D-A=&%T86XB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I
M;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+B(*;7-G<W1R(")4:61A:R!A9&$@>6%N9R!D87!A="!D:6)R;W=S92P@<VEL
M86MA;B!K96UB86QI+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)E
M<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z>GD*
M;7-G:60@(DYU;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C4*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O
M9B!C:&%R86-T97)S(@IM<V=S='(@(DIU;6QA:"!B87)I<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")*=6UL86@@:V]L;VTB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I
M9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B2G5M;&%H(&)A<FES(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*
M;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T
M<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B4&5N8VEP
M=&$@3V)J96LB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM
M<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B4&5N8VEP=&$@3V)J96LB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"B,L(&9U>GIY"FUS
M9VED(")/8W1A;"(*;7-G<W1R(")496YA;F<B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G
M<W1R(")/:W1O8F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS
M9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT97(@4&5L86YG9V%R
M86XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/
M9F9I8V4B"FUS9W-T<B`B2V%N=&]R(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S
M="!B92!D:69F97)E;G0N(@IM<V=S='(@(E-A;F1I(&QA;6$@9&%N(&)A<G4@
M:&%R=7,@8F5R8F5D82XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")386YD:2!L86UA
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E-A;F1I(&QA
M;6$@=&ED86L@8F5N87(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(DAA;GEA(')A;6%L86X@>6%N9R!T:61A:R!S;W!A;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DW,0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+B(*;7-G<W1R(")096YG9V%N=&D@86QA;6%T(&5M86EL(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*
M;7-G<W1R("(B"B)(86YY82!P96UI;&EK(&%T874@<VES=&5M(&%D;6EN:7-T
M<F%T;W(@<V%J82!Y86YG(&1A<&%T(&UE;F=U8F%H(&ME<&5M:6QI:V%N("(*
M(F%T874@<&5M:6QI:R!I>FEN('5N='5K(&)A9VEA;B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R(")"=6MA(&1I(&IE;F1E;&$@>6%N9R!B87)U(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")"=6MA(&QI;FL@:6YI
M(&1I(&IE;F1E;&$@>6%N9R!B87)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(E-I<W1E
M;2!/<&5R87-I(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U
M,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")0:6QI:&%N(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(E!I
M;&EH86X@=6YT=6L@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B
M1&%F=&%R($YO;6]R($)E<G5R=70B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-PHC+"!F=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N
M(@IM<V=S='(@(E1R86YS;&%S:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G
M:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B365N9V%T=7(B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@
M=&5M<&QA=&4B"FUS9W-T<B`B07!L:6MA<VD@=&5M<&QA=&4@87-L:2(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B5&5M<&QA=&4@
M87-L:2!D:2!D86QA;2`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H
M97(B"FUS9W-T<B`B3&%I;BUL86EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B26YF
M;W)M87-I($QA:6XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q
M"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("))>FEN(%!E;6EL
M:6LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*(RP@9G5Z
M>GD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D:6%K
M86XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I9"`B
M4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T
M960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED
M(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B
M2V]D92!02%`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(
M4"!3:&5L;"(*;7-G<W1R(")02%`@4VAE;&PB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I
M;B(*;7-G<W1R(")032!'97)I;6ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T
M<B`B4$T@1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(E!-($)E<G-A
M;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")032!'97)I;6ES
M(%-A;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")032!#97)A:"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")0
M32!4+5-T;W)M<R(*;7-G<W1R(")032!(=6IA;B!P971I<B!D:7-E<G1A:2!D
M96YG86X@86YG:6X@<FEB=70B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R
M(")%:W-T96YS:2!03U-)6"!T:61A:R!D:71E;75K86XB"@HC.B!L:6(O87!I
M+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4$A0(%-H96QL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")*87)A:R!S<&%S:2!D
M87)I(&)O<F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&%K
M:7-T86XB"FUS9W-T<B`B4V%L:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N86UA(@IM<V=S='(@(FYA;6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G
M:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4V5B86=I86X@0F5R87=A;B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*
M;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E-A;F1I(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4V%N9&D@8F5R:&%S:6P@9&EU8F%H
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC
M+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E-A
M;F1I(&QA;6$@=&ED86L@8F5N87(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PHC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2V5T:6L@<V%N9&D@9'5A
M(&MA;&D@=6YT=6L@;65N9VMO;F9I<FUA<VDB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")3
M86YD:3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I
M9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")386YD:3HB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R
M9',@;75S="!M871C:"XB"FUS9W-T<B`B4V%N9&D@:&%R=7,@8V]C;VLN(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM
M<V=S='(@(E-A;&EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS
M9W-T<B`B3&5K871K86X@9&%R:2!C;&EP8F]A<F0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM
M<V=S='(@(E!A=&@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")096YD869T87)A
M;B!Y86YG(&1I='5N9&$Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T
M"FUS9VED(")096]P;&4B"FUS9W-T<B`B3W)A;F<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N
M="(*;7-G<W1R(")097)S96XB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS(@IM<V=S='(@(DUE;&%K<V%N86MA;B!/<&5R87-I(%!E
M;65L:6AA<F%A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`B365L86MS86YA:V%N(&]P97)A<VD@<&5M96QI:&%R86%N('!A
M9&$@=V%K='4@;&]G:6X_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M27II;B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM
M<V=S='(@(DEZ:6X@=6YT=6L@7"(E<UPB('1I9&%K(&1A<&%T(&1I:&%P=7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z>GD*
M;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(DEZ:6XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B27II;B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P
M.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O
M:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@
M(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(DEZ:6X@061M
M:6YI<W1R87-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS9VED
M(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA<VD@4')I
M8F%D:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T
M<B`B0FEN871A;F<@2V5S87EA;F=A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B4&AO;F4B
M"FUS9W-T<B`B5&ED86L@861A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(E!I>&5L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(DMA=&$M:V%T82!K;&ES
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*
M;7-G<W1R(")3:6QA:V%N(&ML:6L@:V4@9&%L86T@8F5B97)A<&$@<V5L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(E-I;&%K86X@:V]N9FER
M;6%S:2!B86AW82!A;F1A(&EN9VEN(&UE;6EN9&%H:V%N(&5L96UE;B!I;FDZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(E-I;&%K86X@:V]N
M9FER;6%S:2!B86AW82!A;F1A(&EN9VEN(&UE;F=H87!U<R!L:6YK('5N='5K
M(&5L96UE;B!I;FDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W
M,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@
M>65A<BXB"FUS9W-T<B`B4VEL86MA;B!M87-U:VMA;B!N86UA('5N='5K(&MA
M=&5G;W)I('EA;F<@8F%R=3HB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B4VEL86MA;B!M87-U
M:VMA;B!N86UA('5N='5K(&MA=&5G;W)I('EA;F<@8F%R=3HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q
M"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S
M='(@(E-I;&%K86X@;6%S=6MK86X@<FEN9VMA<V%N('5N='5K(&UA<V%L86@N
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")3:6QA:V%N(&UA<W5K
M:V%N(&YA;6$@<&5N9V=U;F$@9&%N('-A;F1I(&%N9&$B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H
M92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R
M;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E-I;&%K86X@
M;65M8F%C82!T96MS(&)E<FEK=70@:6YI+B!!;F1A($A!4E53('-E='5J=2!D
M96YG86X@<WEA<F%T+7-Y87)A="`B"B)U;G1U:R!M96YG9W5N86MA;B!S:7-T
M96TN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B4VEL86MA;B!M87-U:VMA;B!N86UA
M('5N='5K(&MA=&5G;W)I('EA;F<@8F%R=3HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@
M9G5Z>GD*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")#;VUM86YD(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R
M(")0;VQI=&EK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM
M<V=I9"`B4&]L;',B"FUS9W-T<B`B4&]L;&EN9R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M(RP@9G5Z>GD*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1A;&MU(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM
M<V=S='(@(E!O<VES:2!U;G1U:R!G86UB87(@:6YI(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B4&]S:7-I('5N='5K('1A
M8F5L(&EN:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS
M9W-T<B`B2'5J86X@<V%L:G4@=6YT=6L@)7,@:F%M('1E<F%K:&ER.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I
M<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B2V5M=6YG:VEN86X@/&)R
M+SY(=6IA;B!S86QJ=2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P
M+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S
M=7)E(@IM<V=S='(@(E1E:V%N86XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B
M5&5K86YA;B!P861A('!E<FUU:V%A;B!L875T.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T
M<B`B5&5K86YA;CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R
M("),:6AA="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(DQI:&%T(&=A;6)A<B!D:2!D86QA
M;2!J96YD96QA('EA;F<@8F%R=2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V
M"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(DME
M;6)A;&D@:V4@4&EL:6AA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S
M='(@(D-E=&%K(&1O:W5M96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*
M;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B3W)A;F<B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B1&5S:W)I<'-I($UA<V%L86@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96LB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(X-0HC+"!F=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B1&%R
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET
M:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2
M:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@
M(E%A=&%R(@IM<V=S='(@(DMU;W1A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")1=65R>2(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B2W5O=&$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"B,L(&9U
M>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B4V%L:6X@4&EL
M:6AA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0S"FUS9VED(")286EN(@IM<V=S='(@(DAU:F%N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R
M;'DB"FUS9W-T<B`B2'5J86X@9&D@<&%G:2!H87)I(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T
M92(*;7-G<W1R(")(=6IA;B!B96)E<F%P82!S86%T(&QA9VDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I
M;B!3:&]W97(B"FUS9W-T<B`B1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W
M(@IM<V=S='(@(DAU:F%N(&1A;B!"97)S86QJ=2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N
M;W<B"FUS9W-T<B`B2'5J86X@8F5R8V%M<'5R(&1E;F=A;B!S86QJ=2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N
M92(*;7-G<W1R(")286UA;&%N($%C86LB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(E)A=&EO(@IM<V=S='(@
M(DAU:F%N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#`*;7-G:60@(E)E860B"FUS9W-T<B`B0F%C82(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A
M9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")9
M86MI;B!U;G1U:R!M96YG:&%P=7,@)7,_($]P97)A<VD@:6YI('1I9&%K(&1A
M<&%T(&1I8F%T86QK86XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(B(*(EEA:VEN('5N='5K(&UE;6EN9&%H:V%N
M(&1A=&$@<&5N9V=U;F$@=6YT=6L@<&5N9V=U;F$@)7,_($]P97)A<VD@:6YI
M('1I9&%K("(*(F1A<&%T(&1I8F%T86QK86XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B56QA;F=I(&%K<VD@=&5R86MH:7(@
M86YD82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN
M86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")2969R97-H($5L96UE;B!-
M96YU($1I;F%M:7,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM
M<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B4F5F<F5S:"!,
M:6AA="!0;W)T86PZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T
M<B`B071U<B!K96UB86QI("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*
M;7-G<W1R(")"86-A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G
M:60@(E)E;6%R:W,B"FUS9W-T<B`B1&ET86YD86DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R
M(")296UO=&4@4V5R=F5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")0:6YD86AK86XB"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C
M:R(*;7-G<W1R(")0:6YD86AK86X@0FQO:VER(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")(87!U<R!K;VQO;2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E
M;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E!I;F1A:&MA;B!#87)A($9O<FUA
M="(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")2
M96UO=F4@<&%I<B(*;7-G<W1R(")0:6YD86AK86X@<&%S86YG86XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@
M<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B4&EN9&%H:V%N('-C<FEP="!Y86YG('-U9&%H(&1I<VEM<&%N(&1A
M<FD@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A<F$N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED
M(")296UO=F4@=&AE(@IM<V=S='(@(E!I;F1A:&MA;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I
M9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R
M(")0:6YD86AK86X@;F]D92!I;FD@9&%R:2!D;VMU;65N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S
M97(B"FUS9W-T<B`B4&EN9&%H:V%N('!E;F=G=6YA(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")0:6YD86AK86X@<&5N9V=U;F$Z
M("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G
M:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO
M="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1I9&%K
M(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I("5S+B(*"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO
M;F9I9W5R87-I("5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@
M(D%T=7(@:V5M8F%L:2`B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B071U<B!K96UB
M86QI(%-A;F1I(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*
M;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B071U<B!K96UB
M86QI(%-A;F1I($%N9&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"B,L
M(&9U>GIY"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B1F%S
M92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86XB"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H
M96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")(87-I;"(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T
M<B`B2V5M8F%L:2!K92!0:6QI:&%N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S
M='(@(DME=&EK('5L86YG('-A;F1I(&)A<G4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L
M(&9U>GIY"FUS9VED(")2975N:6]N(@IM<V=S='(@(DIA;&%N:V%N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")+
M96UB86QI(&ME($MO;F9I9W5R87-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S
M='(@(E!I;&EH86X@161I=&]R(%)I8V@@5&5X="(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")496MA+71E
M:VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(DMA;F%N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*
M(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")$869T87(@
M5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R(")0<F]P97)T:2!"87)I<RXN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(E)O;&4B
M"FUS9W-T<B`B071U<F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G
M:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G
M<W1R(")0<F]P97)T:2!"87)I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T
M:65S(@IM<V=S='(@(E!R;W!E<G1I(&)A<FES(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM
M<V=S='(@(D)A<FES.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(D%T
M=7)A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B071U<F%N(&%K86X@9&ET
M86UP:6QK86X@9&EA;G1A<F$@<V5M=6$@8F%R:7,@9&%N(&MO;&]M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'DB"FUS9W-T<B`B071U<F%N(&%K86X@9&ET86UP:6QK86X@:&%N>6$@9&EA
M;G1A<F$@:V]L;VTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>2(*;7-G<W1R(")!='5R86X@86MA;B!D:71A;7!I
M;&MA;B!H86YY82!D:6%N=&%R82!B87)I<R(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R(")*86QA;FMA;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")2=V%N9&$B"FUS9W-T
M<B`B0F%C82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"B,L(&9U>GIY
M"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D%R96$@:V4@=V5A=&AE<BYC;VT@=&ED86L@9&ES961I86MA
M;BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")3
M35,@365S<V%G:6YG(@IM<V=S='(@(E!E<V%N(%--4R(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!3
M:&5L;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@
M(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM
M<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H
M96QL(@IM<V=S='(@(E-?44P@4VAE;&PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")3
M8G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V
M:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")3
M86EN="!,=6-I82(*;7-G<W1R(")(=6IA;B!B96)E<F%P82!S86%T(&QA9VDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E
M;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")&<F%M92!Y86YG('-A;6$@*%]S
M96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(E-A;6]A(@IM
M<V=S='(@(E-P86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3
M86X@36%R:6YO(@IM<V=S='(@(DUA<F=I;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G
M:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@
M4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U
M9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R(")3:6UP86XB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")3:6UP86X@
M)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E-I;7!A;B`E<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N
M<R(*;7-G<W1R(")3:6UP86X@4&EL:6AA;B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB4VEM<&%N(&MO;F9I9W5R
M87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!02%`@:V4@9&%L
M86T@9&ER96MT;W)I("(*(G-E<G9E<B!S96UE;G1A<F$@86YD82XB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+;VYF:6=U<F%S
M:2`E<R!S=61A:"!D:7-I;7!A;BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B4V-R:7!T
M('-E='5P('5P9W)A9&4@<W5D86@@9&ES:6UP86X@:V4Z("<E<R<N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@
M(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")396)A9VEA;B!(=6IA;B!P
M971I<B!D:7-E<G1A:2!A;F=I;B!R:6)U="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("));&UU(%!E;F=E
M=&%H=6%N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C
M:"(*;7-G<W1R(")096YC87)I86XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")-97-I
M;B!096YC87)I86XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S
M"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")0:6QI:"!S97)V97(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@
M9W)O=7`@=&\@861D(@IM<V=S='(@(E!I;&EH(&=R=7`@=6YT=6L@9&ET86UB
M86@B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")3
M96QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4&EL:6@@<&5M:6QI:R!B87)U
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")3
M96QE8W0@82!S97)V97(B"FUS9W-T<B`B4&EL:6@@<V5R=F5R(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S
M97(@=&\@861D(@IM<V=S='(@(E!I;&EH('!E;F=G=6YA('5N='5K(&1I=&%M
M8F%H(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")(87!U
M<R!S96PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T
M<B`B4&EL:6@@9F]R;6%T('1A;F=G86PZ(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&%N(&]B:F5C="(*;7-G<W1R(")0:6QI:"!P96UI;&EK(&)A<G4B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")0:6QI:"!P96UI
M;&EK(&)A<G4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)0:6QI:"!K87)A
M:W1E<B!Y86YG(&%N9&$@<&5R;'5K86X@9&%R:2!K;W1A:RUK;W1A:R!D:6)A
M=V%H(&EN:2X@06YD82!D87!A="`B"B)M96YY86QI;B!D86X@;65L96MA=&MA
M;FYY82!K92!D86QA;2!A<F5A('1E:W,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M(@IM<V=S='(@(E!I;&EH(&)A=&%S('1A;F=G86PZ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M
M870Z(@IM<V=S='(@(E!I;&EH(&9O<FUA="!T86YG9V%L.B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")0
M:6QI:"!I9&5N=&ET87,@>6%N9R!I;F=I;B!D:75B86@@;VQE:"!A;F1A.B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")0:6QI:"!B871A<R!W86MT
M=3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4&EL:6@@9F]R;6%T('=A
M:W1U.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@
M(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")0:6QI:"!D
M=6$@:V]L;VT@>6%N9R!C;V-O:RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S
M='(@(E!I;&EH('=A<FYA('-C:&5M92!A;F1A+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93HB"FUS9W-T<B`B4&EL:6@@8F%H87-A('EA;F<@86YD82!I;F=I
M;FMA;CHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM
M<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")+:7)I;2!,87!O
M<F%N($UA<V%L86@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B
M4V5N<V]R.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P=&5M8F5R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@
M(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0HC+"!F=7IZ>0IM<V=I9"`B
M4V5R:6%L($YU;6)E<B(*;7-G<W1R(")!;F=K82!$97-I;6%L(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B
M4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R("))>FEN($%D;6EN:7-T<F%S:2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)
M1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@
M9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(DEZ:6XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"B,L(&9U>GIY"FUS9VED(")3970B
M"FUS9W-T<B`B4V5T=7`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*
M;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB
M071U<B!P:6QI:&%N('5N='5K(&UE;F=I>FEN:V%N(&%N9&$@9&%P870@;65N
M9V%T=7(@=6QA;F<@:V5M8F%L:2!S86YD:2!A;F1A("(*(F%P86)I;&$@86YD
M82!L=7!A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@
M(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S
M<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")!='5R(')E;6]T92!S97)V
M97(@>6%N9R!I;F=I;B!A;F1A(&%K<V5S(&1A<FD@<&]R=&%L(&%N9&$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N
M(@IM<V=S='(@(D%T=7(@8F%H87-A+"!Z;VYA('=A:W1U(&1A;B!P:6QI:&%N
M('1A;F=G86PL('EA;F<@86YD82!I;F=I;FMA;BXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)!='5R(&%P
M;&EK87-I(&%W86P@86YD82P@=V%R;F$@<V-H96UE+"!H86QA;6%N(')E9G)E
M<V@@9&%N('!I;&EH86X@=&%M<&EL86X@(@HB;&%I;FYY82XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R(")3
M971U<"(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W
M"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S
M='(@(E-C<FEP="!S971U<"!U<&=R861E('1E<G-E9&EA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A
M=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B
M0F5B97)A<&$@;&]K87-I('EA;F<@;75N9VMI;B!D96YG86X@<&%R86UE=&5R
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO
M<'!I;F<B"FUS9W-T<B`B0F5L86YJ82(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@
M(E)I;F=K87-A;B!096YD96LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\B"FUS9W-T<B`B4&5R;'5K86@@:W5N8VD@86MS97,@9&ED
M969I;FES:6MA;B!U;G1U:R!K96)A;GEA:V%N(&QI;FL_(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS
M9W-T<B`B5&%M<&EL:V%N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U
M-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B)486UP:6QK86X@<&5R8F5D86%N(&1I86YT87)A
M(&MO;F9I9W5R87-I('EA;F<@8F%R=2!D:7-I;7!A;B!D86X@>6%N9R!B87)U
M("(*(F1I:&%S:6QK86XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y
M,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/R(*;7-G<W1R(")486UP:6QK86X@=V%K='4@;&]G:6X@=&5R86MH:7(@:V5T
M:6MA(&%N9&$@;&]G:6X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"B,L(&9U
M>GIY"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")'97)I;6ES(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")486UP:6QK86X@<&%N96P@
M;65N=2!T86)E;"!O<&5R87-I/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\B"FUS9W-T<B`B5&%M<&EL:V%N($UE;G4@)7,@9&D@<V5B
M96QA:"!K:7)I/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486UP:6QK86X@9&EA;&]G
M(%!R;W!E<G1I(%-E;"!486)E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@
M5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%M<&EL:V%N(&1I
M86QO9R!0<F]P97)T:2!486)E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@
M5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A;7!I;&MA
M;B!D:6%L;V<@4')O<&5R=&D@0F%R:7,@5&%B96PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@
M(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A
M;7!I;&MA;B!D:6%L;V<@<')O<&5R=&D@9V%M8F%R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B1V5R:6UI<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W
M97)S($5A<FQY(@IM<V=S='(@(D=E<FEM:7,@9&D@<&%G:2!H87)I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@
M(E-H;W=E<G,@3&%T92(*;7-G<W1R(")'97)I;6ES(&)E8F5R87!A('-A870@
M;&%G:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")'
M97)I;6ES(&1I('-E:VET87(@9&%E<F%H(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*
M;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@HC+"!F=7IZ>0IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(D1A9G1A<B!"
M86-A86XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("),97=A=&D@
M4&5M96QI:&%R86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B4V%L:G4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3
M:&]W97(B"FUS9W-T<B`B1V5R:6UI<R!386QJ=2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B1V5R:6UI<R!386QJ=2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@
M16%R;'DB"FUS9W-T<B`B1V5R:6UI<R!386QJ=2!D:2!P86=I(&AA<FDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I
M9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B1V5R:6UI<R!386QJ=2!B
M96)E<F%P82!S86%T(&QA9VDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W
M.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(DME9&%L86UA;B!386QJ
M=3HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B4&5R8F%N9&EN9V%N('-A
M;&IU(&1I("AD86QA;2D@86ER.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O
M;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("),86=U("8@4V%J
M86LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"B,L(&9U>GIY
M"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")(87!U<R!P
M:6QI:&%N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E
M<W,B"FUS9W-T<B`B06QA;6%T($5M86EL($%N9&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*2(*;7-G<W1R(")%<F]P82!396QA=&%N("A)4T\M.#@U.2TS*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE
M<FX@2&5M:7-P:&5R92(*;7-G<W1R(")"96QA:&%N($)U;6D@4V5L871A;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S
M"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@
M(DIA<F%K(&%N=&%R82!S96P@>6%N9R!B97)D96MA=&%N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P
M86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T
M<B`B2F%R86L@86YT87)A(&ES:2!D86X@8F]R9&5R(&1I(&1A;&%M('-E;"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(DIA<F%K('-P87-I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3
M<&%C:6YG(@IM<V=S='(@(DIA<F%K('-P87-I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A
M8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")*87)A:R!S<&%S:2!D86X@:F%R
M86L@<W!A<VD@9&%R:2!B;W)D97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM
M<V=I9"`B4W!A:6XB"FUS9W-T<B`B2F%R86L@<W!A<VDB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A
M;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B36%S=6MK86X@2V%R86MT97(@
M4W!E<VEA;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B4&ES
M86AK86X@4V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@
M(E!I<V%H:V%N(&MO;&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S
M='(@(E!I<V%H:V%N(&)A<FES(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B3VQA:')A9V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@
M(E!E<FIA;&%N86X@0FEN=&%N9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0HC+"!F=7IZ
M>0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")097)J86QA;F%N($)I;G1A
M;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*
M;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$U"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")&
M;W)M870@5V%K='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")!;F=K82]H=7)U9B]S:6UB;VP@
M>6%N9R!D:6)E<FD@=&%N9&$@9V%R:7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED
M(")3='EL92!;0U-372(*;7-G<W1R(")'87EA(%M#4U-=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B
M"FUS9W-T<B`B36EN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4W5B9&ER96MT;W)I("<E<R<@=&ED86L@
M9&ET96UU:V%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B
M06YG:V$O:'5R=68O<VEM8F]L('EA;F<@9&ET=6QI<R!D:6)A=V%H(&=A<FES
M(&)A<FES('1E:W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"B,L(&9U>GIY
M"FUS9VED(")3=6)M:70B"FUS9W-T<B`B06YG:V$O:'5R=68O<VEM8F]L('EA
M;F<@9&ET=6QI<R!D:6)A=V%H(&=A<FES(&)A<FES('1E:W,B"@HC.B!S:6=N
M=7`N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M
M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO
M=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E
M96X@87!P<F]V960N(@IM<V=S='(@(B(*(B!097)M:6YT86%N('EA;F<@9&ES
M86UP86EK86X@=6YT=6L@;65N86UB86AK86X@)R4@<R<@:V4@9&%L86T@<VES
M=&5M+B!!;F1A("(*(G1I9&%K(&1A<&%T(&QO9R!I;B!S86UP86D@<&5R;6EN
M=&%A;B!A;F1A('1E;&%H(&1I<V5T=6IU:2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B
M"FUS9W-T<B`B06YG:V$O:'5R=68O<VEM8F]L('EA;F<@9&ET=6QI<R!D:6)A
M=V%H(&=A<FES(&)A<FES('1E:W,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B
M0F5R:&%S:6PB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G('-U9&%H(&)E<FAA<VEL(&1I=&%M
M8F%H:V%N(&ME(&1A;&%M('-I<W1E;2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B1&%T82!U;G1U:R!P96YG9W5N82`G)7,G('-U9&%H(&)E<FAA
M<VEL(&1I8F5R<VEH:V%N(&1A<FD@<VES=&5M+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(G-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G
M<W1R("(G)7,@<W5D86@@8F5R:&%S:6P@9&EP:6YD86AK86X@9&%R:2!S:7-T
M96TN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S
M964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A<VD@<W5D86@@8F5R
M:&%S:6P@9&EK96UB86QI:V%N+B!5;&%N9VD@=6YT=6L@;65L:6AA="!P97)U
M8F%H86XN("(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")"86-K=7`@:V]N9FEG
M=7)A<VD@<W5D86@@8F5R:&%S:6P@9&ES:6UP86XN(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(D9I;&4@0F%C:W5P($MO;F9I9W5R87-I("5S('-U9&%H(&)E
M<FAA<VEL(&1I<VEM<&%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M7"(E<UPB(@IM<V=S='(@(B<E<R<@<W5D86@@8F5R:&%S:6P@9&EP97)B86AA
M<G5I(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('=R;W1E("5S(@IM<V=S='(@(B<E<R<@<W5D86@@8F5R:&%S:6P@9&ET
M=6QI<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-U9&%N(@IM
M<V=S='(@(D-E<F%H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")2
M:6YG:V%S86XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@
M(E-U;B!2:7-E(@IM<V=S='(@(DUA=&%H87)I(%1E<F)I="(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")-
M871A:&%R:2!497)B96YA;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R(")#97)A:"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U
M;G)I<V4B"FUS9W-T<B`B36%T86AA<FD@5&5R8FET(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED
M(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")-871A:&%R:2!497)B:70O36%T
M86AA<FD@5&5R8F5N86TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B36%T86AA<FD@5&5R
M8FET.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G
M:60@(E-U;G-E="(*;7-G<W1R(")-871A:&%R:2!497)B96YA;2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@
M(@IM<V=S='(@(DUA=&%H87)I(%1E<F)E;F%M.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R
M:7!T(@IM<V=S='(@(D%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG(&1I='5L:7,@
M9&EA=&%S(&)A<FES('1E:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D1U:W5N9V%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B
M;F%M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T
M"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(FYA;6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO
M9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I
M;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O
M<FTB"FUS9W-T<B`B2'5J86X@<&5T:7(@9&ES97)T86D@9&5N9V%N(&%N9VEN
M(')I8G5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(DAU:F%N
M('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!B861A:2!A;F=I;B!R:6)U="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED
M(")4+5-T;W)M<R(*;7-G<W1R(")(=6IA;B!P971I<B!D:7-E<G1A:2!D96YG
M86X@86YG:6X@<FEB=70B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB
M"FUS9W-T<B`B1V5R:6UI<R!D:2!P86=I(&AA<FDB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL
M92(*;7-G<W1R(")*=61U;"(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP
M:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R(")$869T87(@
M5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!E<G1I(%1A8F5L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4V5T(@IM
M<V=S='(@(E!R;W!E<G1I(%1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O
M<&5R=&EE<R(*;7-G<W1R(")0<F]P97)T:2!T86)E;"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")(=6IA
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS
M9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(E1A<F=E=#HB
M"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(E1U9V%S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@
M(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(E-U:'4@=6YT=6L@:F%M('1E<F%K:&ER.B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")3=6AU
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B
M5&5M<&5R871U<F4Z("(*;7-G<W1R(")3=6AU.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R
M(")3=6AU/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B1&ER96MT;W)I($UO=&EF("<E<R<@=&ED86L@9&ET96UU:V%N+B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")496UP;&%T92!!9&UI;FES=')A<VDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,S8*(RP@9G5Z>GD*;7-G:60@(E1E>'0B"FUS9W-T
M<B`B0F5R:6MU=&YY82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*
M;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")(86YY82!496MS(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM
M<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")097)A=&%A;B!496MS(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I
M9"`B5&5X='1O<"(*;7-G<W1R(")496MS($)A9VEA;B!!=&%S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B
M5&@B"FUS9W-T<B`B2VUS(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*
M;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1H86D@*%1)4RTV,C`I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"B,L(&9U>GIY"FUS9VED(")4:&4@
M1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!<F5A
M(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B4&5M
M96QI:&%R86%N.CH@8VQA<W,@=&ED86L@8F5R:&%S:6P@9&EP86YG9VEL(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S
M='(@(E=I;F1O=R!0:6QI:&%N('-U9&%H(&1I='5T=7`N(%-I;&%K86X@2V5L
M=6%R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!0
M97)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O
M;2!S:61E(&]N;'DB"FUS9W-T<B`B2&%N>6$@<VES:2!B86=I86X@8F%W86@B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K
M(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO
M="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS
M9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S
M"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@
M8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL
M;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E
M;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N
M970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W
M97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE
M;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N
M9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@
M(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB36]D92!,87EA
M<B!096YU:"!D:6ME;F%L(&1A<&%T(&UE;GEE8F%B:V%N(&UA<V%L86@@9&5N
M9V%N($EN=&5R;F5T($5X<&QO<F5R+"`B"B)J=6=A('5N='5K(&UE;F-A<FD@
M:V5S86QA:&%N('EA;F<@;65N>65B86)K86X@86YD82!T:61A:R!M86UP=2!B
M96ME<FIA("(*(F1E;F=A;B!B86EK+B!!;F1A(&UU;F=K:6X@<&5R;F%H(&UE
M;F=A;&%M:2!T86UP:6QA;B!Y86YG(&)U<G5K+"!K96MU<F%N9V%N("(*(F1A
M<FD@9G5N9W-I(&5D:71O<B!D86XO871A=2!B<F]W<V5R('EA;F<@<V5R:6YG
M(&MA;&D@<G5S86L@9&%N(&AA<G5S(&1I=6QA;F<@(@HB:V5M8F%L:2X@2FEK
M82!S:7-T96T@86YD82!A9&%L86@@5VEN9&]W<R`Y>"!A9&$@:V5M=6YG:VEN
M86X@86YD82!A:V%N("(*(FUE;F1A<&%T:V%N("=+97-A;&%H86X@4&5R;&EN
M9'5N9V%N(%5M=6TG(&1A;B!P97)L=2!U;G1U:R!M92UR97-T87)T("(*(FMO
M;7!U=&5R(&%N9&$N7%QN7%QN($%N9&$@<W5D86@@9&EP97)I;F=A=&DN(%-I
M;&%K86X@:VQI:R!/2R!J:6MA(&%N9&$@:6YG:6X@(@HB;65N8V]B82!E9&ET
M;W(@;&%Y87(@<&5N=6@N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&%S(%PB)7-<(B!S=61A:"!D
M:6AA<'5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(DAA;GEA('-I<VD@8F%G:6%N(&MI<FDB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB
M)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A
M;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S
M=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T
M:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0T,0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@
M;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E
M(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS
M-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H
M<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H
M<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS
M9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(")(
M86YY82!S:7-I(&)A9VEA;B!K86YA;B!D86X@:VER:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@
M(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")(86YY82!S:7-I
M(&)A9VEA;B!K86YA;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")397)V97(@7"(E<UPB
M('-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(E-E<G9E<B!<(B5S
M7"(@<W5D86@@8F5R:&%S:6P@9&ES:6UP86XN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B4&5R;6EN=&%A
M;B!P96YD869T87)A;B!U;G1U:R`E<R!S=61A:"!B97)H87-I;"!D:7!I;F1A
M:&MA;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS
M,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M(@IM<V=S='(@(DAA;GEA('-I<VD@8F%G:6%N(&%T87,@9&%N(&)A=V%H(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B2&%N>6$@
M<VES:2!B86=I86X@871A<R(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%R96$@:V4@=V5A=&AE<BYC
M;VT@=&ED86L@9&ES961I86MA;BXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B1&ER96MT;W)I($UO
M=&EF("<E<R<@=&ED86L@9&ET96UU:V%N+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(D%R96$@365T87(@=&ED
M86L@9&ES961I86MA;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N
M(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B061A(&UA<V%L86@@:V5T:6MA(&UE;F%M
M8F%H:V%N("<E<R<@:V4@9&%L86T@<VES=&5M.B`E<R`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B061A(&UA<V%L86@@:V5T:6MA
M(&UE;6)E<G-I:&MA;B!D871A('5N='5K('!E;F=G=6YA("<E<R<@9&%R:2!S
M:7-T96TZ(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")!9&$@;6%S86QA:"!K
M971I:V$@;65M:6YD86AK86X@)R5S)R!D87)I('-I<W1E;3HB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R
M(")!9&$@;6%S86QA:"!K971I:V$@;65M<&5R8F%H87)U:2`G)7,G.B5S(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"B)!9&$@:V5S86QA:&%N(&1I(&1A;&%M(&9O
M<FUU;&ER(&MO;F9I9W5R87-I+B!-=6YG:VEN(&%N9&$@=&ED86L@;65N9VES
M:2`B"B)K;VQO;2!Y86YG(&1I<&5R;'5K86XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D
M<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D%D82!K97-A;&%H86X@
M9&D@9&%L86T@9F]R;75L:7(@:V]N9FEG=7)A<VDN($UU;F=K:6X@86YD82!T
M:61A:R!M96YG:7-I("(*(FMO;&]M('EA;F<@9&EP97)L=6MA;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@HC+"!F
M=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@HB061A(&ME<V%L86AA;B!D:2!D86QA;2!F;W)M=6QI<B!K
M;VYF:6=U<F%S:2X@375N9VMI;B!A;F1A('1I9&%K(&UE;F=I<VD@(@HB:V]L
M;VT@>6%N9R!D:7!E<FQU:V%N+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS
M9W-T<B`B0G)O=W-E<B!A;F1A('1I9&%K(&UE;F1U:W5N9R!U;G1U:R!F:71U
M<B!I;FDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*
M(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC
M;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V
M86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P
M86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L
M9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&ES("5S+B(*;7-G<W1R("));FD@861A;&%H("5S+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V
M:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI
M96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M
M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S
M92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS
M-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/
M<'1I;VYS('=I;F1O=R(*;7-G<W1R(")7:6YD;W<@:6YI(&AA<G5S(&1I<&%N
M9V=I;"!D87)I(%!I;&EH86X@5VEN9&]W(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T
M<B`B4&5T:7(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS
M9VED(")4:6-K971S(@IM<V=S='(@(E1I:V5T(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`B2G5D=6PB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K
M:6YG(@IM<V=S='(@(DUE;F=I:W5T:2!786MT=2(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B1F]R;6%T
M(%=A:W1U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0HC+"!F
M=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL
M:6AA;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM
M<V=S='(@(DIU9'5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R
M(")*=61U;"`H0V%T871A;B!P971U;FIU:RDB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")4
M;R(*;7-G<W1R(")!=&%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B2&%R:2!);FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B
M"FUS9W-T<B`B1V%N=&D@4V]U<F-E($A434PB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O
M:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B0F5S;VLB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;VYG82(*;7-G<W1R(")(87)I
M($EN:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(D%T87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4
M;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(D9R86UE($%T87,@*%]T;W`I(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO
M;G,B"FUS9W-T<B`B5')A;G-L87-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(E-E;"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)K
M:2`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(DEN9&5K<R!5+E8Z(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO
M:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS
M9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B1V%R:7,@
M8F%W86@B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G
M:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U
M<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT
M=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S<6PN<&AP.C0S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B5&ED86L@9&%P870@=&5R
M:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K
M(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B5&ED
M86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G
M<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P
M=7,@7"(E<UPB.B`E<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")4:61A:R!D87!A
M="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M
M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N
M9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")4:61A:R!D87!A
M="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*
M;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L
M9&5R(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA
M<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B5&ED86L@9&%P
M870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@
M97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS
M9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S
M(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX,S4*;7-G
M:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C8*
M;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I
M(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(E1I9&%K(&1A<&%T
M('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS-#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")4:61A:R!D87!A
M="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E1I9&%K
M(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL
M;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM
M<V=S='(@(D=A<FES(&)A=V%H(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D)A=&%L:V%N(%!E
M<G5B86AA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S
M='(@(D)A=&%L:V%N(&%K<VD@=&5R86MH:7(@86YD82(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(E1I9&%K(&1I
M87)S:7!K86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-
M:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q
M"FUS9VED(")5;FET<R(*;7-G<W1R(")5;FET(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G
M:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S
M<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(E1I9&%K(&%D82!L;VMA<VD@>6%N9R!D:6%T
M=7(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(D)A=&%L:V%N(&QI;FL@<&%D82!E;&5M96X@
M>6%N9R!S96MA<F%N9R(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(FYA
M;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C
M=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N
M;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S
M='(@(B(*(E-C<FEP="!Y86YG('1I9&%K(&UE;7!U;GEA:2!H86L@:7-T:6UE
M=V$@=&ED86L@9&%P870@;65N9V%K<V5S($AA<'5S+U-A;&EN+R(*(DQE:V%T
M:V%N('-E<W5A:2!R96YC86YA('5N='5K(&%L87-A;B!K96%M86YA;BY+;&EK
M($]+('5N='5K(&UE;&EH870@8V%T871A;B`B"B)T96MN:7,@<&%D82!M;WII
M;&QA+F]R9R!D:6UA;F$@86YD82!A:V%N(&1I<&5R;&EH871K86X@8V%R82!B
M86=A:6UA;F$@=6YT=6L@(@HB;65N9VEZ:6YK86X@<V-R:7!T('5N='5K(&1A
M<&%T(&UE;F=A:W-E<R!K92!C;&EP8F]A<F0N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS
M970@8V]L;W(B"FUS9W-T<B`B5V%R;F$@8F5L=6T@9&EA='5R(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B
M57!D871E(@IM<V=S='(@(E!E<F)A:&%R=6DB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T92`E<R(*;7-G<W1R(")097)B86AA<G5I("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`B4&5R8F%H87)U:2!P96YG9W5N82(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@<W5D86@@9&EP97)B86AA<G5I
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R
M861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")38W)I<'0@=7!G<F%D92!S
M=61A:"!D:6AA<'5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I
M9"`B57!L;V%D(@IM<V=S='(@(E5P;&]A9"(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")396UU82!F:6QE
M('-E='5P(&%P;&EK87-I('-U9&%H(&1I=7!L;V%D(&ME('-E<G9E<BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(E-I
M;6)O;"!H=7)U9B!B97-A<B!L871I;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B4VEM8F]L(&AU<G5F(&)E<V%R(')O
M;6%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT
M.B`E<R(*;7-G<W1R(")&87-E(%-E:V%R86YG(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!3
M4TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM
M<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BXB"FUS9W-T<B`B1W5N86MA;FQA:"!J:6MA(&YA;6$O<V%N
M9&D@86YD82!B97)B961A('5N='5K('-E<G9E<B!)35-0+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@
M(E5S97(B"FUS9W-T<B`B4&5N9V=U;F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%S:2!096YG9W5N82(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"B,L(&9U>GIY"FUS9VED(")5
M<V5R($]P=&EO;G,B"FUS9W-T<B`B4VEM<&%N(%!I;&EH86XB"@HC.B!S:6=N
M=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")0
M96YD869T87)A;B!096YG9W5N82(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@
M(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N(@IM<V=S='(@(E!E;F1A9G1A<F%N(%!E;F=G=6YA('-U9&%H(&1I
M;F]N+6%K=&EF:V%N('5N='5K('-I=&4@:6YI+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B
M"FUS9W-T<B`B06-C;W5N="!096YG9W5N82!T:61A:R!D:71E;75K86XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(").
M86UA(%!E;F=G=6YA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DYA
M;6$@4&5N9V=U;F$Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(").86UA(%!E;F=G=6YA.B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E!E;F=G=6YA(&1I(&1A;&%M
M('-I<W1E;3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@
M(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E-U8F1I
M<F5K=&]R:2`G)7,G('1I9&%K(&1I=&5M=6MA;BXB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R("),
M:6)U<F%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"B,L(&9U
M>GIY"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")+96QE;6)A8F%N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@
M=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R(")687)I86)L
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I
M9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"B,L(&9U>GIY"FUS9VED(")6
M97)S:6]N(@IM<V=S='(@(E9E<G-I($MO;G1R;VPB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS
M9W-T<B`B5F5R<VD@2V]N=')O;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L
M:6=N(@IM<V=S='(@(DIA<F%K('!O<VES:2!V97)T:6MA;"!A;G1A<F$@9V%R
M:7,@9&%S87(@9&5N9V%N(&=A;6)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I
M;F<B"FUS9W-T<B`B2F%R86L@<&]S:7-I('9E<G1I:V%L(&%N=&%R82!B;W)D
M97(@9&5N9V%N(&=A;6)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")6
M97)T:6MA;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(E-A;F=A="!4:6YG
M9VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S
M92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M("A625-#24DI(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*
M;7-G<W1R("),:6AA="!W96(@<&%G92!E:W-T97)N86PB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I
M;&ET>2(*;7-G<W1R(")*87)A:R!086YD86YG(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S
M='(@(DIA<F%K(%!A;F1A;F<Z(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET
M86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G
M:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E!%4DE.1T%404XA
M(2$@4$E.1$%(2T%.(%-#4DE05"!)3DD@4T5#05)!($U!3E5!3"!$05))("5S
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S
M"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N
M:6YG(@IM<V=S='(@(E!E<FEN9V%T86XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")2
M86)U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED
M(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(E)A;6%L86X@0W5A8V$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T
M:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B1&%T82!#=6%C82!D:7-E
M9&EA:V%N(&]L96@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*
M(RP@9G5Z>GD*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N
M8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R(")796(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W
M"FUS9VED(")796(@4VET92(*;7-G<W1R(")796(@4VET92(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E
M96ML>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")396QA;6%T($1A=&%N9R(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE
M('1O("5S(@IM<V=S='(@(E-E;&%M870@9&%T86YG(&ME("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM
M<V=S='(@(E-E;&%M870@9&%T86YG+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R
M(")797-T97)N("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B
M5V5S=&5R;B`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E
M<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B07!A
M:V%H(&%P;&EK87-I("5S('!E<FQU(&1I=&%M<&EL:V%N('-E=&5L86@@;&]G
M:6X_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@
M(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(D%P
M86MA:"!Y86YG(&UE<G5P86MA;B!B871A<R!K87)A:W1E<C\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")!<&%K86@@>6%N9R!M97)U<&%K
M86X@:V%R86MT97(@:6YD96YT87-I/R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R
M86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S
M"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B1F%S92!Y86YG(&UA;F$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM
M<V=S='(@(E!L=6=I;B!M86YA:V%H('EA;F<@9&%P870@9&EA:W1I9FMA;B!U
M;G1U:R!E9&ET;W(@4FEC:"!497AT+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM
M<V=S='(@(DQE8F%R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M-0HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@
M(DQE8F%R('5N:70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R
M("(B"B),96)A<B!M96YU("5S('!A9&$@8F%G:6%N(&MI<FD@*&%K86X@8F5R
M<&5N9V%R=6@@<&%D82!L;V=I;B!B97)I:W5T;GEA*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T
M:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B3&5B87(@=&%B96PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B
M5VED=&@@=6YI="(*;7-G<W1R("),96)A<B!U;FET(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H
M.B(*;7-G<W1R("),96)A<CHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(D%N9VEN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*
M;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B06YG:6X@9&D@<&%G:2!H87)I
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E
M9"!I;B!K;F]T<R(*;7-G<W1R(")+96-E<&%T86X@86YG:6X@9&D@9&%L86T@
M:VYO="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD
M.B(*;7-G<W1R(")!;F=I;CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B06YG:6XZ(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T
M<B`B2V%T82!":6IA:W-A;F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")$869T87(@2V5I;F=I
M;F%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K
M(@IM<V=S='(@(E!E:V5R:F%A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!!9&1R
M97-S(@IM<V=S='(@(D%L86UA="!%;6%I;"!!;F1A(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0
M:&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E
M9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B
M6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED
M(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S
M(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(EE9(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9
M(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM
M<V=I9"`B665A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I
M9"`B665S+"!)($%G<F5E(@IM<V=S='(@(EEA+"!305E!(%-%5%5*52(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G
M:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)!;F1A
M(&)E<F%D82!D:2!D86QA;2!-3T1%(%1%2U,N($=U;F%K86X@=&]M8F]L(%L\
M/ET@=6YT=6L@;65N9V=A;G1I(&ME;6)A;&D@(@HB:V4@9&%L86T@;6]D92!7
M65-)5UE'+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T
M92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")!;F1A('1I9&%K(&1I
M:7II;FMA;B!U;G1U:R!M96UB=6%T(&QE8FEH(&1A<FD@)60@87)E82XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO
M="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"B,L(&9U>GIY"FUS9VED(")9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S
M='(@(E!E;F=G86YT:2!A;&%M870@96UA:6PB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)!;F1A(&AA<G5S(&UE;FIE;&%S
M:V%N(&UA<V%L86@@<V5B96QU;2!A;F1A(&1A<&%T(&UE;F=I<FEM:V%N(&QA
M<&]R86X@(@HB;6%S86QA:"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B06YD82!H
M87)U<R!M96UA<W5K:V%N(%523"!D:6UA;F$@;&EN:R!I;FD@;65N=6YJ=6L@
M:V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R(")!;F1A(&AA<G5S(&UE;6EL:6@@<V5R=F5R('5N='5K(&1A<&%T(&1I
M:&%P=7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")!
M;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!Y86YG(&EN9VEN
M(&1I8F5R<VEH:V%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T
M<B`B06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@>6%N9R!I
M;F=I;B!D:7!I;F1A:&MA;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B06YD82!H
M87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@=6YT=6L@9&ET86UB86@N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(D%N9&$@:&%R
M=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('5N='5K(&1I<&5R8F%H87)U
M:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B06YD82!H87)U<R!M96YE=&%P:V%N
M(&YA;6$@<&5N9V=U;F$@>6%N9R!I;F=I;B!D:7!I;F1A:&MA;BXB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG
M9W5N82!Y86YG(&EN9VEN(&1I<&EN9&%H:V%N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D
M<F5S<R(*;7-G<W1R(")!;&%M870@16UA:6P@06YD82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB
M"FUS9W-T<B`B06YD82!$87)I.B!A;&%M870Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y
M"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%S:2!!
M;F1A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(").86UA($%N9&$B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ
M>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB
M"FUS9W-T<B`B(@HB0F%C:V5N9"!A<VQI(&%N9&$@=&ED86L@9&%P870@;65N
M9'5K=6YG('!E;F%M8F%H86X@<&5N9V=U;F$L(&%T874@9FET=7(@:6YI("(*
M(G-U9&%H(&1I;F]N+6%K=&EF:V%N('5N='5K(&)E8F5R87!A(&%L87-A;B!L
M86EN+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R
M("(B"B)"86-K96YD(&%S;&D@86YD82!T:61A:R!D87!A="!M96YD=6MU;F<@
M<&5N9&%F=&%R86X@<&5N9V=U;F$L(&%T874@9FET=7(@:6YI("(*(G-U9&%H
M(&1I;F]N+6%K=&EF:V%N('5N='5K(&)E8F5R87!A(&%L87-A;B!L86EN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G
M:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92XB"FUS9W-T<B`B0G)O=W-E<B!A;F1A('1I9&%K(&UE;F1U:W5N9R!U;G1U
M:R!F:71U<B!I;FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N
M:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O
M;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)"<F]W<V5R(&%N
M9&$@=&ED86L@;65N9'5K=6YG('!I;&EH86X@=6YT=6L@;65N8V5T86LN(%1E
M:V%N($-O;G1R;VPO4&EL:6AA;B`K("(*(E`@=6YT=6L@;65N8V5T86LN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R
M96YT('1I;64@>F]N93HB"FUS9W-T<B`B6F]N82!786MT=2!!;F1A(%-E:V%R
M86YG.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@IM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(D1E
M9F%U;'0@:61E;G1I=&%S(&%N9&$@<W5D86@@9&EU8F%H+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N
M=&ET>3HB"FUS9W-T<B`B1&5F875L="!I9&5N=&ET87,@86YD83HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"FUS9VED(")9;W5R(&9U;&P@;F%M
M93HB"FUS9W-T<B`B3F%M82!L96YG:V%P(&%N9&$Z(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z,3`P,`IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M9F]R("5S(&ES.B`E<R(*;7-G<W1R(")386YD:2!B87)U(&%N9&$@=6YT=6L@
M)7,@861A;&%H.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@
M9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"B,L(&9U>GIY
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S
M='(@(D1E9F%U;'0@:61E;G1I=&%S(&%N9&$@<W5D86@@9&EU8F%H+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E-A;F1I(&%N9&$@<W5D
M86@@9&EA='5R('5L86YG(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L
M(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*
M(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)386YD:2!A;F1A('-U9&%H(&1I871U
M<B!U;&%N9RP@<&5R:6MS86QA:"!E;6%I;"!A;F1A(&1A;B!L;V=I;B!D96YG
M86X@(@HB;65N9V=U;F%K86X@<V%N9&D@8F%R=2!A;F1A(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S,R"B,L(&9U>GIY"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")386YD:2!A;F1A('-U9&%H
M(&1I871U<B!U;&%N9R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B4F5M
M;W1E('-E<G9E<B!A;F1A.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B
M0V5R86@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G
M<W1R(")#97)I82(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT
M72(*;7-G<W1R(");4V5M8G5N>6EK86X@26YD96YT87-I(%1E:W-=(@H*(SH@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R
M=%TB"FUS9W-T<B`B6TQA<&]R86X@36%S86QA:%TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2(*;7-G<W1R(");5&%M<&EL86X@26YD96YT87-I(%1E:W,@
M+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM486UP:6QA
M;B!);F1E;G1A<VD@5&5K<R`M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S
M(&]F("5S72(*;7-G<W1R("(E<R!U;G1U:R`E<R`E<R(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN
M:7-T<F%S:2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G
M<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R
M964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E
M(%)O=R(*;7-G<W1R(")(87!U<R!"87)I<R(*"B,Z(&QI8B]A<&DN<&AP.C$S
M,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<"(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](
M96QP(@IM<V=S='(@(D)A;G1U86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!E<G1I($=A;6)A<BXN+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*
M;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B3&]G:6XB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G
M(&]U="(*;7-G<W1R("),;V<@;W5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y
M($QI;FLN+BXB"FUS9W-T<B`B56)A:"!,:6YK+BXN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P
M=&EO;G,B"FUS9W-T<B`B4&EL:6AA;B(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM
M<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ:6XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G
M:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")0:6YD86AK86X@3&EN:RXN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@
M(E]3971U<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B4')O<&5R=&D@5&%B96PN+BXB"@HC.B!L:6(O87!I+G!H<#HQ
M,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")096YG9W5N82(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B0G5K=2!!;&%M870@(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U
M;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")+86QE
M;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T
M<B`B5&5N86YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*
M;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@
M:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S
M='(@(E!E<F)E9&%A;B!+;VYF:6=U<F%S:2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@
M9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@
M(D%C8V]U;G0@4&5N9V=U;F$@=&ED86L@9&ET96UU:V%N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI
M;F<B"FUS9W-T<B`B:F%T=6@B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B5&ED
M86L@9&EA<G-I<&MA;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`B1&%R:2`E<R`H)7,I('!A9&$@)7,@)7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM
M<V=S='(@(F%N9VEN(&ME;F-A;F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS
M9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")M87-I:"!D:2!D86QA;2!A;G1R
M:6%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R(")B87)I<UTB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B
M;F%M92(*;7-G<W1R(")N86UA(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP
M.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T
M('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDP-0HC+"!F=7IZ>0IM<V=I9"`B;F]T97!A9"(*;7-G
M<W1R(")T971A<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<&5R
M<V5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*
M(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(DEZ
M:6X@=6YT=6L@7"(E<UPB('1I9&%K(&1A<&%T(&1I:&%P=7,N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM
M<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(FYA
M:6LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@HC
M+"!F=7IZ>0IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")!
M<F5A($UE=&%R('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R
M(")T86UP:6QK86X@<&5R8F5D86%N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V
M:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B
M<W1E861Y(@IM<V=S='(@(G1E=&%P(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U
M,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*
M;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"FUS9VED(")T<GD@86=A:6XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@
M='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")+971I:R!S86YD:2!D=6$@:V%L
M:2!U;G1U:R!M96YG:V]N9FER;6%S:2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D
M(@IM<V=S='(@(FUE;GEA='5K86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U!A<G0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")U;FYA;65D(@IM<V=S='(@
M(FYA;6$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(G5S97(@<V5L96-T(@IM
M<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(G9#87)D(@IM
M<V=S='(@(DMA<F%K=&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M
M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P;R]I<U])4RYP;P``````````````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C,R,S0T`#$P-#$W
M,S8S,#`Q`#`Q-C0P-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C($EC96QA;F1I8R!T<F%N<VQA=&EO;G,@9F]R(&1I<VL@
M<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!D:7-K('!A8VMA9V4N"B,*;7-G:60@(B(*;7-G<W1R("(B
M"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"XU7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#(M,#$M,3`@,3DZ,#`K,#$P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-2TQ,2TQ.2`R,#HS,RLP,#`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($)J;W)N($1A=FED<W-O;B`\8FIO<W-I0'-N97)P82YI<SY<
M;B(*(DQA;F=U86=E+51E86TZ($EC96QA;F1I8R`\<W5P<&]R=$!S;F5R<&$N
M:7,^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HT.0IM<V=I9"`B(@HB("`M32P@+2UM97-S86=E/4U%4U-!1T4@(%5S92!T
M:&ES(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE
M<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4S"FUS9VED
M("(B"B(@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE
M('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&]<;B(*(B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F
M97)E;G0@8G)A;F-H('1O7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!T
M:&4@9V5N97)A=&5D(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,3,*;7-G:60@(B(*(B`@+6(L("TM8F%S93TO4$%4
M2"`@1G5L;"!P871H('1O('1H92`H2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H
M870@<VAO=6QD(&)E7&XB"B(@("`@("`@("`@("`@("`@("`@('5S960N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.0IM<V=I9"`B(@HB
M("`M8RP@+2UC;VUP96YD:75M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA=&EO
M;G,@=&\@=&AI<R!C;VUP96YD:75M(&9I;&5<;B(*(B`@("`@("`@("`@("`@
M("`@("`@("`@("!I;G-T96%D(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N
M9&EU;2YP;R!I;B!T:&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!H
M;W)D92]P;R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HV,R!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$@<&\O=')A;G-L871I
M;VXN<&AP.C@W"FUS9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@
M57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'1<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I
M=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,30*;7-G:60@(B`@+60L("TM9&5B
M=6<@("`@("`@4VAO=R!E<G)O<B!M97-S86=E<R!F<F]M('1H92!E>&5C=71E
M9"!B:6YA<FEE<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C4T"FUS9VED("(@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M
M<&5N9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$Q-0IM<V=I9"`B("`M:"P@+2UH96QP("`@("`@
M("!3:&]W('1H:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-#(@<&\O=')A;G-L871I;VXN<&AP.C8W('!O+W1R
M86YS;&%T:6]N+G!H<#HW-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@
M("`@(%5S92!O;FQY('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-#<@<&\O=')A;G-L871I;VXN<&AP.C8Q('!O+W1R
M86YS;&%T:6]N+G!H<#HW.0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4*;7-G
M:60@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-0IM<V=I9"`B
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@*;7-G:60@(B`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T
M:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-#,*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#
M;&5A;G5P(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT.`IM<V=I9"`B
M(@HB("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO
M;G,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C8R"FUS9VED("(@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z.#`*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!0
M3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S8*;7-G:60@(B(*(B`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#8*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M("!5<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@*;7-G:60@(B`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C<P"FUS9VED("(B"B(@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N
M)W0@;65R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2XB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8T('!O+W1R86YS
M;&%T:6]N+G!H<#HX,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@*;7-G:60@(B`@
M+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$*;7-G:60@
M(B`@+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T
M871I<W1I8W,@:6X@82!L;V-A;"!F:6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3$V"FUS9VED("(@("UT+"`M+71E<W0@("`@("`@
M(%-H;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@86YY
M=&AI;F<N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#4*
M;7-G:60@(B(*(B`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U
M<"!F<F]M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RXB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.`IM<V=I9"`B("!C
M;VUM:70@("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y"FUS
M9VED("(@(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#
M5E,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.3D*;7-G:60@(B(*(B`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N
M9&EU;2!F:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE7&XB"B(@
M("`@("`@("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,`IM<V=I9"`B("!E>'1R86-T("`@
M("!'96YE<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY.`IM<V=I9"`B("!H96QP("`@
M("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3`Q"FUS9VED("(B"B(@(&EN:70@("`@("`@
M($-R96%T92!O;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE
M+B!787)N:6YG.B!4:&ES7&XB"B(@("`@("`@("`@("`@(&]V97)W<FET97,@
M=&AE(&5X:7-T:6YG(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V"FUS9VED("(@(&UA:V4@
M("`@("`@($)U:6QD(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I
M960@4$\@9FEL97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#<*;7-G:60@(B(*(B`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE
M<R!I;B!T:&4@6$U,(&AE;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9%QN
M(@HB("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE(&9O<B!T:&4@;F5X
M="!E>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=5QN(@HB("`@("`@("`@
M("`@("!S:&]U;&0@;VYL>2!R=6X@;6%K92UH96QP($%&5$52('5P9&%T92UH
M96QP(&%N9"!R979I<VEN9R!T:&5<;B(*(B`@("`@("`@("`@("`@:&5L<"!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`R"FUS
M9VED("(B"B(@(&UE<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT(%!/(&9I
M;&4@=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T92!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`S"FUS9VED("(@('5P9&%T
M92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S97%U96YT+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`T"FUS9VED("(B"B(@('5P
M9&%T92UH96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E;G1R:65S
M(&9R;VT@=&AE($5N9VQI<V@@6$U,(&AE;'!<;B(*(B`@("`@("`@("`@("`@
M9FEL92!A;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T
M;W`N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S8W"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y
M<R!A9V\I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H=&]D
M87DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M-S,*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-CD*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS
M9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3<V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&)Y=&5S('=R:71T96XN(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C@T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]T;W`N:6YC.C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C,R"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R-"!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?=&]P+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M(@IM<V=S='(@(E9I\&AA;&1S8?!G97+P:7(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C4V."!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C8S-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(DUA<'!A;B!<(B5S7"(@97(@;OH@_F5G
M87(@=&EL(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3<@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-C,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-#,@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HT,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E
M<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN
M=FET871I;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR.#<@<&\O=')A
M;G-L871I;VXN<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!N
M;W0@=W)I=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B
MP2!F:6UM(&WM;OIT;F$@9G)E<W1I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C$R,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,U
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@;F]T(&9O=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G
M(&9I<G-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U
M<B!P<F5S96YC92!A="`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)60@=&EL("5D(&%F("5D('-K
M97ET=6TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@
M861D('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E
M:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.#DQ"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R
M(").971F86YG86+S:R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.#@S"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX-S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.#DY"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(G)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HU-30*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HY,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R
M964N<&AP.C$V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('1R964@<F5N
M9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C4W"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-2!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@;F]T(&-R
M96%T960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$X-B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L
M92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-CDQ"FUS
M9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$S,C@@<&\O=')A;G-L871I;VXN<&AP.C$S,S`*;7-G:60@(BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@1F]R
M;6%T(@IM<V=S='(@(E5P<&S]<VEN9V%R(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R
M(")5<'!L_7-I;F=A<B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X
M"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO4&%G97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS
M9W-T<B`B1GER<FD@8FQA\'/M\&$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(CQG971T97AT/B!T86<@;F]T
M(&-L;W-E9"!I;B!F:6QE("5S+EQN(@HB3W!E;FEN9R!T86<@9F]U;F0@:6X@
M;&EN92`E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3<*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@
M=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDQ-PIM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$T,@IM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`W
M-`IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.CDY,@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB
M82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW"FUS9VED
M(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z.`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@
M(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS
M9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C0P"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C8X,0IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O
M<F0B"FUS9W-T<B`B3'EK:6QO<O`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(D%C8V]U;G0@9G)O
M>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S$T"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DCF:VMA
M;F1I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT-3$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV,C4*(RP@9G5Z>GD*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B
M0?!G97+P(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4T(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3,R"B,Z('1E;7!L871E<R]P;W)T
M86PO861D+FEN8SHQ-"!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHQ-@IM<V=I9"`B061D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"FUS9VED(")!9&0@0VAI
M;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@U"FUS
M9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C`X(&%D;6EN+V=R;W5P<RYP
M:'`Z,C`Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S,@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HW-`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@
M=&\@)R5S)R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3,@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@
M82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0IM<V=I9"`B061D(&-O;'5M;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,U
M"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D9"!P86ER(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-C,Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C,W"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C
M86QE;F1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R
M97-S(&)O;VLZ(@IM<V=S='(@(D+F=&$@[2!N971F86YG86+S:R`H)7,I(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L
M(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@
M(D+F=&$@[2!N971F86YG86+S:R`H)7,I(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D("<E<R<@=&\@
M=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N
M=7`@:6YF;W)M871I;VXZ("4B"B)S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N
M<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D("<E<R<@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z.38R"FUS9VED(")!9&1I;F<@;F5W(&9I;&5S
M('1O(')E<&]S:71O<GDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHT"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0V
M"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(@IM<V=S='(@(E-E;F1A;F1A;F5T
M9F%N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S8*;7-G:60@
M(D%D9')E<W,@0F]O:R(*;7-G<W1R(").971F86YG86+S:R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI
M;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,@IM<V=I9"`B
M061S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS
M9VED(")!;&EA<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(M9L;"!S
M:V5Y=&DB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3@@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@
M57-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI
M;B]G<F]U<',N<&AP.C(Q,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,S@@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HW-PIM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L
M;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3(S"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R
M9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964O<W%L+G!H<#HT,#@*;7-G:60@(D%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*
M;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.38*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.#@*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY
M"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(").971F
M86YG(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R
M;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!
M;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*
M;7-G<W1R("+3=.9K="!G:6QD:2!T:6QG<F5I;G0N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")!;G-W
M97(B"FUS9W-T<B`B4W9A<F'P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C
M=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N
M9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ-@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B0?!G
M97+P(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L
M:6-A=&EO;B!,:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,SD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B
M07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@R-`IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B
M07!R:6PB"FUS9W-T<B`B87!R[6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B
M17)T(/[Z('9I<W,@=6T@8?`@_OH@=FEL:FER(&=E<F$@_F5T=&$_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.CD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D
M96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D5R="#^
M^B!V:7-S('5M(&'P(/[Z('9I;&II<B!TYFUA(/YE<W-A(&WV<'!U/R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!
M<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I
M9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#$U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B07-S:6=N;65N="!C
M;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,38V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S$X"FUS9VED(")!='1A8VAE9"!I
M<R!A;B!I0V%L96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E
M;G0B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-0IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,S@*;7-G:60@(D%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.CDX"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-3<W"B,L(&9U>GIY"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B
M5FGP:&5N9VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C@*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I
M9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@
M(N%G^G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D%U<W1R:6$B"FUS9W-T
M<B`BX6?Z<W0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED
M(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H
M<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB
M"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*(E9I<W1U;B!U<'!K87-T<VEN<R!M:7-T\VMS="X@3F5T_FKS;FYI
M;FX@:V]M(&UE\"!E9G1I<F9A<F%N9&D@=FEL;'4Z("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(X.0HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM
M<V=S='(@(D5N9'5R=NUS=6X@;6ES:&5P<&'P:7-T+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N
M("5S(@IM<V=S='(@(D5N9'5R=NUS=6X@;6ES:&5P<&'P:7-T+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8X"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHX,PHC+"!F=7IZ>0IM
M<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B5&EL=.9K87(@;F5T
M9F%N9V%BYFMU<CHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8Q-`IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@
M17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E
M<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC
M("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B
M861O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C`X"FUS9VED(")"87)E(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS
M9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F5L:7IE
M(@IM<V=S='(@(E-TYG+P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B
M0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C
M:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS
M9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX"B,L(&9U>GIY"FUS9VED(")";VQD(@IM<V=S='(@(DUE9VEN;>%L(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@X"FUS9VED(")";V]K;6%R:W,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(DWV<'!U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B3?9P<'5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@
M(D)O=&@B"FUS9W-T<B`B0N;P:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W
M86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-0HC+"!F=7IZ>0IM<V=I9"`B0F]T=&]M(@IM
M<V=S='(@(D+F\&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@
M5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE
M:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HV-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0G5I;&1I;F<@34\@9FEL97,@
M9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C<S"B,L('!H<"UF;W)M870*;7-G:60@(D)U:6QD:6YG(&QO8V%L
M92`E<RXN+B`B"FUS9W-T<B`B0GEG9VD@;OH@;&]C86QE("5S("XN+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U
M;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N
M9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W
M,PIM<V=I9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S(*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS
M9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$T-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,PHC+"!F=7IZ
M>0IM<V=I9"`B0V%L;2(*;7-G<W1R(")(YG1T82!V:?`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T
M;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,30@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C$W"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3<*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")(YG1T
M82!V:?`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM
M<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS
M9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HR-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964N<&AP.C$Q,B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HU.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4Q,PIM
M<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U
M<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S
M=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B0V%N;F]T(')O=71E(&UE
M<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U
M>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E9A;'-T:6QL:6YG87(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@
M86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y
M;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I
M9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P
M86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B0V5N=&5R(@IM<V=S
M='(@(D+Z82!T:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#
M97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M(RP@9G5Z>GD*;7-G:60@(D-H860B"FUS9W-T<B`B169N:7/^<N'P=7(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Y
M-@HC+"!F=7IZ>0IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(E!E<G/S
M;G5L96=T(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PIM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(D)R97ET82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@HC
M+"!F=7IZ>0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(DCI<B!G971U<B#^^B!B<F5Y
M='0@_G;M(&AV8?!A(&YA9FXL(&YE=&9A;F<@;V<@<VME>71I<V)O=&X@:V5M
M=7(@9G)A;2#M("(*(G-K97ET=6T@_NUN=6TN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM
M<V=I9"`B0VAA<B(*;7-G<W1R(")"<F5Y=&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H
M96-?:R!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]C;VYF:7)M7W1O<"YI;F,Z,3,*;7-G:60@(D-H96-K('1H92!B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E
M(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I
M9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*(RP@9G5Z
M>GD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(E-E;6IA(&[]
M='0@<VME>71I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HT-3(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HV,C8*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A
M8W1I;VXZ(@IM<V=S='(@(E9E;&1U(&'P9V5R\#HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C@X"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T
M('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HV,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F
M:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HX-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE86YI
M;F<@=7`@4$\@9FEL97,@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#8W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L96%N:6YG('5P(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B2')E:6YS82!T
M:6P@[2!L;V-A;&4@)7,@+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D-L96%R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G
M:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ-@IM<V=I9"`B0VQE87(@=7-E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")#;&5A
M<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]N;W1I8V5?8F]T=&]M+FEN8SHV"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.#,*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#(*;7-G:60@
M(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U
M"B,L(&9U>GIY"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B069R:70B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C0*(RP@9G5Z
M>GD*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B3&]K82!M]G!P
M=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM
M<V=S='(@(DQO:V$@;?9P<'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y
M-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDX
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-S(@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV.`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV.0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX-0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX-@IM<V=I9"`B0V]L
M;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X-3`*(RP@9G5Z>GD*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS
M9W-T<B`B5F5L9'4@8?!G97+P.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU
M;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR.#,*(RP@9G5Z>GD*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")396UJ
M82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O
M;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C,X"FUS9VED(")#;VUM86YD(&]P=&EO;G,Z(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HY-PIM<V=I9"`B0V]M;6%N9',Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y.0IM<V=I
M9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`P,`IM<V=I9"`B0V]M;6ET=&EN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"B,L(&9U>GIY"FUS9VED(")#
M;VUO<F]S(@IM<V=S='(@(E-E;6IA(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S.0HC+"!F=7IZ>0IM<V=I9"`B0V]M<&%N
M>2(*;7-G<W1R(")!9G)I="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-CDW"B,L(&9U>GIY"FUS9VED(")#;VUP;&5T
M960B"FUS9W-T<B`B4V5M:F$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;7!O<V4@365S<V%G92`H)7,I(@IM<V=S='(@(E-E;6IA('-K97ET:2`H
M)7,I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"B,L(&9U>GIY"FUS
M9VED(")#;VUP=71E<G,B"FUS9W-T<B`B4V5M:F$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T-PIM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HX.0IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3,T"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S<*(RP@9G5Z>GD*
M;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B3'EK:6QO<O`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U
M"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*
M;7-G<W1R(")%;F1U<G;M<W5N(&UI<VAE<'!A\&ES="XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED
M(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(D5N9'5R=NUS=6X@;6ES
M:&5P<&'P:7-T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<W-@IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW-C(*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(DYE=&9A;F=I\"!<(B5S7"(@=F%R(&+F='0@[2!N971F86YG86+S:VEN82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;G1E;G1S(&]F("<E<R<B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O;G1I;G5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*(RP@9G5Z>GD*;7-G
M:60@(D-O;VMI92(*;7-G<W1R(")396UJ82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P
M>2(*;7-G<W1R(")!9G)I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G:60@(D-O<'D@<V5L96-T
M:6]N(@IM<V=S='(@(E9E;&1U(&'P9V5R\#HB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>6EN
M9R`E<R!T;R`E<R(*;7-G<W1R(")496YG:F%S="`E<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#,P"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`BWOH@X71T(#$@;OUT="!S:V5Y
M=&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V
M-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,3@S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@
M8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HW,`IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,34U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@
M)7,B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O<'D@)7,@=&\@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R
M96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D
M:7)E8W1O<GD@9F]R(&QO8V%L92`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$P,@IM<V=I9"`B0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B1V%T(&5K:VD@97ET="!S:V5Y='5M(&9RX2`E<SH@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B1V%T(&5K:VD@97ET
M="!S:V5Y='5M(&9RX2`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R(")'
M870@96MK:2!E>71T('-K97ET=6T@9G+A("5S.B`E<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@R
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0Y,@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-0IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;&]A9"!S=')A=&5G>2`G)7,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@)R5S)RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S`U"FUS9VED(")#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)R5S
M)R!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@
M(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D
M<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")'870@96MK:2!E>71T('-K97ET=6T@
M9G+A("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER
M("<E<R<N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@)R5S)RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B
M"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y
M(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C@P"FUS9VED(")#;W5L
M9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U;FQI;FL@)R5S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`G)7,G.B`E<R(*
M;7-G<W1R(")'870@96MK:2!E>71T('-K97ET=6T@9G+A("5S.B`E<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-38*;7-G:60@(D-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9&XG="!G:79E('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B`G)7,G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(T"B,L(&9U>GIY"FUS9VED(")#;W5N=&5D('1E
M>'0B"FUS9W-T<B`B3&5I\'+I='1U<B!T97AT:2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C<*;7-G:60@
M(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PHC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q"FUS9VED(")#<F5A=&4B
M"FUS9W-T<B`B0OIA('1I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B0W)E
M871E(&$@;&EN:R(*;7-G<W1R(")"^F$@=&EL(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B0W)E
M871E(&$@;F5W(&]N92(*;7-G<W1R(")"^F$@=&EL(&[]:F$@;?9P<'4@*')U
M<VQA:_9R9G4I('5N9&ER(&5Y9&0@<VME>71I(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(D-R
M96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")"^F$@=&EL(&WV<'!U(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z,3,V(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C$T"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S0*;7-G:60@
M(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0HC
M+"!F=7IZ>0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")"^F$@=&EL(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@4&AA<V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P
M"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B3&5I\'+I
M='1U<B!T97AT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R
M<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S<*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS
M9W-T<B`B4W1I;&QA(&'P9V5R\&ER('-E;2!E<G4@9G)A;6MVYFUD87(@_F5G
M87(@_OH@=&5N9VES="`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0R,R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`BVG1L
M:70B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E
M($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,SDW"FUS9VED(")$871E(@IM<V=S='(@(D1A9W,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R(")-\W1T96MI\"#^86YN.B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D1A=&4@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#$*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")M8>TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*
M(RP@9G5Z>GD*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(D5Y\&$@
M;?9P<'4H;2DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B9&5S96UB97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"B,L(&9U>GIY"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T
M<B`B9&5S96UB97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8X-0HC+"!F=7IZ>0IM<V=I9"`B1&5C;&EN960B"FUS
M9W-T<B`B17ET="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E
M9G,N<&AP.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")%
M>?!A(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#$*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B
M3F]T82!S:N%L9F=E9FGP(&=I;&1I(@H*(SH@9G)A;65W;W)K+TED96YT:71Y
M+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G
M<W1R(")3:N%L9F=E9FGP(&ME;FYI;6%R:R(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$Q.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-@IM
M<V=I9"`B1&5F875L="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-PIM<V=I9"`B1&5F875L="!P
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(E-K
M:6QG<F5I;FEN9R#A('/M=7)E9VQU(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#,*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5G871E('!O<VET:6]N(@IM<V=S='(@(E-E;6IA(&[]='0@<VME>71I(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV
M.3,*(RP@9G5Z>GD*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R(")%>71T(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0V(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR.34@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS,34*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,S(@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY.2!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3,*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")%>?!A(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR,3<*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")%>?!A(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HV,R!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C@W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4&5R;6ES<VEO
M;B(*;7-G<W1R(")%>?!A('-K97ET=6TB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")%>61D('-K97ET:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(D5Y\&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@
M(D5Y\&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4P(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@)R5S)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!R;W<B"FUS9W-T<B`B17GP82(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")696QD=2!K96YN:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@HC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G
M<W1R(")3=&EL;&$@;OIV97)A;F1I('3M;6%B96QT:2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B
M4W1I;&QA(&[Z=F5R86YD:2!T[6UA8F5L=&DN(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT.`IM<V=I9"`B1&5L971E('1H:7,@<&5R;6ES<VEO;B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4R"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM
M<V=S='(@(D5Y\&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-C0R"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-S$*
M;7-G:60@(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q,"!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HQ,30@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(T
M"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B5F%L:V]S=&ER(&YO=&%N9&$B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0HC+"!F=7IZ>0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HBWF5T=&$@<VME>71I(&AE9G5R('9E<FGP('-E;G0@
M=&EL(&ME<F9I<W5M<VKS;F%R('-E;2!T:6QK>6YN:6YG('5M(')U<VQP\W-T
M("(*(BA34$%-*2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DU
M"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDR"FUS9VED(")$97<@4&]I;G0@9F]R
M(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.30*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*
M;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G
M:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")$:7)E8W1O
M<GDB"FUS9W-T<B`B4O;P=6YA<N%T="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-38*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P
M;&%Y($]P=&EO;G,B"FUS9W-T<B`BVG1L:71S<W1I;&QI;F=A<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#,*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@
M*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@R,0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B
MVG1L:70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS
M9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,Q-0HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R
M(")%;F1U<G9E:VIA(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(T
M"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ.0IM<V=I9"`B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#,U"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M(")3YFMJ82!Y9FER(.$@=FEN;G5S=/;P(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(D1O
M=VYL;V%D("5S(@IM<V=S='(@(E/F:VIA("5S('EF:7(@X2!V:6YN=7-T]O`B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38U"FUS9VED(")$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED
M(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y.0HC+"!F=7IZ>0IM<V=I9"`B
M12U-86EL(@IM<V=S='(@(E#S<W1M87!P82(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*
M;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A
M9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,CDT('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T
M96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET(@IM<V=S
M='(@(D)R97ET82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z
M-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="!"
M;&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X."!A9&UI
M;B]G<F]U<',N<&AP.C(Q-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C8R(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#8*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,#0@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!P97)M:7-S:6]N<R!F;W(@)R5S)R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D5D=6-A
M=&EO;B(*;7-G<W1R(")!\&=E<O`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-#`*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B3F5T
M9F%N9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*(RP@9G5Z
M>GD*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R
M(").971F86YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM
M<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X,`HC+"!F
M=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(E9A;'-T:6QL:6YG87(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#$*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@
M(L%R[?!A;F1I('-K97ET:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T
M<B`B5.9M82!R=7-L86OV<F9U(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(E3F;6$@<G5S;&%K]G)F=6WV<'!U(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S,@IM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O
M9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-#@*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M-3,*;7-G:60@(D5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C`V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3$*;7-G
M:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I
M;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!5
M4DP@:&5R92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%;G1R:65S.B`E9"!T;W1A;"P@)60@
M=7`M=&\M9&%T92P@)60@;F5W+"`E9"!C:&%N9V5D+"`E9"!U;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HW.0IM<V=I9"`B17)R;W(B"FUS9W-T<B`B5FEL;&$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Y-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(W.`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R`G)7,G+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N
M+G!H<#HU,C(@<&\O=')A;G-L871I;VXN<&AP.C$S-S<*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$T,S@@<&\O=')A;G-L871I;VXN<&AP.C$U,#$*(RP@9G5Z
M>GD*;7-G:60@(D5R<F]R.B`B"FUS9W-T<B`B5FEL;&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,CD*;7-G:60@(D5V97)Y(#$U
M(&UI;G5T97,B"FUS9W-T<B`BP2!K;W)T97)S(&9R97-T:2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-SD*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@
M;6EN=71E<R(*;7-G<W1R("+!(&9I;6T@;>UN^G1N82!F<F5S=&DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BP2`S,"!S
M96LN(&9R97-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S
M(@IM<V=S='(@(L$@9FEM;2!M[6[Z=&YA(&9R97-T:2(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*(RP@9G5Z>GD*;7-G
M:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(L$@;>UN^G1U(&9R97-T:2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S`*;7-G:60@(D5V97)Y(&AA;&8@
M:&]U<B(*;7-G<W1R("+!(&CA;&9T[6UA(&9R97-T:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM
M<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(L$@;>UN^G1U(&9R97-T:2(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(X"FUS9VED(")%>&%M
M<&QE('9A;'5E<SHB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(X"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HR.3D@<&\O=')A;G-L871I;VXN<&AP.C,R,"!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,S8R"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-#$@<&\O=')A
M;G-L871I;VXN<&AP.C4T,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-C`Q"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HW,#(@<&\O=')A;G-L871I;VXN<&AP.C<S-R!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-SDX"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX
M-S4@<&\O=')A;G-L871I;VXN<&AP.CDY-"!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`Q-@IM<V=I9"`B17AE8W5T:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS.30*(RP@9G5Z>GD*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R(")/<&YA(&%L;&%R(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]S:61E8F%R+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(%-I
M9&5B87(B"FUS9W-T<B`B3W!N82!M]G!P=2(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U
M"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T
M97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C,Y.`IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%
M>'!O;F5N="(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5X=')A8W1I;F<@9G)O;2`E<RXN+B`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`IM<V=I9"`B1E10('5P;&]A
M9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C8P"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A
M<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-C0Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E
M('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I
M9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S<U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B9F5B<OIA<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$X"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.3@*;7-G:60@
M(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B1F5W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3@*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T
M<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"B,L(&9U>GIY"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`B4VMRX7)N869N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G
M<W1R(")3:W+A<FYA9FXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3DY"B,L(&9U>GIY"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")E
M;F=I;B!R96=L82!V86QI;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T.3$*(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E)E
M:71U<B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U,PIM
M<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX-@IM<V=I9"`B1FEL=&5R
M<R(*;7-G<W1R(")3[75R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B
M1FEN;&%N9"(*;7-G<W1R(")&:6YN82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B1GER
M<W1A('/M\&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<V"B,L(&9U>GIY"FUS9VED(")&:7)S="!1=6%R=&5R(@IM
M<V=S='(@(D9Y<G-T82!S[?!A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S.0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,30*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3D*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C$U."!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO
M="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S,R"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S@*;7-G:60@
M(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R
M96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-0IM<V=I
M9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.3D*(RP@9G5Z>GD*;7-G:60@(D9O<FUS
M(@IM<V=S='(@(D9RX2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R
M='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,SDP"B,L(&9U>GIY"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B3?9P<'5R
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-@HC+"!F=7IZ>0IM
M<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`BP69R86US96YD82(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ-#4X"B,L('!H<"UF;W)M870*;7-G:60@(D9O=6YD
M(&%P<&QI8V%T:6]N<SH@)7,B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$T-3(*;7-G:60@(D9O=6YD(&1I<F5C=&]R:65S.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8P"B,L(&9U>GIY"FUS9VED(")&<B(*;7-G<W1R(")&<N$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L
M(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`B3F%F;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R(")(YG1T82!V:?`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$W"B,L(&9U>GIY"FUS
M9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B57!P;/US:6YG
M87(@;F5T_FKS;G,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C0R-PIM<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#(R"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C(W,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C,T,0IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R
M;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@
M(D9RX2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*(RP@
M9G5Z>GD*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")&<N$B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B
M1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")3:VEL9W)E:6YI;F<@X2!S[75R
M96=L=2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3@Q"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS.0HC+"!F=7IZ>0IM<V=I
M9"`B1G5L;"!.86UE(@IM<V=S='(@(DYA9FXB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C4W"FUS9VED(")&=7IZ>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M8V]N9FEG+FAT;6PZ,3`*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$S-S$*;7-G:60@(D=E=&]P="!%<G)O<CH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM
M<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")3:W+A<FYA9FXB"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0HC+"!F=7IZ
M>0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("),96ET82#M('-K97ET
M=6TB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(P"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"B,L(&9U>GIY"FUS9VED(")'<F5N861A(@IM<V=S='(@(D5F;FES
M_G+A\'5R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-S`*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"YP:'`Z-3@*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(W-PIM<V=I9"`B1W)O
M=7`@<&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4P"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$R-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(P-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'
M=65S="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,C@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#8*
M;7-G:60@(D=U97-T('!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'=6EN96$B"FUS
M9W-T<B`B:OIN[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A
M=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S,Q"FUS9VED(")(2"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT
M='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDY
M"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B2&%Z92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS-@IM<V=I9"`B2&5A9&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-S@@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$X-0HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*
M;7-G<W1R(")(:N%L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S8*(RP@9G5Z
M>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")(:N%L<"(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HY-0IM<V=I9"`B(@HB2&5L<&5R(&%P<&QI8V%T:6]N('1O
M(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@2&]R
M9&5<;B(*(F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RY<;B(*(D9O
M<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI
M<R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ-R!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ-PIM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HS,C$*;7-G:60@(DAI<W1O<GD@
M96YT<GD@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8SHT"FUS9VED(")(;U]M92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$T,C8*;7-G:60@(DAO;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"B,L(&9U>GIY"FUS9VED(")(
M;VUE($%D9')E<W,B"FUS9W-T<B`B4V5N9&%N9&%N971F86YG(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`HC+"!F=7IZ
M>0IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")4[6UA8F5L=&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HV,@IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,CD*;7-G:60@(DAO<F1E('1R86YS
M;&%T:6]N(&=E;F5R871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,C<W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M
M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R,#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`B36%P<&%N(%PB)7-<(B!V87(@96YD=7)N969N9"!<(B5S7"(N
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,34T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M('-Y;F-H<F]N:7-E9"`E<R!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB('9A<B!G
M97+P('9I<FLB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM
M<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT.#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-
M3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C`U"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R
M:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$U,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C@R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS
M9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(DAO
M=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(X"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C@*;7-G:60@(DAU;6ED:71Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C$*;7-G
M:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,CDR"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,C`*(RP@9G5Z>GD*
M;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B4V5N9&%N9&%N971F86YG(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.30*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(DEC;VYS($]N;'DB
M"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"FUS9VED("))8V]N<R!W:71H('1E
M>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,`IM
M<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(")+96YN:6YA9FXZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3@V"B,L('!H
M<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C
M=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-0IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,34X"FUS9VED("(B"B))
M9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G
M92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y
M('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("))
M;6%G92!0<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!5
M4DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL
M97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S8U"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHQ,`HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"B,L('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHW,PIM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C<P,0IM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I
M9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,0HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"XB"FUS9W-T<B`B4VSA\'4@:6YN(&YO=&%N9&%N869N(&]G(&QY
M:VQI;W+P(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G
M:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S
M<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B
M26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,30Q('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I
M=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ
M>0IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(F5N9VEN;B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*(RP@9G5Z>GD*
M;7-G:60@(DEN9F\B"FUS9W-T<B`B2'5N9'-A(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB
M"FUS9W-T<B`B57!P;/US:6YG87(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-3@R"B,L('!H<"UF;W)M870*;7-G:60@(DEN:71I86QI>FEN9R!M;V1U;&4@
M)7,N+BX@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T($-?;VQU
M;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED
M("));G-E<G0@26UA9V4B"FUS9W-T<B`B4VME>71I('-E;2!B^FGP(&5R(&'P
M('-V87)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@
M(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(DEN
M<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@
M(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8P"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("))
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Y"FUS
M9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM
M<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DWS='1E
M:VGP(&9Y<FER.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G
M<W1R(")3:V5Y=&D@<V5M(&+Z:?`@97(@8?`@<W9A<F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*
M;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,C`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED
M("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C(X,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C,U,@IM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R
M('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!B871C:"!)
M1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y
M-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDY"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS
M9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@
M(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HT,PIM<V=I9"`B26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED
M("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDR"B,L('!H<"UF;W)M
M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B`G)7,G(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`T,R!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$R,C`*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J
M96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D
M<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED("));G9A;&ED('5N:6-O9&4@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R,@IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"B,L(&9U>GIY"FUS9VED("))<F5L86YD(@IM<V=S='(@(D5F;FES
M_G+A\'5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G
M:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED("))<V]L871E9"!4+5-T
M;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S0*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED
M(")*86YU87)Y(@IM<V=S='(@(FIA;OIA<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")J^FSM(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS
M9W-T<B`B:OIN[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W
M"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@
M(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF
M>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K
M:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T-@IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L
M($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,SDW"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED(")+
M97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,SDX"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y-PIM<V=I
M9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*
M;7-G<W1R(")3:V5Y=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW,C8*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B
M069T96YG:F%S="(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S8@
M<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T
M<B`B5'5N9W5MX6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G
M<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(DQA<W0@2&%L9B(*;7-G
M<W1R(")S[?!A<W1A(&)L<RXB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@@
M;&EB+T)L;V-K+VUO;VXN<&AP.CDP"B,L(&9U>GIY"FUS9VED("),87-T(%%U
M87)T97(B"FUS9W-T<B`B<^WP87-T82!B;',N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-#D*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B<^WP
M87-T('5P<&;F<G0Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-C8V
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@
M(E/M\&%S="!T96YG<W0Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z-C8X"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R
M;VT@)7,B"FUS9W-T<B`B4^WP87-T('1E;F=S=#H@)7,@9G+A("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-C8S"FUS9VED("),87-T(&QO9VEN
M.B!.979E<B(*;7-G<W1R(")3[?!A<W0@=&5N9W-T.B!!;&1R96DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),971T;&%N9"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D9R86US971N:6YG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM
M<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3.UB86YO;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")6:6YS=')I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B3&5F="!H96%D97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),97-O=&AO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("),[6)E<NUA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B3&EG:'0@
M1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM
M<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@
M4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C@*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%-N
M;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-38*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E
M;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O
M:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F
M;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM
M<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B3&ES
M="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F
M=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DAJX6QP(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M
M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M
M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@
M(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]L:7-T+FEN8SHT"FUS9VED("),:7-T:6YG('5S97)S(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET:.%E;B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,S,X"FUS9VED("),;V%D:6YG(&QI8G)A<FEE
M<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S@*;7-G:60@(DQO
M8V%L('1I;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4W,"!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@
M(DQO8V%T:6]N(@IM<V=S='(@(D'P9V5R\"(*"B,Z(&QO9VEN+G!H<#HQ-34@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$V-"!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQO9R!I
M;B(*;7-G<W1R(")496YG:F%S="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BVG1S:W+A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S
M:W,B"FUS9W-T<B`B5F5R:V5F;FD@=FGP('1E;F=I;F=U(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3$Q"B,L(&9U>GIY"FUS9VED("),;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)496YG:6YG(&UI<W3S
M:W-T+B!,[6ML96=A(&5R(&YO=&%N9&%N869N(/YI='0@9?!A(&QY:VEL;W+P
M(')A;F=T(&EN;G-L96=I\"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY,#<*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B
M16YD=7)V[7-U;B!M:7-H97!P8?!I<W0N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,W,`IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,PIM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R
M(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W
M97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),
M;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S0R"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-S,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,"!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U,`IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M
M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G
M87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y
M"FUS9VED(")-86=I8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-S@*;7-G:60@(DUA:6PB"FUS9W-T<B`B5F5F</-S='5R(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-PIM<V=I9"`B36%I;"!!
M9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*;7-G:60@(DUA:V4@;&EN7VLN+BXB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-3<*;7-G:60@
M(DUA:V4@<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS=&%L;&5D(&%N9"!I
M;B!Y;W5R(&EN8VQU9&4@<&%T:"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C8W."!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-86MI;F<@9&ER96-T;W)Y("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%V[2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L8>US
M[6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(D=R
MYFYH]F;P865Y:F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S
M='(@(DUA;.TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#`*;7-G:60@(DUA<#(T(&UA<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3<X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#4U"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@
M(DUA<F-H(@IM<V=S='(@(FUA<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS
M9W-T<B`B4W#A<W/M82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA
M9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG
M+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87)S:&%L;&5Y
M:F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3$Q"B,L(&9U>GIY
M"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B4W;F\&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B3>%R[71A;NUA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$T"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-PIM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`T"FUS9VED(")-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.38*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS
M9VED(")-87DB"FUS9W-T<B`B;6'M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ
M>0IM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")M8>TB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3,Q
M"FUS9VED(")-965T:6YG($-A;F-E;&QA=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,PIM
M<V=I9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.0IM<V=I
M9"`B365E=&EN9R!0<F]P;W-A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4R-0IM<V=I9"`B365E
M=&EN9R!297!L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q-`IM<V=I9"`B365E=&EN9R!5<&1A
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU,3D*;7-G:60@(DUE971I;F<@57!D871E(%)E<75E
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ.0IM<V=I9"`B365M8F5R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S8X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HU,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365R
M9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365R9VEN9R!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365R9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I
M=6TN+BX@(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@
M;6]D=6QE("5S+BXN(@IM<V=S='(@(E-A;65I;F$@_OWP:6YG87(@9GER:7(@
M)7,@96EN:6YG=6YA+BXN(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`IM<V=I9"`B365S
M<V%G92(*;7-G<W1R(")3:V5Y=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B
M365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C8*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4Y"FUS
M9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3$P"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S$*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@)R5S)R!I<R!N;W0@
M9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,PIM<V=I9"`B365T<FEC
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S
M='(@(DUE>.UK\R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&
M961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DWM:W+S;F5S[6$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*
M;7-G:60@(DUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X"FUS9VED(")-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#`*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,3<*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")3<&5G;&$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O
M=7,B"FUS9W-T<B`BW6UI<VQE9W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8W,0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,SD*;7-G:60@(DUI<W-I;F<@
M4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,PIM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HU-PIM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DWA(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C<Q"FUS9VED(")-;V)I;&4@36%I;"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4R"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(D)R97ET
M82!S;//P(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B36]D
M=6QE(@IM<V=S='(@(D5I;FEN9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B3?-N
M86OS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`R"FUS9VED(")-;VYT
M:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B36]S=&QY($-L96%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,Q"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED
M(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-#(X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T
M<B`B1FQY=&IA(&YI\'5R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-#,R"B,L(&9U>GIY"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`B1FQY=&IA('5P<"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C0S-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT,C0*;7-G:60@(DUO
M=F4@57`B"FUS9W-T<B`B1FQY=&IA('5P<"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT.3<*(RP@9G5Z>GD*;7-G:60@(DUO
M=F4@9&]W;B(*;7-G<W1R(")FYG)A(&YI\'5R(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DW"B,L(&9U>GIY"FUS9VED(")-
M;W9E('5P(@IM<V=S='(@(F;F<F$@=7!P(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R
M"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R."!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,U"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-3$*;7-G:60@(DUY(%!O<G1A;"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3(T"FUS
M9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-PIM<V=I9"`B3D\L($D@
M1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C,Y-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-3@S"FUS9VED(").86UE(@IM<V=S='(@(DYA9FXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<P-@HC+"!F=7IZ>0IM<V=I
M9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(D'P9V5R\"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PHC+"!F=7IZ>0IM<V=I9"`B3F5P86PB"FUS9W-T<B`B3OUR('#S<W1U<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q
M"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!
M('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM
M<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").
M971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,S8*(RP@9G5Z>GD*;7-G:60@(DYE='=O<FLB
M"FUS9W-T<B`B3OUT="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(U"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DYE=F5R(@IM<V=S='(@(D%L9')E
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHR-PIM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B3F5W($UO;VXB
M"FUS9W-T<B`B3OUR('#S<W1U<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F5W
M(%IE86QA;F0B"FUS9W-T<B`B3OUR('#S<W1U<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD
M;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3@*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T
M<B`B3OUT="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3(*;7-G
M:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,C$@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#8*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S<@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,S(*;7-G:60@(DYE>'0B"FUS9W-T<B`B3N9S=&$B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE
M>'0@4&AA<V4B"FUS9W-T<B`B3N9S=&$@<^WP82(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8X(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<R"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T
M<B`B5F%L:V]S=&ER(&YO=&%N9&$B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B3N9S
M=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@
M(D%L9')E:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"FUS9VED
M(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@X.`IM<V=I9"`B3F\B"FUS9W-T<B`B3F5I(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HQ-@IM<V=I9"`B3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B
M3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(S,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HR-3(*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4U"B,L(&9U>GIY"FUS9VED(").;R!C
M:&%N9V4N(@IM<V=S='(@(D)R97ET82(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,30P"FUS9VED(").;R!C:&EL9"!P97)M:7-S:6]N<R!A
M<F4@=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8Q"FUS9VED(").;R!C:&EL
M9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W-PHC+"!F=7IZ>0IM<V=I
M9"`B3F\@8V]M;6%N9"!S<&5C:69I960N(@IM<V=S='(@(D5N9VEN(&UA<'!A
M('9A<B!T:6QG<F5I;F0B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0W-PHC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<T,0IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-3<U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<P-`IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!C<F5D:70@;&5F="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(W,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(").;R!E;G1R>2!W:71H('1H92!I9"`G)7,G(&5X
M:7-T<R!I;B!T:&4@;W)I9VEN86P@:&5L<"!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S$*;7-G:60@(DYO
M(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-3(R"B,L(&9U>GIY"FUS9VED(").;R!L;V-A;&4@<W!E8VEF:65D+B(*;7-G
M<W1R(")%;F=I;B!M87!P82!V87(@=&EL9W)E:6YD(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$R,"!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C$*;7-G:60@(DYO(&QO8V%T
M:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DYO
M(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(D[]('-K97ET:2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"B,L
M(&9U>GIY"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B96YG
M:6YN('1E>'1I('1I;&=R96EN9'5R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO
M(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(F5N9VEN;B!T97AT:2!T:6QG
M<F5I;F1U<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B
M3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX
M-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP
M.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A
M=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-3
M3"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$S,`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,`HC+"!F=7IZ
M>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM
M<V=S='(@(E-LX?!U(&EN;B!N;W1A;F1A;F%F;B!O9R!L>6ML:6]R\"(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V
M86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DV"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY,#8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDQ-PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3,T"FUS9VED(").;R!V86QU
M97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.0IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`T"FUS9VED(").;VX@4&%R=&EC:7!A
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-38P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY,@IM<V=I9"`B3F]N92(*;7-G<W1R(")%;F=I;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@
M(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G
M:60@(DYO<G=A>2(*;7-G<W1R("+!9G)A;7-E;F1A(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(DYO
M="!!9G1E<B(*;7-G<W1R(")%:VMI('5P<&MA<W0B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$*
M(RP@9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")2]O!U
M;F%RX71T(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(RP@9G5Z>GD*;7-G
M:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B16MK:2!E>71T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F
M=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")%:VMI(&5Y='0B"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,3<U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C(V
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(U-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C<T"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V
M-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#0T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU,3,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4S,`IM<V=I
M9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,38Q"B,L(&9U>GIY"FUS9VED(").;W1E<R(*;7-G<W1R(")%
M;F=I;B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I
M9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*(RP@
M9G5Z>GD*;7-G:60@(DYO=&EC92(*;7-G<W1R(")%;F=I;B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E
M;6)E<B(*;7-G<W1R(")N\W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(")N
M\W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S`*;7-G
M:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S0@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4P('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T."!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F
M(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#@S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C8S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-"!P;R]T<F%N<VQA=&EO;BYP:'`Z,30X"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,S0X"FUS9VED(")/2R(*;7-G<W1R("+-(&QA9VDB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$T"B,L
M(&9U>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B169N:2(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O
M<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S<@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,34*;7-G:60@(D]B:F5C="!C
M<F5A=&]R('!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#,*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED
M(")/8W1O8F5R(@IM<V=S='(@(F]K=/-B97(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3@*;7-G:60@(D]F9FEC
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S
M(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C
M="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-30*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED
M(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`P"FUS9VED(")/<'1I
M;VYA;"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(E9A
M;'-T:6QL:6YG87(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(E9A;'-T:6QL:6YG87(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")/<'1I
M;VYS.B(*;7-G<W1R(")686QS=&EL;&EN9V%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$R.0IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`HC
M+"!F=7IZ>0IM<V=I9"`B3W1H97(B"FUS9W-T<B`B;VMT\V)E<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Y"B,L
M(&9U>GIY"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")5<'!L
M_7-I;F=A<B!N973^:O-N<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-3`*(RP@9G5Z>GD*
M;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")(869A('5N
M9&ER<VMR:69T:7(@;67P(&1A=69U;2!L:70_(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3(Y-@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$
M871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S-#@*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,S`*;7-G:60@(E!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B4$T@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I
M9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3=6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,SD*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R-@IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V
M"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&%K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*
M;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(E!A<G1L>2!#
M;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<P('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S8*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,U,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B
M3'EK:6QO<O`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R("),>6MI;&]R\"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S
M+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DQY:VEL
M;W+P(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z
M>GD*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B3'EK:6QO<O`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S
M-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED
M(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W1E(@IM
M<V=S='(@(D1A9W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHT"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`W"B,L(&9U>GIY"FUS9VED(")097)C96YT(@IM
M<V=S='(@(E!R96YT82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF
M:7)M7V)O='1O;2YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(E9I\&AA;&1S8?!G97+P:7(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"B,L(&9U>GIY"FUS9VED
M(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM
M<V=S='(@(D9R86UK=N9M82!V:?!H86QD<V'P9V5R\&ER('9I\"!T96YG:6YG
M=2(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,2!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-C0*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C8W"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E!E<G/S
M;G5L96=T(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HV.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")097)M:7-S:6]N("<E<R<@;F]T(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(R-"!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@
M(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E5P<&S]<VEN
M9V%R('5M(&YO=&%N9&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T.`HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U,@IM<V=I9"`B4&5R;6ES
M<VEO;G,@9F]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B57!P
M;/US:6YG87(@=6T@;F]T86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R
M=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G
M:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL
M:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")0:&]N92(*;7-G
M<W1R(")E;F=I;FXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#$U
M"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I
M='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.`IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0HC+"!F=7IZ>0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B4VSA\'4@:6YN(&[]:F$@;F%F;FGP.B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0
M;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G
M<W1R(")3;.'P=2!I;FX@;OUT="!M]G!P=6YA9FXZ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,P-PHC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B4VSA\'4@:6YN(&=I
M;&1A<B!L96ET87)F;W)S96YD=7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8V-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@
M8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T.0HC+"!F=7IZ
M>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B
M4VSA\'4@:6YN(&=I;&1A<B!L96ET87)F;W)S96YD=7(N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$X('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C(*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E-LX?!U(&EN;B!N;W1A;F1A;F%F
M;B!O9R!L>6ML:6]R\"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E
M96UE;G1?=&]P+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$W"FUS9VED(")0;&5A<V4@<F5P
M;W)T(&%N>2!B=6=S('1O(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4T,`IM<V=I9"`B(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG
M(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@
M=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#,U"B,L(&9U>GIY"FUS
M9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E
M;&]W+B(*;7-G<W1R(")696QD=2!A+FTN:R!E:6YA(&WV<'!U('1I;"!A\"!L
M96ET82#M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E-LX?!U(&EN;B!N_6IA(&YA
M9FYI\#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C0*
M;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@
M(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8T(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@
M(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C,*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C4W"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`R
M"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"B,L(&9U
M>GIY"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D9Y<G)I(&)L8?!S[?!A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-3@@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(*(RP@
M9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B1GER<F$@
M<VME>71I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`Y"FUS9VED(")0<FEV
M871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S='(@
M(E9A;F1A;>%L/R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I
M9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C$P"FUS9VED(")0<F]J96-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q.#@*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P.0IM
M<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O
M<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,C(W"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-C(*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G
M:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`IM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4F%I
M;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!A;F0@4VYO
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S,*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@P"B,L(&9U>GIY"FUS9VED(")296%D(@IM
M<V=S='(@(M-L97-I\"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM
M<V=S='(@(D[]('-K97ET:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T
M92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O
M<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED(")2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,0HC+"!F=7IZ>0IM<V=I9"`B4F5F
M<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B16YD=7)H;&'P82!M]G!P=6AA
M;3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,U"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R(")%;F1U<G-E
M=&IA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(U,PIM<V=I9"`B
M4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,C0*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M-S8*;7-G:60@(E)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D9J87)LYF=J
M82!V86QI;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM
M<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ-0HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(DAA;&1A(.%F<F%M(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B1FIA<FSF9VIA('9A;&EN(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4S,@HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")FYG)A(&YI
M\'5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T
M<B`B57!P;/US:6YG87(@;F5T_FKS;G,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8U.`IM<V=I9"`B4F5M;W9E(&9R
M;VT@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,S8*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!P86ER(@IM
M<V=S='(@(F;F<F$@=7!P(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P
M-0IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E
M;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")&:F%R;.9G:F$@=F%L:6XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#D*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T
M<B`B9FIA<FSF9VIA(&AA;F1R:70B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S
M97(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C@P"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0Y"B,L(&9U>GIY"FUS9VED(")2
M97!L>2!396YT+B(*;7-G<W1R(")3=F%R82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#8X"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<X"FUS9VED(")2
M97!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V
M-@IM<V=I9"`B4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT
M:',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#8U"FUS9VED(")297!L>2!W:71H(')E<75E<W1E
M9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3@Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297!L>3H@)7,B"FUS9W-T<B`B4W9A
M<CHB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I
M9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R
M;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT.#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-3@Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S0W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP
M.C,R.`IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.3(*;7-G
M:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,34@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,0HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C0T"FUS9VED(")297-E="(*;7-G<W1R(")%;F1U<G-E
M=&IA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z
M>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(DQY:VEL;W+P(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T
M(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B3FGP=7)S
M=&'P82!L96ET87(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(Q"FUS9VED
M(")297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z.#$Y"B,L(&9U>GIY"FUS9VED(")297-U;'1S
M.B(*;7-G<W1R(").:?!U<G-T8?!A(&QE:71A<B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#(@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-PHC+"!F=7IZ>0IM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
M5F%L:V]S=&ER(&YO=&%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N
M:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F5V
M97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B57!P;/US:6YG87(@;F5T_FKS
M;G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,P"FUS9VED(")2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R-0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-3@S"FUS9VED(")2;VQE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P.`IM<V=I
M9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,L(&9U>GIY"FUS9VED(")2;W1A
M=&4@3&5F="(*;7-G<W1R(")496YG:6QI\&%L:7-T:2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,3$*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ
M>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`B16YD=7)S971J82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O
M;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,R,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(E-E;F1A('-K97ET:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0T.0HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*
M;7-G<W1R(")3:V_P82!S:V5Y=&DB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")34R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8P"FUS9VED
M(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#
M0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S`*;7-G:60@(E-?
M44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED
M(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I
M($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z.3@*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`B5FES=&$@
M<V5M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B5FES=&$@
M<V5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`G)7,G(@IM<V=S='(@
M(E9I<W1A('-E;2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*(RP@
M9G5Z>GD*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")686QK;W-T:7(@
M;F]T86YD82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S`*;7-G:60@
M(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M("<E<R<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")3
M8VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B3&5I=&$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C<U"B,L(&9U>GIY"FUS9VED(")396%R8V@@16YG:6YE
M<R(*;7-G<W1R(").:?!U<G-T8?!A(&QE:71A<B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ-#0X"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:&EN9R!(
M;W)D92!A<'!L:6-A=&EO;G,@:6X@)7,B"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$R,PIM<V=I9"`B4V5A<F-H:6YG(&=E='1E>'0@8FEN
M87)I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDW-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@
M(E9E;&IA(&%L;'0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4V"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM
M<V=S='(@(E9E;&1U(&ME;FYI(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B5F5L:F$@96MK
M97)T(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5F5L9'4@<W1A
M9F%S971T.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")6
M96QD=2!S=&%F87-E='0Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8W,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N
M=',N(@IM<V=S='(@(D5Y\&$@=FGP:&5N9VDN(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")696QJ82!E:VME<G0B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E9E;&1U
M('-T869A<V5T=#HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.C@Y"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED
M(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C8T"FUS9VED(")396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Y-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,X"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9E
M;&1U('-JX6QF9V5F:?`@='5N9W5MX6PZ(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3,*(RP@9G5Z>GD*;7-G:60@
M(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(E5P<&S]<VEN9V%R
M(&YE=/YJ\VYS(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-`HC+"!F
M=7IZ>0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4V5N9&$@<VME>71I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Q-`IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")S97!T96UB97(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R
M8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$R"B,L
M(&9U>GIY"FUS9VED(")3970B"FUS9W-T<B`B5F5L:F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+B(*;7-G<W1R(")696QD=2!S:N%L9F=E9FGP('1U;F=U;>%L.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*;7-G:60@(E-E='5P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C,Y"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-3,*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0T,0IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U
M;6UA<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S
M-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,CDR('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-3@*;7-G:60@(B(*(E-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0X,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")3_6YA
M(&AV96[F<B#^^B!T96YG9&ES="!S[?!A<W0B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8Y"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3<*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,34*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8S"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G
M:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C<*(RP@9G5Z>GD*
M;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(E/F:VIA('EF:7(@X2!V:6YN
M=7-T]O`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-PIM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4VAO=V5R<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.0IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS
M9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS.3D*;7-G:60@(E-H
M<FEN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HV.3(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-S4T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@Q,B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX-S0*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3`Y(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.CDT-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HY-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`P-`IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG
M(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3
M:6=N('5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.#D*;7-G:60@(E-I9VX@=7`@:68@;F]T(')E9VES=&5R960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*
M(RP@9G5Z>GD*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")5;F1I<G-K<FEF
M="#^[6XZ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,T"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C<*;7-G:60@(E-I>F4B"FUS9W-T
M<B`B4W3F<O`B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B
M;W1T;VTN:6YC.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0S,2!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#@T('!O+W1R86YS;&%T:6]N+G!H<#HV-C8*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C@V,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(R,PIM<V=I9"`B4VMI
M<'!E9"XN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,0IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VYO=R!3
M:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM
M<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W
M(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W-@IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C@P"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@
M:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3
M;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC+"!F=7IZ>0IM<V=I9"`B4V]R
M="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4O;P=6YA<N%T="(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34X"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@X
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Q-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#8*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S
M='(@(D9U;&QT(&YE=&9A;F<@_FET="`H1G+A.BD@.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX
M.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@
M1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P
M86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D
M9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDU"FUS9VED
M(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M-`HC+"!F=7IZ>0IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS
M9W-T<B`B4^ER=.%K;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C(*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(&-E
M;&PB"FUS9W-T<B`B5F5L:F$@86QL="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(E-T86YD87)D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A
M<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#0S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-30X"FUS9VED(")3=&%R="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-T87)T('EE87(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*
M;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T
M=7,B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q.0HC+"!F
M=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B57!P;/US:6YG
M87(@;F5T_FKS;G,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T
M<B`B4V5N9&%N9&%N971F86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED
M(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D
M<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y
M("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@
M(D5F;FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M-`IM<V=I9"`B4W5B:F5C="!0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,Q,@HC+"!F=7IZ>0IM<V=I9"`B4W5B;6ET
M(@IM<V=S='(@(D5F;FDB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"`G)7,G('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*
M(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*(RP@9G5Z
M>GD*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")%9FYI(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$P-0HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C
M97-S(@IM<V=S='(@(D9R86UK=N9M="(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@)R5S)R!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(").971F86YG:?`@7"(E
M<UPB('9A<B!BYG1T(.T@;F5T9F%N9V%B\VMI;F$B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,2!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!D96QE=&5D("<E<R<N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E
M9"`G)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4U"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@=W)O=&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W5D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU-3@*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C8*;7-G:60@
M(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HW,0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4W5N;GDB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X,PIM
M<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I
M<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ.#(*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"B,L(&9U>GIY"FUS9VED
M(")3=6YS970B"FUS9W-T<B`B169N:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.#4*(RP@9G5Z>GD*;7-G:60@(E-U;G-E=#H@(@IM<V=S
M='(@(B!%9FYI<VSM;F$Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-U
M<'!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I
M9"`B4W5R:6YA;64B"FUS9W-T<B`B4VMRX7)N869N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E-U
M<FYA;64B"FUS9W-T<B`B3F]T86YD86YA9FXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3=V5D96XB"FUS9W-T<B`B3&5S:?`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")4+5-T;W)M(&%N9"!7
M:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.0IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ
M,S8*;7-G:60@(E1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE
M(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O
M<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")486EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W,`HC
M+"!F=7IZ>0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5F5R:V5F;FD@=FGP('1E
M;F=I;F=U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#@*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$R"FUS
M9VED(")496UP97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3DP"FUS9VED(")496UP97)A='5R93H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z,C$W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E("<E<R<@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I
M9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#$*;7-G
M:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Y
M"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q"FUS9VED(")497AT(@IM<V=S
M='(@(E1E>'1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-0HC+"!F
M=7IZ>0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E1E>'1I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC
M+"!F=7IZ>0IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(").YG-T82!S[?!A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,0HC+"!F=7IZ>0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")497AT:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G
M:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ
M"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY,#,*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F
M;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HBWOH@:&5F=7(@;OH@
M869T96YG<W0@)7,N(%1A:VL@9GER:7(@;F]T:W5N:6YA+B#>96=A<B#^^B!V
M:6QT('1E;F=J87-T(&%F='5R+"`B"B)N;W1A\'4@_N$@<F5I=&EN82!HZ7(@
M8?`@;F7P86XN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VXG
M="!Y970@97AI<W0N($-R96%T:6YG(&$@;F5W(&]N92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,S<*;7-G:60@(E1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E
M<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C(Y"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*(RP@9G5Z>GD*
M;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+B(*;7-G<W1R(")3:V5Y=&EN=2!S96T@=F5R:?`@=F%R(&'P('-E;6IA(&AE
M9G5R('9E<FGP(&QO:V'P+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,34X(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,38Y"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,3@P(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`S(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C,S(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C<R
M"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G
M:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#D*;7-G:60@
M(E1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*
M;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D
M871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(").971F86YG:?`@7"(E<UPB('9A<B!BYG1T(.T@;F5T9F%N
M9V%B\VMI;F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,30V"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N
M;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM
M<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q
M,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW.`IM<V=I9"`B5&AE
M(&5V96YT(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-#@X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,34R"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,C8P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I
M9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@
M<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET
M)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y-R!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:&5L
M<"!F:6QE("5S(&1I9&XG="!S=&%R="!W:71H(#P_>&UL(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(DME;FYI;G4@7"(E<UPB(&AE9G5R('9E<FGP(&5Y='0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM
M<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,30S"FUS9VED("(B"B)4
M:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N
M('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B
M:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<RYP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F
M97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@
M9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T
M+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R
M<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N
M<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL
M:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X
M8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*
M;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B2V5N;FEN=2!<(B5S7"(@:&5F=7(@=F5R:?`@97ET
M="XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@<V%V960N(@IM<V=S='(@(DME;FYI\"`@7"(E<UPB(&AE9G5R('9E<FGP
M('9I<W1A\"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B2V5N;FGP("!<(B5S7"(@:&5F=7(@
M=F5R:?`@=FES=&'P+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C(Y,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,3`X"FUS9VED(")4:&4@=&%S:R!H87,@8F5E
M;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS
M,#<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+V-S=BYP:'`Z,C0P(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-S(*(RP@9G5Z>GD*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD
M(&YO="!B92!S879E9"XB"FUS9W-T<B`B16MK:2!V87(@:.9G="!A\"!S:VEP
M=&$@=6T@=6YD:7)S:W)I9G0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B5&AE('5S
M97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T
M;W)E9"XB"FUS9W-T<B`B56YD:7)S:W)I9G0@:&5F=7(@=F5R:?`@8G)E>71T
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$P-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Q
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@)R5S)R!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N(@IM<V=S='(@(MYA\"!E<G4@96YG:6X@<VME>71I(.T@
M_F5S<W4@</-S=&CS;&9I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C,S.`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L
M9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,#8P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E(&1O
M97-N)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HU,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES
M=&5M+B`E<RXB"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P<"!V:?`@=.9M
M:6YG=2#A("5S+B!6:6QL=71I;&MY;FYI;F<@;F5T_FKS;G-I;G,@9GEL9VER
M(&CI<B#A("(*(F5F=&ER(@H*(SH@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG("<E<R<@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B(@HB5F%N9&%M
MX6P@:V]M('5P<"!V:?`@=.9M:6YG=2#A("5S+B!6:6QL=71I;&MY;FYI;F<@
M;F5T_FKS;G-I;G,@9GEL9VER(&CI<B#A("(*(F5F=&ER(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@)R5S)R!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B)686YD86WA;"!K;VT@=7!P
M('9I\"!TYFUI;F=U('#S<W1H\VQF<RX@5FEL;'5T:6QK>6YN:6YG(&YE=/YJ
M\VYS:6YS(&9Y;&=I<B`B"B)HZ7(@X2!E9G1I<B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(B(*(E9A;F1A;>%L(&MO;2!U<'`@=FGP('3F;6EN9W4@X2`E<RX@
M5FEL;'5T:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@X2`B"B)E
M9G1I<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`G)7,G
M.B`E<R(*;7-G<W1R(")%:VMI('3S:W-T(&'P('-E;F1A('-K97ET:?`Z("5S
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S
M='(@(B(*(E9A;F1A;>%L(&MO;2!U<'`@=FGP('5P<&AL9?!S;'4@<VMRX7(N
M(%-K<N%I;B!E<B!E+G0N=BX@<W3F<G)I(&5N(&QE>69I;&5G="`B"B)E<BXB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S
M='(@(B(*(E9A;F1A;>%L(&MO;2!U<'`@=FGP('5P<&AL9?!S;'4@<VMRX7(N
M(%-K<N%I;B!E<B!E+G0N=BX@<W3F<G)I(&5N(&QE>69I;&5G="`B"B)E<B`H
M)60@34(I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M
M('5P<"!V:?`@=7!P:&QE\'-L=2!S:W+A<BX@4VMRX6EN(&5R(&4N="YV+B!S
M=.9R<FD@96X@;&5Y9FEL96=T("(*(F5R+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@
M(E9I;&QA(&MO;2!U<'`@=FGP(&)I<G1I;F=U(/YE<W-A(&AL=71A('-K97ET
M:7-I;G,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C0X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(E9I;&QA(&MO;2!U<'`@
M_F5G87(@X71T:2!A\"!V:7-T82!U<'!K87-T:?`N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")6:6QL82!K;VT@=7!P(/YE9V%R
M(.%T=&D@8?`@<_UN82!U;6)E\&GP('-K97ET:2XB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+VEM8RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G
M<W1R(")6:6QL82!K;VT@=7!P(/YE9V%R(.%T=&D@8?`@=FES=&$@=7!P:V%S
M=&GP+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS9W-T<B`B
M5FEL;&$@:V]M('5P<"#^96=A<B#A='1I(&'P('/];F$@=6UB9?!I\"!S:V5Y
M=&DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HY,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T
M:6]N.B`E<RXB"FUS9W-T<B`B16MK:2!T\VMS="!A\"!S96YD82!S:V5Y=&GP
M.B`E<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-SD*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M
M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P-R!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3$Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(T-0HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y
M(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE("(*(F9L86<@+60@
M=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y
M"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B5FEL;&$@:V]M('5P<"!V:?`@8FER=&EN9W4@_F5S<V$@
M:&QU=&$@<VME>71I<VEN<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")6:6QL82!K;VT@
M=7!P(/YE9V%R(.%T=&D@8?`@<_UN82!U;6)E\&GP('-K97ET:2XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@
M(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z.#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HY-@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C$Q,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(P,`IM<V=I9"`B5&AI<R!A8W1I
M;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3@*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@
M(E1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G
M<W1R("+>971T82!G:6QD:2!V97+P=7(@8?`@=F5R82!T86QA+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E
M;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,30*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M
M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX,`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,CDP(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34V
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P
M-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0U,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,S(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$T,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-S(X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,W,S8*;7-G:60@(E1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I
M;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q-@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y
M"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N(@IM<V=S='(@(MYE='1A(&=I;&1I('9E<O!U<B!A\"!V97)A('1A
M;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T,`IM<V=I9"`B
M(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G
M:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E
M('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")486QA;B!V97+P=7(@8?`@=F5R
M82!A\"!LX6=M87)K:2`Q+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S`T
M"FUS9VED(")4:&ES('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM
M86YD(&QI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@
M=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,30W"FUS9VED
M(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS
M9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(MYE
M='1A(&=I;&1I('9E<O!U<B!A\"!V97)A('1A;&$N(@H*(SH@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=R(*;7-G<W1R("(B"B+>97-S:2!G;'5G9VD@_F%R9B!A\"!V97)A(';M<W5N
M(&9RX2!G;'5G9V%N=6T@_F%R('-E;2!N_2!S:V5Y=&D@97)U('-A;6EN+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS
M9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,3D*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R-@HC+"!F=7IZ>0IM<V=I9"`B5&EM
M92(*;7-G<W1R(")4[6UA8F5L=&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S`U"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B5&EM92!F
M;W)M870B"FUS9W-T<B`B5.UM86)E;'1I(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4S-PHC+"!F=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I;VXB
M"FUS9W-T<B`B5.UM86)E;'1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM
M;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM
M<V=I9"`B5&ET;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")4:6PB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C(Y"FUS9VED("(B
M"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N
M=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K
M:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4;V1A>2(*;7-G<W1R(")-96=I;FWA
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4;V=O(@IM<V=S='(@(E1I;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-PIM<V=I9"`B5&]M;W)R
M;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<W"B,L(&9U>GIY"FUS9VED(")4;W`B"FUS9W-T<B`B5&EL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED(")4<F%N<VQA=&5D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L
M871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI
M9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W
M"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME
M>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I
M9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R
M(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S$*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-#`*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,S-0IM<V=I9"`B56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT
M<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S(V"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS,#@@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8W,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,S<Q"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-@IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$U."!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-C,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$X."!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DS"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*;7-G:60@(E5N86)L92!T;R!C;W!Y
M(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C0X"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y.`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED
M(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(U-"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,P-0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW.2!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@)R5S)SH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#`@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-C`@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-@IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,S,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(V(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,C`V"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,W.`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S
M:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C<R,`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!
M=71H+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$R.2!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ,S0*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$U."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38S"FUS9VED
M(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P-2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,C4*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL
M93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C4Y,@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$P-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M.#4*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C4S,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,C,X(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C<W"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O
M(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,3(R(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,3(U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$Q,@IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Y(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$S-0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`*(RP@9G5Z>GD*;7-G:60@(E5N9&5R;&EN92(*;7-G
M<W1R(")%;F1U<G9E:VIA(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-@HC+"!F=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D)R97ET
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8T"B,L(&9U>GIY"FUS9VED(")5;F9I
M;&5D(@IM<V=S='(@(M-L97-I\"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%54
M1BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R
M86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5
M;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HV.0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$U(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-@IM<V=I9"`B56YK;F]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3<*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&-L:6US
M9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ-3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;FMN;W=N(&-O;6UA;F0Z("5S(@IM<V=S='(@(E/F:VIA("5S('EF:7(@
MX2!V:6YN=7-T]O`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B4W1I;&QA(&[Z
M=F5R86YD:2!T[6UA8F5L=&DN(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED
M96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BTVYE9FYT
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L
M;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS
M:6]N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*(RP@
M9G5Z>GD*;7-G:60@(E5N=')A;G-L871E9"(*;7-G<W1R("+3<W9A<F'P(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`V(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,3@S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,S"B,L(&9U>GIY"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B1&%G<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0X"FUS9VED
M(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PIM<V=I9"`B57!D871E
M('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ,S<@861M
M:6XO<&5R;7,O961I="YP:'`Z,C$W('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"`G)7,G+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y,B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&EN9R`E
M<R!H96QP(&9I;&4@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX,0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,2!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@R"FUS9VED
M(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X.0IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@
M(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I
M9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HS-2!P;R]T<F%N<VQA=&EO;BYP:'`Z.3(@<&\O=')A;G-L871I
M;VXN<&AP.CDS"B,L(&9U>GIY"FUS9VED(")5<V%G93HB"FUS9W-T<B`B4VME
M>71I(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,W"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(E5S92!I9B!N86UE
M+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M-C$X"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO
M<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR
M,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3`*;7-G:60@(E5S97(@
M3W!T:6]N<R(*;7-G<W1R(")686QK;W-T:7(@;F]T86YD82(*"B,Z('-I9VYU
M<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM
M<V=S='(@(E9A;&MO<W1I<B!N;W1A;F1A(@H*(SH@<VEG;G5P+G!H<#HR,@IM
M<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R
M('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3<R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0V"B,L(&9U
M>GIY"FUS9VED(")5<V5R('!E<FUI<W-I;VYS(@IM<V=S='(@(E9A;&MO<W1I
M<B!N;W1A;F1A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3<@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-2!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E
M<FYA;64B"FUS9W-T<B`B3F]T86YD86YA9FXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V5R;F%M92`G)7,G(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")-
M87!P86X@7"(E<UPB(&5R(&[Z(/YE9V%R('1I;"(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z
M(@IM<V=S='(@(DYO=&%N9&%N869N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R
M(").;W1A;F1A;F%F;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")5<V5R<R(*;7-G<W1R(").;W1A;F1A
M;F%F;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G
M:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3`Q(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$X.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q
M-0HC+"!F=7IZ>0IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B0?!G97+P(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-30*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3,R"FUS9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED(")687)I86)L
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`HC+"!F=7IZ
M>0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")097)S\VYU;&5G="(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#(*;7-G:60@(E9E<G-I;VX@0V]N
M=')O;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5F5R>2!(:6=H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T
M;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.CDU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W("5S(@IM<V=S='(@(E/];F$@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@Q
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G
M<W1R(")3_6YA("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HW.0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(E/];F$@
M)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@
M27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(P-PIM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(U"FUS9VED(")6:7-I8FEL:71Y
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-SD*;7-G:60@(E9O9&%F;VYE($ET86QY('9I
M82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!
M4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B0?!V]G)U;B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4@<&\O=')A;G-L871I;VXN<&AP.C8X
M,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HW,C4@<&\O=')A;G-L871I;VXN<&AP.C$P-C`@<&\O=')A;G-L871I;VXN
M<&AP.C$P-CD*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-S<@<&\O=')A;G-L
M871I;VXN<&AP.C$P.#<@<&\O=')A;G-L871I;VXN<&AP.C$P.3<*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$Q,#<@<&\O=')A;G-L871I;VXN<&AP.C$Q,3,@
M<&\O=')A;G-L871I;VXN<&AP.C$R,S4*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$R-#4@<&\O=')A;G-L871I;VXN<&AP.C$R-3$@<&\O=')A;G-L871I;VXN
M<&AP.C$R-S$*(RP@9G5Z>GD*;7-G:60@(E=A<FYI;F<Z("(*;7-G<W1R(")!
M\';V<G5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#D*
M;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N
M8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS
M9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,V-@IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E
M:VQY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(E9E;&MO;6EN
M*&XI(.T@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")696QK;VUI;BAN*2#M("5S(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7
M96QC;VUE+"`E<R(*;7-G<W1R(")696QK;VUI;BAN*2#M("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS
M9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T
M97(@;&]G:6X_(@IM<V=S='(@(DUA<'!A(&7P82!H86UU<B!S96T@X2!A\"!S
M_6YA(.T@=7!P:&%F:3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR,0IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C0*
M;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,0IM
M<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E
M>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Y"FUS9VED
M(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T
M86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-3@*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*(RP@9G5Z>GD*
M;7-G:60@(E=I;F0B"FUS9W-T<B`B1FEN;F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5VEN9"!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")7
M:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")7:6YD.B(*;7-G<W1R(")&
M:6YN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#D*(RP@
M9G5Z>GD*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")&:6YN82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-SD*;7-G:60@(E=I<VAL
M:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*
M(RP@9G5Z>GD*;7-G:60@(E=O<FLB"FUS9W-T<B`B9?!A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"B,L(&9U>GIY"FUS
M9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B4V5N9&%N9&%N971F86YG(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM
M<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3$V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<FET:6YG('5P9&%T
M960@:&5L<"!F:6QE('1O("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(EE9(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0R-PIM<V=I9"`B65E962(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P,@IM<V=I9"`B
M66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B665M96XB"FUS9W-T
M<B`B3&5S:?`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#@X"FUS9VED(")997,B"FUS9W-T<B`B2N$B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-@IM<V=I9"`B
M665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$58
M5"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T
M;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$R.#@*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP
M:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A
M8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA
M<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O
M<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY,#,*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B4W1I;&QI;F=A<B#^
M[6YA<B!H869A('9E<FGP('5P<&;F<O!A<BXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG
M('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B
M86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C0S,0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM
M<V=S='(@(E9E;&1U(&AV8?!A(&ME;FYI(/[Z('9I;'0@97GP82XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E1I;&=R
M96EN9'4@=FGP=&%K86YD82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N(@IM<V=S='(@(E1I;&=R96EN9'4@=FGP=&%K86YD82XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"XB"FUS9W-T<B`BWOH@_F%R9G0@9GER<W0@8?`@=F5L
M:F$@_F%U('9I\&AE;F=I('-E;2#^^B!V:6QT('-E;F1A(&UE\"!S:V5Y=&EN
M=2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T
M<B`BWOH@_F%R9G0@9GER<W0@8?`@=F5L:F$@_F%U('9I\&AE;F=I('-E;2#^
M^B!V:6QT('-E;F1A(&UE\"!S:V5Y=&EN=2XB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S<*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T
M<B`B5&EL9W)E:6YD=2!V:?!T86MA;F1A+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<R"B,L(&9U>GIY"FUS9VED
M(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@
M(E1I;&=R96EN9'4@=FGP=&%K86YD82XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(DQO=&%N("5S(&5R(')U;FYI;B#Z="#A('3M;6$N(%1E;F=D=2#^:6<@869T
M=7(N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(").971F
M86YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,@IM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")&=6QL="!N971F86YG(/YI='0@
M*$9RX3HI(#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M
M871I;VXB"FUS9W-T<B`B57!P;/US:6YG87(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HX.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!.86UE(@IM<V=S='(@(D9U;&QT(&YA9FX@_FET=#HB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z.0IM<V=I9"`B(@HB66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HX.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+B(*;7-G<W1R("(B"B)6969S:V_P87)I(/YI;FX@<W1Y\'5R(&5K:VD@_F5S
M<V$@<')E;G1A\&=E<O`N($YO=&'P=2!#5%),+T]P=&EO;B!O9R!0('1I;"`B
M"B)A\"!P<F5N=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N
M:G,Z,C<*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO;B`K(%`@
M=&\@(@HB<')I;G0N(@IM<V=S='(@(B(*(E9E9G-K;_!A<FD@_FEN;B!S='GP
M=7(@96MK:2#^97-S82!P<F5N=&'P9V5R\"X@3F]T8?!U($-44DPO3W!T:6]N
M(&]G(%`@=&EL("(*(F'P('!R96YT82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C0W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G
M<W1R(").^G9E<F%N9&D@=.UM86)E;'1I.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS
M9W-T<B`B4VKA;&9G969I\"!K96YN:2#^:71T.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.3$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R
M(")&=6QL="!N869N(/YI='0Z(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T
M-0IM<V=I9"`B(@HB66]U<B!G971T97AT('9E<G-I;VX@:7,@=&]O(&]L9"!A
M;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN7&XB"B).;W0@86QL
M('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B4W1I;&QI
M;F=A<B#^[6YA<B!H869A('9E<FGP('5P<&;F<O!A<BXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")3=&EL;&EN9V%R(/[M;F%R
M(&AA9F$@=F5R:?`@=7!P9N9R\&%R+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C
M:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P
M87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C4X"B,L(&9U>GIY"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S
M.B(*;7-G<W1R(")&=6QL="!N971F86YG(/YI='0@*$9RX3HI(#HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA
M:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII
M<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HU-@IM
M<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF
M;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L
M('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,S(@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S-`IM<V=I9"`B7T-,22(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(E]$
M871A5')E92(*;7-G<W1R(")$86=S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R(")%>?!A(@H*(SH@;&EB+V%P:2YP:'`Z
M,3$T"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@
M(DAJX6QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E1E;F=J87-T
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I
M9"`B7TQO9R!O=70B"FUS9W-T<B`BVG1S:W+A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?
M36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B
M5F%L:V]S=&ER(@H*(SH@;&EB+V%P:2YP:'`Z,3$X"FUS9VED(")?4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN
M+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3`V"FUS9VED(")?4V5T
M=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")?5&%B;&4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,3`*;7-G:60@(E]5
M<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C@Y,`HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(DYE
M=&9A;F=A8O-K(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<Q,0IM<V=I9"`B
M86X@97)R;W(@:&%S(&]C8W5R960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.#@R"FUS9VED(")C86QE;F1A<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4X-@IM
M<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-#0U('!O+W1R86YS;&%T:6]N+G!H<#HU-3`@<&\O=')A;G-L871I
M;VXN<&AP.C8Q,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S0Y('!O+W1R86YS
M;&%T:6]N+G!H<#HX,3`@<&\O=')A;G-L871I;VXN<&AP.C@X-PIM<V=I9"`B
M9&]N92(*;7-G<W1R(")L;VMI\"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU
M-3(@<&\O=')A;G-L871I;VXN<&AP.C4X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C$S"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-S@@<&\O=')A;G-L871I;VXN
M<&AP.C@Q,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#DP"FUS9VED(")F86EL960B
M"FUS9W-T<B`B:VQI:VMA\&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-#D*;7-G:60@(F9I
M;&4B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.0IM<V=I
M9"`B9F]U;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U."!L:6(O0FQO8VLO;65T87(N
M<&AP.C,X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I
M(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38T
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,@IM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8X(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<V"B,L(&9U
M>GIY"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B96YG:6YN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S
M72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@W('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#4*(RP@9G5Z>GD*;7-G:60@(FYA
M;64B"FUS9W-T<B`B3F%F;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS-S@*
M;7-G:60@(FYO="!C:&%N9V5D(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,S$*;7-G:60@(FYO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")N;W0@
M:6UP;&5M96YT960B"FUS9W-T<B`B16MK:2!E>71T(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"B,L(&9U>GIY"FUS9VED(")N
M;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(D5K:VD@97ET="(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.#<T"B,L(&9U>GIY"FUS9VED(")N
M;W1E<&%D(@IM<V=S='(@(M-L97-I\"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U
M>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B0?!V]G)U;B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z.3@*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,3,*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.#DX"B,L(&9U>GIY"FUS9VED(")T87-K(&QI<W0B
M"FUS9W-T<B`B4W9A<G1L:7-T:2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B=&AE($AO<F1E(%!/(&9I;&4@9F]R
M('1H92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O
M;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C@@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-S8*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PHC+"!F
M=7IZ>0IM<V=I9"`B=6YN86UE9"(*;7-G<W1R("+3;F5F;G0B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,S<U"FUS9VED(")U<&1A=&5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38T"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B
M96YG:6X@<F5G;&$@=F%L:6XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*(RP@
M9G5Z>GD*;7-G:60@(G<Z(@IM<V=S='(@(L%F<F%M<RXZ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM
M<V=S='(@(B(*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!O+VET7TE4+G!O````````````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`V-#<V,3<`,3`T,3<S-C,P,#$`,#$V-#$W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",*(R!(
M;W)D92!)=&%L:6%N('1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P
M,2!086]L82!#87)P96YT97(N"B,@4&%O;&$@0V%R<&5N=&5R(#QP8V%R<&5N
M=&5R0&EN9G9I8RYI=#XL(#(P,#$N"B,@1VEO=F%N;FD@365N96=H971T:2`\
M9VUE;F5G:&5T=&E`:6YF=FEC+FET/BP@,C`P,2X*(R!#;W!Y<FEG:'0@*&,I
M(#(P,#,@4V5R9VEO($<N($-A<F5D9&$N"B,@4V5R9VEO($<N($-A<F5D9&$@
M/'-C87)E9&1A0'1I<V-A;&DN:70^+"`R,#`S+@HC(`IM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#(M,C,@,3`Z,3,K,#$P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!-87)C;R!0:7)O=F%N;R`\;6%R8V\N<&ER;W9A
M;F]`=6YI8F]C8V]N:2YI=#Y<;B(*(DQA;F=U86=E+51E86TZ($ET86QI86X@
M/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y
M<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M,PHC+"!F=7IZ>0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B3V=G:2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*(RP@9G5Z>GD*;7-G:60@
M(B`H=&]M;W)R;W<I(@IM<V=S='(@(D1O;6%N:2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(@86QL92`B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T
M<B`B)7,@;F]N('1R;W9A=&\N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B06=G:75N=&\@)R5S)R!A
M;"!S:7-T96UA(&1I(&=R=7!P:2XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B
M)R5S)R!A9V=I=6YT;R!A;"!S:7-T96UA(&1I('!E<FUE<W-I+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C
M<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S)R!N;VX@92<@<W1A=&\@8W)E871O
M.B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G
M<W1R("(E9"`E<R!E("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@071T
M96YZ:6]N92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S
M,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B
M)7,@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO;F4@+2!#;VYF97)M82(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!497)M:6YI
M(&0G57-O(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M
M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&$@
M)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O
M<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@
M0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N
M="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B0V]N=')O;&QA
M(&QA(&-A<V5L;&$@<&5R('%U86QS:6%S:2!O<&5R87II;VYE*&DI('1U('9O
M9VQI82!F87)E(&]R82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71I(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&YO
M;B!T<F]V871O+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T
M<B`B)7,@82`E<R!D:2`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")2=6)R:6-A(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@0V%L96YD87(B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,@+2!!='1E;GII;VYE(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@
M;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F
M;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T
M:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*(RP@9G5Z>GD*;7-G:60@
M(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!A("5S("5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@82`E
M<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L
M('9A<FEA8FEL92!D82`E<R!A("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@
M1F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@,3(@;W)E(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R(")&
M;W)M871O(#(T(&]R92(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X
M"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!O<F4B"@HC.B!F<F%M97=O
M<FLO54DO54DO4&%G97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E=FEO
M=7,B"FUS9W-T<B`B071T:79I=&$G('!R96-E9&5N=&4B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B02!F
M871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B92<@879V96YU=&\@
M=6X@97)R;W)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW
M"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB
M82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"B,L(&9U
M>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B3G5V;VQE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*
M;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B4$T@4&EO9V=I82!,96=G
M97)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3$*(RP@9G5Z>GD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B4&EO9V=I82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS
M9VED(")!32!3:&]W97)S(@IM<V=S='(@(DUO<W1R82!!32(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"B,L(&9U>GIY"FUS
M9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B36]S=')A($%-(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S
M='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I
M9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*
M;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")686D@82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI
M9&1L92(*;7-G<W1R(")296=O;&4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(E9O<W1R82!I;F9O<FUA>FEO;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B06-C
M;W5N="!087-S=V]R9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!F
M<F]Z96XN(@IM<V=S='(@(D-O;G1A8FEL:71A)R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B
M0V]N=&%B:6QI=&$G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS
M9W-T<B`B06=G:75N9VDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI
M;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S
M='(@(D%G9VEU;F=I(%-O='1O($=R=7!P;R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY.0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B5'5T=&D@:2!097)M97-S:2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B06=G:75N9VD@
M<75I.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(D%G9VEU;F=I
M($YU;W9O(%5T96YT92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`HC+"!F=7IZ
M>0IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(E1U='1I(&D@
M4&5R;65S<VDB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B06=G:75N9VD@<V]T=&\M9W)U
M<'!O(&$@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")!9V=I=6YG:2!S;W1T;RUP
M97)M97-S;R!A("<E<R<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B
M061D(&$@;F5W('5S97(Z(@IM<V=S='(@(D%G9VEU;F=I('5N(&YU;W9O('5T
M96YT93HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34T"B,L(&9U>GIY"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(D1I
M=FED:2!C;VQO;FYA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(D%G9VEU
M;F=I('5N(&YU;W9O(&UE;6)R;R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(D%G9VEU;F=I('!A
M:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O
M;VLZ(@IM<V=S='(@(E)U8G)I8V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M
M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B4G5B<FEC82(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")!9V=I=6YG:2!U
M=&5N=&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U
M="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N
M.B`B"B(E<RXB"FUS9W-T<B`B(@HB06=G:75N=&\@)R5S)R!A;"!S:7-T96UA
M+"!M82!N;VX@97)A('!O<W-I8FEL92!I;G-E<FER92!L)VEN9F]R;6%Z:6]N
M92`B"B)A9V=I=6YT:79E(&1E;&QA(')E9VES=')A>FEO;F4Z("5S+B(*"B,Z
M('-I9VYU<"YP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N
M(@IM<V=S='(@(D%G9VEU;G1O("<E<R<@86P@<VES=&5M82X@3W)A('!U;VD@
M:6YI>FEA<F4@;&$@='5A('-E<W-I;VYE+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(DQA(&9U;GII;VYE(&1I(&%G9VEU;G1A('5T96YT
M:2!N;VX@Z"!A='1I=F$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*
M(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B4G5B<FEC82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@
M0F]O:R(*;7-G<W1R(")2=6)R:6-A(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(D%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@
M(DUO9&EF:6-A('!E<FUE<W-I('!E<B`E<R(*"B,Z(&%D;6EN+VEN9&5X+G!H
M<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")!;6UI;FES=')A>FEO;F4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B"FUS9W-T
M<B`B4'5B8FQI8VETX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"B,L
M(&9U>GIY"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&QI;F5A;65N=&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&QI;F5A;65N=&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED
M(")!;&EG;FUE;G0Z(@IM<V=S='(@(D%L;&EN96%M96YT;SHB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5
M<V5R<R(*;7-G<W1R(")4=71T:2!G;&D@571E;G1I($%U=&5N=&EC871I(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM
M<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")4=71T:2!I($=R=7!P:2(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(E1U='1I(&D@4&5R;65S<VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!
M;&P@9F]U<B!S:61E<R(*;7-G<W1R(")4=71T:2!I('%U871T<F\@;&%T:2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*(RP@
M9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(E5T
M96YZ82!)35-0(&%L=&5R;F%T:79A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4P-PHC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O
M<F0B"FUS9W-T<B`B571E;GIA($E-4U`@86QT97)N871I=F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5
M<V5R;F%M92(*;7-G<W1R(")5=&5N>F$@24U34"!A;'1E<FYA=&EV82(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA
M=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("));F1I<FEZ>F\@96UA:6P@86QT
M97)N871I=F\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B
M06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")!=G9I<V$@<W4@86=G:6]R
M;F%M96YT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(E1E<W1O(&%L=&5R;F%T:79O.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,34*(RP@9G5Z>GD*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`B3F5S<W5N($QO8V%L92!3<&5C:69I8V%T;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@
M(F4G(&%V=F5N=71O('5N(&5R<F]R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N
M9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E)I<W!O
M<W1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE
M;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P
M;&EC871I;VXB"FUS9W-T<B`B07!P;&EC87II;VYE(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(D%P<&QI8V%Z:6]N92(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G
M<W1R(")!<'!L:6-A>FEO;F4@92<@<')O;G1A+B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI
M;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I
M;&4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC
M("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C
M:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\B"FUS9W-T<B`B4V5I('-I8W5R;R!D:2!V;VQE<B!E;&EM
M:6YA<F4@;&$@<FEC:&EE<W1A(&1I(&ES8W)I>FEO;F4@<&5R("5S/R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(E-I
M8W5R;R!D:2!V;VQE<B!C86YC96QL87)E("<E<R<@92!T=71T:2!I('-O='1O
M+6=R=7!P:3\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%2
M35-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S
M='(@(D-H:65D:2!C;VYF97)M82!P<FEM82!D:2!E<V5G=6ER92!O<&5R87II
M;VYI(&1I(&UA;G5T96YZ:6]N92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,3,*(RP@9G5Z>GD*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*
M;7-G<W1R(")$:79I9&D@8V]L;VYN82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+B(*;7-G<W1R(")496YT871I=F\@9&D@8V%N8V5L;&%Z:6]N92!D:2!U
M;B!G<G5P<&\@:6YE<VES=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B5&5N=&%T:79O(&1I(&5L:6UI;F%Z
M:6]N92!D:2!U;B!P97)M97-S;R!I;F5S:7-T96YT92XB"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E1E;G1A=&EV;R!D:2!M
M;V1I9FEC82!D:2!U;B!P97)M97-S;R!I;F5S:7-T96YT92(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")496YT871I=F\@9&D@
M;6]D:69I8V$@9&D@=6X@<&5R;65S<V\@:6YE<VES=&5N=&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%G;W-T;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"B,L
M(&9U>GIY"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(D%G;W-T;R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S
M-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E
M<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*
M;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5
M<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC
M86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I
M<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B5'5T=&D@9VQI(%5T96YT:2!!=71E
M;G1I8V%T:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#86UP
M:2!D:7-P;VYI8FEL:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I
M9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG
M<F]U;F0B"FUS9W-T<B`B4V9O;F1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I9"`B0F%C:V=R
M;W5N9"!#;VQO<B(*;7-G<W1R(")39F]N9&\B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O
M<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"86AR86EN(@IM<V=S='(@(DUA<F=I
M;F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC
M("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B
M861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E
M;&EN92(*;7-G<W1R(")"87-E;&EN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E
M;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B0F%S96QI;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED
M(")"96YI;B(*;7-G<W1R(")"87-E;&EN92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T
M<B`B26UP;W-T87II;VYI($)L;V-C;R(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")4:7!O
M(&1I($)L;V-C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")'<F%S<V5T=&\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G
M<W1R(")0<F5F97)I=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B
M36%R9VEN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B36%R9VEN:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"B,L(&9U>GIY"FUS9VED
M(")";W1H(@IM<V=S='(@(D)A<W-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM
M<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B36%R<F]N92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B
M0F]T=&]M(@IM<V=S='(@(D)A<W-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U
M=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS
M9VED(")"<F%Z:6PB"FUS9W-T<B`B4&]S=&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G
M:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R
M;W!R:65TX"!D96QL92!#7V5L;&4N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M
M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD
M87(B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B0V%L;6\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I
M;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T
M;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@8V]N;F5T
M=&5R<VD@86P@<V5R=F5R("<E<R<@=7-A;F1O($944#H@)7,B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A;&5N9&%R
M:6\B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")#
M86YC96QL82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y
M"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B16QI;6EN
M82!287!P;W)T;R!D:2!0<F]B;&5M82(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE
M=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B0W)E87II;VYE(&1I<F5C=&]R>2`E
M<R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B3W!Z:6]N:2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM
M<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R
M(")#871E9V]R:64@92!%=&EC:&5T=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B
M0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R(")0<F]P<FEE=.`@9&5L;&4@8V5L;&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U
M"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I973@(&1E
M;&QE(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B4W!E
M<W-O<F4@8V5L;&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM
M<V=S='(@(E!R;W!R:65TX"!D96QL92!C96QL92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P
M86-I;F<Z(@IM<V=S='(@(E-P87II;R!C96QL93HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H
M25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*
M;7-G<W1R(")#96YT<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED
M(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@
M4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS
M9VED(")#:&%D(@IM<V=S='(@(D-I860B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B36]D:69I8V$B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D%N;G5L;&$@;&$@='5A(%!A<W-W
M;W)D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#
M:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H
M96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS
M9W-T<B`B(@HB36]D:69I8V$@;F]M92P@:6YD:7)I>GIO(&4@9FER;6$@8VAE
M('9E<G)A;FYO('9I<W5A;&EZ>F%T:2!D86QL92!P97)S;VYE(&-H92`B"B)L
M96=G;VYO(&4@<FES<&]N9&]N;R!A:70@='5O:2!M97-S86=G:2XB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG
M:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C
M=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R
M(")#:6%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R
M(")697)I9FE?8V$@3&EN:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D-H:6QE(@IM<V=S='(@(E1I=&]L;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z
M>GD*;7-G:60@(D-H:6YA(@IM<V=S='(@(D-I860B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS
M9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY
M"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")!;FYU;&QA(%!A
M<W-W;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")396QE>FEO;F$@8V]M92!V:7-U86QI
M>GIA<F4@;&4@9&%T93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I
M9"`B0VQE87(B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U3
M3V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B16QI
M;6EN82!U=&5N=&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B
M"FUS9W-T<B`B16QI;6EN82!U=&5N=&4Z("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S
M='(@(D5L:6UI;F$@=71E;G1E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")%
M;&EM:6YA(&QE(&EN9F]R;6%Z:6]N:2!D96QL)W5T96YT92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS
M9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(E!I;V=G:6$@5&%R9&DB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B0VQI8V-A('!E<B!#
M;VYT:6YU87)E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM
M<V=S='(@(D-H:75D:2!L82!&:6YE<W1R82(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3G5V;VQE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z
M>GD*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(").=79O;&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B
M0VQO=61Y(@IM<V=S='(@(DYU=F]L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O
M8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(D-O;&QA
M<'-E(%-I9&5B87(B"FUS9W-T<B`B36%R9VEN:2!C;VQL87-S871I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B36%R9VEN:2!C
M;VQL87-S871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0V]L;VUB
M:6$B"FUS9W-T<B`B0V]L;W)E(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ
M."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM
M<V=S='(@(D-O;&]R92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")396QE>FEO;F$@0V]L
M;W)E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@HC+"!F=7IZ
M>0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")396QE>FEO;F4@
M5&%G;&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(D-O;&]N;F4Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I
M=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B5FEG;F5T=&4B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M
M86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N
M9"!3:&5L;"(*;7-G<W1R(")3:&5L;"!D:2!#;VUA;F1I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")#
M;VUM96YT(@IM<V=S='(@(D-O;6%N9&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-@HC+"!F=7IZ>0IM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B26P@='5O(&YO;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ
M>0IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")$;VUA;FDB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"B,L(&9U>GIY"FUS
M9VED(")#;VUP86YY(@IM<V=S='(@(D-O<&EA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`B0V]R<VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW
M"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B0V]N9&EZ:6]N
M:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I
M;VYS(@IM<V=S='(@(D-O;F1I>FEO;FDB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<R(*;7-G<W1R(")?0V]N9FEG=7)A>FEO;F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC
M:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@9G5Z>GD*
M;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@
M(DQA(&-O;F9I9W5R87II;VYE(&1E=F4@97-S97)E(&%G9VEO<FYA=&$N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B0V]N9FEG=7)A("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N
M9FER;2!087-S=V]R9"(*;7-G<W1R(")#;VYF97)M82!087-S=V]R9"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(D-O;F=O(@IM<V=S='(@(D-O;&]R
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS
M9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O
M;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(D-O;G1I;G5A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;W!I82(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B0V%M
M<&\@:6UP;W)T871O.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(E-E;&5Z:6]N92!L82!C;W!I82(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-O<&EA<F4@)7,@:6X@)7,B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("));7!O
M<W-I8FEL92!C;W!I87)E("5S(&EN("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B26UP;W-S:6)I;&4@8V]N;F5T=&5R
M<VD@86P@<V5R=F5R("<E<R<@=7-A;F1O($944#H@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10
M.B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!C;VYN971T97)S:2!A;"!S97)V
M97(@)R5S)R!U<V%N9&\@1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!C<F5A<F4@9&ER96-T;W)Y(&QO
M8V%L<F4@<&5R(&QO8V%L92`E<SHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3(U"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T82XB"FUS9W-T<B`B26UP;W-S:6)I;&4@8V]P:6%R92`E
M<R!I;B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@
M:6YV97)T:7)E(&QA(&-O;F9I9W5R87II;VYE+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!E;&EM:6YA<F4@;&\@
M<V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@)R5S)RXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HS.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!L;R!S8W)I<'0@9&D@
M86=G:6]R;F%M96YT;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!C;W!I87)E
M("5S(&EN("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U
M8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(DEM<&]S<VEB:6QE('-A;'9A<F4@;&$@8V]N9FEG=7)A>FEO;F4@)7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8V]P:6%R92`E<R!I;B`E<R(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@
M8V]P:6%R92`E<R!I;B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I
M9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G
M<W1R("));7!O<W-I8FEL92!C;W!I87)E("5S(&EN("5S(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*
M;7-G<W1R("));7!O<W-I8FEL92!C<F5A<F4@9&ER96-T;W)Y(&QO8V%L<F4@
M<&5R(&QO8V%L92`E<SHB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("));7!O<W-I8FEL92!I;G9E<G1I<F4@;&$@8V]N9FEG=7)A>FEO
M;F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DEM
M<&]S<VEB:6QE(&EN=F5R=&ER92!L82!C;VYF:6=U<F%Z:6]N92XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DEM<&]S<VEB
M:6QE(&EN=F5R=&ER92!L82!C;VYF:6=U<F%Z:6]N92XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<V%L=F%R
M92!L82!C;VYF:6=U<F%Z:6]N92`E<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@<V%L=F%R92!U;F$@8V]P:6$@9&D@<V-O<G1A(&1E;&QA
M(&-O;F9I9W5R87II;VYE(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE
M('-A;'9A<F4@=6YA(&-O<&EA(&1I('-C;W)T82!D96QL82!C;VYF:6=U<F%Z
M:6]N92(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!E
M;&EM:6YA<F4@;&\@<V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@)R5S)RXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<V%L=F%R92!U
M;F$@8V]P:6$@9&D@<V-O<G1A(&1E;&QA(&-O;F9I9W5R87II;VYE(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C
M:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B
M26UP;W-S:6)I;&4@<V%L=F%R92!L82!C;VYF:6=U<F%Z:6]N92`E<RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@
M<V-R:79E<F4@;&$@8V]N9FEG=7)A>FEO;F4@<&5R("<E<R<Z("5S+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@<V-R:79E<F4@;&$@8V]N
M9FEG=7)A>FEO;F4@<&5R("<E<R<Z("5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S
M97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"B,L(&9U>GIY
M"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(D-E;G1R82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B
M0V]R<VDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<F5A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(D-R96$@
M=6X@8V]L;&5G86UE;G1O(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R
M(")#<F5A;F4@=6YO(&YU;W9O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T
M,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")097)M97-S
M:2!D:2!#<F5A=&]R92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M,S`*(RP@9G5Z>GD*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R
M(").=6UE<F\@9&5C:6UA;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0HC+"!F=7IZ>0IM<V=I
M9"`B0W)O871I82(*;7-G<W1R(")#<F5A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@
M9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B4W1I;&4@
M871T=6%L92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`HC+"!F=7IZ>0IM
M<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")097)M97-S:2!D:2!#
M<F5A=&]R92(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D]R82!A
M='1U86QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R
M("),82!54DP@871T=6%L92#H(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S
M"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(E-T:6QE
M(&%T='5A;&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#
M=7)R96YT(%=E871H97(B"FUS9W-T<B`B365T96\@071T=6%L92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@
M8V]N9&ET:6]N.B`B"FUS9W-T<B`B0V]N9&EZ:6]N:2!A='1U86QI.B`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS
M9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(E-T:6QE(&%T='5A;&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB
M"FUS9W-T<B`B26UP;W-T82!L92!O<&5R87II;VYI(&1A(&5S96=U:7)E('%U
M86YD;R!E;G1R:2!I;B`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R
M(")486=L:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5Z
M:6]N92!486=L:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL
M;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D='(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")$
M86EL>2(*;7-G<W1R(")':6]R;F\B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B0G)O=W-E<B!$
M871A5')E92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G
M:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S.3D*(RP@9G5Z>GD*;7-G:60@(D1A=&4B"FUS9W-T<B`B
M1&%T:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S
M"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(D1A=&$@4FEC979U=&\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"B,L(&9U>GIY"FUS
M9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")396QE>FEO;F4@5&%G;&EA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"FUS9VED(")$87DB"FUS9W-T<B`B
M1VEO<FYO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R
M(")%7VQI;6EN82!#;VQO;FYA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1I
M8V5M8G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S
M='(@(DYU;65R;R!D96-I;6%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X
M-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*
M;7-G<W1R(")#;VQO<F4@9&D@1&5F875L="(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(D-O;&]R92!D:2!$969A=6QT(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0HC+"!F=7IZ>0IM<V=I9"`B1&5F
M875L="!)9&5N=&ET>2(*;7-G<W1R("))9&5N=&ETX"!D:2!$969A=6QT(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$
M969A=6QT(%-H96QL(@IM<V=S='(@(D-O;&]R92!D:2!$969A=6QT(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")$969I
M;FET:6]N<R(*;7-G<W1R(")#;VYD:7II;VYI(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(D-A;F-E;&QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M0V5L;"(*;7-G<W1R(")%;&EM:6YA(&-E;&QA(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'
M<F]U<"(*;7-G<W1R(")%;&UI;F$@1W)U<'!O(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G
M(@IM<V=S='(@(D5L;6EN82!R:6=A(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M4&5R;65S<VD@9&D@9&5F875L="(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE
M<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM
M<V=S='(@(D5L:6UI;F$@8V5L;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L
M=6UN(@IM<V=S='(@(D5L:6UI;F$@8V]L;VYN82(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E(@IM<V=S='(@(D%V=FES82!S=2!A9V=I;W)N86UE;G1I(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(D5L:6UI;F$@<&5R;65S<VD@<&5R("<E<R<B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(D5L:6UI;F$@<75E
M<W1O('!E<FUE<W-O(&4@<75A;'-I87-I('-O='1O+7!E<FUE<W-O/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B16QM:6YA(')I9V$B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED
M(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B16QI;6EN82!L
M)VED96YT:73@('-E;&5Z:6]N871A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(D5L:6UI;F$@;&$@8V]L;VYN
M82!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT
M(')O=R(*;7-G<W1R(")%;&EM:6YA(&QA(')I9V$@8V]R<F5N=&4B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(D5L:6UI;F%T;R!I;"!S8W)I<'0@9&D@86=G:6]R;F%M96YT
M;R!D96P@<V5T=7`@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS
M9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(D-A;F-E;&QA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0HC+"!F=7IZ>0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(").;W1E(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E
M<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D1E<V-R:79I(&EL(%!R;V)L
M96UA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7II;VYE(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.3D*(RP@9G5Z>GD*;7-G:60@(D1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(D1E='1A9VQI(&QO9V=A=&D@<&5R(&PG86UM:6YI<W1R871O<F4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P
M;65N="(*;7-G<W1R(")3=FEL=7!P;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4'5N=&\@9&D@4G5G
M:6%D82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"B,L(&9U>GIY"FUS
M9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7!E
M<F%T=7)A('5L=&EM82!O<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(E!U;G1O(&1I(%)U9VEA9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D-A<G1E;&QA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I
M;65S/R(*;7-G<W1R(")6:7-U86QI>GIA(&YE;"!F;W)M871O(#(T(&]R93\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@
M3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI(%9I<W5A;&EZ>F%Z:6]N92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I
M9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")/<'II;VYI
M(%9I<W5A;&EZ>F%Z:6]N92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*
M;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B
M1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!/<F$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F]N
M(&5L:6UI;F%R92(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM
M<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B
M"FUS9W-T<B`B3F]N(&%C8V5D97)E(&1I<F5T=&%M96YT92!A(&UA:6YT96YA
M;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F
M:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE
M8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*(DQA('!R:6UA(')I9V$@8V]N=&EE
M;F4@;&4@971I8VAE='1E(&1I(&-A;7!O/R!-87)C82!S92!S:2P@;&%S8VEA
M('9U;W1A('-E("(*(FYO.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U
M8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R(")#;VUA;F1O('-C;VYO
M<V-I=71O.B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G
M:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N(@IM<V=S='(@(E-C87)I8V$@;&$@8V]N9FEG=7)A>FEO;F4@9V5N
M97)A=&$@8V]M92!S8W)I<'0@4$A0+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B4&]S=&$B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I
M9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@
M=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET(@IM<V=S='(@(DUO9&EF:6-A(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U
M"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(DUO9&EF:6-A($)L;V-C;R(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V
M"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(DUO9&EF:6-A($=R=7!P;R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;B(*;7-G<W1R(")-;V1I9FEC82!097)M97-S:2(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B36]D:69I8V$@4&5R;65S<VDB"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(DUO9&EF:6-A('!E<FUE
M<W-I('!E<B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G
M:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(DUO9&EF:6-A(&]P>FEO
M;FD@<&5R.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(B"FUS9W-T<B`B36]D:69I8V$@<&5R;65S<VD@<&5R("5S
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")-
M;V1I9FEC82!P97)M97-S:2!P97(@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("),
M=6]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*
M;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@
M8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G
M:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0HC+"!F=7IZ>0IM<V=I
M9"`B16UA:6PB"FUS9W-T<B`B4&]S=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO(&1I
M(%!O<W1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PHC+"!F
M=7IZ>0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(DQE('!A<W-W;W)D(&1E=F]N;R!C;W)R:7-P;VYD97)E+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G:60@(D5M
M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E-A;'9A=&\@;&$@8V]N
M9FEG=7)A>FEO;F4@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR.3@*(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R
M(")#;VYD:7II;VYI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M
M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG
M:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R
M9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H
M92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V
M:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R
M(")%<G)O<F4B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C
M:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN
M8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U
M"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@
M;6EN=71E<R(*;7-G<W1R(")/9VYI(#$U(&UI;G5T:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G
M<W1R(")/9VYI(#(@;6EN=71I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S
M,"!S96-O;F1S(@IM<V=S='(@(D]G;FD@,S`@<V5C;VYD:2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D]G;FD@-2!M:6YU
M=&DB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C8P"B,L(&9U>GIY"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")/9VYI
M(&UI;G5T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@
M(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")/9VYI($UE>GHG;W)A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B3V=N:2!M:6YU
M=&\B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B
M17AA;7!L92!V86QU97,Z(@IM<V=S='(@(E9A;&]R:2!D:2!E<V5M<&EO.B(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z
M-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G
M<W1R(")%<V5C=7II;VYE(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I
M9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$V.`HC+"!F=7IZ>0IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S
M='(@(D5S96-U>FEO;F4B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D
M('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V
M"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#
M;VQO<B(*;7-G<W1R(")#;VQO<F4@1D<B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@
M(E5P;&]A9"`H0V%R:6-A;65N=&\I(&9I;&4@;F]N('-U<'!O<G1A=&\N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&
M86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL
M92!C;W!I87)E("5S(&EN("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B1VEU<W1O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I
M9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D5R<F]R93H@(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*
M(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9R86UE<R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&
M96)R=6%R>2(*;7-G<W1R(")&96)B<F%I;R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(E-I('-E;G1E
M(&-O;64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS
M9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B4VD@<V5N=&4@8V]M93H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G
M:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(E!O8VAI($%C<75A>GIO;FDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`HC+"!F
M=7IZ>0IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")0;V-H:2!!
M8W%U87IZ;VYI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM
M<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@
M(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I
M:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(D9I;'1R:2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL
M92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@
M(D9I;&4@36%N86=E<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U
M"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B3F]M92!#;VUP
M;&5T;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*(RP@9G5Z
M>GD*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5Z:6]N92!4
M86=L:6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED
M(")&:6QE('5P;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX-3D*(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")5<&QO860@*$-A<FEC86UE;G1O
M*2!F:6QE(&YO;B!S=7!P;W)T871O+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<FDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B
M4')I;6$@365T82<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L
M;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@
M(E!R:6UO(%1R:6UE<W1R92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q
M"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(D9L;V%T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S
M(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S
M='(@(D-O;&]R92!&;VYT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W
M"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B
M4&5R(&)R;W=S97(@8VAE(&YO;B!S;W!P;W)T86YO(&QE(&EM;6%G:6YI(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4
M048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@
M(DAA:2!D:6UE;G1I8V%T;R!L82!T=6$@<&%S<W=O<F0_(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B
M36]D=6QI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&
M;W)T=6YE(@IM<V=S='(@(DEN9&]V:6YO(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B1F]R='5N
M92!4>7!E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&
M;W)T=6YE<R(*;7-G<W1R(")&;W)T=6YE<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R
M(")&;W)T=6YE<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*
M;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;W)U;2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(DEN
M;VQT<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")696XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&
M<F%M97,B"FUS9W-T<B`B1G)A;65S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM
M<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86UE<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN
M97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"B,L(&9U>GIY"FUS9VED
M(")&<F]M(@IM<V=S='(@(E9E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B1&%L("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@
M(D1E<V-R:7II;VYE($-O;7!L971A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*
M;7-G<W1R("),=6YA(%!I96YA(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@
M(D9U;&P@3F%M92(*;7-G<W1R(").;VUE($-O;7!L971O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'
M86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I
M9W5R871I;VXB"FUS9W-T<B`B1V5N97)A($-O;F9I9W5R87II;VYE("5S("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED
M(")'96YE<F%T960@0V]D92(*;7-G<W1R(")#;V1I8V4@1V5N97)A=&\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L
M=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R(")6
M86D@82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E
M9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G;&4@36%P<R(*
M;7-G<W1R(")2:6-E<F-A($=O;V=L92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B4FEC97)C
M82!';V]G;&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(D=R965C92(*;7-G<W1R(")697)D92(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/
M+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I
M9"`B1W)E96YL86YD(@IM<V=S='(@(E9E<F1E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`HC+"!F
M=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")697)D92(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")!;6UI;FES=')A>FEO;F4@1W)U<'!I(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E
M;&5T92!G<F]U<"`E<R(*;7-G<W1R("));7!O<W-I8FEL92!C86YC96QL87)E
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T
M<B`B1W)U<'!I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(D=U
M97)N<V5Y(@IM<V=S='(@(D=R:6=I;R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*
M;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUE<W-I($]S
M<&ET:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@
M(D=U97-T8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS
M9VED(")'=6EN96$B"FUS9W-T<B`B1VEU9VYO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP
M:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G
M:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3,R"B,L(&9U>GIY"FUS9VED(")(96%D97(B
M"FUS9W-T<B`B3&5G9VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M
M(@IM<V=S='(@(E0M5&5M<&5S=&$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")!;'1E>GIA(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP
M(@IM<V=S='(@(D%I=71O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F
M=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%I=71O(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(D5M
M:7-F97)O(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B06QT82(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`B2&]?<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"B,L(&9U>GIY"FUS9VED
M(")(;VUE(@IM<V=S='(@(DAO7W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$U-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92!!
M9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R!D:2!0;W-T82(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!$:7)E
M8W1O<GDB"FUS9W-T<B`B0V%R=&5L;&$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D
M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R
M<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")3
M8W)I='1O(&-O;B!S=6-C97-S;R`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T
M:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y
M<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S
M:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED
M(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B3W)I>GIO;G1A;&4Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(E)I96UP:6UE;G1O($]R
M:7IZ;VYT86QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B3W)I>GIO
M;G1A;&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@
M*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R
M(")1=6%N=&4@8V]L;VYN92!V=6]I('5N:7)E/R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B475A;G1I(&-A;7!I("AC;VQO
M;FYE*2!C:2!S;VYO/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E%U86YT92!R:6=H92!V
M=6]I('5N:7)E/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM
M<V=S='(@(E5M:61I=.`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4Y"B,L(&9U>GIY"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(E5M
M:61I=.`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU
M;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R
M96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*
M;7-G<W1R("));F1I<FEZ>F\@9&D@4&]S=&$B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEP8F%S:6,N<&AP.C<W"B,L(&9U>GIY"FUS9VED("))4"!!9&1R
M97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;V-K(&YO;B!D:7-P;VYI
M8FEL92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"
M969O<F4B"FUS9W-T<B`B25]N<V5R:7-C:2!L82!R:6=A('!R:6UA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T
M<B`B4V]L;R!)8V]N92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S
M='(@(D]P>FEO;FD@9F]R("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(DEC;VYE(&-O
M;B!497-T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B3F]M92!D96QL)TED96YT:73@
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O
M<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*
M(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@
M='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B
M(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I
M9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B06YT97!R:6UE($EM;6%G:6YE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E523"!);6UA9VEN
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@
M26UM86=I;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B26UM
M86=I;FDB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O
M<G1A+"!087-S;R`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*
M;7-G<W1R(")#86UP;R!I;7!O<G1A=&\Z("5S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G
M<W1R(")#86UP:2!I;7!O<G1A=&DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T
M(%)O=R!!9G1E<B(*;7-G<W1R("));E]S97)I<V-I('5N82!R:6=A(&1O<&\B
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*
M;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(D1E=FD@:6YS97)I<F4@:6P@='5O(&YO
M;64@=71E;G1E(&4@;&$@<&%S<W=O<F0B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R
M(")5=&5N=&D@26YD:79I9'5A;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(DEN9&]N97-I82(*;7-G<W1R(")F871T;R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PIM
M<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87II;VYE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF;W)M
M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U
M"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("));G-E<FES
M8VD@=6YA($-?;VQO;FYA(&1O<&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R
M="!);6%G92(*;7-G<W1R("));G-E<FES8VD@=6XG:6UM86=I;F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED
M("));G-E<G0@5&%B;&4B"FUS9W-T<B`B26YS97)I<V-I(%1A8F5L;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS
M9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B26YS97)I<V-I($-O;&QE
M9V%M96YT;R!796(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E
M9F]R92(*;7-G<W1R("));G-E<FES8VD@7V-O;&]N;F$@4')I;6$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@;G5O=F$@8V]L;VYN82!D
M;W!O('%U96QL82!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN
M<V5R:7-C:2!U;F$@;G5O=F$@8V]L;VYN82!P<FEM82!D:2!Q=65L;&$@8V]R
M<F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@;G5O=F$@
M<FEG82!D;W!O('%U96QL82!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS
M97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(DEN<V5R:7-C:2!U;F$@;G5O=F$@<FEG82!P<FEM82!D:2!Q=65L;&$@8V]R
M<F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R:7-C
M:2!U;F$@;G5O=F$@<FEG82!D;W!O('%U96QL82!C;W)R96YT92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@;G5O=F$@
M<FEG82!P<FEM82!D:2!Q=65L;&$@8V]R<F5N=&4B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M92(*;7-G<W1R("));G-E<FES8VD@=6X@=&5M<&QA=&4@86QT97)N871I=F\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T
M(&-E;&P@869T97(B"FUS9W-T<B`B26YS97)I<V-I(&-E;&QA(&1O<&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B26YS97)I
M<V-I(&-E;&QA('!R:6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A
M9G1E<B(*;7-G<W1R(")!9V=I=6YG:2!C;VQO;FYA(&1O<&\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("));G-E<FES8VD@
M8V]L;VYN82!P<FEM82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDP"B,L(&9U>GIY"FUS9VED("));G-E<G0@;65S<V%G97,B
M"FUS9W-T<B`B26YS97)I<V-I('5N)VEM;6%G:6YE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DEN<V5R:7-C:2!P
M87)A9W)A9F\@9&]P;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!B969O<F4B"FUS9W-T<B`B26YS97)I<V-I('!A<F%G<F%F;R!P<FEM82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B26YS97)I
M<V-I(')I9V$@9&]P;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E
M(@IM<V=S='(@(DEN<V5R:7-C:2!R:6=A('!R:6UA(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS
M9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DEN<V5R:7-C:2]-
M;V1I9FEC82!);6UA9VEN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#D*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="]-;V1I
M9GD@3&EN:R(*;7-G<W1R("));G-E<FES8VDO36]D:69I8V$@26UM86=I;F4B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-S4*(RP@9G5Z>GD*;7-G:60@(DEN=&5G97(B"FUS
M9W-T<B`B0V5N=')A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S
M,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@
M(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B07!P;&EC87II;VYE(&EN=F%L:61A+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV
M86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RXB"FUS9W-T<B`B07!P;&EC87II;VYE(&EN=F%L:61A
M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F]R
M;6%T;R!/<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R
M(")!<'!L:6-A>FEO;F4@:6YV86QI9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B07!P;&EC87II;VYE(&EN=F%L:61A
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`S"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED
M+B(*;7-G<W1R(")$871O(&YO;B!V86QI9&\N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B
M1&%T;R!N;VX@=F%L:61O+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B1&%T;R!N;VX@=F%L:61O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I
M9"XB"FUS9W-T<B`B1&%T;R!N;VX@=F%L:61O+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M<')O9'5C="!C;V1E+B(*;7-G<W1R(")!<'!L:6-A>FEO;F4@:6YV86QI9&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G
M<W1R(")!<'!L:6-A>FEO;F4@:6YV86QI9&$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV
M86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E
M<W,N(@IM<V=S='(@(D1A=&\@;F]N('9A;&ED;RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")!<'!L:6-A
M>FEO;F4@:6YV86QI9&$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&%R:6\B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"B,L
M(&9U>GIY"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5Z
M:6]N92!486=L:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M("))<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*(RP@9G5Z>GD*;7-G:60@
M(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(E0M5&5M<&5S=&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(D-O<G-I=F\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(D-O<G-I
M=F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G
M:60@(DIA;G5A<GDB"FUS9W-T<B`B1V5N;F%I;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B
M1VEA<'!O;F5S92`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@
M9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO
M="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G:60@
M(DIE<G-E>2(*;7-G<W1R(")'<FEG:6\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("),=6=L:6\B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM
M<V=I9"`B2G5N92(*;7-G<W1R(")':75G;F\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T
M:69Y(@IM<V=S='(@(D=I=7-T:69I8V%T;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"B,L(&9U>GIY"FUS
M9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")':75S=&EF:6-A=&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(D=I
M=7-T:69I8V%T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$T"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y($QE
M9G0B"FUS9W-T<B`B1VEU<W1I9FEC871O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G
M:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B1VEU<W1I9FEC871O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@
M(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0HC+"!F=7IZ>0IM
M<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D]P>FEO;FDB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG
M97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@
M5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@
M(E5T:6QI>GIO.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED
M(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?1F]R;6%T;R(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E
M(@IM<V=S='(@(DQI;F=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3&%S="!(86QF
M(@IM<V=S='(@(E!R:6UA($UE=&$G(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*
M;7-G<W1R(")!;FYU;&QA(%!A<W-W;W)D(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(E5L=&EM;R!1=6%R=&\B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")5;'1I
M;6\@06=G:6]R;F%M96YT;SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS
M9W-T<B`B56QT:6UO(&%C8V5S<V\Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,B"FUS9W-T<B`B56QT:6UO(&%C8V5S<V\Z("5S(&1A("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T
M(&QO9VEN.B!.979E<B(*;7-G<W1R(")5;'1I;6\@86-C97-S;SH@36%I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("),871V:6$B"FUS9W-T<B`B
M1&%T:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`HC+"!F=7IZ>0IM
M<V=I9"`B3&%W(@IM<V=S='(@(D)A<W-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B
M"FUS9W-T<B`B1F]R;6%T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")S:6YI<W1R
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE
M9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@
M(E9A;&]R:2!D:2!E<V5M<&EO.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S
M;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@(DUA:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U
M"B,L(&9U>GIY"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(D)L=2!#
M:&EA<F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")0:6]G9VEA($QE9V=E
M<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-PHC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R(")0
M:6]G9VEA($QE9V=E<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!,871E
M(@IM<V=S='(@(E!I;V=G:6$@3&5G9V5R82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"B,L(&9U>GIY"FUS9VED("),:6=H
M="!286EN(%-H;W=E<B(*;7-G<W1R(")0:6]G9VEA($QE9V=E<F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`HC+"!F=7IZ
M>0IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B4&EO
M9V=I82!,96=G97)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T
M<B`B4&EO9V=I82!,96=G97)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B
M3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R(")%;G1R82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PHC+"!F=7IZ>0IM<V=I9"`B3&EN:W,B
M"FUS9W-T<B`B0V]M<&ET:2!D:2!I;FEZ:6\@<V5S<VEO;F4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(D5L
M96YC82!G;&D@87)G;VUE;G1I(&1I($%I=71O(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T
M<B`B26YS97)I<V-I(%1A8F5L;&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L
M(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B16QE;F-A(&=L:2!A
M<F=O;65N=&D@9&D@06EU=&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES
M="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"B,L(&9U>GIY
M"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R(")3;W1T;W-C<FEV:2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED
M("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(DYO;B#H(&%T=&EV82!L
M82!F=6YZ:6]N92!D:2!E;&5N8V\@=71E;G1I+B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(DYO;B#H(&%T=&EV82!L82!F
M=6YZ:6]N92!D:2!E;&5N8V\@=71E;G1I+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`B3F]N(.@@871T:79A(&QA(&9U;GII;VYE(&1I
M(&5L96YC;R!U=&5N=&DN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W
M"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R871U<F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R(")5
M;FETX"!,87)G:&5Z>F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C@S"B,L(&9U>GIY"FUS9VED("),;V%D:6YG+BXN(@IM
M<V=S='(@(D%G9VEO<FYA;F1O:6X@8V]R<V\N+BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS
M9W-T<B`B3W)A(&QO8V%L93H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B3&EN9W5A(&4@
M3W)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),
M;V-A=&EO;B(*;7-G<W1R("),=6]G;R(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*
M;7-G<W1R(")%;G1R82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS
M9VED("),;V<@;W5T(@IM<V=S='(@(D5S8VDB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(D5N
M=')A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G
M:6X@5&%S:W,B"FUS9W-T<B`B0V]M<&ET:2!D:2!I;FEZ:6\@<V5S<VEO;F4B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDY,@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I
M;&5D+B(*;7-G<W1R(")F86QL:71O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@
M(D5S8VDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*(RP@9G5Z>GD*
M;7-G:60@(DQO=F4B"FUS9W-T<B`B16QI;6EN82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T
M<B`B0F%S<V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3D*(RP@9G5Z>GD*;7-G:60@(DQO=V5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B;G5M97)I(')O;6%N:2!P:?D@8F%S<VDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(FYU;65R:2!R;VUA;FD@<&GY(&)A<W-I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU4
M3D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DU31R(*;7-G<W1R
M(")#35,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA8V%O(@IM
M<V=S='(@(E9A8V%N>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI
M82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-
M86=I8R(*;7-G<W1R(")-87)G:6YE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(E!O<W1A(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*
M;7-G<W1R("));F1I<FEZ>F\@06UM:6YI<W1R871O<F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G
M:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L
M(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`B4&]S=&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L
M(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(E!O<W1A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")0;W-T82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@HB1V5S=&ES8VD@;&$@;&ES=&$@9&5L;&4@
M8V%T96=O<FEE(&1A;F1O(&QO<F\@=6XG971I8VAE='1A(&4@87-S;V-I86YD
M;R!L;W)O("(*(G5N(&-O;&]R92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S
M=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-87)Z;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G:6YE(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA
M<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B
M36%R=&EN:7%U92(*;7-G<W1R(")-87)G:6YE(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G
M<W1R(")#86UP:2!C;W)R:7-P;VYD96YT:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F
M=7IZ>0IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-87)G:6YE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS
M9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I
M9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"B,L(&9U>GIY"FUS9VED(")-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@=6QT
M:6UA(&]R83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*(RP@9G5Z
M>GD*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E
M;7!E<F%T=7)A('5L=&EM82!O<F$Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS
M9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-
M87DB"FUS9W-T<B`B36%G9VEO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM
M<V=I9"`B36%Y;W1T92(*;7-G<W1R(")&;W)M871O(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-
M96UB97)S(@IM<V=S='(@(DUE;6)R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM
M<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B56YI<V-I($-E;&QE(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B571I;&EZ>F\Z
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G
M:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@
M<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T
M87(@5V5A=&AE<B(*;7-G<W1R(")-971E;R!!='1U86QE(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B0FQO8VL@;F]N(&1I<W!O;FEB:6QE+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971T86=L:2!L;V=G871I('!E
M<B!L)V%M;6EN:7-T<F%T;W)E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*
M;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D
M969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*
M;7-G:60@(DUE=')I8R(*;7-G<W1R(")M971R:6-O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"B,L(&9U>GIY"FUS9VED(")-97AI8V\B"FUS9W-T<B`B;65T<FEC;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D-E
M;G1R;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R(")496UP97)A='5R82!U;'1I;6$@;W)A.B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B
M36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@
M=6QT:6UA(&]R83H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(D5R<F]R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN
M9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@
M:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I
M;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DQU;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA
M:6PB"FUS9W-T<B`B36]B:6QE($UA:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T
M<B`B36]D97)A=&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`HC
M+"!F=7IZ>0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")-;V1E<F%T
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")-;V1I9FEC
M82!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@
M9G5Z>GD*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]D97)A=&\B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*
M;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@
M:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-
M;W-T;'D@0VQE87(B"FUS9W-T<B`B4')I;F-I<&%L;65N=&4@4V5R96YO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*(RP@
M9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B4')I;F-I<&%L
M;65N=&4@4V5R96YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@
M(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HU,3,*(RP@9G5Z>GD*;7-G:60@(DUO=F4@3&5F="(*
M;7-G<W1R(")S:6YI<W1R82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4Q-PHC+"!F=7IZ>0IM<V=I9"`B36]V92!2:6=H="(*;7-G
M<W1R(")$97-T<F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V
M92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA
M<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T,@HC+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(E-E;&5Z:6]N92!486=L:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUI;R!!
M8V-O=6YT(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY
M"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E9O<W1R
M82!I;F9O<FUA>FEO;F4B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B36EO(%!O<G1A;&4B"@HC
M.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T
M86P@3&%Y;W5T(@IM<V=S='(@(D9O<FUA=&\@9&5L($UI;R!0;W)T86QE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED
M(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D\L($Y/3B!3;VYO(&0G
M06-C;W)D;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`HC+"!F
M=7IZ>0IM<V=I9"`B3F%M92(*;7-G<W1R(")N;VUE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS
M9VED(").97!A;"(*;7-G<W1R(")4;W1A;&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@
M0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T
M"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T
M<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-3
M3"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(E)E=&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").
M979E<B(*;7-G<W1R(")-86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G
M:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3G5O=F$@0V%T96=O<FEA(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").=6]V82!#871E9V]R
M:6$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I
M9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA
M;"DB"FUS9W-T<B`B3G5O=F\@3F]M92!5=&5N=&4@*$]P>FEO;F%L92DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ>0IM
M<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B3&4@
M<&%S<W=O<F0@9&5V;VYO(&-O<G)I<W!O;F1E<F4N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I
M;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W1I
M>FEE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B
M3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P<&D@9&D@;F]T:7II92(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM
M<V=S='(@(E!R;W-S:6UO(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS
M9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T
M<B`B5&]R;F$@86QL92!/<'II;VYI+B(*"B,Z(&9R86UE=V]R:R]522]522]0
M86=E<BYP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(").97AT/B(*;7-G<W1R(")0
M<F]S<VEM;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS
M9W-T<B`B3F]T=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM
M<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F]T=&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@
M9G5Z>GD*;7-G:60@(DYI=64B"FUS9W-T<B`B3F]T82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*(RP@9G5Z>GD*;7-G
M:60@(DYO(@IM<V=S='(@(DYE<W-U;F\B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E
M;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W
M"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN
M<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-
M0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G
M<W1R(")N;VX@;6]D:69I8V%T;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(").;VX@<'5O:2!C<F5A<F4@
M9FEG;&D@82!Q=65S=&\@<&5R;65S<V\N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*
M(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L('!H<"UF;W)M870*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E
M9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S
M='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B5S(&YO;B!T<F]V871O
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S
M"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@
M(D%P<&QI8V%Z:6]N92!E)R!P<F]N=&$N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(DYE<W-U;B!,;V-A;&4@4W!E8VEF:6-A=&\B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS
M9W-T<B`B3F5S<W5N($QO8V%L92!3<&5C:69I8V%T;R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,L(&9U>GIY
M"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3F5S<W5N($QO
M8V%L92!3<&5C:69I8V%T;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"B,L(&9U>GIY"FUS9VED(").;R!N=6UB
M97(@<W!E8VEF:65D+B(*;7-G<W1R(").97-S=6X@3&]C86QE(%-P96-I9FEC
M871O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A
M<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T
M;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I
M;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").
M97-S=6YA(')E9VES=')A>FEO;F4@:6X@871T97-A+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HW-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DYO('%U;W1A('-E="XB"FUS9W-T<B`B3F]N(&EM<&]S=&%T;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*
M;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DYE<W-U;F$@<F5G;VQA(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED
M(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R(").97-S=6X@3&]C
M86QE(%-P96-I9FEC871O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T
M<B`B3F5S<W5N(&QA=&\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4X,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(DYE
M<W-U;B!L871O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S
M.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+B(*;7-G<W1R(").97-S=6X@9&ER971T;W)I;R!T96UP;W)A;F5O
M(&1I<W!O;FEB:6QE('!E<B!L82!C86-H92XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(D1E
M=FD@:6YS97)I<F4@:6P@='5O(&YO;64@=71E;G1E(&4@;&$@<&%S<W=O<F0B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*(RP@9G5Z>GD*
M;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(").97-S=6YA(')E9V]L82(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@
M9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B).97-S=6YA('9E<G-I;VYE('1R
M;W9A=&$@;F5L;&$@8V]N9FEG=7)A>FEO;F4@;W)I9VEN86QE+B!296=E;F5R
M82!L82`B"B)C;VYF:6=U<F%Z:6]N92XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"B).97-S=6YA('9E<G-I;VYE('1R;W9A=&$@;F5L;&$@='5A(&-O;F9I
M9W5R87II;VYE+B!296=E;F5R82!L82`B"B)C;VYF:6=U<F%Z:6]N92XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").
M;VYE(@IM<V=S='(@(DYE<W-U;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC
M:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS
M9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*(RP@
M9G5Z>GD*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B16UI
M<V9E<F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DYO
M;B!I;7!O<W1A=&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*(RP@9G5Z>GD*;7-G:60@(DYO
M="!A(&1I<F5C=&]R>2(*;7-G<W1R(")#87)T96QL82(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F]N(&EM<&]S=&%T;R(*"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO
M=&5S(@IM<V=S='(@(DYO=&4B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E
M>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB<F4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED
M(").=6UB97(B"FUS9W-T<B`B3F]V96UB<F4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(U"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@8VAA
M<F%C=&5R<R(*;7-G<W1R(").=6UE<F\@9&D@<FEG:&4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M
M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B3G5M97)O(&1I(&-O;&]N;F4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM
M<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B3G5M97)O(&1I(')I9VAE
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I
M;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB
M"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B
M4')O<')I971A<FEO(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(E!R;W!R:65T87)I
M;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*(RP@9G5Z>GD*
M;7-G:60@(D]C=&%L(@IM<V=S='(@(F-A;&UO(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B3W1T;V)R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(E5F
M9FEC:6\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G
M:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V
M"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O
M<F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@
M(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F
M96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0HC
M+"!F=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+B(*;7-G<W1R("));F1I<FEZ>F\@96UA:6P@86QT97)N871I=F\B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/
M<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!<')I(&EN(&YU;W9A(&9I
M;F5S=')A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R(")!<')I('%U97-T;R!C;VQL96=A;65N=&\@:6X@;G5O=F$@9FEN97-T
M<F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A
M=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S
M(@IM<V=S='(@(D]P>FEO;FD@9F]R("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38W"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B
M1W)O=7!787)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI
M>FEN9R(*;7-G<W1R(")'<F]U<%=A<F4B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B
M"FUS9W-T<B`B87!P;&EC87II;VYE(&EN=&5R;F$B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")A<'!L:6-A>FEO;F4@
M:6YT97)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R
M(")!;'1R;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@
M(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%L=')E($EN9F]R;6%Z:6]N
M:2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W
M;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUE<W-I(&1E;"!0<F]P<FEE
M=&%R:6\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R("));"!M;V1U;&\@=V5A=&AE<BYC;VT@;F]N(.@@9&ES
M<&]N:6)I;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM
M<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%
M;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S
M"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS
M9W-T<B`B0V]D:6-E(%!(4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM
M<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN
M(@IM<V=S='(@(E!-(%!I;V=G:6$@3&5G9V5R82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")0
M32!3:&]W97)S(@IM<V=S='(@(DUO<W1R82!!32(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0P"B,L(&9U>GIY"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B36]S=')A($%-(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@HC+"!F=7IZ>0IM
M<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B5"U496UP97-T92(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO
M;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM
M<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"B,L(&9U>GIY"FUS
M9VED(")0861D:6YG(@IM<V=S='(@(E-P97-S;W)E(&-E;&QE.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B26YC
M;VQL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS
M9VED(")086YA;6$B"FUS9W-T<B`B;F]M92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R(").=79O;&4B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R(")087-S=V]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM
M<V=S='(@(E!A<W-W;W)D.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#4S"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")D:6=I=&$@;&$@<&%S<W=O<F0@
M9'5E('9O;'1E('!E<B!C;VYF97)M87)E(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4&%S
M<W=O<F0Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G
M:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4&%S<W=O<F0Z("(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A
M<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("),92!P87-S=V]R9"!D979O
M;F\@8V]R<FES<&]N9&5R92XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B26YC;VQL82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A
M<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS
M9W-T<B`B4&5R8V]R<V\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")296=I<W1R
M87II;VYI(&EN($%T=&5S83HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R(")0<F]B;&5M82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W
M"FUS9VED(")097)C96YT(@IM<V=S='(@(E!E<F-E;G1U86QE(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@
M(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")%<V5G
M=6D@;&4@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO;F4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D5S96=U:2!L92!O<&5R
M87II;VYI(&1I(&UA;G5T96YZ:6]N92!A;"!L;V=I;C\B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*
M;7-G<W1R(")097)M97-S:2(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E
M<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")097)M97-S:2`G)7,G(&YO;B!E
M;&EM:6YA=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*
M(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E
M<FUE<W-I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G
M:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E]097)M97-S:2(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D%M;6EN:7-T<F%Z:6]N92!D96D@4&5R;65S<VDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%Z:6]N:2!097)S;VYA;&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")0971S(@IM<V=S='(@
M(E!R;V=E='1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")0:&]N92(*;7-G<W1R(")F871T
M;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H
M;W1O<R(*;7-G<W1R(")&;W1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:7AE
M;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET
M=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M(@IM<V=S='(@(E!R96=O(&-O;F9E<FUA<F4@96QI;6EN87II;VYE(&5L96UE
M;G1O.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")0<F5G;R!C
M;VYF97)M87)E(&5L:6UI;F%Z:6]N92!L:6YK.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U-S$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(DEN<V5R:7-C:2!U;B!N
M;VUE('!E<B!L82!N=6]V82!C871E9V]R:6$Z(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(DEN
M<V5R:7-C:2!U;B!N;VUE('!E<B!L82!N=6]V82!C871E9V]R:6$Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I
M9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(D1E=FD@
M:6YS97)I<F4@:6P@='5O(&YO;64@=71E;G1E(&4@;&$@<&%S<W=O<F0B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@
M(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM
M<V=S='(@(B(*(DQE9V=I(&EL('-E9W5E;G1E('1E<W1O+B!$159)(&%C8V5T
M=&%R92!I('1E<FUI;FD@9#MU<V\@<&5R('5T:6QI>GIA<F4@:6P@(@HB<VES
M=&5M82XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("));G-E<FES8VD@=6X@;F]M92!P
M97(@;&$@;G5O=F$@8V%T96=O<FEA.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ
M>0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(D-O;6%N9&\B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E!O;&ET:6-S(@IM
M<V=S='(@(E-O;F1A9V=I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B4V]N9&%G9VDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")-:6\@
M4&]R=&%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI
M<R!I;6%G92(*;7-G<W1R(")0;W-I>FEO;F%M96YT;R!D:2!Q=65S=&$@:6UM
M86=I;F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS
M9W-T<B`B4&]S:7II;VYA;65N=&\@9&D@<75E<W1A('1A8F5L;&$B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")4
M96UP97)A='5R82!U;'1I;6$@;W)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA
M;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P
M+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S
M=7)E(@IM<V=S='(@(E!R97-S:6]N92(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R
M(")0<F5S<VEO;F4@86P@;&EV96QL;R!D:2!M87)E.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM
M<V=S='(@(E!R97-S:6]N93H@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B
M"FUS9W-T<B`B06YT97!R:6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W
M('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B06YT97!R:6UA
M(&1E;&PG:6UM86=I;F4@:6X@;G5O=F$@9FEN97-T<F$B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N
M<R(*;7-G<W1R(")!='1I=FET82<@<')E8V5D96YT92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT
M(&1O8W5M96YT(@IM<V=S='(@(E-T86UP82!D;V-U;65N=&\@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E
M($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96UA(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E
M<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7II;VYE(&1E;"!P<F]B;&5M82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE
M8W1S(@IM<V=S='(@(E!R;V=E='1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*(RP@9G5Z>GD*;7-G:60@(E!R
M;VUP="!T97AT(@IM<V=S='(@(D1A;"`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G
M:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@
M2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")1871A<B(*;7-G<W1R(")$871I(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R
M(")$;VUA;F1A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED
M(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC
M($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C8T"B,L(&9U>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB
M"FUS9W-T<B`B4V5L97II;VYE(&QA(&-O<&EA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T
M<B`B4&EO9V=I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(E!I;V=G:6$@
M4')E<W1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")0:6]G9VEA(%1A<F1I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*
M(RP@9G5Z>GD*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(D%C<75A>GIO
M;FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T
M;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")&;W)T=6YA($-A<W5A
M;&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*(RP@9G5Z
M>GD*;7-G:60@(E)A=&EO(@IM<V=S='(@(E!I;V=G:6$B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G
M<W1R("),96=G:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")3:6-U<F\@9&D@=F]L97(@96QI
M;6EC87)E)7,_($PG;W!E<F%Z:6]N92!N;VX@<'5O)R!E<W-E<F4@86YN=6QL
M871A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(B(*(E-I8W5R;R!D:2!V;VQE<B!E;&EM:6YA<F4@:2!D871I(&1I
M("5S/R!,)V]P97)A>FEO;F4@;F]N('!U;R<@97-S97)E("(*(F%N;G5L;&%T
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S0*(RP@9G5Z>GD*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(E)I;75O=FD@1F]R;6%T=&%Z:6]N92(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED
M(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED
M(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")!9V=I;W)N82!L82!V
M:7-U86QI>GIA>FEO;F4@4&]R=&%L93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"B,L(&9U>GIY"FUS9VED(")2
M96=E>"(*;7-G<W1R(")!;FYU;&QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L
M;V%D(@IM<V=S='(@(DQE9V=I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B3F]T92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S
M='(@(E-E<G9E<B!296UO=&DB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.B(*;7-G<W1R(")54DP@<F5M;W1A("AH='1P.B\O=W=W
M+F5S96UP:6\N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")%;&EM:6YA(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO
M8VLB"FUS9W-T<B`B16QI;6EN82!B;&]C8V\B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4@8V]L=6UN(@IM<V=S='(@(D5L:6UI;F$@8V]L;VYN82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@
M(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E)I;75O=FD@1F]R;6%T=&%Z
M:6]N92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED
M(")296UO=F4@<&%I<B(*;7-G<W1R(")%;&EM:6YA('!A:6\B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C`R"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@HB4V%L=F$@;&$@8V]N9FEG=7)A>FEO;F4@9V5N97)A
M=&4@8V]M92!S8W)I<'0@4$A0('-U;&QA(&-A<G1E;&QA('1E;7!O<F%N96$@
M(@HB9&5L('1U;R!S97)V97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE
M(@IM<V=S='(@(D5L:6UI;F$@:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T
M:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E
M('5S97(B"FUS9W-T<B`B16QI;6EN82!U=&5N=&4B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(D5L:6UI;F$@=71E;G1E.B`E<R(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34W"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("));7!O<W-I8FEL
M92!S86QV87)E(&QA(&-O;F9I9W5R87II;VYE("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("))
M;7!O<W-I8FEL92!S86QV87)E(&QA(&-O;F9I9W5R87II;VYE("5S+B(*"B,Z
M(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<V%L=F%R92!L
M82!C;VYF:6=U<F%Z:6]N92`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*
M;7-G<W1R(")!;FYU;&QA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(D%N;G5L;&$@
M4&%S<W=O<F0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM
M<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")!;FYU;&QA(&QA
M('1U82!087-S=V]R9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*(RP@
M9G5Z>GD*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")5;'1I
M;6\@475A<G1O(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M
M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E
M<W5L=',B"FUS9W-T<B`B4FES=6QT871I(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS
M9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")4;W)N82!A;&QE($]P
M>FEO;FDN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L
M(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(D%N
M;G5L;&$@4&%S<W=O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED
M(")2975N:6]N(@IM<V=S='(@(D5S96=U:2(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B
M4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B26YV97)T:2!L82!#;VYF
M:6=U<F%Z:6]N92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G
M:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI
M($5D:71O<B!2:6-H(%1E>'0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B4FED9&QE<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I
M9"`B4FEG:'0B"FUS9W-T<B`B1&5S=')A(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*(RP@9G5Z>GD*;7-G
M:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")";'4@0VAI87)O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X
M"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I973@
M(&1E;&QA(%)?:6=A+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B4F]L92(*;7-G<W1R
M(")296=O;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T
M871E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E!R
M;W!R:65T82!D96QL82!R:6=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I
M97,B"FUS9W-T<B`B4')O<')I973@(&1E;&QA(')I9V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W
M<SHB"FUS9W-T<B`B4FEG:&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T
M<B`B4F5G;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B17-E9W5I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G<W1R("),
M96=G:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U
M"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*
M;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"B,L(&9U>GIY"FUS
M9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(DEL(&UO9'5L;R!W96%T:&5R+F-O;2!N;VX@Z"!D:7-P;VYI8FEL
M92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")3
M35,@365S<V%G:6YG(@IM<V=S='(@(DUE<W-A9V=I(%--4R(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S
M=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(E-A8B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@
M(E!I;V=G:6$@5&%R9&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0
M:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*
M;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")386UO82(*;7-G<W1R(")3
M<&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4V%N($UA<FEN
M;R(*;7-G<W1R(")-87)G:6YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O
M(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B
M:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDX"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9A(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4V%L=F$@)7,B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E("5S(@IM<V=S='(@(E-A;'9A("5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@
M(E-A;'9A($]P>FEO;FDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W
M"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*(E-A;'9A(&QA(&-O;F9I9W5R87II;VYE(&=E
M;F5R871E(&-O;64@<V-R:7!T(%!(4"!S=6QL82!C87)T96QL82!T96UP;W)A
M;F5A("(*(F1E;"!T=6\@<V5R=F5R+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E-A;'9A=&\@;&$@8V]N9FEG=7)A>FEO;F4@
M)7,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(E-A;'9A=&\@:6P@<V-R:7!T(&1I(&%G
M9VEO<FYA;65N=&\@9&5L('-E='5P(&$Z("<E<R<N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@
M(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")4+51E;7!E<W1E(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`B4FEC97)C82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(DUO=&]R92!D
M:2!R:6-E<F-A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM
M<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L97II;VYA('5N('-E<G9E<B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE
M8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B4VQE>FEO;F$@=6X@9W)U<'!O
M(&1A(&%G9VEU;F=E<F4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4V5L97II
M;VYA('5N(&YU;W9O('!R;W!R:65T87)I;R(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S
M='(@(E-E;&5Z:6]N82!U;B!S97)V97(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS
M9W-T<B`B4V5L97II;VYA('5N('5T96YT92!D82!A9V=I=6YG97)E(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")%;&EM:6YA(&-E;&QA
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E-E
M<V-E9VQI(&EL(&9O<FUA=&\@9&5L;&$@9&%T83HB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E-E;&5Z:6]N82!U;B!N=6]V
M;R!P<F]P<FEE=&%R:6\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N92(*
M;7-G<W1R(")396QE>FEO;F$@=6X@;G5O=F\@<')O<')I971A<FEO(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82XB"FUS9W-T<B`B(@HB4V5L97II;VYA(&D@8V%R871T97)I(&1I
M(&-U:2!H86D@8FES;V=N;R!D86QL92!C87-E;&QE('%U:2!S;W1T;RX@4'5O
M:2`B"B)Q=6EN9&D@8V]P:6%R;&4@92!I;F-O;&QA<FQE(&1A;&QA('1E>'1A
M<F5A+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")3
M96QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE>FEO;F$@
M:6P@9&5L:6UI=&%T;W)E(&1I(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM
M<V=S='(@(E-E<V-E9VQI(&EL(&9O<FUA=&\@9&5L;&$@9&%T83HB"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E-E;&5Z:6]N82!I
M;"!D96QI;6ET871O<F4@9&5L;"=O<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM
M<V=S='(@(E-C96=L:2!I;"!F;W)M871O(&1E;&PG;W)A.B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")396QE>FEO;F$@9'5E(&-A;7!I(&-O
M<G)I<W!O;F1E;G1I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*
M;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4V5L
M97II;VYA(&EL('1U;R!S8VAE;6$@8V]L;W)I+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93HB"FUS9W-T<B`B4V5L97II;VYA(&QA(&QI;F=U82!C:&4@<')E
M9F5R:7-C:3HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU
M.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("));G9I82!I
M;"!R97!O<G0@9&5L('!R;V)L96UA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@
M(@IM<V=S='(@(E-E;G-O<F4Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B
M4V5T=&5M8G)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0HC+"!F
M=7IZ>0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(").=6UE<F\@9&5C
M:6UA;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L
M(&9U>GIY"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")";&]C:R!N;VX@9&ES<&]N:6)I;&4N(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D
M;6EN(@IM<V=S='(@(D%M;6EN:7-T<F%Z:6]N92!D96D@4&5R;65S<VDB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G
M<W1R(")?4&5R;65S<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S$T"B,L(&9U>GIY"FUS9VED(")3970B"FUS9W-T<B`B5')A;6]N=&\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@
M(DEM<&]S=&D@:2!S97)V97(@<F5M;W1I(&%I('%U86QI('9U;VD@86-C961E
M<F4@9&%L('1U;R!P;W)T86QE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE
M>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")396QE>FEO;F$@;&$@
M;&EN9W5A('!R969E<FET82!E(&EL(&9U<V\@;W)A<FEO+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(DUO
M9&EF:6-A(&QA('1U82!A<'!L:6-A>FEO;F4@9&D@879V:6\L(&=L:2!S8VAE
M;6D@8V]L;W)E+"!E9"!A;'1R92!O<'II;VYI("(*(F1I('9I<W5A;&EZ>F%Z
M:6]N92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3
M971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L92(*;7-G<W1R(")38W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96P@<V5T
M=7`@9&ES<&]N:6)I;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(E-H;W!P
M:6YG(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G
M:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B0G)E=F4@4FEA<W-U;G1O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@
M(D1E9FEN:6%M;R!G;&D@86-C97-S:2!D82!T87-T:65R82!P97(@:2!L:6YK
M/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS
M9VED(")3:&]W(@IM<V=S='(@(DUO<W1R82(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E
M;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/R(*;7-G<W1R(")-;W-T<F$@;"=U;'1I;6\@;&]G:6X@86QL
M)V%C8V5S<V\_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM
M<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"B,L(&9U>GIY"FUS
M9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")!8W%U87IZ;VYI(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R
M871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")-;W-T<F$@=&%B96QL82!O<&5R
M87II;VYI(&YE;&QA(&)A<G)A(&1E;"!M96YU/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B36]S=')A(&EL("5S($UE
M;F\@<W5L;&$@<VEN:7-T<F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUO<W1R82!L
M92!0<F]P<FEE=.`@5&%B96QL82!#96QL82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S=')A
M(&QE(%!R;W!R:65TX"!486)E;&QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S=')A
M(&QE(%!R;W!R:65TX"!486)E;&QA(%)I9V$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*(RP@9G5Z>GD*
M;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(DUO<W1R82!L92!0<F]P<FEE=.`@5&%B96QL82(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(D%C<75A>GIO;FDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B
M4VAO=V5R<R!%87)L>2(*;7-G<W1R(")!8W%U87IZ;VYI(&$@0G)E=F4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I
M9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(D%C<75A>GIO;FD@5&%R9&DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I
M9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I
M;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S
M-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B
M4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<Q,@HC+"!F=7IZ>0IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S
M='(@(DQI=&5R871U<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R
M(")386QT82!-86YU=&5N>FEO;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4VYO=R(*;7-G<W1R(")-
M;W-T<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-0HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B4&]C
M:&D@06-Q=6%Z>F]N:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B4&]C:&D@06-Q=6%Z>F]N:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B06-Q=6%Z>F]N:2!A($)R979E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*(RP@9G5Z
M>GD*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(D%C<75A>GIO
M;FD@5&%R9&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B
M4VYO=R!D97!T:#H@(@IM<V=S='(@(E!R;V9O;F1I=&$G(&1I(&YE=F4Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@HC+"!F=7IZ>0IM<V=I
M9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4V5L97II;VYE(%1A
M9VQI82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S
M(@IM<V=S='(@(E1U;R!);F1I<FEZ>F\@16UA:6PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B16UI<V9E<F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX,34*(RP@9G5Z>GD*;7-G:60@(E-P86-E<B(*
M;7-G<W1R(")3<&%Z:6%T=7)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S
M='(@(E-P87II871U<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")3
M<&%I;B(*;7-G<W1R(")3<&%Z:6%T=7)A(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R($EN<'5T(@IM<V=S='(@(D-A<F%T=&5R92!3<&5C:6%L92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*
M;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B1&EV:61I($-E;&QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(D1I=FED:2!C;VQO;FYA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(D1I=FED:2!2:6=A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY"FUS9VED
M(")3<&]R=',B"FUS9W-T<B`B4W5P<&]R=&\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B
M4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<F0B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,#D*(RP@9G5Z>GD*;7-G:60@(E-T87)T('EE87(B"FUS9W-T
M<B`B365T96\@071T=6%L92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871O(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M
M870B"FUS9W-T<B`B1F]R;6%T;R!/<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S
M"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED
M(")3=2(*;7-G<W1R(")$;VTB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N;VX@=')O=F%T;RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"B,L
M(&9U>GIY"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E-O='1O<V-R:79I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PHC+"!F=7IZ>0IM<V=I9"`B4W5B;6ET
M(@IM<V=S='(@(E-O='1O<V-R:79I(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@
M=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@
M:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*
M;7-G<W1R("(B"B));G9I871O(&QA(')I8VAI97-T82!P97(@86=G:75N9V5R
M92`G)7,G(&%L('-I<W1E;6$N($YO;B!P=6]I(&9A<F4@=6X@;&]G:6X@(@HB
M9FEN8VAE)R!N;VX@92<@<W1A=&$@87!P<F]V871A+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C
M<FEP="(*;7-G<W1R(")3;W1T;W-C<FEV:2(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G
M<W1R(")3=6-C97-S;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB
M('1O('1H92!S>7-T96TN(@IM<V=S='(@(D%G9VEU;G1O("<E<R<@86P@<VES
M=&5M82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1&%T:2!D:2`G
M)7,G(&5L:6UI;F%T:2!D86P@<VES=&5M82XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB
M"FUS9W-T<B`B)R5S)R!E;&EM:6YA=&\@8V]N('-U8V-E<W-O+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B4FEM;W-S;R`G)7,G(&1A;"!S:7-T96UA+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N(@IM<V=S='(@(E-A;'9A=&\@;&$@8V]N9FEG=7)A>FEO;F4N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(E-A;'9A=&\@;&$@8V]N9FEG=7)A>FEO
M;F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")386QV871O(&QA
M(&-O;F9I9W5R87II;VYE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M7"(E<UPB(@IM<V=S='(@(B<E<R<@86=G:6]R;F%T;R!C;VX@<W5C8V5S<V\B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=W)O=&4@)7,B"FUS9W-T<B`B4V-R:71T;R!C;VX@<W5C8V5S<V\@)7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS
M9VED(")3=6UM87)Y(@IM<V=S='(@(E)I87-S=6YT;R(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B06QB
M82(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E
M="(*;7-G<W1R(")4<F%M;VYT;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR
M:7-E(@IM<V=S='(@(D%L8F$B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N
M<V5T(@IM<V=S='(@(D%L8F$O5')A;6]N=&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B
M06QB83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM
M<V=I9"`B4W5N<V5T(@IM<V=S='(@(E1R86UO;G1O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T
M<B`B5')A;6]N=&\Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(E-U
M<&5R<V-R:7!T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM
M<V=I9"`B4W5P<&]R="(*;7-G<W1R(")3=7!P;W)T;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(FYO;64B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ
M>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")N;VUE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L
M;V<@9&5L971E9"(*;7-G<W1R(").;VX@96QI;6EN87)E(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")4+51E;7!E<W1A(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M
M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G
M<W1R(")4+51E;7!E<W1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY
M(@IM<V=S='(@(D%C<75A>GIO;FD@82!"<F5V92(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE
M(@IM<V=S='(@(E1I=&]L;R(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP
M:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R(")4;W1A;&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R
M:65TX"!486)E;&QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4V5T(@IM<V=S
M='(@(E!R;W!R:65TX"!486)E;&QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O
M<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE=.`@5&%B96QL82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")0
M:6]G9VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B1&5S
M=&EN87II;VYE.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T
M<B`B071T:79I=.`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@=6QT:6UA(&]R83H@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E
M(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")4
M96UP97)A='5R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(E<R!N;VX@=')O=F%T;RXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V
M.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B06UM
M:6YI<W1R87II;VYE(%1E;7!L871E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"B,L(&9U
M>GIY"FUS9VED(")497AT(@IM<V=S='(@(E!R;W-S:6UO(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@
M(E-O;&\@5&5S=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@
M(D%L;&EN96%M96YT;R!T97-T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B
M5&5S=&\@:6X@86QT;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(D=I;R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@
M(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1W)A
M>FEE(&1I(&%V97(@=7-A=&\@:6P@<VES=&5M82XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@R,`HC+"!F=7IZ>0IM<V=I9"`B5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B26P@;6]D=6QO
M('=E871H97(N8V]M(&YO;B#H(&1I<W!O;FEB:6QE+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V
M-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE
M(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT
M(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M
M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*
M;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A
M<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F
M96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN
M9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I
M='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G
M:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*
M(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B3"=I9&5N=&ETX"!<(B5S7"(@92<@<W1A=&$@96QI
M;6EN871A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE
M9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"FUS9VED
M(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S
M,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M
M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP
M92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4
M:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F
M="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M26P@<V5R=F5R(%PB)7-<(B!E)R!S=&%T;R!E;&EM:6YA=&\N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@
M(DEL('-E<G9E<B!<(B5S7"(@92<@<W1A=&\@<V%L=F%T;RXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("),
M82!R:6-H:65S=&$@9&D@<F5G:7-T<F%Z:6]N92!P97(@)7,@Z"!S=&%T82!E
M;&EM:6YA=&$N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@
M9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(FEL(&9I;&4@
M4$\@9&D@2&]R9&4@<&5R(&QA(&QI;F=U82`E<R!N;VX@97-I<W1E.B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT
M('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C
M<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O
M<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S
M:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A
M+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@
M8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B26P@;6]D=6QO('=E
M871H97(N8V]M(&YO;B#H(&1I<W!O;FEB:6QE+B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;V-K
M(&YO;B!D:7-P;VYI8FEL92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N
M<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@
M=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B4VD@Z"!V97)I9FEC871O('5N('!R
M;V)L96UA(&%G9VEU;F=E;F1O("<E<R<@86P@<VES=&5M82X@)7,N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(E-I(.@@=F5R:69I
M8V%T;R!U;B!P<F]B;&5M82!R:6UU;W9E;F1O("<E<R<@9&%L('-I<W1E;6$N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")3:2#H('9E<FEF:6-A=&\@=6X@
M<')O8FQE;6$@<FEM=6]V96YD;R`G)7,G(&1A;"!S:7-T96UA+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S
M='(@(E-I(.@@=F5R:69I8V%T;R!U;B!P<F]B;&5M82!A9V=I;W)N86YD;R`G
M)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z
M,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE
M(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B
M"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D
M<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N(@IM<V=S='(@(DEL('1U;R!B<F]W<V5R(&YO;B!H82!Q=65S=&$@8V%P
M86)I;&ET82<N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A
M9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@
M(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F
M:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I
M96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@
M9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")1=65S=&\@92<@)7,N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE
M87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES
M(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@
M;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N
M($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S
M='(@(E1U;VYO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM
M<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")4:6-K970B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R(")4:71O;&\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R
M86-K:6YG(@IM<V=S='(@(D=E<W1I;VYE(&1E;"!496UP;R(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
M1F]R;6%T;R!/<F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y
M"B,L(&9U>GIY"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")396QE
M>FEO;F4@5&%G;&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`B5&ET;VQO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")4;R(*;7-G<W1R(")!;'1O
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U
M-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W
M:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B3V=G:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*
M;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B1&]M
M86YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS
M9W-T<B`B3V=G:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(D%L=&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS
M9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(E1R861O='1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I
M;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3<*;7-G:60@(E1U(@IM<V=S='(@(DUA<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0HC+"!F=7IZ
M>0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(D=R:6=I;R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A
M:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z
M>GD*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4;W1A;&4B"@HC.B!F<F%M97=O
M<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V
M.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I
M9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(E-O='1O;&EN
M96$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@
M(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,X.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(D5L:6UI;F$@<&5R;65S<VD@<&5R("<E<R<B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T
M<B`B26UP;W-S:6)I;&4@8V%N8V5L;&%R92`G)7,G.B`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A;F-E;&QA<F4@)R5S)SH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z.#,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@8V%N8V5L;&%R92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&-A;F-E;&QA<F4@)R5S)SH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A;F-E;&QA<F4@)R5S)SH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DEM
M<&]S<VEB:6QE(&-A;F-E;&QA<F4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<
M(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8V%N8V5L
M;&%R92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("));7!O<W-I8FEL92!C86YC96QL87)E("<E<R<Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M("));7!O<W-I8FEL92!C86YC96QL87)E("<E<R<Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B26UP;W-S:6)I;&4@8V%N8V5L;&%R92`G)7,G.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,SDQ"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FEL92!C86YC96QL87)E("<E<R<Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!C86YC96QL87)E
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A
M;F-E;&QA<F4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T
M:"YP:'`Z,3$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@8V%N8V5L;&%R92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("))
M;7!O<W-I8FEL92!C86YC96QL87)E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@
M9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP
M:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*
M;7-G<W1R("));7!O<W-I8FEL92!C86YC96QL87)E("<E<R<Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("))
M;7!O<W-I8FEL92!C86YC96QL87)E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(DEM<&]S
M<VEB:6QE(&-A;F-E;&QA<F4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S
M<VEB:6QE(&-A;F-E;&QA<F4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B
M4V]T=&]L:6YE82(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G
M:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")!;FYU;&QA(&QE($UO9&EF:6-H
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S
M='(@(DEN9&5F:6YI=&\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM
M<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5
M;FET<R(*;7-G<W1R(")5;FETX"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34Y"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0B"FUS9W-T<B`B16QI;6EN82!%;&5M96YT;R!#;W)R96YT92(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U
M>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(FYO;64B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@
M($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N
M;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G
M:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(D5L:6UI;F$@0V]L;W)E(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N
M<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I
M9"`B57!D871E(@IM<V=S='(@(D%G9VEO<FYA(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&4@)7,B"FUS9W-T<B`B06=G:6]R;F$@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*
M;7-G<W1R(")!9V=I;W)N82!U=&5N=&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D
M871E9"!<(B5S7"(N(@IM<V=S='(@(D%G9VEO<FYA=&\@)R5S)R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP
M="!D96QE=&5D+B(*;7-G<W1R(")38W)I<'0@9&D@86=G:6]R;F%M96YT;R!E
M;&EM:6YA=&\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5
M<&QO860B"FUS9W-T<B`B06=G:6]R;F$B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`HC
M+"!F=7IZ>0IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(").
M=6UE<B!R;VUA;FD@86QT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N
M(&YU;6)E<G,B"FUS9W-T<B`B3G5M97(@<F]M86YI(&%L=&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B
M4W1I;&4@871T=6%L92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B7U5T96YT:2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@
M(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B06UM:6YI<W1R87II;VYE
M(%5T96YT:2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q
M"B,L(&9U>GIY"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B4V%L=F$@
M3W!Z:6]N:2(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T
M<F%T:6]N(@IM<V=S='(@(E)E9VES=')A>FEO;F4@571E;G1E(@H*(SH@<VEG
M;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B27-C<FEZ:6]N92!5
M=&5N=&4@92<@<W1A=&\@9&ES86)I;&ET871O('!E<B!Q=65S=&\@<VET;RXB
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"B,L(&9U>GIY"FUS9VED
M(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B5S(&YO;B!T<F]V
M871O+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM
M<V=S='(@(DYO;64@571E;G1E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<
M(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S
M='(@(DYO;64@571E;G1E.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3F]M92!5=&5N=&4Z
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B
M57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B571E;G1I(&YE;"!S:7-T
M96UA.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R
M>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B5F%C
M86YZ92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B
M5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`HC+"!F=7IZ
M>0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B56UI9&ETX"(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM
M<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E
M;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A
M;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B:6QE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*(RP@9G5Z>GD*;7-G:60@(E9E<G-I
M;VXB"FUS9W-T<B`B4&5R;65S<VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B0V]N
M=')O;&QO(%9E<G-I;VYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB
M"FUS9W-T<B`B06QL:6YE86UE;G1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN
M9R(*;7-G<W1R(")2:65M<&EM96YT;R!697)T:6-A;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`B5F5R=&EC86QE.B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS
M9W-T<B`B36]L=&\@06QT;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@
M3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS
M9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS
M9W-T<B`B5FES=6%L:7IZ82!U;F$@<&%G:6YA('=E8B!E<W1E<FYA(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@
M(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES:6)I;&ETX"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R(")6:7-I8FEL:73@.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@
M271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM
M<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)
M3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")7
M86QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`B071T96YZ:6]N93HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")-
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@
M(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B4')E=FES:6]N92!-971E;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E
M871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3(*(RP@9G5Z>GD*;7-G:60@(E=E871H97(N
M8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B0F5N
M=F5N=71O(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B0F5N=F5N=71O(&$@)7,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B
M"FUS9W-T<B`B0F5N=F5N=71O+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")7
M97-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(D-H
M92!A<'!L:6-A>FEO;F4@)7,@9&5V92!M;W-T<F%R92!D;W!O(&EL(&QO9VEN
M/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")#;W-A
M(&4G(&-A<F%T=&5R92!D96QI;6ET871O<F4B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA
M<F%C=&5R/R(*;7-G<W1R(")#;W-A(&4G(&EL(&-A<F%T=&5R92!V:7)G;VQE
M='1E/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM
M<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E
M>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G
M<W1R("),87)G:&5Z>F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(U"B,L(&9U>GIY"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T
M<B`B56YI=.`@3&%R9VAE>GIA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R
M(")!;7!I97IZ82!D96QL82!T86)E;&QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B
M"FUS9W-T<B`B56YI=.`@3&%R9VAE>GIA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R("),87)G:&5Z>F$Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7:6YD(@IM<V=S='(@(E9E
M;G1O.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8V"B,L(&9U>GIY"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E!I;V=G
M:6$@4')E<W1O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B
M5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5F5N=&\Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN
M9#H@(@IM<V=S='(@(E9E;G1O.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DV"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES="(*
M;7-G<W1R("),:7-T82!D96D@9&5S:61E<FDB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"B,L(&9U>GIY"FUS
M9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B5'5O($EN9&ER:7IZ;R!%;6%I
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@
M(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS
M9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*
M;7-G:60@(EE965DB"FUS9W-T<B`B04$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")996%R;'DB"FUS9W-T<B`B5&]T
M86QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B665M96XB"FUS
M9W-T<B`B5F5R9&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE
M<RP@22!!9W)E92(*;7-G<W1R(")3:2P@<V]N;R!D)V%C8V]R9&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED
M(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B
M;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS
M,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-S4*(RP@9G5Z>GD*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@
M96UA:6P@861D<F5S<RXB"FUS9W-T<B`B26YD:7)I>GIO(&5M86EL(&%L=&5R
M;F%T:79O(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+B(*;7-G<W1R("),82!S97-S:6]N92#H('-T871A('1E<FUI;F%T82XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET
M<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P
M"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T
M960N(@IM<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@:6P@<V5R=F5R(&1A(&5L
M:6UI;F%R92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@
M(D1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@9&$@<FEM=6]V97)E+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B1&5V:2!S<&5C:69I
M8V%R92!L;R!U<V5R;F%M92!D82!R:6UU;W9E<F4N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM
M<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@;&\@=7-E<FYA;64@9&$@86=G:75N
M9V5R92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B1&5V
M:2!S<&5C:69I8V%R92!L;R!U<V5R;F%M92!D82!A9V=I;W)N87)E+B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+B(*;7-G<W1R(")$979I('-P96-I9FEC87)E(&QO('5S97)N86UE
M(&1A(')I;75O=F5R92XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")$979I('-P96-I
M9FEC87)E(&QO('5S97)N86UE(&1A(')I;75O=F5R92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I
M9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL
M($%D9')E<W,B"FUS9W-T<B`B5'5O($EN9&ER:7IZ;R!%;6%I;"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D
M<F5S<SHB"FUS9W-T<B`B5'5O($EN9&ER:7IZ;R!%;6%I;"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")6;W-T
M<F$@:6YF;W)M87II;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R
M("));"!T=6\@;F]M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO
M=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C
M;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A
M=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B));"!T=6\@8F%C:V5N9"!D:2!A
M=71E;G1I8V%Z:6]N92!N;VX@<W5P<&]R=&$@;&$@86=G:75N=&$@9&D@=71E
M;G1I+"!O(&QA("(*(F-A<F%T=&5R:7-T:6-A(.@@<W1A=&$@9&ES86)I;&ET
M871A('!E<B!Q=6%L8VAE(&UO=&EV;RXB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB26P@='5O(&)A8VME;F0@9&D@875T
M96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A(&QA(&5L96YC87II;VYE(&1E9VQI
M('5T96YT:2P@;R`B"B)L82!C87)A='1E<FES=&EC82#H('-T871A(&1I<V%B
M:6QI=&%T82!P97(@<75A;&-H92!M;W1I=F\N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B26P@
M='5O(&)R;W=S97(@;F]N(&AA('%U97-T82!C87!A8FEL:71A)RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I
M;G0N(@IM<V=S='(@(B(*(DEL('1U;R!B<F]W<V5R(&YO;B!S=7!P;W)T82!L
M82!V:7-U86QI>GIA>FEO;F4@:6YL:6YE(&1I('%U97-T;R!T:7!O(&1I("(*
M(FEM;6%G:6YE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I
M9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B26P@='5O(&9U
M<V\@;W)A<FEO(&%T='5A;&4Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"XB"FUS9W-T<B`B261E;G1I=.`@9&D@1&5F875L="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>3HB"FUS9W-T<B`B261E;G1I=.`@9&D@1&5F875L="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*;7-G:60@(EEO=7(@9G5L;"!N
M86UE.B(*;7-G<W1R("));"!T=6\@;F]M93HB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HQ,#`P"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M(@IM<V=S='(@(DQA('-E<W-I;VYE(.@@<W1A=&$@=&5R;6EN871A+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM
M<V=S='(@(DD@='5O:2!S97)V97(@<F5M;W1I.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B6F%I
M<F4B"FUS9W-T<B`B1VEU<W1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M
M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I
M9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@HC+"!F=7IZ>0IM<V=I9"`B
M6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM-;W-T<F$@5&5S=&\@<75O
M=&%T;R`M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0
M<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6T1O8W5M96YT;R!D:2!D97-C<FEZ
M:6]N92!D96P@<')O8FQE;6%=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB
M"FUS9W-T<B`B6TUO<W1R82!497-T;R!Q=6]T871O("TB"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X
M="`M("5S(&QI;F5S72(*;7-G<W1R(");36]S=')A(%1E<W1O('%U;W1A=&\@
M+2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B
M0V]P:6%N9&\@)7,@82`E<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%M;6EN:7-T<F%Z:6]N92(*"B,Z
M(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T
M851R964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]%
M;&EM:6YA(%)I9V$B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U
M<',B"FUS9W-T<B`B7T=R=7!P:2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E]!:75T;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M4')O<')I973@(&1E;&PG7TEM;6%G:6YE+BXN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I
M;B(*;7-G<W1R(")%;G1R82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-
M96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E]&:6YE('-E
M<W-I;VYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T
M<B`B7TUO9&EF:6-A($QI;FLN+BXZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T]P
M>FEO;FDB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N
M<R(*;7-G<W1R(")?4&5R;65S<VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@
M3&EN:RXN+B(*;7-G<W1R(")?16QI;6EN82!,:6YK+BXN(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS
M9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE=.`@
M9&5L;&$@7U1A8F5L;&$B"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5
M<V5R<R(*;7-G<W1R(")?571E;G1I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G
M<W1R(")2=6)R:6-A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS
M9VED(")C86QE;F1A<B(*;7-G<W1R(")#86QE;F1A<FEO(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")C86QM;R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E
M;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@
M(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ>0IM<V=I
M9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")?0V]N9FEG=7)A>FEO
M;F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM
M<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I
M9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N
M=')Y(&YO="!F;W5N9"(*;7-G<W1R(")N;VX@=')O=F%T;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R(")F86QL:71O
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")D
M86QL92`E<R`H)7,I(&%L;&4@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C4P"B,L(&9U>GIY"FUS9VED(")G=7-T:6YG(@IM<V=S
M='(@(BP@82`E<R`E<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F
M=7IZ>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(FQI;F5E72(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O
M=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B;&EN965=(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N
M<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D
M92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y
M,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`B
M;F]M92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@(FYO
M="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,#4*(RP@9G5Z>GD*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B8V]S=&%N=&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(G!E<F-E;G1O(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*
M;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(E!E<FUE<W-I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G
M<W1R(")A=6UE;G1A;F1O)R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,30R"B,L(&9U>GIY"FUS9VED(")S97)V:6-E('5N879A:6QA
M8FQE(@IM<V=S='(@(D)L;V-K(&YO;B!D:7-P;VYI8FEL92XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G
M<W1R(")C;W-T86YT92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@
M(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T
M96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C,P-0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FTB"FUS9W-T<B`B9&EG:71A(&QA('!A<W-W;W)D(&1U92!V;VQT
M92!P97(@8V]N9F5R;6%R92(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")U;FEF
M:65D(@IM<V=S='(@(DEN9&5F:6YI=&\B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U!A<G0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")U;FYA;65D(@IM<V=S
M='(@(FYO;64B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(E-E;&5Z:6]N92!486=L:6$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(G9#
M87)D(@IM<V=S='(@(D-I860B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]J85]*4"YP;P``````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C<W
M-S,R`#$P-#$W,S8S,#`Q`#`Q-C,W,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````C($IA<&%N97-E('1R86YS;&%T:6]N(&9O
M<B!(;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($AI<F]M:2!+:6UU<F$@/&AI
M<F]M:4!T86,N='-U:W5B82YA8RYJ<#X*(PIM<V=I9"`B(@IM<V=S='(@(B(*
M(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ+C!<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`V+3`S+3`V(#$R.C0W*S`Q,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#8M,#,M,C(@,3(Z,#`K,#DP,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N
M:G`^7&XB"B),86YG=6%G92U496%M.B!*87!A;F5S92`\=6YK;F]W;D!U;FMN
M;W=N+F1O;6%I;CY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]4TA)1E1?2DE37&XB"B)#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S8V"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@
M9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@D_J13RDB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$S.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!
M8V-E<W-K97D@)7,I(@IM<V=S='(@(H-!@TZ#6H-8@TR#0R`E<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("*!:25S()/Z@LR3X(+)@6HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<P"FUS9VED("(@*'1O9&%Y
M*2(*;7-G<W1R("(@*(VAD_HI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W,@IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B@6F6OI/Z@6HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8X"FUS9VED("(@*'EE
M<W1E<F1A>2DB"FUS9W-T<B`B("B-\)/Z*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED
M("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D
M:7)E8W1O<GDN(@IM<V=S='(@(B<E<R<@@LV#9H-"@XR#3H-G@XJ!6X+%@LV"
MH(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I
M8V4N(@IM<V=S='(@(EPB)7-<(B""S9"S@K6"HI%)D?""Q8+-@J""Z(+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW
M,3`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E
M9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B""S2!(
M;W)D92"#C(-7@UB#9X.*@LF0W9+H@K."ZH+$@J*"W(*Y@O$N(@H*(SH@9G)A
M;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E
M<UPB((-C@XJ!6Y5<CJ:+0)1<@JJ,J95T@JF"Z(+<@KF"\8%"(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S
M7"(@@JJ#3X.+@5N#=H-6@UB#98.`@LF2QXG!@K."ZH+<@K6"O8%"(@H*(SH@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E
M;2XB"FUS9W-T<B`B7"(E<UPB((*J@T&#3H-:@UB,H(-6@UB#98.`@LF2QXG!
M@K."ZH+<@K6"O2XB"@HC(&US9W-T<B`B)R5S)X*JBY:)PI#=DNB#5H-8@V6#
M@(+)DL>)P8*S@NJ"W(*U@KTN(@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB
M((+-C>R0K(*S@NJ"W(*Y@O&"Q8*U@KTZ("5S+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("*799?*("4R
M)"XR9DU"()*&@LP@)3$D+C)F34(@CF>7<"@E,R0N,F8E)2DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R""QB`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I
M;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(H-P@UB#CX%;@VB"
MS8*@@L8@)60@D_J73(SX@L6"MX%"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R
M96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(I+*DFT@+2`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM
M<V=S='(@(B5S()-DCG&.=Y;D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0P(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E
M<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N(@IM<V=S='(@(B5S()7;CN>1@(WL@LR*;91&(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S
M((+,D-V2Z"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E
M<R"#5(-#@Y.#08-B@W8B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT
M(@IM<V=S='(@(B5S().OB-./\(V`(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT,S(@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D
M>2!E>&ES=',N(@IM<V=S='(@(B5S((+-BOF"R9&VC=V"M8+<@K>!0B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O
M<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N
M(@IM<V=S='(@(B(*(B5S((+-CI^"R8YWDNB"LX+J@L2"HH+IE=N.YY&`C>R"
M\([`C7."MX+ICX"4]8*JD*Z"HH+<@K6"O8%"CL"-<X*U@KV"HI&`C>R"S"(*
M(H-[@V*#3H-8@O"#8(-&@V*#3H*U@L2"K8*^@K."HH%"(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R""JI5+EW:"Q8*W(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;6EN=71E<R(*;7-G<W1R("(E<R"5JB(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R""JH*@@NB"W(*Y@O&!0B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@@JF"YR`E<X%!
MC8>,=B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@
M(B5S((+,@T&#:(.,@UB2H"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS
M9W-T<B`B)7,@@LR77)+HE5PB"@HC(&US9W-T<B`B)7."S(-*@XR#DX-?(@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,@@LR#@8."DJ`B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S((+,@UZ#6(-.@XJ#
M6(-G(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA
M:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I
M;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S
M;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z((*Q@LR#@8-B@UJ!
M6X-7@LV.IH*S@NJ"Q(*B@NF1EY!-CM*"J8+G@LR"X(+,@L6"S8+(@J*"QHYV
M@NV"ZH+<@K>!0H*[@LR2AB(*(H+,@XJ#DX-.@O"#3H.*@V*#3H*U@KV"Z(%!
MC,*0;(_NE?&"\)&7D$V"MX+I@LR"S8]<E:J"R9*-B-."M8+$B;J"LX*B@4(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG
M("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`X
M"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C<T.`IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM()%)D?`@
M+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@
M1F]R;6%T(@IM<V=S='(@(C$RCIZ*U(Q@CJXB"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(TCIZ*
MU(Q@CJXB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B
M,C0@:&]U<G,B"FUS9W-T<B`B,C0@CIZ*U"(*"B,Z(&9R86UE=V]R:R]522]5
M22]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\D4^"
MS(-Y@5N#5R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(H*Q@LR#=8.-@V*#3H+)@LV#9H%;@UZ#>(%;@UB"JI5+EW:"
MQ8*W@4(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,0IM<V=I
M9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`BDG:6O9-)
M@LB#1X.)@5N"JI2MD+:"M8+<@K6"O2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B4$=0C/:*
M2HRN@JJ#@8-B@UJ!6X-7@LR(PXV&B;N"R95+EW:"Q8*W@4(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R(")01U",]HI*C*Z"JH^0EKR"LX+J@KV#@8-B@UJ!6X-7
M@LR,GX_8@LF52Y=V@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E!'4(SVBDJ,KH%!
M4$=0E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7
M@LR5G(V&@LF52Y=V@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(E!'4(SVBDJ,KH%!4$=0E.F6
MIXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/D):\@LF52Y=V
M@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)3+TU)346,]HI*C*Z!05,O
M34E-193IEJ>,KH*H@N:"T8-P@UB#=(.,@5N#68*JB,.-AHF[@X&#8H-:@5N#
M5X+,E9R-AH+)E4N7=H+%(@HB@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB4R]-
M24U%C/:*2HRN@4%3+TU)3464Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JH.!
M@V*#6H%;@U>"S(^0EKR"R95+EW:"Q8*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M(")3+TU)346,]HI*C*Z"JH.!@V*#6H%;@U>"S(C#C8:)NX+)E4N7=H+%@K>!
M0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*
M;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!
M32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(H*Q@LR#
M1X-F@T*#7H%;@LF"PH*B@L0B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T
M=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&
M4X-F@T*#C(-.@V>#BH+,C>R0K(+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B5D93
M@W2#0(-#@XN"S(WLD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(H-!@TJ#18.3@V>/[I7Q(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S
M='(@(H-!@TJ#18.3@V>"S(-P@UB#CX%;@V@B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U
M;G0@9G)O>F5N+B(*;7-G<W1R("*#08-*@T6#DX-G@LV3@(R+@K."ZH+$@J*"
MW(*W@4(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED
M(")!8V-O=6YT:6YG(@IM<V=S='(@(H-!@TJ#18.3@V<B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D
M9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI
M;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("*2QXG!(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#
M:&EL9"!'<F]U<"(*;7-G<W1R("*#5(-U@T^#BX%;@W:"\)+'B<$B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(H-4@W6#08-.@UJ#6(R@@O"2QXG!(@H*(R!M<V=S='(@(H-4
M@W6+EHG"@W2#B8-/@O"2QXG!(@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI
M;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(H*Q@K&"R9+'B<$Z(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*
M;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`BD%:"M8*B@T^#BX%;@W:"
M\)+'B<$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@
M4&5R;6ES<VEO;B(*;7-G<W1R("*05H*U@J*"\(-!@TZ#6H-8C*""\)+'B<$B
M"@HC(&US9W-T<B`BD%:"M8*BBY:)PH-T@XF#3X+PDL>)P2(*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B
M@U2#=8-/@XN!6X-V@O`@7"(E<UPB((+)DL>)P2(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(H-4@W6#
M08-.@UJ#6(R@@O`@7"(E<UPB((+)DL>)P2(*"B,@;7-G<W1R("*#5(-UBY:)
MPI#=DNB"\"<E<R>"R9+'B<$B"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED
M(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`BD%:+2X.&@5N#58+PDL>)P8%&
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("*7\8+PDL>)P2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N
M97<@;65M8F5R<R(*;7-G<W1R("*05HM+@X&#DX-O@O"2QXG!@48B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*
M;7-G<W1R("*#>8-!@O"2QXG!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@
M82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B)7,@@X&#:H.%@5N"\"!-;WII
M;&QA((+,@U2#0X-H@V^!6X+)DL>)P8*W@NDB"@HC(&US9W-T<B`B@TJ#C(.3
M@U^!6X+)DL>)P2(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R
M("*#08-H@XR#6)*@@LF2QXG!.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@
M8F]O:R(*;7-G<W1R("*.A(+,@LR#08-H@XR#6)*@@LF2QXG!(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(H.&@5N#
M58+PDL>)P2(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB
M)7,N(@IM<V=S='(@(B(*(H-6@UB#98.`@LD@7"(E<UPB((+PDL>)P8*U@MR"
MM8*]@JJ!08-4@T.#DX-!@V*#=H+,C^Z5\8*JDL>)P8+%@JN"W(*Y@O&"Q8*U
M(@HB@KV!1B5S(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+B(*;7-G<W1R("*#5H-8@V6#@(+)(%PB)7-<(B""\)+'B<&"M8+<
M@K6"O8+,@L6!08.-@T^#0X.3@L6"JX+<@K>!0B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(H.&@5N#58+,DL>)P8^(EYV"S9:SC/B"R8+(
M@L&"Q(*B@MR"MX%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S@*;7-G
M:60@(D%D9')E<W,B"FUS9W-T<B`BCUJ/BB(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("*#
M08-H@XR#6)*@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-38*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S(@IM<V=S='(@(HK'EYT@+2"1O(+,@X:!6X-5@LR#08-.
M@UJ#6(R@(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(HK'EYTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS
M9VED(")!9',B"FUS9W-T<B`B061S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G
M:&%N:7-T86XB"FUS9W-T<B`B@T&#=(-+@VJ#6(->@Y,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(H-!@XN#;X-J@T$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(H-!@XN#5X-&@XJ#02(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(I7*EKPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(HC*DG61M8*F
M@48B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*
M;7-G<W1R("*14Y64(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`BD5.41H_8@X:!6X-5(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM
M<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("*14X+$@LR#3X.+@5N#=B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(I%3@L2"S(-!@TZ#6H-8C*`B"@HC(&US9W-T<B`BD5."
MQ(+,BY:)PI#=DN@B"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-C@*;7-G:60@
M(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("*5H9"4@LR#08-H
M@XR#6(+PBY:)PB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(I34C8:5=(*K@XJ#6(-G@O"0W9+H@L6"JX+I@N:"I(+)@K6"W(*W@JF!
M2"(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P
M-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`BBOF"R9&VC=V"M8+<
M@K<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E
M<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("*1XY'6@LP@24U34""#C8-/@T.#
MDR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R
M;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(I'CD=:"S"!)35-0((-P@UB#
MCX%;@V@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!
M;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("*1XY'6@LP@24U34""#
MAH%;@U66O"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS
M9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("*1XY'6@LR#
M@8%;@XN#08-H@XR#6"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS
M9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(I'CD=:"S(-E@Y.#
M=H.,@5N#9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(I'CD=:#98-,@UB#9X%&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE
M<FEC86X@4V%M;V$B"FUS9W-T<B`B@T&#@8.*@TJ7S(-4@X*#02(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"XB"FUS9W-T<B`BE7.0LX+(DFR"JHYWDNB"LX+J@L2"HH+<
M@K<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED
M(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("*77(KZ
M@K6"R(*B@T>#B8%;@JJ4K9"V@K6"W(*U@KTB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!;F1O<G)A(@IM<V=S='(@(H-!@Y.#:(.)(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06YG;VQA(@IM<V=S='(@(H-!@Y.#4X.)BZ2888V1(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B@T&#DX-/@T*#B2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U
M<R!0<F]X>2(*;7-G<W1R("*3O9:\@W:#C8-,@U:!6R(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
MDYJ"IB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B
MD^R+R8%ID>67I(%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@
M0F%R8G5D82(*;7-G<W1R("*#08.3@V6#0H-/@T&!18-O@5N#=8%;@U\B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS
M-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N
M(@IM<V=S='(@(H-!@W:#BH-0@5N#5H.'@Y,B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B
M@T&#=H.*@U"!6X-6@X>#DXCJEY<B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B
M@T&#=H.*@U"!6X-6@X>#DXYGEW")PB(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS
M9W-T<B`BB;J(RH+,BZ273(+)DTN7<"(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(H^S
ME$8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`*
M;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B@JB"J(+F@KN"S(-4
M@T.#62(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("*"4XR.(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I
M9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B@T&!6X-*@T.#=8-T@T"#
M0X.+@U2#0X-9(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G
M:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("*#08%;@TJ#0X-UEKPB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H
M<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B5S((+,
M@U2#0X.3@T&#8H-VEW:+@8+PEGN3EH+)C>V/G(*U@L2"HH*B@L6"MX*I@4@B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(I9[DY:"
MR2!<(B5S7"(@@L:#5(-U@T^#BX%;@W:14X+$@O"-[8^<@K6"Q(*B@J*"Q8*W
M@JD_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(H-!
M@XN#6X.3@V"#DXNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B
M"FUS9W-T<B`B@T&#BX.!@VJ#08NDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("*#
M08.+@V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED
M(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(H-!@UJ#DX-6@X>#DY.'(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U
M"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(H-!@U>#08%>
MD;Z5O9=MDFZ(YB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G
M:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/R(*;7-G<W1R("*5VX[GC>R+QH+,CL"-<Y%/@LF*
M;91&@O"+@8+?@NF"YH*D@LF"M8+<@K>"J8%((@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S`Y,@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("*1
MMHW=@K6"R(*B@T^#BX%;@W:"\(WMCYR"M8+F@J2"QH*U@MR"M8*]@4(B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("*1
MMHW=@K6"R(*B@T&#3H-:@UB,H(+PC>V/G(*U@N:"I(+&@K6"W(*U@KV!0B(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BD;:-
MW8*U@LB"HH-!@TZ#6H-8C*""\)72CU>"M8+F@J2"QH*U@MR"M8*]@4(B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`BD;:-W8*U
M@LB"HHNDETR"\)72CU>"M8+F@J2"QH*U@MR"M8*]@4(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R
M("*1KI"K(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("*"5XR.(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(H-)@5N#6(-G@XF#BH-!(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("*#28%;@UB#9X.*
M@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@E4N7=H+(24U!
M4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K
M96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S
M='(@(D%U=&A?8WER=7,Z((-O@V*#3H-'@Y.#:(+-E4N7=H+(E%R7S8+PETR"
MM8+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B"7=HN!@K>"
MZ6EM87"*9Y*C@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?
M9G1P.B!&5%"*9Y*CBT"47(*J@MV"PH*I@NB"W(*Y@O$N(%!(4(+P("TM96YA
M8FQE+69T<""#28-V@U:#AX.3@O""PH*O@L0B"B*#4H.3@W"#0X.+@K6"R(*H
M@K6"Q(*M@KZ"LX*B@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!)34%0BF>2HXM`
ME%R"JHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!K<F(U
MBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R(")!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O<GD@@L6"S(.&@5N#
M59+'B<&"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO
M=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2""Q8+,
M@X:!6X-5C>V/G(+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\2(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VQD87`Z($Q$05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L
M9&%P.B"#AH%;@U4@)7,@@O"2QXG!@L6"JX+<@KF"\8%"@U2!6X-O@LR)GI.:
M.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z((.&@5N#52`E<R""\(WMCYR"
MQ8*K@MR"N8+Q(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B"#AH%;@U4@)7,@
M@O"-6)!6@L6"JX+<@KF"\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@
M(D%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2""Q8+,@X:!6X-5C5B05H+-
M@U2#?(%;@V>"LX+J@L2"HH+<@KF"\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!
M3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($U#
M05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?<VUB875T:#H@<VUB875T:(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED
M(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(DE-05"#5(%;@V^"Q8+,E$:/V(+)CKB4<X*U@MR"M8*]@4(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("*41H_8@LF.
MN)1S@K6"W(*U@KTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(I1&C]B"R8ZXE'."M8+<
M@K6"O8%")7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z
M,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+B(*;7-G<W1R(")2041)55.#5(%;@V^"R8+F@NB41H_8@JJ+D93;
M@K."ZH+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")&5%"#5(%;@V^"S)1&C]B"R8ZXE'."M8+<@K6"O8%"(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")3
M34*#5(%;@V^"S)1&C]B"R8ZXE'."M8+<@K6"O8%"(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB
M"FUS9W-T<B`BCF>7<(G"E%R"R(-T@T*!6X.+@VB!1B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B@T&#6X.+@V^#0X-7@X.#DXND
MF&&-D2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&
M2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B
M"FUS9W-T<B`BE'>,:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T
M<B`BE'>,:9!&(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")+97)O
M8F5R;W,@@W"#6(./@5N#:(*JEK.,^(+%@K>!0B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R
M;F%M92XB"FUS9W-T<B`B2V5R;V)E<F]S((.&@5N#59:\@JJ6LXSX@L6"MX%"
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("*#;X-N@WTB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(H-O@5N#C(%;
M@Y,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC
M("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F%N9VQA9&5S:"(*;7-G<W1R("*#;X.3@T^#B8-F@U:#A9!LEJ^+I)AAC9$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("*#;X.+@V^#
M:(-8(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(HKNEGN#3X.)@W2#0H-.@UB"S(-F@T*#C(-.@V>#
MBH%;(%PB)7-<(B""JH*@@NB"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI
M;F4B"FUS9W-T<B`BBNZ/@)#\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U
M<R(*;7-G<W1R("*#>(.)@XN!6X-6BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F5L9VEU;2(*;7-G<W1R("*#>(.+@TV!6R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R("*#>(.*@5N#62(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)E;FEN(@IM<V=S='(@(H-X@VF#DXNDF&&-D2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B@V^#?H.%@5N#7X%ICY23AX%J(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(H-U@5N#7H.3B:2-
MD2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(I)AD+:3^B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(H-U@XV#8H-.(%PB)7-<(B""S(-!@W:#
MBH-0@5N#5H.'@Y,@7"(E<UPB((*J@J""Z(+<@KF"\8%"(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG
M<R(*;7-G<W1R("*#=8.-@V*#3I#=DN@B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B@W6#
MC8-B@TZ#7H-#@W8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`BD;Z.FB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B@WN#BH-R@T&+I)AAC9$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K
M;6%R:W,B"FUS9W-T<B`B@W6#8H-.@WV!6X-.(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R
M9&5R(@IM<V=S='(@(HF/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS
M9W-T<B`BB8^"S)&^@K.!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`BB8\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V
M:6YA(@IM<V=S='(@(H-[@UB#:H-!@46#=X.+@V.#1H-3@W*#:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("*#>X-C@X^#
M:8NDF&&-D2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B@W6!6X-XDX<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B@W6#B8-7@XLB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y(@IM<V=S='(@(HEPE\R#0X.3@VB/E).'(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B@W6#BX-L@T.!18-?
M@XN#5(.)@5N#@"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S
M='(@(H-U@XN#2X.*@T$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@
M(HG3C_"/D8*K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM
M<V=S='(@(H-U@XN#3(-I@W2#0(-<(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M=6YD:2(*;7-G<W1R("*#=8.+@Y.#5XNDF&&-D2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED
M(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@IM<V=S='(@(D-23""4>I5Z@WR#0X.3@V<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?
M96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7T6#6H.+D:Z0JRXN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE
M(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(H-,@X.#8H-6@X6"
MS(^)BOJ)NX*JBJZ7N8*U@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@U"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0P
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R
M(@IM<V=S='(@(I=<DNB57"(*"B,@;7-G<W1R("*#2H.,@Y.#7X%;(@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R
M("*#2H.3@WN#5X-!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS
M9W-T<B`B@TJ#@8.+@5N#DXNDF&&-D2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("*#<(-8@X^!6X-H@LV.J9.N@L6"S8.*@UJ#8H-G@L6"JX+<@KF"\8%"
MBL>7G8[2@LF809>-@K6"Q(FZ@K."HH%"(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@
M=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B@W2#0(-#@XL@7"(E<UPB
M((+)CY&"KX+<@KF"\8%"(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS
M9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE
M<G,N(@IM<V=S='(@(HI/E92"S(-:@V*#5H.'@Y.#;H.3@VB#B8%;@LV*QY>=
M@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,B"FUS9W-T<B`B24U!4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"
MM8*].B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("*#=(-`@T.#BR!<(B5S7"(@@JJ*2H*O@MR"N8+Q@4(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B@TJ#:8-?(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B@TR#@X.3@UJ#BR(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#
M86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BC^&*497QC9""\(-,@X.#
MDX-:@XN"MX+I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B@W2#0(-#@XL@7"(E<UPB((+PC>V/G(+%@JN"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(HWLB\:#9H-"@XR#3H-G@XJ"JHRIE72"J8+H@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ
M"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N(@IM<V=S='(@(B=T87)G971&:6QE)R"#<(.)@X&!6X->@LB"
MM8+%@LV1L8US@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V
M92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("*#9H-"@XR#3H-G@XJ!6R!<
M(B5S7"(@@O"-[8^<@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("*-[8^<@L6"JX+<
M@KF"\8%"CG&1MX*J("5D()&VC=V"M8+<@K>!0B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@
M(B(*(I7`@M>1UH*F@LR1SH_;@LR0E(*JE=N1MH*S@NJ"Q(*B@NF0E(+&C8>"
M[8+(@J*"S(+%E<""UY'6@J:"JH+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS
M9W-T<B`BCG>2Z(*S@NJ"O934C8:"R8.!@V*#6H%;@U>"\)1ZD9>"Q8*K@MR"
MN8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(H-*@5N#?(-X@XN#9HNDF&&-D2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I
M;VXB"FUS9W-T<B`BE5R1Z"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("*#
M3(.#@XJ#02(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B
M0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(I6JE]Z"QH.)@WB#BR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("*#
M4(-#@WV#DX^4DX<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(HQGD=&3
M9)AB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(H-:
M@XN1KI"K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B@UJ#BY:$
MD9"!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("*#
M6H.+D:Z0JR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(H-:@XN7
M7922@48B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<Q"FUS9VED
M(")#96QL<&AO;F4B"FUS9W-T<B`BC&>1T9-DF&(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(I*&B9LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`BDH:)FX-!@W2#BH-*BZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#(*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(H_8
MEKZ/D8+,C]J-UR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("*/V):^
MCY&"S(^*ETR.TB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("*/
MV):^CY&#?(.*@U:!6R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G
M<W1R("*#8(.#@VB+I)AAC9$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED
M(")#:&%N9V4B"FUS9W-T<B`BE<^-6"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS
M9W-T<B`B@W"#6(./@5N#:(+PE<^-6"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(I-DCG&#@8-#@XN"R8YGEW""MX+I
MEKR13X+&@T&#:(.,@UB"\)7/C5B"M8+<@K>!0B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"B*,NXW=@LR0W9+H@L6"S8-P@UB#CX%;@VB"S)7/C5B"\(-4
M@WR!6X-G@K6"Q(*B@MR"N8+Q@4**QY>=CM*"R9A!EXV"M8+$B;J"LR(*(H*B
M@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I
M9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B7TN#BH.3@TZ"\(-@@T:#8H-.
M+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B@V"#BHND
MF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(I*&B=B0
M;):OBZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@
M(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R("*#
M08-V@XJ#4(%;@U:#AX.3D4F1\(%&(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`B@W"#6(./@5N#:(+PD4F1\"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM
M<V=S='(@(H.&@5N#59:\@O"129'P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*
M;7-G<W1R("*3^I5TE5R.IHQ@CJZ!1B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S
M92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S
M='(@(H-.@XJ#6(-]@UB3AR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP
M:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(H-.@XF#6)+HBV`@)7,@@JJ,J95T@JF"Z(+<@KF"\8%"(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@
M(D-L96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B
M"FUS9W-T<B`B35,M3V9F:6-E@LR#7H-/@O".YH+HCYR"K2(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@
M(HR?C?6/P8N.(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM
M<V=S='(@(H.&@5N#58+,D=Z+CH%&)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B
M@X:!6X-5C\&+CB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B@X:!6X-5@V:!
M6X->C\&+CB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED
M(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("*#3H.*@V*#3H*W@NF"QHZ?
M@M8B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M@T6#0H.3@VB#18+PE<*"MH+I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-3$*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B@U*#
M4H-8CY23AR(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*
M;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B@U2#0X-H@V^!6X+P
MC_2"WB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(H-2@XV#
MDX-R@T&+I)AAC9$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B
MD$8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M,S8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P
M,R!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#
M;VQO<B!0:6-K97(B"FUS9W-T<B`BD$:129'P(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@R-0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G
M<W1R("*01I%)D?`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`BE_&!1B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#,*;7-G:60@(D-O;'5M;B!T
M:71L97,B"FUS9W-T<B`BE_&#7H-#@V>#BR(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R("*#4H-^@V*#
M3H-8(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(V"FUS9VED(")#;VUM86YD
M(@IM<V=S='(@(H-2@WV#DX-H(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P
M"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(H-2@WV#DX-H@U:#1H.+
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(H-2@X&#DX-G(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM
M<V=S='(@(HNDDLJ6O"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM
M<V=S='(@(H-2@X*#C9A!C8<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(HGO
MCM`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U
M=&5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`BD-V2Z(+,C;>5JB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RXB"FUS9W-T<B`B4$1!@4&#6(-]@5N#9X-T@TB#DX%!3W5T;&]O:X+&@LR3
MKXKZ@O"0W9+H@K6"W(*W@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G
M<W1R("*0W9+H@LV/W):ABOJ,P)#8@NJ"Q8*W@4(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R
M92`E<R(*;7-G<W1R("(E<R""\)#=DNB"MX+I(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R
M9"(*;7-G<W1R("*#<(-8@X^!6X-H@O"*;91&(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]N9V\B"FUS9W-T<B`B@U*#DX-3BZ2888V1(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*
M;7-G<W1R("*#4H.3@U.6KX[EBZ2888V1(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960N(@IM<V=S='(@(I#:D;&.N)1S@4(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@(@IM<V=S='(@(I#:D;&.N)1S@48B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BC/:/3XRN@U2!6X-O
M@M:"S)#:D;&"JHN1E-N"LX+J@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S
M;VXZ("5S("@E<RDB"FUS9W-T<B`BC/:*2HRN@U2!6X-O@M:"S)#:D;&"JHN1
ME-N"LX+J@MR"M8*]@4*7G9=2@48E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(D944(-4@5N#;X+6@LR0VI&Q@LF.N)1S
M@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(T
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*
M;7-G<W1R("*809>-D.8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("*809>-
MD.:"S8-!@VB#C(-8DJ""R9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT
M('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`BB+./:X-T@T"#
M0X.+@LR#4H.3@V6#DX-C@UZ#0X-V@48B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<
M(B5S7"(B"FUS9W-T<B`B7"(E<UPB((+,D^"792(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`BD;&"K2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("*#3H-B@TZ/E).'(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(H-2@W.!6R(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("*#4H-S@5N.N)1S
M@48E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(I%)D?"4S8C-
M@O"#4H-S@5LB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(H-2@UB#7H.*@TJ+I)AAC9$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(H-2@5N#
M9X-7@WN#CX%;@XN+I)AAC9$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E.B`B"FUS9W-T<B`B@X&#8H-:@5N#5X+,(%!'4""(PXV&B;N"JH+%@JN"
MW(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B
M"FUS9W-T<B`B@X&#8H-:@5N#5X+,(%!'4""/D):\@JJ"Q8*K@MR"N8+Q@L6"
MM8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y
M,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM
M<V=S='(@(H.!@V*#6H%;@U>"S"!3+TU)344@B,.-AHF[@JJ"Q8*K@MR"N8+Q
M@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(H.!@V*#6H%;@U>"S"!3+TU)344@CY"6O(*J@L6"JX+<@KF"\8+%
M@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D
M9"!C;VYT86-T+B`E<R(*;7-G<W1R("*809>-D.:"\)+'B<&"Q8*K@MR"N8+Q
M@L6"M8*]@4(E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4""#5(%;@V^"R8-O@T.#DX-H
M@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("*.8XV"
M@JJ*;91&@L6"JX+<@KF"\8+%@K6"O8%")7,B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3$1!4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q
M@L6"M8*]@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(D944"""Q8-4@5N#;R!<(B5S
M7"(@@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O3H@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("*1EY!-D.:#BH-8@V>"JHWLD*R"Q8*K@MR"N8+Q@L6"
MM8*]@4(E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T
M<B`B4$=0((-F@5N#7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*].B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#
M;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B4R]-24U%
M((-F@5N#7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S
M(@IM<V=S='(@(IA!EXV0YH*JC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BD9>039#F@XJ#6(-G@JJ-[8^<
M@L6"JX+<@KF"\8+%@K6"O8%")7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`BD-V2Z(U8
MD%:7<(-8@TZ#BH-V@V<@7"(E<UPB((+PC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M(@IM<V=S='(@(H[SD$V.TH+,DV2.<8.!@5N#BX-!@VB#C(-8@JJ*;9+H@L6"
MJX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(H-!@VB#C(-8DJ""JHJN
MD5."R8+-CN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(I&7D$V0YH.*@UB#9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%@K6"
MO8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(I&7D$V0YH.*
M@UB#9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@
M(H-8@V>#B8-E@U>!6R!<(B5S7"(@@O"#C8%;@VB"Q8*K@MR"N8+Q@L6"M8*]
M@4(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T
M+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@
M7"(E<UPB+B(*;7-G<W1R(")-:V1I<B!<(B5S7"(@@LF.N)1S@K6"W(*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I
M9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BXB"FUS9W-T<B`BC/:*2HRN@O",KH-4@5N#;X*I@N>.YI.^@L6"JX+<
M@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I
M;F<N(@IM<V=S='(@(EPB)7-<(B""\(^1@JN-GH+=EW""R8-)@5N#=H.3@L6"
MJX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(E<R""\(-)@5N#=H.3@L6"JX+<
M@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`BE=N.
MYXWLB\:#@H-7@X6!6X.+("5S((+PBDJ"KX+<@KF"\8+%@K6"O8%"(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(H-F@T*#C(-.
M@V>#BH%;(%PB)7-<(B""JHI*@J^"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT
M-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3$1!4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B
M)7,@@JJ3QX+=CV^"N8+<@KF"\8%"(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S
M<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@
M=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R
M=&AE<B!H96QP+B(*;7-G<W1R("(B"B*7=HN!@K."ZH*]@X:!6X-5@LR#<(-8
M@X^!6X-H@O"#BH-:@V*#9X+%@JN"W(*Y@O&"Q8*U@KV!0H*B@JV"PH*I@J""
MZ8*B@LV14X+$(@HB@LR/[I7Q@LV*U(CA@L&"Q(*B@MR"MX%"C<23>(Z.@K6"
MQ(+=@NF"J8K'EYV.TH+)F$&7C8*U@L2)NH*S@J*!0B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<U"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!!0TPB"FUS9W-T<B`B04-,((+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KTB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("*#08-H@XR#6)*@@O".YI.^@L6"
MJX+<@KF"\8+%@K6"O8%")7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(I&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`BD9>039#F@XJ#6(-G@O".
MYI.^@L6"JX+<@KF"\8+%@K6"O8%")7,B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("*#5(%;@V^"S(M`E%R(
MZI>7@O".YI.^@L6"JX+<@KF"\8+%@K6"O2(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BD-V2Z(+PC+."R9;?@KF"W(*Y@O&"Q8*U@KV!0B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@@V:#0H.,
M@TZ#9X.*@5N"JHWMCYR"Q8*K@MR"N8+Q@4(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R"0W9+H@O"5VY&V
M@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(I#=DNB"
MS(-O@V*#3H-!@V*#=H+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S
M='(@(I#=DNB"S(-O@V*#3H-!@V*#=H+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!
M1B5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BD-V2Z(U8D%:7<(-8@TZ#BH-V@V>"
M\"!<(B5S7"(@@LF5VY&V@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB
M"FUS9W-T<B`BD-V2Z(+,@V^#8H-.@T&#8H-V@W2#0(-#@XL@)7,@@O"5VY&V
M@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*
M;7-G<W1R("(B"B*0W9+H@W2#0(-#@XL@)7,@@LF5VY&V@L6"JX+<@KF"\8+%
M@K6"O8%")7,@@LF6WX+!@L25VY&V@TF#=H-6@X>#DX+PCL"-<X*W@NDB"B*"
MJ8%!CNB"Q8*Q@LR)YI;*@LR#4H%;@VB"\"`E<R""R8-2@W.!6X*U@L2)NH*S
M@J*!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS
M9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B3$1!4""#5(%;@V^"JHR?C?6"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N
M;&EN:R!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B""\(WMCYPH=6YL:6YK*8+%
M@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BF$&7C9#F@O"-
M6)!6@L6"JX+<@KF"\8+%@K6"O8%")7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("*1EY!-D.:#BH-8@V>"\(U8D%:"Q8*K@MR"N8+Q@L6"M8*]@4(E
M<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E
M<UPB.B`E<R(*;7-G<W1R(")<(B5S7"(@@LR0W9+H@JJ/D8*KC9Z"WX+<@KF"
M\8%&)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#
M;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T
M:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R(")-;WII;&QA((+,@U2#0X-H
M@V^!6X*JC*F5=(*I@NB"W(*Y@O&!0H-4@T.#:(-O@5N"\(I*@J*"Q(FZ@K."
MHH%"(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E
M<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#$V"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O
M=6YT<GDB"FUS9W-T<B`BC9$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM
M<V=I9"`B0W)E871E(@IM<V=S='(@(HWLD*PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R
M96%T92!A(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*
M;7-G<W1R("*05HM+C>R0K"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T
M<B`B@U2#=8-T@TB#BX-?@O"-[)"L(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`BC>R0K([2@LR#08-.@UJ#6(R@(@H*(R!M<V=S='(@(HWLD*R.TH+,
ME=N,[)#=DN@B"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,#D*;7-G
M:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("*#3H.,@U>#8H-G@TJ!
M6X-HE-2-AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@
M(H-.@XV#08-@@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM
M<V=S='(@(H-,@X6!6X-OBZ2888V1(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*
M;7-G<W1R("*,NXW=@LR#6H-B@U:#AX.3(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I
M;64B"FUS9W-T<B`BC+N-W8+,CIZ*U"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N
M="!54DP@:7,B"FUS9W-T<B`BC+N-W8+,(%523"""S2(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("*,
MNXW=@LR#AH%;@U6!6R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G
M:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO
M;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N(@IM<V=S='(@(B5S((+6@LR#C8-/@TF#DXZ>@LF.P(US@K>"Z8->@UB#
M3H+PD-V2Z(*U@MR"MX%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B
MD-B"Z([F@N@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(I%)D?"4
MS8C-@O"0V(+HCN:"Z"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G
M<W1R("*#3(-V@XV#6(NDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O
M=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R
M("*#8(-&@U*+I)AAC9$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")$1"(*;7-G<W1R("*3^B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-CD*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`BEHB3^B(*"B,Z(&%D
M;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*
M;7-G<W1R(")$871A5')E92")>Y>7(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(V-PIM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(H-F
M@5N#7H-X@5N#6(Y1C\8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.34*
M;7-G:60@(D1A=&4B"FUS9W-T<B`BD_J5="(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM
M<V=S='(@(H-F@5N#7H[SD$TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-S@V"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("*3^I5TD4F1
M\"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B7TR7
M\8+,C>V/G"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("(Q,HR.(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(H]<D&F0E"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G
M:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("*2:8FZ@K""\)#S@JTB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N
M<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R("*#9H-T@TB#BX-G(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*
M;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B@V:#=(-(@XN#9Y!&(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B
M1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("*#9H-T@TB#BX-G($E$(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL
M(@IM<V=S='(@(H-F@W2#2(.+@V<@<VAE;&PB"@HC(&US9W-T<B`B@V:#=(-(
M@XN#9XN6B<*0W9+H(@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G
M:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R
M("*-[8^<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("*#
M6H.+C>V/G"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B@T^#BX%;
M@W:"\(WMCYPB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*
M;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B@XV#3X+,C>V/G"(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM
M<V=S='(@(H-!@TZ#6H-8C*""\(WMCYPB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G
M92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L
M;"(*;7-G<W1R("*#6H.+C>V/G"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU
M;6XB"FUS9W-T<B`BE_&"S(WMCYPB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M92(*;7-G<W1R("*1XY'6@V6#DX-V@XR!6X-G@LR-[8^<(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T
M92!M97-S86=E<R(*;7-G<W1R("*#@8-B@UJ!6X-7@O"-[8^<(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B
M7"(E<UPB((+,@T&#3H-:@UB,H(+PC>V/G"(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/R(*;7-G<W1R(")<(B5S7"(@@LR#08-.@UJ#6(R@@L:"NX+,@U2#=8-!
M@TZ#6H-8C*""\)%3@L2-[8^<@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E
M;&5T92!R;W<B"FUS9W-T<B`BC7."S(WMCYPB"@HC.B!T96UP;&%T97,O<')E
M9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T
M960@:61E;G1I='DB"FUS9W-T<B`BD4F1\(*U@KU)1(+PC>V/G"(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$
M96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B@U2#=8-T@TB#BX-?@O"-[8^<
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM
M<V=S='(@(HR[C=V(RI)U@LR7\8+PC>V/G"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L
M971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("*,NXW=B,J2=8+,C7."\(WM
MCYPB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`BD-V2Z(U8D%:7<(-8@TZ#BH-V@V<@7"(E<UPB((+PC>V/
MG(*U@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T
M:6UE(@IM<V=S='(@(I1ZD9>.GHK4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N
M;6%R:R(*;7-G<W1R("*#9H.3@WV!6X-.(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(H_ABE&3X)=E@LR0X):^(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3,U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(I#@
MEKXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-@IM<V=I9"`B
M1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("*/
MVHW7@6E(;W)D98+,@XV#3X-T@T"#0X.+@N".48_&@6J!1B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*/
MVHW7@LV*QY>=CM*"S(*]@M^"R8M,F%Z"LX+J@MR"M8*]@4(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*
M;7-G<W1R("**2I2M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C0*;7-G
M:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS
M9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H="(*;7-G<W1R("*-MH*I@N>)18+6(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`BB46"J8+GC;:"UB(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B
M1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(R-(Z>BM257(ZF(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/
M<'1I;VYS(@IM<V=S='(@(I5<CJ:#28-V@U:#AX.3(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D
M(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B1&ES<&QA
M>2!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@
M(H-7@W6#8(NDF&&-D2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(HWMCYR"M8+(
M@J(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@
M(FUA:6YT96YA;F-E+G!H<"""R9*\D-J#08-.@UJ#6(*U@LB"HH+%@JV"OH*S
M@J(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@
M<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H
M:7,@8F]X.B(*;7-G<W1R("*-Q8^)@LR7\8*J@W2#0H%;@XN#:):\@O"*W(+Q
M@L6"HH+<@K>"J3\@@KN"I(+(@N>#8(-&@V*#3H*U@L2"K8*^@K."HH%&(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B@VB#?H-J@THB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B@VB#?H-J@TJ+I)AAC9$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(H-!@TJ#18.3@V>"JI5+EW:"R(+G@U2#0X.3@T&#8H-V@4(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G
M:60@(D1O=VYL;V%D(@IM<V=S='(@(H-?@T6#DX.-@5N#:"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(E<R""S(-?@T6#DX.-@5N#
M:"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM
M<V=S='(@(I"VD*R"LX+J@KV0W9+H@O`@4$A0((-8@TZ#BH-V@V>"\(+&@K6"
MQ(-?@T6#DX.-@5N#:(*W@NF!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#0*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS
M9VED(")%+4UA:6PB"FUS9W-T<B`BDV2.<8.!@5N#BR(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I
M;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P
M<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5C=6%D;W(B"FUS9W-T<B`B@T>#3H-!@VB#BXNDF&&-D2(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R("*5TH]7(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I
M="!";&]C:R(*;7-G<W1R("*#=8.-@V*#3H+,E=*/5R(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET
M($=R;W5P(@IM<V=S='(@(H-/@XN!6X-V@LR5TH]7(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(H-!
M@TZ#6H-8C*""S)72CU<B"@HC(&US9W-T<B`BBY:)PI#=DNB"S)72CU<B"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B@T&#3H-:@UB,H(+,E=*/5R(*"B,@;7-G<W1R
M("*+EHG"D-V2Z(+,E=*/5R(*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R("(E<R""S(-!@TZ#6H-8C*""S)72CU<B"@HC(&US9W-T
M<B`B)7,@@LR+EHG"D-V2Z(+,E=*/5R(*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B@TF#
M=H-6@X>#DX+,E=*/5X%&(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B""S(-!@TZ#6H-8C*""S)72
MCU<B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@
M(B5S((+,@T&#3H-:@UB,H(+,E=*/5R(*"B,@;7-G<W1R("(E<R""S(N6B<*0
MW9+H@LR5TH]7(@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@
M(D5D=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP
M="(*;7-G<W1R("*#1X-7@W:#9X%%@T&#B8-UBZ2888V1(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("*#1X.+@U2#BX-O@VB#
MBXNDF&&-D2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#8V"FUS9VED(")%;6%I;"(*;7-G<W1R("*39(YQ@X&!6X.+(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(D6#@8%;@XN#08-H@XR#6"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-C`*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R(")%@X&!6X.+@T&#:(.,@UB"JHCJDG:"M8+(@J^"ZH+.@J*"KX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX-@IM<V=I
M9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B18.!@5N#BX-!
M@VB#C(-8BFV41B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,CDY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("*+\X.!@V*#6H%;@U>"Q8*W@4(B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(HF]@N",J8+"@JF"
MZ(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(HOS@LR,
MGXWUC.HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/R(*;7-G<W1R("*#38.#@XF#BH%;@JF"YXGFD9R"\)%]D_R"
MQ8*K@NF"YH*D@LF"M8+<@K>"J8%((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`BB46#3H.*@V*#3H+%@X&#:H.%@5N"\)5<CJ:"M8+<@K>"
MJ8%((@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDP"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("*#1X-F@T*#7H%;
MB>:6RH+PD>6"JX*M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM
M<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@
M=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A
M<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z
M(@IM<V=S='(@(B(*(H*@@LB"O8+,@W"#6(./@5N#:(+P@XJ#6H-B@V>"MX+I
MCIZ"S)=PD%."S(*]@M^"S(Z_EN*"\)/\E\V!0I?A@J:"SH%!@76#>8-B@V<B
M"B*"S):\D4^"S8%(@7:!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE
M(&EM86=E(%523"!H97)E(@IM<V=S='(@(HGFD9R"S%523(+PD_R7S2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G
M:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("*0U).Y
M@TV#:H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G
M<W1R("*#1X.*@V>#BH-!(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M"FUS9VED(")%<G)O<B(*;7-G<W1R("*#1X.)@5LB"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B@W6#C8-B@TZ-
M[)"L@T>#B8%;.B`E<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(I.OBOJ#C8-/@LR-[8^<@T>#B8%;
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S(@IM<V=S='(@(I/@EV6.YI.^@T>#B8%;.B`E<RXB"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(H-P@UB#CX%;
M@VB-6)!6@T>#B8%;.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92XB"FUS9W-T<B`B@X&!6X.+@T&#:(.,@UB"S(-'@XF!6X+%
M@K>!0B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B""
MS(^1@JN-GH+=@T>#B8%;@L6"MX%"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T
M;VYI82(*;7-G<W1R("*#1X-8@V>#:H-!BZ2888V1(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B@T>#8(-)@W.#02(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R
M;W!E(@IM<V=S='(@(H.(@5N#C8-B@W`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(C$U
ME:J6B"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V
M97)Y(#(@;6EN=71E<R(*;7-G<W1R("(RE:J6B"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I
M9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("(S,)6JEH@B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("(UE:J6B"(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G
M:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(H.-@T^#0X.3EH@B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B
M"FUS9W-T<B`B,S"5JI:((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`B,96JEH@B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(HYWDNB2
M;(+,E^$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#(@861M:6XO8VUD<VAE
M;&PN<&AP.C4Q(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D5X96-U
M=&4B"FUS9W-T<B`BCL"-<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B
MDU>*2B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G
M:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(H-4@T.#:(-O@5N"\)-7BDHB
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED
M(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B)RDG((+PDU>*2B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`BETR,^(KZC,`B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B
M"FUS9W-T<B`BCG>0E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@
M(I%/C&F01B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`BD-V2Z(+P($944"""Q8-!
M@V*#=H.-@5N#:(*W@NDB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR,C`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R("*#=H.,@W2#0(.,@Y.#6)#=DNB"\([FD[Z"Q8*K@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@@U2!6X-O
M@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+B(*;7-G<W1R(")334(@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"
M\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(EPB)7-<(B""J8+G@LR#4H-S@5N"R8ZXE'."M8+<@K6"
MO8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G
M<W1R(")<(B5S7"(@@M:"S(-2@W.!6X+)CKB4<X*U@MR"M8*]@4(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@
M=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(I!6BTN"
MS"!305-,()#:D;&"R8ZXE'."M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E
M<UPB+B(*;7-G<W1R(")<(B5S7"(@@M:"S(C:DZZ"R8ZXE'."M8+<@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("*.
MYI.^@LF.N)1S@K6"W(*U@KV!1B5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I
M(@IM<V=S='(@(H-T@TB!6X-.@XF#DX-HCY23AX%I@WV#BX-R@VF#6(^4DX>!
M:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B
M@W2#1H.-@5N/E).'(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM
M<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(I)VEKV328-'@XF!6X%&(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM
M<V=I9"`B1F%X(@IM<V=S='(@(D9!6"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9!6"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&
M96)R=6%R>2(*;7-G<W1R("*"48R.(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,C<*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B
M1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.30Q"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R,@IM<V=I9"`B1FEG
M;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,R-@IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("*#=(-"@U>!6X^4DX>+I)AA
MC9$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@
M(D9I;&4B"FUS9W-T<B`B@W2#0(-#@XLB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE(@IM<V=S='(@(H-T@T"#0X.+D)0Z("5S((-T@T"#0X.+(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B@W2#0(-#@XN0E#H@
M)7,@@W2#0(-#@XLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y
M"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B@W2#0(-#@XN#?8-L@5N#
M5X.#(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I
M;&4@3F%M92(*;7-G<W1R("*#=(-`@T.#BY:\(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDW-`IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T
M<B`B@W2#0(-#@XN129'P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30X,PIM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B@W2#0(-#@XN#08-B
M@W:#C8%;@V@B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,#(*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M("*#=(-`@T.#BX-!@V*#=H.-@5N#:(+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"
M\8%"(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&
M:6QT97)S(@IM<V=S='(@(H-T@T*#BX->(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M1FEN;&%N9"(*;7-G<W1R("*#=(-"@Y.#B8.3@VB+I)AAC9$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`BC^.,MX+,C(XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W
M"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(H-T
M@TB#BX-?@5L@)7,@@JJ"H(+H@MR"N8+Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*
M;7-G<W1R("*5MHZ:D$8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*
M;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("*)
MYI&<@O"#5(-\@5N#9X*U@LB"HH-U@XF#18-5EW`B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,T,0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B
M"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED
M(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B@W"#6(./@5N#:(+P
MEEF"ZH+$@K6"W(*B@MR"M8*]@JF!2"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(H-T@TB!6X.`(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B
M1F]R='5N92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O
M<G5M<R(*;7-G<W1R("*#=(-(@5N#B8.`(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I
M9"`B1G(B"FUS9W-T<B`BB^`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T
M<B`BF&<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B@W2#
MB8.3@UB+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(H-T@XF#
MDX-8@6F6>XV1@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA
M(@IM<V=S='(@(H-T@XF#DX-8E\R#38-!@VDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("*#=(.)@Y.#6)?,@WR#BH-L
M@U:#02(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E
M<G)I=&]R:65S(@IM<V=S='(@(H-T@XF#DX-8E\R+R9/LCY23AR(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@
M(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("*/VH*U@J*0
MX):^(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("*6GHR.(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("*.@9:\
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B@TN#>X.3BZ28
M88V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R("*)YI&<@O".YH+HCV^"MX--@X.#B8.*@5LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(H--@X.#B8.*@5N!1B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("*#2X.3@W*#08ND
MF&&-D2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R
M("(E<R"-7)"LC^Z5\8+PD+:0K(*W@NDB"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS
M9W-T<B`BD+:0K(*S@NJ"O8-2@5N#:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E
M;W)G:6$B"FUS9W-T<B`B@T^#BX-7@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(H-H@T.#8YA!EDV+I)AAC9$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("*#2X%;@VF+I)AAC9$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B@U>#=8.)@XN#
M7H.+(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*
M;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`BD*DB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B
M86P@3W!T:6]N<R(*;7-G<W1R("*+I)+*@TF#=H-6@X>#DR(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE((-]
M@V*#=B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O
M;V=L92!396%R8V@B"FUS9W-T<B`B1V]O9VQE((R?C?4B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y
M<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*
M;7-G<W1R("*#38.*@U:#@XNDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(H-/@XJ!6X.3
M@XF#DX-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("*#
M3X.,@VF#7R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U
M<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*#3X.+@5N#=HK'EYTB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y(@IM<V=S='(@(H-/@XN!6X-VEKR"S8OSE)*"Q8+-@LB"HH*Q
M@L8B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G
M<W1R(")'<F]U<%]L9&%P.B"#3X.+@5N#=B`E<R""\)+'B<&"Q8*K@MR"N8+Q
M@4*#5(%;@V^"S(F>DYHZ("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@
M9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@@O"-
M[8^<@L6"JX+<@KF"\2(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z((-/@XN!6X-V("5S
M((+PC5B05H+%@JN"W(*Y@O$B"@HC(&US9W-T<B`B@T^#BX%;@W:+EHG"D-V2
MZ"(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("*#3X.+@5N#=B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B@T^#08-H@XN!6X-V
MDX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("*#3X-!@X"3
MAR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B@T^#
M08-E@WV#B8NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(H-+@5N#DX-7@5N3AR(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(H-1@UB#9X-!@TZ#6H-8C*`B"@HC(&US9W-T<B`B@U&#6(-GBY:)
MPI#=DN@B"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@
M(D=U97-T8F]O:R(*;7-G<W1R("*#48-8@V>#=8-B@TXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`B@TV#:H-!BZ2888V1(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(H--@VJ#08-R
M@U2#18NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S
M='(@(H-+@T.#08-IBZ23KXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDU-PIM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP
M:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B2%144""41H_8@JJ"W8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("*#;H-#@V"+I)AAC9$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA
M<V@M06QG;W)I=&AM(@IM<V=S='(@(H-N@V*#5H.%@T&#BX-3@XJ#68.`(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G
M:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3$*;7-G:60@(DAE
M861E<B(*;7-G<W1R("*#=X-B@U\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@
M(H-W@V*#7R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N
M9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(H-N@5N#:(%%@WV#3H-H@VF#
MBX-HCY23AR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX.#4Y
M+3@M22DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(HV"@K,B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T
M<B`B@W>#BX-V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.`IM<V=I9"`B2&5L
M<&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I
M9"`B2&5M:7-P:&5R92(*;7-G<W1R("*4O(N%(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S$*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A
M9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R("*#>H%;@X`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*2(*;7-G<W1R("*#C8%;@WV60(FDDJ&!:8-O@V"#2H.3CG.-D8%J(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30X"FUS9VED(")(;VUE(@IM
M<V=S='(@(H-Z@5N#@"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(HZI
MD>Z"S(]:CXHB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@
M(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(H-Z@5N#@(-F@T*#C(-.@V>#BH%;
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("*.J9'N@LR39)ABE-2-AB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B@WJ#DX-7
M@X6#B8-8BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B
M"FUS9W-T<B`BC8&-8"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV
M-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"5<Y"S@L@@6$U,((-F
M@5N#7B`E<R""JH.!@V*#6H%;@U<@)7,@@L6,GX]O@K."ZH+<@K6"O2(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O
M(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@@TF#=8-7@T:#3H-G
M("5S((+)D<Z)GH*W@NF#@8-B@UJ!6X-7@LV"H(+H@MR"N8+Q(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z((-)@W6#5X-&@TZ#
M9XQ>("5S((+-@X&#8H-:@5N#5R`E<R""R8+-@J""Z(+<@KF"\2(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E
M<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R""S8WMCYR"LX+J@MR"M8*]
M(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS
M9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U
M:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@4$A0((IGDJ,@)V1O;7AM;"<@@JJ52Y=V@L6"MR(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E
M92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"#28-U@U>#
M1H-.@V<@)7,@@LP@6$U,((-C@XJ!6X*JC>R0K(+%@JN"W(*Y@O$B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@@JJ-[8^<@L6"JX+<@KF"
M\2!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B`E<R""S"!-24U%($E$((*JCN:3OH+%@JN"
MW(*Y@O$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E
M<R""QI.OBOJ"Q8*K@MR"N8+Q(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B"3KXKZ@L6"JX+<@KF"\8%&)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(%PB)7-<(B""S95SEKZ"R(NDETR"Q8*W(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I
M9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(I"%E;V0_"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO
M<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@
M(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(H*B@JV"PH+,E_&"\(R+C8>"M8+<@K>"J8%((@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("*#=(-"@5N#BX-H*(US
M*8+,D)2"S8*B@JV"PH+%@K>"J8%((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B@J*"K8+"
M@LR-<X+PC(N-AX*U@MR"MX*I@4@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")(
M=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("*#
M;H.3@TN#BH%;BZ2888V1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B24U!4""#@8%;@XN#>X-B@TZ#6(+,C>R0K(+)
MCKB4<X*U@MR"M8*].B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(DE-05`@@X&!6X.+@WN#8H-.@UB"S(WMCYR"
MR8ZXE'."M8+<@K6"O3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0((.!@5N#BX-[@V*#3H-8
M@TZ#2(%;@UZ"S(WLD*R"R8ZXE'."M8+<@K6"O3H@)7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S$S"FUS9VED("))4"!!9&1R97-S(@IM<V=S
M='(@(DE0((-!@VB#C(-8(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A
M<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("))4""#08-H@XR#6(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25"#
M08-H@XR#6(*JBY:)PH*S@NJ"O4-)1%*#=8.-@V*#3I/@@LF"H(+H@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T
M<B`B25"5E8V]B.&4O8+%@K>!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2
M;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E
M;&%N9"(*;7-G<W1R("*#08-#@UB#B8.3@VB+I)AAC9$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@
M(H-!@T.#4H.3@LR"W2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@
M@LR#08-#@U*#DR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G
M:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("*#08-#@U*#DX+&@V6#3(-8
M@V<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N
M=&ET>2=S(&YA;64Z(@IM<V=S='(@(DE$@LR6O)%/(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G
M:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O
M<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B@N""M8+@D+."M8*M
ME5R.IH*S@NJ"R(*B@LB"YX%!)7,@@K6"Q)!6@K6"HH-%@T.#DX-H@5N"\(I*
M@J*"Q(FZ@K."HH%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM
M<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT
M97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B
M"B*"X(*U@N`@26YT97)N970@17AP;&]R97(@@O".9X+!@L2"HH+$@4&#08-#
M@U*#DX*JE5R.IH*S@NJ"R(*B@LB"YX%!@K&"L8+PD4F1\"(*(H*U@L2)NH*S
M@J*!0B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(HGFD9R#
M=H.,@W*#A8%;(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(HGF
MD9P@55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@
M(HGFD9P@55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL
M97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S4X"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("*)
MYI&<(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B@T.#DX-\
M@5N#9X%!@UB#98-B@W8@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@
M)7,B"FUS9W-T<B`B@T.#DX-\@5N#9X*S@NJ"O8-T@T*!6X.+@VB!1B`E<R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R
M=&5D(&9I96QD<SHB"FUS9W-T<B`B@T.#DX-\@5N#9X*S@NJ"O8-T@T*!6X.+
M@VB!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S
M='(@(HK4B.&"P8*]@T&#3H-6@X>#DX-2@5N#:(*JEUZ"IH+G@NJ"Q(*B@MR"
MMX%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(H.&@5N#59:\@JF#<(-8@X^!6X-H@JJ0LX*U@JV"
MH(+H@MR"N8+Q@4(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU
M,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B*#
MAH%;@U66O(*ID>.1UH-!@VB#C(-8@JJ0LX*U@JV"H(+H@MR"N8+Q@4*-Q)-X
MCHZ"M8+$@MV"Z8*I@4&*QY>=CM*"R9A!EXV"M8+$(@HBB;J"LX*B@4(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS
M9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`BDFF)NH*P@O"06X*M(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("*#0X.3@V@B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*
M;7-G<W1R("*,PI7*@X:!6X-5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O
M;F5S:6$B"FUS9W-T<B`B@T.#DX-H@VR#5H-!BZ2888V1(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF
M;R(*;7-G<W1R("*/[I7Q(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B@T.#DX-T@TB#@8%;
M@U:#AX.3(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM
M<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R(")?3XSC@NN"R9?Q@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`BB>:1G(+PD7V3_"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!4
M86)L92(*;7-G<W1R("*57(+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN
M:R(*;7-G<W1R("*#BH.3@TZ"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R
M="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")?0Y%/@LF7\8+PD7V3_"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`BC+N-W8C*DG6"S(SC@NN"R9?Q@O"1?9/\(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`BC+N-W8C*DG6"S)%/@LF7\8+PD7V3_"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`BC+N-W8C*DG6"S(SC@NN"R8US@O"1?9/\(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`BC+N-W8C*DG6"S)%/@LF-<X+PD7V3_"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R
M96YT(&YO9&4B"FUS9W-T<B`BC+N-W8C*DG6"S(SC@NN"R9)IEXZ"\)%]D_PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D92(*;7-G<W1R("*,NXW=B,J2=8+,D4^"R9)IEXZ"\)%]
MD_PB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T
M(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("*1XY'6@V6#DX-V@XR!6X-G
M@LR1?9/\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B
M26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E
M:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(I!6@K6"HH-P@UB#CX%;
M@VB"\([S@J^.YH+I@X&!6X.+@T&#:(.,@UB"\)/\E\V!1B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G
M:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(HSC@NN"R8-:@XN"\)%]
MD_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B
MD4^"R8-:@XN"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F
M=&5R(@IM<V=S='(@(HSC@NN"R9?Q@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`BD4^"R8-:@XN"\)%]D_PB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B
M26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(H.!@V*#6H%;@U>"\)%]D_PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B
MC.."ZX+)DFF7CH+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!B969O<F4B"FUS9W-T<B`BD4^"R9)IEXZ"\)%]D_PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(HSC@NN"R8US@O"1?9/\
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BD4^"
MR8US@O"1?9/\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I
M9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y
M('%U97-T:6]N.B(*;7-G<W1R("*7<)!3@LR"O8+?@LR.OY;B@LR3FH*F@O"3
M_)?-@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(HGF
MD9R"S)%]D_R!7I7/C5@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS
M9W-T<B`B@XJ#DX-.@LR1?9/\@5Z5SXU8(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(I&7D$V0YH+)D9>"Z8*]@M^"S(YCC8*"JI5SD:N"M8+$@J*"
MW(*W@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T
M<B`BCF.-@H*JE7.1JX+%@K>!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-S(*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,`IM<V=I9"`B26YT96=E<B!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T
M<B`BE7.0LX+((%II<""#9H%;@UZ"Q8*W@4(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G
M<W1R("*5<Y"S@LB#08-V@XJ#4(%;@U:#AX.3@L6"MX%"(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#@T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M-34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,CDV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T
M960N(@IM<V=S='(@(I:SC/B"R(-F@5N#7H*JDO&/;X*S@NJ"W(*U@KTN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S
M='(@(I&7@NB0YH+,@T&#:(.,@UB"JI5SD+."Q8*W@4(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F
M:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G
M<W1R("*5<Y"S@LB#B8-#@UJ#DX-8@TR#0X+%@K>!0B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(I5SD+."R(_JCXJ"JHYWDNB"LX+J@MR"
MM8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M("*/XXC*@LR#08-.@UJ#6(R@@JJ5<Y"S@L6"MX%"(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R
M(&ED+B(*;7-G<W1R("*5<Y"S@LB#<(%;@V>#:8%;242"Q8*W@4(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED
M('!R;V1U8W0@8V]D92XB"FUS9W-T<B`BE7.0LX+(D+N5:8-2@5N#:(+%@K>!
M0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`BE7.0
MLX+(@W:#C8-G@U*#BX+%@K>!0B(*"B,@('!H<"UF;W)M870*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*;7-G:60@(DEN=F%L:60@<F5C
M:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`BE7.0LX+(CO.038[2@L6"MX%&7"(E
M<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#@P(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R
M92!O8FIE8W0B"FUS9W-T<B`BE7.0LX+(BZ273(-)@W6#5X-&@TZ#9R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`BE7.0
MLX+(E*V038RS@T&#:(.,@UB"Q8*W@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@
M=6YI8V]D92!D871A+B(*;7-G<W1R("*5<Y"S@LAU;FEC;V1E@V:!6X->@L6"
MMX%"(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B
M26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB
M"FUS9W-T<B`BD4F1\(+PE+V372(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("*#0X.)@Y.!18-#@UB#
MB8.`BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(H-#@XF#3HNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*
M;7-G<W1R("*#08-#@XN#B8.3@V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B@WV#DY.'
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*
M;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(H-#@UB#B8-'@XLB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S
M=65R(@IM<V=S='(@(I2MC7..TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(H[.
MD<PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(H-#@UZ#
MBH-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S
M='(@(H-7@X.#?8-#@THB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("*"4(R.(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("*3^I9[(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M
M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("*#5X.#@5N#5X%;DX<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("*#B(.+@U^#
MDR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q
M"FUS9VED(")*=6QY(@IM<V=S='(@(H)6C(XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R
M("*"58R.(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("*1M8*F@NDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`BDH:)FY&U
M@J8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(I>\DEN1
MM8*F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("*-MI&U
M@J8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("*)19&U
M@J8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B
M@TJ#58-T@UB#7H.3BZ2888V1(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS
M9W-T<B`B@TF#BH-7@VF#BX+PE=N1MH%((@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")+96YY82(*;7-G<W1R("*#4(-J@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S((-4
M@5N#;X*JE$:/V(N1E-N"M8+<@K6"O8%"(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!#<F5A=&EO;B(*;7-G<W1R("*,KHWLD*R3^B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT
M(@IM<V=S='(@(HRNCG>6Y"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("*,KI*W(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+
M97D@5'EP92(*;7-G<W1R("*,KH[ME]XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I
M9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("*39(YQC*Z"JH*W@L6"R8SVCT^,KH-4@5N#;X+)D;:-W8*U
M@MR"MX%"(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+
M:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB
M"FUS9W-T<B`B@TR#BH-O@UB+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(I*ID4Z6KX[ECN6+8)!LEJ^+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("*1Y8K8EJ^-D2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS
M9W-T<B`B@TZ#18-&@5N#9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ
M<W1A;B(*;7-G<W1R("*#3(.+@TV#6(NDF&&-D2(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?68.,
M@T.#08-%@V<B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS
M9VED("),86YG=6%G92(*;7-G<W1R("*,OHSJ(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS
M9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R
M("*#B8-)@UB0;):OEJ^.Y8NDF&&-D2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("*)
MNHRW@LR,CB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34X"FUS9VED("),
M87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R(*;7-G<W1R("*13XGQ@LR#C8-/@T.#DSH@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("*13XGQ@LR#C8-/@T.#DSH@)3(D
M<R""J8+G("4Q)',B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*
M;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(I%/B?&"S(.-@T^#
M0X.3.B""R(*U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T
M<B`B@XF#9X-R@T&+I)AAC9$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*
M;7-G<W1R("*4>I)U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS
M9W-T<B`B@XR#;X-M@Y.+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T
M<B`BC;8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DX"FUS9VED
M("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,#DT"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B@XR#7(-GB:2-
MD2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M3&5V96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA
M(@IM<V=S='(@(H.*@WB#BH-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(I'E@XJ#<H-!@46#
M08.)@W6.T(GOCN6+8)!LEJ^#5X.#@WV!6X-Q@XJ!6X.$(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(H.*@W&#98.3@U:#
MA8->@T.#DXSVC9$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I
M9"`B3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS
M9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q,0IM
M<V=I9"`B3&EN:R(*;7-G<W1R("*#BH.3@TXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<R"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(H.!
M@5N#BXWLD*R7<(+)@X&!6X.+@T&#:(.,@UB"R8.*@Y.#3H*W@NDB"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R
M"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM
M<V=S='(@(H-F@5N#7H-X@5N#6(CJEY<B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("*#
M=X.+@W:-@);:@O"57(ZF@K>"Z2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(I5<@LR(ZI>7(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI
M<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED
M("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED
M("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP
M"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG
M('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B@UJ#8H-6@X>#DX+,B.J7
MEXWLD*R"R8ZXE'.!1B5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*
M;7-G<W1R("*#AH%;@U6"S(CJEY>-[)"L@LF.N)1S@48E<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B@X:!6X-5@LR#BH-8@V>"S9:S
MC/B"R8+(@L&"Q(*B@MR"MX%"(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(H.*@V>#08-J@T&+I)AAC9$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W
M"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(H.-@5N#:)*&+BXN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@
M=&EM93H@(@IM<V=S='(@(HR[DFZ.GHK4@48B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("*2
M;HCF@L:.GHK4(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS
M9VED("),;V-A=&EO;B(*;7-G<W1R("*/ZH^*(@H*(SH@;&]G:6XN<&AP.C$X
M.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G
M(&EN(@IM<V=S='(@(H.-@T^#0X.3(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B@XV#3X-!@T6#9R(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T
M<B`B@XV#3X-#@Y,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS
M9VED("),;V=I;B!487-K<R(*;7-G<W1R("*#C8-/@T.#DR"#7H-8@TXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A
M:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N
M=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(H.&@5N#59:\@JF#<(-8@X^!
M6X-H@JJ0LX*U@JV"R(*B@KV"WX+)@XV#3X-#@Y."R8ZXE'."M8+<@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I
M;B!F86EL960N(@IM<V=S='(@(H.-@T^#0X.3@LF.N)1S@K6"W(*U@KV!0B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C(*;7-G:60@(DQO;F<@
M=&5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*
M;7-G:60@(DQO=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(H--
M@XJ#5H.#E;:.FH%ICZR5MHZ:@6HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(H.)@V6#DY6VCIJ!:8^LE;:.FH%J(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("*#
MC8%;@WV0E(Z:@6F/K)6VCIJ!:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X
M96UB;W5R9R(*;7-G<W1R("*#BX-.@UJ#DX-U@XN#3I'EC/:-D2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`BC(XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(I-9E72"LX+J@KT@35,M5$Y%1B""S8-F@5N#7H+PBMR"
M\8+%@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@
M(H-]@TJ#22(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(H-]@U"#:(-J
M@T&+C(.&@5N#4X-8@XF#<H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-861A9V%S8V%R(@IM<V=S='(@(H-]@U^#2X-8@TJ#BXNDF&&-D2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-
M86EL(@IM<V=S='(@(I-DCG&#@8%;@XLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R("*#?8.)@T6#0XNDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B@WV#C(%;
M@U:#02(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B
M@X*#BX-F@T*#=8NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*
M;7-G<W1R("*39(YQ@X&!6X.+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT
M82(*;7-G<W1R("*#?8.+@UZ+I)AAC9$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@
M(I!&E72"KX*S@NJ"O8.)@WB#BX+PD<Z)GH*S@KF"Q)6JE]Z"\(K'EYV"M8+<
M@K>!0B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA
M<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*
M;7-G:60@(DUA<F-H(@IM<V=S='(@(H)2C(XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G
M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(H-]@5N#5H.#@XN/E).'BZ28
M88V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@
M(H-]@XN#98-"@VJ#3I.'(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("*#=(-"@5N#
MBX-H@O"(ZI)V@K."N8+$@J*"W(*W(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-
M875R:71A;FEA(@IM<V=S='(@(H."@5N#BH->@VJ#08%%@T.#6(.)@X"+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("*#
M@H%;@XJ#5H.#@UB+I)AAC9$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R
M961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T
M<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,3,*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X('1E
M;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DU(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,30*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-@IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G
M:60@(DUA>2(*;7-G<W1R("*"5(R.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M36%Y;W1T92(*;7-G<W1R("*#?8-#@XB#8H-GDX<B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE
M;6)E<G,B"FUS9W-T<B`B@X&#DX-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("*#@8-J@X6!6X."
M@5N#:"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(H-:@XN,
MBXV'(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BEGN5MB(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B
M"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS
M9W-T<B`B@X&#8H-:@5N#5X+-C)^/V(+%@JN"W(*U@KV"JH%!CY"6O([2@LR0
M9XRS@LV,GX_8@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S
M86=E(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@
M(DUE<W-A9V4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*
M;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H
M;V0B"FUS9W-T<B`B@X&#7(-B@V@B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I
M;F5D(@IM<V=S='(@(H.!@UR#8H-H(%PB)7-<(B""S9+HBV""LX+J@L2"W(*Y
M@O$B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H
M;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP.C@R"FUS9VED(")-971R:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T
M<B`B@X&#3(-6@U*-AX]/C9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("*#?H-.@XV#;(-6
M@T&8099-(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI
M;64@5'EP92(*;7-G<W1R(")-:6UE(%1Y<&4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-
M:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S
M=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED
M(")-:7)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I
M9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R
M(")014%2((-P@V*#4(%;@U>"S"!(5%107U)E<75E<W0@@JJ,J9.6@KV"Z(+<
M@KF"\8%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B
M(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I
M;VXN(@IM<V=S='(@(B(*(I:BD-V2Z(+%@K>!0H*Q@LR#08-V@XJ#4(%;@U:#
MAX.3@O".9Y=P@K>"Z8*]@M^"R8+-D-V2Z(-T@T"#0X.+@O"-[)"L@K>"Z95+
MEW8B"B*"JH*@@NB"W(*W@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G
M92!)1"XB"FUS9W-T<B`B@X&#8H-:@5N#5R!)1"""JHRIDY:"O8+H@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"FUS9W-T<B`B4$5!4B"#<(-B@U"!6X-7@LP@36%I;"""JHRI
MDY:"O8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)
M1"XB"FUS9W-T<B`B@UJ#8H-6@X>#DR!)1"""JHRIDY:"O8+H@MR"N8+Q@4(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V
M"FUS9VED(")-;R(*;7-G<W1R("*,CB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`BC&>1T8.!
M@5N#BR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M("*/0Y"SD_HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G
M:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("*#@H.+@VB#;XNDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(H."@VF#4HSV
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(H."
M@Y.#4X.+(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,0IM<V=I
M9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R("*6B(R.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T
M(@IM<V=S='(@(H."@Y.#9X-:@XF#9Y.'(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E
M<R(*;7-G<W1R("*,CI?N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B@X*#C8-B@U*)I(V1(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO
M<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-0IM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*
M;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V
M92!$;W=N(@IM<V=S='(@(HFZ@M8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V92!,969T(@IM
M<V=S='(@(HVV@M8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("*)
M18+6(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`BC^."UB(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@
M(DUO=F4@9&]W;B(*;7-G<W1R("*)NH+6(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P(@IM<V=S
M='(@(H_C@M8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS
M9W-T<B`B@X*#58.3@W*!6X-.BZ2888V1(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$X,0IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI
M<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S.0IM<V=I9"`B
M375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B
M@T&#2H-%@Y.#9R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I
M9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("*#08-*@T6#DX-G
MC^Z5\2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#4*;7-G:60@
M(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z-#,*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(H-^@X.#DX-]
M@5N8099-(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("*3
MKXC3@K6"W(*Y@O$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B3F%M92(*;7-G<W1R("*6O)%/(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").86UI8FEA(@IM<V=S='(@(H-I@WZ#<H-!BZ2888V1(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").875R=2(*;7-G<W1R("*#:8-%@XN+I)AAC9$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(H-L@W"!6X.+B:2-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B@TF#
MB8.3@U^)I(V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N
M=&EL;&5S(@IM<V=S='(@(H-)@XF#DX-?E\R#08.3@V6#0H.+CY23AR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").
M971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS
M9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T
M:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B@VR#8H-G@X^!
M6X-.(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B@LB"M2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("*#=(.)@Y.#6)?,
M@VJ#A8%;@TJ#C(-H@VJ#02(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS
M9W-T<B`BD%:+2Y6JE]XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G
M:60@(DYE=R!-;V]N(@IM<V=S='(@(I!6C(XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P
M=&EO;F%L*2(*;7-G<W1R("*05H*U@J*#AH%;@U66O"B40XC3*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B@VJ#A8%;@U>!
M6X.)@Y.#:"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM
M<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(I!6@K6"HH-P@UB#CX%;@V@B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB
M"FUS9W-T<B`BD%:"M8*B@W"#6(./@5N#:(+-("5X((+)BOJ,P)#8@NJ"R8+(
M@NB"W(*W@4(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*
M;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(I!6
M@K6"HH-P@UB#CX%;@VB"JHCJDG:"M8+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I
M;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R("*#:H.%
M@5N#6"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@
M(DYE=W-G<F]U<',B"FUS9W-T<B`B@VJ#A8%;@UB#3X.+@5N#=B(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM
M<V=S='(@(HZ?(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").
M97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S8V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`BCI^"S(-)@W:#5H.'
M@Y,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B
M3F5X=#XB"FUS9W-T<B`BCI^"S(-Y@5N#5SXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI8V%R86=U82(*;7-G<W1R("*#:H-*@XF#3X-!BZ2888V1(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R("*#:H-7@T:!6X.+BZ28
M88V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(H-I
M@T.#5X-&@XJ#09A!EDV+I)AAC9$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B@VJ#18-'DX<B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").
M;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH
M=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@
M=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(HVWE:J"\)5<CJ:"
MMX+I@KV"WX+,D-V2Z(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3`Q"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,S@U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G
M<W1R("*5SXU8@LB"M8%"(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(H*Q@LR#08-.@UJ#6(R@@LF"S8-4
M@W6#08-.@UJ#6(R@@LV2QXG!@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-S@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,3<*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S8X"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B)7,@@LR0W9+HC^Z5\8*JCG>2Z(*S
M@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@U-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N(@IM<V=S='(@(D944"!61E,@@LR-7)"LC^Z5
M\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(E-13"!61E,@
M@LR-7)"LC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+B(*;7-G<W1R(")344P@@TJ#98-3@XJ"S(U<D*R/[I7Q@JJ.=Y+H@K."ZH+$
M@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S
M='(@(HYCC8*"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`BD9>039#F@JJ.=Y+H@K."ZH+$@J*"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR
M,`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("*#=(-`@T.#BX*J
M@T&#8H-V@XV!6X-H@K."ZH+$@J*"W(*Y@O$B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("*#
M08-#@U*#DX*J@J""Z(+<@KF"\8%"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,S`*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E
M="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(H_J
MCXJ"JHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A
M9V4@<W5P<&QI960N(@IM<V=S='(@(H.!@V*#6H%;@U>"JHYWDNB"LX+J@L2"
MHH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G
M<W1R("*6O)%/@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").
M;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("*4U(V&@JJ.=Y+H@K."ZH+$
M@J*"W(*Y@O&!0B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I
M9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")(
M5%10()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M24U!4""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DME<F)E<F]S()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K
M+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(H.-@T^#0X.3()1&C]B"
MS(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!!4U-7
M1""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E--0B"4
M1H_8@LR-7)"LC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO
M('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E
M;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N(@IM<V=S='(@(B(*(D]P96Y34TP@@W:#C8-/@XF#@(+,@W"#
M6(*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4)/<&5N4U-,((+-(%!+0U,@,3(@@LR#
M9H%;@UZ"\(BU(@HB@J2"S(+)E4N7=H+%@K>!0B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG
M;G5P<RXB"FUS9W-T<B`BE=N7KX+,@U2#0X.3@T&#8H-V@LB"M8%"(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T
M+B(*;7-G<W1R("*#3H-(@5N#7H*JD-V2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C
M:69I960N(@IM<V=S='(@(H-:@W"#C(%;@UZ"JHYWDNB"LX+J@L2"HH+<@KF"
M\8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R("**69.6@W2#0(-#@XN"R(*U(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C
M=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(H.&
M@5N#59:\@JF#<(-8@X^!6X-H@JJ1EX+G@NJ"W(*Y@O&"Q8*U@KV!0B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V
M86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("*6LXSX@LQ834R#9H%;
M@UZ"JI74@NB"W(*U@KTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(I)L@LB"
MM2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*#28.*@U>#:8.+@LR0W9+H
M@W2#0(-#@XN"R8-O@5N#5X.'@Y."JH*@@NB"W(*Y@O&!0I#=DNB"\(W$D+:0
MK(*U@MR"MX%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BD-V2Z(-T@T"#0X.+
M@LF#;X%;@U>#AX.3@JJ"H(+H@MR"N8+Q@4*0W9+H@W2#0(-#@XN"\(WL@NB2
MO(*U@L2)NH*S@J*!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B@LB"M2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO
M;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS
M9W-T<B`B@VV!6X-T@TB!6X-.DX<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(I9KE+R+A2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(I9K@WV#BH-!@VF/
ME).'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B@VV#
MBX-%@T:!6XFDC9$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(H*Q@NJ"YH+HD4\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I
M9"`B3F]T($)E9F]R92(*;7-G<W1R("*"L8+J@N:"Z(SC(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E8W1O
M<GDB"FUS9W-T<B`B@V:#0H.,@TZ#9X.*@L6"S8*@@NB"W(*Y@O$B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R("*.P)&5@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-#4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C`X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S0*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(U,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#4@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,P,0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V
M-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(V"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W-`HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3DQ(&9R86UE=V]R:R]61E,O5D93+G!H<#HV
M-CD*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(H-4@WR!6X-G@K."
MZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3@@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B@X&#@B(*"B,Z
M('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E
M<B(*;7-G<W1R("(Q,8R.(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`T,PIM<V=I9"`B3G5M8F5R(@IM<V=S='(@(I"4(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R,@IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E
M<G,B"FUS9W-T<B`BE;:.FI"4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(P"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS
M(@IM<V=S='(@(I?QD)0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30T,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T
M<B`BC7.0E"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*1EY!-
MD.:#BH-8@V>"\(U8D%:"O8+?@LR4U(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"
MO8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G
M<W1R("*#28-U@U>#1H-.@V<B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B@TF#=8-7
M@T:#3H-GC>R0K([2(@H*(R!M<V=S='(@(H-)@W6#5X-&@TZ#9XWLD*R.TH+,
MBY:)PI#=DN@B"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#$*;7-G
M:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(C$P
MC(XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N
M<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R("*#28-T@T*#6"(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L
M9"!P87-S=V]R9"(*;7-G<W1R("*,PX*B@W"#6(./@5N#:"(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("*,PX*B@W"#6(./@5N#:(*JD+."
MM8*M@J""Z(+<@KF"\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G
M<W1R("*#28-]@5N#DR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("*+I)=,@W2#2(.+@U^"S2!)34%0
M((-4@5N#;X*^@J^"JH-4@WR!6X-G@L6"JX+<@K>!0B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38X"FUS9VED(")/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(I-DCG&#@8%;@XN#
M08-H@XR#6(+-,8+"@KZ"KXYWDNB"Q8*K@MR"MX%"(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O
M<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O
M<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("*/
MBI=,CM*"J8-6@UB#98.`BL>7G8[2@KZ"KX*JBZ273(+,CXJ73(R@@L:#08-.
M@UJ#6(R@@O"5SXU8@L6"JX+<@K<B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HT,2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`BD%:+2X-%@T.#DX-H@5N"R95<CJ8B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B
M3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I
M9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33""#1X.)@5N!
M1E,O34E-12"/D):\@K."ZH*]@W"!6X-G@JF"YX-F@5N#7H+PCN:"Z(]O@KF"
MW(*Y@O&"Q8*U@KV!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B
M3W!T:6]N<R(*;7-G<W1R("*#28-V@U:#AX.3(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(B5S((-)@W:#
M5H.'@Y,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`BE-2-AI5TB=./
M\(^1@JLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(I%GD$0B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI
M<V%T:6]N86P@56YI="(*;7-G<W1R("*5E(^0(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("*0
MKI>=(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(HRS@LR#08-V@XJ#
M4(%;@U:#AX.3@V6#DX-V@XR!6X-G(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM
M<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`BD;R"S(-#@Y.#=(-(
M@X&!6X-6@X>#DR(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*
M;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(H^*ETR.TH+,@T&#
M3H-:@UB,H"(*"B,@;7-G<W1R("*/BHZ=CM*"S(N6B<*0W9+H(@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")004T@E$:/V(+-
MCF>7<(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")0
M1U`@DV2.<8^0EKPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0
M((C#C8:5MB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"",]HI*C*XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED
M(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4""/D):\
MC<\OB,.-AHF[@V:!6X->(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS
M9VED(")02%`@0V]D92(*;7-G<W1R(")02%"#4H%;@V@B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%"#
M5H-&@XLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@
M4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I
M9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%0M4W1O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*
M;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/
M4TE8((IGDJ."JHRIDY:"O8+H@MR"N8+Q(@H*(SH@;&EB+V%P:2YP:'`Z,30Y
M"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A
M9&1I;F<B"FUS9W-T<B`BEH21D"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K
M:7-T86XB"FUS9W-T<B`B@W"#3(-8@UZ#DX%%@T.#6(.)@X"+I)AAC9$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("*#<(.)@TF+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(H-P@XR#6(-@@VF.J8ZAB^8B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("*#<(-I@WV+I)AAC9$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T
M<B`B@W"#=H-!@VJ#A8%;@TV#:H-!D\:7IXV1(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B@W"#B8-/@T&#0XNDF&&-D2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,34*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM
M<V=S='(@(H-P@UB#CX%;@V@B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("*#<(-8@X^!6X-H@LV0LX_M@LF5SXU8@K."ZH+<@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS
M9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B@W"#6(./@5N#:(*J
MD+."M8*M@J""Z(+<@KF"\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E)!1$E54R"41H_8@LR#<(-8
M@X^!6X-H@JJ52Y=V@L6"MX%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`U,`IM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS
M9W-T<B`B@W"#6(./@5N#:(+,BFV41B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(H-P@UB#
MCX%;@V@Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G
M:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B@W"#6(./@5N#:#H@(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S$*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(H-P@UB#CX%;@VB"JHCJ
MDG:"M8+<@KF"\8%"(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*
M;7-G:60@(E!A<W1E(@IM<V=S='(@(I-<@NB5=(*O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@
M9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B@TZ#BH-B@W:#>X%;@VB"J8+GDUR"
MZ)5T@J\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(H-P@U@B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S
M.B(*;7-G<W1R("*5VY>ODH:"S(-4@T.#DX-!@V*#=H%&(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*
M;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B@W"!6X-:@Y.#9R(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`BE=N.YY&`
MC>R"\([`C7."MX+I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM
M<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/R(*;7-G<W1R("*#C8-/@T.#DXZ>@LF5VX[GD8"-[(+PCL"-<X*U@MR"MX*I
M@4@B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I
M9"`B4&5R;6ES<VEO;B(*;7-G<W1R("*#08-.@UJ#6(R@(@H*(R!M<V=S='(@
M(HN6B<*0W9+H(@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H
M<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D
M+B(*;7-G<W1R("*#08-.@UJ#6(R@(%PB)7-<(B""S8WMCYR"LX+J@MR"N8+Q
M@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Y,`IM
M<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B@T&#3H-:@UB"S8N1
ME-N"LX+J@MR"M8*](@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(H-!@TZ#6H-8C*`B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P
M"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("*#08-.@UJ#6(R@@LR*QY>=(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R
M("*,PI!LC^Z5\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R
M("*#>8.+@5N+I)AAC9$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*
M;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M:&EL:7!P:6YE<R(*;7-G<W1R("*#=(-"@XJ#<X.3BZ2888V1(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B
M4&AO;F4B"FUS9W-T<B`BDV288B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT.#`*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("*#<X-G@U"#08.3DX<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM
M<V=I9"`B4&EX96QS(@IM<V=S='(@(H-S@TZ#6H.+(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U-3D*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H
M(&%N9"!A('EE87(N(@IM<V=S='(@(HR.@L:43H+PD_R7S8*U@L2"K8*^@K."
MHH%"(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M8V%T96=O<GDZ(@IM<V=S='(@(I!6@K6"HI6JE]Z"S):\D4^"\)/\E\V"M8+$
MB;J"LX*B.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.3@*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,S<*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(I"S@K6"HI/ZE72"\)/\E\V"
MM8+$@JV"OH*S@J(N((R.@LR3^I"4@O"#8(-&@V*#3H*U@L2"K8*^@K."HH%"
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-`IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("*/X8I1D^"7
M98+PEW:6\8*U@L2"LHM,D_R"K8*^@K."HH%"(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V
M"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9"(*;7-G<W1R("*#AH%;@U66O(+&@W"#6(./@5N#:(+PD_R7S8*U@L2"
MK8*^@K."HH%"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS
M9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-
M55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M
M+B(*;7-G<W1R("(B"B*.GX+,E;:/D8+PD\>"\8+%@JV"OH*S@J(N((*Q@LR#
M5H-8@V6#@(+PCF>7<(*W@NF"O8+?@LR+2Y+HCI:-@(+)DZ^(TX*W@NF52Y=V
M(@HB@JJ"H(+H@MR"MX%"(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")0;VQA;F0B"FUS9W-T<B`B@WR!6X.)@Y.#:(NDF&&-D2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B
M4&]L;',B"FUS9W-T<B`BDXJ56Y"4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&]R='5G86PB"FUS9W-T<B`B@WR#BX-G@TN#BXNDF&&-D2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I
M9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I
M<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R
M969S7VQD87`Z()5+EW:"R$Q$05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM
M<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B"52Y=V@LAS97-S
M:6]NBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E
M82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B@W:#C(-R@X6!6R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(I!6@K6"HH-%@T.#DX-H@5N"R8GFD9R"\)5<CJ8B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N
M<R(*;7-G<W1R("*13X+,@TF#=H-6@X>#DR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(HCSC?PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(I3IEJ>,
MKB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G
M:60@(E!R;V)L96TB"FUS9W-T<B`BC^&*42(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R
M("*/X8I1D^"798+,D."6OB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<S"FUS9VED(")0
M<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`BC/:*
M2HRN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*
M;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(HSVCT^,KH-!
M@XN#4X.*@UF#@"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`BC/:*2HRN
MC^Z5\2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM
M<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`BC/:/3XRN+Y3IEJ>,KH*JD+:0K(+%@JN"
MW(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2
M:6-O(@IM<V=S='(@(H-V@T>#BX-G@XJ#4B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E
M<R(*;7-G<W1R("*#@8-B@UJ!6X-7@O"#<(%;@U<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")1871A<B(*;7-G<W1R("*#2H->@5N#BR(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV-`IM<V=I9"`B475E<GDB"FUS9W-T<B`B@TZ#1X.*@5LB
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM
M<V=S='(@(H-*@UZ!6X.+(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!C/:/3XRN*"5D@W*#8H-G*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C$*;7-G:60@(E)A9&EO('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B
M4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X
M"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!A;F0@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R
M='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(I3D(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T
M<B`BD\>"WB(*"B,@D\>-GB"3QX]O"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("*6>Y.6@LD@)7,@@O"-
M[8^<@K6"W(*W@JD_((*Q@LR1@(WL@LV,LX+)EM^"N8+<@KF"\8%"(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(I9[
MDY:"R8.&@5N#52`E<R""S(-F@5N#7H+PC>V/G(*U@MR"MX*I@4@@@K&"S)&`
MC>R"S8[F@NB/P8*Y@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R("*-Q8SC@LR1@(WL@O""XH+HDKR"MR(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.B(*;7-G<W1R("*3KI-)@X&#:H.%@5N"S(W$E5R.IHK4BG4Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0
M;W)T86P@5FEE=SHB"FUS9W-T<B`B@WR!6X->@XN"S(W$E5R.IB(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S(*;7-G
M:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R,C@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R
M("*#BH.-@5N#:"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED
M(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(H.*@X*!6X-G
M@U2!6X-R@U@B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R("*#BH."@5N#9U523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ("(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM
M<V=I9"`B4F5M;W9E(@IM<V=S='(@(HWMCYPB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R
M("*#=8.-@V*#3H+PC>V/G"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BCY&.KH+P
MC>V/G"(*"B,@;7-G<W1R("*.J96J@LR#2H.,@Y.#7X*I@N>-[8^<(@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A
M:7(B"FUS9W-T<B`B@WF#08+PC>V/G"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("*5VY&V@K6"O8-8
M@TZ#BH-V@V>"\(WLB\:#9H-"@XR#3H-G@XJ"J8+GC>V/G(*W@NF!0B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("*-[8^<@48B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B
M"FUS9W-T<B`B@K&"S(-M@5N#:(+P@VB#3(.%@X&#DX-G@JF"YXWMCYPB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")2
M96UO=F4@=7-E<B(*;7-G<W1R("*#AH%;@U6"\(WMCYPB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(H.&@5N#58+PC>V/G#H@)7,B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B`B"FUS9W-T<B`BEW:+@8+)E=23FH+%@JN"W(*Y@O$Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#4@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`BEW:+@8*S@NJ"O2!<(B5S7"(@@LT@)7,@@LR0W9+H@LF.=Y+H@K."
MZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-C<X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8Q"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(I=VBX&"LX+J@KT@7"(E<UPB((+-(%9&4R"0
MW9+H@LF.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("*7=HN!@K."ZH*](%PB)7-<(B""S9#=DNB"R8YWDNB"LX+J@L2"HH+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("*#BH-:@V*#9R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E
M="!087-S=V]R9"(*;7-G<W1R("*#<(-8@X^!6X-H@O"#BH-:@V*#9R(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(H*@@LB"O8+,@W"#6(./@5N#:(+P@XJ#
M6H-B@V<B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,Q"FUS9VED(")297-T
M;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C<R(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C<*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`BC(N)RB(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B@TF#
M=H-6@X>#DX+)EM^"Z2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("*#<(-8
M@X^!6X-H@O"-Q)/\E\TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`BC+."S(U<D*R"R9;?@K<B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,B"FUS9W-T<B`B@V6#3(-8@V>#1X-F@T*#7H%;@LR#28-V@U:#AX.3(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`BB44B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`P"FUS9VED(")2:6=H="!H96%D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y
M-@IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I
M9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B
M"FUS9W-T<B`BEO"*A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B
M"FUS9W-T<B`B@XN!6X-]@VJ#02(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T
M<B`B,3@PDWB)\9-=(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`BC;:"
MR8GQDUTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`BB46"R8GQDUTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("*-<Y&ND*LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("*-<Y&ND*LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`BC7.!1B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U
M;&5S(@IM<V=S='(@(HQRD/PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(I%3
M@L2"S(US@L:7\8+,BM2"R8QRD/R"\(CX@JTB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("*-
M<X+,BM2"R8QRD/R"\(CX@JTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("*7\8+,BM2"R8QRD/R"
M\(CX@JTB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED(")2=6XB
M"FUS9W-T<B`BCL"-<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@
M1F5D97)A=&EO;B(*;7-G<W1R("*#C8-6@T&8099-(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(H.+@X^#DX-?(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@B,.-AH^0
MEKPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM
M<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E,O34E-
M12"(PXV&E;8B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q
M"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(E-!4TP@E$:/V(+-CF>7<(+%@JN"W(*Y@O&!0B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I
M;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B4U%,((-6@T:#BR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R-S$*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R
M('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BD*R,]R(*"B,Z
M(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q
M"FUS9VED(")382(*;7-G<W1R("*3>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-A:6YT($AE;&5N82(*;7-G<W1R("*#6H.3@V>#=X.,@VF3AR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@
M(H-:@Y.#9X-,@V*#8X&5@VR!6X.4@T*#6"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B@UJ#DX-G@XN#5H-!(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G
M<W1R("*#5(.3@W.#1X%;@XN!18-^@TZ#C8.3DX<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G
M<W1R("*#6H.3@V>#<X.3@UJ#DX-G@JB"YH+1@T^#C(-I@V:#0H%;@Y./E).'
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(H-4@X*#09/&EZ>-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B@U2#
MDX-]@XJ#;8NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE
M(&%N9"!0<FEN8VEP92(*;7-G<W1R("*#5(.3@V>#@8%%@W:#BH.3@U:#>9:O
MCN6+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(H-4@T6#5X-!
M@XF#<H-!B:2-D2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY
M.0IM<V=I9"`B4V%V92(*;7-G<W1R("*5VY&V(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@@O"5VY&V(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V92`E<R(*;7-G<W1R("(E<R""\)7;D;8B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B@TF#
M=H-6@X>#DX+PE=N1MB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*
M;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!0
M2%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@HBD+:0K(*S@NJ"O9#=DNB"\"!02%`@@UB#3H.*
M@W:#9X+&@K6"Q(-4@5N#;X+,C>R+QH-F@T*#C(-.@V>#BH+)E=N1MH*W@NF!
M0B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B5S
M()#=DNB"\)7;D;:"M8+<@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BD-V2Z(U8D%:7<(-8
M@TZ#BH-V@V<@7"(E<UPB((+PE=N1MH*U@MR"M8*]@4(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E
M<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(HR?C?4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@
M16YG:6YE<R(*;7-G<W1R("*,GXWU@T>#DX-7@Y,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.34R"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T
M<B`B@W2#0(-#@XN"\)%)D?`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S
M='(@(I/ZE72"\(YWDNB"M8+$@JV"OH*S@J*!1B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A
M9&0B"FUS9W-T<B`BDL>)P8*W@NF#3X.+@5N#=H+PD4F1\(*U@L2"K8*^@K."
MHB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E
M;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("*05H*U@J*/BHZ=CM*"\)%)D?""
MM8+$@JV"OH*S@J(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("*#5(%;@V^"\)%)
MD?""M8+$@JV"OH*S@J(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`BDL>)
MP8*W@NF#AH%;@U6"\)%)D?""M8+$@JV"OH*S@J(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@
M86QL(@IM<V=S='(@(I%3@L2129'P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8T,`IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M-PIM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB
M"FUS9W-T<B`B(@HBE4N7=H+(E;:.FH+PB;J"S(-[@V*#3H-8@JF"YY%)@O&"
MQ8-2@W.!6X*W@NF"QH%!@V6#3(-8@V>#1X.*@T&"UH-Y@5N#6(-G@L6"JR(*
M(H+<@K>!0B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("*3^I5T@LR+
MYI#8@NB5MHZ:@O".=Y+H@K6"Q(*M@KZ"LX*B@48B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA
M=#HB"FUS9W-T<B`BD_J5=(+,C&".KH+PCG>2Z(*U@L2"K8*^@K."HH%&(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I
M9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM
M<V=S='(@(I7/C5B"M8*]@J))1(+PD4F1\#HB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E
M<CHB"FUS9W-T<B`BCIZ-CX+,B^:0V(+HE;:.FH+PCG>2Z(*U@L2"K8*^@K."
MHH%&(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(HZ>C8^"S(Q@CJZ"\(YW
MDNB"M8+$@JV"OH*S@J*!1B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G
M<W1R("*(ZI)V@K>"Z8)1@L*"S(-T@T*!6X.+@VB"\)%)@O&"Q8*M@KZ"LX*B
M@4(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE
M8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(I!&DK*"\)%)D?""M8+$
M@JV"OH*S@J(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I
M9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("*,
MOHSJ@O"129'P@K6"Q(*M@KZ"LX*B.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(H_ABE&#C(-\@5N#9X+PD9>038*W@NDB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`B4TU3()&7D$TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M96YE9V%L(@IM<V=S='(@(H-:@VR#2X.+BZ2888V1(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,C,*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED
M(")397!T96UB97(B"FUS9W-T<B`B@EB,CB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E
M;F5G<F\B"FUS9W-T<B`B@UJ#BX-R@T&!18."@Y.#98-L@T^#C2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(I+*E-0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B@UJ#8H-6@X>#
MDXK'EYTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G
M<W1R("*#6H-B@U:#AX.3(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Q,0IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*
M;7-G<W1R("*668+J@L2"M8+<@L&"O8-P@UB#CX%;@VB"\(.*@UJ#8H-G@L6"
MJX+I@N:"I(+)@K6"W(*W@4(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B@WR!6X->
M@XN"Q8-!@TZ#6H-8@K>"Z8.*@X*!6X-G@U2!6X-O@O"0W9+H@K6"W(*W@4(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`BC+Z,ZH%!CIZ*U)'1@4&3^I5T@O"0W9+H@K6"W(*W@4(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@
M>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@
M<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS
M9W-T<B`B(@HBBDJ.;HZ>@LR#08-V@XJ#4(%;@U:#AX.3@4&01I*R@4&#>8%;
M@U>-Q)5<CJ:!08*[@LR1O(+,E5R.IH-)@W:#5H.'@Y."\)%)D?""M2(*(H+$
M@JV"OH*S@J(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I
M9"`B4V5T=7`B"FUS9W-T<B`BD-V2Z"(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE(@IM<V=S='(@(I#=DNB-6)!6@UB#3H.*@W:#9R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R
M86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS
M9W-T<B`B@UJ!6X-6@T:#BXNDF&&-D2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3
M=6UM87)Y(@IM<V=S='(@(HK(DE""R)=VEO&!1B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("*!:8.!@VJ#A8%;@LB"
MQX+%@6J#5H.'@5N#9X-*@V*#9X-,@5N"JHYG@J:"Z8+F@J2"R8*U@MR"MX*I
M@4@B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM
M<V=I9"`B4VAO=R(*;7-G<W1R("*57(ZF(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*,NXW=@LR0W9+H@L:05H*U@JV0MI"L
M@K."ZH*]D-V2Z(+&@LR-MY6J@O"57(ZF@K>"Z8%"(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("*#C8-/@T.#DXZ>@LF13XGQ@LR#
MC8-/@T.#DXZ>BM2"\)5<CJ:"M8+<@K>"J8%((@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<V,@IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-SDR"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(I5<D8"-[(.!@VJ#A8%;@O"57(ZF
M@K6"W(*W@JF!2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\B"FUS9W-T<B`BB>:6RHVV@LD@)7,@@X&#:H.%@5N"\)5<CJ:"M8+<@K>"
MJ8%((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(I5<@LR#6H.+D:Z0JX-?@T.#08.-@T^"
M\)5<CJ8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(I5<D:Z0JX-?@T.#08.-@T^"\)5<CJ8B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("*57(+,E_&1KI"K@U^#0X-!@XV#3X+PE5R.IB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`BE5R"S(USD:Z0JX-?@T.#08.-@T^"\)5<CJ8B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8P"FUS9VED(")3:&]W('5P;&]A9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R
M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U
M"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q
M.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(H]KCZPB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB
M;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@
M(H+<@KB7UX+H@LR#=8.-@V*#3H+PCVN/K(+<@KV"S8C:DZZ"LX*Y@L2"K8*^
M@K."HH%"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM
M<V=S='(@(H-6@T>#B8.,@TF#;(NDF&&-D2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
M@U2#0X.3@T&#8H-V(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("*39(YQCY"6O"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED
M(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(I-DCG&/D):\@T&#BX-3
M@XJ#68.`(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S
M='(@(H-6@Y.#2X-\@5N#BXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,S0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,#(*;7-G:60@(E-I>F4B"FUS9W-T<B`B@U2#0X-9(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G
M:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`BE=N.YX+P@UB#3(-B@W:"
MMX+I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B
M@UB#C8-O@TR#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E
M;FEA(@IM<V=S='(@(H-8@XV#>(-J@T&+I)AAC9$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-PIM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8P"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO=R!D97!T:#H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED
M(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B@UR#
MC8."@Y./E).'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G
M<W1R("*#7(-]@XJ#09:OCN6+I)AAC9$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDP-0IM<V=I9"`B4V]R="!O<F1E
M<B!S96QE8W1I;VXB"FUS9W-T<B`BE<""T8^'@LR129'P(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V
M-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM
M<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`BD9>038RS@T&#:(.,@U@B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B
MD^R#08-T@XJ#2HNDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS
M"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("*3[(-7@X>!6X-7@T&3
MAX%%D^R#5(.3@VB#0X-B@V"/E).'(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R("*3[)2\BX4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("*7UX+,@UJ#BX+&@LR77922(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*
M;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&PB"FUS9W-T<B`B@UJ#BX+&BZN*18+&@LR77922(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#$R"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(I==E)(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED
M(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(I==E)*"QI:$D9`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B@UB#>8-#@Y,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B
M4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`BD\&.ZI6VCIJ"S)/\
ME\TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(H-:@XN5JHJ$
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(I?QE:J*A"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("*-<Y6JBH0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("*#
M6(.*@XF#DX-*EJ^.Y8[0B>^.Y8M@BZ2888V1(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z.#$*;7-G
M:60@(E-T86YD87)D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#,@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C<X.`IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@
M;W(@4')O=FEN8V4B"FUS9W-T<B`BCT*"W(*]@LV,IR(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`BC_.1U"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.30*
M;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D
M<F5S<R(*;7-G<W1R("*/6H^*E-22;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B
M"FUS9W-T<B`BCN:/P8*UD/PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,P"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<P"FUS9VED(")3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL
M92!;0U-372(*;7-G<W1R("*#6(->@T.#BR!;0U-372(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM
M<V=S='(@(I/Z(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("*#5(-U@V:#0H.,@TZ#9X.*(%PB)7-<(B""JH*@@NB"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(Y(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(H[`C7,B"@HC.B!S
M:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B
MB;J5=(*K(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-0HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(I"LC/<B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B""S8-6@UB#98.`@LF2QXG!@K."ZH+<@K6"O8%"(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B7"(E<UPB((*J@U:#6(-E@X""J8+GC>V/G(*S@NJ"W(*U@KV!
M0B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L
M971E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B""JHWMCYR"LX+J@MR"M8*]
M@4(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B7"(E<UPB((*J@U:#6(-E@X""J8+GC>V/G(*S@NJ"W(*U
M@KV!0B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N(@IM<V=S='(@(I#=DNB"S9"SC^V"R9;?@K."ZH+<@K6"
MO8%"@XJ#C8%;@VB"M8+$BFV41H+%@JN"W(*W@4(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BD-V2Z(+,@V^#8H-.@T&#8H-V@LV0LX_M@LF5VY&V@K."ZH+<
M@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(I#=DNB#=(-`@T.#BX+,
M@V^#8H-.@T&#8H-V("5S((+-D+./[8+)E=N1MH*S@NJ"W(*U@KV!0B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB((+-D+./
M[8+)C5B05H*S@NJ"W(*U@KTB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@@LV0LX_M
M@LF/D8*KC9Z"W(+J@MR"M8*](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D
M86XB"FUS9W-T<B`B@UB!6X-?@Y.+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM
M87)Y(@IM<V=S='(@(HI4EW8B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(I/Z@LR/;R(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("*3
M^H+,D_R"Z"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`BD_J"
MS(]O+Y/Z@LR3_(+H(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(I/Z@LR/;X%&(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T
M(@IM<V=S='(@(I/ZEG8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R("*3^I9V@48B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED
M(")3=7!E<G-C<FEP="(*;7-G<W1R("*/XY5T@JLB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(H-4
M@WR!6X-G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T
M<B`B@UB#BH-I@X"+I)AAC9$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("*0J2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B@UB#E(-`@5N#BX-O@XN!08.$@Y.#?8-#@T>#DX^4DX<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B@UB#CX-7@XF#
MDX-HB:2-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R
M("*#6(-%@T:!6X-F@Y.)I(V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z
M97)L86YD(@IM<V=S='(@(H-8@T.#6)A!EDTB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3
M>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B
M(%)E<'5B;&EC(@IM<V=S='(@(H-6@XJ#08%%@T&#B8-UBZ2888V1(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@
M(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8T"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R
M;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6@W2#0(-#
M@XLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(I5<
MD:Z0JR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED
M(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(I5<D:Z0JR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R("*1Y)AP(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`BD>28<(%IDH:-D8+,
MB.J5E(%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G
M<W1R("*#7H-7@TR#6(->@Y.+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED
M(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(H->@Y.#
M58-J@T&8099-BZ2888V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`T.0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y
M"FUS9VED(")487-K<R(*;7-G<W1R("*#7H-8@TXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU
M;6)E<B(*;7-G<W1R("*39)ABE-2-AB(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B@V6#DX-V@XR!6X-G(%PB)7-<(B""JH*@@NB"
MW(*Y@O&!0B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")4
M96UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*#98.3@W:#C(%;@V>"
MS(K'EYTB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C0*;7-G:60@(E1E>'0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/
M;FQY(@IM<V=S='(@(H-E@TR#6(-G@LR"W2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@
M86QI9VXB"FUS9W-T<B`BE;:.FI1ZDG4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S
M='(@(I6VCIJ"S(_C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`BEM@B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T
M<B`B@UZ#0XFDC9$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U
M,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B1E10((IGDJ."JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S
M>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(I>:E_"#5H-8@V6#@(+-EK.,
M^(+)@LB"P8+$@J*"W(*W@4(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP
M.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA
M;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")-86EN=&5N86YC92"#3H.)@UB"
MS)/'C9Z"W8*JD+./[8+)C7."IH+<@KF"\8+%@K6"O2(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("*#28-V@U:#
MAX.3@T6#0H.3@VB#18+PE<*"MH+<@K6"O8%"CTF7N8*U@MR"MX%"(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N
M<RXB"FUS9W-T<B`B(@HB@T&#3H-:@UB,H(+PETR,^(+)@K>"Z8+)@LV*QY>=
MCM*"JH*[@LR#;X-B@TZ#1X.3@VB"\)#=DNB"MX+I@K&"QH*JE4N7=H+%@K>!
M0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T
M:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(IA!EXV0YDE$E-2-AH*JCG>2
MZ(*S@NJ"R(*I@L&"O8*I@4&+\X*^@L&"O8*I@4&"H(+I@J*"S8-F@5N#7H-X
M@5N#6)*&@LF,J95T@JDB"B*"Z(+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R("*809>-D.:"S8*@@LB"O8+,@T&#:(.,@UB2H(+)
MDL>)P8*S@NJ"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(I-DCG&/D):\@K."ZH*]@X&#8H-:@5N#5X+PC)^/
MV(*W@NF"R8+-@4%01U`@CY"6O(*JE4N7=H+%@K>!0B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(B(*(I&7D$V0YDE$E-2-AH*JCG>2Z(*S@NJ"R(*I
M@L&"O8*I@4&+\X*^@L&"O8*I@4&"H(+I@J*"S8-F@5N#7H-X@5N#6)*&@LF,
MJ95T@JDB"B*"Z(+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T
M<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`BD9>0
M39#F2424U(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N
M(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(HC#C8:)NX+)@LV(P)%3@LB#18-&@W60VI&Q@JJ52Y=V@L6"MX%"
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#8@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R
M("*#=(-`@T.#BR`E<R""R8+-("5S((+,D-V2Z(*JE4N0>X+%@K>!0B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@
M(H-T@T"#0X.+("5S((+)@LT@)7,@@LR0W9+H@JJ52Y![@L6"MX%"(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL
M92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("*#=(-`
M@T.#BX+-CJF5JHZID&>"R8-2@W.!6X+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(H-T@T"#0X.+@JJ#9H%;@UZ"\(K<@O&"
MQ8*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R
M("*(R(FZ@LV"L8+,@X&#8H-:@5N#5X%I4D9#.#(R@6J"S(-W@V*#7X+%@K>!
M0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O
M(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B
M"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R
M:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES
M<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@
M8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W
M<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE
M<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<
M7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/
M2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D
M:71O<BXB"FUS9W-T<B`B(@HBDHV(TX%)((-T@XN#6(-.@XJ!6X.3@X*!6X-H
M@LT@26YT97)N970@17AP;&]R97(@@L6"S9;BD>B"JI2MD+:"MX+I@K&"QH*J
M@J""Z"(*(H+<@K>!:8-U@XF#18-5@LR#;X-/@L6"MX%J@4*)YI;*@LF#4X-^
M@JJ57(ZF@K."ZH*]@NB!05=I;F1O=W,@@JJ#3H.)@V*#5H.%@K4B"B*"O8+H
M@K>"Z8*I@N""M8+J@MR"N8+Q@4)<;B(*(H-T@XN#6(-.@XJ!6X.3@X*!6X-H
M@LF"MX+I@LB"YR!/2R""\(F?@K6"Q(FZ@K."HH%"(@H*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I
M='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DE$(%PB)7-<
M(B""S8WMCYR"LX+J@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH
M86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+B(*;7-G<W1R("(B"B)';G501R"#;X-#@VF#BH+,@W"#6(*J
M($-R>7!T7W!G<""#3H.)@UB"R9#=DNB"LX+J@L2"HH+IE4N7=H*J@J""Z(+<
M@K>!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<
M;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<T"FUS9VED(")4:&4@;F%M92!T;R!U
M<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@
M(H*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I
M9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B2&]R9&5?0W)Y<'1?
M<VUI;66#3H.)@UB"R8+-;W!E;G-S;(."@U>#A8%;@XN"JI5+EW:"Q8*W@4(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA
M>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB@W:#C(-T@T"#C(.3
M@UA<(B5S7"*"S8-F@5N#7H*J@U2#0X-9D*>,P(+PB7J"IH*]@KV"WY7;D;:"
MQ8*K@MR"N8+Q@L6"M8*]+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB@K&"S(-F
M@5N#7HQ>*"5S*8+PE5R.IH*W@NF"O8+?@LR#=H.-@T^#B8.`@JJ"L8+,@U:#
M6(-E@X""R8+=@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`BB/B7<)6$@LV"
M4)6VCIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM
M<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E
M<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R
M("*+YI#8@NB5A(+-@E"5MHZ:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(H-4@5N#;R!<(B5S7"(@@LV-[8^<@K."ZH+<@K6"O8%"(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S
M='(@(H-4@5N#;R!<(B5S7"(@@LV5VY&V@K."ZH+<@K6"O8%"(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@
M*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BCG>2Z(*U@KV7\8%I)62!
M:H*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE
M(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BB.J.GH-T@T"#0X.+
M(%PB)7-<(B""JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.3D*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N
M;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"XB"FUS9W-T<B`B@T&#8H-V@XV!6X-H@V:!6X->@JJ2O)%/@LR#6(-E
M@V*#=H+%C\&.N(*U@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*
M;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB
M"FUS9W-T<B`B@T&#8H-V@XV!6X-H@V:!6X->@O"5VY&V@L6"JX+<@KF"\8+%
M@K6"O8%"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("*#98%;@WV#9H-"@XR#3H-G@XJ!6R!<(B5S7"(@@JJ"H(+H@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("*.=Y+H
M@L6"JX+I@TF#=H-6@X>#DX+-@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0X"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B@T.#DX.)@T.#DY5<CJ:"Q8*K@NF5E)6J@LV"H(+H@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B*5MHZ:
MD)2"JH*Q@LR#=(-"@5N#BX-H@LF1O8G?@JR"W(*W+B`E<R""S)6VCIJ"JI/\
ME\V"LX+J@L2"HH+<@K<N("5S((C(B;J"Q8+((@HB@JV"Q(+-@J*"KX+<@KF"
M\8%"(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<
M(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B7"(E<UPB((+P@U:#
M6(-E@X""UI+'B<&2AH+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E<R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(H.&@5N#52!<(B5S7"(@@LR#9H%;
M@UZ"\(-6@UB#98.`@JF"YX_!BXZ2AH+)EN*1Z(*JE*V0MH*U@MR"M8*].B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R(")<(B5S7"(@@O"#5H-8@V6#@(*I@N>-[8^<DH:"
MR9;BD>B"JI2MD+:"M8+<@K6"O3HB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A
M=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(EPB)7-<(B""\(U8D%:2AH+)EN*1
MZ(*JE*V0MH*U@MR"M8*].B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.CDR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L
M;V%D960N(@IM<V=S='(@(B(*(H-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H
M@JJ4K9"V@K6"W(*U@KTZ("5S((+-@T&#8H-V@XV!6X-H@K."ZH+$@J*"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R
M("(B"B*#=(-`@T.#BX-!@V*#=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"M8*]
M.B`E<R""S8-T@T"#0X.+@LR#5(-#@UF0IXS`DFPH)62#;X-#(@HB@V<I@O")
M>H*F@L2"HH+<@K>!0B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B*#=(-`@T.#BX-!@V*#
M=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E<R""S8CJE92"S(+=@T&#
M8H-V@XV!6X-H@K."ZH+<@K4B"B*"O8%"(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B
M@K&"S(-P@5N#9X+PE5R.II*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82XB"FUS9W-T<B`BF$&7C9#F@V:!6X->@LR#0X.3@WR!6X-GDH:"R8-'@XF!
M6X*JE*V0MH*U@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM
M8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")I0V%L96YD87(@@LR#0X.3
M@WR!6X-GDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B*0W9+H@W2#
M2(%;@X"2AH+)@T>#B8%;@JJ"H(+H@MR"M8*]@4*"O8+4@O&!095+D'N-@);:
M@JJ+\Y22@KZ"P8*]@LR"Q8*U@N6"I(%"(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B*.=Y+H@K."ZH*]@T&#:(.,@UB2H(+,D8"-[)*&@LF#1X.)
M@5N"JI2MD+:"M8+<@K6"O8%"C.."Q8W$DWB.P(US@K6"Q(*M@KZ"LR(*(H*B
M@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(IA!EXV0YH+,C]J-UX+PC5B05I*&@LF#1X.)@5N"JI2MD+:"
MM8+<@K6"O8%"C.."Q8W$DWB.P(US@K6"Q(*M@KZ"LX*B@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BD9>0
M39#F@XJ#6(-G@LR-6)!6DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4*,XX+%
MC<23>([`C7."M8+$@JV"OH*S@J*!0B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E
M<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B
M@K&"S"!)34%0((-4@5N#;X+-BZ273(-T@TB#BX-?@O"#5(-\@5N#9X*U@L2"
MHH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B@K&"ZH+-ETR,^(+((')A<B"#
M08%;@TJ#0X-U@L6"S8+(@J*"YH*D@L6"MX%"(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B@K&"
MZH+-ETR,^(+(('II<""#=(-`@T.#BX+%@LV"R(*B@N:"I(+%@K>!0B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C0*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M("*"L8+J@LV73(SX@LB#2H%;@VB4U(V&@L6"S8+(@J*"YH*D@L6"MX%"(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@
M(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET
M86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDW-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#,@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3<Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-3,*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,SDU"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-30@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.34U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#(*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#<U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Q.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8S-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#`W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y-`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS.#`R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X
M,3`*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(H*Q
M@LR#=(-"@5N#BX-H@LV52Y![@L6"MX%"(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`V,@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R("*"L8+,@W2#0H%;@XN#:(+-D*Z0E(+%
M@LB"K8+$@LV"HH*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#$S"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("*"L8+,@W2#0H%;@XN#
M:(+-D)2.FH+&@U*#C8.3@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.3$*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(H*Q@LR#
M=(-"@5N#BX-H@LTXD&F0E(+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(P"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<R(*;7-G<W1R("(B"B*"L8+,@W2#0H%;@XN#:(+-@U*#DX-]@MR"
MO8+-B_.4DH+%B^:0V(+G@NJ"O9"ND)2"S(.*@UB#9X+%@LB"K8+$@LV"HH*O
M@MR"N2(*(H+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#8*
M;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS
M9W-T<B`B@K&"S(-T@T*!6X.+@VB"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B
M(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*
M;7-G<W1R("*"L8+,@W2#0H%;@XN#:(+-,3:0:5)'0I5<BTR"S)!&@U*!6X-H
M@LB"K8+$@LV"HH*O@MR"N8+Q@4*7X3HG(S$R,S1A9B<N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z-34X"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(H*Q@LR#=(-(@5N#@(+-
MBOF"R8^(EYV"LX+J@L2"HH+<@K>!0B(*"B,Z('1E;7!L871E<R]H96QP+V%B
M;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A
M<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@
M86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B
M"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C
M=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*
M(H*Q@LR#@8-B@UJ!6X-7@LV"H(+(@KV"JHYGEW""MX+I@LR"QHC9@LB"Z96V
MCIJ#6H-B@V>!:25S@6J"Q8^1@JF"ZH+$@J*"W(*W@4(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(H*Q@LR4U(V&@LV-Q8^L
M@L6"X#&"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B@K&"S(-4@5N#;X+%@LUZ:7""QF=Z:7"#=(-`@T.#BX+PDU>*2H+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N(@IM<V=S='(@(H*Q@LR#5H-8@V6#@(+-B.J.GI-)@LF6LXSX@LF"
MR(+!@L2"HH+<@K>!0B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM
M<V=S='(@(H*Q@LR2;(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(B"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W(@IM<V=S='(@(H*Q@LR#18-"@Y.#:(-%@LV#28-V@U:#AX.3@T6#0H.3
M@VB#18*I@N>,Q(]O@K."ZH+IE4N7=H*J@J""Z(+<@K>!0B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")4:'5N
M9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,S8*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0R,B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(E1I;64B"FUS9W-T<B`BCIZ*U"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T
M<B`B@UZ#0X.`@U:!6X-G(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS
M9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("*.GHK4CY&.KB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U,C@*;7-G:60@(E1I;64@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E
M(@IM<V=S='(@(I.,@V6#0H."@5N#BY:OCN6+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("*#7H-#@V>#BR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*
M;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HBE:&0E(+,C8"6
MVH+PD4F1\(*W@NF"R8+-@4%00X+%@LU#;VYT<F]L@TR#0X%!36%C@LB"YT-O
M;6UA;F2#3(-#@O")GX*U@LB"JH+G@TXB"B*#BH-B@TZ"M8+<@K>!0B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R
M(")(5$U,@UR!6X-8E5R.II#8D=8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M;V=O(@IM<V=S='(@(H-G@5N#4XNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1O:V5L874B"FUS9W-T<B`B@V>#4(.)@T6/E).'(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B
M@V>#DX-+B:2-D2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:V]L86(N<&AP
M.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H
M92!L87-T(&UI;G5T97,N(@IM<V=S='(@(H*Q@LR0E)6JBM2"R8F]DWB"X(.-
M@T^#0X.3@JJ.CHUS@K."ZH+<@K6"O8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A
M;F0@5&]B86=O(@IM<V=S='(@(H-G@XJ#:H-?@5N#:(%%@V>#;X-3BZ2888V1
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<X-PIM<V=I9"`B5')U
M92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("*)SB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B@V"#A8-J
M@U>#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G
M<W1R("*#9X.+@U*+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(H-G@XN#
M3H.!@VJ#6(->@Y,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B@UZ!6X-.@UB!18-*@T.#4H-8CY23
MAR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("*#8X-O
M@XLB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E
M('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`BD4F1\(%&(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*
M;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D
M96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S
M='(@(H-%@TN#DX-?BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR
M86EN92(*;7-G<W1R("*#18-.@XF#0X-I(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ"R8-!@TZ#6H-8
M@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B5D93((-T@T"#0X.+(%PB)7-<(B""S(-!@TZ#6H-8C*""
MS97/C5B"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS.3(@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")61E,@@W2#0(-#@XL@)7,O
M)7,@@LR#08-.@UJ#6(R@@LV5SXU8@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B)7,@@LF5SXU8@L6"
MJX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S7"(N(@IM<V=S='(@(H-T@T"#0X.+(%PB)7-<(B""S(-4@T.#
M68*J@V"#1H-B@TZ"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-CDU(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`R.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<R\E<UPB+B(*;7-G<W1R("*#=(-`@T.#BR!<(B5S+R5S7"(@@LR#5(-#@UF"
MJH-@@T:#8H-.@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BXB"FUS9W-T<B`B4U%,((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5
M;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B4U-,((+%D-J1
ML8+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(S,B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S<*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P-"!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C`Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*
M;7-G<W1R(")61E,@@W2#0(-#@XN"\(-2@W.!6X+%@JN"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XH@7"(E<UPB((+PC>R0K(+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,V,2!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH+P
MC>R0K(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM
M<V=S='(@(E9&4R"#=(-`@T.#BX+PC>R0K(+%@JN"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(E9&4R"#9H-"@XR#3H-G@XH@7"(E<UPB((+PC>R0K(+%@JN"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`BB_."
MS"!61E,@@W2#0(-#@XN"\(WLD*R"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(H-F@5N#7H+PB+./:X+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(X(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2XB"FUS9W-T<B`B7"(E<UPB@O"-[8^<@L6"JX+<@KF"\2X@
M@V:#0H.,@TZ#9X.*@JJ+\X+%@LV"H(+H@MR"N8+Q@4(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*
M;7-G<W1R(")<(B5S7"*"\(WMCYR"Q8*K@MR"N8+Q.B`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS.34*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q
M,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B5S@O"-[8^<@L6"JX+<@KF"\2X@
M@V:#0H.,@TZ#9X.*@JJ+\X+%@LV"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B5D93((-F@T*#C(-.
M@V>#BH+PC<2+09-)@LF-[8^<@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,S0T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH+P
MC>V/G(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#(P(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ"\(WMCYR"Q8*K@MR"N8+Q
M@48E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(")61E,@@W2#0(-#@XL@7"(E<UPB((+PC>V/G(+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Q,"!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(Y,0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R"#=(-`@T.#BX+PC>V/G(+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XH@7"(E<UPB((+P
MC>V/G(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B5D93((+PC<2+09-)@LF-
M[8^<@L6"JX+<@KF"\8%&)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2XB"FUS9W-T<B`BC+N-W8+,@V:#0H.,@TZ#9X.*@5N"JI/!DNB"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<R(*;7-G<W1R("*/V):^CY&"S(_:C=>"JH[F@NB/;X*Y@MR"N8+Q
M(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM
M<V=S='(@(B5S((+,DNB+8(*J@XV!6X-H@L6"JX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3<T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G
M:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@@W2#
M0(-#@XN"JHC:DZZ"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C4R(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@@W2#0(-#@XL@
M7"(E<UPB((*JBDJ"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C@T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S
M='(@(E9&4R"#=(-`@T.#BX+PCY&"JXV>@MV7<(+)BDJ"KX+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#,@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM
M<V=S='(@(E9&4R"#=(-`@T.#BX*JBDJ"KX+<@KF"\8%"(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("*(LX]KCY&,
MR8-T@T"#0X.+@O"*2H*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL
M97-I>F4H*2!F86EL960I+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"JI/'@M^"
MW(*Y@O&!:69I;&5S:7IE*"D@@T>#B8%;@6J!0B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(E9&4R"#=(-`@T.#
MBX*JD\>"WX+<@KF"\8%I9V5T1FEL95-I>F4H*2"#1X.)@5N!:H%"(@H*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N
M<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B
M5D93((-T@T"#0X.+@JJ3QX+?@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B=F9S<F]O=""#9H-"@XR#3H-G
M@XJ"\)/'@M^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3$P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B
M"FUS9W-T<B`BEKR13R`E<R""\"`E<R""R97/C5B"Q8*K@MR"N8+Q@4:#=(-(
M@XN#7X%;@LV*^8+)D;:-W8*U@MR"MR(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH%;@LR6O)%/
M@O"5SXU8@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#
MBH%;@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%&)7,B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(W,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93((-T@T"#0X.+(%PB)7-<(B""
MS):\D4^"\)7/C5B"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV,3<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R(")61E,@@W2#0(-#@XL@)7,O)7,@@LR6O)%/
M@O"5SXU8@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,C8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92XB"FUS9W-T<B`B5D93((-T@T"#0X.+@LR6O)%/@O"5SXU8@L6"JX+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W
M;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0B"FUS9W-T<B`B@K&"S"!7;W)D()6VCY&"\)9\EO."Q8*K
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-"!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")61E,@@W2#0(-#@XL@7"(E<UPB((+)CY&"KX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")61E,@
M@W2#0(-#@XN"R8^1@J^"W(*Y@O&!:6-O<'DH*8ZXE'.!:H%"(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N(@IM<V=S='(@(E9&4R"#=(-`@T.#BX+)CY&"KX+<@KF"\8%"(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R
M(")61E,@@W2#0(-#@XN"R8^1@J^"W(*Y@O&!0G%U;W1A((+PDK2)WX*U@KV"
MYH*D@L6"MX%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(HFZD/PB"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`BE<^-6(+PCN:"Z(_!@K<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R("*-Q8SC@LR1@(WL@O",LX+)EM^"MR(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@(@IM<V=S='(@(I#:D;&.GH+,@U2!6X-O@5N"J8+G@LR77(KZ@K6"
MR(*BB9Z3FH%&(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,S.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-S8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@R"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O
M.B`B"FUS9W-T<B`B@U2!6X-O@5N"J8+G@LR77(KZ@K6"R(*BB9Z3FH%&(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BEJ*0KI>=(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B@T&#B8-UCO&2MXV1F$&632(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`BB7"-D2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`BE<2-D2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI
M;F<@27-L86YD<R(*;7-G<W1R("*5Q)?,D;Z5O9=MCY23AR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C<X"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#,P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`BE7.6OB(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I
M9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+B(*;7-G<W1R("*#AH%;@U66O(*I@W"#6(./@5N#:(*JE7.6OH+%
M@K>!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HS,#(*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BEK.6O"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@
M(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S
M;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z
M:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C
M<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB@UJ#
M3(.%@XJ#98-"@5N/XX+,EYV74H*I@N>3P8R@@LR6LX*B@UB#3H.*@W:#9X+-
M($-U="]#;W!Y+U!A<W1E((+%@JN"W(*Y@O&!0B(*(D]+((+P@TZ#BH-B@TZ"
MMX+I@L:!08+'@J2"XH+!@L2#3H.*@V*#=H-[@5N#:(+)@T&#3H-:@UB"MX+I
M@JF"QH*B@J0@;6]Z:6QL82XB"B)O<F<@@LR+6H]PE;:/D8+PC*F"Z8*Q@L:"
MJH+%@JN"W(*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T
M960@17AT96YS:6]N(@IM<V=S='(@(H-4@WR!6X-G@K6"Q(*B@LB"HHIGDJ..
M<8+%@K<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(HU8D%8B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G
M<W1R("(E<R""\(U8D%:"MX+I@4(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("*#
MAH%;@U6"\(U8D%:"MX+I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M
M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM
M<V=S='(@(EPB)7-<(B""\(U8D%:"M8+<@K6"O8%"(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N(@IM<V=S='(@(HU8D%:#6(-.@XJ#=H-G@O"-[8^<@K6"W(*U@KV!0B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S
M='(@(H-!@V*#=H.-@5N#:"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("*14X+$@LR#08-V@XJ#4(%;@U:#
MAX.3@LR0W9+H@W2#0(-#@XN"\(-4@5N#;X+)@T&#8H-V@XV!6X-H@K6"W(*U
M@KV!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS
M9W-T<B`B@XF#98.3E;:.FH%ID>65MHZ:@6HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5
M<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(H.-@5N#?9"4CIJ!:9'EE;:.
MFH%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("*#
M18.+@T^#08-#DXR5^XNDF&&-D2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("*,NXW=@LR2;(+PCF>7<(%&)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")34TP@@O".9Y=P(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T
M<B`B24U34""#5(%;@V^"S(.&@5N#59:\@5Z#<(-8@X^!6X-H@JJ(V8+(@NF/
MZHV'@LF.9Y=P@K6"W(*W@4(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(H.&@5N#52(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S<T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R("*#AH%;@U4@)7,@@LT@)7,@@L641H_8@K."ZH+$@J*"
MW(*Y@O&!0B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("*#AH%;@U6*QY>=(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N
M<R(*;7-G<W1R("*#AH%;@U6#28-V@U:#AX.3(@H*(SH@<VEG;G5P+G!H<#HV
M,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B@X:!6X-5DV^8
M7B(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N
M(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(H.&
M@5N#58+,DV^87H+-@K&"S(-4@T.#9X+%@LV+UHY^@K."ZH+$@J*"W(*W@4(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C
M8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(H.&@5N#58%;@T&#2H-%@Y.#9X*J
M@J""Z(+<@KF"\8%"@4(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5
M<V5R;F%M92(*;7-G<W1R("*#AH%;@U66O"(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("*#AH%;@U66
MO"!<(B5S7"(@@LV*^8+)@J""Z(+<@K>!0B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(H.&
M@5N#59:\.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G
M:60@(E5S97)N86UE.B`B"FUS9W-T<B`B@X:!6X-5EKPZ("(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H
M92!S>7-T96TZ(@IM<V=S='(@(H-6@UB#98.`DH:"S(.&@5N#58%&(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("*#18-9@WB#
M3(-8@UZ#DXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$W,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C(*;7-G:60@(E9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(HMXB<DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C,*
M;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*
M;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(I=,C/B0JR(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I
M9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E
M<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(V,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,#<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#8@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X,PIM<V=I9"`B5F%L=65S('1O('-E;&5C
M="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A
M='4B"FUS9W-T<B`B@V^#:X-!@V.+I)AAC9$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B@WB#
M;(-9@T>#B8%%@WN#BH-O@XN+I)AAC9$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE
M9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N
M(@IM<V=S='(@(HR?C]B.N)1S("T@@K&"S(.!@V*#6H%;@U>"S8G\XH*"LX+J
M@L2"HH+I@N:"I(+%@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(I3%(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#
M;VYT<F]L(@IM<V=S='(@(H-O@5N#5X.'@Y.*QY>=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B
M5F5R=&EC86P@86QI9VXB"FUS9W-T<B`BCV.(RI)U(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC
M86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S(*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:65T($YA;2(*;7-G<W1R("*#>(-G@VF#@([0B>^.Y8M@BZ28
M88V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N
M86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B)7,@@O",J8+I(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G
M<W1R("**3Y64@LP@=V5B((-Y@5N#5X+PE5R.IB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(HEPE\R#;X%;@U>#
MDX^4DX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M52Y3+B(*;7-G<W1R("*5Q)?,@V^!6X-7@Y./E).'(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,38*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES
M:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)
M=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS
M9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%
M(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A
M;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(H-%@TB#BH-8@46#=(-G@T2!6X-I
MCY23AR(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX
M,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("*,>(V0(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS
M9W-T<B`BD(4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*
M;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A
M('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@X.0IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@
M4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`BEHB/5"(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC
M;VUE(@IM<V=S='(@(H+F@J2"L8*[(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B)7,@@LF"
MYH*D@K&"NR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE+"`E<R(*;7-G<W1R("(E<R""LX+Q@4&"YH*D@K&"NR(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M
M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M.0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("*0O(-4
M@VZ#B2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B)7.#C8-/@T.#DXSC@L>"S(-!@W:#
MBH-0@5N#5H.'@Y."\)5<CJ:"M8+<@K>"J8%((@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_(@IM<V=S='(@(HOFD-B"Z)6VCIJ"S8F]@L6"MX*I@4@B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("*(^)=PE;:.FH+-
MB;V"Q8*W@JF!2"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC
M:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("*#98-,@UB#9X-'@V:#0H->@5N"
MS(-V@XF#3X-#@Y."\)%)D?""M8+<@K>!0B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H
M(@IM<V=S='(@(I6=(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P
M-`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C
M="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(HVV@LF2=8*M)7.#@8-J@X6!
M6X+,E9V!:8Z?B?&"S(.-@T^#0X.3@JF"YY=,C/B!:CHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED
M=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(I5<@LR5G2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T
M:"!U;FET(@IM<V=S='(@(I6=@LR24(C*(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R("*5G8%&(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM
M<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8W"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@
M(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@
M(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("*7?H*U@J*"X(+,B.J7
MER(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("*+SI:QD.:"
MS(]:CXHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(HO.EK&0YH+,DV28
M8I34C88B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(E9""-<Y;:@L6*U(CA@L&"O8V`
MEMJ0E(%"D+."M8*M@LT@)62!08YWDNB"LX+J@KV"S(+-("5D@4(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O
M=6YD("5D+B(*;7-G<W1R("**U(CA@L&"O8V`EMJ0E(%"D+."M8*M@LT@)62!
M08YWDNB"LX+J@KV"S(+-("5D@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T
M("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5D93@W2#
M0(-#@XN"S)/'@MV/;X*UDH:"R95SD+."R(-)@W2#6H-B@V<@)60@@JJ.=Y+H
M@K."ZH+<@K6"O8%"(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T
M-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS
M=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@BNZ6>Y"GC,`B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y=C,@C*Z.9Y=PED`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y
M=C,@CN61S([2@LR5RI:\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R(@IM<V=S='(@(E@U,#EV,R".Y9',CM*"S(RNCJ^5RHYQ(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV
M,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R"*9Y*CBT"47"(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("*43B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I
M9"`B65E962(*;7-G<W1R("*43B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("*6B)1.(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B@T.#1X.!@Y.+I)AAC9$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS
M9VED(")997,B"FUS9W-T<B`B@LV"HB(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B
M"FUS9W-T<B`BDZ^(TX*U@MR"MR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+B(*;7-G<W1R("*-H8+-@V6#3(-8@V>#@H%;@VB"Q8*W@4);/#Y=
M@WN#7H.3@L5765-)5UE'@X*!6X-H@LF6WX+H@MR"MX%"(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B)60@B,B/XX+,@W6#C8-B
M@TZ"\(WLD*R"MX+I@K&"QH+-BY:)PH*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C0*;7-G:60@(EEO=2!A<F4@
M;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(H*@@LB"O8+-E$:/V(*S@NJ"
MQ(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A
M8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`BEKR13X+,DH:"R2`G
M7%PG((+&@J*"I)6VCIJ"S8YG@J:"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW
M,@IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+B(*;7-G<W1R("*73(SX@LB39(YQ@X&!6X.+@T&#:(.,@UB"Q8+-@J""
MZ(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(H-#@Y.#?(%;@V>"LX+J
M@KV#=(-`@T.#BX+,@W2#0H%;@XN#:(+P)7.3X(+,D<Z)GH*W@NF#=(-"@5N#
MBX-H@LF#?8-B@W:"M8+$@MPB"B*"N8+Q+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+B(*;7-G<W1R("*#C8-/@T&#18-G@K6"W(*U@KTN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(U.`IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA
M;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(I"S@K6"HI-DF&*4U(V&@O"3_)?-
M@K>"Z8+F@J2"R9*-B-."M8+$B;J"LX*B@4*0E(Z:@KZ"KX*JCF>7<(+%@JN"
MW(*W@JJ!08V1C=LB"B*39)AB@LB"YY#FDZJ"R8%[@O"5=(*O@MR"MX%"(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X-0IM<V=I9"`B66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`BD+."M8*BDFR"
M\)/\E\V"M8+$B;J"LX*B@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(H-4@T.#
MDX-!@V*#=H+PEYB7<(*W@NF"O8+?@LF"S2!$871A5')E92"#;X-B@TZ#1X.3
M@VB"\)#=DNB"MX+IE4N7=H*J@J""Z(+<(@HB@K>!0B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B5D93((-O@V*#3H-'@Y.#:(+P
MD-V2Z(*W@NF52Y=V@JJ"H(+H@MR"MX%"(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+B(*;7-G<W1R("*/X8I1@LR3X)=E@O"+3(]Q@K6"Q(*I@N>!08_ABE&#
MC(-\@5N#9X+PD9>038*U@L2"K8*^@K."HH%"(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S
M='(@(H*Q@K&"R8.*@Y.#3H*W@NE54DR"\)/\E\V"M8+$B;J"LX*B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BC>V/
MG(*W@NF#5(%;@V^"\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(&-L96%R(&]U="XB"FUS9W-T<B`BC\&+CH*W@NF#AH%;@U66O(+PCG>2
MZ(*U@L2"K8*^@K."HH%"(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G
M<W1R("*-[8^<@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"XB"FUS9W-T<B`BDL>)P8*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"
MK8*^@K."HH%"(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(HU8D%:"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G
M<W1R("*.P(US@K>"Z8-!@TZ#5H.'@Y."\(YWDNB"M8+$@JV"OH*S@J*!0B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M(@IM<V=S='(@(I!6@K6"HI6JE]Z6O(+PD_R7S8*U@L2)NH*S@J*!0B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO
M;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B)7,@
M@UJ#8H-6@X>#DX+,ETR,^(KZC,""JI#8@NJ"Q(*B@MR"MX%"@XV#3X-#@Y."
MM9*\@K6"Q(*M@KZ"LX*B@4(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(I-DCG&#@8%;@XN#08-H@XR#6"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B@J""
MR(*]@LP@1G)O;3H@@T&#:(.,@U@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B@J""R(*]@LR#0X.3@W2#2(.!
M@5N#5H.'@Y,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B*#6H-B@U:#AX.3("5S((+,BM2"R8*@
M@LB"O8+,@T&#:(.,@UB"JI7/C5B"LX+J@MR"M8*]@4*#6H-,@X6#BH-E@T*!
M6Y7;C.R"S(*](@HB@M^"R8.-@T^#0X.3@K62O(*W@M>"JX+%@K>!0B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`B@J""R(*]@LR6O)%/(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@
M268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E
M<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(H*Q@LR41H_8@V^#8H-.
M@T>#DX-H@L6"S8%!@X:!6X-5@LR2QXG!@JJ#5(-\@5N#9X*S@NJ"Q(*B@MR"
MN8+Q@4*"X(*U($AO<F1E((+%(@HB@X:!6X-5@T&#2H-%@Y.#9X+PBL>7G8*U
M@KV"HH+,@LB"YX%!D;R"S)1&C]B#;X-B@TZ#1X.3@VB"\(YG@J2"UX*K@L6"
MMX%"(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS
M9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@
M(B(*(H*Q@LR41H_8@V^#8H-.@T>#DX-H@L6"S8%!@X:!6X-5@LR#BH-8@V>"
MJH-4@WR!6X-G@K."ZH+$@J*"R(*B@JF!08*@@NF"HH+-B;TB"B*"YX*I@LR7
MG9=2@L6"L8+,BT"47(*JEK.,^(+)@LB"P8+$@J*"W(*W@4(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"B*#6H-B@U:#AX.3("5S((+,BM2"R8*@@LB"O8+,@W6#B8-%@U6"
MJI7/C5B"LX+J@KV"YH*D@LB"S(+%@4&#6H-,@X6#BH-E@T*!6Y7;(@HBC.R"
MS(*]@M^"R8.-@T^#0X.3@K62O(*W@M>"JX+%@K>!0B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C4W"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(H*HCF>"HH+,@W6#B8-%
M@U6"S8*Q@LR+0)1<@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0
M<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R
M("(B"B*"J(YG@J*"S(-U@XF#18-5@LV"L8+,B/.-_(-)@W:#5H.'@Y."\(-4
M@WR!6X-G@K6"Q(*B@MR"N8+Q@4)#;VYT<F]L+T-O;6UA;F0@(@HB*R!0((+%
MB/.-_(*U@L2)NH*S@J*!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(H->
M@T.#@(-=@5N#DX%&(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM
M<V=S='(@(H*@@LB"O8+,@V:#=(-(@XN#9TE$@LV5SXU8@K."ZH+<@K6"O8%"
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("*"H(+(@KV"S(-F@W2#2(.+@V=)
M1#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R
M(&9U;&P@;F%M93HB"FUS9W-T<B`B@J""R(*]@LR.@9:\(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R("*#C8-/@T.#DX+-BOJ,P)#8@NJ"Q8*W@4(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S
M='(@(I!6@K6"HB`E<R"7<(+,@W"#6(./@5N#:(%&)7,B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+B(*;7-G<W1R("*"H(+(@KV"S(-)@W:#5H.'@Y."S8R[C=V"S(-:
M@V*#5H.'@Y.2AH+)E<^-6(*S@NJ"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N(@IM<V=S='(@(H-)@W:#5H.'@Y."\(U8D%:"M8+<
M@K6"O2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(H-P@UB#
MCX%;@VB"S8.*@UJ#8H-G@K."ZH+<@K6"O8%"(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B*#<(-8@X^!6X-H
M@LV#BH-:@V*#9X*S@NJ"W(*U@KV"S(+%@4&05H*U@J*#<(-8@X^!6X-H@L6#
MC8-/@T.#DX*U@L2"W8+$B;J"LR(*(H*B@4(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N(@IM<V=S='(@(H-P@UB#CX%;@VB"JHKZC,"0V(+J@L6"MX%"(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E
M;6]T92!S97)V97)S.B(*;7-G<W1R("*#BH."@5N#9X-4@5N#;SHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(H.&
M@5N#4X-8@XF#<H-!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B@U6#0X%;@XN+I)AAC9&!:8-2
M@Y.#4Y:OCN6+I)AAC9&!:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I
M82(*;7-G<W1R("*#58.3@W*#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EII;6)A8G=E(@IM<V=S='(@(H-7@Y.#;X-U@T>+I)AAC9$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L
M96T@4F5P;W)T72(*;7-G<W1R("*!;8_ABE&5\8V0@6XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF
M;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`T"B,L
M('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");
MC7,Z)7,O)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-34T
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")?08K'EYTB"@HC.B!L:6(O87!I+G!H<#HQ-3<*
M;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS
M9VED(")?1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L
M971E(%)O=R(*;7-G<W1R(")?1(US@O"-[8^<(@H*(SH@;&EB+V%P:2YP:'`Z
M,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'@T^#BX%;@W8B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L
M<"(*;7-G<W1R(")?2(-W@XN#=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B7TF)YI&<@W:#C8-P@V6#0BXN+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],
M;V<@:6XB"FUS9W-T<B`B7TR#C8-/@T.#DR(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(E],@XV#3X-!@T6#9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN
M(@IM<V=S='(@(E]-@XJ#DX-.E<^-6"(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/
M@TF#=H-6@X>#DR(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI
M<W-I;VYS(@IM<V=S='(@(E]0@T&#3H-:@UB,H"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B
M7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]2@XJ#DX-.C>V/G"(*"B,Z(&QI
M8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]3@UJ#8H-G
M@T&#8H-V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")?5)5<D:Z0JR(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B
M7U5S97)S(@IM<V=S='(@(E]5@X:!6X-5(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("*#
M08-H@XR#6)*@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(I5SEKZ"
MR(-!@VB#C(-8(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3<*
M;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(I=<DNB57"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H
M<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A
M=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`BCV^7S8-T@T"#0X.+@JJ-[)"L@L6"
MJX+<@KF"\2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("*3_)?-@W2#
M0(-#@XN"JHI*@J^"W(*Y@O$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3@*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B@K&"
ML8+P@TZ#BH-B@TXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S
M='(@(H-2@WV#DX-HC7..9Y=P@LR#1X.)@5LB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E
M<G)O<B(*;7-G<W1R("*0W9+H@T>#B8%;(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F
M:6QE(&UI<W-I;F<B"FUS9W-T<B`BCV27=H+(@U:#6(-E@X"#=(-`@T.#BX+,
MC(>7CB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V
M"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("*#9H%;@UZ,8(ZN
M@T>#B8%;(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I
M9"`B961I="(*;7-G<W1R("*5TH]7(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G
M<W1R("*-@);:@JJ"H(+H@MR"N8+Q(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DX"FUS9VED
M(")F:6QE(@IM<V=S='(@(H-T@T"#0X.+(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.#$@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C<@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*;7-G
M:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R("*#>H-8@V>6O(*JE7.6OB(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I
M;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R
M("*3_(]OE\V#1X.)@5LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS
M9W-T<B`B@UR#=(-G@T6#1H-!D^"5E(+,@T>#B8%;(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F
M<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S`*
M;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M
M92(*;7-G<W1R("*6O)%/(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R
M-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(H[`D96"LX+J@L2"
MHH+<@KF"\2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("*"W(*^
MCL"1E8*S@NJ"Q(*B@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B@X&#@I*@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("*#<(%;@UJ#DX-G(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI
M<W-I;VX@9&5N:65D(@IM<V=S='(@(H-!@TZ#6H-8@LV+D93;@K."ZH+<@K6"
MO2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("*#<X-.@UJ#BR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B@XJ#@H%;@V>"Q8+,
M@W:#C8-G@U*#BX-'@XF!6R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E
M<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B@U2!6X-R@UB5<Y1<(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R
M96YC97,B"FUS9W-T<B`BC;>5JH+PE5R.IB(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA
M:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G
M:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@
M(H-6@UB#98.`@T>#B8%;(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("*#7H-8@TZ#BH-8@V<B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I
M9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`BB.J.GI-)@LB#1X.)@5LB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M(@IM<V=S='(@(HIME$:"S(*]@M^#<(-8@X^!6X-H,I-XD_R7
MS8*U@L2)NH*S@J(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI
M;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(I:SEKPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L
M96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS
M9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&\O:VU?2T@N<&\`````````````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8T,#<R-``Q,#0Q-S,V,S`P,0`P
M,38S-S``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R!33TU%($1%4T-225!4259%(%1)5$Q%+@HC($-O<'ER:6=H="`H0RD@
M645!4B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D
M('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(%!!0TM!1T4@<&%C:V%G
M92X*(R!,96%N9R!#:'5M<V]B96X@/'-O8F5N0&MH;65R;W,N:6YF;SXL(#(P
M,#8N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M($E-4%QN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#0M,3(M,#@@,3`Z,C@K
M,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-BTQ-2`Q,3HU,RLP
M-S`P7&XB"B),87-T+51R86YS;&%T;W(Z($QE86YG($-H=6US;V)E;B`\<V]B
M96Y`:VAM97)O<RYI;F9O/EQN(@HB3&%N9W5A9V4M5&5A;3H@2VAM97(@/'-U
M<'!O<G1`:VAM97)O<RYI;F9O/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*
M(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UU=&8M.%QN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(.&>D.&?DN&>A.&?@^*`B^&>
M@.&>D^&?DN&>F^&>A.*`B^&>D>&?A2DB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$S.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K
M97D@)7,I(@IM<V=S='(@(B`HX9Z"X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z%X9Z[
MX9Z%XH"+X9Z5X9^2X9Z;X9Z\X9Z<XH"+X9Z`X9ZVX9Z/X9^+("5S*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S@Q"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@
M*.&>D.&?DN&>A.&?@^*`B^&>D^&?@>&?ARDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S@S"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@
M*.&>D.&?DN&>A.&?@^*`B^&>G^&?DN&>HN&?@N&>@"DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS
M9W-T<B`B("CAGICAGY+AGI_AGK?AGIOAGICAGXGAGK?AGHDI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S4S"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.3D*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(.&>F.&>M^&>
MD^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>D.&>C^*`B^&>H>&>ON&>F<*@
MX9^4(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G
M<W1R(")<(B5S7"(@X9Z8X9ZWX9Z3XH"+X9Z8X9^"X9Z3XH"+X9Z'X9ZVXH"+
MX9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<P,PHC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$P-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U
M<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D
M.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S(.&>D^&>M^&>A"`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8W(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-#(@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!-0B(*;7-G<W1R("(E<R#AGICAGX'AGH#AGK;AGI3AGX,B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Q(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<W(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S4W(&QI8B]";&]C:R]M971A<BYP:'`Z,S8S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S
M='(@(B5S(.&?EB`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI
M<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B
M92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@
M;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF
M;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-3<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P,@IM
M<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(P-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V
M87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$S-@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0V"FUS9VED("(M+2!S96QE8W0@
M+2TB"FUS9W-T<B`B+2T@X9Z'X9^2X9Z:X9Z^X9Z?("TM(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(U"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R
M("+AGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGID@X9^AX9^B(.&>F.&?
MB>&?A.&>A"(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR-`IM<V=I9"`B,C0@
M2&]U<B!&;W)M870B"FUS9W-T<B`BX9Z1X9^2X9Z:X9Z$X9^+X9Z1X9^2X9Z:
MX9ZVX9Z9(.&?HN&?I"#AGICAGXGAGX3AGH0B"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`BX9^BX9^D
M(.&>F.&?B>&?A.&>A"(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z
M-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\X9Z8X9Z[X9Z3(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S$*;7-G:60@(D$@9&%T86)A<V4@8F%C
M:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C(*;7-G:60@(D$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#`W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D$@;65S<V%G92!H87,@8F5E;B!S96YT('1O(%PB)7-<(B!T;R!V
M97)I9GD@=&AA="!T:&ES(&ES(')E86QL>2!Y;W5R("(*(F%D9')E<W,N(%1H
M92!N97<@96UA:6P@861D<F5S<R!I<R!A8W1I=F%T960@87,@<V]O;B!A<R!Y
M;W4@8V]N9FER;2!T:&ES("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,38*;7-G
M:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*
M;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!2
M86EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED
M(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM
M<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I
M=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S
M"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("+AGJ+AGX;AGI;AGKCB@(LN+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T
M"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@
M(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BX9Z6X9^0X9Z/X9^,X9Z8
MX9ZVX9Z3XH"+X9ZBX9^&X9Z6X9ZXX9Z"X9Z.X9Z3X9ZX(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*;7-G:60@(D%C
M8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!
M9&0B"FUS9W-T<B`BX9Z4X9Z3X9^2X9Z0X9^"X9Z8(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#
M:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*
M;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S
M+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U
M<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T
M"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU
M"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BX9Z4X9Z3X9^2X9Z0X9^"X9Z8
MXH"+XH"+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@
M7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET
M:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*
M(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM
M<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T.0IM<V=I9"`B061D<F5S<R(*;7-G
M<W1R("+AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,30X"FUS9VED(")!9&1R97-S($)O;VLB"FUS
M9W-T<B`BX9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+
MX9ZVX9Z3(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ
M.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGH+AGY+AGIKAGI3A
MGXOB@(OAGH+AGY+AGIKAGH0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S4W"FUS9VED(")!9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B069G:&%N:7-T86XB"FUS9W-T<B`BX9ZBX9ZVX9Z@X9^2X9Z"X9ZVX9Z3
MX9ZXX9Z?X9^2X9Z0X9ZVX9Z3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI
M82(*;7-G<W1R("+AGJ+AGK;AGIOAGXOAGI3AGK;AGI/AGK@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(N&>HN&>MN&>F^&?B^&>H.&?
MDN&>G^&?@>&>FN&>N"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(N&>B.&?DN&>
MF.&?A.&?A^*`B^&>@.&?DN&>F^&?@N&>A.&>@.&?DN&>F^&>MN&>F2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(N&>C^&>F.&?DN&>FN&>N>&>F"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*
M;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDR"FUS9VED(")!;&PB"FUS9W-T<B`BX9Z1X9ZVX9^&X9Z$
MXH"+X9ZBX9Z?X9^+(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R
M;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*
M;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED
M(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<Y"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM
M<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-3$X"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA
M=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E
M<W,B"FUS9W-T<B`BX9Z4X9^2X9Z*X9Z\X9Z:XH"+X9ZBX9ZVX9Z?X9Z9X9Z*
MX9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B
M"FUS9W-T<B`BX9Z?X9ZVX9Z8X9Z\X9ZBX9ZV(.&>HN&>MN&>F.&?@>&>FN&>
MM^&>@"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,`IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B06YD;W)R82(*;7-G<W1R("+AGJ+AGH3AGXOAGHKAGKSAGIKAGXGAGK8B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`BX9ZBX9Z$X9^+
MX9Z@X9^2X9Z"X9^$X9ZAX9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL
M;&$B"FUS9W-T<B`BX9ZBX9Z$X9^+X9Z@X9^2X9Z?X9^*X9ZXX9ZAX9ZV(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO
M;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("+AGI?AGK;AGH+B@(OA
MGH'AGK;AGH3B@(OAGH_AGY+AGI3AGKSAGH0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(N&>HN&>A.&?B^&>D>&>
MN.&>H.&?DN&>@N&>MB#AGI/AGK?AGH0@X9Z4X9ZVX9Z4X9^*X9Z[X9Z9X9Z*
MX9ZV(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L
M;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L
M:6-A=&EO;B(*;7-G<W1R("+AGH#AGICAGY+AGICAGISAGK?AGI+AGK@B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N
M($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T
M,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T
M;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,@IM<V=I9"`B07!P
M<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B
MX9Z8X9^!X9Z?X9ZV(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S$*;7-G
M:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("+AGJ+AGK;AGIKA
MGXGAGK;AGI3AGXL@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R
M8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B
M+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT
M:6YA(@IM<V=S='(@(N&>HN&>MN&>H.&?DN&>G^&>A.&?B^&>D>&>N.&>DR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`BX9ZBX9ZVX9Z8
MX9^!X9Z3X9ZX(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S(*;7-G:60@
M(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(N&>HN&>MN&>FN&>O.&>E.&>
MMB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S
M8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF
M:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`V"FUS9VED(")!<W-I9VYM96YT(&-O
M;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED
M(")!='1R:6)U=&5S(@IM<V=S='(@(N&>@N&>N^&>CN&>F^&>@.&?DN&>@>&>
MCN&?B"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`BX9Z?X9ZXX9Z@X9ZV(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(N&>HN&>O.&>G^&?
MDN&>C^&?DN&>FN&>MN&>F^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`BX9ZBX9Z\X9Z1X9^2X9Z:X9ZXX9Z?(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q-@IM<V=I9"`B075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,Q"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C(S-`IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z-38*;7-G:60@(B(*(D%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#0*;7-G
M:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C<S"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS,#$*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-38*
M;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDR"FUS9VED(")!=71H7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E
M<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C0Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C0P-`IM<V=I9"`B075T:%]L9&%P.B!5<&1A
M=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN
M<&AP.C8R"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.C@V"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D
M('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H
M96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(N&>
M@.&>MN&>FN*`B^&>E>&?DN&>D>&?@.&>A.*`B^&>E>&?DN&>D>&>MN&>C^&?
MB^*`B^&>E^&>MN&>EN*`B^&>C^&?DN&>FN&>N>&>F.*`B^&>C^&?DN&>FN&>
MO.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>FN&>MN&>A^&?D.&>F2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V
M"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N
M<&AP.C$X,@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$
M2553('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`BX9ZB
MX9ZVX9Z@X9^2X9Z?X9^*X9^"X9Z:X9Z4X9^"X9Z@X9^2X9Z?X9Z$X9^+(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")"3T9(($5X8W5S
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R
M("+AGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGIDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S
M"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(N&>EN&>CN&?C.*`
MB^&>E>&?DN&>D>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#(*;7-G:60@(D)A
M9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX-`IM<V=I9"`B0F%D(&ME<F)E<F]S('5S
M97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S
M(@IM<V=S='(@(N&>E.&>MN&>H.&>MN&>F.&?B>&>MN&>GR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`BX9Z4X9ZVX9Z:X9^)X9^"X9Z3
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)A;'1I8R`H
M25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A
M;F=L861E<V@B"FUS9W-T<B`BX9Z4X9Z$X9^+X9Z`X9^2X9Z;X9ZVX9Z*X9^!
MX9Z?X9^2X9Z@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T
M<B`BX9Z4X9ZVX9Z:X9Z4X9ZVX9Z*X9Z\X9Z?(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI
M8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F5L87)U<R(*;7-G<W1R("+AGI3AGX'AGJ'AGK;AGIKAGKOAGI_AGY+A
MGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(N&>E.&?
M@N&>F^*`B^&>H.&?DN&>G^&?BN&>M^&>@"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)E;&EZ92(*;7-G<W1R("+AGI3AGX'AGIOAGKCAGJ#AGY+AGI\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("+AGI3AGX'AGH[AGK;AGX;A
MGH0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(N&>E.&?
MBN&?@>&>FN&>F.&>O.&>BN&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A
M;B(*;7-G<W1R("+AGI3AGXKAGKSAGH_AGK;AGI,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A
M>2(*;7-G<W1R("+AGI#AGY+AGH3AGX/AGH#AGX;AGH[AGK[AGH\B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW,@IM<V=I
M9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B
MX9Z*X9ZWX9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R
M("+AGI3AGKSAGIOAGKCAGISAGK@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C(Q"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`BX9Z`X9Z3X9^2
MX9Z;X9^"X9Z$XH"+X9Z%X9^&X9Z.X9ZVX9^&(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R
M9&5R(@IM<V=S='(@(N&>G^&?BN&>N^&>F"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC
M:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`BX9Z?X9^*X9Z[X9Z8XH"+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("+AGI3AGKSAGI_AGY+AGI/AGXKA
MGK@@X9Z3X9ZWX9Z$(.&>H.&>NN&>H.&?DN&>G^&?BN&?@>&>H.&?DN&>@N&?
MA.&>G.&>N.&>CN&>MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HQ,#$*
M;7-G:60@(D)O=&@B"FUS9W-T<B`BX9Z1X9ZVX9^&X9Z$XH"+X9Z6X9ZXX9Z:
MXH"+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`BX9Z4
MX9Z[X9Z/X9Z?X9^2X9Z<X9ZVX9Z.X9ZV(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB
M"FUS9W-T<B`BX9Z4X9ZVX9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T
M($ES;&%N9"(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGI3AGXKAGKSAGISAGXGA
MGX(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`BX9Z4X9^2
MX9Z:X9^!X9Z?X9^*X9ZXX9Z;(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("+AGJ+AGK;AGH[A
MGK;AGH7AGH#AGY+AGIKB@(OAGI_AGICAGKOAGI'AGY+AGIKB@(OAGJ7AGH[A
MGY+AGHSAGK8@X9ZBX9Z$X9^+X9Z"X9^2X9Z;X9^!X9Z?(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`BX9Z4X9^2X9Z:
MX9^*X9Z[X9Z9X9Z.X9^!XH"+X9Z*X9ZVX9Z:X9^*X9Z[X9Z9X9Z?X9ZVX9ZA
MX9ZVX9Z8(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B
MX9Z4X9^*X9Z[X9Z;X9Z@X9^2X9Z"X9ZVX9Z:X9ZX(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA
M($9A<V\B"FUS9W-T<B`BX9Z4X9^*X9Z\X9Z:X9Z"X9ZXX9Z.X9ZVX9Z@X9^2
MX9Z<X9ZVX9Z?X9Z\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G
M<W1R("+AGI3AGXKAGKSAGIKAGKOAGI/AGHSAGK@B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8P"FUS9VED(")#35,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B
M0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U
M-@IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X,R!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U-0HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,38T"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+A
MGI3AGY+AGIKAGH_AGK?AGI'AGK?AGI,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0P"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("+AGH#AGICAGY+AGI;A
MGKOAGH?AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R
M("+AGH#AGK;AGICAGXGAGK;AGIKAGKSAGI,B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS
M9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE
M<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C(T,2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S,P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B
M"FUS9W-T<B`BX9Z`X9ZVX9Z.X9ZVX9Z*X9ZV(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R
M"FUS9VED(")#86YC96PB"FUS9W-T<B`BX9Z4X9^$X9^'X9Z4X9Z$X9^+(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N
M;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS
M9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A
M;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,C(*;7-G:60@(B(*
M(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O
M('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`BX9Z`X9ZVX9Z4X9Z<X9^"X9Z:(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+AGH7AGX;AGH[AGH3AGH?A
MGK[AGH0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`BX9Z<X9Z/X9^2X9Z0
MX9Z[XH"+X9Z*X9ZYX9Z`XH"+X9Z'X9Z)X9^2X9Z'X9Z\X9Z3(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,
M86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)
M<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>@.&?@^&>F.&?B>&>MN&>
MDR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B
M0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I
M;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO
M;F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G
M:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G
M:60@(D-E;G1E<B(*;7-G<W1R("+AGH#AGH[AGY+AGH_AGK;AGILB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z@
MX9^2X9Z<X9^2X9Z:X9ZWX9Z`XH"+X9Z`X9Z.X9^2X9Z*X9ZVX9Z;(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A
M:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I
M9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(N&>AN&>MN&>BB(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("+AGI7AGY+AGIOA
MGK;AGI_AGXOB@(OAGI3AGY+AGH_AGKSAGIHB"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*
M(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W
M"FUS9VED(")#:&%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K
M($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B
M"FUS9W-T<B`BX9Z(X9ZXX9Z;X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`BX9Z%X9ZWX9Z3(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S8*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C<Q"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#
M:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(N&>@.&?
MA.&?A^*`B^&>@N&?DN&>FN&>N.&>G^&?DN&>C^&>F.&?B>&>MN&>GR(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*
M;7-G<W1R("+AGH?AGICAGY+AGIKAGX<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC
M92!T86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*
M;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(N&>A^&>F.&?DN&>FN&?A^*`
MB^&>G^&?AN&>CN&>O>&>FB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R
M.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S
M97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T
M"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(N&>E.&>M^&>
MD>*`B^&>E.&>A.&?DN&>HN&>O>&>A2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4V"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(N&>@.&?A.&?A^*`B^&>@.&>O.&>@.&>O"`HX9Z#X9ZXX9Z;X9ZXX9Z$*2(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C0*;7-G:60@(D-O
M;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P
M<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L
M;VUB:6$B"FUS9W-T<B`BX9Z`X9Z\X9ZAX9Z[X9^&X9Z4X9^*X9ZX(@H*(SH@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(N&>EN&>CN&?C"(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S`*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`Q('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,Y
M"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#
M;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.34T"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.#`*;7-G:60@(D-O;6EC<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B
M"FUS9W-T<B`BX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z4X9Z)X9^2X9Z'X9ZV(@H*
M(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("+AGI_AGX'AGH7AGH#AGY+A
MGH_AGKCB@(OB@(OAGJ+AGI+AGK?AGI3AGY+AGI3AGK;AGIDB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N
M($YA;64B"FUS9W-T<B`BX9Z(X9^2X9Z8X9^$X9^'XH"+X9Z2X9Z8X9^2X9Z8
MX9Z/X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B
MX9Z`X9Z[X9^&X9Z8X9^)X9Z\X9Z:X9^)X9Z\X9Z?(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N
M>2(*;7-G<W1R("+AGH#AGY+AGIKAGKOAGICAGJ#AGXKAGKOAGI,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D-O;7!U=&5R<R(*;7-G
M<W1R("+AGH#AGKOAGX;AGI;AGY+AGIGAGKSAGI'AGY#AGIHB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDP"FUS9VED(")#;VYD:71I;VXB
M"FUS9W-T<B`BX9Z;X9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-C$*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B
MX9Z;X9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO
M;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C;VYF:7)M+G!H<#HS.`IM<V=I9"`B0V]N9FER;2!%
M;6%I;"!!9&1R97-S(@IM<V=S='(@(N&>HN&?A^&>HN&>MN&>A.*`B^&>HN&>
MMN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>FR(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@
M(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HS.#4*;7-G:60@(D-O;F9I<FT@;F5W(&5M
M86EL(&%D9')E<W,B"FUS9W-T<B`BX9ZBX9^'X9ZBX9ZVX9Z$XH"+X9ZBX9ZV
MX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+
MX9Z0X9^2X9Z8X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T
M<B`BX9Z`X9Z[X9Z$X9Z@X9^2X9Z"X9^$(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BX9Z`X9ZVX9Z:
MXH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z:
MX9ZVX9Z'X9^0X9Z9XH"+PJ#AGY0B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,3`P"FUS
M9VED(")#;VYT86-T<R(*;7-G<W1R(")#;VYT86-T<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D
M(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU
M92(*;7-G<W1R("+AGI3AGI/AGY+AGH\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;V]K($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z`X9Z\X9Z`(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")#;V]K:64B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(N&>A>&>F.&?
MDN&>F^&>A"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#<R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V
M"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S
M='(@(N&>@.&>O.&>G^&?DN&>C^&>MN&>FN&>N.&>@.&>MB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@
M4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@
M8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A
M<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G
M:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@
M8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!
M4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B
M:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M96%D("5S+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R
M9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@
M(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R
M(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI
M=&EE<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T
M"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L
M9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N
M(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE
M(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E
M;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R
M871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I
M=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F
M;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(W"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G
M:60@(D-O=6YT<GDB"FUS9W-T<B`BX9Z4X9^2X9Z:X9Z1X9^!X9Z?(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B0V]U<G-E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("+A
MGI3AGH3AGY+AGH#AGK[AGH\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI
M;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R,C,*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("+AGH#AGY+A
MGIKAGKSAGJ+AGK;AGH\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S
M='(@(N&>@N&>N^&>F>&>E.&>MB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I
M;64N<&AP.C,U"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`BX9Z6X9^!
MX9Z;XH"+X9Z<X9^!X9Z;X9ZVXH"+X9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2X9Z4
MX9Z3X9^2X9Z3(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E
M;G0@57-E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,`IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(D-U<G)E;G0@8V]N
M9&ET:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G
M<W1R("+AGIKAGH7AGI/AGK;AGI3AGY#AGI'AGY+AGICB@(OAGI3AGH7AGY+A
MGH7AGKOAGI3AGY+AGI3AGI/AGY+AGI/B@(LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T
M87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`BX9Z4X9^2
MX9Z/X9Z\X9Z:XH"+X9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%XH"+X9Z*X9^"
MX9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z:X9Z/X9^+XH"+X9Z/X9ZVX9Z8
MXH"+X9Z4X9^&X9Z.X9Z$(.&>HN&>MN&>G^&?DN&>FN&?D.&>F>*`B^&>F^&>
MON*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>F^*`B^&>D>&?A>*`BR`E<R#AGY0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("+AGH#AGK;AGH_AGXLB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS
M9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-Y<')U<R(*;7-G<W1R("+AGI_AGXKAGKCAGI;AGIKAGXTB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0WER:6QL:6,@*$M/23@M
M4BDB"FUS9W-T<B`BX9Z?X9^*X9ZXX9Z:X9ZXX9Z;X9ZXX9Z`("A+3TDX+5(I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(N*`B^*`B^&>G^&?BN&>N.&>FN&>
MN.&>F^&>N.&>@"`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B
M"FUS9W-T<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.XH"+X9Z:X9Z*X9^2X9Z+XH"+
MX9Z&X9^!X9Z`(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,"!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B
M"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S
M"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(N&>FN&>MN&>F^&?B^*`B^&>
MD.&?DN&>A.&?@R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B
M1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C@Q"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`V"FUS9VED(")$871E
M(@IM<V=S='(@(N&>@.&>MN&>F^*`B^*`B^&>E.&>FN&>M^&>A>&?@>&?DN&>
MAN&>D2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S
M"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#`*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q-`IM<V=I9"`B1&%Y(@IM
M<V=S='(@(N&>D.&?DN&>A.&?@R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(N&>DN&?
MDN&>D^&>O"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`BX9Z4X9Z3
MX9^2X9Z0X9Z9(.&>A>&>O.&>F^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?BR(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F
M<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(N&>F^&?AN&>D^&>
MMN&?AN&>BN&>ON&>F"(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1&5F:6YI
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(N&>F^&>N^&>
ME.*`BR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*
M;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("+A
MGIOAGKOAGI3B@(OAGH?AGKWAGIKB@(OAGHCAGIHB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*
M;7-G<W1R("+AGIOAGKOAGI3B@(OAGH?AGKWAGIKAGHKAGX'AGH`B"@HC.B!T
M96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$
M96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S
M='(@(N&>BN&>MN&>CN&>NN&>F.&?B>&>MN&>@"(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z:X9Z6
MX9ZWX9Z6X9Z.X9^,X9Z3X9ZV(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,S4*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(N*`
MB^&>HN&>E^&>M^&>G.&>C.&?DN&>C2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(Y"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R,0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("+AGI#A
MGH\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P
M;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.30*;7-G:60@
M(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HY-PIM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$P"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&II8F]U=&DB"FUS9W-T<B`BX9Z@X9^2X9Z?X9^*X9ZXX9Z4X9Z\X9Z1X9ZX
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@
M(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM
M<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("+AGHKAGKSAGICAGKCA
MGI/AGKCAGH#AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+
MXH"+X9Z*X9Z\X9Z8X9ZXX9Z3X9ZXX9Z`X9^"X9Z3(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHX.`IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O
M=6YT/R!3:6=N('5P+B(*;7-G<W1R("+AGICAGK?AGI/B@(OAGICAGK;AGI/B
M@(OAGH+AGH[AGI/AGKC"H#\@X9Z?X9Z\X9Z8XH"+X9Z%X9Z[X9^'X9Z(X9^2
MX9Z8X9^$X9^'PJ#AGY0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-3@*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(N&>D>&>MN&>
MB>&>F>&>@"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N
M;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$U"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,SD*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B1'EN86UI8R!-86EL
M(@IM<V=S='(@(N&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>D.&>MN&>F.&>
MG.&>D^&?DN&>CR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(N&>HN&?BN&>N.&>F.&?@N&>
MFR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`BX9ZBX9^!X9Z`X9^2
MX9Z<X9ZVX9Z,X9^0X9Z:(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS
M9VED(")%9&ET(@IM<V=S='(@(N&>@.&?@N*`B^&>G^&>F.&?DN&>FN&>O>&>
MFR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@
M(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!0
M97)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO
M;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#`*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("+AGH#AGK;AGIKB
M@(OAGJ+AGI3AGXOAGIKAGX8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*
M;7-G<W1R("+AGJ+AGX'AGJ#AGY+AGI_AGXKAGKCAGI0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(N&>HN&?@N&>F^&>G^&>
MMN&>F^&?B^&>G.&?B>&>MN&>C.&?D.&>FB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE
M;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")%;6%I;"(*;7-G<W1R
M("+AGJ+AGXKAGKCAGICAGX+AGILB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*
M;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`BX9ZBX9ZVX9Z?X9Z9X9Z*
MX9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;(@H*(SH@<V5R=FEC
M97,O8V]N9FER;2YP:'`Z,S`*;7-G:60@(D5M86EL(&%D9')E<W-E<R!H879E
M(&)E96X@;&]C:V5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.3<Q"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"XB"FUS9W-T<B`BX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZB
MX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+
MX9Z*X9Z\X9Z%X9Z"X9^2X9Z3X9ZVPJ#AGY0B"@HC.B!S97)V:6-E<R]C;VYF
M:7)M+G!H<#HR,PIM<V=I9"`B16UA:6P@861D<F5S<V5S('1O(&-O;F9I<FT@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3DW"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y
M-PIM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(N&>G^&>B>&?DN&>B>&>MN*`
MB^&>HN&>MN&>FN&>F.&?DN&>F.&>CN&?C2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R
M=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I
M9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`T"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y
M"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS
M9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,`IM<V=I
M9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(N&>H.&?
MDN&>@N&>N.&>CN&?@>*`B^&>HN&?@>&>@.&?DN&>G.&>MN&>D>&?D.&>FB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`BX9ZBX9^!X9Z:
MX9ZXX9Z1X9^2X9Z:X9ZV(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HU,PHC.B!L:6(O0FQO8VLO;65T87(N<&AP.C0Q
M"FUS9VED(")%<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI\B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O
M;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN
M9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W
M:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B
M"FUS9W-T<B`BX9ZBX9^!X9Z?X9^2X9Z/X9Z\X9Z3X9ZX(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`BX9ZBX9^!X9Z/X9^2X9Z9X9Z\
MX9Z6X9ZX(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")%
M=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`BX9ZBX9ZZX9Z:X9^)X9Z[
MX9Z4(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S
M(@IM<V=S='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`BR#AGZ'AGZ4@
MX9Z3X9ZVX9Z1X9ZX(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM
M<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHY."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y
M(#,P('-E8V]N9',B"FUS9W-T<B`BX9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+
MXH"+(.&?H^&?H"#AGISAGK?AGI/AGK;AGI'AGK@B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z,3`P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@
M-2!M:6YU=&5S(@IM<V=S='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?BR#A
MGZ4@X9Z3X9ZVX9Z1X9ZX(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS
M9W-T<B`BX9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+X9Z`X9Z3X9^2X9Z;
MX9^'XH"+X9Z8X9^)X9^$X9Z$(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$P,PIM<V=I9"`B179E<GD@:&]U<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED
M(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BX9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;
MX9^+X9Z3X9ZVX9Z1X9ZX(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B
MX9Z4X9^2X9Z:X9Z/X9ZWX9Z4X9Z/X9^2X9Z/X9ZW(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-C8*;7-G:60@(D5X
M<&%N9"(*;7-G<W1R("+AGI3AGI/AGY+AGIOAGK;AGIDB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A;F0@4VED96)A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T
M<B`BX9ZBX9^*X9ZWX9Z%X9Z?X9^2X9Z4X9Z\X9Z.X9Z$X9^+X9Z?X9^"X9Z;
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H
M<#HR-#4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HQ,#$*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#D*;7-G:60@(D9A
M:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU,#$@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGJ#AGY+AGISAGXGA
MGH#AGJ'AGH3AGXL@*.&>F.&?B>&>MN&>F^&?B^&>G.&>N.&>CN&>MBDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(N&>@.&?
MA.&?A^&>H.&?DN&>G.&>MN&>HN&?@>&>FN&>O"(*"B,Z(&9R86UE=V]R:R]#
M3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W
M"FUS9VED(")&87@B"FUS9W-T<B`BX9Z1X9Z\X9Z:X9Z?X9ZVX9Z:(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V-0IM<V=I9"`B1F%X97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(N&>@.&>N^&>F.&?DN&>
ME^&?B"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C4*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B
M1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU,@IM
M<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-#`*;7-G:60@
M(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I
M:FDB"FUS9W-T<B`BX9Z@X9^2X9Z<X9ZXX9Z@X9^2X9Z?X9^*X9ZX(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM
M<V=S='(@(N&>K^&>@.&>G^&>MN&>FB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM
M<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`BX9Z(
MX9^2X9Z8X9^$X9^'XH"+X9ZOX9Z`X9Z?X9ZVX9Z:(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDX.`IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Y-`IM<V=I
M9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#@U"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.CDX"FUS9VED(")&:6QT97)S(@IM<V=S='(@(N&>C^&>F.&?DN&>FN&>
MA"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`BX9Z@X9^2
MX9Z<X9ZVX9^&X9Z$X9ZAX9Z$X9^+(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&
M:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-34*;7-G:60@(D9I>"!R871I;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,P"FUS9VED(")&;&EP(@IM<V=S='(@(N&>C^&?DN&>FN&>H>&>E.&?
MBR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(N&>D>&>G^&>E^&>MN&>
M@B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q
M"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR-C`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("+AGI;AGH[A
MGXSB@(OAGI;AGKOAGICAGY+AGI;B@(OAGJ+AGH#AGY+AGI_AGIHB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(D9O;V0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,T-@IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<W"FUS9VED("(B"B)&;W)E
M8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E
M='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H
M97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.30*;7-G:60@(D9O<F=O
M="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")&;W)M<R(*;7-G<W1R("+AGI_AGX;A
MGH[AGKOAGX;B@(OB@(OAGI3AGX+AGI3AGI3AGI$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C8*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C$P-`IM<V=I9"`B1F]R='5N92!T>7!E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I
M9"`B1F]R='5N97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0T"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-CD*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")&
M;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"FUS9VED(")&<F%M97,B"FUS9W-T<B`BX9Z?X9^*X9Z[X9Z8(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(N&>E.&>MN&>FN&>MN&?AN&>
MA"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("+AGJ#AGY+AGH+AGKSAGJ+A
MGXKAGKCAGIGAGXGAGK;AGH[AGK8@X9Z4X9ZVX9Z:X9ZVX9^&X9Z$(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`BX9Z4
MX9^)X9Z\X9Z;X9ZXX9Z3X9^!X9Z?X9^*X9ZXXH"+X9Z4X9ZVX9Z:X9ZVX9^&
MX9Z$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,B"FUS9W-T<B`BX9ZBX9ZVX9Z.X9Z%X9Z`X9^2X9Z:XH"+X9Z!
MX9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$(.&>E.&>MN&>FN&>MN&?AN&>A"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*
M;7-G:60@(D9R;VTB"FUS9W-T<B`BX9Z6X9ZX(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4R"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3@*;7-G
M:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`BX9Z(X9^2
MX9Z8X9^$X9^'XH"+X9Z6X9^!X9Z)(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B
M;VXB"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZVX9Z4X9Z[X9Z$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P
M"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("+AGJ#AGY+AGH#AGK;AGX;A
MGI3AGXKAGK@B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H
M<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL
M.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`BX9Z@X9^2X9Z?X9Z`X9Z@X9^2
MX9Z?X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R
M("+AGJ+AGK;AGIOAGY+AGIOAGKKAGICAGXGAGH3AGXLB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")':&%N82(*;7-G<W1R("+AGJ#AGY+AGH#AGK;AGH[AGK8B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`BX9Z@X9^2X9Z"
MX9ZXX9Z4X9^2X9Z:X9ZVX9Z;X9^+X9Z/X9ZV(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS
M9W-T<B`BX9Z3X9ZVX9Z8X9Z!X9^2X9Z;X9Z]X9Z3(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO
M8F%L($]P=&EO;G,B"FUS9W-T<B`BX9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z?
MX9Z`X9Z;(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@
M(D=O(@IM<V=S='(@(N&>D>&?A2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-0IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(Y"FUS9VED(")';V]G;&4@
M36%P<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q
M"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S8*;7-G:60@(D=R87ES
M8V%L92(*;7-G<W1R("+AGICAGK;AGH_AGY+AGIKAGHKAGY+AGHOAGK;AGI/B
M@(OAGI3AGY+AGIKAGI7AGX'AGX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E
M96-E(@IM<V=S='(@(N&>@.&?DN&>FN&>M^&>@"(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T
M<B`BX9Z`X9^2X9Z:X9ZWX9Z`("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("+AGH+AGY+AGIKAGKCAGJ'AGH3A
MGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(N&>H.&?
MDN&>@N&?DN&>FN&>N.&>CN&>MN&>BN&>MB(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*
M;7-G:60@(D=R;W5P<R(*;7-G<W1R("+AGH#AGY+AGIKAGKOAGI@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(N&>H.&?DN&>@N&>
MO.&>HN&>MN&>BN&>NN&>F^&>O.&>E.&?B>&?@2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")'=6%M(@IM<V=S='(@(N&>H.&?DN&>@N&>MN&?AN&>F"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZV
MX9Z/X9^!X9Z8X9^)X9ZVX9ZAX9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-@IM<V=I9"`B
M1W5E<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE
M82(*;7-G<W1R("+AGJ#AGY+AGH+AGKCAGH[AGX$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZXX9Z.
MX9^!X9Z4X9^*X9ZXX9Z?X9^%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA
M;F$B"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZXX9Z9X9^)X9ZVX9Z.X9ZV(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S
M='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34T"FUS9VED(")(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R("+AGJ#AGX/AGI'AGK@B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG
M;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDR,R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3(U"FUS9VED(")(96%D97(B"FUS9W-T<B`BX9Z4X9Z+X9Z8X9Z`
MX9Z0X9ZVXH"+(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("+AGI3AGHOAGICA
MGH#AGI#AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGJ#A
MGXKAGK[AGHH@X9Z3X9ZWX9Z$(.&>@.&?A.&?A^*`B^&>F.&?B>&>MN&>@.&>
MBN&>O.&>CN&>MN&>F^&?BR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")(96)R97<@
M*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT
M(@IM<V=S='(@(N&>@.&>F.&?DN&>EN&>G^&?BR(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92](96QP+G!H<#HQ.#$@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$X,@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T
M96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R
M("+AGH?AGX;AGI/AGKWAGIDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Y"FUS
M9VED(")(96QP97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<P"FUS9VED(")(:6=H(@IM<V=S='(@(N&>@>&?DN&>EN&>
MG^&?BR(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92DB"FUS9W-T<B`BX9Z@X9Z\X9Z;X9ZXX9Z?X9^*X9ZX
M("CAGIKAGHKAGY+AGHOB@(OAGH#AGY+AGIKAGKOAGH3B@(OAGISAGXGAGK;A
MGI'AGKCAGH#AGH3AGXLI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-34U"FUS9VED(")(;VUE(@IM<V=S='(@(N&>@N&?@>&>H.&>D>&?AN&>
MEN&?D.&>FB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(N&>HN&>MN&>
MG^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>E>&?DN&>D>&?AR(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS
M9W-T<B`BX9Z0X9Z/X9Z5X9^2X9Z1X9^'(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*
M;7-G<W1R("+AGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI'B@(OAGI7AGY+AGI'A
MGX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(N&>
MH.&>N^&>A.&>C.&>O.&>FN&?B>&>MN&>G^&?BR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(N&>H.&>N^&>A.&>@.&>N^&>A"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0V
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@
M:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@
M97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z-3`R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#<S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$Q.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@
M(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L
M('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N
M>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W
M(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#(*;7-G:60@(DAU;6ED
M:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3,*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(N&>H.&>
MN^&>A.&>@N&?DN&>FN&>N"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$W,"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,T
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,CDV"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$W-R!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C0Q"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T
M<B`BX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+($E0(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D
M<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*
M;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(N&>HN&?BN&>N.&>
MG^&?DN&>F^&>A.&?BR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*
M;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`BX9Z/X9^"XH"+X9Z:X9Z\X9Z4
MX9Z/X9^&X9Z.X9ZVX9Z$(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W
M:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL
M("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E
M(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-CD*
M;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(N&>FN&>O.&>
ME.&>E^&>MN&>EB(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E
M9"!F:65L9',Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS
M9W-T<B`BX9Z4X9Z$X9^2X9Z`X9Z^X9Z3XH"+X9Z`X9ZVX9Z:XH"+X9Z%X9Z\
MX9Z;XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("));F1I82(*;7-G<W1R("+AGJ7AGH[AGY+AGHSAGK8B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("+A
MGJ7AGH[AGY+AGHSAGKSAGI/AGX'AGI_AGXKAGK@B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>DR(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@
M(N&>EN&?D.&>C^&?C.&>F.&>MN&>DR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,C(*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?
M;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S
M='(@(N&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>C^&>MN&>FN&>MN&>A"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@
M(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED
M("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM
M<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G
M:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R
M="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("))
M;G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R
M="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O
M('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS
M97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D
M:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<Y"FUS9VED("))
M;G1E9V5R(@IM<V=S='(@(N&>A>&?AN&>D^&>O>&>D^*`B^&>@N&>C^&?BR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S<*;7-G:60@(DEN=&5G
M97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H
M57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D
M871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*
M;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM
M<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,38V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,P-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M
M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W,`IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-`IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-@IM<V=I9"`B26YV86QI9"!P87)T;F5R
M(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38X"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-2!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-3@*;7-G:60@(DEN=F%L:60@<VAA<F4@
M;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@
M861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O
M9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,W,PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(DEN
M=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("+AGJ+AGXKAGKCAGIKAGXGA
MGK;AGH#AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T
M<B`BX9ZBX9^`X9Z:X9ZAX9Z$X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED
M("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DES<F%E;"(*;7-G<W1R("+AGJ+AGXKAGKCAGI_AGY+AGIKAGK;A
MGJ+AGX+AGILB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>
MA>&?@>&>B2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(N&>D>&?DN&>FN&?@>&>
MCR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`BX9ZBX9^*
MX9ZXX9Z/X9ZVX9Z;X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A
M(@IM<V=S='(@(N&>A>&>MN&>F.&?B>&?@^&>@.&>MB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y
M(@IM<V=S='(@(N&>F.&>@.&>FN&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F%P86XB"FUS9W-T<B`BX9Z'X9Z4X9^)X9Z[X9Z3(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#,*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB
M"FUS9W-T<B`BXH"+X9Z'X9Z4X9^)X9Z[X9Z3("A)4T\M,C`R,BU*4"DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S
M='(@(N&>H.&?DN&>G^&?BN&>@.&>BN&>MN&>D^&>N"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM
M<V=S='(@(N&>@.&>@.&?DN&>@.&>BN&>MB(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@
M(N&>F.&>M^&>D.&>N^&>D^&>MB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS
M9W-T<B`BX9Z/X9Z8X9^2X9Z:X9ZYX9Z8XH"+X9Z?X9Z$XH"+X9Z!X9ZVX9Z$
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S
M=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA
M>F%K:'-T86XB"FUS9W-T<B`BX9Z`X9ZVX9Z@X9^2X9Z?X9ZVX9Z`X9^+X9Z?
MX9^2X9Z/X9Z$X9^+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("+AGH#AGX+A
MGI/AGIGAGXGAGK8B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@V"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-PIM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@
M3&5N9W1H(@IM<V=S='(@(N&>E.&?DN&>FN&>G.&?@N&>A.*`B^&>@.&>O.&>
MD^&>G^&?A"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`BX9Z4X9^2X9Z:X9Z7X9^!X9Z1
MXH"+X9Z"X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z%X9Z[X9Z%(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0X"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM
M<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`BX9Z"X9ZWX9Z:X9ZWX9Z4X9ZVX9Z1
MX9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(N*`B^&>@.&>O.&>FN&?B>&?@2`H155#+4M2*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(N&>@N&>N^&>F>*`B^&>G.&?
MB>&?@N&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G
M<W1R("+AGH+AGX#AGIKAGJ#AGY+AGH+AGKCAGI_AGY+AGH_AGH3AGXLB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-0IM
M<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`BX9Z7X9ZVX9Z?X9ZV(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8R(*;7-G<W1R("+AGI_AGK;AGI+AGK;AGIKAGH[AGIKAGHKAGY+AGHOB@(OA
MGI3AGY+AGIKAGH?AGK;AGI+AGK?AGI3AGH_AGX'AGIGAGY+AGIGB@(OAGI3A
MGY+AGIKAGH?AGK;AGICAGK;AGI/AGK?AGH_B@(OAGJ'AGK;AGIPB"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T
M(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U
M87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*
M;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@
M;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F
M<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`BX9ZAX9ZVX9Z/X9Z<
MX9ZXX9Z9X9^)X9ZV(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS
M9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T
M<B`BX9Z4X9^2X9Z;X9Z$X9^+XH"+(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE
M8F%N;VXB"FUS9W-T<B`BX9Z;X9ZXX9Z4X9Z$X9^+(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),
M969T(@IM<V=S='(@(N&>AN&?DN&>G.&?@>&>A"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,3(*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#@*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S
M;W1H;R(*;7-G<W1R("+AGJ'AGX'AGI_AGKSAGH_AGKPB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@
M(N&>@.&>F.&?DN&>FN&>M^&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("+AGIOAGKCAGI3AGX'AGIKAGKCAGIGAGXGAGK8B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS
M9W-T<B`BX9Z%X9ZVX9Z8X9^)X9ZVX9ZBX9^*X9ZWX9Z:X9ZXX9Z9X9^)X9ZV
MXH"+X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+(.&>F^&>N.&>E.&?BN&>N"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("+AGIOA
MGK?AGH7AGI'AGX'AGI/AGI_AGY+AGH_AGX+AGI,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I
M>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I
M9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I
M;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*
M;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@
M4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,`IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@R,@IM<V=I9"`B3&EN:R(*;7-G<W1R("+AGH_AGX;A
MGHXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@S"FUS9VED("),:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S
M='(@(N&>C^&?AN&>CB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@
M2&5L<"!4;W!I8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,#D*;7-G:60@(DQI<W0M07)C
M:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4P-`IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3$Q"FUS9VED("),:7-T
M+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3`W"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`X"FUS9VED("),:7-T
M+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU,#8*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`U"FUS9VED
M("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I
M;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@IM<V=I
M9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("+AGIOAGKCAGI'AGKOAGIGAGJ+AGK;AGI/A
MGK@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(N&>@.&?AN&>EN&>N^&>
MA.*`B^&>E>&?DN&>D>&>N^&>@"XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#4*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A
M;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S<*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(N&>D>&>N.&>C^&>MN&?
MAN&>A"(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C(P,"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.#(*;7-G:60@(DQO9R!I;B(*;7-G<W1R("+AGH7AGKSAGILB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO
M9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*
M;7-G<W1R("+AGH7AGX'AGHDB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(N&>A>&>O.&>FR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S
M='(@(N&>E^&>MN&>FN&>@.&>M^&>A>&?DN&>A>*`B^&>A>&>O.&>FR(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S,*;7-G:60@(DQO
M;F<@=&5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3,*;7-G:60@(DQO=F4B"FUS9W-T<B`BX9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZX
MXH"+X9Z?X9^2X9Z:X9ZAX9ZVX9Z)X9^+(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DQO=R(*;7-G<W1R("+A
MGI'AGK;AGI0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U
M<F<B"FUS9W-T<B`BX9Z;X9Z[X9Z%X9Z@X9^2X9Z?X9^&X9Z4X9Z]X9Z:(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y.0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,W('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3<*;7-G:60@(DU/5$0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B
M35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS
M9W-T<B`BX9Z8X9^)X9ZVX9Z`X9ZVX9Z<(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM
M<V=S='(@(N&>F.&?B>&>MN&>BN&>MN&>H.&?DN&>@.&>MN&>G^&?DN&>@.&>
MMN&>FB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B36%G
M:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDP
M"FUS9VED(")-86EL(@IM<V=S='(@(N&>G^&?AN&>E.&>N^&>C^&?DN&>FB(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,S@*;7-G:60@(DUA:6P@
M061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S
M='(@(N&>F.&?B>&>MN&>H>&>MN&>G.&?@R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36%L87ES:6$B"FUS9W-T<B`BX9Z8X9^)X9ZVX9ZAX9^!X9Z?X9^*X9ZX
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("+AGICA
MGXGAGK;AGIOAGXOAGHSAGKCAGIPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA
M;&DB"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z;X9ZX(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-86QT82(*;7-G<W1R("+AGICAGXGAGK;AGIOAGXOAGH_AGK8B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34T"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-CD*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(N&>F.&>N.&>
MD^&>MB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+AGIKAGKGAGICB
M@(OAGI'AGX;AGI;AGY#AGIHB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$
MX9^'($UA<G-H86QL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E
M(@IM<V=S='(@(N&>F.&?B>&>MN&>FN&>D>&>N.&>D^&>N.&>@B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F
M:65L9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A
M;FEA(@IM<V=S='(@(N&>F.&?B>&>O.&>FN&>N.&>C^&>MN&>D^&>N"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(N&>F.&?B>&>
MO.&>FN&>N.&>D>&>N^&>GR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q.`IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX
M-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C0S"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I
M9"`B36%Y(@IM<V=S='(@(N&>I^&>G^&>E^&>MB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`BX9Z8X9^#X9ZBX9Z\X9Z/X9^!(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")-961I8VEN92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(N&>G^&>F.&>MN&>A^&>M^&>
M@"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@
M;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BX9Z?X9ZV
MX9Z:(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*
M;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF
M:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B
M365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C0R"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-`IM<V=I9"`B(@HB
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.`IM<V=I9"`B365T87)$
M0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("+A
MGISAGK?AGI+AGKCAGI_AGK;AGI_AGY+AGIKAGY+AGH\B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W!H
M<&=W+G!H<#HX.`HC.B!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z.#D@
M9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B365T<FEC(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@
M(N&>F.&?B>&>M^&>A>&>G^&?BN&>M^&>@"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(N&>@.&>CN&?DN&>C^&>MN&>
MFR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X
M"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`BX9Z4X9^2X9Z:X9Z7X9^!X9Z1
M($UI;64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,@IM<V=I9"`B36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$T"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0S.`IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@
M97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,S"FUS9VED(")-:7)R;W(B"FUS9W-T<B`BX9Z&
MX9^2X9Z;X9Z[X9^'(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS
M9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(N&>E>&?DN&>G^&?@>&>A.&?
ME^*`BR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!M=7-T
M(&=E;F5R871E(&ET(&)E9F]R92!U<VEN9R!T:&ES(&%P<&QI8V%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S
M97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-
M86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8Y"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@1&%T
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0*
M;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("+AGICAGXGAGKSAGH[AGK;AGH#A
MGKPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(N&>
MF.&?B>&>N^&>A.&>H.&?DN&>@N&?A.&>F^&>N"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U.3(*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S
M='(@(N&>@>&?@B#AGI/AGK?AGH0@X9Z&X9^2X9Z3X9ZVX9^&(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B
M36]N=&AL>2(*;7-G<W1R("+AGIKAGK;AGIOAGXOB@(OAGH'AGX(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`BX9Z8X9^)X9Z[
MX9Z$X9Z?X9^!X9Z:X9^)X9ZV(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R
M;V-C;R(*;7-G<W1R("+AGICAGXGAGK;AGIKAGXGAGKOAGH`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S
M=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HU,#`*;7-G:60@
M(DUO=F4@1&]W;B(*;7-G<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'A
MGKCB@(OAGH7AGKOAGX?B@(OAGH#AGY+AGIKAGX3AGI@B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C4P-`IM<V=I9"`B
M36]V92!,969T(@IM<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>
MN.*`B^&>D>&?A>*`B^&>AN&?DN&>G.&?@>&>A"(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-3`X"FUS9VED(")-;W9E
M(%)I9VAT(@IM<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`
MB^&>D>&?A>*`B^&>G^&?DN&>C^&>MN&?AB(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#DV"FUS9VED(")-;W9E(%5P
M(@IM<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`B^&>H>&>
MON&>A.*`B^&>F^&>OB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("+AGH7A
MGKOAGX?B@(OAGH#AGY+AGIKAGX3AGI@B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T
M<B`BX9ZAX9Z^X9Z$XH"+X9Z;X9Z^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M;WIA;6)I<75E(@IM<V=S='(@(N&>F.&?B>&>O.&>H.&?DN&>G^&>MN&?AN&>
ME.&?BN&>M^&>@"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.3(*
M;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U
M-@IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3`*;7-G:60@(DUU;'1I<&QE('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#$V"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C8V
M"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C$S-0IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B
MX9Z8X9ZXX9Z9X9^)X9ZVX9Z3X9^+X9Z8X9^)X9ZV(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)
M($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+AGHCAGY+AGICAGX3A
MGX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`BX9Z.
MX9ZVX9Z8X9ZXX9Z4X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R
M=2(*;7-G<W1R("+AGH[AGKSAGIKAGKLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYE<&%L(@IM<V=S='(@(N&>D^&?@>&>E.&?B>&>MN&>F^&?BR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`BXH"+X9Z@X9Z[
MX9Z;X9^2X9Z;X9Z$X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA
M;F1S($%N=&EL;&5S(@IM<V=S='(@(N&>HN&>A.&?B^&>D>&>N.&>F>&?C>*`
MB^&>H.&>O.&>F^&?DN&>F^&>A.&?BR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*
M;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE
M='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O
M8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C<*;7-G:60@
M(DYE='=O<FLB"FUS9W-T<B`BX9Z4X9Z.X9^2X9Z/X9ZVX9Z)(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHY-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S
M='(@(N&>@.&>N^&?AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D
M;VYI82(*;7-G<W1R("+AGI/AGKSAGISAGX+AGIOAGH#AGK;AGIOAGX'AGHKA
MGKSAGI/AGK@B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX
M-`HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M.#@*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C$Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*
M;7-G<W1R("+AGI_AGK;AGIKB@(OAGI#AGY+AGICAGKCB@(OAGI'AGX4@)7,B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`BX9Z3
MX9Z\X9Z<X9^"X9Z;X9Z@X9^*X9^2X9Z?X9^!X9ZAX9Z$X9^+(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O
M<F0B"FUS9W-T<B`BX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$X9ZV
MX9Z/X9^+XH"+X9Z0X9^2X9Z8X9ZX(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S<6PN<&AP.C(T.0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O
M<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D
M;VXG="!M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L
M86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,P-0IM<V=I9"`B3F5W<R(*;7-G<W1R("+AGI;AGY#AGH_AGXSA
MGICAGK;AGI,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(Q"FUS
M9VED(").97=S9W)O=7!S(@IM<V=S='(@(N&>G.&?@>&>D>&>M^&>@.&>MN*`
MB^&>EN&?D.&>C^&?C.&>F.&>MN&>DR(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(N&>E.&>D^&?
MDN&>D>&>MN&>E.&?BR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I
M9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V-R!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R
M("+AGI/AGKCAGH#AGK;AGIKAGXGAGK;AGJ#AGY+AGH+AGY#AGIHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(N&>D^&>N.&>H.&?DN&>
MG^&?@>&>FB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M("+AGI/AGKCAGJ#AGY+AGI_AGX'AGIKAGKCAGIGAGXGAGK8B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<R"FUS9VED(").:6=H="(*;7-G
M<W1R("+AGIGAGI3AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS
M9W-T<B`BX9Z3X9ZXX9Z<(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV-`IM<V=I9"`B3F\B"FUS9W-T<B`BX9Z1X9^!(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S
M"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HW-@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-PHC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(U
M.0IM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<#HV-PIM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38Y(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(P"B,Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4U"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV.3@*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP,PIM
M<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(Q(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$S-0IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38R"FUS9VED(").;R!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE
M<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE
M('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S
M<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY.0IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I
M9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W
M:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N
M=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S8V
M"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@
M(DYO(')U;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@
M9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3,Q"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`@9G)A;65W;W)K+U)00R]24$,O<&AP
M9W<N<&AP.C$W-0IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3@R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P,3`*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B
M3F]N92(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU
M<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@U"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@
M(N&>@.&?A.&?A^*`B^&>CN&?B>&>H.&?DN&>G.&?B>&>@"(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@
M(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`BX9Z`
MX9^$X9^'XH"+X9Z8X9^)X9ZVX9Z:X9^`X9Z.X9ZVXH"+X9Z7X9ZVX9Z"XH"+
MX9Z!X9ZVX9Z$XH"+X9Z'X9Z^X9Z$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M;W)W87DB"FUS9W-T<B`BX9Z3X9^0X9Z:X9Z<X9^"X9Z?(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3@*;7-G:60@(DYO="!A(&1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.CDU"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I
M9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(P."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR-3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V.0HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@U(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS,#$*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S,S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M-C8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-3`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C4Y,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-C8Y"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HX,B!F<F%M97=O
M<FLO5D93+U9&4R]H;W)D92YP:'`Z,3,Q"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VAO<F1E+G!H<#HQ-3$@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3@Y(&9R86UE=V]R
M:R]61E,O5D93+VAO<F1E+G!H<#HR,#<*(SH@9G)A;65W;W)K+U9&4R]61E,O
M:&]R9&4N<&AP.C(R-R!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,S,P
M"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#@U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.#<*;7-G:60@(DYO=&5S(@IM<V=S='(@(N&>A>&?AN&>CN&>MN&?AB(*"B,Z
M('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E
M<B(*;7-G<W1R("+AGISAGK?AGH7AGY+AGH;AGK?AGH#AGK8B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T
M<B`BX9Z;X9^!X9Z!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S
M,PIM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`BX9Z%X9^&
MX9Z3X9Z]X9Z3XH"+X9Z/X9Z]X9ZBX9Z`X9^2X9Z?X9Z:(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,W-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#,Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-3,@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU
M;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-S4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R.0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4Q('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@
M<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R("+AGIGAGIOAGXOAGI;AGY+AGIKAGI@B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<Q
M"FUS9VED(")/8FIE8W0B"FUS9W-T<B`BX9Z<X9Z/X9^2X9Z0X9Z[(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#
M<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,#@*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM
M<V=S='(@(N&>C^&>N^&>F^&>MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-PIM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,@IM<V=I9"`B3V9F:6-E(@IM<V=S
M='(@(N&>@.&>MN&>FN&>M^&>F>&>MN&>F^&?D.&>F2(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S
M<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R
M9"(*;7-G<W1R("+AGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;A
MGH_AGXOB@(OAGH7AGK;AGI_AGXLB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S
M='(@(N&>HN&>O.&>F.&?@N&>DR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S
M=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,3`P"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T
M=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#4Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-SD*;7-G:60@(D]N;'D@
M;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O
M=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R
M<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO
M:69R86UE+G!H<#HT,`IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`BX9Z4X9Z^X9Z`XH"+XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+XH"+X9Z4
MX9Z$X9^2X9ZBX9Z]X9Z%XH"+X9Z0X9^2X9Z8X9ZX(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L
M:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3@*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T
M<B`BX9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z4X9^2X9Z:X9Z/X9ZW
MX9Z4X9Z/X9^2X9Z/X9ZWX9Z`X9ZVX9Z:(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("+AGH?A
MGICAGY+AGIKAGK[AGI_B@(LB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S(@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R
M9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM
M<V=I9"`B3W1H97(B"FUS9W-T<B`BX9Z5X9^2X9Z?X9^!X9Z$X9^7(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C@P"FUS9VED(")004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS
M9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET
M86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG
M;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*
M;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%)A:6XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,SD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-
M(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,@IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!4+5-T;W)M<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED
M(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("+AGH7AGI/AGY+AGIOAGX3A
MGX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(N&>
ME.&?B>&>MN&>@N&>N.&>G^&?DN&>D.&>MN&>DR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!A;&%U(@IM<V=S='(@(N&>E.&?B>&>MN&>H>&>O"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS
M9W-T<B`BX9Z4X9^)X9ZVX9Z.X9ZVX9Z8X9^)X9ZV(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(N&>E.&?B>&>MN&>
MEN&>O.&>B>&>O.&>G.&>H.&?DN&>@N&>N.&>CN&?@2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(N&>E.&?B>&>MN&>FN&?B>&>
MMN&>H.&?DN&>@N&>MN&>F2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C8*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV.2!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,SD*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(N&>EN&>MN&>@.&?DN&>F>*`
MB^&>G^&>F.&?DN&>A.&>MN&>C^&?BR(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3<*
M;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P-C$*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I
M9"`B4&%S<W=O<F0Z(@IM<V=S='(@(N&>EN&>MN&>@.&?DN&>F>*`B^&>G^&>
MF.&?DN&>A.&>MN&>C^&?B\*@X9^6(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-#(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I
M9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("+A
MGI3AGK?AGI'AGI?AGY+AGH?AGK;AGI3AGXLB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M
M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(N&>
ME>&?DN&>F^&>O.&>G"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(N&>F.&>D^&>N^&>G^&?DN&>GR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@
M(N&>E^&>MN&>@N&>FN&>F2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/R(*;7-G<W1R("+AGI+AGY+AGISAGK[B@(OAGI3AGY+AGIKA
MGH_AGK?AGI3AGH_AGY+AGH_AGK?AGH#AGK;AGIKB@(OAGH_AGX;AGJ#AGX+A
MGI'AGK;AGX8@X9Z6X9^!X9Z;XH"+X9Z%X9Z\X9Z;(#\B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*
M;7-G<W1R("+AGI_AGK?AGI'AGY+AGI+AGK<B"@HC.B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@
M7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E
M<FUI<W-I;VYS(@IM<V=S='(@(N&>G^&>M^&>D>&?DN&>DN&>MR(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM
M<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`BX9Z6X9^0X9Z/
MX9^,X9Z8X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;
MX9Z]X9Z3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(N&>
ME.&?B>&?@>&>FN&?B>&>O"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,`IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!H:6QI<'!I;F5S(@IM<V=S='(@(N&>H.&?DN&>G.&>N.&>F^&>N.&>EN&>
MN.&>DR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(N&>D>&>O.&>FN&>G^&?D.&>
MEN&?DN&>D2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.30*;7-G
M:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0
M:71C86ER;B(*;7-G<W1R("+AGI;AGKCAGH_AGH'AGK;AGIGAGIKAGK?AGI,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(N&>E^&>N.&>@.&>G^&?@N&>FR(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4&QA=&ET=61E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S
M;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<P"FUS9VED(")0;&5A<V4@
M96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D
M87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0U-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@
M=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H
M92!P<F]B;&5M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I
M9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T
M96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M;VQA;F0B"FUS9W-T<B`BX9Z4X9^)X9Z\X9ZAX9Z\X9Z)(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`S"FUS9VED(")0;VQL
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*
M;7-G<W1R("+AGI;AGY#AGIKAGI'AGKOAGIGAGJ#AGY+AGH+AGK;AGIOAGXLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W."!L:6(O0FQO8VLO;65T87(N<&AP.C(X,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDQ
M"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HQ,S,*;7-G:60@
M(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(N&>G^&>F.&?DN&>EN&>MN&>DB(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"FUS9VED(")0<F5S<W5R92!A="!S
M96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(Y"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(N&>F.&>ON&>F^*`B^&>
MA^&>MN*`B^*`B^*`B^&>F.&>N^&>DR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4W(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8Q"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B
M4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X-0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`BX9Z"X9Z8X9^2X9Z:
MX9^$X9Z$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#<*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B
M;&EC($ME>2(*;7-G<W1R("+AGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;AGI+A
MGK;AGIKAGH[AGX@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G
M:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@
M(N&>EN&?D.&>FN&>C^&>O.&>FN&>N.&>@.&>O"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E%A=&%R(@IM<V=S='(@(N&>@.&>MN&>C^&>MB(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`BX9Z?X9^&
MX9Z.X9Z]X9Z:XH"+(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS
M9VED(")1=6]T82(*;7-G<W1R("+AGH#AGKSAGH_AGK8B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C<R"FUS9VED(")2861I;R!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A
M:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM
M<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@86YD(%-N
M;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<V"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("+A
MGJ+AGK;AGI,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2
M969R97-H(@IM<V=S='(@(N&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>
MG^&?DN&>FN&>G^&?BR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*
M;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R
M97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.30*;7-G:60@(E)E9G)E<V@@<F%T93HB"FUS9W-T
M<B`BX9ZBX9Z/X9^2X9Z:X9ZVXH"+X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9
MXH"+X9Z?X9^2X9Z:X9Z?X9^+PJ#AGY8B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0R"FUS9VED
M(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`BX9Z5X9^2X9Z1X9Z[
MX9Z`XH"+X9ZAX9Z^X9Z$XH"+X9Z<X9ZWX9Z)(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,S@*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`BX9Z`X9^&X9Z.
MX9Z/X9^+XH"+X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED
M(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS
M9W-T<B`BX9Z9X9Z`XH"+X9Z%X9^!X9Z)(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B
M4F5M;W9E('!A:7(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM
M<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B
M4F5M;W9E('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U
M<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C$S."!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z,3<S"FUS
M9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E
M<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34P"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N
M;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3<V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-S`T(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#8Q"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HT,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,T
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-#,*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$Y('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`BX9Z`X9^&X9Z.
MX9Z/X9^+XH"+X9ZAX9Z^X9Z$XH"+X9Z<X9ZWX9Z)(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS
M9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD
M<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S
M=6QT<R(*;7-G<W1R("+AGIOAGI'AGY+AGI+B@(OAGI7AGILB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(N&>
MC^&?DN&>FN&>H>&>E.&?B^*`B^&>D>&?A>*`B^&>A^&>F.&?DN&>FN&>ON&>
MGR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B
M4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")2975N:6]N(@IM<V=S='(@(N&>FN&>N.&>HN&>N^&>F>&>D^&>
MN.&>F>&?B>&>N^&>A"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I
M9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B4FED9&QE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(N*`B^&>
MG^&?DN&>C^&>MN&?AB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,30*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$P"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("+AGH_AGKWAGI/AGK;AGI'A
MGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(N&>
MFN&>O.&>F.&?B>&>MN&>D^&>N"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C0*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R,0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z<
MX9ZWX9Z;XH"+X9Z1X9^%XH"+X9Z&X9^2X9Z<X9^!X9Z$(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-PIM<V=I9"`B4F]T
M871E(%)I9VAT(@IM<V=S='(@(N&>E.&>A.&?DN&>G.&>M^&>F^*`B^&>D>&?
MA>*`B^&>G^&?DN&>BN&>MN&?AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T
M:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("+AGH?AGKWAGIKB@(OA
MGHKAGX'AGH#"H.&?EB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O
M=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I
M9"`B4G5N(@IM<V=S='(@(N&>FN&>C^&?B^*`BR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("+AGI_AGJ#AGI;A
MGY#AGI/AGY+AGI+B@(OAGIKAGKOAGI_AGY+AGI_AGXKAGK@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`BX9Z:X9Z<X9^)X9ZVX9Z3
MX9^+X9Z*X9ZV(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#(*;7-G:60@
M(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,`IM<V=I9"`B
M4TU3($UE<W-A9VEN9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")344P@<W1A=&5M96YT(&9O
M<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-#<*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS
M9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN
M="!(96QE;F$B"FUS9W-T<B`BX9Z?X9Z$X9^+XH"+X9Z@X9^!X9ZAX9^!X9Z.
MX9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V
M:7,B"FUS9W-T<B`BX9Z?X9Z$X9^+X9Z#X9ZXX9Z/(.&>D^&>M^&>A"#AGI/A
MGX'AGISAGKCAGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA
M(@IM<V=S='(@(N&>G^&>A.&?B^&>F^&>O.&>G^&?BN&>N.&>F>&?B>&>MB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VXB"FUS9W-T<B`BX9Z?X9Z$X9^+XH"+X9Z6X9^2X9Z9X9^"X9Z:(.&>D^&>
MM^&>A"#AGICAGKCAGH+AGKOAGIGAGJ+AGX'AGJ'AGKOAGH0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<R(*;7-G<W1R("+AGI_AGH3AGXOAGISAGK;AGX;AGH3AGI_AGH3AGXL@X9Z3
MX9ZWX9Z$(.*`B^&>H.&?DN&>@N&?DN&>FN&>N.&>CN&>MN&>C.&>N.&>DR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*
M;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("+AGI_AGK;AGICAGKSAGJ+A
MGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@
M(N&>G^&>MN&>D^&?B^&>F.&?B>&>MN&>FN&>N.&>CN&>O"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S
M='(@(N&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>E.&?BN&>N.&>G^&>MN&>
MHN&>O.&>C.&>N"(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ
M,34*;7-G:60@(E-A=F4B"FUS9W-T<B`BX9Z:X9Z`X9^2X9Z?X9ZVXH"+XH"+
MX9Z1X9Z[X9Z`XH"+XH"+(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*
M;7-G<W1R("+AGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(L@X9Z'X9Z8
MX9^2X9Z:X9Z^X9Z?(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM
M<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4V-A='1E<F5D(%0M4W1O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM
M<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(N&>G^&?DN&>G.&?@N&>A.&>
MFN&>@"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S8*;7-G:60@
M(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(N&>F.&?B>&>MN&>G^&?BN&>N.&>
MD^*`B^&>G^&?DN&>G.&?@N&>A.&>FN&>@"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y-C8*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@S
M"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(N&>A^&?DN&>FN&>ON&>
MG^*`B^&>@.&>MN&>F^&>E.&>FN&>M^&>A>&?DN&>AN&?@>&>D2(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B
M4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<T"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(N&>A^&?DN&>
MFN&>ON&>G^*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?BR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-30*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#<Q"FUS9VED(")396QE8W0@86X@;V)J96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S4*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(N&>A^&?
MDN&>FN&>ON&>G^*`B^&>@N&?DN&>F.&>MN&>DR(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S
M('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@
M8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU
M.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,`IM<V=I
M9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V5N96=A;"(*;7-G<W1R("+AGI_AGX'AGH[AGX'AGJ#AGY+AGH+AGK;AGIOA
MGXLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R.`IM<V=I9"`B4V5N<V]R
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("+AGH#AGHGA
MGY+AGHGAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(N&>
MG^&?@N&>E.&?BN&>N"#AGI/AGK?AGH0@X9Z8X9^)X9Z[X9Z$X9Z/X9^!X9Z.
MX9^!X9Z@X9^2X9Z`X9^2X9Z:X9Z\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T
M<B`BX9Z;X9^!X9Z!XH"+X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-`IM<V=I9"`B4V5R=F5R(&1A
M=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S
M='(@(N&>G^&>F.&?D.&>F2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,C(*;7-G:60@(E-E="(*;7-G<W1R("+AGH#AGX;AGH[AGH_AGXLB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q
M"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L
M87D@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`BX9Z*X9^&X9ZAX9Z^X9Z$
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G
M:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X,`IM<V=I9"`B
M4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE
M<R(*;7-G<W1R("+AGI_AGKCAGI_AGY+AGJ#AGX+AGILB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3$R"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I
M9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T
M<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U
M<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I
M;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-S,*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-@IM<V=I
M9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@
M8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W,0IM<V=I9"`B4VAO=R!U<&QO860B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E
M<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-`IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M-S$*;7-G:60@(E-H<FEN:R(*;7-G<W1R("+AGI3AGH3AGY+AGIKAGKWAGHDB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C<V,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C@R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$P,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#<U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3$P-`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,S<*;7-G:60@(E-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@
M3&5O;F4B"FUS9W-T<B`BX9Z?X9^!X9Z:X9^)X9ZVX9ZAX9^!X9ZBX9Z\X9Z3
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-PIM<V=I
M9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(N&>
MH.&>C^&?DN&>D.&>F^&?@>&>@>&>MB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*
M;7-G<W1R("+AGI_AGKGAGH3AGY+AGJ#AGI3AGKOAGIKAGK@B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,#`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C0Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR,PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$V"FUS9VED(")3:7IE(@IM<V=S='(@
M(N&>D>&?AN&>H.&?AB(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@
M(N&>G^&?DN&>F^&>O.&>G.&?B>&>MN&>@N&>N"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(N&>G^&?DN&>F^&>O.&>G.&?B>&>
MMN&>D^&>N"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4U"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED
M(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO
M=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDP"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGI_AGKSAGJ'AGKSA
MGICAGXGAGKSAGI,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM
M<V=S='(@(N&>G^&>O.&>F.&?B>&>MN&>F^&>N"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-0IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$Y"FUS9VED(")3;W)T
M(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3
M;W5R8V4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`BX9ZBX9ZVX9Z@X9^2X9Z:X9ZWX9Z`
MXH"+XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M
M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S
M='(@(N&>H.&?DN&>G^&>@.&>H.&?DN&>G^&?BN&>N.*`B^&>@>&>MN&>A.*`
MB^&>C^&?DN&>E.&>O.&>A"#AGI/AGK?AGH0@X9Z`X9^$X9^'X9Z?X9ZVX9^&
MX9Z$X9Z<X9ZWX9Z%XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,3D*
M;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B
M"FUS9W-T<B`BX9Z"X9Z8X9^2X9Z;X9ZVX9Z/(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A
M8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B4W!A:6XB"FUS9W-T<B`BX9ZBX9^!X9Z?X9^)X9^2X9Z4X9ZVX9Z)(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-PIM<V=I9"`B4W!A;2(*
M;7-G<W1R("+AGI_AGK;AGIKB@(OAGJ7AGH_B@(OAGI3AGK;AGI/B@(OAGH#A
MGK;AGIHB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P
M96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@
M(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L
M=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*
M;7-G<W1R("+AGI_AGY+AGIKAGKCAGIOAGH3AGY+AGH#AGK8B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S$@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX-@IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`BX9Z!X9^2X9Z3X9ZVX9Z/
MXH"+X9Z"X9^&X9Z:X9Z\(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8W
M"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`R
M"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V
M:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(N&>G^&?DN&>D.&>
MMN&>D^&>E^&>MN&>EB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,#@*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@
M061D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S
M='(@(N&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>AN&>O.&>CR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*;7-G:60@(E-T<FEN9R!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X.#$*
M;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@
M(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+AGI3A
MGY+AGIKAGI+AGK;AGI/B@(OAGI3AGI$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S8@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S$V"FUS9VED(")3=6)M:70B"FUS9W-T<B`BX9Z*X9ZVX9Z`X9^+XH"+X9Z?
MX9^2X9Z3X9Z^(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H
M92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q
M=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B
M<V-R:7!T(@IM<V=S='(@(N&>HN&>@.&?DN&>G^&>FN*`B^&>C^&>O.&>A>*`
MB^&>@.&?DN&>FN&?A.&>F"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+AGH?A
MGX3AGH+AGH?AGY#AGIDB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E
M9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K
M=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('=R;W1E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U
M9&%N(@IM<V=S='(@(N&>G^&?BN&>O.&>BN&>A.&?BR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@
M(E-U;6UA<GDB"FUS9W-T<B`BX9Z?X9Z$X9^2X9Z!X9^!X9Z4(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3
M970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C`*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3`*;7-G:60@(E-U;G)I<V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`Y"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q,PIM<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E-U;G-E=#H@
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(N&>HN&>
M@.&?DN&>G^&>FN*`B^&>C^&>O.&>A>*`B^&>F^&>OB(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.30*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B
MX9Z"X9ZVX9^&X9Z1X9^2X9Z:(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R
M:6YA;64B"FUS9W-T<B`BX9Z?X9^*X9Z\X9Z:X9ZXX9Z.X9ZVX9Z8X9ZX(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@
M(E-U<FYA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A
M;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("+AGI_AGY+AGISAGK;AGIOA
MGXOAGI3AGK;AGH\@X9Z3X9ZWX9Z$(.&>H.&?DN&>G^&>A.&?B^&>F.&?B>&>
MMN&>F>&?@>&>DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R("+AGI_AGY+AGISAGK;AGJ#AGY+AGI_AGXKAGKCAGJ'AGH3AGXLB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`BX9Z?X9^*
MX9Z[X9Z9X9ZBX9^"X9Z*(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L
M86YD(@IM<V=S='(@(N&>G^&?DN&>G.&?BN&>N.&>GR(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G
M:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N
M($%R86(@4F5P=6)L:6,B"FUS9W-T<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:
MX9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+(.&>G^&?BN&>N.&>
MFN&>N"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Q"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M(&%N
M9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G
M:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"FUS9VED(")4
M86)L92(*;7-G<W1R("+AGH_AGK;AGIKAGK;AGH0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")4
M86)L92!0<F]P97)T:65S(@IM<V=S='(@(N&>F^&>@.&?DN&>@>&>CN&?B.*`
MB^&>G^&>F.&?DN&>E.&>C^&?DN&>C^&>M^*`B^&>C^&>MN&>FN&>MN&>A"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*
M;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L
M92!P<F]P97)T:65S(@IM<V=S='(@(N&>F^&>@.&?DN&>@>&>CN&?B.*`B^&>
MG^&>F.&?DN&>E.&>C^&?DN&>C^&>M^*`B^&>FN&>E.&>G^&?B^*`B^*`B^&>
MC^&>MN&>FN&>MN&>A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A
M:7=A;B(*;7-G<W1R("+AGH_AGX/AGISAGXGAGK;AGI/AGXLB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N
M+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(N&>C^&>MN&>BN&>H.&?DN&>
MG^&?BN&>N.&>@N&>N.&>G^&?DN&>C^&>A.&?BR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`W,"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS
M9VED(")487-K<R(*;7-G<W1R("+AGI?AGK;AGIKAGH#AGK?AGH7AGY+AGH4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I
M9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("+AGIOAGX'AGH'B@(OAGI'A
MGKSAGIKAGI_AGY#AGI;AGY+AGI$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P,@IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C8*;7-G:60@(E1E;7!E<F%T=7)E
M(@IM<V=S='(@(N&>G^&>N.&>C^&>N^&>CN&?DN&>H.&>E^&>MN&>EB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3<*;7-G:60@(E1E;7!E
M<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T
M92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*
M;7-G:60@(E1E>'0B"FUS9W-T<B`BX9ZBX9Z/X9^2X9Z0X9Z4X9Z1(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM
M<V=S='(@(N&>C^&?@N&>HN&>C^&?DN&>D.&>E.&>D2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@
M(E1E>'0@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`BX9Z0X9^#(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C8S"FUS9VED(")4:&4@
M2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G
M(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G
M:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B
M(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@
M8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE
M(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED
M("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@
M9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+V-O;F9I<FTN<&AP.C(X"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!E;6%I;"!A9&1R97-S("5S(&AA<R!B965N(&%D9&5D('1O('EO=7(@
M:61E;G1I=&EE<RX@66]U(&-A;B!C;&]S92!T:&ES("(*(G=I;F1O=R!N;W<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$V
M"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3<P(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R.0IM<V=I9"`B5&AE(&9I;&4@
M8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C
M;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO
M=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N
M(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE
M="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E
M<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N
M8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO
M;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R
M('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y
M;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD
M(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@
M4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T
M:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,3(P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N
M=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B
M"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I
M=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X.#4*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI
M;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z.30*;7-G:60@(E1H92!N97<@9G)O;2!A9&1R97-S
M(&-A;B=T(&)E('9E<FEF:65D+"!T<GD@86=A:6X@;&%T97(Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@
M(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R
M"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A
M=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@
M86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#<*;7-G:60@(E1H
M92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E
M(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,Q,PIM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO
M="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H
M92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S
M=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP
M:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@
M(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4T(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34*;7-G:60@(E1H92!W96%T:&5R
M+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C;VYF:7)M+G!H<#HQ-R!S97)V:6-E<R]C;VYF:7)M
M+G!H<#HR,0IM<V=I9"`B5&AE<F4@87)E(&YO(&5M86EL(&%D9')E<W-E<R!T
M;R!C;VYF:7)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HS-#4*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N
M<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES
M=&5M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN
M9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@
M)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HY,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.3$W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T(@IM<V=S='(@(N&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>N^&>G^*`
MB^&>F.&>O>&>F2#AGH#AGY+AGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OAGI3A
MGH3AGY+AGJ#AGK;AGHGB@(OAGI7AGY+AGI/AGX+AGH#B@(OAGIKAGI3AGI_A
MGXOB@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I
M96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$S.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E
M=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N
M(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V,0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DP(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8P"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-38U(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X
M-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,CD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S@Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(T"FUS9VED(")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,C0*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.3@*;7-G:60@(E1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#(Y"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E
M96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A
M8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W
M87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D
M(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA
M8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@
M(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DT"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A
M8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM
M<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z,3@R"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R
M96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@
M8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@
M(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U,`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#,S('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R("+AGI;AGX'AGIOB@(OAGISA
MGX'AGIOAGK;B@(LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R
M"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HR,@IM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`BX9Z1
MX9^2X9Z:X9Z$X9^+XH"+X9Z1X9^2X9Z:X9ZVX9Z9XH"+XH"+XH"+XH"+X9Z6
MX9^!X9Z;XH"+XH"+X9Z<X9^!X9Z;X9ZVXH"+(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS
M9W-T<B`BX9Z%X9^&X9Z.X9Z$XH"+X9Z'X9Z^X9Z$(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@
M*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("+AGI'A
MGX4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C4R"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*
M(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`S"FUS9VED(")4;V1A>2(*;7-G<W1R("+AGI#A
MGY+AGH3AGX/B@(OAGI/AGX'AGX<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R
M8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G
M<W1R("+AGH_AGKSAGJ#AGY+AGH+AGX0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VME;&%U(@IM<V=S='(@(N&>C^&>O.&>@.&?@>&>H>&>MN&>HN&?BN&>
MO"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#4*;7-G:60@
M(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O
M;F=A(@IM<V=S='(@(N&>C^&>N^&>A.&>H.&?DN&>@N&?A"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&]P(@IM<V=S='(@(N&>@.&?AN&>EN&>O.&>FR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F
M<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8X"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("+A
MGI'AGY+AGIKAGKCAGI/AGKCAGHKAGK;AGHH@X9Z3X9ZWX9Z$XH"+XH"+(.&>
MC^&>O.&>E.&>MN&>H.&?DN&>@N&?A"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W.3@*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N
M:7-I82(*;7-G<W1R("+AGI'AGKOAGIGAGH[AGX'AGI_AGXKAGK@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`BX9Z1X9Z]X9Z:X9Z"
MX9ZX(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(E1U<FMI
M<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(N&>D>&>O>&>FN&>@N&>N"`H25-/
M+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB
M"FUS9W-T<B`BX9Z1X9Z]X9Z"X9Z8X9^!X9Z3X9ZXX9Z?X9^2X9Z/X9Z$X9^+
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>D>&>O>&>@"#AGI/AGK?AGH3B
M@(L@X9Z`X9^#X9Z`X9Z\X9Z?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V
M86QU(@IM<V=S='(@(N&>D>&>N^&>F>&>G.&?B>&>MN&>F^&>N^&>F2(*"B,Z
M(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C
M:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8S"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U
M<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(N&>HN&?
MBN&>O.&>H.&?DN&>@N&>A.&?B^&>BN&>MB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5K<F%I;F4B"FUS9W-T<B`BX9ZBX9^*X9Z[X9Z9X9Z`X9^2X9Z:X9^"
MX9Z3(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#(R"FUS9VED
M(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS.34@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDX(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`V,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,`IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S-2!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-#`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,3<*;7-G:60@(E5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C0@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,CDP
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(W-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(R."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T,2!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q.`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U-B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T-R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#0S(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,3,@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HS,30*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,T"FUS9VED(")5;F%B;&4@
M=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE
M=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`V
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<T(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-C4R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#$@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z.#8*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,30P(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW
M-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G
M:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@U-@IM<V=I9"`B56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@X-PIM<V=I9"`B
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C<Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,U
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(W,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C(P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E
M<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS-#D@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3@Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR.3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,34Q
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V,@IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`BX9Z"X9Z\
MX9Z?XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z`X9^2X9Z:X9^$X9Z8
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#
M:&%N9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED
M(")5;F9I;&5D(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>E.&>MN&>D^*`B^&>
MFN&?@.&>E.&>A>&?AB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS
M9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`BX9Z9X9Z\X9Z3X9ZXX9Z`
MX9Z\X9Z*("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R
M86(@16UI<F%T97,B"FUS9W-T<B`BX9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+XH"+
MX9Z:X9Z]X9Z8(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O
M;2(*;7-G<W1R("+AGH7AGH#AGY+AGIKB@(OAGI?AGI;B@(OAGJ+AGH3AGXOA
MGH+AGY+AGIOAGX'AGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@
M4W1A=&5S(@IM<V=S='(@(N&>G^&>H.&>FN&>BN&?DN&>B^&>HN&>MN&>F.&?
M@>&>FN&>M^&>@"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX?B
M@(OAGH;AGY+AGH3AGK;AGIGAGY?B@(OAGIKAGI3AGI_AGXOB@(OAGI_AGJ#A
MGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGICAGX'AGIKAGK?AGH`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,PIM<V=I9"`B56YI=',B"FUS9W-T<B`BX9ZOX9Z`X9Z/X9ZV(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0S,`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(N&>
MF.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?BR(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK
M;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U,@IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(N&>@N&?
MDN&>F.&>MN&>D^*`B^&>B.&?DN&>F.&?A.&?AR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B
M56YS970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY
M,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@
M(N&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>D>&>MN&>D^&?B^*`B^&>
MG^&>F.&?D.&>F2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G
M:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS
M9W-T<B`BX9Z5X9^2X9Z1X9Z[X9Z`XH"+X9ZAX9Z^X9Z$(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(N&>
MHN&?BN&>N^&>F>&>FN&?B>&>MN&>H.&?DN&>@N&>MN&>F2(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM
M<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OB(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S8W"B,L('!H<"UF;W)M
M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z"X9^2X9Z:
MX9Z4X9^+X9Z"X9^2X9Z:X9Z$XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:
MX9Z^(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*;7-G
M:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C8R
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!S:6=N
M=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C0@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S
M97)N86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?A^*`B^&>HN&?DN&>D^&>
M@.*`B^&>E.&?DN&>FN&>OB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HQ,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M("+AGHCAGY+AGICAGX3AGX?B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKA
MGK["H.&?EB(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G
M:60@(E5S97)N86UE.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*
M;7-G<W1R("+AGJ+AGXKAGKSAGJ#AGY+AGI_AGI3AGX'AGH+AGKCAGI_AGY+A
MGH_AGH3AGXLB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S,@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3(W"FUS9VED(")686-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-S`*;7-G:60@(E9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A
M;&ED:71Y(@IM<V=S='(@(N&>G^&>N^&>EN&>F^&>E^&>MN&>EB(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(W-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S
M(@IM<V=S='(@(N&>C^&>F.&?DN&>F^&?@R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y-`IM
M<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`BX9Z<X9^)X9ZVX9Z3
MX9Z[X9Z9X9ZBX9ZVX9Z1X9Z[X9Z9(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S.`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`BX9ZBX9Z0
MX9^!X9Z:(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S
M='(@(N&>G.&?@>&>CN&?@>&>H.&?DN&>G^&>N^&>F>&>HN&?@>&>H>&>MB(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED
M(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS
M9W-T<B`BX9Z`X9^&X9Z.X9^"(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(T,@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(N&>@.&>
MMN&>FN*`B^&>C^&?DN&>FN&>O>&>C^*`B^&>EN&>M^&>D^&>M^&>C^&?DN&>
MF>*`B^&>@.&?AN&>CN&?@B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")697)Y($AI9V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E9I
M971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@)7,B"FUS9W-T<B`BX9Z8X9Z^X9Z;("5S(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G
M:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGISAGKCA
MGH?AGKCAGI,@X9Z?X9Z@X9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z8X9^!X9Z:
MX9ZWX9Z`(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E9I
M<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U-PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@
M(N&>G.&?B>&>MN&>F^&>N.&>GR#AGI/AGK?AGH0@X9Z@X9^2X9Z<X9^*X9Z\
MXH"+X9Z1X9Z[X9Z9X9Z.X9ZV(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C0@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(N&>EN&?
MDN&>FN&>F.&>MN&>DR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-`IM<V=I9"`B5V5A=&AE<B!&;W)E
M8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#$Y"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"FUS9VED(")7
M96%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(N&>G.&>M^&>E"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(E=E8B!3:71E(@IM<V=S
M='(@(N&>C^&?AN&>E.&>D^&?B^&>E.&>CN&?DN&>C^&>MN&>B2(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@
M(E=E96ML>2(*;7-G<W1R("+AGIKAGK;AGIOAGXOB@(OAGI_AGI3AGY+AGHKA
MGK;AGJ#AGXTB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM
M<V=I9"`B5V5L8V]M92(*;7-G<W1R("+AGI_AGKSAGICB@(OAGI_AGY+AGISA
MGK;AGH+AGICAGI/AGXTB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+AGI_AGKSAGICB@(OA
MGI_AGY+AGISAGK;AGH+AGICAGI/AGXWB@(OAGICAGH#B@(OAGH#AGK;AGI/A
MGXL@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5V5L8V]M92P@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E
M<W1E<FX@4V%H87)A(@IM<V=S='(@(N&>G^&>MN&>H.&>MN&>FN&?B>&>MN*`
MB^&>@>&>MN&>A.*`B^&>F^&>M^&>A2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@
M:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8R"FUS9VED(")7:&5R96ES
M($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T
M;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("+AGI'AGI'AGKGAGH3B@(LB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$X"FUS9VED(")7:61T
M:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I
M9"`B5VED=&@Z(@IM<V=S='(@(N&>D>&>D>&>N>&>A"#AGY8B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(Y"FUS9VED(")7:6MI(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C<*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V.`IM<V=I
M9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV.0IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3(*;7-G:60@(E=I<VAL
M:7-T(@IM<V=S='(@(N&>E.&>B>&?DN&>A^&>N.*`B^&>E.&?DN&>FN&>MN&>
MD.&?DN&>D^&>MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HW,`IM<V=I
M9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R
M("+AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGH#AGI/AGY+AGIOA
MGX+AGH3B@(OAGI+AGY+AGISAGK[B@(OAGH#AGK;AGIHB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K
M(%!H;VYE(@IM<V=S='(@(N&>D>&>O.&>FN&>G^&?D.&>EN&?DN&>D>*`B^*`
MB^*`B^&>@.&>D^&?DN&>F^&?@N&>A.*`B^*`B^*`B^&>DN&?DN&>G.&>ON&>
M@.&>MN&>FB(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E
M8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A
M9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4Y"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT
M96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+
M97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9
M(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4T"FUS9VED(")965E9(@IM<V=S='(@(EE965DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.0IM<V=I
M9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T
M<B`BX9Z4X9^2X9Z:X9Z%X9ZVX9^&X9Z&X9^2X9Z3X9ZVX9^&(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`BX9Z9X9^!X9Z8X9^"X9Z3
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV
M-`IM<V=I9"`B665S(@IM<V=S='(@(N&>E.&>MN&>D2_AGH7AGK;AGI\B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(U"FUS
M9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P.`IM<V=I9"`B
M66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<&AP
M9W<N<&AP.C$Q-PIM<V=I9"`B66]U(&1I9"!N;W0@875T:&5N=&EC871E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#,*;7-G:60@(EEO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX
M-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,W,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@:&%V92!R97%U97-T960@=&\@861D
M('1H92!E;6%I;"!A9&1R97-S(%PB)7-<(B!T;R!T:&4@;&ES="!O9B!Y;W5R
M("(*(G!E<G-O;F%L(&5M86EL(&%D9')E<W-E<RY<;B(*(EQN(@HB1V\@=&\@
M=&AE(&9O;&QO=VEN9R!L:6YK('1O(&-O;F9I<FT@=&AA="!T:&ES(&ES(')E
M86QL>2!Y;W5R(&%D9')E<W,Z7&XB"B(E<UQN(@HB7&XB"B))9B!Y;W4@9&]N
M)W0@:VYO=R!W:&%T('1H:7,@;65S<V%G92!M96%N<RP@>6]U(&-A;B!D96QE
M=&4@:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L
M;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G
M*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3DR"FUS
M9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G
M:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-#<T"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@
M8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E
M(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ
M(&%D9')E<W,Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B
M66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.
M86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?A^*`B^&>FN&>E.&>G^&?B^&>
MHN&?DN&>D^&>@"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*
M(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L
M+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3(V
M"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E
M9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M
M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY
M"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"FUS
M9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R
M(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I
M<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T
M<B`BX9Z9X9Z\X9Z@X9^2X9Z"X9^$X9Z?X9^2X9Z;X9ZVX9Z<X9ZX(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B
M"FUS9W-T<B`BX9Z?X9^#(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA
M(@IM<V=S='(@(N&>H.&?DN&>G^&>MN&?AN&>E.&?BN&>N"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(N&>H.&?DN&>G^&?BN&>
MN.&>F.&>E.&>MN&>G.&?B>&?@2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HW,0IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B
M6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@
M)7-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34V,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS
M9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I
M9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T
M92!2;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?
M1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-
M96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM
M<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?3.&>A>&?@>&>B2`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?
M3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@
M(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO
M=F4@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G
M:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM
M<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(P"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>G^&?
MDN&>@N&>MN&>F^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>F^*`
MB^&>G^&?AN&>E.&>N^&>C^&?DN&>FB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3$R"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$X-"!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>
MHN&>MN&>A>*`B^&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>K^&>@.&>G^&>MN&>
MFN*`B^&>F^&>D>&?DN&>DN&>E>&>FR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGK[AGH#B@(OA
MGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGI3AGHGAGY+AGH7AGKSAGILB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.34*;7-G:60@
M(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E
M<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OAGH#AGK;AGIKB@(OA
MGI3AGY+AGIKAGK[B@(OAGI3AGI/AGY+AGI'AGK;AGH_AGXOB@(OAGI;AGK;A
MGH#AGY+AGIGAGI3AGHGAGY+AGH?AGK8B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O
M<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OAGH#AGK;AGIKB@(OAGH#A
MGX;AGH[AGH_AGXOB@(OAGIKAGH7AGI/AGK;AGI_AGICAGY+AGI;AGY#AGI/A
MGY+AGI(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U
M-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R
M("+AGI3AGK;AGH_AGXOB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI3AGY+AGIKA
MGI;AGY#AGI/AGY+AGI+B@(OAGI_AGX;AGH'AGK;AGI/AGXOB@(OAGI3AGX;A
MGI7AGKOAGH\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`BX9Z`X9^&
MX9Z@X9Z[X9Z?XH"+X9Z1X9^2X9Z:X9Z$X9^+X9Z1X9^2X9Z:X9ZVX9Z9XH"+
MX9Z1X9ZWX9Z3X9^2X9Z3X9Z3X9^0X9Z9(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR.`IM<V=I9"`B961I="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(N&>FN&>@.*`B^&>F.&>M^&>D^*`B^&>@^&>
MON&>B>*`B^&>DN&>MN&>C^&>N^*`B^&>E.&>B>&?DN&>A>&>O.&>FR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED
M(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@X,0IM<V=I9"`B9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$X-B!L:6(O0FQO8VLO;65T87(N<&AP.C,W,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(F=U<W1I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(T.`IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U-PIM<V=I9"`B:&@B"FUS9W-T
M<B`B:&@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`BX9Z8X9ZWX9Z3
MXH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z8
MX9^)X9ZVX9Z?X9^*X9ZXX9Z3(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B
M:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`
MB^&>E.&>B>&?DN&>A>&?@>&>B2_AGI3AGHGAGY+AGH7AGKSAGILB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT
M97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?
MXH"+X9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZXXH"+X9Z!X9ZVX9Z$XH"+X9Z`
MX9^2X9Z:X9^%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE
M(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-C@*;7-G:60@(FUM(@IM<V=S='(@(N&>
MF"[AGI@N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#8@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S='(@(N&>
MB.&?DN&>F.&?A.&?AR(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*
M;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@
M:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,#0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM
M<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B
M"FUS9W-T<B`BX9Z?X9ZWX9Z1X9^2X9Z2X9ZWXH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z*X9ZWX9Z?X9^!X9Z2(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I
M9"`B<&EX96QS(@IM<V=S='(@(N&>E^&>N.&>@.&>G^&?@N&>FR(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO
M=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?
MXH"+X9Z6X9ZXXH"+X9Z%X9Z8X9^2X9Z$X9ZVX9Z9XH"+X9Z`X9^2X9Z3X9Z[
MX9Z$XH"+X9Z6X9ZWX9Z2X9ZXX9Z`X9ZVX9Z:(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G)I<VEN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T
M,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("+AGICAGK?A
MGI/B@(OAGJ+AGK;AGH7B@(OAGIKAGH#B@(OAGI_AGX'AGISAGK;B@(OAGI3A
MGK;AGI,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,@IM<V=I9"`B
M<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M
M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(G-S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*
M;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S
M='(@(N&>@.&?AN&>H.&>N^&>G^*`B^&>E.&?DN&>FN&>EN&?D.&>D^&?DN&>
MDB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(X"FUS9VED(")T
M87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S
M='(@(N&>E.&>FN&>MN&>A^&?D.&>F>*`B^&>E.&>CN&?DN&>BN&?A.&?A^&>
MHN&>MN&>G^&>D^&?DN&>DR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S$*;7-G:60@(G1Y<&4@=&AE
M('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O:&]R9&4N<&AP.C(W.0IM<V=I9"`B=6YK;F]W;B!E<G)O<B(*;7-G<W1R
M("+AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOAGXOB@(OAGH#AGX;AGJ#A
MGKOAGI\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS
M9VED(")U;FYA;65D(@IM<V=S='(@(N&>@N&?DN&>F.&>MN&>D^*`B^&>B.&?
MDN&>F.&?A.&?AR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#`*;7-G:60@(G<Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS
M9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P;R]K;U]+4BYP;P``````````````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C4P,#`S`#$P-#$W,S8S,#`Q`#`Q-C,W
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M($MO<F5A;B!T<F%N<VQA=&EO;G,@9F]R(&AO<F1E('!A8VMA9V4*(R!H;W)D
M92#&T,6PP?:_H2"TZ\?1(,?1L;F^[B"Y^+^JN:XN"B,@0V]P>7)I9VAT("A#
M*2`R,#`U($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T
M960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@:&]R9&4@<&%C:V%G
M92X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#$M,3$M
M,#D@,38Z,CDK,#DP,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!*:6YH>6]K($AE
M;R`\;F]V96UB<F5`;W5R;F%T=7)E+F]R9SY<;B(*(DQA;F=U86=E+51E86TZ
M(&DQ.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4550RU+4EQN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B`HM-S#X,6P("5S*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI
M;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*+_`M,,I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO
M<G)O=RDB"FUS9W-T<B`B("BSN\#/*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*+[N
MP:8I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S
M='(@(K7PM[K%Y+BN(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A
M;&ED(&-H;VEC92XB"FUS9W-T<B`BO\.YV;BE(+#+N_8@N?S!UKBF(,#4M\+'
MS[R\O^0N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(E
M<R?`S"BPH2D@2&]R9&4@M[G!]KVZQJZXKK^AO*T@O+/!I+7'ONX@P-;!]B"^
MRKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H
M92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ$@P]^P
MH;7'OOJ]P+3/M-DN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R>PH2"]
MP[VZQ=N_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*
M;7-G<W1R("(E9"`O("5D("BXWKW#P?8Z("5D*2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y
M(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I
M8V4B"FUS9W-T<B`BPOS!MB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R
M:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB
M"FUS9W-T<B`B)7,@P*_!]K#\N*X@P-N^]R`M(,BNP,XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!4
M97)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(EPB)7-<(K3"(,#,N<P@P-:]P+3/
MM-DN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@
M(B5D("\@)60@*+C>O</!]CH@)60I(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM
M<V=S='(@(L'VL=T@O/;'X,?2(,#;OO?`NR"\L<7#Q\^\O+_D+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI
M;G5T97,B"FUS9W-T<B`B-;K0(+BVM-DB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5S
MP+LHN*8I(,.CP+L@O/8@OOB]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)60@+R`E9"`HN-Z]P\'V.B`E9"DB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
MP=:\TK?/(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T
M<B`BM-ZWPB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T
M<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDS,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K
M;&ES="(*;7-G<W1R("*\]KW%L,6ZSB(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O
M;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B
M"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@
M=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-S0Y"B,L(&9U>GIY"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`BL=3$
MHBBW_"D@O+'%PR"_P+?Y(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L
M(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("+!I+JX(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(
M;W5R($9O<FUA="(*;7-G<W1R("+!I+JX(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(+W#L*,B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"B,L(&9U>GIY"FUS
M9VED("(\4')E=FEO=7,B"FUS9W-T<B`BP,S`_"#&Y,#,P?8B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B/&(^Q*&X[<#[
MP,X@O\"W^2"YW[O].CPO8CXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.CD*(RP@9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("*ZN;OG(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*(RP@
M9G5Z>GD*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`BM\ZQU\#.(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*(RP@
M9G5Z>GD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`BL*'`Y<#:N*XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B
M04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED
M(")!32]032(*;7-G<W1R("*_P,#\+[_`R,0B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)
M1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R
M("+`S""_H;7PQ<VTPB(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R
M"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED(")!
M8G-B;W1T;VTB"FUS9W-T<B`BOL:WH2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@(D%B<VUI
M9&1L92(*;7-G<W1R("*PH;_NM:4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C<P"B,L(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@M?"WNL7D
MN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(D%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LH
MN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*
M;7-G<W1R("+!I+JX(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"B,L
M(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(K[/R*,@
MR*[`SB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM
M<V=S='(@(K_`N*?"][SX(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,S,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("*_P+BG
MPO>\^"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(L/?
ML*$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP
M.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD(%!E
M<FUI<W-I;VXB"FUS9W-T<B`BL+/`SB"XWL#/(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G
M<W1R("*[Y[_KP-H@P]^PH2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B
M061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(K"SP,X@N-[`SR(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<
M(B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S
M='(@(B5S(+''Q]$@O/;!I"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED
M(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`BN_6WSK_N(+OGO^O`VB##W["A
M.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-30*(RP@9G5Z>GD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`BOZT@NM#'
MTB(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("*[];?.O^X@
MN^>_Z\#:(,/?L*$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY
M-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BQN2^[BAP86ER*2##W["A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*
M;7-G<W1R("(H)7,IN*8@P=:\TK?/OZ$@P]^PH2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B
M061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("(H)7,IN*8@P=:\TK?/
MOZ$@P]^PH2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E
M<B(*;7-G<W1R("*[Y[_KP-H@P]^PH2(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I
M;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BN^>_Z\#:(,/?L*$@N^>_Z[[(
MQ]0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S
M<R(*;7-G<W1R("+!UKS2(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(L'6O-*WSR(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED
M(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB
M"FUS9W-T<B`BL/RXKB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R("+#W["A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@HC+"!F=7IZ>0IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`BM-S#
MO"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`BOO.V\\#,ONZ]NB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L
M9V5R:6$B"FUS9W-T<B`BOO.V\\#,ONZ]NB(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S
M='(@(K[SMO/`S+[NO;HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("+!
MI+?$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("+!I+?$.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(KCP
MM<X@O+'%PR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*(RP@9G5Z>GD*;7-G:60@
M(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(KC>P,\@P/RTWB"_
MP+?Y.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H
M<#HR,C(*(RP@9G5Z>GD*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`BN^C!
MIB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0HC+"!F=7IZ>0IM<V=I
M9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(L7DM]`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED
M(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("*X\+7G(#2XZ2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T
M>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HU,#0*(RP@9G5Z>GD*;7-G:60@(D%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(EPB)7-<(K3"(,#,N<P@P-:]P+3/M-DN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G
M:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PHC
M+"!F=7IZ>0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T
M<B`BOL_(HR#(KL#.(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM
M<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@
M(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(L#?N/BUR"#`S+C>
MP,\@P=:\TB(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"B,L(&9U>GIY
M"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(K3KP[P@L=LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("*T
MZ\.\(+';(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("+`W[CXM<@@N:[`
MVK"A(,#6O<"TS[39+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C
M8W5R960N(@IM<V=S='(@(CQB/L2AN.W`^\#.(+_`M_D@N=^[_3H\+V(^(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"B,L(&9U>GIY
M"FUS9VED(")!;G-W97(B"FUS9W-T<B`BR+B]Q<?1(+C>P,\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HV"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A
M=&EO;B(*;7-G<W1R("*]Q\?@(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@
M(KW'Q^`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"B,L(&9U>GIY
M"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`BO<?'X"(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L
M>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S
M"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R("(TO_DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM
M<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@
M4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,`HC+"!F=7IZ>0IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(L?*M>7`
MS+BG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHQ,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(#\B"FUS9W-T<B`BL.B\TR#!^,?@Q\^]P[#:O<"TS['N/R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(L#,(+C>O</!
M]KBF(+^UO_C(]R"[Z,&FQ\^]P[#:O<"TS['N/R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*(RP@
M9G5Z>GD*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("*^\[;SP,R^[KVZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM
M."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS
M9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM
M<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S
M:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(L"O
MP?:P_+BNO<?'X,#\(,BNP,['S['B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$Q,PHC+"!F=7IZ>0IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS
M(@IM<V=S='(@(K^M(+K0Q](B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G
M:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R
M("(XO_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")!=7-T<F%L:6$B
M"FUS9W-T<B`B.+_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B075S
M=')I82(*;7-G<W1R("(XO_DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($94
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M
M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R
M"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(L#3O<.ZN+#\Q]0@
MP/K`Y2"_P+?Y+B"\K;GVP,<@O\"W^2"XWKW#P?8Z("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!U<V5R("5S(@IM<V=S='(@(L#3O<.ZN+#\Q]0@P/K`Y2"_P+?Y
M+B"\K;GVP,<@O\"W^2"XWKW#P?8Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT
M-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`HC+"!F
M=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(KOH
MP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(KC>P,\@P/RTWB"_
MP+?Y.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*
M(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N(@IM<V=S='(@(F9T<""\K;GV(+^LL.$@O\"W^2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0HC+"!F=7IZ>0IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(F9T<""\K;GV(+^LL.$@O\"W^2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T
M;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(F9T<""\K;GV(+^L
ML.$@O\"W^2XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS
M9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R("*PH;3)Q]$@Q\JUY3HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B
MN>BPYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`BN>BPYB"[
M]K'R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I
M9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R
M;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*
M;7-G:60@(D)A:&%M87,B"FUS9W-T<B`BP,RXIR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*(RP@
M9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`BP*6XWL#/(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T
M<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF*2##
MH\"[(+SV(+[XO<"TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B0F%S96QI
M;F4B"FUS9W-T<B`BQ:FQXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B0F5L9VEU
M;2(*;7-G<W1R("+%J;'B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B
M0F5L:7IE(@IM<V=S='(@(L6IL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R("*[_<#/(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.C
MP+L@O/8@OOB]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y
M<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(K&]L-0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`BL.:PZ"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@
M(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(K#FL.@@M<ZRLB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*
M;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`BL.:PZ"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(KCP
MM<XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("*^QK>A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L
M(&9U>GIY"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`BP*6XWL#/(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"=6QG
M87)I82(*;7-G<W1R("*^\[;SP,R^[KVZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES
M="(*;7-G<W1R("*QXLBC(+BNO;K&KB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U
M;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-#0*(RP@9G5Z>GD*;7-G:60@(D--4R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")?9;R_(+S3O+HN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`BM-ZWPB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*
M(RP@9G5Z>GD*;7-G:60@(D-A;&TB"FUS9W-T<B`BP^N\TB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L
M(&9U>GIY"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("*PL\#.(+C>P,\B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(E9&4R#&Q,#/
M("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N
M86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DQ$05`@
MO*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JO
ML.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED
M(")#86YA9&$B"FUS9W-T<B`BM-ZWPB(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I
M9"`B0V%N8V5L(@IM<V=S='(@(L/KO-(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T
M(@IM<V=S='(@(K_`M_D@NKBP[<?/L>(@P^N\TB(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@QL3`
MSR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A
M;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM
M<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")-86EN=&5N86YC95]4
M87-K(+CPM>(@)7/`NRBXIBD@OZT@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*
M;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB
M<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I
M9"`B0V%P=&EO;B(*;7-G<W1R("+$N+S'(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B
M0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL
M(%!H;VYE(@IM<V=S='(@(LC>M.O&^2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O
M<&5R=&EE<R(*;7-G<W1R("*\OR"\T[RZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN
M9SHB"FUS9W-T<B`BO+\@QN2U^2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R
M=&EE<R(*;7-G<W1R("*\OR"\T[RZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB
M"FUS9W-T<B`BO+\@L*.PW2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("+(WK3KQODB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U
M.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@
M(K"AO^ZUI2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H
M860B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED
M(")#:&%N9V4B"FUS9W-T<B`BNJ^PYB(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`BOL_(HR#(KL#.(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V"B,L(&9U>GIY"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`BN-[`S\"[(+JX
ML[ZVIR"[Y[_KQ](@P,RXIRP@P=:\TBP@O*VX[<"[(+JOL.;'U;3/M-DN(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#
M:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@
M(D-H87(B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,
M:6YK+BXN(@IM<V=S='(@(E]KN+7%J2"PR[OG+BXN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC
M+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`BP::X\2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(L'?L;DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS
M9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY
M"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("*^S\BC(,BNP,XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"B,L(&9U
M>GIY"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("*XWKW#P?8@
MP-N\NB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H
M;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I(@IM<V=S='(@(KSXO*T@N*Z]NL:N(,&^M_D@O+'%PR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(L7KP?8@N*Z]
MNK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/M-DN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@
M(D-L96%R(@IM<V=S='(@(K3>M\(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(DU3O\#'Q[VZ(,77L=<@P?:_[+'B(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E<GDB
M"FUS9W-T<B`BL,N[]L?7N/$@P\JQXLBM(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("*PR[OVQ]>X\2##RK'BR*TB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*(RP@9G5Z
M>GD*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`BL,N[]L?7N/$@P\JQXLBM
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*(RP@9G5Z
M>GD*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("*PR[OVQ]>X\2##
MRK'BR*TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("*P
MR[OVQ]>X\2##RK'BR*TB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S
M='(@(L.B(+3=L>(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`HC+"!F
M=7IZ>0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(KJYN^<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I
M9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(KJYN^<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B
M0VQO=61Y(@IM<V=S='(@(KJYN^<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O
M<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R
M(@IM<V=S='(@(K_>PLJXM[3K(+3=L>(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S
M960@8F]R9&5R<R(*;7-G<W1R("+'U</$P?@@L.:PZ"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M(RP@9G5Z>GD*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(KOVL?(B"@HC.B!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`BN_:Q\B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"B,L(&9U
M>GIY"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(KRQQ<.[Y\?7
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("*_K3HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@
M(D-O;6EC<R(*;7-G<W1R(")#;VUI8W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`BR+B[YR(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R("+(N+OG(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")#;VUM96YT(@IM
M<V=S='(@(LBXN^<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V-@HC+"!F=7IZ>0IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B
MP,RXISHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B0V]M;W)O<R(*
M;7-G<W1R("*[]2"XWL#/(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+(N+OG
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"B,L(&9U>GIY"FUS9VED
M(")#;VUP=71E<G,B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO
M;B(*;7-G<W1R("*PX;?0(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*
M(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`BL.&WT"(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET
M:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U
M<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R("*^
MS\BC(,BNP,XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")#;VYG;R(*
M;7-G<W1R("*YWK3"(+OGMO<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@
M5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z
M>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("*[Z,&F(+W'
MQM`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P
M"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@
M(KOHP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")F='`@O*VY]B"_K+#A(+_`
MM_DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G
M<W1R(")F='`@O*VY]B"_K+#A(+_`M_DN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX-#4*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(F9T<""\K;GV(+^LL.$@O\"W
M^2XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N
M=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`BQ]>X\2!<(B5S7"*PH2#!UKS2M\^_H2##W["AM<>^^KW`M,^TV2XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(B<E
M<R?`QR"SN[_K(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"B,L(&9U>GIY"FUS9VED
M(")#;VYT:6YU92(*;7-G<W1R("*PX;?0(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(KOU(+C>
MP,\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`BNKF[YR(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`BN^C!IB"]Q\;0
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`BNKF[YR(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T
M($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-S8*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R("(QL+/`QR"[];?.O^X@N-Z]P\'VL*$@P-:]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PHC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S
M='(@(C&PL\#'(+OUM\Z_[B"XWKW#P?:PH2#`UKW`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@
M(KC>O</!]B#`_+S;(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT-C<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG
M;B!M97-S86=E+B(*;7-G<W1R("(QL+/`QR"[];?.O^X@N-Z]P\'VL*$@P-:]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4""\K;GV
M(,&BO-,@O<?&T"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E
M<R(*;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!L9&%P('-E<G9E<B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB
M('5S:6YG($944#H@)7,B"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("*^LK'BL*&TR<?1
M(,'6O-*WS\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DAO<F1E
ML*$@N=FXH[#4(+RSP:2UQ\'V(+[*OM*]P+3/M-DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(DAO<F1EL*$@N=FXH[#4(+RSP:2UQ\'V
M(+[*OM*]P+3/M-DN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDU,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S
M='(@(L#?N/BUR"#`S+C>P,\@P=:\TB(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("*^LK'BL*&TR<?1(,'6O-*WS\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(DUA:6YT96YA;F-E7U1A<VL@N/"UXB`E<\"[*+BF
M*2"_K2"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@7"(E<UPB+B(*;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<
M(BXB"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S$Y"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R
M("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M("5S+B(*;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<R(*;7-G<W1R(")-86EN=&5N86YC95]487-K(+CPM>(@)7,@N*8@OZT@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(")-86EN=&5N86YC95]487-K(+CPM>(@)7/`NRBXIBD@
MOZT@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(E<[BF(+^QM,^TV3\B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0HC+"!F=7IZ>0IM
M<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*(L/?L*''S[3"M:4@O\"W^;"A(+G?N_W'W[W`M,^TV2X@O<.]
MNL7;L/RXKL#:OZ&PU""UM;_RP+L@O^3#N\?/O<.QXB"YV;;XM,^TV2XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(KZRL>*PH;3)
MQ]$@P=:\TK?/P,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M(@IM<V=S='(@(KZRL>*PH;3)Q]$@P=:\TK?/P,P@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BOK*QXK"AM,G'T2#!
MUKS2M\_`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@
M)7,B"FUS9W-T<B`BOK*QXK"AM,G'T2#!UKS2M\_`S""^^+W`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI
M=&EE<R(*;7-G<W1R("*^LK'BL*&TR<?1(,'6O-*WS\#,(+[XO<"TS[39+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R
M9&6PH2"YV;BCL-0@O+/!I+7'P?8@OLJ^TKW`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B5SN*8@O[&TS[39/R(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^A
MO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(E9&4R"\
ML\&D(,&DNKB_H;RM("=P;W)T)\#,(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")61E,@O+/!I"#!
MI+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B5SN*8@
MO[&TS[39/R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(B5SN*8@O[&TS[39
M/R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")-86EN=&5N
M86YC95]487-K(+CPM>(@)7/`NRBXIBD@OZT@O/8@OOB]P+3/M-DN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E
M<UPB.B`E<R(*;7-G<W1R(")(;W)D9;"A(+G9N*.PU""\L\&DM<?!]B"^RK[2
MO<"TS[39+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@
M(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(K&SP:2UR""YKL#:OZTB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("*[]2"XWL#/(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PHC+"!F=7IZ>0IM<V=I9"`B0V]U
M<G-E<R(*;7-G<W1R("*[]2"XWL#/(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A
M=&4B"FUS9W-T<B`BN+BUZ;'B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L
M:6YK(@IM<V=S='(@(KBUQ:D@N+BUZ;'B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E
M(&$@;F5W(&]N92(*;7-G<W1R("+(WL'VQ>L@N_6WSB"XN+7IL>(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@HC+"!F=7IZ
M>0IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(KOUQOJT]2"X
MN+7IL>(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`HC
M+"!F=7IZ>0IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("*[
MY[_KP-H@L<?'T2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*
M(RP@9G5Z>GD*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("*\
M_<#:(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D-R;V%T:6$B"FUS
M9W-T<B`BN+BUZ;'B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@
M(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`BQ_;`YR"]NL6XP,\B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@
M4V5S<VEO;G,B"FUS9W-T<B`BQ_;`YR!54DS`NB(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`HC+"!F=7IZ>0IM<V=I
M9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(K&SP:2UR""YKL#:OZTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(L?VP.<@55),P+HB
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U
M<G)E;G0@57-E<G,B"FUS9W-T<B`BQ_;`YR"]NL6XP,\B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%=E871H
M97(B"FUS9W-T<B`BQ_;`YR"]NL6XP,\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C<U"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(&-O;F1I
M=&EO;CH@(@IM<V=S='(@(K#AM]`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM
M<V=S='(@(L?VP.<@O;K%N,#/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A
M<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("))35`@M\ZQ
MU[_"O<,@O</`V[7'M,(@P-N^]\"[(+RSP:3'U;3/M-DN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS
M9VED(")#=70B"FUS9W-T<B`BP-JXH['B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO
M;B(*;7-G<W1R("+`VKBCL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@
M(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@
M(K3KQ]&YSK&Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B
M"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q
M"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(L#/NK`B"@HC.B!A9&UI;B]D
M871A=')E92YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`BP,_`VB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B
MLZ_"I2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(KSVO<4@
MLZ_"I3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"B,L(&9U
M>GIY"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("+`VKBCL>(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G
M<W1R("+`S[JP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G
M<W1R(")?;+^M(+OHP:8B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B,3*_^2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("*\_<#:
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(K.[ONZ^LK'B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S
M+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BL>*ZNR(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U
M>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(K'BNKNPJB"[Y[_K
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I
M9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("*QXKJ[(+W$NK#`VB(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F
M875L="!3:&5L;"(*;7-G<W1R("*QXKJ[(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R
M("*QU,2B(,&DP,<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`BN^C!IB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`BO+\@N^C!
MIB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`BN^C!
MIB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("+'X""[Z,&F(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`BN-Z]P\'V(+OHP:8B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("*[Z,&FM<@@N-[`SR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(KR_(+OHP:8B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(K^M(+OHP:8B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`B)7,@L<?'T2"\]L&D(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`BQ^`@N^C!
MIB(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G
M<W1R("*]Q+JPP-H@O+'%PR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;B(*;7-G<W1R("+']L#G(+^M(,'VO_(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`BQ_;`YR#'
MX"#!]K_R(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@9G5Z>GD*;7-G
M:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BN^C!IB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(K_`M_D@O+.X[2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("*\L[CM.B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A
M:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("*\O+K.P:2ZN+"A(+#\N*[`VKBF(,"GQ]@@L>*WS[7'ON[!L[W`M,^T
MV2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I
M<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C
M=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`BM?"WNL7D
MN*XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(LBMN.D@O+/!
MI"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA
M>2!/<'1I;VYS(@IM<V=S='(@(LBMN.D@O+/!I"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D
M971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C@U"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O
M<F5C87-T("A4048I(@IM<V=S='(@(LBMN.D@O+/!I"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@
M9F]R;6%T(@IM<V=S='(@(LBMN.D@O+/!I"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("*ZN;&X
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(")M
M86EN=&5N86YC92YP:'"_H2#!]\&B(,&BL=G'S\'V(+BVO+R_Y"XB"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*
M;7-G<W1R("+#N;GXPK`@Q^#`NB#'U[CQ(,#,N*?`NR"PKK#M(,#6O<"TS['N
M/R"QU[>XM-FXZ2P@OZFQXKBF(,.\Q:G'S[R\O^0Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ
M>0IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(K3KQ]&YSK&Y
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N
M)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O
M=VYL;V%D(@IM<V=S='(@(K.[M\&YWK'B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O
M=VYL;V%D("5S(@IM<V=S='(@(B5S(+.[M\&YWK'B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"B,L
M(&9U>GIY"FUS9VED(")$<G5G<R(*;7-G<W1R("*Y^K>YM>DB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@
M(D4M36%I;"(*;7-G<W1R("+`I;C>P,\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3
M(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T
M:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@
M(KSVP:0B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E
M;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O
M=7!S+G!H<#HR,C8*(RP@9G5Z>GD*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T
M<B`BN^C!IB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("*PL\#.(+C>P,\B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"B,L(&9U>GIY"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B5S(+''Q]$@O/;!I"(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@L<?'T2"\
M]L&D(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I
M="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BO+'%P[OGQ]<@O/;!I#HB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM
M<V=S='(@(B5S(+''Q]$@O/;!I"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S(+''Q]$@O/;!I"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B161U8V%T
M:6]N(@IM<V=S='(@(KS2L+,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S
M+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(K_DO-(N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.0IM<V=I9"`B16TB"FUS9W-T<B`B96TB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(L#,N-[`SR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R("+`S+C>P,\@P=:\TCHB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.38S"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"XB"FUS9W-T<B`BOL_(H["A(,#/Q*''S\'V(+[*O<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(K'BQ;@@
MP:2ZN"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX
M"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BP,RX\,:\Q-PB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@
M9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(L'?O^3'T2"X
MWL#/(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("*PX;#Z(+[X
MP+TB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS
M9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O
M9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$Q"B,L(&9U>GIY"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M("*_WL+*N+>TZR#(KL#E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T
M<B`BQNW!_;'B(,BNM.LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q
M"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO
M=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB
M<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_
M)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4B"FUS9W-T<B`BL=>XLB!54DP@P-2WPB(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N
M=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R
M(@IM<V=S='(@(K_`M_DB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN
M9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E
M<GD@,34@;6EN=71E<R(*;7-G<W1R("(Q-;K0(+BVM-DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI
M;G5T97,B"FUS9W-T<B`B-;K0(+BVM-DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B,S##RB"XMK39(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP
M"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B-;K0(+BVM-DB"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS
M9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("*X\+7G(+?.L=?`SB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R("(S,+K0(+BVM-DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y
M(&UI;G5T92(*;7-G<W1R("*XQ;K0(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("*_
MN3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN
M<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-#<U"B,L(&9U>GIY"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BN/"USB#(
MKL#E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I
M9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`BO]["RKBWM.L@R*[`Y2(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X
M<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<V"B,L(&9U>GIY"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("*_HKVZ
MQO?&KB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(L#\L.:[]B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO
M860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RXB"FUS9W-T<B`BR*^PYKRSP:0@P-"QXB"_P+?Y+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ>0IM
M<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T
M<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B3$1!4""\K;GV(,&B
MO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<
M(B5S7"(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"B,L(&9U>GIY"FUS9VED(")&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(DQ$05`@OZRPX2`E<R"]Q\;0(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<
M(BXB"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(DQ$05`@O*VY
M]B#!HKS3(+W'QM`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.`HC+"!F=7IZ>0IM<V=I9"`B1F%I<B(*;7-G<W1R("+'RL7-
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9A
M<F]E($ES;&%N9',B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M
M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%
M<G)O<CHB"FUS9W-T<B`BP-"^[K_`L>(HP-/&]\:N*2"_P+?Y.B`B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED
M(")&87@B"FUS9W-T<B`BQM&]NB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(L;1O;HB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM
M<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B,K_Y(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@
M;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM
M<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I
M9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I
M;&4B"FUS9W-T<B`BP::X\2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B
M1FEL92!-86YA9V5R(@IM<V=S='(@(L;$P,\@L/RXKL#:(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R("+'RK7EP,RXIR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y.34*(RP@9G5Z>GD*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(K'4Q*(HM_PI(+RQQ<,@O\"W^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T.#8*(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S
M='(@(L?*M>4B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I
M;'1E<G,B"FUS9W-T<B`BQ\K%S2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G
M:60@(D9I;FQA;F0B"FUS9W-T<B`BPZ.QXB(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B
MP[G&Y,#,P?8B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<V"B,L(&9U>GIY"FUS9VED(")&:7)S="!1=6%R=&5R(@IM
M<V=S='(@(L.YQN3`S,'V(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*
M;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(K';
MP-H@N_:Q\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B
M1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@
M(KKJMO._[,#ZL*$@P,P@L>*TR<"[(,'VO_C'S\'V(+[*O<"TS[39+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T
M=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@
M(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B
M;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ,#(*(RP@9G5Z>GD*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*
M;7-G<W1R("*^S\BC(,BNP,XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#8R"B,L(&9U>GIY"FUS9VED(")&;W)M<R(*;7-G<W1R("+`I\2A(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"B,L(&9U>GIY"FUS9VED(")&
M;W)T=6YE(@IM<V=S='(@(L+\P;8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("+"
M_,&V(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS
M9VED(")&;W)T=6YE<R(*;7-G<W1R("+"_,&V(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S
M='(@(L+\P;8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"B,L
M(&9U>GIY"FUS9VED(")&;W)U;7,B"FUS9W-T<B`BN-[`S\?4(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0HC+"!F=7IZ>0IM<V=I9"`B1F]R
M=V%R9',B"FUS9W-T<B`BP/RTWB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9R(@IM<V=S
M='(@(L"GQ*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`BQ\&WN<#3
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;F-E(@IM<V=S='(@
M(L/KO-(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G
M:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("+`I\2A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,#8*(RP@9G5Z>GD*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("+`I\2A(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*
M;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BP/S#O""\L[CM.B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("+`S+BG
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("*XWL#/(+RM
MN?8@P:2ZN+OGQ]<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG
M+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")'97)M86YY(@IM<V=S='(@(K6VP,\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L
M(&9U>GIY"FUS9VED(")':&%N82(*;7-G<W1R("+!W[&Y(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"B,L(&9U>GIY"FUS9VED(")':79E
M;B!.86UE(@IM<V=S='(@(L?*M>7`S+BG(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(K"AL>(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R
M.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`BL,N[]L?7
MN/$@P\JQXLBM(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0HC+"!F
M=7IZ>0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("*PR[OVQ]>X\2##
MRK'BR*TB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=R965N;&%N9"(*;7-G
M<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*(RP@9G5Z>GD*;7-G
M:60@(D=R96YA9&$B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B1W)O=7`@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`BL/RXKB(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V
M.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@(@IM<V=S='(@(L#3O<.ZN+#\Q]0@P/K`Y2"_P+?Y+B"\K;GVP,<@O\"W
M^2"XWKW#P?8Z("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^P
MYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PHC+"!F=7IZ>0IM<V=I9"`B1W5A;2(*;7-G
M<W1R("(VO_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*(RP@9G5Z
M>GD*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(K6VP,\B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C@X"B,L(&9U>GIY"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*
M;7-G<W1R("*XWKW#P?8@N^C!IB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("+!
MUKS2M\\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'=6EN96$B"FUS
M9W-T<B`B-K_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")'=6EN
M96$M0FES<V%U(@IM<V=S='(@(C:_^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`HC+"!F=7IZ
M>0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(C:_^2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:'1T<"YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")(5%10($%U=&AE;G1I8V%T
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(R"B,L(&9U>GIY"FUS9VED(")(87IE(@IM<V=S='(@(L?LM>6V\\#.
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*;7-G:60@(DAE861E<B(*;7-G
M<W1R("+'[+7EMO/`SB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T
M<B`BQ^RUY;;SP,XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@
M5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("*S],#,(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W
M('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S
M='(@(K6UO_*XNR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@
M(K6UO_*XNR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@
M9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R("*UM;_RN+LB"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(DAE;6ES<&AE<F4B
M"FUS9W-T<B`BM;6_\KB[(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`BQL3`
MS\#'(+W#P-O`S""TV<"]L/H@L+"]P+3/M-DZ(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(DAI
M9V@B"FUS9W-T<B`BL_3`S"(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0HC+"!F
M=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*(RP@
M9G5Z>GD*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@
M061D<F5S<R(*;7-G<W1R("+!_2#!UKS2(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G
M<W1R("*U\+>ZQ>2XKB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BP?T@
MP/S(K;GXR*,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R
M9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV
M86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O
M<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S
M<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B
MN-[`S\?4(%PB)7-<(L#,(%PB)7-<(K?.(+JOL.:UQ[[ZO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
MN-[`S\?4(%PB)7-<(L#,(%PB)7-<(K?.(+JOL.:UQ[[ZO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")<(B5S7"(@N-[`S\?4P+L@N^>_Z\?5
MM,^TV2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")<(B5S7"(@N-[`
MS\?4P+L@N^>_Z\?5M,^TV2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK
M;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A
M;"!2=6QE(@IM<V=S='(@(KSVQO*\L2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D
M9&EN9R(*;7-G<W1R("*PH;?.(,.DO_(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*
M;7-G<W1R("*PH;?..B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I
M9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B
M"FUS9W-T<B`BQ]7$H;#M(+W-P+H@OZW`QR"\]B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`BQ]>X\2B_K2G`QR"\]C\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R("+'U<2AL.T@O<W`NB#'X,#'(+SV(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU
M;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(KC>P,\@P/RTWB"_P+?Y.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("*XWL#/(,#\M-X@O\"W^3HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM
M<V=S='(@(L'6O-(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N
M<&AP.C<W"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@O+'%P[OGQ]?`S""^^+W`M,^TV2XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED
M("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B
M"FUS9W-T<B`B7VZ^U;^A(,?@(,/?L*$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z
M>GD*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY
M(@IM<V=S='(@(K[&P,S$W"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM
M<V=S='(@(B5SOZ&PU""\TK"S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(K[&P,S$W+#Z
M(+FNP-HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))
M9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(KW$NK#`VB#`S+BG.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D
M;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y
M;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@
M4')E=FEE=SHB"FUS9W-T<B`BL=>XLB"YS+BNNKBQXCHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED
M("));6%G92!54DPB"FUS9W-T<B`BL=>XLB!54DPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G
M:60@(DEM86=E(%523#HB"FUS9W-T<B`BL=>XLB!54DPZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*(RP@9G5Z>GD*;7-G:60@
M(DEM86=E('5P;&]A9"(*;7-G<W1R("+'RK7E(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DEM86=E<R(*;7-G<W1R("*Q
MU[BR(%523"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G
M<W1R("*PH<&NO\"QXBP@M-RPZ"`E<R(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I
M96QD.B`E<R(*;7-G<W1R("*PH<&NO\(@Q]>X\3H@)7,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z
M(@IM<V=S='(@(K"AP:Z_PB#'U[CQ.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`B7W.TV<"]OZ$@Q^`@P]^PH2(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC
M+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"XB"FUS9W-T<B`BN^>_Z\#:P,RXI[#Z(+[/R*.XIB#`U+?"Q\^\O+_D
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*(RP@9G5Z>GD*
M;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HBP]^P
MH<?/M,*UI2"_P+?YL*$@N=^[_<??O<"TS[39+B"]P[VZQ=NP_+BNP-J_H;#4
M(+6UO_+`NR"_Y,.[Q\^]P['B(+G9MOBTS[39+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E
M($EN9&5N="(*;7-G<W1R("*UZ;^IOK*QXB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0HC+"!F
M=7IZ>0IM<V=I9"`B26YD:6$B"FUS9W-T<B`BOOC`O2(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B26YD;VYE<VEA(@IM<V=S
M='(@(K[XP+TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C8W"B,L(&9U>GIY"FUS9VED("));F9O(@IM<V=S='(@(KFKO<,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"B,L(&9U>GIY"FUS
M9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+!I+JX(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,S,`HC+"!F=7IZ>0IM<V=I9"`B26YF;W)M
M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`BP,R_Z["AM,G'
MT2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T
M($-?;VQU;6X@069T97(B"FUS9W-T<B`B7V^TV<"]OZ$@OZT@P]^PH2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(K'7N+(@P]^P
MH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("+'I2##W["A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I
M9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(L"E(+BUQ:D@P]^PH2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E]C
MOM6_H2"_K2##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+']L#G(+^M(+7:
MOZ$@N_4@OZT@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(L?VP.<@OZT@
MOM6_H2"[]2"_K2##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+']L#G(,?@(+7:
MOZ$@N_4@Q^`@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(L?VP.<@Q^`@OM6_
MH2"[]2#'X"##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("+']L#G(,'VP:$@
MM=J_H2"TW+;T(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("+']L#G(,'V
MP:$@OM6_H2"TW+;T(,/?L*$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U
M,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("*TZ\.\(+';(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(K7:OZ$@O+\@
MP]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R
M("*^U;^A(+R_(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F
M=&5R(@IM<V=S='(@(K7:OZ$@OZT@P]^PH2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R
M="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(K[5OZ$@OZT@P]^PH2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"B,L(&9U>GIY
M"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`BR+B]Q<?1(+C>P,\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T
M<B`BM=J_H2"TW+;T(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@8F5F;W)E(@IM<V=S='(@(K[5OZ$@M-RV]"##W["A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("*UVK^A(,?@(,/?L*$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("*^U;^A
M(,?@(,/?L*$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED
M("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA
M9V4B"FUS9W-T<B`BL=>XLB##W["A+[SVP:0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D
M:69Y($QI;FLB"FUS9W-T<B`BN+7%J2##W["A+[SVP:0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B
M26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-S4*(RP@9G5Z>GD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`BL*&_[K6E
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT
M96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("+`W[CX
MM<@@P,RXIRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@
M(L#?N/BUR"#`S+BG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6
MO-(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX
M,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(L#?
MN/BUR"#`S+BG+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S
M='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PHC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`BP-^X^+7((,#,N*<N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`S"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+B(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("+`
MW[CXM<@@P,RXIRXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(L#?N/BUR"#!UKS2M\\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<G1N97(@
M:60N(@IM<V=S='(@(L#?N/BUR"#!UKS2M\\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R
M;V1U8W0@8V]D92XB"FUS9W-T<B`BP-^X^+7((,'6O-*WSR(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`BP-^X^+7(
M(,'6O-*WSR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@HC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`BP-^X^+7((,#,
MN*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R
M97-S+B(*;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6O-(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("+`W[CX
MM<@@P,RXIRXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS
M9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0HC+"!F=7IZ>0IM<V=I9"`B26YV
M97)T('-E;&5C=&EO;B(*;7-G<W1R("+`VKBCL>(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M(RP@9G5Z>GD*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`BM.O'T;G.L;DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("))<F5L86YD
M(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS
M9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*(RP@9G5Z>GD*;7-G:60@(DES<F%E;"(*;7-G<W1R("+`T,'V(+[*P+H@
MN-[`SR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U
M"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T
M<B`BL>*_[\#,L>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET
M86QY(@IM<V=S='(@(L#/NK`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I
M8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B,;_Y(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("+`S[J[(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R
M,BU*4"DB"FUS9W-T<B`BP,^ZN[[N("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP
M="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@
M<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I
M9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R
M9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(C>_^2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*
M=6YE(@IM<V=S='(@(C:_^2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T
M<B`BP:2WQ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R
M("*PH;_NM:4@P:2WQ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS
M9W-T<B`BON?"RB#!I+?$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*
M;7-G<W1R("*_WL+*(,&DM\0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H
M="(*;7-G<W1R("*_P+BEPLH@P:2WQ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B
M2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@
M(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+
M97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$*(RP@9G5Z>GD*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R("+$N+S'(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("*XWKW#P?8B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*(RP@9G5Z>GD*;7-G:60@(DME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B9G1P(+RMN?8@OZRPX2"_P+?Y+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0HC
M+"!F=7IZ>0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`BM.O'T;G.L;DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("*TZ\?1N<ZQN2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`BQ]&QN;[N("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("*WSK'7
MOL:_]"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@
M(DQA;F=U86=E(@IM<V=S='(@(K[PONXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DQA
M<W0@2&%L9B(*;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T(%!A<W-W;W)D
M($-H86YG92(*;7-G<W1R("*^S\BC(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B3&%S
M="!1=6%R=&5R(@IM<V=S='(@(KBVP?:XMR#&Y,#,P?8B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B3&%S="!5<&1A=&5D
M.B(*;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(@IM<V=S='(@(KBVP?:XMR"WSK'7P,XZ("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@
M;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BN+;!]KBW(+?.L=?`SCH@)7,L
M(,&BO-,@P*?$H3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(KBVP?:XMR"W
MSK'7P,XZ(+[XP+TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DQA
M='9I82(*;7-G<W1R("*XN+7IL>(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U
M="(*;7-G<W1R("*WN<#,OL:_]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A
M;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("*_WL+*
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0HC+"!F=7IZ>0IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`BO[DZ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU
M97,B"FUS9W-T<B`BO[DZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`BP,RUOR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"B,L
M(&9U>GIY"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(K?.L=?`SB(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L
M(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(K?.L=?`SB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"B,L(&9U
M>GIY"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(K?.L=?`SB(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"B,L
M(&9U>GIY"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`BM\ZQU\#.
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*
M(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(K?.
ML=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,P"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G
M<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T
M"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S='(@(K?.L=?`SB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M=&UL,G1E>'0N<&AP.C$X,PHC+"!F=7IZ>0IM<V=I9"`B3&EN:W,B"FUS9W-T
M<B`BM\ZQU\#.(+W#P-O`V[[W(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`BN_4@
MN-[`SR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PHC+"!F=7IZ>0IM
M<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`BN+;!]KBW(,;DP,S!]B(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE
M;'`@5&]P:6-S(@IM<V=S='(@(K6UO_*^RR"X\<+W(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="!486)L97,B"FUS
M9W-T<B`BN+;!]KBW(,;DP,S!]B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DT"B,L(&9U>GIY"FUS9VED("),:7-T+4%R8VAI=F4B
M"FUS9W-T<B`BN^>_Z\?/P?8@OLJTPB"XWL#/Q]0@O/NQZ"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED
M("),:7-T+4AE;'`B"FUS9W-T<B`BM;6_\K[+(+CQPO<B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@HC+"!F=7IZ>0IM<V=I9"`B
M3&ES="U)9"(*;7-G<W1R("*UM;_ROLL@N/'"]R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"B,L(&9U>GIY"FUS9VED("),:7-T
M+4]W;F5R(@IM<V=S='(@(K6UO_*^RR"X\<+W(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M,0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`BN^>_
MZ\?/P?8@OLJTPB"XWL#/Q]0@O/NQZ"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DP"B,L(&9U>GIY"FUS9VED("),:7-T+55N<W5B
M<V-R:6)E(@IM<V=S='(@(KOGO^O'S\'V(+[*M,(@N-[`S\?4(+S[L>@B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("*[
MY[_KQ](@O/8@OOBTPB"[Y[_KP-H@N/&WSRXB"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("*[Y[_KQ](@O/8@OOBTPB"[Y[_K
MP-H@N/&WSRXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(KOGO^O'TB"\]B"^^+3"(+OGO^O`VB"X\;?/+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-PHC+"!F=7IZ>0IM<V=I9"`B3&ET97)A='5R92(*;7-G
M<W1R("*\K;CM.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B3&ET
M:'5A;FEA(@IM<V=S='(@(K/*NO$@M-S`IR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,0HC+"!F=7IZ>0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(KW'Q^`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A
M;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP
M:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(KW'Q^`B
M"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`BM\ZQU\#.(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E
M=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B
MM\ZQU[[&O_0B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z
M>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@
M(K?.L=?`SB"]P\#;P-N^]R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDY-@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2XB"FUS9W-T<B`B(@HBONZVLB#`S,"OM\X@M\ZQU\#.P,P@O<?&T,??O<"T
MS[39+B"TZ[K.NM#`QR"PYK_L(+OGO^O`VB#`S+BG(+;'M,(@OL_(H["A(,#?
M(@HBN/@@P-2WPK7((+#FO^P@N=^[_<?5M,^TV2XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.3(*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE
M9"XB"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@
M(K?.L=>^QK_T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"B,L(&9U
M>GIY"FUS9VED("),;W9E(@IM<V=S='(@(L#,M;\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS
M9W-T<B`BL=>XKKVZ(+S2N:[`VB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`BMO/&OB"\TKFNP-HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS
M9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(K?.N+8@O-*YKL#:
M(+S]P-HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R
M(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@
M(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(DU3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`BQL3`S[^A(+[&N:NW
ML2#`VK?AL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PHC+"!F=7IZ
M>0IM<V=I9"`B35-'(@IM<V=S='(@(D-64R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F
M=7IZ>0IM<V=I9"`B36%C86\B"FUS9W-T<B`B,[_Y(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ
M"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S
M8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC
M+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`BP*6XWL#/(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@
M(KC>P,\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED
M(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L
M:6Y?:RXN+B(*;7-G<W1R(")?:[BUQ:D@N+BUZ;'B+BXN(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`BP*6XWL#/(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")-86QA>7-I82(*;7-G<W1R
M("+`I;C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&1I
M=F5S(@IM<V=S='(@(KC>P,\@Q\K%S2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ
M>0IM<V=I9"`B36%L:2(*;7-G<W1R("+`I;C>P,\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(L"EN-[`SR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X
M-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V
M.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B,[_Y(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM
M<V=I9"`B36%R9VEN(@IM<V=S='(@(K"AP.7`VKBN(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B36%R=&EN
M:7%U92(*;7-G<W1R("*PH<#EP-JXKB(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B
MP,_$H<?/M,(@Q]>X\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B
M36%U<FET86YI82(*;7-G<W1R("*PH<#EP-JXKB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L
M;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*(RP@9G5Z>GD*;7-G:60@
M(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("*XWKW#P?8@
MQ]>X\2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@
M(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B
M-;_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B36%Y;W1T92(*
M;7-G<W1R("(UO_DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*(RP@
M9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(KOHP::UR""XWL#/(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@HC+"!F=7IZ
M>0IM<V=I9"`B365M8F5R<R(*;7-G<W1R("(Q,;_Y(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("*X
MWK2Z(+CPM>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("*\
MOR#'U<2AL>(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("*XWKW#
MP?8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R("*XWKW#P?8@Q]>X\2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*
M(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("*XWKW#P?8@
MP,_`VB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@
M5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M"B,L(&9U>GIY"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(KR\NL[!I+JX
ML*$@L/RXKL#:N*8@P*?'V""QXK?/M<>^[L&SO<"TS[39+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#
M+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D
M(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`BL*&_[K6E(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G
M:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R
M9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY
M"FUS9VED(")-:7)R;W(B"FUS9W-T<B`BO\"W^2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S
M="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM
M<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P
M;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`HC+"!F=7IZ>0IM<V=I9"`B36ES
M<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("*XWKW#P?8@P,RUO\?/L>(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDT"B,L(&9U>GIY"FUS9VED(")-:7-S:6YG('-E
M<W-I;VX@240N(@IM<V=S='(@(KC>O</!]B#`S+6_Q\^QXB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*(RP@9G5Z>GD*
M;7-G:60@(DUO(@IM<V=S='(@(L#,M;\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-S0*(RP@9G5Z>GD*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S
M='(@(KOU(+C>P,\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@
M(E523""\]L&D(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-S,*(RP@9G5Z>GD*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`BOZK'TB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B36]L9&]V82P@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`BM.O'T;G.L;DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*(RP@9G5Z
M>GD*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(SO_DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BN,6_^2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@
M4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T
M:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T
M<B`BNKF[YR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`BOL:WH;?.(,#,M;\B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(RP@9G5Z>GD*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R("+`I[?.(,#,M;\B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HU,3<*(RP@9G5Z>GD*;7-G:60@(DUO=F4@4FEG
M:'0B"FUS9W-T<B`BO\"XI<+*(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(L"GM\X@
MP,RUOR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("*^QK>A
MM\X@P,RUOR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-`HC+"!F=7IZ>0IM<V=I9"`B36]V92!U<"(*;7-G<W1R("+`I[?.
M(,#,M;\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B
M375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED
M(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T,@HC+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@<V5L
M96-T:6]N(@IM<V=S='(@(K'4Q*(HM_PI(+RQQ<,@O\"W^2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*(RP@9G5Z>GD*;7-G:60@(DUY($%C
M8V]U;G0B"FUS9W-T<B`BO\"XI\+WO/@B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I
M;VXB"FUS9W-T<B`BP:2ZN"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP
M:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B37EA
M;FUA<B(*;7-G<W1R("+`S+BG(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B3F%M92(*;7-G<W1R("+`S+BG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U
M<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").
M97!A;"(*;7-G<W1R("*[]2"XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY
M"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("*[]2"XWL#/(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED
M(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC
M>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R
M"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`BL]?&KK_V
MQ:DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R("*[Y[_KOLC'U"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@
M(KC>O</!]B#`V[RZ("@E<RDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(KOU(+C>P,\B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"B,L(&9U>GIY
M"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("*UM;_R
MN+LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(DYE=R!:96%L86YD
M(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R
M("*^S\BC(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@
M;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`BOL_(H["A(,#/Q*''S\'V(+[*O<"TS[39+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G
M:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`BN_4@PZ(H7V)L86YK
M*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L
M(&9U>GIY"FUS9VED(").97=S(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U
M"FUS9VED(").97AT(@IM<V=S='(@(K39P+TB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T
M<B`BM-G`O2#&Y,#,P?8B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F
M=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(K_)O,?`N+?.(+6Y
MOL:PH;'B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*(RP@
M9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S='(@(K39P+TB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(KOGO^N^R,?4(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<FEA(@IM<V=S='(@(KOG
MO^N^R,?4(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`HC
M+"!F=7IZ>0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`BO\"XI<+*(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"B,L(&9U>GIY"FUS9VED(").:75E(@IM<V=S='(@(L+\P;8B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS
M9VED(").;R(*;7-G<W1R("*^QK3/O\`B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E
M;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W
M"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN
M<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@P,[!
M]2"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(KJO
ML.:[Y\?7(+7'M;FXKK'B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R
M"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")344P@5D93(+RSP:3!I+JXL*$@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!&5%`@5D93+B(*;7-G<W1R(")&5%`@5D93N*8@P*?'T2"\L\&DP:2Z
MN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B4U%,(%9&4R"\L\&DP:2ZN+"A
M(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(E-13"U&:6QE(%9&
M4R"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"B,L(&9U>GIY"FUS9VED(").;R!D97-T
M:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`BN_4@N-[`SR(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PHC+"!F=7IZ>0IM<V=I9"`B
M3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("+'RK7E(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(L;ZM/6XIB"\L<7#
MQ\^\O+_D(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI
M960N(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC+"!F=7IZ>0IM<V=I9"`B3F\@
M;F%M92!S<&5C:69I960N(@IM<V=S='(@(KFNP-J_K2#`U+?"(+_`M_DB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T
M<B`BN:[`VK^M(,#4M\(@O\"W^2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*(RP@9G5Z>GD*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")344P@P,[!]2"\L\&DP:2ZN+"A(+[XO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"B,L(&9U
M>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^^+W`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"B,L
M(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"#`SL'U(+RSP:3!I+JX
ML*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")344P@P,[!]2"\L\&DP:2ZN+"A(+[XO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^^+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@
M<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C<U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T
M+B(*;7-G<W1R("+!IKCQ(+[XP+TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").
M;R!R=6QE<R(*;7-G<W1R("+"_,&V(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E
M8VEF:65D+B(*;7-G<W1R("*YKL#:OZT@P-2WPB"_P+?Y(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`BPOS!MB(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"B,L(&9U>GIY"FUS9VED(").;R!S
M=6-H(&9I;&4B"FUS9W-T<B`BPOS!MB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G
M:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R
M("*[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'S[R\O^0B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*(RP@9G5Z>GD*;7-G:60@(DYO('9A
M;'5E<R(*;7-G<W1R("+"_,&V(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`BO+'%
MP\?/P?8@OLK`O2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE
M<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYO<G=A>2(*;7-G<W1R("+`_+3>(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*(RP@9G5Z
M>GD*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("+`T[W#NKBP_+7'P?8@OLK`
MNB"XWL#/(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,SD*(RP@9G5Z>GD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`BP-.]P[JX
ML/RUQ\'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S
M='(@(K7PM[K%Y+BN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(RP@9G5Z
M>GD*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`BN^C!IK7'P?8@
MOLK`NB"XWL#/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R("+!
MIKCQ(+[XP+TB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V
M-0HC+"!F=7IZ>0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BN^C!
MIK7'P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*
M;7-G<W1R("+"_,&V(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP
M.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(C$QO_DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B
M"FUS9W-T<B`B,3&_^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C4*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S
M='(@(L?@P,<@O/8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T
M<B`BOZW`QR"\]B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("+'
MX,#'(+SV(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I
M9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S
M='(@(L&FN/$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0HC
M+"!F=7IZ>0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`BP::X\2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*(RP@9G5Z>GD*;7-G
M:60@(D]C=&%L(@IM<V=S='(@(L#/NK`B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R
M("(Q,+_Y(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/
M9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S(V"B,L(&9U>GIY"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B
MP::X\2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I
M9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*
M(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("*^S\BC(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS
M9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(K[/
MR*,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@
M(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3<Q"B,L(&9U>GIY"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S
M(&%L;&]W960N(@IM<V=S='(@(L#?N/BUR"#`S+C>P,\@P=:\TB(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@
M;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE
M<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*(RP@9G5Z>GD*
M;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(KOU(,.BOZ$@
MN+7%J2"_K;'B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T
M(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R("*[]2##HK^A(+BUQ:D@OZVQXB(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/
M<'1I;VYS(@IM<V=S='(@(KRQQ<.[Y\?7(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(B5S(+RQQ<.[Y\?7
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(KS]P-H@N/&WSR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")/
M<F=A;FES871I;VXB"FUS9W-T<B`BM-S#O"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38X"B,L(&9U>GIY"FUS9VED(")/<F=A;FES
M871I;VYA;"!5;FET(@IM<V=S='(@(K3<P[PB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")/<F=A;FEZ:6YG(@IM
M<V=S='(@(K3<P[PB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0HC+"!F
M=7IZ>0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS
M9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN
M("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B
M"FUS9W-T<B`BL>+%N"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*
M;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(K'BQ;@@P:2ZN"(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*(RP@9G5Z>GD*;7-G
M:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(KOGO^O`VB"QQ\?1(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"B,L(&9U>GIY"FUS
M9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`BN^C!IB"]Q\;0(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3(W,PHC+"!F=7IZ>0IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM
M<V=S='(@(KRMN.TZ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@
M(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X
M"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,W"B,L(&9U>GIY"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(K?.
ML=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G
M:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]3
M25@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*
M;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`BQN2U^2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC
M+"!F=7IZ>0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`BNMG`S+'B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B4&%L874B"FUS9W-T<B`BP*6X
MWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z
M>GD*;7-G:60@(E!A;F%M82(*;7-G<W1R("+`S+BG(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"B,L(&9U>GIY"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(KJYN^<B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R
M9"(*;7-G<W1R("*^S\BC(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS
M9W-T<B`BOL_(HR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H
M<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"#`SL'U(+RSP:3!
MI+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`U,PHC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VXB"FUS9W-T<B`BL>+%N"#!I+JX(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#HB"FUS9W-T
M<B`BOL_(HR(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L
M(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(K[/R*,B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S
M-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED
M(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`BOL_(H["A(,#/Q*''
MS\'V(+[*O<"TS[39+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R
M"FUS9VED(")087-T92(*;7-G<W1R("*ZV<#,L>(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F
M<F]M(&-L:7!B;V%R9"(*;7-G<W1R("+%K+BSNKBUY;^AO*T@NMG`S+'B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM
M<V=I9"`B4&%T:"(*;7-G<W1R("*PYK?.(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS
M9VED(")096]P;&4B"FUS9W-T<B`BOZK'TB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM
M<V=S='(@(L;;O+[&KB(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,B"FUS9W-T<B`BP*_!]B"P_+BN(,#;OO<@O<?'X"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*(RP@9G5Z>GD*;7-G:60@(E!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B
MP*_!]B"P_+BN(,#;OO<@O<?'X"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N(@IM<V=S
M='(@(K"SP,X@N-[`SR(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB
M(&YO="!D96QE=&5D+B(*;7-G<W1R("*]Q+JPP-H@7"(E<UPB(+"A(+OHP::U
MQ[[ZO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V
M"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("*P
ML\#.(+C>P,\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM
M<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ>2WT"(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*
M(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(K#\N*XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(K"S
MP,X@P:2ZN"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*(RP@9G5Z>GD*;7-G:60@
M(E!E=',B"FUS9W-T<B`BQ\B\OR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI
M;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`BP/S(
MK;GXR*,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED
M(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("+'R+R_
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U
M9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O
M('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*(RP@9G5Z>GD*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@
M(KOUM\Z_[B#`S+BGP+L@P-2WPL?/O+R_Y#HB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS
M9W-T<B`B7%QNN_6WSK_N(+C>P,_'U,#'(,#,N*?`NR#`U+?"Q\^\O+_D.EQ<
M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*(RP@9G5Z>GD*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S
M='(@(K_#N=FXI2"PR[OV(+G\P=:XIB#`U+?"Q\^\O+_D+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-3$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N(@IM<V=S='(@(K_#N=FXI2"PR[OV(+G\P=:XIB#`U+?"Q\^\O+_D+B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T
M<B`BN:[!IK^A(+3KQ]$@O^2^X,"[(,#4M\+'V"#!UKR\O^0N(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9"(*;7-G<W1R("*[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4
MM\+'S[R\O^0B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T
M:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(KOUM\Z_[B#`S+BGP+L@
MP-2WPL?/O+R_Y#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!O
M;&%N9"(*;7-G<W1R("+(N+OG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#@W"B,L(&9U>GIY"FUS9VED(")0;VQL<R(*;7-G
M<W1R("*_K3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3$*(RP@9G5Z>GD*;7-G:60@(E!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`BQZ7`QR"SRKKQ(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@
M=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N
M(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N
M/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"B,L(&9U
M>GIY"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(K[/R*,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("*YS+BNNKBQXB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(KOU(,.BOZ$@N<RXKKJXL>(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R
M("+`S,#\(+C>O</!]B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@
M(KFNO*T@P,Z\XB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B
M4')O8FQE;2(*;7-G<W1R("*YKL&F(+G?N_T_(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S
M='(@(KFNP:8@O+.X[2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"B,L(&9U>GIY"FUS
M9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("*QL\&DM<@@N:[`VK^M(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L
M:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B46%T87(B
M"FUS9W-T<B`BP,_`VB(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I
M9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")2
M4T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C8T"B,L(&9U>GIY"FUS9VED(")2861I;R!S
M96QE8W1I;VXB"FUS9W-T<B`BO<.PHR"\L\&D(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*(RP@9G5Z>GD*;7-G:60@(E)A
M:6XB"FUS9W-T<B`BL*'`Y<#:N*XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I
M9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS"B,L(&9U>GIY"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G
M<W1R("+"_,&V(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V
M"B,L(&9U>GIY"FUS9VED(")2871I;R(*;7-G<W1R("+$N+S'(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*(RP@9G5Z>GD*;7-G
M:60@(E)E860B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ>0IM<V=I
M9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("*[]2"XWL#/(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L
M87-T(&%C=&EO;B(*;7-G<W1R("*XML'VN+<@N.VWR2"YW;JY(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE
M;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$*(RP@9G5Z>GD*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S
M='(@(KC>P,_'U""[];?.(,#0L>(Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G
M97@B"FUS9W-T<B`BP.>\L\&D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D
M(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E(%-E
M<G9E<G,B"FUS9W-T<B`BO+'%P[7((+C>P,\@N^C!IB(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(@IM<V=S='(@(L;DONXH<&%I<BD@N^C!IB(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K
M(@IM<V=S='(@(KRQQ<.UR""XWL#/(+OHP:8B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4@8V]L=6UN(@IM<V=S='(@(K[&MZ&WSB#`S+6_(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BOL:WH;?.(,#,M;\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`BQN2^[BAP86ER*2"[Z,&F(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R
M("*\L<7#M<@@N-[`SR"[Z,&F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@
M(E)E;6]V92!U<V5R(@IM<V=S='(@(L;DONXH<&%I<BD@N^C!IB(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(L;DONXH
M<&%I<BD@N^C!IB(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")297%U97-T960@
M<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(KRMN.W`NR"Z
MK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9&4R"\L\&D
M(,&DNKB_H;RM("=P;W)T)\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")61E,@
MO+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(E9&4R"\L\&D(,&DNKB_H;RM("=P;W)T)\#,(+[X
MO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP
M.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(L#4M\(@
MP^N\TB(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U
M>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("*^S\BC(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@
M(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BOL_(HR#(KL#.(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R
M92!,87-T(%%U97)Y(@IM<V=S='(@(KBVP?:XMR#&Y,#,P?8B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN
M+W-Q;'-H96QL+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<R(*;7-G
M<W1R("*PR[OV(+#AL/HB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R
M;B!T;R!/<'1I;VYS(@IM<V=S='(@(K_)O,?`N+?.(+6YOL:PH;'B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L(&9U>GIY"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(K[/R*,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`HC
M+"!F=7IZ>0IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
MN-[`SR"\K;GV(,&DNKB[Y\?7(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M(@IM<V=S='(@(K_)O,?`N+?.(+6YOL:PH;'B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")2:61D;&5S(@IM<V=S='(@
M(K"AO^ZUI2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`BO\"XI<+*(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3<*(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("*_
MN3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")?=\?@(+S3O+HN+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(K^JQ](B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@
M(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B4F]T871E
M($QE9G0B"FUS9W-T<B`BP*>WSB#`S+6_(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S
M='(@(L?@(+S3O+HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R("+'X""\T[RZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(L?@.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(K^JQ](B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E
M9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM
M<V=I9"`B4G=A;F1A(@IM<V=S='(@(K3>M\(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R
M87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S(S"B,L(&9U>GIY"FUS9VED(")3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`BN-Z]P\'V(,#\O-LB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"B,L(&9U>GIY"FUS9VED
M(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(KOHP:8@O<?&T"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`BN-Z]
MP\'V(+JXL>(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-1
M3"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*
M;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED
M(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I
M9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"B,L(&9U>GIY"FUS9VED(")382(*
M;7-G<W1R("+`^L#E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L
M96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET
M=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B
M4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T
M<B`BL+#`NB#'P;>YP-,H7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I
M9"`B4V%N($UA<FEN;R(*;7-G<W1R("*PH<#EP-JXKB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("+`^L#E(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`BM-FX
MI<#,N*?`N+?.(,#ZP.4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G
M<W1R("*TV;BEP,RXI\"XM\X@P/K`Y2(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("*\L<7#N^?'
MUR#`^L#E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B
M(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]P+3/
MM-DN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C
M:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G
M:60@(E-E87)C:"(*;7-G<W1R("*PR[OV(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,R,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($5N9VEN97,B
M"FUS9W-T<B`BL,N[]B"PX;#Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDW,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@
M(KCPM<X@O+'%PR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS
M9W-T<B`BO<2ZL,#:(+RQQ<,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D
M(@IM<V=S='(@(KFNP-J_K2"\L<7#.B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE
M<B(*;7-G<W1R("*\L<7#(,/KO-(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*
M;7-G<W1R("*YKL#:OZT@O+'%PSHB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A
M9&0B"FUS9W-T<B`BN:[`VK^M(+RQQ<,Z(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&%L;"(*;7-G<W1R("*X\+7.(+RQQ<,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`BLZ_`VB#'_+W$(+RQQ<,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(KRQQ<,@P^N\
MTB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(KRQQ<,@
MP^N\TB(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(K[&MZ$@N_/`VK^AO*T@Q\J_
MY,?1(+FNP-JXIB"\L<7#Q\^P[2"ZN;OGQ\^_J2"ZV;^IL];`N+R\O^0N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(K.OP-H@L;BZT,>EO<,@O+'%
MPSHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`BLZ_`VB#'_+W$(+RQQ<,B
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93HB"FUS9W-T<B`BP-/&]\:NQ](@P*?$H2"\L<7#.B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("*SK\#:(+&XNM#'I;W#
M(+RQQ<,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@
M(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(KW#L*,@Q_R]Q""\
ML<7#(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(K7.L+/`QR#`
MS\2AQ\^TPB#'U[CQ(+RQQ<,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`BP-K!UKOGO^O'
MS[3"(+[PONZXIB"\L<7#Q\^\O+_D+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(KFNP::YW[O](+JXL.V\K2#`_+S;Q\^QXB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"B,L(&9U>GIY"FUS
M9VED(")396YD(%--4R(*;7-G<W1R("*XWKW#P?8@P/R\VR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,38*(RP@9G5Z>GD*;7-G:60@(E-E;G-O<CH@(@IM<V=S
M='(@(B#!IKCQ.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(CF_^2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")3
M97)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*(RP@9G5Z>GD*;7-G:60@(E-E
M<FEA;"!.=6UB97(B"FUS9W-T<B`BO/W`VB(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@
MO+'%P[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`BL/RX
MKB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,@HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*
M;7-G<W1R("*XWKW#P?8@Q]>X\2(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F
M=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`BQ>2WT"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*(RP@9G5Z>GD*;7-G:60@(E-E="(*
M;7-G<W1R("*XWKW#P?8@O+'%PR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@
M(L;DP,S!]B"PN[W%P=:QXB"YUR"QXL6X(,BMN.D@O+/!I,"[(,?/O+R_Y"XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@
M(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R("+&Y,#,P?8@L+N]Q<'6L>(@N=<@L>+%N"#(K;CI(+RS
MP:3`NR#'S[R\O^0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC
M+"!F=7IZ>0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`BN-Z]P\'V(+RQQ<,B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*(RP@
M9G5Z>GD*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(K#%N*XB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B
M4VAO<G0@4W5M;6%R>2(*;7-G<W1R("*PH[3<Q]$@O^2^X#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H
M;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM
M<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"B,L
M(&9U>GIY"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I
M;F<@:6X_(@IM<V=S='(@(K?.L=?`SKW#(,/6P;X@M\ZQU\#.(+W#L*,@NKB_
MJ<'6L>(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED
M(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC
M:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*
M(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\B"FUS9W-T<B`BQZ4@O-.\NL.B(+JXL>(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("*\OR"\T[RZPZ(@NKBQXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQZ4@O-.\NL.B(+JXL>(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("*_K2"\T[RZPZ(@NKBQXB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I
M9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
ML=>XLB"\T[RZPZ(@NKBQXB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(K.[
MM\&YWK'B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`BP-"^[K_`
ML>(HP-/&]\:N*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S
M='(@(K"CM-S'T2"_Y+[@.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*
M;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`HC+"!F=7IZ
M>0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A
M($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
MO*VX[3HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@HC+"!F=7IZ>0IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(KRMN.TZ(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*(RP@9G5Z
M>GD*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`BO*VX[3HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3:6YG87!O<F4B"FUS
M9W-T<B`BO*VX[3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S
M"FUS9VED(")3:7IE(@IM<V=S='(@(L6IL>(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN
M=&5N86YC92(*;7-G<W1R("+`K\'VL/RXKB"[_;>K(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*
M;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@9G5Z>GD*;7-G:60@(E-N;W<@9&5P
M=&@Z("(*;7-G<W1R("(@P::X\3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N
M9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3(V"B,L(&9U>GIY"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO
M;B(*;7-G<W1R("+!I+?$(+GFN?TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+!]\#E(,'6O-(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O
M=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS
M9W-T<B`BO+^PH[#=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`BO+\@L.:PZ+_-(+.[O^L@N^?`
MS,#'(+"CL-TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*(RP@
M9G5Z>GD*;7-G:60@(E-P86-E<B(*;7-G<W1R("+`^L#E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED
M(")3<&%C:6YG(@IM<V=S='(@(K#%N*XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG
M(&%N9"!P861D:6YG(@IM<V=S='(@(K#%N*Z_S2##I+_LL>(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0HC+"!F=7IZ>0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`BL,6XKB(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B
M4W!A;2(*;7-G<W1R("+`^L#E(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("+&
MK[SV(+FNP-H@P-2WPB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T
M<B`BO+\@NM#'TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R
M("*_K2"ZT,?2(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(L?@
M(+K0Q](B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*
M;7-G:60@(E-P;W)T<R(*;7-G<W1R("+`T+[NO\"QXBC`T\;WQJXI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(K3>M\(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE
M87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED
M(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T
M<B`BN-[`SR"\K;GV(,&DNKB[Y\?7(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R
M97-S(@IM<V=S='(@(L'WP.4@P=:\TB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B
M"FUS9W-T<B`BL*&_[K6EP=DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,S"B,L(&9U>GIY"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("*\
M]KW%L,6ZSB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G
M:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(KVZQ;C`SUM#4U-=
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BQ>O!]B"XKKVZL\H@)7/`
MNRBXIBD@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S
M='(@(L&FN/$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M
M:70B"FUS9W-T<B`BP:;#XB(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U
M<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS
M9VED(")3=6)S8W)I<'0B"FUS9W-T<B`BOL:WH<.WP-HB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E
M<W,B"FUS9W-T<B`BO+JP^"(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R>PH2"]P[VZQ=N_H2##
MW["AM<>^^KW`M,^TV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A
M=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M)R5S)["A(+W#O;K%V[^AO*T@N^C!IK7'OOJ]P+3/M-DN(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<
M(B5S7"(N(@IM<V=S='(@(B<E<R>PH2"]P[VZQ=N_H2##W["AM<>^^KW`M,^T
MV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TN(@IM<V=S='(@(B<E<R>PH2"]P[VZQ=N_H;RM(+OHP::UQ[[Z
MO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@
M(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PHC+"!F=7IZ
M>0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`
MM,^TV2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B)R5S)["A(+W#O;K%V[^A
M(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)R5S
M)["A(+W#O;K%V[^A(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`BO^2^X"(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0HC
M+"!F=7IZ>0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`BP::X\2(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4W5N(%-E
M="(*;7-G<W1R("+!IKCQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*(RP@9G5Z>GD*;7-G:60@
M(E-U;G)I<V4B"FUS9W-T<B`BP::X\2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I
M9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`BP::X\2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(E-U;G)I
M<V4Z("(*;7-G<W1R("(@P::X\3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@
M(L&FN/$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"B,L
M(&9U>GIY"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(@P::X\3H@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I
M9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BP*W#M\#:(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*
M;7-G<W1R("+`T+[NO\"QXBC`T\;WQJXI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F
M=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`BP,RXIR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED
M(")3=7)N86UE(@IM<V=S='(@(L#,N*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("+#H['B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4W=E9&5N(@IM<V=S
M='(@(L#0P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N
M9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("*Z
MN;&X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN
M8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I
M9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@
M(E0M4W1O<FUS(@IM<V=S='(@(L"GQ*$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V
M-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`BP::X\2(*"B,Z
M(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED
M(")486)L92(*;7-G<W1R("+!IKCQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O
M<&5R=&EE<R(*;7-G<W1R("+'I2"\T[RZ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B5&%B
M;&4@4V5T(@IM<V=S='(@(L&FN/$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P
M97)T:65S(@IM<V=S='(@(L>E(+S3O+HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J
M:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS
M9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(K3K
MQ]&YSK&Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("*XWKW#
MP?8B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(L#;OO<B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I
M9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E
M;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")496UP
M;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E
M<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("*P_+BN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")4
M97AT(@IM<V=S='(@(KFNP-J_K2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("*YKL#:(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM
M<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("*YKL#:(,&DM\0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"B,L(&9U>GIY
M"FUS9VED(")497AT=&]P(@IM<V=S='(@(KFNP-J_K2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4
M:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U
M>GIY"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("+#H['B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S
M:6YG('1H92!S>7-T96TN(@IM<V=S='(@(KOGO^O'V,'6O,6\K2"PJ+OGQ]6T
MS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"B,L(&9U
M>GIY"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"B,L(&9U>GIY"FUS9VED
M(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G
M<W1R("*\K;CMP+L@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4
M:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!0
M97)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O
M;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q
M"B,L(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("+'U[CQ(%PB
M)7-<(K"A(,'6O-*WS[^A(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A
M8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF
M>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C
M;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(L;$P,^_H2"^QKFKM[$@P-JW
MX;"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X
M,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@
M(L;$P,^_H2"^QKFKM[$@P-JWX;"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F
M;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C
M.#(R(&UE<W-A9V4N(@IM<V=S='(@(K[&MZ&TPB#`S"!M97-S86=E+W)F8S@R
M,B#&[<'VP,<@N-.XM+B[P-2TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I
M9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BO<2Z
ML,#:(%PB)7-<(B"PH2"[Z,&FM<>^^KW`M,^TV2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4
M:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB
M)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A
M;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S
M=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T
M:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O
M9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("+`S""PJL"Z(+S]
MP-J_J;[?(,?5M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U
M:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V
M:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@
M<WES=&5M+B(*;7-G<W1R("+`S""XWKW#P?8@Q_S%PB@E<RFXIB"ZN+'B(,"G
MQ]$@Q\&WSK'7MZ7`NR##H\"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("*]Q+JPP-H@
M7"(E<UPB(+"A(+OHP::UQ[[ZO<"TS[39+B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`BO<2Z
ML,#:(%PB)7-<(B"PH2#`^L#EM<>^^KW`M,^TV2XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B
MO<2ZL,#:(%PB)7-<(B"PH2#`^L#EM<>^^KW`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C
M:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS
M9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T
M97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*
M;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W
M;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@HC+"!F=7IZ>0IM<V=I9"`B5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("*\
MK;CMP+L@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
MP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+%
MZ\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@
MO+'%P[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HS-#(*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N
M;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD
M+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T
M(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H
M<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H
M92!S>7-T96TZ("5S(@IM<V=S='(@(B<E<R>XIB"]P[VZQ=N_H2##W["AQ](@
MO/8@OOB]P+3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(B<E<R>XIB"]P[VZQ=N_H;RM(+OHP:;'TB"\]B"^^+W`M,^TV2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B<E<R>XIB"]P[VZQ=N_H;RM(+OH
MP:;'TB"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(G)7,GN*8@O<.]NL7;OZ$@
MP]^PH<?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L
M;V%D960N(@IM<V=S='(@(L;$P,\@O\.XKK'BOZ$@N:[!IK"A(,#6O<"TS[39
M+B`E<R#&Q,#/P,P@OO>WSK7EM<?!]B"^RK[2O<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HBQL3`
MSR"^][?.M>4@O\"W^2X@P,S&Q,#/P+H@OO>WSK7E(,?CO^NUR"##UK3K(,6I
ML>(H)60@34(INKBTV2#%J[#-(+"PO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS
M9W-T<B`B(@HBOO>WSK7E(,;$P,^_H2"YKL&FL*$@P-:]P+3/M-DN(,#,QL3`
MS\"Z(+[WM\ZUY2##UK3KQ^._Z\6IL>*XIB##RK#ZQ]6TS[39+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T(@IM<V=S='(@(KC>O</!]B#`_+S;(+_`M_DB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"B,L(&9U>GIY
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N(@IM<V=S='(@(K6EP,S%N"#`T\;WQJX@O\"W^2(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(K6EP,S%N"#`T\;WQJX@O\"W^2(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("*_
MY,.[M<@@N-Z]P\'V(,#0L>(@O\"W^2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"B,L(&9U>GIY"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`BO^3#N[7((+C>O</!]B#`T+'B(+_`M_DB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC
M+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(K[WM\ZUY2#&Q,#/(,#3QO?&KB"_P+?Y(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*(RP@9G5Z>GD*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(K_DP[NUR""XWKW#P?8@P-"QXB"_P+?Y(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"B,L(&9U>GIY"FUS9VED(")4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+B(*;7-G<W1R("*ZZK;SO^S`^K"A(,#,(+'BM,G`NR#!]K_XQ\_!]B"^
MRKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("+`S""PJL"Z(+S]
MP-J_J;[?(,?5M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C4R"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("+`S""PJL"Z
M(+S]P-J_J;[?(,?5M,^TV2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,30U"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BP,P@L*K`NB"\_<#:
MOZF^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL
M("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P
M-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U
M>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M(@IM<V=S='(@(L#,(+"JP+H@O/W`VK^IOM\@Q]6TS[39+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@
M;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M
M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"B,L(&9U>GIY"FUS9VED(")4
M:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@
M(L#,N<P@P=:\TK?/OZ$@M>ZWS[7'ONX@P-:]P+3/M-DN(@H*(SH@=&5M<&QA
M=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*
M;7-G<W1R("+`S""\_<#:M,(@P]:\TL?1(#'`VKBN(,#,N_/`S+[NOM\@Q]6T
MS[39+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@
M86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I
M<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(L#,(+"JP+H@O/W`VK^IOM\@
MQ]6TS[39+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@
M3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B
M5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ
M>0IM<V=I9"`B5&EM92(*;7-G<W1R("+!IKCQ(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@
M(E1I;64@9F]R;6%T(@IM<V=S='(@(KW#L*,@O+/!I"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U,SD*(RP@9G5Z>GD*;7-G:60@(E1I;64@<V5L
M96-T:6]N(@IM<V=S='(@(KW#L*,@O+/!I"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(L&FN/$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L
M92`H=&]O;'1I<"DZ(@IM<V=S='(@(L6XP,S&LBC%^,;!*3HB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4
M;R(*;7-G<W1R("*YWK3"(+OGMO<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"B,L(&9U>GIY
M"FUS9VED(")4;V1A>2(*;7-G<W1R("*ZN[FN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A4
M34P@4V]U<F-E(@IM<V=S='(@(DA434P@O-*]NB"ZN+'B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G<W1R("*YWK3"(+OGMO<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*(RP@9G5Z>GD*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(B`HL[O`SRDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"B,L(&9U>GIY"FUS9VED(")4;VYG82(*;7-G<W1R("*YWK3"(+OGMO<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S<*;7-G:60@(E1O<"(*;7-G<W1R("+`IR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H
M7W1O<"DB"FUS9W-T<B`BN_/`IR#'P;>YP-,H7W1O<"DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E1R86YS;&%T:6]N
M<R(*;7-G<W1R("+(K[#FO+/!I"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R
M:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U
M<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM
M<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y
M;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B
M55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@
M<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ
M(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@
M(E5G86YD82(*;7-G<W1R("*TWK?"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC+"!F=7IZ
M>0IM<V=I9"`B56MR86EN92(*;7-G<W1R("*YV,'9(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@M?"W
MNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R
M82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E
M<\#'(,;;N<R\Q\"[(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")6
M1E,@QL3`SR`E<R\E<\#'(,;;N<R\Q\"[(+JOL.;'TB"\]B"^^+W`M,^TV2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS
M9W-T<B`B4U%,(+RMN?:_H2#!HKS3Q](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB
M+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB
M"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@
M(E-13""\K;GVOZ$@P:*\T\?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B4U%,(+RMN?:_H2#!HKS3
MQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(P.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'
MTB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B=F9S<F]O=""U
M\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R
M(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII
M<"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N(@IM<V=S='(@(LBOL.:\L\&DP+L@NJ^PYL?2(+SV(+[XO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(G9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[
M(+SV(+[XO<"TS[39+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")61E,@
MQL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B=F9S<F]O=""U\+>Z
MQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S4R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(G9F<W)O;W0@M?"W
MNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@M?"WNL7D
MN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("*U\+>ZQ>2XKB"PR[OVO\"W^3H@
M)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'
MTB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`
MSR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"Z
MK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@M?"WNL7DN*ZX
MIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T
M:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(E<R#!I,#'N*8@P-#`
MNR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I
M(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$P,\@
M)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"Z
MK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/
M("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@
M(LBOL.:\L\&DP+L@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(E9&
M4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*
M;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!F:6QE.B`B"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2
M(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@
M9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>3H@)7,N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V
M-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G
M<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T
M<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N="(*;7-G<W1R("+`S""_]K7EN:Z\K;BF(+JOL.;'TB"\]B"^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2
M(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(")6
M1E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]
MP+3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(KG8P=DB"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B
M"FUS9W-T<B`BNJ^PYKOGQ]<@M<>UN;BNL>(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R("*XML'VN+<@N.VWR2##Z[S2(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C$*(RP@9G5Z>GD*;7-G:60@(E5N9FEL960B
M"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")5;FET960@07)A8B!%;6ER871E
M<R(*;7-G<W1R("*YS+&Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@
M2VEN9V1O;2(*;7-G<W1R("*_M;&Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R(*;7-G<W1R("*YS+&Y(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L
M:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS
M9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("*[
MY[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'S[R\O^0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@
M(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(L?VP.<@O^2\
MTK^A(+BUQ:D@P::PQ2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D(@IM<V=S='(@(L#,N*<@OOC`O2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*
M;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@
M0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO
M=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`BN_:Q\B#!IK#%
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D
M($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M,PHC+"!F=7IZ>0IM<V=I9"`B57!D871E(@IM<V=S='(@(L#/P-HB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`BP,_`VB(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*(RP@9G5Z>GD*
M;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(KOGO^O`VB##W["A(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("*[Y[_KP-H@
MP]^PH2(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5
M<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R("*V\\:^ONX@M.NYKL#:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R("*WSKBV(+3KN:[`VB"\_<#:(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@
M(L?VP.<@O;K%N,#/(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("*[Y[_KP-JX[2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*(RP@9G5Z
M>GD*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B2&]R9&4@
MN^>_Z\#:(+#\N*XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(KOGO^O`VB"\L<7#
MN^?'UR(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@
M4F5G:7-T<F%T:6]N(@IM<V=S='(@(DAO<F1E(+OGO^O`VB"P_+BN(@H*(SH@
M<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO
M="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED
M(")5<V5R;F%M92(*;7-G<W1R("*[Y[_KP-JX[2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`BN-[`S\?4(%PB)7-<(K"A(,#,N<P@N^>_Z\'?P-2TS[39+B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B
M57-E<FYA;64Z(@IM<V=S='(@(KOGO^O`VKCM(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*
M;7-G<W1R("*[Y[_KP-JX[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@
M(KW#O;K%V\#'(+OGO^O`VCHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E
M:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*(RP@9G5Z
M>GD*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/M-DN(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`HC+"!F=7IZ>0IM<V=I
M9"`B5F%C871I;VXB"FUS9W-T<B`BO<?'X"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@
M=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0T"B,L(&9U>GIY"FUS9VED(")687)I86)L92(*;7-G<W1R
M("+!IKCQ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*(RP@9G5Z>GD*;7-G
M:60@(E9E<G-I;VXB"FUS9W-T<B`BL+/`SB"XWL#/(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(R-@HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B!#
M;VYT<F]L(@IM<V=S='(@(K"SP,X@N-[`SR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I
M8V%L(&%L:6=N(@IM<V=S='(@(KSVP?<@P:2WQ"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L
M('!A9&1I;F<B"FUS9W-T<B`BO/;!]R##I+_R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PHC+"!F=7IZ>0IM<V=I9"`B
M5F5R=&EC86PZ(@IM<V=S='(@(KSVP?<@P:2WQ"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE
M="!.86TB"FUS9W-T<B`BQ\JUY<#,N*<B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(E<R"ZN+'B(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E9I97<@87,@)7,B"FUS9W-T<B`B)7,@NKBQXB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6
M:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*
M;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BL.:P[2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I
M9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O
M=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("*XQ<'6(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B
M"FUS9W-T<B`BR*^_M2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(LBOO[7'U;3/M-DA("5S
M(,#4M,^TV2XB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`BR*^_M<?5M,^TV2P@)7,B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO
M9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B
M"FUS9W-T<B`BL;BZT""YKL#:M,(@N:N^^<#4M,^Q[C\B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/R(*;7-G<W1R("+`SK_K(+K.R*.TPB"YJ[[YP-2TS['N
M/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I
M9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R
M("*SRKKQ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0HC+"!F
M=7IZ>0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(K/*NO$@
MM-S`IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS
M9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BQZ7`QR"SRKKQ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*
M;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`BL\JZ\2"TW,"G(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@
M(E=I9'1H.B(*;7-G<W1R("*SRKKQ.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B5VEN9"(*;7-G
M<W1R("+#H['B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B
MPZ.QXB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@
M<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z(@IM<V=S='(@(L.CL>(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"B,L(&9U>GIY
M"FUS9VED(")7:6YD.B`B"FUS9W-T<B`BPZ.QXB(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B5VES9&]M(@IM<V=S='(@
M(L.CL>(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED
M(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E=O<FLB"FUS9W-T<B`BML>TPB(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I
M9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(L'WP.4@P=:\TCHB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7
M;W)K(%!H;VYE(@IM<V=S='(@(L'WP.4@P/S(K;GXR*,B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O
M9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@
M17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I
M9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*
M;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")962(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ
M>0IM<V=I9"`B65E962(*;7-G<W1R(")962(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("*XQ;/B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B665M96XB"FUS9W-T<B`BP-#`
MNB"XWL#/(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(K^Y(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@
M22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$
M12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE3
M25=91RXB"FUS9W-T<B`B5$585+CPM>7`U+3/M-DN(%L\/ET@N?;&L,"[(+2I
MN*.XZ2!765-)5UE'(+CPM>6WSB"UN;[&L*FTS[39+B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T
M,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS
M9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"B,L
M(&9U>GIY"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N(@IM<V=S='(@(L#?N/BUR"#`S+C>P,\@P=:\TB(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B
M"B)I;B`E<RXB"FUS9W-T<B`BP-/&]\:NM<@@QL3`S\#'(+[NMK(@Q]>X\;6U
M(%1U<F)AP,<@Q]>X\;^A(+C"L-0@O+/!I,?/P?8@OLJ^TKW`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`BM\ZQU[[&O_0@Q\^_M+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B
M"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L
M(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`BP-^X
M^+7((,#,N-[`SR#!UKS2(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E
M92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C
M<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B
M;&5M(')E<&]R="XB"FUS9W-T<B`BN:[!IB"ZN+#MO*VXIB"ZN+.[L>+`_+^A
M(,#,N:[!IK^A(+3KQ]$@O+.X[<"[(,#4M\+'V+[?(,?5M,^TV2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED
M(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\B"FUS9W-T<B`BP,P@N+7%J;"A(+"AN*[$H;3"(%523,"[(,#4M\+'
MV+[?(,?5M,^TV2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX
M,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+B(*;7-G<W1R("*XU<#Z(+OHP:;'TB"]Q+JPP-JXIB"\
ML<7#Q]B^WR#'U;3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+B(*;7-G<W1R("*[Z,&FQ](@N^>_Z\#:(,#,N*?`NR#`U+?"Q]B^
MWR#'U;3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("*[
MZ,&FQ](@N^>_Z\#:(,#,N*?`NR#`U+?"Q]B^WR#'U;3/M-DN(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N(@IM<V=S='(@(L/?L*''TB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5
MM,^TV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS
M9W-T<B`BP]^PH<?2(+OGO^O`VB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T
M;R!P97)F;W)M+B(*;7-G<W1R("*\]KW%P,[`S""^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R("*[Z,&FQ](@N^>_Z\#:(,#,N*?`NR#`U+?"Q]B^WR#'
MU;3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(E<R"\O+S'P,P@N+BWX;7'OOJ]P+3/M-DN(+39O<,@M\ZQU\#.
MQ\^\O+_D+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X
M"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`BP,RXWL#/(,'6
MO-(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("*XWL#/(,'6O-(Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(L&D
MNK@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(L#,N*<Z(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S
M='(@(B(*(K3GO<7`QR#`SL'UQ:RV\\#,OO#&KK"A(+OGO^O`VKBF(,/?L*''
MTB"\]B"^^+W`M,^TV2X@ML>TPB"TV;BE(,#,P*^WSB"[Y[_KP-H@(@HBP]^P
MH;'BM,G`NR"[Y[_KQ](@O/8@OOB]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S
M+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M
M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(K3GO<7`QR#`SL'UQ:RV\\#,
MOO#&KK"A(+OGO^O`VB"X\;?/NKBQXKBF(,'VO_C'S\'V(+[*O<"TS[39+B"V
MQ[3"(+39N*4@P,S`KR(*(K?.(+OGO^O`VB"X\;?/NKBQXKBF(+OGO^O'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@
M=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("*ZZK;SO^S`^K"A(,#,(+'BM,G`
MNR#!]K_XQ\_!]B"^RKW`M,^TV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(KOG
MO^O'S[#M(+#HO<4@NNJV\[_LP/JTPB#`SKSB(+_)O,?`NR#!]K_XQ\_!]B"^
MRKW`M,^TV2X@P,Z\XL?/L>(@P*?'V+RMM,(@Q,$B"B+&KK?1+[_)O,?%L+_-
M(%"XIB"TJ;BCO+R_Y"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W
M"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("+']L#G
M(+W#L*.TZSHB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D
M+B(*;7-G<W1R("*QXKJ[(+W$NK#`VCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,34X"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S
M='(@(K'BNKL@O<2ZL,#:.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("+`_,.\(,#,N*<Z
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`BO\F\Q\#,
M(,#ZP.6UQ[[ZO<"TS[39+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB
M"FUS9W-T<B`BP,P@O+R\QR"UO[[((+_)O,?`S"#`^L#EM<NTS[39+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(K_)O,?`S"#`
M^L#EM<>^^KW`M,^TV2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I
M9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM
M<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"B,L(&9U>GIY"FUS
M9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("*XWL#/(,'6O-(Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"B,L
M(&9U>GIY"FUS9VED("):86ER92(*;7-G<W1R("+'RL7-(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM
M<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EO`SK_K(+S[L>*Q
MXETB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L
M96T@4F5P;W)T72(*;7-G<W1R(");O\"W^2"ZN+#MQ\^QXETB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");P,Z_ZR"ZN+'B("TB"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=(@IM<V=S='(@(EO`SK_K(+JXL>(@+2`E<R#!V5TB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6[;SP,X@)7,@+R`E
M<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(E]!L/RXKB(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*(RP@9G5Z>GD*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R("+`S\#:(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R(")?1,?@(,'VO_(B"@HC.B!L:6(O87!I
M+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS
M9W-T<B`BM;6_\KB[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R(")?2;'7N+(@O-.\NBXN+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@
M:6XB"FUS9W-T<B`BM\ZQU\#.(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7TRWSK'7
MOL:_]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@
M(E]MN+7%J2"\]L&D+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T^\L<7#N^?'
MUR(*"B,Z(&QI8B]A<&DN<&AP.C$S-PHC+"!F=7IZ>0IM<V=I9"`B7U!E<FUI
M<W-I;VYS(@IM<V=S='(@(L7DM]`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@
M3&EN:RXN+B(*;7-G<W1R(")?<KBUQ:D@N^C!IBXN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(U"B,L(&9U>GIY"FUS9VED(")?4V5T=7`B"FUS9W-T<B`BN-Z]P\'V
M(+RQQ<,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E]TQZ4@O-.\NBXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0HC+"!F
M=7IZ>0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(KOGO^O`VKCM(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D
M9')E<W,@8F]O:R(*;7-G<W1R("+!UKS2M\\B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B861D<F5S
M<V5E('5N:VYO=VXB"FUS9W-T<B`BP=:\TK?/(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM
M<V=S='(@(K3>M\(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B8V%L;2(*;7-G<W1R("+#Z[S2(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T
M(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM
M<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S
M86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T:6]N
M(&5R<F]R(@IM<V=S='(@(KC>P,\@O*VY]B#!I+JXN^?'UR(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A
M;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA
M="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD
M(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/
MM-DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#4U"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM
M<V=S='(@(L&FN/$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3`*(RP@9G5Z>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B.+_Y(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I
M9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@
M;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I
M871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")I;FQI;F4B
M"FUS9W-T<B`BOOC`O2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G
M:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L
M:6YE<UTB"FUS9W-T<B`BP=E=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*
M;7-G:60@(FYA;64B"FUS9W-T<B`BP,RXIR(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*
M;7-G<W1R("*[Z,&FM<?!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*(RP@9G5Z>GD*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`BN^C!IK7'P?8@OLK`NB"XWL#/(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*(RP@9G5Z>GD*;7-G
M:60@(FYO=&5P860B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS
M9VED(")P97)C96YT(@IM<V=S='(@(L;;O+[&KB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M
M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("*PL\#.(+C>P,\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED
M(")P:7AE;',B"FUS9W-T<B`BQ\B\OR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O
M=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R
M("*PYK#M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B<VAO
M=R!D:69F97)E;F-E<R(*;7-G<W1R("*[Y[_KP-H@R*^PYB(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED
M(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T96%D>2(*;7-G<W1R("+`T,'V(+[*
MP+H@N-[`SR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS
M9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E
M;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDR.0HC+"!F=7IZ>0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(KSV
MO<6PQ;K.(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T
M<GD@86=A:6XB"FUS9W-T<B`BN/"UYR"WSK'7P,XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS
M9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")U;FEF:65D(@IM<V=S='(@
M(L#0P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T
M+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("+`S+BG(+[XP+TB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*(RP@9G5Z>GD*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(K'4
MQ*(HM_PI(+RQQ<,@O\"W^2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q
M"B,L(&9U>GIY"FUS9VED(")W.B(*;7-G<W1R("+`_+3>.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*
M;7-G<W1R("(B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P;R]L=%],5"YP;P``````````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P-S(Q-S<V`#$P-#$W,S8S,#`Q`#`Q-C0R-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C($QI
M=&AU86YI86X@=')A;G-L871I;VYS(&9O<B!(;W)D92!P86-K86=E+@HC($-O
M<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES
M(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO
M<F1E('!A8VMA9V4N"B,@1&%R:75S($UA='5L:6%U<VMA<R`\9&%R:75S0&QN
M:RYL=#XL(#(P,#(N"B,@5FEL:75S(%-U;7-K87,@/'9I;&EU<T!L;FLN;'0^
M+"`R,#`S+"`R,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)
M9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-"TQ,2TR.2`Q,CHU,BLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z
M(%9I;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT/EQN(@HB3&%N9W5A9V4M
M5&5A;3H@3&ET:'5A;FEA;B`\=FEL:75S0&QN:RYL=#Y<;B(*(DU)344M5F5R
M<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]25-/+3@X-3DM,3-<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AP
M<FEE\"`E<R!D:65N87,I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*
M;7-G<W1R("(@*&UY9W1U:V%S("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B`H:6X@
M)7,@9&%Y<RDB"FUS9W-T<B`B("AP<FEE\"`E<R!D:65N87,I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS
M9W-T<B`B("CP:6%N9&EE;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<U"B,L(&9U>GIY"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R(")2
M>71O:B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@
M(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*'9A:V%R*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W
M"FUS9VED("(@870@(@IM<V=S='(@(B`B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F4@:V%T86QO9V%S
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB
M"FUS9W-T<B`B)R5S)R!Y<F$@;F5L96ES=&EN82!R96EK\&WK+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!N97-U:V]N9FEG
M^W)U;W1A<R!(;W)D92!R96=I<W1R92XB"@HC.B!F<F%M97=O<FLO5')E92]4
M<F5E+G!H<#HQ-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B3NMR82`G)7,G
M(&UE9/YI;R!G96YE<F%T;W)I875S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D
M960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(D=R=7#K("<E<R<@
M<W5K=7)T82XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B5&5I<^L@)R5S)R!S
M=6MU<G1A+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S)R!N96)U
M=F\@<W5K=7)T83H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S(&ER("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S
M<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@
M9F]R96-A<W0B"FUS9W-T<B`B)60M9&EE;O@@<')O9VYO>NLB"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!P87-T86)A(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@86YT<W!A=61A<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E
M<R!P<F]F:6QA:W1I:V]S('9E:6MS;6%I("T@<&%T=FER=&EN:6UA<R(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B
M"FUS9W-T<B`B7TMO;F9I9_MR86-I:F$B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I
M9VX@57`B"FUS9W-T<B`B)7,@<F5G:7-T<F%C:6IA(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E
M<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!N=6]S=&%T;W,B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U
M,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@:F%U(&5G
M>FES='5O:F$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B
M)7,@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B4&'^>6WK
M:VET92P@:W5R:6%S(&]P97)A8VEJ87,@;F]R:71E(&%T;&EK=&DN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!Y<F$@<')I=F%L;VUA
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=73K<R(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N97)A
M<W1A<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(FYU
M;R`E<R!I:VD@)7,@:?`@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O
M:R(*;7-G<W1R("(E<R!A9')E<_@@:VYY9V5LZR(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M0V%L96YD87(B"FUS9W-T<B`B)7,@:V%L96YD;W)I=7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`B)7,@=?YR8?#X(&MN>6=E;.LB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S(&1A<F+X('/@<F'P87,B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E
M<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z
M(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@
M=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET
M(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,3`*(RP@9G5Z>GD*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!G^W-I
M86D@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I
M;F<@)7,@)7,B"FUS9W-T<B`B+"!G^W-I86D@)7,@)7,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA
M8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!K:6YT82!N=6\@)7,@:6MI
M("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#D*
M;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!P87-I<FEN:VET92`M
M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`B,3(@=F%L86YD^"!F;W)M871A<R(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T
M<B`B,C0@=F%L86YD^"!F;W)M871A<R(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!V86QA;F1O
M<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*(RP@9G5Z>GD*
M;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R(")!;FMS=&5S;FES('!U<VQA<&ES
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A
M<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T
M<B`BT&EA;2!B;&]K=6D@<F5I:V%L:6YG82!V:65T82!D=6]M96[X(&)A>NMJ
M92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`BP79Y:V\@<FEM
M=&$@:VQA:61A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(").;W+K9&%M:2!U_FMO9'5O=&D@
M;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!01U`@<F%K=.`N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B(@HB3F]RZV1A;6D@<&%T:6MR:6YT:2!P
M87-I<F'P>73@(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4$=0
M(')A:W3@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B
M"B)M97-S86=E+B(*;7-G<W1R("(B"B).;W+K9&%M:2!A=&MO9'5O=&D@;&%I
M\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!01U`@
M<F%K='5S+"`B"B)B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B).;W+K9&%M:2!P87-I<F'P>71I(&QA:?!KX"!P<FEV86QO=&4@='5R
MZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4$=0(')A:W1U<RP@(@HB8F5I(/YI
M;F]T:2!S;&%P=.!JX"!F<F%ZYBXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(DYO
M<NMD86UI(&%T:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67P
MX&KA(&ER('-L87!TX&KA(%,O34E-12`B"B)R86MT=7,L(&)E:2#^:6YO=&D@
M<VQA<'3@:N`@9G)A>N8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B).;W+K9&%M:2!P
M87-I<F'P>71I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@
M<VQA<'3@:N$@4R]-24U%("(*(G)A:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!J
MX"!F<F%ZYBXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(").;W+K9&%M:2!U_FMO9'5O
M=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!3+TU)344@<F%K
M=.`N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M.0HC+"!F=7IZ>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(D1E8F5S=6]T
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P
M"B,L(&9U>GIY"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(E!-(&QE
M;F=V87,@;&EE='5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3$*(RP@9G5Z>GD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B
M3&EE='5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B04T@<F]D>6UA<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"B,L
M(&9U>GIY"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4/MG82(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*
M;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%0
M22!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D%P:64@
M\.$@<F5D86MT;W)I^"(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R
M"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")!<&EE+BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S
M8F]T=&]M(@IM<V=S='(@(E9I<VGP:V%I(&%P8>AI;VIE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S
M;6ED9&QE(@IM<V=S='(@(E9I<VGP:V%I('!E<B!V:61U<N$B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E-I<W1E;6$@
M;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!K871A;&]GX"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")3:7-T96UA(&YE='5R
M:2!T96ES:?@@<W5K=7)T:2!61E,@9F%I;.`N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I
M;VXB"FUS9W-T<B`B26YF;W)M86-I:F$@87!I92!*=7,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS
M9W-T<B`B4VQA<'1A_F]D:7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N
M+B(*;7-G<W1R(")3X'-K86ET82!U_O!A;&1Y=&$N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R
M(")!<'-K86ET82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S
M='(@(E-U:W5R=&DB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G
M<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@
M(E-U:W5R=&D@<&]G<G5PX2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I
M9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B4W5K=7)T:2!P;W1E
M:7-E<R(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!
M9&0@2&5R93HB"FUS9W-T<B`B0FQO:V\@X71E<G!I;6%S.B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!
M9&0@3F5W($=R;W5P(@IM<V=S='(@(E-U:W5R=&D@;F%U:N`@9W)U<.8B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO
M;B(*;7-G<W1R(")3=6MU<G1I(&YA=6IA<R!T96ES97,B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS
M9W-T<B`B4&]G<G5P:6\@9W)U<&5I("<E<R<@<W5K^W)I;6%S(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB
M(@IM<V=S='(@(E!O=&5I<^MS('1E:7-E:2`G)7,G('-U:_MR:6UA<R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS
M9W-T<B`B3F%U:F\@=F%R=&]T;VIO('-U:_MR:6UA<SHB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@
M8V]L=6UN(@IM<V=S='(@(E!R:63K=&D@<W1U;'!E;.$B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE
M;6)E<G,B"FUS9W-T<B`B3F%U:O@@;F%R:?@@<')I9.MJ:6UA<R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM
M<V=S='(@(E-U:W5R=&D@<&]RX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S
M(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(E!R:63K=&D@)7,@;65N:74@
M<')I92!-;WII;&]S(.%R86YK:?@@:G5O<W1O<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D
M9')E<W,@8F]O:SHB"FUS9W-T<B`BP71R875K=&D@X2!A9')E<_@@:VYY9V5L
MYCHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`BP71R
M875K=&D@X2!M86YO(&%D<F5S^"!K;GEG96SF.B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")3=6MU<G1I('9A<G1O
M=&]JX"(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("(*(B5S+B(*;7-G<W1R("(B"B)687)T;W1O:F%S("<E<R<@<W5K=7)T87,L
M('1AZ&EA=2!P87!I;&1O;6$@<F5G:7-T<F%C:6IO<R!I;F9O<FUA8VEJ82!N
M96)U=F\@(@HB:?!S875G;W1A.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")687)T;W1O
M:F%S("<E<R<@<W5K=7)T87,N($=A;&ET92!P<FES:6IU;F=T:2XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG
M('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")687)T;W1O:O@@:_MR:6UA
M<R!I\&IU;F=T87,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G
M:60@(D%D9')E<W,B"FUS9W-T<B`B061R97-A<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R
M(")!9')E<V%I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<G5O=&D@+2!G86QI
M(&YU<W1A='ET:2!T96ES97,@:VET:65M<R!V87)T;W1O:F%M<R(*"B,Z(&%D
M;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")686QD>6UA<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@(D%D<R(*
M;7-G<W1R(")"86YE<FEA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES
M=&%N(@IM<V=S='(@(D%F9V%N:7-T86YA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")!;&=E<FEA(@IM<V=S='(@(D%L_GER87,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G
M<W1R(")0<F%V87)DZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(DQY
M9VEU;W1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("),>6=I879I;6%S
M.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM
M<V=S='(@(E9I<V]S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B5FES:2!P<FES:6IU;F?F
M('9A<G1O=&]J86DB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E9I<V]S
M(&=R=7#K<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B
M06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E9I<V]S('1E:7/K<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*
M;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(E9I<V]S(&ME='5R:6]S
M('!U<^MS(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(DQE:7-T:2!K
M96QE=.`@861R97/X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM
M<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS
M9W-T<B`B3&5I<W1I(&YA=61O=&D@<W5R^_!I=6]TX"!SX')A\.`_(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED
M(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")*874@96=Z:7-T=6]J82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)
M35-0($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T>79U<R!)35-0('!R:7-I:G5N
M9VEM87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!
M;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA='EV=7,@
M24U34"!S;&%P=&'^;V1I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(D%L
M=&5R;F%T>79U<R!)35-0('9A<G1O=&]J;R!V87)D87,B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL
M(&%D9')E<W,B"FUS9W-T<B`B06QT97)N871Y=G5S(&5L+B!P8?!T;R!A9')E
M<V%S(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R
M;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N871Y=OMS(/!A8FQO;F%I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B
M06QT97)N871Y=G5S('1E:W-T87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R
M:6-A;B!386UO82(*;7-G<W1R(")!;65R:6MO<R!386UO82(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`BP79E9.MT92!N96QE:7-T:6[@(')E:6OP;>8N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ
M>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T
M<B`BP79Y:V\@<FEM=&$@:VQA:61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD
M;W)R82(*;7-G<W1R(")!;F1O<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O
M;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL
M;&$B"FUS9W-T<B`B06YG:6QA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!
M;F]N:6UI;FES('!R;WAY('-E<G9E<FES(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")!='-A:WEM
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N
M=&%R:W1I9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B
M=61A(@IM<V=S='(@(D%N=&EG=6$@:7(@0F%R8G5D82(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B
M36]D=6QI<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@HC+"!F=7IZ
M>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R(")-;V1U;&ES(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I
M;VX@:7,@<F5A9'DN(@IM<V=S='(@(DUO9'5L:7,@=F5I:VEA(&=E<F%I+B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L
M>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B4')I=&%I:WET:2!I<B!P;_!A
M:VEA;7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")0871V:7)T:6YT:2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P
M<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B
M0F%L86YD:7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B
M07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)I\&MA("A7:6YD
M;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G
M:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(D%R8VAY=F\@9F%I;&\@
M9'ED:7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B
M07)C:&EV92!.86UE(@IM<V=S='(@(D%R8VAY=F\@9F%I;&\@<&%V861I;FEM
M87,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S
M='(@(D%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@)7,@<F5G:7-T<F%C:6IO
M<R!P<F'P>6W@/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U
M<',_(@IM<V=S='(@(D%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@)R5S)R!I
M<B!V:7-U<R!P;V=R=7!I=7,_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT
M:6YA(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R
M;65N:6$B"FUS9W-T<B`B07)MZVYI:F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M07)MZVYI\&MA("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B365N87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS
M9W-T<B`B2W)I<W1A=7,@_F5N9VEM;R#A(&1A;F?X('-A;&$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R
M(")!8W-I:2!M96YA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")!>FEJ
M82]286UI;VIO('9A;F1E;GEN;R!R96=I;VYA<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")!
M<B!P<F'P>71I('!A='9I<G1I;G1I('!R;V9I;&%K=&EK;W,@=F5I:W-M=7,_
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S
M:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(E!R:7-K>7)I;6\@<W1U;'!E;&EA
M:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")"86YD;W1E
M(&GP=')I;G1I(&YE96=Z:7-T=6]J86[H:>`@9W)U<.8N(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B0F%N9&]T92!I
M\'1R:6YT:2!N965G>FES='5O:F%NZ&EA<R!T96ES97,N(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")"86YD;W1E(')E9&%G
M=6]T:2!N965G>FES='5O:F%NZ&EA<R!T96ES97,N(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(D)A;F1O=&4@<F5D86=U;W1I
M(&YE96=Z:7-T=6]J86YTX2!E;&5M96YTX"XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R(")!=')I
M8G5T86DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(E)U9W!J^W1I<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%L:6IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R(")!=7-T<FEJ82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@
M(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!N97)A<W1A<R!R96EK86QI;F=A
M<R!)34%0(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER
M=7,Z(&-Y<G5S(&YE='5R:2!R96EK:6%M^"!G86QI;7EB:?@N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?8WER=7,Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($E-05`@;6]D
M=6QI<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G
M:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W
M:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z(&YE<F%S=&%S(')E:6MA;&EN
M9V%S($944"!M;V1U;&ES+B!3=6MO;7!I;&EU;VMI=&4@4$A0('-U("TM96YA
M8FQE+2(*(F9T<"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!N97)A<W1A<R!R96EK
M86QI;F=A<R!)34%0(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@;F5R
M87-T87,@<F5I:V%L:6YG87,@:W)B-2!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?;&1A<#H@;F5R87-T87,@<F5I:V%L:6YG87,@3$1!4"!M
M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D
M9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS
M9W-T<B`B075T:%]L9&%P.B!S=6MU<G1I('9A<G1O=&]JX"`E<R!N97!A=GEK
M;RX@4V5R=F5R:6\@<')A;F7P:6UA<SH@(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%P.B!I\'1R:6YT:2!V87)T;W1O:N`@)7,@;F5P879Y:V\B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G
M<W1R(")!=71H7VQD87`Z(&%T;F%U:FEN=&D@=F%R=&]T;VK@("5S(&YE<&%V
M>6MO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G
M:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;6-A;#H@;F5R87-T87,@<F5I:V%L:6YG87,@34-!3"!M;V1U;&ES+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T
M:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@;F5R87-T87,@<F5I:V%L:6YG
M87,@<VUB875T:"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D(@IM<V=S='(@(E!R:7-I:G5N9W1I(&YE<&%V>6MO(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<R(*;7-G<W1R(")0<FES:6IU;F=T:2!N97!A=GEK;RX@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R
M(")2041)55,@<V5R=F5R:7,@;F5L96ED_FEA(&%U=&5N=&EF:6MU;W1I<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E!R
M:7-I:G5N9W1I('!R:64@1E10('-E<G9E<FEO(&YE<&%V>6MO+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B4')I<VEJ=6YG=&D@<')I92!&5%`@<V5R=F5R:6\@;F5P879Y:V\N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA
M8FQE(&9I96QD<SHB"FUS9W-T<B`B1V%L:6UI(&QA=6MA:3HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B86ED_F%N87,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC
M=7-E<R(*;7-G<W1R(")"3T9((&%T<VEP<F'P>6UA:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@
M(D)A8VMG<F]U;F0B"FUS9W-T<B`B1F]N87,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD
M($-O;&]R(@IM<V=S='(@(D9O;F\@<W!A;'9A(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+B(*;7-G<W1R(").971E:7-I;F=A<R!K97)B97)O<R!S;&%P=&'^;V1I
M<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED
M(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(DYE=&5I<VEN9V%S
M(&ME<F)E<F]S('9A<G1O=&]J;R!V87)D87,N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6%I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR96EN87,B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS
M9W-T<B`B0F%L=&GP:V$@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%G;&%D9?!A<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S87,B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(DML87/K<R`E<R!NZW)A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S
M96QI;F4B"FUS9W-T<B`B4&%G<BX@;&EN:6IO:F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")"96QA<G5S(@IM<V=S='(@(D)A;'1A<G5S:6IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:6IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;F%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)H=71A;B(*;7-G<W1R(")"=71A;F%S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B1VEM=&%D:65N:7,B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B2VQA<^MS("5S(&[K<F$N(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG
M<R(*;7-G<W1R(")";&]K;R!P87)A;65T<F%I(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(D)L;VMO('1I<&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(E!A<W1O<FEN=&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV:6IA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(D%T_GEM;W,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B
M"FUS9W-T<B`B2W)A\'1A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM
M<V=S='(@(DMR8?!T;R!S=&]R=6UA<SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S
M(@IM<V=S='(@(DMR8?!T86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI:F$@:7(@2&5R8V5G;W9I
M;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B
M"FUS9W-T<B`B5FES;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*
M;7-G<W1R(")";W1S=F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@
M(D%P8>AI;VIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*
M;7-G<W1R(")"=79E="!S86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL
M(@IM<V=S='(@(D)R87II;&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=/@@26YD
M:6IO<R!V86YD96YY;F\@=&5R:71O:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5NZVIA=7,@9&%R=7-A;&5M
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QG
M87)I:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(E-U_GEMZW1A
M<R!SX')A\&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM
M<V=S='(@(D)U<FMI;F%S($9A<V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M=6YD:2(*;7-G<W1R(")"=7)U;F1I:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`B5%93(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#
M(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G
M<W1R(")#4DP@<&%S:VER<W1Y;6\@<'5N:W1A:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B
M0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?0V5LZW,@;G5S=&%T>6UA
M:2XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*(RP@
M9G5Z>GD*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM
M<V=S='(@(DYEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P;RXB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YD;W)I=7,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V"FUS9VED(")#
M86QM(@IM<V=S='(@(E)A;74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D
M:6$B"FUS9W-T<B`B2V%M8F]D_F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE
M<F]O;B(*;7-G<W1R(")+86UE<OMN87,B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A
M=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HB3F5V96EK:6$@875T;VUA=&EN:7,@<VQA<'1A_F]D_FEO('!A
M:V5I=&EM87,L('-U<VES:65K:71E('-U("(*(F%D;6EN:7-T<F%T;W)I=6UI
M+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB
M)7-<(B(*;7-G<W1R(").96=A;&EU(&GP=')I;G1I(&9A:6QO(%PB)7-<(BXB
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN
M:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B
M3F5G86QI=2!P<FES:6IU;F=T:2!P<FEE($E-05`@<V5R=F5R:6\Z("5S(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(").96=A;&EU(&GP=')I;G1I(&9A:6QO(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B073P875K=&DB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%T\&%U:W1I('!R;V)L96UO<R!P
M<F%N9?!I;>`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").96=A;&EU(&GP=')I;G1I(&9A:6QO(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM
M<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R(").96=A;&EU(')A<W1I(&QA:6MI;F]J;R!K871A;&]G;RXB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(DYE9V%L:74@87!D;W)O=&D@)W1A<F=E=$9I;&4G('!A
M<F%M971R;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(DYE9V%L:74@:?!T<FEN=&D@:V%T86QO9V\@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="XB"FUS9W-T<B`B3F5G86QI=2!I\'1R:6YT:2X@16=Z:7-T=6]J82`E
M9"!P;_!A:VEA:2XB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O
M<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B).96=A;&EU('!E<G+[
M\&EU;W1I+B#!=F5S=&%S(.%R8?#X('-K86GH:75S(&YE<W5T86UP82!S=2#A
M<F'P^"!S:V%IZ&EU;6D@(@HB9'5O;65N^"!B87KK:F4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED
M(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*
M;7-G<W1R(").96=A;&EU(&YU:W)E:7!T:2#^:6YU=.MS(.$@;G5R;V1Y=.`@
M;G5M97+A+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T
M<B`B2V5I<'9E<F1I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B
M4&%V861I;FEM87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N
M9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEJ;W,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM
M<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B2V%I;6%N^"!S86QO<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*
M;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6QU<R!T96QE9F]N87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B0V5LZW,@
M;G5S=&%T>6UA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(E1A
M<G!A:2!C96SK<V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM
M<V=S='(@(D-E;.MS(&YU<W1A='EM86DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG
M.B(*;7-G<W1R(")487)P86D@=&%R<"!C96QI^#HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B
M36]B:6QU<VES('1E;&5F;VYA<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT
M^"`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@
M(D-E;G1R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R(*;7-G<W1R(")#96YT<FENZW,@069R:6MO<R!297-P=6)L:6MA
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@
M175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D-E;G1R:6[K<R!%=7)O
M<&]S("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S
M='(@(E-E<G1I9FEK871O(&1E=&%LZW,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8Q,0HC+"!F=7IZ>0IM<V=I9"`B0V5R=&EF:6-A
M=&4@3W=N97(B"FUS9W-T<B`B4V5R=&EF:6MA=&\@9&5T86SK<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T
M:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")397)T:69I:V%T;R!T96ESZW,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`BR&%D87,B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B4&%K
M96ES=&DB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@
M9G5Z>GD*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E-L
M87!T8?YO9/YI;R!K96ET:6UA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(DK[<_@@=F%R9&\@:7(@861R97-O
M+"!K=7)I=6]S(&UA='ES(/YM;V[K<RP@<VMA:71A;G1Y<R!I<B!A='-A:VEN
MZVIA;G1Y<R#A("(*(DK[<_@@;&%I\&MU<RP@:V5I=&EM87,N(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN
M9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R
M<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B
M4VEM8F]L:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S
M='(@(E!A7W1I:W)I;G1I(&YU;W)O9.`N+BXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EL92(*;7-G<W1R("+(:6SK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B2VEN:6IA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R
M(")+:6YI971I\&MA('!A<')A<W1A("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I
M9S4I(@IM<V=S='(@(DMI;FEE=&GP:V$@=')A9&EC:6[K("A":6<U*2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H
M;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E!A<VER:6YK:71E('-L87!T8?YO
M9.$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS
M9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")087-I<FEN:VET92!V
M87)T;W1O:F\@=F%R9.`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX
M"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@
M(E!A<VER:6YK:71E(&MA:7`@=F%I>F1U;W1I(&1A=&%S.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*
M;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*2(*;7-G<W1R(")087-I<FEN:VET92!S=7+[\&EU;W1O('/@<F'P;R!S
M=&EL:?@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM
M<V=S='(@(DMA;.MD^"!S86QA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`B2VQA<^MS("5S(&[K<F$N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@
M(D=I961R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B
M2?!T<FEN=&D@35,@3V9F:6-E(/YY;65S(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B
M2?!V86QY=&D@=F%R=&]T;VIO(&1U;VUE;FES(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE
M87(@;W5T('5S97(Z("5S(@IM<V=S='(@(E9A<G1O=&]J;R!D=6]M96[X('9A
M;'EM87,Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(DGP=F%L>71I('9A<G1O
M=&]J;R!D=6]M96YI<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B2?!V86QY
M=&D@=F%R=&]T;VIO(&1U;VUE;FES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R:6YG
M($QA=&4B"FUS9W-T<B`B3&EE='5S('9A:V%R92(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T
M;R!#;VYT:6YU92(*;7-G<W1R(")4YG-T:2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA
M=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('!E<B!(5%10(@H*
M(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B5?YD
M87)Y=&D@;&%N9^`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I
M9"`B0VQO=61S(@IM<V=S='(@(D1E8F5S=6]T82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"B,L(&9U>GIY"FUS9VED(")#
M;&]U9',@16%R;'DB"FUS9W-T<B`B1&5B97-U;W1A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*
M;7-G<W1R(")$96)E<W5O=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H
M2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")+;VMO<V\@*$MY;&EN9V\I('-A
M;&]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PHC+"!F
M=7IZ>0IM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")4=?#H:?@@
M8V5L:?@@:W)A\'3X(')O9'EM87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@
M8F]R9&5R<R(*;7-G<W1R(")4=?#H:?@@8V5L:?@@:W)A\'3X(')O9'EM87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I
M:F$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B4W!A;'9A(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@
M4&EC:V5R(@IM<V=S='(@(E!A<VER:6YK:71E('-P86QVX"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I
M;VXB"FUS9W-T<B`B4W!A;'9O<R!P87-I<FEN:VEM87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L
M<SHB"FUS9W-T<B`B4W1U;'!E;&EA:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(E-T
M=6QP96QI^"!P879A9&EN:6UA:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")+;VUI:W-A:2(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R
M(")+;VUA;F1A(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#
M;VUM86YD(%-H96QL(@IM<V=S='(@(DMO;6%N9&ENZR!E:6QU=.LB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE
M;G0B"FUS9W-T<B`B2V]M96YT87)A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M(")687)D87,O<&%V87)DZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(DMO;6]R86DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(DMO
M;7!A;FEJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B
M0V]M<'5T97)S(@IM<V=S='(@(DMO;7!I=71E<FEA:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O;F1I
M=&EO;B(*;7-G<W1R(")3X&QY9V]S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B4^!L>6=O<R(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S(@IM<V=S='(@(DYU<W1A='EM^"!P86ME:71I;6%I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/
M=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3,U"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+B(*;7-G<W1R(")296EK:6$@871N875J:6YT:2!K;VYF:6?[<F%C:6[A
M(&9A:6S@+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(DMO;F9I9_MR
M=6]T:2`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B4VQA<'1A_F]D
M:7,@9&%R(&MA<G3@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T
M<B`B2V]N9V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")$96UO:W)A=&ENZR!+
M;VYG;R!297-P=6)L:6MA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S
M='(@(E!R:7-I:G5N9W1I(&YE<&%V>6MO+B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D.B`B"FUS9W-T<B`B4')I<VEJ=6YG=&D@;F5P879Y:V\Z("(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M(")0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R=F5R:6\@;F5P
M879Y:V\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@
M(E!R:7-I:G5N9W1I('!R:64@=FEE\/AJ^"!R86MT^"!S97)V97)I;R!N97!A
M=GEK;RP@;F5S.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(E!R:7-I:G5N9W1I('!R:64@1E10('-E<G9E<FEO(&YE
M<&%V>6MO+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED
M(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R
M(")+;VYK86MT86D@<^MK;6EN9V%I(.%T<F%U:W1I(.$@2OMS^"!A9')E<_@@
M:VYY9V5LYB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS
M9W-T<B`B)R5S)R!T=7)I;GES(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED
M(")#;VYT:6YU92(*;7-G<W1R(")4YG-T:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O;VL@27-L86YD<R(*;7-G<W1R(")+=6MO('-A;&]S(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B3&%I
M;>MS(/YI;G5TZW,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P
M:6IU;W1I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G
M<W1R(")0<FES:6IU;F=T:2!N97!A=GEK;SH@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE
M8W1I;VXB"FUS9W-T<B`B2V]P:6IU;W1I('!A<VER:6YK:6W@(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@
M240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*
M;7-G<W1R(")+;W-T82!2:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D
M)TEV;VER92(*;7-G<W1R(")$<F%M8FQI;R!+875L;R!+<F%N=&%S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3F5P879Y:V\@
M=?YK;V1U;W1I(%!'4"!L86GP:V\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4N(@IM<V=S='(@(DYE<&%V>6MO('!A<VER8?!Y=&D@4$=0(&QA:?!K
M;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S
M='(@(DYE<&%V>6MO('7^:V]D=6]T:2!3+TU)344@;&%I\&MO+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B3F5P879Y:V\@
M<&%S:7)A\'ET:2!3+TU)344@;&%I\&MO+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F5P
M879Y:V\@<')I9.MT:2!K;VYT86MT;RX@)7,B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+B(*;7-G<W1R(").97!A=GEK;R!A=71E;G1I9FEK=6]T:7,@X2!,1$%0('-E
M<G9E<N$N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T
M<B`B3F5P879Y:V\@875T96YT:69I:W5O=&ES(.$@3$1!4"!S97)V97+A+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@
M8F%L86YC92X@)7,B"FUS9W-T<B`B3F5P879Y:V\@<&%T:6MR:6YT:2!B86QA
M;G-O+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4TU"('-E<G9E<FEO
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N
M9W1I('!R:64@)R5S)R!S97)V97)I;R!P97(@1E10.B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@9&ES=')I8G5C
M:6IO<R!SX')A\&\N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N
M(@IM<V=S='(@(DYE<&%V>6MO(&%T:V]D=6]T:2!01U`@9'5O;65N^"XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B
M0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DYE<&%V
M>6MO(&%T:V]D=6]T:2!3+TU)344@9'5O;65N^"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S
M='(@(DYE<&%V>6MO(&GP=')I;G1I(&MO;G1A:W1O+B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(&1I<W1R:6)U
M8VEJ;W,@<^!R8?!O+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3F5P
M879Y:V\@:?!T<FEN=&D@871N875J:6YI;6\@<VMR:7!T;R`G)7,G+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S
M='(@(DYE<&%V>6MO(&YU<W1A='ET:2!G87;K:F\@96PN('!A\'1O(&%D<F5S
M;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B4&%V>6MO(&=A=71I('9I<V]S(&%D<F5S^"!K
M;GEG96SK<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").97!A=GEK;R!G875T:2!V
M:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+B(*;7-G<W1R(").97!A=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ
M;W,@<^!R8?#X('/@<F'P;RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO('7^
M:W)A=71I('-T<F%T96=I:F]S("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@
M(DYE<&%V>6MO('-U:W5R=&D@:V%T86QO9V\@)R5S)RXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@
M(DYE<&%V>6MO(&=A=71I('9I9?!O:F\@<F%K=&\@:?`@<F%K=/@@<V5R=F5R
M:6\N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG
M+B(*;7-G<W1R(").97!A=GEK;R!A=&ED87)Y=&D@)R5S)R!R8?!Y;75I+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`B3F5P879Y:V\@871I9&%R>71I("5S+B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A<GET:2!-86EN=&5N86YC
M95]487-K(&UO9'5L:6\@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A<GET:2!K871A
M;&]G;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B3F5P879Y:V\@<&%I9?!K82!,1$%0('-E<G9E<GEJ92XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B3F5P879Y:V\@<VMA
M:71Y=&D@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B).97!A=GEK;R!P86ME:7-T:2!S;&%P=&'^;V3^:6\@\&EA
M;2!V87)T;W1O:G5I+B!+86D@:W5R:2!A<F)A('9I<V$@(@HB:6YF;W)M86-I
M:F$@>7)A(&YE=&EK<VQI+B!086)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S
M=7-I<VEE:VET92!S=2!S879O("(*(F%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U
M(')E:6MA;&EN9V$@<&%G86QB82XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM
M<V=S='(@(DYE<&%V>6MO(&=A=71I($%#3"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM
M<V=S='(@(DYE<&%V>6MO(&=A=71I(&%D<F5S^"!K;GEG96SK<RX@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE<&%V>6MO(&=A=71I(&1I
M<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M(@IM<V=S='(@(DYE<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ;W,@<^!R8?#X
M+B`E<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET
M:65S(@IM<V=S='(@(DYE<&%V>6MO(&YU<W1A='ET:2!S97)V97)I;R!G86QI
M;7EB:?@B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#
M;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYE<&%V
M>6MO(&%T:V5I<W1I(&YU<W1A='EM^"XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I
M<B!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(&MA=&%L;V=O
M("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B3F5P879Y:V\@:?!S875G;W1I("5S(&YU<W1A='EM^"XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F5P879Y:V\@<&%D87)Y=&D@871S87)G
M:6[K<R!N=7-T871Y;?@@:V]P:6IO<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B3F5P
M879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R`E<R!N=7-T871Y;?@@:V]P:6IO
M<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@:?!S875G
M;W1I(&%T;F%U:FEN:6UO('-K<FEP="#A.B`G)7,G+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R(").97!A=GEK;R!P861A<GET:2!A='-A<F=I;NMS("5S
M(&YU<W1A='EM^"!K;W!I:F]S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*(DYE<&%V>6MO('7^<F'P>71I+B!*^W,@9V%L
M:71E(&%R8F$@;F%U9&]T:7,@871N875J:6YI;6\@<VMR:7!T=2!A<F)A('!A
M='ES("(*(FYU:V]P:6IU;W1I(&MO9.`@87!AZ&EO:F4@X2`E<RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE<&%V>6MO
M('!A:67P:V$@3$1!4"!S97)V97)Y:F4N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL
M:6YK(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@;G5T<F%U:W1I(')Y\.$@
M)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE<&%V>6MO(&%T;F%U:FEN=&D@
M:V]N=&%K=&\N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5P
M879Y:V\@871N875J:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(DYE<&%V>6MO('7^<F'P>71I("<E<R<@;G5S
M=&%T>6WX.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*(DYE<&%V>6MO
M(')A<W1I($UO>FEL;W,@X7)A;FMI^"!J=6]S=&]S+B#!<VET:6MI;FMI=&4L
M(&MA9"!J:2!A=&ED87)Y=&$N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@
M<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F5P
M879Y:V\@<W5T96EK=&D@\&GX('1E:7-I^"!V87)T;W1O:G5I("<E<R<@:V%T
M96QO9V4@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B4FEB;W1A<R!T96MS
M=&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*
M;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B5F%L<W1Y8NLB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@
M(DMU<G-A:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(E-U
M:W5R=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B
M4W5K=7)T:2!N=6]R;V3@(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R
M(")3=6MU<G1I(&YA=6K@(&%P<F'PX"(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E
M<G,B"FUS9W-T<B`B4W5K=7)T:2!P86MA=&%L;V=I=7,B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M
M:7-S:6]N<R(*;7-G<W1R(")3879I;FEN:V\@=&5I<^MS(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M
M8F5R(@IM<V=S='(@(DMR961I=&ENZW,@:V]R=&5LZW,@;G5M97)I<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR;V%T:6IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@
M4&AA<V5S(@IM<V=S='(@(D1A8F%R=&ENZR!F87KK(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS
M(@IM<V=S='(@(E-A=FEN:6YK;R!T96ESZW,B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@
M5&EM92(*;7-G<W1R(")$86)A<G1I;FES(&QA:6MA<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I
M9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`BT&EU;R!M971U(%523"!Y<F$B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U
M<G)E;G0@57-E<G,B"FUS9W-T<B`B1&%B87)T:6[K(&9A>NLB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS
M9W-T<B`B1&%B87)T:6[K<R!O<F\@<^!L>6=O<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B1&%B87)T:6[K<R!SX&QY9V]S.B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R
M96YT('-T>6QE(@IM<V=S='(@(D1A8F%R=&EN:7,@<W1I;&EU<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G
M<W1R(")696EK<VWX+"!A=&QI96MA;?@@<')I<VEJ=6YG=7,@<')I92`E<RP@
M;G5S=&%T>6UA<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")097)K
M96QT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B4&5R:V5L=&D@
M<&%S:7)I;FMI;>`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T
M<B`B2VEP<F%S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@
M(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(DMI<FEL:6-A("A+3TDX+5(I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(DMI<FEL:6-A("A7:6YD;W=S+3$R
M-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")+:7)I;&EC82]5:W)A
M:6YI971I\&MA("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@
M4F5P=6)L:6,B"FUS9W-T<B`BR&5K:6IO<R!297-P=6)L:6MA(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E
M92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY
M(@IM<V=S='(@(DMA<V1I96XB"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*
M;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1'5O;65N^"!M963^
M:6\@;F%R\'EK;.LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y
M"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(D1A=&$B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I
M9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")'875T82(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM
M<V=S='(@(D1A=&]S('!A<VER:6YK:6UA<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,R,@IM<V=I9"`B1&%Y(@IM<V=S='(@(D1I96YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED
M(")$95]L971E($-O;'5M;B(*;7-G<W1R("))\'1R:6YT:2!?<W1U;'!E;.$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM
M<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1W)U;V1I<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G
M:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(")$9?!I;71A:6YI86D@<VMA
M:>AI86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B4W5M8?YI
M;G1I(&%T:71R875K:6W@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E
M9F%U;'0B"FUS9W-T<B`B4W1A;F1A<G1I;NL@<W!A;'9A(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E
M9F%U;'0@0V]L;W(B"FUS9W-T<B`B4W1A;F1A<G1I;NL@<W!A;'9A(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F
M875L="!)9&5N=&ET>2(*;7-G<W1R(")3=&%N9&%R=&EN:7,@87!R8?!A<R(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5F875L="!3:&5L;"(*;7-G<W1R(")3=&%N9&%R=&ENZR!S<&%L=F$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS
M(@IM<V=S='(@(D%P:6)RZ_YI;6%I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(DGP
M=')I;G1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@0V5L;"(*
M;7-G<W1R("))\'1R:6YT:2!C96SF(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*
M;7-G<W1R("))\'1R:6YT:2!G<G5PYB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G
M<W1R("))\'1R:6YT:2!E:6QU=.8B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q
M"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("))\'1R:6YT:2!T
M96ESYB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(E9I<VGP:V%I(&GP=')I;G1I(&QA:?!K=7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE
M=&4@8V5L;"(*;7-G<W1R("))\'1R:6YT:2!C96SF(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B
M1&5L971E(&-O;'5M;B(*;7-G<W1R("))\'1R:6YT:2!S='5L<&5LX2(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DGP=')I;G1I(&5G>FES
M='5O:F%N=.$@86QT97)N871Y=O@@\&%B;&]NX"(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(G
M)7,G('1E:7-I^"!T<GEN:6UA<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\B"FUS9W-T<B`B07(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2`G)7,G
M('1E:7-E<R!I<B!V:7-A<R!P;W1E:7-E<S\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@<F]W(@IM<V=S='(@(DGP=')I;G1I(&5I;'5TYB(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("))\'1R:6YT:2!P87-I<FEN:W3@
M(&%P<F'PX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;B(*;7-G<W1R("))\'1R:6YT:2#PX2!S='5L<&5LX2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM
M<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("))\'1R:6YT
M:2#P:>`@96EL=73F(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")!=&YA=6II;FEM;R!S:W)I
M<'1A<R`G)7,G(&GP=')I;G1A<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$
M96QI=F5R>2!T:6UE(@IM<V=S='(@(E!R:7-T871Y;6\@;&%I:V%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$86YI:F$B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I
M8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B4')O8FQE;6]S(&%P<F'P>6UA<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C
M<FEP=&EO;B(*;7-G<W1R(")!<')A\'EM87,B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&EA=2`H=&%I<"!P870@_FG[
M<NMK:71E($AO<F1E(&QO9R!F86EL92DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D%D;6EN:7-T<F%T
M;W)I=6D@:?!S:?AS=&%S(&1E=&%L=7,@87!R8?!Y;6%S+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM
M<V=S='(@(E9Y<W1Y;6%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*
M;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")$<NMG;G5M87,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R(")$<NMG;G5M87,@<&%S:W5T:6[F('9A;&%N9.`Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@
M(D1E=R!P;VEN=#H@(@IM<V=S='(@(D1RZV=N=6UA<SH@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B2W)Y<'1I<R!I\"!K86ER
MZW,@X2!D9?!I;N8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*
M;7-G<W1R(")+<GEP=&ES(&GP(&1E\&ENZW,@X2!K86ERYB(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B
M2V%T86QO9V%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I
M9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")2;V1Y=&D@,C0M
M:?@@=F%L+B!F;W)M873@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E9A:7ID879I;6\@
M;G5S=&%T>6UA:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*
M;7-G<W1R(")2;V1Y=&D@<')O9W)O;N8@*%1!1BDB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM
M<V=S='(@(E)O9'ET:2!P<F]G<F]NYB`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S
M='(@(E9A:7ID879I;6\@9F]R;6%T87,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VXB"FUS9W-T<B`B3&%I\&MO('!R:7-T871Y;6\@<')A;F7P:6UA:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D3^:6)U=&ES(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O
M(&YO="!D96QE=&4B"FUS9W-T<B`B3F5T<FEN=&DB"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DYE<VEK<F5I<&MI=&4@=&EE
M<VEO9VEA:2#A(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R
M"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(D%R('!I
M<FUA<R#A<F'P87,@>7)A(&QA=6MO('9A<F1A:3\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEK82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEK;W,@
M4F5S<'5B;&EK82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*
M;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T
M"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R(")!='-I<VGX<W1I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M
M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(D%T<VES:?AS=&D@)7,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G
M<W1R(")!='-I<VGX<W1I('-U9V5N97)U;W1U<R!N=7-T871Y;75S(&MA:7`@
M4$A0('-K<FEP=.`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P
M-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B2?!S:7-K;&5I9/YI
M86YT:7,@<^!R8?!A<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM
M<V=I9"`B1')U9W,B"FUS9W-T<B`B5F%I<W1A:2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@
M(D5L+B!P8?!T;R!A9')E<V%S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%
M4E(B"FUS9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*
M;7-G<W1R(")%:W9A9&]R87,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*
M;7-G<W1R(")+96ES=&DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN
M<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D
M:70@0FQO8VLB"FUS9W-T<B`B2V5I<W1I(&)L;VMO('!A<F%M971R=7,B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM
M<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")2961A9W5O=&D@9W)U<.8B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B4F5D86=U;W1I('1E:7-E<R(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B4F5D86=U;W1I('1E:7-E<R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B)7,@=&5I<VGX(')E9&%G879I;6%S(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS
M(&9O<CHB"FUS9W-T<B`B2V5I<W1I(&YU<W1A='EM=7,Z(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M("(E<R!T96ES:?@@<F5D86=A=FEM87,B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S('1E:7-I^"!R961A9V%V:6UA<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N
M(@IM<V=S='(@(E5G9'EM87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*
M;7-G<W1R(")%9VEP=&%S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T
M:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM
M<V=S='(@(E-A;'9A9&]R87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB
M"FUS9W-T<B`B16QE;65N=&%S+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*
M;7-G<W1R(")%;"X@<&'P=&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5L+B!P8?!T;R!A9')E<V%S
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D5L+B!P8?!T;R!A
M9')E<V%I('1U<FD@<W5T87!T:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R(")%;"X@<&'P=&\@861R97-A<R!S=2!P871V:7)T:6YI;74B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO
M=&EC;VYS(@IM<V=S='(@(M!Y<'-E;NMLZW,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y
M(&UE<W-A9V4N(@IM<V=S='(@(MYI;G5TZR!T=?#H:6$N(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P
M-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B
M16UP='D@<F5S=6QT+B(*;7-G<W1R(")297IU;'1A=&%S('1U\.AI87,N(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B
M16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(DYE;G5R;V3K=&4@<&%I9?!K
M;W,@=&5R;6EN^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G
M:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(DQE:7-T:2!T96MS=&4@X71E<G!T
M:2!P879E:6MS;.ML:75S(&GP($YU;W1R875K^"!G86QE<FEJ;W,_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT
M(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`BP6IU;F=T:2!D9?!I;FEO
M:F\@<&5LZW,@;7EG='5K;R!M96YI=3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(D=A;&EN:6%I(&UE=&%I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B
M16YL87)G92!%9&ET;W(B"FUS9W-T<B`B2?!P;.MS=&D@<F5D86MT;W)I^"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R
M(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@
M:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B+!
M<F'P>6MI=&4@:VQA=7-I;>`L(&MU<FES(&IU;7,@8G5S('7^9'5O=&%S(&IE
M:6=U('!A;6ER\&ET92!S879O('-L87!T8?YO9.$L("(*(G!V>BXZ("=K;VMS
M('ER82!*^W/X(&=Y=OMN;R!V87)D87,_)SHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@
M(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("+!=F5S:VET92!P
M879E:6MS;.ML:6\@55),(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L
M;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@
M1W5I;F5A(@IM<V=S='(@(D5K=F%T;W)I;NL@1W9I;NMJ82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I='+K:F$B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED
M(")%<G)O<B(*;7-G<W1R(")+;&%I9&$B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(DML86ED82!S
M:75NZ&EA;G0@871S86MY;>`Z("5S+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(DML86ED
M82!S:75NZ&EA;G0@871S86MY;>`Z("5S+B(*"B,Z(&9R86UE=V]R:R]496UP
M;&%T92]496UP;&%T92YP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(DML86ED
M82!S:75NZ&EA;G0@871S86MY;>`Z("5S+B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(DML86ED82!S
M:75NZ&EA;G0@871S86MY;>`Z("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")+;&%I9&$@;&%I\&ME+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")+;&%I9&$@<F'P
M86YT("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R
M(")%<W1I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R
M(")%=&EO<&EJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I
M9"`B171H;FEC(@IM<V=S='(@(D5T;FENZW,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O
M<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMA<R`Q-2!M:6YUZ&GX(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B179E<GD@,B!M:6YU=&5S
M(@IM<V=S='(@(DMA<R`R(&UI;G5T97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B2V%S(#,P('-E:W5N9/YI^"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DMA<R`U
M(&UI;G5T97,B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")+:65K=FEE
M;F\@<')I<VEJ=6YG:6UO(&UE='4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B2V%S('!U
M<W9A;&%N9.$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R(")+87,@;6EN=73F(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")0879Y>F3^
M:75I.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L
M;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T
M92(*;7-G<W1R(")6>6MD>71I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B2?!S:VQE
M:7-T:2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*(RP@
M9G5Z>GD*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(D=A;&EN:6%I
M(&UE=&%I(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V
M.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(E)E:6MA;&EN9V%S("<I
M)R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G
M:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB
M"FUS9W-T<B`B4F5I:V%L:6YG87,@_F]D:7,@87)B82!K86)U=.MS92#A<F'P
M>71A<R!P86EE\&MO<R!K<FET97)I:G5S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS
M9W-T<B`B1V%L:6]J:6UO(&1A=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B16MS
M<&]N96YTZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(E1E:W-T
M;R!S<&%L=F$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED
M(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(DYU<W1A='EM^"!S:75N
M=&EM87,@<&5R($944"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R(")+;&%I9&$@;G5S:V%I=&%N="!N=7-T871Y;75S+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5P879Y:V\@<')I<VEJ=6YG
M=&D@<')I92!,1$%0('-E<G9E<FEO+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BXB"FUS9W-T<B`B3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!3
M34(@<V5R=F5R:6\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&YU:V]P:6IU;W1I(&GP(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S
M='(@(DYE<&%V>6MO(&YU:V]P:6IU;W1I(.$@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3F5P879Y:V\@
M<W5K=7)T:2!N875J;R!305-,(')Y\&EO+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<
M(BXB"FUS9W-T<B`B3F5P879Y:V\@<&5R:V5L=&D@X2!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
M3F5P879Y:V\@<&5R:V5L=&D@X2!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T
M<B`BT'9E;&YU<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N
M9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&;VQK;&%N9/@@<V%L;W,@*$UA;'9I
M;F%I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T
M<B`B1F%R97+X('-A;&]S(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S
M.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(DMR:71I
M;NL@:VQA:61A(2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&86MS87,B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&
M87AE<R(*;7-G<W1R(")&86MS87,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B
M5F%S87)I<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&
M965L<R!,:6ME(@IM<V=S='(@(D%T<F]D;R!L>6<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS
M9W-T<B`B071R;V1O(&QY9SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@
M(E1R=6UP86QA:6MI<R!L:65T=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B1F5W(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")0^V=A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#
M05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FED_FES(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM
M<V=S='(@(F9A:6QA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS
M9W-T<B`B1F%I;/@@<VMA:>AI=7,Z("5S(&9A:6QA<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@
M0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D9A:6SX('-K86GH:75S.B`E<R!F
M86EL86DH^"DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS
M9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1F%I;/@@='9A<FMY;6%S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R(")&86EL;R!P879A9&EN:6UA<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(D9A:6QO('!A<VER:6YK:6UA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(D9A:6QO
M('-I=6YT:6UA<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S
M='(@(DYA<O!Y:VSK(&YE<&%L86EK;R!F86EL^"!S:75N=&EM;RXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B1FEL=')A:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS
M9W-T<B`B4W5O;6EJ82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G
M:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B4&ER;6]J:2!P=7/K(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I
M9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")0:7)M87-I<R!K971V:7)T:7,B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V
M"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B3G5S=&%T>71A<R!K;V5F:6-I
M96YT87,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(D%T=FER:_#H:6%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B2?!DZW-T>6UA<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B
M"FUS9W-T<B`B4OMK87,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R
M(")+871A;&]G87,@)7,@;F5E9WII<W1U;VIA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO
M<B(*;7-G<W1R(")496MS=&\@<W!A;'9A(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(DUA:7-T87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S(@IM<V=S='(@(DYA<O!Y:VSK;7,L(&MU<FEO<R!N97!A;&%I:V\@
M<&%V96EK<VSK;&GX(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G
M:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(D]R^"!P<F]G;F]ZZR`H5$%&
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B
M(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G
M<W1R("(B"B)/<O@@<')O9VYO>NMS(&%P:6UT:7,@*.%S:63K;>MK:71E+"!K
M860@\&D@9G5N:V-I:F$@9W)A_FEN82!I<B!D:65N;W,@:7(@(@HB;F%K=&EE
M<R!P<F]G;F]ZYCL@<&5R(&1I9&5L:7,@<VMA:>AI=7,@9V%L:2!S=61A<FMY
M=&D@9&EZ86ENX"DB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P
M,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(E!A;6ER
M\&]T92!S879O('-L87!T8?YO9.$_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R;6]S(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S
M='(@(D9R87KK(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED
M(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B1G)A>FGX('1I<&%S(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R
M(")&<F%ZZW,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@
M(D9O<G1U;F5S(#(B"FUS9W-T<B`B1G)A>NMS(#(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1&ES
M:W5S:6IO<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G
M:60@(D9O<G=A<F1S(@IM<V=S='(@(E!E<G-I=6YT:6UA:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R
M(@IM<V=S='(@(E!E;FLN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@
M(DMR8?!T:6[K<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R
M(")0<F%N8_MZ:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")0<F%N
M8_MZ:6IA+"!-971R;W!O;&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H
M($=U:6%N82(*;7-G<W1R(")0<F%N8_MZ:6IO<R!'=FEA;F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")0<F%N8_MZ
M:6IO<R!0;VQI;F5Z:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B4')A;F/[>FEJ;W,@<&EE
M=&ENZW,@=&5R:71O<FEJ;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(DYU;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B3G5O("(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&
M=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E!I;&YA<R!A<')A\'EM87,B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W
M-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(E!I;&YA=&ES(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")0:6QN87,@
M=F%R9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B
M;VYA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VTB"FUS9W-T<B`B1V%L97)I:F$@:?`@:W5R:6]S(&GP(&MU<FEO<R!B
M=7,@<F]D;VUA<R!P879E:6MS;.ML:7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A
M;&QE<GDZ(@IM<V=S='(@(D=A;&5R:6IA.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=A;6)I82(*;7-G<W1R(")'86UB:6IA(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R=6]T:2`E<R!N=7-T871Y;75S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G
M:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(E-U9V5N97)U;W1A<R!K;V1A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1W)U>FEJ
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B5F]K:65T
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1V%N82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT
M87)A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(E9A<F1A<R(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R(")2;V1Y
M=&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E
M;"(*;7-G<W1R(")'861E;&ES(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-
M87!S(@IM<V=S='(@(D=O;V=L92!P86EE\&MA(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")'
M;V]G;&4@<&%I9?!K82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(").97-P
M86QV;W1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B
M1W)A:6MI:F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B
M1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R86EK:?!K82`H25-/+3@X
M-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B
M1W)E;FQA;F1I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S
M='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<&GX(&%D;6EN:7-T
M<F%V:6UA<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@
M;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B1W)U<.MS('9A<F1A
M<R!T=7)I(&+[=&D@;F5T=?#H:6%S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@<W5K
M=7)T:2!V87)T;W1O:N`@)7,@;F5P879Y:V\N(%-E<G9E<FEO('!R86YE\&EM
M87,Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@871N875J:6YT:2!V87)T;W1O:N`@
M)7,@;F5P879Y:V\B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!A=&YA=6II
M;G1I('9A<G1O=&]JX"`E<R!N97!A=GEK;R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B
M"FUS9W-T<B`B1W)U<.MS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P
M92(*;7-G<W1R(")'=F%D96QU<.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M;2(*;7-G<W1R(")'=6%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA
M;&$B"FUS9W-T<B`B1W9A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1V5R;G-I<R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(E-V9>AI^"!T96ESZW,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B4W9EZ&GX
M(&MN>6=A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=V
M:6[K:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B0FES<V%U+4=V:6[K:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M>6%N82(*;7-G<W1R(")'86IA;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!N96=A;&D@:?!T
M<FEN=&D@<&%S:W5T:6[K<R!C96SK<R!E:6QU=.MJ92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YE9V%L:2!I
M\')I;G1I('!A<VMU=&EN:6\@<W1U;'!E;&EO(&QE;G1E;.MJ92XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YE9V%L
M:2!I\'1R:6YT:2!P87-K=71I;NMS(&5I;'5TZW,@;&5N=&5LZVIE+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4F5I:V%L:6YG
M82!(5%10(&%U=&5N=&EF:6MA8VEJ82XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DAA:71I(@IM<V=S='(@(DAA:71I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T
M<B`B2&%S:"U!;&=O<FET;6%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B36EG;&$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(D%N=')A
M\'3K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")!;G1R8?!T
MZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O
M;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE<F1O('-A;&$@:7(@36%K9&]N86QD
M;R!S86QO<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@
M(E0M875D<F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B
M2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)A:O@@*$E33RTX
M.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B075K\'1I
M<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM
M<V=I9"`B2&5L<"(*;7-G<W1R(")086=A;&)A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN
M9R!E9&ET;W(B"FUS9W-T<B`B4F5D86MT;W)I875S(&YA=61O:FEM;W-I('!A
M9V%L8F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED
M(")(96QP97(B"FUS9W-T<B`B4&%G86QB:6YI;FMA<R(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(96UI
M<V9E<F$B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("+0=&%I(.AI82!Y<F$@
M9F%I;&\@<')A9/YI83HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R(")3=F%R8G4B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN
M+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(E]0
M;W)T86QA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(M!V96YT87-I<R!3;W-T87,@*%9A
M=&EK86YO('9A;'-T:6IA*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R(")0;W)T86QA<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B
M2&]M92!!9&1R97-S(@IM<V=S='(@(DYA;?@@861R97-A<R(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!$:7)E
M8W1O<GDB"FUS9W-T<B`B2V%T86QO9V%S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*
M;7-G<W1R(").86WX('1E;&5F;VYA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M2&]N9'5R87,B"FUS9W-T<B`B2&]N9/MR87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G
M:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYK;VYG87,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(E!O
M<G1A;&%S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@;F5T96ES:6YG:2`E<R!834P@9'5O;65N>7,@_FEN=73K:F4@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P
M;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&]B:F5K
M=&\@)7,@;F5A=&ET:6YK82!J;VMI82#^:6YU=.LB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;V)J96MT;R!T:7!A<R`E<R!N
M97)A<W1A<R#^:6YU=.MJ92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B`E<R!<(B5S7"(@<^MK;6EN86D@:?!T<FEN=&$B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&EN=&5G<F%C
M:6IO<R!V87)I:VQI=6MU:2!R96EK86QI;F=A<R`G9&]M>&UL)R!02%`@;6]D
M=6QI<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!N97!A=GEK;R!S=6MU<G1I(&YA=6IO(%A-3"!M963^:6\@;V)J96MT
M=6D@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P879Y
M:V\@:?!T<FEN=&D@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@
M;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P879Y:V\@9V%U
M=&D@34E-12!)1"!D86QI86D@)7,@=&EP;R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O=&D@
M)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O=&D@96QE;65N=/@Z("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!N9?YI;F]M87,@96QE;65N=&%S(%PB)7-<
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")(;W)I>F]N=&%L
M:2!L:6YI:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B
M2&]R:7IO;G1A;'5S('1A<G!A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S
M='(@(DAO<FEZ;VYT86QI86DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")+86EP(.AI
M82!P871E:V]T93\@*%!R86YE\&MI=&4A*2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(DMI96L@<W1U;'!E;&GX(&YO<FET92!S=6IU;F=T:3\B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DMI96L@;&%U:_@@*'-T
M=6QP96QI^"D@=&5N('ER83\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+:65K(&5I;'7H
M:?@@;F]R:71E('-U:G5N9W1I/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU
M;6ED:71Y(@IM<V=S='(@(D1RZV=N=6UA<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B
M1'+K9VYU;6%S.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G
M:60@(DAU;6]R:7-T<R(*;7-G<W1R(")*=6UO<F5S:V]S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(E9E;F=R:6IA(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B3F5P879Y
M:V\@<W5K=7)T:2!)34%0('!A\'1O(&3K_G5TZW,Z("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B3F5P879Y:V\@
M:?!T<FEN=&D@24U!4"!P8?!T;R!DZ_YU=.MS.B`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DYE<&%V
M>6MO(&YU<W1A='ET:2!)34%0('!A\'1O(&3K_G5TZW,@9'ED_FEO.B`E<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*;7-G:60@(DE0($%D
M9')E<W,B"FUS9W-T<B`B25`@861R97-A<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B3F5P879Y:V\@9V%U=&D@25`@861R97-O+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@
M(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM
M<V=S='(@(DE0(&%D<F5S87,@;F5T96ES:6YG86UE($-)1%(@8FQO:V4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(DE0
M('7^<F%K:6YT87,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O
M<F4B"FUS9W-T<B`B7\%T97)P=&D@96EL=73F('9I<O!U:F4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YD:6IA(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*
M;7-G<W1R(")4:6L@<&EK=&]G<F%M;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O
M<B`E<R(*;7-G<W1R("(E<R!N=7-T871Y;6%I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@
M(E!I:W1O9W)A;6]S('-U('1E:W-T=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B07!R
M8?!O('!A=F%D:6YI;6%S.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N(@IM<V=S='(@(DIE:2!N96=A;&ET92!P97)S:V%I='ET:2#P
M:6\@;&%I\&MO+"`E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U
M"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I
M;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B
M"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)*96EG
M=2!M871O=&4@\&G@(/YI;G5TYB!V:65T;VH@<&%V96EK<VSK;&EO+"!K=7+A
M(&YO<FET92#A:V5L=&DL('1A:2!*^W/X("(*(FYA<O!Y:VSK(&YE9V%L:2!J
M;R!A='9A:7ID=6]T:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I
M97<Z(@IM<V=S='(@(E!A=F5I:W-LZVQI;R!P97+^:?MR82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G
M:60@(DEM86=E(%523"(*;7-G<W1R(")0879E:6MS;.ML:6\@55),(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E!A=F5I:W-LZVQI
M;R!54DPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB
M"FUS9W-T<B`B4&%V96EK<VSK;&ES(&GP(&=A;&5R:6IO<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")0879E:6MS
M;.ML:7,@:?`@9V%L97)I:F]S.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")0879E:6MS
M;.ML:6\@X6OK;&EM87,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM
M<V=I9"`B26UA9V5S(@IM<V=S='(@(E9A:7ID86DB"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M="P@4W1E<"`E9"(*;7-G<W1R("+!:^ML:6UA<RP@)60@_FEN9W-N:7,B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B3&%U:V%S(.%K
M96QT87,Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM
M<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("+!:V5L=&D@;&%U:V%I
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B
MP5]T97)P=&D@96EL=73F(&%P8>AI;VIE(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(DYE=&5I<VEN9V%S('9E:6MS;6\@
M:V]D87,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(DYE=&5I<VEN9V%S('9A<G1O=&]J;R!V87)D
M87,@:7(O87)B82!S;&%P=&'^;V1I<RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B).96ET96ES:6YG87,@=F%R=&]T;VIO('9A<F1A<R!A<F)A
M(&%L=&5R;F%T>79U<R!E;"X@<&'P=&\@861R97-A<RX@0F%N9'EK:71E("(*
M(F1A<B!K87)TX"!A<F)A('-U<VES:65K:71E('-U('-A=F\@861M:6YI<W1R
M871O<FEU;6D@:F5I9W4@<F5I:V%L:6YG82`B"B)T;VQE<V[K('!A9V%L8F$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(E!A9&ED:6YT:2!A
M=&ET<F%U:VEMX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T
M<B`B26YD:6IA(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV
M:61U86P@57-E<G,B"FUS9W-T<B`B26YD:79I9'5A;/MS('9A<G1O=&]J86DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O
M;F5Z:6IA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O<FUA8VEJ82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*;7-G:60@(DEN9F]R;6%T
M:6]N(@IM<V=S='(@(DEN9F]R;6%C:6IA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,S,`HC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VX@
M;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B3G5S=&%T>6WX(&[K<F$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R
M("+!=')A=6MT:2!S='5L<&5LX2!?9&7P:6[K:F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G
M:60@(DEN<V5R="!);6%G92(*;7-G<W1R("+!=&5R<'1I('!A=F5I:W-LZVSA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(L%T97)P=&D@;&5N=&5L
MYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("+!=&5R<'1I(&YU
M;W)O9.`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*
M;7-G<W1R("+!=&5R<'1I('-T=6QP96SA(%]K86ERZVIE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("+!=&5R<'1I(&YA=6K@('-T=6QP96SA(&5S86UO('-T=6QP
M96QI;R!D9?!I;NMJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(L%T97)P=&D@
M;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&MA:7+K:F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(L%T97)P=&D@;F%U:N`@96EL=73F(&5S86UO<R!E:6QU
M=.MS(&%P8>AI;VIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BP71E<G!T:2!N875J
MX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@=FER\'5J92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B
M"FUS9W-T<B`BP71E<G!T:2!P87)A9W)A9N`@96QE;65N=&\@87!AZ&EO:F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D92(*;7-G<W1R("+!=&5R<'1I('!A<F%G<F%GX"!E;&5M
M96YT;R!V:7+P=6IE(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G
M:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BP71E<G!T
M:2!A;'1E<FYA='EV^"#P86)L;V[@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(L%R8?!Y:VET92!E;"X@<&'P=&\@861R97/@+"#A(&MU<N$@;F]R:71E(&=A
M=71I(&YA=6K@('-L87!T8?YO9.$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E
M;&P@869T97(B"FUS9W-T<B`BP71E<G!T:2!C96SF('!O('1O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM
M<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(L%T97)P=&D@8V5L
MYB!P<FEE\"!T86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R
M(@IM<V=S='(@(L%T97)P=&D@<W1U;'!E;.$@9&7P:6[K:F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("+!=&5R<'1I('-T
M=6QP96SA(&MA:7+K:F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@
M(L%T97)P=&D@;&%I\&MU<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!A9G1E<B(*;7-G<W1R("+!=&5R<'1I('!A<F%G<F%FX"!P;R!T;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T
M<B`BP71E<G!T:2!P87)A9W)A9N`@<')I9?`@=&%I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B
M26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("+!=&5R<'1I(&5I;'5TYB!P;R!T
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(L%T
M97)P=&D@96EL=73F('!R:67P('1A:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O
M('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`BP7)A\'EK:71E(')E
M:6MI86W@(&%T<V%K>6W@(.$@:VQA=7-I;>`@=FER\'5J93HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("))
M;G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(L%T97)P=&DO<F5D86=U;W1I
M('!A=F5I:W-LZVSA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S
M='(@(L%T97)P=&DO4F5D86=U;W1I(&YU;W)O9.`B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B1&ES=')I8G5C:6IO<R!SX')A\'5I(&YU<VGX<W1I
M(&YE=?YT96YK82!K<F5D:71O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET+B(*;7-G<W1R(").977^=&5N:V$@:W)E9&ET;RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S
M='(@(E-K86GH:75S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S
M,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(E-K86GH:?@@<^!R8?!A
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2XB"FUS9W-T<B`B3F5T96ES:6YG87,@541(+B`H57-E<B!$871A($AE861E
M<BDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B3F5T
M96ES:6YG:2!U;FEK;V1O(&1U;VUE;GES+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S
M='(@(DYE=&5I<VEN9V%S(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED
M(&)A=&-H($E$+B(*;7-G<W1R(").971E:7-I;F=A<R!)1"XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S
M=6)M:71T960N(@IM<V=S='(@(L%V97-T:2!N971E:7-I;F=I(&1U;VUE;GES
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*
M;7-G<W1R(").971E:7-I;F=A<R!A9')E<V%S+B(*"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F
M;W)M870B"FUS9W-T<B`B3F5T96ES:6YG87,@9F%I;&\@9F]R;6%T87,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(").971E:7-I;F=A
M<R!M;V1U;&ES+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-S$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N
M(@IM<V=S='(@(DYE=&5I<VEN9V%S(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("))
M;G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(").971E:7-I;F=A<R!M<V=?='EP
M92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM
M<V=S='(@(DYE=&5I<VEN9V%S(&%R8F$@;NMR82!A<&E?:60N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B
M4&%R86UE=')A:2!N971E:7-I;F=I(&%R8F$@:O@@;NMR82XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE=&5I<VEN9V]S('!A=F5L9&EM;W,@
M=&5I<^MS+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B
M3F5T96ES:6YG;W,@<&%V96QD:6UO<R!T96ESZW,N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(DYE=&5I<VEN9V%S('!R;W1O:V]L
M87,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(").
M971E:7-I;F=A<R!P<F]T;VMO;&%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))
M;G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(DYE=&5I<VEN9V%S
M(&=A=NMJ87,Z("<E<R<B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("))
M;G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(").971E:7-I;F=A<R!O8FIE
M:W1A<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS
M9W-T<B`B3F5T96ES:6YG87,@<VEU;G3K:F\@861R97-A<RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G
M:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(").971E:7-I;F=I
M('5N:6MO9&\@9'5O;65N>7,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&]R:75S
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M.0HC+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R(")0
M97)K96QT:2!P87-I<FEN:VEMX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<VQA;6GP:V$@27)A
M;F\@4F5S<'5B;&EK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G
M<W1R("))<F%K87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS
M9W-T<B`B06ER:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(DUE;F\@<V%L82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED
M("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("))>F]L:75O=&]S(%0M875D
M<F]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27IR
M865L:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R
M-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(DGP9&%VZVIA<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A
M;&EC(@IM<V=S='(@(DMU<G-Y=F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M=&%L>2(*;7-G<W1R("))=&%L:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*
M86UA:6-A(@IM<V=S='(@(DIA;6%I:V$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R
M(")3875S:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@
M(DIA<&]N:6IA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@
M(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P;VYI\&MA("A)
M4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q
M,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y
M;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L
M87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(D3^97)S
M:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D
M86YI:F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("),:65P82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM
M<V=S='(@(D)I<OYE;&ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R
M(")0:6QN86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T
M<B`B3'EG:75O=&D@8V5N=')E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L
M;"(*;7-G<W1R("),>6=U;W1I('!I;&YA:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T
M:69Y($QE9G0B"FUS9W-T<B`B3'EG:75O=&D@:V%I<NMJ92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS
M9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(DQY9VEU;W1I(&1E\&ENZVIE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA
M>F%K<W1A;F%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B2?!S
M875G;W1I(&]R:6=I;F%LX#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA
M(@IM<V=S='(@(DME;FEJ82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I
M92!+97)B97)O<R!S97)V97)I;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(D)R86YD=6]L
M:6\@;F%U:F]K86DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")286MT;R!K^W)I
M;6%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS
M9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B4F%K=&\@871S<&%U9&%S
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED
M(")+97D@3&5N9W1H(@IM<V=S='(@(E)A:W1O(&EL9VES(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*
M;7-G<W1R(")286MT;R!T:7!A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DX"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B4F%K
M=&\@<&%N875D;VII;6%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N(@IM<V=S='(@(E)A:W1A<R!J874@>7)A('9I9?#X
M:O@@<F%K=/@@<V5R=F5R>6IE+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(")686EK86DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B1&5M;VMR871I;NL@2V]RZVIO<R!,:6%U9&EE
M<R!297-P=6)L:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B2V]RZVIO<R!297-P=6)L:6MA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*
M;7-G<W1R(")+;W+K:FEE=&GP:V$@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=79E:71A<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:7II:F$B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS
M9W-T<B`B7TGP9.MS='EM87,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")+86QB82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L
M:6,B"FUS9W-T<B`B3&%O<V\@1&5M;VMR871I;NL@3&EA=61I97,@4F5S<'5B
M;&EK82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@
M2&%L9B(*;7-G<W1R(")!;G1R82!P=7/K(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG
M92(*;7-G<W1R(")086ME:7-T:2!S;&%P=&'^;V3A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S
M="!1=6%R=&5R(@IM<V=S='(@(E!A<VMU=&EN:7,@:V5T=FER=&ES(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB
M"FUS9W-T<B`B071N875J:6YT83HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B
M"FUS9W-T<B`B4&%S:W5T:6YI<R!P<FES:6IU;F=I;6%S.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(E!A<VMU=&EN:7,@
M<')I<VEJ=6YG:6UA<SH@)7,@:?`@861R97-O("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*
M;7-G<W1R(")0<FES:6IU;F?K=&4@<&ER;>`@:V%R=.`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),871V:6IA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B5&5I<^LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("))\&3K<W1Y;6%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I
M9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R(")*96EG=2!N
M96YO<FET92!N96YA=61O=&D@:W)A\'3X+"!P86QI:VET92!T=?#H:>`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3&EB86YA<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")+86ERZVIE(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS
M9W-T<B`B2V%I<FEO:FD@86YT<F'P=.LB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$U"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")+86ER
M:6]S:6]S(')E:6OP;>MS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO
M(@IM<V=S='(@(DQE<V]T87,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@(DUE:6SK
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER
M:7EA(@IM<V=S='(@(DQI8FEJ;W,@07)A8O@@16UY<F%T86DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EC:'1E;O!T
M96EN87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")3;75L:W5S(&QI
M971U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(DYE9&ED96QI<R!L:65T
M=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R(").961I9&5L:7,@
M;&EE='5S(')Y=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(DYE
M9&ED96QI<R!L:65T=7,@=F%K87)E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R
M(@IM<V=S='(@(DYE9&ED96SK(&QI^W1I<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I
M=&@@5&AU;F1E<B(*;7-G<W1R(").961I9&5L:7,@;&EE='5S('-U('!E<FO[
M;FEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DYE9&ED96QI<R!S;FEE
M9V%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(DYE9&ED96SK
M(/!L87!D<FEB82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I
M9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EM97)I:V%S(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*;7-G<W1R(").=6]R
M;V1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M3G5O<F]D82#A.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*
M;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B4&%D87)Y=&D@96PN('!A
M\'1O(&%D<F5SX"!N=6]R;V1A(.$@;&%I\&MO(')A\'EM;R!P=7-L87#A(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3G5O<F]D;W,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G
M<W1R("),:6YU>"!L86EMZW,@_FEN=73K<R(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B4F]D>71I("T@=F%R=&]T;VIA
M<R!G86QI(&UA='ET:2!K871A;&]G;R!T=7)I;N$B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")2
M;V1Y=&D@9'5O;65N^"!B87II^"!SX')A\.`B"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R
M(")2;V1Y=&D@<&%G86QB;W,@=&5M87,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")2;V1Y=&D@;&5N
M=&5L:?@@<^!R8?#@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R(")+;VYF97)E
M;F-I:F]S(&%R8VAY=F%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R(")+;VYF97)E
M;F-I:F]S('!A9V%L8F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R(")+;VYF97)E;F-I
M:F]S($E$(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B2V]N9F5R96YC:6IO<R!S
M879I;FEN:V%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R(")28?!Y=&D@X2!K;VYF
M97)E;F-I:N`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B4')I<VEJ=6YG
M=&D@<')I92!K;VYF97)E;F-I:F]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS
M9W-T<B`B071S:6IU;F=T:2!N=6\@:V]N9F5R96YC:6IO<R(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(E9A<G1O=&]J
M^"!SX')A\&%S('7^9')A=7-T87,N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B5F%R=&]T;VKX('/@<F'P87,@=?YD<F%U
M<W1A<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(E9A
M<G1O=&]J^"!SX')A\&%S('7^9')A=7-T87,N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R
M873[<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R
M("),:65T=79A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(")+<F%U;F$N
M+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED
M("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B5FEE=&EN:7,@;&%I:V%S.B`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@
M5&EM92(*;7-G<W1R("),;VMA;.L@:7(@;&%I:V%S(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O
M0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")6
M:65T82(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")0<FES:6IU;F=T
M:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T
M(@IM<V=S='(@(D%T<VEJ=6YG=&DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(E!R:7-I:G5N
M9W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G
M:6X@5&%S:W,B"FUS9W-T<B`B4')I<VEJ=6YG:6UO(&1A<F)A:2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4')I<VEJ=6YG=&D@;F5P879Y
M:V\N($YE=&5I<VEN9V%S($K[<_@@;G5R;V1Y=&%S('9A<G1O=&]J;R!V87)D
M87,@:7(O87(@(@HB<VQA<'1A_F]D:7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(E!R
M:7-I:G5N9W1I(&YE<&%V>6MO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("));&=A<R!T96MS
M=&%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E
M(@IM<V=S='(@(DUE:6SK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R(").97-V87)B=2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B
M36'^;W-I;W,@9W)A:6MI\&MO<R!R86EDZW,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),
M;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(DUA_F]S:6]S(&QO='EN:?!K
M;W,@<F%I9.MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R(")-8?YI96II(')O;>MN:?!K:2!S:V%IZ&EA:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),:75K<V5M8G5R
M9V%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R
M(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@
M(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@
M8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(E!R:6MA8FEN=&%M92!-4RU4
M3D5&(&9A:6QE(&[K<F$@9'5O;>MN^"XB"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS
M9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M86-A;R(*;7-G<W1R(")-86MA;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(DUA:V5D;VYI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C
M87(B"FUS9W-T<B`B36%D86=A<VMA<F%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-86=I:F$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T
M<B`B4&'P=&%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM
M<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")08?!T;R!V86QD>6UA<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")3=6MU<G1I(%]N
M=6]R;V3@+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T
M<B`B36%L879I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS
M9W-T<B`B36%L86EZ:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E
M<R(*;7-G<W1R(")-86QD>79A:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L
M:2(*;7-G<W1R(")-86QI<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B
M"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*
M;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I
M871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(DMA=&5G
M;W)I:O@@<^!R8?!O+"!K=7)I;VUS('!R:7-K:7)I86UI(&]B:F5K=&%I+"!I
M<B!S=2!J;VUI<R!S=7-I:G5S:?@@(@HB<W!A;';X(&ME:71I;6%S+B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS
M9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0@_F5MZVQA<&ES(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G
M:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="#^96WK;&%P:7,B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA
M<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@
M(DMO=F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(E!A<F'P=.LB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM
M<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(E!A
M_GEMZW1I(&MA:7`@<VMA:71Y='5S+VYE<VMA:71Y='5S(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM
M<V=S='(@(E!A_GEMZW1I(&MI=&%I<R!A=')I8G5T86ES("AP=GHN('-V87)B
M=2]A='-A:WET82DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES
M;&%N9',B"FUS9W-T<B`B36%R\&%L;R!S86QO<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI:V$B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE
M;&1S(@IM<V=S='(@(E-U:G5N9W1I(&QA=6MA:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:71A;FEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I8VEJ=7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%K
M<VEM86QU<R!K<F5D:71A<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A
M<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")-86MS:6UA;'5S(/YI;G7H:?@@9&%L
M:?@@:VEE:VES(&GP96EK=F]T87,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R
M(")-86MS+B!T96UP+B!P87-K+B`R-"!V86PZ("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R(")-86MS+B!T96UP+B!P87-K+B`V('9A;#H@(@H*(SH@;&EB+V%P
M:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B36%K<VEM86QU<R!I;&=I<R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B1V5G=?[K
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-;VIO
M=.LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC
M:6YE(@IM<V=S='(@(DUE9&EC:6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(").87)I
M86DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU
M(&UO9&4Z(@IM<V=S='(@(DUE;FEU(')E_FEM87,Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B
M365R9V4@8V5L;',B"FUS9W-T<B`B4W5J=6YG=&D@8V5L97,B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM
M<V=I9"`B365S<V%G92(*;7-G<W1R("+>:6YU=.LB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(DQA
M:?!K87,@<&%V:7)T:6YT87,L('1AZ&EA=2!N97!A='9I<G1I;G1A<R!P87-I
M<F'P:75S:6\@87-M96YS('-E<G1I9FEK871A<RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE
M<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`BWFEN=73K(&YE:?!S:?AS=&$N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(MYI
M;G5TZW,@=&EP87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@
M(DUE=&%R(%=E871H97(B"FUS9W-T<B`B3W)O('-A;'EG;W,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")/<F\@<^!L>6?X(&)L;VMO(&[K<F$N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D]R;R!SX&QY9_@@8FQO:V\@
M;NMR82X@061M:6YI<W1R871O<FEU:2!I\'-I^'-T87,@9&5T86QU<R!A<')A
M\'EM87,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM
M<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO
M9"(*;7-G<W1R(")-971O9&%S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL
M<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T
M(&1E9FEN960B"FUS9W-T<B`B365T;V1A<R`G)7,G(&YE87!R8?!Y=&%S(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S
M='(@(DUA=&%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T
M<B`B365K<VEK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&
M961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O;F5Z:6IO<R!&961E
M<F%C:6[K<R!686QS=&EJ;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R
M(")6:61U<GEJ92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B34E-12!T:7!A
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36EN+B!T96UP+B!P87-K+B`R
M-"!V86PZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-
M:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")-:6XN('1E;7`N('!A
M<VLN(#8@:&]U<G,Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S0*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")!
M='-P:6YD>7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B2VET;W,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B3F5R
M87-T87,@4$5!4B!(5%107U)E<75E<W0@<&%K971A<RXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R
M871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N
M="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB3G5S
M=&%T>6WX(&[K<F$N($IE:6=U(&YO<FET92!N875D;W1I(/#A(&UO9'5LX2P@
M='5R:71E(&KA('-U:V]N9FEG^W)U;W1I+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN
M9R!M97-S86=E($E$+B(*;7-G<W1R(").ZW)A(/YI;G5TZW,@240N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN
M(@IM<V=S='(@(DYE<F%S=&%S(')E:6MA;&EN9V%S(%!%05(@36%I;"!P86ME
M=&%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R
M(").ZW)A('-E<VEJ;W,@240N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B4&ER;2XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(DUO8FEL=7,@<&'P=&%S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E
M(@IM<V=S='(@(E9I9'5T:6YI<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(E)E9&%G879I
M;6\@9&%T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")+
M96ES=&D@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QI<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M36]L9&]V;W,@4F5S<'5B;&EK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N
M86-O(@IM<V=S='(@(DUO;F%K87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO
M;F=O;&EA(@IM<V=S='(@(DUO;F=O;&EJ82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@
M(DWK;F5S:6%I(&ER(&UE=&%I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")+
M87,@;>MN97/A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM
M<V=S='(@(DUO;G-E<F%T87,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S
M='(@(DWK;G5L:6\@9F%ZZW,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H
M<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@
M=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:V%S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L
M>2!#;&5A<B(*;7-G<W1R(")$875G:6%U<VEA(&=I961R82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T
M;'D@0VQO=61Y(@IM<V=S='(@(D1A=6=I875S:6$@87!S:6YA=6OF(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@
M(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")$875G:6%U<VEA('-A=6SK=&$B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@
M(DUO=F4@1&]W;B(*;7-G<W1R(")097)K96QT:2#^96UI874B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R(")097)K96QT:2!K86ER:6%U(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(E!E<FME;'1I(&1E\&EN:6%U(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S
M='(@(E!E<FME;'1I(&%U:_#H:6%U(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(E!E<FOK;&EM87,@_F5M>6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
M4&5R:^ML:6UA<R!A=6OP='EN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA
M;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK87,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',B"FUS9W-T<B`B2V5L971O(&QY9VGX(&GP<VES:VQE:63^:6%N=&ES
M('/@<F'P87,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I
M<&QE('-E;&5C=&EO;B(*;7-G<W1R(")+96QE=&%S('!A<VER:6YK:6WX(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C
M;W5N="(*;7-G<W1R(")-86YO('/@<VMA:71A(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:6IA(&%P:64@2G5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM
M<V=S='(@(DUA;F\@<&]R=&%L87,B"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUA
M;F\@<&]R=&%L;R!I\&3K<W1Y;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M>6%N;6%R(@IM<V=S='(@(DUA:6YM87)A<R(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.
M3U0@06=R964B"FUS9W-T<B`B3D4L($Y%4U5424Y+52(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(E9A<F1A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI
M8FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U
M<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A
M;&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R
M(").>61E<FQA;F1A:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD
M<R!!;G1I;&QE<R(*;7-G<W1R(").>61E<FQA;F3X($%N=&EL86DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T
M<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T<V-P87!E(&)A>FEN:7,@55),
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G
M:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C
M<&%E('-E<FEF:6MA=&\@873P875K:6UO(%523"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P
M;VQI8WD@55),(@IM<V=S='(@(DYE='-C<&%E('-E<G1I9FEK871O('1E:7-I
M^"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T<V-A
M<&4@871N875J:6YO;6\@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(DYE='-C87!E(&%T\&%U:VEM;R!54DPB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"!S97)V97)I
M;R!V87)D87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G
M<W1R(").971S8V%P92!S97)T:69I:V%T;R!A<')A\'EM87,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P92!S97)T:69I
M:V%T;R!T:7!A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*
M;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B5&EN:VQA<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE
M=F5R(@IM<V=S='(@(DYI96MA9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE
M=R!#86QE9&]N:6$B"FUS9W-T<B`B3F%U:F]J:2!+86QE9&]N:6IA(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*
M;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").875J82!K871E9V]R:6IA
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A
M9V4@=&\@)7,B"FUS9W-T<B`B4F'P>71I(&QA:?!KX"`H)7,I(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(").
M875J87,@;>MN=6QI<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S
M='(@(DYA=6IA<R!V87)T;W1O:F\@=F%R9&%S("AN96+[=&EN87,I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").875J;VII
M(%IE;&%N9&EJ82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(E-L87!T
M8?YO9&ES(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@
M;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`B4VQA<'1A_F]D_FEA:2!T=7)I('-U=&%P=&DN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM
M<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").875J86UE(&QA
M;F=E("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR.#D*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F%U:FEE;F]S(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P
M<R(*;7-G<W1R(").875J:65N^"!G<G5PZW,B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT
M,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(")396MA
M;G1I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(")396MA;G1I(&9A>NLB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,W-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S
M='(@(E-E:V%N='ES(&YU<W1A='EM86DB"@HC.B!F<F%M97=O<FLO54DO54DO
M4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B
M4V5K86YT:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G
M<W1R(").:6MA<F%G=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM
M<V=S='(@(DYI9V5R:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B
M"FUS9W-T<B`B3FEG97)I:F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G<W1R(").86MT:7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU:NLB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").
M;R(*;7-G<W1R(").92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F
M+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T
M82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B3F5U_G1E;FMA
M(&1U;VUE;O@@<VMI<G1U;?@@<&%R;V1Y;75I+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R
M(").96YU<F]D>71A('-T<F%T96=I:F$@25-/(')A\'EM=6DN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS
M9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B3NMR82!S=63K=&EN
M:6\@\&%B;&]N;RXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED
M(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*
M;7-G<W1R(").=7)O9'ET;VIE('!O>FEC:6IO:F4@8FQO:V\@;NMR82(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DYEX79E9.MT92!K86QE;F1O<FEA=7,@=F%R9&\@34-!3"!A
M=71E;G1I9FEK86-I:F]J92XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU
M-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")3:VER='5M^"!NZW)A+B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*
M;7-G<W1R("+0:6]S('1E:7/K<R!N96=A;&D@='5RZW1I('!O=&5I<VGX+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(D[K<F$@:6YF
M;W)M86-I:F]S(&%P:64@)7,@:V]N9FEG^W)A8VEJX"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@
M(D[K<F$@:6YF;W)M86-I:F]S(&%P:64@1E10(%9&4R!K;VYF:6?[<F%C:6K@
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RXB"FUS9W-T<B`B3NMR82!I;F9O<FUA8VEJ;W,@87!I92!344P@5D93
M(&MO;F9I9_MR86-I:N`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B3NMR82!I
M;F9O<FUA8VEJ;W,@87!I92!344PM1FEL92!61E,@:V]N9FEG^W)A8VEJX"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")+<F5D:71A
M<R!I\&5I:W9O=&%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P
M;&EE9"XB"FUS9W-T<B`B3F7A=F5S=&%S(&=A=NMJ87,N(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P
M;&]A9&5D(@IM<V=S='(@(D9A:6QA<R!N96YU<VGX<W1A<R(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B3F\@:6-O;G,@
M9F]U;F0N(@IM<V=S='(@(B5S(&YE<F%S=&%S+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO
M;B!I<R!S970N(@IM<V=S='(@(DYE;G5S=&%T>71A('9I971O=NLN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE;G5S=&%T>71A
M('9I971O=NLN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM
M<V=S='(@(DYEX7)A\.MT92#^:6YU=.MS+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE
M('-P96-I9FEE9"XB"FUS9W-T<B`B3F7A<F'PZW1E('9A<F1O+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS
M9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").9>%R8?#K=&4@
M;G5M97)I;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@
M(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").97)O9'ET:2#A_F5I
M9/YI86[H:?@@9G)A>FGX(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P
M+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYEX79E9.MT92!S;&%P=&'^;V3^
M:6\@2%144"!A=71E;G1I9FEK86-I:F%I+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F7A=F5DZW1E
M('-L87!T8?YO9/YI;R!)34%0(&%U=&5N=&EF:6MA8VEJ86DN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(").9>%V963K=&4@<VQA<'1A_F]D_FEO($ME<F)E<F]S(&%U=&5N=&EF
M:6MA8VEJ86DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW
M-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F7A
M=F5DZW1E('-L87!T8?YO9/YI;R!,;V=I;B!A=71E;G1I9FEK86-I:F%I+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DYEX79E9.MT92!S;&%P=&'^;V3^:6\@4$%34U=$(&%U
M=&5N=&EF:6MA8VEJ86DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").9>%V963K=&4@<VQA<'1A_F]D_FEO
M(%--0B!A=71E;G1I9FEK86-I:F%I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@
M3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I
M<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS
M9W-T<B`B(@HB3F7A=F5S=&%S(&ME;&EA<R!I:VD@3W!E;E-33"!P86=R:6YD
M:6YI^"!F86EL^"X@3W!E;E-33"!R96EK86QI;F=A(&1A<F)U:2!S=2`B"B)0
M2T-3(#$R(&1U;VUE;FEM:7,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G
M<W1R(").97!A='9I<G1I;G3X(')E9VES=')A8VEJ^"!NZW)A+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B3F5N=7)O9'ET82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DYE;F%U9&]T:2!S:VER='5K
M^"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B3F7A
M<F'PZW1E(&YU;65R:6\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T
M<B`B3NL@=FEE;F]J92!P=7/K:F4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S
M='(@(D[K('9I96YO:F4@<'5SZVIE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")3<&%R=&EN:6UU:2!NZW)A
M(&QA:6MI;F]J;R!K871A;&]G;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(E9A<G1O=&]J;R!V87)D87,@
M:7(O87)B82!S;&%P=&'^;V1I<R!N96YU<VGX<W1A<RXB"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B5&5I<VEN9_@@6$U,(&1U;VUE;O@@
M;NMR82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3DR"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B3NMR82!R96EK\&UI^"(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+;VYF:6?[<F%C:6YI86UE(&9A
M:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E;F5R=6]K:71E(&YU<W1A='EM=7,N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N9FEG^W)A8VEN:6%M92!F86EL
M92!NZW)A('9E<G-I:F]S+B!097)G96YE<G5O:VET92!N=7-T871Y;75S+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@
M(DYO;F4B"FUS9W-T<B`B3F5N=7)O9'ET82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I
M;7!L:6-I="DB"FUS9W-T<B`B3NMR82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("+0
M:6%U<NMS("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO
M<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&MO('-A;&]S(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I
M9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("+0:6%U<FENZR!H96UI
M<V9E<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@
M27-L86YD<R(*;7-G<W1R("+0:6%U<FENZW,@36%R:6IA;O@@<V%L;W,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)V96=I:F$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I
M9"`B3F]T($%F=&5R(@IM<V=S='(@(DYE('!O('1O(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B
M"FUS9W-T<B`B3F4@<')I9?`@=&%I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
M3F4@:V%T86QO9V%S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@
M(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3F5R96%L:7IU;W1A+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G
M:60@(DYO="!S970B"FUS9W-T<B`B3F5N=7)O9'ET82(*"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D
M+B(*;7-G<W1R(").97!A;&%I:V]M87,N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED
M(").;W1E<R(*;7-G<W1R(")5_G)A\&%I(@H*(SH@<V5R=FEC97,O;V)R;W=S
M97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RXB"FUS9W-T<B`B3NMR82!KX"!P97+^:?MRZW1I+"!E:6MI=&4@871G
M86PN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DQA<&MR:71I<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G
M<W1R(").=6UE<FES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B4VEM8F]L
M:?@@<VMA:>AI=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T
M<B`B4W1U;'!E;&GX('-K86GH:75S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S
M(@IM<V=S='(@(D5I;'7H:?@@<VMA:>AI=7,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R
M<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B3F7A=F5S=&D@9&ES=')I8G5C:6IO<R!SX')A\&\@
M871N875J:6YI;6\@<VMA:>AI86DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*
M;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE:W1A<R(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*
M;7-G<W1R(")/8FIE:W1O('-A=FEN:6YK87,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R(")!\'1U;G1A
M:6YI<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(E-P86QI<R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS
M9W-T<B`BWFEA=7)U;6\@9FEL=')A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R(")/9FES87,B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A
M;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY
M"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4VQA<'1A_F]D:7,B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G
M:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B4VQA
M<'1A_F]D:7,@;F5T96ES:6YG87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M
M86XB"FUS9W-T<B`B3VUA;F%S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(DMA=&%L;V?X(&1A;&EJ
M:6W@<VD@<&%L86EK;R!T:6L@24U!4"!S97)V97)I86DN(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T
M=6YE<R(*;7-G<W1R(")4:6L@X?YE:63^:6%NZ&EO<R!F<F%ZZW,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B3&5I9/YI86UA<R!T:6L@=FEE;F%S(&5L+B!P8?!T
M;R!A9')E<V%S+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM
M<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB16QE;65N=&\@<V%V:6YI;FMO
M('1E:7-E<R!G86QI(&ME:7-T:2!T:6L@:F\@<V%V:6YI;FMA<R!A<F)A('-I
M<W1E;6]S("(*(F%D;6EN:7-T<F%T;W)I=7,B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B071I9&%R>71I(&YA=6IA;64@;&%N9V4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%T:61A<GET:2#P:>`@;G5O<F]D
MX"!N875J86UE(&QA;F=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S
M"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D]P<F%C:6[K<R!S
M:7-T96UO<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*
M;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3G5S=&%T>6UA:2(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(E
M<R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E-U
M<OOP:75O=&%S('/@<F'P87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R
M9V%N:7IA8VEJ82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(E!A
M9&%L:6YY<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G
M:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B4VES=&5M:6YI;6%S(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E(@IM<V=S='(@(D]R:6=I;F%L=7,@87!L:6MA8VEJ;W,@
M\&%B;&]N87,B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S
M='(@(D]R:6=I;F%L^',@\&%B;&]N86D@)7,Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*
M;7-G:60@(D]T:&5R(@IM<V=S='(@(DMI=&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R
M(")+:71A(&EN9F]R;6%C:6IA(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4V%V
M:6YI;FEK;R!T96ESZW,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP
M:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(").ZW)A(%!!32!A=71E;G1I9FEK86-I:F]S(&UE8VAA
M;FEZ;6\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I
M9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(E!'4"!S:V%I=&UE
M;FEN:7,@<&%R8?!A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")0
M1U`@=?YK;V1U;W1A(&EN9F]R;6%C:6IA(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS
M9W-T<B`B4$=0('9I9?!A<VES(')A:W1A<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B4$=0('!A<VER8?!Y=&DO=?YK;V1U;W1I(&1U
M;VUE;GES(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@
M0V]D92(*;7-G<W1R(")02%`@:V]D87,B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@0TQ)(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@
M(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B4$T@;&5N9W9A<R!L:65T=7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I
M9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")032!L:?MT:7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0HC+"!F=7IZ>0IM<V=I
M9"`B4$T@4VYO=R(*;7-G<W1R(")032!L:?MT:7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`HC+"!F=7IZ>0IM<V=I9"`B
M4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E#[9V$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")032!4+6%U9')A
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@
M97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?2%`@0TQ)(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")487)P86D@8V5LZW-E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A
M;F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L
M874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(E7^:6UT;VII(%!A;&5S=&EN;W,@=&5R
M:71O<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@
M(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE
M82(*;7-G<W1R(")087!U82!.875J;VII($=V:6[K:F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W9A:G5S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@
M(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B1&%L:6YA:2!D96)E<W5O=&$B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS
M9VED(")087-S=V]R9"(*;7-G<W1R(")3;&%P=&'^;V1I<R(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA
M;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@IM<V=I9"`B4&%S<W=O<F0@:6YC
M;W)R96-T(@IM<V=S='(@(E-L87!T8?YO9&ES(&YE=&5I<VEN9V%S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4D%$2553(&%U=&5N=&EF:6MA8VEJ86D@<F5I:VEA('-L87!T8?YO
M9/YI;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED
M(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")3;&%P=&'^
M;V1I<R!S=2!P871V:7)T:6YI;74B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")3;&%P=&'^
M;V1I<SHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I
M9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")3;&%P=&'^;V1I<SH@(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(E-L87!T8?YO9/YI86D@
M='5R:2!S=71A<'1I+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R
M"FUS9VED(")087-T92(*;7-G<W1R("+!:V5L=&DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F
M<F]M(&-L:7!B;V%R9"(*;7-G<W1R("+!:V5L=&D@:?`@;&%I:VEN;W-I;W,@
M<V%U9WEK;&]S("AC;&EP8F]A<F0I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")+
M96QI87,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I
M9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(").97!A='9I<G1I;G1O<R!R
M96=I<W1R86-I:F]S.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM
M<V=I9"`B4&5O<&QE(@IM<V=S='(@(MYM;V[K<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT
M(@IM<V=S='(@(E!R;V-E;G1A:2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B071L:6MT:2!P<F]F:6QA:W1I;FEU
M<R!V96EK<VUU<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`B07(@871L:6MT:2!P<F]F:6QA:W1I;FEU<R!V96EK<VUU<R!P
M<FES:6IU;F=I;6\@;65T=3\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")496ESZW,B
M"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB
M"FUS9W-T<B`B5&5I<^MS("<E<R<@;F5I\'1R:6YT;W,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z>GD*;7-G:60@(E!E<FUI
M<W-I;VX@1&5N:65D(@IM<V=S='(@(E1E:7/K<R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M(")?5&5I<^MS(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP
M:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B5&5I<VGX(&%D;6EN:7-T
M<F%V:6UA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B
M4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B07-M96YI;NL@:6YF;W)M
M86-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R
M=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*
M;7-G<W1R(")'>7;[;F%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P
M:6YE<R(*;7-G<W1R(")&:6QI<&EN86DB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R
M(")496QE9F]N87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X
M"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B3G5O=')A=6MO<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&MR86YA<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS
M9VED(")0:7AE;',B"FUS9W-T<B`B4&EK<V5L:6%I(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(D)A
M;F%L>6+K<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;"(*;7-G<W1R("))\'-I<FEN:VET92!K=7)IX"!N;W)S(&-E;.8B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B4&%T=FER=&EN:VET92P@
M87(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#PX2!E;&5M96YTX#HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B4&%T=FER=&EN:VET92P@87(@
M=&EK<F%I(&YO<FET92!I\'1R:6YT:2#P:6\@96QE;65N=&\@;G5O<F]DX"XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED(")0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("+!=F5S:VET
M92!MZVYE<^$@:7(@;65T=7,N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(L%V97-K:71E(&YA
M=6IO<R!K871E9V]R:6IO<R!P879A9&EN:6W@.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N(@IM<V=S='(@(L%V97-K:71E('1E:7-I;F?@($E0(&%D
M<F5SX"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED
M(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R
M(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("+!=F5S:VET92!T96ES
M:6YGX"!D873@+"!P871I:W)I;FMI=&4@9&EE;O@@<VMA:>AI^"!MZVYE<WEJ
M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("+!=F5S:VET92!T
M96ES:6YGX"!L86EKX"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN(@IM<V=S='(@(D%P<F'P>6MI=&4@<')O8FQE;>`N(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N
M86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(").=7)O9'EK:71E('-A=F\@=F%R
M=&]T;VIO('9A<F3@(&)E:2!S;&%P=&'^;V3A(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)0<F'P
M;VUE('!E<G-K86ET>71I(/#A('1E:W-TX"X@2OMS(%!2259!3$]412!S=71I
M:W1I('-U('/@;'EG;VUI<RP@:F5I("(*(FYO<FET92!N875D;W1I<R!S:7-T
M96UA+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z(@IM<V=S='(@(L%V97-K:71E(&YA=6K@(&MA=&5G;W)I:F]S('!A
M=F%D:6YI;>`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T
M<B`B3&5N:VEJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I
M9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:V%I(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B0F%L
M<V%V:6UA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S
M='(@(E!O<G1U9V%L:6IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E!A=F5I:W-LZVQI;R!P;WII8VEJ
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@
M(DQE;G1E;.MS('!O>FEC:6IA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("))\'-A=6=O=&D@\&EA
M;64@:V%T86QO9V4@*&YE9V%L:6]J82!)34%0*2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS
M*3H@(@IM<V=S='(@(DMR:71U;&EA:2!P87-K+B`E<R!V86QA;F3@*&%S*3H@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B4')E9G-?;&1A<#H@;F5R87-T87,@<F5I:V%L:6YG87,@3$1!4"!M;V1U
M;&ES+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS
M,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!N97)A
M<W1A<R!R96EK86QI;F=A<R!S97-I:O@@;6]D=6QI<RXB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B4VSK
M9VES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S
M=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(E-LZV=I<R!J^W)O<R!L>6=Y
M:F4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G
M:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B4VSK9VES.B`B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4')E=FEE=R(*;7-G<W1R(")097+^:?MR82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM
M<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(E!E<OYI^W+K=&D@<&%V96EK<VSK;.$@;F%U:F%M92!L86YG92(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(D%N:W-T97-N:2!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@
M9&]C=6UE;G0B"FUS9W-T<B`B071S<&%U<V1I;G1I(&1O:W5M96YTX"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I
M=F%T92!+97DB"FUS9W-T<B`B4VQA<'1A<VES(')A:W1A<R(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB
M"FUS9W-T<B`B4')O8FQE;6$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ
M,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O8FQE
M;6]S(&%P<F'P>6UA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE:W1A:2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS
M9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")0<F'P>6UA<R!T96MS='5I(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(E9I9?!A<VES(')A:W1A<R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(*;7-G<W1R(")6:67P;VIO(')A:W1O(&%L9V]R:71M
M87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`HC
M+"!F=7IZ>0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(E9I9?!A
M<VES(')A:W1A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5FEE\&]J;R]S;&%P=&]J;R!R
M86MT^"!P;W)A(&YE<W5G96YE<G5O=&$N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I:V%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87)A<R(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B4V%K
M:6YY<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!F=7IZ>0IM
M<V=I9"`B475O=&$B"FUS9W-T<B`B2V%T87)A<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@
M(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302!V:67P87-I
M<R!R86MT87,@*"5D(&)I=&%I*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(G4F%D
M:6\G('!A<VER:6YK:6UA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(DQI971U<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS
M9VED(")286EN($5A<FQY(@IM<V=S='(@(DQI971U<R!R>71E(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A
M:6X@3&%T92(*;7-G<W1R("),:65T=7,@=F%K87)E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO
M=V5R(@IM<V=S='(@(DQI^W1I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0W"B,L(&9U>GIY"FUS9VED(")286EN(&%N9"!3
M;F]W(@IM<V=S='(@(DQI971U<R]3;FEE9V%S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)A
M:6X@=&\@4VYO=R(*;7-G<W1R("),:65T=7,O4VYI96=A<R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G
M<W1R(")!='-I=&EK=&ENZR!F<F%ZZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B4V%N='EK:7,B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I
M9"`B4F5A9"(*;7-G<W1R(")3:V%I='ET:2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S
M(@IM<V=S='(@(E!E<G-K86ET>71I(&QA:?!K86DB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92XB"FUS9W-T<B`B5&EK<F%I(&GP=')I;G1I("5S/R!'<F'^:6YT:2!A
M=&=A;"!N96)E9V%LZW-I=&4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(E1I:W)A:2!I\'1R:6YT:2!V87)T;W1O
M:F\@)7,@9'5O;65N:7,_($=R8?YI;G1I(&%T9V%L(&YE8F5G86SK<VET92XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T
M"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")086MA
M<G1O=&D@86YK<W1E<V[A('9E:6MS;>`B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F
M<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ
M"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T
M<B`B071N875J:6YT:2!K86ER:6]J;R!M96YI=2!E;&5M96YT=7,Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T
M86P@5FEE=SHB"FUS9W-T<B`B071N875J:6YT:2!P;W)T86QO('9A:7IDX#HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C,U"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(E/@<GGP:?@@;F%R\'EK;.LB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`B4VMA:71Y
M=&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K
M<R(*;7-G<W1R(")087-T86)O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(DYU=&]LYB!S
M97)V97)I86DB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R(").=71O;.9S(%523"`H:'1T<#HO+W=W=RYP879Y>F1Y
M<RYC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM
M<V=I9"`B4F5M;W9E(@IM<V=S='(@(DGP=')I;G1I(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS
M9W-T<B`B4&'P86QI;G1I(&)L;VO@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*
M;7-G<W1R(")086YA:6MI;G1I('-T=6QP96SA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O
M<FUA='1I;F<B"FUS9W-T<B`B4&%N86EK:6YT:2!F;W)M871A=FEMX"(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@
M<&%I<B(*;7-G<W1R("))\'1R:6YT:2!P;W+@(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(DGP=')I
M;G1I(&%T;F%U:FEN:6UO('-K<FEP=.`@:?`@<V5R=F5R:6\@;&%I:VEN;VIO
M(&MA=&%L;V=O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R
M(")08?!A;&EN=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@
M9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B4&'P86QI;G1I(/#A(&5L96UE
M;G3@(&GP(&1O:W5M96YT;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(DGP=')I
M;G1I('9A<G1O=&]JX"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B
M"FUS9W-T<B`B5F%R=&]T;VIO('1R>6YI;6%S.B`E<R(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M(").96=A;&EU(&%T<V%K>71I(.$@=?YK;&%U<^`N($ML86ED;W,@:V]D87,Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z
M>GD*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N
M9"XB"FUS9W-T<B`B3F5G86QI=2!I\'-A=6=O=&D@;G5S:?AS=&\@9F%I;&\N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E!A<F%M971R87,@)R5S)R!N96YU<F]D>71A
M<R`E<R!K;VYF:6?[<F%C:6IO:F4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E!A<F%M971R87,@
M)R5S)R!N96YU<F]D>71A<R!61E,@:V]N9FEG^W)A8VEJ;VIE+B(*"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&%R86UE=')A<R`G)7,G(&YE;G5R;V1Y
M=&%S(&MO;F9I9_MR86-I:F]J92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*
M;7-G<W1R("))\"!N875J;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")086ME:7-T
M:2!S;&%P=&'^;V3A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4VQA<'1A
M_F]D_FEO(&ME:71I;6%S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`HC
M+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(E!A
M<VMU=&EN:7,@:V5T=FER=&ES(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q
M(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*
M;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5Z=6QT871A:2(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B1W+A
M_G1I(.$@;G5S=&%T>6UU<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*
M;7-G<W1R(")086ME:7-T:2!S;&%P=&'^;V3A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")296K[;FEJ82(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM
M<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B071S=&%T>71I
M(&MO;F9I9_MR86-I:N`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R
M"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B2%1-
M3"!R961A:W1O<FEA=7,@;G5S=&%T>6UA:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")-X7-LZW,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(D1E\&ENZVIE(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM
M<V=S='(@(D1E\&EN:6]J:2!A;G1R8?!TZR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")$
M9?!I;FEO<VEO<R!R96EK\&WK<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(E]%:6QU=.MS(&YU<W1A='EM86DN+BXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS
M9VED(")2;VQE(@IM<V=S='(@(E)O;.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")2;VUA;FEA(@IM<V=S='(@(E)U;75N:6IA(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X
M,"(*;7-G<W1R(")087-U:W1I(#$X,"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM
M<V=S='(@(E!A<W5K=&D@:V%I<NMN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM
M<V=S='(@(E!A<W5K=&D@9&7P:6[K;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P
M97)T:65S(@IM<V=S='(@(D5I;'5TZW,@;G5S=&%T>6UA:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G
M:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(D5I;'5TZW,@;G5S=&%T>6UA
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")%:6QU=.MS.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G
M:60@(E)U;&5S(@IM<V=S='(@(E-K:7)T=6MA:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B
M"FUS9W-T<B`B4VMI<G1U:V%I('1A<G`@=FES^"!E:6QUZ&GX(&ER('-T=6QP
M96QI^"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M8V]L=6UN<R!O;FQY(@IM<V=S='(@(E-K:7)T=6MA:2!T:6L@=&%R<"!S='5L
M<&5L:?@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>2(*;7-G<W1R(")3:VER='5K86D@=&EK('1A<G`@96EL=>AI
M^"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G
M<W1R(")6>6MD>71I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&
M961E<F%T:6]N(@IM<V=S='(@(E)U<VEJ;W,@1F5D97)A8VEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N9&$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12!P
M87)A\&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")3
M+TU)344@=?YK;V1U;W1A<R!L86GP:V%S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").ZW)A(%-!4TP@875T96YT:69I
M:V%C:6IO<R!M96-H86YI>FUO+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,#0*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3(/YI
M;G5TZW,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3
M:&5L;"(*;7-G<W1R(")344P@0TQ)(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O
M:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")005992T\B"@HC.B!L:6(O87!I
M+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4U]13"!#3$DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q
M"FUS9VED(")382(*;7-G<W1R("+09?!T+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("+0=F5N=&]J:2!(96QE;F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G
M<W1R(")386EN="!+:71S87,@:7(@3F5V:7-A<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3&EU8VEJ82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB
M"FUS9W-T<B`BT'9E;G1A<VES(%!E=')A<R!I<B!-:6=E;&]N87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<R(*;7-G<W1R(")386EN="!6:6YC96YT87,@:7(@1W)E;F%D:6YA:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*
M;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")486UE('!AZ&EA
M;64@;&%N9V4@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A
M(@IM<V=S='(@(E-A;6]A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA
M<FEN;R(*;7-G<W1R(")386X@36%R:6YA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G
M:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!I
M<B!0<FEN8VEPZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")086QY9&]V
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T
M<B`B4V%U9&\@07)A8FEJ82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("))\'-A=6=O=&DB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("))\'-A=6=O
M=&D@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(DGP<V%U9V]T:2`E
M<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@
M3W!T:6]N<R(*;7-G<W1R("))\'-A=6=O=&D@;G5S=&%T>6UU<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB2?!S
M875G;W1I('-U9V5N97)U;W1U<R!N=7-T871Y;75S(&MA:7`@4$A0('-K<FEP
M=.`@:OMS^"!S97)V97)I;R!L86EK:6YA:F%M92`B"B)K871A;&]G92XB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!N=7-T
M871Y;6%I(&GP<V%U9V]T:2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B071N875J:6YI
M;6\@<VMR:7!T87,@:?!S875G;W1A<R#A.B`G)7,G+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"B,L(&9U>GIY"FUS9VED
M(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B27IO;&EU;W1O<R!4+6%U
M9')O<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I
M96YC92(*;7-G<W1R(")-;VMS;&%S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("))9?!K;W1I(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B
M"FUS9W-T<B`B4&%I9?!K82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")087-I<FEN:VET
M92!F86EL=7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@T"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E!A<VER
M:6YK:71E(&1A=.`B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y
M.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E!A<VER
M:6YK:71E(&=R=7#F(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT
M,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E!A<VER:6YK
M:71E(&YA=6K@('-A=FEN:6YKX"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E!A
M<VER:6YK:71E('-E<G9E<N$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B
M4&%S:7)I;FMI=&4@=F%R=&]T;VK@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&%L;"(*;7-G<W1R(")087-I<FEN:VET92!F86EL=7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C8S"FUS9VED(")396QE8W0@86QL(&1A=&4@
M8V]M<&]N96YT<RXB"FUS9W-T<B`B4&%S:7)I;FMI=&4@=FES=7,@9&%T;W,@
M:V]M<&]N96YT=7,N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R
M(")087-I<FEN:VET92!O8FIE:W3@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&YO;F4B"FUS9W-T<B`B4&%S:7)I;FMI=&4@;F%U:N`@<V%V:6YI;FO@(@H*
M(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82XB"FUS9W-T<B`B(@HB2?`@_F5M:6%U(&5S86[H:?@@<^!R
M8?#X('!A<VER:6YK:71E(')E:6MI86UU<R!S:6UB;VQI=7,N(%;K;&EA=2!G
M86QI=&4@:G5O<R`B"B)N=6MO<&EJ=6]T:2#A(&QA:?!KX"XB"@HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CHB"FUS9W-T<B`B4&%S:7)I;FMI=&4@9&%T;W,@<VMI<G1U
M:^`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E!A<VER:6YK:71E(&1A
M=&]S(&9O<FUA=.`Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z(@IM<V=S='(@(E!A<VER:6YK:71E(&%P<F'PX"!K=7+A
M(&YO<FET92!R961A9W5O=&DZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(E!A<VER:6YK:71E(&QA:6MO('-K:7)T=6O@.B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R
M;6%T.B(*;7-G<W1R(")087-I<FEN:VET92!L86EK;R!F;W)M873@.B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")087-I<FEN:VET92!D=2!A
M=&ET:6YK86[H:75S(&QA=6MU<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S
M='(@(E!A<VER:6YK:71E('-P86QV^"!D97)I;N$N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.B(*;7-G<W1R(")087-I<FEN:VET92!N;W)I;>`@:V%L8N`Z
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@
M(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4VGX<W1I('!R;V)L96UO
M<R!P<F%N9?!I;>`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4VGX<W1I
M(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B
M4V5N96=A;&%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@
M(E-E;G-O<CH@(@IM<V=S='(@(E-E;G-O<FEU<SH@(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E
M<B(*;7-G<W1R(")2=6=SZVII<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B
M"FUS9W-T<B`B4V5R8FEJ82!I<B!-;VYT96YE9W)A<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M
M8F5R(@IM<V=S='(@(E-E<FEJ;W,@;G5M97)I<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D]R;R!SX&QY
M9_@@8FQO:V\@;NMR82XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@
M9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B5&5I<VGX(&%D
M;6EN:7-T<F%V:6UA<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D
M+B(*;7-G<W1R(")397-I:F]S($E$('!A<VEB86EGZRXB"@HC.B!L:6(O87!I
M+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E]4
M96ESZW,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED
M(")3970B"FUS9W-T<B`B4FEN:VEN>7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS
M9W-T<B`B(@HB3G5S=&%T>6UA:2!L96ED_FEA;G1Y<R!*=6US('!A<VEK96ES
M=&D@<VQA<'1A_F]DX2P@:F5I9W4@:N$@:V%D82!N;W)S("(*(G!A;6ER\&ET
M92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B3G5T;VQU<VGX('-E<G9E<FGX+"!K
M=7)I=6]S(&YO<FET92!M871Y=&D@:?`@<&]R=&%L;RP@;G5S=&%T>6UA:2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`B2V%L8F]S+"!L86EK;R!Z;VYO<R!I<B!D871O<R!N=7-T
M871Y;6%I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B
M(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO
M;G,N(@IM<V=S='(@(B(*(E!U<VQA<&EO('-P86QV^"P@871S:6YA=6II;FEM
M;R!D8?YN=6UO(&ER(&MI=/@@=F%I>F1A=FEM;R!P87)A;65T<O@@(@HB;G5S
M=&%T>6UA:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L(&9U
M>GIY"FUS9VED(")3971U<"(*;7-G<W1R(")?2V]N9FEG^W)A8VEJ82(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3
M971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(E)A<W1A
M<R!A=&YA=6II;FEM;R!S:W)I<'1A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(E-U(/!I=6\@<&%R
M86UE=')U(&=A;&EM;W,@:V5L:6]S('9I971O=NMS.B`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E:?!E;&%I(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B
M"FUS9W-T<B`B4&%R9'5O='5VZR(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(E1R
M=6UP87,@87!R8?!Y;6%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(D%R(&YA=61O=&D@:VQA=FEA=/MR;W,@;7EG
M='5K=7,@=F%L9'EM=6D_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B4F]D>71I(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F
M97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY
M(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)087)O
M9'ET:2!S:VER='5M=7,@=&%R<"!I\'-A=6=O=&\@:7(@:^`@=&EK('-U9V5N
M97)U;W1O(&MO;F9I9_MR86-I;FEO(&9A:6QO+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B4F]D>71I('!A<VMU=&EN:6\@<')I
M<VEJ=6YG:6UO(&QA:6O@/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`B4F]D>71I(&=A;&EM>6+F('!A;&EK=&D@;W)I9VEN86S@(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K
M97(B"FUS9W-T<B`B4F]D>71I('!A<FES:6YK:6W@(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/R(*;7-G<W1R(")2;V1Y=&D@;&5N=&5LZW,@;W!E<F%C:6KX
M(&UE;FEU/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B
M"FUS9W-T<B`B4F]D>71I("5S(&UE;FEU(&MA:7+K:F4_(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS
M9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(E)O9'ET:2!C96SK<R!N=7-T871Y;?@@;&%N9^`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(E)O9'ET:2!L96YT96SK<R!N=7-T871Y;?@@;&%N9^`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(")2;V1Y=&D@96EL=73K<R!N=7-T871Y;?@@;&%N9^`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(E)O9'ET:2!P879E:6MS;.ML:6\@;G5S=&%T>6WX(&QA;F?@(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U
M<&QO860B"FUS9W-T<B`B4F]D>71I(&9A:6SX(.%KZVQI;>`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO
M=V5R<R(*;7-G<W1R("),:?MT:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G
M<W1R("),:?MT:7,@<GET92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
M3&G[=&ES('9A:V%R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")3=6UA_FEN=&DB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E-U;6'^:6YT:2!A<F)A('!A<W1U;71I
M(&MA:6UY;FEN:75S(&)L;VMU<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I
M97)R82!,96]N92(*;7-G<W1R(")3:65R82!,96]NZR(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS
M9W-T<B`B4F5G:7-T<F%C:6IA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")087)A
M\&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*
M;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B4&%R8?!O(&%L
M9V]R:71M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS
M9W-T<B`B4VEN9V%P^W)A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B1'ED:7,B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI
M<"!-86EN=&5N86YC92(*;7-G<W1R(")0<F%L96ES=&D@<')O9FEL86MT:6O@
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO
M=F%K:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T
M<B`B4VQO=NMN:6IA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E-N;W<B"FUS9W-T<B`B4F]D
M>71I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(E#[9V$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@HC+"!F=7IZ>0IM
M<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(E#[9V$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PHC+"!F=7IZ>0IM<V=I
M9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(DQI^W1I<R!R>71E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*(RP@
M9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(DQI^W1I
M<R!V86MA<F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B
M4VYO=R!D97!T:#H@(@IM<V=S='(@(E-N:65G;R!G>6QI<SH@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@(@IM<V=S='(@(E-N:65G;R!K:65K:7,@=F%N9&5N:74Z("(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R
M(")3;VQO;6]N;R!S86QO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L
M:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")$86EN;W,@:7(@
M16ELZW)A\.AI86DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V
M"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")2^_!I879I
M;6\@='9A<FMO<R!P87-I<FEN:VEM87,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R
M8V4@861D<F5S<R(*;7-G<W1R(")3:75N=.MJ;R!A9')E<V%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(E!I973X($%F
M<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T
M:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B4&EE=/@@175R;W!O
M<R`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@
M(E!I973X($3^;W)D_FEJ;W,@:7(@4&EE=/@@4V%N9'9IZ&\@<V%L;W,B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R
M"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(E!I971I;NL@
M:&5M:7-F97)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',B"FUS9W-T<B`B5&%R<&%S('1A<G`@8V5L:?@B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")4
M87)P87,@=&%R<"!C96SK<R!T=7)I;FEO(&ER(&MR8?!T:6[K<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S
M='(@(E1A<G!A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")487)P
M86D@=&%R<"!C96QI^"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B5&%R<&%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN
M(@IM<V=S='(@(DES<&%N:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86UA<R(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@
M26YP=70B"FUS9W-T<B`B4W!E8VEF:6YI^"!S:6UB;VQI^"#A=&5R<&EM87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(E!E<G-K96QT:2!C
M96SF(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(E!E<G-K
M96QT:2!S='5L<&5LX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M(")097)S:V5L=&D@96EL=73F(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G1A<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(M!R:2!,86YK82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T
M87(N<&AP.C<T"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R=&%S
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R
M96LB"FUS9W-T<B`B4W1A<B!4<F5K)V%S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS
M9VED(")3=&%R="!Y96%R(@IM<V=S='(@(E!R861I;FEA:2!M971A:2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")286IO;F%S(&%R8F$@<')O=FEN
M8VEJ82(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R
M"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B0OMS96YA(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS
M9W-T<B`B4V%U9V]J:6UO(&9O<FUA=&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(D=A=';K<R!A9')E<V%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*
M;7-G<W1R(")5_F)R875K=&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("+>;V3^:?@@<^!R
M8?!A<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@
M(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(DYU:6UT
M:2!D;VUE;N`@;G5O(&%D<F5S;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=
M(@IM<V=S='(@(E-T:6QI=7,@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")3
M96MM+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B5S(&YE<F%S=&%S+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS
M9W-T<B`B5&5M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U
M8FUI="(*;7-G<W1R("+!=F5S=&DB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T
M;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM
M<V=S='(@(B(*(E9A<G1O=&]J87,@)R5S)R!S=6MU<G1A<R!S:7-T96UO:F4N
M($MO;"!J:7,@;F5P871V:7)T:6YT87,L('!R:7-I:G5N9W1I("(*(FYE9V%L
MZW-I=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(DEN9&5K<V%S(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS
M9VED(")3=6-C97-S(@IM<V=S='(@(E/K:VUI;F=A(@H*(SH@861M:6XO=7-E
M<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S
M)R!SZVMM:6YG86D@<W5K=7)T87,@<VES=&5M;VIE+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M+B(*;7-G<W1R(")687)T;W1O:F\@)R5S)R!D=6]M96YY<R!SZVMM
M:6YG86D@:?!T<FEN=&D@:?`@<VES=&5M;W,N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N
M(@IM<V=S='(@(B<E<R<@<^MK;6EN9V%I(&GP=')I;G1A+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B)R5S)R!SZVMM:6YG86D@:?!T<FEN=&%S(&GP('-I<W1E;6]S+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N(@IM<V=S='(@(B(*(DMO;F9I9_MR86-I:F$@871S=&%T>71A('/K
M:VUI;F=A:2X@4&5R:W)A=6MI=&4@<'5S;&%PX2P@:V%D('!A;6%T>71U;>MT
M92`B"B)P86ME:71U;75S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU
M.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")!='-A
M<F=I;NL@:V]N9FEG^W)A8VEJ;W,@:V]P:6IA('/K:VUI;F=A:2!I\'-A=6=O
M=&$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")!='-A<F=I;NL@
M:V]N9FEG^W)A8VEJ;W,@:V]P:6IA('/K:VUI;F=A:2!I\'-A=6=O=&$@X2`E
M<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R
M("(G)7,G('/K:VUI;F=A:2!A=&YA=6II;G1A<RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T
M<B`B)R5S)R!SZVMM:6YG86D@=?YR8?!Y=&%S+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3
M=6UM87)Y(@IM<V=S='(@(E1U<FEN>7,B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E-A=6SK=&5K:7,B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B
M"FUS9W-T<B`B4V%U;.ML>6=I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R(")3875L
MZW1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I
M9"`B4W5N<FES92(*;7-G<W1R(")3875LZW1E:VES(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED
M(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")3875LZW1E:VES+U-A=6SK;'ED
M:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`B4V%U;.MT96MI<SH@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S
M='(@(E-A=6SK;'EG:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")3875LZVQY9VES.B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S
M"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("),86EP<VYI<R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS
M9W-T<B`B07!T87)N879I;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R
M:6YA;64B"FUS9W-T<B`B4W5R:6YA;6%S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B
M4&%V87)DZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*
M86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F1A<R!I<B!$_F%N;6%I;F%S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-V87II
M;&%N9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@
M(M!V961I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS
M9W-T<B`BT'9E:6-A<FEJ82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S
M='(@(DYE=')I;G1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM
M<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C
M:"!T97)M<R(*;7-G<W1R(")3:6YT86MSZW,@:VQA:61A('!A:67P:V]S(&MR
M:71E<FEJ=6IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@
M4F5P=6)L:6,B"FUS9W-T<B`B4VER:6IO<R!!<F%B^"!297-P=6)L:6MA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B5"UA=61R82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N
M9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B5"UA
M=61R;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B
M3&G[=&ES(')Y=&4B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")44U8@9F%I;&%S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM
M<V=S='(@(DQE;G1E;.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S
M(@IM<V=S='(@(DQE;G1E;.MS(&YU<W1A='EM86DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"B,L(&9U>GIY"FUS9VED
M(")486)L92!3970B"FUS9W-T<B`B3&5N=&5LZR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A
M8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B3&5N=&5LZW,@;G5S=&%T>6UA:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")4
M86EV86YA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@
M(E1A:79A;F%S+"!+:6YI:F]S('!R;W9I;F-I:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9/YI:VES=&%N87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(DIU;F=T:6[K(%1A;GIA;FEJ;W,@4F5S<'5B;&EK82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*
M;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B5&%I:VEN>7,Z(@H*(SH@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3@W"FUS9VED(")487-K<R(*;7-G<W1R(")$87)B86DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE
M($YU;6)E<B(*;7-G<W1R(")496QE9F]N;R!N=6UE<FES(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@
M(@IM<V=S='(@(E1E;7`N('!A<VLN('9A;&%N9.`Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")4
M96UP97)A=/MR82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R873[<F$Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E
M<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O
M5&5M<&QA=&4N<&AP.C8X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F5R87-T87,@
M)R5S)R#P86)L;VYA<RXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM
M<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`BT&%B;&]N
M^"!A9&UI;FES=')A=FEM87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E
M>'0B"FUS9W-T<B`B5&5K<W1A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")4:6L@=&5K<W1A<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B3'EG:75O=&D@=&5K
M<W3@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")496MS=&\@=FER\'5J92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*
M;7-G:60@(E1H(@IM<V=S='(@(DME='8N(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1A:6QA
M;F1I971I\&MA("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H
M86EL86YD(@IM<V=S='(@(E1A:6QA;F1A<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@
M<WES=&5M+B(*;7-G<W1R(")!Z&G[(&MA9"!N875D;VIA=.MS('-I<W1E;6$N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D[K
M<F$@1E10(&UO9'5L:6\N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G
M<W1R(")(;W)D92]+;VQA8B!I;G1E9W)A8VEJ;W,@=F%R:6ML:75K87,@;F5P
M86QA:6MO(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O
M;VLN<&AP.C$R.3(*(RP@9G5Z>GD*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L
M9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DYE9V%L:74@:?!S875G
M;W1I(&YU<VGX<W1O(&9A:6QO+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(").97!A=GEK;R!U_FMR875T
M:2!-86EN=&5N86YC93HZ(&ML87/K<R(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(").=7-T871Y;?@@;&%N9V%S
M('7^9&%R>71A<RX@2?!E:6YU+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(DIE:6=U
M(&YO<FET92!N875D;W1I(&YU<W1A='EM=7,L('!A<')A\'EK:71E(&MA9"!A
M9&UI;FES=')A=&]R:75S("(*(G-U:V]N9FEG^W)U;W3X('!A<W1O=FG@(&1U
M;VUE;O@@8F%ZYB!N=7-T871Y;6%M<R!S875G;W1I+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@
M(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(E1I:R!A<&%T:6[K:F4@
M<'5SZVIE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W
M87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD
M(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B3F7A<F'PZW1E(&-O;G1A
M:W1O($E$(&YU;65R:6\@87)B82!J:7,@;F5R87-T87,@9'5O;65N^"!B87KK
M:F4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT87,@<^MK
M;6EN9V%I(.%T<F%U:W1A<R#A($K[<_@@861R97/X(&MN>6=E;.8N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B3F]RZV1A
M;6D@<&%T:6MR:6YT:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!A='-K:7+@
M(%!'4"!P87)A\&\@8FQO:^`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T
M<B`B3F7A<F'PZW1E(&1I<W1R:6)U8VEJ;W,@<^!R8?!O($E$(&%R8F$@:FES
M(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(DYE
MX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P;RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@HB4$=0('7^:V]D879I;6\@9V%L:6UY8NL@<F5I:V%L875J82!S875G
M875S('!R:7-I:G5N9VEM;RX@0F%N9'EK:71E(')A\'ET:2`B"B)H='1P<SHO
M+R!A9')E<V\@<')A9/YI;VIE+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RXB"FUS9W-T<B`B1F%I;&%S("5S('!R:79A;&\@='5RZW1I
M("5S('!A<F%M971RX"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+B(*;7-G<W1R(")&86EL87,@)7,@<')I=F%L;R!T=7+K=&D@
M:V%I(&MU<FEU;W,@)7,@<&%R86UE=')U<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")&86EL87,@;F5G86QI(&+[
M=&D@;G5K;W!I:G5O=&%S(&%N="!S87;F<RXB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R(")&86EL92!NZW)A(&1U;VUE;O@N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE
M(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R
M9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B4D9#.#@R(&QA:?!K;R!A;G1R8?!T
MZW,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+B(*;7-G<W1R("(B"B)*96EG=2!D:7)B871E($EN=&5R;F5T($5X
M<&QO<F5R(&YA<O!Y:VQE+"!P:6QN865K<F%N:7,@<F5D86MT;W)I875S(')E
M_FEM87,@(@HB9V%L:2!S=6ME;'1I('!R;V)L96WX+"!DZVP@\&EO<R!N87+P
M>6MLZW,@:VQA:63X+B!'86QI=&4@;F5M871Y=&D@:V%I(&MU<FGX("(*(G)E
M9&%K=&]R:6%U<R!E;&5M96YT^"X@2F5I9W4@;F%U9&]J871E(%=I;F1O=W,@
M.7@@3U,@9W)E:>AI875S:6%I(&K[<_@@(@HB:V]M<&EU=&5R:7,@<&%P<F'P
MZ&EA=7-I86D@;G5L=?`@<&%S:V5L8F1A;6%S(&%P:64@<&%G<FEN9&ENYB!K
M;&%I9.`N7%QN(@HB7%QN2OMS(&)U=F]T92!P97)S<.MT87,N($IE:6=U('9I
M<W1I96L@;F]R:71E(&GP8F%N9'ET:2!P:6QN865K<F%NX2!R9?YI;>`@(@HB
M<W!A=7-K:71E($]++B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(D%P<F'P87,@7"(E<UPB(&GP=')I;G1A<RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R
M(")4:6L@:V%I<NMJ92!P=7/K:F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@
M1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ
M(&-L87-S+B(*;7-G<W1R(")#<GEP=%]P<7`Z.B!K;&%S96D@<F5I:VEA(&YU
M<F]D>71I(&MU<B!Y<F$@1VYU4$<@9F%I;&%I+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E
M<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N
M=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T
M;V]D+B(*;7-G<W1R("(B"B),86GP:V%S(&GP<VGX<W1A<R`E<R!A9')E<V%T
M=6D@)7,@=&5M82!<(B5S7"(@8G5V;R!P87)O9'ET87,N7&XB"B)48>AI874@
M=&%I(&YE9V%R86YT=6]J82!K860@;&%I\&MA<R!B=79O('!E<G-K86ET>71A
M<R!A<F)A('-U<')A<W1A<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O
M('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B4&%V861I;FEM87,@:W5RX2!N
M875D;W-I=&4@;G5O<F]D;VIE(.$@;&%I\&MO(')A\'EM;R!P=7-L87#A(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY"FUS
M9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM
M<V=S='(@(M!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!K;&%S96D@<F5I:V%L:6YG87,@3W!E;E-33"!M;V1U;&ES+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B).96=A;&EU(&GP<V%U9V]T:2!N
M=7-T871Y;6\@7"(E<UPB+"!N97,@9'5O;65N^"!D>61I<R!V:7+P>6IA(&QE
M:7-T:6[@(')I8N`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D
M96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R
M:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O
M=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI
M9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(E!R;V=R86UA+"!S:VER
M=&$@<&5R_FG[<NMT:2#PX2!D=6]M96[X('1I<.`@*"5S*2P@;F5R87-T82!S
M:7-T96UO:F4N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T
M"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(E1I:R!K86ERZVIE(&ER
M(&1E\&ENZVIE('!U<^MS92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD
M('-I9&4@;VYL>2(*;7-G<W1R(")4:6L@9&7P:6[K:F4@<'5SZVIE(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P
M87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(E-E<G9E<FES(%PB)7-<(B!I\'1R:6YT87,N(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S
M='(@(E-E<G9E<FES(%PB)7-<(B!I\'-A=6=O=&%S+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(B5S(')E
M9VES=')A8VEJ;W,@<')A\'EM87,@:?!T<FEN=&%S+B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I
M9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DYU<F]D>71A(&5I
M;'5TZR!N965G>FES='5O:F$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HQ-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP
M;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DYU
M<F]D>71A(&5I;'5TZR!N965G>FES='5O:F$N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@
M9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>2(*;7-G<W1R(")4:6L@=FER\'5T:6[K:F4@:7(@87!A=&ENZVIE('!U<^MS
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E1I
M:R!A<&%T:6[K:F4@<'5SZVIE(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC
M92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B3G5S:?AS=&D@9'5O;65N
M>7,@<')A<F%S=&DN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP
M.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@
M(DYE9V%L:74@:?!S875G;W1I(&YU<VGX<W1O(&9A:6QO+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q
M-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M5V5A=&AE<BYC;VT@8FQO:V\@;NMR82XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F5R87-T87,@
M)R5S)R#P86)L;VYA<RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+B(*;7-G<W1R(").=7-T871Y;?@@;NMR82XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")$
M86QI^"P@:W5R:6%S(&=A;&EM82!R;V1Y=&D@;&%I\&MO('1E:W-T92P@;NMR
M82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B
M"B+0:6%M92!L875K92#A=F5S=&$@<&5R(&1A=6<@<VEM8F]L:?@N($K[<R#A
M=F5DZW1E("5S+"!O(&UA:W-I;6%L=7,@<VMA:>AI=7,@(@HB+2`E<R!S:6UB
M;VQI86DN(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(E-U
M:W5R=&D@)R5S)R!N97!A=GEK;SH@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@=F%R=&]T;VIO
M("<E<R<@9'5O;65N^"!I\"!S:7-T96UO<SH@(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("))\'1R:6YT:2`G)7,G(&YE<&%V>6MO.B`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")!
M=&YA=6II;G1I("<E<R<@;F5P879Y:V\Z("5S(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"XB"FUS9W-T<B`B4')O8FQE;6]S('-U(&9A:6SX('-I
M=6YT:6UU.B`E<R!N96YU<VGX<W1A<RXB"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB3G5S:?AS=&D@9F%I;&\@;F5P879Y
M:V\N($9A:6QA<R`E<R!Y<F$@9&ED97-N:7,@;F5G=2!L96ED_FEA;6%S(&1Y
M9&ES("@E9"`B"B)B86ET86DI+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R(").=7-I^'-T:2!F
M86EL;R!N97!A=GEK;RX@1F%I;&%S("5S('1I:R!D86QI;F%I(&YU<VGX<W1A
M<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R="(*;7-G<W1R(").96=A;&EU('!A<F]D>71I(/!I;W,@
M;&%I\&MO(&1A;&EE<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B2VQA:61A(.%K96QI86YT
M(&MO;G1A:W1I;FEU<R!D=6]M96YI<RXB"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")+;&%I9&$@X6ME
M;&EA;G0@:4-A;&5N9&%R(&1U;VUE;FES+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T
M:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A
M("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)+;&%I9&$@:V]N9FEG
M^W)A8VEJ;W,@9F]R;6]J92X@1W)E:>AI875S:6%I(&YE=?YP:6QDZW1E(')E
M:6MI86WX(&QA=6OX+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M2VQA:61A(&%T;&EE:V%N="!N=7)O9'ETX"!A9')E<_@@:VYY9V5LZW,@9G5N
M:V-I:N`N(%!A8F%N9'EK:71E(';K;&EA=2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(DML86ED82!A=&YA
M=6II;F%N="!K;VYT86MT:6YI=7,@9'5O;65N:7,N(%!A8F%N9'EK:71E(';K
M;&EA=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B2VQA:61A(&%T;F%U:FEN86YT(&1I<W1R:6)U8VEJ;W,@
M<^!R8?#@+B!086)A;F1Y:VET92!VZVQI874N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G
M<W1R("+0:7,@24U!4"!S97)V97)I<R!N97!A;&%I:V\@:V%T86QO9_@@9&%L
M:6II;6]S:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")!=')O9&\L(&MA9"!T86D@;F5T
M=F%R:VEN9V%S(%)!4B!A<F-H>79A<RXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")!=')O9&\L
M(&MA9"!T86D@;F5T=F%R:VEN9V%S(%I)4"!A<F-H>79A<RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T
M('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B071R
M;V1O+"!K860@=&%I(&YE=&5I<VEN9V%S(&MO<G1E;.MS(&YU;65R:7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"B+0:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!P
M97(@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2`B"B)P87-I
M;F%U9&]J86YT($A45%`@<')O=&]K;VQU(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"B+0:2!T=F%R:WEK;.L@;&5I9/YI
M82!S:?AS=&D@_FEN=71E<R!P97(@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M
M86EL+F-O;2D@(@HB<&%S:6YA=61O:F%N="!(5%10('!R;W1O:V]L=2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@HBT&D@='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I(/YI;G5T97,@<&5R('-M
M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI("(*(G!A<VEN875D;VIA
M;G0@2%144"!P<F]T;VMO;'4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G
M:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A
M9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I
M=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS
M9W-T<B`B(@HBT&D@='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I(/YI;G5T97,@
M4TU44"!P<F]T;VMO;'4@<&5R(%9O9&%F;VYE($ET86QI:F]S("(*(G9A<G1U
M<RP@=&EK(%9O9&%F;VYE(&YU;65R:6%M<RX@2FD@<F5I:V%L875J82!E;"X@
M<&'P=&\@861R97-O(%9O9&%F;VYE("(*(DET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB"FUS9W-T<B`BT&ES(&QA=6MA<R!P<FEV86QO;6%S+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`BT&EA;64@;&%U
M:V4@9V%L:2!B^W1I('1I:R!S=F5I:VEE:FD@<VMA:>AI86DN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T
M<B`BT&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S:V%IZ&EA:2!I<B!D=FET
M8?!K:6%I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N
M(@IM<V=S='(@(M!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@8?!T=6YT86EN
M:6%I('-K86GH:6%I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E
M('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*(M!I86UE
M(&QA=6ME('1U<FD@8OMT:2!K86)L96QI86ES(&%R8F$@=&%R<&%I<R!A='-K
M:7)T:2!S=F5I:VEE:FD@<VMA:>AI86DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BXB"FUS9W-T<B`BT&D@<F5I:_!MZR!T=7)I(&+[=&D@<VMA:>AI
M=7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B
M(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*
M;7-G<W1R("(B"B+0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-P86QV;W,@
M:V]D87,@4D="($AE>"!F;W)M871E+"!P879Y>F3^:75I("(*(B<C,3(S-$%&
M)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B
MT&D@9F]R;6$@:F%U(&%P9&]R;W1A+B(*"B,Z('1E;7!L871E<R]H96QP+V%B
M;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM
M<V=S='(@(E1A:2`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H
M92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@
M96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB
M5&%I($MO;&%B($=R;W5P=V%R92!O8FIE:W1A<RX@3F]RZV1A;6D@<&5R_FG[
M<NMT:2!O8FIE:W3@('!R:79A;&]T92!T=7+K=&D@(@HB96PN('!A\'1O(&ML
M:65N=.`L(&MU<FES('-U<')A;G3@(/#A(&9O<FUA=.`N(%1O:VGX(&5L+B!P
M8?!T;R!K;&EE;G3X('/@<F'PX"`B"B)G86QI=&4@<F%S=&D@87!S:6QA;FOF
M("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+B(*;7-G<W1R("+0:7,@;&%I\&MA<R!B=79O('!A<F'P>71A<R`E<R!K;V1U
M;W1E+B!*^W,@;F%U9&]J871E(&MI=&]K:>`@:V]D=6]TYBXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(M!I<R!S:V%IZ&EU
M<R!T=7)I(&+[=&D@9&ED97-N:7,@=?X@;G5LX2XB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G
M<W1R("+0:7,@<V5R=F5R:7,@;F5G86QI(&GP87)C:'EV=6]T:2!Z:7`@:7(@
M9WII<"!F86EL^"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+B(*;7-G<W1R("+0:2!S:7-T96UA(&1A8F%R(&GP:G5N9W1A
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(M!I(')E
M:6OP;>L@='5R:2!B^W1I('-K86GH:75S+B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`BT.$@
M;&%N9^`@<F5I:VEA(&%T:61A<FENZW1I(&GP(&YU<W1A='EM^"!L86YG;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS
M9VED(")4:'5N9&5R(@IM<V=S='(@(E!E<FO[;FEJ82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B
M0FEL:65T86DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G
M<W1R("),86EK87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V
M"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(DQA:6MO(&%P<VMA:71A
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA
M="(*;7-G<W1R("),86EK;R!F;W)M871A<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@
M(DQA:6MO('!A<VER:6YK:6UA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I
M;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R;&5S=.LB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")087)E:6=O<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B4&%V861I;FEM87,Z(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B2V%M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU
M;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#
M;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B
M(@HB3F]RZV1A;6D@<&%S:7)I;FMT:2!K96QE=.`@96QE;65N=/@L(&QA:6MY
M:VET92!#;VYT<F]L("A00RD@87)B82!#;VUM;F%D("(*(BA-86,I(&ML879I
M\.`L(&ER('!A<VER:6YK:71E('!E;&4N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`BT&EA;F1I
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B4F]D>71I
M($A434P@:V]DX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T
M<B`B5&]G87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S
M='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")2>71O:B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED
M(")4;W`B"FUS9W-T<B`B5FER\'5J92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O
M<"DB"FUS9W-T<B`B5FER\'5T:6YI86UE(&QA;F=E("A?=&]P*2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM
M<V=S='(@(E9E<G1I;6%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED
M860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9&%S(&ER(%1O8F%G87,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E
M(&]R(&9A;'-E(@IM<V=S='(@(E1A:7`@87)B82!N92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM
M<V=S='(@(D%N='(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*
M;7-G<W1R(")4=6YI<V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y
M(@IM<V=S='(@(E1U<FMI:F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R:VGP
M:V$@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE
M;FES=&%N(@IM<V=S='(@(E1U<FMMZVYI:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W-O
M(&ER($MA:6MO<V\@<V%L;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(L%V97-K
M:71E('-A=F\@<&%S:7)I;FMI;>`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R(")5
M+E8N(&EN9&5K<V%S.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED
M(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")3:W)I<'1O
M('!R:7-T871Y;6\@<W1A='5S;R!R87!O<G1O(%523"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB
M"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*
M;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(E5K<F%I;F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B3F5P879Y:V\@<&5R<VMA:71Y=&D@5D93(&MA=&%L;V=O
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I
M9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"XB"FUS9W-T<B`B3F5P879Y:V\@<')I9.MT:2!P87!I;&1O
M;6]S('9A<G1O=&]J;R!R96=I<W1R86-I:F]S(&EN9F]R;6%C:6IO<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@<&%K96ES=&D@5D93(&9A
M:6QO(%PB)7-<(B!T96ES:?@N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B3F5P879Y:V\@<&%K96ES
M=&D@=&5I<VGX(%9&4R!F86EL=6D@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F5P879Y:V\@<&5R96ET:2#A
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@871I9&%R>71I(%9&
M4R!F86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB
M)7,O)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I
M;&\@)7,O)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S
M-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS
M9W-T<B`B3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!344P@<V5R=F5R:6\N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(").97!A=GEK;R!P
M<FES:6IU;F=T:2!34TP@<F7^:6UU+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&
M4R!F:6QE+B(*;7-G<W1R(").97!A=GEK;R!N=6MO<&EJ=6]T:2!61E,@9F%I
M;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO
M9V\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U
M-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P879Y:V\@<W5K=7)T
M:2!61E,@:V%T86QO9V\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS
M9W-T<B`B3F5P879Y:V\@<W5K=7)T:2!61E,@9F%I;&\N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DYE<&%V
M>6MO('-U:W5R=&D@='7PZ&EO(%9&4R!F86EL;RXB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D
M96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DYE<&%V>6MO(&GP87)C:'EV=6]T
M:2!D=6]M96[X+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@7"(E
M<UPB+"!K871A;&]G87,@;F5T=?#H:6%S(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I("<E<R<Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@)7,L
M(&MA=&%L;V=A<R!N971U\.AI87,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2XB"FUS9W-T<B`B3F5P879Y:V\@<F5K=7)S:?!K86D@:?!T
M<FEN=&D@5D93(&MA=&%L;V=O+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(%9&4R!K871A;&]G
M;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").
M97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T86QO9V\Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").
M97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S
M='(@(DYE<&%V>6MO(&GP=')I;G1I(%9&4R!F86EL;RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@5D93(&9A:6QO(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M(@IM<V=S='(@(DYE<&%V>6MO(')E:W5R<VGP:V%I(&GP=')I;G1I(%9&4SH@
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@
M(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYE<&%V>6MO(&YU<W1A='ET:2!D86)A<G1I;FEO(&MA=&%L;V=O+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED
M(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S
M='(@(DYE<&%V>6MO(&=A=71I('-E<G1I9FEK871O(&%P<F'P>6UO(@H*(SH@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@
M(DYE<&%V>6MO('7^:W)A=71I("5S(&%P<F'P>6UO+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V
M-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"FUS9VED(")5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B3F5P879Y:V\@<&5R
M:V5L=&D@5D93(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A<GET:2!6
M1E,@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(").
M97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO(')A\'EM=6DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@
M(DYE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(").97!A=GEK;R!A
M=&ED87)Y=&D@<W5S<&%U<W1O(&%R8VAY=F\N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5P879Y
M:V\@X7)A\'ET:2!61E,@9F%I;&\@*&-O<'DH*2!K;&%I9&$I+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX-C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM
M<V=S='(@(DYE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("AC;W!Y*"D@:VQA
M:61A*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R
M96%D(&9I;&4Z("(*;7-G<W1R(").97!A=GEK;R!P97)V861I;G1I(%9&4R!F
M86EL;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G
M:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3F5P879Y:V\@<&5R<VMA:71Y=&D@=F9S<F]O="!K871A;&]G;RXB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DYE<&%V>6MO
M('!E<G9A9&EN=&D@)7,@X2`E<SH@=&]K<R!K871A;&]G87,@:F%U(&5G>FES
M='5O:F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@5D93(&MA=&%L;V=O+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S
M='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@5D93(&MA=&%L;V=O.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@
M<&5R=F%D:6YT:2!61E,@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@
M5D93(&9A:6QO("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@
M(DYE<&%V>6MO('!A;&5I<W1I("=M:VES;V9S)RXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(").97!A
M=GEK;R!I\'9E<G-T:2#P:6\@5V]R9"!D;VMU;65N=&\B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R#A<F'P>71I(%9&
M4R!F86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH
M*2!F86EL960I+B(*;7-G<W1R(").97!A=GEK;R#A<F'P>71I(%9&4R!F86EL
M;R`H8V]P>2@I(&ML86ED82DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DYE<&%V
M>6MO(.%R8?!Y=&D@5D93(&9A:6QO(&1U;VUE;O@N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@T,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R
M(").97!A=GEK;R#A<F'P>71I(%9&4R!F86EL;R`H8V]P>2@I(&ML86ED82DN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E!A8G)A=6MT:2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*
M;7-G<W1R(")!=/!A=6MT:2!P86ME:71I;75S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO
M=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B073P875K=&D@86YK<W1E<V[A('9E
M:6MS;>`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R(").971I:^MT82!S97)V97)I;R!K;&%I
M9&$Z("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(DYE=&EKZW1A('-E<G9E<FEO(&ML86ED83H@(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@
M(E5N9FEL960B"FUS9W-T<B`B3F5N=7)O9'ET82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B
M56YI:V]D87,@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@
M07)A8B!%;6ER871E<R(*;7-G<W1R(")*=6YG=&EN:6%I($%R86+X($5M>7)A
M=&%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G
M<W1R(")*=6YG=&ENZR!+87)A;'ES=.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S(@IM<V=S='(@(DIU;F=T:6[K<R!686QS=&EJ;W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B2G5N9W1I;FGX(%9A;'-T>6KX($%T
M;VME<V[K<R!S86QO<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G
M<W1R(")6:65N971A:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G
M:60@(E5N:VYO=VXB"FUS9W-T<B`B3F7^:6YO;6%S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(DYE
M_FEN;VUA<R!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I
M9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G
M<W1R(").9?YI;F]M87,@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"B,L(&9U>GIY
M"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").
M96YU<W1A='ET82!V:65T;W;K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R
M;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F7^:6YO;6%S('9A<G1O=&]J
M;R!V87)D87,@:7(O87)B82!S;&%P=&'^;V1I<RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@
M(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(E!A;F%I:VEN
M=&D@;G5O<F]DX"#P:6%M(&5L96UE;G1U:2(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D(@IM<V=S='(@
M(DYEX79A<F1I;G1A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"XB"FUS9W-T<B`B(@HB4V%U9W5M;R!S=6UE=&EM86ES(&YE<')I=FEL
M96=I:G5O=&D@<VMR:7!T86D@;F5G86QI(&%T;&EK=&D@4&5R:^ML:6UO+R(*
M(DMO<&EJ879I;6\OP6OK;&EM;R!P<F]G<F%M:?!K86DN($YO<NMD86UI('!E
M<OYI^W+K=&D@=&5C:&YI;F5S(&1E=&%L97,@(@HB;6]Z:6QL82YO<F<@=&EN
M:VQA<'EJ92P@:7(@<W7^:6YO=&D@:V%I<"!S:W)I<'1A;7,@;&5I<W1I('!R
M:65I=&D@<')I92`B"B)L86EK:6YO<VEO<R!S875G>6ML;W,L('!A<W!A=7-K
M:71E($]++B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(DYE
M;F%U9&]T:2!S<&%L=F]S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY
M,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G
M:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(")0;.MT:6YY<R!N
M97!A;&%I:V]M87,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B
M57!D871E(@IM<V=S='(@(D%T;F%U:FEN=&DB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T92`E<R(*;7-G<W1R(")!=&YA=6II;G1I("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`B071N875J:6YT:2!V87)T;W1O:N`B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B<E<R<@871N875J:6YT82XB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B071N875J:6YI;6\@<VMR:7!T
M87,@:?!T<FEN=&%S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I
M9"`B57!L;V%D(@IM<V=S='(@(DYU<VGX<W1I(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(E9I<VD@;6]D
M=6QI^"!A=&YA=6II;FEM;R!F86EL86D@X6ME;'1I(.$@<V5R=F5RX2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(D1I
M9/YI;W-I;W,@;&]T:6YI\&MO<R!R86EDZW,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5
M<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(D1I9&EE:FD@<F]MZVYI\&MI
M('-K86GH:6%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G
M<W1R(")5<G5G=F%J=7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@
M0W5R<F5N=#H@)7,B"FUS9W-T<B`B3F%U9&]T:2!D86)A<G1I;N8Z("5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B3F%U9&]T:2!34TPB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R
M(").875D;W1I(&IE:6=U('9A<G1O=&]J;R!V87)D87,O<VQA<'1A_F]D:7,@
M24U34"!S97)V97)I=6D@>7)A(&MI=&]K<RXB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM
M<V=S='(@(E9A<G1O=&]J86DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B5F%R=&]T;VIA
M<R`E<R!N96%U=&]R:7IU;W1A<R!P<FGK:FEM=6D@<')I92`E<RXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B5F%R=&]T;VKX(&%D;6EN:7-T<F%V:6UA<R(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO
M;G,B"FUS9W-T<B`B5F%R=&]T;VIO(&YU<W1A='EM86DB"@HC.B!S:6=N=7`N
M<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")687)T
M;W1O:O@@<F5G:7-T<F%C:6IA(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92XB"FUS9W-T<B`B5F%R=&]T;VKX(')E9VES=')A8VEJ82!I\&IU;F=T
M82XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"B,L(&9U>GIY"FUS
M9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B5S(&YE<F%S
M=&%S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM
M<V=S='(@(E9A<G1O=&]J;R!V87)D87,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(E9A
M<G1O=&]J;R!V87)D87,@)R5S)R!J874@96=Z:7-T=6]J82XB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*
M;7-G<W1R(")687)T;W1O:F\@=F%R9&%S.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B5F%R
M=&]T;VIO('9A<F1A<SH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B
M5F%R=&]T;VIA:2#P:6]J92!S:7-T96UO:F4Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM
M<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R(")5>F)E:VES=&%N87,B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R(")61E,@:V%T86QO9V%S(&YE96=Z:7-T=6]J82XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")686-A
M=&EO;B(*;7-G<W1R(")!=&]S=&]G;W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B`B"FUS9W-T<B`B4F%S=&]S('1E:7-I;F=O<R!V:65T;W;K<SH@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@
M(E9A;&ED:71Y(@IM<V=S='(@(D=A;&EO:FEM87,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@
M(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(E)E:6OP;>L@
M;6EN=73K;6ES(&YU;R!D86)A<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B4F5I:_!MZW,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G
M<W1R(")296EK\&WK<R!I\"!K=7)I^"!G86QI;6$@<&%S:7)I;FMT:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(DMI;G1A;G1I<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE<W5E;&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(E!A='9I<G1I;FEM87,@;F5B86EG=&%S("T@
M\&ES(&QA:?!K87,@<W5G861I;G1A<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")6
M97)S:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I
M9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E9E<G-I:O@@:V]N=')O;.LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("),>6=I=6]T
M:2!V97)T:6MA;&EA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T
M<B`B5F5R=&EK86QU<R!T87)P87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T
M<B`B5F5R=&EK86QU<SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(DQA8F%I
M(&1I9&5L:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G
M<W1R(")6:65T;F%M87,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM
M<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M:65T
M:?!K82`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(E!E<OYI^W+K=&D@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS
M"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E)O
M9'ET:2!I\&]R:6[A('!U<VQA<.$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A
M<R`E<R(*;7-G<W1R(")097+^:?MRZW1I(&MA:7`@)7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")"
M<FET^"!6:7)D_FEN:6IO<R!S86QO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DI!5B!6:7)D_FEN:6IO
M<R!S86QO<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6
M:7-I8FEL:71Y(@IM<V=S='(@(DUA=&]M=6UA<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G
M<W1R(")-871O;75M87,Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L:6IA('!E<B!33510
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")705).
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N(@IM<V=S='(@(D3+345324\A(2$@4$%465,@2=!44DE.2TE412!3
M2U))4%3`($G0("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED(")724X@=FEA($A45%`B"FUS
M9W-T<B`B<VUS,F5M86EL('!E<B!(5%10(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5F%L:7,@:7(@1G5T=6YA
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS
M9VED(")787)N:6YG(@IM<V=S='(@(D3K;65S:6\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G
M<W1R(")4<F7H+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")/<O@@<')O9VYO
M>NLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED
M(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B3W+X('!R;V=N
M;WKK('!A9V%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS
M9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5U=7
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B
M(%-I=&4B"FUS9W-T<B`B5U=7('!U<VQA<&ES(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM
M<V=S='(@(DMA<R!S879A:73F(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B4W9E:6MI(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@
M)7,B"FUS9W-T<B`B4W9E:6MI(&%T=GEKYB#A("5S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@
M(DQA8F%S+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")686MA<O@@*$E33RTX
M.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R(")686MA<O@@*$E33RTX.#4Y
M+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G
M<W1R(")686MA<O@@4V%C:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S
M:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B2V]KX2!M
M;V1U;.$@)7,@='5R:2!R;V1Y=&D@<&\@<')I<VEJ=6YG:6UO/R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")+;VMS('-K:7)T=6MO
M('-I;6)O;&ES/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W
M"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@
M(DMO:W,@:V%B=>AI^"!S:6UB;VQI<S\B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0HC+"!F=7IZ>0IM<V=I9"`B5VAE
M<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(D%U<W1R86QI:F$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G
M<W1R(")+=7)I;W,@9F%ZZW,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DA434P@<F5D86MT;W)I875S(&UO
M9'5L:?@@X6IU;F=I;6%S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@
M(E!L;W1I<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G
M:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R(")0;&]T:7,@0U-3(&UA
M=&%I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B5S(&MA
M:7)I;VIO(&UE;FEU('!L;W1I<R`H<&%K96ET:6UA:2!B=7,@;6%T>71I('!O
M(&MI=&\@<')I<VEJ=6YG:6UO*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A
M8FQE(@IM<V=S='(@(DQE;G1E;.MS('!L;W1I<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U
M;FET(@IM<V=S='(@(E!L;^AI;R!M871A<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS
M9W-T<B`B4&QO=&ES.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E=I;F0B"FUS9W-T<B`B
M5NMJ87,Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B3&EE
M='5S(')Y=&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED(")7
M:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E;K:F\@9W)E:71I<R!M87IG
M86ES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z
M(@IM<V=S='(@(E;K:F%S.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")6ZVIA<SH@(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T
M<B`B2?!M:6YT:7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV
M"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")086=E:61A=FEM
M86DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB
M"FUS9W-T<B`B1&%R8F%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B
M1&%R8F\@861R97-A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B1&%R
M8F\@=&5L969O;F%S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@
M)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")3:7-T96UA
M(&YE='5R:2!T96ES:?@@<W5K=7)T:2!61E,@9F%I;.`N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B
M6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U
M,#EV,R!P86=R:6YD:6YI86D@;G5S=&%T>6UA:2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R!I\'!LZW-T;R!R86MT;R!P
M86YA=61O:FEM87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M92(*;7-G<W1R(")8-3`Y=C,@86QT97)N871Y=G5S('9A<F1A<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@<F%K
M=&\@:61E;G1I9FEK871O<FEU<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G
M<W1R(")8-3`Y=C,@;6]D=6QI86DB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B65DB"FUS9W-T<B`B65DB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-34*;7-G:60@(EE965DB"FUS9W-T<B`B
M65E962(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O(2#^96WK
M;&%P:7,B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B2V%S;65T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B2F5M96YA<R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@
M(EEE<R(*;7-G<W1R(")486EP(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G
M<W1R(")486EP+"!A\"!S=71I;FMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4
M($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O
M(%=94TE764<N(@IM<V=S='(@(B(*(DK[<R!E<V%T92!414M35$E.24%-12!2
M1=Y)344N($YO<NMD86UI(&=RX?YT:2#A(%=94TE764<@<W!A=7-K:71E(%L\
M/ETN(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N
M=&EC871E9"XB"FUS9W-T<B`B2OMS(&YE<')I<VEJ=6YGYBXB"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N(@IM<V=S='(@(E-A=F\@=F%R9&4@;F5G86QI=&4@;F%U9&]T:2!S:6UB
M;VQI;R`G7%PG+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N
M;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("+!=F5D
MZW1E(&YE=&5I<VEN9^`@96PN('!A\'1O(&%D<F5SX"XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B3F5P<FEJ=6YGZW1E(&IO:VGX(&QA=6OX(&GP(.%K96QI86UO(&9A
M:6QO('!R:64@)7,@871I=&EN:V%M^"!L875K^"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D
M(&]U="XB"FUS9W-T<B`B2OMS(&%T<VEJ=6YGZW1E+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)4=7)I=&4@X79E<W1I('1E:7-I
M;F?@('1E;&5F;VYO(&YU;65RX2`H=&EK('-K86GH:75S(&ER("<K)RP@:F5I
M9W4@;F]R:71E("(*(FYU<F]D>71I('1A<G!T875T:6[A(&MO9.`I+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(L%V963K=&4@;F5T
M96ES:6YGX"!R96EK\&WF+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB3F]RZV1A
M;6D@;F%U9V]T:7,@<F5G:7-T<F%C:6IO<R!S:7-T96UA+"!T=7)I=&4@<W5K
M;VYF:6?[<G5O=&D@9'5O;65N^"`B"B)M963^:6\@<&]S:7-T96WF+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"B,L(&9U>GIY"FUS9VED
M(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B
M(@HB3F]RZV1A;6D@;F%U9V]T:7,@<F5G:7-T<F%C:6IO<R!S:7-T96UA+"!T
M=7)I=&4@<W5K;VYF:6?[<G5O=&D@9'5O;65N^"`B"B)M963^:6\@<&]S:7-T
M96WF+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS
M9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B4')I9?`@
M<VGX<V1A;6D@<')A;F7P:6W@+"!A<')A\'EK:71E('!R;V)L96W@+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G
M:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;R(*;7-G<W1R("+!<F'P>6MI=&4@;G5O<F]D;W,@55),(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B5'5R
M:71E('!A<VER:6YK=&D@<V5R=F5RX2P@:W5RX2!N;W)I=&4@:?!T<FEN=&DN
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(").=7)O9'EK
M:71E('9A<G1O=&]J;R!V87)DX"P@:W5R:6\@9'5O;65N:7,@=')I;F%T92XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(DYU<F]D>6MI=&4@
M=F%R=&]T;VIO('9A<F3@('1R>6YI;75I+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R
M(").=7)O9'EK:71E(&MU<FEA;6\@=F%R=&]T;VIO('9A<F3@+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(").=7)O9'EK:71E(&%T;F%U
M:FEN86UO('9A<G1O=&]J;R!V87)DX"XB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B3G5R;V1Y:VET
M92!V96EK<VW@+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A
M=&5G;W)Y(&YA;64N(@IM<V=S='(@(DK[<R!T=7)I=&4@X79E<W1I(&YA=6IO
M<R!K871E9V]R:6IO<R!P879A9&EN:6W@+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@
M;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B)7,@<V5S:6IA(&)A:6?K<VDN
M(%!R8?!O;64@<')I<VEJ=6YG=&D@:?`@;F%U:F\N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D
M<F5S<R(*;7-G<W1R(")*^W/X(&5L+B!P8?!T;R!A9')E<V%S.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D
M<F5S<SHB"FUS9W-T<B`B16PN('!A\'1O(&%D<F5S87,Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R
M;6%C:6IA(&%P:64@2G5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB3G5O("5S('-E<VEJ;W,@
M<')A9/YI;W,@:OMS^"!)4"!A9')E<V%S('!A<VEK96ETZRX@5'5R:71E('!R
M:7-I:G5N9W1I(&GP("(*(FYA=6IO+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B2OMS
M^"!V87)D87,O<&%V87)DZR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF
M('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@
M86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT
M:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)*^W/X('-I<W1E;6]S(&%U
M=&5N=&EF:6MA=FEM;R!P;W-I<W1E;>L@;F5P86QA:6MO('9A<G1O=&]J^"!K
M^W)I;6\L(&%R8F$@\&D@(@HB9V%L:6UY8NL@:?!J=6YG=&$@9.ML('1A;2!T
M:6MR^"!P<FEE_F%SZ&GX+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("(B"B)*^W/X(&%U=&5N=&EF:6MA=FEM;R!S:7-T96UA
M(&YE<&%L86EK;R!V87)T;W1O:O@@<^!R8?!O+"!A<F)A(/!I(&9U;FMC:6IA
M("(*(G7^9')A=7-T82!DZVP@=&%M('1I:W+X('!R:67^87/H:?@N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@HB3G5O("5S('-E<VEJ;W,@<')A9/YI;W,@:OMS^"!N87+P
M>6MLZW,@=&EP87,@<&%S:6ME:73K+B!4=7)I=&4@<')I<VEJ=6YG=&D@(@HB
M:?`@;F%U:F\N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB
M"FUS9W-T<B`B2OMS^"!N87+P>6MLZR!N97!A;&%I:V\@\&EO<R!G86QI;7EB
MZW,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*(RP@
M9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0
M("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)*^W/X(&YA<O!Y:VSK(&YE<&%L
M86EK;R#P:6\@<W!A=7-D:6YI;6\@;G5S=&%T>6UO+B!.;W+K9&%M:2!A='-P
M875S9&EN=&D@(@HB<W!A=7-K:71E($-O;G1R;VPO3W!T:6]N("L@4"XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")*^W/X(&QA:6MO(&IU;W-T83HB"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")*
M^W/X('-T86YD87)T:6YI<R!A<')A\&%S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS
M9W-T<B`B2OMS^"!S=&%N9&%R=&EN:7,@87!R8?!A<SHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C`Q"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS
M9W-T<B`B2OMS^"!V87)D87,O<&%V87)DZSHB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")*^W/X(&YU<W1A='EM86D@871N875J:6YT
M:2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M(@IM<V=S='(@(DK[<_@@;F%U:F%S("5S('-L87!T8?YO9&ES('ER83H@)7,B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T
M:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")*^W/X(&YU
M<W1A='EM86D@871N875J:6YT:2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+B(*;7-G<W1R(")*^W/X(&YU<W1A='EM86D@871N875J:6YT:2XB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")*^W/X('-L87!T
M8?YO9&ES('!A:V5I<W1A<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B
M"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB2OMS^"!S;&%P=&'^;V1I<R!P86ME
M:7-T87,N(%!A<VET:6MR:6YK:71E('-A=F\@<&'P=.`@:7(@<')I<VEJ=6YK
M:71E('-U("(*(FYA=6IU('-L87!T8?YO9/YI=2XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,S(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(DK[<_@@<VQA<'1A_F]D:7,@<&%K
M96ES=&%S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS
M9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")*^W/X(&YU=&]L
MYB!S97)V97)I86DZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G
M;W-L879I82(*;7-G<W1R(")*=6=O<VQA=FEJ82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA
M:7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):
M86UB:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T
M<B`B6FEM8F%B=NLB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G
M:60@(EII<'!Y(@IM<V=S='(@(D5N97)G:6YG;W,B"@HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED
M(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6U!A<VSK<'1I(&-I='5O
M:F%MX"!T96MS=.!=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G
M:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U!R;V)L96UO<R!P<F%N
M9?!I;6%S72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS
M+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM2
M;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*
M;7-G<W1R(");4F]D>71I(&-I='5O:F%MX"!T96MS=.`@+2`E<R!E:6QU=&5S
M72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF
M;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");96EL=73K
M("5S(&GP("5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T
M,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B7U9A;&1Y;6%S(@H*(SH@;&EB+V%P:2YP:'`Z
M,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H
M<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1'5O;65N^"!M961I
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B7TGP=')I
M;G1I(&5I;'5TYB(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P
M<R(*;7-G<W1R(")'7W)U<.MS(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B4&%?9V%L8F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E]0879E:6MS;.ML:6\@;G5S=&%T>6UA:2XN+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T
M<B`B4')I<VE?:G5N9W1I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B071S:5]J=6YG
M=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?
M2V5I<W1I(&YU;W)O9.`N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-
M96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E].=7-T871Y
M;6%I(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B7U1E:7/K<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK
M+BXN(@IM<V=S='(@(E])\'1R:6YT:2!N=6]R;V3@+BXN(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7TMO;F9I9_MR86-I
M:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(E],96YT96SK<R!N=7-T871Y;6%I+BXN(@H*(SH@;&EB+V%P:2YP:'`Z
M,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B5E]A<G1O=&]J86DB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0IM<V=I9"`B861D<F5S<R!B
M;V]K(@IM<V=S='(@(F%D<F5S^"!K;GEG96SK(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(F%D9')E
M<W-E92!U;FMN;W=N(@IM<V=S='(@(F%D<F5S^"!K;GEG96SK(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*;7-G:60@(F-A;&5N9&%R(@IM
M<V=S='(@(DMA;&5N9&]R:75S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B8V%L;2(*;7-G<W1R(")R86UU<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*
M;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B<W!A=7-K:71E(.AI82(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C
M;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@
M(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B)7,@;G5S=&%T>6UA:2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED
M(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D
M871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(B5S(&YE<F%S=&%S+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG
M(@IM<V=S='(@(FMR96YT82(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R(")F86EL87,B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(FYU;R`E<R`H
M)7,I("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M,`HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(L(&?[<VEA:2`E
M<R`E<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(F$Z(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*
M;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM
M<V=I9"`B:6UM961I871E(@IM<V=S='(@(G1U;VIA=2!P870B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM
M<V=I9"`B:6YL:6YE(@IM<V=S='(@(G!A<')A<W1I(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U
M="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")E:6QU=&5S72(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@
M)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B;6MI<V]F<R!K;&%I9&]S
M(&MO9&%S("5D(&)E9&%R86YT($E33RXB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`B=F%R9&%S(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(FYE<F5A;&EZ=6]T82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L
M96UE;G1E9"(*;7-G<W1R(")D87(@;F5R96%L:7IU;W1A(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T
M<B`B=?YR8?#X(&MN>6=E;.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S
M='(@(G!R;V-E;G1A:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*
M;7-G<W1R(")496ESZW,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B
M<&EK<V5L:6%I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(FMY;&$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@HC+"!F=7IZ>0IM<V=I9"`B<V5R
M=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")/<F\@<^!L>6?X(&)L;VMO(&[K
M<F$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO
M=R!D:69F97)E;F-E<R(*;7-G<W1R(")R;V1Y=&D@<VMI<G1U;75S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*
M;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@
M<&5R($A45%`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM
M<V=S='(@(G-T86)I;&DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED
M(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")D87)B
M^"!SX')A\&%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED
M(")T<GD@86=A:6XB"FUS9W-T<B`B2VEE:W9I96YO('!R:7-I:G5N9VEM;R!M
M971U(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;2(*;7-G<W1R(")S;&%P=&'^;V3A('1U<FET92#A<F'P
M>71I(&1U(&MA<G1U<R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@
M(G5N:69I:W5O=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP
M.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(F1A;&ES(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS
M9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")V87)T;W1O:F\@<&%S:7)I;FMI
M;6%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM
M<V=S='(@(G`Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H``"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O;'9?3%8N<&\`````````````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8Q,3,U,@`Q
M,#0Q-S,V,S`P,@`P,38T,34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!,871V:6%N('1R86YS;&%T:6]N(&9O<B!(;W)D
M92X*(R!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^+"`R,#`R
M+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D92`R+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q
M-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R+3$Q+3(X(#$T
M.C`P*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2V%S<&%R<R!+87!E;FEE
M:W,@/&MA<W!A<G-`<F-C+FQV/EQN(@HB3&%N9W5A9V4M5&5A;3H@3&%T=FEA
M;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N
M,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U
M-UQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y
M<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY
M97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H
M;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*
M;7-G<W1R("(G)7,G(&YA=B!N;W+B9.YT<R!(;W)D92!R9>QI<W1RXB(*"B,Z
M(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;B(*;7-G<W1R("(E<R!5>G1U<N?P86YA<R!O<&5RXF-I:F%S("T@
M87!S=&EP<FENXFIU;7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N
M(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E
M<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")!='KN;>=J:65T(&1A<F+N
M8F%S+"!K;R!VYVQA=&EE<R!V96EK="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I
M<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@
M(DMA=')A<R`U(&UI;OMT97,B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B6W)I;F1A("5S(&YO("5S72(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")+;VYT86MT:2(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N
M9.)R<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@
M8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO
M=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S
M96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I
M;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(;W5R
M($9O<FUA="(*;7-G<W1R(")*^W-U(&EN9F]R;>)C:6IA(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(;W5R($9O<FUA
M="(*;7-G<W1R(")*^W-U(&EN9F]R;>)C:6IA(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('-T
M=6YD87,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED
M("(\4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB/DER(&YO=&EK=7-I(&MR:71I<VMA
M(&OO^VUE.CPO8CXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B
M"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S
M,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B
M"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G
M:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]0
M32(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S
M;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*
M(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B
M2OMS=2!I;F9O<FWB8VEJ82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")0
M87)O;&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O
M=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B061D(@IM<V=S='(@(D%D<F5S92(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@
M1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED
M(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B061D($AE<F4Z
M(@IM<V=S='(@(D%D<F5S92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!0
M97)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@
M;F5W(&UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B4&EE=FEE;F]T
M('#B<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S
M(&)O;VLZ(@IM<V=S='(@(DMO;G1A:W1I(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@
M=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(DMO;G1A:W1I(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S
M='(@(E!I979I96YO="!PXG)I(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")!9')E<V4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`B2V]N=&%K=&DB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G
M:60@(D%D<R(*;7-G<W1R(")!9')E<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS
M9VED(")!;&)A;FEA(@IM<V=S='(@(D%I>G-TXFIVXG)D<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*(RP@9G5Z>GD*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06EZ<W3B:G;B
M<F1S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06EZ<W3B:G;B<F1S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`B06EZ<W3B:G;B<F1S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@
M(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U
M>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")*
M^W-U(&4M<&%S=&$@861R97-E.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B3F]RXF3N=&$@;F5D97+N9V$@=N=R
M=.YB82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@
M9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM
M<V=S='(@(CQB/DER(&YO=&EK=7-I(&MR:71I<VMA(&OO^VUE.CPO8CXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N
M<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A
M<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A
M9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV
M"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P
M;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI
M;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD
M;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.
M86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S
M/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@
M*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G
M:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@
M(D%U9W5S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X
M"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E
M<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!
M=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS
M-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F
M='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U
M:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H
M7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM
M<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@
M(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U
M:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S
M;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A
M=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L
M92!F:65L9',Z(@IM<V=S='(@(E!I965J86UI92!L875K:3HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B
M0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O
M<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")"96QI>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N
M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM
M<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B1'II;?!A;F%S(&1I96YA(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI
M8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYA=B!S=')O9&%M
M<R!P87II\F]J=6UU(&ML875S[G3B:G,@)7,B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I
M9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S
M='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED
M(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(E!A<W1S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@
M1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG
M87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*(RP@9G5Z>GD*;7-G:60@(D--
M4R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E
M;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@
M8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY
M.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L
M96YD87(B"FUS9W-T<B`B2V%L96YDXG)S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O
M<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM
M<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S
M($Q$05`@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@
M(D-A;F%D82(*;7-G<W1R(")+86QE;F3B<G,B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N
M:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*
M;7-G:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T
M(@IM<V=S='(@(D%T8V5L="!P<F]B;.=M87,@<&EE=&5I:W5M=2(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS
M9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM
M<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U
M<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S
M=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE
M<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U
M>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D]P8VEJ87,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@
M(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*
M;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6QA:7,@=.)L<G5N:7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T
M<B`B36]B:6QA:7,@=.)L<G5N:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L
M;'!H;VYE(@IM<V=S='(@(DUO8FEL86ES('3B;')U;FES(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T
M:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@
M(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(D%T8V5L="!I>FUA:?)A<R(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V
M"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*
M(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES
M(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N
M+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H87(B"FUS9W-T<B`B=D-A<F0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM<V=S='(@(E9I<G-R86MS
M=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF
M:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y
M"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@
M82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y
M<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").878@<W1R;V1A;7,@
M<&%Z:?)O:G5M=2!K;&%U<^YTXFIS("5S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R
M(@IM<V=S='(@(DMA;&5N9.)R<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A
M9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I
M9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@
M;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B
M0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M06EZ=N=R="!L;V=U(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G
M:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@
M4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R
M9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@
M4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G
M:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM
M<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")5>O+G;75M<R(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@
M(D-O;7!A;GDB"FUS9W-T<B`B57KRYVUU;7,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"FUS9VED(")#;VYD:71I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G
M:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO
M;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"B,L(&9U
M>GIY"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E!A<F]L92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T
M:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B)R5S)R!S871U<G,B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`B
M57KRYVUU;7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM
M<V=S='(@(DEE;.)DYW1A:7,@;&%U:W,Z("5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E
M;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").96EZ9&5VXG,@
M<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E
M<G9E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE:7ID97;B
M<R!P:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I
M<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(").96EZ9&5VXG,@871V
MYW)T($UA:6YT96YA;F-E7U1A<VL@;6]D=6QI("5S(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").96EZ9&5VXG,@
M871VYW)T($UA:6YT96YA;F-E7U1A<VL@;6]D=6QI("5S(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I
M97,@3$1!4"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE
M8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A
M9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*
M(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I
M97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")(;W)D92!N878@:V]R96MT:2!K;VYF:6=U<N=T82(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C
M:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N(@IM<V=S='(@(DYE:7ID97;B<R!P:65S;.=G=&EE<R!,1$%0
M('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C
M;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<
M(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT
M<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W
M,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@
M(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI
M;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB
M+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I
M9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM
M<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S
M='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y
M"FUS9VED(")$86EL>2(*;7-G<W1R(")):V1I96YA<R(*"B,Z(&%D;6EN+V1A
M=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$
M871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I
M=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(DEK
M9&EE;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B
M1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN
M9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5F
M875L="(*;7-G<W1R(")087)A<W3B(&ED96YT:73B=&4B"@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM
M<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("))>FUA;G1O="!N;VML=7/G
M=&\@=N=R=.YB=2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP
M:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B4&%R87-T
MXB!I9&5N=&ETXG1E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L
M(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E!A<F%S=.(@
M:61E;G1I=.)T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I
M9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G
M:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@
M86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B
M1&5L971E(')O=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L
M971E:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L
M96-T960@:61E;G1I='DB"FUS9W-T<B`B4&%R87-TXB!I9&5N=&ETXG1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L
M:79E<GD@=&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM
M87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")!
M<')A:W-T:65T('!R;V)LYVUU(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@
M(E!I;&YS(&%P<F%K<W1S.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL
M92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R(")3[FOB:V$@:6YF;W)MXF-I:F$@:7(@
M;F]S^W3N=&$@861M:6YI<W1R871O<F%M+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@
M(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I
M<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/
M<'1I;VYS(@IM<V=S='(@(D5K<N)N82!I97-T873N:G5M:2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B1&ES
M<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")%:W+B;F$@:65S=&%T
M[FIU;6DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P
M;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R
M;6%T(@IM<V=S='(@(D5K<N)N82!I97-T873N:G5M:2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB
M;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DYA=B!T:67P
M87,@<&EE96IA<R!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V
M92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W
M"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM
M<V=I9"`B12U-86EL(@IM<V=S='(@(E!A<W1S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O
M+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I
M9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T
M"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U
M861O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E
M;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O
M=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G
M:60@(D5D=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%
M9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H
M96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y
M"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M<&%S=',B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B
M"FUS9W-T<B`B2OMS=2!E+7!A<W1A(&%D<F5S93HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I
M;VXB"FUS9W-T<B`B0VET82!I;F9O<FWB8VEJ82(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT
M;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"B,L(&9U>GIY"FUS9VED(")%;6]T
M:6-O;G,B"FUS9W-T<B`B3W!C:6IA<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B
M16UP='D@;65S<V%G92XB"FUS9W-T<B`B5'5K\',@<F5Z=6QTXG1S+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*
M;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B5'5K\',@<F5Z=6QTXG1S
M+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G
M:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F
M(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B
M;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@
M(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*
M;7-G<W1R(")+[_MD82(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMA=')A<R`Q-2!M:6[[=&5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ>0IM<V=I9"`B179E
M<GD@,B!M:6YU=&5S(@IM<V=S='(@(DMA=')A<R`U(&UI;OMT97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B2V%T<F%S
M(#,P('-E:W5N9&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T
M97,B"FUS9W-T<B`B2V%T<F%S(#4@;6EN^W1E<R(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO
M9VEN(@IM<V=S='(@(DMA='+B('!I97-LYV?P86[B<R!R96EZYR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R(")+871R=2!P=7-S='5N9'4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@
M(D5V97)Y(&UI;G5T92(*;7-G<W1R(")+871R=2!M:6[[=&DB"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU
M97,Z(@IM<V=S='(@(E!A<F%U9W;G<G3N8F%S(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D
M("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D
M('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V
M"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#
M;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W
M"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DYE:7ID97;B<R!S
M8?)E;70@:65S=&%T[FIU;75S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L(&9U>GIY"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R
M(").96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS
M9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(").96EZ9&5V
MXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(").96EZ9&5VXG,@
M<V'R96UT(&EE<W1A=.YJ=6UU<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U
M>GIY"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B265LXF1E<R!K;/MD
M83HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<W,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G
M<W1R(")&86MS<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED
M(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA
M=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM
M<V=I9"`B1FEL92(*;7-G<W1R(")6:7)S<F%K<W1S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@
M3F%M92(*;7-G<W1R(")6XG)D<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L
M;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I
M9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL
M86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G
M:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM
M<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N
M)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B
M1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@
M(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(E!I
M97KN;65S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&
M;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED
M(")&<F%M97,B"FUS9W-T<B`B5N)R9',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&
M<F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B
M1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")0:6QN<R!A<')A:W-T<SHB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W
M-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B2OMS=2!V
MXG)D<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A
M=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L
M92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A
M>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@
M(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM
M<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L
M971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N
M<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R(")+;VYT86MT:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*
M;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED
M(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I
M9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O
M:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")086SN9'KN
M8F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(
M96QP97(B"FUS9W-T<B`B4&%L[F1Z[F)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE
M(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M
M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$U,S4*(RP@9G5Z>GD*;7-G:60@(DAO;64B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")-XFIA<R!A
M9')E<V4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO
M;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS
M9W-T<B`B3>)J87,@=&5L969O;G,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO
M;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+
M;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV
M-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I
M9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V
M92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED
M(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R
M92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N
M<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@
M(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU
M;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S
M<R(*;7-G<W1R(")!9')E<V4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP
M8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP
M:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@
M4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC
M96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R
M("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G
M:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM
M<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I
M9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA
M9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R
M;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E
M(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S
M='(@(DEE;.)DYW1A:7,@;&%U:W,Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@
M9FEE;&0Z("5S(@IM<V=S='(@(DEE;.)DYW1A:7,@;&%U:W,Z("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R("))96SB9.=T:64@;&%U:VDZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS
M9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R
M<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z
M>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(DS[9'IU(&YO<N)D:65T('-A=G4@;&EE=&]TXFIA(';B<F1U
M('5N('!A<F]L:2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q
M"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G
M:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T
M"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PHC
M+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B2OMS=2!I;F9O
M<FWB8VEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*
M;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN
M<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R
M="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B
M26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED
M("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I
M9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B
M26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN
M<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S
M86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S
M96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO
M9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI
M;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*
M;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED("))
M;G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A
M;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI
M9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q
M"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"FUS9VED("));G9A
M;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV
M86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A
M;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN
M=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R(")):V1I96YA
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA
M<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS
M9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R
M:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI
M<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS
M9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I
M9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T
M:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z
M86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N
M96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@
M(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E
M(@IM<V=S='(@(EII\F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`B5F%L;V1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W
M;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@
M(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U
M>GIY"FUS9VED("),87EO=70B"FUS9W-T<B`B27II970B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU97,B
M"FUS9W-T<B`B4&%R875G=N=R=.YB87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(").96MA
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY
M"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(E!I97-LYV=T:65S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@
M(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@
M3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS
M9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*
M;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B
M4&EE<VSG9W1I97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS
M9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI
M;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@
M2&5L<"!4;W!I8W,B"FUS9W-T<B`B4&%RXF3N="!P86SN9'KN8F%S('1E;6%T
M=7,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A
M8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY
M"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B4&%RXF3N="!P86SN9'KN8F%S
M('1E;6%T=7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C
M<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B
M3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD
M(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z
M,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),
M;V<@:6XB"FUS9W-T<B`B4&EE<VSG9W1I97,B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC
M('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("))>FEE="(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G
M:6XB"FUS9W-T<B`B4&EE<VSG9W1I97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`W"B,L(&9U>GIY"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R
M(")5>F1E=G5M:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@HC
M+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R
M;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS
M9W-T<B`B4&EE<VSG9W1I97,@;F5I>F1E=N)S:2Y.97!A<F5I>G,@;&EE=&]T
MXFIA(';B<F1S('9A:2!P87)O;&4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*;7-G:60@
M(DQO;F<@=&5X="(*;7-G<W1R("))>FEE="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-
M(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X
M,0IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS
M9VED(")-86=I8R(*;7-G<W1R(")087-T<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")087-T<R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M
M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I
M(@IM<V=S='(@(E!A<W1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*
M;7-G<W1R(")087-T<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B
M36%L=&$B"FUS9W-T<B`B4&%S=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S
M"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T
M(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@
M(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G:60@(DUA<F=I
M;B(*;7-G<W1R(")"<NYD:6[B:G5M<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5
M;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H
M:6YG(&9I96QD<R(*;7-G<W1R(")387-K86YO\&EE(&QA=6MI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B
M36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA
M>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX
M"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R
M=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"B,L(&9U>GIY"FUS
M9VED(")-96UB97)S(@IM<V=S='(@(E1E:W-T:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(DUE<W-A9V4B"FUS9W-T<B`B6FGR82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(EII\F$B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B
M"FUS9W-T<B`B6FGR82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@HC+"!F=7IZ
M>0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B4^YKXFMA(&EN9F]R;>)C:6IA(&ER(&YO<_MT[G1A(&%D;6EN:7-T
M<F%T;W)A;2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U
M"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T
M:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP
M:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T
M<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(E!A<W1S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@
M97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS
M9W-T<B`B2^_[9&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G
M:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@
M8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF
M('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N
M($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@
M(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD
M;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO
M;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@
M(DUO;G1H;'DB"FUS9W-T<B`B2V%T<G4@;>=N97-I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0
M:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B
M36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM
M<V=I9"`B36]V92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O
M<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M
M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T
M,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U
M>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DK[
M<W4@:6YF;W)MXF-I:F$B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G
M<W1R(")6XG)D<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*
M;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").
M971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E
M(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS
M9VED(").979E<B(*;7-G<W1R(").96MA9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A
M=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E
M<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D
M(@IM<V=S='(@(E!A<F]L92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I
M;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR.#D*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`B4&EE>NYM97,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S
M9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I9"`B3F5X
M="!O<'1I;VYS(@IM<V=S='(@(D%T9W)I97IT:65S('!I92!O<&-I:N)M(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B
M"FUS9W-T<B`B3F5K860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X
M,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G
M>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I
M9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DYO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(E-13"!A=71E;G1I9FEKXF-I:F%I(&YA=B!N;W+B9.YT82!K;VYF
M:6=U<N)C:6IA<R!I;F9O<FWB8VEJ82XB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")!
M=&-E;'0@:7IM86GR87,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*
M(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(E-13"!K871E9V]R:6KB;2!N878@
M;F]RXF3N=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)MXF-I:F$N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*(RP@9G5Z>GD*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+B(*;7-G<W1R("),1$%0(&EE<W1A=.YJ=6UO<R!N878@;F]RXF3N=&$@
M:V]N9FEG=7+B8VEJ87,@:6YF;W)MXF-I:F$N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G
M<W1R(")344P@:V%T96=O<FEJXFT@;F%V(&YO<N)D[G1A(&MO;F9I9W5RXF-I
M:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,3<*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S
M='(@(E-13"!K871E9V]R:6KB;2!N878@;F]RXF3N=&$@:V]N9FEG=7+B8VEJ
M87,@:6YF;W)MXF-I:F$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0IM<V=I
M9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED
M(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B
M3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N
M=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P
M+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U
M=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"!A=71E
M;G1I9FEKXF-I:F%I(&YA=B!N;W+B9.YT82!K;VYF:6=U<N)C:6IA<R!I;F9O
M<FWB8VEJ82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z
M,3,U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@875T96YT:69I
M:^)C:6IA:2!N878@;F]RXF3N=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)MXF-I
M:F$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"B,L(&9U
M>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(")344P@875T96YT:69I:^)C:6IA:2!N878@
M;F]RXF3N=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)MXF-I:F$N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).
M;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P
M96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S
M"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")0:65Z[FUE<R(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@
M<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B4&EE>NYM97,B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("),^V1Z=2!N;W+B
M9&EE="!S879U(&QI971O=.)J82!VXG)D=2!U;B!P87)O;&DB"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@
M6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED
M(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R(")4XFQR
M=6YI<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/
M+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R
M9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS
M9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP
M;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`B4&EE>NYM97,B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R(")0:65Z[FUE<R(*
M"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L(&9U>GIY"FUS
M9VED(").;W9E;6)E<B(*;7-G<W1R(").96MA9"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G
M<W1R(")6XG)D<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*
M;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED
M(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R
M(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I
M9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G
M:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V
M"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQE
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0
M('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G
M:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S
M:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM
M<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y3
M4TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@
M4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@
M=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U
M,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-I:F%S(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G
M<W1R(")/<&-I:F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED
M(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S
M,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B
M3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B0VET82!I;F9O<FWB8VEJ82(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B
M86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y
M"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U
M8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z
M>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G
M:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS
M9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@
M(E!A<W-W;W)D(@IM<V=S='(@(E!A<F]L92(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC
M;W)R96-T(@IM<V=S='(@(E!A<F]L92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(E!A<F]L92(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q
M"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E!A<F]L92(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM
M<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@
M(E!E;W!L92(*;7-G<W1R("),;VUA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*
M;7-G<W1R("))>G!I;&3N="!U>G1U<N?P86YA<R!O<&5RXF-I:F%S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@HC+"!F=7IZ>0IM<V=I9"`B4&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R
M("))>G!I;&3N="!U>G1U<N?P86YA<R!O<&5RXF-I:F%S(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M.#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C4*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D-I=&$@:6YF;W)MXF-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T
M<B`B5.)L<G5N:7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X
M"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I
M='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O
M9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B3/MD>G4@;F]RXF1I970@<')O8FSG
M;6%S(&%N;W3B8VEJ=2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@
M(DS[9'IU(&YO<N)D:65T('-A=G4@;&EE=&]TXFIA(';B<F1U('5N('!A<F]L
M:2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED
M(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@
M(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I
M=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@
M(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U
M"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED
M(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O
M<'1I;VYS(@IM<V=S='(@(D%T9W)I97IT:65S('!I92!O<&-I:N)M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I
M9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y
M"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(EM0<F]B;.=M87,@
M>FGR;VIU;7-=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED
M(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!R;V)LYVUA<R!A<')A
M:W-T<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@
M(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@
M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS
M9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0
M=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1
M871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G
M:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@
M(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM
M<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z
M>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B6FGR82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@
M<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P
M.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E
M9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*
M;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D%T:F%U;F]T
M(&MO<'-A=FEL:W5M82!S:V%T=3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E
M<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C$S"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`B27ID>N=S="!P
MXG)I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U
M>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B27ID>N=S="!PXG)I
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("))>F1ZYW-T('#B<FDB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`B27ID>N=S="!PXG)I(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F
M<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("))
M>F1ZYW-T('#B<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@
M9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M('5S97(B"FUS9W-T<B`B27ID>N=S="!PXG)I(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B27ID>N=S="!PXG)I(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E!I97!R87/N=&%I
M<R`G=6ED)R!N878@;F]RXF3N=',@:65S=&%T[FIU;74@:V]N9FEG=7+B8VEJ
MXBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B4&EE<')A<^YT86ES("=U:60G(&YA=B!N;W+B9.YT
M<R!I97-T873N:G5M=2!K;VYF:6=U<N)C:6KB+B(*"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B4&EE<')A<^YT86ES("=U:60G(&YA=B!N;W+B9.YT<R!I
M97-T873N:G5M=2!K;VYF:6=U<N)C:6KB+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")0
M87)O;&4B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I
M9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H
M96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L
M=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@
M=&\@3W!T:6]N<R(*;7-G<W1R(")!=&=R:65Z=&EE<R!P:64@;W!C:6KB;2(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T
M>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V
M97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS(@IM<V=S='(@(D%T9W)I97IT:65S('!I92!O<&-I:N)M(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*
M;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@
M(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM
M<V=S='(@(DQO;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B
M4F]T871E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS
M9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2
M=6QE<R(*;7-G<W1R("),;VUA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M
M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)
M344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@365S
M<V%G:6YG(@IM<V=S='(@(EII\F$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")3
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T
M<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")3
M86EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")3
M86EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS
M9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E-A9VQA8N)T(&]P8VEJ
M87,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E
M($]P=&EO;G,B"FUS9W-T<B`B4V%G;&%BXG0@;W!C:6IA<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R
M)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*
M;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED
M(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X
M-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("))>G;G
M;&EE=&EE<R!D871U;6$@9F]R;>)T=3HB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G
M:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U
M-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@
M8V]M<&]N96YT<RXB"FUS9W-T<B`B27IVYVQI971I97,@9&%T=6UA(&9O<FWB
M='4Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+B(*;7-G<W1R("(B"B))>G;G;&EE=&EE<R!S:6UB;VQU<R!N;R!Z96WB:R!R
M961Z86UA:N)M(&EZ=N=L;N=M+B!0YV,@=&%M(&K[<R!V:?)U<R!V87)A="`B
M"B)PXG)N97-T(&%R(&-O<'DO<&%S=&4B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB
M"FUS9W-T<B`B27IVYVQI971I97,@9&%T=6UA(&%T9&%L[G3B:G4Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!F;W)M870Z(@IM<V=S='(@(DEZ=N=L:65T:65S(&1A='5M82!F;W)M
MXG1U.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ
M-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB
M"FUS9W-T<B`B27IVYVQI971I97,@9&%T=6UA(&%T9&%L[G3B:G4Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!F;W)M870Z(@IM<V=S='(@(DEZ=N=L:65T:65S(&QA:6MA(&9O<FWB
M='4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(DEZ=N=L:65T
M:65S(&1I=G5S('-A9&5R[F=U<R!L875K=7,N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS
M9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@
M(DEZ=N=L:65T:65S('9A;&]D=3HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G
M<W1R(").;W/[=.YT('!R;V)LYVUA<R!P:65T96EK=6UU(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E
M;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G
M86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G
M:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*
M;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R
M:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED
M(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V%G
M;&%BXG0@;W!C:6IA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G
M<W1R("))97-TXF3N="!L87!U871J875N;_!A;N)S('5N(&-I=&%S(&5K<N)N
M82!O<&-I:F%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(DEE<W3B9.YT(&QA<'5A=&IA=6YO
M\&%NXG,@=6X@8VET87,@96MRXFYA(&]P8VEJ87,N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED
M(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*
M;7-G<W1R("+.<V$@86YO=.)C:6IA.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D
M(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I
M9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H
M92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q
M,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I
M9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS
M9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET
M:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*
M;7-G:60@(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N
M8V4B"FUS9W-T<B`B27IL86ES="!U>G1U<N?P86YU(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*
M;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*(RP@
M9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D1A<F)A(&%D
M<F5S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I
M9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@
M26YP=70B"FUS9W-T<B`BSG!A\&\@<VEM8F]L=2!I979A9&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS
M9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY
M"FUS9VED(")3<&]R=',B"FUS9W-T<B`B265LXF1E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*(RP@
M9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(DMA;&5N9.)R<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T
M871U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$U"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")*
M^W-U(&EN9F]R;>)C:6IA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(D1A<F)A(&%D<F5S92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I
M9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D
M9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F%V('-T<F]D
M86US('!A>FGR;VIU;74@:VQA=7/N=.)J<R`E<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B
M;6ET(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B
M"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED
M(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@
M(E9E:6MS;64B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B36%N<R!K;W!S879I;&MU;7,B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I
M9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*
M;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS
M9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I
M9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R
M("))96SB9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I
M;F%M92(*;7-G<W1R("),:65T;W3B:F$@=N)R9',B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R
M;F%M92(*;7-G<W1R("),:65T;W3B:F$@=N)R9',B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G
M:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N
M($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4
M+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F
M=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5FER<W)A:W-T<R(*"B,Z
M(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED
M(")486)L92(*;7-G<W1R(")6:7)S<F%K<W1S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B
M;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*
M;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R(")5>F1E=G5M:2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")4
M96QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R
M871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E
M+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q
M"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A4
M25,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I
M;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#@*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B2OMS(&5S870@:7IGXFII<R!N;R!S:7-TYVUA<RX\
M8G(@+SY086QD:65S('!A<B!S:7-TYVUA<R!L:65T;_!A;G4N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z
M.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@
M(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T
M=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A
M8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF
M>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*
M;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E
M96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BT&%I(';G<G3N8F%I(&ER(&KB8OMT
M('-K86ET;&EM+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R
M;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B
M5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS
M9W-T<B`B265S=&%T[FIU;6D@;F%V('!I965J86UI(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S
M7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(M!A
M:2!VYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI;2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A
M>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E
M;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W
M=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BT&%I(';G<G3N8F%I(&ER(&KB
M8OMT('-K86ET;&EM+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C
M,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C
M97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN
M8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J
M96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA
M:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE
M;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`BT&EM('-K86ET
M;&EM(&ER(&KB8OMT('9I<VUA>B`Q+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N
M)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS
M9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T
M"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@
M(M!A:2!VYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI;2XB"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T
M<B`B5FER<W)A:W-T<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P
M"FUS9VED(")4:71L92(*;7-G<W1R(")6:7)S<F%K<W1S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET
M;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T
M"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H
M:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED
M(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&]G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B
M5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N
M<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I
M;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R
M:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS
M9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO
M=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")5
M4DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S
M=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB
M"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I
M9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('1O("5S+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S
M(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@7"(E<R\E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S
M(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@S.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!3
M4TPN(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E
M<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,#D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE
M+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V
M97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DYA
M=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB
M"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R
M:6TN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z
M-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@
M<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(").878@:65S
M<.=J86US('-E<VEJXB!R9>QI<W1RYW0@:65S=&%T[FIU;75S+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,
M('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92XB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE
M<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(").878@:65S<.=J86US('!I
M97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL
M97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*
M;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N
M(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYA=B!I
M97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G
M:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED
M(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G
M<W1R(").878@:65S<.=J86US(&EN=&5R<')E=.=T(/!O(%=O<F0@9&]K=6UE
M;G1U(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q
M=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E
M<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D%T8V5L="!I>FUA:?)A
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC
M;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N
M:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@
M(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*
M(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B3&EE=&]TXFIA(';B
M<F1S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C
M8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E
M8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@
M;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O
M(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT
M96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS
M9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@
M)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL
M97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED
M(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED
M(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B
M"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(DQI971O=.)J
M82!O<&-I:F%S(@H*(SH@<VEG;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B
M57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B3&EE=&]TXFIA(&]P8VEJ87,B
M"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U
M;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DQI971O=.)J82!VXG)D<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*
M(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("),:65T;W3B:F$@
M=N)R9',B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L(&9U
M>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(DQI971O=.)J82!VXG)D
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@
M(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM
M<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC
M;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T
M;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I
M;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A
M;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(
M:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED
M(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T
M=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")"<NYD:6[B:G5M
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED
M(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B
M5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*
M;7-G<W1R(")+871R=2!N963G[W4B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("),
M86EP;FD@;/MD>FTL("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M
M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B3&%I<&YI(&S[9'IA
M;2`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M96QC;VUE+"`E<R(*;7-G<W1R("),86EP;FD@;/MD>FTL("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS
M9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS
M9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q
M"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T
M:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I
M9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"FUS9VED
M(")7:6YD.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D1A<F)A(&%D<F5S
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B1&%R8F$@=.)L<G5N:7,B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!6
M1E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME
M>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R
M(")'1R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R(")'1R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED
M(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R
M(")+871R=2!G861U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@
M06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O
M(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@
M;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H
M879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS
M9W-T<B`B2OMS=2!O<&-I:F%S(&ER('-A9VQA8N)T87,N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T
M851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(D%P<F%K<W1I970@<')O8FSG;74@
M<&ER;7,@<&EE=&5I:W5M82!S^W3N\&%N87,N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A
M(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D
M+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(DK[<W4@)7,@<V5S:6IA
M(&ER(&)E:6=U<VEE<RX@3/MD>G4@<&EE<VSG9'II971I97,@871KXG)T;W1I
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U
M>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B2OMS=2!E
M+7!A<W1A(&%D<F5S93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R
M"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(DK[<W4@92UP87-T82!A9')E<V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED
M(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DK[<W4@:6YF;W)MXF-I:F$B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B
M"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(DK[<W4@
M=N)R9',Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*
M;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E
M($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@
M=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M
M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO
M;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H
M86YG960N(@IM<V=S='(@(DK[<W4@;W!C:6IA<R!I<B!S86=L86+B=&%S+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B4&%R87-TXB!I9&5N
M=&ETXG1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(DK[<W4@=N)R9',Z
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B2OMS=2!O
M<&-I:F%S(&ER('-A9VQA8N)T87,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@
M=&AI<R!S97-S:6]N+B(*;7-G<W1R(")*^W-U(&]P8VEJ87,@:7(@<V%G;&%B
MXG1A<RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R
M(")*^W-U(&]P8VEJ87,@:7(@<V%G;&%BXG1A<RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@
M(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E
M9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX
M.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O8FSG;6%S
M('II\F]J=6US72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI
M;F4@)7,@;V8@)7-=(@IM<V=S='(@(EMR:6YD82`E<R!N;R`E<UTB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY
M"FUS9VED(")?2&5L<"(*;7-G<W1R(")086SN9'KN8F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G
M:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@
M(E],;V<@:6XB"FUS9W-T<B`B4&EE<VSG9W1I97,B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G
M(&]U="(*;7-G<W1R("))>FEE="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-
M96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@
M(D]P8VEJ87,B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO
M=F4@3&EN:RXN+B(*;7-G<W1R("))>F1ZYW-T('#B<FDB"@HC.B!L:6(O87!I
M+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G
M:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B2V]N=&%K=&DB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9.)R
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G
M:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A
M;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R
M,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED
M(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS
M9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R
M(")6:7)S<F%K<W1S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O
M=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S
M"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T
M<B`B5N)R9',B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED
M(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@
M(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R
M:7-I;F<B"FUS9W-T<B`B0G+N9&ENXFIU;7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL
M86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY
M"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED
M(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R
M:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G
M:60@(G1R>2!A9V%I;B(*;7-G<W1R(")+871RXB!P:65S;.=G\&%NXG,@<F5I
M>N<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z
M,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U
M<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#
M87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VUK7TU++G!O
M````````````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`V,3$V-#8`,3`T,3<S-C,P,#(`,#$V,S<W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@=')A;G-L871I;VX@;V8@;6M?
M34LN<&\@=&\@36%C961O;FEA;@HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E
M9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E
M+@HC($-O<'ER:6=H="`H0RD@,C`P,R!%=7)E:V$@26YF;W)M871I:V$*(R!3
M=&]J86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M+FUK/BP@,C`P,PHC"FUS9VED
M("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!M:U]-2UQN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#8M,C8@,34Z,3@K,#(P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!3=&]J86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M
M+FUK/EQN(@HB3&%N9W5A9V4M5&5A;3H@36%C961O;FEA;B`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+35<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E@M1V5N97)A=&]R
M.B!+0F%B96P@,2XP+C%<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B
M("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R
M964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@
MX^'?U>C=WB#4WM30U-7=(-W0(.'8X>+5W-[B+B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T
M(&-R96%T960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@
M)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O
M<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R
M96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@OM_5
MX-#FV-@@U]`@WM3@UN/2T/K5("T@O][BTN#4T"(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS
M(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@
M)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(K+:
MV^/GV"#0VMX@X=#:T.@@U-`@V-?2X.C8Z"#=U=K>V"#>W]7@T.;8V"#2WB#<
MWMS5W>+>TBXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D
M<F5S<R!";V]K(@IM<V=S='(@(K#4X-7AT.`B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A
M;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S
M86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W
M87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O
M=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B
M+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L
M92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(
M;W5R($9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R
M("(R-"#GT.'0(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM
M<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER
M960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@
M4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B
M04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED
M(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I
M9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!
M8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(K_>XM+@U-@@V][7V-W:T"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!9&0B
M"FUS9W-T<B`BL-3@U>'0(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M
M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL
M9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B
MM-[4T-38(-K>X-CAW=C:(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M
M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*
M;7-G<W1R("*TWM30U-@@W=[2(-K>X-CAW=C:.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU
M;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(K3>U-#4V"#=WM(@VM[@V.'=V-HZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BM-[4T-38
M(-_0X"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@
M8F]O:SHB"FUS9W-T<B`BL-3@U>'0X"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O
M(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("*PU.#5X=#@(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(K3>U-#4V"#:
MWN#8X=W8VB(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB
M)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"XB"FUS9W-T<B`BM-[4T-+0^M7BWB#=T"#:WN#8X=W8YM@@U2#>W=72WM?<
MWM;5W=XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D
M9')E<W,B"FUS9W-T<B`BL-3@U>'0(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$S.0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S
M='(@(K#4X-7AT.`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N
M<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@
M(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(K#4W-C=V.'BX-#FV/C0(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B
M061S(@IM<V=S='(@(K#4X-7AT"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA
M;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@
M(D%L8F%N:6$B"FUS9W-T<B`B06QI87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY
M"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L:6%S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B
M"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*
M;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I
M8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS
M,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R
M86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L
M;"!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U
M<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS
M9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED
M(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5
M<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E
M<W,B"FUS9W-T<B`BLM#HT"!%;6%I;"#0U.#5X=`Z(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"FUS9VED(")!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N
M9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L
M;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L
M:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@
M<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G
M:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED
M(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I
M9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O
M4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE
M;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T
M"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM
M<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*
M;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB
M075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#
M;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T
M"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@
M57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R
M861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@
M4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM
M<V=S='(@(K3>X>+0W]W8(-_>V]CZT#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G
M:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#
M;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@
M(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`BP-[4U=W4U=TB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC
M+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B
M0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM
M<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM
M<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM
M<V=I9"`B0G)A>FEL(@IM<V=S='(@(K_>Z.+0(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS
M9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-#0*(RP@9G5Z>GD*;7-G:60@(D--4R(*;7-G<W1R(")#5E,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED
M(")#4D,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S
M"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@
M;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E
M<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BO=7C
MX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R
M"FUS9VED(")#86YC96PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R
M="(*;7-G<W1R("*^XMK0UM@@O^#>T=O5W"#`U=_>X.(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ
M"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@
M(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E
M('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM
M<V=I9"`B0V%P=&EO;B(*;7-G<W1R("*WT.?CTM#X(-[?YMC8(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED
M(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT
M"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(KS>T=C;U=TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L
M(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BO-[1V-O5
MW2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G
M:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S
M<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C<T"B,L(&9U>GIY"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BO-[1
MV-O5W2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT
M:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B
M0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O
M;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,L(&9U>GIY"FUS9VED
M(")#:&%N9V4B"FUS9W-T<B`BON+:T-;8(-/8(-_@WMS5W=CBU2(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B
M0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BO][BTN#4V"#;WM?8W=K0
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H
M87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL92(*
M;7-G<W1R("*]T.';WM(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!P87-S=V]R
M9"(*;7-G<W1R("*_WN+2X-38(-O>U]C=VM`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS
M9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O
M<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED
M(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L
M96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM
M<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@
M=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO
M<V4@5VEN9&]W(@IM<V=S='(@(K?0XM+>X-@@T]X@W^#>U][@U>;>XB(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG
M*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO
M=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#
M;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS
M9W-T<B`BQ-C@W-`B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@
M(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED
M(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(L38
MX-S0(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP
M=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I
M;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G
M<W1R("*_WN+2X-38(-O>U]C=VM`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ
M("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T
M"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E
M<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM
M<V=S='(@(L'>U.#6V-W0(-W0("<E<R<B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*
M;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`BQ-C@W-`B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(KC<W][@XMC@T-W>(-_>
MV]4Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O
M<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M,C$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+B(*;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@
MTM7@WN(N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B
M0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA
M;F-E+B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P
M('-E<G9E<B(*;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@
MX=7@TM7@WN(N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<
M(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W
M<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S(@IM<V=S='(@(KS>U./;WN(@W=`@U]#4T.?0XM`@U]`@WM3@UN/2T/K5
M("5S(-W5(-S>UM4@U-`@T=C4U2#>XM+>X-7=(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("*\WM3CV][B(-W0(-?0
MU-#GT.+0(-?0(-[4X-;CTM#ZU2`E<R#=U2#<WM;5(-30(-'8U-4@WN+2WN#5
MW2(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BO=7CX=_5
MZ-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!!0TPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W1S+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(-W5(-4@W^#0TMC;W=X@
MVM[=Y-C3X^#8X-#=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BO=7CX=_5Z-W0
M(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E
M(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O
M=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@
M9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*
M;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@
M;F5W(&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P
M"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D
M(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T
M(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*
M;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#
M=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT
M(%523"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*
M;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@
M(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED
M(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX
M+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS
M9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN
M:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z
M96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("*TW=72
MW=XB"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E
M($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0HC+"!F=7IZ>0IM<V=I9"`B1&%T
M92(*;7-G<W1R("*XU]'@V.C8(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R
M"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`BM-W5TMW>(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V
M"B,L(&9U>GIY"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("*XU]'@
MV.C8(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@
M(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!)
M;F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E
M9F%U;'0B"FUS9W-T<B`BN-?1X-CHV"(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT($-O;&]R(@IM<V=S='(@(KK>X-CAXM@@X>+0W=30X-3=T"#2X-74W=[A
MXB(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`BP>+0W=30X-35W2#8U-7=
MXMCBU>(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`BP>+0W=30X-35W2#8U-7=
MXMCBU>(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E
M9FEN:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("*XU]'@
MV.C8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@0V5L;"(*;7-G
M<W1R("*XU]'@V.C8(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO
M9W)O=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!'<F]U<"(*
M;7-G<W1R("*XU]'@V.C8(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(KC7
MT>#8Z-@B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@
M4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M
M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@8V5L;"(*;7-G<W1R("*XU]'@V.C8(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("*XU]'@V.C8(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!R;W<B"FUS9W-T<B`BN-?1X-CHV"(*"B,Z('1E;7!L871E<R]P
M<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("+!XM#=U-#@U-7=(-C4
MU=WBV.+5XB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R
M861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*
M(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BN-?1X-CH
MV"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R
M:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(K[?V.$@W=`@W^#>T=O5W-[B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G
M:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(KK>W-_;U>+5W2#>W]CA.B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I
M<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C
M=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M("*WT.?CTM#X(-[?YMC8(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.CDV"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L
M87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@
M;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(KW5(-_@V.'BT-_CTM#X(-38X-7:
MXMW>(-3>(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS
M9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M
M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N
M(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G
M:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED
M(")%+4UA:6PB"FUS9W-T<B`BO][HXM`B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3
M(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T
M:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N
M<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B
M161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B
M161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@
M)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G
M:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V
M.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`BU2W?WNCBT"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G
M<W1R("*RT.C0($5M86EL(-#4X-7AT#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.38S"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"XB"FUS9W-T<B`BN][7V-W:V.+5(-S>X-`@U-`@T=C4T.(@
MV.'BV"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B
M16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S
M<V%G92XB"FUS9W-T<B`BO^#0U]7=(.#5U^/;XM#B+B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M
M<'1Y(')E<W5L="XB"FUS9W-T<B`BO^#0U]7=(.#5U^/;XM#B+B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y
M('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F
M<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@
M161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B
M"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I
M;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T
M=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U
M871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E
M<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("*S
MX-7HVM`B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A
M;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS
M9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H
M:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V
M"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN
M=71E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y
M"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`BP=7:
MWM4@W^#8^-#2X]+0^M4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E
M8V]N9',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"B,L(&9U>GIY"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`BP=7:WM4@W^#8^-#2X]+0^M4B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS
M9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("+!U=K>U2#?X-CXT-+CTM#ZU2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*(RP@9G5Z>GD*;7-G:60@
M(D5V97)Y(&UI;G5T92(*;7-G<W1R("+!U=K>U2#?X-CXT-+CTM#ZU2(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE
M('9A;'5E<SHB"FUS9W-T<B`BO^#8W-7@.B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN
M<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R
M"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G
M*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM
M<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM
M<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*(RP@9G5Z>GD*;7-G:60@
M(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("*]U2#<
MWM;5TB#4T"#3V"#8U]S5W=#<(-_>U-7AX]+0^M#BT"XB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N(@IM<V=S='(@(KW5X^'?U>C=T"#:WMW5VN;8^-`@X=X@3$1!
M4"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S
M97)V97(N(@IM<V=S='(@(KW5X^'?U>C=T"#:WMW5VN;8^-`@X=X@3$1!4"#A
MU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M('1O(%PB)7-<(BXB"FUS9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,
M1$%0(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3$1!4"#:WMW5VN;8^-#BT"#4WB`E
M<R#5(-W5X^'?U>C=T"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@TM7@WN(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM
M<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O
M<CHB"FUS9W-T<B`BL^#5Z-K0(-_@V"#8W-_>X.(Z(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(L30VN$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y
M"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("+$T-KA(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E
M8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P
M"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#
M05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@
M(KW0X=O>TB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H
M<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA
M9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U
M"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`BN-S5(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I
M>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N
M="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&
M;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A
M('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I
M9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B
M1F]R='5N97,B"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS
M9VED(")&;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`BN-S5(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R
M;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H
M($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H
M(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&
M<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-#@*(RP@9G5Z>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
MNM[<W]O5XM7=(-[?V.$Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.
M86UE(@IM<V=S='(@(K+0Z-4@V-S5.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A
M8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T
M86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'
M86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M
M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3<Y"B,L(&9U>GIY"FUS9VED(")'<F]U<"!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("*PU-S8W=CAXN#0YMCXT"(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<P"B,L(&9U>GIY"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B
ML-3@U>'0X"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC
M871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*
M;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@
M(DAE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R
M97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I
M9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I
M;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R("*_WMS>Z"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@
M(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G
M<W1R("*_WMS>Z"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B
M2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M.0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC
M.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-3,U"B,L(&9U>GIY"FUS9VED(")(;VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED
M(")(;VUE($%D9')E<W,B"FUS9W-T<B`BM-[<T.C=T"#0U.#5X=`Z(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(K3>W-#H
MU=T@XM7;U>3>W2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(
M;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!)
M;G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@
M8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M
M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R
M("(G)7,G(./AW]7HW=X@WN+AXN#0W=7B(-[4(.'8X>+5W-[B+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T
M"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R
M:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G
M:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED
M(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(K#4
MX-7AT"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*
M;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B
M25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@
M=VET:"!T97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF
M;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO
M=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G
M92!0<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q
M"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`BN-S?WN#BV.#0
MW=X@W][;U3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS
M9W-T<B`BN-S?WN#BV.#0W=X@W][;U3H@)7,B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S
M='(@(KC<W][@XMC@T-W8(-_>V]CZT#HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E
M<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO
M;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B
M26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B
MLM4@W-[;V-S5(-W0TM74U>+5(-+0Z-4@VM[@V.'=V.?:WB#8W-4@V"#;WM?8
MW=K0(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@
M(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC
M<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B
M26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@
M(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("))
M;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L
M=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T
M($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T
M"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW
M,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED
M("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED
M("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G
M:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS
M97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM
M<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS
M-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L
M:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M,PIM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED
M('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED
M('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E
M8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R
M-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@
M(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R
M-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS
M9W-T<B`BM-W5TMW>(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@
M(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W
M<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*
M;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I
M9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*
M;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE
M;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED
M(")+97D@57-A9V4B"FUS9W-T<B`BO][@T-K0(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+
M;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@
M(DQA;F=U86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S
M="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1
M=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q
M"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(KC7V]77(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I
M9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED
M("),969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@
M=F%L=65S(@IM<V=S='(@(K_@V-S5X#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS
M9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B
M3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@
M4F%I;B(*;7-G<W1R("*[WM/8X-#ZU2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G
M:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!2
M86EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L
M(&9U>GIY"FUS9VED("),:6YK(@IM<V=S='(@(KO>T]C@T/K5(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W
M"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@
M861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT
M;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@
M(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O
M:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@
M(KC7V]CAXM#X(.+5W-@@U]`@W][<WN@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!
M<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T
M<B`BN-?;V.'BT/@@XM7<V"#7T"#?WMS>Z"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS
M9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*
M;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B
M<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F
M86EL960Z("5S(@IM<V=S='(@(KO8X>+0^M7BWB#=T"#:WN#8X=W8YM@@U2#>
MW=72WM?<WM;5W=XN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,B"FUS9W-T<B`BN]CAXM#ZU>+>(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>
MUM7=WBXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(KO8
MX>+0^M7BWB#=T"#:WN#8X=W8YM@@U2#>W=72WM?<WM;5W=XN(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B
M3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@
M;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY
M,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(KO>T]C@T/K5(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO
M=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BN-?;
MU=<B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G
M:60@(DQO9VEN(@IM<V=S='(@(KO>T]C@T/K5(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ
M>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(KC7V]77(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED
M("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@
M;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM
M<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@
M9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(K_>Z.+0(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(K_>
MZ.+0(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN
M7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`BO][HXM`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L
M9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED
M(")-86QI(@IM<V=S='(@(K_>Z.+0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY
M"FUS9VED(")-86QT82(*;7-G<W1R("*_WNCBT"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I
M9"`B36%R9VEN(@IM<V=S='(@(K+=V-S0W=C5(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3
M965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T
M:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B
M36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(KK>X-7AW][=U-C@T.?:V"#?WMO8
M^M`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU
M;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA
M>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P
M"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M365S<V%G92(*;7-G<W1R("*_WN#0VM`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F
M=7IZ>0IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("*_WN#0VM`B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B
M"FUS9W-T<B`BO][@T-K0(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS
M9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED
M("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-
M971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A
M;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G
M:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE
M(@IM<V=S='(@(K_>Z.+0(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I
M9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS9W-T<B`BL^#5
MZ-K0(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C
M96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R
M871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N
M="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T
M"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X
M"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA
M8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS
M9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY
M(@IM<V=S='(@(KS5X=7GW=XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S
M97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@
M(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C
M;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED
M(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE
M9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V
M92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT
M:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,
M87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA
M;64B"FUS9W-T<B`BN-S5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM
M<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E
M($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P
M;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G
M:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A
M=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E
M<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D
M(@IM<V=S='(@(KO>U]C=VM`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q
M;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W
M:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C4R"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O
M<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("*[WM?8W=K8XM4@W-[@T"#4T"#1
MV-30XB#8X>+8+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*
M(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R("*]T-?0U"#:WMT@WM_FV-CBU2(*"B,Z(&9R86UE=V]R
M:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B
M3F\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N
M:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@
M8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!
M3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0
M(-_>U-7AX]+0^M4@W=`@4U%,(-C4U=WBV.+5XMCBU2XB"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*
M;7-G<W1R("*^XMK0UM@@T]@@W^#>W-7=V.+5(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("*]U=S0(-C=
MY-[@W-#FV-@@U]`@W][4U>'CTM#ZU2#=T"!344P@VM#BU=/>X-C8XM4N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+B(*;7-G<W1R("*]U=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'C
MTM#ZU2#=T"!,1$%0(-S>UMW>X>+8XM4N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R
M("*]U=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'CTM#ZU2#=T"!344P@VM#BU=/>
MX-C8XM4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q
M-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`BO=7<T"#8
MW>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@W=`@4U%,(-K0XM73WN#8V.+5+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS
M9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F
M:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED
M(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P
M;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED
M(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW
M,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP
M.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("*]U=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'C
MTM#ZU2#=T"!344P@V-35W>+8XM7BV.+5+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%S<W=D+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(KW5W-`@V-WDWN#<T.;8V"#7T"#?WM35X>/2T/K5(-W0(%-13"#8U-7=
MXMCBU>+8XM4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("*]U=S0(-C=Y-[@W-#FV-@@U]`@
MW][4U>'CTM#ZU2#=T"!344P@V-35W>+8XM7BV.+5+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF;W)M
M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F
M=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS9VED(").;R!S97!A
M<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS
M9VED(").;R!S:61E<R(*;7-G<W1R("*WT-'5V]7HVM@B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*
M;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C
M86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("*RU2#<WMO8W-4@W=#2
MU=35XM4@TM#HU2#:WN#8X=W8Y]K>(-C<U2#8(-O>U]C=VM`B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@
M6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED
M(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R("+"U=O5
MY-[=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M
M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F
M;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE
M<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*
M;7-G<W1R("*WT-'5V]7HVM@B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R("*WT-'5V]7HVM@B
M"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V
M96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(KC<U2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O
M9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B
M3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E
M871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F
M9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W
M('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED
M(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`BN][7V-W:T"(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES
M(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@
M82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G
M:60@(D]P=&EO;G,B"FUS9W-T<B`BM]#GX]+0^"#>W^;8V"(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X
M"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R
M9V%N:7-A=&EO;B(*;7-G<W1R("*PU-S8W=CAXN#0YMCXT"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES
M871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@
M(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M
M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED
M(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+
M97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G
M:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-
M($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")0
M32!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W
M;W)D(@IM<V=S='(@(KO>U]C=VM`B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C
M="(*;7-G<W1R("*[WM?8W=K0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R
M861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B
MN][7V-W:T"(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L
M(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(KO>U]C=VM`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS
M9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`BN][7V-W:V.+5
M(-S>X-`@U-`@T=C4T.(@V.'BV"XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@
M9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B
M4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R("+#
MV][3T"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`BN-?2X.C8(-[?
MU>#0YMC8(-?0(-[4X-;CTM#ZU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,#8*(RP@9G5Z>GD*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BN-?2X.C8(-[?U>#0YMC8(-?0
M(-[4X-;CTM#ZU2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES
M<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E
M;FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI
M;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M.`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`BL-3<V-W8X>+@T.;8^-`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV
M"FUS9VED(")0:&]N92(*;7-G<W1R("+"U=O5Y-[=(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS
M9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G
M:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED
M(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE
M87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E
M+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED
M(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(K+5
M(-S>V]C<U2#=T-+5U-7BU2#3WB#?X-[1V]7<WN(N(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P
M87-S=V]R9"(*;7-G<W1R("*RU2#<WMO8W-4@W=#2U=35XM4@TM#HU2#:WN#8
MX=W8Y]K>(-C<U2#8(-O>U]C=VM`B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H
M92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G
M:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E
M<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U
M<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F=7IZ
M>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("*]T-?0U"#:WMT@
MWM_FV-CBU2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I
M=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R
M(");N-?2U>CBT/@@U]`@W^#>T=O5W-[B72(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R
M("*^W]CA(-W0(-_@WM';U=S>XB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED
M(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G
M:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@
M2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T
M"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")2
M86EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A
M;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T
M<B`BO][@T-K0(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T
M"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5S970B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO
M;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X
M"FUS9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS
M9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"B,L
M(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I
M9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("*^U.'BX-#=V"#?T.`B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A
M:7(B"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("*^U.'BX-#=
MV"#?T.`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B
M"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@=7-E<CH@)7,B"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@
M8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*
M;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(K'0X-#=V-[B("=U:60G(-W5
M(-4@W=#2U=35W2#2WB#?WM35X>/2T/K0XM`N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(K'0X-#=
MV-[B("=U:60G(-W5(-4@W=#2U=35W2#2WB#?WM35X>/2T/K0XM`N(@H*(SH@
M9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*QT.#0W=C>XB`G=6ED)R#=U2#5(-W0
MTM74U=T@TMX@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N
M<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T
M(@IM<V=S='(@(E)E<V5T(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@
M(KO>U]C=VM`B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PHC
M+"!F=7IZ>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("*_
MWN+2X-38(-O>U]C=VM`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS
M9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T
M<B`B4F5S970B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/
M<'1I;VYS(@IM<V=S='(@(KW0U]#4(-K>W2#>W^;8V.+5(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A
M<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI
M;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG
M=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B
M"FUS9W-T<B`BO=#7T-0@VM[=(-[?YMC8XM4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS
M9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L
M=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`BP]O>T]`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@
M(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*
M;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@
M(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R("+#
MV][3T"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M,`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R
M("*_WN#0VM`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-1
M3"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*
M;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED
M(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I
M9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@
M86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*
M;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI
M=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E("5S(@IM<V=S='(@(K?0Y^/2T/@@WM_FV-@B"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T
M<B`BM]#GX]+0^"#>W^;8V"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4
M+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS
M9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&$@9&%T92(*;7-G<W1R("*XU]'5X-@@Y-[@W-#B(-?0(-30XN/<
MWN(Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@
M(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S
M97(@=&\@861D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@
M(KC7T=7@V"#DWN#<T.(@U]`@U-#BX]S>XCHB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@
M;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(KC7T=7@V"#:
MWM@@VM#@T-KBU>#8(.+8(.+@U='0T.(N(+S>UM7H(-_>XM[0(-W8TB#4T"#3
MV"#8X=K>W]C@T.@@WM0@W][;U>+>("(*(M?0(.+5VN'B+B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9&5L:6UI=&5R.B(*;7-G<W1R("*XU]'5X-@@X=7?T.#0XM[@(-?0(-30XN/<
MWN(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(KC7T=7@V"#DWN#<T.(@
MU]`@U-#BX]S>XCHB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z(@IM<V=S='(@(KC7T=7@V"#AU=_0X-#BWN`@U]`@U-#BX]S>XCHB
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T
M('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`BN-?1U>#8(.3>X-S0XB#7T"#2
MX-7<U>+>.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G
M:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("*XU]'5
MX-@@U-+5(-[4T][2T.#0Y]K8(-_>V]CZT"XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G
M:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@
M(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BO^#0XM@@V-?2U>CBT/@@
MU]`@W^#>T=O5W-[B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N
M=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M
M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I
M9"`B4V5S<VEO;G,B"FUS9W-T<B`BM]#GX]+0^"#>W^;8V"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O
M<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES
M<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@
M(KK@T.+:WB#@U=?8W-4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN
M('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G
M:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G
M:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W
M97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I
M;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W
M87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE
M<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I
M9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B
M4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G
M<W1R("*_X-7AVM[:W=@@WM3@UN/2T/K5(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@
M(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I
M9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I
M=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@
M;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*
M;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(K#4X-7AT"#=T"#@T-'>
MXM`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E
M;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@
M(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN
M<'5T(@IM<V=S='(@(K+=U>'CTM#ZU2#=T"#AW]7FV/C0V]W8(-?=T.;8(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED
M(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC
M+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(KC<W][@XB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP
M.C<T"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B
M4W1O<F%G92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(K#4X-7AT"#=T"#@T-'>XM`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I
M:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T
M>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM
M<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T
M;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U
M8V-E<W,B"FUS9W-T<B`BP^'?U>C=WB(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@X^'?U>C=
MWB#4WM30U-7=(-W0(.'8X>+5W-[B+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*
M;7-G<W1R("(G)7,G(./AW]7HW=X@WN+AXN#0W=7B(-[4(.'8X>+5W-[B+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(G)7,G(./AW]7HW=X@U-[4T-35
MW2#=T"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@X^'?U>C=WB#>
MXN'BX-#=U>(@WM0@X=CAXM7<WN(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(G
M)7,G(./AW]7HW=X@U-[4T-35W2#=T"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(B<E<R<@X^'?U>C=WB#4WM30U-7=(-W0(.'8X>+5W-[B
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BNN#0XMK>(.#5
MU]C<U3HB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U
M;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I
M9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O
M4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM
M<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`HC
M+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("*XW-_>X.(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("*Z
MWN#8X=W8Y]K>(-C<U2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(KK>
MX-CAW=CGVMX@V-S5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@
M86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W=E9&5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS
M9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M
M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*
M;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F
M:6QE(@IM<V=S='(@(KW0X=O>TB(*"B,Z(&9R86UE=V]R:R]522]522]486)L
M92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R("*]T.';
MWM(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*
M;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L
M92!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II
M:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R
M9V5T.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO
M=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM
M<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E1E;7!L871E($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(K#4W-C=V.'BX-#FV/C0(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E
M>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B
M5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L
M;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM
M<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED
M("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H
M92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4
M:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G
M:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H
M92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R
M>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H
M87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM
M<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M
M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T,0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B
M92!N=6UE<FEC+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X
M"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@
M<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S
M<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q
M"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H
M92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@
M(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A
M;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B
M5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N(@IM<V=S='(@(KW5W-`@U-[AXM#?W=@@W][4U>'CTM#ZT"XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@
M(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP
M.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T
M<B`BO=#AXM#=T"#?X-[1V]7<(-_@V"#4WM30TM#ZU2#=T"`E<R#2WB#AV.'B
MU=S>XBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B
MO=#AXM#=T"#?X-[1V]7<(-_@V"#>XN'BX-#=X]+0^M4@W=`@)7,@WM0@X=CA
MXM7<WN(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("*]T.'BT-W0(-_@WM';
MU=P@W^#8(-[BX>+@T-WCTM#ZU2#=T"`E<R#>U"#AV.'BU=S>XBXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G
M<W1R("*]T.'BT-W0(-_@WM';U=P@W^#8(-3>U-#2T/K5(-W0("5S(-+>(.'8
MX>+5W-[B+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z
M,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE
M(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B
M"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D
M<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E
M;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@
M271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U
M-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L
M=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A
M($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@
M>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T
M86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O
M9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS
M9W-T<B`BO=#AV][2(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X
M-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I
M;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*
M;7-G:60@(E1I=&QE(@IM<V=S='(@(KW0X=O>TB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT
M;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I
M9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C
M;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G
M9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K
M96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I
M;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D
M(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS
M9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI
M<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B
M5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H
M;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S
M='(@(E523"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2U>#>XBXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@
M(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I
M9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG
M92!T;R`E<RXB"FUS9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#A
MWB!344P@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BXB"FUS9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0
MW"#AWB!344P@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>
M(%-13"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92XB"FUS9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#A
MWB!344P@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U
M-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-1
M3"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE
M+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#A
MU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M96UP='D@5D93(&9I;&4N(@IM<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:
MXMC@T-P@X=X@4U%,(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E
M<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2U>#>
MXBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BO=7CX=_5Z-W>(.#5T]CAXN#8X-#ZU2#=T"#?WM35
MX>/2T/K0XM`@TMX@X=7AV/C0XM`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!
M=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B
MO=4@W-[6U=(@U-`@T]@@V-?<U=W0W"#?WM35X>/2T/K0XM`N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R
M("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2U>#>XBXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N(@IM<V=S='(@(KW5(-S>UM72(-30(-/8(-C7W-7=T-P@W][4U>'CTM#Z
MT.+0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX,S4*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C8*;7-G:60@
M(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E
M860@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0
MW"#AWB!344P@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U
M;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(KW5(-S>UM72(-30
M(-/>(-_@U=+5U-#<(-[2WO@@5V]R9"#4WMKCW-7=XBXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H
M86YG97,B"FUS9W-T<B`BON+:T-;8(-/8(-_@WMS5W=CBU2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M
M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D
M($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI
M=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E
M<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*(RP@9G5Z>GD*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`BNM[@V.'=V.?:WB#8W-4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B
M"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*
M;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"B,L(&9U
M>GIY"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("*TWM30U-@@VM[@V.'=
MV-HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO
M;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM
M<V=I9"`B57-E<B(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M
M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*(RP@9G5Z>GD*;7-G
M:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B2&]R9&4@L-3<V-W8
MX>+@T.+>X"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q
M"B,L(&9U>GIY"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`BM]#GX]+0
M^"#>W^;8V"(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S
M97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(DAO<F1E(+#4W-C=V.'BX-#BWN`B
M"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U
M;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PHC
M+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(KK>X-CAW=CGVMX@
MV-S5(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ
M>0IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(KK>X-CAW=CFV"#2WB#AV.'B
MU=S>XCHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I
M='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S
M(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B
M5F5R<VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R
M=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*
M;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G
M:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D
M869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G
M:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B
M"FUS9W-T<B`BLMW8W-#=V-4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@
M1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I
M9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X
M"FUS9VED(")7965K;'DB"FUS9W-T<B`BO=74U=O=WB(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(K3>T>#5U-[XU-4L("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(K3>T>#5U-[XU-4L("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(K3>T>#5U-[XU-4L
M("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C
M:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC
M:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U
M"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F
M('1H92!T86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7
M:6YD.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED
M(")7;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@
M(K#4X-7AT"#=T"#@T-'>XM`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@
M(L+5V]7DWMT@W=`@X-#1WN+0(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI
M;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E
M9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS
M"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@
M(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@
M97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B65DB"FUS9W-T<B`BL[,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB
M"FUS9W-T<B`BL[,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS
M9VED(")996%R;'DB"FUS9W-T<B`BL][4V.C=WB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q
M"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I
M9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U
M<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I
M9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H
M;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@
M(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED
M(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@
M(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G
M<W1R("*^W]CHU>+5(-/>(-_@WM';U=S>XB#?X-74(-30(-CAW^#0XM7BU2#8
MU]+5Z.+0^"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BO=#2
MU=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-[BX>+@T-W8+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`BO=#2
MU=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-[BX>+@T-W8+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`BO=#2U=35XM4@VM[5(-K>
MX-CAW=CGVMX@V-S5(-30(.'5(-[BX>+@T-W8+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G
M<W1R("*]T-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8W-4@U-`@X=4@U-[4T-35
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC+"!F=7IZ>0IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R
M("*]T-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8W-4@U-`@X=4@U-[4T-35+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T
M;R!P97)F;W)M+B(*;7-G<W1R("*]T-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8
MW-4@U-`@X=4@WN+AXN#0W=@N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`BO=#2U=35
MXM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-[BX>+@T-W8+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S
M"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("*RT.C0($5M86EL(-#4
MX-7AT#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY
M"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(K+0Z-`@16UA
M:6P@T-3@U>'0.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O
M<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!
M9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.
M86UE(@IM<V=S='(@(K+0Z-4@V-S5.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A
M=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B*RT.C8WN(@T-+B
MWN#8U]#FV-[=U=T@W^#>XM[:WML@W=4@W][4X-;CTM`@U-[4T-+0^M4@VM[@
MV.'=V.;8+"#8V]@@XM#0("(*(MS>UMW>X>(@U2#>W=72WM?<WM;5W=`@WM0@
MU.#CT]@@W^#8Y]C=V"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BXB"FUS9W-T<B`B(@HBLM#HV-[B(-#2XM[@V-?0YMC>W=7=(-_@WN+>VM[;
M(-W5(-_>U.#6X]+0(-O8X>+0^M4@VM[@V.'=V.;8+"#8V]@@XM#0("(*(MS>
MUMW>X>(@U2#>W=72WM?<WM;5W=`@WM0@U.#CT]@@W^#8Y]C=V"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT
M,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB
M=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@IM<V=I9"`B66]U<B!D969A
M=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`BP>+0W=30X-35W2#8U-7=
MXMCBU>(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"B,L(&9U>GIY
M"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BLM#HU2#8W-4Z(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`IM<V=I9"`B66]U<B!L
M;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI
M<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM
M<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@
M>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O
M<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S
M,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9
M;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R
M;V)L96T@4F5P;W)T72(*;7-G<W1R(");N-?2U>CBT/@@U]`@W^#>T=O5W-[B
M72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@
M)7-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`BL-3<V-W8X>+@T.;8^-`B
M"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R
M("*XU]'@V.C8(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@(K_>W-[H(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U
M>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(KO>T]C@T/K5(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I
M9"`B7TQO9R!O=70B"FUS9W-T<B`BN-?;U=<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-
M;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*
M;7-G<W1R("*WT.?CTM#X(-[?YMC8(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS
M9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY
M"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`BOM3AXN#0W=@@W]#@
M(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ
M>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(K#4X-7AT.`B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D
M<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,3,*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A
M;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O
M<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I
M9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF
M:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@
M9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F
M86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R("*]T.';
MWM(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@
M(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I
M9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y
M"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R("*XW-4B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M
M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED
M(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*
M;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R
M;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T
M<B`BLMW8W-#=V-4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I
M9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T
M96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED
M(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B
M=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*
M;7-G<W1R("+!U=K>U2#?X-CXT-+CTM#ZU2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@
M(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H
M97(N8V]M(@IM<V=S='(@(B(*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M;R]N8E].3RYP;P``````````````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P-C8U-#(V`#$P-#$W,S8S,#`R`#`Q-C0P,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C($YO<G=E9VEA
M;B!(;W)D92!4<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$M,C`P
M,B!(;W)D92!0<F]J96-T+@HC($]Y<W1E:6X@4W1E:6UL97(@/&]Y<W1E:6Y`
M<F5X=&$N;F5T/BP@,C`P,2X*(R!4;W)S=&5I;B!3+B!(86YS96X@/&AU;&5B
M;V5R0'1E8VAB964N;F\^+"`R,#`R+@HC($%N9')E87,@1W5N;&5I:W-K86%S
M(#QA;F1R96%S0&=U;FQE:6MS:V%A<RYN;SXL(#(P,#,N"B,@1V5I<B!/+B!(
M;V=B97)G(#QH;W)D94!S:WED:79E<BYN;SXL(#(P,#4N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"XT7&XB
M"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN
M(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,#4M,3@@,3(Z-#,K,#(P,%QN
M(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-2TQ."`Q-#HS-RLP,C`P7&XB
M"B),87-T+51R86YS;&%T;W(Z($=E:7(@3RX@2&]G8F5R9R`\:&]R9&5`<VMY
M9&EV97(N;F\^7&XB"B),86YG=6%G92U496%M.B!.;W)W96=I86X@*$)O:VUA
M;"D@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q
M+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M
M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#D*;7-G:60@(B(*(B`@+4TL("TM
M;65S<V%G93U-15-304=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G92!I;G-T
M96%D(&]F('1H92!D969A=6QT(&]N97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HU,PIM<V=I9"`B(@HB("`M82P@+2UA9&0]1DE,12`@
M("`@("`@061D('1H:7,@4$\@9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E
M9G5L('1O7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E(&$@
M8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T;UQN(@HB("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R871E9"!C;VUP96YD:75M
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$S"FUS9VED
M("(B"B(@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@<&%T:"!T;R!T:&4@*$AO
M<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L9"!B95QN(@HB("`@("`@
M("`@("`@("`@("`@("!U<V5D+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-CD*;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U&24Q%
M("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N9&EU;2!F
M:6QE7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T
M:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE7&XB"B(@("`@
M("`@("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C,@<&\O=')A;G-L871I
M;VXN<&AP.C@Q('!O+W1R86YS;&%T:6]N+G!H<#HX-PIM<V=I9"`B(@HB("`M
M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL
M92!I;G-T96%D(&]F('1H92!D969A=6QT7&XB"B(@("`@("`@("`@("`@("`@
M("`@("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D
M:7)E8W1O<GDI+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3$T"FUS9VED("(@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S
M<V%G97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I97,N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-`IM<V=I9"`B("`M9"P@+2UD:7)E
M8W1O<GD]1$E2("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,34*;7-G
M:60@(B`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0R('!O+W1R
M86YS;&%T:6]N+G!H<#HV-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-S4*;7-G:60@
M(B`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W('!O+W1R
M86YS;&%T:6]N+G!H<#HV,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-SD*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C@U"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#
M0R`@("`@57-E('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-34*;7-G:60@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@
M(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C8X"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0G5I
M;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0S"FUS9VED("(@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-#@*;7-G:60@(B(*(B`@+6TL("TM;6]D=6QE/4U/1%5,
M12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E
M*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV
M,@IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-R96%T92!A(%!/
M(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@P"FUS9VED("(@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@365R9V4@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C<V"FUS9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D
M871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V"FUS9VED("(@
M("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&]N;'D@=&AI<R`H2&]R
M9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C4X"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@($=E;F5R871E(%!/
M5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,`IM<V=I9"`B(@HB("`M;BP@
M+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T<F%N<VQA=&EO
M;G,@=&\@=&AE(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HV-"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(@<&\O=')A;G-L
M871I;VXN<&AP.C@X"FUS9VED("(@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@
M1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C<Q"FUS9VED("(@("US+"`M+7-T871I<W1I8W,@("`@
M("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-@IM<V=I
M9"`B("`M="P@+2UT97-T("`@("`@("!3:&]W('1H92!E>&5C=71E9"!C;VUM
M86YD<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3`U"FUS9VED("(B"B(@(&-L96%N=7`@("`@
M($-L96%N<R!T:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS;&%T960@86YD
M(&]B<V]L971E(&5N=')I97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,#@*;7-G:60@(B`@8V]M;6ET("`@("`@0V]M;6ET('1R86YS
M;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P.0IM<V=I9"`B("!C;VUM:70M:&5L<"!#;VUM
M:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.CDY"FUS9VED("(B"B(@(&-O;7!E;F1I
M=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I=6T@9FEL92X@5V%R;FEN9SH@5&AI
M<R!O=F5R=W)I=&5S('1H95QN(@HB("`@("`@("`@("`@("!C=7)R96YT(&-O
M;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#`*;7-G:60@(B`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA=&4@
M*"YP;W0I(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z.3@*;7-G:60@(B`@:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,0IM
M<V=I9"`B(@HB("!I;FET("`@("`@("!#<F5A=&4@;VYE(&]R(&UO<F4@4$\@
M9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI<UQN(@HB("`@
M("`@("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O
M9B!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P-@IM<V=I9"`B("!M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@
M9FEL97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I;&5S+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W"FUS9VED("(B"B(@(&UA:V4M
M:&5L<"`@($UA<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@
M8F5I;F<@=7`M=&\M9&%T92!A;F1<;B(*(B`@("`@("`@("`@("`@<')E<&%R
M92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T92UH
M96QP+B!9;W5<;B(*(B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA
M:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE7&XB
M"B(@("`@("`@("`@("`@(&AE;'`@9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P,@IM<V=I9"`B(@HB("!M97)G92`@("`@("!-
M97)G92!T:&4@8W5R<F5N="!03R!F:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@
M=&5M<&QA=&4@9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P,PIM<V=I9"`B("!U<&1A=&4@("`@("!2=6X@97AT<F%C="!A;F0@
M;65R9V4@<V5Q=65N="XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P-`IM<V=I9"`B(@HB("!U<&1A=&4M:&5L<"!%>'1R86-T(&%L;"!N
M97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H(%A-3"!H
M96QP7&XB"B(@("`@("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET
M:"!T:&4@97AI<W1I;F<@;VYE<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RXB"FUS9W-T
M<B`B(@HB("8C,34Q.R`E<R!E<B!K;&%R(&9O<B#E('5T9OAR92!V961L:6ME
M:&]L9'-O<&5R87-J;VYE;F4@<V]M(&5R('9A;&=T("(*(FYE9&5N9F]R+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S4R"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@9&%G97(@<VED96XI
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*&AU<G1I9W1A<W0@)7,I(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-C`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&EN;F5N("5S(&1A9V5R*2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S4V"FUS9VED("(@*'1O9&%Y*2(*
M;7-G<W1R("(@*&D@9&%G*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S4X
M"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&D@;6]R9V5N*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,S4T"FUS9VED("(@*'EE<W1E<F1A>2DB
M"FUS9W-T<B`B("AI(&?E<BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$T"FUS9VED("(@870@(@IM<V=S='(@(B!D96X@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@;V<@)7,B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3$V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!B>71E<R!W<FET=&5N+B(*;7-G<W1R("(E9"!B>71E<R!S:W)E=F5T+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C8U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4B"FUS
M9W-T<B`B)60@878@)60@;W!P9OAR:6YG97(@;6%R:V5T('-O;2!O<'!D871E
M<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UD
M86=E<G,@=F%R<V5L(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC
M95]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B
M"FUS9W-T<B`B)7,@+2!4:6P@:6YF;R(*"B,Z('1E;7!L871E<R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!A9&UI;FES=')A<VIO;B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S(X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S($9I;F=E<G!R:6YT
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U-R!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T
M<B`B)7,@=F5D;&EK96AO;&1S;W!E<F%S:F]N97(@+2!"96MR969T96QS92(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G
M<W1R("(E<R!I;G-T:6QL:6YG97(B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(W-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM
M<V=S='(@(B5S(')E9VES=')E<FEN9R(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]A9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!A=G1A;&5V:6QK
MY7(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z-3DV(&QI8B]61E,O9G1P+G!H<#HV
M-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B5S(&9I;FYE<R!A;&QE<F5D92XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U-R!L:6(O0FQO8VLO;65T87(N<&AP.C$V,R!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S-PHC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,R!L:6(O
M0FQO8VLO;65T87(N<&AP.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M="`E<R`E<R(*;7-G<W1R("(E<R!PY2`E<R`E<R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!H87,@8V%N8V5L;&5D("5S+B(*;7-G<W1R("(E<R!H87(@:V%N
M<V5L;&5R="`E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI
M960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B)7,@:&%R(&)E
M<W9A<G0@96X@9F]R97-P^')S96P@;VT@:6YF;W)M87-J;VX@86YGY65N9&4@
M;&5D:6<O;W!P=&%T="XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E
M<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@(B5S(&AA
M<B!S=F%R="!PY2!I;G9I=&%S:F]N96X@=&EL("5S+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(E<R!H87(@<V5N9'0@9&5G(&EN9F]R;6%S:F]N(&]M(&QE
M9&EG+V]P<'1A='0N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(X-R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES
M(&YO="!W<FET86)L92XB"FUS9W-T<B`B)7,@97(@<VMR:79E8F5S:WET=&5T
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S(R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&5R('#E:W)E=F0B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T=&5R(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3,S,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(B5S(&EK:V4@9G5N;F5T+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B!2
M=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I<G-T+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(&9O<F5S</AR(&EN9F]R;6%S:F]N
M(&]M(&[E<B!D=2!E<B!L961I9R]O<'1T871T+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R
M("(E<R!F;W)E<W#X<B!D:6X@9&5L=&%G96QS92!PY2`E<RXB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHV"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S("T@)7,@878@)7,B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%D9"!T;R`E<RXB"FUS
M9W-T<B`B)7,@^&YS:V5R(.4@;&5G9V4@=&EL("5S+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM
M<V=S='(@(B5S(/AN<VME<B#E(&=J^')E(&1E9R!O<'!M97)K<V]M('#E("5S
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@<F5C96EV92!T
M:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+B(*;7-G<W1R("(E<R#X
M;G-K97(@Y2!M;W1T82!D96X@<VES="!O<'!D871E<G1E(&EN9F]R;6%S:F]N
M96X@;VT@)7,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B061D
M<F5S<V5B;VL@9F]R("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+
M86QE;F1E<B!F;W(@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B3F]T
M871B;&]K:R!F;W(@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(D]P
M<&=A=F5L:7-T92!F;W(@)7,B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B](;W)D92]#3$DN<&AP
M.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G(&ES(&YO="!A('9A;&ED
M(&-H;VEC92XB"FUS9W-T<B`B)R5S)R!E<B!I:VME(&5T(&=Y;&1I9R!V86QG
M+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-3@R(&QI8B](;W)D92]2
M96=I<W1R>2YP:'`Z.3@R"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@:7,@
M;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R
M("(G)7,G(&5R(&EK:V4@8V]N9FEG=7)E<G0@:2!(;W)D92!296=I<W1E<F5T
M+B(*"B,Z(&QI8B](;W)D92]4<F5E+G!H<#HQ-C`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B<E<R<@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B5S(&EK:V4@9G5N;F5T+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@861D960@=&\@=&AE
M(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B5S(&)L92!L86=T('1I;"!G<G5P
M<&5S>7-T96UE="XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!B;&4@;&%G="!T:6P@
M<F5T=&EG:&5T<W-Y<W1E;65T+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G
M:60@(B<E<R<@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B)7,@8FQE
M(&EK:V4@;W!P<F5T=&5T.B`E<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$X-B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B5S('#E("5S
M("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@
M=F%R:6%B96P@;65L;&]M("5S(&]G("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P-3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3(*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8Y,0IM<V=I9"`B+2T@<V5L96-T
M("TM(@IM<V=S='(@(BTM('9E;&<@+2TB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3,P.2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,Q,0IM<V=I9"`B+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B
M,3(@5&EM97)S(&9O<FUA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM
M<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@5&EM97)S(&9O<FUA
M="(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H
M;W5R<R(*;7-G<W1R("(R-"!T:6UE<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB/&=E='1E>'0^('1A9R!N
M;W0@8VQO<V5D(&EN(&9I;&4@)7,N7&XB"B)/<&5N:6YG('1A9R!F;W5N9"!I
M;B!L:6YE("5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$Q-PIM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")%;B!D871A8F%S96MO8FQI;F<@97(@
M<.5K<F5V9"!F;W(@9&5N;F4@8FQO:VME;BXB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$V-@IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T
M<B`B16X@9F%T86P@9F5I;"!H87(@;W!P<W3E='0B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HY-#$*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(D5N(&]F
M9F5N=&QI9R!01U`M;OAK:V5L(&5R('#E:W)E=F0@9F]R(.4@:W)Y<'1E<F4@
M;65L9&EN9V5N+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-C<*
M;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI9R!01U`M
M;OAK:V5L(&5R('#E:W)E=F0@9F]R(.4@=F5R:69I<V5R92!S:6=N97)T(&UE
M;&1I;F<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.`IM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!01U`M;OAK:V5L+"!P<FEV
M870@4$=0+6[X:VME;"!O9R!P87-S<&AR87-E(&5R('#E:W)E=F0@9F]R(.4@
M(@HB9&5K<GEP=&5R92!E;B!M96QD:6YG+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$P,3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)%;B!O9F9E;G1L:6<@
M4$=0+6[X:VME;"P@<')I=F%T(%!'4"UN^&MK96P@;V<@<&%S<W!H<F%S92!E
M<B!PY6MR979D(&9O<B#E("(*(G-I9VYE<F4@96X@;65L9&EN9RXB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!3+TU)344M;OAK:V5L+"!P<FEV870@
M4R]-24U%+6[X:VME;"P@;V<@<&%S<W!H<F%S92!E<B!PY6MR979D("(*(F9O
M<B#E(&1E:W)Y<'1E<F4@96X@;65L9&EN9RXB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C0T.0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5N(&]F
M9F5N=&QI9R!3+TU)344M;OAK:V5L+"!P<FEV870@4R]-24U%+6[X:VME;"P@
M;V<@<&%S<W!H<F%S92!E<B!PY6MR979D("(*(F9O<B#E('-I9VYE<F4@96X@
M;65L9&EN9RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X,@IM
M<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4R]-24U%+6[X
M:VME;"!E<B!PY6MR979D(&9O<B#E(&MR>7!T97)E(&5N(&UE;&1I;F<N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R-0HC+"!F=7IZ>0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R(")296=N('#E(&9O<FUI9&1A9V5N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R-@HC+"!F=7IZ>0IM
M<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")296=N8GEG97(@<.4@9F]R;6ED
M9&%G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(W"B,L
M(&9U>GIY"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4V[X8GEG
M97(@<.4@9F]R;6ED9&%G96XB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P-`IM<V=I9"`B05!)($E$(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D]M
M(&1E;FYE(&5D:71O<F5N(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D]M+BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S
M8F]T=&]M(@IM<V=S='(@(D%B<V]L=71T(&YE9&5R<W0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`B06)S;VQU='0@;6ED="(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,`IM<V=I9"`B06-C97!T(')E
M<75E<W0B"FUS9W-T<B`B1V]D:VIE;FX@9F]R97-P^')S96PB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#$*;7-G:60@(D%C
M8V5P=&5D(@IM<V=S='(@(D=O9'1A='0B"@HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HR.#4*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B5&EL9V%N9R!N96MT970@=F5D(&]P<')E='1E;'-E
M(&%V(%9&4R!K871A;&]G+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$S.`IM
M<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T
M<B`B5&EL9V%N9R!N96MT970@=F5D(&]P<')E='1E;'-E(&%V(%9&4R!F:6PN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT
M(%!A<W-W;W)D(@IM<V=S='(@(DMO;G1O(%!A<W-O<F0B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B06-C;W5N="!F
M<F]Z96XN(@IM<V=S='(@(DMO;G1O(&9R^'-E="XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@
M(D)O:VAO;&1I;F<O06-C;W5N=&EN9R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C0U,0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HV,C4*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B
M2&%N9&QI;F=E<B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU-"!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$S-@HC.B!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI
M;F,Z,38*;7-G:60@(D%D9"(*;7-G<W1R("),96=G('1I;"(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"FUS9VED(")!
M9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B3&5G9R!T:6P@=6YD97)G<G5P<&4B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@Q(&QI8B](;W)D92]097)M
M<R]522YP:'`Z.#(*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S
M='(@(DQE9V<@=&EL('5N9&5R<F5T=&EG:&5T97(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(DQE
M9V<@=&EL(&AE<CHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(P."!A9&UI;B]G
M<F]U<',N<&AP.C(P.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("),
M96=G('1I;"!N>2!G<G5P<&4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C<P(&QI8B](;W)D92]097)M<R]522YP:'`Z-S$*;7-G:60@(D%D9"!.97<@
M4&5R;6ES<VEO;B(*;7-G<W1R("),96=G('1I;"!N>2!R971T:6=H970B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHY"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O("<E<R<B"FUS
M9W-T<B`B3&5G9R!T:6P@96X@=6YD97)G<G5P<&4@=&EL("<E<R<B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3,@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R
M;6ES<VEO;B!T;R`G)7,G(@IM<V=S='(@(DQE9V<@=&EL('5N9&5R<F5T=&EG
M:&5T('1I;"`G)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D
M9"!A(&YE=R!U<V5R.B(*;7-G<W1R("),96=G('1I;"!N>2!B<G5K97(Z(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0IM<V=I
M9"`B061D(&-O;'5M;B(*;7-G<W1R("),96=G('1I;"!K;VQO;FYE(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B061D
M(&YE=R!M96UB97)S(@IM<V=S='(@(DQE9V<@=&EL(&YY92!M961L96UM97(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B061D
M('!A:7(B"FUS9W-T<B`B3&5G9R!T:6P@<&%R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S
M($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B3&5G9R!T:6P@
M)7,@;65N>65N('-O;2!-;WII;&QA(%-I9&5B87(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,S$*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C,W"FUS9VED(")!9&0@=&AI<R!T
M;R!M>2!C86QE;F1A<B(*;7-G<W1R("),96=G('1I;"!I(&UI;B!K86QE;F1E
M<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S0*;7-G
M:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(DQE9V<@=&EL(&D@
M861D<F5S<V5B;VLZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HX,0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("),96=G('1I;"!I(&UI;B!A9&1R97-S96)O:R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("),96=G('1I;"!B<G5K
M97(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!9&1E9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E(@HB<RXB"FUS
M9W-T<B`B(@HB3&$@=&EL("<E<R<@:2!S>7-T96UE="P@;65N(&MU;FYE(&EK
M:V4@;&5G9V4@=&EL(&5K<W1R82!R96=I<W1R97)I;F=S:6YF;SH@)2(*(G,N
M(@H*(SH@<VEG;G5P+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E
M9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS
M9W-T<B`B3&$@)R5S)R!T:6P@<WES=&5M970N($1U(&MA;B!L;V=G92!I;FX@
M;N4N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDU-@IM<V=I9"`B061D:6YG
M(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.B(*;7-G<W1R("),82!T:6P@;GEE
M(&9I;&5R(&D@<F5P;W-I=&]R>3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;V%D9"YI;F,Z-`IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+B(*;7-G<W1R(")-=6QI9VAE="!F;W(@Y2!L96=G92!T:6P@;GEE(&)R=6ME
M<F4@97(@9&5A:W1I=F5R="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30S
M."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R.0HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W-@IM<V=I9"`B061D<F5S
M<R(*;7-G<W1R(")!9')E<W-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$S-`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V4@
M0F]K(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDW"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R(")!9&UI;FES=')E<B`M('-E='0@<F5T=&EG:&5T97(@
M9F]R(&%N9')E(&)R=6ME<F4B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B061M:6YI<W1R87-J;VXB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`V"FUS9VED(")!9',B"FUS9W-T<B`B4F5K;&%M
M97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;&)A
M;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3`*;7-G:60@(D%L
M:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T
M<B`B2G5S=&5R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B2G5S=&5R
M:6YG.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL
M(@IM<V=S='(@(D%L;&4B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3@@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE
M;G1I8V%T960@57-E<G,B"FUS9W-T<B`B06QL92!A=71E;G1I<V5R=&4@8G)U
M:V5R92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H
M<#HR,3(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B06QL92!'<G5P<&5R
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-S0*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R
M(")!;&QE(')E9&1I9VAE=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED
M97,B"FUS9W-T<B`B06QL92!F:7)E('-I9&5R(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-34*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*
M;7-G<W1R(")4:6QL871T(&9L97)E(&%D<F5S<V5R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R,PIM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B5&EL;&%T="!E;F1R:6YG(&%V(&9O
M<FUA=&5T('#E(&YU;6UE<F5R=&4@;&ES=&5R/R(*"B,Z(&QI8B](;W)D92]$
M871A5')E92]S<6PN<&AP.C0P,PIM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B16MS:7-T97)E<B!A;&QE<F5D92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C(*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S
M='(@(D%L=&5R;F%T:78@24U34"!,;V=I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.38*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM
M<V=S='(@(D%L=&5R;F%T:79T($E-4U`@<&%S<V]R9"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.#@*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N
M86UE(@IM<V=S='(@(D%L=&5R;F%T:79T($E-4U`@8G)U:V5R;F%V;B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA
M=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA=&EV(&4M<&]S="!A
M9')E<W-E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L
M=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N871I=F4@;6%L97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")!
M;'1E<FYA=&EV('1E:W-T.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.3<@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HQ,3<*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"XB"FUS9W-T<B`B16X@=6QO=FQI9R!V97)D:2!V87(@;W!P
M9VET="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%N9V]L
M82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,C`*;7-G:60@(D%N;VYY;6]U<R!0
M<F]X>2(*;7-G<W1R(")!;F]N>6T@4')O>'DB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E-V87(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N=&EG=6$@
M86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S`@;&EB+TAO<F1E+T)L;V-K+U5)
M+G!H<#HU.0HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV
M"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")0<F]G<F%M(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T
M(@IM<V=S='(@(E!R;V=R86UL:7-T92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,S`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R
M(")0<F]G<F%M;65T(&5R(&ML87)T+B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS
M9W-T<B`B3W!P9&%T97(@;V=SY2!R96MU<G-I=G0@;F5D;W9E<B!F;W(@=6YD
M97)M87!P97(O9FEL97(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHS,PIM<V=I9"`B07!P<F]V92(*;7-G<W1R(")';V1K:F5N;B(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3<*;7-G:60@(D%P
M<')O>&EM871E(%-I>F4B"FUS9W-T<B`B3VUT<F5N=&QI9R!S=/AR<F5L<V4B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R
M:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S$*;7-G
M:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B1FEL
M<W3X<G)E;'-E('#E(&%R:VEV970B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV,2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B
M07)C:&EV92!.86UE(@IM<V=S='(@(D%R:VEV;F%V;B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")%<B!D=2!324M+15(@
M<.4@870@9'4@=FEL(&9J97)N92!R96=I<W1R97)I;F=S9F]R97-P^')S96QE
M;B!F;W(@)7,_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T
M<B`B17(@9'4@<VEK:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@)R5S)R!O9R!D
M96YS('5N9&5R9W)U<'!E<C\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W,@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B
M"FUS9W-T<B`B2W5N<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS
M9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@:W5N<W0B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$U
M"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B0F4@;VT@8F5K<F5F=&5L
M<V4@9OAR(&=J96YN;VUF^')I;F<@878@=F5D;&EK96AO;&1S;W!E<F%S:F]N
M97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y.`IM<V=I9"`B07-S:6=N
M;65N="!C;VQU;6YS(@IM<V=S='(@(DMO;&]N;F5A;G9I<VYI;F<B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ-C8*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C0Y"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,Q.`IM<V=I9"`B071T
M86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T
M('EO=2!S96YT(@IM<V=S='(@(E9E9&QA9W0@:2!S=F%R970@97(@96X@:4-A
M;&5N9&%R(&9I;"!F;W(@96X@9F]R97-P^')S96P@9'4@<V5N9'1E(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW-0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(D9O<G/X:W1E(.4@<VQE
M='1E(&5N(&=R=7!P92!S;VT@:6MK92!E:W-I<W1E<F5R+B(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z,S@*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D9O<G/X:W1E
M(.4@<VQE='1E(&5N(')E='1I9VAE="!S;VT@:6MK92!E:W-I<W1E<F5R+B(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.CDX"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1F]R
M<_AK=&4@Y2!R961I9V5R92!E;B!R971T:6=H970@<V]M(&EK:V4@96MS:7-T
M97)E<BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T
M<B`B1F]R<_AK=&4@Y2!R961I9V5R92!E;B!D96QT(')E<W-U<G,@<V]M(&EK
M:V4@96MS:7-T97)E<BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU-S<*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R(")$96QT
M86=E<F4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-R!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R(")!='1R:6)U="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B075S=')A;&EA
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`BV'-T97)R:6ME
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ-C,*;7-G:60@(D%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?8WER<W%L.B!+86X@:6MK92!F:6YN92!D96X@;OAD
M=F5N9&EG92!)34%0('5T=FED96QS96XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER=7,N<&AP.C$S-PIM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H
M7V-Y<G5S.B!"86-K96YD(&EN;F5H87(@:6MK92!N^&1V96YD:6<@9G5N:W-J
M;VYA;&ET970N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R-`IM
M<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!+86X@:6MK92!F:6YN92!D
M96X@;OAD=F5N9&EG92!)34%0('5T=FED96QS96XN(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O9G1P+G!H<#HT,`IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T
M<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@1E10('5T=FED96QS
M96XN($MO;7!I;&5R(%!(4"!M960@+2TB"B)E;F%B;&4M9G1P+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VEM87`N<&AP.C8X"FUS9VED(")!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]I;6%P.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!)34%0('5T
M=FED96QS96XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3,*;7-G
M:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z($MA;B!I:VME(&9I;FYE(&1E;B!N
M^&1V96YD:6=E(&MR8C4@=71V:61E;'-E;BXB"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HV,0IM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N
M(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@3$1!4"!U='9I9&5L<V5N+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$X.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A
M<#H@2W5N;F4@:6MK92!L96=G92!T:6P@8G)U:V5R("5S+B!397)V97)E;B!S
M83H@(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2W5N;F4@:6MK92!F:F5R;F4@8G)U
M:V5R96X@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR.#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!+=6YN92!I:VME(&]P<&1A
M=&5R92!B<G5K97(@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU
M,`IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@2V%N(&EK:V4@9FEN;F4@
M9&5N(&[X9'9E;F1I9V4@34-!3"!U='9I9&5L<V5N+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-M8BYP:'`Z-C4*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7W-M8F%U=&@Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E('-M8F%U
M=&@@=71V:61E;'-E;BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.0IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S
M='(@(D%U=&5N=&ES97)I;F<@9F5I;&5T(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HV.2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,B"FUS9W-T<B`B075T96YT:7-E<FEN9R!F96EL970N("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ.#$*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S
M='(@(D%U=&5N=&ES97)I;F<@;F5K=&5T(&%V(%)!1$E54R!T:F5N97(N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C@P,`IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@
M;6]T($944"!T:F5N97)E;B!F96EL970N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHX,PIM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T
M<B`B5&EL9VIE;F=E;&EG92!F96QT.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8Q-`IM<V=I9"`B07=A:71I;F<@4F5S<&]N
M<V4B"FUS9W-T<B`B5F5N=&5R('#E('-V87(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")!>F5R8F%I:F%N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I
M9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@17AC=7-E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*
M;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B0F%K9W)U;FXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"
M86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D)A:V=R=6YN<V9A<F=E(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O
M<R!P87-S=V]R9"XB"FUS9W-T<B`B1F5I;"!K97)B97)O<R!P87-S;W)D+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")"860@:V5R
M8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(D9E:6P@:V5R8F5R;W,@8G)U:V5R
M;F%V;BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:')A
M:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S,*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A
M;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3,*;7-G:60@(D)A<F4B"FUS
M9W-T<B`B0FQA;FLB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S
M)R!N;W0@9F]U;F0N(@IM<V=S='(@(D)A<V5K871A;&]G(&9O<B!G<F%F:6MK
M("<E<R<@8FQE(&EK:V4@9G5N;F5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B
M"FUS9W-T<B`B1W)U;FYL:6YJ92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QI9V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")"96QI
M>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F5R;75D82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,30*;7-G:60@
M(D)I<G1H9&%Y(@IM<V=S='(@(D)U<G-D86<B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")";&]K:R!<(B5S7"(@878@<')O9W)A;6UE="!<(B5S7"(@8FQE
M(&EK:V4@9G5N;F5T+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO:VL@:6YN
M<W1I;&QI;F=E<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW
M-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")";&]K:R!T>7!E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED
M(")";VQD(@IM<V=S='(@(D9E="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-@IM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(D)O:VUE<FME<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R(")286UM92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM
M<V=S='(@(E)A;6UE='EK:V5L<V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*
M;7-G<W1R(")286UM97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I
M9"`B0F]T:"(*;7-G<W1R(")"96=G92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D)O='-W86YA(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)U;FXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)R87II;"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<S"B,L('!H<"UF;W)M
M870*;7-G:60@(D)U:6QD:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES
M="(*;7-G<W1R(")0=6YK=&QI<W1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G5R:VEN82!&87-O(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,Y-PIM<V=I9"`B0TU3(@IM<V=S='(@(D--
M4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED
M(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV,C$*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S
M='(@(D-23"!$:7-T<FEB=7-J;VYS<'5N:W1E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B
M0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")%9V5N<VMA<&5R(&9O<B!C
M7V5L;&4N+BXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4V(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#,*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P.0IM<V=I9"`B0V%L;2(*;7-G<W1R(")3=&EL;&4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%M97)O;VXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*
M;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DMA;B!I:VME
M(&YU;&QS=&EL;&4@<&%S<V]R9"!A=71O;6%T:7-K+"!K;VYT86MT(&1I;B!A
M9&UI;FES=')A=&]R+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR
M-#$@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS
M9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL($E-05`@=&IE;F5R96XZ("5S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M-PIM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%V8G)Y="(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B079B<GET('!R;V)L96UR87!P;W)T(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C(V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!S;&5T
M=&4@9FEL96X@7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0W"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,PIM<V=I9"`B0V%N;F]T
M(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK
M92!F:6YN92!E;B!T96UP+6MA=&%L;V<N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.CDW"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DMA;B!I:VME(&9O<G1S971T
M92!U=&5N("=T87)G971&:6QE)R!P87)A;65T97(N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME('-L971T92!K
M871A;&]G96X@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z
M,3$R(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4W.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB
M"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E+"`E9"!B87)N(&5K<VES=&5R97(N
M(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED("(B
M"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB
M"FUS9W-T<B`B(@HB2V%N(&EK:V4@96YD<F4@<F5K:V5F^&QG96XL(&%N=&%L
M;&5T(&]P<&;X<FEN9V5R('9A;&=T(&9O<B!O;7-O<G1E<FEN9R`B"B)S=&5M
M;65R(&EK:V4@;65D(&%N=&%L;&5T(&QA9W)E9&4@;W!P9OAR:6YG97(N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3@*;7-G:60@
M(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM
M<V=S='(@(DMA;B!I:VME('-E;F1E(&UE;&1I;F=E;B!T:6P@9&5T('-P97-I
M9FES97)T92!N=6UM97)E="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B571D<F%G(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N
M9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEE<B!O9R!E=&EK971T97(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3<*;7-G:60@(D-E;&P@4&AO;F4B
M"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P
M97)T:65S(@IM<V=S='(@(D5G96YS:V%P97(@9F]R(&-E;&QE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@
M(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B3'5F="!R=6YD="!I;FYH;VQD(&%V
M(&-E;&QE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R
M(")%9V5N<VMA<&5R(&9O<B!C96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z
M(@IM<V=S='(@(DQU9G0@<G5N9'0@8V5L;&5N.B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C8V"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36]B:6QT
M96QE9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G:60@(D-E
M;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E
M;G1E<B(*;7-G<W1R(")396YT97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S4*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S(S"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(D1E=&%L:F5R(&9O<B!S
M97)T:69I:V%T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C`*
M;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E)E='1N:6YG
M<VQI;FIE<B!F;W(@<V5R=&EF:6MA="(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B0VAA9"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M.38*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R(")/<F1S='ER97(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDW"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B16YD
M<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G
M<W1R("(B"B)%;F1R92!N879N(&]G(&%D<F5S<V4@<V]M(&UO='1A:V5R92!S
M97(@;N5R(&1E(&QE<V5R(&]G('-V87)E<B!PY2!P;W-T96X@9&EN+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B5&5G;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B
M0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B4VIE:U]K(&QI;FLN+BXB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED
M(")#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT
M('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")696QG(&1E(&]P
M97)A<VIO;F5N92!D=2!V:6P@=71F^')E(&[E+B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H:6QE(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<V"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*
M;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C@R"FUS9VED(")#:&]O
M<V4@82!P87-S=V]R9"(*;7-G<W1R(")696QG(&5T="!P87-S;W)D(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR.#$*;7-G:60@(D-H;V]S92!A
M('5S97)N86UE(@IM<V=S='(@(E9E;&<@971T(&)R=6ME<FYA=FXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3(*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C(V"FUS9VED(")#
M:&]O<V4@86X@86-T:6]N.B(*;7-G<W1R(")696QG(&AA;F1L:6YG.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.#@*;7-G:60@(D-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B5F5L9R!H=F]R9&%N(&1U('9I
M;"!V:7-E(&1A=&]E<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B5F5L9R!S
M=&EL('#E(&QI<W1E='EP92`H9F]R(&YU;6UE<F5R=&4@;&ES=&5R*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4RYP
M:'`Z-C4U(&QI8B].970O4TU3+G!H<#HS,3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(DML87-S961E9FEN:7-J;VX@9F]R("5S(&)L92!I:VME(&9U;FYE="XB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4U"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C@*;7-G:60@(D-L
M96%R(@IM<V=S='(@(DML87)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G
M<R(*;7-G<W1R(")&:F5R;B!-4T]F9FEC92!T86=S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(D9J97)N(&)R=6ME<CH@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,38*;7-G:60@
M(D-L96%R('5S97(B"FUS9W-T<B`B1FIE<FX@8G)U:V5R(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S<*;7-G:60@(D-L96%R('5S97(@
M9&%T82(*;7-G<W1R(")&:F5R;B!B<G5K97)D871A(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VYO=&EC95]B;W1T;VTN:6YC.C8*;7-G:60@(D-L:6-K
M('1O($-O;G1I;G5E(@IM<V=S='(@(DML:6MK(&9O<B#E(&9O<G1S971T92(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@V"FUS9VED
M(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@=FEA
M($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G
M<W1R("),=6MK('9I;F1U(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#(*
M;7-G:60@(D-L;W5D<R(*;7-G<W1R(")3:WEE<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,CD*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")3
M:WEE="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z-`IM<V=I9"`B
M0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")3;.4@<V%M;65N('-I9&5L:6YJ
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")3
M86UM96YS;.5T="!R86UM92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")&87)G92(*"B,Z(&QI
M8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HR.3<@;&EB+TAO<F1E+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C(Y.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#<R('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-3$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-3(*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-CD*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z.#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z.#8*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")&87)G979E
M;&=E<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#,U"FUS9VED(")#;VQO
M=7(@<V5L96-T:6]N(@IM<V=S='(@(D9A<F=E=F%L9R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"B,L(&9U>GIY"FUS
M9VED(")#;VQS.B(*;7-G<W1R(")+;VQO;FYE<CHB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DS,`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")+
M;VQO;FYE+71I=&QE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M.#D*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")496=N97-E<FEE<B(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")+
M;VUM86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R(")+;VUM86YD;W9I;F1U(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C,X"FUS9VED(")#;VUM86YD(&]P=&EO;G,Z(@IM<V=S
M='(@(E9A;&<@9F]R(&MO;6UA;F1O.B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HY-PIM<V=I9"`B0V]M;6%N9',Z(@IM<V=S='(@(DMO;6UA;F1O97(Z(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,SDY"FUS9VED(")#;VUM96YT
M(@IM<V=S='(@(DMO;6UE;G1A<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY
M.34*;7-G:60@(D-O;6UI='1I;F<Z(@IM<V=S='(@(E-J96MK(&EN;CHB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,`IM<V=I9"`B0V]M;6]N
M($YA;64B"FUS9W-T<B`B5F%N;&EG(&YA=FXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B0V]M;W)O<R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(T,@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y-PIM<V=I9"`B0V]M
M<&QE=&5D(@IM<V=S='(@(D9E<F1I9R(*"B,Z(&QI8B](;W)D92]497AT+T9I
M;'1E<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I
M;',N<&AP.C@W"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP
M.CDW(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VUP;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R
M(")3:W)I=B!M96QD:6YG("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")$871A;6%S:VEN97(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-PIM<V=I9"`B0V]N9&ET:6]N
M<R(*;7-G<W1R(")6:6QKY7(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HX
M.0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")&
M;W)S:VIE;&QE<B!I(&EN;G-T:6QL:6YG96YE(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$R-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!N965D<R!U<&1A
M=&EN9RXB"FUS9W-T<B`B26YN<W1I;&QI;F=E<B!B96CX=F5R(&]P<&1A=&5R
M:6YG+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HY.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B2V]N9FEG=7)E<B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S<*;7-G
M:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0F5K<F5F="!P87-S;W)D
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`V(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,3D*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M+B(*;7-G<W1R(")4:6QK;V)L:6YG(&UI<VQY:W1E<RXB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`V(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,3D*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B
M"FUS9W-T<B`B5&EL:V]B;&EN9R!M:7-L>6MT97,Z("(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C<Y,PIM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")+;V)L:6YG96X@
M=&EL(&1E;B!O9F9E;G1L:6=E(&[X:VME;'1J96YE<F5N(&9E:6QE="XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B2V]B;&EN9V5N('1I;"!D
M96X@;V9F96YT;&EG92!N^&MK96QT:F5N97)E;B!F96EL970N(,5R<V%K.B`E
M<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<Y-`IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B2V]B;&EN9V5N
M('1I;"!&5%`@=&IE;F5R96X@;6ES;'EK=&5S+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-38*;7-G:60@(D-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R(")+;VYT86MT96YE(&)L92!L86=T('1I;"!A9')E<W-E8F]K96XB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.2!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O
M9B`G)7,G(@IM<V=S='(@(DEN;FAO;&0@:2`G)7,G(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@
M(D9O<G1S971T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S
M='(@(D-O;VMI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")+;W!I
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W!I97(@=F%L
M9W0@;VURY61E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]P>6EN9R`E<R!T;R`E<R(*;7-G<W1R(")+;W!I
M97)E<B`E<R!T:6P@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK92!01U`M:W)Y<'1E<F4@
M;65L9&EN9R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-34*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R(")+=6YN
M92!I:VME(%!'4"US:6=N97)E(&UE;&1I;F<B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C0Q,0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R
M>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK:V4@:W)Y<'1E<F4@;65L
M9&EN9V5N(&UE9"!3+TU)344N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HT.#4*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E
M+B(*;7-G<W1R(")+=6YN92!I:VME('-I9VYE<F4@;65L9&EN9V5N(&UE9"!3
M+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N
M("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;&5G9V4@=&EL(&MO;G1A:W0Z("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3$S"FUS9VED(")#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B5&EL:V]B;&EN
M9R!T:6P@3$1!4"US97)V97(@9F5I;&5T+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ-30@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H
M96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@<VIE:VME('1I
M;&=J96YG96QI9R!K<F5D:71T+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DML87)T
M92!I:VME(.4@:V]B;&4@=&EL('1J96YE<F5N("<E<R<@=F5D(&)R=6L@878@
M1E10.B`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<U"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C;W!Y("5S('1O("5S(@IM<V=S='(@
M(DMU;FYE(&EK:V4@:V]P:65R92`E<R!T:6P@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(DMU;FYE(&EK:V4@;&%G92!D:7-T<FEB=7-J;VYS;&ES=&4N("5S(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&QO
M8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SHB"FUS9W-T<B`B2W5N;F4@
M:6MK92!O<'!R971T92!L;V-A;&4@:V%T86QO9R!F;W(@;&]C86QE("5S.B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C8*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(")+=6YN92!I:VME(&1E
M:W)Y<'1E<F4@4$=0(&UE;&1I;F<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-#`*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D
M871A+B(*;7-G<W1R(")+=6YN92!I:VME(&1E:W)Y<'1E<F4@4R]-24U%(&UE
M;&1I;F<N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(U
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(DML87)T92!I:VME(.4@<VQE='1E(&MO;G1A:W0N
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,V-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+;&%R=&4@:6MK92#E('-L971T92!D
M:7-T<FEB=7-J;VYS;&ES=&4N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R(")+=6YN92!I
M:VME('-L971T92!S971U<"!O<'!G<F%D97)I;F=S<V-R:7!T("<E<R<N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.3D@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z.34Y"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!F:6YN92!M;W1T86ME<G,@92UP;W-T(&%D<F5S<V4N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X.`IM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2W5N
M;F4@:6MK92!H96YT92!U="!H96QE(&%D<F5S<V5B;VME;BXB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$P"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(DMU;FYE(&EK:V4@=70@:&5L92!D:7-T<FEB=7-J;VYS;&ES=&5N+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-C$*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I
M;VX@;&ES=',N(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@=70@:&5L92!L
M:7-T96X@;65D(&1I<W1R:6)U<VIO;G-L:7-T97(N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.0HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S)RXB"FUS
M9W-T<B`B2W5N;F4@:6MK92!L87-T92!I;FX@<W1R871E9VD@)R5S)RXB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ,3$*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V1I<F5C="YP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&UK9&ER("<E<R<N(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!P<F5T=&4@:V%T
M86QO9V5N("<E<R<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S(P
M"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@
M:V5Y<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&]F9F5N
M=&QI9R!N^&MK96P@9G)A(&[X:VME;'1J96YE<F5N+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HW,#(@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@Y7!N92`E<RXB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)R5S
M)R!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2W5N;F4@:6MK92#E<&YE("<E<R<@
M9F]R('-K<FEV:6YG+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-#$U"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DMA;B!I:VME(.5P;F4@
M36%I;G1E;F%N8V5?5&%S:RUM;V1U;&5N("5S(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@Y7!N92!K871A;&]G96X@)R5S)RXB"@HC.B!L
M:6(O5D93+T]B:F5C="YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(")+=6YN92!I:VME(&QE<V4@)7,B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB
M0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E
M9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T
M(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M(DMU;FYE(&EK:V4@;G5L;'-T:6QL92!P87-S;W)D970@9F]R(&1E;B!F;W)E
M<W!U<G1E(&)R=6ME<F5N+B!.;V5N(&5L;&5R(&%L;&4@(@HB9&5T86QJ96YE
M(&5R('5R:6MT:6=E+B!&;W)S^&L@:6=J96X@96QL97(@:V]N=&%K="!A9&UI
M;FES=')A=&]R96X@:'9I<R!D=2`B"B)T<F5N9V5R('ET=&5R;&EG97)E(&AJ
M96QP+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3@@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T.0HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@V(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.3(*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Y.`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R(")+=6YN92!I:VME(&AE;G1E('5T($%#3"(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B
M2W5N;F4@:6MK92!H96YT92!U="!A9')E<W-E8F]K+B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&1I<W1R:6)U<VIO;G-L
M:7-T92X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#4R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N
M=&4@=70@9&ES=')I8G5S:F]N<VQI<W1E+B`E<R(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,#8@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(R-@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C,P"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@=70@:6YF;W)M
M87-J;VX@;VT@=&IE;F5R96YS(&9U;FMS:F]N86QI=&5T97(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@<F5V97)T97)E
M(&MO;F9I9W5R87-J;VYE;F4N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')M9&ER("<E<R<N(@IM<V=S='(@(DMU;FYE(&EK:V4@
M9FIE<FYE(&MA=&%L;V=E;B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G<F4@
M)7,@:V]N9FEG=7)A<VIO;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!L86=R92!E;B!B86-K=7`@:V]N9FEG=7)A<VIO;BXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R
M(")+=6YN92!I:VME(&QA9W)E(&5N(&)A8VMU<"!C;VYF:6=U<F%S:F]N.B`E
M<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDR"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B`G)7,G+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9W)E('-E='5P(&]P
M<&=R861E<FEN9W,M<V-R:7!T970@=&EL.B`G)7,G+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@;&%G<F4@8F%C:W5P(&MO;F9I9W5R87-J;VYS
M9FEL96X@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H
M92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B
M"B)+=6YN92!I:VME(&QA9W)E(&MO;F9I9W5R87-J;VYS9FEL96X@)7,N($1U
M(&MA;B!E;G1E;B!B96YY='1E(&1E9R!A=B!E;B!A=B`B"B)M=6QI9VAE=&5N
M92!F;W(@Y2!L86=R92!D871A('1I;&)A:V4@=&EL("5S(&5L;&5R(&MO<&EE
M<F4@:V]D96X@=6YD97(@(@HB;6%N=65L="!T:6P@)7,N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z,3(S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!U=&;X<F4@
M<_AK('#E($Q$05`@=&IE;F5R96XN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5N;&EN:R`G)7,G+B(*;7-G<W1R(")+=6YN92!I
M:VME(&9J97)N92`G)7,G+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&]P<&1A=&5R
M92!K;VYT86MT+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!O
M<'!D871E<F4@9&ES=')I8G5S:F]N<VQI<W1E;BX@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E<R<Z("5S(@IM<V=S='(@
M(DMU;FYE(&EK:V4@<VMR:79E(&MO;F9I9W5R87-J;VX@9F]R("<E<R<Z("5S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-@IM<V=I9"`B0V]U;&1N
M)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I
M9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!F:6YN92!-;WII
M;&QA(%-I9&5B87(N(%-J96MK(&%T(&1E;B!E<B#E<&5N+B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R
M:6=H=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,B"FUS9W-T<B`B0G)U:V5R
M96X@)R5S)R!B;&4@9VET="!F^&QG96YD92!R971T:6=H971E<B!T:6P@;6%P
M<&5N("<E<R<Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,38*;7-G
M:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")486QT('1E:W-T(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(D-O=6YT<GDB"FUS
M9W-T<B`B3&%N9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*
M;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B2W5R<V5R(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q"FUS
M9VED(")#<F5A=&4B"FUS9W-T<B`B3W!P<F5T="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B
M0W)E871E(&$@;&EN:R(*;7-G<W1R(")/<'!R971T(&5N(&QI;FLB"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.C@Y"FUS9VED(")#
M<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D]P<')E='0@96X@;GDB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.34*;7-G:60@(D-R96%T
M92!S=6(@9F]L9&5R<R(*;7-G<W1R(")/<'!R971T('5N9&5R;6%P<&5R(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,V(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,C(R"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(E)E='1I9VAE=&5R(&9O<B!E:65R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,R,34*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R(")+<F5D
M:71T:V]R=&YU;6UE<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V
M"FUS9VED(")#=7)R96YT(%!H87-E(@IM<V=S='(@(D=J96QD96YD92!F87-E
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP
M.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B1VIE;&1E;F1E('1I
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B1VIE;&1E;F1E(%523"!E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")':F5L9&5N
M9&4@=N9R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM
M<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")':F5L9&5N9&4@
M=71S:6MT97(Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B1VIE
M;&1E;F1E('-T:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O
M;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B5&EL<&%S<R!O<'!G879E<B!S;VT@
M:VKX<F5S('9E9"!I;FYL;V=G:6YG('1I;"`E<RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@
M(D-U="(*;7-G<W1R(")+;&EP<"!U="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB
M"FUS9W-T<B`B2VQI<'`@=70@=F%L9W0@;VURY61E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(DMY<')O<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*
M;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(S('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&QI8B](;W)D
M92]-86EN=&5N86YC92YP:'`Z,S@*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1A
M9VQI9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@
M(D1A=&$B"FUS9W-T<B`B1&%T82(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV
M-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")$871A5')E('5T
M9F]R<VME<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S@R(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<W"FUS9VED(")$871E(@IM<V=S
M='(@(D1A=&\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ,@IM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")$871O($UO='1A
M='0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B1&%T92!S
M96QE8W1I;VXB"FUS9W-T<B`B1&%T;R!V86QG(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(W-PIM<V=I9"`B1&%Y(@IM<V=S='(@(D1A9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B4VQE='0@
M:V]L;VYN92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS
M9VED(")$96-E;6)E<B(*;7-G<W1R(")$97-E;6)E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G
M:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(")$97-I;6%L=&%L;"(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X-0IM<V=I
M9"`B1&5C;&EN960B"FUS9W-T<B`B079S;.5T="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R(")2961U<V5R(&EN;G)Y:VLB"@HC.B!L:6(O<')E
M9G,N<&AP.C$P."!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Y,0IM<V=I9"`B
M1&5F875L="(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0W"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(E-T86YD87)D(&9A<F=E(@H*(SH@;&EB+TAO<F1E+TED
M96YT:71Y+G!H<#HY,@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R
M(")3=&%N9&%R9&ED96YT:71E="(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$Q.2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-`IM<V=I9"`B1&5F875L
M="!097)M:7-S:6]N<R(*;7-G<W1R(")3=&%N9&%R9"!R971T:6=H971E<B(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`U"FUS9VED(")$969A=6QT
M('!E<FUI<W-I;VYS(@IM<V=S='(@(E-T86YD87)D(')E='1I9VAE=&5R(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N
M<R(*;7-G<W1R(")$969I;FES:F]N97(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HV-#,*;7-G:60@(D1E;&5G871E('!O<VET
M:6]N(@IM<V=S='(@(D1E;&5G97(@<&]S:7-J;VXB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.3,*;7-G:60@(D1E;&5G871E
M9"(*;7-G<W1R(")$96QE9V5R="(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S(@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4R"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDW(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,S(W"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S0W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3D@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,T"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4VQE='0B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$X.2!A9&UI;B]G<F]U<',N<&AP.C(Q-PIM<V=I
M9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E-L971T(&=R=7!P92(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-C`@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HX-`IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4VQE='0@
M<F5T=&EG:&5T(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDV"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(E-L971T(&]G(&9J97)N(&UE;&1I;F=E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T
M92!C96QL(@IM<V=S='(@(E-L971T(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L
M971E(&-O;'5M;B(*;7-G<W1R(")3;&5T="!K;VQO;FYE(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B4VQE='0@96MS:7-T97)E;F1E(&%L
M=&5R;F%T:78@;6%L(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,"!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`B1FIE<FX@
M<F5T=&EG:&5T96YE('1I;"`G)7,G(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M(")&:F5R;B!R971T:6=H971E;F4@=&EL("<E<R<@;V<@86QL92!U;F1E<BUR
M971T:6=H971E<C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@
M(E-L971T(')A9"(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET
M>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G
M<W1R(")3;&5T="!V86QG="!I9&5N=&ET970B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(D1E
M;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B4VQE='0@9VIE;&1E
M;F1E(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!R;W<B"FUS9W-T<B`B4VQE='0@9VIE;&1E;F1E(')A9"(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#@*;7-G:60@(D1E;&5T92!T:&ES('!E<FUI
M<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E-L971T
M92!D96YN92!R971T:6=H971E;B!O9R!A;&QE('5N9&5R+7)E='1I9VAE=&5R
M/R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB
M"FUS9W-T<B`B4VQE='0@<V5T=7`@;W!P9W)A9&5R:6YG<RUS8W)I<'0@)R5S
M)RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@U(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,3D*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-C$*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T
M<B`B3&5V97)I;F=S=&ED(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$86YM
M87)K(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-C0R"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B079S;.4@9F]R97-P
M^')S96PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HT-S$*;7-G:60@(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N(@IM<V=S='(@(D%V<VSE(&9O<F5S</AR<V5L(&9O<B!L961I9R]O
M<'!T871T+6EN9F]R;6%S:F]N(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M.34@<V5R=FEC97,O<')O8FQE;2YP:'`Z.3D@<V5R=FEC97,O<')O8FQE;2YP
M:'`Z,3`Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")"
M97-K<FEV('!R;V)L96UE="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,S,@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*
M;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)E<VMR:79E;'-E(@H*(SH@
M;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T86QJ97(@*&]G<^4@:2!(;W)D
M92=S(&QO9V=F:6PI.B(*"B,Z(&QI8B](;W)D92YP:'`Z,C`U"FUS9VED(")$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R(")$971A;&IE<B!H87(@8FQI='0@;&]G9V5T(&9O<B!A9&UI
M;FES=')A=&]R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y
M,PIM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B571V:6ML:6YG(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,34*;7-G:60@(D1E=R!0;VEN="(*;7-G
M<W1R(")$;V=G<'5N:W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,@IM
M<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")$;V=G
M<'5N:W0@9F]R(&1E;B!S:7-T92!T:6UE;CH@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Y,`IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T
M<B`B1&]G9W!U;FMT.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M="(*;7-G<W1R(")2971N:6YG(&9R82!V96YS=')E(&UO="!H^'ER92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G
M:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(E)E=&YI;F<@
M9G)A(&CX>7)E(&UO="!V96YS=')E(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(*;7-G<W1R(")6:7,@,C0M=&EM97)S('1I9&5R/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I
M;VYS(@IM<V=S='(@(E9I<VYI;F=S=F%L9R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z.#,*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T
M<B`B5FES(&9O<G9A<G-E;"`H5$%&*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#`V"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")6:7-N:6YG
M<V9O<FUA="(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,C`S"FUS9VED
M(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B365L9&EN9R!O
M;2!O<F1N:6YG(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,R-PIM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(")):VME('-L971T
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(T"FUS9VED(")$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("))
M:VME(.5P;F4@;6%I;F5N86YC92YP:'`@9&ER96MT92(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$Y('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$Y"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@
M9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@
M(DMR>7-S(&%V(&AE<B!H=FES(&1E;B!F^')S=&4@<F%D96X@:6YN96AO;&1E
M<B!F96QT+6YA=FYE=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C@V.`IM<V=I9"`B1&]W;FQO860B"FUS
M9W-T<B`B3&%S="!N960B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E
M<R(*;7-G<W1R("),87-T(&YE9"`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-38*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(DQA<W0@;F5D(&=E;F5R97)T
M(&MO;F9I9W5R87-J;VX@<V]M(%!(4"!S8W)I<'0N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P.3$*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@
M(DYE9'1R96MK<VQI<W1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T
M"FUS9VED(")$<G5G<R(*;7-G<W1R(")-961I<VEN97(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HS.3D*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%
M+7!O<W0B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S<*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDV
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET(@IM<V=S='(@
M(E)E9&EG97(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4Q('1E;7!L
M871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@(D5D:70@0FQO8VLB"FUS
M9W-T<B`B4F5D:6=E<F4@8FQO:VLB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X
M."!A9&UI;B]G<F]U<',N<&AP.C(Q-@IM<V=I9"`B161I="!'<F]U<"(*;7-G
M<W1R(")2961I9V5R($=R=7!P92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z-3D@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX,PIM<V=I9"`B161I="!0
M97)M:7-S:6]N(@IM<V=S='(@(E)E9&EG97(@<F5T=&EG:&5T97(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(E)E9&EG97(@<F5T=&EG:'1E<B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B4F5D:6=E<B!R971T
M:6=H971E<B!F;W(@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHY
M"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")2961I9V5R('9A
M;&<@9F]R.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B4F5D:6=E<B!R971T:6=H971E<B!F;W(@)7,B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HR,#0@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR.#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)R5S
M)R(*;7-G<W1R(")2961I9V5R(')E='1I9VAE=&5R(&9O<B`E<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S
M='(@(D]P<&SF<FEN9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I
M9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")%;&5M
M96YT+BXN(@IM<V=S='(@(D5L96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T
M<B`B16TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U,R!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R-PIM<V=I9"`B16UA:6PB"FUS9W-T
M<B`B12UP;W-T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#D@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0P"FUS9VED(")%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(D4M<&]S=&%D<F5S<V4B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3DT-PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(D4M<&]S=&%D<F5S<V4@;>4@<W1E;6UE+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.3<S"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")%+7!O<W0@;65D(&)E:W)E9G1E;'-E(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X,`IM<V=I9"`B16UO
M=&EC;VYS(@IM<V=S='(@(D;X;&5L<V5R(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM
M<V=S='(@(E1O;2!M96QD:6YG+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C$S,0IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")4;VUT(')E
M<W5L=&%T+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$Q-`IM
M<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E3X;2!S^&ME:W)I
M=&5R:65R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,@IM<V=I9"`B
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\B"FUS9W-T<B`B06MT:79E<B!M=6QI9VAE="!F;W(@Y2!S
M971T92!I;FX@8FEL9&5R(&9R82!G86QL97)I97(@:2!T96MS=&5N/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D5N86)L92!R:6=H
M="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K=&EV97)E(&CX>7)E
M:VQI:VL@;65N>3\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT-#@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-34S"FUS9VED(")%;F0B"FUS9W-T<B`B4VQU='0B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C4Y,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,`IM
M<V=I9"`B16YD('EE87(B"FUS9W-T<B`BQ7)S<VQU='0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA
M<F=E($5D:71O<B(*;7-G<W1R(")':OAR(&5D:71O<F5N('-T^')R92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3$*;7-G:60@(B(*(D5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B)3:W)I
M=B!I;FX@971T('-I:VME<FAE='-S</AR<VWE;"!S;VT@9'4@=FEL(&)L:2!S
M<'5R="!O;2!H=FES(&1U(/AN<VME<B#E("(*(FYU;&QS=&EL;&4@<&%S<V]R
M9&5T(&1I='0L(&8N96MS+B`G:'9A(&5R(&YA=FYE="!PY2!K:N9L961Y<F5T
M(&1I='0_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!5
M4DP@:&5R92(*;7-G<W1R(")3:W)I=B!I;FX@861R97-S96X@=&EL(&)I;&1E
M="!H97(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@
M)60@;F5W+"`E9"!C:&%N9V5D+"`E9"!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D5R:71R
M96$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3$*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C<X"FUS9VED(")%<G)O<B(*;7-G<W1R(")&96EL(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DU"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(W.`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(D9E:6P@=F5D
M('-E;F1I;F<@878@<W9A<CH@)7,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+B(*;7-G<W1R(")&96EL(&UE9"!E+7!O<W0@;65L9&EN9V5N+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG("<E<R<N
M(@IM<V=S='(@(D9E:6P@=F5D('-K<FEV:6YG('1I;"`G)7,G+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I;VXN<&AP.C4R,B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3,U.`HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,30Q.2!P;R]T<F%N<VQA=&EO;BYP:'`Z,30X,@IM<V=I9"`B17)R;W(Z("(*
M;7-G<W1R(")&96EL.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R
M;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R.0IM<V=I9"`B179E
M<GD@,34@;6EN=71E<R(*;7-G<W1R(")(=F5R="`Q-2X@;6EN=71T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B179E<GD@,B!M:6YU
M=&5S(@IM<V=S='(@(DAV97)T(#(N(&UI;G5T="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I
M9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")(=F5R="`S,"X@<V5K=6YD
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R."!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@P"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B
M2'9E<G0@-2X@;6EN=71T(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HS.0IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B2'9E<B!I;FYL;V=G
M:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,`IM<V=I9"`B179E
M<GD@:&%L9B!H;W5R(@IM<V=S='(@(DAV97(@:&%L=G1I;64B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S(W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")(=F5R="!M:6YU='0B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR.`IM<V=I9"`B17AA
M;7!L92!V86QU97,Z(@IM<V=S='(@(D5K<V5M<&5L=F5R9&EE<CHB"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-S8@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S8*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B
M2VKX<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR.3D@<&\O=')A;G-L871I
M;VXN<&AP.C,R,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,S8R"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HT-#$@<&\O=')A;G-L871I;VXN<&AP.C4T,2!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-C`Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,#(@<&\O
M=')A;G-L871I;VXN<&AP.C<S-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-SDX"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HX-S4@<&\O=')A;G-L871I;VXN<&AP.CDX
M.2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Q,0IM<V=I9"`B17AE8W5T:6YG.B(*
M;7-G<W1R(")+:OAR97(Z(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z,S@V"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B571V:60B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A;F0@4VED
M96)A<B(*;7-G<W1R(")5='9I9"!3:61E8F%R(@H*(SH@;&EB+TAO<F1E+U-1
M3"]+97EW;W)D<RYP:'`Z,38Y"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T
M<B`B1F]R=F5N=&5T("<I)R(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.C$W-@IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;2(*;7-G<W1R(")&;W)V96YT970@8FQA;FMT(&]R9"!E;&QE
M<B!Q=6]T970@<_AK96MR:71E<FEE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,SDX"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B571L
M^'!S9&%T;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`P"FUS
M9VED(")%>'!O;F5N="(*;7-G<W1R(")%:W-P;VYE;G0B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5X=')A8W1I
M;F<@9G)O;2`E<RXN+B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L
M;W(B"FUS9W-T<B`B1F]R9W)U;FYS9F%R9V4B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<Q"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S
M='(@(D]P<&QA<W1I;F<@878@<V5T=7`@=FEA($944"(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]S<6PN<&AP.C(T,`IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N(@IM<V=S='(@(E5T:&5N=&EN9R!A=B!I;G-T:6QL:6YG
M97(@9F5I;&5T+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$P,PIM
M<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(E1I;&MO8FQI;F<@=&EL($Q$05`M=&IE;F5R(&9E:6QE="XB"@HC.B!L
M:6(O2&]R9&4O075T:"]S;6(N<&AP.C$P,PIM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B5&EL:V]B;&EN9R!T:6P@
M4TU"+71J96YE<B!F96EL970N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8S,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<
M(BXB"FUS9W-T<B`B1F5I;&5T('9E9"!K;W!I97)I;F<@9G)A(%PB)7-<(BXB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C,V"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B1F5I;&5T('9E
M9"!K;W!I97)I;F<@=&EL(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O075T:"]S
M87-L+G!H<#HY,@IM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+B(*;7-G<W1R(")&96EL970@=F5D(&]P<')E='1E;'-E(&%V
M(&YY(%-!4TP@:V]B;&EN9RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB
M"FUS9W-T<B`B1F5I;&5T('9E9"!F;'ET=&EN9R!T:6P@7"(E<UPB+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(D9A:7(B
M"FUS9W-T<B`B4&5N="!VYG(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-
M86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR,S4*;7-G:60@(D9A=&%L
M($5R<F]R.B(*;7-G<W1R(")&871A;"!&96EL.B`B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B1F%X(@IM<V=S='(@
M(D9A>"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-S4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED
M(")&96)R=6%R>2(*;7-G<W1R(")&96)R=6%R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,3@*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B1OAL97,@
M<V]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y-`IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(D;X;&5S('-O;3H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,0IM<V=I9"`B1F5W(%-H;W=E
M<G,B"FUS9W-T<B`B1N4@8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S,R"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(D;E('-N^&)Y9V5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y,C@*;7-G
M:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")&96QT;6%T<FES92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9I:FDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")!;G1A;&P@
M9FEL97(Z("5S(&9I;&5R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B06YT86QL
M(&9I;&5R.B`E<R!F:6QE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&:6QB96AA;F1L
M97(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@
M(D9I;&YA=FXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDX,`IM<V=I9"`B
M1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B1FEL=F%L9R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#@S"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("),
M87-T(&]P<"!F:6QE<B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-S0*
M;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")/
M<'!L87-T:6YG(&%V(&9I;&5R('-T^'1T97,@:6MK92XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.#8*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B
M1FEL=&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<Q"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(D;X
M<G-T92!H86QV;>5N92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`B1OAR<W1E(&MV87)T;>5N92(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")&
M87-T(&9O<FAO;&0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C$T"FUS9VED(")&;&EP(@IM<V=S='(@(E-N=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G
M:60@(D9L;V%T(@IM<V=S='(@(D9L>70B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S,S"FUS9VED(")&;V<B"FUS9W-T<B`B5.5K92(*"B,Z
M(&QI8B]61E,O<W%L+G!H<#HQ-C,@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`X"B,L
M('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*
M;7-G<W1R(")-87!P96X@)7,@96MS:7-T97)E<B!I:VME(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N
M="!#;VQO<B(*;7-G<W1R(")&;VYT9F%R9V4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B36%T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(*;7-G<W1R(")&;W(@;F5T=&QE<V5R92!S;VT@:6MK92!S=/AT=&5R
M(&)I;&1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,R"FUS9VED(")&
M;W)E8V%S="`H5$%&*2(*;7-G<W1R(")&;W)V87)S96P@*%1!1BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0*;7-G:60@(B(*(D9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB
M06YT86QL(&1A9V5R<R!F;W)V87)S96P@*';F<B!O8G,@<.4@870@9&5T(')E
M='5R;F5R=&4@9F]R=F%R<VQE="!I;FYE:&]L9&5R("(*(F+E9&4@9&%G(&]G
M(&YA='0[(&5N('-T;W(@=F5R9&D@:&5R(&MA;B!R97-U;'1E<F4@:2!E;B!S
M=&]R(&)L;VMK*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.34*
M;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")';&5M="!P
M87-S;W)D970_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM
M<V=I9"`B1F]R;7,B"FUS9W-T<B`B4VMJ96UA97(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B4VMJ96)N
M92]L>6MK92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B
M1F]R='5N92!T>7!E(@IM<V=S='(@(E1Y<&4@<VMJ96)N92]L>6MK92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS
M9W-T<B`B4VMJ96)N97(O;'EK:V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B4VMJ96)N97(O;'EK
M:V4@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,30*;7-G:60@
M(D9O<G5M<R(*;7-G<W1R(")&;W)U;65R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,U.`IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5FED97)E
M<V5N9'1E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F]U;F0@87!P;&EC871I;VYS.B`E<R(*;7-G<W1R(")&
M86YT('!R;V=R86UM96YE.B`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M-#,S"FUS9VED(")&;W5N9"!D:7)E8W1O<FEE<SHB"FUS9W-T<B`B1F%N="!K
M871A;&]G96YE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(D9R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I
M9"`B1G)A;65S(@IM<V=S='(@(E)A;6UE<B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R86YC92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$W"FUS9VED(")&<F5E+T)U
M<WD@26YF;W)M871I;VXB"FUS9W-T<B`B3&5D:6<O;W!P=&%T="UI;F9O<FUA
M<VIO;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0R-PIM<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(DQE9&EG+V]P
M<'1A='0@<W9A<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C0R,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B
M3&5D:6<O;W!P=&%T="!F;W)E<W#X<G-E;"(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C(W,@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HS-#$*;7-G:60@(D9R964O0G5S>2!297%U
M97-T(%)E<W!O;G-E(@IM<V=S='(@(E-V87(@<.4@;&5D:6<O;W!P=&%T="!F
M;W)E<W#X<G-E;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*
M;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")&
M<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-SD*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B1G)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q,0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D9R82`B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C
M<FEP=&EO;B(*;7-G<W1R(")&=6QL(&)E<VMR:79E;'-E(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@R(&QI8B]";&]C:R]M;V]N+G!H<#HQ.#$*;7-G:60@
M(D9U;&P@36]O;B(*;7-G<W1R(")&=6QL;>5N92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,SD*;7-G:60@(D9U;&P@3F%M92(*;7-G
M<W1R(")&=6QL="!N879N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM
M<V=I9"`B1G5Z>GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V%B;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;2(*;7-G<W1R(")'86QL97)I(&1U(/AN<VME<B#E(&AE;G1E(&)I;&1E(&9R
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L;&5R
M:3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R97(@)7,@:V]N9FEG=7)A
M<VIO;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HQ
M,`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N97)E<G0@:V]D
M92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D=E<FUA
M;GDB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-3(*;7-G
M:60@(D=E=&]P="!%<G)O<CH@(@IM<V=S='(@(D=E=&]P="!&96EL.B`B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")':6)R86QT87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@
M(D=I=F5N($YA;64B"FUS9W-T<B`B1VET="!.879N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,38*;7-G:60@(D=O(@IM<V=S='(@(D=O(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O
M9VQE(%-E87)C:"(*;7-G<W1R(")3^&L@<.4@1V]O9VQE(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`IM<V=I9"`B1W)A>7-C
M86QE(@IM<V=S='(@(D=RY71O;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W)E96-E(@IM<V=S='(@
M(DAE;&QA<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")'
M<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96YL86YD
M(@IM<V=S='(@(D=R^&YL86YD(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W,`IM<V=I9"`B1W)O=7`@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B1W)U<'!E(&%D;6EN:7-T<F%S:F]N(@H*(SH@
M;&EB+TAO<F1E+T=R;W5P+G!H<#HU-PIM<V=I9"`B1W)O=7`@;F%M97,@;75S
M="!B92!N;VXM96UP='DB"FUS9W-T<B`B1W)U<'!E;F%V;B!K86X@:6MK92!V
MYG)E('1O;6UE(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`Q(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C@U"FUS9VED(")'<F]U<"!P97)M:7-S:6]N
M<R(*;7-G<W1R(")'<G5P<&5R971T:6=H971E<B(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$W-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U."!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!P97(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6%M(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C<@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR,3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I
M9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5T=&EG:&5T97(@9F]R
M(&=J97-T(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(X(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,C$T"FUS9VED(")'=65S="!P97)M:7-S:6]N<R(*
M;7-G<W1R(")2971T:6=H971E<B!F;W(@9VIE<W0B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B
M1VIE<W1E8F]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D=U>6%N82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S,Q"FUS9VED(")(2"(*;7-G<W1R(")(2"(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY-34*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!N96MT97(@Y2!S
M;&5T=&4@9&5N('-I<W1E(&-E;&QE;B!I(&5N(')A9"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YE:W1E<B#E
M('-L971T92!D96X@<VES=&4@:V]L;VYN96X@:2!T86)E;&QE;BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YE:W1E
M<B#E('-L971T92!D96X@<VES=&4@<F%D96X@:2!T86)E;&QE;BXB"@HC.B!L
M:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-C0*;7-G:60@(DA45%`@075T:&5N
M=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10(&%U=&5N=&ES97)I
M;F<@:6MK92!F=6YN970N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HS.3D*;7-G:60@(DAA<V@M06QG
M;W)I=&AM(@IM<V=S='(@(DAA<V@M86QG;W)I=&UE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,S-`IM<V=I9"`B2&%Z92(*;7-G<W1R(")$
M:7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3$T(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3(Q"FUS9VED(")(96%D97(B"FUS9W-T<B`B2&]D92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")(96)R97<@
M*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT
M(@IM<V=S='(@(DCX>61E(@H*(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$W.2!L
M:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C$W"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP
M(@IM<V=S='(@(DAJ96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS
M9W-T<B`B2&IE;'`@=&EL(&)R=6L@878@961I=&]R(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S-C@*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")(:F5L<&5R
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDU"FUS9VED("(B"B)(96QP97(@
M87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO
M;G,@9F]R('1H92!(;W)D95QN(@HB9G)A;65W;W)K(&%N9"!I=',@87!P;&EC
M871I;VYS+EQN(@HB1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H92!F:6QE
M(%)%041-12!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@
M(DAA;'9K=6QE(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3<@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(DAE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B2&5R(&5R(&)E
M9WEN;F5L<V5N('#E(&9I;&5N.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-S8*;7-G:60@(DAI9V@B"FUS9W-T<B`B2/AY(@H*(SH@;&EB
M+TAO<F1E+TAI<W1O<GDN<&AP.C,R,@IM<V=I9"`B2&ES=&]R>2!E;G1R>2!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")(:7-T;W)I96]P<&;X
M<FEN9V5R('#E(&AA(&YA=FX@<V]M(&EK:V4@97(@=&]M;64B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO
M;BUH96%D97(N:6YC.C0*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAJ95]M(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#8V"FUS9VED(")(;VUE(@IM<V=S
M='(@(DAJ96TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U.`IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DAJ96UM96%D<F5S<V4B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,PIM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R(")496QE9F]N(&AJ96UM92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&]N
M9'5R87,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8R"FUS9VED(")(;W)D
M92(*;7-G<W1R(")(;W)D92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S$P
M"FUS9VED(")(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N
M=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@56=Y
M;&1I9R`E<R!834P@9&%T82!F=6YN970@:2!M96QD:6YG("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HR-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F=E;B!M96QD:6YG('!A<W-E<B!M
M960@;V)J96MT970@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@26YT970@;V)J96MT(&%V('1Y<&5N("5S(&9U;FYE="!I(&UE;&1I
M;F<@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@1FIE<FYE="`E<R!<
M(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O
M;FES960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!3>6YK<F]N
M:7-E<G1E("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@26YT96=R87-J;VYS;6]T;W)E;B!K<F5V97(@4$A0("=D
M;VUX;6PG('5T=FED96QS92(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@Q
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!+=6YN92!I:VME(&]P<')E='1E(&YY='0@6$U,('1R92!F
M;W(@;V)J96MT970@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2W5N
M;F4@:6MK92!F:F5R;F4@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@
M='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2W5N;F4@:6MK92!H96YT
M92!-24U%($E$(&9O<B!D96QE;B!A=B!T>7!E("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@2W5N;F4@:6MK92!S>6YK<F]N:7-E<F4@)7,@
M7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,Q,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MU;FYE
M(&EK:V4@<WEN:W)O;FES97)E(&1E;'1E(')E<W-U<G-E<CH@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(%5K:F5N="!D96QT(')E<W-U<G,@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(DAO<FES;VYT86P@;&EN:F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS
M9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B2&]R:7-O;G1A;"!P
M861D:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7-O;G1A
M;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(DAV;W)D86X@:V]M(&1U(&AI=#\@*%9E
M;FYL:6=S="!R87!P;W)T97(A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(DAV;W(@
M;6%N9V4@:V]L;VYN97(@^&YS:V5R(&1U(.4@<VSE('-A;6UE;C\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR.`IM<V=I9"`B2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DAV;W(@;6%N
M9V4@9F5L=&5R("AK;VQO;FYE<BD@97(@9&5T/R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(DAV;W(@;6%N9V4@<F%D97(@^&YS:V5R(&1U(.4@<VSE('-A;6UE;C\B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R.`IM<V=I9"`B2'5M:61I='DB"FUS
M9W-T<B`B1G5K=&EG:&5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q-PIM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")&=6MT:6=H970Z
M("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I
M<W1S(@IM<V=S='(@(DAU;6]R:7-T97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DAU;F=A<GDB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W-B!L:6(O
M2&]R9&4O075T:"]C>7)S<6PN<&AP.C(R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")/
M<'!R971T96QS92!A=B!)34%0('!O<W1B;VMS(&9E:6QE=#H@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C(P(&QI8B](;W)D92]!=71H+V-Y
M<G-Q;"YP:'`Z,C@X"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-L971T:6YG(&%V($E-
M05`@<&]S=&)O:W-E;B!F96EL970Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER=7,N<&AP.C$X,R!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")/<'!R971T96QS92!A=B!K=F]T92!P
MY2!)34%0('!O<W1B;VMS(&9E:6QE=#H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3,Q,@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!!9')E
M<W-E(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z.#(*;7-G:60@
M(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@061R97-S
M92!I:VME('1I;&=J96YG96QI9RXB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A
M<VEC+G!H<#HY-`IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@061R97-S92!I:VME(&EN;F5N
M9F]R('1I;&%T=&4@0TE$4B!B;&]K:RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T
M:6]N+B(*;7-G<W1R(")"<G5D9"!PY2!)4"!L;V-K9&]W;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")37V5T="!I;FX@
M;GD@<F%D(&;X<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED("))8V]N<R!/;FQY(@IM
M<V=S='(@(DMU;B!I:V]N97(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@
M(DEK;VYE<B!F;W(@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W
M"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;F5R(&UE9"!T
M96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#`*;7-G:60@(DED
M96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B261E;G1I=&5T96YS(&YA=FXZ(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C8P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(DAV:7,@
M9&5N(&EK:V4@=FES97,@<FEK=&EG+"`E<R!F;W(@Y2#E<&YE(&D@;GET="!V
M:6YD=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0U"FUS9VED("(B
M"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(DAV:7,@
M9'4@:6MK92!S97(@;F]E;B!I:V]N97(@;N5R(&1U(&)E;GET=&5R($EN=&5R
M;F5T($5X<&QO<F5R+"!K86X@9&5T("(*(FAE;F1E(&1U('1R96YG97(@Y2!K
M<GES<V4@878@9&5N;F4@8F]K<V5N(&9O<B#E('-K<G4@878@=')A;G-P87)E
M;G0@4$Y'+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-3@*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)(
M=FES(&1U('-E<B!D96YN92!M96QD:6YG96X@;65N(&EN=&5T(&)I;&1E+"!K
M86X@9&5T(&AE;F1E(&%T(&)I;&1E="!D=2!V:6P@(@HB;&%S=&4@;W!P(&EK
M:V4@:V%N('9I<V5S(&D@9&EN(&YE='1L97-E<BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN9R!A
M=B!B:6QD93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B0FEL
M9&5A9')E<W-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S
M='(@(D)I;&1E861R97-S93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R
M;VT@9V%L;&5R>2(*;7-G<W1R(")":6QD92!F<F$@9V%L;&5R:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")":6QD
M92!F<F$@9V%L;&5R:3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<T.0IM
M<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D]P<&QA<W1I;F<@878@8FEL
M9&4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S
M(@IM<V=S='(@(D)I;&1E<B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$P('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$P"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-3<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D
M(@IM<V=S='(@(DEM<&]R=&5R:6YG+"!S=&5G("5D(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R=&5R=&4@9F5L=#H@)7,B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<S"FUS9VED("));7!O
M<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R=&5R=&4@9F5L=#HB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#$*;7-G:60@
M(DEN(%!R;V-E<W,B"FUS9W-T<B`B56YD97(@87)B96ED(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS
M9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")?4V5T="!I;FX@<F%D
M(&5T=&5R(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,30Q"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D9E
M:6P@:&%N9&QI;F=S:V]D92!G:71T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-3<*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5G>6QD:6<@8G)U:V5R;F%V;B!O
M9R]E;&QE<B!P87-S;W)D+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(D9E:6P@8G)U:V5R;F%V;B!E;&QE<B!A;'1E<FYA=&EV(&%D<F5S<V4N
M(%9E;FYL:6=S="!F;W)S^&L@:6=J96X@96QL97(@(@HB:V]N=&%K="!S>7-T
M96UA9&UI;FES=')A=&]R96X@9&EN(&9O<B!Y='1E<FQI9V5R97)E(&AJ96QP
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("+8:R!I;FYR>6MK
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@R"FUS9VED("));F1I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ-#$@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G
M:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B26YD:79I9'5E;&QE(&)R
M=6ME<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#$*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B26YF;R(*
M;7-G<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T
M.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87-J;VXB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@R"B,L('!H<"UF;W)M870*;7-G:60@
M(DEN:71I86QI>FEN9R!M;V1U;&4@)7,N+BX@(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-`IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B4V5T="!I
M;FX@:U]O;&]N;F4@971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!)
M;6%G92(*;7-G<W1R(")3971T(&EN;B!B:6QD92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!4
M86)L92(*;7-G<W1R(")3971T(&EN;B!T86)E;&PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@
M5V5B($QI;FLB"FUS9W-T<B`B4V5T="!I;FX@=V5B;&EN:R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM
M<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E-E='0@:6YN
M(%]K;VQO;FYE(&;X<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4V5T="!I;FX@
M96X@;GD@:V]L;VYN92!E='1E<B!D96X@9VIE;&1E;F1E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B4V5T="!I;FX@96X@;GD@:V]L;VYN92!F^'(@9&5N(&=J
M96QD96YD92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4V5T="!I;FX@96X@;GD@<F%D
M(&5T=&5R(&1E;B!G:F5L9&5N9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")3971T
M(&EN;B!E;B!N>2!R860@9OAR(&1E;B!G:F5L9&5N9&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(E-E='0@:6YN(&QI;FIE<VMI9G0@971T97(@9&5N(&=J96QD
M96YD92!N;V1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(E-E='0@:6YN(&QI
M;FIE<VMI9G0@9OAR(&1E;B!G:F5L9&5N9&4@;F]D96XB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T92(*;7-G<W1R(")3971T(&EN;B!A;'1E<FYA=&EV(&UA;"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,CD*;7-G:60@(DEN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.B(*;7-G<W1R(")3971T(&EN;B!E;B!E+7!O<W0@861R97-S92!D
M=2#X;G-K97(@Y2!M;W1T82!D970@;GEE('!A<W-O<F1E="!PY3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X
M"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")3971T(&EN;B!C
M96QL92!E='1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*
M;7-G<W1R(")3971T(&EN;B!C96QL92!E='1E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN
M<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B4V5T="!I;FX@:V]L;VYN92!E
M='1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S
M='(@(E-E='0@:6YN(&MO;&]N;F4@9OAR(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS
M9W-T<B`B4V5T="!I;FX@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(E-E='0@:6YN(&QI;FIE<VMI
M9G0@971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(E-E='0@:6YN(&QI;FIE<VMI9G0@9OAR(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R(")3971T(&EN;B!R860@
M971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R
M(")3971T(&EN;B!R860@9OAR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(R,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE
M('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")3971T(&EN;B!D970@<.5K
M<F5V9&4@<W9A<F5T('1I;"!F^&QG96YD92!S:6MK97)H971S<W#X<G-MY6PZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R(")3971T(&EN
M;B]R961I9V5R92!B:6QD92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*
M;7-G<W1R(")3971T(&EN;B]R961I9V5R92!L:6YK(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8V.`IM<V=I9"`B26YS=69F:6-I96YT
M(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B26MK92!N;VL@:W)E9&ET="!F;W(@Y2!K=6YN92!S96YD92!T:6P@
M9&ES=')I8G5S:F]N<VQI<W1E;BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C8P"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*
M;7-G<W1R(")):VME(&YO:R!K<F5D:71T+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#<P"FUS9VED("));G1E9V5R(@IM<V=S='(@(DEN=&5G97(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B26YT
M96=E<B!L:7-T(@IM<V=S='(@(DEN=&5G97(@;&ES=&4B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR.#,*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S4R"FUS9VED("));G9A;&ED
M($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@
M(E5G>6QD:6<@:&%N9&QI;F<@=F%L9W0@9F]R(&1E;FYE(&MO;7!O;F5N=&5N
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M(")59WEL9&EG(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I
M;VXN(@IM<V=S='(@(E5G>6QD:6<@<')O9W)A;2XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R,0IM<V=I9"`B26YV86QI9"!B871C
M:"!)1"XB"FUS9W-T<B`B56=Y;&1I9R!B871C:"!)1"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#<Q(&QI8B](;W)D92]&;W)M+G!H<#HR,30R(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C$V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C@Q
M"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")59WEL
M9&EG(&1A=&$@<V5N9'0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#D*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RXB"FUS9W-T<B`B56=Y;&1I9R!M;W1T86ME<B!A9')E<W-E+B(*"B,Z(&QI
M8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C@T(&QI8B](;W)D92]#;VUP<F5S
M<R]D8G@N<&AP.C$P,PHC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR
M,C,*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B56=Y;&1I
M9R!F:6QF;W)M870B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-@IM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B56=Y
M;&1I9R!M96QD:6YG<W1Y<&4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"XB"FUS9W-T<B`B56=Y;&1I9R!E;&QE<B!M86YG;&5N9&4@87!I7VED+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED
M("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B56=Y
M;&1I9R!E;&QE<B!M86YG;&5N9&4@<&%R86UE=&5R92XB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-#,*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(E5G>6QD:6=E(')E='1I9VAE=&5R+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED("))
M;G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")59WEL9&EG('!R;W1O:V]L;"XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z("<E<R<B"FUS9W-T
M<B`B56=Y;&1I9R!M;W1T86ME<CH@)R5S)R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,3`W,2!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#@*;7-G:60@(DEN
M=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(E5G>6QD:6<@9&5L="!O8FIE
M:W0B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM
M<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B56=Y;&1I
M9R!K:6QD96%D<F5S<V4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,R,`IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S
M='(@(E5G>6QD:6<@=6YI8V]D92!D871A+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C@*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));FYH
M;VQD(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER96QA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,S-0IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B
M"FUS9W-T<B`B27-O;&5R=&4@=&]R9&5N+7-T;W)M97(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DES
M<F%E;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8T.0IM<V=I9"`B27-S=65R(@IM<V=S='(@(E5T9VEV97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET
M86QI8R(*;7-G<W1R(")+=7)S:78B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DET86QY(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<T(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*
M86YU87(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@S"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G
M:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DIO<F1A;B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@P
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B
M2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,W.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G
M:60@(DIU<W1I9GDB"FUS9W-T<B`B2G5S=&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU
M<W1I9GD@0V5N=&5R(@IM<V=S='(@(DUI9'1S=&EL;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"B,L(&9U
M>GIY"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B0FQO:VMJ=7-T97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-`HC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@
M(E9E;G-T<F5J=7-T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF
M>2!2:6=H="(*;7-G<W1R(")(^'ER96IU<W1E<B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B2V%Z86MH
M<W1A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C0V"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")"
M96AO;&1E(&]R9VEN86P_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-PIM<V=I9"`B2V5R8F5R;W,@
M<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B
M97)O<R!T:F5N97)E;B!A=G9I<W1E(&%U=&5N=&ES97)I;F=E;BXB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S
M(@IM<V=S='(@(DME<FYE;"!.>6)E9WEN;F5R92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@
M(D[X:VME;&=E;F5R97)I;F<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,#`*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(").^&MK96P@
M9FEN9V5R<')I;G0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HS.3@*
M;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B3OAK:V5L(&QE;F=D92(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y(%1Y<&4B
M"FUS9W-T<B`B3OAK:V5L('1Y<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8R,@IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(D[X:VME;&)R
M=6LB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#,*;7-G:60@(DME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B3OAK:V5L(&5K<VES=&5R97(@86QL97)E9&4@<.4@9&5N(&]F9F5N
M=&QI9V4@;OAK:V5L=&IE;F5R96XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(D)A<FXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMI
M<FEB871I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+;W)E
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#0*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*
M;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMY<F=Y>G-T86XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS
M9VED("),85]Y;W5T(@IM<V=S='(@(E5T7W-E96YD92(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S8@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM
M<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B4W!RY6LB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQA;R!0
M96]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R
M(")3:7-T92!H86QT:6UE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@X(&QI
M8B]";&]C:R]M;V]N+G!H<#HY,`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S
M='(@(E-I<W1E(&MV87)T97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$T
M.0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")3:7-T92!O<'!D871E
M<FEN9SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-CDQ"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E-I<W1E(&EN;FQO
M9V=I;F<Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@
M(E-I<W1E(&EN;FQO9V=I;F<Z("5S(&9R82`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HV.#@*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@
M(E-I<W1E(&EN;FQO9V=I;F<Z($%L9')I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED("),871V:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),
M87<B"FUS9W-T<B`B3&]V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B
M571S965N9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM
M<V=S='(@(MAN<VME<R!I;F=E;B!R86UM97(@;&%R(&1U(&9E;'1E="!VYG)E
M('1O;70B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED
M("),969T(@IM<V=S='(@(E9E;G-T<F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$P-`IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B5F5N<W1R92!H
M;V1E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#`*;7-G:60@(DQE9G0@
M=F%L=65S(@IM<V=S='(@(E9E;G-T<F4@=F5R9&EE<B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&5S
M;W1H;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S,V"FUS9VED("),:6=H="!$<FEZ>FQE(@IM
M<V=S='(@(DQE='0@9'5S:W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S,W"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(DQE='0@
M<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S@*;7-G
M:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B3&5T="!F;W)M:61D86=S
M<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,SD*;7-G
M:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("),971T(&5T=&5R;6ED9&%G
M<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0P"FUS
M9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("),971T92!R96=N8GEG
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Q"FUS9VED
M("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("),971T(')E9VX@
M;65D('1O<F1E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-#(*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B3&5T="!S;OAF86QL(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T,PIM<V=I9"`B3&EG
M:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B3&5T=&4@<V[X8GEG97(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(DQI;65R:6-K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,#(*;7-G
M:60@(DQI;FLB"FUS9W-T<B`B3&EN:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B3&EN:R!P
M;VEN=',@=&\Z(@IM<V=S='(@(DQI;FL@<&5K97(@=&EL.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#4Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S
M='(@(DQI;FL@92UP;W-T(&%D<F5S<V5N('1I;"`G<VMR:78@;GDG+7-I9&4@
M=F5D('9I<VYI;F<B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T
M97AT+G!H<#HQ.#$*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI;FME<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE
M(@IM<V=S='(@(DQI;G5X($-O;VMI92(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R(@IM<V=S='(@(DQI<W0@+2!B<G5K97)E;B!K86X@<V4@;6%P
M<&5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S.`IM<V=I9"`B3&ES="!$
M871A8F%S97,B"FUS9W-T<B`B3&ES="!D871A8F%S97(B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*
M;7-G<W1R(")%;6YE<B!I($AJ96QP(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S-PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3&ES="!T86)E;&QE
M<B(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8S-PIM<V=I9"`B
M3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W1E+6%R:VEV(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-C,R"FUS9VED("),:7-T+4AE;'`B"FUS
M9W-T<B`B3&ES=&5H:F5L<"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C8S.0IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T92U)9"(*"B,Z
M(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8S-0IM<V=I9"`B3&ES="U/
M=VYE<B(*;7-G<W1R(")%:65R(&%V(&QI<W1E(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-C,V"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B
M3&ES=&4M<&]S="(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8S
M-`IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B06)B;VYE<B!PY2!L
M:7-T92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8S,PIM<V=I
M9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R(")3=&]P<"!A8F)O;FYE;65N
M="!PY2!L:7-T92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI
M;F,Z-`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B375L:6=H970@9F]R(.4@;&ES=&4@8G)U:V5R92!E<B!D96%K=&EV97)T
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A
M='5R92(*;7-G<W1R("),:71T97)A='5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED("),:71H=6%N:6$B
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,3D*;7-G:60@
M(DQO861I;F<@;&EB<F%R:65S+BXN(@IM<V=S='(@(DQA<W1E<B!B:6)L:6]T
M96ME<BXN+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C@V"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(DQA<W1E<BXN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S0*;7-G:60@(DQO8V%L
M('1I;64Z("(*;7-G<W1R("),;VMA;"!T:60Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B
M4W!RY6L@;V<@=&ED(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.34@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<P"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,"!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,C(*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HV,PIM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`B3&]K87-J;VXB"@HC.B!L;V=I;BYP:'`Z,34U
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-C0@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),;V<@
M:6XB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,34X"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DQO9V<@=70B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R("));FYL;V=G:6YG<V]P<&=A=F5R(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDU,@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2XB"FUS9W-T<B`B3&]G:6X@9F5I;&5T(&9O<F1I(&)R=6ME<FYA=FYE
M="!E;&QE<B!P87-S;W)D970@9'4@<VMR978@:6YN('9A<B!F96EL+B(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY-#@*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`B3&]G:6X@9F5I;&5T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,S8R"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B3&%N9R!T96MS="(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G
M<W1R(")+:N9R;&EG:&5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,W-`IM<V=I9"`B3&]W(@IM<V=S='(@(DQA=B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G
M:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B4VWE(&=R97-K92!B
M;VMS=&%V97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S
M(@IM<V=S='(@(E-MY2!L871I;G-K92!B;VMS=&%V97(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS
M9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S0R(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS-S,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,"!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS
M9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4V"FUS
M9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.0IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@
M(DU31R(*;7-G<W1R(")#5E,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(DUA8V%O(@IM
M<V=S='(@(DQO:V%S:F]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-
M861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B12UP;W-T(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<Q"FUS9VED(")-86EL(@IM
M<V=S='(@(DEN;F)O:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3$T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`IM<V=I
M9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3,S.`IM<V=I9"`B36%K92!S=7)E('1H870@>6]U(&AA=F4@4$5!
M4B!I;G-T86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P871H+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<X('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-86MI;F<@
M9&ER96-T;W)Y("5S(@IM<V=S='(@(E-O<G1E<FEN9W-R96MK96;X;&=E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`B12UP;W-T(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"B,L
M(&9U>GIY"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")%+7!O<W0B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*(RP@
M9G5Z>GD*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(E!O<W0B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z
M>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B4&]S="(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I
M9"`B36%L=&$B"FUS9W-T<B`B12UP;W-T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O
M<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S
M("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T
M,`IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-S@*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUA<%%U97-T(&UA<"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S<V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PHC
M+"!F=7IZ>0IM<V=I9"`B36%R8V@B"FUS9W-T<B`B4_AK(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F
M=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(D%D=F%R<V5L(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")-87)K('=I
M=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")-87)K('=I=&@@;W1H
M97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3(*(RP@9G5Z>GD*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B
M3W!P9&%T97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T
M<B`B061V87)S96PB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$Q
M,0IM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-A;7-V87)E;F1E
M(&9E;'0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B
M061V87)S96PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R
M(")!9'9A<G-E;"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S(T"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$W"B,L(&9U
M>GIY"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T
M<B`B365L9&EN9V5N(&)L92!S;&5T=&5T+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`T"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.38*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX.3,@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,#D@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,S$*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"B,L(&9U
M>GIY"FUS9VED(")-87DB"FUS9W-T<B`B1&%G;&EG(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM
M<V=I9"`B36%Y;W1T92(*;7-G<W1R(")5='-E96YD92(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B365D:6-I;F4B"FUS
M9W-T<B`B079S;.5T="(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4S,0IM<V=I9"`B365E=&EN9R!#86YC96QL871I;VXB"FUS
M9W-T<B`B3?AT96%V;'ES;FEN9R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4P,PIM<V=I9"`B365E=&EN9R!);F9O<FUA=&EO
M;B(*;7-G<W1R(")-^'1E:6YF;W)M87-J;VXB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#D*;7-G:60@(DUE971I;F<@4')O
M<&]S86PB"FUS9W-T<B`B3?AT96EN;FMA;&QE;'-E(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(U"FUS9VED(")-965T:6YG
M(%)E<&QY(@IM<V=S='(@(DWX=&5S=F%R(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$T"FUS9VED(")-965T:6YG(%5P9&%T
M92(*;7-G<W1R(")-^'1E;W!P9&%T97)I;F<B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3D*;7-G:60@(DUE971I;F<@57!D
M871E(%)E<75E<W0B"FUS9W-T<B`B1F]R97/X<G-E;"!O;2!M^'1E;W!P9&%T
M97)I;F<B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$Y
M"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE;6\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"FUS9VED(")-96YU(&UO9&4Z(@IM
M<V=S='(@(DUE;GEM;V1U<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8P"B,L(&9U>GIY"FUS9VED(")-97)G
M92!C96QL<R(*;7-G<W1R(")-96QD:6YG<V9E;'0B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@86QL
M("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN("(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,X"B,L('!H<"UF;W)M870*;7-G
M:60@(DUE<F=I;F<@;&]C86QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S@X"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I
M;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD:75M+BXN("(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#(U"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO9'5L92`E
M<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S(*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B
M365L9&EN9R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C(V"FUS
M9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3D*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS
M9W-T<B`B365L9&EN9W-F96QT(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y,2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C(V"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C,S(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8X"B,L(&9U>GIY"FUS
M9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B365L9&EN9W-D871O(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-971A<B!7
M96%T:&5R(@IM<V=S='(@(E-T87)T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-PHC+"!F=7IZ>0IM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B1&5T(&5R(&EN9V5N(&UE;&1I;F=E<B!I(&1E;FYE('!O
M<W1B;VMS96XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3`*(RP@9G5Z
M>GD*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(D1E=&%L:F5R(&AA<B!B;&ET="!L;V=G970@9F]R(&%D;6EN:7-T
M<F%T;W)E;BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HW
M,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`HC+"!F=7IZ>0IM
M<V=I9"`B365T:&]D(@IM<V=S='(@(DQA=F5S="(*"B,Z(&QI8B](;W)D92]2
M4$,O>&UL<G!C+G!H<#HX,B!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D("<E<R<@:7,@;F]T
M(&1E9FEN960B"FUS9W-T<B`B36%P<&5B<G5K(&5R(&EK:V4@=&EL9VIE;F=E
M;&EG+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C<S"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(DUI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY
M"FUS9VED(")-:61D;&4B"FUS9W-T<B`B4VMJ=6QT(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1N968N<&AP.C0Q"FUS9VED(")-:6UE(%1Y<&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#@*;7-G:60@(DUI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P,`IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(Q-PHC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(D9E
M:6PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E
M;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8Y-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,T.0IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`U"FUS
M9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3,*(RP@9G5Z>GD*;7-G:60@(DUI<W-I;F<@;65S<V%G
M92!)1"XB"FUS9W-T<B`B1&5N;F4@;65L9&EN9V5N('1I;"(*"B,Z(&QI8B].
M970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3<*;7-G:60@(DUI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,L(&9U>GIY
M"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D1E;FYE(&UE
M;&1I;F=E;B!T:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4V"B,L(&9U>GIY"FUS9VED(")-;R(*;7-G<W1R(")&;'ET
M="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C(*(RP@9G5Z>GD*
M;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(DYY('!O<W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<U"B,L(&9U>GIY"FUS9VED(")-
M;V1E<F%T92(*;7-G<W1R(")3:7-T(&UO9&EF:7-E<G0B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV.2!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HX.`HC+"!F=7IZ>0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")3
M:7-T(&UO9&EF:7-E<G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*(RP@9G5Z>GD*;7-G:60@(DUO9&EF
M>2!54DPB"FUS9W-T<B`B16YD<F4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C4W"B,L(&9U>GIY"FUS9VED(")-;V1U;&4B"FUS9W-T<B`B4F]L;&4B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Y-PHC+"!F=7IZ>0IM<V=I
M9"`B36]D=6QU<R(*;7-G<W1R(")2;VQL92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36]L9&]V82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"B,L(&9U>GIY"FUS9VED(")-;VYA
M8V\B"FUS9W-T<B`B3&]K87-J;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(DUO;F=O
M;&EA(@IM<V=S='(@(E1I;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3@W
M"B,L(&9U>GIY"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")3;'5T
M="!PY2!M96QD:6YG96XB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP
M.C,V"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DWE;F5D=&QI9R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,0IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED
M(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B2V]P:65R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,T-0HC+"!F=7IZ>0IM<V=I9"`B36]S=&QY
M($-L;W5D>2(*;7-G<W1R(")+;W!I97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S0V"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@4W5N;GDB
M"FUS9W-T<B`B2V]P:65R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z-#(P"B,L(&9U>GIY"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B9FQY
M='0@;F5D(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#(T"B,L
M(&9U>GIY"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B9FQY='0@;W!P(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#(X"B,L(&9U>GIY"FUS
M9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(D9L>71T('1I;"!H^'ER92(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0Q-@HC+"!F=7IZ>0IM<V=I
M9"`B36]V92!5<"(*;7-G<W1R(")F;'ET="!O<'`B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DW"FUS9VED(")-;W9E(&1O=VXB
M"FUS9W-T<B`B9FQY='0@;F5D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Y-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#DW"FUS9VED(")-;W9E('5P(@IM<V=S='(@(F9L>71T(&]P<"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")!9'9A<G-E
M;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,38X"FUS9VED(")-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R,C8*(RP@9G5Z>GD*;7-G:60@(DUU;'1I<&QE('-E;&5C
M=&EO;B(*;7-G<W1R(")&:6QT97)I;FYS=&EL;&EN9V5R(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,S-"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DMO
M;E]T;V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU,0IM<V=I
M9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E
M9&ET+G!H<#HQ,C0*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDS"B,L(&9U>GIY"FUS9VED(")->6%N;6%R(@IM<V=S='(@(FYA=FXB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z
M-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C,Y-R!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE
M9BYP:'`Z-#$@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-3@S"FUS9VED(").86UE(@IM<V=S='(@(DYA=FXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYA;6EB
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#8*;7-G:60@
M(DYE961S($%C=&EO;B(*;7-G<W1R(")4<F5N9V5R(&AA;F1L:6YG(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"B,L
M(&9U>GIY"FUS9VED(").97!A;"(*;7-G<W1R(").>2!P;W-T(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"B,L(&9U
M>GIY"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(").>2!P;W-T(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*(RP@
M9G5Z>GD*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(DYY
M('!O<W0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-0IM<V=I
M9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,#<*;7-G:60@(DYE='-C87!E($-!(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C`Y"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`X"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8P-@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV,3`*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,0HC+"!F
M=7IZ>0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G
M<W1R("));G1E="!P97)S;VYL:6<@<V5R=&EF:6MA="!T:6QG:F5N9V5L:6<N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*(RP@9G5Z>GD*
M;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B4V5T
M="!I;FX@<V5R=&EF:6MA="!H97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C0R"B,L(&9U>GIY"FUS9VED(").971W;W)K(@IM<V=S='(@(DYY
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM
M<V=I9"`B3F5V97(B"FUS9W-T<B`B06QD<FDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3&5G9R!T:6P@96X@;GD@:V]N=&%K
M="(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4Q
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(W
M"B,L(&9U>GIY"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B1FER;6%K
M871E9V]R:2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W.0HC+"!F=7IZ>0IM
M<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3GD@<&]S="(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M
M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B3F5W
M(%IE86QA;F0B"FUS9W-T<B`B3GD@<&]S="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@
M*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-C0*;7-G:60@(DYE=W,B"FUS9W-T<B`B3GEH971E<B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#8*(RP@9G5Z>GD*;7-G
M:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B1W)U<'!E(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,C$@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z-#8*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S<@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,S(*;7-G:60@(DYE>'0B"FUS9W-T<B`B
M3F5S=&4B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$Q-2!L:6(O2&]R
M9&4O54DO4&%G97(N<&AP.C$Q-@IM<V=I9"`B3F5X="!086=E(@IM<V=S='(@
M(DYE<W1E('-I9&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(DYE>'0@4&AA<V4B"FUS9W-T<B`B3F5S=&4@<VED92(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,S<P"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T
M<B`B5&EL8F%K92!T:6P@5F%L9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEC87)A9W5A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS9W-T<B`B06QD<FDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*(RP@9G5Z>GD*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B06QD<FDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"B,L(&9U>GIY"FUS
M9VED(").:6=H="(*;7-G<W1R(")(^'EE<W0B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@
M(DYI=64B"FUS9W-T<B`B3V)S(2(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HX.#@*;7-G:60@(DYO(@IM<V=S='(@(DYE:2(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ,38*;7-G:60@(DYO
M(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E
M;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H
M<#HQ,3$*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG
M($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S(R"FUS9VED(").;R!B871C:"!T96UP;&%T92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S@@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C(T"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C(T-@IM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T
M('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;6-A;"YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R
M(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C4U"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(D%N9W)E
M(&5N9')I;F=E<B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30T"FUS
M9VED(").;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@8F5L
M;W<@=&AI<R!L979E;"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(").;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(G)7,G(&)L
M92!L86=T('1I;"!R971T:6=H971S<WES=&5M970N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$S-3@*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;6UA;F0@<W!E
M8VEF:65D+B(*;7-G<W1R("));F=E;B!B<G5K97(@=F%L9W0N(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-S,@;&EB+TAO<F1E+G!H<#HT.3,@;&EB+TAO<F1E+U5T
M:6PN<&AP.C<U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G
M<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O<B!3
M44PM:V%T96=O<FEE<BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S<S"B,L(&9U
M>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO
M;B!E<B!S<&5S:69I<V5R="!F;W(@3$1!4"UI;G-T:6QL:6YG96YE+B(*"B,Z
M(&QI8B]61E,O<W%L+G!H<#HU.34*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*
M;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O
M<B!344PM:V%T96=O<FEE<BXB"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW
M-3<*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(DEN9V5N
M(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R(%-13"UK871E9V]R
M:65R+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(S
M"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U.0HC+"!F=7IZ>0IM<V=I9"`B
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DEN9V5N(&UE;&1I
M;F=E<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(DYO(&5N=')Y('=I=&@@=&AE(&ED("<E<R<@97AI<W1S(&EN
M('1H92!O<FEG:6YA;"!H96QP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]"<F]W<V5R+G!H<#HX.3(*(RP@9G5Z>GD*;7-G:60@(DYO(&9I;&4@
M=7!L;V%D960B"FUS9W-T<B`B5FES('-L971T961E(&5L96UE;G1E<B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M:6-O;G,@9F]U;F0N(@IM<V=S='(@(DEN9V5N('9E9&QE9V<@9G5N;F5T+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I;VXN<&AP
M.C4R,@HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C86QE('-P96-I9FEE9"XB"FUS
M9W-T<B`B26YG96X@8G)U:V5R('9A;&=T+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(").;R!L
M;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(E-V87(@=&EL(&QI<W1E;B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-3@*(RP@9G5Z>GD*
M;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DEN9V5N(&UE
M;&1I;F=E<B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-C$*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R
M("));F=E;B!B<G5K97(@=F%L9W0N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8V,@HC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M8F5R('-P
M96-I9FEE9"XB"FUS9W-T<B`B26YG96X@8G)U:V5R('9A;&=T+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B3F\@;V9F
M96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DEN9V5N('9E9&QE9V<@9G5N;F5T
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDS"B,L(&9U>GIY"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I
M<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:6UA<"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG
M96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N
M=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-S0*(RP@
M9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO
M;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O
M<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L
M+G!H<#HX,B!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#@*(SH@;&EB+TAO
M<F1E+T%U=&@O<&%M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O<B!344PM
M875T96YT:7-E<FEN9RXB"@HC.B!L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP
M.C$S.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG
M=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX.0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R
M="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HQ,S$X"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ.0IM
M<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"B,L
M(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").;W1A=&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B26YG96X@;65L
M9&EN9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM
M<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C4V"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B5F5N;FQI<W0@<VMR:78@:6YN(&)R
M=6ME<FYA=FX@;V<@<&%S<V]R9"(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C
M+G!H<#HQ-#$*(RP@9G5Z>GD*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D(@IM<V=S='(@(DEN9V5N('9#87)D(&1A=&$@9G5N;F5T+B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.38@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDP-@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3$W(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY,S0*(RP@9G5Z>GD*;7-G:60@(DYO('9A;'5E
M<R(*;7-G<W1R("));F=E;B!M96QD:6YG97(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3$P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I
M;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`T"FUS9VED(").;VX@
M4&%R=&EC:7!A;G0B"FUS9W-T<B`B26MK92!D96QT86=E<B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,R!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.C@X"FUS9VED(").;VYE(@IM<V=S='(@(DEN9V5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U
M.2TQ,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").;W)F;VQK($ES
M;&%N9"(*;7-G<W1R(")/<'!D871E<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(DYO
M<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&IE;'`B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DYO
M<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)M86PB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!F=7IZ>0IM<V=I9"`B3F]T($%F=&5R
M(@IM<V=S='(@(DEK:V4@:VQA9&0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8V,PHC+"!F=7IZ>0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R
M(")):VME(&ML861D(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-38*(RP@9G5Z
M>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")3;W)T97)I;F=S
M<F5K:V5F^&QG92(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV-R!L:6(O
M5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0Y"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HV,`HC
M+"!F=7IZ>0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")):VME
M('-L971T970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DEK
M:V4@<VQE='1E="(*"B,Z(&QI8B]61E,N<&AP.C$X-"!L:6(O5D93+G!H<#HR
M,#,@;&EB+U9&4RYP:'`Z,C(Q(&QI8B]61E,N<&AP.C(S.`HC.B!L:6(O5D93
M+G!H<#HR-34@;&EB+U9&4RYP:'`Z,C<Q(&QI8B]61E,N<&AP.C(X.2!L:6(O
M5D93+G!H<#HS,C4*(SH@;&EB+U9&4RYP:'`Z,S@X(&QI8B]61E,N<&AP.C0W
M,B!L:6(O5D93+G!H<#HU-#0@;&EB+U9&4RYP:'`Z-38R"B,L(&9U>GIY"FUS
M9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")$96X@9F]R97-P=7)T92!O
M<'!G879E;B!E<B!I:VME('-T;W1T970N(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#<@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$U.0IM<V=I9"`B3F]T97,B"FUS9W-T<B`B3F]T871E<B(*"B,Z('-E<G9I
M8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B
M<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*;7-G:60@(DYO=&EC92(*;7-G
M<W1R(")/8G,A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*
M(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(D%L9')I(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-#$*(RP@9G5Z>GD*;7-G:60@(DYU;6)E
M<B(*;7-G<W1R(").879N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C(*
M(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(C$P,"!T96=N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-C8@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,C`@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*(RP@
M9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(D%N=&%L
M;"!K;VQO;FYE<B!I(&]P<'-U;6UE<FEN9W-V:7-N:6YG96XZ(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-C0@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,3@@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*(RP@9G5Z>GD*;7-G:60@(DYU;6)E
M<B!O9B!R;W=S(@IM<V=S='(@(D%N=&%L;"!K;VQO;FYE<B!I(&]P<'-U;6UE
M<FEN9W-V:7-N:6YG96XZ(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8V.0HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B1'4@;&%G97(@96X@9&ES=')I8G5S:F]N<R!L:7-T92XB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT.#,*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C8S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-"!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,30X"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S(Y"FUS9VED(")/
M2R(*;7-G<W1R(")/2R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HX,30*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R(")%
M;6YE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*(RP@9G5Z
M>GD*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B:F5K=&5T(&)L
M92!I:VME(&9U;FYE="(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-R!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B3V)J
M96-T(&-R96%T;W(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B3W)D<W1Y<F5R(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.3D*(RP@9G5Z>GD*;7-G:60@(D]C
M=&%L(@IM<V=S='(@(D1A9VQI9R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS.#,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-`IM<V=I
M9"`B3V9F:6-E(@IM<V=S='(@(DMO;G1O<B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B3VUA;B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S8*
M(RP@9G5Z>GD*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA
M<F5D(&9O;&1E<G,N(@IM<V=S='(@(D1E;FYE('1J96YE<F5N('-T^'1T97(@
M:6MK92!D96QI;F<@878@;6%P<&5R+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B26YG96X@=F5D;&5G9R!F=6YN970N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X,S4@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-34*(RP@
M9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B17!O<W1A9')E<W-E;B!D:6XZ(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S
M>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O
M=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B3W!E
M;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B5FES92!I;FYH;VQD(&D@970@
M96=E="!V:6YD=2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(U
M-PIM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T
M82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T
M"B,L(&9U>GIY"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(DAE;G1E(&YY92!M96QD:6YG97(@:2!E="!E9V5T('9I
M;F1U/R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E
M<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HV,#`*;7-G:60@(D]P=&EO;F%L(%!A<G1I
M8VEP86YT(@IM<V=S='(@(E9A;&=F<FD@9&5L=&%G97(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S
M='(@(E9A;&<B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,CD@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B5F%L9R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(D]P=&EO;G,Z(@IM<V=S='(@
M(E9A;&<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$X"B,L(&9U>GIY"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B
M5F5L9R!L:7-T92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DQ
M"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI
M<V5R:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3(*(RP@
M9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B3W)G
M86YI<V5R:6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R-PIM
M<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FES97)I;F<B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B2&%N9&QI;F=E<B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G
M:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3(P('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,CD*;7-G:60@(D]T
M:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%N;F5N(&EN9F]R;6%S:F]N(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0HC+"!F=7IZ>0IM<V=I
M9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B3&%G<F4@5F%L9R(*"B,Z
M(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(E!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/
M;6%D<F5S<V5R:6YG(&9E:6QE="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,C<Y"B,L(&9U>GIY"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U
M<F4B"FUS9W-T<B`B4VMY9V=E;&5G9R!S:6=N871U<C\B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,S(X"B,L(&9U>GIY"FUS9VED(")01U`@16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0+6MR>7!T97(@;65L9&EN9R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S.#<*(RP@9G5Z>GD*;7-G:60@
M(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D]F9F5N=&QI9R!01U`M;OAK:V5L
M<FEN9R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-C8*(RP@9G5Z
M>GD*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B
M4$=0('-I9VYE<B]K<GEP=&5R(&UE;&1I;F<B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO
M<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,T.`HC+"!F=7IZ>0IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("),
M;V=G(&EN;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*
M(RP@9G5Z>GD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B5FES="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(RP@9G5Z>GD*;7-G
M:60@(E!-(%-N;W<B"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-3$*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,U,@HC+"!F=7IZ>0IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B1G)A(@H*(SH@;&EB+V%P:2YP:'`Z,3(V"FUS9VED(")07TA0(%-H96QL
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#8*(RP@9G5Z>GD*;7-G:60@(E!A9&1I;F<B"FUS
M9W-T<B`B571V:61E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(E!A:VES=&%N(@IM
M<V=S='(@(D1A=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")086QA=2(*;7-G<W1R
M(")%+7!O<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&%N86UA(@IM
M<V=S='(@(FYA=FXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(D4M
M<&]S="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#<*(RP@
M9G5Z>GD*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B2V]P:65R(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P,@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-34W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C`S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S`@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S8W"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")0
M87-S;W)D(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S4T"B,L
M(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%S
M<V]R9"(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34W"B,L(&9U
M>GIY"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P
M97-I9FES97)T(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`S-PHC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B5FES(&UA:6QL:7-T92!I;F9O<FUA
M<VIO;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F
M=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B
M4&%S<W=O<F0Z("(*;7-G<W1R(")087-S;W)D(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(E!A<W-W
M;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")087-S<&AR87-E('-T96UM97(@
M:6MK92!O=F5R96YS(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R."!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*
M(RP@9G5Z>GD*;7-G:60@(E!A<W1E(@IM<V=S='(@(D1A=&\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")0
M87-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"B,L(&9U>GIY"FUS9VED
M(")0871H(@IM<V=S='(@(D1A=&\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHT('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z-`IM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@
M(E!E;W!L92(*;7-G<W1R(")2;VQL92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"B,L(&9U>GIY"FUS9VED(")097)C
M96YT(@IM<V=S='(@(E-K<FEV('5T(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHV"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B571F^'(@=F5D;&EK96AO;&1S
M;W!E<F%S:F]N97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"FUS
M9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M(@IM<V=S='(@(E5T9OAR('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R('9E9"!I
M;FYL;V=G:6YG/R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,2!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C0*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N(@IM<V=S
M='(@(E!E<G-O;FQI9R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@)R5S)R!N
M;W0@9&5L971E9"XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@
M97(@:6MK92!I;7!L96UE;G1E<G0N(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,C(T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HY,PHC.B!A9&UI;B]P
M97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HW-`HC
M+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B)7,@4$=0(&%D;6EN:7-T<F%S:F]N(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ-#D@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-3(*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(E!E
M<FUI<W-I;VYS(&9O<B(*;7-G<W1R(")097)S;VYL:6<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N
M(@IM<V=S='(@(E!E<G-O;FQI9R!I;F9O<FUA<VIO;B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&5R
M=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G
M:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&AI;&EP<&EN97,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3D*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#0W"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,0HC+"!F=7IZ>0IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B1&%T;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X
M"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*
M;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#@*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B17(@
M9'4@4TE+2T52('#E(&%T(&1U(/AN<VME<B#E('-L971T92!D92!V86QG=&4@
M;W!P9OAR:6YG96YE/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+B(*;7-G<W1R(")%<B!D=2!324M+15(@<.4@870@9'4@^&YS:V5R(.4@<VQE
M='1E(&1E('9A;&=T92!O<'!F^')I;F=E;F4_(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U-38*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E9E;FYL:6=S="!S:W)I=B!I;FX@
M9&5T(&YY92!N879N970Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E9E;FYL
M:6=S="!S:W)I=B!I;FX@;F%V;F5T('#E(&1E;B!N>64@;6%P<&5N.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,CDY"B,L(&9U>GIY"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")696YN;&EG
M<W0@<F5T="!T=F5T>61I9V4@96QL97(@=6=Y;&1I9V4@861R97-S97(N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-3(*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-#,T"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+B(*;7-G<W1R(")696YN;&EG<W0@<VMR:78@:6YN(&1E="!N>64@;F%V;F5T
M.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@
M(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS
M9W-T<B`B5F5N;FQI9W-T(&=I(&5T('-A;6UE;F1R86<@878@<')O8FQE;65T
M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3@@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B5F5N;FQI<W0@<VMR
M:78@:6YN(&)R=6ME<FYA=FX@;V<@<&%S<V]R9"(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9
M;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y
M<W1E;2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$W"FUS
M9VED(")0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O(&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU-#`*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"B)696YN
M;&EG<W0@<V4@;W9E<B!D96X@9OAL9V5N9&4@:6YF;W)M87-J;VYE;BP@=F5L
M9R!SY2!E;B!H86YD;&EN9R!F<F$@;65N>65N("(*(FYE9&5N=6YD97(N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#,U"FUS
M9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E
M;&]W+B(*;7-G<W1R(")696YN;&EG<W0@=F5L9R!E;B!H86YD;&EN9R!F<F$@
M;65N>65N(&YE9&5N=6YD97(N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B5F5N;FQI9W-T('-K
M<FEV(&EN;B!D970@;GEE(&YA=FYE=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")0
M;VQA;F0B"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E-LY2!S
M86UM96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4V"B,L(&9U
M>GIY"FUS9VED(")0;VQL<R(*;7-G<W1R(")3;.4@<V%M;65N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I
M=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C8T(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA
M<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]L9&%P+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VEM<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I
M9&5L<V5N+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H<#HS-@HC
M+"!F=7IZ>0IM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM<#H@2V%N
M(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I9&5L<V5N+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3@*(RP@9G5Z>GD*;7-G
M:60@(E!R97-E;G1A=&EO;G,B"FUS9W-T<B`B1F]R<FEG92!M96QD:6YG(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(E!R
M97-S=7)E(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(U-PHC+"!F=7IZ>0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L
M.B`B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ.3@*(RP@9G5Z>GD*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T
M<B`B4&%S<V]R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ.#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D9O
M<FCE;F1S=FES;FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(E9I<R!V
M961L96=G(&D@970@96=E="!V:6YD=2(*"B,Z(&QI8B](;W)D92]522]086=E
M<BYP:'`Z-S$@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HW,@IM<V=I9"`B4')E
M=FEO=7,@4&%G92(*;7-G<W1R(")&;W)R:6=E('-I9&4B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V
M,`HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")&
M;W)R:6=E(&UE;&1I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#D*(RP@9G5Z>GD*
M;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(D1I;B!P<FEV871E(&[X:VME
M;"(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@
M(E!R;V)L96TB"FUS9W-T<B`B6U!R;V)L96UR87!P;W)T72(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C$Q,@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO
M;B(*;7-G<W1R(")0<F]B;&5M8F5S:W)I=F5L<V4B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C$V"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C$W,@HC+"!F=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B
M4F5T=&5T('1E:W-T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Y
M"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(D1I;B!O9F9E
M;G1L:6=E(&[X:VME;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C8Y"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G
M<W1R(")/9F9E;G1L:6<@4$=0+6[X:VME;')I;F<B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(E!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(E!E<G-O;FQI9R!01U`M;OAK:V5L<&%R(&=E;F5R97)T+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*(RP@
M9G5Z>GD*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!R;W1O:V]L;#HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`S"B,L(&9U>GIY"FUS9VED(")1871A<B(*;7-G<W1R(")3=&%R="(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HW,`IM<V=I9"`B475E<GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM
M<V=S='(@(D]F9F5N=&QI9R!01U`M;OAK:V5L('1E:W-T(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(R-#@*(RP@9G5Z>GD*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R(")&:6QT97)I;FYS=&EL;&EN9V5R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,PHC+"!F=7IZ>0IM<V=I9"`B4F%I
M;B(*;7-G<W1R("),;VMA<VIO;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-30*(RP@9G5Z>GD*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T
M<B`B079S;.5T=#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,U-0HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(DQO9V<@
M:6YN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-@HC+"!F
M=7IZ>0IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B5FES="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3<*(RP@9G5Z>GD*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-3@*(RP@9G5Z>GD*;7-G:60@(E)A:6X@=&\@
M4VYO=R(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,*(RP@9G5Z>GD*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(DYO
M=&%T97(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HW,2!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@HC+"!F=7IZ>0IM<V=I
M9"`B4F%T:6\B"FUS9W-T<B`B3&]K87-J;VXB"@HC.B!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(Y-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,`HC+"!F=7IZ>0IM<V=I9"`B4F5A9"(*;7-G<W1R
M(")/<'!D871E<B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,`HC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(").
M>64@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(D=J96YO<'!T82!S97-J;VXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Q"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M
M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M,0HC+"!F=7IZ>0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T
M<B`B3W!P9&%T97(@;6%P<&5V:7-N:6YG.B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HX.#D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,#4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,C<*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@(DYU
M;&QS=&EL;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C,T"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,R-`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<V"FUS9VED(")2
M96UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R(")(
M=7-K(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E(%-E<G9E
M<G,B"FUS9W-T<B`B5&IE;F5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP
M;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,2!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHT,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$U"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`B1FIE
M<FX@<&%R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L
M(&9U>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B1FIE<FX@:VEL
M9&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3,R
M"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(D9J97)N
M(&MI;&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS
M9W-T<B`B1FIE<FX@<&%R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-C4X"B,L(&9U>GIY"FUS9VED(")296UO=F4@9G)O;2!M
M>2!C86QE;F1A<B(*;7-G<W1R(")3;&5T="!F<F$@:V%L96YD97)E;B!M:6XB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$S-@IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`B1FIE<FX@<&%R(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$Y-@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")&:F5R
M;B!K:6QD92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M
M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E
M<B(*;7-G<W1R(")&:F5R;B!K:6QD92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(D9J97)N(&MI;&1E(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DW"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(X,`HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#D*;7-G:60@(E)E<&QY
M(%-E;G0N(@IM<V=S='(@(E-V87(@<V5N9'0N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4Y"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C0V.`HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-S@*;7-G:60@(E)E<&QY('=I=&@@3F]T
M(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(E-V87(@870@;65L9&EN9V5N
M(&EK:V4@<W3X='1E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C0V-@IM<V=I9"`B4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R
M(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(E-V87(@;65D(&QE9&EG+V]P<'1A
M='0@9F]R(&1E(&YE<W1E('1O(&WE;F5D96YE+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V-0IM<V=I9"`B4F5P;'D@=VET
M:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R(")3
M=F%R(&UE9"!D96X@9F]R97-P=7)T92!L961I9R]O<'!T871T+6EN9F]R;6%S
M:F]N96XN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z,3@Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297!L>3H@)7,B
M"FUS9W-T<B`B4W9A<CHB"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z
M,3,Y"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP
M.C$X,"!L:6(O2&]R9&4N<&AP.C4P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E#E:W)E=F0@)W5I9"<@97(@:6MK92!S<&5S
M:69I<V5R="!I(&EN<W1I;&QI;F=S:V]N9FEG=7)A<VIO;F5N+B(*"B,Z(&QI
M8B]61E,O<W%L+G!H<#HV,#$@;&EB+U9&4R]F='`N<&AP.C<W.2!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HW-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B4.5K<F5V9"`G=6ED)R!E<B!I:VME('-P97-I9FES
M97)T(&D@:6YS=&EL;&EN9W-K;VYF:6=U<F%S:F]N96XN(@H*(SH@;&EB+TAO
M<F1E+U5T:6PN<&AP.C<V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E#E:W)E=F0@)W5I9"<@97(@:6MK92!S<&5S:69I<V5R="!I
M(&EN<W1I;&QI;F=S:V]N9FEG=7)A<VIO;F5N+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+U)E;F1E<F5R+G!H<#HS,CD*;7-G:60@(E)E<75I<F5D($9I96QD(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4Y,@IM<V=I9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B
M3V)L:6=A=&]R:7-K(&1E;'1A9V5R(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,S.2!L:6(O2&]R9&4O1F]R;2]296YD97)E
M<BYP:'`Z,S$V"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-`IM<V=I9"`B4F5S
M970B"FUS9W-T<B`B3G5L;'-T:6QL(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM
M<V=S='(@(E!A<W-O<F0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G
M<W1R(")':F5N;W!P=&$@<V5S:F]N(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8V(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-S,*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4_AK97)E<W5L
M=&%T(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@R,0IM<V=I9"`B4F5S=6QT
M<R`H:6YC;'5D:6YG($AO<F1E*3HB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C@Q.0HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<SHB"FUS9W-T
M<B`B4_AK97)E<W5L=&%T(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U
M<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")4:6QB86ME('1I;"!686QG(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PHC
M+"!F=7IZ>0IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")/8G-E<G9E<B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B0F4@;VT@;&5V97)I;F=S8F5K<F5F=&5L<V4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,P"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E
M>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B5&EL8F%K92!T:6P@5F%L9R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B
M4FED9&QE<R(*;7-G<W1R(")3:VIU;'0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*;7-G:60@
M(E)I9VAT(@IM<V=S='(@(DCX>65S="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3`V"B,L(&9U>GIY"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B
M16MS96UP96QV97)D:65R.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`R
M"B,L(&9U>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B16MS96UP
M96QV97)D:65R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B4F]?=R!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(DQA=B!P<FEO<FET970B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-R!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*;7-G:60@(E)O;&4B"FUS9W-T<B`B
M4F]L;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(DYO
M<FUA;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,#@*(RP@9G5Z>GD*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B9FQY='0@
M;W!P(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P
M-0HC+"!F=7IZ>0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B9FQY='0@
M;W!P(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q
M,0HC+"!F=7IZ>0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(D9L>71T
M('1I;"!H^'ER92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#D*(RP@9G5Z>GD*;7-G:60@(E)O=R!0<F]P97)T
M:65S(@IM<V=S='(@(DQA=B!P<FEO<FET970B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"B,L(&9U>GIY"FUS
M9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("),878@<')I;W)I=&5T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*
M(RP@9G5Z>GD*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E-LY2!S86UM96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R(")2;VQL92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0HC+"!F=7IZ
M>0IM<V=I9"`B4G5N(@IM<V=S='(@(D]B<V5R=F5R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4G5S
M<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@
M(E)W86YD82(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,S`P"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS-#$*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S
M<V%G92(*;7-G<W1R(")+<GEP=&5R(&UE9"!3+TU)344B"@HC.B!L:6(O2&]R
M9&4O075T:"]S87-L+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/;6%D<F5S
M<V5R:6YG(&9E:6QE="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#@Q"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(DUE
M;&1I;F=S=FES;FEN9R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I
M9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(E-3(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S4*;7-G:60@(E-32"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S@*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,3,P"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*(RP@
M9G5Z>GD*;7-G:60@(E-A(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(E-A:6YT($MI='1S
M(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-A:6YT($QU8VEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(E-A;6]A(@IM<V=S='(@
M(DQA9W)E('-O;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E-A;B!-87)I;F\B"FUS
M9W-T<B`B061V87)S96PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I
M<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3(P
M"B,L(&9U>GIY"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B
M4W1A="]&>6QK92`H07)B96ED*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A=61I($%R86)I82(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*
M;7-G:60@(E-A=F4B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@)7,B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`G)7,G(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*
M;7-G<W1R("),86=R92!686QG(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V,0IM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HV.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4V5N9"!S:7-T92!I;F9O<FUA<VIO
M;B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDP"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L86=E(%9&4RUB86-K96YD
M.B`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0HC+"!F=7IZ>0IM
M<V=I9"`B4V-I96YC92(*;7-G<W1R(")3:6=N97)T(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,34@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,3<*;7-G:60@(E-E87)C:"(*;7-G<W1R(")3^&LB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"B,L(&9U>GIY"FUS9VED(")3
M96%R8V@@16YG:6YE<R(*;7-G<W1R(")3^&L@)7,B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,30R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5A
M<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<R(*;7-G<W1R("));FYS
M=&EL;&EN9V5R(&9O<B!S^&LB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S
M"B,L(&9U>GIY"FUS9VED(")396%R8VAI;F<@9V5T=&5X="!B:6YA<FEE<RXN
M+B(*;7-G<W1R("));FYS=&EL;&EN9V5R(&9O<B!S^&LB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDU.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I;&5S
M(@IM<V=S='(@(E9E;&<@86QL92(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T
M<B`B5F5L9R!E;B!D871O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.3@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*
M;7-G<W1R(")696QG(&5N(&MO;G1O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R
M(@IM<V=S='(@(E9E;&<@:6YG96XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*
M;7-G<W1R(")696QG(&5N(&1A=&\B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A
M9&0B"FUS9W-T<B`B5F5L9R!E="!F96QT(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(V-34*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP
M;VYE;G1S+B(*;7-G<W1R(")696QG(&5N(&1A=&\B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$T"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@86X@;V)J96-T(@IM<V=S='(@(E9E;&<@:6YG96XB"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)696QG(&MA<F%K=&5R96YE(&1U
M('1R96YG97(@9G)A(&)O:W-E;B!U;F1E<BX@1'4@:V%N(&1E<F5T=&5R(&MO
M<&EE<F4@;V<@(@HB;&EM92!D96T@:6YN(&9R82!T96MS=&9E;'1E="XB"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5F5L9R!D871O<VMI;&QE=&5G
M;CHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5F5L9R!D871O9F]R;6%T
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHX-0IM
M<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G
M<W1R(")696QG(&1A=&]S:VEL;&5T96=N.B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*
M;7-G<W1R(")696QG('1I9'-F;W)M870Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-`IM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N(@IM<V=S='(@(E9E;&<@=&\@<V%M<W9A<F5N9&4@9F5L="XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDV"FUS9VED(")396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,S@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93HB"FUS9W-T<B`B5F5L9R#X;G-K970@<W!RY6LZ(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C4S"FUS9VED(")396YD($QA
M=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R(")396YD('-I<W1E(&EN9F]R;6%S
M:F]N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G
M:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4V5N9"!P<F]B;&5M
M<F%P<&]R="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C0*(RP@9G5Z>GD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E-E;F0@
M;65L9&EN9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,30*(RP@9G5Z>GD*;7-G:60@(E-E;G-O<CH@
M(@IM<V=S='(@(B`@("!%;6YE.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@R(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@
M(DUE;6\B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS
M9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,C4*(RP@9G5Z>GD*;7-G:60@(E-E
M<FEA;"!.=6UB97(B"FUS9W-T<B`B3F%V;B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED(")397-S:6]N
M($E$(&5X<&ER960N(@IM<V=S='(@(DUE;&1I;F=S9F5L="(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,CDV"B,L(&9U>GIY"FUS9VED(")3970B"FUS9W-T
M<B`B5F5L9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"B,L
M(&9U>GIY"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(E-E='0@<VED92!O
M<'!D871E<FEN9RP@;V<@=FES;FEN9W,@=F%L9RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(B(*(E-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R(")3
M971T('-I9&4@;W!P9&%T97)I;F<L(&]G('9I<VYI;F=S('9A;&<N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4V5T
M=7`B"FUS9W-T<B`B5F5L9R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C,X"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-#D*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-E>6-H
M96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B5FES="(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"B,L(&9U>GIY
M"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DMO<G0@<V%M;65N9')A
M9SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,V"FUS9VED(")3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.30@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*(RP@
M9G5Z>GD*;7-G:60@(E-H;W<B"FUS9W-T<B`B5FES="(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-#D*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0X,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3<U,PIM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,@HC+"!F
M=7IZ>0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B5FES="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,34*(RP@9G5Z>GD*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5FES92!F:6QT
M97)I:V]N970@:2!M96YY96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B5FES92!F:6QT97)I:V]N970@
M:2!M96YY96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D9O<FCE;F1S
M=FES;FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B1F]R:.5N9'-V:7-N:6YG
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!486)L92!2;W<@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B1F]R:.5N9'-V:7-N:6YG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4Q"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3<U,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!U<&QO
M860B"FUS9W-T<B`B5FES('-L971T961E(&5L96UE;G1E<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3D*(RP@9G5Z>GD*;7-G:60@(E-H
M;W=E<G,B"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-C`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-C$*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")6:7-T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,@IM<V=I9"`B
M4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z,SDQ"B,L(&9U>GIY"FUS9VED(")3:')I
M;FLB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HV.#0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S0V"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@P-"!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HX-C8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z.3`Q(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDS.`HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY-C8@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z.3DV"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I
M;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]!=71H+U-I9VYU<"YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")3:6=N('5P
M(@IM<V=S='(@(E-I9VYE<G0B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C@Y"FUS9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D(@IM<V=S
M='(@(E)E9VES=')E<B!D96<@;VT@:6MK92!R96=I<W1R97)T(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,S8*(RP@9G5Z>GD*;7-G:60@(E-I
M9VYA='5R92(*;7-G<W1R(")$:6X@<VEG;F%T=7(Z(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E-I9VYA='5R
M92!!;&=O<FET:&TB"FUS9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*(RP@9G5Z
M>GD*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")$:6X@<VEG;F%T=7(Z(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(P-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R.0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(S,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$P.`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-PIM<V=I9"`B4VEZ92(*;7-G
M<W1R(")3=/AR<F5L<V4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]B;W1T;VTN:6YC.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS
M9W-T<B`B2&]P<"!O=F5R('9E9&QI:V5H;VQD(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C0S,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-#@T('!O+W1R86YS;&%T
M:6]N+G!H<#HV-C8*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V,"!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3(P-`IM<V=I9"`B4VMI<'!E9"XN+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V"B,L(&9U>GIY"FUS9VED(")3;&]V86MI82(*;7-G<W1R(").;W)M86PB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V"B,L(&9U>GIY"FUS9VED(")3;&]V96YI82(*;7-G<W1R(").;W)M86PB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8S"B,L(&9U>GIY
M"FUS9VED(")3;F]W(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8T"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E
M<B(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V-0HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8V"B,L
M(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B5FES
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C<*(RP@9G5Z
M>GD*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(E9I<W0B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W-@HC+"!F=7IZ>0IM<V=I9"`B4VYO
M=R!D97!T:#H@(@IM<V=S='(@(B`@("!%;6YE.B`B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(X,`IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4V]L;VUO;B!)<VQA
M;F1S(@IM<V=S='(@(D]P<&1A=&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PHC+"!F=7IZ>0IM<V=I9"`B4V]M
M86QI82(*;7-G<W1R(").;W)M86PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y,34*(RP@9G5Z>GD*;7-G:60@(E-O<G0@;W)D
M97(@<V5L96-T:6]N(@IM<V=S='(@(E-O<G1E<FEN9W-R96MK96;X;&=E(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X,2!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C$S"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*
M;7-G<W1R(")&:7)M86%D<F5S<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3;W5T:"!!9G)I8V$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@
M(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G
M:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B2&IE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T
M=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$U"B,L(&9U>GIY"FUS9VED(")3<&%C
M97(B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,L(&9U>GIY"FUS9VED(")3
M<&%C:6YG(@IM<V=S='(@(E5T=FED97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG
M(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")3<&%I
M;B(*;7-G<W1R(")5='9I9&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.CDU"B,L(&9U>GIY"FUS9VED(")3<&%M(@IM<V=S='(@(DQA9W)E('-O
M;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B4W!E<VEA;'1E9VYI;FYT87-T
M:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R
M(")696QG(&%L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8V"B,L(&9U>GIY"FUS9VED(")3<&QI="!C;VQU
M;6XB"FUS9W-T<B`B5F5L9R!A;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I9"`B
M4W!L:70@<F]W(@IM<V=S='(@(E9E;&<@86QL92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@
M(E9I:W1I9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@
M(DQO9V<@:6YN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8X
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E-T86YD
M87)D(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A
M<G0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M-#,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-30X
M"FUS9VED(")3=&%R="(*;7-G<W1R(")3=&%R="(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-3@Y(&QI8B](;W)D92]&;W)M+G!H<#HR-SDX"B,L(&9U>GIY
M"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(E-T87)T(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*(RP@9G5Z>GD*;7-G:60@(E-T871E
M(&]R(%!R;W9I;F-E(@IM<V=S='(@(E-T870O1GEL:V4@*$%R8F5I9"DB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U
M<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E-T871U<R!F;W(@;&]C86QE("5S+BXN
M("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-`HC+"!F
M=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1&EN(&EN9F]R
M;6%S:F]N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*(RP@
M9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D9R82UA9')E
M<W-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(R-0HC+"!F=7IZ>0IM<V=I9"`B4W1R:6YG(&QI
M<W0B"FUS9W-T<B`B4W9A<G1E;&ES=&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@U-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O
M<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(DYO=&ES(&QY='1E<B`E<R!I
M:VME(&9U;FYE="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S
M-2!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW.`IM<V=I9"`B
M4W5B:F5C="(*;7-G<W1R(")%;6YE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV-C@*(RP@9G5Z>GD*;7-G:60@(E-U8FIE8W0@4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(D1I;B!O9F9E;G1L:6=E(&[X:VME;"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,S(@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N
M<&AP.C,Q,PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E-E;F0B"@HC.B!S:6=N
M=7`N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R
M97%U97-T('1O(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T
M(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(*(RP@9G5Z>GD*;7-G:60@(E-U8G-C<FEP="(*;7-G
M<W1R(")396YD(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q,R!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`B4W5K<V5S<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M861D960@)R5S)R!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(E<R!B;&4@;&%G
M="!T:6P@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O
M<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(E<R!B;&4@
M;&%G="!T:6P@)7,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,2!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+B(*;7-G<W1R(")(96YD96QS
M96X@8FQE('-L971T970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"`G
M)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)7,@8FQE(&QA9W0@=&EL
M("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*(RP@9G5Z>GD*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G
M92!61E,M8F%C:V5N9#H@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-34*(RP@9G5Z>GD*;7-G:60@
M(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B2W5N;F4@:6MK92!L86=E(%9&4RUB86-K96YD.B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L86=E(%9&4RUB
M86-K96YD.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)R(*
M;7-G<W1R("));FYS=&EL;&EN9V5N92!B;&4@;W!P9&%T97)T+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=W)O=&4@)7,B"FUS9W-T<B`B)7,@8FQE(&QA9W0@=&EL("5S+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*(RP@
M9G5Z>GD*;7-G:60@(E-U9&%N(@IM<V=S='(@(E5T=FED97(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-3@*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@
M(E-U;6UA<GDB"FUS9W-T<B`B4V%M;65N9')A9R(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T
M<B`B16UN92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HW,0HC+"!F=7IZ
M>0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")%;6YE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,V.`IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W.0HC+"!F=7IZ
M>0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")%;6YE(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"B,L(&9U
M>GIY"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")%;6YE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W.`HC+"!F=7IZ>0IM<V=I
M9"`B4W5N<FES93H@(@IM<V=S='(@(B`@("!%;6YE.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")3=6YS
M970B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.#$*(RP@9G5Z>GD*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B`@
M("!%;6YE.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$S"B,L(&9U>GIY"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R
M(")"97-K<FEV96QS92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-C4*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B26UP;W)T97(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`W"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")N879N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G
M:60@(E-U<FYA;64B"FUS9W-T<B`B;F%V;B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-V86QB87)D
M(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B
M4W=A>FEL86YD(@IM<V=S='(@(E/X:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*(RP@9G5Z>GD*;7-G:60@(E-W
M961E;B(*;7-G<W1R("),97-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(E-W:71Z97)L
M86YD(@IM<V=S='(@(E/X:R(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.CDX"B,L(&9U>GIY"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H
M('1E<FUS(@IM<V=S='(@(E3X;2!S^'!P96QK=7)V96XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3
M>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M
M(@IM<V=S='(@(D9R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-S`*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(D9R82(*
M"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED
M(")44U8@9FEL92(*;7-G<W1R(")4:71T96PB"@HC.B!L:6(O2&]R9&4O54DO
M5&%B;&4N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B
M5&ET=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4')O<&5R=&EE
M<R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"B,L(&9U>GIY"FUS
M9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN
M9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")486EW86XB"FUS9W-T
M<B`B4_AK(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM
M<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P
M"B,L(&9U>GIY"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(D1A=&\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.34*(RP@9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B0G)U:V5R;F%V
M;CHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,38X"FUS9VED(")4
M87-K<R(*;7-G<W1R(")/<'!G879E<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3DW"B,L(&9U>GIY"FUS9VED(")496QE<&AO;F4@3G5M8F5R
M(@IM<V=S='(@(DYA=FXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.`IM
M<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,3(*(RP@9G5Z>GD*;7-G:60@(E1E;7!E<F%T
M=7)E(@IM<V=S='(@(D1I;B!S:6=N871U<CHB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3@V"B,L(&9U>GIY"FUS9VED(")496UP97)A='5R
M93H@(@IM<V=S='(@(D1I;B!S:6=N871U<CHB"@HC.B!L:6(O2&]R9&4O5&5M
M<&QA=&4N<&AP.C(Q,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&QA=&4@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(E9E9&QE9V=E="!B;&4@
M:6MK92!F=6YN970N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*(RP@
M9G5Z>GD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B5S(%!'4"!A9&UI;FES=')A<VIO;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8T,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C
M97!T(')E<75E<W0B"FUS9W-T<B`B1V]D=&$@9F]R97-P^')S96P@9F]R96SX
M<&EG(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-C@Y"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R(")';V1T
M82!F;W)E;/AP:6<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(P,PHC+"!F
M=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R(")495]K<W0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S8U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M2W5N('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B5&5X="!A;&EG;B(*
M;7-G<W1R(").97-T92!S:61E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I9"`B5&5X='1O<"(*
M;7-G<W1R(")495]K<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B
M4_AK(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDT-`HC+"!F=7IZ>0IM<V=I
M9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R(")$
M=2!H87(@8FQI="!L;V=G970@=70N(#QB<B`O/B!486MK(&9O<B!A="!D=2!B
M<G5K=&4@<WES=&5M970N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@
M9&]E<VXG="!Y970@97AI<W0N($-R96%T:6YG(&$@;F5W(&]N92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V.0HC+"!F=7IZ>0IM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M1&5T(&5R(&EN9V5N(&UE;&1I;F=E<B!I(&1E;FYE('!O<W1B;VMS96XN(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,CD*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM
M<V=S='(@(DUE;&1I;F=E;B!S;VT@:&%R(&)L:71T('-K<F5V970@:&%R(&)L
M:71T('-T96YG="X@079S;'5T=&5R+B(*"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,38P(&QI8B](;W)D92]097)M<RYP:'`Z,3<Q(&QI8B](;W)D92]097)M
M<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3DT(&QI8B](;W)D
M92]097)M<RYP:'`Z,C`U(&QI8B](;W)D92]097)M<RYP:'`Z,C(S"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,C,U(&QI8B](;W)D92]097)M<RYP:'`Z,C<T
M"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G
M:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Y"FUS9VED(")4:&4@
M8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(DMA;&5N9&5R9&%T
M82!E<B!U9WEL9&EG(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8V-`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M
M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@
M9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R(")$96X@9F]R97-P
M=7)T92!O<'!G879E;B!E<B!I:VME('-T;W1T970N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B3W!P9OAR:6YG96X@7"(E<UPB(&)L92!L86=T
M('1I;"!A9')E<W-E8F]K96XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,3<Q"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4$=0+6[X:VME;"!E
M<B!PY6MR979D(&9O<B#E('9E<FEF:7-E<F4@<VEG;F5R="!M96QD:6YG+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C8*(RP@9G5Z
M>GD*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*
M(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P
M9V%V96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B1&5N(&9O
M<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="YP:'`Z,3(W"B,L(&9U>GIY"FUS9VED(")4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R(")3^'1T92!F;W(@<&5R<V]N;&EG(%!'4"!N^&MK96QP87(@
M:W)E=F5R(&5N('-I:VME<B!W96(M=&EL:V]B;&EN9RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW.`HC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&5V96YT(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N
M(@IM<V=S='(@(DAE;F1E;'-E;B!B;&4@;&%G="!T:6P@:2!D:6X@:V%L96YD
M97(N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.#$@;&EB+TAO<F1E+G!H<#HU,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP
M.C$W-"!L:6(O2&]R9&4N<&AP.C0Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$V-`IM<V=I9"`B5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-C0*;7-G:60@(E1H92!F:6QE
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B5&AE(&9O;&QO=VEN
M9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y
M<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G
M;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE
M960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE
M87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@
M9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3`X-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(Q-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@:&5L<"!F:6QE("5S(&1I9&XG="!S=&%R="!W
M:71H(#P_>&UL(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HX
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET971E;B!<
M(B5S7"(@8FQE('-L971T970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3,V"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE
M9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@V,0IM<V=I9"`B5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(U.0IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R
M969S+G!H<#HR.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E
M<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D
M871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,U
M(&QI8B](;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S4*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S4@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)P;2YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W=E8F-P<"YP:'`Z-#`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI
M9VAL:71E+G!H<#HS.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E
M;"YP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS
M9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB)7-<(B!B;&4@<VQE='1E="XB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB)7-<(B!B;&4@;&%G<F5T
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R
M96UO=F5D+B(*;7-G<W1R("))9&5N=&ET971E;B!<(B5S7"(@8FQE(&QA9W)E
M="XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR.#0*(RP@9G5Z
M>GD*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")$96X@<W!E<VEF:7-E<G1E(&9I;&5N(&5K<VES=&5R97(@:6MK
M92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ
M,#@*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S
M:VQI<W0N(@IM<V=S='(@(DAA;F1L:6YG96X@:&%R(&)L:71T(&QA9W0@=&EL
M(&1I;B!L:7-T92!O=F5R(&AA;F1L:6YG97(N(@H*(SH@;&EB+U9&4R]S<6PN
M<&AP.C$Q,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O
M<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&5N
M('-P97-I9FES97)T92!F:6QE;B!E:W-I<W1E<F5R(&EK:V4N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM
M<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,Q,0IM<V=I9"`B5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C4P(&QI8B](;W)D
M92]$871A+W1S=BYP:'`Z,3<W"B,L(&9U>GIY"FUS9VED(")4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(E-I9VYA='5R
M96X@:W5N;F4@:6MK92!E<G-T871T97,N(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z.3,*;7-G:60@(E1H92!U<V5R)W,@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM
M<V=S='(@(D)R=6ME<F5N<R!L961I9R]O<'!T871T(&EN9F]R;6%S:F]N(&)L
M92!L86=R970N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU,@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3`S(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C
M:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")$970@97(@:6YG96X@;65L
M9&EN9V5R(&D@9&5N;F4@<&]S=&)O:W-E;BXB"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H96UE
M<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(E9E9&QE9V=E
M="!B;&4@:6MK92!F=6YN970N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92XB"FUS9W-T<B`B1&5T(&5R(&EN9V5N(&UE;&1I;F=E<B!I(&1E
M;FYE('!O<W1B;VMS96XN(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C,T,`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D1E="!E<B!I
M;F=E;B!A;'1E<FYA=&EV92!D96QE<B!S;VT@:V%N('9I<V5S(&EN;&EN92XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES
M(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+B(*;7-G
M<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H
M92!S>7-T96TN("5S+B(*;7-G<W1R(")$970@;W!P<W1O9"!E="!P<F]B;&5M
M('5N9&5R('-L971T:6YG96X@878@)7,N($UE;&1I;F<@9G)A('-E<G9E<F5N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B1&5T(&]P<'-T;V0@970@<')O8FQE;2!U
M;F1E<B!S;&5T=&EN9V5N(&%V("5S+B!-96QD:6YG(&9R82!S97)V97)E;B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB1&5T(&]P
M<'-T;V0@970@<')O8FQE;2!V960@9FIE<FYI;F<@878@<&]S=&)O:W-E;BX@
M365L9&EN9R!F<F$@<V5R=F5R96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")$
M970@;W!P<W1O9"!E="!P<F]B;&5M('5N9&5R('-L971T:6YG96X@878@)7,N
M($UE;&1I;F<@9G)A('-E<G9E<F5N(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M('5P9&%T:6YG("<E<R<Z("5S(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N
M(&9E:6P@=6YD97(@;W!P9&%T97)I;F<@878@:&5N9&5L<V5N.B`E<R(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0G)O=W-E<BYP:'`Z.3`T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z,S@*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D1E
M="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@9F]R<_AK('#E(.4@=FES92!D96YN
M92!M96QD:6YG<V1E;&5N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HT,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q
M"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E
M:6P@=F5D(&EM<&]R=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M979E;G0Z("5S+B(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R
M(&EM<&]R=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,N(@H*(SH@;&EB+TAO<F1E
M+T1A=&$O:6UC+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@
M(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@:6UP;W)T97)I;F<@878@:&5N
M9&5L<V5N.B`E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(D1E="!O
M<'!S=&]D(&5N(&9E:6P@=F5D(&EM<&]R=&5R:6YG(&%V(&AE;F1E;'-E;CH@
M)7,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS
M9W-T<B`B(@HB1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T97)I;F<@
M878@8G)U:V5R96YS(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXZ("4B"B)S
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW.0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N
M(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE
M;&0N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@;W!P9&%T
M97)I;F<@878@:&5N9&5L<V5N.B`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#DU('!O+W1R86YS;&%T:6]N+G!H<#HQ,3`Q('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,C(V"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!O<&5N:6YG('1H
M92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP:'`@=VET:"!T
M:&4@(@HB9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S(&9R;VT@
M=&AE('AM;"!P87)S97(N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-C,*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R(&]P<&1A=&5R:6YG
M(&%V(&AE;F1E;'-E;CH@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C8U"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U
M;F1E<B!O<'!D871E<FEN9R!A=B!H96YD96QS96XZ("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,`HC+"!F=7IZ>0IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B1&5T
M(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!O<'!D871E<FEN9R!A=B!H96YD96QS
M96XZ("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U
M,PHC+"!F=7IZ>0IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B1&5N;F4@=&IE;F5R
M96X@<W3X='1E<B!I:VME(&1E;&EN9R!A=B!M87!P97(N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.#(*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.38*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3$R"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C(P,`IM<V=I9"`B5&AI<R!A8W1I;VX@
M:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P
M9V%V96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO
M="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E(&]P
M<&=A=F5N(&5R(&EK:V4@:6UP;&5M96YT97)T+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G
M<W1R("(E<R!S97(@:6MK92!U="!S;VT@96X@9WEL9&EG('!O<W1B;VMS+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4U"B,L(&9U>GIY
M"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II
M<"!F:6QE+B(*;7-G<W1R("(E<R!S97(@:6MK92!U="!S;VT@96X@9WEL9&EG
M('!O<W1B;VMS+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3,P"B,L(&9U
M>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C
M87)D(&YU;6)E<BXB"FUS9W-T<B`B)7,@<V5R(&EK:V4@=70@<V]M(&5N(&=Y
M;&1I9R!P;W-T8F]K<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-PIM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#(*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P.#$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q-S0@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M-#@*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R.#(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S.34@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-#<*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y.#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,3,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M,S,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,#4@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S.3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,S<*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(V-#D@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,C(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,V.3(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,W,#`*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B5S(&AA<B!A=G-LY71T+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8P"FUS9VED(")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#`Q"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`X.0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3@*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#0*
M(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BXB"FUS9W-T<B`B1&5T=&4@;>4@=N9R92!E="!T86QL+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.#(U"FUS9VED("(B"B)4:&ES(&9I96QD(&UU
M<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T
M+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR
M96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I
M<R`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HV,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(X"FUS9VED(")4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B1&5T=&4@=&%L;&5T
M(&WE(';F<F4@;6EN<W0@,2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(X
M-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O
M;2!T:&4@8V]M;6%N9"!L:6YE+B(*;7-G<W1R(")$971T92!V:6YD=65T(&WE
M(&)L:2#E<&YE="!F<F$@)TYY(&UE;&1I;F<G('9I;F1U970B"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+B(*;7-G<W1R(")$96YN92!T:F5N97)E;B!S=/AT=&5R(&EK:V4@9&5L:6YG
M(&%V(&UA<'!E<BXB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$T-PIM
M<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I
M9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")$971T
M92!MY2!VYG)E(&5T('1A;&PN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")$
M971T92!V:6YD=65T(&WE(&)L:2#E<&YE="!F<F$@)TYY(&UE;&1I;F<G('9I
M;F1U970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<Q"FUS
M9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,C4*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(T,3$*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS
M9W-T<B`B5&ET=&5L(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Q
M,0IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(E1I;64@9F]R;6%T(@IM
M<V=S='(@(D9O<FUA="!PY2!N879N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(U,C(*(RP@9G5Z>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@
M(D9I;'1E<FEN;G-T:6QL:6YG97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4:6UO<BU,97-T92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S,B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS
M9W-T<B`B5&ET=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HX,`IM
M<V=I9"`B5&\B"FUS9W-T<B`B5&EL(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8R.0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS
M9W-T<B`B(@HB1F]R(.4@=F5L9V4@9FQE<F4L(&AO;&0@;F5D92!#;VYT<F]L
M("A00RD@96QL97(@0V]M;6%N9"`H36%C*2!M96YS(&1U(&ML:6MK97(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Q"B,L(&9U>GIY"FUS
M9VED(")4;V1A>2(*;7-G<W1R(")-96QD:6YG<W1E:W-T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G
M9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@
M(E1O9V\B"FUS9W-T<B`B5&EL(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&]K96QA=2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4S"B,L(&9U
M>GIY"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(").>2!M96QD:6YG(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0HC
M+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&EL(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"B,L(&9U
M>GIY"FUS9VED(")4;W`B"FUS9W-T<B`B5&EL(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE
M("A?=&]P*2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W
M"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&5D(@IM<V=S='(@(E5B97-V87)T
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED
M(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B3W)G86YI<V5R:6YG(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3<W.`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=6YI<VEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E1U<FME>2(*;7-G<W1R(")N
M^&MK96PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B5'5R
M:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0HC+"!F=7IZ>0IM<V=I
M9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(D]B<V5R=F5R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B
M5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C(*
M;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")5+E8N(&EN9&5X
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-3(@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*
M;7-G<W1R(")54DPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*
M;7-G<W1R(")54DPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")59V%N9&$B"FUS9W-T
M<B`B2V%L96YD97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S
M='(@(D=J96YO<'!R971T(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-C`*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3`P"FUS9VED(")5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S0V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B
M;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,P
M(&QI8B]61E,O;75S<6PN<&AP.C4P,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`E<R\E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E
M<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,#0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@
M(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O2&]R
M9&4O075T:"]S<6PN<&AP.C,W-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-1
M3'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW.#@*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")+
M86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HQ-S`@;&EB+U9&4R]F:6QE+G!H<#HQ-S4@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,3DW"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P,B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@
M4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-1
M3'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,CDU(&QI8B]61E,O
M;75S<6PN<&AP.C(W,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-S`*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI
M8B]61E,O;75S<6PN<&AP.C$R-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL
M(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C$R"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*
M;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z-SD@;&EB+TAO<F1E+T-O;7!R
M97-S+V=Z:7`N<&AP.C@R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R(")+;&%R=&4@:6MK92#E(&AE;G1E(&EN
M9F]R;6%S:F]N(&]M(&MV;W1E(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(T.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<
M(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")+
M86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HR-S`@;&EB+U9&4R]S<6PN<&AP.C,R,R!L:6(O5D93+VUU<W%L
M+G!H<#HS,S4*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R(")+86X@:6MK92!K;V)L
M92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW.2!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+B(*;7-G<W1R(")+
M86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,S<X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,X,@HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R
M=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-S8@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,S0X(&QI8B]61E,O;75S<6PN<&AP.C,V,0HC.B!L:6(O5D93+VUU
M<W%L+G!H<#HS-CD@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<T"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z,S0X(&QI8B]61E,O<W%L+G!H<#HS-C`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V
M97)E;BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3<Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C0R(&QI8B]61E,O<W%L+G!H<#HR,3,@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,3<S"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X
M-B!L:6(O5D93+VUU<W%L+G!H<#HQ.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M-#$R"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0R,`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK
M:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O<W%L+G!H
M<#HS,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@
M:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW
M-3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VME(')E9VES=')E<F4@:6YS
M=&EL;&EN9V5N92!I(/AK=&5N+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C(W"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(E-E='0@:6YN('-E<G1I9FEK
M870@:&5R(@H*(SH@;&EB+TYE="])35-0+G!H<#HT-C`@;&EB+TYE="])35-0
M+T%U=&@N<&AP.C$Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B5S
M(&AA<B!S=F%R="!PY2!I;G9I=&%S:F]N96X@=&EL("5S+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,3,Y(&QI8B]61E,O9FEL92YP:'`Z,30T(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C$V-0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-S`*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G
M<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I
M:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C(Q.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,C<@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,P"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@
M=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-S,@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@
M4U%,<V5R=F5R96XN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-#<*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E
M<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C(R"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM
M<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$P.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C,Q-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,
M<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(U-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E
M<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR.38*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HU-C,@;&EB+U9&4R]M=7-Q;"YP:'`Z,C0Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@
M4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(T.2!L:6(O5D93
M+VUU<W%L+G!H<#HR,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z-#@U"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,P-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,C<*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(DMA;B!I:VME
M(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O;7-W;W)D+G!H<#HV,@IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B2V%N(&EK:V4@;W9E<G-E
M='1E(&1E='1E(%=O<F0M9&]K=6UE;G1E="(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HQ,C<@;&EB+U9&4R]F='`N<&AP.C$S,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B2VQA<G1E(&EK:V4@Y2!H96YT92!I;F9O<FUA<VIO;B!O;2!K=F]T
M92(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R(")+;&%R=&4@:6MK92#E(&AE;G1E(&EN9F]R;6%S:F]N(&]M(&MV;W1E
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C,@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,3,U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T,`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DML
M87)T92!I:VME(.4@:&5N=&4@:6YF;W)M87-J;VX@;VT@:W9O=&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"B,L(&9U
M>GIY"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B1VIE;F]P<')E='0B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`B06YG<F4@96YD<FEN9V5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B
M56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B1VIE;F]P<'1A('-E
M<VIO;B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,S`@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y.0IM<V=I9"`B56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S4P"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Y,PIM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4X"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8T"B,L(&9U>GIY"FUS9VED
M(")5;F9I;&5D(@IM<V=S='(@(D4M<&]S="(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C,X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(E5H
MY6YD=&5R="!K;VUP;VYE;G0@878@='EP96XZ("5S(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#D*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5
M;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C4@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HV.0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$U(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-@HC
M+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")5:VIE;G0@9&%T;R(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS
M9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#@R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N(&-O;6UA;F0Z("5S(@IM<V=S
M='(@(DQA<W0@;F5D(&UA<'!E;BAE*2(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`P"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N('5S
M97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")696YN;&ES="!S:W)I=B!I
M;FX@8G)U:V5R;F%V;B!O9R!P87-S;W)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"B,L(&9U>GIY"FUS
M9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")3;&5T
M="!NY7;F<F5N9&4@;OAK;&5R(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HR.3@*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B571E;B!N879N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I
M9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@R"B,L(&9U>GIY"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")3971T
M(&EN;B!S97)T:69I:V%T(&AE<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-S$P(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.34R"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.34X"B,L(&9U>GIY"FUS9VED(")5
M;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B57-U<'!O<G1E<G0@:6YN
M:&]L9',M='EP92XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"B,L(&9U
M>GIY"FUS9VED(")5;G1R86YS;&%T960B"FUS9W-T<B`B56)E<W9A<G0B"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#8@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ.3$*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S8*
M(RP@9G5Z>GD*;7-G:60@(E5P9&%T92(*;7-G<W1R(")3:7-T92!O<'!D871E
M<FEN9SHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T
M<B`B4VES=&4@;W!P9&%T97)I;F<Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C0X"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N
M="!S=&%T=7,B"FUS9W-T<B`B3W!P9&%T97(@<W1A='5S('#E(&%V<V5N9&5R
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(RP@
M9G5Z>GD*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(E-I<W1E(&]P<&1A
M=&5R:6YG.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D("<E<R<N(@IM<V=S
M='(@(E)E9&EG97(@)R5S)R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@P
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,C$Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@Q"FUS9VED(")5<&=R861E('-C
M<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M.#(*;7-G:60@(E5P;&]A9"(*;7-G<W1R("),87-T(&]P<"(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#`*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-`IM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,S4@<&\O=')A;G-L871I;VXN<&AP.CDR('!O+W1R86YS
M;&%T:6]N+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B57-A9V4Z(@IM<V=S='(@
M(D)R=6ME<FYA=FXZ(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S92!#
M=7)R96YT.B`E<R(*;7-G<W1R(")3;&5T="!NY7;F<F5N9&4@;OAK;&5R(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.`IM<V=I9"`B
M57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(S"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@
M9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C8U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,C`T"B,L(&9U>GIY"FUS9VED(")5<V5R($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B5S(%!'4"!A9&UI;FES=')A<VIO;B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS
M9W-T<B`B3&%G<F4@5F%L9R(*"B,Z('-I9VYU<"YP:'`Z-C0*(RP@9G5Z>GD*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(DQA9W)E(%9A;&<B
M"@HC.B!S:6=N=7`N<&AP.C$Y"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G
M<W1R(")&:6QT97)S=/AT=&4@97(@879S;.5T="!I(&1E='1E('-Y<W1E;65T
M+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W,B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(U-`HC+"!F=7IZ>0IM<V=I9"`B57-E<B!P97)M:7-S:6]N
M<R(*;7-G<W1R("),86=R92!686QG(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W,PHC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-34V(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.3<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,#(@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHV-2!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHQ,0IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B0G)U:V5R
M;F%V;B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3,Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92`G)7,G(&%L<F5A9'D@
M97AI<W1S+B(*;7-G<W1R(")-87!P96X@7"(E<UPB(&9I;FYE<R!A;&QE<F5D
M92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B
M57-E<FYA;64Z(@IM<V=S='(@(D)R=6ME<FYA=FXZ(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z
M("(*;7-G<W1R(")"<G5K97)N879N.B(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")5<V5R<R(*;7-G<W1R(")"<G5K
M97)N879N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`IM
M<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0HC+"!F
M=7IZ>0IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R(")$871O(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HQ,#D@;&EB+U9&4R]F:6QE+G!H<#HR,#(*(RP@9G5Z
M>GD*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(D1E;B!S<&5S:69I<V5R=&4@9FEL96X@96MS:7-T97)E<B!I:VME+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#,*(RP@9G5Z>GD*;7-G
M:60@(E9A8V%T:6]N(@IM<V=S='(@(DQO:V%S:F]N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C@V,0IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8V,@IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8R,2!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(V,PIM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F
M<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R
M,C@@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(R.3@*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3<*(RP@9G5Z>GD*;7-G
M:60@(E9A;'5E<R(*;7-G<W1R("));F=E;B!M96QD:6YG97(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`Y,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$W,`IM
M<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P-PHC+"!F=7IZ>0IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T
M<B`B5&ET=&5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C(X"FUS9VED(")697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HW,C0*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B
M4&5R<V]N;&EG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P,`HC
M+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E!E<G-O
M;FQI9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM
M<V=S='(@(D9E=&-H;6%I;#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC86P@
M<&%D9&EN9R(*;7-G<W1R(")&971C:&UA:6PZ("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@
M(E9E<G1I8V%L.B(*;7-G<W1R(")&971C:&UA:6PZ("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-S<*(RP@9G5Z>GD*;7-G:60@(E9E<GD@
M2&EG:"(*;7-G<W1R(")(^'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")6:65T($YA
M;2(*;7-G<W1R(").879N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*
M;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDY-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(@IM<V=S='(@(E9I<R`E<R(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G
M<W1R(")6:7,@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HW.0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R(")6:7,@:&5N
M9&5L<V4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HQ,#D*;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R(")6:7,@:&%N9&QI;F=E
M<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`W"FUS9VED(")6:7-I8FEL:71Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C$*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@Q"FUS9VED(")6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,SD*;7-G:60@(E=!4DXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E=A;&QI<R!A
M;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,0IM<V=I9"`B5V%R;FEN9R(*;7-G
M<W1R(")!9'9A<G-E;"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4@<&\O
M=')A;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HW,C4@<&\O=')A;G-L871I;VXN<&AP.C$P
M-#@@<&\O=')A;G-L871I;VXN<&AP.C$P-3<*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P-C4@<&\O=')A;G-L871I;VXN<&AP.C$P-S4@<&\O=')A;G-L871I
M;VXN<&AP.C$P.#4*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.34@<&\O=')A
M;G-L871I;VXN<&AP.C$Q,#$@<&\O=')A;G-L871I;VXN<&AP.C$R,38*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$R,C8@<&\O=')A;G-L871I;VXN<&AP.C$R
M,S(@<&\O=')A;G-L871I;VXN<&AP.C$R-3(*(RP@9G5Z>GD*;7-G:60@(E=A
M<FYI;F<Z("(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-0IM<V=I9"`B
M5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`U"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED
M960@8GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@X-PIM
M<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,SDP"B,L(&9U>GIY"FUS9VED(")796(@4VET
M92(*;7-G<W1R(")796)S:61E(&%D<F5S<V4B"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C,W"FUS9VED(")7965K;'DB"FUS9W-T<B`B56ME;G1L
M:6<B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ
M>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")696QK;VUM96XB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R(")696QK;VUM96X@=&EL("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L
M('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E9E;&MO
M;6UE;BP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B5FES;FEN9R!E;&QE<B!P;W-T8F]K
M<R!S;VT@<VMA;"!V:7-E<R!E='1E<B!I;FYL;V=G:6YG.B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")7:&%T(&ES('1H92!D
M96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR-`IM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,Q"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#0*(RP@9G5Z>GD*;7-G:60@(E=I9'1H(@IM<V=S='(@(E/X:R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,3$P"FUS9VED(")7:61T:"!I;B!#4U,@=6YI
M=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`HC
M+"!F=7IZ>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")3^&LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0HC+"!F
M=7IZ>0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(E/X:R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT.3`*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,W,@HC+"!F=7IZ>0IM
M<V=I9"`B5VEN9"(*;7-G<W1R(")3^&LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S<S"B,L(&9U>GIY"FUS9VED(")7:6YD($5A<FQY(@IM
M<V=S='(@(D%V<VSE='0Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*
M;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z(@IM
M<V=S='(@(E/X:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#4*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")!=G-LY71T.B`B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@
M(E=I<V1O;2(*;7-G<W1R(")3^&LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3<W"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES=',B"FUS9W-T<B`B
M0F5T<F]D9&4@861R97-S97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C4*(RP@9G5Z>GD*;7-G:60@(E=O<FLB"FUS9W-T<B`B96QL97(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-R!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$V-PIM<V=I9"`B5V]R:R!!9&1R97-S
M(@IM<V=S='(@(D9I<FUA861R97-S92(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DU"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@
M(D9I<FUA=&5L969O;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,34W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@
M=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,S0*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C$W"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R
M86EN=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,38*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3@*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3D*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S`V"FUS9VED(")8-3`Y=C,@97AT96YS
M:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B65DB"FUS9W-T<B`BY>4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S@V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,C<*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`BY>4B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P,@IM<V=I
M9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C,U"FUS9VED(")996%R;'DB"FUS9W-T<B`BY7)L:6<B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M"B,L(&9U>GIY"FUS9VED(")996UE;B(*;7-G<W1R("),97-T(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X.`IM<V=I9"`B665S
M(@IM<V=S='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E
M;65N=%]B;W1T;VTN:6YC.C8*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^
M72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S(V"FUS9VED(")9;W4@87)E(&YO="!A
M=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O261E;G1I
M='DN<&AP.C,P-`IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C
M:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#,Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.34Y
M"B,L(&9U>GIY"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N(@IM<V=S='(@(E9E;FYL:6=S="!R971T('1V971Y9&EG
M92!E;&QE<B!U9WEL9&EG92!A9')E<W-E<BXB"@HC.B!L:6(O2&]R9&4O1&%T
M82YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@
M;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@
M8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY-#0*(RP@9G5Z>GD*;7-G:60@(EEO=2!H
M879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B1&EN92!V86QG(&AA<B!B
M;&ET="!O<'!D871E<G0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(U,PIM
M<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@P"B,L(&9U>GIY"FUS9VED
M(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")6
M96YN;&EG<W0@<VMR:78@:6YN(&1E="!N>64@;F%V;F5T.B(*"B,Z(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B
M"@HC.B!L:6(O2&]R9&4N<&AP.C0T-PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(DMU;FYE(&EK
M:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N(@IM<V=S='(@(D1U(&WE(&)E<VMR:79E('!R;V)L96UE="!F^'(@9'4@
M:V%N('-E;F1E(&5N('!R;V)L96UR87!P;W)T+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT
M<R!T;R(*;7-G<W1R(")$=2!MY2!H82!M:6YS="#I;B!M;W1T86ME<BXB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*
M;7-G<W1R(")$=2!MY2!V96QG92!E;B!I9&5N=&ET970@<V]M('-K86P@<VQE
M='1E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM
M<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5N(&UO='1A:V5R+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B1'4@;>4@<W!E
M<VEF:7-E<F4@96X@;6]T=&%K97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"B,L(&9U>GIY"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM
M<V=S='(@(D1U(&WE(&;X<G-T('-P97-I9FES97)E(&9I;&5N('-O;2!S:V%L
M(&QE9V=E<R!V960N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N(@IM<V=S='(@(D1U(&WE(&;X<G-T('-P97-I9FES97)E(&9I;&5N('-O
M;2!S:V%L(&QE9V=E<R!V960N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII
M<"YP:'`Z,30T"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H
M870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(D1U(&WE('-P97-I9FES
M97)E(&5N(&UO='1A:V5R+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(D1U(&WE('-P97-I9FES
M97)E(&5N(&UO='1A:V5R+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(D1I;B`E<R!T:6QK
M;V)I;F<@:&%R(&?E='0@=70N(%9E;FYL:6=S="!L;V<@:6YN(&EG:F5N+B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U>GIY
M"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B17!O<W1A9')E
M<W-E;B!D:6XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,@HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")%<&]S
M=&%D<F5S<V5N(&1I;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@
M26YF;W)M871I;VXB"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.CDS-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9
M;W5R($YA;64B"FUS9W-T<B`B1G5L;'0@;F%V;B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE
M(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HY-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P
M<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(").971T
M;&5S97)E;B!D:6X@<W3X='1E<B!I:VME('9I<VYI;F<@878@9&5N;F4@='EP
M92!B:6QD97(@:6YL:6YE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R
M:6YT+FIS.C(W"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/<'1I;VX@
M*R!0('1O("(*(G!R:6YT+B(*;7-G<W1R("(B"B).971T;&5S97)E;B!D:6X@
M<W3X='1E<B!I:VME(&1E;FYE('5T<VMI9G1S;W!E<F%S:F]N96XN(%1R>6MK
M($MO;G1R;VQL+R(*(D]P<VIO;B`K(%`@9F]R(.4@<VMR:79E('5T+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#<*;7-G:60@(EEO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>3HB"FUS9W-T<B`B4W1A;F1A<F1I9&5N=&ET970B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DQ"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M
M93HB"FUS9W-T<B`B3F%V;F5T(&1I='0Z(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$T-0IM<V=I9"`B(@HB66]U<B!G971T97AT('9E<G-I;VX@:7,@=&]O
M(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN7&XB"B).
M;W0@86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B1&EN92!V
M86QG(&AA<B!B;&ET="!O<'!D871E<G0B"@HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C$U.`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+B(*;7-G<W1R(")$:6YE('9A;&<@:&%R(&)L:71T(&]P<&1A=&5R="(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"B,L(&9U>GIY"FUS9VED
M(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")4:F5N97(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EIA:7)E
M(@IM<V=S='(@(D9R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B
M6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C4V"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@
M(EM0<F]B;&5M<F%P<&]R=%TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=
M(@IM<V=S='(@(EML:6YJ92`E<R!A=B`E<UTB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$T-S(@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S(%!'4"!A9&UI;FES
M=')A<VIO;B(*"B,Z(&QI8B]A<&DN<&AP.C$S-`IM<V=I9"`B7T-,22(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(E]$
M871A5')E92(*;7-G<W1R(")$871O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R(")?4VQE='0B"@HC.B!L:6(O87!I+G!H
M<#HQ,30*(RP@9G5Z>GD*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B1W)U<'!E
M(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$X,0IM<V=I9"`B7TAE;'`B"FUS
M9W-T<B`B2&IE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C,*(RP@9G5Z>GD*;7-G:60@(E]);6%G92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN9R(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HR,#`*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB
M"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DV
M"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("),;V=G('5T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"B,L
M(&9U>GIY"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B1FIE<FX@
M<&%R(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$W,`IM<V=I9"`B7T]P=&EO
M;G,B"FUS9W-T<B`B5F%L9R(*"B,Z(&QI8B]A<&DN<&AP.C$Q.`HC+"!F=7IZ
M>0IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<G-O;FQI9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-@HC+"!F=7IZ>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@
M(D9J97)N('!A<B(*"B,Z(&QI8B]A<&DN<&AP.C$P-@HC+"!F=7IZ>0IM<V=I
M9"`B7U-E='5P(@IM<V=S='(@(E9E;&<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G
M:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(D9O<FCE;F1S=FES
M;FEN9R(*"B,Z(&QI8B]A<&DN<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B7U5S
M97)S(@IM<V=S='(@(D)R=6ME<FYA=FXB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDQ,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@
M(D%D<F5S<V5B;VLB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q"B,L(&9U
M>GIY"FUS9VED(")A;B!E<G)O<B!H87,@;V-C=7)E9#HB"FUS9W-T<B`B/&(^
M16X@9F%T86P@9F5I;"!H87(@;W!P<W3E='0Z/"]B/B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3`S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G
M<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<P(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")C86QM(@IM<V=S='(@(D%V8G)Y="(*"B,Z(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HV,#@*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0T-2!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-34P('!O+W1R86YS;&%T:6]N+G!H<#HV,3$*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C<T.2!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$P('!O+W1R86YS;&%T
M:6]N+G!H<#HX.#<*(RP@9G5Z>GD*;7-G:60@(F1O;F4B"FUS9W-T<B`B1F5R
M9&EG(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4U,B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-3@T('!O+W1R86YS;&%T:6]N+G!H<#HV,3,*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C<W."!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$R('!O+W1R86YS
M;&%T:6]N+G!H<#HX.#D*(RP@9G5Z>GD*;7-G:60@(F9A:6QE9"(*;7-G<W1R
M(")%+7!O<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<X
M"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HX-S`*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B1FEL
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.0HC+"!F=7IZ>0IM<V=I9"`B
M9F]U;F0Z("(*;7-G<W1R(")!=G-LY71T.B`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U."!L:6(O0FQO8VLO
M;65T87(N<&AP.C,X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(E<R!PY2`E<R`E<R(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G
M:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#@*;7-G:60@(FDQ.&XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4X-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R.0IM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8X(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<V"B,L(&9U>GIY"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B26YL:6YE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*(RP@
M9G5Z>GD*;7-G:60@(FQI;F5S72(*;7-G<W1R("));FQI;F4B"@HC.B!L:6(O
M5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR.#@@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P-@IM<V=I9"`B;F%M92(*;7-G
M<W1R(")N879N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,W.`HC+"!F=7IZ
M>0IM<V=I9"`B;F]T(&-H86YG960B"FUS9W-T<B`B06YG<F4@96YD<FEN9V5R
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,0HC+"!F=7IZ>0IM<V=I9"`B
M;F]T(&9O=6YD(@IM<V=S='(@(D]B:F5K=&5T(&)L92!I:VME(&9U;FYE="(*
M"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R,@HC+"!F=7IZ>0IM<V=I9"`B;F]T
M(&EM<&QE;65N=&5D(@IM<V=S='(@(D9E<F1I9R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,3(T-0HC+"!F=7IZ>0IM<V=I9"`B;F]T('EE="!I
M;7!L96UE;G1E9"(*;7-G<W1R(")$96X@9F]R97-P=7)T92!O<'!G879E;B!E
M<B!I:VME(&EM<&QE;65N=&5R="XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C@Y-0HC+"!F=7IZ>0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(").;W1A=&)L
M;VMK(&9O<B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#@*(RP@9G5Z>GD*;7-G:60@(G!E<F-E;G0B"FUS
M9W-T<B`B4VMR:78@=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`HC+"!F=7IZ
M>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D]R9V%N:7-E<FEN9R(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3@*;7-G:60@(G-H;W<@9&EF9F5R96YC
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S,PIM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-SD*(RP@9G5Z>GD*
M;7-G:60@(G-T96%D>2(*;7-G<W1R(")/<'!D871E<B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3$Y"B,L(&9U>GIY"FUS9VED(")T87-K(&QI<W0B"FUS
M9W-T<B`B4W9A<G1E;&ES=&4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S(U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")T:&4@2&]R9&4@4$\@9FEL
M92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#HB"FUS9W-T<B`B
M1&5N('-P97-I9FES97)T92!F:6QE;B!E:W-I<W1E<F5R(&EK:V4N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR
M.#(*(RP@9G5Z>GD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FTB"FUS9W-T<B`B5FES(&UA:6QL:7-T92!I;F9O<FUA<VIO;B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8X(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<V"B,L(&9U>GIY"FUS9VED(")U;FEF:65D(@IM<V=S='(@(D4M<&]S
M="(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C$W"B,L(&9U>GIY"FUS
M9VED(")U;FYA;65D(@IM<V=S='(@(E5T96X@;F%V;B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HS-S4*(RP@9G5Z>GD*;7-G:60@(G5P9&%T960B"FUS9W-T
M<B`B4VES=&4@;W!P9&%T97)I;F<Z(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R.0HC+"!F=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B
M:6YG96X@;6%P<&4@=F%L9W0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C,X"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*(RP@9G5Z
M>GD*;7-G:60@(G<Z(@IM<V=S='(@(D9W9#HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,PIM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VYL7TY,
M+G!O````````````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`W,S0V,38`,3`T,3<S-C,P,#(`,#$V-#`V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@2&]R9&4@1'5T8V@@=')A
M;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`Q+3(P,#8@2F%N($MU:7!E
M<G,N"B,@2F%N($MU:7!E<G,@/&IR:W5I<&5R<T!L875W97)S8V]L;&5G92YN
M;#XL(#(P,#$M,C`P-BX*(R`*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T
M+4ED+59E<G-I;VXZ($AO<F1E(#,N,2XQ+6-V<UQN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`S+3$R(#`P.C,Q*S`Q,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#8M,#,M,3,@,C(Z-#`K,#$P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@1'5T8V@@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A
M9V\I(@IM<V=S='(@(B`H)7,@9&%G96X@9V5L961E;BDB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$S.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H4VYE;'1O971S("5S*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&)I;FYE;B`E<R!D86=E
M;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@
M*'1O9&%Y*2(*;7-G<W1R("(@*'9A;F1A86<I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B
M("AM;W)G96XI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM
M<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H9VES=&5R96XI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B(&]P("(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!I
M<R!G965N(&1I<F5C=&]R>2XB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z
M,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!I<R!G965N(&=E;&1I9V4@:V5U
M>F4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW
M,3`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E
M9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!I<R!N
M:65T(&=E8V]N9FEG=7)E97)D(&EN(&AE="!(;W)D92!R96=I<W1E<BXB"@HC
M.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")<(B5S7"(@=')E92!W965R9V5V97(@;FEE="!G979O;F1E;BXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(B!A86X@:&5T(&=R;V5P96YS>7-T965M('1O96=E=F]E9V0N(@H*(SH@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E
M;2XB"FUS9W-T<B`B7"(E<UPB(&%A;B!H970@<F5C:'1E;G-Y<W1E96T@=&]E
M9V5V;V5G9"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB(&ES(&YI970@
M86%N9V5M86%K=#H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!G96)R=6EK="!V86X@
M)2XR9DU"('1O96=E<W1A86X@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S
M(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!E;B`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B5D(&1A9V5N('1O="!U=R!W86-H
M='=O;W)D('9E<G9A;'0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B
M"FUS9W-T<B`B)60M9&%G('9O;W)U:71Z:6-H="(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO
M=&EC92(*;7-G<W1R("(E<R`M($]P;65R:VEN9R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S('9I;F=E<F%F9')U:R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!/
M;F1E<FAO=61S=V5R:WIA86UH961E;B`M($)E=F5S=&EG:6YG(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S
M($EN<W1E;&QE;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R
M("(E<R!I;G-C:')I:G9E;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE
M;G0B"FUS9W-T<B`B)7,@9V5B<G5I:V5R<V]V97)E96YK;VUS="(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@R(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S4P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,R
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DT"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!B97-T86%T
M(&%L+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&]P
M("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@:7,@9V5R965D
M(&]M(&]N9&5R<W1A86YD92!G97-E;&5C=&5E<F1E(&]N9&5R:&]U9'-W97)K
M>F%A;6AE9&5N('5I="!T92`B"B)V;V5R96XN(%9I;FL@9&4@8F5W97)K:6YG
M*&5N*2!A86X@9&EE('4@;W`@9&ET(&UO;65N="!W:6QT('5I='9O97)E;BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&ES('9E<F5I
M<W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T96XB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,R"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEE
M="!G979O;F1E;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S
M='(@(B5S('1O="`E<R!V86X@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@
M0F]O:R(*;7-G<W1R("(E<R=S(&%D<F5S8F]E:R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M0V%L96YD87(B"FUS9W-T<B`B)7,G<R!A9V5N9&$B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($YO=&5P860B"FUS9W-T<B`B)7,G<R!N;W1I=&EE8F]E:R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,G<R!T86ME;FQI:G-T(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS
M9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z($1I="!B97)I8VAT(&MO;70@;6ES
M<V-H:65N(&YI970@=F%N(&1E9V5N92!D:64@:&5T(&)E=V5E<G0@=&4@>FEJ
M;BX@5V5E<R`B"B)V;V]R>FEC:'1I9R!B:6H@:&5T(&ML:6MK96X@;W`@;&EN
M:W,@:6X@:&5T(&)E<FEC:'0@;V8@9&4@869Z96YD97(@(@HB<&5R<V]O;FQI
M:FME(&EN9F]R;6%T:64@=&4@<W1U<F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L('=I;F1V;&%G96X@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S
M(@IM<V=S='(@(BP@=VEN9'9L86=E;B`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FEA8F5L('9A;B`E<R!T;W0@
M)7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-S0X(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-CD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM('-E;&5C=&5R96X@+2TB
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R
M;6%T(@IM<V=S='(@(C$R('5U<G-W965R9V%V92(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@
M=75R<W=E97)G879E(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*
M;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('5U<G,B"@HC.B!F<F%M97=O
M<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T
M<B`B/%9O<FEG92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED
M(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN(@IM<V=S='(@(D5E;B!D871A8F%S92!B86-K96YD(&ES('9E<F5I<W0@
M=F]O<B!D:70@8FQO:RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W,0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T
M<B`B17(@:&5E9G0@>FEC:"!E96X@9F%T86QE(&9O=70@=F]O<F=E9&%A;B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES('9E
M<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@8V]D97)E;BXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"B)%96X@;W!E;F)A<F4@4$=0('-L975T96P@:7,@=F5R
M96ES="!O;2!E96X@;VYD97)T96ME;F0@8F5R:6-H="!T92!V97)I9FGK<F5N
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G
M:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"B)%96X@;W!E;F)A<F4@4$=0('-L975T96PL('!R
M:7;I(%!'4"!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I
M<W0@(@HB;VT@965N(&)E<FEC:'0@=&4@9&5C;V1E<F5N+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"B)%96X@;W!E;F)A<F4@4$=0('-L975T96PL('!R:7;I(%!'4"!S;&5U=&5L
M(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@(@HB;VT@965N(&)E
M<FEC:'0@=&4@;VYD97)T96ME;F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB
M165N(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)344@<VQE
M=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B`B"B)V97)E:7-T(&]M(&5E
M;B!B97)I8VAT('1E(&1E8V]D97)E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5E
M;B!O<&5N8F%R92!3+TU)344@<VQE=71E;"P@<')I=ND@4R]-24U%('-L975T
M96P@96X@=V%C:'1W;V]R9')E9V5L('II:FX@(@HB=F5R96ES="!O;2!E96X@
M8F5R:6-H="!T92!O;F1E<G1E:V5N96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M165N(&]P96YB87)E(%--24U%('-L975T96P@:7,@=F5R96ES="!O;2!E96X@
M8F5R:6-H="!T92!C;V1E<F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")"
M97=O;&MI;F<@=F]O<B`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*
M;7-G<W1R("),:6-H=&4@<F5G96X@=F]O<B`Q,BXP,"!U=7(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@
M4F%I;B(*;7-G<W1R(")296=E;B!V;V]R(#$R+C`P('5U<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(D)U:65N('9O;W(@,3(N,#`@=75R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")3;F5E=7=B=6EE;B!V;V]R(#$R+C`P
M('5U<B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!
M32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S
M='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@
M(D]V97(@9&5Z92!E9&ET;W(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B3W9E<BXN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@
M(D%B<V)O='1O;2(*;7-G<W1R(")!8G-B;W1T;VTB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D
M;&4B"FUS9W-T<B`B06)S;6ED9&QE(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")4;V5G86YG(&=E=V5I9V5R9"!B:6H@
M:&5T(&UA:V5N('9A;B!61E,@9&ER96-T;W)Y+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E1O96=A;F<@9V5W96EG97)D(&)I
M:B!H970@;6%K96X@=F%N(%9&4R!B97-T86YD+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(D%C8V]U;G1I;F9O<FUA=&EE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(D%C8V]U
M;G1W86-H='=O;W)D(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS
M9W-T<B`B06-C;W5N="!B979R;W)E;BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(E9E<F%N
M='=O;W)D:6YG(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T
M<B`B5&]E=F]E9V5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO
M9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R
M(")#:&EL9"!G<F]E<"!T;V5V;V5G96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(D-H:6QD
M(')E8VAT('1O979O96=E;B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B2&EE<B!T;V5V;V5G96XZ
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR
M,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3FEE=7=E(&=R;V5P
M('1O979O96=E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D
M($YE=R!097)M:7-S:6]N(@IM<V=S='(@(DYI975W(')E8VAT('1O979O96=E
M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E
M<UPB(@IM<V=S='(@(D5E;B!<(F-H:6QD9W)O97!<(B!A86X@7"(E<UPB('1O
M979O96=E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@7"(E<UPB(@IM<V=S='(@(D5E;B!<(F-H:6QD<F5C:'1<(B!A86X@7"(E
M<UPB('1O979O96=E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!
M9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B3FEE=7=E(&=E8G)U:6ME<B!T;V5V
M;V5G96XZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4U-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")+;VQO;2!T;V5V
M;V5G96XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T
M"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B3FEE=7=E(&QE9&5N
M('1O979O96=E;B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*
M;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E!A87(@=&]E=F]E9V5N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T
M<B`B2&5T("5S(&UE;G4@=&]E=F]E9V5N(&%L<R!E96X@36]Z:6QL82!3:61E
M8F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")6;V5G
M('1O92!A86X@861R97-B;V5K.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@
M8F]O:R(*;7-G<W1R(")6;V5G('1O92!A86X@;6EJ;B!A9')E<V)O96LB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B
M1V5B<G5I:V5R('1O979O96=E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O
M<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(EPB)7-<(B!A86X@:&5T('-Y
M<W1E96T@=&]E9V5V;V5G9"P@;6%A<B!K;VX@9V5E;B!E>'1R82`B"B)I;G-C
M:')I:G9I;F=S:6YF;W)M871I92!T;V5V;V5G96XZ("5S+B(*"B,Z('-I9VYU
M<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B7"(E
M<UPB(&%A;B!H970@<WES=&5E;2!T;V5G979O96=D+B!5(&MU;G0@;G4@86%N
M;65L9&5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR
M"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(E1O
M979O96=E;B!V86X@9V5B<G5I:V5R<R!I<R!U:71G97-C:&%K96QD+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S
M='(@(D%D<F5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S8F]E:R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4V"FUS9VED(")!9&UI
M;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G
M<W1R(")"96AE97(@+2!R96-H=&5N('9O;W(@86YD97)E(&=E8G)U:6ME<G,@
M:6YS=&5L;&5N(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D)E:&5E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-#,*;7-G:60@(D%D<R(*;7-G<W1R(")!9'9E<G1E;G1I97,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,0IM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A;FGK(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&=E<FEJ92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*
M;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI
M9VXB"FUS9W-T<B`B56ET;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G
M<W1R(")5:71L:6IN:6YG.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX
M-PIM<V=I9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")!
M;&QE(&=E875T:&5N=&EC965R9&4@9V5B<G5I:V5R<R(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`B06QL92!G<F]E<&5N(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDQ"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M06QL92!R96-H=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B06QL92!V:65R('II:F1E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*
M;7-G<W1R(")-965R9&5R92!A9')E<W-E;B!T;V5S=&%A;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(DEN<W1E;&QE;B!V86X@9V5O
M<F1E;F1E(&QI:G-T('1Y<&4@=&]E<W1A86X_(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X
M:7-T<R(*;7-G<W1R(")"97-T86%T(&%L(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T
M<B`B06QT97)N871I979E($E-4U`@86%N;65L9&EN9R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D(@IM<V=S='(@(D%L=&5R;F%T:65F($E-4U`@=V%C:'1W;V]R9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T:65V92!)35-0(&=E8G)U
M:6ME<G-N86%M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*
M;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L=&5R
M;F%T:65F(&4M;6%I;&%D<F5S(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N
M871I979E('-J86)L;VYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@IM<V=I9"`B06QT97)N871E
M('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T:65V92!T96MS=#HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(W"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R(")!;65R:6MA86YS
M(%-A;6]A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")%96X@;VYG96QD
M:6=E('=A87)D92!O<&=E9V5V96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C
M=7)E9"XB"FUS9W-T<B`B17(@:&5E9G0@>FEC:"!E96X@;VYB96ME;F1E9F]U
M="!V;V]R9V5D86%N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38*;7-G:60@(D%N9&]R<F$B"FUS
M9W-T<B`B06YD;W)R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0*;7-G:60@(D%N9V]L82(*;7-G
M<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P"FUS9VED(")!;F=U:6QL82(*;7-G
M<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N:65M
M92!P<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS
M9VED(")!;G-W97(B"FUS9W-T<B`B06YT=V]O<F0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U"FUS
M9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R8W1I8V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG
M=6$@96X@0F%R8G5D82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HS-B!A9&UI
M;B]T96UP;&%T97,N<&AP.C<T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]5
M22YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM
M<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B5&]E<&%S<VEN9R(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES
M="(*;7-G<W1R(")4;V5P87-S:6YG96YL:6IS="(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*
M;7-G<W1R(")4;V5P87-S:6YG(&ES(&=E<F5E9"XB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA
M<F5S(@IM<V=S='(@(D]P(&-H:6QD<VAA<F5S('1O97!A<W-E;B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R
M;W9E(@IM<V=S='(@(D=O961K975R96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G:60@(D%P<')O>&EM871E(%-I>F4B
M"FUS9W-T<B`B1V5S8VAA='1E(&=R;V]T=&4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T
M<B`B07!R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)I<V-H("A7:6YD
M;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*;7-G
M:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(D%R8VAI969B97-T86YD
M<V=R;V]T=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0IM<V=I
M9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D%R8VAI969N86%M(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")7965T('4@
M>F5K97(@9&%T('4@:&5T(&%A;FUE;&1I;F=S=F5R>F]E:R!V86X@)7,@=VEL
M="!V97)W:6ID97)E;C\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_
M(@IM<V=S='(@(E=E970@=2!Z96ME<B!D870@=2!<(B5S7"(@96X@86QL92!S
M=6)G<F]E<&5N('=I;'0@=F5R=VEJ9&5R96X_(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-@IM<V=I
M9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN:>LB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;65N:>LB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB
M"FUS9W-T<B`B07)M965N<R`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(DMU;G-T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,`IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L
M86YD(@IM<V=S='(@(D%S8V5N<VEO;B!E:6QA;F0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<V-I
M:2!K=6YS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")!>FGK+U!A8VEF
M:7-C:&4@4F5G:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS
M9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B3VT@8F5V97-T:6=I;F<@=G)A
M9V5N('9O;W(@:&5T('5I='9O97)E;B!V86X@;VYD97)H;W5D<W=E<FMZ86%M
M:&5D96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-0IM<V=I
M9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D]P9')A8VAT(&MO;&]M
M;65N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E!O9VEN
M9R!O;2!E96X@;FEE="!B97-T86%N9&4@9W)O97`@=&4@=F5R=VEJ9&5R96XN
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD(')E8VAT('1E('9E<G=I
M:F1E<F5N+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD(')E8VAT('1E(&)E
M=V5R:V5N+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G
M<W1R(")0;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F1E('-H87)E('1E(&)E
M=V5R:V5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"FUS9VED
M(")!='1R:6)U=&5S(@IM<V=S='(@(D%T=')I8G5T96XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T
M(@IM<V=S='(@(D%U9W5S='5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.0IM<V=I9"`B075S=')A
M;&EA(@IM<V=S='(@(D%U<W1R86QIZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@*;7-G:60@(D%U
M<W1R:6$B"FUS9W-T<B`B3V]S=&5N<FEJ:R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M8WER<W%L.B!V97)E:7-T92!I;6%P(&5X=&5N=&EE(&YI970@9V5V;VYD96XN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED
M(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z(&)A8VME;F0@:&5E
M9G0@;FEE="!D92!V97)E:7-T92!B96MW86%M:&5D96XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?8WER=7,Z('9E<F5I<W1E(&EM87`@97AT96YT:64@;FEE="!G979O
M;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G
M:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W
M:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z('9E<F5I<W1E($944"!E>'1E
M;G1I92!N:65T(&=E=F]N9&5N+B!#;VUP:6QE97(@4$A0(&UE="!D92`M+65N
M86)L92TB"B)F='`@;W!T:64N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@=F5R96ES
M=&4@24U!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VMR8C4Z('9E<F5I<W1E(&MR8C4@97AT96YT:64@;FEE="!G979O;F1E;BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z('1O979O
M96=E;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R<W1E=6YD('9O
M;W(@06-T:79E("(*(D1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS
M9W-T<B`B(@HB075T:%]L9&%P.B!697)W:6ID97)E;B!V86X@9V5B<G5I:V5R
M<R!W;W)D="!N:65T(&]N9&5R<W1E=6YD('9O;W(@06-T:79E("(*(D1I<F5C
M=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G
M:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z('9E<F5I<W1E($Q$05`@97AT96YT
M:64@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE="!I;B!S=&%A="!G96)R
M=6EK97(@)7,@=&]E('1E('9O96=E;BX@1&4@<V5R=F5R(&UE;&1T.B`B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<R(*;7-G<W1R(")!=71H7VQD87`Z($YI970@:6X@<W1A870@9V5B<G5I:V5R
M("5S('1E('9E<G=I:F1E<F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.
M:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!B:6H@=&4@=V5R:V5N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?
M;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!":6IW97)K
M96X@=F%N(&=E8G)U:6ME<G,@=V]R9'0@;FEE="!O;F1E<G-T975N9"!V;V]R
M($%C=&EV92`B"B)$:7)E8W1O<GDN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@=F5R
M96ES=&4@34-!3"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H
M.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?<VUB875T:#H@=F5R96ES=&4@<VUB875T:"!E>'1E;G1I92!N
M:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O061M:6XN
M<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R(")!=71H96YT:6-A=&EE(&]P($E-05`@<V5R=F5R
M(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B
M"FUS9W-T<B`B075T:&5N=&EC871I92!M:7-L=6MT(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G
M<W1R(")!=71H96YT:6-A=&EE(&UI<VQU:W0N("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B075T:&5N
M=&EC871I92!G97=E:6=E<F0@9&]O<B!D92!2041)55,@<V5R=F5R+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@R"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T:&5N
M=&EC871I92!O<"!&5%`@<V5R=F5R(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@
M=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71H96YT:6-A=&EE
M(&]P(&1E(%--0B!S97)V97(@;6ES;'5K="XB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G
M<W1R(")"97-C:&EK8F%R92!V96QD96XZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,0IM<V=I9"`B
M07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I9'IJ86XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R
M(")"3T9(($5X8W5S97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S
M='(@(D%C:'1E<F=R;VYD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G
M<W1R(")!8VAT97)G<F]N9&ML975R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*
M;7-G<W1R(")&;W5T(&ME<F)E<F]S=V%C:'1W;V]R9"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@
M=7-E<FYA;64N(@IM<V=S='(@(D9O=71E(&ME<F)E<F]S9V5B<G5I:V5R<VYA
M86TN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-0IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA
M;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS.`IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR
M96EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I
M8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I<V-H("A)4T\M.#@U.2TQ
M,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,T"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A
M;F=L861E<V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,S"FUS9VED(")"87)B861O<R(*;7-G<W1R
M(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")"87-I<R!A9F)E96QD:6YG96YD:7)E
M8W1O<GD@7"(E<UPB(&YI970@9V5V;VYD96XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"FUS9VED(")"87-E
M;&EN92(*;7-G<W1R(")"87-I<VQI:FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y"FUS9VED(")"
M96QA<G5S(@IM<V=S='(@(E=I="!R=7-L86YD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-0IM<V=I
M9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:>LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P"FUS9VED
M(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,`IM<V=I9"`B
M0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q"FUS9VED(")"97)M
M=61A(@IM<V=S='(@(D)E<FUU9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V"FUS9VED(")":'5T
M86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B
M5F5R:F%A<F1A9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB
M(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D)L
M;VL@7"(E<UPB('9A;B!T;V5P87-S:6YG(%PB)7-<(B!N:65T(&=E=F]N9&5N
M+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B
M0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO:VEN<W1E;&QI;F=E;B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@
M5'EP92(*;7-G<W1R(")";&]K='EP92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")6
M970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0S"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV
M:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")"
M;V]K;6%R:W,B"FUS9W-T<B`B0F]O:VUA<FMS(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R
M9&5R(@IM<V=S='(@(E)A;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R(")286YD9&EK=&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G
M<W1R(")286YD96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R"FUS9VED(")";W-N:6$@86YD($AE
M<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYIZR!E;B!(97)Z96=O=FEN82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R
M(")"96ED96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0X"FUS9VED(")";W1S=V%N82(*;7-G<W1R
M(")";W1S=V%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,@IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D]N9&5R
M:V%N="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#<*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T
M<B`B0F]U=F5T(&5I;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0*;7-G:60@(D)R87II;"(*
M;7-G<W1R(")"<F%Z:6QIZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W"FUS9VED(")"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=',@26YD:7-C
M:&4@3V-E86%N(%1E<G)I=&]R:75M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,@IM<V=I9"`B0G)U
M;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,W"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QG87)I:F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y
M"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(D]N9V5O<F1E;F1E(&QI
M:G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-@IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@
M(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD*;7-G:60@(D)U<G5N9&DB"FUS
M9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B
M0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*
M;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23"!$
M:7-T<FEB=71I97!U;G1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")#7V5L96EG96YS8VAA<'!E;BXN+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(D-A8VAE(&EN:71I86QI
M<V%T:64@:7,@;FEE="!A9F=E<F]N9"XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3$V"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0P(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S
M='(@(D%G96YD82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B2V%L;2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X"FUS
M9VED(")#86UB;V1I82(*;7-G<W1R(")#86UB;V1J82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`*
M;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R;V5N(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@
M<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(DMA;B!W86-H='=O;W)D(&YI970@875T;VUA
M=&ES8V@@<F5S971T96XL(&YE96T@8V]N=&%C="!O<"!M970@9&4@(@HB<WES
M=&5E;6)E:&5E<F1E<BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F
M:6QE(%PB)7-<(B(*;7-G<W1R(")+86X@;FEE="!N86%R(&)E<W1A;F0@7"(E
M<UPB('-C:')I:G9E;B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I
M9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S
M+B(*;7-G<W1R(")+86X@9V5E;B!E>'1E<FYE('-E<W-I96AA;F1L97(@8F5H
M97)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*
M;7-G<W1R(")+86X@;FEE="!V97)B:6YD96X@;65T($E-05`@<V5R=F5R.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")+86X@8F5S=&%N9"!<(B5S7"(@;FEE="!O<&5N96XN(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,0IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A;F%D82(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$R('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ
M,0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%F8G)E:V5N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R(")0<F]B;&5E;7)A<'!O<G0@869B<F5K96XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")+86X@8F5S=&%N9"!<(B5S7"(@;FEE="!V97)W:6ID97)E;BXB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@IM<V=I
M9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M(")+86X@9V5E;B!T:6ID96QI:FME(&1I<F5C=&]R>2!V:6YD96XN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I
M9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+B(*;7-G<W1R(")+86X@;FEE="!D;V]R9V%A;B!Z;VYD97(@)W1A<F=E
M=$9I;&4G('!A<F%M971E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!D:7)E8W1O<GD@7"(E<UPB
M(&YI970@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q
M;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L
M("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")+86X@;FEE="!V97)W:6ID
M97)E;CL@)60@8VAI;&1R96X@8F5S=&%A;BXB"@HC.B!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B
M"B)+86X@;FEE="!O<&YI975W(')A;F=S8VAI:VME;BP@:&5T(&%A;G1A;"!I
M;G9O97)E;B!O;2!O<&YI975W('1E("(*(G)A;F=S8VAI:VME;B!K;VUT(&YI
M970@;W9E<F5E;B!M970@:&5T(&]P9V5S;&%G96X@86%N=&%L+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM
M<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BXB"FUS9W-T<B`B2V%N(&)E<FEC:'0@;FEE="!N86%R(&AE="!O<&=E9V5V
M96X@;G5M;65R('9E<G-T=7)E;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U"FUS9VED(")#87!E
M(%9E<F1E(@IM<V=S='(@(DMA87`@5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T
M:6]N(@IM<V=S='(@(D]P<V-H<FEF="(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G
M<W1R(")$<F%G97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G
M:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")#871E9V]R:67K
M;B!E;B!L86)E;',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-0IM<V=I9"`B0V%Y;6%N($ES;&%N
M9',B"FUS9W-T<B`B0V%Y;6%N(&5I;&%N9&5N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N
M92(*;7-G<W1R(")496PN;G(N;6]B:65L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0
M<F]P97)T:65S(@IM<V=S='(@(D-E;&5I9V5N<V-H87!P96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B
M0V5L;"!P861D:6YG.B(*;7-G<W1R(")#96P@=G)I:F4@<G5I;71E.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")#96QE:6=E;G-C
M:&%P<&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B0V5L<W!A
M=&GK<FEN9SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"FUS
M9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5&5L+FYR+FUO8FEE;"(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E33RTX.#4Y
M+3$T*2(*;7-G<W1R(")+96QT:7-C:"`H25-/+3@X-3DM,30I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM
M<V=I9"`B0V5N=&5R(@IM<V=S='(@(DUI9&1E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30*;7-G
M:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")#96YT<F%A
M;"!!9G)I:V%A;G-E(%)E<'5B;&EE:R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*
M;7-G<W1R(")#96YT<F%A;"!%=7)O<&5E<R`H25-/+3@X-3DM,BDB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R
M=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")#97)T:69I8V%A=&1E=&%I;',B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I
M9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B0V5R=&EF:6-A871E:6=E
M;F%A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW
M"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")#97)T:69I
M8V%A=&)E;&5I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,0IM<V=I9"`B0VAA9"(*;7-G<W1R
M(")4<VIA860B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B
M"FUS9W-T<B`B5VEJ>FEG96XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(E=I:GII9R!U=R!W86-H='=O;W)D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB5VEJ>FEG(&1E(&YA86TL(&%D
M<F5S(&5N(&]N9&5R=&5K96YI;F<@9&EE(&UE;B!Z:65T(&)I:B!H970@;&5Z
M96X@96X@(@HB8F5A;G1W;V]R9&5N('9A;B!U=R!E+6UA:6QS+B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I
M;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U
M<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B)7:6IZ:6=E;B!V86X@=7<@=V%C:'1W;V]R
M9"!W;W)D="!N:65T(&]N9&5R<W1E=6YD(&1O;W(@9&4@:'5I9&EG92`B"B)C
M;VYF:6=U<F%T:64N($YE96T@8V]N=&%C="!O<"!M970@=7<@<WES=&5E;6)E
M:&5E<F1E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(DMA<F%K=&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")#;VYT
M7W)O;&5E<B!L:6YK+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.0IM<V=I9"`B0VAI;&4B"FUS
M9W-T<B`B0VAI;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q"FUS9VED(")#:&EN82(*;7-G<W1R
M(")#:&EN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B0VAI;F5E<R!V
M97)E96YV;W5D:6=D("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S
M='(@(D-H:6YE97,@=')A9&ET:6]N965L("A":6<U*2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB
M"FUS9W-T<B`B2VEE<R!T;V5P87-S:6YG.B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D
M(@IM<V=S='(@(DMI97,@965N('=A8VAT=V]O<F0B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R
M;F%M92(*;7-G<W1R(")+:65S(&5E;B!G96)R=6EK97)S;F%A;2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B2VEE<R!D871U;7=E97)G879E.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O
M<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")+:65S(&QI:G-T<W1I:FQT>7!E("AV
M;V]R(&=E;W)D96YD92!L:6IS=&5N*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8*;7-G:60@(D-H
M<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B0VAR:7-T;6%S(&5I;&%N9"(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,30@9G)A;65W;W)K+TYE=%]335,O
M4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(D-L87-S9&5F:6YI=&EE
M('9A;B`E<R!N:65T(&=E=F]N9&5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")(
M96QD97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(DU3
M3V9F:6-E('1A9W,@=VES<V5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M.0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B5VES('%U97)Y(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(E=I<R!G96)R
M=6EK97(Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(E=I<R!G96)R=6EK97(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B
M0VQE87(@=7-E<B!D871A(@IM<V=S='(@(E=I<R!G96)R=6EK97)S9&%T82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS
M9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(DQA=&4@;W!K;&%R:6YG96XB
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV
M,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2VQI:R!O;2!V
M97)D97(@=&4@9V%A;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%14
M4"(*;7-G<W1R(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R
M"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B4VQU:70@<V-H97)M(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*;7-G
M<W1R(")7;VQK96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(E9R;V5G
M92!B97=O;&MI;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D)E=V]L:W0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4R"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G
M<W1R(")#;V-O<R`H2V5E;&EN9RD@96EL86YD96XB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R
M(@IM<V=S='(@(EII:F)A;&L@:6YK;&%P<&5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B26YG96ML87!T92!R86YD96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8R"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")#;VQO;6)I82(*
M"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")+;&5U<B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#,*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.`HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Y('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME
M<B(*;7-G<W1R(")+;&5U<F5N:VEE>F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@R.`IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R
M(")+;&5U<G-E;&5C=&EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(DMO;&]M
M;65N.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@
M(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B2V]L;VUT:71E;',B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T
M<B`B4W1R:7!S(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(V"FUS9VED(")#
M;VUM86YD(@IM<V=S='(@(D]P9')A8VAT(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(D]P9')A8VAT
M<VAE;&PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B3W!M97)K:6YG(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(D%L9V5M96YE(&YA86TB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,`IM<V=I
M9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F5N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*
M;7-G<W1R(")"961R:6IF(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q
M"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B0V]M<'5T97)S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N
M(@IM<V=S='(@(D-O;F1I=&EE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B0V]N9&ET:65S(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,B"FUS9W-T<B`B5F5R<V-H:6QL96X@:6X@8V]N9FEG=7)A
M=&EE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S
M(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"B)#;VYF:6=U<F%T:64@=F]O<B!H
M970@<WEN8VAR;VYI<V5R96X@;65T(%!$02=S+"!3;6%R='!H;VYE<R!E;B!/
M=71L;V]K+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@
M(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(D-O;F9I
M9W5R871I92!I<R!V97)O=61E<F0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS
M9W-T<B`B)7,@8V]N9FEG=7)E<F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G
M<W1R(")"979E<W1I9R!W86-H='=O;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-0IM<V=I9"`B
M0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S"FUS9VED(")#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(DMO
M;F=O+"!$92!$96UO8W)A=&ES8VAE(%)E<'5B;&EE:R!V86X@9&4B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B5F5R8FEN9&EN9R!M:7-L=6MT
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B5F5R8FEN9&EN
M9R!M:7-L=6MT.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9&EN9RP@;65T(&1E(&]P96YB
M87)E('-L975T96QS97)V97(L(&ES(&=E=V5I9V5R9"XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@HB5F5R8FEN9&EN9RP@;65T
M(&1E(&]P96YB87)E('-L975T96QS97)V97(L(&ES(&=E=V5I9V5R9"X@4F5D
M96XZ("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W
M-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B5F5R8FEN9&EN9R!M970@1E10('-E<G9E<B!M:7-L=6MT+B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(T(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")!9')E<W-E
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D%D<F5S<V5N('II:FX@;65T
M('-U8V-E<R!A86X@=7<@861R97-B;V5K('1O96=E=F]E9V0N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N
M=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(D-O;G1E
M;G0@='EP92!V86X@9V5C;VUP<FEM965R9"!B97-T86YD.B`B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B26YH;W5D('9A;B!<(B5S7"(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@
M(D1O;W)G86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU.`IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM
M<V=S='(@(D-O;VL@96EL86YD96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#;V]K:64B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:>MR96XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P:>MR96X@;6ES;'5K=#H@)7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS
M9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W!I965R('-E;&5C=&EE
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G
M:60@(D-O<W0@240B"FUS9W-T<B`B2V]S=&5N($E$(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,PIM
M<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-PIM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("))=F]O<FMU<W0B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@
M(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B2V]N
M(%!'4"!B97)I8VAT(&YI970@8V]D97)E;CH@(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4Z("(*;7-G<W1R(")+;VX@4$=0(&)E<FEC:'0@;FEE="!O
M;F1E<G1E:V5N96XZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`B2V]N(&)E<FEC:'0@;FEE="!3+TU)344@8V]D97)E
M;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(DMO;B!B97)I8VAT(&YI970@4R]-24U%(&]N9&5R=&5K96YE;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M(@IM<V=S='(@(DMO;B!A9')E<R`E<R!N:65T('1O979O96=E;BXB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0X,@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DMO;B!G965N('9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R
M(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$W,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C$U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B2V]N('1E9V]E9"`E<R!N
M:65T(&-O;G1R;VQE<F5N+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(")+;VX@;FEE="!V97)B:6YD96X@;65T($Q$05`@<V5R=F5R+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG
M($944#H@)7,B"FUS9W-T<B`B2V]N(&YI970@=F5R8FEN9&5N(&UE="!S97)V
M97(@7"(E<UPB(&UE="!&5%`Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B2V]N(&=E96X@9&ES=')I8G5T:65L:6IS="`E<R!M86ME;BXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(DMO;B!01U`@
M9&%T82!N:65T(&1E8V]D97)E;CH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+B(*;7-G<W1R(")+;VX@4R]-24U%(&1A=&$@;FEE="!D96-O
M9&5R96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+;VX@861R97,@)7,@;FEE="!V
M97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+;VX@
M9&ES=')I8G5T:65L:6IS="`E<R!N:65T('9E<G=I:F1E<F5N+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R(")+;VX@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB(&YI
M970@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S
M"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B2V]N(&AE="!E+6UA:6QA9')E<R!V
M86X@9&4@;VYT=F%N9V5R(&YI970@8F5P86QE;BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M2V]N(&-O;7!L971E(&%D<F5S8F]E:R!N:65T(&]P:&%L96XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B2V]N(&-O;7!L971E(&1I<W1R:6)U=&EE;&EJ<W0@;FEE
M="!O<&AA;&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(")+
M;VX@8V]M<&QE=&4@;&EJ<W0@=F%N(&1I<W1R:6)U=&EE;&EJ<W1E;B!N:65T
M(&]P:&%L96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G
M>2!<(B5S7"(N(@IM<V=S='(@(DMO;B!S=')A=&5G:64@7"(E<UPB(&YI970@
M;&%D96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B2V]N(&1I<F5C=&]R>2!<(B5S7"(@;FEE
M="!M86ME;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N(@IM<V=S='(@(DMO;B!D92!O<&5N8F%R92!S;&5U=&5L
M(&YI970@=F5R:W)I:F=E;B!V86X@9&4@<VQE=71E;'-E<G9E<BXB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V]N(%PB
M)7-<(B!N:65T(&]P96YE;B!V;V]R('-C:')I:G9E;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(DMO
M;B`E<R!N:65T(&]P96YE;BXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R
M(")+;VX@;VYD97)H;W5D<W1A:V5N;6]D=6QE("5S(&YI970@;W!E;F5N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMO;B!D
M:7)E8W1O<GD@7"(E<UPB(&YI970@;W!E;F5N+B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B2V]N(&1E($Q$05`M<V5R=F5R(&YI970@8F5R96EK96XN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DMO
M;B`E<R!N:65T(&QE>F5N+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D
M(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B
M"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@HB2V]N(&AE="!W86-H='=O;W)D('9A;B!D92!G
M97=E;G-T92!G96)R=6EK97(@;FEE="!R97-E='1E;BX@4V]M;6EG92!O9B!A
M;&QE("(*(F1E=&%I;',@>FEJ;B!N:65T(&IU:7-T+B!0<F]B965R(&]P;FEE
M=7<@;V8@;F5E;2!C;VYT86-T(&]P(&UE="!D92`B"B)S>7-T965M8F5H965R
M9&5R+"!W86YN965R('4@=F5R9&5R92!H=6QP(&YO9&EG(&AE969T+B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<U"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B2V]N($%#3"!N:65T(&]P:&%L
M96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")+;VX@861R97-B;V5K("5S
M(&YI970@;W!H86QE;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(DMO;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@;W!H86QE;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")+;VX@9&ES=')I8G5T:65L:6IS
M=&5N("5S(&YI970@;W!H86QE;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E
M<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")+;VX@<V5R=F5R8F5K=V%A
M;6AE9&5N(&YI970@;W!H86QE;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B2V]N(&-O;F9I9W5R871I92!N:65T('1E<G5G>F5T=&5N+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(")+;VX@9&ER96-T;W)Y
M(%PB)7-<(B!N:65T('9E<G=I:F1E<F5N+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMO;B!C;VYF:6=U<F%T
M:64@)7,@;FEE="!O<'-L86%N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")+;VX@
M9V5E;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S;&%A;BXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(")+
M;VX@9V5E;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S;&%A;CH@)7,B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E
M<UPB+B(*;7-G<W1R(")+;VX@<V5T=7`@=7!G<F%D92!S8W)I<'0@;FEE="!O
M<'-L86%N(&%L<SH@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DMO;B!H
M970@8F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N9"!N:65T(&]P<VQA86X@)7,N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I
M;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A
M;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B)+;VX@:&5T
M(&-O;F9I9W5R871I96)E<W1A;F0@)7,@;FEE="!O<'-L86%N+B!5(&MU;G0@
M;V8@Z^MN('9A;B!D92!O<'1I97,@(@HB9V5B<G5I:V5N(&]M(&1E(&-O9&4@
M=&5R=6<@;W`@=&4@<VQA86X@;W`@)7,@;V8@;VYD97)S=&%A;F1E(&-O9&4@
M:&%N9&UA=&EG("(*(FYA87(@)7,@:V]P:>MR96XN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+;VX@9&4@3$1!4"US97)V
M97(@;FEE="!D;V]R>F]E:V5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB
M"FUS9W-T<B`B2V]N(%PB)7-<(B!N:65T(&QO<VMO<'!E;&5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B2V]N(&%D<F5S("5S(&YI970@8FEJ=V5R:V5N+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMO;B!D:7-T<FEB=71I96QI:G-T
M("5S(&YI970@8FEJ=V5R:V5N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N
M9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(")+;VX@8V]N9FEG
M=7)A=&EE('9O;W(@7"(E<UPB(&YI970@=V5G<V-H<FEJ=F5N.B`E<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN(@IM<V=S='(@(B(*(DMO;B!D92!-;WII;&QA(%-I9&5B87(@
M;FEE="!V:6YD96XN(%IO<F<@97)V;V]R(&1A="!D92!S:61E8F%R(&]P96X@
M:7,N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E
M<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"B)+;VX@9V5B<G5I:V5R(%PB)7-<(B!D
M92!V;VQG96YD92!R96-H=&5N(&]P(&1E(&UA<"!<(B5S7"(@;FEE="!G979E
M;CH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED
M(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B1V5T96QD92!T96MS="(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N
M=')Y(@IM<V=S='(@(DQA;F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(D-U<G-U<W-E;B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(DUA:V5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X
M"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(DUA86L@965N(&QI;FLB
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS
M9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(DUA86L@965N(&YI975W
M92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"FUS
M9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B36%A:R!S=6)M87!P
M96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I
M9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")%:6=E;F%A<G)E8VAT
M96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C$R"FUS9VED(")#
M<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B0W)E9&ET8V%R9&YU;6UE<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR;V%T:>LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8T"FUS9VED(")#=6)A(@IM<V=S='(@(D-U8F$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B
M"FUS9W-T<B`B2'5I9&EG92`T(&9A<V5N(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(DAU:61I
M9V4@<V5S<VEE<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C
M:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(DAU
M:61I9V4@=&EJ9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B2'5I9&EG92!54DP@:7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B2'5I9&EG92!G96)R
M=6EK97)S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R
M<F5N="!796%T:&5R(@IM<V=S='(@(DAU:61I9R!W965R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD
M:71I;VXZ("(*;7-G<W1R(")(=6ED:6=E(&-O;F1I=&EE.B`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#
M=7)R96YT('-T>6QE(@IM<V=S='(@(DAU:61I9V4@<W1I:FPB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T
M<B`B06%N<&%S<V5N('9A;B!T86ME;B!T:6ID96YS(&%A;FUE;&1I;F<@8FEJ
M("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DMN:7!P96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS
M9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C=&EE(&MN:7!P96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8W"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B0WEP<G5S(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+
M3TDX+5(I(@IM<V=S='(@(D-Y<FEL;&ES8V@@*$M/23@M4BDB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2DB"FUS9W-T<B`B0WER:6QL:7-C:"`H5VEN9&]W<RTQ,C4Q*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0WER:6QL:7-C:"]5:W)A:6YS("A+
M3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV.`IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS
M9W-T<B`B5'-J96-H:7-C:&4@4F5P=6)L:65K(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C<R"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(D133B`H>FEE(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<"DB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")$86=E;&EJ:W,B"@HC
M.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`B1&%T851R964@8G)O=W-E<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R-S`*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G
M<W1R(")$871A8F%S92!D;V]R>F]E:V5N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,SDX"FUS9VED(")$871E(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@
M4F5C96EV960B"FUS9W-T<B`B1&%T=6T@3VYT=F%N9V5N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C<X.0IM<V=I9"`B1&%T92!S96QE8W1I;VXB
M"FUS9W-T<B`B1&%T=6T@<V5L96-T:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3$*;7-G:60@(D1A>2(*;7-G<W1R(")$86<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E
M7VQE=&4@0V]L=6UN(@IM<V=S='(@(E9E<E]W:6ID97(@:V]L;VTB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`B1&5C96UB97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$
M96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5C:6UA;&4@9V5T86QL96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS
M9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B26YS<')I;F=E;B!V97)K
M;&5I;F5N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@
M;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4W1A
M;F1A87)D(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B4W1A;F1A
M87)D(&ML975R(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")3=&%N9&%A
M<F0@:61E;G1I=&5I="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-0IM
M<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")3=&%N9&%A<F0@<VAE;&PB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I
M;VYS(@IM<V=S='(@(D1E9FEN:71I97,B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$P"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
M5F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S
M='(@(E9E<G=I:F1E<B!C96PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A
M9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S
M='(@(D=R;V5P('9E<G=I:F1E<F5N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(E9E<G=I
M:F1E<B!L;V<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE
M=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")296-H="!V97)W:6ID97)E;B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED
M(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E9E<G=I:F1E
M<B!E;B!W:7,@8F5R:6-H=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB
M"FUS9W-T<B`B5F5R=VEJ9&5R(&-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C
M;VQU;6XB"FUS9W-T<B`B5F5R=VEJ9&5R(&MO;&]M(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B0F5S=&%A;F0@86QT97)N871I968@<VIA
M8FQO;VX@=F5R=VEJ9&5R96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S
M='(@(E9E<G=I:F1E<B!B97)I8VAT96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")296-H=&5N('9A;B!<
M(B5S7"(@=F5R=VEJ9&5R96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS
M9W-T<B`B4F5C:'1E;B!E;B!E=F5N='5E;&4@<W5B<F5C:'1E;B!V;V]R(%PB
M)7-<(B!V97)W:6ID97)E;C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM
M<V=S='(@(E9E<G=I:F1E<B!R:6HB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L
M971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E
M;G1I='DB"FUS9W-T<B`B1V5S96QE8W1E97)D92!I9&5N=&ET96ET('9E<G=I
M:F1E<F5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")697)W
M:6ID97(@<W5B;6%P<&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN(@IM<V=S='(@(E9E<G=I:F1E<B!D92!H=6ED:6=E(&MO
M;&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM
M<V=S='(@(E9E<G=I:F1E<B!D92!H=6ED:6=E(')I:B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")3971U
M<"!U<&=R861E('-C<FEP="!<(B5S7"(@=F5R=VEJ9&5R9"XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DU"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(D%F;&5V97)T
M:6ID(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$96YE
M;6%R:V5N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*
M;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D)E<V-H<FEJ
M9B!H970@<')O8FQE96TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B0F5S8VAR:6IV:6YG
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#8*;7-G:60@(D1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T
M86EL<R`H;V]K(&EN($AO<F1E)W,@;&]G8F5S=&%N9"DZ(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HR,3`*;7-G:60@(D1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E
M=&%I;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S>7-T965M8F5H965R9&5R+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L
M;W!M96YT(@IM<V=S='(@(D]N='=I:VME;&EN9R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B1&%U=W!U
M;G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O
M:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")$875W<'5N="!V;V]R(&AE
M="!A9F=E;&]P96X@=75R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")$875W<'5N
M=#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B
M4FEC:'1I;F<@;&EN:W,@;F%A<B!R96-H="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(E)I8VAT:6YG(')E8VAT<R!N86%R(&QI
M;FMS(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C
M=&]R>2(*;7-G<W1R(")$:7)E8W1O<GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S
M='(@(C(T+75U<G,@=&EJ9'=E97)G879E/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")7
M965R9V%V96]P=&EE<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M(")'961E=&%I;&QE97)D92!W965R<W9O;W)S<&5L;&EN9R!T;VYE;B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B5V5E<G-V;V]R<W!E;&QI;F<@=&]N96X@*%1!
M1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDY"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")7965R9V%V969O<FUA870B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B5F]O<F)E<F5I9&EN9W-N;W1I
M9FEC871I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S`*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@
M(D1J:6)O=71I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3FEE="!V97)W:6ID
M97)E;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B
M1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T
M<B`B;6%I;G1E;F%N8V4N<&AP(&YI970@9&ER96-T(&%A;G-P<F5K96XB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O
M;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X
M.B(*;7-G<W1R(")"979A="!D92!E97)S=&4@<FEJ(&1E('9E;&1N86UE;C\@
M6F\@:F$L(&1I="!H;VMJ92!A86YV:6YK96XZ(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,@IM<V=I
M9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S"FUS
M9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI8V%A;G-E
M(%)E<'5B;&EE:R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*
M;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T
M<B`B1V5E;B!A8V-O=6YT/R!38VAR:6IF('4@:6XN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4S"FUS9VED(")$;W=N;&]A9"(*
M;7-G<W1R(")$;W=N;&]A9&5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#4S"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D
M("5S(@IM<V=S='(@(B5S(&1O=VYL;V%D96XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")$;W=N;&]A9"!G96=E
M;F5R965R9&4@8V]N9FEG=7)A=&EE(&%L<R!02%`@<V-R:7!T+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L
M:7-T(@IM<V=S='(@(D1R;W`@9&]W;B!L:6IS="(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B1')U9W,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M
M36%I;"(*;7-G<W1R(")%+4UA:6PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A
M=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES
M('-E<G9I8V4N(@IM<V=S='(@(B(*(D4M;6%I;"!N86%R(%--4R!G871E=V%Y
M('-T=75R<')O9W)A;6UA+"!V;V]R(&1R86=E<G,@9&EE(&1E>F4@<V5R=FEC
M92`B"B)O;F1E<G-T975N96XN(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B
M15)2(@IM<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4*;7-G:60@(D5C=6%D;W(B
M"FUS9W-T<B`B16-U861O<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM
M<V=I9"`B161I="(*;7-G<W1R(")"97=E<FME;B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T
M<B`B0FQO:R!B97=E<FME;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@
M(D=R;V5P(&)E=V5R:V5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E)E8VAT(&)E=V5R:V5N(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!0
M97)M:7-S:6]N<R(*;7-G<W1R(")296-H=&5N(&)E=V5R:V5N(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")296-H=&5N('9A
M;B`G)7,G(&)E=V5R:V5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B3W!T:65S(&)E
M=V5R:V5N('9O;W(Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(E)E8VAT96X@=F%N(%PB)7-<(B!B97=E<FME
M;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M4F5C:'1E;B!V86X@)7,@8F5W97)K96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")/;F1E<G=I:G,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<W"FUS9VED(")%9WEP="(*;7-G<W1R(")%9WEP=&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A
M;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L
M96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M;6%I
M;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R(")%+6UA:6QA9')E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R(")%+6UA:6QA9')E<W-E;B!M;V5T96X@;W9E<F5E;FMO;65N
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M
M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D4M;6%I;"!M970@8F5V
M97-T:6=I;F<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T
M<B`B12UM86EL(&YA87(@4TU3(&=A=&5W87DB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED(")%;6]T:6-O;G,B
M"FUS9W-T<B`B16UO=&EC;VYS(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E
M+B(*;7-G<W1R("),965G(&)E<FEC:'0N(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S
M=6QT+B(*;7-G<W1R(")'965N(')E<W5L=&%A="XB"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B3&5G92!Z;V5K=&5R;65N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I
M;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B
M26YV;V5G96X@=F%N(&%F8F5E;&1I;F=E;B!U:70@9F]T;V%L8G5M<R!I;B!T
M96MS="!I;G-C:&%K96QE;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R(")296-H=&ML:6MK96X@8V]N=&5X="!M96YU(&EN<V-H86ME;&5N
M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C<Y,PIM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B
M16EN9&IA87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")697)G
M<F]O="!E9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@HB1V5E9B!E96X@8F5V96EL:6=I;F=S=G)A86<@9&EE('4@
M9V5V<F%A9V0@=V]R9'0L('=A;FYE97(@:&5T(&YO9&EG(&ES(&]M('5W("(*
M(G=A8VAT=V]O<F0@=&4@<F5S971T96XL(&(N=BX@)W=A="!I<R!D92!N86%M
M('9A;B!U=R!H=6ES9&EE<C\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0IM<V=I9"`B16YT97(@
M=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(E9O97(@9&4@869B965L9&EN
M9R!54DP@:&EE<B!I;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W
M.B(*;7-G<W1R(")6;V5R(&]N9&5R<W1A86YD92!L971T97)S(&EN.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3D*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D5Q
M=6%T;W)I86%L($=U:6YE92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD*;7-G:60@(D5R:71R96$B
M"FUS9W-T<B`B17)I=')E82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M.`IM<V=I9"`B17)R;W(B"FUS9W-T<B`B1F]U="(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")&;W5T(&)I:B!M
M86ME;B!V86X@8FQO:SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S
M>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B1F]U="!B:6H@=F5R=VEJ9&5R96X@
M=F%N('-Y;F,@86YK97(Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S(@IM<V=S='(@(D9O=70@8FEJ('9E<G=I:F1E<F5N('9A
M;B!S>6YC(&QO9SH@)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S(@IM<V=S='(@(D9O=70@8FEJ(&]P:&%L96X@=F%N(&EN
M:&]U9#H@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z
M("5S(@IM<V=S='(@(D9O=70@8FEJ(&)I:G=E<FME;B!V86X@=V%C:'1W;V]R
M9#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB
M"FUS9W-T<B`B1F]U="!M970@92UM86EL8F5R:6-H="XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I
M;F<@7"(E<UPB+B(*;7-G<W1R(")&;W5T(&)I:B!S8VAR:6IV96X@=F%N(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<V"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S
M=&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%
M=&AI;W!IZR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B
M171H;FEC(@IM<V=S='(@(D5T;FES8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q
M-2!M:6YU=&5S(@IM<V=S='(@(D5L:V4@,34@;6EN=71E;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*
M;7-G<W1R(")%;&ME(#(@;6EN=71E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E
M<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")%;&ME(#,P('-E8V]N9&5N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B16QK92`U
M(&UI;G5T96XB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")%;&ME(&%A
M;FUE;&1I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED
M(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B16QK(&AA;&8@=75R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B16QK92!M:6YU
M=70B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B
M17AA;7!L92!V86QU97,Z(@IM<V=S='(@(E9O;W)B965L9'=A87)D96XZ(@H*
M(SH@861M:6XO8VUD<VAE;&PN<&AP.C4Q(&%D;6EN+W!H<'-H96QL+G!H<#HX
M,B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")%>&5C=71E(@IM<V=S
M='(@(E5I='9O97)E;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B56ET
M:VQA<'!E;B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*
M;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(EII:F)A;&L@=6ET:VQA
M<'!E;B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*
M;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")697)W86-H='1E("<I)R(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@
M(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS
M9W-T<B`B5F5R=V%C:'1T92!E;FME;"!W;V]R9"!O9B!A86YG96AA86QD92!Z
M;V5K=&5R;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(E9E<G9A;&1A='5M
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G
M:60@(D5X<&]N96YT(@IM<V=S='(@(D5X<&]N96YT(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B
M1D<@0V]L;W(B"FUS9W-T<B`B5F]O<F=R;VYD:VQE=7(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P
M(@IM<V=S='(@(D944"!U<&QO860@=F%N('-E='5P(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-Q;"YP:'`Z,C(P"FUS9VED(")&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B3W!H86QE;B!V;V]R:V5U<G-I
M;G-T96QL:6YG96X@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY
M.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(E9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&ES(&UI<VQU
M:W0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED
M(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")6
M97)B:6YD:6YG(&UE="!D92!334(M<V5R=F5R(&ES(&UI<VQU:W0N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DMO
M<&GK<F5N('5I="!<(B5S7"(@:7,@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DMO<&GK<F5N(&YA87(@
M7"(E<UPB(&ES(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+B(*;7-G<W1R(")-86ME;B!V86X@;FEE=7=E(%-!4TP@=F5R
M8FEN9&EN9R!I<R!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S4U(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS
M9W-T<B`B5F5R<&QA871S96X@;F%A<B!<(B5S7"(@:7,@;6ES;'5K="XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(D]P:&%L
M96X@=F%N("5S(&ES(&UI<VQU:W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")-;V]I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX-`IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I(@IM<V=S='(@(D9A;&ML86YD(&5I;&%N9&5N("A-86QV:6YA<RDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@V"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9A<F_K
M<B!E:6QA;F1E;B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G
M:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")&871A;&4@9F]U=#HB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED
M(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X96XB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B
M<G5A<GDB"FUS9W-T<B`B1F5B<G5A<FDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")6;V5L="!A;',B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&
M965L<R!L:6ME.B`B"FUS9W-T<B`B5F]E;'0@86QS.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H
M;W=E<G,B"FUS9W-T<B`B16YK96QE(&)U:65N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B16YI9V4@<VYE975W8G5I96XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS
M9W-T<B`B5F5L9&UA=')I>"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,C4*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(D9I9VQE="!#
M05!40TA!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R.0IM<V=I
M9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B1FEG;&5T(&9O;G0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@S"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B0F5S
M=&%N9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B06%N
M=&%L(&)E<W1A;F1E;CH@)7,@8F5S=&%N9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HW.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&5S(@IM<V=S='(@(D%A;G1A;"!B97-T86YD96XZ("5S(&)E<W1A
M;F1E;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@
M(D9I;&4@36%N86=E<B(*;7-G<W1R(")"97-T86YD8F5H965R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*;7-G:60@(D9I;&4@3F%M92(*;7-G
M<W1R(")"97-T86YD<VYA86TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3<W"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")"97-T86YD
M(&MI97IE;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G
M:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(D)E<W1A;F1U<&QO860B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#(*;7-G:60@(D9I;&4@
M=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")"97-T86YD=7!L;V%D
M<R!W;W)D96X@;FEE="!O;F1E<G-T975N9"XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=&5R
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#(*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;&%N
M9"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA
M;&8B"FUS9W-T<B`B165R<W1E(&AE;&9T(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R(")%97)S=&4@:W=A<G1A86PB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T
M:6\B"FUS9W-T<B`B5F5R:&]U9&EN9R!H97)S=&5L;&5N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI
M<"(*;7-G<W1R(")/;6ME<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T
M<B`B1')I:G9E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B36ES="(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T(@IM<V=S='(@(DUA<"`E<R!B97-T86%T(&YI970B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS
M9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D9O;G1K;&5U<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")6;V5D
M<V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")6;V]R(&)R;W=S97)S(&1I92!G
M965N(&%F8F5E;&1I;F=E;B!O;F1E<G-T975N96XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,T,0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M5V5E<G-V;V]R<W!E;&QI;F<@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@
M=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A
M;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT
M(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB5F]O<G5I='II8VAT9&%G
M96X@*&UE<FL@;W`@9&%T(&AE="!G96=E=F5N('9O;W)U:71Z:6-H="!D86=E
M;B!E;B!N86-H=&5N("(*(F=E969T.R!E96X@9W)O;W0@86%N=&%L(&MA;B!R
M97-U;'1E<F5N(&EN(&5E;B!B<F5E9"!B;&]K*2(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R
M9#\B"FUS9W-T<B`B57<@=V%C:'1W;V]R9"!V97)G971E;C\B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R
M(")&;W)M=6QI97)E;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R(")&;W)T=6YE(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B
M1F]R='5N971Y<&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G
M:60@(D9O<G1U;F5S(@IM<V=S='(@(D9O<G1U;F5S(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(D9O
M<G1U;F5S(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS
M9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R=6US(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B1&]O
M<G-T=7)E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E9R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B
M1G)A;65S(@IM<V=S='(@(D9R86UE<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<*;7-G:60@(D9R
M86YC92(*;7-G<W1R(")&<F%N:W)I:FLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM
M<V=S='(@(D9R86YK<FEJ:RP@2&]O9F1S=&5D96QI:FLB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ
M"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(D9R86YS($=U>6%N82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@T"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@
M(D9R86YS(%!O;'EN97-IZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,@IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YS92!:=6ED96QI
M:FME(%1E<G)I=&]R:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(E9A;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B5F%N(&1E("(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&
M=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E9O;&QE9&EG92!B97-C:')I:G9I
M;F<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(E9O;&QE(&UA86XB
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C4@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@
M(E9O;&QE9&EG92!N86%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.`IM<V=I9"`B1V%B;VXB"FUS
M9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M(@IM<V=S='(@(D%L8G5M('=A87)U:70@9&4@869B965L
M9&EN9R!G96AA86QD(&1I96YT('1E('=O<F1E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I
M9"`B1V%L;&5R>3HB"FUS9W-T<B`B06QB=6TZ(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-@IM<V=I
M9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<F5E<B`E<R!C;VYF:6=U<F%T
M:64B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM
M<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5G96YE<F5E<F1E(&-O
M9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDP"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G
M:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(D1U:71S
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3,*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H86YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A
M;'1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(E9O;W)N86%M(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I
M9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B1VQO8F%L92!O<'1I97,B"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T
M<B`B1V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O
M961E;"(*;7-G<W1R(")';V5D96PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B"FUS
M9W-T<B`B1V]O9VQE(&MA87)T96XB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92!Z
M;V5K96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B1W)I:G-S8VAA86PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,`IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=R:65K96YL
M86YD(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D=R965K
M("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<FEE:W,@*$E33RTX.#4Y+3<I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R;V5N;&%N
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#D*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E;F%D
M82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")'<F]E<'-B96AE97(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y(@IM<V=S='(@(D=R;V5P;F%M96X@;6]G96X@;FEE="!L965G('II:FXB
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O
M=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M(")'<F]U<%]L9&%P.B!.:65T(&EN('-T86%T(&=R;V5P("5S('1O92!T92!V
M;V5G96XN($1E('-E<G9E<B!M96QD=#H@(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!.:65T(&EN
M('-T86%T(&=R;V5P("5S('1E('9E<G=I:F1E<F5N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?
M;&1A<#H@3FEE="!I;B!S=&%A="!G<F]E<"`E<R!B:6H@=&4@=V5R:V5N(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<F]E<&5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M.`IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D96QO=7!E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#,*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`R"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB
M"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED
M(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")'87-T(')E8VAT96XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O
M;VLB"FUS9W-T<B`B1V%S=&5N8F]E:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<*;7-G:60@(D=U
M:6YE82(*;7-G<W1R(")'=6EN964B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0*;7-G:60@(D=U
M:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5E+4)I<W-A=2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U>6%N82(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(
M5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!
M<F5A('=E:6=E<G0@;&%F(&]M(&1E(&QA871S=&4@8V5L(&EN(&1E(')I:B!T
M92!V97)W:6ID97)E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N
M(@IM<V=S='(@(DA434Q!<F5A('=E:6=E<G0@;&%F(&]M(&1E(&QA871S=&4@
M:V]L;VT@:6X@9&4@=&%B96P@=&4@=F5R=VEJ9&5R96XN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!W96EG97)T(&QA
M9B!O;2!D92!L86%T<W1E(')I:B!I;B!D92!T86)E;"!T92!V97)W:6ID97)E
M;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I
M9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(DA4
M5%`@875T:&5N=&EC871I92!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM
M(@IM<V=S='(@(DAA<V@M86QG;W)I=&AM92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@
M(DYE=F5L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,30*;7-G:60@(DAE861E<B(*;7-G<W1R
M(")+;W`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(DMO<'!E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-PIM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S(@IM<V=S='(@(DAE87)D(&5I;&%N9"!E;B!-8T1O;F%L9"!E:6QA;F1E
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S
M"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(EIW87)E(&]N=V5E<G-B
M=6DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W
M("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E975W<R`H25-/+3@X-3DM
M."U)*2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE
M:6=H="(*;7-G<W1R(")(;V]G=&4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H
M<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S
M+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B2&5L<"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*
M;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(DAE;'`@8FEJ(&=E
M8G)U:6L@=F%N(&5D:71O<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")(96QP97(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B
M2&%L9G)O;F0B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,"!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")(:65R(&ES(&AE
M="!B96=I;B!V86X@:&5T(&)E<W1A;F0Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(DAI9V@B"FUS9W-T<B`B
M2&]O9R(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS
M9W-T<B`B2&]?;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S"FUS9VED(")(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")(;VQY(%-E92`H5F%T:6-A
M86YS=&%D*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T.`IM
M<V=I9"`B2&]M92(*;7-G<W1R(")(;VUE(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B
M"FUS9W-T<B`B061R97,@*'!R:7;I*2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HW,`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B2&]M961I
M<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L+FYR+B`H
M<')I=NDI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`X"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R
M(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-@IM<V=I9"`B2&]N9R!+;VYG(@IM
M<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!/;F=E;&1I9V4@
M)7,@6$U,(&1A=&$@=&5G96YG96MO;65N(&EN(&)E<FEC:'0@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($=E96X@8F5R:6-H="!C
M;W)R97-P;VYD965R="!M970@;V)J96-T("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($=E96X@;V)J96-T('9A;B!T>7!E
M("5S(&=E=F]N9&5N(&EN(&)E<FEC:'0@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@)7,@;65T('-U8V-E<R!V97)W:6ID97)D(%PB)7-<
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@1&4@:6YT97)G<F%T:64@=F5R96ES="!D92`G9&]M>&UL)R!E>'1E;G-I
M92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE
M=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!+86X@9V5E;B!N:65U=V4@6$U,(&)O;VT@;6%K96X@=F]O<B!O8FIE8W0@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N("5S(%PB
M)7-<(B!N:65T('9E<G=I:F1E<F5N.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@
M;V8@='EP92`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@3FEE="!I;B!S
M=&%A="!H970@34E-12!)1"P@=F]O<B!H970@9V5D965L=&4@;65T('1Y<&4@
M)7,L(&]P('1E("(*(FAA;&5N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@2V%N("5S(%PB)7-<(B!N:65T('-Y;F-H<F]N:7-E<F5N
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!G
M961E96QD92!B<F]N;F5N(&YI970@<WEN8VAR;VYI<V5R96XZ("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!/;F)E:V5N9&4@9V5D965L9&4@8G)O;B!<(B5S
M7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B2&]R:7IO;G1A
M;&4@;&EJ;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(
M;W)I>F]N=&%L92!V<FEJ92!R=6EM=&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*
M;7-G<W1R(")(;W)I>F]N=&%A;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(DAO92!K
M=V%M('4@:&EE<C\@*$=R86%G(')A<'!O<G1A9V4A*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@
M(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(DAO979E96P@:V]L;VUM96X@=VEL="!U('-A;65N=F]E9V5N/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B2&]E
M=F5E;"!V96QD96X@*&MO;&]M;65N*2!Z:6IN(&5R/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@
M(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(DAO979E96P@<FEJ96X@=VEL="!U('-A;65N=F]E9V5N/R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#D*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(E9O8VAT:6=H96ED
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM<V=I9"`B
M2'5M:61I='DZ("(*;7-G<W1R(")6;V-H=&EG:&5I9#H@(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B
M2'5M;W)I<W1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,0IM<V=I9"`B2'5N9V%R>2(*;7-G
M<W1R(")(;VYG87)I:F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R(")-86ME;B!V86X@24U!4"!M86EL8F]X(&UI<VQU
M:W0Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y
M-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B5F5R=VEJ9&5R96X@=F%N($E-05`@;6%I;&)O>"!M:7-L=6MT
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(DUA:V5N('9A;B!)34%0(&UA:6QB;W@@<75O=&$@;6ES
M;'5K=#H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS
M9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0($%D<F5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!A9')E<R!N:65T(&)E<V-H
M:6MB86%R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z
M.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@
M8FQO8VLN(@IM<V=S='(@(DE0(&%D<F5S('9A;'0@;FEE="!B:6YN96X@:&5T
M('1O96=E<W1A;F4@0TE$4B!B;&]K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+B(*;7-G<W1R("))4"!L;V-K9&]W;B!O=F5R=')E9&EN
M9RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R
M(")2:6H@:5]N=F]E9V5N('9O;W(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`*;7-G:60@(DEC
M96QA;F0B"FUS9W-T<B`B24IS;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B06QL965N('!I
M8W1O9W)A;6UE;B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B4&EC=&]G
M<F%M;65N('9O;W(@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q
M"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B4&EC=&]G<F%M;65N
M(&UE="!T96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G
M:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B261E;G1I=&5I='-N86%M
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O
M<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S
M='(@(B(*(E=A;FYE97(@:&5T(&YI970@9V]E9"!W;W)D="!W965R9V5G979E
M;BP@)7,@;VT@:&5T(&EN(&5E;B!N:65U=R!S8VAE<FT@=&4@(@HB;W!E;F5N
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF
M('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO
M<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB06QS('4@9V5E
M;B!P:6-T;V=R86UM96X@>FEE="P@8FEJ(&=E8G)U:6L@=F%N($EN=&5R;F5T
M($5X<&QO<F5R+"!K86X@:&5T("(*(FYO9&EG('II:FX@9&ET('9A:VIE(&%A
M;B!T92!V:6YK96X@;VT@4$Y'('1R86YS<&%R871I92!U:70@=&4@<V-H86ME
M;&5N+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)7
M86YN965R('4@9&ET(&)E<FEC:'0@>FEE="P@;6%A<B!G965N(&%F8F5E;&1I
M;F<L(&1A;B!K86X@9&4@869B965L9&EN9R!D:64@(@HB=2!W:6QT('5P;&]A
M9&5N(&YI970@9&]O<B!U=R!B<F]W<V5R('=O<F1E;B!W965R9V5G979E;BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C4*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(D%F
M8F5E;&1I;F=S8F5O;W)D96QI;F<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),
M(@IM<V=S='(@(D%F8F5E;&1I;F<@55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"FUS9VED("))
M;6%G92!54DPZ(@IM<V=S='(@(D%F8F5E;&1I;F<@55),.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(D%F8F5E;&1I
M;F<@=6ET(&%L8G5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A
M;&QE<GDZ(@IM<V=S='(@(D%F8F5E;&1I;F<@=6ET(&%L8G5M.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A
M9"(*;7-G<W1R(")!9F)E96QD:6YG<W5P;&]A9"(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B069B965L9&EN
M9V5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-R!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4T"B,Z('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C<@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T
M97)E;BP@<W1A<"`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*
M;7-G<W1R(")'96EM<&]R=&5E<F0@=F5L9#H@)7,B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM
M<V=S='(@(D=E:6UP;W)T965R9&4@=F5L9&5N.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B
M26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B4FEJ(&EN=F]E9V5N(&YA(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D]N
M:G5I<W1E(&)E=V5R:VEN9W-C;V1E(&]P9V5G979E;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B
M26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M3VYJ=6ES=&4@9V5B<G5I:V5R<VYA86T@96XO;V8@=V%C:'1W;V]R9"XB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)/;FIU:7-T92!G96)R=6EK
M97)S;F%A;2!O9B!A;'1E<FYA=&EE9B!A9')E<RX@4')O8F5E<B!O<&YI975W
M(&]F(&YE96T@(@HB8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E
M<BP@=V%N;F5E<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H965F="XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B5F5R9W)O;W0@:6YS<')I;F=I
M;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,38*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EA
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E
M<G,B"FUS9W-T<B`B26YD:79I9'5E;&4@9V5B<G5I:V5R<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N97-IZR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G
M:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R
M;6%T:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS
M9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R
M("));F9O<FUA=&EE(&YI970@;&%N9V5R(&)E<V-H:6MB86%R+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B2V]L;VT@
M:6YV;V5G96X@;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*;7-G:60@(DEN<V5R="!);6%G92(*
M;7-G<W1R(")!9F)E96QD:6YG(&EN=F]E9V5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A
M8FQE(@IM<V=S='(@(E1A8F5L(&EN=F]E9V5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E
M8B!,:6YK(@IM<V=S='(@(E=E8FQI;FL@:6YV;V5G96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G
M:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")?2V]L;VT@:6YV
M;V5G96X@=F]O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B165N(&YI975W92!K
M;VQO;2!I;G9O96=E;B!N82!D92!H=6ED:6=E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B165N(&YI975W92!K;VQO;2!I;G9O96=E;B!V;V]R(&1E(&AU:61I
M9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5E;B!N:65U=V4@<FEJ(&EN=F]E9V5N
M(&YA(&1E(&AU:61I9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")%96X@;FEE=7=E
M(')I:B!I;G9O96=E;B!N82!D92!H=6ED:6=E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("))
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R(")%96X@;FEE=7=E('!A<F%G<F%A9B!I;G9O96=E;B!N82!D92!H=6ED
M:6=E(&YO9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")%96X@;FEE=7=E('!A
M<F%G<F%A9B!I;G9O96=E;B!N82!D92!H=6ED:6=E(&YO9&4B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R(")!;'1E<FYA=&EE9B!S:F%B;&]O;B!I;G9O96=E
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R
M="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T
M:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R(")%96X@92UM86EL861R97,@:6YV
M;V5G96XL('=A87(@=2!H970@;FEE=7=E('=A8VAT=V]O<F0@:V%N(&]N='9A
M;F=E;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R
M(")#96P@:6YV;V5G96X@;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B
M969O<F4B"FUS9W-T<B`B0V5L(&EN=F]E9V5N('9O;W(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED
M("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DMO;&]M(&EN=F]E9V5N
M(&YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T
M<B`B2V]L;VT@:6YV;V5G96X@=F]O<B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDP"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4P"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS
M9W-T<B`B0F5R:6-H=&5N(&EN=F]E9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(E!A<F%G<F%A9B!I;G9O96=E
M;B!N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B
M"FUS9W-T<B`B4&%R86=R86%F(&EN=F]E9V5N('9O;W(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED
M("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(E)I:B!I;G9O96=E;B!N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(E)I:B!I
M;G9O96=E;B!V;V]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM
M<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.B(*;7-G<W1R(")(970@9V5W96YS=&4@86YT=V]O<F0@
M=F]O<B!D92!B979E:6QI9VEN9W-V<F%A9R!I;G9O96=E;CHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("))
M;G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(D%F8F5E;&1I;F<@:6YV;V5G
M96XO86%N<&%S<V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S
M='(@(DQI;FL@:6YV;V5G96XO86%N<&%S<V5N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(D]N=F]L9&]E;F1E(&MR961I970@;VT@;F%A<B!D92!D
M:7-T<FEB=71I96QI:G-T('1E('IE;F1E;BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="XB"FUS9W-T<B`B3VYV;VQD;V5N9&4@:W)E9&EE="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G
M97(B"FUS9W-T<B`B26YT96=E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("));G1E9V5R
M(&QI:G-T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+B(*;7-G<W1R(")/;F=E;&1I9V4@541(+B`H57-E<B!$871A($AE
M861E<BDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR
M,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B3VYG96QD:6=E
M(%I)4"!D871A(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I
M9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B3VYG96QD:6=E('1O
M97!A<W-I;F<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G
M<W1R(")/;F=E;&1I9R!B871C:"!)1"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM
M<V=S='(@(D]N9V5L9&EG92!D871A(&]P9V5G979E;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@
M(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B3VYG96QD
M:6<@8F5S=&5M;6EN9V%D<F5S+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM
M<V=S='(@(D]N9V5L9&EG('1I:F1F;W)M86%T(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME
M>2XB"FUS9W-T<B`B3VYG96QD:6=E(&QI8V5N=&EE<VQE=71E;"XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED
M(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")/;F=E;&1I9V4@;&]C871I
M92!O<&=E9V5V96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*
M;7-G<W1R(")/;F=E;&1I9R!M<V=?='EP92XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(D]N9V5L9&EG(&]F(&]N
M=&)R96ME;F0@87!I7VED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG('!A<F%M971E<G,N(@IM<V=S='(@(D]N9V5L9&EG92!O9B!O;G1B<F5K
M96YD92!P87)A;65T97)S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B3VYG96QD:6<@<&%R96YT(')E8VAT+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB
M"FUS9W-T<B`B3VYG96QD:6<@<&%R=&YE<B!I9"XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@
M8V]D92XB"FUS9W-T<B`B3VYG96QD:6=E('!R;V1U8W1I96-O9&4N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V
M"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")/;F=E;&1I9R!P
M<F]T;V-O;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E
M<UPB(@IM<V=S='(@(D]N9V5L9&EG92!O;G1V86YG97(Z(%PB)7-<(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`X,"!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T
M(@IM<V=S='(@(D]N9V5L9&EG92!G961E96QD92!B<F]N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")/;F=E;&1I9R!B
M<F]N861R97,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB
M"FUS9W-T<B`B3VYG96QD:6=E('5N:6-O9&4@9&%T82XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T
M<B`B26YV96YT87)I<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T
M<B`B4V5L96-T:64@;VUK97)E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.0IM<V=I9"`B27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N+"!)<VQA;6ET
M:7-C:&4@4F5P=6)L:65K('9A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.`IM<V=I9"`B27)A
M<2(*;7-G<W1R("))<F%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S"FUS9VED("))<F5L86YD
M(@IM<V=S='(@(DEE<FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B16EL86YD($UA
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T
M"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")'96ES;VQE97)D
M92!O;G=E97)S8G5I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30*;7-G:60@(DES<F%E;"(*
M;7-G<W1R("))<W)AZVPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(E5I=&=E=F5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS
M9VED("))=&%L:6,B"FUS9W-T<B`B0W5R<VEE9B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,0IM
M<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&GK(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S"FUS
M9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*
M;7-G<W1R(")*86YU87)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U"FUS9VED(")*87!A;B(*
M;7-G<W1R(")*87!A;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS
M9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&%N<R`H
M25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C0*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D86YIZR(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY
M(@IM<V=S='(@(DIU;&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")U:71L:6IN96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM
M<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B1V5C96YT<F5E<F0@=6ET
M;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")6
M;VQL961I9R!U:71L:6IN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T
M(@IM<V=S='(@(DQI;FMS('5I=&QI:FYE;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T
M:69Y(%)I9VAT(@IM<V=S='(@(E)E8VAT<R!U:71L:6IN96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z86-H<W1A;B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C4*
M;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(D]R:6=I;F5E;"!B96AO
M=61E;C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C8*;7-G:60@(DME;GEA(@IM<V=S='(@(DME
M;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I
M9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")+97)B97)O<R!S97)V97(@=V5I9V5R9&4@875T:&5N=&EC871I
M92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE
M;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"!.97=B:65S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I
M;VXB"FUS9W-T<B`B4VQE=71E;"!M86ME;B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM
M<V=S='(@(E-L975T96QV:6YG97)A9F1R=6LB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T
M<B`B4VQE=71E;&QE;F=T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B4VQE=71E;'1Y
M<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM
M<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E-L975T96QG96)R=6EK(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D1E('-L975T96P@8F5S=&%A="!A;"!O<"!D92!O<&5N8F%R92!S;&5U
M=&5L<V5R=F5R+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I
M9"`B2VED<R(*;7-G<W1R(")+:6YD97)E;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.0IM<V=I
M9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(*
M;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DMO<F5A+"!$96UO8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K
M('9A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,PIM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DMO<F5A+"!297!U8FQI96L@=F%N(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R
M(")+;W)E86%N<R`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-`IM<V=I9"`B2W5W
M86ET(@IM<V=S='(@(DMO97=E:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<*;7-G:60@(DMY
M<F=Y>G-T86XB"FUS9W-T<B`B2WER9VEE<VGK(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(D]?<&UA
M86LB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),
M86YG=6%G92(*;7-G<W1R(")486%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W"FUS9VED("),
M86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R(")$96UO
M8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K($QA;R(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("),86%T<W1E
M(&AE;&9T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@X"FUS9VED("),
M87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("),86%T<W1E('=A8VAT=V]O
M<F1W:6IZ:6=I;F<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B
M3&%A='-T92!K=V%R=&EE<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34X
M"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(DQA871S="!B:6IG97=E
M<FMT.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("),86%T<W1E
M(&%A;FUE;&1I;F<Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`B3&%A='-T92!A86YM96QD:6YG.B`E<R!V86X@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G
M:6XZ($YE=F5R(@IM<V=S='(@(DQA871S=&4@86%N;65L9&EN9SH@3F]O:70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#8*;7-G:60@(DQA='9I82(*;7-G<W1R("),971L86YD
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS
M9W-T<B`B4F5C:'1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D]P
M;6%A:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T
M<B`B3&%A="!L965G('9O;W(@9V5E;B!R86YD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X"FUS
M9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*;7-G:60@(DQE
M9G0B"FUS9W-T<B`B3&EN:W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3`Q"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("),:6YK<V4@:V]P
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-PIM<V=I9"`B3&5F
M="!V86QU97,B"FUS9W-T<B`B3&EN:W-E('=A87)D96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#,*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T
M<B`B3FEV96%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R"FUS9VED("),:6)E<FEA(@IM<V=S
M='(@(DQI8F5R:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<*;7-G:60@(DQI8GEA;B!!<F%B
M($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB:7-C:&4@07)A8FES8VAE($IA;6%H
M:7)I>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#`*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS
M9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S
M='(@(EIA8VAT(&)U:71J92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(DQI
M8VAT92!R96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(E9R
M;V5G(&QI8VAT92!R96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T
M<B`B3&EC:'1E(')E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S
M='(@(DQI8VAT92!R96=E;F)U:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU
M;F1E<B(*;7-G<W1R("),:6-H=&4@<F5G96X@;65T(&]N=V5E<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),
M:6=H="!3;F]W(@IM<V=S='(@(DQI8VAT92!S;F5E=7<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@
M4VYO=R!3:&]W97(B"FUS9W-T<B`B3&EC:'1E('-N965U=V)U:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T
M<B`B3&EM97)I8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T
M"FUS9VED("),:6YK(@IM<V=S='(@(DQI;FLB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("),:6YK('=I:G-T(&YA87(Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R("),:6YK(&AE="!E+6UA:6QA9')E<R!A86X@9&4@;FEE
M=7<@8F5R:6-H="!P86=I;F$@=&EJ9&5N<R!W965R9V%V92(*"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G
M:60@(DQI;FMS(@IM<V=S='(@(DQI;FMS(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@@
M0V]O:VEE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G
M<W1R("),:6IS="`M(&=E8G)U:6ME<B!K86X@9&4@;6%P('II96XB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*
M;7-G<W1R(")$871A8F%S96QI:G-T(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B3&EJ
M<W0@=F%N(&AE;'`@;VYD97)D96QE;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(E1A8F5L;&EJ<W0B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I
M9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI:G-T+4%R8VAI968B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES
M="U(96QP(@IM<V=S='(@(DQI:G-T+4AE;'`B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R
M("),:6IS="U)9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DQI:G-T+45I9V5N
M86%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*
M;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:6IS="U0;W-T(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M
M4W5B<V-R:6)E(@IM<V=S='(@(DQI:G-T+4EN<V-H<FEJ=F5N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M
M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&EJ<W0M56ET<V-H<FEJ=F5N(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI
M<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")7965R9V5V96X@
M=F%N('-E<W-I96QI:G-T(&ES(&UI<VQU:W0Z("5S(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")7965R9V5V96X@=F%N(&=E8G)U:6ME
M<G-L:6IS="!I<R!M:7-L=6MT.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B5V5E<F=E=F5N('9A;B!G96)R=6EK97)S;&EJ<W0@
M:7,@=6ET9V5S8VAA:V5L9"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET97)A='5U<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-`IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI=&]U=V5N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW
M-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("),861E;BXN+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO8V%L('1I
M;64Z("(*;7-G<W1R("),;VMA;&4@=&EJ9#HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("),
M86YD:6YS=&5L;&EN9R!E;B!T:6ID(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4W"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),;V-A=&EE(@H*
M(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C`P('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D%A;FUE;&1E;B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("),;V<@=F%N('9O;W)G86%N
M9&4@<WEN8R!S97-S:64B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D%F;65L9&5N(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q"FUS9VED("),;V=I;B(*;7-G<W1R
M(")!86YM96QD96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS
M9VED("),;V=I;B!487-K<R(*;7-G<W1R(")!86YM96QD=&%K96XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(D%A;FUE;&1I;F<@;6ES;'5K
M="!O;61A="!U=R!G96)R=6EK97)S;F%A;2!O9B!W86-H='=O;W)D(&]N:G5I
M<W0@:7,@(@HB:6YG979O97)D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")!86YM96QD
M:6YG(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DQA;F=E('1E:W-T(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@
M(DQI969D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B3&%A9R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G
M:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B1W)I96MS92!K;&5I
M;F4@;&5T=&5R<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`B3&%T:6IN<V4@:VQE:6YE(&QE='1E<G,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W
M"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DML96EN92!2
M;VUE:6YS92!G971A;&QE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-0IM<V=I9"`B3'5X96UB
M;W5R9R(*;7-G<W1R("),=7AE;6)U<F<B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,SD@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@
M(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B35,M5$Y%1B!B:6IL86=E(&)E=F%T=&4@9V5E;B!D871A+B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3<*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34S"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B36%C961O;FGK+"!$92!V<F]E9V5R92!*;V5G
M;W-L879I<V-H92!297!U8FQI96L@=F%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q"FUS9VED
M(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-C87(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VEE
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL
M(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B36%I;&)E:&5E<F1E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")-86%K
M(&QI;E]K+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U"FUS9VED(")-86QA=VDB"FUS9W-T
M<B`B36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W"FUS9VED(")-86QA>7-I82(*;7-G
M<W1R(")-86QE:7-IZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-`IM<V=I9"`B36%L9&EV97,B
M"FUS9W-T<B`B36%L861I=F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T"FUS9VED(")-86QI
M(@IM<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(*;7-G:60@(DUA;'1A(@IM
M<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS
M9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)"96AE97(@
M=7<@;&EJ<W0@;65T(&-A=&5G;W)I9>MN(&5N(&1E(&-O<G)E<W!O;F1E<F5N
M9&4@:VQE=7)E;BP@=V%A<FUE92`B"B)O;F1E<F1E;&5N('=O<F1E;B!G96QA
M8F5L9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0@:V%A<G0B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X
M-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W
M,0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T:V%A<G0B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA
M<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B2V]P<&5L:6YG96X@;W!G97-L86=E
M;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%A<G0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-
M87)G:6XB"FUS9W-T<B`B36%R9V4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HT.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(DUA<FME97(@;65T($=E>FEE;B].:65T($=E>FEE
M;B!V;&%G9V5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DUA<FME97(@;65T(&%N9&5R92!V
M;&%G9V5N("AB+G8N($)E;&%N9W)I:FLO0F5A;G1W;V]R9"DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3(*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R8VAA
M;&P@96EL86YD96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D*;7-G:60@(DUA<G1I;FEQ=64B
M"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B3W9E
M<F5E;FMO;65N9&4@=F5L9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P"FUS9VED(")-875R
M:71A;FEA(@IM<V=S='(@(DUA=7)E=&%N:>LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:71I=7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%X:6UA86P@=&]E9V5S
M=&%A;B!K<F5D:65T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N(@IM<V=S='(@(DUA>&EM=6T@8F5R:6-H=&]N9&5R9&5L96X@
M;W9E<G-C:')E9&5N+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S"FUS
M9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36%X:6UU
M;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N(#(T('5U<CH@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@(@IM<V=S='(@(DUA>&EM=6T@=&5M<&5R871U=7(@=F%N(&1E
M(&%F9V5L;W!E;B`V('5U<CH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@
M(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B36%X
M:6UU;2!A86YT86P@<&]R=&%A;&)L;VMK96XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M
M(&QE;F=T:"(*;7-G<W1R(")-87AI;75M(&QE;F=T92(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS
M9W-T<B`B365I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,PIM<V=I9"`B36%Y;W1T92(*;7-G
M<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS
M9VED(")-961I8VEN92(*;7-G<W1R(")'96YE97-K=6YD92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B
M"FUS9W-T<B`B3&5D96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R
M"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE;G4@;6]D93HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P
M"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")#96QL96X@<V%M96YV;V5G
M96XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")"97)I8VAT(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@
M(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG
M;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*
M;7-G<W1R("(B"B)"97)I8VAT(&UE="!S=6-C97,@9V5V97)I9FEE97)D+"!M
M86%R(&AE="!C97)T:69I8V%A="!V86X@9&4@;VYD97)G971E:V5N9&4@(@HB
M:V]N(&YI970@=V]R9&5N(&=E=F5R:69I965R9"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE
M<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B0F5R:6-H="!V97)L;W!E;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C8P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C`R"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B0F5R
M:6-H='1Y<&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE
M=&%R(%=E871H97(B"FUS9W-T<B`B365T87(@5V5E<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(DU%5$%2(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BXB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB345405(@8FQO
M:R!I<R!N:65T(&)E<V-H:6MB86%R+B!$971A:6QS('II:FX@9V5L;V=D('9O
M;W(@9&4@<WES=&5E;6)E:&5E<F1E<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T
M960N(@IM<V=S='(@(DUE=&%R1$(@:7,@;FEE="!V97)B;VYD96XN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B
M"FUS9W-T<B`B365T:&]D92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W-O87`N
M<&AP.C$Q-R!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B
M"FUS9W-T<B`B365T:&]D92!<(B5S7"(@:7,@;FEE="!G961E9FEN:65E<F0B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S(@IM<V=S='(@(DUE=&AO9&4@:7,@;FEE="!G961E9FEN:65E<F0N($%A
M;F=E<F]E<&5N(&UE=&AO9&4Z("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<*;7-G:60@(DUE
M=')I8R(*;7-G<W1R(")-971R:7-C:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-@IM<V=I9"`B
M365X:6-O(@IM<V=S='(@(DUE>&EC;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U"FUS9VED(")-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI8W)O
M;F5S:>LL($9E9&5R86QE(%-T871E;B!V86XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*;7-G:60@(DUI9&1L
M92(*;7-G<W1R(")-:61D96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI
M;64@='EP92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W"FUS9VED(")-
M:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36EN:6UU;2!T96UP
M97)A='5U<B!V86X@9&4@869G96QO<&5N(#(T('5U<CH@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(DUI;FEM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L
M;W!E;B`V('5U<CH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960B"FUS9W-T<B`B36EN:6UU;2!W86-H='=O;W)D;&5E9G1I:F0@
M:7,@;F]G(&YI970@=F5R;&]P96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B
M36ER<F]R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-
M:7-C96QL86YE;W5S(@IM<V=S='(@(D%L;&5R:&%N9&4B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@
M(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B
M3VYT8G)E:V5N9&4@4$5!4B!M;V1U;&4@2%144%]297%U97-T+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B
M"B)/;G1B<F5K96YD92!C;VYF:6=U<F%T:64N(%4@9&EE;G0@9&5Z92!N=2!T
M92!G96YE<F5R96XL('=A;FYE97(@=2!D97IE("(*(G1O97!A<W-I;F<@=VEL
M="!G96)R=6EK96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N
M(@IM<V=S='(@(D]N=&)R96ME;F0@8F5R:6-H="!)1"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I
M9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T
M<B`B3VYT8G)E:V5N9&4L('9E<F5I<W1E+"!014%2(&UO9'5L92!-86EL+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")/;G1B
M<F5K96YD('-E<W-I92!)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")-82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA
M:6PB"FUS9W-T<B`B36]B:65L92!E+6UA:6PB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B36]D97)A=&4B"FUS
M9W-T<B`B1V5M:61D96QD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S,*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B5VEJ>FEG:6YG<V1A
M='5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(E=I:GII
M9R!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34P"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD
M879IZRP@4F5P=6)L:65K('9A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.0IM<V=I9"`B36]N
M86-O(@IM<V=S='(@(DUO;F%C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-@IM<V=I9"`B36]N
M9V]L:6$B"FUS9W-T<B`B36]N9V]L:>LB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3@T"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-
M86%N9"!E;B!J86%R(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-86%N9&5L
M:6IK<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,0IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R
M(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")-
M86%N9F%S96XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@
M97AP96-T960@)60N(@IM<V=S='(@(DUE97(@=F5L9&5N(&EN(')E9V5L("5D
M(&=E=F]N9&5N+"!D86X@9&4@=F5R=V%C:'1T92`E9"XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#@*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;VMK;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T
M;'D@0VQE87(B"FUS9W-T<B`B5F]O<FYA;65L:6IK(&]N8F5W;VQK="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED
M(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(E9O;W)N86UE;&EJ:R!B97=O;&MT
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*
M;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@(E9O;W)N
M86UE;&EJ:R!B97=O;&MT(&5N('=I;F1E<FEG(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!3=6YN
M>2(*;7-G<W1R(")6;V]R;F%M96QI:FL@>F]N;FEG(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO
M=F4@1&]W;B(*;7-G<W1R(").86%R(&)E;F5D96XB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V
M92!,969T(@IM<V=S='(@(DYA87(@;&EN:W,B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2
M:6=H="(*;7-G<W1R(").86%R(')E8VAT<R(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P
M(@IM<V=S='(@(DYA87(@8F]V96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T
M<B`B3F%A<B!B96YE9&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P(@IM<V=S='(@(DYA87(@
M8F]V96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C@*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T
M<B`B36]Z86UB:7%U92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R
M(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&EJ<W1E;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4Y"FUS9VED(")-=6QT
M:6UA<"!52R!M87`B"FUS9W-T<B`B375L=&EM87`@5DL@:V%A<G0B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S
M96QE8W1I;VXB"FUS9W-T<B`B365E<G9O=61I9V4@<V5L96-T:64B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT
M(@IM<V=S='(@(DUI:FX@86-C;W5N="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M(")5=R!A8V-O=6YT:6YF;W)M871I92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I
M;F1E>"YP:'`Z-#0*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-:6IN('!O
M<G1A86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#(*;7-G:60@
M(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B36EJ;B!P;W)T86%L;&%Y;W5T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34U"FUS9VED(")->6%N;6%R(@IM<V=S='(@(D)I<FUA
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").964L(&EK
M(&%C8V5P=&5E<B!D92!V;V]R=V%A<F1E;B!.2454(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%A;2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V.0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI8FGK
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<X"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S4*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYE9&5R
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S"FUS9VED(").971H97)L86YD<R!!;G1I;&QE
M<R(*;7-G<W1R(").961E<FQA;F1S($%N=&EL;&5N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A
M<V4@55),(@IM<V=S='(@(DYE='-C87!E($)A<VES(%523"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P
M92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92!#02!I;G1R
M96MK:6YG(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@
M(DYE='-C87!E($-!(&)E;&5I9"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!5
M4DPB"FUS9W-T<B`B3F5T<V-A<&4@=F5R;FEE=7=I;F<@55),(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C
M87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(&EN=')E:VMI
M;F<@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").
M971S8V%P92!34TP@<V5R=F5R;F%A;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT(@IM<V=S='(@(DYE='-C87!E(&-E<G1I9FEC86%T8V]M;65N
M=&%A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(DYE
M='-C87!E(&-E<G1I9FEC86%T='EP92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B3F5T=V5R:R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYO;VET(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P
M"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYI975W($-A;&5D;VYI
MZR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3FEE=7=E(&-A
M=&5G;W)I92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W
M($UO;VXB"FUS9W-T<B`B3FEE=7=E(&UA86XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P
M=&EO;F%L*2(*;7-G<W1R(").:65U=V4@9V5B<G5I:V5R<VYA86T@*&]P=&EO
M;F5E;"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#`*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S
M='(@(DYI975W(%IE96QA;F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(").:65U=R!W
M86-H='=O;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I
M<F4@;VX@)7@N(@IM<V=S='(@(DYI975W('=A8VAT=V]O<F0@>F%L('9E<FQO
M<&5N(&]P("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B
M3FEE=7=E(%=A8VAT=V]O<F1E;B!K;VUE;B!N:65T(&]V97)E96XN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I
M9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").:65U=R!S8VAE<FT@
M*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z-#`*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").:65U=W,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S
M='(@(DYI975W<V=R;V5P96XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR-2!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.0HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHT,2!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ-0IM<V=I9"`B3F5X="(*;7-G<W1R(")6;VQG96YD92(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*
M;7-G<W1R(")6;VQG96YD92`T(&9A<V5N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")6;VQG96YD92!O
M<'1I97,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`B5F]L9V5N9&4^(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T"FUS
M9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87)A9W5A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<Q"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,PIM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B3FEG:'0B"FUS9W-T
M<B`B3F%C:'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD*;7-G:60@(DYI=64B"FUS9W-T<B`B
M3FEU92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(DYE92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS
M9W-T<B`B1V5E;B!B97-C:&EK8F%R92!C;VYF:6=U<F%T:65D871A(&]M('9E
M<G-C:&EL;&5N('1E(&QA=&5N('II96XN(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(D=E
M96X@8F5S8VAI:V)A<F4@<W1R871E9VEE('9O;W(@:&5T(&UA:V5N('9A;B!)
M4T\@:6UA9V5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM
M<V=S='(@(D=E96X@8F%T8VAS:F%B;&]O;BXB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`B17(@8F5S=&%A="!G965N(&)L;VL@;W`@9&4@9V5V<F%A9V1E('!O
M<VET:64B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS
M9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(")'965N(&%G96YD86YA86T@;W!G96=E=F5N
M('9O;W(@34-!3"!A=71H96YT:6-A=&EE+B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(D=E96X@=VEJ
M>FEG:6YG96XN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN(@IM<V=S='(@(D%A;B!D:70@<F5C:'0@:W5N;F5N(&=E96X@
M8VAI;&0@<F5C:'1E;B!W;W)D96X@=&]E9V5V;V5G9"XB"@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S@*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")'965N(&-O;F9I9W5R871I96EN
M9F]R;6%T:64@;W!G96=E=F5N('9O;W(@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-34*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(")'965N
M(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O;W(@1E10(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W,@IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N(@IM<V=S='(@(D=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O
M<&=E9V5V96X@=F]O<B!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@
M(D=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!3
M44PM8F5S=&%N9"!61E,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB
M"FUS9W-T<B`B1V5E;B!K<F5D:65T(&UE97(N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E
M<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(")'965N(&)E<W1E;6UI;F<@
M;W!G96=E=F5N+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDR,`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(")'965N(&)E
M<W1A;F0@=7!L;V%D960B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*
M;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(")'965N('!I8W1O9W)A
M;6UE;B!G979O;F1E;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,"!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q-@IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G
M<W1R(")%<B!I<R!G965N(&QO8V%T:64@:6YG97-T96QD+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R(")'965N(&QO8V%T:64@;W!G96=E=F5N+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(")'965N
M(&)E<FEC:'0@9V5L979E<F0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF
M:65D+B(*;7-G<W1R(")'965N(&YA86T@;W!G96=E=F5N+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED
M(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(")'965N(&=E=&%L(&]P
M9V5G979E;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@
M(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")'965N(&)E;&5D:6=E
M;F1E(&9O<G1U;F5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(D=E96X@=V%C:'1W;V]R9"!O<&=E9V5V
M96X@=F]O<B!(5%10(&%U=&AE;G1I8V%T:64N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")'965N('=A
M8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@24U!4"!A=71H96YT:6-A=&EE+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V86X@2V5R
M8F5R;W,@875T:&5N=&EC871I92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQO9VEN+G!H<#HX-"!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-PIM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@3&]G:6X@
M875T:&5N=&EC871I92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W
M9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")'965N('=A8VAT=V]O<F0@
M;W!G96=E=F5N('9O;W(@4$%34U=$(&%U=&AE;G1I8V%T:64N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")'
M965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@4TU"(&%U=&AE;G1I8V%T
M:64N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@W
M"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B)'965N('!A9"!N
M86%R(&1E($]P96Y34TP@8FEN87)Y(&]P9V5G979E;BX@1&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F]D:6<@;VT@=&4@(@HB:W5N;F5N('=E<FME;B!M970@4$M#
M4R`Q,B!D871A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B1V5E
M;B!H86YG96YD92!I;G-C:')I:G9I;F=E;BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(D=E
M96X@<75O=&$@:6YG97-T96QD+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM
M<V=S='(@(D=E96X@;&EN:>MR:6YG(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*
M;7-G<W1R(")'965N('-C:&5I9&EN9W-T96ME;B!O<&=E9V5V96XN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B1V5E;B!Z:6ID96XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F
M:6QE(@IM<V=S='(@(D=E96X@9&5R9V5L:6IK(&)E<W1A;F0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(D=E
M96X@=&EJ9&5L:6IK(&1I<F5C=&]R>2!B97-C:&EK8F%A<B!V;V]R(&-A8VAE
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB
M"FUS9W-T<B`B1V5E;B!G96)R=6EK97)S;F%A;2!E;B]O9B!W86-H='=O;W)D
M('9E<GIO;F1E;BXB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B1V5E;B!G96QD:6=E(%A-3"!D871A('1E<G5G9V5S='5U<F0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.#0*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B
M3F\@=F%L=65S(@IM<V=S='(@(D=E96X@=V%A<F1E;B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B)'965N('9E<G-I92!G979O;F1E;B!I;B!O<FEG
M:6YE;&4@8V]N9FEG=7)A=&EE+B!(97)G96YE<F5E<B!C;VYF:6=U<F%T:64N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1V5E;B!V97)S:64@9V5V;VYD96X@
M:6X@=7<@8V]N9FEG=7)A=&EE+B!(97)G96YE<F5E<B!C;VYF:6=U<F%T:64N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0IM<V=I9"`B
M3F]N92(*;7-G<W1R(")'965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET
M*2(*;7-G<W1R(")'965N("AV97)P;&EC:'0I(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S
M='(@(DYO;W)D($5U<F]P965S("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S(*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&L@96EL
M86YD(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(").
M;V]R9&5L:6IK(&AA;&9R;VYD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X"FUS9VED(").;W)T
M:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B36%R:6%N96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S8*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;V]R=V5G96XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B
M3F]T($%F=&5R(@IM<V=S='(@(DYI970@;F$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G
M<W1R(").:65T('9O;W(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,34*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")'965N(&1I
M<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"FUS9VED(").;W0@
M:6UP;&5M96YT960N(@IM<V=S='(@(DYI970@9V5I;7!L96UE;G1E97)D+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*
M;7-G:60@(DYO="!S970B"FUS9W-T<B`B3FEE="!I;F=E<W1E;&0B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S-"!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-CD@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,S,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8V
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C8@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4P-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<T(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU.3$*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C8V.2!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B3FEE="!O;F1E<G-T975N9"XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`X"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HQ,#4X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO
M=&5S(@IM<V=S='(@(DYO=&ET:65S(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O
M:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RXB"FUS9W-T<B`B3FEE=',@=&4@8FQA9&5R96XL(&=A('1E<G5G+B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED
M(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R(")'971A
M;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU
M;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(D%A;G1A;"!K87)A:W1E<G,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B06%N=&%L(&MO
M;&]M;65N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D%A;G1A
M;"!R:6IE;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")'971A
M;&QE;B!N:65T(&]P9V5G979E;B!V;V]R(&)I:G=E<FME;B!I;B!E96X@9&ES
M=')I8G5T:65L:6IS="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B
M3V)J96-T(@IM<V=S='(@(D]B:F5C="(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")/
M8FIE8W1E:6=E;F%A<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]C=&%A;"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(D]K=&]B97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(D)E;&5D:6=I;F=F
M:6QT97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED
M(")/9F9I8V4B"FUS9W-T<B`B2V%N=&]O<B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")/=61E(&5N(&YI975W92!W
M86-H='=O;W)D96X@9&EE;F5N('9E<G-C:&EL;&5N9"!T92!Z:6IN+B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A
M<W-W;W)D(@IM<V=S='(@(D]U9&4@=V%C:'1W;V]R9"(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES
M(&YO="!C;W)R96-T+B(*;7-G<W1R(")/=61E('=A8VAT=V]O<F0@:7,@;FEE
M="!J=6ES="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,0IM<V=I9"`B3VUA;B(*;7-G<W1R(")/
M;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N(@IM<V=S='(@(D%L;&5E;B!)34%0('-E<G9E<G,@;VYD97)S=&5U
M;F5N(&=E9&5E;&1E(&UA<'!E;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(D%L;&5E;B!B96QE9&EG96YD92!F;W)T=6YE<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW
M,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G
M<W1R(")3;&5C:'0@Z>EN(&4M;6%I;&%D<F5S('1O96=E<W1A86XN(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*
M;7-G<W1R("(B"B)!;&QE96X@9&4@96EG96YA87(@;V8@965N('-Y<W1E96UB
M96AE97)D97(@;6%G(&1E(&5I9V5N86%R<F5C:'1E;B!V86X@965N("(*(G-H
M87)E('=I:GII9V5N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#$@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D]P96X@:6X@965N(&YI975W('-C:&5R;2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+B(*;7-G<W1R("(B"B)/<&5N4U-,(&9O=70Z(&MO;B!G
M965N(&1A=&$@=6ET(&AE="!O;F1E<G1E:V5N9&4@4R]-24U%(&]N9&5R9&5E
M;"!H86QE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B3W!E;G0@9&5Z92!L:6YK(&EN(&5E;B!N
M:65U=R!S8VAE<FTB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G
M:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B0F5S='5R:6YG<W-Y=&5E
M;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@
M(D]P=&EO;G,B"FUS9W-T<B`B3W!T:65S(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P=&EE<R!V;V]R
M("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(D=E;W)D96YD92!L
M:6IS="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X
M"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI<W1A=&EE(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@
M(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B3W)G86YI<V%T:64@965N
M:&5I9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@
M(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI<V5R96XB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@
M=&5M<&QA=&4B"FUS9W-T<B`B3W)I9VEN965L('1O97!A<W-I;F=S<VIA8FQO
M;VXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(D]R
M:6=I;F5L92!S:F%B;&]N96X@:6X@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G
M:60@(D]T:&5R(@IM<V=S='(@(D%N9&5R92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(D%N9&5R92!I;F9O<FUA=&EE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B16EG
M96YA87)R96-H=&5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP
M.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B4$%-(&%U=&AE;G1I8V%T:64@:7,@;FEE="!B97-C:&EK
M8F%A<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")0
M14%2.CI-86EL(&)A8VME;F0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS
M9W-T<B`B1&EG:71A;&4@4$=0(&AA;F1T96ME;FEN9R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T
M960@1&%T82(*;7-G<W1R(")'96-O9&5E<F1E(%!'4"!D871A(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U
M8FQI8R!+97DB"FUS9W-T<B`B3W!E;F)A<F4@4$=0('-L975T96PB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(D]N9&5R=&5K96YD92]G
M96-O9&5E<F1E(%!'4"!D871A(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y
M"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")02%`@8V]D92(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(
M4"!S:&5L;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,X"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(DQI8VAT92!R
M96=E;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")296=E
M;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")"=6EE
M;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")3;F5E=7<@
M;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")3
M;F5E=7=B=6EE;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(EIO;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B
M3VYW965R<V)U:65N(&YA(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HR.#8*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG
M(@IM<V=S='(@(E!/4TE8(&5X=&5N<VEE(&]N=&)R965K="(*"B,Z(&QI8B]A
M<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")02%`@7U-H
M96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")6<FEJ92!R=6EM
M=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#<*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A
M:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-`IM<V=I9"`B4&%L874B"FUS9W-T<B`B
M4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DR"FUS9VED(")086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S=&EJ;G,@5&5R<FET;W)I
M=6TL($)E>F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R"FUS9VED(")086YA;6$B"FUS9W-T
M<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U"FUS9VED(")087!U82!.97<@1W5I
M;F5A(@IM<V=S='(@(E!A<'5A($YI975W($=U:6YE82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.34*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!A
M<G1L>2!#;&]U9'DB"FUS9W-T<B`B1V5D965L=&5L:6IK(&)E=V]L:W0B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS
M9VED(")087-S=V]R9"(*;7-G<W1R(")786-H='=O;W)D(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N
M9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5V%C:'1W;V]R9"!M970@<W5C
M8V5S(&=E=VEJ>FEG9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R
M(")786-H='=O;W)D(&]N:G5I<W0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@
M4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")786-H='=O;W)D(&ES
M('9E<F5I<W0@=F]O<B!2041)55,@875T:&5N=&EC871I92XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")786-H='=O;W)D(&UE="!B979E<W1I
M9VEN9R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I
M9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E=A8VAT=V]O<F0Z(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS
M9W-T<B`B5V%C:'1W;V]R9#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N(@IM<V=S='(@(E=A8VAT=V]O<F1E;B!M;V5T96X@;W9E<F5E;FMO;65N
M+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T
M92(*;7-G<W1R(")0;&%K:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`B4&QA:VME;B!V86YA9B!P<FEK8F]R9"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A
M=&@B"FUS9W-T<B`B4&%D(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B2&%N9V5N
M9&4@:6YS8VAR:6IV:6YG96XZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B365N<V5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E
M<F-E;G0B"FUS9W-T<B`B4')O8V5N="(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B3VYD97)H;W5D<W=E<FMZ86%M
M:&5D96X@=6ET=F]E<F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q
M,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN/R(*;7-G<W1R(")/;F1E<FAO=61S=V5R:WIA86UH961E;B!U:71V;V5R
M96X@8FEJ(&%A;FUE;&1I;F<_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4F5C:'0B
M"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*
M;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R
M(")296-H="!<(B5S7"(@;FEE="!V97)W:6ID97)D+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R(")296-H="!G97=E:6=E<F0B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5C:'1E;B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,"!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4X"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI
M;B]P97)M<R]I;F1E>"YP:'`Z,C(*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(E)E8VAT96YB96AE97(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N
M(@IM<V=S='(@(E!E<G-O;VYL:6IK92!I;F9O<FUA=&EE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@S"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B2'5I<V1I97)E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-@IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B
M4&AI;&EP<&EJ;F5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;VXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T
M;W,B"FUS9W-T<B`B1F]T;R=S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S
M='(@(E!I>&5L<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I
M9"`B4&QA=&ET=61E<R(*;7-G<W1R(")0;&%T:71U9&5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I
M9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(DML:6L@
M:6X@965N(&-E;"P@82YU+F(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM
M<V=S='(@(D)E=F5S=&EG+"!D870@=2!D:70@96QE;65N="!W:6QT('9E<G=I
M:F1E<F5N+"!A+G4N8CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T
M<B`B0F5V97-T:6<L(&1A="!U(&1I="!E;&5M96YT('=I;'0@;&]S:V]P<&5L
M96XL(&$N=2YB+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-C(*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S
M='(@(D=E968@965N(&UA86YD(&5N(&5E;B!J86%R+"!A+G4N8BXB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB
M"FUS9W-T<B`B165N(&YA86T@=F]O<B!D92!N:65U=V4@8V%T96=O<FEE(&EN
M=F]E<F5N+"!A+G4N8BXZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB
M"FUS9W-T<B`B1V5E9B!E96X@9V5L9&EG($E0(&%D<F5S+"!A+G4N8BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0P"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"B)'965F(&5E;B!G96QD:6=E(&1A
M='5M(&$N=2YB+BP@8V]N=')O;&5E<B!H970@86%N=&%L(&1A9V5N(&EN(&1E
M(&UA86YD+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#<*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(D=E968@
M965N(&=E;&1I9V4@=&EJ9"P@82YU+F(N(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM
M87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")'965F(&5E;B!S86UE;G9A
M='1I;F<@=F%N(&AE="!P<F]B;&5E;2P@82YU+F(N(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P
M87-S=V]R9"(*;7-G<W1R(")'965F('5W(&=E8G)U:6ME<G-N86%M(&5N('=A
M8VAT=V]O<F0L(&$N=2YB+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT
M+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*
M(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3&5E<R!D92!V;VQG96YD92!T96MS="P@
M82YU+F(N(%4@34]%5"!D92!V;V]R=V%A<F1E;B!T92!A8V-E<'1E<F5N(&]M
M(&AE="`B"B)S>7-T965M('1E(&MU;FYE;B!G96)R=6EK96XN(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G
M:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T
M<B`B1V5E9B!D92!N:65U=V4@8V%T96=O<FEE;F%A;2P@82YU+F(N.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X.`IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&5N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G
M<W1R(")0;VQI=&EE:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(E!E:6QI;F=E;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3,*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(T"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S
M='(@(E!O<VET:6]N97)I;F<@=F%N(&1E>F4@869B965L9&EN9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VET:6]N
M97)I;F<@=F%N(&1E>F4@=&%B96PB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H
M;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(E-T=75R(&YA87(@9&5Z
M92!M87`@*&YI970@869G961W;VYG96X@9&]O<B!)34%0*2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L
M('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@(@IM<V=S='(@(DYE97)S;&%G('9A;B!D92!A9F=E;&]P96X@
M)7,@=7)E;CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(").
M965R<VQA9SQB<B`O/FMA;G,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@=F5R
M96ES=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?
M<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!V97)E:7-T92!S97-S:64@97AT
M96YT:64@;FEE="!G979O;F1E;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B3'5C:'1D<G5K(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E
M82!L979E;#H@(@IM<V=S='(@(DQU8VAT9')U:R!O<"!Z965N:79E874Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`B3'5C:'1D<G5K.B`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`IM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R(")"96]O<F1E;&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"FUS
M9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B0F5O;W)D965L(&1E(&%F8F5E;&1I;F<@:6X@965N(&YI975W('-C:&5R
M;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O
M<'1I;VYS(@IM<V=S='(@(E9O<FEG92!O<'1I97,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D
M;V-U;65N="(*;7-G<W1R(")$;V-U;65N="!A9F1R=6MK96XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@
M2V5Y(@IM<V=S='(@(E!R:79E('-L975T96PB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@
M(E!R;V)L965M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED
M(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!R;V)L965M8F5S8VAR
M:6IV:6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I
M9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5C=&5N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S8*;7-G:60@(E!R
M;VUP="!T97AT(@IM<V=S='(@(E!R;VUP="!T96MS="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*
M;7-G<W1R(")/<&5N8F%R92!S;&5U=&5L(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I
M=&AM(@IM<V=S='(@(D]P96YB87)E('-L975T96P@86QG;W)I=&AM92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0
M=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B3W!E;F)A<F4@<VQE=71E;&EN9F]R
M;6%T:64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*
M;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(D]P96YB86%R+U!R:79E('-L975T96QP
M86%R(&YI970@9V5G96YE<F5E<F0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,0IM<V=I9"`B
M4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I8V\B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@
M;65S<V%G97,B"FUS9W-T<B`B5VES(&)E<FEC:'1E;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.38*;7-G:60@(E%A=&%R(@IM<V=S='(@(E%U871A<B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV-`IM<V=I9"`B475E<GDB"FUS9W-T<B`B475E<GDB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*;7-G:60@(E%U;W1A(@IM<V=S
M='(@(E%U;W1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="DB"FUS9W-T<B`B4E-!(&]P96YB87)E('-L975T96P@*"5D(&)I="DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I
M;R!S96QE8W1I;VXB"FUS9W-T<B`B2V5U>F5R;VYD:F4@<V5L96-T:64B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I
M9"`B4F%I;B(*;7-G<W1R(")296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN($5A<FQY(@IM<V=S
M='(@(E9R;V5G(')E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("),86%T
M(')E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(E)E9V5N8G5I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G
M:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B4F5G96X@96X@<VYE975W(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G
M:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")296=E;B!N86%R('-N965U=R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R
M='5N92(*;7-G<W1R(")286YD;VT@1F]R='5N92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B5F5R
M:&]U9&EN9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQE>F5N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*;7-G:60@(E)E860@;65S<V%G
M97,B"FUS9W-T<B`B3&5E<R!B97)I8VAT96XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A
M;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92XB"FUS9W-T<B`B)7,@96-H="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI
M;F<@:V%N(&YI970@;VYG961A86X@9V5M86%K="!W;W)D96XN(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(D=E
M8G)U:6ME<G-D871A('9A;B!G96)R=6EK97(@)7,@96-H="!V97)W:6ID97)E
M;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@(@HB;VYG961A86X@9V5M86%K
M="!W;W)D96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS
M9W-T<B`B2&5R:&%A;'0@=7<@=F]R:6=E(&)E=V5R:VEN9R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V
M"FUS9VED(")2969R97-H(@IM<V=S='(@(E9E<G9E<G-E;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-
M96YU($5L96UE;G1S.B(*;7-G<W1R(")697)V97)S(&1Y;F%M:7-C:&4@;65N
M=2!O;F1E<F1E;&5N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*
M;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E!O<G1A;'=E
M97)G879E('9E<G9E<G-E;CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R(")2
M96=E>"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S$*;7-G:60@
M(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(D)E=')E:VMI;F=E;B!B
M<F]W<V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM
M<V=S='(@(DAE<FQA9&5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*
M;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B3W!M97)K:6YG96XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*
M;7-G<W1R(")397)V97)S(&]P(&%F<W1A;F0B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")54DP@;W`@869S=&%N
M9"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,R!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C(R"FUS9VED(")296UO=F4B"FUS9W-T<B`B5F5R
M=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*
M;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")";&]K('9E<G=I:F1E<F5N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")+;VQO;2!V97)W:6ID
M97)E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D]P;6%A
M:R!V97)W:6ID97)E;B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")086%R('9E<G=I:F1E
M<F5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M
M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*(E9E<G=I:F1E<B!H970@;W!G97-L86=E;B!S
M8W)I<'0@=6ET(&1E('1I:F1E;&EJ:V4@9&ER96-T;W)Y(&]P(&1E('-E<G9E
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B5F5R=VEJ
M9&5R(&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT(@IM<V=S='(@(E9E<G=I:F1E<B!D97IE(&YO9&4@=6ET
M(&AE="!D;V-U;65N="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(D=E8G)U:6ME
M<B!V97)W:6ID97)E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B
M"FUS9W-T<B`B5F5R=VEJ9&5R(&=E8G)U:6ME<CH@)7,B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T
M<B`B5F5R>F]E:R!K;VX@;FEE="!W;W)D96X@8F5A;G1W;V]R9"X@1V5R971O
M=7)N965R9&4@9F]U=&-O9&4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO
M="!B92!F;W5N9"XB"FUS9W-T<B`B1&4@9V5V<F%A9V1E('-E<G9I8V4@:V]N
M(&YI970@=V]R9&5N(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(W"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9E<F5I<W1E(%PB
M)7-<(B!N:65T(&]P9V5G979E;B!I;B`E<R!C;VYF:6=U<F%T:64N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HV-S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M5F5R96ES=&4@7"(E<UPB(&YI970@;W!G96=E=F5N(&EN(%9&4R!C;VYF:6=U
M<F%T:64N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<V"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9E<F5I<W1E(%PB)7-<(B!N
M:65T(&]P9V5G979E;B!I;B!C;VYF:6=U<F%T:64N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,V"FUS9VED(")297%U:7)E9"!&
M:65L9"(*;7-G<W1R(")697)E:7-T('9E;&0B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,2!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C$*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<W"FUS9VED(")297-E="(*;7-G<W1R(")(97)S=&5L;&5N(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W
M;W)D(@IM<V=S='(@(E)E<V5T('=A8VAT=V]O<F0B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R(")297-E="!U=R!W86-H='=O;W)D(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S
M='(@(E9O;W)G86%N9&4@<75E<GD@:&5R<W1E;&QE;B(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR.2!A9&UI;B]P:'!S:&5L;"YP:'`Z-S(@861M:6XO<W%L
M<VAE;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM<V=S='(@(E)E<W5L=&%T
M96XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS
M(@IM<V=S='(@(E1E<G5G(&YA87(@;W!T:65S(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D
M(@IM<V=S='(@(E1Y<"!N:65U=R!W86-H='=O;W)D(&]P;FEE=7<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DW"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)E=6YI;VXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@
M(D-O;F9I9W5R871I92!T97)U9WIE='1E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*
M;7-G<W1R(")2:6-H(%1E>'0@161I=&]R(&]P=&EE<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")286%D
M<V5L<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B4F5C:'1S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,PIM<V=I9"`B4FEG:'0@:&5A
M9&5R(@IM<V=S='(@(E)E8VAT<V4@:V]P(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(E)E
M8VAT<V4@=V%A<F1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(E)I7VIE:6=E;G-C:&%P<&5N+BXN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L
M92(*;7-G<W1R(")2;VPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX"FUS9VED(")2;VUA;FEA
M(@IM<V=S='(@(E)O96UE;FGK(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M("(Q.#`@9')A86EE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(DYA
M87(@;&EN:W,@9')A86EE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M(").86%R(')E8VAT<R!D<F%A:65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E
M<G1I97,B"FUS9W-T<B`B4FEJ(&5I9V5N<V-H87!P96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED
M(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")2:6H@96EG96YS8VAA<'!E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q
M"FUS9VED(")2;W=S.B(*;7-G<W1R(")2:6IE;CHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2
M=6QE<R(*;7-G<W1R("),:6YIZW)I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S
M='(@(DQI;FGK<FEN9R!Z86P@=F5R<V-H:6IN96X@='5S<V5N(&%L;&4@<FEJ
M96X@96X@:V]L;VUM96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("),:6YIZW)I;F<@>F%L
M(&%L;&5E;B!T=7-S96X@:V]L;VUM96X@=F5R<V-H:6IN96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G
M<W1R("),:6YIZW)I;F<@>F%L(&%L;&5E;B!T=7-S96X@<FEJ96X@=F5R<V-H
M:6IN96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED(")2=6XB
M"FUS9W-T<B`B4W1A<G1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D*;7-G:60@(E)U<W-I
M86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-S:7-C:&4@1F5D97)A=&EE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,`IM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W86YD82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED
M(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B0W)Y
M<'1O9W)A9FES8VAE(%,O34E-12!H86YD=&5K96YI;F<B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N
M8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E,O34E-12!G96-O9&5E<F0@8F5R
M:6-H="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G
M:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B4T%33"!A=71H96YT:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A87(N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3
M($UE<W-A9VEN9R(*;7-G<W1R(")335,@=F5R<W1U<F5N(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,
M('-H96QL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W-`IM<V=I
M9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")3
M44P@<W1A=&5M96YT('9O;W(@=V%A<F1E>F]E:V]P9')A8VAT96XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T
M<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G
M<W1R(")354-#15,B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@
M4VAE;&PB"FUS9W-T<B`B4U]13"!S:&5L;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@
M(EIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-PIM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S
M='(@(E-T($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,0IM<V=I9"`B4V%I;G0@2VET
M=',@86YD($YE=FES(@IM<V=S='(@(E-T($MI='1S(&5N($YE=FES(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Y"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")3="!,=6-I
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#D*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`B4W0@4&EE<G)E(&5N($UI<75E;&]N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-`IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,B"FUS9W-T<B`B4W0@5FEN8V5N="!E;B!D92!'<F5N861I;F5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I
M9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(EIE;&9D92!F<F%M92`H
M7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`B
M4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$R"FUS9VED(")386X@36%R:6YO(@IM<V=S
M='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V"FUS9VED(")386\@5&]M
M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@96X@4')I;F-I<&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3
M871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QL:65T<')O=FED97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`Q"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B
M4V%U9&D@07)A8FGK(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDY"FUS9VED(")3879E(@IM<V=S='(@(D]P<VQA86XB"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!O<'-L86%N(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92`E<R(*;7-G<W1R("(E<R!O<'-L86%N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(D]P=&EE<R!O<'-L86%N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)'96=E;F5R965R9&4@8V]N9FEG=7)A
M=&EE(&%L<R!02%`@<V-R:7!T(&]P9V5S;&%G96X@:6X@9&4@=&EJ9&5L:6IK
M92`B"B)D:7)E8W1O<GD@=F%N('5W('-E<G9E<BXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!C;VYF:6=U<F%T:64@;W!G
M97-L86=E;B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B!<(B5S7"(N(@IM<V=S='(@(E-E='5P('5P9W)A9&4@<V-R:7!T(&]P9V5S
M;&%G96X@;F%A<CH@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B
M"FUS9W-T<B`B1V5S<')E:61E(&]N=V5E<G-B=6EE;B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")7971E
M;G-C:&%P(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C
M:"(*;7-G<W1R("):;V5K96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("):;V5K;6%C
M:&EN97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.34U"FUS9VED
M(")396QE8W0@1FEL97,B"FUS9W-T<B`B2VEE<R!B97-T86YD96XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@9&%T=6TB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L
M96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@9W)O
M97`@;VT@=&]E('1E('9O96=E;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")3
M96QE8W1E97(@965N(&YI975W92!E:6=E;F%A<B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM
M<V=S='(@(E-E;&5C=&5E<B!E96X@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D
M(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@9V5B<G5I:V5R(&]M('1O92!T92!V
M;V5G96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(D%L;&5S('-E;&5C
M=&5R96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0S"FUS9VED
M(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-T
M965R(&%L;&4@9&%T=6UC;VUP;VYE;G1E;BXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@
M;V)J96-T(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@;V)J96-T(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B
M4V5L96-T(&YO;F4B"FUS9W-T<B`B3FEE=',@<V5L96-T97)E;B(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N(@IM<V=S='(@(B(*(E-E;&5C=&5E<B!D92!B96YO9&EG9&4@:V%R
M86MT97)S('5I="!D92!O;F1E<G-T86%N9&4@=F%K:F5S+B!5(&MU;G0@9&5Z
M92!D86X@(@HB:V]P:>MR96X@96X@<&QA:VME;B!I;B!H970@=&5K<W1G96)I
M960N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E-E;&5C=&5E<B!H
M970@9&%T=6US8VAE:61I;F=S=&5K96XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM
M<V=S='(@(E-E;&5C=&5E<B!H970@9&%T=6UF;W)M86%T.B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")3
M96QE8W1E97(@9&4@:61E;G1I=&5I="!D:64@=2!W:6QT('=I:GII9V5N.B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE8W1E97(@:&5T('1I
M:F1S8VAE:61I;F=S=&5K96XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@
M(E-E;&5C=&5E<B!H970@=&EJ9'-F;W)M86%T.B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+B(*;7-G<W1R(")396QE8W1E97(@='=E92!O=F5R965N:V]M96YD
M92!V96QD96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I
M9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")396QE8W1E
M97(@=7<@:VQE=7)S8VAE;6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*
M;7-G<W1R(")396QE8W1E97(@=7<@9V5W96YS=&4@=&%A;#HB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R(")0<F]B;&5E;7)A<'!O<G0@=F5R>F5N9&5N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E9E<GIE;F0@4TU3(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@(E-E;G-O<CH@(@IM
M<V=S='(@(E-E;G-O<CH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")397!T
M96UB97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<G9I
MZR!E;B!-;VYT96YE9W)O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B4V5R
M:65N=6UM97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y
M"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")397)V97)D871A(&9O=70@;V8@;FEE="!B97-C:&EK8F%A<BXB
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M
M:6XB"FUS9W-T<B`B4V5S<VEE8F5H965R9&5R(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S
M:6]N($E$(&5X<&ER960N(@IM<V=S='(@(E-E<W-I92!)1"!V97)L;W!E;BXB
M"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@
M(E-E<W-I97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS
M9VED(")3970B"FUS9W-T<B`B26YS=&5L;&5N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N
M(@IM<V=S='(@(B(*(DEN<W1E;&QE;B!V86X@;W!T:65S(&]M('4@=&]E('1E
M('-T86%N('5W('=A8VAT=V]O<F0@=&4@<F5S971T96XL('=A;FYE97(@=2`B
M"B)D:70@8F5N="!V97)G971E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HB
M26YS=&5L;&5N('9A;B!S97)V97)S(&]P(&%F<W1A;F0@9&EE('4@=VEL="!B
M96YA9&5R96X@=F%N=6ET('5W('!O<G1A;"XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B26YS=&5L
M;&5N('9A;B!U=R!G97=E;G-T92!T86%L+"!T:6ID>F]N92!E;B!D871U;6]P
M=&EE<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B
M"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N
M<RXB"FUS9W-T<B`B(@HB26YS=&5L;&5N('9A;B!U=R!O<'-T87)T=&]E<&%S
M<VEN9RP@:VQE=7)S8VAE;6$L('!A9VEN879E<G9E<G-I;F<@96X@86YD97)E
M("(*(G=E97)G879E;W!T:65S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(DEN<W1E;&QE;B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(E-E='5P('5P
M9W)A9&4@<V-R:7!T<R!B97-C:&EK8F%A<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(E9E<G-C:&EL
M;&5N9&4@;&]C871I97,@;6]G96QI:FL@;65T(&1E('!A<F%M871E<CH@(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,PIM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")397EC
M:&5L;&5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I
M9"`B4VAO<'!I;F<B"FUS9W-T<B`B5VEN:V5L96XB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*
M;7-G<W1R(")+;W)T92!S86UE;G9A='1I;F<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B1&EE;F5N('-N96QT;V5T
M<V5N('9O;W(@9&4@;65E<W1E(&QI;FMS(&=E9&5F:6YI965R9"!T92!W;W)D
M96X_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*
M;7-G:60@(E-H;W<B"FUS9W-T<B`B5V5E<F=E=F5N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B
M971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E
M9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)697)S8VAI;&QE;B!L
M871E;B!Z:65N('1U<W-E;B!D92!H=6ED:6=E(&]P9V5S;&%G96X@8V]N9FEG
M=7)A=&EE(&5N(&1E("(*(FYI975W92!G96=E;F5R965R9&4@8V]N9FEG=7)A
M=&EE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B
M3&%A='-T92!A86YM96QD:6YG<W1I:F0@=V5E<F=E=F5N(&)I:B!A86YM96QD
M96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")/<'1I92!W
M965R9V5V96X@;VT@;W)I9VEN965L('1E(&)E=V%R96XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDU"FUS9VED(")3:&]W('!I8VME<B(*;7-G
M<W1R(")+:65Z97(@=V5E<F=E=F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R
M/R(*;7-G<W1R(")486)E;&)E=V5R:VEN9W-T86%K8F%L:R!W965R9V5V96X_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R
M("(E<R!M96YU(&%A;B!D92!L:6YK97)K86YT('=E97)G979E;C\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B5&%B96QC96QE:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS
M=&5R('=E97)G979E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%B96QE:6=E;G-C:&%P<&5N
M(&1I86QO;V=V96YS=&5R('=E97)G979E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A
M8F5L<FEJ96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(D%F8F5E;&1I;F=S96EG96YS8VAA<'!E;B!D:6%L;V]G
M=F5N<W1E<B!W965R9V5V96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")5<&QO860@=V5E
M<F=E=F5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B0G5I96XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO
M=V5R<R!%87)L>2(*;7-G<W1R(")"=6EE;B!V<F]E9R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S
M($QA=&4B"FUS9W-T<B`B0G5I96X@;&%A="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3:&]W97)S(&EN('1H
M92!6:6-I;FET>2(*;7-G<W1R(")"=6EE;B!I;B!D92!N86)I:FAE:60B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q
M.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(E9E<FML96EN96XB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P
M-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM
M<V=S='(@(E9E<FML96EN(&]F('9E<G!L86%T<R!N86)U<FEG92!B;&]K:V5N
M(&5E<G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM
M<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B26YT96ME
M;F5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3,*
M;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")(86YD=&5K96YI;F<B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG
M;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")(86YD=&5K96YI;F<@86QG;W)I
M=&AM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#8*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R
M(")3:6YG87!O<F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDQ,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`U
M"FUS9VED(")3:7IE(@IM<V=S='(@(D=R;V]T=&4B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-
M86EN=&5N86YC92(*;7-G<W1R(")/;F1E<FAO=60@;W9E<G-L86%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,`IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=V%K:6IE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P.`IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO
M=F5N:>LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R(")3;F5E=7<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3
M:&]W97(B"FUS9W-T<B`B4VYE975W=FQA86<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S
M(@IM<V=S='(@(E-N965U=V)U:65N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L
M>2(*;7-G<W1R(")S;F5E=7=B=6EE;B!V<F]E9R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3;F]W(%-H;W=E
M<G,@3&%T92(*;7-G<W1R(")3;F5E=7=B=6EE;B!L86%T(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M(")3;F5E=7=D:65P=&4Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y
M"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")3
M;F5E=7=E<75I=F%L96YT(&EN('=A=&5R.B`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R"FUS
M9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B4V]L;VUO;B!E:6QA;F1E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,30*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M
M86QIZR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N
M9W,@)B!0;V5M<R(*;7-G<W1R("),:65D97)E;B!E;B!G961I8VAT96XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`X"FUS9VED(")3;W)T(&]R
M9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3;W)T965R=F]L9V]R9&4@<V5L96-T
M:64B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")"
M<F]N861R97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T:"!!9G)I8V$B
M"FUS9W-T<B`B6G5I9"!!9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S
M='(@(EIU:60@175R;W!E97,@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q
M"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<R(*;7-G<W1R("):=6ED($=E;W)G:>L@96X@9&4@6G5I9"!386YD
M=VEC:"!E:6QA;F1E;B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B6G5I9&5L:6IK(&AA;&9R;VYD(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B4W!A=&GK<FEN9R!T=7-S
M96X@86%N9W)E;GIE;F1E(&-E;&QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N
M(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(E-P871IZW)I
M;F<@='5S<V5N(&EN:&]U9"!E;B!R86YD(&EN(&-E;"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(E-C
M:&5I9&EN9W-T96ME;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-0IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")3
M<&%T:>MR:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*
M;7-G<W1R(")3<&%T:>MR:6YG(&5N('9R:6IE(')U:6UT92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@P"FUS9VED(")3<&%I;B(*;7-G<W1R(")3<&%N:F4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-P
M86TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I
M86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(E-P96-I86%L(&MA<F%K=&5R
M(&EN=F]E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B0V5L
M(&]P<W!L:71S96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T
M<B`B2V]L;VT@;W!S<&QI='-E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*
M;7-G<W1R(")2:6H@;W!S<&QI='-E;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30Q"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C8*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD86%R
M9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4
M<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y,0IM<V=I
M9"`B4W1A<G0@>65A<B(*;7-G<W1R(")3=&%R=&IA87(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@
M4')O=FEN8V4B"FUS9W-T<B`B4W1A870@;V8@<')O=FEN8VEE(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U
M<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-SDW"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")/<'-L86=F
M;W)M86%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")$;V]R:&%L96XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*
M;7-G<W1R(")3=')I;F=L:6IS="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(E-T<FEP(&1O;65I;B!V86X@:&5T(&%D<F5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I:FP@6T-34UTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED
M(")3=2(*;7-G<W1R("):;R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N:65T(&=E
M=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B3VYD97)W97)P(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,Q.`IM<V=I9"`B4W5B;6ET(@IM<V=S='(@
M(D)E=F5S=&EG96XB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R
M97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)697)Z;V5K
M('9E<G-T=75R9"!O;2!<(B5S7"(@86%N(&AE="!S>7-T965M('1O92!T92!V
M;V5G96XN(%4@:W5N="!N:65T("(*(F%A;FUE;&1E;B!T;W0@=7<@=F5R>F]E
M:R!I<R!G;V5D9V5K975R9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B
M4W5B<V-R:7!T(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-0HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U8V-E<R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB(&UE="!S=6-C97,@86%N(&AE="!S>7-T965M('1O96=E=F]E9V0N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1&%T82!V86X@9V5B<G5I:V5R(%PB
M)7-<(B!M970@<W5C8V5S('5I="!H970@<WES=&5E;2!V97)W:6ID97)D+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E
M9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!M970@<W5C8V5S('9E<G=I:F1E
M<F0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(EPB)7-<(B!M970@<W5C8V5S('5I="!H970@<WES=&5E
M;2!V97)W:6ID97)D+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(D-O;F9I9W5R871I92!M
M970@<W5C8V5S('1E<G5G9V5Z970N(%9E<FYI975W(&]M('=I:GII9VEN9V5N
M('1E('II96XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D)A8VMU<&-O;F9I
M9W5R871I92!M970@<W5C8V5S<R!O<&=E<VQA9V5N+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R(")"86-K=7!C;VYF:6=U<F%T:65B97-T86YD("5S(&UE="!S
M=6-C97-S(&]P9V5S;&%G96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<
M(B(*;7-G<W1R(")<(B5S7"(@;65T('-U8V-E<R!B:6IG97=E<FMT(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(B5S(&UE="!S=6-C97,@9V5S8VAR979E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-O961A;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*
M;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4V%M96YV871T:6YG(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R
M("):;VYS;W!G86YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS
M9VED(")3=6X@4V5T(@IM<V=S='(@(EIO;G-O;F1E<F=A;F<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B4W5N
M;GDB"FUS9W-T<B`B6F]N;FEG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R("):;VYS;W!G86YG
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("):;VYS
M;W!G86YG+UIO;G-O;F1E<F=A;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B6F]N<V]P
M9V%N9SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM
M<V=I9"`B4W5N<V5T(@IM<V=S='(@(EIO;G-O;F1E<F=A;F<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*
M;7-G<W1R("):;VYS;VYD97)G86YG.B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*
M;7-G<W1R(")3=7!E<G-C<FEP="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B3VYD97)S=&5U;FEN
M9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U
M<FEN86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B06-H=&5R;F%A;2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#D*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T
M<B`B4W!I='-B97)G96X@96X@2F%N($UA>65N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.0IM
M<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W87II;&%N9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#4*;7-G:60@(E-W961E;B(*;7-G<W1R("):=V5D96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B6G=I='-E<FQA;F0B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN
M8R!L;V<@9&5L971E9"(*;7-G<W1R(")3>6YC(&QO9R!V97)W:6ID97)D(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM
M<V=S='(@(E-Y;F--3"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*
M;7-G<W1R(")3>6YT87AF;W5T(&EN('IO96MT97)M96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$X"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3>7)I
M<V-H92!!<F%B:7-C:&4@4F5P=6)L:65K(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS9W-T
M<B`B3VYW965R<V)U:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R
M(")/;G=E97)S8G5I96X@96X@=VEN9&5R:6<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,B"FUS
M9W-T<B`B3VYW965R<V)U:65N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S
M='(@(D]N=V5E<G-B=6EE;B!V<F]E9R(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135B!B
M97-T86YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R
M(")486)E;&5I9V5N<V-H87!P96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T
M<B`B5&%B96QS970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM
M<V=S='(@(E1A8F5L96EG96YS8VAA<'!E;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S0*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")486EW86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XL(%!R;W9I;F-I92!V
M86X@0VAI;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U"FUS9VED(")486II:VES=&%N(@IM
M<V=S='(@(E1A9'IJ:6MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4*;7-G:60@(E1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>F%N:6$L
M(%9E<F5N:6=D92!297!U8FQI96L@=F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R(")$;V5L.B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,R
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(E1A:V5N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@
M(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L969O;VYN=6UM97(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U=7(@=F%N(&AE="!A9F=E;&]P
M96X@=75R.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B
M5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U=7(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@
M(@IM<V=S='(@(E1E;7!E<F%T=75R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M
M<&5R871U=7(\8G(@+SXH)7-(;V]G)7,O)7-,86%G)7,I("9G<F0[)7,B"@HC
M.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")3:F%B;&]O;B!<(B5S7"(@;FEE="!G979O;F1E;BXB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B4VIA8FQO;VYB96AE97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,C<*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5K<W0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B06QL
M965N('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")4
M96MS="!U:71L:6IN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E:W-T
M8F]V96YK86YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B1&\B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T
M<B`B5&AA:7,@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-`IM<V=I9"`B5&AA
M:6QA;F0B"FUS9W-T<B`B5&AA:6QA;F0B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B1&4@1E10(&5X=&5N=&EE(&ES(&YI970@
M8F5S8VAI:V)A87(N(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP
M:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`B2&5T(&=E<V-H:65D96YI<W-Y<W1E96T@:7,@=6ET9V5S8VAA
M:V5L9"XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(D1E($AO
M<F1E+TMO;&%B(&EN=&5G<F%T:64@;VYD97)S=&5U;G0@7"(E<UPB(&YI970B
M"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDX"FUS
M9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*
M;7-G<W1R(")(970@24U34"!L;V<@:V]N(&YI970@=V]R9&5N(&=E:6YI=&EA
M;&ES965R9"XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G
M:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'DB"FUS9W-T<B`B1&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!W97)D
M(&YI970@9V5L861E;B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D
M+B!%>&ET:6YG+B(*;7-G<W1R(")(970@3W!T:65S<V-H97)M(&ES(&=E<VQO
M=&5N+B!!9G-L=6ET96XN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*
M;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R
M92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W
M86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB1&4@8F5H965R
M9&5R(&1I96YT(&5E;B!P97)M86YE;G0@<F5C:'1E;F)A8VME;F0@=&4@8V]N
M9FEG=7)E<F5N(&%L<R!U("(*(G)E8VAT96X@=VEL="!G96)R=6EK96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B06QL
M965N(&1E(&]N9&5R:V%N="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DAE
M="!C;VYT86-T($E$(&YU;6UE<B!I<R!N:65T(&]P9V5G979E;BP@;&5E9R!G
M96QA=&5N(&]F(&ES(&YI970@9V5V;VYD96X@:6X@(@HB9&4@9&%T86)A<V4N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q
M"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")(970@861R97,@:7,@;65T
M('-U8V-E<R!A86X@=7<@861R97-B;V5K('1O96=E=F]E9V0N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB2&5T(&QO
M<V=E:V]P<&5L9&4@4$=0(&]N9&5R=&5K96YI;F=S8FQO:R!I<R!V97)E:7-T
M(&]M(&AE="!O;F1E<G1E:V5N9&4@(@HB8F5R:6-H="!T92!V97)I9FGK<F5N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(DAE="!D:7-T<G5B
M=71I96QI:G-T($E$(&ES(&YI970@;W!G96=E=F5N+"!L965G(&=E;&%T96X@
M;V8@:7,@;FEE="!G979O;F1E;B`B"B)I;B!D92!D871A8F%S92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM
M<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+B(*;7-G<W1R(")$92!D:7-T<FEB=71I96QI:G-T(&ES(&YI970@;W!G96=E
M=F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$V"FUS9VED
M(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R(")$92!C;V1E97)M;V=E;&EJ:VAE9&5N
M('9E<F5I<V5N(&5E;B!B979E:6QI9V1E('=E8G9E<F)I;F1I;F<N(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#8@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")(970@
M8F5S=&%N9"`E<R!D:65N="!E96X@)7,@:6YS=&5L;&EN9R!T92!B979A='1E
M;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W.2!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*
M;7-G<W1R(")(970@8F5S=&%N9"`E<R!D:65N="!E;FEG92`E<R!I;G-T96QL
M:6YG96X@=&4@8F5V871T96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+B(*;7-G<W1R(")(970@8F5S=&%N9"!K86X@;FEE="!N86%R
M('II8VAZ96QF(&=E:V]P:65E<F0@=V]R9&5N+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(DAE="!B97-T86YD(&)E=F%T=&4@9V5E;B!D871A
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(DAE="!V;VQG
M96YD92!Z:6IN(&1E(&MO<'!E;B!V86X@9&ET(&UE<W-A9V4O<F9C.#(R(&)E
M<FEC:'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO
M=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@
M9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G
M92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A
M;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7
M:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@
M)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R
M97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E
M96X@961I=&]R+B(*;7-G<W1R("(B"B)686X@9&4@=F]L;&5D:6<@<V-H97)M
M(&UO9&4@:7,@8F5K96YD+"!D870@9&ET('!R;V)L96UE;B!K86X@=F5R;V]R
M>F%K96X@;65T("(*(DEN=&5R;F5T($5X<&QO<F5R+"!V86YW96=E(&)R;W=S
M97)B=6=S('=A87(@=VEJ(&YI970@;VUH965N(&MU;FYE;BX@2&5T(&ES("(*
M(FUO9V5L:6IK(&1A="!U(')O;6UE;"!I;B!H970@8F5E;&1S8VAE<FTL(&=E
M8G)E:R!A86X@961I=&]R9G5N8W1I97,@96XO;V8@(@HB<F%N9&]M(&)R;W=S
M97(M(&-R87-H97,@97)V86%R="X@5V%N;F5E<B!U=R!S>7-T965M(%=I;F1O
M=W,@.7@@:7,L(&ES(&AE="`B"B)W86%R<V-H:6IN;&EJ:R!D870@=2!E96X@
M)T%L9V5M96YE($)E=F5I;&EG:6YG<R!&;W5T)R!K<FEJ9W0L(&5N(&]P;FEE
M=7<@(@HB9&EE;G0@=&4@:&5R<W1A<G1E;BY<7&Y<7&Y5(&)E;G0@9V5W86%R
M<V-H=7=D+B!$<G5K(&]P($]+('=A;FYE97(@=2!T;V-H(&1E("(*(G9O;&QE
M9&EG('-C:&5R;2!E9&ET;W(@=VEL="!P<F]B97)E;BXB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N
M=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B1&4@:61E
M;G1I=&5I="!<(B5S7"(@:7,@=F5R=VEJ9&5R9"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4
M:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")!;&QE96X@9&4@;&EN
M:V5R:V%N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U
M-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@
M;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S
M='(@(B(*(D1E('!L86%T<R!V86X@:&5T($=N=5!'('!R;V=R86UM82!D:65N
M="!O<&=E9V5V96X@=&4@=V]R9&5N(&EN(&1E("(*(D-R>7!T7W!G<#HZ(&-L
M87-S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<
M;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)(970@8F5R
M:6-H="!V97)S='5U<F0@;W`@)7,@86%N("5S(&UE="!O;F1E<G=E<G`@7"(E
M<UPB(&ES('=E97)G96=E=F5N+EQN(@HB1&ET(&ES(&=E96X@9V%R86YT:64@
M9&%T(&AE="!B97)I8VAT(&ES(&=E;&5Z96X@;V8@8F5G<F5P96XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(D1E(&YA86T@9&EE(&=E8G)U:6MT('=O<F1T(&)I:B!L:6YK96X@;F%A
M<B!D92!N:65U=R!B97)I8VAT('!A9VEN82(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@
M;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")(970@86%N=&%L('9E;&1E;B!D
M:65N="!N=6UE<FEE:R!T92!Z:6IN+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE
M(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S
M<RXB"FUS9W-T<B`B1&4@;W!E;G-S;"!M;V1U;&4@:7,@=F5R96ES="!V;V]R
M(&1E($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A
M=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L
M92!S:7IE(@IM<V=S='(@(B(*(D1E('9O;W)K975R<VEN<W1E;&QI;F<@7"(E
M<UPB(&MO;B!N:65T('=O<F1E;B!O<&=E<VQA9V5N+"!O;61A="!D92!D871A
M(&1E("(*(FUA>&EM=6T@=&]E;&%A=&)A<F4@9W)O;W1T92!O=F5R<V-H<FEJ
M9'0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z
M,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP
M:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)(970@<')O9W)A;6UA(&]M(&1I
M="!D871A='EP92`H)7,I('1E(&)E:VEJ:V5N+"!W97)D(&YI970@;W`@:&5T
M('-Y<W1E96T@(@HB9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(DAE="!A86YH86QI
M;F=S=&5K96X@9&EE;G0@Z^MN(&5N:V5L('1E:V5N('1E('II:FXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T
M<B`B06QL965N(&1E(')E8VAT97(M(&5N(&QI;FME<FMA;G0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS
M9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B06QL965N
M(&1E(')E8VAT97)K86YT(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(DAE="!S8VAE:61I;F=S=&5K96X@9&EE
M;G0@Z^MN(&5N:V5L('1E:V5N('1E('II:FXN(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E
M<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B1&4@<V5R
M=F5R(%PB)7-<(B!I<R!V97)W:6ID97)D+B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V
M97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")$92!S97)V97(@
M7"(E<UPB(&ES(&]P9V5S;&%G96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B2&5T(&%A;FUE;&1I;F=S
M=F5R>F]E:R!V;V]R("5S(&ES('9E<G=I:F1E<F0N(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B1&4@;W!G96=E=F5N(')I:B`H)60I(&)E<W1A870@
M;FEE="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R(")(970@=&EJ9&5L:6IK(&)E<W1A;F0@
M7"(E<UPB(&)E<W1A870@;FEE="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S`R"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T
M(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(D1E(&EN
M9V5V;V5R9&4@=&5K<W0@:V]M="!N:65T(&]V97)E96X@;65T(&1E('1E:W-T
M(&]P(&AE="!S8VAE<FTN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B06QL965N(&1E(&)O=F5N+2!E;B!O
M;F1E<FMA;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G
M<W1R(")!;&QE96X@9&4@8F]V96YK86YT(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B1&4@=7!L;V%D
M960@9&%T82!I<R!N82!D92!V;V]R9V%A;F1E('-T87`@=F5R;&]R96X@9V5G
M86%N+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A
M;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")(970@=7!L
M;V%D960@8F5S=&%N9"!I<R!N:65T(&]P9V5S;&%G96XN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")(970@=V5A=&AE<BYC;VT@8FQO:R!I
M<R!N:65T(&)E<V-H:6MB86%R+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E1H96UA9&ER96-T;W)Y(%PB)7-<
M(B!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(D=E96X@;W!T:65S(&)E<V-H:6MB86%R+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,U,`IM<V=I9"`B5&AE
M<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M(@IM<V=S='(@(D5R('II:FX@9V5E;B!O;F1E<F1E;&5N+"!W96QK92!I;FQI
M;F4@=V5E<F=E9V5V96X@:W5N;F5N('=O<F1E;BXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)%<B!Z:6IN('1E('9E96P@
M:V%R86MT97)S(&EN(&1I="!V96QD+B!5(&AE969T("5S(&MA<F%K=&5R<R!O
M<&=E9V5V96X[('4@(@HB9&EE;G0@;6EN9&5R(&1A;B`E<R!O<"!T92!G979E
M;BXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB
M)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")%96X@<')O8FQE96T@
M;65T(&AE="!T;V5V;V5G96X@=F%N(%PB)7-<(B!A86X@:&5T('-Y<W1E96TZ
M("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB165N('!R
M;V)L965M(&UE="!H970@=F5R=VEJ9&5R96X@=F%N(&1A=&$@=F%N(&=E8G)U
M:6ME<B!<(B5S7"(@=6ET(&AE="`B"B)S>7-T965M.B`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B165N('!R;V)L965M(&UE="!H970@=F5R=VEJ9&5R96X@=F%N(%PB
M)7-<(B!U:70@:&5T('-Y<W1E96TZ("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B165N('!R;V)L965M(&UE="!H
M970@8FEJ=V5R:V5N('9A;B!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3(W"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"XB"FUS9W-T<B`B165N('!R;V)L965M(&UE="!D92!B
M97-T86YD<W5P;&]A9#H@1V5E;B`E<R!W97)D(&=E=7!L;V%D+B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)%96X@<')O
M8FQE96T@;65T(&1E(&)E<W1A;F1S=7!L;V%D.B!(970@)7,@:7,@9W)O=&5R
M(&1A;B!D92!M87AI;75M("(*(G1O96QA871B87)E(&=R;V]T=&4@*"5D(&)Y
M=&5S*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB165N('!R;V)L965M(&UE="!D92!B
M97-T86YD<W5P;&]A9#H@2&5T("5S(&ES('-L96-H=',@9V5D965L=&5L:6IK
M(&=E=7!L;V%D+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D5E;B!F;W5T(&)I:B!H
M970@8F5K:6IK96X@=F%N(&1I="!B97)I8VAT;VYD97)D965L(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*
M;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R96X@=F%N(&1E(&%D
M<F5S9&%T82XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&EM<&]R=&5R
M96X@=F%N(&1E(&E#86QE;F1A<F1A=&$N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(D5E;B!F;W5T(&EN(&AE
M="!C;VYF:6=U<F%T:65F;W)M=6QI97(N($UI<W-C:&EE;B!B96YT('4@965N
M('9E<G!L:6-H="!V96QD("(*(G9E<F=E=&5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HB165N(&9O=70@8FEJ(&AE="!U:71V;V5R96X@=F%N
M(&1E(&]P9V5G979E;B!A9')E<V)O96MF=6YC=&EE+B!0<F]B965R(&QA=&5R
M("(*(F]P;FEE=7<L(&$N=2YB+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB165N(&9O=70@;65T(&AE
M="!B:6IW97)K96X@=F%N(&1E(&%D<F5S9&5T86EL<RX@4')O8F5E<B!L871E
M<B!O<&YI975W+"!A+G4N8BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB165N(&9O=70@;65T(&AE="!B
M:6IW97)K96X@=F%N(&1E(&1I<W1R:6)U=&EE;&EJ<W0N(%!R;V)E97(@;&%T
M97(@;W!N:65U=RP@82XB"B)U+F(N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$
M97IE($E-05`@<V5R=F5R(&]N9&5R<W1E=6YT(&=E96X@9&5L:6YG('9A;B!M
M87!P96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92XB"FUS9W-T<B`B1&ET(&QI:FMT(&YI970@965N(&=E
M;&1I9R!R87(@8F5S=&%N9"!T92!Z:6IN+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(D1I="!L
M:6IK="!N:65T(&5E;B!G96QD:6<@>FEP(&)E<W1A;F0@=&4@>FEJ;BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(W"FUS9VED(")4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T
M<B`B1&ET(&QI:FMT(&YI970@965N(&=E;&1I9R!K86%R=&YU;6UE<B!T92!Z
M:6IN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@HB1&ET('-T=75R<')O9W)A;6UA(&=E969T(&1E(&UO
M9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E($-L:6-K871E;&P@(@HB
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD96XL
M(&0N;2YV+B!D92!(5%10($%022(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@HB1&ET('-T=75R<')O9W)A;6UA(&=E969T(&1E(&UO9V5L
M:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E(%=)3B`H:'1T<#HO+R(*(G=I
M;G!L8RYC;VTI(&=A=&5W87D@=&4@=F5R>F5N9&5N+"!D+FTN=BX@9&4@2%14
M4"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O
M(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*(D1I="!S='5U<G!R;V=R86UM82!G965F="!D92!M;V=E
M;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!S;7,R96UA:6P@(@HB*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@9"YM
M+G8N(&1E($A45%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*(D1I="!S='5U<G!R;V=R86UM82!G965F="!D92!M;V=E;&EJ:VAE
M:60@;VT@8F5R:6-H=&5N('9I82!33510(&0N;2YV+B!D92`B"B)6;V1A9F]N
M92!)=&%L>2!G871E=V%Y('1E('9E<GIE;F1E;B!N86%R(%9O9&%F;VYE(&YU
M;6UE<G,N($AI97)V;V]R(&ES(&5E;B`B"B)6;V1A9F]N92!)=&%L>2!E+6UA
M:6QA9')E<R`H:'1T<#HO+W=W=RXQ.3`N:70I(&YO;V1Z86ME;&EJ:RXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0P."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,S<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@P-2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#$S"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G
M<W1R(")$:70@=F5L9"!I<R!V97)E:7-T(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R(")$:70@=F5L9"!M86<@86QL965N(&EN
M=&5G97)S(&)E=F%T=&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,38*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB
M97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D1I="!V96QD(&UA9R!A;&QE
M96X@9V5T86QL96X@96X@9&4@9'5B8F5L92!P=6YT(&)E=F%T=&5N+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D1I
M="!V96QD(&UA9R!A;&QE96X@;V-T86%L('=A87)D96X@8F5V871T96XN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F
M:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@
M;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB1&ET('9E;&0@9&EE;G0@965N(&MO
M;6UA(&]F('-P871I92!G97-C:&5I9&5N(&QI:G-T(&UE="!I;G1E9V5R<R!T
M92!Z:6IN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED
M(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@
M(D1E>F4@=V%A<F1E(&1I96YT(&5E;B!G96QD:6<@9V5T86P@=&4@>FEJ;BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$X"FUS9VED("(B"B)4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S
M='(@(B(*(D1I="!V96QD(&1I96YT(&5E;B!K;&5U<F-O9&4@:6X@4D="($A%
M6"UF;W)M86%T('1E(&)E=F%T=&5N+"!B+G8N("<C,3(S-&%F)RXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B1&ET(&9O<FUU
M;&EE<B!I<R!R965D<R!V97)W97)K="XB"@HC.B!T96UP;&%T97,O:&5L<"]A
M8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*
M;7-G<W1R(")$:70@:7,@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@
M(B(*(D1I="!I<R!E96X@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@3VT@9&ET
M(&]B:F5C="!W965R('1E(&=E=F5N(&AE969T('4@965N(&4M(@HB;6%I;"!C
M;&EE;G0@;F]D:6<@9&EE(&AE="!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A="!B
M96=R:6IP="X@5F]O<B!E96X@;&EJ<W0@(@HB;65T(&1E>F4@92UM86EL8VQI
M96YT<RP@8F5Z;V5K("5S+"!A+G4N8BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(D1I="!B97)I8VAT
M(&ES(&EN(&5E;B!A;F1E<F4@:V%R86MT97)S970@*"5S*2!G97-C:')E=F5N
M+"!D86X@=7<@96EG96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+B(*;7-G<W1R(")$:70@9V5T86P@9&EE;G0@=&5N;6EN<W1E(.GI;B!T
M92!Z:6IN+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP
M+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(D1E>F4@<V5R=F5R(&MA;B!G
M965N('II<"!E;B!G>FEP(&)E<W1A;F1E;B!U:71P86MK96XN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H
M:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B
M2&5T('-Y<W1E96T@:7,@;6]M96YT965L('5I=&=E<V-H86ME;&0N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B1&5Z92!W86%R9&4@
M9&EE;G0@965N(&=E=&%L('1E('II:FXN(@H*(SH@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")$:70@
M<V-H97)M(&1I96YT(&%A;F=E<F]E<&5N('1E('=O<F1E;B!V86YU:70@965N
M($]P=&EE<W-C:&5R;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(D]N=V5E<B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I8VME
M=',B"FUS9W-T<B`B5&EC:V5T<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T,C4@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M(")4:6UE(@IM<V=S='(@(E1I:F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(E1I:F1P
M;&%N;FEN9R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM
M92!F;W)M870B"FUS9W-T<B`B5&EJ9&9O<FUA870B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3,Q"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G
M<W1R(")4:6ID<V5L96-T:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P"FUS9VED(")4:6UO
M<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I=&5L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B
M5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")4:71E;"`H=&]O;'1I<"DZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B06%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU
M;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#
M;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B
M(@HB3VT@;65E<F1E<F4@;VYD97)D96QE;B!T92!S96QE8W1E<F5N+"!H;W5D
M(&1E($-O;G1R;VP@*%!#*2!O9B!#;VUM86YD("A-86,I("(*(G1O971S('9A
M<W0@=&EJ9&5N<R!K;&EK:V5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(E9A;F1A86<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS
M9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B2%1-3"!B<F]N(&]M
M<V-H86ME;&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,PIM<V=I9"`B5&]G;R(*;7-G<W1R
M(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-@IM<V=I9"`B5&]K96QA=2(*;7-G<W1R
M(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P
M,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B36]R9V5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R.0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@(E1O;R!M86YY(&EN
M=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(*;7-G<W1R
M(")492!V965L(&]N9V5L9&EG92!A86YM96QD:6YG96X@9V5D=7)E;F1E(&1E
M(&%F9V5L;W!E;B!M:6YU=&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I9"`B5&]P(@IM<V=S='(@
M(D)O=F5N:V%N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B
M0F]V96YS=&4@9G)A;64@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B5F5R=&%L:6YG
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,R"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O
M(@IM<V=S='(@(E1R:6YI9&%D(&5N(%1O8F%G;R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T
M<B`B5')U92!O9B!F86QS92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(D1I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R.`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YE<VGK(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1U<FMI:F4B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H
M25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R:W,@*$E33RTX.#4Y+3DI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-PIM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM
M96YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`*;7-G:60@(E1U<FMS(&%N9"!#86EC
M;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<R!E;B!#86EC;W,@96EL86YD96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,S"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y
M;W5R(&-H;VEC93H@(@IM<V=S='(@(E1Y<"!U=R!K975Z93H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E
M>#H@(@IM<V=S='(@(E4N5BX@:6YD97@Z("(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),
M(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S
M='(@(E523"!V;V]R('5W(&%F;&5V97)I;F=S<W1A='5S<F%P<&]R="!S8W)I
M<'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W
M"FUS9VED(")59V%N9&$B"FUS9W-T<B`B3V5G86YD82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S8*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B3V5K<F'O;F4B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!A
M8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!6
M1E,@9&ER96-T;W)Y(&%A;B!T92!S<')E:V5N+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T
M<B`B(@HB3FEE="!I;B!S=&%A="!E>'1R82!G96)R=6EK97)S:6YF;W)M871I
M92!T;V4@=&4@=F]E9V5N(&)I:B!I;G-C:')I:G9E;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!D92!R96-H=&5N('9A;B!61E,@
M8F5S=&%N9"!<(B5S7"(@=&4@=VEJ>FEG96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,SDR(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B3FEE="!I
M;B!S=&%A="!D92!R96-H=&5N('9A;B!61E,@8F5S=&%N9"`E<R\E<R!T92!W
M:6IZ:6=E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*
M;7-G<W1R(").:65T(&EN('-T86%T('1E('=I:GII9V5N(&YA87(@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(@IM<V=S='(@(DYI970@:6X@<W1A870@8F5S=&%N9'-G<F]O='1E('9A;B!<
M(B5S7"(@=&4@8V]N=')O;&5R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-CDU(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`R.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<R\E<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T(&)E<W1A;F1S9W)O;W1T
M92!V86X@7"(E<R\E<UPB('1E(&-O;G1R;VQE<F5N+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYI970@:6X@<W1A870@;65T
M(&1E(%-13"!S97)V97(@=&4@=F5R8FEN9&5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W
M:71H(%-33"XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!M970@4U-,('1E('9E
M<F)I;F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S(@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR,#0@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(P.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!K;W!IZW)E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@7"(E<UPB
M('1E(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,V
M,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!6
M1E,@9&ER96-T;W)Y('1E(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I
M;&4N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;6%K
M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@;6%P(%PB)7-<(B!T
M92!M86ME;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S(*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S
M='(@(DYI970@:6X@<W1A870@965N(&QE96<@5D93(&)E<W1A;F0@=&4@;6%K
M96XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP
M.C<Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(").
M:65T(&EN('-T86%T(&1A=&$@=6ET('1E('!A:VME;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@
M(DYI970@:6X@<W1A870@7"(E<UPB('1E('9E<G=I:F1E<F5N+"!D92!D:7)E
M8W1O<GD@:7,@;FEE="!L965G(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B3FEE="!I
M;B!S=&%A="!<(B5S7"(Z("5S('1E('9E<G=I:F1E<F5N+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S."!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S$Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDU
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3FEE="!I;B!S=&%A="`E<R!T92!V
M97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y(&ES(&YI970@;&5E9R(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(").:65T(&EN
M('-T86%T(%9&4R!D:7)E8W1O<GD@<F5C=7)S:65F('1E('9E<G=I:F1E<F5N
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T-"!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYI
M970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!V97)W:6ID97)E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R,"!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").:65T(&EN
M('-T86%T(%9&4R!D:7)E8W1O<GD@)7,@=&4@=F5R=VEJ9&5R96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@7"(E<UPB('1E('9E<G=I
M:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Q,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$X-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(Y,2!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A
M;F0@=&4@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!6
M1E,@;6%P(%PB)7-<(B!T92!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DYI
M970@:6X@<W1A870@5D93("5S(')E8W5R<VEE9B!T92!V97)W:6ID97)E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!H=6ED:6=E(&1I<F5C=&]R>2!T92!B97!A;&5N+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED
M(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S
M='(@(DYI970@:6X@<W1A870@8V5R=&EF:6-A871D971A:6QS('5I="!T92!F
M:6QT97)E;B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT,S<@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R(").:65T(&EN('-T86%T(&]M(&1E(&1E9FEN:71I92!V
M86X@)7,@=&4@;&%D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C`S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<T(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E
M('9E<G!L86%T<V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.3@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C$P-B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C8U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A
M;F0@7"(E<UPB('1E(&]P96YE;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!O<&5N96X@=F]O<B!S
M8VAR:6IV96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#,@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,W"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M=&4@;W!E;F5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!H970@:6YG97!A:W1E(&)E
M<W1A;F0@=&4@;W!E;F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I
M(&9A:6QE9"DN(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M=&4@;&5Z96X@*&9I;&5S:7IE*"D@;6ES;'5K="DN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@X-PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I
M;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3FEE="!I;B!S
M=&%A="!61E,@8F5S=&%N9"!T92!L97IE;B`H9V5T1FEL95-I>F4H*2!M:7-L
M=6MT*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z
M("(*;7-G<W1R(").:65T(&EN('-T86%T(&)E<W1A;F0@=&4@;&5Z96XZ("(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8W-@IM<V=I9"`B56YA
M8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(").
M:65T(&EN('-T86%T('9F<W)O;W0@9&ER96-T;W)Y('1E(&]P96YE;BXB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DYI970@:6X@<W1A
M870@;VT@)7,@=&4@:&5R;F]E;65N(&YA87(@)7,Z(&)E<W1E;6UI;F=S;6%P
M(&)E<W1A870@86PB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!H97)N
M;V5M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y
M("5S('1E(&AE<FYO96UE;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!<(B5S7"(@
M=&4@:&5R;F]E;65N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@)7,O)7,@=&4@
M:&5R;F]E;65N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M,3,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,R-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S
M='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@:&5R;F]E;65N+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S
M='(@(DMA;B`G;6MI<V]F<R<@;FEE="!U:71V;V5R96XN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA
M8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!D:70@5V]R9"!D;V-U;65N="!T92!V97)T86QE;B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@7"(E<UPB('1E('-C:')I:G9E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DYI
M970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@<V-H<FEJ=F5N("AC;W!Y*"D@
M9F%I;&5D*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#@@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T-@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!6
M1E,@8F5S=&%N9'-D871A('1E('-C:')I:G9E;BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(DYI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@=&4@<V-H<FEJ=F5N+"!Q=6]T82!W;W)D="!O
M=F5R<V-H<F5D96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(D]N9&5R
M<W1R97!E;B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@
M(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")(97)S=&5L('=I:GII9VEN9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM
M<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B1&]E="!U
M=R!L86%T<W1E(&)E=V5R:VEN9R!T96YI970B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")/
M;G9E<G=A8VAT(&%N='=O;W)D('9A;B!D92!S97)V97(@;W`@=F5R8FEN9&EN
M9SH@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS
M9W-T<B`B3VYV97)W86-H="!A;G1W;V]R9"!V86X@<V5R=F5R(&%A;CH@(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3VYB96YO96UD(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*
M;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-PIM<V=I9"`B
M56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B5F5R96YI9V1E($%R86)I
M<V-H92!%;6ER871E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.`IM<V=I9"`B56YI=&5D($MI
M;F=D;VTB"FUS9W-T<B`B5F5R96YI9V0@2V]N:6YG:W)I:FLB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0P"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(E9E<F5N:6=D
M92!3=&%T96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y"FUS9VED(")5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B5F5R96YI9V1E(%-T
M871E;BP@:VQE:6YE(&)U:71E;B!L:6=G96YD92!E:6QA;F1E;B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z-S@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8R"FUS9VED(")5;FET<R(*;7-G<W1R(")%96YH961E;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")/;F)E
M:V5N9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+B(*;7-G<W1R(")/;F)E:V5N9"!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+B(*;7-G<W1R(")/;F)E:V5N9"!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(D]N8F5K96YD92!L;V-A=&EE(&]P9V5G979E;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G
M:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(D]N
M8F5K96YD92!G96)R=6EK97)S;F%A;2!O9B!W86-H='=O;W)D+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B
M2&5T(&AU:61I9V4@96QE;65N="!L;W-K;W!P96QE;B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM
M<V=S='(@(D]N8F5N;V5M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E
M(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO
M=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L
M:7!B;V%R9"XB"FUS9W-T<B`B(@HB3FEE="!G97)E8VAT:6=D92!S8W)I<'1S
M(&MU;FYE;B!P<F]G<F%M;6%M871I9R!N:65T($MN:7!P96XO2V]P:>MR96XO
M(@HB4&QA:VME;BP@=F%N=V5G92!B979E:6QI9VEN9W-R961E;F5N+B!+;&EK
M(&]P($]+(&]M(&5E;B!T96-H;FES8VAE(&]P;65R:VEN9R`B"B)O<"!M;WII
M;&QA+F]R9R!T92!B96MI:FME;B!H;V4@=2!E96X@<V-R:7!T('1O97-T86%T
M(&AE="!P<FEK8F]R9"!T92`B"B)B96YA9&5R96XN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B
M56YS970@8V]L;W(B"FUS9W-T<B`B2VQE=7(@=&5R=6=S=&5L;&5N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N
M<VEO;B(*;7-G<W1R(").:65T(&]N9&5R<W1E=6YD92!E>'1E;G1I92(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B
M0FEJ=V5R:V5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B
M)7,@8FEJ=V5R:V5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B1V5B<G5I:V5R
M(&)I:G=E<FME;BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T
M<B`B7"(E<UPB(&)I:F=E=V5R:W0N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S
M='(@(E5P9W)A9&4@<V-R:7!T('9E<G=I:F1E<F0N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B57!L;V%D(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM
M<V=S='(@(D%L;&4@=&]E<&%S<VEN9R!S971U<&)E<W1A;F1E;B!N86%R(&1E
M('-E<G9E<B!G975P;&]A9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(DQA=&EJ;G-E(&AO;V9D;&5T=&5R<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B1W)O
M=&4@4F]M96EN<V4@9V5T86QL96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q"FUS9VED(")5
M<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B1V5B<G5I:R!H=6ED:6=E
M.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(D=E8G)U:6L@4U-,
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB
M"FUS9W-T<B`B1V5B<G5I:V5N('=A;FYE97(@;F%A;2]W86-H='=O;W)D('9E
M<G-C:&EL="!M970@24U34"!S97)V97(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")'96)R
M=6EK97(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B1V5B<G5I:V5R("5S(&ES(&YI970@
M9V5A=71O<FES965R9"!V;V]R("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P
M,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'96)R=6EK
M97)S8F5H965R(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR
M-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")'96)R=6EK97)S;W!T
M:65S(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I
M;VXB"FUS9W-T<B`B1V5B<G5I:V5R<W)E9VES=')A=&EE(@H*(SH@<VEG;G5P
M+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B1V5B<G5I:V5R<W)E9VES
M=')A=&EE(&ES('5I=&=E<V-H86ME;&0@;W`@9&5Z92!S:71E+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N
M;W0@9F]U;F0B"FUS9W-T<B`B1V5B<G5I:V5R<V%C8V]U;G0@;FEE="!G979O
M;F1E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*
M;7-G<W1R(")'96)R=6EK97)S;F%A;2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA
M;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")'96)R=6EK97)S
M;F%A;2!<(B5S7"(@8F5S=&%A="!A;"XB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")'96)R
M=6EK97)S;F%A;3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(D=E8G)U:6ME<G-N86%M.B`B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5
M<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")'96)R=6EK97)S(&EN(&AE
M="!S>7-T965M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(*;7-G:60@(E5Z8F5K:7-T86XB
M"FUS9W-T<B`B3V5Z8F5K:7-T86XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R"FUS
M9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")6
M1E,@9&ER96-T;W)Y(&)E<W1A870@;FEE="XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")!9G=E
M>FEG:&5I9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I
M9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")'
M979O;F1E;B!G96QD:6=E(&QO8V%T:65S(&)E=F%T=&5N.B`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I
M='DB"FUS9W-T<B`B1V5L9&EG:&5I9"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PIM<V=I9"`B5F%L=64@
M:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B5V%A<F1E(&EN(&UI;G5T
M96X@=F%N868@;G4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M(@IM<V=S='(@(E=A87)D92!L:6=T(&)O=F5N(&1E(&UA>&EM=6T@;&5N9W1E
M('9A;B`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$P"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G
M:60@(E9A;'5E<R(*;7-G<W1R(")786%R9&5N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V
M"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5V%A<F1E
M;B!W86%R=6ET(&=E<V5L96-T965R9"!K86X@=V]R9&5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T.0IM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B
M"FUS9W-T<B`B5F%R:6%B96QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-0IM<V=I9"`B5F5N
M97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I
M;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET
M:"XB"FUS9W-T<B`B5F5R:69I8V%T:64@;6ES;'5K="`M(&5R(&MA;B!M970@
M9&ET(&)E<FEC:'0@9V5K;F]E:60@>FEJ;BXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R
M(")697)S:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS
M9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEE8V]N=')O;&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")697)T:6MA
M86P@=6ET;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R
M(")697)T:6MA;&4@=G)I:F4@<G5I;71E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM
M<V=S='(@(E9E<G1I:V%A;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(D5R
M9R!H;V]G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.`IM<V=I9"`B5FEE="!.86TB"FUS9W-T
M<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED
M(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(E9I971N86UE97,@*%9)
M4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(E<R!B
M96MI:FME;B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I
M97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B0F5K:6IK(&5E;B!E
M>'1E<FYE('=E8G!A9VEN82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S
M(@IM<V=S='(@(D)E:VEJ:V5N(&%L<R`E<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(DUA86=D96X@
M96EL86YD96XL($)R:71S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DUA86=D96X@96EL86YD96XL(%8N
M4RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I
M;&ET>2(*;7-G<W1R(")::6-H="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")::6-H
M=#H@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM
M<V=S='(@(E9O9&%F;VYE($ET86QY('9I82!33510(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")705).(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@
M(E=!05)30TA55TE.1R$A(2`@5D525TE*1$52(%-#4DE05"!(04Y$34%424<@
M54E4("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.('9I82!(
M5%10(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,`IM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B
M"FUS9W-T<B`B5V%L;&ES(&5N($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HY-0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R
M(")786%R<V-H=7=I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")7;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&
M;W)E8V%S="(*;7-G<W1R(")7965R<W9O;W)U:71Z:6-H="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T
M82!P<F]V:61E9"!B>2(*;7-G<W1R(")7965R8F5R:6-H="!G96=E=F5N<R!G
M96QE=F5R9"!D;V]R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR
M"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B
M5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B
M5V5B(%-I=&4B"FUS9W-T<B`B5V5B<VET92(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G
M<W1R(")796ME;&EJ:W,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")796QK;VTB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R(")796QK;VT@8FEJ("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E=E;&MO;2P@
M)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B5V5S=&5R<R`H25-/+3@X-3DM,2DB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,34I(@IM<V=S='(@(E=E<W1E<G,@*$E33RTX.#4Y+3$U*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<X"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R(")7
M97-T96QI:FME(%-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B5V5L:V4@=&]E
M<&%S<VEN9R!D:65N="`E<R!W965R('1E(&=E=F5N(&YA(&%A;FUE;&1I;F<_
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(E=A="!I
M<R!H970@<V-H96ED:6YG<VMA<F%K=&5R/R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R
M86-T97(_(@IM<V=S='(@(E=A="!I<R!H970@8VET86%T:V%R86MT97(_(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*
M;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES
M($%U<W1R86QIZR!K86%R="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM
M<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(E=E;&ME(&9A<V5N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN
M<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R
M(")796QK92!P;'5G:6YS('9O;W(@9&4@4FEC:"!497AT(&5D:71O<B!I;G-C
M:&%K96QE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R(")"<F5E9'1E
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-PIM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(D)R965D=&4@:6X@0U-3(&5E;FAE
M9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@HB0G)E
M961T92!V86X@:&5T("5S(&UE;G4@86%N(&1E(&QI;FME<FMA;G0@*&%K=&EE
M9B!B:6H@=F]L9V5N9&4@86%N;65L9&EN9RDZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F
M('1H92!T86)L92(*;7-G<W1R(")"<F5E9'1E('9A;B!D92!T86)E;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS
M9VED(")7:61T:"!U;FET(@IM<V=S='(@(D)R965D=&4@965N:&5I9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS
M9VED(")7:61T:#HB"FUS9W-T<B`B0G)E961T93HB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")7:6YD(@IM
M<V=S='(@(E=I;F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")7:6YD('9R
M;V5G(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S
M<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")7:6YD<VYE;&AE:60@:6X@:VYO<&5N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(E=I;F0Z(@IM
M<V=S='(@(E=I;F0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E=I;F0Z("(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E=I
M:G-H96ED(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I
M9"`B5VES:&QI<W0B"FUS9W-T<B`B5V5N<VQI:G-T(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(E=E<FLB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G
M:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")797)K861R97,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7
M;W)K(%!H;VYE(@IM<V=S='(@(E1E;"YN<BX@*'=E<FLI(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB
M"FUS9W-T<B`B5F5R:V5E<F0@86%N=&%L('9E;&1E;B!I;B!R96=E;"`E9"X@
M5F5R=V%C:'0@)60L(&=E=F]N9&5N("5D+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S
M='(@(E9E<FME97)D(&%A;G1A;"!V96QD96XN(%9E<G=A8VAT("5D+"!G979O
M;F1E;B`E9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5F5R:V5E<F1E(&]F9G-E="`E
M9"!B:6H@;&5Z96X@=F%N(%9&4R!B97-T86YD+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G
M:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@
M8F%S:7-B97!E<FMI;F=E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E
M(@IM<V=S='(@(E@U,#EV,R!U:71G96)R96ED('-L975T96QG96)R=6EK(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P
M.78S(&%L=&5R;F%T:65V92!O;F1E<G=E<G!N86%M(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U,#EV,R!O;F1E<G=E<G`@
M<VQE=71E;&ED96YT:69I8V%T;W(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS
M9W-T<B`B6#4P.78S(&5X=&5N=&EE<R(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C4P"FUS9VED(")962(*;7-G<W1R(")*2B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B65E962(*;7-G<W1R
M(")*2DI*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B66%H;V\A(&UA
M<"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")*86%R;&EJ:W,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4R"FUS9VED(")996UE;B(*;7-G<W1R(")*96UE;B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE
M<R(*;7-G<W1R(")*82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B
M2F$L(&EK(&%C8V5P=&5E<B!D92!V;V]R=V%A<F1E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)5(&)E;G0@:6X@5$5+
M4U0@34]$12X@1V5B<G5I:R!D92!;/#Y=(&MN;W`@;VT@;F%A<B!765-)5UE'
M('1E<G5G('1E("(*(G-C:&%K96QE;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@8FQO8VMS+B(*;7-G<W1R(")(970@:7,@=2!N:65T('1O96=E<W1A86X@
M;VT@;65E<B!D86X@)60@8FQO:VME;B!T92!M86ME;BXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C0*;7-G:60@(EEO=2!A<F4@;F]T(&%U
M=&AE;G1I8V%T960N(@IM<V=S='(@(E4@8F5N="!N:65T(&=E875T:&5N=&EF
M:6-E97)D+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(")5(&MU;G0@9V5E;B`G7%PG
M(&MA<F%K=&5R(&EN('5W('9O;&QE9V4@;F%A;2!H96)B96XN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N(@IM<V=S='(@(E4@:&5E9G0@9V5E;B!G96QD:6<@92UM
M86EL861R97,@;W!G96=E=F5N+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA
M<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O
M<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B)5(&AE
M969T(&=E96X@=F5L9&5N('5I="!H970@9V5I;7!O<G1E97)D92!B97-T86YD
M(&=E:V]P<&5L9"!M970@9&4@(@HB;W9E<F5E;FMO;7-T:6=E('9E;&1E;B!I
M;B`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#<*;7-G:60@
M(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B52!B96YT(&%F
M9V5M96QD+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G
M:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B
M"B)5(&1I96YT(&5E;B!G96QD:6<@;6]B:65L(&YU;6UE<B!I;B!T92!V;V5R
M96XL(&%L;&5E;B!C:6IF97)S(&UE="!E96X@(@HB;W!T:6]N96QE("<K)R!V
M;V]R(&AE="!I;G1E<FYA=&EO;F%L92!K:65S=F]O<G9O96=S96PN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B52!D:65N="!E96X@
M9V5L9&EG92!W86%R9&4@;W`@=&4@9V5V96XN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R
M("(B"B)5(&1I96YT(&5E;B!$871A5')E92!B86-K96YD('1E(&-O;F9I9W5R
M97)E;B!O;2!I;G-C:')I:G9I;F=E;B!T92!K=6YN96X@(@HB9V5B<G5I:V5N
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#<Q"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B52!D
M:65N="!E96X@5D93(&)A8VME;F0@=&4@8V]N9FEG=7)E<F5N+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@HB52!D:65N="!H970@<')O
M8FQE96T@=&4@8F5S8VAR:6IV96XL('9O;W)D870@=2!H970@<')O8FQE96UR
M87!P;W)T(&MU;G0@(@HB=F5R>F5N9&5N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R
M(")5(&1I96YT(&5E;B!54DP@:6X@=&4@=F]E<F5N('=A87)N86%R(&1E>F4@
M;&EN:R!V97)W:6IS="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(E4@9&EE;G0@965N('-E<G9E<B!T92!S96QE8W1E
M<F5N(&]M('1E('9E<G=I:F1E<F5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q
M.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R
M(&]U="XB"FUS9W-T<B`B52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@
M=&4@9V5V96X@;VT@=&4@=VES<V5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92XB"FUS9W-T<B`B52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@
M9V5V96X@;VT@=&4@=F5R=VEJ9&5R96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@
M(E4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M('1O
M92!T92!V;V5G96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S
M='(@(E4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M
M(&)I:B!T92!K=6YN96X@=V5R:V5N+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")5(&1I96YT(&5E
M;B!B97=E<FMI;F<@;W`@=&4@9V5V96X@=V5L:V4@=6ET9V5V;V5R9"!M;V5T
M('=O<F1E;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E
M9V]R>2!N86UE+B(*;7-G<W1R(")5(&1I96YT(&5E;B!N:65U=V4@8V%T96=O
M<FEE;F%A;2!O<"!T92!G979E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")5
M(&1I96YT(&5E;B!)=&%L:6%A;G,@=&5L969O;VYN=6UM97(@;W`@=&4@9V5V
M96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(E5W("5S('-E<W-I92!I<R!V97)L
M;W!E;BX@3W!N:65U=R!A86YM96QD96XL(&$N=2YB+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D
M9')E<W,B"FUS9W-T<B`B57<@92UM86EL861R97,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM
M<V=S='(@(E5W(%9A;CH@861R97,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED
M(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E5W(&EN9F]R;6%T:64B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(B"B)5=R!I;G1E<FYE=&%D<F5S(&ES(&=E=VEJ>FEG9"!S:6YD
M<R!H970@8F5G:6X@=F%N('5W("5S('-E<W-I92X@3VT@=7<@(@HB=F5I;&EG
M:&5I9"!T92!B97-C:&5R;65N+"!D:65N="!U('II8V@@;W!N:65U=R!A86X@
M=&4@;65L9&5N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B57<@;F%A;3HB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M
M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E
M;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB2&5T
M('1O979O96=E;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R<W1E
M=6YD(&1O;W(@=7<@875T:&5N=&EC871I92`B"B)B86-K96YD+B!786YN965R
M('4@2&]R9&4@9V5B<G5I:V5R<R!W:6QT(&)E:&5R96XL(&1I96YT('4@965N
M(&%N9&5R("(*(F%U=&AE;G1I8V%T:64@8F%C:V5N9"!T92!G96)R=6EK96XN
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*
M(DAE="!W965R9V5V96X@=F%N(&5E;B!G96)R=6EK97)S;&EJ<W0@=V]R9'0@
M;FEE="!O;F1E<G-T975N9"!D;V]R('5W("(*(F%U=&AE;G1I8V%T:64@8F%C
M:V5N9"P@;V8@9&5Z92!O<'1I92!I<R!O;2!A;F1E<F4@<F5D96YE;B!U:71G
M97-C:&%K96QD+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E5W(&)R;W=S97(@;&EJ:W0@
M=&4@>FEJ;B!G97=I:GII9V0@<VEN9',@:&5T(&)E9VEN('9A;B!U=R`E<R!S
M97-S:64N($]M('5W("(*(G9E:6QI9VAE:60@=&4@8F5S8VAE<FUE;BP@9&EE
M;G0@=2!Z:6-H(&]P;FEE=7<@86%N('1E(&UE;&1E;BXB"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HU-PIM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")5=R!B<F]W<V5R(&]N
M9&5R<W1E=6YT(&1E>F4@;6]G96QI:FMH96ED(&YI970N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S
M<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B
M"B)5=R!B<F]W<V5R(&]N9&5R<W1E=6YT(&1E>F4@<')I;G1O<'1I92!N:65T
M+B!$<G5K(&]P($-O;G1R;VPO0V]M;6%N9"`K(%`@;VT@(@HB868@=&4@9')U
M:VME;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9
M;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")5=R!H=6ED:6=E('1I
M:F1Z;VYE.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M(")5=R!S=&%N9&%A<F0@:61E;G1I=&5I="!I<R!G97=I:GII9V0N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D969A=6QT
M(&ED96YT:71Y.B(*;7-G<W1R(")5=R!S=&%N9&%A<F0@:61E;G1I=&5I=#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U
M;&P@;F%M93HB"FUS9W-T<B`B57<@=F]L;&5D:6=E(&YA86TZ(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")5=R!A86YM96QD:6YG(&ES('9E<FQO<&5N
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B
M"FUS9W-T<B`B57<@;FEE=7=E('=A8VAT=V]O<F0@=F]O<B`E<R!I<SH@)7,B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I
M;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")5=R!O<'1I97,@>FEJ;B!B
M:6IG97=E<FMT('9O;W(@9&4@9'5U<B!V86X@9&5Z92!S97-S:64N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B57<@;W!T:65S
M('II:FX@8FEJ9V5W97)K="XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*
M;7-G<W1R(")5=R!W86-H='=O;W)D(&ES(&=E<F5S970B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(E5W('=A
M8VAT=V]O<F0@:7,@=F5R;FEE=7=D+"!C;VYT<F]L965R('5W(&4M;6%I;"!E
M;B!M96QD(&%A;B!M970@=7<@;FEE=7=E("(*(G=A8VAT=V]O<F0N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W
M;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")5=R!W86-H='=O;W)D(&ES('9E
M<FQO<&5N+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM
M<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B57<@<V5R=F5R
M<R!O<"!A9G-T86YD.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30*;7-G:60@(EEU
M9V]S;&%V:6$B"FUS9W-T<B`B2F]E9V]S;&%V:>LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):
M8>]R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-38*;7-G:60@(EIA;6)I82(*;7-G<W1R("):
M86UB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4W"FUS9VED(")::6UB86)W92(*;7-G<W1R
M(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I
M9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED
M92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6U9E<F)E<F<@86%N9V5H86%L9&4@
M=&5K<W1=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0
M<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U!R;V)L965M<F%P<&]R=%TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");06%N9V5H86%L9&4@
M=&5K<W0@=V5E<F=E=F5N("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*
M;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@
M(EM!86YG96AA86QD92!T96MS="`M("5S(')E9V5L<UTB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C(P-`HC+"!P:'`M9F]R;6%T"FUS9VED(");
M;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)E9V5L("5S('9A;B`E<UTB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-30@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D)?96AE97(B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB
M"FUS9W-T<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A
M=&%4<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B5F5R7W=I:F1E<B!R:6HB"@HC.B!L:6(O87!I
M+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R;V5P96XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?
M2&5L<"(*;7-G<W1R(")?2&5L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B7T%F8F5E;&1I;F=S96EG96YS8VAA<'!E
M;BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*
M;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7T%A;FUE;&1E;B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T
M(@IM<V=S='(@(E]!9FUE;&1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(E]7:6IZ:6<@;&EN:RXN+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM
M<V=S='(@(E]/<'1I97,B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]0
M97)M:7-S:6]N<R(*;7-G<W1R(")?4F5C:'1E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B
M7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]697)W:6ID97(@;&EN:RXN+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E])
M;G-T96QL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(E]486)E;&5I9V5N<V-H87!P96XN+BXB"@HC.B!L:6(O87!I
M+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")'95]B<G5I:V5R<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B061R97-B;V5K(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN
M;W=N(@IM<V=S='(@(D=E861R97-S965R9&4@;VYB96ME;F0B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-PIM<V=I9"`B8V%L96YD87(B"FUS
M9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W.2!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V-0IM<V=I9"`B8V%L;2(*;7-G<W1R(")+
M86QM(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*
M;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B2V%N
M(&]U='!U=&)E<W1A;F0@;FEE="!M86ME;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U
M="(*;7-G<W1R(")+86X@:6YP=70@;FEE="!O<&5N96XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE
M<F4B"FUS9W-T<B`B2VQI:R!H:65R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E
M<G)O<B(*;7-G<W1R(")#;VUM86YD;W)E9V5L(&=E8G)U:6MS9F]U="(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C
M;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(D-O;F9I9W5R871I969O=70B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I
M9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")+<FET
M:7-C:"!S>7-T965M8F5S=&%N9"!O;G1B<F5E:W0B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@
M97)R;W(B"FUS9W-T<B`B1&%T869O<FUA871F;W5T(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R(")B97=E
M<FME;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R
M"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B:6YV;V5R(&YI970@
M9V5V;VYD96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")D86QE;F0B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3@*;7-G:60@(F9I;&4B
M"FUS9W-T<B`B8F5S=&%N9"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z
M,SDS"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@
M)7,@)7,B"FUS9W-T<B`B=F%N(&1E("5S("@E<RD@;W`@)7,@)7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG
M(@IM<V=S='(@(G9L86=E<FEG(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS
M9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G
M<W1R(")H;W-T;F%A;2!O;F)E:V5N9"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B:6UM961I
M871E(@IM<V=S='(@(F]N;6ED9&5L:6IK(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN
M92(*;7-G<W1R(")I;FQI;F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S
M='(@(FEN<'5T+V]U='!U="!F;W5T(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R
M<F]R(@IM<V=S='(@(FEN=&5R;F4@<V]F='=A<F5F;W5T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S
M72(*;7-G<W1R(")R96=E;'-=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*
M;7-G<W1R(")M:VES;V9S(&9O=71C;V1E("5D(&)I:B!H970@86%N;6%K96X@
M=F%N($E33RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T
M,0IM<V=I9"`B;F%M92(*;7-G<W1R(")N86%M(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@
M(FYI970@=F%N('1O97!A<W-I;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B
M"FUS9W-T<B`B3F]G(&YI970@=F%N('1O97!A<W-I;F<B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDP.0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R
M(")N;W1I=&EE8F]E:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B
M<')O8V5N="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")296-H="!G
M97=E:6=E<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B<&EX96QS
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G
M:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")296UO=&4@
M9F]U="!I;B!P<F]T;V-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B<W1I:F=E
M;F0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM
M<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")397)V:6-E(&YI
M970@8F5S8VAI:V)A87(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P
M,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")T;V]N('9E<G-C
M:&EL;&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R
M(")S;7,R96UA:6P@=FEA($A45%`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R(")S<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS
M9VED(")S=&5A9'DB"FUS9W-T<B`B<W1A8FEE;"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B
M"FUS9W-T<B`B<WES=&5E;69O=70B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(G1A:V5N;&EJ
M<W0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B=&EJ9&5L:6IK92!M
M:7-L=6MK:6YG(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")6;V5R+"!T97(@8F5V97-T
M:6=I;F<L(&AE="!W86-H='=O;W)D('1W964@;6%A;"!I;B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I960B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@
M(F]N8F5N;V5M9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T
M<B`B1V5B<G5I:V5R<V5L96-T:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#
M87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B
M=V5A=&AE<BYC;VTB"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&\O;FY?3D\N<&\`````````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8R-#,S-P`Q,#0Q-S,V
M,S`P,P`P,38T,3(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!(;W)D92!.;W)W96=I86X@3GEN;W)S:R!T<F%N<VQA=&EO
M;@HC($-O<'ER:6=H="`H0RD@,C`P,B!097(M4W1I86X@5F%T;F4*(R!4:&ES
M(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A
M<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!097(M4W1I86X@5F%T;F4@/'!S=D!O
M<G-T82YO<F<^+"`R,#`R+@HC(`IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#(M,#8M,#@@,C(Z,S`K,#$P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^7&XB"B),86YG
M=6%G92U496%M.B!.;W)W96=I86X@3GEN;W)S:R`\;GEN;W)S:T!O<G-T82YO
M<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G
M;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM
M<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(&5R(&EK
M:VIE(&MO;F9I9W5R97)T(&D@<F5G:7-T97)E="!T:6P@2&]R9&4N(@H*(SH@
M9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E
M;2XB"FUS9W-T<B`B)R5S)R!V87)T(&QA9W0@=&EL(&=R=7!P97-Y<W1E;65T
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,G('9A<G0@;&%G="!T:6P@
M=&EL9V%N9W-S>7-T96UE="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@
M(B<E<R<@=F%R="!I:VMJ92!O<'!R971T83H@)7,B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@
M<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD
M87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM
M<V=S='(@(B5S("T@3F]T:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P
M<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M(@IM<V=S='(@(B5S('9E9&QI:V5H86QD<V]P97)A<VIO;F%R("T@4W1A9&9E
M<W1I;F<B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B
M)7,@5FEL:^5R(&9O<B!A=G1A;&4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P
M97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L
M;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(DMR>7-S
M(&%V(&9O<B!O<&5R87-J;VXH87(I(&1U('9I;"!K^'ER92!N;RXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M
M:6YU=&5S(@IM<V=S='(@(DMV87)T(#4N(&UI;G5T="(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R(");;&EN:F4@)7,@878@
M)7-=(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S
M='(@(D%D<F5S<V5B;VLB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO
M=&5P860B"FUS9W-T<B`B)7,@+2!.;W1I<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S
M:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@
M:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L
M:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N
M>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#D*;7-G
M:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S
M='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B1&EN
M(&EN9F]R;6%S:F]N(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*
M;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('1I;6%R(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P"B,L
M(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G
M<W1R("(\8CY$970@<VMJ961D92!E:6X@:V%T87-T<F]F86P@9F5I;#H\+V(^
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G
M:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B
M04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!
M8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I
M9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS
M9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS
M9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D1I;B!I;F9O<FUA
M<VIO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM
M<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")3=&%D9F5S="!P87-S
M;W)D(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N
M=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*
M;7-G<W1R("),96=G('1I;"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(U"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@
M1W)O=7`B"FUS9W-T<B`B3&5G9R!T:6P@=6YD97)O<F1N82!O8FIE:W0B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL
M9"!097)M:7-S:6]N(@IM<V=S='(@(DQE9V<@=&EL('5N9&5R;W)D;F$@;V)J
M96MT=&EL9V%N9R!T:6P@)R5S)R(*"B,Z('1E;7!L871E<R]P;W)T86PO861D
M+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B3&5G
M9R!T:6P@8G)U:V%R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO
M9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"B,L(&9U>GIY"FUS9VED(")!9&0@
M3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B5&EL9V%N9R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G
M<W1R("),96=G('1I;"!U;F1E<F]R9&YA(&]B:F5K=&=R=7!P92!T:6P@)R5S
M)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O(%PB)7-<(B(*;7-G<W1R("),96=G('1I;"!U;F1E<F]R9&YA(&]B:F5K
M='1I;&=A;F<@=&EL("<E<R<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I
M9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(DQE9V<@=&EL(&YY(&)R=6MA
M<CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D%D
M9"!N97<@;65M8F5R<R(*;7-G<W1R("),96=G('1I;"!N>71T(&UE9&QE;2(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P
M86ER(@IM<V=S='(@(DQE9V<@=&EL('!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM
M<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B061R97-S96)O
M:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G
M<W1R(")!9')E<W-E8F]K(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@
M(D%D9"!U<V5R(@IM<V=S='(@(DQE9V<@=&EL(&)R=6MA<B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G
M:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&5G9R!T
M:6P@8G)U:V%R87(@97(@<VSE='0@878N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R97-S92(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@
M0F]O:R(*;7-G<W1R(")!9')E<W-E8F]K(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(D%D;6EN
M:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S
M='(@(D5N9')E('1I;&=A;F<@9F]R("<E<R<B"@HC.B!A9&UI;B]I;F1E>"YP
M:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R97)I;F<B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!
M9',B"FUS9W-T<B`B3&5G9R!T:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H
M86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED
M(")!;&)A;FEA(@IM<V=S='(@(D%L:6%S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ
M>0IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&EA<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S
M(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT
M:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`B1W)U<'!E<B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E
M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(E1I;&=A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED
M(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@
M24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F
M=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B
M1&D@92UP;W-T861R97-S93HB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N(@IM<V=S='(@(D5I;B!U;&]V;&5G('9E<F1I('9A<G0@
M<W!E<VEF:7-E<G0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C
M=7)E9"XB"FUS9W-T<B`B/&(^1&5T('-K:F5D9&4@96EN(&MA=&%S=')O9F%L
M(&9E:6PZ/"]B/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*(RP@9G5Z>GD*;7-G:60@(D%N9&]R
M<F$B"FUS9W-T<B`B1FYO<G)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H
M<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T
M:6]N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM
M<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D
M>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B
M07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R
M8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS
M9W-T<B`B17(@9'4@<VEK:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@)R5S)S\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R
M(")%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('-L971T92`G)7,G/R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!
M<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I
M9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B4W#X<B!O;2!S
M=&%D9F5S=&EN9R!F^'(@:_AY<FEN9R!A=B!V961L:6ME:&%L9'-O<&5R87-J
M;VYA<C\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED
M(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N(@IM<V=S='(@(E!R^'9D92#E('-L971T92!E:2!I:VMJ
M92UE:W-I<W1E<F%N9&4@9W)U<'!E+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!R^'9D92#E('-L971T92!E:6X@
M:6MK:F4M96MS:7-T97)A;F1E('1I;&=A;F<N(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0<OAV9&4@Y2!E;F1R92!E:6X@
M:6MK:F4M96MS:7-T97)A;F1E('1I;&=A;F<N(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E!R^'9D92#E(&5N
M9')E(&5I;B!I:VMJ92UE:W-I<W1E<F%N9&4@=&EL9V%N9RXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@HC+"!F=7IZ>0IM<V=I9"`B075G=7-T(@IM<V=S='(@(DQU<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B
M075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A
M<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q
M"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@
M(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V
M"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z
M,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B5&EL
M9VIE;F=E;&5G92!F96QT.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ
M86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS
M9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C
M:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*
M;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME
M<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G
M:60@(D)A:')A:6XB"FUS9W-T<B`B0F%R8FEE(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED
M(")":7)T:&1A>2(*;7-G<W1R(")"=7)S9&%G(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(D9A;FX@:6MK:F4@=F%R<V5L;'ET=&%R
M("5S+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I
M9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M;VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U
M>GIY"FUS9VED(")";W)D97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D
M97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED
M(")";W)D97)S(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0G)U
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC
M+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D4M<&]S="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L
M86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T
M<B`B0U93(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM
M<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T-@HC+"!F=7IZ>0IM<V=I9"`B0V%L;2(*;7-G<W1R(")!=F)R>70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@
M<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O
M(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N
M(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@:V]P
M;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ>0IM
M<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B079B<GET(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R(")!=F)R>70@<')O8FQE;7)A<'!O<G0B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU
M,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV
M,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC
M+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")!;'1E<FYA=&EV(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T
M"B,L(&9U>GIY"FUS9VED(")#87)R:65R(@IM<V=S='(@(D)A<F)I92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A
M;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM
M86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S
M='(@(DUO8FEL=&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@
M4')O<&5R=&EE<R(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L
M;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ
M>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL=&5L969O;B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX
M.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS
M9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I
M9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A
M=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B0VAA9"(*
M;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(RP@9G5Z>GD*
M;7-G:60@(D-H86YG92(*;7-G<W1R(")!;F=R92!E;F1R:6YG87(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E-T861F97-T('!A<W-O
M<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G
M:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E
M9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ
M>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B
M0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ
M>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B
M0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B4W1A9&9E<W0@<&%S<V]R9"(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@
M(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(D9A;FX@
M:6MK:F4@=F%R<V5L;'ET=&%R("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*
M;7-G<W1R(")+86QE;F1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B
M0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T
M('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE
M87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")+
M;&EK:R!F;W(@Y2!H86QD92!F<F%M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO
M<V4@5VEN9&]W(@IM<V=S='(@(DQU:VL@=FEN9&%U9V5T(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I
M9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X
M"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I
M9"`B0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T
M:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H
M96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")&
M:7)M82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N
M9"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO
M;B!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW
M"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H
M(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R
M92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E-T
M861F97-T('!A<W-O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T
M:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y
M,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R(")/<'!K;W!L:6YG(&UO="!O9F9E;G1L96<@;OAK
M:V5L=&5N87(@;F5K=&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*2(*;7-G<W1R(")/<'!K;W!L:6YG(&UO="!O9F9E;G1L96<@;OAK
M:V5L=&5N87(@;F5K=&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS
M9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S
M='(@(DEN;FAA;&0@:2`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"B,L(&9U
M>GIY"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")+;&EK:R!F;W(@Y2!H86QD
M92!F<F%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O
M:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*
M;7-G<W1R(")&:7)M82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B26UP;W)T97)T92!F96QT.B`E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO
M="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VMJ92!0
M1U`M:V]D92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!01U`M<VEG;F5R92!M96QD:6YG+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB
M"FUS9W-T<B`B2W5N;F4@:6MK:F4@4$=0+6MO9&4@;65L9&EN9RXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PHC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(DMU;FYE(&EK:VIE(%!'4"US:6=N97)E(&UE;&1I;F<N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@9&5K;V1E(%!'4"UD871A+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:VIE
M(&MO<&QE('1I;"!,1$%0+71E;F%R96XN(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M;&1A<"!S97)V97(B"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VMA9F9E(&]F9F5N
M=&QE9R!N^&MK96P@9G+E(&[X:VME;'1E;F%R96XN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*
M;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG
M($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(DMU
M;FYE(&EK:VIE(&1E:V]D92!01U`M9&%T82XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DMU;FYE(&EK:VIE
M(&1E:V]D92!01U`M9&%T82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+
M=6YN92!I:VMJ92!D96MO9&4@4$=0+61A=&$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DMU;FYE
M(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E+7!O<W1A9')E<W-E+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C@S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M861D<F5S<R!B;V]K+B(*;7-G<W1R(")+=6YN92!I:VMJ92!A=F=J97)E(&UO
M='1A:V%R96X@<VD@92UP;W-T861R97-S92XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N
M<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y
M(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VMA
M9F9E(&]F9F5N=&QE9R!N^&MK96P@9G+E(&[X:VME;'1E;F%R96XN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(DMU;FYE(&EK:VIE(%!'4"UK;V1E(&UE;&1I;F<N(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@;W!N92!-
M86EN=&5N86YC95]487-K+6UO9'5L96X@)7,B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:VIE(&]P
M;F4@36%I;G1E;F%N8V5?5&%S:RUM;V1U;&5N("5S(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@
M3$1!4"UT96YA<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP
M:'`Z,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5A9"`E<RXB"FUS9W-T<B`B)R5S)R!V87)T(&EK:VIE(&]P<')E='1A.B`E
M<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B
M"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S
M=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@879G:F5R92!M;W1T
M86MA<F5N('-I(&4M<&]S=&%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(DAO<F1E(&5R(&EK:VIE(&]R9&5N=&QE9R!K;VYF:6=U<F5R="(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I;"!,
M1$%0+71E;F%R96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB
M"FUS9W-T<B`B2W5N;F4@:6MK:F4@4$=0+7-I9VYE<F4@;65L9&EN9RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!C;VYT86-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VMJ92!D96MO9&4@4$=0
M+61A=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@
M(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B
M0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G
M:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S
M=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(T,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871O<B!097)M:7-S
M:6]N<R(*;7-G<W1R(")4:6QG86YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B0W5R<F5N="!3
M97-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L
M:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B0W5R<F5N="!5
M<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS
M9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I
M;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U
M"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS
M9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS
M9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E
M;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1A9VQE9R(*"B,Z(&%D;6EN+V1A
M=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$
M871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,SDY"B,L(&9U>GIY"FUS9VED(")$871E(@IM<V=S='(@(D]P<&1A
M=&5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*
M;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED
M(")$87DB"FUS9W-T<B`B1&%G;&5G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED
M(")$95]L971E($-O;'5M;B(*;7-G<W1R(")3;&5T=&4B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@HC+"!F=7IZ>0IM<V=I
M9"`B1&5C96UB97(B"FUS9W-T<B`B365D;&5M;6%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5F875L="(*;7-G<W1R(")3;&5T=&4B"@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F
M875L="!#;VQO<B(*;7-G<W1R(")"<G5K('-T86YD87)D=F5R9&DB"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A
M=6QT($ED96YT:71Y(@IM<V=S='(@(E-T86YD87)D:61E;G1I=&5T(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT(%-H96QL(@IM<V=S='(@(E-T86YD87)D:61E;G1I=&5T(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4VQE='1E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")3;&5T=&4B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PHC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E-L971T92(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")3;&5T=&4B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4&5R;6ES<VEO
M;B(*;7-G<W1R(")4:6QG86YG(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(&-E;&PB"FUS9W-T<B`B4VQE='1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E(&-O;'5M;B(*;7-G<W1R(")3;&5T=&4B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B16YD<F4@=&EL
M9V%N9R!F;W(@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@
M(E-L971T92(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI
M;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R(")3=&%N9&%R9&ED96YT:71E="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B
M1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y
M('1I;64B"FUS9W-T<B`B4VQE='1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N
M;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B
M4VMI;&1R92!P<F]B;&5M970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1G5L;"!S:VEL9')I;F<Z(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%L:F%R(&5R(&QO9V=A(&9O<B!A
M9&UI;FES=')A=&]R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT
M(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y
M"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@
M(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS
M9W-T<B`B5FES:6YG<V%L=&5R;F%T:78B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL
M960@9F]R96-A<W0B"FUS9W-T<B`B5FES:6YG<V%L=&5R;F%T:78B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T
M("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@
M(E9I<VEN9W-A;'1E<FYA=&EV(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"B,L(&9U
M>GIY"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(E-L971T92(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B26MK:F4@
M8G)U:R!M86EN=&5N86YC92YP:'`@9&ER96MT92XB"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@
M:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL
M;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED
M(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R
M:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(D1R=6=S(@IM
M<V=S='(@(DQU<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S='(@(D4M<&]S="(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR
M"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R
M:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*
M;7-G:60@(D5D:70B"FUS9W-T<B`B16YD<F4B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*(RP@9G5Z>GD*;7-G
M:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B1W)U<'!E<B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*
M;7-G<W1R(")4:6QG86YG(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S-PHC+"!F=7IZ>0IM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R
M(")4:6QG86YG(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B16YD<F4@=&EL9V%N9R!F;W(@)R5S)R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(D5D:70@
M;W!T:6]N<R!F;W(Z(@IM<V=S='(@(D5N9')E('1I;&=A;F<@9F]R("<E<R<B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(D5N9')E('1I;&=A;F<@9F]R("<E<R<B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")%;F1R
M92!T:6QG86YG(&9O<B`G)7,G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L
M92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A
M9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R(")%+7!O<W0B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D
M9')E<W,B"FUS9W-T<B`B1&D@92UP;W-T861R97-S93HB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A
M9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B4&%S<V]R9&$@;>4@<V%M
M<W9A<F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0HC+"!F
M=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B
M06YN86X@:6YF;W)M87-J;VXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S
M='(@(D%L=&5R;F%T:78B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE
M<W-A9V4N(@IM<V=S='(@(E1O;70@<F5S=6QT870N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP
M='D@<F5S=6QT+B(*;7-G<W1R(")4;VUT(')E<W5L=&%T+B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E
M87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M
M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*
M;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I
M=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*
M;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U
M('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P
M87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G
M92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R
M<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O
M<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I
M=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")&96EL
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R
M.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T
M=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B
M17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R
M:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%
M<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I
M9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B
M"FUS9W-T<B`B2W9A<G0@,34N(&UI;G5T="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*
M;7-G<W1R(")+=F%R="`U+B!M:6YU='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B2W9A<G0@,S`N('-E:W5N9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DMV87)T
M(#4N(&UI;G5T="(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DMV87(@
M:6YN;&]G9VEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")+=F%R(&AA;'9E('1I;64B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")+=F%R
M="!M:6YU='0B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM
M<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(D5K<V5M<&5L=F5R9&EA
M<CHB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN
M<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP
M:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB
M"FUS9W-T<B`B2W5N;F4@:6MK:F4@:&5N=&4@:6YN<W1I;&QI;F=A<B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@:V]P;&4@
M=&EL($Q$05`M=&5N87)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I;"!,
M1$%0+71E;F%R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I
M;"!,1$%0+71E;F%R96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM
M<V=S='(@(DMU;FYE(&EK:VIE(&AE;G1E(&EN;G-T:6QL:6YG87(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B
M1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)
M<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB"FUS
M9W-T<B`B26UP;W)T9F5I;#H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A:W,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS
M9VED(")&87AE<R(*;7-G<W1R(")&86MS(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B
M1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM
M<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@
M(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I
M:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(E1I='1E;"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL
M92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@
M(D9I;&AA;F1S86UI;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D9I;&AA;F1S
M86UI;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED
M(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@
M(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U
M-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S
M-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M
M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R
M"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS
M9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A
M<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C$*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F4B"FUS9W-T
M<B`B1FYO<G)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED
M(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(").
M;W1A=&%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&
M;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED
M(")&<F%M97,B"FUS9W-T<B`B3F%M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*
M;7-G:60@(D9R86YC92(*;7-G<W1R(")/<F%N<VIE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L
M:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I
M86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L
M>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC
M+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")&=6QL
M('-K:6QD<FEN9SHB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B
M"FUS9W-T<B`B1&ET="!N86UN.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL
M97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX
M"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R
M.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M(RP@9G5Z>GD*;7-G:60@(D=R965C92(*;7-G<W1R(")'<OAN(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'<F5E
M;FQA;F0B"FUS9W-T<B`B1W+X;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*(RP@9G5Z>GD*;7-G
M:60@(D=R96YA9&$B"FUS9W-T<B`B1W+X;B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'
M<G5P<&5A9&UI;FES=')E<FEN9R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM
M<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R
M;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@
M)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<'!E<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")'=65R;G-E>2(*;7-G<W1R
M(")'<N4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"B,L(&9U>GIY"FUS9VED(")'
M=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W1B
M;V]K(@IM<V=S='(@(D%D<F5S<V5B;VLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M
M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM
M<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG
M;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3,R"B,L(&9U>GIY"FUS9VED(")(96%D97(B"FUS9W-T<B`B3W9E
M<G-K<FEF=&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")/
M=F5R<VMR:69T97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@
M5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](
M96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M
M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B
M2&IE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED
M(")(96QP97(B"FUS9W-T<B`B2&IE;'`B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G<W1R
M(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R
M(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4L
M('!R:79A="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B
M2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*
M;7-G<W1R(")496QE9F]N+"!P<FEV870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@
M(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N
M9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<
M(B5S7"(B"FUS9W-T<B`B1FIE<FYA("<E<R<@9G+E('-Y<W1E;65T+B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B
M2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT
M86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I
M9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*
M;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS
M9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR
M,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@
M(D%D<F5S<V4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP
M.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G
M:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B
M26-O;G,@3VYL>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC
M;VYS('=I=&@@=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E
M8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF
M('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO
M<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB
M268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA
M9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@
M55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R
M=&5R=&4@9F5L=#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B
M"FUS9W-T<B`B26UP;W)T97)T92!F96QT.B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B26UP;W)T97)T92!F96QT.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N
M(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("))
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(")3
M:W)I=B!I;FX@9&ET="!B<G5K87)N86UN(&]G('!A<W-O<F0B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T
M('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5
M<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@9G5Z>GD*;7-G:60@(DEN9F]R
M;6%T:6]N(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B
M26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS
M9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A
M8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T
M97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B
M26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y
M"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE
M;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A
M($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN
M=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV
M86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED
M("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("));G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@
M;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M
M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3<S"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G
M:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G
M:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS
M9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E
M;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA
M=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M27-R865L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))
M=&%L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED
M("))=&%L>2(*;7-G<W1R(")$86=L96<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R
M+4I0*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O
M;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I
M<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,@HC+"!F=7IZ>0IM<V=I9"`B2F5R<V5Y(@IM
M<V=S='(@(D=RY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G
M:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*
M=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@
M3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"B,L(&9U>GIY"FUS9VED(")+96YY82(*;7-G<W1R(").96MT
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME
M<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I
M9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*
M(RP@9G5Z>GD*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(DU)344M='EP92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U
M>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B365L9&EN9R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`HC+"!F=7IZ>0IM<V=I
M9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R(")/<'!K;W!L:6YG(&UO="!O9F9E;G1L96<@;OAK:V5L=&5N
M87(@;F5K=&$N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED
M(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A
M=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%
M54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G
M:60@(DQA7WEO=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B4W!RY6LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E
M<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*
M;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B3&%S="!5
M<&1A=&5D.B(*;7-G<W1R(")/<'!D871E<B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*
M;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F
M=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(DQO9V<@=70B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),
M96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE
M9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU
M97,B"FUS9W-T<B`B16MS96UP96QV97)D:6%R.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@
M(D%L9')I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS
M9W-T<B`B3'ES(&)LY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S
M='(@(DQO9V<@:6YN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*
M;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@
M4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4
M:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Q"B,L(&9U>GIY"FUS9VED("),:6=H="!3;F]W(@IM
M<V=S='(@(DQY<R!B;.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE
M<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S='(@(DQO9V<@:6YN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O
M;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@
M9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*
M;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM
M<V=S='(@(E9I<R!E;6YE(&9RY2!(:F5L<"(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T
M+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G
M<W1R(")6:7,@96UN92!F<N4@2&IE;'`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I
M9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS
M9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C
M<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("),:7-T:6YG(&%V(&)R=6MA<F%R(&5R('-LY71T
M(&%V+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S
M='(@(DQI<W1I;F<@878@8G)U:V%R87(@97(@<VSE='0@878N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG
M('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),:7-T:6YG(&%V(&)R=6MA
M<F%R(&5R('-LY71T(&%V+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@
M(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G
M<W1R("),;V=G(&EN;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS
M9VED("),;V<@;W5T(@IM<V=S='(@(DQO9V<@=70B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@
M(DQO9V<@:6YN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PHC+"!F
M=7IZ>0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B3W!P9^5V97(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*(RP@9G5Z>GD*;7-G:60@
M(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(DMU;FYE
M(&%V(&5I;B!E;&QE<B!A;FYA;B!G<G5N;B!I:VMJ92!L;V=G92!I;FXN(%-A
M;FYS>6YL96=V:7,@97(@8G)U:V%R;F%M;B`B"B)E;&QE<B!P87-S;W)D('1A
M<W1A(&EN;B!F96EL+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY
M,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E
M>'0B"FUS9W-T<B`B3&]G9R!U="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`HC+"!F=7IZ>0IM<V=I9"`B3&]V92(*;7-G<W1R(")&:F5R;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED
M("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@
M;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.
M148M=F5D;&5G9R!I;FYE:&5L9'0@:6YG96X@9&%T82XB"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS
M9VED(")-86=I8R(*;7-G<W1R(")%+7!O<W0B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B12UP;W-T(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!
M9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA
M=VDB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA
M>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L
M:2(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G
M:60@(DUA;'1A(@IM<V=S='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P
M475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM
M<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B
M36%R9VEN(@IM<V=S='(@(L5T=F%R:6YG(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T
M8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-A;7-V87)A;F1E(&9E;'0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0
M;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N
M9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE
M;6)E<G,B"FUS9W-T<B`B365D;&5M;6%R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P
M"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M365S<V%G92(*;7-G<W1R(")-96QD:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@
M9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365L9&EN
M9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP
M92(*;7-G<W1R(")-96QD:6YG(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"B,L
M(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R(")$971A;&IA<B!E<B!L;V=G82!F;W(@861M:6YI<W1R871O
M<F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G
M:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX
M,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B
M"FUS9W-T<B`B365T;V1E("<E<R<@:6MK:F4@9&5F:6YE<G0B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T
M<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-24U%+71Y<&4B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM
M<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B
M1F5I;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES
M8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!
M4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U
M<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A
M;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU
M.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N
M86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL
M>2(*;7-G<W1R(")-Y6YA9&QE9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N
M='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E
M8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G
M:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-
M;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*
M;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU
M;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B
M37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")$:6X@:6YF;W)M87-J
M;VXB"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")-
M>2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N
M<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@
M(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").14DL(&5G(&5R($E+2TI%
M('-A;60B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B
M3F%M92(*;7-G<W1R(").86UN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI
M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C
M87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#
M02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*
M;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@
M(DYE='1V97)K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B06QD<FDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS
M-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G
M:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(")087-S;W)D(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ>0IM
M<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B4&%S
M<V]R9&$@;>4@<V%M<W9A<F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W1A=&%R
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0HC+"!F=7IZ>0IM
M<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P<&5R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@
M4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"B,L
M(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B5&EL8F%K92!T
M:6P@86QT97)N871I=B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z
M,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z
M>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(D%L9')I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL
M.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A
M=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY
M"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N<VEN
M9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E<FEN9RXB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@8VAA;F=E+B(*;7-G<W1R(")!;F=R92!E;F1R:6YG87(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@HC+"!F=7IZ>0IM<V=I9"`B
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B)R5S)R!V87)T(&QA9W0@=&EL('1I;&=A;F=S<WES=&5M970N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP
M:'`Z-S<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@
M(DEN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@<W!E<VEF:7-E<G0@
M9F]R(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M,C0*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("));F=E;B!K;VYF
M:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344P@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;G-I;F9O<FUA<VIO
M;B!S<&5S:69I<V5R="!F;W(@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"B,L(&9U>GIY"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N
M('-P97-I9FES97)T(&9O<B!344P@5D93+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E
M9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S
M='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@
M:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S
M970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM
M<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P
M+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("));F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T
M(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("));F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T
M(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N
M(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@<W!E<VEF:7-E<G0@9F]R(%-1
M3"UA=71E;G1I<V5R:6YG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E
M<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I
M9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(DYO('%U
M;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M<G5L97,B"FUS9W-T<B`B3F]T871A<B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS
M9W-T<B`B3F]T871A<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y
M(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0HC
M+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N(@IM<V=S='(@(E-K<FEV(&EN;B!D:71T(&)R=6MA<FYA;6X@;V<@<&%S
M<V]R9"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS
M9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("));F=E
M;B!G>6QD:6=E(%A-3"UD871A(')E='5R;F5R="(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`B5&5L
M969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/
M+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R
M9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS
M9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP
M;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`B3F]T871A<B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&%T87(B"@HC
M.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM<V=I
M9"`B3F]V96UB97(B"FUS9W-T<B`B365D;&5M;6%R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM
M<V=S='(@(DUE9&QE;6UA<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T
M"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B
M3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@
M;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J
M96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC
M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E
M<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B
M4&%S<V]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM
M<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D]M86XB"FUS9W-T<B`B
M3W)A;G-J92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X
M=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM
M<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S
M='(@(D%L=&5R;F%T:78B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D%L=&5R;F%T:78B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS
M9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R9V%N
M:7-A=&EO;B(*;7-G<W1R(")!9&UI;FES=')E<FEN9R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I
M;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B
M3W)A;G-J92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/
M<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G
M<W1R(")!;FYA;B!I;F9O<FUA<VIO;B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I
M9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS
M9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")0
M32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@(E!-(%-U;B(*;7-G<W1R
M(")3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED
M(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL
M($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N
M86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W
M($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A
M9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S
M"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")087-S;W)D(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N
M9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S
M=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E
M<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W
M;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O
M<F0Z(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M(")087-S;W)D(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(E!A<W-O<F1A(&WE('-A;7-V87)E+B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")0
M87-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS
M9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S
M='(@(E)O;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@
M(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")+^'ER
M('9E9&QI:V5H86QD<V]P97)A<VIO;F%R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")+^'ER('9E9&QI:V5H86QD<V]P97)A
M<VIO;F%R('9E9"!I;FYL;V=G:6YG/R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N(@IM
M<V=S='(@(E1I;&=A;F<B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R
M"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS
M9W-T<B`B5&EL9V%N9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC
M.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B5&EL9V%N9W-A9&UI;FES=')E<FEN9R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-0HC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86P@26YF;W)M
M871I;VXB"FUS9W-T<B`B06YN86X@:6YF;W)M87-J;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B
M"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B
M4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED
M(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ
M,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU
M;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM
M87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")3:W)I=B!I;FX@96ET('-A
M;6%N9')A9R!A=B!P<F]B;&5M970N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED
M(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*
M;7-G<W1R(")3:W)I=B!I;FX@9&ET="!B<G5K87)N86UN(&]G('!A<W-O<F0B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*(RP@9G5Z>GD*;7-G
M:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*(E9E<B!V96YL96<@;V<@;&5S(&;X;&=J86YD92!T96MS
M="X@1'4@3<4@=F5R92!S86UD(&UE9"!V:6QKY7)A(&9O<B#E(&)R=6ME("(*
M(G-Y<W1E;65T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&]L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ
M"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@
M24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S
M"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE
M=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@
M(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E
M=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0<F5S96YT87-J;VYA<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@
M(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC
M+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(");4')O8FQE;7)A<'!O
M<G1=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B
M;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E-K:6QD<FEN9R!A=B!P<F]B;&5M
M970B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0
M<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S
M"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L
M9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I
M9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B3V9F96YT;&5G+W!R:79A="!N^&MK96QP87(@
M=F%R="!I:VMJ92!G96YE<F5R="XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0
M=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1
M871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G
M:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@
M(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM
M<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3&5S(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@
M9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B365L9&EN9R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G
M:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*(RP@
M9G5Z>GD*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D9R
M:7-K(&]P<"!O=F5R<VEK='9I<VEN9SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"B,L(&9U>GIY"FUS9VED(")2
M96=E>"(*;7-G<W1R(").=6QL<W1I;&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")2
M96QO860B"FUS9W-T<B`B3&5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B
M"FUS9W-T<B`B1FIE<FXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")&:F5R;B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W9E($)L;V-K(@IM<V=S='(@(D9J97)N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W9E(&-O;'5M;B(*;7-G<W1R(")&:F5R;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D9J97)N('!A<B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*
M;7-G<W1R(")&:F5R;B!P87(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U
M>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D9J97)N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P
M"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(D9J97)N
M('!A<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM
M<V=S='(@(D9J97)N('!A<B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P
M8RYP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E
M(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(")+=6YN
M92!I:VMJ92!S=F%R92!PY2!F^')E<W!U<FYA9"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B2W5N;F4@
M:6MK:F4@<W9A<F4@<.4@9OAR97-P=7)N860B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M3OAD=F5N9&EG("=T86)L92<@:6MK:F4@<W!E<VEF:7-E<G0@:2!K;VYF:6=U
M<F%S:F]N(&9O<B!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D[X9'9E;F1I9R`G=&%B;&4G
M(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@5D93+B(*
M"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3OAD=F5N9&EG("=T86)L92<@
M:6MK:F4@<W!E<VEF:7-E<G0@:2!K;VYF:6=U<F%S:F]N(&9O<B!61E,N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED
M(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B3G5L;'-T:6QL(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@
M(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@
M66]U<B!087-S=V]R9"(*;7-G<W1R(")3=&%D9F5S="!P87-S;W)D(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U
M97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"B,L(&9U
M>GIY"FUS9VED(")297-U;'1S(@IM<V=S='(@(DYU;&QS=&EL;"(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
M5&EL8F%K92!T:6P@86QT97)N871I=B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC+"!F=7IZ
M>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(E1I
M;&)A:V4@=&EL(&%L=&5R;F%T:78B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2
M:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PHC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@
M=F%L=65S(@IM<V=S='(@(DQY<R!B;.4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@
M(E)O;&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T
M92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B
M4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B
M"FUS9W-T<B`B4F]L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O
M;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E)U;B(*;7-G<W1R(")3;VPB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4G=A;F1A
M(@IM<V=S='(@(DQE<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS
M9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@
M9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B365L9&EN9R(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G
M:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-(
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H
M96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN
M8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M
M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A
M;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O
M(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B
M:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDX"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S='(@(DQA9W)E("<E<R<B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("),
M86=R92`G)7,G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B
M3&%G<F4@)R5S)R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G
M:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("),86=R92!A;'1E<FYA=&EV(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT.0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S
M='(@(E9E;"!D871O9F]R;6%T.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B
M4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS
M9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")3
M96QE8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP
M;VYE;G1S+B(*;7-G<W1R(")696P@9&%T;V9O<FUA=#HB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE
M8W0@86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C="!N;VYE(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ
M>0IM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E9E
M;"!T96EK;F$@9'4@=')E;F<@9G+E(&)O:W-A;F4@=6YD97(N($1U(&MA;B!S
MY2!K;W!I97)E(&]G(&QI;64@9&5I(&EN;B!F<N4@(@HB=&5K<W1B;VMS82XB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5F5L('-K:6QJ971E:6MN
M(&9O<B!D871O.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")696P@9&%T
M;V9O<FUA=#HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z(@IM<V=S='(@(E9E;"!S:VEL:F5T96EK;B!F;W(@9&%T;SHB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`B5F5L('1I9'-F;W)M870Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E9E;"!T;R!S86US=F%R86YD92!F
M96QT+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B5F5L(&9A<F=E<VMJ
M96UA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B5F5L(/AN
M<VMA('-P<N5K.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-E;F0@
M<')O8FQE;7)A<'!O<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S,*(RP@9G5Z>GD*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")-961L96UM
M87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM
M<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")4:6QG
M86YG<V%D;6EN:7-T<F5R:6YG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X
M<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ
M>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM
M<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")696P@^&YS:V$@<W!RY6LZ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED("(B
M"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N
M<RXB"FUS9W-T<B`B4V5T(&9A<F=E<VMJ96UA+"!S:61E;W!P9G)I<VMI;F<@
M;V<@86YD<F4@=FES:6YG<V%L=&5R;F%T:78N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3
M:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R(")+;W)T('-A;6%N9')A9SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B5FES
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO
M=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE
M(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T
M:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G
M:60@(E-H;W=E<G,B"FUS9W-T<B`B5FES(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B
M4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG
M;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N
M871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3
M:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(DAO<'`@;W9E<B!V961L:6ME:&%L
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"B,L(&9U
M>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(E9I<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED
M(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO
M=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R
M8V4@861D<F5S<R(*;7-G<W1R(")!9')E<W-E+"!A<F)E:60B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O
M=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED
M(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD
M('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM
M<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@
M(DEN;G1A<W1I;F<@878@<W!E<VEA;'1E:6MN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L
M:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B
M4W!O<G1S(@IM<V=S='(@(DEM<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS
M9VED(")3=&%N9&%R9"(*;7-G<W1R("(E<R!3=&%N9&%R9"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L
M(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")$:6X@:6YF
M;W)M87-J;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B
M061R97-S92P@87)B96ED(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3
M=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8R"B,L(&9U>GIY"FUS9VED(")3=2(*;7-G<W1R(")3;VPB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")&
M86YN(&EK:VIE('9A<G-E;&QY='1A<B`E<RXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI
M="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B
M4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")3
M=6MS97-S(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B3&$@=&EL("<E<R<@=&EL('-Y<W1E;65T+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")&:F5R;F$@)R5S)R!F<N4@
M<WES=&5M970N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(E-L971T82`G
M)7,G+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B1FIE<FYA("<E<R<@9G+E('-Y<W1E;65T
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E
M<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E
M(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B4VQE='1A("<E<R<N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W
M<F]T92`E<R(*;7-G<W1R(")3;&5T=&$@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"B,L(&9U>GIY"FUS9VED(")3=61A;B(*;7-G<W1R(")3;VPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L
M(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(DUI='0@<V%M86YD<F%G
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*(RP@
M9G5Z>GD*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4V]L(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G
M:60@(E-U;FYY(@IM<V=S='(@(E-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,38*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4B"FUS9W-T
M<B`B4V]L(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@
M(E-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G
M:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@
M9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B26UP;W)T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B0G)U
M:V%R;F%M;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(D)R=6MA<FYA
M;6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3
M=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T
M<B`B5&ET=&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*
M(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1I='1E;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*
M;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B
M;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I
M=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E
M9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B3W!P
M9^5V97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,
M;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L
M871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")"<G5K87)A9&UI;FES=')E<FEN9R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED
M(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*(RP@
M9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B1'4@97(@;&]G9V$@=70N/&)R("\^5&%K:R!F;W(@870@9'4@
M8G)U:V%R(&1E='1E('-Y<W1E;65T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN
M<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI
M=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")+;&%S<V$@36%I;G1E;F%N
M8V4Z.B!V87)T(&EK:VIE(&QA<W1A(&EN;B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT
M86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E
M(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C
M:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP
M:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")+<GEP=&5R:6YG
M<V9U;FMS:F]N86YE(&MR978@96D@<VEK:V5R(&YE='1O<'!K;W!L:6YG+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS
M9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"B,L
M(&9U>GIY"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B35,M5$Y%1BUV961L96=G(&EN;F5H96QD="!I;F=E;B!D871A+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*
M(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L
M96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E
M<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E
M8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V
M92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I
M;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N
M("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA
M>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G
M92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@
M9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M
M97)I8RXB"FUS9W-T<B`B1&5N;F4@=F5R9&EE;B!MY2!V97)E(&5I="!T86PN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS
M9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(
M;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D
M(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL
M;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B(@HB1F%N;B!I:VMJ92!P<F]G<F%M;65T('-O;2!B<G5K87-T('1I;"#E
M('9I<V4@9&5N;F4@='EP96X@;65L9&EN9V%R("@E<RDN(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA
M<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S
M7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS
M9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R
M"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R
M92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B26YG96X@:6YN<W1I
M;&QI;F=A<B!E<B!T:6QG:F5N9V5L96=E+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B
M"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB
M)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")0<F]B;&5M(&UE9"#E
M(&QE9V=E('1I;"`G)7,G('1I;"!S>7-T96UE="XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')O8FQE;2!V960@9FIE<FYI;F<@
M878@)R5S)R!F<N4@<WES=&5M970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M(")0<F]B;&5M('9E9"!F:F5R;FEN9R!A=B`G)7,G(&9RY2!S>7-T96UE="XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E
M<R(*;7-G<W1R(")0<F]B;&5M(&UE9"#E(&QE9V=E('1I;"`G)7,G('1I;"!S
M>7-T96UE="XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T
M:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP
M.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"B,L(&9U>GIY"FUS9VED(")4
M:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB
M"FUS9W-T<B`B1&5N;F4@=F5R9&EE;B!MY2!V97)E(&5I="!T86PN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*
M;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM
M<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D1E;FYE('9E
M<F1I96X@;>4@=F5R92!E:70@=&%L+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN
M(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M
M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP
M+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA
M<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED
M(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B
M1&5T=&4@=&%L970@;>4@=F5R92!M:6YS="!E:6XN(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E
M<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB
M"FUS9W-T<B`B1&5N;F4@=F5R9&EE;B!MY2!V97)E(&5I="!T86PN(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE
M(@IM<V=S='(@(E1I='1E;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4
M:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71T96PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L
M92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*
M;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI
M;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@
M(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4
M;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@9G5Z>GD*;7-G
M:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")0<F5S96YT87-J;VYA<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B
M5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1U<FME>2(*;7-G<W1R(")'
M<N4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES
M:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G
M:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G
M:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E52
M3"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S='(@
M(D]R86YS:F4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM
M<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P
M;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@S.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET
M:"!34TPN(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G
M<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VMJ92!K
M;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E
M;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S
M)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE
M+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@
M(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@
M)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-#(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")+=6YN92!I
M:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I
M:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B
M2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS
M9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(")+
M86X@:6MK:F4@<F5G:7-T<F5R92!I;FYS=&EL;&EN9V%R(&D@^&MT82XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE
M=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@
M;V8@)7,N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV
M-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@
M:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(DMA;B!I
M:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF
M:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS
M.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S
M='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VMJ92!K
M;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE
M='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')U
M;B`G;6MI<V]F<R<N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G
M.B`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N="(*;7-G<W1R(")+86X@:6MK:F4@;VUS971J92!D971T92!7;W)D
M+61O:W5M96YT970N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R
M;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV
M"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B06YG<F4@96YD<FEN9V%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`HC+"!F
M=7IZ>0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O
M;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B56=Y;&1I9R!S=F%R(&9RY2!T96YA
M<B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`HC+"!F
M=7IZ>0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@(@IM<V=S='(@(E5G>6QD:6<@<W9A<B!F<N4@=&5N87(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I
M9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO
M<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS
M9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK
M;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S
M='(@(D)R=6MA<FYA;6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U
M<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")/<'!D871E<B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")/<'!D871E
M<G1E("<E<R<N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHW-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B3W!P
M9&%T97(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S
M='(@(D]P<&1A=&5R=&4@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I
M9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-3
M3"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS
M9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-
M4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@
M(D)R=6MA<F%R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@
M875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")"
M<G5K87)A9&UI;FES=')E<FEN9R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B0G)U
M:V%R86QT97)N871I=B(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(D)R=6MA<F%D;6EN:7-T
M<F5R:6YG(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E
M<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y
M.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")"<G5K87)N86UN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D)R=6MA<FYA
M;6XB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L(&9U>GIY
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(D)R=6MA<FYA;6XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I
M;B!T:&4@<WES=&5M.B(*;7-G<W1R(")"<G5K87)A<B!I('-Y<W1E;65T.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*
M;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*
M;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G
M:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM
M<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@
M:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"B,L(&9U>GIY"FUS9VED
M(")697)S:6]N(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM
M<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE3
M0TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W
M(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL
M:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM
M<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@
M(E=A<FYI;F<B"FUS9W-T<B`BQ71V87)I;F<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@
M(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I
M9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B2W9A<B!V96ME(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G
M:60@(E=E;&-O;64B"FUS9W-T<B`B5F5L:V]M96XL("5S(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS
M9W-T<B`B5F5L:V]M96X@=&EL("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E9E;&MO;65N
M+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T
M97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF
M;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI
M8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@
M4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED
M=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C
M="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O
M9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B
M5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I
M9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R
M(")!9')E<W-E+"!A<F)E:60B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@
M(E1E;&5F;VXL(&%R8F5I9"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE
M("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@
M=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM
M<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X
M=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(EE9(@IM<V=S='(@(L7%(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM
M<V=S='(@(L7%(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I
M9"`B665A<FQY(@IM<V=S='(@(L5R;&5G(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F
M=7IZ>0IM<V=I9"`B665M96XB"FUS9W-T<B`B1W+X;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(DIA+"!E
M9R!E<B!S86UD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@
M=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T
M92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U
M=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H
M92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3<U"B,L(&9U>GIY"FUS9VED(")9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DMU;FYE
M(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E+7!O<W1A9')E<W-E+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*
M(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U
M="XB"FUS9W-T<B`B06QT97)N871I=F$@9&EN92!H87(@8FQI='0@;W!P9&%T
M97)T92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED
M("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T
M:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U
M-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q
M"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B1'4@
M;>4@<VMI;&1R92!P<F]B;&5M970@9OAR(&1U(&MA;B!S96YD92!P<F]B;&5M
M<F%P<&]R=&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<G!C<W5M+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")$
M=2!MY2!S<&5S:69I<V5R92!E:70@8G)U:V%R;F%M;B#E(&9J97)N92XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(D1U
M(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N86UN(.4@9FIE<FYE+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF:7-E
M<F4@96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S
M='(@(D1U(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N86UN(.4@;&5G9V4@
M=&EL+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G
M<W1R(")$=2!MY2!S<&5S:69I<V5R92!E:70@8G)U:V%R;F%M;B#E(&QE9V=E
M('1I;"XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF:7-E<F4@
M96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B
M1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P
M:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("+8
M:W1A(&1I("@E<RD@:&%R(&?E='0@=70@<.4@=&ED+B!,;V=G(&EN;B!PY2!N
M>71T+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L
M(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B1&D@
M92UP;W-T861R97-S93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R
M"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(D1I(&4M<&]S=&%D<F5S<V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9
M;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S
M"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B1&ET="!N86UN
M.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U
M>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*
M(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD
M+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG<V)A:V1E;&XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB3&ES=&EN9R!A=B!B
M<G5K87)A<B!E<B!I:VMJ92!S=/AT=&$@878@8F%K<F4@875T96YT:7-E<FEN
M9RP@96QL97(@9G5N:W-J;VYE;B`B"B)H87(@878@96EN(&5L;&5R(&%N;F%N
M(&=R=6YN(&)L:71T('-LY71T(&%V+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@
M4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U
M<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B06QT97)N871I=F$@
M9&EN92!H87(@8FQI='0@;W!P9&%T97)T92XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ(@IM<V=S='(@(E-T86YD87)D:61E;G1I=&5T(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL
M(&YA;64Z(@IM<V=S='(@(D1I='0@;F%M;CHB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")!;'1E<FYA=&EV82!D:6YE(&AA<B!B;&ET
M="!O<'!D871E<G1E+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BXB"FUS9W-T<B`B06QT97)N871I=F$@9&EN92!H87(@8FQI='0@;W!P
M9&%T97)T92XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U
M-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G
M<W1R(")!;'1E<FYA=&EV82!D:6YE(&AA<B!B;&ET="!O<'!D871E<G1E+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W
M;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S
M;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I
M9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S
M='(@(EM0<F]B;&5M<F%P<&]R=%TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*
M;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");;&EN:F4@)7,@878@
M)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E]!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')E<FEN9R(*"B,Z(&QI8B]A
M<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E-L971T92(*
M"B,Z(&QI8B]A<&DN<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B7T=R;W5P<R(*
M;7-G<W1R(")'<G5P<&5R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B2&IE
M;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*
M(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B3&]G9R!I;FXB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY
M"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("),;V=G('5T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS
M9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P
M=&EO;G,B"FUS9W-T<B`B06QT97)N871I=B(*"B,Z(&QI8B]A<&DN<&AP.C$S
M-PHC+"!F=7IZ>0IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E1I;&=A
M;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*
M;7-G<W1R(")&:F5R;B!P87(B"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@
M(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0HC+"!F
M=7IZ>0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(D)R=6MA<F%R(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D
M9')E<W,@8F]O:R(*;7-G<W1R(")!9')E<W-E8F]K(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U
M;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")+86QE
M;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*
M;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@
M(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS
M9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A
M;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA
M="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q
M"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G
M<W1R(")4:71T96PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(FQI;F5S72(*;7-G<W1R(")/
M=F5R<VMR:69T97(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ
M>0IM<V=I9"`B;F%M92(*;7-G<W1R(").86UN(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM
M<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS
M9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")4:6QG86YG(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@
M<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G
M<W1R("+%='9A<FEN9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@
M9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V
M:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@HC+"!F=7IZ
M>0IM<V=I9"`B<W1E861Y(@IM<V=S='(@(DQE<R(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I
M<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I
M9"`B=')Y(&%G86EN(@IM<V=S='(@(DMV87(@:6YN;&]G9VEN9R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B
M=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED
M(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]P;%]03"YP
M;P``````````````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P-C(P,#$U`#$P-#$W,S8S,#`S`#`Q-C,W-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C($A/4D1%(%!O;&ES:"!T<F%N
M<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@36%R:75S>B!:>6YE;"`\
M;6%R:75S>D!M:7IA<BYO<F<^"B,@36%R:75S>B!:>6YE;"`\;6%R:75S>D!M
M871H+G5W8BYE9'4N<&P^+"`R,#`Q+@HC(%!I;W1R(%)O<WIA='EC:VD@/&1E
M>'1E<D!D96)I86XN;W)G/BP@,C`P,2X*(R!+<GIY<WIT;V8@2V]Z;&]W<VMI
M(#QK;WII:S%`;S(N<&P^+"`R,#`U+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3$M,C0@,C`Z-38K,#$P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-2TQ,2TR-"`R,3HT-BLP,3`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($MR>GES>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#Y<
M;B(*(DQA;F=U86=E+51E86TZ(%!O;&ES:"`\<&Q`;&DN;W)G/EQN(@HB34E-
M12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#UI<V\M.#@U.2TR7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X+6)I=%QN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I
M<FU?=&]P+FEN8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(@)B,Q-3$[
M("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RXB"FUS9W-T<B`B)7,@+2!G;W1O=WD@9&\@
M=WEK;VYA;FEA(&-Y:VQI8WIN>6-H(&]P97)A8VII('IA>FYA8WIO;GEC:"!P
M;VYIOV5J+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S8X"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@9&YI
M('1E;74I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,C4V"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(H:VQU8WH@9&]S=.IP
M=2`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H=R!C:;%G=2`E
M<R!D;FDI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S(*;7-G:60@(B`H
M=&]D87DI(@IM<V=S='(@(B`H9'IIMBDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W-`IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AJ=71R;RDB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,`IM<V=I9"`B("AY97-T97)D
M87DI(@IM<V=S='(@(B`H=V-Z;W)A:BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B
M(&%T("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC
M92XB"FUS9W-T<B`B7"(E<UPB(&YI92!J97-T('!R87=I9+-O=WEM('=Y8F]R
M96TN(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HU-30@;&EB+TAO<F1E
M+U)E9VES=')Y+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS
M9W-T<B`B7"(E<UPB(&YI92!J97-T('-K;VYF:6=U<F]W86YY('<@<F5J97-T
M<GIE($AO<F1E+B(*"B,Z(&QI8B](;W)D92]4<F5E+G!H<#HQ-C0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEE>FYA;&5Z:6]N>2XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4W"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(E5D8;-O
M('-IZB!D;V1AYB!<(B5S7"(@9&\@9W)U<"XB"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")5
M9&&S;R!S:>H@9&]D8>8@7"(E<UPB(&1O('5P<F%W;FEE\2XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4U(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HX,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E
M<RXB"FUS9W-T<B`B7"(E<UPB(&YI92!Z;W-T8;,@=71W;W)Z;VYY.B`E<RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!I("5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]T;W`N:6YC.C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!5=V%G
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!9&UI;FES=')A8VIA("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B
M"FUS9W-T<B`B)7,@;V1C:7-K('!A;&-A(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C@S,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M.#,R"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S(&M"
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@+2!O<&5R86-J92!C>6ML
M:6-Z;F4@+2!P;W1W:65R9'IE;FEE(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(DMO;F9I9W5R86-J82`E<R(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B4F5J97-T<F%C:F$@)7,B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C4V."!L:6(O5D93+V9T
M<"YP:'`Z-C,V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R("(E<R!J=;\@:7-T;FEE:F4N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&1O("5S('H@)7,B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!J97-T('=Y;6%G86YY(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU="(*"B,Z(&QI8B](;W)D
M92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N:65Z;F%L97II;VYY+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@9&\@)7,@
M>B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DQ"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(DMS:;&_:V$@
M861R97-O=V$@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@X,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N
M9&%R>B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#<U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(").;W1A=&YI:R`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DY"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B3&ES=&$@>F%D8?$@)7,B
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S
M.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3,@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.`IM<V=I9"`B+"!G=7-T:6YG
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B5S(&1O("5S('H@)7,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P-S`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,CD*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8X.`IM<V=I
M9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM('=Y8FEE<GH@+2TB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM
M<V=S='(@(C$R+6=O9'II;FYY(&9O<FUA="(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0M9V]D
M>FEN;GD@9F]R;6%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*
M;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&=O9'HN(@H*(SH@;&EB+TAO
M<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@
M(CQ0;W!R>F5D;FDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0HC+"!F
M=7IZ>0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")"<F%K(&MO;F9I9W5R86-J:2!W97=N
MZG1R>FYE:B!D;&$@=&5G;R!H;W-T82(*"B,Z(&QI8B](;W)D92YP:'`Z,38P
M"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(").
M87-TL7!ILR!BL[%D(&MR>71Y8WIN>2(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.CDR,`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B4&]T<GIE8FYY(&IE
M<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!Z87-Z>69R;W=A;FEA('=I861O
M;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$T-0IM<V=I
M9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S
M:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB4&]T<GIE8FYY(&IE<W0@:VQU
M8WH@<'5B;&EC>FYY(%!'4"!D;R!S<')A=V1Z96YI82!P;V1P:7-A;F5J('=I
M861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`W-PIM
M<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*(E!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z
M;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A>B!H87.S;R!D;R`B"B)O
M9'-Z>69R;W=A;FEA('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.3DU"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB4&]T<GIE8FYE('.Q(&ML
M=6-Z('!U8FQI8WIN>2!01U`L(&ML=6-Z('!R>7=A=&YY(%!'4"!O<F%Z(&AA
M<[-O(&1O("(*(G!O9'!I<V%N:6$@=VEA9&]M;[9C:2XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(E!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C
M>B!P<GEW871N>2!3+TU)344@;W)A>B!H87.S;R!D;R`B"B)O9'-Z>69R;W=A
M;FEA('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)0;W1R>F5B;F4@<[$@:VQU
M8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T;GD@4R]-24U%(&]R
M87H@:&%SLV\@9&\@(@HB<&]D<&ES86YI82!W:6%D;VUOMF-I+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(E!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!334E-12!D
M;R!Z87-Z>69R;W=A;FEA('=I861O;6^V8VDN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(EIA;6MN:6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`HC+"!F=7IZ>0IM<V=I9"`B04T@3&EG
M:'0@4F%I;B(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*(RP@9G5Z>GD*;7-G:60@(D%-(%)A
M:6XB"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@HC+"!F=7IZ>0IM<V=I9"`B04T@4VAO
M=V5R<R(*;7-G<W1R("));7!O<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,PHC+"!F=7IZ>0IM<V=I9"`B04T@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(DEM<&]R="(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@
M240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T
M<B`B3R!T>6T@961Y=&]R>F4B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B3R!P<F]G<F%M:64N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T
M"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B
M06)S;6ED9&QE(@IM<V=S='(@(E-T86YO=VES:V\B"@HC.B!L:6(O5D93+VUU
M<W%L+G!H<#HR-S`*(RP@9G5Z>GD*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q
M8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+VUU<W%L
M+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S
M:>H@>B!S97)W97)E;2!344PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DAA<[-O(&1O
M(&MO;G1A(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")+;VYT;R!Z86)L
M;VMO=V%N92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S$W"FUS
M9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DMO;G1A(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4T(&QI8B](;W)D92]097)M<R]522YP:'`Z,3,R
M"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-"!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ-@IM<V=I9"`B061D(@IM<V=S='(@
M(D1O9&%J(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,30@861M:6XO9W)O=7!S
M+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G
M<W1R(")$;V1A:B!N;W>Q(&=R=7#J(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HX-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@U"B,L(&9U>GIY"FUS
M9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")$;V1A:B!N;W=E
M('5P<F%W;FEE;FEE(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*
M;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")$;V1A:B!T=71A:CHB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(P."!A9&UI;B]G<F]U<',N<&AP.C(P.0IM<V=I
M9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")$;V1A:B!N;W>Q(&=R=7#J(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW,R!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C<T"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M1&]D86H@;F]W92!U<')A=VYI96YI92(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O861D8VAI;&0N:6YC.CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")/<&-J
M92`E<R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$S,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B
M3W!C:F4@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@
M;F5W('5S97(Z(@IM<V=S='(@(D1O9&%J(&YO=V5G;R!UOWET:V]W;FEK83HB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS
M9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(D1O9&%J(&MO;'5M;NHB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,U"FUS9VED(")!9&0@
M;F5W(&UE;6)E<G,B"FUS9W-T<B`B1&]D86H@;F]W>6-H(&-ZLV]N:_-W(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D9"!P
M86ER(@IM<V=S='(@(D1O9&%J('!A<NHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N
M=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")$;V1A:B!M96YU("5S
M(&1O('!A<VMA($UO>FEL;&DB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G
M<W1R(")$;V1A:B!D;R!K<VFQOVMI(&%D<F5S;W=E:CHB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@
M861D<F5S<R!B;V]K(@IM<V=S='(@(D1O9&%J(&1O(&UO:F5J(&MS:;%Z:VD@
M861R97-O=V5J(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U
M<V5R(@IM<V=S='(@(D1O9&%J('6_>71K;W=N:6MA(@H*(SH@861M:6XO=7-E
M<BYP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I
M=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(D1O
M9&%N;R!<(B5S7"(@9&\@<WES=&5M=2X@36^_97-Z('-IZB!Z86QO9V]W8>8N
M(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*
M;7-G<W1R(")$;V1A;F\@7"(E<UPB(&1O('-Y<W1E;74N($UOOV5S>B!S:>H@
M>F%L;V=O=V'F+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHT"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(D1O9&%W86YI92!UOWET:V]W;FEK\W<@:F5S="!W>;-A8WIO;F4N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#,@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R97,B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O
M;VLB"FUS9W-T<B`B2W-IL;]K82!A9')E<V]W82(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T
M<B`B3W!C:F4@)7,B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B061M:6YI<W1R86-J82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.3(*;7-G:60@(D%D<R(*;7-G<W1R(")296ML86UY(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G86YI<W1A;B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L
M8F%N:6$B"FUS9W-T<B`B06QB86YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T
M<B`B06QG:65R:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS
M9VED(")!;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL
M(@IM<V=S='(@(E=S>GES=&MO(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3$X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!
M=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E=S>GES8WD@=7=I97)Z>71E
M;&YI96YI('6_>71K;W=N:6-Y(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A
M9&UI;B]G<F]U<',N<&AP.C(Q,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R
M(")7<WIY<W1K:64@9W)U<'DB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z,S@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-PIM<V=I9"`B06QL(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E=S>GES=&MI92!U<')A=VYI96YI82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3<*(RP@9G5Z>GD*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(E5W
M86=I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S(*;7-G:60@(D%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")0;WIW\VP@;F$@=VEE;&4@
M861R97/S=R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@
M(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C0P.`IM<V=I9"`B
M06QR96%D>2!E>&ES=',B"FUS9W-T<B`B2G6_(&ES=&YI96IE(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@
M3&]G:6XB"FUS9W-T<B`B06QT97)N871Y=VYY(&QO9VEN($E-4U`B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA='EW;GD@:&%SLV\@24U34"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3$*;7-G:60@(D%L=&5R;F%T
M92!)35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T>7=N82!N87IW82!U
MOWET:V]W;FEK82!)35-0(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(D%L=&5R;F%T>7=N>2!A9')E<R!E;6%I;"(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,30R"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S
M(@IM<V=S='(@(E1W\VH@861R97,@92UM86EL.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I
M9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T>7=N>2!T96MS
M=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM
M<V=S='(@(EIO<W1ALV$@<&]D86YA(&YI97!R87=I9+-O=V$@=V%R=&^VYBXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34T"B,L(&9U>GIY
M"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R
M(")0<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(D%N9V]L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I
M;&QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!
M;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;FEM;W=E(%!R;WAY(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*
M;7-G<W1R(")/9'!O=VEE9+PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@
M(D%N=&%R:W1Y9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE
M;&PN<&AP.C,U(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I
M;VXB"FUS9W-T<B`B07!L:6MA8VIA(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$S.0IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@
M(D%P;&EK86-J82!G;W1O=V$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS
M9VED(")!<'!R;W9E(@IM<V=S='(@(EIA='=I97)DO"(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX,S`*;7-G:60@(D%P<')O>&EM871E(%-I
M>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,W-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(DMW:65C:67Q(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`B5VEE;&MOMN8@87)C:&EW=6TB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DYA>G=A(&%R
M8VAI=W5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/R(*;7-G<W1R(")#>GD@;F$@<&5W;F\@8VAC97-Z('5S=6ZQYB!TZB!R
M96=UL^H_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M.CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B
M"FUS9W-T<B`B0WIY(&YA('!E=VYO(&-H8V5S>B!U<W5NL>8@=.H@<F5G=;/J
M/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1Y;F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!<FUE;FEA(@IM<V=S='(@(D%R;65N:6$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS
M9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q-PIM<V=I9"`B07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_(@IM<V=S='(@(E!O<')OMB!O('!O='=I97)D>F5N:64@<')Z
M960@=WEK;VYA;FEE;2!O<&5R86-J:2!C>6ML:6-Z;GEC:#\B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$Q,@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S4*;7-G:60@(D%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C,X"FUS9VED(")!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HY.`IM<V=I9"`B071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-"!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R
M(")!=')Y8G5T>2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS.#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R
M"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B4VEE<G!I9?$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T
M<F%L:6$B"FUS9W-T<B`B075S=')A;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G
M<W1R(")!=7-T<FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ
M-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($YI92!Z;F%L97II
M;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&EM87`N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED
M(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($YI92!Z;F%L97II;VYO('=Y;6%G
M86YE9V\@<F]Z<WIE<GIE;FEA(&EM87`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@3FEE
M('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@1E10+B!3:V]M
M<&EL=6H@4$A0('H@(@HB<&%R86UE=')E;2`M+65N86)L92`N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q
M=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VEM87`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA
M($E-05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@
M(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VMR8C4Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE
M9V\@<F]Z<WIE<GIE;FEA(&MR8C4N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z-3@*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($YI92!Z;F%L
M97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA($Q$05`N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(EIA<&ES>F%N
M:64@<WIK:6-U(&YI975D86YE+B!397)W97(@>G=R\V-ILR!O9'!O=VEE9+PZ
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C(R"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE('5D8;-O('-IZB!U<W5NL>8@
M=;]Y=&MO=VYI:V$@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.:64@=61ALV\@
M<VGJ('5A:W1U86QN:>8@=;]Y=&MO=VYI:V$@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@
M3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@34-!3"XB
M"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]S;6)A=71H.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N
M96=O(')O>G-Z97)Z96YI82!S;6)A=71H+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960B"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@
M<VGJ(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B
M57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ+B`E<R(*"B,Z(&QI
M8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")5=VEE
M<GIY=&5L;FEE;FEE(&]D<GIU8V]N92!P<GIE>B!S97)W97(@4D%$2553+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C@*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")5=VEE<GIY=&5L;FEE
M;FEE(&1O('-E<G=E<F$@1E10(&YI92!P;W=I;V2S;R!S:>HN(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHX,PIM<V=I9"`B079A:6QA8FQE(&9I
M96QD<SHB"FUS9W-T<B`B1&]S=.IP;F4@<&]L83HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(D%Z97)B96IDOV%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B5WEM\W=K
M:2!"3T9((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")4LV\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S
M"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(DMO;&]R('2S82(*
M"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R
M8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(EJS92!H87.S;R!+97)B97)O<V$N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K
M97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B6K-A(&YA>G=A('6_>71K;W=N
M:6MA($ME<F)E<F]S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B5WES<'D@
M0F%H86UA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR86IN(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X
M-3DM,3,I(@IM<V=S='(@(D)ALW1Y8VMI("A)4T\M.#@U.2TQ,RDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L861E<WHB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B
M861O<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(D)A<V5L:6YE
M(@IM<V=S='(@(D]D<GIU8V]N92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B
M0FEALV]R=;8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G
M<W1R(")"96YI;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D>2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS
M9W-T<B`B1&%T82!U<F]D>F5N:6$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(X"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB
M)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@
M(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(E5S=&%W:65N:6$@8FQO:W4B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K
M(%1Y<&4B"FUS9W-T<B`B5'EP(&)L;VMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"B,L(&9U>GIY"FUS9VED(")";VQD
M(@IM<V=S='(@(E1R9;;F(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VQI
M=VEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y,0IM<V=I9"`B
M0F]O:VUA<FMS(@IM<V=S='(@(EIA:[-A9&MI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM
M<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H
M:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R
M9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$B"FUS9W-T<B`B0F^V;FEA(&D@2&5R8V5G;W=I;F$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B3V)A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T
M;VTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F]U=F5T($ES;&%N9"(*
M;7-G<W1R(")7>7-P>2!/=V-Z92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"
M<F%Z>6QI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G6S9V%R:6$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"B,L(&9U
M>GIY"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(E=Y8FEE<GH@;&ES
M=.HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S@S"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED
M(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E>S8;9C:7=OMF-I(&MO
M;?-R:VDN+BX@*%]C*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3`*(RP@9G5Z>GD*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP
M;&5T960N(@IM<V=S='(@(EIAL[%C>FYI:R!N:64@>F]S=&&S('IN86QE>FEO
M;GDN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30X"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,T"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#
M86UB;V1I82(*;7-G<W1R(")+86UB;V2_82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM
M<V=S='(@(DMA;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A
M;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB
M3FEE('5D8;-O('-IZB!Z<F5S971O=V'F(&AA<[-A(&%U=&]M871Y8WIN:64L
M('-K;VYT86MT=6H@<VGJ('H@(@HB861M:6YI<W1R871O<F5M+B(*"B,Z(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q
M8WIE;FEA('-IZB!Z('-E<G=E<F5M($E-05`Z("5S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A
M(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI
M;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3<*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ-PIM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(D%N=6QU:B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`B06YU;'5J(')A<&]R="!O('!R;V)L96UI92(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HR-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T
M92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UOOVYA('-K87-O=V'F('!L
M:6MU(%PB)7-<(B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@
M82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").:64@=61ALV\@<VGJ
M('IN86QEO.8@:V%T86QO9W4@='EM8WIA<V]W96=O+B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U
M="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z,C4R"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UOOVYA('-K
M87-O=V'F(&MA=&%L;V=U(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]$871A5')E
M92YP:'`Z,3$R(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4X-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N(@IM<V=S='(@(DYI92!M;[]N82!S:V%S;W=AYB!K871A
M;&]G=2!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU
M,3(*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!6
M97)D92(*;7-G<W1R(")7>7-P>2!::65L;VYE9V\@4')Z>6RQ9&MA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")/<&-J92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A
M;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G;W)I92!I(&]Z;F%C>F5N:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@HC
M+"!F=7IZ>0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B5WES<'D@
M4V%L;VUO;F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")496PN(&MO;2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B5[-AMF-I=V^V
M8VD@:V]M\W)K:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")7LV&V8VEW
M;[9C:2!K;VWS<FMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N
M92(*;7-G<W1R(")496PN(&MO;2XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0V5L
M='EC:VD@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D-E
M;G1E<B(*;7-G<W1R(")3='?S<GHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,B"FUS9W-T<B`B4F5P=6)L:6MA(*9R;V1K;W=E:B!!9G)Y:VDB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`BIG)O9&MO=V]E=7)O<&5J
M<VMI("A)4T\M.#@U.2TR*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(E-Z
M8WIE9_.S>2!C97)T>69I:V%T=2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")7
MLV&V8VEC:65L(&-E<G1Y9FEK871U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC
M:65S(@IM<V=S='(@(E-Z8WIE9_.S>2!C97)T>69I:V%T=2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B
M0VAA9"(*;7-G<W1R(")#>F%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PIM<V=I
M9"`B0VAA;F=E(@IM<V=S='(@(EIM:67Q(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B6FUI9?$@:6UIZBP@;F%Z=VES
M:V\@:2!A9')E<RP@:W3S<GD@:6YN:2!W:61ZL2!W(%1W;VEC:"!L:7-T86-H
M(&5M86EL+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H87(B"FUS9W-T<B`B
M2V%L96YD87)Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G
M<W1R(")3<')A=V2\(&QI;FLN+BXB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#:&5C:R!T:&4@8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+B(*;7-G<W1R("):87IN86-Z('!O>GEC:NH@9&QA(&MT\W)E:B!C
M:&-E<WH@=WEK;VYAYB!O<&5R86-JZBXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R
M(")#:&EL92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(D-H:6YY(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@
M(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E!O9&%J(&AA<[-O(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A
M('5S97)N86UE(@IM<V=S='(@(E!O9&%J(&YA>G?J('6_>71K;W=N:6MA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y,`IM<V=I9"`B0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")7>6)I97)Z('-P;W/S8B!W
M>;9W:65T;&%N:6$@9&%T.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T
M('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(E=Y<W!A($)OOV5G;R!.
M87)O9'IE;FEA(@H*(SH@;&EB+U9&4RYP:'`Z-C$U(&QI8B].970O4TU3+G!H
M<#HR.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("):8;.Q8WIN:6L@;FEE
M('IO<W1ALR!Z;F%L97II;VYY+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G
M<W1R(")+86QE;F1A<GHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHW
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@
M)7,B"FUS9W-T<B`B6F1A;&YE('-E<G=E<GDB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S
M97(B"FUS9W-T<B`B2V%L96YD87)Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@
M3&%T92(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@IM<V=I9"`B0VQI8VL@=&\@0V]N
M=&EN=64B"FUS9W-T<B`B2VQI:VYI:B!B>2!K;VYT>6YU;W=AYB(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC
M:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I
M9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(EIA;6MN:6H@;VMN;R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C0T"B,L(&9U>GIY"FUS9VED(")#;&]U9',B
M"FUS9W-T<B`B6F%M:VYI:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$V"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R;'DB
M"FUS9W-T<B`B2W+S=&MI92!S=')E<WIC>F5N:64B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B
M0VQO=61Y(@IM<V=S='(@(DMR86HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@
M27-L86YD<R(*;7-G<W1R(")7>7-P>2!+;VMO<V]W92`H2V5E;&EN9V$I(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHT"FUS9VED(")#;VQL
M87!S92!3:61E8F%R(@IM<V=S='(@(E-C:&]W86H@<&%S96LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"B,L
M(&9U>GIY"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("):=VGQ
M(&9O;&1E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEA(@H*
M(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(DMO;&]R(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y.2!L:6(O2&]R9&4O0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S`P"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-S(@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHU,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHU,@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV.`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX-@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(E=Y8FEE<GH@
M:V]L;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@T-0IM<V=I9"`B0V]L
M;W5R('-E;&5C=&EO;B(*;7-G<W1R(")7>6+S<B!K;VQO<G4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]L<SHB"FUS9W-T<B`B6G=I\2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.30W"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(E1Y
M='6S>2!K;VQU;6XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@V
M"B,L(&9U>GIY"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B5'?S<GHB"@HC.B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B
M2V]M96YD82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R(")0;W>S;VMA(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#`R"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DMO;65N
M=&%R>B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED
M(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G
M<W1R(")+;VUO<GDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z(&QI
M8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D92]497AT+T9I
M;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I
M;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VUP;W-E($UE<W-A
M9V4@*"5S*2(*;7-G<W1R(")3='?S<GH@=VEA9&]M;[;F("@E<RDB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G
M<W1R(")+;VUP=71E<GDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@U"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B5V%R
M=6YK:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD
M:71I;VYS(@IM<V=S='(@(E=A<G5N:VDB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,T"FUS9VED(")#
M;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N9FEG=7)E("5S(@IM<V=S='(@(E-K;VYF:6=U<G5J("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-PIM<V=I9"`B0V]N9FER
M;2!087-S=V]R9"(*;7-G<W1R(")0;W1W:65R9+P@:&%SLV\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B1&5M;VMR871Y8WIN82!2
M97!U8FQI:V$@2V]N9V\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")0;[.Q8WIE;FEE
M(&YI92!P;W=I;V2S;R!S:>HN(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(E!OL[%C
M>F5N:64@;FEE('!O=VEO9+-O('-IZCH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-S<Y"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D]D;?-W:6]N;R!P;[.Q8WIE
M;FEA(&1O('!U8FQI8WIN96=O('-E<G=E<F$N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-S@Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I(@IM<V=S='(@(D]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI
M8WIN96=O('-E<G=E<F$N(%!O=_-D.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C<V,@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E
M<G=E<F5M($944"XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K='D@>F]S
M=&&S>2!P;VUYMFQN:64@9&]D86YE(&1O(%1W;VIE:B!K<VFQOVMI(&%D<F5S
M;W=E:BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM
M<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("):87=A<G1OMN8@7"(E<UPB(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O;G1I
M;G5E(@IM<V=S='(@(DMO;GEN=75J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM
M<V=S='(@(E=Y<W!Y($-O;VMA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,R"B,L(&9U>GIY"FUS9VED(")#;V]K:64B"FUS9W-T<B`B5'?S<GHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B4VMO<&EU:B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(E-K;W!I=6H@=WEB\W(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34V"FUS9VED
M(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3FEE
M('5D8;-O('-IZB!Z87-Z>69R;W=AYB`H4$=0*2!W:6%D;VUOMF-I+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,S,*;7-G:60@(D-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R(").:64@=61ALV\@<VGJ('!O
M9'!I<V'F("A01U`I('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP
M="!M97-S86=E+B(*;7-G<W1R(").:64@=61ALV\@<VGJ('IA<WIY9G)O=V'F
M("A3+TU)344I('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+B(*;7-G<W1R(").:64@=61ALV\@<VGJ('!O9'!I<V'F("A3+TU)344I
M('=I861O;6^V8VDN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@
M;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HQ,3`*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@3$1!4"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@
M8F%L86YC92X@)7,B"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF("5S+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG
M($944#H@)7,B"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z
M('-E<G=E<F5M(%PB)7-<(B!P;W!R>F5Z($944#H@)7,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U
M<F]W86YE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,#4*;7-G
M:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(").:64@
M=61ALV\@<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!01U`N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R
M>7!T(%,O34E-12!D871A+B(*;7-G<W1R(").:64@=61ALV\@<VGJ(&]D<WIY
M9G)O=V'F(&1A;GEC:"!3+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")(;W)D92!N
M:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R
M;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(").:64@;6^_;F$@;W1W
M;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HY,S@*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").:64@=61ALV\@<VGJ('5S
M=&%L:>8@861R97-U(&4M;6%I;"!O9&)I;W)C>2XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").
M:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@
M36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-#8*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM
M<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?
M5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z-C@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N
M82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q
M,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER
M96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UOOVYA('5T=V]R>GGF
M(&MA=&%L;V=U(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C<P.`IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!U>GES:V'F
M('H@<V5R=V5R82!K;'5C>F$@<&)U;&EC>FYE9V\N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!O='=O<GIYYB!<(B5S7"(@
M9&\@>F%P:7-U+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@
M(DYI92!M;[]N82!O='=O<GIYYB`E<RXB"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(").:64@
M;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@:V%T
M86QO9W4@7"(E<UPB(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM
M<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?
M5&%S:R`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS
M9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@
M<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS
M(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P
M.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@Y"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I
M;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DAO<F1E
M(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF
M:6=U<F]W86YE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DAO<F1E
M(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B2&]R9&4@;FEE(&IE
M<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S
M;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DYI
M92!U9&&S;R!S:>H@<VMA<V]W86YI92!K871A;&]G=2!<(B5S7"(N(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DAO<F1E(&YI92!J97-T
M('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DAO
M<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B!<(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@
M36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R
M(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S
M('!R>F5S>G5K:7=A;FEA('H@<V5R=V5R96T@3$1!4"XB"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS
M9W-T<B`B3FEE('5D8;-O('-IZB!S:V%S;W=AYB!P;&EK=2!<(B5S7"(N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT
M96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").:64@
M;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO
M;F9I9W5R;W=A;F4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U.`IM
M<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B3FEE('5D8;-O
M('-IZB!Z;F%L9;SF('!A<VMA($UO>FEL;&DN(%5P97=N:6H@<VGJ+""_92!J
M97-T(&]N(&]T=V%R='DN(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*(E6_>71K;W=N
M:6L@7"(E<UPB('!R87=I9+-O=V\@>F1E9FEN:6]W8;,@<')A=V$@9&]S=.IP
M=2!D;R!F;VQD97)A(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30R,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(E=Y
M;&]G=6HB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I
M9"`B0V]U;G1R>2(*;7-G<W1R(")+<F%J(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(W,`HC+"!F=7IZ>0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R
M("*L<O-DLV$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDW"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#$*;7-G:60@(D-R96%T92(*;7-G<W1R(")3
M='?S<GHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C<*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B
M4W1W\W)Z(&QI;FLB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.CDS"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(E-T
M=_-R>B!N;W>Q(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDR"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T
M<B`B571W\W)Z(&YO=WD@9F]L9&5R(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3,V(&QI8B](;W)D92]097)M<R]522YP:'`Z,C$T"B,L(&9U>GIY"FUS
M9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D1O;7FV;&YE('5P
M<F%W;FEE;FEA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,CD*;7-G:60@
M(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R(").=6UE<B!K87)T>2!K<F5D
M>71O=V5J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0VAO<G=A8VIA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S
M='(@(D]B96-N>2!C>F%S(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB
M+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T
M<B`B3V)E8VYY(&-Z87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E
M;G0@55),(&ES(@IM<V=S='(@(D]B96-N>2!C>F%S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!796%T:&5R
M(@IM<V=S='(@(D]B96-N>2!C>F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!C;VYD:71I
M;VXZ("(*;7-G<W1R(")/8F5C;GD@:V%T86QO9SH@)7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D]B96-N>2!C>F%S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM
M<V=S='(@(E-P97)S;VYA;&EZ=6H@>F%D86YI82!U<G5C:&%M:6%N92!P<GIY
M(&QO9V]W86YI=2!D;R`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R
M(")7>71N:6HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,U"B,L(&9U>GIY"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S
M='(@(E-K87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*
M;7-G<W1R(")#>7!R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I
M9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E)E<'5B;&EK82!#>F5C:"(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C,@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*
M(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB
M"FUS9W-T<B`B0V]D>FEE;FYI92(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV
M-0HC+"!F=7IZ>0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")$
M871A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S.3@@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`B
M1&%T82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(D]T<GIY
M;6%N92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`V"B,L(&9U>GIY"FUS
M9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S=6H@=WEB<F%NL2!T
M;[]S86UOMN8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@P
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3`*(RP@9G5Z>GD*;7-G
M:60@(D1A>2(*;7-G<W1R(")#;V1Z:65N;FEE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED(")$
M95]L971E($-O;'5M;B(*;7-G<W1R(")?57-U\2!K;VQU;6[J(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM
M<V=S='(@(D=R=61Z:67Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B1&5C
M:6UA;"!N=6UB97)S(@IM<V=S='(@(D=R=61Z:67Q(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I
M9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(E)A<&]R='5J(&IA:V\@;FEE
M<WIK;V1L:7=Y(@H*(SH@;&EB+W!R969S+G!H<#HQ,3$@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ.#<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T
M<B`B1&]M>;9L;GDB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHX,0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")$
M;VUYMFQN>2!K;VQO<B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.3$*
M;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B1&]M>;9L;F$@=&^_
M<V%M;[;F(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$Y(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,3DV"FUS9VED(")$969A=6QT(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HQ.3<*;7-G:60@(D1E9F%U;'0@<&5R;6ES<VEO;G,B
M"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D1E9FEN:71I;VYS(@IM
M<V=S='(@(E!ELVYY(&]P:7,Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.34@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HS,34*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,S(@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.2!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V1E;&5T92YI;F,Z,3,*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")5<W7Q(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR,3<*;7-G:60@
M(D1E;&5T92!'<F]U<"(*;7-G<W1R(")5<W7Q($=R=7#J(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HV,R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W
M"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")5<W7Q('5P<F%W
M;FEE;FEA(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS
M"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E5S
M=?$@:2!W>6-Z>;;F('=I861O;6^V8VDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@
M8V5L;"(*;7-G<W1R(")5<W7Q(&MO;?-R:^HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@8V]L=6UN(@IM<V=S='(@(E5S=?$@:V]L=6UNZB(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,30X"B,L(&9U>GIY"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E1W\VH@861R97,@92UM
M86EL.B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3`@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B4VMA<W5J('5P<F%W
M;FEE;FEA(&1L82!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B
M4VMA<V]W8>8@=7!R87=N:65N:6$@9&QA(%PB)7-<(B!I('=S>GES=&MI92!P
M;V0M=7!R87=N:65N:6$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G
M<W1R(")5<W7Q('=I97)S>B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I
M9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R(")3:V%S=6H@=WEB<F%NL2!T;[]S86UOMN8B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B57-U
M\2!A:W1U86QNL2!K;VQU;6[J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@<F]W(@IM<V=S='(@(E5S=?$@86MT=6%L;GD@=VEE<G-Z(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT.`IM<V=I9"`B1&5L971E('1H
M:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T
M<B`B4VMA<V]W8>8@=&\@=7!R87=N:65N:64@:2!W<WIY<W1K:64@<&]D+75P
M<F%W;FEE;FEA/R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF
M(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,L
M(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(E5S=?$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$96YM87)K(@IM<V=S='(@(D1A;FEA(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3$P('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q-"!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HQ,C0*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(D]P:7-Z('!R;V)L96TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@
M(E!ELVYY(&]P:7,Z(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E-Z8WIE
M9_.S>2!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D;6EN:7-T<F%T;W)A+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*(RP@9G5Z>GD*;7-G
M:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D1Z:6&S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X
M"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS
M9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S
M='(@(DMA=&%L;V<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4X"FUS
M9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(E=YMG=I971L
M(&-Z87,@=R!F;W)M86-I92`R-"UG;V1Z:6YN>6T_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T
M<B`B57-T87=I96YI82!W>6=LL61U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C@X"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D
M(&9O<F5C87-T(@IM<V=S='(@(E5S=&%W:65N:6$@=WEG;+%D=2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@
M9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B57-T87=I96YI82!W>6=LL61U(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,38*(RP@9G5Z>GD*;7-G:60@(D1I
M<W!L87D@9F]R;6%T(@IM<V=S='(@(E5S=&%W:65N:6$@=WEG;+%D=2(*"B,Z
M(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B4F]Z;6EE<WIC>F5N
M:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$OVEB=71I(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,Q-0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(").:64@:V%S=6HB
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C0*;7-G:60@(D1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(D)R
M86L@8F5Z<&^V<F5D;FEE9V\@9&]S=.IP=2!D;R!M86EN=&5N86YC92YP:'`B
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ.2!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ.0IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI
M;FEK82`H5W-P\VQN;W1A($1O;6EN:6MI*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!2
M97!U8FQI8R(*;7-G<W1R(")$;VUI;FEK86YA("A297!U8FQI:V$@1&]M:6YI
M:V'Q<VMA*2(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#$*
M;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(J9C:;%G;FEJ(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$;W=N;&]A9"`E<R(*;7-G<W1R("*F8VFQ9VYI:B`E<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C4*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3`X"FUS9VED(")$<F]P(&1O=VX@;&ES
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G
M:60@(D1R=6=S(@IM<V=S='(@(DYA<FMO='EK:2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0P,@IM<V=I9"`B12U-86EL(@IM<V=S='(@(D4M;6%I
M;"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B
M"FUS9W-T<B`B16MW861O<B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDT
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET(@IM<V=S='(@
M(D5D>6-J82(*"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@HC+"!F=7IZ>0IM<V=I9"`B161I="!"
M;&]C:R(*;7-G<W1R(")%9'ET=6H@8WIA<FZQ(&QI<W3J(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.#@@861M:6XO9W)O=7!S+G!H<#HR,38*;7-G:60@(D5D
M:70@1W)O=7`B"FUS9W-T<B`B57-U\2!'<G5PZB(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-C(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-@IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(EIM:67Q('5P<F%W;FEE;FEE
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I
M="!097)M:7-S:6]N<R(*;7-G<W1R("):;6EE\2!U<')A=VYI96YI82(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B6FUI9?$@
M=7!R87=N:65N:6$@9&QA("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B6FUI9?$@
M=7-T87=I96YI82!D;&$Z(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`T
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C@P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`B6FUI9?$@=7!R87=N:65N:6$@9&QA("5S(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("):;6EE\2!U<')A=VYI96YI82!D
M;&$@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*(RP@9G5Z>GD*
M;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")/<&-J92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T
M(@IM<V=S='(@(D5G:7!T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R
M(")386QW861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*
M;7-G:60@(D5M86EL(@IM<V=S='(@(D5M86EL(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0P
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%D<F5S(&5M86EL(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C0*;7-G:60@(D5M86EL(&%D9')E
M<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")!9')E<WD@96UA:6P@;75S>K$@
M9&\@<VEE8FEE('!A<V]W8>8N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M.3`*(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(DAA<[-O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(X,`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(D5M;W1I:V]N
M>2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS
M9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")0=7-T82!W:6%D;VUOMN8N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(X"FUS9VED(")%;7!T
M>2!R97-U;'0N(@IM<V=S='(@(D)R86L@<F5Z=6QT873S=RXB"@HC.B!L:6(O
M2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(D5M
M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")/<'+SOVYI:B!F;VQD97(@:V]S
M>F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,U"FUS9VED(")%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$P"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R(")7L[%C>GGF(&UE;G4@:V]N=&5K<W1O=V4@<&]D('!R87=Y;2!P
M<GIY8VES:VEE;2!M>7-Z>3\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y
M-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q,`HC+"!F=7IZ>0IM<V=I9"`B16YD
M('EE87(B"FUS9W-T<B`B4F]Z=VGQ('!A<V5K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%
M9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q
M,PIM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM
M86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I
M;F5A(@IM<V=S='(@(D=W:6YE82!2\W=N:6MO=V$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A
M(@IM<V=S='(@(D5R>71R96$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<@<V5R=FEC97,O
M<&]R=&%L+VEN9&5X+G!H<#HW.0IM<V=I9"`B17)R;W(B"FUS9W-T<B`B0K.Q
M9"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"B,L
M(&9U>GIY"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S
M='(@(D)R86L@9F]L9&5R=2!Z(&YO=WEM:2!W:6%D;VUOMF-I86UI(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB
M+B(*;7-G<W1R(")"L[%D('!R>GD@>F%P:7-I92!<(B5S7"(N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M17-T;VYI82(*;7-G<W1R(")%<W1O;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS
M9W-T<B`B171I;W!I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@HC
M+"!F=7IZ>0IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5S=&]N:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S
M='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S$*;7-G
M:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B0V\@:V&_9&4@,34@;6EN
M=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED(")%=F5R
M>2`R(&UI;G5T97,B"FUS9W-T<B`B0V\@:V&_9&4@,B!M:6YU='DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(X(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B0V\@:V&_
M9&4@,S`@<V5K=6YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")%=F5R>2`U(&UI;G5T
M97,B"FUS9W-T<B`B0V\@:V&_9&4@-2!M:6YU="(*"B,Z(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@
M(D-O(&MAOV1E('IA;&]G;W=A;FEE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S,@IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D-O(&MA
MOV1E('#SLR!G;V1Z:6YY(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R
M.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`B0V\@:V&_9+$@;6EN=73J(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z,C@*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G
M<W1R(")0<GIY:[-A9&]W92!W87)T;[9C:3HB"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R."!A9&UI;B]P:'!S:&5L
M;"YP:'`Z.#$*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B5WEK;VYA:B(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,Y-`IM<V=I9"`B17AP86YD
M(@IM<V=S='(@(E)O>G=I\2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A
M<BYI;F,Z,S$*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(E)O>G=I
M\2!P87-E:R(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`HC
M+"!F=7IZ>0IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(E=Y:V]N86HB
M"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X
M<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Q"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-S8*(RP@9G5Z>GD*;7-G:60@(D5X<&]N96YT(@IM<V=S
M='(@(D5K<W!O<G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED(")&1R!#;VQO<B(*
M;7-G<W1R(")$;VUYMFQN>2!K;VQO<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#`*(RP@9G5Z>GD*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B
M"FUS9W-T<B`B5V=R>7=A;FEE('!L:6OS=R!N:64@:F5S="!O8G.S=6=I=V%N
M92XB"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L+G!H<#HR,38*(RP@9G5Z>GD*
M;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@>FUI86YY('5S=&%W:67Q+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C$P,`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI
M82!S:>H@>B!S97)W97)E;2!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M
M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S
M:>H@>B!S97)W97)E;2!,1$%0+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!K;W!I;W=A;FEA('H@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@:V]P:6]W86YI82!D;R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<V%S;"YP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C<F5A
M=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S
M(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`@)7,N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C8T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!P<GIE;F]S
M>F5N:6$@9&\@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$X"B,L(&9U>GIY"FUS9VED(")&86ER(@IM<V=S='(@
M(D]D(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S
M='(@(D9A;&ML86YD>2`H36%L=VEN>2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(E=Y<W!Y($]W8WIE(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z
M,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B0K.Q9"!K<GET>6-Z
M;GDZ("(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W
M"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-S4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("),=71Y
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI
M:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q.0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"B,L(&9U>GIY"FUS
M9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("));7!O<G0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`HC+"!F=7IZ>0IM<V=I
M9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("));7!O<G0B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DT-0IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEDOVDB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-#8*;7-G:60@(D9I;&4@36%N86=E<B(*
M;7-G<W1R(")-96YE9+]E<B!P;&EK\W<B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I
M9"`B1FEL92!.86UE(@IM<V=S='(@(DYA>G=A('!L:6MU(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Y.30*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(E=Y8O-R('!L:6MU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T.#@*
M;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E=G<GEW86YI92!P;&EK=2(*
M"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-C,*;7-G:60@(D9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")79W)Y=V%N:64@<&QI:_-W
M(&YI92!J97-T(&]B<[-U9VEW86YE+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<GDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FQA;F1I82(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(D9I<G-T($AA;&8B"FUS
M9W-T<B`B26UIZB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(D9I<G-T(%%U87)T97(B
M"FUS9W-T<B`B26UIZB(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$T"FUS9VED(")&
M;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS
M9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W
M(&QI8B]61E,O<W%L+G!H<#HQ-C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R(")5OWEC:64@
M9F]L9&5R=2!N:64@:F5S="!A:W1Y;G=E+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*(RP@9G5Z>GD*;7-G:60@(D9O
M;G0@0V]L;W(B"FUS9W-T<B`B1&]M>;9L;GD@:V]L;W(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B2F5D>F5N
M:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E=Y;6%G86YA(&IE
M<W0@;V)SLW5G82!I1G)A;65S*'"S>7=A:K%C>6-H(')A;65K*2!P<GIE>B!P
M<GIE9VRQ9&%R:^HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`HC+"!F
M=7IZ>0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B57-T87=I96YI
M82!W>6=LL61U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Q
M"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*
M(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.3@*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("):87!O
M;6YI8;-EMB!H87.S83\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`Y"B,L(&9U>GIY"FUS9VED(")&;W)M<R(*;7-G<W1R(")5=V%G:2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0HC+"!F=7IZ>0IM<V=I9"`B1F]R
M='5N92(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E5W
M86=I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS
M9VED(")&;W)T=6YE<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R(")5=V%G:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*
M(RP@9G5Z>GD*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*(RP@9G5Z>GD*;7-G:60@(D9O
M<G=A<F1S(@IM<V=S='(@(E!R>F5K8;\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"B,L(&9U>GIY"FUS9VED(")&<B(*
M;7-G<W1R(")/9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G
M<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R
M(")&<F%N8VIA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G
M:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R
M96YC:"!'=6EA;F$B"FUS9W-T<B`B1W5J86YA($9R86YC=7-K82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!O;&EN97IJ82!&<F%N8W5S
M:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G
M<W1R(")&<F%N8W5S:VEE(%1E<GET;W)I82!0;[-U9&YI;W=E(&D@06YT87)K
M='EC>FYE(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B3V0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-#@*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-`HC+"!F
M=7IZ>0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D]D(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U
M;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&6S;GD@;W!I<R(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HX,B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3@Q"FUS9VED
M(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHS.0HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM
M<V=S='(@(E1W;VIE(&EM:>HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")(;W)D
M92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HQ,`IM<V=I9"`B1V5N97)A
M=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")'97)M86YY(@IM<V=S='(@(DYI96UC>2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA
M(@IM<V=S='(@(D=H86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDT
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I
M8G)A;'1A<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U"B,L
M(&9U>GIY"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DUE;F5DOV5R('!L
M:6OS=R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")'
M;R(*;7-G<W1R("))9+PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*
M;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(E=Y<WIU
M:VEW87)K82!';V]G;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(P"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G
M:60@(D=R965C92(*;7-G<W1R(")'<F5C:F$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-0HC+"!F=7IZ>0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I
M(@IM<V=S='(@(J9R;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,BDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)E;FQA;F1I82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R
M96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3<P"B,L(&9U>GIY"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")!9&UI;FES=')A8VIA(@H*(SH@;&EB+TAO<F1E+T=R;W5P+G!H<#HU
M.`IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`Q(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C<W"B,L(&9U>GIY"FUS9VED(")'<F]U<"!P97)M:7-S
M:6]N<R(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$W-B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!Y(&1Y
M<VMU<WEJ;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=W861E;'5P
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M
M86QA(@IM<V=S='(@(D=W871E;6%L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C<@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR,#4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`HC+"!F
M=7IZ>0IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1&]M>;9L
M;F4@=7!R87=N:65N:6$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C@@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#8*(RP@9G5Z>GD*;7-G:60@(D=U
M97-T('!E<FUI<W-I;VYS(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Q-PIM<V=I9"`B1W5E
M<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=VEN
M96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W=I;F5A($)I
M<W-A=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U:F%N82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-
M3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:'1T<"YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!N
M:64@<&]W:6]DLV\@<VGJ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET
M:2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,@HC+"!F=7IZ>0IM
M<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)Y=&T@<&]D<&ES
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R
M"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,S$*(RP@9G5Z>GD*;7-G:60@
M(DAE861E<B(*;7-G<W1R(").86>S\W=K:2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(E=Y<W!Y($AE87)D
M(&D@36-$;VYA;&1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS
M9W-T<B`B57=A9VDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@HC+"!F
M=7IZ>0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(J9R
M;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,BDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"B,L(&9U>GIY
M"FUS9VED(")(96EG:'0B"FUS9W-T<B`B5WES;VMI(@H*(SH@;&EB+TAO<F1E
M+TAE;'`N<&AP.C$W.2!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN
M8SHS"FUS9VED(")(96QP(@IM<V=S='(@(E!O;6]C(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U
M<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S-S,*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")0;VUO8R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B2&5M
M:7-P:&5R92(*;7-G<W1R(")0;VUO8R(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$W('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(E=Y<V]K:2(*"B,Z(&QI8B](;W)D
M92](:7-T;W)Y+G!H<#HS,C$*;7-G:60@(DAI<W1O<GD@96YT<GD@;F%M97,@
M;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R
M+FEN8SHT"FUS9VED(")(;U]M92(*;7-G<W1R(")?4W1A<G0B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")7871Y
M:V%N("A3=&]L:6-A($%P;W-T;VQS:V$I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M-#,U"FUS9VED(")(;VUE(@IM<V=S='(@(E!O8WJQ=&5K(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G
M<W1R(")!9')E<R!D;VUO=WDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496PN
M(&1O;2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9TMO;F<B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@
M(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,C`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-
M3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B561A
MLV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,C<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,B"FUS9W-T<B`B561ALV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU
M+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#$S"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,3(P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!59&&S;R!S:>H@=7-U;K'F("5S(%PB)7-<(B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES960@)7,@
M7"(E<UPB(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB('H@<WES
M=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R
M9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE
M("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HT.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F
M;W(@;V)J96-T("5S(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB
M('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,#4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B561ALV\@<VGJ('5S
M=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z-#4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F
M('1Y<&4@)7,B"FUS9W-T<B`B561ALV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S
M>7-T96UU+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$U,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(E5D8;-O('-IZB!U
M<W5NL>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$R.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R
M(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HS,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R
M(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@
M<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(X"FUS9VED(")(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X."!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-PIM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B5^IG<GDB"@HC.B!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP
M:'`Z,C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")0;[.Q8WIE;FEE(&YI
M92!P;W=I;V2S;R!S:>HZ("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N
M<&AP.C(Q-"!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@<VGJ
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(E5W:65R>GET96QN:65N:64@;FEE('!O=VEO9+-O('-IZBX@
M)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Q-PHC+"!F=7IZ>0IM<V=I
M9"`B25`@061D<F5S<R(*;7-G<W1R(")!9')E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+VEP8F%S:6,N<&AP.C<W"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@7")-971A<EPB(&YI92!J
M97-T(&1O<W3J<&YY+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP
M.C@Y"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R(")";&]K(%PB365T87)<(B!N:64@
M:F5S="!D;W-TZG!N>2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,CD*(RP@9G5Z>GD*;7-G:60@(DE?;G-E<G0@4F]W($)E
M9F]R92(*;7-G<W1R(")7<')O=V%DO"!K;'5C>B!T=71A:B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M26-E;&%N9"(*;7-G<W1R("))<VQA;F1I82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C@*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B5'EL:V\@
M:6MO;GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Y"FUS9VED("))
M8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;GD@>B!T96MS=&5M(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,@IM<V=I9"`B261E;G1I='DG<R!N
M86UE.B(*;7-G<W1R(").87IW82!T;[]S86UOMF-I.B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HU.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#0W"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A
M<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ-3@*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S
M86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A
M9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(DEM86=E(%!R979I
M97<Z(@IM<V=S='(@(E!O9&=LL60@<&]C>G1Y(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PHC+"!F=7IZ>0IM
M<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D=R869I:V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B1W)A9FEK82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V,@HC+"!F=7IZ>0IM
M<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(E=G<GEW86YI92!P;&EK=2(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B1W)A9FEK82(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$P('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$P"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-3<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E
M<"`E9"(*;7-G<W1R("));7!O<G1O=V%N92!P;VQE.B`E<R(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C(P"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1O=V%N92!P;VQE
M.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S,*;7-G:60@
M(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T;W=A;F4@<&]L83HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@;&EB+TAO<F1E+T-O
M;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(E!R;W-ZZB!P;V1AYB!N
M87IWZB!UOWET:V]W;FEK82!I(&AA<[-O(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM
M<V=S='(@(E)A<&]R='5J(&IA:V\@;FEE<WIK;V1L:7=Y(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M;F1I82(*;7-G<W1R("));F1I92(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$T,2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD
M:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*
M;7-G<W1R("));F1O;F5Z:F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-@HC+"!F=7IZ>0IM<V=I9"`B
M26YF;W)M871I;VXB"FUS9W-T<B`B5'=O:F4@:6YF;W)M86-J92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3@*(RP@9G5Z>GD*;7-G:60@
M(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN
M9F]R;6%C:F4@;R!O<V]B:7-T>6T@:VQU8WIU('!U8FQI8WIN>6TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S
M='(@(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("))
M;G-E<G0@26UA9V4B"FUS9W-T<B`B5VML96H@;V)R87IE:R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*(RP@9G5Z>GD*
M;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R(")0<GIY:[-A9&]W92!W87)T
M;[9C:3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(U"B,L(&9U>GIY"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T
M<B`B6FUI9?$@;&EN:RXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B26YS
M97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E=P<F]W862\(&ML=6-Z('1U
M=&%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8U"B,L(&9U>GIY"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")5<W7Q(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"B,L(&9U>GIY"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(E5S=?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(E5S=?$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")5<W7Q(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B5'?S:B!A9')E<R!E+6UA:6PZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,0IM<V=I9"`B26YS97)T
M(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H
M92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G
M:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(D)R86L@<F5Z=6QT873S
M=RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B
M"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"B,L(&9U>GIY
M"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(D)R86L@<F5Z
M=6QT873S=RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8U"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN
M(&)E9F]R92(*;7-G<W1R(")7<')O=V%DO"!K;'5C>B!T=71A:B(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`HC+"!F=7IZ>0IM<V=I
M9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(D)R86L@<F5Z=6QT873S=RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T
M97(B"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*(RP@
M9G5Z>GD*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@
M(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T(')O=R!A9G1E<B(*;7-G<W1R(")7<')O=V%DO"!K;'5C>B!T=71A
M:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM
M<V=S='(@(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R,@IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"B,L(&9U
M>GIY"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(EIM:67Q
M(&QI;FLN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Y"B,L(&9U>GIY"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB
M"FUS9W-T<B`B6FUI9?$@;&EN:RXN+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*(RP@9G5Z>GD*;7-G:60@(DEN<W5F9FEC:65N
M="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?
M5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<U"B,L(&9U>GIY"FUS9VED("));G1E
M9V5R(@IM<V=S='(@(D]D=W+SYB(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3,S"B,L(&9U>GIY"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B3V1W
M<O/F(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*
M;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$W,"!L:6(O
M2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(%I)4"!D
M871A(@IM<V=S='(@(D%D<F5S(&1O;6]W>2(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@87!P;&EC871I
M;VXN(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DYI97!O<')A=VYY($E$(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.#@@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S,*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R.3@*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM
M<V=S='(@(E=Y<[-A;F4@;FEE<')A=VEDLV]W92!D86YE+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DYI97!R87=I9+-O=WD@
M861R97,@9&]C96QO=WDN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z.#$@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE
M(&9O<FUA="(*;7-G<W1R(").:65P<F%W:62S;W=Y(&9O<FUA="!P;&EK=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C0*;7-G:60@(DEN
M=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(DYI97!R87=I9+-O=WD@:VQU
M8WH@;&EC96YC:FDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U.`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B3FEE>FYA;GD@861R97-A="(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED(&US9U]T>7!E+B(*;7-G<W1R(").:65P;W!R87=N82!N87IW82(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(")$
M;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N
M:6$B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-#,*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D1O
M;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED
M+B(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C(*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")!9')E<R!D;VUO=WDB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B3FEE<&]P<F%W;GD@
M;V)J96-T260B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I
M96YT.B!<(B5S7"(B"FUS9W-T<B`B3FEE<&]P<F%W;GD@=W!I<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3`T,R!L:6(O2&]R9&4O2V]L86(N<&AP.C$R
M,C`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S
M='(@(DYI97!O<')A=VYY(&]B:F5C=$ED(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D%D<F5S(&1O;6]W>2(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B061R97,@9&]M
M;W=Y(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-0HC+"!F=7IZ
M>0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DYI97!O<')A=VYY('=P:7,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M27)A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))
M<F5L86YD(@IM<V=S='(@(DER;&%N9&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*(RP@9G5Z
M>GD*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(E5W86=I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M"FUS9VED("))<W)A96PB"FUS9W-T<B`B27IR865L(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R(")7
M>61A=V-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY"B,L(&9U>GIY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B5[-O8VAY
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@R"FUS9VED("))=&%L>2(*;7-G<W1R(")7LV]C:'DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA
M;6%I8V$B"FUS9W-T<B`B2F%M86IK82(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-S0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(E-T>6-Z9?$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N:6$B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"B,L
M(&9U>GIY"FUS9VED(")*97)S97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D86XB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@P(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("),:7!I96,B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<Y(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,38*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N
M92(*;7-G<W1R(")#>F5R=VEE8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I
M9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T
M86XB"FUS9W-T<B`B2V%Z86-H<W1A;B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME97`@;W)I9VEN86P_(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N:6$B"@HC.B!L
M:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,`IM
M<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(E1W;W)Z96YI92!K;'5C>F$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#,*;7-G:60@(DME>2!&
M:6YG97)P<FEN="(*;7-G<W1R(")/9&-I<VL@:VQU8WIA(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#`Q"FUS9VED(")+97D@3&5N9W1H(@IM<V=S
M='(@(D2S=6=OMN8@:VQU8WIA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#`P"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4>7`@:VQU8WIA(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G
M:60@(DME>2!5<V%G92(*;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HW,CD*;7-G:60@(DME>2!A;')E861Y(&5X:7-T
M<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B2VQU8WH@:G6_
M(&ES=&YI96IE(&YA('!U8FQI8WIN>6T@<V5R=V5R>F4@:VQU8WIY+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R
M(")$>FEE8VDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9B(*;7-G<W1R(")+;W)E8?%S:V$@4F5P=6)L:6MA($QU9&]W;RU$96UO
M:W)A='EC>FYA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B4F5P=6)L:6MA($MO<F5I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMU=V%I="(*;7-G<W1R(")+=7=E:G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB
M"FUS9W-T<B`B2VER9VES=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(E=Y9VRQ9"`H7WDI(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW.0IM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`B2NIZ>6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("),87-T($AA;&8B"FUS9W-T
M<B`B3F%Z=VES:V\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@@;&EB+T)L
M;V-K+VUO;VXN<&AP.CDP"B,L(&9U>GIY"FUS9VED("),87-T(%%U87)T97(B
M"FUS9W-T<B`B3F%Z=VES:V\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U
M,0HC+"!F=7IZ>0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(").87IW
M:7-K;R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B3W-T871N:64@;&]G
M;W=A;FEE.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV.#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R
M(")/<W1A=&YI92!L;V=O=V%N:64Z("5S('H@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z-C@S"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R
M(")/<W1A=&YI92!L;V=O=V%N:64Z(&YI9V1Y(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B
M"FUS9W-T<B`BHV]T=V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*
M(RP@9G5Z>GD*;7-G:60@(DQA=R(*;7-G<W1R(").:7-K:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F
M=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(E=Y;&]G=6HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),
M96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B4')Z97-U\2!W(&QE=V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$Q.`HC+"!F=7IZ>0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B
M4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,30*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E!R
M>GEKLV%D;W=E('=A<G1OMF-I.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R
M("),97-O=&AO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS
M=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(U"B,L(&9U>GIY"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(EIA
M;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("):86QO
M9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C<*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B
M6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(X"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T
M<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Y"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*
M;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S`*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6X@=VET
M:"!4:'5N9&5R(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B3&EG
M:'0@4VYO=R(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(DQI9VAT
M(%-N;W<@4VAO=V5R(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(DQI8F5R:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q-0HC+"!F
M=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("):861A;FEA('!R>GD@;&]G;W=A
M;FEU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4V"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S8*;7-G:60@(DQI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT
M;6PR=&5X="YP:'`Z,3@S"B,L(&9U>GIY"FUS9VED("),:6YK<R(*;7-G<W1R
M("):861A;FEA('!R>GD@;&]G;W=A;FEU(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0V"B,L(&9U>GIY"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T
M<B`B5'?S<GHB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"B,L(&9U>GIY"FUS
M9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")0<GIY:[-A9&]W92!W87)T
M;[9C:3HB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B
M3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")7>;9W:65T;"!T96UA='D@<&]M
M;V-Y(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0HC+"!F=7IZ>0IM<V=I
M9"`B3&ES="!486)L97,B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ
M(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DT"B,L(&9U>GIY
M"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B56MR>6H@;FEE<W5B<VMR
M>6)O=V%N92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4X.0HC
M+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(E=YMG=I971L('1E
M;6%T>2!P;VUO8WDB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU
M.38*(RP@9G5Z>GD*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B5WFV=VEE=&P@
M=&5M871Y('!O;6]C>2(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP
M.C4Y,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R(")7>;9W
M:65T;"!T96UA='D@<&]M;V-Y(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R
M<RYP:'`Z-3DS"B,L(&9U>GIY"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B
M5WFV=VEE=&P@=&5M871Y('!O;6]C>2(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4Y,0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B
M"FUS9W-T<B`B56MR>6H@;FEE<W5B<VMR>6)O=V%N92(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4Y,`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U5
M;G-U8G-C<FEB92(*;7-G<W1R(")5:W)Y:B!N:65S=6)S:W)Y8F]W86YE(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHT"FUS9VED("),
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),:7-T;W=A;FEE
M('6_>71K;W=N:6OS=R!J97-T('=YL[%C>F]N92XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@(DQI=&5R871U<F4B"FUS
M9W-T<B`B4&]D<&ES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET
M=V$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H<#HY,@IM
M<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("*C861O=V%N:64N+BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DY"FUS9VED("),;V-A;"!T
M:6UE.B`B"FUS9W-T<B`B0WIA<R!L;VMA;&YY.B`B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R
M(")5<W1A=VEE;FEA(&QO:V%L;F4@:2!C>F%S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C8U(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<Q"B,L(&9U>GIY"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")/
M<&-J92(*"B,Z(&QO9VEN+G!H<#HQ-C(@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$V-"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.#8*;7-G:60@(DQO9R!I;B(*;7-G<W1R("):86QO9W5J(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U.`IM<V=I9"`B3&]G
M(&]U="(*;7-G<W1R(")7>6QO9W5J(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B6F%D86YI82!P
M<GIY(&QO9V]W86YI=2(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,S$*;7-G
M:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(DQO
M9V]W86YI92!N:64@<&]W:6]DLV\@<VGJ+"!P;VYI97=AOR!P;V1ALV6V(&YI
M97!R87=I9+-O=V4@:&%SLV\@;'5B(&YA>G?J("(*(G6_>71K;W=N:6MA+B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,C<*;7-G:60@(DQO9VEN(&9A:6QE
M9"XB"FUS9W-T<B`B3&]G;W=A;FEE(&YI92!P;W=I;V2S;R!S:>HN(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$S-C<*(RP@9G5Z>GD*;7-G:60@(DQO;F<@
M=&5X="(*;7-G<W1R(")7>6QO9W5J(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0X"B,L(&9U>GIY"FUS9VED("),;W9E(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@<&Q?4$PN<&\@*$EN9V\@:#,M,2XP+C$I("`C+2,M(RTC+2-<;B(*
M(E!R>F5S=?%<;B(*(B,M(RTC+2,M(R`@<&Q?4$PN<&\@*$EM<"!H,RTT+C`N
M,RD@(",M(RTC+2,M(UQN(@HB4')Z96YI9;9<;B(*(B,M(RTC+2,M(R`@<&Q?
M4$PN<&\@*%1U<F)A(&@S+3(N,"XS*2`@(RTC+2,M(RTC7&XB"B)0<GIE;FEE
MMB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W
M"FUS9VED("),;W<B"FUS9W-T<B`B3FES:VDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),
M;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PHC+"!F
M=7IZ>0IM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")'<G5D
M>FEE\2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=6MS96UB=7)G
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,R!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DU/5$0B"FUS9W-T
M<B`B34]41"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA:V%U(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N
M:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M36%C961O;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G
M87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*
M;7-G:60@(DUA9VEC(@IM<V=S='(@(E!O8WIT82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")0;V-Z=&$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<W"FUS9VED(")-86EL
M($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`IM<V=I9"`B36%K92!L:6Y?:RXN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=VDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&5Z:F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA;&1I=F5S(@IM<V=S='(@(DUA;&5D:7=Y(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM
M<V=S='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C
M871E9V]R:65S+B(*;7-G<W1R("(B"B):87)ZL61Z86H@;&ES=+$@:V%T96=O
M<FEI+"!K=/-R>6UI(&+J9'II97-Z(&]Z;F%C>F&S('!O>GEC:F4L(&D@:V]L
M;W)A;6D@>B`B"B)N:6UI('IW:;%Z86YY;6DN(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(DUA<#(T(&UA<"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3<W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4T"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@
M(DUA<GIE8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G:6YE
M<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I
M9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@
M(E=Y<W!Y($UA<G-H86QL82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R
M(")-87)T>6YI:V$B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$Q
M,0IM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E!A<W5JL6-E('!O
M;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<F5T86YI82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@
M86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`X"B,L(&9U>GIY"FUS9VED(")-87@@;65S
M<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B5VEA9&]M;[;F(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU
M;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,W."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-86HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-
M87EO='1E(@IM<V=S='(@(DUA:F]T=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(D]D
M<GIU8V]N92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,3D*(RP@9G5Z>GD*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B1W)U9'II9?$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")-96YU(&UO
M9&4Z(@IM<V=S='(@(E1R>6(@;65N=3HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C
M96QL<R(*;7-G<W1R(")0;[.Q8WH@:V]M\W)K:2(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`IM<V=I9"`B365S
M<V%G92(*;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C
M97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N
M;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")-97-S
M86=E(&5X<&ER960N(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V
M,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E=I861O
M;6^VYB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PHC+"!F=7IZ>0IM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")/8F5C;GD@8WIA<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@7")-971A<EPB(&YI92!J97-T(&1O
M<W3J<&YY+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B
M"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)"
M;&]K(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N>2X@4WIC>F5G\[-Y('ID
M87)Z96YI82!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA("(*(F%D;6EN:7-T<F%T
M;W)A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3(*;7-G
M:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(DUE=&AO9"(*
M;7-G<W1R("),97-O=&AO(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP
M.C@Q(&QI8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(E6_>6-I92!F;VQD97)U(&YI92!J97-T(&%K='EN=V4N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A
M<BYP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-96MS
M>6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-96MS>6LB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R(")3=&%N;W=I<VMO
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED
M(")-:6UE(%1Y<&4B"FUS9W-T<B`B5'EP($UI;64B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED
M(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$W"B,L(&9U>GIY"FUS
M9VED(")-:7)R;W(B"FUS9W-T<B`B0K.Q9"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"FUS9VED(")-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG
M=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W
M86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`HC+"!F=7IZ
M>0IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")7:6%D;VUO
MMN8@9&\B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL
M+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-`HC+"!F=7IZ>0IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*
M;7-G<W1R(").:64@>F1E9FEN:6]W86YO('1E:W-T=2!W(&YO8VEE('=A:V%C
M>6IN96HN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C<T"B,L(&9U>GIY"FUS9VED(")-;V)I;&4@36%I;"(*
M;7-G<W1R(").;W=A('!O8WIT82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8X"B,L(&9U>GIY"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R(")/<W1A=&YI82!M;V1Y9FEK86-J82(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U
M"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(D]S=&%T;FEA(&UO9'EF
M:6MA8VIA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4R"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(EIM
M:67Q(&QI;FLB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W,PIM
M<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;[-D87=I82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L
M9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4F5P=6)L:6MA($UOLV1A=VEI
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86MO(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M;VYG;VQI82(*;7-G<W1R(")-;VYG;VQI82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-3DS"B,L(&9U>GIY"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G
M<W1R(")2;WIW:?$@<&%S96LB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(D-O(&UI97-IL6,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I
M9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B1F%Z>2!K<VGJOWEC82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:V\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S
M='(@(DMR86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R.`IM<V=I9"`B36]V92!$;W=N
M(@IM<V=S='(@(E!R>F5S=?$@=R!D\[,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HT,S(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")0<GIE
M<W7Q('<@;&5W;R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0S
M-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")0<GIE<W7Q('<@<')A=V\B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,C0*;7-G:60@(DUO
M=F4@57`B"FUS9W-T<B`B4')Z97-U\2!W(&?S<NHB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV"FUS9VED(")-;W9E(&1O=VXB
M"FUS9W-T<B`B4')Z96YI9;8@=R!D\[,B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#DU(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.38*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B4')Z97-U
M\2!W(&?S<NHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB
M:6LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-0IM<V=I9"`B375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C0S"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!S96QE
M8W1I;VXB"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@=&^_<V%M;[;F(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,2!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S,X"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DMO;G1O
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU,0IM<V=I9"`B37D@
M4&]R=&%L(@IM<V=S='(@(DWS:B!P;W)T86PB"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")->2!0;W)T86P@3&%Y
M;W5T(@IM<V=S='(@(E!O<G1U9V%L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS
M9W-T<B`B0FER;6$B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M
M96YT7V)O='1O;2YI;F,Z-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3`R(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DYA;64B"FUS9W-T<B`B
M3F%Z=VES:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L
M(@IM<V=S='(@(DYE<&%L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R
M(")(;VQA;F1I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G
M<W1R(")!;G1Y;&4@2&]L96YD97)S:VEE(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED
M(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G
M:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!3
M4TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#<*(RP@9G5Z>GD*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B0G)A:R!O<V]B:7-T96=O(&-E<G1Y
M9FEK871U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#`*(RP@
M9G5Z>GD*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T
M<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C,Y"FUS9VED(").971W;W)K(@IM<V=S='(@(E-I9>8B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,30@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,R-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED
M(").979E<B(*;7-G<W1R(").:6=D>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI
M82(*;7-G<W1R(").;W=A($MA;&5D;VYI82(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C(W"FUS9VED(").97<@0V%T96=O<GDB
M"FUS9W-T<B`B3F]W82!K871E9V]R:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYO=WD@
M:V]N=&%K="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F]W82!:96QA;F1I82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*
M;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C$*;7-G:60@(DYE=W,B
M"FUS9W-T<B`B5VEA9&]M;[9C:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR.34*(RP@9G5Z>GD*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B
M1W)U<'D@9'ES:W5S>6IN92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0V"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C,R"FUS9VED(").97AT(@IM<V=S='(@(DYA<W3J<&YE(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT(#0@
M4&AA<V5S(@IM<V=S='(@(DYA<W3J<&YA('-T<F]N82(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,S<P(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<T
M"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B3F%S=.IP;F4@;W!C:F4B
M"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`B3F%S=.IP;F4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U
M82(*;7-G<W1R(").:6MA<F%G=6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@
M(DYI9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI9V5R:6$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8X"B,L(&9U>GIY"FUS
M9VED(").:6=H="(*;7-G<W1R(")7>7-O:VDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS
M9W-T<B`B3FEU92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HX.#4*(RP@9G5Z>GD*;7-G:60@(DYO(@IM<V=S='(@(DYI92(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ,38*;7-G:60@(DYO
M(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E
M;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H
M<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG
M($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-SD@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C,P"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C(U,@IM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T
M('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DYO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(D)R86L@:6YF;W)M86-J:2!O('-E<G=E<GIE(%-13"!Z('6_>71K
M;W=N:6MA;6DB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B
M3F\@8VAA;F=E+B(*;7-G<W1R(")"97H@>FUI86XN(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(DYO(&-H:6QD('!E
M<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+B(*
M;7-G<W1R(")59&&S;R!S:>H@9&]D8>8@7"(E<UPB(&1O('5P<F%W;FEE\2XB
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(E5D8;-O('-IZB!D;V1AYB!<(B5S7"(@9&\@=7!R87=N
M:67Q+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38W(&QI8B](;W)D92YP:'`Z-#<W
M(&QI8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+B(*;7-G<W1R(")"<F%K(&MO;F9I9W5R86-J:2!D;&$@)7,N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C<T,0HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S
M='(@(D)R86L@:6YF;W)M86-J:2!O('-E<G=E<GIE($Q$05`@>B!U<W1A=VEE
M;FEA;6DN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C4Y,0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N(@IM<V=S='(@(D)R86L@:6YF;W)M86-J:2!O('-E<G=E<GIE
M(%-13"!Z(&MA=&5G;W)I86UI+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C<P-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B0G)A
M:R!I;F9O<FUA8VII(&\@<V5R=V5R>F4@4U%,('H@:V%T96=O<FEA;6DN(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(").:64@=WEG96YE
M<F]W86YO(+]A9&YE9V\@<VMR>7!T=2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,T"B,L(&9U>GIY"FUS9VED(").;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B5VEA9&]M;[;F(@H*(SH@;&EB+TAO
M<F1E+T)R;W=S97(N<&AP.C@X,0IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*
M;7-G<W1R(").:64@=V=R86YO('!L:6MU(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*(RP@9G5Z>GD*;7-G:60@(DYO(&QO
M8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B07!L:6MA8VIA(&=O=&]W82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-38*(RP@9G5Z>GD*;7-G
M:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").:65Z;F%N>2!A
M9')E<V%T(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T
M<B`B5VEA9&]M;[;F(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-@HC+"!F=7IZ>0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM
M<V=S='(@(DYI92!W>6)R86YO('6_>71K;W=N:6MA+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*(RP@9G5Z>GD*;7-G:60@(DYO
M(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYI92!W>6)R86YO('6_>71K
M;W=N:6MA+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYI92!Z
M;F%L97II;VYO(&MO;G1A:W3S=R(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N
M<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEE('!O9&%N;R!H87.S82!D;&$@
M=7=I97)Z>71E;&YI96YI82!(5%10+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM
M87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@
M9&QA('5W:65R>GET96QN:65N:6$@24U!4"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").:64@<&]D86YO
M(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($ME<F)E<F]S+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.CDT"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEE
M('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!,1$%0+B(*"B,Z
M(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C<W(&QI8B](;W)D92]!=71H+VQO
M9VEN+G!H<#HX-`HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<U"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN
M:65N:6$@3$]'24XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ
M,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@9&QA('5W
M:65R>GET96QN:65N:6$@4$%34U=$+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M
M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@9&QA
M('5W:65R>GET96QN:65N:6$@4TU"+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E
M<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I
M9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"B,L(&9U
M>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")5=V%G:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@
M9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-0IM<V=I9"`B3F\@=&5M<&]R
M87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,L(&9U
M>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB
M"FUS9W-T<B`B4')O<WKJ('!O9&'F(&YA>G?J('6_>71K;W=N:6MA(&D@:&%S
MLV\B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").
M;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DS(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY,#,*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDQ-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3,Q"B,L(&9U>GIY"FUS9VED(").;R!V86QU97,B"FUS
M9W-T<B`B57=A9VDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y"FUS
M9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$R-PIM<V=I9"`B3F\@=F5R<VEO;B!F
M;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$V('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY,@IM<V=I9"`B3F]N92(*;7-G<W1R("*O861N82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@
M*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#D*(RP@9G5Z>GD*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I
M(@IM<V=S='(@(J9R;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,BDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&LB"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"B,L
M(&9U>GIY"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(E!O
M;6]C(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R=V5G:6$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B
M3F]T($%F=&5R(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,SD*(RP@9G5Z>GD*;7-G:60@(DYO="!"969O<F4B"FUS
M9W-T<B`B57=A9VDB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S,0HC+"!F=7IZ
M>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V<B"@HC
M.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B3FEE('IA:6UP;&5M96YT;W=A;F\N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I
M9"`B3F]T('-E="(*;7-G<W1R(").:65U<W1A=VEO;F4B"@HC.B!L:6(O5D93
M+G!H<#HQ-S4@;&EB+U9&4RYP:'`Z,3DS(&QI8B]61E,N<&AP.C(Q,"!L:6(O
M5D93+G!H<#HR,C8*(SH@;&EB+U9&4RYP:'`Z,C0R(&QI8B]61E,N<&AP.C(U
M-R!L:6(O5D93+G!H<#HR-S0@;&EB+U9&4RYP:'`Z,S`W"B,Z(&QI8B]61E,N
M<&AP.C,V-R!L:6(O5D93+G!H<#HT-#8@;&EB+U9&4RYP:'`Z-3$U(&QI8B]6
M1E,N<&AP.C4S,@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M,R!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W,R!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP.C$X-PHC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C(S-`IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3FEE;V)SLW5G
M:7=A;F4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T
M-"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,38T"FUS9VED(").;W1E<R(*
M;7-G<W1R(")5=V%G:2(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H
M<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI
M;F,Z,3`*;7-G:60@(DYO=&EC92(*;7-G<W1R(")5=V%G82(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R("),:7-T;W!A9"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#0V"B,L
M(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B3&ES=&]P860B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30R-PHC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R
M(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B3&EC>F)A('=I97)S>GDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O
M;'5M;G,B"FUS9W-T<B`B3&EC>F)A(&MO;'5M;B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S8Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(S(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R
M("),:6-Z8F$@=VEE<G-Z>2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#0*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(E-T=V]R>GFS9;8@;&ES=.H@9'ES=')Y8G5C>6INL2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+
M(@IM<V=S='(@(D]+(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@Q,0HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(E1E
M;6%T(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*(RP@9G5Z
M>GD*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D1O;7FV;&YE('5P
M<F%W;FEE;FEA(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,W(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")/8FIE8W0@
M8W)E871O<B!P97)M:7-S:6]N<R(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI
M96YI82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A
M;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")08;QD>FEE<FYI:R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P,0IM
M<V=I9"`B3V9F:6-E(@IM<V=S='(@(D)I=7)O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM
M<V=S='(@(D]M86XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E1E;B!S97)W97(@;FEE(&]B
M<[-U9W5J92!U9&]S=.IP;FEA;FEA(&9O;&1E<O-W+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3(@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Y-S(*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B5'?S:B!J961E;B!A9')E<R!E+6UA
M:6P@:F5S="!D;WIW;VQO;GDN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P
M97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B3W1W\W)Z('<@;F]W>6T@;VMN:64B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U
M;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4T"B,L(&9U>GIY"FUS9VED(")/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(E!O8G)AYB!P;V-Z=.H@
M=R!O<V]B;GEM(&]K;FEE/R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM
M<V=S='(@(D]P8VIE(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C(Y('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P
M=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P8VIE("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`HC+"!F=7IZ>0IM<V=I
M9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E=Y8FEE<GH@;&ES=.HB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T
M:6]N(@IM<V=S='(@(D]R9V%N:7IA8VIA(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS
M9W-T<B`B2F5D;F]S=&MA(&]R9V%N:7IA8WEJ;F$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@
M(D]R9V%N:7IA=&]R(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*(RP@
M9G5Z>GD*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM
M<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M
M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/
M=&AE<B(*;7-G<W1R("));FYE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$*;7-G:60@(D]T:&5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DEN;F4@:6YF;W)M86-J92(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(DEN;F4@=7!R87=N:65N:6$B"@HC.B!L:6(O2&]R9&4O075T:"]P
M86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!004T@;FEE(&IE
M<W0@9&]S=.IP;F4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(U
M,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D-Y9G)O
M=WD@<&]D<&ES(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R
M.3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")7:6%D;VUO
MMN8@>F%S>GEF<F]W86YA(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$S-3$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(DML=6-Z
M('!U8FQI8WIN>2!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,S,S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(E=I861O;6^VYB!Z87-Z>69R;W=A;F$O<&]D<&ES86YA(&ML=6-Z96T@4$=0
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*
M;7-G<W1R(")+;V0@4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS
M9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4&]WLV]K82!02%`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PHC+"!F=7IZ>0IM
M<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*(RP@9G5Z>GD*;7-G
M:60@(E!-(%-N;W<B"FUS9W-T<B`B4&]K8;\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`HC+"!F=7IZ>0IM<V=I9"`B4$T@
M4VYO=R!3:&]W97)S(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E5W
M86=I(@H*(SH@;&EB+V%P:2YP:'`Z,3(X"FUS9VED(")07TA0(%-H96QL(@IM
M<V=S='(@(E!O=[-O:V$@4%](4"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*(RP@9G5Z>GD*;7-G:60@(E!A
M9&1I;F<B"FUS9W-T<B`B4F]Z=VEJ86YI92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB
M"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R(")0
M86QA=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A+4YO
M=V$@1W=I;F5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=W
M86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-@HC+"!F=7IZ>0IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")+<F%J
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#$Y('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S,*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S8R"FUS9VED(")087-S=V]R9"(*;7-G<W1R
M(")(87.S;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,@IM
M<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(DAA<[-O(&YI97!R
M87=I9+-O=V4B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$U,@HC
M+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B0G)A:R!I;F9O<FUA8VII(&\@<V5R
M=V5R>F4@4U%,('H@=;]Y=&MO=VYI:V%M:2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#4T"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*
M;7-G<W1R(")(87.S;R!Z('!O='=I97)D>F5N:65M(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T
M<B`B2&%SLV\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*
M;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B2&%SLV\Z("(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S-0HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R
M9',@;75S="!M871C:"XB"FUS9W-T<B`B2&%SLV\@;75S:2!P87-O=V'F+B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*
M;7-G<W1R(")7:VQE:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM
M<V=S='(@(E=K;&5J('IE('-C:&]W:V$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"B,L(&9U>GIY"FUS9VED(")0871H
M(@IM<V=S='(@(E=K;&5J(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C0*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P
M;&4B"FUS9W-T<B`B6U)A<&]R="!O('!R;V)L96UI95TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PHC+"!F=7IZ>0IM
M<V=I9"`B4&5R8V5N="(*;7-G<W1R(")$<G5K=6HB"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.C8*;7-G:60@(E!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")7>6MO;F%J(&-Y
M:VQI8WIN92!O<&5R86-J92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\B"FUS9W-T<B`B5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4@<&]D
M8WIA<R!L;V=O=V%N:6$_(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C8Q(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV-`HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-C<*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M57!R87=N:65N:64B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C8X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N
M;W0@9&5L971E9"XB"FUS9W-T<B`B0G)A:R!D;W-TZG!U(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,C(T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HY
M,PHC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-J82(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,30U(&QI8B](;W)D92]097)M<R]522YP:'`Z,30X
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34R"FUS9VED(")097)M:7-S
M:6]N<R!F;W(B"FUS9W-T<B`B57!R87=N:65N:6$@9&QA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R("));F9O<FUA8VIE(&]S;V)I<W1E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U
M(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*
M;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*
M;7-G<W1R(")&:6QI<&EN>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&AO=&]S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A
M:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT.`IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(").82!P97=N
M;R!U<W5NL>8@=&5N('=Y8G)A;GD@96QE;65N=#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@
M(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="XB"FUS9W-T<B`B3F$@<&5W;F\@=7-U;K'F('=Y8G)A;GD@96QE
M;65N=#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4W,`HC+"!F=7IZ>0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B4')O<WKJ('!O9&'F(&YO=[$@;F%Z=^HZ(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM
M<V=S='(@(E!R;W-ZZB!P;V1AYB!N87IWZB!D;&$@;F]W96=O(&9O;&1E<G4Z
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E!R;W-ZZB!P;V1A
MYB!P;W!R87=N>2!A9')E<R!)4"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C8U.0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3`*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E!R;W-ZZB!P;V1AYB!P;W!R87=N
M>2!C>F%S+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*
M;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2XB"FUS9W-T<B`B4')O<WKJ(&]P:7-AYB!P<F]B;&5M+B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3@@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0B"FUS9W-T<B`B4')O<WKJ('!O9&'F(&YA>G?J('6_>71K
M;W=N:6MA(&D@:&%SLV\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R
M965M96YT7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@
M=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z(@IM<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@
M:W3S<F5G;R!C:&-E<WH@=7-U;K'F+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S
M='(@(E!O;'-K82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PHC+"!F
M=7IZ>0IM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B6G=I\2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S0*(RP@9G5Z>GD*;7-G:60@(E!O;&QS
M(@IM<V=S='(@(EIW:?$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DS
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0
M;W)T=6=A;&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS
M*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#8*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX"B,L(&9U>GIY
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE('IN86QE>FEO;F\@
M=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@3$1!4"XB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O<V5S<VEO;BYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(E!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]I;7`Z(%=Y;6%G86YE(')O>G-Z97)Z96YI92!)34%0
M(&YI92!Z;F%L97II;VYE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U
M"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM
M<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E
M=FEE=R(*;7-G<W1R(")0;V1G;+%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS
M9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B5WFV=VEE=&P@>F&SL6-Z;FEK('<@;W-O8FYY;2!O:VYI92(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,S8P(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,S8T"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S
M='(@(E!R97IE;G1A8VIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R(")+;'5C>B!P<GEW871N>2(*"B,Z(&QI8B](
M;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4')O
M8FQE;2(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O
M8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")/<&ES('!R;V)L96UU(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q,PIM<V=I9"`B4')O:F5C=',B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Q.#D*(RP@9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT
M(@IM<V=S='(@(E=Y;&]G=6HB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3(*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B2VQU8WH@<'5B;&EC
M>FYY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@
M(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R>71M(&ML=6-Z
M82!P=6)L:6-Z;F5G;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B26YF;W)M86-J
M92!O(&ML=6-Z=2!P=6)L:6-Z;GEM(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,C,P"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")087)A(&ML=6-Z>2!O
M<V]B:7-T>6-H(&YI92!Z;W-T8;-A('=Y9V5N97)O=V%N82!P;VUYMFQN:64N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4&]R=&]R>6MO(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C(*;7-G:60@(E%U97)Y(@IM<V=S='(@(EIA<'ET86YI92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(DML
M=6-Z('!U8FQI8WIN>2!24T$@*"5D(&)I=/-W*2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,C8U"B,L(&9U>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB
M"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@=&^_<V%M;[;F(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*(RP@9G5Z>GD*;7-G
M:60@(E)A:6XB"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`HC+"!F=7IZ>0IM<V=I9"`B
M4F%I;B!%87)L>2(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E)A
M:6X@3&%T92(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)A:6X@
M4VAO=V5R(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B!A
M;F0@4VYO=R(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)A:6X@
M=&\@4VYO=R(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S
M='(@(E5W86=I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*(RP@9G5Z>GD*
M;7-G:60@(E)A=&EO(@IM<V=S='(@(D]P8VIE(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HR.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#`*(RP@9G5Z>GD*;7-G:60@(E)E860B"FUS9W-T
M<B`B4')Z9;-A9'5J(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(DYO=V4@=VEA9&]M;[9C:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T
M92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O
M<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,T"B,L(&9U>GIY"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R(")7>F[S=R!S=V]JL2!S97-JZB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#,*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.B(*;7-G<W1R(")/9+9W:66_(&1Y;F%M:6-Z;F4@96QE;65N
M='D@;65N=3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,S"FUS9VED
M(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")/9+9W:66_('=I9&]K
M('-E<G=I<W4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-0IM<V=I
M9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M-#@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"B,L(&9U>GIY"FUS9VED(")296UA
M<FMS(@IM<V=S='(@(D1A;FEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B6F1A;&YE('-E
M<G=E<GDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G
M:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(Q('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,34*;7-G
M:60@(E)E;6]V92(*;7-G<W1R(")5<W7Q(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B
M57-U\2!B;&]K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")5<W7Q(&MO
M;'5M;NHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G
M<W1R(")5<W7Q('!A<NHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$S-@IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B57-U\2!P87+J(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P-0IM<V=I9"`B4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R
M(")5<W7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Y"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,38*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@
M(E5S=?$@=;]Y=&MO=VYI:V$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z
M("5S(@IM<V=S='(@(EID86QN92!UOWET:V]W;FEK83H@)7,B"@HC.B!L:6(O
M2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30T"B,L(&9U
M>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N(@IM<V=S='(@(J]A9&%N>2!O8FIE:W0@;FEE>FYA;&5Z:6]N>2XB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$W-"!L:6(O2&]R9&4N<&AP.C0X-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0G)A:R!W>6UA
M9V%N96H@;W!C:FD@)W5I9"<@9&QA(&MO;F9I9W5R86-J:2!U<W1A=VEE\2XB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S0W(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C<Q,"!L:6(O5D93+W-Q;"YP:'`Z-3DW"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0G)A:R!W>6UA9V%N96H@;W!C:FD@
M)W5I9"<@9&QA(&MO;F9I9W5R86-J:2!U<W1A=VEE\2XB"@HC.B!L:6(O2&]R
M9&4O571I;"YP:'`Z-S@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")"<F%K('=Y;6%G86YE:B!O<&-J:2`G=6ED)R!D;&$@:V]N
M9FEG=7)A8VII('5S=&%W:67Q+B(*"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E
M<F5R+G!H<#HS,C@*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS,SD@
M;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q-0HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-#0*;7-G:60@(E)E<V5T(@IM<V=S='(@(DMA<W5J(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A
M<W-W;W)D(@IM<V=S='(@(E=Y8WIYMN8@:&%SLV\B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R(")7>6-Z>;;F(%1W;VIE(&AA<[-O(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-2!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-S$*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B5WEN:6MI(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G
M<W1R(")0;W=R\W0@9&\@;W!C:FDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)E=F5R
M="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S
M;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@
M(E)O>F)U9&]W86YY(&5D>71O<B!T96MS='4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M4W1A;F]W:7-K;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I9"`B4FEG:'0B"FUS9W-T
M<B`B5WES;VMI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C`*(RP@9G5Z
M>GD*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")0<GIY:[-A9&]W92!W
M87)T;[9C:3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q-@HC+"!F=7IZ
M>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A
M<G1OMF-I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B4F]?=R!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E-T
M86YO=VES:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)U;75N:6$B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`X"FUS
M9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D]B<O/F(&\@,3@P('-T;W!N:2(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*;7-G
M:60@(E)O=&%T92!,969T(@IM<V=S='(@(D]B<O/F('<@;&5W;R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,3$*;7-G:60@(E)O
M=&%T92!2:6=H="(*;7-G<W1R(")/8G+SYB!W('!R87=O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0HC+"!F
M=7IZ>0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B5[-AMF-I=V^V
M8VD@<GKJ9'4@4')O<&5R=&EE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T
M:65S(@IM<V=S='(@(E>S8;9C:7=OMF-I(')ZZF1U(%!R;W!E<G1I97,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM
M<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B
M4G5L97,B"FUS9W-T<B`B4W1A;F]W:7-K;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2;W-J82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N9&$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R
M87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4B"FUS9W-T<B`B5VEA9&]M;[;F('IA<WIY9G)O=V%N82!3+TU)344B"@HC
M.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")5=VEE<GIY
M=&5L;FEE;FEE(%-!4TP@;FEE(&IE<W0@9&]S=.IP;F4N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0U.0HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE
M<W-A9VEN9R(*;7-G<W1R(")7>;9W:65T;&%N:64@=VEA9&]M;[9C:2(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S
M='(@(E!O=VQO:V$@4U%,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,W,`IM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#
M0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S(*;7-G:60@(E-?
M44P@4VAE;&PB"FUS9W-T<B`B4&]WLV]K82!37U%,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0HC+"!F=7IZ>0IM<V=I
M9"`B4V$B"FUS9W-T<B`B6F%P:7-Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA
M(@IM<V=S='(@(J9W:>IT82!(96QE;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S
M(&%N9"!.979I<R(*;7-G<W1R(")386EN="!+:71T<R!I($YE=FES(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS
M9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,=6-I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0M
M4&EE<G)E(&D@36EQ=65L;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N
M9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")386EN="!6:6YC96YT(&D@1W)E
M;F%D>6YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N
M($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O
M;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B4V%T96QL:71E(%!R;W9I
M9&5R(@IM<V=S='(@(E=O:F5W\V2\='=O(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A
M8FEA(@IM<V=S='(@(D%R86)I82!3875D>6IS:V$B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B6F%P
M:7-Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("):87!I<WH@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(EIA<&ES>B!<(B5S
M7"(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E
M($]P=&EO;G,B"FUS9W-T<B`B6F%P:7-Z(&]P8VIE(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W,`IM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HV.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@;FEE
M(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HY,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K
M("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#D*(RP@9G5Z>GD*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R
M(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0HC+"!F=7IZ
M>0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(").861A=V-A(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")3>G5K86HB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<X"B,L(&9U>GIY"FUS
M9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")/<&-J92!W>7-Z=6MI=V%N
M:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDW,@IM<V=I9"`B4V5L96-T
M($9I;&5S(@IM<V=S='(@(E=Y8FEE<GH@<&QI:VDB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@82!D871E(@IM<V=S='(@(E=Y8FEE<GH@9F]R;6%T(&1A='DZ(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")3='?S<GH@;F]W
ML2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")3='?S<GH@;F]W
ML2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E-T=_-R>B!N;W>Q
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E-T=_-R>B!N
M;W>Q(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-C(*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")7>6)I
M97)Z(&9O<FUA="!D871Y.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HX,3$*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!O8FIE
M8W0B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+B(*;7-G<W1R("(B"B)7>6)I97)Z('IN86MI('H@<&]N:;]S>GEC:"!P\VP@
M9F]R;75L87)Z82X@36^_97-Z(&IE('-K;W!I;W=AYB!I('=K;&5IYB!Z("(*
M(G!O;&$@=&5K<W1O=V5G;RXB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T
M<B`B5WEB:65R>B!Z;F%K('!O9'II8;-U(&1A='DZ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M
M870Z(@IM<V=S='(@(E=Y8FEE<GH@9F]R;6%T(&1A='DZ(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHX.0IM<V=I9"`B4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E=Y
M8FEE<GH@=&^_<V%M;[;F(&1O('IM:6%N>3HB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E
M<CHB"FUS9W-T<B`B5WEB:65R>B!Z;F%K('!O9'II8;-U(&1A='DZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!F;W)M870Z(@IM<V=S='(@(E=Y8FEE<GH@9F]R;6%T(&-Z87-U.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C0*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")7>6)I97)Z(&1W82!P
M87-U:K%C92!P;VQA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*
M;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B5WEB
M:65R>B!S8VAE;6%T(&MO;&]R\W<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(T,`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R(")7>6)I97)Z('1W\VH@<')E9F5R;W=A;GD@:NIZ>6LZ(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E
M;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B5WFV;&EJ(')A<&]R="!O('!R
M;V)L96UI92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C$*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$V"B,L(&9U>GIY"FUS9VED(")396YS;W(Z("(*;7-G<W1R(").87IW
M82!UOWET:V]W;FEK82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B5W)Z97-I9?$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@
M86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B
M3G5M97(@<V5R>6IN>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@7")-971A<EPB(&YI92!J97-T
M(&1O<W3J<&YY+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDR"B,L(&9U>GIY"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM
M<V=S='(@(E=I861O;6^VYB(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S$S
M"FUS9VED(")3970B"FUS9W-T<B`B57-T87<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I
M9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(E5S=&%W('ID86QN92!S
M97)W97)Y+"!D;R!K=/-R>6-H(&-H8V5S>B!M:67F(&1O<W3J<"!Z('-E<G=I
M<W4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N(@IM<V=S='(@(E5S=&%W('!R969E<F]W86YY(&KJ>GEK+"!S=')E
M9NH@8WIA<V]WL2!I(&]P8VIE(&1A='DN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB57-T87<@=7.S=6?J
M('!O8WJQ=&MO=[$L('-C:&5M870@:V]L;W+S=RP@;V2V=VEEOV%N:64@<W1R
M;VYY(&D@:6YN92!O<&-J92`B"B)W>;9W:65T;&%N:6$B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<T"FUS9VED(")3971U<"(*;7-G<W1R(")+;VYF
M:6=U<F%C:F$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M
M;#HS.0HC+"!F=7IZ>0IM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V
M86EL86)L92(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA
M:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<T"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W
M:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC
M:&5L;&5S(@IM<V=S='(@(E-Z97-Z96QE(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0U,0HC+"!F=7IZ>0IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T
M<B`B2&ES>G!A;FEA(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2W+S=&MI(&]P
M:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,X"FUS9VED(")3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.3(@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G
M:60@(E-H;W<B"FUS9W-T<B`B4&]K8;\B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,34X"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@
M8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.#(*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G
M9VEN9R!I;C\B"FUS9W-T<B`B4&]K87IY=V'F(&-Z87,@;W-T871N:65G;R!Z
M86QO9V]W86YI82!P;R!L;V=O=V%N:74_(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$W-C8*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3(*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(DEM<&]R="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*(RP@9G5Z>GD*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5WFV=VEE=&QA
MYB!I:V]NZB!F:6QT97+S=R!N82!P87-K=2!Z861A\3\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Q"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(E!O:V&_(&UE;G4@
M)7,@<&\@;&5W96H_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED(")3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1E;"X@
M:V]M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&5L+B!K;VTN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y
M"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B5&5L+B!K;VTN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"B,L(&9U>GIY
M"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R(")496PN(&MO;2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-`HC
M+"!F=7IZ>0IM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B5V=R>7=A;FEE
M('!L:6MU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B26UP;W)T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*
M(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B2W+S=&MI
M92!S=')E<WIC>F5N:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS.3D*
M(RP@9G5Z>GD*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")"86AR86IN(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-CDR(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C<U-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HX,3(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#<T"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.CDP.2!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HY-#8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3<T
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P,#0*;7-G:60@(E-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS
M9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B4F5J
M97-T<F%C:F$@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDR
M"FUS9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D(@IM<V=S='(@(EIA
M<F5J97-T<G5J('-IZBP@:F6V;&D@:F5S>F-Z92!T96=O(&YI92!Z<F]B:;-E
MMB(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3
M:6=N871U<F4B"FUS9W-T<B`B4&]D<&ES(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS
M9W-T<B`B06QG;W)Y=&T@<&]D<&ES=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*
M;7-G<W1R(")3:6YG87!U<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.38@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#<@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Y,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C(*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#0*;7-G:60@(E-I>F4B"FUS9W-T<B`B5VEE;&MOMN8B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.CD*;7-G:60@(E-K
M:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B4&]M:?$@;W!E<F%C:F4@8WEK;&EC
M>FYE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4[-O=V%C:F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3LV]W96YI82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"B,L(&9U>GIY"FUS
M9VED(")3;F]W(@IM<V=S='(@(E!O:V&_(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*(RP@9G5Z>GD*;7-G:60@(E-N;W<@
M4VAO=V5R(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO
M=V5R<R!%87)L>2(*;7-G<W1R(")+<O-T:VEE('-T<F5S>F-Z96YI92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"B,L(&9U
M>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("));7!O<G0B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T
M:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS
M9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B5WES<'D@4V%L;VUO
M;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:6$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,C4*(RP@9G5Z
M>GD*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E-K87-U
M:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4X.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC+"!F=7IZ>0IM
M<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B061R97,@9&]M;W=Y(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(E!OLW5D;FEO=V$@069R
M>6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R(")0;[-U9&YI;W=O975R
M;W!E:G-K:2`H25-/+3@X-3DM,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@
M86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D=E;W)G
M:6$@4&^S=61N:6]W82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B4&]M;V,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T
M=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$U"B,L(&9U>GIY"FUS9VED(")3<&%C
M97(B"FUS9W-T<B`B2&ES>G!A;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,L(&9U>GIY"FUS9VED(")3
M<&%C:6YG(@IM<V=S='(@(DAI<WIP86YI82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S
M='(@(DAI<WIP86YI82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R(")%9'EC:F$@>FYA:_-W('-P96-J86QN>6-H(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I
M9"`B4W!L:70@8V5L;"(*;7-G<W1R(")0;V1Z:65L(&MO;?-R:^HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V
M"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B4&]D>FEE;"!K;VQU;6[J
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(E!O9'II96P@=VEE
M<G-Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY"FUS
M9VED(")3<&]R=',B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N
M:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8U(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*(RP@9G5Z>GD*
M;7-G:60@(E-T86YD87)D(@IM<V=S='(@(DMA;&5N9&%R>B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B4W1A<B!4<F5K
M(@IM<V=S='(@(E-T87)T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.34@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#@*(RP@9G5Z>GD*;7-G:60@(E-T87)T
M('EE87(B"FUS9W-T<B`B4W1A<G0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B
M5V]J97?S9+QT=V\@;'5B('-T86XB"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$T"B,L(&9U>GIY"FUS9VED
M(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")&;W)M870@8WIA<W4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D
M9')E<W,B"FUS9W-T<B`B061R97,@9&]M;W=Y(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR
M;W5G:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S,PHC
M+"!F=7IZ>0IM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B57-T87=I96YI
M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<T"FUS9VED(")3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED
M(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I
M9"`B4W5B:F5C="(*;7-G<W1R(")496UA="(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,S(@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q,@IM<V=I
M9"`B4W5B;6ET(@IM<V=S='(@(E=YMFQI:B(*"B,Z('-I9VYU<"YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@
M861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@
M=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B4&6S
M;GD@;W!I<SHB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B
M4W5C8V5S<R(*;7-G<W1R(")0;W=O9'IE;FEE(@H*(SH@861M:6XO=7-E<BYP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")59&&S;R!S:>H@9&]D
M8>8@7"(E<UPB(&1O('-Y<W1E;74N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A
M=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M561ALV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z.#$@861M:6XO<&5R;7,O9&5L971E+G!H<#HV,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N
M(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")5
M9&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B4W5C8V5S<V9U
M;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA
M;F=E<RXB"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG
M=7)O=V%N92XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-34*(RP@9G5Z>GD*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R
M9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@
M<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*
M;7-G<W1R(")59&&S;R!S:>H@=6%K='5A;&YIYB!<(B5S7"(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R
M;W1E("5S(@IM<V=S='(@(E5D8;-O('-IZB!D;V1AYB!<(B5S7"(@9&\@<WES
M=&5M=2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=61A;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*
M(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B2W+S=&MI92!S=')E
M<WIC>F5N:64Z(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8V"B,L(&9U
M>GIY"FUS9VED(")3=6X@4FES92(*;7-G<W1R(").87IW82!UOWET:V]W;FEK
M82(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HW,0HC+"!F=7IZ>0IM<V=I
M9"`B4W5N(%-E="(*;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3
M=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`T"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(DYA>G=A
M('6_>71K;W=N:6MA(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*
M;7-G<W1R(")7<V-H\V0O>F%C:/-D('.S;_%C82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#,*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4Z
M("(*;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#<*(RP@9G5Z>GD*;7-G:60@(E-U;G-E="(*
M;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#8*(RP@9G5Z>GD*;7-G:60@(E-U;G-E=#H@(@IM
M<V=S='(@(DYA>G=A('6_>71K;W=N:6MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4W5P
M97)S8W)I<'0B"FUS9W-T<B`B4&6S;GD@;W!I<SHB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#0S"B,L(&9U>GIY"FUS9VED(")3=7!P;W)T(@IM
M<V=S='(@(DEM<&]R="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U
M<FEN86TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F
M=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(").87IW82!UOWET:V]W;FEK
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-U87II(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4W=E9&5N(@IM<V=S='(@(E-Z=V5C:F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA
M;F0B"FUS9W-T<B`B4WIW86IC87)I82(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.CDW"B,L(&9U>GIY"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(D]P<O._;FEJ(&9O;&1E<B!K;W-Z82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-Y<FEA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*
M(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B57=A9VDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B
M5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E0M
M4W1O<FUS(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS
M($5A<FQY(@IM<V=S='(@(DMR\W1K:64@<W1R97-Z8WIE;FEE(@H*(SH@;&EB
M+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F
M:6QE(@IM<V=S='(@(E1Y='6S(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H
M<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(E>SL6-Z;VYE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G
M<W1R(")496PN(&MO;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<R"B,L(&9U>GIY"FUS9VED(")486)L92!P
M<F]P97)T:65S(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")486EW86XB"FUS9W-T<B`B5&%J=V%N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN82(*;7-G<W1R(")486IW86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N
M(@IM<V=S='(@(E1A9+]Y:VES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ86YI82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*(RP@9G5Z>GD*
M;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B5VEA9&]M;[;F(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$W,PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B
M6F%D86YI82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS
M9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(DYU;65R('1E;&5F;VYU
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R
M(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C$T"B,L(&9U>GIY"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")0
M;V1P:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"B,L
M(&9U>GIY"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E!O9'!I<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@
M)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP
M.C(Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEE>FYA;&5Z:6]N>2XB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B5&5M
M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-J82(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$Q"B,L(&9U>GIY"FUS9VED(")4
M97AT(@IM<V=S='(@(E1Y;&MO('1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V-PIM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E1Y;&MO('1E
M:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R
M(")4>6QK;R!T96MS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T
M<B`B5'EL:V\@=&5K<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&%J;&%N9&EA
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDR,PIM<V=I9"`B5&AA;FL@>6]U
M(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R(")$>FGJ:W5J96UY('IA
M(&MO<GIY<W1A;FEE('H@<V5R=VES=2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M-S,W"B,L(&9U>GIY"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")5=VEE<GIY=&5L;FEE;FEE(&YI92!P;W=I
M;V2S;R!S:>HB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O24U34"]";V]K+G!H<#HQ,CDT"B,L(&9U>GIY"FUS9VED(")4:&4@
M24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(")0
M;V1P:7,@;FEE(&UOOV4@8GGF('IA<W2Q<&EO;F$N(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C(Y"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*(RP@9G5Z>GD*
M;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+B(*;7-G<W1R(")4=V]R>F]N82!W:6%D;VUOMN8@>F]S=&&S82!Z86UK;FGJ
M=&$N(%=Y8VAO9'IE;FEE+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,34X
M(&QI8B](;W)D92]097)M<RYP:'`Z,38Y(&QI8B](;W)D92]097)M<RYP:'`Z
M,3@P"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3DR(&QI8B](;W)D92]097)M
M<RYP:'`Z,C`S(&QI8B](;W)D92]097)M<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,C,S(&QI8B](;W)D92]097)M<RYP:'`Z,C<R"FUS9VED
M("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H
M92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ
M>0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K='D@>F]S=&&S
M>2!P;VUYMFQN:64@9&]D86YE(&1O(%1W;VIE:B!K<VFQOVMI(&%D<F5S;W=E
M:BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,30Y"B,L(&9U>GIY
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"B)0;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4$=0(&1O
M('-P<F%W9'IE;FEA('!O9'!I<V%N96H@=VEA9&]M;[9C:2XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"B,L(&9U>GIY"FUS9VED
M("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@
M9&%T86)A<V4N(@IM<V=S='(@(E1A(&]P97)A8VIA(&YI92!J97-T(&]B<[-U
M9VEW86YA+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#(*(RP@9G5Z>GD*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B5&$@;W!E<F%C:F$@;FEE(&IE<W0@
M;V)SLW5G:7=A;F$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,3,*(RP@
M9G5Z>GD*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@
M82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(D]B<[-U9V$@;W-O
M8FES=&5G;R!K;'5C>F$@4$=0('=Y;6%G82!B97IP:65C>FYE9V\@<&^SL6-Z
M96YI82!W=W<N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S4@;&EB+TAO<F1E+G!H
M<#HT.#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B6FUI9?$@
M=7-T87=I96YI82!T<F%K=&]W86YI82!P;&EK\W<@:2!K871A;&]G\W<N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-C@@;&EB+TAO<F1E+G!H<#HT-S@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(EIM:67Q('5S=&%W:65N
M:6$@=')A:W1O=V%N:6$@<&QI:_-W(&D@:V%T86QO9_-W+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,34R"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A
M=&$N<&AP.C(V,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F
M;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS
M9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S
M92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@
M8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U
M;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B
M"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HX.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(E1OOW-A;6^VYB!<(B5S7"(@>F]S=&&S82!U<W5N
M:>IT82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-#8*;7-G
M:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#<X"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG
M('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U
M;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L
M87-S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(X-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@
M8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@
M=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O<G!M
M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H<#HS
M-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F
M="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")397)W97(@
M7"(E<UPB('IO<W1ALR!U<W5N:>IT>2XB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R=V5R(%PB)7-<
M(B!Z;W-T8;,@>F%P:7-A;GDN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(DMO;G1O(%PB)7-<
M(B!Z;W-T8;-O('IA<&ES86YE+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C(Y,`HC+"!F=7IZ>0IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D]K<F6V;&]N>2!P;&EK(&YI92!I
M<W1N:65J92XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,3`X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R(")/:W)EMFQO;GD@<&QI:R!N:64@:7-T
M;FEE:F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,P-PIM<V=I
M9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I
M;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP
M:'`Z,C0P(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R"B,L(&9U>GIY"FUS
M9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM
M<V=S='(@(E!O9'!I<R!N:64@;6^_92!B>>8@>F%S=+%P:6]N82XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$P.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@=V5A=&AE<BYC;VT@
M;FEE(&IE<W0@9&]S=.IP;GDN(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB
M"FUS9W-T<B`B3FEE(&UA(+]A9&YY8V@@9&]S=.IP;GEC:"!O<&-J:2XB"@HC
M.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Q"B,L(&9U>GIY"FUS
M9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D
M(&EN;&EN92XB"FUS9W-T<B`B3FEE(&UA(+]A9&YY8V@@86QT97)N871Y=VYY
M8V@@8WKJMF-I+"!K=/-R92!M;V>S>6)Y('IO<W1AYB!P;VMA>F%N92XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P
M+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y
M<W1E;3H@)7,B"FUS9W-T<B`B5WES=+%P:;,@<')O8FQE;2!P<GIY(&1O9&%W
M86YI=2!<(B5S7"(@9&\@<WES=&5M=3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(*;7-G<W1R("(B"B)7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N
M:74@9&%N>6-H(&1L82!UOWET:V]W;FEK82!<(B5S7"(@=R!S>7-T96UI93H@
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;3H@(@IM<V=S='(@(E=Y<W2Q<&FS('!R;V)L96T@<')Z>2!U<W5W
M86YI=2!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B5WES=+%P:;,@<')O8FQE;2!P
M<GIY('5A:W1U86QN:6%N:74@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]"
M<F]W<V5R+G!H<#HX.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.#DS"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@
M<&]D8WIA<R!W>;9W:65T;&%N:6$@=&5J(&-ZZK9C:2!W:6%D;VUOMF-I(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@<&]C>F%S(&EM<&]R=&]W86YI82!D
M86YY8V@@:4-A;&5N9&%R+B(*"B,Z(&QI8B](;W)D92]$871A+VEM8RYP:'`Z
M,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O8WIA<R!I
M;7!O<G1O=V%N:6$@9&%N>6-H(&E#86QE;F1A<BXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<Y"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B5WES
M=+%P:;,@8K.Q9"!P;V1C>F%S(&%K='5A;&EZ86-J:2!T96=O('=P:7-U.B`E
M<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*(RP@
M9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG
M('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@
M(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O
M9&-Z87,@86MT=6%L:7IA8VII('1E9V\@=W!I<W4Z("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(E=Y<W2Q
M<&FS(&*SL60@<&]D8WIA<R!A:W1U86QI>F%C:FD@=&5G;R!W<&ES=3H@)7,B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,L(&9U
M>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O9&-Z87,@86MT=6%L:7IA8VII('1E
M9V\@=W!I<W4Z("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B5&5N('-E
M<G=E<B!N:64@;V)SLW5G=6IE('5D;W-TZG!N:6%N:6$@9F]L9&5R\W<N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M(@IM<V=S='(@(E!L:6L@;FEE('=Y9VRQ9&$@;F$@<&]P<F%W;F4@87)C:&EW
M=6T@4D%2+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R
M"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II
M<"!F:6QE+B(*;7-G<W1R(")0;&EK(&YI92!W>6=LL61A(&YA('!O<')A=VYE
M(&%R8VAI=W5M(%I)4"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$T-`HC
M+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L
M:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(F9O;&1E<B`E<R!N:64@:F5S="!P
M<F%W:62S;W=Y+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB
M8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB
M9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E
M<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT
M='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDW."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U-R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`X-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(U-@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30P,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,34U.0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3@T,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`P-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`W.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U,`HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C0P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U,PHC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C8U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R-R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$S-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S<R,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S<S,0IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB"FUS9W-T<B`B5&\@<&]L92!J97-T('=Y;6%G86YE+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#$W"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#D*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B
M5&\@<&]L92!M=7-I(&)YYB!P;W!R87=NL2!L:6-Z8K$N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(X,S4*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C
M;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O
M<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0S-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N
M(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'
M<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB
M8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C4X.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T
M("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B5VEA9&]M;[;F
M('IO<W1ALV$@;F%P:7-A;F$@=R!I;FYE:B!N:;\@='=O:F$@<W1R;VYI92!K
M;V1O=V5J("@E<RDN(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*
M(RP@9G5Z>GD*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+B(*;7-G<W1R(")-=7-I<WH@=W!R;W=A9'IIYB!P<GIY;F%J;6YI96H@
M:F5D;F5G;R!A9')E<V%T82XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII
M<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@
M>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")496X@<V5R=V5R(&YI92!P
M;W1R869I(')O>G!A:V]W>7=AYB!A<F-H:7?S=R!Z:7`@:2!G>FEP+B(*"B,Z
M(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,30W"B,L(&9U>GIY"FUS9VED(")4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(E-K<GEP="!D96%K='EW;W=A;GD@<&]P<F%W;FEE+B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(DUU<VES>B!W<')O=V%D>FGF
M(&QI8WIBZBXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C,U"B,L(&9U>GIY"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(E1O(&]K;F\@;75S
M:2!Z;W-T8>8@=WEW;[-A;F4@<')Z97H@;VMN;R!K;VUP;WIY=&]R82!W:6%D
M;VUOMF-I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8T"B,L(&9U>GIY"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(DYA9&%W
M8V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(R"FUS9VED(")4
M:6-K971S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(W
M"FUS9VED(")4:6UE(@IM<V=S='(@(D-Z87,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S`X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M
M870B"FUS9W-T<B`B1F]R;6%T(&-Z87-U(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(U,S@*(RP@9G5Z>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S
M='(@(E-K87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y"FUS9VED(")4
M:71L92(*;7-G<W1R(")4>71ULR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(D1O(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R-@IM<V=I9"`B(@HB5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T
M<B`B(@HB06)Y('=Y8G)AYB!W:65L;VMR;W1N92!P;VQA('!R>GET<GIY;6%J
M('!R>GEC:7-K($-T<FP@*%!#*2!L=6(@0V]M;6%N9"`H36%C*2`B"B)P;V1C
M>F%S(&ML:6MA;FEA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.3D*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D1Z:;8B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G
M;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G
M<W1R(")4;V=O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,0IM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B2G5T<F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G
M<W1R(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-PHC+"!F=7IZ>0IM<V=I9"`B5&]P(@IM<V=S='(@
M(D1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E1R86YS
M;&%T:6]N<R(*;7-G<W1R(")0<F5Z96YT86-J92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI
M9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')Y;FED860@:2!4;V)A9V\B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y,0IM<V=I9"`B5')U92!O<B!F86QS
M92(*;7-G<W1R(")0<F%W9&$@;'5B(&9ALW-Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YE>FIA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1U<F-J82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G
M<W1R(")4=7)E8VMI("A)4T\M.#@U.2TY*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI
M<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU
M(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM
M<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3<*;7-G:60@(E4N5BX@:6YD97@Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-R!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.0IM<V=I9"`B55),(@IM
M<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E52
M3#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B56=A;F1A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56MR86EN92(*;7-G<W1R(")5:W)A:6YA(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HS,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-I
MZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N
M<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,S(V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M
M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,P."!L:6(O5D93+VUU<W%L
M+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S
M='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(")"L[%D('!O9&-Z
M87,@>FUI86YY(&1O("5S+B(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z
M,S<Q"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*
M;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@
M4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-38*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,34X(&QI8B]61E,O9FEL92YP:'`Z,38S(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C$X.`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ.3,@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q
M8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z,S`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,C<W(&QI8B]61E,O;75S<6PN<&AP.C(U."!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HR-#@*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q
M8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+VUU<W%L
M+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S
M97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ.3@*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM
M<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!3
M44PN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z-S8@;&EB+TAO
M<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@<F]Z<&%K;W=Y
M=V%N:6$@9&%N>6-H+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,S8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B0K.Q9"!P
M;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<Y(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB.B`E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z
M('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(U-"!L:6(O
M5D93+VUU<W%L+G!H<#HS,3$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S(V"B,Z
M(&QI8B]61E,O<W%L+G!H<#HS,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S
M97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0P(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C8P(&QI8B]61E,O;75S<6PN<&AP.C,R
M,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,S-@HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")"L[%D
M('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI
M8B]61E,O<W%L+G!H<#HS,SD@;&EB+U9&4R]S<6PN<&AP.C,U,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-I
MZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3<P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA
M('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(R
M-B!L:6(O5D93+VUU<W%L+G!H<#HQ-C<@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P
M"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS-S`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<X"B,Z(&QI8B]61E,O<W%L
M+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S
M97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,R.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@
M<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,C`*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!344PN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I
M9FEC871E(&1E=&%I;',B"FUS9W-T<B`B4WIC>F5G\[-Y(&-E<G1Y9FEK871U
M(@H*(SH@;&EB+TYE="])35-0+G!H<#HT-3$@;&EB+TYE="])35-0+T%U=&@N
M<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(D*SL60@<&]D
M8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HQ,CD@;&EB+U9&4R]F:6QE+G!H<#HQ,S0@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,34X"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$V,PHC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S
M='(@(D*SL60@<&]D8WIA<R!Z;6EA;GD@=7-T87=I9?$N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D*SL60@<&]D
M8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HR,#4@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3(R(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$R-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(D*SL60@<&]D
M8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HV-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,@HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S('IM:6%N>2!U<W1A=VEE\2XB"@HC.B!L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")"L[%D('!O9&-Z87,@
ML[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z-3DR"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z
M96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HQ,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<R(*;7-G<W1R("(B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M
M(%-13"XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C4Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ
M("5S+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R
M=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR.#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-3,S(&QI8B]6
M1E,O;75S<6PN<&AP.C(R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B0K.Q
M9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C(W-PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HR.3,@;&EB+U9&4R]S<6PN<&AP.C(T-0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S
M(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]M:VES;V9S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z
M96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DYI92!M;[]N82!P<GIE
M=+-U;6%C>GGF('1E9V\@9&]K=6UE;G1U(%=O<F0M82(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HQ,C(@;&EB+U9&4R]F='`N<&AP.C$R-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E
M<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$Q,@HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E
M<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P.2!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,U"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS
M9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-1
M3"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P"B,L(&9U>GIY"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B3V1T=_-R
M>B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@
M0VAA;F=E<R(*;7-G<W1R(")#;V9N:6H@>FUI86YY(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I
M9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5WIN\W<@<W=O
M:K$@<V5S:NHB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-`HC+"!F=7IZ>0IM
M<V=I9"`B56YF:6QE9"(*;7-G<W1R(")P;&EK(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B6FIE9&YO
M8WIO;F4@16UI<F%T>2!!<F%B<VMI92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D
M;VTB"FUS9W-T<B`B5VEE;&MA($)R>71A;FEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D
M(%-T871E<R(*;7-G<W1R(")54T$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8Q(&QI8B]";&]C:R]M971A<BYP:'`Z
M-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C4X(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M.`HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3D*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B3FEE>FYA;F4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N
M(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").:65Z;F%N>2!A9')E<V%T
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*(RP@
M9G5Z>GD*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM
M<V=S='(@(E!R;W-ZZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N="(*;7-G<W1R(")5<W7Q(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y
M+G!H<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B0F5Z(&YA>G=Y(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM
M<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@R"B,L(&9U>GIY"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")$
M;VUYMFQN>2!K;VQO<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C@V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E
M;G-I;VXB"FUS9W-T<B`B3FEE;V)SLW5G:7=A;F4@<F]Z<WIE<GIE;FEE(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`V(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,3@S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S
M"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B56%K='5A;&YI:B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")$;V1A:B!UOWET:V]W
M;FEK82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*
M(RP@9G5Z>GD*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D1O9&%J('6_
M>71K;W=N:6MA(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ,S<@861M:6XO<&5R
M;7,O961I="YP:'`Z,C$W('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*
M;7-G<W1R(")$;V1A:B!UOWET:V]W;FEK82(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@Q"B,L(&9U>GIY"FUS9VED(")5<&=R861E('-C<FEP="!D
M96QE=&5D+B(*;7-G<W1R(").:64@=WEG96YE<F]W86YO(+]A9&YE9V\@<VMR
M>7!T=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@Q(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#(*;7-G:60@(E5P;&]A9"(*
M;7-G<W1R("):8;-A9'5J(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M.0IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P
M<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`HC+"!F=7IZ
M>0IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")'<G5D>FEE
M\2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W=A:B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B
M57-U\2!O8F5C;F4@:VQU8WIE(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C8Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"B,L(&9U>GIY"FUS
M9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C
M:F$@=;]Y=&MO=VYI:_-W($AO<F1E(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")/<&-J92!U
MOWET:V]W;FEK82(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(@IM<V=S='(@(E)E:F5S=')A8VIA('6_>71K;W=N:6MA(@H*
M(SH@<VEG;G5P+G!H<#HR,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T
M<B`B3V)SLW5G82!F:6QT<O-W(&IE<W0@=WFSL6-Z;VYA(&YA('1Y;2!S>7-T
M96UI92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-S(@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HR-#8*(RP@9G5Z>GD*;7-G:60@(E5S97(@<&5R;6ES
M<VEO;G,B"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@R"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8@;&EB+TYE="]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y."!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8X('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*
M;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE
M(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B5;]Y=&MO=VYI:R!O
M(&YA>G=I92!<(B5S7"(@:G6_(&ES=&YI96IE+B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@
M(DYA>G=A('6_>71K;W=N:6MA.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3F%Z=V$@=;]Y
M=&MO=VYI:V$Z("(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C$Y"B,L
M(&9U>GIY"FUS9VED(")5<V5R<R(*;7-G<W1R(").87IW82!UOWET:V]W;FEK
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@
M(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E6_>71K;W=N:6-Y('<@
M<WES=&5M:64Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R(")5>F)E
M:VES=&%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,#$@;&EB+U9&4R]F:6QE
M+G!H<#HQ.#@*(RP@9G5Z>GD*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(D]K<F6V;&]N>2!P;&EK(&YI92!I<W1N:65J
M92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")6
M86-A=&EO;B(*;7-G<W1R(")786MA8VIE(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S
M.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO
M=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#4@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R-C<@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,34*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Y,C<*(RP@9G5Z>GD*;7-G:60@(E9A;'5E<R(*;7-G<W1R
M(")5=V%G:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$P(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3@W"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,@HC+"!F=7IZ
M>0IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5WFSL6-Z;VYE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(E=E;F5Z=65L82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I
M;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET
M:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW
M,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5V5R<VIA(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(P-0HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO
M;B!#;VYT<F]L(@IM<V=S='(@(E]5<')A=VYI96YI82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*(RP@9G5Z
M>GD*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(E1Y;&MO('1E:W-T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-`HC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")4
M>6QK;R!T96MS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R
M(")4>6QK;R!T96MS="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")697)Y($AI9V@B"FUS9W-T
M<B`B5WES;VMI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5VEE=&YA
M;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M
M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HY-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*
M;7-G<W1R(")7:61O:R`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*
M;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B4&]K
M8;\@<W1R;V[J(%=75R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HX,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R
M(")0;VMAOR!J86MO("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R
M:71I<V@B"FUS9W-T<B`B0G)Y='EJ<VMI92!7>7-P>2!$>FEE=VEC>F4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")7>7-P>2!$
M>FEE=VEC>F4@4W1A;O-W(%IJ961N;V-Z;VYY8V@B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Q"FUS9VED(")6:7-I
M8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--
M5%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G
M:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G
M<W1R(")786QL:7,@:2!&=71U;F$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*;7-G:60@(E=A<FYI;F<B"FUS
M9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4X"B,L(&9U>GIY"FUS9VED(")792(*;7-G<W1R
M(")75U<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G
M:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0Q-0IM<V=I9"`B5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX
M.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5U=7(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W-@HC+"!F=7IZ>0IM<V=I9"`B
M5V5B(%-I=&4B"FUS9W-T<B`B55),('-T<F]N>2(*"B,Z(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")#;R!T
M>61Z:67Q(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G
M:60@(E=E;&-O;64B"FUS9W-T<B`B5VET86UY(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4S
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B
M5VET86UY('<@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5VET86UY+"`E<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R("):86-H;V1N:2`H25-/+3@X-3DM,2DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,34I(@IM<V=S='(@(EIA8VAO9&YI("A)4T\M.#@U.2TQ-2DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B4V%H87)A(%IA8VAO9&YI82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L
M;V=I;C\B"FUS9W-T<B`B2F%KL2!A<&QI:V%C:NH@;6$@)7,@=WFV=VEE=&QA
MYB!P;R!Z86QO9V]W86YI=2!S:>H_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C$*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(T"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI
M8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@
M4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B2F%K:64@=W1Y8WIK:2!A:W1Y
M=V]W8>8@=R!2;WIB=61O=V%N>6T@961Y=&]R>F4@=&5K<W1U+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*
M(RP@9G5Z>GD*;7-G:60@(E=I9'1H(@IM<V=S='(@(D]S=')Z9;]E;FEE(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C0*(RP@9G5Z>GD*;7-G:60@(E=I
M9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("),:71W82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(E-Z97)O:V^VYB!L97=E9V\@;65N
M=2`E<R`H>FUI86YA('IA8WIN:64@;V)O=VFQ>GEW8>8@<')Z>2!N87-TZG!N
M>6T@(@HB;&]G;W=A;FEU*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"B,L(&9U>GIY"FUS9VED(")7:61T:"!U;FET(@IM<V=S
M='(@(DQI='=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#4*(RP@9G5Z>GD*;7-G:60@(E=I9'1H.B(*;7-G<W1R(")/
M<W1R>F6_96YI92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C@*
M;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B5VEN9"(*;7-G<W1R(")/<W1R>F6_
M96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8V"B,L(&9U>GIY"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(D]S=')Z
M9;]E;FEE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN
M9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U-@HC+"!F=7IZ>0IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B3W-T
M<GIEOV5N:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,P
M"B,L(&9U>GIY"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B3W-T<GIEOV5N:64B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@R"B,L
M(&9U>GIY"FUS9VED(")7:7-H;&ES=',B"FUS9W-T<B`B0FEALV$@;&ES=&$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@
M(E=O<FLB"FUS9W-T<B`B;'5B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')E<R!D;R!P
M<F%C>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR
M"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;"X@9&\@<')A8WDB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,Q"FUS9VED(")8+5)E9B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM
M<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(E)2(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(W"FUS9VED(")965E9
M(@IM<V=S='(@(E)24E(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`P,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB
M"FUS9W-T<B`B0V\@<F]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B2F5M
M96XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@U
M"FUS9VED(")997,B"FUS9W-T<B`B5&%K(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C8*;7-G:60@(EEE<RP@22!!
M9W)E92(*;7-G<W1R(")486LL('IG861Z86T@<VGJ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,3(Y-PIM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@
M(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-@HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G
M<W1R(")4=_-J(&%D<F5S(&4M;6%I;#HB"@HC.B!L:6(O2&]R9&4O1&%T82YP
M:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HY,C,*;7-G:60@(EEO=2!H879E(&)E96X@;&]G
M9V5D(&]U="XB"FUS9W-T<B`B5WEL;V=O=V&S9;8@<VGJ+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@
M86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N(@IM<V=S='(@(E1W\VH@861R97,@92UM86EL.B(*"B,Z(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N(@IM<V=S='(@(D)R86L@:V]N9FEG=7)A8VII('=E=V[J=')Z;F5J
M(&1L82!T96=O(&AO<W1A(@H*(SH@;&EB+TAO<F1E+G!H<#HT,S$*(RP@9G5Z
M>GD*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*
M;7-G<W1R(")"<F%K(&MO;F9I9W5R86-J:2!W97=NZG1R>FYE:B!D;&$@=&5G
M;R!H;W-T82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q
M"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B375S
M:7-Z(&]P:7-AYB!P<F]B;&5M('IA;FEM(&=O('=YMFQE<WHN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI
M;FL@<&]I;G1S('1O(@IM<V=S='(@(DUU<VES>B!W<')O=V%D>FGF('!R>GEN
M86IM;FEE:B!J961N96=O(&%D<F5S871A+B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(DUU<VES>B!O
M:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B
M375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U
M<W5NL>8N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")-=7-I
M<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z('5S=6ZQ
MYBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"XB"FUS9W-T<B`B375S:7-Z(&]K<F6V;&GF('6_>71K
M;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!D;V1AYBXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B375S:7-Z(&]K<F6V;&GF
M('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!D;V1AYBXB"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T
M<B`B375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S
M>B!U<W5NL>8N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@
M8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B375S:7-Z(&]K<F6V;&GF('6_>71K
M;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N(@H*(SH@;&EB+TYE="]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$Q"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(E1W\VH@861R97,@92UM86EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(P-`IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")4=_-J
M(&%D<F5S($]D.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O
M<FUA=&EO;B(*;7-G<W1R(")4=V]J92!I;F9O<FUA8VIE(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDQ-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E1W
M\VH@861R97,@:6YT97)N971O=WD@<VGJ('IM:65N:;,@;V0@<&]C>K%T:W4@
M<V5S:FD@)7,N(%<@>G=IL7IK=2!Z("(*(F)E>G!I96-Z9?%S='=E;2!4=V]J
M96=O(&MO;G1A(&UU<VES>B!Z86QO9V]W8>8@<VGJ('!O;F]W;FEE+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`B5'=O:F4@:6UIZB(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB5&5N('-Y<W1E;2!A=71E;G1Y:V%C
M:FD@;FEE(&]B<[-U9W5J92!D;V1A=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@
M=&$@;W!C:F$@(@HB>F]S=&&S82!W>;.Q8WIO;F$N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(E1E;B!S>7-T96T@875T
M96YT>6MA8VII(&YI92!O8G.S=6=U:F4@;&ES=&]W86YI82!UOWET:V]W;FEK
M\W<L(&QU8B!T82!O<&-J82`B"B)Z;W-T8;-A('=YL[%C>F]N82XB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z.3$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*(E1W\VH@861R97,@:6YT97)N971O=WD@<VGJ('IM:65N
M:;,@;V0@<&]C>K%T:W4@<V5S:FD@)7,N(%<@>G=IL7IK=2!Z("(*(F)E>G!I
M96-Z9?%S='=E;2!4=V]J96=O(&MO;G1A(&UU<VES>B!Z86QO9V]W8>8@<VGJ
M('!O;F]W;FEE+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N(@IM<V=S='(@(B(*(E1W;VIA('!R>F5G;+%D87)K82!N:64@
M;V)SLW5G=6IE('=YMG=I971L86YI82!P;&EK\W<@9W)A9FEC>FYY8V@@=&5G
M;R!T>7!U+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R
M"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD
M("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB5'=O:F$@<')Z96=LL61A
M<FMA(&YI92!O8G.S=6=U:F4@=&5J(&]P8VII(&1R=6MO=V%N:6$N($YA:F-I
MMFYI:B!#=')L+T]P8VIA("(*(BL@4"!A8GD@=WED<G5K;W=AYBXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0Y"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R(")4=V]J82!O8F5C;F$@<W1R969A(&-Z87-O
M=V$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,`IM<V=I9"`B66]U
M<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")$;VUYMFQN82!T;[]S86UO
MMN8Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B66]U
M<B!F=6QL(&YA;64Z(@IM<V=S='(@(E1W;VIE('!ELVYE(&EM:>H@:2!N87IW
M:7-K;SHB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S(@IM<V=S='(@(E1W;VEM(&YO=WEM(&AA<[-E;2!W("5S(&IE<W0Z("5S
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B5'=O:F4@=7-T87=I96YI82!Z;W-T
M8;-Y('5A:W1U86QN:6]N92!N82!C>F%S('1R=V%N:6$@=&5J('-E<VII+B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(E1W;VIE('5S=&%W
M:65N:6$@>F]S=&&S>2!U86MT=6%L;FEO;F4N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B5'=O:6T@;F]W>6T@:&%SLV5M
M('<@)7,@:F5S=#H@)7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@
M8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB
M<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T
M<B`B5'=O:F4@>F1A;&YE('-E<G=E<GDZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W.S87=I82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I
M<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")::6UB86)W92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED
M(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z-38*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T
M<B`B6U)A<&]R="!O('!R;V)L96UI95TB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG
M:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EML
M:6YE("5S(&]F("5S72(*;7-G<W1R("(E<R!D;R`E<R!Z("5S(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-#0Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*
M;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R86-J
M82(*"B,Z(&QI8B]A<&DN<&AP.C$S-@IM<V=I9"`B7T-,22(*;7-G<W1R(")?
M0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")?1&%T
M851R964B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B7U5S=?$@=VEE<G-Z(@H*(SH@;&EB+V%P:2YP:'`Z,3$V
M"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P>2(*"B,Z(&QI8B](;W)D
M92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E]0;VUO8R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B5&5L+B!K;VTN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y
M-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?6F%L;V=U:B(*"B,Z(&QI8B](
M;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E]7
M>6QO9W5J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T
M<B`B6FUI9?$@;&EN:RXN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*
M;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<&-J92(*"B,Z(&QI8B]A<&DN
M<&AP.C$R,`IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]5<')A=VYI
M96YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@
M(E5S=?$@;&EN:RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.`IM<V=I9"`B7U-E
M='5P(@IM<V=S='(@(E]+;VYF:6=U<F%C:F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*
M;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E1E;"X@:V]M
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,@IM<V=I9"`B7U5S97)S(@IM<V=S='(@
M(E]5OWET:V]W;FEC>2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DP"FUS
M9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B:W-IL;]K82!A9')E<V]W82(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#@R"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R(")K86QE;F1A<GHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W
M,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")C86QM(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HU.#D*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A
M;&QI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@U
M.0IM<V=I9"`B9FEL92(*;7-G<W1R(")P;&EK(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B)7,@9&\@)7,@>B`E
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S@*(RP@9G5Z
M>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B4VEE<G!I9?$B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")H.B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S,Q"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*(RP@9G5Z>GD*;7-G:60@(FEN;&EN92(*;7-G<W1R(").86>S\W=K:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"B,L
M(&9U>GIY"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B3F%GL_-W:VDB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,T,@IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HR.#@@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C(P-0IM<V=I9"`B;F%M92(*;7-G<W1R(").87IW:7-K;R(*"B,Z(&QI8B](
M;W)D92]24$,N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B;F]T(&EM<&QE;65N
M=&5D(@IM<V=S='(@(E5K;_%C>F]N92(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,3(Q.0HC+"!F=7IZ>0IM<V=I9"`B;F]T('EE="!I;7!L96UE
M;G1E9"(*;7-G<W1R(")482!O<&-J82!N:64@:F5S="!J97-Z8WIE('IAL[%C
M>F]N82XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@W-`IM<V=I9"`B;F]T
M97!A9"(*;7-G<W1R(")N;W1A=&YI:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*(RP@9G5Z>GD*;7-G:60@
M(G!E<F-E;G0B"FUS9W-T<B`B1')U:W5J(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B3W)G
M86YI>F%T;W(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDX"FUS9VED
M(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@
M2%144"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S4X"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@HC+"!F=7IZ>0IM<V=I
M9"`B<W1E861Y(@IM<V=S='(@(DYO=&%T;FEK("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HX.3@*(RP@9G5Z>GD*;7-G:60@(G1A<VL@;&ES="(*;7-G
M<W1R(")#>F%R;F$@;&ES=&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")(87.S
M;R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G!L
M:6LB"@HC.B!L:6(O2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN
M86UE9"(*;7-G<W1R(")B97H@;F%Z=WDB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R
M(")7>6+S<B!K;VQO<G4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*(RP@9G5Z>GD*
M;7-G:60@(G<Z(@IM<V=S='(@(D9W9#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]P=%]"4BYP;P``````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S,S
M-S,U`#$P-#$W,S8S,#`S`#`Q-C0Q-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````C('1R86YS;&%T:6]N(&]F(&AO<F1E+G!O
M('1O($)R87II;&EA;B!0;W)T=6=U97-E"B,@0V]P>7)I9VAT("A#*2!914%2
M($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD
M97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(PHC
M($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB<CXL(#(P,#8N"FUS9VED
M("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D95QN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,34@,38Z-3`M,#(P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!&86)I;R!';VUE<R`\9FQG;VUS0'5O;"YC;VTN
M8G(^7&XB"B),86YG=6%G92U496%M.B!"<F%Z:6QI86X@4&]R='5G=65S92`\
M:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E@M
M1V5N97)A=&]R.B!+0F%B96P@,2XS+C%<;B(*(E!L=7)A;"U&;W)M<SH@(&YP
M;'5R86QS/3([('!L=7)A;#TH;B`^(#$I.UQN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A
M>7,@86=O*2(*;7-G<W1R("(@*"5S(&1I87,@871RX7,I(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<T"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%1E8VQA(&1E($%T86QH;R`E
M<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AE;2`E<R!D
M:6%S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*;7-G:60@
M(B`H=&]D87DI(@IM<V=S='(@(B`H:&]J92DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@
M*&%M86YHXRDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS
M9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AO;G1E;2DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@82`B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@3N-O(.D@
M=6T@9&ER973S<FEO+B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H
M;VEC92XB"FUS9W-T<B`B)R5S)R!NXV\@Z2!U;6$@97-C;VQH82!VX6QI9&$N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@;N-O(&5S=.$@
M8V]N9FEG=7)A9&\@;F\@4F5G:7-T<F\@9&\@2&]R9&4N(@H*(SH@9G)A;65W
M;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B<F5N9&5R
M:7IA9&]R(&1E(.%R=F]R92!<(B5S7"(@;N-O(&5N8V]N=')A9&\N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<
M(B5S7"(@9F]I(&%D:6-I;VYA9&\@86\@<VES=&5M82!D92!G<G5P;W,N(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y
M<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&9O:2!A9&EC:6]N861O(&%O('-I<W1E
M;6$@9&4@<&5R;6ES<_5E<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(G)7-<
M(B!NXV\@9F]I(&-R:6%D;SH@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!U<V%D;W,@
M9&4E+C)F34(@<&5R;6ET:61O<R`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&4@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(E9"!D:6%S(&%TZ2!S=6$@<V5N
M:&$@97AP:7)A<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G
M<W1R("(E9"!P<F5V:7/C;R!D;R!D:6$B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B
M"FUS9W-T<B`B)7,@+2!!=FES;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E
M<G!R:6YT(@IM<V=S='(@(DEM<')E<W/C;R!$:6=I=&%L(&1E("5S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S($]P
M97)AY_5E<R!D92!-86YU=&5NY^-O("T@0V]N9FER;6'GXV\B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B0V]N
M9FEG=7)AY^-O(&1E("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM
M<V=S='(@(D-A9&%S=')O(&1E("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G
M<F5E;65N="(*;7-G<W1R("(E<R!497)M;W,@9&\@06-O<F1O(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT.30*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#(@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&KA(&5X:7-T
M92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!A("5S
M("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@97-TX2!P<F]N=&\@
M<&%R82!E>&5C=71A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!M87)C
M861A<R!A8F%I>&\N("(*(DUA<G%U92!A(&-A:7AA('!A<F$@<75A;'%U97(@
M;W!E<F'GXV\@<75E('9O8^H@<75E:7)A(&5X96-U=&%R(&1E<W1A('9E>BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(.D@;V)R:6=A
M=/-R:6\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T;W,B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@
M;N-O(&5N8V]N=')A9&\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*
M;7-G<W1R("(E<R!A("5S(&1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B0V%TX6QO9V\@9&4@16YD97)EYV]S(&1E("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$@9&4@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B06YO=&'G]65S(&1E
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("),:7-T82!D
M92!487)E9F%S(&1E("5S(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M
M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*
M(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W
M:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z
M($5S=&$@;65N<V%G96T@<&]D92!NXV\@<V5R(&1E('%U96T@96QA(&1I>B!S
M97(N(%1O;64@8W5I9&%D;R!C;VT@(@HB<75A;'%U97(@;&EN:R!P<F5S96YT
M92!N96QA(&]U(&5M(&9O<FYE8V5R(&%O(')E;65T96YT92!Q=6%L<75E<B!I
M;F9O<FUAY^-O("(*(G!E<W-O86PN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY
M"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@8G)I<V$@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@
M(BP@8G)I<V$@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B
M"FUS9W-T<B`B+"!V87)IX79E;"!D92`E<R!P87)A("5S(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W
M,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3,R"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HW-#8*;7-G:60@(BTM('-E;&5C
M="`M+2(*;7-G<W1R("(M+2!S96QE8VEO;F4@+2TB"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O
M<FUA=&\@,3(@2&]R87,B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G
M:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@,C0@2&]R87,B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U
M<G,B"FUS9W-T<B`B,C0@:&]R87,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/%#A9VEN82!!
M;G1E<FEO<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(E5M(&-O;F5C=&]R(&1E(&)A;F-O(&1E(&1A9&]S(.D@;V)R
M:6=A=/-R:6\@<&%R82!E<W1E(&)L;V-O+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R(")5;2!E<G)O(&9A=&%L(&]C;W)R974B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(E5M82!C:&%V92!P^F)L:6-A(%!'4"#I(&]B<FEG873S<FEA('!A
M<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("(B"B)5;6$@8VAA=F4@</IB;&EC82!01U`@Z2!O8G)I9V%T\W)I
M82!P87)A('9E<FEF:6-A<B!U;6$@;65N<V%G96T@87-S:6YA9&$N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM
M<V=S='(@(B(*(E5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!S96YH82!S
MXV\@;V)R:6=A=/-R:6%S('!A<F$@9&5S8W)I<'1O9W)A9F%R('5M82`B"B)M
M96YS86=E;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@HB56UA(&-H879E('!R:79A9&$@4$=0(&4@
M=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I87,@<&%R82!A<W-I;F%R('5M82!M
M96YS86=E;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E5M82!C:&%V92!P^F)L
M:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-24U%(&4@=6UA('-E
M;FAA('/C;R`B"B)O8G)I9V%T\W)I87,@<&%R82!D97-C<FEP=&]G<F%F87(@
M=6UA(&UE;G-A9V5M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB56UA(&-H879E('#Z
M8FQI8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@
M<V5N:&$@<^-O("(*(F]B<FEG873S<FEA<R!P87)A(&%S<VEN87(@=6UA(&UE
M;G-A9V5M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E5M82!C:&%V92!P^F)L:6-A
M(%,O34E-12#I(&]B<FEG873S<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M82!M
M96YS86=E;2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B3G5V96YS(&UA='5T
M:6YA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(D-H=79A($9R86-A
M(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")#:'5V82!M871U
M=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D-H=79A<R!M871U=&EN
M87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(DYE=F%S8V%S($UA
M='5T:6YA<R(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED
M(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM
M<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S
M='(@(E-O8G)E(&5S=&4@961I=&]R(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(E-O8G)E+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM
M<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(D%B<V)O='1O;2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R(")!8G-M:61D;&4B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D%C97-S;R!N96=A9&\@86\@
M8W)I87(@9&ER973S<FEO(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+B(*;7-G<W1R(")!8V5S<V\@;F5G861O(&%O(&-R:6%R(&%R<75I
M=F\@5D93+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!
M8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E-U87,@26YF;W)M8>?U97,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`B4V5N:&$@9&$@0V]N=&$B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@
M(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")#;VYT82!D97-A=&EV861A+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U
M;G1I;F<B"FUS9W-T<B`B0V]N=&%S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED
M(")!9&0B"FUS9W-T<B`B061I8VEO;F%R(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'
M<F]U<"(*;7-G<W1R(")!9&EC:6]N87(@1W)U<&\@4W5B;W)D:6YA9&\B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S
M:6]N(@IM<V=S='(@(D%D:6-I;VYA<B!097)M:7-S]65S(%-U8F]R9&EN861A
M<R(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@
M2&5R93HB"FUS9W-T<B`B061I8VEO;F4@07%U:3HB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE
M=R!'<F]U<"(*;7-G<W1R(")!9&EC:6]N87(@3F]V;R!'<G5P;R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM
M<V=S='(@(D%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C;R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(D%D
M:6-I;VYA<B!U;2!G<G5P;R!S=6)O<F1I;F%D;R!A("<E<R<B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R
M(")!9&EC:6]N87(@=6UA('!E<FUI<W/C;R!S=6)O<F1I;F%D82!A("<E<R<B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z
M(@IM<V=S='(@(D%D:6-I;VYA<B!U;2!N;W9O('5S=>%R:6\Z(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B
M061D(&-O;'5M;B(*;7-G<W1R(")!9&EC:6]N87(@8V]L=6YA(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE
M=R!M96UB97)S(@IM<V=S='(@(D%D:6-I;VYA<B!N;W9O<R!M96UB<F]S(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A
M:7(B"FUS9W-T<B`B061I8VEO;F%R('!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(D%D:6-I;VYA<B!O
M($UE;G4@)7,@8V]M;R!U;6$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS
M9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")!9&EC:6]N87(@
M86\@8V%TX6QO9V\@9&4@96YD97)EYV]S.B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D
M9')E<W,@8F]O:R(*;7-G<W1R(")!9&EC:6]N87(@86\@;65U(&-A=.%L;V=O
M(&1E(&5N9&5R9>=O<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!
M9&0@=7-E<B(*;7-G<W1R(")!9&EC:6]N87(@=7-UX7)I;R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(B<E
M<R<@861I8VEO;F%D;R!A;R!S:7-T96UA+"!M87,@;N-O('!U9&4@:6YC;'5I
M<B!I;F9O<FUAY_5E<R!A9&EC:6]N86ES(&1O("(*(F-A9&%S=')O.B`E<RXB
M"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM
M<V=S='(@(B5S(&%D:6-I;VYA9&\@86\@<VES=&5M82X@5F]CZB!P;V1E('-E
M(&-O;F5C=&%R(&%G;W)A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(D%D:>?C;R!D92!U<W7A<FEO<R!E<W3A(&1E<V%B:6QI=&%D82XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-0IM<V=I9"`B061D<F5S<R(*
M;7-G<W1R(")%;F1E<F7G;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")#873A;&]G;R!D
M92!%;F1E<F7G;W,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<W1R87(@+2!C;VYF
M:6=U<F$@<&5R;6ES<_5E<R!P87)A(&]U=')O<R!U<W7A<FEO<R(*"B,Z(&%D
M;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A
MY^-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I9"`B
M061S(@IM<V=S='(@(D%N^FYC:6]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G
M:&%N:7-T86XB"FUS9W-T<B`B069E9V%N:7-TXV\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8N)N:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")!;&=E<FEA(@IM<V=S='(@(D%R9^ER:6$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*
M;7-G<W1R(")!<&5L:61O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B
M06QI;FAA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B06QI;FAA;65N
M=&\Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB
M"FUS9W-T<B`B5&]D;W,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!
M;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")4;V1O<R!5<W7A<FEO
M<R!!=71E;G1I8V%D;W,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E1O
M9&]S($=R=7!O<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I
M9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1O9&%S(%!E<FUI<W/U97,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")4;V1O<R!Q
M=6%T<F\@;&%D;W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U
M"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B4&5R
M;6ET:7(@;?IL=&EP;&]S(&5N9&5R9>=O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_(@IM<V=S='(@(E!E<FUI=&ER(&-O;F9I9W5R87(@;R!T:7!O
M(&1E(&QI<W1A<R!O<F1E;F%D87,_(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*
M;7-G<W1R(")*X2!E>&ES=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("),;V=I
M;B!)35-0($%L=&5R;F%T:79O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B
M4V5N:&$@24U34"!!;'1E<FYA=&EV82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S
M='(@(E5S=>%R:6\@24U34"!!;'1E<FYA=&EV;R(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D
M<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!D92!E+6UA:6P@86QT97)N871I=F\B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E
M('1E;7!L871E<R(*;7-G<W1R(")-;V1E;&]S(&%L=&5R;F%T:79O<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E1E>'1O
M(&%L=&5R;F%T:79O.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A
M;6]A(@IM<V=S='(@(E-A;6]A($%M97)I8V%N82(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"XB"FUS9W-T<B`B56T@=F%L;W(@:6QE9V%L(&9O:2!E<W!E8VEF:6-A9&\N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B
M06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B3V-O<G)E
M=2!U;2!E<G)O(&1E<V-O;FAE8VED;RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!
M;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T
M<B`B4')O>'D@86[T;FEM;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B4F5S<&]S=&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=.%R=&ED82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T
M<B`B06YT:6=U82!E($)A<F)A9&]S(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI8V'GXV\B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T
M:6]N($QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@07!L:6-AY_5E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES
M(')E861Y+B(*;7-G<W1R(")!(&%P;&EC8>?C;R!E<W3A('!R;VYT82XB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@
M=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P;&EC87(@86]S($-O;7!A<G1I
M;&AA;65N=&]S(%-U8F]R9&EN861O<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(D%P
M<F]V87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-#`*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B5&%M86YH;R!!
M<')O>&EM861O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%B<FEL(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ
M,C4V*2(*;7-G<W1R(")!<N%B:6-O("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3
M:7IE(@IM<V=S='(@(E1A;6%N:&\@9&\@07)Q=6EV;R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T
M<B`B3F]M92!D;R!!<G%U:79O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@/R(*;7-G<W1R(")6;V/J('1E;2!C97)T97IA('%U92!Q=65R
M(')E;6]V97(@82!S;VQI8VET8>?C;R!D92!C861A<W1R;R!D92`E<S\B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(E9O8^H@=&5M
M(&-E<G1E>F$@<75E(&1E<V5J82!E>&-L=6ER("<E<R<@92!S975S('-U8F=R
M=7!O<S\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
M07)G96YT:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R
M(")!<FWJ;FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@
M(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;>IN:6\@*$%235-#
M24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R
M="(*;7-G<W1R(")!<G1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS
M9W-T<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(DEL:&$@07-C96YS
MXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI
M($%R="(*;7-G<W1R(")!<G1E($%S8VEI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM
M<V=S='(@(L%S:6$O4F5G:>-O(&1O(%!A8^UF:6-O(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@
M(E-O;&EC:71A<B!C;VYF:7)M8>?C;R!A;G1E<R!D92!E>&5C=71A<B!A<R!O
M<&5R8>?U97,@9&4@;6%N=71E;N?C;S\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3`R"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T
M<B`B0V]L=6YA<R!D92!D97-I9VYAY^-O(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M9W)O=7`N(@IM<V=S='(@(E1E;G1O=2!E>&-L=6ER('5M(&=R=7!O(&EN97AI
M<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(E1E;G1O=2!E>&-L=6ER('5M82!P97)M:7-SXV\@;N-O(&5X
M:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(E1E;G1O=2!E9&ET87(@=6UA('!E<FUI<W/C;R!NXV\@97AI<W1E
M;G1E+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R
M(")496YT;W4@961I=&%R('5M(&-O;7!A<G1I;&AA;65N=&\@;N-O(&5X:7-T
M96YT92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B
M071T<FEB=71E<R(*;7-G<W1R(")!=')I8G5T;W,B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM
M<V=S='(@(D%G;W-T;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*
M;7-G<W1R(")!=7-T<N%L:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA
M(@IM<V=S='(@(L%U<W1R:6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@
M3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:6UA<"!N96-E<W/A<FEA
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I
M9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!/(&-O;F5C=&]R
M(&[C;R!P;W-S=6D@87,@8V%P86-I9&%D97,@;F5C97-SX7)I87,N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?8WER=7,Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N
M<^-O(&EM87`@;F5C97-SX7)I82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($[C
M;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($944"!N96-E<W/A<FEA+B!#
M;VUP:6QE(&\@4$A0(&-O;2!A("(*(F]PY^-O("TM96YA8FQE+69T<"XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H
M7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]I;6%P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C
M;R!I;6%P(&YE8V5S<^%R:6$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@3N-O(&9O
M:2!E;F-O;G1R861A(&$@97AT96YSXV\@:W)B-2!N96-E<W/A<FEA+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H
M7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@26YC;'5SXV\@9&4@
M=7-UX7)I;W,@;N-O(.D@<W5P;W)T861A('!A<F$@06-T:79E($1I<F5C=&]R
M>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED
M(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!%>&-L
M=7/C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@
M1&ER96-T;W)Y(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV
M,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@3N-O(&9O:2!E;F-O;G1R
M861A(&$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L9&%P.B!)
M;7!O<W/M=F5L(&%D:6-I;VYA<B!O('5S=>%R:6\@)7,N($ES=&\@9F]I(&\@
M<75E(&\@<V5R=FED;W(@(@HB<F5P;W)T;W4Z("(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U
M=&A?;&1A<#H@26UP;W-S[79E;"!R96UO=F5R(&\@=7-UX7)I;R`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M(@IM<V=S='(@(D%U=&A?;&1A<#H@26UP;W-S[79E;"!A='5A;&EZ87(@;R!U
M<W7A<FEO("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T
M:%]L9&%P.B!!='5A;&EZ8>?C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A
M9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@
M34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ
M($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($U#04P@;F5C97-SX7)I
M82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@
M(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z($[C;R!F;VD@96YC;VYT
M<F%D82!A(&5X=&5N<^-O('-M8F%U=&@@;F5C97-SX7)I82XB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T96YT
M:6-AY^-O(&YO('-E<G9I9&]R($E-05`@9F%L:&]U+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D9A;&AA(&YA(&%U=&5N
M=&EC8>?C;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B1F%L:&$@;F$@875T96YT:6-A
MY^-O.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N(@IM<V=S='(@(D%U=&5N=&EC8>?C;R!R96IE:71A9&$@<&5L;R!S
M97)V:61O<B!2041)55,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R(")!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!&5%`@
M9F%L:&]U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B02!A=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@4TU"(&9A;&AO
M=2XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!
M=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#86UP;W,@9&ES<&]N[79E:7,Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R
M8F%I:N-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"
M3T9(($5X8W5S97,B"FUS9W-T<B`B1&5S8W5L<&%S(&1O($)/1D@B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X
M"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D9U;F1O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C
M:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")#;W(@9&4@1G5N9&\B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R
M;W,@<&%S<W=O<F0N(@IM<V=S='(@(E-E;FAA(&ME<F)E<F]S(&EN8V]R<F5T
M82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED
M(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(E5S=>%R:6\@:V5R
M8F5R;W,@:6YC;W)R971O+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B
M"FUS9W-T<B`B0F%H86UA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB
M"FUS9W-T<B`B0F%H<F%I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V
M"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"X6QT:6-O
M("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H
M(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B
M861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").XV\@9F]I(&5N
M8V]N=')A9&\@;R!D:7)E=/-R:6\@8F%S92!D92!I;6%G96YS("<E<R<N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("),:6YH82!D92!087)T:61A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")"96QO<OIS
M<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"Z6QG
M:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")"=73C;R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G
M:60@(D)I<G1H9&%Y(@IM<V=S='(@(D%N:79E<G/A<FEO(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B3N-O(&9O:2!E;F-O;G1R861O(&\@8FQO
M8V\@7"(E<UPB(&1A(&%P;&EC8>?C;R!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*
M;7-G<W1R(")#;VYF:6=U<F'G]65S(&1O($)L;V-O(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S
M='(@(E1I<&\@9&4@0FQO8V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B3F5G<FET
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L[79I
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O
M;VMM87)K<R(*;7-G<W1R(")&879O<FET;W,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B0F]R9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R("),87)G=7)A(&1A(&)O<F1A.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E
M<G,B"FUS9W-T<B`B0F]R9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")"\W-N:6$@92!(97)Z96=O=FEN
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*
M;7-G<W1R(")!;6)O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(D)O='-U86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B
M4F]D87#I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G
M<W1R("));&AA($)O=79E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*
M;7-G<W1R(")"<F%S:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(E1E<G)I=/-R:6\@9&\@
M3V-E86YO(,UN9&EC;R!);F=LZG,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QGX7)I82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE
M=&5D($QI<W0B"FUS9W-T<B`B3&ES=&$@8V]M($UA<F-A9&]R97,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&
M87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U
M;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B
M0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B4&]N=&]S(&1E($1I<W1R
M:6)U:>?C;R!#4DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A($/I7VQU;&$N+BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")#86-H92!I
M;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(")!(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@S(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U
M-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B06=E;F1A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R
M(")#86QM;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R
M(")#86UB;V1J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S
M='(@(D-A;6%R]65S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D[C
M;R#I('!O<W/M=F5L(&=E<F%R('5M82!N;W9A('-E;FAA(&%U=&]M871I8V%M
M96YT92P@96YT<F4@96T@8V]N=&%T;R!C;VT@;R`B"B)A9&UI;FES=')A9&]R
M+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM
M<V=S='(@(D[C;R!C;VYS:6=O(&=R879A<B!O(&%R<75I=F\@7"(E<UPB(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES
M=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(D[C;R#I
M('!O<W/M=F5L(&%D;6EN:7-T<F%R(&=E<F5N8VEA9&]R97,@97AT97)N;W,@
M9&4@<V5S<^-O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S(@IM<V=S='(@(D[C;R#I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I
M9&]R($E-05`Z("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(D[C;R!C;VYS:6=O(&%B<FER(&\@87)Q=6EV;R!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A;F%D
MX2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D-A
M;F-E;&%R(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*
M;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")#86YC96QA
M<B!296QA=/-R:6\@9&4@4')O8FQE;6$B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L
M971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@Z2!P;W-S[79E;"!E>&-L
M=6ER(&\@87)Q=6EV;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@
M=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3N-O(.D@<&]S<^UV96P@
M96YC;VYT<F%R('5M(&1I<F5T\W)I;R!T96UP;W+A<FEO+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB
M"FUS9W-T<B`B3N-O(.D@<&]S<^UV96P@8V]N=&EN=6%R('-E;2!O('!A<N)M
M971R;R`G=&%R9V5T1FEL92<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").XV\@Z2!P;W-S[79E;"!E>&-L
M=6ER(&\@9&ER973S<FEO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(D[C;R#I('!O<W/M
M=F5L(&5X8VQU:7(L("5D('!O<W-U:2!S=6)O<F1I;F%D;W,N(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B
M"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB
M"FUS9W-T<B`B(@HB3N-O(.D@<&]S<^UV96P@<F5O<F1E;F%R+"!N^FUE<F\@
M9&4@<F5G:7-T<F]S(&9O<FYE8VED;W,@<&%R82!R96]R9&5N87(@;N-O("(*
M(F-O<G)E<W!O;F1E(&%O(&[Z;65R;R!A<FUA>F5N861O+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I
M9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB
M"FUS9W-T<B`B3N-O(.D@<&]S<^UV96P@<F]T96%R(&UE;G-A9V5M('!A<F$@
M;R!N^FUE<F\@97-P96-I9FEC861O+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A
M<&4@5F5R9&4B"FUS9W-T<B`B0V%B;R!697)D92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A
M<'1I;VXB"FUS9W-T<B`B5.UT=6QO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S
M='(@(D]P97)A9&]R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM
M<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(D-A=&5G;W)I
M87,@92!.;VUE<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD
M<R(*;7-G<W1R("));&AA<R!#87EM86XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM
M<V=S='(@(E1E;&5F;VYE($-E;'5L87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R
M;W!E<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A($/I;'5L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS
M9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(DUA<F=E;2!D82!CZ6QU;&$Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R
M:65D861E<R!D82!#Z6QU;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G
M<W1R(")%<W!AYV%M96YT;R!D82!CZ6QU;&$Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E
M;&5F;VYE(&-E;'5L87(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM
M<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0^EL=&EC;R`H
M25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(D-E
M;G1R;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U
M8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@9&$@P69R:6-A($-E;G1R86PB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B175R;W!A($-E;G1R86P@*$E3
M3RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B1&5T
M86QH97,@9&\@0V5R=&EF:6-A9&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS
M9W-T<B`B4')O<')I973A<FEO(&1O($-E<G1I9FEC861O(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC
M871E(%!O;&EC:65S(@IM<V=S='(@(E!O;.UT:6-A<R!D;R!#97)T:69I8V%D
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")48VAA9&4B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B
M06QT97)A<B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM
M<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)E(%-U
M82!396YH82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B
M(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E
M92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N
M(@IM<V=S='(@(B(*(D%L=&5R87(@;R!N;VUE(&4@;R!E;F1E<F7G;R!Q=64@
M87,@<&5S<V]A<R!VZF5M('%U86YD;R!E;&%S(&SJ96T@92!R97-P;VYD96T@
M(@HB<W5A<R!M96YS86=E;G,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES
M(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N
M+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M(D%L=&5R8>?C;R!D92!S96YH82!NXV\@Z2!S=7!O<G1A9&$@;F$@8V]N9FEG
M=7)AY^-O(&%T=6%L+B`@16YT<F4@96T@8V]N=&%T;R`B"B)C;VT@;R!A9&UI
M;FES=')A9&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B0VAA<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B5F5R:69I
M8V%R($QI;E]K+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T
M<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R(")#
M:&EN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B0VAI;NIS(%-I;7!L
M:69I8V%D;R`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P
M"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")#
M:&ENZG,@5')A9&EC:6]N86P@*$)I9S4I(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R
M(")%<V-O;&AA(&$@07!L:6-AY^-O.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM
M<V=S='(@(D5S8V]L:&$@=6UA('-E;FAA(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B
M"FUS9W-T<B`B17-C;VQH82!U;2!U<W7A<FEO(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.B(*;7-G<W1R(")%<V-O;&AA(&-O;6\@97AI8FER(&1A=&%S.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E
M<F5D(&QI<W1S*2(*;7-G<W1R(")%<V-O;&AA(&\@=&EP;R!D92!E<W1I;&\@
M9&4@;&ES=&%S("AP87)A(&QI<W1A<R!O<F1E;F%D87,I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("));&AA<R!#:')I
M<W1M87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").XV\@
M9F]I(&5N8V]N=')A9&$@82!D969I;FGGXV\@9&4@8VQA<W-E(&1E("5S+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS
M9VED(")#;&5A<B(*;7-G<W1R("),:6UP87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F
M9FEC92!T86=S(@IM<V=S='(@(DQI;7!A<B!T86=S($U33V9F:6-E(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB"FUS
M9W-T<B`B17AC;'5I<B!U<W7A<FEO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T
M('5S97(Z("5S(@IM<V=S='(@(D5X8VQU:7(@=7-UX7)I;SH@)7,B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R
M('5S97(B"FUS9W-T<B`B17AC;'5I<B!U<W7A<FEO(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R(")%>&-L=6ER(&1A9&]S(&1O('5S=>%R:6\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE
M87)I;F<@3&%T92(*;7-G<W1R(")#Z74@86)E<G1O(&$@5&%R9&4B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I
M9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B0VQI<75E('!A<F$@0V]N
M=&EN=6%R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S
M='(@(D-L:6-K871E;&P@=FEA($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@
M(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")&96-H87(@2F%N96QA(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*;7-G<W1R(").
M=79E;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DYU8FQA9&\@<&5L
M82!-86YHXR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B3G5B;&%D;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(DEL:&%S(&1E($-O8V]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R
M+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")#;VYT
M<F%I<B!"87)R82!,871E<F%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O
M<F1E<G,B"FUS9W-T<B`B0V]N=')A:7(@8F]R9&%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B0V]L]&UB:6$B"@HC.B!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM
M<V=I9"`B0V]L;W(B"FUS9W-T<B`B0V]R(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,#$@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(E!A
M;&AE=&$@9&4@0V]R97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#,U"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E-E;&7GXV\@
M9&4@0V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(D-O;',Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU,`IM<V=I9"`B0V]L=6UN('1I=&QE
M<R(*;7-G<W1R(")4[71U;&]S(&1A<R!#;VQU;F%S(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(E%U
M861R:6YH;W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O
M;6UA;F0B"FUS9W-T<B`B0V]M86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("),:6YH82!D92!#
M;VUA;F1O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;65N=&%R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(DYO;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O
M<R(*;7-G<W1R(")#;VUO<F]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")%
M;7!R97-A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#
M;VUP=71E<G,B"FUS9W-T<B`B0V]M<'5T861O<F5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S
M='(@(D-O;F1IY^-O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G
M:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B0V]N9&GG]65S(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,B"FUS9W-T<B`B1&EF97)E;N=A<R!D92!#;VYF:6=U<F'GXV\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U
M=&QO;VLN(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!D92!S:6YC<F]N:7IAY^-O
M(&-O;2!01$%S+"!3;6%R='!H;VYE<R!E($]U=&QO;VLN(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O
M=70@;V8@9&%T92XB"FUS9W-T<B`B0V]N9FEG=7)AY^-O(&YE8V5S<VET82!D
M92!A='5A;&EZ8>?C;RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")#
M;VYF:6=U<F%R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")#;VYF
M:7)M92!A(%-E;FAA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T
M<B`B0V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(D-O;F=O+"!297#Z8FQI
M8V$@1&5M;V-RX71I8V$@9&\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`B1F%L:&$@;F$@8V]N97CC;RXB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@(@IM<V=S='(@(D9A;&AA(&YA(&-O;F5XXV\Z("(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")#;VYE
M>.-O(')E8W5S861A('!E;&\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")#;VYE
M>.-O(')E8W5S861A('!E;&\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S
M+B!-;W1I=F\Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@W-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B02!C;VYE>.-O(&%O('-E<G9I9&]R($944"!F86QH;W4N
M(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A
M8W1S(@IM<V=S='(@(D-O;G1A=&]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B(@HB3W,@8V]N=&%T;W,@9F]R86T@861I8VEO;F%D;W,@8V]M('-U8V5S
M<V\@86\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT
M('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B5&EP92!D92!C
M;VYT9?ID;R!D;R!A<G%U:79O(&-O;7!R:6UI9&\Z("(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E
M;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")#;VYT9?ID;R!D92`G)7,G(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")#;VYT
M:6YU87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T
M<B`B26QH87,@0V]O:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM
M<V=I9"`B0V]O:VEE(@IM<V=S='(@(D-O;VMI92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B
M0V]P>2(*;7-G<W1R(")#;W!I87(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B1F%L:&$@;F$@8_-P:6$Z("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S
M96QE8W1I;VXB"FUS9W-T<B`B0V]P:6%R('-E;&7GXV\B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*
M;7-G<W1R("))1"!D92!#=7-T;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A
M(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B0V]S=&$@9&\@36%R9FEM(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DEM<&]S<^UV
M96P@8W)I<'1O9W)A9F%R(&$@;65N<V%G96T@8V]M(%!'4#H@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R("));7!O<W/M=F5L(&%S
M<VEN87(@82!M96YS86=E;2!C;VT@4$=0.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M8W)I<'1O9W)A9F%R(&$@;65N<V%G96T@8V]M(%,O34E-12XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*
M;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA<B!C;VYT871O+B`E
M<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S
M97)V:61O<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!V97)I9FEC87(@;R!S86QD;RX@)7,B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S
M97)V:61O<B!,1$%0+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B`G)7,G('5T:6QI>F%N9&\@1E10
M.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@8W)I87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R("));7!O<W/M=F5L
M(&1E<V-R:7!T;V=R869A<B!O<R!D861O<R!01U`Z("(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!D97-C<FEP=&]G<F%F87(@;R!D861O(%,O34E-12XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!O(&-O;G1A=&\N("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!E>&-L=6ER(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5X8VQU:7(@;R!S8W)I<'0@
M9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O("<E<R<N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M
M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&\@96YD97)EYV\@9&4@92UM
M86EL(&1O(&1E<W1I;F%TX7)I;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&\@8V%TX6QO9V\@9&4@96YD
M97)EYV]S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@8V]M<&QE=&%M96YT92!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@HB3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&$@;&ES=&$@9&4@;&ES=&%S
M(&1E(&1I<W1R:6)U:>?C;RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C
M87)R96=A<B!A(&5S=')A=.EG:6$@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&-R:6%R(&\@9&ER973S<FEO("<E<R<N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@8VAA=F4@</IB;&EC82!A
M('!A<G1I<B!D;R!S97)V:61O<B!D92!C:&%V97,N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@86)R:7(@)R5S)R!P87)A(&=R879AY^-O+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!A8G)I<B`E<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO("=-86EN=&5N
M86YC95]487-K)R`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@9&ER973S<FEO
M("<E<R<N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q
M,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L('!E<W%U:7-A<B!N;R!S97)V:61O<B!,1$%0+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&QE<B`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX
M-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@
M=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@9V5R87(@=6UA(&YO=F$@
M<V5N:&$@<&%R82!O('5S=>%R:6\@<V]L:6-I=&%D;RX@06QG=6YS(&]U("(*
M(G1O9&]S(&]S(&1E=&%L:&5S(&[C;R!E<W3C;R!C;W)R971O<RX@5&5N=&4@
M;F]V86UE;G1E(&]U(&5N=')E(&5M(&-O;G1A=&\@(@HB8V]M(&\@861M:6YI
M<W1R861O<B!S92!V;V/J(&YE8V5S<VET82!D92!M86ES(&%J=61A+B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O
M8G1E<B!A($%#3"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@;R!C873A;&]G;R!D92!E;F1E<F7G;W,N("5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@
M87,@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&]B=&5R(&%S(&-A<&%C:61A9&5S(&1O('-E<G9I9&]R(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(')E=F5R=&5R(&$@8V]N9FEG=7)AY^-O+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@
M7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!D
M:7)E=/-R:6\@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L('-A;'9A<B!A
M(&-O;F9I9W5R8>?C;R`E<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!S86QV87(@=6T@8F%C:W5P(&1A(&-O;F9I9W5R8>?C;RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@
M9&$@8V]N9FEG=7)AY^-O.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*(D[C
M;R!F;VD@<&]S<^UV96P@<V%L=F%R(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O
M(&1E(&-O;F9I9W5R8>?C;R!E;3H@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R
M(").XV\@8V]N<V5G=6D@<V%L=F%R(&\@8F%C:W5P(&1O(&%R<75I=F\@9&4@
M8V]N9FEG=7)AY^-O("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@
M)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS
M9W-T<B`B(@HB3N-O(&-O;G-E9W5I('-A;'9A<B!O(&%R<75I=F\@9&4@8V]N
M9FEG=7)AY^-O("5S+B!6;V/J('!O9&4@;W4@=71I;&EZ87(@=6UA("(*(F1A
M<R!O<.?U97,@<&%R82!S86QV87(@;R!C\V1I9V\@9&4@=F]L=&$@96T@)7,@
M;W4@8V]P:6%R(&UA;G5A;&UE;G1E(&\@(@HB8_-D:6=O(&%B86EX;R!P87)A
M("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS
M9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@;F\@<V5R=FED;W(@3$1!
M4"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@<F5M;W9E<B!O(&QI;FL@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@871U86QI>F%R(&\@8V]N=&%T;RX@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&%T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!G<F%V87(@82!C;VYF:6=U<F'G
MXV\@9&4@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P
M"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).XV\@
M9F]I('!O<W/M=F5L(&5N8V]N=')A<B!A($)A<G)A($QA=&5R86P@9&\@36]Z
M:6QL82X@0V5R=&EF:7%U92US92!Q=64@96QA("(*(F5S=.$@86)E<G1A+B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E
M<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!D87(@86\@=7-U
MX7)I;R`E<R!O<R!S96=U:6YT97,@9&ER96ET;W,@<&%R82!A('!A<W1A("<E
M<R<Z("4B"B)S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PIM
M<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(E1E>'1O(&-O;G1A9&\B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B
M0V]U;G1R>2(*;7-G<W1R(")08>US(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")#=7)S;W,B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<FEA<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")#<FEA<B!U;2!L:6YK
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM
M<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")#<FEA<B!U;6$@;F]V
M82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR
M"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B0W)I87(@<W5B
M('!A<W1A<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P
M"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U
M97,@9&\@8W)I861O<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M,3D*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R(").^FUE<F\@
M9&\@8V%R=.-O(&1E(&-RZ61I=&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O
M871I82(*;7-G<W1R(")#<F_A8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B
M82(*;7-G<W1R(")#=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS
M9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(C0@1F%S97,@071U86ES
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E
M<W-I;VYS(@IM<V=S='(@(E-E<W/U97,@071U86ES(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R
M96YT(%1I;64B"FUS9W-T<B`B2&]R82!!='5A;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B
M0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B02!54DP@871U86P@Z2(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G
M<W1R(")5<W7A<FEO<R!N;R!M;VUE;G1O(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(D-L:6UA
M($%T=6%L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM
M<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")#;VYD:>?C;R!A
M='5A;#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")%<W1I;&\@
M871U86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RXB"FUS9W-T<B`B0W5S=&]M:7IA('1A<F5F87,@82!S97)E;2!E
M>&5C=71A9&%S(&%O(&-O;F5C=&%R(&$@)7,N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#
M=70B"FUS9W-T<B`B0V]R=&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G
M<W1R(")#;W)T87(@<V5L9>?C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U
M<R(*;7-G<W1R(")#:&EP<F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B0VER[6QI8V\@
M*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B0VER[6QI8V\@*%=I
M;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I
M9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(D-I<NUL
M:6-O+U5C<F%N:6%N;R`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z
M96-H(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82!48VAE8V$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(B(*(D133B`H
M<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.("AV96IA
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"DB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")$
M:6%R:6%M96YT92(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B
M1&%T851R964@0G)O=W-E<B(*;7-G<W1R(").879E9V%D;W(@9&4@1&%T851R
M964B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<W"FUS9VED(")$
M871A8F%S92!,;V]K=7`B"FUS9W-T<B`B4&5S<75I<V$@;F\@0F%N8V\@9&4@
M1&%D;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,#(*;7-G:60@(D1A
M=&4B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(D1A
M=&$@9&4@4F5C96)I;65N=&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-SDV"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")396QEY^-O
M(&1E(&1A=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*
M;7-G<W1R(")$:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM
M<V=S='(@(D5?>&-L=6ER($-O;'5N82(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R
M(")$97IE;6)R;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*
M;7-G<W1R(").^FUE<F]S(&1E8VEM86ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD
M96YT(@IM<V=S='(@(E)E8W5A<B!)9&5N=&'GXV\B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I
M9"`B1&5F875L="(*;7-G<W1R(")0861RXV\B"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#
M;VQO<B(*;7-G<W1R(")#;W(@4&%D<N-O(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*
M;7-G<W1R("))9&5N=&ED861E(%!A9'+C;R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")3:&5L
M;"!0861RXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@
M(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:>?U97,B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B
M"FUS9W-T<B`B17AC;'5I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB
M"FUS9W-T<B`B17AC;'5I<B!CZ6QU;&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P
M(@IM<V=S='(@(D5X8VQU:7(@1W)U<&\B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B17AC
M;'5I<B!,;V<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE
M=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")%>&-L=6ER(%!E<FUI<W/C;R(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED
M(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(D5X8VQU:7(@
M92!P=7)G87(@;65N<V%G96YS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB
M"FUS9W-T<B`B17AC;'5I<B!CZ6QU;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@
M8V]L=6UN(@IM<V=S='(@(D5X8VQU:7(@8V]L=6YA(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B17AC;'5I<B!M;V1E;&\@<W5B<W1I='5T
M;R!E>&ES=&5N=&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R(")%>&-L=6ER('!E<FUI<W/U97,@<&%R82`G
M)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(D5X8VQU:7(@
M<&5R;6ES<_5E<R!P87)A("<E<R<@92!Q=6%L<75E<B!O=71R82!S=6(M<&5R
M;6ES<^-O/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B17AC
M;'5I<B!L:6YH82(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET
M>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G
M<W1R(")%>&-L=6ER(&ED96YT:61A9&4@<V5L96-I;VYA9&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B17AC
M;'5I<B!A(&-O;'5N82!A='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H
M92!C=7)R96YT(')O=R(*;7-G<W1R(")%>&-L=6ER(&$@;&EN:&$@871U86PB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B4V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C
M;R`G)7,G(&5X8VQU[61O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV
M97)Y('1I;64B"FUS9W-T<B`B2&]R82!D92!E;G1R96=A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$:6YA;6%R8V$B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@
M=&AE(%!R;V)L96TB"FUS9W-T<B`B1&5S8W)E=F$@;R!P<F]B;&5M82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP
M=&EO;B(*;7-G<W1R(")$97-C<FGGXV\B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&AE<R`H=&%M8NEM(&YO(')E9VES
M=')O(&1E(&%T:79I9&%D97,@9&\@2&]R9&4I.B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")/<R!D971A
M;&AE<R!F;W)A;2!G<F%V861O<R!E;2!L;V<@<&%R82!O(&%D;6EN:7-T<F%D
M;W(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B
M1&5V96QO<&UE;G0B"FUS9W-T<B`B1&5S96YV;VQV:6UE;G1O(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R
M(")0;VYT;R!D92!/<G9A;&AO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#$*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B
M4&]N=&\@9&4@3W)V86QH;R!P87)A(&$@^FQT:6UA(&AO<F$Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN
M=#H@(@IM<V=S='(@(E!O;G1O(&1E($]R=F%L:&\Z("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C
M=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(D1I<F7GXV\@9&$@97-Q=65R
M9&$@<&%R82!D:7)E:71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0B"FUS9W-T<B`B1&ER9>?C;R!D82!D:7)E:71A('!A<F$@97-Q=65R9&$B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y
M(@IM<V=S='(@(D1I<F5T\W)I;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B
M17AI8FER(&5M(&9O<FUA=&\@,C0@:&]R87,_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(D]PY_5E<R!D92!%>&EB:>?C;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*
M;7-G<W1R(")%>&EB:7(@<')E=FESXV\@9&5T86QH861A(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")%>&EB:7(@<')E=FESXV\@*%1!1BDB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`V"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*
M;7-G<W1R(")%>&EB:7(@9F]R;6%T;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B(*;7-G<W1R(").;W1I9FEC8>?C;R!D92!$:7-P;W-IY^-O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8G5T:2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@
M9&5L971E(@IM<V=S='(@(D[C;R!E>&-L=6ER(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").XV\@86-E<W-E(&1I<F5T86UE
M;G1E(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED
M(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*(D$@<')I;65I
M<F$@;&EN:&$@8V]N=.EM(&]S(&YO;65S(&1O<R!C86UP;W,_(%-E('-I;2P@
M8VQI<75E(&YE<W1A(&-A:7AA.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN
M:6-A(@IM<V=S='(@(D1O;6EN:6-A;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$
M;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($1O;6EN:6-A
M;F$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$
M;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(D[C;R!T
M96T@=6UA(&-O;G1A/R!#861A<W1R92US92XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G:60@(D1O=VYL;V%D(@IM<V=S
M='(@(D)A:7AA<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G
M<W1R(")"86EX87(@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R
M"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+B(*;7-G<W1R(")"86EX87(@82!C;VYF:6=U<F'GXV\@9V5R
M861A(&-O;6\@=6T@<V-R:7!T(%!(4"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("),
M:7-T82!D92!S96QEY^-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T
M"FUS9VED(")$<G5G<R(*;7-G<W1R(")$<F]G87,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R
M(")#;W)R96EO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E
M<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*
M;7-G<W1R("(B"B)#;VYE8W1O<B!D;R!G871E=V%Y($5-86EL+7!A<F$M4TU3
M+"!P87)A(&]P97)A9&]R87,@<75E(&1I<W!O;FEB:6QI>F%M(&5S=&4@(@HB
M<V5R=FGG;RXB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T
M<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%
M<75A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET
M(@IM<V=S='(@(D5D:71A<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]5
M22YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B161I=&%R($)L
M;V-O(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H
M<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B161I=&%R($=R=7!O
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S
M:6]N(@IM<V=S='(@(D5D:71A<B!097)M:7-SXV\B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(D5D:71A<B!097)M:7-S]65S(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")%9&ET87(@4&5R;6ES<_5E<R!P87)A
M("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I
M="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B161I=&%R(&]PY_5E<R!D93HB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`B161I=&%R('!E<FUI<W/U97,@<&%R82`E<R(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B161I=&%R('!E<FUI<W/U97,@
M<&%R82`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B
M161U8V%T:6]N(@IM<V=S='(@(D5D=6-AY^-O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B16=Y<'0B"FUS9W-T<B`B16=I=&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS
M9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE;G1O+BXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@
M(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S
M"FUS9VED(")%;6%I;"(*;7-G<W1R(")%+6UA:6PB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B16YD97)E
MYV\@9&4@12U-86EL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV
M-PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@
M(D\@96YD97)EYV\@9&4@92UM86EL(&1E=F4@8V]R<F5S<&]N9&5R+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.3,*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DUE;G-A9V5M(&-O;2!C;VYF:7)M
M8>?C;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")'
M871E=V%Y(&1E($5-86EL+7!A<F$M4TU3(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y-PIM<V=I9"`B16UO=&EC;VYS(@IM
M<V=S='(@(D5M;W1I8V]N<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB
M"FUS9W-T<B`B365N<V%G96T@96T@8G)A;F-O+B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y
M(')E<W5L="XB"FUS9W-T<B`B4F5S=6QT861O(&5M(&)R86YC;RXB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T
M>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5&5R;6]S(&1E('!E<W%U:7-A(&5M
M(&)R86YC;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@
M(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R
M:65S(&EN('1E>'0_(@IM<V=S='(@(DAA8FEL:71A<B!I;G-E<N?C;R!D92!I
M;6%G96YS(&$@<&%R=&ER(&1A($=A;&5R:6$@9&4@26UA9V5N<R!N;R!T97AT
M;S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B
M;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")(86)I;&ET
M87(@;65N=2!D92!C;VYT97AT;R!C;VT@;R!B;W3C;R!D:7)E:71O/R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@P,`IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B1FEN86P@
M9&\@86YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B075M96YT
M87(@161I=&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I
M9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL
M;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W
M;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM
M<V=S='(@(B(*(D9O<FYEYV$@=6UA('!E<F=U;G1A(&1E('-E9W5R86[G82!A
M('%U86P@=F]CZB!S97+A('!E<F=U;G1A9&\@<V4@=F]CZB`B"B)N96-E<W-I
M=&%R(&=E<F%R('5M82!N;W9A('-E;FAA+"!E>"X@)W%U86P@;R!N;VUE(&1O
M('-E=2!C86-H;W)R;S\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE
M(&EM86=E(%523"!H97)E(@IM<V=S='(@(D9O<FYEYV$@82!54DP@9&$@:6UA
M9V5M(&%Q=6DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#DP"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS
M9W-T<B`B1&EG:71E(&%S(&QE=')A<R!A8F%I>&\Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B1W5I;ND@17%U871O
M<FEA;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I
M='+I:6$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0X"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*;7-G:60@(D5R
M<F]R(@IM<V=S='(@(D5R<F\B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M
M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A
M=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B17)R;R!A;R!C<FEA<B!B;&]C;SH@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B
M"FUS9W-T<B`B17)R;R!A;R!E>&-L=6ER(.)N8V]R82!D92!S:6YC<F]N:7IA
MY^-O.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E
M<R(*;7-G<W1R(")%<G)O(&%O(&5X8VQU:7(@;&]G(&1E('-I;F-R;VYI>F'G
MXV\Z("5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<R(*;7-G<W1R(")%<G)O(&%O(&]B=&5R(&-O;G1E^F1O.B`E<R(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B
M17)R;R!A;R!A='5A;&EZ87(@82!S96YH83H@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R
M<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B17)R;R!N82!M96YS
M86=E;2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")%<G)O(&=R
M879A;F1O("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G
M<W1R(")%<W3T;FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS
M9W-T<B`B171I\W!I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM
M<V=I9"`B171H;FEC(@IM<V=S='(@(LET;FEC;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U
M<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V
M97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B0V%D82`Q-2!M:6YU=&]S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU
M=&5S(@IM<V=S='(@(D-A9&$@,B!M:6YU=&]S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED
M(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D-A9&$@,S`@<V5G=6YD;W,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")#
M861A(#4@;6EN=71O<R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D-A
M9&$@0V]N97CC;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#861A(&UE:6$@:&]R82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(D-A9&$@
M;6EN=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G
M:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")686QO<F5S(&1E(&5X96UP
M;&\Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL
M+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E
M(@IM<V=S='(@(D5X96-U=&%R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R
M(")%>'!A;F1I<B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(D5X<&%N9&ER($)A
M<G)A($QA=&5R86PB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B17-P97)A9&\@
M)RDG(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM
M<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;2(*;7-G<W1R(")%<W!E<F%D;R!U;6$@<&%L879R82!O=2!T97)M;R!D92!P
M97-Q=6ES82!E;G1R92!A<W!A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@
M(D1A=&$@9&4@17AP:7)AY^-O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5X<&]E
M;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B0V]R(&1O('!R
M:6UE:7)O('!L86YO(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM
M<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")#;VYF:6=U<F'G
MXV\@9&4@96YV:6\@9&4@87)Q=6EV;W,@1E10(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B1F%L:&$@;V)T96YD;R!P<F5F97+J
M;F-I87,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")&86QH82!A
M;R!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B1F%L:&$@86\@8V]N96-T87(@86\@
M<V5R=FED;W(@4TU"+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S$W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@
M7"(E<UPB+B(*;7-G<W1R(")&86QH82!A;R!C;W!I87(@9&4@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B
M1F%L:&$@86\@8V]P:6%R('!A<F$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B1F%L:&$@86\@8W)I87(@
M=6UA(&YO=F$@8V]N97CC;R!305-,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB
M"FUS9W-T<B`B1F%L:&$@86\@;6]V97(@<&%R82!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")&86QH82!A;R!O
M8G1E<CH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")*=7-T;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R
M("));&AA<R!&86QK;&%N9"`H36%L=FEN87,I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("));&AA<R!&87)O92(*"B,Z(&9R
M86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*
M;7-G<W1R(")%<G)O($9A=&%L.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE
M<R(*;7-G<W1R(")&87AE<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")&979E
M<F5I<F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E
M;',@3&EK92(*;7-G<W1R(")396YS8>?C;R!4Z7)M:6-A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@
M(@IM<V=S='(@(E-E;G-AY^-O('3I<FUI8V$Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R
M<R(*;7-G<W1R(")086YC861A<R!D92!#:'5V82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(DYE=F4@1G)A8V$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.30X"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B
M36%T<FEZ(&1O(&-A;7!O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S,@IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!
M4%1#2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R(")&;VYT92!&:6=L970B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B87)Q
M=6EV;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B0V]N
M=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")#;VYT86=E;2!D92!!<G%U:79O<SH@
M)7,@87)Q=6EV;W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y
M"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1V5R96YC:6%D;W(@9&4@
M07)Q=6EV;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I
M9"`B1FEL92!.86UE(@IM<V=S='(@(DYO;64@9&\@07)Q=6EV;R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.#0*;7-G:60@(D9I;&4@<V5L96-T
M:6]N(@IM<V=S='(@(E-E;&7GXV\@9&4@87)Q=6EV;R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T.3`*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S
M='(@(D5N=FEO(&1E(&%R<75I=F\B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.#4*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(")%;G9I;R!D92!A<G%U:79O<R!NXV\@Z2!S=7!O<G1A
M9&\N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&
M:6QT97)S(@IM<V=S='(@(D9I;'1R;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&
M:6YL86YD(@IM<V=S='(@(D9I;FSB;F1I82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B4')I;65I<F$@
M365T861E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")0<FEM
M96ER;R!1=6%R=&\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C4U"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B5&%X82!F
M:7AA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S,`IM<V=I9"`B1FQI<"(*;7-G<W1R(")':7)A<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@
M(D9L;V%T(@IM<V=S='(@(D1I<W!O<VGGXV\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@
M(D[I=F]A(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S<@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B4&%S=&$@
M)7,@;N-O(&5X:7-T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B0V]R
M(&1A($9O;G1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED
M(")&;V]D(@IM<V=S='(@(D-O;6ED82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B
M4&%R82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R=&%M(&EM86=E;G,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,0IM<V=I9"`B1F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`B4')E=FESXV\@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO
M=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A
M>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB1&EA<R!0<F5V:7-T
M;W,@*$YO=&4@<75E(&$@<')E=FESXV\@<F5T;W)N861A(&5X:6)E(&%M8F]S
M(&1I82!E(&YO:71E.R!U;2`B"B)N^FUE<F\@;75I=&\@86QT;R!A<75I('!O
M9&4@<F5S=6QT87(@96T@=6T@8FQO8V\@97AT96YS;RDB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S
M<W=O<F0_(@IM<V=S='(@(D5S<75E8V5U(&$@<V5N:&$_(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B
M1F]R;75LX7)I;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G
M:60@(D9O<G1U;F4B"FUS9W-T<B`B4V]R=&4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")4:7!O
M(&1E(%-O<G1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED
M(")&;W)T=6YE<R(*;7-G<W1R(")3;W)T97,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B4V]R=&5S
M(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&
M;W)U;7,B"FUS9W-T<B`B1O-R=6YS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4F5D:7)E8VEO
M;F%M96YT;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")397@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED
M(")&<F%M97,B"FUS9W-T<B`B475A9')O<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9R86YC92(*;7-G<W1R(")&<F%NYV$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM
M<V=S='(@(D9R86[G82!-971R;W!O;&ET86YA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I
M9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")'=6EA;F$@1G)A;F-E<V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")0
M;VQI;NES:6$@1G)A;F-E<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC
M:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")497)R:73S<FEO<R!&
M<F%N8V5S97,@9&\@4W5L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")$92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1&\H82DB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L
M;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGGXV\@0V]M<&QE=&$B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W
M-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(DQU82!#:&5I82(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B3F]M92!#
M;VUP;&5T;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A
M8N-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R(")'86QE<FEA(&1E(&]N9&4@;V)T97(@87,@:6UA9V5N
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L97)I
M83HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1^)M8FEA
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E
M<F%R(&$@0V]N9FEG=7)AY^-O(&1E("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM
M<V=S='(@(D/S9&EG;R!'97)A9&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R
M9VEA(@IM<V=S='(@(D=E\W)G:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M
M86YY(@IM<V=S='(@(D%L96UA;FAA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA
M;F$B"FUS9W-T<B`B1V%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A
M<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")0
M<FEM96ER;R!.;VUE(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T
M<B`B3W#G]65S($=L;V)A:7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B27(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.0IM
M<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE($UA<&%S(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR
M,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C
M:"(*;7-G<W1R(")097-Q=6ES87(@;F\@1V]O9VQE(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B1W)A>7-C
M86QE(@IM<V=S='(@(D5S8V%L82!D92!#:6YZ87,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1W)E96-E(@IM<V=S='(@(D=RZ6-I82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@T"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T
M<B`B1W)E9V\@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E
M96YL86YD(@IM<V=S='(@(D=R;V5LXFYD:6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")'<F5N861A(@IM<V=S='(@(D=R86YA9&$B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M061M:6YI<W1R8>?C;R!D92!'<G5P;W,B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ
M-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S
M='(@(DYO;65S(&1E(&=R=7!O<R!NXV\@9&5V96T@97-T87(@96T@8G)A;F-O
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R
M;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T
M<B`B(@HB1W)O=7!?;&1A<#H@26UP;W-S[79E;"!A9&EC:6]N87(@9W)U<&\@
M)7,N($ES=&\@Z2!O('%U92!O('-E<G9I9&]R(&1I<W-E.B`B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD
M87`Z($EM<&]S<^UV96P@97AC;'5I<B!G<G5P;R`E<R(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P
M7VQD87`Z($EM<&]S<^UV96P@871U86QI>F%R(&=R=7!O("5S(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G
M:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P;W,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861A;'5P92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;&%M82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@
M(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D92!#;VYV:61A9&\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S
M=&)O;VLB"FUS9W-T<B`B3&EV<F\@9&4@5FES:71A<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6ENZ2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6ENZ2U":7-S874B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=6EA;F$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS
M9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R
M(")(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z
M;'1I;6$@8^EL=6QA(&1A(&QI;FAA+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@<V4@;F5G82!C;W9A<F1E;65N
M=&4@82!E>&-L=6ER(&$@^FQT:6UA(&-O;'5N82!D82!T86)E;&$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!S92!N
M96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@;&EN:&$@9&$@
M=&%B96QA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W
M"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T96YT:6-AY^-O($A45%`@;N-O(&5N8V]N=')A9&$N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O
M<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO($AA<V@B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G
M<W1R(").96)L:6YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3(S
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C$*;7-G:60@(DAE861E<B(*
M;7-G<W1R(")#86)EYV%L:&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(D-A
M8F7G86QH;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N
M9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DEL:&$@2&5A<F0@92!);&AA
M<R!-8T1O;F%L9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(E1E;7!E
M<W1A9&4@1F]R=&4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I
M9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E=2`H25-/
M+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")!;'1U
M<F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@T(&9R
M86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*
M;7-G:60@(DAE;'`B"FUS9W-T<B`B06IU9&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG
M(&5D:71O<B(*;7-G<W1R(")!:G5D82!D;R!E9&ET;W(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S<U"FUS9VED(")(96QP97(B"FUS9W-T<B`B
M07-S:7-T96YT92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B
M2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<V;I<FEO(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93HB"FUS9W-T<B`B07%U:2!E<W3A(&\@:6[M8VEO(&1O(&%R<75I=F\Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G
M:60@(DAI9V@B"FUS9W-T<B`B06QT82(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z
M-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B25]N[6-I;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S
M='(@(E-A;G1A(%/I("A#:61A9&4M17-T861O(&1O(%9A=&EC86YO*2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S.0IM<V=I9"`B2&]M92(*
M;7-G<W1R("));NUC:6\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")%
M;F1E<F7G;R!297-I9&5N8VEA;"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B1&ER973S<FEO
M(%!E<W-O86PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(D9O;F4@4F5S
M:61E;F-I86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S
M='(@(DAO;F1U<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B
M"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D
M(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($1A9&\@6$U,
M("5S(&EN=N%L:61O(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G
M96T@8V]R<F5S<&]N9&4@86\@;V)J971O("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;FAU;2!O8FIE=&\@9&\@=&EP
M;R`E<R!F;VD@96YC;VYT<F%D;R!N82!M96YS86=E;2`E<R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!296UO=FED;R!C;VT@<W5C97-S;R`E
M<R!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM
M<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($$@96YG:6YE(&1E(&EN=&5G<F'GXV\@<F5Q=65R(&$@97AT
M96YSXV\@4$A0("=D;VUX;6PG(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@8W)I87(@=6UA(&YO=F$@
MX7)V;W)E(%A-3"!P87)A(&\@;V)J971O("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@<F5M;W9E<B`E<R!<(B5S7"(Z
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V
M92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*
M(DAO<F1E+TMO;&%B.B!);7!O<W/M=F5L(&]B=&5R(&$@:61E;G1I9FEC8>?C
M;R!-24U%('!A<F$@82!P87)T92!D;R!T:7!O("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,3DR"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA
M<B`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,S,R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA<B!C;VUP87)T:6QH86UE;G1O
M<SH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($-O;7!A<G1I;&AA;65N=&\@
M9&5S8V]N:&5C:61O(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*
M;7-G<W1R("),:6YH82!(;W)I>F]N=&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P
M861D:6YG(@IM<V=S='(@(DUA<F=E;2!H;W)I>F]N=&%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R
M:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G1A;#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(D-O;6\@=F]CZB!C:&5G;W4@87%U:3\@*%!O<B!F879O<B!C;VUU;FEQ
M=64A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E%U86YT87,@8V]L=6YA<R!V;V/J
M(&=O<W1A<FEA(&1E(&UE<V-L87(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/R(*;7-G<W1R(")1=6%N=&]S(&-A;7!O<R`H8V]L=6YA<RD@
M97AI<W1E;3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1=6%N=&%S(&QI;FAA<R!V;V/J
M(&=O<W1A<FEA(&1E(&UE<V-L87(_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO;65T87(N<&AP.C(S-PIM<V=I9"`B
M2'5M:61I='DB"FUS9W-T<B`B56UI9&%D92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B
M56UI9&%D93H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED
M(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1A<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")(=6YG<NUA(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B1F%L:&$@86\@
M8W)I87(@8V%I>&$@<&]S=&%L($E-05`Z("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B1F%L:&$@86\@97AC;'5I
M<B!C86EX82!P;W-T86P@24U!4#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O
M=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")&86QH82!A;R!C<FEA
M<B!Q=6]T82!D82!C86EX82!P;W-T86P@24U!4#H@)7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S(P"FUS9VED("))4"!!9&1R97-S(@IM<V=S
M='(@(D5N9&5R9>=O($E0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A
M<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")%;F1E<F7G;R!)4"!NXV\@9&ES<&]N[79E;"XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R(")%
M;F1E<F7G;R!)4"!NXV\@97-TX2!N;R!B;&]C;R!P97)M:71I9&\@0TE$4BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B
M5FEO;&'GXV\@9&\@8FQO<75E:6\@25`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS
M97)T(%)O=R!"969O<F4B"FUS9W-T<B`B25]N<VER82!,:6YH82!!;G1E<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VSB;F1I
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS
M($]N;'DB"FUS9W-T<B`B4V]M96YT92#-8V]N97,B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R
M("5S(@IM<V=S='(@(LUC;VYE<R!P87)A("5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@
M(LUC;VYE<R!E('1E>'1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(").;VUE(&1A(&ED
M96YT:61A9&4Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RXB"FUS9W-T<B`B4V4@;N-O(&9O<B!E>&EB:61O(&-O<G)E=&%M96YT92P@
M)7,@<&%R82!A8G+M+6QO(&5M('5M82!N;W9A(&IA;F5L82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@
M<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA
M>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T
M<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(E-E('9O8^H@;N-O(';J(&YE;FAU
M;2#M8V]N92!A;R!U=&EL:7IA<B!O($EN=&5R;F5T($5X<&QO<F5R+"!V;V/J
M('!O9&4@(@HB8VAE8V%R(&5S=&$@8V%I>&$@<&%R82!D97-A8FEL:71A<B!A
M('1R86YS<&%RZFYC:6$@4$Y'+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+B(*;7-G<W1R("(B"B)392!V;V/J(';J(&5S=&$@;65N<V%G96T@;6%S(&[C
M;R!A(&EM86=E;2P@82!I;6%G96T@<75E('9O8^H@<75E<B!E;G9I87(@;N-O
M("(*(G!O9&4@<V5R(&5X:6)I9&$@<&5L;R!S974@;F%V96=A9&]R+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B4'+I+79I
M<W5A;&EZ8>?C;R!D82!);6%G96TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),
M(@IM<V=S='(@(E523"!D82!);6%G96TB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM
M86=E(%523#HB"FUS9W-T<B`B55),(&1A($EM86=E;3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("));6%G96T@9&$@
M9V%L97)I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M.B(*;7-G<W1R("));6%G96T@9&$@9V%L97)I83HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED("));6%G92!U<&QO860B"FUS9W-T
M<B`B16YV:6\@9&4@26UA9V5M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("));6%G96YS(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T87(L(%!A<W-O("5D(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-A;7!O(&EM
M<&]R=&%D;SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U
M"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(D-A;7!O<R!I;7!O
M<G1A9&]S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS
M9W-T<B`B26Y?<V5R:7(@3&EN:&$@07#S<R(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")#\V1I9V\@9&4@8>?C;R!F;W)N
M96-I9&\@97-TX2!I;F-O<G)E=&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5S=>%R:6\@92]O
M=2!S96YH82!I;F-O<G)E=&]S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*(E5S=>%R:6\@;W4@96YD97)EYV\@86QT97)N871I=F\@:6YC;W)R
M971O<RX@5&5N=&4@;F]V86UE;G1E(&]U(&5N=')E(&5M("(*(F-O;G1A=&\@
M8V]M(&\@861M:6YI<W1R861O<B!S92!V;V/J(&YE8V5S<VET82!D92!M86ES
M(&%J=61A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")!=6UE
M;G1A<B!)9&5N=&'GXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM
M<V=S='(@(LUN9&EA(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN
M9&EV:61U86P@57-E<G,B"FUS9W-T<B`B57-UX7)I;W,@:6YD:79I9'5A:7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O
M;NES:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R;6'GXV\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO
M;B(*;7-G<W1R("));F9O<FUAY^-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V
M86EL86)L92XB"FUS9W-T<B`B3N-O(&5X:7-T96T@;W#G]65S(&1I<W!O;NUV
M96ES+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS
M9W-T<B`B26YS97)I<B!#7V]L=6YA($%P\W,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@
M(DEN<V5R="!);6%G92(*;7-G<W1R("));G-E<FER($EM86=E;2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R("));G-E<FER(%1A8F5L82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@
M(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("));G-E<FER($QI;FL@9&$@5V5B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T
M<B`B26YS97)I<B!?0V]L=6YA($%N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("));G-E<FER('5M82!N;W9A(&-O;'5N82!A</-S(&$@871U86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("));G-E<FER('5M82!N;W9A(&-O;'5N82!A;G1E
M<R!D82!A='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)I<B!U;6$@;F]V
M82!L:6YH82!A</-S(&$@871U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E
M<FER('5M82!N;W9A(&QI;FAA(&%N=&5S(&1A(&%T=6%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R("));G-E<FER('5M('!A<N%G<F%F;R!A</-S(&\@871U86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G-E<FER('5M('!A<N%G<F%F;R!A
M;G1E<R!D;R!A='5A;"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS
M9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DEN<V5R
M:7(@=6T@;6]D96QO(&%L=&5R;F%T:79O(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@
M=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S
M='(@(D9O<FYEYV$@=6T@96YD97)EYV\@9&4@92UM86EL(&YO('%U86P@=F]C
MZB!P;V1E(')E8V5B97(@82!N;W9A('-E;FAA.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN
M<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@8^EL=6QA(&%P\W,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B26YS
M97)I<B!CZ6QU;&$@86YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN
M(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@8V]L=6YA(&%P\W,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("));G-E<FER(&-O
M;'5N82!A;G1E<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B26YS
M97)I<B!M96YS86=E;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@869T97(B"FUS9W-T<B`B26YS97)I<B!P87+A9W)A9F\@87#S<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B
M26YS97)I<B!P87+A9W)A9F\@86YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@;&EN:&$@87#S<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*
M;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7(@;&EN
M:&$@86YT97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED
M("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ(@IM<V=S='(@(D9O<FYEYV$@82!R97-P;W-T82!O8G)I9V%T
M\W)I82!P87)A(&$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN
M<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B26YS97)I<B]!;'1E<F%R($EM
M86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("));G-E
M<FER+T%L=&5R87(@3&EN:R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M(")#<NED:71O(&EN<W5F:6-I96YT92!P87)A(&5N=FEA<B!P87)A(&$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET+B(*;7-G<W1R(")#<NED:71O(&EN<W5F:6-I96YT92XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<Y"FUS9VED("));G1E9V5R(@IM
M<V=S='(@(D[Z;65R;R!);G1E:7)O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(DQI<W1A
M(&1E($EN=&5I<F]S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+B(*;7-G<W1R(")#1%4@*$-A8F7G86QH;R!D92!$861O
M<R!D92!5<W7A<FEO*2!I;G;A;&ED;RXB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*
M;7-G<W1R(")$861O<R!:25`@:6YVX6QI9&]S(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B07!L:6-AY^-O(&EN=N%L:61A+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI
M9"!B871C:"!)1"XB"FUS9W-T<B`B261E;G1I9FEC8>?C;R!D;R!B871C:"!I
M;G;A;&ED82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DQ(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-C(*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(S-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S`S"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G
M:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(D1A9&]S(&5N
M=FEA9&]S('/C;R!I;G;A;&ED;W,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(D5N9&5R9>=O(&1E(&1E<W1I
M;F\@Z2!I;G;A;&ED;RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R
M(")&;W)M871O(&1O(&%R<75I=F\@Z2!I;G;A;&ED;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS
M92!K97DN(@IM<V=S='(@(D[Z;65R;R!D92!L:6-E;N=A(&EN=N%L:61O+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN
M=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DQO8V%L:7IAY^-O
M(&9O<FYE8VED82#I(&EN=N%L:61A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M
M<V=?='EP92XB"FUS9W-T<B`B5&EP;R!D82!M96YS86=E;2#I(&EN=N%L:61O
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS
M9W-T<B`B07!I7VED(.D@:6YVX6QI9&\@;W4@97-TX2!F86QT86YD;RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G
M<W1R(")087+B;65T<F]S(&EN=N%L:61O<R!O=2!F86QT86YD;RXB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!E<FUI<W/U97,@9&\@<&%I('/C
M;R!I;G;A;&ED87,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(")097)M
M:7-S]65S(&1O('!A:2!SXV\@:6YVX6QI9&%S+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R(")#\V1I9V\@9&\@<')O9'5T;R#I(&EN=N%L:61O+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B4')O=&]C
M;VQO(&EN=N%L:61O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT
M.B!<(B5S7"(B"FUS9W-T<B`B1&5S=&EN873A<FEO(&EN=N%L:61O.B`G)7,G
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<U(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R92!O
M8FIE8W0B"FUS9W-T<B`B3V)J971O(&-O;7!A<G1I;&AA9&\@:6YVX6QI9&\B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@
M(D9O;G1E(&1O(&5N9&5R9>=O(&EN=N%L:61A+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV
M86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(D1A9&]S('5N:6-O9&4@:6YV
MX6QI9&]S+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G
M:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G3A<FEO(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B26YV
M97)T('-E;&5C=&EO;B(*;7-G<W1R("));G9E<G1E<B!S96QEY^-O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DERXRP@4F5P^F)L:6-A($ES;.)M:6-A(&1O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER87%U92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA;F1A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM
M<V=S='(@(DEL:&$@9&\@2&]M96TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B
M"FUS9W-T<B`B5&5M<&5S=&%D97,@27-O;&%D87,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)A96PB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S
M='(@(D5M:7-S;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("))=.%L:6-O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("))=.%L:6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EC82(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS
M9VED(")*86YU87)Y(@IM<V=S='(@(DIA;F5I<F\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<.-O(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#8*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B2F%P;V[J<R`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S
M97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D
MXFYI82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(DIU;&AO(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS
M9W-T<B`B2G5N:&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(DIU
M<W1I9FEC87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T
M<B`B06QI;FAA<B!A;R!#96YT<F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&
M=6QL(@IM<V=S='(@(DIU<W1I9FEC87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF
M>2!,969T(@IM<V=S='(@(D%L:6YH87(@X"!%<W%U97)D82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS
M9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(D%L:6YH87(@X"!$:7)E:71A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(D-A
M>F%Q=6ES=.-O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B36%N
M=&5R(&\@;W)I9VEN86P_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*
M;7-G<W1R(")1=>IN:6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(E-E<G9I9&]R(&ME<F)E<F]S(')E:F5I=&]U
M(&$@875T96YT:6-AY^-O+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B3F]V871O<R!D92!+
M97)N96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*
M;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")#<FEAY^-O(&1E($-H879E
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED
M(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B26UP<F5S<^-O($1I9VET86P@
M9&$@0VAA=F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B5&%M86YH;R!D82!#:&%V
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I
M9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5&EP;R!D82!#:&%V92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A
M9V4B"FUS9W-T<B`B57-O(&1A($-H879E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D-H879E(&KA(&5X
M:7-T92!N;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(D-R
M:6%NYV%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R
M(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]RZ6EA+"!2
M97#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(D-O<NEI82P@
M4F5P^F)L:6-A(&1A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G
M:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")#;W)E86YO("A%54,M2U(I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5W86ET
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(E%U
M:7)G=6ES=.-O(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS
M9VED("),85]Y;W5T(@IM<V=S='(@(DQA7WEO=70B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R("))
M9&EO;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;R!297#Z8FQI8V$@1&5M;V-R
MX71I8V$@4&]P=6QA<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G
M:60@(DQA<W0@2&%L9B(*;7-G<W1R("+:;'1I;6$@365T861E(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H
M86YG92(*;7-G<W1R(")'97)A<B!.;W9A(%-E;FAA(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S
M="!1=6%R=&5R(@IM<V=S='(@(MIL=&EM;R!1=6%R=&\B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U.`IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R
M("+:;'1I;6$@071U86QI>F'GXV\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S
M(@IM<V=S='(@(MIL=&EM;R!L;V=I;CH@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<R(*;7-G<W1R("+:;'1I;6\@;&]G:6XZ("5S(.`@<&%R
M=&ER(&1E("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T"FUS
M9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("+:;'1I;6\@;&]G:6XZ
M($YU;F-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B
M3&5T]&YI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B
M3&%W(@IM<V=S='(@(DQE:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@
M(DQA>6]U="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS
M9W-T<B`B1&5I>&$@=F%Z:6\@<V4@<75I<V5R('-E;2!B;W)D82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),[6)A;F\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*
M;7-G:60@(DQE9G0B"FUS9W-T<B`B17-Q=65R9&$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3`X"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M(")#86)EYV%L:&\@97-Q=65R9&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3`T"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")686QO<F5S
M(&1A(&5S<75E<F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM
M<V=S='(@(DQE<V]T;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B06UO<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6+I<FEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DSM
M8FEA(,%R86)E($IA;6%H:7)I>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI
M96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H
M="!$<FEZ>FQE(@IM<V=S='(@(D-H:79I<V-O1G)A8V\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@
M4F%I;B(*;7-G<W1R(")#:'5V82!&<F%C82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A
M<FQY(@IM<V=S='(@(D-H=79A($9R86-A($UA='5T:6YA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT
M(%)A:6X@3&%T92(*;7-G<W1R(")#:'5V82!&<F%C82!697-P97)T:6YA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G
M:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DQE=F5S(%!A;F-A9&%S
M(&1E($-H=79A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S
M='(@(D-H=79A<R!&<F%C87,@8V]M(%1R;W;U97,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO
M=R(*;7-G<W1R(").979E($9R86-A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(D)R979E($YE=F%S8V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(E!OZFUA<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3@*;7-G:60@(DQI;FLB"FUS
M9W-T<B`B3&EN:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM
M<V=S='(@(DQI;FL@87!O;G1A('!A<F$Z(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W.0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T
M;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("),
M:6=A<B!O(&5N9&5R9>=O(&1E(&4M;6%I;"#@('#A9VEN82!D92!C;VUP;W-I
MY^-O(&%O(&5X:6)I<B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI
M;FMS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU
M>"!#;V]K:64B"FUS9W-T<B`B0V]O:VEE(&1O($QI;G5X(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T87(@+2!U
M<W7A<FEO('!O9&4@=F5R(&$@<&%S=&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("),:7-T87(@
M0F%N8V]S(&1E($1A9&]S(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B3&ES=&%R(%3S
M<&EC;W,@9&4@06IU9&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS
M9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("),:7-T87(@5&%B96QA<R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),
M:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES="U!<F-H:79E(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L
M<"(*;7-G<W1R("),:7-T+4AE;'`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T
M+4ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*
M;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES="U/=VYE<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T
M+5!O<W0B"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM
M<V=S='(@(DQI<W0M4W5B<V-R:6)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS
M9W-T<B`B3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B02!L:7-T86=E;2!D92!S97-S]65S(&9A;&AO
M=3H@)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(D$@
M;&ES=&%G96T@9&4@=7-UX7)I;W,@9F%L:&]U.B`E<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&ES=&%G96T@9&4@=7-UX7)I;W,@
M97-TX2!D97-A8FEL:71A9&$N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R871U<F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71UXFYI
M82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B0V%R<F5G86YD;RXN+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO
M8V%L('1I;64Z("(*;7-G<W1R(")(;W)A(&QO8V%L.B`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G
M<W1R("),;V-A;&EZ8>?C;R!E($AO<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E)E9VGC;R(*
M"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C(P,"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")#;VYE8W1A<B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("),;V<@9&$@<V5S<^-O(&1E
M('-I;F-R;VYI>F'GXV\@86YT97)I;W(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D1E<V-O
M;F5C=&%R(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),
M;V=I;B(*;7-G<W1R(")#;VYE8W1A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(E1A<F5F87,@
M9&4@0V]N97CC;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM
M<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B3R!L
M;V=I;B!F86QH;W4@<&]R<75E('-E=2!U<W7A<FEO(&]U('-E;FAA(&5S=&%V
M82!I;F-O<G)E=&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DQ
M"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(D9A;&AA(&1E($QO9VEN
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD*;7-G:60@(DQO
M;F<@=&5X="(*;7-G<W1R(")497AT;R!L;VYG;R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")!;6]R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@
M(DQO=R(*;7-G<W1R(")"86EX82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R
M965K(&QE='1E<G,B"FUS9W-T<B`B06QF86)E=&\@9W)E9V\@96T@;6EN^G-C
M=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R(")!;&9A8F5T;R!L871I;F\@96T@;6EN^G-C=6QO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM
M<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S(')O
M;6%N;W,@96T@;6EN^G-C=6QO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE
M;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R9V\B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,SDY"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,S<@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G
M:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B3R!A;F5X;R!-4RU43D5&(&[C;R!C;VYTZ6T@9&%D;W,N(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(*;7-G<W1R(")-86-E9&]N:6$L($%N=&EG82!297#Z8FQI
M8V$@275G;W-LX79I82!D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R(")-861A9V%S8V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-X6=I8V\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T
M<B`B0V]R<F5I;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*
M;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B061M:6YI<W1R861O<B!D;R!#
M;W)R96EO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@
M(D-R:6%R(&QI;E]K+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB
M"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I
M82(*;7-G<W1R(")-86SA<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD
M:79E<R(*;7-G<W1R(")-86QD:79A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT
M82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O
M8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B1V5R96YC
M:6$@82!L:7-T82!D92!C871E9V]R:6%S(&4@87,@8V]R97,@87-S;V-I861A
M<R!A(&5L87,N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q-30*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87!E86UE
M;G1O($UA<#(T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P.#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q-CD*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!E
M86UE;G1O($UA<%%U97-T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(DUA<&5A
M;65N=&]S(&=R879A9&]S+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-87+G;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G96TB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R
M:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(DUA<F-A<B!C;VT@
M9FQA9W,@3&ED82].XV\@3&ED82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-87)C87(@
M8V]M(&]U=')O<R!F;&%G<R`H97@N($EM<&]R=&%N=&4O4F5S<&]N9&ED82DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T
M<B`B26QH87,@36%R<VAA;&PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I
M;FEQ=64B"FUS9W-T<B`B36%R=&EN:6-A(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R
M(")#86UP;W,@8V]R<F5S<&]N9&5N=&5S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I=.)N:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R[6-I;R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM
M<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")#<NED:71O(&WA
M>&EM;R!P97)M:71I9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T
M<R!E>&-E961E9"XB"FUS9W-T<B`B3OIM97)O(&WA>&EM;R!D92!P87)T97,@
M9&$@;65N<V%G96T@97AC961E=2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q,PIM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(E1E;7!E<F%T=7)A(&WA>&EM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA
M<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WA>&EM82!N87,@
M^FQT:6UA<R`V(&AO<F%S.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(").^FUE
M<F\@3>%X:6UO(&1E($)L;V-O<R!D92!0;W)T86PB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY,#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(R
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0S"FUS9VED(")-87AI
M;75M(&QE;F=T:"(*;7-G<W1R(")486UA;FAO(&WA>&EM;R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB
M"FUS9W-T<B`B36%I;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B
M"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D:6-I;F$B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S
M(@IM<V=S='(@(DUE;6)R;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUO9&\@9&\@;65N=3HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")-97-C;&%R(&/I
M;'5L87,B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-96YS86=E
M;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS
M9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@HB365N<V%G96T@5F5R:69I8V%D82!C;VT@4W5C97-S
M;R!M87,@;R!C97)T:69I8V%D;R!D;R!A<W-I;F%N=&4@;N-O('#T9&4@<V5R
M("(*(G9E<FEF:6-A9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N
M(@IM<V=S='(@(DUE;G-A9V5M(&5X<&ER861A+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*
M;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4:7!O(&1E(&UE;G-A9V5M
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T
M:&5R(@IM<V=S='(@(D-L:6UA($UE=&%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B0FQO8V\@365T87(@;N-O(&1I<W!O;NUV96PN(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D)L;V-O($UE=&%R(&[C;R!D:7-P
M;V[M=F5L+B!$971A;&AE<R!F;W)A;2!G<F%V861O<R!E;2!L;V<@<&%R82!O
M("(*(F%D;6EN:7-T<F%D;W(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*
M;7-G<W1R(")/($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861O+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM
M<V=S='(@(DWI=&]D;R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP
M:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS
M9W-T<B`B3>ET;V1O("<E<R<@;N-O(&5S=.$@9&5F:6YI9&\B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S
M='(@(DWI=&]D;R!NXV\@9&5F:6YI9&\N($WI=&]D;R!C:&%M861O.B`E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO
M;65T87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T<B`B3>ET<FEC82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DWI>&EC;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F(@IM<V=S='(@(DUI8W)O;NES:6$L($5S=&%D;W,@1F5D97)A9&]S
M(&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B365I;R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-
M:6UE(%1Y<&4B"FUS9W-T<B`B5&EP;R!-:6UE(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R(")496UP97)A='5R82!M[6YI;6$@;F%S(/IL=&EM87,@,C0@:&]R
M87,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-:6X@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UP97)A='5R82!M[6YI
M;6$@;F%S(/IL=&EM87,@-B!H;W)A<SH@(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E
M(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B261A9&4@;>UN:6UA(&1A
M('-E;FAA(&%I;F1A(&[C;R!E>'!I<F]U(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,PIM<V=I9"`B36ER<F]R(@IM<V=S
M='(@(D5S<&5L:&\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G
M:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B1&EV97)S;W,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G
M:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T
M<B`B4&%C;W1E(%!%05(@2%144%]297%U97-T(&9A;'1A;F1O+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B
M"B)#;VYF:6=U<F'GXV\@9F%L=&%N9&\N(%9O8^H@=&5M('%U92!G97)A<B!E
M;&$@86=O<F$@<V4@=F]CZB!Q=65R('5T:6QI>F%R("(*(F5S=&$@87!L:6-A
MY^-O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R
M("))1"!D82!M96YS86=E;2!F86QT86YD;RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES
M<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B4&%C
M;W1E(&]B<FEG873S<FEO(%!%05(@36%I;"!F86QT86YD;RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G
M:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B240@9&$@<V5S<^-O
M(&9A;'1A;F1O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(E-E9R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS
M9W-T<B`B0V]R<F5I;R!-\W9E;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")-
M;V1E<F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@
M(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&%T82!-;V1I9FEC861A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(D%L=&5R87(@55),(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@
M(DUO9'5L=7,B"FUS9W-T<B`B3?-D=6QO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD;W9A+"!297#Z
M8FQI8V$@9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R
M(")-]&YA8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S
M='(@(DUO;F?S;&EA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X
M.`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B3>IS(&4@86YO(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM
M<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-96YS86QM96YT92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")&87-E<R!D82!,=6$B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@
M9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N
M(@IM<V=S='(@(DUA:7,@8V%M<&]S(&5N8V]N=')A9&]S(&YA(&QI;FAA("5D
M('%U92!O(&[Z;65R;R!E<W!E<F%D;R`E9"XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R<F]C;W,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L
M96%R(@IM<V=S='(@(D=R86YD92!087)T92!,:6UP82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@
M0VQO=61Y(@IM<V=S='(@(D=R86YD92!087)T92!.=6)L861O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO
M<W1L>2!3=6YN>2(*;7-G<W1R(")'<F%N9&4@4&%R=&4@16YS;VQA<F%D;R(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B36]V97(@06)A:7AO(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")-;W9E<B#@($5S<75E<F1A
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B36]V97(@X"!$:7)E
M:71A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B36]V97(@06-I;6$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T
M"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B06)A:7AO(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E
M('5P(@IM<V=S='(@(D%C:6UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA
M;6)I<75E(@IM<V=S='(@(DUOYV%M8FEQ=64B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',B"FUS9W-T<B`B3&ES=&%S(&1E('-E;&7GXV\@9&4@;?IL=&EP;&]S
M(&[M=F5I<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#4V"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B36%P
M87,@26YG;&5S97,@375L=&EM87`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C0V"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B
M4V5L9>?C;R!M^FQT:7!L82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B36EN:&$@0V]N=&$B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`B4W5A<R!);F9O<FUAY_5E<R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#4*;7-G:60@(DUY(%!O<G1A
M;"(*;7-G<W1R(")-974@4&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D
M:70N<&AP.C0S"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUE
M=2!,87EO=70@9&4@4&]R=&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N
M;6%R(@IM<V=S='(@(D)I<FWB;FEA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!
M9W)E92(*;7-G<W1R(").PT\L($5U($[#3R!#;VYC;W)D;R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(DYO
M;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M
M[6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U
M<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(")(
M;VQA;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL
M;&5S(@IM<V=S='(@(D%N=&EL:&%S($AO;&%N9&5S87,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@
M0F%S92!54DPB"FUS9W-T<B`B55),($)A<V4@9&\@3F5T<V-A<&4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),(&1E(%)E=F]G
M8>?C;R!D92!#02!D;R!.971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@
M55),(@IM<V=S='(@(E523"!D92!P;VSM=&EC87,@9&4@0T$@9&\@3F5T<V-A
M<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM
M<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B55),(&1E(%)E
M;F]V8>?C;R!D;R!.971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%52
M3"(*;7-G<W1R(")54DP@9&4@4F5V;V=AY^-O(&1O($YE='-C87!E(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE
M='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").;VUE(&1O('-E<G9I
M9&]R(%-33"!D;R!.971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT(@IM<V=S='(@(D-O;65N=.%R:6\@9&\@8V5R=&EF:6-A9&\@9&\@
M3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R
M(")4:7!O(&1E(&-E<G1I9FEC861O(&1O($YE='-C87!E(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R
M(")2961E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3G5N8V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F]V82!#
M86QE9/1N:6$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO
M=F$@0V%T96=O<FEA(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@
M365S<V%G92!T;R`E<R(*;7-G<W1R(").;W9A($UE;G-A9V5M('!A<F$@)7,B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM
M<V=S='(@(DQU82!.;W9A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS
M9W-T<B`B3F]V;R!5<W7A<FEO("AO<&-I;VYA;"DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO=F$@6F5LXFYD:6$B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P
M87-S=V]R9"(*;7-G<W1R(").;W9A('-E;FAA(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@
M<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(DYO=F$@<V5N
M:&$@97AP:7)A<N$@96T@)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*
M;7-G<W1R(")!<R!N;W9A<R!S96YH87,@;N-O('/C;R!I9W5A:7,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I
M9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").;W9A(&IA;F5L82`H
M7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYO=.UC:6%S(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G
M<W1R(")'<G5P;W,@9&4@3F]T[6-I87,B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(")0<O-X:6UA
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA
M<V5S(@IM<V=S='(@(E!R\WAI;6%S(#0@1F%S97,B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V-B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E!R\WAI
M;6%S(&]PY_5E<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S
M"FUS9VED(").97AT/B(*;7-G<W1R(")0<O-X:6UA/B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%RX6=U82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEGZ7)I82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM
M<V=S='(@(DYO:71E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S
M='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.38T"FUS9VED(").;R(*;7-G<W1R(").XV\B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M(@IM<V=S='(@(DYE;FAU;2!D861O(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M
M=F5L('!A<F$@97AI8FER(&%S(&1I9F5R96[G87,N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S
M='(@(DYE;FAU;6$@97-T<F%TZ6=I82!D:7-P;V[M=F5L('!A<F$@8W)I87(@
M:6UA9V5N<R!)4T\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB
M"FUS9W-T<B`B3F5N:'5M(&UO9&5L;R!D92!B871C:"XB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM
M<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VXB"FUS9W-T<B`B3F5N:'5M(&)L;V-O(&5X:7-T92!N82!P;W-IY^-O('-O
M;&EC:71A9&$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P
M"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96YH=6T@;F]M92!D92!A9V5N9&$@
M9F]R;F5C:61O('!A<F$@82!A=71E;G1I8V'GXV\@34-!3"XB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R
M(").96YH=6UA(&%L=&5R8>?C;RXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5N:'5M('-U8F]R9&EN
M861O('!O9&4@<V5R(&%D:6-I;VYA9&\@82!E<W1A('!E<FUI<W/C;RXB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V.2!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4P.`HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").96YH=6UA(&EN
M9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A("5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4U"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RXB"FUS9W-T<B`B3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R
M8>?C;R!E<W!E8VEF:6-A9&$@<&%R82!&5%`@5D93+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B
M3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A
M9&$@<&%R82!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(DYE;FAU
M;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A
M<F$@4U%,+49I;&4@5D93+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N
M(@IM<V=S='(@(DYE;FAU;2!C<NED:71O(')E<W1A;G1E+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED
M(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B3F5N:'5M(&1E
M<W1I;F\@9F]R;F5C:61O+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.CDP,PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(").
M96YH=6T@87)Q=6EV;R!E;G9I861O(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B3F5N:'5M
M(.UC;VYE(&5N8V]N=')A9&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,S`*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB
M"FUS9W-T<B`B3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3F5N:'5M82!L;V-A;&EZ8>?C
M;R!C;VYF:6=U<F%D82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE
M9"XB"FUS9W-T<B`B3F5N:'5M82!M96YS86=E;2!F;W)N96-I9&$N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*
M;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").96YH=6T@;F]M
M92!E<W!E8VEF:6-A9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I
M960N(@IM<V=S='(@(DYE;FAU;2!N^FUE<F\@97-P96-I9FEC861O+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E
M(&9O<G1U;F5S(@IM<V=S='(@(E-E;2!S;W)T97,@;V9E;G-I=F%S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DYE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'G
MXV\@2%144"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P
M.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DYE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A
M<F$@82!A=71E;G1I8V'GXV\@24U!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE;FAU;6$@
M<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@2V5R8F5R;W,N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O
M<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5N:'5M82!S96YH
M82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!,;V=I;BXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(").96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT
M:6-AY^-O(%!!4U-71"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP
M:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DYE;FAU;6$@<V5N:&$@9F]R;F5C:61A
M('!A<F$@82!A=71E;G1I8V'GXV\@4TU"+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T
M:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R
M>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB
M"FUS9W-T<B`B(@HB3F5N:'5M('!A=&@@<&%R82!O(&)I;N%R:6\@9&\@3W!E
M;E-33"!F;VD@9F]R;F5C:61O+B!/(&)I;N%R:6\@9&\@3W!E;E-33"#I("(*
M(FYE8V5S<^%R:6\@<&%R82!M86YI<'5L87(@;W,@9&%D;W,@4$M#4R`Q,BXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED
M(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(DYE;FAU;2!C861A<W1R
M;R!P96YD96YT92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S8V"FUS
M9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(E%U;W1A(&[C;R!C;VYF:6=U
M<F%D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")396T@;&EN
M:&%S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS9VED
M(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R(").96YH=6T@<V5P
M87)A9&]R(&9O:2!E<W!E8VEF:6-A9&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED
M97,B"FUS9W-T<B`B4V5M(&QA9&]S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(")!<G%U
M:79O(&EN97AI<W1E;G1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+B(*;7-G<W1R(").96YH=6T@9&ER973S<FEO('1E;7!O
M<N%R:6\@9&ES<&]N[79E;"!P87)A(&\@8V%C:&4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").96YH=6T@
M=7-UX7)I;R!E+V]U('-E;FAA(&9O<FYE8VED;W,N(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D(@IM<V=S='(@(DYE;FAU;2!D861O(%A-3"!VX6QI9&\@
M<F5T;W)N861O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3@R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P,3`*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")396T@=F%L;W)E
M<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B).96YH=6T@=F5R<^-O
M(&5N8V]N=')A9&$@;F$@8V]N9FEG=7)AY^-O(&]R:6=I;F%L+B!'97)E(&YO
M=F%M96YT92!A("(*(F-O;F9I9W5R8>?C;RXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B).96YH=6UA('9E<G/C;R!E;F-O;G1R861A(&YA('-U82!C;VYF
M:6=U<F'GXV\N($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO
M;F4B"FUS9W-T<B`B3F5N:'5M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I
M="DB"FUS9W-T<B`B3F5N:'5M82`H=7-O(&EM<&SM8VET;RDB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ
M,"DB"FUS9W-T<B`B3O-R9&EC;R`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("));&AA($YO<F9O
M;&LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DAE
M;6ES9NER:6\@3F]R=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N
M($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("));&AA<R!-87)I86YA(&1O($YO
M<G1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R
M=65G82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q
M"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B3N-O($%P\W,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E
M9F]R92(*;7-G<W1R(").XV\@06YT97,B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HT,34*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R
M(").XV\@Z2!U;2!D:7)E=/-R:6\B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU
M.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(").XV\@26UP;&5M
M96YT861O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3N-O(&-O;F9I9W5R
M861O(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-#4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S0*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(U,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR.#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V-B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-#(V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W-`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3DQ(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-CD*;7-G
M:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(D[C;R!S=7!O<G1A9&\N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R(")!;F]T8>?U97,B
M"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").861A('!A<F$@
M97AI8FER+"!V;VQT92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB
M<F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4P"FUS9VED(").
M=6UB97(B"FUS9W-T<B`B3OIM97)O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T
M<B`B3OIM97)O(&1E(&-A<F%C=&5R97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T.2!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O
M;'5M;G,B"FUS9W-T<B`B3OIM97)O(&1E(&-O;'5N87,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-R!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M
M8F5R(&]F(')O=W,B"FUS9W-T<B`B3OIM97)O(&1E(&QI;FAA<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").^FUE<F\@;N-O(&5S<&5C:69I
M8V%D;R!P87)A(&%T=6%L:7IAY^-O(&YA(&QI<W1A(&1E(&1I<W1R:6)U:>?C
M;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,0IM<V=I9"`B3V)J96-T(@IM<V=S
M='(@(D]B:F5T;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q
M"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")#<FEA9&]R(&1O($]B
M:F5T;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#@*;7-G:60@
M(D]C=&%L(@IM<V=S='(@(D]C=&%L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B
M3W5T=6)R;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B
M3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=')O(&]F96YS:79O(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM
M<V=S='(@(D5S8W)I=/-R:6\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E
M(&1I9F9E<F5N="XB"FUS9W-T<B`B4V5N:&%S(&%N=&EG82!E(&YO=F$@9&5V
M96T@<V5R(&1I9F5R96YT97,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4V5N:&$@
M86YT:6=A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS
M9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E-E
M;FAA(&%N=&EG82!NXV\@97-TX2!C;W)R971A+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3VUA;B(*;7-G<W1R(")/;>,B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B4V]M96YT92!S
M97)V:61O<F5S($E-05`@<W5P;W)T86T@<&%S=&%S(&-O;7!A<G1I;&AA9&%S
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B4V]M96YT92!S;W)T97,@;V9E
M;G-I=F%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")/;FQY(&]N92!E;6%I
M;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(E-O;65N=&4@=6T@96YD97)E
MYV\@9&4@92UM86EL('!E<FUI=&ED;RXB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(E-O;65N
M=&4@;R!P<F]P<FEE=.%R:6\@;W4@;R!A9&UI;FES=')A9&]R(&1O('-I<W1E
M;6$@<&]D96T@86QT97)A<B!A<R`B"B)P97)M:7-S]65S(&1E('!R;W!R:65D
M861E(&]U('!R;W!R:65TX7)I;R!D92!U;2!C;VUP87)T:6QH86UE;G1O(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%B
M<FER(&5M('5M82!N;W9A(&IA;F5L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*
M;7-G<W1R(")%<G)O(&1O($]P96Y34TPZ($[C;R!P=61E(&5X=')A:7(@9&%D
M;W,@9&$@<&%R=&4@87-S:6YA9&$@4R]-24U%+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!8G)E
M(&5S=&4@;&EN:R!E;2!U;6$@;F]V82!J86YE;&$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T
M<B`B4VES=&5M82!/<&5R86-I;VYA;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W#G]65S
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S
M(@IM<V=S='(@(D]PY_5E<R!D92`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*
M;7-G<W1R("),:7-T82!/<F1E;F%D82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T
M<B`B3W)G86YI>F'GXV\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R
M(")5;FED861E($]R9V%N:7IA8VEO;F%L(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A
M;FEZ86YD;R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")-;V1E;&\@
M;W)I9VEN86P@9&4@87!L:6-AY^-O(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.B(*;7-G<W1R(")-;V1E;&\@;W)I9VEN86P@96T@)7,Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D]U=')O(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M
M871I;VXB"FUS9W-T<B`B3W5T<F%S($EN9F]R;6'G]65S(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D;R!0<F]P<FEE=.%R:6\B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!=71E;G1I
M8V'GXV\@4$%-(&[C;R!E<W3A(&1I<W!O;NUV96PN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2
M.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B0V]N96-T;W(@4$5!4CHZ36%I;"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@
M(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")!<W-I;F%T=7)A($1I
M9VET86P@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(D1A9&]S
M($-R:7!T;V=R869A9&]S(&-O;2!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G
M<W1R(")#:&%V92!0^F)L:6-A(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B1&%D;W,@07-S:6YA9&]S+T-R:7!T;V=R869A9&]S
M(&-O;2!01U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(
M4"!#;V1E(@IM<V=S='(@(D/S9&EG;R!02%`B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("),:6YH82!D92!#
M;VUA;F1O(%!(4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(D-H=79A
M($9R86-A(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")#:'5V
M82!697-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B0VAU=F%S
M(%9E<W!E<G1I;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B3F5V92!697-P
M97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#$*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(").979A<V-A
M(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,@IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(DYE=F4@5F5S<&5R
M=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0S"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")4<F]V;V%D87,@5F5S
M<&5R=&EN87,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED
M(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")%<W3A(&9A
M;'1A;F1O(&$@97AT96YSXV\@4$]325@B"@HC.B!L:6(O87!I+G!H<#HQ-#D*
M;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B3&EN:&$@9&4@0V]M86YD;R!0
M7TA0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")-87)G96TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A<75I<W3C
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y
M+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I;F\L(%1E<G)I=/-R:6\@3V-U
M<&%D;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A
M;F%MX2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*
M;7-G<W1R(")0X7!U82!.;W9A($=U:6[I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U86DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L
M;W5D>2(*;7-G<W1R(")087)C:6%L;65N=&4@3G5B;&%D;R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C(*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A
M<W-W;W)D(@IM<V=S='(@(E-E;FAA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B4V5N:&$@86QT97)A9&$@8V]M('-U8V5S<V\N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED
M(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4V5N:&$@:6YC;W)R971A
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I
M9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B4V5N:&$@;V)R:6=A=/-R:6$@<&%R82!A(&%U=&5N=&EC
M8>?C;R!2041)55,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U
M-PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B
M4V5N:&$@8V]M(&-O;F9I<FUAY^-O(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4V5N:&$Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A
M<W-W;W)D.B`B"FUS9W-T<B`B4V5N:&$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R(")396YH87,@9&5V96T@<V5R(&EG=6%I<RXB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B
M"FUS9W-T<B`B0V]L87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*
M;7-G<W1R(")#;VQA<B!D82#A<F5A(&1E('1R86YS9F5RZFYC:6$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED
M(")0871H(@IM<V=S='(@(E!A=&@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")#
M861A<W1R;W,@4&5N9&5N=&5S.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(E!E<W-O87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B
M4&5R8V5N="(*;7-G<W1R(")0;W)C96YT86=E;2(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B17AE8W5T87(@3W!E
M<F'G]65S(&1E($UA;G5T96[GXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(D5X96-U=&%R(&]P97)AY_5E<R!D92!M86YU
M=&5NY^-O(&%O(&-O;F5C=&%R/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E!E<FUI
M<W/C;R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM
M<V=S='(@(E!E<FUI<W/C;R!<(B5S7"(@;N-O(&5X8VQU[61A+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")097)M:7-S:6]N
M($1E;FEE9"(*;7-G<W1R(")097)M:7-SXV\@3F5G861A(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!E
M<FUI<W/U97,B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H
M<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')AY^-O(&1E
M(%!E<FUI<W/U97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6'G]65S
M(%!E<W-O86ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@
M(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E
M=',B"FUS9W-T<B`B06YI;6%I<R!D92!%<W1I;6'GXV\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YA<R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G
M:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VYE(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET
M8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I>&5L<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G
M<W1R(")#;&EC:.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S
M;VUE(&-E;&PB"FUS9W-T<B`B4&]R(&9A=F]R(&-L:7%U92!E;2!A;&=U;6$@
M8^EL=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(E!O<B!F
M879O<B!C;VYF:7)M92!Q=64@=F]CZB!Q=65R(')E;6]V97(@97-T92!E;&5M
M96YT;SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B4&]R(&9A
M=F]R(&-O;F9I<FUE('%U92!V;V/J('%U97(@<F5M;W9E<B!O(&QI;FL@9&5S
M=&4@96QE;65N=&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4V
M-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS
M9W-T<B`B4&]R(&9A=F]R(&9O<FYEYV$@=6T@;>IS(&4@=6T@86YO+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS
M9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y
M.B(*;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G82!U;2!N;VUE('!A<F$@82!N
M;W9A(&-A=&5G;W)I83HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*
M;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G82!U;2!E;F1E<F7G;R!)4"!VX6QI
M9&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T-PIM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B4&]R(&9A=F]R(&9O<FYE
MYV$@=6UA(&1A=&$@=N%L:61A+"!V97)I9FEQ=64@;R!N^FUE<F\@9&4@9&EA
M<R!N;R!MZG,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B4&]R
M(&9A=F]R(&9O<FYEYV$@=6UA(&AO<F$@=N%L:61A+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B4&]R(&9A=F]R
M(&9O<FYEYV$@=6T@<F5S=6UO(&1O('!R;V)L96UA+B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0B"FUS9W-T<B`B4&]R(&9A=F]R(&9O<FYEYV$@<V5U('5S=>%R
M:6\@92!S96YH82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E
M;2XB"FUS9W-T<B`B(@HB4&]R(&9A=F]R(&QE:6$@;R!T97AT;R!A('-E9W5I
M<BX@5F]CZB!$159%(&-O;F-O<F1A<B!C;VT@;W,@=&5R;6]S(&1E('5S;R!D
M;R`B"B)S:7-T96UA+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E!O<B!F879O<B!D:6=I=&4@;R!N
M;VUE(&1A(&YO=F$@8V%T96=O<FEA.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&]L86YD(@IM<V=S='(@(E!O;/1N:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;.UT:6-A(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B
M"FUS9W-T<B`B16YQ=65T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U
M9V%L(@IM<V=S='(@(E!O<G1U9V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I
M=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E!O<VGGXV\@9&5S=&$@
M:6UA9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS
M9W-T<B`B4&]S:>?C;R!D97-T82!T86)E;&$B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(D5N=FEE
M('!A<F$@97-T82!P87-T82`H;N-O(.D@;V)R:6=A9&\@<&5L;R!)34%0*2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E!R96-I<&ET8>?C;R!P87)A
M(&$H<RD@^FQT:6UA*',I("5S(&AO<F$H<RDZ("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B4')E8VEP:71AY^-O/&)R("\^8VAA;F-E(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(E!R969S7VQD87`Z($5X=&5N<^-O($Q$05`@;V)R:6=A=/-R
M:6$@;N-O(&5N8V]N=')A9&$N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7W-E<W-I;VXZ($5X=&5N<^-O(&1E('-E<W/C;R!O8G)I9V%T\W)I82!NXV\@
M96YC;VYT<F%D82XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I
M9"`B4')E<W-U<F4B"FUS9W-T<B`B4')E<W/C;R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*
M;7-G<W1R(")0<F5S<^-O(&5M(&[M=F5L(&1O(&UA<CH@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*
M;7-G<W1R(")0<F5S<^-O.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C`T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*
M;7-G<W1R(")0<NDM=FES=6%L:7IAY^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B4')E
M=F5R(&$@:6UA9V5M(&5M('5M82!N;W9A(&IA;F5L82(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@
M(D]PY_5E<R!A;G1E<FEO<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS
M9W-T<B`B26UP<FEM:7(@9&]C=6UE;G1O(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R
M(")#:&%V92!0<FEV861A(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M82(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$
M97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGGXV\@9&\@4')O8FQE;6$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T
M<R(*;7-G<W1R(")0<F]J971O<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y,@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")0<F]M<'0@=&5X="(*
M;7-G<W1R(")497AT;R!B<F5V92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")#:&%V
M92!0^F)L:6-A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D%L
M9V]R:71M;R!D82!#:&%V92!0^F)L:6-A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*
M;7-G<W1R(")#:&%V92!0^F)L:6-A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")087(@9&4@
M8VAA=F5S(%#Z8FQI8V$O4')I=F%D82!NXV\@9F]R86T@9V5R861O<R!C;VT@
M<W5C97-S;RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*
M;7-G<W1R(")0;W)T;R!2:6-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T
M87(B"FUS9W-T<B`B46%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*
M;7-G:60@(E%U97)Y(@IM<V=S='(@(D-O;G-U;'1A<B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B46%T87(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R(")#:&%V92!0^F)L:6-A(%)302`H)60@8FET*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-C@*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*
M;7-G<W1R(")";W3U97,@9&4@<V5L9>?C;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN(@IM<V=S='(@
M(D-H=79A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#4*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B0VAU=F$@36%T=71I
M;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(D-H=79A(%9E<W!E<G1I;F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM
M<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B4&%N8V%D87,@9&4@0VAU=F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM
M<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")#:'5V82!E($YE=F4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I
M9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(D-H=79A('!A<F$@3F5V92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N
M92(*;7-G<W1R(")3;W)T92!!;&5A=/-R:6$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E)E;&'G
MXV\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM
M<V=I9"`B4F5A9"(*;7-G<W1R("),97(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*
M;7-G<W1R("),97(@;65N<V%G96YS(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(D5X8VQU:7(@<F5A;&UE;G1E("5S/R!%<W1A(&]P97)AY^-O(&[C
M;R!P;V1E('-E<B!D97-F96ET82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB4F5M;W9E<B!R96%L;65N=&4@
M;W,@9&%D;W,@9&\@=7-UX7)I;R`E<S\@17-T82!O<&5R8>?C;R!NXV\@<&]D
M92!S97(@(@HB9&5S9F5I=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A
M8W1I;VXB"FUS9W-T<B`B4F5F87H@<W5A(/IL=&EM82!AY^-O(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B071U86QI>F%R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D%T=6%L:7IA<B!-96YU(&1E($5L
M96UE;G1O<R!$:6[B;6EC;W,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B071U
M86QI>F%R($5X:6)IY^-O(&1O(%!O<G1A;#HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*
M;7-G<W1R(")296=E>"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M,S@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(DYA=F5G
M861O<B!D92!296QAY_5E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@
M(E)E;&]A9"(*;7-G<W1R("),97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,S,PIM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")/8G-E<G9AY_5E<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V
M97)S(@IM<V=S='(@(E-E<G9I9&]R97,@4F5M;W1O<R(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E523"!296UO
M=&$@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(E)E
M;6]V97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G
M:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")296UO=F5R($)L;V-O(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I
M9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")296UO=F5R(&-O;'5N82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G
M:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E)E;6]V97(@9F]R;6%T
M8>?C;R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED
M(")296UO=F4@<&%I<B(*;7-G<W1R(")296UO=F5R('!A<B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I
M<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M(")296UO=F5R('-C<FEP="!G<F%V861O(&YO(&1I<F5T\W)I;R!T96UP;W+A
M<FEO(&1O('-E<G9I9&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*
M;7-G<W1R(")296UO=F5R(&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B4F5M;W9E<B!E<W1E
M(&[S(&1O(&1O8W5M96YT;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(E)E;6]V
M97(@=7-UX7)I;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS
M9W-T<B`B4F5M;W9E<B!U<W7A<FEO.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E
M(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(")3;VQI
M8VET8>?C;R!NXV\@</1D92!S97(@<F5S<&]N9&ED82X@0_-D:6=O(&1E(&5R
M<F\@<F5T;W)N861O.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@
M9F]U;F0N(@IM<V=S='(@(D\@<V5R=FGG;R!R97%U:7-I=&%D;R!NXV\@<&]D
M92!S97(@96YC;VYT<F%D;RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$W-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G)7,G(&]B<FEG873S<FEO
M(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W."!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@V,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(G)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O
M;F9I9W5R8>?C;R!61E,N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z
M-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B<E<R<@;V)R
M:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM
M<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B0V%M<&\@3V)R:6=A=/-R
M:6\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS-#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS
M9W-T<B`B3&EM<&%R(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(D=E<F%R($YO=F$@
M4V5N:&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I
M9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")'97)A<B!.;W9A(%-E
M;FAA(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R
M92!,87-T(%%U97)Y(@IM<V=S='(@(MIL=&EM;R!1=6%R=&\B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN
M+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")297-U
M;'1A9&]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T
M:6]N<R(*;7-G<W1R(")2971O<FYA<B#@($]PY_5E<R(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S
M=V]R9"(*;7-G<W1R(")$:6=I=&4@82!N;W9A('-E;FAA(&YO=F%M96YT92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FGC
M;R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B4F5V97)T97(@0V]N9FEG=7)AY^-O(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M(@IM<V=S='(@(D]PY_5E<R!D;R!%9&ET;W(@4FEC:"!497AT(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@
M(D-H87)A9&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")$:7)E:71A
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,`IM<V=I9"`B4FEG
M:'0@:&5A9&5R(@IM<V=S='(@(D-A8F7G86QH;R!D:7)E:71O(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-@IM<V=I9"`B4FEG:'0@=F%L=65S
M(@IM<V=S='(@(E9A;&]R97,@9&$@9&ER96ET82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B
M4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!?
M3&EN:&$N+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(D9U;N?C;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4F]MZFYI82(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*;7-G
M:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B1VER87(@,3@P(&=R875S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,0IM<V=I
M9"`B4F]T871E($QE9G0B"FUS9W-T<B`B1VER87(@<&%R82!A($5S<75E<F1A
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M-PIM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(D=I<F%R('!A<F$@82!$
M:7)E:71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B
M4')O<')I961A9&5S(&1A($QI;FAA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E
M<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A(&QI;FAA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@
M(E)O=W,Z(@IM<V=S='(@(DQI;FAA<SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*
M;7-G<W1R("),:6YH87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(DQI;FAA
M<R!A<&%R96-E<N-O(&5N=')E('1O9&%S(&%S(&QI;FAA<R!E(&-O;'5N87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M
M;G,@;VYL>2(*;7-G<W1R("),:6YH87,@87!A<F5C97+C;R!S;VUE;G1E(&5N
M=')E(&-O;'5N87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>2(*;7-G<W1R("),:6YH87,@87!A<F5C97+C;R!S
M;VUE;G1E(&5N=')E(&QI;FAA<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C`*;7-G:60@(E)U;B(*;7-G<W1R(")%>&5C=71A<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")&961E<F'G
MXV\@4G5S<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T
M<B`B4G5A;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*
M;7-G<W1R(")!<W-I;F%T=7)A($-R:7!T;V=RX69I8V$@4R]-24U%(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O
M34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")-96YS86=E;2!#<FEP
M=&]G<F%F861A(&-O;2!3+TU)344B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(D%U=&5N=&EC8>?C;R!305-,(&[C;R!E
M<W3A(&1I<W!O;NUV96PN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")#;W)R96EO(%--
M4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(DQI;FAA(&1E(&-O;6%N9&\@4U%,(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<R(*;7-G<W1R(")396YT96[G82!344P@<&%R82!P97-Q
M=6ES87,@9&4@=F%L;W)E<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(E-50T534T\B"@HC.B!L:6(O
M87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B3&EN:&$@
M9&4@8V]M86YD;R!37U%,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B4V%B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A;G1A
M($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD
M($YE=FES(@IM<V=S='(@(E/C;R!+:71T<R!E($YE=FES(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386YT82!,=7II82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VXB"FUS9W-T<B`B4^-O(%!E9')O(&4@36EQ=65L;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*
M;7-G<W1R(")3XV\@5FEC96YT92!E($=R86YA9&EN87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE
M(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B365S;6\@<75A9')O("A?<V5L9BDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R(")386UO82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N
M($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0
M<FEN8VEP92(*;7-G<W1R(")3XV\@5&]MZ2!E(%!R[6YC:7!E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E
M(%!R;W9I9&5R(@IM<V=S='(@(E!R;W9E9&]R(&1E(%-A=.EL:71E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(D%RX6)I
M82!3875D:71A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY
M"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9A<B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V92!<(B5S7"(B"FUS9W-T<B`B4V%L=F%R("5S(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M92`E<R(*;7-G<W1R(")386QV87(@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B4V%L=F%R
M($]PY_5E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@
M(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@HB4V%L=F%R(&-O;F9I9W5R8>?C;R!G97)A9&$@8V]M;R!U
M;2!S8W)I<'0@4$A0('!A<F$@;R!D:7)E=/-R:6\@=&5M<&]RX7)I;R!D;R`B
M"B)S974@<V5R=FED;W(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B0V]N9FEG=7)AY^-O("5S('-A;'9A+B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@
M(E-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@<V%L=F\@
M96TZ("<E<R<N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3`*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")4
M96UP97-T861E<R!)<V]L861A<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")#:>IN8VEA(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")097-Q
M=6ES87(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED
M(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")%;F=I;F5S(&1E(%!E<W%U:7-A
M("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-C(*;7-G:60@(E-E
M;&5C="!&:6QE<R(*;7-G<W1R(")396QE8VEO;F4@;W,@07)Q=6EV;W,B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@S"FUS
M9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C:6]N92!U;6$@9&%T
M82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")3
M96QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B4V5L96-I;VYE('5M(&=R
M=7!O('!A<F$@861I8VEO;F%R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E-E
M;&5C:6]N92!U;2!N;W9O(&UE;6)R;R(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@
M(E-E;&5C:6]N92!U;2!S97)V:61O<B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G
M<W1R(")396QE8VEO;F4@=6T@=7-UX7)I;R!P87)A(&%D:6-I;VYA<B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S0*;7-G
M:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B4V5L96-I;VYA<B!T;V1O<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3`*;7-G:60@(E-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")396QE8VEO;F4@=&]D;W,@
M;W,@8V]M<&]N96YT97,@9&4@9&%T82XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<Q"FUS9VED(")396QE8W0@86X@;V)J
M96-T(@IM<V=S='(@(E-E;&5C:6]N92!U;2!O8FIE=&\B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<U"FUS9VED(")396QE
M8W0@;F]N92(*;7-G<W1R(").XV\@<V5L96-I;VYA<B!N96YH=6TB"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+B(*;7-G<W1R("(B"B)396QE8VEO;F4@;W,@8V%R86-T97)E<R!Q
M=64@=F]CZB!P<F5C:7-A(&YA(&-A:7AA(&%B86EX;RX@5F]CZB!P;V1E(&5N
M=.-O("(*(F-O<&GA+6QO<R!E(&-O;.$M;&]S(&YA(.%R96$@9&4@=&5X=&\N
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C
M="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E-E;&5C:6]N92!U;2!D
M96QI;6ET861O<B!D92!D871A.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R
M(")396QE8VEO;F4@;R!F;W)M871O(&1E(&1A=&$Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E-E;&5C
M:6]N92!A(&ED96YT:61A9&4@<75E('9O8^H@<75E<B!A;'1E<F%R.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE
M('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE8VEO;F4@=6T@9&5L:6UI
M=&%D;W(@9&4@:&]R83HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V5L
M96-I;VYE(&\@9F]R;6%T;R!D92!H;W)A.B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+B(*;7-G<W1R(")396QE8VEO;F4@9&]I<R!C86UP;W,@8V]R<F5S<&]N
M9&5N=&5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@
M(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4V5L96-I;VYE
M('-E=2!E<W%U96UA(&1E(&-O<F5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93HB"FUS9W-T<B`B4V5L96-I;VYE('-E=2!I9&EO;6$@<')E9F5R:61O.B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")3
M96YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D5N=FEA<B!296QA=/-R:6\@
M9&4@4')O8FQE;6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`T,`IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B16YV:6%R
M(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B
M4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(S"FUS9VED(")3
M96YS;W(Z("(*;7-G<W1R(")396YS;W(Z("(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS
M9W-T<B`B4V5T96UB<F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S
M='(@(E-E<G9I82!E($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G
M<W1R(").^FUE<F\@9&4@4^ER:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")$861O<R!D;R!S97)V:61O<B!E<G)A9&]S
M(&]U(&[C;R!D:7-P;V[M=F5I<RXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B061M:6YI<W1R861O
M<B!D92!397-SXV\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB
M"FUS9W-T<B`B240@9&$@4V5S<^-O(&5X<&ER;W4N(@H*(SH@;&EB+V%P:2YP
M:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")397-S]65S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q.`IM<V=I9"`B4V5T(@IM<V=S
M='(@(D%J=7-T87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G
M:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB0V]N
M9FEG=7)A(&%S(&]PY_5E<R!P87)A('!E<FUI=&ER('9O8^H@9V5R87(@=6UA
M(&YO=F$@<V5N:&$@<V4@=F]CZB!E<W%U96/J+2(*(FQA+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+B(*;7-G<W1R("(B"B)#;VYF:6=U<F$@;W,@<V5R=FED;W)E<R!R96UO=&]S
M('%U92!V;V/J('%U97(@86-E<W-A<B#@('!A<G1I<B!D;R!P;W)T86PN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N
M(@IM<V=S='(@(D-O;F9I9W5R82!S974@:61I;VUA('!R969E<FED;RP@9G5S
M;R!H;W+A<FEO(&4@;W#G]65S(&1E(&1A=&$N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L
M:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O
M=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D-O;F9I9W5R
M82!S=6$@87!L:6-AY^-O(&EN:6-I86PL(&5S<75E;6$@9&4@8V]R97,L(&%T
M=6%L:7IAY^-O(&1E('#A9VEN87,@92`B"B)O=71R87,@;W#G]65S(&1E(&5X
M:6)IY^-O+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@
M(E-E='5P(@IM<V=S='(@(D-O;F9I9W5R8>?C;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(E-C<FEP=',@9&4@871U86QI
M>F'GXV\@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV96ES(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A
M=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B
M1&EV97)S87,@;&]C86QI9&%D97,@<&]S<^UV96ES(&-O;2!O('!A<N)M971R
M;SH@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R
M(")396EC:&5L97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX
M"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")#;VUP<F%S(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA
M<GDB"FUS9W-T<B`B4F5S=6UO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_(@IM<V=S='(@(E1E8VQA<R!D92!A=&%L:&\@9&5V97+C
M;R!S97(@9&5F:6YI9&%S('!A<F$@82!M86EO<FEA(&1O<R!L:6YK<S\B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B
M4VAO=R(*;7-G<W1R(")%>&EB:7(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(D5X:6)I<B!A<R!D:69E<F5NYV%S(&5N=')E
M(&$@8V]N9FEG=7)AY^-O(&%T=6%L(&4@82!N;W9A(&=E<F%D82XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G
M:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(D5X:6)I<B!D871A
M(&4@:&]R82!D82#Z;'1I;6$@8V]N97CC;R!A;R!S92!C;VYE8W1A<C\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Y"FUS9VED(")3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(D5X:6)I<B!A(&]PY^-O
M(&1E(&UA;G1E<B!O(&]R:6=I;F%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@P,@IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B17AI8FER
M('-E;&5T;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED
M(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(D5X
M:6)I<B!B87)R82!D92!M96YU(&-O;2!O<&5R8>?U97,@9&4@=&%B96QA/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B
M17AI8FER(&\@365N=2`E<R#@(&5S<75E<F1A/R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M(")%>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D
M82!486)E;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(D5X:6)I<B!D:>%L;V=O(&1E(%!R;W!R
M:65D861E<R!D82!486)E;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")%>&EB:7(@9&GA
M;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@3&EN:&%S(&1A(%1A8F5L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B17AI8FER(&1IX6QO9V\@9&4@<')O<')I961A9&5S(&1E(&EM
M86=E;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C<*;7-G:60@
M(E-H;W<@=7!L;V%D(@IM<V=S='(@(D5X:6)I<B!U<&QO860B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO
M=V5R<R(*;7-G<W1R(")#:'5V87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G
M<W1R(")#:'5V87,@;6%T:6YA:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S
M='(@(D-H=79A<R!697-P97)T:6YA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S(&EN('1H92!6
M:6-I;FET>2(*;7-G<W1R(")#:'5V87,@;F%S(')E9&]N9&5Z87,B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM
M<V=I9"`B4VAR:6YK(@IM<V=S='(@(E)E9'5Z:7(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB
M;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@
M(E!R:6UE:7)A;65N=&4@<F5D=7IA(&]U('1I<F4@9&\@8V%M:6YH;R!O*',I
M(&)L;V-O*',I(&%D:F%C96YT92AS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R(")397)R82!,96]A(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*
M;7-G<W1R(")296=I<W1R87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(D%S<VEN
M871U<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET
M;6\@9&$@07-S:6YA='5R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A
M<&]R92(*;7-G<W1R(")#:6YG87!U<F$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#`*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C0Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3`@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ.0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$R"FUS9VED(")3:7IE(@IM<V=S='(@(E1A;6%N:&\B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM
M<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("))9VYO<F%R($UA;G5T
M96[GXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R
M(")%<VQO=N%Q=6EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B
M"FUS9W-T<B`B17-L;W9E;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<B"FUS9W-T<B`B3F5V92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS
M9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(").979A<V-A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@
M4VAO=V5R<R(*;7-G<W1R(").979A<V-A<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@
M16%R;'DB"FUS9W-T<B`B0VAU=F%S(&UA=&EN86ES(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO
M=V5R<R!,871E(@IM<V=S='(@(DYE=F%S8V%S(%9E<W!E<G1I;F%S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*
M;7-G<W1R(")0<F]F=6YD:61A9&4@9&$@3F5V93H@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.#D*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@(@IM<V=S='(@(D5Q=6EV86QE;G1E(&1E(&YE=F4@96T@X6=U83H@(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@
M(DEL:&%S(%-A;&]MXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(E-O;>%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B0V%NY_5E<R`F(%!O
M96UA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,34*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(D]R9&5N87(@<V5L9>?C
M;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D5N
M9&5R9>=O(&1E(&]R:6=E;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H
M($%F<FEC82(*;7-G<W1R("+!9G)I8V$@9&\@4W5L(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#D*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*2(*;7-G<W1R(")3=6P@175R;W!E=2`H25-/+3@X-3DM,RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(E-U;"!D82!'96]R9VEA(&4@4W5L
M(&1A<R!);&AA<R!386YD=>UC:&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(DAE;6ES9NER:6\@4W5L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E
M(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B17-P8>=O(&5N=')E
M(&/I;'5L87,@861J86-E;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(D5S<&'G;R!E;G1R
M92!O(&-O;G1E^F1O(&4@8F]R9&$@9&$@8^EL=6QA(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#$Y"FUS9VED(")3<&%C97(B"FUS9W-T<B`B17-P
M8>=A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(D5S<&'G86UE
M;G1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R
M(")%<W!AYV%M96YT;R!E(&UA<F=E;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3
M<&%I;B(*;7-G<W1R(")%<W!A;FAA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E
M<B!);G!U="(*;7-G<W1R(")%;G1R861A(&1E($-A<F%C=&5R97,@17-P96-I
M86ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")$:79I9&ER
M(&/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")$
M:79I9&ER(&-O;'5N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M(")$:79I9&ER(&QI;FAA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q
M"FUS9VED(")3<&]R=',B"FUS9W-T<B`B17-P;W)T97,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX,0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4&%D<N-O(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS
M9W-T<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDX"FUS9VED(")3=&%R
M="!Y96%R(@IM<V=S='(@(D%N;R!I;FEC:6%L(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I
M;F-E(@IM<V=S='(@(D5S=&%D;R!O=2!0<F]V[6YC:6$B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM
M<V=S='(@(E-I='5AY^-O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@P-`IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D
M;R!A<FUA>F5N86UE;G1O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(DYO
M;64@9&$@4G5A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")4<F'G
M861O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PIM<V=I9"`B
M4W1R:6YG(&QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@8V%D96EA<R!D92!C87)A
M8W1E<F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I
M9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B4F5T
M:7)A<B!A('!A<G1E(&1O(&1O;>UN:6\@9&\@96YD97)EYV\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS
M9VED(")3='EL92!;0U-372(*;7-G<W1R(")%<W1I;&\@6T-34UTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED
M(")3=2(*;7-G<W1R(")$;VTB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E-U8F1I<F5T\W)I;R`G)7,G(&[C;R!E;F-O
M;G1R861O+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B07-S=6YT;R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R(")%
M;G9I87(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T
M(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)%;G9I861A(&$@<V]L
M:6-I=&'GXV\@9&4@861I8VEO;F%R(%PB)7-<(B!A;R!S:7-T96UA+B!6;V/J
M(&[C;R!P;V1E(&-O;F5C=&%R+2(*(G-E(&%TZ2!Q=64@<W5A('-O;&EC:71A
MY^-O('-E:F$@87!R;W9A9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@
M(E-U8G-C<F5V97(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5C97-S;R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B)R5S)R!A9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B3W,@9&%D;W,@9&\@=7-UX7)I;R`G)7,G
M(&9O<F%M(')E;6]V:61O<R!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<
M(B5S7"(N(@IM<V=S='(@(B<E<R<@97AC;'7M9&\@8V]M('-U8V5S<V\N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(D5X8VQU[61O("<E<R<@9&\@<VES=&5M82!C;VT@<W5C97-S;RXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+B(*;7-G<W1R(")#;VYF:6=U<F'GXV\@<F5V97)T:61A(&-O;2!S
M=6-E<W-O+B!!='5A;&EZ92!P87)A('9E<B!A<R!A;'1E<F'G]65S+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")"86-K=7`@9&$@8V]N9FEG=7)AY^-O('-A
M;'9A(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")/(&)A
M8VMU<"!D;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<R!F;VD@<V%L=F\@
M8V]M('-U8V5S<V\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G
M<W1R("(G)7,G(&%T=6%L:7IA9&\@8V]M('-U8V5S<V\B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`B)7,@9W)A=F%D;R!C;VT@<W5C97-S;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9.-O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M
M;6%R>2(*;7-G<W1R(")297-U;6\B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(D%M86YH96-E<B(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G
M<W1R(")0]'(M9&\M4V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-U;FYY(@IM<V=S='(@(D5N<V]L87)A
M9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED
M(")3=6YR:7-E(@IM<V=S='(@(D%M86YH96-E<B(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B
M4W5N<FES92]3=6YS970B"FUS9W-T<B`B06UA;FAE8V5R+U#T<BUD;RU3;VPB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3
M=6YR:7-E.B`B"FUS9W-T<B`B06UA;FAE8V5R.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B
M4/1R+61O+5-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(E#T<BUD;RU3;VPZ("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G
M:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(E-O8G)E<V-R979E<B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS
M9W-T<B`B4W5P;W)T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE
M(@IM<V=S='(@(E-U<FEN86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4V]B<F5N
M;VUE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-
M87EE;B(*;7-G<W1R(")3=F%L8F%R9"!E($IA;B!-87EE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=6%Z:6SB;F1I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")3=>EC:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4W7M
MYV$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B
M4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(").XV\@97AC;'5I<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R
M(")3>6YC34PB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T
M<B`B17)R;R!D92!S:6YT87AE(&YO<R!T97)M;W,@9&$@<&5S<75I<V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G
M<W1R(")297#Z8FQI8V$@P7)A8F4@9&$@4^UR:6$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2(*
M;7-G<W1R(")496UP97-T861E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM
M<V=S='(@(E1E;7!E<W1A9&5S(&4@5F5N=&%N:6$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,B
M"FUS9W-T<B`B5&5M<&5S=&%D97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS
M9W-T<B`B5&5M<&5S=&%D97,@36%T:6YA:7,B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")!
M<G%U:79O(%135B(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T
M"FUS9VED(")486)L92(*;7-G<W1R(")486)E;&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")4
M86)L92!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!486)E
M;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B5&%B96QA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM
M<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@
M9&$@=&%B96QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N
M(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(E1A:7=A;BP@4')O=NUN8VEA(&1A($-H:6YA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")486II<75I<W3C
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B5&%N>N)N:6$L(%)E</IB;&EC82!D82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G
M:60@(E1A<F=E=#HB"FUS9W-T<B`B06QV;SHB"@HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G
M:60@(E1A<VMS(@IM<V=S='(@(E1A<F5F87,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E
M<B(*;7-G<W1R(").^FUE<F\@9&4@5&5L969O;F4B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B5&5M<&5R871U<F$@<&%R82!A(/IL=&EM82!H;W)A.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`B5&5M<&5R871U<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E
M<F%T=7)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R871U<F$\8G(@+SXH
M)7-!;'1A)7,O)7-"86EX825S*2`F9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B36]D96QO("<E
M<R<@;N-O(&5N8V]N=')A9&\N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D
M;6EN:7-T<F'GXV\@9&4@36]D96QO<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I
M9"`B5&5X="(*;7-G<W1R(")497AT;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")3;VUE;G1E(%1E
M>'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")!;&EN:&%M
M96YT;R!D92!497AT;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B0F]R9&$@
M<W5P97)I;W(@9&\@5&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")1=6DB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B5&AA:2`H5$E3+38R
M,"DB"FUS9W-T<B`B5&%I;&%N9.IS("A425,M-C(P*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A:6SB;F1I82(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!(&5X=&5N<^-O
M($944"!NXV\@97-TX2!D:7-P;V[M=F5L+B(*"B,Z(&9R86UE=V]R:R](:7-T
M;W)Y+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@
M:7,@9&ES86)L960N(@IM<V=S='(@(D\@:&ES=/-R:6-O(&1O('-I<W1E;6$@
M97-TX2!D97-A8FEL:71A9&\N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*
M;7-G<W1R(")!(&5N9VEN92!D92!I;G1E9W)AY^-O($AO<F1E+TMO;&%B(&[C
M;R!S=7!O<G1A(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0
M+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(D\@;&]G($E-4U`@;N-O('!O9&4@
M<V5R(&EN:6-I86QI>F%D;RXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B02!C;&%S<V4@7")-86EN=&5N
M86YC95PB(&[C;R!F;VD@8V%R<F5G861A(&-O;2!S=6-E<W-O(@H*(SH@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(D$@
M:F%N96QA(&1E($]PY_5E<R!F;VD@9F5C:&%D82X@4V%I;F1O+B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R
M871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO
M;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N
M(@IM<V=S='(@(B(*(D\@861M:6YI<W1R861O<B!P<F5C:7-A(&-O;F9I9W5R
M87(@=6T@8V]N96-T;W(@<&5R;6%N96YT92!D92!097)M:7-S]65S('-E("(*
M(G9O8^H@<75E<B!U=&EL:7IA<B!097)M:7-S]65S+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@
M(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(E-O;65N=&4@;R!L861O
M(&1E(&)A:7AO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB3R!N^FUE<F\@
M240@9&\@8V]N=&%T;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@9&5I>&%D;R!E
M;2!B<F%N8V\@;W4@;N-O(&9O:2`B"B)E;F-O;G1R861O(&YO(&)A;F-O(&1E
M(&1A9&]S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3R!C;VYT871O
M(&9O:2!A9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O('-E=2!C873A;&]G;R!D
M92!E;F1E<F7G;W,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92XB"FUS9W-T<B`B(@HB4&%R82!V97)I9FEC87(@82!M96YS86=E;2!A<W-I
M;F%D82#I(&YE8V5S<^%R:6\@=6T@8FQO8V\@<V5P87)A9&\@9&$@(@HB87-S
M:6YA='5R82!01U`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@
M;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB
M3R!)1"!D82!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF
M:6-A9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R`B"B)F;VD@96YC;VYT
M<F%D;R!N;R!B86YC;R!D92!D861O<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(")!(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B07,@9G5NY_5E<R!D92!C<FEP=&]G<F%F:6$@<F5Q
M=65R96T@=6UA(&-O;F5XXV\@=V5B('-E9W5R82XB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D\@87)Q=6EV;R`E<R!D
M979E<FEA(&-O;G1E<B!U;6$@8V]N9FEG=7)AY^-O(&1E("5S+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<P(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(D\@
M87)Q=6EV;R`E<R!D979E<FEA(&-O;G1E<B!A;&=U;6%S(&-O;F9I9W5R8>?U
M97,@9&4@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(V
M"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF
M+B(*;7-G<W1R(")/(&%R<75I=F\@;N-O('!O9&4@<V5R(&-O<&EA9&\@<&%R
M82!E;&4@;65S;6\N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P
M"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B
M3R!A<G%U:79O(&[C;R!C;VYTZ6T@9&%D;W,N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO
M=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@
M;65S<V%G92XB"FUS9W-T<B`B4V5G=65M(&]S(&-A8F7G86QH;W,@9&5S=&$@
M;65N<V%G96TO;65N<V%G96T@<F9C.#(R+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@
M9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@
M(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY
M('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A
M<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T
M;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HBR2!S
M86)I9&\@<75E(&\@;6]D;R!T96QA(&-H96EA(&-A=7-A('!R;V)L96UA<R!C
M;VT@;R!);G1E<FYE="!%>'!L;W)E<BP@96T@(@HB=FER='5D92!D92!B=6=S
M(&1O(&YA=F5G861O<B!Q=64@;O-S(&[C;R!E<W1A;6]S(&%P=&]S(&$@8V]N
M=&]R;F%R+B!6;V/J("(*(G!O9&4@;V)S97)V87(@97)R;W,@9&4@97AI8FGG
MXV\L(&9A;'1A(&1E(&9U;N?U97,@9&\@961I=&]R(&4O;W4@=')A=F%M96YT
M;W,@(@HB86QE873S<FEO<R!D;R!N879E9V%D;W(N(%-E('-E=2!S:7-T96UA
M(.D@5VEN9&]W<R`Y>"#I(&UU:71O('!R;W;A=F5L('%U92`B"B)V;V/J(')E
M8V5B82!U;2!E<G)O(&1E("=&86QH82!'97)A;"!D92!0<F]T9>?C;R<@92!P
M<F5C:7-A<N$@<F5I;FEC:6%R+B!<7&XB"B)<7&X@5F]CZB!F;VD@879I<V%D
M;RX@4&]R(&9A=F]R('!R97-S:6]N92!/2R!S92!V;V/J(&%I;F1A('%U97(@
M=&5N=&%R('5S87(@(@HB;R!E9&ET;W(@9&4@=&5L82!C:&5I82XB"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M02!I9&5N=&ED861E(%PB)7-<(B!F;VD@97AC;'7M9&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I
M9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B4V]M96YT92!O
M(&QA9&\@97-Q=65R9&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@
M8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S
M+B(*;7-G<W1R("(B"B)!(&QO8V%L:7IAY^-O(&1O(&)I;N%R:6\@9&\@1VYU
M4$<@9&5V92!S97(@9F]R;F5C:61A(.`@8VQA<W-E(%PB0W)Y<'1?<&=P7"(N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB
M5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E
M;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(D$@;65N<V%G96T@
M96YV:6%D82!E;2`E<R!P87)A("5S(&-O;2!O(&%S<W5N=&\@7"(E<UPB(&9O
M:2!E>&EB:61A+EQN(@HB27-T;R!NXV\@9V%R86YT92!Q=64@82!M96YS86=E
M;2!F;VD@;&ED82!O=2!E;G1E;F1I9&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@X,0IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(D\@;F]M92!U=&EL
M:7IA9&\@86\@=FEN8W5L87(@82!PX6=I;F$@9&4@8V]M<&]S:>?C;R(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")/(&[Z
M;65R;R!D92!C86UP;W,@9&5V92!S97(@;G5MZ7)I8V\N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+B(*;7-G<W1R(")/(&WS9'5L;R!O<&5N<W-L(.D@;V)R
M:6=A=/-R:6\@<&%R82!A(&-L87-S92!<(DAO<F1E7T-R>7!T7W-M:6UE7"(N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(D$@<')E9F5RZFYC
M:6$@7"(E<UPB(&[C;R!P;V1E('-E<B!S86QV82!P;W)Q=64@<V5U<R!D861O
M<R!E>&-E9&5R86T@;R`B"B)T86UA;FAO(&WA>&EM;R!P97)M:71I9&\B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*(D\@<')O9W)A;6$@=71I;&EZ861O('!A<F$@
M=FES=6%L:7IA<B!E<W1E('1I<&\@9&4@9&%D;R`H)7,I(&[C;R!F;VD@(@HB
M96YC;VYT<F%D;R!N;R!S:7-T96UA+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")/(&-A<F%C=&5R
M92!P87)A(&-I=&'GXV\@9&4@<V5R(&%P96YA<R!U;2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED
M(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(")3;VUE
M;G1E(&]S(&QA9&]S(&1I<F5I=&\@92!E<W%U97)D;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@
M(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")3;VUE;G1E(&\@
M;&%D;R!D:7)E:71O(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(D\@<V5P87)A9&]R(&1E=F4@<V5R('5M(/IN
M:6-O(&-A<F%C=&5R92XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")/('-E<G9I9&]R(%PB)7-<(B!F
M;VD@97AC;'7M9&\N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(D\@<V5R=FED;W(@7"(E<UPB(&9O:2!S
M86QV;RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R(")!('-O;&EC:71AY^-O(&1E(&-A9&%S=')O(&1E("5S
M(&9O:2!E>&-L=>UD82XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!
M(&QI;FAA(&5S<&5C:69I8V%D82`H)60I(&[C;R!E>&ES=&4N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B3R!A<G%U:79O('1E;7!O<N%R:6\@7"(E<UPB(&[C;R!E>&ES
M=&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P.0IM<V=I9"`B
M5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O
M;B!T:&4@<V-R965N+B(*;7-G<W1R(")/('1E>'1O('%U92!V;V/J(&1I9VET
M;W4@;N-O(&-O<G)E<W!O;F1E(&%O('1E>'1O(&YA('1E;&$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM
M<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B
M4V]M96YT92!O<R!L861O<R!D92!C:6UA(&4@9&4@8F%I>&\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS
M9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R(")3;VUE;G1E(&\@;&%D
M;R!D92!C:6UA(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS
M9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"XB"FUS9W-T<B`B3W,@9&%D;W,@96YV:6%D;W,@9F]R86T@
M<&5R9&ED;W,@9&5S9&4@;R!P87-S;R!A;G1E<FEO<BXB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O
M='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"XB"FUS9W-T<B`B3R!A<G%U:79O(&5N=FEA9&\@;N-O('#T
M9&4@<V5R('-A;'9O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B3R!B;&]C;R!<(G=E871H97(N8V]M7"(@;N-O(&5S=.$@9&ES<&]N[79E
M;"XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")/(&1I<F5T\W)I;R!D92!T96UA<R`G)7,G(&[C;R!F;VD@96YC
M;VYT<F%D;RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W
M.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G
M<W1R(").XV\@97AI<W1E;2!O<.?U97,@9&ES<&]N[79E:7,N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB
M"FUS9W-T<B`B3N-O(&5X:7-T96T@<&%R=&5S('%U92!P;W-S86T@<V5R(&5X
M:6)I9&%S(&EN8V]R<&]R861A<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#`U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+B(*;7-G<W1R("(B"B)%>&ES=&5M(&UU:71O<R!C87)A8W1E<F5S
M(&YE<W1E(&-A;7!O+B!6;V/J('!R965N8VAE=2!C;VT@)7,@8V%R86-T97)E
M<SL@(@HB=F]CZB!D979E('!R965N8VAE<B!C;VT@)7,@;W4@;65N;W,N(@H*
M(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@
M=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B2&]U=F4@=6T@<')O8FQE;6$@
M861I8VEO;F%N9&\@)R5S)R!A;R!S:7-T96UA.B`E<R(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;3H@(@IM<V=S='(@(DAO=79E('5M('!R;V)L96UA(&%O(&5X8VQU
M:7(@9&\@<VES=&5M82!O<R!D861O<R!D;R!U<W7A<FEO("<E<R<Z("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(*;7-G<W1R(")(;W5V92!U;2!P<F]B;&5M82!A;R!E>&-L=6ER("<E
M<R<@9&\@<VES=&5M83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@
M7"(E<UPB.B`E<R(*;7-G<W1R(")(;W5V92!U;2!P<F]B;&5M82!A;R!A='5A
M;&EZ87(@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+B(*;7-G<W1R(")(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A
M<G%U:79O.B!.96YH=6T@)7,@9F]I(&5N=FEA9&\N(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3$U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(DAO=79E('5M('!R;V)L
M96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\N($\@)7,@97)A(&UA:6]R('%U
M92!O('1A;6%N:&\@(@HB;>%X:6UO('!E<FUI=&ED;R`H)60@8GET97,I+B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDQ-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A
M9&5D+B(*;7-G<W1R("(B"B)(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I
M;R!D;R!A<G%U:79O+B!/("5S(&9O:2!E;G9I861O('!A<F-I86QM96YT92XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R(")(;W5V92!U;2!E<G)O(&%O(&5X:6)I<B!E
M<W1A('!A<G1E(&1A(&UE;G-A9V5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")(;W5V92!U
M;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S(&1O(&-O;G1A=&\N(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS
M9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!I;7!O<G1A<B!O<R!D861O<R!D;R!I
M0V%L96YD87(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N
M(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE
M;&0N(@IM<V=S='(@(B(*(DAO=79E('5M(&5R<F\@;F\@9F]R;75LX7)I;R!D
M92!C;VYF:6=U<F'GXV\N(%1A;'9E>B!V;V/J(&1E:7AO=2!U;2!C86UP;R`B
M"B)O8G)I9V%T\W)I;R!E;2!B<F%N8V\N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B)(;W5V92!U;2!E<G)O(&%O(&5X96-U=&%R(&$@9G5NY^-O
M(&1E(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!E<W!E8VEF:6-A9&$N("(*(E!O
M<B!F879O<B!T96YT92!N;W9A;65N=&4@;6%I<R!T87)D92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(DAO=79E('5M(&5R<F\@86\@871U86QI>F%R(&]S(&1E=&%L:&5S(&1O(&-O
M;G1A=&\N(%!O<B!F879O<B!T96YT92!N;W9A;65N=&4@(@HB;6%I<R!T87)D
M92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@HB2&]U=F4@=6T@97)R;R!A;R!A='5A;&EZ87(@82!L:7-T
M82!D92!D:7-T<FEB=6GGXV\N(%!O<B!F879O<B!T96YT92`B"B)N;W9A;65N
M=&4@;6%I<R!T87)D92XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D5S=&4@<V5R
M=FED;W(@24U!4"!NXV\@<W5P;W)T82!P87-T87,@8V]M<&%R=&EL:&%D87,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92XB"FUS9W-T<B`B17-T92!NXV\@<&%R96-E('-E<B!U;2!A<G%U
M:79O(')A<B!VX6QI9&\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B17-T92!NXV\@<&%R96-E
M('-E<B!U;2!A<G%U:79O('II<"!VX6QI9&\N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$S-`IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D5S=&4@;N-O('!A
M<F5C92!S97(@=6T@;OIM97)O(&1E(&-A<G3C;R!VX6QI9&\N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"B)%<W1E(&-O;F5C=&]R('!E<FUI=&4@96YV:6%R(&UE;G-A9V5N<R!A=')A
M=NES(&1O($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2DL
M('5T:6QI>F%N9&\@82!!4$D@2%144"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@HB17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!M
M96YS86=E;G,@871R87;I<R!D;R!G871E=V%Y('-M<S)E;6%I;"`H:'1T<#HO
M+R(*(G-M<S)E;6%I;"YC;VTI+"!U=&EL:7IA;F1O(&\@05!)($A45%`B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M
M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*(D5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T
M<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2P@=71I;&EZ86YD;R!O($%022!(5%10(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I
M82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W
M+C$Y,"YI="DN(@IM<V=S='(@(B(*(D5S=&4@8V]N96-T;W(@<&5R;6ET92!E
M;G9I87(@=6UA(&UE;G-A9V5M('9I82!33510(&%T<F%VZ7,@9&\@5F]D869O
M;F4@(@HB271A;&EA;F\L('-O;65N=&4@<&%R82!N^FUE<F]S(%9O9&%F;VYE
M+B#)(&]B<FEG873S<FEO('!O<W-U:7(@=6UA(&-O;G1A(&YO("(*(E9O9&%F
M;VYE($ET86QI86YO("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3$Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34V,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0S"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-C(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.#(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(U"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R
M,`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B17-T
M92!C86UP;R#I(&]B<FEG873S<FEO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-CD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!I;G1E9V5R<RXB"FUS9W-T<B`B17-T92!C86UP;R!P;V1E(&-O;G1E<B!A
M<&5N87,@;OIM97)O<R!I;G1E:7)O<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")%<W1E(&-A;7!O
M('!O9&4@8V]N=&5R(&%P96YA<R!N^FUE<F]S(&4@=NUR9W5L82XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")%<W1E
M(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!V86QO<F5S(&]C=&%I<RXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)%<W1E(&-A;7!O(&1E=F4@<V5R('5M
M82!L:7-T82!D92!N^FUE<F]S(&EN=&5I<F]S('-E<&%R861A('!O<B!V[7)G
M=6QA<R!O=2`B"B)E<W!AYV]S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3DS"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N(@IM<V=S='(@(D5S=&4@8V%M<&\@9&5V92!S97(@=6T@;OIM97)O(';A
M;&ED;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(U"FUS9VED
M("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N
M(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@9&5V92!C;VYT97(@=6T@8_-D:6=O
M(&1E(&-O<B!E;2!F;W)M871O(%)'0B!(97AA+"!P;W(@97AE;7!L;R`B"B(G
M(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38U"FUS
M9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM
M<V=S='(@(D5S=&4@9F]R;75LX7)I;R!JX2!F;VD@<')O8V5S<V%D;RXB"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("))<W1O(.D@)7,N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E
M('9I<VET("5S(@IM<V=S='(@(B(*(D5S=&4@Z2!U;2!O8FIE=&\@2V]L86(@
M1W)O=7!W87)E+B!087)A('9I<W5A;&EZ87(@97-T92!O8FIE=&\@=F]CZB!P
M<F5C:7-A<N$@(@HB9&4@=6T@8VQI96YT92!D92!C;W)R96EO('%U92!E;G1E
M;F1A(&\@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=6UA("(*(FQI
M<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@8V]M(&5S=&%S(&9U;N?U97,@
M<&]R(&9A=F]R('9I<VET92`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@HB17-T82!M96YS86=E;2!F
M;VD@97-C<FET82!E;2!U;2!C;VYJ=6YT;R!D92!C87)A8W1E<F5S("@E<RD@
M<75E(&[C;R#I(&\@(@HB;65S;6\@<75E(&\@<V5U+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B17-T92!N^FUE<F\@9&5V
M92!S97(@<&5L;R!M96YO<R!U;2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T
M('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")%<W1E
M('-E<G9I9&]R(&[C;R!P;V1E(&1E<V-O;7!R:6UI<B!A<G%U:79O<R!Z:7`@
M92!G>FEP+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N(@IM<V=S='(@(D5S=&4@<VES=&5M82!E<W3A(&%T=6%L;65N=&4@
M9&5S871I=F%D;RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G
M<W1R(")%<W1E('9A;&]R(&1E=F4@<V5R('5M(&[Z;65R;RXB"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM
M<V=S='(@(D5S=&$@:F%N96QA(&1E=F4@<V5R(&-H86UA9&$@82!P87)T:7(@
M9&$@:F%N96QA(&1E($]PY_5E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(E)A
M:6\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4
M:6-K971S(@IM<V=S='(@(D)I;&AE=&5S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(E1I;64B"FUS9W-T<B`B2&]R82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B
M06-O;7!A;FAA;65N=&\@9&4@2&]RX7)I;R(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D
M92!H;W)A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S-0IM<V=I
M9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L9>?C;R!D92!H;W)A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM
M;W(@3&5S=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L
M92(*;7-G<W1R(")4[71U;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM
M<V=S='(@(D%S<W5N=&\@*&1I8V$I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(E!A
M<F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C4R"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*
M(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)087)A('-E;&5C:6]N87(@
M;?IL=&EP;&]S(.UT96YS+"!S96=U<F4@82!T96-L82!#;VYT<F]L("A00RD@
M;W4@0V]M;6%N9"`B"B(H36%C*2!A;R!C;&EC87(N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B
M2&]J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")4<F]C
M87(@<&%R82!C\V1I9V\@2%1-3"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O
M9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L
M874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(D%M86YHXR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B5&]P;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M
M92`H7W1O<"DB"FUS9W-T<B`B475A9')O(&1O(%1O<&\@*%]T;W`I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B
M"FUS9W-T<B`B5')A9'7G]65S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I
M;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN9&%D92!E(%1O8F%G;R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R=64@
M;W(@9F%L<V4B"FUS9W-T<B`B5F5R9&%D96ER;R!O=2!F86QS;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@
M(E1U(@IM<V=S='(@(E1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES
M:6$B"FUS9W-T<B`B5'5N[7-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U
M<FME>2(*;7-G<W1R(")4=7)Q=6EA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U
M<F-O("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM
M96YI<W1A;B(*;7-G<W1R(")4=7)C;VUE;FES=.-O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(DEL
M:&%S(%1U<FMS(&4@0V%I8V]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V
M86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R(")0<F5E
M;F-H82!C;VT@<W5A(&5S8V]L:&$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("+-
M;F1I8V4@52Y6+CH@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B
M55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),(&1O('-E
M=2!R96QA=/-R:6\@9&4@<VET=6'GXV\@9&4@96YT<F5G82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E52
M3#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD
M82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A
M:6YE(@IM<V=S='(@(E5C<N)N:6$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B26UP;W-S[79E;"!A8V5S<V%R(&1I<F5T\W)I;R!6
M1E,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS
M9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE
M;B!S:6=N:6YG('5P+B(*;7-G<W1R("));7!O<W/M=F5L(&%D:6-I;VYA<B!I
M;F9O<FUAY_5E<R!E>'1R87,@9&4@=7-UX7)I;R!A;R!R96=I<W1R87(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@86QT97)A<B!P97)M
M:7-SXV\@9&\@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,Y,B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEM<&]S
M<^UV96P@86QT97)A<B!P97)M:7-SXV\@9&\@87)Q=6EV;R!61E,@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B
M26UP;W-S[79E;"!A;'1E<F%R('!A<F$@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S
M<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D;R!A<G%U:79O(&1E(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.34@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#(X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HX-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(DEM
M<&]S<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D;R!A<G%U:79O(&1E(%PB
M)7,O)7-<(BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,Y
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G
M<W1R("));7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R(%-13"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DEM<&]S<^UV96P@8V]N
M96-T87(@=71I;&EZ86YD;R!34TPN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C,R(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S-PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`T(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93
M(&9I;&4N(@IM<V=S='(@(DEM<&]S<^UV96P@8V]P:6%R(&%R<75I=F\@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@8W)I87(@9&ER973S<FEO(%9&
M4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8Q
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W/M=F5L(&-R:6%R
M(&1I<F5T\W)I;R!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS
M9W-T<B`B26UP;W-S[79E;"!C<FEA<B!A<G%U:79O(%9&4RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("));7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S(*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<^UV
M96P@8W)I87(@87)Q=6EV;R!61E,@=F%Z:6\N(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R("));7!O<W/M=F5L(&1E<V-O;7!R:6UI
M<B!D861O<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R."!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(DEM<&]S<^UV96P@97AC;'5I<B!<(B5S
M7"(L(&\@9&ER973S<FEO(&[C;R!E<W3A('9A>FEO+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(DEM<&]S<^UV96P@97AC;'5I<B!<(B5S7"(Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S."!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,Y-0HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B26UP;W-S[79E;"!E>&-L=6ER
M("5S+"!O(&1I<F5T\W)I;R!NXV\@97-TX2!V87II;R(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("));7!O<W/M=F5L(&5X
M8VQU:7(@<F5C=7)S:79A;65N=&4@;R!D:7)E=/-R:6\@5D93+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T-"!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<^UV96P@
M97AC;'5I<B!D:7)E=/-R:6\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#,R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@97AC;'5I<B!D:7)E=/-R
M:6\@5D93.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Q
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!E>&-L=6ER(&%R<75I
M=F\@5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.3$*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU
M:7(@87)Q=6EV;R!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!E>&-L=6ER
M(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@
M97AC;'5I<B!61E,@<F5C=7)S:79A;65N=&4Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#,T"FUS9VED(")5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W/M=F5L(&1E
M=&5R;6EN87(@;R!D:7)E=/-R:6\@871U86PN(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R
M86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B26UP;W-S[79E;"!E
M>'1R86ER(&1E=&%L:&5S(&1O(&-E<G1I9FEC861O(@H*(SH@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEM<&]S<^UV
M96P@8V%R<F5G87(@82!D969I;FGGXV\@9&4@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<T
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N
M86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W/M=F5L(&UO
M=F5R(&\@87)Q=6EV;R!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8U,B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!A8G)I<B!A
M<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C@T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@
M(DEM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!61E,@<&%R82!G<F%V8>?C;RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,R!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB
M"FUS9W-T<B`B26UP;W-S[79E;"!A8G)I<B!A<G%U:79O(%9&4RXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(DEM
M<&]S<^UV96P@86)R:7(@87)Q=6EV;R!C;VUP<FEM:61O+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DEM<&]S<^UV
M96P@;&5R(&%R<75I=F\@5D93("AF:6QE<VEZ92@I(&9A;&AO=2DN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@X-PIM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M26UP;W-S[79E;"!L97(@87)Q=6EV;R!61E,@*&=E=$9I;&53:7IE*"D@9F%L
M:&]U*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z
M("(*;7-G<W1R("));7!O<W/M=F5L(&QE<B!O(&%R<75I=F\Z("(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8W-@IM<V=I9"`B56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W/M
M=F5L(&QE<B!A(')A:7H@9&\@9&ER973S<FEO(%9&4RXB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$Q,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DEM<&]S<^UV96P@<F5N;VUE87(@
M)7,@<&%R82`E<SH@82!P87-T82!D92!D97-T:6YO(&KA(&5X:7-T92(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S
M[79E;"!R96YO;65A<B!O(&1I<F5T\W)I;R!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B26UP
M;W-S[79E;"!R96YO;65A<B!D:7)E=/-R:6\@5D93.B`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(W,2!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!R96YO
M;65A<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-C$W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B26UP;W-S[79E;"!R96YO;65A<B!A<G%U
M:79O(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,R-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(Y,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*
M;7-G<W1R("));7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@
M(DEM<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DEM
M<&]S<^UV96P@=')A9'5Z:7(@97-T92!D;V-U;65N=&\@5V]R9"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@9W)A
M=F%R(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DEM<&]S<^UV96P@9W)A=F%R
M(&%R<75I=F\@5D93("AC;W!Y*"D@9F%L:&]U*2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS
M9W-T<B`B26UP;W-S[79E;"!G<F%V87(@9&%D;W,@9&\@87)Q=6EV;R!61E,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*
M;7-G<W1R("));7!O<W/M=F5L(&=R879A<B!A<G%U:79O(%9&4RP@<75O=&$@
M97AC961E<N$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E-U8FQI;FAA
M9&\B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O
M($-H86YG97,B"FUS9W-T<B`B1&5S9F%Z97(@06QT97)AY_5E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@
M(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D1E<V9A>B!S=6$@
M^FQT:6UA(&'GXV\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")297-P;W-T82!I;F5S<&5R
M861A(&1O('-E<G9I9&]R(&1U<F%N=&4@82!C;VYE>.-O.B`B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")297-P;W-T
M82!I;F5S<&5R861A(&1O('-E<G9I9&]R('!A<F$Z("(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5
M;F9I;&5D(@IM<V=S='(@(E-E;2!C871E9V]R:6$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@
M(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@
M07)A8B!%;6ER871E<R(*;7-G<W1R(")%;6ER861O<R#!<F%B97,@56YI9&]S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R
M(")296EN;R!5;FED;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3
M=&%T97,B"FUS9W-T<B`B17-T861O<R!5;FED;W,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B
M"FUS9W-T<B`B26QH87,@4&5R:6;I<FEC87,@365N;W)E<R!D;W,@17-T861O
M<R!5;FED;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B56YI=',B"FUS9W-T<B`B
M56YI9&%D97,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B1&5S8V]N:&5C:61O(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(F%P:6US9VED
M(&1E<V-O;FAE8VED;R`H05!)($UE<W-A9V4@240I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B
M56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R
M(")C;&EM<V=I9"!D97-C;VYH96-I9&\@*$-L:65N="!-97-S86=E($E$*2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5
M;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").96YH=6UA(&QO
M8V%L:7IAY^-O(&-O;F9I9W5R861A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U
M<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B57-UX7)I;R!O=2!S96YH
M82!D97-C;VYH96-I9&]S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B1&5S=FEN8W5L87(@;R!E;&5M96YT
M;R!A='5A;"(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E-E;2!.;VUE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B
M(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O
M;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII
M;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)38W)I
M<'1S(&[C;R!P<FEV:6QE9VEA9&]S(&[C;R!P;V1E;2!U=&EL:7IA<B!#;W)T
M87(O0V]P:6%R+T-O;&%R('!O<B!R87KU97,@(@HB9&4@<V5G=7)A;N=A+B!#
M;&EQ=64@96T@3TL@<&%R82!V97(@82!N;W1A('3I8VYI8V$@96T@;6]Z:6QL
M82YO<F<@82!Q=6%L("(*(F5N<VEN82!C;VUO('!E<FUI=&ER('-C<FEP=',@
M86-E<W-A<F5M(&$@X7)E82!D92!T<F%N<V9E<NIN8VEA+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G
M:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(D1E<VUA<F-A<B!C;W(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS
M:6]N(@IM<V=S='(@(D5X=&5N<^-O($[C;R!3=7!O<G1A9&$B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%T=6%L
M:7IA<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B5S(&%T
M=6%L:7IA9&\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")!='5A;&EZ87(@=7-U
MX7)I;R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H
M<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("(G)7,G
M(&%T=6%L:7IA9&\N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*
M;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(E-C<FEP
M="!D92!A='5A;&EZ8>?C;R!R96UO=FED;RXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")%;G9I87(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`B(@HB5&]D;W,@87)Q=6EV;W,@9&4@(&-O;F9I9W5R8>?U97,@9&%S(&%P
M;&EC8>?U97,@9F]R86T@96YV:6%D;W,@86\@<V5R=FED;W(N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")!;&9A8F5T
M;R!L871I;F\@96T@;6%I^G-C=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S(')O;6%N;W,@96T@;6%I
M^G-C=6QO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R
M(")5<G5G=6%I(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E
M;G0Z("5S(@IM<V=S='(@(E5T:6QI>F%R($%T=6%L.B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED
M(")5<V4@4U-,(@IM<V=S='(@(E5T:6QI>F%R(%-33"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D
M(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(E5T:6QI
M>F%R('-E(&\@;F]M92]S96YH82#I(&1I9F5R96YT92!N;R!S97)V:61O<B!)
M35-0+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*
M;7-G:60@(E5S97(B"FUS9W-T<B`B57-UX7)I;W,B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T
M<B`B57-UX7)I;R`E<R!NXV\@97-TX2!A=71O<FEZ861O('!A<F$@)7,N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@57-UX7)I;W,B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/
M<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!5<W7A<FEO<R(*"B,Z('-I9VYU
M<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E
M9VES=')O(&1E(%5S=>%R:6]S(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92XB"FUS9W-T<B`B4F5G:7-T<F\@9&4@57-UX7)I;W,@97-TX2!D97-A
M8FEL:71A9&\@;F5S=&4@<VET92XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@
M(D-O;G1A(&1E('5S=>%R:6\@;N-O(&5N8V]N=')A9&$B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")5<W7A<FEO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(E5S=>%R:6\@)R5S)R!JX2!E>&ES=&4N(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS
M9W-T<B`B57-UX7)I;SHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(E5S=>%R:6\Z("(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S
M(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5S=>%R:6]S(&YO('-I<W1E;6$Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R(")5
M>F)E<75I<W3C;R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W
M,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C(*;7-G:60@(E9&4R!D
M:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D\@9&ER973S<FEO
M(%9&4R!NXV\@97AI<W1E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D;I<FEA<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C871I
M;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("),;V-A;&EZ8>?U97,@=N%L
M:61A<R!E;F-O;G1R861A<R!I;F-L=65M.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T
M<B`B5F%L:61A9&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(@IM<V=S='(@(E9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@
M9&4@86=O<F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8P(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM
M<V=S='(@(D\@=F%L;W(@97-TX2!A8VEM82!D;R!T86UA;FAO(&WA>&EM;R!D
M92`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,R,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@
M(E9A;'5E<R(*;7-G<W1R(")686QO<F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$Q,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DP"FUS
M9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L;W)E<R!P
M87)A('-E;&5C:6]N87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U
M(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R(")687)IX79E;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE
M>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M
M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(D9A;&AA(&YA
M('9E<FEF:6-AY^-O("T@97-T82!M96YS86=E;2!P;V1E('1E<B!S:61O(&%D
M=6QT97)A9&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<^-O(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(D-O;G1R;VQE(&1E(%9E<G/C;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@
M(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D%L:6YH86UE;G1O('9E<G1I8V%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")-87)G96T@=F5R
M=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EC86PZ(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G
M:60@(E9E<GD@2&EG:"(*;7-G<W1R(")-=6ET;R!!;'1A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&[C(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E9I971N86UE<V4@*%9)4T-)
M22DB"FUS9W-T<B`B5FEE=&YA;6ET82`H5DE30TE)*2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(@IM<V=S='(@(E9E<B`E<R(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B5FES=6%L:7IA<B!U;6$@<.%G:6YA('=E8B!E>'1E<FYA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L('!H
M<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5FES=6%L:7IA
M<B!C;VUO("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L($)R:71I<V@B"FUS9W-T<B`B26QH87,@5FER9V5N<RP@0G)I=.)N:6-A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N
M(@IM<V=S='(@(DEL:&%S(%9I<F=E;G,L($4N52Y!+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(E9I
M<VEB:6QI9&%D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6:7-I8FEL:61A9&4Z
M("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G
M<W1R(")6;V1A9F]N92!)=&%L:6%N;R!V:6$@4TU44"(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B051%3L?#3R(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G
M<W1R(")!5$5.Q\-/(2$A(%)%34]602!/(%-#4DE05"!-04Y504Q-14Y412!$
M12`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!V:6$@2%14
M4"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM
M<V=S='(@(E=A;&QI<R!E($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(Q(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!
M=&5NY^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B475A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T
M(@IM<V=S='(@(E!R979I<^-O(&1O(%1E;7!O(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I
M9&5D(&)Y(@IM<V=S='(@(D1A9&]S(&1O($-L:6UA(&9O<FYE8VED;R!P;W(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*;7-G:60@(E=E871H
M97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*;7-G
M<W1R(")3:71E(%=E8B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")396UA;F%L
M;65N=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I
M9"`B5V5L8V]M92(*;7-G<W1R(")"96TM=FEN9&\B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R
M(")"96TM=FEN9&\@86\@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE
M+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0F5M+79I;F1O+"`E
M<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")797-T97)N
M("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")/8VED96YT86P@*$E33RTX.#4Y+3$I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@
M*$E33RTX.#4Y+3$U*2(*;7-G<W1R(")/8VED96YT86P@*$E33RTX.#4Y+3$U
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R
M(")386AA<F$@3V-I9&5N=&%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")1=64@87!L
M:6-AY^-O("5S(&1E=F5R:6$@97AI8FER(&%P\W,@82!C;VYE>.-O/R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")1=6%L(&\@8V%R
M86-T97)E(&1E;&EM:71A9&]R/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M(@IM<V=S='(@(E%U86P@;R!C87)A8W1E<F4@9&4@8VET8>?C;S\B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,@IM<V=I
M9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(DUA<&%S($%U<W1R
M86QI86YO<R!7:&5R96ES(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS
M9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B475A:7,@9F%S97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@
M(E%U86ES('!L=6=I;G,@:&%B:6QI=&%R('!A<F$@;R!E9&ET;W(@4FEC:"!4
M97AT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(DQA<F=U<F$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$T"FUS9VED(")7:61T:"!I
M;B!#4U,@=6YI=',B"FUS9W-T<B`B3&%R9W5R82!E;2!U;FED861E<R!#4U,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME
M<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("),87)G=7)A(&1O
M(&UE;G4@)7,@9&\@;&%D;R!E<W%U97)D;R`H=&5RX2!E9F5I=&\@;F$@<'+S
M>&EM82!C;VYE>.-O*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM
M<V=S='(@(DQA<F=U<F$@9&$@=&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B
M"FUS9W-T<B`B56YI9&%D92!D92!,87)G=7)A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*
M;7-G<W1R("),87)G=7)A.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0B"FUS9W-T<B`B5F5N=&\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM
M<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")696YT;W,@<&5L82!M86YHXR(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B5F5L;V-I9&%D92!D;R!V96YT;R!E;2!N\W,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B5VEN9#HB"FUS
M9W-T<B`B5F5N=&\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9E;G1O.B`B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")3
M86)E9&]R:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS
M9VED(")7:7-H;&ES="(*;7-G<W1R("),:7-T82!D92!P961I9&]S(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@
M(E1R86)A;&AO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B16YD97)E
MYV\@0V]M97)C:6%L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")&;VYE
M($-O;65R8VEA;"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y
M,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D[Z;65R;R!I;F-O<G)E
M=&\@9&4@8V%M<&]S(&YA(&QI;FAA("5D+B!%<W!E<F%D;W,@)60L(&5N8V]N
M=')A9&]S("5D+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,S
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D[Z;65R;R!E<G)A
M9&\@9&4@8V%M<&]S+B!%<W!E<F%D;W,@)60L(&5N8V]N=')A9&]S("5D+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$R,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&
M4R!F:6QE+B(*;7-G<W1R(")/9F9S970@)60@:6YC;W)R971O(&%O(&QE<B!O
M(&%R<75I=F\@5D93+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*;7-G<W1R(")297-T<FGG]65S($+A<VEC87,@6#4P
M.78S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*
M;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B571I
M;&EZ8>?C;R!D92!#:&%V92!%>'1E;F1I9&$@6#4P.78S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B3F]M92!!;'1E<FYA
M=&EV;R!D92!!<W-U;G1O(%@U,#EV,R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<B(*;7-G<W1R("))9&5N=&EF:6-A9&]R(&1A($-H879E(&1E
M($%S<W5N=&\@6#4P.78S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@
M(D5X=&5N<_5E<R!8-3`Y=C,B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-30*;7-G:60@(EE965DB"FUS9W-T<B`B04%!
M02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3`Y"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(DUA<&$@66%H;V\A(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM
M<V=I9"`B665A<FQY(@IM<V=S='(@(D%N=6%L;65N=&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")996UE;B(*;7-G<W1R("),ZFUE;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C0*;7-G:60@(EEE<R(*
M;7-G<W1R(")3:6TB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(E-I
M;2P@174@0V]N8V]R9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RXB"FUS9W-T<B`B(@HB5F]CZB!E<W3A(&5M($U/1$\@5$585$\N("!5=&EL
M:7IA(&\@8F]TXV\@6SP^72!P87)A('9O;'1A<B!P87)A(&\@;6]D;R`B"B)7
M65-)5UE'+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S
M='(@(E9O8^H@;N-O(&5S=.$@875T;W)I>F%D;R!A(&-R:6%R(&UA:7,@9&4@
M)60@8FQO8V]S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q
M-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B
M5F]CZB!NXV\@97-TX2!A=71E;G1I8V%D;RXB"@HC.B!F<F%M97=O<FLO261E
M;G1I='DO261E;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E
M('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T
M<B`B5F]CZB!NXV\@<&]D92!T97(@;R!C87)A8W1E<B!<7"!N;R!S974@;F]M
M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-SD*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R
M(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B5F]CZB!NXV\@9F]R
M;F5C974@=6T@96YD97)EYV\@9&4@92UM86EL(';A;&ED;RXB"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E
M9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB
M"FUS9W-T<B`B(@HB5F]CZB!NXV\@;6%P96]U(&YE;FAU;2!C86UP;R!D;R!A
M<G%U:79O(&EM<&]R=&%D;R!A;W,@8V%M<&]S(&-O<G)E<W!O;F1E;G1E<R`B
M"B)E;2`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#<*;7-G
M:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B5F]CZB!F
M;VD@9&5S8V]N96-T861O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L
M;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G
M*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*
M;7-G<W1R("(B"B)6;V/J(&1E=F4@<')E96YC:&5R('5M(&[Z;65R;R!D92!T
M96QE9F]N92!C96QU;&%R(';A;&ED;RP@<V]M96YT92!D[6=I=&]S("(*(F-O
M;2!U;2!O<&-I;VYA;"`G*R<@<&%R82!D:7-C86=E;2!D92!P<F5F:7AO(&EN
M=&5R;F%C:6]N86PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y
M,@IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS
M9W-T<B`B5F]CZB!D979E('!R965N8VAE<B!U;2!V86QO<B!VX6QI9&\N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+B(*;7-G<W1R(")6;V/J(&1E=F4@8V]N9FEG=7)A<B!U;2!C;VYE
M8W1O<B!$871A5')E92!P87)A('5T:6QI>F%R($-A9&%S=')O<RXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E9O8^H@9&5V92!C
M;VYF:6=U<F%R('5M(&-O;F5C=&]R(%9&4RXB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N(@IM<V=S='(@(B(*(E9O8^H@9&5V92!D97-C<F5V97(@;R!P<F]B
M;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R:6\@9&4@<')O8FQE;6$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI
M;FL@<&]I;G1S('1O(@IM<V=S='(@(E9O8^H@9&5V92!F;W)N96-E<B!A(%52
M3"!O;F1E(&\@;&EN:R!A<&]N=&$B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+B(*;7-G<W1R(")6;V/J(&1E=F4@<V5L96-I;VYA<B!U
M;2!S97)V:61O<B!P87)A('-E<B!E>&-L=>UD;RXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N(@IM<V=S='(@(E9O8^H@9&5V92!E<W!E8VEF:6-A<B!U
M;2!U<W7A<FEO('!A<F$@97AC;'5I<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO
M=F4N(@IM<V=S='(@(E9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO
M('!A<F$@<F5M;W9E<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B5F]CZB!D979E
M(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R82!A9&EC:6]N87(N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(E9O8^H@9&5V92!E<W!E
M8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@871U86QI>F%R+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R
M(")6;V/J(&1E=F4@97-P96-I9FEC87(@=6UA(&'GXV\@<&%R82!E>&5C=71A
M<BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")6;V/J(&1E=F4@<')E96YC:&5R('5M(&YO;64@<&%R
M82!A(&YO=F$@8V%T96=O<FEA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T
M;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(E9O
M8^H@<')E8VES82!F;W)N96-E<B!U;2!N^FUE<F\@9&4@=&5L969O;F4@:71A
M;&EA;F\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(E-U82!S97-SXV\@)7,@97AP
M:7)O=2X@4&]R(&9A=F]R+"!C;VYE8W1E+7-E(&YO=F%M96YT92XB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%
M;6%I;"!!9&1R97-S(@IM<V=S='(@(E-E=2!%;F1E<F7G;R!D92!%+6UA:6PB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R
M;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E-E=2!%;F1E<F7G;R!D92!296UE=&5N
M=&4@*$1E.BDZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(E-U87,@26YF;W)M8>?U97,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B
M"B)3974@16YD97)EYV\@9&4@26YT97)N970@;75D;W4@9&5S9&4@;R!I;NUC
M:6\@9&4@<W5A('-E<W/C;R`E<RX@4&%R82`B"B)P<F]T96=E<B!S=6$@<V5G
M=7)A;N=A('9O8^H@9&5V92!C;VYE8W1A<BUS92!N;W9A;65N=&4N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@
M3F%M92(*;7-G<W1R(")3974@3F]M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO
M=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C
M;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A
M=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)3974@8F%C:V5N9"!D92!A=71E
M;G1I8V'GXV\@;N-O('-U<&]R=&$@861IY^-O(&1E('5S=>%R:6]S+"!O=2!A
M(&9U;N?C;R!F;VD@(@HB9&5S86)I;&ET861A('!O<B!A;&=U;6$@;W5T<F$@
M<F%ZXV\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU
M"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S
M='(@(B(*(E-E=2!B86-K96YD(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T
M82!L:7-T86=E;2!D92!U<W7A<FEO<RP@;W4@82!F=6[GXV\@(@HB9F]I(&1E
M<V%B:6QI=&%D82!P;W(@86QG=6UA(&]U=')A(')A>N-O+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(E-E=2!N879E9V%D;W(@<&%R96-E('1E<B!A;'1E<F%D;R!D97-D
M92!O(&EN[6-I;R!D92!S=6$@<V5S<^-O("5S+B!087)A("(*(G!R;W1E9V5R
M('-U82!S96=U<F%NYV$L('9O8^H@9&5V92!C;VYE8W1A<BUS92!N;W9A;65N
M=&4N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T
M<B`B4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&9U;N?C;RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I
M;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM
M<V=S='(@(B(*(E-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@97-T82!O<.?C
M;R!D92!I;7!R97-SXV\N(%!R97-S:6]N92!#;VYT<F]L+T]P=&EO;B`B"B(K
M(%`@<&%R82!I;7!R:6UI<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")3
M974@9G5S;R!H;W+A<FEO(&%T=6%L.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HQ,3$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R(")3=6$@:61E;G1I9&%D92!P861RXV\@9F]I(&%L
M=&5R861A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B4W5A(&ED96YT:61A
M9&4@<&%D<N-O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G
M:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")3974@;F]M92!C;VUP;&5T
M;SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO
M=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(E-U82!C;VYE>.-O(&5X
M<&ER;W4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<R(*;7-G<W1R(")3=6$@;F]V82!S96YH82!P87)A("5S(.DZ("5S(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B4W5A<R!O<.?U97,@9F]R86T@
M871U86QI>F%D87,@<&]R(&-A=7-A(&1A(&1U<F'GXV\@9&5S=&$@<V5S<^-O
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED
M(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(E-U
M87,@;W#G]65S(&9O<F%M(&%T=6%L:7IA9&%S+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T(@IM<V=S='(@(E-U82!N;W9A('-E;FAA(&9O:2!G97)A9&$B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S
M='(@(B(*(E-U82!N;W9A('-E;FAA(&9O:2!G97)A9&$L('9E<FEF:7%U92!S
M974@92UM86EL(&4@8V]N96-T92US92!C;VT@<W5A(&YO=F$@(@HB<V5N:&$N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R
M('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")3=6$@<V5N:&$@97AP
M:7)O=2XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G
M:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E-E=7,@<V5R=FED
M;W)E<R!R96UO=&]S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU
M9V]S;&%V:6$B"FUS9W-T<B`B275G;W-LX79I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA
M:7)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EKB
M;6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@
M(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED
M(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E
M(%%U;W1E9"!497AT72(*;7-G<W1R(");3V-U;'1A<B!497AT;R!#:71A9&]=
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M
M(%)E<&]R=%TB"FUS9W-T<B`B6U)E;&%T\W)I;R!D92!0<F]B;&5M85TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");17AI8FER(%1E>'1O
M($-I=&%D;R`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");17AI8FER
M(%1E>'1O($-I=&%D;R`M("5S(&QI;FAA<UTB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E
M<R!O9B`E<UTB"FUS9W-T<B`B6VQI;FAA("5S(&1E("5S72(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,34T-2!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D
M;6EN:7-T<F'GXV\B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB
M"FUS9W-T<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A
M=&%4<F5E(@IM<V=S='(@(D1A=&%?5')E92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B15]X8VQU:7(@0V]L=6YA(@H*(SH@;&EB+V%P
M:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P;W,B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?
M2&5L<"(*;7-G<W1R(")!7VIU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!?26UA9V5M
M+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM
M<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?0V]N96-T87(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*
M;7-G<W1R(")?1&5S8V]N96-T87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@
M3&EN:RXN+B(*;7-G<W1R(")!7VQT97)A<B!,:6YK+BXN(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B
M"FUS9W-T<B`B7T]PY_5E<R(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B
M7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]097)M:7-S]65S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS
M9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7U)E;6]V97(@3&EN:RXN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@
M(D-O;F9I9W5R85]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@7U1A8F5L82XN+B(*"B,Z
M(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]5<W7A
M<FEO<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(P"FUS9VED
M(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B8V%TX6QO9V\@9&4@96YD97)EYV]S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G
M:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(F-A=.%L;V=O(&1E(&5N
M9&5R9>=O<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$R"FUS
M9VED(")C86QE;F1A<B(*;7-G<W1R(")A9V5N9&$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(F-A;&UO(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B:6UP;W-S[79E;"!C<FEA<B!A
M<G%U:79O(&1E(&1E<W1I;F\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T
M<B`B:6UP;W-S[79E;"!A8G)I<B!A(&]R:6=E;2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I9"`B8VQI8VL@:&5R92(*
M;7-G<W1R(")C;&EQ=64@87%U:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(B"FUS9W-T<B`B97)R;R!D92!S:6YT87AE(&1A(&QI;FAA(&1E(&-O;6%N
M9&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM
M<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")E<G)O(&1E(&-O
M;F9I9W5R8>?C;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM
M<V=S='(@(G5M(&%R<75I=F\@8W+M=&EC;R!D;R!S:7-T96UA(&5S=.$@9F%L
M=&%N9&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R
M-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B97)R;R!N;R!F
M;W)M871O(&1O<R!D861O<R(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI
M;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B961I=&%R(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO
M="!F;W5N9"(*;7-G<W1R(")R96=I<W1R;R!NXV\@96YC;VYT<F%D;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED
M(")F86QL:6YG(@IM<V=S='(@(G%U961A(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#@Q"FUS9VED(")F:6QE(@IM<V=S='(@(F%R<75I
M=F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T
M87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@
M(F$@<&%R=&ER(&1E("5S("@E<RD@X"`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B
M8G)I<V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C0X"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-3<*;7-G:60@(FAH(@IM<V=S
M='(@(FAH(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(FYO;64@9&\@
M:&]S="#I(&1E<V-O;FAE8VED;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E
M(@IM<V=S='(@(FEM961I871O(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G
M<W1R(")I;F-O<G!O<F%D;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T
M<B`B97)R;R!D92!E;G1R861A+W-A[61A(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E
M(&5R<F]R(@IM<V=S='(@(F5R<F\@:6YT97)N;R!D;R!P<F]G<F%M82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED
M(")L:6YE<UTB"FUS9W-T<B`B;&EN:&%S72(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B8_-D:6=O(&1E(&5R<F\@)60@9&\@;6MI<V]F<R!E
M;G%U86YT;R!G97)A=F$@82!)4T\N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,V.`IM<V=I9"`B;6TB"FUS9W-T<B`B;6TB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X-2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS9W-T<B`B;F]M92(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE
M;G1E9"(*;7-G<W1R(")NXV\@:6UP;&5M96YT861O(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(F[C;R!I;7!L96UE;G1A9&\@86EN9&$B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-`IM<V=I9"`B;F]T97!A
M9"(*;7-G<W1R(")B;&]C;R!D92!N;W1A<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E
M;G0B"FUS9W-T<B`B<&]R8V5N=&%G96TB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B
M"FUS9W-T<B`B4&5R;6ES<^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S
M='(@(G!I>&5L<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T
M<B`B97)R;R!R96UO=&\@;F\@<')O=&]C;VQO(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G)I<VEN9R(*;7-G
M<W1R(")N87-C96YT92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@
M(G-E<G9IYV\@:6YD:7-P;V[M=F5L(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B97AI
M8FER(&1I9F5R96[G87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10
M(@IM<V=S='(@(G-M<S)E;6%I;"!V:6$@2%144"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S
M='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S,*;7-G:60@(G-T96%D>2(*;7-G<W1R(")E<W3A=F5L(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E
M;2!E<G)O<B(*;7-G<W1R(")E<G)O(&1E('-I<W1E;6$B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR.`IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S
M='(@(FQI<W1A(&1E('1A<F5F87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS
M9W-T<B`B9F%L:&$@=&5M<&]RX7)I82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B<')E
M96YC:&$@<W5A('-E;FAA(&1U87,@=F5Z97,@<&%R82!C;VYF:7)M87(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H
M<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U;FEF:6-A9&\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D
M(@IM<V=S='(@(G-E;2!N;VUE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C
M="(*;7-G<W1R(")S96QEY^-O(&1E('5S=>%R:6\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM
M<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(T,`IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB
M"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]P=%]0
M5"YP;P``````````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P-S(P-3(P`#$P-#$W,S8S,#`S`#`Q-C0R,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C($AO<F1E(%!O<G1U9V%L
M(%!O<G1U9W5E<V4@=')A;G-L871I;VXN"B,@36%N=65L($UE;F5Z97,@9&4@
M4V5Q=65I<F$@/$UA;G5E;"Y397%U96ER83XL(#(P,#4N"B,@0F%S960@;VX@
M82!P<F5V:6]U<R!T<F%N<VQA=&EO;B!B>2!.=6YO($QO=7)E:7)O(#QN=6YO
M0&5T:"YP=#XL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T
M+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,2TR-"`P,3HQ."LP,#`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`R+3`Q+3(Q(#$X.C(R+3`P,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N<'0^7&XB"B),86YG=6%G92U4
M96%M.B!0;W)T=6=A;"!0;W)T=6=U97-E(#QD979`;&ES=',N:&]R9&4N;W)G
M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#D*;7-G:60@(B(*(B`@+4TL("TM;65S<V%G93U-15-304=%("!5<V4@=&AI
M<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N97,N
M(@IM<V=S='(@(B(*(B`@+4TL("TM;65S<V%G93U-14Y304=%32!5<V%R(&5S
M=&$@;65N<V%G96T@9&4@8V]M971I;65N=&\@96T@=F5Z(&1A7&XB"B(@("`@
M("`@("`@("`@("`@("`@("`@("`@;65N<V%G96T@<&]R(&]M:7-SXV\N(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C4S"FUS9VED("(B"B(@("UA+"`M+6%D
M9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE('1O('1H92!C;VUP96YD
M:75M+B!5<V5F=6P@=&]<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@(&EN
M8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F97)E;G0@8G)A;F-H('1O
M7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V5N97)A=&5D(&-O
M;7!E;F1I=6TN(@IM<V=S='(@(B(*(B`@+6$L("TM861D/4%2455)5D\@("`@
M($%D:6-I;VYA<B!E<W1E(&%R<75I=F\@4$\@86\@8V]M<.IN9&EO+B!5=&EL
M('!A<F%<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU:7(@=6T@
M8V]M<.IN9&EO(&1E('5M(')A;6\@9&EF97)E;G1E(&YO7&XB"B(@("`@("`@
M("`@("`@("`@("`@("`@("!C;VUPZFYD:6\@9V5R861O+B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,3,*;7-G:60@(B(*(B`@+6(L("TM8F%S93TO4$%4
M2"`@1G5L;"!P871H('1O('1H92`H2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H
M870@<VAO=6QD(&)E7&XB"B(@("`@("`@("`@("`@("`@("`@('5S960N(@IM
M<V=S='(@(B`@+6(L("TM8F%S93TO0T%-22`@0V%M:6YH;R!P87)A(&\@9&ER
M96-T\W)I;R!B87-E("A(;W)D92D@82!U<V%R+B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HV.0IM<V=I9"`B(@HB("`M8RP@+2UC;VUP96YD:75M/49)3$4@
M($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI<R!C;VUP96YD:75M(&9I
M;&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F('1H
M92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&5<;B(*(B`@("`@
M("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U!4E%5("!);G1E9W)A<B!N;W9A
M<R!T<F%D=>?U97,@82!E<W1E(&%R<75I=F\@9&4@(@HB8V]M<.IN9&EO7&XB
M"B(@("`@("`@("`@("`@("`@("`@("`@("`@92!NXV\@86\@8V]M<.IN9&EO
M('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O(&YA7&XB"B(@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%S=&$@:&]R9&4O<&\N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C8S('!O+W1R86YS;&%T:6]N+G!H<#HX,2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#<*;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U&24Q%
M("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T:&4@9&5F
M875L=%QN(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M<&5N
M9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2XB"FUS9W-T<B`B
M(@HB("`M8RP@+2UC;VUP96YD:75M/4%2454@(%5S87(@97-T92!A<G%U:79O
M(&1E(&-O;7#J;F1I;R!E;2!V97H@9&\@87)Q=6EV;UQN(@HB("`@("`@("`@
M("`@("`@("`@("`@("`@('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O(&YA
M('!A<W1A(&AO<F1E+W!O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,30*
M;7-G:60@(B`@+60L("TM9&5B=6<@("`@("`@4VAO=R!E<G)O<B!M97-S86=E
M<R!F<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RXB"FUS9W-T<B`B("`M9"P@
M+2UD96)U9R`@("`@("!-;W-T<F%R(&UE;G-A9V5N<R!D92!E<G)O(&1O<R!B
M:6[A<FEO<R!E>&5C=71A9&]S+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU
M-`IM<V=I9"`B("`M9"P@+2UD:7)E8W1O<GD]1$E2("`@0W)E871E(&-O;7!E
M;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN(@IM<V=S='(@(B`@+60L("TM9&ER
M96-T;W)Y/5!!4U1!($-R:6%R('5M(&-O;7#J;F1I;R!N97-T82!P87-T82XB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U"FUS9VED("(@("UH+"`M+6AE
M;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N(@IM<V=S='(@(B`@
M+6@L("TM:&5L<"`@("`@("`@36]S=')A<B!E<W1A(&UE;G-A9V5M(&1E(&%J
M=61A+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C<@<&\O=')A;G-L871I;VXN<&AP.C<U"FUS9VED("(@("UL+"`M
M+6QO8V%L93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N(@IM<V=S
M='(@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V%R(&%P96YA<R!E<W1A
M(&QO8V%L:7IAY^-O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-C$@<&\O=')A;G-L871I;VXN<&AP.C<Y"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HX-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?
M0T,@("`@(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T<B`B("`M;"P@+2UL;V-A
M;&4];&Q?0T,@("`@(%5S87(@97-T82!L;V-A;&EZ8>?C;RXB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-34*;7-G:60@(B`@+6PL("TM;&]C86QE/6QL7T-#
M("`@(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T<B`B("`M;"P@+2UL;V-A;&4]
M;&Q?0T,@("`@57-A<B!E<W1A(&QO8V%L:7IAY^-O+B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HV.`IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($)U:6QD($U/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#;VYS=')U
M:7(@87)Q=6EV;W,@34\@87!E;F%S('!A<F$@97-T92!M\V1U;&]<;B(*(B`@
M("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HT,PIM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($QI;7!A
M<B!A<G%U:79O<R!03R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;UQN(@HB("`@
M("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C0X"FUS9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@0V]M;6ET('1R86YS;&%T:6]N<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@
M;6]D=6QE+B(*;7-G<W1R("(B"B(@("UM+"`M+6UO9'5L93U-TT153$\@("`@
M0V]M971E<B!A<R!T<F%D=>?U97,@87!E;F%S('!A<F$@97-T92!M\V1U;&]<
M;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HV,@IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I
M(&UO9'5L92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@
M($-R:6%R(&\@87)Q=6EV;R!03R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;UQN
M(@HB("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C@P"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@365R9V4@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO
M9'5L92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($EN
M=&5G<F%R(&%R<75I=F]S(%!/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO7&XB
M"B(@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2XB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S8*;7-G:60@(B(*(B`@+6TL("TM;6]D=6QE/4U/
M1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+B(*;7-G<W1R("(B"B(@("UM+"`M+6UO9'5L93U-TT153$\@
M("`@06-T=6%L:7IA<B!A<G%U:79O<R!D92!A:G5D82!A<&5N87,@<&%R82!E
M<W1E7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@;?-D=6QO("A(;W)D
M92DN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V"FUS9VED("(@("UM+"`M
M+6UO9'5L93U-3T153$4@("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO
M9'5L92XB"FUS9W-T<B`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($%C='5A
M;&EZ87(@87!E;F%S(&5S=&4@;?-D=6QO("A(;W)D92DN(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C4X"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@
M($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U
M;&4N(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!'97)A
M<B!A<F-H:79O(%!/5"!A<&5N87,@<&%R82!E<W1E(&WS9'5L;UQN(@HB("`@
M("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C<P"FUS9VED("(B"B(@("UN+"`M+6YO+6-O;7!E;F1I=6T@
M("`@1&]N)W0@;65R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N
M9&EU;2XB"FUS9W-T<B`B("`M;BP@+2UN;RUC;VUP96YD:75M("`@($[C;R!I
M;G1E9W)A<B!N;W9A<R!T<F%D=>?U97,@;F\@8V]M<.IN9&EO+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HV-"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(@<&\O
M=')A;G-L871I;VXN<&AP.C@X"FUS9VED("(@("UN+"`M+6YO+6-O;7!E;F1I
M=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2XB"FUS9W-T<B`B("`M;BP@
M+2UN;RUC;VUP96YD:75M("`@($[C;R!U<V%R('5M(&-O;7#J;F1I;RXB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$*;7-G:60@(B`@+7,L("TM<W1A=&ES
M=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T871I<W1I8W,@:6X@82!L
M;V-A;"!F:6QE+B(*;7-G<W1R("(B"B(@("US+"`M+7-T871I<W1I8W,@("`@
M("`@1W5A<F1A<B!E<W1A=.US=&EC87,@9&4@=')A9'7GXV\@;G5M(&9I8VAE
M:7)O(&QO8V%L+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38*;7-G:60@
M(B`@+70L("TM=&5S="`@("`@("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N
M9',@8G5T(&1O;B=T(')U;B!A;GET:&EN9RXB"FUS9W-T<B`B("`M="P@+2UT
M97-T("`@("`@("!-;W-T<F%R(&]S('!R;V=R86UA<R!A(&5X96-U=&%R(&UA
M<R!NXV\@;R!F87IE<BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`U"FUS
M9VED("(B"B(@(&-L96%N=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@
M9G)O;2!U;G1R86YS;&%T960@86YD(&]B<V]L971E(&5N=')I97,N(@IM<V=S
M='(@(B(*(B`@8VQE86YU<"`@("`@3&EM<&%R(&]F(&%R<75I=F]S(%!/(&1E
M(&5N=')A9&%S('!O<B!T<F%D=7II<B!O=2!O8G-O;&5T87,N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P.`IM<V=I9"`B("!C;VUM:70@("`@("!#;VUM
M:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R=F5R+B(*;7-G<W1R("(@
M(&-O;6UI="`@("`@($-O;65T97(@87,@=')A9'7G]65S(&YO('-E<G9I9&]R
M($-64RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y"FUS9VED("(@(&-O
M;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#5E,@<V5R=F5R
M+B(*;7-G<W1R("(@(&-O;6UI="UH96QP($-O;65T97(@87)Q=6EV;W,@9&4@
M86IU9&$@;F\@<V5R=FED;W(@0U93+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HY.0IM<V=I9"`B(@HB("!C;VUP96YD:75M("!296)U:6QD('1H92!C;VUP
M96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E<G=R:71E<R!T:&5<;B(*
M(B`@("`@("`@("`@("`@8W5R<F5N="!C;VUP96YD:75M+B(*;7-G<W1R("(B
M"B(@(&-O;7!E;F1I=6T@(%)E8V]N<W1R=6ER(&\@87)Q=6EV;R!D92!C;VUP
MZFYD:6\N($%T96[GXV\Z($\@;F]V;R!A<G%U:79O7&XB"B(@("`@("`@("`@
M("`@('-O8G)E</5E+7-E(&%O(&%N=&EG;RXB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`P"FUS9VED("(@(&5X=')A8W0@("`@($=E;F5R871E(%!/('1E
M;7!L871E("@N<&]T*2!F:6QE<RXB"FUS9W-T<B`B("!E>'1R86-T("`@("!'
M97)A<B!A<G%U:79O<R!M;V1E;&\@4$\@*"YP;W0I+B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HY.`IM<V=I9"`B("!H96QP("`@("`@("!3:&]W('1H:7,@
M:&5L<"!M97-S86=E+B(*;7-G<W1R("(@(&AE;'`@("`@("`@($UO<W1R87(@
M97-T82!M96YS86=E;2!D92!A:G5D82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3`Q"FUS9VED("(B"B(@(&EN:70@("`@("`@($-R96%T92!O;F4@;W(@
M;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG.B!4:&ES
M7&XB"B(@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG(%!/
M(&9I;&5S(&]F('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"B(@(&EN:70@("`@
M("`@($-R:6%R('5M(&]U(&UA:7,@87)Q=6EV;W,@4$\@<&%R82!U;6$@;F]V
M82!L;V-A;&EZ8>?C;RY<;B(*(B`@("`@("`@("`@("`@071E;N?C;SH@3W,@
M;F]V;W,@87)Q=6EV;W,@<V]P<F5P]65M+7-E(&%O<R!A;G1I9V]S+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8*;7-G:60@(B`@;6%K92`@("`@("`@
M0G5I;&0@8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!03R!F
M:6QE<RXB"FUS9W-T<B`B(@HB("!M86ME("`@("`@("!#;VYS=')U:7(@87)Q
M=6EV;W,@8FENX7)I;W,@34\@82!P87)T:7(@9&]S(&%R<75I=F]S7&XB"B(@
M("`@("`@("`@("`@(%!/(&5S<&5C:69I8V%D;W,N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P-PIM<V=I9"`B(@HB("!M86ME+6AE;'`@("!-87)K(&%L
M;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F:6QE(&)E:6YG('5P+71O+61A
M=&4@86YD7&XB"B(@("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I;&4@9F]R
M('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U7&XB"B(@
M("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@049415(@
M=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H95QN(@HB("`@("`@("`@("`@
M("!H96QP(&9I;&4N(@IM<V=S='(@(B(*(B`@;6%K92UH96QP("`@36%R8V%R
M('1O9&%S(&%S(&5N=')A9&%S(&YO(&%R<75I=F\@6$U,(&1E(&%J=61A(&-O
M;6\@97-T86YD;UQN(@HB("`@("`@("`@("`@("!A8W1U86QI>F%D87,@92!P
M<F5P87)A<B!O(&%R<75I=F\@<&%R82!A('!R\WAI;6$@97AE8W7GXV]<;B(*
M(B`@("`@("`@("`@("`@9&4@=7!D871E+6AE;'`N($1E=F4M<V4@97AE8W5T
M87(@;6%K92UH96QP($1%4$])4R!D95QN(@HB("`@("`@("`@("`@("!U<&1A
M=&4M:&5L<"!E(&1E(')E=F5R(&\@87)Q=6EV;R!D92!A:G5D82XB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3`R"FUS9VED("(B"B(@(&UE<F=E("`@("`@
M($UE<F=E('1H92!C=7)R96YT(%!/(&9I;&4@=VET:"!T:&4@8W5R<F5N="!0
M3R!T96UP;&%T92!F:6QE+B(*;7-G<W1R("(B"B(@(&UE<F=E("`@("`@($EN
M=&5G<F%R(&\@87)Q=6EV;R!03R!C;W)R96YT92!C;VT@;R!A<G%U:79O(&UO
M9&5L;R!03R`B"B)C;W)R96YT92XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`S"FUS9VED("(@('5P9&%T92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G
M92!S97%U96YT+B(*;7-G<W1R("(@('5P9&%T92`@("`@($5X96-U=&%R(&5X
M=')A8W0@92!M97)G92!E;2!S97%UZFYC:6$N(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P-`IM<V=I9"`B(@HB("!U<&1A=&4M:&5L<"!%>'1R86-T(&%L
M;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H(%A-
M3"!H96QP7&XB"B(@("`@("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@
M=VET:"!T:&4@97AI<W1I;F<@;VYE<RXB"FUS9W-T<B`B(@HB("!U<&1A=&4M
M:&5L<"!%>'1R86ER('1O9&%S(&%S(&5N=')A9&%S(&YO=F%S(&4@;6]D:69I
M8V%D87,@9&\@87)Q=6EV;R!D95QN(@HB("`@("`@("`@("`@("!A:G5D82!8
M34P@96T@:6YG;.IS(&4@:6YT96=RX2UL87,@8V]M(&%S(&5X:7-T96YT92XB
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B(*;7-G<W1R("(B"B(@)B,Q-3$[("5S(&5S=.$@<')O;G1O('!A
M<F$@969E8W1U87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\@;6%R8V%D
M87,@(@HB86)A:7AO+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S8X"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H
M)7,@9&EA<R!A='+A<RDB"@HC.B!L:6(O2&]R9&4N<&AP.C$R-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H0VAA
M=F4@9&4@86-E<W-O("5S*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<V
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B
M("AD96YT<F\@9&4@)7,@9&EA<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,W,@IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AH;VIE*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S<T"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G
M<W1R("(@*&%M86YHXRDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,`IM
M<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H;VYT96TI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.34*;7-G:60@(B!A="`B"FUS9W-T<B`B(&-O;2`B"@HC.B!L:6(O2&]R
M9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&[C;R#I('5M
M82!E<V-O;&AA(';A;&ED82XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C4U-"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.CDS-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@;N-O(&5S=.$@8V]N9FEG=7)A
M9&\@;F\@4F5G:7-T;R!D;R!(;W)D92XB"@HC.B!L:6(O2&]R9&4O5')E92YP
M:'`Z,38T"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB(')E<')E<V5N=&%D;W(@
M9&4@X7)V;W)E(&[C;R!E;F-O;G1R861O+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&9O:2!A9&EC
M:6]N861O(&%O('-I<W1E;6$@9&4@9W)U<&]S+B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B<@9F]I(&%D:6-I;VYA9&\@86\@<VES=&5M82!D92!P97)M:7-S
M]65S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@
M;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S7"(@;N-O(&9O:2!C<FEA
M9&\Z("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D
M("5S(&4@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$W-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!B>71E<R!W<FET=&5N+B(*;7-G<W1R("(E9"!B
M>71E<R!E<V-R:71O<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C@T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S
M('5P+71O+61A=&4B"FUS9W-T<B`B)60@9&4@)60@96YT<F%D82!M87)C861A
M<R!C;VUO(&%C='5A;&EZ861A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C
M87-T(@IM<V=S='(@(G!R979I<^-O(&1E("5D(&1I87,B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;F]T:6-E7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($YO=&EF:6-AY^-O
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C,R"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B5S($%D;6EN:7-T<F'GXV\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*
M;7-G<W1R("(E<R!);7!R97-SXV\@1&EG:71A;"(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX,S`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C@S,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E
M<R!+0B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI
M;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S($]P97)AY_5E<R!D
M92!-86YU=&5NY^-O("T@0V]N9FER;6'GXV\B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)A<B`E
M<R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@4W5B<V-R979E
M<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN
M8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N
M="(*;7-G<W1R("(E<R!497)M;W,@9&\@06-O<F1O(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C4V."!L:6(O5D93+V9T<"YP:'`Z-C,V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!JX2!E>&ES
M=&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@96T@
M)7,@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,C@W('!O+W1R86YS;&%T
M:6]N+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@;F]T('=R
M:71A8FQE+B(*;7-G<W1R(")NXV\@<V4@<&]D92!E<V-R979E<B!E;2`E<RXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R#I(&]B<FEG873S<FEO
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&]S(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3,U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(B5S(&[C;R!F;VD@96YC;VYT<F%D;RXB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-3@U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F
M;W5N9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T)R!F:7)S="XB"FUS9W-T
M<B`B)7,@;N-O(&9O:2!E;F-O;G1R861O+B!%>&5C=71A<B`G=')A;G-L871I
M;VX@97AT<F%C="<@<')I;65I<F\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O
M9B`E<R(*;7-G<W1R("(E<R!A("5S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B0V]N=&%C=&]S(&1E("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HX.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE
M;F1A<B(*;7-G<W1R(")#86QE;F3A<FEO(&1E("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HX-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E
M<&%D(@IM<V=S='(@(DYO=&%S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HX.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*
M;7-G<W1R(")487)E9F%S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4S(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.3@*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!C;VT@<F%J861A
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E
M<R(*;7-G<W1R("(L(&-O;2!R86IA9&%S("5S("5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L
M92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:>%V96P@9&4@)7,@82`E
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#<P(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3(Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HV.#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!E<V-O;&AA
M("TM(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,C@@<&\O=')A;G-L871I
M;VXN<&AP.C$S,S`*;7-G:60@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2(*;7-G<W1R("(M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM
M<V=S='(@(D9O<FUA=&\@9&4@,3(@:&]R87,@*$%-+U!-*2(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T
M<B`B1F]R;6%T;R!D92`R-"!H;W)A<R(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!H;W)A<R(*
M"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U
M<R(*;7-G<W1R("(\06YT97)I;W(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(CQG971T97AT/B!T86<@;F]T
M(&-L;W-E9"!I;B!F:6QE("5S+EQN(@HB3W!E;FEN9R!T86<@9F]U;F0@:6X@
M;&EN92`E9"XB"FUS9W-T<B`B(@HB971I<75E=&$@/&=E='1E>'0^('!O<B!F
M96-H87(@;F\@9FEC:&5I<F\@)7,N7&XB"B)!8G)I;F1O(&$@971I<75E=&$@
M96YC;VYT<F%D82!N82!L:6YH82`E9"XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D
M(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")%<W1E(&)L;V-O(&5X:6=E('5M
M(&UE8V%N:7-M;R!U<V%N9&\@8F%S97,@9&4@9&%D;W,N(@H*(SH@;&EB+TAO
M<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D
M(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!F871A;"(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.CDR,`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BR2!N
M96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%!'4"!P87)A(&5N8W)I<'1A
M<B!A(&UE;G-A9V5M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q
M-#4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(LD@;F5C97-SX7)I
M82!U;6$@8VAA=F4@</IB;&EC82!01U`@<&%R82!V97)I9FEC87(@82!A<W-I
M;F%T=7)A(&1E('5M82`B"B)M96YS86=E;2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$P-S<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)087)A(&1E8VEF
M<F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z
M8FQI8V$@4$=0+"!U;6$@8VAA=F4@(@HB<')I=F%D82!01U`@92!U;6$@9G)A
M<V4M<&%S<V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3DU"FUS
M9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G
M92XB"FUS9W-T<B`B(@HB4&%R82!A<W-I;F%R('5M82!M96YS86=E;2!SXV\@
M;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4$=0+"!U;6$@8VAA=F4@
M(@HB<')I=F%D82!01U`@92!U;6$@9G)A<V4M<&%S<V4N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("(B"B)087)A(&1E8VEF<F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I
M87,@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@(@HB8VAA=F4@<')I
M=F%D82!3+TU)344@92!U;6$@9G)A<V4M<&%S<V4N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)0
M87)A(&%S<VEN87(@=6UA(&UE;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@
M8VAA=F4@</IB;&EC82!3+TU)344L('5M82`B"B)C:&%V92!P<FEV861A(%,O
M34E-12!E('5M82!F<F%S92UP87-S92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+)(&YE8V5S
M<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%('!A<F$@96YC<FEP=&%R
M('5M82!M96YS86=E;2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B3OIV96YS
M(&1E(&UA;FCC(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B0VAU=FES
M8V]S(&1E($UA;FCC(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B0VAU=F$@9&4@
M;6%N:.,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")!9W5A8V5I<F]S(&1E
M(&UA;FCC(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(").97;U97,@
M9&4@;6%N:.,B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%0
M22!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D%C97)C
M82!D97-T92!E9&ET;W(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B06-E<F-A+BXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(D)A<V5S(&%L:6YH861A<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R(")#96YT<F]S(&%L:6YH861O<R(*"B,Z(&QI8B]6
M1E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")!8V5S<V\@;F5G861O(&%O(&-R
M:6%R('!A<W1A(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(D%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q=6EV;R!61E,N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D
M(@IM<V=S='(@(E!A;&%V<F$M4&%S<V4@9&$@0V]N=&$B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F
M<F]Z96XN(@IM<V=S='(@(D-O;G1A(&-O;F=E;&%D82XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S$W"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S
M='(@(D-O;G1A8FEL:61A9&4B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-30@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,S(*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]A9&0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C$V"FUS9VED(")!9&0B"FUS9W-T<B`B061I8VEO;F%R(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HR,30@861M:6XO9W)O=7!S+G!H<#HR,34*
M;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")!9&EC:6]N87(@1W)U
M<&\@1FEL:&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@T(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.#4*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S
M:6]N(@IM<V=S='(@(D%D:6-I;VYA<B!097)M:7-SXV\@1FEL:&$B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM
M<V=S='(@(D%C<F5S8V5N=&%R($%Q=6DZ(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,#@@861M:6XO9W)O=7!S+G!H<#HR,#D*;7-G:60@(D%D9"!.97<@1W)O
M=7`B"FUS9W-T<B`B061D:6-I;VYA<B!.;W9O($=R=7!O(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HW,R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<T
M"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B061I8VEO;F%R
M($YO=F$@4&5R;6ES<^-O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B061I8VEO;F%R('5M(&=R=7!O
M(&9I;&AO(&$@7"(E<UPB(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C4S(&QI8B](;W)D92]097)M<R]522YP:'`Z,3,Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S
M='(@(D%D:6-I;VYA<B!U;6$@<&5R;6ES<^-O(&9I;&AA(&$@7"(E<UPB(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*
M;7-G<W1R(")!9&EC:6]N87(@;F]V;R!U=&EL:7IA9&]R.B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(D%D9"!C
M;VQU;6XB"FUS9W-T<B`B061I8VEO;F%R(&-O;'5N82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S4*;7-G:60@(D%D9"!N97<@;65M
M8F5R<R(*;7-G<W1R(")!9&EC:6]N87(@;F]V;W,@;65M8G)O<R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")!9&0@<&%I<B(*
M;7-G<W1R(")!9&EC:6]N87(@<&%R8V5I<F\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4Y"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")!9&EC:6]N87(@
M;R!-96YU("5S(&-O;6\@0F%R<F$@3&%T97)A;"!-;WII;&QA(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O
M(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B061I8VEO;F%R(&%O<R!#;VYT86-T
M;W,Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM
M<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!9&EC:6]N
M87(@86]S(&UE=7,@8V]N=&%C=&]S(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*
M;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D%D:6-I;VYA<B!U=&EL:7IA9&]R
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS
M9W-T<B`B(@HB061I8VEO;F5I(%PB)7-<(B!A;R!S:7-T96UA+"!M87,@;N-O
M('!U9&4@861I8VEO;F%R(&EN9F]R;6'GXV\@9&4@<W5B<V-R:>?C;R`B"B)A
M9&EC:6]N86PZ("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB"FUS9W-T<B`B061I8VEO;F5I(%PB)7-<(B!A;R!S:7-T
M96UA+B!*X2!P;V1E(&5N=')A<BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.38R"FUS9VED(")!9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ(@IM
M<V=S='(@(D%D:6-I;VYA;F1O(&YO=F]S(&%R<75I=F]S(&%O(')E<&]S:73S
M<FEO.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHT"FUS
M9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(D$@861I
MY^-O(&1E('5T:6QI>F%D;W)E<R!E<W3A(&1E<V%C=&EV861A+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#0S(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!"
M;V]K(@IM<V=S='(@(D-O;G1A8W1O<R(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<W1R87(@
M+2!A=')I8G5I<B!P97)M:7-S]65S(&$@;W5T<F]S('5T:6QI>F%D;W)E<R(*
M"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI
M;FES=')AY^-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Y,@IM
M<V=I9"`B061S(@IM<V=S='(@(D%N^FYC:6]S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T
M86XB"FUS9W-T<B`B069E9V%N:7-TXV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S
M='(@(D%L8N)N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%R9^EL:6$B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I
M9"`B06QI87,B"FUS9W-T<B`B06QC=6YH82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N
M(@IM<V=S='(@(D%L:6YH87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(D%L:6YH86UE;G1O.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(E1U9&\B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,3@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B
M06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B5&]D;W,@;W,@571I
M;&EZ861O<F5S($%U=&5N=&EC861O<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,S,@861M:6XO9W)O=7!S+G!H<#HR,3(*;7-G:60@(D%L;"!'<F]U<',B"FUS
M9W-T<B`B5&]D;W,@;W,@1W)U<&]S(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C,X(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<*;7-G:60@(D%L
M;"!097)M:7-S:6]N<R(*;7-G<W1R(")4;V1A<R!A<R!097)M:7-S]65S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B5&]D;W,@;W,@
M*'%U871R;RD@;&%D;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,@IM
M<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E!E<FUI
M=&ER(&WZ;'1I<&QO<R!E;F1E<F7G;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3(V"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/R(*;7-G<W1R(")097)M:71I<B!A=')I8G5IY^-O(&1O('1I<&\@
M9&4@;&ES=&%S(&]R9&5N861A<S\B"@HC.B!L:6(O2&]R9&4O1&%T851R964O
M<W%L+G!H<#HT,#@*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DKA
M(&5X:7-T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@
M(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D5N=')A9&$@24U34"!!
M;'1E<FYA=&EV82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(E!A;&%V<F$M
M4&%S<V4@24U34"!!;'1E<FYA=&EV82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S
M='(@(DYO;64@9&4@571I;&EZ861O<B!)35-0($%L=&5R;F%T:79O(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T
M92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O(&EN=N%L:61O(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T
M96UP;&%T97,B"FUS9W-T<B`B36]D96QO<R!A;'1E<FYA=&EV;W,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")497AT;R!A
M;'1E<FYA=&EV;SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R(")3
M86UO82!!;65R:6-A;F$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.CDU
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D9O:2!E<W!E8VEF:6-A
M9&\@=6T@=F%L;W(@:6YVX6QI9&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U-`IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C
M=7)E9"XB"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&1E<V-O;FAE8VED;RXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U
M"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O
M;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B
M06YG=6EL82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I
M9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D5N=')E<&]S=&\@*'!R;WAY
M*2!!;O-N:6UO(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*
M;7-G:60@(D%N<W=E<B(*;7-G<W1R(")297-P;W-T82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R
M8W1I8V$B"FUS9W-T<B`B06YTX7)C=&EC;R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD
M($)A<F)U9&$B"FUS9W-T<B`B06YT[6=U82!E($)A<F)U9&$B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O
M2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P
M;&EC8>?C;R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,SD*;7-G:60@
M(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!<&QI8V'GXV\@<')O
M;G1A+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED
M(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B07!L:6-A<B!A(%!A
M<G1I;&AA<R!&:6QH87,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")!<')O=F%R(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@S,`IM<V=I9"`B07!P
M<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")486UA;FAO($%P<F]X:6UA9&\B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`B06)R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM
M<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%RX6)I8V\@
M*%=I;F1O=W,M,3(U-BDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV
M92!&:6QE(%-I>F4B"FUS9W-T<B`B5&%M86YH;R!D;R!&:6-H96ER;R!D92!!
M<G%U:79O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*
M;7-G<W1R(").;VUE(&1O($%R<75I=F\B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B5&5M(&$@8V5R=&5Z82!Q=64@<75E
M<B!R96UO=F5R(&\@<&5D:61O(&1E('-U8G-C<FGGXV\@<&%R82`E<R`_(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T
M92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")496T@82!C
M97)T97IA('%U92!Q=65R(')E;6]V97(@7"(E<UPB(&4@<75A:7-Q=65R('-U
M8BUG<G5P;W,_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)MZ6YI82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX
M*2(*;7-G<W1R(")!<FWI;FEO("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B07)T92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(DEL
M:&$@9&4@07-C96YSXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*
M;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<G1E($%30TE)(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!2
M96=I;VXB"FUS9W-T<B`B4F5G:>-O(,%S:6$O4&%C[69I8V\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#$W"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS
M9W-T<B`B4&5D:7(@8V]N9FER;6'GXV\@86YT97,@9&4@<F5A;&EZ87(@;W!E
M<F'G]65S(&1E(&UA;G5T96[GXV\_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,3(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")#;VQU
M;F%S(&1E(&%T<FEB=6GGXV\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<U"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB
M"FUS9W-T<B`B5&5N=&%T:79A(&1E(')E;6_GXV\@9&4@=6T@9W)U<&\@:6YE
M>&ES=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HS.`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B5&5N=&%T:79A(&1E(')E;6_GXV\@9&4@=6UA('!E<FUI
M<W/C;R!I;F5X:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HY
M.`IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(E1E;G1A=&EV82!D92!E9&GGXV\@9&4@=6UA('!E
M<FUI<W/C;R!I;F5X:7-T96YT92XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92XB"FUS9W-T<B`B5&5N=&%T:79A(&1E(&5D:>?C;R!D92!U;6$@
M<&%R=&EL:&$@:6YE>&ES=&5N=&4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@
M(D%T=')I8G5T97,B"FUS9W-T<B`B071R:6)U=&]S(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!
M9V]S=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S='+A;&EA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B075S=')I82(*;7-G<W1R("+!=7-T<FEA(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M8WER<W%L.B!!(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82!NXV\@9F]I(&5N
M8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM
M<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!/(&UE8V%N
M:7-M;R!NXV\@=&5M(&%S(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]C>7)U<SH@02!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@;N-O
M(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z
M,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB
M9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($$@97AT96YSXV\@
M1E10(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B!#;VUP:6QE(&\@
M4$A0(&-O;2!A("(*(F]PY^-O("TM96YA8FQE+69T<"XB"@HC.B!L:6(O2&]R
M9&4O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA
M<#H@02!E>'1E;G/C;R!)34%0(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R
M861A+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]K<F(U.B!!(&5X=&5N<^-O(&MR8C4@;F5C97-SX7)I
M82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z-3@*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($$@97AT96YS
MXV\@3$1!4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82XB"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"B)!=71H7VQD87`Z
M($EM<&]S<^UV96P@861I8VEO;F%R('5T:6QI>F%D;W(@)7,N($5I<R!O('%U
M92!O('-E<G9I9&]R(&1I<W-E.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!);7!O
M<W/M=F5L(')E;6]V97(@;R!U=&EL:7IA9&]R("5S(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?
M;&1A<#H@26UP;W-S[79E;"!A8W1U86QI>F%R(&\@=71I;&EZ861O<B`E<R(*
M"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]M8V%L.B!!(&5X=&5N<^-O($U#04P@;F5C97-SX7)I82!NXV\@
M9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HV
M,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@02!E>'1E
M;G/C;R!S;6)A=71H(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B02!A=71E;G1I8V'G
MXV\@9F%L:&]U(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS
M9W-T<B`B02!A=71E;G1I8V'GXV\@9F%L:&]U+B`E<R(*"B,Z(&QI8B](;W)D
M92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!(&%U=&5N=&EC
M8>?C;R!F;VD@<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$2553+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HW-C@*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!(&%U=&5N=&EC8>?C;R!N
M;R!S97)V:61O<B!&5%`@9F%L:&]U+B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z.#,*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@
M(D-A;7!O<R!D:7-P;V[M=F5I<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S
M='(@(D%Z97)B86EJXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*
M;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")$97-C=6QP87,@7")"3T9(
M7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D9U;F1O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM
M<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")#;W(@9&\@1G5N9&\B
M"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME
M<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")086QA=G)A+5!A<W-E(&ME<F)E
M<F]S(&5R<F%D82XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM
M<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").;VUE(&1E
M(%5T:6QI>F%D;W(@:V5R8F5R;W,@97)R861O+B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B
M"FUS9W-T<B`B0F%A;6%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"87+I
M;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@
M*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"X6QT:6-O("A)4T\M.#@U.2TQ,RDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L861E8VAE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A
M<V5L:6YE(@IM<V=S='(@(DQI;FAA(&)A<V4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM
M<V=S='(@(D)I96QO<G+Z<W-I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B
M0NEL9VEC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"96YI;B(*;7-G<W1R(")"96YI;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T
M<B`B0F5R;75D82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")"=73C;R(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")"
M:7)T:&1A>2(*;7-G<W1R(")!;FEV97)SX7)I;R(*"B,Z(&QI8B](;W)D92]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D\@8FQO8V\@7"(E<UPB(&1A(&%P;&EC8>?C;R!<(B5S7"(@
M;N-O(&9O:2!E;F-O;G1R861O+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0V]N
M9FEG=7)AY_5E<R!D92!";&]C;W,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5&EP;R!D
M92!";&]C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(").96=R:71O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F]L:79I82(*;7-G<W1R(")";VSM=FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(DUA<F-A
M9&]R97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B0F]R9&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS
M9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")%<W!E<W-U<F$@9&$@
M8F]R9&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")";W)D87,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D+S<VYI
M82U(97)Z96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM
M<V=I9"`B0F]T:"(*;7-G<W1R(")!;6)A<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(D)O='-U86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B
M0F%S92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B26QH82!";W5V
M970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")497)R:73S
M<FEO($)R:73B;FEC;R!D;R!/8V5A;F\@S6YD:6-O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I
M($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D)U
M:6QD:6YG($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B0V]N
M<W1R=6EN9&\@87)Q=6EV;W,@34\@<&%R82!O(&WS9'5L;R`E<RXN+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HV-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0G5I;&1I;F<@;&]C86QE("5S+BXN("(*;7-G<W1R(")#;VYS=')U:6YD;R!L
M;V-A;&EZ8>?C;R`E<RXN+B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"
M=6QGX7)I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B3&ES="!)
M=&5M:7IA9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R<75I
M;F$@1F%S;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R^FYD:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#,*;7-G:60@(D--4R(*;7-G
M<W1R(")#35,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<R(*;7-G<W1R(")0;VYT;W,@9&4@1&ES=')I8G5IY^-O($-23"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE
M9&%D97,@9&$H<RD@0^E?;'5L82AS*2XN+B(*"B,@8RUF;W)M870*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,`IM<V=I9"`B0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B26YI8VEA;&EZ8>?C;R!D
M82!<(F-A8VAE7"(@;N-O(&9O:2!C;VYC;'7M9&$N(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,30X"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")#86QE;F3A
M<FEO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-`IM<V=I
M9"`B0V%L;2(*;7-G<W1R(")#86QM;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G
M<W1R(")#86UB;V1J82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(D-A;6%R
M]65S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@
M(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D[C;R!P;W-S;R!R
M96EN:6-I87(@82!P86QA=G)A+7!A<W-E(&%U=&]M871I8V%M96YT92P@8V]N
M=&%C=&4@;R!S974@(@HB861M:6YI<W1R861O<B!D92!S:7-T96UA<RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI8B](;W)D92]!=71H
M+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DEM<&]S<^UV96P@
M8V]N96-T87(@86\@<V5R=FED;W(@24U!4#H@)7,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B
M"FUS9W-T<B`B0V%N863A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN
M+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ-PHC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$W"FUS9VED(")#86YC
M96PB"FUS9W-T<B`B0V%N8V5L87(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(D-A;F-E;&%R(%)E;&%T\W)I;R!D92!0<F]B;&5M87,B"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(D[C;R!C;VYS:6=O(')E
M;6]V97(@;R!F:6-H96ER;R!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED
M(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@
M(D[C;R!C;VYS:6=O(&5N8V]N=')A<B!U;2!D:7)E8W3S<FEO('1E;7!O<N%R
M:6\N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM
M<V=S='(@(DEM<&]S<^UV96P@8V]N=&EN=6%R('-E;2!O('!A<N)M971R;R`G
M=&%R9V5T1FEL92<N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(U,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%PB
M)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$Q,B!L:6(O2&]R
M9&4O1&%T851R964O<W%L+G!H<#HU.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DEM
M<&]S<^UV96P@<F5M;W9E<BP@97AI<W1E;2`E9"!F:6QH;W,N(@H*(SH@;&EB
M+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3$R"FUS9VED("(B"B)#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B
M(@HB3N-O(.D@<&]S<^UV96P@<F5O<F1E;F%R.B!O(&[Z;65R;R!D92!E;G1R
M861A<R!F;W)N96-I9&%S(&[C;R!C;W)R97-P;VYD92!A;R`B"B)N^FUE<F\@
M9W5A<F1A9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@96YC86UI;FAA
M<B!A(&UE;G-A9V5M('!A<F$@;R!N^FUE<F\@:6YD:6-A9&\N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0V%P92!697)D92(*;7-G<W1R(")297#Z8FQI8V$@9&4@0V%B;R!697)D92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B3&5G96YD82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@
M3&%B96QS(@IM<V=S='(@(D-A=&5G;W)I87,@92!#;W)E<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#
M87EM86X@27-L86YD<R(*;7-G<W1R("));&AA<R!#86EMXV\B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0
M:&]N92(*;7-G<W1R(")496QE9F]N92!#96QU;&%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B
M0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D87,@0^EL
M=6QA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(D5N8VAI;65N
M=&\@9&%S($/I;'5L87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S
M(@IM<V=S='(@(E!R;W!R:65D861E<R!D87,@8^EL=6QA<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#
M96QL('-P86-I;F<Z(@IM<V=S='(@(D5S<&'G86UE;G1O(&1A<R!CZ6QU;&%S
M.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO
M;F4B"FUS9W-T<B`B5&5L96WS=F5L(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(D/I
M;'1I8V\@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G
M<W1R(")#96YT<F%R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(E)E</IB;&EC82!#96YT<F\@069R:6-A;F$B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BDB"FUS9W-T<B`B175R;W!A($-E;G1R86P@*$E33RTX.#4Y
M+3(I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@
M(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B4&]R;65N;W)E<R!D;R!#
M97)T:69I8V%D;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$Q
M"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")$;VYO(&1O($-E
M<G1I9FEC861O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*
M;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E!O;.UT:6-A
M<R!D92!#97)T:69I8V%D;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")297#Z
M8FQI8V$@9&\@0VAA9&4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDW"FUS9VED(")#
M:&%N9V4B"FUS9W-T<B`B06QT97)A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(D%L=&5R92!O(&YO;64@92!E
M;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!V97+C;R!Q=6%N9&\@;&5R96T@92!R
M97-P;VYD97)E;2#@<R`B"B)S=6%S(&UE;G-A9V5N<RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED
M(")#:&%R(@IM<V=S='(@(D-A<F%C=&5R92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE
M8U]K($QI;FLN+BXB"FUS9W-T<B`B5F5R:5]F:6-A<B!,:6=AY^-O+BXN(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,PIM
M<V=I9"`B0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B36%R<75E
M(&%S(&]P97)AY_5E<R!Q=64@9&5S96IA(&5X96-U=&%R(&YE<W1E(&UO;65N
M=&\N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B4F5P^F)L:6-A(&1O($-H:6QE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B4F5P^F)L:6-A(%!O<'5L87(@9&$@
M0VAI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(D-H:6[J<R!3:6UP
M;&EF:6-A9&]S("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@
M(D-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2DB"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`B17-C;VQH82!A('!A;&%V<F$M<&%S<V4B"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B
M"FUS9W-T<B`B17-C;VQH82!U;2!.;VUE(&1E(%5T:6QI>F%D;W(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDP"FUS9VED(")#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(D5S8V]L:&$@8V]M;R!M;W-T<F%R
M(&%S(&1A=&%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")%<V-O;&AA(&\@
M97-T:6QO(&1A<R!L:7-T82`H<&%R82!L:7-T87,@;W)D96YA9&%S*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B26QH82!D;R!.871A;"(*
M"B,Z(&QI8B]61E,N<&AP.C8Q-2!L:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O
M=6YD+B(*;7-G<W1R(").XV\@9F]I(&5N8V]N=')A9&$@82!D969I;FGGXV\@
M9&$@8VQA<W-E("5S+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQE86YI;F<@=7`@4$\@9FEL97,@9F]R(&UO
M9'5L92`E<RXN+B(*;7-G<W1R("),:6UP86YD;R!O<R!A<G%U:79O<R!03R!D
M;R!M\V1U;&\@)7,N+BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L96%N:6YG('5P(&QO8V%L92`E<RXN+B`B
M"FUS9W-T<B`B3&EM<&%N9&\@82!L;V-A;&EZ8>?C;R`E<RXN+B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B
M0VQE87(B"FUS9W-T<B`B3&EM<&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R("),:6UP87(@971I<75E=&%S(&1O($U33V9F:6-E(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(DQI;7!A
M<B!D861O<R!D;R!U=&EL:7IA9&]R.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ-@IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R
M("),:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B
M"FUS9W-T<B`B3&EM<&%R(&1A9&]S(&1O('5T:6QI>F%D;W(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE
M87)I;F<@3&%T92(*;7-G<W1R("),:6UP82!487)D92(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]N;W1I8V5?8F]T=&]M+FEN8SHV"FUS9VED(")#;&EC
M:R!T;R!#;VYT:6YU92(*;7-G<W1R(")#;&EQ=64@<&%R82!#;VYT:6YU87(B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I
M9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('9I
M82!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS
M9W-T<B`B1F5C:&%R(&IA;F5L82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3OIV96YS(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D
M<R!%87)L>2(*;7-G<W1R(").^G9E;G,@36%T:6YA:7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y
M(@IM<V=S='(@(D5N979O861O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES
M;&%N9',B"FUS9W-T<B`B26QH87,@0V]C;W,@*$ME96QI;F<I(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHT"FUS9VED(")#;VQL87!S92!3
M:61E8F%R(@IM<V=S='(@(D-O;&%P<V%R($)A<G)A($QA=&5R86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X
M"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")";W)D87,@0V]L
M87!S861A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(E)E</IB;&EC82!D
M82!#;VST;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")#
M;W)E<R(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HR.3D@
M;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,P,`HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#<R('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-3$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-3(*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-CD*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#8*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G
M<W1R(")086QE=&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@T-0IM<V=I
M9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")396QE8^?C;R!D92!C;W)E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")#;VQU;F%S.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.30W"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S
M='(@(E3M='5L;W,@9&%S(&-O;'5N87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B0D0B"@HC.B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B
M0V]M86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R(")#;VYS;VQA(&1E($-O;6%N9&]S(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C,X"FUS9VED(")#;VUM86YD(&]P=&EO;G,Z
M(@IM<V=S='(@(D]PY_5E<R!D;R!C;VUA;F1O.B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HY-PIM<V=I9"`B0V]M;6%N9',Z(@IM<V=S='(@(D-O;6%N9&]S
M.B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,@IM<V=I9"`B0V]M
M;65N="(*;7-G<W1R(")#;VUE;G3A<FEO(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P,#`*;7-G:60@(D-O;6UI='1I;F<Z(@IM<V=S='(@(D-O;65T96YD
M;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#
M;VUM;VX@3F%M92(*;7-G<W1R(").;VUE($-O;75M(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R
M;W,B"FUS9W-T<B`B0V]M;W)O<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D5M<')E
M<V$B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HX,2!L
M:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!L:6(O2&]R
M9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY-R!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]M
M<&]S92!-97-S86=E("@E<RDB"FUS9W-T<B`B17-C<F5V97(@*"5S*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM
M<V=S='(@(D-O;7!U=&%D;W)E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#4*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")#;VYD:>?C
M;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I
M;VYS(@IM<V=S='(@(D-O;F1IY_5E<R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(D1I9F5R96[G87,@9&4@0V]N9FEG=7)AY^-O(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92XB"FUS9W-T<B`B02!C;VYF:6=U<F'GXV\@97-TX2!D97-A8W1U
M86QI>F%D82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HY.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B0V]N9FEG=7)A
M<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S<*
M;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0V]N9FER;64@82!0
M86QA=G)A+5!A<W-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B4F5P^F)L:6-A
M($1E;6]C<N%T:6-A(&1O($-O;F=O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")297#Z8FQI8V$@1&5M
M;V-RX71I8V$@9&\@0V]N9V\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")#;VYE>.-O
M(&9A;&AO=2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B0V]N97CC;R!F86QH;W4Z
M("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<W.0IM<V=I9"`B0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G
M<W1R(")#;VYE>.-O(&%O('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<R!R
M96-U<V%D82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B0V]N
M97CC;R!A;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,@<F5C=7-A9&$N
M(%)A>N-O.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V,@IM<V=I
M9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M0V]N97CC;R!A;R!S97)V:61O<B!&5%`@<F5C=7-A9&$N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(D-O;G1A8W1O<R!A9&EC:6]N861O<R!C;VT@<W5C97-S;R!A
M;R!S974@;&EV<F\@9&4@96YD97)EYV]S+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M
M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B5&EP;R!D92!C;VYT9?ID;R!D;R!A
M<G%U:79O(&-O;7!R:6UI9&\Z("(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")#;VYT
M9?ID;R!D92`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y
M"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")#;VYT:6YU87(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;V]K($ES;&%N9',B"FUS9W-T<B`B26QH87,@0V]O:R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(D)O;&EN
M:&\@8VAI;NIS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EA
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(D-O<&EA<B!S96QE
M8^?C;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O<'EI;F<@)7,@=&\@)7,B"FUS9W-T<B`B0V]P:6%N9&\@
M9&4@)7,@<&%R82`E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B4F5P
M^F)L:6-A(&1A($-O<W1A(%)I8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM
M<V=S='(@(E)E</IB;&EC82!D82!#;W-T82!D;R!-87)F:6TB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-38*;7-G:60@(D-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5N
M8W)I<'1A<B!A(&UE;G-A9V5M(&-O;2!01U`N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3`S,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A(&UE
M;G-A9V5M(&-O;2!01U`N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5N8W)I<&%R(&$@;65N<V%G
M96T@8V]M(%,O34E-12XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O
M;2!3+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A
M8W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@861I8VEO;F%R(&\@
M8V]N=&%C=&\N("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3$P
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B1F%L:&$@;F$@;&EG8>?C;R`H8FEN9"D@86\@<V5R=FED;W(@3$1!4"XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L('9E<FEF:6-A<B!O('-A;&1O+B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@
M)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V
M:61O<B!<(B5S7"(@=7-A;F1O($944#H@)7,B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]P
M>2`E<R!T;R`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-O<&EA<B`E
M<R!P87)A("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&-R:6%R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-C@Q('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<W"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@;&]C86QE(&1I<F5C
M=&]R>2!F;W(@;&]C86QE("5S.B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&-R:6%R('!A<W1A(&1E(&QO8V%L:7IAY^-O('!A<F$@82!L;V-A;&EZ8>?C
M;R`E<SHB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3`U"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!D97-E;F-R:7!T87(@;W,@9&%D;W,@8V]M(&\@4$=0+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!D97-E;F-R:7!T87(@;W,@9&%D;W,@8V]M(%,O34E-12XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&-O;G1A8W1O+B`E<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@7")S8W)I<'1<(B!D92!A8W1U86QI
M>F'GXV\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS.`IM<V=I9"`B0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@9&5T97)M:6YA<B!O(&5N
M9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@9&\@(@HB9&5S=&EN873A
M<FEO+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@;R!L:79R;R!D92!E
M;F1E<F7G;W,@8V]M<&QE=&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&-O;7!L971A+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I
M;VX@;&ES=',N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!L
M:7-T82!C;VUP;&5T82!D87,@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RXB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G
M>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@8V%R<F5G87(@97-T<F%T
MZ6=I82!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S
M<^UV96P@;6MD:7(@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C<P.`IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E
M;"!O8G1E<B!A(&-H879E('#Z8FQI8V$@82!P87)T:7(@9&\@<V5R=FED;W(@
M9&4@8VAA=F5S("(*(G#Z8FQI8V%S+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@7"(E<UPB('!A<F$@97-C
M<FET82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&%B<FER("5S+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N
M86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@86)R:7(@;R!M\V1U;&\@9&4@36%N=71E;N?C;R!D92!4
M87)E9F%S("5S(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!A8G)I<B!P87-T82!<(B5S7"(N(@H*(SH@;&EB+U9&4R]/8FIE
M8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A
M9"`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!L97(@)7,N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).XV\@
M9F]I('!O<W/M=F5L(')E:6YI8VEA<B!A('!A;&%V<F$M<&%S<V4@9&\@=71I
M;&EZ861O<B!I;F1I8V%D;RX@06QG=6T@;W4@(@HB=&]D;W,@;W,@<&]R;65N
M;W)E<R!NXV\@97-T879A;2!C;W)R96-T;W,N(%!O<B!F879O<B!T96YT92!D
M92!N;W9O(&]U("(*(F-O;G1A8W1E(&\@<V5U(&%D;6EN:7-T<F%D;W(@9&4@
M<VES=&5M87,@<V4@<')E8VES87(@9&4@;6%I<R!A:G5D82XB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@S"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!!0TPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@;V)T97(@;&EV<F\@9&4@96YD97)EYV]S+B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&]B=&5R(&%S(&-O;7!E=.IN8VEA<R!D;R!S97)V:61O<B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E
M<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R
M979E<G1E<B!A(&-O;F9I9W5R8>?C;RXB"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("));7!O
M<W/M=F5L(')M9&ER(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&=U
M87)D87(@82!C;VYF:6=U<F'GXV\@9&4@)7,N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R8>?C;R!D
M92!S86QV86=U87)D82XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&=U
M87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R9&$Z("5S(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&\@7")S
M8W)I<'1<(B!D92!A8W1U86QI>F'GXV\@96TZ(%PB)7-<(BXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U
M<F'GXV\@9&4@<V%L=F%G=6%R9&$@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+B(*;7-G<W1R("(B"B).XV\@9F]I('!O<W/M=F5L(&=U87)D87(@;R!A
M<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX@4&]D92!U<V%R('5M82!D87,@
M(@HB;W#G]65S('!A<F$@9W5A<F1A<B!O(&/S9&EG;R!E;2`E<R!O=2!C;W!I
M87(@;6%N=6%L;65N=&4@;R!C\V1I9V\@86)A:7AO("(*(G!A<F$@)7,N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(P"FUS9VED(")#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!P<F]C=7)A<B!N;R!S97)V:61O<B!,1$%0+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*
M;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&1E<VQI9V%R(%PB)7-<(BXB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8W1U86QI>F%R(&-O;G1A8W1O+B`E
M<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8W1U86QI
M>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(&5S8W)E=F5R(&$@8V]N9FEG=7)AY^-O('!A
M<F$@7"(E<UPB.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3@*
M;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*(D[C;R!E
M;F-O;G1R96D@82!"87)R82!,871E<F%L(&1O($UO>FEL;&$N($%S<V5G=7)E
M+7-E('%U92!A(&)A<G)A(&QA=&5R86P@(@HB97-TX2!A8F5R=&$N(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F
M;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!A=')I8G5I<B!A;R!U=&EL:7IA
M9&]R(%PB)7-<(B!O<R!S96=U:6YT97,@9&ER96ET;W,@<V]B<F4@82`B"B)P
M87-T82!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C$*
M;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")497AT;R!#;VYT861O(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT
M<GDB"FUS9W-T<B`B4&'M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-S`*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B0W5R<V]S(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0W)I87(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G
M:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0W)I87(@=6UA(&QI9V'GXV\B
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS
M9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D-R:6%R('5M82!N;W9A
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED
M(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B0W)I87(@<W5B+7!A<W1A
M<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(Q-`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G
M<W1R(")097)M:7-S]65S(&1O($-R:6%D;W(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S(R.0IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@
M(D[Z;65R;R!D;R!C87)TXV\@9&4@8W+I9&ET;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA
M(@IM<V=S='(@(E)E</IB;&EC82!D82!#<F_A8VEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*
M;7-G<W1R(")297#Z8FQI8V$@9&4@0W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")1=6%T
M<F\@9F%S97,@8V]R<F5N=&5S(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@
M;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS
M9W-T<B`B1&%T82](;W)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")#=7)R96YT(%523"!I
M<R(*;7-G<W1R(")54DP@8V]R<F5N=&4@Z2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")%<W1A
M9&\@9&\@5&5M<&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C8S"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(E-I='5A
MY^-O(&%C='5A;#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")%
M<W1I;&\@86-T=6%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!E<G-O;F%L:7IA<B!A<R!T87)E
M9F%S('%U92!S97+C;R!E>&5C=71A9&%S(&%Q=6%N9&\@;R!L;V=I;B!N;R`E
M<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")#;W)T87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED
M(")#=70@<V5L96-T:6]N(@IM<V=S='(@(D-O<G1A<B!A('-E;&5CY^-O(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0WEP<G5S(@IM<V=S='(@(E)E</IB;&EC82!D92!#:&EP<F4B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/
M23@M4BDB"FUS9W-T<B`B0VER[6QI8V\@*$M/23@M4BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2DB"FUS9W-T<B`B0VER[6QI8V\@*%=I;F1O=W,M,3(U-BDB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I(@IM<V=S='(@(D-I<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82!#
M:&5C82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,C,@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@
M(D1$(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B
M1&%I;'DB"FUS9W-T<B`B1&EA<FEA;65N=&4B"@HC.B!A9&UI;B]D871A=')E
M92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B3F%V
M96=A9&]R(&1E(,%R=F]R92!D92!$861O<R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,SDX(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R
M"FUS9VED(")$871E(@IM<V=S='(@(D1A=&$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*
M;7-G<W1R(")$871A(&1E(%)E8V5PY^-O(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(X,#8*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C
MY^-O(&1E(&1A=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3`*;7-G:60@(D1A
M>2(*;7-G<W1R(")$:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(D1E7VQE=&4@0V]L=6UN
M(@IM<V=S='(@(E)E;6]V97(@0V]?;'5N82(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$97IE
M;6)R;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M(").^FUE<F]S(&1E8VEM86ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM
M<V=S='(@(E)E9'5Z:7(@:6YD96YT8>?C;R(*"B,Z(&QI8B]P<F5F<RYP:'`Z
M,3$Q(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W"FUS9VED(")$969A=6QT
M(@IM<V=S='(@(E!O<B!/;6ES<^-O(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#<*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*;7-G:60@(D1E9F%U;'0@0V]L;W(B
M"FUS9W-T<B`B0V]R(%!O<B!/;6ES<^-O(@H*(SH@;&EB+TAO<F1E+TED96YT
M:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("))
M9&5N=&ED861E(%!A9'+C;R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q
M.2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-@IM<V=I9"`B1&5F875L="!0
M97)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S(%!O<B!/;6ES<^-O(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<*;7-G:60@(D1E9F%U;'0@
M<&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!P;W(@;VUI<W/C;R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO
M;G,B"FUS9W-T<B`B1&5F:6YIY_5E<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S(@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4R"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDU(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,S$U"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,S,R('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3D@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4F5M;W9E<B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@Y(&%D;6EN+V=R;W5P<RYP:'`Z,C$W
M"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B4F5M;W9E<B!'<G5P;R(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-C,@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HX-PIM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M4F5M;W9E<B!097)M:7-SXV\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B
M"FUS9W-T<B`B4F5M;W9E<B!E('!U<F=A<B!M96YS86=E;G,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS
M9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")296UO=F5R(&/I;'5L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B4F5M;W9E<B!C;VQU
M;F$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")296UO=F5R
M(&UO9&5L;R!A;'1E<FYA=&EV;R!E>&ES=&5N=&4B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C4P(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(E)E;6]V97(@<&5R;6ES<_5E<R!D92!<(B5S7"(B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E)E;6]V97(@<&5R;6ES<_5E<R!P87)A
M("<E<R<@92!Q=6%I<W%U97(@<W5B+7!E<FUI<W/U97,_(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E(')O=R(*;7-G<W1R(")296UO=F5R(&QI;FAA(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L
M971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E)E;6]V97(@:61E;G1I
M9&%D92!S96QE8V-I;VYA9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B4F5M;W9E<B!A(&-O;'5N82!C;W)R
M96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,@IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*
M;7-G<W1R(")296UO=F5R(&$@;&EN:&$@8V]R<F5N=&4B"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0X"FUS9VED(")$96QE=&4@=&AI<R!P97)M:7-S
M:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")296UO=F5R
M(&5S=&$@<&5R;6ES<^-O(&4@=&]D87,@87,@<W5A<R!S=6(M<&5R;6ES<_5E
M<S\B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`B7")38W)I<'1<(B!D92!A8W1U86QI>F'GXV\@7"(E<UPB
M(')E;6]V:61O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM
M92(*;7-G<W1R(")-;VUE;G1O(&1E(&5N=')E9V$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K
M(@IM<V=S='(@(D1I;F%M87)C82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C$Q,"!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,30@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3(T"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M(")$97-C<F5V82!O(%!R;V)L96UA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGGXV\B
M"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")0;W)M96YO<F5S("AT86UB
MZ6T@;F\@<F5G:7-T;RP@7")L;V=<(BP@9&\@2&]R9&4I.B(*"B,Z(&QI8B](
M;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")/<R!D971A;&AE<R!F
M;W)A;2!E;G9I861O<R!P87)A(&\@861M:6YI<W1R861O<B!D;R!S:7-T96UA
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G:60@(D1E
M=F5L;W!M96YT(@IM<V=S='(@(D1E<V5N=F]L=FEM96YT;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B
M4&]N=&\@9&4@3W)V86QH;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT
M"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E!O
M;G1O(&1E($]R=F%L:&\@;F$@^FQT:6UA(&AO<F$Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(D1E=R!P;VEN=#H@(@IM
M<V=S='(@(E!O;G1O(&1E(&]R=F%L:&\Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(@IM<V=S='(@(D1I<F5CY^-O(&1A(&5S<75E<F1A('!A
M<F$@82!D:7)E:71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B
M"FUS9W-T<B`B1&ER96/GXV\@9&$@9&ER96ET82!P87)A(&$@97-Q=65R9&$B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y
M(@IM<V=S='(@(D1I<F5C=/-R:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4X"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@
M(DUO<W1R87(@=&5M<&]S(&-O;2`R-"!H;W)A<S\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M(")/<.?U97,@9&4@5FES=6%L:7IAY^-O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C@X"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C
M87-T(@IM<V=S='(@(DUO<W1R87(@<')E=FESXV\@<&]R;65N;W)I>F%D82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B36]S=')A<B!P<F5V:7/C;R`H5$%&*2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$V"FUS9VED(")$:7-P;&%Y(&9O
M<FUA="(*;7-G<W1R(")&;W)M871O(&1E('9I<W5A;&EZ8>?C;R(*"B,Z(&QI
M8B](;W)D92]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VXB"FUS9W-T<B`B3F]T:69I8V'GXV\@9&4@1&ES<&]S:>?C
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)U=&DB"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C0V(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,S$U"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(D[C;R!R96UO=F5R
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(T"FUS9VED(")$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").
MXV\@=71I;&EZ92!O(&UA:6YT96YA;F-E+G!H<"!D:7)E8W1A;65N=&4B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ.2!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ.0IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O
M;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X
M.B(*;7-G<W1R("(B"B)!('!R:6UE:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE
M<R!D;W,@8V%M<&]S/R!392!S:6TL(&%S<VEN86QA<B!E<W1A(&-A:7AA.B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN:6-A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M
M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82!$;VUI;FEC86YA
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,0IM<V=I9"`B
M1&]W;FQO860B"FUS9W-T<B`B4F5C96)E<B(*"B,Z(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HX-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO
M860@)7,B"FUS9W-T<B`B4F5C96)E<B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C4*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(D1E<V-A<G)E9V%R(&$@
M8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(%PB<V-R:7!T7"(@4$A0+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3`X"FUS9VED(")$<F]P(&1O=VX@
M;&ES="(*;7-G<W1R("),:7-T82!D92!D97-E;G)O;&%R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")$<F]G
M87,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#(*;7-G:60@(D4M
M36%I;"(*;7-G<W1R(")#;W)R96EO(&5L96-T<O-N:6-O(@H*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED
M(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")2
M97#Z8FQI8V$@9&\@17%U861O<B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,CDT('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T
M96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET(@IM<V=S
M='(@(D5D:71A<B(*"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="!";&]C:R(*
M;7-G<W1R(")%9&ET87(@0FQO8V\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X
M."!A9&UI;B]G<F]U<',N<&AP.C(Q-@IM<V=I9"`B161I="!'<F]U<"(*;7-G
M<W1R(")%9&ET87(@1W)U<&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C8R(&QI8B](;W)D92]097)M<R]522YP:'`Z.#8*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R(")%9&ET87(@4&5R;6ES<_5E<R(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B161I=&%R(%!E<FUI<W/U97,B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(D5D:71A<B!P97)M:7-S]65S
M(&1E("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B
M161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B161I=&%R(&]PY_5E<R!D93HB
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,#0@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5D:71A<B!P97)M:7-S]65S(&1E
M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B161I=&%R('!E<FUI<W/U97,@9&4@)7,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")%9'5C
M8>?C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G:7!T;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M16P@4V%L=F%D;W(B"FUS9W-T<B`B4F5P^F)L:6-A(&1E($5L(%-A;'9A9&]R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0R"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE;G1O
M+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-S`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(D-O<G)E:6\@16QE8W1R\VYI8V\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-#`*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T
M<B`B16YD97)EYV\@9&4@0V]R<F5I;R!%;&5C='+S;FEC;R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.38T"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"XB"FUS9W-T<B`B3W,@96YD97)EYV]S('3J;2!Q=64@8V]I;F-I
M9&ER+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DP"FUS9VED(")%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")-96YS86=E;2!C;VT@8V]N
M9FER;6'GXV\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C@P"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B4^UM8F]L;W,@9&4@
M16UOY^-O(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(DUE;G-A9V5M('9A
M>FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$R.`IM<V=I9"`B
M16UP='D@<F5S=6QT+B(*;7-G<W1R(")396T@<F5S=6QT861O<RXB"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E
M87)C:"!T97)M<R(*;7-G<W1R(")396T@=&5R;6]S(&1E('!R;V-U<F$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,U"FUS9VED(")%;F%B;&4@:6YS
M97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT
M/R(*;7-G<W1R(")!8W1I=F%R(&EN<V5RY^-O(&1E(&EM86=E;G,@9&4@1V%L
M97)I87,@1F]T;V=RX69I8V%S(&YO('1E>'1O/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3`*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_(@IM<V=S='(@(D%C=&EV87(@;65N=2!D92!C;VYT97AT;R!N
M;R!B;W3C;R!D:7)E:71O(&1O(')A=&\_(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(U.3<@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3`*;7-G:60@(D5N9"!Y
M96%R(@IM<V=S='(@(D%N;R!D92!F:6TB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O
M<B(*;7-G<W1R(")!=6UE;G1A<B!%9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$S"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB26YT<F]D=7IA('5M82!P97)G
M=6YT82!D92!S96=U<F%NYV$@<75E('-E<N$@8V]N=FED861O(&$@<F5S<&]N
M9&5R('-E("(*(G!R96-I<V%R(&1E(')E:6YI8VEA<B!A('-U82!P86QA=G)A
M+7!A<W-E+"!E+F<N+"`G8V]M;R!S92!C:&%M82!O('-E=2!A;FEM86P@(@HB
M9&4@97-T:6UAY^-O/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@
M:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B26YT<F]D=7IA(&\@55),(&1A(&EM
M86=E;2!A<75I(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A
M=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;B(*;7-G<W1R("(B
M"B)%;G1R861A<SH@)60@=&]T86PL("5D(&%C='5A;&EZ861A<RP@)60@;F]V
M87,L("5D(&%L=&5R861A<RP@)60@9&5S8V]N:&5C:61A<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q
M=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D=U:6[I($5Q=6%T;W)I86PB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")%<FET<F5A(@IM<V=S='(@(D5S=&%D;R!D82!%<FET<F5I82(*"B,Z
M(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#<@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C<Y
M"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)O(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92XB"FUS9W-T<B`B17)R;R!N82!M96YS86=E;2!D92!C;W)R
M96EO(&5L96-T<O-N:6-O+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B17)R;R!A;R!E<V-R
M979E<B!<(B5S7"(N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-3(R('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<W"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ-#,X('!O+W1R86YS;&%T:6]N+G!H<#HQ
M-3`Q"FUS9VED(")%<G)O<CH@(@IM<V=S='(@(D5R<F\Z("(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S
M=&]N:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($5S=/-N:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M=&AI;W!I82(*;7-G<W1R(")297#Z8FQI8V$@1&5M;V-RX71I8V$@1F5D97)A
M;"!D82!%=&GS<&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS
M9VED(")%=&AN:6,B"FUS9W-T<B`BR71I8V\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S$*;7-G:60@(D5V97)Y(#$U
M(&UI;G5T97,B"FUS9W-T<B`B0V%D82`Q-2!M:6YU=&]S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM
M<V=S='(@(D-A9&$@,B!M:6YU=&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,R."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")%=F5R
M>2`S,"!S96-O;F1S(@IM<V=S='(@(D-A9&$@,S`@<V5G=6YD;W,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,P(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#(*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")#861A(#4@
M;6EN=71O<R(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-C`*;7-G
M:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D-A9&$@16YT<F%D82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S(*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R(")#861A(&UE:6$@:&]R82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,CD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B
M179E<GD@;6EN=71E(@IM<V=S='(@(D-A9&$@;6EN=71O(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C@*;7-G:60@(D5X86UP;&4@=F%L=65S
M.B(*;7-G<W1R(")686QO<F5S(&5X96UP;&\Z(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(X"FUS9VED(")%>&5C=71E(@IM<V=S='(@(D5X96-U=&%R(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C(Y.2!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,S(P('!O+W1R86YS;&%T:6]N+G!H<#HS-C(*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C0T,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-30Q('!O+W1R86YS;&%T:6]N
M+G!H<#HV,#$*(SH@<&\O=')A;G-L871I;VXN<&AP.C<P,B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-S,W('!O+W1R86YS;&%T:6]N+G!H<#HW.3@*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C@W-2!P;R]T<F%N<VQA=&EO;BYP:'`Z.3DT('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,#$V"FUS9VED(")%>&5C=71I;F<Z(@IM<V=S='(@
M(D5X96-U=&%N9&\Z(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M,SDT"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B17AP86YD:7(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A;F0@4VED
M96)A<B(*;7-G<W1R(")-;W-T<F%R($)A<G)A($QA=&5R86PB"@HC.B!L:6(O
M2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I
M)R(*;7-G<W1R("(G*2<@97-P97)A9&\B"@HC.B!L:6(O2&]R9&4O4U%,+TME
M>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q
M=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B17-P97)A=F$@=6UA('-I;7!L
M97,@<&%L879R82!O=2!U;2!T97)M;R!D92!P<F]C=7)A(&5N=')E(&%S<&%S
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Q"FUS9VED(")%>'!I
M<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T82!D92!%>'!I<F'GXV\B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B
M"FUS9W-T<B`B17AP;V5N=&4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5X=')A8W1I;F<@9G)O;2`E<RXN+B`B
M"FUS9W-T<B`B17AT<F%I;F1O(&1E("5S+BXN("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'
M($-O;&]R(@IM<V=S='(@(D-O<B!D;R!0<FEM96ER;R!0;&%N;R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*;7-G:60@(D944"!U<&QO860@;V8@
M<V5T=7`B"FUS9W-T<B`B0V%R<F5G87(@8V]N9FEG=7)AY^-O(&1E(&EN<W1A
M;&'GXV\@<&]R($944"(*"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP.C(Q
M-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@<'5X87(@87,@<')E9F5RZFYC:6%S+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$P,`IM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D9A;&AA(&YA
M(&QI9V'GXV\@86\@<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+B(*;7-G<W1R(")&86QH82!N82!L:6=AY^-O(&%O('-E<G9I9&]R
M(%--0BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C`S"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")&
M86QH82!A;R!C;W!I87(@9&4@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HV,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@
M7"(E<UPB+B(*;7-G<W1R(")&86QH82!A;R!C;W!I87(@<&%R82!<(B5S7"(N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B1F%L
M:&$@86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!305-,+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HV-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")&86QH82!A;R!M;W9E<B!P87)A
M(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")";VTB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B26QH87,@1F%L:VQA
M;F0@*$UA;'9I;F%S*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B
M26QH87,@1F%R;V4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR,S@*;7-G:60@
M(D9A=&%L($5R<F]R.B(*;7-G<W1R(")%<G)O($9A=&%L.B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS
M9W-T<B`B1F%X(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,W-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E=F5R96ER;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(D%P87)E;G1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M.0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(D%P87)E;G1A.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B06QG=6YS($%G=6%C96ER;W,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I
M9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")!;&=U;G,@3F5V]65S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#4*;7-G:60@(D9I96QD(&UA=')I
M>"(*;7-G<W1R(")-871R:7H@9&4@8V%M<&]S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G
M<W1R(")&:6II(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")#;VYT86=E;2!D92!!
M<G%U:79O<SH@)7,@87)Q=6EV;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D-O
M;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-#8*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G
M<W1R(")'97-TXV\@9&4@1FEC:&5I<F]S(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G
M:60@(D9I;&4@3F%M92(*;7-G<W1R(").;VUE(&1O($%R<75I=F\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDY-`IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B4V5L96/GXV\@9&\@87)Q=6EV;R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#@X"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")#87)R
M96=A;65N=&\@9&4@87)Q=6EV;R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HX-C,*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R(")#87)R96=A;65N=&]S(&1E(&9I8VAE:7)O<R!NXV\@<^-O('-U<&]R
M=&%D;W,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED
M(")&:6QT97)S(@IM<V=S='(@(D9I;'1R;W,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM
M<V=S='(@(D9I;FSB;F1I82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S$*
M;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B475A<G1O($-R97-C96YT92(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B475A<G1O($-R97-C
M96YT92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,SD*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")&:7AA<B!RX6-I;R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,30*;7-G:60@
M(D9L:7`B"FUS9W-T<B`B26YV97)T97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*
M;7-G<W1R(")&;'5T=6%N=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(DYE=F]E:7)O
M(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$V,"!L:6(O5D93+VUU<W%L+G!H<#HQ
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(D$@<&%S=&$@)7,@;N-O(&5X:7-T92XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&
M;VYT($-O;&]R(@IM<V=S='(@(D-O<B!D;R!497AT;R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")#;VUI9&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U
M<'!O<G0@:6UA9V5S(@IM<V=S='(@(E!A<F$@;F%V96=A9&]R97,@<75E(&[C
M;R!S=7!O<G1A;2!I;6%G96YS(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(E!R979I<^-O("A4
M048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Q"FUS9VED
M("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O
M<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E
M(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM
M<V=S='(@(B(*(D1I87,@9&4@4')E=FESXV\@*&YO=&4M<V4@<75E(&%S('!R
M979I<_5E<R!I;F-L=65M('1A;G1O(&1I87,@8V]M;R!N;VET97,[("(*(G5M
M('9A;&]R(&1E;6%S:6%D;R!G<F%N9&4@<&]D92!R97-U;'1A<B!N=6T@8FQO
M8V\@;75I=&\@;&%R9V\I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHY.`IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(D5S
M<75E8V5U+7-E(&1A('!A;&%V<F$M<&%S<V4_(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B36]D96QO
M<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N
M92(*;7-G<W1R(")$:71O<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E1I<&\@9&4@9&ET;W,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S
M(@IM<V=S='(@(D1I=&]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y
M"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(D1I=&]S(#(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")&;W)U;7,B"FUS9W-T
M<B`B1O-R=6YS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM
M<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4F5E;G9I;W,B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&;W5N9"!A
M<'!L:6-A=&EO;G,Z("5S(@IM<V=S='(@(D%P;&EC8>?U97,@*&WS9'5L;W,I
M(&5N8V]N=')A9&%S.B`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4R
M"FUS9VED(")&;W5N9"!D:7)E8W1O<FEE<SHB"FUS9W-T<B`B4&%S=&%S(&5N
M8V]N=')A9&%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(C:J(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I
M9"`B1G)A;65S(@IM<V=S='(@(DUO;&1U<F%S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM
M<V=S='(@(E)E</IB;&EC82!&<F%N8V5S82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G
M<W1R(")&<F%NYV$L($UE=')O<&]L:71A;F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I
M86YA(@IM<V=S='(@(D=U:6%N82!&<F%N8V5S82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@
M4&]L>6YE<VEA(@IM<V=S='(@(E!O;&ENZ7-I82!&<F%N8V5S82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(E1E<G)A
M<R!!=7-T<F%I<R!E($%N=.%R8W1I8V%S($9R86YC97-A<R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM
M<V=S='(@(D1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0X"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.30*;7-G:60@(D9R;VT@=&AE("(*;7-G
M<W1R(")$92`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGGXV\@
M0V]M<&QE=&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#(@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$X,0IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(DQU82!#
M:&5I82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,SD*
M;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").;VUE($-O;7!L971O(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B1G5Z>GDB"FUS9W-T<B`B
M1&EF=7-A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(E)E</IB;&EC82!'86)O
M;F5S82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VTB"FUS9W-T<B`B1V%L97)I82!D92!O;F1E(')E=&ER87(@82!I;6%G
M96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R
M:6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(E)E</IB;&EC82!D82!'XFUB
M:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M
M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
M1V5R87(@0V]N9FEG=7)AY^-O("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+V-O;F9I9RYH=&UL.C$P"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G
M<W1R(")#\V1I9V\@1V5R861O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T:6YG('-T871U<R!F;W(@
M;6]D=6QE("5S+BXN(@IM<V=S='(@(D=E<F%N9&\@;R!E<W1A9&\@9&\@;?-D
M=6QO("5S+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDP(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'9?-R9VEA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")297#Z8FQI8V$@1F5D97)A;"!D82!!
M;&5M86YH82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<Q"FUS9VED(")'
M971O<'0@17)R;W(Z("(*;7-G<W1R(")%<G)O(&5M(&=E=&]P=#HB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")':&%N82(*;7-G<W1R(")297#Z8FQI8V$@9&\@1V%N82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I
M8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(").
M;VUE(%!R\W!R:6\B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM
M<V=I9"`B1V\B"FUS9W-T<B`B27(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")']F1E;"(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS
M9W-T<B`B4&5S<75I<V$@1V]O9VQE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R,`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@
M(D[M=F5I<R!D92!C:6YZ96YT;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B
M1W+I8VEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R
M965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<F5G;R`H25-/+3@X-3DM-RDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)O;F5LXFYD:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")'<F5N861A(@IM<V=S='(@(D=R86YA9&$B"@HC"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3<P"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!9&UI;FES=')AY^-O(&1E($=R=7!O<R(*"B,Z(&QI8B](;W)D92]'<F]U
M<"YP:'`Z-3@*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M(@IM<V=S='(@(DYO;65S(&1E(&=R=7!O<R!NXV\@<&]D96T@97-T87(@=F%Z
M:6]S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`Q(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C<W"FUS9VED(")'<F]U<"!P97)M:7-S:6]N<R(*;7-G
M<W1R(")097)M:7-S]65S(&1E(&=R=7!O(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,C4P(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<&]S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A
M9&5L;W5P92(*;7-G<W1R(")'=6%D86QU<&4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G
M<W1R(")'=6%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")297#Z8FQI
M8V$@9&$@1W5A=&5M86QA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR
M"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$R-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P
M-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S
M="!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S(&1A<R!6:7-I=&%S
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(X(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,C`V"FUS9VED(")'=65S="!P97)M:7-S:6]N<R(*;7-G<W1R
M(")097)M:7-S]65S(&1A<R!6:7-I=&%S(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0Q-PIM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DQI=G)O
M(&1E(%9I<VET87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;NDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;NDM0FES<V%U(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B4F5P^F)L:6-A($-O+6]P97)A=&EV
M82!D82!'=6EA;F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.38P"FUS9VED
M(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RXB"FUS9W-T<B`B3R!(5$U,07)E82!R96-U<V$M<V4@8V]B87)D96UE;G1E
M(&$@<F5M;W9E<B!A(/IL=&EM82!CZ6QU;&$@9&$@;&EN:&$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R(")/($A434Q!<F5A(')E
M8W5S82US92!C;V)A<F1E;65N=&4@82!R96UO=F5R(&$@^FQT:6UA(&-O;'5N
M82!D82!T86)E;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G
M<W1R(")/($A434Q!<F5A(')E8W5S82US92!C;V)A<F1E;65N=&4@82!R96UO
M=F5R(&$@^FQT:6UA(&QI;FAA(&1A('1A8F5L82XB"@HC.B!L:6(O2&]R9&4O
M075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71E;G1I8V'GXV\@2%104"!NXV\@9F]I
M(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")297#Z8FQI
M8V$@9&\@2&%I=&DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#(*
M;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M;R!D92!<
M(DAA<VA<(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DYE8FQI;F$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z.3$Y(&QI8B](;W)D92]&;W)M+G!H<#HR.3,Q"FUS
M9VED(")(96%D97(B"FUS9W-T<B`B0V%B9>=A;&AO(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R
M9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B26QH87,@
M2&5A<F0@92!-8T1O;F%L9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@
M(E1E;7!O<F%L+50@1F]R=&4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E
M=2`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R
M(")!;'1U<F$B"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3<Y(&QI8B](;W)D
M92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T
M<B`B06IU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")!
M:G5D82!S;V)R92!O(&5D:71O<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S<S"FUS9VED(")(96QP97(B"FUS9W-T<B`B06IU9&$B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.34*;7-G:60@(B(*(DAE;'!E<B!A<'!L:6-A=&EO;B!T
M;R!C<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@=&AE($AO
M<F1E7&XB"B)F<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N7&XB"B)&
M;W(@86X@:6YT<F]D=6-T:6]N(')E860@=&AE(&9I;&4@4D5!1$U%(&EN('1H
M:7,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)!<&QI8V'GXV\@875X:6QI87(@
M<&%R82!C<FEA<B!E(&UA;G1E<B!T<F%D=>?U97,@9&$@<&QA=&%F;W)M85QN
M(@HB2&]R9&4@92!D87,@<W5A<R!A<&QI8V'G]65S("AM\V1U;&]S*2Y<;B(*
M(E!A<F$@=6UA(&EN=')O9'7GXV\@;&5R(&\@9FEC:&5I<F\@4D5!1$U%(&YE
M<W1A('!A<W1A+B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B
M2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<V;I<FEO(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3<*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93HB"FUS9W-T<B`B07%U:2!E<W3A(&\@:6[M8VEO(&1O(&%R<75I=F\Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G
M:60@(DAI9V@B"FUS9W-T<B`B06QT82(*"B,Z(&QI8B](;W)D92](:7-T;W)Y
M+G!H<#HS,C$*;7-G:60@(DAI<W1O<GD@96YT<GD@;F%M97,@;75S="!B92!N
M;VXM96UP='DB"FUS9W-T<B`B3F]M97,@9&%S(&5N=')A9&%S(&AI<W3S<FEA
M<R!NXV\@<&]D96T@97-T87(@=F%Z:6]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8SHT"FUS9VED(")(;U]M92(*;7-G<W1R(")#85]S82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO
M;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(D5S=&%D;R!D
M82!#:61A9&4@9&\@5F%T:6-A;F\B"@HC.B!L:6(O2&]R9&4N<&AP.C$T,S4*
M;7-G:60@(DAO;64B"FUS9W-T<B`B0V%S82(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B16YD
M97)EYV\@9&4@0V%S82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VYE
M(&1E($-A<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(E)E</IB;&EC
M82!D87,@2&]N9'5R87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(
M;VYG=65C;VYG=64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*
M;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$S,CD*;7-G:60@(DAO<F1E('1R86YS;&%T:6]N(&=E;F5R871O
M<B(*;7-G<W1R(")'97)A9&]R(&1E('1R861UY_5E<R!(;W)D92(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($1A9&]S(%A-3"`E
M<R!I;G;A;&ED;W,@;F$@;65N<V%G96T@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G96T@8V]R<F5S<&]N9&4@86\@
M;V)J96-T;R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#$S"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!.96YH=6T@;V)J96-T;R!D;R!T:7!O("5S(&5N8V]N=')A9&\@;F$@;65N
M<V%G96T@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4F5M;^?C;R!D
M92`E<R!<(B5S7"(@=&5V92!S=6-E<W-O(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HQ,34T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S(%PB)7-<(B(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@4VEN8W)O;FEZ8>?C;R!D92`E<R!<(B5S7"(@=&5V92!S
M=6-E<W-O(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO
M<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H
M92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!/(&UO=&]R(&1E(&EN=&5G<F'GXV\@<F5Q=65R(&$@97AT96YSXV\@4$A0
M("=D;VUX;6PG(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@
M;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@HB2&]R9&4O
M2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@8W)I87(@=6UA(&YO=F$@X7)V;W)E
M<R!834P@<&%R82!O(&]B:F5C=&\@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$R,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R("5S(%PB)7-<(CH@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($[C;R!F;VD@<&]S<^UV96P@;V)T97(@;R!)1"!-24U%('!A<F$@82!P87)T
M92!D92!T:7!O("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,34Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B`E<R!<(B5S7"(Z("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S
M:6YC<F]N:7IA<B!P87)T:6QH87,Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!087)T
M:6QH82!<(B5S7"(@9&5S8V]N:&5C:61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2
M=6QE(@IM<V=S='(@(E1R8>=O($AO<FEZ;VYT86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N
M=&%L('!A9&1I;F<B"FUS9W-T<B`B16YC:&EM96YT;R!H;W)I>F]N=&%L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM
M<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G1A;#HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3`*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I(@IM<V=S='(@(D-O;6\@8VAE9V]U(&%Q=6D_("A0;W(@9F%V;W(@<F5P
M;W)T92UO(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1=6%N=&%S(&-O;'5N87,@
M<')E=&5N9&4@:G5N=&%R/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(X"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T
M:&5R93\B"FUS9W-T<B`B475A;G1O<R!C86UP;W,@*&-O;'5N87,I(&5X:7-T
M96T_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1A<R!L:6YH87,@<')E=&5N9&4@
M:G5N=&%R/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#@@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S
M='(@(DAU;6ED861E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-PIM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")(=6UI9&%D93H@(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B
M"FUS9W-T<B`B2'5M;W)I<W1A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R
M(")297#Z8FQI8V$@9&$@2'5N9W)I82(*"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<#HQ-S(@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B02!C<FEAY^-O(&1A(&-A:7AA('!O<W1A;"!)34%0
M(&9A;&AO=3H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C$T
M(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(E)E;6_GXV\@9&$@8V%I>&$@<&]S=&%L($E-05`@9F%L:&]U.B`E<R(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD@;&EB+TAO<F1E+T%U
M=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B0W)I
M8>?C;R!D92!Q=6]T82!D92!C86EX82!P;W-T86P@24U!4"!F86QH;W4Z("5S
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,3<*;7-G:60@(DE0($%D9')E
M<W,B"FUS9W-T<B`B16YD97)EYV\@25`B"@HC.B!L:6(O2&]R9&4O075T:"]I
M<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")%;F1E<F7G;R!)4"!I;F1I<W!O;NUV96PN(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@
M;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(D5N9&5R
M9>=O($E0(&9O<F$@9&\@8FQO8V\@0TE$4B!P97)M:71I9&\N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO
M8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B5FEO;&'GXV\@9&4@8FQO<75E
M:6\@9&4@25`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*
M;7-G<W1R("))7VYS97)I<B!,:6YH82!!;G1E<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N
M9"(*;7-G<W1R(")297#Z8FQI8V$@9&$@27-LXFYD:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B
M07!E;F%S(,UC;VYE<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-CD*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("+-8V]N97,@8V]M(%1E
M>'1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,@IM<V=I9"`B261E
M;G1I='DG<R!N86UE.B(*;7-G<W1R(").;VUE(&1A(&ED96YT:61A9&4Z(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4X.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(E-E(&[C
M;R!F;W(@;6]S=')A9&\@8V]R<F5C=&%M96YT92P@)7,@<&%R82!O(&%B<FER
M(&YU;6$@;F]V82!J86YE;&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T-PIM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B
M"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G
M<W1R("(B"B)392!NXV\@=FER('%U86QQ=65R(.UC;VYE(&%O('5S87(@;R!)
M;G1E<FYE="!%>'!L;W)E<BP@<&]D92!P<F5C:7-A<B!D92`B"B)S96QE8V-I
M;VYA<B!E<W1A(&-A:7AA('!A<F$@9&5S;&EG87(@82!T<F%N<W!A<NIN8VEA
M+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-3@*
M;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G
M92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D
M:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)392!V:7(@
M97-T82!M96YS86=E;2!N;6%S(&[C;R!A(&EM86=E;2!P<F]P<FEA;65N=&4@
M9&ET82P@82!I;6%G96T@<75E("(*(G!R971E;F1E(&-A<G)E9V%R(&[C;R!P
M;V1E('-E<B!M;W-T<F%D82!P96QO('-E=2!N879E9V%D;W(N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")0<F5V:7/C;R!D
M82!);6%G96TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E52
M3"!D82!I;6%G96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS
M9W-T<B`B55),(&1A(&EM86=E;3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E
M(&9R;VT@9V%L;&5R>2(*;7-G<W1R("));6%G96T@9&4@9V%L97)I82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("))
M;6%G96T@9&4@9V%L97)I83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V
M,@IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D-A<G)E9V%M96YT;R!D
M82!I;6%G96TB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B
M26UA9V5S(@IM<V=S='(@(DEM86=E;G,B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ,`HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@
M4W1E<"`E9"(*;7-G<W1R("));7!O<G1A<BP@4&%S<V\@)60B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B0V%M<&\@:6UP;W)T861O
M.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S,*;7-G:60@
M(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0V%M<&]S(&EM<&]R=&%D;W,Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("))
M;E]S97)I<B!,:6YH82!$97!O:7,B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E
M;BXB"FUS9W-T<B`B0_-D:6=O(&1E(&%CY^-O(&EN=')O9'5Z:61O(&5S=.$@
M:6YC;W)R96-T;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+B(*;7-G<W1R(").;VUE(&1E('5T:6QI>F%D;W(@;W4@<&%L879R82UP
M87-S92!E<G)A9&]S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M(DYO;64@9&4@=71I;&EZ861O<B!O=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!E
M<G)A9&]S+B!#;VYT86-T92!O('-E=2`B"B)A9&UI;FES=')A9&]R(&1E('-I
M<W1E;6$@<&%R82!O8G1E<B!A:G5D82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E
M;G0B"FUS9W-T<B`B075M96YT87(@82!);F1E;G1AY^-O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M;F1I82(*;7-G<W1R(")297#Z8FQI8V$@9&$@S6YD:6$B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ-#$@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B571I;&EZ861O
M<F5S($EN9&EV:61U86ES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B
M4F5P^F)L:6-A(&1A($EN9&]NZ7-I82(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R
M;6'GXV\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0V"FUS9VED
M("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUAY^-O(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.`IM<V=I9"`B26YF;W)M871I;VX@
M;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B26YF;W)M8>?C;R!JX2!N
MXV\@97-TX2!D:7-P;V[M=F5L(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4X
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("));FET:6%L:7II;F<@;6]D=6QE("5S
M+BXN("(*;7-G<W1R("));FEC:6%L:7IA;F1O(&\@;?-D=6QO("5S+BXN("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-`IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B
M26YS97)I<B!#7V]L=6YA($1E<&]I<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS
M97)T($EM86=E(@IM<V=S='(@(DEN<V5R:7(@26UA9V5M(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS
M97)T(%1A8FQE(@IM<V=S='(@(DEN<V5R:7(@5&%B96QA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS
M97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN<V5R:7(@3&EG8>?C;R#@(%=E8B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,PIM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@
M(DEN<V5R:7(@7T-O;'5N82!!;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T
M(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M26YS:7)I<B!U;6$@;F]V82!C;VQU;F$@9&5P;VES(&1A(&-O<G)E;G1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8T"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS:7)I<B!U;6$@;F]V82!C;VQU;F$@
M86YT97,@9&$@8V]R<F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<VER:7(@
M=6UA(&YO=F$@;&EN:&$@9&5P;VES(&1A(&-O<G)E;G1E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS
M9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B26YS:7)I<B!U;6$@;F]V82!L:6YH82!A;G1E<R!D82!C;W)R
M96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS97)I<B!U;2!P87+A9W)A
M9F\@87#S<R!O(&[S(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
M26YS97)I<B!U;2!P87+A9W)A9F\@86YT97,@9&\@;O,@8V]R<F5N=&4B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R("));G-I<FER(&UO9&5L;R!A;'1E<FYA
M=&EV;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S$*;7-G:60@(DEN
M<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV
M92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"B));G1R;V1U>F$@=6T@
M96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!O;F1E('!O<W-A(')E
M8V5B97(@82!N;W9A("(*(G!A;&%V<F$M<&%S<V4Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B
M26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B26YS:7)I<B!CZ6QU;&$@87#S
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("))
M;G-E<FER(&/I;'5L87,@86YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L
M=6UN(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@8^EL=6QA(&1E<&]I<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN<V5R
M:7(@8V]L=6YA(&%N=&5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B26YS
M97)I<B!M96YS86=E;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@869T97(B"FUS9W-T<B`B26YS97)I<B!P87+A9W)A9F\@86YT97,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#,*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@
M(DEN<V5R:7(@<&%RX6=R869O(&%N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T
M(')O=R!A9G1E<B(*;7-G<W1R("));G-E<FER(&QI;FAA(&1E<&]I<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7(@
M;&EN:&$@86YT97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(R"FUS
M9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ(@IM<V=S='(@(DEN=')O9'5Z82!A(')E<W!O<W1A(&5X
M:6=I9&$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R86[G83HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("))
M;G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DEN<V5R:7(O36]D:69I8V%R
M($EM86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("))
M;G-E<FER+TUO9&EF:6-A<B!,:6=AY^-O(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I
M="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B
M0W+I9&ET;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I87(@<&%R82!A(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G
M<W1R(")#<NED:71O(&EN<W5F:6-I96YT92XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("));G1E:7)O(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES
M="(*;7-G<W1R("),:7-T82!D92!I;G1E:7)O<R(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")51$@@*%5S97(@1&%T82!(
M96%D97(I(&EN=N%L:61O+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N
M<&AP.C$W,"!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)
M4"!D871A(@IM<V=S='(@(D1A9&]S(%I)4"!I;G;A;&ED;W,B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T
M:6]N+B(*;7-G<W1R(")!<&QI8V'GXV\@:6YVX6QI9&$N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@
M8F%T8V@@240N(@IM<V=S='(@(DE$(&1E(&QO=&4@*%PB8F%T8VA<(BD@:6YV
MX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.#@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Q-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S,*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R.3@*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M
M:71T960N(@IM<V=S='(@(D]S(&1A9&]S('-U8FUE=&ED;W,@<^-O(&EN=N%L
M:61O<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R
M(")%;F1E<F7G;R!D92!D97-T:6YO(&EN=N%L:61O+B(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C@Q(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N
M<&AP.C$P,`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G
M:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D;R!A
M<G%U:79O(&EN=N%L:61O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V-`IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B
M0VAA=F4@9&$@;&EC96[G82!I;G;A;&ED82XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34X"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("),;V-A;&EZ8>?C;R!I;G;A;&ED82!E<W!E8VEF
M:6-A9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(FUS9U]T>7!E
M(&EN=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G
M<W1R(")A<&E?:60@:6YVX6QI9&\@;W4@96T@9F%L=&$N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")087+B;65T<F]S(&EN
M=N%L:61O<R!O=2!E;2!F86QT82XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z-#,*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(E!E<FUI<W/C;R!P87)E;G1A;"!I;G;A;&ED82XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38P"FUS9VED("));G9A;&ED('!A
M<G1N97(@:60N(@IM<V=S='(@(DE$(&1E('!A<F-E:7)O(&EN=N%L:61O+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C(*;7-G:60@(DEN
M=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")#\V1I9V\@9&4@<')O9'5T
M;R!I;G;A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B4')O
M=&]C;VQO(&EN=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP
M:65N=#H@7"(E<UPB(@IM<V=S='(@(D1E<W1I;F%TX7)I;R!I;G;A;&ED;SH@
M7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#0S(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3(R,`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B
M"FUS9W-T<B`B3V)J96-T;R!D92!P87)T:6QH82!I;G;A;&ED;R(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A
M;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")%;F1E<F7G;R!D82!O<FEG
M96T@:6YVX6QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R
M(")$861O<R!U;FEC;V1E(&EN=N%L:61O<RXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(U"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV
M96YTX7)I;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*
M;7-G<W1R(")297#Z8FQI8V$@27-LXFUI8V$@9&\@27+C;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B
M27)A<2(*;7-G<W1R(")297#Z8FQI8V$@9&\@27)A<75E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))
M<F5L86YD(@IM<V=S='(@(E)E</IB;&EC82!D82!)<FQA;F1A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS
M9W-T<B`B26QH82!D92!-86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS
M9W-T<B`B5&5M<&]R86ES+50@27-O;&%D;W,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*
M;7-G<W1R(")%<W1A9&\@9&4@27-R865L(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R(")%;6ES<V]R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M"FUS9VED("))=&%L:6,B"FUS9W-T<B`B273A;&EC;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A
M;'DB"FUS9W-T<B`B4F5P^F)L:6-A($ET86QI86YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA
M:6-A(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S<T(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YE:7)O(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")*87!A;B(*;7-G<W1R(")*87#C;R(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM
M<V=S='(@(DIA<&]NZG,@*$E33RTR,#(R+4I0*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")296EN;R!(87-H96UI=&$@9&$@
M2F]R9.)N:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM
M<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QH;R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-SD@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FAO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")*=7-T:69I8V%R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(D-E;G1R87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(DIU<W1I9FEC87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(DIU<W1I9FEC
M87(@X"!%<W%U97)D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM
M<V=S='(@(DIU<W1I9FEC87(@X"!$:7)E:71A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS
M=&%N(@IM<V=S='(@(E)E</IB;&EC82!D;R!#87IA<75I<W3C;R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME
M97`@;W)I9VEN86P_(@IM<V=S='(@(E!R97-E<G9A<B!O(&]R:6=I;F%L/R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1O(%%UZ6YI82(*
M"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D\@
M<V5R=FED;W(@2V5R8F5R;W,@<F5J96ET;W4@82!A=71E;G1I8V'GXV\N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W
M8FEE<R(*;7-G<W1R(").;W9A=&]S(&YO(%PB2V5R;F5L7"(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DME>2!#<F5A=&EO;B(*
M;7-G<W1R(")#<FEAY^-O(&1A($-H879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#`S"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M26UP<F5S<^-O(&1I9VET86P@9&$@8VAA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,#$*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B0V]M
M<')I;65N=&\@9&$@8VAA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,#`*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E1I<&\@9&$@0VAA=F4B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(E5T:6QI>F'GXV\@9&$@0VAA=F4B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,CD*;7-G:60@(DME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B02!C:&%V
M92!JX2!E>&ES=&4@;F\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G
M<W1R(")-:?ID;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(E%U:7)I
M8F%T:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I
M8V$@9&$@0V]R96EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B4F5P^F)L:6-A(&1A($-O<F5I82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B0V]R
M96%N;R`H155#+4M2*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=V%I
M="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")297#Z8FQI8V$@475I
M<F=U:7IE(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED
M("),85]Y;W5T(@IM<V=S='(@(E]$:7-P;W-IY^-O(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW.2!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS
M9VED("),86YG=6%G92(*;7-G<W1R("))9&EO;6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!0
M96]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC
M82!0;W!U;&%R($1E;6]C<N%T:6-A($QA;R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")1=6%R=&\@1&5C
M<F5S8V5N=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@@;&EB+T)L;V-K
M+VUO;VXN<&AP.CDP"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B475A
M<G1O($1E8W)E<V-E;G1E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*
M;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`BVFQT:6UA($%C='5A;&EZ
M8>?C;SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(MIL=&EM82!E;G1R
M861A.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV.#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("+:
M;'1I;6$@96YT<F%D83H@)7,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z-C@S"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("+:;'1I
M;6$@96YT<F%D83H@3G5N8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R(")2
M97#Z8FQI8V$@9&$@3&5T\VYI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DQE:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(D1I<W!O<VGGXV\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R(@IM<V=S='(@(D1E:7AA<B!V87II;R!P87)A(&9I8V%R
M('-E;2!B;W)D82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),[6)A;F\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B17-Q=65R9&$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$Q.`IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T
M<B`B0V%B9>=A;&AO(&1A(&5S<75E<F1A(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,30*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E9A;&]R97,@
MX"!E<W%U97)D82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EBZ7)I82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R(")'<F%N9&4@2F%M86AI
M<FEY82!3;V-I86QI<W1A(%!O<'5L87(@P7)A8F4@9&$@3.UB:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&ES=&5N<W1A:6YE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@
M(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B0VAU=F$@7")-;VQH82U4;VQO<UPB
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*
M;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B0VAU=FES8V]S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI
M9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B0VAU=FES8V]S($UA=&EN86ES(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G
M:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")#:'5V:7-C;W,@5F5S<&5R
M=&EN;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B4&5Q=65N
M;R!!9W5A8V5I<F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS
M9W-T<B`B0VAU=FES8V\@8V]M(%1R;W9O861A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`B475E9&$@9&4@3F5V92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E
M<B(*;7-G<W1R(").979E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U
M"FUS9VED("),:6UE<FEC:R(*;7-G<W1R(")<(DQI;65R:6-K7"(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q-0IM<V=I9"`B3&EN:R(*;7-G<W1R("),
M:6=AY^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4V"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T
M<B`B3&EG8>?C;R!A<&]N=&$@<&%R83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@W-@IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"B),:6=A
M<B!O(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@X"!PX6=I;F$@
M9&4@8V]M<&]S:>?C;R!A;R!M;W-T<F%R(@H*(SH@;&EB+TAO<F1E+U1E>'0O
M1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R
M("),:6=AY_5E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I
M9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(D)O;&EN:&\@;&EN=7CJ<R(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W1A("T@
M;R!U=&EL:7IA9&]R('!O9&4@=F5R(&$@<&%S=&$B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,P"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("),
M:7-T87(@0F%S97,@9&4@1&%D;W,B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")-;W-T
M<F%R(%3S<&EC;W,@9&4@06IU9&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(Y"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("),:7-T87(@5&%B96QA
M<R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B
M3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W1A9V5M+4%R<75I=F\B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L
M<"(*;7-G<W1R("),:7-T86=E;2U!:G5D82(*"B,Z(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("))1"!D
M82!,:7-T82(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,@IM
M<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T86=E;2U$;VYO(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O
M<W0B"FUS9W-T<B`B3&ES=&%G96TM4W5B;6ES<_5E<R(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B
M"FUS9W-T<B`B3&ES=&%G96TM4W5B<V-R:71A<R(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*
M;7-G<W1R("),:7-T86=E;2U.XV\@<W5B<V-R:71A<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-`IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B02!L:7-T86=E;2!D92!U=&EL:7IA
M9&]R97,@97-TX2!D97-A8W1I=F%D82XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET97)A='5R
M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R(")297#Z8FQI8V$@9&$@
M3&ET=>)N:6$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,S.`IM<V=I9"`B
M3&]A9&EN9R!L:6)R87)I97,N+BXB"FUS9W-T<B`B0V%R<F5G86YD;R!B:6)L
M:6]T96-A<RXN+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.CDR"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(D-A<G)E9V%N9&\N
M+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DY"FUS9VED
M("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B5&5M<&\@;&]C86PZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B
M"FUS9W-T<B`B3&]C86QI>F'GXV\@92!&=7-O($AO<N%R:6\B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DQO
M8V%L:7IAY^-O(@H*(SH@;&]G:6XN<&AP.C$V,B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,38T('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHX-@IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D5N=')A
M<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3@*;7-G:60@
M(DQO9R!O=70B"FUS9W-T<B`B4V%I<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(E1A<F5F87,@
M9&4@16YT<F%D82(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,S$*;7-G:60@
M(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(D$@875T
M96YT:6-AY^-O(&9A;&AO=2!P;W(@;R!.;VUE(&1E(%5T:6QI>F%D;W(@;W4@
M82!086QA=G)A+5!A<W-E(&5S=&%R96T@(@HB:6YC;W)R96-T;W,N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDR-PIM<V=I9"`B3&]G:6X@9F%I;&5D+B(*
M;7-G<W1R(")!(&%U=&5N=&EC8>?C;R!F86QH;W4N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S-C<*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")497AT
M;R!L;VYG;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B
M3&]V92(*;7-G<W1R(")!;6]R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R(")"86EX;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B
M3&5T<F%S(&=R96=A<R!M:6[Z<V-U;&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W
M97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("),971R87,@;&%T:6YA<R!M:6[Z
M<V-U;&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*
M;7-G<W1R(").^FUE<F]S(')O;6%N;W,@;6EN^G-C=6QO<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)U<F=O(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,R!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3,*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%
M1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")/(&%N
M97AO($U3+51.148@;N-O(&-O;G1I;FAA(&1A9&]S+B(*"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B
M35-'(@IM<V=S='(@(DU31R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C
M874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(*;7-G<W1R(")-86-E9/-N:6$L($%N=&EG82!297#Z8FQI
M8V$@2G5G;W-L879A(&1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@
M(DUA9&%GX7-C87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G
M:60@(DUA9VEC(@IM<V=S='(@(DUA9VEA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(D-O<G)E:6\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<W"FUS9VED(")-86EL($%D
M;6EN(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@0V]R<F5I;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,`IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")&87IE<B!L:5]G8>?C
M;RXN+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S4W"FUS9VED(")-86ME
M('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U
M<B!I;F-L=61E('!A=&@N(@IM<V=S='(@(B(*(D%S<V5G=7)E+7-E(&1E('%U
M92!T96T@;R!014%2(&EN<W1A;&%D;R!E(&YO(&-A;6EN:&\@9&4@:6YC;'5S
M]65S("AI;F-L=61E("(*(G!A=&@I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HV-S@@<&\O=')A;G-L871I;VXN<&AP.C$P-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B36%K:6YG(&1I<F5C=&]R>2`E<R(*;7-G<W1R(")#<FEA;F1O(&$@
M<&%S=&$@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=6DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;.%S:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA
M;&1I=F5S(@IM<V=S='(@(DUA;&1I=F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S
M='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE
M(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W
M:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+B(*;7-G<W1R("(B"B)':7)A(&$@;&ES=&$@9&4@8V%T96=O<FEA
M<R!Q=64@<&]D92!A=')I8G5I<B!A;W,@:71E;G,L(&)E;2!C;VUO(&%S(&-O
M<F5S("(*(G%U92!L:&5S(&5S=.-O(&%S<V]C:6%D87,N(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(DUA<#(T
M(&UA<"(*;7-G<W1R(")-87!A($UA<#(T(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDW-PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`U-`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S
M='(@(DUA<&$@36%P475E<W0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S<V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%RYV\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS
M9VED(")-87)G:6XB"FUS9W-T<B`B36%R9V5M(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5
M;G-E96X@9FQA9W,B"FUS9W-T<B`B36%R8V%R(&-O;6\@3&ED82].XV\@;&ED
M82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I
M9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"DB"FUS9W-T<B`B36%R8V%R(&1E(&]U=')A<R!F;W)M87,@*&4N9RXL
M($EM<&]R=&%N=&4O4&]R(')E<W!O;F1E<BDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL
M($ES;&%N9',B"FUS9W-T<B`B26QH87,@36%R<VAA;&PB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA
M<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6-A(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,3$*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G
M<W1R(")#86UP;W,@<75E(&-O<G)E<W!O;F1E;2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET
M86YI82(*;7-G<W1R(")-875R:73B;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B
M"FUS9W-T<B`B36%U<NUC:6\B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G
M<W1R(")-X7AI;6\@8W+I9&ET;R!P97)M:71I9&\N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E
M('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")-X7AI;6\@;OIM97)O(&1E('!A
M<G1E<R!N=6UA(&UE;G-A9V5M(&5X8V5D:61O+B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B
M"FUS9W-T<B`B5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S(#(T(&AO
M<F%S.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X
M('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>%X
M:6UA(&YA<R#Z;'1I;6%S(#8@:&]R87,Z("(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3<@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(D-O
M;7!R:6UE;G1O(&WA>&EM;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%I;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA
M>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D:6-I;F$B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$Y"FUS9VED(")-
M96UB97)S(@IM<V=S='(@(DUE;6)R;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<P"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUO9&\@9&\@
M;65N=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")5;FER
M(&/I;'5L87,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3(W"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE<F=I;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C
M;VUP96YD:75M+BXN("(*;7-G<W1R("));G1E9W)A;F1O('1O9&]S(&]S(&9I
M8VAE:7)O<R`E<RYP;R!C;VT@;R!C;VUPZFYD:6\N+BXB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-#,X"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@
M;&]C86QE("5S+BXN("(*;7-G<W1R("));G1E9W)A;F1O(&$@;&]C86QI>F'G
MXV\@)7,N+BX@(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<X.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-97)G:6YG('1H92!03R!F:6QE(&9O<B`E<R!T;R!T
M:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T<B`B26YT96=R86YD;R!O(&%R<75I
M=F\@4$\@9&4@)7,@8V]M(&\@8V]M<.IN9&EO+BXN("(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HT,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B365R9VEN9R!T
M<F%N<VQA=&EO;B!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(DEN=&5G<F%N
M9&\@82!T<F%D=>?C;R!D;R!M\V1U;&\@)7,N+BXB"@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*;7-G:60@(DUE
M<W-A9V4B"FUS9W-T<B`B365N<V%G96TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C
M97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N
M;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(DUE;G-A9V5N(%9E<FEF
M:6-A9&$@8V]M(%-U8V5S<V\L(&UA<R!O(&-E<G1I9FEC861O(&1O('-U8G-C
M<FET;W(@;N-O('#T9&4@(@HB<V5R('9E<FEF:6-A9&\N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@
M97AP:7)E9"XB"FUS9W-T<B`B365N<V%G96T@97AP:7)O=2XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4:7!O(&1E(&UE
M;G-A9V5M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A
M<B!796%T:&5R(@IM<V=S='(@(DUE=&5O<F]L;V=I82!-151!4B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D)L;V-O($U%5$%2(&EN9&ES<&]N[79E;"XB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB0FQO8V\@3454
M05(@:6YD:7-P;V[M=F5L+B!/<R!P;W)M96YO<F5S(&9O<F%M(')E9VES=&%D
M;W,@<&%R82!O("(*(F%D;6EN:7-T<F%D;W(N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U,@IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(*;7-G<W1R(")!($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861A
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8W(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS
M9W-T<B`B3>ET;V1O(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q
M(&QI8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G
M:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B3R!M
MZ71O9&\@7"(E<UPB(&[C;R!E<W3A(&1E9FEN:61O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*
M;7-G:60@(DUE=')I8R(*;7-G<W1R(")-Z71R:6-O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI
M8V\B"FUS9W-T<B`B3>EX:6-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EC<F]NZ7-I82P@17-T861O<R!&
M961E<F%D;W,@9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")#96YT
M<F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G
M:60@(DUI;64@5'EP92(*;7-G<W1R(")4:7!O($U)344B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R
M<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R
M-"!H;W)A<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-
M:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UP97)A='5R82!M
M[6YI;6$@;F%S(/IL=&EM87,@-B!H;W)A<R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,3<*;7-G:60@(DUI<G)O<B(*;7-G<W1R
M(")%<W!E;&AO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED
M(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DUI<V-E;.)N96$B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C
M:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(E!A8V]T92!(5%107U)E<75E
M<W0@9&\@4$5!4B!E;2!F86QT82XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$T"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB0V]N9FEG=7)AY^-O(&5M
M(&9A;'1A+B!497+A(&1E(&$@9V5R87(@86=O<F$@<V4@<75I<V5R('5S87(@
M97-T82!A<&QI8V'GXV\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T
M<B`B240@9&$@;65N<V%G96T@96T@9F%L=&$N(@H*(SH@;&EB+TYE="]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B4&%C;W1E($UA:6P@
M9&\@4$5!4B!E;2!F86QT82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G
M<W1R("))1"!D82!S97-SXV\@96T@9F%L=&$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T
M<B`B,JHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@
M(DUO8FEL92!-86EL(@IM<V=S='(@(D-O<G)E:6\@3?-V96PB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D
M97)A=&4B"FUS9W-T<B`B36]D97)A9&\B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I
M9"`B36]D:69I960@1&%T92(*;7-G<W1R(")$871A(&1E($UO9&EF:6-AY^-O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4R"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(DUO9&EF:6-A
M<B!54DPB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED(")-;V1U
M;&4B"FUS9W-T<B`B3?-D=6QO(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B3?-D=6QO(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")297#Z8FQI8V$@
M9&$@36]L9&]V82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(E!R:6YC:7!A
M9&\@9&\@3?-N86-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG
M\VQI82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DS"FUS9VED(")-;VYT
M:"!A;F0@>65A<B(*;7-G<W1R(")-ZG,@92!A;F\B"@HC.B!L:6(O2&]R9&4O
M36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DUE
M;G-A;&UE;G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S
M97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(D9A<V4@9&$@
M3'5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(E)E:6YO(&1E($UA<G)O
M8V]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")3;V)R971U9&\@3&EM
M<&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")3;V)R971U9&\@16YE
M=F]A9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(E-O8G)E='5D;R!3
M;VQA<F5N9V\B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,C@*
M;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")$97-C97(B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,S(*;7-G:60@(DUO=F4@3&5F="(*;7-G
M<W1R(")-;W9E<B!P87)A(&$@17-Q=65R9&$B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HT,S8*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B
M36]V97(@<&%R82!A($1I<F5I=&$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HT,C0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B4W5B:7(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV"FUS9VED
M(")-;W9E(&1O=VXB"FUS9W-T<B`B1&5S8V5R(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-2!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#DV"FUS9VED(")-;W9E('5P(@IM<V=S='(@(E-U
M8FER(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(E)E</IB;&EC82!D
M92!-;^=A;6)I<75E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#4*;7-G
M:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("),:7-T
M87,@9&4@9&5S96YR;VQA<B!M=6QT:2UN[79E;"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,C0S"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T
M<B`B4V5L96/GXV\@;?IL=&EP;&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,Q(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S@*;7-G:60@
M(DUY($%C8V]U;G0B"FUS9W-T<B`B02!-:6YH82!#;VYT82(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-3$*;7-G:60@(DUY(%!O<G1A;"(*;7-G
M<W1R(")/($UE=2!0;W)T86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP
M:'`Z,3(T"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(D1I<W!O
M<VGGXV\@9&\@4&]R=&%L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(E5N
M:>-O(&1E($UY86YM87(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R
M965M96YT7V)O='1O;2YI;F,Z-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(D[C;RP@;N-O(&-O;F-O<F1O(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#`P(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B3F%M92(*;7-G<W1R(").;VUE(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM
M<V=S='(@(E)E</IB;&EC82!D82!.86WM8FEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*
M;7-G<W1R(").875R=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(E)E:6YO(&1O<R!08>US
M97,@0F%I>&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S
M='(@(D%N=&EL:&%S($AO;&%N9&5S87,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T
M<B`B55),(&1E($)A<V4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B55),(&1E(%)E=F]G8>?C;R!#02!.971S8V%P92(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P
M92!#02!P;VQI8WD@55),(@IM<V=S='(@(E523"!C;VT@82!P;VSM=&EC82!D
M92!#02!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(")54DP@
M9&4@4F5N;W9AY^-O($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(E523"!D92!2979O9V'GXV\@3F5T<V-A<&4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE(@IM<V=S='(@(DYO;64@9&\@<V5R=FED;W(@4U-,($YE='-C
M87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B0V]M96YT
MX7)I;R!D92!C97)T:69I8V%D;R!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!T>7!E(@IM<V=S='(@(E1I<&\@9&4@8V5R=&EF:6-A9&\@3F5T<V-A<&4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,Y"FUS9VED(").971W
M;W)K(@IM<V=S='(@(E)E9&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,30@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-PHC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<X"FUS9VED(").979E<B(*;7-G<W1R(").=6YC82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").;W9A($-A;&5D\VYI
M82(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(W
M"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F]V82!#871E9V]R:6$B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-SD*;7-G:60@(DYE=R!-;V]N(@IM
M<V=S='(@(DQU82!.;W9A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS
M9W-T<B`B3F]V;R!.;VUE(&1E(%5T:6QI>F%D;W(@*&]P8VEO;F%L*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F]V82!:96SB;F1I82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G
M:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F]V82!J86YE;&$@
M*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(V,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W3M8VEA<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.34*;7-G:60@(DYE=W-G<F]U<',B"FUS
M9W-T<B`B1W)U<&]S(&1E($YO=.UC:6%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,C$@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#8*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S<@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,S(*;7-G:60@(DYE>'0B"FUS9W-T<B`B4'+S>&EM
M82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H
M87-E<R(*;7-G<W1R(")0<O-X:6UA<R`T($9A<V5S(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HS-S`@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S0*
M;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")0<O-X:6UA<R!O<.?U97,B
M"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB
M"FUS9W-T<B`B4'+S>&EM83XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R
M(")297#Z8FQI8V$@9&$@3FEC87+A9W5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G
M<W1R(")297#Z8FQI8V$@9&\@3NUG97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS
M9W-T<B`B4F5P^F)L:6-A($9E9&5R86P@9&$@3FEG97)I82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C@*;7-G:60@(DYI9VAT(@IM<V=S
M='(@(DYO:71E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@U"FUS9VED(").
M;R(*;7-G<W1R(").XV\B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF
M9BYH=&UL.C$V"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"B).XV\@
M:.$@9&%D;W,@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV96ES(&5M(')E;&'G
MXV\@86]S('%U86ES(&UO<W1R87(@(@HB9&EF97)E;N=A<RXB"@HC.B!L:6(O
M5D93+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").XV\@:.$@
M;F5N:'5M82!E<W1R873I9VEA(&1I<W!O;NUV96P@<&%R82!R96%L:7IA<B!I
M;6%G96YS($E33RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(D[C
M;R!HX2!M;V1E;&\@9&4@;&]T92!<(F)A=&-H7"(N(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-SD@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z,C,P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(U,@IM<V=I
M9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB
M"FUS9W-T<B`B3N-O(&5X:7-T92!B;&]C;R!N82!P;W-IY^-O(&EN9&EC861A
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(D[C;R!F;VD@9F]R;F5C:61O('5M(&YO;64@9&4@8V%L96YD
MX7)I;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B4V5M
M(&UO9&EF:6-AY_5E<RXB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T
M,`IM<V=I9"`B3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D
M(&)E;&]W('1H:7,@;&5V96PN(@IM<V=S='(@(D[C;R!S92!P;V1E(&%D:6-I
M;VYA<B!P97)M:7-S]65S(&1E(&9I;&AO<R!A8F%I>&\@9&5S=&4@;NUV96PN
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8Q"FUS9VED(").;R!C
M:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G
M<W1R(").XV\@<V4@<&]D92!A9&EC:6]N87(@9FEL:&]S(&$@97-T82!P97)M
M:7-SXV\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-S<*;7-G:60@(DYO
M(&-O;6UA;F0@<W!E8VEF:65D+B(*;7-G<W1R(").96YH=6T@8V]M86YD;R!E
M<W!E8VEF:6-A9&\N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C<@;&EB+TAO<F1E
M+G!H<#HT-S<@;&EB+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(@IM<V=S='(@(D[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF
M;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@<&%R82`E<RXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z-S0Q"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@HB3N-O(&9O
M:2!E<W!E8VEF:6-A9&$@82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!P
M87)A(%9&4R!B87-E861O(&5M($944"XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M-3DQ"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@HB3N-O(&9O:2!E<W!E8VEF
M:6-A9&$@82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!N96-E<W/A<FEA
M('!A<F$@;R!61E,@(@HB8F%S96%D;R!E;2!344PN(@H*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z-S`T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B
M"B).XV\@9F]I(&5S<&5C:69I8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG
M=7)AY^-O(&YE8V5S<^%R:6$@<&%R82!O(%9&4R`B"B)B87-E861O(&5M(%-1
M3"U&:6QE+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B0W+I9&ET;R!E
M<V=O=&]U+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").
M96YH=6T@9&5S=&EN873A<FEO(&9O:2!F;W)N96-I9&\N(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$R-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@96YT
M<GD@=VET:"!T:&4@:60@7"(E<UPB(&5X:7-T<R!I;B!T:&4@;W)I9VEN86P@
M:&5L<"!F:6QE+B(*;7-G<W1R("(B"B).XV\@97AI<W1E('%U86QQ=65R(&5N
M=')A9&$@8V]M(&\@:60@7"(E<UPB(&YO(&%R<75I=F\@9&4@86IU9&$@;W)I
M9VEN86PN(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X,0IM<V=I9"`B
M3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(").XV\@<V4@8V%R<F5G;W4@;F%D
M82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N
M+G!H<#HU,C(*;7-G:60@(DYO(&QO8V%L92!S<&5C:69I960N(@IM<V=S='(@
M(DYE;FAU;6$@;&]C86QI>F'GXV\@97-P96-I9FEC861A+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L
M;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(D9A;'1A(&EN9&EC87(@=6UA(&QO
M8V%L:7IAY^-O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-38*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!(&QO
M8V%L:7IAY^-O(&[C;R!F;VD@97-P96-I9FEC861A+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@
M<W5P<&QI960N(@IM<V=S='(@(DYE;FAU;6$@;65N<V%G96T@9F]I(&9O<FYE
M8VED82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V
M"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3F5N:'5M(&YO
M;64@97-P96-I9FEC861O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S
M='(@(DYE;FAU;2!N^FUE<F\@97-P96-I9FEC861O+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(E-E;2!D:71O<R!O9F5N<VEV;W,B"@HC.B!L:6(O2&]R9&4O
M075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D[C;R!F;VD@9F]R
M;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!(5%10
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(D[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A
M(&%U=&5N=&EC8>?C;R!)34%0+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D[C;R!F;VD@9F]R;F5C:61A
M('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!+97)B97)O<RXB
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY-`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(D[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U
M=&5N=&EC8>?C;R!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP
M.C<W(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`HC.B!L:6(O2&]R9&4O
M075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D[C;R!F;VD@9F]R
M;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!,;V=I
M;BXB"@HC.B!L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P
M87)A(&$@875T96YT:6-AY^-O(%!!4U-71"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").XV\@9F]I(&9O<FYE8VED
M82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@4TU"+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82XB"FUS9W-T<B`B(@HB3N-O(&9O:2!I;F1I8V%D;R!C86UI;FAO
M('!A<F$@;R!B:6[A<FEO($]P96Y34TPN($\@8FENX7)I;R!/<&5N4U-,(.D@
M(@HB;F5C97-SX7)I;R!P87)A('1R86)A;&AA<B!C;VT@9&%D;W,@4$M#4R`Q
M,BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS
M9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(D[C;R!HX2!S=6)S
M8W)IY_5E<R!P96YD96YT97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS
M9W-T<B`B4V5M('1R8>=O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S
M='(@(E-E;2!L861O<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,C4*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92XB"FUS9W-T<B`B3N-O(&CA('!A<W1A('1E;7!O<N%R:6$@
M9&ES<&]N[79E;"!P87)A(%PB8V%C:&5<(BXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B3N-O(&9O<F%M(&5N=FEA9&]S
M(&\@;F]M92!D;R!U=&EL:7IA9&]R(&]U(&$@<&%L879R82UP87-S92XB"@HC
M.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI
M9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(").XV\@9F]R86T@<F5T;W)N
M861O<R!D861O<R!E;2!834P@=N%L:61O<R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.3,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDP,PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3$T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY,S$*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")396T@=F%L;W)E<R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3D*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B).XV\@9F]I(&5N8V]N=')A
M9&$@=F5R<^-O(&YA(&-O;F9I9W5R8>?C;R!O<FEG:6YA;"X@4F5G96YE<F%R
M(&-O;F9I9W5R8>?C;RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(W
M"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").XV\@9F]I
M(&5N8V]N=')A9&$@=F5R<^-O(&YA('-U82!C;VYF:6=U<F'GXV\N(%)E9V5N
M97)A<B!C;VYF:6=U<F'GXV\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$V('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY,@IM<V=I9"`B3F]N92(*;7-G<W1R(").96YH=6UA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N
M92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(").96YH=6T@*'5S87(@:6UP;.UC
M:71O*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D
M:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(").\W)D:6-O("A)4T\M.#@U.2TQ
M,"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DEL:&$@9&4@
M3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B2&5M:7-FZ7)I;R!.;W)T92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($UA<FEA;F%S(&1O($YO<G1E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").;W)W87DB"FUS9W-T<B`B4F5I;F\@9&$@3F]R=65G82(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T
M97(B"FUS9W-T<B`B3G5N8V$@1&5P;VES(&1E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B
M3G5N8V$@06YT97,@9&4B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S,0IM<V=I
M9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(D[C;R#I('5M(&1I<F5C=/-R
M:6\B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO
M="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3N-O(&EM<&QE;65N=&%D82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS
M9VED(").;W0@<V5T(@IM<V=S='(@(E!O<B!A=')I8G5I<B(*"B,Z(&QI8B]6
M1E,N<&AP.C$W-2!L:6(O5D93+G!H<#HQ.3,@;&EB+U9&4RYP:'`Z,C$P(&QI
M8B]61E,N<&AP.C(R-@HC.B!L:6(O5D93+G!H<#HR-#(@;&EB+U9&4RYP:'`Z
M,C4W(&QI8B]61E,N<&AP.C(W-"!L:6(O5D93+G!H<#HS,#<*(SH@;&EB+U9&
M4RYP:'`Z,S8W(&QI8B]61E,N<&AP.C0T-B!L:6(O5D93+G!H<#HU,34@;&EB
M+U9&4RYP:'`Z-3,R"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z
M,30S(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3<S(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,3@W"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,C,T"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").XV\@<W5P
M;W)T861O+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0T(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-C0*;7-G:60@(DYO=&5S
M(@IM<V=S='(@(DYO=&%S(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N
M<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS
M9W-T<B`B3F%D82!P87)A(&YA=F5G87(L('9O;'1E('!A<F$@='+A<RXB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$P"FUS
M9VED(").;W1I8V4B"FUS9W-T<B`B3F]T82(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E
M;6)R;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB
M97(B"FUS9W-T<B`B3OIM97)O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M,C<*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(D[Z;65R
M;R!D92!C87)A8W1E<F5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(D[Z;65R;R!D
M92!C;VQU;F%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-CD@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D[Z;65R;R!D92!L:6YH87,B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED
M(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"B).82!L:7-T82!D92!D:7-T<FEB
M=6GGXV\@:.$@;OIM97)O<R!Q=64@;N-O(&9O<F%M(&5S<&5C:69I8V%D;W,@
M<&%R82`B"B)A8W1U86QI>F'GXV\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8T('!O+W1R86YS;&%T:6]N+G!H<#HQ-#@*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-#@*;7-G:60@(D]+(@IM<V=S='(@
M(D]+(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q
M,0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5C=&\B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`B0W)I861O<B!D;R!/8FIE8W1O(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z,3,W(&QI8B](;W)D92]097)M<R]522YP:'`Z,C$U"FUS9VED
M(")/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S
M]65S(&1O(&-R:6%D;W(@9&\@;V)J96-T;R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R(")/8W1A;"(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#,@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM
M<V=S='(@(D]U='5B<F\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*
M;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(D9I;'1R;R!D92!M871E
M<FEA;"!O9F5N<VEV;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,#$*;7-G:60@(D]F9FEC92(*;7-G<W1R(")'86)I;F5T92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M3VUA;B(*;7-G<W1R(")3=6QT86YA=&\@9&\@3VWC(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R
M=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")3\R!O<R!S
M97)V:61O<F5S($E-05`@<W5P;W)T86T@<&%S=&%S('!A<G1I;&AA9&%S+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B07!E;F%S(&1I=&]S(&]F96YS:79O
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4R(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.3<R"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N(@IM<V=S='(@(E/S(.D@<&5R;6ET:61O('5M(&5N9&5R9>=O(&1E(&-O
M<G)E:6\@96QE8W1R\VYI8V\N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P
M97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B)!<&5N87,@;R!D
M;VYO(&]U('5M(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<&]D92!A;'1E
M<F%R(&$@=&ET=6QA<FED861E(&1E("(*(G5M82!P87)T:6QH82!O=2!A<R!P
M97)M:7-S]65S(&1O('-E=2!D;VYO(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%B
M<F4@;G5M82!N;W9A(&IA;F5L82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT
M<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B
M"B)%<G)O($]P96Y34TPZ($[C;R!F;VD@<&]S<^UV96P@97AT<F%I<B!D861O
M<R!D92!U;6$@<&%R=&4@87-S:6YA9&$@8V]M(%,O(@HB34E-12XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B06)R92!E<W1A(&QI9V'GXV\@;G5M82!N;W9A(&IA;F5L82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y
M<W1E;2(*;7-G<W1R(")3:7-T96UA($]P97)A=&EV;R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T
M<B`B3W#G]65S(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C(Y('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO
M;G,@9F]R("5S(@IM<V=S='(@(D]PY_5E<R!D;R`E<R(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,3(*;7-G:60@(D]P=&EO;G,Z(@IM<V=S='(@(D]PY_5E
M<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B3&ES=&$@3W)D96YA
M9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B
M3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7IAY^-O(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L
M(%5N:70B"FUS9W-T<B`B56YI9&%D92!/<F=A;FEZ86-I;VYA;"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B
M"FUS9W-T<B`B3W)G86YI>F'GXV\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS
M9W-T<B`B36]D96QO(&]R:6=I;F%L(&1A(&%P;&EC8>?C;R(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I
M;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B36]D96QO<R!O<FEG:6YA
M:7,@96T@)7,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M3W5T<F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B
M3W5T<F%S($EN9F]R;6'G]65S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R
M;6ES<_5E<R!D;R!$;VYO(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW
M.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E
M;"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C4S"FUS9VED(")0
M1U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B07-S:6YA='5R82!$:6=I
M=&%L(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R.3D*;7-G
M:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")$861O<R!E;F-R:7!T
M861O<R!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4Q"FUS
M9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")#:&%V92!0^F)L:6-A(%!'
M4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,S,*;7-G:60@(E!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%D;W,@07-S:6YA
M9&]S+T5N8W)I<'1A9&]S(&-O;2!01U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(D/S9&EG;R!02%`B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G
M<W1R(")#;VUA;F1O<R!02%`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R
M(")#:'5V:7-C;W,@<&5L82!487)D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S
M='(@(D%G=6%C96ER;W,@9&4@5&%R9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R
M(").979E(.`@5&%R9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(DYE=O5E<R#@(%1A<F1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")3;VP@X"!4
M87)D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")496UP;W)A:7,M5"#@
M(%1A<F1E(@H*(SH@;&EB+V%P:2YP:'`Z,3(X"FUS9VED(")07TA0(%-H96QL
M(@IM<V=S='(@(D-O;6%N9&]S(%!?2%`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG
M(@IM<V=S='(@(D5N8VAI;65N=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S
M='(@(E)E</IB;&EC82!)<VSB;6EC82!D;R!087%U:7-TXV\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QA=2(*;7-G<W1R(")297#Z8FQI8V$@9&4@4&%L874B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E1E
M<G)I=/-R:6\@4&%L97-T:6YI86YO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T
M<B`B4&%N86WA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@
M(E!A<'5A($YO=F$@1W5I;NDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R
M(")297#Z8FQI8V$@9&\@4&%R86=U86DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*
M;7-G<W1R(")087)C:6%L;65N=&4@16YC;V)E<G1O(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`Q.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S,@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHS-@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S8R"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")086QA=G)A+5!A<W-E
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"FUS9VED(")0
M87-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%L879R82U087-S92!I;F-O
M<G)E8W1A(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(E!A;&%V<F$M4&%S<V4@;F5C97-SX7)I82!P87)A(&%U
M=&5N=&EC8>?C;R!2041)55,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`U
M-`IM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B
M4&%L879R82U087-S92!C;VT@8V]N9FER;6'GXV\B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R
M(")086QA=G)A+5!A<W-E.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E!A;&%V<F$M4&%S
M<V4Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`S-0HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U
M"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B07,@<&%L
M879R87,M<&%S<V4@=.IM(&1E('-E<B!I9W5A:7,N(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(D-O;&%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B0V]L87(@
M9&4@<F5C;W)T97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(D-A;6EN:&\B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-`IM<V=I9"`B4&5N9&EN
M9R!3:6=N=7!S.B(*;7-G<W1R(")3=6)S8W)IY_5E<R!096YD96YT97,Z(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS
M9W-T<B`B4&5S<V]A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!E<F-E
M;G1A9V5M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?8F]T
M=&]M+FEN8SHV"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,B"FUS9W-T<B`B17AE8W5T87(@3W!E<F'G]65S(&1E($UA;G5T96[GXV\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDX"FUS9VED(")097)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D5X
M96-U=&%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%Q=6%N9&\@9&$@96YT
M<F%D83\B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8T"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HV-PIM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")097)M:7-SXV\B
M"@HC(&,M9F]R;6%T"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T
M960N(@IM<V=S='(@(D$@<&5R;6ES<^-O(%PB)7-<(B!NXV\@9F]I(')E;6]V
M:61A+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(R-"!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*;7-G:60@(E!E<FUI<W-I;VYS
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@4&5R
M;6ES<_5E<R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30U(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,30X"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,34R"FUS9VED(")097)M:7-S:6]N<R!F;W(B"FUS9W-T<B`B4&5R;6ES
M<_5E<R!D92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B
M4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M8>?U97,@4&5S
M<V]A:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R^B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")!;FEM
M86ES(&1E($5S=&EM8>?C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T
M<B`B1FEL:7!I;F%S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VYE(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&AO=&]S(@IM
M<V=S='(@(D9O=&]G<F%F:6%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T
M<B`B26QH87,@4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E#M
M>&5I<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA
M=&ET=61E<R(*;7-G<W1R(")0;&%T:71U9&5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE
M87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(E!O<B!F879O<B!C
M;&EQ=64@<V]B<F4@=6UA(&/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.`IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.B(*;7-G<W1R(")0;W(@9F%V;W(@8V]N9FER;64@<V4@<F5A;&UE;G1E('!R
M971E;F1E(')E;6]V97(@97-T92!E;&5M96YT;SHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@
M(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="XB"FUS9W-T<B`B4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E86QM
M96YT92!P<F5T96YD92!D97-L:6=A<B!E<W1E(&5L96UE;G1O+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3<P"FUS9VED(")0;&5A<V4@96YT97(@82!M
M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R(")0;W(@9F%V;W(@:6YT<F]D=7IA
M('5M(&WJ<R!E('5M(&%N;RXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B4&]R(&9A=F]R(&EN
M=')O9'5Z82!O(&YO;64@9&$@;F]V82!C871E9V]R:6$Z(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N(@IM<V=S='(@(E!O<B!F879O<B!I;G1R;V1U>F$@=6T@
M96YD97)EYV\@25`@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C4Y"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T
M:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"B)0
M;W(@9F%V;W(@:6YT<F]D=7IA('5M82!D871A(';A;&ED83L@=F5R:69I<75E
M(&\@;OIM97)O(&1E(&1I87,@9&\@;>IS+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#4P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R(")0;W(@9F%V;W(@:6YT<F]D=7IA('5M82!H;W)A(';A;&ED82XB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S
M='(@(E!O<B!F879O<BP@9F]R;F7G82!U;6$@8G)E=F4@9&5S8W)IY^-O(&1O
M('!R;V)L96UA+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3@@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,@IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4&]R
M(&9A=F]R+"!I;G1R;V1U>F$@;R!S974@3F]M92!D92!5=&EL:7IA9&]R(&4@
M82!S=6$@4&%L879R82U087-S92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]A9W)E96UE;G1?=&]P+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A
M9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS
M9W-T<B`B(@HB4&]R(&9A=F]R(&QE:6$@;R!T97AT;R!S96=U:6YT92X@5&5M
M(&1E($-/3D-/4D1!4B!C;VT@;W,@=&5R;6]S(&1E<W1E(&%C;W)D;R`B"B)P
M87)A('5S87(@;R!S:7-T96UA+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M-PIM<V=I9"`B4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S
M+FAO<F1E+F]R9RXB"FUS9W-T<B`B4&]R(&9A=F]R(')E<&]R=&4@;W,@97)R
M;W,@<&%R82!I,3AN0&QI<W1S+FAO<F1E+F]R9R(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E!O<B!F879O<B!I
M;G1R;V1U>F$@;R!N;VUE(&1A(&YO=F$@8V%T96=O<FEA.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&]L86YD(@IM<V=S='(@(E!O;/-N:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;.UT:6-A(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-`IM<V=I9"`B4&]L;',B
M"FUS9W-T<B`B4V]N9&%G96YS(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T
M<B`B4F5P^F)L:6-A(%!O<G1U9W5E<V$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O
M<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B4&]S:6-I;VYA;65N
M=&\@9&5S=&$@:6UA9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4B"FUS9W-T<B`B4&]S:6-I;VYA;65N=&\@9&5S=&$@=&%B96QA(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0
M;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS
M9W-T<B`B7")0;W-T7"(@<&%R82!E<W1A('!A<W1A("ANXV\@Z2!R97%U:7-I
M=&\@9&\@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C
M:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")0<F5C
M:7!I=&'GXV\@;F%S(/IL=&EM87,@)7,@:&]R82AS*3H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC92(*;7-G<W1R(")0<F]B86)I;&ED861E(&1E/&)R("\^
M4')E8VEP:71AY^-O(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z($$@97AT96YSXV\@3$1!
M4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82XB"@HC.B!L:6(O2&]R
M9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B4')E9G-?<V5S<VEO;CH@02!E>'1E;G/C;R!D92!S97-SXV\@;F5C97-S
MX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(E!R97-SXV\B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@
M<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')E<W/C;R!A;R!N[79E;"!D;R!M87(Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@
M(E!R97-S=7)E.B`B"FUS9W-T<B`B4')E<W/C;SH@(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`B4')E=FESXV\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@
M(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")0
M<F5V97(@82!I;6%G96T@;G5M82!N;W9A(&IA;F5L82(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,S8P(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8T
M"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!A;G1E
M<FEO<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B26UP<FEM
M:7(@;R!D;V-U;65N=&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(D-H879E(%!R:79A9&$B
M"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM
M<V=S='(@(E!R;V)L96UA(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W
M"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:>?C
M;R!D;R!0<F]B;&5M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,3,*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE8W1O<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3$R(&QI8B](;W)D92]&;W)M+G!H<#HR,3@Y
M"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")-96YS86=E;2UP<F]N=&\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(E!U8FQI
M8R!+97DB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H
M;2(*;7-G<W1R(")!;&=O<FET;6\@9&4@0VAA=F4@4/IB;&EC82(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y
M($EN9F\B"FUS9W-T<B`B26YF;W)M8>?C;R!3;V)R92!A($-H879E(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C,P"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(")/('!A<B!D92!C:&%V97,@4'5B;&EC82]0<FEV861A(&[C;R!F;VD@
M9V5R861A(&-O;2!S=6-E<W-O+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM
M<V=S='(@(E!O<G1O(%)I8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R(")%
M<W1A9&\@9&\@46%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C(*;7-G
M:60@(E%U97)Y(@IM<V=S='(@(E!E9&ED;R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L
M:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(D-H879E(%#Z8FQI8V$@4E-!("@E
M9"!B:70I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C4*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R(")396QE8^?C;R!<(G+A9&EO7"(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I
M9"`B4F%I;B(*;7-G<W1R(")#:'5V82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S
M='(@(D-H=79A($UA=&EN86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(D-H
M=79A(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B06=U
M86-E:7)O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B0VAU=F$@92!.
M979E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")#:'5V82!A($YE=F4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O
M<G1U;F4B"FUS9W-T<B`B1&ET;R!!;&5A=/-R:6\B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B4F5L8>?C;R(*"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,CDS('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(DQE<B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("),97(@;65N<V%G
M96YS(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")1=65R(&UE<VUO
M(')E;6]V97(@)7,_($5S=&$@;W!E<F'GXV\@;N-O('1E;2!R96=R97-S;RXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(B(*(E)E;6]V97(@;65S;6\@;W,@9&%D;W,@9&\@=71I;&EZ861O<B`E
M<S\@17-T82!O<&5R8>?C;R!NXV\@=&5M(')E9W)E<W-O+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E)E9F%Z(&$@<W5A(/IL
M=&EM82!A8^?C;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#,*;7-G
M:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")2
M969R97-C87(@16QE;65N=&]S(&1E($UE;G4@1&ENXFUI8V\Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S,PIM<V=I9"`B4F5F<F5S:"!0;W)T86P@
M5FEE=SHB"FUS9W-T<B`B4F5F<F5S8V%R(%9I<W5A;&EZ8>?C;R!D;R!0;W)T
M86PZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G
M97@B"FUS9W-T<B`B17AP<F5S<^-O(%)E9W5L87(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S(T.`IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS
M9W-T<B`B3F%V96=A9&]R(&1E(%)E;&'G]65S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B3V)S97)V8>?U
M97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO
M=&4@4V5R=F5R<R(*;7-G<W1R(")397)V:61O<F5S(%)E;6]T;W,B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")5
M4DP@4F5M;W1O("AH='1P.B\O=W=W+F5X96UP;&\N<'0O:&]R9&4I.B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ-0IM<V=I9"`B4F5M;W9E(@IM<V=S
M='(@(E)E;6]V97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")296UO=F5R($)L;V-O
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0IM
M<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")296UO=F5R(&-O;'5N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*
M;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E)E;6]V97(@9F]R
M;6%T8>?C;R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,V"FUS
M9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")296UO=F5R('!A<B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HR,#4*;7-G:60@(E)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R(")296UO=F5R(&\@7")S8W)I<'1<(B!G=6%R9&%D;R!D82!P87-T82!T
M96UP;W+A<FEA(&1O('-E<G9I9&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B4F5M;W9E
M('1H92(*;7-G<W1R(")296UO=F5R(&\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B4F5M;W9E
M<B!E<W1E(&[S(&1O(&1O8W5M96YT;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,38*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@
M(E)E;6]V97(@571I;&EZ861O<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E
M<CH@)7,B"FUS9W-T<B`B4F5M;W9E<B!U=&EL:7IA9&]R.B`E<R(*"B,Z(&QI
M8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@<F5S<&]N9&5R(&%O('!E9&ED;RX@0_-D
M:6=O(&1E(&5R<F\@9&5V;VQV:61O.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,30T"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L
M9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(D\@<V5R=FGG;R!P961I9&\@;N-O
M(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<T(&QI8B](
M;W)D92YP:'`Z-#@W"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(EPB)7-<(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N
M82!C;VYF:6=U<F'GXV\@9&4@)7,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C4Y
M-R!L:6(O5D93+V9T<"YP:'`Z-S0W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<Q
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB
M(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R
M8>?C;R!61E,N(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S7"(@;V)R:6=A=/-R:6\@
M;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C@*;7-G:60@(E)E<75I<F5D
M($9I96QD(@IM<V=S='(@(D-A;7!O($]B<FEG873S<FEO(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C,S.2!L:6(O2&]R9&4O
M1F]R;2]296YD97)E<BYP:'`Z,S$U"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT
M-`IM<V=I9"`B4F5S970B"FUS9W-T<B`B3&EM<&%R(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM
M<V=S='(@(E)E:6YI8VEA<B!086QA=G)A+5!A<W-E(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O
M<F0B"FUS9W-T<B`B4F5I;FEC:64@82!3=6$@4&%L879R82U087-S92(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@
M861M:6XO<W%L<VAE;&PN<&AP.C8U"FUS9VED(")297-U;'1S(@IM<V=S='(@
M(E)E<W5L=&%D;W,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(Q"FUS9VED
M(")297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.B(*;7-G<W1R(")297-U;'1A
M9&]S("AI;F-L=6EN9&\@2&]R9&4I.B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HX,3D*;7-G:60@(E)E<W5L=',Z(@IM<V=S='(@(E)E<W5L=&%D;W,Z(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G
M<W1R(")6;VQT87(@X',@3W#G]65S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G
M<W1R(")2975N:>-O(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG
M=7)A=&EO;B(*;7-G<W1R(")2179E<G1E<B!#;VYF:6=U<F'GXV\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"FUS9VED(")2:6-H(%1E>'0@161I
M=&]R($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1E($5D:>?C;R!2:6-A(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM
M<V=S='(@(D%D:79I;FAA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B
M1&ER96ET82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3(P"FUS9VED(")2
M:6=H="!H96%D97(B"FUS9W-T<B`B0V%B9>=A;&AO(&1A(&1I<F5I=&$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q-@IM<V=I9"`B4FEG:'0@=F%L=65S
M(@IM<V=S='(@(E9A;&]R97,@X"!D:7)E:71A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2
M;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A($QI
M;E]H82XN+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E)E9W)A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M
M86YI82(*;7-G<W1R(")2;VWI;FEA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(P.`IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M(")2;V1A<B`Q.#`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C`U"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")2;V1A<B#@
M($5S<75E<F1A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Q,0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(E)O9&%R(.`@
M9&ER96ET82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!R:65D861E<R!D82!,:6YH82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P
M97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!L:6YH82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED
M(")2;W=S.B(*;7-G<W1R("),:6YH87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B
M"FUS9W-T<B`B5')AYV]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")4<F'G
M;W,@87!A<F5C97+C;R!E;G1R92!T;V1A<R!A<R!L:6YH87,@92!C;VQU;F%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU
M;6YS(&]N;'DB"FUS9W-T<B`B5')AYV]S(&%P87)E8V5RXV\@87!E;F%S(&5N
M=')E(&%S(&-O;'5N87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")4<F'G;W,@87!A<F5C97+C
M;R!A<&5N87,@96YT<F4@;&EN:&%S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(D5X96-U=&%R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(D9E9&5R8>?C;R!2=7-S82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")297#Z8FQI8V$@9&\@4G5A;F1A
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")!<W-I;F%T
M=7)A($-R:7!T;V=RX69I8V$@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G
M92(*;7-G<W1R(")-96YS86=E;2!%;F-R:7!T861A(&-O;2!3+TU)344B"@HC
M.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!=71E;G1I
M8V'GXV\@4T%33"!I;F1I<W!O;NUV96PN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0U.0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")-
M96YS86=E;G,@4TU3(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B0V]M86YD;W,@4U%,(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,W,`IM<V=I9"`B4U-((@IM<V=S='(@(E-3
M2"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")354-%4U-/(@H*(SH@
M;&EB+V%P:2YP:'`Z,3,R"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(D-O
M;6%N9&]S(%-?44PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")SX2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-A:6YT($AE;&5N82(*;7-G<W1R(")386YT82!(96QE;F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@
M(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")3XV\@2VET=',@92!.
M979I<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%N=&$@3/IC
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(E/C;R!0961R;R!E($UI<75E;&]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN
M8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4^-O(%9I8V5N=&4@
M92!'<F5N861I;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S
M='(@(DUE<VUA(&UO;&1U<F$@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM
M<V=S='(@(D5S=&%D;R!);F1E<&5N9&5N=&4@9&$@4V%M;V$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")386X@36%R:6YO(@IM<V=S='(@(E)E</IB;&EC82!397)E;NUS<VEM82!D
M92!3XV\@36%R:6YO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E
M(@IM<V=S='(@(E/C;R!4;VWI(&4@4'+M;F-I<&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*
M;7-G<W1R(")&;W)N96-E9&]R(&1O(%-A=.EL:71E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U
M9&D@07)A8FEA(@IM<V=S='(@(D%RX6)I82!3875D:71A(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@
M(D=U87)D87(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(D=U87)D87(@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@)R5S)R(*;7-G<W1R(")'=6%R9&%R
M("<E<R<B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3
M879E($]P=&EO;G,B"FUS9W-T<B`B1W5A<F1A<B!/<.?U97,B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<P"FUS9VED("(B"B)3879E(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E
M<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(D=U87)D
M87(@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(%PB<V-R:7!T7"(@4$A0
M(&YO(&1I<F5C=/-R:6\@=&5M<&]RX7)I;R`B"B)D;R!S974@<V5R=FED;W(N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1W5A
M<F1E:2!C;VYF:6=U<F'GXV\@)7,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B1W5A<F1E:2!O(%PB
M<V-R:7!T7"(@9&4@86-T=6%L:7IAY^-O(&5M.B!<(B5S7"(N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C
M871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")496UP;W)A:7,M5"!$:7-P97)S
M;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N
M8V4B"FUS9W-T<B`B0VGJ;F-I82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B4')O8W5R87(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C<X"FUS9VED(")396%R8V@@16YG:6YE<R(*
M;7-G<W1R(")-;W1O<F5S(&1E(%!R;V-U<F$B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,30T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8VAI;F<@2&]R
M9&4@87!P;&EC871I;VYS(&EN("5S(@IM<V=S='(@(E!R;V-U<F%N9&\@87!L
M:6-AY_5E<R`H;?-D=6QO<RD@2&]R9&4@96T@)7,B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3(S"FUS9VED(")396%R8VAI;F<@9V5T=&5X="!B:6YA<FEE
M<RXN+B(*;7-G<W1R(")0<F]C=7)A;F1O(&]S(&)I;N%R:6]S(&1E(&=E='1E
M>'0N+BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDW,@IM<V=I9"`B4V5L
M96-T($9I;&5S(@IM<V=S='(@(E-E;&5C8VEO;F%R($%R<75I=F]S(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B
M4V5L96-T(&$@9&%T92(*;7-G<W1R(")396QE8V-I;VYE('5M82!D871A(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C
M="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")396QE8V-I;VYE('5M(&=R=7!O
M(&$@86-R97-C96YT87(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4V5L96-C
M:6]N87(@=6T@;F]V;R!D;VYO(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B4V5L
M96-C:6]N92!U;2!S97)V:61O<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R
M(")396QE8V-I;VYE('5M('5T:6QI>F%D;W(@82!A9&EC:6]N87(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C8V,@IM<V=I9"`B4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N(@IM<V=S='(@(E-E;&5C8VEO;F4@=&]D;W,@;W,@8V]M
M<&]N96YT97,@9&$@9&%T82XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#$Q"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S
M='(@(E-E;&5C8VEO;F4@=6T@;V)J96-T;R(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S
M='(@(B(*(E-E;&5C8VEO;F4@;W,@8V%R86-T97)E<R!N87,@8V%I>&%S(&%B
M86EX;RX@4&]D97+A(&5N=.-O(&-O<&GA+6QO<R!E(&-O;.$M(@HB;&]S(&YA
M(.%R96$@9&4@=&5X=&\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@
M(E-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D82!D871A.B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D82!D871A
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.#D*
M;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.B(*;7-G<W1R(")396QE8V-I;VYE(&$@:61E;G1I9&%D92!Q=64@<')E=&5N
M9&4@86QT97)A<CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L
M96-C:6]N92!O(&1E;&EM:71A9&]R(&1A<R!H;W)A<SHB"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O
M<FUA=#HB"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@:&]R83HB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8T"FUS9VED(")396QE
M8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4V5L96-C:6]N92!D
M;VES(&-A;7!O<R!R96QA8VEO;F%D;W,N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Y.`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*
M;7-G<W1R(")%<V-O;&AA(&\@<V5U(&-O;FIU;G1O(&1E(&-O<F5S+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#`*;7-G:60@(E-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B4V5L96-C:6]N92!O('-E
M=2!I9&EO;6$@<')E9F5R:61O.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S
M='(@(D5N=FEA<B!296QA=/-R:6\@9&4@4')O8FQE;6%S(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,0IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`B16YV:6%R(%--4R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS
M9W-T<B`B4F5P^F)L:6-A(&1O(%-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(%-E;G-O<CH@
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E
M<'1E;6)E<B(*;7-G<W1R(")3971E;6)R;R(*"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R
M;R(*;7-G<W1R(")3Z7)V:6$@92!-;VYT96YE9W)O(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS
M9W-T<B`B3OIM97)O(&1E(%/I<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$T.`IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B1&%D;W,@9&\@<V5R=FED;W(@97)R861O
M<R!O=2!I;F1I<W!O;NUV96ES+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM
M<V=S='(@(DE$(&1E('-E<W/C;R!E>'!I<F]U+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S$S"FUS9VED(")3970B"FUS9W-T<B`B071R:6)U:7(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB17-T86)E;&7G82!O<.?U97,@
M<75E(&QH92!P97)M:71A;2!R96EN:6-I87(@82!S=6$@<&%L879R82UP87-S
M92!S92!A;&=U;6$@(@HB=F5Z(&1E;&$@<V4@97-Q=65C97(N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN(@IM<V=S='(@(D5S<&5C:69I8V%R('-E<G9I9&]R97,@<F5M;W1O<R!Q
M=64@9&5S96IA(&%C961E<B!N;R!S974@<&]R=&%L+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("(B
M"B)396QE8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F97)I9&\L(&\@<V5U(&9U
M<V\@:&]RX7)I;R!E(&%S('-U87,@;W#G]65S(&1E("(*(F1A=&%S+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@
M(B(*(D5S8V]L:&$@82!S=6$@87!L:6-AY^-O(&EN:6-I86PL(&\@97-Q=65M
M82!D92!C;W)E<RP@;R!R969R97-C86UE;G1O(&1E("(*(G#A9VEN87,@92!O
M=71R87,@;W#G]65S(&1E('9I<W5A;&EZ8>?C;RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<T"FUS9VED(")3971U<"(*;7-G<W1R(")#;VYF:6=U
M<F%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,SD*
M;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T
M<B`B7")38W)I<'1S7"(@9&4@86-T=6%L:7IAY^-O(&1I<W!O;NUV96ES(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-`IM<V=I9"`B4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B
M"FUS9W-T<B`B5N%R:6%S(&QO8V%L:7IAY_5E<R!P;W-S[79E:7,@8V]M(&\@
M<&%RXFUE=')O.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E
M:6-H96QE<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3$*;7-G
M:60@(E-H;W!P:6YG(@IM<V=S='(@(D-O;7!R87,B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*
M;7-G<W1R(")"<F5V92!3=6WA<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0S.`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(D1E=F5M+7-E(&1E9FEN:7(@=&5C
M;&%S(&1E(&%C97-S;R!P87)A(&$@;6%I;W)I82!D87,@;&EG8>?U97,_(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.3(@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B
M"FUS9W-T<B`B36]S=')A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-3@*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HB36]S=')A<B!D:69E<F5NYV%S(&5N=')E(&$@
M8V]N9FEG=7)AY^-O(&=U87)D861A(&4@87%U92!F;VD@86=O<F$@9V5R861A
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#(*;7-G:60@(E-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B36]S
M=')A<B!M;VUE;G1O(&1A(/IL=&EM82!E;G1R861A(&YO('-I<W1E;6$_(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C8*;7-G:60@(E-H;W<@;W!T:6]N
M('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B36]S=')A<B!O<.?C;R!P87)A
M('!R97-E<G9A<B!O(&]R:6=I;F%L(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(X,3(*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(DUO<W1R87(@<&%L
M971E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")-;W-T<F%R
M(&$@8F%R<F$@9&4@;65N=2!C;VT@87,@;W!E<F'G]65S('-O8G)E('1A8F5L
M87,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G
M<W1R(")-;W-T<F%R(&\@365N=2`E<R#@(&5S<75E<F1A/R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(")-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I
M961A9&5S(&1E($/I;'5L87,@9&4@5&%B96QA/R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S
M=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!4
M86)E;&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S=')A<B!A(&-A:7AA(&1E(&1I
MX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!,:6YH87,@9&4@5&%B96QA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4Q"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R(")-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O
M<')I961A9&5S(&1E($EM86=E;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-S8T"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")-;W-T<F%R(&-A<G)E
M9V%M96YT;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(D%G=6%C96ER;W,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I
M9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")!9W5A8V5I<F]S($UA=&EN86ES
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*
M;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")!9W5A8V5I<F]S(%9E<W!E
M<G1I;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@
M(D%G=6%C96ER;W,@;F$@5FEZ:6YH86[G82(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C,Y.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(D5N8V]L
M:&5R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-CDR(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C<U-`HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HX,3(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#<T
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDP.2!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HY-#8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z.3<T(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P,#0*;7-G
M:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")%;F-O;&AA(&]U(&UO=F$@;RAS
M*2!B;&]C;RAS*2!V:7II;FAO*',I('!R:6UE:7)O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE
M<G)A($QE;VYE(@IM<V=S='(@(E-E<G)A($QEXV\B"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")3
M=6)S8W)E=F5R(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,@IM
M<V=I9"`B4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9"(*;7-G<W1R(")3=6)S
M8W)E=F$L('-E(&%I;F1A(&[C;R!E<W3A(')E9VES=&%D;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS
M9W-T<B`B07-S:6YA='5R82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L
M9V]R:71M;R!D92!!<W-I;F%T=7)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM
M<V=S='(@(E)E</IB;&EC82!D92!3:6YG87!U<F$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.#DV(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C,W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0W(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3(Y(&QI8B](;W)D92]&;W)M+G!H<#HS,3(R
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8U(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE(@IM<V=S='(@(E1A;6%N:&\B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B4V%L=&%R($UA
M;G5T96[GXV\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,Q('!O+W1R86YS
M;&%T:6]N+G!H<#HT.#0@<&\O=')A;G-L871I;VXN<&AP.C8V-@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.#8P('!O+W1R86YS;&%T:6]N+G!H<#HQ,C(S"FUS
M9VED(")3:VEP<&5D+BXN(@IM<V=S='(@(D[C;R!P<F]C97-S861O+BXN(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B17-L;W;A<75I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-L;W9E;FEA(@IM<V=S='(@(E)E</IB;&EC82!D82!%<VQO=NEN:6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM
M<V=I9"`B4VYO=R(*;7-G<W1R(").979E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM
M<V=S='(@(DYE=N-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(").97;U
M97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(DYE=O5E<R!-
M871I;F%I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(").97;U
M97,@5F5S<&5R=&EN;W,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM
M<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(D%L='5R82!D92!N979E.B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I
M=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B36]S=')A<B!E<75I=F%L96YT
M92!N82#A9W5A.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T
M<B`B26QH87,@4V%L;VWC;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B
M4V]MX6QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B
M4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")#86[G]65S(&4@4&]E;6%S(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,C4*;7-G:60@(E-O<G0@;W)D97(@<V5L
M96-T:6]N(@IM<V=S='(@(E-E;&5CY^-O(&1O('-E;G1I9&\@9&$@;W)D96YA
MY^-O(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.2!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C0W"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G
M<W1R(")%;F1E<F7G;R!D92!O<FEG96TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I
M8V$B"FUS9W-T<B`BP69R:6-A(&1O(%-U;"(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB
M"FUS9W-T<B`B175R;W!A(&1O(%-U;"`H25-/+3@X-3DM,RDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@
M(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M(@IM<V=S='(@(D=E\W)G:6$@9&\@4W5L(&4@26QH87,@4V%N9'=I8V@@9&\@
M4W5L(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")(
M96UI<V;I<FEO(%-U;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS(@IM<V=S='(@(D5S<&'G;R!E;G1R92!CZ6QU;&%S(&%D:F%C96YT
M97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;"(*;7-G<W1R(")%<W!AYV\@96YT<F4@;R!C;VYT9?ID;R!E(&$@
M8F]R9&$@9&4@=6UA(&/I;'5L82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX
M,34*;7-G:60@(E-P86-E<B(*;7-G<W1R(")%<W!AYV%D;W(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G
M:60@(E-P86-I;F<B"FUS9W-T<B`B17-P8>=A;65N=&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED
M(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(D5S<&'G86UE;G1O(&4@
M96YC:&EM96YT;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")296EN;R!D92!%
M<W!A;FAA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED
M(")3<&%M(@IM<V=S='(@(D-O<G)E:6\@;N-O('-O;&EC:71A9&\B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R($EN<'5T(@IM<V=S='(@(DEN<V5R:7(@0V%R86-T97(@17-P96-I86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(D1I=FED:7(@8^EL
M=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(D%D:6-I
M;VYA<B!C;VQU;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B
M1&EV:61I<B!L:6YH82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(D1E<W!O<G1O<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I
M($QA;FMA(@IM<V=S='(@(E)E</IB;&EC82!$96UO8W+A=&EC82!3;V-I86QI
M<W1A(&1O(%-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV-2!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R(")0861RXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P
M.`IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!;F\@9&4@:6[M8VEO(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E
M(&]R(%!R;W9I;F-E(@IM<V=S='(@(D5S=&%D;R!O=2!0<F]V[6YC:6$B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B
M4W1A='5S(@IM<V=S='(@(E-T871U<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HT.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W1A='5S(&9O<B!L;V-A;&4@
M)7,N+BX@(@IM<V=S='(@(D5S=&%D;R!D82!L;V-A;&EZ8>?C;R`E<RXN+B`B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q-`IM<V=I9"`B4W1O<F%G92!F
M;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D92!A<FUA>F5N86UE;G1O(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O(&1E(%)U82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK
M971H<F]U9V@B"FUS9W-T<B`B4F%S=7)A9&\B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B3&ES=&$@
M9&4@8V%D96EA<R!D92!C87)A8W1E<F5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S0*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(E)E=&ER87(@9&]M[6YI;R!D;R!E;F1E<F7G;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*
M;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(D5S=&EL;R!;0U-372(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G
M:60@(E-U(@IM<V=S='(@(F1O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B07-S=6YT
M;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(@;&EB+TAO<F1E+T9O<FTO
M4F5N9&5R97(N<&AP.C,Q,@IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E-U8FUE
M=&5R(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(D9O:2!S=6)M971I9&\@
M<&5D:61O('!A<F$@861I8VEO;F%R(%PB)7-<(B!A;R!S:7-T96UA+B!.XV\@
M<&]D97+A(&5N=')A<B`B"B)E;G%U86YT;R!O('-E=2!P961I9&\@;N-O(&9O
M<B!A<')O=F%D;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B26YF97)I
M;W(@X"!L:6YH82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(E-U8V5S<V\B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!A9&EC:6]N
M861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@HB3&EM<&5Z82!D;R!S:7-T96UA(&1O<R!D861O<R!D;R!U=&EL
M:7IA9&]R(%PB)7-<(B!R96%L:7IA9&$@8V]M('-U8V5S<V\N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HX,2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<
M(BXB"FUS9W-T<B`B4F5M;^?C;R!D92!<(B5S7"(@8V]M('-U8V5S<V\N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(E)E;6_GXV\@9&4@7"(E<UPB(&1O('-I<W1E;6$@8V]M('-U8V5S
M<V\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S
M964@8VAA;F=E<RXB"FUS9W-T<B`B0V]N9FEG=7)AY^-O(')E=F5R=&ED82!C
M;VT@<W5C97-S;RX@4F5C87)R96=U92!P87)A('9E<B!A<R!M=61A;N=A<RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-34*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0V]N9FEG=7)AY^-O(&1E('-A;'9A
M9W5A<F1A(&=U87)D861A(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(")&:6-H96ER;R!D92!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R
M9&$@)7,@9W5A<F1A9&\@8V]M('-U8V5S<V\N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A
M=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@86-T=6%L:7IA9&\@8V]M('-U
M8V5S<V\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@97-C<FET;R!C;VT@<W5C97-S
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E)E</IB;&EC82!D;R!3=63C
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4F5S=6UO(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8V"FUS9VED(")3=6X@4FES92(*;7-G
M<W1R(").87-C97(@9&\@4V]L(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C<Q"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(E#T<B!D;R!3;VPB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B
M4W5N;GDB"FUS9W-T<B`B4V]L87)E;F=O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES92(*;7-G<W1R(").87-C
M97(@9&\@4V]L(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G
M<W1R(").87-C97(O4/1R(&1O(%-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#,*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(").87-C
M97(@9&\@4V]L.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`W"FUS9VED(")3=6YS970B"FUS9W-T<B`B4/1R(&1O(%-O;"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#8*;7-G:60@(E-U;G-E=#H@
M(@IM<V=S='(@(E#T<B!D;R!3;VPZ("(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM
M<V=S='(@(E-U<&5R:6]R(.`@;&EN:&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0S"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E-U<&]R=&4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")3=7)N86UE(@IM
M<V=S='(@(D%P96QI9&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(E-V86QB87)D(&4@2F%N($UA>65N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B
M4W=A>FEL86YD(@IM<V=S='(@(E)E:6YO(&1A(%-U87II;.)N9&EA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W=E9&5N(@IM<V=S='(@(E)E:6YO(&1A(%-UZ6-I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=>WG82(*"B,Z(&QI8B](;W)D92]3
M44PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(D5R<F\@9&4@<VEN=&%X92!N;W,@=&5R;6]S
M(&1E('!R;V-U<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*
M;7-G<W1R(")297#Z8FQI8V$@P7)A8F4@4^UR:6$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*
M;7-G<W1R(")496UP;W)A;"U4(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM
M<V=S='(@(E1E;7!O<F%L+50@92!696YT;W-O(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM
M<V=S='(@(E1E;7!O<F%I<RU4(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S
M='(@(E1E;7!O<F%I<RU4($UA=&EN86ES(@H*(SH@;&EB+TAO<F1E+T1A=&$O
M='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(D%R<75I=F\@
M5%-6(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S8*;7-G:60@(E1A
M8FQE(@IM<V=S='(@(E1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E
M<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A(%1A8F5L82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*
M;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S
M(&1A('1A8F5L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T
M<B`B1F]R;6]S82(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B
M1F]R;6]S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B4F5P^F)L
M:6-A(&1O(%1A9&II<75I<W3C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>N)N:6$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G
M970Z(@IM<V=S='(@(D%L=F\Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$W,PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5&%R969A<R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!496QE9F]N92(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R(")496UP97)A='5R82!D82#Z;'1I;6$@:&]R83HB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`B5&5M<&5R871U<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$Q"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E
M<F%T=7)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R871U<F$\8G(@+SXH
M)7-!;'1A)7,O)7-"86EX825S*2`F9&5G.R5S(@H*(SH@;&EB+TAO<F1E+U1E
M;7!L871E+G!H<#HR,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3R!M;V1E;&\@7"(E<UPB(&[C
M;R!F;VD@96YC;VYT<F%D;RXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V
M.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M
M:6YI<W1R8>?C;R!D92!-;V1E;&]S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R,3$*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X=&\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S8W"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M07!E;F%S(%1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R
M(")!;&EN:&%M96YT;R!D;R!T97AT;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T
M<B`B5&]P;R!D;R!T97AT;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(C6J(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I
M(@IM<V=S='(@(E1A:6QA;F3J<R`H5$E3+38R,"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I
M;&%N9"(*;7-G<W1R(")296EN;R!D82!486ELXFYD:6$B"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z.3(S"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H
M92!S>7-T96TN(@IM<V=S='(@(D]B<FEG861O('!O<B!U<V%R(&5S=&4@<VES
M=&5M82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@)7,@:&5L<"!F:6QE(&9O<B`E<R!D;V5S;B=T('EE
M="!E>&ES="X@0W)E871I;F<@82!N97<@;VYE+B(*;7-G<W1R(")/(&%R<75I
M=F\@9&4@86IU9&$@)7,@<&%R82`E<R!NXV\@97AI<W1E(&%I;F1A+B!#<FEA
M;F1O('5M(&YO=F\N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<S-PIM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N[79E;"XB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDP,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@7"(E<UPB(@IM<V=S='(@(D\@96YG96YH;R!D92!I;G1E9W)AY^-O($AO
M<F1E+TMO;&%B(&[C;R!S=7!O<G1A(%PB)7-<(B(*"B,Z(&QI8B].970O24U3
M4"]";V]K+G!H<#HQ,CDT"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T
M(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(")/(')E9VES=&\@*%PB;&]G7"(I
M($E-4U`@;N-O('#T9&4@<V5R(&EN:6-I86QI>F%D;RXB"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,CD*;7-G:60@(E1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B02!C
M;&%S<V4@36%I;G1E;F%N8V4Z.B!NXV\@9F]I(&-A<G)E9V%D82!C;VT@<W5C
M97-S;R(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*
M;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+B(*;7-G<W1R(")!(&IA;F5L82!D92!/<.?U97,@9F5C:&]U+B!38>UN9&\N
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ-3@@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HQ-CD@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ.#`*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HQ.3(@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#,@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HR,C$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S,@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HR-S(*;7-G:60@(B(*(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N
M<RXB"FUS9W-T<B`B(@HB3R!A9&UI;FES=')A9&]R('1E;2!D92!C;VYF:6=U
M<F%R('5M(&UE8V%N:7-M;R!D92!P97)M:7-S]65S('!E<FUA;F5N=&4@<V4@
M(@HB<75I<V5R('5S87(@4&5R;6ES<_5E<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@
M8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")!<&5N87,@;R!L861O(&EN9F5R
M:6]R(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM
M<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A
M=&%B87-E+B(*;7-G<W1R("(B"B)/(&[Z;65R;R!D92!)1"!D;R!C;VYT86-T
M;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@9F]I(&1E:7AA9&\@96T@8G)A;F-O
M(&]U("(*(F[C;R!F;VD@96YC;VYT<F%D;R!N82!B87-E(&1E(&1A9&]S+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@
M(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(D\@8V]N=&%C=&\@9F]I(&%D:6-I;VYA
M9&\@X"!L:7-T82!D92!C;VYT86-T;W,@8V]M('-U8V5S<V\N(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$T.0IM<V=I9"`B(@HB5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB3R!B;&]C;R!D92!A
M<W-I;F%T=7)A(%!'4"!D97-T86-A9&\@Z2!N96-E<W/A<FEO('!A<F$@=F5R
M:69I8V%R('5M82!M96YS86=E;2`B"B)A<W-I;F%D82XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM
M<V=S='(@(B(*(D\@240@9&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F
M;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E;2!B<F%N8V\@;W4@(@HB
M;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@9&%D;W,N(@H*(R!C+69O
M<FUA=`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS
M9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M(@IM<V=S='(@(D$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P
M96-I9FEC861A+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z,3$S"FUS9VED
M(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R(")!<R!F=6YC:6]N86QI9&%D97,@9&4@
M96YC<FEP=&'GXV\@97AI9V5M('5M82!L:6=AY^-O('-E9W5R82XB"@HC.B!L
M:6(O2&]R9&4N<&AP.C$W-2!L:6(O2&]R9&4N<&AP.C0X.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N(@IM<V=S='(@(D\@87)Q=6EV;R`E<R!D979E<FEA(&-O;G1E<B!U
M;2!A=')I8G5T;R`E<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$V."!L:6(O2&]R
M9&4N<&AP.C0W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")/(&%R
M<75I=F\@)7,@9&5V97)I82!C;VYT97(@86QG=6YS(&%T<FEB=71O<R`E<RXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$U,@IM<V=I9"`B5&AE(&9I;&4@8V%N
M(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(D\@9FEC:&5I
M<F\@;N-O('!O9&4@<V5R(&-O<&EA9&\@<&%R82!S:2!P<O-P<FEO+B(*"B,Z
M(&QI8B](;W)D92]$871A+G!H<#HR-C`*;7-G:60@(E1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R(")/(&9I8VAE:7)O(&[C;R!C;VYTZ6T@
M9&%D;W,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(D%B86EX;R!E
M<W3C;R!O<R!C86)EYV%L:&]S(&1E<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F
M8S@R,BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E
M<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E
M;B!E9&ET;W(N(@IM<V=S='(@(B(*(D\@;6]D;R!D92!E8W+C(&EN=&5I<F\@
M8V%U<V$@<')O8FQE;6%S(&YO($EN=&5R;F5T($5X<&QO<F5R+"!D979I9&\@
M82!E<G)O<R`B"B)N;R!N879E9V%D;W(@<75E(&[C;R!C;VYS96=U:6UO<R!U
M;'1R87!A<W-A<BX@(%!O9&4@<W5R9VER(&QI>&\L('!O9&5M("(*(F1E<V%P
M87)E8V5R(&9U;F-I;VYA;&ED861E<R!D;R!E9&ET;W(@92]O=2!O('-E=2!N
M879E9V%D;W(@<&]D92!A8F]R=&%R+B!392`B"B)O('-E=2!S:7-T96UA(.D@
M=6T@5VEN9&]W<R`Y>"P@Z2!M=6ET;R!P<F]VX79E;"!Q=64@;V)T96YH82!U
M;2`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!E('!R96-I<V4@9&4@
M<F5I;FEC:6%R(&\@<VES=&5M82Y<7&Y<7&Y&;VD@879I<V%D;RX@(%!O<B`B
M"B)F879O<B!P<F5S<VEO;F4@3TL@<V4@86EN9&$@87-S:6T@<75I<V5R(&5X
M<&5R:6UE;G1A<B!O(&5D:71O<B!D92!E8W+C("(*(FEN=&5I<F\N(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P.3<@<&\O=')A;G-L871I;VXN<&AP.C$R
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&AE;'`@9FEL92`E<R!D:61N
M)W0@<W1A<G0@=VET:"`\/WAM;"(*;7-G<W1R(")/(&9I8VAE:7)O(&1E(&%J
M=61A("5S(&[C;R!C;VUEYV$@8V]M(#P_>&UL(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B02!I9&5N=&ED861E
M(%PB)7-<(B!F;VD@<F5M;W9I9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B07!E;F%S(&\@;&%D;R!E<W%U97)D
M;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$T-@IM<V=I9"`B(@HB
M5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E
M;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*(D$@;&]C
M86QI>F'GXV\@9&\@87)Q=6EV;R!E>&5C=73A=F5L(&1E($=N=5!'('1E;2!D
M92!S97(@:6YD:6-A9&$@X"!C;&%S<V4@(@HB0W)Y<'1?<&=P.CHN(@H*(SH@
M;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE
M8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)!(&UE;G-A9V5M(&5N=FEA9&$@96T@
M)7,@<&%R82`E<R!C;VT@87-S=6YT;R!<(B5S7"(@9F]I(&UO<W1R861A+EQN
M(@HB3N-O(&CA(&=A<F%N=&EA(&1E('%U92!A(&UE;G-A9V5M('1E;FAA('-I
M9&\@<F5A;&UE;G1E(&QI9&$@;W4@8V]M<')E96YD:61A+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<X"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3R!N;VUE
M(&$@=7-A<B!Q=6%N9&\@;&EG86YD;R#@('#A9VEN82!D92!C;VUP;W-IY^-O
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")/(&WS9'5L;R!O<&5N<W-L
M(.D@;F5C97-SX7)I;R!P87)A(&$@8VQA<W-E($AO<F1E7T-R>7!T7W-M:6UE
M.CHN(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI
M;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(D$@;W#GXV\@7"(E<UPB
M(&[C;R!P]&1E('-E<B!G=6%R9&%D82P@<&]I<R!O<R!S975S(&1A9&]S(&5X
M8V5D96T@82!D:6UE;G/C;R`B"B)MX7AI;6$@<&5R;6ET:61A(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H
M<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M(@IM<V=S='(@(B(*(D\@<')O9W)A;6$@=7-A9&\@<&%R82!V97(@97-T92!T
M:7!O(&1E(&1A9&]S("@E<RD@;N-O(&9O:2!E;F-O;G1R861O(&YO("(*(G-I
M<W1E;6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'DB"FUS9W-T<B`B07!E;F%S(&]S(&QA9&]S(&5S<75E<F1O(&4@9&ER
M96ET;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R(")!<&5N87,@;R!L861O(&1I<F5I=&\B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")/('-E
M<G9I9&]R(%PB)7-<(B!F;VD@<F5M;W9I9&\N(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E
M<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(D\@<V5R=FED
M;W(@7"(E<UPB(&9O:2!G=6%R9&%D;RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")/('!E9&ED;R!D92!S
M=6)S8W)IY^-O(&1E("5S(&9O:2!R96UO=FED;RXB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HR.3`*;7-G:60@(E1H92!S<&5C:69I960@<F]W
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!(&QI;FAA(&EN9&EC861A(&[C
M;R!E>&ES=&4N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R(")/(&%R<75I=F\@=&5M<&]RX7)I;R!<(B5S7"(@
M;N-O(&5X:7-T92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>2(*;7-G<W1R(")!<&5N87,@;W,@;&%D;W,@<W5P97)I;W(@
M92!I;F9E<FEO<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM
M<V=S='(@(D%P96YA<R!O(&QA9&\@<W5P97)I;W(B"@HC.B!L:6(O2&]R9&4O
M1&%T82YP:'`Z,S`W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B3W,@9&%D;W,@
M8V%R<F5G861O<R!P97)D97)A;2US92!D97-D92!O('!A<W-O(&%N=&5R:6]R
M+B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C0P(&QI8B](;W)D92]$
M871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D\@87)Q=6EV;R!C87)R96=A9&\@
M;N-O('#T9&4@<V5R(&=U87)D861O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3`Y
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B3R!B;&]C;R!W96%T:&5R+F-O;2!NXV\@97-TX2!D:7-P
M;V[M=F5L+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS9VED
M(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(D[C
M;R!HX2!O<.?U97,@9&ES<&]N[79E:7,N(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C,T,0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D[C;R!HX2!P
M87)T97,@<75E('!O<W-A;2!S97(@;6]S=')A9&%S(&5M(&QI;FAA+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`S"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)(X2!D96UA<VEA
M9&]S(&-A<F%C=&5R97,@;F5S=&4@8V%M<&\N($EN=')O9'5Z:74@)7,@8V%R
M86-T97)E<SL@=&5M(&1E("(*(FEN=')O9'5Z:7(@;65N;W,@9&\@<75E("5S
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8P"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E(&1O97-N)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O
M<B`E<RXB"FUS9W-T<B`B3N-O(&5X:7-T92!A:6YD82!U;2!A<G%U:79O(&1E
M(&%J=61A('!A<F$@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R
M+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B
M3V-O<G)E=2!U;2!P<F]B;&5M82!N82!A9&GGXV\@9&4@7"(E<UPB(&%O('-I
M<W1E;6$Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F
M;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB
M3V-O<G)E=2!U;2!P<F]B;&5M82!A;R!L:6UP87(@;W,@9&%D;W,@9&\@=71I
M;&EZ861O<B!<(B5S7"(@9&\@<VES=&5M82XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B
M3V-O<G)E=2!U;2!P<F]B;&5M82!N82!R96UOY^-O(&1E(%PB)7-<(B!D;R!S
M:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B3V-O<G)E=2!U;2!P<F]B;&5M82!A;R!A8W1U86QI>F%R
M(%PB)7-<(CH@)7,N(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@
M(B(*(DAO=79E('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M96YT;R!D;R!F
M:6-H96ER;SH@)7,@;N-O(&9O:2!C87)R96=A9&\N(@H*(SH@;&EB+TAO<F1E
M+T)R;W=S97(N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H
M)60@8GET97,I+B(*;7-G<W1R("(B"B)/8V]R<F5U('5M('!R;V)L96UA(&-O
M;2!O(&-A<G)E9V%M96YT;R!D;R!A<G%U:79O.B!/("5S(&5X8V5D92!O('1A
M;6%N:&\@(@HB;>%X:6UO('!E<FUI=&ED;R`H)60@8GET97,I+B(*"B,Z(&QI
M8B](;W)D92]"<F]W<V5R+G!H<#HX.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B
M(@HB3V-O<G)E=2!U;2!P<F]B;&5M82!C;VT@;R!C87)R96=A;65N=&\@9&\@
M87)Q=6EV;SH@3R`E<R!F;VD@87!E;F%S("(*(G!A<F-I86QM96YT92!C87)R
M96=A9&\N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!A;R!M;W-T
M<F%R(&5S=&$@<&%R=&4@9&$@;65N<V%G96TB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,Y(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O
M(&%O(&EM<&]R=&%R(&1A9&]S(&1E(&-O;G1A8W1O+B(*"B,Z(&QI8B](;W)D
M92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")/8V]R<F5U
M('5M(&5R<F\@86\@:6UP;W)T87(@9&%D;W,@:4-A;&5N9&%R+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-SD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)/
M8V]R<F5U('5M(&5R<F\@;F\@9F]R;75LX7)I;R!D92!C;VYF:6=U<F'GXV\N
M(%1A;'9E>B!T96YH82!O;6ET:61O('5M(&-A;7!O("(*(F]B<FEG873S<FEO
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3`W('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,3$S('!O+W1R86YS;&%T:6]N+G!H<#HQ,C0U"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN
M9R!T<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@(@HB9FQA9R`M9"!T;R!S964@
M86YY(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S97(N(@IM<V=S
M='(@(B(*(D]C;W)R974@=6T@97)R;R!A;R!A8G)I<B!O(&%R<75I=F\@)7,N
M($5X<&5R:6UE;G1E(&5X96-U=&%R('1R86YS;&%T:6]N+G!H<"`B"B)C;VT@
M82!O<.?C;R`M9"!P87)A(&-O;G-E9W5I<B!V97(@87,@;65N<V%G96YS(&1E
M(&5R<F\@9&\@86YA;&ES861O<B!834PN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(D]C;W)R974@=6T@97)R;R!A;R!R96%L:7IA<B!A(&9U;N?C;R!D92!L:79R
M;R!D92!E;F1E<F7G;W,@97-P96-I9FEC861A+B!0;W(@(@HB9F%V;W(@=&5N
M=&4@9&4@;F]V;R!M86ES('1A<F1E+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"B)/8V]R<F5U('5M(&5R<F\@86\@86-T
M=6%L:7IA<B!O<R!P;W)M96YO<F5S(&1O(&-O;G1A8W1O+B!0;W(@9F%V;W(@
M=&5N=&4@9&4@(@HB;F]V;R!M86ES('1A<F1E+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D]C;W)R974@=6T@97)R
M;R!A;R!A8W1U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B!0;W(@
M9F%V;W(@=&5N=&4@9&4@(@HB;F]V;R!M86ES('1A<F1E+B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!
M4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM
M<V=S='(@(D5S=&4@<V5R=FED;W(@24U!4"!NXV\@<W5P;W)T82!P87)T:6QH
M82!D92!P87-T87,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(D[C;R!P87)E8V4@<V5R('5M(&%R
M<75I=F\@<F%R(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B3N-O('!A<F5C92!S97(@=6T@
M87)Q=6EV;R!Z:7`@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,30T"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C
M87)D(&YU;6)E<BXB"FUS9W-T<B`B3N-O('!A<F5C92!S97(@=6UA(&[Z;65R
M;R!D92!C87)TXV\@=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"B)%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@
M;R!E;G9I;R!D92!M96YS86=E;G,@871R87;I<R!D;R!#;&EC:V%T96QL("AH
M='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI+"!U<V%N9&\@82!!4$D@2%144"(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%<W1E
M(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@871R
M87;I<R!D;R!S;7,R;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI+"!U
M<V%N9&\@82!!4$D@2%144"(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(D5S
M=&4@8V]N=')O;&%D;W(@<&5R;6ET92!O(&5N=FEO(&1E(&UE;G-A9V5N<R!V
M:6$@4TU44"!A=')A=NES(&1A(%9O9&%F;VYE("(*(DETX6QI82!E(&%P96YA
M<R!P87)A(&[Z;65R;W,@5F]D869O;F4N($5X:6=E('5M82!C;VYT82!D92!C
M;W)R96EO("(*(F5L96-T<O-N:6-O(&YA(%9O9&%F;VYE($ETX6QI82`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-S@@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-38*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S,#4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$U-3D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-#`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S`@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P-SD@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3`*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R,C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#D@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T-3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-38@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,S8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,W,C,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,W,S$*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(D5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R(")%<W1E(&-A;7!O('!O9&4@8V]N=&5R
M(&%P96YA<R!I;G1E:7)O<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q
M-PIM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B17-T92!C86UP;R!P;V1E(&%P96YA
M<R!C;VYT97(@;OIM97)O<R!E(&\@<^UM8F]L;R!D;VES+7!O;G1O<RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B17-T92!C
M86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O8W1A:7,N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@=&5M(&1E(&-O;G1E<B!U;6$@
M;&ES=&$@9&4@:6YT96ER;W,@<V5P87)A9&]S('!O<B!E<W!AYV]S(&]U("(*
M(G;M<F=U;&%S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#D*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B
M17-T92!C86UP;R!T96T@9&4@<V5R('5M(&[Z;65R;R!VX6QI9&\N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S4*;7-G:60@(B(*(E1H:7,@9FEE;&0@
M;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M
M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HB17-T
M92!C86UP;R!T96T@9&4@8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@;F\@9F]R
M;6%T;R!21T(@:&5X861E8VEM86PL('!O<B`B"B)E>&5M<&QO("<C,3(S-&%F
M)RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D5S=&4@
M;6]D96QO(&KA(&9O:2!P<F]C97-S861O+B(*"B,Z('1E;7!L871E<R]H96QP
M+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N
M(@IM<V=S='(@(DES=&\@Z2`E<RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H
M92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@
M96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB
M17-T92#I('5M(&]B:F5C=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!E
M<W1E(&]B:F5C=&\@<')E8VES82!D92!U;2`B"B)C;&EE;G1E(&1E(&-O<G)E
M:6\@96QE8W1R\VYI8V\@<75E(&-O;FAEYV$@;R!F;W)M871O($MO;&%B($=R
M;W5P=V%R92X@4&%R82`B"B)U;6$@;&ES=&$@9&4@8VQI96YT97,@9&4@8V]R
M<F5I;R!E;&5C='+S;FEC;R!N97-S87,@8VER8W5N<W3B;F-I87,@=FES:71E
M("5S(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4X.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B17-T82!M96YS86=E;2!F;VD@97-C<FET82!N=6T@8_-D:6=O("@E
M<RD@9&EF97)E;G1E(&1O('-E=2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N(@IM<V=S='(@(D5S=&4@;OIM97)O('!R96-I<V$@9&4@<V5R('!E;&\@
M;65N;W,@=6TN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,#0*;7-G:60@
M(E1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN
M92XB"FUS9W-T<B`B17-T92!<(G-C<FEP=%PB('1E;2!S97(@97AE8W5T861O
M(&$@<&%R=&ER(&1E('5M82!L:6YH82!D92!C;VUA;F1O<RXB"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R
M(")%<W1E('-E<G9I9&]R(&[C;R!C;VYS96=U92!D97-C;VUP<FEM:7(@87)Q
M=6EV;W,@>FEP(&]U(&=Z:7`N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H
M<#HQ-#<*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"XB"FUS9W-T<B`B17-T92!S:7-T96UA(&5N8V]N=')A+7-E(&1E<V%C
M=&EV861O+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D5S=&$@
M=F%L;W(@=&5M(&1E('-E<B!U;2!N^FUE<F\N(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")%
M<W1A(&IA;F5L82!T96T@9&4@<V5R(&-H86UA9&$@82!P87)T:7(@9&4@=6UA
M(&IA;F5L82!D92!/<.?U97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")4<F]V
M;V%D82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C(*;7-G:60@
M(E1I8VME=',B"FUS9W-T<B`B0FEL:&5T97,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C0R-PIM<V=I9"`B5&EM92(*;7-G<W1R(")$871A+TAO<F$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`X"FUS9VED(")4:6UE(%1R
M86-K:6YG(@IM<V=S='(@(E-E9W5I;65N=&\@5&5M<&]R86PB"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@
M(D9O<FUA=&\@9&\@=&5M<&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S
M.`IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96/GXV\@9&%T
M82]H;W)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M
M3&5S=&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T
M<B`B5.UT=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")4
M[71U;&\@*&1I8V$I.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")087)A(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R-@IM<V=I9"`B(@HB5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB
M"FUS9W-T<B`B(@HB4&%R82!S96QE8V-I;VYA<B!M^FQT:7!L;W,@:71E;G,L
M(&-A<G)E9W5E(&5M($-O;G1R;VP@*%!#*2!O=2!#;VUM86YD("A-86,I("(*
M(F5N<75A;G1O(&-L:6-A<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CDY"FUS9VED(")4;V1A>2(*;7-G<W1R(")(;VIE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B
M5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E1R;V-A<B!&;VYT92!(5$U,
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")297#Z8FQI8V$@5&]G;VQE<V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O<75E;&%U(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,0IM<V=I9"`B5&]M;W)R;W<B
M"FUS9W-T<B`B06UA;FCC(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B4F5I
M;F\@9&\@5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R(")4;W!O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM
M<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")-;VQD=7)A(&1E('1O
M<&\@*%]T;W`I(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B
M5')A;G-L871E9"(*;7-G<W1R(")4<F%D=7II9&%S(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B
M5')A9'7G]65S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G
M<W1R(")4<FEN9&%D92!E(%1O8F%G;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-SDQ"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E9E<F1A9&5I
M<F\@;W4@9F%L<V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(SJB(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U;FES:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A(%1U;NUS:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4=7)K97DB"FUS9W-T<B`B4F5P^F)L:6-A(&1A(%1U<G%U:6$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/
M+3@X-3DM.2DB"FUS9W-T<B`B5'5R8V\@*$E33RTX.#4Y+3DI(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<G%U96UE;FES=.-O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM
M<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(DEL:&%S
M(%1U<F-A<R!E($-A:6-O<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4
M=79A;'4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@
M>6]U<B!C:&]I8V4Z("(*;7-G<W1R(")%<V-R979A(&$@<W5A(&5S8V]L:&$Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-PIM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(LUN9&EC92!5+E8N.B`B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R
M86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@
M>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")5
M4DP@9&\@<V5U(')E;&%T\W)I;R!D92!E<W1A9&\@9&\@96YV:6\@9&4@7")S
M8W)I<'1S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED
M(")59V%N9&$B"FUS9W-T<B`B4F5P^F)L:6-A(&1O(%5G86YD82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5K<F%I;F4B"FUS9W-T<B`B56-RXFYI82(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,S,U"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86-E9&5R(.`@<&%S=&$@
M5D93+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@
M(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I
M9VYI;F<@=7`N(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@861I8VEO
M;F%R(&EN9F]R;6'GXV\@9&4@=71I;&EZ861O<B!E>'1R82!A<75A;F1O(&1A
M("(*(G-U8G-C<FGGXV\N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!M=61A<B!A<R!P97)M:7-S]65S(&1O(&%R<75I=F\@5D93(%PB)7-<(BXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,P."!L:6(O5D93+VUU<W%L+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!M=61A<B!A<R!P97)M:7-S]65S(&1O(&%R<75I=F\@5D93("5S
M+R5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!M=61A<B!P87)A("5S+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-Q;"YP:'`Z,S<Q"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&QI9V%R(&%O('-E
M<G9I9&]R(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S4V"FUS9VED(")5
M;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!L:6=A<B!U<V%N9&\@4U-,+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,34X(&QI8B]61E,O9FEL92YP:'`Z,38S(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C$X.`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ.3,@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,C`Q"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C;W!I87(@;R!A<G%U:79O
M(%9&4RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!P87-T82!61E,@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C<W(&QI8B]61E,O;75S
M<6PN<&AP.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-#@*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4RXB"@HC.B!L:6(O5D93+VUU
M<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8W)I87(@;R!A<G%U:79O(%9&
M4RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$Y.`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!C<FEA<B!U;2!A<G%U:79O(%9&4R!V87II;RXB"@HC.B!L:6(O2&]R
M9&4O0V]M<')E<W,O=&%R+G!H<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII
M<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9&5S8V]M<')I;6ER(&]S(&1A9&]S
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@
M7"(E<UPB+"!P;VES(&$@<&%S=&$@;N-O(&5S=.$@=F%Z:6$N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(%PB)7-<(CH@
M)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-30@;&EB+U9&4R]S<6PN<&AP
M.C,Q-"!L:6(O5D93+VUU<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@<F5M;W9E<B`E<RP@<&]I<R!A('!A<W1A(&[C;R!E
M<W3A('9A>FEA(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0P(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(')E;6]V97(@82!P87-T82!61E,@<F5C=7)S:79A;65N=&4N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HR-C`@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R
M(&QI8B]61E,O;75S<6PN<&AP.C,S-0HC.B!L:6(O5D93+VUU<W%L+G!H<#HS
M-#,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S,V"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@<F5M;W9E<B!A('!A<W1A(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M,S,Y(&QI8B]61E,O<W%L+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@5D93.B`E<RXB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O(%9&4R!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C8@;&EB+U9&4R]S<6PN<&AP.C(Q,"!L
M:6(O5D93+VUU<W%L+G!H<#HQ-C<*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P
M(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-S`*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<X"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@;R!A<G%U:79O(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M,S(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R
M96UO=F5R(')E8W5R<VEV86UE;G1E.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z-S(P"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@
M82!P87-T82!C;W)R96YT92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5X=')A:7(@;W,@
M<&]R;65N;W)E<R!D;R!C97)T:69I8V%D;R(*"B,Z(&QI8B].970O24U34"YP
M:'`Z-#4Q(&QI8B].970O24U34"]!=71H+G!H<#HQ,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M(@IM<V=S='(@(DEM<&]S<^UV96P@;&5R(&$@9&5F:6YIY^-O(&1E("5S+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(Y(&QI8B]61E,O9FEL92YP:'`Z,3,T
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U.`HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HQ-C,*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!61E,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C(P-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,C(@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3(U"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!A8G)I<B!O(&%R<75I=F\@5D93('!A<F$@97-C<FET82XB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C8W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<R"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@5D93+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@86)R:7(@;R!A<G%U:79O(&-O;7!R:6UI9&\N(@H*(SH@;&EB+TAO<F1E
M+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!F:6QE.B`B"FUS9W-T<B`B3N-O(&-O;G-I9V\@;&5R(&\@87)Q=6EV
M;SH@(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HU.3(*;7-G:60@(E5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!L97(@82!P87-T82!V9G-R;V]T+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3`V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B`E
M<R!C;VUO("5S.B!A('!A<W1A(&1E(&1E<W1I;F\@:N$@97AI<W1E(@H*(SH@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M<F5N;VUE87(@82!P87-T82!61E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(U
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;F]M
M96%R(&$@<&%S=&$@5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C@Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;F]M96%R
M(&\@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M-3,S(&QI8B]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&\@87)Q=6EV;R!61E,@)7,O)7,N
M(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(T-2!L:6(O5D93+VUU<W%L+G!H<#HR
M,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C(W-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@<F5N;VUE87(@87)Q=6EV;R!61E,N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5X96-U=&%R("=M:VES
M;V9S)RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C;VYV97)T97(@97-T92!D
M;V-U;65N=&\@5V]R9"(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ,C(@;&EB+U9&
M4R]F='`N<&AP.C$R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&5S8W)E=F5R(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C$Q,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E
M<V-R979E<B!O(&%R<75I=F\@5D93("AC;W!Y*"D@9F%L:&]U*2XB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C(P.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S`@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,U"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B3N-O(&-O;G-I9V\@<F5M;W9E
M<B`G)7,G.B`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B4W5B;&EN
M:&%D;R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N
M9&\@0VAA;F=E<R(*;7-G<W1R(")$97-F87IE<B!!;'1E<F'G]65S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I
M9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B1&5S9F%Z(&$@
M<W5A(/IL=&EM82!A8^?C;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C,@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y
M,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B`B"FUS9W-T<B`B4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S
M97)V:61O<B!N82!C;VYE>.-O.B`B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$Y(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-#$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W."!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B4F5S
M<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!A.B`B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-`IM<V=I9"`B56YF:6QE
M9"(*;7-G<W1R(")396T@8V%T96=O<FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC
M;V1E("A55$8M."DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS
M9W-T<B`B16UI<F%D;W,@P7)A8F5S(%5N:61O<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D
M($MI;F=D;VTB"FUS9W-T<B`B4F5I;F\@56YI9&\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET
M960@4W1A=&5S(@IM<V=S='(@(D5S=&%D;W,@56YI9&]S(&1A($%MZ7)I8V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',B"FUS9W-T<B`B26QH87,@365N;W)E<R!$:7-T86YT97,@9&]S($5S=&%D
M;W,@56YI9&]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Q
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@
M(E5N:61A9&5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$X(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q.0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")$97-C
M;VYH96-I9&\B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+B(*;7-G<W1R(")A<&EM<V=I9"`H240@9&4@365N<V%G96T@9&4@05!)*2XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I
M9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G
M<W1R(")C;&EM<V=I9"!D97-C;VYH96-I9&\@*$E$(&1E($UE;G-A9V5M(&1E
M($-L:65N=&4I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-3`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N:VYO=VX@8V]M;6%N9#H@)7,B"FUS9W-T<B`B
M0V]M86YD;R!D97-C;VYH96-I9&\Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$T-@IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V
M:61E9"XB"FUS9W-T<B`B1F]I(&9O<FYE8VED82!U;6$@;&]C86QI>F'GXV\@
M9&5S8V]N:&5C:61A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+B(*;7-G<W1R(").;VUE(&1E('5T:6QI>F%D;W(@;W4@<&%L879R82UP87-S
M92!E<G)A9&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N="(*;7-G<W1R(")296UO=F5R(&QI9V'GXV\@9&\@96QE;65N=&\@
M8V]R<F5N=&4B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C(Y-@IM<V=I
M9"`B56YN86UE9"(*;7-G<W1R(")396T@;F]M92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB4&]R(')A>O5E<R!D
M92!S96=U<F%NYV$L(%PB<V-R:7!T<UPB('-E;2!P<FEV:6SI9VEO(&[C;R!P
M;V1E;2!A8V5D97(@82`B"B)#;W)T87(O0V]P:6%R+T-O;&%R('!R;V=R86UA
M=&EC86UE;G1E+B!#87)R96=U92!E;2!/2R!P87)A('9E<B!U;6$@;F]T82`B
M"B)TZ6-N:6-A(&5M(&UO>FEL;&$N;W)G('%U92!L:&4@;6]S=')A<N$@8V]M
M;R!A=71O<FEZ87(@=6T@7")S8W)I<'1<(B!A("(*(F%C961E<B!A;W,@<F5C
M;W)T97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B4F5M
M;W9E<B!C;VQO<F'GXV\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8X-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT
M96YS:6]N(@IM<V=S='(@(D5X=&5N<^-O(&[C;R!3=7!O<G1A9&$B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED(")5;G1R86YS;&%T960B"FUS
M9W-T<B`B4&]R('1R861U>FER(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3@S"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B
M36]D:69I8V%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B
M06-T=6%L:7IA<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-#,*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D%C='5A;&EZ
M87(@=71I;&EZ861O<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G
M<W1R(")<(B5S7"(@86-T=6%L:7IA9&\N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P.3(@<&\O=')A;G-L871I;VXN<&AP.C$R,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871I;F<@)7,@:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T
M<B`B06-T=6%L:7IA;F1O(&%R<75I=F\@9&4@86IU9&$@)7,@<&%R82`E<RXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,0IM<V=I9"`B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B7")38W)I<'1<(B!D92!A8W1U
M86QI>F'GXV\@<F5M;W9I9&\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@R"FUS
M9VED(")5<&QO860B"FUS9W-T<B`B57!L;V%D(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X.0IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(D-A<G)E9V%D
M;W,@;F\@<V5R=FED;W(@=&]D;W,@;W,@87)Q=6EV;W,@9&4@:6YS=&%L8>?C
M;R!D92!A<&QI8V'G]65S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B3&5T<F%S(&QA=&EN87,@96T@;6%I^G-C=6QA
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B3OIM97)O<R!R;VUA;F]S(&5M(&UA:?IS8W5L87,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M<G5G=6%Y(@IM<V=S='(@(E)E</IB;&EC82!/<FEE;G1A;"!D;R!5<G5G=6%I
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,U('!O+W1R86YS;&%T:6]N+G!H
M<#HY,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3,*;7-G:60@(E5S86=E.B(*;7-G
M<W1R(")5=&EL:7IAY^-O.B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R
M96YT.B`E<R(*;7-G<W1R(")5<V%R(&\@0V]R<F5N=&4Z("5S(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-3
M3"(*;7-G<W1R(")5<V%R(%-33"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"B)5<V%R('-E(&\@;F]M
M92!D92!U=&EL:7IA9&]R(&]U(&$@<&%L879R82UP87-S92!F;W)E;2!D:69E
M<F5N=&5S(&YO('-E<G9I9&]R("(*(DE-4U`N(@H*(SH@;&EB+TAO<F1E+U)E
M9VES=')Y+G!H<#HV,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I
M<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(E5T:6QI>F%D;W(@
M)7,@;N-O(&5S=.$@875T;W)I<V%D;R!P87)A("5S+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!9&UI;FES=')AY^-O(&1E(%5T:6QI>F%D;W)E<R(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T
M<B`B3W#G]65S(&1O(%5T:6QI>F%D;W(B"@HC.B!S:6=N=7`N<&AP.C8R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")296=I<W1O(&1E(%5T
M:6QI>F%D;W)E<R(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM
M<V=S='(@(D\@4F5G:7-T;R!D92!5=&EL:7IA9&]R97,@97-TX2!I;F%C=&EV
M;RXB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-S(@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR-#8*;7-G:60@(E5S97(@<&5R;6ES<VEO;G,B"FUS9W-T
M<B`B4&5R;6ES<_5E<R!D;R!U=&EL:7IA9&]R(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.3@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.3@@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV."!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B
M3F]M92!D92!5=&EL:7IA9&]R(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB
M(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")/($YO;64@9&4@571I;&EZ861O
M<B!<(B5S7"(@:N$@97AI<W1E+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DYO;64@9&4@
M571I;&EZ861O<CHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(DYO;64@9&4@571I;&EZ861O
M<CH@(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,3D*;7-G:60@(E5S
M97)S(@IM<V=S='(@(E5T:6QI>F%D;W)E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ
M(@IM<V=S='(@(E5T:6QI>F%D;W)E<R!D;R!S:7-T96UA.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(E5Z8F5K:7-T86XB"FUS9W-T<B`B4F5P^F)L:6-A(&1O(%5Z8F5Q=6ES=.-O
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,#$@;&EB+U9&4R]F:6QE+G!H<#HQ
M.#@*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(D$@<&%S=&$@5D93(&[C;R!E>&ES=&4N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B075S
MZFYC:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8V"FUS9VED(")686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(D%S(&QO8V%L
M:7IAY_5E<R!VX6QI9&%S(&5N8V]N=')A9&%S(&EN8VQU96TZ(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM
M<V=S='(@(E9A;&ED861E+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(E9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@9&5S=&4@:6YS=&%N=&4N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B5F%L;W(@97AC961E(&\@
M8V]M<')I;65N=&\@;>%X:6UO(&1E("5S+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0U(&QI8B](;W)D92]&;W)M+G!H<#HR,C8W(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S$U"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3(W"FUS9VED
M(")686QU97,B"FUS9W-T<B`B5F%L;W)E<R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3$P(&QI8B](;W)D92]&;W)M+G!H<#HR,3@W"FUS9VED(")686QU
M97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B4&]S<^UV96P@=F%L;W)E<R!A
M(&5S8V]L:&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,@IM<V=I9"`B
M5F%R:6%B;&4B"FUS9W-T<B`B5F%R:>%V96PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E
M;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R
M(")697)I9FEC8>?C;R!F86QH;W4@+2!E<W1A(&UE;G-A9V5M('!O9&4@=&5R
M('-I9&\@861U;'1E<F%D82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)SXV\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")697)S:6]N($-O
M;G1R;VPB"FUS9W-T<B`B0V]N=')O;&\@9&4@5F5R<_5E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D%L:6YH86UE;G1O(%9E<G1I
M8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")#86SG;R!6
M97)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6-A;#HB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM
M<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(DUU:71O($%L=&\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:65T($YA;2(*;7-G<W1R(")297#Z8FQI8V$@4V]C:6%L:7-T82!D;R!6
M:65T;F%M92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6
M:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(E9I971N86UI=&$@*%9)4T-)
M22DB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.34Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5FES=6%L:7IA<B`E
M<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@
M97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B5F5R('5M82!PX6=I;F$@97AT
M97)N82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")6:7-U86QI
M>F%R(&-O;6\@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:"(*;7-G<W1R("));&AA<R!6:7)G96YS($)R:73B;FEC87,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("));&AA<R!6:7)G96YS
M($%M97)I8V%N87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I
M9"`B5FES:6)I;&ET>2(*;7-G<W1R(")6:7-I8FEL:61A9&4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Q"FUS9VED(")6:7-I8FEL:71Y
M.B`B"FUS9W-T<B`B5FES:6)I;&ED861E.B`B"@HC.B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=.%L:6$@=FEA(%--5%`B
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B059)4R(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)
M3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R
M(")!5$5.Q\-/(2$A(%)%34]602!/(%PB4T-225!47"(@34%.54%,345.5$4@
M1$4@)7,N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B
M5V%L;&ES(&4@1G5T=6YA(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(Y"FUS9VED(")787)N:6YG(@IM<V=S='(@
M(D%V:7-O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T-2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-C@Q('!O+W1R86YS;&%T:6]N+G!H<#HW,3$*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C<R-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V,"!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`V.0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W
M-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-R!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`Y-PHC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P-R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3$Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S-0HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3(T-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(U,2!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3(W,0IM<V=I9"`B5V%R;FEN9SH@(@IM<V=S='(@
M(D%V:7-O.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(TJB(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S
M="(*;7-G<W1R(")0<F5V:7/C;R!D;R!496UP;R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT,34*;7-G:60@(E=E871H97(@9&%T82!P<F]V
M:61E9"!B>2(*;7-G<W1R(")$861O<R!M971E;W)O;/-G:6-O<R!F;W)N96-I
M9&]S('!O<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3(*;7-G:60@(E=E
M871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<V"FUS9VED(")796(@4VET92(*
M;7-G<W1R(")0X6=I;F$B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B4V5M86YA;&UE;G1E(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B
M"FUS9W-T<B`B0F5M+79I;F1A*&\I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4S"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B0F5M+79I
M;F1A*&\I(&$@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0F5M+79I;F1A*&\I+"`E<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ*2(*;7-G<W1R(")/8VED96YT86P@*$E33RTX.#4Y+3$I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*2(*;7-G<W1R(")/8VED96YT86P@*$E33RTX.#4Y+3$U*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R(")386%R82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\B"FUS9W-T<B`B475E(&%P;&EC8>?C;R!D979E(&\@)7,@;6]S=')A<B!A
M</-S(&$@96YT<F%D83\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR,0IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B
M"FUS9W-T<B`B475A;"#I(&\@8V%R86-T97)E(&1E;&EM:71A9&]R/R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(T"FUS9VED(")7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(E%U86P@Z2!O(&-A<F%C
M=&5R92!D92!C:71AY^-O/R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM
M<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(E%U92!F87-E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B
M475E(%PB<&QU9VEN<UPB(&%C=&EV87(@<&%R82!A($5D:>?C;R!2:6-A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(DQA<F=U<F$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$R-`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S
M(@IM<V=S='(@(DQA<F=U<F$@96T@=6YI9&%D97,@0U-3(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T
M:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N
M(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B3&%R9W5R82!D;R!-96YU("5S(.`@
M97-Q=65R9&$@*'1E;2!E9F5I=&\@;F$@<'+S>&EM82!E;G1R861A*3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM
M<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(DQA<F=U<F$@9&$@
M=&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B56YI9&%D92!D
M92!L87)G=7)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("),87)G=7)A.B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C@*;7-G:60@(E=I:VDB
M"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*
M;7-G:60@(E=I;F0B"FUS9W-T<B`B5F5N=&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L>2(*
M;7-G<W1R(")696YT;R!-871I;F%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")696QO
M8VED861E(&1O('9E;G1O(&5M(&[S<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R(")696YT;SHB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,P"FUS9VED(")7:6YD.B`B"FUS
M9W-T<B`B5F5N=&\Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM
M<V=I9"`B5VES9&]M(@IM<V=S='(@(E-A8F5D;W)I82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.#(*;7-G:60@(E=I<VAL:7-T<R(*;7-G<W1R
M("),:7-T87,@9&4@1&5S96IO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")4<F%B86QH;R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS
M9W-T<B`B16YD97)EYV\@*$5M<')E9V\I(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T
M<B`B5&5L969O;F4@*$5M<')E9V\I(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$Q-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)I=&EN9R!U<&1A=&5D(&AE
M;'`@9FEL92!T;R`E<RXB"FUS9W-T<B`B17-C<F5V96YD;R!A<G%U:79O(&1E
M(&%J=61A(&%C='5A;&EZ861O('!A<F$@)7,N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(S,0IM<V=I9"`B6"U2968B"FUS9W-T<B`B4F5F97+J
M;F-I87,@8W)U>F%D87,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@
M(E)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G92(*;7-G<W1R(")5=&EL:7IAY^-O(&1E($-H879E($5X=&5N9&ED82!8
M-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I
M9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(").
M;VUE($%L=&5R;F%T:79O(&1E(%-U:F5I=&\@6#4P.78S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T
M($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(DED96YT:69I8V%D;W(@0VAA=F4@
M9&4@4W5J96ET;R!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B17AT
M96YS]65S(%@U,#EV,R(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")962(*;7-G<W1R(")!02(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0R-PIM<V=I9"`B65E962(*;7-G<W1R(")!04%!(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#$*;7-G:60@(EEA:&]O
M(2!M87`B"FUS9W-T<B`B36%P82!986AO;R$B"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B06YU86QM
M96YT92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DGI;65N(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X-0IM<V=I9"`B665S
M(@IM<V=S='(@(E-I;2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E
M96UE;G1?8F]T=&]M+FEN8SHV"FUS9VED(")997,L($D@06=R964B"FUS9W-T
M<B`B4VEM+"!#;VYC;W)D;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%
M+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)
M5UE'+B(*;7-G<W1R("(B"B)%<W3A(&5M($U/1$\@9&4@5$585"X@(%5S92!O
M(&)O=.-O(%L\/ET@<&%R82!T<F]C87(@<&%R82!O(&UO9&\@5DE354%,+B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3(Y-PIM<V=I9"`B66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"XB"FUS9W-T<B`B3N-O(&5S=.$@875T96YT:6-A9&\N(@H*
M(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@
M;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE
M+B(*;7-G<W1R(").XV\@<&]D92!T97(@;R!C87)A8W1E<F4@)UQ<)R!N;R!S
M974@;F]M92!C;VUP;&5T;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U
M-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-@IM<V=I9"`B66]U(&1I9"!N;W0@
M96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(").XV\@:6YT
M<F]D=7II=2!U;2!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(';A
M;&ED;RXB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*(D[C;R!M87!E;W4@;F5N:'5M(&-A;7!O
M(&1O(&%R<75I=F\@:6UP;W)T861O('!A<F$@;W,@8V%M<&]S(&-O<G)E<W!O
M;F1E;G1E<R`B"B)E;2`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3(S
M"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D%C
M86)O=2!D92!S86ER+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8Q"FUS
M9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N
M=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B
M(@HB5&5M(&1E(&EN=')O9'5Z:7(@=6T@;OIM97)O(&1E('1E;&5M\W9E;"!V
MX6QI9&\L('/S(&-O;2!D[6=I=&]S+"!M87,@8V]M('5M("(*(B<K)R!O<&-I
M;VYA;"!P87)A(&\@<')E9FEX;R!I;G1E<FYA8VEO;F%L+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED('9A;'5E+B(*;7-G<W1R(")496T@9&4@:6YT<F]D=7II<B!U;2!V
M86QO<B!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS
M-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB5&5M(&1E(&-O;F9I9W5R
M87(@=6T@;65C86YI<VUO(&+A<VEC;R!P87)A($1A=&%4<F5E('-E('%U:7-E
M<B!U<V%R("(*(E-U8G-C<FGG]65S(@H*(SH@;&EB+TAO<F1E+G!H<#HT,S$*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G
M<W1R(")496T@9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@8F%S92!P87)A
M(&\@5D93+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q
M"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B1&5V
M92!D97-C<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA
M=/-R:6\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T
M:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(E1E;2!D92!I;G1R;V1U>FER
M(&\@55),(&1O(')E8W5R<V\@<75E(&5S=&$@;&EG8>?C;R!S92!R969E<F4B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R
M(")496T@9&4@<V5L96-C:6]N87(@=6T@<V5R=FED;W(@82!R96UO=F5R+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B1&5V92!E<W!E
M8VEF:6-A<B!O('5T:6QI>F%D;W(@82!L:6UP87(N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+B(*;7-G<W1R(")$979E(&5S<&5C:69I8V%R(&\@;F]M92!D
M;R!U=&EL:7IA9&]R(&$@<F5M;W9E<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV
M,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B
M5&5M(&1E(&5S<&5C:69I8V%R(&\@;F]M92!D;R!U=&EL:7IA9&]R(&$@861I
M8VEO;F%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")4
M96T@9&4@97-P96-I9FEC87(@;R!U=&EL:7IA9&]R(&$@86-T=6%L:7IA<BXB
M"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T
M<B`B5&5M(&1E(&5S<&5C:69I8V%R(&$@86/GXV\@82!D97-E;7!E;FAA<BXB
M"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,@IM
M<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G
M<W1R(")496T@9&4@:6YT<F]D=7II<B!U;2!N;W9O(&YO;64@9&4@8V%T96=O
M<FEA+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(B"FUS9W-T<B`B5&5M(&1E(&9O<FYE8V5R('5M(&[Z;65R;R!D
M92!T96QE9F]N92!I=&%L:6%N;R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY
M,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(D$@<W5A('-E
M<W/C;R`E<R!E>'!I<F]U+B!0;W(@9F%V;W(@96YT<F4@9&4@;F]V;RXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U
M<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D\@<V5U($5N9&5R9>=O(&1E($-O
M<G)E:6\@16QE8W1R\VYI8V\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(P-`IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")/('-E
M=2!E;F1E<F7G;R!<(D1E.EPB(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9
M;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D$@<W5A($EN9F]R;6'GXV\B"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@HB3R!S974@96YD97)EYV\@25`@<&%R96-E('1E<B!M=61A9&\@9&5S
M9&4@;R!I;NUC:6\@9&$@<V5S<^-O("5S+B!087)A("(*(F=A<F%N=&ER(&$@
M<W5A('-E9W5R86[G82P@9&5V92!A=71E;G1I8V%R+7-E(&1E(&YO=F\N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO
M=7(@3F%M92(*;7-G<W1R(")/(%-E=2!.;VUE(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]A9&0N:6YC.CD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)/('-E=2!M96-A;FES;6\@9&4@
M875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&%D:>?C;R!D92!U=&EL:7IA9&]R
M97,@;W4@97-T82`B"B)O<.?C;R!F;VD@9&5S86-T:79A9&$@<&]R(&%L9W5M
M(&]U=')O(&UO=&EV;RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.CD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BXB"FUS9W-T<B`B(@HB3R!S974@;65C86YI<VUO(&1E(&%U=&5N=&EC8>?C
M;R!NXV\@<W5P;W)T82!L:7-T86=E;2!D92!U=&EL:7IA9&]R97,@;W4@97-T
M82`B"B)O<.?C;R!F;VD@9&5S86-T:79A9&$@<&]R(&%L9W5M(&]U=')O(&UO
M=&EV;RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@HB3R!S974@;F%V96=A9&]R('!A<F5C92!T97(@
M;75D861O(&1E<V1E(&\@:6[M8VEO(&1A('-E<W/C;R`E<RX@4&%R82!G87)A
M;G1I<B`B"B)A('-U82!S96=U<F%NYV$L(&1E=F4@875T96YT:6-A<BUS92!D
M92!N;W9O+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM
M<V=S='(@(D\@<V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&9U;F-I
M;VYA;&ED861E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS
M.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B
M"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB3R!S974@;F%V96=A9&]R(&[C;R!S
M=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O+B!0<F5S<VEO;F4@0V]N
M=')O;"\B"B)#;VUM86YD("L@4"!P87)A(&EM<')I;6ER+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-#D*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE
M('IO;F4Z(@IM<V=S='(@(D9U<V\@:&]RX7)I;R!A8W1U86PZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$U,`IM<V=I9"`B66]U<B!D969A=6QT(&ED
M96YT:71Y.B(*;7-G<W1R("))9&5N=&ED861E('!A9'+C;SHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED(")9;W5R(&9U;&P@;F%M93HB
M"FUS9W-T<B`B3F]M92!C;VUP;&5T;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ-#4*;7-G:60@(B(*(EEO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O
M;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+EQN(@HB3F]T
M(&%L;"!S=')I;F=S('=I;&P@8F4@97AT<F%C=&5D+B(*;7-G<W1R("(B"B)!
M('-U82!V97)SXV\@9&\@9V5T=&5X="#I(&1E;6%S:6%D;R!A;G1I9V$L(&[C
M;R!S=7!O<G1A;F1O(%!(4"!D92!F;W)M82`B"B)N871I=F$N($YE;2!T;V1A
M<R!A<R!C861E:6%S(&1E(&-A<F%C=&5R97,@<V5RXV\@97AT<F'M9&%S+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS
M9W-T<B`B02!S=6$@;F]V82!P86QA=G)A+7!A<W-E('!A<F$@)7,@Z3H@)7,B
M"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@
M=&AI<R!S97-S:6]N+B(*;7-G<W1R(")!<R!S=6%S(&]PY_5E<R!F;W)A;2!A
M;'1E<F%D87,@873I(&%O(&9I;F%L(&1E<W1A('-E<W/C;RXB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")!<R!S=6%S(&]PY_5E<R!F;W)A
M;2!A8W1U86QI>F%D87,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS
M9W-T<B`B02!S=6$@<&%L879R82UP87-S92!F;VD@<F5C<FEA9&$B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*
M(D$@<W5A('!A;&%V<F$M<&%S<V4@9F]I(')E8W)I861A+"!V97)I9FEQ=64@
M;R!S974@8V]R<F5I;R!E;&5C='+S;FEC;R!E("(*(F5N=')E(&-O;2!A('-U
M82!N;W9A('!A;&%V<F$M<&%S<V4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G
M<W1R(")/<R!S975S('-E<G9I9&]R97,@<F5M;W1O<SHB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O<VSA=FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G
M<W1R("):86ER92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):XFUB:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)UZ2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B
M6FEP<'DB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O
M=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");
M17-C;VYD97(@5&5X=&\@0VET861O72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN
M<&AP.C4V"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM296QA
M=/-R:6\@9&4@4')O8FQE;6%S72`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2(*;7-G<W1R(");36]S=')A<B!497AT;R!#:71A9&\@+2(*"B,Z(&QI8B](
M;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M72(*;7-G<W1R(");36]S=')A<B!497AT;R!#:71A9&\@+2`E<R!L:6YH87-=
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6YH82`E<R!D92`E<UTB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$T-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI;FES
M=')AY^-O(@H*(SH@;&EB+V%P:2YP:'`Z,3,V"FUS9VED(")?0TQ)(@IM<V=S
M='(@(E]#;VYS;VQA(@H*(SH@;&EB+V%P:2YP:'`Z,3(T"FUS9VED(")?1&%T
M851R964B"FUS9W-T<B`BP7)?=F]R92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T
M92!2;W<B"FUS9W-T<B`B7U)E;6]V97(@3&EN:&$B"@HC.B!L:6(O87!I+G!H
M<#HQ,38*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!O<R(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(D%?
M:G5D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B4')O<')I961A9&5S(&1A(%]);6%G96TB"@HC.B!L:6(O2&]R9&4O
M365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E]%;G1R87(B
M"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*
M;7-G<W1R(")?4V%I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN
M(@IM<V=S='(@(E]-;V1I9FEC87(@3&EG8>?C;R(*"B,Z(&QI8B](;W)D92]-
M96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<.?U97,B
M"@HC.B!L:6(O87!I+G!H<#HQ,C`*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G
M<W1R(")?4&5R;6ES<_5E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK
M+BXN(@IM<V=S='(@(E]296UO=F5R($QI9V'GXV\N+BXB"@HC.B!L:6(O87!I
M+G!H<#HQ,#@*;7-G:60@(E]3971U<"(*;7-G<W1R(")?0V]N9FEG=7)AY^-O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,R"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")0<F]P<FEE9&%D97,@9&$@7U1A8F5L82(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M,@IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]5=&EL:7IA9&]R97,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C@Y,`IM<V=I9"`B861D<F5S<R!B;V]K(@IM
M<V=S='(@(F-O;G1A8W1O<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,3$*
M;7-G:60@(F%N(&5R<F]R(&AA<R!O8V-U<F5D.B(*;7-G<W1R(")O8V]R<F5U
M('5M(&5R<F\Z(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.#(*;7-G:60@
M(F-A;&5N9&%R(@IM<V=S='(@(F-A;&5N9.%R:6\B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(F-A;&UO(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C4X.0IM<V=I9"`B8VQI8VL@:&5R92(*
M;7-G<W1R(")C;&EQ=64@87%U:2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT
M-#4@<&\O=')A;G-L871I;VXN<&AP.C4U,"!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-#D@<&\O=')A;G-L871I;VXN
M<&AP.C@Q,"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@W"FUS9VED(")D;VYE(@IM
M<V=S='(@(F9E:71O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4U,B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-3@T('!O+W1R86YS;&%T:6]N+G!H<#HV,3,*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C<W."!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$R
M('!O+W1R86YS;&%T:6]N+G!H<#HX.3`*;7-G:60@(F9A:6QE9"(*;7-G<W1R
M(")F86QH;W4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")D:6UI;G5I;F1O(@H*
M(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B9FEL92(*;7-G
M<W1R(")F:6-H96ER;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,CD*;7-G
M:60@(F9O=6YD.B`B"FUS9W-T<B`B96YC;VYT<F%D;SH@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")D;R`E<R`H)7,I(.!S
M("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.`IM
M<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")R86IA9&%S(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B:#HB"FUS9W-T
M<B`B:#HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S,Q"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")I;65D:6%T
M;R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B96T@;&EN:&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B;&EN97-=(@IM<V=S='(@(FQI;FAA<UTB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B
M17)R;R!M:VES;V9S(&-O;2!C\V1I9V\@)60@86\@8V]N<W1R=6ER($E33RXB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S0R"FUS
M9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,C@X('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#4*;7-G:60@
M(FYA;64B"FUS9W-T<B`B;F]M92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS
M-S@*;7-G:60@(FYO="!C:&%N9V5D(@IM<V=S='(@(G-E;2!A;'1E<F'G]65S
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,0IM<V=I9"`B;F]T(&9O=6YD
M(@IM<V=S='(@(F[C;R!E;F-O;G1R861O(@H*(SH@;&EB+TAO<F1E+U)00RYP
M:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B;N-O(&EM
M<&QE;65N=&%D82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(Q
M.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")A:6YD82!P
M;W(@:6UP;&5M96YT87(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@W-`IM
M<V=I9"`B;F]T97!A9"(*;7-G<W1R(")C861E<FYO(&1E(&YO=&%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P97)C96YT86=E;2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*
M;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P[7AE:7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM
M<V=S='(@(G-U8FEN9&\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDX
M"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(FUO<W1R87(@9&EF
M97)E;N=A<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA
M:6P@=FEA($A45%`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S4X"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB
M"FUS9W-T<B`B97-TX79E;"(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DX
M"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B;&ES=&$@9&4@=&%R969A<R(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H92!L;V-A;&4@)7,@9&]E<R!N
M;W0@97AI<W0Z(@IM<V=S='(@(D\@9FEC:&5I<F\@4$\@<&%R82!O(&QO8V%L
M92`E<R!NXV\@97AI<W1E+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S
M=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(FEN=')O9'5Z82!A('!A
M;&%V<F$M<&%S<V4@9'5A<R!V97IE<RP@<&%R82!C;VYF:7)M8>?C;R(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I8V%D;R(*"B,Z(&QI
M8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S
M='(@(G-E;2!N;VUE(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,W-0IM<V=I
M9"`B=7!D871E9"(*;7-G<W1R(")A8W1U86QI>F%D;R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@
M(G-E;&5C8VEO;F%D82!P96QO('5T:6QI>F%D;W(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R
M(")V0V%R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C0*;7-G:60@(G<Z(@IM<V=S='(@(E)E96YC.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G
M<W1R(")W96%T:&5R+F-O;2(*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+W)O
M7U)/+G!O````````````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`V,3$U,C$`,3`T,3<S-C,P,#,`,#$V-#$R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````",@2&]R9&4@4F]M86YI
M86X@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`R($AO<F1E(%!R
M;VIE8W0N"B,@0V]R;F5L:74@3553050@/&-M=7-A=$!K97ES>7,N<F\^+"`R
M,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!(3U)$12`R+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R+3`X+3`Q
M(#`Y.C,T*S`R.C`P7&XB"B),87-T+51R86YS;&%T;W(Z($-O<FYE;&EU($U5
M4T%4(#QC;75S871`:V5Y<WES+G)O/EQN(@HB3&%N9W5A9V4M5&5A;3H@4D]-
M04Y)04X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)
M4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN
M("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G
M:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I
M9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V
M86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I
M<W1R>2XB"FUS9W-T<B`B)R5S)R!N=2!E<W1E(&-O;F9I9W5R870@:6X@2&]R
M9&4@4F5G:7-T<GDB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T
M960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E
M<R!A;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP
M:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@3W!E<F%T:75N
M:2!D92!M96YT96YA;G1A("T@0V]N9FER;6%R92(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS
M(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@
M)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(D)I
M9F%T:2!O<&5R871I=6XH96$O:6QE*2!P92!C87)E(&1O<FET:2!S82!L92!F
M86-E=&D@86-U;2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(DQA(&9I96-A<F4@
M-2!M:6YU=&4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B
M"FUS9W-T<B`B6VQI;FEA("5S(&1I;B`E<UTB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B06=E;F1A(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B0V%L96YD87(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!4
M87-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO
M;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY
M(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@
M86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`B26YF;W)M871I:2!D97-P<F4@=&EN92(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS
M9W-T<B`B26YF;W)M871I:2!D97-P<F4@=&EN92(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!D
M92!O<F4B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED
M("(\4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB/D$@87!A<G5T(&\@97)O87)E(&9A
M=&%L83H\+V(^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW
M"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB
M82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED
M(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB
M"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P
M"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI
M9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L
M(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN
M9F]R;6%T:6D@9&5S<')E('1I;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T
M<B`B4&%R;VQA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B
M06-C;W5N=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*(RP@9G5Z
M>GD*;7-G:60@(D%D9"(*;7-G<W1R(")!9')E<V$B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H
M:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM
M<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(D%D9"!(
M97)E.B(*;7-G<W1R(")!9')E<V$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q
M."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.
M97<@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S
M97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B
M061D(&YE=R!M96UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(D%D875G
M82!P97)E8VAE82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D
M9')E<W,@8F]O:SHB"FUS9W-T<B`B06=E;F1A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!
M9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%G96YD82(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G
M<W1R(")!9&%U9V$@<&5R96-H96$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF
M;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*(RP@9G5Z>GD*;7-G:60@
M(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9V5N9&$B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G
M:60@(D%D<R(*;7-G<W1R(")!9')E<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS
M9VED(")!;&)A;FEA(@IM<V=S='(@(D%L:6%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F
M=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&EA<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L
M:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI
M9VXB"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H
M96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED
M(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL
M(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@
M(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P
M-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G
M:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM
M<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-
M4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S(@IM<V=S='(@(D%D<F5S82!T82!D92!%;6%I;#HB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(E,M82!S
M<&5C:69I8V%T(&\@=F%L;V%R92!I;F-O<F5C=&$N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B/&(^02!A<&%R=70@
M;R!E<F]A<F4@9F%T86QA.CPO8CXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O
M<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!
M;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@
M(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS
M9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O
M=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS
M:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!2
M96=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T
M=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@
M(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU
M,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED
M(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT
M-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I
M9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP
M.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D-I
M;7!U<FD@9&ES<&]N:6)I;&4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A
M:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*
M;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"
M86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@
M:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G
M:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H
M<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM
M<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC
M<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S
M"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I
M=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM
M<V=S='(@(EII=6$@9&4@;F%S=&5R92(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(").;W1I9FEC871I;VX@;&ES=&5N97(@)7,@;F]T
M(&9O=6YD+B`M(&1E('1R861U<R(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C
M:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B"FUS9W-T<B`B2&]R
M9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q
M"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0V]R97-P;VYD96YT
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!4
M97)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I
M($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L
M9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#
M35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?
M96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O
M<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM
M<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@
M<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ>0IM<V=I
M9"`B0V%N861A(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R
M"FUS9VED(")#86YC96PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R
M="(*;7-G<W1R(")296YU;G1A(&QA(%)A<&]R="(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G
M:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M
M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@
M<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED
M(")#87!T:6]N(@IM<V=S='(@(D]P=&EU;FDB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED
M(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E
M;&P@4&AO;F4B"FUS9W-T<B`B5&5L969O;B!-;V)I;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z
M>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")496QE9F]N($UO
M8FEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM
M<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL
M('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")4
M96QE9F]N($UO8FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G
M:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G
M:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX
M.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q
M"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF
M:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U
M>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(G9#87)D("T@9&4@=')A9'5S(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(D%N=6QE87IA(%-C:&EM8F%R:6QE(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G
M:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA
M:6QS+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B
M"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-PHC+"!F=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")V0V%R9"`M(&1E('1R
M861U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B
M5&ET;'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP
M;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O
M<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").;W1I9FEC871I
M;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+B`M(&1E('1R861U<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY
M"FUS9VED(")#;&5A<B(*;7-G<W1R(")#86QE;F1A<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R
M($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#
M;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT
M:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A4
M5%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD
M;W<B"FUS9W-T<B`B26YC:&ED92!F97)E87-T<F$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#
M;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G
M:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#
M;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D-O;7!A
M;FEA(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD
M(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N
M($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")#;VUP86YI82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I
M=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R
M871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG
M=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B
M"FUS9W-T<B`B4&%R;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#0U"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I
M9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R
M(")#;VYT:6YU='5L(&QU:2`G)7,G("T@9&4@=')A9'5S(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O;7!A;FEA
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")#
M:6UP(&EM<&]R=&%T.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU
M"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T
M92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@
M<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A
M(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T
M('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES
M="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H
M<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F
M<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYU('!O="!D97-C:&ED92!M;V1U
M;'5L(&1E($UE;G1E;F%N=&$@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYU('!O="!D97-C:&ED92!M;V1U
M;'5L(&1E($UE;G1E;F%N=&$@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E
M($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED
M("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M2&]R9&4@;G4@97-T92!C;VYF:6=U<F%T(&-O<F5S<'5N>F%T;W(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@
M=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E
M(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@
M;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U
M;"!D92!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C
M;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<
M(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT
M<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W
M,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@
M(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI
M;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB
M+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I
M9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM
M<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S
M='(@(EI:(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y
M"FUS9VED(")$86EL>2(*;7-G<W1R(")::6QN:6,B"@HC.B!A9&UI;B]D871A
M=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T
M86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W
M"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")::6QN
M:6,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS
M9VED(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I
M;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A=6QT
M(@IM<V=S='(@(DED96YT:71A=&4@26UP;&EC:71A(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B571I;&EZ96%Z82!686QO<FD@
M26UP;&EC:71E(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("))9&5N=&ET
M871E($EM<&QI8VET82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC
M+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("))9&5N=&ET
M871E($EM<&QI8VET82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM
M<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*
M;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E(')O=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B261E;G1I=&%T92!);7!L:6-I
M=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@
M<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED
M(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S
M='(@(D1E<V-R:64@<')O8FQE;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B1&5S8W)I97)E(&-O;7!L971A.B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@
M;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971A;&EI(&EN<F5G:7-T
M<F%T92!I;B!,3T<@<&5N=')U(&%D;6EN:7-T<F%T;W(N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E
M=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$
M97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!T:75N:2!D92!!9FES87)E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(D]P=&EU
M;FD@9&4@069I<V%R92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G
M:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES
M<&QA>2!F;W)M870B"FUS9W-T<B`B3W!T:75N:2!D92!!9FES87)E(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B
M5&4@<F]G(&YU(&%C8V5S82!D:7)E8W0@;6%I;G1E;F%N8V4N<&AP(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G
M:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS
M9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W
M;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")#;W)E<W!O;F1E
M;G1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R
M(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN
M8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@
M1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%
M9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC
M($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%
M;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S
M='(@(D5M86EL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,L(&9U>GIY"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!T82!D92!%;6%I
M;#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA
M:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B06QT92!I;F9O<FUA=&EI
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*(RP@
M9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")/<'1I=6YI(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R
M"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")%;7!T
M>2!R97-U;'0N("T@9&4@=')A9'5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R(")%;7!T>2!R97-U;'0N("T@9&4@=')A9'5S(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R
M;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%
M9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM
M86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T
M97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A
M=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S
M+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R
M;V%R92(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E
M<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G
M:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI
M;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*
M;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU
M=&5S(@IM<V=S='(@(D\@9&%T82!L82`Q-2!M:6YU=&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI
M;G5T97,B"FUS9W-T<B`B3&$@9FEE8V%R92`U(&UI;G5T92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")/(&1A=&$@;&$@
M,S`@<V5C=6YD92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S
M(@IM<V=S='(@(DQA(&9I96-A<F4@-2!M:6YU=&4B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,
M;V=I;B(*;7-G<W1R("),82!F:65C87)E($-O;F5C=&%R92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*
M;7-G<W1R(")/(&1A=&$@;&$@,S`@;6EN=71E(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED
M(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B26X@9FEE8V%R92!M:6YU="(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE
M('9A;'5E<SHB"FUS9W-T<B`B17AE;7!L92!D92!V86QO<FDZ(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I
M9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS
M9VED(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I
M9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DYU
M('!O="!C:71I('!R969E<FEN=&5L92XB"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E($Q$
M05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L(&9U
M>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E
M<UPB+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D
M92!,1$%0+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R
M(").=2!P;W0@8VET:2!P<F5F97)I;G1E;&4N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S
M.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D5R;V%R
M92!D92!I;G1R87)E.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&
M87AE<R(*;7-G<W1R(")&87@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&
M:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T
M(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@
M9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B5&ET;'4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE
M($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M92!.86UE(@IM<V=S='(@(DYU;64B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN
M;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS
M9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U
M87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*
M;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*
M(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A
M<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M
M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@
M(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED
M(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(").
M;W1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T
M=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P
M"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&
M<F%M97,B"FUS9W-T<B`B3G5M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:65R92!C;VUP;&5T83HB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W
M-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B3G5M96QE
M('1A=3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A
M=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L
M92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A
M>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@
M(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM
M<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L
M971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N
M<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R(")!9V5N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS
M9VED(")(96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B
M2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@
M(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ
M.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B2&5L<"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G
M:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*
M;7-G<W1R(")(96QP(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED
M(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]R9&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$U,S4*(RP@9G5Z>GD*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G
M:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')E<V$@9&4@86-A<V$B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L
M969O;G5L(&1E(&%C87-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G
M:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO
M<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H
M92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F
M;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-
M12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS
M9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R
M:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U
M"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE
M<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO
M<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L
M('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL
M960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,B"FUS
M9W-T<B`B061R97-A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC
M+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"
M969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G
M:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED
M("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B
M"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@
M(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE
M(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y
M960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM
M86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%52
M3#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A
M;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M
M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R(")#
M:6UP(&EM<&]R=&%T.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E
M<R(*;7-G<W1R(")#:6UP(&EM<&]R=&%T.B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B0VEM<'5R:2!I;7!O<G1A=&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I
M;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@
M(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@
M(E1E(')O9R!I;G1R;V1U('5N(&YU;64@9&4@=71I;&EZ871O<B!S:2!O('!A
M<F]L82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED
M("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN
M8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@
M(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED
M("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PHC+"!F=7IZ
M>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I:2!D97-P
M<F4@=&EN92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*
M;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN
M<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R
M="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B
M26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED
M("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I
M9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B
M26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN
M<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S
M86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S
M96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO
M9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI
M;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*
M;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED("))
M;G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A
M;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI
M9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q
M"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"FUS9VED("));G9A
M;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV
M86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A
M;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN
M=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R(")::6QN:6,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@
M(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I
M9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP
M="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@
M<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I
M9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R
M9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W
M"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@
M(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF
M>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K
M:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L
M($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+
M97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I
M9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*
M;7-G<W1R(")-97-A:B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T
M"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS
M9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G
M<W1R("),:6UB82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R
M9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V
M(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),
M87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G
M:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F=7IZ
M>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D1E8V]N96-T87)E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B
M3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),
M969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L
M=65S(@IM<V=S='(@(D5X96UP;&4@9&4@=F%L;W)I.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S
M='(@(DYI8VEO9&%T82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA
M;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C
M:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(D-O;F5C
M=&%R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),
M:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG
M:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK
M(@IM<V=S='(@(D-O;F5C=&%R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN
M=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM
M<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I
M9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("),:7-T82!S=6)I96-T96QO
M<B!D:6X@2&5L<"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@
M(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*
M(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T82!S=6)I
M96-T96QO<B!D:6X@2&5L<"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T
M+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI
M<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI
M<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S
M"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO
M8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M
M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO
M9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*
M;7-G:60@(DQO9R!I;B(*;7-G<W1R(")#;VYE8W1A<F4B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U
M<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")$96-O
M;F5C=&%R92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0HC+"!F=7IZ
M>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B0V]N96-T87)E(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@5&%S
M:W,B"FUS9W-T<B`B4V%R8VEN:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY-@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2XB"FUS9W-T<B`B(@HB4')O8FQE;6$@8W4@0V]N96-T87)E82X@4')O
M8F%B:6P@;G5M96QE(&1E(%5T:6QI>F%T;W(@<V%U+W-I(%!A<F]L82!S:6YT
M("(*(F=R97-I=&4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR
M"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*;7-G:60@(DQO;F<@=&5X
M="(*;7-G<W1R(")$96-O;F5C=&%R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM
M<V=S='(@(DQ,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM
M<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D
M;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED
M(")-86=I8R(*;7-G<W1R(")#;W)E<W!O;F1E;G1A(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(D-O<F5S
M<&]N9&5N=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS
M9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K
M92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*
M;7-G:60@(DUA;&%W:2(*;7-G<W1R(")#;W)E<W!O;F1E;G1A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC
M+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R(")#;W)E<W!O;F1E;G1A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")#
M;W)E<W!O;F1E;G1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS
M9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B
M36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS
M9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T
M<B`B071E;G1I92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!)
M;7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM
M<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*
M;7-G<W1R(")#:6UP=7)I('!O=')I=FET92`M(&1E('1R861U<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O
M<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG
M=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@HC+"!F=7IZ>0IM
M<V=I9"`B365M8F5R<R(*;7-G<W1R(").;W1E(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I
M9"`B365S<V%G92(*;7-G<W1R(")-97-A:B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE<V%J
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E
M(@IM<V=S='(@(DUE<V%J(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS
M9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"B,L(&9U
M>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R(")$971A;&EI(&EN<F5G:7-T<F%T92!I;B!,3T<@<&5N=')U(&%D
M;6EN:7-T<F%T;W(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@
M(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L
M;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@
M(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*
M;7-G:60@(DUI9&1L92(*;7-G<W1R(")#;W)E<W!O;F1E;G1A(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI
M;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q
M,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED
M(")-:7)R;W(B"FUS9W-T<B`B17)O87)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U
M,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED
M("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R
M871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@
M240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI
M<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-
M;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF
M:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DQU;F%R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B
M36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE
M("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#
M;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM
M<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V
M92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA
M<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C
M8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X
M"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(DEN9F]R;6%T:6D@9&5S<')E('1I;F4B"@HC.B!S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R
M=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY
M86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I
M9"`B3F%M92(*;7-G<W1R(").=6UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").
M86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE
M='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P
M92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI8VEO9&%T82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR
M-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV
M."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U
M"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W
M:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS
M9W-T<B`B3F]T92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*
M;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY
M"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B26YA<&]I(&QA(&]P=&EU
M;FDB"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B
M3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G
M=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").
M:6=E<B(*;7-G<W1R(").:6-I;V1A=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I
M9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DYU(&5S=&4@8V]N9FEG=7)A=&$@875T96YT:69I
M8V%R96$@4U%,(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B06YU;&5A>F$@4V-H:6UB
M87)I;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM
M<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W
M;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(DYU(&5S=&4@8V]N9FEG=7)A=&$@0V%T96=O<FEA
M(%-13"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"B,L(&9U
M>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B3G4@<VEN="!C;VYF:6=U<F%T
M92!0<F5F97)I;G1E;&4@3$1!4"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C8Y"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B3G4@
M97-T92!C;VYF:6=U<F%T82!#871E9V]R:6$@4U%,(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RXB"FUS9W-T<B`B3G4@97-T92!C;VYF:6=U<F%T82!#871E9V]R
M:6$@4U%,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G
M:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0IM<V=I9"`B3F\@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S
M86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S
M<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E
M8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L
M;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYU(&5S=&4@8V]N9FEG=7)A
M=&$@875T96YT:69I8V%R96$@4U%,(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P87-S=V0N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M3G4@97-T92!C;VYF:6=U<F%T82!A=71E;G1I9FEC87)E82!344PB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DYU(&5S=&4@8V]N9FEG=7)A=&$@875T96YT:69I8V%R96$@
M4U%,(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V
M"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG
M('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R
M(").;W1E(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS
M9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R(").;W1E(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@
M9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B5&4@<F]G
M(&EN=')O9'4@=6X@;G5M92!D92!U=&EL:7IA=&]R('-I(&\@<&%R;VQA(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V
M86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R
M,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T
M<B`B5&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE
M<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").
M;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO
M="!S970B"FUS9W-T<B`B3F]T92(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q
M,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU
M-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&4B"@HC
M.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM<V=I
M9"`B3F]V96UB97(B"FUS9W-T<B`B3FEC:6]D871A(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM
M<V=S='(@(DYU;64B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U
M"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I
M9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E
M<B!O9B!R;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S
M<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM
M<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G
M:60@(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS
M9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L
M82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B
M3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS
M9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB
M3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H
M86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*
M;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!T:75N:2(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B3W!T:75N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I
M9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5
M;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@
M(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%L=&4@:6YF;W)M871I:2(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B
M86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y
M"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U
M8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z
M>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G
M:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS
M9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@
M(E!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC
M;W)R96-T(@IM<V=S='(@(E!A<F]L82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(E!A<F]L82(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q
M"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E!A<F]L82(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM
M<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@
M(E!E;W!L92(*;7-G<W1R(")2;VQE("T@9&4@=')A9'5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E
M<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R(*;7-G<W1R(")%>&5C=71A($]P97)A=&EU;FEL92!D92!-
M96YT96YA;G1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@HC+"!F
M=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/R(*;7-G<W1R(")%>&5C=71A($]P97)A=&EU;FEL92!D92!-96YT
M96YA;G1A(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N
M(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU.#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E
M<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS
M9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*(RP@9G5Z>GD*;7-G:60@(E!E
M<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D%L=&4@:6YF;W)M871I:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS
M9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED
M(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@
M(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)
M4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E1E(')O
M9R!S<&5C:69I8V$@=6X@<W5M87(@86P@<')O8FQE;65I+B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0B"FUS9W-T<B`B5&4@<F]G(&EN=')O9'4@=6X@;G5M92!D
M92!U=&EL:7IA=&]R('-I(&\@<&%R;VQA(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI
M<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI
M<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H
M;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R
M97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*(RP@
M9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B26YA<&]I
M(&QA(&]P=&EU;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS
M9W-T<B`B6U)A<&]R="!0<F]B;&5M85TB"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1&5S8W)I97)E82!P<F]B;&5M96DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I
M9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS
M9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC
M($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H
M<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@
M(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B
M4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")2
M86YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S
M='(@(DUE<V%J(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T
M"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB
M"FUS9W-T<B`B4F5I;7!R;W-P871E87IA(%-U;6%R=6P@+2!D92!T<F%D=7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C,U"FUS9VED(")296=E>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@
M(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4B"FUS9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R
M;6%T=&EN9R(*;7-G<W1R(")3=&5R9V4@<&5R96-H96$B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS
M9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")3=&5R9V4@<&5R
M96-H96$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B
M"FUS9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B=U:60G(&YE<W!E
M8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@<')E9F5R:6YT92XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B)W5I9"<@;F5S<&5C:69I8V%T(&EN(&-O;F9I9W5R871I82!D92!P
M<F5F97)I;G1E+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)W5I9"<@
M;F5S<&5C:69I8V%T(&EN(&-O;F9I9W5R871I82!D92!P<F5F97)I;G1E+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I
M9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!0
M87-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T
M;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("));F%P;VD@
M;&$@;W!T:75N:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(DEN87!O:2!L82!O<'1I
M=6YI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D
M;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*
M;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2
M;VQE(@IM<V=S='(@(E)O;&4@+2!D92!T<F%D=7,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I
M9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T
M:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S
M"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R(")2;VQE("T@9&4@=')A
M9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P
M"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E)W86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H
M:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE
M<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@
M(DUE<V%J(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS
M9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B
M4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@
M(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")3
M86EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS
M9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E
M(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A
M=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V92`E<R(*;7-G<W1R(")386QV87IA($]P=&EU;FDB"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T
M<B`B4V%L=F%Z82!/<'1I=6YI(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E<F5D
M(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*
M;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(D9O<FUA='5L(&1E(&%F:7-A<F4@
M82!D871E:3HB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM
M<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE
M=R!O=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T
M(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS
M9W-T<B`B1F]R;6%T=6P@9&4@869I<V%R92!A(&1A=&5I.B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E
M;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U
M>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B
M"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB
M06QE9V4@8V%R86-T97)E;&4@9&4@8V%R92!A:2!N979O:64@9&EN(&-A<W5T
M96QE(&1E(&UA:2!J;W,N(%9E:2!P=71E82!A<&]I("(*(G-A(&QE(&-O<&EE
M>FD@:6X@>F]N82!D92!T97AT+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G
M<W1R(")$96QI;6ET871O<B!D92!D871A.B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*
M;7-G<W1R(")&;W)M871U;"!D92!A9FES87)E(&$@9&%T96DZ(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")$96QI
M;6ET871O<B!D92!D871A.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")&
M;W)M871U;"!D92!A9FES87)E(&$@;W)E:3HB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RXB"FUS9W-T<B`B4V5L96-T96%Z82!D;W5A(&-I;7!U<FD@<&]T<FEV
M:71E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.B(*;7-G<W1R(")396QE8W1E87IA(&QI;6)A('!R969E
M<F%T83HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM
M<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")4<FEM:71E(%)A
M<&]R="!D92!%<F]A<F4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@
M(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!
M9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS
M9VED(")397-S:6]N<R(*;7-G<W1R(")386QV87IA($]P=&EU;FDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@
M;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I
M9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z
M>GD*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO
M;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B06QE9V4@=&EM<'5L(&1E
M(')E:6UP<F]S<&%T87)E(&$@<&%G:6YI:2!S:2!A;'1E(&]P=&EU;FD@9&4@
M869I<V%R92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*(RP@9G5Z
M>GD*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES
M<&QA>2!O<'1I;VYS+B(*;7-G<W1R(")!;&5G92!T:6UP=6P@9&4@<F5I;7!R
M;W-P871A<F4@82!P86=I;FEI('-I(&%L=&4@;W!T:75N:2!D92!A9FES87)E
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@
M(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B4W5M87(@<V-U<G0Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K
M97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3
M:&]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*
M;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM
M<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS
M9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@
M<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E
M('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P
M"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@
M(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@
M8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I
M9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG
M;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B
M4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")387)I('!E<W1E($UE;G1E;F%N
M=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I
M9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*
M;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W
M97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B
M4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O
M;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B
M"FUS9W-T<B`B061R97-A(&QA(%-E<G9I8VEU(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R
M9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS
M9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U
M"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C
M96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q
M-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P
M86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS
M9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")#87)A8W1E
M<F4@4W!E8VEA;&4@+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S
M='(@(DEM<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L
M:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R(")#86QE;F1A<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@
M4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS9VED(")3
M=&]R86=E(&9O<FUA="(*;7-G<W1R("));F9O<FUA=&EI(&1E<W!R92!T:6YE
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@
M9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!L
M82!397)V:6-I=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG
M(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM
M<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F]T:69I8V%T:6]N(&QI<W1E
M;F5R("5S(&YO="!F;W5N9"X@+2!D92!T<F%D=7,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U
M8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@
M(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I
M9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R
M(")3=6-C97,B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B4W5M87)U;"!-974B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*
M;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N
M;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@
M(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3
M=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P
M97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("));7!O
M<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*
M;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T
M<B`B571I;&EZ871O<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D
M(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I
M9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE
M<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM
M<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R
M;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S
M"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@
M9FEL92(*;7-G<W1R(")4:71L=2(*"B,Z(&9R86UE=V]R:R]522]522]486)L
M92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R(")4:71L
M=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM
M<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE
M('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G
M970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS
M9W-T<B`B4V%R8VEN:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S
M2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B
M5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U
M"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X
M="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*
M;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO
M=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B06D@9F]S="!D96-O
M;F5C=&%T+CQB<B`O/DUU;'1U;65S8R!C82!F;VQO<V5S=&D@<VES=&5M=6PN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@
M9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-
M4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM
M<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E
M(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED
M(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B
M(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*
M(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D
M('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q
M"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE
M<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I
M;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@
M96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN
M96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S
M('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O
M;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C
M;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P
M<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R
M965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE
M(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I
M;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#
M<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S
M7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT
M964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O
M;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@
M9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B06-E87-T82!V86QO
M87)E('1R96)U:64@<V$@9FEE(&YU;65R:6-A+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@
M;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N
M8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A
M(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP
M.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN
M="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP
M.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z
M,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN
M<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*
M;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G
M:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I
M9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@
M;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@
M=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E
M<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP
M.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3G4@97AI<W1A('!R969E<FEN=&4@
M9&ES<&]N:6)I;&4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9
M;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N
M=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU
M,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@
M)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A
M<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@
M=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B
M"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL
M<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM
M<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I
M;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0HC
M+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L
M:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D%C96%S=&$@=F%L;V%R92!T<F5B
M=6EE('-A(&9I92!N=6UE<FEC82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L
M:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T
M;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O
M=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BXB"FUS9W-T<B`B06-E87-T82!V86QO87)E('1R96)U:64@<V$@
M9FEE(&YU;65R:6-A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C
M,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C
M97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN
M8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J
M96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA
M:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE
M;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B5F%L;V%R96$@
M;6EN:6UA(&5S=&4@,2(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D%C96%S=&$@
M=F%L;V%R92!T<F5B=6EE('-A(&9I92!N=6UE<FEC82XB"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T
M<B`B5&ET;'4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS
M9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M
M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I
M9"`B5&ET;&4B"FUS9W-T<B`B5&ET;'4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I
M<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*
M(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI
M;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(
M5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@
M5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B
M5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI
M<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO
M:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS
M9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")5
M4DPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3G4@
M;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I
M9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B
M3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O
M;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L
M82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U
M-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!3
M44PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T
M<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB
M"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I
M9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L
M82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYU('!O="!I;G)E9VES=')A
M('!R969E<FEN=&5L92!I;B!S97-I=6YE("T@9&4@=')A9'5S(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO
M3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@
M4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@
M4U%,+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R
M=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX,S4*;7-G:60@
M(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C8*;7-G
M:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A
M:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O
M(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@
M<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(").=2!P;W0@=')A9'5C92!A
M8V5S="!D;V-U;65N="!7;W)D("T@9&4@=')A9'5S(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E
M9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N
M9V5S(@IM<V=S='(@(D%N=6QE87IA(%-C:&EM8F%R:6QE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI
M<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@
M2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET
M960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R
M;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5
M;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I
M9"`B56YN86UE9"(*;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED
M(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D
M871E('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@
M861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS
M9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E
M;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B571I;&EZ871O
M<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*
M;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T
M:6]N<R(*;7-G<W1R(")/<'1I=6YI(%5T:6QI>F%T;W(B"@HC.B!S:6=N=7`N
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G
M<W1R(")/<'1I=6YI(%5T:6QI>F%T;W(B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S
M='(@(E5T:6QI>F%T;W(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<
M(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB
M"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B
M571I;&EZ871O<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G
M:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G
M:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@
M(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I
M9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G
M:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")6
M97)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I
M9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I
M;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED
M(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I
M82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI
M<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!
M=&5N=&EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*
M;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N
M8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS
M9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E
M:VQY(@IM<V=S='(@(E-A<'1A;6EN86PB"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R
M(")":6YE(&%I('9E;FET+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D)I;F4@86D@
M=F5N:70@:6X@<VES=&5M=6P@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0FEN92!A:2!V
M96YI="P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@
M(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@
M=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G
M:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED
M=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO
M=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G
M:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H
M;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*
M;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS
M9W-T<B`B061R97-A(&QA(%-E<G9I8VEU(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*
M;7-G<W1R(")496QE9F]N(&QA(%-E<G9I8VEU(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED
M(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G
M:60@(EE965DB"FUS9W-T<B`B04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B06YU86PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED
M(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B
M;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS
M,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D
M<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N
M>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S
M<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")/<'1I=6YI;&4@874@9F]S
M="!S86QV871E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*
M;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE
M(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB
M9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M(")4<F5B=6EE('-A(&1E<V-R:6D@<')O8FQE;6$@:6YA:6YT92!D92!A('1R
M:6UI=&4@<F%P;W)T=6PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HV
M,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@
M<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(E-E<VEU;F5A('1A(&1E("5S(&$@97AP:7)A
M="X@5&4@<F]G('-A(&9A8VD@3&]G($EN(&1I;B!N;W4N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")!9')E<V$@=&$@9&4@16UA:6PZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")!9')E<V$@=&$@9&4@
M16UA:6PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DEN9F]R;6%T:6D@9&5S<')E('1I;F4B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(DYU;65L92!T874Z(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B
M(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I
M9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ
M<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM
M<V=S='(@(D]P=&EU;FEL92!A=2!F;W-T('-A;'9A=&4N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$U.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A
M=6QT(&ED96YT:71Y.B(*;7-G<W1R("))9&5N=&ET871E($EM<&QI8VET82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(").=6UE;&4@=&%U.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(D]P=&EU;FEL92!A=2!F
M;W-T('-A;'9A=&4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R
M("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S
M:6]N+B(*;7-G<W1R(")/<'1I=6YI;&4@874@9F]S="!S86QV871E+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(D]P=&EU;FEL
M92!A=2!F;W-T('-A;'9A=&4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B
M66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0
M<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U)A<&]R="!0<F]B;&5M85TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R
M"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*
M;7-G<W1R(");;&EN:6$@)7,@9&EN("5S72(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q
M"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM
M<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](96QP
M(@IM<V=S='(@(DAE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-
M96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B
M0V]N96-T87)E(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B1&5C;VYE
M8W1A<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L
M(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")/<'1I=6YI(@H*(SH@
M;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS
M9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS
M9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*
M;7-G:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM
M<V=S='(@(D%G96YD82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F=7IZ>0IM
M<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B0V%L96YD87(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E
M871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO
M;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES
M<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G
M:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B5&ET;'4B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I
M;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM
M<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@
M(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@HC
M+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R(").=6UE(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED
M(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P
M:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D%T96YT
M:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM
M<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I
M9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y
M(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("),
M82!F:65C87)E($-O;F5C=&%R92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B
M=D-A<F0B"FUS9W-T<B`B=D-A<F0@+2!D92!T<F%D=7,B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM
M<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P;R]R=5]252YP;P``````````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P-C8U,S(T`#$P-#$W,S8S,#`S`#`Q-C0T,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C($AO
M<F1E(%)U<W-I86X@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*0HC($EG
M;F%T($EK<GEA;F]V(#QI:6=N871`;F5W;6%I;"YR=3XL(#(P,#$*(R!&961O
M<B!!+B!&971I<V]V(#QF869`<W-C+G)U/BP@,C`P,@HC($%L97AE>2!:86MH
M87)O=B`\8F%B97)`;6]S9V$N;F5T/BP@,C`P-@HC"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92!V,RXQ+5)#,UQN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3`W(#$Q.C$P*S`R,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,3<@,3<Z,#`K,#(P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!!;&5X97D@6F%K:&%R;W8@/&)A8F5R0&UO<V=A
M+FYE=#Y<;B(*(DQA;F=U86=E+51E86TZ(%)U<W-I86X@/&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3%<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T
M:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B(*;7-G
M<W1R("(B"B+/\.CK[N;E[>CE("5S(./N\N[B[B#J(.[Q\_GE\?+BZ^7MZ/X@
M[N_E\.#VZ.D@[^[DY.7PYNKH+"#N\NSE]^7M[?OU(.WHYN4N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E
M<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S<T
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,X,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S<W"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@
M(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B
M(&%T("(*;7-G<W1R("(B"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T
M;W)Y+B(*;7-G<W1R("+*X/+@Z^[C(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z
M,C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN
M(.'[\OP@]^CQZ^[L+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-S$P
M(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(
M;W)D92!296=I<W1R>2XB"FUS9W-T<B`BS_#HZ^[FY>WHY2`G)7,G(.WE(/'J
M[NWTZ./S\.CP[N+@[>X@XB!(;W)D92!296=I<W1R>2(*"B,Z(&QI8B](;W)D
M92]4<F5E+G!H<#HQ-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@
M\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(
M,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB
M"B+/X._JX"!<(B5S7"(@X?OKX"#S\>_E^.WN(._E\.7H[.7M[N+@[>`@XB!<
M(B5S7"(N7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I
M("`C+2,M(RTC+2-<;B(*(EOQ\O#NZN`@)7,@Z.<@)7-=7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(EOQ
M\O#NZN`@)7,@Z.<@)7-=7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(EOQ\O#NZN`@)7,@Z.<@)7-=7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC
M+2-<;B(*(EOQ\O#NZN`@)7,@Z.<@)7-=7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(EOQ\O#NZN`@)7,@
MZ.<@)7-=(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL
M;W=E9"`H)2XR9B4E*2(*;7-G<W1R("+(\>_NZ_SG[N+@[>XZ("4N,F;,X2#H
MYR`E+C)FS.$@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A
M;F0@)7,B"FUS9W-T<B`B6_'R\.[JX"`E<R#HYR`E<UTB"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S
M<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@
M9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C8X('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G
M<W1R("+'X.SE\NKH(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,"!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0R"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HT.2!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC
M.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("+.[^7PX/;H_R#O[N3DY?#F
MZN@@)7,@+2#/[N3RXN7PYN3E[>CE(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I
M9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4Y('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*
M;7-G<W1R("(B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#,R(&QI8B]61E,O<VUB
M+G!H<#HT.30@;&EB+U9&4R]F='`N<&AP.C8X,@HC.B!L:6(O5D93+V9T<"YP
M:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y
M;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BSO+L
MY?+\\N4@].O@YNK@[.@@[N_E\.#VZ/XHZ.@I+"#J[O+N\/OE(,+[(/7N\NCR
MY2#N\?/YY?'RXNCR_"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(EOQ\O#NZN`@)7,@
MZ.<@)7-=(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDR,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!
M9&1R97-S($)O;VLB"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDQ,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDP-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDR.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A
M<VML:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M
M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@
M0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@
M<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0HC+"!F
M=7IZ>0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R(");\?+P[NK@("5S(.CG
M("5S72(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#<S(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3,R(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,S0X(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HW-#8*(RP@9G5Z>GD*;7-G:60@(BTM('-E;&5C="`M
M+2(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N
M,2D@(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*(R!F=7IZ>0HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S
M='(@(C$R+??@\>[B[NDB"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0M]^#Q[N+N
MZ2(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H
M;W5R<R(*;7-G<W1R("(R-"#WX/'@(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R
M+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(L_P
MY>3[Y//YX/\@\?+PX.WH]N`B"@HC.B!L:6(O2&]R9&4N<&AP.C$V,@HC+"!F
M=7IZ>0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T
M<B`B/&(^S_#NZ.?N^.O@(.KPZ/+H]^7QZN#_(.[XZ.'JX#H\+V(^(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"B,L(&9U>GIY"FUS9VED(")!
M32!#;&]U9',B"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`HC+"!F=7IZ>0IM<V=I9"`B04T@
M3&EG:'0@4F%I;B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*(RP@9G5Z>GD*;7-G:60@(D%-(%)A
M:6XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,@HC+"!F=7IZ>0IM<V=I9"`B04T@4VAO=V5R
M<R(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,PHC+"!F=7IZ>0IM<V=I9"`B04T@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(LCL[^[P\B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T
M+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(D%B<V)O='1O;2(*;7-G
M<W1R("+"[.7Q\N4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"B,L(&9U>GIY"FUS9VED(")!8G-M:61D;&4B"FUS9W-T
M<B`B24U0(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P"B,L(&9U>GIY"FUS
M9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(M/WY?+MX/\@Y^#OZ/'\(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<X"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(L_@\.[K_"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS
M9W-T<B`BT^_PX.+KY>WHY2#Q]^7RX.SH(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,S-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G
M<W1R("+$\//CZ.4@__GHZN@B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B
M061D(@IM<V=S='(@(L3NX>#BZ/+\(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U
M<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B++Z/?M^^4B"@HC(&9U
M>GIY"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@
M2&5R93HB"FUS9W-T<B`BQ.[AX.+H\OPZ(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O
M=7`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@X"B,L(&9U>GIY"FUS9VED(")!9&0@
M3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K
M_R(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(LW@\?+P
M[NGJZ"(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A
M(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(LW@\?+P[NGJ
MZ"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E
M<CHB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4U-`HC+"!F=7IZ>0IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC
M+2,M(RTC7&XB"B+D[N'@XNCR_"#Q\N[KX>7V(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE
M=R!M96UB97)S(@IM<V=S='(@(L3NX>#BZ/+\(._@\/,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R
M("+$[N'@XNCR_"#OX/#S(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF
M;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<Q"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(B"FUS9W-T<B`BQ.[AX.+H\OP@36]Z:6QL82!3:61E8F%R(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F=7IZ
M>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BP.3PY?'M
MX/\@ZNWHX^`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM
M<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(L3NX>#BZ/+\(._@
M\/,B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*
M;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0U(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@
M(L#D\.7Q(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I
M9"`B061D<F5S<R!";V]K(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(R!F
M=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`BS>#Q\O#NZ>KH("T@
M\_'RX.WNXNK@(._PX.(@Y.O_(.3P\^/H]2#O[NO\Y^[BX/+EZ^7I(@H*(R!F
M=7IZ>0HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MT^_PX.+KY>WHY2(*"B,@(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(PHC(&9U>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-#,*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R("+$[N'@XNCR
M_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-38*(RP@9G5Z>GD*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(LW@\?+P
M[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM
M<V=S='(@(L_QY>+D[NWH["(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L9V5R:6$B"FUS
M9W-T<B`BS_'EXN3N[>CL(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(L_QY>+D[NWH["(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D%L:6=N(@IM<V=S='(@(L_QY>+D[NWH
M["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C<*(RP@9G5Z>GD*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`BS_'EXN3N
M[>CL(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N
M=&EC871E9"!5<V5R<R(*;7-G<W1R("+"\>4@XN[XY>3XZ.4B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!
M;&P@1W)O=7!S(@IM<V=S='(@(L+QY2#C\//O[_LB"@HC(&9U>GIY"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(L+Q
MY2#O\.#BX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*(RP@9G5Z>GD*;7-G:60@(D%L;"!F;W5R('-I9&5S
M(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W
M-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(M#@Y_#E^.CR
M_"#N[^7PX/;HZ"#Q[B#Q[^CQZN#LZ"(*"B,Z(&QI8B](;W)D92]$871A5')E
M92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N
M871E($E-4U`@3&]G:6XB"FUS9W-T<B`BP.O\\N7P[>#RZ.+M^^D@25--4"(*
M"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B
M06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%5S97)N86UE(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\@25--4#HB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM
M<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BPN#X($5M
M86EL.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E
M<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0HC+"!F=7IZ
M>0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(L+@^"!%;6%I;#HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U
M"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S
M='(@(L'[Z^X@\^K@Y^#M[B#MY>KN\/#EZO+M[N4@Y^W@]^7MZ.4N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0HC+"!F=7IZ>0IM<V=I
M9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B/&(^
MS_#NZ.?N^.O@(.KPZ/+H]^7QZN#_(.[XZ.'JX#H\+V(^(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD
M;W)R82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G
M:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS
M-2!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S
M='(@(L_PZ.ONYN7MZ.4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*
M(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`BS>#Q
M\O#NZ>KH(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B
M07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(LW@\?+P[N7M[B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T
M;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,`IM<V=I9"`B
M07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G:60@(D%R86)I8R`H5VEN9&]W
M<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>0IM
M<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`BR.S_(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S<*(RP@9G5Z>GD*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R
M("+([/\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_
M(@IM<V=S='(@(L+[(//BY?#E[?LL(/?R[B#U[O+H\N4@[O?H\?+H\OP@_?+S
M(._@[^KS/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("+/
M\>7BY.[MZ.PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(L_Q
MY>+D[NWH["(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@
M(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS
M9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y
M"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`BQ^#O\.#XZ.+@\OP@[^[D
M\N+E\.;DY>WHY2#OY?#EY"#B^^_NZ^WE[>CE["#N[^7PX/;HZ2#NX?'K\^;H
MXN#MZ/\_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#(*(RP@9G5Z>GD*
M;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+D
M[N'@XNCR_"#Q\N[KX>7V(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(L_N[_ORZN`@\^3@Z^CR_"#MY?'S^>7Q\N+S_OGHY2#O\.#B
MX"(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
MS^[O^_+JX"#PY>3@ZO+H\.[BX/+\(.WE\?/YY?'RXO/^^>CE(._PX.+@(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8T(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L
M+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!
M=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED
M("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET
M8V@N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8T
M"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H
M7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]M
M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!9&UI;BYP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")!
M=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`HC+"!F=7IZ>0IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(L#D\.7QX/(@
M\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE
M[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N
M<&AP.C$W-@HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H
M[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX
M.#(*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E
M\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY
M"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@
M3$1!4"XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED
M(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R("+$[O'R\^_M^^4@[^[K_SHB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*
M;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`BR/'O[NO\Y^[BX/+\(.?MX/?E
M[>CE(._N(//L[NOWX.WH_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C,*(RP@9G5Z>GD*;7-G:60@(D)A8VMG<F]U;F0@
M0V]L;W(B"FUS9W-T<B`BR/'O[NO\Y^[BX/+\(.?MX/?E[>CE(._N(//L[NOW
MX.WH_B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"
M860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA
M;64N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)A:&%M87,B"FUS9W-T
M<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R
M("))35`B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B0F%L
M=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S
M:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(M/DX.OE[>W[Y2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`HC+"!F
M=7IZ>0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("+0X.?LY?`B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY
M"FUS9VED(")"96QI>F4B"FUS9W-T<B`BT.#G[.7P(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I
M9"`B0F5N:6XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(M/DX.OE[>W[Y2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E
M<FUU9&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0FAU=&%N(@IM<V=S
M='(@(DE-4"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("+$Y>W\(/#NYN3E[>C_(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T
M:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[L
MZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G
M<W1R("+-X/'R\.[IZN`Z(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(M#@\?CH\.7MZ.4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*
M(RP@9G5Z>GD*;7-G:60@(D)O;&0B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M;VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U
M>GIY"FUS9VED(")";W)D97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D
M97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED
M(")";W)D97)S(@IM<V=S='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(
M97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(D)O='1O;2(*;7-G<W1R("+"[.7Q
M\N4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*
M;7-G:60@(D)R87II;"(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE
M:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)U;&=A
M<FEA(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-2
M3"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PHC+"!F
M=7IZ>0IM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+*Z^7R
M[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C
M;VUP;&5T960N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@S(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BRN#KY>WDX/#\(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0HC+"!F=7IZ>0IM
M<V=I9"`B0V%L;2(*;7-G<W1R("+.\NSE[>`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PHC+"!F=7IZ>0IM<V=I9"`B
M0V%M8F]D:6$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B
M0V%M97)O;VXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LOH]^W[Y2(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A
M<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,U,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE
M(%PB)7-<(B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,
M(/'E\.+E\.[L+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B
M0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI
M8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*
M;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N
M(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(L[R[.7MX"(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@
M4')O8FQE;2!297!O<G0B"FUS9W-T<B`BSO+LY>W@(.[R]^7RX"#N(._P[N'K
MY>SE(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SN
MY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BS>4@[.[C\R#N\NKP
M^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E
M+T1A=&%4<F5E+G!H<#HQ,C@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E
M+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\
M(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ
M>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O
M3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@
M(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("+*X/+EX^[PZ.@@Z"#L
MY?+JZ"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*
M(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("+*Z^7R
M[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,@(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@HC+"!F=7IZ
M>0IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\
M(.K@ZEQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M
M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R-S@*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("+*Z^7R
M[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W
M"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V
M"B,L(&9U>GIY"FUS9VED(")#96YT97(B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G
M:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5N=')A;"!%=7)O<&5A
M;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS
M9W-T<B`B(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C$R"B,L(&9U>GIY"FUS9VED(")#97)T
M:69I8V%T92!/=VYE<B(*;7-G<W1R("+(\>K@\OP@XB#.\N+E\O'RXN7M[?OU
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E
M<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I
M9"`B0VAA9"(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G<W1R("+.\NSE[>CR_"#HY^SE
M[>7MZ/\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@
M9G5Z>GD*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(L_@
M\.[K_"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB
M0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W
M:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM
M<V=S='(@(LW@\?+P[NGJZ"#H[.7MZ"P@X.3PY?'@+"#O[N3OZ/'H+B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA
M;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE
M(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#
M:&%R(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#
M:&5C7VL@3&EN:RXN+B(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("+.\NSE\OSRY2#TZ^#F
MZN#LZ"#N[^7PX/;H_BCHZ"DL(.KN\N[P^^4@POL@]>[RZ/+E(.[Q\_GE\?+B
MZ/+\+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM<V=S='(@(L?@X^[K[N+N
MZB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6YA(@IM<V=S='(@(G9#87)D(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS
M9W-T<B`B(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW
M"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(L+[X>7PZ/+E
M(._PZ.ONYN7MZ.4Z(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR
M-S`*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M
M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N
M<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB
M"FUS9W-T<B`BU.[P[.#R(.[R[N'PX.;E[>C_(.3@\OLZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM
M<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+U9&4RYP:'`Z.3$T(&QI8B].970O4TU3+G!H<#HR.30*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_
M("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`B
MRN#KY>WDX/#\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED
M(")#;&5A<B!1=65R>2(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(M/DX.OH\OP@
M[^#P\R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0HC
M+"!F=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("+*X.OE[>3@\/PB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`HC+"!F=7IZ
M>0IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(LK@Z^7MY.#P_"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L
M(&9U>GIY"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(L+U[N0B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`HC
M+"!F=7IZ>0IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`BS>#Q
M\O#NZ>KH(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`BQ^#J\/OR
M_"#NZNWN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("+*
M[NSOX.WH_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$W"B,L(&9U>GIY"FUS9VED(")#;&]U9'DB"FUS9W-T<B`BRN[L[^#M
MZ/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B
M"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*
M;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`BT^'PX/+\(.SE[?XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(X"B,L(&9U>GIY"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G
M<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M
M(RTC+2,M(UQN(@HBT.#GXN7P[?/R_"#B\>4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#
M;VQO;6)I82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O0FQO8VLO8V]L
M;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0HC+"!F=7IZ
M>0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-2!L:6(O2&]R9&4O0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S(V"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,#$@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,@HC+"!F=7IZ>0IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(LCL
M[^[P\B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#,U"B,L(&9U>GIY"FUS
M9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+H
MY3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,PHC+"!F=7IZ>0IM<V=I9"`B0V]L<SHB"FUS9W-T<B`BRN#KY>WDX/#\
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M;B!T
M:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(V-@HC+"!F=7IZ>0IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(LK@Z^7MY.#P
M_"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B
M0V]M;6%N9"(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D-O
M;6UE;G0B"FUS9W-T<B`BRN[L[^#MZ/\B"@HC(&9U>GIY"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")#;VUM;VX@
M3F%M92(*;7-G<W1R("+"X/CE(.CL_SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B0V]M
M;W)O<R(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+*
M[NSOX.WH_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*
M(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("+-X/'R\.[IZN@B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I
M9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(LKN[?3HX_/PX/;H
M_R#S\?+@\.7KX"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*(RP@9G5Z>GD*
M;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@HC+"!F
M=7IZ>0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`BRN[L\R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7M
MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G
M<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z.#<V"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CM
MY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.C$P,30*(RP@9G5Z>GD*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(L_N
MZN#GX/+\(,KN[?+@ZO+[(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT
M('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S
M(&]F(%PB)7-<(B(*;7-G<W1R("+1[N3E\.;@[>CE("5S(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("+-
MX/'R\.[IZN@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Q"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S='(@(LKN[._@[>C_(@H*
M(SH@;&EB+U9&4R]S;6(N<&AP.C0W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC7&XB"B+.^.CAZN`@[_#H(//DX.OE[>CH7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBS>7S
MY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+EQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*
M(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"B,L(&9U
M>GIY"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBQ.7I
M\?+BZ.4Z(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$W,"!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T
M92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HY-S<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E.B`B"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-
M86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3`U-0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4Z("(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT
M96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I
M;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-#8W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@
M;65S<V%G92XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN
M=&5N86YC95]487-K("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@
M[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M
M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(LWE(.SNX_,@
M[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@
M\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B
M"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM
M[B#MX/'R\.[E[2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B
M"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]4
M87-K("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C,*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*
M;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A
M<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM[B#MX/'R
M\.[E[2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+H
MZ_SM[B#MX/'R\.[E[2(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B2&]R9&4@
M[>4@[_#@XNCK_.WN(.W@\?+P[N7M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HS.#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34S"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+-Y2#L
M[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D
M\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*
M;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A
M<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(LWE(.SN
MX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C<Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB
M"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("+-Y2#L[N/S
M(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HR-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N("5S+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA
M:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-
M86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("+-Y2#L[N/S(.[R
MZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-
M86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N
M(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(LWE(.SN
MX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N
M;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N
M(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C
M="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.2!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X,PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@
M(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(")(;W)D92#MY2#O\.#BZ.O\[>X@[>#Q\O#N
MY>TB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")(;W)D92#MY2#O\.#B
MZ.O\[>X@[>#Q\O#NY>TB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI
M=&EE<R(*;7-G<W1R(")(;W)D92#MY2#O\.#BZ.O\[>X@[>#Q\O#NY>TB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E
M(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R
M("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CM
MY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E
M;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS.38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(LWE(.SN
MX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK_.WN(.W@\?+P[N7M(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@
M9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B
M87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L
M9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O
M<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,C,*(RP@9G5Z>GD*;7-G:60@(D-O=6YT960@=&5X
M="(*;7-G<W1R("+"^_7NY"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3<P"B,L(&9U>GIY"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB
M"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C<U"B,L(&9U>GIY"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(M/Q[^7X
M[>XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("+1[N?DX/+\
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S
M='(@(M'NY^3@\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`BT>[GY.#R_"#M[N+[Z2#O\.[TZ.O\(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E
M<G,B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("+1
M[N?DX/+EZ_PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q.0HC+"!F=7IZ
M>0IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(LCL_R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"B,L
M(&9U>GIY"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(M'NY^3@\OPB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#=6)A(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S
M='(@(M+EZO/YX/\B"@HC(&9U>GIY"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU
M,`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("+1
M[N?DX/+EZ_PB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO
M=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("+2Y>KS
M^>7E(.+PY>S_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4T"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%52
M3"!I<R(*;7-G<W1R("+2Y>KS^>7E(.+PY>S_(@H*(R!F=7IZ>0HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E
M<G,B"FUS9W-T<B`BTN7J\_G@_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-C0*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R("+2Y>KS^>7E(.+PY>S_(@H*(R!P:'`M9F]R;6%T
M"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS
M9W-T<B`BQ^#DX/?H+"#GX._S\>K@Y>S[Y2#O\.@@XO7NY.4@XB`E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0W5T(@IM<V=S='(@(B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+N
MY2#Q[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,U"B,L(&9U>GIY"FUS9VED(")#=70@<V5L96-T:6]N(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@
M(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-Y<FEL
M;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3`@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(D1$(@IM<V=S='(@(L3$(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M-SD*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I
M9"`B1&%I;'DB"FUS9W-T<B`BQ>;EY.WEXNWN(@H*(SH@861M:6XO9&%T871R
M964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<W"FUS9VED(")$871A8F%S92!,
M;V]K=7`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#(@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A
M=&4B"FUS9W-T<B`BQ.#RX"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDV"B,L(&9U>GIY"FUS9VED(")$
M871E('-E;&5C=&EO;B(*;7-G<W1R("+/[NOM[N4@[N_H\>#MZ.4Z(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T
M<B`BQ>;EY.WEXNWN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L971E
M($-O;'5M;B(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(D1E8V5M8F5R(@IM<V=S
M='(@(L?@[.7RZN@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`BR.S_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT
M(@IM<V=S='(@(B(*"B,Z(&QI8B]P<F5F<RYP:'`Z,3$W(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3@W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S
M='(@(M/DX.OH\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM
M<V=S='(@(M;BY?(@[^X@\^SNZ_?@[>C^(@H*(SH@;&EB+TAO<F1E+TED96YT
M:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("+/
M\.[TZ.O\(._N(//L[NOWX.WH_B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("+3
MY.#KZ/+\(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C,R-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C0S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDX('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E
M(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!#96QL(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R
M;W5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("+3Y.#K
MZ/+\(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-R!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PHC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("+1[N[A^>7M
MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R
M("+3Y.#KZ/+\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M
M;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V
M,2XQ*2`@(RTC+2,M(RTC7&XB"B+SX?#@\OP@\?+NZ^'E]B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("+-X/'R\.[IZN@@
M[^[K_.?NXN#RY>O_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E(')O=R(*;7-G<W1R("+3Y.#KZ/+\(@H*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$
M96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`BT^3@Z^CR_"#B^^'P
MX.WM^^D@[_#N].CK_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+SX?#@\OP@
M\?+NZ^'E]B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(')O=R(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("+-
MY2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS
M9W-T<B`BT^3@Z^CR_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R
M:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(L[OZ/CH\N4@[_#NX>OE[/,B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.30R('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E
M<V-R:7!T:6]N(@IM<V=S='(@(L_NZ^WNY2#N[^CQX.WHY3HB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C(P,0IM
M<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`BS^[D\.[A[>[Q\N@@X?OKZ"#GX._H\>#M^R#B
M(.;S\.W@ZR#DZ_\@X.3LZ.WH\?+PX/+N\.`N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B
M1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@
M=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O
M(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*
M;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("+*X/+@Z^[C(@H*(R!F=7IZ>0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_(@IM<V=S='(@(L[R[N'PX.;@\OP@XO#E[/\@XB`R-"WW
MX/'NXN[L(/3N\.S@\N4_(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BQ/#S
MX^CE(.W@\?+P[NGJZ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HX.0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M="(*;7-G<W1R("+-X/'R\.[IZN@@[N'NZ^[WZN@B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C@P-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B
M"FUS9W-T<B`BS>#Q\O#NZ>KH(.[A[NON]^KH(@H*(SH@;&EB+TAO<F1E+TU)
M344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@
M;F]T(&1E;&5T92(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("+-Y2#B^^?[XN#I\N4@;6%I;G1E
M;F%N8V4N<&AP(.WE[^[Q\.7D\?+BY>WM[B(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R
M"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(L(@[^7P
MXN[I(/'R\.[JY2#SZN#GX.W[(.CLY>W@(._NZ^7I/R#%\>OH(.3@+"#O[O'R
MX.+\\N4@X^#K[O?J\SH@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B1&]M:6YI8V$B"FUS
M9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G
M:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B
M(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Q
M"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("+'X./P\^?H\OPB"@HC.B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(L?@X_#SY^CR_"`E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@
M;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R("))35`B"@HC.B!L
M:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`BT.7DX.KRZ/#NXN#M
MZ.4B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`*;7-G
M:60@(D5D:70@0FQO8VLB"FUS9W-T<B`BT.7DX.KRZ/#NXN#R_"(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED
M(")%9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#`*(RP@9G5Z>GD*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("+-X/'R\.[IZN@@[^[K
M_.?NXN#RY>O_(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PHC
M+"!F=7IZ>0IM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("+-X/'R
M\.[IZN@@[^[K_.?NXN#RY>O_(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U
M>GIY+"!P:'`M9F]R;6%T"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@
M)7,B"FUS9W-T<B`BT_'RX.WNXNK@(._PX.(@Y.O_("5S(@H*(R!F=7IZ>2P@
M<&AP+69O<FUA=`HC(&9U>GIY"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(LW@\?+P[NGJ
MZ"(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC(&9U
M>GIY+"!P:'`M9F]R;6%T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,R!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS
M9W-T<B`B16UA:6PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V
M-B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@
M(D5M86EL($%D9')E<W,B"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.38W"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"XB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.3DS"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+/\.[WX/\@Z.WT[O#LX/;H_R(*
M"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M
M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D5M
M;W1I8V]N<R(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@
M;65S<V%G92XB"FUS9W-T<B`BS?/KY>+NZ2#PY>?SZ_SRX/(N(@H*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`BS?/K
MY>+NZ2#PY>?SZ_SRX/(N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP
M:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM
M<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T
M<B`BRN[M\N7J\?+M[N4@[.7M_B#O[B#MX.;@\NCH(._PX.+NZ2#J[>[OZN@@
M[/OXZ"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DR(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#`P"B,L(&9U>GIY"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC
M+2,M(UQN(@HBT.#GXN7P[?/R_"#B\>4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@Y,`IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L
M;W<Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0X"FUS9VED(")%<G)O<B(*;7-G<W1R("+.^.CAZN`B
M"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R
M:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*
M(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%
M=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(LK@YN3[Y2`Q-2#LZ.WS\B(*"B,@
M9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E
M<GD@,B!M:6YU=&5S(@IM<V=S='(@(LK@YN3[Y2`R(.SH[?/R^R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("+*X.;D^^4@
M,S`@\>7J\^WD(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@
M;6EN=71E<R(*;7-G<W1R("+*X.;D^^4@-2#LZ.WS\B(*"B,Z(&QI8B](;W)D
M92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S
M='(@(LK@YN3[Z2#PX.<@[_#H(.+U[N3E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(LK@
MYN3[Y2#O[NOWX/'@(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y
M(&UI;G5T92(*;7-G<W1R("+*X.;D\_X@[.CM\_+S(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*
M;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#<U(&QI8B](;W)D92]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T
M<B`BT.#Q^.CPZ/+\(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHS,@HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC
M+2-<;B(*(M#@Y^+E\.WS\OP@XO'E(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW
M;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP
M:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q
M"B,L(&9U>GIY"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("+(\>_NZ_SG[N+@
M\OP@Y^W@]^7MZ.4@[^X@\^SNZ_?@[>C^(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("+"[O'Q\N#M
M[N+KY>WHY2#MX/'R\.[EZB#MY2#SY.#K[O'\+B(*"B,Z(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HW-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM
M<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC
M.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("+-Y?/D
MX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C<Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q
M[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z-S(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE
M(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H
M<#HX-PHC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%3
M3"!C;VYN96-T:6]N+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_
M(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU,#$@;&EB
M+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("+-Y?/DX/?M[N4@
M\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R]S;6(N
M<&AP.C0V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(')E=')I979E.B`E<R(*;7-G<W1R("+4X.GK(._PZ.W_\CH@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*(RP@9G5Z>GD*
M;7-G:60@(D9A:7(B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L[R(.KNX^Y<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(L[R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*
M(RP@9G5Z>GD*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`BRN[L[^#M
MZ/\B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@
M(D9A=&%L($5R<F]R.B(*;7-G<W1R("+.^.CAZN`@Z.SO[O#RX#H@(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A
M>"(*;7-G<W1R("+4X.KQ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U,0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS9W-T<B`BU.#J\2(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*(RP@9G5Z>GD*;7-G
M:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"B,L(&9U>GIY"FUS9VED
M(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.30X"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,S(*;7-G:60@(D9I9VQE
M="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,S,V"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II
M(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S='(@(M3@Z>LB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,@9G5Z
M>GD*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL
M92!-86YA9V5R(@IM<V=S='(@(M7PX.WHZ^CYX"(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R
M"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`BR.S_(@H*(R!F
M=7IZ>0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDX-`HC+"!F=7IZ>0IM<V=I
M9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE(._P
M[N'KY>S[.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#DP"B,L(&9U>GIY
M"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("+([/\B"@HC.B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.#@U"B,L(&9U>GIY"FUS9VED(")&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'Y
MY>WHY2(*"B,@9G5Z>GD*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ
M"FUS9VED(")&:6QT97)S(@IM<V=S='(@(M3HZ_SR\/LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS
M9VED(")&:6YL86YD(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C4U"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,`IM<V=I9"`B1FQI
M<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I
M9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR,S<@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`BP.3PY?'@\B#S
MXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B1F]N
M="!#;VQO<B(*;7-G<W1R("+(\>_NZ_SG[N+@\OP@Y^W@]^7MZ.4@[^X@\^SN
MZ_?@[>C^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")&;W(@8G)O=W-E
M<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("+"X/@@X?#N
M\^?E\"#MY2#O[N3DY?#FZ.+@Y?(@[N_VZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H
M(.W@YNSH\N4@0U123"M0+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H
M92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H
M=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$P,@HC+"!F=7IZ>0IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O
M<F0_(@IM<V=S='(@(L_@\.[K_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-C0*(RP@9G5Z>GD*;7-G:60@(D9O<FUS(@IM<V=S='(@(LCL_R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*(RP@9G5Z>GD*;7-G
M:60@(D9O<G5M<R(*;7-G<W1R("+'X.SE\NKH(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9',B"FUS
M9W-T<B`BS^7PY?'KX/+\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G(B"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(L[R(.KNX^Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q
M+C$I("`C+2,M(RTC+2-<;B(*(L[R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B
M1G)A;65S(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*
M;7-G<W1R("+([/\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN
M97-I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1G)O;2(*;7-G<W1R("(B
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBSO(@ZN[C[EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N
M,2D@(",M(RTC+2,M(UQN(@HBSO(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0HC+"!F=7IZ>0IM
M<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+.\B#J[N/N7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.
M\B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BS^[K[>[E(.[O
MZ/'@[>CE(._P[N'KY>S[.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@
M3F%M92(*;7-G<W1R("+"X/CE(.CL_SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")'86)O
M;B(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED
M(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM
M<V=I9"`B1VAA;F$B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S8*
M(RP@9G5Z>GD*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`BR.S_(@H*(R!F
M=7IZ>0HC(&9U>GIY"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@
M(L_N\/+@ZR(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED
M(")';R(*;7-G<W1R("+/Y?#EZ?+H(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,CD*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-
M87!S(@IM<V=S='(@(L_NZ/'J(.(@1V]O9VQE(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("+/
M[NCQZB#B($=O;V=L92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,S8*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@T"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F
M=7IZ>0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*(RP@
M9G5Z>GD*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z-3D@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(L_P[N'KY>S@(._PZ"#O
M[N_[\NKE(.+[]^7PZNWS\OP@)7,N(-'E\.+E\"#QZN#GX.LB"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$X(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S
M+C`N,RD@(",M(RTC+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q
M(%-13"#QY?#BY?#N["Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ
M_R#Q(%-13"#QY?#BY?#N["Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH
M\OSQ_R#Q(%-13"#QY?#BY?#N["Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7D
MZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS
M9W-T<B`BP_#S[^_[(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDX(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E
M<FYS97DB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED
M(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("+#[O'R_"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'=6EN96$B"FUS9W-T<B`BTN7LX"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*(RP@9G5Z>GD*
M;7-G:60@(D=U>6%N82(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M
M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A
M8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ
M-3<*(RP@9G5Z>GD*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E
M[2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DAA:71I(@IM<V=S='(@(LW@\?+P[NGJ
MZ"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C(*(RP@9G5Z>GD*;7-G:60@(DAA>F4B"FUS
M9W-T<B`BS^[D\>K@Y^K@(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDR,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDR,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R
M(@IM<V=S='(@(L_NY/'JX.?JX"(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(L?@X^[K
M[N+JZ"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM
M<V=S='(@(LCL[^[P\B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS
M9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`HC
M+"!F=7IZ>0IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(LWHZN[CY.`B"@HC.B!L
M:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ.#8@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O
M:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`BS^[D\>K@Y^K@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM
M<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S-S4*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G
M<W1R("+/[N3QZN#GZN`B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("+/[NOS^.#PZ.4B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.B(*;7-G<W1R("+-Z.;E(._PY>3Q\N#BZ^7MX"#H[?3N
M\.S@]NC_(.CG(/'@[.[C[B#MX/?@Z^`@].#IZ^`Z(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@
M(DAI9V@B"FUS9W-T<B`BS>CJ[N/DX"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A
M9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R("+/[O#RX.LB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS
M9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B
M"@HC(&9U>GIY"B,Z(&QI8B](;W)D92YP:'`Z,34S.0IM<V=I9"`B2&]M92(*
M;7-G<W1R("+/[O#RX.LB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U
M-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(L3N[.#X[>CI(.#D\.7Q
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"B,L(&9U>GIY"FUS9VED
M(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("+*X/+@Z^[C(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO
M;F4B"FUS9W-T<B`BQ.[LX/CMZ.D@\N7KY?3N[2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R
M87,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*
M(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@
M(DAO<F1E(@IM<V=S='(@(L_N\/+@ZR(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N
M9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H
M(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G
M<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N
M<VEO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C4P,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R
M96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3DR"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$S,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS
M9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO
M;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@
M(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@Y"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET
M>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!=71H
M+V-Y<G-Q;"YP:'`Z,C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+`Y/#E
M\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4O
M075T:"]C>7)U<RYP:'`Z,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z
M,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<#HQ-SD@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7M
MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S(P
M"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(L#D\.7Q(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*(RP@9G5Z>GD*;7-G
M:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N
M\?+S[^W[]2#MX/'R\.[EZBXB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC
M+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#M
MX/'R\.[EZBXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#(*(RP@9G5Z>GD*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`BRN[L[^#MZ/\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/
M;FQY(@IM<V=S='(@(M+NZ_SJ[B#HZN[MZN@B"@HC(&9U>GIY+"!P:'`M9F]R
M;6%T"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(LW@\?+P[NGJ
MZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS
M('=I=&@@=&5X="(*;7-G<W1R("+(ZN[MZN@@\2#RY>KQ\N[L(@H*(R!F=7IZ
M>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET
M>2=S(&YA;64Z(@IM<V=S='(@(LCL_R#O\.[TZ.O_.B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A
M<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S
M86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A
M9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(DEM86=E(%!R979I
M97<Z(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC7&XB"B+-X.?@Y"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E
M(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A
M;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U
M"B,L(&9U>GIY"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`BR.S_(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G
M<W1R("+*X/#RZ.WJZ"(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0L(%-T97`@)60B"FUS9W-T<B`BR.SO[O#R+"#XX.,@)60B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BR.SO[O#RZ/#NXN#M
M[B#O[NOE.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*
M;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`BR.SO[O#RZ/#NXN#M
M^R#O[NO_.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B26Y?<V5R="!2;W<@
M069T97(B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@
M9VEV96XN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(L_NYN#K\^GQ\N`L(.+BY>3H
M\N4@PN#XZ"#H[/\@[^[K_.?NXN#RY>O_(.@@[^#P[NO\(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U
M<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,0HC+"!F=7IZ>0IM<V=I9"`B26YD:6$B"FUS9W-T<B`BTN7K
MY?3N[2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C4T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S
M(@IM<V=S='(@(L_NZ_SG[N+@\N7KZ"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B26YD
M;VYE<VEA(@IM<V=S='(@(M+EZ^7T[NTB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G
M<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M
M(RTC+2,M(UQN(@HBR./M[O#H\.[BX/+\(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U.0HC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HBS_#N]^#_(.CM].[P[.#VZ/]<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+([?3N\.S@]NC_
M(.X@\>7PXN7PY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3D*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I
M;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"B,L(&9U>GIY"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!);6%G92(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"B,L(&9U>GIY"FUS9VED
M("));G-E<G0@5&%B;&4B"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*(RP@
M9G5Z>GD*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("+3Y.#KZ/+\
M(._@\/,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN
M(@HB\^'PX/+\(/'R[NOAY?8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N
M871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*
M;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("+1[N[A
M^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8U"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&)E
M9F]R92(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M97-S
M86=E<R(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*(RP@9G5Z>GD*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`BT>[NX?GE[>CE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@<F]W(&%F=&5R
M(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B
M"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*(RP@9G5Z>GD*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E
M;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<Y"B,L(&9U>GIY"FUS9VED
M("));G1E9V5R(@IM<V=S='(@(M'NY^3@\OPB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$S-PHC+"!F=7IZ>0IM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S
M='(@(M'NY^3@\OPB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z
M,38W(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R
M9&4O0V]M<')E<W,O>FEP+G!H<#HR,3(*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@6DE0(&1A=&$B"FUS9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C$V,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S-@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,P,R!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS
M9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D
M8G@N<&AP.C$P.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*
M"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B
MS>7J[O#PY>KR[>[E(.CL_RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G
M7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`S"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+B(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("+0X.'N
M]^CI(.#D\.7Q(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(LW@\?+P[NGJZ"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("+-X/'R\.[I
MZN@B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`BS>#Q
M\O#NZ>KH(@H*(R!F=7IZ>0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z.3,@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C<Q"B,Z(&QI8B].
M970O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("+-Y>KN
M\/#EZO+M[N4@Z.S_+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`W-2!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$R-3@*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0HC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`BT.#A[O?H
MZ2#@Y/#E\2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS
M9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-3D*(RP@9G5Z>GD*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("+-
MY>KN\/#EZO+M[N4@Z.S_+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S8*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I
M;VXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S
M+C$I("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("))<F5L86YD(@IM<V=S='(@
M(LKN[._@[>C_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I
M9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,30@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B27-R865L(@IM<V=S
M='(@(LKN[._@[>C_(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*(RP@9G5Z>GD*;7-G:60@(DET
M86QI8R(*;7-G<W1R("+%YN7D[>7B[>XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET
M86QY(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DIA<&%N
M(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#8*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"B,L(&9U>GIY
M"FUS9VED(")*=6YE(@IM<V=S='(@(M+E[.`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"B,L(&9U>GIY"FUS
M9VED(")*=7-T:69Y(@IM<V=S='(@(M'NY^3@\OPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0HC+"!F=7IZ
M>0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$W"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`BT>[G
MY.#R_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$T"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y($QE9G0B"FUS
M9W-T<B`BT>[GY.#R_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y
M(%)I9VAT(@IM<V=S='(@(M'NY^3@\OPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(DMA
M>F%K:'-T86XB"FUS9W-T<B`BQ.#RX"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-C,*;7-G:60@(DME97`@;W)I9VEN86P_(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@0W)E
M871I;VXB"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@
M3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3D*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G
M92(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W
M"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+
M=7=A:70B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?
M>6]U="(*;7-G<W1R("+0X/'JZ^#DZN`B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R("+?Y_OJ(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W
M"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"B,L(&9U>GIY"FUS
M9VED("),87-T($AA;&8B"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B3&%S
M="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`BS^#P[NO\(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`HC+"!F=7IZ
M>0IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+!^_'R\/OI
M(/'RX/#R(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("+/\.7D^^3S^>CI
M(.+U[N0@X?OK.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G
M<W1R("+/\.7D^^3S^>CI(.+U[N0@X?OK.B`E<R#Q(.KN[._\_O+E\.`@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN
M.B!.979E<B(*;7-G<W1R("+/\.7D^^3S^>CI(.+U[N0@[>4@Y^#TZ.KQZ/#N
MXN#M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Y"B,L(&9U>GIY"FUS9VED("),871V:6$B"FUS9W-T<B`BT>[GY.#R
M_"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`BPOOU[N0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V
M"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G
M:60@(DQE9G0B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(N_E\.7LY?'RZ/+\(.+BY?#U(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#@*(RP@9G5Z>GD*;7-G:60@(DQE
M9G0@:&5A9&5R(@IM<V=S='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$P-`HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU
M97,B"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H
M;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@(M/DX.OH\OP@[^#P
M\R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.`HC+"!F=7IZ>0IM<V=I9"`B3&EB97)I82(*;7-G<W1R("+-Z.KNX^3@
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0HC+"!F=7IZ>0IM<V=I
M9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@
M(DQI9VAT(%)A:6XB"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"B,L(&9U>GIY"FUS9VED("),:6=H
M="!286EN($5A<FQY(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B3&EG
M:'0@4F%I;B!,871E(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3&EG
M:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"B,L(&9U>GIY"FUS9VED("),
M:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*
M;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"B,L(&9U>GIY"FUS9VED
M("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X,3@*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T
M<B`BPO7NY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E
M<B]H=&UL,G1E>'0N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B3&EN:W,B"FUS
M9W-T<B`BPO7NY"(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(M'O
MZ/'NZB#PX.?DY>ONXB#O[N3QZN#GZN@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC(&9U>GIY
M"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-`HC+"!F=7IZ>0IM
M<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(LCQZN#R_"(*"B,Z(&QI8B](
M;W)D92]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES
M="U(96QP(@IM<V=S='(@(M'OZ/'NZB#PX.?DY>ONXB#O[N3QZN#GZN@B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.38*(RP@9G5Z>GD*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`BT>_H\>[J(/#@Y^3EZ^[B(._NY/'JX.?J
MZ"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,@HC+"!F=7IZ
M>0IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("+1[^CQ[NH@\.#GY.7K[N(@
M[^[D\>K@Y^KH(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS
M"B,L(&9U>GIY"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`BT>_H\>[J(/#@
MY^3EZ^[B(._NY/'JX.?JZ"(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`Z-3DQ"B,L(&9U>GIY"FUS9VED("),:7-T+5-U8G-C<FEB
M92(*;7-G<W1R("+(\>K@\OPB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C4Y,`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U5;G-U8G-C
M<FEB92(*;7-G<W1R("+(\>K@\OPB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO
M;G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HBSOCHX>K@(._PZ"#SY.#KY>WHZ%QN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LWE\^3@]^WNY2#Q
M[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"Y<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB"B+-Y?/DX/?M
M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`BS^[H\>HB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0HC+"!F=7IZ>0IM<V=I
M9"`B3&ET:'5A;FEA(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I
M;64B"FUS9W-T<B`BR^[JX.OHY^#VZ/\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R"FUS9VED("),;V-A=&EO;B(*
M;7-G<W1R("+0X/'O[NONYN7MZ.4B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS
M9W-T<B`BPO7NY"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R
M("(B"@HC(&9U>GIY"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BPOOU[N0B"@HC(&9U>GIY"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T
M<B`BT_?E\NW@_R#GX._H\?PB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(L+U[N0B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DU"B,L(&9U>GIY"FUS9VED("),
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B+/[B#JX.KH
M["WR[B#O\.CWZ.W@["#B]>[D(.(@\>CQ\N7L\R#MY2#SY.#K\?\N(,+E\.[_
M\NWEY2#B\>7C[BP@PN#XZ"#H[/\@(@HB[^[K_.?NXN#RY>O_(.CKZ"#OX/#N
MZ_P@X?OKZ"#BXN7DY>W[(.WEXN7P[>XN(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDY,0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R
M("))35`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.0HC+"!F=7IZ>0IM
M<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(L+[]>[D(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DQO=R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B3&]W97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R("+([/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,Y.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("+,
MS"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/
M5$0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N
M<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,@HC+"!F=7IZ>0IM<V=I9"`B36%C86\B"FUS9W-T<B`B24U0(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,@
M9G5Z>GD*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-
M86EL(@IM<V=S='(@(L_N]_+@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*
M;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS
M9VED(")-86QA=VDB"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")-
M86QA>7-I82(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&1I
M=F5S(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G
M<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(DE-
M4"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`BS>#Q\O#NZ>K@(/'OZ/'JX"#JX/+E
MX^[PZ.D@Z"#VXN7R[N(@Z/4@[O+NX?#@YN7MZ/\B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-`IM<V=I9"`B36%P,C0@;6%P
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#@U"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,38Y"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S
M=&]R960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8W"B,L(&9U>GIY"FUS9VED(")-87)C:"(*;7-G<W1R("+/[NCQZB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#$*(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+"[>CLX.WH
MY2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I
M9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,PHC+"!F=7IZ>0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("+"[>CL
MX.WHY2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED
M(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`BT>[B[^#DX/[YZ.4@[^[K_R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,PHC+"!F=7IZ>0IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("+"[>CLX.WH
MY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(L+MZ.S@
M[>CE(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*
M;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*(RP@9G5Z>GD*;7-G
M:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("+1[N[A
M^>7MZ.4B"@HC.B!L:6(O87!I+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("+,X.KQZ.S@
MZ_SM[N4@ZN[KZ/?E\?+B[B#Q\O#@[>CV(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*(RP@9G5Z>GD*;7-G
M:60@(DUA>2(*;7-G<W1R("+%YN7D[>7B[>XB"@HC(&9U>GIY"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z
M>GD*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`BPOOU[N0B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")-
M96UB97)S(@IM<V=S='(@(L?@[.7RZN@B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B
MT.7FZ.P@[.7M_CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"B,L(&9U>GIY"FUS9VED(")-97)G92!C96QL
M<R(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+1[N[A^>7M
MZ.4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B
M(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N
M97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$P"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@
M(M'N[N'YY>WHY2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-CD@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S
M<V%G92!T>7!E(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O
M;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*
M;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4E!#+WAM
M;')P8RYP:'`Z.#$@;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E
M9FEN960B"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GD
MY>TN(@H*(SH@;&EB+TAO<F1E+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV-PIM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE
M(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R
M9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,S"B,L(&9U>GIY"FUS
M9VED(")-:7)R;W(B"FUS9W-T<B`BSOCHX>K@(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,T,`HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C4P
M"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@
M(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R
M("(B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X
M"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS
M9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS
M9VED(")-;V1E<F%T92(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*(RP@
M9G5Z>GD*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S0*(RP@9G5Z>GD*
M;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`BT?;E[>#PZ.DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`HC+"!F=7IZ>0IM<V=I
M9"`B36]N86-O(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36]N
M9V]L:6$B"FUS9W-T<B`BRN[L\R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-3@X"B,L(&9U>GIY"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M
M(UQN(@HBT.#GXN7P[?/R_"#B\>4B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(L7FY>SE\?_W[>XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N
M(%!H87-E<R(*;7-G<W1R("+4X.?[(,OS[?LB"@HC.B!L:6(O1FEL92]#4U8N
M<&AP.C$Y-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X
M<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DUO<F]C
M8V\B"FUS9W-T<B`B24U0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&5A<B(*
M;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@0VQO=61Y
M(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!3=6YN
M>2(*;7-G<W1R("+*[NSOX.WH_R(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z-3`Y(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B[^7PY>SE
M\?+H\OP@XNWHYR(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-3$S(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B[^7PY>SE\?+H\OP@XNOE
MXNXB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4Q
M-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I
M9"`B36]V92!2:6=H="(*;7-G<W1R("+OY?#E[.7Q\NCR_"#B[_#@XNXB"@HC
M(&9U>GIY"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P-2!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V
M92!5<"(*;7-G<W1R("+OY?#E[.7Q\NCR_"#BXN7P]2(*"B,@9G5Z>GD*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B
M36]V92!D;W=N(@IM<V=S='(@(N_E\.7LY?'RZ/+\(.+MZ.<B"@HC(&9U>GIY
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V
M92!U<"(*;7-G<W1R("+OY?#E[.7Q\NCR_"#BXN7P]2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM
M<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-38*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G
M<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V"B,L
M(&9U>GIY"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BS^[K
M[>[E(.[OZ/'@[>CE(._P[N'KY>S[.B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R
M("+3]^7R[>#_(.?@[^CQ_"(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(L+@^.`@Z.WT[O#LX/;H_R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E
M>"YP:'`Z-#4*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO961I="YP:'`Z-#,*;7-G:60@(DUY(%!O<G1A;"!,87EO
M=70B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")->6%N;6%R(@IM<V=S
M='(@(LK@Z^7MY.#P_"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E
M96UE;G1?8F]T=&]M+FEN8SHW"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R
M("+([/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M875R=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PHC
M+"!F=7IZ>0IM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`BRN#KY>WDX/#\
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P
M92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*
M;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E
M(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM
M<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I
M8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-3,*(RP@9G5Z>GD*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`BS>[B
M^^4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP
M"FUS9VED(").979E<B(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@
M0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T
M<B`BS>[BX/\@ZN#RY>/N\.C_(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+V5M86EL<RYP:'`Z.#$@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP
M:'`Z.#<*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R
M("+-[N+[Y2#Q[N[A^>7MZ/\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(L+E\.WS\OSQ_R#J
M(.W@\?+P[NGJX.PB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(LK@
MZ^7MY.#P_"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC
M+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*
M"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*
M;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"B,L(&9U
M>GIY"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R
M("+"X/@@16UA:6PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G
M<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T
M<B`BS>[B[O'RZ"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*
M(RP@9G5Z>GD*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`BT^3@Z^CR_"(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").
M97AT(@IM<V=S='(@(L3@Z^7E(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T
M<B`BT>OEY//^^>#_(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C,V-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X
M="!O<'1I;VYS(@IM<V=S='(@(M'KY>3S_OG@_R#Q\O#@[>CVX"(*"B,Z(&QI
M8B](;W)D92]522]086=E<BYP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(").97AT
M/B(*;7-G<W1R("+$X.OEY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEC87)A9W5A
M(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS9W-T
M<B`BS>CJ[N/DX"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M("+-Z.KNX^3@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M.0HC+"!F=7IZ>0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PHC
M+"!F=7IZ>0IM<V=I9"`B3FEU92(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-`IM<V=I9"`B3F\B
M"FUS9W-T<B`BS>7R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N
M:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!L:6(O
M5D93+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@
M8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C<Y(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(T
M-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-C<@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H
M].CJX/;HZ"#O[B!344PB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("+.\NSE[>CR_"#H
MY^SE[>7MZ/\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I
M9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E
M+G!H<#HU,#@@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+B(*;7-G<W1R("+-Y2#A^^ON(//JX.?@[>X@\>[N
M\N+E\O'RXO/^^>7I(.CM].[P[.#VZ.@@Y.O_(.K@\N7C[O#HZ2!344PN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M(@IM<V=S='(@(L3K_R#MX/'R\.[EZB!,1$%0(.WE(.'[Z^X@\^K@Y^#M[B#Q
M[N[RXN7R\?+B\_[YY>D@Z.WT[O#LX/;HZ"XB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z-C<R"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BS>4@X?OK
M[B#SZN#GX.WN(/'N[O+BY?+Q\N+S_OGEZ2#H[?3N\.S@]NCH(.3K_R#JX/+E
MX^[PZ.D@4U%,+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<R-0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`BS>4@X?OK[B#SZN#G
MX.WN(/'N[O+BY?+Q\N+S_OGEZ2#H[?3N\.S@]NCH(.3K_R#JX/+EX^[PZ.D@
M4U%,+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T
M"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(M'N[N'YY>WHY2(*
M"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,#,*(RP@9G5Z>GD*;7-G:60@
M(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`BR.S_(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(").;R!I8V]N<R!F;W5N
M9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N
M(&ES('-E="XB"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G:60@(DYO
M(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G
M:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("+!^^ON(//JX.?@[>X@
M[>7J[O#PY>KR[>[E(.?MX/?E[>CE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S<*(RP@9G5Z>GD*;7-G:60@(DYO(&YU;6)E<B!S
M<&5C:69I960N(@IM<V=S='(@(L'[Z^X@\^K@Y^#M[B#MY>KN\/#EZO+M[N4@
MY^W@]^7MZ.4N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*(RP@
M9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;E
MY//P^R#@\_+E[?+H].CJX/;HZ"#O[B!344PB"@HC.B!L:6(O2&]R9&4O075T
M:"]I;6%P+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-Y?(@
M[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H].CJX/;HZ"#O[B!344PB
M"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@HC+"!F=7IZ>0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@
M\_+E[?+H].CJX/;HZ"#O[B!344PB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L
M+G!H<#HW-R!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO
M<F1E+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H].CJX/;HZ"#O
M[B!344PB"@HC.B!L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS>7R(.W@\?+P[N7J(.3K_R#O\.[V
MY>3S\/L@X//RY>WRZ/3HZN#VZ.@@[^X@4U%,(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<VUB+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS>7R(.W@
M\?+P[N7J(.3K_R#O\.[VY>3S\/L@X//RY>WRZ/3HZN#VZ.@@[^X@4U%,(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).
M;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P
M96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]61E,N<&AP.C<V-@HC+"!F=7IZ>0IM<V=I9"`B
M3F\@<75O=&$@<V5T+B(*;7-G<W1R("+'X.SE\NKH(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ
M>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B]&
M:6QE+T-35BYP:'`Z-#@R"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@
M<W!E8VEF:65D+B(*;7-G<W1R("+"^R#MY2#SZN#GX.OH(._@[^KH(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`BQ^#LY?+JZ"(*
M"B,Z(&QI8B]61E,O<VUB+G!H<#HU.#<*(RP@9G5Z>GD*;7-G:60@(DYO('-U
M8V@@9FEL92(*;7-G<W1R("+'X.SE\NKH(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("+/[N;@Z_/I\?+@+"#BXN7DZ/+E
M(,+@^.@@Z.S_(._NZ_SG[N+@\N7K_R#H(._@\.[K_"(*"B,Z(&QI8B](;W)D
M92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3@R"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.3,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,3`*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("+-Y2#N[_#E
MY.7KY>WN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B
M3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!2
M96=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#(W('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R("(M[>4@XOOA\.#M+2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G
M:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B
M(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(M'EXN7P[>[E(._NZ_/XX/#HY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0Q"B,L(&9U
M>GIY"FUS9VED(").;W0@069T97(B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED(").
M;W0@0F5F;W)E(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C0Q-0HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S
M='(@(LK@\N#K[N,B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*
M(RP@9G5Z>GD*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(LWNXN[E(/'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93
M+G!H<#HR,#@@;&EB+U9&4RYP:'`Z,C,T(&QI8B]61E,N<&AP.C(U,@HC.B!L
M:6(O5D93+G!H<#HR-CD@;&EB+U9&4RYP:'`Z,C@U(&QI8B]61E,N<&AP.C,P
M,2!L:6(O5D93+G!H<#HS,38*(SH@;&EB+U9&4RYP:'`Z,S,S(&QI8B]61E,N
M<&AP.C,V-B!L:6(O5D93+G!H<#HT,C8@;&EB+U9&4RYP:'`Z-3`U"B,Z(&QI
M8B]61E,N<&AP.C4W-"!L:6(O5D93+G!H<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y
M"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D
M92]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,3<U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z
M,3@Y"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"B,L(&9U
M>GIY"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B
M[N4@\>[NX?GE[>CE(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
MQ^#LY?+JZ"(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM
M<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*
M(RP@9G5Z>GD*;7-G:60@(DYO=&EC92(*;7-G<W1R("+'X.SE\NKH(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,"!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@
M(DYO=F5M8F5R(@IM<V=S='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`U,`HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(LCL
M_R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(Y"B,L(&9U>GIY"FUS9VED
M(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+([/\B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3,W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-`HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB\^'PX/+\(/'R[NOAY?8B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@HC+"!F=7IZ>0IM<V=I
M9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I9"`B3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN
M=&5N86YC95]487-K("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S$*(RP@9G5Z>GD*
M;7-G:60@(D]B:F5C="(*;7-G<W1R("+2Y>S@(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,3$*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!#<F5A
M=&]R(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$P.`HC+"!F=7IZ>0IM<V=I9"`B3V-T86PB"FUS
M9W-T<B`BQ>;EY.WEXNWN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R.`HC+"!F=7IZ>0IM<V=I9"`B3V9F:6-E(@IM
M<V=S='(@(L?@X^[K[N+NZB(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@
M9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G
M<W1R("+/X/#NZ_PB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-#8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="XB"FUS9W-T<B`BS^#P[NO\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PHC+"!F=7IZ
M>0IM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RXB"FUS9W-T<B`BPN#X(.'P[O/GY?`@[>4@[^[DY.7PYNCBX.7R(.[O
M]NC^(._E]^#RZ"X@Q.O_(._E]^#RZ"#MX.;LZ/+E($-44DPK4"XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW
M-0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT
M,`IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S
M='(@(LW@\?+P[NGJZ"(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@
M<&AP+69O<FUA=`HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N
M<R!F;W(@)7,B"FUS9W-T<B`BS>#Q\O#NZ>KH(.3K_SH@)7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/
M<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-C@*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G
M<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-CD*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO
M;F%L(%5N:70B"FUS9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,@
M9G5Z>GD*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B
M3W)G86YI>FEN9R(*;7-G<W1R("+.\./@[>#IY^7P(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SHB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T
M<B`B(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS
M9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("+/\.[WX/\@Z.WT[O#L
MX/;H_R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*(RP@9G5Z
M>GD*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(LW@\?+P[NGJ
MZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y
M"B,L(&9U>GIY"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[EZBXB"@HC
M.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!
M4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS
M9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM
M<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#
M;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P
M"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(E!-
M($QI9VAT(%)A:6XB"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")032!2
M86EN(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(E!-(%-H;W=E
M<G,B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<B"FUS
M9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0S"B,L(&9U>GIY"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("+(
M[._N\/(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")0
M3U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@
M(E!A:VES=&%N(@IM<V=S='(@(L3@\N`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")0
M86QA=2(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B
M4&%N86UA(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W
M($=U:6YE82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")087)A9W5A
M>2(*;7-G<W1R("))35`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B4&%R=&QY($-L;W5D>2(*
M;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,C(*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,34Q('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,R!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R
M("+/X/#NZ_PB"@HC(&9U>GIY"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(M'N[N'YY>WHY2#S\>_E^.WN(.[R[_#@XNOE
M[>XN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"B,L(&9U
M>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`BS^#P[NO\
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*(RP@9G5Z>GD*
M;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(LWE\B#MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[(.#S
M\N7M\NCTZ.K@]NCH(._N(%-13"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#4W"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("+/\.[WX/\@Z.WT[O#LX/;H_R(*"B,@9G5Z>GD*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`BS^#P[NO\(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+/X/#N
MZ_PB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P,S@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0HC
M+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@
M(L+@^"!%;6%I;#HB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@HC
M+"!F=7IZ>0IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BQ.#RX"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A
M<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*(RP@9G5Z>GD*;7-G:60@
M(E!A=&@B"FUS9W-T<B`BQ.#RX"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W
M"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z-@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(L[Q\_GE\?+BZ^7MZ.4@
M[N_E\.#VZ.D@[^[DY.7PYNKH(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(L+[[^[K[>CR_"#N[^7PX/;HZ"#N
MX?'K\^;HXN#MZ/\@[_#H(.+U[N3E(.(@\>CQ\N7L\S\B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R
M("+/\.#BX"(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D
M96QE=&5D+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)
M35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M
M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H
M,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(
M,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H
M,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5
M+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R`C
M+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M
M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H
M,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(
M,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H
M,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5
M+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(SH@
M;&EB+U9&4R]S;6(N<&AP.C4Y,`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO
M;B!$96YI960B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N
M-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0
M($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@
M(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC
M7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE
M[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.
M86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@
MY.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N
M,RDI("`C+2,M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%=H=7!S(#$N,"UC=G,I("`C+2,M(RTC
M+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*%=H=7!S(#$N,"UC=G,I("`C+2,M(RTC+2-<;B(*(LW@\?+P
M[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%=H
M=7!S(#$N,"UC=G,I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[B
MX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%=H=7!S(#$N,"UC=G,I
M("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*%=H=7!S(#$N,"UC=G,I("`C+2,M(RTC+2-<
M;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<
M;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#N
MZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R
M8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?N
MXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP
M+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC
M+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-
MX/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O
M[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S
M+C`N-BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H36YE
M;6\@2#,@*#(N,"XR*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@
MY.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@*#(N
M,"XR*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M
M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HB
MS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P
M[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U
M<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG
M[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N
M,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M
M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC(&9U>GIY"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("+/\.#BX"#D
M[O'R\^_@(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z
M,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T
M:6]N(@IM<V=S='(@(LOH]^W[Y2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G
M<W1R("+2Y>OE].[M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(L3@\N`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-38V"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT
M97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ(@IM<V=S='(@(L+BY>3H\N4@[>#GXN#MZ.4@[>[B[ND@ZN#RY>/N\.CH
M.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`U"B,L(&9U>GIY"FUS9VED
M(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("+"
MX/@@16UA:6PZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#<*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#4Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!T:6UE+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("+/[N;@Z_/I
M\?+@+"#Q[N[A^>CRY2#Q\_+\(._P[N'KY>S[+B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B"FUS9W-T<B`BS^[FX.OSZ?'RX"P@XN+EY.CRY2#"X/CH(.CL_R#O
M[NO\Y^[BX/+EZ_\@Z"#OX/#NZ_PB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O86=R965M96YT7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I
M9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")0;VQA;F0B"FUS
M9W-T<B`BRN[L[^#MZ/\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#@Y"B,L(&9U>GIY"FUS9VED(")0;VQL<R(*;7-G<W1R("+1XN7P[?/R_"#B
M\>4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*
M;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*
M;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0
M;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM
M<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED
M(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C0*(RP@9G5Z>GD*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T
M<B`BS^#P[NO\(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(P-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C,*(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(LW@Y^#D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W
M('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(R!F=7IZ
M>0HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R
M("+/\.7D^^3S^>#_(/'R\.#MZ/;@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](
M;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`BS_#N
MX>OE[.`_(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0
M<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(L[OZ/'@[>CE(._P[N'KY>S[
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O
M:F5C=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,34@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M.#,*(RP@9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(L+[]>[D
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L
M:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0HC+"!F=7IZ>0IM
M<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(L+@^.4@[^[K[>[E(.CL
M_SHB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#(*(RP@9G5Z>GD*;7-G:60@(E%A=&%R(@IM<V=S='(@(DE-4"(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L(&9U>GIY"FUS9VED
M(")1=6]T82(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME
M>2`H)60@8FET*2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,C8X"B,L(&9U>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB
M"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE(._P[N'KY>S[.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"B,L(&9U>GIY"FUS
M9VED(")286EN(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E)A
M:6X@16%R;'DB"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")286EN($QA
M=&4B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0W"B,L(&9U>GIY"FUS9VED(")286EN(%-H;W=E<B(*
M;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS
M9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T
M<B`BPO7NY"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8X
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS
M9VED(")2871I;R(*;7-G<W1R("+-X/'R\.[IZN@B"@HC(&9U>GIY"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S
M='(@(M?H\N#R_"(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("+1
M[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*
M(RP@9G5Z>GD*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S
M='(@(M/DX.OH\OP@[^#P\R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM
M<V=S='(@(L[A[>[BZ/+\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S
M='(@(L[A[>[BZ__R_"#DZ.W@[.CWY?'JZ.4@[_/MZO+[(.SE[?XZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T
M86P@5FEE=SHB"FUS9W-T<B`BSN'M[N+K__+\(.CM].[P[.#VZ/XZ(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q
M-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0HC+"!F=7IZ>0IM<V=I9"`B4F5G
M97@B"FUS9W-T<B`BT>'P[O'H\OPB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S(S.`IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM
M<V=S='(@(L_P[O?H\N#M[?OE(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("+/
M[O?R[N+[Y2#QY?#BY?#@(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`BP.3PY?$@\>7PXN7PX"`H[>#O\.CLY?`@
M:'1T<#HO+VUA:6PN<G4I(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R("+3Y.#KZ/+\(@H*(R!F
M=7IZ>0HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@
M(E)E;6]V92!";&]C:R(*;7-G<W1R("+3Y.#KZ/+\(.'K[NHB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(O/A\.#R_"#Q
M\N[KX>7V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS
M9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(M/DX.OH\OP@
M[^#P\R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E
M;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!T:&4B"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED
M(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(M/DX.OH\OP@[^#P
M\R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S
M='(@(M/DX.OH\OP@[^#P\R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H
M<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@
M\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-S8@;&EB+TAO<F1E+G!H<#HU,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(LWE[N'U[N3H[/OI(._@\.#LY?+P("=U
M:60G(.WE(//JX.?@[2#B(.KN[?3HX_/PX/;HZ"#MX/'R\.[EZBXB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z-C<X(&QI8B]61E,O9G1P+G!H<#HX-C$@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CL^^D@[^#PX.SE\O`@)W5I9"<@
M[>4@\^K@Y^#M(.(@ZN[M].CC\_#@]NCH(.W@\?+P[N7J+B(*"B,Z(&QI8B](
M;W)D92]5=&EL+G!H<#HW-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(LWE[N'U[N3H[/OI(._@\.#LY?+P("=U:60G(.WE(//J
MX.?@[2#B(.KN[?3HX_/PX/;HZ"#MX/'R\.[EZBXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S0S(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,"!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("+1
MX?#N\>CR_"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L
M(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PHC+"!F=7IZ>0IM
M<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"B,L(&9U>GIY"FUS9VED(")297-T
M;W)E($QA<W0@475E<GDB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI
M;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G
M<W1R("+"Y?#M\_+\\?\@ZB#MX/'R\.[IZN#L(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")2971Y<&4@;F5W
M('!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@
M(E)E=6YI;VXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(M/DX.OE[>W[Y2(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(R!F
M=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`BS>#Q\O#NZ>KH(.+HY_/@
MZ_SM[N/N(/#EY.#J\N[PX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I9"`B4FEG:'0B
M"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$P
M"B,L(&9U>GIY"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`BS_#H[.7P
M(.?MX/?E[>CI.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`V"B,L(&9U
M>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`BS_#H[.7P(.?MX/?E
M[>CI.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B4F]?=R!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS
M9W-T<B`BT?;E[>#PZ.DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")2;VUA;FEA(@IM
M<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C0*(RP@9G5Z>GD*;7-G:60@(E)O=&%T92`Q.#`B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(N_E\.7LY?'RZ/+\(.+BY?#U(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B
M4F]T871E($QE9G0B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(N_E\.7LY?'RZ/+\(.+BY?#U
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-PHC
M+"!F=7IZ>0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+O
MY?#E[.7Q\NCR_"#BXN7P]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*(RP@9G5Z>GD*;7-G:60@(E)O=R!0
M<F]P97)T:65S(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,`HC+"!F=7IZ>0IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`BRNOE
M\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,0HC+"!F=7IZ>0IM<V=I9"`B4F]W<SHB"FUS
M9W-T<B`BRN#KY>WDX/#\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B
M"FUS9W-T<B`BT?;E[>#PZ.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM
M<V=I9"`B4G=A;F1A(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A
M<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!%;F-R>7!T
M960@365S<V%G92(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA
M:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H
M<#HX,0HC+"!F=7IZ>0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*(RP@9G5Z>GD*
M;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`BSO+O\.#BZ/+\(/'N[N'Y
MY>WHY2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H
M96QL(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C@Q"FUS
M9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-3
M2"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@
M(B(*"B,@(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC
M+2,*(R!F=7IZ>0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8Q"B,L(&9U>GIY"FUS9VED(")382(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT>[U
M\.#MZ/+\(.K@ZEQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N
M,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@
M2&5L96YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE
M=FES(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,SD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4V%I;G0@3'5C:6$B
M"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H
M7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#8*(RP@9G5Z>GD*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`BPNWH[.#M
MZ.4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A
M8FEA(@IM<V=S='(@(B(*"B,@(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S
M+C$I("`C+2,M(RTC+2,*(R!F=7IZ>0HC(&9U>GIY"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R("+1[O7P
MX.WH\OPB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G
M<W1R("+1[O7PX.WH\OP@[>#Q\O#NZ>KH(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@)7,B"FUS9W-T<B`BT>[U\.#MZ/+\(.W@\?+P[NGJZ"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G
M<W1R("+1[O7PX.WH\OP@[>#Q\O#NZ>KH(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BS>4@
M[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@9G5Z
M>GD*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("+([._N\/(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(L_NZ/'J(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S(R"B,L(&9U>GIY"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R("+/[NCQZB(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.38R"B,L(&9U>GIY"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`BPOOA
MY?#H\N4@].[P[.#R(.3@\OLZ(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@Y.#R^SHB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[
M.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("+"^^'E\.CRY2#T
M[O#LX/(@Y.#R^SHB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(L+[
MX>7PZ/+E(/'E\.+E\"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,34V"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G
M<W1R("+"^^'E\.CRY2#T[O#LX/(@Y.#R^SHB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<T"FUS9VED(")396QE8W0@86QL(@IM
M<V=S='(@(L+[X?#@\OP@XO'E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V
M-3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+B(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@Y.#R^SHB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<Q"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#D
MX/+[.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S4*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(L[R[.7MZ/+\(.+[X>[P
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED
M("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T
M:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HBPOOAY?#H\N4@
M[?/F[?OE(,+@["#QZ.SB[NO[(.CG(/3N\.P@XNWHY_,N(,?@\N7L(,+[(.SN
MYN7RY2#QZN[OZ/#NXN#R_"#H("(*(N+Q\N#BZ/+\(.CU(.(@\N7J\?(N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(L+[X>7PZ/+E(/#@Y^3EZ^CR
MY>O\(._NZ^7I(.3@\OLZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(L+[
MX>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("+"^^'E\.CRY2#O\.[TZ.O\
M(.3K_R#MX/'R\.[IZN@Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M(@IM<V=S='(@(L+[X>7PZ/+E(/#@Y^3EZ^CRY>O\(._NZ^7I(.3@\OLZ(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(L+[X>7PZ/+E(.[R[N'PX.;E[>C_
M(/3N\.S@\B#B\.7LY>WH.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G
M<W1R("+"^^'E\.CRY2#DXN`@\>[B[^#DX/[YZ/4@[^[K_RXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N(@IM<V=S='(@(L+@^.`@]N+E\N[BX/\@\?7E[.`B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(M_G^^H@[O+NX?#@YN7MZ/\B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B
M4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+/[O'KX/+\(/'N[N'YY>WH
MY2#N(._P[N'KY>SE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-#`*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G
M:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R
M("+'X.SE\NKH(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"B,L(&9U>GIY"FUS9VED
M(")397)I86P@3G5M8F5R(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#D*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R
M\^_M^_4@[>#Q\O#NY>HN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L
M(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M
M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LCG[.7M
MZ/+\(._PX.+@(.3N\?+S[^`B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I
M<F5D+B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L:6(O87!I+G!H<#HQ-#4*
M(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(L?@[.7MZ/+\(.W@
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,3@*(RP@9G5Z>GD*;7-G:60@
M(E-E="(*;7-G<W1R("+2Y>S@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"B+$[N_NZ^WH\N7K_.W[Y2#O[O?R
M[N+[Y2#QY?#BY?#@+"#J(.KN\N[P^^P@XOL@]>[RZ/+E(.CLY?+\(.3N\?+S
M[R#HYR#/[O#RX.O@+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM
M<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("+3\?+@[>[BZN`@_^?[ZN`@XOOB
M[N3@+"#B\.7LY>WM[ND@Y^[M^R#H(/3N\.S@\N`@[O+NX?#@YN7MZ/\@XO#E
M[.7MZ"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B
M"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N
M<RXB"FUS9W-T<B`B(@HBT_'RX.WNXNK@(._PZ.ONYN7MZ/\@[^X@\^SNZ_?@
M[>C^+"#VXN7R[N+NZ2#Q]>7L^R#H(._P[O?H]2#N[_;HZ2#N\N[A\.#FY>WH
M_R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P
M(@IM<V=S='(@(L_PZ.ONYN7MZ/\B"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HS-PHC+"!F=7IZ>0IM<V=I9"`B4V5T=7`@=7!G<F%D
M92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@
M[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P
M;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,@(RTC+2,M(RTC("!R=5]2
M52YP;R`H24U0('8S+C$I("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"B,L(&9U>GIY"FUS9VED(")3:&]P<&EN
M9R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@
M(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(.K@ZEQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("+*\.#RZN[E(.[A[N'Y
MY>WHY3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B
M"FUS9W-T<B`BSN_PY>3EZ^CR_"#A^_'R\/OE(.KKX.+H^.@@Y.O_(/'Q^^ON
MZC\B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(S('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y
M"FUS9VED(")3:&]W(@IM<V=S='(@(L_NZN#GX/+\(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B
M971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E
M9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W
M:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(L_NZN#G^^+@\OP@Z.WT[O#LX/;H
M_B#N(._PY>3[Y//YY>P@XO7NY.4_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$W-CD*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#(*(RP@9G5Z>GD*
M;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(LCL[^[P\B(*"B,@9G5Z>GD*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L
M92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("+/[NK@Y^#R_"#LY>W^
M(.[OY?#@]NCI(/$@\N#AZ^CVX.SH(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL
M('!H<"UF;W)M870*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T
M/R(*;7-G<W1R("+.\N[A\.#FX/+\(.SE[?X@)7,@\>OEXN`_(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y
M"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4R"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-S8W"B,L(&9U>GIY"FUS9VED(")3:&]W('5P
M;&]A9"(*;7-G<W1R("+([/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*;7-G
M<W1R("+([._N\/(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4R"B,L(&9U>GIY"FUS9VED(")3:&]W97)S($5A
M<FQY(@IM<V=S='(@(LKPX/+J[N4@[N'NX?GE[>CE.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"B,L(&9U>GIY"FUS9VED
M(")3:&]W97)S($QA=&4B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@
M:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#@P(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`BT?/G
MZ/+\(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C@S-@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HY,C(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3@T
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P-#<@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HQ,3$V(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$Q-#D*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M
M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S
M="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I
M9VX@=7`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R
M:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDP,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(Q.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S$Q,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-`IM<V=I9"`B4VEZ92(*
M;7-G<W1R("+0X.?LY?`B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]B;W1T;VTN:6YC.CD*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS
M9W-T<B`BS_#N[_/Q\NCR_"#O[N3DY?#FZO,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI
M82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0HC+"!F
M=7IZ>0IM<V=I9"`B4VYO=R(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@HC+"!F=7IZ>0IM<V=I
M9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@
M(E-N;W<@4VAO=V5R<R(*;7-G<W1R("+([._N\/(B"@HC(&9U>GIY"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"B,L(&9U>GIY
M"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`BRO#@\NKNY2#N
MX>[A^>7MZ.4Z(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S
M($QA=&4B"FUS9W-T<B`BRO#@\NKNY2#NX>[A^>7MZ.4Z(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@
M(E-O;6%L:6$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Y,34*(RP@9G5Z>GD*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T
M:6]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.#D*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*
M(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V-B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S
M<R(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R
M:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS
M9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N
M($AE;6ES<&AE<F4B"FUS9W-T<B`BWN;M[N4@[^[K\_C@\.CE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@
M(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G
M:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB
M"FUS9W-T<B`B(@H*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@
M(",M(RTC+2,M(PHC(&9U>GIY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,3D*
M(RP@9G5Z>GD*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\
M(.K@ZEQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M
M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(@H*(R`C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(PHC(&9U>GIY"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`HC+"!F=7IZ>0IM
M<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(.K@ZEQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN
M(@HBT>[U\.#MZ/+\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
MPNWH[.#MZ.4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"B,L
M(&9U>GIY"FUS9VED(")3<&%M(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E
M<B!);G!U="(*;7-G<W1R("+1[^7VZ.#K_.W[Y2#QZ.SB[NO[(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@HC
M+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+D
M[N'@XNCR_"#Q\N[KX>7V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@
M8V]L=6UN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U
M<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(N3NX>#BZ/+\(/'R[NOAY?8B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Q"B,L(&9U>GIY"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN
M(@HBY.[AX.+H\OP@\?+NZ^'E]B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B4W)I($QA
M;FMA(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(LK@
MZ^7MY.#P_"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DP(&QI8B](;W)D
M92]&;W)M+G!H<#HR-SDX"B,L(&9U>GIY"FUS9VED(")3=&%R="!Y96%R(@IM
M<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC
M(&9U>GIY"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R
M"FUS9VED(")3=&%T=7,B"FUS9W-T<B`BT?+@\O/Q(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(X,#0*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T
M(@IM<V=S='(@(L+@^.`@Z.WT[O#LX/;H_R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<S"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S
M<R(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G
M:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-PIM<V=I
M9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S<*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[L
MZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(M+E[.`B
M"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S8@;&EB+TAO<F1E
M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@
M(LCQZN#R_"(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@HC+"!F
M=7IZ>0IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(LCQZN#R_"(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,#0@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@
M(M/Q[^7X[>XB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B(*;7-G<W1R("+/X._JX"!<(B5S7"(@X?OKX"#S\>_E^.WN
M(._E\.7H[.7M[N+@[>`@XB!<(B5S7"(N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("+'X.SE\NK@("<E<R<@\_'OY?CM
M[B#Q[O7PX.WE[>`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+/\.[AZ^7LX"#O
M\.@@[_#N\>SN\O#E(.?@[_#N^.7M[>[C[B#OZ/'\[.`N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R("+1\N#PX/\@ZN[M].CC\_#@]NC_(/'N]?#@[>7MX"#B(/3@
MZ>LZ("5S(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R
M;6%T"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@
M(L?@[.7RZN`@)R5S)R#S\>_E^.WN(/'N]?#@[>7MX"(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G
M<W1R("+-[N+@_R#J[NWTZ./S\.#VZ/\@\>[U\.#MY>W@(.(Z("5S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`HC
M+"!F=7IZ>0IM<V=I9"`B4W5D86XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V
M"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(L/KX.+MX/\B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E-U
M;B!2:7-E(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E-U;B!3970B"FUS
M9W-T<B`BTN7LX"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"B,L(&9U>GIY"FUS9VED(")3=6YR
M:7-E(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\B"@HC(&9U>GIY"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ
M-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`BPO#E[/\@XN[Q]>[D
MX"_GX.K@\N`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T
M"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`BR.S_(._NZ_SG
M[N+@\N7K_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*
M(RP@9G5Z>GD*;7-G:60@(E-U;G-E="(*;7-G<W1R("+2Y>S@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PHC+"!F=7IZ>0IM<V=I9"`B
M4W5N<V5T.B`B"FUS9W-T<B`BTN7LX"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(E-U<&5R
M<V-R:7!T(@IM<V=S='(@(L_NZ^WNY2#N[^CQX.WHY3HB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"B,L(&9U>GIY"FUS9VED(")3=7!P;W)T
M(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE
M(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G
M<W1R("+([/\@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD
M($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")3=V%Z
M:6QA;F0B"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3
M>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(L_NZN#GX/+\(//DX.OE[>W[Y2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM
M<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I
M9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,@9G5Z>GD*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*(RP@
M9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(LKPX/+J[N4@
M[N'NX?GE[>CE.B(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V"B,L
M(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R("+'X./NZ^[B[NHB"@HC
M.B!L:6(O2&]R9&4O54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B
M5&%B;&4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I
M9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[Q
MXO_G_"(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W
M"B,L(&9U>GIY"FUS9VED(")486)L92!3970B"FUS9W-T<B`BQ^#C[NONXN[J
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G
M<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"B,L(&9U
M>GIY"FUS9VED(")486EW86XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@
M(E1A:FEK:7-T86XB"FUS9W-T<B`BQ.#RX"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I
M9"`B5&%R9V5T.B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*
M;7-G:60@(E1A<VMS(@IM<V=S='(@(L?@Y.#WZ"(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z
M-CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S
M(.WE(.W@Z>3E[2XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I
M9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,S0*
M(RP@9G5Z>GD*;7-G:60@(E1E>'0B"FUS9W-T<B`BQ.#KY>4B"@HC(&9U>GIY
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R("+2[NO\ZNX@\N7J\?(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED
M(")497AT(&%L:6=N(@IM<V=S='(@(M'KY>3S_OGE_R#Q\O#@[>CVX"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*(RP@
M9G5Z>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`BQ.#KY>4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4
M:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AA:6QA;F0B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z.#4Q"B,L(&9U>GIY"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P
M[N7J+B(*"B,Z(&QI8B](;W)D92](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE
M($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U
M<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&QI8B].970O24U34"]";V]K
M+G!H<#HQ,CDX"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("+/[N3OZ/'\(.WE(.SNYN7R
M(.'[\OP@Y^#LY>WE[>`N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,"!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R
M,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(U,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED
M("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A
M<V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A
M8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF
M>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF
M:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM
M<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-S<@;&EB+TAO<F1E+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$W,"!L:6(O2&]R9&4N<&AP.C4P
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$N
M<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED
M("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN
M(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T9I;&4O0U-6+G!H<#HT-S0*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BW?+N(.?M
MX/?E[>CE(.3NZ^;M[B#A^_+\(/?H\>ON["XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP:'`Z,C@S"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6
M:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]M<W=O<F0N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP
M.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#<*;7-G:60@(E1H
M92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QE+T-35BYP
M:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(M'E\.+E\"`E<R#A
M^^L@\^3@Z^7M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@<V%V960N(@IM<V=S='(@(M'E\.+E\"`E<R#A^^L@\>[GY.#M(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@
M<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L#D\.7QX/(@\^+E
MY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C,S,`HC+"!F=7IZ>0IM<V=I9"`B5&AE('-P96-I9FEE9"!R
M;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7M
MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<
M(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[L
MZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,S`Y"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H
M('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G
M:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D
M871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(V,B!L:6(O2&]R9&4O
M1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#N
MY>HN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#I
MY.7M+B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*
M;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T
M<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[EZBXB"@HC(&9U>GIY"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HS-#D*;7-G:60@(E1H97)E(&%R92!N
M;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M("+1[N[A^>7MZ.4@XB#MY>+E\.WN["#T[O#LX/+E(.@@[>4@[.[FY?(@X?OR
M_"#N\N[A\.#FY>WN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A
M8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R
M86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S
M='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L_P[N'KY>S@(._P
MZ"#O\.[Q[.[R\.4@Y^#O\.[XY>WM[N/N(._H\?SLX"XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("+/
M\.@@\^3@Z^7MZ.@@Y^#DX/?H(.+NY^WHZNOH(.[XZ.'JZ"XB"@HC.B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S
M97(N<&AP.CDQ-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA
M<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET
M97,I+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L
M;'D@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("+.^.CAZN`@
M[_#H(.[R[N'PX.;E[>CH(/WR[ND@]^#Q\N@@\>[NX?GE[>C_(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C
M+2,M(RTC+2-<;B(*(L[XZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM^_4N(@H*(SH@
M;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q
M+C$I("`C+2,M(RTC+2-<;B(*(L[XZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM^_4N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E
M<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*
M(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.^.CA
MZN`@[_#H(.CL[^[P\N4@Y.#M[?OU+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@
M[_#H(.CL[^[P\N4@Y.#M[?OU+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,@HC
M+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@
M=C$N,2D@(",M(RTC+2,M(UQN(@HBSOCHX>K@(._PZ"#H[._N\/+E(.3@[>W[
M]2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"B,L
M(&9U>GIY"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("+"X/@@X?#N\^?E\"#MY2#O
M[N3DY?#FZ.+@Y?(@[N_VZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H(.W@YNSH\N4@
M0U123"M0+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C0X
M"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("+=\NX@Y^W@]^7MZ.4@Y.[K
MYNWN(.'[\OP@]^CQZ^[L+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C4R"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("+=\NX@Y^W@]^7M
MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3,T"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BW?+N(.?MX/?E[>CE
M(.3NZ^;M[B#A^_+\(/?H\>ON["XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@
M4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@R
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,#DP"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$Y(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3@V(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8P"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S`Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`R(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-38Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0S
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.38R(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#`Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,S(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#@R(&QI8B](;W)D92]&;W)M+G!H<#HR,34S"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C(U(&QI8B](;W)D92]&;W)M+G!H<#HR-#$R(&QI8B](
M;W)D92]&;W)M+G!H<#HR-#4T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0T
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#$W(&QI8B](;W)D92]&;W)M+G!H<#HS
M,3(V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`T(&QI8B](;W)D92]&;W)M
M+G!H<#HS.#$R(&QI8B](;W)D92]&;W)M+G!H<#HS.#(P"FUS9VED(")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C0R,`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3DS"B,L(&9U>GIY"FUS9VED
M(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@
M(MWR[B#G[>#WY>WHY2#D[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(X,C4*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C
M;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O
M<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N
M(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'
M<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB
M8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T
M("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("+=\NX@]^CQZ^X@[>4@[.[F
MY?(@X?OR_"#LY>W\^.4@Y>3H[>CV^RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E
M<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@
M8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+B(*;7-G<W1R("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@
M]^CQZ^[L+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@
M3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E1H=6YD97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B
M5&EC:V5T<R(*;7-G<W1R("+'X._P[O'[(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(T,CD@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U
M>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B
M"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*
M;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(M3N\.S@\B#N\N[A\.#FY>WH
M_R(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*(RP@9G5Z
M>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(L_NZ^WNY2#N[^CQ
MX.WHY2#O\.[AZ^7L^SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B
MQ^#C[NONXN[J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I
M9"`B5&\B"FUS9W-T<B`BRN[L\R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-3(*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L
M92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N
M9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(M?R[N'[
M(.+[X?#@\OP@[>7QZN[K_.KN(/WKY>SE[?+NXBP@\^3E\.;HXN#I\N4@[>#F
MX/+NZ2#JZ^#BZ.;S($-T<FPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S`P"B,L(&9U>GIY"FUS9VED(")4;V1A>2(*;7-G<W1R("+*[NSS
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@
M9G5Z>GD*;7-G:60@(E1O9V\B"FUS9W-T<B`BRN[L\R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O
M:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`BRN#K
MY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`BRN[L
M\R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-PHC+"!F=7IZ>0IM<V=I9"`B5&]P(@IM<V=S='(@(LKN[/,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS
M9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R
M:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G
M<W1R("+/\>7BY.[MZ.PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H
M;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO
M:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@
M9G5Z>GD*;7-G:60@(E5G86YD82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"B,L
M(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z-#$Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CM
MZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN
M9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C,Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7P
MXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS.3(@;&EB+U9&4R]M=7-Q
M;"YP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G
M<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HW.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(LWEXN[G
M[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C(S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HV.34@;&EB+U9&4R]S<6PN<&AP.C$P,C@@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z.#4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS
M9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB
M"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z.#<P"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W
M:71H(%-33"XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-1
M3"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(S,B!L:6(O5D93
M+V9I;&4N<&AP.C(S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#0*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q
M-PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,W,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,V,2!L:6(O5D93+VUU<W%L
M+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C8T"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H
M[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR
M.3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[E
MY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!3
M44P@\>7PXN7P[NPN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z
M-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HR,C@@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("+-Y>+NY^SNYNWN
M(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M
M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["Y<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC
M+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N
M["Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M
M(RTC+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@
M(",M(RTC+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#Q
MY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S."!L:6(O5D93+W-Q
M;"YP:'`Z,SDU(&QI8B]61E,O;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HS-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P
M[NPN(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,V,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("+-Y>+NY^SN
MYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,S0T(&QI8B]61E,O;75S<6PN<&AP.C,R,B!L:6(O5D93+VUU
M<W%L+G!H<#HS,S4*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,U,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H
M[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT
M,C`@;&EB+U9&4R]S<6PN<&AP.C0S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS
M9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,Q,"!L:6(O5D93+W-Q;"YP:'`Z,CDQ
M(&QI8B]61E,O;75S<6PN<&AP.C$V-PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ
M.#`@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C,Y,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3D*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G
M[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(T.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z-#`Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@
M(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C@S-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B[N?L
M[N;M[B#Q[O7PX.WH\OP@\_'RX.WNXNKH(.(@\>7Q\>CH+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(LWEXN[G[.[F[>X@Y^#C\//GZ/+\(.[O\.7D
MY>OE[>CE("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`S(&QI8B]61E,O
M9FEL92YP:'`Z,C`X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W-`HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR
M_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HY,R!L
M:6(O5D93+W-M8BYP:'`Z,3`V(&QI8B]61E,O<VUB+G!H<#HV-3(*(SH@;&EB
M+U9&4R]F='`N<&AP.CDX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(LWEXN[G
M[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HR.#0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$T,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HX,R!L:6(O5D93+V9I;&4N<&AP.C$S-R!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@
M\>7PXN7P[NPN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-1
M3"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+G!H<#HX-38*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7P
MXN7P[NPN(@H*(SH@;&EB+U9&4RYP:'`Z.#@W"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I
M+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS
M.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S
M='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HV-S8*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C$Q,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,S(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@
M\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(W,2!L:6(O
M5D93+V9T<"YP:'`Z,S0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C8Q-R!L:6(O5D93+VUU<W%L+G!H<#HR,CD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!3
M44P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,R-B!L:6(O5D93
M+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C(Y,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#D*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("+-
MY>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("+=
M\N[R(.3NZO/LY>WR(%=O<F0@[>4@[.[FY?(@X?OR_"#OY?#EXN7DY>TN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L:6(O5D93+V9T<"YP:'`Z,34W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_
M(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3@V"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH
M*2!F86EL960I+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C@X(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$T-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z(&QI8B]61E,N<&AP.C@V,@HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`*(RP@9G5Z>GD*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("+'X./N
MZ^[B[NHB"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5
M;F1O($-H86YG97,B"FUS9W-T<B`BSO+LY>WH\OP@Z.?LY>WE[>C_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
MT^3@Z^CR_"#OX/#S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$Y(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W."!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(R!F
M=7IZ>0HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("+/\_'R[NDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,@IM<V=I9"`B56YI=',B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0S,`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK
M;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B
M56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"B,L(&9U
M>GIY"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M("+-X/'R\.[IZN@B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"XB"FUS9W-T<B`BS^[FX.OSZ?'RX"P@XN+EY.CRY2#"X/CH(.CL
M_R#O[NO\Y^[BX/+EZ_\@Z"#OX/#NZ_PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G
M:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<
M;B(*(O/A\.#R_"#Q\N[KX>7V(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HS,#(*(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BR.S_(._N
MZ_SG[N+@\N7K_R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A
M;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O
M<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U
M(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,@HC+"!F=7IZ>0IM<V=I9"`B56YS970@8V]L
M;W(B"FUS9W-T<B`BR/'O[NO\Y^[BX/+\(.?MX/?E[>CE(._N(//L[NOWX.WH
M_B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@W(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T
M<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(L_PZ.SE[>CR_"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T92`E<R(*;7-G<W1R("+1[O7PX.WH\OP@[>#Q\O#NZ>KH(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM<V=I
M9"`B57!D871E('5S97(B"FUS9W-T<B`BQ.[AX.+H\OP@[^#P\R(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`BT>[U\.#MZ/+\
M(.W@\?+P[NGJZ"(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS
M9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.3@*(RP@9G5Z>GD*;7-G:60@(E5P;&]A9"(*;7-G
M<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N
M-"D@(",M(RTC+2,M(UQN(@HBS_#N]^CRX.WM^^5<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@
M(RTC+2,M(RTC7&XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS
M9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@
M;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"B,L(&9U>GIY"FUS
M9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(LCL_R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*(RP@
M9G5Z>GD*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("+2Y>KS
M^>7E(.+PY>S_(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"B+(\>_N
MZ_SG\^7R\?\@Y?'KZ"#BX/CH(.CL_R_OX/#NZ_P@Y.O_($E-4U`@\>7PXN7P
MX"#N\NOH]^#^\O'_(.[R(/+EZO/YZ/4B"@HC(&9U>GIY"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T
M<B`BS^[K_.?NXN#RY>O\(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P
M,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS
M(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!S:6=N=7`N
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G
M<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@<VEG;G5P+G!H<#HR
M,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@
M9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0V.0HC+"!F=7IZ>0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F
M;W5N9"(*;7-G<W1R("+.\NSE[>CR_"#HY^SE[>7MZ/\B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8@;&EB+TYE="]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34P
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-S(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(LCL_R#O[NO\
MY^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R("+/X._JX"!<(B5S7"(@\^;E(/'S^>7Q
M\N+SY?(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+E
MZ_\B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*
M;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*(RP@9G5Z>GD*;7-G
M:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`BQ.#RX"(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,3<P(&QI8B]61E,O9FEL92YP:'`Z,C8R"B,L(&9U>GIY"FUS9VED
M(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+`Y/#E
M\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3(P"B,L(&9U>GIY"FUS9VED(")686-A=&EO;B(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@
M(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#<P"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y
M"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DW(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8P(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(W,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,R,`HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,CDQ-R!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HU.0HC+"!F=7IZ>0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(L?@[.7RZN@B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C$Y,`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S,PHC+"!F=7IZ>0IM<V=I9"`B5F%R:6%B
M;&4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS
M9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H
M879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*(RP@9G5Z>GD*;7-G:60@(E9E<G-I
M;VXB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C(X"B,L(&9U>GIY"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS
M9W-T<B`BPNWH[.#MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T:6-A
M;"!A;&EG;B(*;7-G<W1R("+1Z^7D\_[YY?\@\?+PX.WH]N`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"B,L(&9U>GIY
M"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(M'KY>3S_OGE_R#Q
M\O#@[>CVX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("+1
MZ^7D\_[YY?\@\?+PX.WH]N`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B5F5R>2!(:6=H(@IM
M<V=S='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$V"B,L(&9U>GIY"FUS9VED(")6:65T($YA;2(*
M;7-G<W1R("+([/\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I
M9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@)7,B"FUS9W-T<B`BS_#N\>SN\O`@)7,B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M(@IM<V=S='(@(L_NZN#GX/+\(.+EX2WQ\O#@[>CV\R(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX,C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`BS_#N\>SN\O`@)7,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED
M(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N
M9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]H=&UL+G!H<#HQ,C$@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS
M9VED(")787)N:6YG(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS
M9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P
M<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.#DV"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(L+EX2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3@*
M;7-G:60@(E=E96ML>2(*;7-G<W1R("+%YN7MY>3EZ_SM[B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC
M;VUE(@IM<V=S='(@(L3NX?#N(._NYN#K[N+@\OPL("5S(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS
M9W-T<B`BQ.[A\.X@[^[FX.ONXN#R_"#B("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(L3N
MX?#N(._NYN#K[N+@\OPL("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.30*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M
M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM
M<V=S='(@(B(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O
M<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-#$*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(M?R[B#N\N[A\.#FX/+\(._N
M\>OE(.+U[N3@(.(@\>CQ\N7L\SHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P-C(*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E
M<R(*;7-G<W1R("+4X.?@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+B(*;7-G<W1R("+*X.KHY2#N[_;HZ"#A\^3S\B#D[O'R
M\^_M^R#B(.+HY_/@Z_SM[NP@\.7DX.KR[O#E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM
M<V=I9"`B5VED=&@B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$Q-`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S
M='(@(B(*"B,@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C
M="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(MCH\.CMX"#LY>W^("5S(/'K
MY>+@("CA\^3E\B#O\.CLY>WE[>`@[_#H(/'KY>3S_OGE["#B]>[DY2DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM
M<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"B,L(&9U>GIY
M"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*(RP@9G5Z
M>GD*;7-G:60@(E=I9'1H.B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ>0IM<V=I
M9"`B5VEN9"(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")7:6YD
M($5A<FQY(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S,0HC+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM<V=S
M='(@(L+MZ.S@[>CE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y
M.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+0
MX.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`BT.#A[O?HZ2#R
MY>OE].[M(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB+T9I;&4O0U-6
M+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ
M,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E
M9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME
M>2!5<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y
M-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@
M(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+#PR(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U-`HC+"!F=7IZ>0IM<V=I9"`B65E962(*
M;7-G<W1R("+#PR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3`Y"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G
M<W1R("+%YN7C[N3M[B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C0*;7-G:60@
M(EEE<R(*;7-G<W1R("+$X"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A
M9W)E96UE;G1?8F]T=&]M+FEN8SHV"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE
M(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92YP:'`Z,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N
M=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T
M97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#4Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Y"B,L(&9U
M>GIY"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D
M9')E<W,N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!L:6(O2&]R9&4O1&%T
M82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@
M;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@
M8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("+"^R#B^_CKZ"#HYR#QZ/'R
MY>S[+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8U"FUS9VED("(B"B)9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q.3(*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(L+@^"!%;6%I;#HB
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C0V,@IM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@HBPOL@Y.[KYNW[
M(.[OZ/'@\OP@[_#NX>OE[/LL(._PY>;DY2#WY>P@\>SNYN7RY2#N\N[QZ^#R
M_"#Q[N[A^>7MZ.4@[B#MY>DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S
M="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM
M<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G
M<W1R("(B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO
M;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(L+@^.`@)7,@
M\>7Q\>C_(.?@ZN[M]^CKX/'\+B#/[N;@Z_/I\?+@+"#B[NGDZ/+E(.(@\>CQ
M\N7L\R#GX.WNXNXN(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(L+@^"!%;6%I;#HB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B
MPN#X(.#D\.7Q(.[R[_#@XNCRY>O_.B(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B
MPN#XX"#H[?3N\.S@]NC_(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G
M<W1R("+"X/CE(.CL_SHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D
M9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C
M:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HU-0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("+"X/@@X?#N\^?E\"#M
MY2#O[N3DY?#FZ.+@Y?(@[N_VZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H(.W@YNSH
M\N4@0U123"M0+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS
M.C0R"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`BPN#X(.'P[O/GY?`@[>4@
M[^[DY.7PYNCBX.7R(.[O]NC^(._E]^#RZ"X@Q.O_(._E]^#RZ"#MX.;LZ/+E
M($-44DPK4"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED
M(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("+7X/'NXN[I(._N
M__$B"@HC(&9U>GIY"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3$*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N
M9V5D+B(*;7-G<W1R("+"X/@@[_#N].CK_"#O[B#S[.[K]^#MZ/XZ(@H*(R!F
M=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R
M(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(L+@^"#O\.[TZ.O\(._N(//L
M[NOWX.WH_CHB"@HC(&9U>GIY"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(L+@
M^.4@Z.S_.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.3D*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(L+@^.@@
M[>#Q\O#NZ>KH(.'[Z^@@[N'M[N+KY>W[+B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W
M('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`BPN#XZ"#MX/'R\.[IZN@@X?OKZ"#NX>WN
MXNOE[?LN(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`BPN#X
MZ"#MX/'R\.[IZN@@X?OKZ"#NX>WNXNOE[?LN(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G
M:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(M'R[O#N[>WHZ2#Q
MY?#BY?`Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"B,L(&9U>GIY
M"FUS9VED("):86ER92(*;7-G<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I
M82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*
M;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*
M;7-G<W1R(");T>[NX?GE[>CE(.X@[_#NX>OE[.5=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML
M:6YE("5S(&]F("5S72(*;7-G<W1R(");\?+P[NK@("5S(.CG("5S72(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("+3
M[_#@XNOE[>CE(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0HC+"!F=7IZ>0IM<V=I9"`B
M7T1A=&%4<F5E(@IM<V=S='(@(L3@\N`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G
M:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(M/DX.OH\OPB"@HC(&9U>GIY"B,Z
M(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("+#\//O
M[_LB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@
M(E](96QP(@IM<V=S='(@(L_N[.[Y_"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BRNOE\N[W[>#_(/#@
MY.CN\>+_Y_PB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY
M"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(L+U[N0B"@HC(&9U>GIY"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(L+[]>[D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")?36]D:69Y($QI;FLN
M+BXB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(R!F=7IZ>0HC.B!L:6(O2&]R
M9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("+-X/'R
M\.[IZN@B"@HC(&9U>GIY"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E
M<FUI<W-I;VYS(@IM<V=S='(@(L_PX.+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS
M9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*
M(R!F=7IZ>0HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G
M<W1R("+/\.CK[N;E[>C_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")?5&%B
M;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G
M_"(*"B,@9G5Z>GD*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`BS^[K_.?NXN#RY>OH(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,C`*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+`
MY/#E\>W@_R#J[>CCX"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$S-`HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T
M<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ
M,@HC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`BRN#KY>WDX/#\
M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@
M:6YP=70B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C4Y.0IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN
M92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS
M9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T
M82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!T96UP;&%T
M97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(L_P
MX.+H\OPB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@
M9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("+.\NSE[>CR
M_"#HY^SE[>7MZ/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.#@Q"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM
M<V=S='(@(L?@X^[K[N+NZB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,SD*(RP@9G5Z>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B6_'R
M\.[JX"`E<R#HYR`E<UTB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C0X"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4W"FUS9VED(")H:"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G
M:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F
M+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*
M(RP@9G5Z>GD*;7-G:60@(FQI;F5S72(*;7-G<W1R("+'X./NZ^[B[NHB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,V.`IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"B,L
M(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D
M92]24$,N<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ
M*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*(RP@9G5Z>GD*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WH
MY2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`T"B,L(&9U>GIY"FUS9VED
M(")N;W1E<&%D(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C
M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[B
MX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I
M*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M
M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I
M>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M-`HC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(L+MZ.S@[>CE(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R"B,L(&9U>GIY"FUS
M9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(LWE\B#D[O'R\^_M
M^_4@[>#Q\O#NY>HN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*
M;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY
M"FUS9VED(")S=&5A9'DB"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,34P"B,L(&9U>GIY"FUS9VED(")S>7-T
M96T@97)R;W(B"FUS9W-T<B`B[O#T[N/PX/3H]^7QZN#_(.[XZ.'JX"(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(X"FUS9VED(")T87-K(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38V"B,L
M(&9U>GIY"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("+/[NCQ
MZB(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU
M<"YP:'`Z,C<P"B,L(&9U>GIY"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T
M=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(L_P[O?@_R#H[?3N\.S@]NC_(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L
M:6(O2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R("+RY>KQ\B#Q[N[A^>7MZ/\B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M
M(UQN(@HBQ.7I\?+BZ.4Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0P"FUS9VED(")W
M.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O
M+W-K7U-++G!O````````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`W,#`P-S``,3`T,3<S-C,P,#,`,#$V-#`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@2&]R9&4@4VQO
M=F%K('1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,B!,96\@37)A
M9FMO(#QL96]`;V5L+G-K/B`H;W)I9VEN86P@=')A;G-L871O<BD*(R`H0RD@
M,C`P,BP@,C`P,R!)=F%N($YO<FES(#QV:7A`=F%Z:V$N<VL^"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,5QN
M(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<
M;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`Q+3`V(#$T.C$P*S`Q,#!<
M;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#$M,S`@,C$Z,C8K,#(P,%QN
M(@HB3&%S="U4<F%N<VQA=&]R.B!)=F%N($YO<FES(#QV:7A`=F%Z:V$N<VL^
M7&XB"B),86YG=6%G92U496%M.B!3;&]V86L@/'9I>$!V87IK82YS:SY<;B(*
M(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@."UB:71<;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@
M(B`H<')E9"`E<R!D\F%M:2DB"@HC.B!L:6(O2&]R9&4N<&AP.C$S-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H
M2VSA=F5S;W;A('-K<F%T:V$@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G
M<W1R("(@*&\@)7,@9&[M*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<W
M"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(H9&YE<RDB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B
M("AZ86IT<F$I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@
M(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*';H97)A*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV
M"FUS9VED("(@870@(@IM<V=S='(@(B!R_6-H;&]SNR`B"@HC.B!L:6(O5D93
M+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!N:64@:F4@861R97/A
M<BXB"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B
M7"(E<UPB(&YI92!J92!P;&%T;N$@=F^U8F$N(@H*(SH@;&EB+TAO<F1E+U)E
M9VES=')Y+G!H<#HV-3(@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0P"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!N:64@:F4@
M;F%K;VYF:6=U<F]V86[I('8@<F5G:7-T<FD@2&]R9&4N(@H*(SH@;&EB+TAO
M<F1E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(GIO8G)A>F]V8>@@
M<W1R;VUU(%PB)7-<(B!N96)O;"!NX6ID96[]+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B4VMU<&EN82!<(B5S
M7"(@8F]L82!P<FED86[A(&1O('-Y<W3I;74N(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B
M4'+A=F\@7"(E<UPB(&)O;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z
M("5S+B(*;7-G<W1R(")<(B5S7"(@;F5B;VQO(&UOOF[I('9Y='9O<FF[.B`E
M<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E
M)2DB"FUS9W-T<B`B4&]UOFET_6-H("4N,F9-0B!Z(&1O=F]L96[]8V@@)2XR
M9DU"("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T
M<B`B)60@)7,@82`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(V
M."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G
M<W1R("(E9"!D;NT@9&\@=GEP<KEA;FEA('!L871N;W-T:2!6X;EH;R!H97-L
M82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R(")P<F5D
M<&]V9>\@;F$@)60@9&[M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(B5S("T@4&]Z;N%M:V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G
M<W1R(")/9'1L8>AO:R`E<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HX-#`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(D]P97+A8VEE(/ID<KYB>2!P<F4@87!L:6OA8VEU("5S("T@4&]T
M=G)D96YI92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M971U<"(*;7-G<W1R(").87-T879E;FEE("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG
M;B!5<"(*;7-G<W1R(")296=I<W1R;W9A;FEE(&1O(&%P;&EKX6-I92`E<R(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B4&]D;6EE
M;FMY('!O=;YI=&EA("5S(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0S,B!L:6(O
M5D93+W-M8BYP:'`Z-#DT(&QI8B]61E,O9G1P+G!H<#HV-S$*(SH@;&EB+U9&
M4R]F='`N<&AP.C<S.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B)7,@=;X@97AI<W1U:F4N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@=F\@=OVY:V4@)7,@)7,B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+B(*;7-G<W1R("(B"B)!<&QI:^%C:6$@)7,@:F4@<')I<')A
M=F5NX2!N82!V>6MO;F%N:64@;W!E<N%C:>T@^F1ROF)Y+D]Z;F'H=&4@N71V
M;W+H96L@<')I("(*(F]P97+A8VGA8V@L(&MT;W+I(&-H8V5T92!V>6MO;F&[
M('1E<F%Z+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S0T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(E!OOF%D=6IE
M('-A("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6[Z="(*"B,Z
M(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N96)O;"!N
MX6ID96[]+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B
M)7,@8;X@)7,@>B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@
M(D%D<F5SX7(@<&]UONUV871EM6$@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM
M<V=S='(@(DMA;&5N9.%R('!O=;[M=F%T9;5A("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E
M<&%D(@IM<V=S='(@(E!O>F[A;6MY('!O=;[M=F%T9;5A("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!487-K;&ES="(*;7-G<W1R("):;WIN86T@^FQO:"!P;W6^[79A=&6U82`E
M<R(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B
M)7,Z("5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA
M>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F
M(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM
M<V=S='(@(B(*(B5S.B!4X71O('-P<N%V82!N96UU<^T@8GF[(&]D(&]D;W-I
M96QA=&6U82P@:W1O<OT@<V$@>F]B<F%Z=6IE(&%K;R`B"B)O9&]S:65L871E
MM2!S<'+A=GDN(%IA8VAO=F%J=&4@;W!A=')N;W.[('!R:2!K;&EK86[M(&YA
M(&QI;FMY('8@<W!RX79E(&%L96)O("(*(G!O<VMY=&]V86[M(&]S;V)N_6-H
M(&EN9F]R;>%C:>T@;V1O<VEE;&%T9;5O=FDN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@;N%R87IO=OT@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S
M(@IM<V=S='(@(BP@=B!NX7)A>F]C:"`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('!R96UE;F[A('8@<F]Z<V%H=2`E
M<R!AOB`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#<S(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3,R(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,S0X(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HW-#4*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G
M<W1R("(M+2!V>6)E<G1E('-I("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUH;V1I;F]V
M_2!F;W)MX70B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T
M($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T+6AO9&EN;W;](&9O<FWA="(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*
M;7-G<W1R("(R-"!H;V3M;B(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z
M-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\4')E9&-HX61Z86KZ8V$B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R
M(")0<F4@=&5N=&\@8FQO:R!J92!P;[YA9&]V86[](&1A=&%BX7IO=OT@8F%C
M:V5N9"XB"@HC.B!L:6(O2&]R9&4N<&AP.C$V,@IM<V=I9"`B02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B5GES:WET;&$@<V$@>N%V8;YN
MX2!C:'EB82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM<V=I
M9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B3F$@>F&Y:69R;W9A;FEE('-P<N%V>2!J92!P
M;[YA9&]V86[]('9E<F5J;OT@4$A0(&NU^N@N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M3F$@;W9E<F5N:64@<&]D<.US86YE:B!S<'+A=GD@:F4@<&^^861O=F%N_2!V
M97)E:F[](%!'4"!KM?KH+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B).82!D9;EI9G)O=F%N:64@<W!R
MX79Y('/Z('!O=')E8F[I.B!V97)E:F[](%!'4"!KM?KH+"!P<FEVX71N>2!0
M1U`@:[7ZZ"!A("(*(FAE<VQO+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B).82!P;V1P[7-A;FEE('-P<N%V
M>2!S^B!P;[YA9&]V86[I.B!V<F5J;OT@4$=0(&NU^N@L('!R:7;A=&YY(%!'
M4"!KM?KH(&$@(@HB:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B).82!D9;EI9G)O
M=F%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU
M^N@L('!R:7;A=&YY(%,O34E-12`B"B)KM?KH(&$@:&5S;&\N(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R
M("(B"B).82!P;V1P[7-A;FEE('-P<N%V>2!S^B!P;[YA9&]V86[I.B!V97)E
M:F[](%,O34E-12!KM?KH+"!P<FEVX71N>2!3+TU)344@(@HB:[7ZZ"!A(&AE
M<VQO+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED
M(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(DYA('IAN6EF<F]V86YI92!S<'+A=GD@:F4@
M<&^^861O=F%N_2!V97)E:F[](%--24U%(&NU^N@N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S
M(@IM<V=S='(@(E!R961P;VQU9&[M;2!O8FQAZ&YO(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B4')E9'!O;'5D;NUM(+5A:&O](&3AON\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B
M04T@4F%I;B(*;7-G<W1R(")0<F5D<&]L=61N[6T@9.&^[R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(E!R961P;VQU9&[M;2!P<F5HX6YK>2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!
M32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4')E9'!O;'5D;NUM('-N96AO=ND@
M<')E:.%N:WDB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B,3(@:&]D[6XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@
M(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D\@
M=&]M=&\@961I=&]R92(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S
M"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")/+BXN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T
M=&]M(@IM<V=S='(@(D%B<V]L^G1N>2!S<&]D;VLB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D
M;&4B"FUS9W-T<B`B06)S;VSZ=&YY('-T<F5D(@H*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(E!R:2!V>71VX7)A;NT@5D93(&%D<F5SX7)A
M(&)O;"!Z86UI971N=73]('!R[7-T=7`N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+B(*;7-G<W1R(")0<FD@=GET=N%R86[M(%9&4R!S^F)O<G4@8F]L('IA;6EE
M=&YU=/T@<'+M<W1U<"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM
M<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FWA8VEE
M(&\@^NAT92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B
M06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")(97-L;R!P<F4@^NAE="(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`BVNAE="!Z86)L;VMO=F%N_2XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT
M:6YG(@IM<V=S='(@(MKH=&]V86YI92(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D
M(@IM<V=S='(@(E!R:61ANR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS
M9W-T<B`B4')I9&&[('!O9')I861E;OH@<VMU<&EN=2(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM
M<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B4')I9&&[('!O
M9')I861E;ND@<'+A=F\B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z
M-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(E!R:61ANSHB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B
M061D($YE=R!'<F]U<"(*;7-G<W1R(")0<FED8;L@<VMU<&EN=2(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(E!R:61A
MNR!N;W;I('!RX79O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B4')I9&&[(&1CZ7)S:W4@<VMU<&EN
M=2!D;R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O
M(%PB)7-<(B(*;7-G<W1R(")0<FED8;L@9&/I<G-K92!P<N%V;R!D;R!<(B5S
M7"(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S
M97(Z(@IM<V=S='(@(E!R:61ANR!P;W6^[79A=&6U83HB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34S"FUS9VED(")!9&0@8V]L
M=6UN(@IM<V=S='(@(E!R:61ANR!S=.5P96,B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`B4')I9&&[(.AL96YO=B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E!R:61ANR!P
MX7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A
M<B(*;7-G<W1R(")0<FED8;L@;65N=2`E<R!A:V\@0F_H;OT@<&%N96P@36]Z
M:6QL>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*
M;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(E!R:61ANR!D
M;R!A9')E<^%R83HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@
M(E!R:61ANR!D;R!M]&IH;R!A9')E<^%R82(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")0<FED8;L@<&]UONUV871E
MM6$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*
M;7-G<W1R("(B"B)<(B5S7"(@8F]L('!R:61A;OT@9&\@<WES=.EM=2P@86QE
M(&YE;6^^;F\@<')I9&&[(.]A;+EI92!P<FEH;&%S;W9A8VEE("(*(FEN9F]R
M;>%C:64Z("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RXB"FUS9W-T<B`B7"(E<UPB(&)O;"!P<FED86[](&1O('-Y<W3I
M;74N(%1E<F%Z('-A(&WTOF5T92!P<FEH;.%S:;LN(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B4')I9.%V86YI92!P;W6^[79A=&6U;W8@
M:F4@>F%KX7IA;NDN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS
M9W-T<B`B061R97-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T
M,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5SX7(B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN
M:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S
M='(@(D%D;6EN:7-T<N%C:6$@+2!N87-T879E;FEE('!RX78@<')E(&EN_6-H
M('!O=;[M=F%T9;5O=B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")!9&UI;FES='+A8VEA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(E)E:VQA;7DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M06QB86YI82(*;7-G<W1R(")!;&+A;G-K;R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS
M9W-T<B`B06R^[7)S:V\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V
M"FUS9VED(")!;&EG;B(*;7-G<W1R("):87)O=FYANR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N
M;65N=#HB"FUS9W-T<B`B6F%R;W9N86YI93HB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")6N65T:WDB"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G
M<W1R(")6N65T8VD@875T96YT:69I:V]V86[M('!O=;[M=F%T96QI82(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G
M:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B5KEE=&MY('-K=7!I;GDB"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDQ(&QI8B](;W)D92]097)M<R]D871A
M=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")6
MN65T:WD@<'+A=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G
M<W1R(")6N65T:WD@N71Y<FD@<W1R86YY(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S4*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G
M<W1R(")0;W9O;&F[('9I86-E<ND@861R97-Y(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\B"FUS9W-T<B`B4&]V;VQINR!N87-T879E;FEE('1Y<'4@
M>F]R861E;NEH;R!Z;WIN86UU/R(*"B,Z(&QI8B](;W)D92]$871A5')E92]S
M<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B5;X@
M97AI<W1U:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED
M(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=.UV;F4@
M<')I:&QA<V]V86-I92!M96YO($E-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G
M<W1R(")!;'1E<FYA=.UV;F4@:&5S;&\@24U34"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE
M(@IM<V=S='(@(D%L=&5R;F%T[79N92!P;W6^[79A=&6U<VOI(&UE;F\@24U3
M4"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!
M;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA=.UV;F$@
M92UM86EL;W;A(&%D<F5S82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R
M"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T
M[79N92"Y86)L\VYY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X
M=#HB"FUS9W-T<B`B06QT97)N873M=FYY('1E>'0Z(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC
M86X@4V%M;V$B"FUS9W-T<B`B06UE<FEC:^$@4V%M;V$B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U
M"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S
M='(@(D)O;&$@>F%D86[A(&YE<&QA=&[A(&AO9&YO=&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R
M<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(").87-T86QA(&YE>F[A;6$@8VAY
M8F$N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(D%N9W5I;&QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;GEM;ND@<')O
M>'DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B
M06YS=V5R(@IM<V=S='(@(D]D<&]V9>\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM
M<V=S='(@(D%N=&%R:W1I:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A
M(@IM<V=S='(@(D%N=&EG=6$@82!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4@;&EB+TAO<F1E+T)L
M;V-K+U5)+G!H<#HU.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI:^%C:6$B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T
M:6]N($QI<W0B"FUS9W-T<B`B6F]Z;F%M(&%P;&EKX6-I[2(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E
M861Y+B(*;7-G<W1R(")!<&QI:^%C:6$@:F4@<')I<')A=F5NX2XB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P;&EK;W9ANR!N82!P;V1R:6%D96[I
M('ID:66U86[I('!R:67H:6YK>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(E-C:';A
M;&F[(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,`IM<V=I
M9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")0<FEB;&F^;N$@=F6U:V]S
MNR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!
M<')I;"(*;7-G<W1R(")!<'+M;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<Q"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S
M='(@(E9EM6MO<[L@87)C:.UV=2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C4X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`B365N;R!A<F-H[79U(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(").86]Z86H@8VAC
M971E('9Y;6%Z8;L@OFEA9&]SNR!O('!R:6ALX7-E;FEE("<E<R<_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(").86]Z86H@8VAC
M971E('9Y;6%Z8;L@7"(E<UPB(&$@=KEE=&MY('!O9'-K=7!I;GD_(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=.UN82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N
M:6$B"FUS9W-T<B`B07)MZ6YS:V\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W,@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T
M<B`B56UE;FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B3W-T<F]V($%S8V5N<VEO;B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%S8VEI
M('5M96YI92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(L%Z:6$O4&%C:69I8VO]
M(')E9VGS;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@
M(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/R(*;7-G<W1R(")6>;YA9&]V8;L@<&]T=G)D96YI92!P
M<F5D('9Y:V]N86[M;2!O<&5RX6-I[2#Z9'*^8GD_(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,#(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B4&]K
M=7,@;R!V>6UA>F%N:64@;F5E>&ES='5J^F-E:B!S:W5P:6YY+B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!O:W5S
M(&\@=GEM87IA;FEE(&YE97AI<W1U:OIC96AO('!RX79A+B(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&]K=7,@;R#Z<')A
M=G4@;F5E>&ES='5J^F-E:&\@<'+A=F$N(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<VAA<F4N(@IM<V=S='(@(E!O:W5S(&\@^G!R879U(&YE97AI<W1U
M:OIC96AO('ID:66U86[I:&\@;V)J96MT=2XB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HW,0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM
M<V=I9"`B071T<FEB=71E<R(*;7-G<W1R(")!=')I8OIT>2(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T
M<B`B075G=7-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1RX6QI
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B4F%K^G-K;R(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7V-Y<G-Q;#H@4&^^861O=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B;VQO
M(&[A:F1E;NDN(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM
M<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!B86-K96YD
M(&YE;>$@<&^^861O=F%NZ2!S8VAO<&YO<W1I+B(*"B,Z(&QI8B](;W)D92]!
M=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U
M<SH@<&^^861O=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B;VQO(&[A:F1E;NDN
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T
M:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP
M:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G
M<W1R("(B"B)!=71H7V9T<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($944"!N
M96)O;&\@;N%J9&5NZ2X@4VMO;7!I;'5J=&4@4$A0(',@(@HB<')E<.UN8>AO
M;2`M+65N86)L92UF='`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z
M-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z('!OOF%D;W9A;ND@<F]Z
MN>UR96YI92!)34%0(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!P
M;[YA9&]V86[I(')O>KGM<F5N:64@:W)B-2!N96)O;&\@;N%J9&5NZ2XB"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A
M<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!P<FEDX79A;FEE('!O
M=;[M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;ND@<')E($%C=&EV92!$:7)E
M8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@
M(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z('9Y
M;6%ZX79A;FEE('!O=;[M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;ND@<')E
M($%C=&EV92!$:7)E8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@<&^^861O=F%NZ2!R
M;WJY[7)E;FEE($Q$05`@;F5B;VQO(&[A:F1E;NDN(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!.97!O9&%R:6QO
M('-A('!R:61ANR!P;W6^[79A=&6U82`E<RX@4V5R=F5R(&]D<&]V961A;#H@
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S
M(@IM<V=S='(@(D%U=&A?;&1A<#H@;F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@
M<&]UONUV871EM6$@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!N97!O9&%R:6QO
M('-A(&%K='5A;&EZ;W9ANR!P;W6^[79A=&6U82`E<R(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M+B(*;7-G<W1R("(B"B)!=71H7VQD87`Z(&%K='5A;&EZX6-I82!P;W6^[79A
M=&6U;W8@;FEE(&IE('!O9'!O<F]V86[A('!R92!!8W1I=F4@1&ER96-T;W)Y
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VUC86PZ('!OOF%D;W9A;ND@<F]ZN>UR96YI92!-0T%,(&YE
M8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*
M;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z('!OOF%D;W9A
M;ND@<F]ZN>UR96YI92!S;6)A=71H(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI
M8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T96YT:69I
M:^%C:6$@<&]M;V-O=2!)34%0('-E<G9E<F$@>FQY:&%L82XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D%U=&5N=&EF:6OA8VEA('IL>6AA
M;&$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")!
M=71E;G1I9FEKX6-I82!Z;'EH86QA+B`E<R(*"B,Z(&QI8B](;W)D92]!=71H
M+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")397)V97(@4D%$2553('IA
M;6EE=&]L(&%U=&5N=&EF:6OA8VEU+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX
M-S$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")!=71E;G1I9FEKX6-I82!P;VUO8V]U($944"!S97)V97)A
M('IL>6AA;&$N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H
M96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D%U=&5N=&EF:6OA8VEA('!O;6]C;W4@4TU"('-E<G9E<F$@>FQY:&%L82XB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I
M;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")$;W-T=7!NZ2!P;VQOOFMY.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A:F2^86XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G
M<W1R(")"3T9(($5X8W5S97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM
M<V=S='(@(E!O>F%D:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S
M='(@(D9A<F)A('!O>F%D:6$B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H
M<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("):
M;.D@:&5S;&\@<')E(&ME<F)E<F]S+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR
M8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S
M='(@(EILZ2!P;W6^[79A=&6U<VOI(&UE;F\@<')E(&ME<F)E<F]S+B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G
M:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UY(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R(")"86AR86IN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S,*
M;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9.FY(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D
M;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4')I9>AI;F]K(',@
M9W)A9FEK;W4@7"(E<UPB(&YE8F]L(&[A:F1E;OTN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"
M87-E;&EN92(*;7-G<W1R("):X6ML861N_2!R:6%D;VLB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(D)I96QO<G5S:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S
M='(@(D)E;&=I8VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*
M;7-G<W1R(")"97)M=61Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)U=.%N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G
M:60@(D)I<G1H9&%Y(@IM<V=S='(@(DYA<F]D96YI;GDB"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G
M:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(")";&]K(%PB)7-<(B!A<&QI:^%C:64@7"(E<UPB(&YE
M8F]L(&[A:F1E;OTN(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(").87-T879E;FEA
M(&)L;VMU(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS
M9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1Y<"!B;&]K=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L
M9"(*;7-G<W1R(")4=>ANZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L
M[79I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@
M(D)O;VMM87)K<R(*;7-G<W1R("):X6QOOFMY(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R
M9&5R(@IM<V=S='(@(D]K<F%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB
M"FUS9W-T<B`BJ>UR:V$@;VMR86IA.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B
M"FUS9W-T<B`B3VMR86IE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN
M82(*;7-G<W1R(")";W-N82!A($AE<F-E9V]V:6YA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D]B92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")"
M;W1T;VTB"FUS9W-T<B`B0F]T=&]M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*
M;7-G<W1R(")";W5V970@27-L86YD(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@
M(D)R87KM;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I
M=&]R>2(*;7-G<W1R(")"<FET<VOI(/IZ96UI92!V($EN9&EC:V]M(&]C9>%N
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$
M87)U<W-A;&%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L:&%R<VMO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("):;WIN86T@<R!O9'+A
MOFMA;6DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&
M87-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@
M(D--4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS
M9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM
M<V=S='(@(D1I<W1R:6)UZ&[I(&)O9'D@0U),(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#
M7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E9L87-T;F]S=&D@7V)U;FMY
M+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I
M9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B26YC
M:6%L:7KA8VEA('9Y<F]V;N%V86-E:B!P86WD=&D@;F5B;VQA(&1O:V]NZ&5N
MX2XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@R
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YD
MX7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED
M(")#86QM(@IM<V=S='(@(D)E>G9E=')I92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*
M;7-G<W1R(")+86UB;V2^82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA
M;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I
M9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3F5P;V1A<FEL
M;R!S82!A=71O;6%T:6-K>2!O8FYO=FF[(&AE<VQO+"!K;VYT86MT=6IT92!S
M=F]J:&\@861M:6YI<W1RX71O<F$N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE
M(%PB)7-<(B(*;7-G<W1R(").97!O9&%R:6QO('-A('IA<.US8;L@9&\@<_IB
M;W)U(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B
M0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*
M;7-G<W1R(").96UOOFYO(&%D;6EI<W1R;W9ANR!E>'1E<F[I(&]V;.%D8>AE
M('-E9&5N[2XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI
M8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@<W!O:FF[(',@24U!4"!S97)V97)O;3H@)7,B"@HC
M.B!L:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A
M(&]T=F]R:;L@<_IB;W(@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R
M(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP
M:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G
M<W1R("):<G6Y:;LB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(EIR
M=;EINR!S<'+A=G4@;R!P<F]B;.EM92(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[('/Z8F]R(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!NX6IS
MNR!D;^AA<V[](&%D<F5SX7(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP
M.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N(@IM<V=S='(@(DYE;6^^;F\@<&]K<F'H;W9ANR!B97H@
M<&%R86UE=')A("=T87)G971&:6QE)RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@
M861R97/A<B!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ
M,C@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*
M;7-G<W1R(").96UOOFYO(&]D<W1RX6YINRP@97AI<W1U:F4@)60@;F%S;&5D
M;W9N[6MO=BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*
M;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB
M<W1O<F5D+B(*;7-G<W1R("(B"B).96UOOFYO('!R975S<&]R:6%D8;LL('!O
MZ&5T('!O;&^^:65K('!R92!P<F5U<W!O<FEA9&%N:64@;F5S^FAL87/M(',@
M<&_H=&]M("(*(G5L;[YE;OUC:"!P;VQOOFEE:RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E
M(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!S;65R;W9ANR!S<'+A=G4@;F$@=7+H96[I(.CM<VQO+B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V%P=F5R9'-KZ2!O<W1R;W9Y(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")4:71U;&]K(@H*(SH@;&EB
M+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED
M(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96?S<FEE(&$@
M<&]P:7-K>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")+86IM
M86YS:^D@;W-T<F]V>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL;OT@
M=&5L96;S;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R
M(")6;&%S=&YO<W1I(&)U;FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS
M9W-T<B`B5GEP;&YE;FEE(&)U;FMY.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O
M<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO<W1I(&)U;FMY(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E
M;&P@<W!A8VEN9SHB"FUS9W-T<B`B4F]Z;W-T=7`@8G5N:65K.B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T
M<B`B36]B:6QN_2!T96QE9O-N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S0*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")$;R!S=')E9'4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4W1R961O869R:6-K
MX2!R97!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I
M9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I
M9FEC871E($1E=&%I;',B"FUS9W-T<B`B4&]D<F]B;ND@:6YF;W)MX6-I92!O
M(&-E<G1I9FEKX71E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E9L87-T;NUK
M(&-E<G1I9FEKX71U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E!O;&ET
M:6MY('!R92!C97)T:69I:^%T>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R("+(
M860B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T
M<B`B6FUE;FF[(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q
M"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("):;65N:;L@
M5F&Y92!H97-L;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*(DYA<W1A=F5N:64@;65N82!A(&%D<FEE<RP@:W1O
M<ND@=FED:6$@M75D:6$L(&ME[R#H[71A:OH@82!O9'!O=F5D86KZ(&YA(%9A
MN64@(@HB92UM86EL>2XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B
M"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB6FUE
M;F$@:&5S;&$@;FEE(&IE('8@86MT=>%L;F5J(&MO;F9I9W5RX6-I:2!P;V1P
M;W)O=F%NX2X@($MO;G1A:W1U:G1E('-V;VIH;R`B"B)A9&UI;FES='+A=&]R
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(EIN86LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*
M;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E-?:V]N=')O;&]V8;L@
M;&EN:W4N+BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")#:&EL92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-H:6YA(@IM<V=S='(@(LCM;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-@IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ
M(@IM<V=S='(@(E9Y8F5R=&4@87!L:6OA8VEU.B(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*
M;7-G<W1R("):=F^U=&4@<VD@:&5S;&\B"@HC.B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T
M<B`B6G9OM71E('-I('!O=;[M=F%T9;5S:^D@;65N;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SHB"FUS9W-T<B`B5GEB97)T92!S</1S;V(@>F]B<F%Z;W9A;FEA
M(&3A='5M;W8Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E9Y8F5R=&4@='EP
M(+ET_6QU('IO>FYA;74@*'!R92!Z;W)A9&5NZ2!Z;WIN86UY*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@
M(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B5FEA;F_H;OT@;W-T<F]V(@H*
M(SH@;&EB+U9&4RYP:'`Z.3$S(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(D1E9FEN[6-I82!T<FEE9'D@)7,@;F5B;VQA(&[A:F1E
M;N$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,30*;7-G:60@(D-L96%R(@IM<V=S='(@(DIA<VYO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@
M35-/9F9I8V4@=&%G<R(*;7-G<W1R(")/9'-T<N%N:;L@<'+M:V%Z>2!-4T]F
M9FEC92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(E9Y;6%Z8;L@9&]T87HB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B3V1S='+A;FF[('!O=;[M=F%T
M9;5A.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ
M,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")/9'-T<N%N:;L@<&]UONUV
M871EM6$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM
M<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(E9Y;6%Z8;L@<&]UONUV
M871EM7-KZ2#Z9&%J92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(DYE
M<VOT<B!V>6IA<VYE;FEE(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM
M<V=S='(@(DML:6MN:71E('!R92!P;VMR8>AO=F%N:64B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L
M;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL(&-E>B!(5%10(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B6F%T=F]R
M:;L@;VMN;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#
M;&]U9',B"FUS9W-T<B`B3V)L86MY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G
M<W1R(")2X6YO(&]B;&'H;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D]B;&'H
M;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")#
M;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T
M<B`B6F)A;&F[($)OZ&[]('!A;F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D
M(&)O<F1E<G,B"FUS9W-T<B`B6F)A;&5NZ2!O:W)A:F4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO
M;6)I82(*;7-G<W1R(")+;VQU;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO
M<B(*;7-G<W1R(")&87)B82(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T
M:6]N+G!H<#HS,C4@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R
M-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R
M(%!I8VME<B(*;7-G<W1R(")6_6)E<B!F87)B>2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#,U"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(E;]8F5R(&9A<F)Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(E-TY7!C93HB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU,`IM<V=I9"`B0V]L=6UN('1I
M=&QE<R(*;7-G<W1R(").861P:7-Y('-TY7!C;W8B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B2V]M
M:6MS(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD
M(@IM<V=S='(@(E!R[6MA>B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM
M<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")0<NUK87IO=OT@:6YT97)P
M<F5T97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`B2V]M96YTX7(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B
M0F6^;ND@;65N;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(DMO;6]R>2(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(E-P;VQOZ&YO<[LB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")0;^CM
M=&'H92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G
M:60@(D-O;F1I=&EO;B(*;7-G<W1R(")3=&%V(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B4W1A=B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(E)O>F1I96QY('8@:V]N9FEG=7+A
M8VEI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S
M(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"B)+;VYF:6=U<N%C:6$@<')E('-Y
M;F-H<F]N:7KA8VEU(',@4$1!+"!I;G1E;&EG96YT;OUM:2!T96QE9O-N;6D@
M82!/=71L;V]K;VTN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B
M2V]N9FEG=7+A8VEA('!O=')E8G5J92!A:W1U86QI>N%C:74N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYF:6=U<F4@)7,B"FUS9W-T<B`B2V]N9FEG=7)O=F&[("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER
M;2!087-S=V]R9"(*;7-G<W1R(")0;W1V<N]T92!H97-L;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;F=O(@IM<V=S='(@(DMO;F=O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")$96UO:W)A=&EC:^$@<F5P
M=6)L:6MA($MO;F=O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B4W!O:F5N:64@>FQY
M:&%L;RXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B4W!O:F5N:64@>FQY:&%L;SH@
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(DNU^N@@8F]L('IA;6EE=&YU=/T@<V5R=F5R;VT@=F5R96IN_6-H(&NU
M^NAO=BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B2[7ZZ"!B
M;VP@>F%M:65T;G5T_2!S97)V97)O;2!V97)E:F[]8V@@:[7ZZ&]V+B!$]'9O
M9#H@)7,@*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C4*;7-G:60@(D-O
M;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E-P;VIE
M;FEE(',@1E10('-E<G9E<F]M('IL>6AA;&\N(@H*(SH@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(DMO;G1A
M:W1Y(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM
M<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1Y(&)O;&D@^G-P9;EN
M92!V;&^^96[A(&1O(%;AN6AO(&%D<F5SX7)A+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@
M8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B5'EP(&MO;7!R:6UO=F%NZ6AO
M('/Z8F]R=3HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU
M-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B3V)S86@@7"(E<UPB(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")0
M;VMR8>AO=F&[(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VMO
M=F4@;W-T<F]V>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I
M9"`B0V]O:VEE(@IM<V=S='(@(D-O;VMI92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P
M>2(*;7-G<W1R(")+;W#M<F]V8;LB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<R
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R
M(")+;W#M<F]V86YI92!Z;'EH86QO.B`E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T
M:6]N(@IM<V=S='(@(DMO<.UR;W9ANR!V_6)E<B(*"B,Z(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HQ-S`@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y
M-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A
M(@IM<V=S='(@(DMO<W1A<FEK82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS
M9W-T<B`B4&]B<F6^:64@<VQO;F]V:6YY(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G93H@(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>F&Y:69R;W9ANR!S<'+A
M=G4@<&]M;V-O=2!01U`Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!P;V1P[7-ANR!S<'+A=G4@<&]M;V-O=2!0
M1U`Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED
M(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!Z8;EI9G)O=F&[('-P<N%V=2!P;VUO8V]U(%,O34E-
M12XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@<&]D<.US8;L@<W!RX79U('!O;6]C;W4@4R]-24U%+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R
M(").97!O9&%R:6QO('-A('!R:61ANR!K;VYT86MT+B`E<RXB"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K($Q$05`@<V5R=F5R
M=2XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L
M9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(").97!O9&%R:6QO
M('-A('!R:7!O:FF[(&L@3$1!4"!S97)V97)U(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O=F5R
M:;L@>F]S=&%T;VL@;F$@^NAT92X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E
M<G9E<B(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K($Q$
M05`@<V5R=F5R=2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@
M7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P
M<FEP;VIINR!K('-E<G9E<G4@7"(E<UPB('!O;6]C;W4@1E10.B`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!Z;WIN86T@
M<'+M:F5M8V]V+B`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q
M,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!D9;EI9G)O=F&[(%!'4"#Z9&%J93H@(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(").97!O9&%R:6QO('-A
M(&1EN6EF<F]V8;L@4R]-24U%(/ID86IE+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(").97!O9&%R:6QO
M('-A('9Y;6%Z8;L@:V]N=&%K="X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@=GEM87IANR!Z;WIN86T@<'+M:F5M8V]V+B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E
M<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@<VMR:7!T(&YA
M('5P9W)A9&4@:V]N9FEG=7+A8VEE(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY
M-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5RZ&F[
M(&4M;6%I;&]V^B!A9')E<W4@<'+M:F5M8W4N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S
M82!S=&EA:&YUNR!C96S](&%D<F5SX7(N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").97!O9&%R:6QO
M('-A('KM<VMANR!K;VUP;&5T;OT@>F]Z;F%M('!R[6IE;6-O=BXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANR!K;VUP;&5T
M;OT@>F]Z;F%M('IO>FYA;6]V('!R[6IE;6-O=BXB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@;F'H[71ANR!S=')A=.EG:74@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-P
M=7-T:;L@;6MD:7(@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z[7-K
M8;L@=F5R96IN_2!KM?KH('IO('-E<G9E<F$@:[7ZZ&]V+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R
M('=R:71I;F<N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V;W)INR!<(B5S
M7"(@<')E('KA<&ES+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-S<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*
M(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!O='9O<FF[("5S+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@;W1V;W)INR!M;V1U;"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O='9O<FF[(&%D<F5S
MX7(@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV
M-38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@
M;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!P<FEP;VIINR!N82!,1$%0('-E<G9E<BXB"@HC.B!L:6(O5D93+T]B
M:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M96%D("5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R9>CM=&&[("5S+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M3F5P;V1A<FEL;R!S82!O8FYO=FF[(&AE<VQO('IA9&%NZ6AO('!O=;[M=F%T
M9;5A+B!.:65K=&]RZ2!A;&5B;R!VN65T:WD@(@HB<&]D<F]B;F]S=&D@;FEE
M('/Z('-P<N%V;F4N(%-K^G-T92!T;R!Z;F]V=2!A;&5B;R!K;VYT86MT=6IT
M92!6X;EH;R`B"B)A9&UI;FES='+A=&]R82P@86L@<&]T<F5B=6IE=&4@<&]M
M;V,N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.2!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X,PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S
M='(@(DYE;6^^;F\@>NUS:V&[($%#3"(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!Z[7-K8;L@861R97/A<BX@)7,B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!Z[7-K8;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>NUS:V&[('IO
M>FYA;7D@<'+M:F5M8V]V("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$Y"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B
M"FUS9W-T<B`B3F5M;[YN;R!Z[7-K8;L@:6YF;W)MX6-I92!O('9L87-T;F]S
M=&EA8V@@<V5R=F5R82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*
M;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!V<N%T:;L@:V]N9FEG=7+A8VEU+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N
M(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<W!U<W1INR!R;61I<B!<(B5S7"(N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!U;&^^:;L@:V]N9FEG=7+A8VEU("5S+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5L;[YINR!ZX6QO
M:'4@:V]N9FEG=7+A8VEE+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=6QO
MOFF[('KA;&]H=2!K;VYF:6=U<N%C:64Z("5S(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!U;&^^:;L@<VMR:7!T(&YA('5P9W)A9&4@;F%S
M=&%V96[M(&1O.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I92`E<RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DYE<&]D87)I;&\@<V$@
M>F%P[7-ANR!K;VYF:6=U<F'H;OT@<_IB;W(@)7,N($WTOF5T92!P;W6^:;L@
M;FEE:W1O<OH@>B`B"B)M;[YN;W-T[2!N82!ZX7!I<R!K\V1U(&YA("5S(&%L
M96)O('-K;W#M<F]V8;L@<G7H;F4@:_-D('5V961E;OT@;FF^N6EE(&1O("5S
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U
M;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@:+5A9&&[(&YA($Q$05`@<V5R=F5R:2XB"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%PB)7-<(BXB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@:V]N=&%K="X@)7,B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('IO>FYA
M;2!P<NUJ96UC;W8N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M>F%P[7-ANR!K;VYF:6=U<N%C:74@<')E(%PB)7-<(CH@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+B(*;7-G<W1R(").96UOOFYO(&[A:G.[($)OZ&[]('!A;F5L($UO>FEL
M;'DN(%-K;VYT<F]L=6IT92P@OF4@:F4@<&%N96P@;W1V;W)E;OTN(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F
M;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@HB4&]UONUV871EM6]V:2!<(B5S7"(@<V$@;F5P;V1A<FEL;R!P
M<FED8;L@<'+A=F$@<')E('!R:67H:6YO:R!<(B5S7"(Z("5S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T,C,*;7-G:60@(D-O=6YT960@=&5X="(*;7-G
M<W1R(")0;^CM=&%N_2!T97AT(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B2W)A:FEN82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S97,B
M"FUS9W-T<B`B2W5R>GDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G
M<W1R(")6>71V;W)INR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*
M;7-G<W1R(")6>71V;W)INR!L:6YK=2(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B
M"FUS9W-T<B`B5GET=F]R:;L@;F]V_2(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM
M<V=S='(@(E9Y='9O<FF[('!O9'!R:67H:6YO:R(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E!RX79A('1V;W)C=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,C$Y"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BR.US;&\@
M:W)E9&ET;F5J(&MA<G1Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0VAO
M<G;A='-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G
M<W1R(")!:W1UX6QN92`T(&;A>GDB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B06MT=>%L;F4@
M<V5D96YI82(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D%K='7A
M;&YY(.AA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T
M<B`B06MT=>%L;F$@55),(&IE(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U
M"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(D%K='7A;&YI('!O=;[M
M=F%T96QI82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U
M<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")!:W1UX6QN92!P;^AA<VEE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N
M="!C;VYD:71I;VXZ("(*;7-G<W1R(")!:W1UX6QN92!P;V1M:65N:WDZ("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*
M;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B06MT=>%L;GD@N73];"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+B(*;7-G<W1R(").87-T879E;FEE(/IL;V@L(&MT;W+I('-A('-P^KF[86KZ
M('!R:2!P<FEH;.%S96[M(&1O(&%P;&EKX6-I92`E<RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G
M:60@(D-U="(*;7-G<W1R(")6>7-T<FEH;OJ[(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C
M=&EO;B(*;7-G<W1R(")6>7-T<FEH;OJ[(';]8F5R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(D-Y<')U<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*
M;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("+(97-KX2!R97!U8FQI
M:V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$
M1"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<P"FUS9VED("(B"B)$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(D133B`H<&]Z
M<FD@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*"B,Z(&QI8B](;W)D92]-86EN=&5N
M86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1E;FYE(@H*(SH@
M861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R
M(@IM<V=S='(@(E!R97IE<F'H(&3A=&]VZ6AO('-T<F]M=2`H1&%T851R964I
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-C@*;7-G:60@(D1A=&%B87-E
M($QO;VMU<"(*;7-G<W1R(")6>6BU863A=F%N:64@=B!D871A8N%Z92(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D3A='5M(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1.%T=6T@<')I:F%T:6$B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B1&%T92!S96QE8W1I;VXB
M"FUS9W-T<B`B5OUB97(@9.%T=6UU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q
M"FUS9VED(")$87DB"FUS9W-T<B`B1&7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L
M971E($-O;'5M;B(*;7-G<W1R(")/7V1S='+A;FF[('-TY7!E8R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*
M;7-G<W1R(")$96-E;6)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M
M8F5R<R(*;7-G<W1R(")$97-I871K;W;I(.CM<VQA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A
M<V4@26YD96YT(@IM<V=S='(@(EIM96ZY:;L@;V1S861E;FEE(@H*(SH@;&EB
M+W!R969S+G!H<#HQ,3<@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.#<*;7-G
M:60@(D1E9F%U;'0B"FUS9W-T<B`B4')E9&YA<W1A=F5NZ2(*"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$
M969A=6QT($-O;&]R(@IM<V=S='(@(E!R961N87-T879E;N$@9F%R8F$B"@HC
M.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED
M96YT:71Y(@IM<V=S='(@(E9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET82(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3
M:&5L;"(*;7-G<W1R(")0<F5D;F%S=&%V96[]('!R[6MA>F]V_2!I;G1E<G!R
M971E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F
M:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6[M8VEE(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,2!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C0R,@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0S.2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(E9Y;6%Z8;LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(E9Y;6%Z8;L@8G5N:W4B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R
M-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E9Y;6%Z8;L@<VMU<&EN
M=2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B
M1&5L971E($QO9R(*;7-G<W1R(")6>6UA>F&[('KA>FYA;2(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(E9Y;6%Z8;L@
M<'+A=F\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*
M;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B5GEM
M87IANR!A(&]D<W1RX6YINR!S<'+A=GDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@
M8V5L;"(*;7-G<W1R(")6>6UA>F&[(&)U;FMU(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L
M971E(&-O;'5M;B(*;7-G<W1R(")6>6UA>F&[('-TY7!E8R(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(E9Y;6%Z8;L@97AI<W1U:OIC=2!A
M;'1E<FYA=.UV;G4@N6%B;/-N=2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(E9Y;6%Z8;L@<'+A=F$@<')E(%PB)7-<
M(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")#:&-E=&4@=GEM87IANR!<
M(B5S7"(@82!VN65T:WD@:F5H;R!P;V1P<N%V83\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$
M96QE=&4@<F]W(@IM<V=S='(@(E9Y;6%Z8;L@<FEA9&]K(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E9Y;6%Z8;L@=GEB<F%N^B!I
M9&5N=&ET=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;B(*;7-G<W1R(")6>6UA>F&[(&%K='7A;&YY('-TY7!E8R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")6>6UA
M>F&[(&%K='7A;&YY(')I861O:R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")3:W)I<'0@;F$@=7!G<F%D
M92!K;VYF:6=U<N%C:64@7"(E<UPB(&)O;"!V>6UA>F%N_2XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BR&%S(&1O<G7H
M96YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1.%N<VMO(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E
M('1H92!0<F]B;&5M(@IM<V=S='(@(E!O<.VY=&4@<')O8FSI;2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4&]P:7,B"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")0;V1R
M;V)N;W-T:2`H=&EEOB!V(&QO9V]V86-O;2!S^F)O<F4@2&]R9&4I(@H*(SH@
M;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%I;'D@
M8F]L:2!Z87IN86UE;F%NZ2!P<F4@861M:6YI<W1RX71O<F$N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B
M"FUS9W-T<B`B5OUV;VHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM
M<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(E)O<V[](&)O9"(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@(@IM<V=S='(@(E)O<V[](&)O9"!Z82!P;W-L961N^B!H;V1I;G4Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@
M(D1E=R!P;VEN=#H@(@IM<V=S='(@(E)O<V[](&)O9#H@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B4VUE<B!ZM6%V82!D;W!R
M879A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B
M4VUE<B!S<')A=F$@9&^U879A(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")!9')E<^%R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R
M('1I;65S/R(*;7-G<W1R("):;V)R87IO=F&[(.AA<R!V(#(T+6AO9&EN;W9O
M;2!F;W)MX71E/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(").87-T879E;FEE('IO8G)A
M>F5N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G
M:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B6F]B<F%Z
M:;L@<&]D<F]B;OH@<')E9'!O=F7O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("):
M;V)R87IINR!P<F5D<&]V9>\@*%1!1BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@P-@IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B1F]R;>%T
M('IO8G)A>F5N:6$B"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,`IM
M<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(E!O='9R
M9&5N:64@;R!D;W)UZ&5N[2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D2^
M:6)U='-K;R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"FUS9VED
M(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYE=GEM87IANR(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3F5P;W6^[79A:G1E
M('!R:6%M;R!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM
M<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")/8G-A:'5J
M92!P<G;](')I861O:R!NX7IV>2!P;VSM/R!!:R#A;F\L('IAN6MR=&YI=&4@
M<&]L[>AK;SH@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:^%N
M<VMA(')E<'5B;&EK82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS
M9W-T<B`B3F5MX71E(/KH970_(%IA<F5G:7-T<G5J=&4@<V$N(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,0IM<V=I9"`B1&]W;FQO860B
M"FUS9W-T<B`B4W1I86AN=;LB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#4Q"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM
M<V=S='(@(E-T:6%H;G6[("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="XB"FUS9W-T<B`B4W1I86AN=;L@=GEG96YE<F]V86[Z
M(&MO;F9I9W5RX6-I=2!A:V\@4$A0('-K<FEP="XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$Q,0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B
M6F]Z;F%M(',@=OUB97)O;2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9WDB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+6UA
M:6PB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED
M(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W
M:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS
M9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R
M(")%:W;A9&]R(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C4@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P
M;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B57!R879I
MNR(*"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O
M<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")5
M<')A=FF[(&)L;VLB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G
M<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")5<')A
M=FF[('-K=7!I;G4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<V(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B57!R879INR!P<N%V;R(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B57!R879INR!P<N%V82(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B57!R879INR!P<N%V82!P<F4@)7,B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R
M.B(*;7-G<W1R(")5<')A=FF[(&YA<W1A=F5N:6$@<')E.B(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")5<')A=FF[('!R
MX79A('!R92!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(E5P<F%V:;L@<'+A=F$@<')E("5S(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B
M5GID96SA=F%N:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%9WEP="(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B4V%L=N%D;W(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE;65N="XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R(")%;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%
M;6%I;"(*;7-G<W1R(")%;6%I;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B
M16UA:6P@061D<F5S<R(*;7-G<W1R(")%;6%I;&]VX2!A9')E<V$Z(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%+6UA:6QO=ND@861R97-Y(&UU<VEA
M(&)YNR!R;W9N86OI+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DS"FUS
M9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%+6UA:6P@
M<R!P;W1V<F1E;NUM(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H
M<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B0G+A
M;F$@16UA:6PM;F$M4TU3(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(Y-PIM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(D5M;W1I
M:V]N>2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R
M"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")0<N%Z9&YA('-P<N%V
M82XB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C8V,B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*
M;7-G<W1R(")0<N%Z9&YY(';]<VQE9&]K+B(*"B,Z(&QI8B](;W)D92]344PO
M2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E!RX7ID;F4@<&]D;6EE;FMY(&BU861A;FEA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O
M9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T
M<B`B4&]V;VQINR!V;&^^96YI92!O8G+A>FMO=B!Z($=A;.ER:>T@9&\@=&5X
M='4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B4&]V;VQI
MNR!K;VYT97AT;W;I(&UE;G4@<')E('!R87;I('1L8>AI9&QO/R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3DR(&QI8B](;W)D92]&;W)M+G!H<#HR.#`P
M"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")+;VYI96,@<F]K82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@
M(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(EIVY.BY:;L@961I=&]R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S
M96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y
M;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(EIA9&%J
M=&4@8F5Z<&7H;F]S=&[Z(&]TX7IK=2P@;F$@:W1O<OH@8G5D971E(&UU<VEE
MNR!O9'!O=F5D8;L@86L@>F%B=61N971E("(*(FAE<VQO+"!N87!R+B`G86MO
M('-A('9O;.$@;6]J92!Z=FEE<F%T:V\_)SHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@
M(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("):861A:G1E(%52
M3"!O8G+A>FMA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@X.0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S
M='(@(EIA9&%J=&4@<.US;65NX2!U=F5D96[I(&YIOKEI93HB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%
M<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")2;W9N[6MO=N$@1W5I;F5A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5A(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT."!L:6(O0FQO8VLO;65T87(N<&AP
M.C,V"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R
M<F]R(@IM<V=S='(@(D-H>6)A(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H
M<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO
M8VLZ("5S(@IM<V=S='(@(D-H>6)A('!R:2!V>71VX7)A;NT@8FQO:W4Z("5S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM
M<V=S='(@(D-H>6)A('!R:2!V>6UA>N%V86[M('5K;W1V96YI82!S>6YC:')O
M;FEZX6-I93H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO
M9SH@)7,B"FUS9W-T<B`B0VAY8F$@<')I('9Y;6%ZX79A;NT@>N%Z;F%M=2!S
M>6YC:')O;FEZX6-I93H@)7,B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP
M.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E
M;G0Z("5S(@IM<V=S='(@(D-H>6)A('!R:2!Z[7-K879A;NT@;V)S86AU.B`E
M<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS
M9W-T<B`B0VAY8F$@<')I(&%K='5A;&EZX6-I:2!H97-L83H@)7,B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R
M;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")#:'EB82!V(&4M;6%I
M;&]V96H@<W!RX79E+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B0VAY8F$@<')I('IA<&ES
M;W9A;NT@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T\VYS
M:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&GS<&EA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B
M171N:6-KZ2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")%=7)O<&4B"FUS9W-T<B`B175R\W!A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")+
M8;YD_6-H(#$U(&UI;OIT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(DMAOF3I(#(@;6EN
M^G1Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(DMAOF3]8V@@,S`@<V5K^FYD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R
M>2`U(&UI;G5T97,B"FUS9W-T<B`B2V&^9/UC:"`U(&UI;OIT(@H*(SH@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB
M"FUS9W-T<B`B4')I(&MAOF1O;2!P<FEH;.%S96[M(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S
M='(@(DMAOF3Z('!O;&AO9&EN=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@
M;6EN=71E(@IM<V=S='(@(DMAOF3Z(&UI;OIT=2(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS
M9W-T<B`B3F%P<NUK;&%D.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM
M<V=I9"`B17AE8W5T92(*;7-G<W1R(")3<'5S=&F[(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B
M4F]Z8F%L:;LB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R
M"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")2;WIB86QINR!";^AN
M_2!P86YE;"(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM
M<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(D_H86OA=F$@<V$@)RDG(@H*
M(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(D_H86OA=F$@<V$@<VQO=F\@86QE8F\@<&]D;6EE;FMA(&BU861A;FEA('8@
M^G9O9'IO=FOA8V@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*
M;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")$X71U;2!E>'!I<N%C
M:64B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B
M17AP;VYE;G0B"FUS9W-T<B`B17AP;VYE;G0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#
M;VQO<B(*;7-G<W1R(")&87)B82!T97AT=2(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T
M<B`B3F%H<F&[(&MO;F9I9W5RX6-I=2!N82!&5%`B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANR!N87-T
M879E;FEA+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW-2!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I
M('-P;VIE;NT@<R!,1$%0('-E<G9E<F]M+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S
M97)V97(N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('!R[7-T=7!E(&L@
M4TU"('-E<G9E<G4N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<P-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!K;W#M<F]V8;L@>B!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C<Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M:V]P[7)O=F&[(&1O(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L
M+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O<FF[(&YO=ND@
M4T%33"!S<&]J96YI92XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3`Q(&QI8B]6
M1E,O9G1P+G!H<#HW-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R97-U
M;OJ[(&1O(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#8U"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!Z[7-K8;LZ("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T
M<B`B1&]B<NDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M"FUS9W-T<B`B1F%L:VQA;F1S:^D@;W-T<F]V>2`H36%L=NUN>2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9A97)S:^D@;W-T<F]V>2(*"B,Z
M(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM
M<V=S='(@(EKA=F&^;N$@8VAY8F$Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*
M;7-G<W1R(")&87AY(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)UX7(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R
M(")0;V-I="!T97!L;W1Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E!O8VET('1E
M<&QO='DZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")-86SI('IRX;YK
M>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P
M"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(DUA;.D@<VYE:&]V
MZ2!P<F5HX6YK>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30X"FUS9VED
M(")&:65L9"!M871R:7@B"FUS9W-T<B`B36%T:6-A('!O;.TB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S,R,PIM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C<*;7-G:60@(D9I
M9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FED
MOFDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@
M(D9I;&4B"FUS9W-T<B`B4_IB;W(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(E!O
MZ&5T('/Z8F]R;W8Z("5S('/Z8F]R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B
M4&_H970@<_IB;W)O=CH@)7,@<_IB;W)O=B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")3
M<'+A=F-A('/Z8F]R;W8B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.
M86UE(@IM<V=S='(@(DUE;F\@<_IB;W)U(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Y.#0*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E;]8F5R
M('/Z8F]R=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#DP"FUS9VED(")&
M:6QE('5P;&]A9"(*;7-G<W1R(").86AR871I92!S^F)O<G4B"@HC.B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.#@U"FUS9VED(")&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B3F%H<N%V86YI92!S^F)O<F]V(&YI92!J
M92!P;V1P;W)O=F%NZ2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN
M;&%N9"(*;7-G<W1R(")&[6YS:V\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(E!R=N$@<&]L;W9I8V$B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(E!R=N$@N71V<KLB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4U"FUS
M9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B4&5V;OT@<&]M97(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,P"FUS9VED(")&;&EP
M(@IM<V=S='(@(D]T;^AINR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@
M(E!LX79A:OIC:2!T97AT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")(;6QA(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C(S-R!L:6(O5D93+VUU<W%L+G!H<#HQ,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM
M<V=S='(@(E!R:67H:6YO:R`E<R!N965X:7-T=6IE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#
M;VQO<B(*;7-G<W1R(")&87)B82!P[7-M82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")0;W1R879A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T
M(&EM86=E<R(*;7-G<W1R(")0<F4@<')E:&QI861AZ&4L(&MT;W+I(&YE<&]D
M<&]R=6KZ(&]B<N%Z:WDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM
M<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')E9'!O=F7O("A4048I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B
M"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S
M='(@(B(*(E!R961P;W9E[R!N82!U=F5D96[]('!OZ&5T(&1N[2`H<&%MY'1A
M:G1E(&YA('1O+""^92!P<F5D<&]V9>\@:F4@<')E(&1N:2!A:B`B"B)N;V-I
M(&$@=&%K(&WTOF4@=F6U:^D@Z.US;&\@=GET=F]R:;L@=F6U;6D@N6ER;VO]
M(&)L;VLI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G
M:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("):86)U9&QI('-T
M92!H97-L;S\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS
M9VED(")&;W)M<R(*;7-G<W1R(")&;W)M=6SA<F4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1F]R='5N
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N
M92!T>7!E(@IM<V=S='(@(E1Y<"!F;W)T=6YY(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")&;W)T=6YY
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE
M<R`R(@IM<V=S='(@(D9O<G1U;GD@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&\W)A(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B
M"FUS9W-T<B`B4')E<VUE<F]V86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E!I
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")2X6UC92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9R86YC92(*;7-G<W1R(")&<F%N8_IZ<VMO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM
M<V=S='(@(D9R86YC^GIS:V\@*$5U<O-P82DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I
M86YA(@IM<V=S='(@(D9R86YC^GIS:V$@1W5A>6%N82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N
M8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R86YC^GIS:V$@4&]L>6[I>FEA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B
M1G)A;F/Z>G-K92!J=;YNZ2!T97)I=/-R:>$B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")/
M9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B6F\@
M<VUE<G4@(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*
M;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BVG!L;OT@<&]P:7,B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(E-P;&XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(D-E;.D@;65N
M;SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)U;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM
M<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L
MZ7)I82P@>B!K=&]R96H@8VAC971E('9Z:6&[(&]B<N%Z;VLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;.ER:6$Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<F]V8;L@:V]N9FEG=7+A8VEU('!R
M92!A<&QI:^%C:74@)7,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N
M9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N
M97)O=F%N_2!K\V0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")'97)M86YY(@IM<V=S='(@(DYE;65C:V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N
M82(*;7-G<W1R(")':&%N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")'
M:6)R86QTX7(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@IM
M<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")+<G-T;ND@;65N;R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R(")/
M9&]S;&&[(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")'
M;V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S
M='(@(D=O;V=L92!-87!S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT
M,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")(M6%D8;L@;F$@1V]O
M9VQE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S
M-@IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(D]D=&EE;F4@N65D96HB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1W)E96-E(@IM<V=S='(@(D=RZ6-K;R(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R\VYS:V\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")'<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M061M:6YI<W1RX6-I82!S:W5P[6XB"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP
M.C4Y(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(DUE;N$@<VMU<.UN
M(&YE<VWZ(&)YNR!P<N%Z9&YE(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B1W)O=7!?;&1A<#H@3F5P;V1A<FEL;R!S82!P<FED
M8;L@<VMU<&EN=2`E<RX@4V5R=F5R(&]D<&]V961A;#H@(@H*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!N97!O9&%R:6QO('-A('9Y
M;6%Z8;L@<VMU<&EN=2`E<R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HS,S@@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P
M("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z(&YE<&]D87)I;&\@<V$@86MT=6%L
M:7IO=F&[('-K=7!I;G4@)7,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(E-K=7!I
M;GDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*
M;7-G<W1R(")'=6%T96UA;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4'+A
M=F$@86YO;GEM;OUC:"!P;W6^[79A=&6U;W8B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B1W5E
M<W1B;V]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN96$M0FES<V%U(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(&YE9&]V;VSM
M('9Y;6%Z8;L@<&]S;&5D;OH@8G5N:W4@=B!R:6%D:W4N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N961O=F]L
M[2!V>6UA>F&[('!O<VQE9&[]('-TY7!E8R!V('1A8G6U:V4N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N961O=F]L
M[2!V>6UA>F&[('!O<VQE9&[](')I861O:R!V('1A8G6U:V4N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B2%144"!A=71E;G1I9FEKX6-I
M82!N96)O;&$@;N%J9&5NX2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA
M:71I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(
M87-H+4%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;75S(&AA<VAO=F%C96H@
M9G5N:V-I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(D]P87(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.3(S(&QI8B](;W)D92]&;W)M+G!H<#HR.3(Q"FUS9VED
M(")(96%D97(B"FUS9W-T<B`B2&QA=FGH:V$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M(")(;&%V:>AK>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D;W8@;W-T<F]V(&$@36-$;VYA;&1O
M=F4@;W-T<F]V>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(E-I;&[A
M(&+Z<FMA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(DAE
M8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(
M96EG:'0B"FUS9W-T<B`B5OVY:V$B"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z
M,3@T(&QI8B](;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@
M(DAE;'`B"FUS9W-T<B`B4&]M;V-N[6LB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D
M:71O<B(*;7-G<W1R(")0;VUO8V[M:R!P<F4@<&]UONUV86YI92!E9&ET;W)A
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S4*;7-G:60@(DAE;'!E<B(*
M;7-G<W1R(")0;VUO8V[M:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM
M<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")0;VQO9W6U82(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE
M(&9I;&4Z(@IM<V=S='(@(E1U(&IE('IAZ&EA=&]K('/Z8F]R=3HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B
M2&EG:"(*;7-G<W1R(")6>7-O:^$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*
M;7-G:60@(DAO7VUE(@IM<V=S='(@(D1O7VUO=B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@
M4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(E9A=&EKX6XB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$U,SD*;7-G:60@(DAO;64B"FUS9W-T<B`B1&]M
M;W8B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M
M92!!9&1R97-S(@IM<V=S='(@(D1O;>%C82!A9')E<V$B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S
M='(@(D1O;>%C:2!P<FEEZ&EN;VLB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")4
M96QE9O-N(&1O;6]V(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD
M=7)A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!V('-P<N%V92`E<R!B;VQI(&[A:F1E;ND@;F5P;&%T;ND@
M)7,@6$U,(/ID86IE(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R
M<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!S
M(&]B:F5K=&]M("5S(&YE:V]R9;EP;VYD=6IE(+YI861N82!S<'+A=F$N(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z('8@<W!RX79E("5S
M(&YE8F]L(&[A:F1E;OT@OFEA9&5N(&]B:F5K="!T>7!U("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,C0V"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(/IS<&6Y;F4@;V1S='+A;F5NZ2`E<R!<(B5S
M7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O
M2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D
M;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&EN
M=&5G<N%C:6$@=GF^861U:F4@4$A0(')O>KGM<F5N:64@)V1O;7AM;"<B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P;V1A<FEL
M;R!S82!V>71V;W)INR!N;W;](%A-3"!S=')O;2!P<F4@;V)J96MT("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@;V1S='+A
M;FF[("5S(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0W
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@>NUS:V&[($U)344@
M240@<')E(.AA<[L@='EP=2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M,3$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z(&YE<&]D87)I;&\@<V$@<WEN8VAR;VYI>F]V8;L@)7,@7"(E<UPB
M.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@
M<V$@<WEN8VAR;VYI>F]V8;L@>F1I9;5A;ND@;V)J96MT>3H@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(&YE>F[A;7D@>F1I9;5A;OT@;V)J96MT(%PB)7-<(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G
M:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")(;W)I>F]N=.%L;F$@Z&EA
M<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B2&]R:7IO
M;G3A;&YE('9Y<&QN96YI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@
M(DAO<FEZ;VYTX6QN93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E
M="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(D%K;R!S=&4@<V$@
M<V5M(&1O<W1A;&D_("A0<F]S[6T@;F%H;.%S=&4A*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@
M(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(DMOM6MO('-TY7!C;W8@8VAC971E('IL^NAINS\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE
M;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(EIA9&%J=&4@<&_H
M970@<&]L[2`H<W3E<&-O=BD_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2V^U:V\@<FEA
M9&MO=B!C:&-E=&4@>FSZZ&F[/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU
M;6ED:71Y(@IM<V=S='(@(E9L:&MO<[LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(E9L
M:&MO<[LZ("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B
M2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T:2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R
M>2(*;7-G<W1R(")-8>]A<G-K;R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ-S(@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!)34%0('-C:'+A
M;FMU.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB
M+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!V>6UA>F&[($E-05`@<V-H<N%N:W4Z("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C
M>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(").97!O9&%R
M:6QO('-A('9Y='9O<FF[($E-05`@:W;S='4Z("5S(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@
M861R97-A(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G
M:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@861R
M97-A(&YI92!J92!D;W-T=7!NX2XB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A
M<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@861R97-A(&YI92!J92!V('+A
M;6-I(&1O=F]L96[I:&\@0TE$4B!B;&]K=2XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+B(*;7-G<W1R(")0;W)UN65N:64@<')A=FED;&$@;R!P979N96H@
M25`@861R97-E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E
M(@IM<V=S='(@(E9L;[YINR!KM?KH(%]P<F5D(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD
M(@IM<V=S='(@(DES;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B26)A(&EK;VYY(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N>2!P<F4@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B
M"FUS9W-T<B`B26MO;GD@82!T97AT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(").X7IO
M=B!I9&5N=&ET>3HB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M-3DY"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y
M960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB
M"FUS9W-T<B`B06L@<V$@;F5Z;V)R87KM(&MO<F5K=&YE+"`E<R!A(&]T=F]R
M[2!S82!V(&YO=F]M(&]K;F4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B
M"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G
M<W1R("(B"B)!:R!N979I9.UT92!P<FD@<&]UOFET[2!);G1E<FYE="!%>'!L
M;W)E<F$@OFEA9&YE(&EK;VYY+"!P;W1R96)U:F5T92`B"B)Z8;EK<G1N^KL@
M=/IT;R!V;[5B=2!P<F4@=GEP;G5T:64@<')I97-V:71N;W-T:2!03D<@;V)R
MX7IK;W8N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO
M(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E
M("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(D%K
M('9I9.UT92!T^G1O('-P<N%V=2!A(&YE=FED[71E(&]B<N%Z;VLL(&]B<N%Z
M;VLL(&MT;W+]('-T92!C:&-E;&D@;F%H<F&[+"`B"B)N96WTOF4@8GF[('IO
M8G)A>F5N_2!V;R!68;EO;2!P<F5H;&EA9&'H:2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E5KX;YK82!O8G+A>FMA.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")54DP@;V)RX7IK82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@;V)R
MX7IK83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*
M;7-G<W1R(")/8G+A>F]K('H@9V%LZ7)I92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B
M26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")/8G+A>F]K('H@9V%LZ7)I
M93HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-0IM<V=I9"`B26UA9V4@
M=7!L;V%D(@IM<V=S='(@(DYA:')A=&EE(&]B<N%Z:W4B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D]B<N%Z
M:WDB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G0L
M(&MR;VL@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T
M<B`B26UP;W)T;W9A;ND@<&]L93H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@
M(DEM<&]R=&]V86[I('!O;&EA.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B5FQOOFF[(&NU^N@@7WIA(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D)O;"!Z861A;OT@;F5S<'+A=FYY
M(&OS9"!A:V-I92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+B(*;7-G<W1R(").97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&$O
M86QE8F\@:&5S;&\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU
M,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).
M97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&%L96)O(&%L=&5R;F%T[79N
M82!A9')E<V$N(%-K^G-T92!T;R!Z;F]V=2`B"B)A;&5B;R!K;VYT86MT=6IT
M92!S<'+A=F-U(%;AN6AO('-Y<W3I;74L(&%K('!O=')E8G5J971E('!O;6]C
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("):=N3HN6F[(&]D
M<V%D96YI92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:6$B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")*
M961N;W1L:7;M('!O=;[M=F%T96QI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM
M<V=S='(@(DEN9&]NZ7II82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO
M;B(*;7-G<W1R("));F9O<FWA8VEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V
M86EL86)L92XB"FUS9W-T<B`B26YF;W)MX6-I92!UOB!N:64@<_H@9&]S='5P
M;NDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R(")6;&^^:;L@7W-TY7!E8R!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS
M97)T($EM86=E(@IM<V=S='(@(E9L;[YINR!O8G+A>F]K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS
M97)T(%1A8FQE(@IM<V=S='(@(E9L;[YINR!T86)UM6MU(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS
M97)T(%=E8B!,:6YK(@IM<V=S='(@(E9L;[YINR!L:6YK=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM
M<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E9L;[YINR!?
M<W3E<&5C('!R960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YINR!N;W;]
M('-TY7!E8R!Z82!A:W1UX6QN>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E9L
M;[YINR!N;W;]('-TY7!E8R!P<F5D(&%K='7A;&YY(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R(")6;&^^:;L@;F]V_2!R:6%D;VL@>F$@86MT=>%L;GDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R(")6;&^^:;L@;F]V_2!R:6%D;VL@<')E9"!A:W1UX6QN>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B5FQOOFF[(&]D<W1A=F5C('IA(&%K='7A
M;&YY(&)O9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(E9L;[YINR!O9'-T879E
M8R!P<F5D(&%K='7A;&YY(&)O9"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(E9L;[YINR!A;'1E<FYA=.UV;G4@N6%B;/-N=2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*
M;7-G<W1R("):861A:G1E(&4M;6%I;&]V^B!A9')E<W4L(&YA(&MT;W+Z(&1O
M<W1A;F5T92!N;W;I(&AE<VQO.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL
M(&%F=&5R(@IM<V=S='(@(E9L;[YINR!B=6YK=2!Z82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@
M(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R(")6;&^^:;L@8G5N:W4@<')E
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B
M5FQOOFF[('-TY7!E8R!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@
M8F5F;W)E(@IM<V=S='(@(E9L;[YINR!S=.5P96,@<')E9"(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE
M<W-A9V5S(@IM<V=S='(@(E9L;[YT92!S<'+A=GDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@
M(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B5FQOOFF[(&]D<W1A
M=F5C('IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R
M92(*;7-G<W1R(")6;&^^:;L@;V1S=&%V96,@<')E9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@
M(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B5FQOOFF[(')I861O:R!Z82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(E9L;[YI
MNR!R:6%D;VL@<')E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*
M;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B6F%D86IT92!P;[YA9&]V86[Z(&]D
M<&]V9>\@;F$@8F5Z<&7H;F]S=&[Z(&]TX7IK=3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O
M36]D:69Y($EM86=E(@IM<V=S='(@(E9L;[YINR]U<')A=FF[(&]B<N%Z;VLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y
M"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B5FQOOFF[+W5P
M<F%V:;L@;&EN:W4B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").82!O9&]S:65L86YI
M92!P<F4@>F]Z;F%M('!R[6IE;6-O=B!N96WA=&4@9&]S=&%T;^AN_2!K<F5D
M:70N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B3F5D;W-T871O
MZ&[](&MR961I="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W.0IM<V=I
M9"`B26YT96=E<B(*;7-G<W1R(")#96SI(.CM<VQO(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q,S<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("):
M;WIN86T@8V5L_6-H(.AI<V5L(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A
M($AE861E<BDN(@IM<V=S='(@(DYE<&QA9&[I(%5$2"`H57-E<B!$871A($AE
M861E<BP@2&QA=FGH:V$@<&]UONUV871EM7-K_6-H(/ID86IO=BDN(@H*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#;VUP
M<F5S<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H
M<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B3F5P;&%T
M;ND@^F1A:F4@9F]R;>%T=2!:25`N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B
M3F5P;&%T;N$@87!L:6OA8VEA+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G
M<W1R(").97!L871NZ2!)1"!DX79K>2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`Y,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$V,B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(S-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,P,R!L:6(O2&]R
M9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D
M871A('-U8FUI='1E9"XB"FUS9W-T<B`B0F]L:2!O9&]S;&%NZ2!N97!L871N
MZ2#Z9&%J92XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G
M<W1R(").97!L871NX2!C:66U;W;A(&%D<F5S82XB"@HC.B!L:6(O2&]R9&4O
M0V]M<')E<W,O9&)X+G!H<#HQ,#D@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z,3,Y"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I
M9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(").97!L871N_2!F;W)M
MX70@<_IB;W)U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3F5P;&%T
M;OT@;&EC96[H;OT@:[7ZZ"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*
M;7-G<W1R(")";VQA('IA9&%NX2!N97!L871NX2!L;VMA;&ET82XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV
M86QI9"!M<V=?='EP92XB"FUS9W-T<B`B3F5P;&%T;N$@:&]D;F]T82!M<V=?
M='EP92XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B
M3F5P;&%T;N$@86QE8F\@8VC]8F%J^F-A(&AO9&YO=&$@87!I7VED+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("))
M;G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B3F5P;&%T
M;ND@86QE8F\@8VC]8F%J^F-E('!A<F%M971R92XB"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(DYE<&QA=&[I(')O9&GH;W9S:^D@<'+A=F\N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV
M86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(").97!L871NZ2!I9"!P87)T;F5R
M82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED
M("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B3F5P;&%T;OT@:_-D
M('!R;V1U:W1U+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(").97!L
M871N_2!P<F]T;VMO;"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN
M=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B3F5P;&%T;OT@<'+M
M:F5M8V$Z(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`W-2!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$R-3@*;7-G:60@(DEN=F%L:60@<VAA<F4@
M;V)J96-T(@IM<V=S='(@(DYE<&QA=&[](&]B:F5K="!Z9&EEM6%N:6$B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B
M26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B3F5P;&%T;N$@>F1R
M;VIO=N$@861R97-A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T
M<B`B3F5P;&%T;ND@^F1A:F4@=6YI8V]D92XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV
M96YTX7(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<U"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DEN=F5R=&]V
M8;L@=OUB97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B27+A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M"FUS9VED("))<F5L86YD(@IM<V=S='(@(LUR<VMO(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B
M27-L92!O9B!-86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B
M3VIE9&EN96SI(&+Z<FMY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27IR
M865L(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@
M(DES<W5E<B(*;7-G<W1R(")6>61A=F%T9;4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G
M<W1R(")+=7)Z[79A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R(")486QI86YS
M:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86IK82(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.3D@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(DIA;G7A<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P;VYS
M:V\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B2F%P86YE
M<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9.%N(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2OIL
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU
M;F4B"FUS9W-T<B`B2OIN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R
M("):87)O=FYANR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G
M<W1R("):87)O=FYANR!D;R!S=')E9'4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF
M>2!&=6QL(@IM<V=S='(@(EIA<F]V;F&[(&1O(&)L;VMU(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("):87)O=FYANR!VM6%V;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(EIA<F]V;F&[('9P
M<F%V;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA8VAS=&%N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V,PIM
M<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B4&]N96-H8;L@;W)I9VEN
MX6P_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+9?)A(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@<V5R
M=F5R('IA;6EE=&]L(&%U=&5N=&EF:6OA8VEU+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B
M2V5R;F5L+6YO=N'H:6MO=FEA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B5GET=F]R96YI
M92!KM?KH82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I
M9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(D1I9VETX6QN>2!O9'1L8>AO
M:R!KM?KH82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I
M9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")$Y;YK82!KM?KH82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T
M<B`B5'EP(&NU^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")0;W6^:71I92!KM?KH82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M(")+M?KH('6^(&5X:7-T=6IE(&YA('-E<G9E<FD@=F5R96IN_6-H(&NU^NAO
M=BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B
M"FUS9W-T<B`B1&5T:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER
M:6)A=&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(J5U9&]V;V1E;6]K<F%T:6-KX2!R97!U8FQI
M:V$@2_-R96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R
M(")+\W)E:G-KX2!R97!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2W5W86ET(@IM<V=S='(@(DMU=F%J="(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A
M;B(*;7-G<W1R(")+:7)G:;ES:V\B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B5GI?:+5A9"(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E
M(@IM<V=S='(@(DIA>GEK(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8R(*;7-G<W1R("),86]S(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E!O<VQE9&[A
M('!O;&]V:6-A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED
M("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")0;W-L961NX2!Z;65N
M82!H97-L82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")0;W-L
M961NX2"Y='9RNR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED
M("),87-T(%5P9&%T960Z(@IM<V=S='(@(E!O<VQE9&[A(&%K='5A;&EZX6-I
M83HB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E!O<VQE9&[I('!R:6AL
MX7-E;FEE.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R
M(")0;W-L961NZ2!P<FEH;.%S96YI93H@)7,@>B`E<R(*"B,Z(&QI8B](;W)D
M92]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S
M='(@(E!O<VQE9&[I('!R:6ALX7-E;FEE.B!N:6MD>2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T
M=FEA(@IM<V=S='(@(DQO='FY<VMO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B4'+A=F\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@
M(DQA>6]U="(*;7-G<W1R(")6>FBU860B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R(@IM<V=S='(@(DYE8VAA:G1E('!RX7ID;F4@<')E(+YI
M861E;B!O:W)A:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(E:U879O(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,#@*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@
M(DAL879IZ&MA(':U879O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#0*
M;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(DAO9&YO='D@=K5A=F\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B
MVG)O=F7R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8NER:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3.UB>6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EC:'1E;KET86IN
M<VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`BI6%H:^D@;7)H;VQE
M;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`BI6%H:_T@9.&^[R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED
M("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(E+A;F\@M6%H:_T@9.&^[R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS
M9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B3F5S:_1R(+5A:&O](&3A
MON\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`BI6%H:^D@9&&^
M[V]VZ2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("*E86AK_2!DX;[O(',@:')M96[M;2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W
M(@IM<V=S='(@(J5A:&OI('-N9;YE;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(J5A:&OI('-N96AO=ND@<')E:.%N:WDB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@
M(DQI;65R:6-K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,3@*;7-G:60@
M(DQI;FLB"FUS9W-T<B`B3&EN:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I
M;G1S('1O.B(*;7-G<W1R("),:6YK82!U:V%Z=6IE(&YA.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S
M='(@(E!R97!O:FF[(&4M;6%I;&]V^B!A9')E<W4@<V\@<W1RX6YK;W4@;F$@
M<.US86YI92!P;[ET>2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL
M,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3&EN:WDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI
M92(*;7-G<W1R("),:6YU>"!#;V]K:64B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<B(*;7-G<W1R("):;WIN86T@+2!P;W6^[79A=&6U('5V:63M
M('!R:67H:6YO:R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@
M(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(E9Y<.US8;L@>F]Z;F%M(&1A=&%B
MX7HB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM<V=I9"`B3&ES
M="!(96QP(%1O<&EC<R(*;7-G<W1R("):;WIN86T@=.EM(%!O;6]C;NUK82(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S
M(@IM<V=S='(@(E9Y<.US8;L@>F]Z;F%M('1A8G5L:65K(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B
M"FUS9W-T<B`B3&ES="U!<F-H:79E(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES="U(
M96QP(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED
M("),:7-T+4ED(@IM<V=S='(@(DQI<W0M260B"@HC.B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B
M3&ES="U/=VYE<B(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W0M4&]S="(*"B,Z(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S
M8W)I8F4B"FUS9W-T<B`B3&ES="U3=6)S8W)I8F4B"@HC.B!L:6(O2&]R9&4O
M34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B
M"FUS9W-T<B`B3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B6F]B<F%Z96YI92!S961E;NT@>FQY:&%L
M;SH@)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(EIO
M8G)A>F5N:64@<&]UONUV871EM6]V('IL>6AA;&\Z("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("):;V)R87IO=F%N:64@>F]Z;F%M
M=2!P;W6^[79A=&6U;W8@:F4@>F%KX7IA;NDN(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R
M873Z<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71V82(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),
M;V%D:6YG+BXN(@IM<V=S='(@(DYAZ.UT879A('-A+BXN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@
M(@IM<V=S='(@(DUI97-T;GD@Z&%S.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("),;VMA
M;&EZX6-I82!A(.AA<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3<R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I
M9"`B3&]C871I;VXB"FUS9W-T<B`B3&]K86QI=&$B"@HC.B!L;V=I;BYP:'`Z
M,3@V('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),
M;V<@:6XB"FUS9W-T<B`B4')I:&SA<V5N:64B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC
M('-E<W-I;VXB"FUS9W-T<B`B6N%Z;F%M>2!P<F5D8VCA9'IA:OIC96H@<WEN
M8VAR;VYI>N%C:64B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D]D:&SA<VF[(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R(")0
M<FEH;.%S96YI92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(MIL;VAY('!R:2!P<FEH;.%S96[M
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4')I:&SA<V5N:64@>FQY
M:&%L;RP@<')E=&^^92!S=&4@>F%D86QI(&YE<W!RX79N92!P;W6^[79A=&6U
M<VOI(&UE;F\@86QE8F\@(@HB:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDX.`IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")0<FEH;.%S
M96YI92!Z;'EH86QO+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y"FUS
M9VED("),;VYG('1E>'0B"FUS9W-T<B`B1&QH_2!T97AT(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(DSA<VMA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*
M;7-G:60@(DQO=R(*;7-G<W1R(").[7IK82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO
M=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B36%LZ2!G<NEC:V4@<.US;65N
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`B36%LZ2!L871I;G-KZ2!P[7-M96[A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W
M97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")-86SI('+M;7-K92#H[7-L:6-E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R<VMO(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y."!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,V"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B
M4W!RX79A(&3R82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R(")0<NUL;VAA($U3+51.148@;F5O8G-A:&]V86QA(+YI
M861N92#Z9&%J92XB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N
M:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M36%C963S;G-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A
M9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-
M86=I8R(*;7-G<W1R(")-X6=I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R(")0;[ET82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS
M9W-T<B`B4&]S;&&[(&4M;6%I;"!A9&UI;FES='+A=&]R;W9I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q
M"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(E9Y='9O<FF[(&QI;E]K
M=2XN+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36%L87ES:6$B"FUS9W-T<B`B36%L86IZ:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I
M=F5S(@IM<V=S='(@(DUA;&5D:79Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@
M(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@=&AE(&QI
M<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H
M+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R
M:65S+B(*;7-G<W1R("(B"B)3<')A=F]V8;L@>F]Z;F%M(&MA=&5G\W)I[2P@
M<R!K=&]R_6UI(&]Z;F'H=6IE=&4@<&]L;[YK>2!A(&9A<F)Y(&%S;V-I;W9A
M;ND@(@HB<R!T_6UI=&\@:V%T96?S<FEA;6DN(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*
M;7-G<W1R(")-87!A($UA<#(T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P.#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-
M87!A($UA<%%U97-T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(DUA<&]V86YI
M82!U;&^^96[I+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W
M"FUS9VED(")-87)C:"(*;7-G<W1R(")-87)E8R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA
M<F=I;B(*;7-G<W1R(")/:W)A:B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L
M86=S(@IM<V=S='(@(D]Z;F'H:;L@<'+M>FYA:VUI(%!R9>CM=&%NZ2].97!R
M9>CM=&%NZ2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"DB"FUS9W-T<B`B3WIN8>AINR!I;OUM:2!P<NUZ;F%K;6D@
M*&YA<'(N($3T;&6^:73I+UIO9'!O=F5D86[I*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA
M;&P@27-L86YD<R(*;7-G<W1R(")-87)S:&%L;&]V92!O<W1R;W9Y(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEK(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD
M<R(*;7-G<W1R(")::&]D;ND@<&]L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B
M"FUS9W-T<B`B36%U<F5TX6YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S
M='(@(DUA=7+M=&EU<R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(DUA>&EMX6QN>2!P;W9O;&5N_2!K<F5D:70N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A
M<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")";VP@<')E:W)OZ&5N_2!M87AI;>%L
M;GD@<&_H970@Z&%S=.T@<W!RX79Y+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B3F%J=GFYN6EA('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`R-"!H;V3M;CH@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP
M(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DYA:G9YN;EI82!T97!L;W1A('IA
M('!O<VQE9&[]8V@@-B!H;V3M;CH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G
M:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B
M36%X:6WA;&YY('!OZ&5T(&)L;VMO=B!P;W)TX6QU(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B36%X:6WA;&YA(&3EOFMA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-X6HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-
M87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EC[6YA(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B
M365M8F5R<R(*;7-G<W1R("+(;&5N;W9I82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B6F]B<F%Z
M96YI92!M96YU.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@
M(EIL^NAINR!B=6YK>2(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B4W!RX79A(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A
M9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R
M=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B
M"B)3<'+A=F$@8F]L82#Z<W!EN6YE(&]V97)E;N$L(&%L92!C97)T:69I:^%T
M('!O9'!I<W4@<V$@;F5P;V1A<FEL;R!O=F5R:;LN(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP
M:7)E9"XB"FUS9W-T<B`B4&QA=&YO<[L@<W!RX79Y('9Y<'*Y86QA+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1Y<"!S
M<'+A=GDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R
M(%=E871H97(B"FUS9W-T<B`B4&_H87-I92!-971A<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(MID86IE($UE=&%R(&YI92!S^B!D;W-T=7!NZ2XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBVF1A:F4@365T87(@
M;FEE('/Z(&L@9&ES<&]Z[6-I:2X@1&5T86EL>2!B;VQI('IA>FYA;65N86[I
M('!R92!A9&UI;FES='+A=&]R82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N
M(@IM<V=S='(@(E-Y<W3I;2!-971A<D1"(&YI92!J92!P<FEP;VIE;OTN(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M(")-973S9&$B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$@;&EB
M+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-973S9&$@
M7"(E<UPB(&YI92!J92!D969I;F]V86[A(@H*(SH@;&EB+TAO<F1E+U)00R]R
M97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E
M9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(DYE9&5F:6YO=F%N
MX2!M973S9&$N(%9O;&%NZ2!Z(&UE=/-D>3H@)7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I8VOI(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI
M8V\B"FUS9W-T<B`B365X:6-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]NZ7IS:V4@9F5D97)A=.UV
M;F4@N73A='DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")3=')E9"(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B
M36EM92!4>7!E(@IM<V=S='(@(E1Y<"!-:6UE(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R(").86IN:;ZY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#(T(&AO
M9.UN.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN
M('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B3F%J;FF^N6EA('1E<&QO
M=&$@>F$@<&]S;&5D;OUC:"`V(&AO9.UN.B`B"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA
M<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B36EN:6WA;&YA(&1O8F$@<&QA
M=&YO<W1I(&AE<VQA(&6Y=&4@;F5V>7!RN6%L82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S,*;7-G:60@(DUI<G)O<B(*;7-G
M<W1R("):<FMA9&QO=F\@;V)RX71INR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")2]'IN92(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@
M2%144%]297%U97-T+B(*;7-G<W1R(")#:/UB82!B86SM:R!014%2($A45%!?
M4F5Q=65S="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED
M("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R
M871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B(@HB0VC]8F$@:V]N9FEG=7+A8VEA+B!!:R!C:&-E
M=&4@<&]UONUV8;L@=/IT;R!A<&QI:^%C:74L(&UU<^UT92!T97)A>B`B"B)V
M>6=E;F5R;W9ANR!K;VYF:6=U<N%C:74N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)
M1"XB"FUS9W-T<B`B0VC]8F$@240@<W!RX79Y+B(*"B,Z(&QI8B].970O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(D-H_6)A('!OOF%D
M;W9A;OT@4$5!4B!B86SM:R!-86EL+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N
M(@IM<V=S='(@(D-H_6)A($E$(')E;.%C:64N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T
M<B`B4&]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED
M(")-;V)I;&4@36%I;"(*;7-G<W1R(")-;V)I;&[](&UA:6PB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D
M97)A=&4B"FUS9W-T<B`B36EE<FYY(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@
M(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1.%T=6T@<&]S;&5D;F5J('IM96YY
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(E5P<F%V:;L@
M55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@
M(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QU<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&%V<VMO(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA
M8V\B"FUS9W-T<B`B36]N86MO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M(")-;VYG;VQS:V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X.`IM<V=I
M9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B365S:6%C(&$@<F]K(@H*(SH@
M;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R(")-97-AZ&YE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@
M(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(DUE
M<V'H;ND@9N%Z>2(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DV(&QI8B]&:6QE
M+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S
M='(@(DYA(')I861K=2`E9"!B;VQO(&[A:F1E;OUC:"!V:6%C('!O;.T@86MO
M(&_H86OA=F%N_6-H("5D+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-
M87)O:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(E!R979AOFYE(&IA
M<VYO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B4')E=F&^;F4@;V)L
M8>AN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B4')E=F&^;F4@<VQN
M9>AN;R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I
M9"`B36]V92!$;W=N(@IM<V=S='(@(E!R97-U;OJ[(&1O;'4B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*
M;7-G<W1R(")0<F5S=6[ZNR!VM6%V;R(*"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")0<F5S
M=6[ZNR!V<')A=F\B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU
M,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B4')E<W5N^KL@:&]R92(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*;7-G:60@
M(DUO=F4@9&]W;B(*;7-G<W1R(")0<F5S=6[ZNR!D;VQU(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"FUS9VED(")-;W9E('5P(@IM<V=S
M='(@(E!R97-U;OJ[(&AO<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T
M<B`B36]Z86)M:6LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I
M9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(E9I86/Z
M<F]V\F]VZ2!V>6)E<F%C:64@>F]Z;F%M>2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M
M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8*;7-G
M:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")6:6%C;N%S;V)N_2!V
M_6)E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@
M(DUY($%C8V]U;G0B"FUS9W-T<B`B36]J92!K;VYT;R(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO
M;B(*;7-G<W1R("));F9O<FWA8VEE(&\@;6]J;VT@^NAT92(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G
M<W1R(")-]&H@<&]R=.%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")6>FBU860@
M;?1J:&\@<&]R=.%L=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")->6%N
M;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").:64L
M($Y%4]I(3$%3S4TN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G
M<W1R(")-96YO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;>UB:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A
M;"(*;7-G<W1R(").97#A;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T
M<B`B2&]L86YD<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM
M<V=S='(@(DAO;&%N9'-KZ2!!;G1I;'DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T
M<B`B6N%K;&%D;N$@55),($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@
M55),(@IM<V=S='(@(E523"!P<F4@>FYE<&QA=&YE;FEE(&-E<G1I9FEKX71O
M=B!#02!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(E52
M3"!P<F4@<&]L:71I:W4@0T$@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB
M"FUS9W-T<B`B55),('!R92!O8FYO=F5N:64@<&QA=&YO<W1I(&-E<G1I9FEK
MX71O=B!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(")5
M4DP@<')E('IN97!L871N96YI92!C97)T:69I:^%T;W8@3F5T<V-A<&4B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DUE;F\@4U-,('-E<G9E<F$@
M3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X.`IM
M<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(")+
M;VUE;G3A<B!C97)T:69I:^%T=2!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!T>7!E(@IM<V=S='(@(E1Y<"!C97)T:69I:^%T=2!.971S8V%P92(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB
M"FUS9W-T<B`B4VEENR(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI:V1Y(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO=N$@2V%L963S;FEA(@H*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G
M:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").;W;A(&MA=&5G\W)I82(*"B,Z
M(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D
M92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D92]497AT
M+T9I;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I;'1E<B]E
M;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G
M92!T;R`E<R(*;7-G<W1R(").;W;A('-P<N%V82!P<F4@)7,B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYO
M=B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G
M:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYO=ND@<&]U
MONUV871EM7-KZ2!M96YO("AN97!O=FEN;NDI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A
M;&%N9"(*;7-G<W1R(").;W;](%KI;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@
M(DYO=ND@:&5S;&\B"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@
M;VX@)7@N(@IM<V=S='(@(E!L871N;W.[(&YO=NEH;R!H97-L82!V>7!RN>T@
M)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED
M(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(").;W;I(&AE
M<VSA(&YI92!S^B!R;W9N86OI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N
M:RDB"FUS9W-T<B`B3F]VZ2!O:VYO("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T
M<B`B3F5W<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G
M:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B1&ES:W5S;ND@<VMU<&EN>2(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT
M(@IM<V=S='(@(L]A;&5J(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS
M9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(DYA<VQE9'5J^F-E(#0@9N%Z
M>2(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<R(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,S<V"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B
MSV%LN6EE(&YA<W1A=F5N:6$B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP
M.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B3F%S;&5D=6KZ8V$^(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEK87)A9W5A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M(").:6?I<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F]C(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM
M<V=S='(@(DYI=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R(").:64B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M(@IM<V=S='(@(B(*(DYI92!S^B!D;W-T=7!NZ2"^:6%D;F4@:V]N9FEG=7)A
MZ&[I(/ID86IE+"!P<F4@:W1O<ND@8GD@<V$@9&%L:2!Z;V)R87IINR`B"B)R
M;WID:65L>2XB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED
M(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+B(*;7-G<W1R(")0<F4@=GET=N%R86YI92!)4T\@;V)R87IO=B!N:64@:F4@
M:R!D:7-P;WKM8VEI(+YI861N82!S=')A=.EG:6$N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E
M;7!L871E+B(*;7-G<W1R(").965X:7-T=6IE(+EA8FSS;F$@<')E(&3A=FMU
M+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C(T-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N(@IM<V=S='(@(DYA('!OOF%D;W9A;F5J('!O>NUC
M:6D@;F5E>&ES='5J92"^:6%D96X@8FQO:RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E
M9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4')E($U#04P@
M875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!M96YO(&MA;&5N9.%R82XB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E
M+B(*;7-G<W1R("*N:6%D;F$@>FUE;F$N(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(DL@=&]M=71O('!RX79U(&YE
M;6^^;F\@<')I9&&[(+YI861N92!P;V1R:6%D96[I('!RX79A+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,38Y(&QI8B](;W)D92YP:'`Z-3`X(&QI8B](;W)D92]5
M=&EL+G!H<#HW-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")0
M<F4@)7,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C@T-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(E!R92!&5%`@
M5D93(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")0<F4@4U%,(%9&
M4R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I82XB"@HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(E!R
M92!344PM1FEL92!61E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@
M(DYO(&-R961I="!L969T+B(*;7-G<W1R("*N:6%D96X@:W)E9&ET+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").96)O;&\@N7!E8VEF
M:6MO=F%NZ2!M:65S=&\@=7+H96YI82XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E
M<BYP:'`Z.3`S"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(E/Z
M8F]R(&YE8F]L(&YA:')A;OTN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B3F5B;VQI(&[A
M:F1E;ND@OFEA9&YE(&EK;VYY+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N
M(@IM<V=S='(@(DYI92!J92!N87-T879E;N$@;&]K86QI=&$N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(DYE8F]L82!Z861A;N$@;&]K86QI=&$N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I
M9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F5B;VQA('IA9&%N
MX2"^:6%D;F$@<W!RX79A+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R
M(").96)O;&\@N7!E8VEF:6MO=F%NZ2"^:6%D;F4@;65N;RXB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB
M97(@<W!E8VEF:65D+B(*;7-G<W1R(").96)O;&\@N7!E8VEF:6MO=F%NZ2#H
M[7-L;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("*N:6%D;F4@=7+AOFQI=ND@
M9F]R='5N>2(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B4')E($A45%`@875T96YT:69I:^%C:74@;F5B;VQO('IA
M9&%NZ2!H97-L;RXB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")0<F4@24U!4"!A=71E;G1I9FEKX6-I=2!N96)O
M;&\@>F%D86[I(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP
M.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!R92!+97)B97)O<R!A=71E;G1I
M9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-A<VPN<&AP.C<W(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`HC
M.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(E!R92!,;V=I;B!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO
M+B(*"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")0<F4@4$%34U=$(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z
M861A;ND@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B4')E(%--0B!A=71E;G1I9FEKX6-I=2!N96)O;&\@
M>F%D86[I(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F5B;VQA
M('IA9&%NX2!C97-T82!K('!R;V=R86UU($]P96Y34TPN(%!R;V=R86T@3W!E
M;E-33"!J92!P;W1R96)N_2!N82!P<N%C=2`B"B)S(/ID86IM:2!02T-3(#$R
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G
M:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`BKFEA9&YE('!R96)I
M96AA:OIC92!P<FEH;.%S96YI82XB"@HC.B!L:6(O5D93+G!H<#HW-C4*;7-G
M:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B2W;S=&$@;FEE(&IE(&YA<W1A
M=F5NX2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")"97H@Z&EA
M<B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T
M;W(@<W!E8VEF:65D+B(*;7-G<W1R(").96)O;""Y<&5C:69I:V]V86[](&]D
M9&6U;W9AZ"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")"97H@
M<W1RX6XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H
M(&9I;&4B"FUS9W-T<B`B4_IB;W(@;F5NX6ID96[](@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")0<F4@=GER
M;W9NX79A8VEU('!A;>2[(&YI92!J92!D;W-T=7!N_2"^:6%D96X@9&_H87-N
M_2!P<FEEZ&EN;VLN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,2!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B3F5B
M;VQO(&]D;W-L86[I('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L96)O(&AE<VQO
M+B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DYE8F]L:2!V<N%T
M96[I('!L871NZ2!834P@^F1A:F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3<Q(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HY.#$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDY,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(JYI861N92!H;V1N;W1Y
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E8@</1V;V1N96H@:V]N
M9FEG=7+A8VEI(&YE8F]L82!NX6ID96[A(+YI861N82!V97)Z:6$N(%9Y9V5N
M97)U:G1E('IN;W9U("(*(FMO;F9I9W5RX6-I=2XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO
M=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B)6(&MO;F9I9W5RX6-I:2!N96)O;&$@;N%J9&5NX2"^:6%D
M;F$@=F5R>FEA+B!6>6=E;F5R=6IT92!Z;F]V=2!K;VYF:6=U<N%C:74N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G
M<W1R("*N:6%D96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S
M='(@(JYI861N92`H<&]UOFF[(&EM<&QI8VET;OH@:&]D;F]T=2DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U
M.2TQ,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G
M<W1R(")/<W1R;W8@3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B4V5V97)NX2!P;VQO9W6U82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R
M=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(E-E=F5R;ND@36%R:>%N
M<VME(&]S=')O=GDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").\W)S:V\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T
M($%F=&5R(@IM<V=S='(@(DYE<&QA=.T@<&\B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(").
M97!L873M('!R960B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B
M3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DYI92!J92!A9')E<^%R(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M
M96YT960N(@IM<V=S='(@(DYI92!J92!I;7!L96UE;G1O=F%NZ2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED
M(").;W0@<V5T(@IM<V=S='(@(DYE;F%S=&%V96[I(@H*(SH@;&EB+U9&4RYP
M:'`Z,3DS(&QI8B]61E,N<&AP.C(P."!L:6(O5D93+G!H<#HR,S,@;&EB+U9&
M4RYP:'`Z,C4Q"B,Z(&QI8B]61E,N<&AP.C(V."!L:6(O5D93+G!H<#HR.#0@
M;&EB+U9&4RYP:'`Z,S`P(&QI8B]61E,N<&AP.C,Q-0HC.B!L:6(O5D93+G!H
M<#HS,S(@;&EB+U9&4RYP:'`Z,S8U(&QI8B]61E,N<&AP.C0R-2!L:6(O5D93
M+G!H<#HU,#0*(SH@;&EB+U9&4RYP:'`Z-3<S(&QI8B]61E,N<&AP.C4Y,"!L
M:6(O5D93+G!H<#HV-C@*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-#4@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+G!H<#HR,S8*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYI92!J
M92!P;V1P;W)O=F%NZ2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R
M(")0;WINX6UK>2(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS
M-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@
M(DYIZ"!N82!P<F5Z97)A;FEE+"!V<N&[=&4@<V$@<W#DNRXB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS
M9W-T<B`B3F]V96UB97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U,`IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(LCM<VQO(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S
M='(@(E!OZ&5T('IN86MO=B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<S
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(W(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")0;^AE="!S
M=.5P8V]V(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@
M(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(E!OZ&5T(')I861K;W8B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB
M97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(")0<F4@86MT=6%L:7KA8VEU('IO>FYA;74@<'+M
M:F5M8V]V(&YE8F]L:2"Y<&5C:69I:V]V86[I(.CM<VQA+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB
M"FUS9W-T<B`B3TLB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#<P"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#
M<F5A=&]R(@IM<V=S='(@(D%U=&]R(&]B:F5K='4B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$P.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3W-M:>AK;W;]
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P."!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C
M=&]B97(B"FUS9W-T<B`B3VMT\V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R
M(&YA(&YA9.%V:WDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X
M"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B4')A8V]V:7-K;R(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")3=&%RZ2!A
M(&YO=ND@:&5S;&\@;75S:6$@8GF[(&]D;&FY;NDN(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS
M9W-T<B`B4W1A<ND@:&5S;&\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB
M"FUS9W-T<B`B4W1A<ND@:&5S;&\@;F5B;VQO('IA9&%NZ2!S<'+A=FYE+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;>%N(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("))8F$@24U!4"!S
M97)V97)Y('!O9'!O<G5J^B!Z9&EEM6%NZ2!P<FEEZ&EN:WDN(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F
M;W)T=6YE<R(*;7-G<W1R("))8F$@=7+AOFQI=ND@9F]R='5N>2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(DIE('!R[7!U<W1NX2!I8F$@:F5D;F$@92UM86EL;W;A(&%D<F5S82XB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E(@IM<V=S='(@(B(*(E9L87-T;NUK82!A;&5B;R!P<N%V82!V;&%S=&[M
M:V$@<')E('ID:66U86[](&]B:F5K="!M]+YE('IM96YINR!I8F$@=FQA<W1N
M[6L@(@HB86QE8F\@<WES=.EM;W;](&%D;6EN:7-T<N%T;W(B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,`IM
M<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3W1V;W)INR!V
M(&YO=F]M(&]K;F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T
M-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T
M82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B0VAY8F$@3W!E
M;E-33#H@;F5P;V1A<FEL;R!S82!Z[7-K8;L@^F1A:F4@>B!P;V1P[7-A;F5J
M(.AA<W1I(%,O34E-12XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3W1V;W)INR!T^G1O(&QI;FMU
M('8@;F]V;VT@;VMN92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM
M<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5R8>AN_2!S>7-T
MZ6TB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED
M(")/<'1I;VYS(@IM<V=S='(@(DYA<W1A=F5N:6$B"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B3F%S=&%V
M96YI82`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("):;W)A9&5N
M_2!Z;WIN86TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM
M<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7KA8VEA(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A
M=&EO;F%L(%5N:70B"FUS9W-T<B`B3W)G86YI>F'H;N$@:F5D;F]T:V$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ
M:6YG(@IM<V=S='(@(D]R9V%N:7IO=F%N:64B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA
M=&4B"FUS9W-T<B`B4/1V;V1NX2"Y86)L\VYA(&%P;&EKX6-I92(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R
M:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B4/1V;V1NZ2"Y86)L
M\VYY('8@)7,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M26[I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H
M97(@26YF;W)M871I;VXB"FUS9W-T<B`BSV%LN6EE(&EN9F]R;>%C:64B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!0
M97)M:7-S:6]N<R(*;7-G<W1R(")0<N%V82!V;&%S=&[M:V$B"@HC.B!L:6(O
M2&]R9&4O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-(&%U=&5N=&EF:6OA
M8VEA(&YI92!J92!D;W-T=7!NX2XB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC
M7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S
M='(@(E!%05(Z36%I;"!B86-K96YD(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(D1I9VETX6QN>2!P;V1P:7,@4$=0(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S
M='(@(MID86IE('IAN6EF<F]V86[I('!O;6]C;W4@4$=0(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B4$=0('9E<F5J;OT@:[7ZZ"(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$B"FUS9W-T<B`BVF1A:F4@<&]D<.US86[I+WIAN6EF<F]V86[I('!O;6]C
M;W4@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@
M0V]D92(*;7-G<W1R(")02%`@:_-D(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0(%-H96QL(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@
M(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B4&]P;VQU9&[M(+5A:&O](&3AON\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM
M<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")0;W!O;'5D;NT@<')E:.%N:WDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM
M<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")0;W!O;'5D;NT@<VYEOF5N:64B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I
M9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E!O<&]L=61N[2!S;F5H;W;I
M('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")0;W!O;'5D;NT@<VYE
MOF5N:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B4&]P;VQU9&[M(&+Z
M<FMY(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]3
M25@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B0VC]8F$@<F]ZN>UR
M96YI92!03U-)6"(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3
M:&5L;"(*;7-G<W1R(")07TA0(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN
M9R(*;7-G<W1R(")6>7!L;F5N:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S
M='(@(E!A:VES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L875S
M:^D@;W-T<F]V>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960B"FUS9W-T<B`B4&%L97-T[6YS:V4@^GIE;6EE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@
M1W5I;F5A(@IM<V=S='(@(E!A<'5A($YO=N$@1W5I;F5A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B
M4&%R86=U87DB"FUS9W-T<B`B4&%R86=U87DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D
M>2(*;7-G<W1R("+(:6%S=&_H;F4@;V)L8>AN;R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P,C(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-S<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHT,R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S
M=V]R9"(*;7-G<W1R(")(97-L;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(DAE<VQO(&)O;&\@^G-P9;EN92!Z;65N96[I+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O
M<F0@:6YC;W)R96-T(@IM<V=S='(@(DYE<W!RX79N92!H97-L;R(*"B,Z(&QI
M8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R
M97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")0
M<F4@875T96YT:69I:^%C:74@4D%$2553(&IE('9YOF%D;W9A;ND@:&5S;&\N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3<*;7-G:60@(E!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DAE<VQO(',@<&]T=G)D96[M
M;2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B
M4&%S<W=O<F0Z(@IM<V=S='(@(DAE<VQO.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DAE
M<VQO.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P,S@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ
M-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(DAE<VSA
M(&UU<VEA(&)YNR!R;W9N86OI+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")6;&^^:;LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")0
M87-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")6;&^^:;L@>F\@<V-H<N%N
M:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Q"FUS9VED(")0871H(@IM<V=S='(@(D-E<W1A(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B4')E8FEE:&%J^F-E(')E9VES='+A8VEE.B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(J5U
M9&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4&5R8V5N="(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED
M(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B5GEK
M;VYANR!O<&5RX6-I92#Z9'*^8GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(E9Y:V]N8;L@;W!E<N%C:64@^F1ROF)Y('!R
M:2!P<FEH;.%S96[M/R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V
M"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E!RX79O(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M
M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B4'+A=F\@7"(E
M<UPB(&YE8F]L;R!V>6UA>F%NZ2XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3DP
M"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")0<NUS='5P('IA
M;6EE=&YU=/TB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V,2!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4'+A=F$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X
M+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M
M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES='+A8VEA
M('!RX78B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E
M<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D]S;V)NZ2!I;F9O<FWA8VEE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B1&]MX6-E('IV
M:65R873A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<.UN
M>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS
M9VED(")0:&]N92(*;7-G<W1R(")496QE9O-N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G
M<F%F:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X
M"FUS9VED(")0:7AE;',B"FUS9W-T<B`B0F]D;W8B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S
M='(@(DML:6MN:71E('!R;W/M;2!D;R!N96IA:V5J(&)U;FMY(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y
M"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(E!O='9R[W1E('!R;W/M;2P@OF4@
M8VAC971E(&]D<W1RX6YINR!T96YT;R!E;&5M96YT.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI
M<R!E;&5M96YT+B(*;7-G<W1R(")0;W1V<N]T92!P<F]S[6TL(+YE(&-H8V5T
M92!O9'-T<N%N:;L@;&EN:W4@>B!T;VAT;R!E;&5M96YT=2XB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C4V-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N
M=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B6F%D86IT92!P<F]S[6T@;65S:6%C
M(&$@<F]K+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("):861A:G1E('!R;W/M;2!M96YO('!R
M92!N;W;Z(&MA=&5G\W)I=3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P
M-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS
M9W-T<B`B6F%D86IT92!P<F]S[6T@<&QA=&[Z($E0(&%D<F5S=2XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C8T-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"XB"FUS9W-T<B`B6F%D86IT92!P<F]S[6T@<&QA=&[](&3A='5M+"!S
M:V]N=')O;'5J=&4@<&_H970@9&[M('8@;65S:6%C:2XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@
M=&EM92XB"FUS9W-T<B`B6F%D86IT92!P<F]S[6T@<&QA=&[](.AA<RXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@
M(E!R;W/M;2!U=F7O=&4@>FAR;G5T:64@<')O8FSI;74N(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9"(*;7-G<W1R(")0<F]S[6T@>F%D86IT92!S=F]J92!P;W6^
M[79A=&6U<VOI(&UE;F\@82!H97-L;R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN
M9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@
M=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB4')EZ.UT86IT92!S:2!P<F]S
M[6T@;F%S;&5D=6KZ8VD@=&5X="X@3553S51%('/Z:&QA<VF[(',@<&]D;6EE
M;FMA;6D@(@HB<&]UONUV86YI82!S>7-TZ6UU+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(EIA9&%J=&4@<')O
M<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S<FEU.B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD
M(@IM<V=S='(@(E!OM7-K;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:V$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R
M(")!;FME='DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A
M;'-K;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(*;7-G<W1R(")5;6EE<W1N96YI92!T;VAT;R!O8G+A>FMU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B56UI97-T
M;F5N:64@=&5J=&\@=&%B=;5K>2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(D]D;W-L8;L@9&\@=&]H=&\@
M<')I9>AI;FMA("AN979Y;G5C=6IE($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B`B"FUS9W-T<B`B6G+AOFMY('IA('!O<VQE9&[]8V@@)7,@:&]D[6XZ("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R
M96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B4')A=F1E<&]D;V)N
M;W.[/&)R("\^>G+AOF]K(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP
M.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z('!OOF%D;W9A;ND@
M<F]ZN>UR96YI92!,1$%0(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<F5F<U]S97-S:6]N.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<V5S<VEO
M;B!N96)O;&\@;N%J9&5NZ2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B5&QA:R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ
M("(*;7-G<W1R(")4;&%K(&YA(/IR;W9N:2!M;W)A.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM
M<V=S='(@(E1L86LZ("(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@
M(E5KX;YK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(EIO8G)A>FF[('5KX;YK=2!O8G+A
M>FMU('8@;F]V;VT@;VMN92(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,S8R(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U
M<R!O<'1I;VYS(@IM<V=S='(@(E!R961C:.%D>F%J^F-E(&YA<W1A=F5N:6$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q
M"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")6>71L8>AINR!D;VMU
M;65N="(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B
M4')I=F%T92!+97DB"FUS9W-T<B`B4')I=N%T;GD@:[7ZZ"(*"B,Z(&QI8B](
M;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4')O
M8FSI;2(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O
M8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")0;W!I<R!P<F]B;.EM=2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S
M(@IM<V=S='(@(E!R;VIE:W1Y(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M,34@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.3(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,R-S0*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E;]>G9A(&YA('IA
M9&%N:64@=&5X='4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*
M;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B5F5R96IN_2!KM?KH(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+
M97D@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M=7,@=F5R96INZ6AO(&NU
M^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@
M(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("));F9O<FWA8VEE(&\@=F5R96IN
M;VT@:[7ZZ&DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G
M:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(E9E<F5J;OTO<')I=N%T;GD@:[7ZZ&]V_2!P
MX7(@;F5B;VP@^G-P9;EN92!V>6=E;F5R;W9A;OTN(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E
M<G1O(%)I8V\B"FUS9W-T<B`B4&]R=&]R:6MO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B
M"FUS9W-T<B`B2V%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G
M:60@(E%U97)Y(@IM<V=S='(@(D1O=&%Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R(")+=O-T82(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302!V97)E
M:F[](&NU^N@@*"5D(&)I=&]V*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C8X"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B4')E<.UN8>@@
M<R!V_6)E<F]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B1.&^[R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN
M($5A<FQY(@IM<V=S='(@(E+A;F\@9.&^[R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B3F5S:_1R(&3AON\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B
M1&&^[V]VZ2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@
M(D3AON\@<V\@<VYE:&]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")$
MX;[O('!R96-HX61Z86KZ8VD@=B!S;F6^96YI92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(").
MX6AO9&[A(&9O<G1U;F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I
M9"`B4F%T:6\B"FUS9W-T<B`B4&]M97(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("+([71ANR(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A
M9"!M97-S86=E<R(*;7-G<W1R("+([71ANR!S<'+A=GDB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92XB"FUS9W-T<B`B3F%O>F%J('9Y;6%Z8;L@)7,_(%3Z=&\@;W!E
M<N%C:74@;F5M;[YN;R!V<N%T:;L@<W#DNRXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB3F%O>F%J('9Y;6%Z
M8;L@<&]UONUV871EM7-KZ2#Z9&%J92!P<F4@<&]UONUV871EM6$@)7,_(%3Z
M=&\@;W!E<N%C:74@;F5M;[YN;R`B"B)V<N%T:;L@<W#DNRXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2
M961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")6<N%T:2!S<.2[(%9A
MN74@<&]S;&5D;OH@86MC:74B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*
M;7-G<W1R(")/8FYO=FF[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S
M='(@(D]B;F]V:;L@96QE;65N='D@9'EN86UI8VOI:&\@;65N=3HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A
M;"!6:65W.B(*;7-G<W1R(")/8FYO=FF[('IO8G)A>F5N:64@<&]R=.%L=3HB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C$W(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*
M;7-G<W1R(")296=U;.%R;GD@=OUR87HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S(S.`IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B
M4')E:&QI861AZ"!V>KMA:&]V(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I
M9"`B4F5L;V%D(@IM<V=S='(@(EIN;W9U(&YAZ.UT8;LB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")0;W-T
M<F5H>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E
M;6]T92!397)V97)S(@IM<V=S='(@(E9Z9&EA;&5NZ2!S97)V97)Y(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B
M5GID:6%L96[A(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B
M"FUS9W-T<B`B3V1S='+A;FF[(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B3V1S='+A
M;FF[(&)L;VLB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34V"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(D]D<W1RX6YI
MNR!S=.5P96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")/
M9'-T<N%N:;L@9F]R;>%T;W9A;FEE(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(D]D<W1R
MX6YINR!PX7(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED
M(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B3V1S='+A;FF[('5L;[YE;OT@<VMR:7!T
M('H@9&_H87-NZ6AO('!R:67H:6YK82!N82!S97)V97)I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM
M<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")/9'-T<N%N:;LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*
M;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS
M9W-T<B`B3V1S='+A;FF[('1E;G1O(&)O9"!Z(&1O:W5M96YT=2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V
M92!U<V5R(@IM<V=S='(@(D]D<W1RX6YINR!P;W6^[79A=&6U82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B3V1S='+A;FF[('!O
M=;[M=F%T9;5A.B`E<R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ
M,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R
M;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(DYA('!OOFEA9&%V:W4@;F5B;VQO
M(&UOOF[I(&]D<&]V961ANRX@3N%V<F%T;W;](&OS9"!C:'EB>3H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S
M=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(")0;[YA
M9&]V86[Z('-L=;YB=2!S82!N97!O9&%R:6QO(&[A:G.[+B(*"B,Z(&QI8B](
M;W)D92YP:'`Z,3<V(&QI8B](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(E8@:V]N9FEG=7+A8VEI("5S(&YI92!J
M92"Y<&5C:69I:V]V86[A('!OOF%D;W9A;N$@<&]L;[YK82!<(B5S7"(B"@HC
M.B!L:6(O5D93+W-Q;"YP:'`Z-C<X(&QI8B]61E,O9G1P+G!H<#HX-3`@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")6(&MO;F9I9W5RX6-I:2!61E,@;FEE(&IE(+EP96-I
M9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA(%PB)7-<(B(*"B,Z(&QI8B](
M;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B5B!K;VYF:6=U<N%C:6D@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^
M861O=F%NX2!P;VQOOFMA(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]&;W)M+U)E
M;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@
M(E!O=FEN;ND@<&]L92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D
M92]&;W)M+G!H<#HS-#,@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R
M,`HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S
M='(@(E9Y;6%Z8;L@9F]R;75LX7(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B3V)N
M;W9INR!H97-L;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W
M"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D]B;F]V:;L@
M5F&Y92!H97-L;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@
M(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")/8FYO=FF[('!O<VQE9&[]
M(&1O=&%Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H
M96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L
M=',B"FUS9W-T<B`B5OUS;&5D:WDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@
M(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(D[A=G)A="!N82!N87-T879E
M;FEA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(EIA9&%J=&4@;F]VZ2!H
M97-L;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
M5G+A=&F[(&MO;F9I9W5RX6-I=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R
M(").87-T879E;FEA(')O>KGM<F5NZ6AO('1E>'1O=NEH;R!E9&ET;W)U(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM
M<V=S='(@(DCA9&%N:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(E9P
M<F%V;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$P"FUS9VED(")2:6=H
M="!H96%D97(B"FUS9W-T<B`B2&QA=FGH:V$@=G!R879O(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,#8*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R
M(")(;V1N;W1Y('9P<F%V;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(E9L87-T;F]S=&D@7W)I861K82XN+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE
M(@IM<V=S='(@(E)O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)U
M;75N<VMO(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R-`IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")/=&_H:;L@;R`Q.#`B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"FUS
M9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")/=&_H:;L@=K5A=F\B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(W"FUS9VED(")2
M;W1A=&4@4FEG:'0B"FUS9W-T<B`B3W1OZ&F[('9P<F%V;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G
M:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@<FEA9&MA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B5FQA<W1N
M;W-T:2!R:6%D:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B4FEA9&MY.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(LAI87)Y(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(*;7-G<W1R("+(:6%R>2!S82!Z;V)R87II82!M961Z:2!VN65T:_UM
M:2!R:6%D:V%M:2!A('-TY7!C86UI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`BR&EA<GD@
M<V$@>F]B<F%Z:6$@:6)A(&UE9'II('-TY7!C86UI(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B
MR&EA<GD@<V$@>F]B<F%Z:6$@:6)A(&UE9'II(')I861K86UI(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(E-P=7-T
M:;LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S
M:^$@9F5D97+A8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W86YD
M82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%
M(&MR>7!T;V=R869I8VO]('!O9'!I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B
M"FUS9W-T<B`B4W!RX79A('IAN6EF<F]V86[A('!O;6]C;W4@4R]-24U%(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"!A
M=71E;G1I9FEKX6-I82!N:64@:F4@9&]S='5P;N$N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G
M<W1R(")0;W-I96QA;FEE(%--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR
M,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!3:&5L;"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,C<R"FUS9VED(")344P@<W1A=&5M96YT(&9O
M<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-13"!P<NUK87H@<')E(&BU861A
M;FEE(&AO9&[T="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*
M;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B
M"FUS9W-T<B`BVE-014-((@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")3
M7U%,(%-H96QL(@IM<V=S='(@(E-?44P@4VAE;&PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G
M<W1R(")3;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")3=N1T
MX2!(96QE;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G
M<W1R(")3=N1T_2!+:71T<R!A($YE=FES(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I
M82(*;7-G<W1R(")3=N1TX2!,=6-I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4W8N(%!I97)R92!A($UI<75E;&]N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B
M"FUS9W-T<B`B4W;D=/T@5FEN8V5N="!A($=R96YA9&EN>2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")496X@:7-T_2!RX6UE8R`H7W-E
M;&8I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@82!0<FEN
M8VEP92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B
M4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E-A=&5L:71N_2!P;W-K>71O
M=F%T9;4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U9'-K
MX2!!<N%B:6$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*
M;7-G:60@(E-A=F4B"FUS9W-T<B`B56QOOFF[(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R(")5;&^^:;L@7"(E<UPB(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V92`E<R(*;7-G<W1R(")5;&^^:;L@)7,B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B56QO
MOFF[(&YA<W1A=F5N:6$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W
M"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*(E5L;[YINR!V>6=E;F5R;W9A;OH@:V]N9FEG
M=7+A8VEU(&%K;R!02%`@<VMR:7!T(&1O(&1OZ&%S;NEH;R!P<FEEZ&EN:V$@
M5N&Y:&\@(@HB<V5R=F5R82XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")+;VYF:6=U<N%C:6$@)7,@8F]L82!U;&^^96[A+B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(E-K<FEP="!N82!U<&=R861E(&YA<W1A=F5N[2!B;VP@=6QO
MOF5N_2!D;SH@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS
M9W-T<B`B3VIE9&EN96SI(&+Z<FMY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(E9E9&$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(DBU861A
MNR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E
M87)C:"!%;F=I;F5S(@IM<V=S='(@(E9Y:+5A9.%V8>AE(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Y-C(*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R
M(")6>6)E<G1E('/Z8F]R>2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#(*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B
M5GEB97)T92!DX71U;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5GEB
M97)T92!S:W5P:6YU(&YA('!R:61A;FEE(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S
M='(@(E9Y8F5R=&4@;F]VZ6AO('9L87-T;NUK82(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM
M<V=S='(@(E9Y8F5R=&4@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(E9Y8F5R=&4@<&]UONUV871EM6$@;F$@<')I9&%N:64B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<S"FUS9VED(")396QE
M8W0@86QL(@IM<V=S='(@(E9Y8F5R=&4@=KEE=&MY(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(V-3`*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+B(*;7-G<W1R(")6>6)E<G1E(':Y971K>2!K;VUP;VYE;G1Y(&3A='5M
M=2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S`*
M;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5GEB97)T92!O8FIE
M:W0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<T
M"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("):<G6Y:;L@=OUB97(B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+B(*;7-G<W1R("(B"B)6>6)E<G1E('IN86MY+"!K=&]RZ2!P
M;W1R96)U:F5T92P@>B!O:VEE;F]K(&YIOKEI92X@4&]T;VT@:6-H(&WTOF5T
M92`B"B)S:V]P[7)O=F&[(&$@=FQOOFF[('H@=&5X=&]VZ6AO('!OM6$N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E9Y8F5R=&4@;V1D9;5O=F'H
M('9O(&9O<FWA=&4@9.%T=6UU.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R
M(")6>6)E<G1E(&9O<FWA="!DX71U;74Z(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E9Y8F5R=&4@:61E
M;G1I='4L(&MT;W+Z(&-H8V5T92!Z;65N:;LZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z(@IM<V=S='(@(E9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA=&4@Z&%S
M=3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5GEB97)T92!F;W)MX70@
MZ&%S=3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED
M(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B5GEB97)T
M92!D=F4@>FAO9&[I('!O;&EA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T
M<B`B5GEB97)T92!S:2!F87)E8F[Z('-C:.EM=2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93HB"FUS9W-T<B`B5GEB97)T92!J87IY:SHB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R(")0;W-L8;L@<W!RX79U(&\@<')O8FSI;64B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I
M9"`B4V5N9"!335,B"FUS9W-T<B`B4&]S;&&[(%--4R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YZ;W(Z("(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB
M97(B"FUS9W-T<B`B4V5P=&5M8F5R(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM
M<V=S='(@(E-R8G-K;R!A(,AI97)N82!H;W)A(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T
M<B`B4^ER:6]VZ2#H[7-L;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(MID86IE('IO('-E<G9E<F$@<_H@;F5S<'+A=FYE
M(&%L96)O(&YI92!S^B!D;W-T=7!NZ2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B061M:6YI<W1R
MX6-I82!S961E;NTB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")0
M;&%T;F]SNR!)1"!S961E;FEA('9Y<'*Y86QA+B(*"B,Z(&QI8B]A<&DN<&AP
M.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5D96YI82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S$X"FUS9VED(")3970B"FUS9W-T<B`B36YO
MOFEN82!H;V1N]'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G
M:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B3F%S=&%V
M=&4@;6^^;F]S=&D@;F$@;V)N;W9E;FEE(%;AN6AO(&AE<VQA(&%K(&AO('IA
M8G5D;F5T92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED
M(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HB3F%S=&%V96YI92!V
M>F1I86QE;OUC:"!S97)V97)O=BP@:W4@:W1O<OUM(&-H8V5T92!P<FES='5P
M;W9ANR!Z(%;AN6AO("(*(G!O<G3A;'4N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L
M('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(E9Y8F5R=&4@
M:F%Z>6LL(.AA<V]V^B!Z\VYU(&$@;F%S=&%V96YI82!DX71U;74N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@
M(B(*(DYA<W1A=F5N:64@87!L:6OA8VEE('-P^KF[86YE:B!P<FD@N71A<G1E
M+"!F87)E8FYE:B!S8VCI;7DL(&EN=&5R=F%L=2`B"B)O8FYO=F]V86YI82!S
M='+A;FMY(&$@:6[]8V@@=FQA<W1N;W-T[2!Z;V)R87IE;FEA+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@
M(DYA<W1A=F5N:64B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R(")3^B!D;W-T=7!NZ2!S:W)I<'1Y(&YA('5P9W)A9&4@;F%S
M=&%V96[M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM
M<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R
M86UE=&5R.B`B"FUS9W-T<B`B1&\@^G9A:'D@<')I8VCA9'IA(&YI96MOM6MO
M(&QO:V%L[70@<&]M;V-O=2!P87)A;65T<F$Z("(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H
M96QL97,B"FUS9W-T<B`B4V5Y8VAE;'DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")3:&]P<&EN
M9R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED
M(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DMRX71K>2!S^FAR;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@
M:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")-86KZ
M('-A('!R92!VY.BY:6YU(&QI;FEE:R!V>71V;W)INR!S:W)A=&MO=ND@:VSA
M=F5S>3\B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I
M9"`B4VAO=R(*;7-G<W1R("):;V)R87IINR(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E
M;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB6F]B<F%Z:;L@<F]Z9&EE;'D@
M;65D>FD@<'+A=F4@=6QOOF5N;W4@82!N;W9O=GEG96YE<F]V86YO=2!K;VYF
M:6=U<N%C:6]U+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G
M:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS
M9W-T<B`B3>$@<V$@<')I('!R:6ALX7-E;NT@>F]B<F%Z:;L@Z&%S('!O<VQE
M9&[I:&\@<')I:&SA<V5N:6$_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W
M-CD*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T
M<B`B6F]B<F%Z:;L@;6^^;F]SNR!N82!P;VYE8VAA;FEE(&]R:6=I;N%L=2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`R"FUS9VED(")3:&]W('!I8VME
M<B(*;7-G<W1R("):;V)R87IINR!NX7-T<F]J(&YA(';]8F5R(&9A<FEE8B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B6F]B<F%Z:;L@;65N
M=2!P<F4@;W!E<N%C:64@<R!T86)UM6MA;6D_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("):;V)R87IINR!M96YU("5S
M(&YA(+5A=F5J('-T<F%N93\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B6F]B<F%Z:;L@
M9&EA;/-G(',@=FQA<W1N;W.[86UI(&)U;FMY('1A8G6U:WDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(EIO8G)A>FF[(&1I86SS9R!S('9L87-T;F]SNV%M:2!T86)UM6MY(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI
M(')I861K=2!T86)UM6MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("):;V)R87IINR!D:6%L\V<@
M<R!V;&%S=&YO<[MA;6D@;V)RX7IK=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-S8W"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("):;V)R87IINR!N
M86AR86[I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B4')E:.%N:WDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B
M4VAO=V5R<R!%87)L>2(*;7-G<W1R(")2X6YO('!R96CA;FMY(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H
M;W=E<G,@3&%T92(*;7-G<W1R(").97-K]'(@<')E:.%N:WDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO
M=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B6G+AOFMY('8@;VMO;.TB
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H
M<FEN:R(*;7-G<W1R("):;65NN6F[(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z-S<T(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@S-@HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,C(@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.C$P-#<@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H
M8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R
M(").86IP<G8@;75S[71E('IM96ZY:;L@86QE8F\@<')E<W5N^KL@<W5S961N
M_2!B;&]K*'DI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I
M97)R82!,96]N92(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V
M"FUS9VED(")3:6=N('5P(@IM<V=S='(@(EIA<F5G:7-T<F]V8;L@<V$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T
M=7)E(@IM<V=S='(@(E!O9'!I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@
M(D%L9V]R:71M=7,@<&]D<&ES=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G
M<W1R(")3:6YG87!U<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#`@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#$*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3(*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*
M;7-G:60@(E-I>F4B"FUS9W-T<B`B5F6U:V]SNR(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA
M:6YT96YA;F-E(@IM<V=S='(@(E!R97-K;^AINR#Z9'*^8G4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3;&]V86MI82(*;7-G<W1R(")3;&]V96YS:V\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M96YI82(*;7-G<W1R(")3;&]V:6YS:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R(")3
M;F6^96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")3;F5H;W;A('!R
M96CA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")3;F5H;W;I('!R
M96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")2X6YO
M('-N96AO=ND@<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS
M9W-T<B`B3F5S:_1R('-N96AO=ND@<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(DCE
M8FMA('-N96AU.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I
M9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B36YOOG-T
M=F\@=F]D>2!E:W9I=F%L96YT;ND@<VYE:'4Z("(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R("*I86QA;?IN;W9E(&]S=')O=GDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;>%L<VMO(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@
M(E!I97-N92!A(&+A<VYE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,34*
M;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E;]8F5R('-M
M97)U('1R:65D96YI82(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,38V(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.#D*
M;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(EID<F]J;W;A(&%D<F5S
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")*=;YNX2!!9G)I
M:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS
M9W-T<B`B2G6^;N$@1V5O<F=I82!A(%-O=71H(%-A;F1W:6-H($ES;&%N9',B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DIUOF[A
M('!O;&]G=;5A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',B"FUS9W-T<B`B365D>F5R82!M961Z:2!S=7-E9&[];6D@8G5N:V%M:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U
M"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C
M96QL(@IM<V=S='(@(DUE9'IE<F$@;65D>FD@;V)S86AO;2!A(&]K<F%J;VT@
M8G5N:WDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$Y"FUS9VED(")3<&%C
M97(B"FUS9W-T<B`B3V1D9;5O=F'H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM
M<V=S='(@(D]D<W1U<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B3V1S='5P(&$@=GEP;&YE;FEE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN
M(@IM<V=S='(@(JEP86YI96QS:V\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M($EN<'5T(@IM<V=S='(@(E9L;[YE;FEE(+EP96-IX6QN>6-H('IN86MO=B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B4F]Z9&5L:;L@8G5N
M:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B4F]Z9&5L
M:;L@<W3E<&5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(E)O
M>F1E;&F[(')I861O:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(JEP;W)T>2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA
M;FMA(@IM<V=S='(@(E-R[2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3
M=&%N9&%R9"(*;7-G<W1R("*I=&%N9&%R9&[I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4
M<F5K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(W.3@*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4&_H:6%T
M;^AN_2!R;VLB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,0IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`BJ73A="!A;&5B;R!P
M<F]V:6YC:6$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M
M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T878B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C@P-`IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T
M<B`B1F]R;>%T('5L;[YE;FEA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D)Y9&QI
M<VMO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")0<F6Y:W)T;G5T
MZ2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@
M;&ES="(*;7-G<W1R("):;WIN86T@<F6[87IC;W8B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@W-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D
M9')E<W,B"FUS9W-T<B`B3V1S='+A;FF[(&1O;>EN=2!Z(&%D<F5S>2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(JET_6P@6T-34UTB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS
M9VED(")3=2(*;7-G<W1R(").92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4&]D<')I9>AI;F]K(%PB)7-<(B!N96)O
M;"!NX6ID96[]+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E!R961M970B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,V(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R
M+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R(")/9&]S;&&[(@H*(SH@
M<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T
M960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C
M86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A
M<'!R;W9E9"XB"FUS9W-T<B`B(@HB4&^^:6%D879K82!N82!P<FED86YI92!<
M(B5S7"(@9&\@<WES=.EM=2!B;VQA(&]D;W-L86[A+B!.96WTOF5T92!S82`B
M"B)P<FEH;.%S:;LL(&O];2!N96)U9&4@5F&Y82!P;[YI861A=FMA('-C:';A
M;&5NX2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B1&]L;OT@:6YD97@B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R("+:<W!E8V@B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(@IM<V=S='(@(E!R:61A;FEE(%PB)7-<(B!D;R!S>7-TZ6UU
M(&)O;&\@^G-P9;ENZ2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@
M=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")6>6UA>F%N
M:64@^F1A:F]V('IO('-Y<W3I;74@<')E('!O=;[M=F%T9;5A(%PB)7-<(B!B
M;VQO(/IS<&6Y;NDN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B5GEM87IA;FEE(%PB
M)7-<(B!B;VQO(/IS<&6Y;NDN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E9Y;6%Z86YI92!<(B5S7"(@
M>F\@<WES=.EM=2!B;VQO(/IS<&6Y;NDN(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I
M9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB
M3N%V<F%T(&MU(&MO;F9I9W5RX6-I:2!B;VP@^G-P9;EN_2X@4')E('IO8G)A
M>F5N:64@>FUI96X@>FYO=G4@;F'H[71A:G1E("(*(G-T<N%N:W4N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(EKA;&]H82!K;VYF:6=U<N%C:64@8F]L82!U
M;&^^96[A+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("):X6QOOF[](&MO;F9I
M9W5R8>AN_2!S^F)O<B`E<R!B;VP@^G-P9;EN92!U;&^^96[]+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B06MT=6%L:7KA8VEA(%PB
M)7-<(B!B;VQA(/IS<&6Y;N$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(EKA<&ES("5S
M(&)O;"#Z<W!EN6[](@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5DX6XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E/Z:')N(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R
M(")6_6-H;V0@<VQN:V$B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*
M;7-G:60@(E-U;B!3970B"FUS9W-T<B`B6N%P860@<VQN:V$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N
M;GDB"FUS9W-T<B`B4VQN9>AN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B5OUC:&]D('-L
M;FMA(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")6
M_6-H;V0O>N%P860@<VQN:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B5OUC:&]D('-L
M;FMA.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS
M9VED(")3=6YS970B"FUS9W-T<B`B6N%P860@<VQN:V$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G
M<W1R("):X7!A9"!S;&YK83H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T
M<B`B2&]R;OT@:6YD97@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E!O9'!O<F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4')I
M97IV:7-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B4W9A;&)A<F0@82!*86X@36%Y96XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA
M;F0B"FUS9W-T<B`B4W9A>FEJ<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S
M='(@(JEVZ61S:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-38@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`BJ79A
M:NAI87)S:V\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM
M<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("):X7IN86UY(&\@<WEN
M8VAR;VYI>N%C:6D@=GEM87IA;NDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@;&EB
M+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B4WEN=&%K=&EC:^$@8VAY8F$@
M=B!P;V1M:65N:V%C:"!HM6%D86YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B
M(%)E<'5B;&EC(@IM<V=S='(@(E/]<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T
M<B`B0OIR:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B0OIR
M:V$@82!V971E<FYO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(D+Z<FMY(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G
M:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(E+A;F\@8OIR:WDB"@HC.B!L
M:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS
M9W-T<B`B5%-6('/Z8F]R(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ
M,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A8G6U:V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED
M(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@=&%B=;5K
M>2(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS
M9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@
M<')O<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO<W1I('1A8G6U:WDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&%I=V%N+"!P<F]V:6YC:6$@
MR.UN>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%DOFEK:7-T
M86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(E1A;GKA;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")#:66U
M.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`BVFQO:'DB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L
M97!H;VYE($YU;6)E<B(*;7-G<W1R(")496QE9O-N;F4@Z.US;&\B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B5&5P;&]T82!Z82!P;W-L961N^B!H;V1I;G4Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R
M92(*;7-G<W1R(")497!L;W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")497!L
M;W1A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5P;&]T83QB<B`O/B@E<TUA>"5S
M+R5S36EN)7,I("9D96<[)7,B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP
M.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("*I86)L\VYA(%PB)7-<(B!N96)O;&$@;N%J9&5N
MX2XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA
M=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B4W!RX79A(+EA8FSS;B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HS
M,S(U"FUS9VED(")497AT(@IM<V=S='(@(E1E>'0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B26)A
M('1E>'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(EIA<F]V
M;F%N:64@=&5X='4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'0@:&]R
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3D*;7-G:60@(E1H(@IM<V=S='(@(JET(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#<*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1H86IS:V\B"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z.#0P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")2;WJY[7)E;FEE($944"!N:64@:F4@9&]S
M='5P;NDN(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("));G1E9W+A8VEA
M($AO<F1E+TMO;&%B(&YE<&]D<&]R=6IE(%PB)7-<(B(*"B,Z(&QI8B].970O
M24U34"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("))35-0('KA>FYA;2!S82!N
M97!O9&%R:6QO('5L;[YINRXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B5')I961A($UA:6YT96YA;F-E
M.CH@<V$@;F5N8>CM=&%L82#Z<W!EN6YE(@H*(SH@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W
M(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(D]K;F\@<R!N87-T879E
M;FEA;6D@<V$@>F%T=F]R:6QO+B!+;VYI96,N(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,C,@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-3(*
M(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB061M
M:6YI<W1RX71O<B!M=7/M(&YA:V]N9FEG=7)O=F&[('!E<FUA;F5N=&[](&)A
M8VME;F0@<')E(%!RX79A+"!A:R!C:&-E=&4@(@HB<&]UONUV8;L@4'+A=F$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B
M26)A('-P;V1NX2!S=')A;F$B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DE$(.CM<VQO(&MO
M;G1A:W1U(&YE8F]L;R"Y<&5C:69I:V]V86[I+"!B;VQO('!O;F5C:&%NZ2!P
M<N%Z9&YE(&%L96)O(&YE8F]L;R`B"B)NX6ID96[I('8@9&%T86+A>F4N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B
M5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K="!B;VP@^G-P9;EN92!V;&^^
M96[](&1O(%;AN6AO(&%D<F5SX7)A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(DYA(&]V97)E;FEE('!O9'#M<V%N96H@<W!R
MX79Y(&IE('!OOF%D;W9A;OT@;V1D96QE;OT@8FQO:R!S(%!'4"!P;V1P:7-O
M;2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS
M9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T
M:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(DE$('IO>FYA;74@<'+M:F5M8V]V
M(&)U[R!N96)O;&\@N7!E8VEF:6MO=F%NZ2P@86QE8F\@8F]L;R!P;VYE8VAA
M;ND@<'+A>F1N92`B"B)A;&5B;R!N96)O;&\@;N%J9&5NZ2!V(&1A=&%BX7IE
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G
M:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB
M"FUS9W-T<B`B3F5B;VP@=7+H96[]('IO>FYA;2!P<NUJ96UC;W8N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N
M(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(JEI9G)O=F%N:64@=GF^861U:F4@8F5Z<&7H;ND@<')I<&]J96YI
M92`H:'1T<',I+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<W(&QI8B](;W)D92YP
M:'`Z-3$Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B4_IB;W(@)7,@8GD@
M;6%L(&]B<V%H;W9ANR!N87-T879E;FEE("5S+B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,3<P(&QI8B](;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N
M(@IM<V=S='(@(E/Z8F]R("5S(&)Y(&UA;"!O8G-A:&]V8;L@;FEE:W1O<ND@
M;F%S=&%V96YI82`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(R,PIM<V=I
M9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS
M9W-T<B`B6F1R;VIO=OT@82!C:66U;W;]('/Z8F]R(&UU<VEA(&)YNR!O9&QI
MN6[I+B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")3^F)O<B!N96]B<V%H
M;W9A;""^:6%D;F4@^F1A:F4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S
M='(@(DYA<VQE9'5J^B!H;&%V:>AK>2!T96IT;R!S<'+A=GD@=F\@9F]R;>%T
M92!M97-S86=E+W)F8S@R,BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N
M<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D-E;&]O8G)A>F]V
M:V]V_2!R9;YI;2!S</1S;V)U:F4@<')O8FSI;7D@=B!);G1E<FYE="!%>'!L
M;W)E<FD@:W;T;&D@8VAY8N%M("(*(G!R96AL:6%D8>AA+"!K=&]RZ2!S82!N
MX6T@;F5P;V1A<FEL;R!O8NUSNRX@3?2^=2!S82!P<F5J879INR!N97-P<N%V
M;GEM("(*(GIO8G)A>F5N[6TL(&-H_6)A:OIC:6UI(&9U;FMC:6%M:2!E9&ET
M;W)A(&$O86QE8F\@;N%H;V1N_6UI('#A9&UI("(*(G!R96AL:6%D8>AA+B!!
M:R!J92!6X;D@<WES=.EM(%=I;F1O=W,@.7@L(&IE('9EM6UI('!R879D97!O
M9&]B;NDL(+YE('-A("(*(GIO8G)A>NT@8VAY8F$@)T=E;F5R86P@4')O=&5C
M=&EO;B!&875L="<@82!B=61E=&4@;75S:66[(')EN71A<G1O=F&[('!OZ.UT
M8>@N(@HB7%QN7%QN5F%R;W9A;&D@<VUE(%;A<RX@4W1L8>AT92!P<F]S[6T@
M3TL@86L@;F%O>F%J(&-H8V5T92!P;W6^:;L@961I=&]R('8@(@HB8V5L;V]B
M<F%Z;W9K;W9O;2!R9;YI;64N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDR
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&$@7"(E<UPB(&)O;&$@
M=GEM87IA;N$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B26)A(+5A=N$@<W1R86YA(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B5')I961A($-R>7!T7W!G<#HZ('!O=')E8G5J
M92!P;WIN8;L@=6UI97-T;F5N:64@<')O9W)A;74@1VYU4$<N(@H*(SH@;&EB
M+TAO<F1E+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A
M<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E
M<G-T;V]D+B(*;7-G<W1R("(B"B)3<'+A=F$@;V1O<VQA;N$@)7,@<')E("5S
M(',@<')E9&UE=&]M(%PB)7-<(B!B;VQA('IO8G)A>F5NX2Y<;B(*(DYE97AI
M<W1U:F4@=KEA:R!ZX7)U:V$L(+YE('-P<N%V82!B;VQA('!R9>CM=&%NX2!A
M;&5B;R!P;V-H;W!E;N$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X.#$*
M;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O
M;7!O<V4@<&%G92(*;7-G<W1R(")-96YO+"!K=&]RZ2!S82!MX2!P;W6^:;L@
M<')I(&QI;FMO=F%N[2!N82!S='+A;FMU(&YA('#M<V%N:64@<W!RX78@(@H*
M(SH@;&EB+T9I;&4O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@
M9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B4&_H970@<&]L[2!M
M=7/M(&)YNR#H[7-L;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F
M;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(E1R
M:65D82!(;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS
M<VPN(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI
M;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(DYA<W1A=F5N:64@7"(E
M<UPB('-A(&YE<&]D87)I;&\@=6QOOFF[+"!P<F5T;[YE(&IE:&\@^F1A:F4@
M<')E:W)AZ'5J^B`B"B)M87AI;>%L;G4@<&]V;VQE;OH@=F6U:V]SNR(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VUS=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P
M;2YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z
M,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS
M-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W
M('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+B(*;7-G<W1R("(B"B)0<F]G<F%M('!O=;[M=F%N_2!N82!Z;V)R87IE
M;FEE('1O:'1O(/ID86IO=NEH;R!T>7!U("@E<RD@;F5B;VP@;N%J9&5N_2XB
M"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H
M87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R
M("):;F%K(&-I=.%C:64@;75S[2!B>;L@:F5D96X@>FYA:RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS
M9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("))
M8F$@<')A=N$@82"U87;A('-T<F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("))8F$@<')A=N$@<W1R86YA(@H*
M(SH@;&EB+T9I;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B3V1D9;5O
M=F'H(&UU<^T@8GF[(&IE9&5N('IN86LN(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=F5R(%PB
M)7-<(B!B;VP@=GEM87IA;OTN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(E-E<G9E<B!<(B5S7"(@8F]L
M('5L;[YE;OTN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"XB"FUS9W-T<B`BKFEA9&]SNR!O('!R:6ALX7-E;FEE("5S(&)O
M;&$@=GEM87IA;N$N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`BJ7!E8VEF:6MO=F%N_2!R:6%D;VL@;F5E>&ES='5J92XB"@HC
M.B!L:6(O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(D1OZ&%S;OT@<_IB;W(@7"(E<UPB(&YE97AI<W1U:F4N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,S,#`*;7-G:60@(E1H92!T97AT('EO=2!E;G1E
M<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS
M9W-T<B`B6F%D86[]('1E>'0@;FEE(&IE(')O=FYA:_T@86MO('1E>'0@;F$@
M;V)R87IO=FME+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(DEB82!H;W)NX2!A('-P;V1NX2!S=')A;F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("))8F$@
M:&]R;N$@<W1R86YA(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,R-PIM<V=I
M9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I
M;W5S('-T97`N(@IM<V=S='(@(DYA:')A;ND@^F1A:F4@<V$@;V0@<')E9&-H
MX61Z86KZ8V5H;R!K<F]K=2!S=')A=&EL:2XB"@HC.B!L:6(O2&]R9&4O1&%T
M82]C<W8N<&AP.C(V,B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,@IM<V=I
M9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G
M<W1R(").86AR86[]('/Z8F]R('-A(&YE<&]D87)I;&\@=6QOOFF[+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B0FQO:R!W96%T:&5R+F-O
M;2!N:64@:F4@9&]S='5P;OTN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4')I9>AI;F]K('3I;2!<(B5S7"(@
M;F5B;VP@;N%J9&5N_2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W
M.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G
M<W1R("*N:6%D;F4@;F%S=&%V96YI82!N:64@<_H@9&]S='5P;NDN(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM
M<V=S='(@(JYI861N92!A;'1E<FYA=.UV;F4@Z&%S=&D@;F5M;[YN;R!Z;V)R
M87IINR!V('1E;&4@<W!RX79Y+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#`U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+B(*;7-G<W1R("(B"B)6('1O;71O('!O;&D@:F4@<'+M;&FY('9EM6$@>FYA
M:V]V+B!:861A;&D@<W1E("5S('IN86MO=CL@;75S[71E('IA9&&[(&UE;F5J
M("(*(F%K;R`E<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(").87-T
M86QA(&-H>6)A('!R:2!P<FEDX79A;NT@7"(E<UPB(&1O('-Y<W3I;74Z("5S
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB3F%S=&%L82!C
M:'EB82!P<FD@;V1S=')A\F]V86[M('!O=;[M=F%T9;5S:_UC:"#Z9&%J;W8@
M7"(E<UPB('IO('-Y<W3I;74Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V
M:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(").87-T86QA
M(&-H>6)A('!R:2!O9'-T<F'R;W9A;NT@7"(E<UPB('IO('-Y<W3I;74Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B3F%S=&%L82!C:'EB82!P<FD@86MT=6%L:7KA8VEI(%PB)7-<(CH@)7,B
M"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$P"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B5GES:WET;VP@<V$@
M<')O8FSI;2!S(&YA:'+A=F%N[6T@<_IB;W)U.B"N:6%D96X@)7,@;F5B;VP@
M;F%H<F%N_2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA
M>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*
M(E9Y<VMY=&]L('-A('!R;V)LZ6T@<R!N86ARX79A;NUM('/Z8F]R=3H@)7,@
M8F]L(';DZ+GM(&%K;R!N86IVY.BY[2!P;W9O;&5N_2`B"B)L:6UI="`H)60@
M8F%J=&]V*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$W"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L
M;V%D960N(@IM<V=S='(@(E9Y<VMY=&]L('-A('!R;V)LZ6T@<R!U:VQA9&%N
M[6T@<_IB;W)U.B`E<R!B;VP@;F%H<F%N_2!L96X@Z&EA<W1OZ&YE+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M="(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!Z;V)R87IO=F%N[2!T96IT
M;R#H87-T:2!S<'+A=GDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C,Y(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82XB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@:6UP;W)T92#Z
M9&%J;W8@;R!K;VYT86MT92XB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP
M.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@:6UP
M;W)T92#Z9&%J;W8@:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*
M(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B).87-T86QA(&-H>6)A('8@
M:V]N9FEG=7)AZ&YO;2!F;W)M=6SA<FDN(%!R879D97!O9&]B;F4@<W1E(&YE
M=GEP;&YI;&D@(@HB<&^^861O=F%NZ2!P;VQE+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("(B"B).87-T86QA(&-H>6)A('!R:2!V>6MO;N%V86[M('5RZ&5N96H@9G5N
M:V-I92!A9')E<^%R82X@4')O<^UM('-K^G-T92!T;R`B"B)N97-K]'(N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(DYA
M<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2!D971A:6QO=B!K;VYT86MT
M=2X@4')O<^UM('-K^G-T92!T;R!N97-K]'(N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"B).87-T86QA(&-H>6)A('!R:2!A:W1U86QI>N%C:6D@
M>F]Z;F%M=2!P<NUJ96UC;W8N(%!R;W/M;2!S:_IS=&4@=&\@>FYO=G4N(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`B5&5N=&\@24U!4"!S97)V97(@;F5P;V1P;W)U:F4@
M>F1I9;5A;FEE('!R:67H:6YK;W8N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(E1O=&\@<')A=F1E
M<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!R87(N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(E1O
M=&\@<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!Z:7`N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,S0*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")4
M;W1O('!R879D97!O9&]B;F4@;FEE(&IE('!L871NZ2#H[7-L;R!K87)T>2XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB
M5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V(&-E>B!B
M<N%N=2!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI('!O
M;6]C;W4@2%144"!!4$DB"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B
M"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5&5N
M=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V(&-E>B!B<N%N
M=2!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)P;VUO8V]U($A45%`@05!)
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E1E
M;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L86YI92!S<'+A=B!C97H@8G+A
M;G4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@<&]M;V-O
M=2!(5%10($%022(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET
M86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(E1E;G1O(&]V
M;.%D8>@@=6UOOO)U:F4@<&]S:65L8;L@<W!RX79Y(&-E>B!33510(&-E>B!B
M<N%N=2!6;V1A9F]N92!)=&%L>2`B"B(H:6)A(&YA(.CM<VQA(%9O9&%F;VYE
M*2X@5GF^861U:F4@92UM86EL;W;](/KH970@5F]D869O;F4@271A;'D@*&AT
M='`Z+R\B"B)W=W<N,3DP+FET*2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Q(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#DP"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$Y(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3@V(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8P"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S`Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`R(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-38Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#0S(&QI8B](;W)D92]&;W)M+G!H<#HQ.38R(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#`Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,S(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#@R(&QI8B](;W)D92]&;W)M+G!H<#HR,34S"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C(U(&QI8B](;W)D92]&;W)M+G!H<#HR-#$R(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#4T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C0T(&QI8B](;W)D92]&;W)M+G!H<#HR.#$W(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3(V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,CDU(&QI8B](;W)D92]&
M;W)M+G!H<#HS.#`S(&QI8B](;W)D92]&;W)M+G!H<#HS.#$Q"FUS9VED(")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")4;W1O('!O;&4@:F4@
M<&]V:6YNZ2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V.0IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R
M(")4;W1O('!O;&4@;?2^92!O8G-A:&]V8;L@:6)A(.CM<VQA+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")4
M;W1O('!O;&4@;?2^92!O8G-A:&]V8;L@:6)A(.CM<VQA(&$@9'9O:F)O9&MU
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")4
M;W1O('!O;&4@;?2^92!O8G-A:&]V8;L@:6)A(&]S;6GH:V]VZ2!H;V1N;W1Y
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<R(*;7-G<W1R(")4;W1O('!O;&4@;75S[2!B>;L@>F]Z;F%M
M(.CM<V5L(&]D9&5L96[]8V@@Z&EA<FMO=2!A;&5B;R!M961Z97)O=2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S
M="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B5&]T;R!P;VQE(&UU<^T@
M8GF[('!L871NZ2#H[7-L;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R
M-0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q
M,C,T868G+B(*;7-G<W1R("(B"B)4;W1O('!O;&4@;75S[2!O8G-A:&]V8;L@
M:_-D(&9A<F)Y('8@N65S=&[A<W1K;W9O;2!F;W)MX71E(%)'0BP@;F%P<NUK
M;&%D("(*(B<C,3(S-&%F)RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z-38U
M"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M(@IM<V=S='(@(E1E;G1O(&9O<FUU;.%R('6^(&)O;"!S<')A8V]V86[]+B(*
M"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(E1O=&\@:F4@)7,N(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I
M<VET("5S(@IM<V=S='(@(B(*(E1O=&\@:F4@;V)J96MT($MO;&%B($=R;W5P
M=V%R92X@4')E('IO8G)A>F5N:64@=&]H=&\@;V)J96MT=2!P;W1R96)U:F5T
M92!E+2(*(FUA:6QO=NEH;R!K;&EE;G1A+"!K=&]R_2!R;WIU;6EE(&9O<FWA
M='4@2V]L86(@1W)O=7!W87)E+B!0<F4@>F]Z;F%M("(*(G1A:_UC:'1O(&ML
M:65N=&]V(&YA=KET[79T92!P<F]S[6T@)7,B"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O
M=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)4X71O('-P<N%V82!B
M;VQA(&YA<.US86[A('8@:6YE:B!A:V\@5F%M:2!P;W6^[79A;F5J('IN86MO
M=F5J('-A9&4@*"5S*2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R
M-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM
M<V=S='(@(E1O=&\@Z.US;&\@;75S[2!B>;L@;F%J;65N96H@,2XB"@HC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G
M<W1R(")496YT;R!S97)V97(@;F5D;VOAOF4@9&5K;VUP<FEM;W9ANR!S^F)O
M<GD@>FEP(&$@9WII<"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X
M,@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+B(*;7-G<W1R(")3>7-TZ6T@:F4@;6]M96YTX6QN92!D96%K=&EV;W9A;OTN
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B5.%T;R!H;V1N;W1A
M(&UU<^T@8GF[(.CM<V5L;N$N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")4;W1O(&]K;F\@
M;75S[2!B>;L@>F%V;VQA;ND@>B!O:VYA($YA<W1A=F5N[2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N
M9&5R(@IM<V=S='(@(DAR;65N:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(E1I8VME=',B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`BR&%S(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN
M9R(*;7-G<W1R(")4:6UE(%1R86-K:6YG(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)MX70@Z&%S
M=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,U"FUS9VED(")4:6UE('-E
M;&5C=&EO;B(*;7-G<W1R(")6_6)E<B#H87-U(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M
M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET=6QO:R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE
M("AT;V]L=&EP*3HB"FUS9W-T<B`B3F%D<&ES("AB=6)L:6YO=OT@=OUP:7,I
M.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS
M9VED(")4;R(*;7-G<W1R(")0<F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C4Q"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP
M;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA
M;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)0
M<F4@=OUB97(@=FEA8V5R_6-H('!O;&^^:65K(&1ROG1E('!OZ&%S(&ML:6MA
M;FEA(&MLX79E<W4@0V]N=')O;"`H4$,I(&%L96)O("(*(D-O;6UA;F0@*$UA
M8RDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I
M9"`B5&]D87DB"FUS9W-T<B`B1&YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O
M=7)C92(*;7-G<W1R(")0<F5P;OJ[('IO8G)A>F5N:64@>F1R;VIO=NEH;R!K
M\V1U($A434PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R
M("):86IT<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&]P(@IM<V=S='(@(E9R8V@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@
M*%]T;W`I(@IM<V=S='(@(E9R8VAN_2!RX6UE8R`H7W1O<"DB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G
M<W1R(")0<F5K;&%D>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B
M"FUS9W-T<B`B5')I;FED860@82!4;V)A9V\B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3<Y-`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")0<F%V
M9&$@86QE8F\@;F5P<F%V9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")5="(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N:7-K;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U
M<FME>2(*;7-G<W1R(")4=7)E8VMO(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#@*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B
M5'5R:W,@82!#86EC;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V
M86QU(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO
M=7(@8VAO:6-E.B`B"FUS9W-T<B`B6F%D86IT92!68;EU('9OM6)U.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N
M(&EN9&5X.B`B"FUS9W-T<B`B52Y6+B!I;F1E>#H@(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),(%;A
MN6AO('-K<FEP='4@<')E('-P<N%V=2!O(&1O<G7H96[M(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),
M.B(*;7-G<W1R(")54DPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G
M86YD82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86II;F$B"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C0Q-@IM<V=I9"`B56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5S:W5T
M;^AN:;L@<'+M<W1U<"!K(%9&4R!A9')E<^%R=2XB"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B
M"B).97!O9&%R:6QO('-A('!R:61ANR#O86RY:64@:6YF;W)MX6-I92!O('!O
M=;[M=F%T9;5O=FD@<')I(')E9VES='+A8VEI+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@>FUE;FF[('!RX79O('!R92!61E,@<_IB;W(@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S@Y(&QI8B]61E,O;75S<6PN<&AP
M.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A('IM96YINR!P<N%V;R!P<F4@5D93('/Z8F]R("5S+R5S+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HW-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z
M;65N:;L@;F$@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB
M)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U
M:V]SNR!S^F)O<G4@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-CDR
M(&QI8B]61E,O<W%L+G!H<#HQ,#$Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S:V]N
M=')O;&]V8;L@=F6U:V]SNR!S^F)O<G4@7"(E<R\E<UPB+B(*"B,Z(&QI8B](
M;W)D92]!=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-P;VII
MNR!S(%-13"!S97)V97)O;2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#4Y"FUS
M9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!S<&]J:;L@<&]M;V-O=2!34TPN(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HR,CD@;&EB+U9&4R]F:6QE+G!H<#HR,S0@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P.2!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&
M4R!F:6QE+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-K;W#M<F]V8;L@5D93
M('/Z8F]R+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@861R97/A
M<B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-3@@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,C4X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A('9Y='9O<FF[(%9&4R!A9')E<^%R+B(*"B,Z(&QI8B]61E,O
M;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@<_IB;W(N
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M(").97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!P<FEEZ&EN;VL@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C8Y"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").97!O9&%R:6QO('-A
M('9Y='9O<FF[('!RX7ID;GD@5D93('/Z8F]R+B(*"B,Z(&QI8B](;W)D92]#
M;VUP<F5S<R]T87(N<&AP.C<V(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H
M<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!D96MO;7!R:6UO=F&[(/ID86IE+B(*"B,Z(&QI
M8B]61E,O<VUB+G!H<#HR,C@@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M=GEM87IANR!<(B5S7"(L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GDN(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB
M.B`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%PB)7-<(CH@
M)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S4@;&EB+U9&4R]S<6PN<&AP
M.C,Y-2!L:6(O5D93+VUU<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@=GEM87IANR`E<RP@861R97/A<B!N:64@:F4@<'+A>F1N
M>2(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U-B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!R96MU
M<GKM=FYE('9Y;6%Z8;L@5D93(&%D<F5SX7(N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HS-#$@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN
M<&AP.C,S-0HC.B!L:6(O5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GEM87IANR!61E,@861R
M97/A<BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-#(P(&QI8B]61E,O<W%L+G!H
M<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA
M>F&[(%9&4R!A9')E<^%R.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C$R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93
M('/Z8F]R(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,P-R!L:6(O
M5D93+W-Q;"YP:'`Z,CDQ(&QI8B]61E,O;75S<6PN<&AP.C$V-PHC.B!L:6(O
M5D93+VUU<W%L+G!H<#HQ.#`@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@W(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<_IB;W(N(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO
M('-A('9Y;6%Z8;L@5D93('!R:67H:6YO:R!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@<F5K=7)Z[79N92!V>6UA>F&[(%9&4SH@)7,N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C@R,PIM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!U<NAINR!A
M:W1UX6QN>2!A9')E<^%R+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>FES=&F[('!O9')O8FYO
M<W1I(&\@8V5R=&EF:6OA=&4N(@H*(SH@;&EB+TYE="])35-0+G!H<#HT,S<@
M;&EB+TYE="])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`B3F5M;[YNZ2!N86AR8;L@9&5F:6[M8VEU("5S+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,C`P(&QI8B]61E,O9FEL92YP:'`Z,C`U(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$W-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G
M:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A('!R97-U;OJ[(%9&4R!S^F)O<BXB"@HC.B!L:6(O5D93+W-M8BYP
M:'`Z.3,@;&EB+U9&4R]S;6(N<&AP.C$P-B!L:6(O5D93+W-M8BYP:'`Z-C4R
M"B,Z(&QI8B]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(@7"(E<UPB+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,C@Q(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S."!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&]T
M=F]R:;L@5D93('/Z8F]R(&YA('KA<&ES+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z.#,@;&EB+U9&4R]F:6QE+G!H<#HQ,S0@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R
M(").97!O9&%R:6QO('-A(&]T=F]R:;L@5D93('/Z8F]R+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@;W1V;W)INR!K;VUP<FEM;W9A;OT@87)C:.UV+B(*"B,Z(&QI8B]61E,N
M<&AP.C@U-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S
M:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<F7H[71A
MNR!61E,@<_IB;W(@*&9U;FMC:6$@9FEL97-I>F4H*2!Z;'EH86QA*2XB"@HC
M.B!L:6(O5D93+G!H<#HX.#8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@<')EZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA(&=E=$9I;&53:7IE
M*"D@>FQY:&%L82DN(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO
M;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!P<F7H[71ANR!S^F)O<CHB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C8W,PIM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O9&%R:6QO('-A(.CM=&&[(&%D
M<F5SX7(@=F9S<F]O="XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E
M<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@<')E;65N;W9ANR`E<R!N82`E<SH@8VEEM6]V_2!P
M<FEEZ&EN;VL@=;X@97AI<W1U:F4B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A9')E<^%R
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A9')E<^%R.B`E<RXB
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C<Q(&QI8B]61E,O9G1P+G!H<#HS-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')E;65N;W9ANR!6
M1E,@<_IB;W(@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C$T(&QI
M8B]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R("5S+R5S+B(*"B,Z(&QI8B]6
M1E,O<W%L+G!H<#HS,C8@;&EB+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O
M;75S<6PN<&AP.C0U,@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR.3,@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R96UE;F]V8;L@
M5D93('/Z8F]R+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!S<'5S=&F[("=M:VES;V9S)RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!P<F5L;[YINR!T96YT;R!D;VMU;65N="!7;W)D(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C$U-"!L:6(O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>F%P[7-ANR!61E,@<_IB;W(@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3@S"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(").
M97!O9&%R:6QO('-A('IA<.US8;L@5D93('/Z8F]R("AF=6YK8VEA(&-O<'DH
M*2!Z;'EH86QA*2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X-2!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!Z87#M<V&[(/ID86IE(%9&4R!S^F)O<G4N(@H*(SH@
M;&EB+U9&4RYP:'`Z.#8Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@>F%P[7-ANR!61E,@<_IB;W(L(&MV\W1A(&IE('!R96MR;^AE;N$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E!O9.AI87)K;G5TZ2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R("):<G6Y:;L@>FUE;GDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;B(*;7-G<W1R("):<G6Y[2!P;W-L961N^B!A:V-I=2(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B
M3F5OZ&%KX79A;N$@;V1P;W9E[R!O9"!S97)V97)A('!OZ&%S('-P;VIE;FEA
M.B`B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B3F5OZ&%KX79A;N$@;V1P;W9E[R!O
M9"!S97)V97)A(&YA.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(").96YA<W1A
M=F5NX2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")5;FEC
M;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M
M:7)A=&5S(@IM<V=S='(@(E-P;VIE;ND@87)A8G-KZ2!E;6ERX71Y(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")69;5KX2!"<FETX6YI82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B4W!O:F5NZ2"Y=.%T
M>2!!;65R:6-KZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,SD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B2F5D;F]T:WDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,CD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N
M(@IM<V=S='(@(DYE>F[A;64B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+B(*;7-G<W1R(").97INX6UE(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2XB"FUS9W-T<B`B3F5Z;N%M92!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*
M;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D)O
M;&$@>F%D86[A(&YE<&QA=&[A(&QO:V%L:71A+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N
M86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(").97INX6UE('!O=;[M=F%T9;5S
M:^D@;65N;R!A;&5B;R!H97-L;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T
M:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(D]D<W1RX6YINR!L:6YK=2!Z
M(&%K='7A;&YE:&\@96QE;65N='4B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN
M<&AP.C,P,0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").97!O;65N;W9A;N$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y
M"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL
M;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@
M(B(*(DYE<')I=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6%J^B!Z(&)E>G!EZ&YO
M<W1N_6-H(&3T=F]D;W8@<'+M<W1U<"!K('9OM6+A;2`B"B)6>7-T<FEH;OJ[
M+TMO<.UR;W9ANR]6;&^^:;LN($ML:6MN:71E(&YA($]+(&$@>F]B<F%Z[2!S
M82!T96-H;FEC:^$@(@HB:6YF;W)MX6-I82!N82!S='+A;FME(&UO>FEL;&$N
M;W)G+"!K=&]RX2!6X7,@:6YF;W)M=6IE+"!A:V\@=6UOOFYINR!S:W)I<'1U
M("(*(G!R[7-T=7`@:R!S8VARX6YK92XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C
M;VQO<B(*;7-G<W1R(")/9'-T<N%N:;L@9F%R8G4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.CDR-PHC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B
M56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(DYE<&]D<&]R;W9A;ND@
M<F]ZN>UR96YI92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DW('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B
M"FUS9W-T<B`B06MT=6%L:7KA8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@
M)7,B"FUS9W-T<B`B06MT=6%L:7IO=F&[("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS
M9W-T<B`B06MT=6%L:7IO=F&[('!O=;[M=F%T9;5A(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D
M871E9"!<(B5S7"(N(@IM<V=S='(@(D%K='5A;&EZX6-I82!<(B5S7"(@8F]L
M82#Z<W!EN6[A+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS
M9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")3:W)I<'0@
M;F$@=7!G<F%D92!B;VP@=GEM87IA;OTN(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B3F%H<F&[(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(E:Y
M971K>2!S^F)O<GD@<R!K;VYF:6=U<N%C:6]U(&)O;&D@;F%H<F%NZ2!N82!S
M97)V97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R(")69;5KZ2!L871I;G-KZ2!P[7-M96[A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I
M9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")69;5KZ2!R[6US:V4@
MZ.US;&EC92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")0
M;W6^:;L@86MT=>%L;F4Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")0;W6^:;L@
M4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BXB"FUS9W-T<B`B4&]UOFET92!V('!R[7!A9&4L(+YE(&IE(&UE;F\O:&5S
M;&\@;V1L:;ENZ2!P<F4@24U34"!S97)V97(N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")0
M;W6^[79A=&6U(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F
M;W(@)7,N(@IM<V=S='(@(E!O=;[M=F%T9;4@)7,@;FEE(&IE(&%U=&]R:7IO
M=F%N_2!N82`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B4W!RX79A('!O=;[M=F%T9;5O
M=B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R
M($]P=&EO;G,B"FUS9W-T<B`B4&]UONUV871EM7-KZ2!N87-T879E;FEA(@H*
M(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS
M9W-T<B`B4F5G:7-T<N%C:6$@<&]UONUV871EM6$B"@HC.B!S:6=N=7`N<&AP
M.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")296=I<W1RX6-I82!P;W6^[79A
M=&6U;W8@8F]L82!P<F4@=&5N=&\@<WES=.EM('IA:^%Z86[A+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N
M;W0@9F]U;F0B"FUS9W-T<B`B4&]UONUV871EM7-K_2#ZZ&5T(&YE8F]L(&[A
M:F1E;OTB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z,34P"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,S('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE
M(@IM<V=S='(@(E!O=;[M=F%T9;5S:^D@;65N;R(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N
M86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B4&]UONUV871E
MM7-KZ2!M96YO(%PB)7-<(B!UOB!E>&ES='5J92XB"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M(")0;W6^[79A=&6U<VOI(&UE;F\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")0;W6^[79A
M=&6U<VOI(&UE;F\Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E!O
M=;[M=F%T96QI82!S>7-TZ6UU.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS
M9W-T<B`B57IB96MI<W1A;B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,38W(&QI
M8B]61E,O9FEL92YP:'`Z,C4Y"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R(")61E,@861R97/A<B!N965X:7-T=6IE+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T
M:6]N(@IM<V=S='(@(D1O=F]L96YK82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HX-S`*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B
M"FUS9W-T<B`B4&QA=&[I('5M:65S=&YE;FEA('IA:.#R86KZ.B`B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB
M"FUS9W-T<B`B4&QA=&YO<[LB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3DW(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R
M(")0;&%T;F]SNR!V(&UI;OIT86-H(&]D=&5R87HN(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C@V,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RXB"FUS9W-T<B`B2&]D;F]T82!P<F5K<F_H:6QA(&UA>&EMX6QN
M=2!DY;YK=2`E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T."!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(W,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,R,`HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-R!L:6(O2&]R9&4O1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(DAO9&YO
M='DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$Y,`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S
M='(@(DAO9&YO='DL('H@:W1O<OUC:"!S:2!M]+YE=&4@=GEB<F&[(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM
M<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T
M<B`B4')E;65N;N$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N
M97IU96QA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G
M:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")/=F5R96YI92!Z;'EH
M86QO("T@=.%T;R!S<'+A=F$@;6]H;&$@8GF[('-F86RY;W9A;N$N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB
M"FUS9W-T<B`B5F5R>FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(DUA;F&^;65N
M="!V97)Z:>TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R
M(")697)T:6OA;&YE('IA<F]V;F%N:64B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D
M:6YG(@IM<V=S='(@(E9E<G1I:^%L;F4@=GEP;&YE;FEE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86PZ(@IM<V=S='(@(E9E<G1I:^%L;F4Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*
M;7-G<W1R(")69;5M:2!V>7-O:^$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G
M<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.CDV.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(@IM<V=S='(@(EIO8G)A>FF[("5S(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M92(*;7-G<W1R("):;V)R87IINR!E>'1E<F[Z('=W=R!S='+A;FMU(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(EIO8G)A>FF[(&%K;R`E<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(D)R
M:71S:^D@4&%N96YS:^D@;W-T<F]V>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!5+E,N(@IM<V=S='(@(D%M97)I8VOI(%!A;F5N<VOI(&]S=')O=GDB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET
M>2(*;7-G<W1R(")6:61I=&6U;F]SNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6
M:61I=&6U;F]SNSH@(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS
M9W-T<B`B5F]D869O;F4@271A;'D@8V5Z(%--5%`B"@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!
M4DXB"FUS9W-T<B`B5D%23U9!3DE%(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E503UI/4DY%
M3DE%(2$A($]$4U12P=)412!32U))4%0@6B`E<R!25<A.12XB"@HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B
M"FUS9W-T<B`B5TE.(&-E>B!(5%10(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&
M=71U;F$B"FUS9W-T<B`B5V%L;&ES(&$@1G5T=6YA(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C0@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(E9A<F]V86YI92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*
M;7-G:60@(E=E(@IM<V=S='(@(E-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@
M(E!R961P;W9E[R!P;^AA<VEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM
M<V=S='(@(MID86IE(&\@<&_H87/M('!O<VMY='5J92(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E
M871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@
M(E=E8B(*;7-G<W1R(")796(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,Y"FUS9VED(")796(@4VET92(*;7-G<W1R(")75U<@<W1RX6YK82(*
M"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML
M>2(*;7-G<W1R(")4_;YD96YN92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(E9I=&%J=&4B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T
M;R`E<R(*;7-G<W1R(")6[71A(%;A<R`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")6:71A
M:G1E+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("):X7!A
M9&[A(%-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B2W1O<OH@87!L:6OA8VEU
M(&WA("5S('IO8G)A>FF[('!O('!R:6ALX7-E;NT_(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_(@IM<V=S='(@(D%K_2!J92!Z;F%K('!R92!O9&1E
MM6]V8>@_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G
M:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B06O]
M(&IE('IN86L@<')E(/IV;V1Z;W9K=3\B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L
M:6$@;6%P(@IM<V=S='(@(DUA<&$@075S='+A;&EE('!R92!S;'6^8G4@5VAE
M<F5I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@
M<&AA<V5S(@IM<V=S='(@(DMT;W+I(&;A>GDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DMT;W+I('KA<W5V
M;ND@;6]D=6QY('!O=F]L:;L@<')E(')O>KGM<F5N_2!T97AT;W;](&5D:71O
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("*I[7)K82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,3$T"FUS9VED(")7:61T:"!I;B!#4U,@=6YI
M=',B"FUS9W-T<B`BJ>UR:V$@=B!J961N;W1KX6-H($-34R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(JGM<FMA(&UE;G4@)7,@=K5A=F\@
M*'!R96IA=NT@<V$@<')I(.]A;+EO;2!P<FEH;.%S96[M*3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B
M5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(JGM<FMA('1A8G6U:WDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM
M<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")*961N;W1K82"Y[7)K>2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS
M9VED(")7:61T:#HB"FUS9W-T<B`BJ>UR:V$Z(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G
M<W1R(")6:65T;W(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")2X6YO('9I
M971O<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@
M<W!E960@:6X@:VYO=',B"FUS9W-T<B`B4OUC:&QO<[L@=F5T<F$@=B!U>FQO
M8V@B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB
M"FUS9W-T<B`B5FEE=&]R.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")6:65T;W(Z("(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S
M='(@(DWZ9')O<[LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX
M"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")7:7-H;&ES="(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")0<N%C
M82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K
M($%D9')E<W,B"FUS9W-T<B`B061R97-A(&1O('!RX6-E(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO
M;F4B"FUS9W-T<B`B5&5L96;S;B!D;R!P<N%C92(*"B,Z(&QI8B]&:6QE+T-3
M5BYP:'`Z,3DS(&QI8B]&:6QE+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP
M96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").97-P<N%V;GD@<&_H970@
M<&]L[2!N82!R:6%D:W4@)60N($_H86OA=F$@<V$@)60L(&YAN6QO('-A("5D
M+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B3F5S<'+A=FYY('!OZ&5T('!O;.TN($_H86OA=F$@
M<V$@)60L(&YAN6QO('-A("5D+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3$X
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R
M96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(EIL_2!O9F9S970@)60@<')I
M(.CM=&%N[2!61E,@<_IB;W)U+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*;7-G<W1R("):X6ML861NZ2!O8FUE9'IE;FEA(%@U
M,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED
M(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E!O=;YI=&EE
M(')O>KGM<F5NZ6AO(&NU^NAA(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE(@IM<V=S='(@(D%L=&5R;F%T[79N92!M96YO('-U8FIE:W1U
M(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("))
M9&5N=&EF:6OA=&]R(&NU^NAA('-U8FIE:W1U(%@U,#EV,R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS
M:6]N<R(*;7-G<W1R(")8-3`Y=C,@<F]ZN>UR96YI82(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")962(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,PIM<V=I9"`B65E962(*;7-G<W1R
M(")965E9(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B66%H;V\A(&UA<"(*
M"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L
M>2(*;7-G<W1R(")2;^AN92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE
M;65N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV
M,PIM<V=I9"`B665S(@IM<V=S='(@(D%N;R(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R
M964B"FUS9W-T<B`B4_IH;&%S[6TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4
M($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O
M(%=94TE764<N(@IM<V=S='(@(B(*(E-T92!V(%1%6%1/5D]-(%)%KDE-12X@
M4&]UOFET92!T;&'H:61L;R!;/#Y=(&YA('!R97!N=71I92!N87-PY+L@9&\@
M5UE325=91RXB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B3F5M]+YE=&4@=GET
M=F]R:;L@=FEA8R!A:V\@)60@8FQO:V]V+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T
M<B`B3FEE('-T92!A=71E;G1I9FEK;W9A;OTN(@H*(SH@;&EB+TAO<F1E+TED
M96YT:71Y+G!H<#HS,#<*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E9O(%9A
MN6]M('!L;F]M(&UE;F4@;F5M]+YE=&4@<&]UOFF[('IN86L@)UQ<)RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U.2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A
M9&1R97-S+B(*;7-G<W1R(").97IA9&%L:2!S=&4@<&QA=&[Z(&4M;6%I;&]V
M^B!A9')E<W4N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(Y,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B).975RZ&EL:2!S=&4@=GJ[86@@
M;65D>FD@OFEA9&YY;6D@<&]L:6%M:2!Z(&EM<&]R=&]V86[I:&\@<_IB;W)U
M(&$@(@HB>F]D<&]V961A:OIC:6UI('!OM6%M:2!V("5S+B(*"B,Z(&QI8B](
M;W)D92]!=71H+G!H<#HY.#0*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D
M(&]U="XB"FUS9W-T<B`B0F]L:2!S=&4@;V1H;.%S96[]+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C8U"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@
M86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"XB"FUS9W-T<B`B(@HB375S[71E('IA9&&[('!L871NZ2#H
M[7-L;R!M;V)I;&[I:&\@=&5L96;S;G4L(&MT;W+I(&]B<V%H=6IE(&EB82#H
M[7-L82!S("(*(G9O;&ET9;5N_6T@<')E9FEX;VT@)RLG('!R92!M961Z:6[A
M<F]D;OT@9F]R;>%T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3DR"FUS
M9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R
M(")-=7/M=&4@>F%D8;L@<&QA=&[Z(&AO9&YO='4N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B
M(@HB06)Y('-T92!M;VAL:2!P;W6^[79ANR!296=I<W1RX6-I92P@;75S[71E
M(&YA:G-K]'(@;F%K;VYF:6=U<F]V8;L@1&%T851R964@(@HB8F%C:V5N9"XB
M"@HC.B!L:6(O2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(DUU<^UT92!N86MO;F9I9W5R
M;W9ANR!61E,@8F%C:V5N9"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L
M96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM
M<V=S='(@(DUU<^UT92!P;W#M<V&[('!R;V)LZ6T@<')E9'3];2P@86MO(&]D
M;[EL971E('-P<N%V=2!O('!R;V)LZ6UE+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R
M(")-=7/M=&4@>F%D8;L@55),(&%D<F5S=2P@;F$@:W1O<OH@=.%T;R!L:6YK
M82!U:V%Z=6IE(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`B375S[71E('9Y8G)ANR!S97)V97(L(&MT;W+](&WA(&)Y
MNR!V>6UA>F%N_2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S
M='(@(DUU<^UT92!U<NAINR!M96YO('!O=;[M=F%T9;5A+"!K=&]RZ6AO(&-H
M8V5T92!V>6UA>F&[+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T
M<B`B375S[71E('5RZ&F[(&UE;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC
M971E('9Y;6%Z8;LN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DUU<^UT92!U<NAI
MNR!M96YO('!O=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!P<FED8;LN(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(DUU<^UT92!U<NAI
MNR!P;W6^[79A=&6U82P@:W1O<OT@<V$@;>$@86MT=6%L:7IO=F&[+B(*"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")-
M=7/M=&4@=7+H:;L@86MC:74L(&MT;W+A('-A(&WA('9Y:V]N8;LN(@H*(SH@
M;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@
M(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B
M375S[71E('IA9&&[(&UE;F\@;F]V96H@:V%T96?S<FEE+B(*"B,Z(&QI8B].
M970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N
M965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T
M<B`B375S[71E('IA9&&[('1A;&EA;G-K92!T96QE9O-N;F4@Z.US;&\B"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"B)0;&%T;F]SNR!68;EE:B!R96SA8VEE('!R92!A
M<&QI:^%C:74@)7,@=GEP<KEA;&$N(%!R;W/M;2!P<FEH;.%S=&4@<V$@>FYO
M=G4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G
M:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")68;EA($5M86EL;W;A
M(&%D<F5S82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B5F&Y82!%;6%I;&]VX2!A
M9')E<V$@<&]UOFETX2!P<F4@;V1C:.%D>F%J^F-U('!ON71U.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")6
M8;EE(&EN9F]R;>%C:64B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<V"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB5F&Y82!I;G1E<FYE=&]VX2!A9')E
M<V$@<V$@>FUE;FEL82!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0
M<F4@5F&Y=2`B"B)B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S
M:;LN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G
M:60@(EEO=7(@3F%M92(*;7-G<W1R(")68;EE(&UE;F\B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S
M97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E
M<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB
M875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB5N&Y(&%U=&5N
M=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('!R:63A=F%N:64@<&]UONUV
M871EM6]V+B!!:R!S:2"^96SA=&4@(@HB<&]UOFF[($AO<F1E(&YA('-P<N%V
M=2!P;W6^[79A=&6U<VO]8V@@^NAT;W8L(&UU<^UT92!P;W6^:;L@:6[]("(*
M(F%U=&5N=&EF:6MAZ&[](&)A8VME;F0N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(E;AN2!A=71E;G1I9FEK8>AN_2!M
M;V1U;"!N97!O9'!O<G5J92!Z;V)R87IO=F%N:64@>F]Z;F%M=2!P;W6^[79A
M=&6U;W8L("(*(F%L96)O(&)O;&$@=.%T;R!M;[YN;W.[('H@;F5J86OI:&\@
M9/1V;V1U('IA:^%Z86[A+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@
M=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B):9.$@<V$L(+YE(%;AN2!P
M<F5H;&EA9&'H('-A('IM96YI;"!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE
M("5S+B!0<F4@5F&Y=2`B"B)B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P
M<FEH;.%S:;LN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-34*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB
M"FUS9W-T<B`B5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK
M8VEU+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P
M<FEN="XB"FUS9W-T<B`B(@HB5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@
M=/IT;R!F=6YK8VEU('1L8>AE+B!3=&QAZ'1E($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB<')E('1L8>@N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V
M,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B5F&Y
M82!A:W1UX6QN82#H87-O=N$@>O-N83HB"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z.3@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R(")68;EA('!R961N87-T879E;N$@:61E;G1I=&$@
M8F]L82!Z;65N96[A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*
M;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B4')E9&YA
M<W1A=F5NX2!I9&5N=&ET83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B5F&Y92!M96YO
M.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.38*;7-G:60@(EEO=7(@;&]G
M:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(E!L871N;W.[(%;AN6AO(/KH='4@
M=GEP<KEA;&$N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<R(*;7-G<W1R(")68;EE(&YO=ND@:&5S;&\@<')E("5S(&IE.B`E
M<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O
M9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E9AN64@;F%S=&%V96YI82!B;VQI
M(&%K='5A;&EZ;W9A;ND@<')E('1O=&\@<V5D96YI92XB"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")68;EE(&YA<W1A=F5N:6$@8F]L:2!A
M:W1U86QI>F]V86[I+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S
M='(@(E9AN64@:&5S;&\@8F]L;R!O8FYO=F5NZ2(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB5F&Y92!H97-L
M;R!B;VQO(&]B;F]V96[I+"!S:V]N=')O;'5J=&4@<VD@<&^Y='4@82!P<FEH
M;.%S=&4@<V$@<R!68;GM;2!N;W;];2`B"B)H97-L;VTN(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.C<S,`IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B4&QA=&YO<[L@5N&Y:&\@:&5S;&$@=GEP<KEA;&$N
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9
M;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")68;EE('9Z9&EA;&5NZ2!S
M97)V97)Y.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(DIU:&]S;.%V:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB
M:6$B"FUS9W-T<B`B6F%M8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T
M<B`B6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G
M:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@;&EB+TAO<F1E+U1E>'0O
M1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T
M960@5&5X=%TB"FUS9W-T<B`B6U-K<GF[(&-I=&]V86[]('1E>'1=(@H*(SH@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R
M=%TB"FUS9W-T<B`B6U-P<N%V82!O('!R;V)LZ6UE72(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M(@IM<V=S='(@(EM:;V)R87IINR!C:71O=F%N_2!T97AT
M("TB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S
M+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6UIO8G)A>FF[(&-I=&]V86[]('1E
M>'0@+2`E<R!R:6%D:V]V72(*"B,Z(&QI8B](;W)D92YP:'`Z,3DU"B,L('!H
M<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");<FEA
M9&]K("5S('H@)7-=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-30U('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")?061M:6YI<W1RX6-I82(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM
M<V=I9"`B7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q
M"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q
M"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")?5GEM87IANR!R:6%D;VLB
M"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B
M7U-K=7!I;GDB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?
M2&5L<"(*;7-G<W1R(")?4&]M;V-N[6LB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E9L87-T;F]S=&D@7V]B<N%Z:W4N
M+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN
M(@IM<V=S='(@(E]0<FEH;.%S:;L@<V$B"@HC.B!L:6(O2&]R9&4O365N=2YP
M:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?3V1H;.%S:;L@<V$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?57!R
M879INR!L:6YK=2XN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G
M:60@(E]/<'1I;VYS(@IM<V=S='(@(E].87-T879E;FEA(@H*(SH@;&EB+V%P
M:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!RX79A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B3V1S
M=%]RX6YINR!L:6YK=2XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B
M7U-E='5P(@IM<V=S='(@(DYA7W-T879E;FEE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?
M5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")6;&%S=&YO<W1I(%]T86)U
MM6MY+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS
M9W-T<B`B4&]?=;[M=F%T96QI82(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3(P"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B861R97/A<B(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S
M<V5E('5N:VYO=VXB"FUS9W-T<B`B861R97/A="!N97INX6UY(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,3(*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@
M(FMA;&5N9.%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*
M;7-G<W1R(")B97IV971R:64B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS
M9W-T<B`B;F5P;V1A<FEL;R!S82!V>71V;W)INR!V_7-T=7!N_2!S^F)O<B(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N
M;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B;F5P;V1A<FEL;R!S82!O='9O<FF[
M('9S='5P(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM
M<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R(")K;&EK;FET92!S96TB"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")C:'EB82!P<FD@<&]UOFET[2!P
M<NUK87IO=NEH;R!R:6%D:W4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B
M8VAY8F$@:V]N9FEG=7+A8VEE(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG
M(@IM<V=S='(@(F-H_6)A(&3T;&6^:73]('-Y<W3I;6]V_2!S^F)O<B(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F
M;W)M870@97)R;W(B"FUS9W-T<B`B8VAY8F$@9F]R;>%T=2#Z9&%J;W8B"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y
M(&YO="!F;W5N9"(*;7-G<W1R(")P;VQOOFMA(&YE;N%J9&5NX2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F
M86QL:6YG(@IM<V=S='(@(FML97/A(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N
M<&AP.C@X,0IM<V=I9"`B9FEL92(*;7-G<W1R(")S^F)O<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B>F\@<VUE<G4@)7,@
M*"5S*2!R_6-H;&]SNV]U("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")NX7)A>F]V
M_2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#@*
M;7-G:60@(F@Z(@IM<V=S='(@(G8Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,U-PIM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@
M;F%M92!U;FMN;W=N(@IM<V=S='(@(FYE>F[A;64@;65N;R!H;W-T:71EM6$B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`B;VMA;;YI=&4B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM
M<V=S='(@(G8@<W!RX79E(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B8VAY
M8F$@=G-T=7!U+W;]<W1U<'4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S
M='(@(FEN=&5R;N$@8VAY8F$@<V]F=';I<G4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S
M='(@(G)I861K;W9=(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(G!OZ&%S('9Y=';A<F%N
M:6$@25-/(&YA<W1A;&$@8VAY8F$@;6MI<V]F<R`E9"(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS-C@*;7-G:60@(FUM(@IM<V=S
M='(@(FUM(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@(FUE;F\B"@HC
M.B!L:6(O2&]R9&4O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E
M9"(*;7-G<W1R(")N96EM<&QE;65N=&]V86[I(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(GIA=&EAM2!N96EM<&QE;65N=&]V86[I(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,#0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B<&]Z
M;N%M:V]V_2!B;&]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P
M97)C96YT(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<T"FUS
M9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")P<NUS='5P('IA;6EE
M=&YU=/TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B8F]D;W8B"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T
M92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")V>F1I86QE;N$@8VAY8F$@
M=B!P<F]T;VMO;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(G-T^G!A(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E
M('5N879A:6QA8FQE(@IM<V=S='(@(G-L=;YB82!N:64@:F4@9&]S='5P;N$B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I
M9F9E<F5N8V5S(@IM<V=S='(@(GIO8G)A>FF[(')O>F1I96QY(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M
M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!C97H@2%144"(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0*;7-G:60@
M(G-S(@IM<V=S='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R(")U<W3A;&5N
M_2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(G-Y<W3I;6]VX2!C:'EB82(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3(X"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B>F]Z;F%M(/IL;V@B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(F1OZ&%S
M;N$@8VAY8F$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;2(*;7-G<W1R(")P<F4@<&]T=G)D96YI92!Z861A:G1E
M(&AE<VQO(&1V86MRX70B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A
M9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R
M(")U;FEF:6MO=F%NZ2(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W
M"FUS9VED(")U;FYA;65D(@IM<V=S='(@(FYE<&]M96YO=F%NX2(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM
M<V=S='(@(F1E9FEN=6IE('!O=;[M=F%T9;4B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V
M0V%R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-#`*;7-G:60@(G<Z(@IM<V=S='(@(KDZ(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E
M871H97(N8V]M(@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O
M+W-L7U-)+G!O````````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`W,C$T,34`,3`T,3<S-C,P,#,`,#$V-#`W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@4VQO=F5N:6%N
M('1R86YS;&%T:6]N(&]F($AO<F1E"B,@0V]P>7)I9VAT("A#*2`R,#`U($AO
M<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@
M=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!-871I
M8R!$;VQA<B`\<VUE<VYI0&UE9&EU;2YS:3X*(PIM<V=I9"`B(@IM<V=S='(@
M(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2$]21$4@,RXP+C)<;B(*(E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`U+3`R+3(Q(#$U.C(U*S`Q,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@36%T:6,@1&]L87(@/'-M97-N:4!M961I=6TN<VD^7&XB
M"B),86YG=6%G92U496%M.B!3;&]V96ZYZ&EN85QN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI
M<V\M.#@U.2TR7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@9&YI
M(&YA>F%J*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B
M("A";&F^;FII8V$@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S
M='(@(B`H=B`E<R!D;F5H*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H9&%N97,I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O
M=RDB"FUS9W-T<B`B("AJ=71R:2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AVZ&5R
M86HI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B('!R:2`B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3FD@;6%P82(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@;FD@=7-T<F5Z;F$@:7IB
M:7)A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C
M;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S
M)R!N:2!N87-T879L:F5N('8@2&]R9&4@4F5G:7-T<G4N(@H*(SH@9G)A;65W
M;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B<E<R<@=7!O9&]B;&IE=F%L;FEK82!D<F5V97-A(&YI(&UO9V_H92!N86IT
M:2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES
M=&5M+B(*;7-G<W1R("(G)7,G(&IE(&)I;"!D;V1A;B!V('-I<W1E;2!S:W5P
M:6XN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P
M97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@:F4@8FEL(&1O9&%N
M('8@<VES=&5M(&1O=F]L:F5N:BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S
M='(@(B<E<R<@;FD@8FEL('5S='9A<FIE;CH@)7,N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U
M<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&EN("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M9&YE=FYA(&YA
M<&]V960B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!/8G9E
M<W1I;&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R
M("(E<R!0<G-T;FD@;V1T:7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S
M($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VXB"FUS9W-T<B`B)7,@5GID<KYE=F%N:F4@+2!0;W1R9&ET978B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HR,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(%-E
M='5P(@IM<V=S='(@(E].86UE<W1I=&5V(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M:6=N(%5P(@IM<V=S='(@(B5S(%!R:6IA=F$B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@
M;V8@06=R965M96YT(@IM<V=S='(@(B5S(%!O9V]J:2!U<&]R86)E(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(+YE(&]B
M<W1A:F$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@
M<')I("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P
M97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L
M;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(D]Z;F'H
M:71E(&]P97)A8VEJ;R]E+"!K:2!J:6@@OF5L:71E(&]P<F%V:71I+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:F4@>F%H=&5V86XB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&YI(&UO9V_H
M92!N86IT:2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@
M(B5S(&L@)7,@;V0@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*
M;7-G<W1R("(E<RUO=B!!9')E<V%R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A
M<B(*;7-G<W1R("(E<RUO=B!+;VQE9&%R(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E
M<&%D(@IM<V=S='(@(B5S+6]V82!"96QEOFYI8V$B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M(%1A<VML:7-T(@IM<V=S='(@(B5S+6]V(%-E>FYA;2!O<')A=FEL(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS
M9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"B,L
M(&9U>GIY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@<&EH86IOZ"`E
M<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E
M<R`E<R(*;7-G<W1R("(L('!I:&%J;^@@)7,@)7,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!S<')E;65N;&II=F\@;V0@)7,@
M9&\@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T
M.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(&EZ8F5R:2`M+2(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M
M870B"FUS9W-T<B`B,3(@57)N82!O8FQI:V$B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T(%5R
M;F$@;V)L:6MA(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G
M:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('5R(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM
M<V=S='(@(E!R96JY;FIA('-T<F%N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B6F$@=&$@8FQO:R!J92!Z86AT979A
M;F$@=7!O<F%B82!B87IE('!O9&%T:V]V+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R(")0<FFY;&\@:F4@9&\@=7-O9&YE(&YA<&%K92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B6F$@N6EF<FER86YJ92!S<&]R;^AI;&$@:F4@<&]T<F5B
M96X@:F%V;FD@4$=0(&ML:G7H+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(EIA
M(&]V97)I=&5V('!O9'!I<V%N96=A('-P;W)OZ&EL82!J92!Z86AT979A;B!J
M879N:2!01U`@:VQJ=>@N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(EIA(&1EN6EF<FER86YJ
M92!S<&]R;^AI;&$@<V\@<&]T<F5B;FD@:F%V;FD@4$=0(&ML:G7H+"!Z87-E
M8FYI(%!'4"!K;&IUZ"!I;B`B"B)G97-L;RXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB6F$@<&]D
M<&ES('-P;W)OZ&EL82!S;R!P;W1R96)N:2!J879N:2!01U`@:VQJ=>@L('IA
M<V5B;FD@4$=0(&ML:G7H(&EN(&=E<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@HB6F$@9&6Y:69R:7)A;FIE('-P;W)OZ&EL82!S;R!P;W1R96)N:2!J879N
M:2!3+TU)344@:VQJ=>@L('IA<V5B;FD@4R]-24U%("(*(FML:G7H(&EN(&=E
M<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q
M"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*
M(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB6F$@<&]D<&ES('-P;W)OZ&EL82!S
M;R!P;W1R96)N:2!J879N:2!3+TU)344@:VQJ=>@L('IA<V5B;FD@4R]-24U%
M(&ML:G7H(&EN("(*(F=E<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(EIA(+EI
M9G)I<F%N:F4@<W!O<F_H:6QA(&IE('!O=')E8F5N(&IA=FYI(%,O34E-12!K
M;&IUZ"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B3V)L86MI
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*
M(RP@9G5Z>GD*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B4&]P;VQD
M86X@<F%H96P@9&6^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3$*(RP@9G5Z>GD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B
M1&6^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B04T@4&QO:&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PHC+"!F=7IZ
M>0IM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N9;YN92!P;&]H
M92(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]0
M32(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@
M(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D\@
M=&5M('5R96IE=F%L;FEK=2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")/+BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S
M8F]T=&]M(@IM<V=S='(@(D%B<V)O='1O;2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*
M;7-G<W1R(")!8G-M:61D;&4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(D1O<W1O<"!P<FD@:7ID96QO=F%N:G4@5D93
M(&UA<&4@>F%V<FYJ96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92XB"FUS9W-T<B`B1&]S=&]P('!R:2!I>F1E;&]V86YJ=2!61E,@9&%T;W1E
M:V4@>F%V<FYJ96XN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@
M9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B5F&Y
M:2!P;V1A=&MI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED
M(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(D=E<VQO(')AZ'5N82(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(E)AZ'5N('IA;7)Z
M;FIE;BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED
M(")!8V-O=6YT:6YG(@IM<V=S='(@(E)AZ'5N;W9O9'-T=F\B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")$;V1A:B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!
M9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B1&]D86H@<&]D<VMU<&EN;R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B1&]D86H@<')A=FEC92!P;V1S:W5P:6YE(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G
M<W1R(")$;V1A:B!T=6MA:CHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A
M9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G
M<W1R(")$;V1A:B!N;W9O('-K=7!I;F\B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")$;V1A:B!N
M;W9O(&1O=F]L:F5N:F4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B1&]D86H@<&]D<VMU
M<&EN;R!K("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B1&]D86H@<')A=FEC92!P
M;V1S:W5P:6YE(&L@)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED
M(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B1&]D86H@;F]V96=A('5P;W)A
M8FYI:V$Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")$;V1A:B!S=&]L
M<&5C(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM
M<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(D1O9&%J(&YO=F4@Z&QA
M;F4B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!
M9&0@<&%I<B(*;7-G<W1R(")$;V1A:B!P87(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")$;V1A:B`E<R!M
M96YU(&MO="!-;WII;&QA(%-I9&5B87(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S
M(&)O;VLZ(@IM<V=S='(@(D1O9&%J('8@861R97-A<CHB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T
M;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B1&]D86H@=B!M;VH@861R97-A
M<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G
M<W1R(")$;V1A:B!U<&]R86)N:6MA(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I
M9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(D1O9&%L("<E
M<R<@=B!S:7-T96TL('9E;F1A<B!N:2!B:6QO(&UO9V_H92!D;V1A=&D@;F%D
M86QJ;FEH(&EN9F]R;6%C:6H@;R`B"B)V<&ES=3H@)7,N(@H*(SH@<VEG;G5P
M+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T
M<B`B1&]D86P@)R5S)R!V('-I<W1E;2X@6F1A:B!S92!L86AK;R!P<FEJ879I
M=&4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G
M:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B1&]D86IA
M;FIE('5P;W)A8FYI:V]V(&IE(&]N96UO9V_H96YO+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(DYA<VQO
M=FDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-A<B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!
M9&UI;FES=')A8VEJ82`M(&YA<W1A=FD@<')A=FEC92!O<W1A;&EH('5P;W)A
M8FYI:V]V(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%C:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,T,0IM<V=I9"`B061S(@IM<V=S='(@(E)E:VQA;64B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A;FEJ82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06R^:7)I:F$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W
M"FUS9VED(")!;&EA<R(*;7-G<W1R(")0<V5V9&]N:6TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED
M(")!;&EG;B(*;7-G<W1R(")0;W)A=FYA:B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB
M"FUS9W-T<B`B4&]R879N879A.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E9S:2(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@
M(E9S:2!/=F5R:F5N:2!U<&]R86)N:6MI(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*
M;7-G<W1R(")6<V4@4VMU<&EN92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H
M<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E9S82!$;W9O
M;&IE;FIA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B
M5G-E(+ET:7)I('-T<F%N:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R
M(")$;W9O;&D@=F7H(&YA<VQO=F]V(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\B"FUS9W-T<B`B1&]V;VQI(&YA<W1A=FET978@=7)E:F5N96=A('1I
M<&$@<V5Z;F%M83\B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O
M<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(JYE
M(&]B<W1A:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED
M(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=&EV;F$@
M24U34"!P<FEJ879A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM
M<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N
M871I=FYO($E-4U`@9V5S;&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!
M;'1E<FYA=&EV;F\@24U34"!U<&]R86)N:;EK;R!I;64B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL
M(&%D9')E<W,B"FUS9W-T<B`B06QT97)N871I=F5N(&4M<&^Y=&YI(&YA<VQO
M=B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:79N92!P<F5D;&]G92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L
M=&5R;F%T:79N;R!B97-E9&EL;SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R
M:6-A;B!386UO82(*;7-G<W1R(")!;65R:;EK82!386UO82(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`B5FYEN65N82!J92!B:6QA(&YA<&'H;F$@=G)E
M9&YO<W0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC
M+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB
M"FUS9W-T<B`B<')IN6QO(&IE(&1O(&YA<&%K93HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM
M<V=S='(@(D%N;VYI;65N('!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")/9&=O=F]R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;FMT87)T
M:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*
M;7-G<W1R(")!;G1I9W9A(&EN($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P;&EK
M86-I:F$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P
M<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B4V5Z;F%M(&%P;&EK86-I:B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N
M(&ES(')E861Y+B(*;7-G<W1R(")!<&QI:V%C:6IA(&IE('!R:7!R879L:F5N
M82XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B
M07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(E5P;W)A8FD@>F$@<&]D
M<F5J96YE(&]B:F5K=&4@=B!S:W5P;FD@<F%B:2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S
M='(@(D]D;V)R:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I
M9"`B07!R:6PB"FUS9W-T<B`B07!R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@
M(D%R86)S:V\@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B
M5F5L:6MO<W0@87)H:79S:V4@9&%T;W1E:V4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DEM
M92!A<FAI=F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M(@IM<V=S='(@(D%L:2!S=&4@<')E<')IZ&%N:2!D82"^96QI=&4@;V1S=')A
M;FET:2!P<FEJ879N;R!Z86AT979O('IA("5S(#\B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S
M7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")!;&D@<W1E('!R97!R
M:>AA;FD@9&$@OF5L:71E(&]D<W1R86YI>FD@)R5S)R!I;B!V<V4@<&]D<VMU
M<&EN93\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
M07)G96YT:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R
M(")!<FUE;FEJ82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED
M(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;FEJ<VMO("A!
M4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`B56UE=&YO<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B3W1O
M:R!!<V-E;G-I;VXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G
M:60@(D%S8VEI($%R="(*;7-G<W1R(")!<V-I:2!S;&EK92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC
M(%)E9VEO;B(*;7-G<W1R(")!>FEJ<VMA+U!A8VEF:;EK82!R96=I:F$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\B"FUS9W-T<B`B5G!R8;EA;2!Z82!P;W1R9&ET978@<')E9"!I>G9E9&)O
M(&]P97)A8VEJ('9Z9'*^979A;FIA/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R
M(")3=&]L<&-I('IA(&1O;&_H:71E=B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+B(*;7-G<W1R(")0;W-K=7,@8G)I<V%N:F$@;F5O8G-T;VIEZ&4@<VMU
M<&EN92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")0;W-K=7,@8G)I<V%N:F$@;F5O8G-T;VIEZ&5G82!D;W9O;&IE
M;FIA+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B4&]S:W5S('5R96IA;FIA(&YE;V)S=&]J9>AE9V$@9&]V;VQJ96YJ82XB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B4&]S
M:W5S('5R96IA;FIA(&YE;V)S=&]J9>AE('-K=7!N92!R86)E+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM
M<V=S='(@(D%T<FEB=71I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!=F=U<W0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B079S=')A
M;&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B079S
M=')I:F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X
M"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@4&]T<F5B;F5G82!)
M34%0(&1O9&%T:V$@;FD@;6]G;^AE(&YA:G1I+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G
M<W1R(")!=71H7V-Y<G5S.B!(<F)T96YI8V$@<')O9W)A;6$@;FEM82!P;W1R
M96)N:6@@>FUOOFYO<W1I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!0;W1R
M96)N96=A($E-05`@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@
M(B(*(D%U=&A?9G1P.B!0;W1R96)N96=A($944"!D;V1A=&MA(&YI(&UO9V_H
M92!N86IT:2X@0V]M<&EL86IT92!02%`@>B!M;[YN;W-T:F\@(@HB+2UE;F%B
M;&4M9G1P+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*
M;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z(%!O=')E8FYE9V$@24U!4"!D
M;V1A=&MA(&YI(&UO9V_H92!N86IT:2XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!0
M;W1R96)N96=A(&MR8C4@9&]D871K82!N:2!M;V=OZ&4@;F%J=&DN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?
M;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS
M9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!0;W1R96)N96=A($Q$05`@9&]D
M871K82!N:2!M;V=OZ&4@;F%J=&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z(%5P;W)A8FYI:V$@)7,@
M;FD@;6]G;^AE(&1O9&%T:2X@4W1R9;YN:6L@:F4@:F%V:6PZ(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS
M9W-T<B`B075T:%]L9&%P.B!5<&]R86)N:6MA("5S(&YI(&UO9V_H92!O9'-T
M<F%N:71I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!5<&]R86)N:6MA("5S
M(&YI(&UO9V_H92!P;W-O9&]B:71I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM
M<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@4&]T<F5B;F5G82!-0T%,(&1O
M9&%T:V$@;FD@;6]G;^AE(&YA:G1I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S
M;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB
M875T:#H@4&]T<F5B;F5G82!S;6)A=71H(&1O9&%T:V$@;FD@;6]G;^AE(&YA
M:G1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S
M='(@(D]V97)J86YJ92!N:2!U<W!E;&\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D]V
M97)J86YJ92!N:2!U<W!E;&\N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B3W9E<FIA;FIE('IA=G)N
M:F5N;R!N82!2041)55,@<W1R9;YN:6MU+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B3W9E<FIA;FIE(&YA($944"!S=')E
MOFYI:W4@;FD@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!3
M34(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B3W9E<FIA;FIE(&YA($944"!S
M=')EOFYI:W4@;FD@=7-P96QO+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(E!O
M;&IA(&MI('-O(&YA('9O;&IO.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B
M86EJ86XB"FUS9W-T<B`B07IE<F)A:F2^86XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")"3T9(
M($EZ9V]V;W)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")/
M>F%D:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D)A<G9A
M(&]Z861J82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*
M;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B3F5P<F%V
M:6QN;R!K97)B97)O<R!G97-L;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM
M<V=S='(@(DYE<')A=FEL;F\@:V5R8F5R;W,@=7!O<F%B;FFY:V\@:6UE+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR86IN(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/
M+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1IN6MO("A)4T\M.#@U.2TQ,RDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L861E
MN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A
M9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")/<VYO=FYE(&UA<&4@>B!I:V]N86UI
M("<E<R<@;FD@;6]G;^AE(&YA:G1I+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B
M"FUS9W-T<B`B3W-N;W9A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*
M;7-G<W1R(")"96QO<G5S:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU
M;2(*;7-G<W1R(")"96QG:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE
M(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM
M<V=S='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G
M<W1R(")"97)M=61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S
M='(@(D)U=&%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B4F]J<W1N:2!D
M86XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S4S"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L
M:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")";&]K82!<(B5S
M7"(@87!L:6MA8VEJ92!<(B5S7"(@;FD@;6]G;^AE(&YA:G1I+B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T
M=&EN9W,B"FUS9W-T<B`B3F%S=&%V:71V92!B;&]K82(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G
M<W1R(")6<G-T82!B;&]K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")+<F5P:V\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV:6IA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(E!R:6QJ=6)L:F5N92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O
M<F1E<B(*;7-G<W1R(")2;V(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R(")$96)E;&EN82!R;V)U.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B
M"FUS9W-T<B`B4F]B;W9I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N
M9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N82!I;B!(97)C96=O=FEN82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G
M<W1R(")/8F]J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S
M='(@(D)O8W9A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")3<&]D
M86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@
M(D]T;VL@0F]U=F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S
M='(@(D)R87II;&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN
M9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=&%N<VMO(&]Z96UL
M:F4@26YD:6IS:V5G82!O8V5A;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96H@1&%R=7-S86QA;2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEJ82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*
M;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B3WIN8>AE;FD@<V5Z;F%M
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U
M<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T
M<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*
M;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G
M:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(E1OZ&ME(&1I
M<W1R:6)U8VEJ92!#4DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B3&%S=&YO<W1I(&-?96QI8V4N+BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"B,L(&9U>GIY"FUS9VED(")#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(")397IN86T@
M<F%Z9&5L:71V92!N:2!B:6P@<&]D86XN(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(DMO;&5D87(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(DUI<FYO
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O
M9+YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M
M97)U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED
M(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)'97-L82!N:2!M
M;V=OZ&4@<&]N87-T879I=&D@879T;VUA=&GH;F\L(&MO;G1A:W1I<F%J=&4@
M<W9O:F5G82`B"B)A9&UI;FES=')A=&]R:F$N(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(D1A=&]T
M96ME(%PB)7-<(B!N:2!M;V=OZ&4@:7IB<FES871I+B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA
M;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")0;W9E>F%V92!Z($E-
M05`@<W1R9;YN:6MO;2!N:2!M;V=OZ&4@=GIP;W-T879I=&DZ("5S(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")$871O=&5K92!<(B5S7"(@;FD@;6]G;^AE(&EZ8G)I<V%T:2XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B4')E:VQIZ&DB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N
M8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E!R96ML:>AI('!R:6IA=F\@
M;F%P86ME(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B1&%T;W1E:V4@7"(E<UPB(&YI(&UO9V_H92!I>F)R:7-A=&DN
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B6F'H87-N92!M87!E(&YI(&UO9V_H92!N86IT:2XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(D)R97H@)W1A<F=E=$9I;&4G('!A<F%M971R82!N:2!M
M;V=OZ&4@;F%D86QJ979A=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")-87!E(%PB)7-<(B!N:2!M;V=O
MZ&4@;V1S=')A;FET:2XB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@
M8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(D]B:F5K=&$@;FD@;6]G;^AE(&]D
M<W1R86YI=&DL(&]B<W1A:F$@)60@<&]D;V)J96MT;W8N(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS
M9W-T<B`B(@HB4&]N;W9N82!R87IV<G-T:71E=B!N:2!M;V=OZ&$L(+ET979I
M;&\@<&]D86YI:"!V<&ES;W8@;F4@=7-T<F5Z82!S:')A;FIE;F5M=2`B"B*Y
M=&5V:6QU('9P:7-O=B!Z82!P;VYO=FYO(')A>G9R<W1I=&5V+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM
M<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BXB"FUS9W-T<B`B4W!O<F_H:6QA(&YI(&UO9V_H92!U<VUE<FET:2!N82!P
M;V1A;F\@N71E=FEL;RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E
M(@IM<V=S='(@(D-A<&4@5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM
M<V=S='(@(DYA<VQO=B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@
M86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R:6IE(&EN(&]Z;F%K92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")+86IM
M86YS:VD@;W1O:VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL
M;FD@=&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G
M<W1R("),87-T;F]S=&D@8V5L:6-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B4')A>F5N('!R;W-T;W(@=B!C96QI8VDZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I
M9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(DQA<W1N;W-T:2!C96QI8V4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")0<F%Z96X@<')O<W1O
M<B!M960@8V5L:6-A;6DZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL;FD@=&5L969O
M;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@
M*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT<VMO("A)4T\M.#@U.2TQ-"DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B4W)E9&EN82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R
M(")3<F5D;FIE869R:;EK82!297!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`B4W)E9&YJ965V<F]P<VMO("A)4T\M.#@U.2TR*2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#
M97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(E!O9')O8FYO<W1I('!O=')D
M:6QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*
M(RP@9G5Z>GD*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E!O
M9')O8FYO<W1I('!O=')D:6QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM
M<V=S='(@(E!O;&ET:6MA('!O=')D:6QA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")#:&%D(@IM<V=S='(@(LAA9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G
M:60@(D-H86YG92(*;7-G<W1R(")3<')E;65N:2(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B4&]N87-T879I=&4@=F&Y92!G97-L;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@
M(B(*(DYA<W1A=FD@:6UE(&EN(&YA<VQO=BP@:VD@9V$@;W-E8F4@=FED:6IO
M+"!K;R!B97)E:F\@:6X@;V1G;W9A<FIA:F\@;F$@=F&Y;R`B"B)E+7!ON71O
M+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B
M(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R
M(@IM<V=S='(@(EIN86LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN
M(@IM<V=S='(@(E!R979?97)I('!O=F5Z879O+BXN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0VAI;&4B"FUS9W-T<B`BR&EL92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-H:6YA(@IM<V=S='(@(DMI=&%J<VMA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*
M;7-G<W1R(")0;V5N;W-T879L:F5N;R!+:71A:G-K;R`H1T(R,S$R*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*2(*;7-G<W1R(")4<F%D:6-I;VYA;&YO($MI=&%J<VMO
M("A":6<U*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(DEZ8F5R:71E
M(&=E<VQO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B27IB97)I=&4@
M=7!O<F%B;FFY:V\@:6UE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y
M.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R
M("))>F)E<FET92!N8>AI;B!P<FEK87IA(&1A='5M;W8Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM
M<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I(@IM<V=S='(@(DEZ8F5R:71E(&EZ9VQE9"!S97IN86UA("AZ82!U<F5J
M96YE('-E>FYA;64I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES
M;&%N9"(*;7-G<W1R(")696QI:V]N;^AN:2!O=&]K(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B1&5F:6YI8VEJ92!R87IR961A("5S(&YI
M(&UO9V_H92!N86IT:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2F%S;F\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS
M9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(E!OZ&ES=&D@35-/
M9F9I8V4@;WIN8>AB92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@
M9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(E!OZ&ES=&D@=7!O
M<F%B;FEK82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G
M<W1R(")0;^AI<W1I('5P;W)A8FYI:V$Z("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S
M='(@(E!OZ&ES=&D@=7!O<F%B;FEK82(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T
M<B`B4&_H:7-T:2!P;V1A=&ME(&\@=7!O<F%B;FEK=2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED
M(")#;&5A<FEN9R!,871E(@IM<V=S='(@(D1EOB!P;WIN;R(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#
M;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")+;&EK;FD@>F$@;F%D86QJ979A
M;FIE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@
M(D-L:6-K871E;&P@<')E:V\@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B
M0VQO<V4@5VEN9&]W(@IM<V=S='(@(EIA<')I(&]K;F\B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(D]B;&%K
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V
M"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B3V)L8>AN
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B3V)L8>AN;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DME96QI
M;F=O=FD@;W1O:VDB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC
M.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E-K<FEJ('-T
M<F%N<VMI(&UE;G4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*
M;7-G<W1R(")3:W)I:B!R;V)O=F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO
M;6)I82(*;7-G<W1R(")+;VQU;6)I:F$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L
M;W(B"FUS9W-T<B`B0F%R=F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B0F%R=FYA('1A
M8F5L82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@
M(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B27IB:7)A(&)A<G9E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G
M:60@(D-O;',Z(@IM<V=S='(@(E-T;VQP8VDZ(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R
M(").87-L;W9I('-T;VQP8V5V(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(E-T<FEP:2(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")5
M:V%Z(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD
M(%-H96QL(@IM<V=S='(@(E5K87IN82!L=7!I;F$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T
M<B`B2V]M96YT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B26UE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)I(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I
M9"`B0V]M<&%N>2(*;7-G<W1R(")0;V1J971J92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(E)AZ'5N
M86QN:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PHC
M+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(E!O9V]J:2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM
M<V=S='(@(E!O9V]J:2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS
M9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(E)A>FQI
M:V4@=B!N87-T879I='9A:"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S
M+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B3F%S=&%V:71V92!J
M92!P;W1R96)N;R!P;W-O9&]B:71I+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM
M<V=S='(@(DYA<W1A=FD@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@
M(E!O=')D:2!G97-L;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S
M='(@(DMO;F=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")$96UO:W)A='-K82!2
M97!U8FQI:V$@2V]N9V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T
M<B`B4&]V97IA=F$@;FD@=7-P96QA+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M.B`B"FUS9W-T<B`B4&]V97IA=F$@;FD@=7-P96QA.B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")0;W9E
M>F%V82!N82!J879N:2!S=')EOFYI:R!S(&ML:G7H:2!Z879R;FIE;F$N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(E!O=F5Z879A
M(&YA(&IA=FYI('-T<F6^;FEK(',@:VQJ=>AI('IA=G)N:F5N82X@4F%Z;&]G
M.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*
M;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(E!O=F5Z879A(&YA($944"!S=')EOFYI:R!N:2!U<W!E;&$N(@H*(SH@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(E-T:6MI('-O(&)I
M;&D@=7-P9;EN;R!D;V1A;FD@=B!A9')E<V%R+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B5G-E8FEN82`G)7,G(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(").87!R
M96HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B
M0V]O:V]V:2!O=&]K:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM
M<V=I9"`B0V]O:VEE(@IM<V=S='(@(E!IN6MO=&5K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED
M(")#;W!Y(@IM<V=S='(@(DMO<&ER86HB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P
M>2!F86EL960Z("5S(@IM<V=S='(@(E!O=F5Z879A(&YI('5S<&5L83HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS
M9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W!I<F%J(&EZ8G)A;F\B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I
M9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T
M82!2:6-A(@IM<V=S='(@(DMO<W1A<FEK82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B4VQO;F]K;[GH96YA(&]B86QA(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B4$=0('-P
M;W)OZ&EL82!N:2!B:6QO(&UO9V_H92"Y:69R:7)A=&DN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(E!'4"!S<&]R;^AI;&$@;FD@
M8FEL;R!M;V=OZ&4@<&]D<&ES871I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B4W!O<F_H:6QA(&YI(&)I;&\@;6]G
M;^AE(+EI9G)I<F%T:2!S(%,O34E-12XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(E-P;W)OZ&EL82!N:2!B:6QO(&UO9V_H
M92!P;V1P:7-A=&D@<R!3+TU)344N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(")3=&EK82!N
M:2!B:6QO(&UO9V_H92!D;V1A=&DN("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B4&]V97IA=F$@;F$@3$1!4"!S=')EOFYI:R!N:2!B:6QA(&UO
M9V_H82XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R
M(")0;W9E>F%V82!N82!,1$%0('-T<F6^;FEK(&YI(&)I;&$@;6]G;^AA+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@
M8F%L86YC92X@)7,B"FUS9W-T<B`B4W1A;FIA(&YI(&)I;&\@;6]G;^AE('!R
M979E<FET:2X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E
M<B(*;7-G<W1R(")0;W9E>F%V82!N82!334(@<W1R9;YN:6L@;FD@=7-P96QA
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYA('-T<F6^;FEK("<E<R<@
M<V4@;FD@8FEL;R!M;V=OZ&4@<&]V97IA=&D@<')E:V\@1E10.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(E-E>FYA;6$@<F%Z9&5L:71V92!N
M:2!B:6QO(&UO9V_H92!I>F1E;&%T:2X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T82XB"FUS9W-T<B`B4$=0('!O9&%T:V]V(&YI(&)I;&\@;6]G
M;^AE(&1EN6EF<FER871I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82XB"FUS9W-T<B`B4R]-24U%('!O9&%T:V]V(&YI(&)I;&\@;6]G;^AE
M(&1EN6EF<FER871I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B4W1I:V$@;FD@8FEL
M;R!M;V=OZ&4@<&]B<FES871I+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(E-E>FYA;6$@<F%Z9&5L:71V92!N:2!B:6QO(&UO9V_H92!P;V)R
M:7-A=&DN("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")3:W)I<'1E('IA
M(&YA;65S=&ET978@<&]S;V1O8FET=F4@;FD@8FEL;R!M;V=OZ&4@:7IB<FES
M871I("<E<R<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED
M(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RXB"FUS9W-T<B`B4')E:F5M;FEK;W9E9V$@92UP;[ET;F5G82!N
M87-L;W9A(&YI(&)I;&\@;6]G;^AE('5G;W1O=FET:2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B0V5L;W1N96=A(&%D<F5S87)J82!N:2!M;V=OZ&4@<')E8G)A=&DN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B0V5L;W1N96=A('-E>FYA;6$@<F%Z9&5L:71V
M92!N:2!M;V=OZ&4@<')E8G)A=&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N
M(@IM<V=S='(@(D-E;&]T;F5G82!S97IN86UA('-E>FYA;6]V(')A>F1E;&ET
M=F4@;FD@;6]G;^AE('!R96)R871I+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B4W1R871E
M9VEJ92`G)7,G(&YI(&UO9V_H92!N86QOOFET:2XB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B56MA>B!M:V1I<B`G)7,G(&YI('5S<&5L+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B
M=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M4R!S=')EOFYI:V$@<R!K;&IUZ&D@;FD@8FEL;R!M;V=OZ&4@9&]B:71I(&IA
M=FYE9V$@:VQJ=>AA+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F
M;W(@=W)I=&EN9RXB"FUS9W-T<B`B)R5S)R!N:2!M;V=OZ&4@;V1P<F5T:2!Z
M82!P:7-A;FIE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B`E<RXB"FUS9W-T<B`B)7,@;FD@;6]G;^AE(&]D<')E=&DN(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B36]D=6QA($UA:6YT96YA;F-E
M7U1A<VL@;FD@;6]G;^AE(&]D<')E=&D@)7,B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DUA<&4@)R5S)R!N:2!M
M;V=OZ&4@;V1P<F5T:2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DES:V%N:F4@3$1!4"!S=')EOFYI:V$@;FD@=7-P96QO+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(E<R!N:2!M
M;V=OZ&4@<')E8G)A=&DN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*
M(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"B):82!Z86AT979A;F5G82!U<&]R86)N:6MA(&YI
M(&)I;&\@;6]G;^AE('!O;F%S=&%V:71I(&=E<VQA+B!.96MA=&5R:2!A;&D@
M=G-I("(*(G!O9&%T:VD@;FES;R!P<F%V:6QN:2X@4&]S:W5S:71E('!O;F]V
M;F\L(&%L:2!P82!S92!O8G)N:71E(&YA('-V;VIE9V$@(@HB<VMR8FYI:V$@
MZ&4@<&]T<F5B=6IE=&4@;F%D86QJ;F\@<&]M;^@N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E($%#3"(*;7-G<W1R(")!0TP@;FD@8FEL;R!M;V=OZ&4@<')E8G)A=&DB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")!9')E<V%R:F$@;FD@;6]G;^AE
M('!R96)R871I+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M4V5Z;F%M82!R87ID96QI='9E(&YI(&UO9V_H92!P<F5B<F%T:2X@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")397IN86UO=B!R87ID96QI
M='9E(&YI(&UO9V_H92!P<F5B<F%T:2X@)7,B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("):;6^^;F]S=&D@
M<W1R9;YN:6MA(&YI(&)I;&\@;6]G;^AE('5G;W1O=FET:2(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F%S=&%V:71E=B!N:2!B:6QO(&UO
M9V_H92!V<FYI=&D@;F$@<')V;W1N;R!S=&%N:F4B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(E5K87H@<FUD:7(@)R5S)R!N:2!U
M<W!E;"XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(").87-T879I=&5V("5S(&YI(&)I;&\@;6]G;^AE('-H<F%N
M:71I+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")687)N;W-T;F4@:V]P:6IE(&YA
M<W1A=FET978@;FD@8FEL;R!M;V=OZ&4@<VAR86YI=&DN(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B
M5F%R;F]S=&YE(&MO<&EJ92!N87-T879I=&5V(&YI(&)I;&\@;6]G;^AE('-H
M<F%N:71I.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")3:W)I<'1E
M('IA(&YA;65S=&ET978@<&]P<F%V:V]V(&YI(&)I;&\@;6]G;^AE('-H<F%N
M:71I('8Z("5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(E9A<FYO<W1N
M92!K;W!I:F4@;F%S=&%V:71E=B!N:2!B:6QO(&UO9V_H92!S:')A;FET:2`E
M<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O
M<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*
M(E!I<V%N:F4@;FD@;6]G;^AE+B!,86AK;R!U<&]R86)I=&4@<VMR:7!T;R!Z
M82!P;W-O9&]B:71E=B!A;&D@<F_H;F\@(@HB<VMO<&ER871E(&EZ=F]R;F\@
M:V]D;R!S<&]D86H@=B`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DES:V%N:F4@3$1!4"!S=')EOFYI:V$@;FD@=7-P
M96QO+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@
M(E!O=F5Z879E('H@)R5S)R!N:2!B:6QO(&UO9V_H92!P<F5K:6YI=&DN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<R(*;7-G<W1R(")3=&EK82!N:2!B:6QO(&UO9V_H92!P;W-O9&]B
M:71I+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(E-E>FYA;6$@
M<F%Z9&5L:71V92!N:2!B:6QO(&UO9V_H92!P;W-O9&]B:71I+B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B3F%S=&%V:71E=B!Z82`G)7,G(&YI(&)I;&\@
M;6]G;^AE('IA<&ES871I.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*
M(DUE;G5J82!-;WII;&QA(%-I9&5B87(@;FD@8FEL;R!M;V=OZ&4@;F%J=&DN
M(%!R97!R:>AA:G1E('-E+"!D82!J92!O9'!R="XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*
M;7-G<W1R(")5<&]R86)N:6MU("<E<R<@>F$@;6%P;R`G)7,G(&YI(&)I;&\@
M;6]G;^AE(&1O9&5L:71I('!R879I8SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B
M57!ON71E=F%N;R!B97-E9&EL;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(D1ROF%V
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O
M=7)S97,B"FUS9W-T<B`B5&7H86II(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A
M=&4B"FUS9W-T<B`B57-T=F%R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@
M;&EN:R(*;7-G<W1R(")5<W1V87)I('!O=F5Z879O(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@
M;F5W(&]N92(*;7-G<W1R(")5<W1V87)I(&YO=F\B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U
M8B!F;VQD97)S(@IM<V=S='(@(E5S='9A<FD@<&]D;6%P;R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E!R879I8V4@;&%S=&YI:V$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N
M=6UB97(B"FUS9W-T<B`BJ71E=FEL:V$@:W)E9&ET;F4@:V%R=&EC92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DAR=F&Y:V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0
M:&%S97,B"FUS9W-T<B`B5')E;G5T;F$@365N82(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*
M;7-G<W1R(")0<F%V:6-E(&QA<W1N:6MA(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I
M;64B"FUS9W-T<B`B5')E;G5T96X@Z&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R
M96YT(%523"!I<R(*;7-G<W1R(")4<F5N=71E;B!54DP@:F4B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E
M<G,B"FUS9W-T<B`B5')E;G5T;F$@365N82(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")4<F5N
M=71N;R!V<F5M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B5')E;G5T
M;F\@<W1A;FIE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B5')E
M;G5T96X@<W1I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+B(*;7-G<W1R(")0<FEL86=O9&D@;W!R879I;&$L(&MI
M('-E('IAOF5N96IO(&]B('!R:6IA=FD@=B`E<RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@
M(D-U="(*;7-G<W1R("))>G)EOFDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM
M<V=S='(@(DEZ<F6^:2!I>F)R86YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP
M<G5S(@IM<V=S='(@(D-I<&5R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-I<FEL:6-A
M("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@
M(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-I<FEL:6-A("A7
M:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G
M:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")#:7)I
M;&EC82]5:W)A:FEN82`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z
M96-H(%)E<'5B;&EC(@IM<V=S='(@(LAEN6MA(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@
M(D1N979N;R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T
M851R964@0G)O=W-E<B(*;7-G<W1R(")"<G-K86QN:6L@1&%T851R964B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S
M92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,SDY"FUS9VED(")$871E(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV
M960B"FUS9W-T<B`B1&%T=6T@<')E:F5M82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@
M(DEZ8FER82!D871U;6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@
M(D1A>2(*;7-G<W1R(")$86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L
M=6UN(@IM<V=S='(@(DEZ8G)IN6D@<W1O;'!E8R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*
M;7-G<W1R(")$96-E;6)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M
M8F5R<R(*;7-G<W1R(")$96-I;6%L:V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E
M;G0B"FUS9W-T<B`B6FUA;FJY86H@>F%M:6LB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ
M>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")0<FEV>F5T82!B87)V82(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS
M9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(E!R:79Z971A(&)A<G9A(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B
M1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")0<FEV>F5T82!I9&5N=&ET971A
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED
M(")$969A=6QT(%-H96QL(@IM<V=S='(@(E!R:79Z971A(&)A<G9A(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*
M;7-G<W1R(")$969I;FEC:6IE(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(DEZ8G)I
MN6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S
M='(@(DEZ8G)IN6D@8V5L:6-O(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@
M861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G
M<W1R("))>F)R:;EI('-K=7!I;F\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T
M<B`B27IB<FFY:2!V<G-T:6-O(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM
M<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B27IB<FFY:2!P<F%V
M:6-O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B
M27IB<FFY:2!I;B!P;^AI<W1I('-P;W)OZ&EL82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E
M;&5T92!C96QL(@IM<V=S='(@(DEZ8G)IN6D@8V5L:6-O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("))>F)R:;EI('-T;VQP96,B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("))>F)R:;EI(&]B<W1O
M:F7H;R!A;'1E<FYA=&EV;F\@<')E9&QO9V\B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B27IB
M<FFY:2!P<F%V:6-E('IA("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_(@IM<V=S='(@(DEZ8G)IN6D@<')A=FEC92!I;B!V<V4@<&]D<F5J
M96YE('!R879I8V4@>F$@)R5S)S\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W
M(@IM<V=S='(@(DEZ8G)IN6D@=G)S=&EC;R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R("))>F)R:;EI(&EZ8G)A;F\@:61E;G1I=&5T
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*
M;7-G<W1R("))>F)R:;EI('1R96YU=&5N('-T;VQP96,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G
M:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B27IB<FFY:2!T
M<F5N=71N;R!V<G-T:6-O(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")3:W)I<'1A('IA(&YA
M;65S=&ET978@<&]S;V1O8FET=F4@:7IB<FES86YA("<E<R<N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("+(87,@9&]S
M=&%V92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N
M<VMA(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G
M:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D]P:;EI('!R;V)L
M96TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B3W!I<R(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ(@IM<V=S='(@(E!O9')O8FYO<W1I("AT=61I('8@2&]R
M9&4@;&]G(&1A=&]T96MI*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B4&]D<F]B;F]S=&D@<V\@8FEL
M92!Z87!I<V%N92!Z82!S:W)B;FEK82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")287IV
M;VHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O
M:6YT(@IM<V=S='(@(E)O<V$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")2
M;W-A('8@>F%D;FII('5R:3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")2;W-A.B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X
M"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3;65R
M(&]D(&QE=F4@<')O=&D@9&5S;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F="(*;7-G<W1R(")3;65R(&]D(&1E<VYE('!R;W1I(&QE=FDB"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM
M<V=S='(@(DEM96YI:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*
M;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B4')I:V&^
M96T@Z&%S('8@;V)L:6MI(#(T('5R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(DUOOFYO
M<W1I('!R:6MA>F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B
M"FUS9W-T<B`B4')I:V&^:2!N87!O=F5D("A4048I(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*
M;7-G<W1R(")0<FEK8;YI(&YA<&]V960@*%1!1BDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$W"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G
M<W1R(")/8FQI:V$@<')I:V%Z82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*
M;7-G<W1R(")/8G9E<W1I;&\@;R!D:7-P;WII8VEJ:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D2^:6)U=&DB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T
M92(*;7-G<W1R(").92!P;V)R:;EI(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<"(*;7-G<W1R(").92!D;W-T;W!A:G1E(&1A=&]T96ME(&UA
M:6YT96YA;F-E+G!H<"!N97!O<W)E9&YO(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*
M;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B06QI('!R
M=F$@=G)S=&EC82!V<V5B=6IE(&EM96YA('!O;&H_(,AE(&1A+"!O9&ML:G5K
M86IT93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$
M;VUI;FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI
M8R(*;7-G<W1R(")$;VUI;FEK86YS:V$@<F5P=6)L:6MA(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A
M8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S
M='(@(E!R96YE<VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS
M9W-T<B`B4')E;F5S:2`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(%!(4"!S8W)I<'0N(@IM<V=S='(@(E!R96YE<VD@9V5N97)I<F%N;R!K;VYF
M:6=U<F%C:6IO(&MO="!02%`@<VMR:7!T;RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R
M(")397IN86T@>B!I>F)I<F\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=E(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T
M<B`B12UP;[ET82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV
M97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S
M='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B
M16MV861O<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T
M97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(E5R
M961I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(E5R961I(&)L;VLB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A
M9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R
M(")5<F5D:2!S:W5P:6YO(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E5R961I('!R879I8V\B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E5R961I('!R879I8V4B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E5R961I('!R879I8V4@
M>F$@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%
M9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")5<F5D:2!M;[YN;W-T:2!Z83HB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(E5R961I('!R879I8V4@>F$@)7,B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E5R961I('!R879I8V4@
M>F$@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D
M=6-A=&EO;B(*;7-G<W1R("))>F]B<F%Z8F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%9WEP="(*;7-G<W1R(")%9VEP="(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B
M;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N
M.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV
M861O<B(*;7-G<W1R(")386QV861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N
M="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@
M(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I
M;"(*;7-G<W1R(")%+7!ON71A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D4M<&^Y=&YI(&YA<VQO=B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%+7!ON71N:2!N87-L
M;W9I('-E(&UO<F%J;R!U:F5M871I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(D4M<&^Y=&$@<R!P;W1R9&ET=FEJ;R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT
M;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B"FUS
M9W-T<B`B4VUEN6MI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G
M<W1R(")0<F%Z;F\@<W!O<F_H:6QO+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L
M="XB"FUS9W-T<B`B4')A>F5N(')E>G5L=&%T+B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T
M97)M<R(*;7-G<W1R(")0<F%Z;F$@:7-K86QN82!P;VQJ82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S
M='(@(D]M;V=OZ&D@=G-T879L:F%N:F4@<VQI:R!I>B!&;W1O(&=A;&5R:6IE
M('8@8F5S961I;&\_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM
M<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T
M<B`B3VUO9V_H:2!D97-N:2!K;&EK('IA(&UE;G4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(DQE=&\@:V]N8V$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED
M(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")0;W9EZ&%J('5R96IE=F%L;FEK
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT
M97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME
M9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N
M("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*
M(E9N97-I=&4@=G!R8;EA;FIE+"!K:2!V86T@8F\@>F%S=&%V;&IE;F\L(.AE
M(&)O<W1E(+YE;&5L:2!P;VYA<W1A=FET:2!S=F]J92`B"B)G97-L;RP@;G!R
M+B`G2V%K;R!J92!I;64@=F&Y:2!D;VUAZ&D@OFEV86QI/R<Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B
M5'5K86H@=G!IN6D@55),('-L:6ME(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E
M<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T
M;W)I86P@1W5I;F5A(@IM<V=S='(@(D5K=F%T;W)I86QN82!'=FEN96IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5J82(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(DYA<&%K82(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B
M3F%P86MA('!R:2!P;[EI;&IA;FIU(&]D9V]V;W)A.B`E<RXB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*
M;7-G<W1R(").87!A:V$@<')I('!ON6EL:F%N:G4@;V1G;W9O<F$Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S(@IM<V=S='(@(DYA<&%K82!P<FD@<&^Y:6QJ86YJ=2!O9&=O=F]R83H@
M)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,B"FUS9W-T<B`B3F%P86MA('!R:2!P;[EI;&IA;FIU(&]D9V]V;W)A
M.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB
M"FUS9W-T<B`B3F%P86MA('H@92UP;[ET;FEM('-P;W)OZ&EL;VTN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(DYA<&%K82!P<FD@
M>F%P:7-O=F%N:G4@)R5S)RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA
M(@IM<V=S='(@(D5S=&]N:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P
M:6$B"FUS9W-T<B`B171I;W!I:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T
M<B`B179R;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I
M9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")6<V%K:6@@,34@;6EN=70B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"FUS9VED(")%=F5R>2`R
M(&UI;G5T97,B"FUS9W-T<B`B5G-A:VD@,B!M:6YU=&DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B5G-A:VEH(#,P('-E
M:W5N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S
M='(@(E9S86MI:"`U(&UI;G5T(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`B3V(@=G-A:VD@<')I:F%V:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")6<V%K92!P
M;VP@=7)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T
M<B`B5G-A:V\@;6EN=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")0<FEM97)I
M.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP
M:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*
M;7-G<W1R("))>G9E9&DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")287JY:7)I(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP
M86YD(%-I9&5B87(B"FUS9W-T<B`B4F%ZN6ER:2!S=')A;G-K:2!M96YU(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B
M17AP96-T960@)RDG(@IM<V=S='(@(E!R:>AA:V]V86P@)RDG(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")0
M<FGH86MO=F%N82!J92!B:6QA(&)E<V5D82!A;&D@<W1A=F5K('IA(&ES:V%N
M:F4@=B!N87)E:V]V86II:"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D1A
M='5M('9E;&IA=FYO<W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5K<W!O;F5N
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D)A<G9A(&]S<')E
M9&IA(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10
M('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")&5%`@<')E;F]S(&YA;65S=&ET
M=F4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G
M:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")0
M<F5N;W,@;F%S=&%V:71E=B!N:2!U<W!E;"XB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(E!O=F5Z879A(&YA($Q$05`@<W1R9;YN:6L@;FD@=7-P
M96QA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B
M4&]V97IA=F$@;F$@4TU"('-T<F6^;FEK(&YI('5S<&5L82XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B2V]P:7)A
M;FIE(&EZ(%PB)7-<(B!N:2!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HV.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")+;W!I<F%N:F4@=B!<(B5S7"(@
M;FD@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B5GIP;W-T879L:F%N:F4@;F]V92!305-,('!O=F5Z879E
M(&YI('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y
M-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(E!R
M96UI:V%N:F4@=B!<(B5S7"(@;FD@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(E!R96UI:V%N:F4@
M=B!<(B5S7"(@;FD@=7-P96QO+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(DQE<&\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RDB"FUS9W-T<B`B1F%L:VQA;F1S:VD@;W1O:VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9A<F]E(&]T;VMI(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T
M86P@17)R;W(Z(@IM<V=S='(@(E5S;V1N82!N87!A:V$A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(D9A:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R(")&86MS(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("+(=71I=&D@
M:F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED
M(")&965L<R!L:6ME.B`B"FUS9W-T<B`BR'5T:71I(&IE.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W
M(%-H;W=E<G,B"FUS9W-T<B`B3F5K86H@<&QO:"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"B,L(&9U>GIY"FUS9VED(")&
M97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N9;YN92!P;&]H92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I
M>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T
M"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I9+YI
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY
M"FUS9VED(")&:6QE(@IM<V=S='(@(F1A=&]T96MA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL92(*;7-G<W1R("*I=&5V:6QO(&1A=&]T96LZ("5S(&1A
M=&]T96MA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B
MJ71E=FEL;R!D871O=&5K.B`E<R!D871O=&5K(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@
M(E5P<F%V:71E;&H@9&%T;W1E:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@U"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B26UE(&1A=&]T96ME
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL
M92!S96QE8W1I;VXB"FUS9W-T<B`B27IB:7)A(&1A=&]T96ME(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B
M"FUS9W-T<B`B4')E;F]S(&1A=&]T96ME(&YA('-T<F6^;FEK(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B4')E;F]S:2!D871O=&5K
M(&YA('-T<F6^;FEK(&YI<V\@<&]D<')T:2XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YS:V$B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF
M(@IM<V=S='(@(E!R=F$@<&]L;W9I8V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R
M=&5R(@IM<V=S='(@(E!R=F$@Z&5T<G1I;F$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B
M"FUS9W-T<B`B1FEK<VYO(')A>FUE<FIE(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R
M(")0<F5Z<F-A;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("),96)D
M9>@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,0IM<V=I9"`B1F]G(@IM<V=S='(@(DUE9VQA(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0B"FUS9W-T<B`B36%P82`E<R!N92!O8G-T86IA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N
M="!#;VQO<B(*;7-G<W1R(")"87)V82!B97-E9&EL82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")(<F%N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,B"FUS9W-T<B`B6F$@8G)S:V%L;FEK92P@:VD@;F4@<&]D
M<&ER86IO('-L:6LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I
M9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B3F%P;W9E9"`H5$%&*2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B
M"B)$;F5V:2!N87!O=F5D:2`H;F%P;W9E9"!B;R!V<FYJ96YA('IA(&]B;VIE
M(&1A;B!I;B!N;^@[('9I<V]K82"Y=&5V:6QK82`B"B)L86AK;R!P;W9Z<F_H
M:2"Y:7)O:R!B;&]K*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B4W1E
M('!O>F%B:6QI(&=E<VQO/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(D]B<F%Z8VDB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B
M1F]R='5N:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B
M1F]R='5N92!T>7!E(@IM<V=S='(@(E9R<W1A($9O<G1U;F]V(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R
M(")&;W)T=6YI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(D9O<G1U;FD@,B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")/
M8G)A>F-I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I
M9"`B1F]R=V%R9',B"FUS9W-T<B`B4&]S<F5D;W9A;FIA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B
M"FUS9W-T<B`B4&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B3VMV
M:7)J:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N
M8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-I:F$L($UE
M<W1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R
M(")&<F%N8V]S:V$@1W5I86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC
M:"!0;VQY;F5S:6$B"FUS9W-T<B`B1G)A;F-O<VMA(%!O;&EN97II:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE
M<R(*;7-G<W1R(")*=;YN82!&<F%N8V]S:V$@;WIE;6QJ82(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R
M;VTB"FUS9W-T<B`B3V0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@
M(@IM<V=S='(@(D]D("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E!O;&YI
M(&]P:7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(E!O;&YA(&QU
M;F$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S
M='(@(E!O;&YO(&EM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S
M='(@(D=A8F]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@
M:6UA9V4@9G)O;2(*;7-G<W1R(")6>F5M:2!S;&EK;R!I>B!G86QE<FEJ92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L97)I:F$Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I:F$B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*
M;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N
M97)I<F%J("5S(&MO;F9I9W5R86-I:F\B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS
M9W-T<B`B1V5N97)I<F%N82!I>G9O<FYA(&MO9&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(DYE;>AI:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':&%N82(*;7-G<W1R(")'86YA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM
M<V=S='(@(DQA<W1N;R!I;64B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B4&]J9&DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R
M.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE
M(&ES:V%N:F4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED
M(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92!I<VMA;FIE(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I
M9"`B1W)A>7-C86QE(@IM<V=S='(@(E-I=FEN<VMA(&QE<W1V:6-A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")'<NAI:F$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(D=RN6MO("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F5E;FQA;F1I:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B061M:6YI<W1R86-I:F$@<VMU<&EN(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>2(*;7-G<W1R("));65N82!S:W5P:6X@;F4@<VUE:F\@8FET:2!P<F%Z
M;F$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B075T:%]L9&%P.B!5<&]R86)N:6MA("5S(&YI(&UO9V_H
M92!D;V1A=&DN(%-T<F6^;FEK(&IE(&IA=FEL.B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A
M<#H@57!O<F%B;FEK82`E<R!N:2!M;V=OZ&4@<&]S;V1O8FET:2(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*
M;7-G<W1R(")!=71H7VQD87`Z(%5P;W)A8FYI:V$@)7,@;FD@;6]G;^AE('!O
M<V]D;V)I=&DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q
M-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(E-K=7!I;F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E
M;&]U<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=F%T
M96UA;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED
M(")'=65R;G-E>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!R879I
M8V4@1V]S=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS
M9VED(")'=65S=&)O;VLB"FUS9W-T<B`B2VYJ:6=A(&=O<W1O=B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=FEN96IA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=V:6YE:F$@
M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M1W9A:F%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I
M9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R
M;W<N(@IM<V=S='(@(DA434Q!<F5A('-T<F%H;W!E=&YO(&YOZ&4@<&]B<FES
M871I('IA9&YJ92!C96QI8V4@=B!V<G-T:6-I+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@<W1R86AO<&5T;F\@
M;F_H92!P;V)R:7-A=&D@>F%D;FIE9V$@<W1O;'!C82!V('1A8F5L:2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A('-T
M<F%H;W!E=&YO(&YOZ&4@<&]B<FES871I('IA9&YJ92!V<G-T:6-E('8@=&%B
M96QI+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS
M9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M2%144"!O=F5R:F%N:F4@;FD@8FEL;R!N86ID96YO+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM
M(@IM<V=S='(@(DAA<V@M06QG;W)I=&5M(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B
M4V]P87)A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R
M(")';&%V82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B1VQA
M=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!O=&]K:2!I;B!-8T1O;F%L
M9"!O=&]K:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@
M(DYE=FEH=&$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B
M2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E=G-K;R`H25-/
M+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")6:;EI
M;F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R
M86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*
M;7-G:60@(DAE;'`B"FUS9W-T<B`B4&]M;^@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG
M(&5D:71O<B(*;7-G<W1R(")0;VUOZ"!P<FD@=7!O<F%B:2!U<F5J979A;&YI
M:V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(
M96QP97(B"FUS9W-T<B`B4&]M;^AN:6LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B4&]L;V)L82(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z(@IM<V=S='(@(E-L961I('IAZ&5T96L@9&%T;W1E:V4Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*
M;7-G:60@(DAI9V@B"FUS9W-T<B`B5FES;VMO(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R
M+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")$;U]M;W8B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*
M;7-G<W1R(")3=F5T:2!S961EOB`H5F%T:6MA;G-K82!M97-T;F$@9'*^879A
M*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B
M2&]M92(*;7-G<W1R(")$;VUO=B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S
M='(@(D1O;6'H:2!N87-L;W8B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-C0*(RP@9G5Z>GD*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(DEM
M96YI:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B1&]M8>AI('1E;&5F
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO
M;F1U<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T
M<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U
M"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YA<&'H;FD@)7,@6$U,
M('!O9&%T:VD@;F%J9&5N:2!V('-P;W)OZ&EL=2`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F]B96YO('-P;W)OZ&EL;R!N92!U
M<W1R97IA(&]B:F5K='4@)7,@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO
M(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($]B:F5K="!T:7!A("5S(&YI(&)I;"!N86ID96X@
M=B!S<&]R;^AI;'4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E
M<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@57-P9;EN;R!O9'-T<F%N:6P@)7,@7"(E<UPB(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@
M:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@
M97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);G1E9W)A8VEJ82!P
M;W1R96)U:F4@4$A0(&1O9&%T96L@)V1O;7AM;"<B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3FD@;6]G;^AE(&EZ9&5L
M871I(&YO=F5G82!834P@9')E=F5S82!Z82!O8FIE:W0@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3FD@;6]G;^AE(&]D<W1R86YI=&D@
M)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@3FD@;6]G;^AE('!R:61O8FET:2!-24U%
M($E$('IA(&1E;"!T:7!A("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@3FD@;6]G;^AE('-I;FAR;VYI>FER871I("5S(%PB)7-<
M(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.:2!M
M;V=OZ&4@<VEN:')O;FEZ:7)A=&D@<VMU<&YE(')A8F4Z("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!.97!O>FYA;F$@<VMU<&YA(')A8F$@7"(E<UPB(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM
M<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(E9O9&]R879N82#H<G1A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(E9O9&]R879N
M:2!O9&UI:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(E9O9&]R879N
M;SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(DMA:V\@<W1E('!R:;EL:2!D;R!S96T_
M("A0<F]S:6T@;V)V97-T:71E(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+;VQI
M:V\@<W1O;'!C978@OF5L:71E('-P;VII=&D_(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")+;VQI:V\@<&]L:B`H<W1O;'!C
M978I(&]B<W1A:F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2V]L:6MO('9R<W1I8R"^
M96QI=&4@<W!O:FET:3\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET
M>2(*;7-G<W1R(")6;&&^;F]S="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B5FQAOFYO
M<W0Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO
M<FES=',B"FUS9W-T<B`B2'5M;W)I<W1I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M(")(=6YG87)Y(@IM<V=S='(@(DUA9+YA<G-K82(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E5S='9A<FIA;FIE($E-
M05`@;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D)R:7-A;FIE($E-05`@
M;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DEZ9&5L879A(&MV
M;W1E($E-05`@;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*;7-G:60@(DE0($%D9')E<W,B"FUS
M9W-T<B`B25`@;F%S;&]V(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A
M<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("))4"!N87-L;W8@;FD@;F$@=F]L:F\N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@;F%S
M;&]V(&YI(&1O=F]L:F5N('8@0TE$4B!B;&]K=2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0
M(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B2W*Y:71E=B!Z86ML96YI
M='9E($E0(&YA<VQO=F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"
M969O<F4B"FUS9W-T<B`B5E]S=&%V:2!V<G-T:6-E('!R960B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YD:6IA(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*
M;7-G<W1R(")386UO(&EK;VYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R
M(")):V]N92!Z82`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")):V]N92!S('1E:W-T
M;VTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N
M=&ET>2=S(&YA;64Z(@IM<V=S='(@(DEM92!I9&5N=&ET971E.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(LAE('!R
M:6MA>B!N:2!P<F%V:6QE;BP@)7,@>F$@;V1P<G1J92!V(&YO=F5M(&]K;G4N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B+(92!P<FD@=7!O
M<F%B:2!);G1E<FYE="!%>'!L;W)E<FIA(&YE('9I9&ET92!I:V]N+"!O9&ML
M:G5K86IT92!T;R!M;[YN;W-T('IA("(*(F]N96UO9V_H96YJ92!P<F]Z;W)N
M;W-T:2!S;&EK(%!.1RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS
M9W-T<B`B(@HBR&4@=FED:71E('1O('-P;W)OZ&EL;RP@<VQI:V4@<&$@;F4L
M('-L:6MA(&MI(&IO(+YE;&ET92!P<F5N97-T:2!N92!M;W)E("(*(F)I=&D@
M<')I:V%Z86YA('8@=F&Y96T@8G)S:V%L;FEK=2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E!R961O9VQE9"!S;&EK93HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B55),('-L:6ME(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"!S;&EK
M93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G
M<W1R(")3;&EK82!I>B!G86QE<FEJ92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")3;&EK82!I>B!G86QE<FEJ93HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G
M92!U<&QO860B"FUS9W-T<B`B4')E;F]S('-L:6ME(&YA('-T<F6^;FEK(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G
M<W1R(")3;&EK92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@
M(E5V;WHL(&MO<F%K("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S
M(@IM<V=S='(@(E5V;[YE;F\@<&]L:F4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G
M<W1R(")5=F^^96YA('!O;&IA.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B5E]S=&%V:2!V<G-T:6-E('IA9&%J(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED
M("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(E!O9&%N
M82!N97!R879I;&YA(&MO9&$@9&5J86YJ82XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F5P<F%V
M:6QN;R!U<&]R86)N:;EK;R!I;64@:6XO86QI(&=E<VQO+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYE<')A=FEL;F\@=7!O<F%B;FFY:V\@
M:6UE(&%L:2!N87-L;W8N(%!O<VMU<VET92!P;VYO=FYO(&%L:2!K;VYT86MT
M:7)A:G1E("(*(G-V;VIE9V$@<VMR8FYI:V$L(.AE('!O=')E8G5J971E(&YA
M9&%L:FYO('!O;6_H+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R
M(")0;W9EZ&%J('IA;6EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*
M;7-G<W1R("));F1I:F$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B
M26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")0;W-A;65Z;FD@=7!O<F%B;FEK
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN
M9&]N97II:F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*
M;7-G<W1R("));F9O<FUA8VEJ92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO
M;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DYO8F5N82!M;[YN;W-T(&YI<V\@
M;F$@=F]L:F\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E
M<B(*;7-G<W1R(")6<W1A=FD@<W1?;VQP96,@>F%D86HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*
M;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R(")6<W1A=FD@<VQI:V\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS
M9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B5G-T879I('1A8F5L;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R(")6<W1A=FD@<W!L971N;R!P
M;W9E>F%V;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E
M(@IM<V=S='(@(E9S=&%V:2!S=&]?;'!E8R!S<')E9&%J(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R(")6<W1A=FD@;F]V('-T;VQP96,@>F$@=')E;G5T;FEM(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B5G-T879I(&YO=B!S=&]L<&5C('!R960@
M=')E;G5T;FEM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")6<V%V:2!N;W9O('9R<W1I
M8V\@>F$@=')E;G5T;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")6<W1A=FD@;F]V
M;R!V<G-T:6-O('!R960@=')E;G5T;F\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@
M(E9S=&%V:2!O9'-T879E:R!Z82!T<F5N=71N:6T@=F]Z;&FYZ&5M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R
M96YT(&YO9&4B"FUS9W-T<B`B5G-T879I(&]D<W1A=F5K('!R960@=')E;G5T
M;FEM('9O>FQIN>AE;2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS
M9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E9S=&%V
M:2!A;'1E<FYA=&EV;F\@<')E9&QO9V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T
M<B`B5G!IN6ET92!E+7!ON71N:2!N87-L;W8@:V%M;W(@OF5L:71E('!R96IE
M=&D@;F]V;R!G97-L;SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E
M<B(*;7-G<W1R(")6<W1A=FD@8V5L:6-O('IA9&%J(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B
M26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(E9S=&%V:2!C96QI8V\@<W!R
M961A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T
M<B`B5G-T879I('-T;VQP96,@>F%D86HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@
M8V]L=6UN(&)E9F]R92(*;7-G<W1R(")6<W1A=FD@<W1O;'!E8R!S<')E9&%J
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*
M;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R(")6<W1A=FD@<W!O<F_H
M:6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM
M<V=S='(@(E9S=&%V:2!O9'-T879E:R!S<')E9&%J(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R(")6<W1A=FD@;V1S
M=&%V96L@>F%D86HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM
M<V=S='(@(E9S=&%V:2!V<G-T:6-O('IA9&%J(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS
M97)T(')O=R!B969O<F4B"FUS9W-T<B`B5G-T879I('9R<W1I8V\@<W!R961A
M:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CHB"FUS9W-T<B`B5G!IN6ET92!O9&=O=F]R(&YA('IA:'1E=F%N;R!V87)N
M;W-T;F\@=G!R8;EA;FIE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B
M"FUS9W-T<B`B5G-T879I+U5R961I('-L:6MO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(E9S=&%V:2]5<F5D:2!P;W9E>F%V;R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S
M"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").97IA9&]S=&5N(&MR961I="!Z
M82!P;[EI;&IA;FIE(&YA('-E>FYA;6$@<F%Z<&^Y:6QJ86YJ82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B3F5Z861O<W1E
M;B!K<F5D:70N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM
M<V=I9"`B26YT96=E<B(*;7-G<W1R("*I=&5V:6QO(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S
M='(@(E-E>FYA;2"Y=&5V:6PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H
M57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(DYA<&'H96X@541(+B`H57-E
M<B!$871A($AE861E<BDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B
M"FUS9W-T<B`B3F%P8>AN:2!U;FEC;V1E('!O9&%T:VDN(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B3F%P8>AN82!A<&QI:V%C:6IA+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B
M26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B3F%P8>AE;B!)1"!P86ME=&$N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A
M;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")/9&1A;FD@;F%P8>AN:2!P
M;V1A=&MI+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+B(*;7-G<W1R(").87!AZ&YE;B!N87-L;W8@9&5S=&EN86-I:F4N(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B
M26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(").87!AZ&YA(&]B;&EK82!D
M871O=&5K92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@
M(DYA<&'H;F$@87!L:6MA8VEJ82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R(").87!AZ&YA(&%P;&EK86-I:F$N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W
M"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(").87!AZ&5N(&US
M9U]T>7!E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"XB"FUS9W-T<B`B3F%P8>AE;B!A;&D@;6%N:V%J;^@@87!I7VED+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S
M='(@(DYA<&'H;FD@86QI(&UA;FMA:F_H:2!P87)A;65T<FDN(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+B(*;7-G<W1R(").87!AZ&YA(&1O=F]L:F5N:F$@;F%D
M<F5J96YE9V$@;V)J96MT82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<G1N97(@:60N
M(@IM<V=S='(@(DYA<&'H;F$@9&]V;VQJ96YJ82!N861R96IE;F5G82!O8FIE
M:W1A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(").
M87!AZ&5N('!R;W1O:V]L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O
M;"XB"FUS9W-T<B`B3F%P8>AE;B!P<F]T;VMO;"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(").979E
M;&IA=F5N('!R96IE;6YI:SH@)R5S)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*
M;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(DYE=F5L:F%V
M96X@;V)J96MT('8@<VMU<&YI(')A8FDB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@
M<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(DYE=F5L:F%V96X@:7IV;W)N:2!N
M87-L;W8N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS
M9W-T<B`B3F%P8>AN:2!U;FEC;V1E('!O9&%T:VDN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@
M(DEN=F5N='5R82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB
M"FUS9W-T<B`B27IR9;YI(&EZ8G)A;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER<VMA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N
M(@IM<V=S='(@(DUA;F]V(&]T;VLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B
M"FUS9W-T<B`B27IO;&ER86YE(&YE=FEH=&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DES<F%E;"(*;7-G<W1R("))>G)A96PB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@
M(DEZ9&%J871E;&HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R(")0;[EE=FYO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("))=&%L:6IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%J:V$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM
M<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YU87(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N<VMA(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB
M"FUS9W-T<B`B2F%P;VYS:V\@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA
M<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E
M(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*
M97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M;W)D86XB"FUS9W-T<B`B2F]R9&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L
M:6HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI:B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU
M<W1I9GDB"FUS9W-T<B`B4&]R879N879A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I
M9GD@0V5N=&5R(@IM<V=S='(@(E-R961I;G-K82!P;W)A=FYA=F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(D]B;VIE<W1R86YS:V$@
M<&]R879N879A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R
M("),979A('!O<F%V;F%V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT
M(@IM<V=S='(@(D1E<VYA('!O<F%V;F%V82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA:'-T86XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R(")/8F1ROFEM(&]R:6=I;F%L/R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N:6IA(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@
M<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B
M97)O<R!S=')EOFYI:R!J92!Z879R;FEL(&]V97)I=&5V+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS
M9W-T<B`B3F]V:6YC:2!K97)N96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B
M27ID96QA=F$@:VQJ=>AA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B4')S
M=&YI(&]D=&ES(&ML:G7H82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")$;VR^:6YA
M(&ML:G7H82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5G)S=&$@:VQJ=>AA(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME
M>2!5<V%G92(*;7-G<W1R(")5<&]R86)A(&ML:G7H82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")+;&IU
MZ""^92!O8G-T86IA(&YA(&IA=FYE;2!S=')EOFYI:W4@<R!K;&IUZ&DN(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S
M='(@(D]T<F]C:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS
M9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5J
M82P@3&IU9'-K82!D96UO:W)A=&GH;F$@<F5P=6)L:6MA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]R96IA
M+"!R97!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I
M9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(DMO<F5J<VMO("A%54,M2U(I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5V86IT
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI
M<F=I>FES=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS
M9VED("),85]Y;W5T(@IM<V=S='(@(E!O<W1?879I=&5V(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T
M<B`B2F5Z:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$
M96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B6F%D
M;FIA('!O;&]V:6-A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L
M(&9U>GIY"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")0
M;VYA<W1A=FD@9V5S;&\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T
M<B`B6F%D;FIA(.AE=')T:6YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B6F%D;FIIZ"!P;W-O
M9&]B;&IE;F\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(EIA
M9&YJ82!P<FEJ879A.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M
M("5S(@IM<V=S='(@(EIA9&YJ82!P<FEJ879A.B`E<R!Z("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.
M979E<B(*;7-G<W1R("):861N:F$@<')I:F%V83H@3FEK;VQI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&%T=FEJ82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(EIA
M:V]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B4&]S=&%V:71E=B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*
M;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B4'5S
M=&ET92!P<F%Z;F\@>F$@8G)E>B!R;V)U(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED
M("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B3&5V;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(DQE=F$@9VQA=F$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"FUS9VED("),969T('9A
M;'5E<R(*;7-G<W1R("),979E('9R961N;W-T:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&\B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM
M<V=S='(@(DQJ=6)E>F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA
M(@IM<V=S='(@(DQI8F5R:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y
M86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8FEJ82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:6AT96ZY=&%J
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U
M"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(E)A:&QO(')O<V5N:F4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM
M<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")286AE;"!D9;XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG
M:'0@4F%I;B!%87)L>2(*;7-G<W1R(")286AE;"!D9;X@>F=O9&%J(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@
M(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")286AE;"!D9;X@<&]Z;F\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I
M9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B4F%H;&$@9&6^979N82!P
M;&]H82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")2
M86AE;"!D9;X@<R!S=')E;&%M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@
M(E)A:&QO('-N9;YE;FIE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S
M='(@(E)A:&QA('-N9;YN82!P;&]H82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EM97)I8VLB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM
M<V=S='(@(E!O=F5Z879A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T
M;SHB"FUS9W-T<B`B4&]V97IA=F$@:V&^92!N83HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S
M='(@(E!O=F6^:2!E+7!ON71N:2!N87-L;W8@;F$@<W1R86X@>F$@<V5S=&%V
M;&IA;FIE('-P;W)OZ&EL(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B
M4&]V97IA=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@
M(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"!P:;EK;W1E:R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B4V5Z;F%M
M("T@=7!O<F%B;FEK(&QA:&MO('9I9&D@;6%P;R(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(E!R
M:6MAOFD@8F%Z92!P;V1A=&MO=B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(E!R:6MA
MOFD@=&5M92!P;VUOZ&DB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS
M9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")0<FEK8;YI('1A8F5L92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),
M:7-T+4%R8VAI=F4B"FUS9W-T<B`B4V5Z;F%M+4%R:&EV(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L
M<"(*;7-G<W1R(")397IN86TM4&]M;^@B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R(")3
M97IN86TM260B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R(")397IN86TM3&%S=&YI
M:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS
M9VED("),:7-T+5!O<W0B"FUS9W-T<B`B4V5Z;F%M+4UE<W1O(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M
M4W5B<V-R:6)E(@IM<V=S='(@(E-E>FYA;2U.87)OZ&DB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U
M8G-C<FEB92(*;7-G<W1R(")397IN86TM3V1P;W9E:B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(E!R:6MA>F]V86YJ
M92!U<&]R86)N:6MO=B!J92!O;F5M;V=OZ&5N;RXB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")0<FEK87IO=F%N:F4@=7!O
M<F%B;FEK;W8@:F4@;VYE;6]G;^AE;F\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")0<FEK87IO=F%N:F4@=7!O<F%B;FEK;W8@:F4@
M;VYE;6]G;^AE;F\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS
M9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R871U<F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71V82(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@
M(DQO861I;F<N+BXB"FUS9W-T<B`B3F%L86=A;2XN+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*
M;7-G<W1R("),;VMA;&5N(.AA<SH@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B2F5Z:6L@
M:6X@Z&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED
M("),;V-A=&EO;B(*;7-G<W1R("),;VMA8VEJ82(*"B,Z(&QO9VEN+G!H<#HQ
M-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO
M9R!I;B(*;7-G<W1R(")0<FEJ879A(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3V1J879A(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*
M;7-G<W1R(")0<FEJ879A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B3W!R879I;&$@;V(@<')I
M:F%V:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4')I:F%V
M82!N:2!U<W!E;&$@>F%R861I(&YA<&'H;F\@=G!I<V%N96=A('5P;W)A8FYI
MN6ME9V$@:6UE;F$@86QI(&=E<VQA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")0<FEJ
M879A(&YI('5S<&5L82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B1&]L9V\@8F5S961I;&\B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS
M9W-T<B`B3&IU8F5Z96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(DYI>FMO(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")-86QE
M(&=RN6ME(.AR:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(DUA;&4@;&%T:6YS:V4@Z')K92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G
M:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B36%L92!R:6US:V4@
MN71E=FEL:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS
M9W-T<B`B3'5K<V5M8G5R9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%
M1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU4
M3D5&('!R:7!O;FMA(&YI('9S96)O=F%L82!P;V1A=&MO=BXB"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86MA;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DUA:V5D;VYI:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G
M:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-
M86EL(@IM<V=S='(@(E!ON71A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")5<')A=FET96QJ
M('!ON71E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@
M(E5S='9A<FD@<&]V95]Z879O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA
M=VDB"FUS9W-T<B`B36%L879I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA
M>7-I82(*;7-G<W1R(")-86QE>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%L9&EV97,B"FUS9W-T<B`B36%L9&EV:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB
M57)E9&ET92!S97IN86T@:V%T96=O<FEJ+"!S(&MA=&5R:6UI(+YE;&ET92!O
M>FYAZ&ET:2!O8FIE:W1E(&EN(&)A<G9E("(*(G!O=F5Z86YE(',@=&5M:2!K
M871E9V]R:6IA;6DN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("):96UL
M:F5V:60@36%P,C0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(EIE
M;6QJ979I9"!-87!1=65S="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I
M9"`B36%R8V@B"FUS9W-T<B`B36%R96,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB
M"FUS9W-T<B`B3V1M:6LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L
M86=S(@IM<V=S='(@(D]Z;F'H:2!Z(&]Z;F%K;R!6:61E;F\O3F4@=FED96YO
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*
M;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I(@IM<V=S='(@(D]Z;F'H:2!Z(&1R=6=I;6D@;WIN86MA;6D@
M*&YP<BX@4&]M96UB;F\O3V1G;W9O<FIE;F\I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS
M9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL;W9I(&]T
M;VMI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@
M(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P
M,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E5J96UA:F_H82!P
M;VQJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R
M(")-879R971A;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S
M(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@
M8W)E9&ET+B(*;7-G<W1R(")-86MS:6UA;&YI(&1O=F]L:F5N(&MR961I="XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G
M<W1R(")-86MS:6UA;&YO(+ET979I;&\@9&5L;W8@<W!O<F_H:6QA('!R96MO
M<F'H96YO+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B3F%J=FFY:F$@=&5M
M<&5R871U<F$@>F%D;FII:"`R-"!U<CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S
M='(@(DYA:G9IN6IA('1E;7!E<F%T=7)A('IA9&YJ:6@@-B!U<CH@(@H*(SH@
M;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A
M;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B
M"FUS9W-T<B`B36%K<VEM86QN82!D;VR^:6YA(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R
M(")-86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@
M(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@
M(DUE9&EC:6YE(@IM<V=S='(@(EID<F%V<W1V;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T
M<B`BR&QA;FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED
M(")-96YU(&UO9&4Z(@IM<V=S='(@(E9R<W1A(&UE;G5J83HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS
M9VED(")-97)G92!C96QL<R(*;7-G<W1R(")3<&]J:2!C96QI8V4B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")3<&]R;^AI;&\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*(E-P;W)OZ&EL;R!J92!B:6QO('5S<&6Y;F\@<')E=F5R:F5N;RP@<&]D
M<&ES;FEK;W9E9V$@<&]T<F1I;&$@<&$@;FD@8FEL;R`B"B)M;V=OZ&4@;W9E
M<FET:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B
M4W!O<F_H:6QO(&IE('!R971E:VQO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@
M(DUE<W-A9V4@='EP92(*;7-G<W1R(")6<G-T82!S<&]R;^AI;&$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS
M9W-T<B`B365T87(@5G)E;64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-
M971A<B!B;&]K(&YI(&YA('9O;&IO+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"B)-971A<B!B;&]K(&YI(&YA('9O;&IO+B!0;V1R;V)N
M;W-T:2!S;R!B:6QE(&QO9VER86YE('IA(&%D;6EN:7-T<F%T;W)J82XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A
M<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@
M(DUE=&]D82(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@
M9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(DUE=&]D82`G)7,G(&YI(&1E9FEN:7)A;F$B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FGH
M;F$@<VMA;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R
M(")-96MS:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]N97II:F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*
M;7-G:60@(DUI9&1L92(*;7-G<W1R(")3<F5D:6YA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP
M92(*;7-G<W1R(")4:7`@36EM92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B
M3F%J;FF^:F$@=&5M<&5R871U<F$@>F%D;FII:"`R-"!U<CH@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(DYA:FYIOFIA('1E;7!E<F%T=7)A('IA9&YJ:6@@
M-B!U<CH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*
M;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S-`IM<V=I9"`B36ER<F]R(@IM<V=S='(@(EIR8V%L:2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N
M96]U<R(*;7-G<W1R(")287IN;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")-86YJ:V$@4$5!4B!P
M86ME="!(5%107U)E<75E<W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V
M92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@
M(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(DMO;F9I9W5R86-I:F$@;6%N
M:FMA+B#(92"^96QI=&4@=7!O<F%B;&IA=&D@=&\@87!L:6MA8VEJ;RP@:F\@
M;6]R871E('ID86H@(@HB9V5N97)I<F%T:2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I
M;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B36%N:FMA($E$('-P;W)OZ&EL82XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@
M36%I;"XB"FUS9W-T<B`B36%N:FMA('IA:'1E=F%N(%!%05(@<&%K970@36%I
M;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B
M36%N:FMA($E$('-E:F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B4&\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL
M(@IM<V=S='(@(DUO8FEL;F$@<&^Y=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T
M<B`B6FUE<FYO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G
M:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&%T=6T@<W!R96UE;6)E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(E-P<F5M96YI(%52
M3"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS
M9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&%V:6IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86MO
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG
M;VQI:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED
M(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-97-E8R!I;B!L971O(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I
M9"`B36]N=&AL>2(*;7-G<W1R(")-97-EZ&YO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G-E<F%T(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R("),=6YI;F4@;65N92(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<F]K
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S
M"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B4')E=&6^;F\@:F%S;F\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM
M<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")0<F5T9;YN;R!O8FQAZ&YO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*
M;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")0<F5T9;YN;R!S;V[H;F\B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G
M:60@(DUO=F4@1&]W;B(*;7-G<W1R(")0<F5M86MN:2!D;VPB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R(")0<F5M86MN:2!L979O(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM
M<V=S='(@(E!R96UA:VYI(&1E<VYO(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E!R
M96UA:VYI(&=O<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")0<F5M86MN
M:2!D;VPB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B4')E;6%K;FD@9V]R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M
M8FEK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B
M375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(E9EZ"UN:79O
M:G-K:2!S97IN86UI('H@:7IB:7)O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R
M"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B5F7H:W)A=&YA
M(&EZ8FER82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G
M:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B36]J(')AZ'5N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E9AN6D@<&]D871K:2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G
M<W1R(")-;VH@<&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")/8FQI:V$@
M;6]J96=A('!O<G1A;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B
M"FUS9W-T<B`B36%J;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B
M"FUS9W-T<B`B3D4L(&YE('-T<FEN:F%M('-E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B26UE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;6)I:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B3FEZ;WIE;7-K
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*
M;7-G<W1R(").:7IO>F5M<VMI($%N=&EL:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%52
M3"(*;7-G<W1R(")/<VYO=FYI($YE='-C87!E(%523"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#
M02!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@>F$@<')E:VQI8R!P;W1R
M9&EL82!.971S8V%P92!#02(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM
M<V=S='(@(E523"!P;VQI=&EK92!.971S8V%P92!#02(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!2
M96YE=V%L(%523"(*;7-G<W1R(")54DP@>F$@;V)N;W9O('!O=')D:6QA($YE
M='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(E52
M3"!Z82!P<F5K;&EC('!O=')D:6QA($YE='-C87!E(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-3
M3"!S97)V97(@;F%M92(*;7-G<W1R("));64@<W1R9;YN:6MA($YE='-C87!E
M(%-33"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@
M(DMO;65N=&%R('!O=')D:6QA($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E('1Y<&4B"FUS9W-T<B`B5G)S=&$@<&]T<F1I;&$@3F5T<V-A<&4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W
M;W)K(@IM<V=S='(@(D]M<F6^:F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R
M(").:6MO;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B
M"FUS9W-T<B`B3F]V82!+86QE9&]N:6IA(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E
M9V]R>2(*;7-G<W1R(").;W9A(&MA=&5G;W)I:F$B"@HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R
M(")397-T879I('-P;W)OZ&EL;R`H)7,I(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(")-;&%J(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S
M97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F]V;R!U<&]R86)N:;EK;R!I
M;64@*&]P8VEJ<VMO*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA
M;F0B"FUS9W-T<B`B3F]V82!:96QA;F1I:F$B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R
M9"(*;7-G<W1R(")'97-L;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I
M;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R
M9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(D=E<VQI('-E(&UO<F%T82!U:F5M
M871I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F]V
M;R!O:VYO("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#D*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]V:6-E(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P
M<R(*;7-G<W1R(").;W9IZ&MA<G-K92!S:W5P:6YE(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B
M3F%P<F5J(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS
M9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(DYA<VQE9&YJ82!M96YA(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T:6]N<R(*
M;7-G<W1R(").87-L961N:F4@;6^^;F]S=&DB"@HC.B!F<F%M97=O<FLO54DO
M54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T
M<B`B3F%P<F5J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS
M9W-T<B`B3FEK87)A9W9A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*
M;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*
M;7-G<W1R(").:6=E<FEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYOZ"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS
M9W-T<B`B3F4B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL
M.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(E!O9&%T:VD@:V]N9FEG
M=7)A8VEJ92!N:7-O(&YA('9O;&IO+"!R87IL:6L@;FD@;6]G;^AE('!O:V%Z
M871I+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").82!V;VQJ;R!N:2!N;V)E;F5G82!N
M8>AI;F$@>F$@:7ID96QA=F\@25-/('!O<VYE=&MO=BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@
M(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(")0<F5D;&]G82!P86ME=&$@
M;F4@;V)S=&%J82XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED
M(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*
M;7-G<W1R(").82"^96QJ96YE;2!P;VQOOF%J=2!B;&]K(&YE(&]B<W1A:F$B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("):82!-0T%,(&%V=&5N=&EK86-I:F\@;FD@8FEL;R!P
M;V1A=&YO(&EM92!K;VQE9&%R:F$N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B0G)E>B!S<')E;65M
M8F4N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(E!O9')E:F5N92!P<F%V:6-E('-E('1E:B!P<F%V:6-I
M(&QA:&MO(&1O9&%J;RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*
M;7-G<W1R("));F9O<FUA8VEJ92!O(&MO;F9I9W5R86-I:FD@>F$@)7,@;FES
M;R!B:6QE('!O9&%N92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N(@IM<V=S='(@(DEN9F]R;6%C:6IE(&\@:V]N
M9FEG=7)A8VEJ:2!Z82!&5%`@5D93(&YI<V\@8FEL92!P;V1A;F4N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*
M;7-G<W1R("));F9O<FUA8VEJ92!O(&MO;F9I9W5R86-I:FD@>F$@4U%,(%9&
M4R!N:7-O(&)I;&4@<&]D86YE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(DEN
M9F]R;6%C:6IE(&\@:V]N9FEG=7)A8VEJ:2!Z82!344PM1FEL92!61E,@;FES
M;R!B:6QE('!O9&%N92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R(")+<F5D:71A(&YI('9EZ"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N(@IM<V=S='(@(D1E<W1I;F%C:6IA(&YI(&)I;&$@
M<&]D86YA+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W
M-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(")$871O=&5K82!N
M:2!P<F5N9;EE;F%N82!S=')EOFYI:R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(DEK;VX@
M;FD@;6]G;^AE(&YA:G1I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM
M<V=S='(@(DQO:V%C:6IA(&YI(&YA<W1A=FQJ96YA+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("),;VMA8VEJ82!N:2!N87-T879L
M:F5N82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T
M<B`B4W!O<F_H:6QO(&YI(&)I;&\@<&]D86YO+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N
M86UE('-P96-I9FEE9"XB"FUS9W-T<B`B26UE(&YI(&)I;&\@<&]D86YO+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("*I=&5V
M:6QK82!N:2!B:6QA('!O9&%N82XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").
M92!P<FEK87IU:B"^86QJ:79I:"!F;W)T=6YE+6]V(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D=E<VQO
M('IA($A45%`@879T96YT:6MA8VEJ;R!N:2!B:6QO('!O9&%N;RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(D=E<VQO('IA($E-05`@879T96YT:6MA8VEJ;R!N:2!B:6QO('!O9&%N
M;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(D=E<VQO('IA($ME<F)E<F]S(&%V=&5N=&EK86-I
M:F\@;FD@8FEL;R!P;V1A;F\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B1V5S;&\@>F$@3&]G:6X@879T96YT:6MA8VEJ;R!N:2!B:6QO('!O
M9&%N;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(")'97-L;R!Z82!005-35T0@879T96YT:6MA
M8VEJ;R!N:2!B:6QO('!O9&%N;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D=E<VQO('IA(%--0B!A=G1E
M;G1I:V%C:6IO(&YI(&)I;&\@<&]D86YO+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T
M:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R
M>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB
M"FUS9W-T<B`B(@HB4&]T(&1O($]P96Y34TP@:7IV<KEI;&YE(&1A=&]T96ME
M(&YI(&)I;&$@<&]D86YA+B!,92UT82!J92!P;W1R96)N82!Z82!D96QO("(*
M(G,@<&]D871K:2!02T-3(#$R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS
M9W-T<B`B3F]B96X@=G!I<R!N92#H86MA+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HW-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U
M;W1A('-E="XB"FUS9W-T<B`B3FD@;F%S=&%V;&IE;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@
M(DYO(')U;&5S(@IM<V=S='(@(D)R97H@Z')T(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T
M;W(@<W!E8VEF:65D+B(*;7-G<W1R("*I=&5V:6QK82!N:2!B:6QA('!O9&%N
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")"<F5Z('-T<F%N
M:6,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PHC+"!F=7IZ
M>0IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(D)R97H@<W1R86YI8R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS
M9W-T<B`B3F$@=F]L:F\@;FD@>F'H87-N92!M87!E('IA(&-A8VAE+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS
M9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T
M<B`B57!O<F%B;FFY:V\@:6UE(&EN+V%L:2!G97-L;R!N:2!B:6QO('!O<VQA
M;F\N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G
M:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DYI<V\@
M8FEL:2!V<FYJ96YI('9E;&IA=FYI(%A-3"!P;V1A=&MI(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A
M;'5E<R(*;7-G<W1R(")"<F5Z('9R961N;W-T:2(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I
M9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")6(&]R:6=I;F%L;FD@:V]N9FEG=7)A8VEJ:2!V97)Z:6IA
M(&YI(&YA:F1E;F$N(%IN;W9A(&IO(&=E;F5R:7)A:G1E+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(E8@=F&Y:2!K;VYF:6=U<F%C:6II('9E<GII:F$@;FD@
M;F%J9&5N82X@6FYO=F$@:F\@9V5N97)I<F%J=&4N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R
M(")"<F5Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")"
M<F5Z("AU<&]R86)I(&EM<&QI8VET;F\I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@
M(DYO<F1I:G-K;R`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VRY:VD@;W1O:R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*
M;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B4V5V97)N82!P
M;VQO8FQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"FUS9W-T<B`B4V5V97)N:2!-87)I86YA(&]T;VMI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R=F6Y:V$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B
M3F]T($%F=&5R(@IM<V=S='(@(DYE('!O(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T
M<B`B3F4@<')E9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P
M.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DYI(&UA<&$B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R(").:2!I;7!L96UE;G1I<F%N;RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T
M(@IM<V=S='(@(DYI(&YA<W1A=FQJ96XB"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B3FD@<&]D<')T;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM
M<V=S='(@(EIA<&ES:VDB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP
M:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G
M<W1R(").:>AE<V%R('IA('!R96)R<VMA=&DL('9R;FD@<V4N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO
M=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(JET979I;&\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB
M97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("*I=&5V:6QO('IN86MO=B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS
M9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("*I=&5V:6QO('-T;VQP
M8V5V(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(JET979I;&\@
M=G)S=&EC(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(JET979I
M;&ME('IA('!O<V]D;V)I=&5V('-E>FYA;6$@<F%Z9&5L:71V92!N:7-O('!O
M9&%N92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(E8@<F5D=2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C
M="(*;7-G<W1R(")/8FIE:W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B5'9O<F5C
M(&]B:F5K=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS
M9VED(")/8W1A;"(*;7-G<W1R(")/:W1A;&YO(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R(+YA;&II=FLB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I
M8V4B"FUS9W-T<B`B4&ES87)N82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*
M;7-G<W1R(")'97-L;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R
M96-T+B(*;7-G<W1R(").97!R879I;&YO(&=E<VQO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")/;6%N(@IM<V=S='(@(D]M86XB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E
M<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B4V%M;R!)
M34%0('-T<F6^;FEK:2!P;V1P:7)A:F\@;6%P92!V('-K=7!N:2!R86)I+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B4V%M;R"^86QJ:79I(&9O<G1U;F4M
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")$;W9O;&IE;B!J92!S86UO(&5N(&4M
M<&^Y=&YI(&YA<VQO=BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES
M=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI
M<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(E-A;6\@;&%S=&YI:R!A
M;&D@<VMR8FYI:R!S:7-T96UA(&QA:&MO('-P<F5M96YI(&QA<W1N:;ET=F\@
M86QI(&QA<W1N:6MA("(*(G!R879I8R!S:W5P;F4@<F%B92(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R(")/9'!R:2!V(&YO=F5M(&]K;G4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B3W!E;E-33"!N87!A:V$Z(%!O9&%T:V]V(&EZ(%,O
M34E-12!P;V1P:7-A;F5G82!D96QA(&YI(&UO9V_H92!I>G9L9>AI+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R(")/9'!R92!T;R!P;W9E>F%V;R!V(&YO=F5M(&]K;G4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T
M96TB"FUS9W-T<B`B3W!E<F%C:6IS:VD@<VES=&5M(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R
M(")-;[YN;W-T:2(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I
M;VYS(&9O<B`E<R(*;7-G<W1R(")-;[YN;W-T:2!Z82`E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R
M9&5R960@3&ES="(*;7-G<W1R(")5<F5J96X@<V5Z;F%M(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A
M=&EO;B(*;7-G<W1R(")/<F=A;FEZ86-I:F$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R(")%;F]T82!O<F=A;FEZ86-I:F4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S
M='(@(D]R9V%N:7IA8VEJ82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U
M"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R
M(")/<FEG:6YA;&YA('!R961L;V=A(&%P;&EK86-I:F4B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(D]R:6=I;F%L;F4@<')E9&QO
M9V4@=B`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T
M<B`B1')U9V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED
M(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")$<G5G92!I;F9O<FUA8VEJ
M92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W
M;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!R879I8V4@;&%S=&YI:V$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")004T@
M879T96YT:6MA8VEJ82!N:2!N82!V;VQJ;RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA
M:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B
M"FUS9W-T<B`B4$=0(&1I9VET86QN:2!P;V1P:7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B4$=0(+EI9G)I<F%N:2!P;V1A=&MI(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U
M8FQI8R!+97DB"FUS9W-T<B`B4$=0(&IA=FYI(&ML:G7H(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@<&]D<&ES86YI+[EI<F9I
M<F%N:2!P;V1A=&MI(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED
M(")02%`@0V]D92(*;7-G<W1R(")02%`@:V]D82(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(4"!U:V%Z
M;F$@;'5P:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B4&]P;VQD
M86X@<F%H96P@9&6^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B4&]P;VQD
M86YS:V4@<&QO:&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")3
M;F5G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")3
M;F6^;F4@<&QO:&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4
M+5-T;W)M<R(*;7-G<W1R(")0;W!O;&1A;G-K92!N979I:'1E(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N
M(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS
M9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?2%`@=6MA>FYA(&QU<&EN82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B3V)R;V)A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9"(*;7-G<W1R(")086QE<W1I;G-K;R!O>F5M;&IE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YO
M=F$@1W9I;F5J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(E!A<F%G=F%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B
M1&5L;F\@;V)L8>AN;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(D=E<VQO
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")0
M87-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"FUS9VED(")0
M87-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B3F5P<F%V:6QN;R!G97-L;R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@
M(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(D=E<VQO('!O=')E8FYO('IA(%)!1$E54R!A=G1E;G1I:V%C
M:6IO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@
M(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D=E<VQO(',@
M<&]T<F1I;&]M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP
M"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B1V5S;&\Z(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS
M9W-T<B`B1V5S;&\Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R(")'97-L:2!S92!M;W)A=&$@=6IE;6%T:2XB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B4')I
M;&5P:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(E!R
M:6QE<&D@>B!O9&QOOFFYZ&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(E!O="(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD
M:6YG(%-I9VYU<',Z(@IM<V=S='(@(LAA:V%J;^AI('9P:7-I.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(DQJ=61J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(D]D<W1O=&5K(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*
M;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R
M("))>G9E9&D@;W!E<F%C:6IE('9Z9'*^979A;FIA(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("))>G9E9&D@;W!E<F%C:6IE
M('9Z9'*^979A;FIA(&]B('!R:6IA=FD_(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M4')A=FEC82(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D
M96QE=&5D+B(*;7-G<W1R(")0<F%V:6-A("<E<R<@;FD@8FEL82!I>F)R:7-A
M;F$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z
M>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!R879I8V$B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B7U!R879I8V4B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D
M;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!9&UI;FES=')A8VEJ82!P<F%V:6,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@
M(D]S96)N92!I;F9O<FUA8VEJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R
M=2(*;7-G<W1R(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U
M"FUS9VED(")0971S(@IM<V=S='(@(D1O;6'H92"^:79A;&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YI(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM
M<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O
M9W)A9FEJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S
M='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:6MS;&DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D
M97,B"FUS9W-T<B`B4&QA=&ET=61E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L
M:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(E!R;W-I;2!K;&EK;FET92!V
M(&-E;&EC;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")0<F]S
M:6T@<&]T<F1I=&4@;V1S=')A;FET978@=&5G82!E;&5M96YT83HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B4')O<VEM('!O=')D:71E(&]D
M<W1A;FET978@<&]V97IA=F4@96QE;65N=&$Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BXB"FUS9W-T<B`B4')O<VEM('9P:;EI=&4@;65S96,@:6X@
M;&5T;RXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE
M=R!C871E9V]R>3HB"FUS9W-T<B`B4')O<VEM('9P:;EI=&4@:6UE('IA(&YO
M=F\@:V%T96=O<FEJ;SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*
M;7-G<W1R(")0<F]S:6T@=G!IN6ET92!V96QJ879E;B!)4"!N87-L;W8N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B4')O<VEM('9P:;EI=&4@=F5L:F%V
M96X@9&%T=6TL('!R979E<FET92"Y=&5V:6QO(&1N:2!V(&UE<V5C=2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")0<F]S:6T@=G!IN6ET92!V
M96QJ879E;B#H87,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+B(*;7-G<W1R(")0<F]S:6T@=G!IN6ET92!P;W9Z971E:R!P<F]B
M;&5M82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E!R;W-I;2!V
M<&FY:71E('9AN64@=7!O<F%B;FFY:V\@:6UE(&EN(&=E<VQO(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R
M("(B"B)0<F]S:6T@<')E8F5R:71E(&YA<VQE9&YJ92!B97-E9&EL;RX@4R!P
M;V=O:FD@=7!O<F%B92!S92!-3U)!5$4@<W1R:6YJ871I+"`B"B+H92"^96QI
M=&4@=7!O<F%B;&IA=&D@<VES=&5M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E!R;W-I;2!V<&FY
M:71E(&EM92!N;W9E(&MA=&5G;W)I:F4Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0;VQA;F0B"FUS9W-T<B`B4&]L:G-K82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:V$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL
M<R(*;7-G<W1R(")!;FME=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T
M=6=A;"(*;7-G<W1R(")0;W)T=6=A;'-K82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-T879I=&5V
M('-L:6ME(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS
M9W-T<B`B4&]S=&%V:71E=B!T86)E;&4B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(E-H<F%N:2!V
M('1O(&UA<&\@*$E-05`@=&5G82!N92!Z86AT979A*2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@(@IM<V=S='(@(DMO;&GH:6YA('!A9&%V:6X@=B!Z861N:FEH("5S
M('5R86@Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*
M;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(E!R969S7VQD87`Z(%!O=')E8F5N($Q$05`@9&]D871E:R!N
M:2!N86ID96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN
M<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ
M(%!O=')E8F5N('-E<W-I;VX@9&]D871E:R!N:2!N86ID96XN(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@
M(E!R:71I<VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B
M4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')I=&ES:R!N82!M
M;W)S:VD@=FFY:6YI.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E!R:71I<VLZ("(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E!R961O9VQE9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(E!R961O9VQE9"!S;&EK92!V(&YO=F5M(&]K;G4B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T
M:6]N<R(*;7-G<W1R(")0<F5JN6YJ92!M;[YN;W-T:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT
M(&1O8W5M96YT(@IM<V=S='(@(DYA=&ES;FD@9&]K=6UE;G0B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@
M2V5Y(@IM<V=S='(@(EIA<V5B;FD@:VQJ=>@B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@
M(E!R;V)L96TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B3W!I<R!P<F]B;&5M82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE
M8W1S(@IM<V=S='(@(E!R;VIE:W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT
M(@IM<V=S='(@(D)E<V5D:6QO('!O>FEV;FEK82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G
M<W1R(")*879N:2!K;&IUZ"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G
M<W1R(")!;&=O<FET96T@:F%V;F5G82!K;&IUZ&$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I9"`B4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(DIA=FYI(&ML:G7H(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(")'96YE<FER86YJ92!P87)A($IA=FYI+UIA<V5B;FD@:VQJ=>@@;FD@
M=7-P96QO+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM
M<V=S='(@(E!O<G1O<FEK;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R
M(@IM<V=S='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS
M9VED(")1=65R>2(*;7-G<W1R(")0;VEZ=F5D8F$B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(E%U;W1A(@IM<V=S='(@
M(E%A=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I
M="DB"FUS9W-T<B`B4E-!(&IA=FYI(&ML:G7H("@E(&)I=&5N*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R("))>F)I<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")$9;XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM
M<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")$9;X@>F=O9&%J(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A
M:6X@3&%T92(*;7-G<W1R(")$9;X@<&]Z;F\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B
M"FUS9W-T<B`B1&6^979N82!P;&]H82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0W"B,L(&9U>GIY"FUS9VED(")286EN(&%N
M9"!3;F]W(@IM<V=S='(@(D1EOF5V;F$@<&QO:&$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B
M4F%I;B!T;R!3;F]W(@IM<V=S='(@(D1EOF5V;F$@<&QO:&$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS
M9W-T<B`B3F%K;&IUZ&5N(&9O<G1U;F4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E)A>FUE<FIE
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G
M:60@(E)E860B"FUS9W-T<B`B4')E8F5R:2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S
M(@IM<V=S='(@(E!R96)E<FD@<W!O<F_H:6QA(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(E)E<R!P;V)R:;EE;2`E<S\@3W!E<F%C:6IE(&YI(&UO
M9V_H92!R87IV96QJ879I=&DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(E)E<R!O9'-T<F%N:6T@=7!O<F%B
M;FEK;W9E('!O9&%T:V4@>F$@)7,_($]P97)A8VEJ92!N:2!M;V=OZ&4@<F%Z
M=F5L:F%V:71I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(E!O;F]V;F\@:7IV961I('IA9&YJ92!D96IA;FIE(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE
M;65N=',Z(@IM<V=S='(@(D]S=F6^:2!D:6YA;6GH;F4@96QE;65N=&4@;65N
M=6IA.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E
M9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D]S=F6^:2!P;V=L960@<&]R
M=&%L83HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI
M<"!"<F]W<V5R(@IM<V=S='(@(D)R<VMA;&YI:R!O9&YO<V]V(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(E!R96)E<FDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B
M4F5M87)K<R(*;7-G<W1R(")0<FEP;VUB92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D]D
M9&%L:F5N:2!S=')EOFYI:VDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.B(*;7-G<W1R(")/9&1A;&IE;B!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(D]D<W1R86YI(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`B3V1S=')A;FD@8FQO:R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C
M;VQU;6XB"FUS9W-T<B`B3V1S=')A;FD@<W1O;'!E8R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V
M92!F;W)M871T:6YG(@IM<V=S='(@(D]D<W1R86YI(&]B;&EK;W9A;FIE(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V
M92!P86ER(@IM<V=S='(@(D]D<W1R86YI('!A<B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")/9'-T
M<F%N:2!S:')A;FIE;F\@<VMR:7!T;R!I>B!S=')EOFYI:V]V92!Z8>AA<VYE
M(&UA<&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D]D
M<W1R86YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT(@IM<V=S='(@(D]D<W1R86YI('1O('9O>FQIN>AE(&EZ
M(&1O:W5M96YT82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(D]D<W1R86YI('5P
M;W)A8FYI:V$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S
M='(@(D]D<W1R86YI('5P;W)A8FYI:V$Z("5S(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@
M8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(DYA
M('IA:'1E=F\@;FD@8FEL;R!M;V=OZ&4@;V1G;W9O<FET:2X@3F%P86MA.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY
M"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M(@IM<V=S='(@(E!O<VYE=&4@9&%T;W1E:V4@;FD@8FEL;R!M;V=OZ&4@<VAR
M86YI=&DN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(EIA:'1E=F%N("<E<R<@;FD@;F%S
M=&%V;&IE;B!V(&YA<W1A=FET=F%H("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("):86AT979A
M;B`G)7,G(&YI(&YA<W1A=FQJ96X@=B!61E,@;F%S=&%V:71V86@N(@H*(SH@
M9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("):86AT979A;B`G)7,G(&YI(&YA<W1A
M=FQJ96X@=B!N87-T879I='9A:"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*
M;7-G<W1R(")0;VYA<W1A=FDB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B4&]N87-T
M879I(&=E<VQO(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*
M;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4&]N87-T879I
M=&4@=F&Y92!G97-L;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*(RP@
M9G5Z>GD*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("):861N
M:F$@Z&5T<G1I;F$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO
M8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B
M4F5S=6QT<R(*;7-G<W1R(")297IU;'1A=&DB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*
M;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(DYA>F%J(&YA($UO
MOFYO<W1I(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L
M(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E!O
M;F%S=&%V:2!G97-L;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB
M"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B3V)N;W9I('!R96JY;FIE(&YA<W1A=FET
M=F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"FUS9VED(")2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B36^^;F]S=&D@=7)E:F5V
M86QN:6MA(&]B;V=A=&5N96=A(&)E<V5D:6QA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(E5G86YK92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B1&5S;F\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS
M9W-T<B`B1&5S;F$@9VQA=F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B1&5S;F4@=G)E
M9&YO<W1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B3&%S7W1N;W-T:2!V<G-T:6-E(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R
M(")6;&]G82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T
M<B`B4F]M=6YI:F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(EIA<W7H
M:2!Z82`Q.#`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("):87-UZ&D@
M;&5V;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("):87-UZ&D@9&5S
M;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("),87-T
M;F]S=&D@=G)S=&EC92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM
M<V=S='(@(DQA<W1N;W-T:2!V<G-T:6-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S
M='(@(E9R<W1I8V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`BR')T
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BR')T92!B;V1O('!R:6MA>F%N
M92!M960@=G-E;6D@=G)S=&EC86UI(&EN('-T;VQP8VDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G
M<W1R("+(<G1E(&)O9&\@<')I:V%Z86YE('-A;6\@;65D('-T;VQP8VDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>2(*;7-G<W1R("+(<G1E(&)O9&\@<')I:V%Z86YE('-A;6\@;65D('9R<W1I
M8V%M:2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*
M;7-G<W1R(")0;[YE;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N
M($9E9&5R871I;VXB"FUS9W-T<B`B4G5S:6IA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%(&MR:7!T;V=R869S
M:VD@<&]D<&ES(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R
M(")3+TU)344@N6EF<FER86YO('-P;W)OZ&EL;R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"!O=F5R:F%N:F4@
M;FD@;F$@=F]L:F\N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P
M-`IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")335,@<W!O<F_H86YJ
M92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(E-13"!L=7!I;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K
M=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,S$*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U
M"FUS9VED(")354-#15-3(@IM<V=S='(@(E534$5,3R(*"B,Z(&QI8B]A<&DN
M<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")37U%,(&QU<&EN
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C$*;7-G:60@(E-A(@IM<V=S='(@(E-O(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-V+B!(96QE;F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")3
M86EN="!+:71T<R!I;B!.979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I
M;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A
M:6YT(%!I97)R92!I;B!-:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A
M:6YT(%9I;F-E;G0@:6X@1W)E;F%D:6YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H
M7W-E;&8I(@IM<V=S='(@(DES=&D@;VMV:7(@*%]S96QF*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM
M<V=S='(@(E-A;R!4;VUE(&EN(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R
M(@IM<V=S='(@(E!O;G5D;FEK('-A=&5L:71S:V5G82!D;W-T;W!A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61O
M=F$@07)A8FEJ82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY
M.`IM<V=I9"`B4V%V92(*;7-G<W1R(")3:')A;FDB"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")3:')A;FD@)7,B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E("5S(@IM<V=S='(@(E-H<F%N:2`E<R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R
M(")3:')A;FD@;6^^;F]S=&DB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(E-H<F%N:2!G96YE<FER86YO(&MO;F9I
M9W5R86-I:F\@:V]T(%!(4"!S:W)I<'1O('8@>F'H87-N;R!M87!O(&YA('9A
MN65M("(*(G-T<F6^;FEK=2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")+;VYF:6=U<F%C:6IA("5S('-H<F%N:F5N82XB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`B4VMR:7!T82!Z82!N86UE<W1I=&5V('!O<')A=FMO
M=B!S:')A;FIE;F$@=CH@)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B4V-A='1E<F5D
M(%0M4W1O<FUS(@IM<V=S='(@(DEZ;VQI<F%N92!N979I:'1E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@
M(EIN86YO<W0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(DES:V%N:F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("))<VMA
M;&YA(&]R;V1J82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*
M;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("))>F)E<FET92!D871O=&5K
M92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M.#0*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B27IB97)I=&4@9&%T
M=6TB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B
M4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(DEZ8F5R:71E('-K=7!I
M;F\@:VD@:F\@OF5L:71E(&1O9&%T:2(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M("))>F)E<FET92!N;W9E9V$@;&%S=&YI:V$B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G
M<W1R("))>F)E<FET92!S=')EOFYI:R(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G
M<W1R("))>F)E<FET92!U<&]R86)N:6MA(&MI(&=A(+YE;&ET92!D;V1A=&DB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(DEZ8F5R:71E
M(&1A=&]T96ME(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PIM
M<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(DEZ
M8F5R:2!V<V4@9&%T=6US:V4@:V]M<&]N96YT92XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@
M86X@;V)J96-T(@IM<V=S='(@(DEZ8F5R:2!O8FIE:W0B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@;F]N92(*;7-G<W1R("))>F)E<FET92!N;W9E9V$@;&%S
M=&YI:V$B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*
M(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B))>F)E<FET92!Z;F%K
M92P@:VD@:FEH('!O=')E8G5J971E(&EZ('-P;V1N:FEH('!O;&HN($YA=&\@
M:FEH(&QA:&MO(&MO<&ER871E("(*(FEN('!R:6QE<&ET92!I>B!O8G)A>F-A
M+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("))>F)E<FD@<F%Z;65J
M:71E=B!Z82!D871U;3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B27IB
M97)I(&]B;&EK;R!Z87!I<V$@9&%T=6UA.B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("))>F)E<FET92!I
M9&5N=&ET971O+"!K:2!J;R"^96QI=&4@<W!R96UE;FET:3HB"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE
M(&1E;&EM:71E<CHB"FUS9W-T<B`B27IB97)I=&4@<F%Z;65J:71E=B!Z82#H
M87,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(DEZ8F5R:71E(&]B;&EK
M;R!Z87!I<V$@>F$@Z&%S.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G
M<W1R("))>F)E<FET92!D=F4@=6IE;6%J8>AI('!O;&II+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B27IB97)I=&4@<W9O:F\@8F%R=FYO('-H96UO
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B27IB97)I=&4@
MOF5L:F5N(&IE>FEK.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E!O
MN6QJ:2!P;W)OZ&EL;R!O(&YA<&%K:2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G
M<W1R(")0;[EL:FD@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A
M;"(*;7-G<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;GIO<CH@(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E
M<'1E;6)E<B(*;7-G<W1R(")397!T96UB97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT
M96YE9W)O(@IM<V=S='(@(E-R8FEJ82!I;B#(<FYA($=O<F$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L
M($YU;6)E<B(*;7-G<W1R(")397)I:G-K82"Y=&5V:6QK82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(E-E
M<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DUE
M=&%R(&)L;VL@;FD@;F$@=F]L:F\N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(D%D
M;6EN:7-T<F%C:6IA('!R879I8R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E
M>'!I<F5D+B(*;7-G<W1R("))1"!S96IE(&IE('!O=&5K;&$N(@H*(SH@;&EB
M+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R
M(")?4')A=FEC92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*
M;7-G:60@(E-E="(*;7-G<W1R(").87-T879I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N
M(@IM<V=S='(@(DYA<W1A=FD@;6^^;F]S=&D@>F$@<&]N87-T879I=&5V(&=E
M<VQA+"!V('!R:6UE<G4@9&$@9V$@<&]Z86)I=&4N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM
M<V=S='(@(DYA<W1A=FD@;V1D86QJ96YE('-T<F6^;FEK92P@9&\@:V%T97)I
M:""^96QI=&4@9&]S=&]P871I(',@<&]R=&%L82XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B3F%S
M=&%V:2"^96QJ96X@:F5Z:6LL(.AA<V]V;FD@<&%S(&EN('!R:6MA>B!D871U
M;6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HB3F%S=&%V:2!Z8>AE=&YO(&%P;&EK86-I:F\L(&)A<G9N
M;R!S:&5M;RP@;W-V9;YE=F%N:F4@<W1R86YI+"!I;B!O<W1A;&4@(@HB;6^^
M;F]S=&D@<')I:V%Z82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U
M"B,L(&9U>GIY"FUS9VED(")3971U<"(*;7-G<W1R(")?3F%M97-T:71E=B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(DYA
M;65S=&ET978@<VMR:7!T('IA('!O<V]D;V)I=&5V(&IE(&YA('9O;&IO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B
M"FUS9W-T<B`B4&]D86YI;2!P87)A;65T<F]M('5S=')E>F$@=F7H(&QO:V%C
M:6HZ("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T
M<B`B4V5JN65L:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*
M;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(DYA:W5P;W9A;FIE(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U
M;6UA<GDB"FUS9W-T<B`B2W)A=&5K('!O=GIE=&5K(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E
M(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(DYA<W1A=FEM(&)L
M:;YN:FEC92!Z82!V9>AI;F\@<&]V97IA=C\B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")0
M<FEK8;YI(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B
M(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B)0<FEK8;YI(')A>FQI:V4@;65D('1R96YU=&YO('-H<F%N:F5N
M;R!I;B!N;W9O(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;RXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(E!R:6MAOF5M(.AA<R!Z
M861N:F4@<')I:F%V92!O8B!P<FEJ879L:F%N:G4_(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;"(*;7-G<W1R(")0<FEK8;YI(&UOOFYO<W0@>F$@;VAR86YI
M=&5V(&]R:6=I;F%L82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(E!O:V&^:2!O<F]D:F4@
M>F$@:7IB:7)O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I
M9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")0
M<FEK8;YE;2!M96YU('IA('5R96IA;FIE('1A8F5L93\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(E!R:6MAOF5M("5S
M($UE;G4@;F$@;&5V:3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B4')I:V&^:2!P;V=O
M=F]R;F\@;VMN;R!,87-T;F]S=&D@8V5L:6-E('1A8F5L92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B4')I:V&^:2!P;V=O=F]R;F\@;VMN;R!,87-T;F]S=&D@=&%B96QE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B4')I:V&^:2!P;V=O=F]R;F\@;VMN;R!,87-T;F]S
M=&D@=G)S=&EC92!T86)E;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E!R:6MAOFD@<&]G;W9O
M<FYO(&]K;F\@3&%S=&YO<W1I('-L:6ME(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B4')I
M:V&^:2!S:')A;FIE=F%N:F4@;F$@<W1R9;YN:6LB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*
M;7-G<W1R(")0;&]H92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(E!L
M;VAE('IG;V1A:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B4&QO:&4@
M<&]Z;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS
M9VED(")3:')I;FLB"FUS9W-T<B`B4VMRZ&DB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY
M.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO
M=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T
M(@IM<V=S='(@(DYA:G!R96H@<VMRZ&D@86QI(&]D;6%K;FD@<V]S961N:F4@
M8FQO:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS
M9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")0<FEJ879A
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G
M:60@(E-I9VYA='5R92(*;7-G<W1R(")0;V1P:7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L
M9V]R:71H;2(*;7-G<W1R(")!;&=O<FET96T@<&]D<&ES82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!U<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS
M9W-T<B`B5F5L:6MO<W0B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G
M<W1R(")0<F5S:V_H:2!V>F1ROF5V86YJ92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9AN6MA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=F5N:6IA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N
M;W<B"FUS9W-T<B`B4VYE9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")3
M;F6^;F$@<&QO:&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N9;YN
M92!P;&]H92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4W"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B4&QO:&4@>F=O9&%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM
M<V=S='(@(E-N9;YN92!P;&]H92!P;WIN;R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B1&5B96QI
M;F$@<VYEOFYE(&]D96IE.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B
M16YA:V$@:V]L:>AI;F$@=F]D93H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-A;&]M;VYO=FD@;W1O:VDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:6IA
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F
M(%!O96US(@IM<V=S='(@(E!E<VUI("8@4&]E>FEJ82(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T
M:6]N(@IM<V=S='(@(E)A>G9R<W1I(&EZ8G)A;F\B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("))>G9O<FYI(&YA<VQO=B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")*=;YN
M82!!9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(DIUOFYO($5V
M<F]P<VMO("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS
M9W-T<B`B2G6^;F$@1V5O<F=I82!I;B!*=;YN:2!386YD=VEC:"!O=&]K:2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2G6^;F$@
M<&]L;V)L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M(@IM<V=S='(@(E!R;W-T;W(@;65D('-O<V5D;FII;6$@8V5L:6-A;6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;"(*;7-G<W1R(")0<F]S=&]R(&UE9"!V<V5B:6YO(&EN(')O8F]M(&-E;&EC
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A
M8V5R(@IM<V=S='(@(E!R97-L961N:6LB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B
M"FUS9W-T<B`B4F%Z;6%K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D
M9&EN9R(*;7-G<W1R(")287IM86MI(&EN(&]D;6EK:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")3<&%I;B(*;7-G<W1R("*I<&%N:6IA(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(E9N;W,@<&]S96)N:6@@>FYA:V]V
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")287ID96QI(&-E
M;&EC;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")287ID
M96QI('-T;VQP96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B
M4F%Z9&5L:2!V<G-T:6-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q
M"FUS9VED(")3<&]R=',B"FUS9W-T<B`BJ7!O<G0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("*I<FEL86YK82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP
M.C<T"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S
M='(@(EIV97ID;F4@<W1E>F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T
M87)T('EE87(B"FUS9W-T<B`B3&5T;R!Z8>AE=&MA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R
M;W9I;F-E(@IM<V=S='(@(D1ROF%V82!A;&D@<')O=FEN8V$B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(E-T86YJ92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,34*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D]B;&EK82!S
M:')A;FIE=F%N:F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B3F%S;&]V
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")0<F7H<G1A;F\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@
M;&ES="(*;7-G<W1R(")397IN86T@8F5S961I;&$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<R(*;7-G<W1R(")/9'-T<F%N:2!D;VUE;F\@:7H@;F%S;&]V
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T:6P@6T-3
M4UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8R"FUS9VED(")3=2(*;7-G<W1R(").92(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E!O9&UA<&$@)R5S
M)R!N:2!B:6QA(&YA:F1E;F$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("):
M861E=F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B4&^Y;&II(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT
M:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R
M("(B"B):86AT979A('IA(&1O9&%N:F4@)R5S)R!V('-I<W1E;2!J92!B:6QA
M('!O<VQA;F$N($1O:VQE<B!V8;EA('IA:'1E=F$@;FD@(@HB;V1O8G)E;F$L
M('-E(&YE(&UO<F5T92!P<FEJ879I=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM
M<V=S='(@(E!O9'!I<V%N;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")5<W!E
MN6YO(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B57-P9;EN;R!D;V1A;"`G)7,G('8@<VES=&5M+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")5<W!EN6YO(&]D<W1R86YI
M;"!P;V1A=&ME('5P;W)A8FYI:V$@)R5S)R!I>B!S:7-T96UA+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T
M960@7"(E<UPB+B(*;7-G<W1R(")5<W!EN6YO(&EZ8G)I<V%L("<E<R<N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R(")5<W!EN6YO(&]D<W1R86YI;"`G)7,G(&EZ('-I<W1E
M;6$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S
M964@8VAA;F=E<RXB"FUS9W-T<B`B57-P9;EN;R!P;W9R;FEL(&YA<W1A=FET
M=F4N(%!O;F]V;F\@;F%L;[YI=&4@<W1R86XN(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(E5S<&6Y;F\@<VAR86YI;"!V87)N;W-T;F\@:V]P:6IO(&MO;F9I
M9W5R86-I:F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")5<W!E
MN6YO('-H<F%N:6P@=F%R;F]S=&YO(&MO<&EJ;R!K;VYF:6=U<F%C:6IE("5S
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@
M(E5S<&6Y;F\@<&]S;V1O8FEL("<E<R<B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B57-P
M9;EN;R!Z87!I<V%L("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB
M"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@
M(E!O=GIE=&5K(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED
M(")3=6X@4FES92(*;7-G<W1R(")3;V[H;FD@=GIH;V0B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4V]N
MZ&YI('IA:&]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-O;NAN;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B
M"FUS9W-T<B`B4V]NZ&YI('9Z:&]D(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E
M+U-U;G-E="(*;7-G<W1R(")3;V[H;FD@=GIH;V0O>F%H;V0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B
M"FUS9W-T<B`B4V]NZ&YI('9Z:&]D.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V]NZ&YI
M('IA:&]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM
M<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B4V]NZ&YI('IA:&]D.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@
M(E-U<&5R<V-R:7!T(@IM<V=S='(@(DYA9'!I<V%N;R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B
M4&]D<&]R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(E-U<FEN86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-`IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")0<FEI;65K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G
M<W1R(")3=F%L8F%R9"!I;B!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W9A>FDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")3=V5D96XB"FUS9W-T<B`BJ79E9'-K82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("*I=FEC82(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC
M(&QO9R!D96QE=&5D(@IM<V=S='(@(DYE('!O8G)IN6DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(DYA<&'H;F$@
M<VEN=&%K<V$@:7-K86YI:"!P;VIM;W8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3:7)I:G-K82!!<F%B
M<VMA(%)E<'5B;&EK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(DYE=FEH=&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM
M<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O
M<FUS(@IM<V=S='(@(DYE=FEH=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,@
M16%R;'DB"FUS9W-T<B`B4&QO:&4@>F=O9&%J(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M5%-6(&1A=&]T96MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ
M,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A8F5L82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@
M(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B3&%S=&YO<W1I('1A8F5L92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*
M(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R(")486)E;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(DQA<W1N;W-T
M:2!T86)E;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB
M"FUS9W-T<B`B5&%J=F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B5&%J=F%N+"!+:71A:G-K82!P<F]V:6YC82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%DOFEK:7-T86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E1A;GIA;FEJ82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS
M9W-T<B`B0VEL:CHB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S
M='(@(D]P<F%V:6QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L
M969O;G-K82"Y=&5V:6QK82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP
M"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")496UE<F%T
M=7)A('IA9&YJ;R!U<F\Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T
M"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")496UP97)A='5R82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E
M<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R871U<F$Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9&QO9V$@)R5S)R!N:2!B:6QA(&YA
M:F1E;F$N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E
M;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E5P<F%V;&IA;FIE('!R
M961L;V<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`B
M0F5S961I;&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED
M(")497AT($]N;'DB"FUS9W-T<B`B4V%M;R!B97-E9&EO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I
M9"`B5&5X="!A;&EG;B(*;7-G<W1R(")0;W)A=FYA=F$@8F5S961I;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS
M9VED(")497AT=&]P(@IM<V=S='(@(E9R:"!B97-E9&EL82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H
M(@IM<V=S='(@(LAE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G
M:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1A:G-K;R`H5$E3+38R,"DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")486IS
M:V$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H
M86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B2'9A;&$@
M>F$@=7!O<F%B;R!S:7-T96UA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")&5%`@9&]D871E:R!N:2!N82!V;VQJ;RXB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B(&EN
M=&5G<F%C:6IA(&YE('!O9'!I<F$@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@HC+"!F=7IZ>0IM<V=I9"`B5&AE
M($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B
M4&]S;F5T92!D871O=&5K92!N:2!B:6QO(&UO9V_H92!S:')A;FET:2XB"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS
M9W-T<B`B4F%Z<F5D($UA:6YT96YA;F-E.CH@<V4@;FD@=7-P9;EN;R!N86QO
MOFEL(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM
M<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M(@IM<V=S='(@(D]K;F\@;6^^;F]S=&D@<V4@:F4@>F%P<FQO+B!:87!I<F%M
M+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*(E-K<F)N:6L@;6]R82!N86UE<W1I=&D@
M<W1A;&YO(&AR8G1E;FEC;R!Z82!D;V1E;&IE=F%N:F4@<')A=FEC+"#H92"^
M96QI=&4@(@HB=7!O<F%B;&IA=&D@4')A=FEC92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4
M:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")386UO('-P;V1N:F$@<W1R
M86XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B))1""Y=&5V:6QK82!S=&EK
M82!N:2!B:6QA('!O9&%N82P@<'6YZ&5N82!P<F%Z;F$@86QI(&YI(&)I;&$@
M;F%J9&5N82!V(&)A>FD@(@HB<&]D871K;W8N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")3=&EK(&IE(&)I;"!U<W!EN6YO(&1O9&%N('8@=F&Y(&%D
M<F5S87(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V
M.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B(@HB3V1D=F]J96X@4$=0('!O9'!I<VYI(&)L;VL@:F4@<&]T<F5B
M96X@>F$@879T96YT:6MA8VEJ;R!P;V1P:7-A;F5G82`B"B)S<&]R;^AI;&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB240@N71E=FEL:V$@
M<V5Z;F%M82!R87ID96QI='9E(&YI(&)I;&$@<&]D86YA+"!P=;GH96YA('!R
M87IN82!A;&D@;FD@8FEL82`B"B)N86ID96YA('8@8F%Z:2!P;V1A=&MO=BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E
M8VEF:65D+B(*;7-G<W1R(")397IN86T@<F%Z9&5L:71V92!N:2!B:6P@<&]D
M86XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(DUOOFYO<W1I(+EI9G)I<F%N:F$@>F%H
M=&5V86IO('9A<FYO('-P;&5T;F\@<&]V97IA=F\N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")$871O=&5K82`E<R!B
M:2!M;W)A;&$@=G-E8F]V871I(&YA<W1A=FET978@)7,N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B1&%T;W1E
M:V$@)7,@8FD@;6]R86QA('9S96)O=F%T:2!N87-T879I='9E("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I
M;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(D1A
M=&]T96ME(&YI(&UO9V_H92!P<F5S;F5T:2!S86UE('9A<V4N(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82XB"FUS9W-T<B`B1&%T;W1E:V$@;F4@=G-E8G5J92!P
M;V1A=&MO=BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R
M<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")3
M;&5D:2!G;&%V82!Z82!T;R!S<&]R;^AI;&\O<F9C.#(R('-P;W)OZ&EL;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*
M;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BXB"FUS9W-T<B`B(@HB3F'H:6X@9&5L;W9A;FIA(.AE>B!C96P@>F%S;&]N
M(&QA:&MO('!O=GIR;^AI('!R;V)L96UE('8@9&5L;W9A;FIU($EN=&5R;F5T
M("(*(D5X<&QO<F5R:F$@>F%R861I(&AR;[GH978@8G)S:V%L;FEK82P@:VD@
M<V4@:FEM(&YI<VUO('5S<&5L:2!O9VYI=&DN($]P87II=&4@(@HB;&%H:V\@
MZ'5D96X@<')I:V%Z+"!M86YJ:V%J;^AE(&UOOFYO<W1I('5R96IE=F%L;FEK
M82!I;B]A;&D@;F%K;&IUZ&YA("(*(G-E<W5T:F$@8G)S:V%L;FEK82X@R&4@
M=7!O<F%B;&IA=&4@5VEN9&]W<R`Y>"P@8F\@;F%P86MA('9E<FIE=&YO("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&MI(&)O('IA:'1E=F%L82!P
M;VYO=FYI('IA9V]N+EQ<;EQ<;D)I;&D@<W1E(&]P;WIO<FIE;FDN("(*(E!R
M;W-I;2!I>F)E<FET92!/2R#H92"Y92!V961N;R"^96QI=&4@<&]S:W5S:71I
M('5P;W)A8FQJ871I(&-E;&]Z87-L;VYS:VD@(@HB=7)E:F5V86QN:6LN(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B261E;G1I=&5T82!<(B5S7"(@:F4@8FEL82!I>F)R:7-A;F$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B4V%M
M;R!L979A('-T<F%N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB
M"FUS9W-T<B`B4F%Z<F5D=2!#<GEP=%]P9W`Z.B!M;W)A(&)I=&D@<&]D86YA
M('!O="!D;R!';G501R!I>G9RN6EL;F4@9&%T;W1E:V4N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N(@IM<V=S='(@(B(*(E-P;W)OZ&EL;R!P;W-L86YO("5S('IA
M("5S('H@>F%D979O(%PB)7-<(B!J92!B:6QO('!R:6MA>F%N;RY<;B(*(E1O
M(&YI('IA9V]T;W9I;&\L(&1A(&IE(&)I;&\@<W!O<F_H:6QO('!R96)R86YO
M(&%L:2!R87IU;6QJ96YO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("));64L('5P;W)A8FQJ96YO('!R
M:2!P;W9E>F]V86YJ=2!N82!S=')A;B!Z82!S97-T879L:F%N:F4B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@
M(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T
M<B`B5&\@<&]L:F4@;6]R82!V<V5B;W9A=&D@=F5L:F%V;F\@N71E=FEL:V\N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS
M9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(
M;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")287IR960@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!Z86AT979A(&UO9'5L(&]P96YS<VPN(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M
M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(DYA<W1A=FET=F4@7"(E<UPB
M(&YI(&)I;&\@;6]G;^AE('-H<F%N:71I+"!K97(@<')E<V5G82!M86MS:6UA
M;&YO(&1O=F]L:F5N;R`B"B)V96QI:V]S="(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP
M92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M(@HB4')O9W)A;2P@:VD@<V4@=7!O<F%B;&IA('IA('!R:6MA>B!T92!V<G-T
M92!P;V1A=&MO=B`H)7,I(&YI(&)I;"!N86ID96XN(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C
M=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM
M<V=S='(@(E-A;6\@9&5S;F4@:6X@;&5V92!S=')A;FDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED
M(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B4V%M;R!D97-N
M82!S=')A;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM
M<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")3=')EOFYI:R!<(B5S7"(@:F4@
M8FEL(&EZ8G)I<V%N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R(")3=')EOFYI:R!<(B5S7"(@:F4@8FEL
M('-H<F%N:F5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N
M(')E;6]V960N(@IM<V=S='(@(EIA:'1E=F$@>F$@<')I:F%V;R`E<R!J92!B
M:6QA(&]D<W1R86YJ96YA+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(DEM96YO=F%N82!V<G-T:6-A(&YE(&]B<W1A
M:F$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S
M7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DEM96YO=F%N82!V<G-T:6-A
M(&YE(&]B<W1A:F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q
M,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T
M:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED
M(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")386UO
M('IG;W)N:F$@:6X@<W!O9&YJ82!S=')A;FEC82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H
M92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E-A;6\@>F=O<FYJ82!S=')A;FEC
M82(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N(@IM<V=S='(@(E!O9&%T:VD@<&]S;F5T:2!N82!S=')EOFYI:R!S;R!S
M92!O9"!P<F5JN6YJ96=A(&MO<F%K82!I>F=U8FEL:2XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O
M='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"XB"FUS9W-T<B`B4&]S;F5T92!D871O=&5K92!N:2!B:6QO
M(&UO9V_H92!S:')A;FET:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@=V5A=&AE<BYC;VT@
M;FD@;F$@=F]L:F\N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DUA<&4@<R!T96UA;6D@)R5S)R!N
M:2!M;V=OZ&4@;F%J=&DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92XB"FUS9W-T<B`B3F]B96YA(&UOOFYO<W0@;FES;R!N82!V;VQJ;RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@
M(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+B(*;7-G<W1R(").;V)E;F5G82!D96QA('-P;W)OZ&EL82!N:2!M;V=O
MZ&4@<')I:V%Z871I('IN;W1R86H@=&5G82!O:VYA+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@
M66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E
M;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(E!O;&IE('9S96)U:F4@
M<')E=F7H('IN86MO=BX@5FYE<VQI('-T92`E<R!Z;F%K;W8[('9N97-T:2!J
M:6@@;6]R871E(&UA;FH@(@HB:V]T("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@
M861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES
M=&5M.B`E<R(*;7-G<W1R(")0<FD@9&]D86IA;FIU("<E<R<@=B!S:7-T96T@
M:F4@<')IN6QO(&1O(&YA<&%K93H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B(@HB4')I(&)R:7-A;FIU('!O9&%T:V]V('IA
M('5P;W)A8FYI:V$@)R5S)R!I>B!S:7-T96UA(&IE('!R:;EL;R!D;R!N87!A
M:V4Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')I(&]D<W1R86YJ979A
M;FIU("<E<R<@:7H@<VES=&5M82!J92!P<FFY;&\@9&\@;F%P86ME.B`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*
M;7-G<W1R(")0<FD@;W-V9;YE=F%N:G4@)R5S)R!J92!P<FFY;&\@9&\@;F%P
M86ME.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S
M='(@(E!R:2!S;F5M86YJ=2!D871O=&5K92!N82!S=')EOFYI:R!J92!P<FFY
M;&\@9&\@;F%P86ME.B`E<R!N:2!S:')A;FIE;BXB"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB4')I('-N96UA;FIU(&1A
M=&]T96ME(&YA('-T<F6^;FEK(&IE('!R:;EL;R!D;R!N87!A:V4Z("5S(&IE
M('9EZ&IA(&]D("(*(FYA:G9EZ&IE(&1O=F]L:F5N92!V96QI:V]S=&D@*"5D
M(&)Y=&]V*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB4')I('-N96UA;FIU(&1A=&]T
M96ME(&YA('-T<F6^;FEK(&IE('!R:;EL;R!D;R!N87!A:V4Z("5S(&IE('!O
M<VYE="!S86UO("(*(F1E;&YO+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E!R:2!P
M<FEK87IO=F%N:G4@=&5G82!D96QA('-P;W)OZ&EL82!J92!P<FFY;&\@9&\@
M;F%P86ME(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M8V]N=&%C="!D871A+B(*;7-G<W1R(")0<FD@=79AOF%N:G4@<&]D871K;W8@
M;R!S=&EK=2!J92!P<FFY;&\@9&\@;F%P86ME+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E!R:2!U
M=F&^86YJ=2!P;V1A=&MO=B!I0V%L96YD87(@:F4@<')IN6QO(&1O(&YA<&%K
M92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@HB1&\@;F%P86ME(&IE('!R:;EL;R!V(&]B<F%Z8W4@>F$@:V]N
M9FEG=7)A8VEJ;RX@36]G;^AE('-T92!P=7-T:6QI('!R87IN;R`B"B)Z86AT
M979A;F\@<&]L:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)0
M<FFY;&\@:F4@9&\@;F%P86ME('!R:2!I>G9A:F%N:G4@>F%H=&5V86YE(&9U
M;FMC:6IE(&%D<F5S87)J82X@4')O<VEM("(*(G!O<VMU<VET92!P;VYO=FYO
M(&MA<VYE:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B)0<FFY;&\@:F4@9&\@;F%P86ME('!R:2!O
M<W9EOF5V86YJ=2!P;V1R;V)N;W-T:2!O('-T:6MU+B!0;W-K=7-I=&4@:V%S
M;F5J92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HB4')IN6QO(&IE(&1O(&YA<&%K92!P<FD@;W-V9;YE
M=F%N:G4@<V5Z;F%M82!R87ID96QI='9E+B!0;W-K=7-I=&4@:V%S;F5J92XB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*
M;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N(@IM<V=S='(@(E1A($E-05`@<W1R9;YN:6L@;F4@<&]D
M<&ER82!S:W5P;F4@<F%B92!N86)I<F%L;FEK;W8N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T
M<B`B1&%T;W1E:V$@=F5R:F5T;F\@;FD@=F5L:F%V96X@<F%R(&%R:&EV+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I
M;&4N(@IM<V=S='(@(D1A=&]T96MA('9E<FIE=&YO(&YI('9E;&IA=F5N('II
M<"!A<FAI=BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"FUS
M9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BXB"FUS9W-T<B`B5G!I<V%N82"Y=&5V:6QK82!N:2!V96QJ879N82"Y
M=&5V:6QK82!K<F5D:71N92!K87)T:6-E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5&$@9V]N:6QN
M:6L@;VUO9V_H82!P;[EI;&IA;FIE('-P;W)OZ&EL('!R96MO($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+B(*(F-O;2D@<')E:&]D82!Z('5P;W)A
M8F\@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*(E1A(&=O;FEL;FEK(&]M;V=OZ&$@<&^Y:6QJ86YJ92!S
M<&]R;^AI;"!P<F5K;R!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN(@HB
M8V]M*2!P<F5H;V1A('H@=7!O<F%B;R!(5%10($%022(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5&$@9V]N
M:6QN:6L@;VUO9V_H82!P;[EI;&IA;FIE('-P;W)OZ&EL('!R96MO('-M<S)E
M;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"XB"B)C;VTI('!R96AO9&$@>B!U<&]R
M86)O($A45%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@
M;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*
M(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@
M(B(*(E1A(&=O;FEL;FEK(&]M;V=OZ&$@<&^Y:6QJ86YJ92!S<&]R;^AI;"!P
M<F5K;R!33510('!R96AO9&$@5F]D869O;F4@(@HB271A;&EJ87-A;6\@5F]D
M869O;F4@N71E=FEL:V%M+B!:86AT979A;B!J92!O8G-T;VIEZ"!E+7!ON71N
M:2!N87-L;W8@<')I("(*(E9O9&%F;VYE($ET86QI:F$@*&AT='`Z+R]W=W<N
M,3DP+FET*2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E
M<75I<F5D+B(*;7-G<W1R(")4;R!P;VQJ92!J92!O8G9E>FYO+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B5&\@<&]L:F4@
M;&%H:V\@=G-E8G5J92!S86UO(+ET979I;&ME+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(E1O('!O
M;&IE(&QA:&MO('9S96)U:F4@<V%M;R"Y=&5V:6QK92!I;B!D=F]P:>AJ92XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R
M(")4;R!P;VQJ92!L86AK;R!V<V5B=6IE('-A;6\@;VMT86QN92!V<F5D;F]S
M=&DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B5&\@<&]L:F4@;6]R82!V<V5B
M;W9A=&D@<V5Z;F%M(+ET979I;"!L;^AE;B!Z(&1V;W!IZ&II(&%L:2!P<F5S
M;&5D:VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B
M5&\@<&]L:F4@;6]R82!V<V5B;W9A=&D@=F5L:F%V;F\@N71E=FEL:V\N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R
M("(B"B)4;R!P;VQJ92!M;W)A('9S96)O=F%T:2!K;V1O(&)A<G9E('8@;V)L
M:6MI(%)'0B!(97@L(&YA<')I;65R("<C,3(S-&%F)RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR
M96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B5&$@;V)R87IE8R!J92!B
M:6P@OF4@;V)D96QA;BXB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")4
M;R!J92`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W
M87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D
M(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA
M8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@
M(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB5&$@;V)J
M96MT(&IE(&EZ($MO;&%B($=R;W5P=V%R92X@R&4@9V$@OF5L:71E('!R:6MA
M>F%T:2P@<&]T<F5B=6IE=&4@(@HB<')O9W)A;7IA(&4M<&^Y=&\L(&MI('!O
M>FYA(&9O<FUA="!+;VQA8B!'<F]U<'=A<F4N(%IA('-E>FYA;2!P<F]G<F%M
M;W8@(@HB;V)IN>AI=&4@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S
M86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R
M('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(E1O('-P;W)OZ&EL;R!J92!B:6QO
M(&YA<&ES86YO('8@9')U9VD@:V]D;FD@=&%B96QI("@E<RD@:V]T(&IE('9A
MN6$N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G
M:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R
M(")4;R"Y=&5V:6QO(&UO<F$@8FET:2!V<V%J(&5N82XB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*
M;7-G<W1R(")482!S=')EOFYI:R!N92!M;W)E(&]D:V]M<')E<VER871I('II
M<"!I;B!G>FEP(&1A=&]T96LN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B4VES=&5M(&IE('1R96YU=&YO
M(&1E86MT:79I<F%N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM
M<V=S='(@(E1A('9R961N;W-T(&UO<F$@8FET:2"Y=&5V:6QO+B(*"B,Z('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B
M"FUS9W-T<B`B5&\@;VMN;R!J92!P;W1R96)N;R!O9'!R971I(&EZ(&]K;F$@
M36^^;F]S=&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")3=')E;&$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM
M<V=S='(@(E9S=&]P;FEC92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4
M:6UE(@IM<V=S='(@(LAA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B4VQE9&5N:F4@
MZ&%S82(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F
M;W)M870B"FUS9W-T<B`B3V)L:6MA('IA<&ES82#H87-A(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB
M"FUS9W-T<B`B27IB:7)A(.AA<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(DYA<VQO=B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B3F%S;&]V("AO:W9I<NAE
M:RDZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B6F$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE
M8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I
M(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G
M<W1R("(B"B):82!I>F)I<F\@=F7H:6@@;6^^;F]S=&DL(&1ROFET92!T:7!K
M;R!#;VYT<F]L("A00RD@86QI($-O;6UA;F0@*$UA8RD@;65D("(*(FML:6MA
M;FIE;2!N82"^96QJ96YE(&UOOFYO<W1I+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D1A;F5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E!R:6MAOFD@
M2%1-3"!I>G9O<FYO(&MO9&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O
M(@IM<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U
M(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")*=71R:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W
M"FUS9VED(")4;W`B"FUS9W-T<B`B6F=O<F%J(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE
M("A?=&]P*2(*;7-G<W1R("):9V]R;FII(&]K=FER("A?=&]P*2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM
M<V=S='(@(E!R979O9&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A
M9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D(&EN(%1O8F%G;R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@
M9F%L<V4B"FUS9W-T<B`B1'*^:2!A;&D@;F4@9'*^:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM
M<V=S='(@(E1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G
M<W1R(")4=6YI>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*
M;7-G<W1R(")4=7+H:6IA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*
M;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<KEK;R`H
M25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T
M86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I
M9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS(&EN
M($-A:6-O<R!O=&]K:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*
M;7-G<W1R(")4=79A;&DB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T
M"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B5G!IN6ET92!I
M>F)I<F\Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*
M;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R(")5+E8N(&EN9&5K<SH@(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E52
M3"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0B"FUS9W-T<B`B55),('IA(&1O<W1A=F\@<W1A='5S82!S
M:W)I<'1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86II;F$B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&]S=&]P(&1O(%9&
M4R!M87!E(&YI(&UO9V_H+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN
M9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B4')I('!R:6IA
M=FQJ86YJ=2!N:2!M;V=OZ&4@9&]D871I(&1O9&%T;FEH(&EN9F]R;6%C:6H@
M;R!U<&]R86)N:6MU+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").:2!M;V=O
MZ&4@<W!R96UE;FET:2!P<F%V:6,@>F$@5D93(&1A=&]T96MO(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R(").:2!M;V=OZ&4@<W!R96UE;FET:2!P<F%V:6,@>F$@5D93
M(&1A=&]T96MO("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N(@IM<V=S='(@(B5S(&YI(&UO9V_H92!S<')E;65N:71I+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB
M)7-<(BXB"FUS9W-T<B`B5D93(&1A=&]T96ME(%PB)7-<(B!N:2!M;V=OZ&4@
M;V1P<F5T:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R(")61E,@9&%T;W1E:V4@)7,O)7,@;F\@;6]G;^AE('!R96EM
M96YO=F%T:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G
M<W1R(")0;W9E>F%V82!N82!344P@<W1R9;YN:6L@;FD@;6]G;^AA+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B4&]V97IA=F$@<R!34TP@
M;FD@;6]G;^AA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R
M-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G
M<W1R(")+;W!I<F%N:F4@5D93(&1A=&]T96ME(&YI(&UO9V_H92XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("))>F1E;&%V82!61E,@;6%P92!<(B5S7"(@;FD@;6]G;^AA+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B27ID96QA=F$@5D93(&UA<&4@;FD@;6]G;^AA
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DEZ9&5L879A
M(%9&4R!D871O=&5K92!N:2!M;V=OZ&$N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E9&
M4R!D871O=&5K92!<(B5S7"(@;FD@;6]G;^AE('!R96EM96YO=F%T:2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DEZ9&5L879A
M('!R87IN92!61E,@9&%T;W1E:V4@;FD@;6]G;^AA+B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B4&]D871K;W8@;FD@;6]G;^AE
M(&]D:V]M<')E<VER871I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B7"(E<UPB(&YI(&UO9V_H
M92!P;V)R:7-A=&DL(&UA<&$@;FD@<')A>FYA+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R("(G)7,G(&YI(&UO9V_H92!P;V)R:7-A=&DZ("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B)7,@;FD@;6]G;^AE('!O
M8G)I<V%T:2P@;6%P82!N:2!P<F%Z;F$B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B5D93(&UA<&4@;FD@;6]G;^AE(')E
M:W5R>FEV;F\@<&]B<FES871I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(E9&4R!M87!E(&YI(&UO9V_H92!P;V)R:7-A=&DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B5D93
M(&UA<&4@;FD@;6]G;^AE('!O8G)I<V%T:3H@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R!D
M871O=&5K92!N:2!M;V=OZ&4@<&]B<FES871I(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V
M-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G
M<W1R(")61E,@9&%T;W1E:V4@;FD@;6]G;^AE('!O8G)I<V%T:2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<
M(BXB"FUS9W-T<B`B5D93(&1A=&]T96ME(&YI(&UO9V_H92!P;V)R:7-A=&D@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RXB"FUS9W-T<B`B5D93(&YI(&UO9V_H92!R96MU<GII=FYO
M('!O8G)I<V%T:3H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN(@IM<V=S='(@(E1R96YU=&YE(&UA<&4@;FD@8FEL;R!M;V=OZ&4@
M=6=O=&]V:71I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS(@IM<V=S='(@(E!O9')O8FYO<W1I(&\@<&]T<F1I;'4@;FD@8FEL
M;R!M;V=OZ&4@:7IV;&7H:2XB"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B1&5F:6YI8VEJ92`E<R!N:2!M;V=O
MZ&4@;F%L;[YI=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+B(*;7-G<W1R(")61E,@9&%T;W1E:V4@;FD@;6]G;^AE('!R96UA:VYI
M=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B5D93(&1A=&]T96ME(%PB)7-<(B!N:2!M;V=OZ&4@;V1P
M<F5T:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B5D93(&1A=&]T96ME
M(&YI(&UO9V_H92!O9'!R971I('IA(&)R86YJ92XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1A
M=&]T96ME(&YI(&UO9V_H92!O9'!R971I+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B2V]M<')E<VER86YE9V$@
M87)H:79A(&YI(&UO9V_H92!O9'!R971I+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(E9&4R!D871O
M=&5K92!N:2!M;V=OZ&4@>F%P:7-A=&D@*'5K87H@8V]P>2@I(&IE('-P;V1L
M971E;"DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93(&1A=&]T96ME(&YI(&UO9V_H92!Z
M87!I<V%T:2`H=6MA>B!C;W!Y*"D@:F4@<W!O9&QE=&5L*2XB"@HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z
M,S@*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G
M<W1R(")61E,@9&%T;W1E:V4@;FD@;6]G;^AE('!R96EM96YO=F%T:2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B=F9S
M<F]O="!M87!E(&YI(&UO9V_H92!P<F5B<F%T:2XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(B5S(&YI(&UO9V_H92!P<F5I;65N;W9A
M=&D@=B`E<SH@;6%P82"^92!O8G-T86IA(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@;6%P92!N:2!M;V=OZ&4@<')E
M:6UE;F]V871I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(E9&4R!M87!E(&YI(&UO9V_H92!P<F5I
M;65N;W9A=&DZ("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")61E,@9&%T;W1E:V4@7"(E<UPB(&YI(&UO9V_H92!P<F5I;65N
M;W9A=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B5D93(&1A=&]T96ME("5S+R5S(&YO(&UO9V_H92!P<F5I;65N;W9A=&DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1A
M=&]T96ME(&YI(&UO9V_H92!P<F5I;65N;W9A=&DN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B56MA>F$@)VUK
M:7-O9G,G(&YI(&UO9V_H92!Z86=N871I+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(E=O<F1O=F4@
M9&%T;W1E:V4@;FD@;6]G;^AE('!R979E<W1I+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R!D871O=&5K92!<(B5S7"(@;FD@
M;6]G;^AE('IA<&ES871I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93(&1A=&]T96ME(&YI(&UO9V_H92!Z
M87!I<V%T:2`H=6MA>B!C;W!Y*"D@:F4@<W!O9&QE=&5L*2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB"FUS9W-T<B`B4&]D871K;W8@;R!61E,@9&%T;W1E:VD@;FD@;6]G;^AE
M('IA<&ES871I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B5D93(&1A=&]T96ME(&YI(&UO
M9V_H92!Z87!I<V%T:2`H=6MA>B!C;W!Y*"D@:F4@<W!O9&QE=&5L*2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS
M9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B4&]DZ')T86YO(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S
M='(@(E)A>G9E;&IA=FD@<W!R96UE;6)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@
M;&%S="!A8W1I;VXB"FUS9W-T<B`B4F%Z=F5L:F%V:2!Z861N:F4@9&5J86YJ
M92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@(@IM<V=S='(@(DYE<')IZ&%K;W9A;B!O9'II=B!S=')EOFYI
M:V$@;V(@<&]V97IA=FDZ("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@(@IM<V=S='(@(DYE<')IZ&%K;W9A;B!O9'II=B!S=')EOFYI
M:V$@;F$Z("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DYE;F%P;VQN
M:F5N;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC
M;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(EID
M<G6^96YI($%R86)S:VD@16UI<F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B6F1R=;YE;F\@:W)A;&IE<W1V;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B
M6F1R=;YE;F4@9'*^879E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(EID<G6^
M96YE(&1ROF%V92`M(&UA;FJY:2!I>G9E;BUL9;YEZ&D@;W1O:VDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B16YO=&4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(DYE
M>FYA;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+B(*;7-G<W1R(").97IN86X@87!I;7-G:60@*$E$($%022!S<&]R
M;^AI;&$I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+B(*;7-G<W1R(").97IN86X@8VQI;7-G:60@*$E$(&]D
M:F5M86SH979E9V$@<W!O<F_H:6QA*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("),;VMA8VEJ82!N:2!N87-T879L:F5N
M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(DYE>FYA;F\@=7!O<F%B;FFY:V\@:6UE(&%L:2!G97-L;RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM
M<V=S='(@(D]D<W1R86YI('!O=F5Z879O('1R96YU=&YE9V$@96QE;65N=&$B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@IM<V=I
M9"`B56YN86UE9"(*;7-G<W1R(").96EM96YO=F%N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)3:W)I<'1E(&)R
M97H@<')A=FEC(&YE(&UO<F%J;R!U<&]R86)L:F%T:2!U:V%Z;W8@27IR9;YI
M+TMO<&ER86HO4')I;&5P:2!I>B`B"B)V87)N;W-T;FEH(')A>FQO9V]V+B!+
M;&EK;FET92!/2R!Z82!T96AN:>AN;R!R87IL86=O(&YA(&UO>FEL;&$N;W)G
M(&MI("(*(G!O;F%Z87)J82P@:V%K;R!O;6]G;^AI=&D@<VMR:7!T:2!D;W-T
M;W`@9&\@;V1L;[YIN>AA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(DYE;F%S=&%V;&IE;F$@8F%R=F$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@
M(DYE<&]D<')T(&1O9&%T96LB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM
M<V=I9"`B57!D871E(@IM<V=S='(@(E!O<V]D;V)I(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&4@)7,B"FUS9W-T<B`B4&]S;V1O8FD@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E
M<B(*;7-G<W1R(")0;W-O9&]B:2!U<&]R86)N:6MA(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")0;W-O9&]B:6P@)R5S)RXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4VMR:7!T82!Z82!N861G<F%D
M;FIO('!O8G)I<V%N82XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G
M:60@(E5P;&]A9"(*;7-G<W1R(")3:')A;FD@;F$@<W1R9;YN:6LB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`B5G-E(&YA;65S=&ET=F5N92!D871O=&5K92!S:')A;FIE;F4@;F$@<W1R
M9;YN:6LN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R(")696QI:V4@;&%T:6YS:V4@Z')K92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@
M(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B5F5L:6ME(')I;7-K92"Y
M=&5V:6QK92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T
M<B`B57)A9W9A:B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R
M96YT.B`E<R(*;7-G<W1R(")5<&]R86)I('1R96YU=&YO.B`E<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS
M9VED(")5<V4@4U-,(@IM<V=S='(@(E5P;W)A8FD@4U-,(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B57!O
M<F%B:2#H92!S92!I;64O9V5S;&\@<F%Z;&EK=6IE=&$@>F$@24U34"!S=')E
MOFYI:RXB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q
M"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(E5P;W)A8FYI:VDB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O
M<B`E<RXB"FUS9W-T<B`B57!O<F%B;FEK("5S(&YI('!O;V)L8;GH96X@>F$@
M)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:6IA('5P;W)A8FYI:V]V
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@
M(E5S97(@3W!T:6]N<R(*;7-G<W1R(")-;[YN;W-T:2!U<&]R86)N:6MO=B(*
M"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM
M<V=S='(@(E)E9VES=')A8VEJ82!U<&]R86)N:6MO=B(*"B,Z('-I9VYU<"YP
M:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(E)E9VES=')A8VEJ82!U<&]R
M86)N:6MO=B!J92!Z82!T;R!S<&QE=&YO(&UE<W1O(&]N96UO9V_H96YA+B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*(RP@9G5Z>GD*;7-G:60@
M(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@;FD@;6]G;^AE
M(&YA:G1I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE
M(@IM<V=S='(@(E5P;W)A8FYIN6MO(&EM92(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M57!O<F%B;FFY:V\@:6UE("<E<R<@OF4@;V)S=&%J82XB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G
M<W1R(")5<&]R86)N:;EK;R!I;64Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")5<&]R86)N
M:;EK;R!I;64Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5P;W)A
M8FYI:VD@=B!S:7-T96UU.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K
M:7-T86XB"FUS9W-T<B`B57IB96MI<W1A;B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(E9&4R!M87!A(&YE(&]B<W1A:F$N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B1&]P=7-T
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(E5S=')E>FYE
M(&YA:F1E;F4@;&]K86-I:F4@=FML:G7H=6IE:F\Z("(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*
M;7-G<W1R(")696QJ879N;W-T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M
M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")6<F5D;F]S="!V(&UI;G5T86@@
M;V0@=&5G82!T<F5N=71K82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O
M9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B5G)E9&YO<W1I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T
M<B`B5G)E9&YO<W1I('IA(&EZ8FER;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E-P
M<F5M96YL:FEV;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(D]V97)J86YJ92!S<&]D;&5T96QO("T@<W!O<F_H:6QO(&IE(&)I;&\@
M<W!R96UE;FIE;F\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R>FEJ82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@
M0V]N=')O;"(*;7-G<W1R(").861Z;W(@=F5R>FEJ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B
M5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B3F%V<&GH;F$@<&]R879N879A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM
M<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(").879P:>AE;B!O9&UI
M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(").879P:>AN;SHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B
M5F5R>2!(:6=H(@IM<V=S='(@(EIE;&\@=FES;VMO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI
M(@IM<V=S='(@(E9I971N86US:V\@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R(")0<FEK8;YI("5S(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M92(*;7-G<W1R(")0<FEK8;YI('IU;F%N:F\@<W!L971N;R!S=')A;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(E!R:6MAOFD@:V]T
M("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R
M:71I<V@B"FUS9W-T<B`B0G)I=&%N<VMI($1E=FFY:VD@;W1O:VDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R
M(")!;65R:;EK:2!$979IN6MI(&]T;VMI(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FED;&II=F]S
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6:61L:FEV;W-T.B`B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM
M<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O
M;F4@271A;&EJ82!P<F5K;R!33510(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I
M9"`B5T%23B(*;7-G<W1R(")/4$]:3U))(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(D]03UI/
M4DE,3R$A(2!23\A.3R!/1%-44D%.251%(%-+4DE05$\@25H@)7,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*(RP@9G5Z
M>GD*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@<')E
M:V\@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T
M=6YA(@IM<V=S='(@(E=A;&QI<R!I;B!&=71U;F$B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W
M,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS
M9W-T<B`B3W!O>F]R:6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B4W(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@
M1F]R96-A<W0B"FUS9W-T<B`B5G)E;65N<VMA(&YA<&]V960B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A
M=&$@<')O=FED960@8GDB"FUS9W-T<B`B5G)E;65N<VMO(&YA<&]V960@<')I
M<VMR8F5L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED
M(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B4W!L970B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@
M4VET92(*;7-G<W1R(")3<&QE=&YO(&UE<W1O(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM
M<V=S='(@(E1E9&5N<VMO(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B1&]B<F]D;[EL:2(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O
M("5S(@IM<V=S='(@(D1O8G)O9&^Y;&D@=B`E<R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")$
M;V)R;V1ON65L+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS
M9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("):86AO9&YO("A)
M4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B6F%H;V1N;R`H25-/
M+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A
M(@IM<V=S='(@(EIA:&]D;F$@4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")+
M871E<F\@87!L:6MA8VEJ;R!N86H@)7,@<')I:V&^92!P;R!P<FEJ879I/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")+871E<FD@
M>FYA:R!R87IM96IU:F4@<&]L:F$_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\B"FUS9W-T<B`B2V%T97)I('IN86L@:F4@=7!O<F%B;&IE;B!Z82!C:71I
M<F%N:F4_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-C$*(RP@9G5Z>GD*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R(")!=G-T<F%L:6IA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B2V%T97)E(&UE;F4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM
M<V=S='(@(B(*(DMA=&5R:2!P;'5G:6YI+2!N86H@8F]D;R!O;6]G;^AE;FD@
M>F$@=7)E:F5V86QN:6L@;V)O9V%T96YE9V$@8F5S961I;&$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM
M<V=I9"`B5VED=&@B"FUS9W-T<B`BJ6ER:6YA(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM
M<V=S='(@(JEI<FEN82!V($-34R!E;F]T86@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R("*I:7)I;F$@)7,@;65N=6IA(&YA(&QE=FD@*'9E
M;&IA(&]B(&YA<VQE9&YJ:2!P<FEJ879I*3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@
M=&AE('1A8FQE(@IM<V=S='(@(JEI<FEN82!T86)E;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED
M=&@@=6YI="(*;7-G<W1R(")%;F]T82"Y:7)I;F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z
M(@IM<V=S='(@(JEI<FEN83HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(E9E=&5R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*
M(RP@9G5Z>GD*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B1&6^('IG;V1A
M:B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E
M960@:6X@:VYO=',B"FUS9W-T<B`B2&ET<F]S="!V971R82!V('9O>FQI:"(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G
M<W1R(")6971E<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5F5T97(Z("(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(DUO
M9')O<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"B,L(&9U
M>GIY"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")397IN86UI(+YE;&IA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S
M='(@(D1E;&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")3;'6^8F5N
M:2!N87-L;W8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E-L=;YB96YI
M('1E;&5F;VXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP
M96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W
M:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(D1O<W1O<"!P<FD@
M:7ID96QO=F%N:G4@5D93(&1A=&]T96ME('IA=G)N:F5N+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@
M(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8
M-3`Y=C,@3W-N;W9N92!O;65J:71V92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y
M(%5S86=E(@IM<V=S='(@(E@U,#EV,R!0;V1A;&JY86YA('5P;W)A8F$@:VQJ
M=>AA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T
M<B`B6#4P.78S($%L=&5R;F%T:79N;R!I;64@<W5B:F5K=&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S
M(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S($ED96YT
M:69I:V%C:6IA(&ML:G7H82!S=6)J96MT82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R(")8-3`Y=C,@9&]D871K:2(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")962(*;7-G<W1R("),3"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*;7-G
M<W1R("),3$Q,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B66%H;V\A
M('IE;6QJ979I9"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("),971N;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I
M9"`B665S(@IM<V=S='(@(D1A(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G
M<W1R(")$82P@<W1R:6YJ86T@<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RXB"FUS9W-T<B`B(@HB4W1E('8@0D53141)3$Y%32!.0<A)3E4N
M(%5P;W)A8FET92!;/#Y=(&=U;6(@>F$@<')E:VQO<"!N87IA:B!V(%=94TE7
M64<N(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N
M=&EC871E9"XB"FUS9W-T<B`B3FES=&4@8FEL:2!O=F5R:F5N:2XB"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U
M(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL
M(&YA;64N(@IM<V=S='(@(E9AN64@<&]L;F\@:6UE(&YE('-M92!V<V5B;W9A
M=&D@>FYA:V$@)UQ<)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B
M3FES=&4@=G!I<V%L:2!V96QJ879N96=A(&YA<VQO=F$@92UP;[ET92XB"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I
M;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I
M;B`E<RXB"FUS9W-T<B`B(@HB3FES=&4@<&]V97IA;&D@;F]B96YE9V$@<&]L
M:F$@:7H@=79OOF5N92!D871O=&5K92!Z('5S=')E>FYI;6D@<&]L:FD@=B`E
M<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO
M=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B3V1J879I;&D@<W1E
M('-E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@
M(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)6
M<&ES871I(&UO<F%T92!V96QJ879N;R"Y=&5V:6QK;R!M;V)I;&YE9V$@=&5L
M969O;F$@+2!S86UO(+ET979I;&ME('H@(@HB;W!C:6IS:VEM("<K)R!Z82!M
M961N87)O9&YO('!R961P;VYO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N(@IM<V=S='(@(E9P:7-A=&D@;6]R871E('9E;&IA=FYO('9R961N;W-T
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I
M9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U
M<V4@4VEG;G5P<RXB"FUS9W-T<B`B1&%T871R964@;6]R871E(&MO;F9I9W5R
M:7)A=&D@>F$@=7!O<F%B;R!3:6=N=7!S+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"XB"FUS9W-T<B`B5D93(&UO<F%T92!K;VYF:6=U<FER871I
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED
M(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B4')E9&5N('!O
MN6QJ971E('!O<F_H:6QO(&\@;F%P86MI+"!M;W)A=&4@;F%P86MO(&]P:7-A
M=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(E9P:7-A=&D@;6]R871E(%523"!K
M86UO<B!N86H@=&$@<&]V97IA=F$@:V&^92(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(DEZ8G)A=&D@;6]R871E('-T
M<F6^;FEK+"!K:2!G82"^96QI=&4@:7IB<FES871I+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(&-L96%R(&]U="XB"FUS9W-T<B`B3F%V97-T:2!M;W)A=&4@=7!O<F%B
M;FFY:V\@:6UE+"!K:2!G82"^96QI=&4@<&_H:7-T:71I+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92XB"FUS9W-T<B`B3F%V97-T:2!M;W)A=&4@=7!O<F%B
M;FFY:V\@:6UE+"!K:2!G82"^96QI=&4@;V1S=')A;FET:2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"XB"FUS9W-T<B`B3F%V97-T:2!M;W)A=&4@=7!O<F%B;FFY:V\@:6UE+"!K
M:2!G82"^96QI=&4@9&]D871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+B(*;7-G<W1R(").879E<W1I(&UO<F%T92!U<&]R86)N:;EK;R!I;64L(&MI
M(&=A(+YE;&ET92!P;W-O9&]B:71I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(").879E<W1I(&UO
M<F%T92!D96IA;FIE+"!K:2!N86H@<V4@:7IV961E+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(E9P
M:7-A=&D@;6]R871E(&EM92!N;W9E(&MA=&5G;W)I:F4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G
M:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")68;EA("5S('-E
M:F$@:F4@<&]T96ML82X@4&]N;W9N;R!S92!P<FEJ879I=&4N(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA
M:6P@061D<F5S<R(*;7-G<W1R(")68;EA(&4M<&^Y=&YI(&YA<VQO=B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@
M861D<F5S<SHB"FUS9W-T<B`B5F&Y($]D.B!N87-L;W8Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E9AN6D@
M<&]D871K:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*(E9AN2!I;G1E<FYE=&YI(&YA<VQO=B!S
M92!J92!S<')E;65N:6P@;V0@>F'H971K82`E<R!S96IE+B!)>B!V87)N;W-T
M;FEH("(*(G)A>FQO9V]V('-E(&UO<F%T92!P;VYO=FYO('!R:6IA=FET:2XB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B
M66]U<B!.86UE(@IM<V=S='(@(E9AN64@:6UE(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN
M9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN
M:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT
M("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(E9AN6$@
M:')B=&5N:6-A('IA(&]V97)J86YJ92!N92!P;V1P:7)A(&1O9&%J86YJ82!U
M<&]R86)N:6MO=BP@86QI('!A(&IE(&)I;&$@(@HB=&$@;6^^;F]S="!I>B!N
M96ME9V$@<F%Z;&]G82!O;F5M;V=OZ&5N82XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE
M(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB5F&Y82!H<F)T96YI8V$@>F$@
M;W9E<FIA;FIE(&YE('!O9'!I<F$@<')I:V%Z;W9A;FIA('5P;W)A8FYI:V]V
M+"!A;&D@<&$@:F4@(@HB8FEL82!T82!M;[YN;W-T(&EZ(&YE:V5G82!R87IL
M;V=A(&]N96UO9V_H96YA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E9AN2!B<G-K86QN
M:6L@<V4@:F4@<W!R96UE;FEL(&]D('IAZ&5T:V$@=F&Y92`E<R!S96IE+B!)
M>B!V87)N;W-T;FEH("(*(G)A>FQO9V]V('-E(&UO<F%T92!P;VYO=FYO('!R
M:6IA=FET:2XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*
M;7-G<W1R(")68;D@8G)S:V%L;FEK(&YE('!O9'!I<F$@=&4@;6^^;F]S=&DN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*(RP@9G5Z
M>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*
M(G1O('!R:6YT+B(*;7-G<W1R("(B"B)68;D@8G)S:V%L;FEK(&YE('!O9'!I
M<F$@=&4@;6^^;F]S=&D@>F$@=&ES:V%N:F4N(%!R:71I<VYI=&4@0V]N=')O
M;"]/<'1I;VX@(@HB*R!0('IA('1I<VMA;FIE+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z
M(@IM<V=S='(@(E9AN2!T<F5N=71E;B#H87-O=FYI('!A<SHB"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")68;EA('!R
M:79Z971A(&ED96YT:71E=&$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")6
M8;EA('!R:79Z971A(&ED96YT:71E=&$Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E9A
MN64@<&]L;F\@:6UE.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P
M,#`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM
M<V=S='(@(E9AN64@;F%S=&%V:71V92!S;R!B:6QE('!O<V]D;V)L:F5N92XB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM
M<V=S='(@(E9AN64@;F]V;R!G97-L;R!Z82`E<R!J93H@)7,B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I
M;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")68;EE(&YA<W1A=FET=F4@
M<V\@8FEL92!P;W-O9&]B;&IE;F4N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"XB"FUS9W-T<B`B5F&Y92!N87-T879I='9E('-O(&)I;&4@<&]S
M;V1O8FQJ96YE+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U
M"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@
M(E9AN64@9V5S;&\@:F4@8FEL;R!P;VYA<W1A=FQJ96YO(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)68;EE
M(&=E<VQO(&IE(&)I;&\@<&]N87-T879L:F5N;RX@4&]G;&5J=&4@=F&Y;R!E
M+7!ON71O(&EN('-E('!R:6IA=FET92!Z("(*(FYO=FEM(&=E<VQO;2XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E9AN64@9V5S
M;&\@:F4@8FEL;R!P;VYA<W1A=FQJ96YO(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*
M;7-G<W1R(")68;EI(&]D9&%L:F5N:2!S=')EOFYI:VDZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O<VQA
M=FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)V92(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<&DB
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B
M6U-K<FEJ(&-I=&ER86YO(&)E<V5D:6QO72(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM0
M;W)OZ&EL;R!O(&YA<&%K:5TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*
M;7-G<W1R(");4')I:V&^:2!C:71I<F%N;R!B97-E9&EL;R`M(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP
M.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M
M("5S(&QI;F5S72(*;7-G<W1R(");4')I:V&^:2!C:71I<F%N;R!B97-E9&EL
M;R`M("5S('9R<W1I8UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS
M9W-T<B`B6W9R<W1I8V$@)7,@;V0@)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*
M;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R86-I
M:F$B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM
M<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B
M"FUS9W-T<B`B7TEZ8G)IN6D@=G)S=&EC;R(*"B,Z(&QI8B]A<&DN<&AP.C$S
M,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?4VMU<&EN92(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM
M<V=S='(@(E]0;VUOZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B7TQA<W1N;W-T:2!S;&EK92XN+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB
M"FUS9W-T<B`B7U!R:6IA=F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?3V1J879A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7U-P
M<F5M96YI('!O=F5Z879O+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7TUOOFYO
M<W1I(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B7U!R879I8V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN
M:RXN+B(*;7-G<W1R(")?3V1S=')A;FD@<&]V97IA=F\N+BXB"@HC.B!L:6(O
M87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?3F%M97-T:71E
M=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B7TQA<W1N;W-T:2!T86)E;&4N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*
M;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?57!O<F%B;FEK:2(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"FUS9VED(")A9&1R97-S(&)O;VLB
M"FUS9W-T<B`B861R97-A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W
M;B(*;7-G<W1R(")A9')E<V%R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,3,*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(FMO;&5D87(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(FUI<FYO
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G
M:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A
M;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G
M<W1R(")K;&EK;FET92!S96TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM
M<V=S='(@(B5S($YA<W1A=FET=F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*
M(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")N:2!N
M86ID96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")P861A:F_H(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"FUS9VED(")F:6QE(@IM
M<V=S='(@(F1A=&]T96MA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<R(*;7-G<W1R(")O9"`E<R`H)7,I('!R:2`E<R`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*(RP@9G5Z>GD*;7-G:60@(F=U
M<W1I;F<B"FUS9W-T<B`B+"!P:6AA:F_H("5S("5S(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS
M9W-T<B`B=CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N
M:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS
M9W-T<B`B=&%K;VJY;FDB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A
M9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@
M(FYO=')A;FII(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B
M:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S
M72(*;7-G<W1R(")V<G-T:6-E72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB
M"FUS9W-T<B`B;6MI<V]F<R!N87!A:V$@N71E=FEL:V$@)60@;65D(&EZ9&5L
M879O($E33R!P;W-N971K82XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`B:6UE(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM
M<V=S='(@(FYI(&EM<&QE;65N=&ER86XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT
M960B"FUS9W-T<B`BN64@;FD@:6UP;&5M96YT:7)A;B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@
M(F)E;&6^;FEC82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B;V1S
M=&]T96LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B
M4')A=FEC82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:7AL;W8B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R
M:7-I;F<B"FUS9W-T<B`B<F%S=&_H(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B365T87(@8FQO:R!N:2!N82!V;VQJ;RXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E
M<F5N8V5S(@IM<V=S='(@(G!O:V&^:2!R87IL:6ME(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M
M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@<')E:V\@2%14
M4"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
M;6ER;F\B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I
M9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")S97IN86T@;W!R879I
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G
M86EN(@IM<V=S='(@(D]B('9S86MI('!R:6IA=FDB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS
M9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S
M='(@(G9P:;EI=&4@9V5S;&\@9'9A:W)A="!Z82!P;W1R9&ET978B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW
M.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")Z9')UOF5N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R(")N96EM96YO=F%N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*
M;7-G<W1R(")I>F)I<F$@=7!O<F%B;FEK82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T
M<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("*Y.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G
M<W1R(")W96%T:&5R+F-O;2(*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P;R]S=E]312YP;P``````````````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`Q,3,Q,#<U`#$P-#$W,S8S
M,#`S`#`Q-C0Q,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````C($AO<F1E(%-W961I<V@@=')A;G-L871I;VX*(R!#;W!Y<FEG
M:'0@*$,I(#(P,#(M,C`P-B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES
M(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO
M<F1E('!A8VMA9V4N"B,@2F]A<75I;2!(;VUR:6=H875S96X@/&IO:&]`=V5B
M8G!L871S96XN<V4^+"`R,#`V+@HC($%N9')E87,@1&%H;.EN(#QA;F1R96%S
M0&1A:&QE;BYW<SXL(#(P,#4N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,5QN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`R+3$U(#$Q.C(Q*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#8M,#(M,38@,#`Z,C8K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!*;V%Q=6EM($AO;7)I9VAA=7-E;B`\:F]H;T!W96)B<&QA='-E;BYS93Y<
M;B(*(DQA;F=U86=E+51E86TZ(%-W961I<V@@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B(*;7-G<W1R("(B"B(@
M)B,Q-3$[("5S(&MO;6UE<B!A='0@=71F]G)A(&1E('5N9&5R:.5L;'-A:W1I
M=FET971E<FYA('-O;2!M87)K97)A=',@;F5D86XN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,V.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@
M*"5S(&1A9V%R('-E9&%N*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3,R-B!L:6(O2&]R9&4N<&AP.C$S-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H<VYA8F)T86YG96YT("5S
M*2(*"B,Z('1E;7!L871E<R]L:6YK<R]L:6YK<RYI;F,Z-`IM<V=I9"`B("A2
M96%D(&]N;'DI(@IM<V=S='(@(B`H4VMR:79S:WED9&%D*2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R
M("(@*&]M("5S(&1A9V%R*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*;7-G:60@(B`H=&]D87DI
M(@IM<V=S='(@(B`H:61A9RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<U(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R
M<F]W*2(*;7-G<W1R("(@*&EM;W)G;VXI(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0IM<V=I9"`B
M("AY97-T97)D87DI(@IM<V=S='(@(B`H:6?E<BDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM
M<V=I9"`B(&%T("(*;7-G<W1R("(@:VP@(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR,34@;&EB+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R
M("(G)7,G(.1R(&EN=&4@96X@:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C<R(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G
M<W1R("(G)7,G(.1R(&EN=&4@971T(&=O9&OD;G0@=F%L+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4V"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`S.2!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C<Q,`HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R#D<B!I;G1E
M(&MO;F9I9W5R97)A="!I($AO<F1E<F5G:7-T<F5R="XB"@HC.B!F<F%M97=O
M<FLO5')E92]4<F5E+G!H<#HQ-S$@;&EB+TAO<F1E+U1R964N<&AP.C$W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E1RY&1H86YT97)A<F5N(&;V<B`E<R!S86MN87,N
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G
M<W1R("(G)7,G(&QA9&5S('1I;&P@:2!G<G5P<'-Y<W1E;65T+B(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M(@IM<V=S='(@(B<E<R<@;&%D97,@=&EL;"!I(&)E:/9R:6=H971S<WES=&5M
M970N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E<R<@<VMA<&%D97,@:6YT93H@
M)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F
M)24I(@IM<V=S='(@(B4N,F9-0B!A;G;D;G0@878@)2XR9DU"('1I;&SE=&5T
M("@E,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E
M9"`E<R!O8V@@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C(V."!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR-C@*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B1&ET="!L
M]G-E;F]R9"!U<'!H]G(@871T(&?D;&QA(&]M("5D(&1A9V%R+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D+61A9W-P<F]G;F]S
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X('1E;7!L871E<R]M
M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@1O9R(&OD;FYE9&]M(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B1FEN9V5R<')I;G0@9O9R("5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,R(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-`HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.#0Q(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HX-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B
M)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHT"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VXB"FUS9W-T<B`B)7,@56YD97)HY6QL<V9U;FMT:6]N("T@0F5K<N1F
M=&5L<V4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T
M=7`B"FUS9W-T<B`B)7,@4V5T=7`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8S(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@
M86YMY&QA;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.2!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B
M5&KD;G-T96%V=&%L(&;V<B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S$Y"B,Z(&QI8B]61E,O<VUB+G!H<#HT,S(@;&EB+U9&4R]S
M;6(N<&AP.C0Y-"!L:6(O5D93+V9T<"YP:'`Z-C@R"B,Z(&QI8B]61E,O9G1P
M+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES
M=',N(@IM<V=S='(@(B5S(&9I;FYS(')E9&%N+B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&%T("5S("5S(@IM<V=S='(@(B5S(&ML("5S("5S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B)7,@
M:&%R(&%N;G5L;&5R870@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T
M<B`B)7,@:&%R('-V87)A="!PY2!E;B!B96?D<F%N(&]M(&EN9F]R;6%T:6]N
M(&%N9^5E;F1E(&QE9&EG+W5P<'1A9V5N+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S
M+B(*;7-G<W1R("(E<R!H87(@<W9A<F%T('#E(&EN8FIU9&%N('1I;&P@)7,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HT,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@:&%R('-K:6-K870@
M9&EG(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N+B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R
M871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N(@IM<V=S='(@(B(*(B5S(&MO;6UE<B!A='0@=71F]G)A(&1E('5N9&5R
M:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A=',@;F5D86XN($UA<FME
M<F$@(@HB9&4@86MT:79I=&5T97(@<V]M(&1U('9I;&P@=71F]G)A+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B
M"FUS9W-T<B`B)7,@:W+D=G,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S
M(&UI;G5T97(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,3(S(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E
M<R!S86MN87,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S
M=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(&5F
M=&5R9G+E9V%R(&EN9F]R;6%T:6]N(&]M(&[D<B!D=2#D<B!L961I9R]U<'!T
M86=E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C4P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y
M;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(E<R!E9G1E<F9RY6=A<B!D
M:6X@;N1R=F%R;R!V:60@)7,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E
M<R(*;7-G<W1R("(E<R!T:6QL("5S(&%V("5S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=VES:&5S('1O(&%D9"!T;R`E<RXB"FUS9W-T<B`B)7,@
M=FEL;"!LY&=G82!T:6QL('1I;&P@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G
M<W1R("(E<R!V:6QL(&?V<F$@9&EG(&UE9'9E=&5N(&]M("5S+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H92!L
M871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B5S('9I;&P@
M97)HY6QL82!D96X@<V5N87-T92!I;F9O<FUA=&EO;F5N(&]M("5S+B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R(&QI8B](;W)D92]+;VQA
M8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!"
M;V]K(@IM<V=S='(@(D%D<F5S<V)O:R!F]G(@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-"!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA
M;&5N9&5R(&;V<B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`V(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(")!;G1E8VMN:6YG87(@9O9R("5S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K
M;&ES="(*;7-G<W1R(")5<'!G:69T97(@9O9R("5S(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HY-@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C(W,B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@HB)7,Z($UE9&1E;&%N9&5T(&MA;G-K92!I;G1E(.1R(&9RY6X@9&5N
M('-O;2!D970@=F5R:V%R+B!687(@9O9R<VEK=&EG(&UE9"`B"B)A='0@9O9L
M:F$@;.1N:V%R(&5L;&5R('-K:6-K82!A=G/D;F1A<F5N('!E<G-O;FQI9R!I
M;F9O<FUA=&EO;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@
M9W5S=&EN9R`B"FUS9W-T<B`B+"!S=&]R;6)Y87(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!S=&]R
M;6)Y87(@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS
M9W-T<B`B+"!V87)I97)A;F1E(&UE;&QA;B`E<R!O8V@@)7,B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<R,R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`W,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$S,B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,T."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0X"FUS
M9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=N1L:B`M+2(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,3(M=&EM;6%R<V9O<FUA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0M=&EM;6%R
M<V9O<FUA="(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED
M("(R-"!H;W5R<R(*;7-G<W1R("(R-"!T:6UM87(B"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C8Y(&QI8B](;W)D92]522]086=E<BYP:'`Z-CD*
M;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\1O9R96?E96YD92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(D5N(&1A
M=&%B87-K;W!P;&EN9R!K<N1V<R!F]G(@86MT=65L;'0@8FQO8VLN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`@;&EB+TAO<F1E+G!H<#HQ
M-C(*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@
M(D5T="!F871A;'0@9F5L(&AA<B!I;G1RY&9F870B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,C`@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%;B!P=6)L:6L@4$=0+6YY
M8VME;"!K<N1V<R!F]G(@871T(&MR>7!T97)A(&5T="!M961D96QA;F1E+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-#4@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D=G,@9O9R(&%T="!V97)I
M9FEE<F$@971T('-I9VYE<F%T(&UE9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`W-R!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB16X@<'5B;&EK(&]C:"!P
M<FEV870@4$=0+6YY8VME;"!S86UT(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@
M9&5K<GEP=&5R82!E='0@(@HB;65D9&5L86YD92XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY.34@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5N('!U8FQI:R!O8V@@<')I=F%T
M(%!'4"UN>6-K96P@<V%M="!L]G-E;F]R9"!K<N1V<R!F]G(@871T('-I9VYE
M<F$@971T("(*(FUE9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%;B!P=6)L:6L@;V-H('!R
M:79A="!3+TU)344M;GEC:V5L('-A;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T
M="!D96MR>7!T97)A("(*(F5T="!M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB16X@<'5B;&EK
M(&]C:"!P<FEV870@4R]-24U%+6YY8VME;"!S86UT(&SV<V5N;W)D(&MRY'9S
M(&;V<B!A='0@<VEG;F5R82!E='0@(@HB;65D9&5L86YD92XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-"!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%;B!P
M=6)L:6L@4R]-24U%+6YY8VME;"!K<N1V<R!F]G(@871T(&MR>7!T97)A(&5T
M="!M961D96QA;F1E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")&]G)M:61D
M86=S;6]L;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(DSD='0@9O9R
M;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")&]G)M:61D86=S
M<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D;V<FUI9&1A9W-S:W5R
M87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D;V<FUI9&1A9W-S
M:W5R87(@;65D('-N]B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y
M"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM
M<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S
M='(@(D]M(&5D:71O<FXB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B3VTN+BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B
M;W1T;VTB"FUS9W-T<B`B0F]T=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S
M='(@(DUI='1E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-C0P"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R
M(")!8V-E<'1E<F$@8F5GY')A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Q"FUS9VED(")!8V-E<'1E9"(*;7-G
M<W1R(")!8V-E<'1E<F%D(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(W,"!L:6(O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B0F5H]G)I
M9VAE="!S86MN87,@871T('-K87!A(%9&4RUM87!P+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G
M<W1R(")"96CV<FEG:&5T('-A:VYA<R!A='0@<VMA<&$@5D93+69I;"XB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O
M<FUA=&EO;B(*;7-G<W1R(")+;VYT;VEN9F]R;6%T:6]N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(DSV<V5N;W)D(&;V<B!K;VYT;R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PHC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z
M96XN(@IM<V=S='(@(DMO;G1O="!F<GES="(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B0G5D
M9V5T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT-3$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV,C4*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`BQ71GY')D97(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$T.`HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI
M;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*
M;7-G:60@(D%D9"(*;7-G<W1R("),Y&=G('1I;&PB"@HC.B!T96UP;&%T97,O
M;&EN:W,O;&EN:W,N:6YC.C$S"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"`E
M<R(*;7-G<W1R("),Y&=G('1I;&P@)7,B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R
M;W5P(@IM<V=S='(@(DSD9V<@=&EL;"!U;F1E<F=R=7!P(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDY"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3@@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B;.1G9R!T:6QL('5N9&5R8F5H]G)I9VAE="(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B3.1G9R!T:6QL(&CD<CHB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U
M<"(*;7-G<W1R("),Y&=G('1I;&P@;GD@9W)U<'`B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B3.1G9R!T:6QL(&YY(&)E:/9R:6=H970B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("),
MY&=G('1I;&P@=6YD97)G<G5P<"!T:6QL("<E<R<B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$T-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O(%PB)7-<(B(*;7-G<W1R("),Y&=G('1I;&P@=6YD97)B96CV<FEG
M:&5T('1I;&P@)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!
M9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B3.1G9R!T:6QL(&5N(&YY(&%N=N1N
M9&%R93HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B3.1G9R!T:6QL(&MO;'5M
M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G
M:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("),Y&=G('1I;&P@;GEA(&UE
M9&QE;6UA<B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G
M:60@(D%D9"!P86ER(@IM<V=S='(@(DSD9V<@=&EL;"!P87(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("),
MY&=G('1I;&P@;65N>6X@9O9R("5S('-O;2!-;WII;&QA(%-I9&5B87(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8S
M,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C8S-PIM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B
M3.1G9R!T:6QL(&D@;6EN(&MA;&5N9&5R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<Q(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM
M<V=S='(@(DSD9V<@=&EL;"!I(&%D<F5S<V)O:SHB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@
M8F]O:R(*;7-G<W1R("),Y&=G('1I;&P@:2!M:6X@861R97-S8F]K(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(DSD
M9V<@=&EL;"!A;G;D;F1A<F4B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M
M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"B),861E('1I;&P@)R5S)R!T:6QL
M('-Y<W1E;65T+"!M96X@:W5N9&4@:6YT92!LY&=G82!T:6QL(&5X=')A("!I
M;F9O<FUA=&EO;CH@)2(*(G,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("),861E('1I;&P@)R5S)R!T:6QL
M('-Y<W1E;65T+B!$=2!K86X@;&]G9V$@:6X@;G4N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B57!P;.1G9R!A=B!A;G;D;F1A<F4@Y'(@
M:6YA:W1I=F5R870N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R97-S(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!"
M;V]K(@IM<V=S='(@(D%D<F5S<V)O:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDT(&QI8B](;W)D92])34%0+T%#3"]R9F,T
M,S$T+G!H<#HU-@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N("T@86YG92!B96CV
M<FEG:&5T(&;V<B!A;F1R82!A;G;D;F1A<F4B"@HC.B!A9&UI;B]I;F1E>"YP
M:'`Z,3D@<V5R=FEC97,O<&]R=&%L+VUE;G4N<&AP.C$Q,PHC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R(")296ML86TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.`HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-`HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QG97)I970B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA
M<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@
M(DIU<W1E<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(DIU<W1E<FEN
M9SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*
M;7-G<W1R(")!;&QA(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR,#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#<*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@
M57-E<G,B"FUS9W-T<B`B06QL82!A=71E;G1I<V5R861E(&%N=N1N9&%R92(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*
M;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B06QL82!G<G5P<&5R(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I
M9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(D%L;&$@8F5H]G)I9VAE=&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B06QL82!F
M>7)A('-I9&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S(@IM<V=S='(@(E1I;&SE="!F;&5R82!A9')E<W-E<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(E1I;&SE="!I;G-T
MY&QL;FEN9R!F]G(@<V]R=&5R860@;&ES=&$_(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T(&QI8B](;W)D92]$871A5')E
M92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M1FEN;G,@<F5D86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS
M9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=&EV
M($E-4U`M:6YL;V=G;FEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(D%L
M=&5R;F%T:79T(&SV<V5N;W)D(&;V<B!)35-0(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B06QT97)N871I=G0@86YVY&YD87)N86UN(&;V<B!)35-0(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R
M;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L=&5R;F%T:78@92UP;W-T
M(&%D<F5S<R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:78@;6%L;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L
M=&5R;F%T:78@=&5X=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A
M(@IM<V=S='(@(D%M97)I:V%N<VMA(%-A;6]A(@H*(SH@9G)A;65W;W)K+TQI
M;FMS+TQI;FMS+G!H<#HR-#<*(SH@9G)A;65W;W)K+U)E;&%T:6]N<VAI<"]2
M96QA=&EO;G-H:7!-86YA9V5R+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B06X@97)R;W(@;V-C=7)R960@9F]L;&]W:6YG('1H:7,@;&EN:SH@)7,B
M"FUS9W-T<B`B171T(&9E;"!U<'!S=&]D(&[D<B!LY&YK96X@*"5S*2!S:W5L
M;&4@86YVY&YD87,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ
M,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS
M9W-T<B`B171T(&9E;&%K=&EG="!VY')D92!A;F=A=G,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B171T(&]KY&YT(&9E;"!H87(@
M:6YT<N1F9F%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N
M9&]R<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,`HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G
M<W1R(")!;F]N>6T@<')O>'DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E-V87(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&ES(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@
M;V-H($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN
M+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN
M<&AP.C4X(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB
M"FUS9W-T<B`B07!P;&EK871I;VXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B07!P;&EK
M871I;VYS;&ES=&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS
M9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B07!P;&EK871I
M;VYE;B#D<B!K;&%R+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B5F5R
M:W-TY&QL('1I;&P@=6YD97)U=&1E;&YI;F=A<B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S
M='(@(D=O9&OD;FXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S(@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,0IM<V=I
M9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")5;F=E9N1R;&EG('-T;W)L
M96LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S@P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P
M<FEL(@IM<V=S='(@(F%P<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B
M:7-K("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM
M<V=S='(@(D%R:VEV9FEL<W1O<FQE:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@P(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS
M9W-T<B`B07)K:79F:6QN86UN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@/R(*;7-G<W1R("+$<B!D970@<^1K97)T(&%T="!D=2!V:6QL
M('1A(&)O<G0@8F5GY')A;B!F]G(@)7,_(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S
M=6(M9W)O=7!S/R(*;7-G<W1R("+$<B!D970@<^1K97)T(&%T="!D=2!V:6QL
M(')A9&5R82`G)7,G(&]C:"!E=F5N='5E;&QA('5N9&5R9W)U<'!E<C\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-@HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,@HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)M86YI96XB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#
M24DM."DB"FUS9W-T<B`B07)M96YI<VL@*$%235-#24DM."DB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")+;VYS
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")!<V-E
M;G-I;VX@27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS
M9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@:V]N<W0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B
M07-I96XO4W1I;&QA(&AA=G-R96=I;VYE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")&<N5G
M82!E9G1E<B!B96MRY&9T96QS92!I;FYA;B!U;F1E<FCE;&QS86MT:79I=&5T
M97(@=71F]G)S/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3D*;7-G:60@(D%S<VEG;FUE;G0@8V]L
M=6UN<R(*;7-G<W1R(")4:6QL9&5L;FEN9W-K;VQU;6XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(T.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,Q.`IM
M<V=I9"`B071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@
M82!R97%U97-T('EO=2!S96YT(@IM<V=S='(@(D)I9F]G860@Y'(@96X@:4-A
M;&5N9&5R(&9I;"!M960@971T('-V87(@<.4@96X@8F5GY')A;B!S;VT@9'4@
M<VMI8VMA="PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B
M1O9R<_9K('1I;&P@871T(')A9&5R82!E;B!G<G5P<"!S;VT@:6YT92!F:6YN
M<RXB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R(")&]G)S]FL@=&EL;"!A='0@<F%D97)A(&5N(&)E:/9R:6=H970@<V]M
M(&EN=&4@9FEN;G,N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")&]G)S]FL@871T(.1N9')A(&5N(&)E:/9R:6=H970@<V]M
M(&EN=&4@9FEN;G,N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M(@IM<V=S='(@(D;V<G/V:R!A='0@Y&YD<F$@96X@=71D96QN:6YG('-O;2!I
M;G1E(&9I;FYS+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3<W"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B1&5L
M=&%G87)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8X"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071T<FEB=70B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C$*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.2!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*
M;7-G<W1R(")A=6=U<W1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS
M9W-T<B`B075S=')A;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G
M<W1R("+6<W1E<G)I:V4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,38X(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED
M(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@24U!4"UE>'1E;G-I;VX@<V%K
M;F%S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-2!L
M:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M(@IM<V=S='(@(D%U=&A?8WER<W%L.B!+;W!P;&EN9V5N('-A:VYA<B!F=6YK
M=&EO;F5R('-O;2!K<N1V<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ,C(@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I
M9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!)34%0+65X=&5N<VEO;B!S86MN
M87,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V(&QI8B](
M;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U
M:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET
M:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B075T:%]F
M='`Z($944"UT:6QLY&=G('-A:VYA<RX@2V]M<&EL97)A(%!(4"!M960@<W=I
M=&-H96X@+2UE;F%B;&4M9G1P+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:6UA<"YP:'`Z-C0@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@
M(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VEM87`Z($E-05`M97AT96YS:6]N('-A:VYA<RXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q(&QI8B](;W)D
M92]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U
M.B!K<F(U+65X=&5N<VEO;B!S86MN87,N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS,#(@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S`R
M"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@
M1&5T(&?E<B!I;G1E(&%T="!LY&=G82!T:6QL(&%N=N1N9&%R92!I($%C=&EV
M92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,U-R!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?
M;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z($1E="!GY7(@:6YT
M92!A='0@<F%D97)A(&%N=N1N9&%R92!F<N5N($%C=&EV92!$:7)E8W1O<GDB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P
M.B!,1$%0+71I;&SD9V<@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S,Y(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(D%U=&A?;&1A<#H@2V%N(&EN=&4@;.1G9V$@=&EL;"!A;G;D;F1A<F4@
M)R5S)RX@4V5R=F5R;B!S=F%R861E.B`B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,X-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!+86X@:6YT92!R861E
M<F$@86YVY&YD87)E("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HT.3D@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EN=&4@=7!P9&%T97)A(&%N
M=N1N9&%R92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#`U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD87`Z($1E="!GY7(@:6YT
M92!A='0@=7!P9&%T97)A(&%N=N1N9&%R92!I($%C=&EV92!$:7)E8W1O<GDN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-B!L:6(O2&]R
M9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E
M9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A
M;#H@34-!3"UE>'1E;G-I;VX@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<#HV,"!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P"FUS
M9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!S;6)A=71H+65X
M=&5N<VEO;B!S86MN87,N(@H*(SH@;&EB+TAO<F1E+TE-05`O061M:6XN<&AP
M.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG('1I;&P@24U!4"US97)V97(@
M;6ES<VQY8VMA9&5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM
M<V=S='(@(D%U=&5N=&ES97)I;F<@;6ES<VQY8VMA9&5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B075T96YT:7-E
M<FEN9R!M:7-S;'EC:V%D97,N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$W-B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W
M-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BXB"FUS9W-T<B`B075T96YT:7-E<FEN9R!A=G9I<V%D97,@878@4D%$
M2553+7-E<G9E<FXN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M-3$@;&EB+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@
M=&EL;"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C<P(&QI8B]61E,O<VUB+G!H<#HW,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")!=71E;G1I<V5R:6YG('1I;&P@4TU"+7-E<G9E<B!M:7-S;'EC:V%D
M97,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B
M079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B5&EL;&?D;F=L:6=A(&;D;'0Z
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HV,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@(E;D;G1A
M<B!PY2!S=F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@
M(D%Z97)B86EJ86XB"@HC.B!C;VYF:6<O=&AE;65S+V%Z=7(N<&AP.C@*;7-G
M:60@(D%Z=7(B"FUS9W-T<B`B07IU<F)LY2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@M
M=7)SY&MT97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D)A
M:V=R=6YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")"86MG
M<G5N9'-FY')G(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,2!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+B(*;7-G<W1R(")&96QA:W1I9W0@;/9S96YO<F0@9O9R
M($ME<F)E<F]S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,R!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E
M<F]S('5S97)N86UE+B(*;7-G<W1R(")&96QA:W1I9W0@86YVY&YD87)N86UN
M(&;V<B!+97)B97)O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R
M(")"86AA;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A
M:')A:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L
M=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&ES:R`H25-/+3@X-3DM
M,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L
M861E<V@B"@HC.B!L:6(O0FQO8VLO8F%R=&EM92YP:'`Z-`IM<V=I9"`B0F%R
M(%1I;64B"FUS9W-T<B`B0F%R=&ED(@H*(SH@;&EB+T)L;V-K+V)A<G1I;64N
M<&AP.C,U"FUS9VED(")"87(@=&EM92(*;7-G<W1R(")2861T:60B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,PHC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,CD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@8V]N
M9FEG+W1H96UE<R]B87)B:64N<&AP.C8*;7-G:60@(D)A<F)I92(*;7-G<W1R
M(")"87)B:64B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B0F%S:V%T86QO9R`G)7,G(&;V<B!B:6QD
M97(@:&ET=&%D97,@:6YT92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S
M='(@(D)A<VQI;FIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@
M(E9I=')Y<W-L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@
M(D)E;&=I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI
M>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,`HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G
M<W1R(")&]F1E;'-E9&%G(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,U,B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S8P"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A
M<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")";&]C:R`G
M)7,G(&;V<B!A<'!L:6MA=&EO;B`G)7,G('-A:VYA<RXB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S
M(@IM<V=S='(@(D)L;V-K:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R
M(")";&]C:W1Y<"(*"B,Z(&-O;F9I9R]T:&5M97,O8FQU96UO;VXN<&AP.C8*
M;7-G:60@(D)L=64@36]O;B(*;7-G<W1R(")";.4@;>5N92(*"B,Z(&-O;F9I
M9R]T:&5M97,O8FQU97=H:71E+G!H<#HV"FUS9VED(")";'5E(&%N9"!7:&ET
M92(*;7-G<W1R(")";.5T="!O8V@@=FET="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R
M(")&970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,PHC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79I
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O
M;VMM87)K<R(*;7-G<W1R(")";VMMY')K96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B4F%M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS
M9W-T<B`B4F%M8G)E9&0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R
M(")286UA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN
M82(*;7-G<W1R(")";W-N:65N(&]C:"!(97)Z96=O=FEN82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")"Y61A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)O='1E;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V970@27-L86YD(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL:65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*
M;7-G<W1R(")"<FET=&ES:V$@=&5R<FET;W)I970@:2!);F1I<VMA(&]C96%N
M96XB"@HC.B!C;VYF:6<O=&AE;65S+V)R;W=N+G!H<#HV"FUS9VED(")"<F]W
M;B(*;7-G<W1R(")"<G5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S
M86QA;2(*;7-G<W1R(")"<G5N96DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA
M(@IM<V=S='(@(D)U;&=A<FEE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`B4'5N:W1L:7-T82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O
M(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&-O;F9I9R]T:&5M97,O8G5R
M;G1O<F%N9V4N<&AP.CD*;7-G:60@(D)U<FYT($]R86YG92(*;7-G<W1R(")"
M<N1N9"!/<F%N9V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B
M0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G
M:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<R(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM
M<V=S='(@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED
M(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(D-?96QL(&EN<W3D;&QN
M:6YG87(N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q
M"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R
M(")#86-H96EN:71I97)I;F<@Y'(@:6YT92!F=6QL<W3D;F1I9RXB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Y"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P-#`*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM
M<V=S='(@(DQU9VYT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S
M='(@(DMA;6)O9&IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R
M(")+86UE<G5N(@H*(SH@8V]N9FEG+W1H96UE<R]C86UO=69L86=E+G!H<#HV
M"FUS9VED(")#86UO=69L86=E(@IM<V=S='(@(DMA;6]U9FQA9V4B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R
M97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B2V%N(&EN=&4@;F]L;'-TY&QL82!L]G-E
M;F]R9"!A=71O;6%T:7-K="P@:V]N=&%K=&$@9&EN(&%D;6EN:7-T<F%T]G(N
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X(&QI8B]&:6QE
M+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I
M=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B2V%N(&EN=&4@<VMR:79A('1I
M;&P@9FEL("<E<R<B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@
M(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB
M"FUS9W-T<B`B1&5T(&?E<B!I;G1E(&%T="!A9&UI;FES=')E<F$@97AT97)N
M82!S97-S:6]N<VAA;G1E<F%R92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C,Q.0HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DMA;B!I
M;G1E(&MO;G1A:W1A($E-05`M<V5R=F5R;CH@)7,B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT,3,@;&EB+T9I;&4O0U-6+G!H<#HT-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B2V%N(&EN=&4@]G!P;F$@9FEL("<E<R<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@
M(D-A;F%D82(*;7-G<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G
M:60@(D-A;F-E;"(*;7-G<W1R(")!=F)R>70B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(D%V8G)Y="!P<F]B;&5M<F%P<&]R="(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X(&QI8B]61E,O9G1P+G!H<#HS,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A("<E<R<N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*(SH@9G)A;65W
M;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C0W"B,Z(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-3,*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(DMA
M;B!I;G1E(&AI='1A(&5N('1E;7!RY'(@;6%P<"XB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ(&9R86UE=V]R:R]61E-?
M25-/+TE33U=R:71E<BYP:'`Z.3<*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP
M.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N(@IM<V=S='(@(DMA;B!I;G1E(&9O<G1SY'1T82!U=&%N
M("=MY6QF:6PG+7!A<F%M971E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Q-"!L:6(O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HV.#`*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H
M<#HQ,C@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T
M+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$[("5D(&)A<FX@97AI<W1E<F%R
M+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P
M."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#D*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N(@IM<V=S='(@(DMA;B!I;G1E(&1I<FEG97)A(&UE9&1E;&%N
M9&4@=&EL;"!A;F=I=F5T(&YU;6UE<BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@
M5F5R9&4B"FUS9W-T<B`B2V%P(%9E<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO
M;B(*;7-G<W1R(")2=6)R:6LB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#0@;&EB+TYE="]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B3W!E<F%T]G(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@
M86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R:65R(&]C:"!R=6)R:6ME<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")#87EM
M86X@27-L86YD<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6QT96QE9F]N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(D-E;&QI
M;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B
M0V5L;'5T9GEL;&YA9#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B
M"FUS9W-T<B`B0V5L;&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C
M:6YG.B(*;7-G<W1R(")#96QL;65L;&%N<G5M.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-S0@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S@*;7-G
M:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ
M-"DB"FUS9W-T<B`B0V5L=&ES:R`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I
M9"`B0V5N=&5R(@IM<V=S='(@(D-E;G1R97)A9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(D-E;G1R86QA9G)I
M:V%N<VMA(')E<'5B;&EK96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T
M<B`B0V5N=')A;&5U<F]P96ES:R`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.2!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G
M<W1R(")#97)T:69I:V%T9&5T86QJ97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8Q,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B0V5R=&EF
M:6MA=.1G87)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.38@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E
M<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(D-E<G1I9FEK871P;VQI8VEE
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B5&-H860B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Y
M-@IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(D]R9&;V<F%N9&4B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BQ&YD
M<F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(L1N9')A(&1I='0@;/9S
M96YO<F0B"@HC.B!T96UP;&%T97,O<')E9G,O8VAA;F=E9&5F875L=&ED96YT
M:71Y+FEN8SHQ,PIM<V=I9"`B0VAA;F=E(&1E9F%U;'0@:61E;G1I='DB"FUS
M9W-T<B`BQ&YD<F$@9O9R=F%L9"!I9&5N=&ET970B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@
M861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E
M<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B+$;F1R82!N86UN
M(&]C:"!A9')E<W,@<V]M(&UO='1A9V%R;F$@<V5R(&[D<B!D92!LY'-E<B!O
M8V@@<W9A<F%R('#E(&1I;F$@(@HB;65D9&5L86YD96XN(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*(D%T="!B>71A(&SV<V5N;W)D('-T]F1S(&EN=&4@
M;65D(&1E;B!N=79A<F%N9&4@:V]N9FEG=7)A=&EO;F5N+B`@5F%R(&=O9"`B
M"B)K;VYT86MT82!A9&UI;FES=')A=/9R96XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA
M<B(*;7-G<W1R(")4:VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN
M(@IM<V=S='(@(DMO;G1R;VQL97)A(&SD;FLN+BXB"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#:&5C:R!T
M:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")-87)K97)A(&1E(&%K=&EV:71E
M=&5R(&1U('9I;&P@=71F]G)A(&YU+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B
M"FUS9W-T<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(DMI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(DMI;F5S:7-K="!F
M]G)E;FML870@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B
M2VEN97-I<VMT('1R861I=&EO;F5L;'0@*$)I9S4I(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*
M;7-G<W1R(")6Y&QJ(&%P<&QI:V%T:6]N.B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-CD@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E;D;&H@
M;/9S96YO<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8X(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O
M<V4@82!U<V5R;F%M92(*;7-G<W1R(")6Y&QJ(&%N=N1N9&%R;F%M;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-C(V"FUS9VED(")#:&]O<V4@86X@86-T:6]N.B(*;7-G<W1R(")6Y&QJ(.5T
M9^1R9#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#
M:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E;D;&H@:'5R
M(&1A='5M('-K86QL('9I<V%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L
M:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")6
MY&QJ(&QI<W1S=&EL("AF]G(@<V]R=&5R861E(&QI<W1O<BDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B2G5L]FXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#DT(&QI8B]61E,N<&AP.CDQ-`HC.B!L:6(O3F5T+U--4RYP:'`Z
M,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S<V1E9FEN:71I;VX@9O9R("5S
M('-A:VYA<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B4F5N<V$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#
M;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(E)E;G-A($U33V9F:6-E+71A
M9V=A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(E)E;G-A(&9RY6=A(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE
M87(@;W5T('5S97(Z("5S(@IM<V=S='(@(E)E;G-A(&%N=N1N9&%R93H@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@
M(D-L96%R('5S97(B"FUS9W-T<B`B4F5N<V$@86YVY&1N87)E(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S
M97(@9&%T82(*;7-G<W1R(")296YS82!A;G;D;F1A<F1A=&$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE
M87)I;F<@3&%T92(*;7-G<W1R(")396YA<F4@=7!P:VQA<FYA;F1E(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]B;W1T;VTN:6YC.C8*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G
M:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML:6-K82!F]G(@871T
M(&9O<G1SY'1T82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R
M(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#
M;&]S92!7:6YD;W<B"FUS9W-T<B`B4W3D;F<@9O9N<W1E<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B36]L
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V
M"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B5&ED:6=A(&UO;&XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I
M9"`B0VQO=61Y(@IM<V=S='(@(DUO;&YI;F=T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#
M;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<R(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B2V]M<')I;65R
M82!S:61O9N1L=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B
M"FUS9W-T<B`B2V]M<')I;65R861E(')A;6%R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M;VQO;6)I82(*;7-G<W1R(")+;VQO;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#
M;VQO<B(*;7-G<W1R(")&Y')G(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-S4@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,S,0HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,R
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,#,*(SH@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@
M4&EC:V5R(@IM<V=S='(@(D;D<F=H86YT97)A<F4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#0V(&QI8B](;W)D92]&;W)M+G!H<#HR.#,R"FUS
M9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(D;D<F=V86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I
M9"`B0V]L<SHB"FUS9W-T<B`B2V]L=6UN97(Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DT-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU,`IM<V=I
M9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")+;VQU;6X@<G5B<FEK97(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B
M"FUS9W-T<B`B3'5S=&EG:&5T97(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B2V]M;6%N9&\B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T
M<B`B2V]M;6%N9&]F]FYS=&5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#`R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B0V]M;65N="(*;7-G<W1R(")+;VUM96YT87(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3F%M;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R;W,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#
M;VUP86YY(@IM<V=S='(@(D;V<F5T86<B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y-PIM<V=I9"`B0V]M<&QE=&5D
M(@IM<V=S='(@(E-L=71F]G)D(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC.B!F<F%M97=O<FLO5&5X="]4
M97AT+T9I;'1E<B]E;6%I;',N<&AP.C@R"B,Z(&9R86UE=V]R:R]497AT+U1E
M>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#@*(SH@9G)A;65W;W)K+U1E>'0O5&5X
M="]&:6QT97(O96UA:6QS+G!H<#HY.`HC.B!F<F%M97=O<FLO5&5X="]497AT
M+T9I;'1E<B]E;6%I;',N<&AP.C$P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VUP;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R(")3:W)I=B!M961D96QA;F1E
M("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O
M;7!U=&5R<R(*;7-G<W1R(")$871O<F5R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(E;D
M9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@(D-O;F1I
M=&EO;G,B"FUS9W-T<B`B5N1D97(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R
M(")+;VYF:6=U<F%T:6]N<W-K:6QL;F%D97(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@
M(B(*(DEN<W3D;&QN:6YG87(@9O9R(&%T="!S>6YK<F]N:7-E<F$@;65D(&AA
M;F1D871O<F5R+"!S;6%R=&$@=&5L969O;F5R(&]C:"`B"B)/=71L;V]K(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B2V]N9FEG=7)A=&EO;B!B
M96CV=F5R('5P<&1A=&5R87,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T
M<B`B2V]N9FEG=7)E<F$@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@
M(D)E:W+D9G1A(&SV<V5N;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G
M<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`B1O9R8FEN9&5L<V4@;6ES<VQY8VMA9&5S+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S
M='(@(D;V<F)I;F1E;'-E(&UI<W-L>6-K861E<SH@(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S<Y(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")&]G)B:6YD96QS92!M960@<'5B;&EK
M(&YY8VME;'-E<G9E<B!N96MA9&5S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B
M1O9R8FEN9&5L<V4@;65D('!U8FQI:R!N>6-K96QS97)V97(@;F5K861E<SH@
M)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U(&QI
M8B]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(D;V<F)I;F1E;'-E(&UE9"!&5%`M<V5R
M=F5R(&UI<W-L>6-K861E<RXB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`V-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B2V]N=&%K=&5R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")+;VYT86MT97(@;&%D97,@=&EL;"!I(&1I;B!A9')E<W-B
M;VLN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G
M:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R
M("));FYE:.5L;'-T>7`@9O9R(&MO;7!R:6UE<F%D(&9I;#H@(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8P"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-38*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(DEN;F5H
MY6QL(&D@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN
M=64B"FUS9W-T<B`B1F]R='/D='0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L
M86YD<R(*;7-G<W1R(")#;V]K($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#;V]K:64B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:65R82(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X(&QI8B]61E,O<VUB+G!H<#HT-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@
M(DMO<&EE<FEN9R!M:7-S;'EC:V%D97,Z("5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE
M8W1I;VXB"FUS9W-T<B`B2V]P:65R82!M87)K97)I;F<B"@HC.B!C;VYF:6<O
M=&AE;65S+V-O<FYF;&]W97(N<&AP.C8*;7-G:60@(D-O<FYF;&]W97(B"FUS
M9W-T<B`B36%J<V)L;VUM82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3DU(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*
M;7-G<W1R(")+;W-T;F%D<RU)1"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC
M82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G
M279O:7)E(@IM<V=S='(@(D5L9F5N8F5N<VMU<W1E;B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU-@IM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMA;B!I;G1E(%!'4"UK<GEP
M=&5R82!M961D96QA;F1E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*
M;7-G<W1R(")+86X@:6YT92!01U`M:W)Y<'1E<F$@;65D9&5L86YD93H@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`S,PIM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DMA;B!I;G1E
M(%!'4"US:6=N97)A(&UE9&1E;&%N9&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4Z("(*;7-G<W1R(")+86X@:6YT92!01U`M<VEG;F5R82!M961D96QA;F1E
M.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,R!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMA;B!I;G1E(%,O
M34E-12UK<GEP=&5R82!M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#8W(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB
M"FUS9W-T<B`B2V%N(&EN=&4@4R]-24U%+7-I9VYE<F$@;65D9&5L86YD92XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B2V%N(&EN=&4@;.1G9V$@=&EL;"!K;VYT86MT+B`E<R(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&MO;G1A
M:W1A($Q$05`@<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R(")+86X@:6YT92!V97)I9FEE<F$@:V]N
M=&]S86QD;RX@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B2W5N9&4@:6YT92!A;G-L=71A('1I;&P@3$1!4"US97)V97(N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10
M.B`E<R(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT82!S97)V97(@)R5S)R!V
M:6$@1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S(R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2V%N(&EN=&4@<VMA
M<&$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$Q,#4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A+B(*;7-G<W1R(")+86X@:6YT92!D96MR>7!T97)A(%!'4"UD
M871A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B2V%N(&EN
M=&4@9&5K<GEP=&5R82!01U`M9&%T83H@(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU,C(@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*
M;7-G<W1R(")+86X@:6YT92!D96MR>7!T97)A(%,O34E-12UD871A+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*
M;7-G<W1R(")+86X@:6YT92!R861E<F$@:V]N=&%K="X@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!D:7-T<FEB=71I;VYS;&ES
M=&$N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E
M('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!U<'!G
M<F%D97)I;F=S<V-R:7!T('1I;&PZ("5S+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDS.`HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X,2!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D
M971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G
M<W1R(")+86X@:6YT92!B97-TY&UM82!M;W1T86=A<F5N<R!E4&]S="UA9')E
M<W,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR.#,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@861R97-S8F]K
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#DS"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@9&ES=')I
M8G5T:6]N<VQI<W1A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#0V"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DMA;B!I
M;G1E(&CD;71A(&MO;7!L971T(&QI<W1A(/9V97(@9&ES=')I8G5T:6]N<VQI
M<W1O<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y
M(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@;&%D9&$@<W1R871E9VD@)R5S
M)RXB"@HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HV.0HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N(@IM<V=S='(@(DMA
M;B!I;G1E(&QA9&1A('-T<F%T96=I("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S
M7"(N(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(&UA<'`@)R5S)RXB"@HC.B!F
M<F%M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3$Q"B,Z(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@)R5S)RXB"FUS9W-T<B`B2V%N(&EN
M=&4@<VMA<&$@;6%P<"`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<P."!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A('!U8FQI:R!N>6-K96P@
M9G+E;B!N>6-K96QS97)V97)N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB
M)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@)R5S
M)R!F]G(@<VMR:79I;F<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C8R(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B2V%N(&EN
M=&4@]G!P;F$@)7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG+B(*;7-G
M<W1R(")+86X@:6YT92#V<'!N82`G)7,G(&;V<B!S:W)I=FEN9RXB"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q."!L:6(O
M2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*
M;7-G<W1R(")+86X@:6YT92#V<'!N82!-86EN=&5N86YC95]487-K(&UO9'5L
M("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(DMA;B!I;G1E(/9P<&YA(&UA<'!E;B`G)7,G(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I
M<F5C=&]R>2`G)7,G+B(*;7-G<W1R(")+86X@:6YT92#V<'!N82!M87!P("<E
M<R<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY
M"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(")+86X@:6YT92!K;VYT86MT82!,1$%0('-E<G9E<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S."!L:6(O5D93+T]B:F5C="YP
M:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S
M+B(*;7-G<W1R(")+86X@:6YT92!LY'-A("5S+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@
M=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@
M86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB1&5T(&=I8VL@:6YT92!A
M='0@Y71E<G-TY&QL82!L]G-E;F]R9&5T(&;V<B!D96X@86YG:79N82!A;G;D
M;F1A<F5N+B!.Y6=O;B`B"B)E;&QE<B!NY6=R82!A=B!U<'!G:69T97)N82#D
M<B!I;G1E(&MO<G)E:W1A+B!&]G)S]FL@:6=E;B!E;&QE<B!K;VYT86MT82`B
M"B)A9&UI;FES=')A=/9R96X@;VT@9'4@8F5H]G9E<B!H:N1L<"XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,S."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S<U"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-PIM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E($%#3"(*;7-G<W1R(")+86X@:6YT92!HY&UT82!!0TPB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(W-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S
M(&)O;VLN("5S(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A(&%D<F5S<V)O:RX@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0X-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@9&ES
M=')I8G5T:6]N<VQI<W1A+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B
M2V%N(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI<W1O<BX@)7,B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,R!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<R(*;7-G<W1R(")+86X@:6YT92!HY&UT82!D<V5R=F5R9G5N
M:W1I;VYE<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@
M(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V%N
M(&EN=&4@Y71E<G-TY&QL82!K;VYF:6=U<F%T:6]N96XN(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.CDT"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!M
M87!P("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R;61I<B`G)7,G+B(*;7-G<W1R(")+86X@:6YT92!R
M861E<F$@;6%P<"`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(DMA;B!I;G1E('-P87)A(&MO;F9I9W5R
M871I;VX@9O9R("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")+86X@:6YT92!S
M<&%R82!B86-K=7`M:V]N9FEG=7)A=&EO;BXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(")+86X@:6YT
M92!S<&%R82!E;B!B86-K=7`M:V]N9FEG=7)A=&EO;CH@)7,N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B2V%N(&EN=&4@<W!A<F$@=7!P9W)A9&5R:6YG<W-C<FEP
M="!T:6QL.B`E<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")+86X@:6YT92!S<&%R
M82!B86-K=7`M:V]N9FEG=7)A=&EO;B`E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*(DMA;B!I;G1E('-P87)A(&MO;F9I9W5R871I
M;VYS9FEL96X@)7,N($1U(&MA;B!A;G1I;F=E;B!A;G;D;F1A(&5N(&%V("(*
M(F%L=&5R;F%T:79E;B!A='0@<W!A<F$@:V]D96X@=&EL;"`E<R!E;&QE<B!K
M;W!I97)A(&MO9&5N(&YE9&%N('1I;&P@)7,N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-#,@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B2V%N(&EN=&4@<_9K82!I($Q$05`M:V%T86QO9V5N+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HX-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@
M<F%D97)A("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@W"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@)R5S)RXB"FUS9W-T<B`B2V%N(&EN
M=&4@<F%D97)A("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR,3D*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMA;B!I;G1E('5P<&1A=&5R
M82!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,SDV"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2V%N(&EN=&4@
M=7!P9&%T97)A(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2V%N(&EN=&$@<W!A<F$@:V]N9FEG=7)A=&EO;B!F]G(@)R5S)SH@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+B(*;7-G<W1R(")+86X@:6YT92!H:71T82!-;WII;&QA
M<R!S:61O9N1L="X@5F5R:69I97)A(&%T="!S:61O9N1L=&5T(.1R(/9P<&5T
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U
M-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*
M;7-G<W1R(")+86X@:6YT92!G92!A;G;D;F1A<F5N("<E<R<@86YG:79N82!R
MY'1T:6=H971E<B!T:6QL(&UA<'!E;B`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C,*
M;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")2Y&MN860@=&5X="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(DQA;F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(DMU<G-E<B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(E-K87!A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@
M82!L:6YK(@IM<V=S='(@(E-K87!A(&SD;FLB"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@
M;VYE(@IM<V=S='(@(E-K87!A(&YY(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3(@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S
M,30N<&AP.C4R"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(E-K87!A('5N
M9&5R;6%P<"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(D)E:/9R:6=H971E<B!F]G(@Y&=A<F$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P(&QI8B](;W)D92]&;W)M
M+G!H<#HS,C$V"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B
M2W)E9&ET:V]R='-N=6UM97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*
M;7-G<W1R(")+<F]A=&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R
M(")+=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R
M96YT(#0@4&AA<V5S(@IM<V=S='(@(D%K='5E;&QA(#0@9F%S97(B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B
M"FUS9W-T<B`B06MT=65L;"!S97-S:6]N(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I
M;64B"FUS9W-T<B`B06MT=65L;"!T:60B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E
M;G0@55),(&ES(@IM<V=S='(@(D%K='5E;&P@55),(.1R(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@
M(D%K=&EV82!A;G;D;F1A<F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B06MT=65L;'0@=N1D
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED
M(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(D%K='5E;&QA('9I;&QK
M;W(Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B06MT=65L;"!S
M=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N(@IM<V=S='(@(E-K<N1D9&%R<WD@86MT:79I=&5T97(@<V]M(&OV
M<G,@=FED(&EN;&]G;FEN9R!T:6QL("5S+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T
M(@IM<V=S='(@(DML:7!P('5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G
M<W1R(")+;&EP<"!U<G9A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S
M='(@(D-Y<&5R;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED
M(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+>7)I;&QI<VL@*$M/23@M
M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B2WER:6QL:7-K("A7:6YD;W=S
M+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y
M<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")+>7)I;&QI<VLO
M56MR86EN<VL@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B
M;&EC(@IM<V=S='(@(E1J96-K:65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0R-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#`@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S8*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.2!L:6(O2&]R
M9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")$
M86=L:6<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4
M<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@8FSD9&1R87)E(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S(W-`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(D1A=&%B
M87-U<'!S;&%G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D1A='5M(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A
M=&4@4F5C96EV960B"FUS9W-T<B`B1&%T=6T@;6]T=&%G970B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W(&QI8B](;W)D92]&;W)M+G!H<#HR
M-SDS"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")$871U;79A;"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@(D1A
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B7U)A
M9&5R82!K;VQU;6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*
M;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E8V5M8F5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM
M<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D1E8VEM86QE<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@U
M"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")!=F+V:G0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R
M96%S92!);F1E;G0B"FUS9W-T<B`B36EN<VMA(&EN9')A9R(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W
M"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W"FUS9VED(")$969A=6QT
M(@IM<V=S='(@(D;V<G9A;'0B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G
M<W1R(")&]G)V86QD(&;D<F<B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.CDQ(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.38*;7-G:60@
M(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B1O9R=F%L9"!I9&5N=&ET970B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@
M4VAE;&PB"FUS9W-T<B`B1O9R=F%L="!S:V%L(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")$969I
M;FET:6]N97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C8T,PIM<V=I9"`B1&5L96=A=&4@<&]S:71I;VXB"FUS9W-T
M<B`B1&5L96=E<F$@<&]S:71I;VXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y,PIM<V=I9"`B1&5L96=A=&5D(@IM
M<V=S='(@(D1E;&5G97)A9"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,SD*(SH@9G)A;65W;W)K+TQI;FMS+TQI;FMS+G!H<#HR-C,*(SH@9G)A
M;65W;W)K+U)E;&%T:6]N<VAI<"]296QA=&EO;G-H:7!-86YA9V5R+G!H<#HR
M-3@@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HT,C(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")2861E<F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G
M:60@(D1E;&5T92!#96QL(@IM<V=S='(@(E)A9&5R82!C96QL(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@
M(D1E;&5T92!'<F]U<"(*;7-G<W1R(")2861E<F$@9W)U<'`B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B
M"FUS9W-T<B`B4F%D97)A(&QO9V<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@
M(E)A9&5R82!B96CV<FEG:&5T(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3,@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(E)A9&5R82!O8V@@<F5N<V$@;65D9&5L86YD96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED
M(")$96QE=&4@8V5L;"(*;7-G<W1R(")2861E<F$@8V5L;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G
M:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B4F%D97)A(&MO;'5M;B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E)A9&5R82!B969I;G1L
M:6<@86QT97)N871I=FUA;&PB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R(")2
M861E<F%D92!M961D96QA;F1E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(Q(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB
M(@IM<V=S='(@(E)A9&5R82!B96CV<FEG:&5T(&;V<B`G)7,G(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM
M<V=S='(@(E)A9&5R82!B96CV<FEG:&5T(&;V<B`G)7,G(&]C:"!U;F1E<F)E
M:/9R:6=H971E<C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@
M(E)A9&5R82!R860B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I
M='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS
M9W-T<B`B4F%D97)A('9A;&0@:61E;G1I=&5T(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@<W5B(&9O;&1E
M<G,B"FUS9W-T<B`B4F%D97)A('5N9&5R;6%P<&%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E)A9&5R82!A
M:W1U96QL(&MO;'5M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(')O=R(*;7-G<W1R(")2861E<F$@86MT=65L;"!R860B"@HC.B!F<F%M
M97=O<FLO3&EN:W,O3&EN:W,N<&AP.C(V,PHC.B!F<F%M97=O<FLO4F5L871I
M;VYS:&EP+U)E;&%T:6]N<VAI<$UA;F%G97(N<&AP.C(U.`IM<V=I9"`B1&5L
M971E('1H:7,@;&EN:R(*;7-G<W1R(")2861E<F$@9&5N(&CD<B!LY&YK96XB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B4F%D97)A9&4@=7!P9W)A9&5R:6YG<W-C<FEP=&5T("<E<R<N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y
M('1I;64B"FUS9W-T<B`B3&5V97)A;G-T:60B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E
M;FUA<FLB"FUS9W-T<B`B1&%N;6%R:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0R"FUS9VED(")$96YY(')E<75E
M<W0B"FUS9W-T<B`B079S;.4@8F5GY')A;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<Q"FUS9VED(")$96YY(')E
M<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R(")!=G-L
MY2!B96?D<F%N(&]M(&QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R
M:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D)E<VMR:78@<')O8FQE;65T(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M-C4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B0F5S
M:W)I=FYI;F<B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-2!L
M:6(O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&IE<B`H;V-K<^4@:2!(;W)D
M97,@;&]G9V9I;"DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.3D@;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%L
M:F5R(&AA<B!L;V=G871S(&;V<B!S>7-T96UA9&UI;FES=')A=/9R96XN(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO
M<&UE;G0B"FUS9W-T<B`B571V96-K;&EN9R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B1&%G9W!U;FMT
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G:60@(D1E=R!0;VEN
M="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B1&%G9W!U;FMT(&;V<B!S96YA
M<W1E('1I;6UE;CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B1&%G9W!U;FMT.B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X
M"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")2:6MT
M;FEN9R!VY&YS=&5R('1I;&P@:/9G97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F="(*;7-G<W1R(")2:6MT;FEN9R!H]F=E<B!T:6QL(';D;G-T
M97(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T
M;W)Y(@IM<V=S='(@(DMA=&%L;V<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@
M(E9I<V$@,C0M=&EM;6%R<R!K;&]C:V$_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E9I
M<VYI;F=S:6YS=.1L;&YI;F=A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*
M;7-G<W1R(")6:7-A(&1E=&%L:F5R860@9O9R=71SY&=E;'-E(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*2(*;7-G<W1R(")6:7-A(&;V<G5T<^1G96QS92`H5$%&*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(X,#,*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(E9I<VYI;F=S
M9F]R;6%T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,"!L
M:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]D:79I9&5R
M+G!H<#HT(&QI8B]";&]C:R]D:79I9&5R+G!H<#HT-0IM<V=I9"`B1&EV:61E
M<B(*;7-G<W1R(")!=G-K:6QJ87)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T
M:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(R(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"FUS9VED
M(")$;R!N;W0@9&5L971E(@IM<V=S='(@(E)A9&5R82!I;G1E(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(")!;G;D;F0@:6YT
M92!M86EN=&5N86YC92YP:'`@9&ER96MT(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*
M;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B26YN96CE
M;&QE<B!F]G)S=&$@<F%D96X@9N1L=&YA;6YE;C\@3VT@)VIA)RP@;6%R:V5R
M82!HY'(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI
M;FEK86YS:V$@<F5P=6)L:6ME;B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U
M<"XB"FUS9W-T<B`B2&%R(&1U(&EN9V5T(&MO;G1O/R!296=I<W1R97)A(&1I
M9RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#,@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,@IM<V=I9"`B1&]W;FQO
M860B"FUS9W-T<B`B2.1M=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#,@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R(")(
MY&UT82`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@
M(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I
M<'0N(@IM<V=S='(@(DCD;71A(&=E;F5R97)A9"!K;VYF:6=U<F%T:6]N('-O
M;2!02%`M<VMR:7!T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G:60@(D1R;W`@9&]W;B!L
M:7-T(@IM<V=S='(@(D1R;W!P;&ES=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=E<B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+7!O<W0B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY
M,B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I
M;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P
M<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@HB1')I=G)U=&EN(&;V
M<B!%+7!O<W0@=&EL;"!335,M8G)Y9V=A.R!F]G(@;W!E<F%T]G)E<B!S;VT@
M=&EL;&AA;F1A:.5L;&5R("(*(F1E;FYA('1JY&YS="XB"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,T"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D9%3"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B16-U861O<B(*;7-G<W1R(")%:W5A9&]R(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C4@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#$*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS9VED
M(")%9&ET(@IM<V=S='(@(L1N9')A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+U5)+G!H<#HU,"!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P"FUS9VED
M(")%9&ET($)L;V-K(@IM<V=S='(@(L1N9')A(&)L;V-K(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D
M:70@1W)O=7`B"FUS9W-T<B`BQ&YD<F$@9W)U<'`B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3`P"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S8@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*
M;7-G<W1R("+$;F1R82!B96CV<FEG:&5T(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R
M("+$;F1R82!B96CV<FEG:&5T97(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S(@IM<V=S='(@(L1N9')A(&)E:/9R:6=H971E<B!F]G(@)7,B
M"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P
M=&EO;G,@9F]R.B(*;7-G<W1R("+$;F1R82!I;G-TY&QL;FEN9V%R(&;V<CHB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BQ&YD<F$@8F5H]G)I
M9VAE=&5R(&;V<B`G)7,G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R("+$;F1R82!B96CV<FEG:&5T97(@9O9R("<E<R<B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*
M;7-G<W1R(")5=&)I;&1N:6YG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G
M<W1R(")%9WEP=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<T(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B
M"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N
M+BXB"FUS9W-T<B`B16QE;65N="XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%
M;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@W,R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-C8*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D4M<&]S=&%D<F5S<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R(")%+7!O<W1A9')E<W-E<B!MY7-T92!S=.1M;6$@]G9E<G)E;G,N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DY,PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`B12UP;W-T;65D9&5L86YD92!M960@8F5K<N1F=&5L<V4B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,2!L
M:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT
M;RU335,@1V%T97=A>2(*;7-G<W1R(")%+7!O<W0@=&EL;"!335,M8G)Y9V=A
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X
M,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS
M9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B2^1N<VQO:6MO;F5R(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%
M;7!T>2!M97-S86=E+B(*;7-G<W1R(")4;VUT(&UE9&1E;&%N9&4N(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,"!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S"B,Z(&QI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<#HT.#0@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8V,@HC
M.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")4
M;VUT(')E<W5L=&%T+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ,3,@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED
M(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5&]M="!S]FMK<FET97)I
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-#0X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-34S"FUS9VED(")%;F0B"FUS9W-T<B`B4VQU="(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B
M4VQU="#E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(D;V<G-T
M;W)A(&5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G
M:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I
M;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!5
M4DP@:&5R92(*;7-G<W1R(")!;F=E('/V:W;D9R`H55),*2!T:6QL(&)I;&1E
M;B!HY'(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#8S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX
M.3(*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R(")3
M2W)I=B!B;VMS=.1V97)N82!N961A;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T
M;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS9VED
M(")%<G)O<B(*;7-G<W1R(")&96PB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O
M5&5M<&QA=&4N<&AP.C0V,R!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B
M"FUS9W-T<B`B1F5L('9I9"!S:V%P86YD92!A=B!B;&]C:SH@)7,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B
M1F5L('9I9"!R861E<FEN9R!A=B!S>6YK<F]N:7-E<FEN9W-MY')K93H@)7,B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T
M<B`B1F5L('9I9"!R861E<FEN9R!A=B!S>6YK<F]N:7-E<FEN9W-L;V=G.B`E
M<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X(&QI
M8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B1F5L(&[D<B!I
M;FYE:.5L(&CD;71A9&5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DU"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C<X"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0W"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R(")&96P@
M=6YD97(@<^1N9&YI;F<@878@<W9A<G-M961D96QA;F1E.B`E<R(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B1F5L
M('9I9"!U<'!D871E<FEN9R!A=B!L]G-E;F]R9#H@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R
M('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$T,@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D9E;"!V:60@<VMR:79N:6YG("<E
M<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!W<FET:6YG("<E<R<N(@IM<V=S='(@(D9E;"!V:60@<VMR:79N:6YG
M(&%V("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S
M=&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,0HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:6]P
M:65N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN
M:6,B"FUS9W-T<B`B171N:7-K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%
M=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")687(@
M,34Z92!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")687)A;FYA;B!M:6YU="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")6
M87(@,S`Z92!S96MU;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN
M=71E<R(*;7-G<W1R(")687(@-3IE(&UI;G5T(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,"!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")687)J
M92!I;FQO9V=N:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM
M<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(E9A<FIE(&AA;'9T:6UM
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(E9A
M<FIE(&UI;G5T(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*
M;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")%>&5M<&5L('#E(';D
M<F1E;CHB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE
M;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U
M=&4B"FUS9W-T<B`B2_9R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-#<U(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0W-0HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I
M9"`B17AP86YD(@IM<V=S='(@(D5X<&%N9&5R82(*"B,Z('1E;7!L871E<R]P
M;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM
M<V=S='(@(D5X<&%N9&5R82!S:61O9N1L="(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ-C@@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B1O9R=N1N=&%D
M92`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U
M(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")&
M]G)VY&YT861E(&5N<VMI;'0@;W)D(&5L;&5R(&-I=&5R870@<_9K8F5G<F5P
M<"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,2!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T
M92(*;7-G<W1R(")&]G)F86QL;V1A='5M(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5X<&]N96YT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B1O9R9W)U;F1S9N1R9R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@
M;V8@<V5T=7`B"FUS9W-T<B`B3&%D9&$@=7!P(&MO;F9I9W5R871I;VX@=FEA
M($944"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38@
M;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B36ES<VQY8VMA9&5S(&%T
M="!HY&UT82!I;G-TY&QL;FEN9V%R+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.CDX"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW-2!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DUI<W-L>6-K861E<R!A='0@:V]N=&%K
M=&$@3$1!4"!S97)V97(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.CDX(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(DUI<W-L>6-K
M861E<R!A='0@:V]N=&%K=&$@4TU"('-E<G9E<BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C8X-B!L:6(O5D93+V9T<"YP:'`Z-S$W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*
M;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&MO<&EE<F$@9G+E;B`G)7,G+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ(&QI8B]61E,O9G1P
M+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@
M=&\@7"(E<UPB+B(*;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&MO<&EE<F$@
M=&EL;"`G)7,G+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M.#<@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T
M;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B36ES<VQY
M8VMA9&5S(&%T="!S:V%P82!N>2!305-,+6;V<F)I;F1E;'-E+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S(T"B,Z(&QI8B]61E,O<VUB+G!H<#HU,#$@;&EB+U9&4R]F
M='`N<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V
M92!T;R!<(B5S7"(N(@IM<V=S='(@(DUI<W-L>6-K861E<R!A='0@9FQY='1A
M('1I;&P@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V
M,2!L:6(O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B36ES<VQY8VMA9&5S(&%T
M="!HY&UT83H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")"<F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<R(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-`HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-SD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&
M86QK;&%N9'/V87)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*
M;7-G<W1R(")&Y'+V87)N82(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M,S@@;&EB+TAO<F1E+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB
M"FUS9W-T<B`B1F%T86QT(&9E;#HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3@W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS
M9W-T<B`B1F%X87(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,34*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(F9E8G)U87)I(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B
M2^1N;G,@<V]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(DOD;FYS('-O;3H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G
M:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D;E=&%L:6=A('-K=7)A<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED
M(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(D;E=&%L:6=A('-N]G-K=7)A
M<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")&
MY&QT;6%T<FES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,R.0IM<V=I9"`B1FEG;&5T($-!4%1#2$$B
M"FUS9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S,W(&QI8B](;W)D92]&;W)M+G!H<#HS,S,S"FUS9VED(")&
M:6=L970@9F]N="(*;7-G<W1R(")&:6=L971T>7!S;FET="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S='(@(D9I;"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C8P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B
M06YT86P@9FEL97(Z("5S(&9I;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@
M0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D%N=&%L(&9I;&5R.B`E<R!F:6QE
M<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I
M;&4@36%N86=E<B(*;7-G<W1R(")&:6QH86YT97)A<F4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-2!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,"!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.
M86UE(@IM<V=S='(@(D9I;&YA;6XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3DU(&QI8B](;W)D92]&;W)M+G!H<#HR.3@Q"FUS9VED(")&:6QE
M('-E;&5C=&EO;B(*;7-G<W1R(")&:6QV86PB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#@V(&QI8B](;W)D92]&;W)M+G!H<#HQ-#DP"FUS9VED
M(")&:6QE('5P;&]A9"(*;7-G<W1R(")&:6QU<'!L861D;FEN9R(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-"!L:6(O2&]R9&4O0G)O
M=W-E<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B1FEL=7!P;&%D9&YI;F<@<W3V9',@:6YT92XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B1FEL=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@
M(D9I;FQA;F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&
M:7)S="!(86QF(@IM<V=S='(@(D;V<G-T82!H86QV86XB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&
M:7)S="!1=6%R=&5R(@IM<V=S='(@(D;V<G-T82!K=F%R=&5N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@
M<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Q-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G
M:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$P-PHC.B!L:6(O5D93+W-Q;"YP:'`Z,C,W(&QI8B]6
M1E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B36%P<"`E<R!E>&ES=&5R87(@
M:6YT92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D9O;G1FY')G(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S
M='(@(DUA="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B1O9R('=E8F)LY'-A<F4@
M<V]M(&EN=&4@<W3V9&5R(&)I;&1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<F]G;F]S
M("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS
M9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D
M(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M(@IM<V=S='(@(B(*(D%N=&%L(&1A9V%R(&;V<B!P<F]G;F]S("AV87)J92!D
M86<@8F5T>61E<B!E;B!P<F]G;F]S(&;V<B!D86<@;V-H(&5N(&;V<B`B"B)N
M871T*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED
M(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B1VSV;70@9&ET="!L
M]G-E;F]R9#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS
M9VED(")&;W)M<R(*;7-G<W1R(")&;W)M=6SD<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")6:7-H971S
M;W)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T
M=6YE('1Y<&4B"FUS9W-T<B`B5'EP(&%V('9I<VAE='-O<F0B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@
M(E9I<VAE='-O<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G
M:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B5FES:&5T<V]R9"`R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S
M='(@(D9O<G5M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM
M<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5FED87)B969O<F1R87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED
M(")&<B(*;7-G<W1R(")&<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R
M(")286UA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YK
M<FEK92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O
M;&ET86XB"FUS9W-T<B`B1G)A;FMR:6ME+"!-971R;W!O;"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$W"FUS9VED
M(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B3&5D:6<O57!P=&%G
M96X@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0R-PIM<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM
M<V=S='(@(DQE9&EG+U5P<'1A9V5N('-V87(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R,@IM<V=I9"`B1G)E92]"
M=7-Y(%)E<75E<W0B"FUS9W-T<B`B3&5D:6<O=7!P=&%G96XM9O9R9G+E9V%N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HR-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HS-#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM
M<V=S='(@(E-V87(@<.4@;&5D:6<O=7!P=&%G96XM9O9R9G+E9V%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@T(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(D9R86YS:V$@1W5I
M86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T
M<B`B1G)A;G-K82!0;VQY;F5S:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E
M;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YS:V$@<_9D
M<F$@=&5R<FET;W)I97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D9RY6XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D9RY6X@9&5N("(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(D9U;&QS=.1N9&EG(&)E<VMR:79N:6YG
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")&=6QL;>5N92(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B1G5L
M;'-TY&YD:6=T(&YA;6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@
M(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;2(*;7-G<W1R(")'86QL97)I(&%T="!T82!B:6QD(&9RY6XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&QE<FDZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R97)A(&MO
M;F9I9W5R871I;VX@9O9R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@
M(D=E;F5R97)A9"!K;V0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T
M<B`B1V5O<F=I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B
M5'ES:VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H86YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B
M"FUS9W-T<B`B1O9R;F%M;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM
M<V=S='(@(D=L;V)A;&$@:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R(")/2R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@
M(D=O961E;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3`P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&5K87)T
M;W(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G
M;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L97/V:VYI;F<B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES8V%L
M92(*;7-G<W1R(")'<N5S:V%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDS(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B
M"FUS9W-T<B`B1W)E:VES:R`H25-/+3@X-3DM-RDB"@HC.B!C;VYF:6<O=&AE
M;65S+V=R965N+G!H<#HV"FUS9VED(")'<F5E;B(*;7-G<W1R(")'<O9N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W+V;FQA;F0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)A;F%D82(*"B,Z(&-O
M;F9I9R]T:&5M97,O9W)E>2YP:'`Z-@IM<V=I9"`B1W)E>2(*;7-G<W1R(")'
M<N4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!A9&UI;FES=')A=&EO;B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$V.0HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4Y
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B`B"FUS9W-T<B`B1W)O=7!?;&1A<#H@2V%N(&EN=&4@;.1G9V$@
M=&EL;"!G<G5P<"`G)7,G+B!397)V97)N('-V87)A9&4Z("(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#$X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$R-"!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A
M<#H@2V%N(&EN=&4@<F%D97)A(&=R=7!P("<E<R<B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS-SD*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,S
M."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B
M"FUS9W-T<B`B1W)O=7!?;&1A<#H@2V%N(&EN=&4@=7!P9&%T97)A(&=R=7!P
M("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-`HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B
M1W)O=7!S(@IM<V=S='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E
M;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T
M<B`B1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B
M1W5A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S
M='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,C8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B1^1S=&)E:/9R:6=H971E<B(*"B,Z('1E;7!L871E<R]G=65S
M="]G=65S="YI;F,Z,3$*;7-G:60@(D=U97-T(%-E<G9I8V5S(@IM<V=S='(@
M(E1JY&YS=&5R(&;V<B!GY'-T97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B1^1S=&)O:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5A+4)I
M<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=6EN
M96$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`@;&EB+TAO<F1E
M+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(';D9W)A
M<B!A='0@<F%D97)A('-I<W1A(&-E;&QE;B!I(&5N(')A9"XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(';D9W)A
M<B!A='0@<F%D97)A('-I<W1A(&MO;'5M;F5N(&D@96X@=&%B96QL+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@=N1G
M<F%R(&%T="!R861E<F$@<VES=&$@<F%D96X@:2!E;B!T86)E;&PN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<@;&EB+TAO<F1E+T%U
M=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B2%144"!!=71E;G1I<V5R:6YG('-A:VYA<RXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,`HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S
M='(@(DAA<VAA;&=O<FET;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(D1I;6UA(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,S(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDR,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDQ.`IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(E)U
M8G)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-C$*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`B4G5B<FEK97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS
M9W-T<B`B2&5A<F0M(&]C:"!-8T1O;F%L9/9A<FYA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M
M4W1O<FTB"FUS9W-T<B`B2W)A9G1I9V$@Y7-K<VMU<F%R(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)
M*2(*;7-G<W1R(")(96)R96ES:R`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G
M:60@(DAE:6=H="(*;7-G<W1R(")(]FID(@H*(SH@;&EB+T)L;V-K+V)A<G1I
M;64N<&AP.C(T(&QI8B]";&]C:R]D:79I9&5R+G!H<#HR-`IM<V=I9"`B2&5I
M9VAT("AI;B!P:7AE;',I(@IM<V=S='(@(DCV:F0@*'!I>&QA<BDB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](
M;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TAE;'`N<&AP
M.C$X-"!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED
M(")(96QP(@IM<V=S='(@(DAJY&QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET
M;W(B"FUS9W-T<B`B2&KD;'`@;65D(&5D:71O<FXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<U"FUS
M9VED(")(96QP97(B"FUS9W-T<B`B2&KD;'!F=6YK=&EO;B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(
M96UI<V;D<B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H
M92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(DCD<B#D<B!B]G)J
M86X@878@9FEL96XZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S`*;7-G:60@(DAI9V@B"FUS9W-T<B`B2/9G(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")(95]M(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$T.3$@;&EB+TAO<F1E+G!H<#HQ-3,Y"FUS9VED(")(;VUE(@IM<V=S='(@
M(DAE;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M
M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S<RP@:&5M(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R
M(")(96UK871A;&]G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE9F]N+"!H
M96TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD
M=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`V
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#8@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(
M;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G
M:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-#(@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@3V=I;'1I9W0@)7,@6$U,+61A=&$@<.5T<N1F9F%D97,@:2!M961D
M96QA;F1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F=E="!M961D96QA;F1E(&UA
M=&-H87(@;V)J96MT970@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0S-2!L:6(O2&]R9&4O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA;CH@26YG970@
M;V)J96MT(&%V('1Y<&5N("5S(&AI='1A9&5S(&D@;65D9&5L86YD970@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(%)A9&5R861E("5S("<E<R<B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(R,R!L:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM
M<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($EN=&5G<F%T:6]N<VUO=&]R;B!K<N1V97(@)V1O;7AM;"<M
M=&EL;.1G9V5T(&;V<B!02%`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C4P,R!L:6(O2&]R9&4O2V]L86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N
M(&EN=&4@<VMA<&$@;GET="!834PM='+D9"!F]G(@;V)J96MT("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!+86X@:6YT92!R861E<F$@)7,@)R5S)SH@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-"!L:6(O2&]R9&4O2V]L86(N<&AP
M.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I;G1E(&CD;71A($U)341%+4E$
M(&;V<B!D96QE;B!M960@='EP("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3DS(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I
M;G1E('-Y;FMR;VYI<V5R82`E<R`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3,S-B!L:6(O2&]R9&4O2V]L86(N<&AP.C$S,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+
M86X@:6YT92!S>6YK<F]N:7-E<F$@=71D96QN:6YG87(Z("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!/:^1N9"!U
M=&1E;&YI;F<@)R5S)R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R
M(")(;W)I<V]N=&5L;"!L:6YJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN
M9R(*;7-G<W1R(")(;W)I<V]N=&5L;"!U=&9Y;&QN860B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I
M>F]N=&%L.B(*;7-G<W1R(")(;W)I<V]N=&5L;#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(DAU<B!H86UN861E(&1U(&CD<C\@*%9A<B!G;V0@<F%P<&]R=&5R82!D
M971T82$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2'5R(&WE;F=A(&MO;'5M;F5R
M('9I;&P@9'4@<VSE(&EH;W`_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/R(*;7-G<W1R(")(=7(@;>5N9V$@9N1L="`H:V]L=6UN97(I(&9I
M;FYS(&1E=#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(=7(@;>5N9V$@<F%D97(@=FEL
M;"!D=2!S;.4@<V%M;6%N/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G:60@(DAU;6ED
M:71Y(@IM<V=S='(@(D9U:W1I9VAE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B1G5K
M=&EG:&5T.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B
M2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS
M9VED(")(=6YG87)Y(@IM<V=S='(@(E5N9V5R;B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,C,U"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B4VMA<&%N9&4@878@24U!4"UM87!P(&UI<W-L>6-K861E.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B4F%D97)I;F<@878@24U!4"UM87!P(&UI<W-L>6-K
M861E<SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-K87!A;F1E(&%V
M('%U;W1A(&;V<B!)34%0+6UA<'`@;6ES<VQY8VMA9&5S.B`E<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`M861R97-S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-R!L:6(O2&]R
M9&4O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("))4"UA9')E<W,@Y'(@:6YT92!T:6QL9^1N
M9VQI9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y
M(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))
M4"UA9')E<W,@Y'(@:6YT92!I;F]M(&=O9&OD;G0@0TE$4BUB;&]C:RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G
M:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B1O9R<_9K(&%T
M="!K<FEN9V?E($E0+6SE<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W
M($)E9F]R92(*;7-G<W1R("))7VYF;V=A(')A9"!F]G)E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@R(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA;F0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@
M(D5N8F%R="!I:V]N97(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(DEK
M;VYE<B!F]G(@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS
M9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;F5R(&UE9"!T97AT
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I
M='DG<R!N86UE.B(*;7-G<W1R("))9&5N=&ET971E;G,@;F%M;CHB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(D]M(&1E="!I;G1E('9I<V%S
M(&MO<G)E:W0L("5S(&;V<B!A='0@]G!P;F$@:2!N>71T(&;V;G-T97(N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)/;2!D=2!I;G1E('-E
M<B!NY6=R82!I:V]N97(@;N1R(&1U(&%N=N1N9&5R($EN=&5R;F5T($5X<&QO
M<F5R+"!SY2!K86X@9'4@(@HB8F5H]G9A(&UA<FME<F$@9&5N;F$@<G5T82!F
M]G(@871T('-TY&YG82!A=B!G96YO;7-K:6YL:6=A(%!.1RUB:6QD9FEL97(N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$U
M.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS
M9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L
M('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB3VT@9'4@<V5R
M(&1E;FYA('1E>'0@;65N(&EN9V5N(&)I;&0L('/E(&MA;B!I;G1E(&1I;B!W
M96)B;.1S87)E('9I<V$@9&5N("(*(F)I;&0@9'4@9O9R<_9K97(@;&%D9&$@
M=7!P+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T
M<B`B1O9R:&%N9'-G<F%N<VMA(&)I;&0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@
M55),(@IM<V=S='(@(D)I;&1A9')E<W,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM
M86=E(%523#HB"FUS9W-T<B`B0FEL9&%D<F5S<SHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")":6QD(&9RY6X@9V%L
M;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*
M;7-G<W1R(")":6QD(&9RY6X@9V%L;&5R:3HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED
M("));6%G92!U<&QO860B"FUS9W-T<B`B3&%D9&$@=7!P(&)I;&0B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@
M(D)I;&1E<B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM
M<&]R=&5R82P@<W1E9R`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E
M<R(*;7-G<W1R("));7!O<G1E<F%D92!FY&QT.B`E<R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB
M"FUS9W-T<B`B26UP;W)T97)A9&4@9N1L=#HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<P,0IM<V=I9"`B26X@4')O
M8V5S<R(*;7-G<W1R(")0Y6?E96YD92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`B26Y?9F]G82!R860@969T97(B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4@;&EB+TAO
M<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D9E;&%K=&EV(&%K=&EV:71E='-K
M;V0@<W!E8VEF:6-E<F%D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(D9E;&%K=&EG="!A;G;D;F1A<FYA;6X@
M;V-H+V5L;&5R(&SV<V5N;W)D+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*(D]G:6QT:6=T(&%N=N1N9&%R;F%M;B!E;&QE<B!A;'1E<FYA=&EV
M(&%D<F5S<RX@1O9R<_9K(&EG96X@96QL97(@:V]N=&%K=&$@(@HB861M:6YI
M<W1R873V<F5N(&]M(&1U(&)E:/9V97(@:&KD;'`N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A
M<V4@26YD96YT(@IM<V=S='(@(M9K82!I;F1R86<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("));F1I82(*;7-G<W1R("));F1I96XB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(U-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U
M-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD
M:79I9'5A;"!5<V5R<R(*;7-G<W1R("));F1I=FED=65L;&$@86YVY&YD87)E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N
M97-I96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("))
M;F9O<FUA=&EO;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM
M<V=S='(@(DEN9F]R;6%T:6]N(.1R(&EN=&4@=&EL;&?D;F=L:6<@;.1N9W)E
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T
M<B`B26YF;V=A(&M?;VQU;6X@969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN
M<V5R="!);6%G92(*;7-G<W1R("));F9O9V$@8FEL9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R
M="!486)L92(*;7-G<W1R("));F9O9V$@=&%B96QL(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T
M(%=E8B!,:6YK(@IM<V=S='(@(DEN9F]G82!W96)B;.1N:R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM
M<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(DEN9F]G82!?
M:V]L=6UN(&;V<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN9F]G82!N>2!K
M;VQU;6X@969T97(@86MT=65L;"!K;VQU;6XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("));F9O9V$@;GD@:V]L=6UN(&;V<F4@86MT=65L;"!K;VQU;6XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(DEN9F]G82!R860@969T97(@86MT=65L;"!R860B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("));F9O9V$@;GD@<F%D(&;V<F4@96MT=65L
M;"!R860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E
M<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN9F]G82!P87)A9W)A9B!E
M9G1E<B!A:W1U96QL(&YO9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN9F]G
M82!P87)A9W)A9B!F]G)E(&%K='5E;&P@;F]D(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B26YF;V=A(&%L=&5R;F%T:78@;6%L;"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*
M;7-G<W1R("));F9O9V$@8V5L;"!E9G1E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R
M="!C96QL(&)E9F]R92(*;7-G<W1R("));F9O9V$@8V5L;"!F]G)E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("));F9O9V$@
M:V]L=6UN(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O
M<F4B"FUS9W-T<B`B26YF;V=A(&MO;'5M;B!F]G)E(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4P"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(DEN
M9F]G82!M961D96QA;F1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!A9G1E<B(*;7-G<W1R("));F9O9V$@<&%R86=R868@969T97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@
M(DEN9F]G82!P87)A9W)A9B!F]G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O
M=R!A9G1E<B(*;7-G<W1R("));F9O9V$@<F%D(&5F=&5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I
M9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B26YF;V=A(')A9"!F]G)E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.B(*;7-G<W1R(")!;F=E(&5R9F]R9')A="!S=F%R('1I;&P@<^1K97)H971S
M9G+E9V%N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B
M26YF;V=A+\1N9')A(&)I;&0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB
M"FUS9W-T<B`B26YF;V=A+\1N9')A(&SD;FLB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PHC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G
M<W1R(")/=&EL;'+D8VML:6<@:W)E9&ET(&;V<B!A='0@<VMI8VMA('1I;&P@
M9&ES=')I8G5T:6]N<VQI<W1A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N
M(@IM<V=S='(@(D]T:6QL<N1C:VQI9R!K<F5D:70N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`W-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W.0IM
M<V=I9"`B26YT96=E<B(*;7-G<W1R(")(96QT86PB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3,S(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,W"FUS
M9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B2&5L=&%L<VQI<W1A(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR.#,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS
M-3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O
M;7!O;F5N="XB"FUS9W-T<B`B3V=I;'1I9R#E=&?D<F0@9O9R(&1E;B!HY'(@
M:V]M<&]N96YT96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDW"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+B(*;7-G<W1R(")/9VEL=&EG(%5$2"`H)W5S97(@9&%T82!H96%D
M97(G*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ-C<@;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&QI8B](;W)D92]#;VUP
M<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G
M<W1R(")/9VEL=&EG="!:25`M87)K:79D871A(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B1F5L86MT:6<@87!P;&EK871I;VXN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A
M=&-H($E$+B(*;7-G<W1R(")&96QA:W1I9W0@8F%T8V@M240B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z,S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M.3$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-C(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R,S8@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,#,*(SH@;&EB+TAO<F1E
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T
M82!S=6)M:71T960N(@IM<V=S='(@(D9E;&%K=&EG(&1A=&$@<VMI8VMA9"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*
M;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B
M1F5L86MT:6<@9&5S=&EN871I;VYS861R97-S+B(*"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`@;&EB+TAO<F1E+T-O;7!R97-S+V1B
M>"YP:'`Z,3`Y"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$S.2!L
M:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@
M9FEL92!F;W)M870B"FUS9W-T<B`B1F5L86MT:6=T(&9I;&9O<FUA="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L
M:60@;&EC96YS92!K97DN(@IM<V=S='(@(D]G:6QT:6<@;&EC96YS;GEC:V5L
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@
M(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D9E;&%K=&EG
M(&]R="!S<&5C:69I8V5R860N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*
M;7-G<W1R(")&96QA:W1I9R!M961D96QA;F1E7W1Y<"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(D9E;&%K=&EG(&5L;&5R
M('-A:VYA9"!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R
M86UE=&5R<RXB"FUS9W-T<B`B1F5L86MT:6=T(&5L;&5R('-A:VYA9"!P87)A
M;65T97(N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED
M("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")&96QA:W1I
M9R#V=F5R;&EG9V%N9&4@8F5H]G)I9VAE="XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N
M(@IM<V=S='(@(D9E;&%K=&EG="!P87)T;F5R+6ED+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C
M="!C;V1E+B(*;7-G<W1R(")&96QA:W1I9R!P<F]D=6MT:V]D+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B
M26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B1F5L86MT:6=T('!R;W1O:V]L
M;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C<Q"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E
M<UPB(@IM<V=S='(@(D9E;&%K=&EG(&UO='1A9V%R93H@)R5S)R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-C(*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#@P(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O
M8FIE8W0B"FUS9W-T<B`B1F5L86MT:6=T('5T9&5L;FEN9W-O8FIE:W0B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#$*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G
M:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D9E;&%K=&EG
M(&%V<^1N9&%R861R97-S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N
M(@IM<V=S='(@(D9E;&%K=&EG="!U;FEC;V1E+61A=&$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T
M<B`B26YV96YT87)I97(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C4T"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B
M26YV97)T97)A('5R=F%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M27)E;&%N9"(*;7-G<W1R("))<FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED
M("))<VQE(&]F($UA;B(*;7-G<W1R("))<VQE(&]F($UA;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L
M871E9"!4+5-T;W)M<R(*;7-G<W1R(")%;G-T86MA(.5S:W-K=7)A<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$T"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)A96PB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-2!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(E5T
M9N1R9&%T(&%V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B2W5R<VEV(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C$*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EE;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EC82(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S<*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G
M<W1R(")J86YU87)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T
M<B`B2F%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!A;G-K("A)4T\M
M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T
M<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q."!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@
M(DIO<F1A;FEE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0R,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM
M<V=I9"`B2G5L>2(*;7-G<W1R(")J=6QI(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Y"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(FIU;FDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X
M"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(DIU<W1E<F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I
M9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B0V5N=&5R:G5S=&5R82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B2G5S=&5R82!JY&UT
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")6Y&YS=&5R
M:G5S=&5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@
M(DCV9V5R:G5S=&5R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-@HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+96YY82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4@;&EB+TAO<F1E+T%U=&@O:W)B
M-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W-S97)V97)N(&%V=FES861E
M(&%U=&5N=&ES97)I;F=E;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,"!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(").>6-K
M96P@<VMA<&%D(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#`S(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I
M;F=E<G!R:6YT(@IM<V=S='(@(D9I;F=E<G!R:6YT(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`Q(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(").>6-K96QLY&YG
M9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,"!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S
M='(@(DYY8VME;'1Y<"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DX(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED
M(")+97D@57-A9V4B"FUS9W-T<B`B3GEC:V5L86YVY&YD86YD92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<R.2!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B3GEC:V5L(&9I;FYS(')E
M9&%N('#E(&1E;B!P=6)L:6MA(&YY8VME;'-E<G9E<FXN(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(D)A<FXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.0HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T
M:2(*"B,Z(&-O;F9I9R]T:&5M97,O:V]L86(N<&AP.CD*;7-G:60@(DMO;&%B
M(@IM<V=S='(@(DMO;&%B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E
M;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B3F]R9&MO
M<F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(E-Y9&MO<F5A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*
M;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")+;W)E86YS:R`H155#
M+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C0@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=7=A
M:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-PHC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI
M<F=I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I
M9"`B3&%?>6]U="(*;7-G<W1R("),85]Y;W5T(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B4W!R
MY6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-PHC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I
M8R!297!U8FQI8R(*;7-G<W1R("),86]S(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E-I<W1A(&AA;'9A
M;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!0
M87-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B3/9S96YO<F0@Y&YD<F%D97,B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X
M"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B4VES=&$@:W9A<G1A;&5T
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@(DQA<W0@57!D
M871E9#HB"FUS9W-T<B`B4V5N87-T('5P<&1A=&5R860Z(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S$Y(&QI8B](;W)D92]!=71H+G!H<#HW,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
M4V5N87-T92!I;FQO9V=N:6YG.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<R,2!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B4V5N
M87-T92!I;FQO9V=N:6YG.B`E<R!F<N5N("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z-S$V(&QI8B](;W)D92]!=71H+G!H<#HW,30*;7-G:60@
M(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(E-E;F%S=&4@:6YL;V=G;FEN
M9SH@06QD<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@
M(DQE='1L86YD(@H*(SH@8V]N9FEG+W1H96UE<R]L879E;F1E<BYP:'`Z-@IM
M<V=I9"`B3&%V96YD97(B"FUS9W-T<B`B3&%V96YD97(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("),86<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("),87EO=70B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(DSD;6YA('1O;2!F]G(@
M871T('-TY&YG82!A=B!K86YT;&EN:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),
M96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS
M9W-T<B`B5N1N<W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#4*;7-G:60@(DQE9G0@:&5A9&5R
M(@IM<V=S='(@(E;D;G-T97)R=6)R:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$U(&QI8B](;W)D92]&;W)M+G!H<#HS,3`Q"FUS9VED("),
M969T('9A;'5E<R(*;7-G<W1R(")6Y&YS=&5R=N1R9&5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R
M(").:7;E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),
M:6)E<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI
M<FEY82(*;7-G<W1R("),:6)Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C
M:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!C;VYF:6<O
M=&AE;65S+VQI9VAT8FQU92YP:'`Z-@IM<V=I9"`B3&EG:'0@0FQU92(*;7-G
M<W1R("),:G5S8FSE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B1'5G
M9W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),Y'1T(')E9VXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I
M9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("),Y'1T(&;V<FUI9&1A9W-R
M96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("),Y'1T(&5F=&5R
M;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B
M3.1T="!R96=N<VMU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("),Y'1T(')E9VX@;65D(.5S:V$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R("),Y'1T('-N]B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G
M<W1R("),Y'1T('-N]G-K=7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI;65R:6-K(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("),Y&YK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED
M("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3.1N:V5N('!E:V%R('#E.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B3.1N
M:V$@92UP;W-T861R97-S96X@=&EL;"!F=6YK=&EO;F5N(&;V<B!A='0@<VMA
M<&$@;GET="!M961D96QA;F1E(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PHC.B!F<F%M97=O<FLO5&5X="]4
M97AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$U.`HC.B!L:6(O2&]R9&4O5&5X
M="]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S
M='(@(DSD;FMA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I
M9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DMA:V$B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD
M97(B"FUS9W-T<B`B3&ES=&$@+2!A;G;D;F1A<F4@:V%N('-E(&UA<'!E;B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A
M<V5S(@IM<V=S='(@(E9I<V$@9&%T86)A<V5R(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T
M<B`B5FES82!H:N1L<.1M;F5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3&ES=&$@=&%B96QL97(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-"!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV
M92(*;7-G<W1R("),:7-T+4%R8VAI=F4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4X.2!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T+4AE;'`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-B!L:6(O2&]R
M9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T
M<B`B3&ES="U)9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DR(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B
M3&ES="U/=VYE<B(*;7-G<W1R("),:7-T+4]W;F5R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3,@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES="U0
M;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U
M8G-C<FEB92(*;7-G<W1R("),:7-T+5-U8G-C<FEB92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R
M("),:7-T+55N<W5B<V-R:6)E(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R
M"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D
M.B`E<R(*;7-G<W1R(")$970@9VEC:R!I;G1E(&%T="!L:7-T82!S97-S:6]N
M97(Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M
M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")$
M970@9VEC:R!I;G1E(&%T="!L:7-T82!A;G;D;F1A<F4Z("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG
M('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),:7-T;FEN9R!A=B!A;G;D
M;F1A<F4@879A:W1I=F5R860N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI='1E<F%T=7(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-`HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET875E;B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@
M(DQO861I;F<N+BXB"FUS9W-T<B`B3&%D9&%R+BXN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM
M<V=S='(@(DQO:V%L('1I9#H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B4F5G:6]N86QT
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-S`@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4W(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED("),;V-A=&EO;B(*;7-G
M<W1R(")0;&%T<R(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L
M+VUE;G4N<&AP.C$V,R!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,34*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHY,"!T96UP;&%T97,O9W5E<W0O9W5E<W0N:6YC.C,P"FUS9VED("),;V<@
M:6XB"FUS9W-T<B`B3&]G9V$@:6XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUE;G4N<&AP.C$U
M-R!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@
M;W5T(@IM<V=S='(@(DQO9V=A('5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("),;V=I;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S
M='(@(DQO9VEN86MT:79I=&5T97(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.38@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB26YL;V=G;FEN9R!M
M:7-S;'EC:V%D97,N(%1R;VQI9W1V:7,@=F%R(&%N=N1N9&%R;F%M;B!E;&QE
M<B!L]G-E;F]R9"`B"B)F96QA:W1I9W0N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3DR(&QI8B](;W)D92]!=71H+G!H<#HY.3$*;7-G:60@(DQO
M9VEN(&9A:6QE9"XB"FUS9W-T<B`B26YL;V=G;FEN9R!M:7-S;'EC:V%D97,N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DSE;F<@
M=&5X="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V
M92(*;7-G<W1R(")+Y')L96LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM<V=S='(@(DSE9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B1W)E
M:VES:V$@9V5M96YE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE
M='1E<G,B"FUS9W-T<B`B3&%T:6YS:V$@9V5M96YE<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G
M:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B4VWE(')O;65R<VMA
M('-I9F9R;W(B"@HC.B!C;VYF:6<O=&AE;65S+VQU8RYP:'`Z-@IM<V=I9"`B
M3&]Y;VQA(@IM<V=S='(@(DQO>6]L82(*"B,Z(&-O;F9I9R]T:&5M97,O;'5C
M8FQU92YP:'`Z-@IM<V=I9"`B3&]Y;VQA($)L=64B"FUS9W-T<B`B3&]Y;VQA
M($)LY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B
M3'5X96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,W-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$
M(@IM<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS-B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B35,M5$Y%1B!B:6QA9V$@:6YN96CV;&P@:6YG96X@9&%T
M82XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@
M(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D;VYI96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9V%G87-K87(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM
M<V=S='(@(DUA9VES:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX
M,PIM<V=I9"`B36%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@
M(D4M<&]S=&%D;6EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(E-K87!A(&SD;FLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA
M=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES
M:6$B"FUS9W-T<B`B36%L87ES:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD
M:79E<R(*;7-G<W1R(")-86QD:79E<FYA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-30*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B
M"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*
M;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I
M871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(E5N9&5R
M:.5L;"!L:7-T86X@;65D(&MA=&5G;W)I97(@9'4@86YVY&YD97(@9O9R(&%T
M="!K871E9V]R:7-E<F$@<&]S=&5R(&UE9"`B"B)O8V@@9N1R9V5R;F$@<V]M
M('1I;&QH]G(@9&5S<V$@:V%T96=O<FEE<BXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R-0HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM
M<V=S='(@(DUA<#(T+6MA<G1A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P-38*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-#`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P.#<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-
M87!1=65S="UK87)T82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("+6=F5R<^1T
M=&YI;F=A<B!S<&%R861E+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-SD*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B;6%R<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA<F=I;B(*;7-G<W1R(")-87)G:6YA;"(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X(&QI8B](;W)D92])34%0+T%#3"]R
M9F,T,S$T+G!H<#HT.`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G
M<W1R(")&;&%G9V$@<V]M(&SD<W0O;VSD<W0B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.2!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-#D*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")&;&%G9V$@;65D(&%N;F%N('-T
M871U<R`H="!E>"!V:6MT:6=T+V)E<W9A<F%T*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,2!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R<VAA;&SV87)N82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN
M:7%U92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED
M(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B36%T8VAA;F1E(&;D;'0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,`HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I=&%N
M:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA
M=7)I=&EU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")-
M87@@=&EL;.5T96X@:W)E9&ET+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N(@IM<V=S='(@(D=RY&YS(&;V<B!M87@@86YT86P@9&5L87(@
M:2!M961D96QA;F1E(/9V97)S:W)I9&5N+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S=&4@,C0@=&EM;6%R;F$Z
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")(]F=S=&$@=&5M<&5R871U<F4@
M<V5N87-T92`V('1I;6UA<FYA.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I
M9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")-
M87AI;6%L="!A;G1A;"!P;W)T86QB;&]C:R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD@;&EB+TAO<F1E+T9O<FTN
M<&AP.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R,0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B
M36%X:6UA;"!LY&YG9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M.0IM<V=I9"`B36%Y(@IM<V=S='(@(FUA:B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I8VEN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,S$*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@(D%V
M8F]K82!M]G1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU,#,*;7-G:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS
M9W-T<B`B3?9T97-I;F9O<FUA=&EO;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`Y"FUS9VED(")-965T:6YG(%!R
M;W!O<V%L(@IM<V=S='(@(DWV=&5S9O9R9G+E9V%N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,C4*;7-G:60@(DUE
M971I;F<@4F5P;'DB"FUS9W-T<B`B3?9T97-S=F%R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,30*;7-G:60@(DUE
M971I;F<@57!D871E(@IM<V=S='(@(DWV=&5S=7!P9&%T97)I;F<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q.0IM
M<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R(")5<'!D871E
M<FEN9W-B96?D<F%N(&]M(&WV=&4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE9&QE
M;6UA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE
M;G4@;6]D93HB"FUS9W-T<B`B365N>6SD9V4Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R
M9V4@8V5L;',B"FUS9W-T<B`B4VSE(&EH;W`@8V5L;&5R(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HS,`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE9&1E;&%N9&4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(DUE9&1E;&%N9&5T
M('9E<FEF:65R861E<R!M96X@9&5N('-I9VYE<F%D97,@8V5R=&EF:6MA="!K
M=6YD92!I;G1E('9E<FEF:65R87,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N
M(@IM<V=S='(@(DUE9&1E;&%N9&4@9^1L;&5R(&EN=&4@;.1N9W)E+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-C`*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B
M"FUS9W-T<B`B365D9&5L86YD971Y<"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")-971A<G;D9&5R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T87)B;&]C:V5T(.1R(&EN
M=&4@=&EL;&?D;F=L:70N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*
M;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(DUE=&%R+6)L;V-K(&5J('1I;&QGY&YG;&EG="X@1&5T86QJ97(@
M:&%R(&QO9V=A=',@9O9R('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"
M(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(DUE=&%R1$(@Y'(@:6YT92!A
M;G-L=71E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M(")-971O9"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@
M9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,Z(&QI8B](;W)D92]2
M4$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I
M;F5D(@IM<V=S='(@(DUE=&]D96X@)R5S)R#D<B!I;G1E(&1E9FEN:65R860B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HV,2!L:6(O2&]R9&4O
M4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N
M;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B365T;V1E
M;B!H87(@:6YT92!D969I;F5R871S+B!!;G)O<&%D(&UE=&]D.B`E<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T
M87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FES:R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI:V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*
M;7-G<W1R(")-:6MR;VYE<VEE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S
M='(@(DUI='1E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;65T>7`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R
M<SH@(@IM<V=S='(@(DSD9W-T82!T96UP97)A='5R('-E;F%S=&4@,C0@=&EM
M;6%R;F$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-
M:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("),Y&=S=&$@=&5M<&5R
M871U<B!S96YA<W1E(#8@=&EM;6%R;F$Z("(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#,Y(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0S
M.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP
M:7)E9"(*;7-G<W1R(")-:6YS=&$@;/9S96YO<F1SY6QD97(@:&%R(&EN=&4@
M=7!P;N5T=',@Y&XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C$W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")3<&5G;&$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B
M"FUS9W-T<B`B1&EV97)S92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(U,"!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0P(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B3V)L
M:6=A=&]R:7-K="!P86ME="!S86MN87,@*%!%05(@2%144%]297%U97-T*2XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@HB2V]N9FEG=7)A=&EO;B!S86MN87,N($1U(&WE<W1E('-K87!A
M(&1E;B!N=2!O;2!D=2!V:6QL(&%N=N1N9&$@9&5N(&CD<B`B"B)A<'!L:6MA
M=&EO;F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")3
M86MN87(@;65D9&5L86YD92U)1"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`HC.B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")/8FQI9V%T;W)I<VMT
M('!A:V5T('-A:VYA<R`H4$5!4B!-86EL*2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S
M<VEO;B!)1"XB"FUS9W-T<B`B4V%K;F%R('-E<W-I;VYS+4E$+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@
M(DUO(@IM<V=S='(@(DWE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")-;V)I;"!E+7!O<W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B36]D97)E<F$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX."!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,R!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I
M960@1&%T92(*;7-G<W1R("+$;F1R860@9&%T=6TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@
M(DUO9&EF>2!54DPB"FUS9W-T<B`BQ&YD<F$@;.1N:R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L=7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,`HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G
M<W1R(")-;VQD879I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS
M9W-T<B`B36]N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS
M9W-T<B`B36]N9V]L:65T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X.`IM<V=I9"`B36]N=&@@86YD
M('EE87(B"FUS9W-T<B`B3>5N860@;V-H(.5R(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-R!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DWE;F%T;&EG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,R!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;W1S
M97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(DWE;F9A<V5R
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC.B!L:6(O1FEL92]#4U8N<&AP.C$Y
M-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D
M("5D+B(*;7-G<W1R(")&;&5R(&;D;'0@:&ET=&%D97,@<.4@<F%D("5D(.1N
M(&1E="!F]G)VY&YT861E("5D+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C
M8V\B"FUS9W-T<B`B36%R;V-K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T
M<B`B365S=&%D96QS(&ML87)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T
M<B`B365S=&%D96QS(&UO;&YI9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S
M='(@(DUE<W1A9&5L<R!S;VQI9W0B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HU,#D@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X
M"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B1FQY='1A(&YE9"(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,R!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")&
M;'ET=&$@=N1N<W1E<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C4Q-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3<*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@
M(DUO=F4@4FEG:'0B"FUS9W-T<B`B1FQY='1A(&CV9V5R(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C4P-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")&;'ET=&$@
M=7!P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Y.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V
M"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1FQY='1A(&YE9"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.3@*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y.0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(U(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS
M9W-T<B`B1FQY='1A('5P<"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ
M=64B"FUS9W-T<B`B36_G86UB:7%U92(*"B,Z(&-O;F9I9R]T:&5M97,O;6]Z
M:6QL82YP:'`Z-@IM<V=I9"`B36]Z:6QL82(*;7-G<W1R(")-;WII;&QA(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S
M(@IM<V=S='(@(D9L97)N:7;E<VQI<W1A(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,C<*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3@*;7-G:60@(DUU;'1I;6%P(%5+(&UA
M<"(*;7-G<W1R(")-=6QT:6UA<"!3=&]R8G)I=&%N;FEE;FMA<G1A(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(T-@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(D9L
M97)V86PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED
M(")->2!!8V-O=6YT(@IM<V=S='(@(DUI='0@:V]N=&\B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I
M;VXB"FUS9W-T<B`B36EN(&MO;G1O:6YF;W)M871I;VXB"@HC.B!S97)V:6-E
M<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS9VED(")->2!0;W)T86PB"FUS9W-T
M<B`B36EN('!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT
M,PIM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")-:6X@<&]R=&%L
M;&%Y;W5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-34*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-
M>6%N;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B
M;W1T;VTN:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R
M(").14HL($IA9R!A8V-E<'1E<F%R(&EN=&4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,#`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C4X,R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S
M='(@(DYA;6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@
M(DYA;6EB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").
M875R=2(*"B,Z(&-O;F9I9R]T:&5M97,O3F585&=R97DN<&AP.C8*;7-G:60@
M(DYE6%0B"FUS9W-T<B`B3F585"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`V"FUS9VED(").965D<R!!8W1I;VXB
M"FUS9W-T<B`B0F5H]G9E<B#E=&?D<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE
M<FQA;F1S(@IM<V=S='(@(DYE9&5R;.1N9&5R;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B3F5D97)LY&YD<VMA
M($%N=&EL;&5R;F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B
M3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5S8V%P92!B87,M55),(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@U(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE
M=V%L(%523"(*;7-G<W1R(").971S8V%P92!F]G)N>65L<V4M55),(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I
M;VX@55),(@IM<V=S='(@(DYE='-C87!E(.5T97)K86QL96QS92U54DPB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"US97)V97)N86UN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V%P92!C97)T:69I:V%T<VMO
M;6UE;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@P(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(DYE='-A<&4@8V5R=&EF
M:6MA='-T>7`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS
M9VED(").971W;W)K(@IM<V=S='(@(D[D='9E<FLB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B06QD<FEG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").
M>6$@2V%L961O;FEE;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C4P"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B
M3GD@:V%T96=O<FDB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HX-PHC
M.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY-R!L:6(O2&]R
M9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B3GET="!M961D96QA
M;F1E('1I;&P@)7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@
M(DYE=R!-;V]N(@IM<V=S='(@(DYY;>5N92(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T
M:6]N86PI(@IM<V=S='(@(DYY='0@86YVY&YD87)N86UN("AV86QF<FET="DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,`HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").>6$@
M6F5E;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM
M<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DYY='0@;/9S96YO<F0B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W(&QI8B](;W)D92]!
M=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S
M=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B3GET="!L]G-E;F]R
M9"!K;VUM97(@871T(&?E('5T("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"XB"FUS9W-T<B`B3/9S96YO<F0@;>5S=&4@=F%R82!S86UM82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED
M(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYY='0@9O9N<W1E<B`H
M7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYY:&5T97(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S
M='(@(DYY:&5T<V=R=7!P97(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(").Y'-T82(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G
M<W1R(")+;VUM86YD92`T(&9A<V5R(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-S`@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-S0*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(").
MY'-T82!I;G-TY&QL;FEN9V%R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R
M+G!H<#HQ,#,@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE
M>'0^(@IM<V=S='(@(D[D<W1A/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R
M86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M:6$B"FUS9W-T<B`B3FEG97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYA='0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3,U"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S
M='(@(DYE:B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ
M.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B1&5T(&9I;FYS(&EN9V5T
M(&MO;F9I9W5R871I;VYS9&%T82!A='0@=FES82!S:VEL;&YA9&5R(&;V<BXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P
M-0HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(N<&AP.C$Q,2!L:6(O
M5D93+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("));F=E;B!T
M:6QL9^1N9VQI9R!S=')A=&5G:2!F]G(@871T('-K87!A($E33RUI;6%G92XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*
M;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("));G1E(&5N(&)A
M=&-H;6%L;"XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C<Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C(T-2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-C<*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L
M;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@
M(D1E="!F:6YN<R!I;F=E="!B;&]C:R!PY2!D96X@8F5GY')D82!P;W-I=&EO
M;F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,"!L:6(O
M2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M26YG970@:V%L96YD97)N86UN(&;V<B!-0T%,(&%U=&5N=&ES97)I;F<@86YG
M:79E="XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@
M8VAA;F=E+B(*;7-G<W1R("));F=E;B#D;F1R:6YG+B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,34V(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI
M<R!P97)M:7-S:6]N+B(*;7-G<W1R("));F=A('5N9&5R8F5H]G)I9VAE=&5R
M(&MA;B!LY&=G87,@=&EL;"!D96X@:.1R(&)E:/9R:6=H971E;BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C0X,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,@
M;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H<#HU,#@*(SH@;&EB+TAO
M<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S
M='(@(DEN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG:79E;B!F
M]G(@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0@;&EB
M+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(DEN9V5N
M(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@1E10(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.2!L:6(O5D93
M+W-Q;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N
M9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N(&;V<B!344P@5D93+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R
M("));F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R
M(%-13"UF:6P@5D93+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@
M(DEN9V5N(&MR961I="!K=F%R+B(*"B,Z(&9R86UE=V]R:R],:6YK<R],:6YK
M<RYP:'`Z,C4V"B,Z(&9R86UE=V]R:R]296QA=&EO;G-H:7`O4F5L871I;VYS
M:&EP36%N86=E<BYP:'`Z,C4Q"FUS9VED(").;R!D97-C<FEP=&EO;B!F;W5N
M9"(*;7-G<W1R(")"97-K<FEV;FEN9R!S86MN87,N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N(@IM<V=S='(@(DEN9V5N(&UO='1A9V%R92!A;F=I
M=F5N+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W,B!L
M:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(P"FUS9VED(").;R!F:6QE('5P;&]A
M9&5D(@IM<V=S='(@(DEN9V5N(&9I;"!U<'!L861D860B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G
M<W1R("));F=A(&EK;VYE<B!H:71T861E<RXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,`IM<V=I9"`B3F\@;&]C871I;VX@
M:7,@<V5T+B(*;7-G<W1R("));F=E;B!O<G0@86YG:79E;BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B26YG96X@;W)T(&%N9VEV96XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B
M3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B26YG970@;65D9&5L86YD
M92!B:69O9V%D97,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@
M(DEN9V5T(&YA;6X@86YG:79E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D
M+B(*;7-G<W1R("));F=E;B!N=6UM97(@86YG:79E="XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE
M<R(*;7-G<W1R("));F=A(&]F]G)S:^1M9&$@=FES:&5T<V]R9"(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$@;&EB+TAO<F1E+T%U=&@O
M:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(
M5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E="!L]G-E;F]R9"!F
M]G(@2%144"UA=71E;G1I<V5R:6YG(&%N9VEV970N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@@;&EB+TAO<F1E+T%U=&@O:6UA<"YP
M:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@;/9S96YO<F0@9O9R($E-
M05`M875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-S(@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-S(*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@;/9S96YO<F0@9O9R($ME<F)E
M<F]S+6%U=&5N=&ES97)I;F<@86YG:79E="XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN
M<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-2!L:6(O
M2&]R9&4O075T:"]S87-L+G!H<#HW-PHC.B!L:6(O2&]R9&4O075T:"]L;V=I
M;BYP:'`Z.#0@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("));F=E="!L]G-E;F]R9"!F]G(@3&]G:6XM875T96YT:7-E<FEN
M9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DEN9V5T(&SV<V5N;W)D(&;V<B!005-35T0M875T96YT:7-E
M<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HX-"!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("));F=E="!L]G-E;F]R9"!F]G(@4TU"+6%U=&5N=&ES97)I;F<@86YG:79E
M="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P
M871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y3
M4TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q
M,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S
M='(@(DEN9V$@=N1N=&%N9&4@<F5G:7-T<F5R:6YG87(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C<T.`IM<V=I9"`B3F\@<75O=&$@<V5T(@IM<V=S
M='(@(DEN9V5N(&MV;W1A(&%N9VEV96XB"@HC.B!L:6(O5D93+G!H<#HW-C8*
M;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B26YG96X@:W9O=&$@86YG
M:79E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("));F=A(')E
M9VQE<B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.2!L:6(O
M1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE
M9"XB"FUS9W-T<B`B26YG96X@879G<N1N<V%R92!A;F=I=F5N+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*
M;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DEN9V$@<VED;W(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,R!L:6(O5D93+W-M8BYP:'`Z-3@W
M"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B26YG96X@<^5D86X@9FEL
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*
M;7-G<W1R("));F=E;B!T96UP;W+D<FMA=&%L;V<@=&EL;&?D;F=L:6<@9O9R
M(&-A8VAE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(Q(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*
M(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DEN9V5T(&%N
M=N1N9&%R;F%M;B!O8V@O96QL97(@;/9S96YO<F0@<VMI8VMA="XB"@HC.B!F
M<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,"!L:6(O2&]R9&4O4E!#
M+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U
M<FYE9"(*;7-G<W1R("));F=E="!G:6QT:6<@6$U,+61A=&$@<F5T=7)N97)A
M9&5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDT,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.34S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-C0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX
M,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<T(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY.#0*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S
M(@IM<V=S='(@(DEN9V$@=N1R9&5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(DEN9V5N('9E<G-I;VX@:&ET=&%D97,@:2!D96X@=7)S<')U;F=L
M:6=A(&MO;F9I9W5R871I;VYE;BX@Q71E<G-K87!A("(*(FMO;F9I9W5R871I
M;VYE;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("));F=E;B!V97)S:6]N(&AI
M='1A9&5S(&D@9&EN(&MO;F9I9W5R871I;VXN(,5T97)S:V%P82!K;VYF:6=U
M<F%T:6]N96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV,#0*;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R
M("))8VME+61E;'1A9V%R92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4V,"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS
M9VED(").;VYE(@IM<V=S='(@(DEN9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM
M<&QI8VET*2(*;7-G<W1R("));F=E;B`H86YVY&YD('5N9&5R9O9R<W3E9&0I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H
M25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO
M<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&OV87)N82(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@
M(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B3F]R<F$@:&5M:7-FY')E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-CD@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD
M<R(*;7-G<W1R(").;W)R82!-87)I86YA]F%R;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").;W)W87DB"FUS9W-T<B`B3F]R9V4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T,"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DEN=&4@969T97(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.2!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*
M;7-G<W1R("));G1E(&;V<F4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT,#@@;&EB+U9&4R]F:6QE+G!H<#HT,34*;7-G:60@(DYO="!A(&1I
M<F5C=&]R>2(*;7-G<W1R("));G1E(&5N(&MA=&%L;V<B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HU.0HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(N
M<&AP.C8W"B,Z(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]6
M1E-?25-/+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#D*(SH@
M9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HV,`HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@
M(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B16H@:6UP;&5M96YT97)A9"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X
M"FUS9VED(").;W0@<V5T(@IM<V=S='(@(D5J(&%N9VEV96XB"@HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU
M.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-2!L:6(O5D93+G!H<#HQ.3,*
M(SH@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N<&AP.C(S-"!L:6(O5D93+G!H
M<#HR-3(@;&EB+U9&4RYP:'`Z,C8Y"B,Z(&QI8B]61E,N<&AP.C(X-2!L:6(O
M5D93+G!H<#HS,#$@;&EB+U9&4RYP:'`Z,S$V(&QI8B]61E,N<&AP.C,S,PHC
M.B!L:6(O5D93+G!H<#HS-C8@;&EB+U9&4RYP:'`Z-#(V(&QI8B]61E,N<&AP
M.C4P-2!L:6(O5D93+G!H<#HU-S0*(SH@;&EB+U9&4RYP:'`Z-3DQ(&QI8B]6
M1E,N<&AP.C8V.2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T-0HC
M.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$V,"!L:6(O2&]R9&4O
M4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP.C$X.2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C(S
M-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B4W3V9',@:6YT92XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#4X"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(D%N=&5C:VYI;F=A<B(*
M"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DEN9V5N=&EN9R!A
M='0@=FES82P@9^4@=&EL;&)A:V$N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`IM<V=I9"`B3F]T:6-E(@IM<V=S='(@
M(D]"4R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0R-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B
M3F]V96UB97(B"FUS9W-T<B`B;F]V96UB97(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#0V(&QI8B](;W)D92]&;W)M+G!H<#HQ,#4P"FUS9VED
M(").=6UB97(B"FUS9W-T<B`B3G5M;65R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R.0IM<V=I9"`B
M3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B06YT86P@=&5C:V5N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M-#4@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S,*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E
M<B!O9B!C;VQU;6YS(@IM<V=S='(@(D%N=&%L(&MO;'5M;F5R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-S$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R
M;W=S(@IM<V=S='(@(D%N=&%L(')A9&5R(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B3G5M;65R(&EN=&4@<W!E8VEF:6-E<F%D92!F]G(@871T('5P<&1A
M=&5R82!I(&1I<W1R:6)U=&EO;G-L:7-T86XN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT.#,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-C,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*
M;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HX-#8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5K="(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E
M871O<B(*;7-G<W1R(")/8FIE:W1S:V%P87)E(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$P-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$P.`IM<V=I
M9"`B3V-T86PB"FUS9W-T<B`B3VMT86PB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@V"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,C,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B;VMT;V)E<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F
M:6QT97(B"FUS9W-T<B`B1FEL=&5R(&;V<B!O9O9R<VOD;61H971E<B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*
M;7-G<W1R(")+;VYT;W(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB"FUS9W-T<B`B1V%M;6%L="!O8V@@;GET="!L]G-E;F]R9"!F
MY7(@:6YT92!V87)A('-A;6UA+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(D=A;6UA
M;'0@;/9S96YO<F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T
M<B`B1V%M;6%L="!L]G-E;F]R9"#D<B!F96QA:W1I9W0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,0HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")/;6%N(@IM<V=S='(@(D]M86XB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,R!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(D1E;&%D92!M87!P87(@<W3V
M9',@96YB87)T(&%V($E-05`M<V5R=G)A<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS
M9W-T<B`B16YB87)T(&]F]G)S:^1M9&$@=FES:&5T<V]R9"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DW,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+B(*;7-G<W1R(")%;F1A<W0@96X@92UP;W-T861R97-S('1I;&SE
M=&5N+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@HB16YD87-T(.1G87)E(&5L;&5R('-Y<W1E
M;6%D;6EN:7-T<F%T]G(@:V%N(.1N9')A(.1G87)E(&5L;&5R(&)E:/9R:6=H
M971E<B!PY2`B"B)E;B!U=&1E;&YI;F<B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,`IM<V=I9"`B3W!E;B!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BUG!P;F$@:2!N>71T(&;V;G-T97(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-2!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"UF96PZ($1E="!G:6-K(&EN=&4@
M871T(&5X=')A:&5R82!D871A(&9RY6X@<VEG;F5R860@4R]-24U%+61E;"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`BUG!P;F$@;.1N:R!I(&YY='0@9O9N<W1E<B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E
M;2(*;7-G<W1R(")/<&5R871I=G-Y<W1E;2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`P"FUS9VED(")/<'1I;VYA
M;"!087)T:6-I<&%N="(*;7-G<W1R("))8VME(&]B;&EG871O<FES:V$@9&5L
M=&%G87)E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUE;G4N<&AP.C$U,"!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM
M<V=S='(@(DEN<W3D;&QN:6YG87(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z
M,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B26YS=.1L;&YI;F=A<B!F
M]G(@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B4V]R=&5R860@
M;&ES=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI
M<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-A=&EO;B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38X(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@
M(D]R9V%N:7-A=&EO;G-E;FAE="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI<V5R
M82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")5<G-P<G5N9VQI9R!A
M<'!L:6MA=&EO;G-M86QL(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.B(*;7-G<W1R(")5<G-P<G5N9VQI9V$@;6%L;&%R(&D@)7,Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3D*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-R!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/
M=&AE<B(*;7-G<W1R(")!;FYA;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%N9')A
M(&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("+$9V%R8F5H
M]G)I9VAE=&5R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y
M(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")004TM075T96YT
M:7-E<FEN9R#D<B!I;G1E('1I;&QGY&YG;&EG+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-2!L:6(O3F5T+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD
M(@IM<V=S='(@(E!%05(Z.DUA:6PM:V]P<&QI;F<B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C4S(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R
M(")01U`@1&EG:71A;"!3:6=N871U<F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,CDY(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S
M,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@16YC
M<GEP=&5D($1A=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S4Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!U8FQI:R!01U`M;GEC:V5L(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,S,R!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S
M='(@(E!(4"UK;V0B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@
M(E!(4"!3:&5L;"(*;7-G<W1R(")02%`M<VMA;"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!2
M86EN(@IM<V=S='(@(DSD='0@9O9R;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4F%I
M;B(*;7-G<W1R(")&]G)M:61D86=S<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3:&]W97)S(@IM
M<V=S='(@(D5F=&5R;6ED9&%G<W-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(@IM<V=S
M='(@(D5F=&5R;6ED9&%G<W-N]B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B169T97)M:61D86=S<VMU<F%R(&UE9"!S;O8B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4W5N
M(@IM<V=S='(@(D5F=&5R;6ED9&%G<W-O;"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!4+5-T;W)M<R(*
M;7-G<W1R("+%<VMS:W5R87(@<.4@969T97)M:61D86=E;B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I
M<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8+71I;&SD9V<@<V%K;F%S(@H*(SH@
M;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?
M2%`M<VMA;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B571F>6QL
M;F%D.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A
M:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DT"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R(")0
M86QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I;F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#4*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82U.>6$@1W5I
M;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S<@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")0
M87)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(D1E;'9I<R!M
M;VQN:6=T(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R,B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,W"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DY(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3$*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DSV<V5N;W)D(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C
M:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B3/9S96YO<F0@Y&YD<F%D
M97,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O
M<F0@:6YC;W)R96-T(@IM<V=S='(@(DSV<V5N;W)D(&9E;&%K=&EG="(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(@;&EB+TAO<F1E
M+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DSV<V5N;W)D
M(&MRY'9S(&;V<B!2041)55,@875T96YT:7-E<FEN9RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#4S(&QI8B](;W)D92]&;W)M+G!H<#HR,#4W
M"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("),
M]G-E;F]R9"!M960@8F5K<N1F=&5L<V4B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("),]G-E
M;F]R9#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I
M9"`B4&%S<W=O<F0Z("(*;7-G<W1R("),]G-E;F]R9#H@(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P,S@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(DSV<V5N;W)D(&WE<W1E('9A<F$@;&EK82XB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B2VQI
M<W1R82!I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@
M(DML:7-T<F$@:6X@9G+E;B!U<FML:7!P<VAA;G1E<F%R96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0
M871H(@IM<V=S='(@(E/V:W;D9R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(E;D
M;G1A;F1E(')E9VES=')E<FEN9V%R.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(DWD;FYI<VMO<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS
M9VED(")097)C96YT(@IM<V=S='(@(E!R;V-E;G0B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.C8*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")5=&;V<B!U;F1E
M<FCE;&QS9G5N:W1I;VYE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\B"FUS9W-T<B`B571F]G(@=6YD97)HY6QL<V%K=&EV:71E=&5R('9I
M9"!I;FQO9V=N:6YG/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,34V(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M
M:7-S:6]N(@IM<V=S='(@(D)E:/9R:6=H970B"@HC.B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@
M7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")"96CV<FEG:&5T("<E<R<@
M<F%D97)A9&5S(&EN=&4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HU.#8@;&EB+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`BQ71K;VUS="!N96MA9"(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,38T"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,38Q(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G
M<W1R(")B96CV<FEG:&5T97(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS
M+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED
M(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")"96CV<FEG
M:&5T<V%D;6EN:7-T<F%T:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")097)S
M;VYL:6<@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM
M<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G
M:60@(E!E=',B"FUS9W-T<B`B2'5S9&IU<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP<&EN97)N82(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM
M<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@
M(E!I>&5L<R(*;7-G<W1R(")0:7AL87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B2VQI8VCI97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS
M9W-T<B`B5F%R(&=O9"!K;&EC:V$@:2!E;B!C96QL(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED
M(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z(@IM<V=S='(@(D)E:W+D9G1A(&%T="!D=2!V:6QL(')A9&5R
M82!V86QD('!O<W0_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@
M(D)E:W+D9G1A(&%T="!D=2!V:6QL(')A9&5R82!A:W1U96QL="!E;&5M96YT
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(U-C8*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N(@IM<V=S='(@(E9A<B!G;V0@86YG92!MY6YA9"!O8V@@Y7(N
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T
M96=O<GDZ(@IM<V=S='(@(E9A<B!G;V0@86YG92!N86UN(&;V<B!K871E9V]R
M:6XZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@
M25`@861D<F5S<RXB"FUS9W-T<B`B5F%R(&=O9"!A;F=E(&=O9&OD;F0@25`M
M861R97-S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(V-#0*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N(@IM<V=S='(@(E9A<B!G;V0@86YG92!E='0@9VEL=&EG="!D871U;3L@
M:V]N=')O;&QE<F$@86YT86QE="!D86=A<B!I(&WE;F%D96XN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T
M<B`B5F%R(&=O9"!A;F=E(&5N(&=O9&OD;F0@=&ED+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B5F%R(&=O9"!S
M=6UM97)A(&1I='0@<')O8FQE;2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(D%N9V4@9&ET="!A;G;D;F1A<FYA;6X@;V-H(&SV<V5N;W)D+B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ
M,@IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S
M>7-T96TN(@IM<V=S='(@(B(*(E9A<B!G;V0@;.1S(&EG96YO;2!F]FQJ86YD
M92!T97AT+B!$=2!-Q5-412!S86UT>6-K82!M960@=FEL;&MO<F5N(&;V<B!A
M='0@(@HB86YVY&YD82!S>7-T96UE="XB"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E
M('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E9A<B!G;V0@;.1S(&EG96YO
M;2!F]FQJ86YD92!T97AT+B!$=2!-Q5-412!S86UT>6-K82!M960@=FEL;&MO
M<F5N(&;V<B!A='0@(@HB86YVY&YD82!S>7-T96UE="XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T,`IM<V=I9"`B
M(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A
M;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*(FUE;G4@8F5L
M;W<N(@IM<V=S='(@(B(*(DMO;G1R;VQL97)A(&;V;&IA;F1E(&EN9F]R;6%T
M:6]N(&]C:"!VY&QJ('-E9&%N(&5N(&AA;F1L:6YG(&D@;65N>6Y<;B(*(FYE
M9&%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#,U"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M
M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R(")6Y&QJ(&5N(&AA;F1L:6YG(&9R
MY6X@;65N>6X@;F5D86XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S`*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B06YG92!N>71T(&MA=&5G;W)I;F%M
M;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L96XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(E!O;&ET:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")5;F1E<G/V:VYI;F=A<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,PHC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G
M86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4B"FUS9W-T<B`B4&]S:71I;VYE<FEN9R!A=B!B:6QD96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")0;W-I=&EO;F5R
M:6YG(&%V('1A8F5L;&5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3$@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I
M9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I
M(@IM<V=S='(@(E-K<FEV('1I;&P@9&5N(&CD<B!M87!P96X@*&5J('1V:6YG
M870@878@24U!4"DB"@HC.B!C;VYF:6<O=&AE;65S+W!O<W1N=6ME+G!H<#HV
M"FUS9VED(")0;W-T;G5K92(*;7-G<W1R(")0;W-T;G5K92(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L
M('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@(@IM<V=S='(@(DYE9&5R8O9R9"!D92!S96YA<W1E("5S('1I
M;6UA<FYA.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W
M"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(D-H
M86YS('1I;&P\8G(O/FYE9&5R8O9R9"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]L9&%P+G!H<#HY."!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z.3@*
M;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K
M;F%S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS
M,R!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@3V)L:6=A=&]R:7-K="!S97-S
M:6]N<W1I;&SD9V<@:&ET=&%D97,@:6YT92XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B5')Y8VLB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@870@
M<V5A(&QE=F5L.B`B"FUS9W-T<B`B3'5F='1R>6-K('9I9"!H879E=#H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I9"`B4')E
M<W-U<F4Z("(*;7-G<W1R("),=69T=')Y8VLZ("(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B1O9R:&%N9'-V:7-N:6YG(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS
M9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B1O9R:&%N9'-G<F%N<VMA(&)I;&0@:2!N>71T(&;V;G-T97(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,"!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V-`HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO
M=7,@;W!T:6]N<R(*;7-G<W1R(")&]G)E9^5E;F1E(&EN<W3D;&QN:6YG87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q
M"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")3:W)I=B!U="!D;VMU
M;65N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y
M(@IM<V=S='(@(E!R:79A=&$@;GEC:V5L(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$V.2!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS
M9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96TB"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4')O8FQE;6)E<VMR:79N:6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5K
M="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@T(&QI8B](;W)D92]&;W)M+G!H<#HR,3$U"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3DR(&QI8B](;W)D92]&;W)M+G!H<#HS,C@P"FUS9VED(")0
M<F]M<'0@=&5X="(*;7-G<W1R(")497AT(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R
M,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")0=6)L:6L@;GEC:V5L(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG
M;W)I=&AM(@IM<V=S='(@(E!U8FQI:R!N>6-K96QA;&=O<FET;2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS
M9W-T<B`B4'5B;&EK(&YY8VME;&EN9F]R;6%T:6]N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C,P(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B1F5L('9I9"!G96YE<F5R
M:6YG(&%V('!U8FQI:W0O<')I=F%T(&YY8VME;'!A<BXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0
M=7)G92!M97-S86=E<R(*;7-G<W1R(")296YS82!M961D96QA;F1E;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-@HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B46%T87(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(D9R
MY6=A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T
M82(*;7-G<W1R(")+=F]T82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T"B,L
M('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM
M<V=S='(@(E!U8FQI:R!24T$M;GEC:V5L("@E9"!B:71A<BDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C8X"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B16YS:VEL="!V
M86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-`IM<V=I9"`B4F%I;B(*;7-G<W1R(")296=N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@16%R;'DB
M"FUS9W-T<B`B5&ED:6=T(')E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@
M(E-E;G0@<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0W"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")296=N<VMU
M<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#@*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B4F5G;B!O8V@@<V[V
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*
M;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")296=N('1I;&P@<V[V(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T
M=6YE(@IM<V=S='(@(E-L=6UP;>1S<VEG="!V:7-H971S;W)D(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")&]G)HY6QL86YD92(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T(&QI8B](;W)D92]097)M
M<RYP:'`Z,S(T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDQ('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DSD<R(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W(&QI8B](
M;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS
M9W-T<B`B3.1S(&UE9&1E;&%N9&5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(E/D:V5R="!A='0@9'4@=FEL;"!R861E<F$@)7,_(%)A9&5R:6YG
M96X@:V%N(&EN=&4@Y6YG<F%S+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)3Y&ME<G0@871T(&1U('9I;&P@
M<F%D97)A(&%N=N1N9&%R9&%T82!F]G(@)7,_(%)A9&5R:6YG96X@:V%N(&EN
M=&4@Y6YG<F%S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(D?V<B!O;2!D:6X@<V5N87-T92!I;FUA=&YI;F<B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")5<'!D871E<F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SHB"FUS9W-T<B`B57!P9&%T97)A(&1Y;F%M:7-K82!M
M96YY96QE;65N=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS
M9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")5<'!D871E<F$@
M<&]R=&%L=GDZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-2!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C$W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,Y"FUS
M9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R-#D@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,S4*;7-G:60@
M(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(E9I<V$@9O9R:.5L;&%N
M9&5N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S
M='(@(DQA9&1A(&]M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G
M:60@(E)E;6%R:W,B"FUS9W-T<B`B2V]M;65N=&%R97(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0W-@IM<V=I
M9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B2V]M(&EHY6<@:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96XN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E
M<G9E<G,B"FUS9W-T<B`B1FKD<G)S97)V<F%R(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")482!B;W)T(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`B5&$@8F]R="!B;&]C:R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,S(*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M
M;B(*;7-G<W1R(")482!B;W)T(&MO;'5M;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M
M871T:6YG(@IM<V=S='(@(E1A(&)O<G0@9F]R;6%T97)I;F<B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8U.`IM<V=I
M9"`B4F5M;W9E(&9R;VT@;7D@8V%L96YD87(B"FUS9W-T<B`B5&$@8F]R="!F
M<N5N(&UI;B!K86QE;F1E<B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")482!B;W)T('!A
M<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V
M92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R(")2861E<F$@<W!A<F%T('-K<FEP="!F<N5N('-E<G9E
M<FYS('1E;7!O<N1R:V%T86QO9RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T
M:&4B"FUS9W-T<B`B5&$@8F]R="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")2861E<F$@9&5N
M;F$@;F]D(&9RY6X@9&]K=6UE;G1E="(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@
M(E1A(&)O<G0@86YVY&YD87)E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R(")482!B;W)T(&%N=N1N9&%R93H@)7,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Y-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(X,`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T
M.0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B4W9A<B!S:VEC:V%T+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-#4Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-#8X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#<X"FUS9VED(")297!L>2!W:71H($YO="!3=7!P;W)T960@365S
M<V%G92(*;7-G<W1R(")3=F%R82!A='0@8F5GY')A;B!I;G1E('-T]F1S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M-C8*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N
M=&AS+B(*;7-G<W1R(")3=F%R82!M960@:6YF;W)M871I;VX@;VT@;&5D:6<O
M=7!P=&%G96X@9O9R(&MO;6UA;F1E('1VY2!MY6YA9&5R+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#8U"FUS9VED
M(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(E-V87)A(&UE9"!D96X@8F5GY')D82!L961I9R]U<'!T86=E
M;BUI;F9O<FUA=&EO;F5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,3@Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<&QY.B`E<R(*;7-G<W1R(")3=F%R.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,3,X(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ
M,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R
M;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(D)E9^1R86X@:W5N9&4@:6YT92!B
M97-V87)A<RX@4F5T=7)N97)A9"!F96QK;V0Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B1&5N(&5F=&5R9G+E9V%D
M92!T:N1N<W1E;B!K=6YD92!I;G1E(&AI='1A<RXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C0Y,@HC.B!L:6(O2&]R9&4N<&AP.C$W-B!L:6(O2&]R9&4N<&AP.C4Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%<F9O9')A9"`G
M)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R871I;VYE;B!A=B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S(S(&QI8B]61E,O<W%L+G!H<#HV-S@@;&EB+U9&4R]F='`N
M<&AP.C@V,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D5R9F]D<F%D("<E<R<@Y'(@
M:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)E<FEN9V5N(&%V(%9&4RXB"@HC.B!F
M<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$@;&EB+TAO<F1E+U5T:6PN<&AP
M.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%<F9O9')A
M9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R97)I;F=E;BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4@;&EB+TAO
M<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE
M;&0B"FUS9W-T<B`B3V)L:6=A=&]R:7-K='0@9N1L="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3DR"FUS9VED(")2
M97%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R(")/8FQI9V%T;W)I<VL@9&5L
M=&%G87)E(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N
M<&AP.C,R,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S0S"B,Z(&QI8B](;W)D92]&
M;W)M+U)E;F1E<F5R+G!H<#HS,C`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,`HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@
M(E)E<V5T(@IM<V=S='(@(L5T97)S=.1L;"(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R
M("+%=&5R<W3D;&P@;/9S96YO<F0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R
M("+%=&5R<W3D;&P@;/9S96YO<F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`BQ7-T97)T
MY&QL('-E;F%S=&4@9G+E9V%N(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q
M(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*
M;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT870B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(L5T97)V
MY&YD('1I;&P@:6YS=.1L;&YI;F=A<B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G
M<W1R(")!;F=E(&YY='0@;/9S96YO<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E)E=6YI;VXB"FUS9W-T<B`B4NEU;FEO;B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B
M4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`BQ71E<G-TY&QL(&MO;F9I
M9W5R871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED
M(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B26YS=.1L;&YI
M;F=A<B!F]G(@4FEC:"!497AT($5D:71O<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")'Y71O<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B2/9G97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(Q(&QI8B](;W)D92]&;W)M+G!H<#HS,3`W"FUS
M9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B2/9G97)R=6)R:6LB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3`S"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B2/9G97)VY')D
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")285]D:6YS=.1L;&YI;F=A<BXN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S0*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6WD
M;FEE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,#@*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")2;W1E<F$@,3@P(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED(")2
M;W1A=&4@3&5F="(*;7-G<W1R(")2;W1E<F$@=N1N<W1E<B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,3$*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E
M(%)I9VAT(@IM<V=S='(@(E)O=&5R82!H]F=E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O
M=R!0<F]P97)T:65S(@IM<V=S='(@(E)A9&EN<W3D;&QN:6YG87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P
M"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")2861I;G-TY&QL;FEN
M9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E)A9&5R.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G
M:60@(E)U;&5S(@IM<V=S='(@(DQI;FIE<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS
M9W-T<B`B3&EN:F5R('9I<V%S(&UE;&QA;B!A;&QA(')A9&5R(&]C:"!K;VQU
M;6YE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M8V]L=6UN<R!O;FQY(@IM<V=S='(@(DQI;FIE<B!V:7-A<R!E;F)A<G0@;65L
M;&%N(&MO;'5M;F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B3&EN:F5R('9I<V%S(&5N8F%R
M="!M96QL86X@<F%D97(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS
M9VED(")2=6XB"FUS9W-T<B`B2_9R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DY"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4GES<VQA;F0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#`*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=V%N9&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-2!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12!S:6=N871U<B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4B"FUS9W-T<B`B4R]-24U%+6MR>7!T97)A="!M961D96QA;F1E(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,2!L:6(O2&]R9&4O075T
M:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,+6%U=&5N=&ES97)I;F<@Y'(@
M:6YT92!T:6QL9^1N9VQI9RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R!M961D
M96QA;F1E;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,
M(%-H96QL(@IM<V=S='(@(E-13"US:V%L(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W.`IM<V=I9"`B
M4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")344PM
M<V5K=F5N<R!F]G(@=7!P<VQA9R!A=B!VY')D96XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-0HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B
M3%E#2T%4(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL
M(@IM<V=S='(@(E-?44PM<VMA;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(DSV(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%I
M;G0@2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD
M($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S(&]C:"!.979I<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E
M;&]N(@IM<V=S='(@(E-A:6YT+5!I97)R92!O8V@@36EQ=65L;VXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@;V-H($=R96YA9&EN97)N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*
M;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")386UM82!R86T@
M*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(U,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B
M4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T
M<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@
M86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&]C:"!0<FEN8VEP92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B
M"FUS9W-T<B`B4V%T=&5L:71L979E<F%N=/9R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U9&EA<F%B:65N(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM
M<V=S='(@(E-P87)A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G
M<W1R(")3<&%R82`G)7,G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")3
M<&%R82`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@
M(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")3<&%R82!I;G-TY&QL;FEN9V%R(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"B)3<&%R82!G96YE<F5R860@:V]N9FEG=7)A=&EO;B!S;VT@4$A0+7-K<FEP
M="!T:6QL(&1I;B!S97)V97)S("!T96UP+6MA=&%L;V<N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4W!A<F%D92!K;VYF:6=U
M<F%T:6]N(&;V<B`E<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")3<&%R861E('5P<&=R861E<FEN
M9W-S8W)I<'0@=&EL;#H@)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*
M;7-G<W1R(")3<')I9&1A(.5S:W-K=7)A<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")6971E;G-K87`B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(E/V:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G
M:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E/V:VUO=&]R97(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S(&QI8B](;W)D92]&;W)M+G!H
M<#HR.34Y"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5N1L:B!F:6QE
M<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")6Y&QJ(&5T="!D871U;2(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE
M8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5N1L:B!G<G5P<"!A='0@;.1G
M9V$@=&EL;"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G
M:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")6Y&QJ(&YY(.1G87)E
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")3
M96QE8W0@82!S97)V97(B"FUS9W-T<B`B5N1L:B!S97)V97(B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E
M<B!T;R!A9&0B"FUS9W-T<B`B5N1L:B!A;G;D;F1A<F4@871T(&SD9V=A('1I
M;&PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C4R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*
M;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5N1L:B!A;&QA(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C8T-PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S
M='(@(E;D;&H@9&%T=6UK;VUP;VYE;G1E<BXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#0V"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE
M8W0B"FUS9W-T<B`B5N1L:B!E='0@;V)J96MT(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,PHC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@;F]N92(*
M;7-G<W1R(")6Y&QJ(&EN9V5N(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B
M"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB
M06YG92!D92!T96-K96X@9'4@8F5H]G9E<B!I(')U=&]R;F$@;F5D86XN($1U
M(&MA;B!S961A;B!K;W!I97)A(&]C:"!K;&ES=')A("(*(FEN(&1E;2!I('1E
M>'1A<G5T86XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E;D;&H@
M879G<N1N<V%R92!F]G(@9&%T=6TZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S
M='(@(E;D;&H@9&%T=6UF;W)M870Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E;D;&H@:61E;G1I=&5T
M(&1U('9I;&P@Y&YD<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@
M(E;D;&H@879G<N1N<V%R92!F]G(@=&ED.B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*
M;7-G<W1R(")6Y&QJ('1I9'-F;W)M870Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N(@IM<V=S='(@(E;D;&H@=';E(&UA=&-H86YD92!FY&QT.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92XB"FUS9W-T<B`B5N1L:B!D:71T(&;D<F=S8VAE;6$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")!;F=E(&1I='0@9O9R
M=F%L9&$@<W!RY6LZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HV-3,*;7-G:60@(E-E;F0@3&%T97-T($EN9F]R;6%T
M:6]N(@IM<V=S='(@(E-K:6-K82!S96YA<W1E(&EN9F]R;6%T:6]N96XB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N
M9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")3:VEC:V$@<')O8FQE;7)A<'!O
M<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`Q,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T
M,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4VMI8VMA(%--4R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@(E-E;G-O<CH@(@IM<V=S
M='(@(E-E;G-O<CH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#(R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B<V5P=&5M8F5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE
M9W)O(@IM<V=S='(@(E-E<F)I96X@;V-H($UO;G1E;F5G<F\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,2!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R
M(")397)I96YU;6UE<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(E-E<G9E<FEN<W3D;&QN:6YG87(@9F5L86MT:6=A(&5L
M;&5R(&EN86MT:78@<V5R=F5R+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")397-S:6]N<V%D;6EN
M:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDR"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@
M(E-E<W-I;VYS+4E$(&AA<B!GY71T('5T+B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S<VEO;F5R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,Q.`IM<V=I9"`B4V5T(@IM<V=S='(@(E/D='0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO
M=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I
M="XB"FUS9W-T<B`B(@HB2V]N9FEG=7)E<F$@86QT97)N871I=B!S;VT@;?9J
M;&EG9_9R(.5T97)S=.1L;&YI;F<@878@8F]R=&=L]FUT(&SV<V5N;W)D+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+B(*;7-G<W1R(")+;VYF:6=U<F5R82!F:N1R<G-E<G9R87(@
M<V]M(&1U('9I;&P@:V]M;6$@Y70@9G+E;B!D:6X@<&]R=&%L+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G
M<W1R(")!;F=E(&1I='0@9O9R=F%L9&$@<W!RY6LL('1I9'-Z;VX@8V]H(&1A
M='5M:6YS=.1L;&YI;F=A<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I
M<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4^1T="!D:71T(&EN:71I86QA
M(&%P<&QI:V%T:6]N+"!FY')G<V-H96UA+"!S:61U<'!D871E<FEN9R!O8V@@
M86YD<F$@(@HB=FES;FEN9W-I;G-TY&QL;FEN9V%R+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(E-E='5P
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G
M:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B
M2V]N9FEG=7)A=&EO;G-U<'!G<F%D97)I;F=S<VMR:7!T(&9I;FYS('1I;&QG
MY&YG;&EG82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*
M;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@(@IM<V=S='(@(D1E="!F:6YN<R!F;&5R82!O<G1E<B!M960@
M<&%R86UE=&5R;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`B4V5Y8VAE;&QE<FYA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B2&%N9&5L(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H
M;W)T(%-U;6UA<GDB"FUS9W-T<B`B2V]R="!S=6UM97)I;F<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B4VMA;&P@
M9V5N=N1G<W1A;F=E;G1E<B!D969I;F5R87,@9O9R(&1E(&9L97-T82!LY&YK
M87(_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HS,C,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B
M5FES82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*
M(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HB5FES82!S:VEL;&YA9&5R(&UE;&QA;B!D96X@86MT=65L;&$@;V-H
M(&1E;B!N>6QI9V5N('-K87!A9&4@:V]N9FEG=7)A=&EO;F5N+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B5FES82!S96YA<W1E
M(&EN;&]G9VYI;F=S=&ED('9I9"!I;FQO9V=N:6YG/R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-CD*
M;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B
M5FES82!I;G-TY&QL;FEN9R!F]G(@871T(&)E:.5L;&$@;W)I9VEN86PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S(&QI8B](;W)D92]&;W)M
M+G!H<#HR-SDY"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")6:7-A('!A
M;&5T="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5FES82`G
M=&%B96QL86MT:79I=&5T97(G(&D@;65N>6X_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")6:7-A(&UE;GD@9O9R("5S
M('1I;&P@=N1N<W1E<C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%B96QL8V5L;&EN
M<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A8F5L;&EN<W3D;&QN:6YG87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R(")486)E;&QI;G-TY&QL;FEN9V%R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R
M"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R(")6:7-A(&1I86QO9W)U=&$@9O9R(&)I;&1E9V5N<VMA<&5R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3<V-PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B5FES82!U<'!L
M861D;FEN9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4Q"FUS9VED(")3:&]W97)S(@IM<V=S='(@(E-K=7)A<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3
M:&]W97)S($5A<FQY(@IM<V=S='(@(E1I9&EG82!S:W5R87(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO
M=V5R<R!,871E(@IM<V=S='(@(E-E;F$@<VMU<F%R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@
M:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(E-K=7)A<B!I(&[D<FAE=&5N(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C0X,`HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@
M(D;V<FUI;G-K82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HQ,30Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<W-"!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z.3(R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.CDX-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z,3$Q-B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ
M,30Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B"FUS9W-T<B`B2W)Y;7`@96QL97(@9FQY='1A(&)O<G0@;N1R;&EG
M9V%N9&4@8FQO8VL@9O9R<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R
M82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U(&QI8B](;W)D92]!=71H+U-I9VYU
M<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(E)E9VES=')E<F$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM
M<V=S='(@(E-I9VYA='5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,3$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G
M:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B4VEG;F%T=7)A;&=O
M<FET;2(*"B,Z(&-O;F9I9R]T:&5M97,O<VEM<&QE>"YP:'`Z-@IM<V=I9"`B
M4VEM<&QE>"(*;7-G<W1R(")3:6UP;&5X(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W)E(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`P(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C$Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,C0Q(&QI8B](;W)D92]&;W)M+G!H<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3$V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`Y(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<R(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T
M"FUS9VED(")3:7IE(@IM<V=S='(@(E-T;W)L96LB"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.CD*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@
M36%I;G1E;F%N8V4B"FUS9W-T<B`B079B<GET('5N9&5R:.5L;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,`HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=F%K:65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]V96YI
M96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-0IM<V=I9"`B4VYO=R(*;7-G<W1R(")3;O8B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97(B
M"FUS9W-T<B`B4V[V<VMU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M4V[V<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")4
M:61I9V$@<V[V<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S
M='(@(E-E;F$@<V[V<VMU<F%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")3;O9D:G5P.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B36]T<W9A<F%N9&4@<V[V(&D@=F%T
M=&5N.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*
M;7-G<W1R(")386QO;6]N]F%R;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O
M;6%L:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")3Y6YG97(@
M;V-H(&1I:W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3(*;7-G:60@(E-O<G0@;W)D97(@<V5L
M96-T:6]N(@IM<V=S='(@(E-O<G1E<FEN9W-I;W)D;FEN9W-V86PB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3@Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.2!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(T-R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,38V
M"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C
M92!A9&1R97-S(@IM<V=S='(@(FOD;&QA9')E<W,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3>61A9G)I:V$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O
M=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM
M<V=S='(@(E/V9')A($=E;W)G:6$@;V-H(%-Y<W-A;F1W:6-H]F%R;F$B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R
M"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(E/D9')A(&AE
M;6ES9N1R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL
M<R(*;7-G<W1R(")5=')Y;6UE(&UE;&QA;B!I;G1I;&QI9V=A;F1E(&-E;&QE
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I
M;B!C96QL(@IM<V=S='(@(E5T<GEM;64@;65L;&%N(&EN;F5HY6QL(&]C:"!K
M86YT96X@:2!C96QL96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M,34@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A8V5R(@IM<V=S
M='(@(DUE;&QA;G)U;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")-
M96QL86YR=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM
M<V=S='(@(DUE;&QA;G)U;2!O8V@@=71JY&UN:6YG(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(E-P86EN(@IM<V=S='(@(E-P86YI96XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA
M<F%C=&5R($EN<'5T(@IM<V=S='(@(DEN;6%T;FEN9R!A=B!S<&5C:65L;&$@
M=&5C:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")$96QA
M(&-E;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B1&5L
M82!K;VQU;6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B1&5L
M82!R860B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P
M;W)T<R(*;7-G<W1R(")3<&]R=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I
M($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@
M5')E:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#0S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-30X"FUS9VED(")3=&%R="(*;7-G<W1R(")3=&%R="(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@P.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R
M(")3=&%R=.5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T
M871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(E-T870@96QL97(@<F5G:6]N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M.#,*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G
M:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$U(&QI8B](;W)D92]&;W)M+G!H<#HR.#`Q"FUS9VED
M(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("),86=R:6YG<V9O<FUA="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*
M;7-G<W1R(")'871U861R97-S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G
M<W1R(")'96YO;7-T<G5K96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@
M;&ES="(*;7-G<W1R(")3='+D;F=L:7-T82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E1A(&)O
M<G0@9&]MY&X@9G+E;B!A9')E<W-E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#
M4U-=(@IM<V=S='(@(E-T:6P@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")3
M]B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B2V%N(&EN=&4@:&ET=&$@=6YD97)K871A;&]G("<E<R<N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C
M="(*;7-G<W1R("+$<F5N9&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,S8@;&EB+TAO<F1E+T9O<FTO4F5N9&5R
M97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E-K:6-K82(*"B,Z
M('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@
M87!P<F]V960N(@IM<V=S='(@(B(*(D1I;B!B96?D<F%N(&%T="!LY&=G82!T
M:6QL(%PB)7-<(B!T:6QL('-Y<W1E;65T(&AA<B!S:VEC:V%T<RX@1'4@:V%N
M(&EN=&4@(@HB;&]G9V$@:6X@:6YN86X@9&EN(&)E9^1R86X@:&%R(&%C8V5P
M=&5R871S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(").961SY&YK="(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B3'EC:V%T(@H*(SH@861M:6XO
M=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(&QA
M9&5S('1I;&P@:2!S>7-T96UE="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")2
M861E<F%D92!I;F9O<FUA=&EO;B!O;2!A;G;D;F1A<F4@)R5S)RXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E
M<UPB+B(*;7-G<W1R("(G)7,G(')A9&5R861E<RXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E
M;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!T
M;V=S(&)O<G0@9G+E;B!S>7-T96UE="XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)+
M;VYF:6=U<F%T:6]N96X@:&%R(.5T97)S=.1L;'1S+B!,861D82!O;2!S:61A
M;B!F]G(@871T('-E(&;V<N1N9')I;F=A<BXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@
M(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B4W!A<F%D92!B86-K=7!K;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R(")3<&%R861E(&)A8VMU<&MO;F9I9W5R871I;VX@)7,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G('5P
M<&1A=&5R861E<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B4VMR978@)7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#0*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-3@*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")386UM86YS=.1L;&YI;F<B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E
M(@IM<V=S='(@(E-O;'5P<&?E;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4V]L;F5D9^5N9R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED
M(")3=6YN>2(*;7-G<W1R(")3;VQI9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(E-O;'5P
M<&?E;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@
M(E-O;'5P<&?E;F<O;F5D9^5N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")3;VQU<'!G
MY6YG.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS
M9VED(")3=6YS970B"FUS9W-T<B`B4V]L;F5D9^5N9R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S
M='(@(E-O;&YE9&?E;F<Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@
M(E5P<&CV:F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"FUS
M9VED(")3=7!P;W)T(@IM<V=S='(@(E-U<'!O<G0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*
M;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86UE(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B169T97)N
M86UN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(E-V86QB87)D(&]C:"!*86X@36%Y96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6QA;F0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")3=F5R:6=E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-C:'=E:7HB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN
M8R!L;V<@9&5L971E9"(*;7-G<W1R(")3>6MR;VYI<V5R:6YG<VQO9V<@<F%D
M97)A9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y
M;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z.3<@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z.3<*
M;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
M4WEN=&%X9F5L(&D@<_9K:W)I=&5R:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-Y<FEE;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4
M+5-T;W)M(@IM<V=S='(@(L5S:W-K=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN
M9'DB"FUS9W-T<B`BQ7-K<VMU<F%R(&]C:"!B;.5S:6=T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O
M<FUS(@IM<V=S='(@(L5S:W-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M<R!%87)L>2(*
M;7-G<W1R(")4:61I9V$@Y7-K<VMU<F%R(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]T<W8N<&AP.C$V-B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V-@IM
M<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6+69I;"(*"B,Z(&9R86UE=V]R
M:R]522]522]486)L92YP:'`Z,3,T(&QI8B](;W)D92]522]486)L92YP:'`Z
M,3,T"FUS9VED(")486)L92(*;7-G<W1R(")486)E;&PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED
M(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E1A8F5L;&EN<W3D;&QN:6YG
M87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4W"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS
M9VED(")486)L92!3970B"FUS9W-T<B`B5&%B96QL=7!P<^1T=&YI;F<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E1A8F5L;&EN
M<W3D;&QN:6YG87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN
M82(*;7-G<W1R(")486EW86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK
M:7-T86XB"FUS9W-T<B`B5&%J:6MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ
M86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B3>5L.B(*"B,Z(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(E5P<&=I9G1E<B(*"B,Z(&-O
M;F9I9R]T:&5M97,O9V5N;F5V:6QL:65R<RYP:'`Z,30*;7-G:60@(E1E86PB
M"FUS9W-T<B`B5&5A;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED
M(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F;VYN=6UM97(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B2/9G<W1A('1E;7!E<F%T=7(@<V5N87-T92!T
M:6UM96XZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")4
M96UP97)A='5R92(*;7-G<W1R(")496UP97)A='5R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*
M;7-G<W1R(")496UP97)A='5R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E
M/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R
M871U<CQB<B`O/B@E<TUA>"5S+R5S36EN)7,I("9D96<[)7,B"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-R!L:6(O2&]R9&4O5&5M
M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")+86X@:6YT92!H:71T82!M86QL
M("5S+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP
M;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!;G;D;F1A<F%D;6EN:7-T
M<F%T:6]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV-#$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T
M(@IM<V=S='(@(D=O9&OD;FX@8F5GY')A;B!P<F5L:6UI;N1R="(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Y"FUS
M9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R(")0<F5L:6UI;N1R
M="!A8V-E<'1E<F%T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,U"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HS,S,Q"FUS9VED(")4
M97AT(@IM<V=S='(@(E1E>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B16YB87)T('1E>'0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(E1E>'1J=7-T97)I;F<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q
M"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'1T;W`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*
M;7-G<W1R(")4;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED
M(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4:&%I("A425,M-C(P*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-`HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:6QA;F0B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK
M('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B5&%C:R!F]G(@
M871T(&1U(&%N=N1N9&5R('-Y<W1E;65T+B(*"B,Z('-E<G9I8V5S+VQI;FMS
M+V1E;&5T92YP:'`Z,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE("5S(&QI
M;FL@=&\@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B3.1N:V5N("5S
M('1I;&P@)7,@:&%R(')A9&5R871S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#(P(&QI8B]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D944"UT
M:6QLY&=G970@Y'(@:6YT92!T:6QL9^1N9VQI9W0N(@H*(SH@;&EB+TAO<F1E
M+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@
M9&ES86)L960N(@IM<V=S='(@(DAI<W1O<FEK<WES=&5M970@Y'(@879A:W1I
M=F5R870N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P
M;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8BUI;G1E9W)A=&EO;G-G
M<N1N<W-N:71T970@<W3V9&5R(&EN=&4@7"(E<UPB(@H*(SH@;&EB+TYE="])
M35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-4U`M;&]G9V5N(&MU;F1E
M(&EN=&4@:6YI=&EE<F%S+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")+;&%S<V5N($UA:6YT96YA;F-E
M.CH@:W5N9&4@:6YT92!L861D87,B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B26YS=.1L;&YI;F=S9O9N<W1R
M970@:&%R('-TY&YG=',N($%V<VQU=&%R+B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S`S"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI8B](;W)D
M92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP:'`Z,C,T
M(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*(D%D;6EN:7-T<F%T]G)E;B!MY7-T92!K
M;VYF:6=U<F5R82!E;B!P97)M86YE;G0@0F5H]G)I9VAE=',M:V]P<&QI;F<@
M;VT@9'4@(@HB=FEL;"!A;G;D;F1A($)E:/9R:6=H971E<BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS
M9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")%;F)A<G0@;F5D
M<F4@<VED86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C0Y"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A
M;&ED(@IM<V=S='(@(DMA;&5N9&5R:6YF;W)M871I;VYE;B#D<B!F96QA:W1I
M9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*
M;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D
M871A8F%S92XB"FUS9W-T<B`B2V]N=&%K=&5N<R!)1"!A;F=A=G,@:6YT92!E
M;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I(&1A=&%B87-E;BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B2V]N=&%K=&5N(&QA9&5S('1I;&P@:2!A9')E<W-B;VME;BXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,30Y(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D1E;B!L]G-G:F]R9&$@
M4$=0+7-I9VYA='5R96X@:W+D=G,@9O9R(&%T="!V97)I9FEE<F$@9&5T('-I
M9VYE<F%D92`B"B)M961D96QA;F1E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@
M(B(*(D1I<W1R:6)U=&EO;G-L:7-T86YS($E$(&%N9V%V<R!I;G1E(&5L;&5R
M(&MU;F1E(&EN=&4@:&ET=&%S(&D@9&%T86)A<V5N+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T
M<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B1&ES
M=')I8G5T:6]N<VQI<W1A;B!H87(@:6YT92!A;F=I=FET<RXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,R!L:6(O2&]R9&4O0W)Y<'0N<&AP
M.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B2W)Y<'1E<FEN9W-F
M=6YK=&EO;F5R;F$@:W+D=F5R(&5N('/D:V5R('=E8F;V<F)I;F1E;'-E("A(
M5%104RDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HW.`IM<V=I9"`B5&AE(&5V96YT(&AA<R!B965N(&%D9&5D('1O
M('EO=7(@8V%L96YD87(N(@IM<V=S='(@(DCD;F1E;'-E;B!L861E<R!T:6QL
M(&D@:V%L96YD97)N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#DS"B,Z(&QI8B](;W)D
M92YP:'`Z,3<W(&QI8B](;W)D92YP:'`Z-3$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB
M"FUS9W-T<B`B1FEL96X@)7,@<VMA;&P@:6YN96CE;&QA(&5N(&EN<W3D;&QN
M:6YG(&;V<B`E<RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0X,PHC.B!L:6(O2&]R9&4N
M<&AP.C$W,"!L:6(O2&]R9&4N<&AP.C4P.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+B(*;7-G<W1R(")&:6QE;B`E<R!S:V%L;"!I;FYE:.5L;&$@:6YS=.1L;&YI
M;F=A<B!F]G(@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BXB"FUS9W-T<B`B1FEL96X@:V%N(&EN=&4@:V]P:65R87,@=&EL;"!S
M:6<@<VKD;'8N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C8*;7-G:60@(E1H
M92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@
M(D9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I;&P@<VEG('-JY&QV+B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,"!L:6(O2&]R9&4O1&%T82YP
M:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B1FEL96X@:6YN96CV;&P@:6YG96X@:6YF;W)M871I;VXN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PHC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE
M(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R
M9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B2'5V=61FY&QT(&;V<B!D971T82!M
M961D96QA;F1E+W)F8S@R,FUE9&1E;&%N9&4@9O9L:F5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F
M(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H
M97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R
M>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E
M(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B261E;G1I=&5T96X@)R5S)R!R861E<F%D97,N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM
M<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B0F%R82!V
MY&YS=&5R('-I9&$B"@HC.B!S97)V:6-E<R]L:6YK<R]D96QE=&4N<&AP.C,W
M"FUS9VED(")4:&4@;&EN:R!H87,@8F5E;B!R96UO=F5D(@IM<V=S='(@(DSD
M;FME;B!H87(@=&%G:71S(&)O<G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ-#8@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,34W"FUS
M9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@HB4_9K=N1G96X@=&EL;"!';G501RUP<F]G<F%M;65T(&WE<W1E('9A<F$@
M86YG:79E;B!T:6QL(&ML87-S96X@0W)Y<'1?<&=P.CHN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C(P,2!L:6(O2&]R9&4O34E-12]-1$XN
M<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S
M96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@
M9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@
M(B(*(DUE9&1E;&%N9&5T('-K:6-K870@)7,@=&EL;"`E<R!M960@Y')E;F1E
M(%PB)7-<(B!H87(@=FES871S+EQN(@HB1&5T=&$@Y'(@:6YG96X@9V%R86YT
M:2!F]G(@871T(&UE9&1E;&%N9&5T(&AA<B!LY'-T<RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<W(&QI8B](;W)D92]&;W)M+G!H<#HQ.#@Q
M"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C
M;VUP;W-E('!A9V4B"FUS9W-T<B`B3F%M;F5T('-O;2!S:V%L;"!A;G;D;F1A
M<R!F]G(@871T(&SD;FMA('1I;&P@<VMA<&$M<VED86XB"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$@;&EB+T9I;&4O0U-6+G!H<#HT-S0*
M;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB
M"FUS9W-T<B`B06YT86P@9N1L="!MY7-T92!V87)A(&5T="!N=6UE<FES:W0@
M=N1R9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C,Q(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B36]D=6QE;B!O<&5N<W-L(&MR
MY'9S(&%V(&ML87-S96X@2&]R9&5?0W)Y<'1?<VUI;64Z.BXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,"!L:6(O2&]R9&4O4')E9G,N<&AP
M.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<
M(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B
M(@HB26YS=.1L;&YI;F=E;B!<(B5S7"(@:W5N9&4@:6YT92!S<&%R87,@<.4@
M9W)U;F0@878@871T(&1A=&%MY&YG9&5N("(*(O9V97)S:W)I=F5R(&1E;B!M
M87AI;6%L="!T:6QLY71N82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VUS97AC96PN<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N
M<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z
M,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z
M,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S
M(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)0<F]G<F%M
M;65T('-O;2!A;G;D;F1S(&;V<B!A='0@=FES82!D96X@:.1R(&UE9&1E;&%N
M9&5T>7!E;B`H)7,I('-A:VYA<R!PY2`B"B)S>7-T96UE="XB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30@;&EB+T9I;&4O0U-6+G!H<#HT
M.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B5&5C:VYE="!F]G(@8VET97)I;F<@
M;>5S=&4@=F%R82!E='0@=&5C:V5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(D)A<F$@:/9G97(@;V-H
M(';D;G-T97(@<VED;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B0F%R82!H]F=E<B!S:61A(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V(&QI8B]&:6QE+T-35BYP:'`Z-#<Y
M"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N(@IM<V=S='(@(E-E<&%R871O<FX@;>5S=&4@=F%R82!E='0@=&5C
M:V5N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(E-E<G9E<B`G)7,G(')A9&5R861E<RXB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`B4V5R=F5R("<E<R<@<W!A<F%D97,N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B4')E;G5M97)A=&EO
M;G-B96?D<F%N(&;V<B`E<R!H87(@=&%G:71S(&)O<G0N(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B06YG:79E;B!R860@*"5D*2!F:6YN<R!I;G1E+B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,"!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!;F=I=F5N(')A9"!E>&ES
M=&5R87(@:6YT92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C$P.`IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@861D
M960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B57!P9VEF=&5N(&AA<B!L
M86=T<R!T:6QL(&D@9&EN('5P<&=I9G1S;&ES=&$N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HQ-S<@;&EB+U9&4R]S<6PN<&AP.C$W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R(")496UP;W+D<B!F:6P@)R5S)R!F:6YN
M<R!I;G1E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3`@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,S,#8*;7-G:60@(E1H92!T97AT('EO=2!E;G1E
M<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS
M9W-T<B`B5&5X=&5N(&1U(&UA=&%T(&EN('-TY&UM97(@:6YT92#V=F5R96YS
M(&UE9"!T97AT96X@<.4@<VOD<FUE;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(D)A<F$@=&]P<"!O8V@@
M8F]T=&5N('-I9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*
M;7-G<W1R(")"87)A('1O<'!S:61A(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,S(W(&QI8B](;W)D92]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+B(*;7-G<W1R(")5<'!L861D870@9&%T82!F]G)S=F%N;B!S961A;B!F]G)E
M9^5E;F1E('-T96<N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP
M.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"B,Z(&QI8B](
M;W)D92]$871A+V-S=BYP:'`Z,C8R(&QI8B](;W)D92]$871A+W1S=BYP:'`Z
M,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V
M960N(@IM<V=S='(@(D1E;B!U<'!L861D861E(&9I;&5N(&MU;F1E(&EN=&4@
M<W!A<F%S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z.3,*;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(DQE9&EG
M+W5P<'1A9V5N+6EN9F]R;6%T:6]N(&;V<B!A;G;D;F1A<F5N(&AA<B!S<&%R
M871S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B5V5A=&AE
M<BYC;VTM8FQO8VME="#D<B!I;G1E('1I;&QGY&YG;&EG="XB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")496UA
M:V%T86QO9R`G)7,G(&9I;FYS(&EN=&4N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-S@@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*
M;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T
M<B`B26YG82!I;G-TY&QL;FEN9V%R('1I;&QGY&YG;&EG82XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#$@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D1E="!F
M:6YN<R!I;F=A(&%L=&5R;F%T:79A(&1E;&%R('-O;2!K86X@=FES87,@:6YL
M:6YE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(D;V<B!MY6YG82!T96-K96X@
M:2!FY&QT970N($1U(&AA<B!A;F=E='0@)7,@=&5C:V5N.R!M87AI;6%L="!A
M;G1A;"!T96-K96X@Y'(@(@HB)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI
M;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS
M9W-T<B`B4')O8FQE;2!M960@871T(&SD9V=A('1I;&P@)R5S)R!T:6QL('-Y
M<W1E;65T.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(E!R
M;V)L96T@;65D(&%T="!R96YS82!I;F9O<FUA=&EO;B!O;2!A;G;D;F1A<F4@
M)R5S)R!F<N5N('-Y<W1E;65T.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')O8FQE
M;2!M960@871T('1A(&)O<G0@)R5S)R!F<N5N('-Y<W1E;65T.B`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(E!R
M;V)L96T@=FED('5P<&1A=&5R:6YG(&%V("<E<R<Z("5S(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<Y(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+B(*;7-G<W1R(")0<F]B;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;BX@
M26YG82`E<R!L861D861E<R!U<'`N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#@T(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@
M;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B
M(@HB1&5T('5P<'-T;V0@<')O8FQE;2!V:60@=7!P;&%D9&YI;F<@878@9FEL
M96XZ("5S(.1R('-T]G)R92#D;B!M87AI;6%L="`B"B)T:6QLY71E;B!S=&]R
M;&5K("@E9"!B>71E<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#@V(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"XB"FUS9W-T<B`B(@HB1&5T('5P<'-T;V0@<')O8FQE;2!V:60@=7!P;&%D
M9&YI;F<@878@9FEL96XZ("5S(&QA9&1A9&5S(&5N8F%R="!U<'`@9&5L=FES
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T(@IM<V=S='(@(D1E="!U<'!S=&]D(&5T="!F96P@=FED('9I<VYI
M;F<@878@;65D9&5L86YD961E;&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-#@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N(@IM<V=S='(@(D9E;"!V:60@:6UP;W)T(&%V(&MO;G1A
M:W1D871A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")&96P@
M=FED(&EM<&]R="!A=B!HY&YD96QS96XZ("5S+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O:6UC+G!H<#HS,2!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82XB"FUS9W-T<B`B1F5L('9I9"!I;7!O<G0@878@:4-A;&5N
M9&%R(&1A=&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(D9E
M;"!V:60@:6UP;W)T(&%V('5P<&=I9G1E;CH@)7,N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HY,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G
M<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R(")&96P@=FED
M(&EM<&]R="!A=B!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;CH@)7,N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E
M<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S
M='(@(B(*(D5T="!F96P@<.5T<N1F9F%D97,@:2!F;W)M=6SD<F5T+B!+;VYT
M<F]L;&5R82!A='0@9'4@:6YT92!G;/9M="!F>6QL82!I(&5T="`B"B)O8FQI
M9V%T;W)I<VMT(&;D;'0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S@*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E
M<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN
M(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D1E="!G
M:6-K(&EN=&4@871T('5T9O9R82!D96X@8F5GY')D82!A9')E<W-B;VMS9G5N
M:W1I;VYE;BX@5F%R(&=O9"!F]G)S]FL@(@HB<V5N87)E+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")&96P@=FED('5P
M<&1A=&5R:6YG(&%V(&MO;G1A:W1U<'!G:69T97(N($;V<G/V:R!I9V5N('-E
M;F%R92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(R,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(D9E;"!V:60@=7!P
M9&%T97)I;F<@878@9&ES=')I8G5T:6]N<VQI<W1A;BX@1O9R<_9K(&EG96X@
M<V5N87)E+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$T."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS
M9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R(")$:6X@24U!4"US97)V97(@<W3V9&5R(&EN
M=&4@9&5L861E(&UA<'!A<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C@R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z.38*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR,#`*;7-G:60@(E1H:7,@86-T
M:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D1E;FYA(&AA;F1L:6YG
M('-T]F1S(&EN=&4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO
M="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(D1E;FYA(&9U;FMT:6]N(.1R
M(&EN=&4@:6UP;&5M96YT97)A9"#D;BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C0X(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")&:6QE;B!V97)K87(@:6YT
M92!V87)A(&5T="!G:6QT:6=T(%)!4BUA<FMI=BXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")&:6QE;B!V97)K87(@
M:6YT92!V87)A(&5T="!G:6QT:6=T(%I)4"UA<FMI=BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,30U(&QI8B](;W)D92]&;W)M+G!H<#HS,3,Q
M"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BXB"FUS9W-T<B`B1F5L86MT:6=T(&MO<G1N=6UM97(N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)$
M96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D
M9&5L86YD96X@=FEA($-L:6-K871E;&PM(@HB8G)Y9V=A;B`H:'1T<#HO+V-L
M:6-K871E;&PN8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"B)$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M
M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA(%=)3BUB<GEG9V%N
M("(*(BAH='1P.B\O=VEN<&QC+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%14
M4"!!4$DZ="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$U"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M
M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"B)$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S
M:VEC:V$@;65D9&5L86YD96X@=FEA('-M<S)E;6%I;"UB<GEG9V%N("(*(BAH
M='1P.B\O<VUS,F5M86EL+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%144"!!
M4$DZ="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@U"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET
M86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(D1E;FYA(&1R
M:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K:6-K82!M961D96QA;F1E
M;B!V:6$@4TU44"!G96YO;2`B"B)6;V1A9F]N92!)=&%L:65N+6)R>6=G86X@
M*&5N8F%R="!T:6QL(%9O9&%F;VYN=6UM97(I+B!$<FEV<G5T:6YE;B!K<N1V
M97(@971T("(*(F4M<&]S=&MO;G1O(&AO<R!6;V1A9F]N92!)=&%L:65N("AH
M='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X
M,3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.3@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Q(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,#DP"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$Y(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3@V(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8P
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`Y(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#`R(&QI8B](;W)D92]&;W)M+G!H<#HQ-38Q"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#0S(&QI8B](;W)D92]&;W)M+G!H<#HQ.38R(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#`Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,S(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#@R(&QI8B](;W)D92]&;W)M+G!H<#HR,34S
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C(U(&QI8B](;W)D92]&;W)M+G!H
M<#HR-#$R(&QI8B](;W)D92]&;W)M+G!H<#HR-#4T"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-C0Q(&QI8B](;W)D92]&;W)M+G!H<#HR.#$T(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3(S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`Q(&QI
M8B](;W)D92]&;W)M+G!H<#HS.#`Y(&QI8B](;W)D92]&;W)M+G!H<#HS.#$W
M"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")&Y&QT
M970@;>5S=&4@=F%R82!I9GEL;'0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`V-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V.0IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")&
MY&QT970@9N5R(&5N8F%R="!I;FYE:.5L;&$@:&5L=&%L+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@@;&EB+TAO<F1E+T9O<FTN<&AP.C(T
M,C`*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S
M(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D;D;'1E="!FY7(@96YB87)T(&EN
M;F5HY6QL82!S:69F<F]R(&]C:"!K;VQO;BXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#DT(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DX"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*
M;7-G<W1R(")&Y&QT970@9N5R(&5N8F%R="!I;FYE:.5L;&$@;VMT86QA('1A
M;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G
M<W1R("(B"B)&Y&QT970@<VMA;&P@=F%R82!E;B!K;VUM82T@96QL97(@;65L
M;&%N<VQA9W-S97!A<F%R860@;&ES=&$@;65D(&AE;'1A;"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDX.2!L:6(O2&]R9&4O1F]R;2YP:'`Z.3DS
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM
M<V=S='(@(D;D;'1E="!MY7-T92!V87)A(&5T="!G;V1KY&YT('1A;"XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#(R"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D1E='1A(&;D;'0@;>5S=&4@
M:6YN96CE;&QA(&5N(%)'0BUFY')G:V]D(&D@:&5X861E8VEM86QT(&9O<FUA
M="P@="!E>"`B"B(G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z-38Q(&QI8B](;W)D92]&;W)M+G!H<#HU-C4*;7-G:60@(E1H:7,@
M9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B1&5T
M=&$@9F]R;75LY'(@:&%R(')E9&%N(&)E87)B971A=',N(@H*(SH@=&5M<&QA
M=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!I<R`E<RXB"FUS9W-T<B`B1&5T(&CD<B#D<B`E<RXB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0U.2!L:6(O2&]R9&4O2V]L86(N<&AP.C0V
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DP(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(DUE9&1E;&%N9&5T
M('-K<F5V<R!I(&5N(&%N;F%N('1E8VME;G5P<'/D='1N:6YG("@E<RD@Y&X@
M9&EN(&5G96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")$970@:.1R(&YU
M;7)E="!MY7-T92!V87)A(&UI;G-T(&5T="XB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4@;&EB+TAO<F1E+T-O;7!R97-S
M+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B4V5R=F5R;B!K86X@
M:6YT92!P86-K82!U<'`@>FEP(&]C:"!G>FEP(&9I;&5R+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@V(&QI8B](;W)D92]2
M96=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-Y<W1E;65T(.1R(&;V<B!T:6QL
M9N1L;&5T(&%V86MT:79E<F%T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(T(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D1E="!H
MY'(@=N1R9&5T(&WE<W1E('9A<F$@;G5M97)I<VMT+B(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T
M<B`B1&5T=&$@9O9N<W1E<B!MY7-T92!A;G)O<&%S(&9RY6X@971T(&MO;F9I
M9W5R871I;VYS9O9N<W1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(L5S:V$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K
M971S(@IM<V=S='(@(L1R96YD96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#(X(&QI8B](;W)D92]&;W)M+G!H<#HR-#(Y"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R(")4
M:60B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4
M:6UE(%1R86-K:6YG(@IM<V=S='(@(E1I9'-R961O=FES;FEN9R(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T
M<B`B5&ED<V9O<FUA="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M,SD@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*;7-G:60@(E1I;64@<V5L96-T
M:6]N(@IM<V=S='(@(E1I9'-V86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I
M;6]R+4QE<W1E(@IM<V=S='(@(M9S='1I;6]R(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B4G5B<FEK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@
M*'1O;VQT:7`I.B(*;7-G<W1R(")2=6)R:6L@*'1O;VQT:7`I.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM
M<V=S='(@(E1I;&PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C(Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@
M:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K
M97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(D;V<B!A='0@;6%R
M:V5R82!F;&5R82!V86PL(&CE;&P@;F5D($-T<FP@*%!#*2!E;&QE<B!#;VUM
M86YD("A-86,I('1A;F=E;G1E;B`B"B)NY'(@9'4@:VQI8VMA<BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*
M;7-G<W1R("))9&%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S
M='(@(E9I<V$@2%1-3"UKY&QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G
M;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U
M(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("));6]R9V]N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&]P(@IM<V=S='(@(E1O<"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H
M7W1O<"DB"FUS9W-T<B`B5&]P(&9R86UE("A?=&]P*2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@
M(M9V97)SY'1T;FEN9V%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A
M9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D(&]C:"!4;V)A9V\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E-A;G0@
M96QL97(@9F%L<VMT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B5&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C@*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N:7-I96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S$*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R."!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)K:65T(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(E1U<FMI<VL@*$E33RTX.#4Y+3DI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES
M=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',B"FUS9W-T<B`B5'5R:W,M(&]C:"!#86EC;W/V87)N82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R
M86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0@;&EB+TAO<F1E+T-,22YP:'`Z,C8T
M"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B06YG92!D:71T
M('9A;#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM
M<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E56+6EN9&5X.B`B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),
M(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S
M='(@(E523"!F]G(@9&ET="!L979E<F%N<W)A<'!O<G1E<FEN9W-S:W)I<'0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW
M"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN82(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C0Q,B!L:6(O5D93+V9I;&4N<&AP.C0Q.0IM<V=I
M9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+
M86X@:6YT92!LY'-A(%9&4RUM87!P+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV
M"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"B)$970@9VEC:R!I;G1E(&%T
M="!LY&=G82!T:6QL('5T]FMA9"!A;G;D;F1A<FEN9F]R;6%T:6]N('9I9"!R
M96=I<W1E<FEN9RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X
M."!L:6(O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")+86X@:6YT92#D;F1R82!B96CV<FEG:&5T(&;V<B!61E,M
M9FEL("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,SDR(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6YT92#D;F1R82!B96CV<FEG:&5T
M(&;V<B!61E,M9FEL("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S4U(&QI8B]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B2V%N(&EN
M=&4@Y&YD<F$@=&EL;"`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92`E<R\E<R(*;7-G<W1R(")+86X@:6YT92!K;VYT<F]L;&5R
M82!F:6QS=&]R;&5K("5S+R5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR,S(@;&EB+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS
M9W-T<B`B2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL<W1O<FQE:R!PY2`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC.B!L:6(O5D93+V9I;&4N<&AP
M.C8Y-2!L:6(O5D93+W-Q;"YP:'`Z,3`R."!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HX-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(&MO;G1R
M;VQL97)A(&9I;'-T;W)L96L@<.4@)7,O)7,N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C0S-2!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C0S
M.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS
M9W-T<B`B2V%N(&EN=&4@:V]N=&%K=&$@4U%,+7-E<G9E<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.2!L:6(O5D93+V9T<"YP:'`Z.#<P
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B
M2V%N(&EN=&4@:V]N=&%K=&$@=FEA(%-33"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y(&QI8B]61E,O9FEL92YP:'`Z,C,R
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,W(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C(P-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB
M"FUS9W-T<B`B2V%N(&EN=&4@:V]P:65R82!61E,M9FEL+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U(&QI8B]61E,O9G1P+G!H<#HS-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<VMA<&$@5D93+6UA
M<'`@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(U-B!L:6(O5D93+V9I;&4N<&AP.C,V,0HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(DMA;B!I;G1E('-K87!A(%9&4RUM87!P+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")+
M86X@:6YT92!S:V%P82!61E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C@V(&QI8B]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B2V%N(&EN=&4@<VMA<&$@5D93+6UA<'`@)R5S)RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4@;&EB+U9&4R]F:6QE+G!H
M<#HR-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M(@IM<V=S='(@(DMA;B!I;G1E('-K87!A('1O;2!61E,M9FEL+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.2!L:6(O2&]R9&4O
M0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII
M<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM
M<V=S='(@(DMA;B!I;G1E('!A8VMA('5P<"!D871A+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,CDX"B,Z(&QI8B]61E,O<VUB+G!H<#HR,C@@;&EB+U9&4R]F='`N<&AP
M.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(DMA
M;B!I;G1E(')A9&5R82`E<RP@;6%P<&5N(.1R(&EN=&4@=&]M+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@
M)7,N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82`G)7,G.B`E<R(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HS,S@@;&EB+U9&4R]S<6PN<&AP.C,Y-2!L:6(O5D93
M+VUU<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R
M82`E<RP@;6%P<&5N(.1R(&EN=&4@=&]M+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,U,@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-38@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DMA;B!I;G1E(')A
M9&5R82!61E,M;6%P<"!R96MU<G-I=G0N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-#0@;&EB+U9&4R]F:6QE+G!H<#HS-#0*(SH@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S-2!L:6(O
M5D93+VUU<W%L+G!H<#HS-#,*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4R
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMA;B!I;G1E(')A9&5R82!61E,M;6%P<"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0R.0HC.B!L:6(O5D93+W-Q;"YP:'`Z-#(P(&QI8B]61E,O<W%L+G!H<#HT
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(%9&4RUM
M87!P.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-R!L
M:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT
M92!R861E<F$@5D93+69I;"`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ(&QI8B]61E,O
M9FEL92YP:'`Z,S$P(&QI8B]61E,O<W%L+G!H<#HR.3$*(SH@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,38W(&QI8B]61E,O;75S<6PN<&AP.C$X,"!L:6(O5D93+VUU
M<W%L+G!H<#HQ.#<*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(%9&4RUF:6PN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0@;&EB+U9&4R]S;6(N
M<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@
M5D93+6UA<'`@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0P-B!L:6(O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T
M<B`B2V%N(&EN=&4@<F%D97)A(%9&4R!R96MU<G-I=G0Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S(&QI8B]61E,O9G1P+G!H<#HX
M,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMA;B!I;G1E(&%V9_9R82!A:W1U96QL(&UA<'`N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R
M86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B2V%N(&EN=&4@97AT
M<F%H97)A($-E<G1I9FEK871S9&5T86QJ97(B"@HC.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U
M=&@N<&AP.C$Q.`HC.B!L:6(O3F5T+TE-4U`N<&AP.C0S-R!L:6(O3F5T+TE-
M4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")+86X@:6YT
M92!L861D82!D969I;FET:6]N96X@878@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HR,#,@;&EB+U9&4R]F:6QE+G!H<#HR,#@@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I
M9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I;G1E
M(&9L>71T82!61E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HY.`HC.B!L:6(O5D93+W-M8BYP:'`Z.3,@;&EB+U9&4R]S;6(N<&AP
M.C$P-B!L:6(O5D93+W-M8BYP:'`Z-C4R"B,Z(&QI8B]61E,O9G1P+G!H<#HY
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(/9P<&YA(%9&4RUF:6P@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$S,R!L:6(O5D93+V9I;&4N<&AP.C(X-`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@5D93+69I;"!F]G(@<VMR:79N
M:6YG+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z-S(@;&EB+U9&4R]F:6QE+G!H<#HX,R!L:6(O5D93
M+V9I;&4N<&AP.C$S-PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I;G1E
M(/9P<&YA(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HT-2!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R(")+86X@:6YT92#V<'!N82!K;VUP<FEM97)A="!A<FMI=BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,V(&QI8B]61E,N<&AP.C@U-@IM
M<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B2V%N(&EN=&4@;.1S82!61E,M9FEL("AF:6QE<VEZ
M92@I(&UI<W-L>6-K861E<RDN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@V-R!L:6(O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DMA;B!I
M;G1E(&SD<V$@5D93+69I;"`H9V5T1FEL95-I>F4H*2!M:7-S;'EC:V%D97,I
M+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<B]N;VYE+G!H<#HS.`HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;F]N
M92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R
M(")+86X@:6YT92!LY'-A(&9I;#H@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-C8Y(&QI8B]61E,O9FEL92YP:'`Z-C<V"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA
M;B!I;G1E(&SD<V$@:V%T86QO9V5N(&;V<B`G=F9S<F]O="<N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3$P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B
M"FUS9W-T<B`B2V%N(&EN=&4@8GET82!N86UN('#E("5S('1I;&P@)7,Z(&1E
M<W1I;F%T:6]N<VUA<'`@9FEN;G,@<F5D86XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P
M,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(")+86X@:6YT92!B>71A(&YA;6X@<.4@5D93+6UA<'`N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD@;&EB+U9&4R]S<6PN<&AP.C,S
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")+86X@:6YT92!B>71A(&YA;6X@<.4@
M5D93+6UA<'`Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,Z(&QI8B]61E,O
M<VUB+G!H<#HR-S$@;&EB+U9&4R]F='`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUF:6P@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR,CD*(SH@;&EB+U9&4R]F:6QE+G!H<#HV,3<@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DMA;B!I;G1E
M(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$@;&EB+U9&4R]S<6PN<&AP.C,R-@HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(DMA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,`HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-3$@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N
M86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(")+86X@:6YT92!K]G)A
M("=M:VES;V9S)RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<W=O<F0N<&AP.C4Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N="(*;7-G<W1R(")+86X@:6YT92#V=F5R<^1T=&$@5V]R9&1O:W5M
M96YT970B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC.B!L:6(O5D93+V9T<"YP:'`Z
M,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N
M(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ-SD@;&EB+U9&4R]F:6QE+G!H<#HQ.#8*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN
M(@IM<V=S='(@(DMA;B!I;G1E('-K<FEV82!T:6QL(%9&4RUF:6P@*&-O<'DH
M*2!M:7-S;'EC:V%D97,I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,@;&EB+U9&4R]F
M:6QE+G!H<#HR.#@*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30V(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N(@IM<V=S='(@(DMA;B!I;G1E('-K<FEV82!D871A('1I
M;&P@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0R(&QI
M8B]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(")+86X@:6YT92!S
M:W)I=F$@=&EL;"!61E,M9FEL+"!K=F]T82!S:W5L;&4@]G9E<G-K<FED87,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E5N9&5R<W1R=6ME;B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R("+%;F=R82#D;F1R:6YG87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R("+%;F=R87(@9&EN('-E;F%S=&4@Y71G
MY')D(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y
M,"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S
M='(@(D]VY&YT870@<W9A<B!F<N5N('-E<G9E<B!PY2!F]G)B:6YD96QS93H@
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,S.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<V"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z("(*;7-G<W1R(")/=N1N=&%T('-V87(@9G+E;B!S97)V97(@=&EL;#H@
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3<*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B16H@:V%T96=O<FES97)A9"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@
M;V8@='EP93H@)7,B"FUS9W-T<B`B26-K92!H86YT97)A9"!K;VUP;VYE;G0@
M878@='EP.B`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED
M(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@
M(D;V<F5N861E($%R86)E;6ER871E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N
M:71E9"!+:6YG9&]M(@IM<V=S='(@(E-T;W)B<FET86YN:65N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(D;V<F5N=&$@
M4W1A=&5R;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")!;65R:6MA;G-K82!3
M=&EL;&%H879S]F%R;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B56YI=',B"FUS
M9W-T<B`B16YH971E<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q."!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3D*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0S,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HU
M.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")/:^1N9"(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")/:^1N="!G
M<N1N<W-N:71T<VUE9&1E;&%N9&5I9"`H87!I;7-G:60I+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")/
M:^1N="!K;&EE;G1M961D96QA;F1E:60@*&-L:6US9VED*2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")/:^1N9"!O<G0@<W!E8VEF:6-E
M<F%D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`B3VOD;G0@86YVY&YD87)N86UN(&5L;&5R(&SV<V5N;W)D+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T
M<B`B5&$@8F]R="!LY&YK96X@9G+E;B!N=79R86YD92!E;&5M96YT(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38@;&EB+TAO<F1E
M+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B3F%M
M;FSV<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T
M;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS
M9W-T<B`B(@HB26-K92UP<FEV:6QI9V5R861E('-K<FEP="!K86X@:6YT92!K
M;VUM82#E="!+;&EP<"!U="]+;W!I97)A+TML:7-T<F$M(@HB9G5N:W1I;VYE
M<FYA(&%V('/D:V5R:&5T<W-KY&PN($ML:6-K82!/2R!F]G(@871T('-E(&5N
M('1E:VYI<VL@8F5S:W)I=FYI;F<@(@HB9G+E;B!M;WII;&QA+F]R9R!O;2!H
M=7(@9'4@:V%N('1I;&SE=&$@871T('-K<FEP="!K;VUM97(@Y70@=7)K;&EP
M<"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")482!B;W)T
M(&;D<F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X
M-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8X-PHC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.CDR-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS
M=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(E1I;&SD9V=E="!S=/9D<R!I
M;G1E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")5<'!D871E
M<F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")5<'!D871E
M<F$@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8T.`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM
M<V=S='(@(E5P<&1A=&5R82!S=&%T=7,@<.4@<W9A<F%N9&4B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@
M=7-E<B(*;7-G<W1R(")5<'!D871E<F$@86YVY&YD87)E(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57!D871E9"!<(B5S7"(N(@IM<V=S='(@(E5P<&1A=&5R861E("<E<R<N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@
M<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(E5P<&1A=&5R:6YG<W-C<FEP="!R
M861E<F%T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X,@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B3&%D9&$@=7!P(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(DQA9&1A9&4@=7!P(&%L;&$@
M:V]N9FEG=7)A=&EO;G-F:6QE<B!T:6QL('-E<G9E<FXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")697)S86QE<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M4F]M97)S:V$@<VEF9G)O<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A
M>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(SH@;&EB+TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M($-U<G)E;G0Z("5S(@IM<V=S='(@(D%N=N1N9"!A:W1U96QL.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@
M(E5S92!34TPB"FUS9W-T<B`B06YVY&YD(%-33"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(D%N=N1N9"!O
M;2!N86UN+VSV<V5N;W)D(.1R(&%N;F]R;'5N9&$@9O9R($E-4U`M<V5R=F5R
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G
M:60@(E5S97(B"FUS9W-T<B`B06YVY&YD87)E(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C`@;&EB+TAO<F1E+U)E9VES=')Y
M+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@
M875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(D%N=N1N9&%R92`E<R#D<B!I
M;G1E(&)E:/9R:6<@9O9R("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM
M<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!;G;D;F1A<F%D
M;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HR-3`@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@
M3W!T:6]N<R(*;7-G<W1R(")!;G;D;F1A<FEN<W3D;&QN:6YG87(B"@HC.B!S
M:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R
M(")!;G;D;F1A<G)E9VES=')E<FEN9R(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N(@IM<V=S='(@(D%N=N1N9&%R<F5G:7-T<F5R:6YG(&AA<B!A
M=F%K=&EV97)A=',N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM
M<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R(")!;G;D;F1A
M<FMO;G1O="!H:71T861E<R!I;G1E(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!L:6(O3F5T+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.CDX(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DX"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3`@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B06YVY&YD87)N86UN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-"!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D%N
M=N1N9&%R;F%M;B`E<R!F:6YN<R!R961A;BXB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")!
M;G;D;F1A<FYA;6XZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")!;G;D;F1A<FYA;6XZ("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(D%N=N1N9&%R92!I('-Y<W1E
M;65T.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R
M(")5>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0HC.B!L:6(O5D93
M+V9I;&4N<&AP.C$W,"!L:6(O5D93+V9I;&4N<&AP.C(V,@IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B5D93+6UA<'`@
M97AI<W1E<F%R(&EN=&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B4V5M97-T97(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@W,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*
M;7-G<W1R(")':6QT:6=A('!L871S97(@<V]M(&AI='1A9&5S(&EN:VQU9&5R
M87(Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R(")':6QT:6=H970B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO
M=RXB"FUS9W-T<B`B36EN=71E<B!F<N5N(&YU(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@V,"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B5N1R9&5T(/9V97)S=&EG
M97(@9&5T(&CV9W-T82!T:6QLY71N82`H)7,I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C4Y(&QI8B](;W)D92]&;W)M+G!H<#HR,C0X"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C<P(&QI8B](;W)D92]&;W)M+G!H<#HR,S(P
M(&QI8B](;W)D92]&;W)M+G!H<#HR.3$T"B,Z(&QI8B](;W)D92]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B5N1R
M9&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3$S(&QI8B](;W)D92]&;W)M+G!H<#HR,3DP"FUS9VED(")686QU97,@=&\@
M<V5L96-T(&9R;VTB"FUS9W-T<B`B5N1R9&5N(&%T="!VY&QJ82!F<N5N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5T874B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")6
M87)I86)L92(*;7-G<W1R(")687)I86)E;"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T
M<B`B5F5R:69I97)I;F<@;6ES<VQY8VMA9&5S("T@;65D9&5L86YD970@:V%N
M(&AA(&UA;FEP=6QE<F%T<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P,"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM
M<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:6]N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM
M<V=S='(@(E9E<G-I;VYH86YT97)I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;"!A;&EG;B(*;7-G<W1R(")697)T:6MA;"!J=7-T97)I;F<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")6
M97)T:6-A;"!P861D:6YG(@IM<V=S='(@(E9E<G1I:V%L('5T9GEL;&YA9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6MA;#HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B5F5R
M>2!(:6=H(@IM<V=S='(@(E;D;&1I9W0@:/9G(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS
M9W-T<B`B5FEE=&YA;65S:7-K("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.38Q(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HY-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G
M<W1R(")6:7-A("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I
M9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")6:7-A(&5N
M(&5X=&5R;B!W96)B<VED82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@R,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5FES
M82!S;VT@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C<Y"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@(E9I<V$@
M:.1N9&5L<V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C$P.0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(E9I<V$@
M=7!P9VEF="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M($)R:71I<V@B"FUS9W-T<B`B2G5N9V9R=?9A<FYA+"!"<FET=&ES:V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S
M='(@(DIU;F=F<G7V87)N82P@06UE<FEK86YS:V$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")3:6MT
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B
M5FES:6)I;&ET>3H@(@IM<V=S='(@(E-I:W0Z(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*(SH@;&EB+TYE
M="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O
M;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O;F4@271A;&EE;B!V
M:6$@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*(SH@;&EB+TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM
M<V=S='(@(E9!4DXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@
M34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B5D%23DE.1R$A(2!2041%4D$@
M4TM225!4150@34%.545,3%0@1E+%3B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$S,R!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.('9I
M82!(5%10(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R(")786QL:7,@;V-H($9U='5N82(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R
M(")687)N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B3VXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A
M<W0B"FUS9W-T<B`B5N1D97)P<F]G;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D
M(&)Y(@IM<V=S='(@(E;D9&5R9&%T82!F<N5N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DR(&QI8B](;W)D92]&;W)M+G!H<#HX.38*;7-G:60@
M(E=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796)B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I
M=&4B"FUS9W-T<B`B5V5B8G!L871S(@H*(SH@8V]N9FEG+W1H96UE<R]W96)B
M<&QA='-E;BUS;V)E<BYP:'`Z,38*;7-G:60@(E=E8F)P;&%T<V5N("T@4V]B
M97(B"FUS9W-T<B`B5V5B8G!L871S96X@+2!3;V)E<B(*"B,Z(&-O;F9I9R]T
M:&5M97,O=V5B8G!L871S96XM<V]B97)?;F5W+G!H<#HV"FUS9VED(")796)B
M<&QA='-E;B`M(%-O8F5R($Y%5R(*;7-G<W1R(")796)B<&QA='-E;B`M(%-O
M8F5R($Y9(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU."!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7
M965K;'DB"FUS9W-T<B`B5F5C:V]V:7,B"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")6Y&QK;VUM
M96XB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92!T;R`E<R(*;7-G<W1R(")6Y&QK;VUM96X@=&EL;"`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R(")6Y&QK;VUM96XL("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(E;D
M<W1E<FSD;F1S:R`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@
M(E;D<W1E<FSD;F1S:R`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E;D<W1R82!386AA<F$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_(@IM<V=S='(@(E9I;&ME;B!A<'!L:6MA=&EO;B!S:V%L;"`E<R!V:7-A
M(&5F=&5R(&EN;&]G9VYI;F<_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_(@IM<V=S='(@(E9I;&ME;B#D<B!A=F=RY&YS;FEN9W-T96-K;F5T/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(E9I;&ME="#D<B!T
M96-K;F5T(&;V<B!C:71E<F%D('1E>'0_(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,S,*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C0*;7-G:60@(E=H97)E:7,@075S=')A
M;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES($%U<W1R86QI96YK87)T82(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(E9I;&MA(&9A<V5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")6:6QK82!P;'5G:6X@<VMA;&P@
M86MT:79E<F%S(&;V<B!2:6-H(%1E>'0@961I=&]R;BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED
M(")7:61T:"(*;7-G<W1R(")"<F5D9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3$*;7-G:60@(E=I
M9'1H(&EN($-34R!U;FET<R(*;7-G<W1R(")"<F5D9"!I($-34RUU;FET<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(D)R961D('#E(&UE
M;GEN(&;V<B`G)7,G('1I;&P@=N1N<W1E<B`H9^1L;&5R(&9RY6X@;N1S=&$@
M:6YL;V=G;FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T
M<B`B5&%B96QL8G)E9&0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")"
M<F5D9&5N:&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R(")"<F5D9#HB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM
M<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS
M9VED(")7:6YD(@IM<V=S='(@(E9I;F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"!%87)L>2(*;7-G
M<W1R(")4:61I9R!V:6YD(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM
M<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")6:6YD:&%S=&EG
M:&5T(&D@:VYO<"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED
M(")7:6YD.B(*;7-G<W1R(")6:6YD.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")6:6YD.B`B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*
M;7-G<W1R(")6:7-D;VTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("+6;G-K96QI<W1A(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@
M(D%R8F5T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$V-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B
M5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<RP@87)B971E(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0
M:&]N92(*;7-G<W1R(")496QE9F]N+"!A<F)E=&4B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,C8R"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS(&QI8B]&:6QE+T-35BYP
M:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F
M:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G
M<W1R(")&96P@86YT86P@9N1L="!PY2!R860@)60N($;V<G;D;G1A9&4@)60L
M(&AI='1A9&4@)60N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,S`P(&QI8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"XB"FUS9W-T<B`B1F5L(&%N=&%L(&;D;'0N($;V<G;D;G1A9&4@)60L(&AI
M='1A9&4@)60N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T
M(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S
M='(@(D9E;"!P;W-I=&EO;B`E9"!V:60@;.1S;FEN9R!A=B!61E,M9FEL+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F
M(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G
M:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME
M>2!5<V%G92(*;7-G<W1R(")8-3`Y5C,@573V:V%D(&YY8VME;&%N=N1N9&YI
M;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-"!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-2!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.#(@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G
M:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#E6,RUT:6QLY&=G
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@
M(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,30@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B
M65E962(*;7-G<W1R(")965E9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P.#`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B
M66%H;V\A(&UA<"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-38@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I
M9"`B665A<FQY(@IM<V=S='(@(L5R;&EG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")996UE;B(*;7-G<W1R(")996UE;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY,S4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM<V=S='(@(DIA(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC
M.C8*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")*82P@:F%G('-A;71Y
M8VME<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R
M(")$=2!H87(@86MT:79E<F%T('1E>'1LY&=E+B!!;G;D;F0@6SP^72!F]G(@
M871T(.5T97)GY2!T:6QL(%=94TE764<N(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L
M;V-K<RXB"FUS9W-T<B`B1'4@:&%R(&EN=&4@8F5H]G)I9VAE="!S:V%P82!F
M;&5R(.1N("5D(&)L;V-K+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3,V-R!L:6(O2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A<F4@;F]T
M(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(D1U(.1R(&EN=&4@875T96YT:7-E
M<F%D+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R
M"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I
M;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B1'4@:V%N(&EN=&4@86YVY&YD
M82`G7%PG(&D@9&ET="!N86UN(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T
M97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(D1U(&MA;B!I;G1E(&%N
M=N1N9&$@)UQ<)R!I(&1I='0@;F%M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@U.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW
M.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+B(*;7-G<W1R(")$=2!A;F=A=B!I;G1E(&5N(&=O9&OD;F0@92UP;W-T
M861R97-S+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,"!L:6(O
M2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL
M92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX."!L:6(O2&]R
M9&4O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N(@IM<V=S='(@(D1U(.1R('5T;&]G9V%D+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C4*;7-G
M:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B
M"B)$=2!MY7-T92!A;F=E(&5T="!G:6QT:6=T(&UO8FEL;G5M;65R.R!E;F)A
M<G0@<VEF9G)O<B!O8V@@971T("<K)R!F]G)E("(*(FEN=&5R;F%T:6]N96QL
M="!P<F5F:7@N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X."!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B1'4@86YG878@:6YT92!E='0@
M9V]D:^1N="!VY')D92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,S<@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RXB"FUS9W-T<B`B(@HB1'4@;>5S=&4@:V]N9FEG=7)E<F$@96X@
M1&%T851RY&1S+6MO<'!L:6YG(&;V<B!A='0@86YVY&YD82!R96=I<W1R97)I
M;F<B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0S-B!L:6(O2&]R
M9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N(@IM<V=S='(@(D1U(&WE<W1E(&MO;F9I9W5R97)A(&5N(%9&4RUK
M;W!P;&EN9R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q
M"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B1'4@
M;>5S=&4@8F5S:W)I=F$@<')O8FQE;65N+"!I;FYA;B!D=2!K86X@<F%P<&]R
M=&5R82!E='0@<')O8FQE;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B1'4@;>5S
M=&4@86YG92!E;B!54DP@<V]M(&SD;FME;B!P96MA<B!PY2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(D1U(&WE<W1E
M(&%N9V4@96X@<V5R=F5R('-O;2!S:V%L;"!R861E<F%S+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B1'4@;>5S=&4@86YG92!E='0@
M86YVY&YD87)N86UN('-O;2!S:V%L;"!R96YS87,N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+B(*;7-G<W1R(")$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A
M<FYA;6X@<V]M('-K86QL(')A9&5R87,N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@
M(D1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@;.1G
M9V%S('1I;&PN(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(D1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@=7!P
M9&%T97)A<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ,S@@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM
M<V=S='(@(D1U(&WE<W1E(&%N9V4@96X@Y71GY')D('-O;2!S:V%L;"!U=&;V
M<F%S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<Q"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T(&YY='0@:V%T96=O<FEN
M86UN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C<S"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA
M;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B1'4@;>5S=&4@86YG92!E='0@:71A
M;&EE;G-K="!T96QE9F]N;G5M;65R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<V(&QI8B](;W)D92]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(D1I;B`E<R!S97-S:6]N(&AA<B!U<'!H
M]G)T+B!687(@9V]D(&QO9V=A(&EN(&EG96XN(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S
M<R(*;7-G<W1R(")$:6X@92UP;W-T861R97-S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G
M<W1R(")$:6X@1G+E;CH@861R97-S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I
M9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")$:6X@:6YF;W)M871I;VXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D1I;B!I;G1E
M<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E9G1E<B!A='0@9'4@;&]G9V%T(&EN
M('1I;&P@)R5S)RX@1O9R(&%T="`B"B)S:WED9&$@9&EG+"!MY7-T92!D=2!L
M;V=G82!I;B!I9V5N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B1&ET="!N86UN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*
M(D1I;B!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E<B!I;G1E('5P<&SD
M9V<@878@86YVY&YD87)E+B!/;2!D=2!V:6QL("(*(F%N=N1N9&$@2&]R9&4@
M9O9R(&%T="!A9&UI;FES=')E<F$@86YVY&YD87)E('/E(&WE<W1E(&1U(&%N
M=N1N9&$@96X@86YN86X@(@HB875T96YT:7-E<FEN9W-K;W!P;&EN9RXB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB1&ET
M="!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E<B!I;G1E(&QI<W1N:6YG
M(&%V(&%N=N1N9&%R92P@96QL97(@<^4@Y'(@(@HB9G5N:W1I;VYE;B!A=G-T
MY&YG9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M(D1I;B!W96)B;.1S87)E+VEN=&5R;F5T861R97-S(&AA<B#D;F1R871S(&5F
M=&5R(&%T="!D=2!L;V=G870@:6X@=&EL;"`G)7,G+B`B"B)&]G(@871T('-K
M>61D82!D:6<L(&WE<W1E(&1U(&QO9V=A(&EN(&EG96XN(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B1&EN('=E8F)LY'-A
M<F4@<W3V9&5R(&EN=&4@9&5N(&CD<B!F=6YK=&EO;F5N+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B
M(@HB1&EN('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@=71S:W)I9G1S9G5N:W1I
M;VYE;BX@5')Y8VL@0W1R;"]/<'1I;VX@*R!0(&;V<B`B"B)A='0@<VMR:79A
M('5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(D1I;B!A:W1U96QL82!T
M:61S>F]N.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M(")$:6X@9O9R=F%L9&$@:61E;G1I=&5T(&AA<B#D;F1R871S+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I
M9&5N=&ET>3HB"FUS9W-T<B`B1&EN(&;V<G9A;&1A(&ED96YT:71E=#HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@
M;F%M93HB"FUS9W-T<B`B1&ET="!F=6QL<W3D;F1I9V$@;F%M;CHB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P(&QI8B](;W)D92]!=71H+G!H
M<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@
M(D1I;B!I;FQO9V=N:6YG(&AA<B!GY71T('5T+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B1&ET="!N>6$@
M;/9S96YO<F0@9O9R("5S(.1R.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,34T(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34T"FUS
M9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(D1I;F$@:6YS=.1L
M;&YI;F=A<B!H87(@=7!P9&%T97)A=',@9O9R(&1E;B!HY'(@<V5S<VEO;F5N
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N(@IM<V=S='(@(D1I;F$@:6YS=.1L;&YI;F=A<B!H
M87(@=7!P9&%T97)A=',N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS
M9W-T<B`B1&ET="!L]G-E;F]R9"!H87(@8FQI=FET(.5T97)S=.1L;'0B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@
M(B(*(D1I='0@;/9S;F]R9"!H87(@Y71E<G-TY&QL=',L(&MO;G1R;VQL97)A
M(&1I;B!E+7!O<W0@;V-H(&QO9V=A(&EN(&UE9"!D:71T("(*(FYY82!L]G-E
M;F]R9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(@;&EB+TAO
M<F1E+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B1&ET="!L]G-E;F]R9"!H87(@9^5T="!U="XB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@
M<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(D1I;F$@9FKD<G)S97)V<F%R.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S
M;&%V:6$B"FUS9W-T<B`B2G5G;W-L879I96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R(")::7!P
M>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+U1E>'0O5&5X="]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@
M5&5X=%TB"FUS9W-T<B`B6T?V;2!C:71E<F%D('1E>'1=(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS
M9W-T<B`B6T9E;')A<'!O<G1=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB
M"FUS9W-T<B`B6U9I<V$@8VET97)A9"!T97AT("TB"@HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z
M(&9R86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,38Y"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");5FES82!C:71E<F%D('1E>'0@
M+2`E<R!R861E<ETB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M,R!L:6(O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)A9"`E<R!A=B`E<UTB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T.3<@;&EB+TAO<F1E+G!H<#HQ-30U
M"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R871I;VXB"@HC.B!L:6(O
M87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,22(*"B,Z(&QI
M8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(E]$871A
M5'+D9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B7U)A
M9&5R82!R860B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B
M"FUS9W-T<B`B7T=R=7!P97(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3<U(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](
M96QP(@IM<V=S='(@(E](:N1L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B7T)I;&1I;G-TY&QL;FEN9V%R+BXN(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-"!L:6(O2&]R
M9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E],;V=G
M82!I;B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`@
M;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T
M<B`B7TQO9V=A('5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`BQ%]N9')A(&SD;FLN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38T(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G
M:60@(E]/<'1I;VYS(@IM<V=S='(@(E]);G-TY&QL;FEN9V%R(@H*(SH@;&EB
M+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7T)E
M:/9R:6=H971E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM
M<V=S='(@(E]482!B;W)T(&SD;FLN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*
M;7-G:60@(E]3971U<"(*;7-G<W1R(")?4V5T=7`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@
M(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]486)E;&QI;G-TY&QL
M;FEN9V%R+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B7T%N=N1N9&%R92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(Q(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B861R97-S8F]K(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*
M;7-G<W1R(")O:^1N9"!M;W1T86=A<F4B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDQ,R!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ-PIM<V=I9"`B
M8V%L96YD87(B"FUS9W-T<B`B:V%L96YD97(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0IM<V=I9"`B8V%L
M;2(*;7-G<W1R(")L=6=N="(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G
M<W1R(")K86X@:6YT92!S:V%P82!U=&9I;"(*"B,Z(&QI8B](;W)D92]-24U%
M+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS
M9W-T<B`B:V%N(&EN=&4@]G!P;F$@:6YD871A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DQ(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HU.3D*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B:VQI8VMA
M(&CD<B(*"B,Z(&QI8B]";&]C:R]B87)T:6UE+G!H<#HU-@IM<V=I9"`B8VQO
M8VLB"FUS9W-T<B`B:VQO8VMA(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS
M9W-T<B`B:V]M;6%N9&]R861S9F5L(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S
M='(@(FMO;F9I9W5R871I;VYS9F5L(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S
M:6YG(@IM<V=S='(@(FMR:71I<VL@<WES=&5M9FEL('-A:VYA<R(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M
M870@97)R;W(B"FUS9W-T<B`B9&%T869O<FUA=&9E;"(*"B,Z('1E;7!L871E
M<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`BY&YD
M<F$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@
M(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")P;W-T96X@:W5N9&4@:6YT92!H
M:71T87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")F86QL86YD92(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U,"!L:6(O2&]R9&4O0G)O
M=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S='(@(F9I;"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A<BYP:'`Z,S8W
M(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@
M(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B9G+E;B!D96X@
M)7,@*"5S*2!K;"`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B<W1O<FUB>6%R(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED
M(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS,S0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U
M;FMN;W=N(@IM<V=S='(@(F]KY&YD(';D<F1D871O<B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS
M9W-T<B`B9V5N87-T(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")I
M;FQI;F4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G
M:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")B96%R8F5T;FEN9W-F
M96PB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@
M(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(DEN=&5R;G0@87!P
M;&EK871I;VYS9F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")R861E<ETB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3,*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+VUK:7-O9G,N
M<&AP.C4T(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H
M<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+B(*;7-G<W1R(")F96QK;V0@)60@9G+E;B!M:VES;V9S(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,T-0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED
M(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,CDP(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C@U"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M96YU+G!H<#HR,3(@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q
M"FUS9VED(")N86UE(@IM<V=S='(@(FYA;6XB"@HC.B!F<F%M97=O<FLO4E!#
M+U)00RYP:'`Z,3(Q(&QI8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B;F]T
M(&EM<&QE;65N=&5D(@IM<V=S='(@(FEN=&4@:6UP;&5M96YT97)A9"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.2!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M
M96YT960B"FUS9W-T<B`B:6YT92!I;7!L96UE;G1E<F%D(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4@;&EB+TAO<F1E+TMO;&%B+G!H<#HY
M,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B86YT96-K;FEN9W-B;&]C:R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<')O8V5N="(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO
M;B!D96YI960B"FUS9W-T<B`BY71K;VUS="!N96MA9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@
M(G!I>&5L<R(*;7-G<W1R(")P:7AL87(B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O
M;"(*;7-G<W1R(")P<F]T;VMO;&QF96PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B<FES:6YG(@IM<V=S='(@
M(G-T:6=A;F1E(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R
M"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(E1JY&YS=&5N
M(.1R(&5J('1I;&QGY&YG;&EG(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B=FES82!S
M:VEL;&YA9&5R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,30*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M
M<S)E;6%I;"!V:6$@2%144"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-C$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<W1E
M861Y(@IM<V=S='(@(G-T861I9W0B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")S>7-T
M96UF96PB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.2!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@
M(G5P<&=I9G1S;&ES=&$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(G1I;&QF
MY&QL:6=T(&9E;"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*(SH@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FTB"FUS9W-T<B`B86YG92!L]G-E;F]R9&5T('1VY2!GY6YG97(@
M9O9R(&%T="!B96MRY&9T82(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S
M='(@(F5N860B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W
M(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM
M<V=S='(@(FYA;6YL]G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B86YVY&YD87)V
M86PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,S4@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B
M=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(T"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM<V=S='(@(G<Z(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N
M8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P;R]T<E]44BYP;P``````````````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S(P,C<T`#$P-#$W,S8S,#`S`#`Q-C0S
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M(%1U<FMI<V@@=')A;G-L871I;VYS(&9O<B!(;W)D92!P86-K86=E"B,@2&]R
M9&4@<&%K971I(&GG:6X@5/QR:^=E(,=E=FER:6QE<BX*(R!#;W!Y<FEG:'0@
M*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB
M=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K
M86=E+@HC($=E;F5R871E9"!B>0HC(%-E<G9E="!'_&YE>2`\<V=U;F5Y0&UE
M='4N961U+G1R/@HC($%H;65T(-9Z=/QR:R`\;V%H;65T0&UE='4N961U+G1R
M/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D978S+C`N-%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#8M,C@@
M,30Z-#@K,#,P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!!=71O;6%T:6-A;&QY
M(&=E;F5R871E9%QN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D
M92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM.5QN(@HB0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU
M<F%L<STQ.R!P;'5R86P],#M<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB
M"FUS9W-T<B`B("@E<R!G_&X@]FYC92DB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K
M97D@)7,I(@IM<V=S='(@(BA%<FG^:6T@06YA:'1A<OT@)7,I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H)7,@9_QN9&4I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS
M9W-T<B`B("AB=6?\;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*'EA<OUN*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R
M9&%Y*2(*;7-G<W1R("(@*&3\;BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T
M("(*;7-G<W1R("(@9&4H9&$I("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C$U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")$:7II;B!D9?!I;"(*"B,Z
M(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S
M='(@(B<E<R<@:7,@9V7G97)L:2!B:7(@<V7G96YE:R!D9?!I;"XB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@2&]R9&4@2V%Y
M_71L87+];F1A('EA</UL86YD_7+];&UA;?W^+B(*"B,Z(&9R86UE=V]R:R]4
M<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(G)7,G
M(&'P8><@YV5V:7)I8VES:2!B=6QU;F%M863]+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@
M9W)U<"!S:7-T96UI;F4@96ML96YD:2XB"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B)R5S)R!I>FEN('-I<W1E;6EN92!E:VQE;F1I+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D
M.B`E<RXB"FUS9W-T<B`B)R5S)WEA<F%T_6QA;6%D_3H@)7,B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR
M9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@=F4@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UG_&YL
M_&L@:&%V82!T86AM:6YI(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(B5S("T@0FEL9&ER:6TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN
M="(*;7-G<W1R("(E<R!087)M86L@W7II(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G
M<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S($)A:_UM(-W^;&5M;&5R:2`M
M($]N87EL86UA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-E='5P(@IM<V=S='(@(B5S($%Y87)L87(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-I9VX@57`B"FUS9W-T<B`B)7,@1VER:?XB"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@
M;V8@06=R965M96YT(@IM<V=S='(@(B5S($%N;&'^;6$@2V_^=6QL87+](@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S('IA
M=&5N('9A<BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E
M<R!D92`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B)'
M97+G:V7^=&ER:6QM97-I;FD@:7-T961I\&EN:7H@:?YL96UL97(@:>=I;B!O
M;F%Y(&MU='5L87+];OT@:?YA<F5T;&5Y:6XN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R
M97%U:7)E9"(*;7-G<W1R("(E<R!I<W1E;FUE:W1E9&ER+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI
M;G5T97,B"FUS9W-T<B`B)7,@9&%K:6MA(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&)U;'5N86UA9/TN(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R`M("5S("\@)7,@
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B)7,@061R
M97,@1&5F=&5R:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B
M)7,@5&%K=FEM(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S
M($YO="!$969T97)I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R
M("(E<R!']G)E=B!,:7-T97-I(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F
M<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG
M("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E
M<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"B,L(&9U>GIY"FUS9VED("(L(&=U<W1I
M;F<@(@IM<V=S='(@(BP@9OUR=/UN86S]("5S("5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@9OUR
M=/UN86S]("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM
M<V=S='(@(BP@9&7P:?YI;2`E<R`M/B`E<R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS
M9W-T<B`B+2T@4V7G("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS
M9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,B!386%T;&EK(%IA;6%N
M($)IYVEM:2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@
M2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@4V%A=&QI:R!:86UA;B!":>=I;6DB
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U
M<G,B"FUS9W-T<B`B,C0@<V%A="(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("+6
M;F-E:VD@4V%Y9F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I
M9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L
M;V-K+B(*;7-G<W1R(")"=2#V8F5K(&GG:6X@=F5R:71A8F%N_2!S;VX@=7IA
M;G3]<_T@9V5R96MM96MT961I<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`B3VYU;&UA>B!B:7(@:&%T82!O;'7^='4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(MUL971I>6D@_FEF<F5L97EE8FEL;65K(&GG:6X@4$=0(&'G_6L@86YA
M:'1A<OT@9V5R96MM96MT961I<BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B
M"B+=;7IA;&%N;?W^(&EL971I>6D@9&_P<G5L=?!U;G4@<V'P;&%M86L@:>=I
M;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E:VUE:W1E9&ER+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B+=;&5T:6YI;B#^:69R97-I;FD@Y_9Z;65K(&GG:6X@8>?]:R!01U`@
M86YA:'1A<OTL]GIE;"!01U`@86YA:'1A<OT@=F4@9V7G:?X@(@HB=/QM8V5C
M:?!I(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(MUL971I>6D@:6UZ86QA
M;6%K(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE;"!01U`@86YA:'1A<OT@
M=F4@9V7G:?X@(@HB=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"B+=;&5T:6YI;B#^:69R97-I;FD@Y_9Z;65K(&GG:6X@
M8>?]:R!3+TU)344@86YA:'1A<OTL(/9Z96P@4R]-24U%(&%N86AT87+]('9E
M("(*(F=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS
M9W-T<B`B(@HBW6QE=&EY:2!I;7IA;&%M86L@:>=I;B!AY_UK(%,O34E-12!A
M;F%H=&%R_2P@]GIE;"!3+TU)344@86YA:'1A<OT@=F4@9V7G:?X@(@HB=/QM
M8V5C:?!I(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BW6QE
M=&EY:2#^:69R96QE>65B:6QM96L@:>=I;B!AY_UK(%--24U%(&%N86AT87+]
M(&=E<F5K;65K=&5D:7(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S
M='(@(D)U;'5T;&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS
M9W-T<B`BUE,@2&%F:68@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B
MUM8@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`BUM8@4V'P;F%K
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*
M;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("+6UB!(869I9B!+87(B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB
M"FUS9W-T<B`BUM8OUE,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!
M4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")$_'IE
M;FQE>6EC:2!H86MK_6YD82(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")(86MK_6YD82XN+BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS
M9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B16YA;'0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D
M;&4B"FUS9W-T<B`B3W)T87EA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@9&EZ:6YI('EA<F%T_7)K96X@97)I
M_FEM(&5N9V5L;&5N9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92XB"FUS9W-T<B`B5D93(&1I>FEN:2!Y87)A=/UL_7)K96X@97)I_FEM(&5N
M9V5L;&5N9&DN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z
M>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B0FEL9VEL
M97)I;FEZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!
M8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DAE<V%P(%!A<F%L;W/](@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS
M"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B2&5S87`@1&]N9'5R
M=6QD=2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED
M(")!8V-O=6YT:6YG(@IM<V=S='(@(DAE<V%P;&%N_7EO<B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(D5K;&4B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D
M($-H:6QD($=R;W5P(@IM<V=S='(@(D%L="!'<G5P($5+;&4B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM
M<V=S='(@(D%L="#=>FEN($5+;&4B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D
M9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D)U<F%Y82!%:VQE
M.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(EEE;FD@1W)U<"!%
M:VQE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B665N:2#=>FEN($5K;&4B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS
M9W-T<B`B06QT(&=R=6)U("<E<R<@:>=I;F4@96ML92(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G
M<W1R("(G)7,G(/QZ97)I;F1E(&%L="!I>FEN(&5K;&4B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(EEE
M;FD@:W5L;&%N_6/](&5K;&4Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R
M(")+;VQO;B!%:VQE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(EEE;FD@
M_'EE(&5K;&4B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS
M9VED(")!9&0@<&%I<B(*;7-G<W1R("+=:VEL:2!%:VQE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B)7,@
M365N_'/\;OP@36]Z:6QL82!+96YA<B#'=6)U\'4@3VQA<F%K($5K;&4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G
M:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%D<F5S(&1E9G1E
M<FEN92!E:VQE.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G
M<W1R(")!9')E<R!D969T97)I;64@96ML92(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")+=6QL86[]8_T@16ML92(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD
M(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S
M+B(*;7-G<W1R("(G)7,G('-I<W1E;64@96ML96YD:2P@86UA(&AE<FAA;F=I
M(&5K(&)I<B!G:7)I_B!B:6QG:7-I(&5K;&5N96UE9&DZ("5S(@H*(SH@<VEG
M;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS
M9W-T<B`B)R5S)R!S:7-T96UE(&5K;&5N9&DN(-YI;61I(&=I<FG^('EA<&%B
M:6QI<G-I;FEZ+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(DMU;&QA;OUC_2!E:VQE;64@<V7G:6QE;65Z(&O];/UN9/TN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B
M061R97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED
M(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97,@1&5F=&5R:2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!
M9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*
M;7-G<W1R(")9]FYE=&EM+2U$:?!E<B!K=6QL86[];&%R(&GG:6X@:7II;FQE
M<FD@8F5L:7)L97EI;B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")9]FYE=&EM(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,T,0IM<V=I9"`B061S(@IM<V=S='(@(D%D<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%R;F%V=71L=6LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D-E>F%Y:7(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS
M9VED(")!;&EA<R(*;7-G<W1R("+6=&5K:2!A9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L
M:6=N(@IM<V=S='(@(DAI>F%L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T
M<B`B2&EZ86QA;6%K.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(E3\;?PB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U
M"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")4_&T@
M1&_P<G5L86YM_?X@2W5L;&%N_6/];&%R(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*
M;7-G<W1R(")4_&T@1W)U<&QA<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H
M<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E3\;2#=>FEN
M;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B5/QM
M(&3V<G0@>?QZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM
M<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(L=O:VQU
M(&%D<F5S;&5R92!I>FEN('9E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_(@IM<V=S='(@(E/]<F%L86YM_?X@;&ES=&4@=/QR_&[\(&%Y87)L86UA
M>6$@:7II;B!V97)I;'-I;B!M:3\B"@HC.B!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(EIA=&5N('9A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(M9T96MI
M($E-4U`@1VER:?YI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM
M<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`BUG1E:VD@
M24U34"!087)O;&%S_2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*
M;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(M9T96MI
M($E-4U`@2W5L;&%N_6/]($%D_2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G
M<W1R("+6=&5K:2!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S
M(@IM<V=S='(@(M9T96MI('1A<VQA:VQA<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B
M06QT97)N871E('1E>'0Z(@IM<V=S='(@(M9T96MI(&UE=&EN.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M97)I:V%N
M(%-A;6]A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")'9>=E<G-I>B!D
M9?!E<B!B96QI<G1I;&1I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S
M(&]C8W5R960N(@IM<V=S='(@(F)I<B!H871A(&]L=?YT=3HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0
M<F]X>2(*;7-G<W1R(")!;F]N:6T@4')O>'DB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(D-E=F%P
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A
M<G1I:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A
M(@IM<V=S='(@(D%N=&EG=6$@=F4@0F%R8G5D82(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B57EG
M=6QA;6$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P
M<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B57EG=6QA;6$@3&ES=&5S:2(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N
M(&ES(')E861Y+B(*;7-G<W1R(")5>6=U;&%M82!(87K]<B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL
M9"!3:&%R97,B"FUS9W-T<B`B06QT('!A>6QA_OUM;&%R82!U>6=U;&$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B
M07!P<F]V92(*;7-G<W1R(")/;F%Y;&$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B
M"FUS9W-T<B`B66%K;&'^_6L@0F]Y=70B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B
M3FES86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A
M8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R87#G82`H5VEN9&]W<RTQ
M,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!
M<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")"96QG96QI:R!$;W-Y82!"=7EU
M='4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C
M:&EV92!.86UE(@IM<V=S='(@(D)E;&=E;&EK($%D_2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B)7,@:>=I;B!G:7)I
M_B!I<W1E\&EN:2!K86QD_7)M86L@:7-T961I\&EN>F4@96UI;B!M:7-I;FEZ
M/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S
M='(@(B<E<R<@=F4@=/QM(&%L="!G<G5P;&%R_6[]('-I;&UE:R!I<W1I>6]R
M(&UU<W5N=7H_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S
M='(@(D%R:F%N=&EN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G
M<W1R(")%<FUE;FES=&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*
M;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D5R;65N:6-E
M("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS
M9VED(")!<G0B"FUS9W-T<B`B4V%N870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B07-C
M96YS:6]N($%D86QA<OTB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*
M;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<V-I:2!386YA=/TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C
M:69I8R!296=I;VXB"FUS9W-T<B`B07-Y82]087-I9FEK($+V;&=E<VDB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\B"FUS9W-T<B`B0F%K_6T@:?YL96UL97)I;F1E;B#V;F-E(&1O\')U;&%M
M82!S;W)U;'-U;B!M=3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B071A;6$@
M2V]L;VYL87+](@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@
M(E9A<B!O;&UA>6%N(&)I<B!G<G5B=2!S:6QM92!G:7)I_FEM:2XB"@HC.B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")687(@
M;VQM87EA;B!B:7(@:7IN:2!S:6QM92!G:7)I_FEM:2XB"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E9A<B!O;&UA>6%N(&)I
M<B!G<G5B=2!D_'IE;FQE;64@9VER:?YI;6DN(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E9A<B!O;&UA>6%N(&)I<B!P87EL
M8?[];?T@9/QZ96YL96UE(&=I<FG^:6UI+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(M9Z;FET
M96QI:VQE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B0?!U<W1O<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=G5S='5R86QY82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B079U<W1U<GEA
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I
M9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ(-US=&5N96X@:6UA<"!U>F%T
M873]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C
M>7)U<SH@W7-T96YE;B!Y971E;F5K;&5R92!S86AI<"!D9?!I;"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?
M8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]C>7)U<SH@W7-T96YE;B!I;6%P('5Z86YT_7/](&)U;'5N
M86UA9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS
M9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S
M=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B#=<W1E;F5N($944"!U>F%N
M=/US_2!B=6QU;F%M863]+B!02%`G>6D@+2UE;F%B;&4M9G1P('-W:71C:"`B
M"B)D9?!I_G1I<F=E<VEY;&4@9&5R;&5Y:6XN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA
M<#H@W7-T96YE;B!)34%0('5Z86YT_7/](&)U;'5N86UA9/TN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?:W)B-3H@W7-T96YE;B!K<F(U('5Z86YT_7/](&)U;'5N86UA9/TN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@
M(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B#=<W1E;F5N($Q$05`@
M=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?:6UA<#H@)7,@:W5L;&%N_6/]<_T@
M96ML96YE;65D:2X@4W5N=6-U.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z
M("5S(&MU;&QA;OUC_7/]('-I;&EN96UE9&DB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H
M7VQD87`Z("5S(&MU;&QA;OUC_7/](&?\;F-E;&QE;F5M961I(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A
M<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@W7-T
M96YE;B!-0T%,('5Z86YT_7/](&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E
M<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]S;6)A=71H.B#=<W1E;F5N('-M8F%U=&@@=7IA;G3]<_T@8G5L=6YA
M;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G
M<W1R(")$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G
M<W1R(")$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B1&_P
M<G5L86UA(%)!1$E54R!S=6YU8W5S=2!T87)A9OUN9&%N(&=E<FD@YV5V<FEL
M9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")&5%`@<W5N=6-U<W5N82!D;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ>0IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R(")&5%`@<W5N=6-U<W5N82!D;_!R=6QA;6$@8F'^87+]<_UZ(&]L
M9'4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B
M079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B2W5L;&%N_6S]<B!A;&%N;&%R
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE
M<F)A>6-A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B
M0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@0>?]:VQA;6%L87+](@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")!<G1A;&%N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B
M0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")!<G1A;&%N(%)E;F=I(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME
M<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")+]G3\(&ME<F)E<F]S('!A<F]L
M87/]+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G
M:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B2_9T_"!K97)B
M97)O<R!K=6QL86[]8_T@863]+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M
M87,B"FUS9W-T<B`B0F%H86UA;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H
M<F%I;B(*;7-G<W1R(")"86AR97EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A
M;'3]:R`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA
M9&5S:"(*;7-G<W1R(")"86YG;&%D9?XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M5&%B86X@9W)A9FEK(&1I>FEN:2`G)7,G(&)U;'5N86UA9/TN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS
M9VED(")"87-E;&EN92(*;7-G<W1R(")486)A;B#G:7IG:7-I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")"97EA>B!2=7-Y82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5LYVEK82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T
M:&1A>2(*;7-G<W1R(")$;_!U;6?\;OPB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")5>6=U;&%M82!<(B5S7"(@<V%H:7`@;VQD=?!U(%PB)7-<
M(B#V8F7P:2!B=6QU;F%M863]+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`BUF)E
M:R!!>6%R;&%R_2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW
M-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("+68F5K(%3\<OPB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@
M(D)O;&0B"FUS9W-T<B`B2V]Y=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV
M:6$B"FUS9W-T<B`B0F]L:79Y82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")997(@W6UL97)I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(E/];OUR(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B
M0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4_UN_7(@2V%L_6YL_?#].B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B4_UN_7)L87(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@
M(D)O<VYA($AE<G-E:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM
M<V=I9"`B0F]T:"(*;7-G<W1R(")(97(@26MI<VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=F%N82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B
M0F]T=&]M(@IM<V=S='(@(D%L="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E
M="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T($%D86QA<OTB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)E>FEL>6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S
M='(@(D)R:71A;GEA($AI;G0@3VMY86YU<W4@0O9L9V5S:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FES
M=&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R(")-861D92#=;6QI
M($QI<W1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S
M='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB
M"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-#0*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T
M<B`B0U)3(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D-2
M3"!$8?#]=/UM($YO:W1A;&%R_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")?2/QC<F4@UGIE;&QI:VQE<FDN+BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"B,L(&9U>GIY"FUS
M9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(")$
M8?#]=/UM(&QI<W1E<VD@8F5L:7)L96YE;65D:2XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM
M<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B5&%K=FEM(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R(")$
M=7)G=6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B
M2V%M8F_G>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R
M(")+86UE<G5N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*
M;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E!A<F]L
M82#V>F1E=FEN:6UL:2!O;&%R86L@<_UF_7)L86YA;6%M86MT863]<BP@;/QT
M9F5N('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BXB"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB
M(&1O<WEA<_T@<VEL:6YE;65D:2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H
M86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0
M('-E<G9E<CH@)7,B"FUS9W-T<B`B24U!4"!S=6YU8W5S=6YA(&)A\&QA;OUL
M863].B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&1O<WEA<_T@<VEL:6YE;65D:2XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BW7!T86PB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N
M8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-O<G5N(%)A<&]R=6YU(-UP
M=&%L($5T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B7"(E<UPB(&1O<WEA<_T@<VEL:6YE;65D:2XB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")'
M9>=I8VD@9&EZ:6X@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E
M9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B=T
M87)G971&:6QE)R!D9?!I_G1I<F=E<VD@;VQM861A;B!D979A;2!E9&EL96UE
M>BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(EPB)7-<(B!D:7II;FD@:V%L9/UR_6QA;6%D_2XB"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S
M='(@(DMA;&3]<OUL86UA9/T@+"5D(&%L="!Y87#]('9A<BXB"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*
M(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*
M;7-G<W1R("(B"B)996YI9&5N(&3\>F5N;&5M961I+"!Y96YI9&5N(&3\>F5N
M;&5M92!IYVEN('-A\&QA;F%N(&MA>?UT;&%R_6X@<V%Y_7/](&EL92`B"B)D
M97!O;&%N;?W^(&]L86YL87+];B!S87G]<_T@9?YL9?YM96UE:W1E9&ER+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BXB"FUS9W-T<B`B0F5L:7)T:6QM:?X@;G5M87)A>6$@:6QE=&D@
M>?9N;&5N9&ER:6QE;65D:2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E
M<F1E(@IM<V=S='(@(D-A<&4@5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N
M(@IM<V=S='(@(D)A_FS]:R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I
M97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R:6QE<B!V92!%=&EK971L
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T
M<B`B0V%Y;6%N($%D86QA<OTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@
M(D-E<"!496QE9F]N=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*
M;7-G<W1R(")(_&-R92#6>F5L;&EK;&5R:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I
M;F<Z(@IM<V=S='(@(DC\8W)E('EA<W3]:VQA;6%S_3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED
M(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B2/QC<F4@UGIE;&QI:VQE<FDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")(_&-R92!";_YL=6ML
M87+].B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G:60@
M(D-E;&QP:&]N92(*;7-G<W1R(")#97`@5&5L969O;G4B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB
M"FUS9W-T<B`B2V5L=&EK("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#
M96YT97(B"FUS9W-T<B`B3W)T82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R
M86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")/<G1A($%F<FEK82!#=6UH
M=7)I>65T:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")/<G1A($%V
M<G5P82`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G
M<W1R(")/;F%Y($)E;&=E<VD@07ER_6YT_6QA<OTB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0HC+"!F=7IZ>0IM<V=I9"`B0V5R
M=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B3VYA>2!"96QG97-I($%Y<OUN=/UL
M87+](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*
M;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(D]N87D@0F5L
M9V5S:2!+=7)A;&QA<OTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS
M9W-T<B`BQV%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E
M(@IM<V=S='(@(D1E\&G^=&ER(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R
M9"(*;7-G<W1R(")087)O;&%N_7K]('/]9OUR;&%Y_6XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A
M;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B+=;G-A;FQA
M<OUN('-I>F1E;B!G96QE;B!E;&5K=')O;FEK('!O<W1A;&%R_2!O:W5R:V5N
M('9E(&-E=F%P;&%R:V5N("(*(F?V<F3\:VQE<FD@860@=F4@861R97-I;FEZ
M:2!D9?!I_G1I<FEN+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*
M(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W
M"FUS9VED(")#:&%R(@IM<V=S='(@(DMA<F%K=&5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED
M(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")"8?!L86YT_7G]($1E7VYE=&QE
M+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`BWFEL:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(L=I;B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BDB"FUS9W-T<B`B0F%S:71L9?YT:7)I;&UI_B#':6YC92`H
M1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#
M:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")'96QE;F5K<V5L
M(,=I;F-E("A":6<U*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E!A
M<F]L82!S9>=I;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(DMU;&QA
M;OUC_2!A9/T@<V7G:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX
M"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@
M(E1A<FEH;&5R:6X@;F%S_6P@9_9S=&5R:6QE8V7P:6YI('-EYVEN.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E
M<F5D(&QI<W1S*2(*;7-G<W1R("),:7-T92!":>=E;2!4_'+\;OP@4V7G:6X@
M*'/]<F%L86YM_?X@;&ES=&5L97(@:>=I;BDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(D-H<FES=&UA<R!!9&%L87/]
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B4_UN_68@=&%N
M_6W](&)U;'5N86UA9/TZ)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B5&5M:7IL
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B35-/9F9I
M8V4@8FGG:6T@:6UL97)I;FD@=&5M:7IL92(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@
M(DMU;&QA;OUC_2!T96UI>FQE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S
M97(Z("5S(@IM<V=S='(@(DMU;&QA;OUC_7G]('1E;6EZ;&4Z("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A
M<B!U<V5R(@IM<V=S='(@(DMU;&QA;OUC_2!T96UI>FQE(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@
M9&%T82(*;7-G<W1R(")+=6QL86[]8_T@=F5R:7-I('1E;6EZ;&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0HC+"!F=7IZ
M>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")'9><@4V%A=&QE<F1E
M(%EA\&UU<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")$
M979A;2!E=&UE:R!IYVEN('3]:VQA>?UN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T
M96QL('9I82!(5%10(@IM<V=S='(@(DA45%`@>6]L=7EL82!#;&EC:V%T96QL
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M4&5N8V5R97EI($MA<&%T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*
M;7-G:60@(D-L;W5D<R(*;7-G<W1R(")"=6QU=&QA<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"B,L(&9U>GIY"FUS9VED
M(")#;&]U9',@16%R;'DB"FUS9W-T<B`B0G5L=71L=2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB
M"FUS9W-T<B`B0G5L=71L=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+
M965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(D-O8V]S($%D86QA<OTB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S
M92!3:61E8F%R(@IM<V=S='(@(DME;F%R(,=U8G7P=6YU($1A<F%L="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(D1A<F%L=/UL
M;?W^(%/];OUR;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS
M9W-T<B`B2V]L;VUB:7EA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S
M='(@(E)E;FLB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS
M9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4F5N:R!39>=I8VDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L
M96-T:6]N(@IM<V=S='(@(E)E;FL@4V7G:6UI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM
M<V=S='(@(DMO;&]N;&%R.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B2V]L;VX@0F'^
M;/UK;&%R_2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G
M:60@(D-O;6EC<R(*;7-G<W1R(")+;VUI:R(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")+;VUU="(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G
M<W1R(")+;VUU="!+86)U\'4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B0>?]:VQA;6$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I
M9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3W)T86L@063](@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B0V]M;W)O<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O
M;7!A;GDB"FUS9W-T<B`BWFER:V5T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B0FEL9VES87EA<FQA
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z
M>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")+;_YU;&QA<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S
M='(@(DMO_G5L;&%R(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G
M:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B66%P_6QA
M;F3]<FUA($9A<FML87+](@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L
M(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U
M<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")987#];&%N9/UR;6%N
M_6X@9_QN8V5L;&5N;65S:2!G97)E:VUE:W1E9&ER+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG
M=7)E("5S(@IM<V=S='(@(EEA</UL86YD_7(Z)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W
M;W)D(@IM<V=S='(@(E!A<F%L;WG]($1O\')U;&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@
M(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T
M<B`B1&5M;VMR871I:R!+;VYG;R!#=6UH=7)I>65T:2(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I
M;VX@9F%I;&5D+B(*;7-G<W1R(")"8?!L86YT_2!B8?YA<OUS_7H@;VQD=2XB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(D)A\&QA;G3](&)A
M_F%R_7/]>B!O;&1U.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")!Y_UK(&%N86AT87(@<W5N=6-U<W5N
M82!B8?!L86YT_2!R961D961I;&1I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*2(*;7-G<W1R(")!Y_UK(&%N86AT87(@<W5N=6-U<W5N82!B8?!L
M86YT_2!R961D961I;&1I+B!396)E8CH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@<W5N=6-U;F$@8F'P;&%N
M=/T@8F'^87+]<_UZ(&]L9'4N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(MUL971I_FEM(&YO:W1A;&%R_2!B8?YA<OUY;&$@861R
M97,@9&5F=&5R:6YI>F4@96ML96YD:2XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N
M=',@;V8@7"(E<UPB(@IM<V=S='(@(MWG97)I:SH@)R5S)R(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B1&5V86TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:R!!
M9&%L87+](@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#
M;V]K:64B"FUS9W-T<B`BQV5R97HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS
M9W-T<B`B2V]P>6%L82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B0F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B
M0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B4V7G:6UI($MO<'EA;&$B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S
M="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A
M(@IM<V=S='(@(DMO<W1A(%)I:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E
M(&0G279O:7)E(@IM<V=S='(@(D-O=&4@9"=)=F]I<F4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!0
M1U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("+=;&5T:2!01U`@:6QE(/YI
M9G)E;&5N96UE9&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(MUL971I(%!'4"!I;&4@:6UZ86QA;F%M863]+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`BW6QE=&D@4R]-
M24U%(&EL92!S:69R96QE;F5M961I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I
M9VX@;65S<V%G92XB"FUS9W-T<B`BW6QE=&D@4R]-24U%(&EL92!I;7IA;&%N
M86UA9/TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D
M9"!C;VYT86-T+B`E<R(*;7-G<W1R("+=;&5T:?YI;2!N;VMT87/](&5K;&5N
M96UE9&DN("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4"!S
M=6YU8W5S=6YA(&)A\&QA;OUL86UA9/TN(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M;&1A<"!S97)V97(B"FUS9W-T<B`B3$1!4"!S=6YU8W5S=6YA(&)A\&QA;OUL
M86UA9/TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")"86MI>64@9&5N971L96YE
M;65D:2X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*
M;7-G<W1R(")334(@<W5N=6-U<W5N82!B8?!L86YT_2!B8?YA<OUS_7HN(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB
M('5S:6YG($944#H@)7,B"FUS9W-T<B`B)R5S)R!S=6YU8W5N82!&5%`@>6]L
M=7EL82!B8?!L86[];&%M863].B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(D1A\/UT_6T@;&ES=&5S:2!Y87)A=/UL86UA9/TN("5S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(E!'4"!V97)I<VEN
M:6X@_FEF<F5S:2#G]GK\;&5M961I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82XB"FUS9W-T<B`B4R]-24U%('9E<FES:6YI;B#^:69R97-I
M(.?V>OQL96UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("+=;&5T:?YI;2!N;VMT
M87/]('-I;&EN96UE9&DN("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B1&'P_73];2!L:7-T97-I('-I;&EN96UE9&DN("5S(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E
M<UPB+B(*;7-G<W1R(")!>6%R(&?\;F-E;&QE;64@8F5T:?!I("<E<R<@<VEL
M:6YE;65D:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B
M0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D
M9')E<W,N(@IM<V=S='(@(D%L_6/];OUN(&5L96MT<F]N:6L@<&]S=&$@861R
M97-I(&)E;&ER;&5N96UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D%D<F5S(&1E9G1E
M<FD@=&%M86UE;B!G971I<FEL96UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B
M1&'P_73];2!L:7-T97-I('1A;6%M96X@9V5T:7)I;&5M961I+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(")$8?#]=/UM(&QI<W1E;&5R:6YI
M;B!L:7-T97-I('1A;6%M96X@9V5T:7)L96UE9&DN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R
M(")3=')A=&5J:2`G)7,G('G\:VQE;F5M961I+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G
M<W1R(")M:V1I<B`G)7,G(&)A_F%R_7/]>B!O;&1U+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B
M=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M06YA:'1A<B!S=6YU8W5S=6YD86X@8>?]:R!A;F%H=&%R(&5D:6YI;&5M961I
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB
M"FUS9W-T<B`B)R5S)R!Y87K];&UA:R!IYVEN(&'G_6QA;6%D_2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S
M='(@(B5S(&'G_6QA;6%D_2XB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R
M(")-86EN=&5N86YC95]487-K(&)I<FEM:2`E<R!AY_UL86UA9/TN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(G
M)7,G(&1I>FEN:2!AY_UL86UA9/TN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R
M=F5R+B(*;7-G<W1R("),1$%0('-U;G5C=7-U(&%R86YA;6%D_2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B)7,@;VMU;F%M
M863]+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED
M("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@HBW7-T96YE;B!K=6QL86YC_2!IYVEN('!A<F]L82!S_6;]<FQA;F%M
M863]+B!"87K]('EA9&$@=/QM(&%Y<OUN=/UL87(@9&_P<G4@(@HB9&7P:6PN
M(%EE;FED96X@9&5N97EI;B!Y861A(&1A:&$@9F%Z;&$@>6%R9/UM(&GG:6X@
M<VES=&5M('GV;F5T:6YI>FQE("(*(F?V<OS^_&XN(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E($%#3"(*;7-G<W1R(")!0TP@97)I_FEL96UE9&DN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O
M:RX@)7,B"FUS9W-T<B`B061R97,@9&5F=&5R:6YE(&5R:?YI;&5M961I+B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B1&'P_73];2!L:7-T
M97-I;F4@97)I_FEL96UE9&DN("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B
M"FUS9W-T<B`B1&'P_73];2!L:7-T96QE<FEN92!E<FG^:6QE;65D:2X@)7,B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*
M;7-G<W1R(")3=6YU8W5N=6X@>65T96YE:VQE<FEN92!E<FG^:6QE;65D:2XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(EEA</UL86YD_7)M
M82!G97)I(&3V;F3\<OQL96UE9&DN+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER
M(%PB)7-<(BXB"FUS9W-T<B`B<FUD:7(@)7,@YV%L_?YT_7+];&%M863]+B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B5S('EA</UL86YD_7)M82!K87ED961I;&5M961I+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+B(*;7-G<W1R(")9961E:R!B:7(@>6%P_6QA;F3]<FUA(&MA>61E9&EL96UE
M9&DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,B"FUS9W-T<B`B665D96L@8FER('EA</UL86YD_7)M82!K87ED961I
M;&5M961I.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")!>6%R(&?\
M;F-E;&QE;64@8F5T:?!I(&MA>61E9&EL96UE9&DZ("<E<R<N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RXB"FUS9W-T<B`B665D96L@>6%P_6QA;F3]<FUA(&1O<WEA<_T@)7,@:V%Y
M9&5D:6QE;65D:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@
M=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R
M(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@
M(B(*(EEA</UL86YD_7)M82!D;W-Y87/]("5S(&MA>61E9&EL96UE9&DN($)U
M(&1U<G5M9&$L(&MO9'4@=&5K<F%R("5S(&GG:6YE("(*(FMA>61E=&UE:R!Y
M861A('1A:VEP(&5D96X@:V]D=2!E;"!I;&4@)7,@:>=I;F4@:V]P>6%L86UA
M:RP@<V7G96YE:VQE<FEN:2`B"B)K=6QL86YA8FEL:7)S:6YI>BXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@<W5N
M=6-U<W4@87)A;F%M863]+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S
M7"(N(@IM<V=S='(@(D)A\"#G]GK\;&5M961I.B`G)7,G+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`BW6QE=&G^:6T@;F]K=&%S_2!G_&YC96QL96YE;65D:2X@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")$8?#]=/UM(&QI<W1E<VD@
M9_QN8V5L;&5N96UE9&DN("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I
M=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(G)7,G
M(&GG:6X@>6%P_6QA;F3]<FUA('EA>OUL86UA9/TZ("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B(@HB36]Z:6QL82!K96YA<B#G=6)U\'4@8G5L=6YA;6%D
M_2X@2V5N87(@YW5B=?!U;G5N(&'G_6L@;VQD=?!U;F1A;B!E;6EN(&]L=6XN
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E
M('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B)R5S)R!D:7II;FD@:>=I;B`G)7,G
M(&MU;&QA;OUC_7/]('1A:VEP(&5D96X@:&%K;&%R_2!V97)E;65D:3H@)7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N
M=&5D('1E>'0B"FUS9W-T<B`B4V%Y_6QM_?X@;65T:6XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*
M;7-G<W1R("+<;&ME(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W
M,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")$97)S;&5R(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B66%R870B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@
M(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0F'P;&%N=/T@>6%R870B"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#
M<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(EEE;FD@66%R870B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E
M871E('-U8B!F;VQD97)S(@IM<V=S='(@(D%L="!D:7II;B!Y87)A="(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A
M=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(EEA<F%T_6/](-UZ:6YL97)I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET
M(&-A<F0@;G5M8F5R(@IM<V=S='(@(DMR961I(&MA<G0@;G5M87)A<_TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")(_7)V871I<W1A
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2_QB82(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N
M="`T(%!H87-E<R(*;7-G<W1R("+>=2!!;F1A:VD@179R92(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S
M:6]N<R(*;7-G<W1R(")987)A=/UC_2#=>FEN;&5R:2(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R
M<F5N="!4:6UE(@IM<V=S='(@(MYU($%N9&%K:2!:86UA;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM
M<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`BWG4@86YD86MI(%523"(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0W5R
M<F5N="!5<V5R<R(*;7-G<W1R("+>=2!!;F1A:VD@179R92(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G
M<W1R("+>=2!!;F1A:VD@2&%V82!$=7)U;74B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@
M(@IM<V=S='(@(MYU($%N9&%K:2#>87)T;&%R.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@
M<W1Y;&4B"FUS9W-T<B`B6?QR_')L_&MT96MI('-I=&EL(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(B5S(&4@9VER:?YT92#G86S]_F%C86L@9_9R979L97)I(&MI_FES96QL9?YT
M:7)I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DME<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@
M(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BWF7G:6QI(&]L86YL87+](&ME<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")+_6)R_7,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/
M23@M4BDB"FUS9W-T<B`B2VER:6P@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB
M"FUS9W-T<B`B2VER:6P@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX
M+54I(@IM<V=S='(@(DMI<FEL+U5K<F%Y;F$@*$M/23@M52DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("+'96L@0W5M:'5R
M:7EE=&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G
M<W1R(")'1R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G
M:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N
M+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1_QN;/QK(@H*(SH@861M:6XO9&%T
M871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@
M(E9E<FD@0?!A8_T@5&%R87G]8_US_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS
M9W-T<B`B5&%R:6@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")'96QI_B!4
M87)I:&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED
M(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")487)I:"!39>=I;6DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A>2(*;7-G<W1R(")'_&XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(DM?;VQO;G4@
M4VEL(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D%R86S]:R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*
M;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(")/;F1A;/UK('-A>?UL
M87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B1VER:6YT:7EI
M($%Z86QT(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@
M;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BUFX@
M=&%N_6UL_2(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(M9N(%1A
M;OUM;/T@4F5N:R(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP
M:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`BUFX@5&%N
M_6UL_2!+:6UL:6LB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@
M9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`BUFX@=&%N_6UL
M_2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI
M=&EO;G,B"FUS9W-T<B`B5&%N_6UL87(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
M4VEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@0V5L;"(*;7-G
M<W1R(")(_&-R92!3:6PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI
M;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@
M(D=R=7`@4VEL(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(E-A=/UR_2!S
M:6PB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R
M;6ES<VEO;B(*;7-G<W1R("+=>FEN(%-I;"(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S(@IM<V=S='(@(MUL971I;&5R:2!S:6P@=F4@=&5M:7IL
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(DC\8W)E(%-I
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B2V]L;VX@
M4VEL(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B5F%R;VQA
M;B#V=&5K:2!T87-L8?#]('-I;"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(G)7,G(&GG:6X@
M:7II;FQE<FD@<VEL(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*
M;7-G<W1R("(G)7,G(&GG:6X@:7II;FQE<B!V92!A;'0@:7II;FQE<B!S:6QI
M;G-I;B!M:3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(E-A
M=/UR_2!S:6PB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN
M:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T
M<B`B4V7G:6QM:?X@:VEM;&GP:2!S:6PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`BWG4@86YD86MI(&MO;&]N
M=2!S:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B
M"FUS9W-T<B`BWG4@86YD86MI('-A=/UR_2!S:6PB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@
M(DMU<G5L=6T@9_QN8V5L;&5M92!B971I\&D@)R5S)R!S:6QI;F1I+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B5&5S
M;&EM('IA;6%N_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T
M<B`B1&%N:6UA<FMA(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(E-O
M<G5N=2!486[];6QA>?UN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D'G_6ML86UA(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B07ER_6YT
M_6QA<B`H07EN_2!Z86UA;F1A($AO<F1E)W5N(&?\;FS\:R!D;W-Y87/];OUN
M(&GG:6YD92DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*
M;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(D%Y<OUN=/UL87(@>?9N971I8VD@:>=I;B!G
M_&YL_&L@;VQA<F%K(&MA>61E9&EL9&DN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B1V5L
M:?YI;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@
M4&]I;G0B"FUS9W-T<B`B3F5M($UI:W1A<OTB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R(")3;VX@<V%A='1E:VD@;F5M(&UI:W1A<OTZ("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@
M(@IM<V=S='(@(DYE;2!M:6MT87+].B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(*;7-G<W1R(")3;VQD86X@<V'P82!Y]FYL_"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@
M(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(E-A\&1A;B!S;VQA
M('GV;FS\(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I
M<F5C=&]R>2(*;7-G<W1R(")$:7II;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T
M<B`B,C0@<V%A=&QI:R!Z86UA;B!M_2!G]G-T97)I;'-I;C\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*
M;7-G<W1R(")']G+\;G3\;&5M92!39>=E;F5K;&5R:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA
M>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")(879A('1A:&UI;FEN:2!G
M]G+\;G3\;&4@*%1!1BDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS
M9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(DAA=F$@=&%H
M;6EN:6YI(&?V<OQN=/QL92`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D?V
M<OQN=/QL96UE($)IYVEM:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.
M+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G
M<W1R(")$_'IE;B!":6QD:7)I;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB
M;W5T:2(*;7-G<W1R(")#:6)U=&DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(")3
M:6QM97EI;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I
M9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS
M9W-T<B`B;6%I;G1E;F%N8V4N<&AP(&1O<WEA<_UN82!D;_!R=61A;B!E<FG^
M;65Y:6XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I
M<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C
M:R!T:&ES(&)O>#HB"FUS9W-T<B`BW6QK('-A=/UR(&%L86X@861L87+];OT@
M:>=E<FEY;W(@;74_($5V970@:7-E(&)U(&MU='5Y=2!S9>=I;CHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEK(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O
M;6EN:6L@0W5M:'5R:7EE=&DB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BW6YD:7(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B)7,@W6YD:7(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R
M(")/;'7^='5R=6QA;B!Y87#];&%N9/UR;6%Y_2!02%`@8F5T:?!I(&]L87)A
M:R!I;F1I<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R(")!_F'P_2!AY_UL_7(@;&ES
M=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S
M(@IM<V=S='(@(MUL8>=L87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+5!O<W1A(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*
M;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I
M97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%:W9A=&]R(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B1/QZ96YL92(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")";&]K
M($3\>F5N;&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U
M<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")'<G5P($3\
M>F5N;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VXB"FUS9W-T<B`BW7II;B!$_'IE;FQE(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*
M;7-G<W1R("+=>FEN;&5R:2!$_'IE;FQE(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R#=YVEN(-UZ:6YL97)I($3\>F5N
M;&4B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET
M(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")39>=E;F5K;&5R:2!D_'IE;FQE.B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(B"FUS9W-T<B`B)7,@:>=I;B!I>FEN;&5R:2!D_'IE;FQE(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R!IYVEN(&EZ
M:6YL97)I(&3\>F5N;&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*
M;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")%\&ET:6TB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%9WEP="(*;7-G<W1R(")-_7/]<B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE
M<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V
M97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I
M9"`B16QE;65N="XN+B(*;7-G<W1R("+6\&4N+BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS
M9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@
M(D5M86EL(@IM<V=S='(@(D5L96MT<F]N:6L@4&]S=&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B16QE
M:W1R;VYI:R!0;W-T82!!9')E<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB
M"FUS9W-T<B`B16QE:W1R;VYI:R!P;W-T82!A<W)E<VQE<FD@9?YL9?YM96QI
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M
M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D]N87EL_2!E;&5K=')O
M;FEK('!O<W1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")$=7EG=2!S:6UG97)L
M97)I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")";_X@
M:6QE=&DN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T
M,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")";_X@
M<V]N=><N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q
M,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(D)O_B!A<F%M
M82!T97)I;6QE<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS
M9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"B)&;W1O\')A9B!'86QE<FES
M:6YD96X@;65T:6YL97)I;B!IYV5R:7-I;F4@9_9R_&YT_"!E:VQE;64@971K
M:6YL9?YT:7)I;'-I;B`B"B)M:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/R(*;7-G<W1R(")38?`@=/UK(&GG97)I:R!M96[\<_P@971K:6YL9?YT:7)I
M;'-I;B!M:3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM
M<V=S='(@(D)I=&G^('G];/TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G
M<W1R(")$_'IE;FQE>6EC:7EI($=E;FG^;&5T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(E!A<F]L86[]>OT@<_UF_7)L
M86UA:R!I<W1E9&GP:6YI>F1E('-O<G5L;6%K(/QZ97)E(&)I<B!G_'9E;FQI
M:R!S;W)U<W4@(@HB9VER:6XL(-9R+B`G179C:6P@:&%Y=F%N_6[]>OUN(&%D
M_2!N961I<C\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E
M(%523"!H97)E(@IM<V=S='(@(D?V<OQN=/P@861R97-I;FD@8G5R87EA(&=I
M<FEN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S
M='(@(D5K=F%T;W(@1VEN97-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E
M82(*;7-G<W1R(")%<FET<F4B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E
M<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")(
M871A(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L
M;V-K.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R;65D92!H871A.B`E<RXB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@
M;&]G.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R;65D92!H871A.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R;65D92!H871A.B`E<RXB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*
M;7-G<W1R(")986[]=/T@9_9N9&5R;65D92!H871A.B`E<RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G
M:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B16QE=')O
M;FEK('!O<W1A(&3V;F1E<FUE9&4@:&%T82XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,30R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET
M:6YG(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R!Y87IA<FME;B!H871A+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T;VYY82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:7EO<'EA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS
M9W-T<B`B171N:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")!=G)U<&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM
M<V=S='(@(DAE<B`Q-2!D86MI:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@Y"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B2&5R(#(@
M9&%K:6MA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM
M<V=S='(@(DAE<B`S,"!S86YI>64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y
M(#4@;6EN=71E<R(*;7-G<W1R(")(97(@-2!D86MI:V$B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R
M>2!,;V=I;B(*;7-G<W1R(")(97(@1VER:?YT92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R
M(")(97(@>6%R_6T@<V%A="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(DAE<B!D86MI:V$B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@
M(M9R;F5K(&1E\&5R;&5R.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM
M<V=I9"`B17AE8W5T92(*;7-G<W1R("+'86S]_G3]<B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM
M<V=S='(@(D=E;FG^;&5T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R
M+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B2V5N87(@
MQW5B=?!U;G4@1V5N:?YL970B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B)RDG
M($)E:VQE;FEY;W(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E
M87)C:"!T97)M(@IM<V=S='(@(E-A9&4@:V5L:6UE('9E>6$@86S];G3](&%R
M86UA('1E<FEM:2!B96ML96YI>6]R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T
M<B`B1V7G97)L:6QI:R!3;VX@5&%R:6AI(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(MQS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(M9N($%L86X@
M4F5N9VDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D%Y87)L87(@:>=I;B!&5%`@
M>?QK;&5M97-I(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z
M,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS
M9W-T<B`B5&5R8VEH;&5R:6X@9V5T:6QM97-I(&)A_F%R_7/]>BXB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@<W5N=6-U<W5N82!B8?!L
M86YT_2!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+B(*;7-G<W1R(")334(@<W5N=6-U<W5N82!B8?!L86YT_2!B8?YA<OUS_7HN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(B!K;VYU;75N9&%N(&MO<'EA;&%M82!B8?YA<OUS_7HN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")<
M(B5S7"(@:V]N=6UU;F$@:V]P>6%L86UA(&)A_F%R_7/]>BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(EEE;FD@4T%3
M3"!B8?!L86YT_7/](&]L=?YT=7)U;&%M863]+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S(T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB
M)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&MO;G5M=6YA('1A_OUM82!B8?YA<OUS
M_7HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B
M"FUS9W-T<B`B7"(E<UPB(&MO;G5M=6YA('1A_OUM82!B8?YA<OUS_7HN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G
M:60@(D9A:7(B"FUS9W-T<B`B57EG=6X@2&%V82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK
M;&%N9"!!9&%L87+]("A-86QV:6YA*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A
M<F]E($ES;&%N9',B"FUS9W-T<B`B1F%R;V4@061A;&%R_2(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G
M<W1R(")/;G5L;6%Z($AA=&$Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A:W,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS
M9VED(")&87AE<R(*;7-G<W1R(")&86MS(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S
M='(@(MYU8F%T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@
M(D9E96QS($QI:V4B"FUS9W-T<B`B2&ES<V5D:6QI>6]R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@
M(@IM<V=S='(@(DAI<W-E9&EL:7EO<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM
M<V=S='(@(DAA9FEF(%-A\&%N86LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R(")(869I9B!+87(@4V'P86YA\/TB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B
M06QA;B!M871R:7-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S
M-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY
M"FUS9VED(")&:6QE(@IM<V=S='(@(F1O<WEA(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL92(*;7-G<W1R(")$;W-Y82!387G]<_TZ("5S(&1O<WEA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B1&]S>6$@4V%Y
M_7/].B`E<R!D;W-Y82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")$;W-Y82!9]FYE=&EC
M:7-I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I
M;&4@3F%M92(*;7-G<W1R(")$;W-Y82!!9/TB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R
M(")$;W-Y82!S9>=I;6DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")$;W-Y82!Y_&ML96UE
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED
M(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1&]S>6$@
M>?QK;&5M92!D97-T96ML96YM:7EO<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B4_QZ9V7G;&5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL86YD
M:7EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@
M2&%L9B(*;7-G<W1R("+=;&L@66%R_2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T
M97(B"FUS9W-T<B`BW6QK(,=E>7)E:R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G
M<W1R(")/<F%N_2!S86)I=&QE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("+'979I
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(DMA>6%N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O
M9R(*;7-G<W1R(")3:7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R
M("(E<R!D:7II;FD@>6]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")9
M87K](%)E;F=I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED
M(")&;V]D(@IM<V=S='(@(EEE;65K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")'
M]G+\;G3\;&5R:2!D97-T96ML96UE>65N('1A<F%Y_6/];&%R(&GG:6XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`B5&%H;6EN("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(E1A:&UI;B!'_&YL97)I
M("A.;W0Z($=E<FD@9/9N_&QE8V5K;&5R(&AE;2!G_&X@:&5M(&=E8V4@;VQA
M<F%K(&3V;OQL96-E:SL@*2(*(F+\>?QK(&)I<B!S87G](&=E;FG^(&)I<B#V
M8F5K;&4@<V]N=>=L86YA8V%K=/UR*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS
M9W-T<B`B4&%R;VQA;OUZ_2!M_2!U;G1T=6YU>C\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R(")&;W)M
M;&%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T
M=6YE(@IM<V=S='(@(D1E>6G^(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B1&5Y:?X@=/QR_"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B1&5Y:?YL97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B1&5Y:?YL97(@,B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*
M;7-G<W1R(")&;W)U;6QA<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(EGV;FQE;F1I<FUE;&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,`IM<V=I9"`B1G(B"FUS9W-T<B`B0W4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B
M"FUS9W-T<B`BQV5RYV5V96QE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC
M92(*;7-G<W1R(")&<F%N<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@
M(D9R86YS82P@365R=&]P;VQI=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R(")&<F%N<_UZ($=U>6%N87/](@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B1G)A;G/]
M>B!0;VQI;F5Z>6%S_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YS_7H@1_QN97D@0O9L
M9V5S:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B2VEM9&5N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")+:6UD96XB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C
M<FEP=&EO;B(*;7-G<W1R(")486T@0F5T:6UL96UE(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R(")$;VQU;F%Y(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*
M;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")!Y_UK($%D(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G
M:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D?V<OQN
M=/QL97)I;B!A;/UN86-A\/T@9V%L97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'
M86QL97)Y.B(*;7-G<W1R(")'86QE<FDZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1V%M8FEA(@IM<V=S='(@(D=A;6)I>6$B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B)7,@66%P_6QA;F3]<FUA<_UN_2!/;'7^
M='5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*
M;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D]L=?YT=7)U;&%N($MO
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1_QR8VES
M=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")!;&UA
M;GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1V%N82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")#96)E;&ET
M87+]:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(E9E<FEL96X@060B"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B
M1VET(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D
M96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-
M87!S(@IM<V=S='(@(D=O;V=L92!!<F%M82(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B1V]O
M9VQE($%R86UA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(E-I>6%H($)E
M>6%Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")9=6YA
M;FES=&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R
M965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")9=6YA;F-A("A)4T\M.#@U.2TW
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<O9N
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E
M;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P(%GV;F5T:6UI(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R(")'<G5P(&ES:6UL97)I(&1O;'4@;VQM86S]9/UR
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M(@IM<V=S='(@(D%U=&A?:6UA<#H@)7,@:W5L;&%N_6/]<_T@96ML96YE;65D
M:2X@4W5N=6-U.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T
M92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/]
M(&?\;F-E;&QE;F5M961I(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@)7,@
M:W5L;&%N_6/]<_T@9_QN8V5L;&5N96UE9&DB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S
M(@IM<V=S='(@(D=R=7!L87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO
M=7!E(@IM<V=S='(@(D=U861A;'5P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U
M86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA
M;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N
M<R(*;7-G<W1R(")+;VYU:R#=>FEN;&5R:2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R(")+;VYU
M:R!$969T97)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@
M(D=I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B1W5I;F4@0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA
M;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@<V%T_7)D86MI('-O
M;B!H_&-R97EI('-I;&UE>6D@<F5D9&5D:7EO<BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(.=I>F5L9V5D96MI
M('-O;B!K;VQO;G4@<VEL;65Y:2!R961D961I>6]R+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@YVEZ96QG961E:VD@
M<V]N('-A=/UR_2!S:6QM97EI(')E9&1E9&EY;W(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC
M871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10($MI;6QI:R!$96YE=&EM
M:2!B=6QA;F%M863]+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS
M9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@@06QG
M;W)I=&UA<_TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")(869I9B!3:7,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(D)A_FS]:R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*(RP@
M9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B0F'^;/UK(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',B"FUS9W-T<B`B2&5A<F0@061A<_T@=F4@36-$;VYA;&0@061A;&%R_2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"B,L
M(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(D?V:R!G_'+\
M;'3\;/P@9OUR=/UN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS
M9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`BW6)R86YI8V4@
M*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B
M6?QK<V5K;&EK(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X
M+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(EEA<F3];2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE
M;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D3\>F5N;&5Y:6-I(&MU;&QA<F%K
M('EA<F3];2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*;7-G
M:60@(DAE;'!E<B(*;7-G<W1R(")987)D_6UC_2(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")987+]:_QR
M92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(D1O<WEA;OUN(&)A_FQA;F?]
M8_TZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(EG\:W-E:R(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B7T%N87-A>69A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92DB"FUS9W-T<B`B5F%T:6MA;B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R(")!;F%S87EF82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM
M<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D5V($%D<F5S:2(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!$
M:7)E8W1O<GDB"FUS9W-T<B`B1&EZ:6XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM
M<V=S='(@(D5V(%1E;&5F;VYU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD
M=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO
M;&%B.B!"=2!M97-A:B!IYVEN9&4@9V7G97)S:7H@)7,@6$U,('9E<FES:2!I
M;&4@:V%R_OUL8?[];&3].B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@)7,@;F5S;F5S:2!I;&4@:6QG:6QI(&)I<B!I;&5T:2!B
M=6QU;F%M863](@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O
M9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z("5S('3\<OQN9&4@:&GG(&)I<B!N97-N92`E<R!M97-A:OT@:>=I
M;F1E('EO:RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@
M7"(E<UPB(&)A_F%R_2!I;&4@<VEL:6YD:2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G
M<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N
M<VEO;B(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@0OQT_&YL96UE(&UO=&]R
M=2`G9&]M>&UL)R!02%`@=7IA;G3]<_UN82!I:'1I>6'G(&1U>6UA:W1A9/UR
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M("5S(&YE<VYE<VD@:>=I;B!Y96YI(%A-3"!A\&%C_2!O;'7^='5R=6QA;?UY
M;W(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@4VEL:6YE;65D
M:2`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!T_'+\;F1E:VD@:_US_6T@:>=I
M;B!-24U%($E$(&)U;'5N86UA9/TB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!%_FQE;F5M961I("5S(%PB)7-<(CH@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S(@IM<V=S='(@(E!A>6QA_OUM;&%R(&7^;&5N96UE9&DZ("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM
M<V=S='(@(D)I;&EN;65Y96X@<&%Y;&'^_6T@7"(E<UPB(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R
M:7IO;G1A;"!2=6QE(@IM<V=S='(@(EEA=&%Y(,=I>F=I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R
M:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(EEA=&%Y('EA<W3]:VQA;6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS
M9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")9871A>3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G
M:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM
M<V=S='(@(D)U<F%Y82!N87/];"!G96QD:6YI>C\@*$S\=&9E;B!R87!O<B!E
M9&EN(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+8><@861E="!K;VQO;G4@8FER
M;&7^=&ER;65K(&ES=&EY;W)S=6YU>C\B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS
M*2!A<F4@=&AE<F4_(@IM<V=S='(@(DMAYR!A;&%N("AK;VQO;BD@=F%R/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(DMAYR!A9&5T('-A=/UR_2!B:7)L9?YT:7)M96L@
M:7-T:7EO<G-U;G5Z/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y
M(@IM<V=S='(@(DYE;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B3F5M.B`B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G
M<W1R(")-:7IA:.?];&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y
M(@IM<V=S='(@(DUA8V%R:7-T86XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0('!O<W1A(&MU='5S=2!O;'7^
M='5R=6QA;6%D_3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("))34%0('!O<W1A(&MU='5S=2!S:6QI;F5M961I
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(DE-05`@<&]S=&$@:W5T=7-U(&MO=&%S_2!O;'7^='5R
M=6QA;6%D_3H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V
M"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0($%D<F5S:2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D
M9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@861R97-I(&UE=F-U
M="!D9?!I;"X@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H
M<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RXB"FUS9W-T<B`B25`@061R97-I(&EZ:6X@=F5R:6QE;B!#2412
M(&)L;_!U(&GG:6YD92!D9?!I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N
M('9I;VQA=&EO;BXB"FUS9W-T<B`B25`@:VEL:71L96UE(&EH;&%L:2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("+6;E]C
M97EE(%-A=/UR(%EE<FQE_G1I<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E
M;&%N9"(*;7-G<W1R("+=>FQA;F1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")3861E8V4@4VEM
M9V5L97(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B5S(&GG:6X@<VEM
M9V5L97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))
M8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B365T:6X@:6QE(&)I<FQI:W1E('-I
M;6=E;&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R(")+:6UL:?!I;B!A9/TZ(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF
M;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B1?!E
M<B!D;_!R=2!G]G+\;G3\;&5N96UI>6]R<V$L('EE;FD@<&5N8V5R961E(&'G
M;6%K(&GG:6X@=/UK;&%Y_6X@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*
M;7-G<W1R("(B"B)%\&5R($EN=&5R;F5T($5X<&QO<F5R(&EL92!S:6UG96QE
M<FD@9_9R96UI>6]R<V%N_7H@8G4@:W5T=7EU('-EYV5R96L@4$Y'("(*(G-A
M>61A;6S]\/UN_2!K87!A=&UA;OUZ(&=E<F5K:7(N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@
M>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@
M>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y
M;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(D?V<OQN=/QL97)I(&?V<F5M:7EO
M<B!F86MA="!B=2!M97-A:OT@9_9R96)I;&ER>6]R<V%N_7HL('G\:VQE;65K
M("(*(FES=&5D:?!I;FEZ(&?V<OQN=/P@=&%R87G]8_UN_7H@=&%R86;];F1A
M;B!G]G-T97)I;&5M96UE:W1E9&ER+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA
M9V4@4')E=FEE=SHB"FUS9W-T<B`B1_9R_&YT_"#6;FEZ;&5M92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*
M;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")']G+\;G3\(%523"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")']G+\;G3\(%523#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M(")397)G:61E;B!G]G+\;G3\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F
M<F]M(&=A;&QE<GDZ(@IM<V=S='(@(E-E<F=I9&5N(&?V<OQN=/PZ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L
M;V%D(@IM<V=S='(@(D?V<OQN=/P@>?QK;&5M96LB"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D?V<OQN=/QL
M97(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("+=YV5R:2!!
M:W1A<BP@063];2`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*
M;7-G<W1R("+=YV5R:2!A:W1A<OUL86X@86QA;CH@)7,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z
M(@IM<V=S='(@(MWG97)I(&%K=&%R_6QA;B!A;&%N;&%R.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM
M<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B4V]N7W)A>6$@4V%T
M_7(@16ML92(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R(")986YL_?X@97EL96T@:V]D=2!G:7)I;&1I+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED
M("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R
M(")986YL_?X@:W5L;&%N_6/](&%D_2!V92]V97EA('!A<F]L82XB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R
M96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)986YL_?X@:W5L;&%N_6/](&%D
M_2!V97EA(/9T96MI(&%D<F5S+EEE;FED96X@9&5N97EI;B!V97EA(&1A:&$@
M9F%Z;&$@>6%R9/UM("(*(FGG:6X@>?9N971I8VEN:7IL92!G]G+\_OQN+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*
M;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")':7)I;G1I>6D@07)T
M=/UR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R(")(:6YD
M:7-T86XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A
M;"!5<V5R<R(*;7-G<W1R(")":7)E>7-E;"!+=6QL86[]8_UL87(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R(")%;F1O;F5Z>6$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"FUS9VED("));F9O(@IM<V=S='(@(D)I;&=I(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B
M0FEL9VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"B,L
M(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+B(*;7-G<W1R(")(:>=B:7(@<V7G96YE:R!M979C=70@9&7P:6PN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R(")3;VYR
M87EA($MO7VQO;B!%:VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA
M9V4B"FUS9W-T<B`B1_9R_&YT_"!997)L9?YT:7(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@
M5&%B;&4B"FUS9W-T<B`BQVEZ96QG92!997)L9?YT:7(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E
M<G0@5V5B($QI;FLB"FUS9W-T<B`B5V5B($)A\&QA;G3]<_T@665R;&7^=&ER
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T
M<B`BUFYC97EE($MO;&]?;B!%:VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")9
M96YI(&MO;&]N=2#^=2!A;F1A:VD@:V]L;VYD86X@<V]N<F$@>65R;&7^=&ER
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B665N:2!K;VQO;G4@_G4@86YD86MI
M(&MO;&]N9&%N(/9N8V5Y92!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(EEE;FD@<V%T_7+](/YU(&%N9&%K:2!S873]<F1A;B!S;VYR87EA('EE<FQE
M_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(EEE;FD@<V%T_7+](/YU(&%N9&%K
M:2!S873]<F1A;B#V;F-E>64@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("))
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R(")996YI('!A<F%G<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@<V]N<F%Y
M82!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")996YI('!A<F%G
M<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@]FYC97EE('EE<FQE_G1I<B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N
M871E('1E;7!L871E(@IM<V=S='(@(M9T96MI('1A<VQA:R!Y97)L9?YT:7(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B665N:2!B:7(@<&%R86QO>?T@86QA
M8FEL96-E\&EN:7H@8FER(&5L96MT<F]N:6L@<&]S=&$@861R97-I(&=I<FEN
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DC\
M8W)E>6D@<V]N<F%S_6YA('EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R
M="!C96QL(&)E9F]R92(*;7-G<W1R(")(_&-R97EI(/9N8V5S:6YE('EE<FQE
M_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T
M<B`B2V]L;VYU('-O;G)A<_UN82!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")+;VQO;G4@]FYC97-I;F4@
M>65R;&7^=&ER(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R(")-97-A
M:B!G:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B
M"FUS9W-T<B`B4&%R86=R86;]('-O;G)A<_UN82!Y97)L9?YT:7(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(E!A
M<F%G<F%F_2#V;F-E<VEN92!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E
M<G0@<F]W(&%F=&5R(@IM<V=S='(@(E-A=/UR_2!S;VYR87/];F$@>65R;&7^
M=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B
M4V%T_7+](/9N8V5S:6YE('EE<FQE_G1I<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R
M('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B1_QV96YL:6L@
M<V]R=7-U;G5N(&-E=F%B_3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E
M(@IM<V=S='(@(D?V<OQN=/QY_"!997)L9?YT:7(O1&7P:?YT:7(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED
M("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B0F'P;&%N=/T@665R;&7^
M=&ER+T1E\&G^=&ER(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D1A
M\/UT_6T@;&ES=&5S:2!G]FYD97)M96L@:>=I;B!Y971E<G-I>B!K<F5D:2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B665T
M97)S:7H@:W)E9&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U
M"FUS9VED("));G1E9V5R(@IM<V=S='(@(E1A;7-A>?TB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS
M9W-T<B`B5&%M<V%Y_2!L:7-T97-I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")'9>=E<G-I>B!51$@N
M("A+=6QL86[]8_T@5F5R:2!"8?YL_6L@0FEL9VES:2DB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`HC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!:25`@9&%T82(*;7-G<W1R(")'9>=E<G-I>B!U;FEC;V1E('9E
M<FES:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("))
M;G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")'9>=E<G-I>B!U>6=U;&%M
M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(D=E
MYV5R<VEZ('G]\/UN(&MI;6QI\&DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G
M<W1R(")'9>=E<G-I>B!V97)I(&?V;F1E<FEL9&DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("))
M;G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(D=EYV5R<VEZ
M('1E<VQI;2!A9')E<VDB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@
M(D=EYV5R<VEZ(&1O<WEA(&)IYVEM:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&EC96YS
M92!K97DN(@IM<V=S='(@(D=EYV5R<VEZ('5Y9W5L86UA+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D=EYV5R<VEZ('5Y
M9W5L86UA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T
M<B`B1V7G97)S:7H@;7-G7W1Y<&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(D=EYV5R<VEZ('EA9&$@871L86YM
M_?X@87!I7VED(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R
M86UE=&5R<RXB"FUS9W-T<B`B1V7G97)S:7H@>6%D82!A=&QA;FW]_B!D9?!I
M_G1I<F=E;&5R(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")'9>=E
M<G-I>B#\<W0@:7II;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM
M<V=S='(@(D=EYV5R<VEZ(/QS="!I>FEN+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O
M9'5C="!C;V1E+B(*;7-G<W1R(")'9>=E<G-I>B!I;&5T:?YI;2!K=7)A;&QA
M<OTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(D=E
MYV5R<VEZ(&EL971I_FEM(&MU<F%L;&%R_2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D=EYV5R<VEZ
M(&%L_6/].B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV
M86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B1V7G97)S:7H@<&%Y;&'^_6QA
M;B!N97-N92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB
M"FUS9W-T<B`B1V7G97)S:7H@:V%Y;F%K(&%D<F5S:2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@
M(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")'9>=E<G-I>B!U;FEC
M;V1E('9E<FES:2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W
M"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B4W1O:R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*(RP@9G5Z>GD*;7-G
M:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`BWF7G:6QI(&]L86YL87+]
M(&ME<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B(*;7-G<W1R("+=<F%N(-US;&%M($-U;6AU<FEY971I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER86LB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`BW7)L86YD82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA
M;B(*;7-G<W1R(")-86X@061A($1E=FQE=&DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3
M=&]R;7,B"FUS9W-T<B`B66%L_73];&W]_B!G]FL@9_QR_&QT_&S\(&;]<G3]
M;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("+=<W)A
M:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM
M<V=I9"`B27-S=65R(@IM<V=S='(@(L?]:V%R86XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*
M;7-G<W1R("+==&%L:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM
M<V=S='(@(MUT86QY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*
M;7-G<W1R(")*86UA:6MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B3V-A:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P;VYY82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H
M25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]N8V$@*$E33RTR,#(R+4I0*2(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*
M879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A
M;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`BW')D_&XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R(")496UM=7HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")(87II<F%N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")987-L82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS
M9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")/<G1A>6$@66%S;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(E1A;6%M96X@66%S
M;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(E-O;&$@
M66%S;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")3
M8?!A(%EA<VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM
M<V=S='(@(DMA>F%K:7-T86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R("+6>F?\;B!O;&%N('-A:VQA;G/];B!M_3\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DME;GEA(@IM<V=S='(@(DME;GEA(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R!S=6YU
M8W4@9&_P<G5L86UA>?T@<F5D9&5T=&DN(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("+'96MI
M<F1E:R!!8V5M:6QE<FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")!;F%H=&%R
M(%EA<F%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T
M"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B06YA:'1A<B!087)M
M86MI>FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*
M;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B06YA:'1A<B!5>G5N;'7P=2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M2V5Y(%1Y<&4B"FUS9W-T<B`B06YA:'1A<B!4:7!I(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME>2!5<V%G92(*
M;7-G<W1R(")!;F%H=&%R($MU;&QA;OUM_2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")!Y_UK(&%N86AT
M87(@<W5N=6-U<W5N9&$@86YA:'1A<B!Z871E;B!V87(N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(L=O8W5K
M;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+
M:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2W5Z97D@2V]R92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(D?\;F5Y($MO<F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(DMO<F5C92`H975C+4M2
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=F5Y
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+
M_7)G_7II<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM
M<V=I9"`B3&%?>6]U="(*;7-G<W1R(")387EF82!?1/QZ96YI(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`B1&EL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86\@1&5M;VMR871I8R!(
M86QK($-U;6AU<FEY971I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM
M<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E-O;B!$]G)D_&XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@4&%S
M<W=O<F0@0VAA;F=E(@IM<V=S='(@(E!A<F]L87G]('/]9OUR;&$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS
M9VED("),87-T(%%U87)T97(B"FUS9W-T<B`BWFG^:VEN($%Y(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`B4V]N($?\;F-E;&QE;64Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S
M(@IM<V=S='(@(E-O;B!':7)I_CH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<R(*;7-G<W1R(")3;VX@1VER:?XZ("5S(/QZ97)I;F1E;B`E
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S
M="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B4V]N($=I<FG^.B!!<VQA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T;VYY82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@
M(EEA<V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")$_'IE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G
M:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B2&GG8FER
M('/];OUR(&GG:6X@8F_^(&+]<F%K;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQE8F%N;VXB"FUS9W-T<B`B3/QB;F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM
M<V=S='(@(E-O;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*
M;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E-O;"!B8?YL_6L@8FEL9VES
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(E-O;&1A:VD@9&7P97)L97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B
M3&5V96PB"FUS9W-T<B`B0?YK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E
M<FEA(@IM<V=S='(@(DQI8F5R>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB>6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS
M=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(L=I<V5L:7EO<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS
M9VED("),:6=H="!286EN(@IM<V=S='(@(DAA9FEF(%EA\&UU<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),
M:6=H="!286EN($5A<FQY(@IM<V=S='(@(D5R:V5N(%-A871L97)D92!(869I
M9B!98?!M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(D=EYR!3
M86%T;&5R9&4@2&%F:68@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R
M(@IM<V=S='(@(DAA9FEF(%EA\&UU<B!38?!A;F'P_2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!2
M86EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")']FL@9_QR_&QT_&S\(&AA9FEF
M('EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DAA9FEF($MA<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS
M9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(")(869I9B!+87(@4V'P
M86YA\/TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI
M;65R:6-K(@IM<V=S='(@(D[\:W1E;&D@WFEI<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T<B`B0F'P;&%N
M=/TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R(")"
M8?!L86YT_2!N;VMT87/].B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B1_9R_&YT_&QE
M<FME;B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:6YI(&]L=?YT=7)M82!S87EF
M87/];F$@8F'P;&$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R(")"8?!L
M86YT_6QA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B
M3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X(,=E<F5Z:2(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&5L92`M
M(&MU;&QA;OUC_2!D:7II;FD@9_9R96)I;&ER(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B5F5R
M:2!486)A;FQA<OUN_2!,:7-T96QE(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B66%R
M9/UM($MO;G5L87+];OT@3&ES=&5L92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(L=I>F5L9V5L97)I
M($QI<W1E;&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W1E;&4M07+^
M:78B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM
M<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1E;&4M66%R9/UM(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI
M<W0M260B"FUS9W-T<B`B3&ES=&5L92U)9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(DQI<W1E;&4M4V%H:7`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W1E
M;&4M1_9N9&5R:6QM:?X@UO!E;&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S
M='(@(DQI<W1E;&4M4_QR9/QR_&UC_&QE<B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E
M(@IM<V=S='(@(DQI<W1E;&4M4_QR9/QR_&UC_"!/;&UA>6%N;&%R(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B2W5L
M;&%N_6/](&QI<W1E;&5M92!S9>=I;&5M97H@:_UL_6YD_2XB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")+=6QL86[]8_T@
M;&ES=&5L96UE('-EYVEL96UE>B!K_6S];F3]+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B2W5L;&%N_6/](&QI<W1E;&5M92!S9>=I
M;&5M97H@:_UL_6YD_2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*
M;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B161E8FEY870B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71V86YY82(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G
M:60@(DQO861I;F<N+BXB"FUS9W-T<B`B6?QK;&5N:7EO<BXN+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I
M;64Z("(*;7-G<W1R(")997)E;"!Z86UA;CHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R(")9
M97(@=F4@6F%M86XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*
M;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(EEE<B(*"B,Z(&QO9VEN+G!H<#HQ
M-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO
M9R!I;B(*;7-G<W1R(")':7)I_B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(L?]:_W^(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G
M<W1R(")':7)I_B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(D=I<FG^($?V<F5V;&5R:2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B2W5L;&%N_6/](&%D_2!V97EA
M('!O<F]L82!D;_!R=2!O;&UA9/WP_2!IYVEN(&=I<FG^(&)A_F%R_7/]>B!O
M;&1U+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B
M3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")':7)I_B!B8?YA<OUS_7H@;VQD=2XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG
M('1E>'0B"FUS9W-T<B`B57IU;B!M971I;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")!_FLB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W
M(@IM<V=S='(@(D3\_OQK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@
M;&5T=&5R<R(*;7-G<W1R(")+_.?\:R!Y=6YA;B!H87)F;&5R:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B2_SG_&L@
M;&%T:6X@:&%R9FQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N
M=6UB97)S(@IM<V=S='(@(DO\Y_QK(')O;6$@<F%K86UL87+](@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DS\:W-E;6)U<F<B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(D%!
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]4
M1"(*;7-G<W1R(")-3U1$(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B!%:VD@=F5R:2!IYV5R
M;65M96MT961I<BXB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS
M9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R
M(")-86-A;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA:V5D;VYY
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-
M861A9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED
M(")-86=I8R(*;7-G<W1R(")"_'G\(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(E!O<W1A(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*
M;7-G<W1R(")0;W-T82!9]FYE=&EC:7-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME
M(&QI;E]K+BXN(@IM<V=S='(@(D)A\&QA7VYT_2!987)A="XN+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%V:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L97IY82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EV;&5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE
M(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W
M:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+B(*;7-G<W1R("(B"B+6\&5L97)I(&5T:6ME=&QE>65C9?!I;FEZ
M(&MA=&5G;W)I(&QI<W1E<VEN:2!V92!K871E9V]R:6QE<FD@(@HB:6QI_FMI
M;&5N9&ER96-E\&EN:7H@<F5N:VQE<FD@>?9N971I;BXB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P
M,C0@;6%P(@IM<V=S='(@(DUA<#(T(&AA<FET87/](@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U
M97-T(&UA<"(*;7-G<W1R(")-87!1=65S="!H87)I=&%S_2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%R="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")+96YA<B!B;_YL=?!U(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@
M(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")/:W5N;77^
M+T]K=6YM86W]_B!O;&%R86L@:?YA<F5T;&4B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T
M:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B
M1&GP97(@:6QE=&D@:?YA<F5T;&5R:7EL92!I_F%R971L92`H]G)N96LZ(-9N
M96UL:2]#979A<&QA;FW]_BD@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S
M:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL($%D86QA<OTB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6LB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T
M8VAI;F<@9FEE;&1S(@IM<V=S='(@(D7^;&5L96X@86QA;FQA<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-;W)I=&%N>6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R
M:71U<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R
M("+=>FEN('9E<FEL96X@96X@>?QK<V5K(&MR961I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(D5N('G\:W-E
M:R!M97-A:B!P87+G87/]('-A>?US_2!A_OUL9/TN(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z
M("(*;7-G<W1R(")3;VX@,C0@<V%A='1E:VD@96X@>?QK<V5K('/]8V%K;/UK
M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E
M;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B4V]N(#8@<V%A='1E:VD@96X@
M>?QK<V5K('/]8V%K;/UK.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")%;B!Y_&MS96L@=7IU
M;FQU:R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%Y_7,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(E3]
M<"(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G
M:60@(DUE;6)E<G,B"FUS9W-T<B`BW'EE;&5R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96[\
M($MI<&DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B2/QC
M<F5L97)I(&)I<FQE_G1I<B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S
M='(@(MUL971I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*
M(G9E<FEF:65D+B(*;7-G<W1R("(B"B+=;&5R:2!B8?YA<OUY;&$@9&_P<G5L
M86YD_2!A;6$@:6UZ86QA>?UC_6[];B!O;F%Y(&)E;&=E<VD@9&_P<G5L86YA
M;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B
M365S86K];B!S_')E<VD@8FET=&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B
M365S<V%G92!T>7!E(@IM<V=S='(@(DUE<V%J('1I<&DB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B
M2&%V82!287!O<G4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED
M(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")(879A(')A
M<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I;"XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB2&%V82!R87!O<G4@]F)E\&D@:W5L
M;&%N_6QA8FEL:7(@9&7P:6PN($%Y<OUN=/UL87(@>?9N971I8VD@:>=I;B!G
M_&YL_&ML96YD:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-
M971H;V0B"FUS9W-T<B`B6?9N=&5M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B"FUS9W-T<B`B6?9N=&5M("<E<R<@=&%N_6UL86YM86W]
M_B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*
M;7-G<W1R(")-971R:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*
M;7-G<W1R(")-96MS:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]N97-Y82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D]R=&$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4
M>7!E(@IM<V=S='(@(DUI;64@5/QR_"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B4V]N(#(T('-A871T96MI(&5N(&3\_OQK('/]8V%K;/UK.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B4V]N(#8@<V%A='1E:VD@96X@9/S^_&L@<_UC
M86ML_6LZ("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y
M"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I
M<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S0*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")986YS_2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N
M96]U<R(*;7-G<W1R(")-=6AT96QI9B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")"=6QU;F%M87EA
M;B!014%2('!A:V5T:3H@2%144%]297%U97-T+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)!=&QA;FW]
M_B!Y87#];&%N9/UR;6$N($)U('5Y9W5L86UA>?T@:W5L;&%N;6%K(&ES=&EY
M;W)S86[]>B!Y87#];&%N9/UR;6%Y_2`B"B+\<F5T;65K('IO<G5N9&%S_6[]
M>BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B
M071L86YM_?X@;65S86H@240N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(D%T;&%N;?W^(&]L
M86X@9V5R96ML:2!014%2('!A:V5T:2!-86EL+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")!=&QA;FW]_B!O='5R=6UA(&%I
M="!)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")0>G0B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@
M(D=E>FEC:2!0;W-T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")386MI;B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE
M9"!$871E(@IM<V=S='(@(D1E\&G^:6T@5&%R:6AI(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED
M(")-;V1I9GD@55),(@IM<V=S='(@(D1E\&G^=&ER.E523"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S
M(@IM<V=S='(@(DUO9"!486)A;OTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=GEA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86-O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;_!O;&ES=&%N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@
M86YD('EE87(B"FUS9W-T<B`B07D@=F4@>?UL(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R(")!>6S]:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A
M="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*
M;7-G<W1R(")!>2!%=G)E;&5R:2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E
M9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(D9A<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`B1V5N96QL:6ML92!!Y_UK(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#
M;&]U9'DB"FUS9W-T<B`B1V5N96QL:6ML92!"=6QU=&QU(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L
M>2!3=6YN>2(*;7-G<W1R(")'96YE;&QI:VQE($?\;F7^;&DB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@
M1&]W;B(*;7-G<W1R(")!_F'P_2!48?[](@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`B4V]L82!48?[](@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(E-A\&$@5&'^
M_2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM
M<V=I9"`B36]V92!5<"(*;7-G<W1R(")9=6MA<OT@5&'^_2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO
M=F4@9&]W;B(*;7-G<W1R(")!_F'P_2!T8?[](@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM
M<V=S='(@(EEU:V%R_2!T8?[](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA
M;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI
M<W1S(@IM<V=S='(@(L=O:VQU(&3\>F5Y(&'^8?#](&'G_6S]<B!L:7-T96QE
M<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L
M96-T:6]N(@IM<V=S='(@(L=O:VQU(%-EYVEM(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")(
M97-A8OUM(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY
M"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D)I;&=I
M;&5R:6YI>B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G
M:60@(DUY(%!O<G1A;"(*;7-G<W1R(")0;W)T86S];2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B
M"FUS9W-T<B`B4&]R=&%L($3\>F5N:6TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.
M3U0@06=R964B"FUS9W-T<B`B2V%B=6P@151-25E/4E5-(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B060B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)Y
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(")(;VQL
M86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE
M<R(*;7-G<W1R(")(;VQL86YD82!!;G1I;&QE<FDB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S
M92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@5&%B86X@55),(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E
M($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E($-!(-UP=&%L
M(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U
M"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C
M87!E($-!(&MU<F%L(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G
M<W1R(").971S8V%P92!996YI;&5M92!23"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T
M:6]N(%523"(*;7-G<W1R(").971S8V%P92#=<'1A;"!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"!S=6YU
M8W4@863](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T
M<B`B3F5T<V-A<&4@;VYA>2!B96QG97-I(&'G_6ML86UA<_TB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P92!O;F%Y(&)E
M;&=E<VD@=/QR_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*
M;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B0?`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*
M;7-G<W1R(")!<VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O
M;FEA(@IM<V=S='(@(EEE;FD@2V%L961O;GEA(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#
M871E9V]R>2(*;7-G<W1R(")996YI($MA=&5G;W)I(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T
M<B`BW6QE=&D@3VQU_G1U<B`H)7,I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(")996YI($%Y(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S
M97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B665N:2!+=6QL86[]8_T@063]
M("A39>=I;6QI*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B
M"FUS9W-T<B`B665N:2!:96QL86YD82(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM
M<V=S='(@(E!A<F]L82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H
M<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@
M97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@
M9&]N)W0@;6%T8V@N(@IM<V=S='(@(E!A<F]L86QA<B!E_FQE_FUE:R!Z;W)U
M;F1A9/UR+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B
M665N:2!096YC97)E("A?8F_^*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(").97=S(@IM<V=S='(@(DAA8F5R;&5R
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W
M<V=R;W5P<R(*;7-G<W1R(")(86)E<B!'<G5P;&%R_2(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@
M(E-O;G)A:VDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*
M;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B4V]N<F%K:2!%=G)E(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T:6]N<R(*
M;7-G<W1R(")3;VYR86MI(%-EYV5N96ML97(B"@HC.B!F<F%M97=O<FLO54DO
M54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T
M<B`B4V]N<F%K:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM
M<V=S='(@(DYI:V%R86=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B
M"FUS9W-T<B`B3FEJ97)Y82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I
M82(*;7-G<W1R(").:6IE<GEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B1V5C92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B
M"FUS9W-T<B`B2&%Y_7(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF
M9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(D9A<FML87+]
M;B!G]G-T97)I;&5B:6QE8V7P:2!K=6QL86[];&%B:6QI<B!Y87#];&%N9/UR
M;6$@=F5R:7-I('EO:RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B25-/(&EM86IL87+]
M(&]U_G1U<FUA:R!IYVEN(&MU;&QA;OUL86)I;&ER(&)I<B!Y]FYT96T@>6]K
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(EG]
M\/UN('1A<VQA\/T@>6]K+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*
M;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET
M:6]N(@IM<V=S='(@(MUS=&5N96X@:V]N=6UD82!H:>=B:7(@]F)E:R!B=6QU
M;FUA;6%K=&%D_7(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")-0T%,(&1O\')U;&%M87/](&GG
M:6X@:&GG8FER('1A:W9I;2!A9/T@<V'P;&%N;6%M_?YT_7(N("(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S
M='(@(D1E\&G^:6ML:6L@66]K(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(D)U(&EZ;F4@:&GG8FER(&%L
M="!I>FEN(&5K;&5N96UE>65C96MT:7(N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*
M(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L('!H<"UF;W)M870*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RXB"FUS9W-T<B`B)7,@:>=I;B!H:>=B:7(@>6%P_6QA;F3]<FUA
M(&)I;&=I<VD@8F5L:7)T:6QM961I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B1E10(%9&4R!I
MYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES:2!B96QI<G1I;&UE9&DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+B(*;7-G<W1R(")344P@5D93(&GG:6X@:&GG8FER('EA</UL86YD_7)M
M82!B:6QG:7-I(&)E;&ER=&EL;65D:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R
M(")344PM1FEL92!61E,@:>=I;B!H:>=B:7(@>6%P_6QA;F3]<FUA(&)I;&=I
M<VD@8F5L:7)T:6QM961I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N
M(@IM<V=S='(@(DMR961I('EO:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I
M;VX@<W5P<&QI960N(@IM<V=S='(@(DAIYV)I<B!T97-L:6T@;F]K=&%S_2!B
M96QI<G1I;&UE;6G^=&ER+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(")(
M:>=B:7(@9&]S>6$@>?QK;&5N96UE9&DB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(")(:>=B
M:7(@<VEM9V4@8G5L=6YA;6%D_2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T
M+B(*;7-G<W1R(")(:>=B:7(@>65R(&)E;&ER=&EL;65D:2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B2&GG8FER('EE<B!B96QI
M<G1I;&UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM
M<V=S='(@(DAIYV)I<B!M97-A:B!S8?!L86YM863]+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").
M;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B060@8F5L:7)T:6QM961I+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").=6UA
M<F$@8F5L:7)T:6QM961I+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E-A;&3]
M<F=A;B!D97EI_B!K=6QL86YM82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(
M5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")(5%10(&1O\')U;&%M87/]
M(&GG:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DE-05`@9&_P<G5L
M86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R
M8F5R;W,@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U
M=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DQO9VEN(&1O\')U;&%M87/]
M(&GG:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")005-35T0@
M9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4TU"
M(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO
M('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E
M;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N(@IM<V=S='(@(B(*(D]P96Y34TP@:6MI;&ES:6YE(&AIYV)I
M<B!Y;VP@8G5L=6YA;6%D_2Y/<&5N4U-,(&EK:6QI<VD@4$M#4R`Q,B!V97)I
M<VEY;&4@(@HB8V%L_?YM86L@:>=I;B!G97)E:VQI+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@
M<VEG;G5P<RXB"FUS9W-T<B`BW'EE(&]L;6%K(&GG:6X@8F5K;&5Y96X@>6]K
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B0F5L:7)T
M:6QM96UI_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DMU<F%L
M('EO:R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B
M3G5M87)A(&)E;&ER=&EL;65D:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*
M;7-G<W1R(")986X@>6]K(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HU.#,*(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(")9
M86X@>6]K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM
M<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+B(*;7-G<W1R("+6;F)E;&QE:R!IYVEN(&=EYVEC:2!D:7II;B!B=6QU
M;F%M863]+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@
M<V5N="XB"FUS9W-T<B`B2W5L;&%N_6/](&%D_2!V92]V97EA('!A<F]L82!G
M]FYD97)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S
M='(@(D=EYV5R;&D@6$U,('9E<FES:2!G97)I(&3V;FUE9&DN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO
M('9A;'5E<R(*;7-G<W1R(")$9?!E<B!Y;VLB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I
M;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BUGIG_&X@>6%P_6QA;F3]<FUA9&$@<_QR_&T@8G5L=6YA;6%D
M_2Y987#];&%N9/UR;6%Y_2!T96MR87(@_')E=&EN+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@
M>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(M9Z9_QN('EA</UL86YD_7)M86[]>F1A('/\<OQM(&)U;'5N
M86UA9/TN66%P_6QA;F3]<FUA>?T@=&5K<F%R(/QR971I;BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM
M<V=S='(@(DAIYV)I<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM
M<V=S='(@(DAIYV)I<FD@*-9R=/QL_"!K=6QL86[];BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB
M"FUS9W-T<B`B2W5Z97D@079R=7!A;/T@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]L
M:R!!9&%S_2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B2W5Z97D@66%R_6UK_')E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T
M:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B2W5Z97D@36%R:6%N82!!
M9&%L87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B
M3F]R=F7G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")3;VYR87/];F1A($1E\&EL
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`BUFYC97-I;F1E($1E\&EL(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D
M:7)E8W1O<GDB"FUS9W-T<B`B1&EZ:6X@9&7P:6PB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")'
M97+G96ML9?YT:7)I;&UE;6G^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")"
M96QI<G1I;&UE;6G^(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(D1E<W1E:VQE
M;FUI>6]R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M3F]T;&%R(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS
M9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B1_9Z
M(&%T_6QA8V%K(&)I<OYE>2!Y;VLL(&=E<FD@9/9N_&XN(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M
M8F5R(@IM<V=S='(@(DMA<_UM(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(E-A>?TB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA
M<F%C=&5R<R(*;7-G<W1R(")+87)A:W1E<B!S87G]<_TB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M
M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B2V]L;VX@<V%Y_7/](@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@
M(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(E-A=/UR('-A>?US_2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")$8?#]=/UM(&QI<W1E;&5R:6YI
M;B!G_&YC96QL96YM97-I(&GG:6X@;G5M87)A;&%R(&)E;&ER=&EL;65M:?XN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T
M"FUS9VED(")/2R(*;7-G<W1R(")%=F5T(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S
M='(@(DYE<VYE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*
M;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(DYE<VYE(%EA<F%T_6/]
M<_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/
M8W1A;"(*;7-G<W1R(")396MI>FQI:R!3:7-T96TB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*
M;7-G<W1R(")%:VEM(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS
M9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")386QD_7)G86YL_6L@<_QZ
M9V5C:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@
M(D]F9FEC92(*;7-G<W1R(")/9FES(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S
M="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D
M(@IM<V=S='(@(E!A<F]L82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C
M;W)R96-T+B(*;7-G<W1R(")986YL_?X@<&%R;VQA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")/;6%N(@IM<V=S='(@(E5M;6%N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S
M97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E-A9&5C
M92!)34%0('-U;G5C=6QA<OT@<&%Y;&'^_6QA;B!D:7II;FQE<FD@9&5S=&5K
M;&5M96MT961I<BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E-A9&5C92!S
M86QD_7)G86X@9&5Y:?YL97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N
M;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B4V%D96-E
M(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:6YE(&EZ:6X@=F5R:6QM96MT
M961I<BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@
M(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E(@IM<V=S='(@(B(*(D)I<B!P87EL8?[];?UN('-A:&EP;&GP
M:6YI('9E>6$@<V%H:6)I;FD@<V%D96-E('-I<WEE;2!Y]FYE=&EC:7-I('9E
M>6$@(@HB<V%H:6)I(&1E\&G^=&ER96)I;&ER+B(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R(")996YI('!E;F-E<F5D92!AYR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*
M;7-G<W1R(")/<&5N4U-,(&AA=&%S_3K=;7IA;&%N;?W^(%,O34E-12!P87+G
M87/];F1A;B!V97)I('-EYVEP(.?]:V%T_6QA;6%D_2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G
M:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M0G4@8F'P;&%N=/UY_2!Y96YI('!E;F-E<F5D92!AYR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G
M<W1R("+=_FQE=&EM(%-I<W1E;6DB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(E-EYV5N96ML
M97(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B)7,@:>=I;B!S9>=E;F5K;&5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E
M9"!,:7-T(@IM<V=S='(@(E/]<F%L86YM_?X@3&ES=&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T
M:6]N(@IM<V=S='(@(DMU<G5L=?XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*
M;7-G<W1R(")+=7)U;7-A;"!":7)I;2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B1/QZ96YL
M96UE(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(M9Z9_QN('5Y9W5L
M86UA('1A<VQA\/TB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM
M<V=S='(@(B5S(&GG:6YD96MI(/9Z9_QN('1A<VQA:VQA<CHB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B1&GP97(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO
M;B(*;7-G<W1R(")$:?!E<B!":6QG:6QE<B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(E-A:&EP(&EZ:6YL97)I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B4$%-(&1O\')U;&%M87/](&UE=F-U="!D9?!I
M;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")0
M1U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0(%-A>?US86P@W6UZ
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G
M:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@WFEF<F5L96YM
M:?X@5F5R:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"!!Y_UK($%N
M86AT87+](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U
M,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")0
M1U`@:6QE(-UM>F%L86YM_?XOWFEF<F5L96YM:?X@5F5R:2(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0
M($MO9'4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3
M:&5L;"(*;7-G<W1R(")02%`@2V%B=?!U(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB
M"FUS9W-T<B`BUE,@2&%F:68@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS
M9W-T<B`BUE,@4V'P86YA:VQA<OTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("+6
M4R!+87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(M93($MA<B!3
M8?!A;F%K;&%R_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")032!3=6XB"FUS9W-T<B`BUE,@
M2V%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(M93($?V:R!G_'+\;'3\
M;/P@9OUR=/UN82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G
M:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")0
M7TA0($MA8G7P=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B66%S
M=/UK;&%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T
M<B`B4&%K:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G
M<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`BW?YG86P@161I;&UI_B!&
M:6QI<W1I;B!"]FQG97-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B
M"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.
M97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A(%EE;FD@1VEN92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@
M(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B2_US;65N($)U;'5T;'4B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED
M(")087-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*
M;7-G<W1R(")986YL_?X@<&%R;VQA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4D%$2553(&1O\')U
M;&%M87/](&GG:6X@<&%R;VQA(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VXB"FUS9W-T<B`B3VYA>6S](%!A<F]L82(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM
M<V=S='(@(E!A<F]L83HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")087)O;&$Z(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I
M9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(E!A<F]L86QA<B!E
M_FQE_FUE:R!Z;W)U;F1A9/UR+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")987#]_G3]<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@
M(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(E!A;F]D86X@>6%P_?YT
M_7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Q"FUS9VED(")0871H(@IM<V=S='(@(EEO;"(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM
M<V=S='(@(D)E:VQE>65N(-QY96QI:VQE<CHB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R("+=;G-A;FQA<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W
M"FUS9VED(")097)C96YT(@IM<V=S='(@(EG\>F1E(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")"86O];2#=_FQE
M;6QE<FEN:2!'97+G96ML9?YT:7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(D)A:_UM(&G^;&5M;&5R:2!G:7)I_G1E(&=E
M<N=E:VQE_G1I<FEL<VEN(&UI/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(MUZ:6XB
M"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB
M"FUS9W-T<B`BW7II;B`G)7,G('-I;&EN96UE9&DN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I
M;VX@1&5N:65D(@IM<V=S='(@(MUZ:6XB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$V-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B7TAA
M:VQA<B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(MUZ:6X@6?9N971I;6DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DMI_FES96P@0FEL9VEL97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")%=F-I;"!(87EV
M86YL87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S
M='(@(D9I;&EP:6YL97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO
M=&]S(@IM<V=S='(@(D9O=&_P<F%F;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS
M(@IM<V=S='(@(E)E<VEM($)I<FEM:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")"97EL:6L@4_9Z
M;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M(@IM<V=S='(@(DS\=&9E;B!B:7)K8><@:/QC<F5Y92!T_6ML87G];B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("),_'1F96X@8G4@]O!E>6D@
MY_UK87)M86L@:7-T961I\&EN:7II(&1O\')U;&%Y_6XZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N(@IM<V=S='(@(DS\=&9E;B!B=2#V\&5N:6X@8F'P_6[]
M(.?V>FUE:R!I<W1E9&GP:6YI>B!D;_!R=6QA>?UN+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(DS\=&9E;B!B:7(@87D@=F4@8FER
M('G];"!G:7)I;BXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@
M=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B3/QT9F5N('EE;FD@:V%T96=O
M<FEN:6X@863];OT@9VER:6XZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S
M<RXB"FUS9W-T<B`B3/QT9F5N(&=EYV5R;&D@8FER($E0(&%D<F5S:2!G:7)I
M;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("),_'1F96X@9V7G97)L:2!B
M:7(@9_QN(&=I<FEN+"!A>61A:VD@9_QN('-A>?US_6[](&MO;G1R;VP@961I
M;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("),_'1F96X@9V7G
M97)L:2!B:7(@>F%M86X@9VER:6XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("),_'1F96X@<V]R=6YU;B!B:7(@
M]GIE=&EN:2!Y87#];BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@
M(DS\=&9E;B!K=6QL86[]8_T@863]('9E('!A<F]L86[]>OT@9VER:6XB"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@
M(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM
M<V=S='(@(B(*(DS\=&9E;B!M971N:2!O:W5Y=6XN(%-I<W1E;6D@:W5L;&%N
M86)I;&UE:R!IYVEN(&MU;&QA;OUM(&MO_G5L;&%R_6[]($M!0E5,("(*(F5T
M;65K('IO<G5N9&%S_6[]>BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE
M(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("),_'1F96X@>65N:2!K871E
M9V]R:6YI(&%D_2!G:7)I;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N
M9"(*;7-G<W1R(")0;VQO;GEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI=&EK82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S
M='(@(D]Y;&%M86QA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L
M(@IM<V=S='(@(E!O<G1E:VEZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(D?V<OQN=/P@:V]N=6UL86YD
M_7+];/UY;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*
M;7-G<W1R("+':7IE;&=E(&MO;G5M;&%N9/UR_6S]>6]R(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@
M=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R
M(")"=2!D:7II;F4@9_9N9&5R("A)34%0('1A<F%F_6YD86X@>F]R;&%N;6%M
M86MT863]<BDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")3;VX@)7,@
M<V%A='1E(&3\_F5N('EA\&UU<B!V92!K87(@;6EK=&%R_3HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L
M9&%P.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@W7-T96YE;B!O='5R=6T@
M=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B0F%S_6[G(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L
M979E;#H@(@IM<V=S='(@(D1E;FEZ('-E=FEY97-I;F1E:VD@8F%S_6[G.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`B0F%S_6[G.B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0
M<F5V:65W(@IM<V=S='(@(M9N:7IL96UE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B1_9R
M_&YT_'G\('EE;FD@<&5N8V5R961E(/9N:7IL92(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(M9N
M8V5K:2!S9>=E;F5K;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T
M<B`B0F5L9V5Y:2!Y87ID_7(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(M9Z96P@
M06YA:'1A<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4V]R=6XB"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B4V]R=6X@5&%N_6UL86UA<_TB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J
M96QE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")-971I;B!B
M:6QG:2!I<W1E;6DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B0>?]:R!!;F%H=&%R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G
M:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D'G_6L@06YA:'1A
M<B!A;&=O<FET;6%S_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS
M9W-T<B`B0>?]:R!!;F%H=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!Y_UK+]9Z96P@
M86YA:'1A<B!I:VEL:7-I(&)A_F%R_7EL82!Y87)A=/UL86UA9/TN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4&]R=&\@
M4FEK;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(DMA
M=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*
M;7-G<W1R(")3;W)G=2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC
M+"!F=7IZ>0IM<V=I9"`B475O=&$B"FUS9W-T<B`B2V%T87(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")24T$@
M0>?]:R!!;F%H=&%R_2`H)60@8FET*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")2
M861Y;R!39>=I;6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")98?!M=7(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B
M4F%I;B!%87)L>2(*;7-G<W1R(")%<FME;B!386%T;&5R9&4@66'P;75R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G
M:60@(E)A:6X@3&%T92(*;7-G<W1R(")'9><@4V%A=&QE<F1E(%EA\&UU<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")38?!A;F%K(%EA\/W^(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B66'P;75R('9E($MA<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")2
M86EN('1O(%-N;W<B"FUS9W-T<B`B2V%R82!D]F[\_F5C96L@>6'P;75R(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T
M=6YE(@IM<V=S='(@(E)A<W1G96QE($1E>6G^(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")/<F%N
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G
M:60@(E)E860B"FUS9W-T<B`B3VMU;6$B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*
M;7-G<W1R("+=;&5T:6QE<FD@3VMU(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(B(*(E-I;&UE:R!I<W1E9&GP:6YI>F4@9V5RYV5K=&5N(&5M:6X@
M;6ES:6YI>C\H0G4@:?YL96T@9V5R:2#G979R:6QE;65Z*3HE<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)+
M=6QL86[]8_T@)7,@92!A:70@:W5L;&%N_6/]('9E<FEL97)I;FD@<VEL;65K
M(&ES=&5D:?!I;FEZ92!E;6EN(&UI<VEN:7HN($)U("(*(FG^;&5M(&=E<FD@
MYV5V<FEL96UE>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R(")3;VX@97EL96UI('1E:W)A<FQA(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@
M(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM
M<V=S='(@(D1E=FEN9V5N($UE;OP@UO!E;&5R:6YI(%1A>F5L93HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2969R97-H(%!O<G1A
M;"!6:65W.B(*;7-G<W1R(")0;W)T86P@1_9R_&[\;?QN_"!487IE;&4Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S
M-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B1/QZ96YL:2#=9F%D92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI
M<"!"<F]W<V5R(@IM<V=S='(@(MUL:?YK:2!487)A>?UC_2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")/
M:W5M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA
M<FMS(@IM<V=S='(@(D'G_6ML86UA;&%R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B57IA
M:W1A:VD@4W5N=6-U;&%R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B57IA:W1A:VD@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")3:6PB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*
M;7-G<W1R("+68F7P:2!3:6PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S
M='(@(DMO;&]N=2!3:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G
M<W1R(")":>=I;6QE;65Y:2!3:6PB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B26MI;&EY
M:2!3:6PB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B2V%Y9&5D:6QM:?X@8F5T:?!I('-U;G5C=6YU
M(&=EYVEC:2!D:7II;FEN9&5N('-I;"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V
M92!T:&4B"FUS9W-T<B`B4VEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D)U('!A<N=A>?T@
M8F5L9V5D96X@Y_UK87)T(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B2W5L;&%N
M_6/](%-I;"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T
M<B`B2W5L;&%N_6/]>?T@<VEL.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("+=<W1E:R!C
M979A<&QA;F%M863]+D3V;OQL96X@:&%T82!K;V1U.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")297%U
M97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(EG\
M:VQE;F5N(&1O<WEA(&MA>61E9&EL96UE9&DN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(D=E<F5K96X@)R5S)R`E<R!Y87#];&%N9/UR;6%S_6YD82!B96QI<G1I;&UE
M;6G^+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")'97)E:V5N("<E<R<@5D93('EA</UL86YD_7)M
M87/];F1A(&)E;&ER=&EL;65M:?XN(@H*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")'97)E:V5N("<E<R<@>6%P_6QA;F3]<FUA9&$@8F5L:7)T:6QM96UI
M_BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*
M;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(D=E<F5K96X@06QA;B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R
M(")496UI>FQE(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*
M;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E!A<F]L87G]('/]9OUR
M;&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")087)O;&%N_7K]('/]9OUR
M;&%Y_6XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"B,L(&9U>GIY"FUS
M9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`BWFG^:VEN($%Y(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR
M."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T
M<B`B4V]N=>=L87(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T
M;R!/<'1I;VYS(@IM<V=S='(@(E-EYV5N96ML97)E($3V;OQN(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")2
M971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L87G]('/]9OUR;&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)E=6YI
M;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(EEA</UL86YD_7)M87G]($=E<FD@1/9N9/QR(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/
M<'1I;VYS(@IM<V=S='(@(EIE;F=I;B!-971I;B!$_'IE;FQE>6EC:7-I(%-E
MYV5N96ML97)I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED
M(")2:61D;&5S(@IM<V=S='(@(D)I;&UE8V5L97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I
M9VAT(@IM<V=S='(@(E-A\"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")38?`@8F'^;/UK
M(&)I;&=I<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS
M9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B1&_P<G4@9&7P97)L97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")385]T
M_7(@UGIE;&QI:VQE<FDN+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(D?V<F5V
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2;VUA
M;GEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(Q.#`@9&5R96-E(&3V
M;F3\<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(E-O;&$@1/9N9/QR
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(E-A\&$@1/9N9/QR(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B4V%T_7(@UGIE
M;&QI:VQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R
M(")3873]<B#V>F5L;&EK;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")3
M873]<FQA<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R("+':7IG:6QE
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BQVEZ9VEL97(@=/QM('-A=/UR
M('9E(&MO;&]N;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM
M<V=S='(@(L=I>F=I;&5R('-A9&5C92!K;VQO;FQA<B!A<F%S_6YD82!B96QI
M<F5C96MT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>2(*;7-G<W1R("+':7IG:6QE<B!S861E8V4@<V%T_7)L
M87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(L=A;/W^=/UR(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U
M<WEA($9E9&5R87-Y;VYU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A
M(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4B"FUS9W-T<B`B4R]-24U%(-YI9G)E;&5M92#=;7IA<_TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E,O34E-12!I;&4@WFEF
M<F5L96YM:?X@W6QE=&DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN
M<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(E-!4TP@9&_P<G5L86UA<_T@;65V8W5T(&1E\&EL
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*;7-G:60@(E--
M4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3($UE<V%J;&'^;6$B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")3
M44P@2V%B=?!U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM
M<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")3
M4T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#
M0T534R(*;7-G<W1R(")"0=Y!4DE,22(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM
M<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")37U%,($MA8G7P=2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@
M(E-A(@IM<V=S='(@(D-T<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT
M($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN="!+
M:71T<R!V92!.979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C
M:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED
M(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT(%!I
M97)R92!V92!-:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I
M;F-E;G0@=F4@1W)E;F%D:6YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF
M*2(*;7-G<W1R(")!>6[](.=E<N=E=F4@*&ME;E]D:7-I*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM
M<V=S='(@(E-A;R!4;VUE('9E(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R
M(@IM<V=S='(@(E5Y9'4@4V'P;&%Y_6/](@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-U=61I($%R86)I<W1A;B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*
M;7-G<W1R(")+87ED970B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB
M)7-<(B(*;7-G<W1R(")+87ED970@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM
M<V=S='(@(DMA>61E="`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")39>=E;F5K;&5R:2!+
M87ED970B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B
M"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*(D]L=?YT=7)U;&%N('EA</UL86YD_7)M87G](%!(4"!B971I
M\&D@;VQA<F%K('-U;G5C=6YU;B!G9>=I8VD@9&EZ:6YI;F4@(@HB:V%Y9&5T
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B5S
M('EA</UL86YD_7)M87/](&MA>61E9&EL9&DN(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A
M=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@
M(D%Y87(@9_QN8V5L;&5M92!B971I\&D@:V%Y9&5D:6QD:3H@)R5S)RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0HC+"!F
M=7IZ>0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(EEA;/UT
M_6QM_?X@9_9K(&?\<OQL=/QL_"!F_7)T_6YA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(D)I;&EM(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R
M(")!<F%M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G
M:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(D%R86UA($UO=&]R;&%R_2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C
M="!&:6QE<R(*;7-G<W1R(")$;W-Y86QA<OT@4V7G(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`IM<V=I9"`B4V5L96-T
M(&$@9&%T92(*;7-G<W1R(")":7(@=&%R:6@@<V7G:6XB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@
M=&\@861D(@IM<V=S='(@(D5K;&5M96L@:>=I;B!B:7(@9W)U<"!S9>=I;B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C
M="!A(&YE=R!O=VYE<B(*;7-G<W1R(")996YI('-A:&EB:2!S9>=I;B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T
M(&$@<V5R=F5R(@IM<V=S='(@(D)I<B!S=6YU8W4@<V7G:6XB"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E
M<B!T;R!A9&0B"FUS9W-T<B`B16ML96UE:R!IYVEN(&)I<B!K=6QL86[]8_T@
M<V7G:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<W"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(D1O
M<WEA;&%R_2!39><B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S
M"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B
M0OQT_&X@=&%R:6@@8FEL9?YE;FQE<FEN:2!S9>=I;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C
M="!A;B!O8FIE8W0B"FUS9W-T<B`B0FER(&YE<VYE('-EYVEN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B665N:2!S86AI8FD@<V7G
M:6XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B+=<W1E9&GP;FEZ(&MA<F%K
M=&5R;&5R:2!A_F'P_61A:VD@:W5T=6QA<F1A;B!S9>=I;BX@1&%H82!S;VYR
M82!M971I;B`B"B)A;&%N_6YD86X@:V]P>6%L87G]<"!Y87#]_G3]<F%B:6QI
M<G-I;FEZ+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")487)I:"!S
M_6[]<FQA>?UC_7/];OT@<V7G_6XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S
M='(@(E1A<FEH(&)IYVEM:6YI('-EYVEN.B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")$9?!I_G1I<FUE
M:R!I<W1E9&GP:6YI>B!K:6UL:?!I('-EYVEN.B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.B(*;7-G<W1R(")386%T('/];OUR;&%Y_6/]<_UN_2!S9>=I;CHB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V%A="!B:>=I;6EN:2!S9>=I;CHB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE
M8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B1?YL9?YE;B!I:VD@
M86QA;OT@<V7G:6XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM
M<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")296YK
M(&3\>F5N:6YI>FD@<V7G:6XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*
M;7-G<W1R(")497)C:6@@971T:?!I;FEZ(&1I;&D@<V7G:6XZ(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O
M8FQE;2!297!O<G0B"FUS9W-T<B`B4V]R=6X@4F%P;W)U($?V;F1E<B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS
M9VED(")396YD(%--4R(*;7-G<W1R(")335,@1_9N9&5R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(D%L9_UL87G]8_TZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")%>6S\;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED
M(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4_UR8FES=&%N('9E
M($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")397)I($YU
M;6%R87/](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC
M+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B2&%V82!R87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL
M:7(@9&7P:6PN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY
M"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(MUZ:6X@6?9N971I;6DB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B3W1U
M<G5M(&MI;6QI\&EN:6X@<_QR97-I(&1O;&1U+B(*"B,Z(&QI8B]A<&DN<&AP
M.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B7TAA:VQA
M<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E
M="(*;7-G<W1R(")"96QI<G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B
M(@HB4&%R;VQA;OUZ_6[]('5N=71U<G-A;OUZ('/]9OUR;&%M86[]>F$@:7II
M;B!V97)E8V5K('-EYV5N96ML97)I(&)E;&ER=&EN+B`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB
M"FUS9W-T<B`B56QA_FUA:R!I<W1E\&EN:7H@=7IA:W1A:VD@<W5N=6-U;&%R
M_2!B96QI<FQE>6EN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM
M<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")497)C:6@@971T:?!I;FEZ(&1I
M;"P@<V%A="!D:6QI;6D@=F4@=&%R:6@@<V7G96YE:VQE<FEN:2!B96QI<FQE
M>6EN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N
M(@IM<V=S='(@(B(*(D)A_FQA;F?]YR!U>6=U;&%M86[]>OTL(')E;FL@9/QZ
M96YI;FEZ:2P@<V%Y9F$@=&%Z96QE;64L('9E(&1I\&5R(&?V<OQN=/P@(@HB
M<V7G96YE:VQE<FEN:2!B96QI<FQE>6EN+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(D%Y87)L87(B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")+=7)U
M;'5M(&?\;F-E;&QE;64@8F5T:6ML97)I(&MU;&QA;OUL86)I;&ER(&1U<G5M
M9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I
M9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B"FUS9W-T<B`B1&7P:?YT:7)G92!I;&4@8FER9&5N(&9A>FQA('EE
M<B!M_&UK_&XZ("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`B4V5Y_F5L(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B06S]_B!V97)I_B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R
M="!3=6UM87)Y(@IM<V=S='(@(DO]<V$@UGIE="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("+';_!U(&)A\&QA;G3]
M(&GG:6X@97)I_FEM(&%N86AT87+]('1A;OUM;&%N<_UN(&W]/R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W
M(@IM<V=S='(@(D?V<W1E<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HB2&%L96X@:V%Y_71L_2!O;&%N('EA</UL86YD
M_7)M82!I;&4@>65N:2!Y87)A=/UL86X@>6%P_6QA;F3]<FUA(&%R87/];F1A
M:VD@(@HB9F%R:VQA<OT@9_9S=&5R+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G
M9VEN9R!I;C\B"FUS9W-T<B`B1VER:?YT92!E;B!S;VX@9VER:?X@=&%R:6AI
M(&?V<W1E<FEL<VEN(&UI/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`BUGIG_&X@;VQA;OT@<V%K;&%M82!S9>=E;F7P:6YI(&?V<W1E<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@
M<&EC:V5R(@IM<V=S='(@(E-EYVEC:7EI(&?V<W1E<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\B"FUS9W-T<B`BQVEZ96QG92!I_FQE;6QE<FD@;65N_"#G
M=6)U\'5N9&$@9_9S=&5R:6QS:6X@;6D_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/R(*;7-G<W1R("(E<R!-96[\<_P@<V]L9&$@9_9S
M=&5R:6QS:6X@;6D_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#
M96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A8FQO($C\8W)E(-9Z
M96QL:6ML97)I($MU='5S=6YU(&?V<W1E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%B;&\@
MUGIE;&QI:VQE<FD@2W5T=7-U;G4@9_9S=&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M5&%B;&\@4V%T_7(@UGIE;&QI:VQE<FD@2W5T=7-U;G4@9_9S=&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(")']G+\;G3\(/9Z96QL:6ML97)I(&MU='5S=6YU(&?V<W1E<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@
M=7!L;V%D(@IM<V=S='(@(EG\:VQE;65Y:2!G]G-T97(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R
M<R(*;7-G<W1R(")38?!A;F%K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T
M<B`B17)K96X@4V%A=&QE<F1E(%-A\&%N86LB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E
M(@IM<V=S='(@(D=EYR!386%T;&5R9&4@4V'P86YA:R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S
M(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("+'979R961E(%-A\&%N86LB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@
M(E-H<FEN:R(*;7-G<W1R(")+_.?\;'0B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM
M<V=S='(@(MUL:R!O;&%R86L@:V]M_G4@]O!E;&5R(&O\Y_QL='/\;B!Y861A
M('1A_OUN<_UN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE
M(@IM<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`BW'EE
M(&]L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*
M;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+=;7IA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!
M;&=O<FET:&TB"FUS9W-T<B`BW6UZ82!!;&=O<FET;6%S_2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!U<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS
M9W-T<B`B0F]Y=70B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R
M(")"86O];?T@071L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA
M(@IM<V=S='(@(E-L;W9A:WEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F5N:6$B"FUS9W-T<B`B4VQO=F5N>6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R(")+
M87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B2V%R(%-A\&%N8?#](@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G
M:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")+87(@4V'P86YA:VQA<OTB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I
M9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(D5R:V5N(%-A871L97)D
M92!+87(@4V'P86YA:VQA<OTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS
M9W-T<B`B1V7G(%-A871L97)D92!+87(@4V'P86YA:VQA<OTB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S
M='(@(DMA<B!$97)I;FQI\&DZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R
M(")98?!A;B!K87+];B!S=2!E_FET:3H@(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O;&]M;VX@061A;&%R_2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F
M(%!O96US(@IM<V=S='(@(MYA<FO];&%R("8@WFEI<FQE<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L
M96-T:6]N(@IM<V=S='(@(E/]<F%L86UA(&3\>F5N:2!S9>=I;6DB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")+87EN86L@861R
M97-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S
M='(@(D?\;F5Y($%F<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP
M"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B
M1_QN97D@079R=7!A("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',B"FUS9W-T<B`B1_QN97D@1V5O<F=I82!V92!'_&YE>2!386YD=VEC:"!!
M9&%L87+](@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M
M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R
M(")'_&YE>2!987+];6O\<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<R(*;7-G<W1R(")":71I_FEK(&C\8W)E;&5R(&%R87/];F1A
M:VD@8F_^;'5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@
M8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B2/QC<F5D96MI('/];OUR('9E(&GG
M97)I:R!A<F%S_6YD86MI(&)O_FQU:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(D)O_FQU:R!!>6%R
M;&%Y_6/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(D%R86S]:R!B
M_7)A:VUA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G
M<W1R(")!<F%L_6L@8OUR86MM82!V92!Y87-T_6ML86UA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(MUS<&%N>6$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`BW7-T
M96YM97EE;B#=;&5T:2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM
M<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`BUGIE;"!+
M87)A:W1E<B!':7)I_FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(DC\8W)E>6D@8O9L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM
M<V=S='(@(DMO;&]N=2!B]FPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS
M9W-T<B`B4V%T_7+](&+V;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)L87(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<G0B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*
M;7-G<W1R(")5>F%Y(%EO;'4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T
M87)T('EE87(B"FUS9W-T<B`B0F'^;&%N9_WG('G];/TB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@
M4')O=FEN8V4B"FUS9W-T<B`B17EA;&5T('9E>6$@W6PB"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM
M<V=S='(@(D1U<G5M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1&5P;VQA;6$@8FGG
M:6UI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*
M;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(E-O:V%K($%D<F5S:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*
M;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`BW'-T_"#G:7IG:6QI(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG
M(&QI<W0B"FUS9W-T<B`B1&EZ9VD@;&ES=&5S:2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H
M92!A9&1R97-S(@IM<V=S='(@(D%D<F5S=&5N(&%L86X@863];OT@Y_UK87)T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4VET:6P@6T-3
M4UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8R"FUS9VED(")3=2(*;7-G<W1R(")0>G(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")!;'1D:7II;B`G
M)7,G(&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")+;VYU
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(D?V;F1E<B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO
M=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB
M)R5S)R!I;B!S:7-T96UE(&5K;&5N;65S:2!I<W1E\&EN:7H@9_9N9&5R:6QD
M:2X@W7-T9?!I;FEZ(&]N87EL86YA(&MA9&%R("(*(F=I<FG^('EA<&%M87IS
M_6[]>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B06QT<VEM9V4B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G
M:60@(E-U8V-E<W,B"FUS9W-T<B`B0F'^87+](@H*(SH@861M:6XO=7-E<BYP
M:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!B
M8?YA<OUY;&$@<VES=&5M92!E:VQE;F1I+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M+B(*;7-G<W1R("(G)7,G(&GG:6X@;VQA;B!V97)I(&)A_F%R_7EL82!S:7-T
M96UD96X@=&5M:7IL96YM:?YT:7(N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX
M,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(D)A_F%R_7EL82!S:6QI;F1I("<E<R<N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")3
M:7-T96UD96X@8F'^87+]>6QA('-I;&EN9&D@)R5S)RXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G
M<W1R("(B"B)987#];&%N9/UR;6$@8F'^87+]>6QA(&=E<FD@9/9N9/QR_&QD
M_"X@1&7P:?YI:VQI:VQE<FD@9_9R;65K(&GG:6X@>65N:61E;B`B"B)Y_&ML
M97EI;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B665D96L@>6%P_6QA;F3]
M<FUA(&)A_F%R_7EL82!K87ED961I;&1I+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R(")9961E:R!Y87#];&%N9/UR;6$@9&]S>6%S_2`E<R!B8?YA<OUY;&$@
M:V%Y9&5D:6QD:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<
M(B(*;7-G<W1R("(G)7,G(&)A_F%R_7EL82!G_&YC96QL96YD:2(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E
M<R(*;7-G<W1R("(E<R!B8?YA<OUY;&$@>6%Z_6QD_2XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=61A;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@
M(E-U;6UA<GDB"FUS9W-T<B`BUGIE="(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B1_QN($1O\'5M=2(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*
M;7-G<W1R(")'_&X@8F%T_6W](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(D?\;F7^
M;&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED
M(")3=6YR:7-E(@IM<V=S='(@(D?\;B!D;_!U;74B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@
M(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(D?\;B!D;_!U;74O1_QN(&)A=/UM
M_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@
M(E-U;G)I<V4Z("(*;7-G<W1R(")'_&X@9&_P=6UU.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T
M<B`B1_QN(&)A=/UM_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(D?\;B!B873];?TZ("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*
M;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(MQS='-I;6=E(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM<V=I9"`B4W5P<&]R="(*;7-G
M<W1R(")$97-T96LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*
M;7-G<W1R(")3=7)I;F%M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4V]Y863](@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*
M;7-G<W1R(")3=F%L8F%R9"!V92!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W9A>FEL86YD(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(MUS=F7G(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(MUS=FGG<F4B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@HC+"!F=7IZ>0IM<V=I
M9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3:6QM97EI;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G
M:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B07)A
M;6$@=&5R:6UL97)I;F1E('/V>F1I>FEM(&AA=&%S_2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-U<FEY
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P
M"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D?V:R!G_'+\;'3\;/P@9OUR=/UN
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q
M"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3
M=&]R;7,B"FUS9W-T<B`B1_9K(&?\<OQL=/QL_"!F_7)T_6YA;&%R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z
M>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(D5R:V5N(%-A871L
M97)D92!38?!A;F%K(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP
M.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6(&1O<WEA<_TB"@HC
M.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B
M"FUS9W-T<B`BQVEZ96QG92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I
M97,B"FUS9W-T<B`BQTEZ96QG92#6>F5L;&EK;&5R:2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G
M:60@(E1A8FQE(%-E="(*;7-G<W1R("+':7IE;&=E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B
M5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("+':7IE;&=E(/9Z96QL:6ML97)I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@
M(E1A>79A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@
M(E1A>79A;BP@QVEN(&5Y86QE=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M86II:VES=&%N(@IM<V=S='(@(E1A8VEK:7-T86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(E1A;GIA;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")(961E9CHB"@HC
M.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(D?V<F5V;&5R(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@
M(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L969O;B!.=6UA<F%S_2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R(")3;VX@<V%A="!IYVEN('/]8V%K;/UK.B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U
M<F4B"FUS9W-T<B`B4_UC86ML_6LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E/]
M8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B<E
M<R<@=&%S;&'P_2!B=6QU;F%M863]+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")487-L86L@6?9N971I;6DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E
M>'0B"FUS9W-T<B`B365T:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B4V%D96-E($UE=&EN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")-971I;B!H:7IA;&%M
M87/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")-971N:6X@W'-T_"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G
M:60@(E1H(@IM<V=S='(@(E!R_B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")486D@*%1)4RTV
M,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B
M5&%Y;&%N9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I
M9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R(")3
M:7-T96UI(&MU;&QA;OUD_?#];OUZ(&GG:6X@=&7^96MK_'(@961E<FEZ+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@
M1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")&5%`@
M=7IA;G3]<_T@:W5L;&%N_6QA8FEL:7(@9'5R=6UD82!D9?!I;"XB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B(&+\=/QN
M;&7^=&ER;64@;6]T;W)U(&1E<W1E:VQE;65M96MT961I<CH@7"(E<UPB(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@HC+"!F
M=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L
M:7IE9"XB"FUS9W-T<B`B6?QK;&5N96X@9&]S>6$@:V%Y9&5D:6QE;65D:2XB
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB
M"FUS9W-T<B`B0F%K_6TZ.B!S_6[]9B!B8?YA<OUY;&$@>?QK;&5N96UE9&DN
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I
M9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM
M<V=S='(@(MYEYV5N96ML97(@<&5N8V5R97-I(&MA<&%N9/TNQ_UK_?X@>6%P
M_6S]>6]R+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B
M"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D7P97(@:7II;FQE<FD@:W5L
M;&%N;6%K(&ES=&EY;W)S86[]>B!Y]FYE=&EC:6YI>FEN(-UZ:6X@<VES=&5M
M:6YI("(*(GEA</UL86YD_7)M87/](&=E<F5K;65K=&5D:7(N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM
M<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B4V%D96-E(&%L
M="!T87)A9B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(MUL971I_FEM(&YO
M:W1A<_UN_6X@240G<VD@8F5L:7)L96YE;65D:2P@8F_^(&+]<F%K_6QM_?X@
M=F5Y82!V97)I('1A8F%N_6YD82`B"B)B=6QU;F%M863]+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`BW6QE=&G^:6T@;F]K=&%S_2!B8?YA<OUY;&$@
M861R97,@9&5F=&5R:6YI>F4@96ML96YD:2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B+'_6MA<G3];&W]_B!01U`@
M:6UZ82#V8F7P:2!I;7IA;&%N;?W^(&EL971I;FEN(&1O\')U;'7P=6YU;B!S
M8?!L86YM87/](&GG:6X@(@HB9V5R96MM96MT961I<BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B
M(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A
M=&%B87-E+B(*;7-G<W1R("(B"B)$8?#]=/UM(&QI<W1E<VD@240G<VD@8F5L
M:7)L96YE;65D:2P@8F_^(&+]<F%K_6QM_?X@=F5Y82!V97)I('1A8F%N_6YD
M82`B"B)B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(D1A\/UT_6T@;&ES
M=&5S:2!B96QI<FQE;F5M961I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("+>:69R96QE
M;64@]GIE;&QI:VQE<FD@9_QV96YL:2!B:7(@=V5B(&)A\&QA;G3]<_T@9V5R
M96MT:7)M96MT961I<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N(@IM<V=S='(@(B5S(&1O<WEA<_T@)7,@87EA<OT@:>=E<FUE;&ED
M:7(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB
M"FUS9W-T<B`B)7,@9&]S>6%S_2`E<R!A>6%R;&%R_2!IYV5R;65L:61I<BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H
M92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R
M(")$;W-Y82!K96YD:2#\>F5R:6YE(&MO<'EA;&%N86UA>BXB"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R(")$;W-Y82!V97)I(&GG97)M:7EO<BXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI
M<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")486MI<"!E9&5N
M;&5R(&)U(&EL971I+W)F8S@R,B!I;&5T:7-I(&GG:6X@8F'^;/UK(&)I;&=I
M;&5R:61I<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K
M;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R
M+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE
M('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B
M86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@
M<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R
M96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D'^86UA9/WP_6W]>B!T87)A>?UC
M_2!H871A;&%R_2!S96)E8FEY;&4@=&%M(&5K<F%N(&MI<&EN:6X@26YT97)N
M970@(@HB17AP;&]R97(G;&$@8FER;&EK=&4@<V]R=6X@Y_UK87)D_?#](&)I
M;&EN;65K=&5D:7(N($%N;&%M<_UZ(&?V<OQN=/QL97)L92P@(@HBYV%L_?YM
M87EA;B!M971I;B!D_'IE;FQE>6EC:2!I_FQE<FEY;&4@=F4O=F5Y82!T87)A
M>?UC_6[];B!R87-T9V5L92`B"B+G]FMM97-I>6QE(&MA<O[];&'^86)I;&ER
M<VEN:7HN($7P97(@<VES=&5M:6YI>B!7:6YD;W=S(#EX(&ES92!Y_&MS96L@
M(@HB:6AT:6UA;"`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!H871A<_T@
M86S]<"!S:7-T96UI('EE;FED96X@8F'^;&%T;6%N_7H@(@HB9V5R96ME8V5K
M+EQ<;EQ<;D)U(&)I<B!U>6%R_7ED_2X@1?!E<B!H86QA('1A;2!E:W)A;B!M
M971I;B!D_'IE;FQE>6EC:7-I;FD@(@HB9&5N96UE:R!I<W1I>6]R<V%N_7H@
M179E="=I('3]:VQA>?UN+B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(DMI;6QI:R!<(B5S7"(@<VEL:6YD:2XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R
M(")3861E8V4@<V]L('1A<F%F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RXB"FUS9W-T<B`B0W)Y<'1?<&=P.CH@<_UN_6;];F$@1VYU4$<@:6MI
M;&ES:6YI;B!K;VYU;74@=F5R:6QM96L@>F]R=6YD863]<BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J
M96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO
M(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@
M=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB)7,@=&%R:6AI;F1E("5S(&4@9_9N
M9&5R:6QE;B!<(B5S7"(@:V]N=6QU(&EL971I(&?V<OQN=/QL96YD:2Y<;B(*
M(D)U(&EL971I;FEN(&]K=6YD=?!U('9E>6$@86YL8?[];&3]\/UN_2!G87)A
M;G1I;&5M96UE:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R(")/;'7^='5R('!E;F-E<F5S:6YE
M(&)A\&QA;OUR:V5N(&MU;&QA;OUL86-A:R!I<VEM(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(D)U(&%L
M86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L_63]<BXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R>7!T7W-I;64Z.B!S_6[]
M9OT@;W!E;G-S;"!B:7)I;6D@:>=I;B!G97)E:VUE:W1E9&ER+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)<(B5S7"(@=&5R8VEH:2!V97)I
M<VD@:7II;B!V97)I;&5N(&5N('G\:W-E:R!B;WEU='4@9V7G=&GP:2!IYVEN
M("(*(FMA>61E9&EL96UE;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"B)"=2!V97)I('EA<'/];OTH)7,I(&?V<W1E<FUE:R!IYVEN(&MU;&QA;OUL
M86X@<')O9W)A;2!S:7-T96UD92`B"B)B=6QU;FUA;6%K=&%D_7(N(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O
M=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY(@IM<V=S='(@(E-A9&5C92!S;VP@=F4@<V'P('1A<F%F;&%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@
M(E-A9&5C92!S8?`@=&%R868B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B7"(E<UPB('-U
M;G5C=7-U('-I;&EN9&DN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@
M:&%S(&)E96X@<V%V960N(@IM<V=S='(@(EPB)7-<(B!S=6YU8W5S=2!K87ED
M961I;&1I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N(@IM<V=S='(@(B5S(&GG:6X@;VQA;B#\>65L:6L@:7-T9?!I('-I
M;&EN9&DN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B0F5L:7)T:6QE;B!S873]<B!B=6QU;FUA;6%K=&%D_7(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B1V7G:6-I(&1O<WEA(%PB)7-<(B!B=6QU;FUA;6%K
M=&%D_7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I
M9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X
M="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")3861E8V4@_'-T
M('9E(&%L="!T87)A9FQA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O
M;FQY(@IM<V=S='(@(E-A9&5C92#\<W0@=&%R868B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")":7(@
M]FYC96MI(&%D_6T@<_UR87/];F1A('G\:VQE;F5N('9E<FD@:V%Y8F5D:6QD
M:2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B6?QK;&5N96X@
M9&]S>6$@:V%Y9&5D:6QE;65D:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L
M;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(G=E871H97(N8V]M(&MU
M;&QA;OUL86)I;&ER(&1E\&EL+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C
M=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")496UA(&1I>FEN:2`G
M)7,G(&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92XB"FUS9W-T<B`B2&GG8FER('-EYV5N96L@;65V8W5T(&1E\&EL+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(DUE=&YE(&?V;?QL_"!O;&%R86L@9_9S=&5R:6QE8FEL
M96-E:R!K_7/];2!Y;VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+B(*;7-G<W1R("(B"B)"=2!A;&%N9&$@YV]K(&9A>FQA(&MA<F%K=&5R('9A
M<BXE<R!T86YE(&MA<F%K=&5R(&=I<F1I;FEZ.R`E<R!T86YE9&5N(&%Z("(*
M(F=I<FUE;FEZ(&=E<F5K:7)D:2XB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN
M+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@
M)7,B"FUS9W-T<B`B)R5S)R!S:7-T96UE(&5K;&5N:7)K96X@8FER('-O<G5N
M(&]L=?YT=3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I
M;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B)R5S)R!K=6QL86[]8_UN_6X@=F5R:6QE<FEN:6X@<VES=&5M9&5N
M('-I;&EN;65S:6YD92!S;W)U;B!V87(Z("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B)R5S)R!K=6QL86[]8_US_6[]('-I<W1E;61E;B#G_6MA<G3];&UA
M<_UN9&$@<V]R=6X@=F%R.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(G)7,G(&?\;F-E;&QE;FER
M:V5N('-O<G5N(&]L=?YT=3H@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+B(*;7-G<W1R(")$;W-Y82`H:V%R_OUD86XI('G\:VQE;FUE<VEN
M9&4@<V]R=6X@=F%R.B`E<R!Y_&ML96YE;65D:2XB"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB1&]S>6$@>?QK;&5N:7)K
M96X@8FER('-O<G5N(&]L=?YT=3H@)7,@96X@8OQY_&L@:7II;B!V97)I;&5N
M(&)O>75T=&%N("@E9"`B"B)B>71E*2!D86AA(&+\>?QK+B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G
M<W1R(")$;W-Y82!Y_&ML96YI<FME;B!B:7(@<V]R=6X@;VQU_G1U.B`E<R!S
M861E8V4@:_US;6D@;VQA<F%K('G\:VQE;F1I+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S
M='(@(DEL971I;FEN(&)U(&O]<VW];OT@9_9R_&YT_&QE;FUE<VEN9&4@:&%T
M82!O;'7^='4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("+=;&5T:?YI;2!N;VMT87/];OUN
M('9E<FEL97)I("AIYV5R:2D@86MT87+];/UR:V5N(&AA=&$@;VQU_G1U+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M(@IM<V=S='(@(FE#86QE;F1A<B!V97)I<VD@*&GG97)I*2!A:W1A<OUL_7)K
M96X@:&%T82!O;'7^='4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX
M,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER
M960@9FEE;&0N(@IM<V=S='(@(B(*(EEA</UL86YD_7)M82!F;W)M=6YD82!B
M:7(@:&%T82!V87(N($=E<F5K;&D@8FER(&%L86[](&1O;&1U<FUA;?W^("(*
M(F]L86)I;&ER<VEN:7HN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"B)"96QI<G1I;&5N(&%D<F5S(&1E9G1E<FD@:?YL979I;FEN(&=E<N=E:VQE
M_G1I<FEL;65S:2!S_7)A<_UN9&$@<V]R=6X@(@HB;VQU_G1U+B!,_'1F96X@
M9&%H82!S;VYR82!T96MR87(@9&5N97EI;BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(MUL971I_FEM
M(&YO:W1A<_UN_6X@87ER_6YT_6QA<OUN_2!G_&YC96QL97)K96X@:&%T82!O
M;'7^='4N($S\=&9E;B!D86AA("(*(G-O;G)A('1E:W)A<B!D96YE>6EN+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"B)$8?#]=/UM(&QI<W1E<VEN:2!G_&YC96QL97)K96X@8FER(&AA
M=&$@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@(@HB9&5N97EI
M;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D)U($E-05`@<W5N=6-U<W4@<&%Y
M;&'^_6QA;B!D:7II;FQE<FD@9&5S=&5K;&5M:7EO<BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G
M<W1R(")"=2!G9>=E<FQI(&)I<B!R87(@87+^:79I(&1E\&EL+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM
M<V=S='(@(D)U(&=EYV5R;&D@8FER('II<"!D;W-Y87/](&1E\&EL+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M(")"=2!G9>=E<FQI(&)I<B!K87)T(&YU;6%R87/](&1E\&EL+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E
M;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@HB0G4@<_QR_&/\($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O
M;2D@8?`@9V7G:61I(/QZ97)I;F1E;B!(5%10($%022`B"B)K=6QL86YA<F%K
M(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)"=2!S_'+\8_P@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL*2!A\"!G9>=I9&D@_'IE<FEN9&5N($A4
M5%`@05!)("(*(FMU;&QA;F%R86L@;65S86H@871M86[]>F$@:7II;B!V97)I
M<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*(D)U('/\<OQC_"!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PI(&'P(&=EYVED:2#\>F5R:6YD96X@2%144"!!4$D@(@HB:W5L;&%N87)A
M:R!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@
M4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I+B(*;7-G<W1R("(B"B)"=2!S_'+\8_P@4TU44"!Y;VQU>6QA(%9O
M9&%F;VYE($ET86QY(&'P(&=EYVED:2#\>F5R:6YD96XL('-A9&5C92!6;V1E
M9F]N92`B"B)N=6UA<F%L87+];F$@;65S86H@871M86[]>F$@:7II;B!V97)I
M<BX@5F]D969O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2`B"B)E;&5K
M=')O;FEK('!O<W1A(&%D<F5S:2!G97)E:W1I<FUE:W1E9&ER+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@
M(D)U(&=E<F5K;&D@8FER(&%L86YD_7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R(")"=2!A;&%N('-A9&5C92!S87G](&GG
M97)M96QI9&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN(@IM<V=S='(@(D)U(&%L86X@<V%D96-E('-A>?T@=F4@
M:6MI(&YO:W1A(/QS=/QS=&4@:?YA<F5T:2!IYV5R96)I;&ER+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D)U(&%L
M86X@<V%D96-E('-E:VEZ;&EK('-A>?T@<VES=&5M:6YD96X@9&7P97)L92!I
MYV5R96)I;&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*
M;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E
M<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(D)U(&%L86X@=FER
M9_QL('9E>6$@8F_^;'5K;&$@87ER_6QM_?X@<V%Y_2!L:7-T92!O;&UA;/UD
M_7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4
M:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D)U
M(&%L86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L_63]<BXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(D)U(&%L
M86X@4D="($AE>"!B:>=I;6EN9&4@8FER(')E;FL@:V]D=2!IYV5R;65L:61I
M<BP@]G)N96LZ("<C,3(S-&%F)R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+B(*;7-G<W1R(")"=2!F;W)M('IA=&5N(&G^;&5N9&DN(@H*(SH@
M=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B0G4@)7,N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET
M("5S(@IM<V=S='(@(B(*(D)U(&)I<B!+;VQA8B!'<F]U<'=A<F4@;F5S;F5S
M:61I<BX@0G4@;F5S;F5Y:2!G]G)E8FEL;65K(&GG:6X@2V]L86(@(@HB1W)O
M=7!W87)E(&)IYVEM:6YI(&%N;&%Y86)I;&5N(&)I<B!E;&5K=')O;FEK('!O
M<W1A(&ES=&5M8VES:6YE(&=E<F5K('9A<BY"=2`B"B)E;&5K=')O;FEK(&ES
M=&5M8VD@;&ES=&5S:2!IYVEN("5S(&%D<F5S:6YE('7P<F%Y_6XN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R
M(")"=2!I;&5T:2!S:7II;B!K87)A:W1E<B!K_&UE;FEZ9&5N(&9A<FML_2!O
M;&%R86LH)7,I('EA>OUL;?W^=/UR+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`B0G4@;G5M87)A(&5N(&%Z_6YD86X@8FER
M(&]L;6%L_63]<BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")"=2!S=6YU8W4@>FEP
M('9E(&=Z:7`@9&]S>6%L87+];OT@8>=A;6%M86MT863]<BXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI
M<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")3
M:7-T96UI;B!E=&MI;FQI\&D@:V%L9/UR_6QM_?YT_7(N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B0G4@9&7P97(@8FER('-A>?T@
M;VQM86S]9/UR+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B0G4@<&5N8V5R92!39>=E;F5K
M;&5R('!E;F-E<F5S:6YD96X@YV'P<OUL;6%L_63]<BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E
M<B(*;7-G<W1R(")']FL@9_QR_&QT_'/\(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")":6QE=&QE
M<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(EIA
M;6%N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B
M5&EM92!4<F%C:VEN9R(*;7-G<W1R("):86UA;B#=>FQE;64B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@
M(EIA;6%N($)IYVEM:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(EIA;6%N(%-EYVEM
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@
M(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`B0F'^;/UK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I
M.B(*;7-G<W1R(")"8?YL_6L@*&'G_6ML86UA*3HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G
M<W1R(")+:6UE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HBQV]K;'4@]O!E
M('-EYVEM:2!IYVEN+"!T_6ML87)K96X@0V]N=')O;"`H4$,I('9E>6$@0V]M
M;6%N9"`H36%C*2!T=?YU;F$@(@HB8F%S_6XN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B0G5G
M_&XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B2%1-3"!+
M87EN8?#];F$@1V7G:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM
M<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM
M<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")987+];B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS
M9VED(")4;W`B"FUS9W-T<B`BW'-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P
M*2(*;7-G<W1R("+<<W0@QV5RYV5V92`HW%]S="DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("+'
M979I<FEL97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@
M5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D('9E(%1O8F%G;R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B
M"FUS9W-T<B`B1&_P<G4@=F5Y82!986YL_?XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R
M(")382(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M5'5N=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B
M5/QR:VEY92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4
M=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4_')KYV4@*$E33RTX.#4Y
M+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S
M='(@(E3\<FMM96YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<R!V92!#86EC;W,@
M061A;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R
M(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED
M(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B4V7G:6UI;FEZ:2!G:7)I
M;CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED
M(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B52Y6+B!E;F1E:W,Z("(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T
M,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T(@IM<V=S='(@(D)E=&EK;&5R:6X@9'5R=6T@<F%P;W)L87+];OUN
M('1E<VQI;2!E9&EL96-E\&D@55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")5
M4DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G
M86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B
M56MR87EN82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@IM
M<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(")61E,@9&EZ:6YI;F4@97)I_FEL96UE;6EY;W(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G
M<W1R("+<>64@;VQU<FME;B!E:R!K=6QL86[]8_T@8FEL9VES:2!E:VQE;F5M
M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(%9&4R!D;W-Y
M87/];OUN(&EZ:6YL97)I(&1E\&G^=&ER:6QE;6EY;W(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
M)7,O)7,@5D93(&1O<WEA<_UN_6X@:7II;FQE<FD@9&7P:?YT:7)I;&5M:7EO
M<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R
M("(E<R!D9?!I_G1I<FEL96UE9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(")61E,@
M9&]S>6%S_2!<(B5S7"(@8>?];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("(E<R\E<R!61E,@9&]S>6%S
M_2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B4U%,('-U;G5C=7-U;F$@8F'P;&%N
M_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")3
M4TP@:6QE(&)A\&QA;OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&
M4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!K;W!Y86QA;F%M_7EO<BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(")<(B5S7"(@5D93(&1I>FEN:2!Y87)A=/UL86W]>6]R
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&1I>FEN:2!Y87)A=/UL86W]>6]R
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!D;W-Y
M87/]('EA<F%T_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E9&4R!D;W-Y
M87/](%PB)7-<(B!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")";_X@5D93(&1O<WEA
M<_T@>6%R873];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N(@IM<V=S='(@(E9E<FD@<_UK_?YT_7+];&%M_7EO<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S
M='(@(EPB)7-<(B!D:7II;FD@<VEL:6YE;6EY;W(L(&1I>FEN(&)O_B!D9?!I
M;"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B)R5S)R!S:6QI;F5M:7EO
M<CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(E<R!S
M:6QI;F5M:7EO<BP@9&EZ:6X@8F_^(&1E\&EL(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(E9&4R!D:7II;FD@]GIY:6YE
M;&D@;VQA<F%K('-I;&EN96UI>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!D:7II;FD@<VEL:6YE;6EY;W(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B5D93(&1I
M>FEN:2!S:6QI;F5M:7EO<CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R!D;W-Y87/](%PB
M)7-<(B!S:6QI;F5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!S
M:6QI;F5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B5D93(&1O<WEA<_T@7"(E
M<UPB('-I;&EN96UI>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B5D93(/9Z>6EN96QI(&]L
M87)A:R!S:6QI;F5M:7EO<CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN(@IM<V=S='(@(EG\<OQR;/QK=&5K:2!D:7II;F4@:V%R
M87(@=F5R:6QE;6EY;W(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',B"FUS9W-T<B`B3VYA>2!B96QG97-I(&%Y<OUN=/UL87+]
M(.?]:V%R=/UL86W]>6]R(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N
M<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N(@IM<V=S='(@(E1A;OUM_2!Y_&ML96YE;6EY;W(Z("5S
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R
M(")61E,@9&]S>6%S_2!T8?[];F%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@9&]S>6%S
M_2!<(B5S7"(@8>?];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B5D93(&1O<WEA<_T@>6%M86L@:>=I;B!AY_UL86W]>6]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R
M(")61E,@9&]S>6%S_2!AY_UL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B4_UK_?YT_6S];?W^(&%R
M_FEV(&'G_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S
M-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93(&1O<WEA<_T@>6%Z_6QA
M;?UY;W(@*&-O<'DH*2!B8?YA<OUS_7H@;VQD=2DN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M5D93(&1O<WEA<_T@>6%Z_6QA;?UY;W(@*&-O<'DH*2!B8?YA<OUS_7H@;VQD
M=2DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!F:6QE.B`B"FUS9W-T<B`B5D93(&1O<WEA<_T@>65N:61E;B!A9&QA;F3]
M<OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V
M.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y
M+B(*;7-G<W1R(")69G-R;V]T(&1I>FEN:2!O:W5N86W]>6]R+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B)7,M/B5S(&]L87)A:R!Y
M96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(Z(&AE9&5F(&1I>FEN('IA=&5N('9A
M<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(E9&4R!D:7II;FD@>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S
M='(@(E9&4R!D:7II;FD@>65N:61E;B!A9&QA;F3]<OUL86W]>6]R.B`E<R(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@9&]S
M>6%S_2!<(B5S7"(@>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B5S+R5S(%9&4R!D
M;W-Y87/]('EE;FED96X@861L86YD_7+];&%M_7EO<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@
M<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B)VUK:7-O9G,G(.=A;/W^=/UR_6QA
M;?UY;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0B"FUS9W-T<B`B0G4@5V]R9"!B96QG97-I(.=E=FER:6QI;&5M
M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")6
M1E,@9&]S>6%S_2!<(B5S7"(@>6%Z_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")61E,@9&]S>6%S
M_2!Y87K];&%M_7EO<B`H8V]P>2@I(&)A_F%R_7/]>B!O;&1U*2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M9&%T82XB"FUS9W-T<B`B5D93(&1O<WEA('9E<FES:2!Y87K];&%M_7EO<BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N(@IM<V=S='(@(E9&4R!D;W-Y87/]('EA>OUL86W]>6]R("AC;W!Y
M*"D@8F'^87+]<_UZ(&]L9'4I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R
M(")!;'3];OT@YVEZ(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM
M<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D1E\&G^:6ML:6ML97)I($=E
M<FD@06PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R
M(")3;VX@97EL96UI(&=E<FD@86PB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")"8?!L86YT
M_61A('-U;G5C=61A;B!B96ML96YM97EE;B!Y86[]=#H@(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B4W5N=6-U9&%N
M(&)E:VQE;FUE>65N('EA;OUT.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G
M<W1R(")$;VQD=7)U;&UA;?W^(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A5
M5$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B0FER;&7^:6L@07)A<"!%;6ER;&EK;&5R:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B0FER;&7^
M:6L@2W)A;&S]:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,B"FUS9W-T<B`B06UE<FEK82!":7)L9?YI:R!$979L971L97)I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S(@IM<V=S='(@(D%M97)I:V$@0FER;&7^:6L@1&5V;&5T;&5R
M:6YI;B!+_.?\:R!5>F%K($%D86QA<OTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B0FER:6UL97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(D)I;&EN;65Y96XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB
M"FUS9W-T<B`B0FEL:6YM97EE;B!A<&EM<V=I9"`H05!)($UE<V%J($E$*2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+B(*;7-G<W1R(")":6QI;FUE>65N(&-L:6US9VED("C=<W1E;6-I(&UE
M<V%J($E$*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*
M(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(DAIYV)I<B!Y97(@8F5L:7)T:6QM961I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B0FEL:6YM
M97EE;B!K=6QL86[]8_T@863]('9E>6$@<&%R;VQA+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I
M9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`BWG4@86YK
M:2#V\&5N:6X@8F'P_6[](.?V>B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D(@IM<V=S='(@(MUS:6US
M:7HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C
M=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N
M;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S
M='(@(B(*(D%Y<OUC86S]:W/]>B!B971I:VQE<B!P<F]G<F%M<V%L(&]L87)A
M:R!+97,O2V]P>6%L82]987#]_G3]<B=A(&?\=F5N;&EK("(*(FYE9&5N:7EL
M92!E<FG^96UE>FQE<BX@0F5T:6ML97)I;B!P86YO>6$@;F%S_6P@=6QA_F%C
M8?#];OT@9_9S=&5R96X@;6]Z:6QL82XB"B)O<F<@=&5K;FEK(&YO='5N=2!G
M]G)M96L@:>=I;B!%5D54(&D@=/UK;&%Y_6XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS
M970@8V]L;W(B"FUS9W-T<B`B0F5L:7)T:6QM:?X@<F5N:W1E;B!V87IG9><B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@
M17AT96YS:6]N(@IM<V=S='(@(D1E<W1E:VQE;FUE>65N(%5Z86YT_2(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B
M1_QN8V5L;&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")'
M_&YC96QL93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")+=6QL86[]8_UY
M_2!G_&YC96QL92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB
M"FUS9W-T<B`B1_QN8V5L;&5N9&DZ("<E<R<B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB
M"FUS9W-T<B`B6?QK<V5L=&UE(&)E=&GP:2!S:6QI;&YD:2XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")9_&ML
M92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+B(*;7-G<W1R(")"_'3\;B!U>6=U;&%M86QA<OUN(&%Y87(@9&]S>6%L87+]
M('-U;G5C=7EA('G\:VQE;F1I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B0OQY_&L@;&%T:6X@:&%R9FQE<FDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(D+\
M>?QK(')O;6$@<F%K86UL87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U
M9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(DMU;&QA;CH@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM
M<V=I9"`B57-E(%-33"(*;7-G<W1R(")34TP@:W5L;&%N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B2W5L
M;&%N_6/](&%D_6[]>B]P87)O;&%N_7H@24U34"!S=6YU8W4@:>=I;B!F87)K
M;/T@:7-E(&MU;&QA;OUN+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B2W5L
M;&%N_6/];&%R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@
M875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B5S(&MU;&QA;OUC_7/]("5S
M(&GG:6X@9&_P<G5L86YA;6%D_2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*
M;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B2W5L;&%N_6/]
M(%GV;F5T:6UI(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR
M-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")+=6QL86[]8_T@4V7G
M96YE:VQE<FDB"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B(*;7-G<W1R(")+=6QL86[]8_T@2V%Y_70B"@HC.B!S:6=N=7`N
M<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")"=2!S:71E(&GG:6X@:W5L
M;&%N_6/](&MA>63]('-EYVEL;65Z(&O];/UN;?W^=/UR+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-CD*(RP@9G5Z>GD*;7-G:60@(E5S97(@86-C
M;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@8G5L=6YA;6%D_2XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")+=6QL
M86[]8_T@063](@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")+=6QL86[]8_T@)R5S)R!Z
M871E;B!V87(N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W
M"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B2W5L;&%N_6/]($%D_3HB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(DMU;&QA;OUC_2!A9/TZ("(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T
M96TZ(@IM<V=S='(@(E-I<W1E;61E:VD@:W5L;&%N_6/];&%R.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`BUGIB96MI<W1A
M;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R!D:7II;FD@>6]K+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N
M(@IM<V=S='(@(E1A=&EL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM
M<V=S='(@(D=EYV5R;&D@:V]N=6UL87+];B!IYV5R9&EK;&5R:3HB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L
M:61I='DB"FUS9W-T<B`B1V7G97)L:6QI:R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L
M=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`BWG4@86YD86X@:71I
M8F%R96X@9&%K:6MA(&1E\&5R:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")$9?!E<FQE<B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S
M='(@(D1E\&5R;&5R:6X@<V7G:6QE8V7P:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@
M(D1E\&G^:V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM
M<V=S='(@(E9E;F5Z=65L;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(D1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2`M(&)U(&EL971I(&MU<F-A
M;&%N;?W^(&]L86)I;&ER+B`@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B4_QR_&TB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S
M:6]N($-O;G1R;VPB"FUS9W-T<B`B4_QR_&T@2V]N=&]L_"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D3\_F5Y($AI>F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED
M(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(D3\_F5Y('EA<W3]:VQA;6$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B1/S^97DZ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@
M2&EG:"(*;7-G<W1R("+';VL@6?QK<V5K(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S
M='(@(E9I971N86UC82`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M("5S(@IM<V=S='(@(D?V<OQN=/QL92`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS
M9W-T<B`B0FER(&3]_B!W96(@<V%Y9F%S_2!G]G+\;G3\;&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(E<R!O;&%R86L@9_9R_&YT
M_&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R
M:71I<V@B"FUS9W-T<B`B0G)I=&%N>6$G>6$@86ET(%9I<F=I;B!!9&%L87+]
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B06UE<FEK82!":7)L97+^:6L@1&5V;&5T;&5R:2=N92!A:70@
M5FER9VEN($%D86QA<OTB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM
M<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")']G+\_B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R(")']G+\_CHB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@
M=FEA(%--5%`B"FUS9W-T<B`B4TU44"!Y;VQU>6QA(%9O9&%F;VYE(-UT86QY
M82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B5T%2
M3B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&
M4D]-("5S+B(*;7-G<W1R(")564%222$A(25S(-W'W4Y$14X@0D54W=#=($5,
M(-U,12#'24M!4E1)3BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B5TE.('9I82!(5%10(@IM
M<V=S='(@(DA45%`@>6]L=7EL82!S;7,R96UA:6PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@=F4@
M1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(E5Y87+](@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B
M"FUS9W-T<B`BQW+^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(DAA=F$@5&%H
M;6EN:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G
M:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")(879A('9E
M<FES:2!S8?!L87G]8_US_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S
M='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G
M:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8B!3:71E<VDB"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K
M;'DB"FUS9W-T<B`B2&%F=&%L_6LB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")(;_YG96QD:6YI
M>B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(B5S($AO_F=E;&1I;FEZ(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S
M='(@(DAO_F=E;&1I;FEZ+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")"873]
M("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS
M9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B0F%T_2`H25-/
M+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A
M(@IM<V=S='(@(D)A=/T@4V%H<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B5S(&=I
M<FG^=&5N('-O;G)A(&AA;F=I('5Y9W5L86UA>?T@9_9R_&YT_&QE<VEN/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")3_6[]<FQA
M>?UC_2!K87)A:W1E<B!N961I<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/R(*;7-G<W1R(")!:W1A<OUM(&MA<F%K=&5R:2!N961I<C\B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0HC+"!F=7IZ
M>0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(D%V=7-T
M=7)A;'EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC
M:"!P:&%S97,B"FUS9W-T<B`B2&%N9VD@179R92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@HB6F5N9VEN
M($UE=&EN(&3\>F5N;&5Y:6-I<VD@:>=I;B!H86YG:2!U>75M;'4@96ML97(@
M<V7G:6QE8FEL:7(@:_UL_6YS_6XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS
M9W-T<B`B1V5N:?YL:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B0U-3(&)I
M<FEM:7EL92!G96YI_FQI:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@
M;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM
M<V=S='(@(E-O;&1A:VD@)7,@;65N_'/\;OQN(&=E;FG^;&GP:2`H8FER('-O
M;G)A:VD@9VER:?YT92!E=&MI;B!O;&%C86LI.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O
M9B!T:&4@=&%B;&4B"FUS9W-T<B`BQVEZ96QG96YI;B!G96YI_FQI\&DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM
M<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")'96YI_FQI:R!B:7)I;6DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM
M<V=I9"`B5VED=&@Z(@IM<V=S='(@(D=E;FG^;&EK.B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B
M"FUS9W-T<B`B4OQZ9V%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B17)K
M96X@4V%A=&QE<F1E(%+\>F=A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B2VYO="!B
M:7)I;6EN9&4@<OQZ9V%R(&C]>OTB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B4OQZ9V%R.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G
M<W1R(")2_'IG87(Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM
M<V=I9"`B5VES9&]M(@IM<V=S='(@(D)I;&=E;&EK(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B5VES:&QI<W0B
M"FUS9W-T<B`BW7-T96L@3&ES=&5S:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("+=_B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!
M9&1R97-S(@IM<V=S='(@(MW^($%D<F5S:2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B
M"FUS9W-T<B`BW?X@5&5L969O;G4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@
M;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@
M(E9&4R!D:7II;FD@>6%R873];/UR:V5N(&5R:?YI;2!E;F=E;&QE;F1I+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F
M(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*
M;7-G<W1R(")8-3`Y=C,@5&5M96P@2_US_71L86UA;&%R_2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R!'96YI_FQE=&EL
M;6G^($%N86AT87(@2W5L;&%N_6W](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(-9T96MI($MO;G4@063](@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U,#EV
M,R!+;VYU($%N86AT87(@5&%N_73]8_US_2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R(")8-3`Y=C,@=7IA;G3];&%R_2(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")962(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*
M;7-G<W1R(")965E9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B66%H
M;V\A(&AA<FET87/](@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(EG];&S]:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(EEE;65N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM
M<V=I9"`B665S(@IM<V=S='(@(D5V970B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E
M(@IM<V=S='(@(D5V970L($MA8G5L($5D:7EO<G5M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(DU%5-U.($U/1%5.1$%3
M24Y)6BX@6SP^72!D_/!M96QE<FEN:2!K=6QL86YA<F%K(%=94TE764<@9_9R
M_&[\;?QN92!D]F[\;BXB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T
M;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")$;_!R=6QA;F%M863];OUZ
M+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS
M9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B)UQ<)R!K87)A:W1E<FD@=&%M(&%D
M_6[]>F1A(&)U;'5N86UA>BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`B1V7G97)L:2!B:7(@96QE:W1R;VYI:R!P;W-T82!A9')E<VD@9VER;65D
M:6YI>BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F
M<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I
M96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB)7,@:>=I;F1E(&MA<O[];/UK
M(&=E;&5N(&%L86YL87)L82`H:>=E<FDI(&%K=&%R_6QA;B!D;W-Y861A:VD@
M86QA;FQA<OT@(@HB9?YL9?YT:7)M961I;FEZ+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+B(*;7-G<W1R("+'_6O]_B!Y87!M863];OUZ+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)'9>=E<FQI(&)I<B!C97`@=&5L
M969O;G4@;G5M87)A<_T@9VER;65L:7-I;FEZ+"!S87G];&%R('9E('-EYV5N
M96ML:2!O;&%R86L@(@HB=6QU<VQA<F%R87/](&%R86UA(/9N96MI("<K)R`B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")'9>=E<FQI
M(&)I<B!D9?!E<B!G:7)M96QI<VEN:7HN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@
M82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("+<
M>64@:V%Y9/T@>6%P86)I;&UE:R!IYVEN(&)I<B!697)I0?!A8_T@>6%P_6QA
M;F3]<FUA;/US_6[]>BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N
M(@IM<V=S='(@(E9&4R!S;VX@8?YA;6%S_6[]('EA</UL86YD_7)M86S]<_UN
M_7HN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G
M:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@
M8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")0<F]B;&5M
M(')A<&]R=2!G]FYD97)M961E;B#V;F-E('-O<G5N=2!T87)F:2!E=&UE;&ES
M:6YI>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B0G4@8F'P;&%N=/UN_6X@9_9S
M=&5R9&GP:2!B:7(@55),(&=I<FUE;&ES:6YI>B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E-I;&EN;65S:2!IYVEN
M(&)I<B!S=6YU8W4@<V7G;65L:7-I;FEZ+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L
M96%R(&]U="XB"FUS9W-T<B`B5&5M:7IL96YM97-I;B!IYVEN(&)I<B!K=6QL
M86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N(@IM<V=S='(@(E-I;&EN;65S:2!IYVEN(&)I<B!K=6QL86[]8_T@
M863](&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B16ML
M96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")'_&YC96QL
M96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ
M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F
M;W)M+B(*;7-G<W1R(")'97+G96ML9?YT:7)I;&5C96L@8FER(&5Y;&5M(&)E
M;&ER=&UE;&ES:6YI>BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")996YI(&MA=&5G;W)Y(&%D_2!G
M:7)M96QI<VEN:7HN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I
M9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(E<R!O='5R=6UU;G5N('/\<F5S:2!D;VQD=2X@3/QT
M9F5N('1E:W)A<B!G:7)I_B!Y87#];BXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(D5L96MT<F]N:6L@4&]S=&$@061R97-I;FEZ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S
M.B(*;7-G<W1R(")+:6UD96XZ(&%D<F5S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM
M<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")":6QG:6QE<FEN:7HB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B
M"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"B(E<R!O='5R=6UU;G5Z=6X@8F'^;&%N9_UC_6YD82#=
M;G1E<FYE="!!9')E<VEN:6YI>B!D9?!I_G1I+B!'_'9E;FQI\&EN:7II("(*
M(FMO<G5M86L@:>=I;BP@>65N:61E;B!G:7)I_B!Y87!M86S]<_UN_7HN(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO
M=7(@3F%M92(*;7-G<W1R(")!9/UN_7HB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S
M97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E
M<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB
M875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB2VEM;&EK(&1E
M;F5T:6UI;FEZ(&MU;&QA;OUC_2!E:VQE;65Y:2!D97-T96ML96UE;65K=&5D
M:7(L('9E>6$@8G4@]GIE;&QI:R`B"B)B:7(@;F5D96X@>?QZ_&YD96X@<V7G
M:6QE;65Z(&O];/UN;?W^=/UR+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+B(*;7-G<W1R("(B"B)+:6UL:6L@9&5N971I;6EN:7H@:W5L;&%N
M_6/](&QI<W1E;&5M97EI(&1E<W1E:VQE;65M96MT961I<B!V97EA(&)U(/9Z
M96QL:6L@(@HB8FER(&YE9&5N('G\>OQN9&5N('-EYVEL96UE>B!K_6S];FW]
M_G3]<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B(E<R!O='5R=6UU;G5Z=6X@8F'^;&%N
M9_UC_6YD82!T87)A>?UC_6[]>B!D9?!I_G1I+B!'_'9E;FQI\&EN:7II(&MO
M<G5M86L@(@HB:>=I;BP@>65N:61E;B!G:7)I_B!Y87!M86S]<_UN_7HN(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B5&%R
M87G]8_UN_7H@8G4@]GIE;&QI\&D@9&5S=&5K;&5M96UE:W1E9&ER+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P
M<FEN="XB"FUS9W-T<B`B(@HB5&%R87G]8_UN_7H@8G4@>6%Z9/UR;6$@=&5R
M8VEH:6YI(&1E<W1E:VQE;65M96MT961I<BY987ID_7)M86L@:>=I;B!#;VYT
M<F]L+R(*(D]P=&EO;B`K(%`@='7^;&%R_6YA(&)A<_UN+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE
M('IO;F4Z(@IM<V=S='(@(EIA;6%N($1I;&EM:6YI>CHB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I
M9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("+6;B!T86[];6S]
M(&MI;6QI\&EN:7HZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("+6;B!T86[]
M;6S](&MI;6QI\&EN:7HZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P
M,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E1A;2!!9/UN_7HZ
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B4V7G96YE
M:VQE<FEN:7H@9_QN8V5L;&5N9&DN(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(E<R!IYVEN('EE;FD@<&%R
M;VQA;OUZ.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R
M('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E-EYV5N
M96ML97)I;FEZ(&)U(&]T=7)U;75N('/\<F5S:2!IYVEN9&4@9_QN8V5L;&5N
M9&DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G
M:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B
M4V7G96YE:VQE<FEN:7H@9_QN8V5L;&5N9&DN(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970B"FUS9W-T<B`B4&%R;VQA;OUZ('/]9OUR;&%N9/TN(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B
M"B)087)O;&%N_7H@<_UF_7)L86YD_2P@96QE:W1R;VYI:R!P;W-T86[]>OT@
M:V]N=&]L(&5D:6X@=F4@>65N:2!P87)O;&%N_7IL82`B"B)G:7)I_B!Y87#]
M;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E!A
M<F]L86[]>B!S_6;]<FQA;F3]+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T
M<B`B57IA:W1A:VD@<W5N=6-U;&%R_6[]>CHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(EEU9V]S;&%V>6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER
M92(*;7-G<W1R("):86ER92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I
M82(*;7-G<W1R("):86UB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB
M86)W92(*;7-G<W1R(")::6UB86)V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B2/UZ;/TB"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z
M,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R
M"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6T%L_6YT_2!-
M971N:2!386ML85TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I
M9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O8FQE;2!287!O<G5=
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*
M;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6T%L_6YT_2!-
M971N:2!']G-T97(@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6T%L
M_6YT_2!-971N:2!']G-T97(@+2`E<R!S873]<ETB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B)7,O)7,@<V%T_7(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]9]FYE
M=&EM(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@
M(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*
M;7-G<W1R(")?5F5R:4'P86/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O
M=R(*;7-G<W1R(")3873]<OT@7U-I;"(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM
M<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<&QA<B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S
M='(@(EEA<E]D_6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(D?V<OQN=/P@UE]Z96QL:6ML97)I+BXN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I
M;B(*;7-G<W1R(")':5]R:?XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("+'_5]K_?XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?0F'P
M;&%N=/UY_2!$9?!I_G1I<BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]39>=E
M;F5K;&5R(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B7TAA:VQA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,
M:6YK+BXN(@IM<V=S='(@(D)A\&QA7VYT_7G](%-I;"XN+B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]!>6%R;&%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+'
M:7IE7VQG92#6>F5L;&EK;&5R:2XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM
M<V=I9"`B7U5S97)S(@IM<V=S='(@(DM?=6QL86[]8_UL87(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0IM<V=I9"`B861D<F5S<R!B;V]K
M(@IM<V=S='(@(F%D<F5S(&1E9G1E<FDB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<V5E
M('5N:VYO=VXB"FUS9W-T<B`B861R97,@9&5F=&5R:2(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C86QE;F1A<B(*;7-G<W1R
M(")T86MV:6TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(OUL_6UL_2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L
M:6-K(&AE<F4B"FUS9W-T<B`B8G5R87EA('3]:VQA>?UN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG
M=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")987#];&%N9/UR;6$@1F%R:VQA<OTB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I
M9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B
M9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y
M(&YO="!F;W5N9"(*;7-G<W1R(")B=6QU;F%M863](@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B
M"FUS9W-T<B`B9/S^_'EO<B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R(")D;W-Y82(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@
M(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B)7,@*"5S*2!D
M96X@)7,@)7,@9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4P"B,L(&9U>GIY"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(BP@9OUR=/UN
M86S]("5S("5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B06-I;"(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")I;FQI;F4B"FUS9W-T<B`B365T;F4@9_9M_&S\(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")S873]<FQA<ETB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F
M<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C
M;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,@25-/
M('EA<&%R:V5N(&AA=&$@:V]D=3HE9"XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`B860B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT
M960B"FUS9W-T<B`B9V5RYV5K;&7^=&ER:6QM961I(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(FAE;OQZ(&=E<N=E:VQE_G1I<FEL;65D:2(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E
M<&%D(@IM<V=S='(@(FYO="!D969T97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N
M="(*;7-G<W1R(")Y_'ID92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE
M9"(*;7-G<W1R("+=>FEN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@
M(G)E<VEM(&)I<FEM:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")Y_&MS96QI>6]R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*
M;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B2&%V82!R87!O
M<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G
M<W1R(")F87)K;&%R_2!G]G-T97(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I
M82!(5%10(@IM<V=S='(@(DA45%`@>6]L=7EL82!S;7,R96UA:6PB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED
M(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G-A8FET(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C
M:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS
M9VED(")T87-K(&QI<W0B"FUS9W-T<B`B9_9R978@;&ES=&5S:2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP
M;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S
M='(@(DAE<B!':7)I_G1E(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")P87)O;&%Y_2!D
M;_!R=6QA;6%K(&GG:6X@:6MI(&1E9F$@9VER:6XB"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M=6YI9FEE9"(*;7-G<W1R(")B:7)L9?YT:7)I;&UI_B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T
M<B`B861L86YD_7+];&UA;?W^(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C
M="(*;7-G<W1R(")K=6QL86[]8_T@<V7G:6UI(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G
M<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(G<Z(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM
M<V=S='(@(G=E871H97(N8V]M(@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!O+W1R86YS;&%T:6]N+G!H<```````````````````````
M````````````````````````````````````````````````````,#$P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-38S-S``,3`T,3<S-C,P,#,`,#(P
M,3$R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<"`M<0H\/W!H<`HO*BH*
M("H@5')A;G-L871I;VX@:&5L<&5R(&%P<&QI8V%T:6]N(&9O<B!T:&4@2&]R
M9&4@9G)A;65W;W)K+@H@*@H@*B!&;W(@=7-A9V4@:6YF;W)M871I;VX@8V%L
M;#H*("H@+B]T<F%N<VQA=&EO;BYP:'`@:&5L<`H@*@H@*B`D2&]R9&4Z(&AO
M<F1E+W!O+W1R86YS;&%T:6]N+G!H<"QV(#$N.3$N,BXQ-2`R,#`V+S`S+S(X
M(#$R.C,Q.C$T(&IA;B!%>'`@)`H@*B\*"F9U;F-T:6]N(&9O;W1E<B@I"GL*
M("`@(&=L;V)A;"`D8RP@)&-U<F1I<CL*"B`@("`D8RT^=W)I=&5L;B@I.PH@
M("`@)&,M/G=R:71E;&XH)U!L96%S92!R97!O<G0@86YY(&)U9W,@=&\@:3$X
M;D!L:7-T<RYH;W)D92YO<F<N)RD["@H@("`@8VAD:7(H)&-U<F1I<BD["B`@
M("!E>&ET.PI]"@IF=6YC=&EO;B!U<V%G92@I"GL*("`@(&=L;V)A;"`D;W!T
M:6]N<RP@)&,["@H@("`@:68@*&-O=6YT*"1O<'1I;VYS6S%=*2`F)@H@("`@
M("`@("@D;W!T:6]N<ULQ75LP72`]/2`G:&5L<"<@)B8@(65M<'1Y*"1O<'1I
M;VYS6S%=6S%=*2!\?`H@("`@("`@("%E;7!T>2@D;W!T:6]N<ULQ75LP72D@
M)B8@:6Y?87)R87DH)&]P=&EO;G-;,5U;,%TL(&%R<F%Y*"=C;VUM:70G+"`G
M8V]M<&5N9&EU;2<L("=E>'1R86-T)RP@)VEN:70G+"`G;6%K92<L("=M97)G
M92<I*2DI('L*("`@("`@("!I9B`H)&]P=&EO;G-;,5U;,%T@/3T@)VAE;'`G
M*2!["B`@("`@("`@("`@("1C;60@/2`D;W!T:6]N<ULQ75LQ73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D8VUD(#T@)&]P=&EO;G-;,5U;,%T[
M"B`@("`@("`@?0H@("`@("`@("1C+3YW<FET96QN*"=5<V%G93HG("X@)R!T
M<F%N<VQA=&EO;BYP:'`@6V]P=&EO;G-=("<@+B`D8VUD("X@)R!;8V]M;6%N
M9"UO<'1I;VYS72<I.PH@("`@("`@(&EF("@A96UP='DH)&-M9"DI('L*("`@
M("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)T-O;6UA;F0@;W!T:6]N<SHG*3L*("`@("`@("!]"B`@("`@("`@<W=I
M=&-H("@D8VUD*2!["B`@("`@("`@("`@(&-A<V4@)V-L96%N=7`G.@H@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C86QE/6QL7T-#
M("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92XG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@("`@0VQE86YU
M<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)V-O;6UI
M="<Z"B`@("`@("`@("`@(&-A<V4@)V-O;6UI="UH96QP)SH*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@
M57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I
M;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@G("`M32P@+2UM97-S86=E/4U%4U-!1T4@
M(%5S92!T:&ES(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0@;VYE<RXG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UN
M+"`M+6YE=R`@("`@("`@("`@("`@5&AI<R!I<R!A(&YE=R!T<F%N<VQA=&EO
M;BP@8V]M;6ET(&%L<V\@0U)%1$E44RPG*3L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"<@("`@("`@("`@("`@("`@("`@("`@("`@0TA!3D=%4R!A
M;F0@;FQS+G!H<"YD:7-T+B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@)V-O;7!E;F1I=6TG.@H@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)R`@+6$L("TM861D/49)3$4@("`@("`@($%D9"!T:&ES
M(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T;R<I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@("`@("`@
M("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F97)E;G0@8G)A
M;F-H('1O)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R871E9"!C;VUP96YD:75M+B<I
M.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+60L("TM9&ER96-T
M;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y
M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C
M86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92XG*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=E>'1R86-T)SH*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@
M($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U
M;&4N)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92`G:6YI="<Z"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;"P@
M+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92XG*3L*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D
M=6QE+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6,L("TM
M8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS
M=&5A9"!O9B!T:&4@9&5F875L="<I.PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)R`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I
M=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN)RD["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@G("`M;BP@+2UN;RUC;VUP96YD:75M("`@
M($1O;EPG="!U<V4@82!C;VUP96YD:75M+B<I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@)VUA:V4G.@H@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@
M;VYL>2!T:&ES(&QO8V%L92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@
M;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XG*3L*("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"<@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@365R
M9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@9FEL92<I
M.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@
M("`@("`@("`@("!I;G-T96%D(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N
M9&EU;2YP;R!I;B!T:&4G*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN
M*"<@("`@("`@("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y
M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6XL("TM;F\M
M8V]M<&5N9&EU;2`@("!$;VY<)W0@;65R9V4@;F5W('1R86YS;&%T:6]N<R!T
M;R!T:&4@8V]M<&5N9&EU;2XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"<@("US+"`M+7-T871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO
M;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL92XG*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M86ME+6AE;'`G.@H@("`@
M("`@("`@("!C87-E("=U<&1A=&4M:&5L<"<Z"B`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY
M('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O
M;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VUE<F=E)SH*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@
M57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F:6QE<R!O
M;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)R`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5<V4@
M=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L="<I
M.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@
M("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O
M(&1I<F5C=&]R>2DN)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G
M("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;EPG="!U<V4@82!C;VUP96YD
M:75M+B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@)W5P9&%T92<Z"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M
M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92XG*3L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92XG*3L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UC+"`M+6-O;7!E;F1I=6T]
M1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE
M(&1E9F%U;'0G*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("`@
M("`@("`@("`@("`@("`@("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN('1H
M92!H;W)D92]P;R!D:7)E8W1O<GDI+B<I.PH@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)R`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VY<)W0@=7-E
M(&$@8V]M<&5N9&EU;2XG*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*("`@('T@96QS92!["B`@("`@("`@)&,M/G=R:71E;&XH)U5S86=E
M.B<@+B`G('1R86YS;&%T:6]N+G!H<"!;;W!T:6]N<UT@8V]M;6%N9"!;8V]M
M;6%N9"UO<'1I;VYS72<I.PH@("`@("`@("1C+3YW<FET96QN*'-T<E]R97!E
M870H)R`G+"!3=')I;F<Z.FQE;F=T:"@G57-A9V4Z)RDI("X@)R!T<F%N<VQA
M=&EO;BYP:'`@6VAE;'!\+6A\+2UH96QP72!;8V]M;6%N9%TG*3L*("`@("`@
M("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("1C+3YW<FET96QN*"=(96QP97(@
M87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO
M;G,@9F]R('1H92!(;W)D92<I.PH@("`@("`@("1C+3YW<FET96QN*"=F<F%M
M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N)RD["B`@("`@("`@)&,M/G=R
M:71E;&XH)T9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$
M344@:6X@=&AI<R!D:7)E8W1O<GDN)RD["B`@("`@("`@)&,M/G=R:71E;&XH
M*3L*("`@("`@("`D8RT^=W)I=&5L;B@G0V]M;6%N9',Z)RD["B`@("`@("`@
M)&,M/G=R:71E;&XH)R`@:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S
M<V%G92XG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!C;VUP96YD:75M("!2
M96)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E
M<G=R:71E<R!T:&4G*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("`@("`@("`@
M("`@("!C=7)R96YT(&-O;7!E;F1I=6TN)RD["B`@("`@("`@)&,M/G=R:71E
M;&XH)R`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA=&4@*"YP;W0I
M(&9I;&5S+B<I.PH@("`@("`@("1C+3YW<FET96QN*"<@(&EN:70@("`@("`@
M($-R96%T92!O;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE
M+B!787)N:6YG.B!4:&ES)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@
M("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@9FEL97,@;V8@
M=&AI<R!L;V-A;&4N)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@;65R9V4@
M("`@("`@365R9V4@=&AE(&-U<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R
M96YT(%!/('1E;7!L871E(&9I;&4N)RD["B`@("`@("`@)&,M/G=R:71E;&XH
M)R`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E<75E;G0N
M)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@=7!D871E+6AE;'`@17AT<F%C
M="!A;&P@;F5W(&%N9"!C:&%N9V5D(&5N=')I97,@9G)O;2!T:&4@16YG;&ES
M:"!834P@:&5L<"<I.PH@("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@
M("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@;VYE
M<RXG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!C;&5A;G5P("`@("!#;&5A
M;G,@=&AE(%!/(&9I;&5S('5P(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O
M;&5T92!E;G1R:65S+B<I.PH@("`@("`@("1C+3YW<FET96QN*"<@(&UA:V4@
M("`@("`@($)U:6QD(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I
M960@4$\@9FEL97,N)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@;6%K92UH
M96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE;'`@9FEL92!B
M96EN9R!U<"UT;RUD871E(&%N9"<I.PH@("`@("`@("1C+3YW<FET96QN*"<@
M("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I;&4@9F]R('1H92!N97AT(&5X
M96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U)RD["B`@("`@("`@)&,M/G=R
M:71E;&XH)R`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L
M<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE)RD["B`@("`@
M("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@:&5L<"!F:6QE+B<I.PH@
M("`@("`@("1C+3YW<FET96QN*"<@(&-O;6UI="`@("`@($-O;6UI="!T<F%N
M<VQA=&EO;G,@=&\@=&AE($-64R!S97)V97(N)RD["B`@("`@("`@)&,M/G=R
M:71E;&XH)R`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE
M($-64R!S97)V97(N)RD["B`@("!]"B`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M)&,M/G=R:71E;&XH)T]P=&EO;G,Z)RD["B`@("`D8RT^=W)I=&5L;B@G("`M
M8BP@+2UB87-E/2]0051(("!&=6QL('!A=&@@=&\@=&AE("A(;W)D92D@8F%S
M92!D:7)E8W1O<GD@=&AA="!S:&]U;&0@8F4G*3L*("`@("1C+3YW<FET96QN
M*"<@("`@("`@("`@("`@("`@("`@('5S960N)RD["B`@("`D8RT^=W)I=&5L
M;B@G("`M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R
M;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S+B<I.PH@("`@)&,M/G=R:71E;&XH
M)R`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92XG
M*3L*("`@("1C+3YW<FET96QN*"<@("UT+"`M+71E<W0@("`@("`@(%-H;W<@
M=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VY<)W0@<G5N(&%N>71H:6YG
M+B<I.PI]"@IF=6YC=&EO;B!C:&5C:U]B:6YA<FEE<R@I"GL*("`@(&=L;V)A
M;"`D9V5T=&5X=%]V97)S:6]N+"`D8SL*"B`@("`D8RT^=W)I=&5L;B@G4V5A
M<F-H:6YG(&=E='1E>'0@8FEN87)I97,N+BXG*3L*("`@(')E<75I<F5?;VYC
M92`G4WES=&5M+G!H<"<["B`@("!F;W)E86-H("AA<G)A>2@G9V5T=&5X="<L
M("=M<V=A='1R:6(G+"`G;7-G8V%T)RP@)VUS9V-O;6TG+"`G;7-G9FUT)RP@
M)VUS9VEN:70G+"`G;7-G;65R9V4G+"`G>&=E='1E>'0G*2!A<R`D8FEN87)Y
M*2!["B`@("`@("`@96-H;R`D8FEN87)Y("X@)RXN+B`G.PH@("`@("`@("1'
M3$]"04Q36R1B:6YA<GE=(#T@4WES=&5M.CIW:&EC:"@D8FEN87)Y*3L*("`@
M("`@("!I9B`H)$=,3T)!3%-;)&)I;F%R>5TI('L*("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)&,M/F=R965N*"=F;W5N9#H@)RD@+B`D1TQ/0D%,4ULD8FEN
M87)Y72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/G)E9"@G;F]T(&9O=6YD)RDI.PH@("`@("`@("`@("!F;V]T97(H
M*3L*("`@("`@("!]"B`@("!]"B`@("`D8RT^=W)I=&5L;B@I.PH*("`@("1O
M=70@/2`G)SL*("`@(&5X96,H)$=,3T)!3%-;)V=E='1E>'0G72`N("<@+2UV
M97)S:6]N)RP@)&]U="P@)')E="D["B`@("`D<W!L:70@/2!E>'!L;V1E*"<@
M)RP@)&]U=%LP72D["B`@("!E8VAO("=G971T97AT('9E<G-I;VXZ("<@+B`D
M<W!L:71;8V]U;G0H)'-P;&ET*2`M(#%=.PH@("`@)&=E='1E>'1?=F5R<VEO
M;B`](&5X<&QO9&4H)RXG+"`D<W!L:71;8V]U;G0H)'-P;&ET*2`M(#%=*3L*
M("`@(&EF("@D9V5T=&5X=%]V97)S:6]N6S!=(#T](#`@)B8@)&=E='1E>'1?
M=F5R<VEO;ELQ72`\(#$R*2!["B`@("`@("`@)$=,3T)!3%-;)W!H<%]S=7!P
M;W)T)UT@/2!F86QS93L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@
M("1C+3YW<FET96QN*"1C+3YR960H)U=A<FYI;F<Z("<I("X@)UEO=7(@9V5T
M=&5X="!V97)S:6]N(&ES('1O;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@
M4$A0(&YA=&EV96QY+B<I.PH@("`@("`@("1C+3YW<FET96QN*"=.;W0@86QL
M('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N)RD["B`@("!](&5L<V4@>PH@
M("`@("`@("1'3$]"04Q36R=P:'!?<W5P<&]R="==(#T@=')U93L*("`@("`@
M("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)R`G("X@)T]+)RDI.PH@("`@?0H@
M("`@)&,M/G=R:71E;&XH*3L*?0H*9G5N8W1I;VX@<V5A<F-H7V9I;&4H)&9I
M;&4L("1D:7(@/2`G+B<L("1L;V-A;"`](&9A;'-E*0I["B`@("!S=&%T:6,@
M)&9F.PH@("`@:68@*"%I<W-E="@D9F8I*2!["B`@("`@("`@)&9F(#T@)FYE
M=R!&:6QE7T9I;F0H*3L*("`@('T*"B`@("!I9B`H<W5B<W1R*"1F:6QE+"`P
M+"`Q*2`A/2!$4RD@>PH@("`@("`@("1F:6QE(#T@(B\D9FEL92\B.PH@("`@
M?0H*("`@(&EF("@D;&]C86PI('L*("`@("`@("`D9FEL97,@/2`D9F8M/F=L
M;V(H)&9I;&4L("1D:7(L("=P97)L)RD["B`@("`@("`@)&9I;&5S(#T@87)R
M87E?;6%P*&-R96%T95]F=6YC=&EO;B@G)&9I;&4G+"`G<F5T=7)N("(G("X@
M)&1I<B`N($13("X@)R(@+B`D9FEL93LG*2P@)&9I;&5S*3L*("`@("`@("!R
M971U<FX@)&9I;&5S.PH@("`@?2!E;'-E('L*("`@("`@("!R971U<FX@)&9F
M+3YS96%R8V@H)&9I;&4L("1D:7(L("=P97)L)RD["B`@("!]"GT*"F9U;F-T
M:6]N('-E87)C:%]E>'0H)&5X="P@)&1I<B`]("<N)RP@)&QO8V%L(#T@9F%L
M<V4I"GL*("`@(')E='5R;B!S96%R8VA?9FEL92@B+BM<7"XD97AT7"0B+"`D
M9&ER+"`D;&]C86PI.PI]"@IF=6YC=&EO;B!G971?<&]?9FEL97,H)&1I<BD*
M>PH@("`@)&QA;F=S(#T@<V5A<F-H7V5X="@G<&\G+"`D9&ER*3L*("`@(&EF
M("@H)&ME>2`](&%R<F%Y7W-E87)C:"@D9&ER("X@1%,@+B`G;65S<V%G97,N
M<&\G+"`D;&%N9W,I*2`A/3T@9F%L<V4I('L*("`@("`@("!U;G-E="@D;&%N
M9W-;)&ME>5TI.PH@("`@?0H@("`@:68@*"@D:V5Y(#T@87)R87E?<V5A<F-H
M*"1D:7(@+B!$4R`N("=C;VUP96YD:75M+G!O)RP@)&QA;F=S*2D@(3T](&9A
M;'-E*2!["B`@("`@("`@=6YS970H)&QA;F=S6R1K97E=*3L*("`@('T*("`@
M(')E='5R;B`D;&%N9W,["GT*"F9U;F-T:6]N(&=E=%]L86YG=6%G97,H)&1I
M<BD*>PH@("`@9VQO8F%L("1C=7)D:7(["@H@("`@8VAD:7(H)&1I<BD["B`@
M("`D;&%N9W,@/2!G971?<&]?9FEL97,H)W!O)RD["B`@("`D;&%N9W,@/2!A
M<G)A>5]M87`H8W)E871E7V9U;F-T:6]N*"<D;&%N9R<L("=R971U<FX@<W1R
M7W)E<&QA8V4H(G!O(B`N($13+"`B(BP@<W1R7W)E<&QA8V4H(BYP;R(L("(B
M+"`D;&%N9RDI.R<I+"`D;&%N9W,I.PH@("`@8VAD:7(H)&-U<F1I<BD["B`@
M("!R971U<FX@)&QA;F=S.PI]"@IF=6YC=&EO;B!S96%R8VA?87!P;&EC871I
M;VYS*"D*>PH@("`@)&1I<G,@/2!A<G)A>2@I.PH@("`@)&AO<F1E(#T@9F%L
M<V4["B`@("!I9B`H0&ES7V1I<BA"05-%("X@1%,@+B`G<&\G*2D@>PH@("`@
M("`@("1D:7)S6UT@/2!"05-%.PH@("`@("`@("1H;W)D92`]('1R=64["B`@
M("!]"B`@("`D9&@@/2!`;W!E;F1I<BA"05-%*3L*("`@(&EF("@D9&@I('L*
M("`@("`@("!W:&EL92`H)&5N=')Y(#T@0')E861D:7(H)&1H*2D@>PH@("`@
M("`@("`@("`D9&ER(#T@0D%312`N($13("X@)&5N=')Y.PH@("`@("`@("`@
M("!I9B`H:7-?9&ER*"1D:7(I("8F"B`@("`@("`@("`@("`@("!S=6)S='(H
M)&5N=')Y+"`P+"`Q*2`A/2`G+B<@)B8*("`@("`@("`@("`@("`@(&9I;&5I
M;F]D92A(3U)$15]"05-%*2`A/2!F:6QE:6YO9&4H)&1I<BDI('L*("`@("`@
M("`@("`@("`@("1S=6(@/2!O<&5N9&ER*"1D:7(I.PH@("`@("`@("`@("`@
M("`@:68@*"1S=6(I('L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H)'-U
M8F5N=')Y(#T@<F5A9&1I<B@D<W5B*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)'-U8F5N=')Y(#T]("=P;R<@)B8@:7-?9&ER*"1D:7(@+B!$
M4R`N("1S=6)E;G1R>2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D:7)S6UT@/2`D9&ER.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1E;G1R>2`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&AO<F1E(#T@=')U93L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&EF("@A)&AO<F1E*2!["B`@("`@("`@("`@(&%R<F%Y7W5N
M<VAI9G0H)&1I<G,L($A/4D1%7T)!4T4I.PH@("`@("`@('T*("`@('T*"B`@
M("!R971U<FX@)&1I<G,["GT*"F9U;F-T:6]N('-T<FEP7VAO<F1E*"1F:6QE
M*0I["B`@("!I9B`H:7-?87)R87DH)&9I;&4I*2!["B`@("`@("`@<F5T=7)N
M(&%R<F%Y7VUA<"AC<F5A=&5?9G5N8W1I;VXH)R1F:6QE)RP@)W)E='5R;B!S
M=')I<%]H;W)D92@D9FEL92D[)RDL("1F:6QE*3L*("`@('T@96QS92!["B`@
M("`@("`@<F5T=7)N('-T<E]R97!L86-E*$)!4T4@+B!$4RP@)R<L("1F:6QE
M*3L*("`@('T*?0H*9G5N8W1I;VX@>'1R86-T*"D*>PH@("`@9VQO8F%L("1C
M;61?;W!T:6]N<RP@)&%P<',L("1D:7)S+"`D9&5B=6<L("1T97-T+"`D8RP@
M)&=E='1E>'1?=F5R<VEO;BP@)'-I;&5N8V4L("1C=7)D:7(["@H@("`@9F]R
M96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@("!S
M=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z"B`@
M("`@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O=&5R
M*"D["B`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("!C87-E("<M
M+6UO9'5L92<Z"B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)&]P=&EO;ELQ
M73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@(&EF("@D1TQ/
M0D%,4ULG<&AP7W-U<'!O<G0G72D@>PH@("`@("`@("1L86YG=6%G92`]("=0
M2%`G.PH@("`@?2!E;'-E('L*("`@("`@("`D;&%N9W5A9V4@/2`G0RLK)SL*
M("`@('T*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D:7)S*3L@)&DK
M*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO9'5L92D@)B8@)&UO9'5L92`A
M/2`D87!P<ULD:5TI('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M?0H@("`@("`@('!R:6YT9B@G17AT<F%C=&EN9R!F<F]M("5S+BXN("<L("1A
M<'!S6R1I72D["B`@("`@("`@8VAD:7(H)&1I<G-;)&E=*3L*("`@("`@("!I
M9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I('L*("`@("`@("`@("`@)&9I;&5S
M(#T@<V5A<F-H7V5X="@G<&AP)RP@)RXG+"!T<G5E*3L*("`@("`@("`@("`@
M9F]R96%C:"`H87)R87DH)V%D;6EN)RP@)V9R86UE=V]R:R<L("=L:6(G+"`G
M<V5R=FEC97,G+"`G=&5M<&QA=&5S)RP@)W5T:6PG+"`G8V]N9FEG)R`N($13
M("X@)W1H96UE<R<I(&%S("1S96%R8VA?9&ER*2!["B`@("`@("`@("`@("`@
M("`D9FEL97,@/2!A<G)A>5]M97)G92@D9FEL97,L('-E87)C:%]E>'0H)RAP
M:'!\:6YC?&IS*2<L("1S96%R8VA?9&ER*2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S+"!S96%R8VA?
M97AT*"=D:7-T)RP@)V-O;F9I9R<I*3L*("`@("`@("`@("`@)'-H(#T@)$=,
M3T)!3%-;)WAG971T97AT)UT@+B`G("TM;&%N9W5A9V4])R`N("1L86YG=6%G
M92`N"B`@("`@("`@("`@("`@("`@("<@+2UF<F]M+6-O9&4]:7-O+3@X-3DM
M,2`M+6ME>7=O<F0]7R`M+7-O<G0M;W5T<'5T("TM8V]P>7)I9VAT+6AO;&1E
M<CTB2&]R9&4@4')O:F5C="(G.PH@("`@("`@("`@("!I9B`H)&=E='1E>'1?
M=F5R<VEO;ELP72`^(#`@?'P@)&=E='1E>'1?=F5R<VEO;ELQ72`^(#$Q*2![
M"B`@("`@("`@("`@("`@("`D<V@@+CT@)R`M+6US9VED+6)U9W,M861D<F5S
M<STB9&5V0&QI<W1S+FAO<F1E+F]R9R(G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1F:6QE(#T@)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,@+B`D
M87!P<ULD:5T@+B`G+G!O="<["B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T
M<R@D9FEL92D@)B8@(6ES7W=R:71A8FQE*"1F:6QE*2D@>PH@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"AS<')I;G1F*"<E<R!I<R!N;W0@
M=W)I=&%B;&4N)RP@)&9I;&4I*2D["B`@("`@("`@("`@("`@("!F;V]T97(H
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&UP7V9I;&4@/2`D9FEL
M92`N("<N=&UP+G!O="<["B`@("`@("`@("`@("1S:"`N/2`G("UO("<@+B`D
M=&UP7V9I;&4@+B`G("<@+B!I;7!L;V1E*"<@)RP@)&9I;&5S*3L*("`@("`@
M("`@("`@:68@*$!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@+B`G+W!O+W1R86YS
M;&%T:6]N+G!H<"<I*2!["B`@("`@("`@("`@("`@("`D<V@@+CT@)R!P;R]T
M<F%N<VQA=&EO;BYP:'`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A)&1E8G5G*2!["B`@("`@("`@("`@("`@("`D<V@@+CT@)'-I;&5N8V4[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S
M="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG
M*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"$D=&5S="D@97AE8R@D<V@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1F:6QE<R`]('-E87)C:%]E>'0H
M)RAP:'!\:6YC?&IS*2<I.PH@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]F
M:6QT97(H)&9I;&5S+"!C<F5A=&5?9G5N8W1I;VXH)R1F:6QE)RP@)W)E='5R
M;B!S=6)S='(H)&9I;&4L(#`L(#DI("$]("(N(B`N($13("X@(F-O;F9I9R(@
M+B!$4SLG*2D["B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E*"1F
M:6QE<RP@<V5A<F-H7V5X="@G9&ES="<L("=C;VYF:6<G*2D["B`@("`@("`@
M("`@("1S:"`]("1'3$]"04Q36R=X9V5T=&5X="==("X@)R`M+6QA;F=U86=E
M/2<@+B`D;&%N9W5A9V4@+@H@("`@("`@("`@("`@("`@("`G("TM:V5Y=V]R
M9#U?("TM<V]R="UO=71P=70@+2UF;W)C92UP;R`M+6-O<'ER:6=H="UH;VQD
M97(](DAO<F1E(%!R;VIE8W0B)SL*("`@("`@("`@("`@:68@*"1G971T97AT
M7W9E<G-I;VY;,%T@/B`P('Q\("1G971T97AT7W9E<G-I;VY;,5T@/B`Q,2D@
M>PH@("`@("`@("`@("`@("`@)'-H("X]("<@+2UM<V=I9"UB=6=S+6%D9')E
M<W,](F1E=D!L:7-T<RYH;W)D92YO<F<B)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D9FEL92`]("=P;R<@+B!$4R`N("1A<'!S6R1I72`N("<N<&]T
M)SL*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE*2`F)B`A:7-?
M=W)I=&%B;&4H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@D8RT^<F5D*'-P<FEN=&8H)R5S(&ES(&YO="!W<FET86)L92XG+"`D9FEL
M92DI*3L*("`@("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T;7!?9FEL92`]("1F:6QE("X@)RYT;7`N<&]T)SL*
M("`@("`@("`@("`@)'-H("X]("<@+6\@)R`N("1T;7!?9FEL92`N("<@)R`N
M(&EM<&QO9&4H)R`G+"`D9FEL97,I("X@*"1D96)U9R`_("<G(#H@)'-I;&5N
M8V4I.PH@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H(21T97-T*2!E>&5C*"1S:"D["B`@("`@("`@?0H@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D=&UP7V9I;&4I*2!["B`@("`@("`@("`@
M("1F:6QE<R`]('-E87)C:%]E>'0H)VAT;6PG+"`G=&5M<&QA=&5S)RD["B`@
M("`@("`@("`@(&EF("@A)'1E<W0I("1T;7`@/2!F;W!E;B@D9FEL92`N("<N
M=&5M<&QA=&5S)RP@)W<G*3L*("`@("`@("`@("`@9F]R96%C:"`H)&9I;&5S
M(&%S("1T96UP;&%T92D@>PH@("`@("`@("`@("`@("`@)&9P(#T@9F]P96XH
M)'1E;7!L871E+"`G<B<I.PH@("`@("`@("`@("`@("`@)&QI;F5N;R`](#`[
M"B`@("`@("`@("`@("`@("!W:&EL92`H*"1L:6YE(#T@9F=E=',H)&9P+"`T
M,#DV*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&QI;F5N
M;RLK.PH@("`@("`@("`@("`@("`@("`@("1O9F9S970@/2`P.PH@("`@("`@
M("`@("`@("`@("`@('=H:6QE("@H)&QE9G0@/2!S=')P;W,H)&QI;F4L("<\
M9V5T=&5X=#XG+"`D;V9F<V5T*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1L969T("L](#D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1B=69F97(@/2`G)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&QI
M;F5S<&%N(#T@,#L*("`@("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"@D
M96YD(#T@<W1R<&]S*"1L:6YE+"`G/"]G971T97AT/B<L("1L969T*2D@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8G5F9F5R
M("X]('-U8G-T<B@D;&EN92P@)&QE9G0I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&QE9G0@/2`P.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&QI;F4@/2!F9V5T<R@D9G`L(#0P.38I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&QI;F5S<&%N*RL["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&QI;F4@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"AS<')I;G1F
M*"(\9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RY<;D]P96YI
M;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N(BP@)'1E;7!L871E+"`D;&EN96YO
M*2DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K(#([
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&)U9F9E<B`N
M/2!S=6)S='(H)&QI;F4L("1L969T+"`D96YD("T@)&QE9G0I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(21T97-T*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F=W)I=&4H)'1M<"P@(B,Z("1T96UP;&%T93HD;&EN
M96YO7&XB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9W<FET92@D
M=&UP+"`G;7-G:60@(B<@+B!S=')?<F5P;&%C92AA<G)A>2@G(B<L(")<;B(I
M+"!A<G)A>2@G7"(G+"`B7%QN7")<;EPB(BDL("1B=69F97(I("X@(EPB7&XB
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9W<FET92@D=&UP+"`G
M;7-G<W1R("(B)R`N(")<;EQN(BD["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@)&]F9G-E="`]("1E;F0@*R`Q
M,#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!F8VQO<V4H)'1M<"D["B`@("`@("`@("`@("1S:"`]("1'3$]"
M04Q36R=M<V=C;VUM)UT@+B`B("TM;6]R92UT:&%N/3`@+2US;W)T+6]U='!U
M="!<(B1T;7!?9FEL95PB(%PB)&9I;&4N=&5M<&QA=&5S7"(@+2UO=71P=70M
M9FEL92!<(B1T;7!?9FEL95PB(B`N("1S:6QE;F-E.PH@("`@("`@("`@("!I
M9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)'-H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21T97-T
M*2!["B`@("`@("`@("`@("`@("!E>&5C*"1S:"D["B`@("`@("`@("`@("`@
M("!U;FQI;FLH)&9I;&4@+B`G+G1E;7!L871E<R<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1D:69F(#T@87)R87E?9&EF9BAF:6QE*"1T;7!?9FEL92DL
M(&9I;&4H)&9I;&4I*3L*("`@("`@("`@("`@("`@("1D:69F(#T@<')E9U]G
M<F5P*"<O7B)03U0M0W)E871I;VXM1&%T93HO)RP@)&1I9F8L(%!214=?1U)%
M4%])3E9%4E0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)&9I;&4I('Q\(&-O=6YT*"1D:69F*2D@>PH@("`@
M("`@("`@("!`=6YL:6YK*"1F:6QE*3L*("`@("`@("`@("`@<F5N86UE*"1T
M;7!?9FEL92P@)&9I;&4I.PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^
M9W)E96XH)W5P9&%T960G*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@0'5N;&EN:R@D=&UP7V9I;&4I.PH@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@D8RT^8F]L9"@G;F]T(&-H86YG960G*2D["B`@("`@("`@?0H@("`@("`@
M(&-H9&ER*"1C=7)D:7(I.PH@("`@?0I]"@IF=6YC=&EO;B!M97)G92@I"GL*
M("`@(&=L;V)A;"`D8VUD7V]P=&EO;G,L("1A<'!S+"`D9&ER<RP@)&1E8G5G
M+"`D=&5S="P@)&,["@H@("`@)&-O;7!E;F1I=6T@/2`G("TM8V]M<&5N9&EU
M;3TB)R`N($)!4T4@+B!$4R`N("=P;R<@+B!$4R`N("=C;VUP96YD:75M+G!O
M(B<["B`@("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@
M>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C
M87-E("=H)SH*("`@("`@("`@("`@("`@('5S86=E*"D["B`@("`@("`@("`@
M("`@("!F;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@
M("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@("1L86YG(#T@
M)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!C87-E("=M)SH*("`@("`@("`@("`@8V%S92`G+2UM;V1U;&4G.@H@("`@
M("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I;VY;,5T["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G8R<Z"B`@("`@("`@("`@
M(&-A<V4@)RTM8V]M<&5N9&EU;2<Z"B`@("`@("`@("`@("`@("`D8V]M<&5N
M9&EU;2`]("<@+2UC;VUP96YD:75M/2<@+B`D;W!T:6]N6S%=.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VXG.@H@("`@("`@
M("`@("!C87-E("<M+6YO+6-O;7!E;F1I=6TG.@H@("`@("`@("`@("`@("`@
M)&-O;7!E;F1I=6T@/2`G)SL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*("`@('T*("`@(&EF("@A:7-S970H)&QA;F<I("8F("%E;7!T>2@D
M8V]M<&5N9&EU;2DI('L*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=%
M<G)O<CH@)R`N("=.;R!L;V-A;&4@<W!E8VEF:65D+B<I*3L*("`@("`@("`D
M8RT^=W)I=&5L;B@I.PH@("`@("`@('5S86=E*"D["B`@("`@("`@9F]O=&5R
M*"D["B`@("!]"@H@("`@8VQE86YU<"@I.PH*("`@(&9O<B`H)&D@/2`P.R`D
M:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH
M)&UO9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@("1C+3YW<FET96QN*'-P
M<FEN=&8H)TUE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO9'5L92`E<RXN+B<L
M("1C+3YB;VQD*"1A<'!S6R1I72DI*3L*("`@("`@("`D9&ER(#T@)&1I<G-;
M)&E=("X@1%,@+B`G<&\G("X@1%,["B`@("`@("`@:68@*&5M<'1Y*"1L86YG
M*2D@>PH@("`@("`@("`@("`D;&%N9W,@/2!G971?;&%N9W5A9V5S*"1D:7)S
M6R1I72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%`9FEL
M95]E>&ES=',H)&1I<B`N("1L86YG("X@)RYP;R<I*2!["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@G4VMI<'!E9"XN+B<I.PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1L86YG<R`](&%R<F%Y*"1L86YG
M*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&QA;F=S(&%S("1L;V-A
M;&4I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G365R9VEN
M9R!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O;&0H)&QO8V%L92DI*3L*("`@("`@
M("`@("`@)'-H(#T@)$=,3T)!3%-;)VUS9VUE<F=E)UT@+B`G("TM=7!D871E
M("UV)R`N("1C;VUP96YD:75M("X@)R`B)R`N("1D:7(@+B`D;&]C86QE("X@
M)RYP;R(@(B<@+B`D9&ER("X@)&%P<'-;)&E=("X@)RYP;W0B)SL*("`@("`@
M("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"$D=&5S="D@97AE8R@D<V@I.PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@D
M8RT^9W)E96XH)V1O;F4G*2D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO
M;B!S=&%T=7,H*0I["B`@("!R971U<FX["B`@("!G;&]B86P@)&-M9%]O<'1I
M;VYS+"`D87!P<RP@)&1I<G,L("1D96)U9RP@)'1E<W0L("1C.PH*("`@("1O
M=71P=70@/2`B<W1A='5S+FAT;6PB.PH@("`@9F]R96%C:"`H)&-M9%]O<'1I
M;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@("!S=VET8V@@*"1O<'1I;VY;
M,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@("`@("`@("!U
M<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O=&5R*"D["B`@("`@("`@("`@
M(&-A<V4@)VPG.@H@("`@("`@("`@("!C87-E("<M+6QO8V%L92<Z"B`@("`@
M("`@("`@("`@("`D;&%N9R`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@(&-A
M<V4@)RTM;6]D=6QE)SH*("`@("`@("`@("`@("`@("1M;V1U;&4@/2`D;W!T
M:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@)V\G.@H@("`@("`@("`@("!C87-E("<M+6]U='!U="<Z"B`@("`@("`@
M("`@("`@("`D;W5T<'5T(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@?0H@("`@?0H@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)&1I<G,I.R`D:2LK*2!["B`@("`@("`@:68@*"%E;7!T>2@D;6]D
M=6QE*2`F)B`D;6]D=6QE("$]("1A<'!S6R1I72D@>PH@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT
M9B@G1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN+B<L("1C+3YB
M;VQD*"1A<'!S6R1I72DI*3L*("`@("`@("!I9B`H96UP='DH)&QA;F<I*2![
M"B`@("`@("`@("`@("1L86YG<R`](&=E=%]L86YG=6%G97,H)&1I<G-;)&E=
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H(4!F:6QE7V5X
M:7-T<R@D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L86YG("X@)RYP
M;R<I*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G4VMI<'!E9"XN
M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L
M86YG<R`](&%R<F%Y*"1L86YG*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C
M:"`H)&QA;F=S(&%S("1L;V-A;&4I('L*("`@("`@("`@("`@)&,M/G=R:71E
M;&XH<W!R:6YT9B@G4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O
M;&0H)&QO8V%L92DI*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N(&-O
M;7!E;F1I=6TH*0I["B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D9&ER<RP@
M)&1E8G5G+"`D=&5S="P@)&,L("1S:6QE;F-E.PH*("`@("1D:7(@/2!"05-%
M("X@1%,@+B`G<&\G("X@1%,["B`@("`D861D(#T@)R<["B`@("!F;W)E86-H
M("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C
M:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@
M("`@("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*
M("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C
M86QE)SH*("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=D)SH*("`@
M("`@("`@("`@8V%S92`G+2UD:7)E8W1O<GDG.@H@("`@("`@("`@("`@("`@
M)&1I<B`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@8V%S92`G82<Z"B`@("`@("`@("`@(&-A<V4@)RTM861D)SH*
M("`@("`@("`@("`@("`@("1A9&0@/2`G("<@+B`D;W!T:6]N6S%=.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H@("`@:68@*"%I
M<W-E="@D;&%N9RDI('L*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=%
M<G)O<CH@)R`N("=.;R!L;V-A;&4@<W!E8VEF:65D+B<I*3L*("`@("`@("`D
M8RT^=W)I=&5L;B@I.PH@("`@("`@('5S86=E*"D["B`@("`@("`@9F]O=&5R
M*"D["B`@("!]"B`@("!P<FEN=&8H)TUE<F=I;F<@86QL("5S+G!O(&9I;&5S
M('1O('1H92!C;VUP96YD:75M+BXN("<L("1L86YG*3L*("`@("1P;V9I;&5S
M(#T@87)R87DH*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D:7)S
M*3L@)&DK*RD@>PH@("`@("`@("1P;V9I;&4@/2`D9&ER<ULD:5T@+B!$4R`N
M("=P;R<@+B!$4R`N("1L86YG("X@)RYP;R<["B`@("`@("`@:68@*&9I;&5?
M97AI<W1S*"1P;V9I;&4I*2!["B`@("`@("`@("`@("1P;V9I;&5S6UT@/2`D
M<&]F:6QE.PH@("`@("`@('T*("`@('T*("`@(&EF("@A96UP='DH)&1I<BD@
M)B8@<W5B<W1R*"1D:7(L("TQ*2`A/2!$4RD@>PH@("`@("`@("1D:7(@+CT@
M1%,["B`@("!]"B`@("`D<V@@/2`D1TQ/0D%,4ULG;7-G8V%T)UT@+B`G("TM
M<V]R="UO=71P=70@)R`N(&EM<&QO9&4H)R`G+"`D<&]F:6QE<RD@+B`D861D
M("X@)R`^("<@+B`D9&ER("X@)V-O;7!E;F1I=6TN<&\@)R`N("@D9&5B=6<@
M/R`G)R`Z("1S:6QE;F-E*3L*("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*
M("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("1C+3YW<FET96QN*"=%
M>&5C=71I;F<Z)RD["B`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@('T*
M("`@(&EF("@D=&5S="D@>PH@("`@("`@("1R970@/2`P.PH@("`@?2!E;'-E
M('L*("`@("`@("!E>&5C*"1S:"P@)&]U="P@)')E="D["B`@("!]"B`@("!I
M9B`H)')E="`]/2`P*2!["B`@("`@("`@)&,M/G=R:71E;&XH)&,M/F=R965N
M*"=D;VYE)RDI.PH@("`@?2!E;'-E('L*("`@("`@("`D8RT^=W)I=&5L;B@D
M8RT^<F5D*"=F86EL960G*2D["B`@("!]"GT*"F9U;F-T:6]N(&EN:70H*0I[
M"B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I<G,L("1D96)U
M9RP@)'1E<W0L("1C+"`D<VEL96YC93L*"B`@("!F;W)E86-H("@D8VUD7V]P
M=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO
M;ELP72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@
M('5S86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@
M("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@
M("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@
M8V%S92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O
M<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@
M("!]"B`@("!I9B`H96UP='DH)&QA;F<I*2![("1L86YG(#T@9V5T96YV*"=,
M04Y')RD[('T*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D:7)S*3L@
M)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO9'5L92D@)B8@)&UO9'5L
M92`A/2`D87!P<ULD:5TI('L@8V]N=&EN=64[('T*("`@("`@("`D<&%C:V%G
M92`]('5C9FER<W0H)&%P<'-;)&E=*3L*("`@("`@("`D<&%C:V%G95]U(#T@
M4W1R:6YG.CIU<'!E<B@D87!P<ULD:5TI.PH@("`@("`@($!I;F-L=61E("1D
M:7)S6R1I72`N("<O;&EB+W9E<G-I;VXN<&AP)SL*("`@("`@("`D=F5R<VEO
M;B`](&1E9FEN960H)'!A8VMA9V5?=2`N("=?5D524TE/3B<I(#\@8V]N<W1A
M;G0H)'!A8VMA9V5?=2`N("=?5D524TE/3B<I(#H@)S\_/R<["B`@("`@("`@
M<')I;G1F*"=);FET:6%L:7II;F<@;6]D=6QE("5S+BXN("<L("1A<'!S6R1I
M72D["B`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&1I<G-;)&E=("X@)R]P
M;R\G("X@)&%P<'-;)&E=("X@)RYP;W0G*2D@>PH@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@D8RT^<F5D*"=F86EL960G*2D["B`@("`@("`@("`@("1C+3YW
M<FET96QN*'-P<FEN=&8H)R5S(&YO="!F;W5N9"X@4G5N(%PG=')A;G-L871I
M;VX@97AT<F%C=%PG(&9I<G-T+B<L("1D:7)S6R1I72`N($13("X@)W!O)R`N
M($13("X@)&%P<'-;)&E=("X@)RYP;W0G*2D["B`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@('T*("`@("`@("`D9&ER(#T@)&1I<G-;)&E=("X@1%,@
M+B`G<&\G("X@1%,["B`@("`@("`@)'-H(#T@)$=,3T)!3%-;)VUS9VEN:70G
M72`N("<@+2UN;RUT<F%N<VQA=&]R("UI("<@+B`D9&ER("X@)&%P<'-;)&E=
M("X@)RYP;W0@)R`N"B`@("`@("`@("`@("`@*"%E;7!T>2@D;&%N9RD@/R`G
M("UO("<@+B`D9&ER("X@)&QA;F<@+B`G+G!O("TM;&]C86QE/2<@+B`D;&%N
M9R`Z("<G*2`N"B`@("`@("`@("`@("`@*"1D96)U9R`_("<G(#H@)'-I;&5N
M8V4I.PH@("`@("`@(&EF("@A96UP='DH)&QA;F<I("8F("%/4U]724Y$3U=3
M*2!["B`@("`@("`@("`@("1P;V9I;&4@/2`D9&ER<ULD:5T@+B`G+W!O+R<@
M+B`D;&%N9R`N("<N<&\G.PH@("`@("`@("`@("`D<V@@+CT@(CL@<V5D("=S
M+U!!0TM!1T4@<&%C:V%G92\D<&%C:V%G92!P86-K86=E+R<@)'!O9FEL92`B
M("X*("`@("`@("`@("`@("`@("`@(")\('-E9"`G<R]004-+04=%(%9%4E-)
M3TXO)'!A8VMA9V4@)'9E<G-I;VXO)R`B("X*("`@("`@("`@("`@("`@("`@
M(")\('-E9"`G<R]M97-S86=E<R!F;W(@4$%#2T%'12]M97-S86=E<R!F;W(@
M)'!A8VMA9V4O)R`B("X*("`@("`@("`@("`@("`@("`@(")\('-E9"`G<R],
M86YG=6%G92U496%M.B!N;VYE+TQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G+R<@(B`N"B`@("`@("`@("`@("`@("`@("`B/B`D<&]F:6QE
M+G1M<"(["B`@("`@("`@?0H@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I
M('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"1T97-T*2!["B`@("`@("`@("`@("1R970@/2`P.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T*3L*("`@
M("`@("!]"B`@("`@("`@<F5N86UE*"1P;V9I;&4@+B`G+G1M<"<L("1P;V9I
M;&4I.PH@("`@("`@(&EF("@D<F5T(#T](#`I('L*("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)&,M/F=R965N*"=D;VYE)RDI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)V9A:6QE9"<I*3L*
M("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N(&UA:V4H*0I["B`@("!G;&]B
M86P@)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I<G,L("1D96)U9RP@)'1E<W0L
M("1C+"`D<VEL96YC92P@)')E9&ER7V5R<CL*"B`@("`D8V]M<&5N9&EU;2`]
M($)!4T4@+B!$4R`N("=P;R<@+B!$4R`N("=C;VUP96YD:75M+G!O)SL*("`@
M("1S879E7W-T871S(#T@9F%L<V4["B`@("!F;W)E86-H("@D8VUD7V]P=&EO
M;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP
M72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@('5S
M86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@
M8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@
M("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@8V%S
M92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I
M;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92`G8R<Z"B`@("`@("`@("`@(&-A<V4@)RTM8V]M<&5N9&EU;2<Z"B`@("`@
M("`@("`@("`@("`D8V]M<&5N9&EU;2`]("1O<'1I;VY;,5T["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;B<Z"B`@("`@("`@
M("`@(&-A<V4@)RTM;F\M8V]M<&5N9&EU;2<Z"B`@("`@("`@("`@("`@("`D
M8V]M<&5N9&EU;2`]("<G.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@)W,G.@H@("`@("`@("`@("!C87-E("<M+7-T871I<W1I
M8W,G.@H@("`@("`@("`@("`@("`@)'-A=F5?<W1A=',@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H@("`@)&AO<F1E
M(#T@87)R87E?<V5A<F-H*"=H;W)D92<L("1D:7)S*3L*("`@("1H;W)D95]M
M<V<@/2!A<G)A>2@I.PH@("`@)'-T871S7V%R<F%Y(#T@87)R87DH*3L*"B`@
M("!R97%U:7)E7V]N8V4@)T-O;G-O;&4O5&%B;&4N<&AP)SL*("`@("1S=&%T
M<R`](&YE=R!#;VYS;VQE7U1A8FQE*"D["B`@("`D<W1A=',M/G-E=$AE861E
M<G,H87)R87DH)TUO9'5L92<L("=,86YG=6%G92<L("=4<F%N<VQA=&5D)RP@
M)T9U>GIY)RP@)U5N=')A;G-L871E9"<I*3L*"B`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI('L*("`@("`@("!I9B`H(65M<'1Y
M*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@)&%P<'-;)&E=*2!C;VYT:6YU93L*
M("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"="=6EL9&EN9R!-3R!F:6QE
M<R!F;W(@;6]D=6QE("5S+BXN)RP@)&,M/F)O;&0H)&%P<'-;)&E=*2DI.PH@
M("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*("`@("`@("`@("`@)&QA;F=S
M(#T@9V5T7VQA;F=U86=E<R@D9&ER<ULD:5TI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1D:7)S6R1I72`N($13
M("X@)W!O)R`N($13("X@)&QA;F<@+B`G+G!O)RDI('L*("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"=3:VEP<&5D+BXN)RD["B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&QA;F=S(#T@87)R87DH)&QA;F<I
M.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;&%N9W,@87,@)&QO8V%L
M92D@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"="=6EL9&EN
M9R!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O;&0H)&QO8V%L92DI*3L*("`@("`@
M("`@("`@)&1I<B`]("1D:7)S6R1I72`N($13("X@)VQO8V%L92<@+B!$4R`N
M("1L;V-A;&4@+B!$4R`N("=,0U]-15-304=%4R<["B`@("`@("`@("`@(&EF
M("@A:7-?9&ER*"1D:7(I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U-Y<W1E;2YP:'`G.PH@("`@("`@("`@("`@("`@:68@*"1D96)U9RD@
M>PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*'-P<FEN=&8H)TUA
M:VEN9R!D:7)E8W1O<GD@)7,G+"`D9&ER*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H(21T97-T("8F("%`4WES=&5M.CIM:V1I
M<B@B+7`@)&1I<B(I*2!["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=#;W5L9"!N;W0@
M8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SHG+"`D;&]C
M86QE*2D["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&1I<BD[
M"B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+RH@0V]N=F5R="!T;R!U;FEX(&QI;F5B
M<F5A:W,N("HO"B`@("`@("`@("`@("1P;V9I;&4@/2`D9&ER<ULD:5T@+B!$
M4R`N("=P;R<@+B!$4R`N("1L;V-A;&4@+B`G+G!O)SL*("`@("`@("`@("`@
M)&9P(#T@9F]P96XH)'!O9FEL92P@)W(G*3L*("`@("`@("`@("`@)&-O;G1E
M;G0@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1P;V9I;&4I*3L*("`@("`@("`@
M("`@9F-L;W-E*"1F<"D["@H@("`@("`@("`@("`D8V]N=&5N="`]('-T<E]R
M97!L86-E*")<<B(L("<G+"`D8V]N=&5N="D["B`@("`@("`@("`@("1F<"`]
M(&9O<&5N*"1P;V9I;&4L("=W8B<I.PH@("`@("`@("`@("!F=W)I=&4H)&9P
M+"`D8V]N=&5N="D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@
M("`@("`@+RH@0VAE8VL@4$\@9FEL92!S86YI='DN("HO"B`@("`@("`@("`@
M("1S:"`]("1'3$]"04Q36R=M<V=F;70G72`N("(@+2UC:&5C:R!<(B1P;V9I
M;&5<(B1R961I<E]E<G(B.PH@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T
M97-T*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG
M.B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H)'1E<W0I('L*("`@("`@("`@("`@
M("`@("1R970@/2`P.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@97AE8R@D<V@L("1O=70L("1R970I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@D<F5T("$](#`I('L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"1C+3YR960H)U=A<FYI;F<Z("<I("X@)V%N(&5R<F]R(&AA
M<R!O8V-U<F5D.B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH:6UP
M;&]D92@B7&XB+"`D;W5T*2D["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@I.PH@("`@("`@("`@("`@("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G
M*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!#;VUP:6QE($U/(&9I;&4N("HO"B`@("`@
M("`@("`@("1S:"`]("1'3$]"04Q36R=M<V=F;70G72`N("<@+2US=&%T:7-T
M:6-S("UO("(G("X@)&1I<B`N($13("X@)&%P<'-;)&E=("X@)RYM;R(@)SL*
M("`@("`@("`@("`@:68@*"1A<'!S6R1I72`A/2`G:&]R9&4G*2!["B`@("`@
M("`@("`@("`@("`D:&]R9&5?<&\@/2`D9&ER<ULD:&]R9&5=("X@1%,@+B`G
M<&\G("X@1%,@+B`D;&]C86QE("X@)RYP;R<["B`@("`@("`@("`@("`@("!I
M9B`H(4!I<U]R96%D86)L92@D:&]R9&5?<&\I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I
M;G1F*"=T:&4@2&]R9&4@4$\@9FEL92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S
M(&YO="!E>&ES=#HG+"`D;&]C86QE*2D["B`@("`@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)&AO<F1E7W!O*3L*("`@("`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@("`@("1S:"`N/2`D9&ER
M<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L;V-A;&4@+B`G+G!O)SL*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'-H
M(#T@)$=,3T)!3%-;)VUS9V-O;6TG72`N("(@+2UM;W)E+71H86X],"`M+7-O
M<G0M;W5T<'5T(%PB)'!O9FEL95PB(%PB)&AO<F1E7W!O7"(@?"`D<V@@+2([
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<V@@+CT@)'!O9FEL93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<V@@+CT@)')E9&ER7V5R<CL*("`@("`@("`@("`@:68@*"1D
M96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1S
M:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U="`]("<G.PH@("`@
M("`@("`@("!I9B`H)'1E<W0I('L*("`@("`@("`@("`@("`@("1R970@/2`P
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<'5T96YV
M*"=,04Y'/65N)RD["B`@("`@("`@("`@("`@("!E>&5C*"1S:"P@)&]U="P@
M)')E="D["B`@("`@("`@("`@("`@("!P=71E;G8H)TQ!3D<])R`N("1'3$]"
M04Q36R=L86YG=6%G92==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H)')E="`]/2`P*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D
M8RT^9W)E96XH)V1O;F4G*2D["B`@("`@("`@("`@("`@("`D;65S<V%G97,@
M/2!A<G)A>2@P+"`P+"`P*3L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O*%QD*RD@=')A;G-L871E9"\G+"`D;W5T6S!=+"`D;6%T8V@I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V5S6S!=(#T@)&UA=&-H6S%=
M.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:&]R9&5?;7-G6R1L
M;V-A;&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;65S<V%G97-;
M,%T@+3T@)&AO<F1E7VUS9ULD;&]C86QE75LP73L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1M97-S86=E<ULP72`\(#`I("1M97-S86=E<ULP72`]
M(#`["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H7&0K*2!F=7IZ>2\G
M+"`D;W5T6S!=+"`D;6%T8V@I*2!["B`@("`@("`@("`@("`@("`@("`@)&UE
M<W-A9V5S6S%=(#T@)&UA=&-H6S%=.PH@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D:&]R9&5?;7-G6R1L;V-A;&5=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;65S<V%G97-;,5T@+3T@)&AO<F1E7VUS9ULD;&]C86QE
M75LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1M97-S86=E<ULQ
M72`\(#`I("1M97-S86=E<ULQ72`](#`["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R\H7&0K*2!U;G1R86YS;&%T960O)RP@)&]U=%LP72P@)&UA=&-H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1M97-S86=E<ULR72`]("1M871C
M:%LQ73L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&AO<F1E7VUS
M9ULD;&]C86QE72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&UE<W-A
M9V5S6S)=("T]("1H;W)D95]M<V=;)&QO8V%L95U;,ET["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D;65S<V%G97-;,ET@/"`P*2`D;65S<V%G97-;
M,ET@/2`P.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("@D87!P<ULD:5T@/3T@)VAO<F1E)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1H;W)D95]M<V=;)&QO8V%L95T@/2`D
M;65S<V%G97,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M<W1A='-?87)R87E;)&%P<'-;)&E=75LD;&]C86QE72`]("1M97-S86=E<SL*
M("`@("`@("`@("`@("`@("1S=&%T<RT^861D4F]W*&%R<F%Y*"1A<'!S6R1I
M72P@)&QO8V%L92P@)&UE<W-A9V5S6S!=+"`D;65S<V%G97-;,5TL("1M97-S
M86=E<ULR72DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G9F%I;&5D)RDI.PH@("`@("`@("`@
M("`@("`@97AE8R@D<V@L("1O=70L("1R970I.PH@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH:6UP;&]D92@B7&XB+"`D;W5T*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*&-O=6YT*"1L86YG<RD@/B`Q*2!["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@365R9V4@=')A;G-L871I;VX@:6YT;R!C;VUP96YD:75M+B`J+PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1C;VUP96YD:75M*2D@>PH@("`@("`@
M("`@("`@("`@<')I;G1F*"=-97)G:6YG('1H92!03R!F:6QE(&9O<B`E<R!T
M;R!T:&4@8V]M<&5N9&EU;2XN+B`G+"`D8RT^8F]L9"@D87!P<ULD:5TI*3L*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&1I<BD@)B8@<W5B<W1R*"1D
M:7(L("TQ*2`A/2!$4RD@>PH@("`@("`@("`@("`@("`@("`@("1D:7(@+CT@
M1%,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<V@@/2`D
M1TQ/0D%,4ULG;7-G8V%T)UT@+B`B("TM<V]R="UO=71P=70@7"(D8V]M<&5N
M9&EU;5PB(%PB)'!O9FEL95PB(#X@7"(D8V]M<&5N9&EU;2YT;7!<(B(["B`@
M("`@("`@("`@("`@("!I9B`H(21D96)U9RD@>PH@("`@("`@("`@("`@("`@
M("`@("1S:"`N/2`D<VEL96YC93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1O=70@/2`G)SL*("`@("`@("`@("`@("`@(&EF("@D=&5S="D@
M>PH@("`@("`@("`@("`@("`@("`@("1R970@/2`P.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!E>&5C*"1S:"P@)&]U
M="P@)')E="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!`
M=6YL:6YK*"1C;VUP96YD:75M*3L*("`@("`@("`@("`@("`@(')E;F%M92@D
M8V]M<&5N9&EU;2`N("<N=&UP)RP@)&-O;7!E;F1I=6TI.PH@("`@("`@("`@
M("`@("`@:68@*"1R970@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"1C+3YG<F5E;B@G9&]N92<I*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M
M/G)E9"@G9F%I;&5D)RDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@?0H@("`@
M?0H@("`@:68@*&5M<'1Y*"1M;V1U;&4I*2!["B`@("`@("`@)&,M/G=R:71E
M;&XH)U)E<W5L=',Z)RD["B`@("!](&5L<V4@>PH@("`@("`@("1C+3YW<FET
M96QN*"=297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.B<I.PH@("`@?0H@("`@
M)&,M/G=R:71E;&XH)'-T871S+3YG971486)L92@I*3L*("`@(&EF("@D<V%V
M95]S=&%T<RD@>PH@("`@("`@("1F<"`]($!F;W!E;B@G=')A;G-L871I;VY?
M<W1A=',N='AT)RP@)W<G*3L*("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@
M("`@(&9W<FET92@D9G`L('-E<FEA;&EZ92@D<W1A='-?87)R87DI*3L*("`@
M("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC
M=&EO;B!C;&5A;G5P*"1K965P7W5N=')A;G-L871E9"`](&9A;'-E*0I["B`@
M("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I<G,L("1D96)U9RP@
M)'1E<W0L("1C.PH*("`@(&9O<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A<R`D
M;W!T:6]N*2!["B`@("`@("`@<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@
M("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("`@("`@=7-A9V4H*3L*("`@
M("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@("`@("`@("!C87-E("=L)SH*
M("`@("`@("`@("`@8V%S92`G+2UL;V-A;&4G.@H@("`@("`@("`@("`@("`@
M)&QA;F<@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("!C87-E("<M+6UO9'5L
M92<Z"B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)&]P=&EO;ELQ73L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI('L*("`@("`@("!I
M9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@)&%P<'-;)&E=*2![
M(&-O;G1I;G5E.R!]"B`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G0VQE
M86YI;F<@=7`@4$\@9FEL97,@9F]R(&UO9'5L92`E<RXN+B<L("1C+3YB;VQD
M*"1A<'!S6R1I72DI*3L*("`@("`@("!I9B`H96UP='DH)&QA;F<I*2!["B`@
M("`@("`@("`@("1L86YG<R`](&=E=%]L86YG=6%G97,H)&1I<G-;)&E=*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H(4!F:6QE7V5X:7-T
M<R@D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L86YG("X@)RYP;R<I
M*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G4VMI<'!E9"XN+B<I
M.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L86YG
M<R`](&%R<F%Y*"1L86YG*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H
M)&QA;F=S(&%S("1L;V-A;&4I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH
M<W!R:6YT9B@G0VQE86YI;F<@=7`@;&]C86QE("5S+BXN("<L("1C+3YB;VQD
M*"1L;V-A;&4I*2D["B`@("`@("`@("`@("1P;V9I;&4@/2`D9&ER<ULD:5T@
M+B!$4R`N("=P;R<@+B!$4R`N("1L;V-A;&4@+B`G+G!O)SL*("`@("`@("`@
M("`@)'-H(#T@)$=,3T)!3%-;)VUS9V%T=')I8B==("X@*"1K965P7W5N=')A
M;G-L871E9"`_("<G(#H@)R`M+71R86YS;&%T960G*2`N("(@+2UN;RUO8G-O
M;&5T92`M+69O<F-E+7!O("1P;V9I;&4@/B`D<&]F:6QE+G1M<"(["B`@("`@
M("`@("`@(&EF("@A)&1E8G5G*2!["B`@("`@("`@("`@("`@("`D<V@@+CT@
M)'-I;&5N8V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D96)U
M9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1O=70@/2`G)SL*("`@("`@("`@("`@:68@*"1T97-T
M*2!["B`@("`@("`@("`@("`@("`D<F5T(#T@,#L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)')E="`]/2`P*2!["B`@
M("`@("`@("`@("`@("!`=6YL:6YK*"1P;V9I;&4I.PH@("`@("`@("`@("`@
M("`@<F5N86UE*"1P;V9I;&4@+B`G+G1M<"<L("1P;V9I;&4I.PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)&,M/F=R965N*"=D;VYE)RDI.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@0'5N;&EN:R@D<&]F
M:6QE("X@)RYT;7`G+"`D<&]F:6QE*3L*("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"1C+3YR960H)V9A:6QE9"<I*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('T*("`@('T*?0H*9G5N
M8W1I;VX@8V]M;6ET*"1H96QP7V]N;'D@/2!F86QS92D*>PH@("`@9VQO8F%L
M("1C;61?;W!T:6]N<RP@)&%P<',L("1D:7)S+"`D9&5B=6<L("1T97-T+"`D
M8SL*"B`@("`D9&]C<R`](&9A;'-E.PH@("`@9F]R96%C:"`H)&-M9%]O<'1I
M;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@("!S=VET8V@@*"1O<'1I;VY;
M,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@("`@("`@("!U
M<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O=&5R*"D["B`@("`@("`@("`@
M(&-A<V4@)VPG.@H@("`@("`@("`@("!C87-E("<M+6QO8V%L92<Z"B`@("`@
M("`@("`@("`@("`D;&%N9R`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@(&-A
M<V4@)RTM;6]D=6QE)SH*("`@("`@("`@("`@("`@("1M;V1U;&4@/2`D;W!T
M:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@)VXG.@H@("`@("`@("`@("!C87-E("<M+6YE=R<Z"B`@("`@("`@("`@
M("`@("`D9&]C<R`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@8V%S92`G32<Z"B`@("`@("`@("`@(&-A<V4@)RTM;65S<V%G
M92<Z"B`@("`@("`@("`@("`@("`D;7-G(#T@)&]P=&EO;ELQ73L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@("1F:6QE<R`]
M(&%R<F%Y*"D["B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[
M("1I*RLI('L*("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U
M;&4@(3T@)&%P<'-;)&E=*2!C;VYT:6YU93L*("`@("`@("!I9B`H)&%P<'-;
M)&E=(#T]("=H;W)D92<I('L*("`@("`@("`@("`@)&1I<G-;72`]("1D:7)S
M6R1I72`N($13("X@)V%D;6EN)SL*("`@("`@("`@("`@)&%P<'-;72`]("=H
M;W)D92]A9&UI;B<["B`@("`@("`@("`@(&EF("@A96UP='DH)&UO9'5L92DI
M('L*("`@("`@("`@("`@("`@("1M;V1U;&4@/2`G:&]R9&4O861M:6XG.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;&%N
M9RDI('L*("`@("`@("`@("`@:68@*"1H96QP7V]N;'DI('L*("`@("`@("`@
M("`@("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@<W1R:7!?:&]R
M9&4H<V5A<F-H7V5X="@G>&UL)RP@)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE
M)RDI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F
M:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@<W1R:7!?:&]R9&4H9V5T7W!O
M7V9I;&5S*"1D:7)S6R1I72`N($13("X@)W!O)RDI*3L*("`@("`@("`@("`@
M("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@<W1R:7!?:&]R9&4H
M<V5A<F-H7V9I;&4H)UY;82UZ77LR?5];02U:77LR?2<L("1D:7)S6R1I72`N
M($13("X@)VQO8V%L92<L('1R=64I*2D["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)&AE;'!?;VYL>2D@>PH@("`@
M("`@("`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&1I<G-;)&E=("X@1%,@
M+B`G;&]C86QE)R`N($13("X@)&QA;F<@+B!$4R`N("=H96QP+GAM;"<I*2!C
M;VYT:6YU93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&EF("@A0&9I;&5?97AI<W1S*"1D:7)S6R1I72`N("<O<&\O)R`N("1L86YG
M("X@)RYP;R<I*2!C;VYT:6YU93L*("`@("`@("`@("`@("`@("1F:6QE<UM=
M(#T@<W1R:7!?:&]R9&4H)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,@+B`D
M;&%N9R`N("<N<&\G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FEL
M97-;72`]('-T<FEP7VAO<F1E*"1D:7)S6R1I72`N($13("X@)VQO8V%L92<@
M+B!$4R`N("1L86YG*3L*("`@("`@("!]"B`@("`@("`@:68@*"1D;V-S("8F
M("$D:&5L<%]O;FQY("8F("1A<'!S6R1I72D@>PH@("`@("`@("`@("`D9FEL
M97-;72`]('-T<FEP7VAO<F1E*"1D:7)S6R1I72`N($13("X@)V1O8W,G*3L*
M("`@("`@("`@("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@("`@
M("`@("`@("`@("`D:&]R9&5?8V]N9B`]("1D:7)S6V%R<F%Y7W-E87)C:"@G
M:&]R9&4G+"`D9&ER<RE=("X@1%,@+B`G8V]N9FEG)R`N($13.PH@("`@("`@
M("`@("`@("`@)&9I;&5S6UT@/2!S=')I<%]H;W)D92@D:&]R9&5?8V]N9B`N
M("=N;',N<&AP+F1I<W0G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*("`@(&-H9&ER*$)!4T4I.PH@("`@:68@*&-O=6YT*"1F:6QE<RDI('L*
M("`@("`@("!I9B`H)&1O8W,I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH
M)T%D9&EN9R!N97<@9FEL97,@=&\@<F5P;W-I=&]R>3HG*3L*("`@("`@("`@
M("`@)'-H(#T@)V-V<R!A9&0G.PH@("`@("`@("`@("!F;W)E86-H("@D9FEL
M97,@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@(&EF("AS=')S='(H)&9I
M;&4L("=L;V-A;&4G*2!\?"!S=')S='(H)&9I;&4L("<N<&\G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1S:"`N/2`B("1F:6QE(CL*("`@("`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@D9FEL92D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-H("X]("<[(&-V<R!A9&0G
M.PH@("`@("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@
M("`@("`@("`@("`@(&EF("AS=')S='(H)&9I;&4L("=L;V-A;&4G*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D:&5L<%]O;FQY*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1S:"`N/2`G("<@+B`D9FEL92`N($13("X@)RHN
M>&UL)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&9I
M;&4@+B!$4R`N("<J+GAM;"<I.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1S:"`N/2`G("<@+B`D9FEL
M92`N($13("X@)RHN>&UL("<@+B`D9FEL92`N($13("X@)TQ#7TU%4U-!1T53
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&9I;&4@
M+B!$4R`N("(J+GAM;%QN)&9I;&4B("X@1%,@+B`G3$-?34534T%'15,G*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"$D:&5L<%]O;FQY*2!["B`@("`@
M("`@("`@("`@("`D<V@@+CT@)SL@8W9S(&%D9"<["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H<W1R<W1R*"1F:6QE+"`G;&]C86QE)RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%D9"`]("1F:6QE("X@1%,@+B`G3$-?34534T%'
M15,G("X@1%,@+B`G*BYM;R<["B`@("`@("`@("`@("`@("`@("`@("`@("1S
M:"`N/2`G("<@+B`D861D.PH@("`@("`@("`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@D861D*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&,M/G=R:71E
M;&XH*3L*("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"$D=&5S="D@<WES=&5M*"1S:"D["B`@("`@("`@("`@
M("1C+3YW<FET96QN*"D["B`@("`@("`@?0H@("`@("`@("1C+3YW<FET96QN
M*"=#;VUM:71T:6YG.B<I.PH@("`@("`@("1C+3YW<FET96QN*&EM<&QO9&4H
M)R`G+"`D9FEL97,I*3L*("`@("`@("!I9B`H(65M<'1Y*"1L86YG*2D@>PH@
M("`@("`@("`@("`D;&%N9R`]("<@)R`N("1L86YG.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)&US9RDI('L*("`@("`@("`@("`@:68@*"1D;V-S
M*2!["B`@("`@("`@("`@("`@("`D;7-G(#T@(D%D9"1L86YG('1R86YS;&%T
M:6]N+B(["B`@("`@("`@("`@('T@96QS96EF("@D:&5L<%]O;FQY*2!["B`@
M("`@("`@("`@("`@("`D;7-G(#T@(E5P9&%T921L86YG(&AE;'`@9FEL92XB
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&US9R`]
M(")5<&1A=&4D;&%N9R!T<F%N<VQA=&EO;BXB.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1S:"`]("=C=G,@8V]M;6ET("UM("(G("X@)&US
M9R`N("<B("<@+B!I;7!L;V1E*"<@)RP@)&9I;&5S*3L*("`@("`@("!I9B`H
M)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@("`@("1C+3YW<FET96QN*"=%
M>&5C=71I;F<Z)RD["B`@("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@
M("`@("`@?0H@("`@("`@(&EF("@A)'1E<W0I('-Y<W1E;2@D<V@I.PH@("`@
M?0I]"@IF=6YC=&EO;B!U<&1A=&5?:&5L<"@I"GL*("`@(&=L;V)A;"`D8VUD
M7V]P=&EO;G,L("1D:7)S+"`D87!P<RP@)&1E8G5G+"`D=&5S="P@)&QA<W1?
M97)R;W)?;7-G+"`D8SL*"B`@("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@
M87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@
M("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@('5S86=E*"D[
M"B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G
M;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@
M("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@8V%S92`G+2UM
M;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I;VY;,5T[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"B`@("`D
M9FEL97,@/2!A<G)A>2@I.PH@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H
M)&1I<G,I.R`D:2LK*2!["B`@("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2`F
M)B`D;6]D=6QE("$]("1A<'!S6R1I72D@>R!C;VYT:6YU93L@?0H@("`@("`@
M(&EF("@A:7-?9&ER*"(D9&ER<ULD:5TO;&]C86QE(BDI(&-O;G1I;G5E.PH@
M("`@("`@(&EF("@D87!P<ULD:5T@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@
M("`D9&ER<UM=(#T@)&1I<G-;)&E=("X@1%,@+B`G861M:6XG.PH@("`@("`@
M("`@("`D87!P<UM=(#T@)VAO<F1E+V%D;6EN)SL*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D;6]D=6QE*2D@>PH@("`@("`@("`@("`@("`@)&UO9'5L92`]
M("=H;W)D92]A9&UI;B<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1L86YG*2D@>PH@("`@("`@("`@("`D9FEL97,@/2!S
M96%R8VA?9FEL92@G:&5L<"YX;6PG+"`D9&ER<ULD:5T@+B!$4R`N("=L;V-A
M;&4G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL97,@/2!A
M<G)A>2@D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G("X@1%,@+B`D;&%N9R`N
M($13("X@)VAE;'`N>&UL)RD["B`@("`@("`@?0H@("`@("`@("1F:6QE7V5N
M("`]("1D:7)S6R1I72`N($13("X@)VQO8V%L92<@+B!$4R`N("=E;E]54R<@
M+B!$4R`N("=H96QP+GAM;"<["B`@("`@("`@:68@*"%`9FEL95]E>&ES=',H
M)&9I;&5?96XI*2!["B`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P
M*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE<F4@9&]E<VY<
M)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RXG+"`D8RT^8F]L9"@D
M87!P<ULD:5TI*2DI.PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H
M)&9I;&5S(&%S("1F:6QE7VQO8RD@>PH@("`@("`@("`@("`D;&]C86QE(#T@
M<W5B<W1R*"1F:6QE7VQO8RP@,"P@<W1R<G!O<R@D9FEL95]L;V,L($13*2D[
M"B`@("`@("`@("`@("1L;V-A;&4@/2!S=6)S='(H)&QO8V%L92P@<W1R<G!O
M<R@D;&]C86QE+"!$4RD@*R`Q*3L*("`@("`@("`@("`@:68@*"1L;V-A;&4@
M/3T@)V5N7U53)RD@8V]N=&EN=64["B`@("`@("`@("`@(&EF("@A0&9I;&5?
M97AI<W1S*"1F:6QE7VQO8RDI('L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G
M5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VY<)W0@>65T(&5X:7-T+B!#
M<F5A=&EN9R!A(&YE=R!O;F4N)RP@)&,M/F)O;&0H)&QO8V%L92DL("1C+3YB
M;VQD*"1A<'!S6R1I72DI*2D["B`@("`@("`@("`@("`@("`D9&ER7VQO8R`]
M('-U8G-T<B@D9FEL95]L;V,L(#`L("TY*3L*("`@("`@("`@("`@("`@(&EF
M("@A:7-?9&ER*"1D:7)?;&]C*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G4WES=&5M+G!H<"<["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;BAS<')I;G1F*"=-86MI;F<@9&ER96-T;W)Y("5S)RP@
M)&1I<E]L;V,I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@:68@*"$D=&5S="`F)B`A0%-Y<W1E;3HZ;6MD:7(H(BUP("1D
M:7)?;&]C(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=#;W5L9"!N;W0@
M8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SHG+"`D;&]C
M86QE*2D["B`@("`@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1D
M:7)?;&]C*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*'=O<F1W<F%P*'-P<FEN=&8H)T-O<'EI;F<@)7,@=&\@
M)7,G+"`D9FEL95]E;BP@)&9I;&5?;&]C*2DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*"$D=&5S="`F)B`A0&-O<'DH)&9I;&5?
M96XL("1F:6QE7VQO8RDI('L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@D8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)T-O=6QD(&YO
M="!C;W!Y("5S('1O("5S)RP@)&9I;&5?96XL("1F:6QE7VQO8RDI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1C+3YW<FET96QN*'-P<FEN=&8H)U5P9&%T:6YG("5S(&AE;'`@
M9FEL92!F;W(@)7,N)RP@)&,M/F)O;&0H)&QO8V%L92DL("1C+3YB;VQD*"1A
M<'!S6R1I72DI*3L*("`@("`@("`@("`@)&9P(#T@9F]P96XH)&9I;&5?;&]C
M+"`G<B<I.PH@("`@("`@("`@("`D;&EN92`](&9G971S*"1F<"D["B`@("`@
M("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!I9B`H(7-T<G-T<B@D
M;&EN92P@)SP_>&UL)RDI('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN
M*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE
M(&AE;'`@9FEL92`E<R!D:61N7"=T('-T87)T('=I=&@@/#]X;6PG+"`D9FEL
M95]L;V,I*2D["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&5N8V]D:6YG(#T@)R<["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O96YC;V1I;F<]*%LB7"==*2A;7EQ<,5TK*5Q<,2\G+"`D;&EN92P@)&UA
M=&-H*2D@>PH@("`@("`@("`@("`@("`@)&5N8V]D:6YG(#T@)&UA=&-H6S)=
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D;V-?96X@/2!D;VUX;6Q?
M;W!E;E]F:6QE*"1F:6QE7V5N*3L*("`@("`@("`@("`@:68@*"%I<U]O8FIE
M8W0H)&1O8U]E;BDI('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*'=O
M<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE<F4@
M=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN:6YG
M('1R86YS;&%T:6]N+G!H<"!W:71H('1H92!F;&%G("UD('1O('-E92!A;GD@
M97)R;W(@;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BXG+"`D9FEL95]E
M;BDI*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@
M("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1D;V-?;&]C(#T@9&]M>&UL7V]P96Y?9FEL92@D9FEL95]L;V,I.PH@("`@
M("`@("`@("!I9B`H(6ES7V]B:F5C="@D9&]C7VQO8RDI('L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z
M("<I("X@<W!R:6YT9B@G5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE
M(&9I;&4@)7,N(%1R>2!R=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H
M92!F;&%G("UD('1O('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@
M>&UL('!A<G-E<BXG+"`D9FEL95]L;V,I*2D["B`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&1O8U]N97<@(#T@9&]M>&UL7VYE=U]D
M;V,H)S$N,"<I.PH@("`@("`@("`@("`D:&5L<%]E;B`@/2`D9&]C7V5N+3YD
M;V-U;65N=%]E;&5M96YT*"D["B`@("`@("`@("`@("1H96QP7VQO8R`]("1D
M;V-?;&]C+3YD;V-U;65N=%]E;&5M96YT*"D["B`@("`@("`@("`@("1H96QP
M7VYE=R`]("1H96QP7VQO8RT^8VQO;F5?;F]D92@I.PH@("`@("`@("`@("`D
M96YT<FEE<U]L;V,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D96YT<FEE<U]N
M97<@/2!A<G)A>2@I.PH@("`@("`@("`@("`D8V]U;G1?=7!T;V1A=&4@/2`P
M.PH@("`@("`@("`@("`D8V]U;G1?;F5W("`@("`@/2`P.PH@("`@("`@("`@
M("`D8V]U;G1?8VAA;F=E9"`@/2`P.PH@("`@("`@("`@("`D8V]U;G1?=6YK
M;F]W;B`@/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D9&]C7VQO8RT^9V5T
M7V5L96UE;G1S7V)Y7W1A9VYA;64H)V5N=')Y)RD@87,@)&5N=')Y*2!["B`@
M("`@("`@("`@("`@("`D96YT<FEE<U]L;V-;)&5N=')Y+3YG971?871T<FEB
M=71E*"=I9"<I72`]("1E;G1R>3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!F;W)E86-H("@D9&]C7V5N+3YG971?96QE;65N='-?8GE?=&%G;F%M92@G
M96YT<GDG*2!A<R`D96YT<GDI('L*("`@("`@("`@("`@("`@("1I9"`]("1E
M;G1R>2T^9V5T7V%T=')I8G5T92@G:60G*3L*("`@("`@("`@("`@("`@(&EF
M("AA<G)A>5]K97E?97AI<W1S*"1I9"P@)&5N=')I97-?;&]C*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D96YT<FEE<U]L;V-;)&ED72T^:&%S7V%T
M=')I8G5T92@G;60U)RD@)B8*("`@("`@("`@("`@("`@("`@("`@("`@;60U
M*"1E;G1R>2T^9V5T7V-O;G1E;G0H*2D@(3T@)&5N=')I97-?;&]C6R1I9%TM
M/F=E=%]A='1R:6)U=&4H)VUD-2<I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VUM96YT(#T@)&1O8U]L;V,M/F-R96%T95]C;VUM96YT*"(@16YG
M;&ES:"!E;G1R>3I<;B(@+B!S=')?<F5P;&%C92@G+2TG+"`G)B,T-3LF(S0U
M.R<L("1D;V-?;&]C+3YD=6UP7VYO9&4H)&5N=')Y*2DI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D96YT<FEE<U]L;V-;)&ED72T^87!P96YD7V-H:6QD
M*"1C;VUM96YT*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y7VYE
M=R`]("1E;G1R:65S7VQO8ULD:61=+3YC;&]N95]N;V1E*'1R=64I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D96YT<GE?;F5W+3YS971?871T<FEB=71E
M*"=S=&%T92<L("=C:&%N9V5D)RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("1C;W5N=%]C:&%N9V5D*RL["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D96YT<FEE<U]L;V-;
M)&ED72T^:&%S7V%T=')I8G5T92@G<W1A=&4G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;6UE;G0@/2`D9&]C7VQO8RT^8W)E871E7V-O
M;6UE;G0H(B!%;F=L:7-H(&5N=')Y.EQN(B`N('-T<E]R97!L86-E*"<M+2<L
M("<F(S0U.R8C-#4[)RP@)&1O8U]L;V,M/F1U;7!?;F]D92@D96YT<GDI*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YT<FEE<U]L;V-;)&ED
M72T^87!P96YD7V-H:6QD*"1C;VUM96YT*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E;G1R>5]N97<@/2`D96YT<FEE<U]L;V-;)&ED72T^8VQO
M;F5?;F]D92AT<G5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E
M;G1R>5]N97<M/G-E=%]A='1R:6)U=&4H)W-T871E)RP@)W5N:VYO=VXG*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N=%]U;FMN;W=N*RL[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D96YT<GE?;F5W(#T@)&5N=')I97-?;&]C6R1I
M9%TM/F-L;VYE7VYO9&4H=')U92D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]U;G1?=7!T;V1A=&4K*SL*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&5N=')Y7VYE=R`]("1E;G1R
M>2T^8VQO;F5?;F]D92AT<G5E*3L*("`@("`@("`@("`@("`@("`@("`D96YT
M<GE?;F5W+3YS971?871T<FEB=71E*"=S=&%T92<L("=N97<G*3L*("`@("`@
M("`@("`@("`@("`@("`D8V]U;G1?;F5W*RL["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D96YT<FEE<U]N97=;72`]("1E;G1R>5]N97<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1O8U]N97<M/F%P<&5N9%]C
M:&EL9"@D9&]C7VYE=RT^8W)E871E7V-O;6UE;G0H)R`D)R`N("=(;W)D920@
M)RDI.PH@("`@("`@("`@("!F;W)E86-H("@D96YT<FEE<U]N97<@87,@)&5N
M=')Y*2!["B`@("`@("`@("`@("`@("`D:&5L<%]N97<M/F%P<&5N9%]C:&EL
M9"@D96YT<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C+3YW<FET
M96QN*'=O<F1W<F%P*'-P<FEN=&8H)T5N=')I97,Z("5D('1O=&%L+"`E9"!U
M<"UT;RUD871E+"`E9"!N97<L("5D(&-H86YG960L("5D('5N:VYO=VXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O=6YT7W5P
M=&]D871E("L@)&-O=6YT7VYE=R`K("1C;W5N=%]C:&%N9V5D("L@)&-O=6YT
M7W5N:VYO=VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]U;G1?=7!T;V1A=&4L("1C;W5N=%]N97<L("1C;W5N=%]C:&%N9V5D
M+"`D8V]U;G1?=6YK;F]W;BDI*3L*("`@("`@("`@("`@)&1O8U]N97<M/F%P
M<&5N9%]C:&EL9"@D:&5L<%]N97<I.PH@("`@("`@("`@("`D;W5T<'5T(#T@
M)&1O8U]N97<M/F1U;7!?;65M*'1R=64L("1E;F-O9&EN9RD["B`@("`@("`@
M("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*'=O<F1W<F%P*'-P<FEN=&8H)U=R:71I;F<@=7!D871E9"!H
M96QP(&9I;&4@=&\@)7,N)RP@)&9I;&5?;&]C*2DI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@A)'1E<W0I('L*("`@("`@("`@("`@("`@("1F
M<"`](&9O<&5N*"1F:6QE7VQO8RP@)W<G*3L*("`@("`@("`@("`@("`@("1L
M:6YE(#T@9G=R:71E*"1F<"P@)&]U='!U="D["B`@("`@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8RT^=W)I
M=&5L;BAS<')I;G1F*"<E9"!B>71E<R!W<FET=&5N+B<L('-T<FQE;B@D;W5T
M<'5T*2DI.PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('T*
M("`@('T*?0H*9G5N8W1I;VX@;6%K95]H96QP*"D*>PH@("`@9VQO8F%L("1C
M;61?;W!T:6]N<RP@)&1I<G,L("1A<'!S+"`D9&5B=6<L("1T97-T+"`D8SL*
M"B`@("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@
M("`@("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E
M("=H)SH*("`@("`@("`@("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@
M("!F;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@
M(&-A<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@("1L86YG(#T@)&]P
M=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C
M87-E("=M)SH*("`@("`@("`@("`@8V%S92`G+2UM;V1U;&4G.@H@("`@("`@
M("`@("`@("`@)&UO9'5L92`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"B`@("!]"B`@("`D9FEL97,@/2!A<G)A>2@I
M.PH@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2![
M"B`@("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A
M<'!S6R1I72D@8V]N=&EN=64["B`@("`@("`@:68@*"%I<U]D:7(H(B1D:7)S
M6R1I72]L;V-A;&4B*2D@8V]N=&EN=64["B`@("`@("`@:68@*"1A<'!S6R1I
M72`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@("1D:7)S6UT@/2`D9&ER<ULD
M:5T@+B!$4R`N("=A9&UI;B<["B`@("`@("`@("`@("1A<'!S6UT@/2`G:&]R
M9&4O861M:6XG.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I*2![
M"B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)VAO<F1E+V%D;6EN)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&QA;F<I
M*2!["B`@("`@("`@("`@("1F:6QE<R`]('-E87)C:%]F:6QE*"=H96QP+GAM
M;"<L("1D:7)S6R1I72`N($13("X@)VQO8V%L92<I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y*"1D:7)S6R1I72`N($13
M("X@)VQO8V%L92<@+B!$4R`N("1L86YG("X@1%,@+B`G:&5L<"YX;6PG*3L*
M("`@("`@("!]"B`@("`@("`@)&9I;&5?96X@(#T@)&1I<G-;)&E=("X@1%,@
M+B`G;&]C86QE)R`N($13("X@)V5N7U53)R`N($13("X@)VAE;'`N>&UL)SL*
M("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9FEL95]E;BDI('L*("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1F
M:6QE<R!A<R`D9FEL95]L;V,I('L*("`@("`@("`@("`@:68@*"%`9FEL95]E
M>&ES=',H)&9I;&5?;&]C*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)U-K:7!P960N+BXG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN
M*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D;&]C86QE(#T@<W5B<W1R*"1F:6QE7VQO8RP@,"P@<W1R
M<G!O<R@D9FEL95]L;V,L($13*2D["B`@("`@("`@("`@("1L;V-A;&4@/2!S
M=6)S='(H)&QO8V%L92P@<W1R<G!O<R@D;&]C86QE+"!$4RD@*R`Q*3L*("`@
M("`@("`@("`@:68@*"1L;V-A;&4@/3T@)V5N7U53)RD@8V]N=&EN=64["B`@
M("`@("`@("`@("1C+3YW<FET96QN*'-P<FEN=&8H)U5P9&%T:6YG("5S(&AE
M;'`@9FEL92!F;W(@)7,N)RP@)&,M/F)O;&0H)&QO8V%L92DL("1C+3YB;VQD
M*"1A<'!S6R1I72DI*3L*("`@("`@("`@("`@)&9P(#T@9F]P96XH)&9I;&5?
M;&]C+"`G<B<I.PH@("`@("`@("`@("`D;&EN92`](&9G971S*"1F<"D["B`@
M("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!I9B`H(7-T<G-T
M<B@D;&EN92P@)SP_>&UL)RDI('L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G
M5&AE(&AE;'`@9FEL92`E<R!D:61N7"=T('-T87)T('=I=&@@/#]X;6PG+"`D
M9FEL95]L;V,I*2D["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&5N8V]D:6YG(#T@)R<["B`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O96YC;V1I;F<]*%LB7"==*2A;7EQ<,5TK*5Q<,2\G+"`D;&EN92P@
M)&UA=&-H*2D@>PH@("`@("`@("`@("`@("`@)&5N8V]D:6YG(#T@)&UA=&-H
M6S)=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D;V-?96X@("`](&1O
M;7AM;%]O<&5N7V9I;&4H)&9I;&5?96XI.PH@("`@("`@("`@("!I9B`H(6ES
M7V]B:F5C="@D9&]C7V5N*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH=V]R9'=R87`H)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4
M:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U
M;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E
M(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+B<L("1F
M:6QE7V5N*2DI.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E(#(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&1O8U]L;V,@(#T@9&]M>&UL7V]P96Y?9FEL92@D9FEL95]L;V,I
M.PH@("`@("`@("`@("!I9B`H(6ES7V]B:F5C="@D9&]C7VQO8RDI('L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*"1C+3YR960H)U=A
M<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI
M;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W
M:71H('1H92!F;&%G("UD('1O('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O
M;2!T:&4@>&UL('!A<G-E<BXG+"`D9FEL95]L;V,I*2D["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AE;'!?;&]C(#T@)&1O8U]L
M;V,M/F1O8W5M96YT7V5L96UE;G0H*3L*("`@("`@("`@("`@)&UD-5]E;B`@
M(#T@87)R87DH*3L*("`@("`@("`@("`@)&-O=6YT7V%L;"`](#`["B`@("`@
M("`@("`@("1C;W5N="`@("`@/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D
M9&]C7V5N+3YG971?96QE;65N='-?8GE?=&%G;F%M92@G96YT<GDG*2!A<R`D
M96YT<GDI('L*("`@("`@("`@("`@("`@("1M9#5?96Y;)&5N=')Y+3YG971?
M871T<FEB=71E*"=I9"<I72`](&UD-2@D96YT<GDM/F=E=%]C;VYT96YT*"DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1D;V-?;&]C
M+3YG971?96QE;65N='-?8GE?=&%G;F%M92@G96YT<GDG*2!A<R`D96YT<GDI
M('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E;G1R>2T^8VAI;&1?;F]D
M97,H*2!A<R`D8VAI;&0I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-H
M:6QD+3YN;V1E7W1Y<&4H*2`]/2!834Q?0T]-345.5%].3T1%("8F('-T<G-T
M<B@D8VAI;&0M/FYO9&5?=F%L=64H*2P@)T5N9VQI<V@@96YT<GDG*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D96YT<GDM/G)E;6]V95]C:&EL9"@D
M8VAI;&0I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1C;W5N=%]A;&PK*SL*("`@("`@("`@("`@
M("`@("1I9"`]("1E;G1R>2T^9V5T7V%T=')I8G5T92@G:60G*3L*("`@("`@
M("`@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D:60L("1M9#5?96XI
M*2!["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H
M)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=.;R!E;G1R>2!W:71H
M('1H92!I9"`B)7,B(&5X:7-T<R!I;B!T:&4@;W)I9VEN86P@:&5L<"!F:6QE
M+B<L("1I9"DI*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&5N=')Y+3YS971?871T<FEB=71E*"=M9#4G+"`D;60U
M7V5N6R1I9%TI.PH@("`@("`@("`@("`@("`@("`@("1E;G1R>2T^<V5T7V%T
M=')I8G5T92@G<W1A=&4G+"`G=7!T;V1A=&4G*3L*("`@("`@("`@("`@("`@
M("`@("`D8V]U;G0K*SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D;W5T<'5T(#T@)&1O8U]L;V,M/F1U;7!?;65M*'1R
M=64L("1E;F-O9&EN9RD["B`@("`@("`@("`@(&EF("@A)'1E<W0I('L*("`@
M("`@("`@("`@("`@("1F<"`](&9O<&5N*"1F:6QE7VQO8RP@)W<G*3L*("`@
M("`@("`@("`@("`@("1L:6YE(#T@9G=R:71E*"1F<"P@)&]U='!U="D["B`@
M("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"<E9"!O9B`E9"!E;G1R:65S
M(&UA<FME9"!A<R!U<"UT;RUD871E)RP@)&-O=6YT+"`D8V]U;G1?86QL*2D[
M"B`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@?0H@("`@?0I]
M"@HD8W5R9&ER(#T@9V5T8W=D*"D["F1E9FEN92@G1%,G+"!$25)%0U1/4EE?
M4T5005)!5$]2*3L*"B1L86YG=6%G92`](&=E=&5N=B@G3$%.1R<I.PII9B`H
M96UP='DH)&QA;F=U86=E*2D@>PH@("`@)&QA;F=U86=E(#T@9V5T96YV*"=,
M04Y'54%'12<I.PI]"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G
M.PH*)&,@/2`F;F5W($AO<F1E7T-,22@I.PII9B`H(21C+3YR=6YN:6YG1G)O
M;4-,22@I*2!["B`@("`D8RT^9F%T86PH)U1H:7,@<V-R:7!T(&UU<W0@8F4@
M<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN92XG*3L*?0HD8RT^:6YI="@I.PH*
M)&,M/G=R:71E;&XH)&,M/F)O;&0H)RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2<I*3L*)&,M/G=R:71E;&XH)&,M/F)O;&0H)TAO<F1E('1R86YS;&%T
M:6]N(&=E;F5R871O<B<I*3L*)&,M/G=R:71E;&XH)&,M/F)O;&0H)RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2<I*3L*"B\J(%-A;FET>2!C:&5C:W,@
M*B\*:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=G971T97AT)RDI('L*("`@("1C
M+3YW<FET96QN*"1C+3YR960H)T=E='1E>'0@97AT96YS:6]N(&YO="!F;W5N
M9"$G*2D["B`@("!F;V]T97(H*3L*?0H*)&,M/G=R:71E;&XH)TQO861I;F<@
M;&EB<F%R:65S+BXN)RD["B1L:6)S7V9O=6YD(#T@=')U93L*"F9O<F5A8V@@
M*&%R<F%Y*"=#;VYS;VQE7T=E=&]P="<@/3X@)T-O;G-O;&4O1V5T;W!T+G!H
M<"<L"B`@("`@("`@("`@("`@("=#;VYS;VQE7U1A8FQE)R`@/3X@)T-O;G-O
M;&4O5&%B;&4N<&AP)RP*("`@("`@("`@("`@("`@)T9I;&5?1FEN9"<@("`@
M("`]/B`G1FEL92]&:6YD+G!H<"<I"B`@("`@("`@(&%S("1C;&%S<R`]/B`D
M9FEL92D@>PH@("`@96-H;R`D8VQA<W,@+B`G+BXN("<["B`@("!`:6YC;'5D
M92`D9FEL93L*("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@
M("`@("1C+3YW<FET96QN*"1C+3YG<F5E;B@G3TLG*2D["B`@("!](&5L<V4@
M>PH@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H<W!R:6YT9B@G)7,@;F]T
M(&9O=6YD+B<L("1C;&%S<RDI*3L*("`@("`@("`D;&EB<U]F;W5N9"`](&9A
M;'-E.PH@("`@?0I]"@II9B`H(21L:6)S7V9O=6YD*2!["B`@("`D8RT^=W)I
M=&5L;B@I.PH@("`@)&,M/G=R:71E;&XH)TUA:V4@<W5R92!T:&%T('EO=2!H
M879E(%!%05(@:6YS=&%L;&5D(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"XG
M*3L*("`@("1C+3YW<FET96QN*"=I;F-L=61E7W!A=&@Z("<@+B!I;FE?9V5T
M*"=I;F-L=61E7W!A=&@G*2D["B`@("!F;V]T97(H*3L*?0HD8RT^=W)I=&5L
M;B@I.PH*+RH@0V]M;6%N9&QI;F4@<&%R86UE=&5R<R`J+PHD87)G<R`@("`]
M($-O;G-O;&5?1V5T;W!T.CIR96%D4$A007)G=B@I.PHD;W!T:6]N<R`]($-O
M;G-O;&5?1V5T;W!T.CIG971O<'0H)&%R9W,L("=B.F1H="<L(&%R<F%Y*"=B
M87-E/2<L("=D96)U9R<L("=H96QP)RP@)W1E<W0G*2D["FEF("A014%2.CII
M<T5R<F]R*"1O<'1I;VYS*2`F)B`D87)G<ULP72`]/2`D7U-%4E9%4ELG4$A0
M7U-%3$8G72D@>PH@("`@87)R87E?<VAI9G0H)&%R9W,I.PH@("`@)&]P=&EO
M;G,@/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T*"1A<F=S+"`G8CID:'0G+"!A
M<G)A>2@G8F%S93TG+"`G9&5B=6<G+"`G:&5L<"<L("=T97-T)RDI.PI]"FEF
M("A014%2.CII<T5R<F]R*"1O<'1I;VYS*2D@>PH@("`@)&,M/G=R:71E;&XH
M)&,M/G)E9"@G1V5T;W!T($5R<F]R.B`G("X@<W1R7W)E<&QA8V4H)T-O;G-O
M;&5?1V5T;W!T.B<L("<G+"`D;W!T:6]N<RT^9V5T365S<V%G92@I*2DI.PH@
M("`@)&,M/G=R:71E;&XH*3L*("`@('5S86=E*"D["B`@("!F;V]T97(H*3L*
M?0II9B`H96UP='DH)&]P=&EO;G-;,%U;,%TI("8F(&5M<'1Y*"1O<'1I;VYS
M6S%=6S!=*2D@>PH@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G17)R;W(Z("<@
M+B`G3F\@8V]M;6%N9"!S<&5C:69I960N)RDI.PH@("`@)&,M/G=R:71E;&XH
M*3L*("`@('5S86=E*"D["B`@("!F;V]T97(H*3L*?0HD9&5B=6<@/2!F86QS
M93L*)'1E<W0@(#T@9F%L<V4["F9O<F5A8V@@*"1O<'1I;VYS6S!=(&%S("1O
M<'1I;VXI('L*("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@(&-A
M<V4@)V(G.@H@("`@("`@(&-A<V4@)RTM8F%S92<Z"B`@("`@("`@("`@(&EF
M("AS=6)S='(H)&]P=&EO;ELQ72P@+3$I(#T]($13*2!["B`@("`@("`@("`@
M("`@("`D;W!T:6]N6S%=(#T@<W5B<W1R*"1O<'1I;VY;,5TL(#`L("TQ*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!D969I;F4H)T)!4T4G+"`D;W!T
M:6]N6S%=*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G9"<Z
M"B`@("`@("`@8V%S92`G+2UD96)U9R<Z"B`@("`@("`@("`@("1D96)U9R`]
M('1R=64["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@)W0G.@H@
M("`@("`@(&-A<V4@)RTM=&5S="<Z"B`@("`@("`@("`@("1T97-T(#T@=')U
M93L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G:"<Z"B`@("`@
M("`@8V%S92`G+2UH96QP)SH*("`@("`@("`@("`@=7-A9V4H*3L*("`@("`@
M("`@("`@9F]O=&5R*"D["B`@("!]"GT*:68@*"$D9&5B=6<I('L*("`@(&EN
M:5]S970H)V5R<F]R7W)E<&]R=&EN9R<L(&9A;'-E*3L*?0II9B`H(61E9FEN
M960H)T)!4T4G*2D@>PH@("`@9&5F:6YE*"="05-%)RP@2$]21$5?0D%312D[
M"GT*:68@*"1O<'1I;VYS6S%=6S!=(#T]("=H96QP)RD@>PH@("`@=7-A9V4H
M*3L*("`@(&9O;W1E<B@I.PI]"B1S:6QE;F-E(#T@)&1E8G5G('Q\($]37U=)
M3D1/5U,@/R`G)R`Z("<@,CX@+V1E=B]N=6QL)SL*)')E9&ER7V5R<B`]($]3
M7U=)3D1/5U,@/R`G)R`Z("<@,CXF,2<["B1O<'1I;VYS7VQI<W0@/2!A<G)A
M>2@*("`@("=C;&5A;G5P)R`@("`]/B!A<G)A>2@G:&PZ;3HG+"!A<G)A>2@G
M;6]D=6QE/2<L("=L;V-A;&4])RDI+`H@("`@)V-O;6UI="<@("`@(#T^(&%R
M<F%Y*"=H;#IM.FY-.B<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO8V%L93TG+"`G
M;F5W)RP@)VUE<W-A9V4])RDI+`H@("`@)V-O;6UI="UH96QP)ST^(&%R<F%Y
M*"=H;#IM.FY-.B<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO8V%L93TG+"`G;F5W
M)RP@)VUE<W-A9V4])RDI+`H@("`@)V-O;7!E;F1I=6TG(#T^(&%R<F%Y*"=H
M;#ID.F$Z)RP@87)R87DH)VQO8V%L93TG+"`G9&ER96-T;W)Y/2<L("=A9&0]
M)RDI+`H@("`@)V5X=')A8W0G("`@(#T^(&%R<F%Y*"=H;3HG+"!A<G)A>2@G
M;6]D=6QE/2<I*2P*("`@("=I;FET)R`@("`@("`]/B!A<G)A>2@G:&PZ;3IN
M8SHG+"!A<G)A>2@G;6]D=6QE/2<L("=L;V-A;&4])RP@)VYO+6-O;7!E;F1I
M=6TG+"`G8V]M<&5N9&EU;3TG*2DL"B`@("`G;65R9V4G("`@("`@/3X@87)R
M87DH)VAL.FTZ8SIN)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=C
M;VUP96YD:75M/2<L("=N;RUC;VUP96YD:75M)RDI+`H@("`@)VUA:V4G("`@
M("`@(#T^(&%R<F%Y*"=H;#IM.F,Z;G,G+"!A<G)A>2@G;6]D=6QE/2<L("=L
M;V-A;&4])RP@)V-O;7!E;F1I=6T])RP@)VYO+6-O;7!E;F1I=6TG+"`G<W1A
M=&ES=&EC<R<I*2P*("`@("=M86ME+6AE;'`G("`]/B!A<G)A>2@G:&PZ;3HG
M+"!A<G)A>2@G;6]D=6QE/2<L("=L;V-A;&4])RDI+`H@("`@)W5P9&%T92<@
M("`@(#T^(&%R<F%Y*"=H;#IM.F,Z;B<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO
M8V%L93TG+"`G8V]M<&5N9&EU;3TG+"`G;F\M8V]M<&5N9&EU;2<I*2P*("`@
M("=U<&1A=&4M:&5L<"<]/B!A<G)A>2@G:&PZ;3HG+"!A<G)A>2@G;6]D=6QE
M/2<L("=L;V-A;&4])RDI+`H@("`@)W-T871U<R<@("`@(#T^(&%R<F%Y*"=H
M;#IM.F\Z)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=O=71P=70]
M)RDI"BD["B1O<'1I;VYS7V%R<B`]("1O<'1I;VYS6S%=.PHD8VUD("`@("`@
M("`@/2!A<G)A>5]S:&EF="@D;W!T:6]N<U]A<G(I.PII9B`H87)R87E?:V5Y
M7V5X:7-T<R@D8VUD+"`D;W!T:6]N<U]L:7-T*2D@>PH@("`@)&-M9%]O<'1I
M;VYS(#T@0V]N<V]L95]'971O<'0Z.F=E=&]P="@D;W!T:6]N<U]A<G(L("1O
M<'1I;VYS7VQI<W1;)&-M9%U;,%TL("1O<'1I;VYS7VQI<W1;)&-M9%U;,5TI
M.PH@("`@:68@*%!%05(Z.FES17)R;W(H)&-M9%]O<'1I;VYS*2D@>PH@("`@
M("`@("1C+3YW<FET96QN*"1C+3YR960H)T5R<F]R.B`G("X@<W1R7W)E<&QA
M8V4H)T-O;G-O;&5?1V5T;W!T.B<L("<G+"`D8VUD7V]P=&EO;G,M/F=E=$UE
M<W-A9V4H*2DI*3L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('5S
M86=E*"D["B`@("`@("`@9F]O=&5R*"D["B`@("!]"GT*"B\J(%-E87)C:&EN
M9R!A<'!L:6-A=&EO;G,@*B\*8VAE8VM?8FEN87)I97,H*3L*"B1C+3YW<FET
M96QN*'-P<FEN=&8H)U-E87)C:&EN9R!(;W)D92!A<'!L:6-A=&EO;G,@:6X@
M)7,G+"!"05-%*2D["B1D:7)S(#T@<V5A<F-H7V%P<&QI8V%T:6]N<R@I.PH*
M:68@*"1D96)U9RD@>PH@("`@)&,M/G=R:71E;&XH)T9O=6YD(&1I<F5C=&]R
M:65S.B<I.PH@("`@)&,M/G=R:71E;&XH:6UP;&]D92@B7&XB+"`D9&ER<RDI
M.PI]"@HD87!P<R`]('-T<FEP7VAO<F1E*"1D:7)S*3L*)&%P<'-;,%T@/2`G
M:&]R9&4G.PHD8RT^=W)I=&5L;BAW;W)D=W)A<"AS<')I;G1F*"=&;W5N9"!A
M<'!L:6-A=&EO;G,Z("5S)RP@:6UP;&]D92@G+"`G+"`D87!P<RDI*2D["B1C
M+3YW<FET96QN*"D["@IS=VET8V@@*"1C;60I('L*("`@(&-A<V4@)V-L96%N
M=7`G.@H@("`@8V%S92`G8V]M;6ET)SH*("`@(&-A<V4@)V-O;7!E;F1I=6TG
M.@H@("`@8V%S92`G;65R9V4G.@H@("`@("`@("1C;60H*3L*("`@("`@("!B
M<F5A:SL*("`@(&-A<V4@)V-O;6UI="UH96QP)SH*("`@("`@("!C;VUM:70H
M=')U92D["B`@("`@("`@8G)E86L["B`@("!C87-E("=E>'1R86-T)SH*("`@
M("`@("!X=')A8W0H*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VEN:70G
M.@H@("`@("`@(&EN:70H*3L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@(&UE<F=E*"D["B`@("`@("`@8G)E86L["B`@("!C87-E("=M86ME)SH*
M("`@("`@("!C;&5A;G5P*'1R=64I.PH@("`@("`@("1C+3YW<FET96QN*"D[
M"B`@("`@("`@;6%K92@I.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G;6%K
M92UH96QP)SH*("`@("`@("!M86ME7VAE;'`H*3L*("`@("`@("!B<F5A:SL*
M("`@(&-A<V4@)W5P9&%T92<Z"B`@("`@("`@>'1R86-T*"D["B`@("`@("`@
M)&,M/G=R:71E;&XH*3L*("`@("`@("!M97)G92@I.PH@("`@("`@(&)R96%K
M.PH@("`@8V%S92`G=7!D871E+6AE;'`G.@H@("`@("`@('5P9&%T95]H96QP
M*"D["B`@("`@("`@8G)E86L["B`@("!C87-E("=S=&%T=7,G.@HO+R`@("`@
M("`@>'1R86-T*"D["B`@("`@("`@;65R9V4H*3L*+R\@("`@("`@('-T871U
M<R@I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D8RT^
M=W)I=&5L;B@D8RT^<F5D*"=%<G)O<CH@)RD@+B!S<')I;G1F*"=5;FMN;W=N
M(&-O;6UA;F0Z("5S)RP@)&-M9"DI.PH@("`@("`@("1C+3YW<FET96QN*"D[
M"B`@("`@("`@=7-A9V4H*3L*("`@("`@("!F;V]T97(H*3L*?0H*9F]O=&5R
M*"D["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O=6M?54$N<&\`````````````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8P-34V,P`Q
M,#0Q-S,V,S`P,P`P,38T,#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!(;W)D92!5:W)A:6YI86X@2T])."U5('1R86YS
M;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R($%N9')I>2!+;W!Y<W1Y86YS
M:WDN"B,@06YD<FEY($MO<'ES='EA;G-K>2`\86YR:4!P;VQY;F5T+FQV:78N
M=6$^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U6
M97)S:6]N.B!(;W)D92!V,BXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,BTP,2TP-2`Q-CHQ-2LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($%N9')I
M>2!+;W!Y<W1Y86YS:WD@/&%N<FE`<&]L>6YE="YL=FEV+G5A/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@56MR86EN:6%N(#QW96)M87-T97)`<&]L>6YE="YL=FEV
M+G5A/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U+3TDX+55<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E
M92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("+U
MT]"FV\[/(,3/Q,'.SR`G)7,G(,3/(-/)T]3%S<DN(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O
M9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S
M=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F
M;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("+OT,72
MP<.FT2#0TL_&ILS!R]3)WL[/Q\\@S\+3S-7'S]?5U\'.SM$@)7,@+2#PIL34
MU\72Q-;%SL[1(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T
M87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*
M(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B]Z;$S:;4V-3%(,_0Q=+#IL`HIRDL
M(-'+IB#3S*;$(-K$ILK3SLG4R2#7(,/%RB#>P=,N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I
M<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("+AQ-+%
MT\[!(,O.R<?!(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R
M;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@
M(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R
M('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y
M-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R
M($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@Q\_$R<[)(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED
M(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L
M;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U
M="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED
M(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G
M<W1R("+PIL34U\72Q-;%SL[1(-#!TL_,P"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!9&0B"FUS9W-T<B`BX<32Q=/!
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR
M,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"B,L(&9U
M>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`BY,_$P=3)(,O/TLG3U-77
MP=[!(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H
M<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T
M;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("+DS\3!
MU,D@SL_7S\?/(,O/TLG3U-77P=[!.B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS
M-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(N3/
MQ,'4R2#.S]?/Q\\@R\_2R=/4U=?!WL$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BY,_$P=3)
M(-#!TM4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S
M(&)O;VLZ(@IM<V=S='(@(N'$TL73SL$@R\[)Q\$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`BX<32Q=/.P2#+SLG'
MP2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G
M<W1R("+DS\3!U,D@R\_2R=/4U=?!WL$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(N3/Q,'7P<[.T2#+S]+)T]35
MU\'>IM<@VL'"S]+/SL7.Q2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("+AQ-+%T\$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")!9&1R97-S
M($)O;VLB"FUS9W-T<B`BX<32Q=/.P2#+SLG'P2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`BX<3-
MILZFT]32U=?!SL[1(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(N'$TL73P2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B\-/%U\3/SJ;-
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R
M("+PT\77Q,_.ILTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+PT\77Q,_.ILTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R("+PT\77Q,_.
MILTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O
M=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@
M9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(O?!V\$@P<32Q=/!(,4MT,_;U,DZ(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU
M92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38W"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA
M<R!O8V-U<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O
M<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!
M;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@
M(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS
M9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O
M=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS
M:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!2
M96=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T
M=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@
M(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU
M,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED
M(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT
M-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I
M9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP
M.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(N3/
MT]35T,ZF(-#/S-$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@
M(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I
M9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R
M;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A
M:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B
M0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED
M(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@
M(N3%SM@@SL'2S\36Q<[.T2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@
M7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I
M9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M;VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U
M>GIY"FUS9VED(")";W)D97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D
M97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED
M(")";W)D97)S(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED
M(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED
M(")"<F%Z:6PB"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I
M9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A
M;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT
M97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(O>FQ,VFSLG4R2#0S]>FQ,_-S,7.SM$@T-+/PLS%S<DB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H
M<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T
M87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT
M<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB
M97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+ZPL72Q<?4R2#/
MT,.FIR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("+SU*;,
MV,[)R\_7R<H@U,7,Q<;/SB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@
M4')O<&5R=&EE<R(*;7-G<W1R("+SU*;,V,[)R\_7R<H@U,7,Q<;/SB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS
M9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E
M;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T
M"B,L(&9U>GIY"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B\]2FS-C.R<O/
MU\G*(-3%S,7&S\XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I
M9"`B0V5N=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R
M86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*
M;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I
M8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@
M(D-H860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ
M>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(O/+P=/5U\'4R2#:S:;.R2(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I
M9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.
MT2#0P=+/S,`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U
M<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM
M<V=I9"`B0VAA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@
M(D-H:6QE(@IM<V=S='(@(O3)U-7,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G
M:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D
M:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@
M<&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.T2#0P=+/S,`B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O
M<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED
M(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(OK!R]+)U,D@UZ;+SL\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L
M;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B
M0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I
M9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM86YD
M(@IM<V=S='(@(NO/S=#!SJ;1(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P
M"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R("+KS\W0P<ZFT2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM
M<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO
M;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*
M;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S
M<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.T2#0P=+/S,`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED
M(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G
M:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N
M=',@;V8@7"(E<UPB(@IM<V=S='(@(O?-IM/4("<E<R<B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`BZ\_-T,'.IM$B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(K;-
MT,_2U,_7P<[%(-#/S,4Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD
M87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB
M)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY
M"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@
M(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(
M;W)D92#.Q2#3R\_.QJ;'U=+/U\'.P2#0TL'7R<S8SL\B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G
M:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*
M;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM
M<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@
M(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R
M96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P
M"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E
M;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U
M="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP
M<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS
M9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G
M:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R("+DY"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B
M1&%I;'DB"FUS9W-T<B`B_<_$Q<[.SR(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H
M<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,
M;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY
M"B,L(&9U>GIY"FUS9VED(")$871E(@IM<V=S='(@(O?)U,72U,DB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G
M<W1R("+]S\3%SL[/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L971E
M($-O;'5M;B(*;7-G<W1R("+WR=3%TM3)(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ
M,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B]\G4Q=+4R2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W
M"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(O?)R\_2
MR=/4S]?5U\'4R2#:SL'>Q<[.T2#:P2#:P<W/U][5U\'.SM'-(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L
M="!)9&5N=&ET>2(*;7-G<W1R("+OT\[/U\[!(*;0S]/4P=/8(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT
M(%-H96QL(@IM<V=S='(@(N_3SL_7SL$@IM#/T]3!T]@B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*
M;7-G:60@(D1E;&5T92(*;7-G<W1R("+WR=3%TM3)(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("+WR=3%TM3)(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("+WR=3%TM3)(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@3&]G(@IM<V=S='(@(O?)U,72U,DB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("+W
MR=3%TM3)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*
M;7-G<W1R("+WR=3%TM3)(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*
M;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T
M<B`B]\G4Q=+4R2(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET
M>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>2(*;7-G<W1R("+OT\[/U\[!(*;0S]/4P=/8(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E
M<GD@=&EM92(*;7-G<W1R("+WR=3%TM3)(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T
M<B`B[]#)VZ;4V"#0TL_"S,7-U2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R
M("+PS]?.R<H@S]#)TSHB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T
M;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*
M;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"B,L(&9U>GIY"FUS9VED(")$:7-P
M;&%Y($]P=&EO;G,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*;7-G:60@(D1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*
M(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B]\G4Q=+4
MR2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$
M<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R("))35`M
MT,_2U,',(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@
M9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI
M;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D
M:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM
M<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED
M(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A
M<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED
M(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM
M<V=S='(@(N4MT,_;U,$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z
M>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B]\';P2#!Q-+%T\$@
MQ2W0S]O4R3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L
M(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS
M9W-T<B`B\,'2S\S8(,W5T\G4V"#3T*;7T,'3U,DN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*
M(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(O#/TL_6
MSJ;*(-+%VM7,V-3!U"XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S
M='(@(O#/TL_6SJ;*(-+%VM7,V-3!U"XB"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I
M9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@
M;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@
M>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B\,_-R<S+P2(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N
M=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI
M8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("+KS];.S\?/(-?(S\35(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM
M<V=S='(@(NO/UL[/Q\\@U\C/Q-4B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G
M<W1R("+KS];.S\?/(-?(S\35(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X.`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(NO/
MUL[/Q\\@U\C/Q-4B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR
M-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(N3!SJ8@Q,S1(-#2
MR<O,P<35.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S
M:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE
M8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED
M96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O
M9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I
M9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A
M:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(O#/S<G,R\$@MLW0S]+4U3H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(N;!
MR],B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY
M"FUS9VED(")&87AE<R(*;7-G<W1R("+FP<O3(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&
M965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT
M-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G
M:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@
M(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(O3)U-7,(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*
M;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("*VS6#1(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I
M9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED
M(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@
M(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@
M(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E
M<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y
M"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*
M(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED
M(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B[L_4P=3+R2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(K;-8-$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ
M>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("+PS]?.R<H@S]#)
MTSHB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B
M]\';Q2"FS2?1.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'
M96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'
M96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")'
M:79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B
M1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED
M(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R
M965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM
M<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3<Y"B,L(&9U>GIY"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC
M+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(N'$TL73SL$@R\[)
MQ\$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)
M4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N
M:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BY,_0S\W/Q\$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(
M96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T
M<B`BY,_0S\W/Q\$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@
M(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G
M:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(N3/S<';SM$@P<32Q=/!(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(N3/S<';
MSJ;*(-3%S,7&S\XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`B]=/0IMO.SR#7R<3!S,7.SR`G)7,G(-H@T\G3U,7-R2XB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,C0W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM
M<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B
M2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("+AQ-+%
MT\$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS
M9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@
M3VYL>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I
M=&@@=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D
M;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y
M;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@
M4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM
M<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(K;-T,_2U,_7P<[%
M(-#/S,4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S
M='(@(K;-T,_2U,_7P<[%(-#/S,4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R
M("*VS=#/TM3/U\'.IB#0S\S1.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O
M<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("+BU<38
M+<S!T\O!+"#7R\'6IM38(,[!VM?5(,O/TLG3U-77P=[!(*8@T,'2S\S8(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@
M26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV
M:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))
M;F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F
M=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS
M9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED
M("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@
M8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*
M;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS
M9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E
M<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B
M26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E
M<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN
M<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B
M26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM
M<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I
M9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@
M(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E;G-E
M(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PIM<V=I
M9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U
M8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O
M8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N
M=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G
M:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I
M9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS
M9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I
M9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B
M_<_$Q<[.SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*
M879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A
M;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G
M:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED
M(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L
M/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G
M:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED
M(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*
M;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(NS)T]0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W
M;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@
M(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U
M>GIY"FUS9VED("),87EO=70B"FUS9W-T<B`B]\G*U,DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU97,B
M"FUS9W-T<B`BY,'.IB#$S-$@T-+)R\S!Q-4Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G
M:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI
M9VAT(%)A:6XB"FUS9W-T<B`B]]>FRM3)(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM
M<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*
M(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B]]>FRM3)(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W
M"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@
M861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT
M;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@
M(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O
M:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@
M(O#%TL7,ILL@TL_:Q*;,IM<@Y,_0S\W/Q\DB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES
M="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS
M9W-T<B`B\,72Q<RFRR#2S]K$ILRFUR#DS]#/S<_'R2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T
M+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S(@IM<V=S='(@(O#%TL7'S-'$(-/0R=/+U2#+S]+)
MT]35U\'>IM<@VL'"S]+/SL7.R<HN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B\,72Q<?,T<0@T]#)T\O5(,O/TLG3U-77
MP=ZFUR#:P<+/TL_.Q<[)RBXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(O#%TL7'S-'$(-/0R=/+U2#+S]+)T]35U\'>IM<@VL'"S]+/
MSL7.R<HN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),
M:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET
M:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B
M3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(O?7ILK4
MR2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T
M(@IM<V=S='(@(O?)RM3)(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("+WUZ;*U,DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G
M:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I
M;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B]\G*U,DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),
M;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("+M[2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G
M:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L
M878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B24U0+=#/
MTM3!S"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B
M36%I;"(*;7-G<W1R("))35`MT,_2U,',(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`B24U0+=#/
MTM3!S"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B24U0
M+=#/TM3!S"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B
M"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*
M;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@
M;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B
M36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(O77P<?!(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE
M;&1S(@IM<V=S='(@(O>FQ-#/UZ;$SJ8@T,_,T2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO
M=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B
M36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-
M96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(NS)
MT]0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R("+LR=/4(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ
M>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(NS)T]0B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T
M"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@
M9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN
M960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U
M"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L
M(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED
M(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E
M;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM
M<V=I9"`B36ER<F]R(@IM<V=S='(@(O#/S<G,R\$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*
M;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@
M9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P
M<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S
M<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I
M9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G
M:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B
M36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF
M>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B_<_-IM/1P]$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD
M(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B
M36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-
M;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS
M9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@
M(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I
M9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B
M37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED
M(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BMLU@T2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A
M<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM
M<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C
M87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@
M<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B
M3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+PP=+/S-@B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R
M"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*
M;7-G<W1R("+PP=+/S-@@S=73R=38(-/0IM?0P=/4R2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@
M=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS9VED(").97=S(@IM
M<V=S='(@(N[/U,'4R\DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H
M87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F
M=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(O#/U\72SM74R=/1
M(,3/(._0PZ;*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*
M;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B
M3FEC87)A9W5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*
M;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL
M86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F
M;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@
M(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8VAA;F=E+B(*;7-G<W1R("+SR\'3U=?!U,D@VLVFSLDB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z
M-S<S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS
M9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F
M:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED
M(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P
M;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED
M(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW
M,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP
M.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP
M:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC
M+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM
M<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(N+5Q-@MS,'3R\$L(-?+
MP=:FU-@@SL':U]4@R\_2R=/4U=?!WL$@IB#0P=+/S-@B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I
M;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R("+TQ<S%QL_.
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U
M.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@
M(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV
M,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE
M;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G
M<W1R("+NS]3!U,O)(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z('-E
M<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L
M(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`BMLU@T2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R
M86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS
M9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@
M9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@
M<&%S<W=O<F0B"FUS9W-T<B`B\,'2S\S8(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B3W!T
M:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED
M(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A
M=&EO;B(*;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N
M86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS
M9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0
M($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")0
M2%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H
M="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS
M9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I
M9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R("+PP=+/S-@B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R("+PP=+/S-@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("+PP=+/S-@B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+PP=+/S-@B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S
M=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B\,'2S\S8(,W5T\G4V"#3T*;7
MT,'3U,DN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@
M(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P
M<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L
M(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`B\L_,V"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")0
M97)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,B"FUS9W-T<B`B]\G+S\[!U,D@T-+/QJ;,P<O4R=[.IB#/
MT,72P<.FIR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*(RP@9G5Z
M>GD*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\B"FUS9W-T<B`B]\G+S\[!U,D@T-+/QJ;,P<O4R=[.IB#/T,72P<.F
MIR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED
M(")097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S
M7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I
M;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC+"!F=7IZ
M>0IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MX<3-ILZFT]32U=?!SL[1(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U
M"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B
M4&AO;F4B"FUS9W-T<B`B],7,Q<;/SB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM
M<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q
M"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE
M=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D
M<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("+BU<38+<S!T\O!
M+"#$P<K4Q2#+S]+/U,O)RB#/T,G3(-#2S\+,Q<W)+B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0B"FUS9W-T<B`BXM7$V"W,P=/+P2P@U\O!UJ;4V"#.P=K7U2#+
MS]+)T]35U\'>P2"F(-#!TL_,V"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T
M97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE
M("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I
M9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S
M<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E
M<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R
M92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY
M"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(O#/U\72SM74R=/1
M(,3/(._0PZ;*(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S
M='(@(EOPS]>FQ,_-S,7.SM$@\-+/PLS%S<E=(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S
M='(@(N_0R=,@T-+/PLS%S<DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B
M4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF
M;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM
M<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I
M;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD
M;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(NS)T]0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G
M:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U
M"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R("+OWLG3U,G4R2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N
M<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*
M;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G
M:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED
M(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!F;W)M871T:6YG(@IM<V=S='(@(O?)U,72U,D@T,'2U2(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I
M<B(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R
M"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(O?)U,72U,D@
MT,'2U2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*
M;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M;6]V92!U<V5R.B`E<R(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM
M<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B[][)T]3)U,DB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM
M<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B\,'2S\S8(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E)E
M<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.T2#0P=+/
MS,`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E
M($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C8*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B[][)T]3)U,DB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM
M<V=S='(@(O#/U\72SM74R=/1(,3/(._0PZ;*(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L
M(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T
M<B`B\,_7Q=+.U=3)T]$@Q,\@[]##ILHB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED
M(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L=65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B\L_,V"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T
M871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I
M9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W
M('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(O+/S-@B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R
M;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G
M:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP
M.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B[,G3
MU"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*
M;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B
M4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%
M4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,
M(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B
M4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V
M:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!
M<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M)7,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B^L+%
MTL7'U,D@S]##IJ<B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS
M9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS
M9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B
M4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A(&1A=&4B"FUS9W-T<B`B]\G"Q=*FU-@@QL_2S<'4(,3!U,DZ(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A
M(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED
M(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(O?)PL72IM38
M(,;/TLW!U"#$P=3).B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82XB"FUS9W-T<B`B(@HB]\G"Q=*FU-@@SL7/PLBFQ,ZF(/?!
MS2#3R<W7S\S)(-H@T,_,IM<@SLG6WL4N(/?)(-K-S];%U,4@T\O/T*;`U\'4
MR2"GR""F("(*(M?3U,'7R=3)(-H@T,_,T2#7U\_$U2#4Q<O3U-4N(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(O?)PL72IM38(-+/VL2FS,#7P=X@
MQ,'4R3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B]\G"Q=*FU-@@QL_2
MS<'4(,3!U,DZ(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.B(*;7-G<W1R("+WR<+%TJ;4V"#2S]K$ILS`U\'>(,3!U,DZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!F;W)M870Z(@IM<V=S='(@(O?)PL72IM38(,;/TLW!U"#>P=/5.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+WIL30
MS]>FQ,ZF(-#/S-$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS
M9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!2
M97!O<G0B"FUS9W-T<B`B]Z;$IM/,P=3)(-#/UZ;$S\W,Q<[.T2#0TL\@T-+/
MPLS%S=4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@
M(E-E<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S
M:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O
M(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R
M(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G
M:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O
M<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P
M;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S
M"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(NO/TL_4
MR\G*(-K-IM/4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G
M:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H
M;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS
M9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("+P
MTL_0U=/4R=3)(-#2S\:FS,'+U,G+U2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3
M;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@
M(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R
M9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS
M9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+RS\+/WL$@P<32Q=/!(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E
M;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@
M86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C
M:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R("+WUZ;$(//0Q<.FP<S8SLG((-/)S=?/S*;7(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I
M9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(K;-T,_2U"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R
M(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F
M;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(O+/PL_>P2#!Q-+%T\$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G
M:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3
M=6)M:70B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G
M:60@(E-U8G-C<FEP="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T
M<B`B]=/0IMO.SR(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(@IM<V=S='(@(O73T*;;SL\@Q,_$P<[/("<E<R<@Q,\@
MT\G3U,7-R2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B]=/0IMO.
MSR#7R<3!S,7.SR`G)7,G(-H@T\G3U,7-R2XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB
M"FUS9W-T<B`B]=/0IMO.SR#$S\3!SL\@)R5S)R#$SR#3R=/4Q<W)+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B]=/0IMO.SR#7R<3!S,7.SR`G)7,G(-H@T\G3U,7-R2XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(O73T*;;SL\@Q,_$P<[/("<E<R<@Q,\@
MT\G3U,7-R2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(O73T*;;SL\@Q,_$
MP<[/("<E<R<@Q,\@T\G3U,7-R2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(NO/TL_4R\G*(-K-IM/4(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*
M;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*
M;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS
M9W-T<B`BMLW0S]+4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B
M4W5R:6YA;64B"FUS9W-T<B`B[L':U\$@R\_2R=/4U=?!WL$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I
M9"`B4W5R;F%M92(*;7-G<W1R("+NP=K7P2#+S]+)T]35U\'>P2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G
M(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R
M;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*
M;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R("+TR=35S"(*
M"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS
M9VED(")486)L92(*;7-G<W1R("+TR=35S"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE
M(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS
M9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.
M=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*
M;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS
M9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0HC+"!F
M=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MX<3-ILZFT]32U=?!SL[1(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G
M:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L
M:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I
M9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*
M;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H
M<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U
M<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P
M96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U
M;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET
M:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB
M"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0IM<V=I9"`B5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I
M;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@
M(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("+TTL'0R<S!
MT]$@T-+/PLS%S<$@T-+)(,3/Q,'7P<[.IB`G)7,G(,3/(-/)T]3%S<DN(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(O32P=#)S,'3
MT2#0TL_"S,7-P2#0TLD@U\G$P<S%SLZF("<E<R<@VB#3R=/4Q<W)+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B]-+!T,G,P=/1(-#2S\+,Q<W!(-#2R2#7
MR<3!S,7.SJ8@)R5S)R#:(-/)T]3%S<DN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B]-+!T,G,P=/1
M(-#2S\+,Q<W!(-#2R2#$S\3!U\'.SJ8@)R5S)R#$SR#3R=/4Q<W)+B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@
M=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F
M:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T
M97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A
M;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O
M86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@
M(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*
M;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED
M(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`B],G4U<PB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE
M(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B
M"FUS9W-T<B`B],G4U<PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G
M:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N
M9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G
M:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM
M96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED
M(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")54DPB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(U-@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-C4*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM<V=I9"`B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I
M(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE
M4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B
M56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@
M=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL
M;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@
M(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+SR\'3U=?!U,D@VLVFSLDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED
M(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&
M+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A
M8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N
M:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I
M9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G
M:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G
M:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(N[!VM?!(,O/TLG3U-77P=[!(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM
M<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5
M<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`BY,_$P=3)
M(,O/TLG3U-77P=[!(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5
M<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE
M+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B[L':U\$@R\_2R=/4U=?!
MWL$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"B,L(&9U>GIY"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(N'$S:;.IM/4TM77P<[.T2#+S]+)T]35U\'>IM<@2&]R9&4B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0HC+"!F=7IZ>0IM<V=I9"`B
M57-E<B!/<'1I;VYS(@IM<V=S='(@(OK"Q=+%Q]3)(,_0PZ:G(@H*(SH@<VEG
M;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VXB
M"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1(,O/TLG3U-77P=ZFUR!(;W)D92(*
M"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N
M="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B[L':U\$@R\_2R=/4U=?!WL$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W
M"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B[L':U\$@R\_2
MR=/4U=?!WL$B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L
M(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(N[!VM?!(,O/TLG3
MU-77P=[!(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM
M<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`BZ\_2R=/4U=?!
MWJ8@UR#3R=/4Q<VF.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED
M(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@
M(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E
M;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P
M"FUS9VED(")697)S:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS
M9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I
M8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@
M86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R("+UU\''P2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A
M=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@
M8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR
M"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("+]S]3)UL[1(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E
M;&-O;64B"FUS9W-T<B`B]Z;4P<`@]\'3+"`E<R(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R("+WIM3!P"#WP=,L("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(O>FU,'`(/?!
MTRP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H
M:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I
M9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@
M;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@
M(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G
M:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T
M<B`B\L_"S][!(,'$TL73P2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B
M\L_"S][)RB#4Q<S%QL_.(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W
M:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS
M9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT
M96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B65DB"FUS9W-T<B`B\O(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS
M9W-T<B`B\O(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`B_<_2IM[.SR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS
M9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B
M66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F
M<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I
M96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*
M;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE
M(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB
M9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M("+WR2#0S]?)SLZF(,_0R=/!U,D@T-+/PLS%S=4L(-#%TML@SJ;6(->FQ-/)
MS,'4R2#0S]>FQ,_-S,7.SM$@T-+/(,[%IRXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z
M>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35
MU\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+
MS]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35
MU\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("+WP<T@
MT\RFQ"#7R\':P=3)(,[!VM?5(,O/TLG3U-77P=[!(,3,T2#$S\3!U\'.SM$N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(O?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(,3/Q,'7
MP<[.T2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.
MP=K7U2#+S]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM
M<V=S='(@(O?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1
M(-?)Q,',Q<[.T2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS
M9W-T<B`B]\';P2#!Q-+%T\$@Q2W0S]O4R3HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E
M<W,Z(@IM<V=S='(@(O?!V\$@P<32Q=/!(,4MT,_;U,DZ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S
M"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B]\';Q2"FS2?1
M.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*
M;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I
M;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@
M*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS
M9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(N_3SL_7SL$@
MIM#/T]3!T]@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B]\';Q2"FS2?1
M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*;7-G:60@(EEO
M=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I
M9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@
M(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6_#/UZ;$S\W,Q<[.T2#PTL_"
MS,7-R5TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E
M<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S
M(&]F("5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77
MP<[.T2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W(@IM
M<V=S='(@(O?)U,72U,DB"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BY,_0
MS\W/Q\$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B]]>FRM3)(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ
M>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B]\G*U,DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G
M:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T
M:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z(&QI8B]A<&DN<&AP
M.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC
M+"!F=7IZ>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(O?)U,72
MU,D@T,'2U2(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*
M(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+AQ-+%T\[!
M(,O.R<?!(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS
M9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I
M=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F
M;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B
M"FUS9W-T<B`B],G4U<PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T
M+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D
M('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G
M<W1R("*VS6#1(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I
M9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L
M96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED
M(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T
M92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B
M<FES:6YG(@IM<V=S='(@(O77P<?!(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I
M9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS
M,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R
M"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T
M<GD@86=A:6XB"FUS9W-T<B`BZ\_6SL_'SR#7R,_$U2(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*
M;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@
M(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P;R]Z:%]#3BYP;P``````````````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C4Q-C<Q`#$P-#$W,S8S,#`S`#`Q
M-C0P-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C($AO<F1E(%-I;7!L:69I960@0VAI;F5S92!4<F%N<VQA=&EO;@HC($-O
M<'ER:6=H="`H0RD@,C`P,2!786YG2&5N9U=E;BX*(R!786YG2&5N9U=E;B`\
M=VAW0&UY,38Y+F-O;3XL(#(P,#$N"B,@1&%V:60@0VAA;F<@/&1A=FED0'1M
M=BYG;W8N='<^+"`R,#`Q+@HC(&QI86]B:6X@/&QI86]B:6Y`:FET92YN970^
M+#(P,#0N"B,@"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`R+C!<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`Q+3`V
M+3$X(#(R.C`U*S`X,#!<;B(*(DQA<W0M5')A;G-L871O<CH@;&EA;V)I;B`\
M;&EA;V)I;D!J:71E+FYE=#Y<;B(*(DQA;F=U86=E+51E86TZ($-H:6YE<V4@
M/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U'0C(S,3)<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@S.S'L"DB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`HO^R]W;S\("5S*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("@E<R#,
M[,>P*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@
M(B`H=&]D87DI(@IM<V=S='(@(B`HO?',["DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<U"B,L(&9U>GIY"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R("+#]\SL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`HU_+,["DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("+3VB(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("*RN\K'
MTKNX]L2_PKPB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+B(*;7-G<W1R("(G)7,G(+*[RL?2N[CVT]#0I[7$T:'4\2XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E
M9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@R=#.M-3:
M($A/4D1%(+7$UZ*RX<[$O/XH4F5G:7-T<GDIUM#%Y-;#+B(*"B,Z(&9R86UE
M=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R
M("+5TK*[M;T@)7,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#2T;/)N::\T\CKM;W3P[NG
MU^G/M<VSUM`N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@TM&\T\CK
MR*C/WL^US;,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(G)7,G(+*B
MSK2]J,&B.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W
M960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@
M)7,@86YD("5S(@IM<V=S='(@(B5S(-+1R*'/^R`E<RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M+61A>2!F;W)E8V%S="(*;7-G<W1R("+7[KW\("5D(,SLQOC/\]2DL:@B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2"QN,W\PKPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R#6N,[&(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S
M(,ZLNZ2RV=?W("T@R+?(SR(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I
M9VX@57`B"FUS9W-T<B`B)7,@UZ*RX2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!
M9W)E96UE;G0B"FUS9W-T<B`B)7,@S:S2XL_NQ+\B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@TM&TYM3:(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@U-H@)7,@)7,B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*
M(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BT:'4\<3ZS^O2JK+9U_>UQ,SUQ+\N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("*QV-#HTJH@)7,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(+?6(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2`E<RXB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B`E<R"UO2`E<R"Y
MLB`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G
M<W1R("+-J-&VLKXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*
M;7-G<W1R("+(U<#Z(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*
M;7-G<W1R("(E<R`M(+&XS?S"O"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@
M:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L
M:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N
M>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#$P"B,L(&9U>GIY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S
M='(@(BP@U?.WYR`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(-7SM^<@)7,@)7,B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B++'DNZ_!O[33("5S
M(+6]("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW
M-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2#1H=3Q("TM(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(
M;W5R($9O<FUA="(*;7-G<W1R("+$^K7$T,7/HB(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS
M9W-T<B`BQ/JUQ-#%SZ(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@T*'*L=;&(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R
M979I;W5S(@IM<V=S='(@(LG/TKO2LR(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@
M9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(K3+Q_B_Z;'8T.O2JM:XMJC*_;[=
MO^*W_L[QMLLN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*
M;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(K>B
MR?K!R]*[N/;1S];8M<2T[<[S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+3^[S3P]S3RKS^
M++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<U+\N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`BT_O1Z=:DTM''J</[M<33RKS^++NYT.C2JM/0TKNX]B!01U`@N:N_
MJL/<U+\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y
M-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(M/[O>+#W-/*O/XLN[G0Z-*JT]#2N[CVN:N_
MJB!01U`@P]S4ORS+O</<(%!'4"##W-2_+-+4O+"_VL'N+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("+3
M^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J(%!'4"##W-2_+,N]P]P@
M4$=0(,/<U+\LTM2\L+_:P>XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+3^[WBP]S3
MRKS^++NYT.C2JM/0TKNX]KFKOZH@4TU)344@P]S4ORS+O</<(%--24U%(,/<
MU+\LTM2\L+_:P>XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("+3^]:TT-#3RKS^QZG#^RR[
MN=#HTJK3T-*[N/:YJ[^J(%,O34E-12##W-2_+,N]P]P@4R]-24U%(,/<U+\L
MTM2\L+_:P>XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BT_N\T\/<T\J\_BR[N=#H
MTJK3T-*[N/8@4TU)344@N:N_JL/<U+\N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B04T@0VQO
M=61S(@IM<V=S='(@(M3&P;\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G
M<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022"Q
MX+K%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`BN=C3VM7B
MN/:QX+RMQO<B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I
M9"`B06)O=70N+BXB"FUS9W-T<B`BN=C3VBXN+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O
M;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+(J,_>
MLKO7XRS.WK>HO:C!HB!61E,@Q+_"O"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+B(*;7-G<W1R("+(J,_>LKO7XRS.WK>HO:C!HB!61E,@SL2\
M_BXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("+$^K7$T,7/HB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R("+(M\C/P]S"ZR(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B
M06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(M7+NL72T;:SO>$N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*
M;7-G<W1R("*]X=7*(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS
M9W-T<B`BT,+4]B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B
MT,+4]L_"O+;7Z2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D
M($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`BT,+4]L_"O+;(J,_>(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*
M;7-G<W1R("+4VK3+T,+4]J.Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@
M861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS
M9W-T<B`BT,+4]M/#NZ?7Z2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I
M9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(M#"U/;(J,_>(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E
M<UPB(@IM<V=S='(@(M#"U/;/PKRVT\.[I]?I("<E<R<B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS
M9W-T<B`BT,+4]L_"O+;(J,_>UL$@)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`BT,+4]M*[N/;3
MP[NG.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(M#"U/;2N[CVL\G4L3HB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("+0
MPM3VMM0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<B(*;7-G<W1R("+0PM3V("5S(,ZJ($UO>FEL;&$@4VED96)A<B"RR[6E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q
M"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R
M("+0PM3VM;W.TK7$S:C1MK*^(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@
M861D<F5S<R!B;V]K(@IM<V=S='(@(M#"U/:UO<[2M<3-J-&VLKXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BT,+4
M]M/#NZ<B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U
M="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N
M.B`B"B(E<RXB"FUS9W-T<B`BTM'0PM3V("<E<R<@M;W/M<VSUM`N(+6KSMZW
MJ-#"U/:V[LWBM<37HK+AT,7/HCH@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`BTM'0PM3V
M("<E<R<@M;W/M<VSUM`N(,3ZS];4VK_)TM2]^-#0M<?"O,'++B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(M#"U/;3P[NGM<2YIL3<M;''
ML+&[N=BQU2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B
M061D<F5S<R(*;7-G<W1R("*UV-:W(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(LVHT;:R
MOB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT
M"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<R(*;7-G<W1R("*SR<ZJN=S`[=2Q("T@SJK&Y,O\T\.[I\7DUL/(
MJ,_>(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(KG<P.TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED
M(")!9',B"FUS9W-T<B`BN>.XYKG<P.TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M9F=H86YI<W1A;B(*;7-G<W1R("*PHKB[NKDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;&)A;FEA(@IM<V=S='(@(K"BMONPS<3AT<<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")!;&=E<FEA(@IM<V=S='(@(K"BMON\L,#[T<<B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA
M<R(*;7-G<W1R("*Q\,/[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`BL?##^R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D%L:6=N;65N=#HB"FUS
M9W-T<B`BO\V[I[;+(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS
M9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I
M9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`BR_G3T-+1T>G6
MI+7$T\.[IR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S
M+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`BR_G3T-/#NZ?7
MZ2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(LOYT]#(J,_>(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL
M(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM
M<V=S='(@(M3*T.VVX+CVM>?7T]/*O/ZUV-:W(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*
M;7-G<W1R("+2T;3FU-HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S
M"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("*QY+C\($E-
M4U`@M<?"O"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(K'DN/P@24U34"##
MW,+K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT
M97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`BL>2X_"!)35-0(-/#NZ<B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM
M<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BL>2X_,2C
ML.8B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N
M871E('1E;7!L871E<R(*;7-G<W1R("*QY+C\Q*.PYB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0HC
M+"!F=7IZ>0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(K'DN/S$
MH[#F(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T
M<B`BP\#*],CXQ*;1QR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@
M(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`BTKNX
M]K*[NL^WJ+7$UK6QN\JYT\,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H
M87,@;V-C=7)E9"XB"FUS9W-T<B`BMZ+)^L'+TKNX]K3MSO,Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("*PLK7`MOLB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`BL+*XY\"M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`BL+*YY\"M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R
M;WAY(@IM<V=S='(@(L3DP_NT^L#M(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(L3/O*O6WB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`BL++,
MX;G/O+"PS;;[LKRT[R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M
M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]5
M22YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM
M<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`BTZ;3P[/,T/(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T
M:6]N($QI<W0B"FUS9W-T<B`BTZ;3P[/,T/(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`BTZ;3P[/,T/+2T;[-T/<B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S
M='(@(M.FT\.UO<OYT]#/PKRVN;+/[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(L7Z
MU[PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*
M;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL
M(@IM<V=S='(@(LO$U,(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM
M<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(K"BP*VRKL[$
M("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(M&YR_7.Q+S^
MM//0H2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`BT;G+]<[$O/[#^[/&(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("+$^LBWMJC2JLF^
ML_T@)7,@M<37HK+APO`@/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U
M8BUG<F]U<',_(@IM<V=S='(@(L3ZR+>VJ-*JR;ZS_2`G)7,G(-+4O+#(SKK.
MU]/3P[NGU^D@/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G
M<W1R("*PHKCYS:(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S
M='(@(M''P\#$X=''(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G
M:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(M''P\#$X=''SL0@
M*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G
M:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*
M;7-G<W1R("*PHL*SL,TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(K"BR:W+R<BZ
MM;HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI
M($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`BT<?6
MWB_,J\:]T?.UV,?X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM
M<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(M:TT-#.K+NDLMG7]\>PS]3*
MOLBWR,^VU+NPO_(_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("+*U,V\R;ZS_=*[N/:RN[3F
MU-JUQ-/#NZ?7Z2XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("+*U,V\R;ZS_=*[N/:RN[3FU-JUQ,BHS]XN(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+*U,V\L>"\
MK=*[N/:RN[3FU-JUQ-/#NZ?7Z2XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92XB"FUS9W-T<B`BRM3-O+'@O*W2N[CVLKNTYM3:M<2YLL_M+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U
M=&5S(@IM<V=S='(@(LKTT-0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(K#+U,(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`BL,2T\\#[
MT<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(K#"M=C`
M^R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G
M:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?8W)Y<W%L.B#5TK*[M;W+^=#HTJJUQ"!I
M;6%P(,"IU;G7Z;S^+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S
M.B"W_L[QMLNRHLZTS.&YJ;C#S^[6I[/6+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-R
M>75S.B#5TK*[M;W+^=#HTJJUQ"!I;6%P(,"IU;G7Z;S^+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B
M"B)!=71H7V9T<#H@U=*RN[6]R_G0Z-*JM<0@1E10(,"IU;G7Z;S^+L?KUMC0
MPK'@TNL@4$A0(+*BQ]*\T\CK("TM96YA8FQE+69T<"#1H2(*(L_N+,#]R.<@
M8V]N9FEG=7)E("TM96YA8FQE+69T<"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z(-72
MLKNUO<OYT.C2JK7$($E-05`@P*G5N=?IO/XN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B
M-3H@U=*RN[6]R_G0Z-*JM<0@:W)B-2#`J=6YU^F\_BXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!
M9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U
M=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VQD87`Z(-72LKNUO<OYT.C2JK7$($Q$05`@P*G5N=?I
MO/XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M(")!=71H7VQD87`Z(,[>MZC0PM3VT\.[IR`E<RX@M_[.\<;WN]C3ICHB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<R(*;7-G<W1R(")!=71H7VQD87`Z(,[>MZC)OK/]T\.[IR`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM
M<V=S='(@(D%U=&A?;&1A<#H@SMZWJ+C\T,+3P[NG("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@
M57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@U=*RN[6]
MR_G0Z-*JM<0@34-!3"#`J=6YU^F\_BXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M
M8F%U=&@Z(-72LKNUO<OYT.C2JK7$('-M8F%U=&@@P*G5N=?IO/XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP
M"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BT>G6I,JG
ML-PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+1Z=:DRJ>PW"X@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")2
M041)55,@T>G6I+3MSO,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R(")&5%`@T>G6I+3MSO,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@T>G6
MI+3MSO,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I
M9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BO\G3P[7$U]:VSCHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(K"BR/NPW;VN
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X
M8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`HC+"!F=7IZ>0IM<V=I9"`B0F%C:V=R
M;W5N9"(*;7-G<W1R("*QL[ZPT=7)JR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L
M;W(B"FUS9W-T<B`BL;.^L-'5R:LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM
M<V=S='(@(FME<F)E<F]S(,/<PNNT[<[S+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B:V5R8F5R;W,@T\.[I\/[M.W.\RXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"86AA;6%S(@IM<V=S='(@(K#-N?["[<BZM;HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(K#-P=8B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB
M"FUS9W-T<B`BLJC"WK7$NJ/.Q"`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("+#S[S3P*VY^B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(K#-L,VVX,NY(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,@M<3`X+'PMJC2Y2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(RP@
M9G5Z>GD*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(K*NP/O7R"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`BL->V[<+>R[DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(K'(P/O*L2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("*RKL#[U\@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("*QM,3^(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F5R;75D82(*;7-G<W1R("*PV<2]M//(NK6Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(K*[M:0B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A
M>2(*;7-G<W1R("+)^LC5(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(M72LKNUO2`E<R"UQ,#@L?"VJ-+E+B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B
M"FUS9W-T<B`BQ_B_Z<7DUL,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`BQ_B_Z<#@T,TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*
M;7-G:60@(D)O;&0B"FUS9W-T<B`BM-;,Y2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)O;&EV:6$B"FUS9W-T<B`BLJ/`^\ZLT<<B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`BRNG'
MJ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@
M(K*HR[G$X=''NLVZVLC[N.?.K,3'(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDV"B,L(&9U>GIY"FUS9VED(")";W1H(@IM<V=S='(@(M3"(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`BLJFTQ,W?Q,DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(K*HSJS,V+6Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(K#-SO<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@
M(M.BRO33H;;(T?/![+78(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`BSL3`LR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M;&=A<FEA(@IM<V=S='(@(K&CO-/`^]''(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES
M="(*;7-G<W1R("+/[L2_M_NZQ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI
M;F$@1F%S;R(*;7-G<W1R("*RO+RJQ,FWJ,OW(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R=6YD:2(*;7-G<W1R("*RO,*AM<\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`BQ-K(W;G<P.W/
MM<VS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<R(*;7-G<W1R(")#4DP@M]:RO+7C(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#
M7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#
M86QE;F1A<B(*;7-G<W1R("+(U<#Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R("+!X[RVM^<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`BO.W&TM6O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`BOZ;"\\*A(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N
M;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("+.WK>HR;ZS
M_<[$O/X@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I
M9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<R(*;7-G<W1R("+.WK>HP:J[^M;!($E-05`@M_[.\<;W.B`E<R(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`BSMZWJ,F^L_W.Q+S^(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#
M86YA9&$B"FUS9W-T<B`BO-/$P[3S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q
M(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ
M,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED
M(")#86YC96PB"FUS9W-T<B`BR*'/^R(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`BR*'/^\[*S.*QJ+CF(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T
M92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^L_W.Q+S^(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU
M,@HC+"!F=7IZ>0IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+B(*;7-G<W1R("+.WK>HR;ZS_<2_PKP@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@
M(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R("+.WK>HR;ZS_<2_PKP@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N(@IM<V=S='(@(L[>MZC)OK/].]/0S\*\MK3FU-H@*"5S*2(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B
M(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N
M(@IM<V=S='(@(L[>MZC6V-?IH:/+^<SAN:FUQ+S'PKS*_<2_T^O/R,>PR_FQ
MH[3FM<3*_;[=LKNW^RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(L[>MZBTJ\O-T,7/
MHK6]UKBVJ+7$NL7"ZRXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E
M(@IM<V=S='(@(K?PM<.]QR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-A<'1I
M;VXB"FUS9W-T<B`BT:'/[B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B0V%R<FEE<B(*
M;7-G<W1R("*WV[KLR:LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*
M;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`BOZK"_,BZ
MM;HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(M+&MJ^UY[NP(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(M+&
MMJ^UY[NP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#
M96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R
M("+2QK:OM>>[L"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED
M(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("+(^[;[S-C.Q"`H25-/
M+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B0V5N=&5R(@IM<V=S
M='(@(KVHP:(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,B"FUS9W-T<B`BUM"WQ[FRNLVY^B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*2(*;7-G<W1R("+6T,6W("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T
M92!$971A:6QS(@IM<V=S='(@(L:^UJ3/N+W:(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*(RP@9G5Z>GD*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(L:^UJ3/N+W:(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E
M(%!O;&EC:65S(@IM<V=S='(@(L:^UJ2RW\+4(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")#:&%D(@IM<V=S='(@(M6GM<,B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BN/RXQ"(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`BR+?(S\/<PNLB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@
M861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E
M<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO
M=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT
M(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I9"`B0VAA<B(*;7-G
M<W1R("+5I[7#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R("+6Q\#[
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`BUM"Y^B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BDB"FUS9W-T<B`BO/+,Y=;0SL0@*$=",C,Q,BDB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D
M:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`BM[',Y=;0SL0@*$)I9S4I(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO
M;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BT:'4\</<PNLB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U
M<V5R;F%M92(*;7-G<W1R("+1H=3QTKNX]M/#NZ?#^R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SHB"FUS9W-T<B`BR-7&VL_4RKZWO<J].B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G
M:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L
M86YD(@IM<V=S='(@(LJEM:ZUNB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(M72LKNUO2`E<R"UQ,#@L?"VJ-+E+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED
M(")#;&5A<B(*;7-G<W1R("+(U<#Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"B,L
M(&9U>GIY"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("+*_;[=O^*RZ=&O
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G
M<W1R("+)OK/]T\.[ISH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*(RP@9G5Z>GD*;7-G
M:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("+1H=3QTKO.N]/#NZ?3P]+4
MT,+4]B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#
M;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("*PM,KSL>J\_+S,T/@B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*
M;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`BN=BQU;2PO]HB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM
M<V=S='(@(M3&P;\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S
M='(@(M3&P;\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(M3&P;\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*
M;7-G<W1R("*_QK_&R[G(NK6Z(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E
M8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("*XY\+7L<C1QR(*
M"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("+1U<FK(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R
M(@IM<V=S='(@(K7WR:O%S"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X-#8*(RP@9G5Z>GD*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T
M<B`BO/3'T-&AU/$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,PHC+"!F=7IZ>0IM<V=I9"`B0V]L<SHB"FUS9W-T<B`B
MS;;&L2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@
M(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(K^HS:@B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T
M<B`BP_S![B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R("+#_,'NO<6QOB(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R
M("+&P,+;(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(LVHT\/#^R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(K_&Q*;"WB(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@
M(D-O;7!A;GDB"FUS9W-T<B`BN:O+OB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(M+1
MS>JSR2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@
M9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("+,];S^(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T
M<B`BS/6\_B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"B,L(&9U>GIY
M"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(L7D
MUL,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@
M86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N(@IM<V=S='(@(L7DUL,B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*
M;7-G<W1R("+%Y-;#("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R("+(
MM\C/P]S"ZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(KC5
MN?LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(KC5N?NYLKK-N?HB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BP:R]T\JGL-PZ("(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G
M:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BP:R]T\JGL-PZ("(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`HC+"!F=7IZ
M>0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R("+!K+W3UL&YJ[^JP]S4O[?^SO'&]\JQU.*^W+[X
M+B#4K=+R.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M(@IM<V=S='(@(L&LO=/6P;FKOZK#W-2_M_[.\<;WRK'4XK[<OO@N(-2MTO(Z
M("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`BP:R]T];!($944"#.Q+S^M_[.\<;WRJ>PW"XB"@HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"B,L
M(&9U>GIY"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BS:C1MLK]OMW2T;/)
MN::UQ-3VO-.UO<3ZM<3-J-&VLK[6T"[3P\KSL>JPM,_"P=#/[L2_TM2\[,K3
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B
M)R5S)R#.Q+S^Q-K(W2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`BS/6\_B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("*_XK_+R+JUNB(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*;7-G<W1R("*YJ\N^(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("+!K+W3
MRJ>PW#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`BN+36QM&A
MU/$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM
M<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M;W-T82!2:6-A(@IM<V=S='(@(KCGR[FT[\#HO-,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(K_&S-BUS\W?(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`BSMZWJ-+4(%!'4""\
MT\/<T\J\_BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T
M<B`BSMZWJ,ZJ(%!'4"#6M-#0T\J\_L>IP_LN(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("+.WK>HTM0@4R]-24U%(+S3
MP]S3RKS^+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS
M9W-T<B`BSMZWJ,ZJ(%,O34E-12#3RKS^QZG#^RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*
M;7-G<W1R("+.WK>HM/*_JB`E<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("+.WK>HL/.VJ"!,1$%0(+?^SO'&]R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M(&QD87`@<V5R=F5R(@IM<V=S='(@(L[>MZBP\[:H($Q$05`@M_[.\<;W(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`BSMZWJ+;!R*$@)7,N(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`BSMZWJ,&L
MO=,@4TU"(+?^SO'&]RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T
M('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("+.WK>H
MP:R]T];!M_[.\<;W("<E<R<@RKG3PR!&5%`Z("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(L[>MZB]J,&BL;ZUV-/OT=0@)7,@R_G0
MZ-*JM<3$O\*\.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G
M<W1R("+.WK>HO>+#W"!01U`@ROV^W2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N(@IM<V=S='(@(L[>MZB]XL/<(%,O34E-12#*_;[=+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E(&-O;G1A8W0N("5S(@IM<V=S='(@(L[>MZC)OK/]N/S0PK/,T/(@)R5S
M)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BSMZWJ,F^
ML_VX_-#"L\S0\B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`BSMZW
MJ,F^L_VX_-#"L\S0\B`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(L[>MZB^]K:HRM6\_LC+M<2U
MY]?3T\J\_K78UK<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR.#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(L[>MZB^]K:H
MRM6\_LC+M<2UY]?3T\J\_K78UK<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`BSMZWJ+#\NJS7ULSEMJC2Y<[$O/XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@
M;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ+;!R*$@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP
M:'`Z,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M
M:V1I<B!<(B5S7"(N(@IM<V=S='(@(L[>MZBVP<BA("5S+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T
M(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T
M<B`BSMZWJ-?4P]S4O[?^SO'&]\BAM<.YJ[^JP]S4ORXB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(L[>MZBT
M\K^J("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B`E<RXB"FUS9W-T<B`BSMZWJ+3ROZH@)7,N(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,B"FUS9W-T<B`BSMZWJ+3ROZK.K+NDN:37]\2CO^D@)7,B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(L[>
MMZC)OK/]Q+_"O"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("+.WK>HLNG5TB!,1$%0(""W_L[QQO<N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(L[>MZBVP<BA("5S+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("+.WK>HML'(H;3FR*&_V-;&
ML>TH04-,*2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("+.WK>H
MML'(H;?^SO'&][7$S^"YV,S8T-0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("+.WK>HML'(H;?^SO'&][7$S^"YV,S8T-0B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`BSMZWJ+;!R*&W_L[Q
MQO>UQ,_@N=C,V-#4(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C
M87!A8FEL:71I97,B"FUS9W-T<B`BSMZWJ+;!R*&W_L[QQO>UQ,_@N=C,V-#4
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+.
MWK>HL:.TYB`E<R"UQ,7DUL,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E
M<UPB+B(*;7-G<W1R("+.WK>HML'(H2`E<RXB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+.WK>HL:.TYB`E<R"U
MQ,7DUL,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(L[>MZBQH[3F
M("5S(+7$Q>36PRXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`BSMZWJ+&CM.8@)7,@M<3%
MY-;#+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("+.WK>HL:.TYKC\T,*S
MS-#RM;TZ("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(L[>MZBQ
MH[3F("5S(+7$Q>36PRXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C
M:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S
M+B(*;7-G<W1R("+.WK>HT+3(ZRX@Q/J_R=+4RKG3P\C.NLZUQ,G]O+:SS-#R
MN_+*UK:ON+36QL_"P^:SS-#RM/K"Z[6]("5S+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BSMZWJ++IU=(@3$1!4"`@M_[.
M\<;W+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@
M(L[>MZBT\K^J("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(L[>MZBT
M\K^J("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+.
MWK>HL/RZK-?6S.6VJ-+ESL2\_BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(L[>
MMZBXLKC'("<E<R<Z("5S(+7$Q>36PRXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R
M("+5TK*[M;T@36]Z:6QL82!3:61E8F%R+B#'Z\BWR,\@<VED96)A<B#*Q[?Q
MM/*_JBXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T
M(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("+.WK>HN+/3Z-/#NZ<@)R5S
M)R#/PL'0R*C/WK6]SL2\_KS0("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1E9"!T97AT
M(@IM<V=S='(@(LSARK[$VLC=(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`BN?J\TB(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*(RP@9G5Z>GD*;7-G
M:60@(D-O=7)S97,B"FUS9W-T<B`BT*'*L2(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(KVHP:(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@
M(D-R96%T92!A(&QI;FLB"FUS9W-T<B`BO:C!HB(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*(RP@9G5Z>GD*;7-G:60@(D-R
M96%T92!A(&YE=R!O;F4B"FUS9W-T<B`BT:'4\=*[SKO0PK7$T[73T-7?(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G
M:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("*]J,&BU]/.Q+S^O-`B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B
M0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("*]J,&BU=^UQ,BHS]XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@
M8V%R9"!N=6UB97(B"FUS9W-T<B`BT,73P[^HNL7"ZR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(K_+PMZUV-''(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0W5B82(*;7-G<W1R("*YQ;#-(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM
M<V=S='(@(K6QQ[#/X,Z[(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"B,L
M(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(KVHP:+5
MW[7$R*C/WB(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(K6QQ[#*
ML;SD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4T"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%523"!I<R(*
M;7-G<W1R("*UL<>PRK&\Y"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC
M+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("*UL<>PS^#.
MNR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@
M5V5A=&AE<B(*;7-G<W1R("*UL<>PS.S&^"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B
M"FUS9W-T<B`BM;''L->TO_8Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS
M9W-T<B`BM;''L+?GN/$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"B,L(&9U>GIY
M"FUS9VED(")#=70B"FUS9W-T<B`BN?J\TB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I
M;VXB"FUS9W-T<B`BO/3'T-&AU/$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R
M=7,B"FUS9W-T<B`BR/O&UL*WR[DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`BSO?`[[;[
MSL0@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I
M9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`BSO?`[[;[SL0@
M*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM
M<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(L[W
MP.^V^\[$+\[:O\O`O,[$("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`BO=V_R[FRNLVY^B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(LC5(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S
M92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*
M;7-G<W1R("+#O\C5(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED
M(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G:60@(D1A
M=&4B"FUS9W-T<B`BR-7&VB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(LK5
MM;W(U<;:(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I
M9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BT:'4\<C5QMHB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A>2(*;7-G<W1R("*PU\SL(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,V"B,L(&9U>GIY"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("+)
MOK/]T\.[I]?I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(LJNMO[4PB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M("+0\KK%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(KSUR=G+
M]<7%(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB
M+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T
M<B`BR;ZS_2(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S
M='(@(M?6T,W1U<FK(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("+$K,C/
MR>VWW<JVL?`B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z
M>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`BQ*S(S\GMM]W*MK'P
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"B,L(&9U>GIY"FUS9VED
M(")$969I;FET:6]N<R(*;7-G<W1R("+,];S^(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(LF^L_TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL
M(@IM<V=S='(@(LF^L_TB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI
M;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@
M(LF^L_W3P[NGU^DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`BR;ZS_2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S
M:6]N(@IM<V=S='(@(LF^L_W(J,_>(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@
M;65S<V%G97,B"FUS9W-T<B`BR;ZS_:&BQ^6_U=/*O/XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("+)OK/](@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PHC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("+)OK/]T\.[
MI]?I(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`BLN7(Z[_)S.:T^L2CL.8B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BR;ZS_2`G)7,GM<3(
MJ,_>(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("+(
MM[:HTJK)OK/]("<E<R>UQ,BHS][2U+RPS\*\MLBHS]X@/R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`BR;ZS_=/#NZ?7Z2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R
M("+1H=3QR-7&VB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("*X_-#"L\S0
M\B`G)7,G(-+1R;ZS_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R
M>2!T:6UE(@IM<V=S='(@(K7=R\W*L;SD(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&5N;6%R:R(*;7-G<W1R("*UI,+S(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM
M<V=S='(@(L[*S.+#Z,KV(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(L/HRO8B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H
M86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("+/N+W:("C'Z[+.
MO[P@2&]R9&4@O,?"O,[$O/XI.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+/N+W:Q^NRSK^\S[7-L[G<
MP.VUQ\*\+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G
M:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(M'0MZ(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(L*VM>/.
MPK;((@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`BU^ZZ\]*[T*'*L;7$PK:U
MX\["ML@Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*
M;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(L*VM>/.PK;(.B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED
M(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("*TT]?SUL'3TB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*
M;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(K33T]+6
MP=?S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C
M=&]R>2(*;7-G<W1R("+$O\*\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("+2
MU"`R-"#0H<JQUL;/U,J^/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(L_4RK[1H<_N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(L_4RKZX
M\<J](@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0HC+"!F=7IZ>0IM<V=I
M9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("+/U,J^N/'*O2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*;7-G:60@(D1I<W!L
M87D@9F]R;6%T(@IM<V=S='(@(L_4RKZX\<J](@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I
M(@IM<V=S='(@(KRJLKS,X2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(K*[R;ZS
M_2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B
MLKO2JM:QO=.TYLBA(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(K7:
MTKNQRKS'PKS*Q[?QL/RZK-?6ML[#^[/&/R#(Y[G[RL?'Z]&AU/$N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`BMN##U\3AO-,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B
MMN##U\3AO-.YLKK-N?HB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BS\+4V"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("+/PM38("5S(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`BS\+4
MV,GZL\FUQ,7DUL/.Q+S^SJH@4$A0(+/,T/(N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T
M<B`BS\+`K;++M:4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G
M:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(K7GU]/3RKS^
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A
M<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`BM.W.\R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`BMO*YS[;@MOLB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("*QX+RM(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R
M=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(K'@
MO*W'^+_I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S
M+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`BL>"\K=/#NZ?7
MZ2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;B(*;7-G<W1R("*QX+RMR*C/WB(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
ML>"\K<BHS]XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM
M<V=S='(@(K'@O*T@)7,@M<3(J,_>(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BL>"\
MK=&AS^XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(K'@O*T@)7,@M<3(J,_>(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("*QX+RM("5S(+7$R*C/
MWB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I
M9"`B161U8V%T:6]N(@IM<V=S='(@(K78Q_@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%9WEP="(*;7-G<W1R("*PH[RP(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L
M92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A
M9&]R(@IM<V=S='(@(LCXMOO-W[;@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT
M+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(K7G
MU]/3RKS^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!
M9&1R97-S(@IM<V=S='(@(K7GU]/3RKS^M=C6MR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T
M(&UA=&-H+B(*;7-G<W1R("*UY]?3T\J\_K78UK>QV-#KSL>ZSRXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R("*UY]?3T\J\_LBWR,\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B
M16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(K'MQ^FW^[K%(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S
M86=E+B(*;7-G<W1R("*_U;#7T,6\_BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V
M,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U
M;'0N(@IM<V=S='(@(K_5L->]X;G[+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED
M(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y
M96%R(@IM<V=S='(@(L3JM=<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G
M<W1R("*WQ;3SL>"\K<;W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM
M86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T
M97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A
M=&]R:6%L($=U:6YE82(*;7-G<W1R("*SX+7`O+C$VM''(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("*V\L&BS-C`[]''(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I
M9"`B17)R;W(B"FUS9W-T<B`BM.W.\R(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-#8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`BM*O+S;O8N+3*
ML;>BR?JT[<[S.B`E<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("*TJ\O-N]BXM,JQMZ+)
M^K3MSO,Z("5S+B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T
M:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(K2KR\V[V+BTRK&WHLGZM.W.\SH@
M)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,B"FUS9W-T<B`BM*O+S;O8N+3*L;>BR?JT[<[S.B`E<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*
M;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(K2KR\V[V+BT
MRK&WHLGZM.W.\SH@)7,N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R("*PKLFSQ.'1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA
M(@IM<V=S='(@(K"CR/NV[;'(T<<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D5T:&YI8R(*;7-G<W1R("*PKLFSQ.'1
MQR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M175R;W!E(@IM<V=S='(@(L6WUMXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(L._(#$U
M(+?6UM,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY
M"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`BP[\@-2"WUM;3(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(L._
M(#,P(,/KUM,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R("+#OR`U(+?6UM,B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R
M("+#O[3.M<?"O"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+#OR`S,""WUM;3(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BP[\@,2"WUM;3
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X
M86UP;&4@=F%L=65S.B(*;7-G<W1R("*WML#]UK4Z(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(M:TT-`B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R("+5N;^J(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHS,@HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`BQ.JUUR(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-C@*(RP@9G5Z>GD*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R
M("+6M-#0(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W
M-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("*UO<;:
MR-4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM
M<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`BO>++M=2Q(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0HC+"!F=7IZ
M>0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`BU];0S='5R:LB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E
M='5P(@IM<V=S='(@(D944"#)S[2KQ>36PRXB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R("*VP<BAQJNZP\7DUL/*I[#<(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+.WK>HP:R]TR!,1$%0(+?^SO'&
M]RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(L[>
MMZC!K+W3(%--0B"W_L[QQO<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@
M9G)O;2!<(B5S7"(N(@IM<V=S='(@(KBTUL;*I[#<U]0@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BN+36
MQLJGL-RUO2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+B(*;7-G<W1R("+.WK>HO:C!HM*[N/;0PK7$(%-!4TP@P:R]TRXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(M+&MJ^UO2!<(B5S7"+*
MI[#<+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S
M(@IM<V=S='(@(M+&MJ^UO2!<(B5S7"+*I[#<+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"B,L(&9U>GIY"FUS9VED(")&
M86ER(@IM<V=S='(@(M3ZTL&V^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("*WJ,"\O\NXH\BZM;H@
M*,+MMOO.K,3)R[G(NK6Z*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`BMZC"WLBZM;HB"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T
M<B`BT<_6V+3MSO,A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(K2KU>8B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&
M87AE<R(*;7-G<W1R("*TJ]7F(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(K;^
MU,(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@
M3&EK92(*;7-G<W1R("*XT+[US_'*QR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("*X
MT+[US_'*QSH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&
M97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L
M970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,X"B,L(&9U>GIY"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R
M("+5TK*[M;W.Q+S^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R
M("+LL[S#(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L
M(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(L[$O/XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE
M($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(L[$O/[*_<2_.B`E<R"X]L[$O/XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("+.Q+S^ROW$
MOSH@)7,@SL2\_B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("+.Q+S^N=S`[<;W(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*
M;7-G<W1R("+.Q+S^P_NSQB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y.34*(RP@9G5Z>GD*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@
M(LJQQ_C1H=3Q(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM
M<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`BSL2\_LG/M*LB"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+.Q+S^R<^TJ[FFQ-S.M+&[
MUJ>SUBXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@
M(D9I;'1E<G,B"FUS9W-T<B`BN?W"R\;W(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M1FEN;&%N9"(*;7-G<W1R("*WTL"\(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("+)S[#KU,(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS
M9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(LG/S]+4PB(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I
M>"!R871I;R(*;7-G<W1R("*YS+:HL<C`_2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T
M<B`BMZW7JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&
M;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR
M,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B
MQ+_"O"`E<R"RN[3FU-HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(M?6
MT,W1U<FK(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&
M;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B
MQ/JUQ.2OP,#&][*BSK36I[/6U>*X]KFFQ-PN(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R
M("(B"B+4I+&HS.S*_2`HU*2QJ,SLROVP_,"HL-?,[-+4O+#2N;SDM<3*_;[=
M.\CGN?O4I+&HS.S*_;W/LZ2]J]6\T\.QR+W/O^VW^;7$L.8B"B+#YBDB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@HC+"!F=7IZ>0IM<V=I
M9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(M&AU/'#W,+K(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B
M"FUS9W-T<B`BM+#,Y2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("++X\/\(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`BR^/#
M_,#@T,TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O
M<G1U;F5S(@IM<V=S='(@(LOCP_PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`BR^/#
M_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O
M<G5M<R(*;7-G<W1R("+"V\RS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`BU]2VK]>JT,4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS
M9VED(")&<B(*;7-G<W1R("+0Q\;:SN4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED
M(")&<F%M97,B"FUS9W-T<B`BM+#,Y2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92(*;7-G<W1R("*WJ+GZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@
M(K>HRO2YY]''Q,<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN
M97-I82(*;7-G<W1R("*WJ,KTLJ/`^\3ASO?1QR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*
M;7-G:60@(D9R;VTB"FUS9W-T<B`BO,2\_LC+(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G
M:60@(D9R;VT@=&AE("(*;7-G<W1R("*TTR(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM
M<V=S='(@(LWJU?O#Z,KV(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M("+"^M3"(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*
M;7-G<W1R("+(J\/[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T
M<B`BO-/%[B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T
M<B`BN-2QR-''(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(K+ZR?H@)7,@M<3/M<VSQ>36PR(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@
M(KCQPK.\JM''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R
M("*UPKGZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`BY<C$
MR2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("+6L;*\
MPM[-TR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(L/[(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(M>JM;TB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B
M1V]O9VQE(,O1R_<B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS
M9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92#+T<OW(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I
M9"`B1W)A>7-C86QE(@IM<V=S='(@(KO2ML@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B1W)E96-E(@IM<V=S='(@(L^CP+`B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(L^C
MP+#.Q"`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA
M;F0B"FUS9W-T<B`BN/'!ZL"\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D
M82(*;7-G<W1R("*X\<'6Q,FT[R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y
M"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+3P[NGU^FY
MW,#M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("+3P[NGU^G#^[/&LKNUP[_5
ML-<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HT,+4]M/#NZ<@)7,N(+?^SO'&
M][O8TZ8Z(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HN/S0PM/#NZ<@)7,B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@
M)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HN/S0PM/#NZ<@)7,B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM
M<V=I9"`B1W)O=7!S(@IM<V=S='(@(M/#NZ?7Z2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G
M:60@(D=U861E;&]U<&4B"FUS9W-T<B`BN<^UPL+>QM6UNB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(KG8M;HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(LZCM=C"[<"M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T
M<B`BN/&V]\[WM;HB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S
M="!097)M:7-S:6]N<R(*;7-G<W1R("*WP[_-R*C/WB(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R
M("*WP[_-P?31U"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R
M("*\N,3:T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B
M"FUS9W-T<B`BO+C$VM''L<C)W+FRNLVY^B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B1W5Y86YA(@IM<V=S='(@(KGGT<?$QR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(M72LKNUO2!(5%10(-'IUJ0N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("*ZH[78(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H
M;2(*;7-G<W1R("+4T[35+<OCMZ@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,@HC+"!F=7IZ>0IM<V=I9"`B2&%Z92(*;7-G
M<W1R("*Q[<VW(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G
M<W1R("*Q[<VW(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("*Q
M[<VW(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',B"FUS9W-T<B`BNM6UPKK-PO2UL<#-R+JUNB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED
M(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T
M<B`BSZ.RKL"TSL0@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"B,L(&9U>GIY"FUS
M9VED(")(96EG:'0B"FUS9W-T<B`BS>W)SR(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE
M;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP
M;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R("*P
M[];Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`BL>"\K<;W
MRKG3P[#OUOHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS
M9VED(")(96QP97(B"FUS9W-T<B`BL._6^B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("*Q
ML;#KQ_(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("+5XL#ORL?.Q+S^M<2_
MJLJ\.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Y"B,L(&9U>GIY"FUS9VED(")(:6=H(@IM<V=S='(@(LWMR<\B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S
M='(@(LK7TK,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("+H\[79N-0B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`B
MRM?2LR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(LK7TK.UV-:W(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")(
M;VUE($1I<F5C=&]R>2(*;7-G<W1R("+$O\*\(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R("+*U]*SM>>[L"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N
M9'5R87,B"FUS9W-T<B`BNNFVO,"MR[DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(DAO;F<@2V]N9R(*;7-G<W1R("+6T+GZS^.XVR(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`BTM&SR;FFN+*XQR`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M075T:%]L9&%P.B#.WK>HR;ZS_=/#NZ<@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T
M(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(
M;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BRZ[&O<_?(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@HC+"!F=7IZ>0IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(LNNQKW/WR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*(RP@9G5Z
M>GD*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(LNNQKW/WR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-0HC+"!F=7IZ>0IM<V=I9"`B2&]W(&UA;GD@
M8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BU]:V
MSLK]Q+^YLKS&/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B
M"FUS9W-T<B`BU]:VSLK]Q+^YLKS&/R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(LJJML@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI
M9&ET>3H@(@IM<V=S='(@(LJJML@Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("+0V='`P/LB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0(-/*
MS^2]J,&BRJ>PW#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("))34%0(-/*S^3)OK/]RJ>PW#H@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("))34%0(-/*S^2TQ<7,Q>36P[VHP:+*I[#<.B`E<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E
M<W,B"FUS9W-T<B`BM=C6MR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B
M87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B25`@M=C6M\[>MZC*N=/#+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0(+78UK>RHK*[
MU-H@0TE$4B"UQ+W3RMS'^+_IUM`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W
M;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R
M="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M26-E;&%N9"(*;7-G<W1R("*Q^;6Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("+6N]/0S;RQZB(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B5S(+7$T:'/[B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I
M=&@@=&5X="(*;7-G<W1R("+-O+'JO+#.Q-?6(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B
M"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@
M(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE
M(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y
M960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*(RP@
M9G5Z>GD*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(M2DP,`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,W"B,L(&9U>GIY"FUS9VED("));6%G92!54DPB"FUS9W-T<B`BS;S&K"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R
M("+-O,:L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("+)S[2KS;S&K"(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T
M<B`BS;S&K"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(KOC
MR.LL(+*]UN@@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS
M9W-T<B`BN^/(Z]?6MLXZ("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("*[X\CK
MU]:VSCHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G
M<W1R("+*Y,CKLKO5_<BWM<37]]/#PNLN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@
M(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@
M(LZTUJJUQ-/#NZ?#^[ORP]S"ZRXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*
M(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`BU/:\T\OU
MQ<4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(M.AML@B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R
M<R(*;7-G<W1R("*X]K'PT\.[IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD
M;VYE<VEA(@IM<V=S='(@(M.AMLC$X<[WT<<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S
M='(@(M#%SZ(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS
M9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+0Q<^B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF;W)M871I;VX@;F\@
M;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("))
M;G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*(RP@
M9G5Z>GD*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("*RY<CKT\J\_B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*
M;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("*RY<CKL>VX\2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@
M(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("*RY<CKS?C"Y\&LO=,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R("*RY<CKO\G,YK3ZQ*.PYB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R("*RY<CKT\J\_B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("*RY<CKL>VX
M\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*
M;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("*RY<CKT\J\_B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@869T97(B
M"FUS9W-T<B`BLN7(Z['MN/$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@<F]W(&)E9F]R92(*;7-G<W1R("*RY<CKL>VX\2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM
M<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("*RY<CK+['DN/S-
MO,:L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(K+ER.LO
ML>2X_,WXPN?!K+W3(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R
M(@IM<V=S='(@(M7[ROTB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`BU?O*_<'0(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW
M"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G
M<W1R("+.WM"GM<0@541(*-/#NZ?*_;[=L>W-MRDN(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`BSM[0I[7$S?+3P\+KROV^W2XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P
M<&QI8V%T:6]N+B(*;7-G<W1R("+.WM"GM<33IM/#L\S0\BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G
M:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(L[>T*>UQ,7ZM,ZZQ<+K
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV
M86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`BS.&]N[7$ROV^W<[>T*<N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM
M<V=S='(@(L[>T*>UQ,2_L>K7H=:W(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*
M;7-G<W1R("*RN[K/MZBUQ,[$O/ZX\<J](@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$W-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L:6-E
M;G-E(&ME>2XB"FUS9W-T<B`BSM[0I[7$TZ;3P[/,T/(N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BSM[0I[7$TZ;3P[/,
MT/(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("+.
MWM"GM<0@;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+B(*;7-G<W1R("+.WM"GM<2[\M72LKNUO2!A<&E?:60N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS
M9W-T<B`BSM[0I[7$N_+5TK*[M;VRSLK]+B(*"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`BLKNZS[>HM<2XN,BHS]XN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P
M87)T;F5R(&ED+B(*;7-G<W1R("*RN[K/MZBUQ+BXR*C/WBXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`BSM[0I[7$S:C1MM"MTNDN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("+.WM"G
MM<3-J-&VT*W2Z2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I
M<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("+.WM"GM<2PYK&^NL7"ZR(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-C(*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<VAA<F4@
M;V)J96-T(@IM<V=S='(@(K*[NL^WJ+7$SL2\_KCQRKTB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(L[>T*>UQ,"TU+37
MH=:W+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S
M='(@(L[>T*>UQ,WRT\/"Z\K]OMTN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*(RP@9G5Z
M>GD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`BO/3'T-&AU/$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`BTL'`RM+!R[G`O+FRNLVY^B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B27)A<2(*;7-G<W1R("+2P<"MO\LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DER96QA;F0B"FUS9W-T<B`BL*ZV^\"\(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@
M(L+\M;HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`BTM3)J\'0(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES
M<W5E<B(*;7-G<W1R("+'J;>BU=\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("+0
ML<SE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("+2XK3S
MP/LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`BT<#"
M\KS3(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`BTKO4PB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P86X@*,C5L;XI(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R
M,BU*4"DB"FUS9W-T<B`BR-7.Q"`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@
M:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A
M9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@
M(DIE<G-E>2(*;7-G<W1R("+4\\[WM;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIO<F1A;B(*;7-G<W1R("+4O+6I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`BQM_4
MPB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P
M"FUS9VED(")*=6YE(@IM<V=S='(@(L'YU,(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"B,L(&9U>GIY"FUS
M9VED(")*=7-T:69Y(@IM<V=S='(@(K^_U_.VU,;K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@
M(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(M;#UM`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B
M2G5S=&EF>2!&=6QL(@IM<V=S='(@(M?ST]*VU,;K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@
M(DIU<W1I9GD@3&5F="(*;7-G<W1R("*_O]?SMM3&ZR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED
M(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(K^_T]*VU,;K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(KG^R/B_R\NYS+DB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS
M9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("*QH\'TU*W1^2`_(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("*_S\3AT<<B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME
M<F)E<F]S(,C/UJ2T[<[S+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I
M;VXB"FUS9W-T<B`BP]S4O[VHP:(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R
M("+#W-2_S-C5]R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("+#W-2_LZ2VR"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`BP]S4O\#@T,TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@
M(L/<U+_3[[>H(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N(@IM<V=S='(@(K6QQ["UQ+FKOZK#W-2_M_[.\<;WUM`LTM&^
MK;3FU-K$^K7$P]S4ORXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*
M;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+
M:7)I8F%T:2(*;7-G<W1R("*[^<#OL,W+N;FRNLVY^B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`BLZ_/RB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(KJKN?HB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(KJK
MSL0@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G
M<W1R("*_QLW^S-@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB
M"FUS9W-T<B`BO*JV^[RJR[G,N2(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("*PYL/F
MQ>36PR(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@
M(DQA;F=U86=E(@IM<V=S='(@(M/OT=0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(L#/
MSLXB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA
M;&8B"FUS9W-T<B`BS\*PZ]3"(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<V"B,L(&9U>GIY"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G
M<W1R("+#W,+K.B`B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B
MS\+/TM3"(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`BR<^TSKC\T,(Z(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@
M;&]G:6XZ("5S(@IM<V=S='(@(LG/TKNTSK7'PKPZ("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M870*;7-G:60@(DQA
M<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BR<_2N[3.M<?"O#H@)7,@
MU]0@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@
M(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(LG/TKNTSK7'PKPZ(+7:TKNT
MSK7'PKPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("+`
MK<W1SJS1QR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B
M3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(K#F
MP^;%Y-;#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B
MP.BPS<3;(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("),969T(@IM<V=S='(@(M?S
MTL8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),
M969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R
M("*_U;#7UK4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T
M<B`BP+/+]\W0(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R("*TT\ZT(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(L#[L<C`[]''(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S
M='(@(L#[L<C1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I
M;B(*;7-G<W1R("+!T-:GMMC*O[7'(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(DQI9VAT($1R
M:7IZ;&4B"FUS9W-T<B`BM:W`MB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN
M(@IM<V=S='(@(K7'PKPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H
M="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`BM:W`MB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*(RP@9G5Z>GD*;7-G
M:60@(DQI;65R:6-K(@IM<V=S='(@(L#[L<C`[]''(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*;7-G<W1R("+!K+W3
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R
M("+!K+W3(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),
M:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S
M964@=&AE(&9O;&1E<B(*;7-G<W1R("+!T+/V("T@T\.[I[_)TM2_M+6]U>*X
M]L[$O/Z\T"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(L'0
ML_;+M</WL>K,XB(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*(RP@9G5Z
M>GD*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(K+ER.NQ[;CQ(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI
M<W0M07)C:&EV92(*;7-G<W1R("+,UL+;T\.[I]?I+<[$O/ZY\2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T
M+4AE;'`B"FUS9W-T<B`BS-;"V]/#NZ?7Z2W'\];Z(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`BS-;"V]/#NZ?7Z2W*MK'PNL7"ZR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(LS6PMO3P[NGU^DMT[73T-7?(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("+,
MUL+;T\.[I]?I+;S$O/[(RR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("+,
MUL+;T\.[I]?I+;:IU,0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("+,
MUL+;T\.[I]?I+<BAS_NVJ=3$(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS
M(&9A:6QE9#H@)7,B"FUS9W-T<B`BP="S]M/#NZ>UQ+FFQ-RQN[G8L=4B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("+!T+/V
MT\.[I[7$N:;$W+&[N=BQU2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`BP="S]M/#NZ>UQ+FFQ-RQN[G8L=4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`BSL31
MIR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(L&B
MS-7-\"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`BU-C(
MZ[JORKV_XM;0+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(K6QM=C*L;SD.B`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A
M;F0@5&EM92(*;7-G<W1R("*UV,?XT^O*L;SD(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("*UV,?X
M(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(K7'PKPB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("+7
MHL_Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I
M;B(*;7-G<W1R("*UQ\*\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BP:R]TR(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`BM<?"O,JGL-PL(,?KO.RR
MZ<3ZM<33P[NGP_NZS</<PNLL(,B[NO/6V,K4+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R
M("*UQ\*\RJ>PW"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U
M"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`BUZ+/^B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B3&]V
M92(*;7-G<W1R("+)OK/](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q
M"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`BPJS)K;&D
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("+4
MPB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/
M5$0B"FUS9W-T<B`BP[_(U=#%SZ(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&(+B]O-/.Q+S^
MUM##N]/0ROV^W2XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS
M9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R
M("+6T+GZL,3#Q2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(L+MQN2V
MV;FRNLVY^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G
M<W1R("+"[;3OO-/+N;S3M;HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(L+MP/LB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T
M<B`BT\J\_B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G
M:60@(DUA:6P@061M:6XB"FUS9W-T<B`BT\J\_KG<P.TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G
M:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-86QA=VDB"FUS9W-T<B`BPNW`K<W^(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-86QA>7-I82(*;7-G<W1R("+"[<"TSO?1QR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`BPNVV^[3ZM_(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`BPNW`^R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`BPNVV^LO[(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("+(_=3"(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ
M>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(L+MS.'$X;_+M;HB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R
M:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(K'JO,>SR2"_M+G]
M+\ZTO[2Y_2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("*QZKS'L\G&Y,O\M<3*MK'P("C`
M_<CG+B#6V-*J+]+1N]BXM"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H
M86QL($ES;&%N9',B"FUS9W-T<B`BPNW)W+;[R+JUNB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("+"[<SAQ.&_R[6Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG
M(&9I96QD<R(*;7-G<W1R("+5_=3:QJ7%Y-?6MLXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`BPZO`[\O^Q.'1QR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(L.KP._'\\NY(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@
M(KB]O/[*_<2_TM&SK+/VO=/*W,G/S]XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G
M<W1R("+7[KW\(#(T(-"ARK&UQ-?NN-_.PK;(.B`B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B
M"FUS9W-T<B`BU^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R
M("*]T\K<U^ZT\[.DML@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(L[EU,(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(L+MU+S,V,BZM;HB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@
M(DUE9&EC:6YE(@IM<V=S='(@(M"[OO@B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(K/)
MU+$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU
M(&UO9&4Z(@IM<V=S='(@(M&AM:7$H\J].B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E
M(&-E;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S
M='(@(M/*O/XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@
M8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB
M=F5R:69I960N(@IM<V=S='(@(M/*O/[1Z=:DTM'-ZK/)++6KRL?3P[NGM<3'
MJ</[R+3.WK>HS:BY_='IUJ0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER
M960N(@IM<V=S='(@(M#%SZ+2T;G]QMHN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I
M9"`B365S<V%G92!T>7!E(@IM<V=S='(@(M#%SZ+`X-#-(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-971A<B!796%T:&5R
M(@IM<V=S='(@(K6QQ[#,[,;X(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M365T87(@Q_B_Z<[>MZC*N=/#+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R(")-971A<B#'^+_ISMZWJ,JYT\,N(,^XO=K'Z[+.O[S/M<VSN=S`
M[;7'PKPN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM
M<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO
M9"(*;7-G<W1R("*WO;>H(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C
M+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E
M9FEN960B"FUS9W-T<B`BM[VWJ"`G)7,G(,ZTL;NVJ-+E(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(KFKUL8B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("+$J\[WN.<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9B(*;7-G<W1R("+#W+_+PM[$X<[WT<?!JK#NN?HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@
M9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R("+$H[_I(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@
M5'EP92(*;7-G<W1R(")-:6UE(,#@T,TB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(M?NO?P@,C0@T*'*L;7$U^ZUS<["ML@Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R("+7[KW\(#8@T*'*L;7$U^ZXW\["ML@Z("(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R("+3L\GD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM
M<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B
M"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`BQ>36P\[$O/[2Q<JG+B#(Y[G[TJK*N=/#U>*X]M.FT\.S
MS-#RQ/JQV-#KS];4VK[-LOK)^LO[+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M
M97-S86=E($E$+B(*;7-G<W1R("+5TK*[M;W0Q<^BM<0@240N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*
M;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G
M<W1R("+5TK*[M;V[X<;:M<0@240N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`BT,?&
MVM*[(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-
M;V)I;&4@36%I;"(*;7-G<W1R("+0T+:OT\J\_B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"B,L(&9U>GIY"FUS9VED(")-
M;V1E<F%T92(*;7-G<W1R("+#R<S8R/O`K<S8(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B
MN/S0PLC5QMHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G
M:60@(DUO9'5L=7,B"FUS9W-T<B`BQ*._Z2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`BQ*:V^[;@S=\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("+$IL3)N.<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(L/)N<4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A
M;F0@>65A<B(*;7-G<W1R("+4PKK-Q.HB"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S
M='(@(L._U,(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS
M9W-T<B`BP\G,V,C[P*W,V"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T
M<B`BU,+!P=.OO_<B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ
M-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M
M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]R;V-C;R(*;7-G<W1R("+$IL+EN.<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED
M(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T
M<B`BS\+2QB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(M?STL8B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`BT]+2QB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("+)S]+&
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(L_"TL8B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@
M=7`B"FUS9W-T<B`BR<_2QB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB
M:7%U92(*;7-G<W1R("+$JLFCL<B_RR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#0*(RP@9G5Z>GD*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<R(*;7-G<W1R("+/PL"MLLNUI2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA
M<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(KBT
MT:$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")-
M>2!!8V-O=6YT(@IM<V=S='(@(L[2M<35R[K%(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(L3ZM<30Q<^B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(L[2M<3#
MQ;NG(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B
M37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("+.TK7$P\6[I]*SP^;%Y-;#(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(L/EM>DB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM
M<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(K*[+,[2LKO-K-+B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B
M"FUS9W-T<B`BP_NSQB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*
M;7-G<W1R("+$R</7L<C1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B
M"FUS9W-T<B`BZ*?"LR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS
M9W-T<B`BQ.&RM+;[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD
M<R(*;7-G<W1R("*ZR<"\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA
M;F1S($%N=&EL;&5S(@IM<V=S='(@(KK)RO2PLK78P=#+N2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P
M92!"87-E(%523"(*;7-G<W1R("*[^=/:3F5T<V-A<&4@M<3-^-:W(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*(RP@9G5Z>GD*
M;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(KOY
MT]I.971S8V%P92"UQ,WXUK<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-0HC+"!F=7IZ>0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L
M:6-Y(%523"(*;7-G<W1R("*[^=/:3F5T<V-A<&4@M<3-^-:W(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*(RP@9G5Z>GD*;7-G
M:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(KOYT]I.971S8V%P
M92"UQ,WXUK<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,@HC+"!F=7IZ>0IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`BN_G3VDYE='-C87!E(+7$S?C6MR(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@
M<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T<V-A<&4@4U-,(+?^SO'&]\/[L\8B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S
M8V%P92#(S]:DM<3%^M>B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B
M"FUS9W-T<B`B3F5T<V-A<&4@R,_6I,#@T,TB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(LWXPN<B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@V"FUS9VED(").979E<B(*;7-G<W1R("*TT\ZT(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(M#"OZ;`[[;@Q.'1QR(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C(V"B,L(&9U>GIY"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`BT,*_
MIL#OMN#$X=''(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BT,7/HL#@T,TB"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(M#"
MU,(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS
M9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("+0PM/#NZ?#
M^R`HM\>QV-*J*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B
M"FUS9W-T<B`BT,+.]\"\(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B
MP]S"ZR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T
M8V@N(@IM<V=S='(@(L/<PNNQV-#KSL>ZSRXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W
M("A?8FQA;FLI(@IM<V=S='(@(M#"M+"_VB`H7V)L86YK*2(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(").97=S(@IM
M<V=S='(@(M#"SL4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U
M"B,L(&9U>GIY"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(M/#NZ?7Z2(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").
M97AT(@IM<V=S='(@(L_"TKNRO2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("+/PM*[
MTK,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@IM<V=I9"`B3F5X="!O<'1I
M;VYS(@IM<V=S='(@(L_"TKNX]M&AS^XB"@HC.B!F<F%M97=O<FLO54DO54DO
M4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B
MS\+2N[*](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T
M<B`BQ.&\T\"MN<\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S
M='(@(L3AR-6V^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G
M<W1R("+$X<C5P/O1QR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(LWMR<\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYI=64B"FUS9W-T<B`BQ::PH[6Z(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PHC+"!F=7IZ>0IM<V=I
M9"`B3F\B"FUS9W-T<B`BSMXB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N
M(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS
M9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA
M9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED
M(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*
M;7-G<W1R("++^=:XMJBUQ,Z[UL/)S\.[T]#'^+_IM.;4VB(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(L.[T]#,X;FIR-7`^L/[L\;2U+FI($U#04P@T>G6I"XB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E
M+B(*;7-G<W1R("+.M+'DN/PN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(K6QQ[#+^;2F
MM<35XKCVM<B\ML[>MZC4]KS3M,[(J,_>+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R
M"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(@IM<V=S='(@(L.[T]#6N+:HM<0@)7,@Q>36P]#%SZ(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R("+#N]/0UKBVJ+7$($944"!61E,@Q>36P]#%SZ(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*
M;7-G<W1R("+#N]/0UKBVJ+7$(%-13"!61E/%Y-;#T,7/HBXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R("+#N]/0UKBVJ+7$(%-13"U&:6QE(%9&4\7DUL/0Q<^B
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T
M"B,L(&9U>GIY"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS
M9W-T<B`BP[O3T,/HRO8B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`BSL2\
M_LZTR<^TJR(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(L.[T]##Z,KV(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G
M:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`BSKO6P]#%SZ+)T,ZT
MQ>36PR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@
M9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+.
MN];#T,7/HLG0SK3%Y-;#(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A
M9V4@<W5P<&QI960N(@IM<V=S='(@(M#%SZ+2T;G]QMHN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z
M>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("+.M-:XMJBU
ML;78T^_1U"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M8F5R('-P96-I
M9FEE9"XB"FUS9W-T<B`BSK36N+:HM;&UV-/OT=0N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY
M,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(L.[T]#6N+:HP]S"Z]+4N:D@2%144"#1Z=:D
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`BP[O3T-:XMJC#W,+KTM2YJ2!)34%0(-'IUJ0N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("+#N]/0UKBVJ,/<PNO2U+FI($ME<F)E<F]S(-'IUJ0N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T
M:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP[O3T-:XMJC#W,+KTM2YJ2!,
M;V=I;B#1Z=:D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#6N+:HP]S"Z]+4N:D@4$%3
M4U=$(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("+#N]/0UKBVJ,/<PNO2U+FI(%--0B#1Z=:D+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I
M9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W
M:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N
M=7!S+B(*;7-G<W1R("+#N]/0M/W)\[7$UZ*RX<GJQ^LN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("+.N];#T,7/HLG0SK3%Y-;#(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`BO]6PU]:U
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"B,L(&9U>GIY
M"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("+.M-:X
MMJBUL;78T^_1U"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*
M;7-G<W1R("*QN,W\PKPB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`BSM[4
MW;3FQ+_"O+_)N:F_[,BA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BSK36JK7$T\.[I\/[
MN_+#W,+K+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P
M"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("+#
MN]/0NL^WJ+7$(%A-3"#*_;[=L;NTJ[O8(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G
M<W1R("*_U;#7UK4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS
M9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BU*W*O,7D
MUL/.Q+S^UM#5TK*[M;VPYK&^T,7/HBX@UMC0PK+ZR?K%Y-;#SL2\_BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+4VL3ZM<3%Y-;#SL2\_M;0U=*RN[6]L.:Q
MOM#%SZ(N(-;8T,*R^LGZQ>36P\[$O/XN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R("+.WB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*
M;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM
M,3`I(@IM<V=S='(@(LC5MOK"_,[$("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(L6UN*._R[6Z
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H
M<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("*QL;#K
MQ_(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L
M86YD<R(*;7-G<W1R("*QL<+MP._1Q\3)R+JUNB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F]R=V%Y(@IM<V=S='(@(L6RS?XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S
M='(@(K?'UJZZ\R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(K?'UJ['L"(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@
M9&ER96-T;W)Y(@IM<V=S='(@(K*[RL?2N[CVQ+_"O"(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"B,L(&9U>GIY"FUS9VED(").;W0@:6UP;&5M96YT960N
M(@IM<V=S='(@(LG0SK3*M<_6+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`BL;C-_,*\(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR
M,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(LZTL;O6
MI[/6(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R("*QN,W\
MPKPB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@
M(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B
M3F]V96UB97(B"FUS9W-T<B`BRJ[2N]3"(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(LK]U]8B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@
M;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+7UK?[ROTB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`BU]:VSLK]Q+\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R
M(&]F(')O=W,B"FUS9W-T<B`BL<K*_2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ>0IM
M<V=I9"`B3V)J96-T(@IM<V=S='(@(M;WUKPB"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T
M<B`BMM3/\[VHP:+5WR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(K#+O?C.NR(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(LJNU,(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*
M;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("*P
M[+FKRM(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G
M:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V
M"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`BP]S"ZR(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`BL*+"_"(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("+6
MN]/0($E-05`@M_[.\<;WUJ>SUL[$O/Z\T+FRS^VYIL3<+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(M:[O=/*W-*[
MN/;3RKS^M=C6MRXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*
M;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I
M;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(M:[T]#3M=/0U=_3Z\^US;.YW,#M
MU+&_R=+4L>2X_+FRS^W(J,_>(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(M3:T,*T
ML+_:UM"T\K^J(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T
M(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-0HC+"!F=7IZ>0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R("+4VM#"M+"_VM;0M/*_JB(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS
M9VED(")/<'1I;VYS(@IM<V=S='(@(M&AS^XB"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@M<31H<_N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(L_NQ+^QX+K%(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R
M9V%N:7-A=&EO;B(*;7-G<W1R("+7Z=:O(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`BU^G6K[6ESKLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@
M(M?IUJ\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I
M9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`BU*W*O-.FT\.S
MS-#RQ*.PYB(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF
M;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T
M<B`BU-H@)7,Z(-;0M<34K<J\Q*.PYBXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I
M9"`B3W1H97(B"FUS9W-T<B`BQN3+_"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(L;D
MR_S0Q<^B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I
M9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BT[73T-7?R*C/WB(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!32#1
MZ=:DSM[0IRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS
M9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0(,K]U];'
MJ</[(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM
M<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4""\T\/<U\K!
MSR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4""YJ[^JP]S4OR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0(-+1QZG#^R_2
MT;S3P]P@U\K!SR(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B
M4$A0($-O9&4B"FUS9W-T<B`B4$A0(+/,T/*T^L+K(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0(+W%
ML;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B
M4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0HC+"!F=7IZ
M>0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")02%`@O<6QOB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*
M;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")086MI<W1A;B(*;7-G<W1R("*PS;OYR[G,N2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!A;&%U(@IM<V=S='(@(L7!P,TB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(K#-P-7+N<RYL;O5O,'LQ_@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M
M82(*;7-G<W1R("*PS<3#PNTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A
M($YE=R!'=6EN96$B"FUS9W-T<B`BL,VRO-''T,*\N,3:T<<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("*PS<"MN><B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B
M4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G
M<W1R("+#W,+K(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R
M"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R
M"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B
MP]S"ZSH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U
M,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`BP[O3T-:XMJC#W,+KTM2YJ2!2041)55,@T>G6
MI"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED(")0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+#W,+KR+?(SR(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S
M<W=O<F0Z(@IM<V=S='(@(L/<PNLZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`BP]S"ZSH@
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ
M-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(L/<PNNQ
MV-#KSL>ZSRXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I
M9"`B4&%S=&4B"FUS9W-T<B`BS/G)SR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI
M<&)O87)D(@IM<V=S='(@(LSYR<\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(L*W
MOK8B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B
M4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("*T_<GSM<?"O*.Z(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P;&4B
M"FUS9W-T<B`BO<?)JR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS
M9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B
MUK30T,ZLNZ2RV=?W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM
M<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/R(*;7-G<W1R("*UQ\*\NO/6M-#0SJR[I++9U_<_(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS
M9W-T<B`BR*C/WB(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO
M="!D96QE=&5D+B(*;7-G<W1R("(G)7,G(+7$R*C/WLZTL;O)OK/]+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R("*TYLBAU.*^W"(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("+(J,_>(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`BR*C/WKG<P.TB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S
M='(@(L[2M<0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B
MP]C"LR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0HC+"!F=7IZ>0IM
M<V=I9"`B4&5T<R(*;7-G<W1R("+7J+"X(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0:&EL:7!P:6YE<R(*;7-G<W1R("*WQL+)L?8B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*
M;7-G<W1R("*UY[NP(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W
M.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(M75QJPB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0:71C86ER;B(*;7-G<W1R("+&I,S8O[6UNB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0
M:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V
M"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM
M<V=S='(@(L?KRN3(Z]*[N/;4PK?=O+#$ZK?=+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"B,L(&9U>GIY"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R("+'Z\KDR.O2N[CVU,*WW;RPQ.JWW2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S`Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("+'Z\KDR.NZS[>HM<3*
ML;SD+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(L?KRN3(Z]*[N/:ZS[>H
MM<3(U<;:.]&AU/&TR]3"M]VUQ,C5QMHN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92XB"FUS9W-T<B`BQ^O*Y,CKNL^WJ+7$RK&\Y"XB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(L?KS.&YJ<[*S.*U
MQ-6JTJHN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("+'Z\KDR.O$
M^K7$T\.[I\/[O+##W,+K(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("+'Z]3$ML'/PL'0Q-K(W2[$^K'8
MT.O-K-+BU>+0J<K"S^ZRQ<3<RKG3P\^US;,N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`BLJC`O"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B4&]L:71I
M8W,B"FUS9W-T<B`BS;;&L2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(LVVQK$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("+&S\S1T<`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*
M;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*2(*;7-G<W1R("*UW<O-T\J\_K6]U>*X]L[$O/Z\T"`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E
M8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`BU^Z]
M_"`E<R#0H<JQM<2]M=/JP;\Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP
M.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z(-72LKNUO<OYT.C2
MJK7$($Q$05`@P*G5N=?IO/XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7W-E<W-I;VXZ(-72LKNUO<OYT.C2JK7$('-E<W-I;VX@P*G5N=?IO/XN(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM
M<V=S='(@(L;XT;DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I
M9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`BNJ/&O</FQOC1
MN3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R("+&^-&Y.B`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R("+4I,#`(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"B,L(&9U>GIY
M"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`BU-K0PK2PO]K6T+3ROZHB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V
M-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("+)S]*[N/;1H<_N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME
M>2(*;7-G<W1R("++O</<P]S4OR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS9W-T
M<B`BSLK,XC\B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BSLK,XL/HRO8B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*
M;7-G<W1R("+7J+"X(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@
M(LSARK[$VLC=(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(KFKOZK#W-2_(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U
M8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(KFKOZK#W-2_T=W+XR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"B,L(&9U>GIY
M"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`BN:N_JL/<U+\B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(KFKOZHOR[W#W,/<U+^VU+*BSK2QN[+ZR?HN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`BLJBVX,#H
MN/<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R("*_J,O^
MMOLB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@
M(E%U97)Y(@IM<V=S='(@(LK]OMV_XK+IT:\B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(E%U;W1A(@IM<V=S='(@(K^H
MR_ZV^R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(E)302"YJ[^JP]S4OR`H)60@SKLI(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(K6ET:$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B(*;7-G<W1R(")3<&%I
M;B`HSO>PX-'`*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"B,L(&9U>GIY
M"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`BRJ7"K,[WT<>UNB(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")2
M86EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS"B,L(&9U>GIY"FUS9VED(")286YD;VT@1F]R
M='5N92(*;7-G<W1R("++X\/\(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R("*QR,+*(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B
M"FUS9W-T<B`BML'(H2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(K;!
MR*'3RKS^(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(M7FM<32JLF^
ML_T@)7,@PO`_(-7BS^ZRV=?WO:O.WK>HN]:XM"XB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(M7FM<32
MJLF^L_T@)7,@PO`_(-7BS^ZRV=?WO:O.WK>HN]:XM"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O
M97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+(H<_[N+34K2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("++HM#"
MP\6[I\K3S;PZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`BN>;4\K'MM._*
MO2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E
M;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("*VP<BA(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS
M9W-T<B`BQL#"VR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G
M:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(M2VL\RW_L[QQO<B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("+4
MMK/,S?C6MR`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T
M<B`BR;ZS_2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM
M<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(LF^L_W'^+_I(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("+)OK/]T\.[IR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(LF^L_VV
MU"(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")2
M96UO=F4@<&%I<B(*;7-G<W1R("+)OK/]MM0B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`BU]2W_L[Q
MQO?4W;3FQ+_"O-;0R;ZS_=+1L:.TYK7$Q>36P[/,T/(N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L
M(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(LF^L_W3P[NG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(LF^L_W3P[NG
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("+)OK/]
MT\.[ISH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S
M.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B`B"FUS9W-T<B`BT.C'\\ZTL;O/[-.F.B"T[<[SNL7"
MZSHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U
M>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N(@IM<V=S='(@(LG/M*O.Q+S^LJ+.M+&[L:.TYBXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B)3(D<R"UQ,7DUL.QV-#KUKBVJ"`G)3$D<R<B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M5D93(+7$Q>36P['8T.O6N+:H("<E<R<B"@HC.B!F<F%M97=O<FLO571I;"]5
M=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(L7DUL/*_;[=L=C0Z]:XMJ@@)R5S)R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE
M;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@
M(E)E<V5T(@IM<V=S='(@(M;8R>@B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS
M9W-T<B`BP]S"ZR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W
M"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(LBWR,_#W,+K(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ
M>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(L_"S]+4PB(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S
M='(@(KWAN?LB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/
M<'1I;VYS(@IM<V=S='(@(K>UN]C1H<_N(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A
M<W-W;W)D(@IM<V=S='(@(M&AU/'#W,+K(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N("C!],3AS?JUNBDB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(K+ZR?H@)7,@M<3/M<VSQ>36PR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<R(*;7-G<W1R("*WM;O8T:'/[B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(RP@
M9G5Z>GD*;7-G:60@(E)I9VAT(@IM<V=S='(@(LWMR<\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PHC+"!F
M=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(K6MP+8B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED
M(")2;VQE(@IM<V=S='(@(KW'R:LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2
M;VUA;FEA(@IM<V=S='(@(E)O;6%N:6$@*,+>PNW$X=''*2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O
M=&%T92`Q.#`B"FUS9W-T<B`BT/W7JB`Q.#`@ML@B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@
M3&5F="(*;7-G<W1R("+/\M?ST/W7JB(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*
M;7-G<W1R("+/\M/2T/W7JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY
M"FUS9VED(")2=6QE<R(*;7-G<W1R("*]Q\FK(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B
MUK30T"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO
M;B(*;7-G<W1R(")2=7-S:6%N($9E9&5R871I;VX@*+;MPM[+N2DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A("C"K+"R
MM.\I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*
M;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R
M(")3+TU)344@O-/#W,>IP_LB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(M/*O/[2T<JYT\,@4R]-24U%(+S3P]PB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TP@T>G6I,[>
MT*<N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`IM<V=I9"`B
M4TU3($UE<W-A9VEN9R(*;7-G<W1R("+0Q<^B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`BROV^W;_BO<6Q
MOB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-1
M3"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S
M='(@(KS3P]S6U;;+N_HB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#
M15-3(@IM<V=S='(@(K/)N:8B"@HC.B!L:6(O87!I+G!H<#HQ-3,*(RP@9G5Z
M>GD*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`BROV^W;_BO<6QOB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G
M:60@(E-A(@IM<V=S='(@(M#'QMK!^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-A:6YT($AE;&5N82(*;7-G<W1R("+*I;K5P-7$P[6Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`BRJ6[
M^;7"NLW!T,ZLR[DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA
M(@IM<V=S='(@(LJEPJS.]]''M;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")3
M86EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(LJEQJ2PH[;[NLW"
M\[_+PM?(NK6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N
M="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`BRJ7.Q,FMS-BZS;CQP=;$
MR;3O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(LVLTKNX
M]K2PO]H@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM
M<V=S='(@(LCXQ*;1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`BRJ7"[<&FQ;4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`BRJ6VX,/`NLW&U<'6SO>Q
MR"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("+.P-#'S.&YJ=7?(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(LFSS-BP
MHL"MLJXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G
M:60@(E-A=F4B"FUS9W-T<B`BL:.TYB(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-A=F4@7"(E<UPB(@IM<V=S='(@(K&CM.8@)7,B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M("5S(@IM<V=S='(@(K&CM.8@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BL:.TYM&AS^XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(KVKLOK)^K7$Q>36P\[$O/[2U"!02%`@T^_1U+CQRKVQH[3FM;W$^K7$M_[.
M\<;WU-VTYL2_PKS6T"XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("+%Y-;#("5S(-+1L:.TYBXB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B
MN/S0PK/,T/+2T;&CM.:UO3H@)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM
M<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(LO1T;`B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"B,L(&9U>GIY"FUS9VED(")396%R8V@@
M16YG:6YE<R(*;7-G<W1R("++T=&P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDW,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S
M='(@(M&AU/'2N[CVR-7&VB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T
M<B`BT:'4\=*[N/;(U<;:(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("+1
MH=3QTKNX]M/#NZ?7Z=/#TM30PM3V(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@
M(M&AU/'2N\Z[T,*UQ-.UT]#5WR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(M&A
MU/'2N[*_M_[.\<;W(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(M&AU/'2
MN\Z[T\.[I]/#TM30PM3V(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"(*
M;7-G<W1R("+1H=3QTKNX]LC5QMHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C8S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB
M"FUS9W-T<B`BT:'4\<OYT]#(U<;:U^F\_BXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@86X@;V)J96-T(@IM<V=S='(@(M&AU/'2N\Z[T,*UQ-.UT]#5WR(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(M&AU/'2N\Z[
MT,*UQ-.UT]#5WR(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I
M9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(M/:TM3/PK7$M+"_
MVM;0T:'(H<3ZTJJUQ-?6M_LNTM3*\['JN+36QLOYT:'.Q-?6+,B[NO/,^<G/
MSL2\_K'@O*W'^"XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`BT:'4
M\<C5QMJWUKCT.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("+1H=3QR-7&
MVLC5QMJX\<J].B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS
M9W-T<B`BT:'4\<JQO.2WUKCT.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R
M("+1H=3QR-7&VLJQO.2X\<J].B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*
M;7-G<W1R("+1H=3QS^"[I<:EQ>2UQ+;^N/;7UK;.+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C
M:&5M92XB"FUS9W-T<B`BT:'4\<3ZM<31U<FKQ>36PR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93HB"FUS9W-T<B`BT:'4\<:KNL/3[]'4.B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(K2KR\W.RLSBM[33IB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD
M(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L
M(@IM<V=S='(@(E-E;F5G86P@*,C[Q-J\T[;[*2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("*TJ[C0QO<Z
M("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`BOL74PB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD
M($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEA(&%N9"!-;VYT96YE9W)O("C(
M^[;[SJS1Q]/KP\G,V,3AN.?"WBDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R
M("+0\KK%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC
M+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B365T87(@Q_B_Z<[>MZC*N=/#+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI
M;B(*;7-G<W1R("+(J,_>N=S`[2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E
M>'!I<F5D+B(*;7-G<W1R("*[X<;:($E$(-+1N?W&VBXB"@HC.B!L:6(O87!I
M+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(LBH
MS]XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3
M970B"FUS9W-T<B`BQ>36PR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"XB"FUS9W-T<B`BQ>36P]2VL\RW_L[QQO?)S\KTT]K$^K7$
MN/;(R]6^S*@N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED
M(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N(@IM<V=S='(@(L7DUL/$^K7$QJNZP]/OT=0L(,JQQ_C2
MU+RPR-7&VKCQRKTN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS
M9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S
M8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@
M;W!T:6]N<RXB"FUS9W-T<B`BQ>36P\3ZM<3&],J\TZ;3P[/,T/(LT=7)J\7D
MUL,LTK/#YKC\T,+&M<+*++RPQN3+_,_4RK[1H<_N+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(E-E='5P(@IM<V=S
M='(@(L7DUL,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M
M;#HS-PHC+"!F=7IZ>0IM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V
M86EL86)L92(*;7-G<W1R("*X_-#"L\S0\M+1L:.TYK6].B`G)7,G+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R
M86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM
M<V=S='(@(M/0NL.\N+CVM=BUX[K-U>*X]K+.ROW3T+G8.B`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL97,@
M*,C[SO2V^RDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS
M9VED(")3:&]P<&EN9R(*;7-G<W1R("*YNL[O(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS
M9W-T<B`BO/*VS-6JTJHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V
M"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\B"FUS9W-T<B`BRL>W\<ZJM/.RO[?=M<3!K+W3MJC2Y;_LO=VY
MIL3<O/P_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`BS]3*OB(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/R(*;7-G<W1R("+#O[3.M<?"O+KSS]3*OLG/TKNTSK7$
MM<?"O,JQO.0@/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*
M;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO
M=R!P:6-K97(B"FUS9W-T<B`BS]3*OK7CT:'&]R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M
M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/R(*;7-G<W1R("+3VM?SL=_/U,J^("5S(+++M:4_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S8S"B,L(&9U>GIY"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("+.Q+S^
MR<^TJR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4P"B,L(&9U>GIY"FUS9VED(")3:&]W97)S(@IM<V=S='(@(L_4RKXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0HC+"!F
M=7IZ>0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("*\\K;,U:K2JB(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS
M9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(LK5
MR_4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T
M.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4@
M*,JHU]/)O;GZ*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`BUZ*RX2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U
M<F4B"FUS9W-T<B`BQZG#^R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S
M='(@(L>IP_O1W<OC(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E
M(@IM<V=S='(@(E-I;F=A<&]R92`HT,*\T\;"*2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`BM//0H2(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R
M"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(L+4N?W.K+ND(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=F%K
M:6$@*,NYPN6WI;_+*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(E-L;W9E;FEA("C+N<+EMZ7$X=''*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"B,L(&9U>GIY"FUS9VED
M(")3;F]W(@IM<V=S='(@(L_4RKXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3
M:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I
M9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(KO]T:G)[K;(.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN
M('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L
M;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O;&]M;VX@27-L86YD<R`HR_?"WL/%
MR+JUNBDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@
M(E-O;6%L:6$@*,OWPNW`^]''*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E
M;&5C=&EO;B(*;7-G<W1R("+%Q<'0M[W/\M&AU/$B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+`M-2TM=C6MR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3;W5T:"!!9G)I
M8V$@*,3/M\<I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("+$S\6W("A)
M4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R
M"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(L3/L.O'\B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S
M"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I
M;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(L"LN_C3RKS^
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@P"B,L(&9U>GIY"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(E-P86EN
M("C.][#@T<`I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
M4W!A:6X@*,[WL.#1P"DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.3@*;7-G:60@(E-P86TB"FUS9W-T<B`BP*R[^-/*O/XB"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN
M<'5T(@IM<V=S='(@(LS8RN+7UK?[RN3(ZR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET
M(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P
M;W)T<R(*;7-G<W1R("+6I[/6(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@
M3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA("C+N<#OP+R_J"DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`BL>K7O"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B4W1A<B!4<F5K
M(@IM<V=S='(@(L;TRKS$ZK?=(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3
M=&%R="!Y96%R(@IM<V=S='(@(L;TRKS$ZK?=(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I
M;F-E(@IM<V=S='(@(LJA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("+7M,RL(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F
M;W)M870B"FUS9W-T<B`BL:.TYKCQRKTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`BO=:UP"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`BR;ZS
M_<_?(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B
M4W1R:6YG(&QI<W0B"FUS9W-T<B`BU]:W^[2NP=`B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-3
M72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("+0Q\;:S.PB"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("+5TK*[M;T@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+6]]:\(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@
M(LSAO;LB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S
M="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R
M:7!T(@IM<V=S='(@(L_"L>HB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BL\FY
MIB(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(K/)N::\T\CK("<E<R<@M;W/M<VSUM`N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(@IM<V=S='(@(K/)N:;7U,^US;/6T,F^L_T@)R5S)R`N
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(K/)N:;)OK/]("<E<R<@+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`BL\FYIM?4S[7-L];0R;ZS_2`G)7,G("XB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
MQ>36PR`E<R#2T;&CM.8N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(K/)N::X
M_-#"("<E<R<B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`BTM&SR;FFN+*XQR`E<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N("C+U;6D
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BU:K2JB(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T
M<B`BR-6S]B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B
M4W5N(%-E="(*;7-G<W1R("+(U<+D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E-U;FYY(@IM
M<V=S='(@(E-U9&%N("C+U;6D*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`BR-6S]B(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`BR-6S]B_(U<+D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B
M4W5N<FES93H@(@IM<V=S='(@(LC5L_8Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("+(U<+D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B
M4W5N<V5T.B`B"FUS9W-T<B`BR-7"Y#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B
M"FUS9W-T<B`BR<^QZB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`BUJ>SUB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86UE("C+U<#[Q,\I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G
M:60@(E-U<FYA;64B"FUS9W-T<B`BM,*ZQ2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@
M86YD($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R(")3=V%Z:6QA;F0@*,JWS=^\P\"\*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")3=V5D96X@*,CPM>0I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-W:71Z97)L
M86YD("C(\,J_*2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V
M"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(K*[
MR;ZS_2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y
M;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@
M4F5P=6)L:6,B"FUS9W-T<B`B4WER:6%N($%R86(@4F5P=6)L:6,@*-#PP/O1
MQRDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@
M5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS(@IM<V=S
M='(@(K2PS.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I
M;&4B"FUS9W-T<B`B5$%"(+?6N/2X\<J]SL2\_B(*"B,Z(&9R86UE=V]R:R]5
M22]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G
M<W1R(")496%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I
M9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`BS*C-Y2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL
M(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(LRHS>4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A:FEK:7-T86X@*,O^
MO*K+N<RY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9B`HS+G)T,3AT<<I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("+$
MO['J.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`BM/VP
M[,K"S^XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("*UY[NPNL7"ZR(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R("+7[KW\TKO0H<JQM<3.PK;(.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`BSL*VR"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`BSL*VR#H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T
M92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[M;W$H[#F("<E<R<N
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L2CL.:YW,#M(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(L3:R-TB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
MM+_.Q-?6(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B5&5X="!A;&EG;B(*;7-G
M<W1R("*TO\[$U]8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<Q"B,L(&9U>GIY"FUS9VED(")497AT=&]P(@IM<V=S='(@
M(L3:R-TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("+0Q\;:R\0B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T
M<B`BS*G.Q"`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I
M;&%N9"(*;7-G<W1R(")4:&%I;&%N9"`HS*FY^BDB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`BT+O0N\3ZRKG3P[&^S[7-LRXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1E10(-'3R>PH
M97AT96YS:6]N*<[>T*<N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ
M,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+B(*;7-G<W1R("+)S[2KSL2\_K*BSK2QN[&CM.8N(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(DUA:6YT96YA;F-E(,#@L?"RHLZTL\FYIM38R.LB"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`BT:'/
M[K2PO]K2U+G8L=4NP.N_JM;0+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*
M;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS
M9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T
M86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`BS:C1MLK]OMW2T;/)N::UQ-3VO-.UO<3ZM<3-J-&VLK[6T"[3
MP\KSL>JPM,_"P=#/[L2_TM2\[,K3.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@
M<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG
M;F5D(&UE<W-A9V4N(@IM<V=S='(@(M'IUJ33RKS^QZG#^]#HTJK3T-*[N/;2
MT;WBOZJUQ"!01U`@Q_B_Z2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,@HC+"!F=7IZ>0IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("*TR]?WT\/.M+&[UJ>SUBXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`BT.C2JM*[N/:^K;G]O-/#W+7$S?C"Y\&LO=,N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R
M("+.Q+S^("5S(-.FN,.P_+JLTKNX]B`E<R#%Y-;#+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(L[$O/X@)7,@
MTZ:XP[#\NJS2N]"I("5S(,7DUL,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")4:&4@9FEL92!C86X@;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`BM,O.Q+S^UM##N]/0
MROV^W2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@
M(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("*TR\[$O/[6
MT,.[T]#*_;[=+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@
M(M+4S\+*QR!R9F,X,C(@T\J\_K7$L>W-MRXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H
M870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@
M97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R
M(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF
M("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L
M>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@
M=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("*TR[?^SO'&]R!<(B5S7"(@TM&QN\F^L_TN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I
M9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B1VYU4$<@MO[4JL[$
MO/ZUQ,*WOK:QV-#KMJC2Y=3:($-R>7!T7W!G<#HZ(,#@L?#6T"XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S
M=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("*Q
MV-#KRL?2N[CVROW7UBXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U
M:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S
M='(@(DAO<F1E7T-R>7!T7W-M:6UE.CH@P."Q\"RQV-#HTJK3T"!O<&5N<W-L
M(,2CO^DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O
M=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H
M92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(K3+QJNZPR!<
M(B5S7"(@ROV^W=+RSJJSK+G]U^ZT\[W3RMS6M2S+^=+4SMZWJ+&[L:.TYB(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@
M=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`BT\/2U+SLRM.TR\K]OMW`X-#-("@E<RD@M<2S
MS-#RLJ*RN[3FU-K3VL^US;/)SRXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B
M5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R("*TR[?^SO'&]R!<(B5S7"(@TM&QN\F^L_TN
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N
M(@IM<V=S='(@(K3+M_[.\<;W(%PB)7-<(B#2T;&[L:.TYBXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(E
M<R"UQ->BLN'0Z,?STM&QN\F^L_TN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BUKBVJ+7$O,?"O+*BLKNTYM3:+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("+6N+:HM<2\Q\*\LJ*RN[3FU-HN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@
M=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T
M('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("*TT\G/TKNX]K*]
MUNC6KKKSR<^TJ[7$ROV^W=+%RJ<N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R
M"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M(@IM<V=S='(@(LG/M*O.Q+S^LJ+.M+&[L:.TYBXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H
M97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(G=E871H
M97(N8V]M(,?XO^G.WK>HRKG3PRXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BU=*RN[6]Q*.PYB`G
M)7,G+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"B,L
M(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N
M(@IM<V=S='(@(DUE=&%R(,?XO^G.WK>HRKG3PRXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N
M;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M("+.WKB]O/Z_R=:QO=.T\K^J+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N(@IM<V=S='(@(K3+U]:VSM;0L/RZK,RKMN"UQ-?6ROTNQ/K2T<KD
MR.L@)7,@N/;7ULK].\3ZRN3(Z[7$U];*_;'8T.O0H=/:("5S+B(*"B,Z('-I
M9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<
M(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("+0PM3V("<E<R<@M;W/M<VS
M.B`E<R#*L;>BR?K2N[CVSLK,XBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`BU]3/M<VSR;ZS_2`G)7,G(,JQMZ+)^M*[N/;.RLSB
M.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BU]3/M<VSR;ZS_2`G)7,G(,JQ
MMZ+)^M*[N/;.RLSB.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A
M=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(KC\T,(@)R5S)SH@)7,@RK&WHLGZ
MTKNX]L[*S.(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G
M<W1R("+)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB.B`E<R#.M+&[R<^TJRXB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`BR<^TJ\[$
MO/[*L;>BR?K2N[CVSLK,XCH@)7,@M//0H;.LN?V]T\K<U^ZT\]:U("@E9"!B
M>71E<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L
M;'D@=7!L;V%D960N(@IM<V=S='(@(LG/M*O.Q+S^RK&WHLGZTKNX]L[*S.(Z
M(+WVLK^WUK7$("5S(,[$O/ZQN\G/M*LN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B
MO.S*T]/*O/[*L;>BR?K2N[CVM.W.\RXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(KOCR.NT
MR\VHT;:ROLK]OMW*L;>BR?JT[<[S+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$O:6UC+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(KOC
MR.NTR\VHT;:ROLK]OMW*L;>BR?JT[<[S+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T
M:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A
M("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("+4VL7DUL.TL,SEUM"WHLGZ
MP<O2N[CVM.W.\R[3T+_)Q-S$^M+%PJG!R['8T.O,[M"TM<37UK;.+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@
M<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D
M971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("*[X\CK
MM,O-J-&VLK[*_;[=RK&WHLGZM.W.\RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@
M;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BN^/(Z[3+
MS:C1MK*^ROV^W<JQMZ+)^K3MSO,N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("*T
MRR!)34%0(+?^SO'&][*BSK36I[/6SL2\_KS0M];/[;FFQ-PN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB
M"FUS9W-T<B`BU>++QKKULKO*Q]7]R+>UQ"!R87(@T;G+]<[$O/XN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB
M"FUS9W-T<B`BU>++QKKULKO*Q]7]R+>UQ"!Z:7`@T;G+]<[$O/XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@
M(M7BR\:Z];*[RL?5_<BWM<30Q=/#OZBZQ<+K+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("*TR]?6ML[*Q['8T.C2JK7$
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B
MM,O7UK;.Q-K(W=:[O=/*W-7[ROW*_=?6+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(K3+U]:VSL3:
MR-W6N[W3RMS*_=?6O+##L+K%+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O
M8W1A;"!V86QU97,N(@IM<V=S='(@(K3+U]:VSL3:R-W6N[W3RMRPR[WXUL;*
M_=:U+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(K3+U]:VSL3:R-VQV-#KSJJV
MNKK%N_*_U;#7M]:X]+7$ROW7UB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+B(*;7-G<W1R("*QV-#KRL?2N[CVROW7UBXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@
M8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F
M;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(K3+U]:VSL3:R-VQ
MV-#KL/RZK-*[U^G*KL'YO?C6QK7$(%)'0B#1U<FKM/K"ZRS`_<CG("<C,3(S
M-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@
M(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T
M<B`BU>*X]K2PS.72T;&[M*;`[;G]+B(*"B,Z('1E;7!L871E<R]H96QP+V%B
M;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM
M<V=S='(@(M7BRL<@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B
M($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I
M;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T
M:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H
M(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*
M;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G
M<W1R("*TR\K]UK77[LG9L=C0Z\K'(#$N(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B
MM,NW_L[QQO?.WK>HMM0@>FEP(+RP(&=Z:7`@N/'*O<[$O/Z]^-#0O>+1N<OU
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*
M;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB
M"FUS9W-T<B`BM,O/M<VSM;''L,K'S:/3P[7$U[3,K"XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("*QV-#KRL?2N[CVROW7UBXB"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W(@IM<V=S='(@(K3+M+"_VK'8T.O2JM/)T:'/[K2PO]HH3W!T:6]N*<OY
MNO2]T"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,S0*(RP@9G5Z>GD*;7-G:60@(E1I8VME=',B"FUS
M9W-T<B`BO\V[I[FDU_>UI2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4
M:6UE(@IM<V=S='(@(LJQO.0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(LJQO.37M]?9
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA
M="(*;7-G<W1R("+*L;SDN/'*O2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(LJQQ_C1
MH=3Q(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T
M<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED
M(")4:71L92(*;7-G<W1R("*QZLSB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("+*U;S^R,LB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED
M("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L
M:6-K:6YG+B(*;7-G<W1R("(B"B+(Y[G[TJJXM-&A+,?KU-JUX]&ARO.QZK7$
MS:S*L;"T($-O;G1R;VR\_"BX]LC+O,;+X[OZ*2"[\B!#;VUM86YDO/PHQKNY
M^[S&R^,B"B*[^BDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`BO?',["(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L
M92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,(-2MRKS.Q+S^(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R("*VX+CG(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("+-T+_+P,W(NK6Z(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R
M;W<B"FUS9W-T<B`BP_?,["(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A
M(@IM<V=S='(@(LS`O-,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(RP@9G5Z>GD*;7-G:60@(E1O<"(*;7-G
M<W1R("+*U;S^R,LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(M?IUJ\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(LS8P:+$X;3O
MNLVVX+#-N.<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS
M9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(M7FN_*\V2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U
M(@IM<V=S='(@(M#'QMJV_B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES
M:6$B"FUS9W-T<B`BS;O$X<NY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R
M:V5Y(@IM<V=S='(@(LW!MOK&Y"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R("+-P;;Z
MQN3.Q"`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K
M;65N:7-T86XB"FUS9W-T<B`BS<&_XL+\R[G,N2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("+,V+_+
MR[FZS;^MO\;+N<BZM;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B
M"FUS9W-T<B`BS;S-W\*L(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V
M-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(LKDR.O$^K7$
MT:'4\3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM
M<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(M?/S>+/W]:XROTZ("(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R("+-^-:W
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(LWX
MUK<Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(L[:
MN,FT[R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B
MSMJ_R\"\(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"FUS
M9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(L[>MZBTYLBA(%9&4R#$O\*\+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R
M(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`BUZ*RX<JQ
MSMZWJ-3VO-.V[LWBM<33P[NGT,7/HBXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`BSMZWJ+C$L>0@5D93(,[$O/X@7"(E<UPB(+7$R*C/WBXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R
M("+.WK>HL>2X_"!61E,@SL2\_B`E<R\E<R"UQ,BHS]XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`BSMZWJ+'DN/S.JB`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S7"(N(@IM<V=S='(@(L[>MZBT\K^J(%9&4R#.Q+S^(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G
M<W1R("+.WK>HL>2X_"!61E,@SL2\_B`E<R\E<R"UQ,/[L\8N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`BSMZWJ,&LO=/6P2!3
M44P@M_[.\<;W+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B
MSMZWJ,JYT\,@4U-,(,&LO=,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N(@IM<V=S='(@(L[>MZBXM-;&(%9&4R#.Q+S^+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(L[>MZB]J,&B(%9&4R#$O\*\(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(L[>MZB]J,&B(%9&4R#$O\*\+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M(@IM<V=S='(@(L[>MZB]J,&B(%9&4R#.Q+S^+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("+.WK>HL>2X_"!61E,@SL2\_B!<(B5S7"(@M<3#^[/&+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`BSMZWJ+VH
MP:(@5D93(,[$O/XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z
M:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*
M;7-G<W1R("+.WK>HO:O*_;[=O>+1N<OU+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@
M(L[>MZC)OK/]("5S++3+Q+_"O+*BM\>_U;#7(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N
M(@IM<V=S='(@(L[>MZC)OK/]("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DB"FUS9W-T<B`BSMZWJ,F^L_T@)7,LM,O$O\*\LJ*WQ[_5L-<B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B
MSMZWJ+7=N>G)OK/]Q+_"O"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@Q+_"O"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@Q+_"
MO#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(L[>MZC)OK/](%9&4R#.Q+S^(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@SL2\_BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T
M<B`BSMZWJ,F^L_T@5D93(,[$O/X@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`BSMZW
MJ+7=N>G)OK/](%9&4SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN(@IM<V=S='(@(L[>MZC%T+;/M;''L+7$Q+_"O"XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA
M8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("+.
MWK>HO>*_JL:^UJ3/N+W:(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N
M<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N(@IM<V=S='(@(L[>MZB\T]38("5S(+7$MJC2Y<K]OMTN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R
M("+.WK>HTL:VKR!61E,@SL2\_BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.WK>HM/*_JB!61E,@SL2\
M_B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(L[>MZC0M,CK
M(%9&4R#.Q+S^+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HM/*_JB!61E,@SL2\_BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(L[>
MMZBT\K^JT;G+]<[$O/XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S
M-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`BSMZWJ+'DN/P@5D93(,[$O/X@
M7"(E<UPB(+7$P_NSQBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T
M1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("+.WK>HT+3(ZR!61E,@SL2\
M_LK]OMTN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!F:6QE.B`B"FUS9W-T<B`BSMZWJ+'DN/P@5D93(,[$O/ZUQ,/[L\8N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@
M(L[>MZBVP<BA('9F<W)O;W0@Q+_"O"XB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BSMZWJ+'DN/P@5D93(,2_PKRUQ,/[L\8N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS
M9W-T<B`BSMZWJ,F^L_T@5D93(,2_PKPZ("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B!<(B5S
M7"(@M<3#^[/&+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q
M,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(L[>MZBQY+C\(%9&4R#.Q+S^("5S+R5S(+7$P_NSQBXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@
MSL2\_K7$P_NSQBXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("+.WK>HL>2X_,ZJ("5S+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G
M:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM
M<V=S='(@(L[>MZC7JKN[(%=O<F0@SL2\_B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(L[>MZC0M,CK(%9&4R!<(B5S7"(@SL2\_BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN(@IM<V=S='(@(L[>MZC0M,CK(%9&4R#.Q+S^ROV^W2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB"FUS9W-T<B`BSMZWJ-"TR.L@5D93(,[$O/[*_;[=+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX-#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS
M9W-T<B`BSMZWJ-"TR.L@5D93(,[$O/[*_;[=+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN
M92(*;7-G<W1R("+/PKNNS]\B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`BR*'/^[C\N,0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS
M9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("*XM-2M(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B`B"FUS9W-T<B`BM_[.\<;WP:R]T\JQMZ+)^LZTU*3&VK7$N]C3ICH@
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED
M(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T
M<B`BMZ+)^LZTU*3&VK7$N]C3IBS3R;?^SO'&]SH@(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*(RP@9G5Z>GD*
M;7-G:60@(E5N9FEL960B"FUS9W-T<B`BRJ>PW"(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B
MS?+3P\+K("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R
M86(@16UI<F%T97,B"FUS9W-T<B`BL*+`K;*NP:JZS\?ULZ2Y^B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`BTZ*Y^B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B
MP\"Y^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI
M=',B"FUS9W-T<B`BM:74JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*
M;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`BSK36JK7$(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("+.N];#T,7/HLG0SK3%Y-;#(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("+.M-:JM<33
MP[NGP_N[\L/<PNLN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G
M<W1R("+.M,/\P_LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@(E5N<V5T(&-O
M;&]R(@IM<V=S='(@(M?6T,W1U<FK(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY
M,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("+.M-:G
ML]:UQ,"IU;G#^R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5
M<&1A=&4B"FUS9W-T<B`BL>2X_"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S
M(@IM<V=S='(@(KC\T,(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("*X_-#"
MT\.[IR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T
M<B`BTM&X_-#"("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(KC\
MT,*SS-#RTM')OK/]+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I
M9"`B57!L;V%D(@IM<V=S='(@(LG/M*LB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`BTM')S[2KR_G3T-.F
MT\.SS-#RM<3%Y-;#SL2\_K6]M_[.\<;W+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P
M<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B
M57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(L[:P*VYYR(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B
MM;''L,_@SKLB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L
M(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(M/#NZ<B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS
M9W-T<B`BT\.[IR`E<R#.M,VHN?T@)7,@M<3*VLBHT>G6I"XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`BT\.[I[G<P.TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(M/#NZ?1H<_N
M(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB
M"FUS9W-T<B`BT\.[I]>BLN$B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+B(*;7-G<W1R("*TR]6^S*BUQ-/#NZ?7HK+AS[7-L]+1S:/3PRXB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"B,L(&9U>GIY"FUS9VED(")5
M<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(M72LKNUO2`E<RXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("+3
MP[NGP_LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(M/#NZ?#^R`G)7,G(-+1M.;4VBXB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S
M97)N86UE.B(*;7-G<W1R("+3P[NGP_LZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("+3P[NG
M.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED
M(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("+/M<VSUM"UQ-/#NZ<Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("+.
MVM?(L?"_R\NYS+DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")61E,@Q+_"O+*B
MLKNTYM3:+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G
M:60@(E9A8V%T:6]N(@IM<V=S='(@(KS9QMHB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B`B"FUS9W-T<B`BTM'5TK6]T]#0I[7$M=BUXSH@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED
M:71Y(@IM<V=S='(@(M/0T*?0U"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`BTM2WUM;3SJJUI<Z[*+33S];4
MVL;PR^,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B
M5F%L=65S(@IM<V=S='(@(M:U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")6
M86QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("+-W\*SL*+-O"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM
M<V=S='(@(K'DNZ\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B
M"FUS9W-T<B`BSJ_$VLCPP*TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(M'IUJ3*I[#<("T@M,O3RKS^O\G$W-+1U.+(R\G#U]2TV[C$+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")6
M97)S:6]N(@IM<V=S='(@(K#FL;XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`BL.:Q
MOK_8UL8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T
M"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E
M<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(M2]Q,\B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S
M92`H5DE30TE)*2(*;7-G<W1R("+4O<3/SL0@*%9)4T-)22DB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("*\[,K3("5S(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@
M<&%G92(*;7-G<W1R("+4VM#"M+"_VK3ROZHB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R!A<R`E<R(*;7-G<W1R("+2U"`E<R"RZ;^T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`BTZ+*
M],ZLMON^J<BZM;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@52Y3+B(*;7-G<W1R("+#P,KTSJR^J<BZM;HB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("+$
MW+S[ML@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS
M9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`BQ-R\^[;(.B`B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM
M<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`BTN*T\\#[
MM_RUPK?GM>?0Q;FKR[[-N+G](%--5%`B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS
M9VED(")705).(@IM<V=S='(@(KZON.8B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`BOJ^XYB$A
M(2"TTR`E<R#*UK:OR;ZS_;/,T/(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R("+-W\#[R[FZS;B[S;S(NK6Z(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S
M='(@(KZON.8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("+0Q\;:R/TB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R
M96-A<W0B"FUS9W-T<B`BS.S&^-2DLN(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@
M8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR
M"B,L(&9U>GIY"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R
M+F-O;2#-^-6^(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@
M(E=E8B(*;7-G<W1R("+-^-6^(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`BS?C5OB(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@
M(E=E96ML>2(*;7-G<W1R("+#O];<(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`BN[;3K2(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O
M("5S(@IM<V=S='(@(KNVTZVUO2`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M
M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R("*[MM.M+"`E
M<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N
M("A)4T\M.#@U.2TQ*2(*;7-G<W1R("+.]\6W("A)4T\M.#@U.2TQ*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M
M.#@U.2TQ-2DB"FUS9W-T<B`BSO?%MR`H25-/+3@X-3DM,34I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(L[WR/:Y_L"M
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/R(*;7-G<W1R("*UQ\*\NO/3IKC#S\C/U,J^("5S(,3$TKNX
M]M.FT\.SS-#R/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T
M"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G
M<W1R("+7UK;.M<2WUKCTU]:W^S\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/R(*;7-G<W1R("+2_<KVM<3'L+6\M_L_(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*(RP@9G5Z>GD*;7-G:60@(E=H
M97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("*PQ+3SP/O1QR(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@B"FUS
M9W-T<B`BM^?+V3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U
M"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F
M('1H92!T86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@
M=6YI="(*;7-G<W1R("+!HLS5S?`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-0HC+"!F=7IZ>0IM<V=I9"`B5VED=&@Z
M(@IM<V=S='(@(K?GR]DZ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7:6YD(@IM<V=S='(@(K?G
MR]DZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C8*(RP@9G5Z>GD*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`BM^?+V3H@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E
M9"!I;B!K;F]T<R(*;7-G<W1R("*WY\O9*+W:*2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R("*WY\O9.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z
M("(*;7-G<W1R("*WY\O9.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3DV"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES="(*;7-G
M<W1R("+&VK3]S^[$OR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM
M<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G
M<W1R("*P[+FKRM*UV-:W(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("*P
M[+FKRM*UY[NP(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@
M=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("+(J,_>LKO7XRS.
MWK>HO:C!HB!61E,@SL2\_BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y
M(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M6#4P.78S(,"IU;G#^R(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")962(*;7-G<W1R("+$ZB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*;7-G<W1R("+$ZB(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS
M9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O("$@M=C-O"(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@
M(EEE87)L>2(*;7-G<W1R("+#O\3J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M665M96XB"FUS9W-T<B`BTK+#Q2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(LK'M<0LSM+-K-+B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I
M9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(L3ZM;''L,JY
MT\.TO\[$U]:QX-"TQ*/*O2X@RKG3PR!;/#Y=(+"TQ:6_R<?0N[O.JLWXTK.Q
MX-"TQ*/*O2XB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A
M=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T
M:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("+$^K*BSK3*Y,CKTKNX
M]KK/MZBUQ+7GU]/3RKS^M=C6MRXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`BQ/JRHLZT
MT\FUO,CKM<3.Q+S^UM"VU-.SR,ZZSM?6MLZUO2`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+B(*;7-G<W1R("+$^M+1OJW7HL_Z+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A
M;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI
M;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+B(*;7-G<W1R("+$^K'8T.O*Y,CKTKNX]KK/MZBUQ-:U+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RXB"FUS9W-T<B`BQ/JQV-#KS\BYYKNNNL/*_;[=RO<H1&%T851R964IM_[.
M\;;+LL7$W+S,T/C*N=/#T,+3P[NGUZ*RX;?^SO$N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HT-38*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("+$^K'8T.O/R+GF
MNZZZP\K]OMW*]RA$871A5')E92FW_L[QMLNRQ<3<O,S0^,JYT\,@2&]R9&4N
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@
M(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("+'Z\/HRO;.RLSB
MHZS4VL3ZM*O+S<[*S.*QJ+CFUJ['L"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B
MQ/JQV-#KRN3(Z[3+P:R]T\OYUKC/\K7$S?C6MR(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(L?KUKBVJ-*JR;ZS_;7$
MM_[.\<;W+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB
M"FUS9W-T<B`BQ^O6N+:HTJK)OK/]M<33P[NG+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(')E;6]V92XB"FUS9W-T<B`BQ^O6N+:HTJK)OK/]M<33P[NG+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+B(*;7-G<W1R("+'Z]:XMJC2JM#"U/:UQ-/#NZ<N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(L?KUKBVJ-*JN/S0PK7$T\.[IRXB
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2XB"FUS9W-T<B`BQ^O6N+:HTJK6M-#0M<37]]/#+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM
M<V=S='(@(L?KUKBVJ-*JR;ZS_;7$T\.[IRXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(L3ZM<0@)7,@N^'&VM+1N?W*
ML2['Z];8T,*UQ\*\+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`BQ/JU
MQ+7GU]/3RKS^M=C6MR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B
MQ/JUQ+7GU]/3RKS^M=C6MR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U
M<B!);F9O<FUA=&EO;B(*;7-G<W1R("+$^K7$T,7/HB(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M(M?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<32\LS8S?BUV-:WTM&QY+C\
M+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8T,(B"B*UQ\*\+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`BQ/JUQ-#5P_LB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S
M97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E
M<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB
M875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`BQ/JUQ-'IUJ2VR[*B
MSK36I[/6T,+4]M/#NZ>[\KC#N:;$W-+1L;NYV+'5+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("+$^K7$T>G6I+;+LJ+.M-:G
ML];!T+/VT\.[I[ORN,.YIL3<TM&QN[G8L=4N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB
MU]2TT\3ZM<0@)7,@N^'&VK^JRKS2U,"TQ/JUQ.2OP,#&]\O&NO72T;'DN/PN
M(,ZJL:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQV-#KUMC0PB(*(K7'PKPN(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`BQ/JUQ.2O
MP,#&][*BSK36I[/6U>*X]KFFQ-PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("+$^K7$
MY*_`P,;WLJ+.M-:GL]:T\M.AT:'/[B['Z["T($-44DPK4"#2U+3RTZ$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R
M96YT('1I;64@>F]N93HB"FUS9W-T<B`BQ/JUL<>PR_G%Y-;#M<3*L<?X.B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@
M(L3ZM<31H<_NTM&X_-#"+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS
M9W-T<B`BQ*S(S\GMM]W*MK'P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@
M(L3ZM<30U</[(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T
M<B`BQ/JUQ-&AS^[2T;C\T,(N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI
M<R!S97-S:6]N+B(*;7-G<W1R("+$^K7$T:'/[M+1N/S0PBXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("+$^K7$T:'/[M+1N/S0
MPBXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V
M97)S.B(*;7-G<W1R("+$^K7$U+:SS+?^SO'&]SHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(L3/R[G`K;?R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I
M<F4B"FUS9W-T<B`BU/K2P;;[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M
M8FEA(@IM<V=S='(@(M3>L<C1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII
M;6)A8G=E(@IM<V=S='(@(KWRL,VRO,ZD(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS
M9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS
M9W-T<B`B6\[*S.*QJ+CF72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG
M:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EO.N]/:T-`@)7,@N;(@)7,@
MT-!=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E]!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("*YW,#M(@H*(SH@;&EB+V%P:2YP:'`Z,34W
M"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0HC
M+"!F=7IZ>0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(LK]OMTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S$*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(LF^L_TB
M"@HC.B!L:6(O87!I+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E]'<F]U<',B
M"FUS9W-T<B`BT\.[I]?I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BL._6
M^B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC
M+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("*UQ\*\(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I
M9"`B7TQO9R!O=70B"FUS9W-T<B`BUZ+/^B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM
M<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(K+ER.LOL>2X_,WXPN?!
MK+W3(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`HC
M+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`BT:'/[B(*"B,Z(&QI
M8B]A<&DN<&AP.C$S-PHC+"!F=7IZ>0IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM
M<V=S='(@(LBHS]XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@
M3&EN:RXN+B(*;7-G<W1R("+)OK/]MM0B"@HC.B!L:6(O87!I+G!H<#HQ,C4*
M(RP@9G5Z>GD*;7-G:60@(E]3971U<"(*;7-G<W1R("+%Y-;#(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S
M"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(E]5<V5R<R(*;7-G<W1R
M("+3P[NG(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@
M9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+-J-&VLKXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B
M861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM
M<V=S='(@(LC5P/HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B8V%L;2(*;7-G<W1R("+!X[RVM^<B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR
M"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(F-O;F9I9W5R871I
M;VX@97)R;W(B"FUS9W-T<B`BQ>36PR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X
M,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(M72
MLKNUO2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R("+.
MQ+S^(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R
M("*TTR`E<R`H)7,I(-/:("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R
M("(L(-7SM^<@)7,@)7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("+*L3HB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED
M(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`BP:*\M"(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<Y"B,L(&9U>GIY"FUS9VED(")I;FQI;F4B"FUS9W-T<B`BS\*[KL_?(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@
M(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F
M='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(FQI;F5S72(*
M;7-G<W1R("*WUB(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V
M.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W
M,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N
M86UE(@IM<V=S='(@(L/[L\8B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z
M,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`BR=#.M,JUS]8N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS
M9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(LG0SK3*M<_6+B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E
M<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*(RP@
M9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(K3FR*'4
MXK[<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G)I
M<VEN9R(*;7-G<W1R("+(J,_>(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I
M;&%B;&4B"FUS9W-T<B`B365T87(@Q_B_Z<[>MZC*N=/#+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B<W1E
M861Y(@IM<V=S='(@(K;!R*$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS
M9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,CD*(RP@9G5Z>GD*;7-G:60@(G1A<VL@;&ES="(*
M;7-G<W1R("+7UK?[M*[!T"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ
M>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(L._M,ZUQ\*\(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER
M;2(*;7-G<W1R("+4V;3.RN3(Z\3ZM<3#W,+KTM3(M\C/SM[.\R(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y
M"B,L(&9U>GIY"FUS9VED(")U;FEF:65D(@IM<V=S='(@(LJGL-PB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D
M(@IM<V=S='(@(LZTP_S#^R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B
M"FUS9W-T<B`BT\.[I]&AU/$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T
M,0IM<V=I9"`B=SHB"FUS9W-T<B`BT,?&VCHB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B
M=V5A=&AE<BYC;VT@S?C5OB(*````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+WIH7U17+G!O````````````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V-#`T,C,`
M,3`T,3<S-C,P,#,`,#$V-#,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@2&]R9&4@5')A9&ET:6]N86P@0VAI;F5S92!4
M<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@1&%V:60@0VAA;F<N
M(+%IJ'VDY2RE>,97"B,@1&%V:60@0VAA;F<@/&1A=FED0'1M=BYG;W8N='<^
M+"`R,#`Q+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#8M,#$M,#4@,34Z,#0K,#@P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,2TQ,BTR,"`Q,CHP,"LP.#`P7&XB"B),87-T+51R86YS;&%T;W(Z($1A=FED
M($-H86YG(#QD879I9$!T;78N9V]V+G1W/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M5')A9&ET:6]N86P@0VAI;F5S92`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB
M"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/4))1S5<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#@M8FET7&XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S
M(*31JV4I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S<T"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@**?6L;;!Y"`E<RDB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,X,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H)7,@I-&DNBDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B("BDM:31*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Y"FUS9VED
M("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@**GZI-$I(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@
M**Q1I-$I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`BJ?,B
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B"D
MHZQ/I$"MTZ78O_TB"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB
M"FUS9W-T<B`B7"(E<UPB(*2CK$^D0*W3IK.NQ*JZO^^^W"XB"@HC.B!L:6(O
M2&]R9&4O4F5G:7-T<GDN<&AP.C8U,B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$P-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB
M(*E\I;RF8B!(3U)$12"JNK7YI57`R2A296=I<W1R>2FDI+-=J7<N(@H*(SH@
M;&EB+TAO<F1E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H
M["!<(B5S7"(@=')E92!R96YD97)E<BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(J1WIJBE7*JZI5ND
M2JCLN'.RU:ATLLZDI"XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")<(B5S7"*D=Z5;I$K%
M=JVMJ'2RSBXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPBJ,.EO*O8I=\Z
M("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*2(*;7-G<W1R("*D=ZC/I<X@)2XR9DU"("RN9;9Q("4N,F9-0B`LL]&^
M;"`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@
M(B5D("5S(*5(I,X@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR
M-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS
M9W-T<B`BL\RJ\:1`IKBQ2[U8Q=RG\ZGS("5D(*31JV4N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`BL\RJ\2`E9""DT:[PMDBY=[/X
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@L\:GT;_](@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@J_ROOB(*"B,Z
M(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#`@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+
M0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(+K[Q4"^WJ=`("T@
MO52[>R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U
M<"(*;7-G<W1R("(E<R"S7:EW(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G
M<W1R("(E<R"U^:55(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*
M;7-G<W1R("(E<R"F4+=.MK6EV"(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT,S(@
M;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O5D93+V9T<"YP:'`Z-C<Q"B,Z(&QI
M8B]61E,O9G1P+G!H<#HW,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(*1WIG.F8B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(*9B("5S("5S(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92XB"FUS9W-T<B`B)7,@I'>T3J15ID.HQK:UJKJZ^\5`OMZG0+1.NOPN(+W0
MJ?.FN:[)I,2_[Z=!MU&M;K[>IT"JNK:UI=@N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`BI;*[W:UN("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R
M("(E<R"DP"(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("*GY*2CJ.P@)7,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G
M<W1R("(@)7,@J.P@)7,@ID`@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDR,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*
M;7-G<W1R("(E<ZJZLW&P5+_](@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M("(E<ZJZIN:HQK[D(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5SJKJS
MQJ?1O_TB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5SJKJKW;_LPZ\B
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S
M.B`E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@
M;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F
M;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T
M:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G
M<W1R("(B"B(E<SH@LV^KRJM(I?.DHZ1`J7>O=:71JTBDI*JZL4BE\Z1(J=*Q
M2+5O+B"]T*I@MTZD5:9#J=*FLZJZNO2X]+-SM;*FLZ5IK^"LJKI\(@HBIT&J
MNJW3I$BXZJ[&+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G
M=7-T:6YG("(*;7-G<W1R("(L(+!]K;<@(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@L'VMMR`E<R`E
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(LQ=RD
MQK9QL7$@)7,@J.P@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C$S,B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,T."!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0U"FUS9VED("(M+2!S96QE8W0@
M+2TB"FUS9W-T<B`B+2T@O^^^W"`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B,3(@I'"NR:CN
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O
M<FUA="(*;7-G<W1R("(R-""D<*[)J.XB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@I'"NR:CN
M(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I
M;W5S(@IM<V=S='(@(J17I$"MMB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R
M('1H:7,@8FQO8VLN(@IM<V=S='(@(J:YL,^V]*6RMK>M;JO\J7>XZJ[&KG>F
M^*I!NMTN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C(*;7-G:60@(D$@9F%T86P@
M97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(K5OI<VD1J1`K=/$6:VKJKJ_
M^;M^(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R("*Q_:5;L4NV;*7S+,'9N]VM;J:SI$"MTR!01U`@I+VV
M?:KWQE\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I
M9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S
M:6=N960@;65S<V%G92XB"FUS9W-T<B`BL?W%Y\/2I'?#L;.YJKJV;*7S+,'9
MN]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(K']N-&Q2[9LI?,LP=F[
MW:UNIK.D0*W3I+VV?2!01U`@JO?&7RRH<+%+(%!'4""J]\9?+*5(I,ZS<</V
MI&:E3RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`BL?VP]:;FMFRE\\.QL[DLP=F[W:UNIK.D0*W3I+VV?2!01U`@
MJO?&7RRH<+%+(%!'4""J]\9?+*5(I,ZS<</VI&:E3RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(K']N-&Q2[9LI?,LP=F[W:UNIK.D0*W3I+VV?2!334E-12"J]\9?+*APL4L@
M4TU)344@JO?&7RRE2*3.LW'#]J1FI4\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B*Q_;#UIN:V
M;*7SP[&SN2S!V;O=K6ZFLZ1`K=.DO;9](%,O34E-12"J]\9?+*APL4L@4R]-
M24U%(*KWQE\LI4BDSK-QP_:D9J5/+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(K']I5NQ2[9L
MI?,LP=F[W:UNIK.D0*W3(%--24U%(*2]MGVJ]\9?+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D
M<R(*;7-G<W1R("*DR*MEIK.VLR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S
M='(@(J3(JV6D<*M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`BI,BK9::SJT(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM
M<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("*DR*MEL'VK0B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`BI,BK9;!]L[<B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`BI,BK92^D
MR*OA(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*
M;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@O7.XN2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T
M('1H:7,@961I=&]R(@IM<V=S='(@(L/VJ?.S;ZW3O7._Z+ZY(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S
M='(@(L/VJ?,N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`BI;^D5:3H
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(J6_I*2EH2(*"B,Z(&QI8B]6
M1E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+%=JVMI*.HK"RU3*IKJ]BEWR!6
M1E,@I=B__2XB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(L5VK:VD
MHZBL++5,JFNKV*7?(%9&4R#`R:[7+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(K%B
MN+FXZK!4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!
M8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(K%BN+F[4+%+O5@B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(K%BN+FD=ZWAM;(N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R
M("*ULK%B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA
M=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`BMW.\5R(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U
M"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`BMW.\5Z:XN'.RU2(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T
M<B`BMW.\5Z1LQ7:MK2(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU
M"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`BIF*FN;=SO%<Z(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@
M(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`BMW.\5[ASLM4B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@W(&QI8B](;W)D92]097)M<R]522YP:'`Z.#@*
M;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("*W<[Q7Q7:MK2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB
M(@IM<V=S='(@(K=SO%>FN+ASLM6H["!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("*W<[Q7IKC%=JVM
MIMQ<(B5S7"(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@
M;F5W('5S97(Z(@IM<V=S='(@(K=SO%>D0*W3J,^ESJK,.B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU-3,*;7-G:60@(D%D9"!C
M;VQU;6XB"FUS9W-T<B`BMW.\5\3FINPB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS
M9W-T<B`BMW.\5Z1`K=.FJ*W[.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(K=SO%>Y[R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S
M='(@(K=SO%<@)7,@K+`@36]Z:6QL82"JNJ3`K;8B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R("*W<[Q7J.RJNK-QL%2__3HB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@
M861D<F5S<R!B;V]K(@IM<V=S='(@(K=SO%>H[*?:JKJS<;!4O_TB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BMW.\
M5ZC/I<ZJS"(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB
M)7,N(@IM<V=S='(@(J1WMW.\5R!<(B5S7"(@J.RH=++.I*0N(*;]M4RJ:[=S
MO%?#0J5^JKJU^:55N.JP5#H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("*D=[=SO%<@7"(E<UPB(*CL
MJ'2RSJ2D+B"G0;)[IF*E::5(MFFFYK5NI$JD1BXB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R("*W<[Q7J,^ESJK,JKJE7*_@I=BK9;-1P_:S
MK"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-2!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S<R(*;7-G<W1R("*F8:=]
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(K-QL%2__2(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`BIJBLL+K>LGJM
M^R`M(*RPJ.2E3*C/I<ZJS+-=J7?%=JVM(@H*(SH@861M:6XO:6YD97@N<&AP
M.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(KK>LGHB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T<B`BO'.G:2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G
M:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9VAA;FES=&%N("BJ_+1)IKTI
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A;FEA("BJ_+JXI-JEIZC(
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QG97)I82`HJORZN*3.IU&H
MR"DB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM
M<V=I9"`B06QI87,B"FUS9W-T<B`BMFRE\Z=/IE<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!
M;&EG;B(*;7-G<W1R("*Y[[OT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R
M("*Y[[OTI.BFH3HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G
M:60@(D%L;"(*;7-G<W1R("*ITJ:S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B
M06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`BJ=*FLZ1WQ>?#TJJZ
MJ,^ESJK,(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N
M<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("*ITJ:SN'.RU2(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS
M+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(JG2IK/%=JVM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`BI7ZNV+UU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S4*;7-G
M:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("*DN;-<IFZT
M6*W3N7&D;+9LI?.F8:=](@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S
M.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B
M"FUS9W-T<B`BI+FS7,7<I_.VM:78O7.XN:JZJZRZ03\B"@HC.B!L:6(O2&]R
M9&4O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(J1WIG.F8B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(L7<I_,@
M24U34""U;J1*(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I
M9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`BQ=RG\R!)35-0
M(+%+O5@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!
M;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("+%W*?S($E-4U`@J,^E
MSJK,(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@
M(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(L7<I_.Y<:1LMFRE
M\Z;MIWTB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT
M97)N871E('1E;7!L871E<R(*;7-G<W1R("+%W*?SO,NJ3R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(K3`I4ZDY:9R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE<FEC86X@4V%M;V$@
M**S\Q%*P[<+$O*^HR"DB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.CDU
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(J1`K=.U3*[$JKJMR+-1
MJ,^ESBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS
M9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("*U
M;Z7-I$:D0*W3I;RJOJJZO_F[?BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@
M(D%N9&]R<F$@**9WN42FU2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG
M;VQA("BF=ZWTJ=0I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL
M;&$@**9WIF.IU*YQ*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(K#.IE>E3K)ZIG.H
M^B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!
M;G-W97(B"FUS9W-T<B`BM:JNUR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B06YT87)C=&EC82`HJVZWI:1JL[`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@
M0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&%N9"!"87)B=61A("BF=[2CI<JN
M<:3.I-JZN*6LN4:N<2DB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@
M(D%P<&QI8V%T:6]N(@IM<V=S='(@(L"SI<ZU>Z:A(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S
M='(@(L"SI<ZU>Z:ALDVSYB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("+`LZ7.
MM7NFH:1WM$ZZ_"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X
M"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`BKDVESJCL
MJ=*FLZJZIKBF0*C)(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`BI^6MXR(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#`*;7-G:60@(D%P<')O>&EM
M871E(%-I>F4B"FUS9W-T<B`BN7>F]*1JI'`B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`BI7RDZR(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Q"FUS9VED(")!<F%B:6,@*%=I
M;F1O=W,M,3(U-BDB"FUS9W-T<B`BJORIU*="I.4@*%=I;F1O=W,M,3(U-BDB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.2!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS
M9W-T<B`BP*/!6<#)I&JD<"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C4X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H
M:79E($YA;64B"FUS9W-T<B`BP*/!6<#)IE>ZV2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`BIT&]5*EWK6ZG4K"C("5S
M(*JZM?FE5;;<(#\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM
M<V=S='(@(J=!O52I=ZUNIU*PHR!<(B5S7"(@I4BDSJ7TIO.JNJ:XN'.RU2`_
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN82`HJORNVJ?*
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)M96YI82`HJ,BL_*6GJ,@I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S(*;7-G:60@(D%R;65N:6%N
M("A!4DU30TE)+3@I(@IM<V=S='(@(JC(K/REIZC(I.4@*$%235-#24DM."DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G
M<W1R("+#P+-.(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$@**K\OGRD
MVJYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R(")!<V-E;G-I;VX@27-L86YD(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS
M9W-T<B`BI.6F<L/`LTXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("*HR*QW+Z33
MI:VL=J9AL,\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED
M(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`BL/6FYK[>IT"Z^\5`JV7%XZ7<O52[
M>[GON-P_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#(*;7-G:60@(D%S
M<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("*DP+!TQ.:F["(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("+`?+C5IU*PHZ1`K=.DHZ9SIF*J
MNKASLM4N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`BP'RXU:=2L*.D0*W3I*.F<Z9BJKK%=JVM+B(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BP'RXU;USO^BD0*W3
MI*.F<Z9BJKJX<[+5+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU
M,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+B(*;7-G<W1R("+`?+C5O7._Z*1`K=.DHZ9SIF*JNJ9`J,DN(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`BQ-VIRB(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B
M"FUS9W-T<B`BI$NDZR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T
M<F%L:6$@*+]$I&JG4:C(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B075S
M=')I82`HMOBF8:=1*2(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z
M,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-R>7-Q;#H@I^2DHZCLJ=*[
MW:UNJKH@:6UA<""IM:;YKDVE\RXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U
M<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER
M=7,Z(*;XJD&ZW:C#I;RTHZC1N-.VM:3DM*DN(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-R>75S
M.B"GY*2CJ.RITKO=K6ZJNB!I;6%P(*FUIOFN3:7S+B(*"B,Z(&QI8B](;W)D
M92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F
M='`Z(*?DI*.H[*G2N]VM;JJZ($944""IM:;YKDVE\RZ]T*VKMW.]<\2V(%!(
M4""HPZ5"I5ND2B`M+65N86)L92UF='`@O^\B"B*VM2RHTJ9P(&-O;F9I9W5R
M92`M+65N86)L92UF='`B"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV
M-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@I^2DHZCLJ=*[W:UNJKH@
M24U!4""IM:;YKDVE\RXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU
M,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@I^2DHZCLJ=*[W:UNJKH@
M:W)B-2"IM:;YKDVE\RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS
M,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P
M.B"W<[Q7J,^ESJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]JD&PR"(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P
M.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@IU*PHZC/I<ZJS+-OMK6E
M7*_@I=BK9:C#I*.DY+2II=B__:I!L,@B"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@I^2DHZCL
MJ=*[W:UNJKH@3$1!4""IM:;YKDVE\RXB"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z(+5,JFNW<[Q7J,^ESJK,("5S
M+B"F^*I!OKFF7L"S.B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,X
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R
M96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(+5,JFNROK"CJ,^E
MSJK,("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@M4RJ:Z?SMW.HSZ7.JLP@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?
M;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B075T:%]L9&%P.B"G\[=SJ,^ESJK,
MLV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]JD&PR"(*"B,Z(&QI8B](;W)D92]!
M=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B"G
MY*2CJ.RITKO=K6ZJNB!-0T%,(*FUIOFN3:7S+B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M
M8F%U=&@Z(*?DI*.H[*G2N]VM;JJZ('-M8F%U=&@@J;6F^:Y-I?,N(@H*(SH@
M;&EB+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("))34%0(*;X
MJD&^N<7GP]*_^;M^+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T
M<B`BQ>?#TJ6BL=$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B
M"FUS9W-T<B`BQ>?#TJ6BL=$N("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D
M:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N(@IM<V=S='(@(E)!1$E54R#%Y\/2O_F[?BXB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z.#<Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1E10(,7GP]*_^;M^+B(*
M"B,Z(&QI8B]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")334(@Q>?#TK_Y
MNWXN(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B
M079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BI6FESJJZQ.:F[#HB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B86EJ86X@**C(MNNK]+5-*2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U
M<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T
M<B`BK4FTNB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`BK4FT
MNL-#IN(B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")K97)B97)O<R"Q2[U8
MO_F[?BXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B
M0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")K97)B97)O<R"HSZ7.
MJLRF5[K9O_F[?BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M87,@
M**3:JZ*PJ"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:6X@**3:
MJDPI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)A;'1I
M8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(JIIP[FJNJ[\I.4@*$E33RTX.#4Y
M+3$S*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9&5S:"`H
MJ7.E6ZG4*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S("BD
MVJBIIF@I(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H[+G/I=REV+_](%PB)7-<(BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(K#RO74B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(D)E;&%R=7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@
M(D)E;&=I=6T@**3QIU&NR2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L
M:7IE("BHJ:B]M+4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6X@**BI
MN><I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A("BFRKQ]N48I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A;B`HI*.DIBDB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER
M=&AD87DB"FUS9W-T<B`BI<VDZ2(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E
M<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(J?DI*.H[,"SI<ZU>Z:A7"(E,B1S7"*JNK#/MO1<(B4Q)'-<(BXB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E
M='1I;F=S(@IM<V=S='(@(K#/MO2S7:EW(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(K#/
MMO2KK+I!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(K+*Q>DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI
M=FEA(@IM<V=S='(@(D)O;&EV:6$@**S!IU&Z^ZC(*2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R
M("*NT<72(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(J[8O74B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS
M9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("*NV+UUI&JD<"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`BKMB]=2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;FEA(&%N9"!(97)Z96=O
M=FEN82`HJFFD:*6GJ,BDSK;"P<FM]+K[J+HI(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(J7^LZ$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82`HJFFEOJBZ*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM
M<V=I9"`B0F]T=&]M(@IM<V=S='(@(JFSLZ$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L
M86YD(@IM<V=S='(@(D)O=79E="!)<VQA;F0B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS
M9W-T<B`B0G)A>FEL("BDVJ;H*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=&ES:"!);F1I86X@3V-E86X@
M5&5R<FET;W)Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B
M0G)U;F5I($1A<G5S<V%L86T@**A:M=PI(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS
M9W-T<B`B0G5L9V%R:6$@**M/I5NG4:C(*2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI
M<W0B"FUS9W-T<B`BMK6EV++%N+DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS
M9W-T<B`B0G5R:VEN82!&87-O("BEK+18K\>J:Z_!*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N
M9&DB"FUS9W-T<B`B0G5R=6YD:2`HNUJVJ:9A*2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R("*JJ:VQNMZR
M>B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED
M(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S
M='(@(D-23""DP+.APDDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`BP'BF<Z[FI+JN92XN+E]E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@
M;F]T(&-O;7!L971E9"XB"FUS9W-T<B`BI]:H^JKLJ6RDQJE\I;RGN::H+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#(@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("*FYJC&ON0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM
M(@IM<V=S='(@(KESK\6MMR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")#
M86UB;V1I82`HK%JN2+GK*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(D-A
M;65R;V]N("BSV+/!MJDI(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(K5,
MJFNFV[#*K:NX;;%+O5@LO=#!<+6XIT&JNJATLLZZWK)ZK?LN(@H*(SH@;&EB
M+T9I;&4O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO
M="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("*U3*IKO&>D2L#)KM<@
M7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BM4RJ
M:[-SO76FW"!)34%0(*;XJD&^N3H@)7,B"@HC.B!L:6(O1FEL92]#4U8N<&AP
M.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("*U3*IKMGVQTL#)KM<@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A
M;F%D82(*;7-G<W1R(")#86YA9&$@**5;KK.D:BDB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("*H^J[X(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R("*H^J[XL-W#1*9>L_@B"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(K5,JFNG4K"CP,FNUR!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-#8*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(J?DI*.H[+S(IG.EV+_]+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("*ORJ36("=T
M87)G971&:6QE)R"PT;S&M4RJ:\1^Q/*S0K)Z+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("*U3*IKLKZPHZ78O_T@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z,3(X(&QI8B](;W)D92]$
M871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`BM4RJ:[*^
ML*,[("5D(*W3I&RVL*1WIG.F8BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964O
M<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("*U3*IKK:NRU:%#J=*THZC1
MJKJP3[_]O,:EV+M0I?VK9:G2P'BF<ZJZN.JNQJ2CLL4N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(K5,
MJFNVQ[!EPK*P5*CLJ_RI=ZJZN+F]6"XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(D-A<&4@5F5R9&4@*+K[O'>HI"DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T
M:6]N(@IM<V=S='(@(KNAJ?JDY:9R(@H*(SH@;&EB+TYE="]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D-A<G)I97(B"FUS9W-T
M<B`BK[NL]:;B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED
M(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`BI,##_KM0O-#%TB(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")#87EM86X@27-L86YD
M<R`HMGVPTKASKG$I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`BIN:PRKEQN-PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BP'BF<Z[F
MI+JN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(L!XIG.NYKG4
MI5(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(L!X
MIG.NYJ2ZKF4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("+`>*9S
MKN:VH;9:.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C<X"FUS9VED(")#
M96QL<&AO;F4B"FUS9W-T<B`BIN:PRKEQN-PB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`BMNNZN*]3I.4@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E
M<B(*;7-G<W1R("*X;:2D(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R`HI*2K1*9`
MJ4VPZBDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B0V5N
M=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`BI*2\VB`H25-/
M+3@X-3DM,C`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM
M<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("*^S,/2LM.X8"(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T
M:69I8V%T92!/=VYE<B(*;7-G<W1R("*^S,/2OM:FLZK,(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O
M;&EC:65S(@IM<V=S='(@(K[,P]*L1K6F(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S
M='(@(D-H860@**QDO'<I(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(J?SI^\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S
M='(@(J?SI^^G0:JZL4N]6"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@
M<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B
M"B)E;6%I;',N(@IM<V=S='(@(J?SI^^G0:JZJKJE_J97I4BDSJ9>MFRF8:=]
M+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B
M(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*EV*MEJKJS7:EWJ,.EO*3DM*FQ
M2[U8Q=RG\RX@O=#!<+6XIT&JNKK>LGJM^RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R
M(@IM<V=S='(@(J9RI+@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN
M(@IM<V=S='(@(L#+K&2S<[6R+BXN7VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R
M(")#:&EL92`HM+RG42DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R(")#:&EN82`H
MI*2PZBDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(L*RQ>FDI*3E("A'
M0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D-H
M:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(J6_Q>FDI*3E("A"
M:6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H
M;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`BO^^^W,"SI<ZU>Z:A.B(*"B,Z
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@
M82!P87-S=V]R9"(*;7-G<W1R("*_[[[<L4N]6"(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R("*_[[[<I$"MTZC/I<ZJS*97NMDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(@IM<V=S='(@(J3IM,'%XZ7<I.BFH3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS
M9W-T<B`BO^^^W+:UI=BKK+I!JKJMMZ[F(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES
M;&%N9"(*;7-G<W1R(")#:')I<W1M87,@27-L86YD("BX=+W/KG$I(@H*(SH@
M;&EB+U9&4RYP:'`Z.3$S(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(J?DI*.H["`E<R"JNL/^IT^I=[AQ+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*
M;7-G<W1R("*TN"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`BLDVPH[=,LVX@3V9F:6-E(+S0Q=(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("*R3;"CK&2XWR(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("*R3;"C
MJ,^ESJK,.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("*R3;"CJ,^ESJK,(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L
M96%R('5S97(@9&%T82(*;7-G<W1R("*R3;"CJ,^ESJK,JKJXZJ[&(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@
M(D-L96%R:6YG($QA=&4B"FUS9W-T<B`BL=_"X+2X(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K
M('1O($-O;G1I;G5E(@IM<V=S='(@(JOVM\:YJ\'DI4C$?L3R(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K
M871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;""S>KE,($A45%`B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+#
M]K.LM?BUH2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#
M;&]U9',B"FUS9W-T<B`BMK.V<2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T
M<B`BIJVF:+:S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("*SL2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O
M8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(D-O8V]S("A+965L:6YG
M*2!)<VQA;F1S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR
M,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("*GZ<5\N.JNQJ>H
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`BI^G%
M?,/DK,DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")#;VQO;6)I82`HK?2M
MVZ3QJ,@I(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO
M8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(L-#IN(B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U(&QI8B](
M;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C8*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B
MO=6FXKU,(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S4*;7-G:60@(D-O
M;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B,3:V::;LPT.FXJ5.O5@B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I
M9"`B0V]L<SHB"FUS9W-T<B`BQ.8Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Y-3`*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`BQ.:F[+S0PT0B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI
M8W,B"FUS9W-T<B`BI62S<2(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM
M<V=I9"`B0V]M;6%N9"(*;7-G<W1R("*I4J5/(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(J?EIKBI
M4J5/(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#
M;VUM96YT(@IM<V=S='(@(K7[O=<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`BNMFI22(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T
M"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R;W,@**SLO*_#N2DB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B
M0V]M<&%N>2(*;7-G<W1R("*DO:5Q(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`BN7&XHR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO
M;B(*;7-G<W1R("+`]+G2(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*
M;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`BL?BE\R(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S(@IM<V=S='(@(JYTLJ<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!
M<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(KM0(%!$02"T
M>*17JZRY<;BC++2\O'JKK*3BOO>E2*3.($]U=&QO;VL@JKJF4*A"LUVI=RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U
M<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("*S7:EWN.JNQKE,M,$N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`BLUVI=R`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I
M<FT@4&%S<W=O<F0B"FUS9W-T<B`BO52[>[%+O5@B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*
M;7-G<W1R(")#;VYG;R`HK>BJ1RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(D-O;F=O+"!4:&4@1&5M
M;V-R871I8R!297!U8FQI8R!O9B!T:&4@**WHJD>F0*E-L.HI(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9"XB"FUS9W-T<B`BLW.ULJ6BL=$N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(K-S
MM;*EHK'1.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`BLW.ULJ;<I+VV?:KWQE^F^*I!OKFNR;Y$J=HN(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(K-SM;*FW*2]MGVJ]\9?IOBJ
M0;ZYKLF^1*G:+B"M[*9=.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C@V-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`BLW.ULJ;<($944"#`R:[7IOBJ0;ZYI:*QT2XB"@HC.B!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T
M<B`BLW.UN*1((@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(K!/O_VD=Z:HI5RF8;=S
MO%>FW*=!JKJS<;!4O_VDI"XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@
M9FEL93H@(@IM<V=S='(@(L"CP5G`R:[7JKJDNJYEJZRZ03H@(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E
M<UPB(@IM<V=S='(@(EPB)7-<(B#`R:[7I+JN92(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`BQ'[$\B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;VL@27-L86YD<R(*;7-G<W1R(")#;V]K($ES;&%N9',@**SLITJX<ZYQ*2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B
M0V]O:VEE(@IM<V=S='(@(L-#IN(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS
M9W-T<B`BO<:[<R(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(KW&NW.EHK'1
M.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(KW&NW,B"@HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3<P(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A("BM]+2UI&J^I*5;
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B0V]T92!D)TEV;VER
M92`HMDBD^J[\J:0I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W
M"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S
M='(@(K5,JFNE2"!01U`@I5NQ2[9LI?,Z("(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E.B`B"FUS9W-T<B`BM4RJ:Z5((%!'4""P]:;FMFRE\\.QL[DZ("(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`BM4RJ:Z5((%,O
M34E-12"E6[%+MFRE\RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(K5,JFNLL"!3+TU)344@MFRE\\.QL[DN(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(K5,JFNW<[Q7
MLW.UN*1(+B`E<R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HY-B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B
M:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("*U3*IKP[2ULB!,1$%0(*;X
MJD&^N2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(K5,JFO#M+6R
M(&QD87`@IOBJ0;ZY(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@
M)7,B"FUS9W-T<B`BM4RJ:\#+K&2W;*]Q+B`E<R(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD
M87`@<V5R=F5R(@IM<V=S='(@(K5,JFNS<[6RIMP@;&1A<""F^*I!OKDB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&
M5%`Z("5S(@IM<V=S='(@(K5,JFNS<[6RIMRF^*I!OKD@7"(E<UPB(*C/I<X@
M1E10.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS
M,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BM4RJ:ZO8I=^P=+AMN'.RU2X@
M)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(K5,JFNXT;%+
M(%!'4""XZJ[&.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R
M,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(K5,JFNXT;%+(%,O34E-12"XZJ[&+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("*U3*IKIU*PH[-S
MM;BD2"X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(K5,JFNG4K"CL'2X;;)-L^8N
M("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C
M<FEP="!<(B5S7"(N(@IM<V=S='(@(K5,JFNG4K"CI_.W<[5[IJ$@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S@Q(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN
M92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(K5,
MJFNH3:EWIJRE\Z1(JKJY<:1LMFRE\Z;LIWTN(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BM4RJ:\#RJ/JGN;[C
MJKJS<;!4O_TN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R("*U3*IKP/*H^J>YON.JNK!TN&VR3;/F+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(K5,JFO`\JCZL'2X;;)-L^:DI*JZN'.R
MU2XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(K5,JFNX_*1*M::RI"!<(B5S7"(N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(K5,JFNKV*7?I=B__2!<(B5S
M7"(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+B(*;7-G<W1R("*U3*IKIMNJ]\9?IOBJ0;ZYJ/JQ;Z2]MGVJ]\9?+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S
M7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(K5,JFNV?;'2(%PB)7-<(B"E2+QG
MI$HN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-R!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("*U3*IKMGVQTB`E<RXB"@HC.B!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<R(*;7-G<W1R("*U3*IKMGVQTKK[Q4"D=:=`O-*RU2`E<R(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(K5,JFNV?;'2I=B__2!<(B5S7"(N(@H*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("*U3*IKLW.QM2!,1$%0(""F^*I!OKDN(@H*(SH@
M;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`BM4RJ:\6JJ/H@)7,N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B*U3*IK
MK:NW<[-=J7>HSZ7.JLRJNK%+O5@N(+.AI,"JNK+3N&"DHZ6_O50N(+W0P7"U
MN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BXB"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-#`*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,W-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`BM4RJ:\6JJ/JF<ZCZL;&H[JKM
M*$%C8V5S<R!#;VYT<F]L($QI<W0I(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("*U3*IKQ:JH
M^K-QL%2__2X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BM4RJ:\6JJ/JP=+AM
MLDVE52X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(K5,JFO%JJCZL'2X;;)-
MI54N("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`BM4RJ
M:\6JJ/JF^*I!OKFJNJS;P_:O4ZG*(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("*U3*IKIEZT7[-=J7<N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`BM4RJ
M:Z=2L*.EV+_](%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*U3*IKP'BF<R`E<R"JNK-=J7<N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN(@IM<V=S='(@(K5,JFO`>*9SL\:E][-=J7<N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T
M<B`BM4RJ:\!XIG.SQJ7WLUVI=SH@)7,N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B
MM4RJ:\!XIG.G\[=SM7NFH:CL.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`BM4RJ:\!XIG.SQJ7WLUVI=R`E<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N(@IM<V=S='(@(B(*(K5,JFO`>*9SLUVI=\#))7,N(*=!I6FE2*C/I<XE
M<Z2DJKJHY*5,I5ROX,!XIG.S7:EWJ<ZDXK#*O<:[<Z15K;&U>Z:AO5BH["`E
M<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O
M=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("*U3*IK
MMVJT32!,1$%0(""F^*I!OKDN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(K5,JFNG4K"C
M(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`BM4RJ:Z?SMW.S<[6XI$@N("5S(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R("*U3*IKI_.W<[!TN&VR3:55+B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R
M("*U3*IKPM"\9R!<(B5S7"(Z("5S(*JZLUVI=RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*
M;7-G<W1R("*GY*2CJ.P@36]Z:6QL82"JNJ3`K;8N(+W0O52[>Z3`K;:L3Z=?
MMGVQTBXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<
M(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E
M<UPB.B`E<R(*;7-G<W1R("*U3*IKO>&DJ:C/I<ZJS"!<(B5S7"(@I%6F0\5V
MK:VH[*M(I?.G6"!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,C,*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("*GWK-.I7DB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R
M>2(*;7-G<W1R("*PZJYA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("*]TJKM(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BJ]BEWR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B
M0W)E871E(&$@;&EN:R(*;7-G<W1R("*KV*7?I$"MT[-SM;(B"@HC.B!T96UP
M;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A
M=&4@82!N97<@;VYE(@IM<V=S='(@(JO8I=^D0*W3MW.JNB(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U
M8B!F;VQD97)S(@IM<V=S='(@(JO8I=^FN*M(I?.G6"(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(JO8I=^JS*JZQ7:MK2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C$Y"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BJTBE
MSJ5DN+F]6"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(D-R;V%T:6$@**=*
MP[FFZ*C(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B0W5B82`HI6JDVBDB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E
M;G0@-"!0:&%S97,B"FUS9W-T<B`BI=BK9:JZI.NLVR(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R
M("*EV*MEMWRTP2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C
M:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(J78
MJV6NR;:A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R
M("*EV*MENO2G?2(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B
M0W5R<F5N="!5<V5R<R(*;7-G<W1R("*EV*MEJKJHSZ7.JLPB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS
M9W-T<B`BI=BK9:31KO`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(J78
MJV6JNJJLJG`Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`BI=BK
M9:JZK;>NYB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+B(*;7-G<W1R("*FVZUQI$"HQ[5NI$HE<ZOAJ=*M;K#UIN:J
MNJ1UIT`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`BL,6D52(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G
M:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BL,6D52(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U
M<R(*;7-G<W1R(")#>7!R=7,@*,')M+:PQ[2U*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<X"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R
M("*FZ*B]NKBDY2`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<Y"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("*F
MZ*B]NKBDY2`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@P"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS
M9W-T<B`BINBHO;JXI.4OKU&G2L3UI.4@*$M/23@M52DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C
M:"!297!U8FQI8R(*;7-G<W1R(")#>F5C:"!297!U8FQI8R`HL;:G2J9`J4VP
MZBDB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R("*D
MZ2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<P"FUS9VED("(B"B)$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(KCJKL:HT[>]
MIE>ZV2`HO="PT:;2(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A
M8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M(@HB9'-N+G!H<"DB"@HC.B!L:6(O
M2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R
M("*H0Z3I(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A
M5')E92!"<F]W<V5R(@IM<V=S='(@(K[PJJRXZJ[&PG/$_2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,C8X"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS
M9W-T<B`BN.JNQJYWMVJT32(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#`R
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$
M871E(@IM<V=S='(@(J3IM,$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("*F
MK*CLI.FTP2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDV"FUS9VED(")$
M871E('-E;&5C=&EO;B(*;7-G<W1R("*_[[[<I.FTP2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@(J75I-$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*
M;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(J=2L*/$YJ;L7VPB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB
M97(B"FUS9W-T<B`BI%&D1Z3K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N
M=6UB97)S(@IM<V=S='(@(J11MFFF[+S&IG(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!)
M;F1E;G0B"FUS9W-T<B`BM.ZDUL%9L<8B"@HC.B!L:6(O<')E9G,N<&AP.C$Q
M-R!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PIM<V=I9"`B1&5F875L="(*
M;7-G<W1R("*Y=[-=(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B
MN7>S7<-#IN(B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.CDV"FUS9VED
M(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(KEWLUVJNJBMI??#T:=/(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H
M96QL(@IM<V=S='(@(KEWLUVI4J5/N-&J4KZY*%-H96QL*2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T
M<B`BJ7>X<2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HS,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY."!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T
M92(*;7-G<W1R("*G4K"C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*
M;7-G<W1R("*G4K"CP'BF<Z[F(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@
M861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G
M<W1R("*G4K"CN'.RU2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("*G4K"CK/:__2(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(J=2
ML*/%=JVM(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS
M"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(J=2
ML*.A0K)-JL6V;*7S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T
M<B`BIU*PH\!XIG.NYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS
M9W-T<B`BIU*PH\3FINPB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM
M<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R("*G4K"CLGNF<ZJZM,"E3KS+JD\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("*G4K"C7"(E<UPBJKK%=JVM(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(KU4J7>M;J=2L*-<(B5S7"*JNL5V
MK:VE2*3.IKC%=JVM(#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S
M='(@(J=2L*.F0R(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET
M>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G
M<W1R("*G4K"CJ=*_[[[<JKJHK:7WP]&G3[CJKL8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`BIU*PHZ78JV6J
MNL3FINPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B
M"FUS9W-T<B`BIU*PHZ78JV6JNJ9#(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(J?SMW.U>Z:A(%PB)7-<
M(B"D=Z=2L*,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE
M(@IM<V=S='(@(KN\L&6NR;:A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$
M96YM87)K("BDIK/!*2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("*P
MW<-$M'FM>B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B
M1&5S8W)I<'1I;VXB"FUS9W-T<B`BM'FM>B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3DW"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M(@IM<V=S='(@(K+3N&`@*+W0L-&FTB!(;W)D92"P3[_]P,FNURDZ(@H*(SH@
M;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(K+3N&"]T+#1
MIM*H=++.NMZR>K5NO_TN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`BK..U;R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T
M<B`BQ5/"2;?%J]<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I
M9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("*SS*OAI$"D
M<*[)JKK%4\))M\6KUSH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`BQ5/"2;?%J]<Z
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(K%Q
MI:JFW*5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T
M<B`BL7&E:Z;<I:HB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I
M9"`B1&ER96-T;W)Y(@IM<V=S='(@(J78O_TB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM
M<V=S='(@(J5((#(T(*1PKLFH[L7CI=P_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(L7C
MI=R_[[:U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS
M9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(L7CI=RX
MU++3JKJY=[/X(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B
M1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("+%XZ7<N7>S^"`H5$%&
M*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`V"FUS9VED(")$:7-P;&%Y
M(&9O<FUA="(*;7-G<W1R("+%XZ7<KN:FH2(*"B,Z(&QI8B](;W)D92]-24U%
M+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB
M"FUS9W-T<B`BML>P9:9>L?@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$
M:FEB;W5T:2`HIDZEK*9A*2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(J2CIU*PHR(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`BI*.M;JJ]
ML;6F<ZCZ(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS
M9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M
M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(K+$I$"UI[!/
MO_VL3Z=?I5VG=,3FINRF5[K9/R"F<*I'K$^]T*3$O^\N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M
M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$@**9HJ?JEIZ5;*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O
M;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEC86X@4F5P=6)L:6,@
M**9HJ?JEIZ5;ID"I3;#J*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB
M"FUS9W-T<B`BP=FH4Z:SL6*XN;;</R"U^:55+B(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@
M(J15N/PB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(J15N/P@
M)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N
M;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*
M;7-G<W1R("*D5;C\LUVI=\#)KM>E=*9SK+`@4$A0(+5[IJ$N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM
M<V=S='(@(J15J=2E7*_@JNTB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(L/$JWXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R("*Y<:1L
MMFRE\R(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G
M:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S
M('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*
M;7-G:60@(D524B(*;7-G<W1R("*_^;M^(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G
M<W1R(")%8W5A9&]R("BDS*7*IFBZN"DB"@HC.B!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*
M;7-G<W1R("*]<[_H(@H*(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,"!T
M96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K
M(@IM<V=S='(@(KUSO^BPS[;T(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@
M861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T
M<B`BO7._Z+ASLM4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<V(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VXB"FUS9W-T<B`BO7._Z,5VK:TB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(KUS
MO^C%=JVM(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("*]<[_H)7.JNL5VK:TB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("*]<[_HO^^V
MM2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M("*]<[_H7"(E<UPBJKK%=JVM(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS
M(&9O<B`E<R(*;7-G<W1R("*]<[_H)7.JNL5VK:TB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("*QT*A\
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=Y<'0@**Y*I,XI(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O<B`HPL2ZN*7+IF@I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(J2XI?,N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$X-S,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G
M:60@(D5M86EL(@IM<V=S='(@(KEQI&RV;*7S(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(KEQI&RV;*7SINVG?2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.38W"FUS9VED(")%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"XB"FUS9W-T<B`BN7&D;+9LI?.F[:=]I;*VMZ=K
MIE@N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.3,*;7-G:60@(D5M86EL
M('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(KEQI&RV;*7SO52[>R(*"B,Z
M(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL
M+71O+5--4R!'871E=V%Y(@IM<V=S='(@(D5M86EL+71O+5--4R"Y:+E$OKDB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDW"FUS
M9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BJNVQH;+%N+DB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S
M<V%G92XB"FUS9W-T<B`BJL6EU:M(I?,N(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-3`*
M;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`BJL6EU;6RJD<N(@H*(SH@
M;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S
M96%R8V@@=&5R;7,B"FUS9W-T<B`BJL6EU;=JM$VVM:78(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O
M9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T
M<B`BI+FS7*;;P\"T6;2AI$JWTZ3YJ.RK2*7SI*0HNO2MMKUSO&>\TJ:A*2`_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE
M(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`BL=*PRK?&N:NE
M:\'DI5ROX*KM/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DR(&QI8B](
M;W)D92]&;W)M+G!H<#HR.#`P"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("*U
MLJ?TIGZE]R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(JGQI&J]
M<[_HOKDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B
M"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E
M(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T
M<B`BIG"J1Z=!N]VM;JVKLUVQ2[U8++W0O^FD2J1`K=.F=Z7^L-VE>2RHTJ9P
M(">G0<-DJJNJNJ97NMD@/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`BIF*FN;_II$J\=KFSJKJZ]*=]
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X.0IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G
M:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D5Q=6%T;W)I86P@1W5I
M;F5A("BHJKE$M%BDNJC(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I
M=')E82`HI,REWZ]3J+VF=RDB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0X(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*(SH@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B
MO_F[?B(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R
M("*KV*7?L,^V]"5SKLFU;Z7-O_F[?B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("*G4K"CIE"H0L'CPDDZ("5S
M(*[)M6^ES;_YNWXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO
M9SH@)7,B"FUS9W-T<B`BIU*PHZ90J$*P3[_].B`E<R"NR;5OI<V_^;M^(@H*
M(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("+%JJCZ
MI+JN93HE<R"NR;5OI<V_^;M^(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R("*G\[=SL4N]6#H@)7,@KLFU;Z7-O_F[
M?B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"B,L
M(&9U>GIY"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S
M='(@(KUSO^BD0*MHL%2NIR(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`BO&>D2B!<(B5S7"(@
MKLFU;Z7-O_F[?BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N:6$@
M*+=2J$:EIZC(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:&EO<&EA
M("BFYZ_!I/&HR"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G
M:60@(D5T:&YI8R(*;7-G<W1R("*ZV+':(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&4@*+S:
MK'<I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E
M<GD@,34@;6EN=71E<R(*;7-G<W1R("*H0R`Q-2"DP,3!(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM
M<V=S='(@(JA#(#(@I,#$P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@
M<V5C;VYD<R(*;7-G<W1R("*H0R`S,""L[<3!(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED
M(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`BJ$,@-2"DP,3!(@H*(SH@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB
M"FUS9W-T<B`BJ$.FN+5NI$HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BJ$,@,S`@I,#$
MP2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(JA#
M(#$@I,#$P2(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS
M9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BO62HTJW(.B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M
M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("*P
M]:;F(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED
M(")%>'!A;F0B"FUS9W-T<B`BKFFV?2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@
M(JYIMGVXZJ[&IZ@B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ
M-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("*M;JA$("<I)R(*"B,Z
M(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER
M871I;VX@1&%T92(*;7-G<W1R("*H[+3!I.DB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`BN-&[
MH:W[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`BJV6TNL-#IN(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L
M;V%D(&]F('-E='5P(@IM<V=S='(@(D944""D5[;'LUVI=RXB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("+%JJCZL+ZF;K-=J7>EHK'1(@H*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<U(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`BM4RJ:[-SO76FW"!,1$%0(*;XJD&^N2XB"@HC
M.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("*U3*IKLW.]=:;<(%--
M0B"F^*I!OKDN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<P-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T
M<B`BO<:[<Z6BL=&FVR!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S
M7"(N(@IM<V=S='(@(KW&NW.EHK'1J.P@7"(E<UPB+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE
M=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(K5,JFNKV*7?I$"MT[=SJKH@
M4T%33""S<[&U+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU,#$@;&EB+U9&4R]F
M='`N<&AP.C<T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V
M92!T;R!<(B5S7"(N(@IM<V=S='(@(K=HLKZEHK'1J.P@7"(E<UPB+B(*"B,Z
M(&QI8B]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("+"7JCZI:*QT3H@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I
M9"`B1F%I<B(*;7-G<W1R("*TMK-Q(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD($ES;&%N9',@JFO$]:=*
MNM:X<ZYQ("BPJ+JXNONOQ[2UN'.N<2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(D9A<F]E($ES;&%N9',B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H
M<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("+$6:VKO_F[?CHB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I
M9"`B1F%X(@IM<V=S='(@(K;'KW4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R("*VQZ]U(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,"!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM
M<V=S='(@(J1'I.LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I
M9"`B1F5E;',@3&EK92(*;7-G<W1R("*W4,2Q(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S
M='(@(K=0Q+$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("*D\J3RJT(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM
M<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("*U=;S(L'VSMR(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.30X"FUS9VED(")&:65L9"!M871R:7@B
M"FUS9W-T<B`BQ.:F[+!]ID,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R
M,PIM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,C<*(RP@9G5Z>GD*;7-G:60@(D9I9VQE="!F;VYT
M(@IM<V=S='(@(K_OOMS`R:[7I4BVUZ1*.B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T
M<B`B1FEJ:2`HM+3`V2DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`BP,FNUR(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&4B"FUS9W-T<B`BP,FNU[S&I=@Z("5S(*W3P,FNUR(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&5S(@IM<V=S='(@(L#)KM>\QJ78.B`E<R#`R:[7(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM
M<V=S='(@(L#)KM?!8+K>(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@
M3F%M92(*;7-G<W1R("+`R:[7IE>ZV2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3@T"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("+`R:[7O^^^
MW"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R("+`R:[7I%>VQR(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HX.#4*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("+`R:[7I%>VQZ5<K^"EO+-1I.2TJ2XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`BN4S"
M;[ZY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL86YD("BJXL3U*2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B
M"FUS9W-T<B`BI%>E8J3K(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G
M<W1R("*D5ZFV(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(JE4J7>D\:C2(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,`IM<V=I
M9"`B1FQI<"(*;7-G<W1R("*D5Z15Q$&MRR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T
M(@IM<V=S='(@(J]"L,HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(L/Z(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C(S-R!L:6(O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S
M='(@(J78O_T@)7,@I*.F<Z9B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R
M("*F<JNLPT.FXB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I
M9"`B1F]O9"(*;7-G<W1R("*MN:JK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("*F
M7:RPPG/$_;ZYJ,.EO*3DM*F\=KFSI5ROX"XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`BKO"V
M2+EWL_@@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T
M=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@
M(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B
M;&]C:RDB"FUS9W-T<B`B(@HBN7>S^*31O,8@*+EWL_BDT;S&I5VL0:75I-&E
M2*3.J5VVH:JZN.JNQCNF<*I'N7>S^*31O,:X^ZKXL4ZF^Z7.I/&X^[QEM%2J
MNJJI(@HBK;$I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*
M;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("*GT;!/L4N]
M6"`_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B
M1F]R;7,B"FUS9W-T<B`BJNVSYB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("*D<+MY(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T
M<B`BI'"[></^JZPB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G
M:60@(D9O<G1U;F5S(@IM<V=S='(@(J1PNWDB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`BI'"[>2`R
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(KW7OL(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("*FV[#*PN"K2"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G
M:60@(D9R(@IM<V=S='(@(JQ0M,&DK2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*
M;7-G<W1R("*NV*Q;(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YC92`H
MJFNPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-E+"!-971R;W!O
M;&ET86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(D9R96YC:"!'
M=6EA;F$@**IKQ-V[7*C(J+HI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B1G)E;F-H(%!O;'EN97-I82`HJFO$W:S!IU&EIZ;HJ,@I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B
M1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B
ML4BE\Z1((@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R
M("*Q<2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS
M9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(J>YON.T>:UZ(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*
M;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("*ZH:3K(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("*E_J97(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1V%B;VXB"FUS9W-T<B`B1V%B;VX@**5;M%XI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED
M(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(L/`M%DZ(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1V%M8FEA(@IM<V=S='(@(D=A;6)I82`HI<RD\:C(*2(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A
M=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("*RHZ7-("5S(*W3J'2RSK-=
MJ7<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM
M<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`BI'>RHZ7-JKJS7:EWN.JN
MQB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1V5O<F=I82`HL^RJ=JC(ID"I
M3;#J*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B1V5R;6%N>2`HO'>PZBDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82`HK7NOQRDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M:6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R("BJO:6LP[FJ^RDB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M
M92(*;7-G<W1R("*F5[K9(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M,3(*;7-G:60@(D=O(@IM<V=S='(@(JMEJ;DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("*M]+QWNK@B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I
M9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE(*9AN<\B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM
M<V=S='(@(D=O;V=L92"W:K1-(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(J;'
MMJ4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=R965C92`HI\;#OBDB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B1W)E96L@*$E33RTX
M.#4Y+3<I(@IM<V=S='(@(J?&P[ZDY2`H25-/+3@X-3DM-RDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M<F5E;FQA;F0B"FUS9W-T<B`B1W)E96YL86YD("BNYK.NQ/6N<2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")'<F5N861A(@IM<V=S='(@(F=R96YA9&$@**[FM^>OQ[E&*2(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("*X<[+5NMZR>B(*"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z
M-3D@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@
M;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`BN'.RU:97NMFDH[%O
MJL6EU2(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U
M<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@
M(D=R;W5P7VQD87`Z(+5,JFNW<[Q7N'.RU2`E<RX@IOBJ0;ZYIE[`LSH@(@H*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B"U3*IKIU*P
MH[ASLM4@)7,B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R(")'<F]U<%]L9&%P.B"U3*IKI_.W<[ASLM4@)7,B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S
M(@IM<V=S='(@(KASLM4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U
M861E;&]U<&4@**WTO'>LI;2V*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U
M86T@*,/VKG$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA
M;&$@**7*IF&PJ*G4*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,@IM
M<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`BKN:NIJ;HKG$B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("*HT[NKQ7:M
MK2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U
M97-T8F]O:R(*;7-G<W1R("*S6*O(KV2HI2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G
M<W1R(")'=6EN96$@*+18I+JHR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B
M"FUS9W-T<B`B1W5I;F5A+4)I<W-A=2`HM%BDNJC(I/&OP:9`J4VPZBDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$@*+M<J,BHNBDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S='(@(K97
MI.6S<[6RNWFHI2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCL($A45%`@Q>?#TBXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I("BN_*9A*2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET
M:&TB"FUS9W-T<B`BPOBTZBVZ=+KB(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`BQD<B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3(S(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3(Q"FUS9VED(")(96%D97(B"FUS9W-T<B`BJNW`62(*"B,Z(&QI8B](
M;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S
M(@IM<V=S='(@(JKMP%DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("*D:KEP
MJT(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B2&5B<F5W
M("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(J?&IT*HTZ3E("A)4T\M.#@U.2TX
M+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(K"JJ]<B"@HC.B!L
M:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ.#8@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O
M:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`BNZ&I^B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@
M(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(KUSO^B^N:C/I<Z[H:GZ(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S4*;7-G:60@(DAE;'!E<B(*;7-G
M<W1R("*[H:GZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(
M96UI<W!H97)E(@IM<V=S='(@(J5BLGDB"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM
M<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G
M<W1R("*S;[C,K$_`R:[7JKJV?:EL.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(K"J
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A
M9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R
M("*N85]M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92DB"FUS9W-T<B`B2&]L>2!3964@*+'KO\VIHRDB"@HC.B!L:6(O2&]R9&4N
M<&AP.C$U,SD*;7-G:60@(DAO;64B"FUS9W-T<B`BKF$B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S
M='(@(J;MKF&F8:=](@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS
M9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("*N8:78O_TB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0
M:&]N92(*;7-G<W1R("*F[:YAN7&XW"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`B2&]N9'5R87,@**>[LZ.IU+2U*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG
M(@IM<V=S='(@(DAO;F<@2V]N9R`HK;NTY"DB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@MFRE\R`E
M,B1S(*2DN4JH[+5,KL2JNB`E,21S(%A-3+CJKL8B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(+5,MFRE\[Y!IEBJJZ7S("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+9LI?,@)3(D<R"DI*?DI*.H[*JK
MI?.KK+I!("4Q)',B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@I'>FJ*5<
MJKJROK"C("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@ON.F6*1UM7N[W:UN("=D;VUX;6PG(*JZ(%!(4""IM:;Y
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+5,JFNK
MV*7?("5S(*JKI?.JNB!834P@OO`B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$R-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@M4RJ:[*^L*,@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z-#<S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP
M92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@M4RJ:\#RJ/JSH:7W("5S(*NL
MND&JNB!-24U%(,/1IT^XN;U8(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,3DR"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@M4RJ:Z90J$(@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(+5,JFNF4*A"I,"HR3H@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M(*6\JKZJNJ3`J,D@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM
M<V=S='(@(J3TI:V]=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G
M<W1R("*D]*6MN=2E4B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(J3T
MI:TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*2(*;7-G<W1R("*G0:9PIO.H[*:Y(#\@*+W0L=2M>B$I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`BIT&M;J98J-:F:*36K=/$YJ;LJ4\_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("+$YJ;L
MO,:EV*9`K7`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BIT&M;J98J-:F:*36ID.I3S\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("*WPZO7
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM<V=I9"`B
M2'5M:61I='DZ("(*;7-G<W1R("*WPZO7.B`B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("*WQKU=I&JN
M=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")(=6YG87)Y("BF2:3ZIU$I
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W,B!L:6(O2&]R9&4O
M075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0(+9L
MO6.KV*7?I:*QT3H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z
M,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(DE-05`@MFR]8Z=2L*.EHK'1.B`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+V-Y<G5S+G!H<#HQ-SD@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R
M96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!4""V;+UCNL^ZT+!TN&VK
MV*7?I:*QT3H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,R,`IM<V=I
M9"`B25`@061D<F5S<R(*;7-G<W1R("))4""F[*=](@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B25`@INRG?;5,JFNHSZ7.+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4""F[*=]
MJ,.DHZ9B($-)1%(@JKJDN;-<L,^V]*2D+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@
M0F5F;W)E(@IM<V=S='(@(J9BJ^&ML;2AI$JF0U]N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L
M86YD(@IM<V=S='(@(DEC96QA;F0@**9"KG$I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("*OPKG/
MI=PB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B5SJKJYSZ7<(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T
M97AT(@IM<V=S='(@(KG/I=RDSJ3EIG(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(JBM
MI??#T:=/JKJF5[K9.B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L
M87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W
M+B(*;7-G<W1R("*F<*I'M4RJ:Z6_O52F8<7CI=PL("5S(*5(I72V?;'2MFRE
M\ZGSMW.U^+6AM^VDI"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y
M"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@
M(B(*(JC/I<X@26YT97)N970@17AP;&]R97(@PG/$_;ZYKLFF<*I'J%.FLZS=
MJ.RE]*;SJKJD<+G/I=PL(*=!I6FOX+O=K6ZDQ+_OLV^MT[:U(@HBI=BE2,/V
MLZP@4$Y'(+QVN;.JNL'TPL.NQ*I'+B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+B(*;7-G<W1R("*F<*I'K-VH[+-OJVBH4Z:SO':YLZJZL%2NIRRS;ZKMI=RG
M0:JZPG/$_;ZYM4RJ:\7CI=RD5[;'JKJ\=KFS+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I
M9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`BO':YL[EWQ/TZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM
M<V=I9"`B26UA9V4@55),(@IM<V=S='(@(KQVN;.Z]*=](@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q
M"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(KQVN;.Z]*=].B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(KQVN;.H
MTZ;;P\"T62(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M.B(*;7-G<W1R("*\=KFSJ-.FV\/`M%DZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$W-C4*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("*D5[;'O':Y
MLR(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B
M"FUS9W-T<B`BO':YLR(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S
M='(@(K;7I$HL(*A"QDH@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@
M)7,B"FUS9W-T<B`BMM>D2L3FINPZ("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R
M("*VUZ1*Q.:F[#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R
M(@IM<V=S='(@(J9BJ^&ML;2AI$JF0U]S(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@
M9VEV96XN(@IM<V=S='(@(K_II$JDHZ6_O52JNJ=`I<Z]6"XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E
M8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("*]T,#+K&2G
M0:JZJ,^ESJK,IE>ZV:3.L4N]6"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(JC/I<ZJS*97NMFDHZ6_O52ISJK,N7&D;+9LI?.F[:=]I'?%W*?S+KW0
MP7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S
M92!);F1E;G0B"FUS9W-T<B`BO%>E6\%9L<8B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM
M<V=S='(@(DEN9&EA("BF3*O7*2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("))
M;F1I=FED=6%L(%5S97)S(@IM<V=S='(@(JW3IT^HSZ7.JLPB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DEN9&]N97-I82(*;7-G<W1R("));F1O;F5S:6$@**9,I:<I(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B
M"FUS9W-T<B`BN.JP5"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(KCJL%0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO
M;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("*U3*5II<ZJNKCJL%0N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R
M("*F8JOAK;&TH:1*Q.:F[%]O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@
M26UA9V4B"FUS9W-T<B`BM*&D2KG/I/DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B
M"FUS9W-T<B`BM*&D2JKMKN8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS
M9W-T<B`BM*&D2KKTN/2S<[6R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O
M;'5M;B!"969O<F4B"FUS9W-T<B`BIF*K9:VQM*&D2L3FINQ?0R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`BIF*EV*MEQ.:F[*OAK;&TH:1*I$"MT[=SQ.:F["(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(J9BI=BK9<3FINRK9:VQM*&D2J1`K=.W
M<\3FINPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(J9BI=BK9:9#J^&ML;2AI$JD0*W3
MMW.F0R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(J9BI=BK9:9#JV6ML;2AI$JD0*W3
MMW.F0R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BIF*EV*MEN&#"2:OAK;&TH:1*
MI$"MTZQQN*@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("*F8J78JV6X8,))JV6M
ML;2AI$JD0*W3K'&XJ"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS
M9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(K2AI$JE
M:;3`I4Z\RZI/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I
M9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(K=SL4N]6+%.L4BU
M;ZCLLV^MT[9LI?.F8:=].B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F
M=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$K`>*9SKN8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("))
M;G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BIF*K9:VQM*&D2L!XIG.NYB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`BIF*K
MX:VQM*&D2L3FINPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R
M92(*;7-G<W1R("*F8JMEK;&TH:1*Q.:F["(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM
M<V=S='(@(K2AI$JV;*7S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R
M87!H(&%F=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$JL<;BH(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("*F8JMEK;&T
MH:1*K'&XJ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T
M<B`BIF*KX:VQM*&D2J9#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O
M<F4B"FUS9W-T<B`BIF*K9:VQM*&D2J9#(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("*F=Z7^L-VE>:JZ
MM:JNUSHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(K2A
MI$HOQ=RG\[QVN;,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T
M<B`BM*&D2B_%W*?SNO2X]+-SM;(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+"2;S&
MI*.HK*5(IMRI\[5,JFNVQ[!EM;FP=+AMN'.RU2XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET+B(*;7-G<W1R("+"2;S&I*.HK"XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("*^X[S&(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S<*;7-G:60@(DEN=&5G97(@;&ES="(*
M;7-G<W1R("*^X[S&ID,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB"FUS9W-T<B`BM4RNQ*JZ(%5$2"BHSZ7.JLRXZJ[&JNW`62DN(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#
M;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`BM4RN
MQ*JZ(%I)4""XZJ[&+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*
M;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(K5,KL2JNL"S
MI<ZU>Z:A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("*U3*[$JKJG
MY::XN+F]6"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$V,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S-@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,P,R!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB
M"FUS9W-T<B`BL&6E6*JZN.JNQK5,KL0N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I
M;VX@861D<F5S<RXB"FUS9W-T<B`BM4RNQ*JZI=B\T*;MIWTB"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,#D@;&EB+TAO<F1E+T-O;7!R97-S
M+V1B>"YP:'`Z,3,Y"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(T
M,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("*U3*[$JKK`
MR:[7KN:FH2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*
M;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(K5,KL2JNK'"
MQ7:]6"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS
M9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("*U3*[$
MJKJF8;#/+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("*U3*[$JKH@
M;7-G7W1Y<&4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S
M='(@(K5,KL2JNJG.I^2DHZCL(&%P:5]I9"XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG('!A<F%M971E<G,N(@IM<V=S='(@(K5,KL2JNJG.I^2DHZCLL-&\QBXB
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L
M:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(K5,KL2JNJ3WQ7:MK2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("))
M;G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(K5,KL2JNKG9IO'#T:=/O5@N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B
M26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(K5,KL2JNK*CJWZ]6"XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I
M9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`BM4RNQ*JZLW&P5*CSJ7<N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS(&QI8B].
M970O4TU3+W=I;E]H='1P+G!H<#HW,0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(*;7-G<W1R("*U3*[$JKJFK*7SI$@Z7"(E<UPB(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#<U(&QI8B](;W)D92]+;VQA8BYP:'`Z
M,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`BM4RN
MQ*JZI,"HR:JKI?,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S
M='(@(K5,KL2JNJC3M[VF[:=]+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB
M"FUS9W-T<B`BM4RNQ*JZN%6PZKU8N.JNQBXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`BN.JR
MHR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S4*
M;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`BIEZT7[_OOMPB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B`HI>RNU"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B
M"FUS9W-T<B`B27)A<2`HI>RIU*=**2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("))<F5L86YD("BW4KJXQ/4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B27-L92!O9B!-
M86X@*+#2KG$I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(J>]
MLZ&Y<*M"(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R865L("BE2*;B
MID,I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@
M(DES<W5E<B(*;7-G<W1R("+#L;5OJLPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R
M("*QU\7I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("))=&%L>2`HN'&D:J=1
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6-A("BD^K92I5LI
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y.2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA
M;G5A<GDB"FUS9W-T<B`BI$"DZR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B
M2F%P86X@**3II;LI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G
M:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`BI.FDY2`H25-/
M+3(P,C(M2E`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I
M9"`B2F5R<V5Y(@IM<V=S='(@(K]!INBN<2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM
M<V=S='(@(DIO<F1A;B`HK/FEN2DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("*D0Z3K(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T
M<B`BI+NDZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`BN>^[]"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("*X;:2D(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("*EJJ5KN>^[]"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BOF&EJKGON_0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("*^8:5KN>^[
M]"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA:VAS=&%N(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V,PIM<V=I
M9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`BJT^O9*WLO,L@/R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2V5N>6$B"FUS9W-T<B`B2V5N>6$@**K6J,@I(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@NWO#TK_Y
MNWXN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N
M96P@3F5W8FEE<R(*;7-G<W1R("*NUJ3?MW.DXB(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@
M(JKWQE^KV*7?(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T"FUS
M9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`BJO?&7Z]3O'@B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`BJO?&7ZKXJ]<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(JKWQE^KK+I!(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G
M92(*;7-G<W1R("*J]\9?NWFJ:R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("*EV*MEJKJDO;9]JO?&7Z;XJD&^N:2D
M+*1WN&>F<Z9BIT&JNJKWQE\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0S"FUS9VED(")+:61S(@IM<V=S='(@(JC@M:,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB
M871I(@IM<V=S='(@(DMI<FEB871I("BP\JB]I-JTM2DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F("BE7\'Z
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A
M+"!297!U8FQI8R!O9B`HJV[!^BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(L'ZI.4@*$55
M0RU+4BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=7=A:70@**SLJ\*O
M4RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2WER9WEZ<W1A;B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U
M="(*;7-G<W1R("*JJ:VQL'2X;5]Y(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`BNWFHI2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T
M<B`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,@*+QDL.HI(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM
M<V=S='(@(J15I6*DZR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM
M<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`BL\RJ\:1`IKBQ
M2[U8Q=RG\ZGS(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C
M:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(J15
MJ;:DZR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T
M(%5P9&%T960Z(@IM<V=S='(@(J17IKBG\[=S.B(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@
M)7,B"FUS9W-T<B`BI%>D0*:XM6ZD2CH@)7,B"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S
M(&9R;VT@)7,B"FUS9W-T<B`BI%>D0*:XM6ZD2CH@)7,@IML@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E
M<B(*;7-G<W1R("*D5Z1`IKBU;J1*.B"RQ*1`IKBU;J1*(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M871V:6$B"FUS9W-T<B`B3&%T=FEA("BIU++FNONHR"DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("*J:ZO?(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`BJJFML;!TN&TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),
M96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M3&5B86YO;B(*;7-G<W1R("),96)A;F]N("B^I*3:N>`I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED
M("),969T(@IM<V=S='(@(J6JP^0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$P.`IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`BI:K#Y*KMP%DB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-`IM<V=I9"`B3&5F="!V86QU97,B
M"FUS9W-T<B`BI:K#Y*W((@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE
M<V]T:&\@*+_@K\&FJRDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@(K=2L:$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I82`HO^"D\;?GJ,@I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8GEA
M;B!!<F%B($IA;6%H:7)I>6$@**=1I/&HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N
M<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B`HID.DY+2PM+6U;BDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I
M9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("*W3*M"(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A
M:6XB"FUS9W-T<B`BI'"K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S
M='(@(J:MIK.D<*M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("*Q
MWZ:SI'"K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("*D<+!]
MJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`BI'"K
M0J:SN7`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("*D<+.W(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI
M9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(J1PL'VSMR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`BI;2J
M;[C6(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,3@*;7-G:60@(DQI;FLB
M"FUS9W-T<B`BLW.ULB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z
M(@IM<V=S='(@(K-SM;+"2:CL.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP
M;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(L7CI=RNR;-SM;*V
M;*7SINVG?:CLO7.\9[9LI?.MMJVQ(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("*S
M<[6R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"B,L(&9U>GIY"FUS
M9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`BPT.FXB(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(J9#I5@@+2"HSZ7.JLRE::5(
MK-VH[+-OK=.K2*7SIU@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS
M9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("*F0Z58N.JNQJYW(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4
M;W!I8W,B"FUS9W-T<B`BID.E6+NAJ?J\T,-$(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`BID.E6*KM
MKN8B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@
M(DQI<W0M07)C:&EV92(*;7-G<W1R("*P4;W7N'.RU2W`R:[7PF0B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L
M<"(*;7-G<W1R("*P4;W7N'.RU2VH1*=5(@H*(SH@;&EB+TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(K!1O=>X
M<[+5+</1IT^XN;U8(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(K!1O=>X<[+5+;[6IK.J
MS"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B
M3&ES="U0;W-T(@IM<V=S='(@(K!1O=>X<[+5+;%(I?.D2"(*"B,Z(&QI8B](
M;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I
M8F4B"FUS9W-T<B`BL%&]U[ASLM4MK7&^7"(*"B,Z(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G
M<W1R("*P4;W7N'.RU2VH^J[XK7&^7"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A
M:6QE9#H@)7,B"FUS9W-T<B`BID.E6+=\M,&EHK'1.B`E<R(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG
M('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`BID.E6*C/I<ZJS*6BL=$Z("5S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED
M("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*F0Z58J,^E
MSJK,JKJE7*_@LU'#]K.L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W
M"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(J3EOL<B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M=&AU86YI82(*;7-G<W1R("),:71H=6%N:6$@**7?L[.I>RDB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN
M9RXN+B(*;7-G<W1R("*X_*1*I*0N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B
MM^VF8:[)MJ$Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I
M9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(J9AL,^[4*[)MJ$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI
M8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@
M(J9AL,\B"@HC.B!L;V=I;BYP:'`Z,3@V('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`BM6ZD2B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F
M('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S
M='(@(K5NI5@B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@
M(DQO9VEN(@IM<V=S='(@(K5NI$HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("*U;J1*I'6G0"(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN(@IM<V=S='(@(K5NI$JEHK'1+""]T,#+K&2[U:15
MJKJESJ3AIE>I3;%+O5@L(+5-J^&MJ[C5+B(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY.#@*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`BM6ZD2J6B
ML=$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-CD*;7-G:60@(DQO;F<@
M=&5X="(*;7-G<W1R("*J^*5Y(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0X"FUS9VED("),;W9E(@IM<V=S='(@(K=2L:$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S
M='(@(J=#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*
M;7-G<W1R("*D<+QGI\;#OKS&IG(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(J1PO&>IU*1"O,:F<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*
M;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`BI'"\9\.YL*B\
MQJ9R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8F]U<F<@
M*+]CM,NS^2DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,SDX(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,S8*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(J3K
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]4
M1"(*;7-G<W1R("*H0Z3IL%2NIR(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&(*K^I5O`R:[7I*2H4Z:S
MN.JNQBXB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUA8V%O(@IM<V=S='(@(DUA8V%O("B_1*KY*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O
M;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B`H
ML*BHY+EYID"I3;#J*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-
M861A9V%S8V%R("BPJ+E&I5NTM:5;*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`BQ5VS3B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R("*V
M;*7S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R("*V;*7SNMZR>B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B
M36%K92!L:6Y?:RXN+B(*;7-G<W1R("*KV*7?LW.ULE]K+BXN(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`B36%L87=I("BPJ*G4J\(I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M86QA>7-I82(*;7-G<W1R(")-86QA>7-I82`HL*BHTZ;HJ,@I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-86QD:79E<R(*;7-G<W1R(")-86QD:79E<R`HL*BZN*9AI-(I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")-86QI(@IM<V=S='(@(DUA;&D@*+"HIU$I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT
M82(*;7-G<W1R(")-86QT82`HL*BZN*5,*2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T
M<B`BNMZR>J=!JKJDP,/^+*C#I4*LL*3`P_ZS7:EWPT.FXBXB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P
M,C0@;6%P(@IM<V=S='(@(DUA<#(T(*9AN<\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM
M<V=S='(@(DUA<%%U97-T(*9AN<\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA
M<F-H(@IM<V=S='(@(J14I.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T
M<B`BP^2LR2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@
M(KS0L$^FJ""LW;E,+Z6\K-VY3"(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`BO-"P3Z:HJ.2E3*JZ
MP]&G3R`HJ-*F<"X@K:NM;B^D=Z9>PM`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)
M<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL($ES;&%N9',@*+"HKDRZN+ASKG$I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEQ=64@*+"H
MM*.EIZ=*KG$I(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*
M;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("*DQ[!TQ.:F[*2D(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I=&%N:6$@**U4IU&V
M\*6GJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET:75S
M("B\KZB]INBTM2DB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("*D
MN;-<JKJSS*1JPDF\QBXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M(@IM<V=S='(@(JK^I?.\QJ78I'>V5Z58I+FS7*17K:TN(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R("*SS*KQ(#(T(*1PKLFJNK/,L*JWQ:O7.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`BL\RJ\2`V(*1PKLFJNK/,L*JWQ:O7.B`B"@HC
M.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R
M=&%L($)L;V-K<R(*;7-G<W1R("*PS[;TI%>MK;S&I=@B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.3`R(&QI8B](;W)D92]&;W)M+G!H<#HQ,C(Q(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C0S"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G
M<W1R("*DN;-<L\RD:JKXJ]<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(J2MI.LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-
M87EO='1E(@IM<V=S='(@(DUA>6]T=&4@*+"HK/FO4ZYQ*2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
MPN6^QR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BIJBM^R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`BO^^S
MYKS2IJ$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`BIEBH
MUL!XIG.NYB(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BMFRE\R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`BMFRE\\7GP]*D
M=Z>YIJ@LIOVL3ZC/I<ZJS*JZP[&SN:MOM4RJ:[-QN4S%Y\/2+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S
M86=E(&5X<&ER960N(@IM<V=S='(@(L*RL%2D=[E,M,$N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`BPK*P5*NLND$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE=&%R
M(%=E871H97(B"FUS9W-T<B`BI=BK9:31KO`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")-971A<B"PS[;TM4RJ:ZC/I<XN(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(DUE=&%R(+#/MO2U3*IKJ,^ESBX@LM.X8+W0L-&F
MTJATLLZZWK)ZM6Z__2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S
M='(@(DUE=&%R1$(@J7REO+-SL;4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("*DZ*IK(@H*(SH@;&EB+TAO<F1E
M+U)00R]X;6QR<&,N<&AP.C@Q(&QI8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E
M9FEN960B"FUS9W-T<B`BI.BJ:R!<(B5S7"(@I;RS4:EWN'$B"@HC.B!L:6(O
M2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B
MI.BJ:Z6\J7>X<2X@I4BI2:5SI.BJ:SH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I
M9"`B365T<FEC(@IM<V=S='(@(J2]J.XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G
M<W1R(")-97AI8V\@*+ZEINBM]"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6-R;VYE<VEA+"!&961E<F%T
M960@4W1A=&5S(&]F("BQ2Z=*P[FEIZ;HJ,@I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D
M;&4B"FUS9W-T<B`BI*2VH2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;64@JZRZ
M02(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`BL\RJ\2`R-""D<*[)JKJSS*=#
MM\6KUSH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(K/,JO$@-B"D<*[)JKJS
MS+"JM\6KUSH@(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS
M9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D
M(@IM<V=S='(@(K/,M76Q2[U8KL2TP:E\I;RH[+3!(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,PIM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(JQ-KF<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G
M:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`BPOBVM2(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#`*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+B(*;7-G<W1R("*GY*2CJ.P@4$5!4B"E7;C+($A45%!?4F5Q=65S="XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG
M(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I
M9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T
M<B`BLUVI=\#)O_*EHBX@IG"J1ZUNJ,^ESK-OK=/`LZ7.M7NFH:=!I;*VM[)[
MIF*T3K*CI<VE3"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("*G
MY*2CJ.S"LK!4JKH@240N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A
M8VMA9V4@36%I;"XB"FUS9W-T<B`BI^2DHZCLI;*VMZJZ(%!%05(@I5VXRR!-
M86EL+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT
M"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(J?DI*.H[+=\
MM,&JNB!)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("*L4+3!I$`B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM
M<V=S='(@(J;FL,JV;*7S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(K?%J4TB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M("*G\[=SI.FTP2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R
M("*MUZ?ONO2G?2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<T
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(KS2LM4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O
M=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=F$L(%)E<'5B;&EC(&]F
M("B\K[JXIFBERRDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA8V\@
M*+ROK\>M]"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;&EA
M("B[6*5J*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3@X"FUS9VED(")-
M;VYT:"!A;F0@>65A<B(*;7-G<W1R("*DZZ3.IGXB"@HC.B!L:6(O2&]R9&4O
M36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(JA#
MI.LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`BNUBVZZG4KU,B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*
M;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(J3KK-LB"@HC.B!L:6(O1FEL
M92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("*F8K+$)62FYJ?DJ.RJNL3FINR\
MQJ78I'>V5Z58N7>TP25D+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("*\
MKZREK?0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(J9HMK.NR;2X(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G
M:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`BIFBVLZ[)L[$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY(%-U;FYY(@IM<V=S='(@(K2XKLFF:+:S(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B
MI%6ROB(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I
M9"`B36]V92!,969T(@IM<V=S='(@(J6JLKXB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B
MI6NROB(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I
M9"`B36]V92!5<"(*;7-G<W1R("*D5[*^(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PIM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(J15LKXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*
M;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BI%>ROB(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB
M:7%U92(*;7-G<W1R(")-;WIA;6)I<75E("BR]J14I/&G2BDB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S(@IM<V=S='(@(KW&O^^FH:15J=2E7*_@JNTB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0HC+"!F=7IZ>0IM
M<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(J9HO':YLR(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C0V"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`BO<:_[R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`BI]JJNK%BN+DB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`BI]JJNK%BN+FXZK!4(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S
M='(@(JW3I$BON*5X(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S
M-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("*MTZ1(K[BE>*VV
MK;&P=+AM(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(@*+UQ
MJ&PI(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("*DHRRG
MVJ2CIE"W3B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,2!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B
MIE>ZV2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI8FEA("BHNJ;,
MI/&HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U("B_U;Y\*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86P@**6GJGFZN"DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYE=&AE<FQA;F1S("BR_,3U*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").971H97)L
M86YD<R!!;G1I;&QE<R`HLOS$W:9WIF&F0[2U*2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*
M;7-G<W1R(").971S8V%P92"LL+#RPJ:JNKKTIWTB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@OLS#TJ=`O&^Z]*=](@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E
M($-!('!O;&EC>2!54DPB"FUS9W-T<B`B3F5T<V-A<&4@OLS#TJQ&M::Z]*=]
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE
M='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E(*?SMW.Z]*=]
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE
M='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(*=`O&^Z
M]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@
M(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").971S8V%P92!3
M4TP@IOBJ0;ZYIE>ZV2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S
M='(@(DYE='-C87!E(+[,P]*JNK7YN-$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP
M92(*;7-G<W1R(").971S8V%P92"^S,/2JZRZ02(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`BNO2X
M]*1UJ.,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDP"FUS9VED(").979E<B(*;7-G<W1R("*Q<:6\(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@
M0V%L961O;FEA(@IM<V=S='(@(DYE=R!#86QE9&]N:6$@*+=SL]BHO:9HI:>H
MR"DB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR
M-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(K=SO%>DP,/^(@H*(SH@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#$@;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+U1E>'0O
M1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M
M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E
M('1O("5S(@IM<V=S='(@(KQGJTBUN2`E<R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`BMW.DZR(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5
M<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(K=SJ,^ESJK,IE>ZV2`HJT2E
MLJUN*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F5W(%IE86QA
M;F0@**_#INC$]2DB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("*W<[%+O5@B"@HC.B!L
M:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(K=S
ML4N]6+%.J?,E>*CLM,$N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G
M<W1R("*W<[%+O5BDH[+%IE@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK
M*2(*;7-G<W1R("*W<[7XM:$@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R("*W
M<[M$(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B
M3F5W<V=R;W5P<R(*;7-G<W1R("*W<[M$N'.RU2(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(J15
MI$"H0B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("*D5:W3I.NLVR(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S<R(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,S<V"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`BI%6D0*W3O^^VM2(*
M"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*
M;7-G<W1R("*D5:1`K;8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").
M:6-A<F%G=6$@**6GI5NIU*7**2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B
M3FEG97(@**6GI.DI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI9V5R
M:6$@**E@I,ZG4:C(*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(K'?I%<B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI
M=64B"FUS9W-T<B`B3FEU92`HK\.N2JYQ*2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(J=?
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED
M(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+B(*;7-G<W1R("*U3*5IJ-'%XZ7<KG2RIZJZLUVI=[CJ
MKL8N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS
M9W-T<B`BM4RE::7.JKJUIK*DJ]BS>2!)4T\@O':YLRXB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@
M=&5M<&QA=&4N(@IM<V=S='(@(JA3IK.GY::XO,NFH2XB"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HW.2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HR-#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS
M9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;B(*;7-G<W1R("*ITJO\J7>JNJ;LN&VD5ZA3IK.PS[;TIG.F8B(*"B,Z(&QI
M8B](;W)D92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("*H4Z:SM*.HT:;FJ,:^Y*97NMFE2*C1($U#04P@Q>?#TBXB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R
M("*H4Z:SQ=RG\RXB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM
M<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`BM4RJ:Z9BI=BK9<5VK:VDI+Q7I5NFN,5VK:TN(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H<#HU,#@@;&EB+TAO
M<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S
M='(@(JA3IK.K_*EWJKH@)7,@LUVI=[CJL%0N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C@T-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(JA3IK.K_*EWJKH@1E10
M(%9&4R"S7:EWN.JP5"XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-C<R"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RXB"FUS9W-T<B`BJ%.FLZO\J7>JNB!344P@5D93LUVI=[CJL%0N
M(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R("*H4Z:SJ_RI=ZJZ(%-13"U&:6QE(%9&4[-=J7>XZK!4
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS
M9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`BM4RST;YLPDF\QBXB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`BI;RTHZC1I=BJNBXB
M"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`S"FUS9VED(").;R!F:6QE
M('5P;&]A9&5D(@IM<V=S='(@(L#)KM>EO*17ML<B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R
M("*GY*2CJ.RYSZ7<+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S
M='(@(J;LN&VXZK!4J7REO+-=J7<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`BJ7REO+2CJ-&F[+AMN.JP5"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R("*EO+2CJ-'"LK!4+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R("*EO*O\J7>F5[K9+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM
M<V=S='(@(J6\J_RI=[BYO5@N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDT"B,L(&9U>GIY"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS
M9W-T<B`BI^2DHZCLN<^EW"XB"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H
M<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(J-$@2%144"#%
MY\/2+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(J-$@24U!4"#%Y\/2+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(JA3IK.K_*EWL4N]6*5(J-$@2V5R8F5R;W,@Q>?#TBXB"@HC.B!L:6(O2&]R
M9&4O075T:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z
M.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("*H4Z:SJ_RI=[%+O5BE2*C1($QO9VEN(,7GP](N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3
MIK.K_*EWL4N]6*5(J-$@4$%34U=$(,7GP](N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BJ%.FLZO\J7>Q2[U8I4BH
MT2!334(@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R
M.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(J6\O^FD2B!/
M<&5N4U-,(*1'I+BP]:;FP,FJNJ7^N/2N?"X@4$M#4R`Q,B"S5Z[FJKJE6[%+
MN.JNQKO=K6ZESJCLN-.U>Z:A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS
M9W-T<B`BJ%.FLZO=O&:JNK7YI56ET[W0+B(*"B,Z(&QI8B]61E,N<&AP.C<V
M-0IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("*ZS[K0L'3#0J6\LUVI
M=R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(K5,KN:]=2(*"B,Z
M(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E
M8VEF:65D+B(*;7-G<W1R("*I?*6\J_RI=\3FINRDP+EJIG*DN"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"FUS9VED(").;R!S:61E<R(*;7-G<W1R("*U3*[8O74B"@HC.B!L:6(O5D93
M+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`BM4RF
MN<#)KM<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS
M9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N(@IM<V=S='(@(K5,O,BF<Z78O_VE::C1I]:H^BXB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"!S96YT+B(*;7-G<W1R("*EO+;'L&6HSZ7.JLRF5[K9J<ZQ2[U8+B(*"B,Z
M(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED
M(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(K5,I6FESJJZ(%A-3""XZJ[&
MLU&VQZ9>(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO
M('9A;'5E<R(*;7-G<W1R("*JQ:75K<@B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`BK>RI;+-=J7?`R:2DI^2DHZCLJJFEN[CJL%0N(*VKMW.RHZ7-LUVI
M=\#)+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(J9BIT&JNK-=J7?`R:2DI^2D
MHZCLJJFEN[CJL%0N(*VKMW.RHZ7-LUVI=\#)+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`BM4PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED
M(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(K5,("AU<V4@:6UP;&EC
M:70I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(J3IIM6PTJ3E("A)4T\M.#@U.2TQ
M,"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&L@
M27-L86YD("B_U;K6ITJN<2DB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(J5?I6*R>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S(@IM<V=S='(@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G=A>2`HKK^KPBDB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R
M(@IM<V=S='(@(JM$I*>KX2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(JM$I*>K92(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z-#$R"FUS9VED(").;W0@82!D:7)E8W1O<GDB
M"FUS9W-T<B`BI*.L3Z1`K=.EV+_](@H*(SH@;&EB+U9&4R])4T]7<FET97(N
M<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(K5[
MIJ&I?*6\I[FFJ"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(J2CLUVI=R(*
M"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,#@@;&EB+U9&4RYP
M:'`Z,C,S(&QI8B]61E,N<&AP.C(U,0HC.B!L:6(O5D93+G!H<#HR-C@@;&EB
M+U9&4RYP:'`Z,C@T(&QI8B]61E,N<&AP.C,P,"!L:6(O5D93+G!H<#HS,34*
M(SH@;&EB+U9&4RYP:'`Z,S,R(&QI8B]61E,N<&AP.C,V-2!L:6(O5D93+G!H
M<#HT,C4@;&EB+U9&4RYP:'`Z-3`T"B,Z(&QI8B]61E,N<&AP.C4W,R!L:6(O
M5D93+G!H<#HU.3`@;&EB+U9&4RYP:'`Z-C8X"B,Z(&QI8B](;W)D92]397-S
M:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3<U(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&QI8B](;W)D92]3
M97-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("*EO+-1I.2TJ2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S
M='(@(K/&I]&__2(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS
M-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@
M(JA3IK.E:<)SQ/VJNBRF7J5H+B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("*D4:1`I.LB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U,`IM<V=I9"`B3G5M8F5R(@IM<V=S
M='(@(KS&IG(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R.0IM<V=I9"`B
M3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`BIG*DN+S&(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU
M;6YS(@IM<V=S='(@(J9RI+B\9:O7(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(J;FO,8B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED
M(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*G\[=SL'2X;;ASLM6NR:6\J_RI=[S&
MI=@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S`*;7-G:60@(D]B:F5C="(*;7-G<W1R
M("*JJZ7S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G
M:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(JJKI?.KV*7?JLPB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3$P.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
MI$NV::;L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G
M:60@(D]C=&]B97(B"FUS9W-T<B`BI%&DZR(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E
M(@IM<V=S='(@(K_LI+VKQR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@
M9&EF9F5R96YT+B(*;7-G<W1R("*W<[%+O5BELK:WNU#"PK%+O5BDHZ90+B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD
M('!A<W-W;W)D(@IM<V=S='(@(L+"L4N]6"(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C
M;W)R96-T+B(*;7-G<W1R("+"PK%+O5BDHZ6_O50B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB
M"FUS9W-T<B`B3VUA;B`HJORPTBDB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(J5UIK,@24U!4""F^*I!OKFD
MY+2IJTBE\Z=8I,"HR:5<K^`N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDU"B,L(&9U>GIY"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*
M;7-G<W1R("*GY*2CJ.RYSZ7<+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"FUS9VED(")/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(J5UI+FS7*1`K=.V;*7S
MINVG?2XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@
M(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E(@IM<V=S='(@(J5UIK.^UJ:SJLR[4*ATLLZZWK)ZK?NE::5(
MQ=RG\Z9`J,G%=JVM(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(J9BMW.JNK7XM:&V?;'2(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM
M<V=S='(@(D]P96Y34TP@O_F[?CH@M4RJ:[%Q(%,O34E-12##L;.YJOZE\[C1
MMGVXZJ[&+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("*F8K=SJKJU^+6AMGVQTK-SM;(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T
M96TB"FUS9W-T<B`BIT"W?JATLLXB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(K_OMK4B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B)7._[[:U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(K:U
MI=B]<[BY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G
M:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("*RU<*T(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`BLM7"M+/FINPB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(K+5PK0B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`BK>RI;,"SI<ZU>Z:AO,NJ3R(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G
M:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`BIF(@)7,Z
M(*2DJKJM[*ELO,NJ3RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G
M<W1R("*HY*5,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I
M9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`BJ.2E3+CJL%0B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M
M:7-S:6]N<R(*;7-G<W1R("*^UJ:SJLS%=JVM(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!32#%Y\/2M4RNQ"XB"@HC.B!L:6(O
M3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I
M;"!B86-K96YD(@IM<V=S='(@(E!%05(Z.K9LI?.F^*I!NMTB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3
M:6=N871U<F4B"FUS9W-T<B`B4$=0(+S&INS#L;.Y(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(E!'4""E6[%+N.JNQB(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'
M4""DO;9]JO?&7R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-38*
M;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0
M(*1WP[&SN2^D=Z5;L4L@N.JNQB(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV
M.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(+5[IJ&]6"(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@
M(E!(4""O\[U:(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`BI,BKX:1P
MJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("*DR*OAL'VK0B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")0
M32!3;F]W(@IM<V=S='(@(J3(J^&FL[.W(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R("*DR*OAL'VSMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`BI,BK
MX;2X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(J3(J^&Y<*M"(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS
M:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B4$]325@@97AT96YS:6]N(+_RI:(B
M"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T
M<B`B4$A0(*_SO5I?2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B
MN=2E4B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86X@**3:
ML/*TM:E:*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U("BIK:];
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B
M"FUS9W-T<B`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"`HI-JP
MQ[2UJ5JF^[OBL,\I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA
M("BDVJZSL*@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@
M(E!A<'5A($YE=R!'=6EN96$@**3:I:RHR+=SM%BDNJC(*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y("BDVJG4IF,I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A
M<G1L>2!#;&]U9'DB"FUS9W-T<B`BIFBVLR(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P,C(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT
M,R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R
M9"(*;7-G<W1R("*Q2[U8(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`BL4N]6,7<I_.GN::H+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S
M='(@(K%+O5BDHZ6_O50B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP
M.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`BJ%.FLZO\J7>Q2[U8I4BHT2!2041)55,@
MQ>?#TBXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`U-PIM<V=I9"`B4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`BL4N]6+U4NWLB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W
M;W)D.B(*;7-G<W1R("*Q2[U8.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(K%+O5@Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED
M(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`BL4N]6*6RMK>G:Z98
M+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T
M92(*;7-G<W1R("*V2Z17(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B
M"FUS9W-T<B`BMDND5R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`BN/2N?"(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG
M(%-I9VYU<',Z(@IM<V=S='(@(JO=O&:U;K_]H4<B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R("*FJ*W[(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*
M;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`BILJDP*3Q(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("*P]:;FNOO%0+[>
MIT`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@
M(K5NI$JKX;#UIN:Z^\5`OMZG0#\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("+%=JVM(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B7"(E
M<UPBJKK%=JVMI;RS4:=2L*,N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4Y,`IM
M<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`BIG.H^KY$J=HB"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V,2!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ7:MK2(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(L5VK:VZWK)Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G
M<W1R("*GVJJZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4@**^UOGPI
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM
M<V=S='(@(L-DJJLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(E!H
M:6QI<'!I;F5S("BUX:O?NZLI(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(KEQN-PB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B
M"FUS9W-T<B`BP\"T62(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I
M=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("*YLZ_`(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;"(*;7-G<W1R("*]T+9II$K`>*9SKN;"2;_O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z(@IM<V=S='(@(KW0O52I=ZUNLKZPHZ:YI+BE\SHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="XB"FUS9W-T<B`BO="]5*EWIT&M;J2DPE^FN:2XI?.J
MNK-SM;(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U-C8*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(KW0O^FD
M2J1`K=.DZZ7WI,ZF?J7W+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("*]T+_II$JW<[Q7I,##
M_JJZIE>ZV3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`BO="_
MZ:1*I$"MTZ:SKL2JNB!)4""F[*=](@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(V-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K
M('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(KW0
MO^FD2J1`K=.FLZ[$JKJDZ;3!.Z3$O^^FN:3KI?>JNJ3IM,$N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED('1I;64N(@IM<V=S='(@(KW0O^FD2J1`K=.FLZ[$JKJNR;:A+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B
MO="THZC1L-W#1*JZNDNM;BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S
M='(@(KW0O^FD2J=!JKJHSZ7.JLRF5[K9I,ZQ2[U8(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("*]T+Y<Q:JD5:9#I+JN
M92ZG0:6RMK>F4+=.LV^HQZC&MK6D?J_@J,^ESJATLLXN(@H*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`BO="_Z:1*
MMW.JNJ3`P_ZF5[K9.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&%N
M9"`HJFG$]2DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@
M(E!O;&ET:6-S(@IM<V=S='(@(JQ&JG8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R("*GZ[*\(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM
M<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86P@*+BRM>6D^BDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS
M9W-T<B`BO':YLZ;LN&TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T
M86)L92(*;7-G<W1R("*J[:[FINRX;2(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H
M;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(KN\L&6V;*7SJ.RS;ZW3
MJTBE\Z=8("AN;W0@96YF;W)C960@8GD@24U!4"DB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ("(*;7-G<W1R("*SS*KQ("5S(*1PKLFJNJVPJT*V<3H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("*ML*M"/&)R("\^OO>R=B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<F5F<U]L9&%P.B"GY*2CJ.RITKO=K6ZJNB!,1$%0(*FUIOFN3:7S+B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B"GY*2CJ.RITKO=K6ZJNB!S
M97-S:6]N(*FUIOFN3:7S+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U
M"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("*N\,"C(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@
M(@IM<V=S='(@(J[\I:VML:[PP*,Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`BKO#`
MHSH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`BN7?$_2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(J9BMW.JNK7XM:&Y=\3]O':YLR(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,S8R(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V
M"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(J17I$"MT[_OMK4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q
M"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("*F0Z9,I.6E\R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+
M97DB"FUS9W-T<B`BJ'"Q2ZKWQE\B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z
M,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(K#=PT0B"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB
M"FUS9W-T<B`BL-W#1+1YK7HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("*Q3:[7(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q,34@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.3(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*;7-G:60@(E!R;VUP="!T97AT(@IM
M<V=S='(@(K2CI=RDNJYE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(J2]MGVJ]\9?(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+
M97D@06QG;W)I=&AM(@IM<V=S='(@(J2]MGVJ]\9?NG2ZXB(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN
M9F\B"FUS9W-T<B`BI+VV?:KWQE^XZK!4(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("*DO;9]+ZAPL4NJ
M]\9?N>^HPZ6\LU&RHZ7-+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S
M='(@(E!U97)T;R!2:6-O("BJ::9HOJ2F52DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*
M;7-G<W1R(")1871A<B`HI62Y1BDB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(JQDN-\B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(KK/NM"P=+AM
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B
M4E-!(*2]MGVJ]\9?("@E9""F[*2X*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C8X"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`BO^^^W+9S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*
M;7-G:60@(E)A:6XB"FUS9W-T<B`BJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G
M<W1R("*FK::SJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(K'?IK.K0B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R("*P?:M"(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD
M(%-N;W<B"FUS9W-T<B`BJT*FL[.W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G
M<W1R("*K0L+@L[<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I
M9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`BP$B^]Z1PNWDB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`BI/&R=B(*
M"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D
M(@IM<V=S='(@(L6JJ/HB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`BQ:JH^K9L
MI?,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`BKW6JNJUNIU*PHR`E
M<R"VW#\@LV^VM;[>IT"Q3K5,JFNK[+1?+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("*O=:JZK6ZR3;"CJ,^ESJK,
M("5S(*JZN.JNQK;<(#\@LV^VM;[>IT"Q3K5,JFNK[+1?+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(JCZKOBT7ZWL(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`BK:NW<[[CLGHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`BK:NW<[[CLGJPRKI!I=B__:2X
MI?,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F
M<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`BK:NW<[[CLGJMTZ1(K[BE>*2Z
MKF4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B4F5G
M97@B"FUS9W-T<B`BL6"S5ZKMI=RFH2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C,X"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("+#
M]L%PPG/$_;ZY(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D
M(@IM<V=S='(@(JVKQ:HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R("*U^[W7(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B
MN[>ZW:;XJD&^N2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(@IM<V=S='(@(KNWNMVZ]*=]("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G
M:60@(E)E;6]V92(*;7-G<W1R("*ROK"C(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B
MLKZPH[#/MO0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34V"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(K*^L*/$YJ;L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BI6BPHZ[FIJ$B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`BLKZPH[GO(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(J;;IOBJ0;ZY
MO,BF<Z78O_VDI+*^L*.D=\!XIG.JNK-=J7>U>Z:A+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I
M9"`B4F5M;W9E('1H92(*;7-G<W1R("*ROK"C(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")2
M96UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(J;;
MI.6E\Z2DLKZPHZ:YI$"X8,))(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`BLKZP
MHZC/I<ZJS"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T
M<B`BLKZPHZC/I<ZJS#H@)7,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP
M:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2
M971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("*[W:A$I;RS4:9>P+,Z(+_Y
MNWZXN;U8.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*
M;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB
M"FUS9W-T<B`BI^2DHZCLJ=*[W:JZJD&PR"XB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$W-B!L:6(O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(E,B1S(*JZLUVI=Z6RMK>K_*EW(%PB)3$D<UPB(@H*
M(SH@;&EB+U9&4R]S<6PN<&AP.C8W."!L:6(O5D93+V9T<"YP:'`Z.#4P(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5D93(*JZLUVI=Z6RMK>K_*EW(%PB)7-<(B(*"B,Z
M(&QI8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`BLUVI=[CJKL:ELK:WJ_RI=R!<(B5S7"(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&
M:65L9"(*;7-G<W1R("*ELK:WQ.:F["(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&QI8B](;W)D92]&;W)M+G!H<#HS-#,@;&EB+TAO<F1E+T9O<FTO4F5N9&5R
M97(N<&AP.C,R,`HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(JVKLUTB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BK:NS7;%+
MO5@B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("*MJ[-=IT&JNK%+O5@Z(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T
M(%%U97)Y(@IM<V=S='(@(J9>IG.SS*OAI$"MTZQDN-\B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R("*ULJI'(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G
M<W1R("*J\*9>O^^VM2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("*F0::X
MO^FD2K=SL4N]6"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO
M;B`HKV2EIZGTKG$I(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG
M=7)A=&EO;B(*;7-G<W1R("*F7K1?LUVI=R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*
M;7-G<W1R("*Z]*VVO7._Z+ZYO^^VM2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("+!O+MY(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS
M9VED(")2:6=H="(*;7-G<W1R("*E:\/D(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,3`*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("*E:\/DJNW`
M62(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`V"FUS9VED(")2:6=H="!V
M86QU97,B"FUS9W-T<B`BI6O#Y*W((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`BID.DNJYE7W<N+BXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G
M<W1R("*HI*;B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2;VUA;FEA
M("C#N;"HI:>HR"DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(T"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(K';PN`@,3@P
M(*O7(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M,0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`BL&:NR;!W(#DP(*O7L=O"
MX"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C<*
M;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("*VMJ[)L'<@.3`@J]>QV\+@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`BID.DNJYE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`BID.DNJYE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(J9#(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L
M97,B"FUS9W-T<B`BKN:]=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BQ.:F
M[+M0ID.NYKUU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`BQ.:F[*[FO74B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G
M<W1R("*F0Z[FO74B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED
M(")2=6XB"FUS9W-T<B`BL/6FYB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A
M=&EO;B(*;7-G<W1R(")2=7-S:6%N($9E9&5R871I;VX@**M8P[FTM2DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A("B_8Z9WN48I(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@I5NQ2\.Q
ML[DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(K9LI?.D=ZC/I<X@
M4R]-24U%(*5;L4LB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM
M<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")305-,(,7GP]*U3*[$+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`BPK*P
M5"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(KCJKL:N=Z_SO5HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S(W,@IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS
M9VED(")34T@B"FUS9W-T<B`BI5NQ2[+7NMV^]R(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#
M0T534R(*;7-G<W1R("*FJ*5<(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED
M(")37U%,(%-H96QL(@IM<V=S='(@(KCJKL:N=Z_SO5I?42(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A
M(@IM<V=S='(@(JQ0M,&DNR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G
M<W1R(")386EN="!(96QE;F$@*+ATNZZPQZ_'*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@
M2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S(&%N9"!.979I
M<R`HN'2G2JB]M+6F:+K6I,ZEI[K[M+4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I
M82(*;7-G<W1R(")386EN="!,=6-I82`HN'3%4Z;HJ,@I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B
M4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN="!0:65R
M<F4@86YD($UI<75E;&]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,@*+ATI.6TRZ3.KN:WYZBZI$(I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F
M<F%M92`H7W-E;&8I(@IM<V=S='(@(J90I$"MT[7XM:$@*%]S96QF*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A("C"Q+ROJ,BX<ZYQ*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*
M;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R`HN'2PJ*=1
MO]4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@
M(E-A;R!4;VUE(&%N9"!0<FEN8VEP92`HN'2F:*S\I,ZTMJI,INBD\2DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET
M92!0<F]V:61E<B(*;7-G<W1R("*]PZQ0M*.HT:K,(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U
M9&D@07)A8FEA(@IM<V=S='(@(E-A=61I($%R86)I82`HJ$:O4:9AJORIU*="
M*2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B
M4V%V92(*;7-G<W1R("+`>*9S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<
M(B(*;7-G<W1R("+`>*9S(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS
M9W-T<B`BP'BF<R`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*
M;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("+`>*9SO^^VM2(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`BL4ZRHZ7-
MJKJS7:EWP,FE2"!02%`@NWFHI:[FIJ'`>*9SJ.RG0:JZIOBJ0;ZYO,BF<Z78
MO_VDI"XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("*S7:EW("5S(*1WP'BF<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("*G\[=SM7NFH:1WP'BF<ZCL
M.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("*Y
M<ZQ0N7"K0B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B
M4V-I96YC92(*;7-G<W1R("*L[+['(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("*W:K1-(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS
M9W-T<B`BMVJT3:3>P+HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDV,@IM
M<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(K_OOMS`R:[7(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X,@IM<V=I9"`B4V5L
M96-T(&$@9&%T92(*;7-G<W1R("*_[[[<I$"MTZ3IM,$B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@
M=&\@861D(@IM<V=S='(@(K_OOMRD0*W3N'.RU:7.I4BW<[Q7(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W
M(&]W;F5R(@IM<V=S='(@(K_OOMRD0*;LMW.JNK[6IK.JS"(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R
M=F5R(@IM<V=S='(@(K_OOMRD0+.AIOBJ0;ZY(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D
M(@IM<V=S='(@(K_OOMRD0*;LJ,^ESJK,I<ZE2+=SO%<B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<S"FUS9VED(")396QE8W0@
M86QL(@IM<V=S='(@(K_OOMRITJ:S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(V-3`*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G
M<W1R("*_[[[<J=*FLZ3IM,&DN*7S+B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX-S`*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B
M"FUS9W-T<B`BO^^^W*1`K=.JJZ7S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W-`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T
M<B`BI*._[[[<(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED
M("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T
M:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`BJ?.E2*15JKJU^+6A
MI*2_[ZCZIT&M;JJZIG*DN"ZE2+?&N:N]QKMSJ=*_[Z3EIG(LM4VKX;9+I%>D
MY:7SO7._Z+#/+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("*_[[[<
MI.FTP:3`N6HZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(K_OOMRDZ;3!
MI.FTP:[FIJ$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z(@IM<V=S='(@(K_OOMRQ_<7<I_.JNJBMI??#T:=/.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE
M('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("*_[[[<KLFVH:3`N6HZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!F;W)M870Z(@IM<V=S='(@(K_OOMRDZ;3!KLFVH:[FIJ$Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W
M;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(K_OOMRLVZ2LI,>P=*JZI$>M
MT\3FINPN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("*_[[[<IT&JNL-#
MIN*P=+AM(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("*_[[[<
ML+ZF;KMYJ*4Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BML>P9;#=
MPT2DS\"S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(K;'L&7"LK!4(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L("BVZZ2ZI5NZN"DB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS
M9W-T<B`BMU"T^KZY.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`W(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(J1%I.LB"@HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD
M($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEA(&%N9"!-;VYT96YE9W)O("BV
MZ[JXNONHR+M0NUBO4Z6GK?3#N2DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("*GQ[BY
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B
M4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
MIOBJ0;ZYN.JNQK_YNWZISJK,M4RJ:ZC/I<XN(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(K=\M,&Z
MWK)Z(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*
M;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`BMWRTP2!)1""D
M=[E,M,$N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*
M;7-G<W1R("*W?+3!(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,3@*;7-G
M:60@(E-E="(*;7-G<W1R("*NUJCZI.BV]"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*
M;7-G<W1R("*DN;-<IT&I\Z?1L$^Q2[U8JKJNR:W4+*5II4BFVZ;FK:NS7;%+
MO5@N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(K-=J7>[M[K=IOBJ0;ZYI%?$W:GS
MIT&JNJW3I$BON*5X+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM
M<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("*S7:EWIT&JNK"^IFZ[>:BE+""N
MR;#/I4BDSJ3IM,&NYJ:A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES
M<&QA>2!O<'1I;VYS+B(*;7-G<W1R("*S7:EWIT&JNK'2J6S`LZ7.M7NFH2S#
M0Z;BL'2X;2RMMJVQI_.W<\!7LG8LI,ZHY*5,Q>.EW+_OMK4N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B
MLUVI=R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W
M"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S
M='(@(J?SMW.U>Z:AM$ZZ_"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(J:SIFZT6*W3IF'"2:E-LV^M
MT[#1O,:FL\/V.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E
M>6-H96QL97,@*+;KJ?6ZN"DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("+!RJJK(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U
M;6UA<GDB"FUS9W-T<B`BPK*U=;I+K6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`BK$^G7ZRPI&JSH:7WJKJS<[6R
MJ7>X<:?6L;:E7*_@P>0_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`BQ>.EW"(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ>.EW+=SLJ.ES;M0K>S`
M>*9SLUVI=\#)JKJN=+*G+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\B"FUS9W-T<B`BJ$.FN+5NI$JKX<7CI=RD5Z1`IKBJNK5NI$JNR;:A(#\B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C@P,@IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`BQ>.E
MW,))O^^^N2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@
M(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BQ>.E
MW*KMKN:^WJ=`I5ROX*KM(#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_(@IM<V=S='(@(JGSI:K#Y,7CI=P@)7,@I5ROX*KM/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("+%XZ7<P'BF<Z[FI+JN9;GON-RDZ+;T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T
M"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R("+%XZ7<JNVNYJ2ZKF6Y[[C<I.BV]"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(L7C
MI=RF0Z2ZKF6Y[[C<I.BV]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQ>.EW+QVN;.DNJYEN>^X
MW*3HMO0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-PIM<V=I9"`B4VAO
M=R!U<&QO860B"FUS9W-T<B`BQ>.EW*17ML<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G
M<W1R("*K^<3RL'VK0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(J:M
MIK.P?:M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("*QWZ:SL'VK0B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS
M9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("*[MZ3HIK.P
M?:M"(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED
M(")3:')I;FLB"FUS9W-T<B`BIJS!62(*"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C<W-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,S8*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.CDX-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HQ,#0W(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,
M96]N92`HM^"D;*1SL.HI(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`BM?FE52(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS
M9W-T<B`BP[&SN2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R
M"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(L.QL[FZ=+KB
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<&]R92`HMW.E
M6ZE9*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#$*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3D@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,3(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*;7-G:60@(E-I
M>F4B"FUS9W-T<B`BI&JD<"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM
M<V=S='(@(K*DN4RZ^\5`(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B
M4VQO=F%K:6$@*+2UK*6E[Z=**2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S
M='(@(E-L;W9E;FEA("BTM:REI>^EIZC(*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@
M(K.W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(K!]L[<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO
M=R!3:&]W97)S(@IM<V=S='(@(K!]L[<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A
M<FQY(@IM<V=S='(@(J:MIK.P?;.W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E
M(@IM<V=S='(@(K'?IK.P?;.W(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("*_;K.WLF"KUSH@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@
M27-L86YD<R(*;7-G<W1R(")3;VQO;6]N($ES;&%N9',@**_!P[FJ^;ASKG$I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA;&EA("BOP;"HIU&H
MR"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S
M("8@4&]E;7,B"FUS9W-T<B`BNG&[4+C6(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Y,34*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@
M(K'&ID.DZ*96O^^^W"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,38V(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.#D*
M;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(JC3M[VF8:=](@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(E-O=71H($%F<FEC82`HJVZK
M1"DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(JMNO-H@*$E33RTX.#4Y
M+3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<R(*;7-G<W1R(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`BJVZE8K)Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E
M96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A8V5R(@IM<V=S
M='(@(JK%I=6FYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("*VH;9:
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("*V
MH;9:NU"YU*52(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(E-P86EN("BFZ*]:
MI/HI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B
M4W!A;2(*;7-G<W1R("*I5:>CMFRE\R(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`BKU.N[:9RI+B_Z:1*(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G
M<W1R("*DP+/.P'BF<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G
M<W1R("*DP+/.Q.:F["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M("*DP+/.ID,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@
M(E-P;W)T<R(*;7-G<W1R("*Y0K#*(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS
M9W-T<B`B4W)I($QA;FMA("BTM:B]Q/6E9"DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I
M9"`B4W1A;F1A<F0B"FUS9W-T<B`BO-"WQR(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(JQ0N]JJI\51
MOM0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C<Y.`IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("*QTJELIGZE
M]R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("*LV2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T
M<B`BJJRZ02(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`T"FUS9VED(")3
M=&]R86=E(&9O<FUA="(*;7-G<W1R("+`>*9SKN:FH2(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*
M;7-G<W1R("*U\[E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("*G
M4K"CO74B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-PIM<V=I9"`B4W1R
M:6YG(&QI<W0B"FUS9W-T<B`BIG*FZJ9#(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S<*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(J;;MFRE\Z9AIWVDI*5HL*.Z]+#LIE>ZV2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G
M:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(KS+IJ$@6T-34UTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3
M=2(*;7-G<W1R("*L4+3!I-$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H[*:XI=B__2!<(B5S7"(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B
M:F5C="(*;7-G<W1R("*E1*:N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S
M-B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M
M:70B"FUS9W-T<B`BL&6E6"(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(KQ7I5L@
M7"(E<UPB(*CLJ'2RSJJZI=.]T*1WL&6E6"X@IT&ELK:WM:6H[+C3I=.]T+-1
MKM:MXZOAI'ZOX+5NI$HN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(J15
MO-`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S
M<R(*;7-G<W1R("*FJ*5<(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B(*;7-G<W1R("*FJ*5<JKJE6Z1*(%PB)7-<(B"H[*ATLLZD
MI"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("*FJ*5<JKJFVZATLLZDI+)-L*.H
MSZ7.JLP@7"(E<UPB(*JZN.JNQBXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"*D=Z=2L*.GN::H+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R("*FJ*5<JKJFVZATLLZDI+*^L*,@7"(E
M<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N(@IM<V=S='(@(J1WIJBE7*JZIEZT7[-=J7<N(+W0K:NW
M<[C\I$K`R[7XKG2RIRXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BI'>FJ*5<
MJKJSQJ7WLUVI=[CJKL8N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(J1WIJBE
M7*JZL\:E][-=J7>XZJ[&("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S
M7"(B"FUS9W-T<B`BIJBE7*JZI_.W<R!<(B5S7"(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T
M<B`BI'>FJ*5<JKK"T+QG("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
M4W5D86X@*,2LI*8I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("*Z
M2ZUN(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@
M4FES92(*;7-G<W1R("*DZ:58(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(J3IN*@B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB
M"FUS9W-T<B`BM+@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(J3II5@B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G
M:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(J3II5@OI.FXJ"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z
M("(*;7-G<W1R("*DZ:58.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`BI.FXJ"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@
M(@IM<V=S='(@(J3IN*@Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@
M(J17O-`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED
M(")3=7!P;W)T(@IM<V=S='(@(J3DM*DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*
M;7-G<W1R(")3=7)I;F%M92`HQ*RG4:MN*2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(KKON+DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V
M86QB87)D(&%N9"!*86X@36%Y96XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS
M9W-T<B`B4W=A>FEL86YD("BE=J7+P-G$]2DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,34*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB
M"FUS9W-T<B`B4W=E9&5N("BWYZCE*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*
M;7-G<W1R(")3=VET>F5R;&%N9"`HM^>D:"DB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G
M<W1R("*F4*A"L$^__:1WIU*PHR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R("*F4*A"IN:PRKC+N&TB"@HC
M.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X
M(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("*W:K1-MK6EV*2DJKJ[
M>:IKO_F[?B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S
M='(@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC("BQU*=1J,@I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O
M<FTB"FUS9W-T<B`BN7"K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G
M<W1R("*Y<*M"IK.MMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("*Y<*M"(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G
M:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(J:MIK.K^<3RN7"K0B(*"B,Z
M(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*
M;7-G<W1R(")404(@I,"Y:J[FIJ'`R:[7(@H*(SH@;&EB+TAO<F1E+U5)+U1A
M8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(JKML^8B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S
M"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(JKMKN:DNJYE(@H*
M(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*(RP@9G5Z
M>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("*J[;/F(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I
M9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("*J[:[FI+JN92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`BI7C&5R(*"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O
M=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`BI7C&5R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK
M:7-T86XB"FUS9W-T<B`B5&%J:6MI<W1A;B`HMO"F3K2UJ5HI(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F("BI6JE\I:>HR"DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")4
M87)G970Z(@IM<V=S='(@(J78O-`Z(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")4
M87-K<R(*;7-G<W1R("*KW;_LJ,:VM2(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@
M(KEQN-RXN;U8(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@
M(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(K/,JO&D0*1PKLFJNK?%
MJ]<Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP
M97)A='5R92(*;7-G<W1R("*WQ:O7(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("*W
MQ:O7.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,B"FUS9W-T<B`BM\6KUSQB<B`O/B@E<["J)7,O)7.G
M0R5S*2`F9&5G.R5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV.#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`BI^2DHZCLO,NJ3R!<(B5S7"(N(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(KS+JD^ZWK)Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,34@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C4*;7-G:60@(E1E>'0B"FUS9W-T
M<B`BI+JN92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@
M(E1E>'0@3VYL>2(*;7-G<W1R("*OPJ3EIG(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT
M(&%L:6=N(@IM<V=S='(@(KGON_2DY:9R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G
M<W1R("*Y[[OTI.6F<K.[NMTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("*L4+3!I7PB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&AA:2`H5$E3
M+38R,"DB"FUS9W-T<B`BKO6DY2`H5$E3+38R,"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I
M;&%N9"(*;7-G<W1R(")4:&%I;&%N9"`HKO6PZBDB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z.#0P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")&5%`@J;6F^2AE>'1E;G-I;VXIM4RNQ"XB"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B(+[CIEBD=;5[
MJ,.EO*3DM*D@7"(E<UPB(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP.C$R
M.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ
M960N(@IM<V=S='(@(DE-4U`@K/:__;5,JFNS4:KLJ6PN(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z
M.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(DUA
M:6YT96YA;F-E(,/^IT^HPZ6\IJBE7+C\I$HB"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD
M;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`BO^^VM;7XM:&E2,/V
MLZPNPO>V?:2D+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI8B](
M;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP:'`Z
M,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]097)M
M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(@IM<V=S='(@(J=!JKJH=++.NMZR>JW[I;*VMZ7]LUVI
M=Z9NI$"MT\5VK:VKX;K=I'ZOX,7]IT&HSZ7.Q7:MK:ATLLXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM
M<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`BJ;.NV+UU(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B
M(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E
M+B(*;7-G<W1R("+!<+6XN+F]6*6\J_RI=RRJQ:75J<ZF8KCJKL:N=Z2DI^2D
MHZCL+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*
M;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(J1WIJBE7*JZL4[!<+6XI$BW
M<[Q7IMRS<;!4O_VDI"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("+%Y\/2MFRE\\.QL[F[W:UNIK.D0*W3I'>XT;9]JKH@4$=0(+#/
MMO0N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM
M<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@
M=&AE(&1A=&%B87-E+B(*;7-G<W1R("*P=+AMN'.RU:JZP]&G3[BYO5@H240I
MI*.L3Z6\J_RI=RRT3JQ/JL6EU:G.JLRDHZ9BN.JNQJYWI*0N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("*P
M=+AMN'.RU:6\J_RI=RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM
M<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BN]VM;J1`K=.X9[E,I5NQ2ZJZ
MNO2X]+-SM;(N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S<@;&EB+TAO<F1E+G!H
M<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("+`R:[7("5S(,"SN-.E
M7:=TI$"MTR`E<R"S7:EW+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<P(&QI8B](
M;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(L#)
MKM<@)7,@P+.XTZ5=IW2D0*C'("5S(+-=J7<N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR,C,*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N(@IM<V=S='(@(K5,JFN]QKMSJ.RFVZBMP,FNURXB"@HC.B!L
M:6(O2&]R9&4O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`BIKG`R:[7I*2H4Z:SN.JNQBXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE
M(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R
M9F,X,C(@;65S<V%G92XB"FUS9W-T<B`BI4BD5:Q/(')F8S@R,B"V;*7SJKJJ
M[<!9+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDR
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`BJ*VE]\/1IT\@)7,@I'>S4:=2L*,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`BI:JNV+UU(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,34W"FUS
M9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B
M1VYU4$<@I$>DN,#)JKJX]*Y\I;*VMZEWN'&F8B!#<GEP=%]P9W`Z.B##_J=/
MI*0N(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W
M:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H
M:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@
M<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B*G0;2_J?,@)7,@L4BU
MN2`E<R"D0*O*I42FKJRP(%PB)7-<(B"JNJM(I?.D=[-1MGVQTBY<;B(*(J;]
MLV^HPZ2CK^"K3\/2N-.K2*7SJKJDNJYEI'>GN:7^LU&FK*7SI$BLW:>YJ<ZD
M1KC1+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B
M"FUS9W-T<B`BLW.ULJCLO7.\9[9LI?.MMJVQJ=*HSZ7.JKJF5[K9(@H*(SH@
M;&EB+T9I;&4O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BI;*VMZQ/I$"MT[S&IG(N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")(;W)D95]#<GEP=%]S;6EM
M93HZ(,/^IT\LI;*[W:UNIK,@;W!E;G-S;""\TK+5+B(*"B,Z(&QI8B](;W)D
M92]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M92(*;7-G<W1R("*FN;"^IFX@7"(E<UPB(+CJKL:F7:RPME>Y3+/,I&JDN;-<
MK<@LJ=*E2+5,JFNS4<!XIG,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M9&5B+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP
M.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP
M.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`BI<ZE2,#+M?BF
MN;CJKL;#_JNL("@E<RD@JKJU>Z:AJ,.DHZ9SIF*I\ZATLLZD5RXB"@HC.B!L
M:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("*DWJUZ
MIG*ELK:WK+"SYJ1`IG*DN"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("*EJJ5KKMB]=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G
M:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("*E:Z[8O74B
M"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("+$YJ;L
MI,"Y:J9RI;*VMZRPL^:D0*9RI+@N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BIKFF^*I!OKD@7"(E
M<UPB(*1WLU&G4K"C+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R("*FN:;XJD&^N2!<(B5S7"(@I'>S4<!X
MIG,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"XB"FUS9W-T<B`B)7,@JKJU^:55N]VH1*1WLU&ROK"C+B(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE
M9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(JO\J7>JNK!/O_VHPZ2C
MIG.F8BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(KS(IG/`R:[77"(E<UPBI*.F<Z9B+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,S`P"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E
M9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S
M='(@(J=!J=*_Z:1*JKJXZJ[&NU"U9:VQN.JNQJ2CLL4N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I
M9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`BI%>D
M5:[8O74B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R
M("*D5Z[8O74B"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,S(W"FUS9VED(")4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"XB"FUS9W-T<B`BL7&D5Z1`K=.H0L9*I*>KX:17ML>JNKCJKL:_\J6B
M+B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C8R(&QI8B](;W)D92]$
M871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(J17ML?`R:[7J,.EO+-1P'BF<RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(G=E871H97(N8V]M
M(+#/MO2U3*IKJ,^ESBXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.R\RZ:AL'2X;:78O_T@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(K5,I6FESJJZ
MO^^VM2XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS
M9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D
M(&EN;&EN92XB"FUS9W-T<B`BM4RJ_J7SI6FJO;&UMGVQTBXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,30P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9
M;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N
M=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`BIKG$YJ;LI*2E7:=TI-.F:*JZ
MIG*\QBZG0:1WO^FD2B`E<R"MTZ9RO,8[IT&_Z:1*JKJF<KS&I;*VMZ1PJ?,@
M)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<
M(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`BMW.\5R!<(B5S7"(@
MJ.RH=++..B`E<R"NR;5OI<VD0*W3L-W#1"XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(*;7-G<W1R("*FVZATLLZR3;"C(%PB)7-<(B"JNKCJKL:NR;5OI<VD
M0*W3L-W#1#HB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BIMNH=++.LKZPHR!<(B5S7"(@
MKLFU;Z7-I$"MT[#=PT0Z(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@
M7"(E<UPB.B`E<R(*;7-G<W1R("*G\[=S(%PB)7-<(CH@)7,@KLFU;Z7-I$"M
MT[#=PT0B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$P"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`BI%>VQ\#)
MKM>NR;5OI<VD0*W3L-W#1#H@)7,@I;RS4:17ML<N(@H*(SH@;&EB+TAO<F1E
M+T)R;W=S97(N<&AP.CDQ-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H
M)60@8GET97,I+B(*;7-G<W1R("*D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E
M<R"D:J1PME>Y3*2YLURSS*1JK<@@*"5D(&)Y=&5S*2XB"@HC.B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.3$W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(J17ML?`
MR:[7KLFU;Z7-I$"MT[#=PT0Z(+;(LZ&DP*JZ("5S(,#)KM>S4:17ML<N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P
M87)T(@IM<V=S='(@(L#+M?BV;*7SKLFU;Z7-I$"MT[_YNWXN(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(K;7I$JF
MN;-QL%2__;CJKL:NR;5OI<V_^;M^+B(*"B,Z(&QI8B](;W)D92]$871A+VEM
M8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("*VUZ1*(&E#86QE;F1A<B"X
MZJ[&KLFU;Z7-I$"MT[_YNWXN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q
M=6ER960@9FEE;&0N(@IM<V=S='(@(J9BLUVI=ZKML^:DI+5OI<VD1J1`K=._
M^;M^+J:SI6FOX*=!O_*Z?*1&I;*VM[;QO&>JNL3FINPN(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(K#UIN:S<;!4O_VK_*EWI5ROX*[)M6^ES:1`K=._^;M^+B"]T+5Y
MJ^&F0;C5I$"FN"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`BI_.W<\%PM;BD2+CJKL:NR;5OI<VD1J1`K=._^;M^+B"]T+5Y
MJ^&F0;C5+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BI_.W<[!TN&VX
M<[+5KLFU;Z7-I$:D0*W3O_F[?BX@O="U>:OAID&XU2XB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G
M<W1R("*FN2!)34%0(*;XJD&^N:C#I;RDY+2IJTBE\Z=8I,"HR:5<K^`N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M(@IM<V=S='(@(K-OIORE1Z2CK$^EO[U4JKH@<F%R(,"CP5G`R:[7+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G
M<W1R("*S;Z;\I4>DHZQ/I;^]5*JZ('II<"#`H\%9P,FNURXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$S-`IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(K-OIORE1Z2C
MK$^EO[U4JKJK2*7.I62XN;U8+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!3
M3510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N
M;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@
M86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M.3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C`*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$U-C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-#,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3,*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,3(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T-30*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#0@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,C8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R.34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,X,#,@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,3$*;7-G:60@(E1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(J:YQ.:F[*Q/I;*[W:UNJKHN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-CD*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`BIKG$YJ;L
MI+JN9:5UI+FS7+[CO,:\QJ9R+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-#(P"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("*FN<3FINRDNJYEI76DN;-<O,:F
M<J3.JU^XN2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS
M9W-T<B`BIKG$YJ;LI+JN9:5UI+FS7*1+MFFF[+S&K<@N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM
M<V=S='(@(J:YQ.:F[*2ZKF6ELK:WK+"S<KBYJ<ZJQ:75I,"Y:JJZO,:F<B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BI;*VMZQ/I$"MT[S&
MIG(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C4*;7-G:60@(B(*(E1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T
M<B`BIKG$YJ;LI+JN9:6RMK>E7:=TI$"RU:11I+NV::;LJKH@4D="(,-#IN*E
M3KU8+*C2IG`@)R,Q,C,T868G+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU
M-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"XB"FUS9W-T<B`BLV^MTZKML^:D=[-1LT*R>KE,+B(*"B,Z('1E;7!L871E
M<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M:7,@)7,N(@IM<V=S='(@(K-OK$\@)7,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@
M(B(*(K-OK$\@2V]L86(@N'.RU:JZI$"MTZJKI?,N(+']P,NU^*:YJJNE\[O=
MK6ZOX*3DM*E+;VQA8B"X<[+5KN:FH:JZN7&D;+9LI?.S;B(*(L7I+KW0L-&F
MTB`E<R"E2*1&N-&S;ZC'MFRE\[-NQ>DB"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("*S;ZO*MFRE\ZC#JT2E2*=!ND2E
MSJJZIG*DN+:PIM.L3ZC/I<X@*"5S*2"NT;QGIM.FJ"XB"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N(@IM<V=S='(@(J:YO,:MR+/,I-:ELK:WK$\@,2XB
M"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+B(*;7-G<W1R("*FN:;XJD&^N;5,JFNY[R!Z:7`@I,X@9WII<""NYJ:AP,FN
MU[9IIN:XT<"CP5DB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X,@IM
M<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*
M;7-G<W1R("*FN:ATLLZEV*MEK$^PL:7.JKJJK+I!+B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N(@IM<V=S='(@(J6RMK>L3Z1`K=.\QJ9R+B(*"B,Z('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS
M9W-T<B`BIKFU^+6AI;*VMZUNI=&_[[:UM?BUH2A/<'1I;VXIJ=*I2:5S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`BN7`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(K#=PT2P;,+<
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,CD@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(J[)MJ$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R
M86-K:6YG(@IM<V=S='(@(J[)MJ&K_*MN(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("*NR;:AKN:FH2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,U"FUS9VED(")4:6UE('-E;&5C
M=&EO;B(*;7-G<W1R("*NR;#/O^^^W"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E
M(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G
M:60@(E1I=&QE(@IM<V=S='(@(KS0PT0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I
M<"DZ(@IM<V=S='(@(KS0PT0@*'1O;VQT:7`I.B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("*F
MK*7SI$@B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C4Q"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*
M(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B*F<*I'K6Z]QK_O++W0IF+"
M2;_OM\:YJZJZIE"NR:OV($-O;G1R;VS!Y"BMTZ1(N7&XHRD@J<X@0V]M;6%N
M9,'D*,2KJD>Y<;BC*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R("*DM:31(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G
M9VQE($A434P@4V]U<F-E(@IM<V=S='(@(DA434P@K>RI;,#)(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&]G;R(*;7-G<W1R(")4;V=O("BF:*WT*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L
M874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(JGZI-$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82`HJD:E6RDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G
M:60@(E1O<"(*;7-G<W1R("*SN[.A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P
M*2(*;7-G<W1R("*SS*17O&BNV*Q;("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A;G-L871I;VYS(@IM
M<V=S='(@(L7<I,8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM
M<V=S='(@(J1DJ+VY1J3.IJNHJ:WT(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`BKW6ISK"P(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`BK%"TP:1'(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*
M;7-G<W1R(")4=6YI<VEA("BL\*6GINBHR"DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB
M"FUS9W-T<B`B5'5R:V5Y("BD9Z;5J.0I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@
M(J1GIM6HY*3E("A)4T\M.#@U.2TY*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A
M;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2`HI&>ER[Y\
M*2(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R
M(&-H;VEC93H@(@IM<V=S='(@(K_II$JG0:JZO^^^W#H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@
M(@IM<V=S='(@(K6UI7Z]=:O\O,8Z("(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS
M9VED(")54DPB"FUS9W-T<B`BNO2G?2(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ
M(@IM<V=S='(@(KKTIWTZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G
M86YD82`HKU&D>KE&*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR
M86EN92`HKU&G2L3U*2(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$V"FUS9VED
M(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(K5,
MJFNF<ZCZ(%9&4R"EV+_]+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(K7YI56NR;5,JFN\5Z5;
MPT*E?JJZJ,^ESJK,N.JP5"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,SDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKI^_%W"!61E,@
MP,FNUR!<(B5S7"(@JKK%=JVM+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S@Y
M(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R("*U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNL5VK:TN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<W-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("*U3*IKQ=RG\ZRP("5S
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S
M='(@(K5,JFO`RZQDP,FNUZ1JI'`@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z-CDR(&QI8B]61E,O<W%L+G!H<#HQ,#$Y(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`BM4RJ:\#+K&3`
MR:[7I&JD<"!<(B5S+R5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H
M<#HT,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M(@IM<V=S='(@(K5,JFNS<[6R(%-13""F^*I!OKDN(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C@U.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(K5,JFNHSZ7.(%-33""S<[6R+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,C(Y(&QI8B]61E,O9FEL92YP:'`Z,C,T(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C(P-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB"FUS9W-T<B`BM4RJ:[W&NW,@5D93(,#)KM<N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("*U3*IKJ]BE
MWR!61E,@I=B__2!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-3@@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,C4X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(V
M-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("*U3*IKJ]BEWR!61E,@I=B__2XB"@HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S
M='(@(K5,JFNKV*7?(%9&4R#`R:[7+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR
M.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:ZO8I=\@5D93(*78O_T@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C8Y"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("*U3*IKJ]BEWZK%
MI=6JNB!61E,@P,FNURXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H
M<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(K5,JFNQ3KCJKL:X
MT<"CP5DN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(R."!L:6(O5D93+V9T<"YP
M:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B
MM4RJ:Z=2L*,@7"(E<UPB+*:YI=B__:C#JT2JQ:75+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(K5,JFNG4K"C(%PB)7-<(CH@)7,B"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C,S-2!L:6(O5D93+W-Q;"YP:'`Z,SDU(&QI8B]61E,O;75S<6PN<&AP
M.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DB"FUS9W-T<B`BM4RJ:Z=2L*,@)7,LIKFEV+_]J,.K1*K%
MI=4B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-38@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(K5,JFN[O+!JIU*PHZ78O_TN
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#$@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S-0HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HS-#,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(K5,JFNG4K"C(%9&
M4R"EV+_]+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,C`@;&EB+U9&4R]S<6PN
M<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("*U3*IKIU*PHR!61E,@I=B_
M_3H@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BM4RJ:Z=2L*,@5D93(,#)KM<@7"(E<UPB+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,S`W(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,38W"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X,"!L:6(O5D93+VUU
M<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92XB"FUS9W-T<B`BM4RJ:Z=2L*,@5D93(,#)KM<N(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("*U3*IKIU*P
MHR!61E,@I=B__2!<(B5S7"(N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C0P.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N(@IM<V=S='(@(K5,JFN[O+!JIU*PHR!61E,Z("5S+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HX,C,*;7-G:60@(E5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(K5,JFNG4,)?I=BK
M9:JZI=B__2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-`IM
M<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*
M;7-G<W1R("*U3*IKN-&V?;[,P]*RT[A@(@H*(SH@;&EB+TYE="])35-0+G!H
M<#HT,S<@;&EB+TYE="])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`BM4RJ:[C\I$HE<ZJZJ7>X<2XB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C(P,"!L:6(O5D93+V9I;&4N<&AP.C(P-2!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HQ-S0*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS9VED(")5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`BM4RJ:[=HLKX@5D93
M(,#)KM<N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.CDS(&QI8B]61E,O<VUB+G!H
M<#HQ,#8@;&EB+U9&4R]S;6(N<&AP.C8U,@HC.B!L:6(O5D93+V9T<"YP:'`Z
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKMGVQTB!61E,@P,FNUR!<(B5S7"(N
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR.#$@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,3,X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(K5,JFN\
M9Z1*(%9&4R#`R:[7+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z.#,@;&EB+U9&
M4R]F:6QE+G!H<#HQ,S0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("*U3*IKMGVQTB!6
M1E,@P,FNURXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("*U3*IKMGVQTL"CP5G`R2XB"@HC.B!L:6(O5D93+G!H<#HX-34*
M;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A
M:6QE9"DN(@IM<V=S='(@(K5,JFO%JJCZ(%9&4R#`R:[7("AF:6QE<VEZ92@I
M(&9A:6QE9"DN(@H*(SH@;&EB+U9&4RYP:'`Z.#@V"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G
M<W1R("*U3*IKQ:JH^B!61E,@P,FNUR`H9V5T1FEL95-I>F4H*2!F86EL960I
M+B(*"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM
M<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(K5,JFO%JJCZ
MP,FNUSH@(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV-S,*;7-G:60@(E5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`BM4RJ
M:\6JJ/H@=F9S<F]O=""EV+_]+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS
M9W-T<B`BM4RJ:Z?SIE<@)7,@K+`@)7,Z(*9=K+"EV+S0JTBE\Z=8I'>F<Z9B
M(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(K5,JFO%W*?S(%9&
M4R"EV+_]JKJF5[K9+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M.B`E<RXB"FUS9W-T<B`BM4RJ:[*^L*,@5D93(*78O_TZ("5S+B(*"B,Z(&QI
M8B]61E,O<VUB+G!H<#HR-S$@;&EB+U9&4R]F='`N<&AP.C,T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`BM4RJ:\7<I_,@5D93(,#)KM<@7"(E<UPB(*JZIE>ZV2XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Q-"!L:6(O5D93+VUU<W%L+G!H<#HR
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`BM4RJ:\7<I_,@5D93(,#)KM<@)7,O)7,@
MJKJF5[K9+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,C8@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,@HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HR.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("*U3*IKQ=RG
M\R!61E,@P,FNUZJZIE>ZV2XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM
M<V=S='(@(K5,JFNP]:;F("=M:VES;V9S)RXB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`BM4RJ:\+@M*L@5V]R
M9""DY:7S(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L:6(O5D93+V9T<"YP
M:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(K5,JFN\9Z1*(%9&4R!<(B5S7"(@
MP,FNURXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$X,PIM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B
MM4RJ:[QGI$H@5D93(,#)KM<@*&-O<'DH*2!F86EL960I+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,C@U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T-B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+B(*;7-G<W1R("*U3*IKO&>D2B!61E,@P,FNU[CJKL8N
M(@H*(SH@;&EB+U9&4RYP:'`Z.#8Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(K5,
MJFN\9Z1*(%9&4R#`R:[7+""ZS[K0L'3#0J1WNJ$N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L
M:6YE(@IM<V=S='(@(JFSO74B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`BJ/JN^*?SI^\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS
M9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("*T7ZWL(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,R!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R
M("*F^*I!OKFS<[6RKLFU;Z7-I;RY=[3!JKJF7L"S.B`B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T
M"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B
M"FUS9W-T<B`BM6^ES:6\N7>TP:JZIE[`LRRET:;XJD&^N3H@(@H*(SH@;&EB
M+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N
M9FEL960B"FUS9W-T<B`BI;RDP,/^(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#D*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("*X5;#JO5@@
M*%541BTX*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R
M(")5;FET960@07)A8B!%;6ER871E<R`HJORIU*="P7"F6*1JI+VPZBDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E5N:71E9"!+:6YG9&]M
M("BM7K#J*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B56YI
M=&5D(%-T871E<R`HK/RPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B56YI=&5D(%-T871E<R!-
M:6YO<B!/=71L>6EN9R!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8R(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N
M:71S(@IM<V=S='(@(K/FINPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,CD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S
M='(@(J6\JKZJNB(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN(@IM<V=S='(@(J6\JKZJNB!!4$D@L%2NI[USN+D@*$%022!-97-S86=E
M($E$*2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+B(*;7-G<W1R("*EO*J^JKJKR*3AL%2NI[USN+D@*$%022!-97-S86=E($E$
M*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED
M(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("*EO*J^JKJF
M[+AMN.JP5"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`BI;RJOJJZJ,^ESJK,IE>ZV:G.L4N]6"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@
M(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(J2DPE^EV*ME
MI+BE\ZJZLW.ULB(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`Q"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(J6\J5*F5R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HBIEVF=Z7^Q56\>Z2C
MI+FS7*6\L<+%=JJZM7NFH;#UIN:PQ:15+[W&NW,OMDND5RX@PDF_[[U4J7>E
M2,#+M?@@;6]Z:6QL82YO<F<@J=(B"B*THZC1JKJLV\/VI]ZS3J3EI?,LQ?VG
M0:5II4BXT;"CIKFD0*VMJ.ZHPZ;;IN:V?:GQM7NFH:9SJ/JPQ;9+PZ\N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`BJ/JN^,-#IN(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-R!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.CDR-PHC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(J6\
MI.2TJ:JZL,;`R:97(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T
M92(*;7-G<W1R("+%W*?S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS
M9W-T<B`BI_.W<R`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(J?SMW.HSZ7.
MJLPB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB
MI'>G\[=S+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED
M(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("*G\[=SM7NFH:1W
MIU*PHRXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*
M;7-G<W1R("*D5[;'(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM
M<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N(@IM<V=S='(@(J1WI%>VQZG2IK/`LZ7.M7NFH:JZLUVI
M=\#)J.RF^*I!OKDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T
M=&5R<R(*;7-G<W1R("*D:KQGJ=2D0KS&IG(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5
M<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(J1JO&?#N;"HO,:F<B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2`HKU&IU*9C*2(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("*HSZ7.
MI=BK9:JZ.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`BJ,^ESB!34TPB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R
M("*F<*I'IT&JNJC/I<ZJS*97NMDOL4N]6+M0($E-4U`@IOBJ0;ZYI*.F4"RE
M::9BIKFS7:EW+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`BJ,^ESJK,(@H*(SH@;&EB+TAO
M<F1E+U)E9VES=')Y+G!H<#HW,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(JC/I<ZJ
MS"`E<R"EO+-QN4P@)7,@JKJQPL5VQ>?#TBXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`BJ,^E
MSJK,NMZR>B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED
M(")5<V5R($]P=&EO;G,B"FUS9W-T<B`BJ,^ESJK,O^^VM2(*"B,Z('-I9VYU
M<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(JC/
MI<ZJS+7YI54B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G
M<W1R("*FN:^XI7BJNJC/I<ZJS+7YI56H=++.I'>PL:7.+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`BI^2DHZCLJ,^ESJK,L6*XN2(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L:6(O3F5T+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3`*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`BJ,^ESJK,IE>Z
MV2(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`BJ,^ESJK,IE>ZV2!<(B5S7"(@I'>F<Z9B+B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM
M<V=S='(@(JC/I<ZJS*97NMDZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("*HSZ7.JLPZ("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(JATLLZDI*JZJ,^ESJK,.B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB96MI<W1A;B`HKU&O
M]Z=/ITHI(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-C<@;&EB+U9&4R]F:6QE
M+G!H<#HR-3D*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(E9&4R"EV+_]J,.DHZ9SIF(N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`BL+*T
MP2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-S`*;7-G:60@(E9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`BI'>GY*CLIK.NQ*JZ
MIF'"23H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(J:SKL2IRB(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N(@IM<V=S='(@(J5(I,#$P:RPL^:F["BQ<;)[IF*P7[KB*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HX-C`@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU
M;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0X(&QI8B](;W)D92]&;W)M+G!H<#HR,C<P(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S(P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3$W(&QI8B](
M;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`BK<@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$Y,`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F
M<F]M(@IM<V=S='(@(K_OJ/JMR*;;(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G
M<W1R(")686YU871U("BERZ6CJORYSRDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R("+%W*3&
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82`HJ66D
MNK?GJ=0I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G
M:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("+%Y\/2I:*QT2`M(*:Y
MMFRE\Z5IK^"D=[Y$I$B^U:;;OWFG[RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("*JJ:6[(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO
M;B!#;VYT<F]L(@IM<V=S='(@(JJII;NQL:CN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86P@86QI9VXB"FUS9W-T<B`BJZNJO;GON_0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A
M;"!P861D:6YG(@IM<V=S='(@(JNKJKVYU*52(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ
M(@IM<V=S='(@(JNKJKTZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("*K1+%@
ML*HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T($YA;2`HME:K
M;BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B5FEE=&YA
M;65S92`H5DE30TE)*2(*;7-G<W1R("*V5JMNI.4@*%9)4T-)22DB"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E9I97<@)7,B"FUS9W-T<B`BP,NU^"`E<R(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A
M9V4B"FUS9W-T<B`BIF*W<[7XM:&V?;'2(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S
M("5S(@IM<V=S='(@(J5(("5S(,#+M?@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R(")6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:"`HK5[$W;K[J,JX<ZYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5
M+E,N(@IM<V=S='(@(E9I<F=I;B!)<VQA;F1S+"!5+E,N("BL_,3=NONHRKAS
MKG$I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB
M:6QI='DB"FUS9W-T<B`BK^"HHZO7(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(J_@
MJ*.KUSH@(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B
MN'&D:J=1I?&\=ZVWN7&K2*2]I7&S>KE,(%--5%`B"@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!
M4DXB"FUS9W-T<B`BQ+6G:2(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("+$M:=I(2$A(+%Q("5S
M(*3BL,JROK"CM7NFH2XB"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.(+AGI=$@2%14
M4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI
M<R!A;F0@1G5T=6YA(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,C0@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")7
M87)N:6YG(@IM<V=S='(@(L2UIVDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("*L4+3!
MI%0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@
M(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`BI-&N\+EWM/HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A
M=&$@<')O=FED960@8GDB"FUS9W-T<B`BKO"V2+CJKL:THZC1(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B=V5A=&AE<BYC;VT@NO2ON"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`BNO2ON"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(KKT
MK[@B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7
M965K;'DB"FUS9W-T<B`BJ$.V9R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(L5WJN\B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E
M<R(*;7-G<W1R("+%=ZKOJ.P@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`BQ7>J[RP@)7,B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,2DB"FUS9W-T<B`BINB\VB`H25-/+3@X-3DM,2DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,34I(@IM<V=S='(@(J;HO-H@*$E33RTX.#4Y+3$U*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")7
M97-T97)N(%-A:&%R82(*;7-G<W1R(")797-T97)N(%-A:&%R82`HINB\NZNB
MJ=0I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/R(*;7-G<W1R("*U;J1*J^'`L[C3I?W%XZ7<("5S(*W^
MI$"MT\"SI<ZU>Z:A/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*
M;7-G<W1R("+$YJ;LJKJDP+EJIG*DN#\B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C
M=&5R/R(*;7-G<W1R("*DWJUZJKJK9;AMIG*DN#\B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P(@IM<V=S='(@(E=H97)E:7,@075S=')A;&EA(*9AN<\B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E
M<R(*;7-G<W1R("*M_JW3I.NLVR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@
M4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`BNO2MMKUSO^B^N:JZM*&E\RAP
M;'5G:6YS*;'2L,JQL:CN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@
M(KQEJ]<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q-`IM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(J5(($-34R"LL+/FINRJNKQEJ]<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME
M<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("*EJL/D)7.E7*_@
MJNVJNKQEJ]<HI%6FN+5NI$JI;*7-KL0I.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T
M:&4@=&%B;&4B"FUS9W-T<B`BJNVNYKQEJ]<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI
M="(*;7-G<W1R("*\9:O7L^:F["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B
MO&6KUSHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED
M(")7:6MI(@IM<V=S='(@(K:PQ>FST*=`(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("*MMR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD
M($5A<FQY(@IM<V=S='(@(J:MIK.MMR(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`BK;>S
M="BX8"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN
M9#HB"FUS9W-T<B`BK;>S=#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`BK;>S=#H@(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T
M<B`BM+R\>B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G
M:60@(E=I<VAL:7-T(@IM<V=S='(@(K3!J]W"IZJK(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(J1UIT`B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R
M97-S(@IM<V=S='(@(K_LI+VKQZ9AIWTB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R
M("*_[*2]J\>Y<;C<(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB+T9I
M;&4O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N(@IM<V=S='(@(K+$)62FYJJZQ.:F[+S&I=BDHZ6_O50N(,"SN-.M;J:S
M)62MT\3FINPLI76GY*CL)62MT\3FINPN(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("+$YJ;LO,:E
MV*2CI;^]5"X@P+.XTZUNIK,E9*W3Q.:F["RE=:?DJ.PE9*W3Q.:F["XB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C$Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92XB"FUS9W-T<B`BM4RJ:\7<I_,@5D93(,#)KM>JNJ97NMDN(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@
M(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y=C,@J;6F^:KWQE^[>:IK(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(*5$
MIJZTP*5.IE>ZV2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R
M(")8-3`Y=C,@I42FKJKWQE_#T:=/JLPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T
M<B`B6#4P.78S(+#&P,FF5R(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")962(*;7-G<W1R("*F?B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,PIM<V=I9"`B65E962(*;7-G<W1R("*F?B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO
M;R$@;6%P(@IM<V=S='(@(EEA:&]O("$@IF&YSR(*"B,Z(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("*H0Z9^
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B665M96X@*+BMJODI(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B
M665S(@IM<V=S='(@(JQ/(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M("*L3ZJZ+*?:IE"W3B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@
M57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'
M+B(*;7-G<W1R("*G0:78JV6HSZ7.K\*DY:9RO7.\9[S2IJ$N(*C/I<X@6SP^
M72"K]K9SI6FDP;2KK+"Z]*VVO7.\9[S2IJ$N(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM
M<V=S='(@(J2CI+FS7*=!J]BEWR5DI4BD5ZJZL,^V]"XB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M(@IM<V=S='(@(J=!I;RS4;'"Q78N(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y
M+G!H<#HS,#<*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(J=!JKJE_J97I*2D
MHZ5IIK,@)UQ<)R"S;[S+JKJF<J2X+B`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@U.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("*G
M0:C#I;R_Z:1*I$"MTZ:SKL2JNKEQI&RV;*7SINRG?2XB"@HC.B!L:6(O2&]R
M9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@
M(J=!J,.EO*71MM>D2JJZP,FNUZ2DN>^L3:7TIO/$YJ;LJ.P@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z.3@T"FUS9VED(")9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N(@IM<V=S='(@(J=!I'>X9[5NI5@N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@
M<')E9FEX+B(*;7-G<W1R("(B"B*]T+_II$JD0*W3IK.NQ*JZN7&XW+BYO5@L
ML.J[VKEQN-RXN;U8MLBE=:2YLUR\QJ9RN+F]6"RHP[7XL:&J<*5IJ?.K9:VQ
MID&E6Z1`(@HBK=,@)RLG+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3DR
M"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G
M<W1R("*G0:6RMK>_Z:1*I$"MTZ:SKL2JNJW(+B(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(J=!
MI;*VMZ7]LU>YNJ9NOO"JK+CJKL8H1&%T851R964IIOBJ0;K=I'ZOX,1^Q/*H
MSZ7.MW.ESJ3AM?FE5:I!L,@N(@H*(SH@;&EB+TAO<F1E+G!H<#HT-C(*;7-G
M:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R
M("*G0:6RMK>E_;-7N;JD0*W3M>K`P,#)KM>H=++.*%9&4RFF^*I!NMTN(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("*]T+1YK7JPW<-$H4&F
M8J=!ML>P9;#=PT2S^*=II*>K92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`BIT&E
MLK:WO^FD2J:YLW.ULJG2J_RF5JJZNO2G?2(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(KW0J_RI=ZUNIU*PHZJZIOBJ
M0;ZY+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`BO="K
M_*EWK6ZR3;"CJKJHSZ7.JLPN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*
M;7-G<W1R("*]T*O\J7>M;K*^L*.JNJC/I<ZJS"XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS
M9W-T<B`BO="K_*EWK6ZW<[Q7JKJHSZ7.JLPN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(KW0J_RI=ZUNI_.W<ZJZJ,^ESJK,+B(*"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("*]
MT*O\J7>M;K#UIN:JNJ=`I<XN(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@
M8V%T96=O<GD@;F%M92XB"FUS9W-T<B`BIT&ELK:WO^FD2K=SI,##_JJZIE>Z
MV2XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S
M"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R(@IM<V=S='(@(J=!I;*VM[2CJ-&D0*W3N'&D:J=1N=*DNJJZN7&X
MW+BYO5@B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<R"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("*G0:JZ("5S(+=\M,&D=[E,KLDNO="M
MJ[=SM6ZD2BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(J=!JKJY<:1L
MMFRE\Z;MIWTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED
M(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(J=!JKJQ2*7SI$BY<:1L
MMFRE\Z;MIWTZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(J=!JKJXZK!4(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T
M($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(J;;L7&G0:JZ("5S
M(+=\M,&V?:ELI4BHTZ=!JKJZ]+O:NO2X]*;LIWVD=\7<I_,N(*RPJT_%0*=!
MJKJF=Z7^L%^HHZ%!IT&ELK:WK:LB"B*W<[5NI$HN(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G
M<W1R("*G0:JZIE>ZV2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O
M("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K
M96YD+B(*;7-G<W1R("(B"B*G0:JZQ>?#TJ;XJD&ZW:C#I*.DY+2IMW.\5ZC/
MI<ZJS"X@IG"J1Z=!I\:QYKK>LGJHSZ7.JLRQ8KBY+*=!I;*VMZ5TO^^HY*5,
MJKK%YR(*(L/2IOBJ0;K=+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("*G0:JZQ>?#TKK=J,.EO*3DM*FF0Z58J,^ESJK,J<ZX
MTZ5<K^"D=[-1P_:SK"XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@P"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HBIMNQ<:=!JKH@)7,@MWRTP;9]
MJ6RE2*C3IT&JNL)SQ/V^N:;\I4>D=\7<I_,N(*RPJT_%0*=!JKJF=Z7^L%^H
MHZ%!IT&ELK:WK:NW<R(*(K5NI$HN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92XB"FUS9W-T<B`BIT&JNL)SQ/V^N:C#I;RDY+2ILV^MTZ5<
MK^`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R
M:6YT+B(*;7-G<W1R("*G0:JZPG/$_;ZYJ,.EO*3DM*FF0Z9,O^^VM2Z]T*OV
M($-44DPO0V]M;6%N9"`K(%`@ID.F3"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G
M<W1R("*G0:78JV6ITK-=J7>JNJ[)L,\Z(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.CDX"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@
M8VAA;F=E9"XB"FUS9W-T<B`BN]6D5;EWLUVJNJBMI??#T:=/I'?%W*?S+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`BN]6D5;EWLUVJNJBMI??#T:=/.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L
M;"!N86UE.B(*;7-G<W1R("*G0:JZI?ZF5SHB"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z.3DV"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G
M<W1R("*G0:JZM6ZD2J1WJ.RTP2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(J=!IF(@)7,@I*2JNK=SL4N]
M6*Q/.B`E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34T"FUS9VED
M(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A
M=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(J=!IF*U;J1*M,&VH:JZ
MO^^VM:1WLU&G\[=S+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S
M='(@(J=!JKJ_[[:UI'>G\[=S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M(@IM<V=S='(@(J=!JKJQ2[U8I'>MJ[=SLUVI=R(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`BL4N]6*1WLU&MJ[=S
MLUVI=RRW<ZJZL4N]6*1WLWJY3+EQI&RV;*7SL4BU;[W0I4BXT[%+O5BU;J1*
M+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,S`*;7-G:60@(EEO=7(@<&%S
M<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(J=!JKJQ2[U8I'>H[+3!+B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U
M<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BIT&JNKNWNMVF^*I!OKDZ(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B675G;W-L
M879I82`HJVZTM:G4I-(I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER92`HPL2E["DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEA("BI?*3QJ,@I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4@**BOI-JKPBDB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EO!],+#
MI-ZM>ETB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R
M;V)L96T@4F5P;W)T72(*;7-G<W1R(");L-W#1*3/K$U=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6\7CI=RDWJUZ("TB"@HC.B!L:6(O
M2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B6\7CI=RDWJUZ("T@)7,@IN9=(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=
M(@IM<V=S='(@(ENF[*GSIN8@)7,@ID`@)7,@IN9=(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@
M(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("*ZWK)Z7T$B"@HC.B!L:6(O87!I
M+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`BJ5*E3Z9#7T,B"@HC.B!L
M:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R("*^\*JL
MN.JNQE]$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R("*G
M4K"CID-?1"(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*
M;7-G<W1R("*X<[+57T<B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS
M9VED(")?2&5L<"(*;7-G<W1R("*[H:GZ7T@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E])
M;6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(KQVN;.DNJYE7TDN+BXB"@HC
M.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S
M='(@(K5NI$I?3"(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@
M(E],;V<@;W5T(@IM<V=S='(@(K5NI5A?3"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO
M9&EF>2!,:6YK+BXN(@IM<V=S='(@(JW7I^^S<[6R7TTN+BXB"@HC.B!L:6(O
M2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("*_
M[[:U7T\B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N
M<R(*;7-G<W1R("+%=JVM7U`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN
M:RXN+B(*;7-G<W1R("*ROK"CN>^S<[6R7U(N+BXB"@HC.B!L:6(O87!I+G!H
M<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("*S7:EW7U,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*
M;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(JKMKN:DNJYE
M7U0N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G
M<W1R("*HSZ7.JLQ?52(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(P"FUS
M9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`BLW&P5+_](@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")A9&1R
M97-S964@=6YK;F]W;B(*;7-G<W1R("*S<;!4O_TB"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDQ,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`BIN:HQK[D
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS
M9W-T<B`BN7.OQ:VW(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(K5,JFNKV*7?O^FE6,#)KM<B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(K5,
MJFNV?;'2O^FD2B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU
M.3D*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`BJ_:FN2(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE
M('5S86=E(&5R<F]R(@IM<V=S='(@(K%+I4^F0[MYJFN_^;M^(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T
M:6]N(&5R<F]R(@IM<V=S='(@(K-=J7>_^;M^(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG(@IM<V=S='(@(K_RI:*MJZUNJKJH=++.P,FNUR(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M
M870@97)R;W(B"FUS9W-T<B`BN.JNQJ[FIJ&_^;M^(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B
M"FUS9W-T<B`BI^2DHZCLL$^__2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")F86QL:6YG(@IM
M<V=S='(@(K7[I,`B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#@Q"FUS
M9VED(")F:6QE(@IM<V=S='(@(L#)KM<B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S(@IM<V=S='(@(K%Q("5S("@E<RD@J?,@)7,@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T
M:6YG(@IM<V=S='(@(K!]K;<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C0X"FUS9VED(")H.B(*;7-G<W1R("*NR3HB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4W"FUS9VED(")H
M:"(*;7-G<W1R("*NR2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`BI;RJOJJZ
MMFRE\Z5$OO>F5[K9(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM
M<V=I9"`B:6UM961I871E(@IM<V=S='(@(J7?IUDB"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M:6YL:6YE(@IM<V=S='(@(JJ]L;7%XZ7<J?.ENZ3EL,\B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E
M<G)O<B(*;7-G<W1R("*_Z:1*+[_II5B_^;M^(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<B(*;7-G<W1R("*DNK.ALV[%Z;_YNWXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S
M='(@(J;F72(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S
M"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8X"FUS9VED(")M;2(*;7-G<W1R("*D
MP"(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C(S,@IM<V=I9"`B;F%M92(*;7-G<W1R("*F5[K9(@H*(SH@;&EB
M+TAO<F1E+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS
M9W-T<B`BJ7REO+GJIT`N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(JE\
MI;RYZJ=`+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`T"FUS9VED(")N
M;W1E<&%D(@IM<V=S='(@(K/&I]&__2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B
M"FUS9W-T<B`BILJDP*3Q(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("*F<ZCZ
MOD2IVB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("*YLZ_`(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`BLW&K2*CSJ7>[M[K=O_F[?B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS
M9VED(")R:7-I;F<B"FUS9W-T<B`BI%>DR2(*"B,Z(&QI8B](;W)D92]-24U%
M+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*
M;7-G<W1R("*U3*5II<ZJNJI!L,@B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(L7CI=RN
M=+*G(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM
M<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;""X
M9Z71($A45%`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@T"FUS9VED(")S<R(*;7-G<W1R("*L[2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS
M9W-T<B`BPZVI=R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U
M,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(JATLLZ_^;M^(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C@*;7-G:60@(G1A<VL@;&ES="(*;7-G
M<W1R("*KW;_LPZ\B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(KS(KLFIRJJZ
MI:*QT2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M(@IM<V=S='(@(J9!IKB_Z:1*IT&JNK%+O5BE2+U4NWNU3+M^
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`BON.F6"(*"B,Z(&QI
M8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S
M='(@(J6\J5*F5R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G
M:60@(G5S97(@<V5L96-T(@IM<V=S='(@(JC/I<ZJS+_OOMPB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*
M;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-#`*;7-G:60@(G<Z(@IM<V=S='(@(JQ0M,$Z(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M
M(@IM<V=S='(@(G=E871H97(N8V]M(+KTK[@B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B\`````````````````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,S`P-P`P,34S-#0`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+P``````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`S`#`Q-C4P,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O````````````````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#,`,#$V
M-S8W`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R\`````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,S`P,P`P,C`Q,S$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+V]C:3@O````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`S`#`R,#<W,P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O:6)A<V4O````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P
M,#,`,#(Q,C$T`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$
M0B]T97-T<R]M>7-Q;"\`````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,S`P,P`P,C$R-S8`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+W!G<W%L+P``````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`S`#`R,3(U-P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O;V1B
M8R\`````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C,P,#,`,#(Q,#0P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]D<FEV97(O````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P,P`P,C$T,C0`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q-W%U97)Y
M+G!H<'0``````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,C`V`#$P-#$W,S8S,#`S`#`R
M,S8S-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+51%4U0M+0I$0E]D<FEV97(Z.G%U97)Y"BTM4TM)4$E&+2T*/#]P:'`*
M"B\J*@H@*B!#86QL<R!T:&4@<75E<GDH*2!M971H;V0@:6X@=F%R:6]U<R!W
M87ES(&%G86EN<W0@86YY($1"35,N"B`J"B`J($!S964@("`@("!$0E]C;VUM
M;VXZ.G%U97)Y*"D*("H@"B`J($!P86-K86=E("!$0@H@*B!`=F5R<VEO;B`@
M)$ED.B`Q-W%U97)Y+G!H<'0L=B`Q+C<@,C`P-"\P,B\Q,B`P-CHU,#HU,2!D
M86YI96QC($5X<"`D"B`J($!C871E9V]R>2!$871A8F%S90H@*B!`875T:&]R
M("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!A;F%L>7-I<V%N9'-O;'5T
M:6]N<RYC;VT^"B`J($!I;G1E<FYA;`H@*B\*"F-H9&ER*&1I<FYA;64H7U]&
M24Q%7U\I*3L*<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.PH*/SX*+2U&
M24Q%+2T*/#]P:'`*"B\O("1)9#H@,3=Q=65R>2YP:'!T+'8@,2XW(#(P,#0O
M,#(O,3(@,#8Z-3`Z-3$@9&%N:65L8R!%>'`@)`H*+RHJ"B`J($-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E(&%N9"!M86ME('1H92!P:'!T97-T('1A8FQE+@H@
M*B\*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*"@HO*BH*("H@3&]C
M86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*("H@1')O<',@=&AE('!H
M<'1E<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@
M:VEL;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O
M("!014%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T
M:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%
M<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B
M86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L*("`@("1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E
M<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1D
M8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/1$5?05-33T,I.PH*"B1R97,@
M/28@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E<W0@5TA%4D4@82`]
M(#$W)RD["G!R:6YT("=D96QE=&4Z("<@+B`H)')E<R`]/2!$0E]/2R`_("=O
M:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*"B1R97,@/28@)&1B:"T^<75E<GDH
M(DE.4T525"!)3E1/('!H<'1E<W0@*&$L(&(L(&,I(%9!3%5%4R`H,3<L("=O
M;F4G+"`G3VYE)RDB*3L*<')I;G0@)VEN<V5R=#H@)R`N("@D<F5S(#T]($1"
M7T]+(#\@)V]K87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*)')E<R`])B`D9&)H
M+3YQ=65R>2@G24Y315)4($E.5$\@<&AP=&5S="`H82P@8BP@8RD@5D%,5453
M("@_+"`_+"`_*2<L(&%R<F%Y*#$W+"`G='=O)RP@)U1W;R<I*3L*<')I;G0@
M)VEN<V5R=#H@)R`N("@D<F5S(#T]($1"7T]+(#\@)V]K87DG(#H@)V5R<F]R
M)RD@+B`B7&XB.PH*"B1R97,@/28@)&1B:"T^<75E<GDH)U-%3$5#5"!A+"!B
M($923TT@<&AP=&5S="!72$5212!A(#T@,3<G*3L*)')O=R`]("1R97,M/F9E
M=&-H4F]W*"D["G!R:6YT(")A(#T@>R1R;W=;)V$G77TL(&(@/2![)')O=ULG
M8B==?5QN(CL*"B1R97,@/28@)&1B:"T^<75E<GDH)U-%3$5#5"!A+"!B($92
M3TT@<&AP=&5S="!72$5212!C(#T@/R<L(&%R<F%Y*"=4=V\G*2D["B1R;W<@
M/2`D<F5S+3YF971C:%)O=R@I.PIP<FEN="`B82`]('LD<F]W6R=A)UU]+"!B
M(#T@>R1R;W=;)V(G77U<;B(["@H*)&%R<F%Y(#T@87)R87DH"B`@("`G9F]O
M)R`]/B`Q,2P*("`@("=B87(G(#T^("=T:')E92<L"B`@("`G8F%Z)R`]/B!N
M=6QL+`HI.PHD<F5S(#TF("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!P:'!T
M97-T("AA+"!B+"!D*2!604Q515,@*#\L(#\L(#\I)RP@)&%R<F%Y*3L*<')I
M;G0@)VEN<V5R=#H@)R`N("@D<F5S(#T]($1"7T]+(#\@)V]K87DG(#H@)V5R
M<F]R)RD@+B`B7&XB.PH*)')E<R`])B`D9&)H+3YQ=65R>2@G4T5,14-4(&$L
M(&(L(&0@1E)/32!P:'!T97-T(%=(15)%(&$@/2`_)RP@,3$I.PHD<F]W(#T@
M)')E<RT^9F5T8VA2;W<H*3L*<')I;G0@(F$@/2![)')O=ULG82==?2P@8B`]
M('LD<F]W6R=B)UU]+"!D(#T@(CL*)'1Y<&4@/2!G971T>7!E*"1R;W=;)V0G
M72D["FEF("@D='EP92`]/2`G3E5,3"<@?'P@)')O=ULG9"==(#T]("<G*2![
M"B`@("!P<FEN="`B3E5,3%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")%4E(Z
M(&5X<&5C=&5D(&0G<R!T>7!E('1O(&)E($Y53$P@8G5T(&ET)W,@)'1Y<&4@
M86YD('1H92!V86QU92!I<R`B.PH@("`@<')I;G0@)')O=ULG9"==("X@(EQN
M(CL*?0H*"B1R97,@/28@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E
M<W0@5TA%4D4@82`](#\G+"!A<G)A>2@Q-RDI.PIP<FEN="`G9&5L971E.B`G
M("X@*"1R97,@/3T@1$)?3TL@/R`G;VMA>2<@.B`G97)R;W(G*2`N(")<;B([
M"@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M"B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E<W0G*3L*"C\^"BTM15A0
M14-4+2T*9&5L971E.B!O:V%Y"FEN<V5R=#H@;VMA>0II;G-E<G0Z(&]K87D*
M82`](#$W+"!B(#T@;VYE"F$@/2`Q-RP@8B`]('1W;PII;G-E<G0Z(&]K87D*
M82`](#$Q+"!B(#T@=&AR964L(&0@/2!.54Q,"F1E;&5T93H@;VMA>0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1$(O=&5S=',O9')I=F5R+S`V<')E<&5X96,N<&AP=```````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(S,C``,3`T,3<S-C,P,#,`,#(T,C<T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM5$535"TM"D1"7V1R
M:79E<CHZ<')E<&%R92]E>&5C=71E"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H
M9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN
M8R<[(#\^"BTM1DE,12TM"CP_<&AP"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE
M+FEN8R<["G)E<75I<F5?;VYC92`G+BXO<')E<&5X92YI;F,G.PH_/@HM+458
M4$5#5"TM"BTM+2TM+2TM+2TM+3$M+2TM+2TM+2TM+2T*<W1H,2QS=&@R+'-T
M:#,L<W1H-"!C<F5A=&5D"G-T:#$Z(#\@87,@<&%R86TL('!A<W-I;F<@87,@
M87)R87DN+BX@<W1H,2!E>&5C=71E9`IS=&@R.B`A(&%N9"`_(&%S('!A<F%M
M<RP@<&%S<VEN9R!A<R!A<G)A>2XN+B!S=&@R(&5X96-U=&5D"G-T:#,Z(#\L
M("$@86YD("8@87,@<&%R86US+"!P87-S:6YG(&%S(&%R<F%Y+BXN('-T:#,@
M97AE8W5T960*<W1H-#H@;F\@<&%R86US+BXN('-T:#0@97AE8W5T960*<F5S
M=6QT<SH*?#<R("T@82`M("`M('P*?#<R("T@9&ER96-T("T@("T@?`I\-S(@
M+2!I="=S(&=O;V0@+2!O<&%Q=64@<&QA8V5H;VQD97(G<R!T97-T("T@?`I\
M-S(@+2!T:&%T)W,@<FEG:'0@+2`@+2!\"@HM+2TM+2TM+2TM+2TR+2TM+2TM
M+2TM+2TM"G)E<W5L=',Z"GPW,B`M('-E=#$@+2!O<&%Q=64@<&QA8V5H;VQD
M97(G<R!T97-T("T@,3(S-"TU-BTW.'P*?#<R("T@<V5T,B`M(&]P87%U92!P
M;&%C96AO;&1E<B=S('1E<W0@+2!\"GPW,B`M('-E=#,@+2!O<&%Q=64@<&QA
M8V5H;VQD97(G<R!T97-T("T@?`H*+2TM+2TM+2TM+2TM,RTM+2TM+2TM+2TM
M+0I44E5%"D9!3%-%"@HM+2TM+2TM+2TM+2TT+2TM+2TM+2TM+2TM"GPW,B`M
M('-E=#$@+2!O<&%Q=64@<&QA8V5H;VQD97(G<R!T97-T("T@,3(S-"TU-BTW
M.'P*?#<R("T@<V5T,B`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2!\
M"GPW,B`M('-E=#,@+2!O<&%Q=64@<&QA8V5H;VQD97(G<R!T97-T("T@?`I^
M?@I^?@I\-S(@+2!S970Q("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M
M(#$R,S0M-38M-SA\"GY^"GPW,B`M('-E=#$@+2!O<&%Q=64@<&QA8V5H;VQD
M97(G<R!T97-T("T@,3(S-"TU-BTW.'P*?#<R("T@<V5T,B`M(&]P87%U92!P
M;&%C96AO;&1E<B=S('1E<W0@+2!\"GPW,B`M('-E=#,@+2!O<&%Q=64@<&QA
M8V5H;VQD97(G<R!T97-T("T@?`I^?@H*+2TM+2TM+2TM+2TM-2TM+2TM+2TM
M+2TM+0II;G-E<G0Z(&]K87D*82`](#$Q+"!B(#T@=&AR964L(&0@/2!S=')I
M;F<*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O
M<V5T=7`N:6YC+F-V<P``````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4Q-``Q,#0Q-S,V
M,S`P,P`P,C0P-3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J"B`J(%1H:7,@:7,@=&AE(&]R:6=I;F%L(")S
M971U<"YI;F,N8W9S(B!F:6QE(&9R;VT@0U93+@H@*@H@*B!04D5005)!5$E/
M3CH*("H@("`Q*2!M86ME(&$@8V]P>2!O9B!T:&ES(&9I;&4@;F%M960@(G-E
M='5P+FEN8R(*("H@("`R*2!E9&ET('1H92!$4DE615)?1%-.)W,@87,@87!P
M<F]P<FEA=&4@9F]R('EO=7(@96YV:7)O;FUE;G0*("H@("`S*2!C;VUM96YT
M(&]U="!T:&4@8FQA;FL@1%))5D527T133@H@*B`@(#0I(&)E9F]R92!E86-H
M(')U;BP@=6YC;VUM96YT('1H92!O;F4@1%))5D527T133B!Y;W4@=V%N=`H@
M*B`@("`@('1O('5S92!D=7)I;F<@=&AA="!R=6X*("HO"@II9B`H(61E9FEN
M960H)U!!5$A?4T5005)!5$]2)RDI('L*("`@(&EF("AS=')I<W1R*%!(4%]/
M4RP@)U=)3B<I*2!["B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L
M("<[)RD["B`@("!](&5L<V4@>PH@("`@("`@(&1E9FEN92@G4$%42%]315!!
M4D%43U(G+"`G.B<I.PH@("`@?0I]"@II;FE?<V5T*"=I;F-L=61E7W!A=&@G
M+"!R96%L<&%T:"AD:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*0H@("`@
M("`@("X@4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@
M("`@("`@("X@:6YI7V=E="@G:6YC;'5D95]P871H)RD**3L*"G)E<75I<F5?
M;VYC92`G1$(N<&AP)SL*"B\O($]P=&EO;G,@=7-E9"!W:&5N(&-O;FYE8W1I
M;F<*)&]P=&EO;G,@/2!A<G)A>2@*("`@("\O)V]P=&EM:7IE)R`]/B`G<&]R
M=&%B:6QI='DG+`H@("`@)W!O<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E4
M65]!3$PL"B`@("`G9&5B=6<G(#T^(#(L"BD["@ID969I;F4H)T12259%4E]$
M4TXG+"`G)RD["B\O9&5F:6YE*"=$4DE615)?1%-.)RP@)W!G<W%L.B\O<&]S
M=&=R97-`;&]C86QH;W-T+W1E<W0G*3L*+R]D969I;F4H)T12259%4E]$4TXG
M+"`G;7ES<6PZ+R]R;V]T0&QO8V%L:&]S="]T97-T)RD["B\O9&5F:6YE*"=$
M4DE615)?1%-.)RP@)V]C:3@Z+R]S>7-T96TZ;6%N86=E<D`G*3L*+R]D969I
M;F4H)T12259%4E]$4TXG+"`G:6)A<V4H9FER96)I<F0I.B\O4UE31$)!.FUA
M<W1E<FME>4`O+V]P="]I;G1E<F)A<V4O97AA;7!L97,O96UP;&]Y964N9V1B
M/V1I86QE8W0],R<I.PHO+V1E9FEN92@G1%))5D527T133B<L("=M<W-Q;#HO
M+W-A0'-O;65H;W-T+W!U8G,G*3L*+R]D969I;F4H)T12259%4E]$4TXG+"`G
M;V1B8RAD8C(I.B\O9&(R:6YS=#$Z6%A86$`O4T%-4$Q%)RD["B\O9&5F:6YE
M*"=$4DE615)?1%-.)RP@)W-Q;&ET93HO+V1U;6UY.D!L;V-A;&AO<W0O)R`N
M(&=E=&-W9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("=T97-T+F1B/VUO
M9&4],#8T-"<I.PH*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P.&%F9F5C=&5D<F]W<RYP:'!T````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,3,T`#$P-#$W,S8S,#`S`#`R-3$T,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+51%4U0M+0I$0E]D
M<FEV97(Z.F%F9F5C=&5D4F]W<PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I
M<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G
M.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI
M;F,G.PH*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(N"B`J
M"B`J($1R;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R
M<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`
M<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC
M86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J
M($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P
M92@D;RD@>PH@("`@9VQO8F%L("1D8F@["@H@("`@)&1B:"T^<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`D9&)H+3YQ=65R>2@G
M1%)/4"!404),12!P:'!T97-T)RD["@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I
M*3L*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"
M04-++"`G<&4G*3L*"@HO+R!#;&5A;B!T86)L90HD9&)H+3YQ=65R>2@B1$5,
M151%($923TT@<&AP=&5S="(I.PH*+R\@069F96-T960@<F]W<R!B>2!)3E-%
M4E0@<W1A=&5M96YT"B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T
M("AA+&(I(%9!3%5%4R@Q+"`G=&5S="<I(BD["B1D8F@M/G%U97)Y*"))3E-%
M4E0@24Y43R!P:'!T97-T("AA+&(I(%9!3%5%4R@R+"`G=&5S="<I(BD["G!R
M:6YT9B@B)60@869T97(@:6YS97)T7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H
M*2D["@HO+R!!9F9E8W1E9"!R;W=S(&)Y(%-%3$5#5"!S=&%T96UE;G0*)&1B
M:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PIP<FEN=&8H(B5D
M(&%F=&5R('-E;&5C=%QN(BP@)&1B:"T^869F96-T9612;W=S*"DI.PHD9&)H
M+3YQ=65R>2@B1$5,151%($923TT@<&AP=&5S="!72$5212!B(#T@)W1E<W0G
M(BD["G!R:6YT9B@B)60@869T97(@9&5L971E7&XB+"`D9&)H+3YA9F9E8W1E
M9%)O=W,H*2D["@HO+R!!9F9E8W1E9"!R;W=S(&)Y($1%3$5412!S=&%T96UE
M;G0*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@*&$L8BD@5D%,
M5453*#$L("=T97-T)RDB*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H
M<'1E<W0@*&$L8BD@5D%,5453*#(L("=T97-T)RDB*3L*)&1B:"T^<V5T3W!T
M:6]N*")O<'1I;6EZ92(L(")P;W)T86)I;&ET>2(I.PHD9&)H+3YQ=65R>2@B
M1$5,151%($923TT@<&AP=&5S="(I.PIP<FEN=&8H(B5D(&%F=&5R(&1E;&5T
M92!A;&P@*&]P=&EM:7IE/25S*5QN(BP@)&1B:"T^869F96-T9612;W=S*"DL
M"B`@("`@("`D9&)H+3YG971/<'1I;VXH(F]P=&EM:7IE(BDI.PH*"B1D8F@M
M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PHD9&)H+3YQ
M=65R>2@G1%)/4"!404),12!P:'!T97-T)RD["@H_/@HM+4584$5#5"TM"C$@
M869T97(@:6YS97)T"C`@869T97(@<V5L96-T"C(@869T97(@9&5L971E"C(@
M869T97(@9&5L971E(&%L;"`H;W!T:6UI>F4]<&]R=&%B:6QI='DI"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$0B]T97-T<R]D<FEV97(O,#EN=6UR;W=S+G!H<'0`````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#,R,0`Q,#0Q-S,V,S`P,P`P,C0Q-S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2U415-4+2T*1$)?9')I=F5R
M.CIN=6U2;W=S"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)
M3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,
M12TM"CP_<&AP"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["G)E<75I
M<F5?;VYC92`G+BXO;G5M<F]W<RYI;F,G.PH_/@HM+4584$5#5"TM"C$*,@HS
M"C0*-0HV"C(*,`H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9')I=F5R+S$Q=')A;G-A8W1I;VYS+G!H<'0`````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,S<`
M,3`T,3<S-C,P,#,`,#(U,3<R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ=')A;G-A8W1I
M;VX@=&5S=`HM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%
M7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M
M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E
M7V]N8V4@)RXN+W1R86YS86-T:6]N<RYI;F,G.PH_/@HM+4584$5#5"TM"F%F
M=&5R(&%U=&]C;VUM:70Z(&)I;F<@;VYE+B`@;W!S/6]K"F)E9F]R92!C;VUM
M:70Z(&)I;F<@;VYE('1W;R!T:')E92X@(&]P<SUO:PIA9G1E<B!C;VUM:70Z
M(&)I;F<@;VYE('1W;R!T:')E92X@(&]P<SUO:PIB969O<F4@<F]L;&)A8VLZ
M(&)I;F<@;VYE('1W;R!T:')E92!F;W5R(&9I=F4N("!O<',];VL*869T97(@
M<F]L;&)A8VLZ(&)I;F<@;VYE('1W;R!T:')E92X@(&]P<SUO:PIB969O<F4@
M875T;V-O;6UI="MR;VQL8F%C:SH@8FEN9R!O;F4@='=O('1H<F5E('-I>"!S
M979E;BX@(&]P<SUO:PIA9G1E<B!A=71O8V]M;6ET*W)O;&QB86-K.B!B:6YG
M(&]N92!T=V\@=&AR964@<VEX('-E=F5N+B`@;W!S/6]K"G1E<W1I;F<@=&AA
M="!S96QE8W0@9&]E<VXG="!D:7-T=7)B92!O<&-O=6YT.B!O:PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9')I=F5R+S$S;&EM:70N<&AP=```````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$U-S0`,3`T,3<S-C,P,#,`,#(S-C`W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ<F]W
M(&QI;6ET"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?
M7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM
M"CP_<&AP"G)E<75I<F5?;VYC92`G+B]C;VYN96-T+FEN8R<["G)E<75I<F5?
M;VYC92`G+BXO;&EM:70N:6YC)SL*/SX*+2U%6%!%0U0M+0H]/3T]/3T]($9R
M;VTZ(#`@?'P@3G5M8F5R(&]F(')O=W,@=&\@9F5T8V@Z(#$P(#T]/3T]/3T*
M,2XM(')E<W5L="`P"C(N+2!R97-U;'0@,0HS+BT@<F5S=6QT(#(*-"XM(')E
M<W5L="`S"C4N+2!R97-U;'0@-`HV+BT@<F5S=6QT(#4*-RXM(')E<W5L="`V
M"C@N+2!R97-U;'0@-PHY+BT@<F5S=6QT(#@*,3`N+2!R97-U;'0@.0H]/3T]
M/3T]($9R;VTZ(#$P('Q\($YU;6)E<B!O9B!R;W=S('1O(&9E=&-H.B`Q,"`]
M/3T]/3T]"C$Q+BT@<F5S=6QT(#$P"C$R+BT@<F5S=6QT(#$Q"C$S+BT@<F5S
M=6QT(#$R"C$T+BT@<F5S=6QT(#$S"C$U+BT@<F5S=6QT(#$T"C$V+BT@<F5S
M=6QT(#$U"C$W+BT@<F5S=6QT(#$V"C$X+BT@<F5S=6QT(#$W"C$Y+BT@<F5S
M=6QT(#$X"C(P+BT@<F5S=6QT(#$Y"CT]/3T]/3T@1G)O;3H@,C`@?'P@3G5M
M8F5R(&]F(')O=W,@=&\@9F5T8V@Z(#$P(#T]/3T]/3T*,C$N+2!R97-U;'0@
M,C`*,C(N+2!R97-U;'0@,C$*,C,N+2!R97-U;'0@,C(*,C0N+2!R97-U;'0@
M,C,*,C4N+2!R97-U;'0@,C0*,C8N+2!R97-U;'0@,C4*,C<N+2!R97-U;'0@
M,C8*,C@N+2!R97-U;'0@,C<*,CDN+2!R97-U;'0@,C@*,S`N+2!R97-U;'0@
M,CD*/3T]/3T]/2!&<F]M.B`S,"!\?"!.=6UB97(@;V8@<F]W<R!T;R!F971C
M:#H@,3`@/3T]/3T]/0HS,2XM(')E<W5L="`S,`HS,BXM(')E<W5L="`S,0HS
M,RXM(')E<W5L="`S,@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O9')I=F5R+S$V=&%B;&5I;F9O+G!H<'0`````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-30S-3(`,3`T,3<S-C,P,#,`,#(T-#0Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM5$535"TM"D1"7V1R:79E
M<CHZ=&%B;&5);F9O"BTM4TM)4$E&+2T*/#]P:'`*"B\J*@H@*B!#86QL<R!T
M86)L94EN9F\H*2!I;B!V87)I;W5S('=A>7,@86YD(&-H96-K<R!T;R!S964@
M=&AA="!T:&4@;W5T<'5T"B`J(&UA=&-H97,@=VAA="=S(&5X<&5C=&5D+@H@
M*@H@*B!4:&5S92!T97-T<R!A8V-O=6YT(&9O<B!E86-H($1"35,@=7-I;F<@
M9&EF9F5R96YT(&-O;'5M;B!T>7!E<R!A;F0*("H@<F5P;W)T:6YG(&)A8VL@
M9&EF9F5R96YT(&EN9F]R;6%T:6]N+B`@5&AE<V4@9&EF9F5R96YC97,@87)E
M(&%C8V]U;G1E9`H@*B!F;W(@:6X@=&AE(#QV87(^)'%U:7)K<SPO=F%R/B!A
M<G)A>2P@=VAI8V@@:&%S('1H92!F;VQL;W=I;F<@9F]R;6%T.@H@*@H@*B`\
M<')E/@H@*B`G9')I=F5R)R`]/B!A<G)A>2@*("H@("`@("=C;&]B)R`]/B!$
M0DU3)W,@8V]L=6UN('1Y<&4@9F]R(&-R96%T:6YG($-,3T(@9FEE;&1S"B`J
M("`@("`G9&%T92<@/3X@1$)-4R=S(&-O;'5M;B!T>7!E(&9O<B!C<F5A=&EN
M9R!$051%(&9I96QD<PH@*B`@("`@)V9I;F1S7W1A8FQE)R`]/B!#86X@=&AI
M<R!$0DU3(&1E=&5R;6EN92!T86)L92!N86UE<R!F<F]M('%U97)I97,_"B`J
M("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@*B`@("`@("`@($5X=')A(&-O
M;6UA;F1S('1O(&)E('!A<W-E9"!T;R!02%`G<R!E=F%L*"D@9G5N8W1I;VX*
M("H@("`@("D*("H@("`@(#`@/3X@87)R87DH"B`J("`@("`@("`@+R\@($EN
M9F\@97AP96-T960@=&\@8F4@<F5P;W)T960@9F]R('!H<'1E<W1?9FLN80H@
M*B`@("`@("`@("=T>7!E)R`]/B!#;VQU;6X@='EP92!R97!O<G1E9"!B>2!T
M:&4@1$)-4PH@*B`@("`@("`@("=L96XG(#T^($-O;'5M;B!S:7IE(')E<&]R
M=&5D(&)Y('1H92!$0DU3"B`J("`@("`@("`@)V9L86=S)R`]/B!&;&%G<R!R
M97!O<G1E9"!B>2!T:&4@1$)-4PH@*B`@("`@*0H@*B`@("`@,2`]/B!A<G)A
M>2@I("!);F9O(&5X<&5C=&5D('1O(&)E(')E<&]R=&5D(&9O<B!P:'!T97-T
M7V9K+F9K"B`J("`@("`R(#T^(&%R<F%Y*"D@($EN9F\@97AP96-T960@=&\@
M8F4@<F5P;W)T960@9F]R('!H<'1E<W1?9FLN8PH@*B`@("`@,R`]/B!A<G)A
M>2@I("!);F9O(&5X<&5C=&5D('1O(&)E(')E<&]R=&5D(&9O<B!P:'!T97-T
M7V9K+F0*("H@("`@(#0@/3X@87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B
M92!R97!O<G1E9"!F;W(@<&AP=&5S=%]F:RYE"B`J("`@("`U(#T^(&%R<F%Y
M*"D@($EN9F\@97AP96-T960@=&\@8F4@<F5P;W)T960@9F]R('!H<'1E<W1?
M9FLN9@H@*B`@("`@.2`]/B!A<G)A>2@I("!);F9O(&5X<&5C=&5D('1O(&)E
M(')E<&]R=&5D(&9O<B!P:'!T97-T+F0*("H@*0H@*B`\+W!R93X*("H*("H@
M0'-E92`@("`@($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("H@"B`J($!P86-K
M86=E("!$0@H@*B!`=F5R<VEO;B`@)$ED.B`Q-G1A8FQE:6YF;RYP:'!T+'8@
M,2XR,"`R,#`T+S`R+S$Y(#`W.C0U.C4P(&1A;FEE;&,@17AP("0*("H@0&-A
M=&5G;W)Y($1A=&%B87-E"B`J($!A=71H;W(@("!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0&%N86QY<VES86YD<V]L=71I;VYS+F-O;3X*("H@0&EN=&5R
M;F%L"B`J+PH*8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N
M8V4@)RXO<VMI<&EF+FEN8R<["B1T86)L94EN9F\@/2`D9&(M/G1A8FQE26YF
M;R@G86IK9'-L9F%J;VEJ:V%D:64G*3L*:68@*$1".CII<T5R<F]R*"1T86)L
M94EN9F\I("8F("1T86)L94EN9F\M/F-O9&4@/3T@1$)?15)23U)?3D]47T-!
M4$%"3$4I('L*("`@(&1I92@B<VMI<"`D=&%B;&5);F9O+3YM97-S86=E(BD[
M"GT*"C\^"BTM1DE,12TM"CP_<&AP"@HO+R`@)$ED.B`Q-G1A8FQE:6YF;RYP
M:'!T+'8@,2XR,"`R,#`T+S`R+S$Y(#`W.C0U.C4P(&1A;FEE;&,@17AP("0*
M"B\J*@H@*B!#;VYN96-T('1O('1H92!D871A8F%S92!A;F0@;6%K92!T:&4@
M<&AP=&5S="!T86)L92X*("HO"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN
M8R<["@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*
M("H@4')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4@
M<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@
M;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J
M($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H
M*0H@*B\*9G5N8W1I;VX@<&4H)&\I>PH@("`@9VQO8F%L("1D8F@["@H@("`@
M:68@*"1O+3YG971-97-S86=E*"D@/3T@(D1"($5R<F]R.B!C86XG="!D:7-T
M:6YG=6ES:"!D=7!L:6-A=&4@9FEE;&0@;F%M97,B*2!["B`@("`@("`@<')I
M;G0@(DY/5$E#13H@)&1B:"T^<&AP='EP92!C86XG="!D:7-T:6YG=6ES:"!D
M=7!L:6-A=&4@9FEE;&0@;F%M97,B.PH@("`@("`@(')E='5R;CL*("`@('T*
M"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L*("`@("1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E<W0G*3L*("`@
M("1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E<W1?9FLG*3L*"B`@("!D
M:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HO*BH*("H@3&]O<"!T:')O=6=H(&%N
M(&%R<F%Y(')E='5R;F5D(&9R;VT@=&%B;&5);F9O*"DL(&-O;7!A<F4@=&AE
M(&%C='5A;`H@*B!C;VYT96YT<R!T;R!T:&4@97AP96-T960@8V]N=&5N=',@
M86YD('!R:6YT(&]U="!W:&%T(&ES(&9O=6YD+@H@*@H@*B!`<&%R86T@87)R
M87D@("`D87)R87D@('1H92!A<G)A>2!T;R!B92!E>&%M:6YE9`H@*B!`<&%R
M86T@<W1R:6YG("`D9FEE;&0@(&9I96QD(&EN9&5X(&YU;6)E<B!O9B`D<75R
M:6MS(&%N9"!T86)L90H@*B!`<&%R86T@8F]O;&5A;B`D<75E<GD@('1R=64@
M:68@87)R87D@:7,@9G)O;2!A('%U97)Y(&]R(&9A;'-E(&EF(&%R<F%Y"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@:7,@=&%B;&5);F9O*"D*("H@0')E
M='5R;B!V;VED"B`J+PIF=6YC=&EO;B!E>&%M:6YE07)R87E$871A*"1A<G)A
M>2P@)&9I96QD(#T@9F%L<V4L("1Q=65R>2`]('1R=64I('L*("`@(&=L;V)A
M;"`D9&)H+"`D<75I<FMS.PH*("`@(&EF("@A:7-?87)R87DH)&%R<F%Y*2D@
M>PH@("`@("`@('!R:6YT(")4:&ES($1-0E,@9&ED;B=T('!R;V1U8V4@<')O
M<&5R(')E<W5L='-<;EQN7&Y<;EQN(CL*("`@("`@("!R971U<FX["B`@("!]
M"@H@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@)'9A;'5E*2!["B`@
M("`@("`@:68@*"1F:65L9"`A/3T@9F%L<V4@)B8*("`@("`@("`@("`@:7-S
M970H)'%U:7)K<ULD9&)H+3YP:'!T>7!E75LD9FEE;&1=6R1K97E=*2D*("`@
M("`@("!["B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=F;&%G<R<@)B8@)'9A
M;'5E(#T]("<G("8F("1Q=65R>2`F)@H@("`@("`@("`@("`@("`@(21Q=6ER
M:W-;)&1B:"T^<&AP='EP95U;)V9I;F1S7W1A8FQE)UTI"B`@("`@("`@("`@
M('L*("`@("`@("`@("`@("`@('!R:6YT("(D:V5Y("XN+B!M871C:&5D(&5X
M<&5C=&5D('9A;'5E7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@:68@*"1Q=6ER:W-;)&1B:"T^<&AP='EP95U;)&9I96QD75LD
M:V5Y72`]/2`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!P<FEN="`B
M)&ME>2`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU95QN(CL*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<')I;G0@(B1K
M97D@+BXN('=A<R`G)'9A;'5E)R!B=70@=V4@97AP96-T960@(CL*("`@("`@
M("`@("`@("`@("`@("!P<FEN="`B)WLD<75I<FMS6R1D8F@M/G!H<'1Y<&5=
M6R1F:65L9%U;)&ME>5U])UQN(CL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D:V5Y
M(#T]("=T86)L92<I('L*("`@("`@("`@("`@("`@(&EF("@D9FEE;&0@/#T@
M-2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=64@/3T@)W!H<'1E
M<W1?9FLG*2!["B`@("`@("`@("`@("`@("`@("`@("`@('!R:6YT("(D:V5Y
M("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E7&XB.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M=F%L=64@/3T@)R<@)B8@)'%U97)Y("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`A)'%U:7)K<ULD9&)H+3YP:'!T>7!E75LG9FEN9'-?=&%B;&4G
M72D*("`@("`@("`@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<')I;G0@(B1K97D@+BXN(&UA=&-H960@97AP96-T960@
M=F%L=65<;B(["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!P<FEN="`B)&ME>2`N+BX@=V%S
M("<D=F%L=64G(&)U="!W92!E>'!E8W1E9"`G<&AP=&5S=%]F:R=<;B(["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D=F%L=64@/3T@)W!H<'1E<W0G*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@('!R:6YT("(D:V5Y("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E
M7&XB.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D=F%L=64@/3T@)R<@)B8@)'%U97)Y("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`A)'%U:7)K<ULD9&)H+3YP:'!T
M>7!E75LG9FEN9'-?=&%B;&4G72D*("`@("`@("`@("`@("`@("`@("`@("`@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@<')I;G0@(B1K97D@+BXN
M(&UA=&-H960@97AP96-T960@=F%L=65<;B(["B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!P
M<FEN="`B)&ME>2`N+BX@=V%S("<D=F%L=64G(&)U="!W92!E>'!E8W1E9"`G
M<&AP=&5S=%]F:R=<;B(["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!P<FEN="`B)&ME>2`]/B`D
M=F%L=65<;B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"GT*"B\J
M*@H@*B!,;V]P('1H<F]U9V@@86X@87)R87D@;V8@=&%B;&4@:6YF;R!D871A
M(&%N9"!R971U<FX@=&AE(')E<W5L=',N"B`J"B`J($!P87)A;2!A<G)A>2`@
M)&%R<F%Y("!T:&4@87)R87D@=&\@8F4@97AA;6EN960*("H@0')E='5R;B!S
M=')I;F<*("HO"F9U;F-T:6]N(')E='5R;D%R<F%Y1&%T82@D87)R87DI('L*
M("`@("1O=70@/2`G)SL*("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^
M("1V86QU92D@>PH@("`@("`@("1O=70@+CT@(B1K97D@/3X@)'9A;'5E7&XB
M.PH@("`@?0H@("`@<F5T=7)N("1O=70["GT*"@HD9&)H+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1Q=6ER:W,@
M/2!A<G)A>2@*("`@("=I8F%S92<@/3X@87)R87DH"B`@("`@("`@)V-L;V(G
M(#T^("=605)#2$%2*#4P*2<L"B`@("`@("`@)V1A=&4G(#T^("=$051%)RP*
M("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=C;VUM
M86YD<R<@/3X@87)R87DH"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'15(G+`H@("`@("`@("`@
M("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=U;FEQ=65?
M:V5Y(&YO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#$@/3X@87)R87DH
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@
M("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)W!R:6UA<GE?
M:V5Y(&YO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#(@/3X@87)R87DH
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G5D%20TA!4B<L"B`@("`@("`@("`@
M("=L96XG(#T^(#4P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@
M("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=$051%)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G=6YI<75E7VME>2!N;W1?;G5L;"<L"B`@("`@("`@
M*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)T-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G
M9FQA9W,G(#T^("=N;W1?;G5L;"!D969A=6QT)RP*("`@("`@("`I+`H@("`@
M("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G3E5-15))
M0R@Y+#$I)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#D@/3X@87)R87DH
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G5D%20TA!4B<L"B`@("`@("`@("`@
M("=L96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@
M("`@("DL"B`@("`I+`H*("`@("=I9G@G(#T^(&%R<F%Y*`H@("`@("`@("=C
M;&]B)R`]/B`G0TA!4B@R.2DG+`H@("`@("`@("=D871E)R`]/B`G0TA!4B@Q
M,"DG+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@
M)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@("`@("`I+`H@("`@("`@(#`@/3X@
M87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G4U%,24Y4)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T
M7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=344Q)3E0G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@
M("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)U-13$-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R.2P*("`@("`@
M("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@
M87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G4U%,0TA!4B<L"B`@("`@
M("`@("`@("=L96XG(#T^(#$P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N
M;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G='EP92<@/3X@)U-13$-(05(G+`H@("`@("`@("`@("`G;&5N
M)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@
M("`@("`@*2P*("`@("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)U-13$1%0TE-04PG+`H@("`@("`@("`@("`G;&5N)R`]/B`U,3,L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@
M("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U-13$-(05(G
M+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S
M)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G;7-S<6PG(#T^(&%R
M<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G
M(#T^("=334%,3$1!5$5424U%)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^
M(&9A;'-E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@
M("`@("=I;FE?<V5T*")M<W-Q;"YD871E=&EM96-O;G9E<G0B+"`B3V9F(BD[
M)RP*("`@("`@("`@("`@)R1D8F@M/G%U97)Y*")3150@1$%4149/4DU!5"!Y
M;60B*3LG+`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T
M+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=M=6QT:7!L95]K97D@=6YI<75E
M7VME>2!N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L
M96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)W!R:6UA<GE?:V5Y
M(&YO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#(@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("=L96XG
M(#T^(#0P.38L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@
M*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)V1A=&5T:6UE)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G;75L=&EP;&5?:V5Y('5N:7%U95]K97D@;F]T7VYU
M;&PG+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL
M"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=R
M96%L)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3DL"B`@("`@("`@("`@("=F
M;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)V-H87(G+`H@("`@("`@("`@("`G;&5N
M)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I
M+`H@("`@*2P*"B`@("`G;7ES<6PG(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B
M)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@
M("`G9FEN9'-?=&%B;&4G(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S)R`]
M/B!A<G)A>2@*("`@("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M,3$L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&UU;'1I<&QE
M7VME>2<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^(#$Q
M+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!P<FEM87)Y7VME
M>2<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`G='EP92<@/3X@)V)L;V(G+`H@("`@("`@("`@("`G;&5N)R`]/B`V-34S
M-2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G8FQO8B<L"B`@("`@("`@*2P*
M("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V1A
M=&4G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;F]T7VYU;&P@;75L=&EP;&5?:V5Y)RP*("`@("`@("`I+`H@
M("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R
M:6YG)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=R96%L)RP*("`@("`@("`@
M("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@
M("`@("`I+`H@("`@("`@(#D@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@
M)V]C:3@G(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G0TQ/0B<L"B`@
M("`@("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@("`G9FEN9'-?=&%B;&4G
M(#T^(&9A;'-E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@
M("`@("`@("<D9&)H+3YQ=65R>2@B04Q415(@4T534TE/3B!3150@3DQ37T1!
M5$5?1D]234%4(#T@7"=965E9+4U-+41$7"<B*3LG+`H@("`@("`@("DL"B`@
M("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=.54U"
M15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,BP*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=.54U"15(G+`H@("`@("`@
M("`@("`G;&5N)R`]/B`R,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T
M7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=#3$]")RP*("`@("`@("`@("`@)VQE;B<@/3X@
M-#`P,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@
M("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$%4
M12<L"B`@("`@("`@("`@("=L96XG(#T^(#<L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@("`@("`@
M("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL
M)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G3E5-0D52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C(L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@
M("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G
M+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S
M)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G<&=S<6PG(#T^(&%R
M<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G
M(#T^("=$051%)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@
M("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@("`@("<D9&)H
M+3YQ=65R>2@B4T54($1!5$535%E,12`]($E33R(I.R<L"B`@("`@("`@*2P*
M("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN
M=#0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA
M9W,G(#T^("=N;W1?;G5L;"!U;FEQ=65?:V5Y(&UU;'1I<&QE7VME>2<L"B`@
M("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)VEN=#0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!P<FEM87)Y7VME>2<L"B`@("`@
M("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)W1E>'0G+`H@("`@("`@("`@("`G;&5N)R`]/B`M,2P*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&%T92<L"B`@("`@("`@("`@
M("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL
M('5N:7%U95]K97D@;75L=&EP;&5?:V5Y)RP*("`@("`@("`I+`H@("`@("`@
M(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G8G!C:&%R)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@+3$L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)VYO=%]N=6QL(&1E9F%U;'1?9&8E,C!T)RP*("`@("`@("`I+`H@("`@
M("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G;G5M97)I
M8R<L"B`@("`@("`@("`@("=L96XG(#T^("TQ+`H@("`@("`@("`@("`G9FQA
M9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=V87)C:&%R)RP*("`@("`@("`@("`@)VQE
M;B<@/3X@+3$L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@
M*2P*("`@("DL"@H@("`@)W-Y8F%S92<@/3X@87)R87DH"B`@("`@("`@)V-L
M;V(G(#T^("=415A4)RP*("`@("`@("`G9&%T92<@/3X@)U--04Q,1$%4151)
M344G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@
M)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@)R1D8F@M/G%U97)Y
M*")3150@1$%4149/4DU!5"!Y;60B*3LG+`H@("`@("`@("DL"B`@("`@("`@
M,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`Q,2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M;75L=&EP;&5?:V5Y('5N:7%U95]K97DG+`H@("`@("`@("DL"B`@("`@("`@
M,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`Q,2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M=6YI<75E7VME>2<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=L
M96XG(#T^(#,R-S8X+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@
M("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=D871E=&EM92<L"B`@("`@("`@("`@("=L96XG(#T^(#(Y+`H@("`@
M("`@("`@("`G9FQA9W,G(#T^("=M=6QT:7!L95]K97D@=6YI<75E7VME>2<L
M"B`@("`@("`@*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`U
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W)E86PG+`H@("`@
M("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G
M+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*
M*3L*"@II9B`H(6ES<V5T*"1Q=6ER:W-;)&1B:"T^<&AP='EP95TI*2!["B`@
M("!D:64H(E1H:7,@=&5S="!D;V5S(&YO="!Y970@<W5P<&]R="`D9&)H+3YP
M:'!T>7!E(BD["GT*"FEF("AC;W5N="@D<75I<FMS6R1D8F@M/G!H<'1Y<&5=
M6R=C;VUM86YD<R==*2D@>PH@("`@9F]R96%C:"`H)'%U:7)K<ULD9&)H+3YP
M:'!T>7!E75LG8V]M;6%N9',G72!A<R`D=F%L=64I('L*("`@("`@("!E=F%L
M*"1V86QU92D["B`@("!]"GT*"@HD9&)H+3YQ=65R>2@G1$5,151%($923TT@
M<&AP=&5S="<I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!6
M04Q515,@*#$L("=O;F4G+"`G3VYE)RP@)S(P,#$M,#(M,38G*2(I.PHD9&)H
M+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,@*#(L("=T=V\G
M+"`G5'=O)RP@)S(P,#$M,#(M,34G*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4
M($E.5$\@<&AP=&5S="!604Q515,@*#,L("=T:')E92<L("=4:')E92<L("<R
M,#`Q+3`R+3$T)RDB*3L*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L*)&1B:"T^<75E<GDH)T123U`@5$%"3$4@<&AP=&5S
M=%]F:R<I.PHD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,
M3$)!0TLL("=P92<I.PH*"B\O("1N=6QL(&ES('-E="!I;B!M:W1A8FQE+FEN
M8PH*)&1B:"T^<75E<GDH(@H@("`@0U)%051%(%1!0DQ%('!H<'1E<W1?9FL@
M*`H@("`@("`@(&$@24Y414=%4B!.3U0@3E5,3"P*("`@("`@("!F:R!)3E1%
M1T52($Y/5"!.54Q,+`H@("`@("`@(&,@>R1Q=6ER:W-;)&1B:"T^<&AP='EP
M95U;)V-L;V(G77T@)&YU;&PL"B`@("`@("`@9"![)'%U:7)K<ULD9&)H+3YP
M:'!T>7!E75LG9&%T92==?2!.3U0@3E5,3"P*("`@("`@("!E($-(05(H-"D@
M1$5&055,5"`G9&8@="<@3D]4($Y53$PL"B`@("`@("`@9B!$14-)34%,*#(L
M,2D@)&YU;&PL"B`@("`@("`@4%))34%262!+15D@*&9K*2P*("`@("`@("!5
M3DE1544@*&$L(&0I"B`@("`I"B(I.PHD9&)H+3YQ=65R>2@B0U)%051%($E.
M1$58('1H961I9'@@3TX@<&AP=&5S=%]F:R`H9"DB*3L*)&1B:"T^<75E<GDH
M(DE.4T525"!)3E1/('!H<'1E<W1?9FL@5D%,5453("@Q,"P@,2P@)T]N92<L
M("<R,#`Q+3`R+3$V)RP@("=C,2<L(#$N,2DB*3L*)&1B:"T^<75E<GDH(DE.
M4T525"!)3E1/('!H<'1E<W1?9FL@5D%,5453("@R,"P@,BP@)U1W;R<L("<R
M,#`Q+3`R+3$U)RP@)V,R)RP@,BXR*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4
M($E.5$\@<&AP=&5S=%]F:R!604Q515,@*#,P+"`S+"`G5&AR964G+"`G,C`P
M,2TP,BTQ-"<L("=C,R<L(#,N,RDB*3L*"@HD<F5S=6QT;V)J(#TF("1D8F@M
M/G%U97)Y*"=314Q%0U0@<&AP=&5S=%]F:RYA+"!P:'!T97-T7V9K+F9K+`H@
M("`@("`@('!H<'1E<W1?9FLN8RP@<&AP=&5S=%]F:RYD+"!P:'!T97-T7V9K
M+F4L('!H<'1E<W1?9FLN9BP*("`@("`@("!P:'!T97-T+F$L('!H<'1E<W0N
M8BP@<&AP=&5S="YC+"!P:'!T97-T+F0*("`@("`@("!&4D]-('!H<'1E<W1?
M9FLL('!H<'1E<W0@5TA%4D4@<&AP=&5S="YA(#T@<&AP=&5S=%]F:RYF:R<I
M.PH*"@IP<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3U<;B(["G!R:6YT(")087-S:6YG(')E<W5L="!/0DI%0U0@
M=&\@;65T:&]D(&EN($1"7SQT>7!E/BY<;B(["G!R:6YT(")/=71P=70@/2!D
M969A=6QT+EQN(CL*<')I;G0@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+5QN(CL*)&%R<F%Y(#T@)&1B:"T^=&%B;&5);F9O
M*"1R97-U;'1O8FHI.PH*<')I;G0@(EQN9FER<W0@9FEE;&0Z7&XB.PIE>&%M
M:6YE07)R87E$871A*"1A<G)A>5LP72P@,"D["@IP<FEN="`B7&YT96YT:"!F
M:65L9#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y6SE=+"`Y*3L*"@H*
M<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]7&XB.PIP<FEN="`B4&%S<VEN9R!R97-U;'0@240@=&\@;65T:&]D
M(&EN($1"7SQT>7!E/BY<;B(["G!R:6YT(")/=71P=70@/2!$0E]404),14E.
M1D]?3U)$15(N7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM7&XB.PHD87)R87D@/2`D9&)H+3YT86)L94EN
M9F\H)')E<W5L=&]B:BT^<F5S=6QT+"!$0E]404),14E.1D]?3U)$15(I.PH*
M<')I;G0@(EQN9FER<W0@9FEE;&0Z7&XB.PIE>&%M:6YE07)R87E$871A*"1A
M<G)A>5LP72P@,"D["@IP<FEN="`B7&YF;W5R=&@@9FEE;&0Z7&XB.PIE>&%M
M:6YE07)R87E$871A*"1A<G)A>5LS72P@,RD["@IP<FEN="`B7&YN=6U?9FEE
M;&1S.EQN(CL*<')I;G0@(GLD87)R87E;)VYU;5]F:65L9',G77U<;B(["@IP
M<FEN="`B7&YO<F1E<CI<;B(["FEF("AI<U]A<G)A>2@D87)R87E;)V]R9&5R
M)UTI*2!["B`@("!K<V]R="@D87)R87E;)V]R9&5R)UTI.PH@("`@97AA;6EN
M94%R<F%Y1&%T82@D87)R87E;)V]R9&5R)UTI.PI](&5L<V4@>PH@("`@<')I
M;G0@(E1H:7,@1$U"4R!D:61N)W0@<')O9'5C92!P<F]P97(@<F5S=6QT<UQN
M7&Y<;EQN7&Y<;EQN(CL*?0H*"@IP<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT(")087-S:6YG
M($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%('1O(&UE=&AO9"!I;B!$0E]R97-U
M;'0N7&XB.PIP<FEN="`B3W5T<'5T(#T@1$)?5$%"3$5)3D9/7T]21$525$%"
M3$4N7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM7&XB.PHD87)R87D@/2`D<F5S=6QT;V)J+3YT86)L94EN
M9F\H1$)?5$%"3$5)3D9/7T]21$525$%"3$4I.PHO+R!&<F5E('1H:7,@=&\@
M:V5E<"!I;G1E<F)A<V4@:&%P<'DN"B1R97-U;'1O8FHM/F9R964H*3L*"G!R
M:6YT(")<;F9I<G-T(&9I96QD.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R
M87E;,%TL(#`I.PH*<')I;G0@(EQN9F]U<G1H(&9I96QD.EQN(CL*97AA;6EN
M94%R<F%Y1&%T82@D87)R87E;,UTL(#,I.PH*<')I;G0@(EQN;G5M7V9I96QD
M<SI<;B(["G!R:6YT(")[)&%R<F%Y6R=N=6U?9FEE;&1S)UU]7&XB.PH*"G!R
M:6YT(")<;F]R9&5R=&%B;&5;<&AP=&5S=%TZ7&XB.PHD97AP96-T960@/2`G
M82`]/B`V"F(@/3X@-PIC(#T^(#@*9"`]/B`Y"B<["FEF("AI<W-E="@D87)R
M87E;)V]R9&5R=&%B;&4G75LG<&AP=&5S="==*2D@>PH@("`@)&%C='5A;"`]
M(')E='5R;D%R<F%Y1&%T82@D87)R87E;)V]R9&5R=&%B;&4G75LG<&AP=&5S
M="==*3L*?2!E;'-E('L*("`@("1A8W1U86P@/2`G)SL*?0II9B`H)&%C='5A
M;"`]/2`D97AP96-T960I('L*("`@('!R:6YT(")M871C:&5D(&5X<&5C=&5D
M('9A;'5E<UQN(CL*?2!E;'-E('L*("`@(&EF("@D<75I<FMS6R1D8F@M/G!H
M<'1Y<&5=6R=F:6YD<U]T86)L92==(#T]/2!F86QS92`F)B`D86-T=6%L(#T]
M("<G*2!["B`@("`@("`@<')I;G0@(FUA=&-H960@97AP96-T960@=F%L=65S
M7&XB.PH@("`@?2!E;'-E('L*("`@("`@("!P<FEN="`B1$E$3B=4(&UA=&-H
M(&5X<&5C=&5D('9A;'5E<RXN+EQN(CL*("`@("`@("!P<FEN="`B?GY^?GY^
M?GY<;D5X<&5C=&5D.EQN)&5X<&5C=&5D7&XB.PH@("`@("`@('!R:6YT(")^
M?GY^7&Y!8W1U86PZ7&XD86-T=6%L7&Y^?GY^?GY^?EQN7&XB.PH@("`@?0I]
M"@H*<')I;G0@(EQN;W)D97)T86)L95MP:'!T97-T7V9K73I<;B(["B1E>'!E
M8W1E9"`]("=A(#T^(#`*9FL@/3X@,0IC(#T^(#(*9"`]/B`S"F4@/3X@-`IF
M(#T^(#4*)SL*:68@*&ES<V5T*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T
M97-T7V9K)UTI*2!["B`@("`D86-T=6%L(#T@<F5T=7)N07)R87E$871A*"1A
M<G)A>5LG;W)D97)T86)L92==6R=P:'!T97-T7V9K)UTI.PI](&5L<V4@>PH@
M("`@)&%C='5A;"`]("<G.PI]"FEF("@D86-T=6%L(#T]("1E>'!E8W1E9"D@
M>PH@("`@<')I;G0@(FUA=&-H960@97AP96-T960@=F%L=65S7&XB.PI](&5L
M<V4@>PH@("`@:68@*"1Q=6ER:W-;)&1B:"T^<&AP='EP95U;)V9I;F1S7W1A
M8FQE)UT@/3T](&9A;'-E("8F("1A8W1U86P@/3T@)R<I('L*("`@("`@("!P
M<FEN="`B;6%T8VAE9"!E>'!E8W1E9"!V86QU97-<;B(["B`@("!](&5L<V4@
M>PH@("`@("`@('!R:6YT(")$241.)U0@;6%T8V@@97AP96-T960@=F%L=65S
M+BXN7&XB.PH@("`@("`@('!R:6YT(")^?GY^?GY^?EQN17AP96-T960Z7&XD
M97AP96-T961<;B(["B`@("`@("`@<')I;G0@(GY^?GY<;D%C='5A;#I<;B1A
M8W1U86Q<;GY^?GY^?GY^7&Y<;B(["B`@("!]"GT*"@IP<FEN="`B7&X]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R
M:6YT(")087-S:6YG(%1!0DQ%($Y!344@)W!H<'1E<W1?9FLG('1O(&UE=&AO
M9"!I;B!$0E\\9')I=F5R/BY<;B(["G!R:6YT(")/=71P=70@/2!D969A=6QT
M+EQN(CL*<')I;G0@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+5QN(CL*)&%R<F%Y(#T@)&1B:"T^=&%B;&5);F9O*"=P:'!T
M97-T7V9K)RD["@IP<FEN="`B7&YF:7)S="!F:65L9#I<;B(["F5X86UI;F5!
M<G)A>41A=&$H)&%R<F%Y6S!=+"`P+"!F86QS92D["@IP<FEN="`B7&YS96-O
M;F0@9FEE;&0Z7&XB.PIE>&%M:6YE07)R87E$871A*"1A<G)A>5LQ72P@,2P@
M9F%L<V4I.PH*<')I;G0@(EQN=&AI<F0@9FEE;&0Z7&XB.PIE>&%M:6YE07)R
M87E$871A*"1A<G)A>5LR72P@,BP@9F%L<V4I.PH*<')I;G0@(EQN9F]U<G1H
M(&9I96QD.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87E;,UTL(#,L(&9A
M;'-E*3L*"G!R:6YT(")<;F9I9G1H(&9I96QD.EQN(CL*97AA;6EN94%R<F%Y
M1&%T82@D87)R87E;-%TL(#0L(&9A;'-E*3L*"G!R:6YT(")<;G-I>'1H(&9I
M96QD.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87E;-5TL(#4L(&9A;'-E
M*3L*"@IP<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3U<;B(["G!R:6YT(")087-S:6YG(%1!0DQ%($Y!344@)W!H
M<'1E<W1?9FLG('1O(&UE=&AO9"!I;B!$0E\\9')I=F5R/BY<;B(["G!R:6YT
M(")/=71P=70@/2!$0E]404),14E.1D]?1E5,3"Y<;B(["G!R:6YT("(M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2U<;B(["B1A
M<G)A>2`]("1D8F@M/G1A8FQE26YF;R@G<&AP=&5S=%]F:R<L($1"7U1!0DQ%
M24Y&3U]&54Q,*3L*"G!R:6YT(")<;F9I<G-T(&9I96QD.EQN(CL*97AA;6EN
M94%R<F%Y1&%T82@D87)R87E;,%TL(#`L(&9A;'-E*3L*"G!R:6YT(")<;F]R
M9&5R.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87E;)V]R9&5R)UTL(&9A
M;'-E*3L*"G!R:6YT(")<;F]R9&5R=&%B;&5;<&AP=&5S=%]F:UTZ7&XB.PIE
M>&%M:6YE07)R87E$871A*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T97-T
M7V9K)UTI.PH*"@IP<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT(")087-S:6YG(%1!0DQ%($Y!
M344@)W!H<'1E<W1?9FLG('1O(&UE=&AO9"!I;B!$0E\\9')I=F5R/B!!1T%)
M3BY<;B(["G!R:6YT(")/=71P=70@/2!$0E]404),14E.1D]?1E5,3"P@;&]W
M97)C87-I;F<@='5R;F5D(&]F9BY<;B(["G!R:6YT("(M+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2U<;B(["B1D8F@M/G-E=$]P
M=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465]!3$P@7B!$0E]0
M3U)404))3$E465],3U=%4D-!4T4I.PHD87)R87D@/2`D9&)H+3YT86)L94EN
M9F\H)W!H<'1E<W1?9FLG+"!$0E]404),14E.1D]?1E5,3"D["@HO+R!T97-T
M:6YG(&YO;BUL;W=E<F-A<VEN9R!A8F]V92!T;R!E;G-U<F4@<')O9W)A;2!D
M;V5S;B=T(&1I92X*+R\@;&]W97)C87-E('1H92!N86UE<R!H97)E('1O(&5N
M<W5R92!T97-T('5N:69O<FUI='DN"B1A<G)A>5LP75LG=&%B;&4G72`]('-T
M<G1O;&]W97(H)&%R<F%Y6S!=6R=T86)L92==*3L*)&%R<F%Y6S!=6R=N86UE
M)UT@/2!S=')T;VQO=V5R*"1A<G)A>5LP75LG;F%M92==*3L*"G!R:6YT(")<
M;F9I<G-T(&9I96QD.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87E;,%TL
M(#`L(&9A;'-E*3L*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L*)&1B:"T^<75E<GDH)T123U`@5$%"3$4@<&AP=&5S="<I
M.PHD9&)H+3YQ=65R>2@G1%)/4"!404),12!P:'!T97-T7V9K)RD["@H_/@HM
M+4584$5#5"TM"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/0I087-S:6YG(')E<W5L="!/0DI%0U0@=&\@;65T:&]D(&EN($1"
M7SQT>7!E/BX*3W5T<'5T(#T@9&5F875L="X*+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@IF:7)S="!F:65L9#H*=&%B;&4@
M+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;F%M92`]/B!A"G1Y<&4@+BXN
M(&UA=&-H960@97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"@IT
M96YT:"!F:65L9#H*=&%B;&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*
M;F%M92`]/B!D"G1Y<&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;&5N
M("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D
M(&5X<&5C=&5D('9A;'5E"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*4&%S<VEN9R!R97-U;'0@240@=&\@;65T:&]D(&EN
M($1"7SQT>7!E/BX*3W5T<'5T(#T@1$)?5$%"3$5)3D9/7T]21$52+@HM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"F9I<G-T
M(&9I96QD.@IT86)L92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN86UE
M(#T^(&$*='EP92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IL96X@+BXN
M(&UA=&-H960@97AP96-T960@=F%L=64*9FQA9W,@+BXN(&UA=&-H960@97AP
M96-T960@=F%L=64*"F9O=7)T:"!F:65L9#H*=&%B;&4@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=64*;F%M92`]/B!D"G1Y<&4@+BXN(&UA=&-H960@97AP
M96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"F9L
M86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"@IN=6U?9FEE;&1S.@HQ
M,`H*;W)D97(Z"F$@/3X@-@IB(#T^(#<*8R`]/B`X"F0@/3X@.0IE(#T^(#0*
M9B`]/B`U"F9K(#T^(#$*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0I087-S:6YG($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%
M('1O(&UE=&AO9"!I;B!$0E]R97-U;'0N"D]U='!U="`]($1"7U1!0DQ%24Y&
M3U]/4D1%4E1!0DQ%+@HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*"F9I<G-T(&9I96QD.@IT86)L92`N+BX@;6%T8VAE9"!E
M>'!E8W1E9"!V86QU90IN86UE(#T^(&$*='EP92`N+BX@;6%T8VAE9"!E>'!E
M8W1E9"!V86QU90IL96X@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*9FQA
M9W,@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*"F9O=7)T:"!F:65L9#H*
M=&%B;&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;F%M92`]/B!D"G1Y
M<&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D
M(&5X<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A
M;'5E"@IN=6U?9FEE;&1S.@HQ,`H*;W)D97)T86)L95MP:'!T97-T73H*;6%T
M8VAE9"!E>'!E8W1E9"!V86QU97,*"F]R9&5R=&%B;&5;<&AP=&5S=%]F:UTZ
M"FUA=&-H960@97AP96-T960@=F%L=65S"@H]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*4&%S<VEN9R!404),12!.04U%("=P
M:'!T97-T7V9K)R!T;R!M971H;V0@:6X@1$)?/&1R:79E<CXN"D]U='!U="`]
M(&1E9F%U;'0N"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H*9FER<W0@9FEE;&0Z"G1A8FQE("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E"FYA;64@/3X@80IT>7!E("XN+B!M871C:&5D(&5X<&5C=&5D
M('9A;'5E"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IF;&%G<R`N
M+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90H*<V5C;VYD(&9I96QD.@IT86)L
M92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN86UE(#T^(&9K"G1Y<&4@
M+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X
M<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E
M"@IT:&ER9"!F:65L9#H*=&%B;&4@+BXN(&UA=&-H960@97AP96-T960@=F%L
M=64*;F%M92`]/B!C"G1Y<&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*
M;&5N("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C
M:&5D(&5X<&5C=&5D('9A;'5E"@IF;W5R=&@@9FEE;&0Z"G1A8FQE("XN+B!M
M871C:&5D(&5X<&5C=&5D('9A;'5E"FYA;64@/3X@9`IT>7!E("XN+B!M871C
M:&5D(&5X<&5C=&5D('9A;'5E"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V
M86QU90IF;&%G<R`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90H*9FEF=&@@
M9FEE;&0Z"G1A8FQE("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FYA;64@
M/3X@90IT>7!E("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FQE;B`N+BX@
M;6%T8VAE9"!E>'!E8W1E9"!V86QU90IF;&%G<R`N+BX@;6%T8VAE9"!E>'!E
M8W1E9"!V86QU90H*<VEX=&@@9FEE;&0Z"G1A8FQE("XN+B!M871C:&5D(&5X
M<&5C=&5D('9A;'5E"FYA;64@/3X@9@IT>7!E("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IF;&%G
M<R`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90H*/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"E!A<W-I;F<@5$%"3$4@3D%-
M12`G<&AP=&5S=%]F:R<@=&\@;65T:&]D(&EN($1"7SQD<FEV97(^+@I/=71P
M=70@/2!$0E]404),14E.1D]?1E5,3"X*+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@IF:7)S="!F:65L9#H*=&%B;&4@+BXN
M(&UA=&-H960@97AP96-T960@=F%L=64*;F%M92`]/B!A"G1Y<&4@+BXN(&UA
M=&-H960@97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C=&5D
M('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"@IO<F1E
M<CH*82`]/B`P"F9K(#T^(#$*8R`]/B`R"F0@/3X@,PIE(#T^(#0*9B`]/B`U
M"@IO<F1E<G1A8FQE6W!H<'1E<W1?9FM=.@IA(#T^(#`*9FL@/3X@,0IC(#T^
M(#(*9"`]/B`S"F4@/3X@-`IF(#T^(#4*"CT]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I087-S:6YG(%1!0DQ%($Y!344@)W!H
M<'1E<W1?9FLG('1O(&UE=&AO9"!I;B!$0E\\9')I=F5R/B!!1T%)3BX*3W5T
M<'5T(#T@1$)?5$%"3$5)3D9/7T953$PL(&QO=V5R8V%S:6YG('1U<FYE9"!O
M9F8N"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0H*9FER<W0@9FEE;&0Z"G1A8FQE("XN+B!M871C:&5D(&5X<&5C=&5D('9A
M;'5E"FYA;64@/3X@80IT>7!E("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E
M"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IF;&%G<R`N+BX@;6%T
M8VAE9"!E>'!E8W1E9"!V86QU90H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O<G5N+F-V<P``
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,34V,0`Q,#0Q-S,V,S`P,P`P,C(W
M-#4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R$@+V)I;B]S:`H*(R`D260Z(')U;BYC=G,L=B`Q+C$@,C`P-"\P,B\Q,B`Q
M-CHQ,SHU-2!D86YI96QC($5X<"`D"@HC('9V=G9V=G9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V"B,@4$5!4B!$0B!415-4
M(%-405)415(*(PHC("`@5&\@<G5N(&%L;"!T97-T<SH@("XO<G5N"B,@("!4
M;R!R=6X@;VYE('1E<W0Z("`@+B]R=6X@/'1E<W0@;F%M93XN<&AP=`HC("`@
M17AA;7!L93H@("`@("`@("`@("XO<G5N(&1B7W!A<G-E9'-N+G!H<'0*(PHC
M($)E9F]R92!R=6YN:6YG('1H92!T97-T<R!Y;W4@;75S="!A9&IU<W0@=&AE
M"B,@9F]L;&]W:6YG('1H<F5E('9A<FEA8FQE<SH*"B,@("!4:&4@9G5L;"!P
M871H('1O('EO=7(@4$A0(&1I<F5C=&]R>3H*("`@($1"7U1%4U1?4$A07U!!
M5$@]8SHO<')O9W)A?C$O<&AP"@HC("`@5&AE(&YA;64@;V8@>6]U<B!02%`@
M0TQ)(&5X96-U=&%B;&4*(R`@("AE>&%M<&QE<R!P:'`N97AE+"!P:'`M8VQI
M+F5X92P@8VQI+W!H<"YE>&4I.@H@("`@1$)?5$535%]02%!?0TQ)/7!H<"YE
M>&4*"B,@("!4:&4@9G5L;"!P871H('1O('1H92!P<F5S96YT(&1I<F5C=&]R
M>0HC("`@*&YO="!U<VEN9R`D4%=$(&1U92!T;R!#>6=W:6XI.@H@("`@1$)?
M5$535%]$25(]9#HO<&5A<G1E<W0O<&5A<B]$0B]T97-T<R]D<FEV97(*"B,@
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>
M7EY>7EX*"@H*5$535%]02%!?15A%0U5404),13TD1$)?5$535%]02%!?4$%4
M2"\D1$)?5$535%]02%!?0TQ)"F5X<&]R="!415-47U!(4%]%6$5#551!0DQ%
M"@HD5$535%]02%!?15A%0U5404),12`D1$)?5$535%]02%!?4$%42"]R=6XM
M=&5S=',N<&AP("1$0E]415-47T1)4B\D,0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#5S
M97%U96YC97,N<&AP=``````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<Q-``Q,#0Q-S,V,S`P
M,P`P,C0T-C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2U415-4+2T*1$)?9')I=F5R.CIS97%U96YC97,*+2U32TE0248M
M+0H\/W!H<`IC:&1I<BAD:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC
M92`G+B]S:VEP:68N:6YC)SL*)'1A8FQE26YF;R`]("1D8BT^9')O<%-E<75E
M;F-E*"=A:FMD<VQF86IO:6IK861I92<I.PII9B`H1$(Z.FES17)R;W(H)'1A
M8FQE26YF;RD@)B8@)'1A8FQE26YF;RT^8V]D92`]/2!$0E]%4E)/4E].3U1?
M0T%004),12D@>PH@("`@9&EE*")S:VEP("1T86)L94EN9F\M/FUE<W-A9V4B
M*3L*?0H_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO8V]N;F5C
M="YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+W-E<75E;F-E<RYI;F,G.PH_/@HM
M+4584$5#5"TM"D1"($5R<F]R.B!N;R!S=6-H('1A8FQE"D1"($5R<F]R.B!N
M;R!S=6-H('1A8FQE(#PM(&=O;V0@97)R;W(@8V%T8VAE9`IA/3$*8CTR"F(M
M83TQ"F,],0ID/3$*93TQ"@``````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+V)U9S(R,S(X+G!H<'0`
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(S,3<`,3`T,3<S-C,P,#,`,#(S-#<W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM5$53
M5"TM"D1"7V1R:79E<CHZ8G5G,C(S,C@*+2U32TE0248M+0H\/W!H<"!C:&1I
M<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N
M:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+V-O;FYE
M8W0N:6YC)SL*"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R
M+@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S="!T86)L92P@<')I;G1S(&]U="!A
M;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@<')O8V5S<RX*("H*
M("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M
M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I
M9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I
M;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@)&1B:"T^<75E
M<GDH)T123U`@5$%"3$4@<&AP7VQI;6ET)RD["@H@("`@9&EE*"1O+3YT;U-T
M<FEN9R@I*3L*?0H*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PHD9&)H+3YQ=65R>2@G1%)/4"!404),12!P:'!?;&EM:70G
M*3L*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#
M2RP@)W!E)RD["@HD9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%('!H<%]L:6UI
M="`H82!#2$%2*#(P*2DG*3L*"@HD<F5S(#T@)&1B:"T^<75E<GDH)W-E;&5C
M="`J(&9R;VT@<&AP7VQI;6ET)RD["B1E<G)O<B`](#`["G=H:6QE("@D<F]W
M(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*2D@>PH):68@
M*$1".CII<T5R<F]R*"1R;W<I("8F("1E<G)O<BD@>PH)"61I92@G8G5G)RD[
M"@E]"@DD<F5S,B`]("1D8F@M/G%U97)Y*")&04M%(%%515)9(BD["@EI9B`H
M(41".CII<T5R<F]R*"1R97,R*2D@>PH)"61I92@G8G5G)RD["@E]"@DD97)R
M;W(@/2!T<G5E.PI]"@H*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C
M87-E("=I8F%S92<Z"B`@("`@("`@)&1B:"T^9G)E95)E<W5L="@D<F5S+3YR
M97-U;'0I.R`@+R\@36%K92!I;G1E<F)A<V4@:&%P<'DN"B`@("`@("`@8G)E
M86L["GT*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<%]L:6UI="<I.PH*/SX*
M+2U%6%!%0U0M+0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]D<FEV97(O,35Q=6]T92YP:'!T````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S$W
M,@`Q,#0Q-S,V,S`P,P`P,C,V,C4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+2U415-4+2T*1$)?9')I=F5R.CIQ=6]T90HM
M+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q
M=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR
M97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI;F,G.PH*"B\J*@H@*B!,;V-A;"!E
M<G)O<B!C86QL8F%C:R!H86YD;&5R+@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S
M="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL
M<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%
M05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@
M;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R
M2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D
M9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PH@("`@)&1B:"T^<75E<GDH)T123U`@5$%"3$4@<&5A<G%U;W1E
M)RD["@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*+R\@1$)-4R!B;V]L
M96%N(&-O;'5M;B!T>7!E('-I;75L871I;VXN+BX*)&)O;VQE86Y?8V]L7W1Y
M<&4@/2!A<G)A>2@*("`@("=D8F%S92<@(#T^("=,;V=I8V%L)RP*("`@("=F
M8F%S92<@(#T^("="3T],14%.)RP*("`@("=I8F%S92<@(#T^("=334%,3$E.
M5"<L"B`@("`G:69X)R`@("`]/B`G4TU!3$Q)3E0G+`H@("`@)VUS<6PG("`@
M/3X@)TE.5$5'15(G+`H@("`@)VUS<W%L)R`@/3X@)T))5"<L"B`@("`G;7ES
M<6PG("`]/B`G5$E.64E.5"@Q*2<L"B`@("`G;7ES<6QI)R`]/B`G5$E.64E.
M5"@Q*2<L"B`@("`G;V-I."<@("`]/B`G3E5-0D52*#$I)RP*("`@("=O9&)C
M)R`@(#T^("=334%,3$E.5"<L"B`@("`G<&=S<6PG("`]/B`G0D]/3$5!3B<L
M"B`@("`G<W%L:71E)R`]/B`G24Y414=%4B<L"B`@("`G<WEB87-E)R`]/B`G
M5$E.64E.5"<L"BD["@HO+R!A9&IU<W0@=&AI;F=S(&9O<B!S<&5C:69I8R!$
M0DU3)W,*"FEF("@D9&)H+3YP:'!T>7!E(#T]("=O9&)C)RD@>PH@("`@:68@
M*"1D8F@M/F1B<WEN=&%X(#T]("=O9&)C)RD@>PH@("`@("`@("1T>7!E(#T@
M)&1B:"T^<&AP='EP93L*("`@('T@96QS92!["B`@("`@("`@)'1Y<&4@/2`D
M9&)H+3YD8G-Y;G1A>#L*("`@('T*?2!E;'-E('L*("`@("1T>7!E(#T@)&1B
M:"T^<&AP='EP93L*?0H*<W=I=&-H("@D='EP92D@>PH@("`@8V%S92`G86-C
M97-S)SH*("`@("`@("`D9&5C:6UA;"`]("=324Y'3$4G.PH@("`@("`@("1N
M=6QL(#T@)R<["B`@("`@("`@)&-H<B`@/2`G5D%20TA!4B@X*2<["B`@("`@
M("`@)&ED96YT:69I97(@/2`G<5QU="`B9&YT)SL*("`@("`@("!B<F5A:SL*
M("`@(&-A<V4@)V1B,B<Z"B`@("!C87-E("=I8F%S92<Z"B`@("`@("`@)&1E
M8VEM86P@/2`G1$5#24U!3"@S+#$I)SL*("`@("`@("`D;G5L;"`]("<G.PH@
M("`@("`@("1C:'(@(#T@)U9!4D-(05(H."DG.PH@("`@("`@("1I9&5N=&EF
M:65R(#T@)W%<=71=(")D;EMT)SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@
M)VEF>"<Z"B`@("`@("`@+R\@9&]I;F<@=&AI<R!F;W(@:69X('1O(&ME97`@
M8V5R=&%I;B!V97)S:6]N<R!H87!P>0H@("`@("`@("1D96-I;6%L(#T@)T1%
M0TE-04PH,RPQ*2<["B`@("`@("`@)&YU;&P@/2`G)SL*("`@("`@("`D8VAR
M("`]("=#2$%2*#@I)SL*("`@("`@("`D:61E;G1I9FEE<B`]("<G.PH@("`@
M("`@(&)R96%K.PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@)&1E8VEM86P@
M/2`G1$5#24U!3"@S+#$I)SL*("`@("`@("`D;G5L;"`]("<G.PH@("`@("`@
M("1C:'(@(#T@)T-(05(H."DG.PH@("`@("`@("1I9&5N=&EF:65R(#T@)W%<
M=71=(")D;EMT)SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)V]C:3@G.@H@
M("`@("`@("1D96-I;6%L(#T@)T1%0TE-04PH,RPQ*2<["B`@("`@("`@)&YU
M;&P@/2`G)SL*("`@("`@("`D8VAR("`]("=605)#2$%2*#@I)SL*("`@("`@
M("`D:61E;G1I9FEE<B`]("=Q7'5T72!D;EMT)SL*("`@("`@("!B<F5A:SL*
M("`@(&1E9F%U;'0Z"B`@("`@("`@)&1E8VEM86P@/2`G1$5#24U!3"@S+#$I
M)SL*("`@("`@("`D;G5L;"`]("=.54Q,)SL*("`@("`@("`D8VAR("`]("=6
M05)#2$%2*#@I)SL*("`@("`@("`D:61E;G1I9FEE<B`]("=Q7'5T72`B9&Y;
M="<["GT*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PHD9&)H+3YQ=65R>2@G1%)/4"!404),12!P96%R<75O=&4G*3L*"@II
M9B`H)&ED96YT:69I97(I('L*("`@("1C<F5A=&4@/2`D9&)H+3YQ=65R>2@B
M"B`@("`@("`@0U)%051%(%1!0DQ%('!E87)Q=6]T92`H"B`@("`@("`@("!N
M("1D96-I;6%L("1N=6QL+`H@("`@("`@("`@<R`D8VAR("1N=6QL+`H@("`@
M("`@("`@(B`N("1D8F@M/G%U;W1E261E;G1I9FEE<B@D:61E;G1I9FEE<BD@
M+B`B("1D96-I;6%L("1N=6QL+`H@("`@("`@("`@8B![)&)O;VQE86Y?8V]L
M7W1Y<&5;)&1B:"T^<&AP='EP95U]("1N=6QL"B`@("`@("`@*0H@("`@(BD[
M"@H@("`@:68@*$1".CII<T5R<F]R*"1C<F5A=&4I("D@>PH@("`@("`@('!E
M*"1C<F5A=&4I.PH@("`@?0H*("`@("1I;F9O(#T@)&1B:"T^=&%B;&5);F9O
M*"=P96%R<75O=&4G*3L*("`@(&EF("A$0CHZ:7-%<G)O<B@D:6YF;RD@*2![
M"B`@("`@("`@:68@*"1I;F9O+3YC;V1E(#T]($1"7T524D]27TY/5%]#05!!
M0DQ%*2!["B`@("`@("`@("`@('!R:6YT(")#<F5A=&EO;B!O9B!T:&4@9&5L
M:6UI=&5D(&ED96YT:69I97(@=V]R:V5D+EQN(CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!P<FEN="`B=&%B;&5);F9O*"D@9F%I;&5D+EQN(CL*
M("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&EF("@D:61E;G1I9FEE
M<B`]/2`D:6YF;ULR75LG;F%M92==*2!["B`@("`@("`@("`@('!R:6YT(")#
M<F5A=&EO;B!O9B!T:&4@9&5L:6UI=&5D(&ED96YT:69I97(@=V]R:V5D+EQN
M(CL*("`@("`@("`@("`@+R\@<')I;G0@(D-/3%5-3B!.04U%($E3.B![)&EN
M9F];,EU;)VYA;64G77U<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<')I;G0@(D5X<&5C=&5D(&-O;'5M;B!N86UE.B`G)&ED96YT:69I97(G
M("XN+B`B.PH@("`@("`@("`@("!P<FEN="`B06-T=6%L(&-O;'5M;B!N86UE
M.B`G>R1I;F9O6S)=6R=N86UE)UU])UQN(CL*("`@("`@("!]"B`@("!]"@I]
M(&5L<V4@>PH@("`@)&1B:"T^<75E<GDH(@H@("`@("`@($-214%412!404),
M12!P96%R<75O=&4@*`H@("`@("`@("`@;B!$14-)34%,*#,L,2D@)&YU;&PL
M"B`@("`@("`@("!S("1C:'(@)&YU;&PL"B`@("`@("`@("!P;&%I;FED96YT
M:69I97(@1$5#24U!3"@S+#$I("1N=6QL+`H@("`@("`@("`@8B![)&)O;VQE
M86Y?8V]L7W1Y<&5;)&1B:"T^<&AP='EP95U]("1N=6QL"B`@("`@("`@*0H@
M("`@(BD["B`@("!P<FEN="`B>R1D8F@M/F1S;ELG<&AP='EP92==?2!D;V5S
M(&YO="!H86YD;&4@9&5L:6UI=&5D(&ED96YT:69I97)S+EQN(CL*?0H*"B1D
M8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E
M)RD["@H*)'-T<FEN9W,@/2!A<G)A>2@*("`@("(G(BP*("`@(")<(B(L"B`@
M("`B7%PB+`H@("`@(B4B+`H@("`@(E\B+`H@("`@(B<G(BP*("`@(")<(EPB
M(BP*("`@(")<7%Q<(BP*("`@(")<7"=<7"<B+`H@("`@(EQ<7")<7%PB(@HI
M.PH*)&YU;7,@/2!A<G)A>2@*("`@(#$R+C,L"B`@("`Q-2P**3L*"B1B;V]L
M<R`](&%R<F%Y*`H@("`@5%)512P*("`@($9!3%-%+`HI.PH*"F5C:&\@(E-T
M<FEN9R!E<V-A<&4@=&5S=#H@(CL*9F]R96%C:"`H)'-T<FEN9W,@87,@)',I
M('L*("`@("1Q=6]T960@/2`D9&)H+3YQ=6]T95-M87)T*"1S*3L*("`@("1D
M8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P96%R<75O=&4@*',I(%9!3%5%4R`H
M)'%U;W1E9"DB*3L*?0HD9&EF9B`](&%R<F%Y7V1I9F8H)'-T<FEN9W,L("1R
M97,@/2`D9&)H+3YG971#;VPH(E-%3$5#5"!S($923TT@<&5A<G%U;W1E(BDI
M.PII9B`H8V]U;G0H)&1I9F8I(#X@,"D@>PH@("`@96-H;R`B1D%)3"(["B`@
M("!P<FEN=%]R*"1S=')I;F=S*3L*("`@('!R:6YT7W(H)')E<RD["GT@96QS
M92!["B`@("!E8VAO(")/2R(["GT*"B1D8F@M/G%U97)Y*")$14Q%5$4@1E)/
M32!P96%R<75O=&4B*3L*"@IE8VAO(")<;DYU;6)E<B!E<V-A<&4@=&5S=#H@
M(CL*9F]R96%C:"`H)&YU;7,@87,@)&XI('L*("`@("1Q=6]T960@/2`D9&)H
M+3YQ=6]T95-M87)T*"1N*3L*("`@("1D8F@M/G%U97)Y*"))3E-%4E0@24Y4
M3R!P96%R<75O=&4@*&XI(%9!3%5%4R`H)'%U;W1E9"DB*3L*?0H*)&1I9F8@
M/2!A<G)A>2@I.PHD<F5S(#TF("1D8F@M/F=E=$-O;"@G4T5,14-4(&X@1E)/
M32!P96%R<75O=&4@3U)$15(@0ED@;B<I.PIF;W)E86-H("@D;G5M<R!A<R`D
M:V5Y(#T^("1V86PI('L*("`@(&EF("@D=F%L("$]("1R97-;)&ME>5TI('L*
M("`@("`@("`D9&EF9EM=(#T@(B1V86P@(3T@>R1R97-;)&ME>5U](CL*("`@
M('T*?0H*:68@*&-O=6YT*"1D:69F*2`^(#`I('L*("`@(&5C:&\@(D9!24Q<
M;B(["B`@("!P<FEN=%]R*"1D:69F*3L*?2!E;'-E('L*("`@(&5C:&\@)T]+
M)SL*?0H*)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!E87)Q=6]T92<I.PH*
M"F5C:&\@(EQN0F]O;&5A;B!E<V-A<&4@=&5S=#H@(CL*)&D@/2`Q.PIF;W)E
M86-H("@D8F]O;',@87,@)&(I('L*("`@("1Q=6]T960@/2`D9&)H+3YQ=6]T
M95-M87)T*"1B*3L*("`@("1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P96%R
M<75O=&4@*&XL(&(I(%9!3%5%4R`H)&DL("1Q=6]T960I(BD["B`@("`D:2LK
M.PI]"@HD9&EF9B`](&%R<F%Y*"D["B1R97,@/28@)&1B:"T^9V5T0V]L*"=3
M14Q%0U0@8BP@;B!&4D]-('!E87)Q=6]T92!/4D1%4B!"62!N)RD["F9O<F5A
M8V@@*"1B;V]L<R!A<R`D:V5Y(#T^("1V86PI('L*("`@(&EF("@D=F%L(#T]
M/2!T<G5E*2!["B`@("`@("`@:68@*"1R97-;)&ME>5T@/3T@,2!\?"`D<F5S
M6R1K97E=(#T]('1R=64@?'P*("`@("`@("`@("`@<W5B<W1R*'-T<G1O;&]W
M97(H)')E<ULD:V5Y72DL(#`L(#$I(#T]("=T)RD*("`@("`@("!["B`@("`@
M("`@("`@("\O(&=O;V0*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9&EF9EM=(#T@(FEN.G1R=64@(3T@;W5T.GLD<F5S6R1K97E=?2(["B`@("`@
M("`@?0H@("`@?2!E;'-E('L*("`@("`@("!I9B`H)')E<ULD:V5Y72`]/2`P
M('Q\("1R97-;)&ME>5T@/3T@9F%L<V4@?'P*("`@("`@("`@("`@<W5B<W1R
M*'-T<G1O;&]W97(H)')E<ULD:V5Y72DL(#`L(#$I(#T]("=F)RD*("`@("`@
M("!["B`@("`@("`@("`@("\O(&=O;V0*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D9&EF9EM=(#T@(FEN.F9A;'-E("$](&]U=#I[)')E<ULD:V5Y
M77TB.PH@("`@("`@('T*("`@('T*?0H*:68@*&-O=6YT*"1D:69F*2`^(#`I
M('L*("`@(&5C:&\@(D9!24Q<;B(["B`@("!P<FEN=%]R*"1D:69F*3L*?2!E
M;'-E('L*("`@(&5C:&\@(D]+7&XB.PI]"@H*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD["B1D8F@M/G%U97)Y*"=$4D]0(%1!
M0DQ%('!E87)Q=6]T92<I.PH*/SX*+2U%6%!%0U0M+0I#<F5A=&EO;B!O9B!T
M:&4@9&5L:6UI=&5D(&ED96YT:69I97(@=V]R:V5D+@I3=')I;F<@97-C87!E
M('1E<W0Z($]+"DYU;6)E<B!E<V-A<&4@=&5S=#H@3TL*0F]O;&5A;B!E<V-A
M<&4@=&5S=#H@3TL*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R
M:79E<B]M:W1A8FQE+FEN8P``````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-C`U`#$P
M-#$W,S8S,#`S`#`R,S4T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*+RHJ"B`J($-R96%T97,@=&AE(#QK8F0^
M<&AP=&5S=#PO:V)D/B!T86)L92X*("H*("H@5')I97,@=&\@9')O<"!T:&4@
M=&%B;&4@9FER<W0L(&EN(&-A<V4@:70@86QR96%D>2!E>&ES=',N"B`J"B`J
M(#QP<F4^"B`J($-214%412!404),12!P:'!T97-T("@*("H@("!A($E.5$5'
M15(@3E5,3"P*("H@("!B($-(05(H-#`I($1%1D%53%0@)V1E9B<@3D]4($Y5
M3$PL"B`J("`@8R!605)#2$%2*#(U-2D@3E5,3"P*("H@("!D(%9!4D-(05(H
M,C`I($Y53$PI"B`J(#PO<')E/@H@*@H@*B!.965D(#QK8F0^3D]4($Y53$P\
M+VMB9#X@;VX@/&MB9#YB/"]K8F0^('1O('1E<W0*("H@/&MB9#Y$0E]03U)4
M04))3$E465]25%))33PO:V)D/BX@($U3(%-13"!A;F0@4WEB87-E('1R:6T@
M;W5T<'5T(&9R;VT*("H@/&MB9#Y605)#2$%2/"]K8F0^+"!B=70@;F]T(&]N
M(#QK8F0^0TA!4CPO:V)D/BX*("H*("H@3F5E9"`\:V)D/D1%1D%53%0\+VMB
M9#X@=F%L=64@;VX@/&MB9#YB/"]K8F0^(&)E8V%U<V4@3W)A8VQE(&-O;G-I
M9&5R<PH@*B!A;B!E;7!T>2!S=')I;F<@=&\@8F4@/&MB9#Y.54Q,/"]K8F0^
M+@H@*@H@*B!);B!/<F%C;&4L('=H96X@=7-I;F<@<&QA8V5H;VQD97)S(&EN
M(#QK8F0^5TA%4D4\+VMB9#X@8VQA=7-E<R!O;B`*("H@/&MB9#Y#2$%2/"]K
M8F0^(&-O;'5M;G,L('1H92!C;VQU;6X@;75S="!H879E(#QK8F0^4E1224TH
M*3PO:V)D/B!R=6X@;VX*("H@=&AE(&-O;'5M;CH*("H@/'-A;7`^"B`J("`@
M(%-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!25%))32AB*2`](#\*("H@
M/"]S86UP/@H@*@H@*B!`<&%C:V%G92`@1$(*("H@0'9E<G-I;VX@)$ED.B!M
M:W1A8FQE+FEN8RQV(#$N,3,@,C`P-"\P,B\P."`P,#HP.#HT,2!D86YI96QC
M($5X<"`D"B`J($!C871E9V]R>2!$871A8F%S90H@*B!`:6YT97)N86P*("HO
M"@HO*BH*("H@17-T86)L:7-H97,@=&AE($1"(&]B:F5C="!A;F0@8V]N;F5C
M=',@=&\@=&AE(&1A=&%B87-E+@H@*B\*<F5Q=6ER95]O;F-E("<N+V-O;FYE
M8W0N:6YC)SL*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PHD9&)H+3YQ=65R>2@B1%)/4"!404),12!P:'!T97-T(BD["@HO
M+R1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]44DE'1T52*3L*
M)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G
M9&5B=6=?9&EE)RD["@II9B`H)&1B:"T^<&AP='EP92`]/2`G;V1B8R<I('L*
M("`@(&EF("@D9&)H+3YD8G-Y;G1A>"`]/2`G;V1B8R<I('L*("`@("`@("`D
M='EP92`]("1D8F@M/G!H<'1Y<&4["B`@("!](&5L<V4@>PH@("`@("`@("1T
M>7!E(#T@)&1B:"T^9&)S>6YT87@["B`@("!]"GT@96QS92!["B`@("`D='EP
M92`]("1D8F@M/G!H<'1Y<&4["GT*"G-W:71C:"`H)'1Y<&4I('L*("`@(&-A
M<V4@)V%C8V5S<R<Z"B`@("`@("`@)&YU;&P@/2`G3E5,3"<["B`@("`@("`@
M)&-H<F,@/2`G5D%20TA!4B@R-34I)SL*("`@("`@("`D8VAR9"`]("=605)#
M2$%2*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`G)SL*("`@("`@("!B<F5A
M:SL*("`@(&-A<V4@)V1B,B<Z"B`@("!C87-E("=I8F%S92<Z"B`@("`@("`@
M)&YU;&P@/2`G)SL*("`@("`@("`D8VAR8R`]("=605)#2$%2*#(U-2DG.PH@
M("`@("`@("1C:')D(#T@)U9!4D-(05(H,C`I)SL*("`@("`@("`D9&5F875L
M="`](")$149!54Q4("=D968G($Y/5"!.54Q,(CL*("`@("`@("!B<F5A:SL*
M("`@(&-A<V4@)VUS<6PG.@H@("`@8V%S92`G:69X)SH*("`@("`@("`O+R!D
M;VEN9R!T:&ES(&9O<B!I9G@@=&\@:V5E<"!C97)T86EN('9E<G-I;VYS(&AA
M<'!Y"B`@("`@("`@)&YU;&P@/2`G)SL*("`@("`@("`D8VAR8R`]("=#2$%2
M*#(U-2DG.PH@("`@("`@("1C:')D(#T@)T-(05(H,C`I)SL*("`@("`@("`D
M9&5F875L="`](")$149!54Q4("=D968G($Y/5"!.54Q,(CL*("`@("`@("!B
M<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@)&YU;&P@/2`G3E5,3"<["B`@
M("`@("`@)&-H<F,@/2`G5D%20TA!4B@R-34I)SL*("`@("`@("`D8VAR9"`]
M("=605)#2$%2*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`B1$5&055,5"`G
M9&5F)R!.3U0@3E5,3"(["GT*"B1T97-T7VUK=&%B;&5?<75E<GD@/2`B"B`@
M("!#4D5!5$4@5$%"3$4@<&AP=&5S="`H"B`@("`@(&$@24Y414=%4B`D;G5L
M;"P*("`@("`@8B!#2$%2*#0P*2`D9&5F875L="P*("`@("`@8R`D8VAR8R`D
M;G5L;"P*("`@("`@9"`D8VAR9"`D;G5L;"D*(CL*"@HD9&)H+3YQ=65R>2@D
M=&5S=%]M:W1A8FQE7W%U97)Y*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/
M('!H<'1E<W0@5D%,5453*#0R+"`G8FEN9R<L("=4:&ES(&ES(&$@=&5S="<L
M("<Q.3DY+3$Q+3(Q)RDB*3L*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PH*/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1"+W1E<W1S+V1R:79E<B\P,6-O;FYE8W0N<&AP=```````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q-#,T`#$P-#$W,S8S,#`S`#`R-#$Q,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+51%4U0M+0I$0E]D<FEV97(Z
M.F-O;FYE8W0*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,
M15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%
M+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+V-O;FYE8W0N:6YC)SL*:68@*&ES
M7V]B:F5C="@D9&)H*2D@>PH@("`@<')I;G0@(EPD9&)H(&ES(&%N(&]B:F5C
M=%QN(CL*?0II9B`H:7-?<F5S;W5R8V4H)&1B:"T^8V]N;F5C=&EO;BDI('L*
M("`@('!R:6YT(")<)&1B:"!I<R!C;VYN96-T961<;B(["GT*"@HD=&5S=%]A
M<G)A>5]D<VX@/2!$0CHZ<&%R<V5$4TXH1%))5D527T133BD["@IF;W)E86-H
M("@D=&5S=%]A<G)A>5]D<VX@87,@)&ME>2`]/B`D=F%L=64I('L*("`@(&EF
M("@D=F%L=64@/3T](&9A;'-E*2!["B`@("`@("`@=6YS970H)'1E<W1?87)R
M87E?9'-N6R1K97E=*3L*("`@('T*?0H*)&1B:&$@/28@1$(Z.F-O;FYE8W0H
M)'1E<W1?87)R87E?9'-N+"`D;W!T:6]N<RD["FEF("A$0CHZ:7-%<G)O<B@D
M9&)H82DI('L*("`@(&1I92@B8V]N;F5C="YI;F,Z("(N)&1B:&$M/G1O4W1R
M:6YG*"DI.PI]"@II9B`H:7-?;V)J96-T*"1D8FAA*2D@>PH@("`@<')I;G0@
M(EPD9&)H82!I<R!A;B!O8FIE8W1<;B(["GT*"FEF("AI<U]R97-O=7)C92@D
M9&)H82T^8V]N;F5C=&EO;BDI('L*("`@('!R:6YT(")<)&1B:&$@:7,@8V]N
M;F5C=&5D7&XB.PI]"@H_/@HM+4584$5#5"TM"B1D8F@@:7,@86X@;V)J96-T
M"B1D8F@@:7,@8V]N;F5C=&5D"B1D8FAA(&ES(&%N(&]B:F5C=`HD9&)H82!I
M<R!C;VYN96-T960*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]S:VEP:68N:6YC````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S4U`#$P-#$W,S8S,#`S`#`R,S0P-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E("<N+W-E='5P+FEN8R<["G)E<75I<F5?;VYC92`G1$(N<&AP)SL*
M"FEF("@A9&5F:6YE9"@G1%))5D527T133B<I('Q\($12259%4E]$4TX@/3T@
M)R<I('L*("`@(&1I92@G<VMI<"!$4TX@;F]T(&1E9FEN960G*3L*?0H*)&1B
M(#TF($1".CIC;VYN96-T*$12259%4E]$4TXI.PII9B`H1$(Z.FES17)R;W(H
M)&1B*2D@>PH@("`@9&EE*")S:VEP("1D8BT^;65S<V%G92(I.PI]"@H_/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D<FEV97(O,3!E<G)O<FUA<"YP:'!T````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C4U-@`Q,#0Q-S,V,S`P,P`P,C0S,38`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2U415-4+2T*1$)?9')I=F5R.CIE<G)O
M<B!M87!P:6YG"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)
M3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,
M12TM"CP_<&AP"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["G)E<75I
M<F5?;VYC92`G+BXO97)R;W)S+FEN8R<["C\^"BTM15A014-4+2T*5')Y:6YG
M('1O('!R;W9O:V4@1$)?15)23U)?3D]354-(5$%"3$4*("!$0B!%<G)O<CH@
M;F\@<W5C:"!T86)L90I4<GEI;F<@=&\@<')O=F]K92!$0E]%4E)/4E]!3%)%
M04197T5825-44R!F;W(@8W)E871E('1A8FQE"B`@1$(@17)R;W(Z(&%L<F5A
M9'D@97AI<W1S"E1R>6EN9R!T;R!P<F]V;VME($1"7T524D]27TY/4U5#2%1!
M0DQ%"B`@1$(@17)R;W(Z(&YO('-U8V@@=&%B;&4*5')Y:6YG('1O('!R;W9O
M:V4@1$)?15)23U)?0T].4U1204E.5"!F;W(@<')I;6%R>2!K97D@:6YS97)T
M(&1U<&QI8V%T90H@($1"($5R<F]R.B!C;VYS=')A:6YT('9I;VQA=&EO;@I4
M<GEI;F<@=&\@<')O=F]K92!$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!P<FEM
M87)Y(&ME>2!U<&1A=&4@9'5P;&EC871E"B`@1$(@17)R;W(Z(&-O;G-T<F%I
M;G0@=FEO;&%T:6]N"E1R>6EN9R!T;R!P<F]V;VME($1"7T524D]27T-/3E-4
M4D%)3E0@9F]R('5N:7%U92!K97D@:6YS97)T(&1U<&QI8V%T90H@($1"($5R
M<F]R.B!C;VYS=')A:6YT('9I;VQA=&EO;@I4<GEI;F<@=&\@<')O=F]K92!$
M0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!U;FEQ=64@:V5Y('5P9&%T92!D=7!L
M:6-A=&4*("!$0B!%<G)O<CH@8V]N<W1R86EN="!V:6]L871I;VX*5')Y:6YG
M('1O('!R;W9O:V4@1$)?15)23U)?0T].4U1204E.5"!F;W(@9F]R96EG;B!K
M97D*("!$0B!%<G)O<CH@8V]N<W1R86EN="!V:6]L871I;VX*5')Y:6YG('1O
M('!R;W9O:V4@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"!O;B!I;G-E
M<G0*("!$0B!%<G)O<CH@;G5L;"!V86QU92!V:6]L871E<R!N;W0M;G5L;"!C
M;VYS=')A:6YT"E1R>6EN9R!T;R!P<F]V;VME($1"7T524D]27T-/3E-44D%)
M3E1?3D]47TY53$P@;VX@=7!D871E"B`@1$(@17)R;W(Z(&YU;&P@=F%L=64@
M=FEO;&%T97,@;F]T+6YU;&P@8V]N<W1R86EN=`I4<GEI;F<@=&\@<')O=F]K
M92!$0E]%4E)/4E]$259:15)/"B`@1$(@17)R;W(Z(&1I=FES:6]N(&)Y('IE
M<F\*5')Y:6YG('1O('!R;W9O:V4@1$)?15)23U)?24Y604Q)1%].54U"15(*
M("!$0B!%<G)O<CH@:6YV86QI9"!N=6UB97(*5')Y:6YG('1O('!R;W9O:V4@
M1$)?15)23U)?3D]354-(1DE%3$0*("!$0B!%<G)O<CH@;F\@<W5C:"!F:65L
M9`I4<GEI;F<@=&\@<')O=F]K92!$0E]%4E)/4E]364Y405@*("!$0B!%<G)O
M<CH@<WEN=&%X(&5R<F]R"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P-&YU;6-O;',N
M<&AP=````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S$Q`#$P-#$W,S8S,#`S`#`R-#$S
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I$0E]D<FEV97(Z.FYU;4-O;',*+2U32TE0248M+0H\/W!H<"!C
M:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP
M:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+VUK
M=&%B;&4N:6YC)SL*<F5Q=6ER95]O;F-E("<N+B]N=6UC;VQS+FEN8R<["C\^
M"BTM15A014-4+2T*,0HR"C,*-`H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]$0B]T97-T<R]D<FEV97(O8V]N;F5C="YI;F,`````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#8S-@`Q,#0Q-S,V,S`P,P`P,C,U-3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"F5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)RXO<V5T=7`N:6YC
M)SL*"FEF("AS=6)S='(H1%))5D527T133BP@,"P@-2D@/3T@)VUS<W%L)RD@
M>PH@("`@:6YI7W-E="@G;7-S<6PN=&5X=&QI;6ET)RP@-#`Y-BD["B`@("!I
M;FE?<V5T*"=M<W-Q;"YT97AT<VEZ92<L(#0P.38I.PI]"@HO+R!3971T:6YG
M(&]F("1O<'1I;VYS(&%N9"!R97%U:7)I;F<@1$(@87)E(&1O;F4@:6X@<V5T
M=7`N:6YC"@HD9&)H(#TF($1".CIC;VYN96-T*$12259%4E]$4TXL("1O<'1I
M;VYS*3L*:68@*$1".CII<T5R<F]R*"1D8F@I*2!["B`@("!D:64H(F-O;FYE
M8W0N:6YC.B`B+B1D8F@M/G1O4W1R:6YG*"DI.PI]"@IF=6YC=&EO;B!D96)U
M9U]D:64H)&\I>PH@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9')I=F5R+S`S<VEM<&QE<75E<GDN<&AP=```````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`S,C(`,3`T,3<S-C,P,#,`,#(U,#,U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ<VEM
M<&QE475E<GD*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,
M15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%
M+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*<F5Q=6ER
M95]O;F-E("<N+B]S:6UP;&5Q=65R>2YI;F,G.PH_/@HM+4584$5#5"TM"G)E
M<V]U<F-E"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E
M<B\Q-&9E=&-H;6]D95]O8FIE8W0N<&AP=```````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S8W`#$P-#$W
M,S8S,#`S`#`R-3<V,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+51%4U0M+0I$0E]D<FEV97(Z.F9E=&-H;6]D92!O8FIE
M8W0*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[
M(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P
M:'`*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*<F5Q=6ER95]O;F-E
M("<N+B]F971C:&UO9&5?;V)J96-T+FEN8R<["C\^"BTM15A014-4+2T*+2TM
M(&9E=&-H('=I=&@@<&%R86T@1$)?1D540TA-3T1%7T]"2D5#5"`M+2T*<W1D
M8VQA<W,@+3X@82!B(&,@9`IS=&1C;&%S<R`M/B!A(&(@8R!D"BTM+2!F971C
M:"!W:71H(&1E9F%U;'0@9F5T8VAM;V1E($1"7T9%5$-(34]$15]/0DI%0U0@
M+2TM"G-T9&-L87-S("T^(&$@8B!C(&0*<W1D8VQA<W,@+3X@82!B(&,@9`HM
M+2T@9F5T8V@@=VET:"!D969A=6QT(&9E=&-H;6]D92!$0E]&151#2$U/1$5?
M3T)*14-4(&%N9"!C;&%S<R!$0E]2;W<@+2TM"F1B7W)O=R`M/B!A(&(@8R!D
M"F1B7W)O=R`M/B!A(&(@8R!D"@```````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#)F971C:"YP
M:'!T```````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$R,0`Q,#0Q-S,V,S`P,P`P,C,U
M-#4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2U415-4+2T*1$)?9')I=F5R.CIF971C:`HM+5-+25!)1BTM"CP_<&AP(&-H
M9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I
M9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT
M86)L92YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+V9E=&-H;6]D97,N:6YC)SL*
M/SX*+2U%6%!%0U0M+0IT97-T:6YG(&9E=&-H<F]W.@IR;W<@,3H@-#(L(&)I
M;F<L(%1H:7,@:7,@82!T97-T+"`Q.3DY+3$Q+3(Q"G)O=R`R.B`Q+"!O;F4L
M($]N92P@,C`P,2TP,BTQ-@IR;W<@,SH@,BP@='=O+"!4=V\L(#(P,#$M,#(M
M,34*<F]W(#0Z(#,L('1H<F5E+"!4:')E92P@,C`P,2TP,BTQ-`IR;W<@-3H@
M3E5,3`IT97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&1E9F%U;'0@9&5F
M875L="P@<&]R=&%B:6QI='D@;6]D92!$0E]03U)404))3$E465]!3$P@7B!$
M0E]03U)404))3$E465]25%))30HP(#$@,B`S"F]U='!U="!M871C:&5D(&5X
M<&5C=&5D(&9O<FUA=`IT97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!D
M969A=6QT(&1E9F%U;'0*,"`Q(#(@,PHT,B!B:6YG(%1H:7,@:7,@82!T97-T
M(#$Y.3DM,3$M,C$*=&5S=&EN9R!F971C:&UO9&5S.B!F971C:')O=R!O<F1E
M<F5D(&1E9F%U;'0*,"`Q(#(@,PIT97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H
M<F]W(&%S<V]C(&1E9F%U;'0*82!B(&,@9`IT97-T:6YG(&9E=&-H;6]D97,Z
M(&9E=&-H<F]W(&]R9&5R960@9&5F875L="!W:71H(&%S<V]C('-P96-I9FEE
M9`IA(&(@8R!D"G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR;W<@87-S;V,@
M9&5F875L="!W:71H(&]R9&5R960@<W!E8VEF:65D"C`@,2`R(#,*=&5S=&EN
M9R!F971C:&UO9&5S.B!F971C:&EN=&\@;W)D97)E9"!D969A=6QT"C`@,2`R
M(#,*=&5S=&EN9R!F971C:&UO9&5S.B!F971C:&EN=&\@87-S;V,@9&5F875L
M=`IA(&(@8R!D"G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&]R9&5R
M960@9&5F875L="!W:71H(&%S<V]C('-P96-I9FEE9`IA(&(@8R!D"G1E<W1I
M;F<@9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&%S<V]C(&1E9F%U;'0@=VET:"!O
M<F1E<F5D('-P96-I9FEE9`HP(#$@,B`S"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V1R:79E<B\Q.&=E="YP:'!T````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#,T-30V`#$P-#$W,S8S,#`S`#`R,S(V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+51%4U0M+0I$0E]D<FEV97(Z.F=E
M=`HM+5-+25!)1BTM"CP_<&AP"@HO*BH*("H@0V%L;',@=&AE(&=E="HH*2!M
M971H;V1S(&EN('9A<FEO=7,@=V%Y<R!A9V%I;G-T(&%N>2!$0DU3+@H@*@H@
M*B!`<V5E($1"7T-O;6UO;CHZ9V5T06QL*"DL($1"7T-O;6UO;CHZ9V5T07-S
M;V,H*2P@1$)?0V]M;6]N.CIG971#;VPH*0H@*B`@("`@($1"7T-O;6UO;CHZ
M9V5T3&ES=$]F*"DL($1"7T-O;6UO;CHZ9V5T3VYE*"DL($1"7T-O;6UO;CHZ
M9V5T4F]W*"D*("H*("H@0'!A8VMA9V4@($1""B`J($!V97)S:6]N("`D260Z
M(#$X9V5T+G!H<'0L=B`Q+C,@,C`P-"\P,B\Q."`P-3HS.#HQ,2!D86YI96QC
M($5X<"`D"B`J($!C871E9V]R>2!$871A8F%S90H@*B!`875T:&]R("`@1&%N
M:65L($-O;G9I<W-O<B`\9&%N:65L8T!A;F%L>7-I<V%N9'-O;'5T:6]N<RYC
M;VT^"B`J($!I;G1E<FYA;`H@*B\*"F-H9&ER*&1I<FYA;64H7U]&24Q%7U\I
M*3L*<F5Q=6ER95]O;F-E("<N+V1R:79E<B]S:VEP:68N:6YC)SL*"C\^"BTM
M1DE,12TM"CP_<&AP"@HO+R`D260Z(#$X9V5T+G!H<'0L=B`Q+C,@,C`P-"\P
M,B\Q."`P-3HS.#HQ,2!D86YI96QC($5X<"`D"@HO*BH*("H@0V]N;F5C="!T
M;R!T:&4@9&%T86)A<V4@86YD(&UA:V4@=&AE(#QK8F0^<&AP=&5S=#PO:V)D
M/B!T86)L92X*("HO"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["@H*
M+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(N"B`J"B`J($1R
M;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE
M<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@
M;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P
M87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@
M4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RE[
M"B`@("!G;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4D5455).*3L*("`@("1D8F@M/G%U97)Y*"=$4D]0(%1!
M0DQ%('!H<'1E<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD
M9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P
M92<I.PH*"B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%
M4R`H,BP@)W1W;R<L("=4=V\G+"`G,C`P,BTP,BTR,B<I(BD["B1D8F@M/G%U
M97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H-#(L("=T:')E92<L
M("=4:')E92<L("<R,#`S+3`S+3(S)RDB*3L*"@IP<FEN="`B/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB
M.PIP<FEN="`G=&5S=&EN9R!G971/;F4Z("<["B1R970@/28@)&1B:"T^9V5T
M3VYE*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`]("=4=V\G(BD[
M"G!R:6YT7W(H)')E="D["G!R:6YT(")<;B(["@IP<FEN="`G=&5S=&EN9R!G
M971/;F4@=VET:"!S=')I;F<@<&%R86US.B`G.PHD<F5T(#TF("1D8F@M/F=E
M=$]N92@G4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`_)RP@)U1H
M<F5E)RD["G!R:6YT7W(H)')E="D["G!R:6YT(")<;B(["@IP<FEN="`G=&5S
M=&EN9R!G971/;F4@=VET:"!A<G)A>2!P87)A;7,Z("<["B1R970@/28@)&1B
M:"T^9V5T3VYE*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`](#\G
M+"!A<G)A>2@G5'=O)RDI.PIP<FEN=%]R*"1R970I.PIP<FEN="`B7&XB.PH*
M<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`B=&5S=&EN9R!G9712;W<Z7&XB
M.PHD<F5T(#TF("1D8F@M/F=E=%)O=R@B4T5,14-4("H@1E)/32!P:'!T97-T
M(%=(15)%(&,@/2`G5'=O)R(I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E
M<W1I;F<@9V5T4F]W('=I=&@@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/
M4D1%4D5$.EQN(CL*)')E="`])B`D9&)H+3YG9712;W<H(E-%3$5#5"`J($92
M3TT@<&AP=&5S="!72$5212!C(#T@)U1W;R<B+`H@("`@("`@(&YU;&PL($1"
M7T9%5$-(34]$15]/4D1%4D5$*3L*<')I;G1?<B@D<F5T*3L*"B\O(%1(25,@
M1$]%4TXG5"!73U)+($1512!43R!"04-+5T%21%,@0T]-4$%424))3$E462!#
M4D%0"B\O('!R:6YT(")T97-T:6YG(&=E=%)O=R!W:71H('-T<FEN9R!P87)A
M;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*+R\@)')E="`])B`D9&)H
M+3YG9712;W<H)U-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R<L
M"B\O("`@("`@("`@)U1W;R<L($1"7T9%5$-(34]$15]/4D1%4D5$*3L*+R\@
M<')I;G1?<B@D<F5T*3L*+R\*+R\@=&5S=&EN9R!G9712;W<@=VET:"!S=')I
M;F<@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*+R\@07)R87D*+R\@
M*`HO+R`@("`@6S!=(#T^(#(*+R\@("`@(%LQ72`]/B!T=V\*+R\@("`@(%LR
M72`]/B!4=V\*+R\@("`@(%LS72`]/B`R,#`R+3`R+3(R"B\O("D*"B`@('!R
M:6YT(")T97-T:6YG(&=E=%)O=R!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%
M5$-(34]$15]!4U-/0RP@87)R87D@<&%R86US.EQN(CL*("`@)')E="`])B`D
M9&)H+3YG9712;W<H)U-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@
M/R<L"B`@("`@("`@("`@1$)?1D540TA-3T1%7T%34T]#+"!A<G)A>2@G5'=O
M)RDI.PH@("!P<FEN=%]R*"1R970I.PH@("`*("`@<')I;G0@(G1E<W1I;F<@
M9V5T4F]W('=I=&@@4D5615)3140@87)G<SH@1$)?1D540TA-3T1%7T%34T]#
M.EQN(CL*("`@)')E="`])B`D9&)H+3YG9712;W<H(E-%3$5#5"`J($923TT@
M<&AP=&5S="!72$5212!C(#T@)U1W;R<B+`H@("`@("`@("`@($1"7T9%5$-(
M34]$15]!4U-/0RD["B`@('!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN
M9R!G9712;W<@=VET:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/
M0SI<;B(["B1R970@/28@)&1B:"T^9V5T4F]W*"=314Q%0U0@*B!&4D]-('!H
M<'1E<W0@5TA%4D4@8R`](#\G+`H@("`@("`@(&%R<F%Y*"=4=V\G*2P@1$)?
M1D540TA-3T1%7T%34T]#*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T
M:6YG(&=E=%)O=R!W:71H(&%R<F%Y('!A<F%M<RP@1$)?1D540TA-3T1%7T]"
M2D5#5#I<;B(["B1R970@/28@)&1B:"T^9V5T4F]W*"=314Q%0U0@*B!&4D]-
M('!H<'1E<W0@5TA%4D4@8R`](#\G+`H@("`@("`@(&%R<F%Y*"=4=V\G*2P@
M1$)?1D540TA-3T1%7T]"2D5#5"D["G!R:6YT7W(H)')E="D["@H*<')I;G0@
M(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]7&XB.PIP<FEN="`B=&5S=&EN9R!G971#;VPZ7&XB.PHD<F5T
M(#TF("1D8F@M/F=E=$-O;"@B4T5,14-4("H@1E)/32!P:'!T97-T($]21$52
M($)9(&(B*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$-O
M;"!W:71H(#$@8V]L.EQN(CL*)')E="`])B`D9&)H+3YG971#;VPH(E-%3$5#
M5"`J($923TT@<&AP=&5S="!/4D1%4B!"62!B(BP@,2D["G!R:6YT7W(H)')E
M="D["@IP<FEN="`B=&5S=&EN9R!G971#;VP@=VET:"!B(&-O;#I<;B(["B1R
M970@/28@)&1B:"T^9V5T0V]L*")314Q%0U0@*B!&4D]-('!H<'1E<W0@3U)$
M15(@0ED@8B(L("=B)RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN
M9R!G971#;VP@=VET:"!B(&-O;"P@<V-A;&%R('!A<F%M<SI<;B(["B1R970@
M/28@)&1B:"T^9V5T0V]L*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@
M82`\(#\@3U)$15(@0ED@8B(L"B`@("`@("`@)V(G+"`Q,#`I.PIP<FEN=%]R
M*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T0V]L('=I=&@@8B!C;VPL(&%R
M<F%Y('!A<F%M<SI<;B(["B1R970@/28@)&1B:"T^9V5T0V]L*")314Q%0U0@
M*B!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B(L"B`@("`@
M("`@)V(G+"!A<G)A>2@Q,#`I*3L*<')I;G1?<B@D<F5T*3L*"@IP<FEN="`B
M7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3U<;B(["G!R:6YT(")T97-T:6YG(&=E=$%S<V]C.EQN(CL*)')E
M="`])B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(L(&,@1E)/32!P:'!T
M97-T(%=(15)%(&$@/"`Q,#`@3U)$15(@0ED@8B<I.PIP<FEN=%]R*"1R970I
M.PH*<')I;G0@(G1E<W1I;F<@9V5T07-S;V,@=VET:"!F86QS92!F;W)C92P@
M;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*)')E="`]
M)B`D9&)H+3YG971!<W-O8R@B4T5,14-4(&$L(&(L(&,@1E)/32!P:'!T97-T
M(%=(15)%(&$@/"`Q,#`@3U)$15(@0ED@8B(L"B`@("`@("`@("`@("`@("`@
M("`@("`@(&9A;'-E+"!N=6QL+"!$0E]&151#2$U/1$5?3U)$15)%1"D["G!R
M:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W:71H(&9A
M;'-E(&9O<F-E+"!S8V%L87(@<&%R86US+"!$0E]&151#2$U/1$5?05-33T,Z
M7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@8BP@8R!&
M4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@(&9A;'-E+"`Q,#`L($1"7T9%5$-(34]$15]!4U-/
M0RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W
M:71H('1W;R!C;VQS+"!F86QS92!F;W)C92P@<V-A;&%R('!A<F%M<RP@1$)?
M1D540TA-3T1%7T%34T]#.EQN(CL*)')E="`])B`D9&)H+3YG971!<W-O8R@G
M4T5,14-4(&$L(&(@1E)/32!P:'!T97-T(%=(15)%(&$@/"`_($]21$52($)9
M(&(G+`H@("`@("`@("`@("`@("`@("`@("`@("!F86QS92P@,3`P+"!$0E]&
M151#2$U/1$5?05-33T,I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I
M;F<@9V5T07-S;V,@=VET:"!T=V\@8V]L<RP@=')U92!F;W)C92P@<V-A;&%R
M('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*)')E="`])B`D9&)H
M+3YG971!<W-O8R@G4T5,14-4(&$L(&(@1E)/32!P:'!T97-T(%=(15)%(&$@
M/"`_($]21$52($)9(&(G+`H@("`@("`@("`@("`@("`@("`@("`@("!T<G5E
M+"`Q,#`L($1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT7W(H)')E="D["@IP
M<FEN="`B=&5S=&EN9R!G971!<W-O8R!W:71H(&9A;'-E(&9O<F-E+"!S8V%L
M87(@<&%R86US+"!$0E]&151#2$U/1$5?05-33T,L('1R=64@9W)O=7`Z7&XB
M.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@8BP@8R!&4D]-
M('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@(&9A;'-E+"`Q,#`L($1"7T9%5$-(34]$15]!4U-/0RP@
M=')U92D["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O
M8R!W:71H(&9A;'-E(&9O<F-E+"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$
M15]/0DI%0U0Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@
M82P@8BP@8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"!A<G)A>2@Q,#`I+"!$
M0E]&151#2$U/1$5?3T)*14-4*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T
M97-T:6YG(&=E=$%S<V]C('=I=&@@=')U92!F;W)C92P@87)R87D@<&%R86US
M+"!$0E]&151#2$U/1$5?3T)*14-4+"!T<G5E(&=R;W5P.EQN(CL*)')E="`]
M)B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(L(&,@1E)/32!P:'!T97-T
M(%=(15)%(&$@/"`_($]21$52($)9(&(G+`H@("`@("`@("`@("`@("`@("`@
M("`@("!F86QS92P@87)R87DH,3`P*2P@1$)?1D540TA-3T1%7T]"2D5#5"P@
M=')U92D["G!R:6YT7W(H)')E="D["@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP
M<FEN="`B=&5S=&EN9R!G971!;&PZ7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%L
M;"@B4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`G5'=O)R!/4B!C
M(#T@)U1H<F5E)R(I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@
M9V5T06QL('=I=&@@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$
M.EQN(CL*)')E="`])B`D9&)H+3YG971!;&PH(E-%3$5#5"`J($923TT@<&AP
M=&5S="!72$5212!C(#T@)U1W;R<@3U(@8R`]("=4:')E92<B+`H@("`@("`@
M(&YU;&PL($1"7T9%5$-(34]$15]/4D1%4D5$*3L*<')I;G1?<B@D<F5T*3L*
M"B\O(%1(25,@1$]%4TXG5"!73U)+($1512!43R!"04-+5T%21%,@0T]-4$%4
M24))3$E462!#4D%0"B\O('!R:6YT(")T97-T:6YG(&=E=$%L;"!W:71H('-T
M<FEN9R!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*+R\@)')E
M="`])B`D9&)H+3YG971!;&PH)U-%3$5#5"`J($923TT@<&AP=&5S="!72$52
M12!C(#T@/R<L"B\O("`@("`@("`@)U1W;R<L($1"7T9%5$-(34]$15]/4D1%
M4D5$*3L*+R\@<')I;G1?<B@D<F5T*3L*+R\*+R\@=&5S=&EN9R!G971!;&P@
M=VET:"!S=')I;F<@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*+R\@
M07)R87D*+R\@*`HO+R`@("`@6S!=(#T^(#(*+R\@("`@(%LQ72`]/B!T=V\*
M+R\@("`@(%LR72`]/B!4=V\*+R\@("`@(%LS72`]/B`R,#`R+3`R+3(R"B\O
M("D*"B`@('!R:6YT(")T97-T:6YG(&=E=$%L;"!W:71H(%)%5D524T5$(&%R
M9W,Z($1"7T9%5$-(34]$15]!4U-/0RP@87)R87D@<&%R86US.EQN(CL*("`@
M)')E="`])B`D9&)H+3YG971!;&PH)U-%3$5#5"`J($923TT@<&AP=&5S="!7
M2$5212!C(#T@/R!/4B!C(#T@/R!/4D1%4B!"62!C)RP*("`@("`@("`@("!$
M0E]&151#2$U/1$5?05-33T,L(&%R<F%Y*"=4=V\G+"`G5&AR964G*2D["B`@
M('!R:6YT7W(H)')E="D["B`@(`H@("!P<FEN="`B=&5S=&EN9R!G971!;&P@
M=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,Z7&XB.PH@
M("`D<F5T(#TF("1D8F@M/F=E=$%L;"@B4T5,14-4("H@1E)/32!P:'!T97-T
M(%=(15)%(&,@/2`G5'=O)R!/4B!C(#T@)U1H<F5E)R(L"B`@("`@("`@("`@
M1$)?1D540TA-3T1%7T%34T]#*3L*("`@<')I;G1?<B@D<F5T*3L*"G!R:6YT
M(")T97-T:6YG(&=E=$%L;"!W:71H(&%R<F%Y('!A<F%M<RP@1$)?1D540TA-
M3T1%7T%34T]#.EQN(CL*)')E="`])B`D9&)H+3YG971!;&PH)U-%3$5#5"`J
M($923TT@<&AP=&5S="!72$5212!C(#T@/R!/4B!C(#T@/R!/4D1%4B!"62!C
M)RP*("`@("`@("!A<G)A>2@G5'=O)RP@)U1H<F5E)RDL($1"7T9%5$-(34]$
M15]!4U-/0RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!
M;&P@=VET:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]/0DI%0U0Z7&XB
M.PHD<F5T(#TF("1D8F@M/F=E=$%L;"@G4T5,14-4("H@1E)/32!P:'!T97-T
M(%=(15)%(&,@/2`_($]2(&,@/2`_($]21$52($)9(&,G+`H@("`@("`@(&%R
M<F%Y*"=4=V\G+"`G5&AR964G*2P@1$)?1D540TA-3T1%7T]"2D5#5"D["G!R
M:6YT7W(H)')E="D["@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`G=&5S
M=&EN9R!G971/;F4@=VET:"!N=6QL('9A;'5E(&EN(&-O;'5M;CH@)SL*)&1B
M:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453("@Y+"`G;FEN
M92<L("<G+"!.54Q,*2(I.PH*)')E="`])B`D9&)H+3YG971/;F4H)U-%3$5#
M5"!D($923TT@<&AP=&5S="!72$5212!A(#T@.2<I.PII9B`H)')E="`]/3T@
M)R<I('L*("`@('!R:6YT(")E;7!T>2!S=')I;F=<;B(["GT@96QS92!["B`@
M("!P<FEN="`G='EP93TG("X@9V5T='EP92@D<F5T*2`N("(L('9A;'5E/21R
M971<;B(["GT*"G!R:6YT("=T97-T:6YG(&=E=$]N92!W:71H(&5M<'1Y('-T
M<FEN9R!I;B!C;VQU;6XZ("<["B1R970@/28@)&1B:"T^9V5T3VYE*"=314Q%
M0U0@8R!&4D]-('!H<'1E<W0@5TA%4D4@82`](#DG*3L*:68@*"1R970@/3T]
M("<G*2!["B`@("!P<FEN="`B96UP='D@<W1R:6YG7&XB.PI](&5L<V4@>PH@
M("`@<')I;G0@)W1Y<&4])R`N(&=E='1Y<&4H)')E="D@+B`B+"!V86QU93TD
M<F5T7&XB.PI]"@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PH*"B1D8F@M/G-E=$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PHD9&)H+3YQ=65R>2@G
M1%)/4"!404),12!P:'!T97-T)RD["@H_/@HM+4584$5#5"TM"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0IT
M97-T:6YG(&=E=$]N93H@,@IT97-T:6YG(&=E=$]N92!W:71H('-T<FEN9R!P
M87)A;7,Z(#0R"G1E<W1I;F<@9V5T3VYE('=I=&@@87)R87D@<&%R86US.B`R
M"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*=&5S=&EN9R!G9712;W<Z"D%R<F%Y"B@*("`@(%LP72`]/B`R
M"B`@("!;,5T@/3X@='=O"B`@("!;,ET@/3X@5'=O"B`@("!;,UT@/3X@,C`P
M,BTP,BTR,@HI"G1E<W1I;F<@9V5T4F]W('=I=&@@;G5L;"!P87)A;7,L($1"
M7T9%5$-(34]$15]/4D1%4D5$.@I!<G)A>0HH"B`@("!;,%T@/3X@,@H@("`@
M6S%=(#T^('1W;PH@("`@6S)=(#T^(%1W;PH@("`@6S-=(#T^(#(P,#(M,#(M
M,C(**0IT97-T:6YG(&=E=%)O=R!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%
M5$-(34]$15]!4U-/0RP@87)R87D@<&%R86US.@I!<G)A>0HH"B`@("!;85T@
M/3X@,@H@("`@6V)=(#T^('1W;PH@("`@6V-=(#T^(%1W;PH@("`@6V1=(#T^
M(#(P,#(M,#(M,C(**0IT97-T:6YG(&=E=%)O=R!W:71H(%)%5D524T5$(&%R
M9W,Z($1"7T9%5$-(34]$15]!4U-/0SH*07)R87D**`H@("`@6V%=(#T^(#(*
M("`@(%MB72`]/B!T=V\*("`@(%MC72`]/B!4=V\*("`@(%MD72`]/B`R,#`R
M+3`R+3(R"BD*=&5S=&EN9R!G9712;W<@=VET:"!A<G)A>2!P87)A;7,L($1"
M7T9%5$-(34]$15]!4U-/0SH*07)R87D**`H@("`@6V%=(#T^(#(*("`@(%MB
M72`]/B!T=V\*("`@(%MC72`]/B!4=V\*("`@(%MD72`]/B`R,#`R+3`R+3(R
M"BD*=&5S=&EN9R!G9712;W<@=VET:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(
M34]$15]/0DI%0U0Z"G-T9$-L87-S($]B:F5C=`HH"B`@("!;85T@/3X@,@H@
M("`@6V)=(#T^('1W;PH@("`@6V-=(#T^(%1W;PH@("`@6V1=(#T^(#(P,#(M
M,#(M,C(**0H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"G1E<W1I;F<@9V5T0V]L.@I!<G)A>0HH"B`@("!;
M,%T@/3X@-#(*("`@(%LQ72`]/B`T,@H@("`@6S)=(#T^(#(**0IT97-T:6YG
M(&=E=$-O;"!W:71H(#$@8V]L.@I!<G)A>0HH"B`@("!;,%T@/3X@8FEN9PH@
M("`@6S%=(#T^('1H<F5E"B`@("!;,ET@/3X@='=O"BD*=&5S=&EN9R!G971#
M;VP@=VET:"!B(&-O;#H*07)R87D**`H@("`@6S!=(#T^(&)I;F<*("`@(%LQ
M72`]/B!T:')E90H@("`@6S)=(#T^('1W;PHI"G1E<W1I;F<@9V5T0V]L('=I
M=&@@8B!C;VPL('-C86QA<B!P87)A;7,Z"D%R<F%Y"B@*("`@(%LP72`]/B!B
M:6YG"B`@("!;,5T@/3X@=&AR964*("`@(%LR72`]/B!T=V\**0IT97-T:6YG
M(&=E=$-O;"!W:71H(&(@8V]L+"!A<G)A>2!P87)A;7,Z"D%R<F%Y"B@*("`@
M(%LP72`]/B!B:6YG"B`@("!;,5T@/3X@=&AR964*("`@(%LR72`]/B!T=V\*
M*0H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"G1E<W1I;F<@9V5T07-S;V,Z"D%R<F%Y"B@*("`@(%LT,ET@
M/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!T:')E90H@
M("`@("`@("`@("!;,5T@/3X@5&AR964*("`@("`@("`I"@H@("`@6S)=(#T^
M($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@='=O"B`@("`@
M("`@("`@(%LQ72`]/B!4=V\*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T07-S
M;V,@=VET:"!F86QS92!F;W)C92P@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$
M15]/4D1%4D5$.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@("`@
M*`H@("`@("`@("`@("!;,%T@/3X@=&AR964*("`@("`@("`@("`@6S%=(#T^
M(%1H<F5E"B`@("`@("`@*0H*("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*
M("`@("`@("`@("`@6S!=(#T^('1W;PH@("`@("`@("`@("!;,5T@/3X@5'=O
M"B`@("`@("`@*0H**0IT97-T:6YG(&=E=$%S<V]C('=I=&@@9F%L<V4@9F]R
M8V4L('-C86QA<B!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0SH*07)R87D*
M*`H@("`@6S0R72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6V)=
M(#T^('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("D*
M"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MB72`]
M/B!T=V\*("`@("`@("`@("`@6V-=(#T^(%1W;PH@("`@("`@("D*"BD*=&5S
M=&EN9R!G971!<W-O8R!W:71H('1W;R!C;VQS+"!F86QS92!F;W)C92P@<V-A
M;&%R('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#.@I!<G)A>0HH"B`@("!;
M-#)=(#T^('1H<F5E"B`@("!;,ET@/3X@='=O"BD*=&5S=&EN9R!G971!<W-O
M8R!W:71H('1W;R!C;VQS+"!T<G5E(&9O<F-E+"!S8V%L87(@<&%R86US+"!$
M0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%LT,ET@/3X@07)R87D*
M("`@("`@("`H"B`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@("`@("D*
M"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MB72`]
M/B!T=V\*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T07-S;V,@=VET:"!F86QS
M92!F;W)C92P@<V-A;&%R('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#+"!T
M<G5E(&=R;W5P.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@("`@
M*`H@("`@("`@("`@("!;,%T@/3X@07)R87D*("`@("`@("`@("`@("`@("@*
M("`@("`@("`@("`@("`@("`@("!;8ET@/3X@8FEN9PH@("`@("`@("`@("`@
M("`@("`@(%MC72`]/B!4:&ES(&ES(&$@=&5S=`H@("`@("`@("`@("`@("`@
M*0H*("`@("`@("`@("`@6S%=(#T^($%R<F%Y"B`@("`@("`@("`@("`@("`H
M"B`@("`@("`@("`@("`@("`@("`@6V)=(#T^('1H<F5E"B`@("`@("`@("`@
M("`@("`@("`@6V-=(#T^(%1H<F5E"B`@("`@("`@("`@("`@("`I"@H@("`@
M("`@("D*"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@
M(%LP72`]/B!!<G)A>0H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@
M("`@("`@(%MB72`]/B!T=V\*("`@("`@("`@("`@("`@("`@("!;8UT@/3X@
M5'=O"B`@("`@("`@("`@("`@("`I"@H@("`@("`@("D*"BD*=&5S=&EN9R!G
M971!<W-O8R!W:71H(&9A;'-E(&9O<F-E+"!A<G)A>2!P87)A;7,L($1"7T9%
M5$-(34]$15]/0DI%0U0Z"D%R<F%Y"B@*("`@(%LT,ET@/3X@<W1D0VQA<W,@
M3V)J96-T"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@
M("`@("`@6V)=(#T^('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@
M("`@("`@("D*"B`@("!;,ET@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@
M*`H@("`@("`@("`@("!;85T@/3X@,@H@("`@("`@("`@("!;8ET@/3X@='=O
M"B`@("`@("`@("`@(%MC72`]/B!4=V\*("`@("`@("`I"@HI"G1E<W1I;F<@
M9V5T07-S;V,@=VET:"!T<G5E(&9O<F-E+"!A<G)A>2!P87)A;7,L($1"7T9%
M5$-(34]$15]/0DI%0U0L('1R=64@9W)O=7`Z"D%R<F%Y"B@*("`@(%LT,ET@
M/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!S=&1#;&%S
M<R!/8FIE8W0*("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@("`@("`@
M("!;85T@/3X@-#(*("`@("`@("`@("`@("`@("`@("!;8ET@/3X@8FEN9PH@
M("`@("`@("`@("`@("`@("`@(%MC72`]/B!4:&ES(&ES(&$@=&5S=`H@("`@
M("`@("`@("`@("`@*0H*("`@("`@("`@("`@6S%=(#T^('-T9$-L87-S($]B
M:F5C=`H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@("`@("`@(%MA
M72`]/B`T,@H@("`@("`@("`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@
M("`@("`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("`@("`@("`@
M*0H*("`@("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@
M("`@("`@("!;,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@("`@("`@
M("`H"B`@("`@("`@("`@("`@("`@("`@6V%=(#T^(#(*("`@("`@("`@("`@
M("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@("`@("`@("`@("`@6V-=(#T^
M(%1W;PH@("`@("`@("`@("`@("`@*0H*("`@("`@("`I"@HI"@H]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*
M=&5S=&EN9R!G971!;&PZ"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A>0H@("`@
M("`@("@*("`@("`@("`@("`@6S!=(#T^(#(*("`@("`@("`@("`@6S%=(#T^
M('1W;PH@("`@("`@("`@("!;,ET@/3X@5'=O"B`@("`@("`@("`@(%LS72`]
M/B`R,#`R+3`R+3(R"B`@("`@("`@*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@
M("`@("@*("`@("`@("`@("`@6S!=(#T^(#0R"B`@("`@("`@("`@(%LQ72`]
M/B!T:')E90H@("`@("`@("`@("!;,ET@/3X@5&AR964*("`@("`@("`@("`@
M6S-=(#T^(#(P,#,M,#,M,C,*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T06QL
M('=I=&@@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.@I!<G)A
M>0HH"B`@("!;,%T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP
M72`]/B`R"B`@("`@("`@("`@(%LQ72`]/B!T=V\*("`@("`@("`@("`@6S)=
M(#T^(%1W;PH@("`@("`@("`@("!;,UT@/3X@,C`P,BTP,BTR,@H@("`@("`@
M("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP
M72`]/B`T,@H@("`@("`@("`@("!;,5T@/3X@=&AR964*("`@("`@("`@("`@
M6S)=(#T^(%1H<F5E"B`@("`@("`@("`@(%LS72`]/B`R,#`S+3`S+3(S"B`@
M("`@("`@*0H**0IT97-T:6YG(&=E=$%L;"!W:71H(%)%5D524T5$(&%R9W,Z
M($1"7T9%5$-(34]$15]!4U-/0RP@87)R87D@<&%R86US.@I!<G)A>0HH"B`@
M("!;,%T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MA72`]/B`T
M,@H@("`@("`@("`@("!;8ET@/3X@=&AR964*("`@("`@("`@("`@6V-=(#T^
M(%1H<F5E"B`@("`@("`@("`@(%MD72`]/B`R,#`S+3`S+3(S"B`@("`@("`@
M*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6V%=
M(#T^(#(*("`@("`@("`@("`@6V)=(#T^('1W;PH@("`@("`@("`@("!;8UT@
M/3X@5'=O"B`@("`@("`@("`@(%MD72`]/B`R,#`R+3`R+3(R"B`@("`@("`@
M*0H**0IT97-T:6YG(&=E=$%L;"!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%
M5$-(34]$15]!4U-/0SH*07)R87D**`H@("`@6S!=(#T^($%R<F%Y"B`@("`@
M("`@*`H@("`@("`@("`@("!;85T@/3X@,@H@("`@("`@("`@("!;8ET@/3X@
M='=O"B`@("`@("`@("`@(%MC72`]/B!4=V\*("`@("`@("`@("`@6V1=(#T^
M(#(P,#(M,#(M,C(*("`@("`@("`I"@H@("`@6S%=(#T^($%R<F%Y"B`@("`@
M("`@*`H@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@("`@("`@6V)=(#T^
M('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("`@("!;
M9%T@/3X@,C`P,RTP,RTR,PH@("`@("`@("D*"BD*=&5S=&EN9R!G971!;&P@
M=VET:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0SH*07)R87D*
M*`H@("`@6S!=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;85T@
M/3X@-#(*("`@("`@("`@("`@6V)=(#T^('1H<F5E"B`@("`@("`@("`@(%MC
M72`]/B!4:')E90H@("`@("`@("`@("!;9%T@/3X@,C`P,RTP,RTR,PH@("`@
M("`@("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@
M(%MA72`]/B`R"B`@("`@("`@("`@(%MB72`]/B!T=V\*("`@("`@("`@("`@
M6V-=(#T^(%1W;PH@("`@("`@("`@("!;9%T@/3X@,C`P,BTP,BTR,@H@("`@
M("`@("D*"BD*=&5S=&EN9R!G971!;&P@=VET:"!A<G)A>2!P87)A;7,L($1"
M7T9%5$-(34]$15]/0DI%0U0Z"D%R<F%Y"B@*("`@(%LP72`]/B!S=&1#;&%S
M<R!/8FIE8W0*("`@("`@("`H"B`@("`@("`@("`@(%MA72`]/B`T,@H@("`@
M("`@("`@("!;8ET@/3X@=&AR964*("`@("`@("`@("`@6V-=(#T^(%1H<F5E
M"B`@("`@("`@("`@(%MD72`]/B`R,#`S+3`S+3(S"B`@("`@("`@*0H*("`@
M(%LQ72`]/B!S=&1#;&%S<R!/8FIE8W0*("`@("`@("`H"B`@("`@("`@("`@
M(%MA72`]/B`R"B`@("`@("`@("`@(%MB72`]/B!T=V\*("`@("`@("`@("`@
M6V-=(#T^(%1W;PH@("`@("`@("`@("!;9%T@/3X@,C`P,BTP,BTR,@H@("`@
M("`@("D*"BD*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0IT97-T:6YG(&=E=$]N92!W:71H(&YU;&P@=F%L
M=64@:6X@8V]L=6UN.B!E;7!T>2!S=')I;F<*=&5S=&EN9R!G971/;F4@=VET
M:"!E;7!T>2!S=')I;F<@:6X@8V]L=6UN.B!E;7!T>2!S=')I;F<*"CT]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1"+W1E<W1S+W1R86YS86-T:6]N<RYI;F,`````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S-#<V`#$P-#$W,S8S,#`S`#`R,S,T,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+R\@5FEE=R!T:&4@=&%B;&4@9G)O;2!A('-E<&%R871E(&-O;FYE8W1I;VX@
M<V\@=V4@9&]N)W0@9&ES='5R8@HO+R!T:&4@=')A;G-A8W1I;VXN"B1D8F@R
M(#T@1$(Z.F-O;FYE8W0H)&1B:"T^9'-N*3L*"F9U;F-T:6]N(&1U;7!T86)L
M92@D97AP96-T960I('L*("`@(&=L;V)A;"`D9&)H+"`D9&)H,CL*("`@('!R
M:6YT(&EM<&QO9&4H)R`G+"`D9&)H+3YG971#;VPH)U-%3$5#5"!B($923TT@
M<&AP=&5S="<I*3L*"B`@("!I9B`H:7-S970H)&1B:"T^=')A;G-A8W1I;VY?
M;W!C;W5N="DI('L*("`@("`@("!I9B`H)&5X<&5C=&5D(#T]("1D8F@M/G1R
M86YS86-T:6]N7V]P8V]U;G0I('L*("`@("`@("`@("`@<')I;G0@(BX@(&]P
M<SUO:UQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B
M+B`@;W!S/21D8F@M/G1R86YS86-T:6]N7V]P8V]U;G1<;B(["B`@("`@("`@
M?0H@("`@?2!E;'-E('L*("`@("`@("!P<FEN="`B+B`@;W!S/6]K7&XB.PH@
M("`@?0I]"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]$244I
M.PHD9&)H+3YA=71O0V]M;6ET*'1R=64I.PHD9&)H+3YQ=65R>2@B24Y315)4
M($E.5$\@<&AP=&5S="!604Q515,H,2P@)V]N92<L("=/;F4G+"`G,C`P,2TP
M,BTQ.2<I(BD["G!R:6YT(")A9G1E<B!A=71O8V]M;6ET.B`B.PID=6UP=&%B
M;&4H,"D["B1D8F@M/F%U=&]#;VUM:70H9F%L<V4I.PHD9&)H+3YQ=65R>2@B
M24Y315)4($E.5$\@<&AP=&5S="!604Q515,H,BP@)W1W;R<L("=4=V\G+"`G
M,C`P,2TP,BTR,"<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T
M97-T(%9!3%5%4R@S+"`G=&AR964G+"`G5&AR964G+"`G,C`P,2TP,BTR,2<I
M(BD["G!R:6YT(")B969O<F4@8V]M;6ET.B`B.PID=6UP=&%B;&4H,BD["B1D
M8F@M/F-O;6UI="@I.PIP<FEN="`B869T97(@8V]M;6ET.B`B.PID=6UP=&%B
M;&4H,"D["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%
M4R@T+"`G9F]U<B<L("=&;W5R)RP@)S(P,#$M,#(M,C(G*2(I.PHD9&)H+3YQ
M=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,H-2P@)V9I=F4G+"`G
M1FEV92<L("<R,#`Q+3`R+3(S)RDB*3L*<')I;G0@(F)E9F]R92!R;VQL8F%C
M:SH@(CL*9'5M<'1A8FQE*#(I.PHD9&)H+3YR;VQL8F%C:R@I.PIP<FEN="`B
M869T97(@<F]L;&)A8VLZ("(["F1U;7!T86)L92@P*3L*)&1B:"T^875T;T-O
M;6UI="AT<G5E*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@
M5D%,5453*#8L("=S:7@G+"`G4VEX)RP@)S(P,#$M,#(M,C0G*2(I.PHD9&)H
M+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,H-RP@)W-E=F5N
M)RP@)U-E=F5N)RP@)S(P,#$M,#(M,C4G*2(I.PIP<FEN="`B8F5F;W)E(&%U
M=&]C;VUM:70K<F]L;&)A8VLZ("(["F1U;7!T86)L92@P*3L*)&1B:"T^<F]L
M;&)A8VLH*3L*<')I;G0@(F%F=&5R(&%U=&]C;VUM:70K<F]L;&)A8VLZ("([
M"F1U;7!T86)L92@P*3L*"G!R:6YT(")T97-T:6YG('1H870@<V5L96-T(&1O
M97-N)W0@9&ES='5R8F4@;W!C;W5N=#H@(CL*)&1B:"T^875T;T-O;6UI="AF
M86QS92D["B1D8F@M/G-I;7!L95%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E
M<W0B*3L*)&1B:"T^<VEM<&QE475E<GDH(E-%3$5#5"!A+&,@1E)/32!P:'!T
M97-T(BD["B1D8F@M/G-I;7!L95%U97)Y*")314Q%0U0@8BQD($923TT@<&AP
M=&5S="(I.PII9B`H96UP='DH)&1B:"T^=')A;G-A8W1I;VY?;W!C;W5N="DI
M('L*("`@('!R:6YT(")O:UQN(CL*?2!E;'-E('L*("`@('!R:6YT(")F86EL
M960@*&-O=6YT/21D8F@M/G1R86YS86-T:6]N7V]P8V]U;G0I7&XB.PI]"@H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]$0B]T97-T<R]I;F-L=61E+FEN8P``````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#4S,P`Q,#0Q-S,V,S`P,P`P,C(R-#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"F5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["@II9B`H(61E9FEN960H)U!!5$A?4T5005)!
M5$]2)RDI('L*("`@(&EF("AS=')I<W1R*%!(4%]/4RP@)U=)3B<I*2!["B`@
M("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L("<[)RD["B`@("!](&5L
M<V4@>PH@("`@("`@(&1E9FEN92@G4$%42%]315!!4D%43U(G+"`G.B<I.PH@
M("`@?0I]"FEN:5]S970H)VEN8VQU9&5?<&%T:"<L(')E86QP871H*&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B<I"B`@("`@("`@+B!0051(7U-%4$%2051/
M4B`N("<N)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@+B!I;FE?9V5T*"=I
M;F-L=61E7W!A=&@G*2D["@H_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O<VEM<&QE<75E<GDN:6YC````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$U,#4`,3`T,3<S-C,P,#,`,#(S,C`Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*BH*("H@3&]C86P@97)R
M;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*("H@1')O<',@=&AE('!H<'1E<W0@
M=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL;',@
M=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!014%2
M(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES(&UE
M=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O<DAA
M;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@)&1B
M:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D54
M55).*3L*("`@("1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E<W0G*3L*
M"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1S=&@@/2`D
M9&)H+3YS:6UP;&51=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["G!R
M:6YT(&=E='1Y<&4H)'-T:"DN(EQN(CL*"@IS=VET8V@@*"1D8F@M/G!H<'1Y
M<&4I('L*("`@(&-A<V4@)VEB87-E)SH*("`@("`@("`O*@H@("`@("`@("`J
M($EN=&5R8F%S92!D;V5S;B=T(&%L;&]W(&1R;W!P:6YG('1A8FQE<R!T:&%T
M(&AA=F4@<F5S=6QT"B`@("`@("`@("H@<V5T<R!S=&EL;"!O<&5N+@H@("`@
M("`@("`J+PH@("`@("`@("1D8F@M/F9R965297-U;'0H)'-T:"D["B`@("`@
M("`@8G)E86L["GT*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD["B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E<W0G*3L*
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O;G5M8V]L<RYI;F,`````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P-S8`,3`T,3<S-C,P,#,`,#(R,S`V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@HO*BH*("H@3&]C
M86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*("H@1')O<',@=&AE('!H
M<'1E<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@
M:VEL;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O
M("!014%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T
M:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%
M<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B
M86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L*("`@("1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E
M<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1S
M=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$@1E)/32!P:'!T97-T(BD["G!R
M:6YT9B@B)61<;B(L("1S=&@M/FYU;4-O;',H*2D["B1S=&@@/2`D9&)H+3YQ
M=65R>2@B4T5,14-4(&$L8B!&4D]-('!H<'1E<W0B*3L*<')I;G1F*"(E9%QN
M(BP@)'-T:"T^;G5M0V]L<R@I*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%
M0U0@82QB+&,@1E)/32!P:'!T97-T(BD["G!R:6YT9B@B)61<;B(L("1S=&@M
M/FYU;4-O;',H*2D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/
M32!P:'!T97-T(BD["G!R:6YT9B@B)61<;B(L("1S=&@M/FYU;4-O;',H*2D[
M"@H*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=I8F%S92<Z
M"B`@("`@("`@+RH*("`@("`@("`@*B!);G1E<F)A<V4@9&]E<VXG="!A;&QO
M=R!D<F]P<&EN9R!T86)L97,@=&AA="!H879E(')E<W5L=`H@("`@("`@("`J
M('-E=',@<W1I;&P@;W!E;BX*("`@("`@("`@*B\*("`@("`@("`D9&)H+3YF
M<F5E4F5S=6QT*"1S=&@M/G)E<W5L="D["B`@("`@("`@8G)E86L["GT*)&1B
M:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B1D8F@M
M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E<W0G*3L*"C\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D8E]F86-T;W)Y
M+G!H<'0````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<Q,0`Q,#0Q-S,V,S`P
M,P`P,C,Q-#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2U415-4+2T*1$(Z.F9A8W1O<GD*+2U32TE0248M+0H\/W!H<"!C
M:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP
M:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*<F5Q
M=6ER95]O;F-E("<N+VEN8VQU9&4N:6YC)SL*<F5Q=6ER95]O;F-E("=$0BYP
M:'`G.PH*)&)A8VME;F1S(#T@87)R87DH"B`@("`G9&)A<V4G+`H@("`@)V9B
M<W%L)RP*("`@("=I8F%S92<L"B`@("`G:69X)RP*("`@("=M<W%L)RP*("`@
M("=M<W-Q;"<L"B`@("`G;7ES<6PG+`H@("`@)VUY<W%L:2<L"B`@("`G;V-I
M."<L"B`@("`G;V1B8R<L"B`@("`G<&=S<6PG+`H@("`@)W-Q;&ET92<L"B`@
M("`G<WEB87-E)RP**3L*"F9O<F5A8V@@*"1B86-K96YD<R!A<R`D;F%M92D@
M>PH@("`@)&]B:B`]($1".CIF86-T;W)Y*"1N86UE*3L*"B`@("!P<FEN="`B
M=&5S=&EN9R`D;F%M93H@(CL*("`@(&EF("A$0CHZ:7-%<G)O<B@D;V)J*2D@
M>PH)("`@('!R:6YT("=E<G)O<CH@)R`N("1O8FHM/F=E=$UE<W-A9V4H*2`N
M(")<;B(["B`@("!](&5L<V4@>PH)("`@('!R:6YT("=O8FIE8W0Z("<@+B`D
M;V)J+3YT;U-T<FEN9R@I("X@(EQN(CL*("`@('T*?0H*/SX*+2U'150M+0HM
M+5!/4U0M+0HM+4584$5#5"TM"G1E<W1I;F<@9&)A<V4Z(&]B:F5C=#H@9&)?
M9&)A<V4Z("AP:'!T>7!E/61B87-E+"!D8G-Y;G1A>#UD8F%S92D*=&5S=&EN
M9R!F8G-Q;#H@;V)J96-T.B!D8E]F8G-Q;#H@*'!H<'1Y<&4]9F)S<6PL(&1B
M<WEN=&%X/69B<W%L*0IT97-T:6YG(&EB87-E.B!O8FIE8W0Z(&1B7VEB87-E
M.B`H<&AP='EP93UI8F%S92P@9&)S>6YT87@]:6)A<V4I"G1E<W1I;F<@:69X
M.B!O8FIE8W0Z(&1B7VEF>#H@*'!H<'1Y<&4]:69X+"!D8G-Y;G1A>#UI9G@I
M"G1E<W1I;F<@;7-Q;#H@;V)J96-T.B!D8E]M<W%L.B`H<&AP='EP93UM<W%L
M+"!D8G-Y;G1A>#UM<W%L*0IT97-T:6YG(&US<W%L.B!O8FIE8W0Z(&1B7VUS
M<W%L.B`H<&AP='EP93UM<W-Q;"P@9&)S>6YT87@];7-S<6PI"G1E<W1I;F<@
M;7ES<6PZ(&]B:F5C=#H@9&)?;7ES<6PZ("AP:'!T>7!E/6UY<W%L+"!D8G-Y
M;G1A>#UM>7-Q;"D*=&5S=&EN9R!M>7-Q;&DZ(&]B:F5C=#H@9&)?;7ES<6QI
M.B`H<&AP='EP93UM>7-Q;&DL(&1B<WEN=&%X/6UY<W%L:2D*=&5S=&EN9R!O
M8VDX.B!O8FIE8W0Z(&1B7V]C:3@Z("AP:'!T>7!E/6]C:3@L(&1B<WEN=&%X
M/6]C:3@I"G1E<W1I;F<@;V1B8SH@;V)J96-T.B!D8E]O9&)C.B`H<&AP='EP
M93UO9&)C+"!D8G-Y;G1A>#US<6PY,BD*=&5S=&EN9R!P9W-Q;#H@;V)J96-T
M.B!D8E]P9W-Q;#H@*'!H<'1Y<&4]<&=S<6PL(&1B<WEN=&%X/7!G<W%L*0IT
M97-T:6YG('-Q;&ET93H@;V)J96-T.B!D8E]S<6QI=&4Z("AP:'!T>7!E/7-Q
M;&ET92P@9&)S>6YT87@]<W%L:71E*0IT97-T:6YG('-Y8F%S93H@;V)J96-T
M.B!D8E]S>6)A<V4Z("AP:'!T>7!E/7-Y8F%S92P@9&)S>6YT87@]<WEB87-E
M*0H`````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1B7VES;6%N:7`N<&AP=```````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,C0W`#$P-#$W,S8S,#`S`#`R,S$S-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+51%4U0M+0I$0CHZ:7--
M86YI<`HM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I
M*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\
M/W!H<"`O+R`M*BT@0RLK("TJ+0IR97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI
M;F,G.PIR97%U:7)E7V]N8V4@)T1"+G!H<"<["@IF=6YC=&EO;B!T97-T*"1Q
M=65R>2D@>PH@("`@<')I;G1F*"(E<R`Z("5D7&XB+"!P<F5G7W)E<&QA8V4H
M)R]<<RLN*B\G+"`G)RP@)'%U97)Y*2P*("`@("`@("`@("!$0CHZ:7--86YI
M<"@D<75E<GDI*3L*?0H*<')I;G0@(G1E<W1I;F<@1$(Z.FES36%N:7`N+BY<
M;B(["@IT97-T*")314Q%0U0@*B!&4D]-('1A8FQE(BD["G1E<W0H(E-E;&5C
M="`J(&9R;VT@=&%B;&4B*3L*=&5S="@B<V5L96-T("H@1G)O;2!T86)L92(I
M.PIT97-T*")S16Q%0W0@*B!F<D]M('1A8FQE(BD["G1E<W0H(E-%3$5#5"!$
M25-424Y#5"!N86UE($923TT@=&%B;&4B*3L*=&5S="@B55!$051%('1A8FQE
M(%-%5"!F;V\@/2`G8F%R)R(I.PIT97-T*")$14Q%5$4@1E)/32!T86)L92(I
M.PIT97-T*")D96QE=&4@9G)O;2!T86)L92!W:&5R92!I9"!I<R!N=6QL(BD[
M"G1E<W0H(F-R96%T92!T86)L92`H:60@:6YT96=E<BP@;F%M92!V87)C:&%R
M*#$P,"DI(BD["G1E<W0H(D-214%412!315%514Y#12!F;V\B*3L*=&5S="@B
M7")#4D5!5$4@4%)/0T5$55)%(&9O;UPB(BD["G1E<W0H(D=204Y4(%-%3$5#
M5"!/3B!T86)L92!43R!U<V5R(BD["G1E<W0H(E)%5D]+12!314Q%0U0@3TX@
M=&%B;&4@1E)/32!U<V5R(BD["G1E<W0H(E-(3U<@3U!424].4R(I.PIT97-T
M*")$4D]0(%1!0DQ%(&9O;R(I.PIT97-T*")!3%1%4B!404),12!F;V\@041$
M($-/3%5-3B`H8F%R($E.5$5'15(I(BD["G1E<W0H(B`@4T5,14-4("H@1E)/
M32!T86)L92(I.PIT97-T*"(@($1%3$5412!&4D]-('1A8FQE(BD["C\^"BTM
M1T54+2T*+2U03U-4+2T*+2U%6%!%0U0M+0IT97-T:6YG($1".CII<TUA;FEP
M+BXN"E-%3$5#5"`Z(#`*4V5L96-T(#H@,`IS96QE8W0@.B`P"G-%;$5#="`Z
M(#`*4T5,14-4(#H@,`I54$1!5$4@.B`Q"D1%3$5412`Z(#$*9&5L971E(#H@
M,0IC<F5A=&4@.B`Q"D-214%412`Z(#$*(D-214%412`Z(#$*1U)!3E0@.B`Q
M"E)%5D]+12`Z(#$*4TA/5R`Z(#`*1%)/4"`Z(#$*04Q415(@.B`Q"B`Z(#`*
M(#H@,0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9&)?97)R;W(N
M<&AP=```````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8P,C,`,3`T,3<S-C,P
M,#,`,#(R-C(R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"TM5$535"TM"D1".CI$0E]%<G)O<@HM+5-+25!)1BTM"CP_<&AP
M(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K
M:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<"`O+R`M*BT@0RLK("TJ+0IR
M97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI;F,G.PIR97%U:7)E7V]N8V4@)T1"
M+G!H<"<["@IF=6YC=&EO;B!T97-T7V5R<F]R7VAA;F1L97(H)&5R<FYO+"`D
M97)R;7-G+"`D9FEL92P@)&QI;F4L("1V87)S*2!["B`@("!I9B`H9&5F:6YE
M9"@G15]35%))0U0G*2D@>PH@("`@("`@(&EF("@D97)R;F\@)B!%7U-44DE#
M5`H@("`@("`@("`@("`F)B`H97)R;W)?<F5P;W)T:6YG*"D@)B!%7U-44DE#
M5"D@(3T@15]35%))0U0I('L*("`@("`@("`@("`@+R\@26=N;W)E($5?4U12
M24-4(&YO=&EC97,@=6YL97-S('1H97D@:&%V92!B965N('1U<FYE9"!O;@H@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@
M("`@("!D969I;F4H)T5?4U1224-4)RP@,C`T."D["B`@("!]"B`@("`D97)R
M;W)T>7!E(#T@87)R87D@*`H@("`@("`@($5?15)23U(@/3X@)T5R<F]R)RP*
M("`@("`@("!%7U=!4DY)3D<@/3X@)U=A<FYI;F<G+`H@("`@("`@($5?4$%2
M4T4@/3X@)U!A<G-I;F<@17)R;W(G+`H@("`@("`@($5?3D]424-%(#T^("=.
M;W1I8V4G+`H@("`@("`@($5?0T]215]%4E)/4B`]/B`G0V]R92!%<G)O<B<L
M"B`@("`@("`@15]#3U)%7U=!4DY)3D<@/3X@)T-O<F4@5V%R;FEN9R<L"B`@
M("`@("`@15]#3TU024Q%7T524D]2(#T^("=#;VUP:6QE($5R<F]R)RP*("`@
M("`@("!%7T-/35!)3$5?5T%23DE.1R`]/B`G0V]M<&EL92!787)N:6YG)RP*
M("`@("`@("!%7U5315)?15)23U(@/3X@)U5S97(@17)R;W(G+`H@("`@("`@
M($5?55-%4E]705).24Y'(#T^("=5<V5R(%=A<FYI;F<G+`H@("`@("`@($5?
M55-%4E].3U1)0T4@/3X@)U5S97(@3F]T:6-E)RP*("`@("`@("!%7U-44DE#
M5"`]/B`G4W1R:6-T($YO=&EC92<L"B`@("`I.PH@("`@)'!R969I>"`]("1E
M<G)O<G1Y<&5;)&5R<FYO73L*("`@('!R:6YT(")<;B1P<F5F:7@Z("1E<G)M
M<V<@:6X@(B`N(&)A<V5N86UE*"1F:6QE*2`N("(@;VX@;&EN92!86%A<;B([
M"GT*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G-E=%]E<G)O<E]H86YD;&5R
M*"=T97-T7V5R<F]R7VAA;F1L97(G*3L*"G!R:6YT(")T97-T:6YG(&1I9F9E
M<F5N="!E<G)O<B!C;V1E<RXN+EQN(CL*)&4@/2!N97<@1$)?17)R;W(H*3L@
M<')I;G0@)&4M/G1O4W1R:6YG*"DN(EQN(CL*)&4@/2!N97<@1$)?17)R;W(H
M(G1E<W0@97)R;W(B*3L@<')I;G0@)&4M/G1O4W1R:6YG*"DN(EQN(CL*)&4@
M/2!N97<@1$)?17)R;W(H1$)?3TLI.R!P<FEN="`D92T^=&]3=')I;F<H*2XB
M7&XB.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4BD[('!R:6YT("1E+3YT
M;U-T<FEN9R@I+B)<;B(["B1E(#T@;F5W($1"7T5R<F]R*$1"7T524D]27U-9
M3E1!6"D[('!R:6YT("1E+3YT;U-T<FEN9R@I+B)<;B(["B1E(#T@;F5W($1"
M7T5R<F]R*$1"7T524D]27T1)5EI%4D\I.R!P<FEN="`D92T^=&]3=')I;F<H
M*2XB7&XB.PH*<')I;G0@(G1E<W1I;F<@9&EF9F5R96YT(&5R<F]R(&UO9&5S
M+BXN7&XB.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4BP@4$5!4E]%4E)/
M4E]04DE.5"D[('!R:6YT("1E+3YT;U-T<FEN9R@I+B)<;B(["B1E(#T@;F5W
M($1"7T5R<F]R*$1"7T524D]27U-93E1!6"P@4$5!4E]%4E)/4E]44DE'1T52
M*3L*"G!R:6YT(")T97-T:6YG(&1I9F9E<F5N="!E<G)O<B!S97)V97)I=&EE
M<RXN+EQN(CL*)&4@/2!N97<@1$)?17)R;W(H1$)?15)23U)?4UE.5$%8+"!0
M14%27T524D]27U1224='15(L($5?55-%4E].3U1)0T4I.PHD92`](&YE=R!$
M0E]%<G)O<BA$0E]%4E)/4E]364Y405@L(%!%05)?15)23U)?5%))1T=%4BP@
M15]54T527U=!4DY)3D<I.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4E]3
M64Y405@L(%!%05)?15)23U)?5%))1T=%4BP@15]54T527T524D]2*3L*"C\^
M"BTM1T54+2T*+2U03U-4+2T*+2U%6%!%0U0M+0IT97-T:6YG(&1I9F9E<F5N
M="!E<G)O<B!C;V1E<RXN+@I;9&)?97)R;W(Z(&UE<W-A9V4](D1"($5R<F]R
M.B!U;FMN;W=N(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<F5T=7)N(&QE=F5L/6YO
M=&EC92!P<F5F:7@](B(@:6YF;STB(ET*6V1B7V5R<F]R.B!M97-S86=E/2)$
M0B!%<G)O<CH@=&5S="!E<G)O<B(@8V]D93TM,2!M;V1E/7)E='5R;B!L979E
M;#UN;W1I8V4@<')E9FEX/2(B(&EN9F\](B)="EMD8E]E<G)O<CH@;65S<V%G
M93TB1$(@17)R;W(Z(&YO(&5R<F]R(B!C;V1E/3$@;6]D93UR971U<FX@;&5V
M96P];F]T:6-E('!R969I>#TB(B!I;F9O/2(B70I;9&)?97)R;W(Z(&UE<W-A
M9V4](D1"($5R<F]R.B!U;FMN;W=N(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<F5T
M=7)N(&QE=F5L/6YO=&EC92!P<F5F:7@](B(@:6YF;STB(ET*6V1B7V5R<F]R
M.B!M97-S86=E/2)$0B!%<G)O<CH@<WEN=&%X(&5R<F]R(B!C;V1E/2TR(&UO
M9&4]<F5T=7)N(&QE=F5L/6YO=&EC92!P<F5F:7@](B(@:6YF;STB(ET*6V1B
M7V5R<F]R.B!M97-S86=E/2)$0B!%<G)O<CH@9&EV:7-I;VX@8GD@>F5R;R(@
M8V]D93TM,3,@;6]D93UR971U<FX@;&5V96P];F]T:6-E('!R969I>#TB(B!I
M;F9O/2(B70IT97-T:6YG(&1I9F9E<F5N="!E<G)O<B!M;V1E<RXN+@I$0B!%
M<G)O<CH@=6YK;F]W;B!E<G)O<EMD8E]E<G)O<CH@;65S<V%G93TB1$(@17)R
M;W(Z('5N:VYO=VX@97)R;W(B(&-O9&4]+3$@;6]D93UP<FEN="!L979E;#UN
M;W1I8V4@<')E9FEX/2(B(&EN9F\](B)="@I5<V5R($YO=&EC93H@1$(@17)R
M;W(Z('-Y;G1A>"!E<G)O<B!I;B!014%2+G!H<"!O;B!L:6YE(%A86`IT97-T
M:6YG(&1I9F9E<F5N="!E<G)O<B!S97)V97)I=&EE<RXN+@H*57-E<B!.;W1I
M8V4Z($1"($5R<F]R.B!S>6YT87@@97)R;W(@:6X@4$5!4BYP:'`@;VX@;&EN
M92!86%@*"E5S97(@5V%R;FEN9SH@1$(@17)R;W(Z('-Y;G1A>"!E<G)O<B!I
M;B!014%2+G!H<"!O;B!L:6YE(%A86`H*57-E<B!%<G)O<CH@1$(@17)R;W(Z
M('-Y;G1A>"!E<G)O<B!I;B!014%2+G!H<"!O;B!L:6YE(%A86`H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1B7V5R<F]R
M,BYP:'!T````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-C<R`#$P-#$W,S8S
M,#`S`#`R,C<Q-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````M+51%4U0M+0I$0CHZ17)R;W(@,@HM+5-+25!)1BTM"CP_<&AP
M(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K
M:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO
M:6YC;'5D92YI;F,G.PIR97%U:7)E7V]N8V4@)T1"+G!H<"<["@IE<G)O<E]R
M97!O<G1I;F<H-#`Y-2D["@IF=6YC=&EO;B!M>69U;F,H)B1O8FHI('L*("`@
M('!R:6YT(")M>69U;F,@:&5R92P@;V)J/2(N)&]B:BT^=&]3=')I;F<H*2XB
M7&XB.PI]"F9U;F-T:6]N(&UY9G5N8S(H)B1O8FHI('L*("`@('!R:6YT(")M
M>69U;F,R(&AE<F4L(&]B:CTB+B1O8FHM/G1O4W1R:6YG*"DN(EQN(CL*?0IC
M;&%S<R!M>6-L87-S('L*("`@(&9U;F-T:6]N(&UY9G5N8R@F)&]B:BD@>PH@
M("`@("`@('!R:6YT(")M>6-L87-S.CIM>69U;F,@:&5R92P@;V)J/2(N)&]B
M:BT^=&]3=')I;F<H*2XB7&XB.PH@("`@?0I]"F9U;F-T:6]N('1E<W1?97)R
M;W)?:&%N9&QE<B@D97)R;F\L("1E<G)M<V<L("1F:6QE+"`D;&EN92P@)'9A
M<G,I('L*("`@(&EF("AD969I;F5D*"=%7U-44DE#5"<I*2!["B`@("`@("`@
M:68@*"1E<G)N;R`F($5?4U1224-4"B`@("`@("`@("`@("8F("AE<G)O<E]R
M97!O<G1I;F<H*2`F($5?4U1224-4*2`A/2!%7U-44DE#5"D@>PH@("`@("`@
M("`@("`O+R!)9VYO<F4@15]35%))0U0@;F]T:6-E<R!U;FQE<W,@=&AE>2!H
M879E(&)E96X@='5R;F5D(&]N"B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"B`@("!](&5L<V4@>PH@("`@("`@(&1E9FEN92@G15]35%))0U0G+"`R
M,#0X*3L*("`@('T*("`@("1E<G)O<G1Y<&4@/2!A<G)A>2`H"B`@("`@("`@
M15]%4E)/4B`]/B`G17)R;W(G+`H@("`@("`@($5?5T%23DE.1R`]/B`G5V%R
M;FEN9R<L"B`@("`@("`@15]005)312`]/B`G4&%R<VEN9R!%<G)O<B<L"B`@
M("`@("`@15].3U1)0T4@/3X@)TYO=&EC92<L"B`@("`@("`@15]#3U)%7T52
M4D]2(#T^("=#;W)E($5R<F]R)RP*("`@("`@("!%7T-/4D5?5T%23DE.1R`]
M/B`G0V]R92!787)N:6YG)RP*("`@("`@("!%7T-/35!)3$5?15)23U(@/3X@
M)T-O;7!I;&4@17)R;W(G+`H@("`@("`@($5?0T]-4$E,15]705).24Y'(#T^
M("=#;VUP:6QE(%=A<FYI;F<G+`H@("`@("`@($5?55-%4E]%4E)/4B`]/B`G
M57-E<B!%<G)O<B<L"B`@("`@("`@15]54T527U=!4DY)3D<@/3X@)U5S97(@
M5V%R;FEN9R<L"B`@("`@("`@15]54T527TY/5$E#12`]/B`G57-E<B!.;W1I
M8V4G+`H@("`@("`@($5?4U1224-4(#T^("=3=')I8W0@3F]T:6-E)RP*("`@
M("D["B`@("`D<')E9FEX(#T@)&5R<F]R='EP95LD97)R;F]=.PH@("`@<')I
M;G0@(B1P<F5F:7@Z("1E<G)M<V<@:6X@(B`N(&)A<V5N86UE*"1F:6QE*2`N
M("(@;VX@;&EN92!86%A<;B(["GT*"B1O8FH@/2!N97<@;7EC;&%S<SL*"B1D
M8F@@/2!$0CHZ9F%C=&]R>2@B;7ES<6PB*3L*"G!R:6YT(")D969A=6QT.B`B
M.PHD92`]("1D8F@M/G)A:7-E17)R;W(H(G)E='5R;B!T97-T:6YG(&5R<F]R
M(BD["G!R:6YT("1E+3YT;U-T<FEN9R@I("X@(EQN(CL*"G!R:6YT(")G;&]B
M86P@9&5F875L=#H@(CL*4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27T-!3$Q"04-++"`B;7EF=6YC,B(I.PHD92`]("1D8F@M/G)A:7-E17)R
M;W(H(F=L;V)A;"!D969A=6QT('1E<W0B*3L*"B1D8F@M/G-E=$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D["G!R:6YT(")M;V1E/7!R:6YT.B`B
M.PHD92`]("1D8F@M/G)A:7-E17)R;W(H(G!R:6YT('1E<W1I;F<@97)R;W(B
M*3L*<')I;G0@(EQN(CL*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]#04Q,0D%#2RP@(FUY9G5N8R(I.PIP<FEN="`B;6]D93UF=6YC=&EO
M;B!C86QL8F%C:SH@(CL*)&4@/2`D9&)H+3YR86ES945R<F]R*")F=6YC=&EO
M;B!C86QL8F%C:R!T97-T:6YG(&5R<F]R(BD["@HD9&)H+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL(&%R<F%Y*"1O8FHL(")M>69U
M;F,B*2D["G!R:6YT(")M;V1E/6]B:F5C="!C86QL8F%C:SH@(CL*)&4@/2`D
M9&)H+3YR86ES945R<F]R*")O8FIE8W0@8V%L;&)A8VL@=&5S=&EN9R!E<G)O
M<B(I.PH*<V5T7V5R<F]R7VAA;F1L97(H(G1E<W1?97)R;W)?:&%N9&QE<B(I
M.PHD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?5%))1T=%4BD[
M"G!R:6YT(")M;V1E/71R:6=G97(Z("(["B1E(#T@)&1B:"T^<F%I<V5%<G)O
M<B@B=')I9V=E<B!T97-T:6YG(&5R<F]R(BD["@H_/@HM+4584$5#5"TM"F1E
M9F%U;'0Z(%MD8E]E<G)O<CH@;65S<V%G93TB1$(@17)R;W(Z(')E='5R;B!T
M97-T:6YG(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<F5T=7)N(&QE=F5L/6YO=&EC
M92!P<F5F:7@](B(@:6YF;STB(ET*9VQO8F%L(&1E9F%U;'0Z(&UY9G5N8S(@
M:&5R92P@;V)J/5MD8E]E<G)O<CH@;65S<V%G93TB1$(@17)R;W(Z(&=L;V)A
M;"!D969A=6QT('1E<W0B(&-O9&4]+3$@;6]D93UC86QL8F%C:R!C86QL8F%C
M:SUM>69U;F,R('!R969I>#TB(B!I;F9O/2(B70IM;V1E/7!R:6YT.B!$0B!%
M<G)O<CH@<')I;G0@=&5S=&EN9R!E<G)O<@IM;V1E/69U;F-T:6]N(&-A;&QB
M86-K.B!M>69U;F,@:&5R92P@;V)J/5MD8E]E<G)O<CH@;65S<V%G93TB1$(@
M17)R;W(Z(&9U;F-T:6]N(&-A;&QB86-K('1E<W1I;F<@97)R;W(B(&-O9&4]
M+3$@;6]D93UC86QL8F%C:R!C86QL8F%C:SUM>69U;F,@<')E9FEX/2(B(&EN
M9F\](B)="FUO9&4];V)J96-T(&-A;&QB86-K.B!M>6-L87-S.CIM>69U;F,@
M:&5R92P@;V)J/5MD8E]E<G)O<CH@;65S<V%G93TB1$(@17)R;W(Z(&]B:F5C
M="!C86QL8F%C:R!T97-T:6YG(&5R<F]R(B!C;V1E/2TQ(&UO9&4]8V%L;&)A
M8VL@8V%L;&)A8VL];7EC;&%S<SHZ;7EF=6YC('!R969I>#TB(B!I;F9O/2(B
M70IM;V1E/71R:6=G97(Z(%5S97(@3F]T:6-E.B!$0B!%<G)O<CH@=')I9V=E
M<B!T97-T:6YG(&5R<F]R(&EN(%!%05(N<&AP(&]N(&QI;F4@6%A8"@``````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O9&)?<&%R<V5D<VXN<&AP=```````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,C,Q-C4`,3`T,3<S-C,P,#,`,#(S,S$V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM5$535"TM
M"D1".CIP87)S94133@HM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H
M7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM
M+49)3$4M+0H\/W!H<"`O+R`M*BT@0RLK("TJ+0IR97%U:7)E7V]N8V4@)RXO
M:6YC;'5D92YI;F,G.PIR97%U:7)E7V]N8V4@)T1"+G!H<"<["@IF=6YC=&EO
M;B!T97-T*"1D<VXI('L*("`@(&5C:&\@(D133CH@)&1S;EQN(CL*("`@('!R
M:6YT7W(H1$(Z.G!A<G-E1%-.*"1D<VXI*3L*?0H*9G5N8W1I;VX@=&5S=$%R
M<F%Y*"1D<VXI('L*("`@(&5C:&\@(D133CH@87)R87E<;B(["B`@("!P<FEN
M=%]R*$1".CIP87)S94133B@D9'-N*2D["GT*"G!R:6YT(")T97-T:6YG($1"
M.CIP87)S94133BXN+EQN7&XB.PH*=&5S="@B;7ES<6PB*3L*=&5S="@B;V1B
M8RAM<W-Q;"DB*3L*=&5S="@G;V1B8RAD8C(I.B\O=7-E<CIP87-S=V]R9$`O
M9&%T86)A<V4G*3L*=&5S="@G;V1B8RAA8V-E<W,I.B\O+V1A=&%B87-E)RD[
M"G1E<W0H)V]D8F,Z+R]A9&UI;D`O9&%T87-O=7)C94YA;64G*3L*=&5S="@B
M;7ES<6PZ+R]L;V-A;&AO<W0B*3L*=&5S="@B;7ES<6PZ+R]R96UO=&4N:&]S
M="YC;VTO9&(B*3L*=&5S="@B;V-I.#HO+W-Y<W1E;3IM86YA9V5R0"(I.PIT
M97-T*")O8VDX.B\O=7-E<CIP87-S0'1N<RUN86UE(BD["G1E<W0H(F]D8F,H
M<V]L:60I.B\O9F]O.F)A<D!T8W`K;&]C86QH;W-T*S$S,3,B*3L@("\O(&1E
M<')E8V%T960*=&5S="@B<&=S<6PZ+R]U<V5R0'5N:7@K;&]C86QH;W-T+W!E
M87(B*3L@("`@("`@("`@+R\@9&5P<F5C871E9`IT97-T*")I8F%S93HO+W5S
M97(E-#!D;VUA:6XZ<&%S<W=O<F1`:&]S="(I.PIT97-T*")I8F%S93HO+W5S
M97)`9&]M86EN.G!A<W-`=V]R9$`O9&%T86)A<V4B*3L@("`O+R!A;'-O('-U
M<'!O<G1E9`IT97-T*")I9G@Z+R]U<V5R0&1O;6%I;CIP87-S0'=O<F1`:&]S
M="YC;VTO+W5S<B]D8B]G96YE<F%L+F1B(BD["G1E<W0H)VEF>#HO+W)E;6]T
M92YH;W-T+F-O;2]C.EQW:6YD;W=S7&UY+F1B)RD["G1E<W0H)V]C:3@Z+R]3
M2$]/5$]55#HJ*BHJ*BI`*$1%4T-225!424]./2A!1$1215-37TQ)4U0]*$%$
M1%)%4U,]*%!23U1/0T],/51#4"DH2$]35#TQ.3(N,38X+C$P,2XQ-C$I*%!/
M4E0],34R,2DI*2A#3TY.14-47T1!5$$]*%-%4E9)0T5?3D%-13U425,I*2DG
M*3L*"B\O(&YE=R!F;W)M871S"G1E<W0H(F]D8F,H<V]L:60I.B\O9F]O.F)A
M<D!L;V-A;&AO<W0Z,3,Q,R(I.PIT97-T*")P9W-Q;#HO+W5S97)`=6YI>"@I
M+W!E87(B*3L*=&5S="@B;7ES<6PZ+R]U<V5R0'5N:7@H+W!A=&@O=&\O<V]C
M:V5T*2]P96%R(BD["G1E<W0H(G!G<W%L.B\O=7-E<D!T8W`H*2]P96%R(BD[
M"G1E<W0H(G!G<W%L.B\O=7-E<D!T8W`H<V]M96AO<W0I+W!E87(B*3L*=&5S
M="@B<&=S<6PZ+R]U<V5R.G!A<W-`=V]R9$!T8W`H<V]M96AO<W0Z-S<W-RDO
M<&5A<B(I.PH*+R\@<W!E8VEA;"!B86-K96YD(&]P=&EO;G,*=&5S="@G:6)A
M<V4Z+R]U<V5R.G!A<W-`;&]C86QH;W-T+R]V87(O;&EB+V1B87-E+F1B9C]R
M;VQE/69O;R<I.PIT97-T*"=D8F%S93HO+T`O/W)O;&4]9F]O)F1I86QE8W0]
M8F%R)RD["G1E<W0H)W-Q;&ET93HO+R\O=6YI>"]P871H+W1O+V1A=&%B87-E
M/V]P=&EO;CUV86QU929A;F]T:&5R;W!T:6]N/6%N;W1H97)V86QU92<I.PIT
M97-T*"=S<6QI=&4Z+R\O8SHO=VEN+W!A=&@O=&\O9&%T86)A<V4_;W!T:6]N
M/79A;'5E)RD["@HO+R!S;VUE(&5X86UP;&5S(&9R;VT@;6%N=6%L"G1E<W0H
M)VUY<W%L.B\O=7-E<FYA;65`:&]S='-P96,G*3L*=&5S="@G;7ES<6PZ+R]H
M;W-T<W!E8R]D871A8F%S92<I.PIT97-T*"=M>7-Q;#HO+VAO<W1S<&5C)RD[
M"G1E<W0H)VUY<W%L.B\O+V1A=&%B87-E)RD["@HO+R!A<G)A>2!T97-T<PHD
M87)R87D@/2!A<G)A>2@*("`@("=P:'!T>7!E)R`@/3X@)VUY<W%L)RP*("`@
M("=H;W-T<W!E8R<@/3X@)V9O;V)A<B<L"BD["G1E<W1!<G)A>2@D87)R87DI
M.PH*/SX*+2U'150M+0HM+5!/4U0M+0HM+4584$5#5"TM"G1E<W1I;F<@1$(Z
M.G!A<G-E1%-.+BXN"@I$4TXZ(&UY<W%L"D%R<F%Y"B@*("`@(%MP:'!T>7!E
M72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@("`@6W5S97)N
M86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^
M(`H@("`@6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K
M971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ(&]D8F,H;7-S<6PI
M"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O9&)C"B`@("!;9&)S>6YT87A=
M(#T^(&US<W%L"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]
M/B`*("`@(%MP<F]T;V-O;%T@/3X@"B`@("!;:&]S='-P96-=(#T^(`H@("`@
M6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^
M(`HI"D133CH@;V1B8RAD8C(I.B\O=7-E<CIP87-S=V]R9$`O9&%T86)A<V4*
M07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@
M/3X@9&(R"B`@("!;=7-E<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R9%T@
M/3X@<&%S<W=O<F0*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P
M96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;
M9&%T86)A<V5=(#T^(&1A=&%B87-E"BD*1%-..B!O9&)C*&%C8V5S<RDZ+R\O
M9&%T86)A<V4*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD
M8G-Y;G1A>%T@/3X@86-C97-S"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A
M<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P
M96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;
M9&%T86)A<V5=(#T^(&1A=&%B87-E"BD*1%-..B!O9&)C.B\O861M:6Y`+V1A
M=&%S;W5R8V5.86UE"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O9&)C"B`@
M("!;9&)S>6YT87A=(#T^(&]D8F,*("`@(%MU<V5R;F%M95T@/3X@861M:6X*
M("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@
M6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^
M(`H@("`@6V1A=&%B87-E72`]/B!D871A<V]U<F-E3F%M90HI"D133CH@;7ES
M<6PZ+R]L;V-A;&AO<W0*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L
M"B`@("!;9&)S>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^(`H@
M("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;
M:&]S='-P96-=(#T^(&QO8V%L:&]S=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O
M8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@;7ES<6PZ+R]R
M96UO=&4N:&]S="YC;VTO9&(*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY
M<W%L"B`@("!;9&)S>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^
M(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@
M("!;:&]S='-P96-=(#T^(')E;6]T92YH;W-T+F-O;0H@("`@6W!O<G1=(#T^
M(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1B"BD*1%-.
M.B!O8VDX.B\O<WES=&5M.FUA;F%G97)`"D%R<F%Y"B@*("`@(%MP:'!T>7!E
M72`]/B!O8VDX"B`@("!;9&)S>6YT87A=(#T^(&]C:3@*("`@(%MU<V5R;F%M
M95T@/3X@<WES=&5M"B`@("!;<&%S<W=O<F1=(#T^(&UA;F%G97(*("`@(%MP
M<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=
M(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D13
M3CH@;V-I.#HO+W5S97(Z<&%S<T!T;G,M;F%M90I!<G)A>0HH"B`@("!;<&AP
M='EP95T@/3X@;V-I.`H@("`@6V1B<WEN=&%X72`]/B!O8VDX"B`@("!;=7-E
M<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R9%T@/3X@<&%S<PH@("`@6W!R
M;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@=&YS+6YA;64*("`@
M(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]
M/B`**0I$4TXZ(&]D8F,H<V]L:60I.B\O9F]O.F)A<D!T8W`K;&]C86QH;W-T
M*S$S,3,*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y
M;G1A>%T@/3X@<V]L:60*("`@(%MU<V5R;F%M95T@/3X@9F]O"B`@("!;<&%S
M<W=O<F1=(#T^(&)A<@H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T
M<W!E8UT@/3X@;&]C86QH;W-T*S$S,3,*("`@(%MP;W)T72`]/B`*("`@(%MS
M;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ('!G<W%L.B\O
M=7-E<D!U;FEX*VQO8V%L:&]S="]P96%R"D%R<F%Y"B@*("`@(%MP:'!T>7!E
M72`]/B!P9W-Q;`H@("`@6V1B<WEN=&%X72`]/B!P9W-Q;`H@("`@6W5S97)N
M86UE72`]/B!U<V5R"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L
M72`]/B!U;FEX"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@
M("`@6W-O8VME=%T@/3X@;&]C86QH;W-T"B`@("!;9&%T86)A<V5=(#T^('!E
M87(**0I$4TXZ(&EB87-E.B\O=7-E<B4T,&1O;6%I;CIP87-S=V]R9$!H;W-T
M"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!I8F%S90H@("`@6V1B<WEN=&%X
M72`]/B!I8F%S90H@("`@6W5S97)N86UE72`]/B!U<V5R0&1O;6%I;@H@("`@
M6W!A<W-W;W)D72`]/B!P87-S=V]R9`H@("`@6W!R;W1O8V]L72`]/B!T8W`*
M("`@(%MH;W-T<W!E8UT@/3X@:&]S=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O
M8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@:6)A<V4Z+R]U
M<V5R0&1O;6%I;CIP87-S0'=O<F1`+V1A=&%B87-E"D%R<F%Y"B@*("`@(%MP
M:'!T>7!E72`]/B!I8F%S90H@("`@6V1B<WEN=&%X72`]/B!I8F%S90H@("`@
M6W5S97)N86UE72`]/B!U<V5R0&1O;6%I;@H@("`@6W!A<W-W;W)D72`]/B!P
M87-S0'=O<F0*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=
M(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T
M86)A<V5=(#T^(&1A=&%B87-E"BD*1%-..B!I9G@Z+R]U<V5R0&1O;6%I;CIP
M87-S0'=O<F1`:&]S="YC;VTO+W5S<B]D8B]G96YE<F%L+F1B"D%R<F%Y"B@*
M("`@(%MP:'!T>7!E72`]/B!I9G@*("`@(%MD8G-Y;G1A>%T@/3X@:69X"B`@
M("!;=7-E<FYA;65=(#T^('5S97)`9&]M86EN"B`@("!;<&%S<W=O<F1=(#T^
M('!A<W-`=V]R9`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E
M8UT@/3X@:&]S="YC;VT*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^
M(`H@("`@6V1A=&%B87-E72`]/B`O=7-R+V1B+V=E;F5R86PN9&(**0I$4TXZ
M(&EF>#HO+W)E;6]T92YH;W-T+F-O;2]C.EQW:6YD;W=S7&UY+F1B"D%R<F%Y
M"B@*("`@(%MP:'!T>7!E72`]/B!I9G@*("`@(%MD8G-Y;G1A>%T@/3X@:69X
M"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP
M<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(')E;6]T92YH;W-T
M+F-O;0H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T
M86)A<V5=(#T^(&,Z7'=I;F1O=W-<;7DN9&(**0I$4TXZ(&]C:3@Z+R]32$]/
M5$]55#HJ*BHJ*BI`*$1%4T-225!424]./2A!1$1215-37TQ)4U0]*$%$1%)%
M4U,]*%!23U1/0T],/51#4"DH2$]35#TQ.3(N,38X+C$P,2XQ-C$I*%!/4E0]
M,34R,2DI*2A#3TY.14-47T1!5$$]*%-%4E9)0T5?3D%-13U425,I*2D*07)R
M87D**`H@("`@6W!H<'1Y<&5=(#T^(&]C:3@*("`@(%MD8G-Y;G1A>%T@/3X@
M;V-I.`H@("`@6W5S97)N86UE72`]/B!32$]/5$]55`H@("`@6W!A<W-W;W)D
M72`]/B`J*BHJ*BH*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P
M96-=(#T^("A$15-#4DE05$E/3CTH041$4D534U],25-4/2A!1$1215-3/2A0
M4D]43T-/3#U40U`I*$A/4U0],3DR+C$V."XQ,#$N,38Q*2A03U)4/3$U,C$I
M*2DH0T].3D5#5%]$051!/2A315)624-%7TY!344]5$E3*2DI"B`@("!;<&]R
M=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@"BD*
M1%-..B!O9&)C*'-O;&ED*3HO+V9O;SIB87)`;&]C86QH;W-T.C$S,3,*07)R
M87D**`H@("`@6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@
M<V]L:60*("`@(%MU<V5R;F%M95T@/3X@9F]O"B`@("!;<&%S<W=O<F1=(#T^
M(&)A<@H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@
M;&]C86QH;W-T"B`@("!;<&]R=%T@/3X@,3,Q,PH@("`@6W-O8VME=%T@/3X@
M"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@<&=S<6PZ+R]U<V5R0'5N:7@H
M*2]P96%R"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!P9W-Q;`H@("`@6V1B
M<WEN=&%X72`]/B!P9W-Q;`H@("`@6W5S97)N86UE72`]/B!U<V5R"B`@("!;
M<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!U;FEX"B`@("!;:&]S
M='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@
M("!;9&%T86)A<V5=(#T^('!E87(**0I$4TXZ(&UY<W%L.B\O=7-E<D!U;FEX
M*"]P871H+W1O+W-O8VME="DO<&5A<@I!<G)A>0HH"B`@("!;<&AP='EP95T@
M/3X@;7ES<6P*("`@(%MD8G-Y;G1A>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M
M95T@/3X@=7-E<@H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@
M/3X@=6YI>`H@("`@6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@
M(%MS;V-K971=(#T^("]P871H+W1O+W-O8VME=`H@("`@6V1A=&%B87-E72`]
M/B!P96%R"BD*1%-..B!P9W-Q;#HO+W5S97)`=&-P*"DO<&5A<@I!<G)A>0HH
M"B`@("!;<&AP='EP95T@/3X@<&=S<6P*("`@(%MD8G-Y;G1A>%T@/3X@<&=S
M<6P*("`@(%MU<V5R;F%M95T@/3X@=7-E<@H@("`@6W!A<W-W;W)D72`]/B`*
M("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@
M6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^
M('!E87(**0I$4TXZ('!G<W%L.B\O=7-E<D!T8W`H<V]M96AO<W0I+W!E87(*
M07)R87D**`H@("`@6W!H<'1Y<&5=(#T^('!G<W%L"B`@("!;9&)S>6YT87A=
M(#T^('!G<W%L"B`@("!;=7-E<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R
M9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]
M/B!S;VUE:&]S=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@
M("!;9&%T86)A<V5=(#T^('!E87(**0I$4TXZ('!G<W%L.B\O=7-E<CIP87-S
M0'=O<F1`=&-P*'-O;65H;W-T.C<W-S<I+W!E87(*07)R87D**`H@("`@6W!H
M<'1Y<&5=(#T^('!G<W%L"B`@("!;9&)S>6YT87A=(#T^('!G<W%L"B`@("!;
M=7-E<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R9%T@/3X@<&%S<T!W;W)D
M"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!S;VUE
M:&]S=`H@("`@6W!O<G1=(#T^(#<W-S<*("`@(%MS;V-K971=(#T^(`H@("`@
M6V1A=&%B87-E72`]/B!P96%R"BD*1%-..B!I8F%S93HO+W5S97(Z<&%S<T!L
M;V-A;&AO<W0O+W9A<B]L:6(O9&)A<V4N9&)F/W)O;&4]9F]O"D%R<F%Y"B@*
M("`@(%MP:'!T>7!E72`]/B!I8F%S90H@("`@6V1B<WEN=&%X72`]/B!I8F%S
M90H@("`@6W5S97)N86UE72`]/B!U<V5R"B`@("!;<&%S<W=O<F1=(#T^('!A
M<W,*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(&QO
M8V%L:&]S=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;
M9&%T86)A<V5=(#T^("]V87(O;&EB+V1B87-E+F1B9@H@("`@6W)O;&5=(#T^
M(&9O;PHI"D133CH@9&)A<V4Z+R]`+S]R;VQE/69O;R9D:6%L96-T/6)A<@I!
M<G)A>0HH"B`@("!;<&AP='EP95T@/3X@9&)A<V4*("`@(%MD8G-Y;G1A>%T@
M/3X@9&)A<V4*("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^
M(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@
M("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@
M/3X@"B`@("!;<F]L95T@/3X@9F]O"B`@("!;9&EA;&5C=%T@/3X@8F%R"BD*
M1%-..B!S<6QI=&4Z+R\O+W5N:7@O<&%T:"]T;R]D871A8F%S93]O<'1I;VX]
M=F%L=64F86YO=&AE<F]P=&EO;CUA;F]T:&5R=F%L=64*07)R87D**`H@("`@
M6W!H<'1Y<&5=(#T^('-Q;&ET90H@("`@6V1B<WEN=&%X72`]/B!S<6QI=&4*
M("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R
M;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@
M/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@+W5N:7@O
M<&%T:"]T;R]D871A8F%S90H@("`@6V]P=&EO;ET@/3X@=F%L=64*("`@(%MA
M;F]T:&5R;W!T:6]N72`]/B!A;F]T:&5R=F%L=64**0I$4TXZ('-Q;&ET93HO
M+R]C.B]W:6XO<&%T:"]T;R]D871A8F%S93]O<'1I;VX]=F%L=64*07)R87D*
M*`H@("`@6W!H<'1Y<&5=(#T^('-Q;&ET90H@("`@6V1B<WEN=&%X72`]/B!S
M<6QI=&4*("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@
M("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;
M<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@
M8SHO=VEN+W!A=&@O=&\O9&%T86)A<V4*("`@(%MO<'1I;VY=(#T^('9A;'5E
M"BD*1%-..B!M>7-Q;#HO+W5S97)N86UE0&AO<W1S<&5C"D%R<F%Y"B@*("`@
M(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@
M("`@6W5S97)N86UE72`]/B!U<V5R;F%M90H@("`@6W!A<W-W;W)D72`]/B`*
M("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(&AO<W1S
M<&5C"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A
M8F%S95T@/3X@"BD*1%-..B!M>7-Q;#HO+VAO<W1S<&5C+V1A=&%B87-E"D%R
M<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]
M/B!M>7-Q;`H@("`@6W5S97)N86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@
M"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!H;W-T
M<W!E8PH@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T
M86)A<V5=(#T^(&1A=&%B87-E"BD*1%-..B!M>7-Q;#HO+VAO<W1S<&5C"D%R
M<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]
M/B!M>7-Q;`H@("`@6W5S97)N86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@
M"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!H;W-T
M<W!E8PH@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T
M86)A<V5=(#T^(`HI"D133CH@;7ES<6PZ+R\O9&%T86)A<V4*07)R87D**`H@
M("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;9&)S>6YT87A=(#T^(&UY<W%L
M"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP
M<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=
M(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1A=&%B
M87-E"BD*1%-..B!A<G)A>0I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES
M<6P*("`@(%MD8G-Y;G1A>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@
M"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B`*("`@(%MH
M;W-T<W!E8UT@/3X@9F]O8F%R"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T
M72`]/B`*("`@(%MD871A8F%S95T@/3X@"BD*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O=&5S=',O1$(O=&5S=',O;G5M<F]W<RYI;F,`````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,R-S(`,3`T,3<S-C,P,#,`,#(R,S,W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@HO*BH*
M("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*("H@1')O<',@
M=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G
M92!A;F0@:VEL;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE
M8W0@("1O("!014%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E
M9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2
M.CIS971%<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@
M("!G;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*("`@("1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%
M('!H<'1E<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I
M.PH*"B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$@1E)/32!P:'!T97-T
M(BD["G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G:6)A<V4G
M.@H@("`@("`@("\J"B`@("`@("`@("H@26YT97)B87-E(&1O97-N)W0@86QL
M;W<@;6%N:7!U;&%T:6YG('1A8FQE<R!T:&%T(&AA=F4@<F5S=6QT"B`@("`@
M("`@("H@<V5T<R!S=&EL;"!O<&5N+@H@("`@("`@("`J+PH@("`@("`@("1D
M8F@M/F9R965297-U;'0H)'-T:"T^<F5S=6QT*3L*("`@("`@("!B<F5A:SL*
M?0II9B`H(41".CII<T5R<F]R*"1R;W=S(#T@)'-T:"T^;G5M4F]W<R@I*2D@
M>PH@("`@<')I;G0@(B1R;W=S7&XB.PI](&5L<V4@>PH@("`@<')I;G0@(EQN
M(CL*?0IF;W(@*"1I(#T@,#L@)&D@/"`U.R`D:2LK*2!["B`@("`D<W1H(#T@
M)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@*&$I(%9!3%5%4R`H
M)&DI(BD["B`@("`D<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"!A($923TT@
M<&AP=&5S="(I.PH@("`@:68@*"%$0CHZ:7-%<G)O<B@D<F]W<R`]("1S=&@M
M/FYU;5)O=W,H*2DI('L*("`@("`@("!P<FEN="`B)')O=W-<;B(["B`@("!]
M(&5L<V4@>PH@("`@("`@('!R:6YT(")<;B(["B`@("!]"GT*"B1D8F@M/G%U
M97)Y*")$14Q%5$4@1E)/32!P:'!T97-T(%=(15)%(&$@/"`T(BD["B1S=&@@
M/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$@1E)/32!P:'!T97-T(BD["FEF("@A
M1$(Z.FES17)R;W(H)')O=W,@/2`D<W1H+3YN=6U2;W=S*"DI*2!["B`@("!P
M<FEN="`B)')O=W-<;B(["GT@96QS92!["B`@("!P<FEN="`B7&XB.PI]"B1S
M=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$@1E)/32!P:'!T97-T('=H97)E
M(&$@/"`P(BD["FEF("@A1$(Z.FES17)R;W(H)')O=W,@/2`D<W1H+3YN=6U2
M;W=S*"DI*2!["B`@("!P<FEN="`B)')O=W-<;B(["GT@96QS92!["B`@("!P
M<FEN="`B7&XB.PI]"@H*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C
M87-E("=I8F%S92<Z"B`@("`@("`@+RH*("`@("`@("`@*B!);G1E<F)A<V4@
M9&]E<VXG="!A;&QO=R!D<F]P<&EN9R!T86)L97,@=&AA="!H879E(')E<W5L
M=`H@("`@("`@("`J('-E=',@<W1I;&P@;W!E;BX*("`@("`@("`@*B\*("`@
M("`@("`D9&)H+3YF<F5E4F5S=6QT*"1S=&@M/G)E<W5L="D["B`@("`@("`@
M8G)E86L["GT*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD["B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<'1E<W0G*3L*"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V9E=&-H;6]D97,N:6YC````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$Q,C(R`#$P-#$W,S8S,#`S`#`R,C<T,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RHJ"B`J($QO
M8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(N"B`J"B`J($1R;W!S('1H92!P
M:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD
M(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D
M;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@
M=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T
M17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO
M8F%L("1D8F@["@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD["B`@("`D9&)H+3YQ=65R>2@G1%)/4"!404),12!P:'!T
M97-T)RD["@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HD
M9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,@*#$L("=O
M;F4G+"`G3VYE)RP@)S(P,#$M,#(M,38G*2(I.PHD9&)H+3YQ=65R>2@B24Y3
M15)4($E.5$\@<&AP=&5S="!604Q515,@*#(L("=T=V\G+"`G5'=O)RP@)S(P
M,#$M,#(M,34G*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S
M="!604Q515,@*#,L("=T:')E92<L("=4:')E92<L("<R,#`Q+3`R+3$T)RDB
M*3L*"G!R:6YT(")T97-T:6YG(&9E=&-H<F]W.EQN(CL*)'-T:"`]("1D8F@M
M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*9F]R("@D:2`](#$[
M("1I(#P](#4[("1I*RLI('L*("`@('!R:6YT(")R;W<@)&DZ("(["B`@("`D
M<F]W(#T@)'-T:"T^9F5T8VA2;W<H*3L*("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F]W*2D@>PH@("`@("`@('!R:6YT("1R;W<M/G1O4W1R:6YG*"D@+B`B7&XB
M.PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H@("`@:68@*&ES7V%R<F%Y*"1R
M;W<I*2!["B`@("`@("`@<')I;G0@:6UP;&]D92@G+"`G+"`D<F]W*2`N(")<
M;B(["B`@("!](&5L<V4@>PH@("`@("`@('9A<E]D=6UP*"1R;W<I.PH@("`@
M?0I]"@HD9&)H+3YQ=65R>2@G1$5,151%($923TT@<&AP=&5S="!72$5212!A
M(#P^(#0R)RD["@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR
M;W<@9&5F875L="!D969A=6QT+"!P;W)T86)I;&ET>2!M;V1E($1"7U!/4E1!
M0DE,25197T%,3"!>($1"7U!/4E1!0DE,25197U)44DE-7&XB.PHD9&)H+3YS
M971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?04Q,(%X@
M1$)?4$]25$%"24Q)5%E?4E1224TI.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%
M3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H
M*3L*<')I;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<;B([
M"B1A8W1U86P@/2!I;7!L;V1E*"<@)RP@87)R87E?=F%L=65S*"1R;W<I*3L*
M<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=M>7-Q;"<Z"B`@
M("!C87-E("=M>7-Q;&DG.@H@("`@8V%S92`G<W%L:71E)SH*("`@("`@("`D
M97AP96-T960@/2`G-#(@8FEN9R!4:&ES(&ES(&$@=&5S="`Q.3DY+3$Q+3(Q
M)SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VEF>"<Z"B`@("`@("`@)&5X
M<&5C=&5D(#T@)S0R(&)I;F<@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@5&AI<R!I<R!A('1E<W0@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$Y.3DM
M,3$M,C$@("`@("`@("`@)SL*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z
M"B`@("`@("`@)&5X<&5C=&5D(#T@)S0R(&)I;F<@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@5&AI<R!I<R!A('1E<W0@,3DY.2TQ,2TR
M,2<["GT*:68@*"1A8W1U86P@/3T@)&5X<&5C=&5D*2!["B`@("!E8VAO(")O
M=71P=70@;6%T8VAE9"!E>'!E8W1E9"!F;W)M871<;B(["GT@96QS92!["B`@
M("!E8VAO(")$241.)U0@34%40T@A("!%>'!E8W1E9"!O=71P=70Z("<D97AP
M96-T960G+B`@06-T=6%L(&]U='!U=#H@)R1A8W1U86PG+EQN(CL*?0H*<')I
M;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&1E9F%U;'0@9&5F
M875L=%QN(CL*)&1B:"T^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/
M4E1!0DE,25197T%,3"D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@
M1E)/32!P:'!T97-T(BD["B1R;W<@/2!A<G)A>2@I.PHD<W1H+3YF971C:$EN
M=&\H)')O=RD["G!R:6YT(&EM<&QO9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I
M*2XB7&XB.PIP<FEN="!I;7!L;V1E*"<@)RP@87)R87E?=F%L=65S*"1R;W<I
M*2XB7&XB.PH*<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR;W<@
M;W)D97)E9"!D969A=6QT7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D54
M0TA-3T1%7T]21$52140I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J
M($923TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H*3L*<')I
M;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<;B(["@IP<FEN
M="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C:')O=R!A<W-O8R!D969A=6QT
M7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T%34T]#*3L*
M)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*
M)')O=R`]("1S=&@M/F9E=&-H4F]W*"D["G!R:6YT(&EM<&QO9&4H(B`B+"!A
M<G)A>5]K97ES*"1R;W<I*2XB7&XB.PH*<')I;G0@(G1E<W1I;F<@9F5T8VAM
M;V1E<SH@9F5T8VAR;W<@;W)D97)E9"!D969A=6QT('=I=&@@87-S;V,@<W!E
M8VEF:65D7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T]2
M1$52140I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP
M=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%3
M4T]#*3L*<')I;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<
M;B(["@IP<FEN="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C:')O=R!A<W-O
M8R!D969A=6QT('=I=&@@;W)D97)E9"!S<&5C:69I961<;B(["B1D8F@M/G-E
M=$9E=&-H36]D92A$0E]&151#2$U/1$5?05-33T,I.PHD<W1H(#T@)&1B:"T^
M<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T:"T^
M9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I.PIP<FEN="!I;7!L;V1E
M*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN(CL*"G!R:6YT(")T97-T:6YG
M(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!O<F1E<F5D(&1E9F%U;'1<;B(["B1D
M8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/1$5?3U)$15)%1"D["B1S=&@@
M/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@
M/2!A<G)A>2@I.PHD<W1H+3YF971C:$EN=&\H)')O=RD["G!R:6YT(&EM<&QO
M9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB.PH*<')I;G0@(G1E<W1I
M;F<@9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&%S<V]C(&1E9F%U;'1<;B(["B1D
M8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/1$5?05-33T,I.PHD<W1H(#T@
M)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@
M87)R87DH*3L*)'-T:"T^9F5T8VA);G1O*"1R;W<I.PIP<FEN="!I;7!L;V1E
M*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN(CL*"G!R:6YT(")T97-T:6YG
M(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!O<F1E<F5D(&1E9F%U;'0@=VET:"!A
M<W-O8R!S<&5C:69I961<;B(["B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#
M2$U/1$5?3U)$15)%1"D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@
M1E)/32!P:'!T97-T(BD["B1R;W<@/2!A<G)A>2@I.PHD<W1H+3YF971C:$EN
M=&\H)')O=RP@1$)?1D540TA-3T1%7T%34T]#*3L*<')I;G0@:6UP;&]D92@B
M("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<;B(["@IP<FEN="`B=&5S=&EN9R!F
M971C:&UO9&5S.B!F971C:&EN=&\@87-S;V,@9&5F875L="!W:71H(&]R9&5R
M960@<W!E8VEF:65D7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-
M3T1%7T%34T]#*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-
M('!H<'1E<W0B*3L*)')O=R`](&%R<F%Y*"D["B1S=&@M/F9E=&-H26YT;R@D
M<F]W+"!$0E]&151#2$U/1$5?3U)$15)%1"D["G!R:6YT(&EM<&QO9&4H(B`B
M+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB.PH*<W=I=&-H("@D9&)H+3YP:'!T
M>7!E*2!["B`@("!C87-E("=I8F%S92<Z"B`@("`@("`@+RH*("`@("`@("`@
M*B!);G1E<F)A<V4@9&]E<VXG="!A;&QO=R!D<F]P<&EN9R!T86)L97,@=&AA
M="!H879E(')E<W5L=`H@("`@("`@("`J('-E=',@<W1I;&P@;W!E;BX*("`@
M("`@("`@*B\*("`@("`@("`D9&)H+3YF<F5E4F5S=6QT*"1S=&@M/G)E<W5L
M="D["B`@("`@("`@8G)E86L["GT*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD["B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H
M<'1E<W0G*3L*"C\^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]S97%U96YC97,N:6YC````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#8U-0`Q,#0Q-S,V,S`P,P`P,C(V,C8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````"CP_<&AP("\O
M("TJ+2!02%`@+2HM"@IF=6YC=&EO;B!E<G)O<E]H86YD;&5R*"8D;V)J*2![
M"B`@("!P<FEN="`B<V5Q=65N8V5S+FEN8R!E<G)O<E]H86YD;&5R.EQN("`@
M("(["B`@("!P<FEN="`D;V)J+3YG971-97-S86=E*"D["GT*;V)?:6UP;&EC
M:71?9FQU<V@H=')U92D["@HD9')O<"`]("1D8F@M/F1R;W!397%U96YC92@G
M=&5S="<I.PII9B`H1$(Z.FES17)R;W(H)&1R;W`I("8F"B`@("`D9')O<"T^
M9V5T365S<V%G92@I("$]("=$0B!%<G)O<CH@;F\@<W5C:"!T86)L92<I"GL*
M("`@('!R:6YT("=#;W5L9"!N;W0@9')O<"!S97%U96YC92XN+B`G("X@)&1R
M;W`M/F=E=$UE<W-A9V4H*2`N(")<;B(["B`@("!I9B`H)&1B:"T^<&AP='EP
M92`]/2`G:6)A<V4G("8F"B`@("`@("`@)&1R;W`M/F=E=$UE<W-A9V4H*2`]
M/2`G1$(@17)R;W(Z(&EN<W5F9FEC:65N="!P97)M:7-S:6]N<R<I"B`@("![
M"B`@("`@("`@<')I;G0@(E5S92!T:&ES('%U97)Y('1O('!R;W9I9&4@=&AE
M('!E<FUI<W-I;VYS(&YE961E9#I<;B(["B`@("`@("`@<')I;G0@)R`@(&=R
M86YT(&%L;"!O;B!21$(D1T5.15)!5$]24R!T;R`\55-%4DY!344^)SL*("`@
M('T*("`@(&5X:70["GT*"B\O(#$I('1E<W0@=&AA="!S97%U96YC97,@87)E
M(&YO="!C<F5A=&5D(&EF(")O;F1E;6%N9"(@:7,@9F%L<V4*"B1E(#T@)&1B
M:"T^;F5X=$ED*")T97-T(BP@9F%L<V4I.PII9B`H1$(Z.FES17)R;W(H)&4I
M*2!["B`@("!P<FEN="`D92T^9V5T365S<V%G92@I("X@(EQN(CL*?2!E;'-E
M('L*("`@('!R:6YT(")T97-T(#$I(&9A:6QE9"%<;B(["GT*"B\O(#(I('1E
M<W0@=&AA="!T:&4@<V5Q=65N8V4@:7,@;F]T(&-R96%T960@8G5T('1H92!E
M<G)O<B!I<PHO+R!H86YD;&5D(&)Y('1H92!C;&%S<R!E<G)O<B!H86YD;&5R
M"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"P@(B5S
M(#PM(&=O;V0@97)R;W(@8V%T8VAE9%QN(BD["B1E(#T@)&1B:"T^;F5X=$ED
M*")T97-T(BP@9F%L<V4I.PII9B`H(41".CII<T5R<F]R*"1E*2D@>PH@("`@
M<')I;G0@(G1E<W0@,BD@9F%I;&5D(5QN(CL*?0HD9&)H+3Y?9&5F875L=%]E
M<G)O<E]M;V1E(#T@;G5L;#L*"B\O(#,I('1E<W0@=&AA="!S97%U96YC97,@
M87)E(&-R96%T960@:68@(F]N9&5M86YD(B!I<R!T<G5E+"!A;F0@=&AA=`HO
M+R!T=V\@<W5C8V5S<VEV92!N97AT261S(')E='5R;B!A9&IA8V5N="!V86QU
M97,*)&$@/2`D9&)H+3YN97AT260H(G1E<W0B*3L*)&(@/2`D9&)H+3YN97AT
M260H(G1E<W0B*3L*:68@*$1".CII<T5R<F]R*"1A*2D@>PH@("`@<')I;G0@
M(F$Z("(N)&$M/G1O4W1R:6YG*"DN(EQN(CL*?2!E;'-E('L*("`@('!R:6YT
M(")A/21A7&XB.PI]"FEF("A$0CHZ:7-%<G)O<B@D8BDI('L*("`@('!R:6YT
M(")B.B`B+B1B+3YT;U-T<FEN9R@I+B)<;B(["GT@96QS92!["B`@("!P<FEN
M="`B8CTD8EQN(CL*?0IP<FEN="`B8BUA/2(N*"1B+21A*2XB7&XB.PH*+R\@
M-"D@=&5S="!T:&%T('1H92!U<V5R+7-P96-I9FEE9"!E<G)O<B!H86YD;&5R
M(&ES(')E86QL>2!D:7-A8FQE9`HO+R!D=7)I;F<@;F5X=$ED+"!W:71H('!E
M<BUO8FIE8W0@:&%N9&QE<B!A<R!W96QL(&%S(&=L;V)A;"!H86YD;&5R"B1D
M8F@M/F1R;W!397%U96YC92@B=&5S="(I.PH*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27T-!3$Q"04-++"`B97)R;W)?:&%N9&QE<B(I.PHD
M8R`]("1D8F@M/FYE>'1)9"@B=&5S="(I.PII9B`H1$(Z.FES17)R;W(H)&,I
M*2!["B`@("!P<FEN="`B8SH@(BXD8RT^=&]3=')I;F<H*2XB7&XB.PI](&5L
M<V4@>PH@("`@<')I;G0@(F,])&-<;B(["GT*)&1B:"T^9')O<%-E<75E;F-E
M*")T97-T(BD["B1D8F@M/E]D969A=6QT7V5R<F]R7VUO9&4@/2!N=6QL.PI0
M14%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL(")E
M<G)O<E]H86YD;&5R(BD["B1D(#T@)&1B:"T^;F5X=$ED*")T97-T(BD["FEF
M("A$0CHZ:7-%<G)O<B@D9"DI('L*("`@('!R:6YT(")D.B`B+B1D+3YT;U-T
M<FEN9R@I+B)<;B(["GT@96QS92!["B`@("!P<FEN="`B9#TD9%QN(CL*?0H*
M+R\@-2D@=&5S="!T:&%T('1H92!S97%U96YC92!I<R!H86YD;&5D(')I9VAT
M('=H96X@=&AE('1A8FQE(&ES(&5M<'1Y"@HO+R!"86-K96YD('=I=&@@<F5A
M;"!S97%U96YC97,@;6%Y(&1O;B=T(&QI:V4@=&AA=`I014%2.CIP=7-H17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B1D8F@M/G%U97)Y*"=$
M14Q%5$4@1E)/32!T97-T7W-E<2<I.PI014%2.CIP;W!%<G)O<DAA;F1L:6YG
M*"D["B1E(#T@)&1B:"T^;F5X=$E$*"=T97-T)RD["FEF("A$0CHZ:7-%<G)O
M<B@D9"DI('L*("`@('!R:6YT(")E.B`B+B1D+3YT;U-T<FEN9R@I+B)<;B([
M"GT@96QS92!["B`@("!P<FEN="`B93TD9%QN(CL*?0H*+R\@9FEN86P@8VQE
M86XM=7`*)&1B:"T^9')O<%-E<75E;F-E*")T97-T(BD["@H_/@H`````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]F971C:&UO9&5?;V)J
M96-T+FEN8P`````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S4P-0`Q,#0Q-S,V,S`P,P`P
M,C0Q,3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B\J*@H@*B!,;V-A
M;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R+@H@*@H@*B!$<F]P<R!T:&4@<&AP
M=&5S="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K
M:6QL<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@
M(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H
M:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R
M<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A
M;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PH@("`@)&1B:"T^<75E<GDH)T123U`@5$%"3$4@<&AP=&5S
M="<I.PH*("`@(&1I92@D;RT^=&]3=')I;F<H*2D["GT*"@IF=6YC=&EO;B!P
M<FEN=%]O8FHH)B1O8FHI('L*("`@(&EF("@A:7-?;V)J96-T*"1O8FHI*2![
M"B`@("`@("`@96-H;R`B15)23U(Z(&YO(&]B:F5C="%<;B(["B`@("!](&5L
M<V4@>PH@("`@("`@(&5C:&\@<W1R=&]L;W=E<BAG971?8VQA<W,H)&]B:BDI
M("X@)R`M/B`G("X@:6UP;&]D92@G("<L(&%R<F%Y7VME>7,H*&%R<F%Y*21O
M8FHI*2`N(")<;B(["B`@("!]"GT*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*96-H;R`B+2TM(&9E=&-H
M('=I=&@@<&%R86T@1$)?1D540TA-3T1%7T]"2D5#5"`M+2U<;B(["B1S=&@@
M/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@
M/2`D<W1H+3YF971C:%)O=RA$0E]&151#2$U/1$5?3T)*14-4*3L*<')I;G1?
M;V)J*"1R;W<I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@
M<&AP=&5S="(I.PHD<W1H+3YF971C:$EN=&\H)')O=RP@1$)?1D540TA-3T1%
M7T]"2D5#5"D["G!R:6YT7V]B:B@D<F]W*3L*"F5C:&\@(BTM+2!F971C:"!W
M:71H(&1E9F%U;'0@9F5T8VAM;V1E($1"7T9%5$-(34]$15]/0DI%0U0@+2TM
M7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T]"2D5#5"D[
M"B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD[
M"B1R;W<@/2`D<W1H+3YF971C:%)O=R@I.PIP<FEN=%]O8FHH)')O=RD["B1S
M=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1S
M=&@M/F9E=&-H26YT;R@D<F]W*3L*<')I;G1?;V)J*"1R;W<I.PH*96-H;R`B
M+2TM(&9E=&-H('=I=&@@9&5F875L="!F971C:&UO9&4@1$)?1D540TA-3T1%
M7T]"2D5#5"!A;F0@8VQA<W,@1$)?4F]W("TM+5QN(CL*)&1B:"T^<V5T1F5T
M8VA-;V1E*$1"7T9%5$-(34]$15]/0DI%0U0L("=$0E]2;W<G*3L*)'-T:"`]
M("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`]
M("1S=&@M/F9E=&-H4F]W*"D["G!R:6YT7V]B:B@D<F]W*3L*)'-T:"`]("1D
M8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)'-T:"T^9F5T
M8VA);G1O*"1R;W<I.PIP<FEN=%]O8FHH)')O=RD["@H*<W=I=&-H("@D9&)H
M+3YP:'!T>7!E*2!["B`@("!C87-E("=I8F%S92<Z"B`@("`@("`@+RH*("`@
M("`@("`@*B!);G1E<F)A<V4@9&]E<VXG="!A;&QO=R!D<F]P<&EN9R!T86)L
M97,@=&AA="!H879E(')E<W5L=`H@("`@("`@("`J('-E=',@<W1I;&P@;W!E
M;BX*("`@("`@("`@*B\*("`@("`@("`D9&)H+3YF<F5E4F5S=6QT*"1S=&@M
M/G)E<W5L="D["B`@("`@("`@8G)E86L["GT*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD["B1D8F@M/G%U97)Y*"=$4D]0(%1!
M0DQ%('!H<'1E<W0G*3L*"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O<G5N+F-V<P``````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$U-34`,3`T,3<S-C,P,#,`,#(Q-#4U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````",A
M("]B:6XO<V@*"B,@)$ED.B!R=6XN8W9S+'8@,2XR(#(P,#0O,#(O,3D@,C$Z
M-38Z,SD@9&%N:65L8R!%>'`@)`H*(R!V=G9V=G9V=G9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=@HC(%!%05(@1$(@5$535"!3
M5$%25$52"B,*(R`@(%1O(')U;B!A;&P@=&5S=',Z("`N+W)U;@HC("`@5&\@
M<G5N(&]N92!T97-T.B`@("XO<G5N(#QT97-T(&YA;64^+G!H<'0*(R`@($5X
M86UP;&4Z("`@("`@("`@("`N+W)U;B!D8E]P87)S961S;BYP:'!T"B,*(R!"
M969O<F4@<G5N;FEN9R!T:&4@=&5S=',@>6]U(&UU<W0@861J=7-T('1H90HC
M(&9O;&QO=VEN9R!T:')E92!V87)I86)L97,Z"@HC("`@5&AE(&9U;&P@<&%T
M:"!T;R!Y;W5R(%!(4"!D:7)E8W1O<GDZ"B`@("!$0E]415-47U!(4%]0051(
M/6,Z+W!R;V=R87XQ+W!H<`H*(R`@(%1H92!N86UE(&]F('EO=7(@4$A0($-,
M22!E>&5C=71A8FQE"B,@("`H97AA;7!L97,@<&AP+F5X92P@<&AP+6-L:2YE
M>&4L(&-L:2]P:'`N97AE*3H*("`@($1"7U1%4U1?4$A07T-,23UP:'`N97AE
M"@HC("`@5&AE(&9U;&P@<&%T:"!T;R!T:&4@<')E<V5N="!D:7)E8W1O<GD*
M(R`@("AN;W0@=7-I;F<@)%!71"!D=64@=&\@0WEG=VEN*3H*("`@($1"7U1%
M4U1?1$E2/60Z+W!E87)T97-T+W!E87(O1$(O=&5S=',*"B,@7EY>7EY>7EY>
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EX*"@H*
M5$535%]02%!?15A%0U5404),13TD1$)?5$535%]02%!?4$%42"\D1$)?5$53
M5%]02%!?0TQ)"F5X<&]R="!415-47U!(4%]%6$5#551!0DQ%"@HD5$535%]0
M2%!?15A%0U5404),12`D1$)?5$535%]02%!?4$%42"]R=6XM=&5S=',N<&AP
M("1$0E]415-47T1)4B\D,2`M;`H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O<')E<&5X92YI;F,`
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`W,3(`,3`T,3<S-C,P,#,`
M,#(R,C<R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HD=&UP9FEL92`]('1E;7!N86TH(B]T;7`B+"`B<&AP=&UP
M(BD["G)E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*")M>5]S:'5T9&]W;B(I
M.PHD9G`@/2!F;W!E;B@D=&UP9FEL92P@(G<B*3L*)&9I;&5D871A(#T@(F]P
M87%U92!P;&%C96AO;&1E<B=S('1E<W0B.PIF=W)I=&4H)&9P+"`D9FEL961A
M=&$I.PIF8VQO<V4H)&9P*3L*"@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A
M8VL@:&%N9&QE<BX*("H*("H@4')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E
M(&%N9"!K:6QL<R!T:&4@<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@
M)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O
M('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E
M=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@('!R
M:6YT(")<;B(@+B`D;RT^=&]3=')I;F<H*3L*("`@(&5X:70["GT*"B1D8F@M
M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD[
M"@H*+R\@,2D@375L=&EP;&4@<')E<&%R92]E>&5C($E.4T525"!Q=65R:65S
M"F5C:&\@(BTM+2TM+2TM+2TM+3$M+2TM+2TM+2TM+2U<;B(["@HD<W1H,2`]
M("1D8F@M/G!R97!A<F4H(DE.4T525"!)3E1/('!H<'1E<W0@*&$L(&(I(%9!
M3%5%4R`H/RP@)V$G*2(I.PHD<W1H,B`]("1D8F@M/G!R97!A<F4H(DE.4T52
M5"!)3E1/('!H<'1E<W0@*&$L8BD@5D%,5453("@A+#\I(BD["B1S=&@S(#T@
M)&1B:"T^<')E<&%R92@B24Y315)4($E.5$\@<&AP=&5S="`H82QB+&,I(%9!
M3%5%4R`H/RPA+"8I(BD["B1S=&@T(#T@)&1B:"T^<')E<&%R92@B24Y315)4
M($E.5$\@<&AP=&5S="`H82P@8BD@5D%,5453("@W,BP@)V1I<F5C="<I(BD[
M"G!R:6YT(")S=&@Q+'-T:#(L<W1H,RQS=&@T(&-R96%T961<;B(["G!R:6YT
M("=S=&@Q.B`_(&%S('!A<F%M+"!P87-S:6YG(&%S(&%R<F%Y+BXN("<["FEF
M("@H)')E<R`]("1D8F@M/F5X96-U=&4H)'-T:#$L(&%R<F%Y*#<R*2DI(#T]
M($1"7T]+*2!["B`@("!P<FEN="`B<W1H,2!E>&5C=71E9%QN(CL*?2!E;'-E
M('L*("`@('!R:6YT(")S=&@Q(&9A:6QE9%QN(CL*?0IP<FEN="`G<W1H,CH@
M(2!A;F0@/R!A<R!P87)A;7,L('!A<W-I;F<@87,@87)R87DN+BX@)SL*:68@
M*"@D<F5S(#T@)&1B:"T^97AE8W5T92@D<W1H,BP@87)R87DH-S(L(")T:&%T
M)W,@<FEG:'0B*2DI(#T]($1"7T]+*2!["B`@("!P<FEN="`B<W1H,B!E>&5C
M=71E9%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")S=&@R(&9A:6QE9%QN(CL*
M?0IP<FEN="`G<W1H,SH@/RP@(2!A;F0@)B!A<R!P87)A;7,L('!A<W-I;F<@
M87,@87)R87DN+BX@)SL*:68@*"@D<F5S(#T@)&1B:"T^97AE8W5T92@D<W1H
M,RP@87)R87DH-S(L("(G:70G)W,@9V]O9"<B+"`D=&UP9FEL92DI*2`]/2!$
M0E]/2RD@>PH@("`@<')I;G0@(G-T:#,@97AE8W5T961<;B(["GT@96QS92![
M"B`@("!P<FEN="`B<W1H,R!F86EL961<;B(["GT*<')I;G0@)W-T:#0Z(&YO
M('!A<F%M<RXN+B`G.PII9B`H*"1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@T
M*2D@/3T@1$)?3TLI('L*("`@('!R:6YT(")S=&@T(&5X96-U=&5D7&XB.PI]
M(&5L<V4@>PH@("`@<')I;G0@(G-T:#0@9F%I;&5D7&XB.PI]"G!R:6YT7W)E
M<W5L=',H*3L*"@HO+R`R*2!/;F4@<')E<&%R960L(&UU;'1I<&QE('1I;64@
M97AE8W5T960*96-H;R`B7&XM+2TM+2TM+2TM+2TR+2TM+2TM+2TM+2TM7&XB
M.PH*)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E<W0G*3L*)'-T:"`]
M("1D8F@M/G!R97!A<F4H)TE.4T525"!)3E1/('!H<'1E<W0@*&$L(&(L(&,L
M(&0I(%9!3%5%4R`H/RP@/RP@)BP@/RDG*3L*)&1A=&$@/2!A<G)A>2@*("`@
M(#`@/3X@87)R87DH-S(L("=S970Q)RP@)'1M<&9I;&4L("<Q,C,T+34V+3<X
M)RDL"B`@("`Q(#T^(&%R<F%Y*#<R+"`G<V5T,B<L("1T;7!F:6QE+"!N=6QL
M*2P*("`@(#(@/3X@87)R87DH-S(L("=S970S)RP@)'1M<&9I;&4L(&YU;&PI
M"BD["B1R97,@/2`D9&)H+3YE>&5C=71E375L=&EP;&4H)'-T:"P@)&1A=&$I
M.PIP<FEN=%]R97-U;'1S*"D["@H*+R\@,RD@9G)E95!R97!A<F5D*"D@=&5S
M=`IE8VAO(")<;BTM+2TM+2TM+2TM+3,M+2TM+2TM+2TM+2U<;B(["@II9B`H
M)&1B:"T^9G)E95!R97!A<F5D*"1S=&@I*2!["B`@("!E8VAO("=44E5%)SL*
M?2!E;'-E('L*("`@(&5C:&\@)T9!3%-%)SL*?0IE8VAO(")<;B(["FEF("@D
M9&)H+3YF<F5E4')E<&%R960H-C8V*2D@>PH@("`@96-H;R`G5%)512<["GT@
M96QS92!["B`@("!E8VAO("=&04Q312<["GT*96-H;R`B7&XB.PH*"B\O(#0I
M(%-%3$5#5',@=&5S=',*96-H;R`B7&XM+2TM+2TM+2TM+2TT+2TM+2TM+2TM
M+2TM7&XB.PH*)'-T:#$@/2`D9&)H+3YP<F5P87)E*")314Q%0U0@*B!&4D]-
M('!H<'1E<W0@5TA%4D4@82`](#\@3U)$15(@0ED@8B(I.PIP<FEN=%\T*"1S
M=&@Q+"`W,BD["G!R:6YT7S0H)'-T:#$L(#<Q*3L*)'-T:#(@/2`D9&)H+3YP
M<F5P87)E*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@9"`](#\@3U)$
M15(@0ED@8B(I.PIP<FEN=%\T*"1S=&@R+"`G,3(S-"TU-BTW."<I.PHD<W1H
M,R`]("1D8F@M/G!R97!A<F4H(E-%3$5#5"`J($923TT@<&AP=&5S="!72$52
M12!C(#T@)B!/4D1%4B!"62!B(BD["G!R:6YT7S0H)'-T:#,L("1T;7!F:6QE
M*3L*"@HO+R`U*2!!4U-/0TE!5$E612!!4E)!62!Q=65R:65S"F5C:&\@(EQN
M+2TM+2TM+2TM+2TM-2TM+2TM+2TM+2TM+5QN(CL*"B1S=&@U(#T@)&1B:"T^
M<')E<&%R92@G24Y315)4($E.5$\@<&AP=&5S="`H82P@8BP@9"D@5D%,5453
M("@_+"`_+"`_*2<I.PHD87)R87D@/2!A<G)A>2@*("`@("=F;V\G(#T^(#$Q
M+`H@("`@)V)A<B<@/3X@)W1H<F5E)RP*("`@("=B87HG(#T^(&YU;&PL"BD[
M"B1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@U+"`D87)R87DI.PIP<FEN="`G
M:6YS97)T.B`G("X@*"1R97,@/3T@1$)?3TL@/R`G;VMA>2<@.B`G97)R;W(G
M*2`N(")<;B(["@HD<W1H-B`]("1D8F@M/G!R97!A<F4H)U-%3$5#5"!A+"!B
M+"!D($923TT@<&AP=&5S="!72$5212!A(#T@/R<I.PHD<F5S(#T@)&1B:"T^
M97AE8W5T92@D<W1H-BP@87)R87DH,3$I*3L*)')O=R`]("1R97,M/F9E=&-H
M4F]W*$1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT(")A(#T@>R1R;W=;)V$G
M77TL(&(@/2![)')O=ULG8B==?2P@9"`]("(@+B!G971T>7!E*"1R;W=;)V0G
M72D@+B`B7&XB.PH*"@IF=6YC=&EO;B!M>5]S:'5T9&]W;B@I('L*("`@(&=L
M;V)A;"`D=&UP9FEL92P@)&1B:"P@)'-T:#$L("1S=&@R+"`D<W1H,RP@)'-T
M:#0L("1S=&@U+"`D<W1H-BP@)')E<SL*"B`@("!S=VET8V@@*"1D8F@M/G!H
M<'1Y<&4I('L*("`@("`@("!C87-E("=I8F%S92<Z"B`@("`@("`@("`@("\J
M"B`@("`@("`@("`@("`J($EN=&5R8F%S92!D;V5S;B=T(&%L;&]W(&1R;W!P
M:6YG('1A8FQE<R!T:&%T(&AA=F4@<F5S=6QT"B`@("`@("`@("`@("`J('-E
M=',@<W1I;&P@;W!E;BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1D
M8F@M/F9R9650<F5P87)E9"@D<W1H,2D["B`@("`@("`@("`@("1D8F@M/F9R
M9650<F5P87)E9"@D<W1H,BD["B`@("`@("`@("`@("1D8F@M/F9R9650<F5P
M87)E9"@D<W1H,RD["B`@("`@("`@("`@("1D8F@M/F9R9650<F5P87)E9"@D
M<W1H-"D["B`@("`@("`@("`@("1D8F@M/F9R9650<F5P87)E9"@D<W1H-2D[
M"B`@("`@("`@("`@("1D8F@M/F9R9650<F5P87)E9"@D<W1H-BD["B`@("`@
M("`@("`@("1D8F@M/F9R965297-U;'0H)')E<RT^<F5S=6QT*3L*("`@("`@
M("`@("`@8G)E86L["B`@("!]"@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD["B`@("`D9&)H+3YQ=65R>2@G1%)/4"!4
M04),12!P:'!T97-T)RD["@H@("`@=6YL:6YK*"1T;7!F:6QE*3L*?0H*9G5N
M8W1I;VX@<')I;G1?<F5S=6QT<R@I('L*("`@(&=L;V)A;"`D9&)H.PH@("`@
M<')I;G0@(G)E<W5L=',Z7&XB.PH@("`@)')E<R`]("1D8F@M/G%U97)Y*")3
M14Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@82`](#<R($]21$52($)9(&(B
M*3L*("`@("1I(#T@,#L*("`@('=H:6QE("@D<F]W(#T@)')E<RT^9F5T8VA2
M;W<H1$)?1D540TA-3T1%7T]21$52140I*2!["B`@("`@("`@<')I;G0@)WPG
M("X@:6UP;&]D92@B("T@(BP@)')O=RD@+B`B?%QN(CL*("`@("`@("`D:2LK
M.PH@("`@?0H@("`@:68@*"$D:2D@>PH@("`@("`@('!R:6YT(")4:&4@<F5C
M;W)D<R!W97)E(&YO="!F;W5N9"X@($1I9"!T:&5Y(&=E="!I;G-E<G1E9#]<
M;B(["B`@("!]"GT*"F9U;F-T:6]N('!R:6YT7S0H)'-T:"P@)&)I;F0I('L*
M("`@(&=L;V)A;"`D9&)H.PH@("`@)')E<R`]("1D8F@M/F5X96-U=&4H)'-T
M:"P@)&)I;F0I.PH@("`@=VAI;&4@*"1R;W<@/2`D<F5S+3YF971C:%)O=RA$
M0E]&151#2$U/1$5?3U)$15)%1"DI('L*("`@("`@("!P<FEN="`G?"<@+B!I
M;7!L;V1E*"(@+2`B+"`D<F]W*2`N(")\7&XB.PH@("`@?0H@("`@96-H;R`B
M?GY<;B(["GT*"C\^"@``````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]$0B]T97-T<R]E<G)O<G,N:6YC````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,#(Q,``Q,#0Q-S,V,S`P,P`P,C(Q,C<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"F9U;F-T:6]N(&5R<FAA;F1L97(H)&]B:BD*>PH@("`@:68@*"1O8FHM/F=E
M=$-O9&4H*2`]/2!$0E]%4E)/4BD@>PH@("`@("`@('!R:6YT("<@('5N:VYO
M=VXZ("<@+B`D;V)J+3YG9715<V5R26YF;R@I+B)<;B(["B`@("!](&5L<V4@
M>PH@("`@("`@("1M<V<@/2`D;V)J+3YG971-97-S86=E*"D["B`@("`@("`@
M<')I;G0@(B`@)&US9R(["B`@("`@("`@:68@*'-U8G-T<B@D;7-G+"`M,2D@
M(3T@(EQN(BD@>PH@("`@("`@("`@("!P<FEN="`B7&XB.PH@("`@("`@('T*
M("`@('T*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!
M3$Q"04-++"`B97)R:&%N9&QE<B(I.PH*"G!R:6YT(")4<GEI;F<@=&\@<')O
M=F]K92!$0E]%4E)/4E].3U-50TA404),15QN(CL*)&1B:"T^<75E<GDH)U-%
M3$5#5"`J($923TT@=&%B;&54:&%T<T)O9W5S)RD["@IP<FEN="`B5')Y:6YG
M('1O('!R;W9O:V4@1$)?15)23U)?04Q214%$65]%6$E35%,@9F]R(&-R96%T
M92!T86)L95QN(CL*)&1B:"T^<75E<GDH)'1E<W1?;6MT86)L95]Q=65R>2D[
M"@IP<FEN="`B5')Y:6YG('1O('!R;W9O:V4@1$)?15)23U)?3D]354-(5$%"
M3$5<;B(["B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('1A8FQE5&AA='-";V=U
M<R<I.PH*"G!R:6YT(")4<GEI;F<@=&\@<')O=F]K92!$0E]%4E)/4E]#3TY3
M5%)!24Y4(&9O<B!P<FEM87)Y(&ME>2!I;G-E<G0@9'5P;&EC871E7&XB.PHD
M9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*)&1B
M:"T^<75E<GDH)T123U`@5$%"3$4@82<I.PHD9&)H+3YS971%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=E<G)H86YD;&5R)RD["B1D8F@M
M/G%U97)Y*"=#4D5!5$4@5$%"3$4@82`H82!)3E1%1T52($Y/5"!.54Q,+"!0
M4DE-05)9($M%62`H82DI)RD["B1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!A
M(%9!3%5%4R`H,2DG*3L*)&1B:"T^<75E<GDH)TE.4T525"!)3E1/(&$@5D%,
M5453("@Q*2<I.PH*<')I;G0@(E1R>6EN9R!T;R!P<F]V;VME($1"7T524D]2
M7T-/3E-44D%)3E0@9F]R('!R:6UA<GD@:V5Y('5P9&%T92!D=7!L:6-A=&5<
M;B(["B1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!A(%9!3%5%4R`H,BDG*3L*
M)&1B:"T^<75E<GDH)U501$%412!A(%-%5"!A/3$@5TA%4D4@83TR)RD["@H*
M<')I;G0@(E1R>6EN9R!T;R!P<F]V;VME($1"7T524D]27T-/3E-44D%)3E0@
M9F]R('5N:7%U92!K97D@:6YS97)T(&1U<&QI8V%T95QN(CL*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B1D8F@M/G%U97)Y
M*"=$4D]0(%1!0DQ%(&$G*3L*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%2
M7T524D]27T-!3$Q"04-++"`G97)R:&%N9&QE<B<I.PHD9&)H+3YQ=65R>2@G
M0U)%051%(%1!0DQ%(&$@*&$@24Y414=%4B!.3U0@3E5,3"P@54Y)455%("AA
M*2DG*3L*)&1B:"T^<75E<GDH)TE.4T525"!)3E1/(&$@5D%,5453("@Q*2<I
M.PHD9&)H+3YQ=65R>2@G24Y315)4($E.5$\@82!604Q515,@*#$I)RD["@IP
M<FEN="`B5')Y:6YG('1O('!R;W9O:V4@1$)?15)23U)?0T].4U1204E.5"!F
M;W(@=6YI<75E(&ME>2!U<&1A=&4@9'5P;&EC871E7&XB.PHD9&)H+3YQ=65R
M>2@G24Y315)4($E.5$\@82!604Q515,@*#(I)RD["B1D8F@M/G%U97)Y*"=5
M4$1!5$4@82!3150@83TQ(%=(15)%(&$],B<I.PH*"G!R:6YT(")4<GEI;F<@
M=&\@<')O=F]K92!$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!F;W)E:6=N(&ME
M>5QN(CL*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%(&(G*3L*)&1B:"T^<75E<GDH
M)T123U`@5$%"3$4@82<I.PHD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?0T%,3$)!0TLL("=E<G)H86YD;&5R)RD["B1D8F@M/G%U97)Y*"=#
M4D5!5$4@5$%"3$4@82`H82!)3E1%1T52($Y/5"!.54Q,+"!04DE-05)9($M%
M62AA*2DG*3L*)&1B:"T^<75E<GDH)T-214%412!404),12!B("AB($E.5$5'
M15(@4D5&15)%3D-%4R!A*&$I*2<I.PHD9&)H+3YQ=65R>2@G24Y315)4($E.
M5$\@82!V86QU97,@*#$I)RD["B1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!B
M('9A;'5E<R`H,BDG*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C
M87-E("=M>7-Q;"<Z"B`@("!C87-E("=S<6QI=&4G.@H@("`@("`@('!R:6YT
M("(@("`@("`@("`@("!/2R`@)&1B:"T^<&AP='EP92!D;V5S;B=T(&-O;G-I
M9&5R('1H:7,@86X@97)R;W)<;B(["B`@("`@("`@8G)E86L["GT*"@IP<FEN
M="`B5')Y:6YG('1O('!R;W9O:V4@1$)?15)23U)?0T].4U1204E.5%].3U1?
M3E5,3"!O;B!I;G-E<G1<;B(["B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PHD9&)H+3YQ=65R>2@G1%)/4"!404),12!P96%R
M=&5S=&YU;&PG*3L*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7T-!3$Q"04-++"`G97)R:&%N9&QE<B<I.PHD9&)H+3YQ=65R>2@G0U)%051%
M(%1!0DQ%('!E87)T97-T;G5L;"`H82!#2$%2*#,I($Y/5"!.54Q,*2<I.PHD
M9&)H+3YQ=65R>2@G24Y315)4($E.5$\@<&5A<G1E<W1N=6QL(%9!3%5%4R`H
M3E5,3"DG*3L*"G!R:6YT(")4<GEI;F<@=&\@<')O=F]K92!$0E]%4E)/4E]#
M3TY35%)!24Y47TY/5%].54Q,(&]N('5P9&%T95QN(CL*)&1B:"T^<75E<GDH
M(DE.4T525"!)3E1/('!E87)T97-T;G5L;"!604Q515,@*"=O;F4G*2(I.PHD
M9&)H+3YQ=65R>2@B55!$051%('!E87)T97-T;G5L;"!3150@82`]($Y53$P@
M5TA%4D4@82`]("=O;F4G(BD["G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@
M("`@8V%S92`G;7ES<6PG.@H@("`@("`@('!R:6YT("(@("`@("`@("`@("!/
M2R`@)&1B:"T^<&AP='EP92!D;V5S;B=T(&-O;G-I9&5R('1H:7,@86X@97)R
M;W)<;B(["B`@("`@("`@8G)E86L["GT*"@IP<FEN="`B5')Y:6YG('1O('!R
M;W9O:V4@1$)?15)23U)?1$E66D523UQN(CL*+R\@26YT97)B87-E(&1E=&5C
M=',@=&AE(&5R<F]R(&]N(&9E=&-H:6YG"B1D8F@M/F=E=$%L;"@G4T5,14-4
M(#`O,"!&4D]-('!H<'1E<W0G*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2![
M"B`@("!C87-E("=M<W-Q;"<Z"B`@("!C87-E("=S>6)A<V4G.@H@("`@("`@
M('!R:6YT("(@("`@("`@("`@("!/2R`@4$A0)W,@)&1B:"T^<&AP='EP92!E
M>'1E;G-I;VX@9&]E<VXG="!R97!O<G0@=&AI<R!E<G)O<EQN(CL*("`@("`@
M("!B<F5A:SL*("`@(&-A<V4@)V]D8F,G.@H@("`@("`@('-W:71C:"`H)&1B
M:"T^9&)S>6YT87@I('L*("`@("`@("`@("`@8V%S92`G86-C97-S)SH*("`@
M("`@("`@("`@("`@('!R:6YT("(@("`@("`@("`@("!/2R`@;V1B8R@D9&)H
M+3YD8G-Y;G1A>"D@9&]E<VXG="!R97!O<G0@=&AI<R!E<G)O<EQN(CL*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*
M("`@(&-A<V4@)VEF>"<Z"B`@("!C87-E("=M>7-Q;"<Z"B`@("!C87-E("=S
M<6QI=&4G.@H@("`@("`@('!R:6YT("(@("`@("`@("`@("!/2R`@)&1B:"T^
M<&AP='EP92!D;V5S;B=T(&-O;G-I9&5R('1H:7,@86X@97)R;W)<;B(["B`@
M("`@("`@8G)E86L["GT*"G!R:6YT(")4<GEI;F<@=&\@<')O=F]K92!$0E]%
M4E)/4E])3E9!3$E$7TY534)%4EQN(CL*)&1B:"T^<75E<GDH(E501$%412!P
M:'!T97-T(%-%5"!A(#T@)V%B8R<@5TA%4D4@82`](#0R(BD["G-W:71C:"`H
M)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G;7ES<6PG.@H@("`@8V%S92`G
M<W%L:71E)SH*("`@("`@("!P<FEN="`B("`@("`@("`@("`@3TL@("1D8F@M
M/G!H<'1Y<&4@9&]E<VXG="!C;VYS:61E<B!T:&ES(&%N(&5R<F]R7&XB.PH@
M("`@("`@(&)R96%K.PI]"@IP<FEN="`B5')Y:6YG('1O('!R;W9O:V4@1$)?
M15)23U)?3D]354-(1DE%3$1<;B(["B1D8F@M/G%U97)Y*"=314Q%0U0@92!&
M4D]-('!H<'1E<W0G*3L*"G!R:6YT(")4<GEI;F<@=&\@<')O=F]K92!$0E]%
M4E)/4E]364Y405A<;B(["B1D8F@M/G%U97)Y*"=#4D5!5$4G*3L*"@HD9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*)&1B:"T^
M<75E<GDH)T123U`@5$%"3$4@<&AP=&5S="<I.PHD9&)H+3YQ=65R>2@G1%)/
M4"!404),12!B)RD["B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%(&$G*3L*)&1B
M:"T^<75E<GDH)T123U`@5$%"3$4@<&5A<G1E<W1N=6QL)RD["@H_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+VQI;6ET+FEN8P``````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R-3<P`#$P-#$W,S8S,#`S`#`R,3<T,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`IE<G)O<E]R97!O
M<G1I;F<H15]!3$PI.PH*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA
M;F1L97(N"B`J"B`J($1R;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN=',@
M;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C97-S
M+@H@*@H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@
M875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R
M;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF
M=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO8F%L("1D8F@["@H@("`@)&1B:"T^
M<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`D9&)H
M+3YQ=65R>2@G1%)/4"!404),12!P:'!?;&EM:70G*3L*"B`@("!D:64H)&\M
M/G1O4W1R:6YG*"DI.PI]"@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD["B1D8F@M/G%U97)Y*"=$4D]0(%1!0DQ%('!H<%]L
M:6UI="<I.PH*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!
M3$Q"04-++"`G<&4G*3L*"B1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@<&AP
M7VQI;6ET("AA($-(05(H,C`I*2<I.PH*"B1F<F]M("`@(#T@,#L*)&-O=6YT
M("`@/2`Q,#L*)&YU;7)O=W,@/2`S,#L*"F9O<B`H)&D],#L@)&D\/21N=6UR
M;W=S*S([("1I*RLI('L*("`@("1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P
M:'!?;&EM:70@5D%,5453*"=R97-U;'0@)&DG*2(I.PI]"F9O<B`H)&D@/2`P
M.R`D:2`\/2`S.R`D:2LK*2!["B`@("`D9G)O;2`](#$P("H@)&D["B`@("`D
M<F5S(#T@)&1B:"T^;&EM:711=65R>2@B<V5L96-T("H@9G)O;2!P:'!?;&EM
M:70B+"`D9G)O;2P@)&-O=6YT*3L*("`@(&5C:&\@(CT]/3T]/3T@1G)O;3H@
M)&9R;VT@?'P@3G5M8F5R(&]F(')O=W,@=&\@9F5T8V@Z("1C;W5N="`]/3T]
M/3T]7&XB.PH@("`@=VAI;&4@*"1R;W<@/2`D<F5S+3YF971C:%)O=RA$0E]&
M151#2$U/1$5?05-33T,I*2!["B`@("`@("`@96-H;R`D<F5S+3YG9712;W=#
M;W5N=&5R*"D@+B`G+BT@)R`N("1R;W=;)V$G72`N(")<;B(["B`@("!]"GT*
M"@IS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)VEB87-E)SH*
M("`@("`@("`O*@H@("`@("`@("`J($EN=&5R8F%S92!D;V5S;B=T(&%L;&]W
M(&1R;W!P:6YG('1A8FQE<R!T:&%T(&AA=F4@<F5S=6QT"B`@("`@("`@("H@
M<V5T<R!S=&EL;"!O<&5N+@H@("`@("`@("`J+PH@("`@("`@("1D8F@M/F9R
M965297-U;'0H)')E<RT^<F5S=6QT*3L*("`@("`@("!B<F5A:SL*?0HD9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*)&1B:"T^
M<75E<GDH)T123U`@5$%"3$4@<&AP7VQI;6ET)RD["@H_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O<VMI<&EF+FEN
M8P``````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-C(`,3`T,3<S-C,P
M,#,`,#(R,3`U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@IR97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI;F,G.PH*
M:68@*"%I;F-L=61E7V]N8V4@)T1"+G!H<"<I('L*("`@('!R:6YT("=S:VEP
M(&-O=6QD(&YO="!F:6YD($1"+G!H<"<["GT*"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+TQO9R\`````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`S`#`Q-S(R,P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+P``
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C,P,#,`,#(P,S8U`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R],;V<O=&5S=',O<W%L:71E+G!H<'0`````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3(U-P`Q,#0Q-S,V,S`P,P`P,C(U-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2U415-4+2T*3&]G.B!3
M<6QI=&4@2&%N9&QE<@HM+5-+25!)1BTM"CP_<&AP(&EF("@A9G5N8W1I;VY?
M97AI<W1S*"=S<6QI=&5?;W!E;B<I*2!D:64H(G-K:7!<;B(I.R`_/@HM+49)
M3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1F:6QE;F%M
M92`](&1I<FYA;64H7U]&24Q%7U\I("X@1$E214-43U)97U-%4$%2051/4B`N
M("=S<6QI=&4M;&]G+F1B)SL*:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI
M('5N;&EN:R@D9FEL96YA;64I.PH*)&1B(#T@<W%L:71E7V]P96XH)&9I;&5N
M86UE+"`P-C8V+"`D97)R;W(I.PHD:61E;G0@/2!T:6UE*"D["B1M97-S86=E
M(#T@)VQO9V=I;F<@86X@979E;G0G.PHD;&]G9V5R(#TF($QO9SHZ9F%C=&]R
M>2@G<W%L:71E)RP@)VQO9U]T86)L92<L("1I9&5N="P@)&1B*3L*)&QO9V=E
M<BT^;&]G*"1M97-S86=E+"!014%27TQ/1U]705).24Y'*3L*"B1Q(#T@(E-%
M3$5#5"!M97-S86=E($923TT@;&]G7W1A8FQE(%=(15)%(&ED96YT/2<D:61E
M;G0G(CL*)')E<R`]('-Q;&ET95]Q=65R>2@D9&(L("1Q*3L*:68@*'-Q;&ET
M95]F971C:%]S=')I;F<H)')E<RD@/3T@)&UE<W-A9V4I('L*"65C:&\@)V]K
M)SL*?0H*<W%L:71E7V-L;W-E*"1D8BD["FEF("AF:6QE7V5X:7-T<R@D9FEL
M96YA;64I*2!U;FQI;FLH)&9I;&5N86UE*3L*"BTM15A014-4+2T*;VL*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R],;V<O=&5S=',O97AT<F%C="YP:'!T````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,R,@`Q,#0Q-S,V,S`P,P`P,C(W,S``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2U415-4+2T*
M3&]G.B!?97AT<F%C=$UE<W-A9V4H*0HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER
M95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH)VQI;F5&;W)M870G
M(#T^("<E,B1S(%LE,R1S72`E-"1S)RD["B1L;V=G97(@/2`F3&]G.CIS:6YG
M;&5T;VXH)V-O;G-O;&4G+"`G)RP@)VED96YT)RP@)&-O;F8I.PH*+RH@3&]G
M9VEN9R!A(')E9W5L87(@<W1R:6YG+B`J+PHD;&]G9V5R+3YL;V<H)U-T<FEN
M9R<I.PH*+RH@3&]G9VEN9R!A(&)A<F4@;V)J96-T+B`J+PIC;&%S<R!"87)E
M3V)J96-T('M]"B1L;V=G97(M/FQO9RAN97<@0F%R94]B:F5C="@I*3L*"B\J
M($QO9V=I;F<@86X@;V)J96-T('=I=&@@82!G971-97-S86=E*"D@;65T:&]D
M+B`J+PIC;&%S<R!'971-97-S86=E3V)J96-T('L@9G5N8W1I;VX@9V5T365S
M<V%G92@I('L@<F5T=7)N(")G971-97-S86=E(CL@?2!]"B1L;V=G97(M/FQO
M9RAN97<@1V5T365S<V%G94]B:F5C="@I*3L*"B\J($QO9V=I;F<@86X@;V)J
M96-T('=I=&@@82!T;U-T<FEN9R@I(&UE=&AO9"X@*B\*8VQA<W,@5&]3=')I
M;F=/8FIE8W0@>R!F=6YC=&EO;B!T;U-T<FEN9R@I('L@<F5T=7)N(")T;U-T
M<FEN9R([('T@?0HD;&]G9V5R+3YL;V<H;F5W(%1O4W1R:6YG3V)J96-T*"DI
M.PH*+RH@3&]G9VEN9R!A;B!O8FIE8W0@=VET:"!A(%]?=&]3=')I;F<H*2!M
M971H;V0@=7-I;F<@8V%S=&EN9RX@*B\*8VQA<W,@0V%S=&%B;&5/8FIE8W0@
M>R!F=6YC=&EO;B!?7W1O4W1R:6YG*"D@>R!R971U<FX@(E]?=&]3=')I;F<B
M.R!]('T*)&QO9V=E<BT^;&]G*&YE=R!#87-T86)L94]B:F5C="@I*3L*"B\J
M($QO9V=I;F<@82!014%27T5R<F]R(&]B:F5C="X@*B\*<F5Q=6ER95]O;F-E
M("=014%2+G!H<"<["B1L;V=G97(M/FQO9RAN97<@4$5!4E]%<G)O<B@G4$5!
M4E]%<G)O<B!O8FIE8W0G+"`Q,#`I*3L*"B\J($QO9V=I;F<@86X@87)R87DN
M("HO"B1L;V=G97(M/FQO9RAA<G)A>2@Q+"`R+"`G=&AR964G(#T^(#,I*3L*
M"BTM15A014-4+2T*:61E;G0@6VEN9F]=(%-T<FEN9PII9&5N="!;:6YF;UT@
M0F%R94]B:F5C="!/8FIE8W0**`HI"@II9&5N="!;:6YF;UT@9V5T365S<V%G
M90II9&5N="!;:6YF;UT@=&]3=')I;F<*:61E;G0@6VEN9F]=(%]?=&]3=')I
M;F<*:61E;G0@6VEN9F]=(%!%05)?17)R;W(@;V)J96-T"FED96YT(%MI;F9O
M72!!<G)A>0HH"B`@("!;,%T@/3X@,0H@("`@6S%=(#T^(#(*("`@(%MT:')E
M95T@/3X@,PHI"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]P
M<FEO<FET>2YP:'!T````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#8U`#$P
M-#$W,S8S,#`S`#`R,S$T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````M+51%4U0M+0I,;V<Z(%!R:6]R:71I97,*+2U&24Q%
M+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R
M<F%Y*"=L:6YE1F]R;6%T)R`]/B`G6R4S)'-=("4T)',G*3L*)&QO9V=E<B`]
M("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G:61E;G0G+"`D8V]N
M9BD["@HO*B!,;V<@870@=&AE(&1E9F%U;'0@4$5!4E],3T=?24Y&3R!L979E
M;"X@*B\*)&QO9V=E<BT^;&]G*"=,;V<@;65S<V%G92<I.PH*+RH@4V5T('1H
M92!D969A=6QT('!R:6]R:71Y('1O(%!%05)?3$]'7T1%0E5'+B`J+PHD;&]G
M9V5R+3YS9710<FEO<FET>2A014%27TQ/1U]$14)51RD["B1L;V=G97(M/FQO
M9R@G3&]G(&UE<W-A9V4G*3L*"B\J(%9E<FEF>2!T:&%T('1H92!G9710<FEO
M<FET>2@I(&UE=&AO9"!A;'-O('1H:6YG<R!W92=R92!A="!014%27TQ/1U]$
M14)51RX@*B\*96-H;R`D;&]G9V5R+3YP<FEO<FET>51O4W1R:6YG*"1L;V=G
M97(M/F=E=%!R:6]R:71Y*"DI("X@(EQN(CL*"BTM15A014-4+2T*6VEN9F]=
M($QO9R!M97-S86=E"EMD96)U9UT@3&]G(&UE<W-A9V4*9&5B=6<*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T
M97-T<R]E<G)O<E]L;V<N<&AP=```````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#(S`#$P-#$W,S8S,#`S`#`R,S(U,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+51%4U0M+0I,;V<Z($5R<F]R7TQO9R!(
M86YD;&5R"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G
M.PH*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G97)R;W)?;&]G)RP@4$5!
M4E],3T=?5%E015]365-414TL("=I9&5N="<I.PIF;W(@*"1I(#T@,#L@)&D@
M/"`S.R`D:2LK*2!["@DD;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]
M"@HM+4584$5#5"TM"FED96YT.B!,;V<@96YT<GD@,`II9&5N=#H@3&]G(&5N
M=')Y(#$*:61E;G0Z($QO9R!E;G1R>2`R"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O8V]M<&]S
M:71E+G!H<'0`````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`U-0`Q,#0Q-S,V
M,S`P,P`P,C,R-C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*3&]G.B!#;VUP;W-I=&4@2&%N9&QE<@HM+49)
M3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@
M87)R87DH)VQI;F5&;W)M870G(#T^("<E,B1S(%LE,R1S72`E-"1S)RD["B1C
M;VYS;VQE,2`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G0T].
M4T],13$G+"`D8V]N9BD["B1C;VYS;VQE,B`]("9,;V<Z.G-I;F=L971O;B@G
M8V]N<V]L92<L("<G+"`G0T].4T],13(G+"`D8V]N9BD["@HD8V]M<&]S:71E
M(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VUP;W-I=&4G*3L*)&-O;7!O<VET92T^
M861D0VAI;&0H)&-O;G-O;&4Q*3L*)&-O;7!O<VET92T^861D0VAI;&0H)&-O
M;G-O;&4R*3L*"B1C;VUP;W-I=&4M/FQO9R@G5&AI<R!E=F5N="!W:6QL(&)E
M(&QO9V=E9"!T;R!B;W1H(&AA;F1L97)S+B<I.PH*+2U%6%!%0U0M+0I#3TY3
M3TQ%,2!;:6YF;UT@5&AI<R!E=F5N="!W:6QL(&)E(&QO9V=E9"!T;R!B;W1H
M(&AA;F1L97)S+@I#3TY33TQ%,B!;:6YF;UT@5&AI<R!E=F5N="!W:6QL(&)E
M(&QO9V=E9"!T;R!B;W1H(&AA;F1L97)S+@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O
M<VEN9VQE=&]N+G!H<'0`````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8R-P`Q
M,#0Q-S,V,S`P,P`P,C,R-C8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*3&]G.B!3:6YG;&5T;VX*+2U&24Q%
M+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N<V]L93$@
M/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G*3L*)&-O;G-O;&4R(#T@)DQO
M9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RD["@II9B`H:7-?82@D8V]N<V]L93$L
M("=,;V=?8V]N<V]L92<I("8F(&ES7V$H)&-O;G-O;&4R+"`G3&]G7V-O;G-O
M;&4G*2D*>PH)96-H;R`B5'=O($QO9U]C;VYS;VQE(&]B:F5C=',N7&XB.PI]
M"@II9B`H)&-O;G-O;&4Q+3Y?:60@/3T@)&-O;G-O;&4R+3Y?:60I('L*"65C
M:&\@(E1H92!O8FIE8W1S(&AA=F4@=&AE('-A;64@240N7&XB.PI]"@HM+458
M4$5#5"TM"E1W;R!,;V=?8V]N<V]L92!O8FIE8W1S+@I4:&4@;V)J96-T<R!H
M879E('1H92!S86UE($E$+@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V9A8W1O<GDN<&AP
M=```````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,C4`,3`T,3<S-C,P,#,`
M,#(R-S,Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM5$535"TM"DQO9SH@1F%C=&]R>0HM+49)3$4M+0H\/W!H<`H*<F5Q
M=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYS;VQE,2`]("9,;V<Z.F9A8W1O
M<GDH)V-O;G-O;&4G*3L*)&-O;G-O;&4R(#T@)DQO9SHZ9F%C=&]R>2@G8V]N
M<V]L92<I.PH*:68@*&ES7V$H)&-O;G-O;&4Q+"`G3&]G7V-O;G-O;&4G*2`F
M)B!I<U]A*"1C;VYS;VQE,BP@)TQO9U]C;VYS;VQE)RDI"GL*"65C:&\@(E1W
M;R!,;V=?8V]N<V]L92!O8FIE8W1S+EQN(CL*?0H*:68@*"1C;VYS;VQE,2T^
M7VED("$]("1C;VYS;VQE,BT^7VED*2!["@EE8VAO(")4:&4@;V)J96-T<R!H
M879E(&1I9F9E<F5N="!)1',N7&XB.PI]"@HM+4584$5#5"TM"E1W;R!,;V=?
M8V]N<V]L92!O8FIE8W1S+@I4:&4@;V)J96-T<R!H879E(&1I9F9E<F5N="!)
M1',N"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+TQO9R]T97-T<R]C;VYS;VQE+G!H<'0`````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#(W`#$P-#$W,S8S,#`S`#`R,C<R,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+51%4U0M
M+0I,;V<Z($-O;G-O;&4@2&%N9&QE<@HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER
M95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH)VQI;F5&;W)M870G
M(#T^("<E,B1S(%LE,R1S72`E-"1S)RD["B1L;V=G97(@/2`F3&]G.CIS:6YG
M;&5T;VXH)V-O;G-O;&4G+"`G)RP@)VED96YT)RP@)&-O;F8I.PIF;W(@*"1I
M(#T@,#L@)&D@/"`S.R`D:2LK*2!["@DD;&]G9V5R+3YL;V<H(DQO9R!E;G1R
M>2`D:2(I.PI]"@IE8VAO(")<;EM"=69F97)I;F<@+R!&;'5S:"!497-T75QN
M(CL*)&-O;F8@/2!A<G)A>2@G;&EN949O<FUA="<@/3X@)R4R)',@6R4S)'-=
M("4T)',G+"`G8G5F9F5R:6YG)R`]/B!T<G5E*3L*)&)U9F9E<F5D7VQO9V=E
M<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G8G5F9F5R960G
M+"`D8V]N9BD["F9O<B`H)&D@/2`P.R`D:2`\(#,[("1I*RLI('L*("`@("`@
M("`D8G5F9F5R961?;&]G9V5R+3YL;V<H(D)U9F9E<F5D(&QO9R!E;G1R>2`D
M:2(I.PI]"F5C:&\@(E!R92UF;'5S:%QN(CL*)&)U9F9E<F5D7VQO9V=E<BT^
M9FQU<V@H*3L*96-H;R`B4&]S="UF;'5S:%QN(CL*9F]R("@D:2`](#`[("1I
M(#P@,SL@)&DK*RD@>PH@("`@("`@("1B=69F97)E9%]L;V=G97(M/FQO9R@B
M0G5F9F5R960@;&]G(&5N=')Y("1I(BD["GT*)&)U9F9E<F5D7VQO9V=E<BT^
M8VQO<V4H*3L*"BTM15A014-4+2T*:61E;G0@6VEN9F]=($QO9R!E;G1R>2`P
M"FED96YT(%MI;F9O72!,;V<@96YT<GD@,0II9&5N="!;:6YF;UT@3&]G(&5N
M=')Y(#(*"EM"=69F97)I;F<@+R!&;'5S:"!497-T70I0<F4M9FQU<V@*8G5F
M9F5R960@6VEN9F]=($)U9F9E<F5D(&QO9R!E;G1R>2`P"F)U9F9E<F5D(%MI
M;F9O72!"=69F97)E9"!L;V<@96YT<GD@,0IB=69F97)E9"!;:6YF;UT@0G5F
M9F5R960@;&]G(&5N=')Y(#(*4&]S="UF;'5S:`IB=69F97)E9"!;:6YF;UT@
M0G5F9F5R960@;&]G(&5N=')Y(#`*8G5F9F5R960@6VEN9F]=($)U9F9E<F5D
M(&QO9R!E;G1R>2`Q"F)U9F9E<F5D(%MI;F9O72!"=69F97)E9"!L;V<@96YT
M<GD@,@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S
M+VYU;&PN<&AP=```````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R-C$`
M,3`T,3<S-C,P,#,`,#(R,C,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM5$535"TM"DQO9SH@3G5L;"!(86YD;&5R"BTM
M1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&QO9V=E
M<B`]("9,;V<Z.G-I;F=L971O;B@G;G5L;"<I.PIF;W(@*"1I(#T@,#L@)&D@
M/"`S.R`D:2LK*2!["@DD;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]
M"@HM+4584$5#5"TM"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]D:7-P;&%Y+G!H
M<'0``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C`T`#$P-#$W,S8S,#`S
M`#`R,C<R-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+51%4U0M+0I,;V<Z($1I<W!L87D@2&%N9&QE<@HM+49)3$4M+0H\
M/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH
M)V5R<F]R7W!R97!E;F0G(#T^("<\='0^)RP@)V5R<F]R7V%P<&5N9"<@(#T^
M("<\+W1T/B<I.PHD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=D:7-P;&%Y
M)RP@)R<L("<G+"`D8V]N9BD["F9O<B`H)&D@/2`P.R`D:2`\(#,[("1I*RLI
M('L*"21L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*"BTM15A014-4
M+2T*/'1T/CQB/DEN9F\\+V(^.B!,;V<@96YT<GD@,#PO='0^/&)R("\^"CQT
M=#X\8CY);F9O/"]B/CH@3&]G(&5N=')Y(#$\+W1T/CQB<B`O/@H\='0^/&(^
M26YF;SPO8CXZ($QO9R!E;G1R>2`R/"]T=#X\8G(@+SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]$871E+P``````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P,P`P,3<S-3<`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8S,#`S`#`R,#4R,0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1&%T92]T97-T<R]T97-T7V1A=&5?;65T:&]D<U]S<&%N+G!H<```````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#4T-C0`,3`T,3<S-C,P,#,`,#(U-S8P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP("`@(`HO+R!V:6TZ
M('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-O9G1T86)S=&]P/30@<VAI9G1W
M:61T:#TT.@HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!0
M2%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!!=71H;W(Z($QE86YD<F\@3'5C87)E;&QA(#QL;'5C87A`
M<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('1E<W1?9&%T95]M
M971H;V1S7W-P86XN<&AP+'8@,2XQ(#(P,#,O,#0O,C<@,#,Z-#(Z,3<@;&QU
M8V%X($5X<"`D"B\O"@IR97%U:7)E7V]N8V4@)T1A=&4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=$871E+U-P86XN<&AP)SL*"B1D871E(#T@;F5W($1A=&4H*3L*
M)'1M<"`](&YE=R!$871E*"1D871E*3L*"G!R:6YT9B@B06-T=6%L(&1A=&4Z
M("5S7&XB+"`D9&%T92T^9V5T1&%T92A$051%7T9/4DU!5%])4T\I*3L*"B1T
M;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YS=6)T<F%C=%-P86XH;F5W($1A=&5?
M4W!A;B@G,#HP,#HP,#HP-2<I*3L*<')I;G1F*")3=6)T<F%C=&EN9R`U('-E
M8V]N9',Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%47TE33RDI
M.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/G-U8G1R86-T4W!A;BAN97<@
M1&%T95]3<&%N*"<P.C`P.C(P.C`P)RDI.PIP<FEN=&8H(E-U8G1R86-T:6YG
M(#(P(&UI;G5T97,Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%4
M7TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/G-U8G1R86-T4W!A
M;BAN97<@1&%T95]3<&%N*"<P.C$P.C`P.C`P)RDI.PIP<FEN=&8H(E-U8G1R
M86-T:6YG(#$P(&AO=7)S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$051%7T9/
M4DU!5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YS=6)T<F%C
M=%-P86XH;F5W($1A=&5?4W!A;B@G,SHP,#HP,#HP,"<I*3L*<')I;G1F*")3
M=6)T<F%C=&EN9R`S(&1A>7,Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?
M1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/G-U8G1R
M86-T4W!A;BAN97<@1&%T95]3<&%N*"<S.C$P.C(P.C`U)RDI.PIP<FEN=&8H
M(E-U8G1R86-T:6YG(#,@9&%Y<RP@,3`@:&]U<G,L(#(P(&UI;G5T97,@86YD
M(#4@<V5C;VYD<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H1$%415]&3U)-051?
M25-/*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^861D4W!A;BAN97<@
M1&%T95]3<&%N*"<P.C`P.C`P.C`U)RDI.PIP<FEN=&8H(D%D9&EN9R`U('-E
M8V]N9',Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%47TE33RDI
M.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/F%D9%-P86XH;F5W($1A=&5?
M4W!A;B@G,#HP,#HR,#HP,"<I*3L*<')I;G1F*")!9&1I;F<@,C`@;6EN=71E
M<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H1$%415]&3U)-051?25-/*2D["@HD
M=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^861D4W!A;BAN97<@1&%T95]3<&%N
M*"<P.C$P.C`P.C`P)RDI.PIP<FEN=&8H(D%D9&EN9R`Q,"!H;W5R<SH@)7-<
M;B(L("1T;7`M/F=E=$1A=&4H1$%415]&3U)-051?25-/*2D["@HD=&UP+3YC
M;W!Y*"1D871E*3L*)'1M<"T^861D4W!A;BAN97<@1&%T95]3<&%N*"<S.C`P
M.C`P.C`P)RDI.PIP<FEN=&8H(D%D9&EN9R`S(&1A>7,Z("5S7&XB+"`D=&UP
M+3YG971$871E*$1!5$5?1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T
M92D["B1T;7`M/F%D9%-P86XH;F5W($1A=&5?4W!A;B@G,SHQ,#HR,#HP-2<I
M*3L*<')I;G1F*")!9&1I;F<@,R!D87ES+"`Q,"!H;W5R<RP@,C`@;6EN=71E
M<R!A;F0@-2!S96-O;F1S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$051%7T9/
M4DU!5%])4T\I*3L*"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W1E
M<W1U;FET7V1A=&5?<W!A;BYP:'``````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C<W-@`Q,#0Q
M-S,V,S`P,P`P,C4Q-#$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@3&5A;F1R;R!,=6-A
M<F5L;&$@/&QL=6-A>$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)
M9#H@=&5S='5N:71?9&%T95]S<&%N+G!H<"QV(#$N,R`R,#`S+S$P+S(T(#$Y
M.C0Q.C`V(&UR;V-H($5X<"`D"B\O"@IR97%U:7)E7V]N8V4@)T1A=&4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=$871E+U-P86XN<&AP)SL*<F5Q=6ER95]O;F-E
M("=02%!5;FET+G!H<"<["@HO*BH*("H@5&5S="!C87-E(&9O<B!$871E7U-P
M86X*("H*("H@0'!A8VMA9V4@1&%T90H@*B!`875T:&]R($QE86YD<F\@3'5C
M87)E;&QA(#QL;'5C87A`<&AP+FYE=#X*("HO"F-L87-S($1A=&5?4W!A;E1E
M<W0@97AT96YD<R!02%!5;FET7U1E<W1#87-E('L*"B`@("!V87(@)'1I;64[
M"@H@("`@9G5N8W1I;VX@1&%T95]3<&%N5&5S="@D;F%M92D@>PH@("`@("`@
M("1T:&ES+3Y02%!5;FET7U1E<W1#87-E*"1N86UE*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!S9715<"@I('L*("`@("`@("`D=&AI<RT^=&EM92`](&YE=R!$
M871E7U-P86XH.3<U,S$I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E87)$;W=N
M*"D@>PH@("`@("`@('5N<V5T*"1T:&ES+3YT:6UE*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!T97-T4V5T1G)O;4%R<F%Y*"D@>PH@("`@("`@("1T:&ES+3YT
M:6UE+3YS971&<F]M07)R87DH87)R87DH-2P@-#@N-2P@,C@N-2P@,S$I*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G-SHP
M.C4Y.C$G+`H@("`@("`@("`@("!S<')I;G1F*"<E9#HE9#HE9#HE9"<L("1T
M:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH;W5R+`H@("`@("`@("`@
M("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E8V]N
M9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13971&<F]M
M4W1R:6YG*"D@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971&<F]M4W1R:6YG
M*"<U.C`P.C4Y.C,Q)RD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*
M("`@("`@("`@("`@)S4Z,#HU.3HS,2<L"B`@("`@("`@("`@('-P<FEN=&8H
M)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A>2P@)'1H:7,M/G1I;64M
M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^;6EN=71E+"`D
M=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&5S=%-E=$9R;VU396-O;F1S*"D@>PH@("`@("`@("1T:&ES+3YT
M:6UE+3YS971&<F]M4V5C;VYD<R@T,S0S-#0I.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H"B`@("`@("`@("`@("<U.C`Z,SDZ-"<L"B`@("`@("`@
M("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A>2P@
M)'1H:7,M/G1I;64M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM
M92T^;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@
M("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E=$9R;VU-:6YU=&5S*"D@>PH@("`@
M("`@("1T:&ES+3YT:6UE+3YS971&<F]M36EN=71E<R@W.#8P+C`Q-C8V-C8V
M-C8I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@
M("<U.C$Q.C`Z,2<L"B`@("`@("`@("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D
M)RP@)'1H:7,M/G1I;64M/F1A>2P@)'1H:7,M/G1I;64M/FAO=7(L"B`@("`@
M("`@("`@("`@("`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM92T^
M<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E
M=$9R;VU(;W5R<R@I('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T1G)O;4AO
M=7)S*#4P+C$R,S0U*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@
M("`@("`@("`@("`G,CHR.C<Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E
M9#HE9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH
M;W5R+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H
M:7,M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1E<W13971&<F]M1&%Y<R@I('L*("`@("`@("`D=&AI<RT^=&EM92T^
M<V5T1G)O;41A>7,H<&DH*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@*("`@("`@("`@("`@)S,Z,SHR,SHU-"<L"B`@("`@("`@("`@('-P<FEN
M=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A>2P@)'1H:7,M/G1I
M;64M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^;6EN=71E
M+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@
M9G5N8W1I;VX@=&5S=%-E=$9R;VU$871E1&EF9B@I('L*("`@("`@("`D=&AI
M<RT^=&EM92T^<V5T1G)O;41A=&5$:69F*`H@("`@("`@("`@("!N97<@1&%T
M92@G,C`P-"TP,RTQ,"`P,3HQ-3HU.2<I+`H@("`@("`@("`@("!N97<@1&%T
M92@G,C`P,RTP,RTQ,"`P,#HQ,#HU,"<I"B`@("`@("`@*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,S8V.C$Z-3HY)RP*
M("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^=&EM
M92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@("1T
M:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@
M("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T0V]P>2@I('L*("`@("`@
M("`D=&EM92`](&YE=R!$871E7U-P86XH*3L*("`@("`@("`D=&EM92T^8V]P
M>2@D=&AI<RT^=&EM92D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*
M("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^=&EM
M92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@("1T
M:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I+`H@("`@
M("`@("`@("!S<')I;G1F*"<E9#HE9#HE9#HE9"<L("1T:6UE+3YD87DL("1T
M:6UE+3YH;W5R+`H@("`@("`@("`@("`@("`@)'1I;64M/FUI;G5T92P@)'1I
M;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E
M<W1&;W)M870H*2!["B`@("`@("`@)&-O9&5S(#T@87)R87DH"B`@("`@("`@
M("`@("=#)R`]/B`G,2P@,#,Z,#4Z,S$G+`H@("`@("`@("`@("`G9"<@/3X@
M)S$N,3(X.#,Q,#$X-3$X-2<L"B`@("`@("`@("`@("=$)R`]/B`G,2<L"B`@
M("`@("`@("`@("=E)R`]/B`G,C<N,#DQ.30T-#0T-#0T)RP*("`@("`@("`@
M("`@)V8G(#T^("<Q-C(U+C4Q-C8V-C8V-C<G+`H@("`@("`@("`@("`G9R<@
M/3X@)SDW-3,Q)RP*("`@("`@("`@("`@)V@G(#T^("<S)RP*("`@("`@("`@
M("`@)T@G(#T^("<P,R<L"B`@("`@("`@("`@("=I)R`]/B`G,R<L"B`@("`@
M("`@("`@("=))R`]/B`G,#,G+`H@("`@("`@("`@("`G;2<@/3X@)S4G+`H@
M("`@("`@("`@("`G32<@/3X@)S`U)RP*("`@("`@("`@("`@)VXG(#T^(")<
M;B(L"B`@("`@("`@("`@("=P)R`]/B`G86TG+`H@("`@("`@("`@("`G4"<@
M/3X@)T%-)RP*("`@("`@("`@("`@)W(G(#T^("<P,SHP-3HS,2!A;2<L"B`@
M("`@("`@("`@("=2)R`]/B`G,#,Z,#4G+`H@("`@("`@("`@("`G<R<@/3X@
M)S,Q)RP*("`@("`@("`@("`@)U,G(#T^("<S,2<L"B`@("`@("`@("`@("=T
M)R`]/B`B7'0B+`H@("`@("`@("`@("`G5"<@/3X@)S`S.C`U.C,Q)RP*("`@
M("`@("`@("`@)R4G(#T^("<E)RP*("`@("`@("`I.PH@("`@("`@(&9O<F5A
M8V@@*"1C;V1E<R!A<R`D8V]D92`]/B`D97AP96-T960I('L*("`@("`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@("`@("(D8V]D
M93H@)&5X<&5C=&5D(BP@)'1H:7,M/G1I;64M/F9O<FUA="@B)&-O9&4Z("4D
M8V]D92(I"B`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N('1E<W1!9&0H*2!["B`@("`@("`@)'1H:7,M/G1I;64M/F%D9"AN
M97<@1&%T95]3<&%N*#8P,#`I*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/G1I;64M/G1O4V5C;VYD<R@I.PH@("`@("`@("1E>'!E8W1E9"`](#$P,S4S
M,3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1E>'!E8W1E9"P@)')E
M<W5L="D[(`H@("`@?0H*("`@(&9U;F-T:6]N('1E<W13=6)T<F%C="@I('L*
M("`@("`@("`D=&AI<RT^=&EM92T^<W5B=')A8W0H;F5W($1A=&5?4W!A;B@V
M,#`P*2D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YT:6UE+3YT;U-E8V]N
M9',H*3L*("`@("`@("`D97AP96-T960@/2`Y,34S,3L*("`@("`@("`D=&AI
M<RT^87-S97)T17%U86QS*"1E>'!E8W1E9"P@)')E<W5L="D[(`H@("`@?0H*
M?0H*+R\@<G5N<R!T:&4@=&5S=',*)'-U:71E(#T@;F5W(%!(4%5N:71?5&5S
M=%-U:71E*")$871E7U-P86Y497-T(BD["B1R97-U;'0@/2!02%!5;FET.CIR
M=6XH)'-U:71E*3L*+R\@<')I;G1S('1H92!T97-T<PIE8VAO("1R97-U;'0M
M/G1O4W1R:6YG*"D["@H_/@H``"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$871E+W1E<W1S+W1E<W1?8V%L8RYP:'``````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C4P,``Q,#0Q-S,V,S`P,P`P,C,Q-C4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*<F5Q
M=6ER95]O;F-E(")$871E+T-A;&,N<&AP(CL*"B\J*@H@*B!497-T(&1A=&5S
M(&9R;VT@,3DW,"!T;R`R,#(Y"B`J($1A=&$@9G)O;3H@:'1T<#HO+W=W=RYM
M97)L>6XN9&5M;VXN8V\N=6LO=VMN;W1E<W0N='AT"B`J($]T:&5R<R!U<V5F
M=6QL(&1A=&%S(&%V86EL86)L92!F<F]M.@H@*B!H='1P.B\O=W=W+FUE<FQY
M;BYD96UO;BYC;RYU:R\C9&%T"B`J+PHD9F%I;&5D7W1E<W1?9&%T82`@(#T@
M9F%L<V4["B1W:VYO("`@/2!F:6QE*"=W:VYO=&5S="YT>'0G*3L*)&-N="`@
M("`]('-I>F5O9B@D=VMN;RD["F9O<B@@)&D],#LD:3PD8VYT.R1I*RL@*7L*
M("`@("1P87)T<R`@("`@(#T@97AP;&]D92@G.B<L)'=K;F];)&E=*3L*("`@
M("1W965K<VYO6R1P87)T<ULP75T@/2!S=')?<F5P;&%C92@B7&XB+"<G+"1P
M87)T<ULQ72D["GT*=6YS970H)'=K;F\I.PIF;W)E86-H*"1W965K<VYO(&%S
M("1D871E/3XD:7-O*7L*("`@("1Y96%R("`@("`@(#T@<W5B<W1R*"1D871E
M+#`L-"D["B`@("`D;6]N=&@@("`@("`]('-U8G-T<B@D9&%T92PT+#(I.PH@
M("`@)&1A>2`@("`@("`@/2!S=6)S='(H)&1A=&4L-BD["B`@("`D:7-O.38P
M,2`]($1A=&5?0V%L8SHZ9W)E9V]R:6%N5&])4T\H)&1A>2PD;6]N=&@L)'EE
M87(I.PH@("`@:68H)&ES;SDV,#$A/21I<V\I>PH@("`@("`@("1F86EL961?
M=&5S=%]D871A("`@/2!T<G5E.PH@("`@("`@(&5C:&\@)&1A=&4@+B`G*"<@
M+B`D:7-O("X@)RD@/3XG("X@)'EE87(N)RTG+B1M;VYT:"XG+2<N)&1A>2`N
M)ST^)R`N("1I<V\Y-C`Q("X@(B`Z(&9A:6QE9%QN(CL*("`@('T*?0H*+RHJ
M"B`J($)U9W,@(S$Y-S@X"B`J+PHD9F%I;&5D7W1E<W1?,3DW.#@@(#T@9F%L
M<V4["B1P87-S,2`@/2`R/3U$871E7T-A;&,Z.G=E96M/9EEE87(H-2PQ+#$Y
M.3@I/W1R=64Z9F%L<V4["B1P87-S,B`@/2`R/3U$871E7T-A;&,Z.G=E96M/
M9EEE87(H-BPQ+#$Y.3@I/W1R=64Z9F%L<V4["B1P87-S,R`@/2`R/3U$871E
M7T-A;&,Z.G=E96M/9EEE87(H-2PQ+#(P,#0I/W1R=64Z9F%L<V4["B1P87-S
M-"`@/2`R/3U$871E7T-A;&,Z.G=E96M/9EEE87(H-BPQ+#(P,#0I/W1R=64Z
M9F%L<V4["FEF*"`A*"1P87-S,2`F)B`D<&%S<S(@)B8@)'!A<W,S("8F("1P
M87-S-"D@*7L*("`@("1F86EL961?=&5S=%\Q.3<X."`@(#T@=')U93L*("`@
M(&5C:&\@(E1E<W0@0G5G(#$Y-S@X(&9A:6QE9"Y<;B(["GT*"FEF*"1F86EL
M961?=&5S=%\Q.3<X."!\?"`D9F%I;&5D7W1E<W1?9&%T82E["B`@("!E8VAO
M(")497-T<R!F86EL961<;B(["GT@96QS92!["B`@("!E8VAO(")%;F0@=&5S
M="P@<W5C8V5S9G5L;'D@<&%S<V5D7&XB.PI]"C\^````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O
M=&5S='5N:71?9&%T92YP:'``````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P,#4T`#$P
M-#$W,S8S,#`S`#`R-#$P-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO+R!V:6TZ('-E="!E>'!A;F1T86(@=&%B
M<W1O<#TT('-O9G1T86)S=&]P/30@<VAI9G1W:61T:#TT.@HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z
M($UA<G-H86QL(%)O8V@@/&UR;V-H0'!H<"YN970^("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+PHO+R`D260Z('1E<W1U;FET7V1A=&4N<&AP+'8@,2XR(#(P,#,O
M,3(O,#D@,3(Z,#DZ,S(@<&%J;WEE($5X<"`D"B\O"@IR97%U:7)E7V]N8V4@
M)T1A=&4N<&AP)SL*<F5Q=6ER95]O;F-E("=02%!5;FET+G!H<"<["@IC;&%S
M<R!M>41A=&4@97AT96YD<R!$871E('L*("`@(&9U;F-T:6]N(&UY1&%T92@D
M9&%T92D*("`@('L*("`@("`@("`D=&AI<RT^1&%T92@D9&%T92D["B`@("!]
M"GT*"B\J*@H@*B!497-T(&-A<V4@9F]R($1A=&4*("H*("H@0'!A8VMA9V4@
M1&%T90H@*B!`875T:&]R($UA<G-H86QL(%)O8V@@/&UR;V-H0'!H<"YN970^
M"B`J+PIC;&%S<R!$871E7U1E<W0@97AT96YD<R!02%!5;FET7U1E<W1#87-E
M('L*"B`@("!V87(@)'1I;64["@H@("`@9G5N8W1I;VX@1&%T95]497-T*"1N
M86UE*0H@("`@>PH@("`@("`@("1T:&ES+3Y02%!5;FET7U1E<W1#87-E*"1N
M86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!S9715<"@I"B`@("!["B`@("`@
M("`@)'1H:7,M/G1I;64@/2!N97<@1&%T92@B,C`P,RTQ,"TP-"`Q-#HP,SHR
M-"(I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E87)$;W=N*"D*("`@('L*("`@
M("`@("!U;G-E="@D=&AI<RT^=&EM92D["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&5S=$1A=&5.=6QL*"D*("`@('L*("`@("`@("`D=&EM92`](&YE=R!$871E
M*"D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@
M9&%T92@G62UM+60@2#II.G,G*2P*("`@("`@("`@("`@<W!R:6YT9B@G)3`T
M9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@
M)'1I;64M/GEE87(L("1T:6UE+3YM;VYT:"P@)'1I;64M/F1A>2P*("`@("`@
M("`@("`@("`@("1T:6UE+3YH;W5R+"`D=&EM92T^;6EN=71E+"`D=&EM92T^
M<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$%B
M<W1R86-T:6]N*"D*("`@('L*("`@("`@("`D9"`](&YE=R!$871E*"D["B`@
M("`@("`@)&UY(#T@;F5W(&UY1&%T92@D9"D["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@D9"T^9V5T1&%T92@I+"1M>2T^9V5T1&%T92@I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!T97-T1&%T94-O<'DH*0H@("`@>PH@("`@("`@
M("1T96UP(#T@;F5W($1A=&4H)'1H:7,M/G1I;64I.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)'1E;7`L("1T:&ES+3YT:6UE*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!T97-T1&%T94E33R@I"B`@("!["B`@("`@("`@)'1E;7`@
M/2!N97<@1&%T92@B,C`P,RTQ,"TP-"`Q-#HP,SHR-"(I.PH@("`@("`@("1T
M:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R,#`S+3$P+3`T(#$T
M.C`S.C(T)RP*("`@("`@("`@("`@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@
M)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@)'1E;7`M/GEE87(L
M("1T96UP+3YM;VYT:"P@)'1E;7`M/F1A>2P*("`@("`@("`@("`@("`@("1T
M96UP+3YH;W5R+"`D=&5M<"T^;6EN=71E+"`D=&5M<"T^<V5C;VYD*0H@("`@
M("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$1A=&5)4T]"87-I8R@I
M"B`@("!["B`@("`@("`@)'1E;7`@/2!N97<@1&%T92@B,C`P,S$P,#14,30P
M,S(T(BD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@
M("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F
M*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@
M("`@("`D=&5M<"T^>65A<BP@)'1E;7`M/FUO;G1H+"`D=&5M<"T^9&%Y+`H@
M("`@("`@("`@("`@("`@)'1E;7`M/FAO=7(L("1T96UP+3YM:6YU=&4L("1T
M96UP+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T
M97-T1&%T94E33T5X=&5N9&5D*"D*("`@('L*("`@("`@("`D=&5M<"`](&YE
M=R!$871E*"(R,#`S+3$P+3`T5#$T.C`S.C(T(BD["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z
M,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D
M.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&5M<"T^>65A<BP@)'1E
M;7`M/FUO;G1H+"`D=&5M<"T^9&%Y+`H@("`@("`@("`@("`@("`@)'1E;7`M
M/FAO=7(L("1T96UP+3YM:6YU=&4L("1T96UP+3YS96-O;F0I"B`@("`@("`@
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1&%T94E33U1I;65S=&%M<"@I
M"B`@("!["B`@("`@("`@)'1E;7`@/2!N97<@1&%T92@B,C`P,S$P,#0Q-#`S
M,C0B*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@
M("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P<FEN=&8H
M)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@
M("`@("1T96UP+3YY96%R+"`D=&5M<"T^;6]N=&@L("1T96UP+3YD87DL"B`@
M("`@("`@("`@("`@("`D=&5M<"T^:&]U<BP@)'1E;7`M/FUI;G5T92P@)'1E
M;7`M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E
M<W1$871E56YI>'1I;64H*0H@("`@>PH@("`@("`@("1T96UP(#T@;F5W($1A
M=&4H<W1R=&]T:6UE*"(R,#`S+3$P+3`T(#$T.C`S.C(T(BDI.PH@("`@("`@
M("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R,#`S+3$P+3`T
M(#$T.C`S.C(T)RP*("`@("`@("`@("`@<W!R:6YT9B@G)3`T9"TE,#)D+24P
M,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@)'1E;7`M/GEE
M87(L("1T96UP+3YM;VYT:"P@)'1E;7`M/F1A>2P*("`@("`@("`@("`@("`@
M("1T96UP+3YH;W5R+"`D=&5M<"T^;6EN=71E+"`D=&5M<"T^<V5C;VYD*0H@
M("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E=$1A=&5)4T\H
M*0H@("`@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971$871E*"(R,#`S+3$P
M+3`T(#$T.C`S.C(T(BD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*
M("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@
M("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@
M("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^>65A<BP@)'1H:7,M/G1I;64M
M/FUO;G1H+"`D=&AI<RT^=&EM92T^9&%Y+`H@("`@("`@("`@("`@("`@)'1H
M:7,M/G1I;64M/FAO=7(L("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT
M:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T
M97-T4V5T1&%T94E33T)A<VEC*"D*("`@('L*("`@("`@("`D=&AI<RT^=&EM
M92T^<V5T1&%T92@B,C`P,S$P,#14,30P,S(T(BD["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z
M,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D
M.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^>65A
M<BP@)'1H:7,M/G1I;64M/FUO;G1H+"`D=&AI<RT^=&EM92T^9&%Y+`H@("`@
M("`@("`@("`@("`@)'1H:7,M/G1I;64M/FAO=7(L("1T:&ES+3YT:6UE+3YM
M:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T4V5T1&%T94E33T5X=&5N9&5D*"D*("`@('L*
M("`@("`@("`D=&AI<RT^=&EM92T^<V5T1&%T92@B,C`P,RTQ,"TP-%0Q-#HP
M,SHR-"(I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@
M("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T)RP*("`@("`@("`@("`@<W!R:6YT
M9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@
M("`@("`@)'1H:7,M/G1I;64M/GEE87(L("1T:&ES+3YT:6UE+3YM;VYT:"P@
M)'1H:7,M/G1I;64M/F1A>2P*("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE
M+3YH;W5R+"`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C
M;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E=$1A
M=&54:6UE<W1A;7`H*0H@("`@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971$
M871E*"(R,#`S,3`P-#$T,#,R-"(I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H"B`@("`@("`@("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T)RP*("`@
M("`@("`@("`@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P
M,F0G+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/GEE87(L("1T:&ES
M+3YT:6UE+3YM;VYT:"P@)'1H:7,M/G1I;64M/F1A>2P*("`@("`@("`@("`@
M("`@("1T:&ES+3YT:6UE+3YH;W5R+"`D=&AI<RT^=&EM92T^;6EN=71E+"`D
M=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&5S=%-E=$1A=&55;FEX=&EM92@I"B`@("!["B`@("`@("`@)'1H
M:7,M/G1I;64M/G-E=$1A=&4H<W1R=&]T:6UE*"(R,#`S+3$P+3`T(#$T.C`S
M.C(T(BDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@
M("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T)RP*("`@("`@("`@("`@<W!R:6YT
M9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@
M("`@("`@)'1H:7,M/G1I;64M/GEE87(L("1T:&ES+3YT:6UE+3YM;VYT:"P@
M)'1H:7,M/G1I;64M/F1A>2P*("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE
M+3YH;W5R+"`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C
M;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$=E=$1A
M=&5)4T\H*0H@("`@>PH@("`@("`@("1D871E(#T@)'1H:7,M/G1I;64M/F=E
M=$1A=&4H1$%415]&3U)-051?25-/*3L*("`@("`@("`D=&AI<RT^87-S97)T
M17%U86QS*"<R,#`S+3$P+3`T(#$T.C`S.C(T)RP@)&1A=&4I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1E<W1'971$871E25-/0F%S:6,H*0H@("`@>PH@("`@
M("`@("1D871E(#T@)'1H:7,M/G1I;64M/F=E=$1A=&4H1$%415]&3U)-051?
M25-/7T)!4TE#*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<R,#`S
M,3`P-%0Q-#`S,C1:)RP@)&1A=&4I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E
M<W1'971$871E25-/17AT96YD960H*0H@("`@>PH@("`@("`@("1D871E(#T@
M)'1H:7,M/G1I;64M/F=E=$1A=&4H1$%415]&3U)-051?25-/7T585$5.1$5$
M*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<R,#`S+3$P+3`T5#$T
M.C`S.C(T6B<L("1D871E*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1V5T
M1&%T951I;65S=&%M<"@I"B`@("!["B`@("`@("`@)&1A=&4@/2`D=&AI<RT^
M=&EM92T^9V5T1&%T92A$051%7T9/4DU!5%]424U%4U1!35`I.PH@("`@("`@
M("1T:&ES+3YA<W-E<G1%<75A;',H)S(P,#,Q,#`T,30P,S(T)RP@)&1A=&4I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1'971$871E56YI>'1I;64H*0H@
M("`@>PH@("`@("`@("1D871E(#T@)'1H:7,M/G1I;64M/F=E=$1A=&4H1$%4
M15]&3U)-051?54Y)6%1)344I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H<W1R=&]T:6UE*"<R,#`S+3$P+3`T(#$T.C`S.C(T)RDL("1D871E*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!T97-T1F]R;6%T*"D*("`@('L*("`@("`@
M("`D8V]D97,@/2!A<G)A>2@*("`@("`@("`@("`@)V$G(#T^("=3870G+`H@
M("`@("`@("`@("`G02<@/3X@)U-A='5R9&%Y)RP*("`@("`@("`@("`@)V(G
M(#T^("=/8W0G+`H@("`@("`@("`@("`G0B<@/3X@)T]C=&]B97(G+`H@("`@
M("`@("`@("`G0R<@/3X@)S(P)RP*("`@("`@("`@("`@)V0G(#T^("<P-"<L
M"B`@("`@("`@("`@("=$)R`]/B`G,3`O,#0O,C`P,R<L"B`@("`@("`@("`@
M("=E)R`]/B`G-"<L"B`@("`@("`@("`@("=()R`]/B`G,30G+`H@("`@("`@
M("`@("`G22<@/3X@)S`R)RP*("`@("`@("`@("`@)VHG(#T^("<R-S<G+`H@
M("`@("`@("`@("`G;2<@/3X@)S$P)RP*("`@("`@("`@("`@)TTG(#T^("<P
M,R<L"B`@("`@("`@("`@("=N)R`]/B`B7&XB+`H@("`@("`@("`@("`G3R<@
M/3X@)RLP,#HP,"<L"B`@("`@("`@("`@("=O)R`]/B`G*S`P.C`P)RP*("`@
M("`@("`@("`@)W`G(#T^("=P;2<L"B`@("`@("`@("`@("=0)R`]/B`G4$TG
M+`H@("`@("`@("`@("`G<B<@/3X@)S`R.C`S.C(T(%!-)RP*("`@("`@("`@
M("`@)U(G(#T^("<Q-#HP,R<L"B`@("`@("`@("`@("=3)R`]/B`G,C0G+`H@
M("`@("`@("`@("`G="<@/3X@(EQT(BP*("`@("`@("`@("`@)U0G(#T^("<Q
M-#HP,SHR-"<L"B`@("`@("`@("`@("=W)R`]/B`G-B<L"B`@("`@("`@("`@
M("=5)R`]/B`G-#`G+`H@("`@("`@("`@("`G>2<@/3X@)S`S)RP*("`@("`@
M("`@("`@)UDG(#T^("<R,#`S)RP*("`@("`@("`@("`@)R4G(#T^("<E)PH@
M("`@("`@("D["@H@("`@("`@(&9O<F5A8V@@*"1C;V1E<R!A<R`D8V]D92`]
M/B`D97AP96-T960I('L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@*("`@("`@("`@("`@("`@("(D8V]D93H@)&5X<&5C=&5D(BP@)'1H:7,M
M/G1I;64M/F9O<FUA="@B)&-O9&4Z("4D8V]D92(I"B`@("`@("`@("`@("D[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('1E<W14;U540V)Y3V9F
M<V5T*"D*("`@('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T5%IB>4E$*"=%
M4U0G*3L*("`@("`@("`D=&AI<RT^=&EM92T^=&]55$,H*3L*("`@("`@("`D
M=&5M<"`](&YE=R!$871E*"(R,#`S+3$P+3`T(#$T.C`S.C(T(BD["B`@("`@
M("`@)'1E;7`M/G1O551#8GE/9F9S970H(BTP-3HP,"(I.PH*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*"1T96UP+"`D=&AI<RT^=&EM92D["B`@("!]
M"@I]"@HO+R!R=6YS('1H92!T97-T<PHD<W5I=&4@/2!N97<@4$A056YI=%]4
M97-T4W5I=&4H(D1A=&5?5&5S="(I.PHD<F5S=6QT(#T@4$A056YI=#HZ<G5N
M*"1S=6ET92D["B\O('!R:6YT<R!T:&4@=&5S=',*96-H;R`D<F5S=6QT+3YT
M;U-T<FEN9R@I.PH*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=VMN;W1E<W0N
M='AT`````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P-S`T`#$P-#$W,S8S,#`S
M`#`R,S$T,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````Q.3DY,3(R-SHQ.3DY+34R+3$*,3DY.3$R,C@Z,3DY.2TU,BTR"C$Y
M.3DQ,C(Y.C$Y.3DM-3(M,PHQ.3DY,3(S,#HQ.3DY+34R+30*,3DY.3$R,S$Z
M,3DY.2TU,BTU"C(P,#`P,3`Q.C$Y.3DM-3(M-@HR,#`P,#$P,CHQ.3DY+34R
M+3<*,C`P,#`Q,#,Z,C`P,"TP,2TQ"C(P,#`P,3`T.C(P,#`M,#$M,@HR,#`P
M,#$P-3HR,#`P+3`Q+3,*,C`P,#`Q,#8Z,C`P,"TP,2TT"C(P,#`P,3`W.C(P
M,#`M,#$M-0HR,#`P,#$P.#HR,#`P+3`Q+38*,C`P,#`Q,#DZ,C`P,"TP,2TW
M"C(P,#`Q,C(U.C(P,#`M-3(M,0HR,#`P,3(R-CHR,#`P+34R+3(*,C`P,#$R
M,C<Z,C`P,"TU,BTS"C(P,#`Q,C(X.C(P,#`M-3(M-`HR,#`P,3(R.3HR,#`P
M+34R+34*,C`P,#$R,S`Z,C`P,"TU,BTV"C(P,#`Q,C,Q.C(P,#`M-3(M-PHR
M,#`Q,#$P,3HR,#`Q+3`Q+3$*,C`P,3`Q,#(Z,C`P,2TP,2TR"C(P,#$P,3`S
M.C(P,#$M,#$M,PHR,#`Q,#$P-#HR,#`Q+3`Q+30*,C`P,3`Q,#4Z,C`P,2TP
M,2TU"C(P,#$P,3`V.C(P,#$M,#$M-@HR,#`Q,#$P-SHR,#`Q+3`Q+3<*,C`P
M,3$R,C0Z,C`P,2TU,BTQ"C(P,#$Q,C(U.C(P,#$M-3(M,@HR,#`Q,3(R-CHR
M,#`Q+34R+3,*,C`P,3$R,C<Z,C`P,2TU,BTT"C(P,#$Q,C(X.C(P,#$M-3(M
M-0HR,#`Q,3(R.3HR,#`Q+34R+38*,C`P,3$R,S`Z,C`P,2TU,BTW"C(P,#$Q
M,C,Q.C(P,#(M,#$M,0HR,#`R,#$P,3HR,#`R+3`Q+3(*,C`P,C`Q,#(Z,C`P
M,BTP,2TS"C(P,#(P,3`S.C(P,#(M,#$M-`HR,#`R,#$P-#HR,#`R+3`Q+34*
M,C`P,C`Q,#4Z,C`P,BTP,2TV"C(P,#(P,3`V.C(P,#(M,#$M-PHR,#`R,3(R
M,SHR,#`R+34R+3$*,C`P,C$R,C0Z,C`P,BTU,BTR"C(P,#(Q,C(U.C(P,#(M
M-3(M,PHR,#`R,3(R-CHR,#`R+34R+30*,C`P,C$R,C<Z,C`P,BTU,BTU"C(P
M,#(Q,C(X.C(P,#(M-3(M-@HR,#`R,3(R.3HR,#`R+34R+3<*,C`P,C$R,S`Z
M,C`P,RTP,2TQ"C(P,#(Q,C,Q.C(P,#,M,#$M,@HR,#`S,#$P,3HR,#`S+3`Q
M+3,*,C`P,S`Q,#(Z,C`P,RTP,2TT"C(P,#,P,3`S.C(P,#,M,#$M-0HR,#`S
M,#$P-#HR,#`S+3`Q+38*,C`P,S`Q,#4Z,C`P,RTP,2TW"C(P,#,Q,C(R.C(P
M,#,M-3(M,0HR,#`S,3(R,SHR,#`S+34R+3(*,C`P,S$R,C0Z,C`P,RTU,BTS
M"C(P,#,Q,C(U.C(P,#,M-3(M-`HR,#`S,3(R-CHR,#`S+34R+34*,C`P,S$R
M,C<Z,C`P,RTU,BTV"C(P,#,Q,C(X.C(P,#,M-3(M-PHR,#`S,3(R.3HR,#`T
M+3`Q+3$*,C`P,S$R,S`Z,C`P-"TP,2TR"C(P,#,Q,C,Q.C(P,#0M,#$M,PHR
M,#`T,#$P,3HR,#`T+3`Q+30*,C`P-#`Q,#(Z,C`P-"TP,2TU"C(P,#0P,3`S
M.C(P,#0M,#$M-@HR,#`T,#$P-#HR,#`T+3`Q+3<*,C`P-#$R,C`Z,C`P-"TU
M,BTQ"C(P,#0Q,C(Q.C(P,#0M-3(M,@HR,#`T,3(R,CHR,#`T+34R+3,*,C`P
M-#$R,C,Z,C`P-"TU,BTT"C(P,#0Q,C(T.C(P,#0M-3(M-0HR,#`T,3(R-3HR
M,#`T+34R+38*,C`P-#$R,C8Z,C`P-"TU,BTW"C(P,#0Q,C(W.C(P,#0M-3,M
M,0HR,#`T,3(R.#HR,#`T+34S+3(*,C`P-#$R,CDZ,C`P-"TU,RTS"C(P,#0Q
M,C,P.C(P,#0M-3,M-`HR,#`T,3(S,3HR,#`T+34S+34*,C`P-3`Q,#$Z,C`P
M-"TU,RTV"C(P,#4P,3`R.C(P,#0M-3,M-PHR,#`U,#$P,SHR,#`U+3`Q+3$*
M,C`P-3`Q,#0Z,C`P-2TP,2TR"C(P,#4P,3`U.C(P,#4M,#$M,PHR,#`U,#$P
M-CHR,#`U+3`Q+30*,C`P-3`Q,#<Z,C`P-2TP,2TU"C(P,#4P,3`X.C(P,#4M
M,#$M-@HR,#`U,#$P.3HR,#`U+3`Q+3<*,C`P-3$R,C8Z,C`P-2TU,BTQ"C(P
M,#4Q,C(W.C(P,#4M-3(M,@HR,#`U,3(R.#HR,#`U+34R+3,*,C`P-3$R,CDZ
M,C`P-2TU,BTT"C(P,#4Q,C,P.C(P,#4M-3(M-0HR,#`U,3(S,3HR,#`U+34R
M+38*,C`P-C`Q,#$Z,C`P-2TU,BTW"C(P,#8P,3`R.C(P,#8M,#$M,0HR,#`V
M,#$P,SHR,#`V+3`Q+3(*,C`P-C`Q,#0Z,C`P-BTP,2TS"C(P,#8P,3`U.C(P
M,#8M,#$M-`HR,#`V,#$P-CHR,#`V+3`Q+34*,C`P-C`Q,#<Z,C`P-BTP,2TV
M"C(P,#8P,3`X.C(P,#8M,#$M-PHR,#`V,3(R-3HR,#`V+34R+3$*,C`P-C$R
M,C8Z,C`P-BTU,BTR"C(P,#8Q,C(W.C(P,#8M-3(M,PHR,#`V,3(R.#HR,#`V
M+34R+30*,C`P-C$R,CDZ,C`P-BTU,BTU"C(P,#8Q,C,P.C(P,#8M-3(M-@HR
M,#`V,3(S,3HR,#`V+34R+3<*,C`P-S`Q,#$Z,C`P-RTP,2TQ"C(P,#<P,3`R
M.C(P,#<M,#$M,@HR,#`W,#$P,SHR,#`W+3`Q+3,*,C`P-S`Q,#0Z,C`P-RTP
M,2TT"C(P,#<P,3`U.C(P,#<M,#$M-0HR,#`W,#$P-CHR,#`W+3`Q+38*,C`P
M-S`Q,#<Z,C`P-RTP,2TW"C(P,#<Q,C(T.C(P,#<M-3(M,0HR,#`W,3(R-3HR
M,#`W+34R+3(*,C`P-S$R,C8Z,C`P-RTU,BTS"C(P,#<Q,C(W.C(P,#<M-3(M
M-`HR,#`W,3(R.#HR,#`W+34R+34*,C`P-S$R,CDZ,C`P-RTU,BTV"C(P,#<Q
M,C,P.C(P,#<M-3(M-PHR,#`W,3(S,3HR,#`X+3`Q+3$*,C`P.#`Q,#$Z,C`P
M."TP,2TR"C(P,#@P,3`R.C(P,#@M,#$M,PHR,#`X,#$P,SHR,#`X+3`Q+30*
M,C`P.#`Q,#0Z,C`P."TP,2TU"C(P,#@P,3`U.C(P,#@M,#$M-@HR,#`X,#$P
M-CHR,#`X+3`Q+3<*,C`P.#$R,C(Z,C`P."TU,BTQ"C(P,#@Q,C(S.C(P,#@M
M-3(M,@HR,#`X,3(R-#HR,#`X+34R+3,*,C`P.#$R,C4Z,C`P."TU,BTT"C(P
M,#@Q,C(V.C(P,#@M-3(M-0HR,#`X,3(R-SHR,#`X+34R+38*,C`P.#$R,C@Z
M,C`P."TU,BTW"C(P,#@Q,C(Y.C(P,#DM,#$M,0HR,#`X,3(S,#HR,#`Y+3`Q
M+3(*,C`P.#$R,S$Z,C`P.2TP,2TS"C(P,#DP,3`Q.C(P,#DM,#$M-`HR,#`Y
M,#$P,CHR,#`Y+3`Q+34*,C`P.3`Q,#,Z,C`P.2TP,2TV"C(P,#DP,3`T.C(P
M,#DM,#$M-PHR,#`Y,3(R,3HR,#`Y+34R+3$*,C`P.3$R,C(Z,C`P.2TU,BTR
M"C(P,#DQ,C(S.C(P,#DM-3(M,PHR,#`Y,3(R-#HR,#`Y+34R+30*,C`P.3$R
M,C4Z,C`P.2TU,BTU"C(P,#DQ,C(V.C(P,#DM-3(M-@HR,#`Y,3(R-SHR,#`Y
M+34R+3<*,C`P.3$R,C@Z,C`P.2TU,RTQ"C(P,#DQ,C(Y.C(P,#DM-3,M,@HR
M,#`Y,3(S,#HR,#`Y+34S+3,*,C`P.3$R,S$Z,C`P.2TU,RTT"C(P,3`P,3`Q
M.C(P,#DM-3,M-0HR,#$P,#$P,CHR,#`Y+34S+38*,C`Q,#`Q,#,Z,C`P.2TU
M,RTW"C(P,3`P,3`T.C(P,3`M,#$M,0HR,#$P,#$P-3HR,#$P+3`Q+3(*,C`Q
M,#`Q,#8Z,C`Q,"TP,2TS"C(P,3`P,3`W.C(P,3`M,#$M-`HR,#$P,#$P.#HR
M,#$P+3`Q+34*,C`Q,#`Q,#DZ,C`Q,"TP,2TV"C(P,3`P,3$P.C(P,3`M,#$M
M-PHR,#$P,3(R-SHR,#$P+34R+3$*,C`Q,#$R,C@Z,C`Q,"TU,BTR"C(P,3`Q
M,C(Y.C(P,3`M-3(M,PHR,#$P,3(S,#HR,#$P+34R+30*,C`Q,#$R,S$Z,C`Q
M,"TU,BTU"C(P,3$P,3`Q.C(P,3`M-3(M-@HR,#$Q,#$P,CHR,#$P+34R+3<*
M,C`Q,3`Q,#,Z,C`Q,2TP,2TQ"C(P,3$P,3`T.C(P,3$M,#$M,@HR,#$Q,#$P
M-3HR,#$Q+3`Q+3,*,C`Q,3`Q,#8Z,C`Q,2TP,2TT"C(P,3$P,3`W.C(P,3$M
M,#$M-0HR,#$Q,#$P.#HR,#$Q+3`Q+38*,C`Q,3`Q,#DZ,C`Q,2TP,2TW"C(P
M,3$Q,C(V.C(P,3$M-3(M,0HR,#$Q,3(R-SHR,#$Q+34R+3(*,C`Q,3$R,C@Z
M,C`Q,2TU,BTS"C(P,3$Q,C(Y.C(P,3$M-3(M-`HR,#$Q,3(S,#HR,#$Q+34R
M+34*,C`Q,3$R,S$Z,C`Q,2TU,BTV"C(P,3(P,3`Q.C(P,3$M-3(M-PHR,#$R
M,#$P,CHR,#$R+3`Q+3$*,C`Q,C`Q,#,Z,C`Q,BTP,2TR"C(P,3(P,3`T.C(P
M,3(M,#$M,PHR,#$R,#$P-3HR,#$R+3`Q+30*,C`Q,C`Q,#8Z,C`Q,BTP,2TU
M"C(P,3(P,3`W.C(P,3(M,#$M-@HR,#$R,#$P.#HR,#$R+3`Q+3<*,C`Q,C$R
M,C0Z,C`Q,BTU,BTQ"C(P,3(Q,C(U.C(P,3(M-3(M,@HR,#$R,3(R-CHR,#$R
M+34R+3,*,C`Q,C$R,C<Z,C`Q,BTU,BTT"C(P,3(Q,C(X.C(P,3(M-3(M-0HR
M,#$R,3(R.3HR,#$R+34R+38*,C`Q,C$R,S`Z,C`Q,BTU,BTW"C(P,3(Q,C,Q
M.C(P,3,M,#$M,0HR,#$S,#$P,3HR,#$S+3`Q+3(*,C`Q,S`Q,#(Z,C`Q,RTP
M,2TS"C(P,3,P,3`S.C(P,3,M,#$M-`HR,#$S,#$P-#HR,#$S+3`Q+34*,C`Q
M,S`Q,#4Z,C`Q,RTP,2TV"C(P,3,P,3`V.C(P,3,M,#$M-PHR,#$S,3(R,SHR
M,#$S+34R+3$*,C`Q,S$R,C0Z,C`Q,RTU,BTR"C(P,3,Q,C(U.C(P,3,M-3(M
M,PHR,#$S,3(R-CHR,#$S+34R+30*,C`Q,S$R,C<Z,C`Q,RTU,BTU"C(P,3,Q
M,C(X.C(P,3,M-3(M-@HR,#$S,3(R.3HR,#$S+34R+3<*,C`Q,S$R,S`Z,C`Q
M-"TP,2TQ"C(P,3,Q,C,Q.C(P,30M,#$M,@HR,#$T,#$P,3HR,#$T+3`Q+3,*
M,C`Q-#`Q,#(Z,C`Q-"TP,2TT"C(P,30P,3`S.C(P,30M,#$M-0HR,#$T,#$P
M-#HR,#$T+3`Q+38*,C`Q-#`Q,#4Z,C`Q-"TP,2TW"C(P,30Q,C(R.C(P,30M
M-3(M,0HR,#$T,3(R,SHR,#$T+34R+3(*,C`Q-#$R,C0Z,C`Q-"TU,BTS"C(P
M,30Q,C(U.C(P,30M-3(M-`HR,#$T,3(R-CHR,#$T+34R+34*,C`Q-#$R,C<Z
M,C`Q-"TU,BTV"C(P,30Q,C(X.C(P,30M-3(M-PHR,#$T,3(R.3HR,#$U+3`Q
M+3$*,C`Q-#$R,S`Z,C`Q-2TP,2TR"C(P,30Q,C,Q.C(P,34M,#$M,PHR,#$U
M,#$P,3HR,#$U+3`Q+30*,C`Q-3`Q,#(Z,C`Q-2TP,2TU"C(P,34P,3`S.C(P
M,34M,#$M-@HR,#$U,#$P-#HR,#$U+3`Q+3<*,C`Q-3$R,C$Z,C`Q-2TU,BTQ
M"C(P,34Q,C(R.C(P,34M-3(M,@HR,#$U,3(R,SHR,#$U+34R+3,*,C`Q-3$R
M,C0Z,C`Q-2TU,BTT"C(P,34Q,C(U.C(P,34M-3(M-0HR,#$U,3(R-CHR,#$U
M+34R+38*,C`Q-3$R,C<Z,C`Q-2TU,BTW"C(P,34Q,C(X.C(P,34M-3,M,0HR
M,#$U,3(R.3HR,#$U+34S+3(*,C`Q-3$R,S`Z,C`Q-2TU,RTS"C(P,34Q,C,Q
M.C(P,34M-3,M-`HR,#$V,#$P,3HR,#$U+34S+34*,C`Q-C`Q,#(Z,C`Q-2TU
M,RTV"C(P,38P,3`S.C(P,34M-3,M-PHR,#$V,#$P-#HR,#$V+3`Q+3$*,C`Q
M-C`Q,#4Z,C`Q-BTP,2TR"C(P,38P,3`V.C(P,38M,#$M,PHR,#$V,#$P-SHR
M,#$V+3`Q+30*,C`Q-C`Q,#@Z,C`Q-BTP,2TU"C(P,38P,3`Y.C(P,38M,#$M
M-@HR,#$V,#$Q,#HR,#$V+3`Q+3<*,C`Q-C$R,C8Z,C`Q-BTU,BTQ"C(P,38Q
M,C(W.C(P,38M-3(M,@HR,#$V,3(R.#HR,#$V+34R+3,*,C`Q-C$R,CDZ,C`Q
M-BTU,BTT"C(P,38Q,C,P.C(P,38M-3(M-0HR,#$V,3(S,3HR,#$V+34R+38*
M,C`Q-S`Q,#$Z,C`Q-BTU,BTW"C(P,3<P,3`R.C(P,3<M,#$M,0HR,#$W,#$P
M,SHR,#$W+3`Q+3(*,C`Q-S`Q,#0Z,C`Q-RTP,2TS"C(P,3<P,3`U.C(P,3<M
M,#$M-`HR,#$W,#$P-CHR,#$W+3`Q+34*,C`Q-S`Q,#<Z,C`Q-RTP,2TV"C(P
M,3<P,3`X.C(P,3<M,#$M-PHR,#$W,3(R-3HR,#$W+34R+3$*,C`Q-S$R,C8Z
M,C`Q-RTU,BTR"C(P,3<Q,C(W.C(P,3<M-3(M,PHR,#$W,3(R.#HR,#$W+34R
M+30*,C`Q-S$R,CDZ,C`Q-RTU,BTU"C(P,3<Q,C,P.C(P,3<M-3(M-@HR,#$W
M,3(S,3HR,#$W+34R+3<*,C`Q.#`Q,#$Z,C`Q."TP,2TQ"C(P,3@P,3`R.C(P
M,3@M,#$M,@HR,#$X,#$P,SHR,#$X+3`Q+3,*,C`Q.#`Q,#0Z,C`Q."TP,2TT
M"C(P,3@P,3`U.C(P,3@M,#$M-0HR,#$X,#$P-CHR,#$X+3`Q+38*,C`Q.#`Q
M,#<Z,C`Q."TP,2TW"C(P,3@Q,C(T.C(P,3@M-3(M,0HR,#$X,3(R-3HR,#$X
M+34R+3(*,C`Q.#$R,C8Z,C`Q."TU,BTS"C(P,3@Q,C(W.C(P,3@M-3(M-`HR
M,#$X,3(R.#HR,#$X+34R+34*,C`Q.#$R,CDZ,C`Q."TU,BTV"C(P,3@Q,C,P
M.C(P,3@M-3(M-PHR,#$X,3(S,3HR,#$Y+3`Q+3$*,C`Q.3`Q,#$Z,C`Q.2TP
M,2TR"C(P,3DP,3`R.C(P,3DM,#$M,PHR,#$Y,#$P,SHR,#$Y+3`Q+30*,C`Q
M.3`Q,#0Z,C`Q.2TP,2TU"C(P,3DP,3`U.C(P,3DM,#$M-@HR,#$Y,#$P-CHR
M,#$Y+3`Q+3<*,C`Q.3$R,C,Z,C`Q.2TU,BTQ"C(P,3DQ,C(T.C(P,3DM-3(M
M,@HR,#$Y,3(R-3HR,#$Y+34R+3,*,C`Q.3$R,C8Z,C`Q.2TU,BTT"C(P,3DQ
M,C(W.C(P,3DM-3(M-0HR,#$Y,3(R.#HR,#$Y+34R+38*,C`Q.3$R,CDZ,C`Q
M.2TU,BTW"C(P,3DQ,C,P.C(P,C`M,#$M,0HR,#$Y,3(S,3HR,#(P+3`Q+3(*
M,C`R,#`Q,#$Z,C`R,"TP,2TS"C(P,C`P,3`R.C(P,C`M,#$M-`HR,#(P,#$P
M,SHR,#(P+3`Q+34*,C`R,#`Q,#0Z,C`R,"TP,2TV"C(P,C`P,3`U.C(P,C`M
M,#$M-PHR,#(P,3(R,3HR,#(P+34R+3$*,C`R,#$R,C(Z,C`R,"TU,BTR"C(P
M,C`Q,C(S.C(P,C`M-3(M,PHR,#(P,3(R-#HR,#(P+34R+30*,C`R,#$R,C4Z
M,C`R,"TU,BTU"C(P,C`Q,C(V.C(P,C`M-3(M-@HR,#(P,3(R-SHR,#(P+34R
M+3<*,C`R,#$R,C@Z,C`R,"TU,RTQ"C(P,C`Q,C(Y.C(P,C`M-3,M,@HR,#(P
M,3(S,#HR,#(P+34S+3,*,C`R,#$R,S$Z,C`R,"TU,RTT"C(P,C$P,3`Q.C(P
M,C`M-3,M-0HR,#(Q,#$P,CHR,#(P+34S+38*,C`R,3`Q,#,Z,C`R,"TU,RTW
M"C(P,C$P,3`T.C(P,C$M,#$M,0HR,#(Q,#$P-3HR,#(Q+3`Q+3(*,C`R,3`Q
M,#8Z,C`R,2TP,2TS"C(P,C$P,3`W.C(P,C$M,#$M-`HR,#(Q,#$P.#HR,#(Q
M+3`Q+34*,C`R,3`Q,#DZ,C`R,2TP,2TV"C(P,C$P,3$P.C(P,C$M,#$M-PHR
M,#(Q,3(R-SHR,#(Q+34R+3$*,C`R,3$R,C@Z,C`R,2TU,BTR"C(P,C$Q,C(Y
M.C(P,C$M-3(M,PHR,#(Q,3(S,#HR,#(Q+34R+30*,C`R,3$R,S$Z,C`R,2TU
M,BTU"C(P,C(P,3`Q.C(P,C$M-3(M-@HR,#(R,#$P,CHR,#(Q+34R+3<*,C`R
M,C`Q,#,Z,C`R,BTP,2TQ"C(P,C(P,3`T.C(P,C(M,#$M,@HR,#(R,#$P-3HR
M,#(R+3`Q+3,*,C`R,C`Q,#8Z,C`R,BTP,2TT"C(P,C(P,3`W.C(P,C(M,#$M
M-0HR,#(R,#$P.#HR,#(R+3`Q+38*,C`R,C`Q,#DZ,C`R,BTP,2TW"C(P,C(Q
M,C(V.C(P,C(M-3(M,0HR,#(R,3(R-SHR,#(R+34R+3(*,C`R,C$R,C@Z,C`R
M,BTU,BTS"C(P,C(Q,C(Y.C(P,C(M-3(M-`HR,#(R,3(S,#HR,#(R+34R+34*
M,C`R,C$R,S$Z,C`R,BTU,BTV"C(P,C,P,3`Q.C(P,C(M-3(M-PHR,#(S,#$P
M,CHR,#(S+3`Q+3$*,C`R,S`Q,#,Z,C`R,RTP,2TR"C(P,C,P,3`T.C(P,C,M
M,#$M,PHR,#(S,#$P-3HR,#(S+3`Q+30*,C`R,S`Q,#8Z,C`R,RTP,2TU"C(P
M,C,P,3`W.C(P,C,M,#$M-@HR,#(S,#$P.#HR,#(S+3`Q+3<*,C`R,S$R,C4Z
M,C`R,RTU,BTQ"C(P,C,Q,C(V.C(P,C,M-3(M,@HR,#(S,3(R-SHR,#(S+34R
M+3,*,C`R,S$R,C@Z,C`R,RTU,BTT"C(P,C,Q,C(Y.C(P,C,M-3(M-0HR,#(S
M,3(S,#HR,#(S+34R+38*,C`R,S$R,S$Z,C`R,RTU,BTW"C(P,C0P,3`Q.C(P
M,C0M,#$M,0HR,#(T,#$P,CHR,#(T+3`Q+3(*,C`R-#`Q,#,Z,C`R-"TP,2TS
M"C(P,C0P,3`T.C(P,C0M,#$M-`HR,#(T,#$P-3HR,#(T+3`Q+34*,C`R-#`Q
M,#8Z,C`R-"TP,2TV"C(P,C0P,3`W.C(P,C0M,#$M-PHR,#(T,3(R,SHR,#(T
M+34R+3$*,C`R-#$R,C0Z,C`R-"TU,BTR"C(P,C0Q,C(U.C(P,C0M-3(M,PHR
M,#(T,3(R-CHR,#(T+34R+30*,C`R-#$R,C<Z,C`R-"TU,BTU"C(P,C0Q,C(X
M.C(P,C0M-3(M-@HR,#(T,3(R.3HR,#(T+34R+3<*,C`R-#$R,S`Z,C`R-2TP
M,2TQ"C(P,C0Q,C,Q.C(P,C4M,#$M,@HR,#(U,#$P,3HR,#(U+3`Q+3,*,C`R
M-3`Q,#(Z,C`R-2TP,2TT"C(P,C4P,3`S.C(P,C4M,#$M-0HR,#(U,#$P-#HR
M,#(U+3`Q+38*,C`R-3`Q,#4Z,C`R-2TP,2TW"C(P,C4Q,C(R.C(P,C4M-3(M
M,0HR,#(U,3(R,SHR,#(U+34R+3(*,C`R-3$R,C0Z,C`R-2TU,BTS"C(P,C4Q
M,C(U.C(P,C4M-3(M-`HR,#(U,3(R-CHR,#(U+34R+34*,C`R-3$R,C<Z,C`R
M-2TU,BTV"C(P,C4Q,C(X.C(P,C4M-3(M-PHR,#(U,3(R.3HR,#(V+3`Q+3$*
M,C`R-3$R,S`Z,C`R-BTP,2TR"C(P,C4Q,C,Q.C(P,C8M,#$M,PHR,#(V,#$P
M,3HR,#(V+3`Q+30*,C`R-C`Q,#(Z,C`R-BTP,2TU"C(P,C8P,3`S.C(P,C8M
M,#$M-@HR,#(V,#$P-#HR,#(V+3`Q+3<*,C`R-C$R,C$Z,C`R-BTU,BTQ"C(P
M,C8Q,C(R.C(P,C8M-3(M,@HR,#(V,3(R,SHR,#(V+34R+3,*,C`R-C$R,C0Z
M,C`R-BTU,BTT"C(P,C8Q,C(U.C(P,C8M-3(M-0HR,#(V,3(R-CHR,#(V+34R
M+38*,C`R-C$R,C<Z,C`R-BTU,BTW"C(P,C8Q,C(X.C(P,C8M-3,M,0HR,#(V
M,3(R.3HR,#(V+34S+3(*,C`R-C$R,S`Z,C`R-BTU,RTS"C(P,C8Q,C,Q.C(P
M,C8M-3,M-`HR,#(W,#$P,3HR,#(V+34S+34*,C`R-S`Q,#(Z,C`R-BTU,RTV
M"C(P,C<P,3`S.C(P,C8M-3,M-PHR,#(W,#$P-#HR,#(W+3`Q+3$*,C`R-S`Q
M,#4Z,C`R-RTP,2TR"C(P,C<P,3`V.C(P,C<M,#$M,PHR,#(W,#$P-SHR,#(W
M+3`Q+30*,C`R-S`Q,#@Z,C`R-RTP,2TU"C(P,C<P,3`Y.C(P,C<M,#$M-@HR
M,#(W,#$Q,#HR,#(W+3`Q+3<*,C`R-S$R,C<Z,C`R-RTU,BTQ"C(P,C<Q,C(X
M.C(P,C<M-3(M,@HR,#(W,3(R.3HR,#(W+34R+3,*,C`R-S$R,S`Z,C`R-RTU
M,BTT"C(P,C<Q,C,Q.C(P,C<M-3(M-0HR,#(X,#$P,3HR,#(W+34R+38*,C`R
M.#`Q,#(Z,C`R-RTU,BTW"C(P,C@P,3`S.C(P,C@M,#$M,0HR,#(X,#$P-#HR
M,#(X+3`Q+3(*,C`R.#`Q,#4Z,C`R."TP,2TS"C(P,C@P,3`V.C(P,C@M,#$M
M-`HR,#(X,#$P-SHR,#(X+3`Q+34*,C`R.#`Q,#@Z,C`R."TP,2TV"C(P,C@P
M,3`Y.C(P,C@M,#$M-PHR,#(X,3(R-3HR,#(X+34R+3$*,C`R.#$R,C8Z,C`R
M."TU,BTR"C(P,C@Q,C(W.C(P,C@M-3(M,PHR,#(X,3(R.#HR,#(X+34R+30*
M,C`R.#$R,CDZ,C`R."TU,BTU"C(P,C@Q,C,P.C(P,C@M-3(M-@HR,#(X,3(S
M,3HR,#(X+34R+3<*,C`R.3`Q,#$Z,C`R.2TP,2TQ"C(P,CDP,3`R.C(P,CDM
M,#$M,@HR,#(Y,#$P,SHR,#(Y+3`Q+3,*,C`R.3`Q,#0Z,C`R.2TP,2TT"C(P
M,CDP,3`U.C(P,CDM,#$M-0HR,#(Y,#$P-CHR,#(Y+3`Q+38*,C`R.3`Q,#<Z
M,C`R.2TP,2TW````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S='5N:70N<&AP````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S0R`#$P-#$W,S8S,#`S`#`R,S$Q,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0
M('9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R<SH@36%R<VAA;&P@4F]C:"`\;7)O8VA`<&AP+FYE
M=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!T97-T=6YI="YP:'`L
M=B`Q+C$@,C`P,R\Q,"\R-"`Q.3HT.3HQ."!M<F]C:"!%>'`@)`H*+RHJ"B`J
M($1I<W!L87ES(&%L;"!T97-T(&-A<V5S(&]N('1H92!S86UE('!A9V4*("H*
M("H@0'!A8VMA9V4@1&%T90H@*B!`875T:&]R($UA<G-H86QL(%)O8V@@/&UR
M;V-H0'!H<"YN970^"B`J+PH*"F5C:&\@(CQP<F4^(CL*<F5Q=6ER95]O;F-E
M("=02%!5;FET+G!H<"<["G)E<75I<F5?;VYC92`G=&5S='5N:71?9&%T92YP
M:'`G.PIR97%U:7)E7V]N8V4@)W1E<W1U;FET7V1A=&5?<W!A;BYP:'`G.PIE
M8VAO("(\+W!R93XB.PH_/@H`````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92\`
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C,P,#,`,#$W,S8Q`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]&:6QE+W1E<W1S+P``````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P,P`P,C`U,C,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O<&%R<V5R
M+G!H<```````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C`P`#$P-#$W,S8S
M,#`S`#`R,C4Q-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HD<&%T:"`](&EN:5]G970H)VEN8VQU9&5?<&%T:"<I
M.PII;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!R96%L<&%T:"@G+BXO)RD@+B`B
M.B1P871H(BD["G)E<75I<F5?;VYC92`G1FEL92]#4U8N<&AP)SL*"B\J+T5X
M86UP;&4@8V]N9CH*)&-O;F8@/2!A<G)A>2@*("`@("=F:65L9',G(#T^(#0L
M"B`@("`G<V5P)R`@("`]/B`B7'0B+`H@("`@)W%U;W1E)R`@/3X@)R(G+`H@
M("`@)VAE861E<B<@/3X@9F%L<V4**3L*+R\J+PIO8E]I;7!L:6-I=%]F;'5S
M:"AT<G5E*3L*)&%R9W8@/2`D7U-%4E9%4ELG87)G=B==.PHD9FEL92`]("1A
M<F=V6S%=.PHD=W)I=&4@/2`H:7-S970H)&%R9W9;,ETI*2`_("1A<F=V6S)=
M(#H@9F%L<V4["E!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]0
M4DE.5"P@(G=A<FYI;F<Z("5S7&XB*3L*"B1C;VYF(#T@1FEL95]#4U8Z.F1I
M<V-O=F5R1F]R;6%T*"1F:6QE*3L*=VAI;&4@*"1F:65L9',@/2!&:6QE7T-3
M5CHZ<F5A9"@D9FEL92P@)&-O;F8I*2!["B`@("!I9B`H)'=R:71E*2!["B`@
M("`@("`@1FEL95]#4U8Z.G=R:71E*"1W<FET92P@)&9I96QD<RP@)&-O;F8I
M.PH@("`@?0H@("`@<')I;G1?<B@D9FEE;&1S*3L*?0H*=F%R7V1U;7`H)&-O
M;F8I.PIE8VAO(")<;B(*"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O
M=&5S="YC<W8`````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#,Q`#$P
M-#$W,S8S,#`S`#`R,C(P-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!F,0EF,@EF,PEF-`IG;V]D,0EG;V]D,@EG;V]D,PEG
M;V]D-`H[.SL[.PD[.SL[.PD[.SL[.PD[.SL[.PHZ(#H@.@D[(#L@(@DB+@DB
M"3HZ.CH[.SL[(@IN;R)Q=6]T90EN;R)Q=2)O=&4);B)Q=6]T92();B)Q(G4B
M;R)T(@HB<75O=&4Q(@DB<75O=&4R(@EN;W%U;W1E,R();F]Q=6]T930*=&5S
M=#$)(FQO;F<*=&5S=#(B"2)L;VYG('1E<W0S"7=I=&@)<V5P<R()(DDG;0H)
M"0D)"7-I;&QY"@D)"0D);&]N9R(*;&5S<S$)(FQE<W,R"2XB"6QE<W,S"FES
M=F%L:60Q"6ES=F%L:60R"6ES=F%L:60S"6ES=F%L:60T"FUO<F4R,0DB;6]R
M93(R"0DN(@EM;W)E,C,);6]R93(T"6UO<F4R-0EM;W)E,C8*:7-V86QI9#(Q
M"6ES=F%L:60R,@EI<W9A;&ED,C,):7-V86QI9#(T"FQE<W-N;W$S,0EL97-S
M;F]Q,S();&5S<VYO<3,S"FES=F%L:60S,0EI<W9A;&ED,S():7-V86QI9#,S
M"6ES=F%L:60S-`IM;W)E;F]Q-#$);6]R96YO<30R"6UO<F5N;W$T,PEM;W)E
M;F]Q-#0);6]R96YO<30U"FES=F%L:60T,0EI<W9A;&ED-#():7-V86QI9#0S
M"6ES=F%L:60T-`H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]0
M87)S97(O````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8S,#`S`#`R,#0U-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R\`````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#,`,#(Q-C(P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S
M+S`P,2YP:'!T````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(T,``Q,#0Q-S,V
M,S`P,P`P,C,P,3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*6$U,(%!A<G-E<CH@<&%R<V4@<VEM<&QE('-T
M<FEN9PHM+5-+25!)1BTM"CP_<&AP(&EF("@A97AT96YS:6]N7VQO861E9"@B
M>&UL(BDI(&5C:&\@)W-K:7`G.R`_/@HM+49)3$4M+0H\/W!H<`HO+PHO+R!4
M97-T(&9O<CH@6$U,+U!A<G-E<BYP:'`*+R\@4&%R=',@=&5S=&5D.B`M('!A
M<G-E<B!C<F5A=&EO;@HO+R`@("`@("`@("`@("`@("T@<V]M92!H86YD;&5R
M<PHO+R`@("`@("`@("`@("`@("T@<&%R<V4@<VEM<&QE('-T<FEN9PHO+PH*
M<F5Q=6ER95]O;F-E(")834PO4&%R<V5R+G!H<"(["@IC;&%S<R!?7U1E<W10
M87)S97(Q(&5X=&5N9',@6$U,7U!A<G-E<B!["B`@("!F=6YC=&EO;B!?7U1E
M<W1087)S97(Q*"D@>PH@("`@("`@("1T:&ES+3Y834Q?4&%R<V5R*"D["B`@
M("!]"B`@("!F=6YC=&EO;B!S=&%R=$AA;F1L97(H)'AP+"`D96QE;65N="P@
M)&%T=')I8G,I('L*("`@("`@("!P<FEN="`B/"1E;&5M96YT(CL*("`@("`@
M("!R97-E="@D871T<FEB<RD["B`@("`@("`@=VAI;&4@*&QI<W0H)&ME>2P@
M)'9A;"D@/2!E86-H*"1A='1R:6)S*2D@>PH@("`@("`@("`@("`D96YC(#T@
M:'1M;&5N=&ET:65S*"1V86PI.PH@("`@("`@("`@("!P<FEN="`B("1K97D]
M7"(D96YC7"(B.PH@("`@("`@('T*("`@("`@("!P<FEN="`B/B(["B`@("!]
M"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L96UE;G0I('L*("`@
M("`@("!P<FEN="`B/"\D96QE;65N=#Y<;B(["B`@("!]"B`@("!F=6YC=&EO
M;B!C9&%T84AA;F1L97(H)'AP+"`D8V1A=&$I('L*("`@("`@("!P<FEN="`B
M/"%;0T1!5$%;)&-D871A75T^(CL*("`@('T*("`@(&9U;F-T:6]N(&1E9F%U
M;'1(86YD;&5R*"1X<"P@)&-D871A*2!["@H@("`@?0I]"F5R<F]R7W)E<&]R
M=&EN9R@Q,#(S*3L*<')I;G0@(FYE=R!?7U1E<W1087)S97(Q("(["G9A<E]D
M=6UP*&=E=%]C;&%S<R@D;R`](&YE=R!?7U1E<W1087)S97(Q*"DI*3L*<')I
M;G0@(G!A<G-E4W1R:6YG("(["G9A<E]D=6UP*"1O+3YP87)S95-T<FEN9R@B
M/#]X;6P@=F5R<VEO;CTG,2XP)R`_/CQR;V]T/F9O;SPO<F]O=#XB+"`Q*2D[
M"@H_/@HM+4584$5#5"TM"FYE=R!?7U1E<W1087)S97(Q('-T<FEN9R@Q,RD@
M(E]?=&5S='!A<G-E<C$B"G!A<G-E4W1R:6YG(#Q23T]4/CPA6T-$051!6V9O
M;UU=/CPO4D]/5#X*8F]O;"AT<G5E*0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`R+G!H<'0`````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,S,P`#$P-#$W,S8S,#`S`#`R,S`Q,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+51%4U0M+0I834P@
M4&%R<V5R.B!P87)S92!F<F]M(&9I;&4*+2U32TE0248M+0H\/W!H<"!I9B`H
M(65X=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO("=S:VEP)SL@/SX*+2U&
M24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*+R\*+R\@5&5S="!F;W(Z(%A-
M3"]087)S97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@+2!P87)S97(@8W)E871I
M;VX*+R\@("`@("`@("`@("`@("`M('-O;64@:&%N9&QE<G,*+R\@("`@("`@
M("`@("`@("`M('!A<G-E(&9R;VT@9FEL90HO+PIC:&1I<B`H9&ER;F%M92A?
M7T9)3$5?7RDI.PH*<F5Q=6ER95]O;F-E(")834PO4&%R<V5R+G!H<"(["@IC
M;&%S<R!?7U1E<W1087)S97(R(&5X=&5N9',@6$U,7U!A<G-E<B!["B`@("!F
M=6YC=&EO;B!?7U1E<W1087)S97(R*"D@>PH@("`@("`@("1T:&ES+3Y834Q?
M4&%R<V5R*"D["B`@("!]"B`@("!F=6YC=&EO;B!S=&%R=$AA;F1L97(H)'AP
M+"`D96QE;65N="P@)&%T=')I8G,I('L*("`@("`@("!P<FEN="`B/"1E;&5M
M96YT(CL*("`@("`@("!R97-E="@D871T<FEB<RD["B`@("`@("`@=VAI;&4@
M*&QI<W0H)&ME>2P@)'9A;"D@/2!E86-H*"1A='1R:6)S*2D@>PH@("`@("`@
M("`@("`D96YC(#T@:'1M;&5N=&ET:65S*"1V86PI.PH@("`@("`@("`@("!P
M<FEN="`B("1K97D]7"(D96YC7"(B.PH@("`@("`@('T*("`@("`@("!P<FEN
M="`B/B(["B`@("!]"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L
M96UE;G0I('L*("`@("`@("!P<FEN="`B/"\D96QE;65N=#Y<;B(["B`@("!]
M"B`@("!F=6YC=&EO;B!C9&%T84AA;F1L97(H)'AP+"`D8V1A=&$I('L*("`@
M("`@("!P<FEN="`B/"%;0T1!5$%;)&-D871A75T^(CL*("`@('T*("`@(&9U
M;F-T:6]N(&1E9F%U;'1(86YD;&5R*"1X<"P@)&-D871A*2!["@H@("`@?0I]
M"G!R:6YT(")N97<@7U]497-T4&%R<V5R,B`B.PIV87)?9'5M<"AG971?8VQA
M<W,H)&\@/2!N97<@7U]497-T4&%R<V5R,B@I*2D["G!R:6YT(")S971);G!U
M=$9I;&4@(CL*=F%R7V1U;7`H)&\M/G-E=$EN<'5T1FEL92@B=&5S=#(N>&UL
M(BDI.PIP<FEN="`B<&%R<V4@(CL*=F%R7V1U;7`H)&\M/G!A<G-E*"DI.PH*
M/SX*+2U%6%!%0U0M+0IN97<@7U]497-T4&%R<V5R,B!S=')I;F<H,3,I(")?
M7W1E<W1P87)S97(R(@IS971);G!U=$9I;&4@<F5S;W5R8V4H-"D@;V8@='EP
M92`H<W1R96%M*0IP87)S92`\4D]/5#X\(5M#1$%405MF;V]=73X\+U)/3U0^
M"F)O;VPH=')U92D*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T
M<R\P,#,N<&AP=```````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-#``,3`T,3<S
M-C,P,#,`,#(S,#$T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"TM5$535"TM"EA-3"!087)S97(Z('!A<G-E(&9R;VT@9FEL
M92!R97-O=7)C90HM+5-+25!)1BTM"CP_<&AP(&EF("@A97AT96YS:6]N7VQO
M861E9"@B>&UL(BDI(&5C:&\@)W-K:7`G.R`_/@HM+49)3$4M+0H\/W!H<"`O
M+R`M*BT@0RLK("TJ+0HO+PHO+R!497-T(&9O<CH@6$U,+U!A<G-E<BYP:'`*
M+R\@4&%R=',@=&5S=&5D.B`M('!A<G-E<B!C<F5A=&EO;@HO+R`@("`@("`@
M("`@("`@("T@<V]M92!H86YD;&5R<PHO+R`@("`@("`@("`@("`@("T@<&%R
M<V4@9G)O;2!F:6QE(')E<V]U<F-E"B\O"F-H9&ER("AD:7)N86UE*%]?1DE,
M15]?*2D["@IR97%U:7)E7V]N8V4@(EA-3"]087)S97(N<&AP(CL*"F-L87-S
M(%]?5&5S=%!A<G-E<C,@97AT96YD<R!834Q?4&%R<V5R('L*("`@(&9U;F-T
M:6]N(%]?5&5S=%!A<G-E<C,H*2!["B`@("`@("`@)'1H:7,M/EA-3%]087)S
M97(H*3L*("`@('T*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D>'`L("1E
M;&5M96YT+"`D871T<FEB<RD@>PH@("`@("`@('!R:6YT("(\)&5L96UE;G0B
M.PH@("`@("`@(')E<V5T*"1A='1R:6)S*3L*("`@("`@("!W:&EL92`H;&ES
M="@D:V5Y+"`D=F%L*2`](&5A8V@H)&%T=')I8G,I*2!["B`@("`@("`@("`@
M("1E;F,@/2!H=&UL96YT:71I97,H)'9A;"D["B`@("`@("`@("`@('!R:6YT
M("(@)&ME>3U<(B1E;F-<(B(["B`@("`@("`@?0H@("`@("`@('!R:6YT("(^
M(CL*("`@('T*("`@(&9U;F-T:6]N(&5N9$AA;F1L97(H)'AP+"`D96QE;65N
M="D@>PH@("`@("`@('!R:6YT("(\+R1E;&5M96YT/EQN(CL*("`@('T*("`@
M(&9U;F-T:6]N(&-D871A2&%N9&QE<B@D>'`L("1C9&%T82D@>PH@("`@("`@
M('!R:6YT("(\(5M#1$%405LD8V1A=&%=73XB.PH@("`@?0H@("`@9G5N8W1I
M;VX@9&5F875L=$AA;F1L97(H)'AP+"`D8V1A=&$I('L*"B`@("!]"GT*<')I
M;G0@(FYE=R!?7U1E<W1087)S97(S("(["G9A<E]D=6UP*&=E=%]C;&%S<R@D
M;R`](&YE=R!?7U1E<W1087)S97(S*"DI*3L*<')I;G0@(F9O<&5N("(["G9A
M<E]D=6UP*"1F<"`](&9O<&5N*")T97-T,RYX;6PB+"`B<B(I*3L*<')I;G0@
M(G-E=$EN<'5T("(["G9A<E]D=6UP*"1O+3YS971);G!U="@D9G`I*3L*<')I
M;G0@(G!A<G-E("(["G9A<E]D=6UP*"1O+3YP87)S92@I*3L*"C\^"BTM15A0
M14-4+2T*;F5W(%]?5&5S=%!A<G-E<C,@<W1R:6YG*#$S*2`B7U]T97-T<&%R
M<V5R,R(*9F]P96X@<F5S;W5R8V4H-"D@;V8@='EP92`H<W1R96%M*0IS971)
M;G!U="!B;V]L*'1R=64I"G!A<G-E(#Q23T]4/CPA6T-$051!6V9O;UU=/CPO
M4D]/5#X*8F]O;"AT<G5E*0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P-"YP:'!T````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3$R,@`Q,#0Q-S,V,S`P,P`P,C,P,3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2U415-4+2T*6$U,
M(%!A<G-E<CH@97)R;W(@8VQA<W,*+2U32TE0248M+0H\/W!H<"!I9B`H(65X
M=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO("=S:VEP)SL@/SX*+2U&24Q%
M+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*+R\*+R\@5&5S="!F;W(Z(%A-3"]0
M87)S97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@+2!P87)S97(@97)R;W(@8VQA
M<W,*+R\*"G)E<75I<F5?;VYC92`B6$U,+U!A<G-E<BYP:'`B.PH*<')I;G0@
M(FYE=R!834Q?4&%R<V5R("(["G9A<E]D=6UP*&=E=%]C;&%S<R@D<"`](&YE
M=R!834Q?4&%R<V5R*"DI*3L*)&4@/2`D<"T^<&%R<V53=')I;F<H(CP_>&UL
M('9E<G-I;VX])S$N,"<@/SX\9F]O/CPO8F%R/B(L('1R=64I.PII9B`H4$5!
M4CHZ:7-%<G)O<B@D92DI('L*("`@('!R:6YT9B@B97)R;W(@;65S<V%G93H@
M)7-<;B(L("1E+3YG971-97-S86=E*"DI.PI](&5L<V4@>PH@("`@<')I;G0@
M(FYO(&5R<F]R7&XB.PI]"@H_/@HM+4584$5#5"TM"FYE=R!834Q?4&%R<V5R
M('-T<FEN9R@Q,"D@(GAM;%]P87)S97(B"F5R<F]R(&UE<W-A9V4Z(%A-3%]0
M87)S97(Z(&UI<VUA=&-H960@=&%G(&%T(%A-3"!I;G!U="!L:6YE(#$*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P-2YP:'!T````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S8W-@`Q,#0Q-S,V,S`P,P`P,C,P,S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*6$U,(%!A<G-E<CH@;6EX:6YG(&-H87)A8W1E<B!E;F-O9&EN9W,*+2U3
M2TE0248M+0H\/W!H<"!I9B`H(65X=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E
M8VAO("=S:VEP)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*
M+R\*+R\@5&5S="!F;W(Z(%A-3"]087)S97(N<&AP"B\O(%!A<G1S('1E<W1E
M9#H@+2!M:7AI;F<@8VAA<F%C=&5R(&5N8V]D:6YG<PHO+PHO+R!4:&ES(&ES
M('=H870@=V4@=&5S=#H*+R\@,2!55$8M."`@("`@("T^($E33RTX.#4Y+3$*
M+R\@,B!55$8M."`@("`@("T^(%53+4%30TE)"B\O(#,@25-/+3@X-3DM,2`M
M/B!55$8M.`HO+R`T($E33RTX.#4Y+3$@+3X@55,M05-#24D*+R\@-2!54RU!
M4T-)22`@("T^(%541BTX"B\O(#8@55,M05-#24D@("`M/B!)4T\M.#@U.2TQ
M"B\O"@IR97%U:7)E7V]N8V4@(EA-3"]087)S97(N<&AP(CL*"F-L87-S(%1E
M<W1%;F-O9&EN9W,Q(&5X=&5N9',@6$U,7U!A<G-E<B!["B`@("!V87(@)&]U
M='!U="`]("<G.PH*("`@(&9U;F-T:6]N(%1E<W1%;F-O9&EN9W,Q*"1T;RP@
M)&9R;VTI('L*("`@("`@("`D=&AI<RT^6$U,7U!A<G-E<B@D9G)O;2P@)V5V
M96YT)RP@)'1O*3L*("`@('T*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D
M>'`L("1E;&5M+"`D871T<FEB<RD@>PH@("`@("`@("1T:&ES+3YO=71P=70@
M+CT@(CPD96QE;3XB.PH@("`@?0H@("`@9G5N8W1I;VX@96YD2&%N9&QE<B@D
M>'`L("1E;&5M*2!["B`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B/"\D96QE
M;3XB.PH@("`@?0H@("`@9G5N8W1I;VX@8V1A=&%(86YD;&5R*"1X<"P@)&1A
M=&$I('L*("`@("`@("`D=&AI<RT^;W5T<'5T("X]("1D871A.PH@("`@?0H@
M("`@9G5N8W1I;VX@=&5S="@D9&%T82D@>PH@("`@("`@("\O("1T:&ES+3YO
M=71P=70@/2`G)SL*("`@("`@("`D=&AI<RT^<&%R<V53=')I;F<H)&1A=&$L
M('1R=64I.PH@("`@("`@(')E='5R;B`D=&AI<RT^;W5T<'5T.PH@("`@?0I]
M"@HD>&UL(#T@(CP_>&UL('9E<G-I;VX])S$N,"<@/SXB.PHD:6YP=70@/2!A
M<G)A>2@*("`@(")55$8M."(@("`@("`]/B`B/&$^86)CPZ;#N,.E/"]A/B(L
M"B`@("`B25-/+3@X-3DM,2(@/3X@(CQA/F%B8^;XY3PO83XB+`H@("`@(E53
M+4%30TE)(B`@(#T^("(\83YA8F-A;V$\+V$^(@HI.PH*)&5N8V]D:6YG<R`]
M(&%R<F%Y7VME>7,H)&EN<'5T*3L*9F]R96%C:"`H)&EN<'5T(&%S("1S<F-E
M;F,@/3X@)'-T<FEN9RD@>PH@("`@9F]R96%C:"`H)&5N8V]D:6YG<R!A<R`D
M=&=T96YC*2!["B`@("`@("`@:68@*"1S<F-E;F,@/3T@)'1G=&5N8RD@>PH@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@<')I;G0@
M(E1E<W1I;F<@)'-R8V5N8R`M/B`D=&=T96YC.B`B.PH@("`@("`@("1P(#TF
M(&YE=R!497-T16YC;V1I;F=S,2@D=&=T96YC+"`D<W)C96YC*3L*("`@("`@
M("`D92`]("1P+3YT97-T*"1I;G!U=%LD<W)C96YC72D["B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&4I*2!["B`@("`@("`@("`@('!R:6YT9B@B3T]0
M4SH@)7-<;B(L("1E+3YG971-97-S86=E*"DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@('9A<E]D=6UP*"1E*3L*("`@("`@("!]"B`@("!]"GT*
M"C\^"BTM15A014-4+2T*5&5S=&EN9R!55$8M."`M/B!)4T\M.#@U.2TQ.B!S
M=')I;F<H,3,I("(\03YA8F/F^.4\+T$^(@I497-T:6YG(%541BTX("T^(%53
M+4%30TE).B!S=')I;F<H,3,I("(\03YA8F,_/S\\+T$^(@I497-T:6YG($E3
M3RTX.#4Y+3$@+3X@551&+3@Z('-T<FEN9R@Q-BD@(CQ!/F%B8\.FP[C#I3PO
M03XB"E1E<W1I;F<@25-/+3@X-3DM,2`M/B!54RU!4T-)23H@<W1R:6YG*#$S
M*2`B/$$^86)C/S\_/"]!/B(*5&5S=&EN9R!54RU!4T-)22`M/B!55$8M.#H@
M<W1R:6YG*#$S*2`B/$$^86)C86]A/"]!/B(*5&5S=&EN9R!54RU!4T-)22`M
M/B!)4T\M.#@U.2TQ.B!S=')I;F<H,3,I("(\03YA8F-A;V$\+T$^(@H`````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R]T97-T,BYX;6P`````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P-#<`,3`T,3<S-C,P,#,`,#(S-#`Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_>&UL('9E<G-I
M;VX])S$N,"<@/SX*/')O;W0^9F]O/"]R;V]T/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-
M3%]087)S97(O=&5S=',O=&5S=#,N>&UL````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#0W`#$P-#$W,S8S,#`S`#`R,S0P,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/WAM;"!V97)S:6]N/2<Q+C`G(#\^
M"CQR;V]T/F9O;SPO<F]O=#X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]497AT7U=I:VDO````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,S`P,P`P,C`T,3$`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+U1E>'1?5VEK:2]T97-T<R\`````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`S`#`R,34U,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O5&5X=%]7:6MI+W1E<W1S+U)%041-10``
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-34`,3`T,3<S-C,P,#,`,#(R
M-#,Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%!L86-E:&]L9&5R(&9O<B!497AT7U=I:VD@=6YI="!T97-T<RX*"D9O<B!N
M;W<L(&%T=&5M<'0@=&\@=')A;G-F;W)M('1H92!T:&4@9&]C<R]386UP;&50
M86=E+G=I:VDN='AT(&9I;&4N"@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+TYE=%]$24U%+P``````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`R,#`R-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3F5T7T1)344O=&5S="\`````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P
M,#0`,#(Q,#`V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R].
M971?1$E-12]T97-T+V1I;65?;65S<V%G95]T97-T+G!H<```````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`V,C8W,P`Q,#0Q-S,V,S`P-``P,C4R,3,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`-"FEN8VQU9&4@)TYE="]$
M24U%+G!H<"<[#0H-"B1T97-T/2<M+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C
M.&,X9#!B.&8W,&4-"D-O;G1E;G0M5'EP93H@=&5X="]X;6P[(&-H87)S970]
M(E541BTX(@T*#0H\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M
M."(_/@T*#0H\4T]!4"U%3E8Z16YV96QO<&4@('AM;&YS.E-/05`M14Y6/2)H
M='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R(-"B`@
M>&UL;G,Z>'-D/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82(-
M"B`@>&UL;G,Z>'-I/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M
M82UI;G-T86YC92(-"B`@>&UL;G,Z4T]!4"U%3D,](FAT='`Z+R]S8VAE;6%S
M+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O(@T*("!33T%0+45.5CIE;F-O
M9&EN9U-T>6QE/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N
M8V]D:6YG+R(^#0H\4T]!4"U%3E8Z0F]D>3X-"@T*/&5C:&]-:6UE071T86-H
M;65N=#X-"CQT97-T(&AR968](F-I9#IA,C(S9F5A,V,S-6(U9C!E-F1E9&8X
M9&$W-65F9#9B,R(O/CPO96-H;TUI;65!='1A8VAM96YT/@T*/"]33T%0+45.
M5CI";V1Y/@T*/"]33T%0+45.5CI%;G9E;&]P93X-"@T*+2T]7V$R8V)B,#4Q
M-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT+41I<W!O<VET:6]N
M.B!A='1A8VAM96YT+G!H<`T*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN#0I#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B!B87-E-C0-"D-O;G1E;G0M240Z
M(#QA,C(S9F5A,V,S-6(U9C!E-F1E9&8X9&$W-65F9#9B,SX-"@T*4$0Y=V%(
M04Y#;DIL8UA6<&-M5F9B,C5J6E-G:54P.4)50SE$8D=L;&)N475C1VAW26EK
M-T11<'E:6$8Q85A*;%@R.759,E5O26Q.4`T*459!=F1'5GID0SDP6EA.,$QN
M5C!A5WAP9$AK=6-':'=):6LW1%%P>5I81C%A6$IL6#(Y=5DR56]);$Y0459!
M=E9M1G-D5U5U8T=H=PT*26EK-T11;VMC,CEH8T8Y:5E83FQ)1#!G8FU6,TE&
M3E!15D)F46U&>EI39W!/=S!+1%%O:V1I03E)0T)U6EAC9U4P.4)51CE"9$A2
M:`T*63)H=%I7-3!+0V0P6EA.,$IY=VYD1U8T9$,Y=V)'1G!B:6-S2C)&,&1'
M1FIA1S%L8FY1=6-':'=*>6LW1%%O:V)75C!A1SEK5FU&<PT*9%=59U!30G5:
M6&-G53`Y0E5&.5=95W@Q6E-G;F1'5GID1T8P9$=&:F%#8W-)0V149$A*,5DS
M46Y,0T)H8VY*:&539VMD:6MP3W<P2PT*1%%O=DQY0GI:5U5G9$=H;$E',7!B
M5U5G65A*>5E8:TY#:3AV2DA::&)#03E)0U)Z8C)&=U@R2FAC,E5T4&PY=%E7
M=&Q25S4R6E=X=@T*8T=5;TI',6QD1VAV6D9::&)(5FQ+5'-.0VDX=F-(2G!B
M;E)F8VEG:V1M1G-+5'-.0V<P2TI'3G-A5U9U9$-!.4E'-6QD>4)45#!&40T*
M6#!.<V%75G5D0V=N84A2,&-$;W9,,GAV63)&<V%'.7ID0SEZ8C)&=U@R;'5D
M1U9Y8C-!=F,R5GED;59Y6#-*=F17-6M-:35W84A!;@T*2U1S3D-I4GE:6$YW
M240P9TI'3G-A5U9U9$,P*UDR1G-B0V=N6E=.;V(P,7!B5U9"9$A2:%DR:'1:
M5S4P2GEX:&-N2FAE4V=K9&EK<`T*3W<P2TDS0GEA5S4P6#-);TI(2FQC,T%P
M3W<P2V-(2G!B;E%G2D=.<V%75G5D0S`K9#)L>5I4<TY#:C@K#0HM+3U?83)C
M8F(P-3$T,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4M+0T*+2T]7V$R8V)B,#4Q
M-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT+51Y<&4Z('1E>'0O
M>&UL.R!C:&%R<V5T/2)55$8M."(-"@T*/#]X;6P@=F5R<VEO;CTB,2XP(B!E
M;F-O9&EN9STB551&+3@B/SX-"@T*/%-/05`M14Y6.D5N=F5L;W!E("!X;6QN
M<SI33T%0+45.5CTB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E
M;G9E;&]P92\B#0H@('AM;&YS.GAS9#TB:'1T<#HO+W=W=RYW,RYO<F<O,C`P
M,2]834Q38VAE;6$B#0H@('AM;&YS.GAS:3TB:'1T<#HO+W=W=RYW,RYO<F<O
M,C`P,2]834Q38VAE;6$M:6YS=&%N8V4B#0H@('AM;&YS.E-/05`M14Y#/2)H
M='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N8V]D:6YG+R(-"B`@
M4T]!4"U%3E8Z96YC;V1I;F=3='EL93TB:'1T<#HO+W-C:&5M87,N>&UL<V]A
M<"YO<F<O<V]A<"]E;F-O9&EN9R\B/@T*/%-/05`M14Y6.D)O9'D^#0H-"CQE
M8VAO36EM94%T=&%C:&UE;G0^#0H\=&5S="!H<F5F/2)C:60Z83(R,V9E83-C
M,S5B-68P939D961F.&1A-S5E9F0V8C,B+SX\+V5C:&]-:6UE071T86-H;65N
M=#X-"CPO4T]!4"U%3E8Z0F]D>3X-"CPO4T]!4"U%3E8Z16YV96QO<&4^#0H-
M"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P90T*0V]N=&5N
M="U$:7-P;W-I=&EO;CH@871T86-H;65N="YP:'`-"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;@T*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@8F%S938T
M#0I#;VYT96YT+4E$.B`\83(R,V9E83-C,S5B-68P939D961F.&1A-S5E9F0V
M8C,^#0H-"E!$.7=A2$%.0VY*;&-85G!C;59F8C(U:EI39VE5,#E"54,Y1&)'
M;&QB;E%U8T=H=TEI:S=$47!Y6EA&,6%82FQ8,CEU63)5;TEL3E`-"E%6079D
M1U9Z9$,Y,%I83C!,;E8P85=X<&1(:W5C1VAW26EK-T11<'E:6$8Q85A*;%@R
M.759,E5O26Q.4%%60796;49S9%=5=6-':'<-"DEI:S=$46]K8S(Y:&-&.6E9
M6$YL240P9V)M5C-)1DY0459"9E%M1GI:4V=P3W<P2T11;VMD:4$Y24-"=5I8
M8V=5,#E"548Y0F1(4F@-"EDR:'1:5S4P2T-D,%I83C!*>7=N9$=6-&1#.7=B
M1T9P8FEC<THR1C!D1T9J84<Q;&)N475C1VAW2GEK-T11;VMB5U8P84<Y:U9M
M1G,-"F1756=04T)U6EAC9U4P.4)51CE765=X,5I39VYD1U9Z9$=&,&1'1FIA
M0V-S24-D5&1(2C%9,U%N3$-":&-N2FAE4V=K9&EK<$]W,$L-"D11;W9,>4)Z
M6E=59V1':&Q)1S%P8E=59UE82GE96&M.0VDX=DI(6FAB0T$Y24-2>F(R1G=8
M,DIH8S)5=%!L.7195W1L4E<U,EI7>'8-"F-'56]*1S%L9$=H=EI&6FAB2%9L
M2U1S3D-I.'9C2$IP8FY29F-I9VMD;49S2U1S3D-G,$M*1TYS85=6=61#03E)
M1S5L9'E"5%0P1E$-"E@P3G-A5U9U9$-G;F%(4C!C1&]V3#)X=EDR1G-A1SEZ
M9$,Y>F(R1G=8,FQU9$=6>6(S079C,E9Y9&U6>5@S2G9D5S5K36DU=V%(06X-
M"DM4<TY#:5)Y6EA.=TE$,&=*1TYS85=6=61#,"M9,D9S8D-G;EI73F]B,#%P
M8E=60F1(4FA9,FAT6E<U,$IY>&AC;DIH95-G:V1I:W`-"D]W,$M),T)Y85<U
M,%@S26]*2$IL8S-!<$]W,$MC2$IP8FY19TI'3G-A5U9U9$,P*V0R;'E:5'-.
M0VHX*PT*+2T]7V$R8V)B,#4Q-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E+2T-
M"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P90T*0V]N=&5N
M="U4>7!E.B!T97AT+WAM;#L@8VAA<G-E=#TB551&+3@B#0H-"CP_>&UL('9E
M<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX(C\^#0H-"CQ33T%0+45.5CI%
M;G9E;&]P92`@>&UL;G,Z4T]!4"U%3E8](FAT='`Z+R]S8VAE;6%S+GAM;'-O
M87`N;W)G+W-O87`O96YV96QO<&4O(@T*("!X;6QN<SIX<V0](FAT='`Z+R]W
M=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA(@T*("!X;6QN<SIX<VD](FAT='`Z
M+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E(@T*("!X;6QN
M<SI33T%0+45.0STB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E
M;F-O9&EN9R\B#0H@(%-/05`M14Y6.F5N8V]D:6YG4W1Y;&4](FAT='`Z+R]S
M8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O(CX-"CQ33T%0+45.
M5CI";V1Y/@T*#0H\96-H;TUI;65!='1A8VAM96YT/@T*/'1E<W0@:')E9CTB
M8VED.F$R,C-F96$S8S,U8C5F,&4V9&5D9CAD83<U969D-F(S(B\^/"]E8VAO
M36EM94%T=&%C:&UE;G0^#0H\+U-/05`M14Y6.D)O9'D^#0H\+U-/05`M14Y6
M.D5N=F5L;W!E/@T*#0HM+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C.&,X9#!B
M.&8W,&4-"D-O;G1E;G0M1&ES<&]S:71I;VXZ(&%T=&%C:&UE;G0N<&AP#0I#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X-"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(&)A<V4V-`T*0V]N=&5N="U)1#H@/&$R,C-F96$S8S,U8C5F,&4V
M9&5D9CAD83<U969D-F(S/@T*#0I01#EW84A!3D-N2FQC6%9P8VU69F(R-6I:
M4V=I53`Y0E5#.41B1VQL8FY1=6-':'=):6LW1%%P>5I81C%A6$IL6#(Y=5DR
M56]);$Y0#0I15D%V9$=6>F1#.3!:6$XP3&Y6,&%7>'!D2&MU8T=H=TEI:S=$
M47!Y6EA&,6%82FQ8,CEU63)5;TEL3E!15D%V5FU&<V17575C1VAW#0I):6LW
M1%%O:V,R.6AC1CEI65A.;$E$,&=B;58S249.4%%60F91;49Z6E-G<$]W,$M$
M46]K9&E!.4E#0G5:6&-G53`Y0E5&.4)D2%)H#0I9,FAT6E<U,$M#9#!:6$XP
M2GEW;F1'5C1D0SEW8D=&<&)I8W-*,D8P9$=&:F%',6QB;E%U8T=H=TIY:S=$
M46]K8E=6,&%'.6M6;49S#0ID5U5G4%-"=5I88V=5,#E"548Y5UE7>#%:4V=N
M9$=6>F1'1C!D1T9J84-C<TE#9%1D2$HQ63-1;DQ#0FAC;DIH95-G:V1I:W!/
M=S!+#0I$46]V3'E">EI756=D1VAL24<Q<&)756=96$IY65AK3D-I.'9*2%IH
M8D-!.4E#4GIB,D9W6#)*:&,R5710;#ET65=T;%)7-3):5WAV#0IC1U5O2D<Q
M;&1':'9:1EIH8DA6;$M4<TY#:3AV8TA*<&)N4F9C:6=K9&U&<TM4<TY#9S!+
M2D=.<V%75G5D0T$Y24<U;&1Y0E14,$91#0I8,$YS85=6=61#9VYA2%(P8T1O
M=DPR>'99,D9S84<Y>F1#.7IB,D9W6#)L=61'5GEB,T%V8S)6>61M5GE8,TIV
M9%<U:TUI-7=A2$%N#0I+5'-.0VE2>5I83G=)1#!G2D=.<V%75G5D0S`K63)&
M<V)#9VY:5TYO8C`Q<&)75D)D2%)H63)H=%I7-3!*>7AH8VY*:&539VMD:6MP
M#0I/=S!+23-">6%7-3!8,TEO2DA*;&,S07!/=S!+8TA*<&)N46=*1TYS85=6
M=61#,"MD,FQY6E1S3D-J."L-"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X
M8SAD,&(X9C<P92TM#0HM+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C.&,X9#!B
M.&8W,&4-"D-O;G1E;G0M5'EP93H@=&5X="]X;6P[(&-H87)S970](E541BTX
M(@T*#0H\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M."(_/@T*
M#0H\4T]!4"U%3E8Z16YV96QO<&4@('AM;&YS.E-/05`M14Y6/2)H='1P.B\O
M<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R(-"B`@>&UL;G,Z
M>'-D/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82(-"B`@>&UL
M;G,Z>'-I/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T
M86YC92(-"B`@>&UL;G,Z4T]!4"U%3D,](FAT='`Z+R]S8VAE;6%S+GAM;'-O
M87`N;W)G+W-O87`O96YC;V1I;F<O(@T*("!33T%0+45.5CIE;F-O9&EN9U-T
M>6QE/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N8V]D:6YG
M+R(^#0H\4T]!4"U%3E8Z0F]D>3X-"@T*/&5C:&]-:6UE071T86-H;65N=#X-
M"CQT97-T(&AR968](F-I9#IA,C(S9F5A,V,S-6(U9C!E-F1E9&8X9&$W-65F
M9#9B,R(O/CPO96-H;TUI;65!='1A8VAM96YT/@T*/"]33T%0+45.5CI";V1Y
M/@T*/"]33T%0+45.5CI%;G9E;&]P93X-"@T*+2T]7V$R8V)B,#4Q-#(T8V,T
M,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT+41I<W!O<VET:6]N.B!A='1A
M8VAM96YT+G!H<`T*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN#0I#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B!B87-E-C0-"D-O;G1E;G0M240Z(#QA,C(S
M9F5A,V,S-6(U9C!E-F1E9&8X9&$W-65F9#9B,SX-"@T*4$0Y=V%(04Y#;DIL
M8UA6<&-M5F9B,C5J6E-G:54P.4)50SE$8D=L;&)N475C1VAW26EK-T11<'E:
M6$8Q85A*;%@R.759,E5O26Q.4`T*459!=F1'5GID0SDP6EA.,$QN5C!A5WAP
M9$AK=6-':'=):6LW1%%P>5I81C%A6$IL6#(Y=5DR56]);$Y0459!=E9M1G-D
M5U5U8T=H=PT*26EK-T11;VMC,CEH8T8Y:5E83FQ)1#!G8FU6,TE&3E!15D)F
M46U&>EI39W!/=S!+1%%O:V1I03E)0T)U6EAC9U4P.4)51CE"9$A2:`T*63)H
M=%I7-3!+0V0P6EA.,$IY=VYD1U8T9$,Y=V)'1G!B:6-S2C)&,&1'1FIA1S%L
M8FY1=6-':'=*>6LW1%%O:V)75C!A1SEK5FU&<PT*9%=59U!30G5:6&-G53`Y
M0E5&.5=95W@Q6E-G;F1'5GID1T8P9$=&:F%#8W-)0V149$A*,5DS46Y,0T)H
M8VY*:&539VMD:6MP3W<P2PT*1%%O=DQY0GI:5U5G9$=H;$E',7!B5U5G65A*
M>5E8:TY#:3AV2DA::&)#03E)0U)Z8C)&=U@R2FAC,E5T4&PY=%E7=&Q25S4R
M6E=X=@T*8T=5;TI',6QD1VAV6D9::&)(5FQ+5'-.0VDX=F-(2G!B;E)F8VEG
M:V1M1G-+5'-.0V<P2TI'3G-A5U9U9$-!.4E'-6QD>4)45#!&40T*6#!.<V%7
M5G5D0V=N84A2,&-$;W9,,GAV63)&<V%'.7ID0SEZ8C)&=U@R;'5D1U9Y8C-!
M=F,R5GED;59Y6#-*=F17-6M-:35W84A!;@T*2U1S3D-I4GE:6$YW240P9TI'
M3G-A5U9U9$,P*UDR1G-B0V=N6E=.;V(P,7!B5U9"9$A2:%DR:'1:5S4P2GEX
M:&-N2FAE4V=K9&EK<`T*3W<P2TDS0GEA5S4P6#-);TI(2FQC,T%P3W<P2V-(
M2G!B;E%G2D=.<V%75G5D0S`K9#)L>5I4<TY#:C@K#0HM+3U?83)C8F(P-3$T
M,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4M+0T*+2T]7V$R8V)B,#4Q-#(T8V,T
M,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT+51Y<&4Z('1E>'0O>&UL.R!C
M:&%R<V5T/2)55$8M."(-"@T*/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN
M9STB551&+3@B/SX-"@T*/%-/05`M14Y6.D5N=F5L;W!E("!X;6QN<SI33T%0
M+45.5CTB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E;G9E;&]P
M92\B#0H@('AM;&YS.GAS9#TB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,2]834Q3
M8VAE;6$B#0H@('AM;&YS.GAS:3TB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,2]8
M34Q38VAE;6$M:6YS=&%N8V4B#0H@('AM;&YS.E-/05`M14Y#/2)H='1P.B\O
M<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N8V]D:6YG+R(-"B`@4T]!4"U%
M3E8Z96YC;V1I;F=3='EL93TB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O
M<V]A<"]E;F-O9&EN9R\B/@T*/%-/05`M14Y6.D)O9'D^#0H-"CQE8VAO36EM
M94%T=&%C:&UE;G0^#0H\=&5S="!H<F5F/2)C:60Z83(R,V9E83-C,S5B-68P
M939D961F.&1A-S5E9F0V8C,B+SX\+V5C:&]-:6UE071T86-H;65N=#X-"CPO
M4T]!4"U%3E8Z0F]D>3X-"CPO4T]!4"U%3E8Z16YV96QO<&4^#0H-"BTM/5]A
M,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P90T*0V]N=&5N="U$:7-P
M;W-I=&EO;CH@871T86-H;65N="YP:'`-"D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;@T*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@8F%S938T#0I#;VYT
M96YT+4E$.B`\83(R,V9E83-C,S5B-68P939D961F.&1A-S5E9F0V8C,^#0H-
M"E!$.7=A2$%.0VY*;&-85G!C;59F8C(U:EI39VE5,#E"54,Y1&)';&QB;E%U
M8T=H=TEI:S=$47!Y6EA&,6%82FQ8,CEU63)5;TEL3E`-"E%6079D1U9Z9$,Y
M,%I83C!,;E8P85=X<&1(:W5C1VAW26EK-T11<'E:6$8Q85A*;%@R.759,E5O
M26Q.4%%60796;49S9%=5=6-':'<-"DEI:S=$46]K8S(Y:&-&.6E96$YL240P
M9V)M5C-)1DY0459"9E%M1GI:4V=P3W<P2T11;VMD:4$Y24-"=5I88V=5,#E"
M548Y0F1(4F@-"EDR:'1:5S4P2T-D,%I83C!*>7=N9$=6-&1#.7=B1T9P8FEC
M<THR1C!D1T9J84<Q;&)N475C1VAW2GEK-T11;VMB5U8P84<Y:U9M1G,-"F17
M56=04T)U6EAC9U4P.4)51CE765=X,5I39VYD1U9Z9$=&,&1'1FIA0V-S24-D
M5&1(2C%9,U%N3$-":&-N2FAE4V=K9&EK<$]W,$L-"D11;W9,>4)Z6E=59V1'
M:&Q)1S%P8E=59UE82GE96&M.0VDX=DI(6FAB0T$Y24-2>F(R1G=8,DIH8S)5
M=%!L.7195W1L4E<U,EI7>'8-"F-'56]*1S%L9$=H=EI&6FAB2%9L2U1S3D-I
M.'9C2$IP8FY29F-I9VMD;49S2U1S3D-G,$M*1TYS85=6=61#03E)1S5L9'E"
M5%0P1E$-"E@P3G-A5U9U9$-G;F%(4C!C1&]V3#)X=EDR1G-A1SEZ9$,Y>F(R
M1G=8,FQU9$=6>6(S079C,E9Y9&U6>5@S2G9D5S5K36DU=V%(06X-"DM4<TY#
M:5)Y6EA.=TE$,&=*1TYS85=6=61#,"M9,D9S8D-G;EI73F]B,#%P8E=60F1(
M4FA9,FAT6E<U,$IY>&AC;DIH95-G:V1I:W`-"D]W,$M),T)Y85<U,%@S26]*
M2$IL8S-!<$]W,$MC2$IP8FY19TI'3G-A5U9U9$,P*V0R;'E:5'-.0VHX*PT*
M+2T]7V$R8V)B,#4Q-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E+2T-"BTM/5]A
M,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P90T*0V]N=&5N="U4>7!E
M.B!T97AT+WAM;#L@8VAA<G-E=#TB551&+3@B#0H-"CP_>&UL('9E<G-I;VX]
M(C$N,"(@96YC;V1I;F<](E541BTX(C\^#0H-"CQ33T%0+45.5CI%;G9E;&]P
M92`@>&UL;G,Z4T]!4"U%3E8](FAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G
M+W-O87`O96YV96QO<&4O(@T*("!X;6QN<SIX<V0](FAT='`Z+R]W=W<N=S,N
M;W)G+S(P,#$O6$U,4V-H96UA(@T*("!X;6QN<SIX<VD](FAT='`Z+R]W=W<N
M=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E(@T*("!X;6QN<SI33T%0
M+45.0STB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E;F-O9&EN
M9R\B#0H@(%-/05`M14Y6.F5N8V]D:6YG4W1Y;&4](FAT='`Z+R]S8VAE;6%S
M+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O(CX-"CQ33T%0+45.5CI";V1Y
M/@T*#0H\96-H;TUI;65!='1A8VAM96YT/@T*/'1E<W0@:')E9CTB8VED.F$R
M,C-F96$S8S,U8C5F,&4V9&5D9CAD83<U969D-F(S(B\^/"]E8VAO36EM94%T
M=&%C:&UE;G0^#0H\+U-/05`M14Y6.D)O9'D^#0H\+U-/05`M14Y6.D5N=F5L
M;W!E/@T*#0HM+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4-
M"D-O;G1E;G0M1&ES<&]S:71I;VXZ(&%T=&%C:&UE;G0N<&AP#0I#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X-"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(&)A<V4V-`T*0V]N=&5N="U)1#H@/&$R,C-F96$S8S,U8C5F,&4V9&5D9CAD
M83<U969D-F(S/@T*#0I01#EW84A!3D-N2FQC6%9P8VU69F(R-6I:4V=I53`Y
M0E5#.41B1VQL8FY1=6-':'=):6LW1%%P>5I81C%A6$IL6#(Y=5DR56]);$Y0
M#0I15D%V9$=6>F1#.3!:6$XP3&Y6,&%7>'!D2&MU8T=H=TEI:S=$47!Y6EA&
M,6%82FQ8,CEU63)5;TEL3E!15D%V5FU&<V17575C1VAW#0I):6LW1%%O:V,R
M.6AC1CEI65A.;$E$,&=B;58S249.4%%60F91;49Z6E-G<$]W,$M$46]K9&E!
M.4E#0G5:6&-G53`Y0E5&.4)D2%)H#0I9,FAT6E<U,$M#9#!:6$XP2GEW;F1'
M5C1D0SEW8D=&<&)I8W-*,D8P9$=&:F%',6QB;E%U8T=H=TIY:S=$46]K8E=6
M,&%'.6M6;49S#0ID5U5G4%-"=5I88V=5,#E"548Y5UE7>#%:4V=N9$=6>F1'
M1C!D1T9J84-C<TE#9%1D2$HQ63-1;DQ#0FAC;DIH95-G:V1I:W!/=S!+#0I$
M46]V3'E">EI756=D1VAL24<Q<&)756=96$IY65AK3D-I.'9*2%IH8D-!.4E#
M4GIB,D9W6#)*:&,R5710;#ET65=T;%)7-3):5WAV#0IC1U5O2D<Q;&1':'9:
M1EIH8DA6;$M4<TY#:3AV8TA*<&)N4F9C:6=K9&U&<TM4<TY#9S!+2D=.<V%7
M5G5D0T$Y24<U;&1Y0E14,$91#0I8,$YS85=6=61#9VYA2%(P8T1O=DPR>'99
M,D9S84<Y>F1#.7IB,D9W6#)L=61'5GEB,T%V8S)6>61M5GE8,TIV9%<U:TUI
M-7=A2$%N#0I+5'-.0VE2>5I83G=)1#!G2D=.<V%75G5D0S`K63)&<V)#9VY:
M5TYO8C`Q<&)75D)D2%)H63)H=%I7-3!*>7AH8VY*:&539VMD:6MP#0I/=S!+
M23-">6%7-3!8,TEO2DA*;&,S07!/=S!+8TA*<&)N46=*1TYS85=6=61#,"MD
M,FQY6E1S3D-J."L-"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X
M9C<P92TM#0HM+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4-
M"D-O;G1E;G0M5'EP93H@=&5X="]X;6P[(&-H87)S970](E541BTX(@T*#0H\
M/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M."(_/@T*#0H\4T]!
M4"U%3E8Z16YV96QO<&4@('AM;&YS.E-/05`M14Y6/2)H='1P.B\O<V-H96UA
M<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R(-"B`@>&UL;G,Z>'-D/2)H
M='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82(-"B`@>&UL;G,Z>'-I
M/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC92(-
M"B`@>&UL;G,Z4T]!4"U%3D,](FAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G
M+W-O87`O96YC;V1I;F<O(@T*("!33T%0+45.5CIE;F-O9&EN9U-T>6QE/2)H
M='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N8V]D:6YG+R(^#0H\
M4T]!4"U%3E8Z0F]D>3X-"@T*/&5C:&]-:6UE071T86-H;65N=#X-"CQT97-T
M(&AR968](F-I9#IA,C(S9F5A,V,S-6(U9C!E-F1E9&8X9&$W-65F9#9B,R(O
M/CPO96-H;TUI;65!='1A8VAM96YT/@T*/"]33T%0+45.5CI";V1Y/@T*/"]3
M3T%0+45.5CI%;G9E;&]P93X-"@T*+2T]7V$R8V)B,#4Q-#(T8V,T,V4W,F0S
M8SAC.&0P8CAF-S!E#0I#;VYT96YT+41I<W!O<VET:6]N.B!A='1A8VAM96YT
M+G!H<`T*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN#0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B!B87-E-C0-"D-O;G1E;G0M240Z(#QA,C(S9F5A,V,S
M-6(U9C!E-F1E9&8X9&$W-65F9#9B,SX-"@T*4$0Y=V%(04Y#;DIL8UA6<&-M
M5F9B,C5J6E-G:54P.4)50SE$8D=L;&)N475C1VAW26EK-T11<'E:6$8Q85A*
M;%@R.759,E5O26Q.4`T*459!=F1'5GID0SDP6EA.,$QN5C!A5WAP9$AK=6-'
M:'=):6LW1%%P>5I81C%A6$IL6#(Y=5DR56]);$Y0459!=E9M1G-D5U5U8T=H
M=PT*26EK-T11;VMC,CEH8T8Y:5E83FQ)1#!G8FU6,TE&3E!15D)F46U&>EI3
M9W!/=S!+1%%O:V1I03E)0T)U6EAC9U4P.4)51CE"9$A2:`T*63)H=%I7-3!+
M0V0P6EA.,$IY=VYD1U8T9$,Y=V)'1G!B:6-S2C)&,&1'1FIA1S%L8FY1=6-'
M:'=*>6LW1%%O:V)75C!A1SEK5FU&<PT*9%=59U!30G5:6&-G53`Y0E5&.5=9
M5W@Q6E-G;F1'5GID1T8P9$=&:F%#8W-)0V149$A*,5DS46Y,0T)H8VY*:&53
M9VMD:6MP3W<P2PT*1%%O=DQY0GI:5U5G9$=H;$E',7!B5U5G65A*>5E8:TY#
M:3AV2DA::&)#03E)0U)Z8C)&=U@R2FAC,E5T4&PY=%E7=&Q25S4R6E=X=@T*
M8T=5;TI',6QD1VAV6D9::&)(5FQ+5'-.0VDX=F-(2G!B;E)F8VEG:V1M1G-+
M5'-.0V<P2TI'3G-A5U9U9$-!.4E'-6QD>4)45#!&40T*6#!.<V%75G5D0V=N
M84A2,&-$;W9,,GAV63)&<V%'.7ID0SEZ8C)&=U@R;'5D1U9Y8C-!=F,R5GED
M;59Y6#-*=F17-6M-:35W84A!;@T*2U1S3D-I4GE:6$YW240P9TI'3G-A5U9U
M9$,P*UDR1G-B0V=N6E=.;V(P,7!B5U9"9$A2:%DR:'1:5S4P2GEX:&-N2FAE
M4V=K9&EK<`T*3W<P2TDS0GEA5S4P6#-);TI(2FQC,T%P3W<P2V-(2G!B;E%G
M2D=.<V%75G5D0S`K9#)L>5I4<TY#:C@K#0HM+3U?83)C8F(P-3$T,C1C8S0S
M93<R9#-C.&,X9#!B.&8W,&4M+2TM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X
M8SAD,&(X9C<P90T*0V]N=&5N="U4>7!E.B!T97AT+WAM;#L@8VAA<G-E=#TB
M551&+3@B#0H-"CP_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX
M(C\^#0H-"CQ33T%0+45.5CI%;G9E;&]P92`@>&UL;G,Z4T]!4"U%3E8](FAT
M='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YV96QO<&4O(@T*("!X
M;6QN<SIX<V0](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA(@T*
M("!X;6QN<SIX<VD](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA
M+6EN<W1A;F-E(@T*("!X;6QN<SI33T%0+45.0STB:'1T<#HO+W-C:&5M87,N
M>&UL<V]A<"YO<F<O<V]A<"]E;F-O9&EN9R\B#0H@(%-/05`M14Y6.F5N8V]D
M:6YG4W1Y;&4](FAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC
M;V1I;F<O(CX-"CQ33T%0+45.5CI";V1Y/@T*#0H\96-H;TUI;65!='1A8VAM
M96YT/@T*/'1E<W0@:')E9CTB8VED.F$R,C-F96$S8S,U8C5F,&4V9&5D9CAD
M83<U969D-F(S(B\^/"]E8VAO36EM94%T=&%C:&UE;G0^#0H\+U-/05`M14Y6
M.D)O9'D^#0H\+U-/05`M14Y6.D5N=F5L;W!E/@T*#0HM+3U?83)C8F(P-3$T
M,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4-"D-O;G1E;G0M1&ES<&]S:71I;VXZ
M(&%T=&%C:&UE;G0N<&AP#0I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X-"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(&)A<V4V-`T*0V]N=&5N="U)1#H@
M/&$R,C-F96$S8S,U8C5F,&4V9&5D9CAD83<U969D-F(S/@T*#0I01#EW84A!
M3D-N2FQC6%9P8VU69F(R-6I:4V=I53`Y0E5#.41B1VQL8FY1=6-':'=):6LW
M1%%P>5I81C%A6$IL6#(Y=5DR56]);$Y0#0I15D%V9$=6>F1#.3!:6$XP3&Y6
M,&%7>'!D2&MU8T=H=TEI:S=$47!Y6EA&,6%82FQ8,CEU63)5;TEL3E!15D%V
M5FU&<V17575C1VAW#0I):6LW1%%O:V,R.6AC1CEI65A.;$E$,&=B;58S249.
M4%%60F91;49Z6E-G<$]W,$M$46]K9&E!.4E#0G5:6&-G53`Y0E5&.4)D2%)H
M#0I9,FAT6E<U,$M#9#!:6$XP2GEW;F1'5C1D0SEW8D=&<&)I8W-*,D8P9$=&
M:F%',6QB;E%U8T=H=TIY:S=$46]K8E=6,&%'.6M6;49S#0ID5U5G4%-"=5I8
M8V=5,#E"548Y5UE7>#%:4V=N9$=6>F1'1C!D1T9J84-C<TE#9%1D2$HQ63-1
M;DQ#0FAC;DIH95-G:V1I:W!/=S!+#0I$46]V3'E">EI756=D1VAL24<Q<&)7
M56=96$IY65AK3D-I.'9*2%IH8D-!.4E#4GIB,D9W6#)*:&,R5710;#ET65=T
M;%)7-3):5WAV#0IC1U5O2D<Q;&1':'9:1EIH8DA6;$M4<TY#:3AV8TA*<&)N
M4F9C:6=K9&U&<TM4<TY#9S!+2D=.<V%75G5D0T$Y24<U;&1Y0E14,$91#0I8
M,$YS85=6=61#9VYA2%(P8T1O=DPR>'99,D9S84<Y>F1#.7IB,D9W6#)L=61'
M5GEB,T%V8S)6>61M5GE8,TIV9%<U:TUI-7=A2$%N#0I+5'-.0VE2>5I83G=)
M1#!G2D=.<V%75G5D0S`K63)&<V)#9VY:5TYO8C`Q<&)75D)D2%)H63)H=%I7
M-3!*>7AH8VY*:&539VMD:6MP#0I/=S!+23-">6%7-3!8,TEO2DA*;&,S07!/
M=S!+8TA*<&)N46=*1TYS85=6=61#,"MD,FQY6E1S3D-J."L-"BTM/5]A,F-B
M8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P92TM#0HM+3U?83)C8F(P-3$T
M,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4-"D-O;G1E;G0M5'EP93H@=&5X="]X
M;6P[(&-H87)S970](E541BTX(@T*#0H\/WAM;"!V97)S:6]N/2(Q+C`B(&5N
M8V]D:6YG/2)55$8M."(_/@T*#0H\4T]!4"U%3E8Z16YV96QO<&4@('AM;&YS
M.E-/05`M14Y6/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N
M=F5L;W!E+R(-"B`@>&UL;G,Z>'-D/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q
M+UA-3%-C:&5M82(-"B`@>&UL;G,Z>'-I/2)H='1P.B\O=W=W+G<S+F]R9R\R
M,#`Q+UA-3%-C:&5M82UI;G-T86YC92(-"B`@>&UL;G,Z4T]!4"U%3D,](FAT
M='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O(@T*("!3
M3T%0+45.5CIE;F-O9&EN9U-T>6QE/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P
M+F]R9R]S;V%P+V5N8V]D:6YG+R(^#0H\4T]!4"U%3E8Z0F]D>3X-"@T*/&5C
M:&]-:6UE071T86-H;65N=#X-"CQT97-T(&AR968](F-I9#IA,C(S9F5A,V,S
M-6(U9C!E-F1E9&8X9&$W-65F9#9B,R(O/CPO96-H;TUI;65!='1A8VAM96YT
M/@T*/"]33T%0+45.5CI";V1Y/@T*/"]33T%0+45.5CI%;G9E;&]P93X-"@T*
M+2T]7V$R8V)B,#4Q-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT
M+41I<W!O<VET:6]N.B!A='1A8VAM96YT+G!H<`T*0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN#0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B!B87-E-C0-
M"D-O;G1E;G0M240Z(#QA,C(S9F5A,V,S-6(U9C!E-F1E9&8X9&$W-65F9#9B
M,SX-"@T*4$0Y=V%(04Y#;DIL8UA6<&-M5F9B,C5J6E-G:54P.4)50SE$8D=L
M;&)N475C1VAW26EK-T11<'E:6$8Q85A*;%@R.759,E5O26Q.4`T*459!=F1'
M5GID0SDP6EA.,$QN5C!A5WAP9$AK=6-':'=):6LW1%%P>5I81C%A6$IL6#(Y
M=5DR56]);$Y0459!=E9M1G-D5U5U8T=H=PT*26EK-T11;VMC,CEH8T8Y:5E8
M3FQ)1#!G8FU6,TE&3E!15D)F46U&>EI39W!/=S!+1%%O:V1I03E)0T)U6EAC
M9U4P.4)51CE"9$A2:`T*63)H=%I7-3!+0V0P6EA.,$IY=VYD1U8T9$,Y=V)'
M1G!B:6-S2C)&,&1'1FIA1S%L8FY1=6-':'=*>6LW1%%O:V)75C!A1SEK5FU&
M<PT*9%=59U!30G5:6&-G53`Y0E5&.5=95W@Q6E-G;F1'5GID1T8P9$=&:F%#
M8W-)0V149$A*,5DS46Y,0T)H8VY*:&539VMD:6MP3W<P2PT*1%%O=DQY0GI:
M5U5G9$=H;$E',7!B5U5G65A*>5E8:TY#:3AV2DA::&)#03E)0U)Z8C)&=U@R
M2FAC,E5T4&PY=%E7=&Q25S4R6E=X=@T*8T=5;TI',6QD1VAV6D9::&)(5FQ+
M5'-.0VDX=F-(2G!B;E)F8VEG:V1M1G-+5'-.0V<P2TI'3G-A5U9U9$-!.4E'
M-6QD>4)45#!&40T*6#!.<V%75G5D0V=N84A2,&-$;W9,,GAV63)&<V%'.7ID
M0SEZ8C)&=U@R;'5D1U9Y8C-!=F,R5GED;59Y6#-*=F17-6M-:35W84A!;@T*
M2U1S3D-I4GE:6$YW240P9TI'3G-A5U9U9$,P*UDR1G-B0V=N6E=.;V(P,7!B
M5U9"9$A2:%DR:'1:5S4P2GEX:&-N2FAE4V=K9&EK<`T*3W<P2TDS0GEA5S4P
M6#-);TI(2FQC,T%P3W<P2V-(2G!B;E%G2D=.<V%75G5D0S`K9#)L>5I4<TY#
M:C@K#0HM+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4M+0T*
M+2T]7V$R8V)B,#4Q-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT
M+51Y<&4Z('1E>'0O>&UL.R!C:&%R<V5T/2)55$8M."(-"@T*/#]X;6P@=F5R
M<VEO;CTB,2XP(B!E;F-O9&EN9STB551&+3@B/SX-"@T*/%-/05`M14Y6.D5N
M=F5L;W!E("!X;6QN<SI33T%0+45.5CTB:'1T<#HO+W-C:&5M87,N>&UL<V]A
M<"YO<F<O<V]A<"]E;G9E;&]P92\B#0H@('AM;&YS.GAS9#TB:'1T<#HO+W=W
M=RYW,RYO<F<O,C`P,2]834Q38VAE;6$B#0H@('AM;&YS.GAS:3TB:'1T<#HO
M+W=W=RYW,RYO<F<O,C`P,2]834Q38VAE;6$M:6YS=&%N8V4B#0H@('AM;&YS
M.E-/05`M14Y#/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N
M8V]D:6YG+R(-"B`@4T]!4"U%3E8Z96YC;V1I;F=3='EL93TB:'1T<#HO+W-C
M:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E;F-O9&EN9R\B/@T*/%-/05`M14Y6
M.D)O9'D^#0H-"CQE8VAO36EM94%T=&%C:&UE;G0^#0H\=&5S="!H<F5F/2)C
M:60Z83(R,V9E83-C,S5B-68P939D961F.&1A-S5E9F0V8C,B+SX\+V5C:&]-
M:6UE071T86-H;65N=#X-"CPO4T]!4"U%3E8Z0F]D>3X-"CPO4T]!4"U%3E8Z
M16YV96QO<&4^#0H-"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X
M9C<P90T*0V]N=&5N="U$:7-P;W-I=&EO;CH@871T86-H;65N="YP:'`-"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;@T*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@8F%S938T#0I#;VYT96YT+4E$.B`\83(R,V9E83-C,S5B-68P939D
M961F.&1A-S5E9F0V8C,^#0H-"E!$.7=A2$%.0VY*;&-85G!C;59F8C(U:EI3
M9VE5,#E"54,Y1&)';&QB;E%U8T=H=TEI:S=$47!Y6EA&,6%82FQ8,CEU63)5
M;TEL3E`-"E%6079D1U9Z9$,Y,%I83C!,;E8P85=X<&1(:W5C1VAW26EK-T11
M<'E:6$8Q85A*;%@R.759,E5O26Q.4%%60796;49S9%=5=6-':'<-"DEI:S=$
M46]K8S(Y:&-&.6E96$YL240P9V)M5C-)1DY0459"9E%M1GI:4V=P3W<P2T11
M;VMD:4$Y24-"=5I88V=5,#E"548Y0F1(4F@-"EDR:'1:5S4P2T-D,%I83C!*
M>7=N9$=6-&1#.7=B1T9P8FEC<THR1C!D1T9J84<Q;&)N475C1VAW2GEK-T11
M;VMB5U8P84<Y:U9M1G,-"F1756=04T)U6EAC9U4P.4)51CE765=X,5I39VYD
M1U9Z9$=&,&1'1FIA0V-S24-D5&1(2C%9,U%N3$-":&-N2FAE4V=K9&EK<$]W
M,$L-"D11;W9,>4)Z6E=59V1':&Q)1S%P8E=59UE82GE96&M.0VDX=DI(6FAB
M0T$Y24-2>F(R1G=8,DIH8S)5=%!L.7195W1L4E<U,EI7>'8-"F-'56]*1S%L
M9$=H=EI&6FAB2%9L2U1S3D-I.'9C2$IP8FY29F-I9VMD;49S2U1S3D-G,$M*
M1TYS85=6=61#03E)1S5L9'E"5%0P1E$-"E@P3G-A5U9U9$-G;F%(4C!C1&]V
M3#)X=EDR1G-A1SEZ9$,Y>F(R1G=8,FQU9$=6>6(S079C,E9Y9&U6>5@S2G9D
M5S5K36DU=V%(06X-"DM4<TY#:5)Y6EA.=TE$,&=*1TYS85=6=61#,"M9,D9S
M8D-G;EI73F]B,#%P8E=60F1(4FA9,FAT6E<U,$IY>&AC;DIH95-G:V1I:W`-
M"D]W,$M),T)Y85<U,%@S26]*2$IL8S-!<$]W,$MC2$IP8FY19TI'3G-A5U9U
M9$,P*V0R;'E:5'-.0VHX*PT*+2T]7V$R8V)B,#4Q-#(T8V,T,V4W,F0S8SAC
M.&0P8CAF-S!E+2T-"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X
M9C<P90T*0V]N=&5N="U4>7!E.B!T97AT+WAM;#L@8VAA<G-E=#TB551&+3@B
M#0H-"CP_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX(C\^#0H-
M"CQ33T%0+45.5CI%;G9E;&]P92`@>&UL;G,Z4T]!4"U%3E8](FAT='`Z+R]S
M8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YV96QO<&4O(@T*("!X;6QN<SIX
M<V0](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA(@T*("!X;6QN
M<SIX<VD](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A
M;F-E(@T*("!X;6QN<SI33T%0+45.0STB:'1T<#HO+W-C:&5M87,N>&UL<V]A
M<"YO<F<O<V]A<"]E;F-O9&EN9R\B#0H@(%-/05`M14Y6.F5N8V]D:6YG4W1Y
M;&4](FAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O
M(CX-"CQ33T%0+45.5CI";V1Y/@T*#0H\96-H;TUI;65!='1A8VAM96YT/@T*
M/'1E<W0@:')E9CTB8VED.F$R,C-F96$S8S,U8C5F,&4V9&5D9CAD83<U969D
M-F(S(B\^/"]E8VAO36EM94%T=&%C:&UE;G0^#0H\+U-/05`M14Y6.D)O9'D^
M#0H\+U-/05`M14Y6.D5N=F5L;W!E/@T*#0HM+3U?83)C8F(P-3$T,C1C8S0S
M93<R9#-C.&,X9#!B.&8W,&4-"D-O;G1E;G0M1&ES<&]S:71I;VXZ(&%T=&%C
M:&UE;G0N<&AP#0I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X-"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(&)A<V4V-`T*0V]N=&5N="U)1#H@/&$R,C-F
M96$S8S,U8C5F,&4V9&5D9CAD83<U969D-F(S/@T*#0I01#EW84A!3D-N2FQC
M6%9P8VU69F(R-6I:4V=I53`Y0E5#.41B1VQL8FY1=6-':'=):6LW1%%P>5I8
M1C%A6$IL6#(Y=5DR56]);$Y0#0I15D%V9$=6>F1#.3!:6$XP3&Y6,&%7>'!D
M2&MU8T=H=TEI:S=$47!Y6EA&,6%82FQ8,CEU63)5;TEL3E!15D%V5FU&<V17
M575C1VAW#0I):6LW1%%O:V,R.6AC1CEI65A.;$E$,&=B;58S249.4%%60F91
M;49Z6E-G<$]W,$M$46]K9&E!.4E#0G5:6&-G53`Y0E5&.4)D2%)H#0I9,FAT
M6E<U,$M#9#!:6$XP2GEW;F1'5C1D0SEW8D=&<&)I8W-*,D8P9$=&:F%',6QB
M;E%U8T=H=TIY:S=$46]K8E=6,&%'.6M6;49S#0ID5U5G4%-"=5I88V=5,#E"
M548Y5UE7>#%:4V=N9$=6>F1'1C!D1T9J84-C<TE#9%1D2$HQ63-1;DQ#0FAC
M;DIH95-G:V1I:W!/=S!+#0I$46]V3'E">EI756=D1VAL24<Q<&)756=96$IY
M65AK3D-I.'9*2%IH8D-!.4E#4GIB,D9W6#)*:&,R5710;#ET65=T;%)7-3):
M5WAV#0IC1U5O2D<Q;&1':'9:1EIH8DA6;$M4<TY#:3AV8TA*<&)N4F9C:6=K
M9&U&<TM4<TY#9S!+2D=.<V%75G5D0T$Y24<U;&1Y0E14,$91#0I8,$YS85=6
M=61#9VYA2%(P8T1O=DPR>'99,D9S84<Y>F1#.7IB,D9W6#)L=61'5GEB,T%V
M8S)6>61M5GE8,TIV9%<U:TUI-7=A2$%N#0I+5'-.0VE2>5I83G=)1#!G2D=.
M<V%75G5D0S`K63)&<V)#9VY:5TYO8C`Q<&)75D)D2%)H63)H=%I7-3!*>7AH
M8VY*:&539VMD:6MP#0I/=S!+23-">6%7-3!8,TEO2DA*;&,S07!/=S!+8TA*
M<&)N46=*1TYS85=6=61#,"MD,FQY6E1S3D-J."L-"BTM/5]A,F-B8C`U,30R
M-&-C-#-E-S)D,V,X8SAD,&(X9C<P92TM#0HM+3U?83)C8F(P-3$T,C1C8S0S
M93<R9#-C.&,X9#!B.&8W,&4-"D-O;G1E;G0M5'EP93H@=&5X="]X;6P[(&-H
M87)S970](E541BTX(@T*#0H\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG
M/2)55$8M."(_/@T*#0H\4T]!4"U%3E8Z16YV96QO<&4@('AM;&YS.E-/05`M
M14Y6/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E
M+R(-"B`@>&UL;G,Z>'-D/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C
M:&5M82(-"B`@>&UL;G,Z>'-I/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-
M3%-C:&5M82UI;G-T86YC92(-"B`@>&UL;G,Z4T]!4"U%3D,](FAT='`Z+R]S
M8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O(@T*("!33T%0+45.
M5CIE;F-O9&EN9U-T>6QE/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S
M;V%P+V5N8V]D:6YG+R(^#0H\4T]!4"U%3E8Z0F]D>3X-"@T*/&5C:&]-:6UE
M071T86-H;65N=#X-"CQT97-T(&AR968](F-I9#IA,C(S9F5A,V,S-6(U9C!E
M-F1E9&8X9&$W-65F9#9B,R(O/CPO96-H;TUI;65!='1A8VAM96YT/@T*/"]3
M3T%0+45.5CI";V1Y/@T*/"]33T%0+45.5CI%;G9E;&]P93X-"@T*+2T]7V$R
M8V)B,#4Q-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT+41I<W!O
M<VET:6]N.B!A='1A8VAM96YT+G!H<`T*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN#0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B!B87-E-C0-"D-O;G1E
M;G0M240Z(#QA,C(S9F5A,V,S-6(U9C!E-F1E9&8X9&$W-65F9#9B,SX-"@T*
M4$0Y=V%(04Y#;DIL8UA6<&-M5F9B,C5J6E-G:54P.4)50SE$8D=L;&)N475C
M1VAW26EK-T11<'E:6$8Q85A*;%@R.759,E5O26Q.4`T*459!=F1'5GID0SDP
M6EA.,$QN5C!A5WAP9$AK=6-':'=):6LW1%%P>5I81C%A6$IL6#(Y=5DR56])
M;$Y0459!=E9M1G-D5U5U8T=H=PT*26EK-T11;VMC,CEH8T8Y:5E83FQ)1#!G
M8FU6,TE&3E!15D)F46U&>EI39W!/=S!+1%%O:V1I03E)0T)U6EAC9U4P.4)5
M1CE"9$A2:`T*63)H=%I7-3!+0V0P6EA.,$IY=VYD1U8T9$,Y=V)'1G!B:6-S
M2C)&,&1'1FIA1S%L8FY1=6-':'=*>6LW1%%O:V)75C!A1SEK5FU&<PT*9%=5
M9U!30G5:6&-G53`Y0E5&.5=95W@Q6E-G;F1'5GID1T8P9$=&:F%#8W-)0V14
M9$A*,5DS46Y,0T)H8VY*:&539VMD:6MP3W<P2PT*1%%O=DQY0GI:5U5G9$=H
M;$E',7!B5U5G65A*>5E8:TY#:3AV2DA::&)#03E)0U)Z8C)&=U@R2FAC,E5T
M4&PY=%E7=&Q25S4R6E=X=@T*8T=5;TI',6QD1VAV6D9::&)(5FQ+5'-.0VDX
M=F-(2G!B;E)F8VEG:V1M1G-+5'-.0V<P2TI'3G-A5U9U9$-!.4E'-6QD>4)4
M5#!&40T*6#!.<V%75G5D0V=N84A2,&-$;W9,,GAV63)&<V%'.7ID0SEZ8C)&
M=U@R;'5D1U9Y8C-!=F,R5GED;59Y6#-*=F17-6M-:35W84A!;@T*2U1S3D-I
M4GE:6$YW240P9TI'3G-A5U9U9$,P*UDR1G-B0V=N6E=.;V(P,7!B5U9"9$A2
M:%DR:'1:5S4P2GEX:&-N2FAE4V=K9&EK<`T*3W<P2TDS0GEA5S4P6#-);TI(
M2FQC,T%P3W<P2V-(2G!B;E%G2D=.<V%75G5D0S`K9#)L>5I4<TY#:C@K#0HM
M+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4M+0T*+2T]7V$R
M8V)B,#4Q-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT+51Y<&4Z
M('1E>'0O>&UL.R!C:&%R<V5T/2)55$8M."(-"@T*/#]X;6P@=F5R<VEO;CTB
M,2XP(B!E;F-O9&EN9STB551&+3@B/SX-"@T*/%-/05`M14Y6.D5N=F5L;W!E
M("!X;6QN<SI33T%0+45.5CTB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O
M<V]A<"]E;G9E;&]P92\B#0H@('AM;&YS.GAS9#TB:'1T<#HO+W=W=RYW,RYO
M<F<O,C`P,2]834Q38VAE;6$B#0H@('AM;&YS.GAS:3TB:'1T<#HO+W=W=RYW
M,RYO<F<O,C`P,2]834Q38VAE;6$M:6YS=&%N8V4B#0H@('AM;&YS.E-/05`M
M14Y#/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N8V]D:6YG
M+R(-"B`@4T]!4"U%3E8Z96YC;V1I;F=3='EL93TB:'1T<#HO+W-C:&5M87,N
M>&UL<V]A<"YO<F<O<V]A<"]E;F-O9&EN9R\B/@T*/%-/05`M14Y6.D)O9'D^
M#0H-"CQE8VAO36EM94%T=&%C:&UE;G0^#0H\=&5S="!H<F5F/2)C:60Z83(R
M,V9E83-C,S5B-68P939D961F.&1A-S5E9F0V8C,B+SX\+V5C:&]-:6UE071T
M86-H;65N=#X-"CPO4T]!4"U%3E8Z0F]D>3X-"CPO4T]!4"U%3E8Z16YV96QO
M<&4^#0H-"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P90T*
M0V]N=&5N="U$:7-P;W-I=&EO;CH@871T86-H;65N="YP:'`-"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;@T*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M8F%S938T#0I#;VYT96YT+4E$.B`\83(R,V9E83-C,S5B-68P939D961F.&1A
M-S5E9F0V8C,^#0H-"E!$.7=A2$%.0VY*;&-85G!C;59F8C(U:EI39VE5,#E"
M54,Y1&)';&QB;E%U8T=H=TEI:S=$47!Y6EA&,6%82FQ8,CEU63)5;TEL3E`-
M"E%6079D1U9Z9$,Y,%I83C!,;E8P85=X<&1(:W5C1VAW26EK-T11<'E:6$8Q
M85A*;%@R.759,E5O26Q.4%%60796;49S9%=5=6-':'<-"DEI:S=$46]K8S(Y
M:&-&.6E96$YL240P9V)M5C-)1DY0459"9E%M1GI:4V=P3W<P2T11;VMD:4$Y
M24-"=5I88V=5,#E"548Y0F1(4F@-"EDR:'1:5S4P2T-D,%I83C!*>7=N9$=6
M-&1#.7=B1T9P8FEC<THR1C!D1T9J84<Q;&)N475C1VAW2GEK-T11;VMB5U8P
M84<Y:U9M1G,-"F1756=04T)U6EAC9U4P.4)51CE765=X,5I39VYD1U9Z9$=&
M,&1'1FIA0V-S24-D5&1(2C%9,U%N3$-":&-N2FAE4V=K9&EK<$]W,$L-"D11
M;W9,>4)Z6E=59V1':&Q)1S%P8E=59UE82GE96&M.0VDX=DI(6FAB0T$Y24-2
M>F(R1G=8,DIH8S)5=%!L.7195W1L4E<U,EI7>'8-"F-'56]*1S%L9$=H=EI&
M6FAB2%9L2U1S3D-I.'9C2$IP8FY29F-I9VMD;49S2U1S3D-G,$M*1TYS85=6
M=61#03E)1S5L9'E"5%0P1E$-"E@P3G-A5U9U9$-G;F%(4C!C1&]V3#)X=EDR
M1G-A1SEZ9$,Y>F(R1G=8,FQU9$=6>6(S079C,E9Y9&U6>5@S2G9D5S5K36DU
M=V%(06X-"DM4<TY#:5)Y6EA.=TE$,&=*1TYS85=6=61#,"M9,D9S8D-G;EI7
M3F]B,#%P8E=60F1(4FA9,FAT6E<U,$IY>&AC;DIH95-G:V1I:W`-"D]W,$M)
M,T)Y85<U,%@S26]*2$IL8S-!<$]W,$MC2$IP8FY19TI'3G-A5U9U9$,P*V0R
M;'E:5'-.0VHX*PT*+2T]7V$R8V)B,#4Q-#(T8V,T,V4W,F0S8SAC.&0P8CAF
M-S!E+2T-"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P90T*
M0V]N=&5N="U4>7!E.B!T97AT+WAM;#L@8VAA<G-E=#TB551&+3@B#0H-"CP_
M>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX(C\^#0H-"CQ33T%0
M+45.5CI%;G9E;&]P92`@>&UL;G,Z4T]!4"U%3E8](FAT='`Z+R]S8VAE;6%S
M+GAM;'-O87`N;W)G+W-O87`O96YV96QO<&4O(@T*("!X;6QN<SIX<V0](FAT
M='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA(@T*("!X;6QN<SIX<VD]
M(FAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E(@T*
M("!X;6QN<SI33T%0+45.0STB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O
M<V]A<"]E;F-O9&EN9R\B#0H@(%-/05`M14Y6.F5N8V]D:6YG4W1Y;&4](FAT
M='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O(CX-"CQ3
M3T%0+45.5CI";V1Y/@T*#0H\96-H;TUI;65!='1A8VAM96YT/@T*/'1E<W0@
M:')E9CTB8VED.F$R,C-F96$S8S,U8C5F,&4V9&5D9CAD83<U969D-F(S(B\^
M/"]E8VAO36EM94%T=&%C:&UE;G0^#0H\+U-/05`M14Y6.D)O9'D^#0H\+U-/
M05`M14Y6.D5N=F5L;W!E/@T*#0HM+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C
M.&,X9#!B.&8W,&4-"D-O;G1E;G0M1&ES<&]S:71I;VXZ(&%T=&%C:&UE;G0N
M<&AP#0I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X-"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(&)A<V4V-`T*0V]N=&5N="U)1#H@/&$R,C-F96$S8S,U
M8C5F,&4V9&5D9CAD83<U969D-F(S/@T*#0I01#EW84A!3D-N2FQC6%9P8VU6
M9F(R-6I:4V=I53`Y0E5#.41B1VQL8FY1=6-':'=):6LW1%%P>5I81C%A6$IL
M6#(Y=5DR56]);$Y0#0I15D%V9$=6>F1#.3!:6$XP3&Y6,&%7>'!D2&MU8T=H
M=TEI:S=$47!Y6EA&,6%82FQ8,CEU63)5;TEL3E!15D%V5FU&<V17575C1VAW
M#0I):6LW1%%O:V,R.6AC1CEI65A.;$E$,&=B;58S249.4%%60F91;49Z6E-G
M<$]W,$M$46]K9&E!.4E#0G5:6&-G53`Y0E5&.4)D2%)H#0I9,FAT6E<U,$M#
M9#!:6$XP2GEW;F1'5C1D0SEW8D=&<&)I8W-*,D8P9$=&:F%',6QB;E%U8T=H
M=TIY:S=$46]K8E=6,&%'.6M6;49S#0ID5U5G4%-"=5I88V=5,#E"548Y5UE7
M>#%:4V=N9$=6>F1'1C!D1T9J84-C<TE#9%1D2$HQ63-1;DQ#0FAC;DIH95-G
M:V1I:W!/=S!+#0I$46]V3'E">EI756=D1VAL24<Q<&)756=96$IY65AK3D-I
M.'9*2%IH8D-!.4E#4GIB,D9W6#)*:&,R5710;#ET65=T;%)7-3):5WAV#0IC
M1U5O2D<Q;&1':'9:1EIH8DA6;$M4<TY#:3AV8TA*<&)N4F9C:6=K9&U&<TM4
M<TY#9S!+2D=.<V%75G5D0T$Y24<U;&1Y0E14,$91#0I8,$YS85=6=61#9VYA
M2%(P8T1O=DPR>'99,D9S84<Y>F1#.7IB,D9W6#)L=61'5GEB,T%V8S)6>61M
M5GE8,TIV9%<U:TUI-7=A2$%N#0I+5'-.0VE2>5I83G=)1#!G2D=.<V%75G5D
M0S`K63)&<V)#9VY:5TYO8C`Q<&)75D)D2%)H63)H=%I7-3!*>7AH8VY*:&53
M9VMD:6MP#0I/=S!+23-">6%7-3!8,TEO2DA*;&,S07!/=S!+8TA*<&)N46=*
M1TYS85=6=61#,"MD,FQY6E1S3D-J."L-"BTM/5]A,F-B8C`U,30R-&-C-#-E
M-S)D,V,X8SAD,&(X9C<P92TM#0HM+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C
M.&,X9#!B.&8W,&4-"D-O;G1E;G0M5'EP93H@=&5X="]X;6P[(&-H87)S970]
M(E541BTX(@T*#0H\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M
M."(_/@T*#0H\4T]!4"U%3E8Z16YV96QO<&4@('AM;&YS.E-/05`M14Y6/2)H
M='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R(-"B`@
M>&UL;G,Z>'-D/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82(-
M"B`@>&UL;G,Z>'-I/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M
M82UI;G-T86YC92(-"B`@>&UL;G,Z4T]!4"U%3D,](FAT='`Z+R]S8VAE;6%S
M+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O(@T*("!33T%0+45.5CIE;F-O
M9&EN9U-T>6QE/2)H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N
M8V]D:6YG+R(^#0H\4T]!4"U%3E8Z0F]D>3X-"@T*/&5C:&]-:6UE071T86-H
M;65N=#X-"CQT97-T(&AR968](F-I9#IA,C(S9F5A,V,S-6(U9C!E-F1E9&8X
M9&$W-65F9#9B,R(O/CPO96-H;TUI;65!='1A8VAM96YT/@T*/"]33T%0+45.
M5CI";V1Y/@T*/"]33T%0+45.5CI%;G9E;&]P93X-"@T*+2T]7V$R8V)B,#4Q
M-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT+41I<W!O<VET:6]N
M.B!A='1A8VAM96YT+G!H<`T*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN#0I#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B!B87-E-C0-"D-O;G1E;G0M240Z
M(#QA,C(S9F5A,V,S-6(U9C!E-F1E9&8X9&$W-65F9#9B,SX-"@T*4$0Y=V%(
M04Y#;DIL8UA6<&-M5F9B,C5J6E-G:54P.4)50SE$8D=L;&)N475C1VAW26EK
M-T11<'E:6$8Q85A*;%@R.759,E5O26Q.4`T*459!=F1'5GID0SDP6EA.,$QN
M5C!A5WAP9$AK=6-':'=):6LW1%%P>5I81C%A6$IL6#(Y=5DR56]);$Y0459!
M=E9M1G-D5U5U8T=H=PT*26EK-T11;VMC,CEH8T8Y:5E83FQ)1#!G8FU6,TE&
M3E!15D)F46U&>EI39W!/=S!+1%%O:V1I03E)0T)U6EAC9U4P.4)51CE"9$A2
M:`T*63)H=%I7-3!+0V0P6EA.,$IY=VYD1U8T9$,Y=V)'1G!B:6-S2C)&,&1'
M1FIA1S%L8FY1=6-':'=*>6LW1%%O:V)75C!A1SEK5FU&<PT*9%=59U!30G5:
M6&-G53`Y0E5&.5=95W@Q6E-G;F1'5GID1T8P9$=&:F%#8W-)0V149$A*,5DS
M46Y,0T)H8VY*:&539VMD:6MP3W<P2PT*1%%O=DQY0GI:5U5G9$=H;$E',7!B
M5U5G65A*>5E8:TY#:3AV2DA::&)#03E)0U)Z8C)&=U@R2FAC,E5T4&PY=%E7
M=&Q25S4R6E=X=@T*8T=5;TI',6QD1VAV6D9::&)(5FQ+5'-.0VDX=F-(2G!B
M;E)F8VEG:V1M1G-+5'-.0V<P2TI'3G-A5U9U9$-!.4E'-6QD>4)45#!&40T*
M6#!.<V%75G5D0V=N84A2,&-$;W9,,GAV63)&<V%'.7ID0SEZ8C)&=U@R;'5D
M1U9Y8C-!=F,R5GED;59Y6#-*=F17-6M-:35W84A!;@T*2U1S3D-I4GE:6$YW
M240P9TI'3G-A5U9U9$,P*UDR1G-B0V=N6E=.;V(P,7!B5U9"9$A2:%DR:'1:
M5S4P2GEX:&-N2FAE4V=K9&EK<`T*3W<P2TDS0GEA5S4P6#-);TI(2FQC,T%P
M3W<P2V-(2G!B;E%G2D=.<V%75G5D0S`K9#)L>5I4<TY#:C@K#0HM+3U?83)C
M8F(P-3$T,C1C8S0S93<R9#-C.&,X9#!B.&8W,&4M+0T*+2T]7V$R8V)B,#4Q
M-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E#0I#;VYT96YT+51Y<&4Z('1E>'0O
M>&UL.R!C:&%R<V5T/2)55$8M."(-"@T*/#]X;6P@=F5R<VEO;CTB,2XP(B!E
M;F-O9&EN9STB551&+3@B/SX-"@T*/%-/05`M14Y6.D5N=F5L;W!E("!X;6QN
M<SI33T%0+45.5CTB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E
M;G9E;&]P92\B#0H@('AM;&YS.GAS9#TB:'1T<#HO+W=W=RYW,RYO<F<O,C`P
M,2]834Q38VAE;6$B#0H@('AM;&YS.GAS:3TB:'1T<#HO+W=W=RYW,RYO<F<O
M,C`P,2]834Q38VAE;6$M:6YS=&%N8V4B#0H@('AM;&YS.E-/05`M14Y#/2)H
M='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N8V]D:6YG+R(-"B`@
M4T]!4"U%3E8Z96YC;V1I;F=3='EL93TB:'1T<#HO+W-C:&5M87,N>&UL<V]A
M<"YO<F<O<V]A<"]E;F-O9&EN9R\B/@T*/%-/05`M14Y6.D)O9'D^#0H-"CQE
M8VAO36EM94%T=&%C:&UE;G0^#0H\=&5S="!H<F5F/2)C:60Z83(R,V9E83-C
M,S5B-68P939D961F.&1A-S5E9F0V8C,B+SX\+V5C:&]-:6UE071T86-H;65N
M=#X-"CPO4T]!4"U%3E8Z0F]D>3X-"CPO4T]!4"U%3E8Z16YV96QO<&4^#0H-
M"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P90T*0V]N=&5N
M="U$:7-P;W-I=&EO;CH@871T86-H;65N="YP:'`-"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;@T*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@8F%S938T
M#0I#;VYT96YT+4E$.B`\83(R,V9E83-C,S5B-68P939D961F.&1A-S5E9F0V
M8C,^#0H-"E!$.7=A2$%.0VY*;&-85G!C;59F8C(U:EI39VE5,#E"54,Y1&)'
M;&QB;E%U8T=H=TEI:S=$47!Y6EA&,6%82FQ8,CEU63)5;TEL3E`-"E%6079D
M1U9Z9$,Y,%I83C!,;E8P85=X<&1(:W5C1VAW26EK-T11<'E:6$8Q85A*;%@R
M.759,E5O26Q.4%%60796;49S9%=5=6-':'<-"DEI:S=$46]K8S(Y:&-&.6E9
M6$YL240P9V)M5C-)1DY0459"9E%M1GI:4V=P3W<P2T11;VMD:4$Y24-"=5I8
M8V=5,#E"548Y0F1(4F@-"EDR:'1:5S4P2T-D,%I83C!*>7=N9$=6-&1#.7=B
M1T9P8FEC<THR1C!D1T9J84<Q;&)N475C1VAW2GEK-T11;VMB5U8P84<Y:U9M
M1G,-"F1756=04T)U6EAC9U4P.4)51CE765=X,5I39VYD1U9Z9$=&,&1'1FIA
M0V-S24-D5&1(2C%9,U%N3$-":&-N2FAE4V=K9&EK<$]W,$L-"D11;W9,>4)Z
M6E=59V1':&Q)1S%P8E=59UE82GE96&M.0VDX=DI(6FAB0T$Y24-2>F(R1G=8
M,DIH8S)5=%!L.7195W1L4E<U,EI7>'8-"F-'56]*1S%L9$=H=EI&6FAB2%9L
M2U1S3D-I.'9C2$IP8FY29F-I9VMD;49S2U1S3D-G,$M*1TYS85=6=61#03E)
M1S5L9'E"5%0P1E$-"E@P3G-A5U9U9$-G;F%(4C!C1&]V3#)X=EDR1G-A1SEZ
M9$,Y>F(R1G=8,FQU9$=6>6(S079C,E9Y9&U6>5@S2G9D5S5K36DU=V%(06X-
M"DM4<TY#:5)Y6EA.=TE$,&=*1TYS85=6=61#,"M9,D9S8D-G;EI73F]B,#%P
M8E=60F1(4FA9,FAT6E<U,$IY>&AC;DIH95-G:V1I:W`-"D]W,$M),T)Y85<U
M,%@S26]*2$IL8S-!<$]W,$MC2$IP8FY19TI'3G-A5U9U9$,P*V0R;'E:5'-.
M0VHX*PT*+2T]7V$R8V)B,#4Q-#(T8V,T,V4W,F0S8SAC.&0P8CAF-S!E+2T-
M"B<[#0HD9&5B=6<@/2!&04Q313L-"B1D871A(#T@3E5,3#L-"B1F(#T@9F]P
M96XH)R]T;7`O9&EM92YD871A)RPG=V(K)RD[#0HD9&EM92`](&YE=R!.971?
M1$E-15]-97-S86=E*"1F+#0P.38L)&1E8G5G*3L-"B1D:6UE+3YS96YD1&%T
M82@D=&5S="D[#0HC)&1I;64M/G-E;F1$871A*"1T97-T*3L-"B1D:6UE+3YS
M96YD16YD365S<V%G92@I.PT*)'-I>F4@/2!F=&5L;"@D9BD[#0IP<FEN="`B
M9FEL97-I>F4Z("1S:7IE+"!D871A<VEZ93H@(BYS=')L96XH)'1E<W0I+B)<
M;B([#0IR97=I;F0H)&8I.PT*#0HD9&EM92`](&YE=R!.971?1$E-15]-97-S
M86=E*"1F+#0P.38L)&1E8G5G*3L-"B1E<G(@/2`D9&EM92T^<F5A9"@I.PT*
M:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("!P<FEN="`D97)R+3YG
M971-97-S86=E*"DN(EQN(CL-"GT@96QS92![#0H@("`@:68@*'-T<F-M<"@D
M9&EM92T^<&%R='-;,%U;)V1A=&$G72PD=&5S="D]/3`I('L-"B`@("`@("`@
M96-H;R`B96YC;V1E+V1E8V]D92!S=6-C97-S7&XB.PT*("`@('T@96QS92![
M#0H@("`@("`@(&5C:&\@(F5N8V]D92]D96-O9&4@9F%I;'5R95QN(CL-"B`@
M("!]#0I]#0H-"C\^````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]$24U%+W1E<W0O9&EM
M95]R96-O<F1?=&5S="YP:'``````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C8W`#$P-#$W,S8S
M,#`T`#`R-3`T,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*:6YC;'5D92`G3F5T+T1)344N<&AP)SL-"@T*)'1E
M<W0])RTM/5]A,F-B8C`U,30R-&-C-#-E-S)D,V,X8SAD,&(X9C<P90T*0V]N
M=&5N="U4>7!E.B!T97AT+WAM;#L@8VAA<G-E=#TB551&+3@B#0H-"CP_>&UL
M('9E<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX(C\^#0H-"CQ33T%0+45.
M5CI%;G9E;&]P92`@>&UL;G,Z4T]!4"U%3E8](FAT='`Z+R]S8VAE;6%S+GAM
M;'-O87`N;W)G+W-O87`O96YV96QO<&4O(@T*("!X;6QN<SIX<V0](FAT='`Z
M+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA(@T*("!X;6QN<SIX<VD](FAT
M='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E(@T*("!X
M;6QN<SI33T%0+45.0STB:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A
M<"]E;F-O9&EN9R\B#0H@(%-/05`M14Y6.F5N8V]D:6YG4W1Y;&4](FAT='`Z
M+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O(CX-"CQ33T%0
M+45.5CI";V1Y/@T*#0H\96-H;TUI;65!='1A8VAM96YT/@T*/'1E<W0@:')E
M9CTB8VED.F$R,C-F96$S8S,U8C5F,&4V9&5D9CAD83<U969D-F(S(B\^/"]E
M8VAO36EM94%T=&%C:&UE;G0^#0H\+U-/05`M14Y6.D)O9'D^#0H\+U-/05`M
M14Y6.D5N=F5L;W!E/@T*#0HM+3U?83)C8F(P-3$T,C1C8S0S93<R9#-C.&,X
M9#!B.&8W,&4-"D-O;G1E;G0M1&ES<&]S:71I;VXZ(&%T=&%C:&UE;G0N<&AP
M#0I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X-"D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(&)A<V4V-`T*0V]N=&5N="U)1#H@/&$R,C-F96$S8S,U8C5F
M,&4V9&5D9CAD83<U969D-F(S/@T*#0I01#EW84A!3D-N2FQC6%9P8VU69F(R
M-6I:4V=I53`Y0E5#.41B1VQL8FY1=6-':'=):6LW1%%P>5I81C%A6$IL6#(Y
M=5DR56]);$Y0#0I15D%V9$=6>F1#.3!:6$XP3&Y6,&%7>'!D2&MU8T=H=TEI
M:S=$47!Y6EA&,6%82FQ8,CEU63)5;TEL3E!15D%V5FU&<V17575C1VAW#0I)
M:6LW1%%O:V,R.6AC1CEI65A.;$E$,&=B;58S249.4%%60F91;49Z6E-G<$]W
M,$M$46]K9&E!.4E#0G5:6&-G53`Y0E5&.4)D2%)H#0I9,FAT6E<U,$M#9#!:
M6$XP2GEW;F1'5C1D0SEW8D=&<&)I8W-*,D8P9$=&:F%',6QB;E%U8T=H=TIY
M:S=$46]K8E=6,&%'.6M6;49S#0ID5U5G4%-"=5I88V=5,#E"548Y5UE7>#%:
M4V=N9$=6>F1'1C!D1T9J84-C<TE#9%1D2$HQ63-1;DQ#0FAC;DIH95-G:V1I
M:W!/=S!+#0I$46]V3'E">EI756=D1VAL24<Q<&)756=96$IY65AK3D-I.'9*
M2%IH8D-!.4E#4GIB,D9W6#)*:&,R5710;#ET65=T;%)7-3):5WAV#0IC1U5O
M2D<Q;&1':'9:1EIH8DA6;$M4<TY#:3AV8TA*<&)N4F9C:6=K9&U&<TM4<TY#
M9S!+2D=.<V%75G5D0T$Y24<U;&1Y0E14,$91#0I8,$YS85=6=61#9VYA2%(P
M8T1O=DPR>'99,D9S84<Y>F1#.7IB,D9W6#)L=61'5GEB,T%V8S)6>61M5GE8
M,TIV9%<U:TUI-7=A2$%N#0I+5'-.0VE2>5I83G=)1#!G2D=.<V%75G5D0S`K
M63)&<V)#9VY:5TYO8C`Q<&)75D)D2%)H63)H=%I7-3!*>7AH8VY*:&539VMD
M:6MP#0I/=S!+23-">6%7-3!8,TEO2DA*;&,S07!/=S!+8TA*<&)N46=*1TYS
M85=6=61#,"MD,FQY6E1S3D-J."L-"BTM/5]A,F-B8C`U,30R-&-C-#-E-S)D
M,V,X8SAD,&(X9C<P92TM#0HG.PT*#0HD9&%T82`]($Y53$P[#0HD9&EM92`]
M(&YE=R!.971?1$E-15]296-O<F0H)&1A=&$I.PT*(R1D:6UE+3YS971-0B@I
M.PT*)&1I;64M/F=E;F5R871E240H*3L-"B1D:6UE+3YS9714>7!E*"=T97AT
M+W!L86EN)RD[#0HD9&EM92T^<V5T1&%T82@D=&5S="D[#0IP<FEN=%]R*"1D
M:6UE+3Y?<F5C;W)D*3L-"B1E;F,@/2`D9&EM92T^96YC;V1E*"D[#0IP<FEN
M="!B:6XR:&5X*'-U8G-T<B@D96YC+#`L."DI+B)<;B([#0IP<FEN="!C:'5N
M:U]S<&QI="AB:6XR:&5X*'-U8G-T<B@D96YC+#@I*2PW,BDN(EQN(CL-"B1D
M:6UE+3YD96-O9&4H)&5N8RD[#0IP<FEN=%]R*"1D:6UE+3Y?<F5C;W)D*3L-
M"C\^````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]!<F-H:79E+P``````````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-``P
M,38W,C(`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%R8VAI=F4O5&%R
M+G!H<```````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,34V
M-38Q`#$P-#$W,S8S,#`T`#`R,#$W-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+RH@=FEM.B!S970@=',]-"!S
M=STT.B`J+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\
M(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4
M:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@
M4$A0(&QI8V5N<V4L("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@
M("`@("!\#0HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<CH@5FEN8V5N="!";&%V
M970@/'9I;F-E;G1`8FQA=F5T+FYE=#X@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\-"B\O
M("1)9#H@5&%R+G!H<"QV(#$N,3,@,C`P,R\P-2\R."`P-SHP.#HT,R!V8FQA
M=F5T($5X<"`D#0H-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*#0HO*BH-
M"BH@0W)E871E<R!A("AC;VUP<F5S<V5D*2!487(@87)C:&EV90T**@T**B!`
M875T:&]R("`@5FEN8V5N="!";&%V970@/'9I;F-E;G1`8FQA=F5T+FYE=#X-
M"BH@0'9E<G-I;VX@("12979I<VEO;CH@,2XQ,R`D#0HJ($!P86-K86=E("!!
M<F-H:79E#0HJ+PT*8VQA<W,@07)C:&EV95]487(@97AT96YD<R!014%2#0I[
M#0H@("`@+RHJ#0H@("`@*B!`=F%R('-T<FEN9R!.86UE(&]F('1H92!487(-
M"B`@("`J+PT*("`@('9A<B`D7W1A<FYA;64])R<[#0H-"B`@("`O*BH-"B`@
M("`J($!V87(@8F]O;&5A;B!I9B!T<G5E+"!T:&4@5&%R(&9I;&4@=VEL;"!B
M92!G>FEP<&5D#0H@("`@*B\-"B`@("!V87(@)%]C;VUP<F5S<SUF86QS93L-
M"@T*("`@("\J*@T*("`@("H@0'9A<B!S=')I;F<@5'EP92!O9B!C;VUP<F5S
M<VEO;B`Z("=N;VYE)RP@)V=Z)R!O<B`G8GHR)PT*("`@("HO#0H@("`@=F%R
M("1?8V]M<')E<W-?='EP93TG;F]N92<[#0H-"B`@("`O*BH-"B`@("`J($!V
M87(@9FEL92!D97-C<FEP=&]R#0H@("`@*B\-"B`@("!V87(@)%]F:6QE/3`[
M#0H-"B`@("`O*BH-"B`@("`J($!V87(@<W1R:6YG($QO8V%L(%1A<B!N86UE
M(&]F(&$@<F5M;W1E(%1A<B`H:'1T<#HO+R!O<B!F='`Z+R\I#0H@("`@*B\-
M"B`@("!V87(@)%]T96UP7W1A<FYA;64])R<[#0H-"B`@("`O+R![>WL@8V]N
M<W1R=6-T;W(-"B`@("`O*BH-"B`@("`J($%R8VAI=F5?5&%R($-L87-S(&-O
M;G-T<G5C=&]R+B!4:&ES(&9L879O=7(@;V8@=&AE(&-O;G-T<G5C=&]R(&]N
M;'D-"B`@("`J(&1E8VQA<F4@82!N97<@07)C:&EV95]487(@;V)J96-T+"!I
M9&5N=&EF>6EN9R!I="!B>2!T:&4@;F%M92!O9B!T:&4-"B`@("`J('1A<B!F
M:6QE+@T*("`@("H@268@=&AE(&-O;7!R97-S(&%R9W5M96YT(&ES('-E="!T
M:&4@=&%R('=I;&P@8F4@<F5A9"!O<B!C<F5A=&5D(&%S(&$-"B`@("`J(&=Z
M:7`@;W(@8GHR(&-O;7!R97-S960@5$%2(&9I;&4N#0H@("`@*@T*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@)'!?=&%R;F%M92`@5&AE(&YA;64@;V8@=&AE
M('1A<B!A<F-H:79E('1O(&-R96%T90T*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@)'!?8V]M<')E<W,@8V%N(&)E(&YU;&PL("=G>B<@;W(@)V)Z,B<N(%1H
M:7,-"B`@("`J("`@("`@("`@("`@("`@("`@('!A<F%M971E<B!I;F1I8V%T
M97,@:68@9WII<"!O<B!B>C(@8V]M<')E<W-I;VX-"B`@("`J("`@("`@("`@
M("`@("`@("`@(&ES(')E<75I<F5D+B`@1F]R(&-O;7!A=&EB:6QI='D@<F5A
M<V]N('1H90T*("`@("H@("`@("`@("`@("`@("`@("`@8F]O;&5A;B!V86QU
M92`G=')U92<@;65A;G,@)V=Z)RX-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!!<F-H:79E7U1A<B@D<%]T87)N86UE+"`D
M<%]C;VUP<F5S<R`](&YU;&PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^4$5!
M4B@I.PT*("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@9F%L<V4[#0H@("`@
M("`@("1T:&ES+3Y?8V]M<')E<W-?='EP92`]("=N;VYE)SL-"B`@("`@("`@
M:68@*"1P7V-O;7!R97-S(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!I9B`H
M0&9I;&5?97AI<W1S*"1P7W1A<FYA;64I*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1F<"`]($!F;W!E;B@D<%]T87)N86UE+"`B<F(B*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`O+R!L;V]K(&9O<B!G>FEP(&UA9VEC(&-O;VMI90T*
M("`@("`@("`@("`@("`@("`@("`D9&%T82`](&9R96%D*"1F<"P@,BD[#0H@
M("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&1A=&$@/3T@(EPS-UPR,3,B*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W-?='EP92`]("=G
M>B<[#0H@("`@("`@("`@("`@("`@("`@("\O($YO('-U<F4@:70G<R!E;F]U
M9VAT(&9O<B!A(&UA9VEC(&-O9&4@+BXN+@T*("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)&1A=&$@/3T@(D):(BD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/2`G8GHR)SL-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@+R\@<')O8F%B
M;'D@82!R96UO=&4@9FEL92!O<B!S;VUE(&9I;&4@86-C97-S:6)L90T*("`@
M("`@("`@("`@("`@("\O('1H<F]U9V@@82!S=')E86T@:6YT97)F86-E#0H@
M("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D<%]T87)N86UE+"`M,BD@/3T@
M)V=Z)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S
M(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S
M<U]T>7!E(#T@)V=Z)SL-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H*'-U
M8G-T<B@D<%]T87)N86UE+"`M,RD@/3T@)V)Z,B<I('Q\#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("AS=6)S='(H)'!?=&%R;F%M92P@+3(I(#T]("=B
M>B<I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W,@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S
M7W1Y<&4@/2`G8GHR)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H*"1P7V-O
M;7!R97-S(#T]('1R=64I('Q\("@D<%]C;VUP<F5S<R`]/2`G9WHG*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W,@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W-?='EP92`]("=G>B<[#0H@
M("`@("`@("`@("!](&5L<V4@:68@*"1P7V-O;7!R97-S(#T]("=B>C(G*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]('1R=64[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T@)V)Z,B<[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]T
M87)N86UE(#T@)'!?=&%R;F%M93L-"B`@("`@("`@:68@*"1T:&ES+3Y?8V]M
M<')E<W,I('L@+R\@87-S97)T('IL:6(@;W(@8GHR(&5X=&5N<VEO;B!S=7!P
M;W)T#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]
M("=G>B<I#0H@("`@("`@("`@("`@("`@)&5X=&YA;64@/2`G>FQI8B<[#0H@
M("`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@
M)V)Z,B<I#0H@("`@("`@("`@("`@("`@)&5X=&YA;64@/2`G8GHR)SL-"@T*
M("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"1E>'1N86UE*2D@
M>PT*("`@("`@("`@("`@("`@(%!%05(Z.FQO861%>'1E;G-I;VXH)&5X=&YA
M;64I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%E>'1E;G-I
M;VY?;&]A9&5D*"1E>'1N86UE*2D@>PT*("`@("`@("`@("`@("`@(&1I92@B
M5&AE(&5X=&5N<VEO;B`G)&5X=&YA;64G(&-O=6QD;B=T(&)E(&9O=6YD+EQN
M(BX-"B`@("`@("`@("`@("`@("`@("`@(E!L96%S92!M86ME('-U<F4@>6]U
M<B!V97)S:6]N(&]F(%!(4"!W87,@8G5I;'0@(BX-"B`@("`@("`@("`@("`@
M("`@("`@(G=I=&@@)R1E>'1N86UE)R!S=7!P;W)T+EQN(BD[#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&1E<W1R=6-T
M;W(-"B`@("!F=6YC=&EO;B!?07)C:&EV95]487(H*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]C;&]S92@I.PT*("`@("`@("`O+R`M+2TM+2!,;V]K(&9O
M<B!A(&QO8V%L(&-O<'D@=&\@9&5L971E#0H@("`@("`@(&EF("@D=&AI<RT^
M7W1E;7!?=&%R;F%M92`A/2`G)RD-"B`@("`@("`@("`@($!U;FQI;FLH)'1H
M:7,M/E]T96UP7W1A<FYA;64I.PT*("`@("`@("`D=&AI<RT^7U!%05(H*3L-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8W)E871E*"D-"B`@
M("`O*BH-"B`@("`J(%1H:7,@;65T:&]D(&-R96%T97,@=&AE(&%R8VAI=F4@
M9FEL92!A;F0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S#0H@("`@*B!T
M:&%T(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0N#0H@("`@*B!)9B!A(&9I
M;&4@=VET:"!T:&4@<V%M92!N86UE(&5X:7-T(&%N9"!I<R!W<FET86)L92P@
M:70@:7,@<F5P;&%C960-"B`@("`J(&)Y('1H92!N97<@=&%R+@T*("`@("H@
M5&AE(&UE=&AO9"!R971U<FX@9F%L<V4@86YD(&$@4$5!4B!E<G)O<B!T97AT
M+@T*("`@("H@5&AE("1P7V9I;&5L:7-T('!A<F%M971E<B!C86X@8F4@86X@
M87)R87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("`@("H@<F5P<F5S96YT
M:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@;F%M92!W:71H('1H96ER
M('!A=&@@:68-"B`@("`J(&YE961E9"X@270@8V%N(&%L<V\@8F4@82!S:6YG
M;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-"B`@("`J('-I
M;F=L92!B;&%N:RX-"B`@("`J($9O<B!E86-H(&1I<F5C=&]R>2!A9&1E9"!I
M;B!T:&4@87)C:&EV92P@=&AE(&9I;&5S(&%N9`T*("`@("H@<W5B+61I<F5C
M=&]R:65S(&%R92!A;'-O(&%D9&5D+@T*("`@("H@4V5E(&%L<V\@8W)E871E
M36]D:69Y*"D@;65T:&]D(&9O<B!M;W)E(&1E=&%I;',N#0H@("`@*@T*("`@
M("H@0'!A<F%M(&%R<F%Y("`D<%]F:6QE;&ES="!!;B!A<G)A>2!O9B!F:6QE
M;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-"B`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG('=I=&@@;F%M97,@
M<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L86YK('-P86-E+@T*("`@("H@0')E
M='5R;B`@("`@("`@("`@("`@("`@("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]N(&5R<F]R+@T*("`@("H@0'-E92!C<F5A=&5-;V1I9GDH*0T*("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T92@D
M<%]F:6QE;&ES="D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^8W)E
M871E36]D:69Y*"1P7V9I;&5L:7-T+"`G)RP@)R<I.PT*("`@('T-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!A9&0H*0T*("`@("\J*@T*("`@("H@5&AI
M<R!M971H;V0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S('1H870@87)E
M(&QI<W1E9"!I;B`D<%]F:6QE;&ES="!I;@T*("`@("H@=&AE(&%R8VAI=F4N
M($EF('1H92!A<F-H:79E(&1O97,@;F]T(&5X:7-T(&ET(&ES(&-R96%T960N
M#0H@("`@*B!4:&4@;65T:&]D(')E='5R;B!F86QS92!A;F0@82!014%2(&5R
M<F]R('1E>'0N#0H@("`@*B!4:&4@9FEL97,@86YD(&1I<F5C=&]R:65S(&QI
M<W1E9"!A<F4@;VYL>2!A9&1E9"!A="!T:&4@96YD(&]F('1H92!A<F-H:79E
M+`T*("`@("H@979E;B!I9B!A(&9I;&4@=VET:"!T:&4@<V%M92!N86UE(&ES
M(&%L<F5A9'D@87)C:&EV960N#0H@("`@*B!3964@86QS;R!C<F5A=&5-;V1I
M9GDH*2!M971H;V0@9F]R(&UO<F4@9&5T86EL<RX-"B`@("`J#0H@("`@*B!`
M<&%R86T@87)R87D@("1P7V9I;&5L:7-T($%N(&%R<F%Y(&]F(&9I;&5N86UE
M<R!A;F0@9&ER96-T;W)Y(&YA;65S+"!O<B!A('-I;F=L90T*("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@=VET:"!N86UE<R!S97!A
M<F%T960@8GD@82!S:6YG;&4@8FQA;FL@<W!A8V4N#0H@("`@*B!`<F5T=7)N
M("`@("`@("`@("`@("`@("`@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@
M97)R;W(N#0H@("`@*B!`<V5E(&-R96%T94UO9&EF>2@I#0H@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@861D*"1P7V9I;&5L
M:7-T*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YA9&1-;V1I9GDH
M)'!?9FEL96QI<W0L("<G+"`G)RD[#0H@("`@?0T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(&5X=')A8W0H*0T*("`@(&9U;F-T:6]N(&5X=')A8W0H)'!?
M<&%T:#TG)RD-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^97AT<F%C
M=$UO9&EF>2@D<%]P871H+"`G)RD[#0H@("`@?0T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(&QI<W1#;VYT96YT*"D-"B`@("!F=6YC=&EO;B!L:7-T0V]N
M=&5N="@I#0H@("`@>PT*("`@("`@("`D=E]L:7-T7V1E=&%I;"`](&%R<F%Y
M*"D[#0H-"B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;E)E860H*2D@>PT*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7V5X=')A8W1,:7-T*"<G+"`D=E]L:7-T
M7V1E=&%I;"P@(FQI<W0B+"`G)RP@)R<I*2![#0H@("`@("`@("`@("`@("`@
M=6YS970H)'9?;&ES=%]D971A:6PI.PT*("`@("`@("`@("`@("`@("1V7VQI
M<W1?9&5T86EL(#T@,#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T
M:&ES+3Y?8VQO<V4H*3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B`D
M=E]L:7-T7V1E=&%I;#L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![
M>WL@8W)E871E36]D:69Y*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D
M(&-R96%T97,@=&AE(&%R8VAI=F4@9FEL92!A;F0@861D('1H92!F:6QE<R`O
M(&1I<F5C=&]R:65S#0H@("`@*B!T:&%T(&%R92!L:7-T960@:6X@)'!?9FEL
M96QI<W0N#0H@("`@*B!)9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@
M:7,@=W)I=&%B;&4L(&ET(&ES(')E<&QA8V5D(&)Y('1H90T*("`@("H@;F5W
M('1A<BX@270@:7,@82!C<F5A=&4@86YD(&YO="!A;B!A9&0N($EF('1H92!F
M:6QE(&5X:7-T<R!A;F0@:7,-"B`@("`J(')E860M;VYL>2!O<B!I<R!A(&1I
M<F5C=&]R>2!I="!I<R!N;W0@<F5P;&%C960N(%1H92!M971H;V0@<F5T=7)N
M#0H@("`@*B!F86QS92!A;F0@82!014%2(&5R<F]R('1E>'0N#0H@("`@*B!4
M:&4@)'!?9FEL96QI<W0@<&%R86UE=&5R(&-A;B!B92!A;B!A<G)A>2!O9B!S
M=')I;F<L(&5A8V@@<W1R:6YG#0H@("`@*B!R97!R97-E;G1I;F<@82!F:6QE
M;F%M92!O<B!A(&1I<F5C=&]R>2!N86UE('=I=&@@=&AE:7(@<&%T:"!I9@T*
M("`@("H@;F5E9&5D+B!)="!C86X@86QS;R!B92!A('-I;F=L92!S=')I;F<@
M=VET:"!N86UE<R!S97!A<F%T960@8GD@80T*("`@("H@<VEN9VQE(&)L86YK
M+@T*("`@("H@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7W)E;6]V95]D:7(@
M=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE#0H@("`@*B!M96UO<FEZ960@<&%T
M:"!O9B!E86-H(&9I;&4@+R!D:7)E8W1O<GD@;&ES=&5D('=H96X@=&AI<R!P
M871H#0H@("`@*B!E>&ES=',N($)Y(&1E9F%U;'0@;F]T:&EN9R!I<R!R96UO
M=F5D("AE;7!T>2!P871H("<G*0T*("`@("H@5&AE('!A=&@@:6YD:6-A=&5D
M(&EN("1P7V%D9%]D:7(@=VEL;"!B92!A9&1E9"!A="!T:&4@8F5G:6YN:6YG
M(&]F#0H@("`@*B!T:&4@;65M;W)I>F5D('!A=&@@;V8@96%C:"!F:6QE("\@
M9&ER96-T;W)Y(&QI<W1E9"X@2&]W979E<B!I="!C86X-"B`@("`J(&)E('-E
M="!T;R!E;7!T>2`G)RX@5&AE(&%D9&EN9R!O9B!A('!A=&@@:7,@9&]N92!A
M9G1E<B!T:&4@<F5M;W9I;F<-"B`@("`J(&]F('!A=&@N#0H@("`@*B!4:&4@
M<&%T:"!A9&0O<F5M;W9E(&%B:6QI='D@96YA8FQE<R!T:&4@=7-E<B!T;R!P
M<F5P87)E(&%N(&%R8VAI=F4-"B`@("`J(&9O<B!E>'1R86-T:6]N(&EN(&$@
M9&EF9F5R96YT('!A=&@@=&AA;B!T:&4@;W)I9VEN(&9I;&5S(&%R92X-"B`@
M("`J(%-E92!A;'-O(&%D9$UO9&EF>2@I(&UE=&AO9"!F;W(@9FEL92!A9&1I
M;F<@<')O<&5R=&EE<RX-"B`@("`J#0H@("`@*B!`<&%R86T@87)R87D@("1P
M7V9I;&5L:7-T("`@("!!;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD(&1I<F5C
M=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-"B`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B
M>2!A('-I;F=L92!B;&%N:R!S<&%C92X-"B`@("`J($!P87)A;2!S=')I;F<@
M)'!?861D7V1I<B`@("`@($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@<&%T
M:"!T;R!B92!A9&1E9"!T;R!T:&4-"B`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@96QE;65N="!I
M;B!T:&4@;&ES="X-"B`@("`J($!P87)A;2!S=')I;F<@)'!?<F5M;W9E7V1I
M<B`@($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@<&%T:"!T;R!B92!R96UO
M=F5D(&9R;VT-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@=&AE(&QI
M<W0L('=H96X-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E;&5V86YT+@T*("`@("H@0')E='5R;B!B;V]L96%N("`@("`@("`@("`@
M("`@=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@*B!`<V5E(&%D9$UO9&EF>2@I#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!C<F5A=&5-;V1I9GDH)'!?9FEL96QI<W0L("1P7V%D
M9%]D:7(L("1P7W)E;6]V95]D:7(])R<I#0H@("`@>PT*("`@("`@("`D=E]R
M97-U;'0@/2!T<G5E.PT*#0H@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N5W)I
M=&4H*2D-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@("!I
M9B`H)'!?9FEL96QI<W0@(3T@)R<I('L-"B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<%]F:6QE;&ES="DI#0H@("`@("`@("`@("`@("`@)'9?;&ES="`]
M("1P7V9I;&5L:7-T.PT*("`@("`@("`@("`@96QS96EF("AI<U]S=')I;F<H
M)'!?9FEL96QI<W0I*0T*("`@("`@("`@("`@("`@("1V7VQI<W0@/2!E>'!L
M;V1E*"(@(BP@)'!?9FEL96QI<W0I.PT*("`@("`@("`@("`@96QS92![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C;&5A;D9I;&4H*3L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@;&ES="<I.PT*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@)'9?<F5S=6QT(#T@)'1H:7,M/E]A9&1,:7-T*"1V
M7VQI<W0L("1P7V%D9%]D:7(L("1P7W)E;6]V95]D:7(I.PT*("`@("`@("!]
M#0H-"B`@("`@("`@:68@*"1V7W)E<W5L="D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]W<FET949O;W1E<B@I.PT*("`@("`@("`@("`@)'1H:7,M/E]C;&]S
M92@I.PT*("`@("`@("!](&5L<V4-"B`@("`@("`@("`@("1T:&ES+3Y?8VQE
M86Y&:6QE*"D[#0H-"B`@("`@("`@<F5T=7)N("1V7W)E<W5L=#L-"B`@("!]
M#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@861D36]D:69Y*"D-"B`@("`O
M*BH-"B`@("`J(%1H:7,@;65T:&]D(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O
M<FEE<R!L:7-T960@:6X@)'!?9FEL96QI<W0@870@=&AE#0H@("`@*B!E;F0@
M;V8@=&AE(&5X:7-T:6YG(&%R8VAI=F4N($EF('1H92!A<F-H:79E(&1O97,@
M;F]T('EE="!E>&ES=',@:70-"B`@("`J(&ES(&-R96%T960N#0H@("`@*B!4
M:&4@)'!?9FEL96QI<W0@<&%R86UE=&5R(&-A;B!B92!A;B!A<G)A>2!O9B!S
M=')I;F<L(&5A8V@@<W1R:6YG#0H@("`@*B!R97!R97-E;G1I;F<@82!F:6QE
M;F%M92!O<B!A(&1I<F5C=&]R>2!N86UE('=I=&@@=&AE:7(@<&%T:"!I9@T*
M("`@("H@;F5E9&5D+B!)="!C86X@86QS;R!B92!A('-I;F=L92!S=')I;F<@
M=VET:"!N86UE<R!S97!A<F%T960@8GD@80T*("`@("H@<VEN9VQE(&)L86YK
M+@T*("`@("H@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7W)E;6]V95]D:7(@
M=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE#0H@("`@*B!M96UO<FEZ960@<&%T
M:"!O9B!E86-H(&9I;&4@+R!D:7)E8W1O<GD@;&ES=&5D('=H96X@=&AI<R!P
M871H#0H@("`@*B!E>&ES=',N($)Y(&1E9F%U;'0@;F]T:&EN9R!I<R!R96UO
M=F5D("AE;7!T>2!P871H("<G*0T*("`@("H@5&AE('!A=&@@:6YD:6-A=&5D
M(&EN("1P7V%D9%]D:7(@=VEL;"!B92!A9&1E9"!A="!T:&4@8F5G:6YN:6YG
M(&]F#0H@("`@*B!T:&4@;65M;W)I>F5D('!A=&@@;V8@96%C:"!F:6QE("\@
M9&ER96-T;W)Y(&QI<W1E9"X@2&]W979E<B!I="!C86X-"B`@("`J(&)E('-E
M="!T;R!E;7!T>2`G)RX@5&AE(&%D9&EN9R!O9B!A('!A=&@@:7,@9&]N92!A
M9G1E<B!T:&4@<F5M;W9I;F<-"B`@("`J(&]F('!A=&@N#0H@("`@*B!4:&4@
M<&%T:"!A9&0O<F5M;W9E(&%B:6QI='D@96YA8FQE<R!T:&4@=7-E<B!T;R!P
M<F5P87)E(&%N(&%R8VAI=F4-"B`@("`J(&9O<B!E>'1R86-T:6]N(&EN(&$@
M9&EF9F5R96YT('!A=&@@=&AA;B!T:&4@;W)I9VEN(&9I;&5S(&%R92X-"B`@
M("`J($EF(&$@9FEL92]D:7(@:7,@86QR96%D>2!I;B!T:&4@87)C:&EV92!I
M="!W:6QL(&]N;'D@8F4@861D960@870@=&AE#0H@("`@*B!E;F0@;V8@=&AE
M(&%R8VAI=F4N(%1H97)E(&ES(&YO('5P9&%T92!O9B!T:&4@97AI<W1I;F<@
M87)C:&EV960-"B`@("`J(&9I;&4O9&ER+B!(;W=E=F5R('=H:6QE(&5X=')A
M8W1I;F<@=&AE(&%R8VAI=F4L('1H92!L87-T(&9I;&4@=VEL;`T*("`@("H@
M<F5P;&%C92!T:&4@9FER<W0@;VYE+B!4:&ES(')E<W5L=',@:6X@82!N;VYE
M(&]P=&EM:7IA=&EO;B!O9B!T:&4-"B`@("`J(&%R8VAI=F4@<VEZ92X-"B`@
M("`J($EF(&$@9FEL92]D:7(@9&]E<R!N;W0@97AI<W0@=&AE(&9I;&4O9&ER
M(&ES(&EG;F]R960N($AO=V5V97(@86X-"B`@("`J(&5R<F]R('1E>'0@:7,@
M<V5N9"!T;R!014%2(&5R<F]R+@T*("`@("H@268@82!F:6QE+V1I<B!I<R!N
M;W0@<F5A9&%B;&4@=&AE(&9I;&4O9&ER(&ES(&EG;F]R960N($AO=V5V97(@
M86X-"B`@("`J(&5R<F]R('1E>'0@:7,@<V5N9"!T;R!014%2(&5R<F]R+@T*
M("`@("H-"B`@("`J($!P87)A;2!A<G)A>2`@("`@("1P7V9I;&5L:7-T("`@
M("!!;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@
M;W(@82!S:6YG;&4-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@82!S:6YG
M;&4@8FQA;FL@<W!A8V4N#0H@("`@*B!`<&%R86T@<W1R:6YG("`@("`D<%]A
M9&1?9&ER("`@("`@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@82!P871H('1O
M(&)E(&%D9&5D('1O('1H90T*("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@96QE;65N="!I
M;B!T:&4@;&ES="X-"B`@("`J($!P87)A;2!S=')I;F<@("`@("1P7W)E;6]V
M95]D:7(@("!!('-T<FEN9R!W:&EC:"!C;VYT86EN<R!A('!A=&@@=&\@8F4@
M<F5M;W9E9"!F<F]M#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=&AE(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@96QE;65N="!I
M;B!T:&4@;&ES="P@=VAE;@T*("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E;&5V86YT+@T*("`@("H@0')E='5R;B`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@
M97)R;W(N#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@("`@9G5N
M8W1I;VX@861D36]D:69Y*"1P7V9I;&5L:7-T+"`D<%]A9&1?9&ER+"`D<%]R
M96UO=F5?9&ER/2<G*0T*("`@('L-"B`@("`@("`@)'9?<F5S=6QT(#T@=')U
M93L-"@T*("`@("`@("!I9B`H(4!I<U]F:6QE*"1T:&ES+3Y?=&%R;F%M92DI
M#0H@("`@("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^8W)E871E36]D:69Y
M*"1P7V9I;&5L:7-T+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER*3L-"B`@
M("`@("`@96QS92![#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!?9FEL
M96QI<W0I*0T*("`@("`@("`@("`@("`@("1V7VQI<W0@/2`D<%]F:6QE;&ES
M=#L-"B`@("`@("`@("`@(&5L<V5I9B`H:7-?<W1R:6YG*"1P7V9I;&5L:7-T
M*2D-"B`@("`@("`@("`@("`@("`D=E]L:7-T(#T@97AP;&]D92@B("(L("1P
M7V9I;&5L:7-T*3L-"B`@("`@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL92!L:7-T)RD[#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*#0H@
M("`@("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^7V%P<&5N9"@D=E]L:7-T
M+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER*3L-"B`@("`@("`@?0T*#0H@
M("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@("`@?0T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(&%D9%-T<FEN9R@I#0H@("`@+RHJ#0H@("`@*B!4:&ES
M(&UE=&AO9"!A9&0@82!S:6YG;&4@<W1R:6YG(&%S(&$@9FEL92!A="!T:&4-
M"B`@("`J(&5N9"!O9B!T:&4@97AI<W1I;F<@87)C:&EV92X@268@=&AE(&%R
M8VAI=F4@9&]E<R!N;W0@>65T(&5X:7-T<R!I=`T*("`@("H@:7,@8W)E871E
M9"X-"B`@("`J#0H@("`@*B!`<&%R86T@<W1R:6YG("`@("`D<%]F:6QE;F%M
M92`@("`@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@=&AE(&9U;&P@9FEL96YA
M;64@<&%T:`T*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H870@=VEL;"!B92!A<W-O8VEA=&5D('=I=&@@=&AE('-T<FEN9RX-
M"B`@("`J($!P87)A;2!S=')I;F<@("`@("1P7W-T<FEN9R`@("`@("!4:&4@
M8V]N=&5N="!O9B!T:&4@9FEL92!A9&1E9"!I;B!T:&4@87)C:&EV92X-"B`@
M("`J($!R971U<FX@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E(&]N
M('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&%D9%-T<FEN9R@D<%]F:6QE;F%M
M92P@)'!?<W1R:6YG*0T*("`@('L-"B`@("`@("`@)'9?<F5S=6QT(#T@=')U
M93L-"@T*("`@("`@("!I9B`H(4!I<U]F:6QE*"1T:&ES+3Y?=&%R;F%M92DI
M('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N5W)I=&4H*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"B`@("`@("`@?0T*("`@
M("`@("`-"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y!<'!E;F0H*2D-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@("`O+R!.965D('1O
M(&-H96-K('1H92!G970@8F%C:R!T;R!T:&4@=&5M<&]R87)Y(&9I;&4@/R`N
M+BXN#0H@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?861D4W1R:6YG*"1P
M7V9I;&5N86UE+"`D<%]S=')I;F<I.PT*#0H@("`@("`@("1T:&ES+3Y?=W)I
M=&5&;V]T97(H*3L-"@T*("`@("`@("`D=&AI<RT^7V-L;W-E*"D[#0H-"B`@
M("`@("`@<F5T=7)N("1V7W)E<W5L=#L-"B`@("!]#0H@("`@+R\@?7U]#0H-
M"B`@("`O+R![>WL@97AT<F%C=$UO9&EF>2@I#0H@("`@+RHJ#0H@("`@*B!4
M:&ES(&UE=&AO9"!E>'1R86-T(&%L;"!T:&4@8V]N=&5N="!O9B!T:&4@87)C
M:&EV92!I;B!T:&4@9&ER96-T;W)Y#0H@("`@*B!I;F1I8V%T960@8GD@)'!?
M<&%T:"X@5VAE;B!R96QE=F%N="!T:&4@;65M;W)I>F5D('!A=&@@;V8@=&AE
M#0H@("`@*B!F:6QE<R]D:7(@8V%N(&)E(&UO9&EF:65D(&)Y(')E;6]V:6YG
M('1H92`D<%]R96UO=F5?<&%T:"!P871H(&%T('1H90T*("`@("H@8F5G:6YN
M:6YG(&]F('1H92!F:6QE+V1I<B!P871H+@T*("`@("H@5VAI;&4@97AT<F%C
M=&EN9R!A(&9I;&4L(&EF('1H92!D:7)E8W1O<GD@<&%T:"!D;V5S(&YO="!E
M>&ES=',@:70@:7,-"B`@("`J(&-R96%T960N#0H@("`@*B!7:&EL92!E>'1R
M86-T:6YG(&$@9FEL92P@:68@=&AE(&9I;&4@86QR96%D>2!E>&ES=',@:70@
M:7,@<F5P;&%C960-"B`@("`J('=I=&AO=70@;&]O:VEN9R!F;W(@;&%S="!M
M;V1I9FEC871I;VX@9&%T92X-"B`@("`J(%=H:6QE(&5X=')A8W1I;F<@82!F
M:6QE+"!I9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&4-
M"B`@("`J('!R;W1E8W1E9"P@=&AE(&5X=')A8W1I;VX@:7,@86)O<G1E9"X-
M"B`@("`J(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!A(&1I<F5C=&]R
M>2!W:71H('1H92!S86UE(&YA;64@86QR96%D>0T*("`@("H@97AI<W1S+"!T
M:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+@T*("`@("H@5VAI;&4@97AT<F%C
M=&EN9R!A(&1I<F5C=&]R>2P@:68@82!F:6QE('=I=&@@=&AE('-A;64@;F%M
M92!A;')E861Y#0H@("`@*B!E>&ES=',L('1H92!E>'1R86-T:6]N(&ES(&%B
M;W)T960N#0H@("`@*B!7:&EL92!E>'1R86-T:6YG(&$@9FEL92]D:7)E8W1O
M<GD@:68@=&AE(&1E<W1I;F%T:6]N(&1I<F5C=&]R>2!E>&ES=`T*("`@("H@
M86YD(&ES('=R:71E('!R;W1E8W1E9"P@;W(@9&]E<R!N;W0@97AI<W0@8G5T
M(&-A;B!N;W0@8F4@8W)E871E9"P-"B`@("`J('1H92!E>'1R86-T:6]N(&ES
M(&%B;W)T960N#0H@("`@*B!)9B!A9G1E<B!E>'1R86-T:6]N(&%N(&5X=')A
M8W1E9"!F:6QE(&1O97,@;F]T('-H;W<@=&AE(&-O<G)E8W0-"B`@("`J('-T
M;W)E9"!F:6QE('-I>F4L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N#0H@
M("`@*B!7:&5N('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960L(&$@4$5!4B!E
M<G)O<B!T97AT(&ES('-E="!A;F0@9F%L<V4-"B`@("`J(&ES(')E='5R;F5D
M+B!(;W=E=F5R('1H92!R97-U;'0@8V%N(&)E(&$@<&%R=&EA;"!E>'1R86-T
M:6]N('1H870@;6%Y#0H@("`@*B!N965D('1O(&)E(&UA;G5A;&QY(&-L96%N
M960N#0H@("`@*@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]P871H("`@("`@
M("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2!W:&5R92!T:&4@9FEL97,O
M9&ER(&YE960@=&\@8GD-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5X=')A8W1E9"X-"B`@("`J($!P87)A;2!S=')I;F<@)'!?<F5M
M;W9E7W!A=&@@(%!A<G0@;V8@=&AE(&UE;6]R:7IE9"!P871H('1H870@8V%N
M(&)E(')E;6]V960@:68-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('!R97-E;G0@870@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL92]D
M:7(@<&%T:"X-"B`@("`J($!R971U<FX@8F]O;&5A;B`@("`@("`@("`@("`@
M('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0H@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("H@0'-E92!E>'1R86-T3&ES="@I#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!E>'1R86-T36]D:69Y*"1P7W!A=&@L("1P7W)E;6]V
M95]P871H*0T*("`@('L-"B`@("`@("`@)'9?<F5S=6QT(#T@=')U93L-"B`@
M("`@("`@)'9?;&ES=%]D971A:6P@/2!A<G)A>2@I.PT*#0H@("`@("`@(&EF
M("@D=E]R97-U;'0@/2`D=&AI<RT^7V]P96Y296%D*"DI('L-"B`@("`@("`@
M("`@("1V7W)E<W5L="`]("1T:&ES+3Y?97AT<F%C=$QI<W0H)'!?<&%T:"P@
M)'9?;&ES=%]D971A:6PL(")C;VUP;&5T92(L(#`L("1P7W)E;6]V95]P871H
M*3L-"B`@("`@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"B`@("`@("`@?0T*
M#0H@("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@("`@?0T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[(&5X=')A8W1);E-T<FEN9R@I#0H@("`@+RHJ#0H@
M("`@*B!4:&ES(&UE=&AO9"!E>'1R86-T(&9R;VT@=&AE(&%R8VAI=F4@;VYE
M(&9I;&4@:61E;G1I9FEE9"!B>2`D<%]F:6QE;F%M92X-"B`@("`J(%1H92!R
M971U<FX@=F%L=64@:7,@82!S=')I;F<@=VET:"!T:&4@9FEL92!C;VYT96YT
M+"!O<B!.54Q,(&]N(&5R<F]R+@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]F
M:6QE;F%M92`@("`@5&AE('!A=&@@;V8@=&AE(&9I;&4@=&\@97AT<F%C="!I
M;B!A('-T<FEN9RX-"B`@("`J($!R971U<FX@("`@("`@("`@("`@("`@("`@
M("`@(&$@<W1R:6YG('=I=&@@=&AE(&9I;&4@8V]N=&5N="!O<B!.54Q,+@T*
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&5X
M=')A8W1);E-T<FEN9R@D<%]F:6QE;F%M92D-"B`@("![#0H@("`@("`@(&EF
M("@D=&AI<RT^7V]P96Y296%D*"DI('L-"B`@("`@("`@("`@("1V7W)E<W5L
M="`]("1T:&ES+3Y?97AT<F%C=$EN4W1R:6YG*"1P7V9I;&5N86UE*3L-"B`@
M("`@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1V7W)E<W5L="`]($Y53$P[#0H@("`@("`@('T-"@T*
M("`@("`@("!R971U<FX@)'9?<F5S=6QT.PT*("`@('T-"B`@("`O+R!]?7T-
M"@T*("`@("\O('M[>R!E>'1R86-T3&ES="@I#0H@("`@+RHJ#0H@("`@*B!4
M:&ES(&UE=&AO9"!E>'1R86-T(&9R;VT@=&AE(&%R8VAI=F4@;VYL>2!T:&4@
M9FEL97,@:6YD:6-A=&5D(&EN('1H90T*("`@("H@)'!?9FEL96QI<W0N(%1H
M97-E(&9I;&5S(&%R92!E>'1R86-T960@:6X@=&AE(&-U<G)E;G0@9&ER96-T
M;W)Y(&]R#0H@("`@*B!I;B!T:&4@9&ER96-T;W)Y(&EN9&EC871E9"!B>2!T
M:&4@;W!T:6]N86P@)'!?<&%T:"!P87)A;65T97(N#0H@("`@*B!)9B!I;F1I
M8V%T960@=&AE("1P7W)E;6]V95]P871H(&-A;B!B92!U<V5D(&EN('1H92!S
M86UE('=A>2!A<R!I="!I<PT*("`@("H@=7-E9"!I;B!E>'1R86-T36]D:69Y
M*"D@;65T:&]D+@T*("`@("H@0'!A<F%M(&%R<F%Y("`D<%]F:6QE;&ES="`@
M("`@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E8W1O<GD@;F%M97,L
M(&]R(&$@<VEN9VQE#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@82!S:6YG;&4@
M8FQA;FL@<W!A8V4N#0H@("`@*B!`<&%R86T@<W1R:6YG("1P7W!A=&@@("`@
M("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('=H97)E('1H92!F:6QE
M<R]D:7(@;F5E9"!T;R!B>0T*("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@97AT<F%C=&5D+@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]R
M96UO=F5?<&%T:"`@4&%R="!O9B!T:&4@;65M;W)I>F5D('!A=&@@=&AA="!C
M86X@8F4@<F5M;W9E9"!I9@T*("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<')E<V5N="!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M+V1I<B!P871H+@T*("`@("H@0')E='5R;B`@("`@("`@("`@("`@("`@("`@
M("`@=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@*B!`<V5E(&5X=')A8W1-;V1I9GDH*0T*("`@
M("HO#0H@("`@9G5N8W1I;VX@97AT<F%C=$QI<W0H)'!?9FEL96QI<W0L("1P
M7W!A=&@])R<L("1P7W)E;6]V95]P871H/2<G*0T*("`@('L-"B`@("`@("`@
M)'9?<F5S=6QT(#T@=')U93L-"B`@("`@("`@)'9?;&ES=%]D971A:6P@/2!A
M<G)A>2@I.PT*#0H@("`@("`@(&EF("AI<U]A<G)A>2@D<%]F:6QE;&ES="DI
M#0H@("`@("`@("`@("`D=E]L:7-T(#T@)'!?9FEL96QI<W0[#0H@("`@("`@
M(&5L<V5I9B`H:7-?<W1R:6YG*"1P7V9I;&5L:7-T*2D-"B`@("`@("`@("`@
M("1V7VQI<W0@/2!E>'!L;V1E*"(@(BP@)'!?9FEL96QI<W0I.PT*("`@("`@
M("!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@
M<W1R:6YG(&QI<W0G*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*#0H@("`@("`@(&EF("@D=E]R97-U;'0@/2`D=&AI<RT^7V]P
M96Y296%D*"DI('L-"B`@("`@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?
M97AT<F%C=$QI<W0H)'!?<&%T:"P@)'9?;&ES=%]D971A:6PL(")P87)T:6%L
M(BP@)'9?;&ES="P@)'!?<F5M;W9E7W!A=&@I.PT*("`@("`@("`@("`@)'1H
M:7,M/E]C;&]S92@I.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1V
M7W)E<W5L=#L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V5R
M<F]R*"D-"B`@("!F=6YC=&EO;B!?97)R;W(H)'!?;65S<V%G92D-"B`@("![
M#0H@("`@("`@("\O("TM+2TM(%1O(&)E(&-O;7!L971E9`T*("`@("`@("`D
M=&AI<RT^<F%I<V5%<G)O<B@D<%]M97-S86=E*3L-"B`@("!]#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@7W=A<FYI;F<H*0T*("`@(&9U;F-T:6]N(%]W
M87)N:6YG*"1P7VUE<W-A9V4I#0H@("`@>PT*("`@("`@("`O+R`M+2TM+2!4
M;R!B92!C;VUP;&5T960-"B`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)'!?
M;65S<V%G92D[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]O
M<&5N5W)I=&4H*0T*("`@(&9U;F-T:6]N(%]O<&5N5W)I=&4H*0T*("`@('L-
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*0T*
M("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&=Z;W!E;B@D=&AI<RT^7W1A
M<FYA;64L(")W8B(I.PT*("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R
M97-S7W1Y<&4@/3T@)V)Z,B<I#0H@("`@("`@("`@("`D=&AI<RT^7V9I;&4@
M/2!`8GIO<&5N*"1T:&ES+3Y?=&%R;F%M92P@(G=B(BD[#0H@("`@("`@(&5L
M<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G;F]N92<I#0H@("`@
M("`@("`@("`D=&AI<RT^7V9I;&4@/2!`9F]P96XH)'1H:7,M/E]T87)N86UE
M+"`B=V(B*3L-"B`@("`@("`@96QS90T*("`@("`@("`@("`@)'1H:7,M/E]E
M<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@*"<N
M)'1H:7,M/E]C;VUP<F5S<U]T>7!E+B<I)RD[#0H-"B`@("`@("`@:68@*"1T
M:&ES+3Y?9FEL92`]/2`P*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R
M*"=5;F%B;&4@=&\@;W!E;B!I;B!W<FET92!M;V1E(%PG)RXD=&AI<RT^7W1A
M<FYA;64N)UPG)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@7V]P96Y296%D*"D-"B`@("!F=6YC=&EO;B!?
M;W!E;E)E860H*0T*("`@('L-"B`@("`@("`@:68@*'-T<G1O;&]W97(H<W5B
M<W1R*"1T:&ES+3Y?=&%R;F%M92P@,"P@-RDI(#T]("=H='1P.B\O)RD@>PT*
M#0H@("`@("`@("`@+R\@+2TM+2T@3&]O:R!I9B!A(&QO8V%L(&-O<'D@;F5E
M9"!T;R!B92!D;VYE#0H@("`@("`@("`@:68@*"1T:&ES+3Y?=&5M<%]T87)N
M86UE(#T]("<G*2![#0H@("`@("`@("`@("`@("1T:&ES+3Y?=&5M<%]T87)N
M86UE(#T@=6YI<6ED*"=T87(G*2XG+G1M<"<[#0H@("`@("`@("`@("`@(&EF
M("@A)'9?9FEL95]F<F]M(#T@0&9O<&5N*"1T:&ES+3Y?=&%R;F%M92P@)W)B
M)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B;&4@
M=&\@;W!E;B!I;B!R96%D(&UO9&4@7"<G+B1T:&ES+3Y?=&%R;F%M92XG7"<G
M*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W1E;7!?=&%R;F%M92`]("<G
M.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("!I9B`H(21V7V9I;&5?=&\@/2!`9F]P96XH
M)'1H:7,M/E]T96UP7W1A<FYA;64L("=W8B<I*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&]P96X@:6X@=W)I=&4@;6]D
M92!<)R<N)'1H:7,M/E]T96UP7W1A<FYA;64N)UPG)RD[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]T96UP7W1A<FYA;64@/2`G)SL-"B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@=VAI;&4@*"1V7V1A=&$@/2!`9G)E860H)'9?9FEL95]F<F]M+"`Q
M,#(T*2D-"B`@("`@("`@("`@("`@("`@($!F=W)I=&4H)'9?9FEL95]T;RP@
M)'9?9&%T82D[#0H@("`@("`@("`@("`@($!F8VQO<V4H)'9?9FEL95]F<F]M
M*3L-"B`@("`@("`@("`@("`@0&9C;&]S92@D=E]F:6QE7W1O*3L-"B`@("`@
M("`@("!]#0H-"B`@("`@("`@("`O+R`M+2TM+2!&:6QE('1O(&]P96X@:68@
M=&AE(&QO8V%L(&-O<'D-"B`@("`@("`@("`D=E]F:6QE;F%M92`]("1T:&ES
M+3Y?=&5M<%]T87)N86UE.PT*#0H@("`@("`@('T@96QS90T*("`@("`@("`@
M("\O("TM+2TM($9I;&4@=&\@;W!E;B!I9B!T:&4@;F]R;6%L(%1A<B!F:6QE
M#0H@("`@("`@("`@)'9?9FEL96YA;64@/2`D=&AI<RT^7W1A<FYA;64[#0H-
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*0T*
M("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&=Z;W!E;B@D=E]F:6QE;F%M
M92P@(G)B(BD[#0H@("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?
M='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@("1T:&ES+3Y?9FEL92`]($!B
M>F]P96XH)'9?9FEL96YA;64L(")R8B(I.PT*("`@("`@("!E;'-E(&EF("@D
M=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@("`@("`@
M)'1H:7,M/E]F:6QE(#T@0&9O<&5N*"1V7V9I;&5N86UE+"`B<F(B*3L-"B`@
M("`@("`@96QS90T*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W
M;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@*"<N)'1H:7,M/E]C;VUP
M<F5S<U]T>7!E+B<I)RD[#0H-"B`@("`@("`@:68@*"1T:&ES+3Y?9FEL92`]
M/2`P*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B;&4@=&\@
M;W!E;B!I;B!R96%D(&UO9&4@7"<G+B1V7V9I;&5N86UE+B=<)R<I.PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(%]O<&5N4F5A9%=R:71E*"D-"B`@("!F=6YC=&EO;B!?;W!E;E)E8617<FET
M92@I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E
M(#T]("=G>B<I#0H@("`@("`@("`@("`D=&AI<RT^7V9I;&4@/2!`9WIO<&5N
M*"1T:&ES+3Y?=&%R;F%M92P@(G(K8B(I.PT*("`@("`@("!E;'-E(&EF("@D
M=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V)Z,B<I#0H@("`@("`@("`@("`D
M=&AI<RT^7V9I;&4@/2!`8GIO<&5N*"1T:&ES+3Y?=&%R;F%M92P@(G(K8B(I
M.PT*("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@
M)VYO;F4G*0T*("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&9O<&5N*"1T
M:&ES+3Y?=&%R;F%M92P@(G(K8B(I.PT*("`@("`@("!E;'-E#0H@("`@("`@
M("`@("`D=&AI<RT^7V5R<F]R*"=5;FMN;W=N(&]R(&UI<W-I;F<@8V]M<')E
M<W-I;VX@='EP92`H)RXD=&AI<RT^7V-O;7!R97-S7W1Y<&4N)RDG*3L-"@T*
M("`@("`@("!I9B`H)'1H:7,M/E]F:6QE(#T](#`I('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&EN(')E860O=W)I=&4@
M;6]D92!<)R<N)'1H:7,M/E]T87)N86UE+B=<)R<I.PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]C;&]S92@I
M#0H@("`@9G5N8W1I;VX@7V-L;W-E*"D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7V9I;&4I*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]C;VUP<F5S<U]T>7!E(#T]("=G>B<I#0H@("`@("`@("`@("`@("`@0&=Z
M8VQO<V4H)'1H:7,M/E]F:6QE*3L-"B`@("`@("`@("`@(&5L<V4@:68@*"1T
M:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@("`@
M("!`8GIC;&]S92@D=&AI<RT^7V9I;&4I.PT*("`@("`@("`@("`@96QS92!I
M9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=N;VYE)RD-"B`@("`@("`@
M("`@("`@("!`9F-L;W-E*"1T:&ES+3Y?9FEL92D[#0H@("`@("`@("`@("!E
M;'-E#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O
M<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@*"<N)'1H:7,M/E]C;VUP<F5S
M<U]T>7!E+B<I)RD[#0H-"B`@("`@("`@("`@("1T:&ES+3Y?9FEL92`](#`[
M#0H@("`@("`@('T-"@T*("`@("`@("`O+R`M+2TM+2!,;V]K(&EF(&$@;&]C
M86P@8V]P>2!N965D('1O(&)E(&5R87-E#0H@("`@("`@("\O($YO=&4@=&AA
M="!I="!M:6=H="!B92!I;G1E<F5S=&EN9R!T;R!K965P('1H92!U<FP@9F]R
M(&$@=&EM92`Z(%1O1&\-"B`@("`@("`@:68@*"1T:&ES+3Y?=&5M<%]T87)N
M86UE("$]("<G*2![#0H@("`@("`@("`@("!`=6YL:6YK*"1T:&ES+3Y?=&5M
M<%]T87)N86UE*3L-"B`@("`@("`@("`@("1T:&ES+3Y?=&5M<%]T87)N86UE
M(#T@)R<[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V-L96%N1FEL92@I#0H@
M("`@9G5N8W1I;VX@7V-L96%N1FEL92@I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7V-L;W-E*"D[#0H-"B`@("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@82!L
M;V-A;"!C;W!Y#0H@("`@("`@(&EF("@D=&AI<RT^7W1E;7!?=&%R;F%M92`A
M/2`G)RD@>PT*("`@("`@("`@("`@+R\@+2TM+2T@4F5M;W9E('1H92!L;V-A
M;"!C;W!Y(&)U="!N;W0@=&AE(')E;6]T92!T87)N86UE#0H@("`@("`@("`@
M("!`=6YL:6YK*"1T:&ES+3Y?=&5M<%]T87)N86UE*3L-"B`@("`@("`@("`@
M("1T:&ES+3Y?=&5M<%]T87)N86UE(#T@)R<[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`O+R`M+2TM+2!296UO=F4@=&AE(&QO8V%L('1A<FYA
M;64@9FEL90T*("`@("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7W1A<FYA;64I
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?=&%R;F%M92`]("<G.PT*
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*
M("`@("\O('M[>R!?=W)I=&5";&]C:R@I#0H@("`@9G5N8W1I;VX@7W=R:71E
M0FQO8VLH)'!?8FEN87)Y7V1A=&$L("1P7VQE;CUN=6QL*0T*("`@('L-"B`@
M("`@(&EF("@D=&AI<RT^7V9I;&4I('L-"B`@("`@("`@("!I9B`H)'!?;&5N
M(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R
M97-S7W1Y<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("`@("`@($!G>G!U=',H
M)'1H:7,M/E]F:6QE+"`D<%]B:6YA<GE?9&%T82D[#0H@("`@("`@("`@("`@
M(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@
M("`@("`@("`@("`@("`@($!B>G=R:71E*"1T:&ES+3Y?9FEL92P@)'!?8FEN
M87)Y7V1A=&$I.PT*("`@("`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O
M;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@("`@("`@("`@("`@0&9P
M=71S*"1T:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A=&$I.PT*("`@("`@("`@
M("`@("!E;'-E#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5
M;FMN;W=N(&]R(&UI<W-I;F<@8V]M<')E<W-I;VX@='EP92`H)RXD=&AI<RT^
M7V-O;7!R97-S7W1Y<&4N)RDG*3L-"B`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=G>B<I
M#0H@("`@("`@("`@("`@("`@("!`9WIP=71S*"1T:&ES+3Y?9FEL92P@)'!?
M8FEN87)Y7V1A=&$L("1P7VQE;BD[#0H@("`@("`@("`@("`@(&5L<V4@:68@
M*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@
M("`@("`@($!B>G=R:71E*"1T:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A=&$L
M("1P7VQE;BD[#0H@("`@("`@("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M
M<')E<W-?='EP92`]/2`G;F]N92<I#0H@("`@("`@("`@("`@("`@("!`9G!U
M=',H)'1H:7,M/E]F:6QE+"`D<%]B:6YA<GE?9&%T82P@)'!?;&5N*3L-"B`@
M("`@("`@("`@("`@96QS90T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E
M<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@*"<N
M)'1H:7,M/E]C;VUP<F5S<U]T>7!E+B<I)RD[#0H-"B`@("`@("`@("!]#0H@
M("`@("!]#0H@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]
M#0H-"B`@("`O+R![>WL@7W)E861";&]C:R@I#0H@("`@9G5N8W1I;VX@7W)E
M861";&]C:R@D<%]L96X];G5L;"D-"B`@("![#0H@("`@("`D=E]B;&]C:R`]
M(&YU;&P[#0H@("`@("!I9B`H)'1H:7,M/E]F:6QE*2![#0H@("`@("`@("`@
M:68@*"1P7VQE;B`]/3T@;G5L;"D-"B`@("`@("`@("`@("`@)'!?;&5N(#T@
M-3$R.PT*("`@("`@("`@("`@("`-"B`@("`@("`@("!I9B`H)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T]("=G>B<I#0H@("`@("`@("`@("`@("1V7V)L;V-K
M(#T@0&=Z<F5A9"@D=&AI<RT^7V9I;&4L(#4Q,BD[#0H@("`@("`@("`@96QS
M92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@
M("`@("`@("`D=E]B;&]C:R`]($!B>G)E860H)'1H:7,M/E]F:6QE+"`U,3(I
M.PT*("`@("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]
M/2`G;F]N92<I#0H@("`@("`@("`@("`@("1V7V)L;V-K(#T@0&9R96%D*"1T
M:&ES+3Y?9FEL92P@-3$R*3L-"B`@("`@("`@("!E;'-E#0H@("`@("`@("`@
M("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C;VUP<F5S
M<VEO;B!T>7!E("@G+B1T:&ES+3Y?8V]M<')E<W-?='EP92XG*2<I.PT*#0H@
M("`@("!]#0H@("`@("!R971U<FX@)'9?8FQO8VL[#0H@("`@?0T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(%]J=6UP0FQO8VLH*0T*("`@(&9U;F-T:6]N
M(%]J=6UP0FQO8VLH)'!?;&5N/6YU;&PI#0H@("`@>PT*("`@("`@:68@*"1T
M:&ES+3Y?9FEL92D@>PT*("`@("`@("`@(&EF("@D<%]L96X@/3T](&YU;&PI
M#0H@("`@("`@("`@("`@("1P7VQE;B`](#$[#0H-"B`@("`@("`@("!I9B`H
M)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=G>B<I#0H@("`@("`@("`@("`@
M($!G>G-E96LH)'1H:7,M/E]F:6QE+"!`9WIT96QL*"1T:&ES+3Y?9FEL92DK
M*"1P7VQE;BHU,3(I*3L-"B`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O
M;7!R97-S7W1Y<&4@/3T@)V)Z,B<I('L-"B`@("`@("`@("`@("`@+R\@+2TM
M+2T@4F5P;&%C92!M:7-S:6YG(&)Z=&5L;"@I(&%N9"!B>G-E96LH*0T*("`@
M("`@("`@("`@("!F;W(@*"1I/3`[("1I/"1P7VQE;CL@)&DK*RD-"B`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F5A9$)L;V-K*"D[#0H@("`@("`@("`@
M?2!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*
M("`@("`@("`@("`@("!`9G-E96LH)'1H:7,M/E]F:6QE+"!`9G1E;&PH)'1H
M:7,M/E]F:6QE*2LH)'!?;&5N*C4Q,BDI.PT*("`@("`@("`@(&5L<V4-"B`@
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG
M(&-O;7!R97-S:6]N('1Y<&4@*"<N)'1H:7,M/E]C;VUP<F5S<U]T>7!E+B<I
M)RD[#0H-"B`@("`@('T-"B`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!?=W)I=&5&;V]T97(H*0T*("`@(&9U
M;F-T:6]N(%]W<FET949O;W1E<B@I#0H@("`@>PT*("`@("`@:68@*"1T:&ES
M+3Y?9FEL92D@>PT*("`@("`@("`@("\O("TM+2TM(%=R:71E('1H92!L87-T
M(#`@9FEL;&5D(&)L;V-K(&9O<B!E;F0@;V8@87)C:&EV90T*("`@("`@("`@
M("1V7V)I;F%R>5]D871A(#T@<&%C:R@B834Q,B(L("<G*3L-"B`@("`@("`@
M("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&$I.PT*("`@("`@
M?0T*("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(%]A9&1,:7-T*"D-"B`@("!F=6YC=&EO;B!?861D3&ES="@D
M<%]L:7-T+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER*0T*("`@('L-"B`@
M("`@("1V7W)E<W5L=#UT<G5E.PT*("`@("`@)'9?:&5A9&5R(#T@87)R87DH
M*3L-"@T*("`@("`@+R\@+2TM+2T@4F5M;W9E('!O=&5N=&EA;"!W:6YD;W=S
M(&1I<F5C=&]R>2!S97!A<F%T;W(-"B`@("`@("1P7V%D9%]D:7(@/2`D=&AI
M<RT^7W1R86YS;&%T95=I;E!A=&@H)'!?861D7V1I<BD[#0H@("`@("`D<%]R
M96UO=F5?9&ER(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0871H*"1P7W)E;6]V
M95]D:7(L(&9A;'-E*3L-"@T*("`@("`@:68@*"$D=&AI<RT^7V9I;&4I('L-
M"B`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@9&5S8W)I
M<'1O<B<I.PT*("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@('T-"@T*
M("`@("`@:68@*'-I>F5O9B@D<%]L:7-T*2`]/2`P*0T*("`@("`@("`@(')E
M='5R;B!T<G5E.PT*#0H@("`@("!F;W(@*"1J/3`[("@D:CQC;W5N="@D<%]L
M:7-T*2D@)B8@*"1V7W)E<W5L="D[("1J*RLI('L-"B`@("`@("`@)'9?9FEL
M96YA;64@/2`D<%]L:7-T6R1J73L-"@T*("`@("`@("`O+R`M+2TM+2!3:VEP
M('1H92!C=7)R96YT('1A<B!N86UE#0H@("`@("`@(&EF("@D=E]F:6QE;F%M
M92`]/2`D=&AI<RT^7W1A<FYA;64I#0H@("`@("`@("`@("!C;VYT:6YU93L-
M"@T*("`@("`@("!I9B`H)'9?9FEL96YA;64@/3T@)R<I#0H@("`@("`@("`@
M("!C;VYT:6YU93L-"@T*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1V7V9I
M;&5N86UE*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]W87)N:6YG*")&:6QE
M("<D=E]F:6QE;F%M92<@9&]E<R!N;W0@97AI<W0B*3L-"B`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM+2T@061D
M('1H92!F:6QE(&]R(&1I<F5C=&]R>2!H96%D97(-"B`@("`@("`@:68@*"$D
M=&AI<RT^7V%D9$9I;&4H)'9?9FEL96YA;64L("1V7VAE861E<BP@)'!?861D
M7V1I<BP@)'!?<F5M;W9E7V1I<BDI#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H-"B`@("`@("`@:68@*$!I<U]D:7(H)'9?9FEL96YA;64I*2![#0H@
M("`@("`@("`@("!I9B`H(2@D<%]H9&ER(#T@;W!E;F1I<B@D=E]F:6QE;F%M
M92DI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]W87)N:6YG*")$:7)E
M8W1O<GD@)R1V7V9I;&5N86UE)R!C86X@;F]T(&)E(')E860B*3L-"B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1P7VAI=&5M(#T@<F5A9&1I<B@D<%]H9&ER*3L@+R\@)RXG(&1I<F5C
M=&]R>0T*("`@("`@("`@("`@)'!?:&ET96T@/2!R96%D9&ER*"1P7VAD:7(I
M.R`O+R`G+BXG(&1I<F5C=&]R>0T*("`@("`@("`@("`@=VAI;&4@*&9A;'-E
M("$]/2`H)'!?:&ET96T@/2!R96%D9&ER*"1P7VAD:7(I*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@D=E]F:6QE;F%M92`A/2`B+B(I#0H@("`@("`@("`@
M("`@("`@("`@("1P7W1E;7!?;&ES=%LP72`]("1V7V9I;&5N86UE+B<O)RXD
M<%]H:71E;3L-"B`@("`@("`@("`@("`@("!E;'-E#0H@("`@("`@("`@("`@
M("`@("`@("1P7W1E;7!?;&ES=%LP72`]("1P7VAI=&5M.PT*#0H@("`@("`@
M("`@("`@("`@)'9?<F5S=6QT(#T@)'1H:7,M/E]A9&1,:7-T*"1P7W1E;7!?
M;&ES="P@)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I<BD[#0H@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@('5N<V5T*"1P7W1E;7!?;&ES="D[#0H@("`@
M("`@("`@("!U;G-E="@D<%]H9&ER*3L-"B`@("`@("`@("`@('5N<V5T*"1P
M7VAI=&5M*3L-"B`@("`@("`@?0T*("`@("`@?0T*#0H@("`@("!R971U<FX@
M)'9?<F5S=6QT.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?
M861D1FEL92@I#0H@("`@9G5N8W1I;VX@7V%D9$9I;&4H)'!?9FEL96YA;64L
M("8D<%]H96%D97(L("1P7V%D9%]D:7(L("1P7W)E;6]V95]D:7(I#0H@("`@
M>PT*("`@("`@:68@*"$D=&AI<RT^7V9I;&4I('L-"B`@("`@("`@("`D=&AI
M<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@9&5S8W)I<'1O<B<I.PT*("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@('T-"@T*("`@("`@:68@*"1P7V9I
M;&5N86UE(#T]("<G*2![#0H@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV
M86QI9"!F:6QE(&YA;64G*3L-"B`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("!]#0H-"B`@("`@("\O("TM+2TM($-A;&-U;&%T92!T:&4@<W1O<F5D
M(&9I;&5N86UE#0H@("`@("`D<%]F:6QE;F%M92`]("1T:&ES+3Y?=')A;G-L
M871E5VEN4&%T:"@D<%]F:6QE;F%M92P@9F%L<V4I.SL-"B`@("`@("1V7W-T
M;W)E9%]F:6QE;F%M92`]("1P7V9I;&5N86UE.PT*("`@("`@:68@*'-T<F-M
M<"@D<%]F:6QE;F%M92P@)'!?<F5M;W9E7V1I<BD@/3T@,"D@>PT*("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@?0T*("`@("`@:68@*"1P7W)E;6]V
M95]D:7(@(3T@)R<I('L-"B`@("`@("`@("!I9B`H<W5B<W1R*"1P7W)E;6]V
M95]D:7(L("TQ*2`A/2`G+R<I#0H@("`@("`@("`@("`@("1P7W)E;6]V95]D
M:7(@+CT@)R\G.PT*#0H@("`@("`@("`@:68@*'-U8G-T<B@D<%]F:6QE;F%M
M92P@,"P@<W1R;&5N*"1P7W)E;6]V95]D:7(I*2`]/2`D<%]R96UO=F5?9&ER
M*0T*("`@("`@("`@("`@("`D=E]S=&]R961?9FEL96YA;64@/2!S=6)S='(H
M)'!?9FEL96YA;64L('-T<FQE;B@D<%]R96UO=F5?9&ER*2D[#0H@("`@("!]
M#0H@("`@("`D=E]S=&]R961?9FEL96YA;64@/2`D=&AI<RT^7W1R86YS;&%T
M95=I;E!A=&@H)'9?<W1O<F5D7V9I;&5N86UE*3L-"B`@("`@(&EF("@D<%]A
M9&1?9&ER("$]("<G*2![#0H@("`@("`@("`@:68@*'-U8G-T<B@D<%]A9&1?
M9&ER+"`M,2D@/3T@)R\G*0T*("`@("`@("`@("`@("`D=E]S=&]R961?9FEL
M96YA;64@/2`D<%]A9&1?9&ER+B1V7W-T;W)E9%]F:6QE;F%M93L-"B`@("`@
M("`@("!E;'-E#0H@("`@("`@("`@("`@("1V7W-T;W)E9%]F:6QE;F%M92`]
M("1P7V%D9%]D:7(N)R\G+B1V7W-T;W)E9%]F:6QE;F%M93L-"B`@("`@('T-
M"@T*("`@("`@)'9?<W1O<F5D7V9I;&5N86UE(#T@)'1H:7,M/E]P871H4F5D
M=6-T:6]N*"1V7W-T;W)E9%]F:6QE;F%M92D[#0H-"B`@("`@(&EF("AI<U]F
M:6QE*"1P7V9I;&5N86UE*2D@>PT*("`@("`@("`@(&EF("@H)'9?9FEL92`]
M($!F;W!E;B@D<%]F:6QE;F%M92P@(G)B(BDI(#T](#`I('L-"B`@("`@("`@
M("`@("`@)'1H:7,M/E]W87)N:6YG*")5;F%B;&4@=&\@;W!E;B!F:6QE("<D
M<%]F:6QE;F%M92<@:6X@8FEN87)Y(')E860@;6]D92(I.PT*("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("!]#0H-"B`@("`@("`@("!I
M9B`H(21T:&ES+3Y?=W)I=&5(96%D97(H)'!?9FEL96YA;64L("1V7W-T;W)E
M9%]F:6QE;F%M92DI#0H@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"@T*
M("`@("`@("`@('=H:6QE("@H)'9?8G5F9F5R(#T@9G)E860H)'9?9FEL92P@
M-3$R*2D@(3T@)R<I('L-"B`@("`@("`@("`@("`@)'9?8FEN87)Y7V1A=&$@
M/2!P86-K*")A-3$R(BP@(B1V7V)U9F9E<B(I.PT*("`@("`@("`@("`@("`D
M=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&$I.PT*("`@("`@("`@
M('T-"@T*("`@("`@("`@(&9C;&]S92@D=E]F:6QE*3L-"@T*("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`O+R`M+2TM+2!/;FQY(&AE861E<B!F;W(@9&ER
M#0H@("`@("`@("`@:68@*"$D=&AI<RT^7W=R:71E2&5A9&5R*"1P7V9I;&5N
M86UE+"`D=E]S=&]R961?9FEL96YA;64I*0T*("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("!]#0H-"B`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?861D4W1R:6YG*"D-"B`@
M("!F=6YC=&EO;B!?861D4W1R:6YG*"1P7V9I;&5N86UE+"`D<%]S=')I;F<I
M#0H@("`@>PT*("`@("`@:68@*"$D=&AI<RT^7V9I;&4I('L-"B`@("`@("`@
M("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@9&5S8W)I<'1O<B<I.PT*
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@('T-"@T*("`@("`@:68@
M*"1P7V9I;&5N86UE(#T]("<G*2![#0H@("`@("`@("`@)'1H:7,M/E]E<G)O
M<B@G26YV86QI9"!F:6QE(&YA;64G*3L-"B`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("!]#0H-"B`@("`@("\O("TM+2TM($-A;&-U;&%T92!T:&4@
M<W1O<F5D(&9I;&5N86UE#0H@("`@("`D<%]F:6QE;F%M92`]("1T:&ES+3Y?
M=')A;G-L871E5VEN4&%T:"@D<%]F:6QE;F%M92P@9F%L<V4I.SL-"@T*("`@
M("`@:68@*"$D=&AI<RT^7W=R:71E2&5A9&5R0FQO8VLH)'!?9FEL96YA;64L
M('-T<FQE;B@D<%]S=')I;F<I+"`P+"`P+"`B(BP@,"P@,"DI#0H@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("`D:3TP.PT*("`@("`@=VAI;&4@
M*"@D=E]B=69F97(@/2!S=6)S='(H)'!?<W1R:6YG+"`H*"1I*RLI*C4Q,BDL
M(#4Q,BDI("$]("<G*2![#0H@("`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P
M86-K*")A-3$R(BP@)'9?8G5F9F5R*3L-"B`@("`@("`@("`D=&AI<RT^7W=R
M:71E0FQO8VLH)'9?8FEN87)Y7V1A=&$I.PT*("`@("`@?0T*#0H@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@
M7W=R:71E2&5A9&5R*"D-"B`@("!F=6YC=&EO;B!?=W)I=&5(96%D97(H)'!?
M9FEL96YA;64L("1P7W-T;W)E9%]F:6QE;F%M92D-"B`@("![#0H@("`@("`@
M(&EF("@D<%]S=&]R961?9FEL96YA;64@/3T@)R<I#0H@("`@("`@("`@("`D
M<%]S=&]R961?9FEL96YA;64@/2`D<%]F:6QE;F%M93L-"B`@("`@("`@)'9?
M<F5D=6-E7V9I;&5N86UE(#T@)'1H:7,M/E]P871H4F5D=6-T:6]N*"1P7W-T
M;W)E9%]F:6QE;F%M92D[#0H-"B`@("`@("`@:68@*'-T<FQE;B@D=E]R961U
M8V5?9FEL96YA;64I(#X@.3DI('L-"B`@("`@("`@("!I9B`H(21T:&ES+3Y?
M=W)I=&5,;VYG2&5A9&5R*"1V7W)E9'5C95]F:6QE;F%M92DI#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@("`D=E]I
M;F9O(#T@<W1A="@D<%]F:6QE;F%M92D[#0H@("`@("`@("1V7W5I9"`]('-P
M<FEN=&8H(B4V<R`B+"!$96-/8W0H)'9?:6YF;ULT72DI.PT*("`@("`@("`D
M=E]G:60@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1V7VEN9F];-5TI*3L-
M"B`@("`@("`@)'9?<&5R;7,@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*&9I
M;&5P97)M<R@D<%]F:6QE;F%M92DI*3L-"@T*("`@("`@("`D=E]M=&EM92`]
M('-P<FEN=&8H(B4Q,7,B+"!$96-/8W0H9FEL96UT:6UE*"1P7V9I;&5N86UE
M*2DI.PT*#0H@("`@("`@(&EF("A`:7-?9&ER*"1P7V9I;&5N86UE*2D@>PT*
M("`@("`@("`@("1V7W1Y<&5F;&%G(#T@(C4B.PT*("`@("`@("`@("1V7W-I
M>F4@/2!S<')I;G1F*"(E,3%S("(L($1E8T]C="@P*2D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@)'9?='EP969L86<@/2`G)SL-"B`@("`@("`@
M("!C;&5A<G-T871C86-H92@I.PT*("`@("`@("`@("1V7W-I>F4@/2!S<')I
M;G1F*"(E,3%S("(L($1E8T]C="AF:6QE<VEZ92@D<%]F:6QE;F%M92DI*3L-
M"B`@("`@("`@?0T*#0H@("`@("`@("1V7VQI;FMN86UE(#T@)R<[#0H-"B`@
M("`@("`@)'9?;6%G:6,@/2`G)SL-"@T*("`@("`@("`D=E]V97)S:6]N(#T@
M)R<[#0H-"B`@("`@("`@)'9?=6YA;64@/2`G)SL-"@T*("`@("`@("`D=E]G
M;F%M92`]("<G.PT*#0H@("`@("`@("1V7V1E=FUA:F]R(#T@)R<[#0H-"B`@
M("`@("`@)'9?9&5V;6EN;W(@/2`G)SL-"@T*("`@("`@("`D=E]P<F5F:7@@
M/2`G)SL-"@T*("`@("`@("`D=E]B:6YA<GE?9&%T85]F:7)S="`]('!A8VLH
M(F$Q,#!A.&$X83AA,3)!,3(B+"`D=E]R961U8V5?9FEL96YA;64L("1V7W!E
M<FUS+"`D=E]U:60L("1V7V=I9"P@)'9?<VEZ92P@)'9?;71I;64I.PT*("`@
M("`@("`D=E]B:6YA<GE?9&%T85]L87-T(#T@<&%C:R@B83%A,3`P839A,F$S
M,F$S,F$X83AA,34U83$R(BP@)'9?='EP969L86<L("1V7VQI;FMN86UE+"`D
M=E]M86=I8RP@)'9?=F5R<VEO;BP@)'9?=6YA;64L("1V7V=N86UE+"`D=E]D
M979M86IO<BP@)'9?9&5V;6EN;W(L("1V7W!R969I>"P@)R<I.PT*#0H@("`@
M("`@("\O("TM+2TM($-A;&-U;&%T92!T:&4@8VAE8VMS=6T-"B`@("`@("`@
M)'9?8VAE8VMS=6T@/2`P.PT*("`@("`@("`O+R`N+BXN+B!&:7)S="!P87)T
M(&]F('1H92!H96%D97(-"B`@("`@("`@9F]R("@D:3TP.R`D:3PQ-#@[("1I
M*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H<W5B<W1R*"1V
M7V)I;F%R>5]D871A7V9I<G-T+"1I+#$I*3L-"B`@("`@("`@+R\@+BXN+BX@
M26=N;W)E('1H92!C:&5C:W-U;2!V86QU92!A;F0@<F5P;&%C92!I="!B>2`G
M("<@*'-P86-E*0T*("`@("`@("!F;W(@*"1I/3$T.#L@)&D\,34V.R`D:2LK
M*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6T@*ST@;W)D*"<@)RD[#0H@("`@
M("`@("\O("XN+BXN($QA<W0@<&%R="!O9B!T:&4@:&5A9&5R#0H@("`@("`@
M(&9O<B`H)&D],34V+"`D:CTP.R`D:3PU,3([("1I*RLL("1J*RLI#0H@("`@
M("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H<W5B<W1R*"1V7V)I;F%R>5]D
M871A7VQA<W0L)&HL,2DI.PT*#0H@("`@("`@("\O("TM+2TM(%=R:71E('1H
M92!F:7)S="`Q-#@@8GET97,@;V8@=&AE(&AE861E<B!I;B!T:&4@87)C:&EV
M90T*("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&%?
M9FER<W0L(#$T."D[#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I=&4@=&AE(&-A
M;&-U;&%T960@8VAE8VMS=6T-"B`@("`@("`@)'9?8VAE8VMS=6T@/2!S<')I
M;G1F*"(E-G,@(BP@1&5C3V-T*"1V7V-H96-K<W5M*2D[#0H@("`@("`@("1V
M7V)I;F%R>5]D871A(#T@<&%C:R@B83@B+"`D=E]C:&5C:W-U;2D[#0H@("`@
M("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T82P@."D[#0H-
M"B`@("`@("`@+R\@+2TM+2T@5W)I=&4@=&AE(&QA<W0@,S4V(&)Y=&5S(&]F
M('1H92!H96%D97(@:6X@=&AE(&%R8VAI=F4-"B`@("`@("`@)'1H:7,M/E]W
M<FET94)L;V-K*"1V7V)I;F%R>5]D871A7VQA<W0L(#,U-BD[#0H-"B`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(%]W<FET94AE861E<D)L;V-K*"D-"B`@("!F=6YC=&EO;B!?=W)I=&5(
M96%D97)";&]C:R@D<%]F:6QE;F%M92P@)'!?<VEZ92P@)'!?;71I;64],"P@
M)'!?<&5R;7,],"P@)'!?='EP93TG)RP@)'!?=6ED/3`L("1P7V=I9#TP*0T*
M("`@('L-"B`@("`@("`@)'!?9FEL96YA;64@/2`D=&AI<RT^7W!A=&A2961U
M8W1I;VXH)'!?9FEL96YA;64I.PT*#0H@("`@("`@(&EF("AS=')L96XH)'!?
M9FEL96YA;64I(#X@.3DI('L-"B`@("`@("`@("!I9B`H(21T:&ES+3Y?=W)I
M=&5,;VYG2&5A9&5R*"1P7V9I;&5N86UE*2D-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D<%]T>7!E(#T]
M("(U(BD@>PT*("`@("`@("`@("1V7W-I>F4@/2!S<')I;G1F*"(E,3%S("(L
M($1E8T]C="@P*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@)'9?
M<VEZ92`]('-P<FEN=&8H(B4Q,7,@(BP@1&5C3V-T*"1P7W-I>F4I*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@("1V7W5I9"`]('-P<FEN=&8H(B4V<R`B+"!$
M96-/8W0H)'!?=6ED*2D[#0H@("`@("`@("1V7V=I9"`]('-P<FEN=&8H(B4V
M<R`B+"!$96-/8W0H)'!?9VED*2D[#0H@("`@("`@("1V7W!E<FUS(#T@<W!R
M:6YT9B@B)39S("(L($1E8T]C="@D<%]P97)M<RDI.PT*#0H@("`@("`@("1V
M7VUT:6UE(#T@<W!R:6YT9B@B)3$Q<R(L($1E8T]C="@D<%]M=&EM92DI.PT*
M#0H@("`@("`@("1V7VQI;FMN86UE(#T@)R<[#0H-"B`@("`@("`@)'9?;6%G
M:6,@/2`G)SL-"@T*("`@("`@("`D=E]V97)S:6]N(#T@)R<[#0H-"B`@("`@
M("`@)'9?=6YA;64@/2`G)SL-"@T*("`@("`@("`D=E]G;F%M92`]("<G.PT*
M#0H@("`@("`@("1V7V1E=FUA:F]R(#T@)R<[#0H-"B`@("`@("`@)'9?9&5V
M;6EN;W(@/2`G)SL-"@T*("`@("`@("`D=E]P<F5F:7@@/2`G)SL-"@T*("`@
M("`@("`D=E]B:6YA<GE?9&%T85]F:7)S="`]('!A8VLH(F$Q,#!A.&$X83AA
M,3)!,3(B+"`D<%]F:6QE;F%M92P@)'9?<&5R;7,L("1V7W5I9"P@)'9?9VED
M+"`D=E]S:7IE+"`D=E]M=&EM92D[#0H@("`@("`@("1V7V)I;F%R>5]D871A
M7VQA<W0@/2!P86-K*")A,6$Q,#!A-F$R83,R83,R83AA.&$Q-35A,3(B+"`D
M<%]T>7!E+"`D=E]L:6YK;F%M92P@)'9?;6%G:6,L("1V7W9E<G-I;VXL("1V
M7W5N86UE+"`D=E]G;F%M92P@)'9?9&5V;6%J;W(L("1V7V1E=FUI;F]R+"`D
M=E]P<F5F:7@L("<G*3L-"@T*("`@("`@("`O+R`M+2TM+2!#86QC=6QA=&4@
M=&AE(&-H96-K<W5M#0H@("`@("`@("1V7V-H96-K<W5M(#T@,#L-"B`@("`@
M("`@+R\@+BXN+BX@1FER<W0@<&%R="!O9B!T:&4@:&5A9&5R#0H@("`@("`@
M(&9O<B`H)&D],#L@)&D\,30X.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE
M8VMS=6T@*ST@;W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T85]F:7)S="PD:2PQ
M*2D[#0H@("`@("`@("\O("XN+BXN($EG;F]R92!T:&4@8VAE8VMS=6T@=F%L
M=64@86YD(')E<&QA8V4@:70@8GD@)R`G("AS<&%C92D-"B`@("`@("`@9F]R
M("@D:3TQ-#@[("1I/#$U-CL@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K
M<W5M("L](&]R9"@G("<I.PT*("`@("`@("`O+R`N+BXN+B!,87-T('!A<G0@
M;V8@=&AE(&AE861E<@T*("`@("`@("!F;W(@*"1I/3$U-BP@)&H],#L@)&D\
M-3$R.R`D:2LK+"`D:BLK*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6T@*ST@
M;W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T85]L87-T+"1J+#$I*3L-"@T*("`@
M("`@("`O+R`M+2TM+2!7<FET92!T:&4@9FER<W0@,30X(&)Y=&5S(&]F('1H
M92!H96%D97(@:6X@=&AE(&%R8VAI=F4-"B`@("`@("`@)'1H:7,M/E]W<FET
M94)L;V-K*"1V7V)I;F%R>5]D871A7V9I<G-T+"`Q-#@I.PT*#0H@("`@("`@
M("\O("TM+2TM(%=R:71E('1H92!C86QC=6QA=&5D(&-H96-K<W5M#0H@("`@
M("`@("1V7V-H96-K<W5M(#T@<W!R:6YT9B@B)39S("(L($1E8T]C="@D=E]C
M:&5C:W-U;2DI.PT*("`@("`@("`D=E]B:6YA<GE?9&%T82`]('!A8VLH(F$X
M(BP@)'9?8VAE8VMS=6TI.PT*("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH
M)'9?8FEN87)Y7V1A=&$L(#@I.PT*#0H@("`@("`@("\O("TM+2TM(%=R:71E
M('1H92!L87-T(#,U-B!B>71E<R!O9B!T:&4@:&5A9&5R(&EN('1H92!A<F-H
M:79E#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T
M85]L87-T+"`S-38I.PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?=W)I=&5,;VYG2&5A9&5R*"D-
M"B`@("!F=6YC=&EO;B!?=W)I=&5,;VYG2&5A9&5R*"1P7V9I;&5N86UE*0T*
M("`@('L-"B`@("`@("`@)'9?<VEZ92`]('-P<FEN=&8H(B4Q,7,@(BP@1&5C
M3V-T*'-T<FQE;B@D<%]F:6QE;F%M92DI*3L-"@T*("`@("`@("`D=E]T>7!E
M9FQA9R`]("=,)SL-"@T*("`@("`@("`D=E]L:6YK;F%M92`]("<G.PT*#0H@
M("`@("`@("1V7VUA9VEC(#T@)R<[#0H-"B`@("`@("`@)'9?=F5R<VEO;B`]
M("<G.PT*#0H@("`@("`@("1V7W5N86UE(#T@)R<[#0H-"B`@("`@("`@)'9?
M9VYA;64@/2`G)SL-"@T*("`@("`@("`D=E]D979M86IO<B`]("<G.PT*#0H@
M("`@("`@("1V7V1E=FUI;F]R(#T@)R<[#0H-"B`@("`@("`@)'9?<')E9FEX
M(#T@)R<[#0H-"B`@("`@("`@)'9?8FEN87)Y7V1A=&%?9FER<W0@/2!P86-K
M*")A,3`P83AA.&$X83$R03$R(BP@)RXO+B]`3&]N9TQI;FLG+"`P+"`P+"`P
M+"`D=E]S:7IE+"`P*3L-"B`@("`@("`@)'9?8FEN87)Y7V1A=&%?;&%S="`]
M('!A8VLH(F$Q83$P,&$V83)A,S)A,S)A.&$X83$U-6$Q,B(L("1V7W1Y<&5F
M;&%G+"`D=E]L:6YK;F%M92P@)'9?;6%G:6,L("1V7W9E<G-I;VXL("1V7W5N
M86UE+"`D=E]G;F%M92P@)'9?9&5V;6%J;W(L("1V7V1E=FUI;F]R+"`D=E]P
M<F5F:7@L("<G*3L-"@T*("`@("`@("`O+R`M+2TM+2!#86QC=6QA=&4@=&AE
M(&-H96-K<W5M#0H@("`@("`@("1V7V-H96-K<W5M(#T@,#L-"B`@("`@("`@
M+R\@+BXN+BX@1FER<W0@<&%R="!O9B!T:&4@:&5A9&5R#0H@("`@("`@(&9O
M<B`H)&D],#L@)&D\,30X.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE8VMS
M=6T@*ST@;W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T85]F:7)S="PD:2PQ*2D[
M#0H@("`@("`@("\O("XN+BXN($EG;F]R92!T:&4@8VAE8VMS=6T@=F%L=64@
M86YD(')E<&QA8V4@:70@8GD@)R`G("AS<&%C92D-"B`@("`@("`@9F]R("@D
M:3TQ-#@[("1I/#$U-CL@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M
M("L](&]R9"@G("<I.PT*("`@("`@("`O+R`N+BXN+B!,87-T('!A<G0@;V8@
M=&AE(&AE861E<@T*("`@("`@("!F;W(@*"1I/3$U-BP@)&H],#L@)&D\-3$R
M.R`D:2LK+"`D:BLK*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6T@*ST@;W)D
M*'-U8G-T<B@D=E]B:6YA<GE?9&%T85]L87-T+"1J+#$I*3L-"@T*("`@("`@
M("`O+R`M+2TM+2!7<FET92!T:&4@9FER<W0@,30X(&)Y=&5S(&]F('1H92!H
M96%D97(@:6X@=&AE(&%R8VAI=F4-"B`@("`@("`@)'1H:7,M/E]W<FET94)L
M;V-K*"1V7V)I;F%R>5]D871A7V9I<G-T+"`Q-#@I.PT*#0H@("`@("`@("\O
M("TM+2TM(%=R:71E('1H92!C86QC=6QA=&5D(&-H96-K<W5M#0H@("`@("`@
M("1V7V-H96-K<W5M(#T@<W!R:6YT9B@B)39S("(L($1E8T]C="@D=E]C:&5C
M:W-U;2DI.PT*("`@("`@("`D=E]B:6YA<GE?9&%T82`]('!A8VLH(F$X(BP@
M)'9?8VAE8VMS=6TI.PT*("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?
M8FEN87)Y7V1A=&$L(#@I.PT*#0H@("`@("`@("\O("TM+2TM(%=R:71E('1H
M92!L87-T(#,U-B!B>71E<R!O9B!T:&4@:&5A9&5R(&EN('1H92!A<F-H:79E
M#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T85]L
M87-T+"`S-38I.PT*#0H@("`@("`@("\O("TM+2TM(%=R:71E('1H92!F:6QE
M;F%M92!A<R!C;VYT96YT(&]F('1H92!B;&]C:PT*("`@("`@("`D:3TP.PT*
M("`@("`@("!W:&EL92`H*"1V7V)U9F9E<B`]('-U8G-T<B@D<%]F:6QE;F%M
M92P@*"@D:2LK*2HU,3(I+"`U,3(I*2`A/2`G)RD@>PT*("`@("`@("`@("`@
M)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A-3$R(BP@(B1V7V)U9F9E<B(I.PT*
M("`@("`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?<F5A9$AE861E<B@I#0H@("`@
M9G5N8W1I;VX@7W)E861(96%D97(H)'9?8FEN87)Y7V1A=&$L("8D=E]H96%D
M97(I#0H@("`@>PT*("`@("`@("!I9B`H<W1R;&5N*"1V7V)I;F%R>5]D871A
M*3T],"D@>PT*("`@("`@("`@("`@)'9?:&5A9&5R6R=F:6QE;F%M92==(#T@
M)R<[#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*#0H@
M("`@("`@(&EF("AS=')L96XH)'9?8FEN87)Y7V1A=&$I("$](#4Q,BD@>PT*
M("`@("`@("`@("`@)'9?:&5A9&5R6R=F:6QE;F%M92==(#T@)R<[#0H@("`@
M("`@("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&)L;V-K('-I>F4@.B`G
M+G-T<FQE;B@D=E]B:6YA<GE?9&%T82DI.PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM+2T@0V%L8W5L
M871E('1H92!C:&5C:W-U;0T*("`@("`@("`D=E]C:&5C:W-U;2`](#`[#0H@
M("`@("`@("\O("XN+BXN($9I<G-T('!A<G0@;V8@=&AE(&AE861E<@T*("`@
M("`@("!F;W(@*"1I/3`[("1I/#$T.#L@)&DK*RD-"B`@("`@("`@("`@("1V
M7V-H96-K<W5M*SUO<F0H<W5B<W1R*"1V7V)I;F%R>5]D871A+"1I+#$I*3L-
M"B`@("`@("`@+R\@+BXN+BX@26=N;W)E('1H92!C:&5C:W-U;2!V86QU92!A
M;F0@<F5P;&%C92!I="!B>2`G("<@*'-P86-E*0T*("`@("`@("!F;W(@*"1I
M/3$T.#L@)&D\,34V.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6T@
M*ST@;W)D*"<@)RD[#0H@("`@("`@("\O("XN+BXN($QA<W0@<&%R="!O9B!T
M:&4@:&5A9&5R#0H@("`@("`@(&9O<B`H)&D],34V.R`D:3PU,3([("1I*RLI
M#0H@("`@("`@("`@("1V7V-H96-K<W5M*SUO<F0H<W5B<W1R*"1V7V)I;F%R
M>5]D871A+"1I+#$I*3L-"@T*("`@("`@("`D=E]D871A(#T@=6YP86-K*")A
M,3`P9FEL96YA;64O83AM;V1E+V$X=6ED+V$X9VED+V$Q,G-I>F4O83$R;71I
M;64O83AC:&5C:W-U;2]A,71Y<&5F;&%G+V$Q,#!L:6YK+V$V;6%G:6,O83)V
M97)S:6]N+V$S,G5N86UE+V$S,F=N86UE+V$X9&5V;6%J;W(O83AD979M:6YO
M<B(L("1V7V)I;F%R>5]D871A*3L-"@T*("`@("`@("`O+R`M+2TM+2!%>'1R
M86-T('1H92!C:&5C:W-U;0T*("`@("`@("`D=E]H96%D97);)V-H96-K<W5M
M)UT@/2!/8W1$96,H=')I;2@D=E]D871A6R=C:&5C:W-U;2==*2D[#0H@("`@
M("`@(&EF("@D=E]H96%D97);)V-H96-K<W5M)UT@(3T@)'9?8VAE8VMS=6TI
M('L-"B`@("`@("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]("<G.PT*
M#0H@("`@("`@("`@("`O+R`M+2TM+2!,;V]K(&9O<B!L87-T(&)L;V-K("AE
M;7!T>2!B;&]C:RD-"B`@("`@("`@("`@(&EF("@H)'9?8VAE8VMS=6T@/3T@
M,C4V*2`F)B`H)'9?:&5A9&5R6R=C:&5C:W-U;2==(#T](#`I*0T*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*#0H@("`@("`@("`@("`D=&AI<RT^
M7V5R<F]R*"=);G9A;&ED(&-H96-K<W5M(&9O<B!F:6QE("(G+B1V7V1A=&%;
M)V9I;&5N86UE)UTN)R(@.B`G+B1V7V-H96-K<W5M+B<@8V%L8W5L871E9"P@
M)RXD=E]H96%D97);)V-H96-K<W5M)UTN)R!E>'!E8W1E9"<I.PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@
M+2TM+2T@17AT<F%C="!T:&4@<')O<&5R=&EE<PT*("`@("`@("`D=E]H96%D
M97);)V9I;&5N86UE)UT@/2!T<FEM*"1V7V1A=&%;)V9I;&5N86UE)UTI.PT*
M("`@("`@("`D=E]H96%D97);)VUO9&4G72`]($]C=$1E8RAT<FEM*"1V7V1A
M=&%;)VUO9&4G72DI.PT*("`@("`@("`D=E]H96%D97);)W5I9"==(#T@3V-T
M1&5C*'1R:6TH)'9?9&%T85LG=6ED)UTI*3L-"B`@("`@("`@)'9?:&5A9&5R
M6R=G:60G72`]($]C=$1E8RAT<FEM*"1V7V1A=&%;)V=I9"==*2D[#0H@("`@
M("`@("1V7VAE861E<ELG<VEZ92==(#T@3V-T1&5C*'1R:6TH)'9?9&%T85LG
M<VEZ92==*2D[#0H@("`@("`@("1V7VAE861E<ELG;71I;64G72`]($]C=$1E
M8RAT<FEM*"1V7V1A=&%;)VUT:6UE)UTI*3L-"B`@("`@("`@:68@*"@D=E]H
M96%D97);)W1Y<&5F;&%G)UT@/2`D=E]D871A6R=T>7!E9FQA9R==*2`]/2`B
M-2(I('L-"B`@("`@("`@("`D=E]H96%D97);)W-I>F4G72`](#`[#0H@("`@
M("`@('T-"B`@("`@("`@+RH@+2TM+2T@06QL('1H97-E(&9I96QD<R!A<F4@
M<F5M;W9E9"!F;W)M('1H92!H96%D97(@8F5C875S92!T:&5Y(&1O(&YO="!C
M87)R>2!I;G1E<F5S=&EN9R!I;F9O#0H@("`@("`@("1V7VAE861E<EML:6YK
M72`]('1R:6TH)'9?9&%T85ML:6YK72D[#0H@("`@("`@("1V7VAE861E<EMM
M86=I8UT@/2!T<FEM*"1V7V1A=&%;;6%G:6-=*3L-"B`@("`@("`@)'9?:&5A
M9&5R6W9E<G-I;VY=(#T@=')I;2@D=E]D871A6W9E<G-I;VY=*3L-"B`@("`@
M("`@)'9?:&5A9&5R6W5N86UE72`]('1R:6TH)'9?9&%T85MU;F%M95TI.PT*
M("`@("`@("`D=E]H96%D97);9VYA;65=(#T@=')I;2@D=E]D871A6V=N86UE
M72D[#0H@("`@("`@("1V7VAE861E<EMD979M86IO<ET@/2!T<FEM*"1V7V1A
M=&%;9&5V;6%J;W)=*3L-"B`@("`@("`@)'9?:&5A9&5R6V1E=FUI;F]R72`]
M('1R:6TH)'9?9&%T85MD979M:6YO<ETI.PT*("`@("`@("`J+PT*#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!?<F5A9$QO;F=(96%D97(H*0T*("`@(&9U;F-T:6]N(%]R96%D3&]N
M9TAE861E<B@F)'9?:&5A9&5R*0T*("`@('L-"B`@("`@("1V7V9I;&5N86UE
M(#T@)R<[#0H@("`@("`D;B`](&9L;V]R*"1V7VAE861E<ELG<VEZ92==+S4Q
M,BD[#0H@("`@("!F;W(@*"1I/3`[("1I/"1N.R`D:2LK*2![#0H@("`@("`@
M("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I.PT*("`@("`@("`D
M=E]F:6QE;F%M92`N/2`D=E]C;VYT96YT.PT*("`@("`@?0T*("`@("`@:68@
M*"@D=E]H96%D97);)W-I>F4G72`E(#4Q,BD@(3T@,"D@>PT*("`@("`@("`D
M=E]C;VYT96YT(#T@)'1H:7,M/E]R96%D0FQO8VLH*3L-"B`@("`@("`@)'9?
M9FEL96YA;64@+CT@)'9?8V]N=&5N=#L-"B`@("`@('T-"@T*("`@("`@+R\@
M+2TM+2T@4F5A9"!T:&4@;F5X="!H96%D97(-"B`@("`@("1V7V)I;F%R>5]D
M871A(#T@)'1H:7,M/E]R96%D0FQO8VLH*3L-"@T*("`@("`@:68@*"$D=&AI
M<RT^7W)E861(96%D97(H)'9?8FEN87)Y7V1A=&$L("1V7VAE861E<BDI#0H@
M("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@)'9?:&5A9&5R6R=F:6QE
M;F%M92==(#T@)'9?9FEL96YA;64[#0H-"B`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?97AT<F%C=$EN4W1R
M:6YG*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D(&5X=')A8W0@9G)O
M;2!T:&4@87)C:&EV92!O;F4@9FEL92!I9&5N=&EF:65D(&)Y("1P7V9I;&5N
M86UE+@T*("`@("H@5&AE(')E='5R;B!V86QU92!I<R!A('-T<FEN9R!W:71H
M('1H92!F:6QE(&-O;G1E;G0L(&]R($Y53$P@;VX@97)R;W(N#0H@("`@*B!`
M<&%R86T@<W1R:6YG("1P7V9I;&5N86UE("`@("!4:&4@<&%T:"!O9B!T:&4@
M9FEL92!T;R!E>'1R86-T(&EN(&$@<W1R:6YG+@T*("`@("H@0')E='5R;B`@
M("`@("`@("`@("`@("`@("`@("`@82!S=')I;F<@=VET:"!T:&4@9FEL92!C
M;VYT96YT(&]R($Y53$PN#0H@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(%]E>'1R86-T26Y3=')I;F<H)'!?9FEL96YA;64I
M#0H@("`@>PT*("`@("`@("`D=E]R97-U;'1?<W1R(#T@(B([#0H-"B`@("`@
M("`@5VAI;&4@*'-T<FQE;B@D=E]B:6YA<GE?9&%T82`]("1T:&ES+3Y?<F5A
M9$)L;V-K*"DI("$](#`I#0H@("`@("`@('L-"B`@("`@("`@("!I9B`H(21T
M:&ES+3Y?<F5A9$AE861E<B@D=E]B:6YA<GE?9&%T82P@)'9?:&5A9&5R*2D-
M"B`@("`@("`@("`@(')E='5R;B!.54Q,.PT*#0H@("`@("`@("`@:68@*"1V
M7VAE861E<ELG9FEL96YA;64G72`]/2`G)RD-"B`@("`@("`@("`@(&-O;G1I
M;G5E.PT*#0H@("`@("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@;&]N9R!F:6QE
M;F%M90T*("`@("`@("`@(&EF("@D=E]H96%D97);)W1Y<&5F;&%G)UT@/3T@
M)TPG*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<F5A9$QO;F=(96%D
M97(H)'9?:&5A9&5R*2D-"B`@("`@("`@("`@("`@<F5T=7)N($Y53$P[#0H@
M("`@("`@("`@?0T*#0H@("`@("`@("`@:68@*"1V7VAE861E<ELG9FEL96YA
M;64G72`]/2`D<%]F:6QE;F%M92D@>PT*("`@("`@("`@("`@("!I9B`H)'9?
M:&5A9&5R6R=T>7!E9FQA9R==(#T]("(U(BD@>PT*("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&5X=')A8W0@:6X@<W1R:6YG
M(&$@9&ER96-T;W)Y(&5N=')Y('LG+B1V7VAE861E<ELG9FEL96YA;64G72XG
M?2<I.PT*("`@("`@("`@("`@("`@("`@<F5T=7)N($Y53$P[#0H@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`D;B`](&9L;V]R
M*"1V7VAE861E<ELG<VEZ92==+S4Q,BD[#0H@("`@("`@("`@("`@("`@("!F
M;W(@*"1I/3`[("1I/"1N.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@)'9?<F5S=6QT7W-T<B`N/2`D=&AI<RT^7W)E861";&]C:R@I.PT*("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@:68@*"@D=E]H
M96%D97);)W-I>F4G72`E(#4Q,BD@(3T@,"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I.PT*("`@
M("`@("`@("`@("`@("`@("`@("1V7W)E<W5L=%]S='(@+CT@<W5B<W1R*"1V
M7V-O;G1E;G0L(#`L("@D=E]H96%D97);)W-I>F4G72`E(#4Q,BDI.PT*("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@<F5T=7)N("1V
M7W)E<W5L=%]S='([#0H@("`@("`@("`@("`@('T-"B`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`D=&AI<RT^7VIU;7!";&]C:RAC96EL*"@D
M=E]H96%D97);)W-I>F4G72\U,3(I*2D[#0H@("`@("`@("`@?0T*("`@("`@
M("!]#0H-"B`@("`@("`@<F5T=7)N($Y53$P[#0H@("`@?0T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[(%]E>'1R86-T3&ES="@I#0H@("`@9G5N8W1I;VX@
M7V5X=')A8W1,:7-T*"1P7W!A=&@L("8D<%]L:7-T7V1E=&%I;"P@)'!?;6]D
M92P@)'!?9FEL95]L:7-T+"`D<%]R96UO=F5?<&%T:"D-"B`@("![#0H@("`@
M)'9?<F5S=6QT/71R=64[#0H@("`@)'9?;F(@/2`P.PT*("`@("1V7V5X=')A
M8W1?86QL(#T@=')U93L-"B`@("`D=E]L:7-T:6YG(#T@9F%L<V4[#0H-"B`@
M("`D<%]P871H(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0871H*"1P7W!A=&@L
M(&9A;'-E*3L-"B`@("!I9B`H)'!?<&%T:"`]/2`G)R!\?"`H<W5B<W1R*"1P
M7W!A=&@L(#`L(#$I("$]("<O)R`F)B!S=6)S='(H)'!?<&%T:"P@,"P@,RD@
M(3T@(BXN+R(@)B8@(7-T<G!O<R@D<%]P871H+"`G.B<I*2D@>PT*("`@("`@
M)'!?<&%T:"`]("(N+R(N)'!?<&%T:#L-"B`@("!]#0H@("`@)'!?<F5M;W9E
M7W!A=&@@/2`D=&AI<RT^7W1R86YS;&%T95=I;E!A=&@H)'!?<F5M;W9E7W!A
M=&@I.PT*#0H@("`@+R\@+2TM+2T@3&]O:R!F;W(@<&%T:"!T;R!R96UO=F4@
M9F]R;6%T("AS:&]U;&0@96YD(&)Y("\I#0H@("`@:68@*"@D<%]R96UO=F5?
M<&%T:"`A/2`G)RD@)B8@*'-U8G-T<B@D<%]R96UO=F5?<&%T:"P@+3$I("$]
M("<O)RDI#0H@("`@("`D<%]R96UO=F5?<&%T:"`N/2`G+R<[#0H@("`@)'!?
M<F5M;W9E7W!A=&A?<VEZ92`]('-T<FQE;B@D<%]R96UO=F5?<&%T:"D[#0H-
M"B`@("!S=VET8V@@*"1P7VUO9&4I('L-"B`@("`@(&-A<V4@(F-O;7!L971E
M(B`Z#0H@("`@("`@("1V7V5X=')A8W1?86QL(#T@5%)513L-"B`@("`@("`@
M)'9?;&ES=&EN9R`]($9!3%-%.PT*("`@("`@8G)E86L[#0H@("`@("!C87-E
M(")P87)T:6%L(B`Z#0H@("`@("`@("`@)'9?97AT<F%C=%]A;&P@/2!&04Q3
M13L-"B`@("`@("`@("`D=E]L:7-T:6YG(#T@1D%,4T4[#0H@("`@("!B<F5A
M:SL-"B`@("`@(&-A<V4@(FQI<W0B(#H-"B`@("`@("`@("`D=E]E>'1R86-T
M7V%L;"`]($9!3%-%.PT*("`@("`@("`@("1V7VQI<W1I;F<@/2!44E5%.PT*
M("`@("`@8G)E86L[#0H@("`@("!D969A=6QT(#H-"B`@("`@("`@)'1H:7,M
M/E]E<G)O<B@G26YV86QI9"!E>'1R86-T(&UO9&4@*"<N)'!?;6]D92XG*2<I
M.PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@8VQE87)S
M=&%T8V%C:&4H*3L-"@T*("`@(%=H:6QE("AS=')L96XH)'9?8FEN87)Y7V1A
M=&$@/2`D=&AI<RT^7W)E861";&]C:R@I*2`A/2`P*0T*("`@('L-"B`@("`@
M("1V7V5X=')A8W1?9FEL92`]($9!3%-%.PT*("`@("`@)'9?97AT<F%C=&EO
M;E]S=&]P<&5D(#T@,#L-"@T*("`@("`@:68@*"$D=&AI<RT^7W)E861(96%D
M97(H)'9?8FEN87)Y7V1A=&$L("1V7VAE861E<BDI#0H@("`@("`@(')E='5R
M;B!F86QS93L-"@T*("`@("`@:68@*"1V7VAE861E<ELG9FEL96YA;64G72`]
M/2`G)RD-"B`@("`@("`@8V]N=&EN=64[#0H-"B`@("`@("\O("TM+2TM($QO
M;VL@9F]R(&QO;F<@9FEL96YA;64-"B`@("`@(&EF("@D=E]H96%D97);)W1Y
M<&5F;&%G)UT@/3T@)TPG*2![#0H@("`@("`@(&EF("@A)'1H:7,M/E]R96%D
M3&]N9TAE861E<B@D=E]H96%D97(I*0T*("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@('T-"@T*("`@("`@:68@*"@A)'9?97AT<F%C=%]A;&PI("8F
M("AI<U]A<G)A>2@D<%]F:6QE7VQI<W0I*2D@>PT*("`@("`@("`O+R`M+2TM
M+2!">2!D969A=6QT(&YO('5N>FEP(&EF('1H92!F:6QE(&ES(&YO="!F;W5N
M9`T*("`@("`@("`D=E]E>'1R86-T7V9I;&4@/2!F86QS93L-"@T*("`@("`@
M("!F;W(@*"1I/3`[("1I/'-I>F5O9B@D<%]F:6QE7VQI<W0I.R`D:2LK*2![
M#0H@("`@("`@("`@+R\@+2TM+2T@3&]O:R!I9B!I="!I<R!A(&1I<F5C=&]R
M>0T*("`@("`@("`@(&EF("AS=6)S='(H)'!?9FEL95]L:7-T6R1I72P@+3$I
M(#T]("<O)RD@>PT*("`@("`@("`@("`@+R\@+2TM+2T@3&]O:R!I9B!T:&4@
M9&ER96-T;W)Y(&ES(&EN('1H92!F:6QE;F%M92!P871H#0H@("`@("`@("`@
M("!I9B`H*'-T<FQE;B@D=E]H96%D97);)V9I;&5N86UE)UTI(#X@<W1R;&5N
M*"1P7V9I;&5?;&ES=%LD:5TI*2`F)B`H<W5B<W1R*"1V7VAE861E<ELG9FEL
M96YA;64G72P@,"P@<W1R;&5N*"1P7V9I;&5?;&ES=%LD:5TI*2`]/2`D<%]F
M:6QE7VQI<W1;)&E=*2D@>PT*("`@("`@("`@("`@("`D=E]E>'1R86-T7V9I
M;&4@/2!44E5%.PT*("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("!]#0H-"B`@("`@("`@("`O+R`M+2TM+2!)="!I<R!A
M(&9I;&4L('-O(&-O;7!A<F4@=&AE(&9I;&4@;F%M97,-"B`@("`@("`@("!E
M;'-E:68@*"1P7V9I;&5?;&ES=%LD:5T@/3T@)'9?:&5A9&5R6R=F:6QE;F%M
M92==*2![#0H@("`@("`@("`@("`D=E]E>'1R86-T7V9I;&4@/2!44E5%.PT*
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("!](&5L<V4@>PT*("`@("`@("`D=E]E>'1R86-T7V9I;&4@/2!44E5%
M.PT*("`@("`@?0T*#0H@("`@("`O+R`M+2TM+2!,;V]K(&EF('1H:7,@9FEL
M92!N965D('1O(&)E(&5X=')A8W1E9`T*("`@("`@:68@*"@D=E]E>'1R86-T
M7V9I;&4I("8F("@A)'9?;&ES=&EN9RDI#0H@("`@("![#0H@("`@("`@(&EF
M("@H)'!?<F5M;W9E7W!A=&@@(3T@)R<I#0H@("`@("`@("`@("`F)B`H<W5B
M<W1R*"1V7VAE861E<ELG9FEL96YA;64G72P@,"P@)'!?<F5M;W9E7W!A=&A?
M<VEZ92D@/3T@)'!?<F5M;W9E7W!A=&@I*0T*("`@("`@("`@("1V7VAE861E
M<ELG9FEL96YA;64G72`]('-U8G-T<B@D=E]H96%D97);)V9I;&5N86UE)UTL
M("1P7W)E;6]V95]P871H7W-I>F4I.PT*("`@("`@("!I9B`H*"1P7W!A=&@@
M(3T@)RXO)RD@)B8@*"1P7W!A=&@@(3T@)R\G*2D@>PT*("`@("`@("`@('=H
M:6QE("AS=6)S='(H)'!?<&%T:"P@+3$I(#T]("<O)RD-"B`@("`@("`@("`@
M("1P7W!A=&@@/2!S=6)S='(H)'!?<&%T:"P@,"P@<W1R;&5N*"1P7W!A=&@I
M+3$I.PT*#0H@("`@("`@("`@:68@*'-U8G-T<B@D=E]H96%D97);)V9I;&5N
M86UE)UTL(#`L(#$I(#T]("<O)RD-"B`@("`@("`@("`@("`@)'9?:&5A9&5R
M6R=F:6QE;F%M92==(#T@)'!?<&%T:"XD=E]H96%D97);)V9I;&5N86UE)UT[
M#0H@("`@("`@("`@96QS90T*("`@("`@("`@("`@)'9?:&5A9&5R6R=F:6QE
M;F%M92==(#T@)'!?<&%T:"XG+R<N)'9?:&5A9&5R6R=F:6QE;F%M92==.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=E]H96%D97);
M)V9I;&5N86UE)UTI*2![#0H@("`@("`@("`@:68@*"A`:7-?9&ER*"1V7VAE
M861E<ELG9FEL96YA;64G72DI("8F("@D=E]H96%D97);)W1Y<&5F;&%G)UT@
M/3T@)R<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=&:6QE("<N
M)'9?:&5A9&5R6R=F:6QE;F%M92==+B<@86QR96%D>2!E>&ES=',@87,@82!D
M:7)E8W1O<GDG*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("!]#0H@("`@("`@("`@:68@*"AI<U]F:6QE*"1V7VAE861E<ELG9FEL
M96YA;64G72DI("8F("@D=E]H96%D97);)W1Y<&5F;&%G)UT@/3T@(C4B*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G1&ER96-T;W)Y("<N)'9?
M:&5A9&5R6R=F:6QE;F%M92==+B<@86QR96%D>2!E>&ES=',@87,@82!F:6QE
M)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@?0T*
M("`@("`@("`@(&EF("@A:7-?=W)I=&5A8FQE*"1V7VAE861E<ELG9FEL96YA
M;64G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T9I;&4@)RXD
M=E]H96%D97);)V9I;&5N86UE)UTN)R!A;')E861Y(&5X:7-T<R!A;F0@:7,@
M=W)I=&4@<')O=&5C=&5D)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@?0T*("`@("`@("`@(&EF("AF:6QE;71I;64H)'9?:&5A
M9&5R6R=F:6QE;F%M92==*2`^("1V7VAE861E<ELG;71I;64G72D@>PT*("`@
M("`@("`@("`@+R\@5&\@8F4@8V]M<&QE=&5D(#H@06X@97)R;W(@;W(@<VEL
M96YT(&YO(')E<&QA8V4@/PT*("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@
M("`@("`@("\O("TM+2TM($-H96-K('1H92!D:7)E8W1O<GD@879A:6QA8FEL
M:71Y(&%N9"!C<F5A=&4@:70@:68@;F5C97-S87)Y#0H@("`@("`@(&5L<V5I
M9B`H*"1V7W)E<W5L="`]("1T:&ES+3Y?9&ER0VAE8VLH*"1V7VAE861E<ELG
M='EP969L86<G72`]/2`B-2(_)'9?:&5A9&5R6R=F:6QE;F%M92==.F1I<FYA
M;64H)'9?:&5A9&5R6R=F:6QE;F%M92==*2DI*2`A/2`Q*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B;&4@=&\@8W)E871E('!A=&@@9F]R
M("<N)'9?:&5A9&5R6R=F:6QE;F%M92==*3L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D=E]E>'1R86-T
M7V9I;&4I('L-"B`@("`@("`@("!I9B`H)'9?:&5A9&5R6R=T>7!E9FQA9R==
M(#T]("(U(BD@>PT*("`@("`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)'9?
M:&5A9&5R6R=F:6QE;F%M92==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M0&UK9&ER*"1V7VAE861E<ELG9FEL96YA;64G72P@,#<W-RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&-R96%T
M92!D:7)E8W1O<GD@>R<N)'9?:&5A9&5R6R=F:6QE;F%M92==+B=])RD[#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@:68@*"@D=E]D97-T7V9I;&4@/2!`9F]P96XH)'9?:&5A
M9&5R6R=F:6QE;F%M92==+"`B=V(B*2D@/3T@,"D@>PT*("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<B@G17)R;W(@=VAI;&4@;W!E;FEN9R![)RXD
M=E]H96%D97);)V9I;&5N86UE)UTN)WT@:6X@=W)I=&4@8FEN87)Y(&UO9&4G
M*3L-"B`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("1N(#T@9FQO;W(H
M)'9?:&5A9&5R6R=S:7IE)UTO-3$R*3L-"B`@("`@("`@("`@("`@("`@(&9O
M<B`H)&D],#L@)&D\)&X[("1I*RLI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`D=E]C;VYT96YT(#T@)'1H:7,M/E]R96%D0FQO8VLH*3L-"B`@("`@("`@
M("`@("`@("`@("`@("!F=W)I=&4H)'9?9&5S=%]F:6QE+"`D=E]C;VYT96YT
M+"`U,3(I.PT*("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"@D=E]H96%D97);)W-I>F4G72`E(#4Q,BD@(3T@,"D@>PT*("`@("`@("`@
M("`@("`D=E]C;VYT96YT(#T@)'1H:7,M/E]R96%D0FQO8VLH*3L-"B`@("`@
M("`@("`@("`@9G=R:71E*"1V7V1E<W1?9FEL92P@)'9?8V]N=&5N="P@*"1V
M7VAE861E<ELG<VEZ92==("4@-3$R*2D[#0H@("`@("`@("`@("!]#0H-"B`@
M("`@("`@("`@($!F8VQO<V4H)'9?9&5S=%]F:6QE*3L-"@T*("`@("`@("`@
M("`@+R\@+2TM+2T@0VAA;F=E('1H92!F:6QE(&UO9&4L(&UT:6UE#0H@("`@
M("`@("`@("!`=&]U8V@H)'9?:&5A9&5R6R=F:6QE;F%M92==+"`D=E]H96%D
M97);)VUT:6UE)UTI.PT*("`@("`@("`@("`@+R\@5&\@8F4@8V]M<&QE=&5D
M#0H@("`@("`@("`@("`O+V-H;6]D*"1V7VAE861E<EMF:6QE;F%M95TL($1E
M8T]C="@D=E]H96%D97);;6]D95TI*3L-"B`@("`@("`@("!]#0H-"B`@("`@
M("`@("`O+R`M+2TM+2!#:&5C:R!T:&4@9FEL92!S:7IE#0H@("`@("`@("`@
M8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@("`@("!I9B`H9FEL97-I>F4H)'9?
M:&5A9&5R6R=F:6QE;F%M92==*2`A/2`D=E]H96%D97);)W-I>F4G72D@>PT*
M("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=%>'1R86-T960@9FEL92`G
M+B1V7VAE861E<ELG9FEL96YA;64G72XG(&1O97,@;F]T(&AA=F4@=&AE(&-O
M<G)E8W0@9FEL92!S:7IE(%PG)RYF:6QE<VEZ92@D=E]F:6QE;F%M92DN)UPG
M("@G+B1V7VAE861E<ELG<VEZ92==+B<@97AP96-T960I+B!!<F-H:79E(&UA
M>2!B92!C;W)R=7!T960N)RD[#0H@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("!]#0H@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("1T:&ES+3Y?:G5M<$)L;V-K*&-E:6PH*"1V7VAE861E
M<ELG<VEZ92==+S4Q,BDI*3L-"B`@("`@("`@?0T*("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`D=&AI<RT^7VIU;7!";&]C:RAC96EL*"@D=E]H96%D97);
M)W-I>F4G72\U,3(I*2D[#0H@("`@("!]#0H-"B`@("`@("\J(%1"0R`Z(%-E
M96US('1O(&)E('5N=7-E9"`N+BX-"B`@("`@(&EF("@D=&AI<RT^7V-O;7!R
M97-S*0T*("`@("`@("`D=E]E;F1?;V9?9FEL92`]($!G>F5O9B@D=&AI<RT^
M7V9I;&4I.PT*("`@("`@96QS90T*("`@("`@("`D=E]E;F1?;V9?9FEL92`]
M($!F96]F*"1T:&ES+3Y?9FEL92D[#0H@("`@("`@("HO#0H-"B`@("`@(&EF
M("@D=E]L:7-T:6YG('Q\("1V7V5X=')A8W1?9FEL92!\?"`D=E]E>'1R86-T
M:6]N7W-T;W!P960I('L-"B`@("`@("`@+R\@+2TM+2T@3&]G(&5X=')A8W1E
M9"!F:6QE<PT*("`@("`@("!I9B`H*"1V7V9I;&5?9&ER(#T@9&ER;F%M92@D
M=E]H96%D97);)V9I;&5N86UE)UTI*2`]/2`D=E]H96%D97);)V9I;&5N86UE
M)UTI#0H@("`@("`@("`@)'9?9FEL95]D:7(@/2`G)SL-"B`@("`@("`@:68@
M*"AS=6)S='(H)'9?:&5A9&5R6R=F:6QE;F%M92==+"`P+"`Q*2`]/2`G+R<I
M("8F("@D=E]F:6QE7V1I<B`]/2`G)RDI#0H@("`@("`@("`@)'9?9FEL95]D
M:7(@/2`G+R<[#0H-"B`@("`@("`@)'!?;&ES=%]D971A:6Q;)'9?;F(K*UT@
M/2`D=E]H96%D97([#0H@("`@("!]#0H@("`@?0T*#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?;W!E
M;D%P<&5N9"@I#0H@("`@9G5N8W1I;VX@7V]P96Y!<'!E;F0H*0T*("`@('L-
M"B`@("`@("`@:68@*&9I;&5S:7IE*"1T:&ES+3Y?=&%R;F%M92D@/3T@,"D-
M"B`@("`@("`@("!R971U<FX@)'1H:7,M/E]O<&5N5W)I=&4H*3L-"B`@("`@
M("`@("`-"B`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W,I('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"@T*("`@("`@("`@("`@:68@*"%`
M<F5N86UE*"1T:&ES+3Y?=&%R;F%M92P@)'1H:7,M/E]T87)N86UE+B(N=&UP
M(BDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=%<G)O<B!W
M:&EL92!R96YA;6EN9R!<)R<N)'1H:7,M/E]T87)N86UE+B=<)R!T;R!T96UP
M;W)A<GD@9FEL92!<)R<N)'1H:7,M/E]T87)N86UE+B<N=&UP7"<G*3L-"B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H-
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V=Z
M)RD-"B`@("`@("`@("`@("`@("`D=E]T96UP7W1A<B`]($!G>F]P96XH)'1H
M:7,M/E]T87)N86UE+B(N=&UP(BP@(G)B(BD[#0H@("`@("`@("`@("!E;'-E
M:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@
M("`@("`@("`D=E]T96UP7W1A<B`]($!B>F]P96XH)'1H:7,M/E]T87)N86UE
M+B(N=&UP(BP@(G)B(BD[#0H@("`@("`@("`@("`@("`@#0H@("`@("`@("`@
M("!I9B`H)'9?=&5M<%]T87(@/3T@,"D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&9I;&4@7"<G+B1T:&ES+3Y?
M=&%R;F%M92XG+G1M<%PG(&EN(&)I;F%R>2!R96%D(&UO9&4G*3L-"B`@("`@
M("`@("`@("`@("!`<F5N86UE*"1T:&ES+3Y?=&%R;F%M92XB+G1M<"(L("1T
M:&ES+3Y?=&%R;F%M92D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?
M;W!E;E=R:71E*"DI('L-"B`@("`@("`@("`@("`@("!`<F5N86UE*"1T:&ES
M+3Y?=&%R;F%M92XB+G1M<"(L("1T:&ES+3Y?=&%R;F%M92D[#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*#0H@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=G>B<I('L-
M"B`@("`@("`@("`@("`@("`D=E]B=69F97(@/2!`9WIR96%D*"1V7W1E;7!?
M=&%R+"`U,3(I.PT*#0H@("`@("`@("`@("`@("`@+R\@+2TM+2T@4F5A9"!T
M:&4@9F]L;&]W:6YG(&)L;V-K<R!B=70@;F]T('1H92!L87-T(&]N90T*("`@
M("`@("`@("`@("`@(&EF("@A0&=Z96]F*"1V7W1E;7!?=&%R*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!D;WL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1V7V)I;F%R>5]D871A(#T@<&%C:R@B834Q,B(L("1V7V)U9F9E<BD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?
M8FEN87)Y7V1A=&$I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9?8G5F
M9F5R(#T@0&=Z<F5A9"@D=E]T96UP7W1A<BP@-3$R*3L-"@T*("`@("`@("`@
M("`@("`@("`@("!]('=H:6QE("@A0&=Z96]F*"1V7W1E;7!?=&%R*2D[#0H@
M("`@("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`@("`@0&=Z8VQO<V4H
M)'9?=&5M<%]T87(I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@96QS
M96EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V)Z,B<I('L-"B`@("`@
M("`@("`@("`@("`D=E]B=69F97)E9%]L:6YE<R`@(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("`@("`D=E]B=69F97)E9%]L:6YE<UM=(#T@0&)Z<F5A9"@D
M=E]T96UP7W1A<BP@-3$R*3L-"@T*("`@("`@("`@("`@("`@("\O("TM+2TM
M(%)E860@=&AE(&9O;&QO=VEN9R!B;&]C:W,@8G5T(&YO="!T:&4@;&%S="!O
M;F4-"B`@("`@("`@("`@("`@("!W:&EL92`H<W1R;&5N*"1V7V)U9F9E<F5D
M7VQI;F5S6UT@/2!`8GIR96%D*"1V7W1E;7!?=&%R+"`U,3(I*2`^(#`I('L-
M"B`@("`@("`@("`@("`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A
M-3$R(BP@87)R87E?<VAI9G0H)'9?8G5F9F5R961?;&EN97,I*3L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D
M871A*3L-"B`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("!`
M8GIC;&]S92@D=E]T96UP7W1A<BD[#0H@("`@("`@("`@("!]#0H-"B`@("`@
M("`@("`@(&EF("@A0'5N;&EN:R@D=&AI<RT^7W1A<FYA;64N(BYT;7`B*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T5R<F]R('=H:6QE
M(&1E;&5T:6YG('1E;7!O<F%R>2!F:6QE(%PG)RXD=&AI<RT^7W1A<FYA;64N
M)RYT;7!<)R<I.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`O+R`M+2TM+2!&;W(@;F]T(&-O;7!R97-S960@=&%R
M+"!J=7-T(&%D9"!F:6QE<R!B969O<F4@=&AE(&QA<W0@-3$R(&)Y=&5S(&)L
M;V-K#0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;E)E8617<FET92@I
M*0T*("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("`@("`@
M("!C;&5A<G-T871C86-H92@I.PT*("`@("`@("`@("`@)'9?<VEZ92`](&9I
M;&5S:7IE*"1T:&ES+3Y?=&%R;F%M92D[#0H@("`@("`@("`@("!F<V5E:R@D
M=&AI<RT^7V9I;&4L("1V7W-I>F4M-3$R*3L-"B`@("`@("`@?0T*#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!?87!P96YD*"D-"B`@("!F=6YC=&EO;B!?87!P96YD*"1P7V9I;&5L
M:7-T+"`D<%]A9&1?9&ER/2<G+"`D<%]R96UO=F5?9&ER/2<G*0T*("`@('L-
M"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y!<'!E;F0H*2D-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@(`T*("`@("`@("!I9B`H
M)'1H:7,M/E]A9&1,:7-T*"1P7V9I;&5L:7-T+"`D<%]A9&1?9&ER+"`D<%]R
M96UO=F5?9&ER*2D-"B`@("`@("`@("`@)'1H:7,M/E]W<FET949O;W1E<B@I
M.PT*#0H@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"@T*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V1I
M<D-H96-K*"D-"@T*("`@("\J*@T*("`@("`J($-H96-K(&EF(&$@9&ER96-T
M;W)Y(&5X:7-T<R!A;F0@8W)E871E(&ET("AI;F-L=61I;F<@<&%R96YT#0H@
M("`@("H@9&ER<RD@:68@;F]T+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<%]D:7(@9&ER96-T;W)Y('1O(&-H96-K#0H@("`@("H-"B`@("`@
M*B!`<F5T=7)N(&)O;VP@5%)512!I9B!T:&4@9&ER96-T;W)Y(&5X:7-T<R!O
M<B!W87,@8W)E871E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]D:7)#:&5C
M:R@D<%]D:7(I#0H@("`@>PT*("`@("`@("!I9B`H*$!I<U]D:7(H)'!?9&ER
M*2D@?'P@*"1P7V1I<B`]/2`G)RDI#0H@("`@("`@("`@("!R971U<FX@=')U
M93L-"@T*("`@("`@("`D<%]P87)E;G1?9&ER(#T@9&ER;F%M92@D<%]D:7(I
M.PT*#0H@("`@("`@(&EF("@H)'!?<&%R96YT7V1I<B`A/2`D<%]D:7(I("8F
M#0H@("`@("`@("`@("`H)'!?<&%R96YT7V1I<B`A/2`G)RD@)B8-"B`@("`@
M("`@("`@("@A)'1H:7,M/E]D:7)#:&5C:R@D<%]P87)E;G1?9&ER*2DI#0H@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("`@(&EF("@A0&UK
M9&ER*"1P7V1I<BP@,#<W-RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R
M;W(H(E5N86)L92!T;R!C<F5A=&4@9&ER96-T;W)Y("<D<%]D:7(G(BD[#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!?<&%T:%)E9'5C=&EO;B@I#0H-"B`@("`O*BH-"B`@("`@*B!#;VUP
M<F5S<R!P871H(&)Y(&-H86YG:6YG(&9O<B!E>&%M<&QE("(O9&ER+V9O;R\N
M+B]B87(B('1O("(O9&ER+V)A<B(L(&%N9`T*("`@("`J(')E;6]V92!D;W5B
M;&4@<VQA<VAE<RX-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)'!?
M9&ER('!A=&@@=&\@<F5D=6-E#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!R961U8V5D('!A=&@-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W!A=&A2961U
M8W1I;VXH)'!?9&ER*0T*("`@('L-"B`@("`@("`@)'9?<F5S=6QT(#T@)R<[
M#0H-"B`@("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@;F]T(&5M<'1Y('!A=&@-
M"B`@("`@("`@:68@*"1P7V1I<B`A/2`G)RD@>PT*("`@("`@("`@("`@+R\@
M+2TM+2T@17AP;&]D92!P871H(&)Y(&1I<F5C=&]R>2!N86UE<PT*("`@("`@
M("`@("`@)'9?;&ES="`](&5X<&QO9&4H)R\G+"`D<%]D:7(I.PT*#0H@("`@
M("`@("`@("`O+R`M+2TM+2!3='5D>2!D:7)E8W1O<FEE<R!F<F]M(&QA<W0@
M=&\@9FER<W0-"B`@("`@("`@("`@(&9O<B`H)&D]<VEZ96]F*"1V7VQI<W0I
M+3$[("1I/CTP.R`D:2TM*2![#0H@("`@("`@("`@("`@("`@+R\@+2TM+2T@
M3&]O:R!F;W(@8W5R<F5N="!P871H#0H@("`@("`@("`@("`@("`@:68@*"1V
M7VQI<W1;)&E=(#T]("(N(BD@>PT*("`@("`@("`@("`@("`@("`@("`O+R`M
M+2TM+2!)9VYO<F4@=&AI<R!D:7)E8W1O<GD-"B`@("`@("`@("`@("`@("`@
M("`@+R\@4VAO=6QD(&)E('1H92!F:7)S="`D:3TP+"!B=70@;F\@8VAE8VL@
M:7,@9&]N90T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!E
M;'-E(&EF("@D=E]L:7-T6R1I72`]/2`B+BXB*2![#0H@("`@("`@("`@("`@
M("`@("`@("\O("TM+2TM($EG;F]R92!I="!A;F0@:6=N;W)E('1H92`D:2TQ
M#0H@("`@("`@("`@("`@("`@("`@("1I+2T[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&5L<V4@:68@*"@D=E]L:7-T6R1I72`]/2`G
M)RD@)B8@*"1I(3TH<VEZ96]F*"1V7VQI<W0I+3$I*2`F)B`H)&DA/3`I*2![
M#0H@("`@("`@("`@("`@("`@("`@("\O("TM+2TM($EG;F]R92!O;FQY('1H
M92!D;W5B;&4@)R\O)R!I;B!P871H+`T*("`@("`@("`@("`@("`@("`@("`O
M+R!B=70@;F]T('1H92!F:7)S="!A;F0@;&%S="`O#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'9?<F5S=6QT(#T@
M)'9?;&ES=%LD:5TN*"1I(3TH<VEZ96]F*"1V7VQI<W0I+3$I/R<O)RXD=E]R
M97-U;'0Z)R<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`D=E]R97-U;'0@/2!S=')T<B@D=E]R97-U
M;'0L("=<7"<L("<O)RD[#0H@("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7W1R86YS;&%T95=I
M;E!A=&@H*0T*("`@(&9U;F-T:6]N(%]T<F%N<VQA=&57:6Y0871H*"1P7W!A
M=&@L("1P7W)E;6]V95]D:7-K7VQE='1E<CUT<G5E*0T*("`@('L-"B`@("`@
M(&EF("A/4U]724Y$3U=3*2![#0H@("`@("`@("`@+R\@+2TM+2T@3&]O:R!F
M;W(@<&]T96YT:6%L(&1I<VL@;&5T=&5R#0H@("`@("`@("`@:68@*"@D<%]R
M96UO=F5?9&ES:U]L971T97(I("8F("@H)'9?<&]S:71I;VX@/2!S=')P;W,H
M)'!?<&%T:"P@)SHG*2D@(3T@9F%L<V4I*2![#0H@("`@("`@("`@("`@("1P
M7W!A=&@@/2!S=6)S='(H)'!?<&%T:"P@)'9?<&]S:71I;VXK,2D[#0H@("`@
M("`@("`@?0T*("`@("`@("`@("\O("TM+2TM($-H86YG92!P;W1E;G1I86P@
M=VEN9&]W<R!D:7)E8W1O<GD@<V5P87)A=&]R#0H@("`@("`@("`@:68@*"AS
M=')P;W,H)'!?<&%T:"P@)UQ<)RD@/B`P*2!\?"`H<W5B<W1R*"1P7W!A=&@L
M(#`L,2D@/3T@)UQ<)RDI('L-"B`@("`@("`@("`@("`@)'!?<&%T:"`]('-T
M<G1R*"1P7W!A=&@L("=<7"<L("<O)RD[#0H@("`@("`@("`@?0T*("`@("`@
M?0T*("`@("`@<F5T=7)N("1P7W!A=&@[#0H@("`@?0T*("`@("\O('U]?0T*
M#0I]#0H_/@T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O075T:"\`````````````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#$V,C0R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P
M-``P,3<P,#0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%U=&@O4T%3
M3"]#<F%M340U+G!H<```````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`V-S`V`#$P-#$W,S8S,#`T`#`R,#<Q,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P
M,#,@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@#0HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@4F5D:7-T<FEB
M=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET
M:"!O<B!W:71H;W5T("`@('P@#0HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E
M<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N
M<R`@("!\(`T*+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\(&\@4F5D:7-T
M<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V
M92!C;W!Y<FEG:'0@("`@("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T
M(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@
M("`@("`@?"`-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O
M<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P@#0HO
M+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\(`T*+R\@?"`@(&1O8W5M
M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H
M('1H92!D:7-T<FEB=71I;VXN?"`-"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE
M(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T
M92`@("`@('P@#0HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@
M<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\(`T*
M+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@#0HO+R!\(%1(25,@4T]&5%=!4D4@25,@
M4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"
M551/4E,@("!\(`T*+R\@?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)
M35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?"`-
M"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P@#0HO+R!\($$@4$%2
M5$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!3
M2$%,3"!42$4@0T]065))1TA4("!\(`T*+R\@?"!/5TY%4B!/4B!#3TY44DE"
M551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#
M241%3E1!3"P@?"`-"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY3
M15%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P@
M#0HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@
M1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!\(`T*+R\@?"!$051!
M+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T56
M15(@0T%54T5$($%.1"!/3B!!3ED@?"`-"B\O('P@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@
M3U(@5$]25"`@('P@#0HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/
M5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\
M(`T*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@
M5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@?"`-"B\O('P@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK(`T*+R\@?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I
M8VAA<F1`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R`-"B\O
M("1)9#H@0W)A;4U$-2YP:'`L=B`Q+C0@,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M
M:B!%>'`@)`T*#0HO*BH-"BH@26UP;&UE;G1A=&EO;B!O9B!#4D%-+4U$-2!3
M05-,(&UE8VAA;FES;0T**@T**B!`875T:&]R("!2:6-H87)D($AE>65S(#QR
M:6-H87)D0'!H<"YN970^#0HJ($!A8V-E<W,@('!U8FQI8PT**B!`=F5R<VEO
M;B`Q+C`-"BH@0'!A8VMA9V4@075T:%]305-,#0HJ+PT*#0IR97%U:7)E7V]N
M8V4H)T%U=&@O4T%33"]#;VUM;VXN<&AP)RD[#0H-"F-L87-S($%U=&A?4T%3
M3%]#<F%M340U(&5X=&5N9',@075T:%]305-,7T-O;6UO;@T*>PT*("`@("\J
M*@T*("`@("H@26UP;&5M96YT<R!T:&4@0U)!32U-1#4@4T%33"!M96-H86YI
M<VT-"B`@("`J(%1H:7,@1$]%4R!.3U0@8F%S938T(&5N8V]D92!T:&4@<F5T
M=7)N('9A;'5E+`T*("`@("H@>6]U('=I;&P@;F5E9"!T;R!D;R!T:&%T('EO
M=7)S96QF+@T*("`@("H-"B`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@
M("!5<V5R;F%M90T*("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<R`@("`@(%!A
M<W-W;W)D#0H@("`@*B!`<&%R86T@<W1R:6YG("1C:&%L;&5N9V4@5&AE(&-H
M86QL96YG92!S=7!P;&EE9"!B>2!T:&4@<V5R=F5R+@T*("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H:7,@<VAO=6QD(&)E(&%L<F5A9'D@8F%S
M938T7V1E8V]D960N#0H@("`@*@T*("`@("H@0')E='5R;B!S=')I;F<@5&AE
M('-T<FEN9R!T;R!P87-S(&)A8VL@=&\@=&AE('-E<G9E<BP@;V8@=&AE(&9O
M<FT-"B`@("`J("`@("`@("`@("`@("`@("(\=7-E<CX@/&1I9V5S=#XB+B!4
M:&ES(&ES($Y/5"!B87-E-C1?96YC;V1E9"X-"B`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=%)E<W!O;G-E*"1U<V5R+"`D<&%S<RP@)&-H86QL96YG92D-"B`@
M("![#0H@("`@("`@(')E='5R;B`D=7-E<B`N("<@)R`N("1T:&ES+3Y?2$U!
M0U]-1#4H)'!A<W,L("1C:&%L;&5N9V4I.PT*("`@('T-"GT-"C\^````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H+U-!
M4TPO4&QA:6XN<&AP````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-C(U,0`Q,#0Q-S,V,S`P-``P,C`U-C$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`-"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR
M,#`S(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`T*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\(%)E9&ES=')I
M8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I
M=&@@;W(@=VET:&]U="`@("!\(`T*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P
M97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO
M;G,@("`@?"`-"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!O(%)E9&ES
M=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O
M=F4@8V]P>7)I9VAT("`@("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES
M="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N
M("`@("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F
M;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\(`T*
M+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@?"`-"B\O('P@("!D;V-U
M;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET
M:"!T:&4@9&ES=')I8G5T:6]N+GP@#0HO+R!\(&\@5&AE(&YA;65S(&]F('1H
M92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO
M=&4@("`@("!\(`T*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES
M('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?"`-
M"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!42$E3(%-/1E1705)%($E3
M(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))
M0E543U)3("`@?"`-"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@
M24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P@
M#0HO+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@
M34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\(`T*+R\@?"!!(%!!
M4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@
M4TA!3$P@5$A%($-/4%E224=(5"`@?"`-"B\O('P@3U=.15(@3U(@0T].5%))
M0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.
M0TE$14Y404PL('P@#0HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].
M4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\
M(`T*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%
M($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?"`-"B\O('P@1$%4
M02P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%
M5D52($-!55-%1"!!3D0@3TX@04Y9('P@#0HO+R!\(%1(14]262!/1B!,24%"
M24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL
M($]2(%1/4E0@("!\(`T*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@
M3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@
M?"`-"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&
M(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P@#0HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*R`-"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR
M:6-H87)D0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@#0HO
M+R`D260Z(%!L86EN+G!H<"QV(#$N-2`R,#`S+S`R+S(Q(#$V.C`W.C$W(&UJ
M($5X<"`D#0H-"B\J*@T**B!);7!L;65N=&%T:6]N(&]F(%!,04E.(%-!4TP@
M;65C:&%N:7-M#0HJ#0HJ($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA
M<F1`<&AP+FYE=#X-"BH@0&%C8V5S<R`@<'5B;&EC#0HJ($!V97)S:6]N(#$N
M,`T**B!`<&%C:V%G92!!=71H7U-!4TP-"BHO#0H-"G)E<75I<F5?;VYC92@G
M075T:"]305-,+T-O;6UO;BYP:'`G*3L-"@T*8VQA<W,@075T:%]305-,7U!L
M86EN(&5X=&5N9',@075T:%]305-,7T-O;6UO;@T*>PT*("`@("\J*@T*("`@
M("H@4F5T=7)N<R!03$%)3B!R97-P;VYS90T*("`@("H-"B`@("`J($!P87)A
M;2`@<W1R:6YG("1A=71H8VED("`@075T:&5N=&EC871I;VX@:60@*'5S97)N
M86UE*0T*("`@("H@0'!A<F%M("!S=')I;F<@)'!A<W,@("`@("!087-S=V]R
M9`T*("`@("H@0'!A<F%M("!S=')I;F<@)&%U=&AZ:60@("!!=71O<FEZ871I
M;VX@:60-"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@("`@("`@4$Q!24X@
M4F5S<&]N<V4-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1A
M=71H8VED+"`D<&%S<RP@)&%U=&AZ:60@/2`G)RD-"B`@("![#0H@("`@("`@
M(')E='5R;B`D875T:'II9"`N(&-H<B@P*2`N("1A=71H8VED("X@8VAR*#`I
M("X@)'!A<W,[#0H@("`@?0T*?0T*/SX-"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O075T:"]3
M05-,+T%N;VYY;6]U<RYP:'``````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#8W-C0`,3`T,3<S-C,P,#0`,#(Q-3$W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M
M,C`P,R!2:6-H87)D($AE>65S("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?"`-"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!2961I<W1R
M:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W
M:71H(&]R('=I=&AO=70@("`@?"`-"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@
M<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I
M;VYS("`@('P@#0HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*
M+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@;R!2961I
M<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B
M;W9E(&-O<'ER:6=H="`@("`@('P@#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M+B`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@
M9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?"`-
M"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P@#0HO+R!\("`@9&]C
M=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I
M=&@@=&AE(&1I<W1R:6)U=&EO;BY\(`T*+R\@?"!O(%1H92!N86UE<R!O9B!T
M:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M
M;W1E("`@("`@?"`-"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI
M<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P@
M#0HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@5$A)4R!33T945T%212!)
M4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E12
M24)55$]24R`@('P@#0HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2
M($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\
M(`T*+R\@?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&
M($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@?"`-"B\O('P@02!0
M05)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4
M(%-(04Q,(%1(12!#3U!94DE'2%0@('P@#0HO+R!\($]73D52($]2($-/3E12
M24)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)
M3D-)1$5.5$%,+"!\(`T*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/
M3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@("`@
M?"`-"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L('P@#0HO+R!\($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7
M159%4B!#0553140@04Y$($].($%.62!\(`T*+R\@?"!42$5/4ED@3T8@3$E!
M0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519
M+"!/4B!43U)4("`@?"`-"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2
M($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%
M('P@#0HO+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/
M1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\(`T*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L@#0HO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\
M<FEC:&%R9$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O(`T*
M+R\@)$ED.B!!;F]N>6UO=7,N<&AP+'8@,2XT(#(P,#,O,#(O,C$@,38Z,#<Z
M,3<@;6H@17AP("0-"@T*+RHJ#0HJ($EM<&QM96YT871I;VX@;V8@04Y/3EE-
M3U53(%-!4TP@;65C:&%N:7-M#0HJ#0HJ($!A=71H;W(@(%)I8VAA<F0@2&5Y
M97,@/')I8VAA<F1`<&AP+FYE=#X-"BH@0&%C8V5S<R`@<'5B;&EC#0HJ($!V
M97)S:6]N(#$N,`T**B!`<&%C:V%G92!!=71H7U-!4TP-"BHO#0H-"G)E<75I
M<F5?;VYC92@G075T:"]305-,+T-O;6UO;BYP:'`G*3L-"@T*8VQA<W,@075T
M:%]305-,7T%N;VYY;6]U<R!E>'1E;F1S($%U=&A?4T%33%]#;VUM;VX-"GL-
M"B`@("`O*BH-"B`@("`J($YO="!M=6-H('1O(&1O(&AE<F4@97AC97!T(')E
M='5R;B!T:&4@=&]K96X@<W5P<&QI960N#0H@("`@*B!.;R!E;F-O9&EN9RP@
M:&%S:&EN9R!O<B!E;F-R>7!T:6]N('1A:V5S('!L86-E(&9O<B!T:&ES#0H@
M("`@*B!M96-H86YI<VTL('-I;7!L>2!O;F4@;V8Z#0H@("`@*B`@;R!!;B!E
M;6%I;"!A9&1R97-S#0H@("`@*B`@;R!!;B!O<&%Q=64@<W1R:6YG(&YO="!C
M;VYT86EN:6YG(")`(B!T:&%T(&-A;B!B92!I;G1E<G!R971E9`T*("`@("H@
M("`@8GD@=&AE('-Y<V%D;6EN#0H@("`@*B`@;R!.;W1H:6YG#0H@("`@*@T*
M("`@("H@5V4@8V]U;&0@:&%V92!S;VUE(&QO9VEC(&AE<F4@9F]R('1H92!S
M96-O;F0@;W!T:6]N+"!B=70@=&AI<PT*("`@("H@=V]U;&0@8GD@;F\@;65A
M;G,@8W)E871E('-O;65T:&EN9R!I;G1E<G!R971A8FQE+@T*("`@("H-"B`@
M("`J($!P87)A;2`@<W1R:6YG("1T;VME;B!/<'1I;VYA;"!E;6%I;"!A9&1R
M97-S(&]R('-T<FEN9R!T;R!P<F]V:61E#0H@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@87,@=')A8V4@:6YF;W)M871I;VXN#0H@("`@*B!`<F5T=7)N
M('-T<FEN9R`@("`@("`@5&AE('5N86QT97)E9"!I;G!U="!T;VME;@T*("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V4H)'1O:V5N(#T@)R<I#0H@
M("`@>PT*("`@("`@("!R971U<FX@)'1O:V5N.PT*("`@('T-"GT-"C\^````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%U=&@O
M4T%33"]#;VUM;VXN<&AP````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`V-30P`#$P-#$W,S8S,#`T`#`R,#<T-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK(`HO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR
M,#`S(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\(%)E9&ES=')I8G5T
M:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@
M;W(@=VET:&]U="`@("!\(`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI
M='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@
M("!\(`HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\(&\@4F5D:7-T<FEB=71I
M;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y
M<FEG:'0@("`@("!\(`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\
M(`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@
M<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\(`HO+R!\("`@;F]T
M:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R(&EN('1H92!\(`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A
M;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R
M:6)U=&EO;BY\(`HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA
M>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\(`HO
M+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET
M:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\(`HO+R!\("`@<&5R;6ES
M<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%
M($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\(`HO+R!\
M(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%
M4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\(`HO+R!\($Q)34E4140@5$\L
M(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.
M1"!&251.15-3($9/4B!\(`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%2
M12!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4
M("!\(`HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2
M($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\(`HO+R!\(%-0
M14-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)
M3D-,541)3D<L($)55"!.3U0@("`@("!\(`HO+R!\($Q)34E4140@5$\L(%!2
M3T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/
M4U,@3T8@55-%+"!\(`HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.
M15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\
M(`HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!
M0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\(`HO+R!\("A)3D-,
M541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9
M(%=!62!/550@3T8@5$A%(%5312!\(`HO+R!\($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$
M04U!1T4N("!\(`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`HO+R!\($%U=&AO<CH@
M4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK(`HO+R`*+R\@)$ED.B!#;VUM;VXN<&AP+'8@,2XV(#(P,#,O,#(O
M,C$@,38Z,#<Z,3<@;6H@17AP("0*"B\J*@HJ($-O;6UO;B!F=6YC=&EO;F%L
M:71Y('1O(%-!4TP@;65C:&%N:7-M<PHJ"BH@0&%U=&AO<B`@4FEC:&%R9"!(
M97EE<R`\<FEC:&%R9$!P:'`N;F5T/@HJ($!A8V-E<W,@('!U8FQI8PHJ($!V
M97)S:6]N(#$N,`HJ($!P86-K86=E($%U=&A?4T%33`HJ+PH*8VQA<W,@075T
M:%]305-,7T-O;6UO;@I["B`@("`O*BH*("`@("H@1G5N8W1I;VX@=VAI8V@@
M:6UP;&5M96YT<R!(34%#($U$-2!D:6=E<W0*("`@("H*("`@("H@0'!A<F%M
M("!S=')I;F<@)&ME>2`@5&AE('-E8W)E="!K97D*("`@("H@0'!A<F%M("!S
M=')I;F<@)&1A=&$@5&AE(&1A=&$@=&\@<')O=&5C=`H@("`@*B!`<F5T=7)N
M('-T<FEN9R`@("`@("!4:&4@2$U!0R!-1#4@9&EG97-T"B`@("`J+PH@("`@
M9G5N8W1I;VX@7TA-04-?340U*"1K97DL("1D871A*0H@("`@>PH@("`@("`@
M(&EF("AS=')L96XH)&ME>2D@/B`V-"D@>PH@("`@("`@("`@("`D:V5Y(#T@
M<&%C:R@G2#,R)RP@;60U*"1K97DI*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AS=')L96XH)&ME>2D@/"`V-"D@>PH@("`@("`@("`@("`D:V5Y(#T@<W1R
M7W!A9"@D:V5Y+"`V-"P@8VAR*#`I*3L*("`@("`@("!]"@H@("`@("`@("1K
M7VEP860@/2!S=6)S='(H)&ME>2P@,"P@-C0I(%X@<W1R7W)E<&5A="AC:'(H
M,'@S-BDL(#8T*3L*("`@("`@("`D:U]O<&%D(#T@<W5B<W1R*"1K97DL(#`L
M(#8T*2!>('-T<E]R97!E870H8VAR*#!X-4,I+"`V-"D["@H@("`@("`@("1I
M;FYE<B`@/2!P86-K*"=(,S(G+"!M9#4H)&M?:7!A9"`N("1D871A*2D["B`@
M("`@("`@)&1I9V5S="`](&UD-2@D:U]O<&%D("X@)&EN;F5R*3L*"B`@("`@
M("`@<F5T=7)N("1D:6=E<W0["B`@("!]"GT*/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H
M+U-!4TPO3&]G:6XN<&AP````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-C(W-``Q,#0Q-S,V,S`P-``P,C`U-S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\($-O<'ER:6=H="`H8RD@,C`P
M,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\(`T*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\(%)E9&ES
M=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L
M('=I=&@@;W(@=VET:&]U="`@("!\(`T*+R\@?"!M;V1I9FEC871I;VXL(&%R
M92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I
M=&EO;G,@("`@?"`-"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!O(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT("`@("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(N("`@("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R
M>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\
M(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD
M('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@?"`-"B\O('P@("!D
M;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@
M=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@#0HO+R!\(&\@5&AE(&YA;65S(&]F
M('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R
M;VUO=&4@("`@("!\(`T*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T
M:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@
M?"`-"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!42$E3(%-/1E1705)%
M($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].
M5%))0E543U)3("`@?"`-"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@
M3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@
M('P@#0HO+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@
M3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\(`T*+R\@?"!!
M(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%
M3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?"`-"B\O('P@3U=.15(@3U(@0T].
M5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L
M($E.0TE$14Y404PL('P@#0HO+R!\(%-014-)04PL($5814U03$%262P@3U(@
M0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@
M("!\(`T*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4
M551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?"`-"B\O('P@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(
M3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P@#0HO+R!\(%1(14]262!/1B!,
M24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)
M5%DL($]2(%1/4E0@("!\(`T*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@
M3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!5
M4T4@?"`-"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$
M($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P@#0HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S
M(#QR:6-H87)D0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@
M#0HO+R`D260Z($QO9VEN+G!H<"QV(#$N-"`R,#`S+S`R+S(Q(#$V.C`W.C$W
M(&UJ($5X<"`D#0H-"B\J*@T**B!4:&ES(&ES('1E8VAN:6-A;&QY(&YO="!A
M(%-!4TP@;65C:&%N:7-M+"!H;W=E=F5R#0HJ(&ET)W,@=7-E9"!B>2!.971?
M4VEE=F4L($YE=%]#>7)U<R!A;F0@<&]T96YT:6%L;'D-"BH@;W1H97(@<')O
M=&]C;VQS("P@<V\@:&5R92!I<R!A(&=O;V0@<&QA8V4@=&\@86)S=')A8W0-
M"BH@:70N#0HJ#0HJ($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`
M<&AP+FYE=#X-"BH@0&%C8V5S<R`@<'5B;&EC#0HJ($!V97)S:6]N(#$N,`T*
M*B!`<&%C:V%G92!!=71H7U-!4TP-"BHO#0H-"G)E<75I<F5?;VYC92@G075T
M:"]305-,+T-O;6UO;BYP:'`G*3L-"@T*8VQA<W,@075T:%]305-,7TQO9VEN
M(&5X=&5N9',@075T:%]305-,7T-O;6UO;@T*>PT*("`@("\J*@T*("`@("H@
M4'-E=61O(%-!4TP@3$]'24X@;65C:&%N:7-M#0H@("`@*@T*("`@("H@0'!A
M<F%M("!S=')I;F<@)'5S97(@57-E<FYA;64-"B`@("`J($!P87)A;2`@<W1R
M:6YG("1P87-S(%!A<W-W;W)D#0H@("`@*B!`<F5T=7)N('-T<FEN9R`@("`@
M("!,3T=)3B!S=')I;F<-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%)E<W!O
M;G-E*"1U<V5R+"`D<&%S<RD-"B`@("![#0H@("`@("`@(')E='5R;B!S<')I
M;G1F*"=,3T=)3B`E<R`E<R<L("1U<V5R+"`D<&%S<RD[#0H@("`@?0T*?0T*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O075T
M:"]305-,+T1I9V5S=$U$-2YP:'``````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,C`R-C``,3`T,3<S-C,P,#0`,#(Q,C,W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L@"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R
M+3(P,#,@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@4F5D:7-T<FEB
M=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET
M:"!O<B!W:71H;W5T("`@('P@"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R
M;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS
M("`@('P@"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O
M<'ER:6=H="`@("`@('P@"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@
M('P@"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S
M="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P@"B\O('P@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(@:6X@=&AE('P@"B\O('P@("!D;V-U;65N=&%T:6]N
M(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES
M=')I8G5T:6]N+GP@"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@
M;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P@
M"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W
M:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P@"B\O('P@("!P97)M
M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!4
M2$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P@"B\O
M('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y4
M2453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P@"B\O('P@3$E-251%1"!4
M3RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@
M04Y$($9)5$Y%4U,@1D]2('P@"B\O('P@02!005)424-53$%2(%!54E!/4T4@
M05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'
M2%0@('P@"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&
M3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P@"B\O('P@
M4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@
M*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P@"B\O('P@3$E-251%1"!43RP@
M4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@
M3$]34R!/1B!54T4L('P@"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E53
M24Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9
M('P@"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY4
M4D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P@"B\O('P@*$E.
M0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!
M3ED@5T%9($]55"!/1B!42$4@55-%('P@"B\O('P@3T8@5$A)4R!33T945T%2
M12P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(
M($1!34%'12X@('P@"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@"B\O('P@075T:&]R
M.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L@"B\O(`HO+R`D260Z($1I9V5S=$U$-2YP:'`L=B`Q+C8@,C`P
M,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@)`H*+RHJ"BH@26UP;&UE;G1A=&EO
M;B!O9B!$24=%4U0M340U(%-!4TP@;65C:&%N:7-M"BH**B!`875T:&]R("!2
M:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^"BH@0&%C8V5S<R`@<'5B
M;&EC"BH@0'9E<G-I;VX@,2XP"BH@0'!A8VMA9V4@075T:%]305-,"BHO"@IR
M97%U:7)E7V]N8V4H)T%U=&@O4T%33"]#;VUM;VXN<&AP)RD["@IC;&%S<R!!
M=71H7U-!4TQ?1&EG97-T340U(&5X=&5N9',@075T:%]305-,7T-O;6UO;@I[
M"B`@("`O*BH*("`@("H@4')O=FED97,@=&AE("AM86EN*2!C;&EE;G0@<F5S
M<&]N<V4@9F]R($1)1T535"U-1#4*("`@("H@<F5Q=6ER97,@82!F97<@97AT
M<F$@<&%R86UE=&5R<R!T:&%N('1H92!O=&AE<@H@("`@*B!M96-H86YI<VUS
M+"!W:&EC:"!A<F4@=6YA=F]I9&%B;&4N"B`@("`J(`H@("`@*B!`<&%R86T@
M('-T<FEN9R`D875T:&-I9"`@($%U=&AE;G1I8V%T:6]N(&ED("AU<V5R;F%M
M92D*("`@("H@0'!A<F%M("!S=')I;F<@)'!A<W,@("`@("!087-S=V]R9`H@
M("`@*B!`<&%R86T@('-T<FEN9R`D8VAA;&QE;F=E(%1H92!D:6=E<W0@8VAA
M;&QE;F=E('-E;G0@8GD@=&AE('-E<G9E<@H@("`@*B!`<&%R86T@('-T<FEN
M9R`D:&]S=&YA;64@(%1H92!H;W-T;F%M92!O9B!T:&4@;6%C:&EN92!Y;W4G
M<F4@8V]N;F5C=&EN9R!T;PH@("`@*B!`<&%R86T@('-T<FEN9R`D<V5R=FEC
M92`@(%1H92!S97)V:6-E;F%M92`H96<N(&EM87`L('!O<"P@86-A<"!E=&,I
M"B`@("`J($!P87)A;2`@<W1R:6YG("1A=71H>FED("`@075T:&]R:7IA=&EO
M;B!I9"`H=7-E<FYA;64@=&\@<')O>'D@87,I"B`@("`J($!R971U<FX@<W1R
M:6YG("`@("`@("`@("`@5&AE(&1I9V5S="!R97-P;VYS92`H3D]4(&)A<V4V
M-"!E;F-O9&5D*0H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%)E<W!O;G-E*"1A=71H8VED+"`D<&%S<RP@)&-H86QL96YG
M92P@)&AO<W1N86UE+"`D<V5R=FEC92P@)&%U=&AZ:60@/2`G)RD*("`@('L*
M("`@("`@("`D8VAA;&QE;F=E(#T@)'1H:7,M/E]P87)S94-H86QL96YG92@D
M8VAA;&QE;F=E*3L*("`@("`@("`D875T:'II9%]S=')I;F<@/2`G)SL*("`@
M("`@("!I9B`H)&%U=&AZ:60@(3T@)R<I('L*("`@("`@("`@("`@)&%U=&AZ
M:61?<W1R:6YG(#T@)RQA=71H>FED/2(G("X@)&%U=&AZ:60@+B`G(B<[(`H@
M("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8VAA;&QE;F=E*2D@>PH@
M("`@("`@("`@("`D8VYO;F-E("`@("`@("`@/2`D=&AI<RT^7V=E=$-N;VYC
M92@I.PH@("`@("`@("`@("`D9&EG97-T7W5R:2`@("`@/2!S<')I;G1F*"<E
M<R\E<R<L("1S97)V:6-E+"`D:&]S=&YA;64I.PH@("`@("`@("`@("`D<F5S
M<&]N<V5?=F%L=64@/2`D=&AI<RT^7V=E=%)E<W!O;G-E5F%L=64H)&%U=&AC
M:60L("1P87-S+"`D8VAA;&QE;F=E6R=R96%L;2==+"`D8VAA;&QE;F=E6R=N
M;VYC92==+"`D8VYO;F-E+"`D9&EG97-T7W5R:2P@)&%U=&AZ:60I.PH*("`@
M("`@("`@("`@<F5T=7)N('-P<FEN=&8H)W5S97)N86UE/2(E<R(L<F5A;&T]
M(B5S(B<@+B`D875T:'II9%]S=')I;F<@("X@)RQN;VYC93TB)7,B+&-N;VYC
M93TB)7,B+&YC/2(P,#`P,#`P,2(L<6]P/6%U=&@L9&EG97-T+75R:3TB)7,B
M+')E<W!O;G-E/25S+"5D)RP@)&%U=&AC:60L("1C:&%L;&5N9V5;)W)E86QM
M)UTL("1C:&%L;&5N9V5;)VYO;F-E)UTL("1C;F]N8V4L("1D:6=E<W1?=7)I
M+"`D<F5S<&]N<V5?=F%L=64L("1C:&%L;&5N9V5;)VUA>&)U9B==*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G26YV86QI9"!D:6=E<W0@8VAA;&QE;F=E)RD["B`@("`@("`@?0H@
M("`@?0H@("`@"B`@("`O*BH*("`@("H@4&%R<V5S(&%N9"!V97)I9FEE<R!T
M:&4@9&EG97-T(&-H86QL96YG92H*("`@("H*("`@("H@0'!A<F%M("!S=')I
M;F<@)&-H86QL96YG92!4:&4@9&EG97-T(&-H86QL96YG90H@("`@*B!`<F5T
M=7)N(&%R<F%Y("`@("`@("`@("`@(%1H92!P87)S960@8VAA;&QE;F=E(&%S
M(&%N(&%S<V]C"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87D@:6X@=&AE(&9O<FT@(F1I<F5C=&EV92`]/B!V86QU92(N"B`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94-H86QL
M96YG92@D8VAA;&QE;F=E*0H@("`@>PH@("`@("`@("1T;VME;G,@/2!A<G)A
M>2@I.PH@("`@("`@('=H:6QE("AP<F5G7VUA=&-H*"<O7BA;82UZ+5TK*3TH
M(EM>(ETK*#\\(5Q<7"DB?%M>+%TK*2]I)RP@)&-H86QL96YG92P@)&UA=&-H
M97,I*2!["@H@("`@("`@("`@("`O+R!)9VYO<F4@=&AE<V4@87,@<&5R(')F
M8S(X,S$*("`@("`@("`@("`@:68@*"1M871C:&5S6S%=(#T]("=O<&%Q=64G
M($]2("1M871C:&5S6S%=(#T]("=D;VUA:6XG*2!["B`@("`@("`@("`@("`@
M("`D8VAA;&QE;F=E(#T@<W5B<W1R*"1C:&%L;&5N9V4L('-T<FQE;B@D;6%T
M8VAE<ULP72D@*R`Q*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!!;&QO=V5D(&UU;'1I<&QE(")R
M96%L;2(@86YD(")A=71H+7!A<F%M(@H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1T;VME;G-;)&UA=&-H97-;,5U=*2!!3D0@*"1M871C:&5S6S%=(#T]("=R
M96%L;2<@3U(@)&UA=&-H97-;,5T@/3T@)V%U=&@M<&%R86TG*2D@>PH@("`@
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T;VME;G-;)&UA=&-H97-;,5U=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T;VME;G-;)&UA=&-H97-;,5U=
M6UT@/2!P<F5G7W)E<&QA8V4H)R]>(B@N*BDB)"\G+"`G7%PQ)RP@)&UA=&-H
M97-;,ETI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=&]K96YS6R1M871C:&5S6S%=72`](&%R<F%Y*"1T;VME;G-;
M)&UA=&-H97-;,5U=+"!P<F5G7W)E<&QA8V4H)R]>(B@N*BDB)"\G+"`G7%PQ
M)RP@)&UA=&-H97-;,ETI*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\O($%N>2!O=&AE<B!M=6QT:7!L92!I;G-T86YC92`](&9A:6QU<F4*
M("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=&]K96YS6R1M871C:&5S
M6S%=72DI('L*("`@("`@("`@("`@("`@("1T;VME;G,@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1O:V5N<ULD;6%T8VAE<ULQ75T@/2!P<F5G7W)E
M<&QA8V4H)R]>(B@N*BDB)"\G+"`G7%PQ)RP@)&UA=&-H97-;,ETI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!296UO=F4@=&AE(&IU<W0@<&%R
M<V5D(&1I<F5C=&EV92!F<F]M('1H92!C:&%L;&5N9V4*("`@("`@("`@("`@
M)&-H86QL96YG92`]('-U8G-T<B@D8VAA;&QE;F=E+"!S=')L96XH)&UA=&-H
M97-;,%TI("L@,2D["B`@("`@("`@?0H*("`@("`@("`O*BH*("`@("`@("`J
M($1E9F%U;'1S(&%N9"!R97%U:7)E9"!D:7)E8W1I=F5S"B`@("`@("`@*B\*
M("`@("`@("`O+R!296%L;0H@("`@("`@(&EF("AE;7!T>2@D=&]K96YS6R=R
M96%L;2==*2D@>PH@("`@("`@("`@("`D=6YA;64@/2!P;W-I>%]U;F%M92@I
M.PH@("`@("`@("`@("`D=&]K96YS6R=R96%L;2==(#T@)'5N86UE6R=N;V1E
M;F%M92==.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`O+R!-87AB=68*
M("`@("`@("!I9B`H96UP='DH)'1O:V5N<ULG;6%X8G5F)UTI*2!["B`@("`@
M("`@("`@("1T;VME;G-;)VUA>&)U9B==(#T@-C4U,S8["B`@("`@("`@?0H@
M("`@("`@(`H@("`@("`@("\O(%)E<75I<F5D.B!N;VYC92P@86QG;W)I=&AM
M"B`@("`@("`@:68@*&5M<'1Y*"1T;VME;G-;)VYO;F-E)UTI($]2(&5M<'1Y
M*"1T;VME;G-;)V%L9V]R:71H;2==*2D@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T=7)N("1T
M;VME;G,["B`@("!]"@H@("`@+RHJ"B`@("`J($-R96%T97,@=&AE(')E<W!O
M;G-E/2!P87)T(&]F('1H92!D:6=E<W0@<F5S<&]N<V4*("`@("H*("`@("H@
M0'!A<F%M("!S=')I;F<@)&%U=&AC:60@("`@075T:&5N=&EC871I;VX@:60@
M*'5S97)N86UE*0H@("`@*B!`<&%R86T@('-T<FEN9R`D<&%S<R`@("`@("!0
M87-S=V]R9`H@("`@*B!`<&%R86T@('-T<FEN9R`D<F5A;&T@("`@("!296%L
M;2!A<R!P<F]V:61E9"!B>2!T:&4@<V5R=F5R"B`@("`J($!P87)A;2`@<W1R
M:6YG("1N;VYC92`@("`@($YO;F-E(&%S('!R;W9I9&5D(&)Y('1H92!S97)V
M97(*("`@("H@0'!A<F%M("!S=')I;F<@)&-N;VYC92`@("`@0VQI96YT(&YO
M;F-E"B`@("`J($!P87)A;2`@<W1R:6YG("1D:6=E<W1?=7)I(%1H92!D:6=E
M<W0M=7)I/2!V86QU92!P87)T(&]F('1H92!R97-P;VYS90H@("`@*B!`<&%R
M86T@('-T<FEN9R`D875T:'II9"`@("!!=71H;W)I>F%T:6]N(&ED"B`@("`J
M($!R971U<FX@<W1R:6YG("`@("`@("`@("`@(%1H92!R97-P;VYS93T@<&%R
M="!O9B!T:&4@9&EG97-T(')E<W!O;G-E"B`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@*B\@("`@"B`@("!F=6YC=&EO;B!?9V5T4F5S<&]N<V5686QU92@D
M875T:&-I9"P@)'!A<W,L("1R96%L;2P@)&YO;F-E+"`D8VYO;F-E+"`D9&EG
M97-T7W5R:2P@)&%U=&AZ:60@/2`G)RD*("`@('L*("`@("`@("!I9B`H)&%U
M=&AZ:60@/3T@)R<I('L*("`@("`@("`@("`@)$$Q(#T@<W!R:6YT9B@G)7,Z
M)7,Z)7,G+"!P86-K*"=(,S(G+"!M9#4H<W!R:6YT9B@G)7,Z)7,Z)7,G+"`D
M875T:&-I9"P@)')E86QM+"`D<&%S<RDI*2P@)&YO;F-E+"`D8VYO;F-E*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D03$@/2!S<')I;G1F*"<E
M<SHE<SHE<SHE<R<L('!A8VLH)T@S,B<L(&UD-2AS<')I;G1F*"<E<SHE<SHE
M<R<L("1A=71H8VED+"`D<F5A;&TL("1P87-S*2DI+"`D;F]N8V4L("1C;F]N
M8V4L("1A=71H>FED*3L*("`@("`@("!]"B`@("`@("`@)$$R(#T@)T%55$A%
M3E1)0T%413HG("X@)&1I9V5S=%]U<FD["B`@("`@("`@<F5T=7)N(&UD-2AS
M<')I;G1F*"<E<SHE<SHP,#`P,#`P,3HE<SIA=71H.B5S)RP@;60U*"1!,2DL
M("1N;VYC92P@)&-N;VYC92P@;60U*"1!,BDI*3L*("`@('T*"B`@("`O*BH*
M("`@("H@0W)E871E<R!T:&4@8VQI96YT(&YO;F-E(&9O<B!T:&4@<F5S<&]N
M<V4*("`@("H*("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;F]N8V4@=F%L
M=64*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$-N;VYC92@I"B`@("!["B`@("`@("`@:68@*&9I;&5?97AI<W1S*"<O
M9&5V+W5R86YD;VTG*2D@>PH@("`@("`@("`@("!R971U<FX@8F%S938T7V5N
M8V]D92AF<F5A9"AF;W!E;B@G+V1E=B]U<F%N9&]M)RP@)W(G*2P@,S(I*3L*
M"B`@("`@("`@?2!E;'-E:68@*&9I;&5?97AI<W1S*"<O9&5V+W)A;F1O;2<I
M*2!["B`@("`@("`@("`@(')E='5R;B!B87-E-C1?96YC;V1E*&9R96%D*&9O
M<&5N*"<O9&5V+W)A;F1O;2<L("=R)RDL(#,R*2D["@H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1S='(@/2`G)SL*("`@("`@("`@("`@;71?<W)A
M;F0H*&1O=6)L92EM:6-R;W1I;64H*2HQ,#`P,#`P,"D["B`@("`@("`@("`@
M(&9O<B`H)&D],#L@)&D\,S([("1I*RLI('L*("`@("`@("`@("`@("`@("1S
M='(@+CT@8VAR*&UT7W)A;F0H,"P@,C4U*2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@"B`@("`@("`@("`@(')E='5R;B!B87-E-C1?96YC;V1E*"1S
M='(I.PH@("`@("`@('T*("`@('T*?0H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O075T:"]305-,+G!H
M<```````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`R
M,#0`,3`T,3<S-C,P,#0`,#$W-3`W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK(`T*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!2
M:6-H87)D($AE>65S("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`-"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!2961I<W1R:6)U=&EO
M;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R
M('=I=&AO=70@("`@?"`-"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET
M=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@
M('P@#0HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O
M<'ER:6=H="`@("`@('P@#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@
M("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M
M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?"`-"B\O('P@
M("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P@#0HO+R!\("`@9&]C=6UE;G1A
M=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE
M(&1I<W1R:6)U=&EO;BY\(`T*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T
M:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@
M("`@?"`-"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T
M=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P@#0HO+R!\
M("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?"`-"B\O('P@5$A)4R!33T945T%212!)4R!04D]6
M241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]2
M4R`@('P@#0HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)
M140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\(`T*+R\@
M?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(
M04Y404))3$E462!!3D0@1DE43D534R!&3U(@?"`-"B\O('P@02!005)424-5
M3$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,
M(%1(12!#3U!94DE'2%0@('P@#0HO+R!\($]73D52($]2($-/3E1224)55$]2
M4R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.
M5$%,+"!\(`T*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%
M3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@("`@?"`-"B\O
M('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$
M4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L('P@#0HO+R!\($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!\(`T*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519
M+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!4
M3U)4("`@?"`-"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$52
M5TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P@#0HO
M+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@
M4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\(`T*+R\@?"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L@#0HO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R
M9$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O(`T*+R\@)$ED
M.B!305-,+G!H<"QV(#$N-"`R,#`S+S`R+S(Q(#$V.C`W.C$W(&UJ($5X<"`D
M#0H-"B\J*@T**B!#;&EE;G0@:6UP;&5M96YT871I;VX@;V8@=F%R:6]U<R!3
M05-,(&UE8VAA;FES;7,@#0HJ#0HJ($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@
M/')I8VAA<F1`<&AP+FYE=#X-"BH@0&%C8V5S<R`@<'5B;&EC#0HJ($!V97)S
M:6]N(#$N,`T**B!`<&%C:V%G92!!=71H7U-!4TP-"BHO#0H-"G)E<75I<F5?
M;VYC92@G4$5!4BYP:'`G*3L-"@T*8VQA<W,@075T:%]305-,#0I[#0H@("`@
M+RHJ#0H@("`@*B!&86-T;W)Y(&-L87-S+B!2971U<FYS(&%N(&]B:F5C="!O
M9B!T:&4@<F5Q=65S=`T*("`@("H@='EP92X-"B`@("`J#0H@("`@*B!`<&%R
M86T@<W1R:6YG("1T>7!E($]N92!O9CH@06YO;GEM;W5S#0H@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@4&QA:6X-"B`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!#<F%M340U#0H@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1&EG97-T340U#0H@("`@*B`@("`@("`@("`@
M("`@("`@("`@(%1Y<&5S(&%R92!N;W0@8V%S92!S96YS:71I=F4-"B`@("`J
M+PT*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1T>7!E*0T*("`@('L-"B`@("`@
M("`@<W=I=&-H("AS=')T;VQO=V5R*"1T>7!E*2D@>PT*("`@("`@("`@("`@
M8V%S92`G86YO;GEM;W5S)SH-"B`@("`@("`@("`@("`@("`D9FEL96YA;64@
M(#T@)T%U=&@O4T%33"]!;F]N>6UO=7,N<&AP)SL-"B`@("`@("`@("`@("`@
M("`D8VQA<W-N86UE(#T@)T%U=&A?4T%33%]!;F]N>6UO=7,G.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E("=L;V=I;B<Z
M#0H@("`@("`@("`@("`@("`@)&9I;&5N86UE("`]("=!=71H+U-!4TPO3&]G
M:6XN<&AP)SL-"B`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@)T%U=&A?
M4T%33%],;V=I;B<[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@
M("`@("`@(&-A<V4@)W!L86EN)SH-"B`@("`@("`@("`@("`@("`D9FEL96YA
M;64@(#T@)T%U=&@O4T%33"]0;&%I;BYP:'`G.PT*("`@("`@("`@("`@("`@
M("1C;&%S<VYA;64@/2`G075T:%]305-,7U!L86EN)SL-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S92`G8W)A;6UD-2<Z#0H@
M("`@("`@("`@("`@("`@)&9I;&5N86UE("`]("=!=71H+U-!4TPO0W)A;4U$
M-2YP:'`G.PT*("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`G075T:%]3
M05-,7T-R86U-1#4G.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@
M("`@("`@("!C87-E("=D:6=E<W1M9#4G.@T*("`@("`@("`@("`@("`@("1F
M:6QE;F%M92`@/2`G075T:"]305-,+T1I9V5S=$U$-2YP:'`G.PT*("`@("`@
M("`@("`@("`@("1C;&%S<VYA;64@/2`G075T:%]305-,7T1I9V5S=$U$-2<[
M#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&1E9F%U
M;'0Z#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)TEN=F%L:60@4T%33"!M96-H86YI<VT@='EP92<I.PT*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5Q=6ER95]O;F-E
M*"1F:6QE;F%M92D[#0H@("`@("`@(')E='5R;B!N97<@)&-L87-S;F%M92@I
M.PT*("`@('T-"GT-"@T*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+P``````````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V
M,S`P-``P,38R-S$`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O
M1$(O````````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`Q-C4U-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]$0B]$0B\`````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#$W,#0S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O8R\`````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,S`P-``P,3<S,C,`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O1$(O9&]C+TE$14%3````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`V-3,W`#$P-#$W,S8S,#`T`#`R,#$P,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!!8G-T<F%C=&5D(%1Y
M<&5S("A3=&EG*0HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*1$(@;F5E9',@
M82!S970@;V8@='EP97,@<F5P<F5S96YT:6YG('1H92!M;W-T(&-O;6UO;FQY
M('5S960@='EP97,@:6X*86QL(&)A8VME;F1S+B`@5&AI<R!T>7!E('-E="!C
M;W5L9"!A;'-O(&)E(&=E87)E9"!T;W=A<F1S(&EN=&5G<F%T:6]N"G=I=&@@
M=&AI;F=S(&QI:V4@6$U,+5)00R]33T%0(&EM<&QE;65N=&%T:6]N<RP@2%1-
M3"!F;W)M(&-L87-S97,L(&5T8RX*"E)E86P@475E<GD@4&%R<V5R("A3=&EG
M*0HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"E=I=&@@82!R96%L('%U97)Y
M('!A<G-E<BP@1$(@8V%N(&EM<&QE;65N="!M;W)E(&]F(&ET<R!P;W)T86)I
M;&ET>0IB87-E9"!O;B!T:&4@<75E<GDL(&EN<W1E860@;V8@:&%V:6YG('-U
M<'!O<G0@9G5N8W1I;VYS(&9O<@IE=F5R>71H:6YG+B`@3VYE(&5X86UP;&4@
M=V]U;&0@8F4@3$E-250L(&%N;W1H97(@(DE.4T525`HN+BX@4D5455).24Y'
M(BX*"E!O<G1A8FQE('1R86YS86-T:6]N<R`H4W1I9RD*+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+0H*268@1$(@8V%N('!A<G-E('%U97)I97,@96YO
M=6=H('1O(&1E=&5R;6EN92!W:&%T('1A8FQE<R!A<F4@869F96-T960*8GD@
M<75E<FEE<RP@:70@<VAO=6QD(&)E('!O<W-I8FQE('1O(&UA:V4@82!R97!L
M87EA8FQE('1R86YS86-T:6]N"FQO9RX@($=.3TU%('5S97,@86X@6$U,(&9O
M<FUA="!F;W(@8V]N9FEG=7)A=&EO;B!D871A('1H870@;&5T<R!Y;W4*8VAE
M8VMP;VEN="!S=&%T92!O;F-E(&EN(&$@=VAI;&4L(&%N9"!R979E<G0@=&\@
M=&AA="!S=&%T92!L871E<BX*5VET:"!A('-I;6EL87(@87!P<F]A8V@@9F]R
M('1R86YS86-T:6]N<R!I;B!$0B!W92!C86X@:6UP;&5M96YT"G!O<G1A8FQE
M('1R86YS86-T:6]N<R!A;F0@8VAE8VMP;VEN=&EN9R!E=F5N(&9O<B!T:&4@
M9&%T86)A<V5S('1H870*9&]N)W0@<W5P<&]R="!T:&5M+@H*"D5R<F]R(')E
M<&]R=&EN9R!C;&5A;BUU<"]D96)U9R`H5&]M87,I"BTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*3F]W(&5A8V@@9')I=F5R(&AA<R!I
M=',@;W=N(')A:7-E17)R;W(@;65T:&]D+"!C;VUM;VX@:&%S(&$@<F%I<V5%
M<G)O<B!A;F0*1$(@:&%S(&$@1$)?97)R;W(@8VQA<W,@86YD(&ET<R!O=VX@
M:7-%<G)O<B@I(&UE=&AO9"X@5&AI<R!E<G)O<B!S='5F9B`*;W9E<FAE860@
M8V]U;&0@8F4@<VEM<&QI9FEE9"!W:71H(&]N;'D@;VYE(')A:7-E17)R;W(L
M(&1R;W!I;F<@=&AE($1"($5R<F]R"F-L87-S(&%N9"!A;'-O('1H92!$0CHZ
M:7-%<G)O<B@I("AU<V4@=&AE(%!%05(N<&AP(&]N97,@:6YS=&5A9"DN"D]T
M:&5R(&ED96$@8V]U;&0@8F4@=&\@861D(&$@<WES=&5M(&9O<B!A;&QO=VEN
M9R!P96]P;&4@86-C97-S('1O(&%L;"!T:&4*<75E<FEE<R!S96YD960@8GD@
M4$5!4B!$0B!T;R!T:&4@8F%C:V5N9"X@06QS;R!A(&YE=R!014%27T524D]2
M7T1%0E5'"F9L86<@=&AA="!A=71O;6%T:6-A;&QY("AS:&]W?'1R:6=G97)S
M*2!D96)U9R!I;F9O+"!P97)H87!S"G=I=&@@82!N97<@4$5!4E\H5V%R;FEN
M9WQ$96)U9RD@;V)J96-T+@H*475O=&4@8VQE86XM=7`@*%-T:6<I"BTM+2TM
M+2TM+2TM+2TM+2TM+2TM+0HQ+B!+965P('%U;W1E(&%N9"!Q=6]T95-T<FEN
M9RP@8G5T(&UO=F4@<75O=&EN9R!O9B!S=')I;F=S(&)A8VL@:6YT;PH@("!Q
M=6]T95-T<FEN9R!A;F0@;6%K92!Q=6]T92!C86QL(&ET(&9O<B!S=')I;F=S
M+@H*,BX@061D(&%N(&]P=&EO;F%L(")O<&5R871O<B(@<&%R86UE=&5R('1O
M('%U;W1E('1H870@:7,@;VYE(&]F("(](BP*("`@(CPB+"`B/B(@;W(@(CP^
M(B!T:&%T('=I;&P@8F4@:6YS97)T960@:6X@9G)O;G0@;V8@=&AE('%U;W1E
M9"!V86QU90H@("!U;FQE<W,@:70@:7,@3E5,3"P@:6X@=VAI8V@@8V%S92!I
M="!W:6QL(&)E(&-O;G9E<G1E9"!T;R`B25,B("AF;W(*("`@(CTB*2!O<B`B
M25,@3D]4(B`H9F]R('1H92!O=&AE<G,I+@H*075T;R!F<F5E('-T871E;65N
M=',@*%1O;6%S*0HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"D)Y('-E
M='1I;F<@82!P87)A;2!I;B!Q=65R>2@I(&]R(&9O<B!T:&4@:&]L92!$0B!I
M;G-T86YC92P@4$5!4B!$0@IC;W5L9"!A=71O+69R964@<F5S=6QT<R!I;B!$
M0E]R97-U;'0M/F9E=&-H*$EN=&]\4F]W*2!W:&5N('1H92!D<FEV97(*<F5T
M=7)N<R!F86QS92X*"D1A=&%T>7!E<R!I;B!P<F5P87)E('-Y;G1A>"`H5&]M
M87,I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"D5X=&5N
M9"!T:&4@86-T=6%L('!R97!A<F4O97AE8W5T92!P;&%C96AO;&1E<G,@=&\@
M<W5P<&]R="!D871A('1Y<&5S+"!B;W1H"G1O(&-H96-K('1H92!D871A(&EN
M=')O9'5C960@=&\@=&AE('%U97)Y(&%N9"!T;R`B8V%S="(@=&AE(')E<W5L
M=`IT;R!N871I=F4@<&AP(&1A=&$@='EP97,N($5X.@H*)'-Q;"`]("))3E-%
M4E0@24Y43R!T86)L92!604Q515,@*'M[:6YT*#0I?7TL('M[8F]O;'U]+"![
M>V1A=&4H)UDM;2UD)RE]?2DB.PHD<F]W(#T@)&1B+3YQ=65R>2@D<W%L+"!A
M<G)A>2@X+"`G="<L("<R,#`Q+3`T+3$G*2D["@I&;W)M870Z('M[/&1A=&%?
M='EP93XH/'!A<F%M,3XL/'!A<F%M,CXI?7T*"B)P87)A;2(@8V]U;&0@8F4@
M=&AE(&UA>"!L96YG:'0@;V8@=&AE(&1A=&$L(&1A=&4@9F]R;6%T<RP@;F]T
M7VYU;&P*8VAE8VMS(&]R(&1E9F%U;'0@=F%L=65S+@H*3W1H97(@:61E87,@
M8V]U;&0@8F4Z"@HQ*0HD<W%L(#T@(DE.4T525"!)3E1/('1A8FQE(%9!3%5%
M4R`H/RP@/RP@/RDB.PHD<W1H(#T@)&1B+3YP<F5P87)E*"1S<6PL(&%R<F%Y
M*"=I;G0H-"DG+"`G8F]O;"<L("=D871E)RD["B1R97,@/2`D9&(M/F5X96-U
M=&4H)'-T:"P@87)R87DH)&$L("1B+"`D8RD["@HR*0HD<W%L(#T@(DE.4T52
M5"!)3E1/('1A8FQE(%9!3%5%4R`H/RP@/RP@/RDB.PHD<&%R86US(#T@87)R
M87DH"@DP(#T^(&%R<F%Y*"1A+"`G:6YT*#0I)RDL"@DQ(#T^(&%R<F%Y*"1B
M+"`G8F]O;"<I"BD["B1R97,@/2`D9&(M/G%U97)Y*"1S<6PL("1P87)A;7,I
M.PH*075T;R!C;VYN96-T(&9E871U<F4@*%1O;6%S*0HM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM"D%D9"!T:&4@86)I;&ET>2!T;R!C<F5A=&4@9F]R
M(&5X86UP;&4@82!L:6=H="!A;F0@9'5M<"!$0B!O8FIE8W0@=VAI8V@*=VEL
M;"!O;FQY('-E="!U<"!T:&4@8V]N;F5C=&EO;B!W:&5N(&YE961E9"X@5VET
M:"!T:&%T('!E;W!L92!C;W5L9`IC<F5A=&4@=&AE($1"(&]B:F5C="!I;B!A
M(&-O;6UO;B!P<F5P96YD(&]R(&1E9F%U;'0@9FEL92!W:71H;W5T('1H90IN
M965D('1O('=A<W1E('-Y<W1E;2!R97-O=7)C97,@:68@=&AE('5S92!O9B!T
M:&4@9&%T86)A<V4@:7,@9FEN86QL>0IN;W0@;F5E9&5D+@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+T1"+V1O8R]35$%455,`````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,#`P,@`Q,#0Q-S,V,S`P-``P,C`R-3<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````4U1!5%53($]&(%1(
M12!014%2($1"(%!!0TM!1T4*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*"B1)9#H@4U1!5%53+'8@,2XR-2`R,#`T+S`R+S$Y(#$Y.C,W.C0S(&1A
M;FEE;&,@17AP("0*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I$0B!$
M<FEV97(@1F5A='5R92!-871R:7@*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"E-Y;6)O;',Z"B`@>"`@/2`@:6UP;&5M96YT960L(&)U="!W:71H;W5T('1E
M<W1S"B`@="`@/2`@:6UP;&5M96YT960L(&)U="!O;F4@;W(@;6]R92!T97-T
M<R!F86EL"B`@5"`@/2`@:6UP;&5M96YT960L('!A<W-I;F<@86QL('1E<W1S
M"B`@92`@/2`@96UU;&%T960L('=I=&AO=70@=&5S=',*("!L("`]("!E;75L
M871E9"P@8G5T(&]N92!O<B!M;W)E('1E<W1S(&9A:6P*("!%("`]("!E;75L
M871E9"P@<&%S<VEN9R!A;&P@=&5S=',*("!N("`]("!R971U<FYS(")N;W0@
M8V%P86)L92(*("`M("`]("!N;R!I;7!L96UE;G1A=&EO;B!O9B!T:&ES(&9E
M871U<F4@;W(@<W1A='5S('5N:VYO=VX*"B`@("`@("`@("`@("`@("`@("`@
M9F)S<6P@("`@("!I9G@@("`@("!M<W-Q;"`@("`@;7ES<6QI("`@("!O9&)C
M("`@("!S<6QI=&4*1D5!5%5212`@("`@("`@9&)A<V4@('P@(&EB87-E("!\
M("!M<W%L("`@?"`@;7ES<6P@('P@("!O8VDX("!\("!P9W-Q;"`@?"`@<WEB
M87-E"G-I;7!L95%U97)Y("`@("`@+2`@("!X("`@(%0@("`@5"`@("!X("`@
M(%0@("`@5"`@("!X("`@(%0@("`@5"`@("!4("`@(%0@("`@5`IN=6U#;VQS
M("`@("`@("`@('@@("`@>"`@("!4("`@('@@("`@>"`@("!4("`@(%0@("`@
M>"`@("!4("`@(%0@("`@5"`@("!4("`@(%0*;G5M4F]W<R`@("`@("`@("!X
M("`@('@@("`@;B`@("!N("`@('@@("`@5"`@("!4("`@('@@("`@12`@("!4
M("`@(%0@("`@5"`@("!N(`IE<G)O<DYA=&EV92`@("`@(&X@("`@>"`@("!N
M("`@('0@("`@;B`@("!4("`@(%0@("`@>"`@("!4("`@(%0@("`@5"`@("!%
M("`@(%0*<')E<&%R92]E>&5C=71E("!E("`@(&4@("`@5"`@("!%("`@(&4@
M("`@12`@("!%("`@(&4@("`@5"`@("!%("`@($4@("`@12`@("!%"G-E<75E
M;F-E<R`@("`@("`@+2`@("!E("`@(%0@("`@12`@("!N("`@($4@("`@12`@
M("!E("`@(%0@("`@12`@("!4("`@($4@("`@10IA9F9E8W1E9%)O=W,@("`@
M(&X@("`@>"`@("!N("`@(%0@("`@>"`@("!N("`@(%0@("`@>"`@("!4("`@
M(%0@("`@5"`@("!4("`@(%0*9F5T8V@@;6]D97,@("`@("!X("`@('@@("`@
M5"`@("!4("`@('@@("`@5"`@("!4("`@('@@("`@5"`@("!4("`@(%0@("`@
M5"`@("!4"F9E=&-H(')O=R!B>2!N;R`@>"`@("!X("`@(&X@("`@5"`@("!X
M("`@(%0@("`@5"`@("!X("`@(&X@("`@>"`@("!4("`@(%0@("`@5`IT<F%N
M<V%C=&EO;G,@("`@("T@("`@>"`@("!4("`@(&X@("`@;B`@("!4("`@('0@
M("`@+2`@("!4("`@(%0@("`@5"`@("`M("`@(%0*875T;RUC;VUM:70@("`@
M("`M("`@('@@("`@>"`@("!N("`@(&X@("`@;B`@("!N("`@("T@("`@>"`@
M("!X("`@('@@("`@+2`@("!N"F5R<F]R(&UA<'!I;F<@("`@+2`@("!X("`@
M(%0@("`@="`@("`M("`@('0@("`@="`@("`M("`@(%0@("`@5"`@("!%("`@
M(&P@("`@;`IT86)L94EN9F\@("`@("`@(&X@("`@>"`@("!4("`@('0@("`@
M;B`@("!4("`@(%0@("`@+2`@("!4("`@(&X@("`@5"`@("`M("`@(%0*"DY/
M5$4Z(&EB87-E('1E<W1I;F<@9&]N92!U;F1E<B!02%`@-2X@(&EB87-E('5N
M9&5R(%!(4"`T(&ES('5N<W1A8FQE(&]N(%=I;F1O=W,N"@H*5%E012`H9V5T
M3&ES=$]F*0IT86)L97,@("`@("`@("`@("T@("`@>"`@("`M("`@("T@("`@
M+2`@("!X("`@('@@("`@+2`@("!X("`@("T@("`@>"`@("`M("`@('@*=FEE
M=W,@("`@("`@("`@("`M("`@("T@("`@+2`@("`M("`@("T@("`@>"`@("!N
M("`@("T@("`@+2`@("`M("`@('@@("`@+2`@("!X"G5S97)S("`@("`@("`@
M("`@+2`@("`M("`@("T@("`@+2`@("`M("`@("T@("`@>"`@("`M("`@("T@
M("`@+2`@("!X("`@("T@("`@+0ID871A8F%S97,@("`@("`@("T@("`@+2`@
M("`M("`@("T@("`@+2`@("`M("`@('@@("`@+2`@("`M("`@("T@("`@>"`@
M("`M("`@("T*9G5N8W1I;VYS("`@("`@("`M("`@("T@("`@+2`@("`M("`@
M("T@("`@+2`@("`M("`@("T@("`@+2`@("`M("`@('@@("`@+2`@("`M"@H*
M5&5S="!#;VYF;W)M86YC90HM+2TM+2TM+2TM+2TM+2TM"E-Y;6)O;',Z"B`@
M("!O("`]("!497-T('!A<W-E9`H@("`@6"`@/2`@5&5S="!F86EL960*("`@
M($X@(#T@(%1E<W0@9F%I;&5D(&1U92!T;R!$0DU3(&YO="!C;VYS:61E<FEN
M9R!S;VUE=&AI;F<@86X@97)R;W(*("`@($4@(#T@(%1E<W0@9F%I;&5D(&1U
M92!T;R!P<F]B;&5M('=I=&@@4$A0(&5X=&5N<VEO;@H*("`@("`@("`@("`@
M("`@("`@("!F8G-Q;"`@("`@(&EF>"`@("`@(&US<W%L("`@("!M>7-Q;&D@
M("`@(&]D8F,@("`@('-Q;&ET90H@("`@("`@("`@("`@("!D8F%S92`@?"`@
M:6)A<V4@('P@(&US<6P@("!\("!M>7-Q;"`@?"`@(&]C:3@@('P@('!G<W%L
M("!\("!S>6)A<V4*,#%C;VYN96-T("`@("`@("`M("`@("T@("`@;R`@("!O
M("`@("T@("`@;R`@("!O("`@("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M(`HP,F9E=&-H("`@("`@("`@("T@("`@+2`@("!O("`@(&\@("`@+2`@("!O
M("`@(&\@("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\*,#-S:6UP;&5Q
M=65R>2`@("`M("`@("T@("`@;R`@("!O("`@("T@("`@;R`@("!O("`@("T@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O"C`T;G5M8V]L<R`@("`@("`@+2`@
M("`M("`@(&\@("`@;R`@("`M("`@(&\@("`@;R`@("`M("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;PHP-7-E<75E;F-E<R`@("`@("T@("`@+2`@("!O("`@
M(&\@("`@+2`@("!O("`@(&\@("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\*,#9P<F5P97AE8R`@("`@("`M("`@("T@("`@;R`@("!O("`@("T@("`@
M;R`@("!O("`@("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C`X869F96-T
M961R;W=S("`@+2`@("`M("`@(%@@("`@;R`@("`M("`@(&\@("`@;R`@("`M
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHP.6YU;7)O=W,@("`@("`@("T@
M("`@+2`@("!8("`@(%@@("`@+2`@("!O("`@(&\@("`@+2`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\*,3!E<G)O<FUA<"`@("`@("`M("`@("T@("`@;R`@
M("!.("`@("T@("`@12`@("!.("`@("T@("`@;R`@("!O("`@(&\@("`@3B`@
M("!%"C$Q=')A;G-A8W1I;VYS("`@+2`@("`M("`@(&\@("`@+2`@("`M("`@
M(&\@("`@6"`@("`M("`@(&\@("`@;R`@("!O("`@("T@("`@;PHQ,VQI;6ET
M("`@("`@("`@("T@("`@+2`@("!O("`@(&\@("`@+2`@("!O("`@(&\@("`@
M+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\*,31F971C:&UO9&5?;V)J92`M
M("`@("T@("`@;R`@("!O("`@("T@("`@;R`@("!O("`@("T@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O"C$U<75O=&4@("`@("`@("`@+2`@("`M("`@(&\@
M("`@6"`@("`M("`@(&\@("`@;R`@("`M("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;PHQ-G1A8FQE:6YF;R`@("`@("T@("`@+2`@("!O("`@(%@@("`@+2`@
M("!O("`@(&\@("`@+2`@("!O("`@("T@("`@;R`@("`M("`@(&\*,3=Q=65R
M>2`@("`@("`@("`M("`@("T@("`@6"`@("!O("`@("T@("`@;R`@("!O("`@
M("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C$X9V5T("`@("`@("`@("`@
M+2`@("`M("`@(%@@("`@;R`@("`M("`@(&\@("`@;R`@("`M("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;PH*3D]413H@:6)A<V4@=&5S=&EN9R!D;VYE('5N
M9&5R(%!(4"`U+B`@:6)A<V4@=6YD97(@4$A0(#0@:7,@=6YS=&%B;&4@;VX@
M5VEN9&]W<RX*"DY/5$4Z(&=E=$%L;"@I(&%N9"!G971!<W-O8R@I(&-R87-H
M97,@4$A0(#4@=VAE;B!U<VEN9R!$0E]&151#2$U/1$5?3T)*14-4+@H@("`@
M("!3964@:'1T<#HO+V)U9W,N<&AP+FYE="\_:60],C<Q,C,*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O1$(O
M9&]C+U1%4U1%4E,`````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$Q,C(Q`#$P-#$W,S8S,#`T`#`R,#,W,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````]/3T]/3T]/3T]/3T]/3T]/3T]"DA/
M5R!43R!415-4(%!%05(@1$(*/3T]/3T]/3T]/3T]/3T]/3T]/0H*)$ED.B!4
M15-415)3+'8@,2XQ-B`R,#`T+S`R+S$Y(#(Q.C4T.C,Q(&1A;FEE;&,@17AP
M("0*"@I)3E123T150U1)3TX*/3T]/3T]/3T]/3T]"@I4:&5S92!A<F4@:6YS
M=')U8W1I;VYS(&9O<B!T97-T:6YG(%!%05(@1$(@;VX@82!7:6YD;W=S(&UA
M8VAI;F4@=7-I;F<@80I#>6=W:6X@0F%S:"!S:&5L;"X@($%D:G5S="!T:&4@
M<&%T:',@86YD(&-O;6UA;F1S('1O(&UA=&-H('EO=7(@<WES=&5M+@I4:&ES
M(&-O;F9I9W5R871I;VX@:7,@=7-E9"!B96-A=7-E('1H97-E('!R96-I<V4@
M<W1E<',@87)E(&MN;W=N('1O('=O<FLN"@I.3U1%.B`@66]U(&UU<W0@;&]G
M(&]N(&%S(&$@=7-E<B!W:&EC:"!H87,@<&5R;6ES<VEO;G,@=&\@;6]D:69Y
M('1H90IC;VYT96YT<R!O9B!Y;W5R(%!(4"!E>&5C=71A8FQE)W,@9&ER96-T
M;W)Y+B`@5&AI<R!I<R!N96-E<W-A<GD@9F]R(&)O=&@*8V]N9FEG=7)I;F<@
M04Y$(')U;FYI;F<@=&AE('1E<W0@<WES=&5M+@H*"DE.4U1!3$Q!5$E/3@H]
M/3T]/3T]/3T]/3T*"D]B=&%I;B!02%`G<R!497-T($9R86UE=V]R:PHM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*268@>6]U(&1O;B=T(&AA=F4@4$A0
M)W,@=&5S="!F<F%M97=O<FLL('EO=2!N965D('1O(&]B=&%I;B!I="X@(%1H
M97-E"G-T97!S(&EN8VQU9&4@8VAA;F=I;F<@=&AE('=O<FMI;F<@9&ER96-T
M;W)Y+"!D;W=N;&]A9&EN9R!R=6XM=&5S=',N<&AP"G9I82!#5E,@86YD(&-O
M<'EI;F<@=&AE(&9I;&4@:6YT;R!P;&%C92X@($-H86YG92!T:&4@<F5V:7-I
M;VX@9FQA9R!I;B!T:&4*0U93(&-O;6UA;F0@87,@87!P<F]P<FEA=&4@9F]R
M('EO=7(@<')E<V5N="!V97)S:6]N(&]F(%!(4"X*"B!C9"!C.B]P<F]G<F%^
M,2]P:'`*(&-V<R`M9"`Z<'-E<G9E<CIC=G-R96%D0&-V<RYP:'`N;F5T.B]R
M97!O<VET;W)Y(&QO9VEN("`@(R!P87-S=V]R9"!I<R!P:'!F:0H@8W9S("UD
M(#IP<V5R=F5R.F-V<W)E861`8W9S+G!H<"YN970Z+W)E<&]S:71O<GD@8V\@
M+7(@4$A07S1?,R!<"B`@("`@+60@=&5S="!P:'`M<W)C+W)U;BUT97-T<RYP
M:'`*(&-P('1E<W0O<G5N+71E<W1S+G!H<"`N"B!R;2`M<F8@=&5S=`H*"D]B
M=&%I;B!$0B!A;F0@:71S(%1E<W0@1G)A;65W;W)K"BTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"D-R96%T92!A(&QO8V%T:6]N('1O('-T;W)E
M('1H92!T97-T(&EN<W1A;&QA=&EO;B!O9B!$0B!A;F0@:71S('1E<W0*<V-R
M:7!T<RX*"B!M:V1I<B!D.B]P96%R=&5S=`H@8V0@9#HO<&5A<G1E<W0*(&-V
M<R`M9"`Z<'-E<G9E<CIC=G-R96%D0&-V<RYP:'`N;F5T.B]R97!O<VET;W)Y
M(&-O("U0('!E87(O1$(*"E=E(&%S<W5M92!Y;W4@86QR96%D>2!H879E('1H
M92!014%2(&)A<V4@<&%C:V%G92!I;G-T86QL960N("!)9B!Y;W4*9&]N)W0L
M('EO=2!W:6QL(&YE960@=&\@9&\@<V\L(&)U="!T:&4@:6YS=')U8W1I;VYS
M(&9O<B!D;VEN9R!T:&%T"F%R92!B97EO;F0@=&AE('-C;W!E(&]F('1H:7,@
M9&]C=6UE;G0N"@H*0V]P>2!T:&4@4W1A<G1E<B!3:&5L;"!38W)I<'0@86YD
M($5D:70@=&AE(%!A=&AS"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+0I4;R!M86ME('-T87)T:6YG('5P(&5A8V@@
M=&5S="!R=6X@96%S:65R+"!W92!H879E(&EN8VQU9&5D('1W;R!S:&5L;`IS
M8W)I<'1S+B`@5&AE(&]R:6=I;F%L(&9I;&5S(&%R92!N86UE9"`B<G5N+F-V
M<R(N("!4:&5Y(&YE960@=&\@8F4*<F5N86UE9"!T;R`B<G5N(B!S;R!#5E,@
M=V]N)W0@8F]T:&5R('EO=2!W:71H('1R86-K:6YG('1H96TN("!4:&5N+`IT
M:&4@<&%T:',@86YD(&9I;&4@;F%M97,@:6X@=&AE;2!N965D('1O(&)E('-E
M="!T;R!T:&]S92!U<V5D(&)Y"GEO=7(@<WES=&5M+@H*(&-D('!E87(O1$(O
M=&5S=',*(&-P(')U;BYC=G,@<G5N"B!C:&UO9"`W-34@<G5N"B!V:2!R=6X*
M"B!C9"!D<FEV97(*(&-P(')U;BYC=G,@<G5N"B!C:&UO9"`W-34@<G5N"B!V
M:2!R=6X*"@I#;W!Y('1H92!3971U<"!&:6QE(&%N9"!%9&ET('1H92!$4TXG
M<PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I4:&4@
M=&5S="!S=6ET92!C;VYT86EN<R!A(&9I;&4@=&AA="!S=&]R97,@=&AE($13
M3B=S(&YE961E9"!T;PIC;VYN96-T('1O('EO=7(@9&%T86)A<V4N("!4:&4@
M;W)I9VEN86P@9FEL92!I<R`B<V5T=7`N:6YC+F-V<R(*86YD(&ET(&YE961S
M('1O(&)E(')E;F%M960@(G-E='5P+FEN8R(@<V\@0U93('=O;B=T('1R86-K
M(&ET+@I4:&5N('EO=2=L;"!N965D('1O(&5D:70@=&AE($133B=S(&EN(&ET
M+@H*(&-P('-E='5P+FEN8RYC=G,@<V5T=7`N:6YC"B!V:2!S971U<"YI;F,*
M"@I254X@5$A%(%1%4U13"CT]/3T]/3T]/3T]/3T*"E1O(')U;B!A;&P@=&5S
M=',Z("`N+W)U;@I4;R!R=6X@;VYE('1E<W0Z("`@+B]R=6X@/'1E<W0@;F%M
M93XN<&AP=`I%>&%M<&QE.B`@("`@("`@("`@+B]R=6X@9&)?<&%R<V5D<VXN
M<&AP=`H*"E1E<W0@5'EP97,@86YD($QO8V%T:6]N<PHM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*=&5S=',@("`@("`@("`@("`@0V]M;6]N(%!%05(@1$(@
M=&5S=',*=&5S=',O9')I=F5R("`@("`@0V]M;6]N('1E<W1S(&9O<B!A;&P@
M=&AE(&1R:79E<G,*"@I297-U;'1S(&%N9"!7:&%T(%1O($1O(%=I=&@@5&AE
M;0HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I%86-H('1E<W0@
M=&AA="!F86EL<R!G96YE<F%T97,@82`N<&AP("AW:&EC:"!Y;W4@8V%N(&5X
M96-U=&4I+"!A("YE>'`**'1H92!E>'!E8W1E9"!O=71P=70I+"!A("YO=70@
M*'1H92!T97-T(&]U='!U="D@86YD(&$@+F1I9F8@*&$@9&EF9B`M=0IF<F]M
M('1H92`N97AP(&%N9"`N;W5T(&9I;&5S*2X*"DEF('EO=2!R=6X@=&AE('1E
M<W1S+"!P;&5A<V4@<F5P;W)T(&]R(&9I;&P@=&AE(%1%4U0@0T].1D]234%.
M0T4@=&%B;&4*:6X@=&AE(%-405154R!D;V-U;65N="X@($)E9F]R92!A;GD@
M8V]M;6ET('1O($-64R!B92!S=7)E('1O(')U;B!T:&4*=&5S=',@86YD(&YO
M=&AI;F<@9V]T(&)R;VME;B!W:71H('1H92!C:&%N9V4N"@I)9B!Y;W4@9V5T
M('1H92!M97-S86=E(")32TE0(BP@;65A;G,@=&AA="!T:&4@=&5S="!I="=S
M(&YO="!E>&5C=71E9"X*3&]O:R!A="!T:&4@1$(O=&5S=',O9')I=F5R+W-K
M:7!I9BYI;F,@=&\@<V5E('=H870G<R!T:&4@<')O8FQE;0HH<')O8F%B;'D@
M82!C;VYN96-T:6]N('!R;V)L96TI+@H*"D1"(%1%4U1%4B!-051225@*/3T]
M/3T]/3T]/3T]/3T]/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9B<W%L("`@(&EF>"`@("!M<W-Q;"`@(&UY<W%L:2`@(&]D8F,@("!S<6QI
M=&4*5$535$52("`@("`@("`@("`@("`@("`@("`@(&1B87-E('P@:6)A<V4@
M?"`@;7-Q;"!\(&UY<W%L('P@(&]C:3@@?"!P9W-Q;"!\('-Y8F%S90I*;VAN
M($AO<G1O;B`@("`@("`@("`@("`@("`@("`M("`@+2`@("T@("!8("`@+2`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M"E1I;2!::6-K=7,@("`@
M("`@("`@("`@("`@("`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M
M("`@6"`@("T@("`M("`@+2`@("T*5&EM(%!A<FMI;B`@("`@("`@("`@("`@
M("`@("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@+2`@
M("T@("`M("`@+0I0875L($=A<F1I;F5R("`@("`@("`@("`@("`@("`M("`@
M+2`@("T@("!8("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M
M"G!E=&5R=V)`:6%F<FEC82YC;VT@("`@("`@("`@("T@("`M("`@+2`@(%@@
M("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T*1&%N:65L+"!!
M9&%M("`@("`@("`@("`@("`@("`@+2`@("T@("`M("`@+2`@("T@("`M("`@
M+2`@("T@("!8("`@+2`@("T@("`M("`@+0IS>FEI0'-Z:6ES;V9T+F-O;2`@
M("`@("`@("`@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@
M("!8N2`@+2`@("T@("`M"FIM:#-`;&EN=7AF<F5A:RYC;VT@("`@("`@("`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@
M+2`@("T*2V5V:6X@2&5N<FEK<V]N("`@("`@("`@("`@("`@+2`@("T@("`M
M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@+2`@("T@("`M("`@+0I3=&EG
M($)A:VME;B`@("`@("`@("`@("`@("`@("`M("`@+2`@("T@("`M("`@+2`@
M("T@("!8("`@+2`@("T@("`M("`@6"`@("T@("`M"D-H=6-K($AA9V5N8G5C
M:"`@("`@("`@("`@("`@("T@("`M("`@+2`@("T@("`M("`@6"`@("T@("`M
M("`@+2`@("T@("`M("`@+2`@("T*3'5D;W9I8V\@36%G;F]C879A;&QO("`@
M("`@("`@+2`@("T@("!8("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@
M("T@("`M("`@+0I$86YI96P@0V]N=FES<V]R("`@("`@("`@("`@("`M("`@
M+2`@(%@@("`M("`@+2`@(%@@("!8("`@+2`@(%@@("!8LB`@6"`@(%@@("!8
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(`I-25-324Y'(%1%4U1%
M4E,@("`@("`@("`@("`@("`M("`@6"`@("T@("`M("`@6"`@("T@("`M("`@
M6"`@("T@("`M("`@+2`@("T@("`M"@I#;VUM96YT<SH*"ELQ73H@3T1"0R!U
M<VEN9R!)0DT@1$(R"ELR73H@3T1"0R!U<VEN9R!)0DT@1$(R(&%N9"!-4R!!
M8V-E<W,*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+T1"+V1O8R]-04E.5$%)3D524P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3(P,P`Q,#0Q-S,V,S`P-``P,C$P,3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````36%I;G1A:6YE<G,@9F]R
M($1"(&1A=&%B87-E(&)A8VME;F1S+V1R:79E<G,Z"@II8F%S92`@("`@.B!,
M=61O=FEC;R!-86=N;V-A=F%L;&\@/&QU9&]`<W5M871R87-O;'5T:6]N<RYC
M;VT^"FUS<6P@("`@("`Z(`IM<W-Q;"`@("`@.B!&<F%N:R!-+B!+<F]M86YN
M(#QF<F%N:T!K<F]M86YN+FEN9F\^"FUY<W%L("`@("`Z(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X*;7ES<6QI"2`@.B!#:&%I;&QA;B!.:6-O;&%S(#QN
M:6-O<T!P:'`N;F5T/@IO8VDX("`@("`@.B!4;VUA<R!6+E8N0V]X(#QC;WA`
M:61E8VYE="YC;VT^"F]D8F,@("`@("`Z(%1O;6%S(%8N5BY#;W@@/&-O>$!I
M9&5C;F5T+F-O;3X*<&=S<6P@("`@(#H@4G5I($AI<F]K87=A(#QR=6E?:&ER
M;VMA=V%`>6)B+FYE+FIP/@H@("`@("`@("`@("!3=&EG($)A:VME;B`\<W-B
M0'!H<"YN970^"G-Y8F%S92`@("`Z(`II9G@@("`@("`@.B!4;VUA<R!6+E8N
M0V]X(#QC;WA`:61E8VYE="YC;VT^"F9B<W%L("`@("`Z($9R86YK($TN($MR
M;VUA;FX@/&9R86YK0&MR;VUA;FXN:6YF;SX*9&)A<V4@("`@(#H@5&]M87,@
M5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@IL9&%P("`@("`@.B!,=61O=FEC
M;R!-86=N;V-A=F%L;&\@/&QU9&]`<W5M871R87-O;'5T:6]N<RYC;VT^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+TQO9R\`````````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-``P,3<P,3(`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S
M,#`T`#`Q-S<T,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],
M;V<O9&]C<R]E>&%M<&QE<R\`````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,#0`,#(Q-38P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W-Q;&ET92YP:'``
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<U,0`Q,#0Q-S,V,S`P-``P,C,U-S(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HO*B!#<F5A=&EN9R!A(&YE
M=R!D871A8F%S92!C;VYN96-T:6]N+B`J+PHD8V]N9B`](&%R<F%Y*"=F:6QE
M;F%M92<@/3X@)VQO9RYD8B<L("=M;V1E)R`]/B`P-C8V+"`G<&5R<VES=&5N
M="<@/3X@=')U92D["B1L;V=G97(@/28@3&]G.CIF86-T;W)Y*"=S<6QI=&4G
M+"`G;&]G7W1A8FQE)RP@)VED96YT)RP@)&-O;F8I.PHD;&]G9V5R+3YL;V<H
M)VQO9V=I;F<@86X@979E;G0G+"!014%27TQ/1U]705).24Y'*3L*"B\J(%5S
M:6YG(&%N(&5X:7-T:6YG(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B1D8B`]
M('-Q;&ET95]O<&5N*"=L;V<N9&(G+"`P-C8V+"`D97)R;W(I.PHD;&]G9V5R
M(#TF($QO9SHZ9F%C=&]R>2@G<W%L:71E)RP@)VQO9U]T86)L92<L("=I9&5N
M="<L("1D8BD["B1L;V=G97(M/FQO9R@G;&]G9VEN9R!A;B!E=F5N="<L(%!%
M05)?3$]'7U=!4DY)3D<I.PIS<6QI=&5?8VQO<V4H)&1B*3L*````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]P:'!?97)R;W)?:&%N9&QE<BYP:'``
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$T,#``,3`T,3<S-C,P,#0`,#(U-S4V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@)TQO9RYP:'`G.PH*9G5N8W1I;VX@97)R;W)(86YD;&5R*"1C;V1E
M+"`D;65S<V%G92P@)&9I;&4L("1L:6YE*0I["B`@("!G;&]B86P@)&QO9V=E
M<CL*"B`@("`O*B!-87`@=&AE(%!(4"!E<G)O<B!T;R!A($QO9R!P<FEO<FET
M>2X@*B\*("`@('-W:71C:"`H)&-O9&4I('L*("`@(&-A<V4@15]705).24Y'
M.@H@("`@8V%S92!%7U5315)?5T%23DE.1SH*("`@("`@("`D<')I;W)I='D@
M/2!014%27TQ/1U]705).24Y'.PH@("`@("`@(&)R96%K.PH@("`@8V%S92!%
M7TY/5$E#13H*("`@(&-A<V4@15]54T527TY/5$E#13H*("`@("`@("`D<')I
M;W)I='D@/2!014%27TQ/1U].3U1)0T4["B`@("`@("`@8G)E86L["B`@("!C
M87-E($5?15)23U(Z"B`@("!C87-E($5?55-%4E]%4E)/4CH*("`@("`@("`D
M<')I;W)I='D@/2!014%27TQ/1U]%4E(["B`@("`@("`@8G)E86L["B`@("!D
M969A=6QT.@H@("`@("`@("1P<FEO=&ET>2`](%!%05)?3$]'7TE.1D\["B`@
M("!]"@H@("`@)&QO9V=E<BT^;&]G*"1M97-S86=E("X@)R!I;B`G("X@)&9I
M;&4@+B`G(&%T(&QI;F4@)R`N("1L:6YE+`H@("`@("`@("`@("`@("`@("1P
M<FEO<FET>2D["GT*"B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O
M;&4G+"`G)RP@)VED96YT)RD["@IS971?97)R;W)?:&%N9&QE<B@G97)R;W)(
M86YD;&5R)RD["G1R:6=G97)?97)R;W(H)U1H:7,@:7,@86X@:6YF;W)M871I
M;VX@;&]G(&UE<W-A9V4N)RP@15]54T527TY/5$E#12D["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]O8G-E<G9E<E]M86EL+G!H
M<```````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$R,3<`,3`T,3<S-C,P,#0`,#(U,3(P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@)TQO9R]O8G-E<G9E<BYP:'`G.PH*8VQA<W,@3&]G7V]B
M<V5R=F5R7VUA:6P@97AT96YD<R!,;V=?;V)S97)V97(*>PH@("`@=F%R("1?
M=&\@/2`G)SL*("`@('9A<B`D7W-U8FIE8W0@/2`G)SL*("`@('9A<B`D7W!A
M='1E<FX@/2`G)SL*"B`@("!F=6YC=&EO;B!,;V=?;V)S97)V97)?;6%I;"@D
M<')I;W)I='DL("1C;VYF*0H@("`@>PH@("`@("`@("\J($-A;&P@=&AE(&)A
M<V4@8VQA<W,@8V]N<W1R=6-T;W(N("HO"B`@("`@("`@)'1H:7,M/DQO9U]O
M8G-E<G9E<B@D<')I;W)I='DI.PH*("`@("`@("`O*B!#;VYF:6=U<F4@=&AE
M(&]B<V5R=F5R+B`J+PH@("`@("`@("1T:&ES+3Y?=&\@/2`D8V]N9ELG=&\G
M73L*("`@("`@("`D=&AI<RT^7W-U8FIE8W0@/2`D8V]N9ELG<W5B:F5C="==
M.PH@("`@("`@("1T:&ES+3Y?<&%T=&5R;B`]("1C;VYF6R=P871T97)N)UT[
M"B`@("!]"@H@("`@9G5N8W1I;VX@;F]T:69Y*"1E=F5N="D*("`@('L*("`@
M("`@("!I9B`H<')E9U]M871C:"@D=&AI<RT^7W!A='1E<FXL("1E=F5N=%LG
M;65S<V%G92==*2`A/2`P*2!["B`@("`@("`@("`@(&UA:6PH)'1H:7,M/E]T
M;RP@)'1H:7,M/E]S=6)J96-T+"`D979E;G1;)VUE<W-A9V4G72D["B`@("`@
M("`@?0H@("`@?0I]"@H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]C;VUP;W-I=&4N
M<&AP````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-C$`,3`T,3<S-C,P,#0`,#(T,C<Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&-O;G-O;&4@/2`F3&]G
M.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)U1%4U0G*3L*)&9I;&4@/2`F
M3&]G.CIS:6YG;&5T;VXH)V9I;&4G+"`G;W5T+FQO9R<L("=415-4)RD["@HD
M8V]M<&]S:71E(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VUP;W-I=&4G*3L*)&-O
M;7!O<VET92T^861D0VAI;&0H)&-O;G-O;&4I.PHD8V]M<&]S:71E+3YA9&1#
M:&EL9"@D9FEL92D["@HD8V]M<&]S:71E+3YL;V<H)U1H:7,@979E;G0@=VEL
M;"!B92!L;V=G960@=&\@8F]T:"!H86YD;&5R<RXG*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O9&ES<&QA>2YP:'``````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-#,P`#$P-#$W,S8S,#`T`#`R,S<S,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH)V5R<F]R7W!R97!E
M;F0G(#T^("<\9F]N="!C;VQO<CTB(V9F,#`P,"(^/'1T/B<L"B`@("`@("`@
M("`@("`@)V5R<F]R7V%P<&5N9"<@(#T^("<\+W1T/CPO9F]N=#XG*3L*)&QO
M9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G9&ES<&QA>2<L("<G+"`G)RP@)&-O
M;F8L(%!%05)?3$]'7T1%0E5'*3L*9F]R("@D:2`](#`[("1I(#P@,3`[("1I
M*RLI('L*("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D
M;V-S+V5X86UP;&5S+W-Y<VQO9RYP:'``````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#(S-``Q,#0Q-S,V,S`P-``P,C,V,#4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G
M+G!H<"<["@HD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=S>7-L;V<G+"!,
M3T=?3$]#04PP+"`G:61E;G0G*3L*9F]R("@D:2`](#`[("1I(#P@,3`[("1I
M*RLI('L*("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE
M<R]M86EL+G!H<```````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-#(`,3`T,3<S
M-C,P,#0`,#(S,C`W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&-O
M;F8@/2!A<G)A>2@G<W5B:F5C="<@/3X@)TEM<&]R=&%N="!,;V<@179E;G1S
M)RD["B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)VUA:6PG+"`G=V5B;6%S
M=&5R0&5X86UP;&4N8V]M)RP@)VED96YT)RP@)&-O;F8I.PIF;W(@*"1I(#T@
M,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT
M<GD@)&DB*3L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O9FEL92YP:'``
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S,P`#$P-#$W,S8S,#`T`#`R,S(P
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH
M)VUO9&4G(#T^(#`V,#`L("=T:6UE1F]R;6%T)R`]/B`G)5@@)7@G*3L*)&QO
M9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G9FEL92<L("=O=70N;&]G)RP@)VED
M96YT)RP@)&-O;F8I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@
M("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W-Q;"YP:'``````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#,S-``Q,#0Q-S,V,S`P-``P,C,P-C4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=D<VXG(#T^("=P
M9W-Q;#HO+VIO;D!L;V-A;&AO<W0K=6YI>"]L;V=S)RD["B1L;V=G97(@/2`F
M3&]G.CIS:6YG;&5T;VXH)W-Q;"<L("=L;V=?=&%B;&4G+"`G:61E;G0G+"`D
M8V]N9BD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D;&]G
M9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O
M9&]C<R]E>&%M<&QE<R]C;VYS;VQE+G!H<```````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`R,C4`,3`T,3<S-C,P,#0`,#(S-S(W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO
M9RYP:'`G.PH*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L
M("<G+"`G:61E;G0G*3L*9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*
M("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L
M97,O<&5A<E]E<G)O<E]H86YD;&5R+G!H<```````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,34T`#$P-#$W
M,S8S,#`T`#`R-C$R-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"F9U
M;F-T:6]N(&5R<F]R2&%N9&QE<B@D97)R;W(I"GL*("`@(&=L;V)A;"`D;&]G
M9V5R.PH*("`@("1M97-S86=E(#T@)&5R<F]R+3YG971-97-S86=E*"D["@H@
M("`@:68@*"%E;7!T>2@D97)R;W(M/F)A8VMT<F%C95LQ75LG9FEL92==*2D@
M>PH@("`@("`@("1M97-S86=E("X]("<@*"<@+B`D97)R;W(M/F)A8VMT<F%C
M95LQ75LG9FEL92==.PH@("`@("`@(&EF("@A96UP='DH)&5R<F]R+3YB86-K
M=')A8V5;,5U;)VQI;F4G72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@+CT@
M)R!A="!L:6YE("<@+B`D97)R;W(M/F)A8VMT<F%C95LQ75LG;&EN92==.PH@
M("`@("`@('T*("`@("`@("`D;65S<V%G92`N/2`G*2<["B`@("!]"@H@("`@
M)&QO9V=E<BT^;&]G*"1M97-S86=E+"`D97)R;W(M/F-O9&4I.PI]"@HD;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=I9&5N="<I
M.PH*4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-+
M+"`G97)R;W)(86YD;&5R)RD["E!%05(Z.G)A:7-E17)R;W(H)U1H:7,@:7,@
M86X@:6YF;W)M871I;VX@;&]G(&UE<W-A9V4N)RP@4$5!4E],3T=?24Y&3RD[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O
M97AA;7!L97,O97)R;W)?;&]G+G!H<```````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C4Q
M`#$P-#$W,S8S,#`T`#`R-#(U-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP
M)SL*"B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V5R<F]R7VQO9R<L(%!%
M05)?3$]'7U194$5?4UE35$5-+"`G:61E;G0G*3L*9F]R("@D:2`](#`[("1I
M(#P@,3`[("1I*RLI('L*("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I
M(BD["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W=I
M;BYP:'`````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,R,``Q,#0Q-S,V,S`P
M-``P,C,P-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`]
M(&%R<F%Y*"=T:71L92<@/3X@)U-A;7!L92!,;V<@3W5T<'5T)RD["B1L;V=G
M97(@/2`F3&]G.CIS:6YG;&5T;VXH)W=I;B<L("=,;V=7:6YD;W<G+"`G:61E
M;G0G+"`D8V]N9BD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@
M("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]N=6QL+G!H<```````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`R,#4`,3`T,3<S-C,P,#0`,#(S,C,U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&QO9V=E<B`]("9,;V<Z.G-I
M;F=L971O;B@G;G5L;"<I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@
M>PH@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O3&]G+V1O8W,O9W5I9&4N='AT````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,3`V-#`W`#$P-#$W,S8S,#`T`#`R,38P-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````]/3T]/3T]/3T]/3T]/3T]
M/0H@5&AE($QO9R!086-K86=E"CT]/3T]/3T]/3T]/3T]/3T]"@HM+2TM+2TM
M+2TM+2TM+2TM+2TM+0H@57-E<B!$;V-U;65N=&%T:6]N"BTM+2TM+2TM+2TM
M+2TM+2TM+2TM"@HZ075T:&]R.B`@("`@("`@2F]N(%!A<FES90HZ0V]N=&%C
M=#H@("`@("`@:F]N0'!H<"YN970*.D1A=&4Z("`@("`@("`@("1$871E.B`R
M,#`T+S`Q+S,Q(#(Q.C0X.C$V("0*.E)E=FES:6]N.B`@("`@("12979I<VEO
M;CH@,2XQ,"`D"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"BXN('-E8W1I;VXM
M;G5M8F5R:6YG.CH*"E5S:6YG($QO9R!(86YD;&5R<PH]/3T]/3T]/3T]/3T]
M/3T]/3T*"E1H92!,;V<@<&%C:V%G92!I<R!I;7!L96UE;G1E9"!A<R!A(&9R
M86UE=V]R:R!T:&%T('-U<'!O<G1S('1H92!N;W1I;VX@;V8*8F%C:V5N9"US
M<&5C:69I8R!L;V<@:&%N9&QE<G,N("!4:&4@8F%S92!L;V=G:6YG(&]B:F5C
M="`H9&5F:6YE9"!B>2!T:&4@8$QO9PIC;&%S<V!?*2!I<R!P<FEM87)I;'D@
M86X@86)S=')A8W0@:6YT97)F86-E('1O('1H92!C=7)R96YT;'D@8V]N9FEG
M=7)E9`IH86YD;&5R+@H*02!W:61E('9A<FEE='D@;V8@:&%N9&QE<G,@87)E
M(&1I<W1R:6)U=&5D('=I=&@@=&AE($QO9R!P86-K86=E+"!A;F0L('-H;W5L
M9`IN;VYE(&]F('1H96T@9FET('EO=7(@87!P;&EC871I;VXG<R!N965D<RP@
M:70G<R!E87-Y('1O(&!W<FET92!Y;W5R(&]W;F!?7RX*"BXN(%],;V<@8VQA
M<W,Z(&AT='`Z+R]C=G,N<&AP+FYE="]C;RYP:'`O<&5A<B],;V<O3&]G+G!H
M<`I?7R!@0W5S=&]M($AA;F1L97)S8%\*"D-R96%T:6YG(&$@3&]G($]B:F5C
M=`HM+2TM+2TM+2TM+2TM+2TM+2TM+2T*5&AE<F4@87)E('1H<F5E('=A>7,@
M=&\@8W)E871E($QO9R!O8FIE8W1S.@H*("`@("T@57-I;F<@=&AE(&!@3&]G
M.CIF86-T;W)Y*"E@8"!M971H;V0*("`@("T@57-I;F<@=&AE(&!@3&]G.CIS
M:6YG;&5T;VXH*6!@(&UE=&AO9`H@("`@+2!$:7)E8W0@:6YS=&%N=&EA=&EO
M;@H*5&AE($9A8W1O<GD@365T:&]D"GY^?GY^?GY^?GY^?GY^?GY^?@I4:&4@
M8&!,;V<Z.F9A8W1O<GDH*6!@(&UE=&AO9"!I;7!L96UE;G1S('1H92!@1F%C
M=&]R>2!0871T97)N8%\N("!)="!A;&QO=W,*9F]R('1H92!P87)A;65T97)I
M>F5D(&-O;G-T<G5C=&EO;B!O9B!C;VYC<F5T92!,;V<@:6YS=&%N8V5S(&%T
M(')U;G1I;64N("!4:&4*9FER<W0@<&%R86UE=&5R('1O('1H92!@8$QO9SHZ
M9F%C=&]R>2@I8&`@;65T:&]D(&EN9&EC871E<R!T:&4@;F%M92!O9B!T:&4*
M8V]N8W)E=&4@:&%N9&QE<B!T;R!C<F5A=&4N("!4:&4@<F5S="!O9B!T:&4@
M<&%R86UE=&5R<R!W:6QL(&)E('!A<W-E9"!O;B!T;PIT:&4@:&%N9&QE<B=S
M(&-O;G-T<G5C=&]R("AS964@8$-O;F9I9W5R:6YG(&$@2&%N9&QE<F!?(&)E
M;&]W*2X*"E1H92!N97<@8&!,;V=@8"!I;G-T86YC92!I<R!R971U<FYE9"!B
M>2!R969E<F5N8V4N"@HZ.@H*("`@(')E<75I<F5?;VYC92`G3&]G+G!H<"<[
M"@H@("`@)&-O;G-O;&4@/2`F3&]G.CIF86-T;W)Y*"=C;VYS;VQE)RP@)R<L
M("=415-4)RD["B`@("`D8V]N<V]L92T^;&]G*"=,;V=G:6YG('1O('1H92!C
M;VYS;VQE+B<I.PH*("`@("1F:6QE(#T@)DQO9SHZ9F%C=&]R>2@G9FEL92<L
M("=O=70N;&]G)RP@)U1%4U0G*3L*("`@("1F:6QE+3YL;V<H)TQO9V=I;F<@
M=&\@;W5T+FQO9RXG*3L*"BXN(%]&86-T;W)Y(%!A='1E<FXZ(&AT='`Z+R]W
M=W<N<&AP<&%T=&5R;G,N8V]M+VEN9&5X+G!H<"]A<G1I8VQE+V%R=&EC;&5V
M:65W+S0Y+S$O,2\*"E1H92!3:6YG;&5T;VX@365T:&]D"GY^?GY^?GY^?GY^
M?GY^?GY^?GY^"E1H92!@8$QO9SHZ<VEN9VQE=&]N*"E@8"!M971H;V0@:6UP
M;&5M96YT<R!T:&4@8%-I;F=L971O;B!0871T97)N8%\N("!4:&4*<VEN9VQE
M=&]N('!A='1E<FX@96YS=7)E<R!T:&%T(&]N;'D@82!S:6YG;&4@:6YS=&%N
M8V4@;V8@82!G:79E;B!L;V<@='EP92!A;F0*8V]N9FEG=7)A=&EO;B!I<R!E
M=F5R(&-R96%T960N("!4:&ES(&AA<R!T=V\@8F5N969I=',Z(&9I<G-T+"!I
M="!P<F5V96YT<PID=7!L:6-A=&4@8&!,;V=@8"!I;G-T86YC97,@9G)O;2!B
M96EN9R!C;VYS=')U8W1E9"P@86YD+"!S96-O;F0L(&ET(&=I=F5S(&%L;`IO
M9B!Y;W5R(&-O9&4@86-C97-S('1O('1H92!S86UE(&!@3&]G8&`@:6YS=&%N
M8V4N("!4:&4@;&%T=&5R(&ES(&5S<&5C:6%L;'D*:6UP;W)T86YT('=H96X@
M;&]G9VEN9R!T;R!F:6QE<R!B96-A=7-E(&]N;'D@82!S:6YG;&4@9FEL92!H
M86YD;&5R('=I;&P@;F5E9`IT;R!B92!M86YA9V5D+@H*5&AE(&!@3&]G.CIS
M:6YG;&5T;VXH*6!@(&UE=&AO9"=S('!A<F%M971E<G,@;6%T8V@@=&AE(&!@
M3&]G.CIF86-T;W)Y*"E@8`IM971H;V0N("!4:&4@;F5W(&!@3&]G8&`@:6YS
M=&%N8V4@:7,@<F5T=7)N960@8GD@<F5F97)E;F-E+@H*.CH*"B`@("!R97%U
M:7)E7V]N8V4@)TQO9RYP:'`G.PH*("`@("\J(%-A;64@8V]N<W1R=6-T:6]N
M('!A<F%M971E<G,@*B\*("`@("1A(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS
M;VQE)RP@)R<L("=415-4)RD["B`@("`D8B`]("9,;V<Z.G-I;F=L971O;B@G
M8V]N<V]L92<L("<G+"`G5$535"<I.PH*("`@(&EF("@D82`]/3T@)&(I('L*
M("`@("`@("!E8VAO("<D82!A;F0@)&(@<&]I;G0@=&\@=&AE('-A;64@3&]G
M(&EN<W1A;F-E+B<@+B`B7&XB.PH@("`@?0H*("`@("\J($1I9F9E<F5N="!C
M;VYS=')U8W1I;VX@<&%R86UE=&5R<R`J+PH@("`@)&,@/2`F3&]G.CIS:6YG
M;&5T;VXH)V-O;G-O;&4G+"`G)RP@)U1%4U0Q)RD["B`@("`D9"`]("9,;V<Z
M.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G5$535#(G*3L*"B`@("!I9B`H
M)&,@(3T]("1D*2!["B`@("`@("`@96-H;R`G)&,@86YD("1D('!O:6YT('1O
M(&1I9F9E<F5N="!,;V<@:6YS=&%N8V5S+B<@+B`B7&XB.PH@("`@?0H*+BX@
M7U-I;F=L971O;B!0871T97)N.B!H='1P.B\O=W=W+G!H<'!A='1E<FYS+F-O
M;2]I;F1E>"YP:'`O87)T:6-L92]A<G1I8VQE=FEE=R\V+S$O,2\*"D1I<F5C
M="!);G-T86YT:6%T:6]N"GY^?GY^?GY^?GY^?GY^?GY^?GY^"DET(&ES(&%L
M<V\@<&]S<VEB;&4@=&\@9&ER96-T;'D@:6YS=&%N=&EA=&4@8V]N8W)E=&4@
M8&!,;V=@8"!H86YD;&5R"FEN<W1A;F-E<RX@($AO=V5V97(L('1H:7,@;65T
M:&]D(&ES("HJ;F]T(')E8V]M;65N9&5D*BH@8F5C875S92!I="!C<F5A=&5S
M(&$*=&EG:'1E<B!C;W5P;&EN9R!B971W965N('EO=7(@87!P;&EC871I;VX@
M8V]D92!A;F0@=&AE($QO9R!P86-K86=E('1H86X@:7,*;F5C97-S87)Y+B`@
M57-E(&]F(&!T:&4@9F%C=&]R>2!M971H;V1@7R!O<B!@=&AE('-I;F=L971O
M;B!M971H;V1@7R!I<PIP<F5F97)R960N"@H*0V]N9FEG=7)I;F<@82!(86YD
M;&5R"BTM+2TM+2TM+2TM+2TM+2TM+2TM+0I!(&QO9R!H86YD;&5R)W,@8V]N
M9FEG=7)A=&EO;B!I<R!D971E<FUI;F5D(&)Y('1H92!A<F=U;65N=',@=7-E
M9"!I;B!I=',*8V]N<W1R=6-T:6]N+B`@2&5R92=S(&%N(&]V97)V:65W(&]F
M('1H;W-E('!A<F%M971E<G,Z.@H*("`@("\J(%5S:6YG('1H92!F86-T;W)Y
M(&UE=&AO9"`N+BX@*B\*("`@("9,;V<Z.F9A8W1O<GDH)&AA;F1L97(L("1N
M86UE+"`D:61E;G0L("1C;VYF+"`D;6%X3&5V96PI.PH*("`@("\J(%5S:6YG
M('1H92!S:6YG;&5T;VX@;65T:&]D("XN+B`J+PH@("`@)DQO9SHZ<VEN9VQE
M=&]N*"1H86YD;&5R+"`D;F%M92P@)&ED96YT+"`D8V]N9BP@)&UA>$QE=F5L
M*3L*"B`@("`O*B!5<VEN9R!D:7)E8W0@:6YS=&%N=&EA=&EO;B`N+BX@*B\*
M("`@(&YE=R!,;V=?:&%N9&QE<B@D;F%M92P@)&ED96YT+"`D8V]N9BP@)&UA
M>$QE=F5L*3L*"BLM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@
M4&%R86UE=&5R("`@("!\(%1Y<&4@("`@("!\($1E<V-R:7!T:6]N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]/3T]
M/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&`D:&%N9&QE<F!@("!\(%-T<FEN9R`@
M("!\(%1H92!T>7!E(&]F($QO9R!H86YD;&5R('1O(&-O;G-T<G5C="X@(%1H
M:7,@("!\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\('!A<F%M971E
M<B!I<R!O;FQY(&%V86EL86)L92!W:&5N(&!T:&4@9F%C=&]R>2!\"GP@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\(&UE=&AO9&!?(&]R(&!T:&4@<VEN
M9VQE=&]N(&UE=&AO9&!?(&%R92!U<V5D+B!\"BLM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"GP@8&`D;F%M96!@("`@("!\(%-T<FEN9R`@("!\
M(%1H92!N86UE(&]F('1H92!L;V<@<F5S;W5R8V4@=&\@=VAI8V@@=&AE("`@
M("!\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\(&5V96YT<R!W:6QL
M(&)E(&QO9V=E9"X@(%1H92!U<V4@;V8@=&AI<R!V86QU92!\"GP@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\(&ES(&1E=&5R;6EN960@8GD@=&AE(&AA
M;F1L97(G<R!I;7!L96UE;G1A=&EO;BY\"GP@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\($ET(&1E9F%U;'1S('1O(&%N(&5M<'1Y('-T<FEN9RX@("`@
M("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@8&`D:61E;G1@8"`@("!\(%-T<FEN9R`@("!\($%N(&ED96YT:69I8V%T
M:6]N('-T<FEN9R!T:&%T('=I;&P@8F4@:6YC;'5D961\"GP@("`@("`@("`@
M("`@("!\("`@("`@("`@("!\(&EN(&%L;"!L;V<@979E;G1S(&QO9V=E9"!B
M>2!T:&ES(&AA;F1L97(N("`@("!\"GP@("`@("`@("`@("`@("!\("`@("`@
M("`@("!\(%1H:7,@=F%L=64@9&5F875L=',@=&\@86X@96UP='D@<W1R:6YG
M(&%N9"!C86Y\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\(&)E(&-H
M86YG960@870@<G5N=&EM92!U<VEN9R!T:&4@8&!S971)9&5N="@I8&!\"GP@
M("`@("`@("`@("`@("!\("`@("`@("`@("!\(&UE=&AO9"X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&`D8V]N9F!@("`@("!\($%R<F%Y("`@
M("!\($%S<V]C:6%T:79E(&%R<F%Y(&]F(&ME>2UV86QU92!P86ER<R!T:&%T
M(&%R92!\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\('5S960@=&\@
M<W!E8VEF>2!A;GD@:&%N9&QE<BUS<&5C:69I8R!S971T:6YG<RY\"BLM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&`D;&5V96Q@8"`@("!\
M($EN=&5G97(@("!\($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG
M('1H:7,@;&5V96PN("!\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\
M(%1H:7,@=F%L=64@9&5F875L=',@=&\@8&!014%27TQ/1U]$14)51V!@+B`@
M("!\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\(%-E92!@3&]G($QE
M=F5L<V!?(&%N9"!@3&]G($QE=F5L($UA<VMS8%\N("`@("!\"BLM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@H*3&]G9VEN9R!A;B!%=F5N=`HM
M+2TM+2TM+2TM+2TM+2TM"D5V96YT<R!A<F4@;&]G9V5D('5S:6YG('1H92!@
M8&QO9R@I8&`@;65T:&]D.CH*"B`@("`D;&]G9V5R+3YL;V<H)TUE<W-A9V4G
M+"!014%27TQ/1U].3U1)0T4I.PH*5&AE(&9I<G-T(&%R9W5M96YT(&-O;G1A
M:6YS('1H92!L;V<@979E;G0G<R!M97-S86=E+B`@179E;B!T:&]U9V@@=&AE
M(&5V96YT(&ES"F%L=V%Y<R!L;V=G960@87,@82!S=')I;F<L(&ET(&ES('!O
M<W-I8FQE('1O('!A<W,@86X@;V)J96-T('1O('1H92!@8&QO9R@I8&`*;65T
M:&]D+B`@268@=&AE(&]B:F5C="!I;7!L96UE;G1S(&$@8&!G9713=')I;F<H
M*6!@(&UE=&AO9"P@82!@8'1O4W1R:6YG*"E@8`IM971H;V0@;W(@6F5N9"!%
M;F=I;F4@,B=S('-P96-I86P@8&!?7W1O4W1R:6YG*"E@8"!C87-T:6YG(&UE
M=&AO9"P@:70@=VEL;"!B90IU<V5D('1O(&1E=&5R;6EN92!T:&4@;V)J96-T
M)W,@<W1R:6YG(')E<')E<V5N=&%T:6]N+B`@3W1H97)W:7-E+"!T:&4*8'-E
M<FEA;&EZ961@7R!F;W)M(&]F('1H92!O8FIE8W0@=VEL;"!B92!L;V=G960N
M"@I4:&4@<V5C;VYD+"!O<'1I;VYA;"!A<F=U;65N="!S<&5C:69I97,@=&AE
M(&QO9R!E=F5N="=S('!R:6]R:71Y+B`@4V5E('1H90I@3&]G($QE=F5L<V!?
M('1A8FQE(&9O<B!T:&4@8V]M<&QE=&4@;&ES="!O9B!P<FEO<FET:65S+B`@
M5&AE(&1E9F%U;'0@<')I;W)I='D*:7,@4$5!4E],3T=?24Y&3RX*"E1H92!@
M8&QO9R@I8&`@;65T:&]D('=I;&P@<F5T=7)N(&!@=')U96!@(&EF('1H92!E
M=F5N="!W87,@<W5C8V5S<V9U;&QY"FQO9V=E9"X*"B)3:&]R=&-U="(@;65T
M:&]D<R!A<F4@86QS;R!A=F%I;&%B;&4@9F]R(&QO9V=I;F<@86X@979E;G0@
M870@82!S<&5C:69I8R!L;V<*;&5V96PN("!3964@=&AE(&!,;V<@3&5V96QS
M8%\@=&%B;&4@9F]R('1H92!C;VUP;&5T92!L:7-T+@H*+BX@7W-E<FEA;&EZ
M960Z(&AT='`Z+R]W=W<N<&AP+FYE="]S97)I86QI>F4*"@I,;V<@3&5V96QS
M"BTM+2TM+2TM+2T*5&AI<R!T86)L92!I<R!O<F1E<F5D(&)Y(&AI9VAE<W0@
M<')I;W)I='D@*&!@4$5!4E],3T=?14U%4D=@8"D@=&\@;&]W97-T"G!R:6]R
M:71Y("A@8%!%05)?3$]'7T1%0E5'8&`I+@H**RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*?"!,979E;"`@("`@("`@("`@("`@("`@?"!3:&]R
M=&-U="`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@("`@("`@("`@
M('P**ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/2L]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8%!%05)?
M3$]'7T5-15)'8&`@("`@?"!@8&5M97)G*"E@8"`@('P@4WES=&5M(&ES('5N
M=7-A8FQE("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7T%,15)48&`@("`@?"!@8&%L97)T
M*"E@8"`@('P@26UM961I871E(&%C=&EO;B!R97%U:7)E9"`@("`@("`@('P*
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'
M7T-2251@8"`@("`@?"!@8&-R:70H*6!@("`@('P@0W)I=&EC86P@8V]N9&ET
M:6]N<R`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*?"!@8%!%05)?3$]'7T524F!@("`@("`@?"!@8&5R<B@I8&`@
M("`@('P@17)R;W(@8V]N9&ET:6]N<R`@("`@("`@("`@("`@("`@('P**RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7U=!
M4DY)3D=@8"`@?"!@8'=A<FYI;F<H*6!@('P@5V%R;FEN9R!C;VYD:71I;VYS
M("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*?"!@8%!%05)?3$]'7TY/5$E#16!@("`@?"!@8&YO=&EC92@I8&`@
M('P@3F]R;6%L(&)U="!S:6=N:69I8V%N="`@("`@("`@("`@('P**RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7TE.1D]@
M8"`@("`@?"!@8&EN9F\H*6!@("`@('P@26YF;W)M871I;VYA;"`@("`@("`@
M("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*?"!@8%!%05)?3$]'7T1%0E5'8&`@("`@?"!@8&1E8G5G*"E@8"`@('P@
M1&5B=6<M;&5V96P@;65S<V%G97,@("`@("`@("`@("`@('P**RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"@I,;V<@3&5V96P@36%S:W,*+2TM
M+2TM+2TM+2TM+2TM"D1E9FEN:6YG(&$@;&]G(&QE=F5L(&UA<VL@86QL;W=S
M('EO=2!T;R!I;F-L=61E(&%N9"]O<B!E>&-L=61E('-P96-I9FEC(&QE=F5L
M<PIO9B!E=F5N=',@9G)O;2!B96EN9R!L;V=G960N("!4:&4@8&`D;&5V96Q@
M8"!C;VYS=')U8W1I;VX@<&%R86UE=&5R("AS964*8$-O;F9I9W5R:6YG(&$@
M2&%N9&QE<F!?*2!U<V5S('1H:7,@;65C:&%N:7-M('1O(&5X8VQU9&4@;&]G
M(&5V96YT<R!B96QO=R!A"F-E<G1A:6X@<')I;W)I='DL(&%N9"!I="=S('!O
M<W-I8FQE('1O(&1E9FEN92!M;W)E(&-O;7!L97@@;6%S:W,@;VYC92!T:&4@
M3&]G"F]B:F5C="!H87,@8F5E;B!C;VYS=')U8W1E9"X*"D5A8V@@<')I;W)I
M='D@:&%S(&$@<W!E8VEF:6,@;6%S:R!A<W-O8VEA=&5D('=I=&@@:70N("!4
M;R!C;VUP=71E(&$@<')I;W)I='DG<PIM87-K+"!U<V4@=&AE('-T871I8R!@
M8$QO9SHZ34%32R@I8&`@;65T:&]D.CH*"B`@("`D;6%S:R`]($QO9SHZ34%3
M2RA014%27TQ/1U])3D9/*3L*"E1O(&-O;7!U=&4@=&AE(&UA<VL@9F]R(&%L
M;"!P<FEO<FET:65S('5P('1O(&$@8V5R=&%I;B!L979E;"P@=7-E('1H90I@
M8$QO9SHZ55!43R@I8&`@;65T:&]D.CH*"B`@("`D;6%S:R`]($QO9SHZ55!4
M3RA014%27TQ/1U])3D9/*3L*"E1H92!A<'!L>2!T:&4@;6%S:RP@=7-E('1H
M92!@8'-E=$UA<VLH*6!@(&UE=&AO9#HZ"@H@("`@)&QO9V=E<BT^<V5T36%S
M:R@D;6%S:RD["@I-87-K<R!C86X@8F4@8F4@8V]M8FEN960@=7-I;F<@8FET
M=VES92!O<&5R871I;VYS+B`@5&\@<F5S=')I8W0@;&]G9VEN9R!T;PIO;FQY
M('1H;W-E(&5V96YT<R!M87)K960@87,@8&!014%27TQ/1U].3U1)0T5@8"!O
M<B!@8%!%05)?3$]'7T1%0E5'8&`Z.@H*("`@("1M87-K(#T@3&]G.CI-05-+
M*%!%05)?3$]'7TY/5$E#12D@?"!,;V<Z.DU!4TLH4$5!4E],3T=?1$5"54<I
M.PH@("`@)&QO9V=E<BT^<V5T36%S:R@D;6%S:RD["@I&;W(@8V]N=F5N:65N
M8V4L('1W;R!S<&5C:6%L(&UA<VMS(&%R92!P<F5D969I;F5D.B!@8%!%05)?
M3$]'7TY/3D5@8"!A;F0*8&!014%27TQ/1U]!3$Q@8"X@(&!@4$5!4E],3T=?
M04Q,8&`@:7,@97-P96-I86QL>2!U<V5F=6P@9F]R(&5X;'5D:6YG(&]N;'D*
M<W!E8VEF:6,@<')I;W)I=&EE<SHZ"@H@("`@)&UA<VL@/2!014%27TQ/1U]!
M3$P@7B!,;V<Z.DU!4TLH4$5!4E],3T=?3D]424-%*3L*("`@("1L;V=G97(M
M/G-E=$UA<VLH)&UA<VLI.PH*270@:7,@86QS;R!P;W-S:6)L92!T;R!R971R
M:65V92!A;F0@;6]D:69Y(&$@3&]G(&]B:F5C="=S(&5X:7-T:6YG(&UA<VLZ
M.@H*("`@("1M87-K(#T@)&QO9V=E<BT^9V5T36%S:R@I('P@3&]G.CI-05-+
M*%!%05)?3$]'7TE.1D\I.PH@("`@)&QO9V=E<BT^<V5T36%S:R@D;6%S:RD[
M"@H*1FQU<VAI;F<@3&]G($5V96YT<PHM+2TM+2TM+2TM+2TM+2TM+2TM"E-O
M;64@;&]G(&AA;F1L97)S("AS=6-H(&%S(&!T:&4@8V]N<V]L92!H86YD;&5R
M8%\I('-U<'!O<G0@97AP;&EC:70*(F)U9F9E<FEN9R(N("!7:&5N(&)U9F9E
M<FEN9R!I<R!E;F%B;&5D+"!L;V<@979E;G1S('=O;B=T(&%C='5A;&QY(&)E
M('=R:71T96X*=&\@=&AE(&]U='!U="!S=')E86T@=6YT:6P@=&AE(&AA;F1L
M97(@:7,@8VQO<V5D+B`@3W1H97(@:&%N9&QE<G,@*'-U8V@@87,*8'1H92!F
M:6QE(&AA;F1L97)@7RD@<W5P<&]R="!I;7!L:6-I="!B=69F97)I;F<@8F5C
M875S92!T:&5Y('5S92!T:&4@;W!E<F%T:6YG"G-Y<W1E;2=S($E/(')O=71I
M;F5S+"!W:&EC:"!M87D@8G5F9F5R('1H92!O=71P=70N"@I)="=S('!O<W-I
M8FQE('1O(&9O<F-E('1H97-E(&AA;F1L97)S('1O(&9L=7-H('1H96ER(&]U
M='!U="P@:&]W979E<BP@8GD*8V%L;&EN9R!T:&5I<B!@8&9L=7-H*"E@8"!M
M971H;V0Z.@H*("`@("1C;VYF(#T@87)R87DH)V)U9F9E<FEN9R<@/3X@=')U
M92D["B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@
M)R<L("=T97-T)RP@)&-O;F8I.PH*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P
M.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^;&]G*"=4:&ES(&5V96YT('=I
M;&P@8F4@8G5F9F5R960N)RD["B`@("!]"@H@("`@+RH@1FQU<V@@86QL(&]F
M('1H92!B=69F97)E9"!L;V<@979E;G1S+B`J+PH@("`@)&QO9V=E<BT^9FQU
M<V@H*3L*"B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@
M("`@("1L;V=G97(M/FQO9R@G5&AI<R!E=F5N="!W:6QL(&)E(&)U9F9E<F5D
M+B<I.PH@("`@?0H*("`@("\J($EM<&QI8VET;'D@9FQU<V@@=&AE(&)U9F9E
M<F5D(&5V96YT<R!O;B!C;&]S92X@*B\*("`@("1L;V=G97(M/F-L;W-E*"D[
M"@I!="!T:&ES('1I;64L('1H92!@8&9L=7-H*"E@8"!M971H;V0@:7,@;VYL
M>2!I;7!L96UE;G1E9"!B>2!@=&AE(&-O;G-O;&4*:&%N9&QE<F!?+"!@=&AE
M(&9I;&4@:&%N9&QE<F!?(&%N9"!@=&AE(&UA:6P@:&%N9&QE<F!?+@H*"E-T
M86YD87)D($QO9R!(86YD;&5R<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H
M92!#;VYS;VQE($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+2TM+0I4:&4@0V]N
M<V]L92!H86YD;&5R(&]U='!U=',@;&]G(&5V96YT<R!D:7)E8W1L>2!T;R!T
M:&4@8V]N<V]L92X@($ET('-U<'!O<G1S"F]U='!U="!B=69F97)I;F<@86YD
M(&-O;F9I9W5R86)L92!S=')I;F<@9F]R;6%T<RX*"D-O;F9I9W5R871I;VX*
M?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F875L="`@
M("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]
M/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@<W1R96%M8&`@("`@("`@('P@
M1FEL92`@("`@('P@4U1$3U547R`@("`@("!\(%1H92!O=71P=70@<W1R96%M
M('1O('5S92X@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(&!@8G5F9F5R:6YG8&`@("`@('P@0F]O;&5A;B`@('P@1F%L<V4@("`@("`@
M("!\(%-H;W5L9"!T:&4@;W5T<'5T(&)E("`@("`@?`I\("`@("`@("`@("`@
M("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&)U9F9E<F5D
M('5N=&EL('-H=71D;W=N/R`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PI\(&!@;&EN949O<FUA=&!@("`@('P@4W1R:6YG("`@('P@8&`E
M,21S("4R)',@("!\($QO9R!L:6YE(&9O<FUA="`@("`@("`@("`@?`I\("`@
M("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@6R4S)'-=("4T)'-@8"!\
M('-P96-I9FEC871I;VXN("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(&!@=&EM949O<FUA=&!@("`@('P@4W1R:6YG
M("`@('P@8&`E8B`E9"`@("`@("!\(%1I;64@<W1A;7`@9F]R;6%T("`@("`@
M("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@)4@Z)4TZ
M)5-@8"`@("!\("AF;W(@<W1R9G1I;65?*2X@("`@("`@("`@?`HK+2TM+2TM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7U-41$]55#H@:'1T<#HO
M+W=W=RYP:'`N;F5T+W=R87!P97)S+G!H<`HN+B!?<W1R9G1I;64Z(&AT='`Z
M+R]W=W<N<&AP+FYE="]S=')F=&EM90H*17AA;7!L90I^?GY^?GY^"CHZ"@H@
M("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G
M:61E;G0G*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@
M("`@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I4
M:&4@1&ES<&QA>2!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM+2T*5&AE($1I
M<W!L87D@:&%N9&QE<B!S:6UP;'D@<')I;G1S('1H92!L;V<@979E;G1S(&)A
M8VL@=&\@=&AE(&)R;W=S97(N("!)=`IR97-P96-T<R!T:&4@8&!E<G)O<E]P
M<F5P96YD7W-T<FEN9V!@(&%N9"!@8&5R<F]R7V%P<&5N9%]S=')I;F=@8"!@
M97)R;W(*:&%N9&QI;F<@=F%L=65S8%\@86YD(&ES('5S969U;"!W:&5N(&!L
M;V=G:6YG(&9R;VT@<W1A;F1A<F0@97)R;W(@:&%N9&QE<G-@7RX*"D-O;F9I
M9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@('P@
M1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK
M/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]
M/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@97)R;W)?<')E
M<&5N9&!@('P@4W1R:6YG("`@('P@4$A0($E.22!V86QU92!\(%1H:7,@<W1R
M:6YG('=I;&P@8F4@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\('!R97!E;F1E9"!T;R!T:&4@;&]G
M("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\(&]U='!U="X@("`@("`@("`@("`@("`@("`@?`HK+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@97)R;W)?87!P96YD
M8&`@('P@4W1R:6YG("`@('P@4$A0($E.22!V86QU92!\(%1H:7,@<W1R:6YG
M('=I;&P@8F4@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@
M("`@('P@("`@("`@("`@("`@("!\(&%P<&5N9&5D('1O('1H92!L;V<@("`@
M("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@
M("`@("`@("!\(&]U='!U="X@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7V5R<F]R(&AA;F1L:6YG
M('9A;'5E<SH@:'1T<#HO+W=W=RYP:'`N;F5T+V5R<F]R9G5N8PH*17AA;7!L
M90I^?GY^?GY^"CHZ"@H@("`@)&-O;F8@/2!A<G)A>2@G97)R;W)?<')E<&5N
M9"<@/3X@)SQF;VYT(&-O;&]R/2(C9F8P,#`P(CX\='0^)RP*("`@("`@("`@
M("`@("`@("`@)V5R<F]R7V%P<&5N9"<@(#T^("<\+W1T/CPO9F]N=#XG*3L*
M("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V1I<W!L87DG+"`G)RP@
M)R<L("1C;VYF+"!014%27TQ/1U]$14)51RD["B`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`Q,#L@)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N
M=')Y("1I(BD["B`@("!]"@H*5&AE($5R<F]R7TQO9R!(86YD;&5R"BTM+2TM
M+2TM+2TM+2TM+2TM+2TM+0I4:&4@17)R;W)?3&]G(&AA;F1L97(@<V5N9',@
M;&]G(&5V96YT<R!T;R!02%`G<R!@97)R;W)?;&]G*"E@7R!F=6YC=&EO;BX*
M"D-O;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@
M("`@('P@1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@
M("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]
M/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@9&5S
M=&EN871I;VY@8"`@('P@4W1R:6YG("`@('P@)R<@8"AE;7!T>2E@("!\($]P
M=&EO;F%L(&1E<W1I;F%T:6]N('9A;'5E?`I\("`@("`@("`@("`@("`@("`@
M('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&9O<B!@97)R;W)?;&]G
M*"E@7RX@(%-E92`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@
M('P@("`@("`@("`@("`@("!\(&!%<G)O<E],;V<@5'EP97-@7R!F;W(@("`@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\(&UO<F4@9&5T86EL<RX@("`@("`@("`@("`@?`HK+2TM+2TM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@97AT<F%?:&5A9&5R<V!@('P@
M4W1R:6YG("`@('P@)R<@8"AE;7!T>2E@("!\($%D9&ET:6]N86P@:&5A9&5R
M<R!T;R!P87-S?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\('1O('1H92!@;6%I;"@I8%\@9G5N8W1I;VX@?`I\
M("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@
M("!\('=H96X@=&AE("`@("`@("`@("`@("`@("`@?`I\("`@("`@("`@("`@
M("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&!@4$5!4E],
M3T=?5%E015]-04E,8&`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\('1Y<&4@:7,@<W!E8VEF:65D+B`@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*17)R
M;W)?3&]G(%1Y<&5S"GY^?GY^?GY^?GY^?GY^?@I!;&P@;V8@=&AE(&%V86EL
M86)L92!L;V<@='EP97,@87)E(&1E=&%I;&5D(&EN('1H92!@97)R;W)?;&]G
M*"E@7R!S96-T:6]N(&]F"G1H92!02%`@;6%N=6%L+B`@1F]R('EO=7(@8V]N
M=F5N:65N8V4L('1H92!,;V<@<&%C:V%G92!A;'-O(&1E9FEN97,@=&AE"F9O
M;&QO=VEN9R!C;VYS=&%N=',@=&AA="!C86X@8F4@=7-E9"!F;W(@=&AE(&!@
M)&YA;65@8"!H86YD;&5R(&-O;G-T<G5C=&EO;@IP87)A;65T97(N"@HK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\($-O;G-T86YT("`@("`@
M("`@("`@("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]*PI\(&!@4$5!4E],3T=?5%E015]365-414U@8"`@?"!,;V<@979E;G1S
M(&%R92!S96YT('1O(%!(4"=S('-Y<W1E;2!L;V=G97(L("`@?`I\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?"!W:&EC:"!U<V5S('1H92!O<&5R871I
M;F<@<WES=&5M)W,@;&]G9VEN9R`@("`@?`I\("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?"!M96-H86YI<VT@;W(@82!F:6QE("AD97!E;F1I;F<@;VX@
M=&AE('9A;'5E("`@?`I\("`@("`@("`@("`@("`@("`@("`@("`@("`@?"!O
M9B!T:&4@8&5R<F]R7VQO9R!C;VYF:6=U<F%T:6]N(&1I<F5C=&EV96!?*2X@
M?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@4$5!4E],
M3T=?5%E015]-04E,8&`@("`@?"!,;V<@979E;G1S(&%R92!S96YT('9I82!E
M;6%I;"!T;R!T:&4@861D<F5S<R`@?`I\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?"!S<&5C:69I960@:6X@=&AE(&!@9&5S=&EN871I;VY@8"!V86QU
M92X@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(&!@4$5!4E],3T=?5%E015]$14)51V!@("`@?"!,;V<@979E;G1S(&%R92!S
M96YT('1H<F]U9V@@4$A0)W,@9&5B=6=G:6YG("`@?`I\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?"!C;VYN96-T:6]N+B`@5&AI<R!W:6QL(&]N;'D@
M=V]R:R!I9B`@("`@("`@("`@?`I\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?"!@<F5M;W1E(&1E8G5G9VEN9V!?(&AA<R!B965N(&5N86)L960N("!4
M:&4@("`@?`I\("`@("`@("`@("`@("`@("`@("`@("`@("`@?"!@8&1E<W1I
M;F%T:6]N8&`@=F%L=64@:7,@=7-E9"!T;R!S<&5C:69Y('1H92`@?`I\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?"!H;W-T(&YA;64@;W(@25`@861D
M<F5S<R!O9B!T:&4@=&%R9V5T('-O8VME="X@?`HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(&!@4$5!4E],3T=?5%E015]&24Q%8&`@("`@
M?"!,;V<@979E;G1S('=I;&P@8F4@87!P96YD960@=&\@=&AE(&9I;&4@;F%M
M960@?`I\("`@("`@("`@("`@("`@("`@("`@("`@("`@?"!B>2!T:&4@8&!D
M97-T:6YA=&EO;F!@('9A;'5E+B`@("`@("`@("`@("`@("`@?`HK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7V5R<F]R7VQO9R@I.B!H
M='1P.B\O=W=W+G!H<"YN970O97)R;W)?;&]G"BXN(%]M86EL*"DZ(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86EL"BXN(%]E<G)O<E]L;V<@8V]N9FEG=7)A=&EO
M;B!D:7)E8W1I=F4Z(&AT='`Z+R]W=W<N<&AP+FYE="]E<G)O<F9U;F,C:6YI
M+F5R<F]R+6QO9PHN+B!?<F5M;W1E(&1E8G5G9VEN9SH@:'1T<#HO+W=W=RYP
M:'`N;F5T+VEN<W1A;&PN8V]N9FEG=7)E(VEN<W1A;&PN8V]N9FEG=7)E+F5N
M86)L92UD96)U9V=E<@H*17AA;7!L90I^?GY^?GY^"CHZ"@H@("`@)&QO9V=E
M<B`]("9,;V<Z.G-I;F=L971O;B@G97)R;W)?;&]G)RP@4$5!4E],3T=?5%E0
M15]365-414TL("=I9&5N="<I.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[
M("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I
M.PH@("`@?0H*"E1H92!&:6QE($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+0I4
M:&4@1FEL92!H86YD;&5R('=R:71E<R!L;V<@979E;G1S('1O(&$@=&5X="!F
M:6QE('5S:6YG(&-O;F9I9W5R86)L92!S=')I;F<*9F]R;6%T<RX*"D-O;F9I
M9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@('P@
M1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK
M/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]
M/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@87!P96YD8&`@
M("`@("`@('P@0F]O;&5A;B`@('P@5')U92`@("`@("`@("!\(%-H;W5L9"!N
M97<@;&]G(&5N=')I97,@8F4@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\(&%P<&5N9"!T;R!A;B!E>&ES=&EN
M9R!L;V<@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\(&9I;&4L(&]R('-H;W5L9"!T:&4@82!N97<@?`I\("`@
M("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\
M(&QO9R!F:6QE(&]V97)W<FET92!A;B`@("`@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&5X:7-T:6YG(&]N
M93\@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PI\(&!@;6]D96!@("`@("`@("`@('P@26YT96=E<B`@('P@,#8T-"`@
M("`@("`@("!\($]C=&%L(')E<')E<V5N=&%T:6]N(&]F("`@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('1H
M92!L;V<@9FEL92=S('!E<FUI<W-I;VYS?`I\("`@("`@("`@("`@("`@("`@
M('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&UO9&4N("`@("`@("`@
M("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PI\(&!@96]L8&`@("`@("`@("`@('P@4W1R:6YG("`@('P@3U,@9&5F875L
M="`@("!\(%1H92!E;F0M;VXM;&EN92!C:&%R86-T97(@?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('-E<75E
M;F-E+B`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(&!@;&EN949O<FUA=&!@("`@('P@4W1R:6YG("`@('P@
M8&`E,21S("4R)',@("!\($QO9R!L:6YE(&9O<FUA="`@("`@("`@("`@?`I\
M("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@6R4S)'-=("4T)'-@
M8"!\('-P96-I9FEC871I;VXN("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@=&EM949O<FUA=&!@("`@('P@4W1R
M:6YG("`@('P@8&`E8B`E9"`@("`@("!\(%1I;64@<W1A;7`@9F]R;6%T("`@
M("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@)4@Z
M)4TZ)5-@8"`@("!\("AF;W(@<W1R9G1I;65?*2X@("`@("`@("`@?`HK+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7W-T<F9T:6UE.B!H
M='1P.B\O=W=W+G!H<"YN970O<W1R9G1I;64*"D5X86UP;&4*?GY^?GY^?@HZ
M.@H*("`@("1C;VYF(#T@87)R87DH)VUO9&4G(#T^(#`V,#`L("=T:6UE1F]R
M;6%T)R`]/B`G)5@@)7@G*3L*("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T
M;VXH)V9I;&4G+"`G;W5T+FQO9R<L("=I9&5N="<L("1C;VYF*3L*("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^
M;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I4:&4@36%I;"!(86YD;&5R
M"BTM+2TM+2TM+2TM+2TM+2T*5&AE($UA:6P@:&%N9&QE<B!A9V=R96=A=&5S
M(&$@<V5S<VEO;B=S(&QO9R!E=F5N=',@86YD('-E;F1S('1H96T@:6X@=&AE
M(&)O9'D*;V8@86X@96UA:6P@;65S<V%G92!U<VEN9R!02%`G<R!@;6%I;"@I
M8%\@9G5N8W1I;VXN"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM
M+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A;65T97(@("`@
M("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$97-C<FEP=&EO
M;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]
M/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/2L*?"!@8&9R;VU@8"`@("`@("`@("!\(%-T<FEN9R`@("!\('-E;F1M
M86EL7V9R;VT@?"!686QU92!F;W(@=&AE(&UE<W-A9V4G<R`@('P*?"`@("`@
M("`@("`@("`@("`@("!\("`@("`@("`@("!\($E.22!V86QU92`@("`@?"!@
M8$9R;VTZ8&`@:&5A9&5R+B`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*?"!@8'-U8FIE8W1@8"`@("`@("!\(%-T<FEN9R`@
M("!\(&!@6TQO9U]M86EL72`@?"!686QU92!F;W(@=&AE(&UE<W-A9V4G<R`@
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\($QO9R!M97-S
M86=E8&`@?"!@8%-U8FIE8W0Z8&`@:&5A9&5R+B`@("`@('P**RTM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'!R96%M8FQE8&`@("`@("!\
M(%-T<FEN9R`@("!\(&!@(&`H96UP='DI8"`@?"!0<F5A;6)L92!F;W(@=&AE
M(&UE<W-A9V4N('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M"BXN(%]M86EL*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86EL"@I%>&%M<&QE
M"GY^?GY^?GX*.CH*"B`@("`D8V]N9B`](&%R<F%Y*"=S=6)J96-T)R`]/B`G
M26UP;W)T86YT($QO9R!%=F5N=',G*3L*("`@("1L;V=G97(@/2`F3&]G.CIS
M:6YG;&5T;VXH)VUA:6PG+"`G=V5B;6%S=&5R0&5X86UP;&4N8V]M)RP@)VED
M96YT)RP@)&-O;F8I.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI
M('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@
M?0H*"E1H92!.=6QL($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+0I4:&4@3G5L
M;"!H86YD;&5R('-I;7!L>2!C;VYS=6UE<R!L;V<@979E;G1S("AA:VEN('1O
M('-E;F1I;F<@=&AE;2!T;PI@8"]D978O;G5L;&!@*2X@(&!,;V<@;&5V96P@
M;6%S:W-@7R!A<F4@<F5S<&5C=&5D+"!A;F0@=&AE(&5V96YT('=I;&P@<W1I
M;&P@8F4*<V5N="!T;R!A;GD@<F5G:7-T97)E9"!@;&]G(&]B<V5R=F5R<V!?
M+@H*17AA;7!L90I^?GY^?GY^"CHZ"@H@("`@)&QO9V=E<B`]("9,;V<Z.G-I
M;F=L971O;B@G;G5L;"<I.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I
M*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@
M("`@?0H*"E1H92!344P@*$1"*2!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM
M+2TM"@I4:&4@4U%,(&AA;F1L97(@<V5N9',@;&]G(&5V96YT<R!T;R!A(&1A
M=&%B87-E('5S:6YG(&!014%2)W,@1$(@86)S=')A8W1I;VX*;&%Y97)@7RX*
M"D-O;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@
M("`@('P@1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@
M("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]
M/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@9'-N
M8&`@("`@("`@("`@('P@4W1R:6YG("`@('P@)R<@8"AE;7!T>2E@("!\($$@
M8$1A=&$@4V]U<F-E($YA;65@7RX@("`@?`I\("`@("`@("`@("`@("`@("`@
M('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('QR97%U:7)E9'P@("`@
M("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PI\(&!@9&)@8"`@("`@("`@("`@('P@3V)J96-T("`@('P@3E5,3"`@("`@
M("`@("!\($%N(&5X:7-T:6YG(&!$0F!?(&]B:F5C="X@?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\($EF('-P
M96-I9FEE9"P@=&AI<R!O8FIE8W0@?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@("`@("`@("`@("`@("!\('=I;&P@8F4@=7-E9"P@86YD
M(&!@9'-N8&`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\('=I;&P@8F4@:6=N;W)E9"X@("`@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7T1".B!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*+BX@7U!%05(G<R!$0B!A8G-T
M<F%C=&EO;B!L87EE<CH@1$)?"BXN(%]$871A(%-O=7)C92!.86UE.B!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B
M+FEN=')O+61S;BYP:'`*"D5X86UP;&5S"GY^?GY^?GY^"E5S:6YG(&$@8$1A
M=&$@4V]U<F-E($YA;65@7R!T;R!C<F5A=&4@82!N97<@9&%T86)A<V4@8V]N
M;F5C=&EO;CHZ"@H@("`@)&-O;F8@/2!A<G)A>2@G9'-N)R`]/B`G<&=S<6PZ
M+R]J;VY`;&]C86QH;W-T*W5N:7@O;&]G<R<I.PH@("`@)&QO9V=E<B`]("9,
M;V<Z.G-I;F=L971O;B@G<W%L)RP@)VQO9U]T86)L92<L("=I9&5N="<L("1C
M;VYF*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@
M("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"E5S:6YG
M(&%N(&5X:7-T:6YG(&!$0F!?(&]B:F5C=#HZ"@H@("`@<F5Q=6ER95]O;F-E
M("=$0BYP:'`G.PH@("`@)&1B(#T@)D1".CIC;VYN96-T*"=P9W-Q;#HO+VIO
M;D!L;V-A;&AO<W0K=6YI>"]L;V=S)RD["@H@("`@)&-O;F9;)V1B)UT@/2`D
M9&(["B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=S<6PG+"`G;&]G
M7W1A8FQE)RP@)VED96YT)RP@)&-O;F8I.PH@("`@9F]R("@D:2`](#`[("1I
M(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R
M>2`D:2(I.PH@("`@?0H*"E1H92!3<6QI=&4@2&%N9&QE<@HM+2TM+2TM+2TM
M+2TM+2TM+2T*.D%U=&AO<CH@("`@("`@($)E<G1R86YD($UA;G-I;VX*.D-O
M;G1A8W0Z("`@("`@(&)M86YS:6]N0&UA;6%S86TN8V]M"@I4:&4@4W%L:71E
M(&AA;F1L97(@<V5N9',@;&]G(&5V96YT<R!T;R!A;B!3<6QI=&4@9&%T86)A
M<V4@=7-I;F<@=&AE(&!N871I=F4*4$A0('-Q;&ET92!F=6YC=&EO;G-@7RX*
M"DET(&ES(&9A<W1E<B!T:&%N(&!T:&4@4U%,("A$0BD@:&%N9&QE<F!?(&)E
M8V%U<V4@<F5Q=65S=',@87)E(&UA9&4@9&ER96-T;'D*=&\@=&AE(&1A=&%B
M87-E('=I=&AO=70@=7-I;F<@86X@86)S=')A8W1I;VX@;&%Y97(N("!)="!I
M<R!A;'-O(&EN=&5R97-T:6YG('1O"FYO=&4@=&AA="!3<6QI=&4@9&%T86)A
M<V4@9FEL97,@8V%N(&)E(&UO=F5D+"!C;W!I960L(&%N9"!D96QE=&5D(&]N
M('EO=7(*<WES=&5M(&IU<W0@;&EK92!A;GD@;W1H97(@9FEL97,L('=H:6-H
M(&UA:V5S(&QO9R!M86YA9V5M96YT(&5A<VEE<BX@($QA<W0@8G5T"FYO="!L
M96%S="P@=7-I;F<@82!D871A8F%S92!T;R!L;V<@>6]U<B!E=F5N=',@86QL
M;W=S('EO=2!T;R!U<V4@4U%,('%U97)I97,*=&\@8W)E871E(')E<&]R=',@
M86YD('-T871I<W1I8W,N"@I7:&5N('5S:6YG(&$@9&%T86)A<V4@86YD(&QO
M9V=I;F<@82!L;W0@;V8@979E;G1S+"!I="!I<R!R96-O;6UE;F1E9"!T;R!S
M<&QI=`IT:&4@9&%T86)A<V4@:6YT;R!S;6%L;&5R(&1A=&%B87-E<RX@(%1H
M:7,@:7,@86QL;W=E9"!B>2!3<6QI=&4L(&%N9"!Y;W4@8V%N"FQA=&5R('5S
M92!T:&4@4W%L:71E(&!!5%1!0TA@7R!S=&%T96UE;G0@=&\@<75E<GD@>6]U
M<B!L;V<@9&%T86)A<V4@9FEL97,*9VQO8F%L;'DN"@I)9B!T:&4@9&%T86)A
M<V4@9&]E<R!N;W0@97AI<W0@=VAE;B!T:&4@;&]G(&ES(&]P96YE9"P@<W%L
M:71E('=I;&P@=')Y('1O"F-R96%T92!I="!A=71O;6%T:6-A;&QY+B!)9B!T
M:&4@;&]G('1A8FQE(&1O97,@;F]T(&5X:7-T+"!I="!W:6QL(&%L<V\@8F4*
M875T;VUA=&EC86QL>2!C<F5A=&5D+B`@5&AE('1A8FQE(&-R96%T:6]N('5S
M97,@=&AE(&9O;&QO=VEN9R!344P@<F5Q=65S=#HZ"@H@("`@0U)%051%(%1!
M0DQ%(&QO9U]T86)L92`H"B`@("`@("`@:60@("`@("`@("`@24Y414=%4B!0
M4DE-05)9($M%62!.3U0@3E5,3"P*("`@("`@("!L;V=T:6UE("`@("!.3U0@
M3E5,3"P*("`@("`@("!I9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*
M("`@("`@("!P<FEO<FET>2`@("!)3E0@3D]4($Y53$PL"B`@("`@("`@;65S
M<V%G90H@("`@*3L*"D-O;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@
M("`@('P@5'EP92`@("`@('P@1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N
M("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]
M/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]*PI\(&!@9FEL96YA;65@8"`@("`@('P@4W1R:6YG("`@('P@)R<@8"AE
M;7!T>2E@("!\(%!A=&@@=&\@86X@4W%L:71E("`@("`@("`@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&1A
M=&%B87-E+B!\<F5Q=6ER961\("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@;6]D96!@("`@("`@("`@('P@26YT96=E<B`@
M('P@,#8V-B`@("`@("`@("!\($]C=&%L(&UO9&4@=7-E9"!T;R!O<&5N("`@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\('1H92!D871A8F%S92X@("`@("`@("`@("`@?`HK+2TM+2TM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@<&5R<VES=&5N=&!@("`@('P@
M0F]O;&5A;B`@('P@9F%L<V4@("`@("`@("!\(%5S92!A('!E<G-I<W1E;G0@
M("`@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\(&-O;FYE8W1I;VXN("`@("`@("`@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*06X@86QR96%D>2!O
M<&5N960@9&%T86)A<V4@8V]N;F5C=&EO;B!C86X@86QS;R!B92!P87-S960@
M87,@<&%R86UE=&5R(&EN<W1E860*;V8@=&AE(&%B;W9E(&-O;F9I9W5R871I
M;VXN("!);B!T:&ES(&-A<V4L(&-L;W-I;F<@=&AE(&1A=&%B87-E(&-O;FYE
M8W1I;VX@:7,*=7`@=&\@=&AE('5S97(N"@HN+B!?;F%T:79E(%!(4"!S<6QI
M=&4@9G5N8W1I;VYS.B!H='1P.B\O=W=W+G!H<"YN970O<W%L:71E"BXN(%]!
M5%1!0T@Z(&AT='`Z+R]W=W<N<W%L:71E+F]R9R]L86YG+FAT;6PC871T86-H
M"@I%>&%M<&QE<PI^?GY^?GY^?@I5<VEN9R!A(&-O;F9I9W5R871I;VX@=&\@
M8W)E871E(&$@;F5W(&1A=&%B87-E(&-O;FYE8W1I;VXZ.@H*("`@("1C;VYF
M(#T@87)R87DH)V9I;&5N86UE)R`]/B`G;&]G+F1B)RP@)VUO9&4G(#T^(#`V
M-C8L("=P97)S:7-T96YT)R`]/B!T<G5E*3L*("`@("1L;V=G97(@/28@3&]G
M.CIF86-T;W)Y*"=S<6QI=&4G+"`G;&]G7W1A8FQE)RP@)VED96YT)RP@)&-O
M;F8I.PH@("`@)&QO9V=E<BT^;&]G*"=L;V=G:6YG(&%N(&5V96YT)RP@4$5!
M4E],3T=?5T%23DE.1RD["@I5<VEN9R!A;B!E>&ES=&EN9R!C;VYN96-T:6]N
M.CH*"B`@("`D9&(@/2!S<6QI=&5?;W!E;B@G;&]G+F1B)RP@,#8V-BP@)&5R
M<F]R*3L*("`@("1L;V=G97(@/28@3&]G.CIF86-T;W)Y*"=S<6QI=&4G+"`G
M;&]G7W1A8FQE)RP@)VED96YT)RP@)&1B*3L*("`@("1L;V=G97(M/FQO9R@G
M;&]G9VEN9R!A;B!E=F5N="<L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@<W%L
M:71E7V-L;W-E*"1D8BD["@H*5&AE(%-Y<VQO9R!(86YD;&5R"BTM+2TM+2TM
M+2TM+2TM+2TM+0I4:&4@4WES;&]G(&AA;F1L97(@<V5N9',@;&]G(&5V96YT
M<R!T;R!T:&4@<WES=&5M(&QO9V=I;F<@<V5R=FEC92`H<WES;&]G(&]N"E5N
M:7@M;&EK92!E;G9I<F]N;65N=',@;W(@=&AE($5V96YT($QO9R!O;B!7:6YD
M;W=S('-Y<W1E;7,I+B`@5&AE(&5V96YT<R!A<F4*<V5N="!U<VEN9R!02%`G
M<R!@<WES;&]G*"E@7R!F=6YC=&EO;BX*"D9A8VEL:71I97,*?GY^?GY^?GY^
M?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\($-O;G-T86YT
M("`@("`@("`@('P@0V%T96=O<GD@1&5S8W)I<'1I;VX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]*PI\(&!@3$]'7T%55$A@8"`@("`@('P@4V5C=7)I='D@+R!A
M=71H;W)I>F%T:6]N(&UE<W-A9V5S.R!@8$Q/1U]!551(4%))5F!@(&ES?`I\
M("`@("`@("`@("`@("`@("`@('P@<')E9F5R<F5D(&]N('-Y<W1E;7,@=VAE
M<F4@:70@:7,@9&5F:6YE9"X@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7T%55$A04DE68&`@('P@4')I
M=F%T92!S96-U<FET>2`O(&%U=&AO<FEZ871I;VX@;65S<V%G97,@("`@("`@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M3$]'7T-23TY@8"`@("`@('P@0VQO8VL@9&%E;6]N("A@8&-R;VY@8"!A;F0@
M8&!A=&!@*2`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7T1!14U/3F!@("`@('P@4WES=&5M
M(&1A96UO;B!P<F]C97-S97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'
M7TM%4DY@8"`@("`@('P@2V5R;F5L(&UE<W-A9V5S("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@3$]'7TQ/0T%,,&!@("XN('P@4F5S97)V960@
M9F]R(&QO8V%L('5S93L@*BIN;W0J*B!A=F%I;&%B;&4@=6YD97(@("`@("`@
M?`I\(&!@3$]'7TQ/0T%,-V!@("`@('P@5VEN9&]W<RX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7TQ04F!@("`@("`@('P@
M4')I;G1E<B!S=6)S>7-T96T@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(&!@3$]'7TU!24Q@8"`@("`@('P@36%I;"!S=6)S>7-T96T@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7TY%5U-@8"`@("`@('P@55-%
M3D54(&YE=W,@<W5B<WES=&5M("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M3$]'7U-94TQ/1V!@("`@('P@26YT97)N86P@<WES;&]G(&UE<W-A9V5S("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7U5315)@8"`@("`@('P@1V5N97)I
M8R!U<V5R+6QE=F5L(&UE<W-A9V5S("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'
M7U550U!@8"`@("`@('P@555#4"!S=6)S>7-T96T@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PH*+BX@7W-Y<VQO9R@I.B!H='1P.B\O=W=W+G!H<"YN
M970O<WES;&]G"@I%>&%M<&QE"GY^?GY^?GX*.CH*"B`@("`D;&]G9V5R(#T@
M)DQO9SHZ<VEN9VQE=&]N*"=S>7-L;V<G+"!,3T=?3$]#04PP+"`G:61E;G0G
M*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@
M)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I4:&4@5VEN
M9&]W($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+2TM"E1H92!7:6YD;W<@:&%N
M9&QE<B!S96YD<R!L;V<@979E;G1S('1O(&$@<V5P87)A=&4@8G)O=W-E<B!W
M:6YD;W<N("!4:&4*;W)I9VEN86P@:61E82!F;W(@=&AI<R!H86YD;&5R('=A
M<R!I;G-P:7)E9"!B>2!#<F%I9R!$879I<R<@6F5N9"YC;VT@87)T:6-L90IE
M;G1I=&QE9"!@(DIA=F%38W)I<'0@4&]W97(@4$A0($1E8G5G9VEN9R)@7RX*
M"D-O;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@
M("`@('P@1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@
M("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]
M/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@=&ET
M;&5@8"`@("`@("`@('P@4W1R:6YG("`@('P@8&!,;V<@3W5T<'5T("!\(%1H
M92!T:71L92!O9B!T:&4@;W5T<'5T("`@?`I\("`@("`@("`@("`@("`@("`@
M('P@("`@("`@("`@('P@5VEN9&]W8&`@("`@("!\('=I;F1O=RX@("`@("`@
M("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PI\(&!@8V]L;W)S8&`@("`@("`@('P@07)R87D@("`@('P@8%)/62!'($))
M5F!?("!\($UA<'!I;F<@;V8@;&]G('!R:6]R:71I97,@?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@*&AI9V@@=&\@;&]W*2!\('1O(&-O
M;&]R<RX@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PH*+BX@7R)*879A4V-R:7!T(%!O=V5R(%!(4"!$96)U9V=I
M;F<B.B!H='1P.B\O=W=W+GIE;F0N8V]M+WIE;F0O='5T+W1U=&]R:6%L+41E
M8G5G3&EB+G!H<`HN+B!?4D]9($<@0DE6.B!H='1P.B\O=W=W+F-I<RYR:70N
M961U+PH*17AA;7!L90I^?GY^?GY^"CHZ"@H@("`@)&-O;F8@/2!A<G)A>2@G
M=&ET;&4G(#T^("=386UP;&4@3&]G($]U='!U="<I.PH@("`@)&QO9V=E<B`]
M("9,;V<Z.G-I;F=L971O;B@G=VEN)RP@)TQO9U=I;F1O=R<L("=I9&5N="<L
M("1C;VYF*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@
M("`@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I#
M;VUP;W-I=&4@2&%N9&QE<G,*/3T]/3T]/3T]/3T]/3T]/3T]"DET(&ES(&]F
M=&5N('5S969U;"!T;R!L;V<@979E;G1S('1O(&UU;'1I<&QE(&AA;F1L97)S
M+B`@5&AE($QO9R!P86-K86=E"G!R;W9I9&5S(&$@8V]M<&]S:71I;F<@<WES
M=&5M('1H870@;6%R:W,@=&AI<R!T87-K('1R:79I86PN"@I3=&%R="!B>2!C
M<F5A=&EN9R!T:&4@:6YD:79I9'5A;"!L;V<@:&%N9&QE<G,Z.@H*("`@("1C
M;VYS;VQE(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=415-4
M)RD["B`@("`D9FEL92`]("9,;V<Z.G-I;F=L971O;B@G9FEL92<L("=O=70N
M;&]G)RP@)U1%4U0G*3L*"E1H96XL(&-O;G-T<G5C="!A(&-O;7!O<VET92!H
M86YD;&5R(&%N9"!A9&0@=&AE(&EN9&EV:61U86P@:&%N9&QE<G,@87,*8VAI
M;&1R96X@;V8@=&AE(&-O;7!O<VET93HZ"@H@("`@)&-O;7!O<VET92`]("9,
M;V<Z.G-I;F=L971O;B@G8V]M<&]S:71E)RD["B`@("`D8V]M<&]S:71E+3YA
M9&1#:&EL9"@D8V]N<V]L92D["B`@("`D8V]M<&]S:71E+3YA9&1#:&EL9"@D
M9FEL92D["@I4:&4@8V]M<&]S:71E(&AA;F1L97(@:6UP;&5M96YT<R!T:&4@
M<W1A;F1A<F0@8&!,;V=@8"!I;G1E<F9A8V4@<V\@>6]U(&-A;B!U<V4*:70@
M:G5S="!L:6ME(&%N>2!O9B!T:&4@;W1H97(@:&%N9&QE<G,Z.@H*("`@("1C
M;VUP;W-I=&4M/FQO9R@G5&AI<R!E=F5N="!W:6QL(&)E(&QO9V=E9"!T;R!B
M;W1H(&AA;F1L97)S+B<I.PH*0VAI;&1R96X@8V%N(&)E(')E;6]V960@9G)O
M;2!T:&4@8V]M<&]S:71E('=H96X@=&AE>2=R92!N;W0@;&]N9V5R(&YE961E
M9#HZ"@H@("`@)&-O;7!O<VET92T^<F5M;W9E0VAI;&0H)&9I;&4I.PH*"DQO
M9R!/8G-E<G9E<G,*/3T]/3T]/3T]/3T]/0I,;V<@;V)S97)V97)S('!R;W9I
M9&4@86X@:6UP;&5M96YT871I;VX@;V8@=&AE(&!O8G-E<G9E<B!P871T97)N
M8%\N("!);B!T:&4*8V]N=&5N="!O9B!T:&4@3&]G('!A8VMA9V4L('1H97D@
M<')O=FED92!A(&UE8VAA;FES;2!B>2!W:&EC:"!Y;W4@8V%N(&5X86UI;F4*
M*&DN92X@;V)S97)V92D@96%C:"!E=F5N="!A<R!I="!I<R!L;V=G960N("!4
M:&ES(&%L;&]W<R!T:&4@:6UP;&5M96YT871I;VX@;V8*<W!E8VEA;"!B96AA
M=FEO<B!B87-E9"!O;B!T:&4@8V]N=&5N=',@;V8@82!L;V<@979E;G0N("!&
M;W(@97AA;7!L92P@=&AE"F]B<V5R=F5R(&-O9&4@8V]U;&0@<V5N9"!A;B!A
M;&5R="!E;6%I;"!I9B!A(&QO9R!E=F5N="!C;VYT86EN960@=&AE('-T<FEN
M9PI@8%!!3DE#8&`N"@I#<F5A=&EN9R!A(&QO9R!O8G-E<G9E<B!I;G9O;'9E
M<R!I;7!L96UE;G1I;F<@82!S=6)C;&%S<R!O9B!T:&4*8&!,;V=?;V)S97)V
M97)@8"!C;&%S<RX@(%1H92!S=6)C;&%S<R!M=7-T(&]V97)R:61E('1H92!B
M87-E(&-L87-S)W,*8&!N;W1I9GDH*6!@(&UE=&AO9"X@(%1H:7,@;65T:&]D
M(&ES('!A<W-E9"!A(&AA<V@@8V]N=&%I;FEN9R!T:&4@979E;G0G<PIP<FEO
M<FET>2!A;F0@979E;G0N("!4:&4@<W5B8VQA<W,G<R!I;7!L96UE;G1A=&EO
M;B!I<R!F<F5E('1O(&%C="!U<&]N('1H:7,*:6YF;W)M871I;VX@:6X@86YY
M('=A>2!I="!L:6ME<RX*"DQO9R!O8G-E<G9E<G,@87)E(&%T=&%C:&5D('1O
M(&!@3&]G8&`@:6YS=&%N8V5S('9I82!T:&4@8&!A='1A8V@H*6!@(&UE=&AO
M9#HZ"@H@("`@)&]B<V5R=F5R(#T@)DQO9U]O8G-E<G9E<CHZ9F%C=&]R>2@G
M>6]U<E1Y<&4G*3L*("`@("1L;V=G97(M/F%T=&%C:"@D;V)S97)V97(I.PH*
M3V)S97)V97)S(&-A;B!B92!D971A8VAE9"!U<VEN9R!T:&4@8&!D971A8V@H
M*6!@(&UE=&AO9#HZ"@H@("`@)&QO9V=E<BT^9&5T86-H*"1O8G-E<G9E<BD[
M"@I!="!T:&ES('1I;64L(&YO(&-O;F-R971E(&!@3&]G7V]B<V5R=F5R8&`@
M:6UP;&5M96YT871I;VYS(&%R92!D:7-T<FEB=71E9`IW:71H('1H92!,;V<@
M<&%C:V%G92X*"BXN(%]O8G-E<G9E<B!P871T97)N.B!H='1P.B\O<&AP<&%T
M=&5R;G,N8V]M+VEN9&5X+G!H<"]A<G1I8VQE+V%R=&EC;&5V:65W+S(W+S$O
M,2\*"@I,;V=G:6YG($9R;VT@4W1A;F1A<F0@17)R;W(@2&%N9&QE<G,*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I,;V=G:6YG(%!(
M4"!%<G)O<G,*+2TM+2TM+2TM+2TM+2TM+2TM"E!(4"=S(&1E9F%U;'0@97)R
M;W(@:&%N9&QE<B!C86X@8F4@;W9E<G)I9&1E;B!U<VEN9R!T:&4@8'-E=%]E
M<G)O<E]H86YD;&5R*"E@7PIF=6YC=&EO;BX@(%1H92!C=7-T;VT@97)R;W(@
M:&%N9&QI;F<@9G5N8W1I;VX@8V%N('5S92!A(&=L;V)A;"!,;V<@:6YS=&%N
M8V4@=&\*;&]G('1H92!02%`@97)R;W)S+@H**BI.;W1E.BHJ($9A=&%L(%!(
M4"!E<G)O<G,@8V%N;F]T(&)E(&AA;F1L960@8GD@82!C=7-T;VT@97)R;W(@
M:&%N9&QE<B!A="!T:&ES"G1I;64N"@HZ.@H*("`@(&9U;F-T:6]N(&5R<F]R
M2&%N9&QE<B@D8V]D92P@)&UE<W-A9V4L("1F:6QE+"`D;&EN92D*("`@('L*
M("`@("`@("!G;&]B86P@)&QO9V=E<CL*"B`@("`@("`@+RH@36%P('1H92!0
M2%`@97)R;W(@=&\@82!,;V<@<')I;W)I='DN("HO"B`@("`@("`@<W=I=&-H
M("@D8V]D92D@>PH@("`@("`@(&-A<V4@15]705).24Y'.@H@("`@("`@(&-A
M<V4@15]54T527U=!4DY)3D<Z"B`@("`@("`@("`@("1P<FEO<FET>2`](%!%
M05)?3$]'7U=!4DY)3D<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A
M<V4@15].3U1)0T4Z"B`@("`@("`@8V%S92!%7U5315)?3D]424-%.@H@("`@
M("`@("`@("`D<')I;W)I='D@/2!014%27TQ/1U].3U1)0T4["B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@(&-A<V4@15]%4E)/4CH*("`@("`@("!C87-E
M($5?55-%4E]%4E)/4CH*("`@("`@("`@("`@)'!R:6]R:71Y(#T@4$5!4E],
M3T=?15)2.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`D<')I;W1I='D@/2!014%27TQ/1U])3D9/.PH@("`@("`@
M('T*"B`@("`@("`@)&QO9V=E<BT^;&]G*"1M97-S86=E("X@)R!I;B`G("X@
M)&9I;&4@+B`G(&%T(&QI;F4@)R`N("1L:6YE+`H@("`@("`@("`@("`@("`@
M("`@("`D<')I;W)I='DI.PH@("`@?0H*("`@('-E=%]E<G)O<E]H86YD;&5R
M*"=E<G)O<DAA;F1L97(G*3L*("`@('1R:6=G97)?97)R;W(H)U1H:7,@:7,@
M86X@:6YF;W)M871I;VX@;&]G(&UE<W-A9V4N)RP@15]54T527TY/5$E#12D[
M"@HN+B!?<V5T7V5R<F]R7VAA;F1L97(H*3H@:'1T<#HO+W=W=RYP:'`N;F5T
M+W-E=%]E<G)O<E]H86YD;&5R"@I,;V=G:6YG(%!%05(@17)R;W)S"BTM+2TM
M+2TM+2TM+2TM+2TM+2T*5&AE($QO9R!P86-K86=E(&-A;B!B92!U<V5D('=I
M=&@@8%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*6!?)W,*8&!014%27T524D]2
M7T-!3$Q"04-+8&`@;65C:&%N:7-M(&)Y('=R:71I;F<@86X@97)R;W(@:&%N
M9&QI;F<@9G5N8W1I;VX@=&AA=`IU<V5S(&$@9VQO8F%L($QO9R!I;G-T86YC
M92X@($AE<F4G<R!A;B!E>&%M<&QE.CH*"B`@("!F=6YC=&EO;B!E<G)O<DAA
M;F1L97(H)&5R<F]R*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;&]G9V5R.PH*
M("`@("`@("`D;65S<V%G92`]("1E<G)O<BT^9V5T365S<V%G92@I.PH*("`@
M("`@("!I9B`H(65M<'1Y*"1E<G)O<BT^8F%C:W1R86-E6S%=6R=F:6QE)UTI
M*2!["B`@("`@("`@("`@("1M97-S86=E("X]("<@*"<@+B`D97)R;W(M/F)A
M8VMT<F%C95LQ75LG9FEL92==.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1E
M<G)O<BT^8F%C:W1R86-E6S%=6R=L:6YE)UTI*2!["B`@("`@("`@("`@("`@
M("`D;65S<V%G92`N/2`G(&%T(&QI;F4@)R`N("1E<G)O<BT^8F%C:W1R86-E
M6S%=6R=L:6YE)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&UE<W-A
M9V4@+CT@)RDG.PH@("`@("`@('T*"B`@("`@("`@)&QO9V=E<BT^;&]G*"1M
M97-S86=E+"`D97)R;W(M/F-O9&4I.PH@("`@?0H*("`@(%!%05(Z.G-E=$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)V5R<F]R2&%N9&QE
M<B<I.PH@("`@4$5!4CHZ<F%I<V5%<G)O<B@G5&AI<R!I<R!A;B!I;F9O<FUA
M=&EO;B!L;V<@;65S<V%G92XG+"!014%27TQ/1U])3D9/*3L*"BXN(%]014%2
M.CIS971%<G)O<DAA;F1L:6YG*"DZ(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+V-O<F4N<&5A<BYP96%R+G-E=&5R<F]R:&%N9&QI;F<N<&AP"@H*
M0W5S=&]M($AA;F1L97)S"CT]/3T]/3T]/3T]/3T]/0I4:&5R92!A<F4@=&EM
M97,@=VAE;B!T:&4@<W1A;F1A<F0@:&%N9&QE<G,@87)E;B=T(&$@<&5R9F5C
M="!M871C:"!F;W(@>6]U<@IN965D<RX@($EN('1H;W-E('-I='5A=&EO;G,L
M('1H92!S;VQU=&EO;B!M:6=H="!B92!T;R!W<FET92!A(&-U<W1O;2!H86YD
M;&5R+@H*57-I;F<@82!#=7-T;VT@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM"E5S:6YG(&$@8W5S=&]M($QO9R!H86YD;&5R(&ES('9E<GD@<VEM
M<&QE+B`@3VYC92!W<FET=&5N("AS964@8%=R:71I;F<@3F5W"DAA;F1L97)S
M8%\@86YD(&!%>'1E;F1I;F<@17AI<W1I;F<@2&%N9&QE<G-@7R!B96QO=RDL
M('EO=2!H879E('1H92!C:&]I8V4@;V8*<&QA8VEN9R!T:&4@9FEL92!I;B!Y
M;W5R(%!%05(@:6YS=&%L;&%T:6]N)W,@;6%I;B!@8$QO9R]@8"!D:7)E8W1O
M<GD@*'5S=6%L;'D*<V]M971H:6YG(&QI:V4@8&`O=7-R+VQO8V%L+VQI8B]P
M:'`O3&]G8&`@;W(@8&!#.EQP:'!<<&5A<EQ,;V=@8"DL('=H97)E(&ET"F-A
M;B!B92!F;W5N9"!A;F0@=7-E(&)Y(&%N>2!02%`@87!P;&EC871I;VX@;VX@
M=&AE('-Y<W1E;2P@;W(@<&QA8VEN9R!T:&4@9FEL90IS;VUE=VAE<F4@:6X@
M>6]U<B!A<'!L:6-A=&EO;B=S(&QO8V%L(&AI97)A<F-H>2!A;F0@:6YC;'5D
M:6YG(&ET(&)E9F]R92!T:&4*=&AE(&-U<W1O;2!,;V<@;V)J96-T(&ES(&-O
M;G-T<G5C=&5D+@H*365T:&]D(#$Z($AA;F1L97(@:6X@=&AE(%-T86YD87)D
M($QO8V%T:6]N"GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?@I!9G1E<B!C;W!Y:6YG('1H92!H86YD;&5R(&9I;&4@=&\@>6]U
M<B!014%2(&EN<W1A;&QA=&EO;B=S(&!@3&]G+V!@(&1I<F5C=&]R>2P*<VEM
M<&QY('1R96%T('1H92!H86YD;&5R(&%S(&EF(&ET('=E<F4@<&%R="!O9B!T
M:&4@<W1A;F1A<F0@9&ES=')I8G5T960N("!)9@IY;W5R(&AA;F1L97(@:7,@
M;F%M960@8&!C=7-T;VU@8"`H86YD('1H97)E9F]R92!I;7!L96UE;G1E9"!B
M>2!A(&-L87-S(&YA;65D"F!@3&]G7V-U<W1O;6!@*3HZ"@H@("`@<F5Q=6ER
M95]O;F-E("=,;V<N<&AP)SL*"B`@("`D;&]G9V5R(#T@)DQO9SHZ9F%C=&]R
M>2@G8W5S=&]M)RP@)R<L("=#55-43TTG*3L*"@I-971H;V0@,CH@2&%N9&QE
M<B!I;B!A($-U<W1O;2!,;V-A=&EO;@I^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?@I)9B!Y;W4@<')E9F5R('-T;W)I;F<@>6]U<B!H
M86YD;&5R(&EN('EO=7(@87!P;&EC871I;VXG<R!L;V-A;"!H:65R87)C:'DL
M"GEO=2=L;"!N965D('1O(&EN8VQU9&4@=&AA="!F:6QE(&)E9F]R92!Y;W4@
M8V%N(&-R96%T92!A($QO9R!I;G-T86YC92!B87-E9"!O;@II="X*"CHZ"@H@
M("`@<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*("`@(')E<75I<F5?;VYC92`G
M3&]C86Q(86YD;&5R<R]C=7-T;VTN<&AP)SL*"B`@("`D;&]G9V5R(#T@)DQO
M9SHZ9F%C=&]R>2@G8W5S=&]M)RP@)R<L("=#55-43TTG*3L*"@I7<FET:6YG
M($YE=R!(86YD;&5R<PHM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5$]$3PH*17AT
M96YD:6YG($5X:7-T:6YG($AA;F1L97)S"BTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H*5$]$3PH*"BXN('QR97%U:7)E9'P@<F5P;&%C93HZ("HJ6W)E
M<75I<F5D72HJ"@HN+B!V:6TZ('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-"!E>'!A;F1T86(@=&5X='=I9'1H/3<X(&9T/7)S=#H*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O1&%T92\`````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`Q-S$T-@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]$871E+U1/1$\`````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-S(`,3`T,3<S
M-C,P,#0`,#$W-C,U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"T@1FEX(&]N8V4@=&AE('1I;65Z;VYE('!R;V)L96T*"BT@
M3VYC92!46B!W;W)K<R!N:6-E;'DL('5P9&%T92!T:&4@=&5S='5N:71?9&%T
M92!A;F0@=7-E"B`@=&AE(')E86P@=&EM97IO;F4@86YD(&1C="!T;R!C:&5C
M:R!T:&4@97AP96-T960@=&EM92!O9F9S970*"BT@0VQE86X@=&AE('1E<W0@
M8V%S97,@86YD(&%T;VUI8R!D:7-P;&%Y(&EN<W1E860@;V8@82!G;&]B86P@
M;VL@;W(@9F%I;&5D"@HM('=R:71E('1H92!D;V-S+BXN+@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O4T]!4"\`````````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`Q-S`S
M,P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP
M;&4O````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C,P,#0`,#(P-#8V`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+U-/05`O97AA;7!L92]D:7-C;U]S97)V97(N<&AP````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`R,C$W-P`Q,#0Q-S,V,S`P-``P,C,V-S0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#\*+R\*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*
M+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE
M(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R.B!$;6ET<FD@5FEN;V=R861O=B`\9&EM:71R:4!V:6YO9W)A9&]V+F1E
M/B`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!D:7-C;U]S97)V97(N<&AP+'8@,2XS(#(P
M,#,O,#0O,C`@,C,Z,#4Z,C@@<VAA;F4@17AP("0*"B\J"B`@5&AI<R!E>&%M
M<&QE('-H;W=S(&AO=R!T;R!M87)K('5P(&$@<V5R=F5R(&]B:F5C="!S;R!T
M:&%T"B`@=W-D;"!F:6QE<R!M87D@8F4@9'EN86UI8V%L>2!G96YE<F%T960@
M8GD@=&AE('-O87`*("!S97)V97(N("!4:&ES(&%L<V\@<')O=FED97,@86-C
M97-S('1O(&$@9V5N97)A=&5D($1)4T-/(&1O8W5M96YT+@H@(%1H92!F86-T
M('1H870@=&AI<R!E>&%M<&QE(&AA<R!A;B!-4#,@8VQA<W,@:7,@:6X@;F\@
M=V%Y"B`@<F5L871E9"!T;R!$25-#3RX@.RD*("`*("!$25-#3SH@:'1T<#HO
M+VUS9&XN;6EC<F]S;V9T+F-O;2]M<V1N;6%G+VES<W5E<R\P,B\P,B]X;6PO
M9&5F875L="YA<W!X"B`@"B`@02!U<FP@86-C97-S:6YG('1H:7,@<V5R=F5R
M('=O=6QD(&QO;VL@;&EK93H*("`*("!H='1P.B\O;&]C86QH;W-T+V1I<V-O
M7W-E<G9E<BYP:'`_=W-D;"`H9V5N97)A=&4@5U-$3"!F:6QE*0H@(&AT='`Z
M+R]L;V-A;&AO<W0O9&ES8V]?<V5R=F5R+G!H<"`H1T54(')E<75E<W0@9V5N
M97)A=&5S($1)4T-/*0H@(&AT='`Z+R]L;V-A;&AO<W0O9&ES8V]?<V5R=F5R
M+G!H<"`H4$]35"!F;W(@;F]R;6%L('-O87`@<F5Q=65S=',I"BHO"@IE<G)O
M<E]R97!O<G1I;F<H15]!3$PI.PIR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R
M+G!H<"<["@IC;&%S<R!-4#-$0E]#;&%S<R!["B`@("!V87(@)%]?9&ES<&%T
M8VA?;6%P(#T@87)R87DH*3L*("`@('9A<B`D7U]T>7!E9&5F("`@("`](&%R
M<F%Y*"D["B`@("`*("`@(&9U;F-T:6]N($U0,T1"7T-L87-S("@I('L*("`@
M("`@("`O*BH*("`@("`@("`J('1H92!O;FQY('=A>2!T;R!D97-C<FEB92!A
M;&P@;65T:&]D<R!I;B!74T1,("AM97-S86=E<RP*("`@("`@("`J(%!O<G14
M>7!E+6]P97)A=&EO;G,@86YD(&)I;F1I;F=S*2!I<R!T;R!U<V4@7U]D:7-P
M871C:%]M87`*("`@("`@("`J('1O(&1E<V-R:6)E(&5V97)Y(&UE=&AO9"`H
M979E;B!M971H;V1S('5S:6YG('-I;7!L92!D871A(`H@("`@("`@("H@='EP
M97,@:6X@)VEN)R!A;F0@)V]U="<@<&%R86UE=&5R<RXN+BD*("`@("`@("`J
M+PH@("`@("`@(`H@("`@("`@("1T:&ES+3Y?7V1I<W!A=&-H7VUA<%LG4V%Y
M2&%L;&\G72`]"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@("=I;B<@/3X@87)R87DH)VEN<'5T)R`]/B`G<W1R
M:6YG)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("=O=70G(#T^(&%R<F%Y
M*"=R971U<FXG(#T^("=S=')I;F<G*0H@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@)'1H:7,M/E]?9&ES<&%T
M8VA?;6%P6R=387E4:&ES3E1I;65S)UT@/0H@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G:6XG(#T^(&%R<F%Y
M*"=387E4:&ES)ST^)W-T<FEN9R<L)TY4:6UE<R<@/3X@)VEN="<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G;W5T)R`]/B!A<G)A>2@G<F5T=7)N)R`]
M/B`G>W5R;CI-4#-$0GU!<G)A>4]F4W1R:6YG<R<I"B`@("`@("`@("`@("`@
M("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`*("`@("`@("`D=&AI<RT^
M7U]D:7-P871C:%]M87!;)T=E=$U0,U1R86-K<R==(#T*("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)VEN)R`]
M/B!A<G)A>2@G<75E<GDG(#T^("=S=')I;F<G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)V]U="<@/3X@87)R87DH)W)E='5R;B<@/3X@)WMU<FXZ35`S
M1$)]1V5T35`S5')A8VMS4F5S=6QT)RD*("`@("`@("`@("`@("`@("`@("`I
M.PH@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("1T:&ES+3Y?7V1I<W!A
M=&-H7VUA<%LG061D35`S5')A8VLG72`]"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=I;B<@/3X@87)R87DH
M)TU0,U1R86-K)R`]/B`G>W5R;CI-4#-$0GU-4#-4<F%C:R<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G;W5T)R`]/B!A<G)A>2@G<F5T=7)N)R`]/B`G
M>W5R;CI-4#-$0GU!9&1-4#-4<F%C:U)E<W5L="<I"B`@("`@("`@("`@("`@
M("`@("`@*3L*"B`@("`@("`@+RHJ"B`@("`@("`@*B!)('5S92!?7W1Y<&5D
M968@=&\@9&5S8W)I8F4@=7-E<F1E9FEN960@5'EP97,@:6X@5U-$3"X*("`@
M("`@("`J(%-T<G5C=',@86YD(&]N92UD:6UE;G-I;VYA;"!A<G)A>7,@87)E
M('-U<'!O<G1E9#H*("`@("`@("`J(%-T<G5C="!E>&%M<&QE.B`D=&AI<RT^
M7U]T>7!E9&5F6R=4>7!E3F%M92==(#T@87)R87DH)U9A<DYA;64G(#T^("=X
M<V14>7!E)RP@+BXN("D["B`@("`@("`@*B`@("!O<B`D=&AI<RT^7U]T>7!E
M9&5F6R=4>7!E3F%M92==(#T@87)R87DH)U9A<DYA;64G(#T^("=[;F%M97-P
M86-E?5-O;65/=&AE<E1Y<&4G*3L*("`@("`@("`J($%R<F%Y(&5X86UP;&4Z
M("1T:&ES+3Y?7W1Y<&5D969;)U1Y<&5.86UE)UT@/2!A<G)A>2AA<G)A>2@G
M:71E;2<@/3X@)WAS9%1Y<&4G*2D["B`@("`@("`@*B`@("!O<B`D=&AI<RT^
M7U]T>7!E9&5F6R=4>7!E3F%M92==(#T@87)R87DH87)R87DH)VET96TG(#T^
M("=[;F%M97-P86-E?5-O;65/=&AE<E1Y<&4G*2D["B`@("`@("`@*B\*("`@
M(`H@("`@("`@("\J*@H@("`@("`@("H@4W1R=6-T("=-4#-4<F%C:R<*("`@
M("`@("`J+PH@("`@("`@("1T:&ES+3Y?7W1Y<&5D969;)TU0,U1R86-K)UT@
M/2`*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@)U1I=&QE)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@)T%R=&ES="<@/3X@)W-T<FEN9R<L(`H@("`@("`@("`@("`@
M("`@("`@("`@("`G06QB=6TG(#T^("=S=')I;F<G+"`*("`@("`@("`@("`@
M("`@("`@("`@("`@)UEE87(G(#T^("=I;G0G+"`*("`@("`@("`@("`@("`@
M("`@("`@("`@)T=E;G)E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)T-O;6UE;G0G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G0V]M<&]S97(G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G3W)I9U]!<G1I<W0G(#T^("=S=')I;F<G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G55),)R`]/B`G<W1R:6YG)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@)T5N8V]D961?8GDG(#T^("=S=')I;F<G"B`@("`@
M("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`*("`@("`@
M("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("`@("`*("`@("`@("`O
M*BH*("`@("`@("`J($U0,U1R86-K<T%R<F%Y("T@87)R87D@;V8@)TU0,U1R
M86-K)R!S=')U8W1S"B`@("`@("`@*B\*("`@("`@("`D=&AI<RT^7U]T>7!E
M9&5F6R=-4#-4<F%C:W-!<G)A>2==(#T@"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VET96TG(#T^("=[=7)N.DU0,T1"?4U0
M,U1R86-K)PH@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`*("`@("`@("`O*BH*
M("`@("`@("`J(%-T<G5C="`G365T:&]D1&5B=6<G"B`@("`@("`@*B\*("`@
M("`@("`D=&AI<RT^7U]T>7!E9&5F6R=-971H;V1$96)U9R==(#T@"B`@("`@
M("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("=R8R<@/3X@)V)O;VQE86XG+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M17)R3F\G(#T^("=I;G0G+"`*("`@("`@("`@("`@("`@("`@("`@("`@)T5R
M<F]R)R`]/B`G<W1R:6YG)PH@("`@("`@("`@("`@("`@("`@("D["B`@("`@
M("`@("`@("`@("`@("`@"B`@("`@("`@+RHJ"B`@("`@("`@*B!R971U<FX@
M4W1R=6-T(&]F(&UE=&AO9"!'971-4#-4<F%C:W,*("`@("`@("`J+PH@("`@
M("`@("1T:&ES+3Y?7W1Y<&5D969;)T=E=$U0,U1R86-K<U)E<W5L="==(#T@
M"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("=-971H;V1$96)U9R<@/3X@)WMU<FXZ35`S1$)]365T:&]D1&5B
M=6<G+`H@("`@("`@("`@("`@("`@("`@("`@("`G35`S5')A8VMS)R`]/B`G
M>W5R;CI-4#-$0GU-4#-4<F%C:W-!<G)A>2<*("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("\J*@H@("`@("`@
M("H@<F5T=7)N(%-T<G5C="!O9B!M971H;V0@061D35`S5')A8VL*("`@("`@
M("`J+PH@("`@("`@("1T:&ES+3Y?7W1Y<&5D969;)T%D9$U0,U1R86-K4F5S
M=6QT)UT@/2`*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@)TUE=&AO9$1E8G5G)R`]/B`G>W5R;CI-4#-$0GU-
M971H;V1$96)U9R<*("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`@("`@("`@(`H@("`@("`@("\J*@H@("`@("`@("H@07)R87D@;V8@<W1R
M:6YG<PH@("`@("`@("HO"B`@("`@("`@)'1H:7,M/E]?='EP961E9ELG07)R
M87E/9E-T<FEN9W,G72`](`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:71E;2<]/B=S=')I;F<G
M*0H@("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@('T*("`@(`H@("`@
M"B`@("!F=6YC=&EO;B!387E(86QL;R@D;F%M92D@>PH@("`@("`@(')E='5R
M;B`B2&%L;&\L("(@+B`D;F%M93L*("`@('T*("`@(`H@("`@"B`@("!F=6YC
M=&EO;B!387E4:&ES3E1I;65S*"1387E4:&ES+"1.5&EM97,I('L*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D3E1I;65S.R`D:2LK*2!["B`@("`@("`@
M("`@("1R971U<FY;)&E=(#T@)%-A>51H:7,@+B`B("1I(CL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N(&YE=R!33T%07U9A;'5E*"=R971U<FXG+"=[=7)N
M.DU0,T1"?4%R<F%Y3V93=')I;F=S)RPD<F5T=7)N*3L*("`@('T*("`@(`H@
M("`@"B`@("!F=6YC=&EO;B!'971-4#-4<F%C:W,H)'%U97)Y(#T@(B(I('L*
M("`@("`@("!F;W(H)&D@/2`P.R`D:2`\(#4[("1I*RLI('L*("`@("`@("`@
M("`@)'1H:7,M/DU0,U1R86-K<ULD:5T@/2!N97<@4T]!4%]686QU92@*("`@
M("`@("`@("`@("`@("`@("`G:71E;2<L"B`@("`@("`@("`@("`@("`@("`@
M)WMU<FXZ35`S1$)]35`S5')A8VLG+`H@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`B5&ET;&4B("`@("`@("`@
M/3X@;F5W(%-/05!?5F%L=64H(E1I=&QE(BPB<W1R:6YG(BPB<V]M92!T<F%C
M:R`D:2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`B07)T:7-T(B`@("`@
M("`@/3X@;F5W(%-/05!?5F%L=64H(D%R=&ES="(L(G-T<FEN9R(L(G-O;64@
M87)T:7-T("1I(BDL"B`@("`@("`@("`@("`@("`@("`@("`@(")!;&)U;2(@
M("`@("`@("`]/B!N97<@4T]!4%]686QU92@B06QB=6TB+")S=')I;F<B+")S
M;VUE(&%L8G5M("1I(BDL"B`@("`@("`@("`@("`@("`@("`@("`@(")996%R
M(B`@("`@("`@("`]/B!N97<@4T]!4%]686QU92@B665A<B(L(FEN="(L*&EN
M=&5G97(I,3DY.2DL"B`@("`@("`@("`@("`@("`@("`@("`@(")'96YR92(@
M("`@("`@("`]/B!N97<@4T]!4%]686QU92@B1V5N<F4B+")I;G0B+"AI;G1E
M9V5R*3$P,"DL"B`@("`@("`@("`@("`@("`@("`@("`@(")#;VUM96YT(B`@
M("`@("`]/B!N97<@4T]!4%]686QU92@B0V]M;65N="(L(G-T<FEN9R(L(F)L
M86)L82`D:2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`B0V]M<&]S97(B
M("`@("`@/3X@;F5W(%-/05!?5F%L=64H(D-O;7!O<V5R(BPB<W1R:6YG(BPB
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@(")/<FEG7T%R=&ES="(@("`]
M/B!N97<@4T]!4%]686QU92@B3W)I9U]!<G1I<W0B+")S=')I;F<B+"(B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@(E523"(@("`@("`@("`@(#T^(&YE
M=R!33T%07U9A;'5E*")54DPB+")S=')I;F<B+"(B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@(D5N8V]D961?8GDB("`@(#T^(&YE=R!33T%07U9A;'5E
M*")%;F-O9&5D7V)Y(BPB<W1R:6YG(BPB(BD*("`@("`@("`@("`@("`@("`@
M("`@("`@*0H@("`@("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@
M"B`@("`@("`@)$UE=&AO9$1E8G5G6R)R8R)=("`@(#T@;F5W(%-/05!?5F%L
M=64H(G)C(BPB8F]O;&5A;B(L=')U92D["B`@("`@("`@)$UE=&AO9$1E8G5G
M6R)%<G).;R)=(#T@;F5W(%-/05!?5F%L=64H(D5R<DYO(BPB:6YT(BPH:6YT
M96=E<BDP*3L*("`@("`@("`D365T:&]D1&5B=6=;(D5R<F]R(ET@/2!N97<@
M4T]!4%]686QU92@B17)R;W(B+")S=')I;F<B+"(B*3L*("`@("`@("`@("`@
M"B`@("`@("`@<F5T=7)N(&YE=R!33T%07U9A;'5E*"=R971U<FXG+"=[=7)N
M.DU0,T1"?4=E=$U0,U1R86-K<U)E<W5L="<L87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@(DUE=&AO9$1E8G5G(B`]/B!N97<@4T]!4%]686QU92@G365T
M:&]D1&5B=6<G+"=[=7)N.DU0,T1"?4UE=&AO9$1E8G5G)RPD365T:&]D1&5B
M=6<I+`H@("`@("`@("`@("`@("`@("`@(")-4#-4<F%C:W,B("`@/3X@;F5W
M(%-/05!?5F%L=64H)TU0,U1R86-K<R<L)WMU<FXZ35`S1$)]35`S5')A8VMS
M07)R87DG+"1T:&ES+3Y-4#-4<F%C:W,I"B`@("`@("`@("`@("`@("`@("`@
M*0H@("`@("`@("`@("`@("`@*3L*("`@('T*("`@(`H@("`@"B`@("!F=6YC
M=&EO;B!!9&1-4#-4<F%C:R@D35`S5')A8VLI('L*("`@("`@("`C('=E;&PL
M(&QE=',@:6UA9VEN92!H97)E('-O;64@8V]D92!F;W(@861D:6YG(&=I=F5N
M(&UP,W1R86-K('1O(&1B(&]R('=H871E=F5R+BXN"B`@("`@("`@)$UE=&AO
M9$1E8G5G6R)R8R)=("`@(#T@;F5W(%-/05!?5F%L=64H(G)C(BPB8F]O;&5A
M;B(L=')U92D["B`@("`@("`@)$UE=&AO9$1E8G5G6R)%<G).;R)=(#T@;F5W
M(%-/05!?5F%L=64H(D5R<DYO(BPB:6YT(BPH:6YT96=E<BDP*3L*("`@("`@
M("`D365T:&]D1&5B=6=;(D5R<F]R(ET@/2!N97<@4T]!4%]686QU92@B17)R
M;W(B+")S=')I;F<B+"(B*3L*("`@("`@("`*("`@("`@("!R971U<FX@;F5W
M(%-/05!?5F%L=64H)W)E='5R;B<L)WMU<FXZ35`S1$)]061D35`S5')A8VM2
M97-U;'0G+&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")-971H;V1$96)U
M9R(@/3X@;F5W(%-/05!?5F%L=64H)TUE=&AO9$1E8G5G)RPG>W5R;CI-4#-$
M0GU-971H;V1$96)U9R<L)$UE=&AO9$1E8G5G*0H@("`@("`@("`@("`@("`@
M("`@("D*("`@("`@("`@("`@("`@("D["B`@("!]"B`@("`*("`@(`H@("`@
M9G5N8W1I;VX@7U]D:7-P871C:"@D;65T:&]D;F%M92D@>PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7U]D:7-P871C:%]M87!;)&UE=&AO9&YA;65=*2D*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?7V1I<W!A=&-H7VUA<%LD;65T
M:&]D;F%M95T["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]"GT*"B1S97)V
M97(@/2!N97<@4T]!4%]397)V97(["B1S97)V97(M/E]A=71O7W1R86YS;&%T
M:6]N(#T@=')U93L*)$U0,T1"7T-L87-S(#T@;F5W($U0,T1"7T-L87-S*"D[
M"B1S97)V97(M/F%D9$]B:F5C=$UA<"@D35`S1$)?0VQA<W,L)W5R;CI-4#-$
M0B<I.PH*"FEF("AI<W-E="@D7U-%4E9%4ELG4D5154535%]-151(3T0G72D@
M)B8*("`@("1?4T525D526R=215%515-47TU%5$A/1"==/3TG4$]35"<I('L*
M("`@("1S97)V97(M/G-E<G9I8V4H)$A45%!?4D%77U!/4U1?1$%402D["GT@
M96QS92!["B`@("!R97%U:7)E7V]N8V4@)U-/05`O1&ES8V\N<&AP)SL*("`@
M("1D:7-C;R`](&YE=R!33T%07T1)4T-/7U-E<G9E<B@D<V5R=F5R+")-4#-$
M0B(I.PH@("`@:&5A9&5R*")#;VYT96YT+71Y<&4Z('1E>'0O>&UL(BD["B`@
M("!I9B`H:7-S970H)%]315)615);)U%515)97U-44DE.1R==*2`F)@H@("`@
M("`@<W1R8V%S96-M<"@D7U-%4E9%4ELG455%4EE?4U1224Y')UTL)W=S9&PG
M*3T],"D@>PH@("`@("`@(&5C:&\@)&1I<V-O+3YG97174T1,*"D["B`@("!]
M(&5L<V4@>PH@("`@("`@(&5C:&\@)&1I<V-O+3YG971$25-#3R@I.PH@("`@
M?0H@("`@97AI=#L*?0H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O
M96UA:6Q?<&]P7V=A=&5W87DN<&AP````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4P,#(`,3`T
M,3<S-C,P,#0`,#(T-C4W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V
M96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R
M92`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)
M9#H@96UA:6Q?<&]P7V=A=&5W87DN<&AP+'8@,2XT(#(P,#,O,#0O,#@@,#8Z
M,C$Z-3`@<VAA;F4@17AP("0*+R\*"B\J(&EN8VQU9&4@=&AE($5M86EL('-E
M<G9E<B!C;&%S<RP@=VAI8V@@:VYO=W,@:&]W('1O"B`@('!A<G-E(&$@<W1A
M;F1A<F0@96UA:6P@87,@82!S;V%P(&UE<W-A9V4@*B\*"G)E<75I<F5?;VYC
M92`G4T]!4"]397)V97(O16UA:6Q?1V%T97=A>2YP:'`G.PH*+RH@:6YC;'5D
M92!A(&-L87-S('1O(&%C8V5S<R!03U`S("HO"@IR97%U:7)E7V]N8V4@)TYE
M="]03U`S+G!H<"<["@HO*B!C<F5A=&4@=&AE(%-/05`@4V5R=F5R(&]B:F5C
M="`J+PH*)'-E<G9E<B`](&YE=R!33T%07U-E<G9E<E]%;6%I;%]'871E=V%Y
M*"=H='1P.B\O;&]C86QH;W-T+W-O87!?:6YT97)O<"]S97)V97)?<F]U;F0R
M+G!H<"<I.PH*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E('1O(&-L87-S
M97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?875T;U]T
M<F%N<VQA=&EO;B`]('1R=64["@IR97%U:7)E7V]N8V4@)V5X86UP;&5?<V5R
M=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L95]397)V
M97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L)W5R;CI3
M3T%07T5X86UP;&5?4V5R=F5R)RD["@H*+RH@0V]N;F5C="!T;R!A(%!/4#,@
M<V5R=F5R(&%N9"!R96%D('1H92!M97-S86=E<R`J+PH*)'!O<#,@/28@;F5W
M($YE=%]03U`S*"D["FEF("@D<&]P,RT^8V]N;F5C="@G;&]C86QH;W-T)RP@
M,3$P*2D@>PH@("`@:68@*"1P;W`S+3YL;V=I;B@G=7-E<FYA;64G+"`G<&%S
M<W=O<F0G*2D@>PH@("`@("`@("1L:7-T:6YG(#T@)'!O<#,M/F=E=$QI<W1I
M;F<H*3L*"@DO*B!N;W<@;&]O<"!T:')O=6=H(&5A8V@@;65S<V%G92P@86YD
M(&-A;&P@=&AE(`H@("`@("`@("`@(%-/05`@<V5R=F5R('=I=&@@=&AA="!M
M97-S86=E("HO"@H@("`@("`@(&9O<F5A8V@@*"1L:7-T:6YG(&%S("1M<V<I
M('L*"B`@("`@("`@("`@("1E;6%I;"`]("1P;W`S+3YG971-<V<H)&US9ULG
M;7-G7VED)UTI.PH*("`@("`@("`@("`@+RH@=&AI<R!I<R!W:&5R92!W92!A
M8W1U86QL>2!H86YD;&4@=&AE(%-/05`*("`@("`@("`@("`@("`@<F5S<&]N
M<V4N("!4:&4@4T]!4#HZ4V5R=F5R.CI%;6%I;"!C;&%S<R!W90H@("`@("`@
M("`@("`@("!A<F4@=7-I;F<@=VEL;"!S96YD('1H92!33T%0(')E<W!O;G-E
M('1O(`H@("`@("`@("`@("`@("!T:&4@<V5N9&5R('9I82!E;6%I;"X@*B\*
M"B`@("`@("`@("`@(&EF("@D96UA:6PI("1S97)V97(M/G-E<G9I8V4H)&5M
M86EL*3L*"B`@("`@("`@("`@(",D<&]P,RT^9&5L971E37-G*"1M<V=;)VUS
M9U]I9"==*3L*("`@("`@("!]"B`@("!]"B`@("`D<&]P,RT^9&ES8V]N;F5C
M="@I.PI]"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]C;VU?8VQI96YT+G!H<```
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#(R-0`Q,#0Q-S,V,S`P-``P,C,S,3,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0
M(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E
M;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E
M;RYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!C;VU?8VQI96YT+G!H
M<"QV(#$N,2`R,#`S+S`T+S$X(#(P.C4R.C(X('-H86YE($5X<"`D"B\O"B\O
M(%-/05!3=')U8W0@:7,@9&5F:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9I;&4*
M<F5Q=6ER95]O;F-E("=E>&%M<&QE7W1Y<&5S+G!H<"<["@HO*B!J=7-T(&$@
M<VEM<&QE(&5X86UP;&4@;V8@=7-I;F<@35,@4T]!4"!O;B!W:6XS,B!A<R!A
M(&-L:65N=`H@("!T;R!T:&4@<&AP('-E<G9E<BX@("HO"@HO+VQO860@0T]-
M(%-/05`@8VQI96YT(&]B:F5C=`HD<V]A<&-L:65N="`](&YE=R!#3TTH(DU3
M4T]!4"Y3;V%P0VQI96YT,S`B*3L*"B\O8V]N;F5C="!T;R!W96(@<V5R=FEC
M90HD<V]A<&-L:65N="T^;7-S;V%P:6YI="@B:'1T<#HO+VQO8V%L:&]S="]3
M3T%0+V5X86UP;&4O<V5R=F5R+G!H<#]W<V1L(BD["@HO+V]B=&%I;B!R97-U
M;'0@9G)O;2!W96(@<V5R=FEC92!M971H;V0*)')E="`]("1S;V%P8VQI96YT
M+3YE8VAO4W1R:6YG*")4:&ES(&ES(&$@=&5S="$B*3L*<')I;G0H(B1R971<
M;B(I.PH*)')E="`]("1S;V%P8VQI96YT+3YE8VAO4W1R:6YG4VEM<&QE*")4
M:&ES(&ES(&%N;W1H97(@=&5S="$B*3L*<')I;G0H(B1R971<;B(I.PH*(R!T
M:&4@9F]L;&]W:6YG(&-A=7-E<R!A;B!E>&-E<'1I;VX@:6X@=&AE($-/32!E
M>'1E;G-I;VX*"B,D<F5T(#T@)'-O87!C;&EE;G0M/F1I=FED92@R,BPW*3L*
M(W!R:6YT("1S;V%P8VQI96YT+3YF875L=&-O9&4["B-P<FEN="`D<V]A<&-L
M:65N="T^9F%U;'1S=')I;F<["B-P<FEN="@B,C(O-STD<F5T7&XB*3L*(W!R
M:6YT7W(H)')E="D["B,D<F5T(#T@)'-O87!C;&EE;G0M/F1I=FED92@R,BPP
M*3L*(W!R:6YT*"(R,B\P/21R971<;B(I.PH*(R1S=')U8W0@/2!N97<@4T]!
M4%-T<G5C="@G=&5S="!S=')I;F<G+#$R,RPQ,C,N,3(S*3L*(R1R970@/2`D
M<V]A<&-L:65N="T^96-H;U-T<G5C="@D<W1R=6-T*3L*(W!R:6YT7W(H)')E
M="D["@HC)')E="`]("1S;V%P8VQI96YT+3YE8VAO4W1R=6-T07-3:6UP;&54
M>7!E<R@D<W1R=6-T*3L*(W!R:6YT7W(H)')E="D["@H_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S97)V
M97(R+G!H<```````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3`U,@`Q,#0Q-S,V
M,S`P-``P,C(U-C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@
M=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\
M4VAA;F5`0V%R879E;RYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!S
M97)V97(R+G!H<"QV(#$N,2`R,#`S+S`T+S$W(#`V.C`T.C0P('-H86YE($5X
M<"`D"B\O"@HO+R!F:7)S="P@:6YC;'5D92!T:&4@4T]!4"]397)V97(@8VQA
M<W,*<F5Q=6ER95]O;F-E("=33T%0+U-E<G9E<BYP:'`G.PH*)'-E<G9E<B`]
M(&YE=R!33T%07U-E<G9E<CL*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E
M('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R
M+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R=64["@HO*B!4:&ES(&ES(&$@<VEM
M<&QE(&5X86UP;&4@;V8@:6UP;&5M96YT:6YG(&$@8W5S=&]M"B`@(&-A;&P@
M:&%N9&QE<BX@($EF('EO=2!D;R!T:&ES+"!T:&4@<V]A<"!S97)V97(@=VEL
M;"!I9VYO<F4*("`@;V)J96-T<R!O<B!F=6YC=&EO;G,@861D960@=&\@:70L
M(&%N9"!W:6QL(&-A;&P@>6]U<B!H86YD;&5R"B`@(&9O<B`J*D%,3"HJ('-O
M87`@8V%L;',@=&AE('-E<G9E<B!R96-E:79E<RP@=V5T:&5R('1H92!C86QL
M"B`@(&ES(&1E9FEN960@:6X@>6]U<B!74T1,(&]R(&YO="X@(%1H92!H86YD
M;&5R(')E8V5I=F5S('1W;PH@("!A<F=U;65N=',L('1H92!M971H;V0@;F%M
M92!B96EN9R!C86QL960L(&%N9"!T:&4@87)G=6UE;G1S"B`@('-E;G0@9F]R
M('1H870@8V%L;"X**B\*9G5N8W1I;VX@;7E#86QL2&%N9&QE<B@D;65T:&]D
M;F%M92P@)&%R9W,I"GL*("`@(&=L;V)A;"`D<V]A<&-L87-S.PH@("`@<F5T
M=7)N($!C86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@D<V]A<&-L87-S+"`D
M;65T:&]D;F%M92DL)&%R9W,I.PI]"B1S97)V97(M/G-E=$-A;&Q(86YD;&5R
M*"=M>4-A;&Q(86YD;&5R)RQF86QS92D["@IR97%U:7)E7V]N8V4@)V5X86UP
M;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L
M95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L
M)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["@II9B`H:7-S970H)%]315)6
M15);)U)%455%4U1?34542$]$)UTI("8F"B`@("`D7U-%4E9%4ELG4D515453
M5%]-151(3T0G73T])U!/4U0G*2!["B`@("`D<V5R=F5R+3YS97)V:6-E*"1(
M5%107U)!5U]03U-47T1!5$$I.PI](&5L<V4@>PH@("`@<F5Q=6ER95]O;F-E
M("=33T%0+T1I<V-O+G!H<"<["B`@("`D9&ES8V\@/2!N97<@4T]!4%]$25-#
M3U]397)V97(H)'-E<G9E<BPG4V5R=F5R17AA;7!L92<I.PH@("`@:&5A9&5R
M*")#;VYT96YT+71Y<&4Z('1E>'0O>&UL(BD["B`@("!I9B`H:7-S970H)%]3
M15)615);)U%515)97U-44DE.1R==*2`F)@H@("`@("`@<W1R8V%S96-M<"@D
M7U-%4E9%4ELG455%4EE?4U1224Y')UTL)W=S9&PG*3T],"D@>PH@("`@("`@
M(&5C:&\@)&1I<V-O+3YG97174T1,*"D["B`@("!](&5L<V4@>PH@("`@("`@
M(&5C:&\@)&1I<V-O+3YG971$25-#3R@I.PH@("`@?0H@("`@97AI=#L*?0H_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5X86UP;&5?<V5R=F5R+G!H<```
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$T,C4T`#$P-#$W,S8S,#`T`#`R-#(R,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R
M<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O
M=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A
M=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@
M?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S
M92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O
M;3X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&5X86UP;&5?<V5R=F5R+G!H
M<"QV(#$N,R`R,#`S+S`W+S,Q(#`P.C4U.C4W('-H86YE($5X<"`D"B\O"@HO
M+R!F:7)S="P@:6YC;'5D92!T:&4@4T]!4"]397)V97(@8VQA<W,*<F5Q=6ER
M95]O;F-E("=33T%0+U9A;'5E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]&
M875L="YP:'`G.PH*+R\@4T]!4%-T<G5C="!I<R!D969I;F5D(&EN('1H92!F
M;VQL;W=I;F<@9FEL90IR97%U:7)E7V]N8V4@)V5X86UP;&5?='EP97,N<&AP
M)SL*"B\O(&-R96%T92!A(&-L87-S(&9O<B!Y;W5R('-O87`@9G5N8W1I;VYS
M"F-L87-S(%-/05!?17AA;7!L95]397)V97(@>PH@("`@+RHJ"B`@("`@*B!4
M:&4@9&ES<&%C=&-H(&UA<"!D;V5S(&YO="!N965D('1O(&)E('5S960L(&)U
M="!A:61S"B`@("`@*B!T:&4@<V5R=F5R(&-L87-S(&EN(&MN;W=I;F<@=VAA
M="!P87)A;65T97)S(&%R92!U<V5D"B`@("`@*B!W:71H('1H92!F=6YC=&EO
M;G,N("!4:&ES(&ES('1H92!/3DQ9('=A>2!T;R!H879E"B`@("`@*B!M=6QT
M:7!L92!/550@<&%R86UE=&5R<RX@($EF('EO=2!U<V4@82!D:7-P871C:"!M
M87`L('EO=0H@("`@("H@35535"!A9&0@04Q,(&9U;F-T:6]N<R!Y;W4@=VES
M:"!T;R!A;&QO=R!B92!C86QL960N("!)9@H@("`@("H@>6]U(&1O(&YO="!U
M<V4@82!D:7-P871C:"!M87`L('1H96X@86YY('!U8FQI8R!F=6YC=&EO;@H@
M("`@("H@8V%N(&)E(&-A;&QE9"!F<F]M('-O87`@*&EN('!H<#0L('=E(&-O
M;G-I9&5R('1H:7,@=&\@8F4*("`@("`J(&%N>2!F=6YC=&EO;B!I;B!T:&4@
M8VQA<W,@=6YL97-S(&ET('-T87)T<R!W:71H('5N9&5R<V-O<F4L"B`@("`@
M*B!P:'`U('-U<'!O<G0@:7,@;F]T(&-O;7!L971E('EE="!I;B!T:&ES(')E
M9V%R9"DN("`*("`@("`J(&EF('EO=2!D;R!N;W0@9&5F:6YE(&EN+V]U="!P
M87)A;65T97)S+"!T:&4@9G5N8W1I;VX@8V%N(&)E"B`@("`@*B!C86QL960@
M=VET:"!P87)A;65T97)S+"!B=70@;F\@=F%L:61A=&EO;B!O;B!P87)A;65T
M97)S('=I;&P*("`@("`J(&]C8W5R92X*("`@("`J+PH@("`@=F%R("1?7V1I
M<W!A=&-H7VUA<"`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@4T]!4%]%>&%M
M<&QE7U-E<G9E<B@I('L*("`@("`@("`O*BH*("`@("`@("`J('=H96X@9V5N
M97)A=&EN9R!W<V1L(&9O<B!A('-E<G9E<BP@>6]U(&AA=F4@=&\@9&5F:6YE
M"B`@("`@("`@*B!A;GD@<W!E8VEA;"!C;VUP;&5X('1Y<&5S('1H870@>6]U
M('5S92`H:64@8VQA<W-E<RDN"B`@("`@("`@*B!U<VEN9R!A(&YA;65S<&%C
M92!I9"!B969O<F4@=&AE('1Y<&4@=VEL;"!C<F5A=&4@86X*("`@("`@("`J
M('AM;"!S8VAE;6$@=VET:"!T:&4@=&%R9V5T3F%M97-P86-E(&9O<B!T:&4@
M='EP90H@("`@("`@("H@;75L=&EP;&4@='EP97,@=VET:"!T:&4@<V%M92!N
M86UE<W!A8V4@=VEL;"!A<'!E87(*("`@("`@("`J(&EN('1H92!S86UE('-C
M:&5M82!S96-T:6]N+B`@='EP97,@=VET:"!D:69F97)E;G0*("`@("`@("`J
M(&YA;65S<&%C97,@=VEL;"!B92!I;B!S97!E<F%T92!S8VAE;6$@<V5C=&EO
M;G,N"B`@("`@("`@*B!T:&4@9F]L;&]W:6YG(%-/05!3=')U8W0@='EP961E
M9B!C;V]R97-P;VYD<R!T;R!T:&4*("`@("`@("`J(%-/05!3=')U8W0@8VQA
M<W,@86)O=F4N"B`@("`@("`@*B\*("`@("`@("`D=&AI<RT^7U]T>7!E9&5F
M6R=[:'1T<#HO+W-O87!I;G1E<F]P+F]R9R]X<V1]4T]!4%-T<G5C="==(#T@
M"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("=V87)3=')I;F<G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G=F%R26YT)R`]/B`G:6YT)RP@"B`@("`@("`@("`@("`@
M("`@("`@("`@("=V87)&;&]A="<@/3X@)V9L;V%T)PH@("`@("`@("`@("`@
M("`@("`@("`@("`@*3L*"B`@("`@("`@+R\@86X@86QI87-E9"!F=6YC=&EO
M;B!W:71H(&UU;'1I<&QE(&]U="!P87)A;65T97)S"@DD=&AI<RT^7U]D:7-P
M871C:%]M87!;)V5C:&]3=')U8W1!<U-I;7!L951Y<&5S)UT@/0H)"6%R<F%Y
M*"=I;B<@/3X@87)R87DH)VEN<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P
M:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G*2P*"0D@("`@("`G;W5T)R`]
M/B!A<G)A>2@G;W5T<'5T4W1R:6YG)R`]/B`G<W1R:6YG)RP@)V]U='!U=$EN
M=&5G97(G(#T^("=I;G0G+"`G;W5T<'5T1FQO870G(#T^("=F;&]A="<I+`H)
M"2`@("`@("=A;&EA<R<@/3X@)VUY16-H;U-T<G5C=$%S4VEM<&QE5'EP97,G
M"@D)("`@("`@*3L*"21T:&ES+3Y?7V1I<W!A=&-H7VUA<%LG96-H;U-T<FEN
M9U-I;7!L92==(#T*"0EA<G)A>2@G:6XG(#T^(&%R<F%Y*"=I;G!U=%-T<FEN
M9U-I;7!L92<@/3X@)W-T<FEN9R<I+`H)"2`@("`@("=O=70G(#T^(&%R<F%Y
M*"=O=71P=713=')I;F=3:6UP;&4G(#T^("=S=')I;F<G*2P*"0D@("`@("`I
M.PH))'1H:7,M/E]?9&ES<&%T8VA?;6%P6R=E8VAO4W1R:6YG)UT@/0H)"6%R
M<F%Y*"=I;B<@/3X@87)R87DH)VEN<'5T4W1R:6YG)R`]/B`G<W1R:6YG)RDL
M"@D)("`@("`@)V]U="<@/3X@87)R87DH)V]U='!U=%-T<FEN9R<@/3X@)W-T
M<FEN9R<I+`H)"2`@("`@("D["@DD=&AI<RT^7U]D:7-P871C:%]M87!;)V1I
M=FED92==(#T*"0EA<G)A>2@G:6XG(#T^(&%R<F%Y*"=D:79I9&5N9"<@/3X@
M)VEN="<L("=D:79I<V]R)R`]/B`G:6YT)RDL"@D)("`@("`@)V]U="<@/3X@
M87)R87DH)V]U='!U=$9L;V%T)R`]/B`G9FQO870G*2P*"0D@("`@("`I.PH)
M)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R=E8VAO4W1R=6-T)UT@/0H)"6%R<F%Y
M*"=I;B<@/3X@87)R87DH)VEN<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P
M:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G*2P*"0D@("`@("`G;W5T)R`]
M/B!A<G)A>2@G;W5T<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P:6YT97)O
M<"YO<F<O>'-D?5-/05!3=')U8W0G*2P*"0D@("`@("`I.PH)"@DD=&AI<RT^
M7U]D:7-P871C:%]M87!;)V5C:&]-:6UE071T86-H;65N="==(#T@87)R87DH
M*3L*("`@('T*"B`@("`O*B!T:&ES('!R:79A=&4@9G5N8W1I;VX@:7,@8V%L
M;&5D(&]N(&)Y(%-/05!?4V5R=F5R('1O(&1E=&5R;6EN92!A;GD*("`@("`@
M("!S<&5C:6%L(&1I<W!A=&-H(&EN9F]R;6%T:6]N('1H870@;6EG:'0@8F4@
M;F5C97-S87)Y+B`@5&AI<RP@9F]R(&5X86UP;&4L"B`@("`@("`@8V%N(&)E
M('5S960@=&\@<V5T('5P(&$@9&ES<&%T8V@@;6%P(&9O<B!F=6YC=&EO;G,@
M=&AA="!R971U<FX@;75L=&EP;&4*("`@("`@("!/550@<&%R86UE=&5R<R`J
M+PH@("`@9G5N8W1I;VX@7U]D:7-P871C:"@D;65T:&]D;F%M92D@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7U]D:7-P871C:%]M87!;)&UE=&AO9&YA
M;65=*2D*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?7V1I<W!A=&-H7VUA
M<%LD;65T:&]D;F%M95T["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]"@H@
M("`@+R\@82!S:6UP;&4@96-H;U-T<FEN9R!F=6YC=&EO;@H@("`@9G5N8W1I
M;VX@96-H;U-T<FEN9U-I;7!L92@D:6YP=713=')I;F<I"B`@("!["@ER971U
M<FX@)&EN<'5T4W1R:6YG.PH@("`@?0H@("`@"B`@("`O+R!A;B!E>'!L:6-I
M="!E8VAO<W1R:6YG(&9U;F-T:6]N"B`@("!F=6YC=&EO;B!E8VAO4W1R:6YG
M*"1I;G!U=%-T<FEN9RD*("`@('L*"7)E='5R;B!N97<@4T]!4%]686QU92@G
M;W5T<'5T4W1R:6YG)RPG<W1R:6YG)RPD:6YP=713=')I;F<I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&1I=FED92@D9&EV:61E;F0L("1D:79I<V]R*0H@("`@
M>PH@("`@("`@("\O('1H92!S;V%P('-E<G9E<B!W;W5L9"!N;W)M86QL>2!C
M871C:"!E<G)O<G,@;&EK92!T:&ES"B`@("`@("`@+R\@86YD(')E='5R;B!A
M(&9A=6QT+"!B=70@=&AI<R!I<R!H;W<@>6]U(&1O(&ET('EO=7)S96QF+@H@
M("`@("`@(&EF("@D9&EV:7-O<B`]/2`P*0H@("`@("`@("`@("!R971U<FX@
M;F5W(%-/05!?1F%U;'0H)UEO=2!C86YN;W0@9&EV:61E(&)Y('IE<F\G+"`G
M0VQI96YT)RD["B`@("`@("`@96QS90H@("`@("`@("`@("!R971U<FX@)&1I
M=FED96YD("\@)&1I=FES;W(["B`@("!]"@H@("`@9G5N8W1I;VX@96-H;U-T
M<G5C="@D:6YP=713=')U8W0I"B`@("!["B`@("`@("`@<F5T=7)N("1I;G!U
M=%-T<G5C="T^7U]T;U]S;V%P*"=O=71P=713=')U8W0G*3L*"2-R971U<FX@
M;F5W(%-/05!?5F%L=64H)V]U='!U=%-T<G5C="<L)WMH='1P.B\O<V]A<&EN
M=&5R;W`N;W)G+WAS9'U33T%04W1R=6-T)RPD:6YP=713=')U8W0I.PH@("`@
M?0H@("`@"B`@("`O*BH*("`@("`J(&5C:&]3=')U8W1!<U-I;7!L951Y<&5S
M"B`@("`@*B!T86ME<R!A(%-/05!3=')U8W0@87,@:6YP=70L(&%N9"!R971U
M<FYS(&5A8V@@;V8@:71S(&5L96UE;G1S"B`@("`@*B!A<R!/550@<&%R86UE
M=&5R<PH@("`@("H*("`@("`J('1H:7,@9G5N8W1I;VX@:7,@86QS;R!A;&EA
M<V5D('-O('EO=2!H879E('1O(&-A;&P@:70@=VET:`H@("`@("H@96-H;U-T
M<G5C=$%S4VEM<&QE5'EP97,*("`@("`J"B`@("`@*B!33T%04W1R=6-T(&ES
M(&1E9FEN960@87,Z"B`@("`@*@H@("`@("H@<W1R=6-T(%-/05!3=')U8W0Z
M"B`@("`@*B`@("!S=')I;F<@=F%R4W1R:6YG"B`@("`@*B`@("!I;G1E9V5R
M('9A<DEN=`H@("`@("H@("`@9FQO870@=F%R1FQO870*("`@("`J"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&UY16-H;U-T<G5C=$%S4VEM<&QE5'EP97,H)'-T
M<G5C="D*("`@('L*"2,@8V]N=F5R="!A(%-/05!3=')U8W0@=&\@86X@87)R
M87D*"7)E='5R;B!A<G)A>2@*"2`@("!N97<@4T]!4%]686QU92@G;W5T<'5T
M4W1R:6YG)RPG<W1R:6YG)RPD<W1R=6-T+3YV87)3=')I;F<I+`H)("`@(&YE
M=R!33T%07U9A;'5E*"=O=71P=71);G1E9V5R)RPG:6YT)RPD<W1R=6-T+3YV
M87));G0I+`H)("`@(&YE=R!33T%07U9A;'5E*"=O=71P=71&;&]A="<L)V9L
M;V%T)RPD<W1R=6-T+3YV87)&;&]A="D*"2`@("`I.PH@("`@?0H@("`@"B`@
M("!F=6YC=&EO;B!E8VAO36EM94%T=&%C:&UE;G0H)'-T=69F*0H@("`@>PH@
M("`@("`@(')E='5R;B!N97<@4T]!4%]!='1A8VAM96YT*"=R971U<FXG+"=A
M<'!L:6-A=&EO;B]O8W1E="US=')E86TG+$Y53$PL)'-T=69F*3L*("`@('T@
M("`@"GT*"C\^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]T8W!?<V5R
M=F5R+G!H<``````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$R,``Q,#0Q-S,V,S`P
M-``P,C,S-#0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P
M,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE
M(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@
M("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA
M;F5`0V%R879E;RYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!T8W!?
M<V5R=F5R+G!H<"QV(#$N,B`R,#`S+S`T+S$Q(#`U.C,R.C$W('-H86YE($5X
M<"`D"B\O"@HO+R!F:7)S="P@:6YC;'5D92!T:&4@4T]!4"]397)V97(@8VQA
M<W,*<F5Q=6ER95]O;F-E("=33T%0+U-E<G9E<B]40U`N<&AP)SL*<V5T7W1I
M;65?;&EM:70H,"D["@HD<V5R=F5R(#T@;F5W(%-/05!?4V5R=F5R7U1#4"@B
M,3(W+C`N,"XQ(BPX,BD["B\J('1E;&P@<V5R=F5R('1O('1R86YS;&%T92!T
M;R!C;&%S<V5S('=E('!R;W9I9&4@:68@<&]S<VEB;&4@*B\*)'-E<G9E<BT^
M7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PH*<F5Q=6ER95]O;F-E("=E>&%M
M<&QE7W-E<G9E<BYP:'`G.PH*)'-O87!C;&%S<R`](&YE=R!33T%07T5X86UP
M;&5?4V5R=F5R*"D["B1S97)V97(M/F%D9$]B:F5C=$UA<"@D<V]A<&-L87-S
M+"=U<FXZ4T]!4%]%>&%M<&QE7U-E<G9E<B<I.PHD<V5R=F5R+3YR=6XH*3L*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O=W-D;%]C;&EE;G0N
M<&AP````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8T-C,`,3`T,3<S-C,P,#0`,#(S
M-3$T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@
M;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A
M<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=W-D;%]C;&EE
M;G0N<&AP+'8@,2XQ(#(P,#,O,#0O,3,@,C$Z,S@Z-3D@<VAA;F4@17AP("0*
M+R\*:6YC;'5D92@B4T]!4"]#;&EE;G0N<&AP(BD["@HO*BH*("H@=&AI<R!C
M;&EE;G0@<G5N<R!A9V%I;G-T('1H92!E>&%M<&QE('-E<G9E<B!I;B!33T%0
M+V5X86UP;&4O<V5R=F5R+G!H<`H@*B!I="!D;V5S(&YO="!U<V4@5U-$3"!T
M;R!R=6X@=&AE<V4@<F5Q=65S=',L(&)U="!T:&%T(&-A;B!B92!C:&%N9V5D
M(&5A<VEL>2!B>2!S:6UP;'D*("H@861D:6YG("<_=W-D;"<@=&\@=&AE(&5N
M9"!O9B!T:&4@=7)L+@H@*B\*)'=S9&P@/2!N97<@4T]!4%]74T1,*")H='1P
M.B\O;&]C86QH;W-T+U-/05`O97AA;7!L92]S97)V97(N<&AP/W=S9&PB*3L*
M)'-O87!C;&EE;G0@/2`D=W-D;"T^9V5T4')O>'DH*3L*"B1R970@/2`D<V]A
M<&-L:65N="T^96-H;U-T<FEN9U-I;7!L92@B=&AI<R!I<R!A('1E<W0@<W1R
M:6YG(BD["B-P<FEN="`D<V]A<&-L:65N="T^7U]G971?=VER92@I.PIP<FEN
M=%]R*"1R970I.V5C:&\@(CQB<CY<;B(["@HD<F5T(#T@)'-O87!C;&EE;G0M
M/F5C:&]3=')I;F<H(G1H:7,@:7,@82!T97-T('-T<FEN9R(I.PIP<FEN=%]R
M*"1R970I.V5C:&\@(CQB<CY<;B(["@HD<F5T(#T@)'-O87!C;&EE;G0M/F1I
M=FED92@R,BPW*3L*(R!P<FEN="`D<V]A<&-L:65N="T^7U]G971?=VER92@I
M.PII9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D*("`@('!R:6YT*")%<G)O<CH@
M(B`N("1R970M/F=E=$UE<W-A9V4H*2`N("(\8G(^7&XB*3L*96QS90H@("`@
M<')I;G0H(E%U;W1I96YT(&ES("(@+B`D<F5T("X@(CQB<CY<;B(I.PH*)')E
M="`]("1S;V%P8VQI96YT+3YD:79I9&4H,C(L,"D["FEF("A014%2.CII<T5R
M<F]R*"1R970I*0H@("`@<')I;G0H(D5R<F]R.B`B("X@)')E="T^9V5T365S
M<V%G92@I("X@(CQB<CY<;B(I.PIE;'-E"B`@("!P<FEN="@B475O=&EE;G0@
M:7,@(B`N("1R970@+B`B/&)R/EQN(BD["@H*+R\@4T]!4%-T<G5C="!I<R!D
M969I;F5D(&EN('1H92!F;VQL;W=I;F<@9FEL90IR97%U:7)E7V]N8V4@)V5X
M86UP;&5?='EP97,N<&AP)SL*"B1S=')U8W0@/2!N97<@4T]!4%-T<G5C="@G
M=&5S="!S=')I;F<G+#$R,RPQ,C,N,3(S*3L*"B\J('-E;F0@86X@;V)J96-T
M+"!G970@86X@;V)J96-T(&)A8VL@*B\*+RH@=&5L;"!C;&EE;G0@=&\@=')A
M;G-L871E('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD
M<V]A<&-L:65N="T^7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PHO*B!O<B!Y
M;W4@8V%N(&5X<&QI8VET;'D@<V5T('1H92!T<F%N<VQA=&EO;B!F;W(*("`@
M82!S<&5C:69I8R!C;&%S<RX@(&%U=&]?=')A;G-L871I;VX@=V]R:W,@9F]R
M(&%L;"!C87-E<RP*("`@8G5T(&]P96YS($%.62!C;&%S<R!I;B!T:&4@<V-R
M:7!T('1O(&)E('5S960@87,@82!D871A('1Y<&4L"B`@(&%N9"!M87D@;F]T
M(&)E(&1E<VER96%B;&4N("!B;W1H(&-A;B!B92!U<V5D(&]N(&-L:65N="!O
M<@H@("!S97)V97(@*B\*)'-O87!C;&EE;G0M/E]?<V5T7W1Y<&5?=')A;G-L
M871I;VXH)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS9'U33T%04W1R=6-T
M)RPG4T]!4%-T<G5C="<I.PHD<F5T(#T@)'-O87!C;&EE;G0M/F5C:&]3=')U
M8W0H)'-T<G5C="T^7U]T;U]S;V%P*"DI.PHC<')I;G0@)'-O87!C;&EE;G0M
M/E]?9V5T7W=I<F4H*3L*<')I;G1?<B@D<F5T*3L*"B\J*@H@*B!02%`@9&]E
M<VXG="!S=7!P;W)T(&UU;'1I<&QE($]55"!P87)A;65T97)S(&EN(&9U;F-T
M:6]N(&-A;&QS+"!S;R!W90H@*B!M=7-T(&1O(&$@;&ET=&QE('=O<FL@=&\@
M;6%K92!I="!H87!P96X@:&5R92X@(%1H:7,@<F5Q=6ER97,@:VYO=VQE9&=E
M(&]N('1H90H@*B!D979E;&]P97)S('!A<G0@=&\@9FEG=7)E(&]U="!H;W<@
M=&AE>2!W86YT('1O(&1E86P@=VET:"!I="X*("HO"B1R970@/2`D<V]A<&-L
M:65N="T^96-H;U-T<G5C=$%S4VEM<&QE5'EP97,H)'-T<G5C="T^7U]T;U]S
M;V%P*"DI.PII9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PH@("`@<')I;G0H
M(D5R<F]R.B`B("X@)')E="T^9V5T365S<V%G92@I("X@(CQB<CY<;B(I.PI]
M(&5L<V4@>PH@("`@;&ES="@D<W1R:6YG+"`D:6YT+"`D9FQO870I(#T@87)R
M87E?=F%L=65S*"1R970I.PI]"F5C:&\@(G9A<E-T<FEN9SH@)'-T<FEN9SQB
M<CY<;G9A<DEN=#H@)&EN=#QB<CY<;G9A<D9L;V%T.B`D9FQO870\8G(^7&XB
M.PH*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5M86EL7V=A=&5W
M87DN<&AP`````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#<R`#$P-#$W,S8S,#`T`#`R
M-#`Q,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#
M87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&5M86EL7V=A
M=&5W87DN<&AP+'8@,2XS(#(P,#,O,#0O,#@@,#8Z,C$Z-3`@<VAA;F4@17AP
M("0*+R\*"B\J"E1H:7,@<F5A9',@82!M97-S86=E(&9R;VT@<W1D:6XL(&%N
M9"!P87-S97,@=&AE(')E<75E<W0@=&\*82!S;V%P('-E<G9E<B!R97-I9&EN
M9R!O;B!A('=E8B!S97)V97(L('-E;F1S('1H92!R97-P;VYS90IO=70@87,@
M86X@96UA:6P*"EEO=2!C86X@=7-E('1H:7,@9G)O;2!Q;6%I;"!B>2!C<F5A
M=&EN9R!A("YQ;6%I;"US;V%P9V%T97=A>2!F:6QE('=I=&@Z"B`@("!\("]U
M<W(O8FEN+W!H<"`O<&%T:"]T;R]E;6%I;%]S97)V97(N<&AP"BHO"@HC(&EN
M8VQU9&4@=&AE(&5M86EL('-E<G9E<B!C;&%S<PIR97%U:7)E7V]N8V4@)U-/
M05`O4V5R=F5R+T5M86EL7T=A=&5W87DN<&AP)SL*"B,@<F5A9"!S=&1I;@HD
M9FEN(#T@9F]P96XH)W!H<#HO+W-T9&EN)RPG<F(G*3L*:68@*"$D9FEN*2!E
M>&ET*#`I.PH*)&5M86EL(#T@)R<["G=H:6QE("@A9F5O9B@D9FEN*2`F)B`D
M9&%T82`](&9R96%D*"1F:6XL(#@P.38I*2!["B`@)&5M86EL("X]("1D871A
M.PI]"@IF8VQO<V4H)&9I;BD["@HC(&1O:70A"B1S97)V97(@/2!N97<@4T]!
M4%]397)V97)?16UA:6Q?1V%T97=A>2@I.PHD<V5R=F5R+3YS97)V:6-E*"1D
M871A+"`G:'1T<#HO+VQO8V%L:&]S="]S;V%P+V5X86UP;&4O<V5R=F5R+G!H
M<"<I.PH_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]T8W!?8VQI96YT+G!H<```
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,W-P`Q,#0Q-S,V,S`P-``P,C,S,S(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0
M(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E
M;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R<SH@4VAA;F4@2&%N;F$@/&EO<F1Y7V%T7VEO<F1Y
M7V1O=%]C;VT^("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!T8W!?8VQI96YT+G!H
M<"QV(#$N,2`R,#`S+S`T+S`X(#`V.C(Q.C4P('-H86YE($5X<"`D"B\O"@IR
M97%U:7)E7V]N8V4H)U-/05`O0VQI96YT+G!H<"<I.PH*(R!C;&EE;G0*)'-O
M87!C;&EE;G0@/2!N97<@4T]!4%]#;&EE;G0H(G1C<#HO+S$R-RXP+C`N,3HX
M,B(I.PH*(R!N86UE<W!A8V4*)&]P=&EO;G,@/2!A<G)A>2@G;F%M97-P86-E
M)R`]/B`G=7)N.E-/05!?17AA;7!L95]397)V97(G+"`G=')A8V4G(#T^(#$I
M.PH*(R!O;F4*)'!A<F%M<R`](&%R<F%Y*")S=')I;F<B(#T^(")T:&ES(&ES
M('-T<FEN9R`Q(BD["B1R970Q(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3
M=')I;F<B+"`D<&%R86US+"`D;W!T:6]N<RD["B,@96-H;R`B5TE213H@7&XB
M+B1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E=#$I.PIE
M8VAO("(\8G(@+SY<;B(["@HC('1W;PHD<&%R86US(#T@87)R87DH(G-T<FEN
M9R(@/3X@(G1H:7,@:7,@<W1R:6YG(#(B*3L*)')E=#(@/2`D<V]A<&-L:65N
M="T^8V%L;"@B96-H;U-T<FEN9R(L("1P87)A;7,L("1O<'1I;VYS*3L*(R!E
M8VAO(")725)%.B!<;B(N)'-O87!C;&EE;G0M/E]?9V5T7W=I<F4H*3L*<')I
M;G1?<B@D<F5T,BD["F5C:&\@(CQB<B`O/EQN(CL*"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]33T%0+V5X86UP;&4O96UA:6Q?<V5R=F5R+G!H<```````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,V-#<`,3`T,3<S-C,P,#0`,#(S-C8S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\O
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S
M:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@
M("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V
M86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M
M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R92`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@96UA:6Q?<V5R=F5R+G!H<"QV
M(#$N,R`R,#`S+S`T+S`X(#`V.C(Q.C4P('-H86YE($5X<"`D"B\O"@HO*@I4
M:&ES(')E861S(&$@;65S<V%G92!F<F]M('-T9&EN+"!A;F0@8V%L;',@=&AE
M('-O87`@<V5R=F5R(&1E9FEN960*"EEO=2!C86X@=7-E('1H:7,@9G)O;2!Q
M;6%I;"!B>2!C<F5A=&EN9R!A("YQ;6%I;"US;V%P=&5S="!F:6QE('=I=&@Z
M"B`@("!\("]U<W(O8FEN+W!H<"`O<&%T:"]T;R]E;6%I;%]S97)V97(N<&AP
M"BHO"@HC(&EN8VQU9&4@=&AE(&5M86EL('-E<G9E<B!C;&%S<PIR97%U:7)E
M7V]N8V4@)U-/05`O4V5R=F5R+T5M86EL+G!H<"<["@HD<V5R=F5R(#T@;F5W
M(%-/05!?4V5R=F5R7T5M86EL.PH*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L
M871E('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R
M=F5R+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R=64["@IR97%U:7)E7V]N8V4@
M)V5X86UP;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?
M17AA;7!L95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P
M8VQA<W,L)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["@HC(')E860@<W1D
M:6X*)&9I;B`](&9O<&5N*"=P:'`Z+R]S=&1I;B<L)W)B)RD["FEF("@A)&9I
M;BD@97AI="@P*3L*"B1E;6%I;"`]("<G.PIW:&EL92`H(69E;V8H)&9I;BD@
M)B8@)&1A=&$@/2!F<F5A9"@D9FEN+"`X,#DV*2D@>PH@("1E;6%I;"`N/2`D
M9&%T83L*?0H*9F-L;W-E*"1F:6XI.PH*(R!D;VET(0HD<V5R=F5R+3YS97)V
M:6-E*"1E;6%I;"D["@H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O4T]!4"]E>&%M<&QE+W-E<G9E<BYP:'``````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S-S0S`#$P-#$W,S8S,#`T`#`R,C4Q,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z('-E<G9E<BYP:'`L=B`Q+C@@,C`P,R\P
M-"\Q,R`R,3HS.#HU.2!S:&%N92!%>'`@)`HO+PH*+R\@9FER<W0L(&EN8VQU
M9&4@=&AE(%-/05`O4V5R=F5R(&-L87-S"G)E<75I<F5?;VYC92`G4T]!4"]3
M97)V97(N<&AP)SL*"B1S97)V97(@/2!N97<@4T]!4%]397)V97(["B\J('1E
M;&P@<V5R=F5R('1O('1R86YS;&%T92!T;R!C;&%S<V5S('=E('!R;W9I9&4@
M:68@<&]S<VEB;&4@*B\*)'-E<G9E<BT^7V%U=&]?=')A;G-L871I;VX@/2!T
M<G5E.PH*<F5Q=6ER95]O;F-E("=E>&%M<&QE7W-E<G9E<BYP:'`G.PH*)'-O
M87!C;&%S<R`](&YE=R!33T%07T5X86UP;&5?4V5R=F5R*"D["B1S97)V97(M
M/F%D9$]B:F5C=$UA<"@D<V]A<&-L87-S+"=U<FXZ4T]!4%]%>&%M<&QE7U-E
M<G9E<B<I.PH*:68@*&ES<V5T*"1?4T525D526R=215%515-47TU%5$A/1"==
M*2`F)@H@("`@)%]315)615);)U)%455%4U1?34542$]$)UT]/2=03U-4)RD@
M>PH@("`@)'-E<G9E<BT^<V5R=FEC92@D2%144%]205=?4$]35%]$051!*3L*
M?2!E;'-E('L*("`@(')E<75I<F5?;VYC92`G4T]!4"]$:7-C;RYP:'`G.PH@
M("`@)&1I<V-O(#T@;F5W(%-/05!?1$E30T]?4V5R=F5R*"1S97)V97(L)U-E
M<G9E<D5X86UP;&4G*3L*("`@(&AE861E<B@B0V]N=&5N="UT>7!E.B!T97AT
M+WAM;"(I.PH@("`@:68@*&ES<V5T*"1?4T525D526R=1545265]35%))3D<G
M72D@)B8*("`@("`@('-T<F-A<V5C;7`H)%]315)615);)U%515)97U-44DE.
M1R==+"=W<V1L)RD]/3`I('L*("`@("`@("!E8VAO("1D:7-C;RT^9V5T5U-$
M3"@I.PH@("`@?2!E;'-E('L*("`@("`@("!E8VAO("1D:7-C;RT^9V5T1$E3
M0T\H*3L*("`@('T*("`@(&5X:70["GT*/SX`````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U-/05`O97AA;7!L92]E;6%I;%]P;W!?<V5R=F5R+G!H<```````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-#<T,``Q,#0Q-S,V,S`P-``P,C0U,S0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@
M?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0
M(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T
M;R!014%2(&%N9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!E;6%I;%]P;W!?<V5R=F5R+G!H<"QV(#$N-"`R
M,#`S+S`T+S`X(#`V.C(Q.C4P('-H86YE($5X<"`D"B\O"@HO*B!I;F-L=61E
M('1H92!%;6%I;"!S97)V97(@8VQA<W,L('=H:6-H(&MN;W=S(&AO=R!T;PH@
M("!P87)S92!A('-T86YD87)D(&5M86EL(&%S(&$@<V]A<"!M97-S86=E("HO
M"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+T5M86EL+G!H<"<["@HO*B!I
M;F-L=61E(&$@8VQA<W,@=&\@86-C97-S(%!/4#,@*B\*"G)E<75I<F5?;VYC
M92`G3F5T+U!/4#,N<&AP)SL*"B\J(&-R96%T92!T:&4@4T]!4"!397)V97(@
M;V)J96-T("HO"@HD<V5R=F5R(#T@;F5W(%-/05!?4V5R=F5R7T5M86EL.PH*
M+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E('1O(&-L87-S97,@=V4@<')O
M=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?875T;U]T<F%N<VQA=&EO
M;B`]('1R=64["@IR97%U:7)E7V]N8V4@)V5X86UP;&5?<V5R=F5R+G!H<"<[
M"@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L95]397)V97(H*3L*)'-E
M<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L)W5R;CI33T%07T5X86UP
M;&5?4V5R=F5R)RD["@H*+RH@0V]N;F5C="!T;R!A(%!/4#,@<V5R=F5R(&%N
M9"!R96%D('1H92!M97-S86=E<R`J+PH*)'!O<#,@/28@;F5W($YE=%]03U`S
M*"D["FEF("@D<&]P,RT^8V]N;F5C="@G;&]C86QH;W-T)RP@,3$P*2D@>PH@
M("`@:68@*"1P;W`S+3YL;V=I;B@G=7-E<FYA;64G+"`G<&%S<W=O<F0G*2D@
M>PH@("`@("`@("1L:7-T:6YG(#T@)'!O<#,M/F=E=$QI<W1I;F<H*3L*"@DO
M*B!N;W<@;&]O<"!T:')O=6=H(&5A8V@@;65S<V%G92P@86YD(&-A;&P@=&AE
M(`H@("`@("`@("`@(%-/05`@<V5R=F5R('=I=&@@=&AA="!M97-S86=E("HO
M"@H@("`@("`@(&9O<F5A8V@@*"1L:7-T:6YG(&%S("1M<V<I('L*"B`@("`@
M("`@("`@("1E;6%I;"`]("1P;W`S+3YG971-<V<H)&US9ULG;7-G7VED)UTI
M.PH*("`@("`@("`@("`@+RH@=&AI<R!I<R!W:&5R92!W92!A8W1U86QL>2!H
M86YD;&4@=&AE(%-/05`*("`@("`@("`@("`@("`@<F5S<&]N<V4N("!4:&4@
M4T]!4#HZ4V5R=F5R.CI%;6%I;"!C;&%S<R!W90H@("`@("`@("`@("`@("!A
M<F4@=7-I;F<@=VEL;"!S96YD('1H92!33T%0(')E<W!O;G-E('1O(`H@("`@
M("`@("`@("`@("!T:&4@<V5N9&5R('9I82!E;6%I;"X@*B\*"B`@("`@("`@
M("`@(&EF("@D96UA:6PI('L*("`@("`@("`@("`@("`@("1S97)V97(M/F-L
M:65N="@D96UA:6PI.PH*("`@("`@("`@("`@("`@("1P;W`S+3YD96QE=&5-
M<V<H)&US9ULG;7-G7VED)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@)'!O<#,M/F1I<V-O;FYE8W0H*3L*?0H_/@H`````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]E;6%I;%]C;&EE;G0N<&AP````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S,Q-@`Q,#0Q-S,V,S`P-``P,C,V,C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E
M<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC
M;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!E;6%I;%]C;&EE;G0N<&AP
M+'8@,2XR(#(P,#,O,#$O,#0@,3$Z-38Z,C`@;6H@17AP("0*+R\*"B\J"E1H
M:7,@<F5A9',@82!M97-S86=E(&9R;VT@<W1D:6XL(&%N9"!C86QL<R!T:&4@
M<V]A<"!S97)V97(@9&5F:6YE9`H*66]U(&-A;B!U<V4@=&AI<R!F<F]M('%M
M86EL(&)Y(&-R96%T:6YG(&$@+G%M86EL+7-O87!T97-T(&9I;&4@=VET:#H*
M("`@('P@+W5S<B]B:6XO<&AP("]P871H+W1O+V5M86EL7W-E<G9E<BYP:'`*
M*B\*"B,@:6YC;'5D92!T:&4@96UA:6P@<V5R=F5R(&-L87-S"G)E<75I<F5?
M;VYC92`G4T]!4"]397)V97(O16UA:6PN<&AP)SL*"B1S97)V97(@/2!N97<@
M4T]!4%]397)V97)?16UA:6P["@HC(')E860@<W1D:6X*)&9I;B`](&9O<&5N
M*"=P:'`Z+R]S=&1I;B<L)W)B)RD["FEF("@A)&9I;BD@97AI="@P*3L*"B1E
M;6%I;"`]("<G.PIW:&EL92`H(69E;V8H)&9I;BD@)B8@)&1A=&$@/2!F<F5A
M9"@D9FEN+"`X,#DV*2D@>PH@("1E;6%I;"`N/2`D9&%T83L*?0H*9F-L;W-E
M*"1F:6XI.PH*"B1R97-P;VYS92`]("1S97)V97(M/F-L:65N="@D96UA:6PI
M.PH*<')I;G1?<B@D<F5S<&]N<V4I.PH*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]33T%0+V5X86UP;&4O871T86-H;65N="YP:'``````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$U,C4`,3`T,3<S-C,P,#0`,#(S,S(W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"G)E<75I
M<F5?;VYC92@B4T]!4"]#;&EE;G0N<&AP(BD["G)E<75I<F5?;VYC92@B4T]!
M4"]T97-T+W1E<W0N=71I;&ET>2YP:'`B*3L*<F5Q=6ER95]O;F-E*")33T%0
M+U9A;'5E+G!H<"(I.PH*)&9I;&5N86UE(#T@)V%T=&%C:&UE;G0N<&AP)SL*
M)'8@/2`@;F5W(%-/05!?071T86-H;65N="@G=&5S="<L)W1E>'0O<&QA:6XG
M+"1F:6QE;F%M92D["B1M971H;V1686QU92`](&YE=R!33T%07U9A;'5E*"=T
M97-T871T86-H)RP@)U-T<G5C="<L(&%R<F%Y*"1V*2D["@HD8VQI96YT(#T@
M;F5W(%-/05!?0VQI96YT*"=M86EL=&\Z=7-E<D!D;VUA:6XN8V]M)RD["B,@
M8V%L;&EN9R!W:71H(&UI;64*)')E<W`@/2`D8VQI96YT+3YC86QL*"=E8VAO
M36EM94%T=&%C:&UE;G0G+&%R<F%Y*"1V*2P*("`@("`@("`@("`@("`@(&%R
M<F%Y*"=A='1A8VAM96YT<R<]/B=-:6UE)RP*("`@("`@("`@("`@("`@("=N
M86UE<W!A8V4G/3XG:'1T<#HO+W-O87!I;G1E<F]P+F]R9R\G+`H@("`@("`@
M("`@("`@("`@)V9R;VTG/3XG=7-E<D!D;VUA:6XN8V]M)RP*("`@("`@("`@
M("`@("`@("=H;W-T)ST^)W-M='`N9&]M86EN+F-O;2<I*3L*<')I;G0@)&-L
M:65N="T^=VER92XB7&Y<;EQN(CL*<')I;G1?<B@D<F5S<"D["@HC(&-A;&QI
M;F<@=VET:"!$24U%"B1R97-P(#T@)&-L:65N="T^8V%L;"@G96-H;TUI;65!
M='1A8VAM96YT)RQA<G)A>2@D=BDI.PHC($1)344@:&%S(&YU;&P@<W!A8V5S
M+"!C:&%N9V4@=&AE;2!S;R!W92!C86X@<V5E('1H92!W:7)E"B1W:7)E(#T@
M<W1R7W)E<&QA8V4H(EPP(BPG*B<L)&-L:65N="T^=VER92D["G!R:6YT("1W
M:7)E+B)<;EQN7&XB.PIP<FEN=%]R*"1R97-P*3L*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O8VQI96YT+G!H<```````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3`P,3,`,3`T,3<S-C,P,#0`,#(R-#0U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!6
M97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS
M92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\
M(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N
M8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@8VQI96YT+G!H<"QV(#$N
M."`R,#`S+S`T+S$S(#(Q.C,X.C4Y('-H86YE($5X<"`D"B\O"FEN8VQU9&4H
M(E-/05`O0VQI96YT+G!H<"(I.PH*+RHJ"B`J('1H:7,@8VQI96YT(')U;G,@
M86=A:6YS="!T:&4@97AA;7!L92!S97)V97(@:6X@4T]!4"]E>&%M<&QE+W-E
M<G9E<BYP:'`*("H@:70@9&]E<R!N;W0@=7-E(%=31$P@=&\@<G5N('1H97-E
M(')E<75E<W1S+"!B=70@=&AA="!C86X@8F4@8VAA;F=E9"!E87-I;'D@8GD@
M<VEM<&QY"B`J(&%D9&EN9R`G/W=S9&PG('1O('1H92!E;F0@;V8@=&AE('5R
M;"X*("HO"B1S;V%P8VQI96YT(#T@;F5W(%-/05!?0VQI96YT*")H='1P.B\O
M;&]C86QH;W-T+U-/05`O97AA;7!L92]S97)V97(N<&AP(BD["B\O('1H:7,@
M;F%M97-P86-E(&ES('1H92!S86UE(&%S(&1E8VQA<F5D(&EN('-E<G9E<BYP
M:'`*)&]P=&EO;G,@/2!A<G)A>2@G;F%M97-P86-E)R`]/B`G=7)N.E-/05!?
M17AA;7!L95]397)V97(G+`H@("`@("`@("`@("`@("`@("=T<F%C92<@/3X@
M,2D["@HD<F5T(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3=')I;F=3:6UP
M;&4B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y
M*")I;G!U=%-T<FEN9U-I;7!L92(]/B)T:&ES(&ES(&$@=&5S="!S=')I;F<B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS*3L*(W!R:6YT
M("1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E="D[96-H
M;R`B/&)R/EQN(CL*"B1R970@/2`D<V]A<&-L:65N="T^8V%L;"@B96-H;U-T
M<FEN9R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R
M87DH(FEN<'5T4W1R:6YG(CT^(G1H:7,@:7,@82!T97-T('-T<FEN9R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G,I.PIP<FEN=%]R*"1R
M970I.V5C:&\@(CQB<CY<;B(["@HD<F5T(#T@)'-O87!C;&EE;G0M/F-A;&PH
M(F1I=FED92(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@
M87)R87DH(F1I=FED96YD(CT^,C(L(F1I=FES;W(B/3XW*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1O<'1I;VYS*3L*(R!P<FEN="`D<V]A<&-L:65N
M="T^7U]G971?=VER92@I.PII9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D*("`@
M('!R:6YT*")%<G)O<CH@(B`N("1R970M/F=E=$UE<W-A9V4H*2`N("(\8G(^
M7&XB*3L*96QS90H@("`@<')I;G0H(E%U;W1I96YT(&ES("(@+B`D<F5T("X@
M(CQB<CY<;B(I.PH*)')E="`]("1S;V%P8VQI96YT+3YC86QL*")D:79I9&4B
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*")D
M:79I9&5N9"(]/C(R+")D:79I<V]R(CT^,"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D;W!T:6]N<RD["FEF("A014%2.CII<T5R<F]R*"1R970I*0H@
M("`@<')I;G0H(D5R<F]R.B`B("X@)')E="T^9V5T365S<V%G92@I("X@(CQB
M<CY<;B(I.PIE;'-E"B`@("!P<FEN="@B475O=&EE;G0@:7,@(B`N("1R970@
M+B`B/&)R/EQN(BD["@H*+R\@4T]!4%-T<G5C="!I<R!D969I;F5D(&EN('1H
M92!F;VQL;W=I;F<@9FEL90IR97%U:7)E7V]N8V4@)V5X86UP;&5?='EP97,N
M<&AP)SL*"B1S=')U8W0@/2!N97<@4T]!4%-T<G5C="@G=&5S="!S=')I;F<G
M+#$R,RPQ,C,N,3(S*3L*"B\J('-E;F0@86X@;V)J96-T+"!G970@86X@;V)J
M96-T(&)A8VL@*B\*+RH@=&5L;"!C;&EE;G0@=&\@=')A;G-L871E('1O(&-L
M87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V]A<&-L:65N="T^
M7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PHO*B!O<B!Y;W4@8V%N(&5X<&QI
M8VET;'D@<V5T('1H92!T<F%N<VQA=&EO;B!F;W(*("`@82!S<&5C:69I8R!C
M;&%S<RX@(&%U=&]?=')A;G-L871I;VX@=V]R:W,@9F]R(&%L;"!C87-E<RP*
M("`@8G5T(&]P96YS($%.62!C;&%S<R!I;B!T:&4@<V-R:7!T('1O(&)E('5S
M960@87,@82!D871A('1Y<&4L"B`@(&%N9"!M87D@;F]T(&)E(&1E<VER96%B
M;&4N("!B;W1H(&-A;B!B92!U<V5D(&]N(&-L:65N="!O<@H@("!S97)V97(@
M*B\*)'-O87!C;&EE;G0M/E]?<V5T7W1Y<&5?=')A;G-L871I;VXH)WMH='1P
M.B\O<V]A<&EN=&5R;W`N;W)G+WAS9'U33T%04W1R=6-T)RPG4T]!4%-T<G5C
M="<I.PHD<F5T(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3=')U8W0B+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'`@/2!A<G)A>2@G:6YP=713=')U
M8W0G(#T^("1S=')U8W0M/E]?=&]?<V]A<"@I*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("1O<'1I;VYS*3L*(W!R:6YT("1S;V%P8VQI96YT+3Y?7V=E
M=%]W:7)E*"D["G!R:6YT7W(H)')E="D["@HO*BH*("H@4$A0(&1O97-N)W0@
M<W5P<&]R="!M=6QT:7!L92!/550@<&%R86UE=&5R<R!I;B!F=6YC=&EO;B!C
M86QL<RP@<V\@=V4*("H@;75S="!D;R!A(&QI='1L92!W;W)K('1O(&UA:V4@
M:70@:&%P<&5N(&AE<F4N("!4:&ES(')E<75I<F5S(&MN;W=L961G92!O;B!T
M:&4*("H@9&5V96QO<&5R<R!P87)T('1O(&9I9W5R92!O=70@:&]W('1H97D@
M=V%N="!T;R!D96%L('=I=&@@:70N"B`J+PHD<F5T(#T@)'-O87!C;&EE;G0M
M/F-A;&PH(F5C:&]3=')U8W1!<U-I;7!L951Y<&5S(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("1P(#T@87)R87DH)VEN<'5T4W1R=6-T)R`]/B`D<W1R
M=6-T+3Y?7W1O7W-O87`H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M;W!T:6]N<RD["FEF("A014%2.CII<T5R<F]R*"1R970I*2!["B`@("!P<FEN
M="@B17)R;W(Z("(@+B`D<F5T+3YG971-97-S86=E*"D@+B`B/&)R/EQN(BD[
M"GT@96QS92!["B`@("!L:7-T*"1S=')I;F<L("1I;G0L("1F;&]A="D@/2!A
M<G)A>5]V86QU97,H)')E="D["GT*96-H;R`B=F%R4W1R:6YG.B`D<W1R:6YG
M/&)R/EQN=F%R26YT.B`D:6YT/&)R/EQN=F%R1FQO870Z("1F;&]A=#QB<CY<
M;B(["@H_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+U-/05`O97AA;7!L92]S=&]C:W%U;W1E+G!H<```````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#0P-@`Q,#0Q-S,V,S`P-``P,C,T,#$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/&AT;6P^/&)O9'D^"CP_
M"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!6
M97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS
M92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\
M(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N
M8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R92`@('P*+R\@?"!!=71H;W)S
M.B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA
M;"!!=71H;W(@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+PHO+R`D260Z('-T;V-K<75O=&4N<&AP+'8@,2XU(#(P,#,O,#$O
M,#0@,3$Z-38Z,C$@;6H@17AP("0*+R\*+R\@:6YC;'5D92!S;V%P(&-L:65N
M="!C;&%S<PII;F-L=61E*")33T%0+T-L:65N="YP:'`B*3L*"G!R:6YT("(\
M8G(^7&X\<W1R;VYG/G=S9&PZ/"]S=')O;F<^(CL*)'=S9&P@/2!N97<@4T]!
M4%]74T1,*")H='1P.B\O<V5R=FEC97,N>&UE=&AO9',N;F5T+W-O87`O=7)N
M.GAM971H;V1S+61E;&%Y960M<75O=&5S+G=S9&PB*3L*)'-O87!C;&EE;G0@
M/2`D=W-D;"T^9V5T4')O>'DH*3L*<')I;G1?<B@D<V]A<&-L:65N="T^9V5T
M475O=&4H(FEB;2(I*3L*<')I;G0@(EQN7&XB.PH*:68@*&5X=&5N<VEO;E]L
M;V%D960H)V]V97)L;V%D)RDI('L*"7!R:6YT(")<;CQB<CX\<W1R;VYG/F]V
M97)L;V%D960Z/"]S=')O;F<^(CL*"21R970@/2`D<V]A<&-L:65N="T^9V5T
M475O=&4H(FEB;2(I.PH)<')I;G1?<B@D<F5T*3L*"7!R:6YT(")<;EQN(CL*
M?0IU;G-E="@D<V]A<&-L:65N="D["@IP<FEN="`B7&X\8G(^/'-T<F]N9SYN
M;VX@=W-D;#H\+W-T<F]N9SXB.PHD<V]A<&-L:65N="`](&YE=R!33T%07T-L
M:65N="@B:'1T<#HO+W-E<G9I8V5S+GAM971H;V1S+FYE=#HX,"]S;V%P(BD[
M"B1N86UE<W!A8V4@/2`B=7)N.GAM971H;V1S+61E;&%Y960M<75O=&5S(CL*
M+RHJ"B`J('-O;64@<V]A<"!S97)V97)S(')E<75I<F4@82!3;V%P86-T:6]N
M(&AT='`@:&5A9&5R+B`@4$5!4CHZ4T]!4"!D;V5S"B`J(&YO="!U<V4@=&AE
M;2!I;B!A;GD@=V%Y+"!O=&AE<B!T;R!S96YD('1H96T@:68@>6]U('-U<'!L
M>2!T:&5M+@H@*B!S;V%P86-T:6]N(&ES(&1E<')E8V%T960@:6X@;&%T97(@
M4T]!4"!V97)S:6]N<RX*("HO"B1S;V%P86-T:6]N(#T@(G5R;CIX;65T:&]D
M<RUD96QA>65D+7%U;W1E<R-G9711=6]T92(["B1R970@/2`D<V]A<&-L:65N
M="T^8V%L;"@B9V5T475O=&4B+&%R<F%Y*")S>6UB;VPB/3XB:6)M(BDL)&YA
M;65S<&%C92PD<V]A<&%C=&EO;BD["G!R:6YT7W(H)')E="D["G!R:6YT(")<
M;EQN(CL*=6YS970H)'-O87!C;&EE;G0I.PH*/SX*/"]H=&UL/CPO8F]D>3X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S;71P+G!H<```````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(V-P`Q,#0Q-S,V,S`P-``P,C(Q-C<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#\*
M+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E
M<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC
M;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!S;71P+G!H<"QV(#$N,R`R
M,#`S+S`Q+S`T(#$Q.C4V.C(Q(&UJ($5X<"`D"B\O"B\O(&EN8VQU9&4@<V]A
M<"!C;&EE;G0@8VQA<W,*:6YC;'5D92@B4T]!4"]#;&EE;G0N<&AP(BD["@HD
M<V]A<&-L:65N="`](&YE=R!33T%07T-L:65N="@B;6%I;'1O.G5S97)`9&]M
M86EN+F-O;2(I.PHD;W!T:6]N<R`](&%R<F%Y*"=N86UE<W!A8V4G/3XG:'1T
M<#HO+W-O87!I;G1E<F]P+F]R9R\G+"=F<F]M)ST^)W5S97)`9&]M86EN+F-O
M;2<L)VAO<W0G/3XG;&]C86QH;W-T)RD["B1R971U<FX@/2`D<V]A<&-L:65N
M="T^8V%L;"@B96-H;U-T<FEN9R(L87)R87DH(FEN<'5T4W1R:6YG(CT^(G1H
M:7,@:7,@82!T97-T(BDL("1O<'1I;VYS*3L*)')E='5R;B`]("1S;V%P8VQI
M96YT+3YC86QL*")E8VAO4W1R:6YG07)R87DB+&%R<F%Y*"=I;G!U=%-T<FEN
M9T%R<F%Y)R`]/B!A<G)A>2@G9V]O9"<L)V)A9"<L)W5G;'DG*2DL("1O<'1I
M;VYS*3L*+R\@9&]N)W0@97AP96-T(&UU8V@@;V8@82!R97-U;'0A"G!R:6YT
M7W(H)')E='5R;BD["G!R:6YT("(\8G(^7&XB+B1S;V%P8VQI96YT+3YW:7)E
M.PH_/@H*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]33T%0+V5X86UP;&4O=&-P7V1A96UO;BYP;```````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,Q-3<`,3`T,3<S-C,P,#0`,#(S,3,W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",A+W5S<B]B
M:6XO<&5R;"`M=PIU<V4@<W1R:6-T.PH*/6AE860Q(%-I;7!L92!33T%0(%1#
M4"!397)V97(*"B`@("!3:6UP;&4@4T]!4"!40U`@4V5R=F5R('=I=&@@=&5S
M="!C;&%S<R`H:G5S="!T;R!C:&5C:R!T:&EN9W,@87)E('=O<FMI;F<I"@H@
M("`@0F5F;W)E('EO=2!R=6X@=&AI<R!T97-T('-E<G9E<B!Y;W4@=VEL;"!N
M965D('-O;64@<&5R;"!C;&%S<V5S+"!N86UE;'DZ"B`@("`@("`@4T]!4#HZ
M3&ET90H@("`@("`@($AO;VLZ.DQE>%=R87`@*&EF('EO=2!W86YT('1O('-E
M92!S;VUE(&1E8G5G9VEN9RD*"B`@("`@("`@1FQE92!O9F8@=&\@=&AE($-0
M04X@:68@>6]U(&YE960@=&AE;2`Z*0H*("`@(%1O(')U;B!T>7!E("=P97)L
M(#QF:6QE;F%M93XG(&%N9"!I9B!Y;W4@9&]N="!G970@86YY(&5R<F]R<RP@
M:70G<R!T:6UE"B`@("!T;R!G;R!W<FET92!S;VUE(&-O9&4@=&\@8V]N;F5C
M="X*/6-U=`H*=7-E(%-/05`Z.E1R86YS<&]R=#HZ5$-0('%W*'1R86-E*3L*
M=7-E($1A=&$Z.D1U;7!E<CL*"@HC(R,C(R,C(R,C(R,C"B,C(&EF('EO=2!W
M86YT('1O('-E92!I;F-O;6EN9R]O=71G;VEN9R!R87<@>&UL"B,C('5N8V]M
M;65N="!T:&4@9F]L;&]W:6YG+@H*(W5S92!(;V]K.CI,97A7<F%P.PHC=W)A
M<"`J24\Z.E-E<W-I;VY$871A.CIR96%D+"!P;W-T(#T^(%PF<VAO=U]R96%D
M.PHC=W)A<"`J24\Z.E-E<W-I;VY$871A.CIW<FET92P@<&]S="`]/B!<)G-H
M;W=?=W)I=&4["@HC(PHC(R,C(R,C(R,C(R,C"@H*;7D@)&1A96UO;B`](%-/
M05`Z.E1R86YS<&]R=#HZ5$-0.CI397)V97(M/FYE=R@*("`@($QO8V%L061D
M<B`]/B`G,3(W+C`N,"XQ)RP*("`@($QO8V%L4&]R="`]/B`G.#(G+`H@("`@
M3&ES=&5N("`@(#T^(#4L"B`@("!2975S92`@("`@/3X@,0HI.PH*(R!D:7-P
M871C:`HD9&%E;6]N+3YD:7-P871C:%]T;R@G4T]!4%]%>&%M<&QE7U-E<G9E
M<B<I.PHD9&%E;6]N+3YH86YD;&4["@HC(R,C(R,C(R,C(R,C"B,C(&-A;&QB
M86-K(&9U;F-T:6]N<R!F;W(@2&]O:SHZ3&5X5W)A<#L*(R,*"B,@<VAO=R!I
M;F-O;6EN9R!X;6P*<W5B('-H;W=?<F5A9"!["B`@("!P<FEN="`D+RPG(R,@
M<F5A9"`C(R<L)"\["B`@("!P<FEN="!$=6UP97(H)%];,%TI.PI]"@HC('-H
M;W<@;W5T9V]I;F<@>&UL"G-U8B!S:&]W7W=R:71E('L*("`@('!R:6YT("0O
M+"<C(R!W<FET92`C(R<L)"\["B`@("!P<FEN="!$=6UP97(H)%];,%TI.PI]
M"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"@H*"B,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@4T]!4%]%>&%M<&QE
M7U-E<G9E<@HC(%-I;7!L92!T97-T(&-L87-S+"!M971H;V0@=&5S="!R971U
M<FYS(&1O=6)L92!W:&%T('EO=2!S96YD('1O(&ET+"!T:&%T<R!A;&PA"B,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"G!A8VMA9V4@4T]!
M4%]%>&%M<&QE7U-E<G9E<CL*"G-U8B!E8VAO4W1R:6YG('L*("`@(')E='5R
M;B`D7ULQ72!X(#(["GT*"C$["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O4T]!4"]E>&%M<&QE+V5X86UP;&5?='EP97,N<&AP````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R-C,W`#$P-#$W,S8S,#`T`#`R-#`V,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*+RH**B!T
M:&ES(&ES(&$@9&%T82!T>7!E('1H870@:7,@=7-E9"!I;B!33T%0($EN=&5R
M;W`@=&5S=&EN9RP@8G5T(&ES"BH@:&5R92!A<R!A;B!E>&%M<&QE(&]F('5S
M:6YG(&-O;7!L97@@='EP97,N("!7:&5N('1H92!C;&%S<R!I<PHJ(&1E<V5R
M:6%L:7IE9"!F<F]M(&$@4T]!4"!M97-S86=E+"!I="=S(&-O;G-T<G5C=&]R
M($E3($Y/5"!#04Q,140A"BH@4V\@>6]U<B!T>7!E(&-L87-S97,@;F5E9"!T
M;R!B96AA=F4@:6X@82!W87D@=&AA="!W:6QL('=O<FL**B!W:71H('1H870N
M"BH**B!3;VUE('1Y<&5S(&UA>2!N965D(&UO<F4@97AP;&EC:70@<V5R:6%L
M:7IA=&EO;B!F;W(@4T]!4"X@(%1H90HJ(%]?=&]?<V]A<"!F=6YC=&EO;B!A
M;&QO=W,@>6]U('1O(&)E('9E<GD@97AP;&EC:70@:6X@8G5I;&1I;F<@=&AE
M"BH@4T]!4%]686QU92!S=')U8W1U<F5S+B`@5&AE('-O87`@;&EB<F%R>2!D
M;V5S(&YO="!C86QL('1H:7,@9&ER96-T;'DL"BH@>6]U('=O=6QD(&-A;&P@
M:70@9G)O;2!Y;W5R('-O87`@<V5R=F5R(&-L87-S+"!E8VAO4W1R=6-T(&EN
M('1H92!S97)V97(**B!C;&%S<R!I<R!A;B!E>&%M<&QE(&]F(&1O:6YG('1H
M:7,N"BHO"F-L87-S(%-/05!3=')U8W0@>PH@("`@=F%R("1V87)3=')I;F<[
M"B`@("!V87(@)'9A<DEN=#L*("`@('9A<B`D=F%R1FQO870["B`@("!F=6YC
M=&EO;B!33T%04W1R=6-T*"1S/4Y53$PL("1I/4Y53$PL("1F/4Y53$PI('L*
M("`@("`@("`D=&AI<RT^=F%R4W1R:6YG(#T@)',["B`@("`@("`@)'1H:7,M
M/G9A<DEN="`]("1I.PH@("`@("`@("1T:&ES+3YV87)&;&]A="`]("1F.PH@
M("`@?0H@("`@"B`@("!F=6YC=&EO;B`F7U]T;U]S;V%P*"1N86UE(#T@)VEN
M<'5T4W1R=6-T)RP@)&AE861E<CUF86QS92P@)&UU<W15;F1E<G-T86YD/3`L
M("1A8W1O<CTG:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]A8W1O
M<B]N97AT)RD*("`@('L*("`@("`@("`D:6YN97);72`])B!N97<@4T]!4%]6
M86QU92@G=F%R4W1R:6YG)RPG<W1R:6YG)RPD=&AI<RT^=F%R4W1R:6YG*3L*
M("`@("`@("`D:6YN97);72`])B!N97<@4T]!4%]686QU92@G=F%R26YT)RPG
M:6YT)RPD=&AI<RT^=F%R26YT*3L*("`@("`@("`D:6YN97);72`])B!N97<@
M4T]!4%]686QU92@G=F%R1FQO870G+"=F;&]A="<L)'1H:7,M/G9A<D9L;V%T
M*3L*("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("!R971U<FX@
M;F5W(%-/05!?2&5A9&5R*"1N86UE+"=[:'1T<#HO+W-O87!I;G1E<F]P+F]R
M9R]X<V1]4T]!4%-T<G5C="<L)&EN;F5R+"1M=7-T56YD97)S=&%N9"PD86-T
M;W(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@;F5W(%-/05!?5F%L=64H
M)&YA;64L)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS9'U33T%04W1R=6-T
M)RPD:6YN97(I.PH@("`@("`@(`H@("`@?0I]"@H_/@``````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]4<F5E+P``````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C,P,#0`,#$W,3<P`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U1R964O9&]C<R\`````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-``P,C`Q,C``(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O5')E92]D;V-S+U1R965%9&ET;W(O````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`R,C$V
M-@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]4<F5E+V1O8W,O
M5')E945D:71O<B]C=70N9VEF````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,#``
M,3`T,3<S-C,P,#0`,#(S-#,U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y81<`%P"A``#<W-R`@(```(#___\A_A5#
M<F5A=&5D('=I=&@@5&AE($=)35``(?D$`0H``P`L`````!<`%P```CB$CZG+
M[0^C"X?*BJ\1AVL@4(&G"9SY`2-H?2;YC:V+IB!82^^]1N'M@3F"K)M/%10^
M<K:F\]DL```[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O5')E92]D;V-S+U1R965%9&ET;W(O
M;W!E;D9O;&1E<BYG:68``````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C4S`#$P-#$W,S8S,#`T
M`#`R-#<U,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$?`!``Q@```````@("2$A(%!04Y.3DZ>GI+R\O____\_/R
M[N[N4%!0<G)R@WYXAH!X^OGXR\G%M[>W`#M<!6F:AX-^\_#LDHI[BGE<E(M[
M1D9&EMGURNOWG,S@]?+OZN#1[>#-E(R"BH%S/S\_.+CG5<+J=+;/S>3MX]&X
MU\&?B'A;UM;5`*GG$X2N7ZO(S+.)@'!5SLW-`'S,%V&1&FN;<F1/P\&]]O;V
MCJJY,G&2&&*28EQ2P\&^0D)"ZNKJX>+CX>'A%5^/,&Z.`#10LK"M-C8VW]_?
MWM[>V]O;UM;6T='1S,S,'7RJ`#A7IJ:B:&AHP,#`SL[.RLK*QL;&N[N[`#I;
MH)^;,C(R8&!@KZ^OM;6UL+"PJJJJ`#A8+BXN6%A8G9V=IZ>G.3DY*2DI/#HW
M____________________________________________________________
M________________________________________________________(?X5
M0W)E871E9"!W:71H(%1H92!'24U0`"'Y!`$*`'\`+``````?`!````?O@'^"
M?P"#AH>"`0*(C(V,`P0%`@(&CH*%EI<'"`D$!`J*"P&9C@`'#`T$#@Z=!`^C
M$+&RLH@1$A$1!Q,4%187JJP/&!",Q(<1&1H;MQ$<'1X?%B">(<:'UH,1(B,D
M&R7+N!TF)R@IU<6,$2HK*RS=W[<M+B_G`/;V?\2%F'\1,#$R9+!SYRW"#!KG
M$&$;!*!&#1LW<`0<&"&'CH37&NU(P*.'#X@_`@()(@2CH86#AA`A4L3($21)
M;"B)L81)M5FS'`48TL3)$RA1G$B1,H5*"%(ZJUBY(@5+%BU;CB*U%(!+%R]?
M(H"9BC1`&#%_`@$`.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O5')E92]D;V-S+U1R965%
M9&ET;W(O<&%S=&4N9VEF````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S(V`#$P-#$W
M,S8S,#`T`#`R,S<V-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$7`!<`XP``W-S<`````/\`__\`@(``@("`____
M``"`________________________________(?X50W)E871E9"!W:71H(%1H
M92!'24U0`"'Y!`$*``@`+``````7`!<```1J$,A)J[TXZ\UI^&#`@5(@G"(6
M!L,PF>D5$`#!?EY6B+OA&QW`CK!;?0J`6&57:P(.T*B2,FP2#S\#%,.DT0K8
M'_9PJ7K!AH]V:^DVT5EM>69%A^3S53A+YA;^?U&"?1R`AD&(B8J+C(T2$0`[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+U1R964O9&]C<R]4<F5E161I=&]R+V-L;W-E
M9$9O;&1E<BYG:68````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(S-@`Q,#0Q-S,V,S`P-``P,C4R
M-C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA'P`0`,8```````("`DA(2!04%,O+R^GIZ2\O+SX^/@!KG@`]6G5U
M=:2DI')R<B@H*,'A[=/M]GF_UN3DY+>WMR`A(3RY[3JCQ7>\UH+#V0ASI0`\
M6T9&1AX>'AFO[@>'MCBBQ5VQT':[U8'"V(7$V0=PH4]/3Q::RQ!LH1)\K0>$
MLE:PS7*YU)')VS\_/RLK*Q.`L@M4@@Y>D0YEEQ%OH!)_L5BNS7"XTT5%1?S\
M_.GDY(JIN2ELC@Y<C0]FF!%UI$!`0$1$1/;V]O'Q\>OKZ^KJZMO7UH&@L"AL
MCP]EEA%RI%>AP$)"0N[N[N;FYN'AX=S<W-75U=?7U\O)R(BFM2=LC"=HDC8V
M-L3$Q-_?W][>WMO;V];6UM'1T<S,S,7%Q;^_O\&^OFYM;<'!P6AH:,#`P,[.
MSLK*RL;&QKN[N[:VMJZNKC(R,F!@8*^OK[6UM;"PL*JJJFQK:RXN+EA86)V=
MG:>GIVII:3DY.2DI*3HX-?___________________________R'Y!`$*`'\`
M+``````?`!````?[@'^"?P"#AH<!`H>+C(V"`P0%`@(&CH:%C@<("0H+D0*)
M#`&6C@T.#Q";G001!06C@A*RL[.+$Q05%J<7&!FK!1JQC!*+&QP='A\@(:<B
M(YPDPH*8?\2'&R4F)RC(*2HKIQ`LTH2#UH8M+B\P,3(S'<@T-0[CU80`^(7$
MA9@V-S@Y=+S8P:/'"7@U?)"C=F[0#R!!A`PA4L3(NB-(DBBT-\W<(B5+AC!I
MXN0)E"A2IKR@LK&AQT-5K%S!DD7+%BY=O'3Y`L9&F#"T@C(*4$7,&#)ES(PY
M@R8-&`T_234*H&8-FS-MW+R!XU,JJ0!QY,RA4\>.U[,![N`9%`@`.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U1R964O9&]C<R]4<F5E161I=&]R
M+V-O;F9I9RYX;6P````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8V-P`Q,#0Q-S,V,S`P
M-``P,C0Q-C4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]X;6P@=F5R<VEO;CTB,2XP(B`_/@H*/%-I;7!L951E;7!L871E
M/@H@("`@/&]P=&EO;G,@;W9E<G)I9&4](GEE<R(^"B`@("`@("`@/&1E;&EM
M:71E<B!B96=I;CTB6R(@96YD/2)=(B\^"B`@("`@("`@/&%U=&]"<F%C97,@
M=F%L=64](G1R=64B+SX*("`@("`@("`\;&]C86QE('9A;'5E/2)E;B(O/@H*
M("`@("`@("`\8V%C:&4^"B`@("`@("`@("`@(#QT:6UE('9A;'5E/2(Q,"(@
M=6YI=#TB;6EN=71E<R(O/@H@("`@("`@(#PO8V%C:&4^"@H@("`@/"]O<'1I
M;VYS/@H*"@H*/"$M+0H*("`@("$A(2$A(2$*("`@(&9R;VT@:&5R90H@("`@
M=&AI<R!S96-T:6]N(&ES(&YO="!I;7!L96UE;G1E9"!Y970*("`@(&]N;'D@
M<&QA;FYE9"`A(2$A(2$A"@HM+3X*"B`@("`\(2TM("`@('!R949I;'1E<B`M
M(')E9VES=&5R(&%N>2!P<F4@9FEL=&5R(&AE<F4*("`@("`@("`@("`@;W9E
M<G)I9&4@+2`@("`@("`@("`_/S\_"B`@("`@("`@("`@(')E9VES=&5R3VYL
M>4]N8V4@+2`@>65S(&]R(&YO+"!T:&ES('1A:V5S(&-A<F4@;V8@;F]T(')E
M9VES=&5R:6YG(&]N92!F:6QT97(@;75L=&EP;&4@=&EM97,*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I="=S(&IU<W0@;F]T('1O(&QO;W-E
M('!E<F9O<FUA;F-E"B`@("`@("`@("`@(&EN:&5R:71/<'1I;VYS("T@("`@
M=&AI<R!I;FAE<FET<R!T:&4@;W!T:6]N<R!F<F]M('1H92!3:6UP;&5496UP
M;&%T92!O8FIE8W0@875T;VUA=&EC86QL>0H@("`@+2T^"B`@("`\<')E1FEL
M=&5R(&]V97)R:61E/2)N;R(*("`@("`@("`@("`@("`@(')E9VES=&5R3VYL
M>4]N8V4](GEE<R(*("`@("`@("`@("`@("`@(&EN:&5R:71/<'1I;VYS/2)Y
M97,B/@H@("`@("`@(#QR96=I<W1E<B!F=6YC=&EO;CTB<F5M;W9E2'1M;$-O
M;6UE;G1S(B!O8FIE8W0](G1P;$9I;'1E<B(@+SX*("`@("`@("`\<F5G:7-T
M97(@9G5N8W1I;VX](G)E;6]V94-3='EL94-O;6UE;G1S(B!O8FIE8W0](G1P
M;$9I;'1E<B(@+SX*("`@("`@("`\<F5G:7-T97(@9G5N8W1I;VX](F%D9$EF
M0F5F;W)E1F]R96%C:"(@;V)J96-T/2)T<&Q&:6QT97(B/@H@("`@("`@("`@
M("`\;W!T:6]N<R!I;FAE<FET/2)3:6UP;&5496UP;&%T92`_/S\_(CX*("`@
M("`@("`@("`@("`\;W!T:6]N(&)E9VEN1&5L:6UI=&5R/2)[(B!E;F1$96QI
M;6ET97(](GTB("\^"B`@("`@("`@("`@(#PO;W!T:6]N<SX*("`@("`@("`\
M+W)E9VES=&5R/@H*("`@("`@("`\(2TM("`@('5N<F5G:7-T97(@+2`@("!T
M:&ES('!R979E;G1S(&9R;VT@8V%L;&EN9R!T:&4@9FEL=&5R(&=I=F5N(&EN
M(&9U;F-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YO
M(&UA='1E<B!F<F]M('=H:6-H(&]B:F5C="]C;&%S<PH@("`@("`@("TM/@H@
M("`@("`@(#QU;G)E9VES=&5R(&9U;F-T:6]N/2)X>'@B("\^"@H@("`@/"]P
M<F5&:6QT97(^"@H\+U-I;7!L951E;7!L871E/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O5')E92]D;V-S+U1R965%9&ET;W(O8V]P>2YG:68`````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,C0Q`#$P-#$W,S8S,#`T`#`R,S8R,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$7`!<`P@``W-S<
M``"`@("`____````____________(?X50W)E871E9"!W:71H(%1H92!'24U0
M`"'Y!`$*``<`+``````7`!<```--"+K<_C#*2:L+.%LEPO@#MG5@.!`621!A
MID4D&'\!"JDKX8&>[<P#7$OTZ^5VI=`#B,LIBRY,DK846*]&9Z`"Y'&C+NYU
MO"F;S^CT)@$`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U1R964O9&]C
M<R]4<F5E161I=&]R+VEN9&5X+G!H<```````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S0W
M-0`Q,#0Q-S,V,S`P-``P,C0P,C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*("`@("\O"B`@("`O+R`@)$ED.B!I
M;F1E>"YP:'`L=B`Q+C(@,C`P,R\P,2\S,"`Q-SHT,SHT,B!C86EN($5X<"`D
M"B`@("`O+PHO+VEN:5]S970H)VEN8VQU9&5?<&%T:"<L<F5A;'!A=&@H9&ER
M;F%M92A?7T9)3$5?7RDN)R\N+B\N+B\N+B\G*2XG.B<N<F5A;'!A=&@H9&ER
M;F%M92A?7T9)3$5?7RDN)R\N+B\N+B\N+B\N+B]I;F-L=61E<R<I+B<Z)RYI
M;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D["B\O:6YI7W-E="@G97)R;W)?<F5P
M;W)T:6YG)RQ%7T%,3"D["@H@("`@(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*("`@(",*("`@(",@("`@("`@
M:6YI="!T96UP;&%T92!E;F=I;F4*("`@(",*"B`@("`O+R!Y;W4@;F5E9"!T
M:&4@=&5M<&QA=&4@8VQA<W,@9G)O;2!H='1P.B\O<V8N;F5T+W!R;VIE8W1S
M+W-I;7!L='!L"B`@("!I9B`H(4!I;F-L=61E*"=(5$U,+U1E;7!L871E+UAI
M<&4N<&AP)RDI('L*("`@("`@("!P<FEN="`@("=S;W)R>2P@>6]U(&YE960@
M=&AE('1E;7!L871E(&-L87-S(%!%05(Z.DA434Q?5&5M<&QA=&5?6&EP93QB
M<CXG+@H@("`@("`@("`@("`@("`@)V]R(&EF(&D@:&%V92!T:6UE(&D@<'5T
M('1H92!E>&%M<&QE<R`\82!H<F5F/2)H='1P.B\O;W,N=FES:6]N<"YD92\B
M/FAE<F4@;VYL:6YE/"]A/B<["B`@("`@("`@9&EE*"D["B`@("!]"B`@("!R
M97%U:7)E7V]N8V4H)TA434PO5&5M<&QA=&4O6&EP92]&:6QT97(O5&%G3&EB
M+G!H<"<I.PH@("`@)&]P=&EO;G,@/2!A<G)A>2@@("`G=&5M<&QA=&5$:7(G
M("`@/3X@9&ER;F%M92A?7T9)3$5?7RD@*3L*("`@("1T<&P@/2!N97<@2%1-
M3%]496UP;&%T95]8:7!E*"1O<'1I;VYS*3L*"B`@("!R97%U:7)E7V]N8V4H
M)TA434PO5&5M<&QA=&4O6&EP92]&:6QT97(O36]D:69I97(N<&AP)RD["B`@
M("`D;6]D:69I97)S(#T@;F5W($A434Q?5&5M<&QA=&5?6&EP95]&:6QT97)?
M36]D:69I97(H)'1P;"T^;W!T:6]N<RD["B`@("`D='!L+3YR96=I<W1E<E!R
M969I;'1E<BAA<G)A>2@F)&UO9&EF:65R<RPG:6UG4W)C)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2AD:7)N86UE*%]?1DE,15]?*2PG
M:'1T<#HO+R<N)%]315)615);)TA45%!?2$]35"==+F1I<FYA;64H)%]315)6
M15);)U!(4%]314Q&)UTI*2D["@H*("`@("\O('-E<W-I;VX@<W1U9F8@=&\@
M<V%V92!T:&4@;W!E;F5D(&9O;&1E<G,@971C+@H@("`@<V5S<VEO;E]S=&%R
M="@I.PH@("`@:68H(7-E<W-I;VY?:7-?<F5G:7-T97)E9"@G<V5S<VEO;B<I
M*0H@("`@>PH@("`@("`@("1S97-S:6]N(#T@;F5W('-T9$-L87-S.R`@("`O
M+R!S=&%N9&%R9"!02%`M8VQA<W,@8V]N<W1R=6-T;W(*("`@("`@("!S97-S
M:6]N7W)E9VES=&5R*"=S97-S:6]N)RD["B`@("`@("`@)'-E<W-I;VXM/F1A
M=&$@/2!A<G)A>2@I.PH@("`@("`@("1S97-S:6]N+3YU<V4@/2`G1FEL97-Y
M<W1E;2<["B`@("!]"B`@("!E;'-E("`@("\O('-I;F-E('1H92!C;&%S<R!I
M<R!R96%D(&9R;VT@=&AE('-E<W-I;VX@:70@:7,@;F]T(&%U=&]M871I8V%L
M;'D@;6%D92!G;&]B86P*("`@('L*("`@("`@("`D<V5S<VEO;B`]("8D7U-%
M4U-)3TY;)W-E<W-I;VXG73L*("`@('T*"B`@("`O+R!S970@=&AE('-O=7)C
M92!T;R!U<V4*("`@(&EF*"!`)%]215%515-46R=U<V5?1$(G72`I"B`@("`@
M("`@)'-E<W-I;VXM/G5S92`]("=$0B<["B`@("!I9B@@0"1?4D5154535%LG
M=7-E7T9I;&5S>7-T96TG72`I"B`@("`@("`@)'-E<W-I;VXM/G5S92`]("=&
M:6QE<WES=&5M)SL*("`@(&EF*"!`)%]215%515-46R=U<V5?6$U,)UT@*0H@
M("`@("`@("1S97-S:6]N+3YU<V4@/2`G6$U,)SL*("`@(&EF*"!`)%]215%5
M15-46R=U<V5?07)R87DG72`I"B`@("`@("`@)'-E<W-I;VXM/G5S92`]("=!
M<G)A>2<["@H@("`@(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,*("`@(",*("`@(",@("`@("`@86-T=6%L('1R
M964@<W1U9F8*("`@(",*("`@(&1E9FEN92@G5$%"3$5?5%)%12<L)U1R965?
M3F5S=&5D)RD["B`@("!D969I;F4H)T1"7T133B<L)VUY<W%L.B\O<F]O=$!L
M;V-A;&AO<W0O=&5S="<I.PH*("`@(')E<75I<F5?;VYC92@G=')E94-L87-S
M+G!H<"<I.PH@("`@:68H("1S97-S:6]N+3YU<V4@/3T@)T1")R`I"B`@("![
M"B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@@)W1A8FQE)R`]/B!404),15]4
M4D5%("P@)V]R9&5R)R`]/B`@)VYA;64G*3L*("`@("`@("`D=')E92`](&YE
M=R!T<F5E0VQA<W,H("=$0FYE<W1E9"<@+"!$0E]$4TX@+"`D;W!T:6]N<R`I
M.PH@("`@?0H@("`@:68H("1S97-S:6]N+3YU<V4@/3T@)T9I;&5S>7-T96TG
M("D*("`@('L*("`@("`@("`C('1O(&QE="!I="!W;W)K(&]N('1H92!F:6QE
M<WES=&5M(#HM*0H@("`@("`@("1O<'1I;VYS(#T@87)R87DH("=O<F1E<B<@
M/3X@("=N86UE)RD["B`@("`@("`@)'1R964@/2!N97<@=')E94-L87-S*"`G
M1FEL97-Y<W1E;2<@+"!D:7)N86UE*%]?1DE,15]?*2XG+W1M<"<@+"`D;W!T
M:6]N<R`I.PH@("`@?0H@("`@:68H("1S97-S:6]N+3YU<V4@/3T@)UA-3"<@
M*0H@("`@>PH@("`@("`@("1T<F5E(#T@;F5W('1R965#;&%S<R@@)UA-3"<@
M+"!D:7)N86UE*%]?1DE,15]?*2XG+V-O;F9I9RYX;6PG("D["B`@("!]"B`@
M("!I9B@@)'-E<W-I;VXM/G5S92`]/2`G07)R87DG("D*("`@('L*("`@("`@
M("`O+R!T:&4@86-T=6%L(&1A=&$@9F]R('1H92!T<F5E+"!T:&5Y(&AA=F4@
M=&\@:&%V92!T:&4@9VEV96X@<W1R=6-T=7)E"B`@("`@("`@)&%R<F%Y1&%T
M82`](&%R<F%Y*"`G;F%M92<]/B=2;V]T)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=C:&EL9')E;B<]/F%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=N86UE)ST^)V1I<C$G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;F%M92<]/B=D:7(R
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-H:6QD
M<F5N)ST^87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G;F%M92<]/B=D:7(R7S$G*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=N86UE)ST^)V1I
M<C)?,B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=N86UE)ST^
M)V1I<C,G*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`O+R!A;GD@;VX@86X@
M87)R87D*("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"`G;W)D97(G(#T^("`G
M;F%M92<I.PH@("`@("`@("1T<F5E(#T@;F5W('1R965#;&%S<R@@)T%R<F%Y
M)R`L("1A<G)A>41A=&$@+"`D;W!T:6]N<R`I.PH@("`@?0H*"@H*"B`@("!I
M9B@@4$5!4CHZ:7-%<G)O<B@D<F5S/21T<F5E+3YS971U<"@I*2`I"B`@("![
M"B`@("`@("`@)&UE=&AO9$9A:6QE9"`]('1R=64["B`@("`@("`@)')E<W5L
M='-;72`]("1R97,["B`@("!]"@H@("`@)'1R964M/G-E=%)E;6]V95)E8W5R
M<VEV96QY*"D["@H@("`@+R\@9&5T96-T(&%C=&EO;@H*("`@(&EF*"!`)%]2
M15%515-46R=A8W1I;VY?8V]P>2==('Q\($`D7U)%455%4U1;)V%C=&EO;E]C
M;W!Y7W@G72!\?`H@("`@("`@($`D7U)%455%4U1;)V%C=&EO;E]C=70G72!\
M?"!`)%]215%515-46R=A8W1I;VY?8W5T7W@G72`I"B`@("!["B`@("`@("`@
M:68H($`D7U)%455%4U1;)V%C=&EO;E]C;W!Y)UT@?'P@0"1?4D5154535%LG
M86-T:6]N7V-O<'E?>"==*2`@("`@("1S97-S:6]N+3YA8W1I;VX@/2`G8V]P
M>2<["B`@("`@("`@:68H($`D7U)%455%4U1;)V%C=&EO;E]C=70G72!\?"!`
M)%]215%515-46R=A8W1I;VY?8W5T7W@G72`I("`@("`@("1S97-S:6]N+3YA
M8W1I;VX@/2`G8W5T)SL*"B`@("`@("`@:68H(&ES7V%R<F%Y*"1?4D515453
M5%LG<V5L96-T961.;V1E<R==*2`F)B!S:7IE;V8H)%]215%515-46R=S96QE
M8W1E9$YO9&5S)UTI*0H@("`@("`@('L*("`@("`@("`@("`@)'-E<W-I;VXM
M/F1A=&$@/2`D7U)%455%4U1;)W-E;&5C=&5D3F]D97,G73L*("`@("`@("!]
M"B`@("`@("`@96QS90H@("`@("`@('L*("`@("`@("`@("`@)'-E<W-I;VXM
M/F%C=&EO;B`]("<G.PH@("`@("`@('T*("`@('T*"B`@("!I9B@@0"1?4D51
M54535%LG86-T:6]N7W!A<W1E)UT@?'P@0"1?4D5154535%LG86-T:6]N7W!A
M<W1E7W@G72`I"B`@("!["B`@("`@("`@:68H(&ES7V%R<F%Y*"1S97-S:6]N
M+3YD871A*2`F)B!S:7IE;V8H)'-E<W-I;VXM/F1A=&$I*0H@("`@("`@('L*
M("`@("`@("`@("`@:68H("1S97-S:6]N+3YA8W1I;VX@/3T@)V-O<'DG("D*
M("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@:68H(&ES7V%R<F%Y*"1?
M4D5154535%LG<V5L96-T961.;V1E<R==*2`F)B!S:7IE;V8H)%]215%515-4
M6R=S96QE8W1E9$YO9&5S)UTI*0H@("`@("`@("`@("`@("`@>PH@("`@("`@
M("`@("`@("`@("`@("1D97-T(#T@)%]215%515-46R=S96QE8W1E9$YO9&5S
M)UT["B`@("`@("`@("`@("`@("`@("`@)'-O=7)C97,@/2`D<V5S<VEO;BT^
M9&%T83L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H*"`D<V]U<F-E<R!A
M<R`D85-R8R`I"B`@("`@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H*"`D9&5S="!A<R`D841E<W0@*0H@("`@("`@
M("`@("`@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;65T:&]D0V%L;'-;72`](")T<F5E+3YC;W!Y*"`D85-R8R`L("1A1&5S
M="`I(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6UT@
M/2`D=')E92T^8V]P>2@@)&%3<F,@+"`D841E<W0@*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`@("`@(R1R97-U;'1S(#T@)U-O<G)Y($-/4%D@:7,@;F]T(&EM
M<&QE;65N=&5D('EE="`Z+2@G.PH@("`@("`@("`@("`@("`@("`@("1S97-S
M:6]N+3YD871A(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D<V5S<VEO;BT^86-T:6]N*3L*("`@("`@("`@("`@("`@("`@("`D=')E
M92T^<V5T=7`H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<V4*("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("`@("`D
M;65T:&]D1F%I;&5D(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`D<F5S
M=6QT<R`]("=0;&5A<V4@8VAO;W-E(&1E<W1I;F%T:6]N(&9O;&1E<BAS*2!T
M;R!P87-T92!T;R$G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B@@)'-E<W-I;VXM/F%C=&EO;B`]/2`G8W5T)RD*
M("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@:68H("$D7U)%455%4U1;
M)VUO=F5$97-T)UT@*0H@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@
M("`@("`@("1M971H;V1&86EL960@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M("`@("1R97-U;'1S(#T@)U!L96%S92!C:&]O<V4@82!D97-T:6YA=&EO;B!T
M;R!P87-T92!T;R$G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@96QS90H@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@H("1S97-S:6]N+3YD871A(&%S("1A3F]D94ED("D*("`@("`@
M("`@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`@("`@("`@("1M971H
M;V1#86QL<UM=(#T@(G1R964M/FUO=F4H("1A3F]D94ED("P@>R1?4D515453
M5%LG;6]V941E<W0G77T@*2(["B`@("`@("`@("`@("`@("`@("`@("`@("1R
M97-U;'1S6UT@/2`D=')E92T^;6]V92@@)&%.;V1E260@+"`D7U)%455%4U1;
M)VUO=F5$97-T)UT@*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)'-E<W-I;VXM/F1A=&$@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@("`@('5N<V5T*"1S97-S:6]N+3YA8W1I;VXI.PH@("`@("`@
M("`@("`@("`@("`@("1T<F5E+3YS971U<"@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&EF*"`H0"1?
M4D5154535%LG86-T:6]N7V1E;&5T92==('Q\($`D7U)%455%4U1;)V%C=&EO
M;E]D96QE=&5?>"==*2`F)@H@("`@("`@(&ES7V%R<F%Y*"1?4D5154535%LG
M<V5L96-T961.;V1E<R==*2`F)B!S:7IE;V8H)%]215%515-46R=S96QE8W1E
M9$YO9&5S)UTI("D*("`@('L*("`@("`@("`D<F]O=$ED(#T@)'1R964M/F=E
M=%)O;W1)9"@I.PH@("`@("`@(&9O<F5A8V@H("1?4D5154535%LG<V5L96-T
M961.;V1E<R==(&%S("1A3F]D94ED("D*("`@("`@("!["B`@("`@("`@("`@
M(&EF*"`D<F]O=$ED(#T]("1A3F]D94ED("D*("`@("`@("`@("`@>PH@("`@
M("`@("`@("`@("`@)&UE=&AO9$-A;&QS6UT@/2`P.PH@("`@("`@("`@("`@
M("`@)')E<W5L='-;72`]("=#86YT(')E;6]V92!2;V]T('=I=&@@=&AI<R!A
M<'!L:6-A=&EO;B$G.PH@("`@("`@("`@("`@("`@)&UE=&AO9$9A:6QE9"`]
M('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS90H@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("`D;65T:&]D0V%L;'-;72`](")T<F5E
M+3YR96UO=F4H("1A3F]D94ED("DB.PH@("`@("`@("`@("`@("`@)')E<R`]
M("1T<F5E+3YR96UO=F4H("1A3F]D94ED("D["B`@("`@("`@("`@("`@("!I
M9BA014%2.CII<T5R<F]R*"1R97,I*0H@("`@("`@("`@("`@("`@("`@("1M
M971H;V1&86EL960@/2!T<G5E.PH@("`@("`@("`@("`@("`@)')E<W5L='-;
M72`]("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'-E
M<W-I;VXM/F1A=&$@/2!A<G)A>2@I.PH@("`@("`@('5N<V5T*"1S97-S:6]N
M+3YA8W1I;VXI.PH@("`@("`@("1T<F5E+3YS971U<"@I.PH@("`@?0H*"B`@
M("!I9B@@0"1?4D5154535%LG86-T:6]N7V%D9"==("8F"B`@("`@("`@:7-?
M87)R87DH)%]215%515-46R=S96QE8W1E9$YO9&5S)UTI("8F('-I>F5O9B@D
M7U)%455%4U1;)W-E;&5C=&5D3F]D97,G72D@)B8*("`@("`@("`D7U)%455%
M4U1;)VYE=T9O;&1E<B==("D*("`@('L*("`@("`@("!F;W)E86-H*"`D7U)%
M455%4U1;)W-E;&5C=&5D3F]D97,G72!A<R`D84YO9&5)9"`I"B`@("`@("`@
M>PH@("`@("`@("`@("`D;65T:&]D0V%L;'-;72`](")T<F5E+3YA9&0H('LD
M7U)%455%4U1;)VYE=T9O;&1E<B==?2`L("1A3F]D94ED("DB.PH@("`@("`@
M("`@("`D<F5S(#T@)'1R964M/F%D9"@@)%]215%515-46R=N97=&;VQD97(G
M72`L("1A3F]D94ED("D["B`@("`@("`@("`@(&EF*%!%05(Z.FES17)R;W(H
M)')E<RDI"B`@("`@("`@("`@("`@("`D;65T:&]D1F%I;&5D(#T@=')U93L*
M("`@("`@("`@("`@)')E<W5L='-;72`]("1R97,["B`@("`@("`@?0H@("`@
M("`@("1S97-S:6]N+3YD871A(#T@87)R87DH*3L*("`@("`@("!U;G-E="@D
M<V5S<VEO;BT^86-T:6]N*3L*("`@("`@("`D=')E92T^<V5T=7`H*3L*("`@
M('T*"@H@("`@)&%L;%9I<VEB;&5&;VQD97)S(#T@)'1R964M/F=E=$%L;%9I
M<VEB;&4H*3L*"B`@("!I9B@@(4!I<U]A<G)A>2@D7U)%455%4U1;)W-E;&5C
M=&5D3F]D97,G72D@*0H@("`@("`@("1?4D5154535%LG<V5L96-T961.;V1E
M<R==(#T@87)R87DH*3L*"B`@("`C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PH@("`@(PH@("`@(R`@("`@("!S
M:&]W('1H92!T96UP;&%T90H@("`@(PH@("`@)'1P;"T^8V]M<&EL92@G:6YD
M97@N='!L)RD["B`@("!I;F-L=61E*"1T<&PM/F-O;7!I;&5D5&5M<&QA=&4I
M.PH_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]4<F5E+V1O8W,O5')E945D:71O<B]I;F1E>"YT<&P`````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,30R,3<`,3`T,3<S-C,P,#0`,#(T,#(P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#PA+2T*("`@
M("1)9#H@:6YD97@N='!L+'8@,2XQ(#(P,#,O,#$O,S`@,3<Z,3@Z,C0@8V%I
M;B!%>'`@)`HM+3X*"CQH=&UL/@H\8F]D>3X*/'-T>6QE/@H@("`@8F]D>2P@
M=&%B;&4N<VEM<&QE"B`@("!<>PH@("`@("`@(&9O;G0M9F%M:6QY(#H@=F5R
M9&%N82P@9V5N979A+"!A<FEA;#L*("`@("`@("!F;VYT+7-I>F4@.B`Q,7!X
M.PH@("`@("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-$0T1#1$,["B`@("!<?0H@
M("`@=&%B;&4L=&0L(&EN<'5T"B`@("!<>PH@("`@("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z('=H:71E.PH@("`@7'T*("`@(&EN<'5T+F)U='1O;BQI;6<N8G5T
M=&]N"B`@("!<>PH@("`@("`@(&)O<F1E<CH@,7!X(&]U='-E="!B;&%C:SL*
M("`@(%Q]"B`@("!T9"YS96QE8W1E9`H@("`@7'L*("`@("`@("!B86-K9W)O
M=6YD+6-O;&]R.B!L:6=H=&)L=64["B`@("!<?0H@("`@80H@("`@7'L*("`@
M("`@("!C;VQO<CH@<F5D.PH@("`@("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N
M93L*("`@(%Q]"@H\+W-T>6QE/@H*/&9O<FT@;65T:&]D/2)P;W-T(B!A8W1I
M;VX](GLD7U-%4E9%4ELG4$A07U-%3$8G77TB/@H*("`@('MI9BA`)'-E<W-I
M;VXM/F%C=&EO;B`]/2`G8W5T)RE]"B`@("`@("`@/&EM9R!S<F,](F-U="(^
M("9N8G-P.PH@("`@("`@(#QI;6<@<W)C/2)C;W!Y(CX@)FYB<W`["B`@("![
M96QS97T*("`@("`@("`\:6YP=70@:60](F-U="(@<W)C/2)C=70B(&YA;64]
M(F%C=&EO;E]C=70B('1Y<&4](FEM86=E(B!C;&%S<STB8G5T=&]N(B!O;FUO
M=7-E9&]W;CTB9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)V-U="<I+G-T>6QE
M+F)O<F1E<CTG,7!X(&EN<V5T(&)L86-K)R(@86QT/2)C=70B(&YA;64](F-U
M="(@=&ET;&4](F-U="(^("9N8G-P.PH@("`@("`@(#QI;G!U="!I9#TB8V]P
M>2(@<W)C/2)C;W!Y(B!N86UE/2)A8W1I;VY?8V]P>2(@='EP93TB:6UA9V4B
M(&-L87-S/2)B=71T;VXB(&]N;6]U<V5D;W=N/2)D;V-U;65N="YG971%;&5M
M96YT0GE)9"@G8V]P>2<I+G-T>6QE+F)O<F1E<CTG,7!X(&EN<V5T(&)L86-K
M)R(@=&ET;&4](F-O<'DB/B`F;F)S<#L*("`@(#QI;G!U="!I9#TB<&%S=&4B
M('-R8STB<&%S=&4B(&YA;64](F%C=&EO;E]P87-T92(@='EP93TB:6UA9V4B
M(&-L87-S/2)B=71T;VXB(&]N;6]U<V5D;W=N/2)D;V-U;65N="YG971%;&5M
M96YT0GE)9"@G<&%S=&4G*2YS='EL92YB;W)D97(])S%P>"!I;G-E="!B;&%C
M:R<B('1I=&QE/2)P87-T92(^("9N8G-P.PH*("`@(#QI;6<@<W)C/2(B('=I
M9'1H/2(Q(B!H96EG:'0](C(R(B!C;&%S<STB8G5T=&]N(CX@)FYB<W`["@H@
M("`@>VEF*$`D<V5S<VEO;BT^86-T:6]N(#T]("=C=70G*7T*("`@("`@("`\
M:6UG('-R8STB9&5L971E(CX@)FYB<W`["B`@("![96QS97T*("`@("`@("`\
M:6YP=70@:60](F1E;&5T92(@<W)C/2)D96QE=&4B(&YA;64](F%C=&EO;E]D
M96QE=&4B('1Y<&4](FEM86=E(B!C;&%S<STB8G5T=&]N(B!O;FUO=7-E9&]W
M;CTB9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)V1E;&5T92<I+G-T>6QE+F)O
M<F1E<CTG,7!X(&EN<V5T(&)L86-K)R(@=&ET;&4](F1E;&5T92(^"@H@("`@
M)FYB<W`["B`@("`\:6UG('-R8STB(B!W:61T:#TB,2(@:&5I9VAT/2(R,B(@
M8VQA<W,](F)U='1O;B(^("9N8G-P.PH*("`@("9N8G-P.PH@("`@=V]R:R!O
M;CH@)FYB<W`["B`@("`\:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB1$(B
M(&YA;64](G5S95]$0B(^"B`@("`F;F)S<#L*("`@(#QI;G!U="!T>7!E/2)S
M=6)M:70B('9A;'5E/2)&:6QE<WES=&5M(B!N86UE/2)U<V5?1FEL97-Y<W1E
M;2(^"B`@("`F;F)S<#L*("`@(#QI;G!U="!T>7!E/2)S=6)M:70B('9A;'5E
M/2)834PB(&YA;64](G5S95]834PB/@H@("`@)FYB<W`["B`@("`\:6YP=70@
M='EP93TB<W5B;6ET(B!V86QU93TB07)R87DB(&YA;64](G5S95]!<G)A>2(^
M"@H@("`@/&)R/CQB<CX*"B`@("!C=7)R96YT('1R964@:6YS=&%N8VEA=&EO
M;B!U<V5D.@H@("`@/&-O9&4^"B`@("![:68H($`D<V5S<VEO;BT^=7-E(#T]
M("=$0B<@*7T*("`@("`@("`D=')E92`](&YE=R!T<F5E0VQA<W,H("=$0FYE
M<W1E9"<@+"`G;7ES<6PZ+R]R;V]T0&QO8V%L:&]S="]T97-T)R`L(&%R<F%Y
M*"=T86)L92<])F=T.U1!0DQ%7U12144@+"`G;W)D97(G(#TF9W0[("`G;F%M
M92<I("D["B`@("![96QS97T*("`@("`@("`D=')E92`](&YE=R!T<F5E0VQA
M<W,H("=&:6QE<WES=&5M)R`L("<O:&]M92]C86EN+W1M<"<@+&%R<F%Y*"=O
M<F1E<B<@/29G=#L@("=N86UE)RD@*3L*("`@(#PO8V]D93X*"B`@("`\:'(^
M"@H@("`@/'1A8FQE(&%L:6=N/2)L969T(CX*("`@("`@("![9F]R96%C:"@@
M)&%L;%9I<VEB;&5&;VQD97)S(&%S("1A1F]L9&5R("E]"B`@("`@("`@("`@
M('L@)&-L87-S/2<G?0H@("`@("`@("`@("![:68H(&EN7V%R<F%Y*"1A1F]L
M9&5R6R=I9"==+"1S97-S:6]N+3YD871A*2`I?0H@("`@("`@("`@("`@("`@
M>R`D8VQA<W,])R!C;&%S<STB<V5L96-T960B)WT*("`@("`@("`@("`@/'1R
M/@H@("`@("`@("`@("`@("`@/'1D('LD8VQA<W-]/@H@("`@("`@("`@("`@
M("`@("`@('MI9B@@0"1S97-S:6]N+3YA8W1I;VX@/3T@)V-U="<I?0H@("`@
M("`@("`@("`@("`@("`@("`@("`\:6YP=70@='EP93TB<F%D:6\B(&YA;64]
M(FUO=F5$97-T(B!V86QU93TB>R1A1F]L9&5R6R=I9"==?2(^"B`@("`@("`@
M("`@("`@("`@("`@>V5L<V5]"B`@("`@("`@("`@("`@("`@("`@("`@(#QI
M;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB<V5L96-T961.;V1E<UM=(B!V
M86QU93TB>R1A1F]L9&5R6R=I9"==?2(^"B`@("`@("`@("`@("`@("`\+W1D
M/@H@("`@("`@("`@("`@("`@/'1D('LD8VQA<W-]/@H@("`@("`@("`@("`@
M("`@("`@('LE=')E95]S:&]W3F]D92@D849O;&1E<BDE?0H@("`@("`@("`@
M("`@("`@/"]T9#X*("`@("`@("`@("`@/"]T<CX*("`@(#PO=&%B;&4^"@H@
M("`@>VEF*"!`)'-E<W-I;VXM/F%C=&EO;B$])V-U="<@*7T*("`@("`@("`\
M=&%B;&4@8VQA<W,](G-I;7!L92(@8F]R9&5R/2(Q(CX*("`@("`@("`@("`@
M/'1R/@H@("`@("`@("`@("`@("`@/'1H(&-O;'-P86X](C(B/D%D9"!&;VQD
M97(\+W1H/@H@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`\='(^"B`@
M("`@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,B(^"B`@("`@("`@("`@("`@
M("`@("`@0VAO;W-E('1H92!P87)E;G0@9F]L9&5R(&]N('1H92!L969T('-I
M9&4L"B`@("`@("`@("`@("`@("`@("`@/&)R/@H@("`@("`@("`@("`@("`@
M("`@('5N9&5R('=H:6-H('1H92!N97<@9F]L9&5R('-H86QL(&)E(&-R96%T
M960A"B`@("`@("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`\+W1R/@H@
M("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`\=&0^3F%M93PO=&0^
M"B`@("`@("`@("`@("`@("`\=&0^"B`@("`@("`@("`@("`@("`@("`@/&EN
M<'5T(&YA;64](FYE=T9O;&1E<EMN86UE72(^"B`@("`@("`@("`@("`@("`\
M+W1D/@H@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`\='(^"B`@("`@
M("`@("`@("`@("`\=&0^)FYB<W`[/"]T9#X*("`@("`@("`@("`@("`@(#QT
M9#X*("`@("`@("`@("`@("`@("`@("`\:6YP=70@='EP93TB<W5B;6ET(B!N
M86UE/2)A8W1I;VY?861D(B!V86QU93TB861D(CX*("`@("`@("`@("`@("`@
M(#PO=&0^"B`@("`@("`@("`@(#PO='(^"B`@("`@("`@/"]T86)L93X*"@H*
M("`@('MI9BA`)'-E<W-I;VXM/F%C=&EO;CT])V-U="<I?0H@("`@("`@(%EO
M=2!H879E(&-H;W-E;B`G0U54)RP@=&AO<V4@9F]L9&5R<R!A<F4@:6X@=&AE
M(&-L:7!B;V%R9"!N;W<N/&)R/@H@("`@("`@(%!L96%S92!S96QE8W0@=&AE
M(&1E<W1I;F%T:6]N(&%N9"!P=7-H('1H92`G4$%35$4G(&)U='1O;B$@/&EM
M9R!C;&%S<STB8G5T=&]N(B!S<F,](G!A<W1E(CX*("`@("`@("`\8G(^"B`@
M("![:68H0"1S97-S:6]N+3YA8W1I;VX]/2=C;W!Y)RE]"B`@("`@("`@66]U
M(&AA=F4@8VAO<V5N("=#3U!9)RP@=&AO<V4@9F]L9&5R<R!A<F4@:6X@=&AE
M(&-L:7!B;V%R9"!N;W<N/&)R/@H@("`@("`@(%!L96%S92!S96QE8W0@=&AE
M(&1E<W1I;F%T:6]N(&%N9"!P=7-H('1H92`G4$%35$4G(&)U='1O;B$@/&EM
M9R!C;&%S<STB8G5T=&]N(B!S<F,](G!A<W1E(CX\8G(^"B`@("`@("`@3W(@
M8VAO;W-E(&]T:&5R(&9O;&1E<BAS*2!T:&%T('EO=2!W86YT('1O('!U="!I
M;B!T:&4@8VQI<&)O87)D+@H@("`@("`@(#QB<CX*"@H@("`@>VEF*$`D<F5S
M=6QT<RE]"B`@("`@("`@/&9O;G0@8V]L;W(](G)E9"(^"B`@("`@("`@("`@
M('MI9B@@0"1M971H;V1&86EL960@*7T*("`@("`@("`@("`@("`@($524D]2
M"B`@("`@("`@("`@('ME;'-E?0H@("`@("`@("`@("`@("`@3TL*("`@("`@
M("`@("`@/&)R/@H@("`@("`@(#PO9F]N=#X*("`@("`@("![:68H<VEZ96]F
M*"1M971H;V1#86QL<RDI?0H@("`@("`@("`@("`\=&%B;&4@8VQA<W,](G-I
M;7!L92(@8F]R9&5R/2(Q(CX*("`@("`@("`@("`@("`@(#QT<CX*("`@("`@
M("`@("`@("`@("`@("`\=&@^;65T:&]D<R!C86QL960\+W1H/@H@("`@("`@
M("`@("`@("`@("`@(#QT:#YR971U<FYE9#PO=&@^"B`@("`@("`@("`@("`@
M("`\+W1R/@H@("`@("`@("`@("`@("`@>V9O<F5A8V@H("1M971H;V1#86QL
M<R!A<R`D:V5Y/3XD84-A;&PI?0H@("`@("`@("`@("`@("`@("`@(#QT<CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'1D(&YO=W)A<#Y[)&%#86QL?3PO
M=&0^"B`@("`@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@('MI9BA014%2.CII<T5R
M<F]R*"1R97-U;'1S6R1K97E=*2E]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/&9O;G0@8V]L;W(](G)E9"(^>R1R97-U;'1S6R1K97E=+3YG
M971-97-S86=E*"E]/"]F;VYT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QB<CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@('MP<FEN
M=%]R*"1R97-U;'1S6R1K97E=*7T*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]T9#X*("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`\
M+W1A8FQE/@H@("`@("`@('ME;'-E?0H@("`@("`@("`@("`\9F]N="!C;VQO
M<CTB<F5D(CX*("`@("`@("`@("`@("`@('MP<FEN=%]R*"1R97-U;'1S*7T*
M("`@("`@("`@("`@/"]F;VYT/@H*"@H*/"]F;W)M/@H*/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B(&QA;F=U86=E/2)*879A4V-R:7!T(B!S<F,]
M(GLD8V]N9FEG+3YV07!P;%)O;W1]+V5X=&5R;F%L+V-A;&5N9&%R+W!O<&-A
M;&5N9&%R+FIS+G!H<"(^/"]S8W)I<'0^"@H\+V)O9'D^"CPO:'1M;#X*"@H*
M"@H*"CPA+2T*("`@('1H:7,@;6%C<F\@<VAO=W,@82!N;V1E(&9O<B!T:&4@
M97AP;&]R97(@=FEE=PH*("`@($!P87)A;2`@87)R87D@("!T:&4@8W5R<F5N
M="!P<F]J96-T"BTM/@I[)6UA8W)O('1R965?<VAO=TYO9&4H)&%.;V1E*25]
M"B`@("![9VQO8F%L("1T<F5E+"1S97-S:6]N?0H*("`@('LE<F5P96%T("1A
M3F]D95LG;&5V96PG72!T:6UE<R5]"B`@("`@("`@)FYB<W`[("9N8G-P.PH*
M("`@('MI9B@@)'1R964M/FAA<T-H:6QD<F5N*"1A3F]D95LG:60G72D@*7T*
M("`@("`@("`\82!H<F5F/2)[)%]315)615);)U!(4%]314Q&)UU]/W5N9F]L
M9#U[)&%.;V1E6R=I9"==?2(^"B`@("`@("`@("`@('MI9BA`)'-E<W-I;VXM
M/G1E;7`M/F]P96Y0<F]J96-T1F]L9&5R<ULD84YO9&5;)VED)UU=*7T*("`@
M("`@("`@("`@("`@(#QI;6<@<W)C/2)O<&5N1F]L9&5R(B!B;W)D97(](C`B
M/CPO83X*("`@("`@("`@("`@>V5L<V5]"B`@("`@("`@("`@("`@("`\:6UG
M('-R8STB8VQO<V5D1F]L9&5R(B!B;W)D97(](C`B/CPO83X*("`@('ME;'-E
M?0H@("`@("`@(#QI;6<@<W)C/2)F;VQD97(B/@H*("`@("9N8G-P.PH@("`@
M/&(^"B`@("`@("`@>VEF*"`D=')E92T^9V5T4F]O=$ED*"D@/3T@)&%.;V1E
M6R=I9"==("E]"B`@("`@("`@("`@("XN+GME8VAO('-U8G-T<B@D84YO9&5;
M)VYA;64G72PM,C@I?0H@("`@("`@('ME;'-E?0H@("`@("`@("`@("![)&%.
M;V1E6R=N86UE)UU]"B`@("`\+V(^"@H@("`@>VEF*"`D=')E92T^9V5T4F]O
M=$ED*"D@/3T@)&%.;V1E6R=I9"==("E]"B`@("`@("`@)FYB<W`[(#QA(&AR
M968](GLD7U-%4E9%4ELG4$A07U-%3$8G77T_=6YF;VQD06QL/71R=64B('1I
M=&QE/2)U;F9O;&0@86QL(CXK*SPO83X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O5')E92]D;V-S+U1R965%9&ET;W(O
M9F]L9&5R+F=I9@```````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C`V`#$P-#$W,S8S,#`T
M`#`R-#$R-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$?`!``Q@```````@("2$A(%!04R\O+Z>GI+R\O/CX^`&N>
M`#U:=75UI*2D<G)R*"@HP>'MT^WV>;_6Y.3D("$A/+GM.J/%=[S6@L/9"'.E
M`#Q;1D9&'AX>&:_N!X>V.*+%7;'0=KO5@<+8A<39!W"A3T]/%IK+$&RA$GRM
M!X2R5K#-<KG4D<G;/S\_*RLK$X"R"U2"#EZ1#F67$6^@$G^Q6*[-<+C3145%
M_/S\Z>3DBJFY*6R.#ER-#V:8$76D0$!`1$1$]O;V\?'QZ^OKZNKJV]?6@:"P
M*&R/#V66$7*D5Z'`0D)"[N[NYN;FX>'AW-S<U=75U]?7R\G(B*:U)VR,)VB2
M-C8VQ,3$W]_?WM[>V]O;UM;6T='1S,S,Q<7%O[^_P;Z^;FUMP<'!:&AHP,#`
MSL[.RLK*QL;&N[N[MK:VKJZN,C(R8&!@KZ^OM;6UL+"PJJJJ;&MK+BXN6%A8
MG9V=IZ>G:FEI.3DY*2DI.C@U________________________________(?D$
M`0H`?P`L`````!\`$```!^.`?X)_`(.&AP$"AXN,C8(#!`4"`@:.AH6.!P@)
M"@N1`HD,`9:.#0X/$)N=!!$%!:.+F(T2$Q05IQ87&*L%&:2+&AL<'1X?(*<A
M(IPCL98:)"4F)\,H*2JG$"N_ARPM+B\P,3(<PS,T#MJ'A>N$[7\U-C<X.2XZ
M.SPFY#0]VX8^/T"""!E"I,@W(T>0\.LG*(D2(4N8-''R!$H4*2ZF+&1(I8J5
M*UBR:-G"I0L7+U]J@`'#\$\`*F'$C"%31HR9,VB^9%C9<E"`-&K6F&'3QLT;
ME3T7!8`31\X<.G62.@I@Y\Z@0``[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O5')E92]D;V-S+U1R965%
M9&ET;W(O;7ES<6Q?9&(N<W%L````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C,U`#$P-#$W
M,S8S,#`T`#`R-#4R-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C('!H<$UY061M:6X@37E344PM1'5M<`HC('9E<G-I;VX@
M,BXS+C`*(R!H='1P.B\O<&AP=VEZ87)D+FYE="]P:'!->4%D;6EN+PHC(&AT
M='`Z+R]W=W<N<&AP;7EA9&UI;BYN970O("AD;W=N;&]A9"!P86=E*0HC"B,@
M2&]S=#H@;&]C86QH;W-T"B,@1V5N97)A=&EO;B!4:6UE.B!*86X@,S`L(#(P
M,#,@870@,#8Z-#`@4$T*(R!397)V97(@=F5R<VEO;CH@,RXR,RXT.`HC(%!(
M4"!697)S:6]N.B`T+C,N,`HC($1A=&%B87-E(#H@8'1E<W1@"B,@+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T*"B,*(R!486)L92!S=')U8W1U<F4@9F]R('1A8FQE(&!4<F5E7TYE
M<W1E9&`*(PH*0U)%051%(%1!0DQ%(%1R965?3F5S=&5D("@*("!I9"!I;G0H
M,3$I($Y/5"!.54Q,(&1E9F%U;'0@)S`G+`H@(&YA;64@=F%R8VAA<B@R-34I
M($Y/5"!.54Q,(&1E9F%U;'0@)R<L"B`@;"!I;G0H,3$I($Y/5"!.54Q,(&1E
M9F%U;'0@)S`G+`H@('(@:6YT*#$Q*2!.3U0@3E5,3"!D969A=6QT("<P)RP*
M("!P87)E;G0@:6YT*#$Q*2!.3U0@3E5,3"!D969A=6QT("<P)RP*("!C;VUM
M96YT('9A<F-H87(H,C4U*2!.3U0@3E5,3"!D969A=6QT("<G+`H@(%!224U!
M4ED@2T59("`H:60I"BD@5%E013U->4E304T["@HC"B,@1'5M<&EN9R!D871A
M(&9O<B!T86)L92!@5')E95].97-T961@"B,*"DE.4T525"!)3E1/(%1R965?
M3F5S=&5D(%9!3%5%4R`H."P@)U)O;W0G+"`Q+"`S,BP@,"P@)R<I.PI)3E-%
M4E0@24Y43R!4<F5E7TYE<W1E9"!604Q515,@*#DL("=014%2)RP@-BP@,C,L
M(#@L("<G*3L*24Y315)4($E.5$\@5')E95].97-T960@5D%,5453("@Q,"P@
M)U1R964G+"`R,2P@,C(L(#DL("<G*3L*24Y315)4($E.5$\@5')E95].97-T
M960@5D%,5453("@Q,2P@)TA434PG+"`W+"`Q-BP@.2P@)R<I.PI)3E-%4E0@
M24Y43R!4<F5E7TYE<W1E9"!604Q515,@*#$R+"`G075T:"<L(#$W+"`Q."P@
M.2P@)R<I.PI)3E-%4E0@24Y43R!4<F5E7TYE<W1E9"!604Q515,@*#$S+"`G
M4$5!4B!C;VUP871I8FQE)RP@,"P@-2P@."P@)R<I.PI)3E-%4E0@24Y43R!4
M<F5E7TYE<W1E9"!604Q515,@*#$T+"`G4VEM<&QE5&5M<&QA=&4G+"`S+"`T
M+"`Q,RP@)R<I.PI)3E-%4E0@24Y43R!4<F5E7TYE<W1E9"!604Q515,@*#$U
M+"`G075T:"<L(#$L(#(L(#$S+"`G)RD["DE.4T525"!)3E1/(%1R965?3F5S
M=&5D(%9!3%5%4R`H,3@L("=496UP;&%T92<L(#@L(#$U+"`Q,2P@)R<I.PI)
M3E-%4E0@24Y43R!4<F5E7TYE<W1E9"!604Q515,@*#$W+"`G1$(G+"`Q.2P@
M,C`L(#DL("<G*3L*24Y315)4($E.5$\@5')E95].97-T960@5D%,5453("@Q
M.2P@)UAI<&4G+"`Q,RP@,30L(#$X+"`G)RD["DE.4T525"!)3E1/(%1R965?
M3F5S=&5D(%9!3%5%4R`H,C$L("=H=&UL)RP@+38L(#$L(#@L("<G*3L*24Y3
M15)4($E.5$\@5')E95].97-T960@5D%,5453("@R,BP@)W1E<W0G+"`M,2P@
M,"P@."P@)R<I.PI)3E-%4E0@24Y43R!4<F5E7TYE<W1E9"!604Q515,@*#(S
M+"`G8V)V8W9B8R<L(#$Q+"`Q,BP@,3@L("<G*3L*24Y315)4($E.5$\@5')E
M95].97-T960@5D%,5453("@R-"P@)T9L97AY)RP@.2P@,3`L(#$X+"`G06QA
M;EQ<7"=S('1E;7!L871E(&-L87-S)RD["B,@+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"B,*(R!4
M86)L92!S=')U8W1U<F4@9F]R('1A8FQE(&!4<F5E7TYE<W1E9%]S97%@"B,*
M"D-214%412!404),12!4<F5E7TYE<W1E9%]S97$@*`H@(&ED(&EN="@Q,"D@
M=6YS:6=N960@3D]4($Y53$P@875T;U]I;F-R96UE;G0L"B`@4%))34%262!+
M15D@("AI9"D**2!465!%/4UY25-!33L*"B,*(R!$=6UP:6YG(&1A=&$@9F]R
M('1A8FQE(&!4<F5E7TYE<W1E9%]S97%@"B,*"DE.4T525"!)3E1/(%1R965?
M3F5S=&5D7W-E<2!604Q515,@*#(T*3L*"@``````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U1R964O9&]C<R]4<F5E161I=&]R
M+V1E;&5T92YG:68````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(P,``Q,#0Q-S,V,S`P
M-``P,C0Q,#0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA%P`7`*$``-S<W/3+R_\``/___R'^%4-R96%T960@=VET
M:"!4:&4@1TE-4``A^00!"@`#`"P`````%P`7```".(2/J<OM#Z,+A\J*KQ&'
M:R!0@:<)G/D!(VA])OF-K8NF(%A+[[U&X>V!.8*LFT\5%#YRMJ;SV2P``#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]4<F5E+V1O8W,O5')E945D:71O<B]T<F5E0VQA<W,N
M<&AP````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#4U,C$`,3`T,3<S-C,P,#0`,#(T-C(T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O"B\O("`D3&]G.B!T<F5E0VQA<W,N<&AP+'8@)`HO+R`@4F5V:7-I;VX@
M,2XQ("`R,#`S+S`Q+S,P(#$W.C$X.C(T("!C86EN"B\O("`M(&UO=F5D(&%L
M;"!E>&%M<&QE<R!T;R!D;V-S"B\O("`M(&%N9"!M86ME('1H96T@=V]R:R!P
M<F]P97)L>0HO+PHO+R`@4F5V:7-I;VX@,2XQ("`R,#`R+S`X+S(S(#$W.C$X
M.C(X("!C86EN"B\O("`M(&$@9V]O9"!E>&%M<&QE('1O('-H;W<@:&]W('1H
M92!T<F5E('=O<FMS"B\O"B\O"@IR97%U:7)E7V]N8V4H)U1R964O365M;W)Y
M+G!H<"<I.PH*"F-L87-S('1R965#;&%S<R!E>'1E;F1S(%1R965?365M;W)Y
M"GL*"B`@("!F=6YC=&EO;B!G9710871H07-3=')I;F<H("1I9"`I"B`@("![
M"B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G+U)O;W1<<RU<<R\G+"<G
M+'!A<F5N=#HZ9V5T4&%T:$%S4W1R:6YG*"`D:60@+"`G("T@)R`I*3L*("`@
M('T*"B`@("`O*BH*("`@("H@("!J=7-T(&$@=W)A<'!E<B!T;R!B92!C;VUP
M871I8FQE('1O('9P7T1"7T-O;6UO;@H@("`@*@H@("`@*B\*("`@(&9U;F-T
M:6]N("9G971!;&PH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9V5T
M3F]D92@I.PH@("`@?0H*("`@("\J*@H@("`@*B`@('1H:7,@:7,@;VYL>2!F
M;W(@=&AE(&=E=$%L;%9I<VEB;&4@:70@:7,@8V%L;&5D(&)Y('1H92!W86QK
M+6UE=&AO9`H@("`@*B`@('1O(')E=')E:79E(&]N;'D@=&AE(&YO9&5S('1H
M870@<VAA;&P@8F4@=FES:6)L90H@("`@*@H@("`@*B`@($!P87)A;2`@("`@
M(&%R<F%Y("`@=&AI<R!I<R!T:&4@;F]D92!T;R!C:&5C:PH@("`@*B`@($!R
M971U<FX@("`@(&UI>&5D("`@86X@87)R87D@:68@=&AE(&YO9&4@<VAA;&P@
M8F4@=FES:6)L90H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;F]T:&EN
M9R!I9B!T:&4@;F]D92!S:&%L;"!N;W0@8F4@<VAO=VX*("`@("HO"B`@("!F
M=6YC=&EO;B!?=V%L:T9O<D=E='1I;F=6:7-I8FQE1F]L9&5R<R@@)&YO9&4@
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<V5S<VEO;CL*"B`@("`@("`@:68H
M("1N;V1E6R=I9"==/3TD=&AI<RT^9V5T4F]O=$ED*"D@*0H@("`@("`@("`@
M("!R971U<FX@)&YO9&4["@H@("`@("`@("1P87)E;G1S261S(#T@)'1H:7,M
M/F=E=%!A<F5N='-)9',H)&YO9&5;)VED)UTI.PH@("`@("`@(&EF*"`A0"1T
M:&ES+3Y?=6YF;VQD06QL("D*("`@("`@("!["B`@("`@("`@("`@(&9O<F5A
M8V@H("1P87)E;G1S261S(&%S("1A4&%R96YT260@*0H@("`@("`@("`@("![
M"B`@("`@("`@("`@("`@("!I9B@@(4`D<V5S<VEO;BT^=&5M<"T^;W!E;E!R
M;VIE8W1&;VQD97)S6R1A4&%R96YT261=("8F"B`@("`@("`@("`@("`@("`@
M("`@)&%087)E;G1)9"$])&YO9&5;)VED)UTI("`@("\O(&1O;G0@8VAE8VL@
M=&AE(&YO9&4@:71S96QF+"!S:6YC92!W92!O;FQY(&QO;VL@:68@=&AE('!A
M<F5N=',@87)E(&]P96YE;F0L('1H96X@=&AI<R`D;F]D92!I<R!S:&]W;B$*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@96QS90H@("`@("`@('L*("`@("`@("`@
M("`@+R\@:68@86QL(&9O;&1E<G,@<VAA;&P@8F4@=6YF;VQD960@<V%V92!T
M:&4@=6YF;VQD+6ED<R!I;B!T:&4@<V5S<VEO;@H@("`@("`@("`@("`D<V5S
M<VEO;BT^=&5M<"T^;W!E;E!R;VIE8W1&;VQD97)S6R1N;V1E6R=I9"==72`]
M("1N;V1E6R=I9"==.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&YO9&4[
M"B`@("!]"@H@("`@+RHJ"B`@("`J("`@=&AI<R!R971U<FYS(&%L;"!T:&4@
M=FES:6)L92!P<F]J96-T<RP@=&AE(&9O;&1E<G,@<F5T=7)N960*("`@("H@
M("!A<F4@=&AO<V4@=VAI8V@@87)E('5N9F]L9&5D+"!T:&4@97AP;&]R97(M
M;&EK92!W87D*("`@("H@("!I="!A;'-O(&AA;F1L97,@=&AE("=U;F9O;&0G
M('!A<F%M971E<BP@=VAI8V@@=V4@<VEM<&QY(&UI9VAT(&)E(&=I=F5N"B`@
M("`J("`@<V\@=&AE('5N9F]L9"]F;VQD('=O<FMS(&]N(&5V97)Y('!A9V4@
M=&AA="!S:&]W<R!O;FQY('9I<VEB;&4@9F]L9&5R<PH@("`@*B`@(&D@=&AI
M;FL@=&AA="!I<R!R96%L;'D@8V]O;"`Z+2D*("`@("H*("`@("H@("!`<F5T
M=7)N("`@("!A<G)A>2`@(&]N;'D@=&AO<V4@9F]L9&5R<R!W:&EC:"!A<F4@
M=FES:6)L90H@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%L;%9I<VEB;&4H*0H@
M("`@>PH@("`@("`@("1T:&ES+3YU;F9O;&1(86YD;&5R*"D["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YW86QK*"!A<G)A>2@F)'1H:7,L)U]W86QK1F]R1V5T
M=&EN9U9I<VEB;&5&;VQD97)S)RD@+"`P("P@)VEF07)R87DG("D["B`@("!]
M"@H@("`@9G5N8W1I;VX@=6YF;VQD2&%N9&QE<B@I"B`@("!["B`@("`@("`@
M9VQO8F%L("1S97-S:6]N.PH*("`@("`@("!I9B@@0"1?4D5154535%LG=6YF
M;VQD06QL)UT@*0H@("`@("`@('L*("`@("`@("`@("`@)'1H:7,M/E]U;F9O
M;&1!;&P@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@:68H($`D7U)%455%
M4U1;)W5N9F]L9"==("D*("`@("`@("!["B`@("`@("`@("`@(&EF*"!`)'-E
M<W-I;VXM/G1E;7`M/F]P96Y0<F]J96-T1F]L9&5R<ULD7U)%455%4U1;)W5N
M9F]L9"==72`I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@('5N<V5T
M*"1S97-S:6]N+3YT96UP+3YO<&5N4')O:F5C=$9O;&1E<G-;)%]215%515-4
M6R=U;F9O;&0G75TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4*
M("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@)'-E<W-I;VXM/G1E;7`M
M/F]P96Y0<F]J96-T1F]L9&5R<ULD7U)%455%4U1;)W5N9F]L9"==72`]("1?
M4D5154535%LG=6YF;VQD)UT["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H*?0H*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U1R
M964O9&]C<R]4<F5E5FEE=R\`````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,S`P-``P,C$V-3(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O5')E92]D;V-S+U1R9656:65W+VEN9&5X+G!H<```
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-#(W`#$P-#$W,S8S,#`T`#`R,S0W-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H@("`@+R\*("`@("\O("`D260Z(&EN9&5X+G!H<"QV(#$N,R`R,#`S+S`R
M+S(U(#$R.C$T.C,P(&-A:6X@17AP("0*("`@("\O"FEN:5]S970H)VEN8VQU
M9&5?<&%T:"<L<F5A;'!A=&@H9&ER;F%M92A?7T9)3$5?7RDN)R\N+B\N+B\N
M+B\G*2XG.B<N<F5A;'!A=&@H9&ER;F%M92A?7T9)3$5?7RDN)R\N+B\N+B\N
M+B\N+B]I;F-L=61E<R<I+B<Z)RYI;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D[
M"FEN:5]S970H)V5R<F]R7W)E<&]R=&EN9R<L15]!3$PI.PH*("`@(",C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M"B`@("`C"B`@("`C("`@("`@(&EN:70@=&5M<&QA=&4@96YG:6YE"B`@("`C
M"B`@("`O+R!Y;W4@;F5E9"!T:&4@=&5M<&QA=&4@8VQA<W,@9G)O;2!H='1P
M.B\O<V8N;F5T+W!R;VIE8W1S+W-I;7!L='!L"B`@("!I9B`H(4!I;F-L=61E
M*"=(5$U,+U1E;7!L871E+UAI<&4N<&AP)RDI('L*("`@("`@("!P<FEN="`@
M("=S;W)R>2P@>6]U(&YE960@=&AE('1E;7!L871E(&-L87-S(%!%05(Z.DA4
M34Q?5&5M<&QA=&5?6&EP93QB<CXG+@H@("`@("`@("`@("`@("`@)V]R(&EF
M(&D@:&%V92!T:6UE(&D@<'5T('1H92!E>&%M<&QE<R`\82!H<F5F/2)H='1P
M.B\O;W,N=FES:6]N<"YD92\B/FAE<F4@;VYL:6YE/"]A/B<["B`@("`@("`@
M9&EE*"D["B`@("!]"B`@("!R97%U:7)E7V]N8V4H)TA434PO5&5M<&QA=&4O
M6&EP92]&:6QT97(O5&%G3&EB+G!H<"<I.PH@("`@)&]P=&EO;G,@/2!A<G)A
M>2@@("`G=&5M<&QA=&5$:7(G("`@/3X@9&ER;F%M92A?7T9)3$5?7RD@*3L*
M("`@("1T<&P@/2!N97<@2%1-3%]496UP;&%T95]8:7!E*"1O<'1I;VYS*3L*
M"@H@("`@(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,*("`@(",*("`@(",@("`@("`@86-T=6%L('1R964@<W1U
M9F8L('5S:6YG($1Y;F%M:6-?1$)N97-T960*("`@(",*("`@(')E<75I<F5?
M;VYC92@G5')E92]4<F5E+G!H<"<I.PH@("`@)'1R964@/2!4<F5E.CIS971U
M<"@@)T1Y;F%M:6-?1$)N97-T960G("P@)VUY<W%L.B\O<F]O=$!L;V-A;&AO
M<W0O=&5S="<@+"!A<G)A>2@G=&%B;&4G/3XG5')E95].97-T960G*2`I.PH@
M("`@"B`@("!I9B@@0"1?4D5154535%LG86-T:6]N7V%D9"==("D*("`@('L*
M("`@("`@("`D;65T:&]D0V%L;"`](")T<F5E+3YA9&0H('LD7U)%455%4U1;
M)VYE=T1A=&$G77T@+"![)%]215%515-46R=P87)E;G1)9"==?2`L('LD7U)%
M455%4U1;)W!R979)9"==?2`I(CL*("`@("`@("`D<F5S=6QT(#T@)'1R964M
M/F%D9"@@)%]215%515-46R=N97=$871A)UT@+"`D7U)%455%4U1;)W!A<F5N
M=$ED)UT@+"`D7U)%455%4U1;)W!R979)9"==("D["B`@("!]"@H@("`@:68H
M($`D7U)%455%4U1;)V%C=&EO;E]R96UO=F4G72`I"B`@("!["B`@("`@("`@
M)&UE=&AO9$-A;&P@/2`B)'1R964M/G)E;6]V92@@>R1?4D5154535%LG<F5M
M;W9E260G77T@*2(["B`@("`@("`@)')E<W5L="`]("1T<F5E+3YR96UO=F4H
M("1?4D5154535%LG<F5M;W9E260G72`I.PH@("`@?0H*("`@(&EF*"!`)%]2
M15%515-46R=A8W1I;VY?=7!D871E)UT@*0H@("`@>PH@("`@("`@("1M971H
M;V1#86QL(#T@(G1R964M/G5P9&%T92@@>R1?4D5154535%LG=7!D871E260G
M77T@+"![)%]215%515-46R=U<&1A=&5$871A)UU]("DB.PH@("`@("`@("1R
M97-U;'0@/2`D=')E92T^=7!D871E*"`D7U)%455%4U1;)W5P9&%T94ED)UT@
M+"`D7U)%455%4U1;)W5P9&%T941A=&$G72`I.PH@("`@?0H*("`@(&EF*"!`
M)%]215%515-46R=A8W1I;VY?;6]V92==("D*("`@('L*("`@("`@("`D;65T
M:&]D0V%L;"`](")T<F5E+3YM;W9E*"![)%]215%515-46R=M;W9E7VED)UU]
M("P@>R1?4D5154535%LG;6]V95]N97=087)E;G1)9"==?2`L('LD7U)%455%
M4U1;)VUO=F5?;F5W4')E=DED)UU]("DB.PH@("`@("`@("1R97-U;'0@/2`D
M=')E92T^;6]V92@@)%]215%515-46R=M;W9E7VED)UT@+"`D7U)%455%4U1;
M)VUO=F5?;F5W4&%R96YT260G72`L("1?4D5154535%LG;6]V95]N97=0<F5V
M260G72`I.PH@("`@?0H*("`@("1M971H;V1&86EL960@/2!F86QS93L*("`@
M(&EF*"!`4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2`I"B`@("`@("`@)&UE=&AO
M9$9A:6QE9"`]('1R=64["@H@("`@)&9I9"`]($`D7U)%455%4U1;)V9I9"==
M.PH@("`@:68H("$D9FED("D*("`@("`@("`D9FED(#T@)'1R964M/F=E=%)O
M;W1)9"@I.PH*("`@("1P871H(#T@)'1R964M/F=E=%!A=&@H("1F:60@*3L*
M("`@("1C:&EL9')E;B`]("1T<F5E+3YG971#:&EL9')E;B@@)&9I9"`I.PH*
M("`@(",C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C"B`@("`C"B`@("`C("`@("`@(&%C='5A;"!T<F5E('-T=69F
M('1O('-H;W<@=&AE(&5N=&ER92!T<F5E('5S:6YG($UE;6]R>5]$0FYE<W1E
M9`H@("`@(PH@("`@<F5Q=6ER95]O;F-E*"=4<F5E+U1R964N<&AP)RD["B`@
M("`D;65M5')E92`](%1R964Z.G-E='5P*"`G365M;W)Y7T1";F5S=&5D)R`L
M("=M>7-Q;#HO+W)O;W1`;&]C86QH;W-T+W1E<W0G("P@"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G=&%B;&4G/3XG5')E95].97-T960G
M*2`I.PH*("`@("1M96U4<F5E+3YS971U<"@I.PH@("`@)&5N=&ER951R964@
M/2`D;65M5')E92T^9V5T3F]D92@I.PH@("`@)'1R965$97!T:"`]("1M96U4
M<F5E+3YG971$97!T:"@I.PH*("`@("1T<&PM/F-O;7!I;&4H)VEN9&5X+G1P
M;"<I.PH@("`@:6YC;'5D92@D='!L+3YC;VUP:6QE9%1E;7!L871E*3L*/SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]4
M<F5E+V1O8W,O5')E959I97<O:6YD97@N='!L````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3$U-3(`,3`T,3<S-C,P,#0`,#(S-3`S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QH=&UL/@H\8F]D>3X*/"$M+0H@
M("`@)$ED.B!I;F1E>"YT<&PL=B`Q+C(@,C`P,R\P,B\R-2`Q,CHQ-#HS,"!C
M86EN($5X<"`D"BTM/@H*/'-T>6QE/@H@("`@=&1<>W!A9&1I;F<Z-7!X.UQ]
M"CPO<W1Y;&4^"@I[:68H0"1M971H;V1#86QL*7T*("`@(#QF;VYT(&-O;&]R
M/2)R960B/@H@("`@("`@('MI9B@@0"1M971H;V1&86EL960@*7T*("`@("`@
M("`@("`@15)23U(*("`@("`@("![96QS97T*("`@("`@("`@("`@3TL*("`@
M("`@("`\8G(^"B`@("`@("`@8V%L;#H@)'LD;65T:&]D0V%L;'T\8G(^"B`@
M("`@("`@;65T:&]D(')E='5R;F5D.B![<')I;G1?<B@D<F5S=6QT*7T*("`@
M(#PO9F]N=#X*"CQF;W)M(&%C=&EO;CTB>R1?4T525D526R=02%!?4T5,1B==
M?2(@;65T:&]D/2)P;W-T(B!N86UE/2)M>49O<FTB/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)F:60B('9A;'5E/2)[)%]215%515-46R=F:60G77TB
M/@H*/'1A8FQE(&)O<F1E<CTB,2(@86QI9VX](FQE9G0B/@H@("`@/'1R/@H@
M("`@("`@(#QT9"!C;VQS<&%N/2(S(CX*("`@("`@("`@("`@<&%T:#QB<CX*
M("`@("`@("`@("`@>V9O<F5A8V@H("1P871H(&%S("1I;F1E>#T^)&%&;VQD
M97(@*7T*("`@("`@("`@("`@("`@(#QA(&AR968](GLD7U-%4E9%4ELG4$A0
M7U-%3$8G77T_9FED/7LD849O;&1E<ELG:60G77TB/GLD849O;&1E<ELG;F%M
M92==?3PO83X@+PH@("`@("`@(#PO=&0^"B`@("`\+W1R/@H*("`@(#QT<CX*
M("`@("`@("`\=&0@<F]W<W!A;CTB,C`B('9A;&EG;CTB=&]P(CX*("`@("`@
M("`@("`@8VAI;&1R96X\8G(^"B`@("`@("`@("`@('MF;W)E86-H*"`D8VAI
M;&1R96X@87,@)&%#:&EL9"`I?0H@("`@("`@("`@("`@("`@/&$@:')E9CTB
M>R1?4T525D526R=02%!?4T5,1B==?3]F:60]>R1A0VAI;&1;)VED)UU](CY[
M)&%#:&EL9%LG;F%M92==?3PO83X\8G(^"B`@("`@("`@/"]T9#X*"B`@("`\
M(2TM"B`@("!\("`@("`@861D(&9O;&1E<@H@("`@*RTM/@H@("`@("`@(#QT
M:"!C;VQS<&%N/2(R(CX*("`@("`@("`@("`@/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB<&%R96YT260B('9A;'5E/2)[)&%&;VQD97);)VED)UU](CX*
M("`@("`@("`@("`@861D(&9O;&1E<B!U;F1E<B`G>R1A1F]L9&5R6R=N86UE
M)UU])PH@("`@("`@(#PO=&@^"B`@("`\+W1R/@H*("`@(#QT<CX*("`@("`@
M("`\=&0^)FYB<W`[/"]T9#X*("`@("`@("`\=&0^"B`@("`@("`@("`@(#QS
M96QE8W0@;F%M93TB<')E=DED(CX*("`@("`@("`@("`@("`@('LE8V]P>2!B
M;&]C:R!C:&EL9')E;D%S3W!T:6]N<R!H97)E("5]"B`@("`@("`@("`@(#PO
M<V5L96-T/@H@("`@("`@(#PO=&0^"B`@("`\+W1R/@H@("`@/'1R/@H@("`@
M("`@(#QT9#YN86UE/"]T9#X*("`@("`@("`\=&0^/&EN<'5T(&YA;64](FYE
M=T1A=&%;;F%M95TB/CPO=&0^"B`@("`\+W1R/@H@("`@/'1R/@H@("`@("`@
M(#QT9#YC;VUM96YT/"]T9#X*("`@("`@("`\=&0^/'1E>'1A<F5A(&YA;64]
M(FYE=T1A=&%;8V]M;65N=%TB(&-O;',](C4P(B!R;W=S/2(S(CX\+W1E>'1A
M<F5A/CPO=&0^"B`@("`\+W1R/@H@("`@/'1R/@H@("`@("`@(#QT9"!C;VQS
M<&%N/2(R(B!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB<W5B;6ET(B!N
M86UE/2)A8W1I;VY?861D(B!V86QU93TB861D(CX\+W1D/@H@("`@/"]T<CX*
M"B`@("`\(2TM"B`@("!\("`@("`@<F5M;W9E(&9O;&1E<@H@("`@*RTM/@H@
M("`@/'1R/@H@("`@("`@(#QT:"!C;VQS<&%N/2(R(CX*("`@("`@("`@("`@
M<F5M;W9E(&9O;&1E<@H@("`@("`@(#PO=&@^"B`@("`\+W1R/@H@("`@/'1R
M/@H@("`@("`@(#QT9#YN86UE/"]T9#X*("`@("`@("`\=&0^"B`@("`@("`@
M("`@(#QS96QE8W0@;F%M93TB<F5M;W9E260B(&]N0VAA;F=E/2)U<&1A=&5#
M;VUM96YT*'1H:7,N=F%L=64I(CX*("`@("`@("`@("`@("`@('LE8V]P>2!B
M;&]C:R!C:&EL9')E;D%S4F5M;W9E3W!T:6]N<R!H97)E("5]"B`@("`@("`@
M("`@(#PO<V5L96-T/@H@("`@("`@(#PO=&0^"B`@("`\+W1R/@H@("`@/'1R
M/@H@("`@("`@(#QT9#YC;VUM96YT/"]T9#X*("`@("`@("`\=&0^/'1E>'1A
M<F5A(&YA;64](G)E;6]V941A=&%;8V]M;65N=%TB(&-O;',](C4P(B!R;W=S
M/2(S(B!R96%D;VYL>3X\+W1E>'1A<F5A/CPO=&0^"B`@("`\+W1R/@H@("`@
M/'1R/@H@("`@("`@(#QT9"!C;VQS<&%N/2(R(B!A;&EG;CTB8V5N=&5R(CX\
M:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)A8W1I;VY?<F5M;W9E(B!V86QU
M93TB<F5M;W9E(CX\+W1D/@H@("`@/"]T<CX*("`@(#PA+2T*("`@('P@("`@
M("!U<&1A=&4@9F]L9&5R"B`@("`K+2T^"B`@("`\='(^"B`@("`@("`@/'1H
M(&-O;'-P86X](C(B/@H@("`@("`@("`@("!U<&1A=&4@9F]L9&5R"B`@("`@
M("`@/"]T:#X*("`@(#PO='(^"B`@("`\='(^"B`@("`@("`@/'1D/FYA;64\
M+W1D/@H@("`@("`@(#QT9#X*("`@("`@("`@("`@/'-E;&5C="!N86UE/2)U
M<&1A=&5)9"(@;VY#:&%N9V4](G5P9&%T94-O;6UE;G0H=&AI<RYV86QU92DB
M/@H@("`@("`@("`@("`@("`@>R5C;W!Y(&)L;V-K(&-H:6QD<F5N07-296UO
M=F5/<'1I;VYS(&AE<F4@)7T*("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@
M("`@/"]T9#X*("`@(#PO='(^"B`@("`\='(^"B`@("`@("`@/'1D/FYA;64\
M+W1D/@H@("`@("`@(#QT9#X\:6YP=70@;F%M93TB=7!D871E1&%T85MN86UE
M72(^/"]T9#X*("`@(#PO='(^"B`@("`\='(^"B`@("`@("`@/'1D/F-O;6UE
M;G0\+W1D/@H@("`@("`@(#QT9#X\=&5X=&%R96$@;F%M93TB=7!D871E1&%T
M85MC;VUM96YT72(@8V]L<STB-3`B(')O=W,](C,B/CPO=&5X=&%R96$^/"]T
M9#X*("`@(#PO='(^"B`@("`\='(^"B`@("`@("`@/'1D(&-O;'-P86X](C(B
M(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](F%C
M=&EO;E]U<&1A=&4B('9A;'5E/2)U<&1A=&4B/CPO=&0^"B`@("`\+W1R/@H@
M("`@/"$M+0H@("`@?"`@("`@(&UO=F4@9F]L9&5R"B`@("`K+2T^"B`@("`\
M='(^"B`@("`@("`@/'1H(&-O;'-P86X](C(B/@H@("`@("`@("`@("!M;W9E
M(&9O;&1E<@H@("`@("`@(#PO=&@^"B`@("`\+W1R/@H@("`@/'1R/@H@("`@
M("`@(#QT9#YN86UE/"]T9#X*("`@("`@("`\=&0^"B`@("`@("`@("`@(#QS
M96QE8W0@;F%M93TB;6]V95]I9"(^"B`@("`@("`@("`@("`@("![)6-O<'D@
M8FQO8VL@=')E94%S3W!T:6]N<R!H97)E("5]"B`@("`@("`@("`@(#PO<V5L
M96-T/@H@("`@("`@("`@("!U;F1E<B!P87)E;G0*("`@("`@("`@("`@/'-E
M;&5C="!N86UE/2)M;W9E7VYE=U!A<F5N=$ED(CX*("`@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](C`B/CPO;W!T:6]N/@H@("`@("`@("`@("`@("`@
M>R5C;W!Y(&)L;V-K('1R965!<T]P=&EO;G,@:&5R92`E?0H@("`@("`@("`@
M("`\+W-E;&5C=#X*("`@("`@("`@("`@;W(@8F5H:6YD"B`@("`@("`@("`@
M(#QS96QE8W0@;F%M93TB;6]V95]N97=0<F5V260B/@H@("`@("`@("`@("`@
M("`@/&]P=&EO;B!V86QU93TB,"(^/"]O<'1I;VX^"B`@("`@("`@("`@("`@
M("![)6-O<'D@8FQO8VL@=')E94%S3W!T:6]N<R!H97)E("5]"B`@("`@("`@
M("`@(#PO<V5L96-T/@H@("`@("`@(#PO=&0^"B`@("`\+W1R/@H@("`@/'1R
M/@H@("`@("`@(#QT9"!C;VQS<&%N/2(R(B!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB<W5B;6ET(B!N86UE/2)A8W1I;VY?;6]V92(@=F%L=64](FUO
M=F4B/CPO=&0^"B`@("`\+W1R/@H\+W1A8FQE/@H*=&AE(&5N=&ER92!T<F5E
M("AD97!T:#U[)'1R965$97!T:'TI.CQB<CX\8G(^"GMF;W)E86-H*"1E;G1I
M<F54<F5E(&%S("1A3F]D92E]"B`@("`F;F)S<#L*("`@('LE<F5P96%T("1A
M3F]D95LG;&5V96PG725]"B`@("`@("`@+0H@("`@/&$@:')E9CTB>R1?4T52
M5D526R=02%!?4T5,1B==?3]F:60]>R1A3F]D95LG:60G77TB/GLD84YO9&5;
M)VYA;64G77T\+V$^"B`@("`H:60]>R1A3F]D95LG:60G77TI/&)R/@H*"CPO
M9F]R;3X*"CQS8W)I<'0^"B`@("!F=6YC=&EO;B!U<&1A=&5#;VUM96YT*&ED
M*0H@("`@7'L*("`@("`@("!V87(@8V]M;65N=',@/2!N97<@07)R87DH*3L*
M("`@("`@("![9F]R96%C:"@@)&-H:6QD<F5N(&%S("1A0VAI;&0@*7T*("`@
M("`@("`@("`@8V]M;65N='-;>R1A0VAI;&1;)VED)UU]72`](")[96-H;R!A
M9&1S;&%S:&5S*"1A0VAI;&1;)V-O;6UE;G0G72E](CL*("`@("`@("!D;V-U
M;65N="YM>49O<FU;(G5P9&%T941A=&%;8V]M;65N=%TB72YV86QU92`](&-O
M;6UE;G1S6VED73L*("`@("`@("!D;V-U;65N="YM>49O<FU;(G)E;6]V941A
M=&%;8V]M;65N=%TB72YV86QU92`](&-O;6UE;G1S6VED73L*("`@(%Q]"CPO
M<V-R:7!T/@H*/"]B;V1Y/@H\+VAT;6P^"@H*"@H*"@H*>R5B;&]C:R!C:&EL
M9')E;D%S3W!T:6]N<R5]"B`@("`\;W!T:6]N('9A;'5E/2(P(CYA<R!F:7)S
M=#PO;W!T:6]N/@H@("`@>V9O<F5A8V@H("1C:&EL9')E;B!A<R`D84-H:6QD
M("E]"B`@("`@("`@/&]P=&EO;B!V86QU93TB>R1A0VAI;&1;)VED)UU](CYA
M9G1E<B`G>R1A0VAI;&1;)VYA;64G77TG/"]O<'1I;VX^"GLE+V)L;V-K)7T*
M"@I[)6)L;V-K(&-H:6QD<F5N07-296UO=F5/<'1I;VYS)7T*("`@('MF;W)E
M86-H*"`D8VAI;&1R96X@87,@)&%#:&EL9"`I?0H@("`@("`@(#QO<'1I;VX@
M=F%L=64](GLD84-H:6QD6R=I9"==?2(^>R1A0VAI;&1;)VYA;64G77T\+V]P
M=&EO;CX*>R4O8FQO8VLE?0H*>R5B;&]C:R!T<F5E07-/<'1I;VYS)7T*("`@
M('MF;W)E86-H*"`D96YT:7)E5')E92!A<R`D84YO9&4@*7T*("`@("`@("`\
M;W!T:6]N('9A;'5E/2)[)&%.;V1E6R=I9"==?2(^"B`@("`@("`@>R5R97!E
M870@)&%.;V1E6R=L979E;"==)7T*("`@("`@("`@("`@+0H@("`@("`@('LD
M84YO9&5;)VYA;64G77T*("`@("`@("`\+V]P=&EO;CX*>R4O8FQO8VLE?0H*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O5')E92]D;V-S+TUE;6]R>5]834PN<&AP````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$S,C`R`#$P-#$W,S8S,#`T`#`R,C8Q-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H@("`@+R\*
M("`@("\O("`D260Z($UE;6]R>5]834PN<&AP+'8@,2XR(#(P,#,O,#$O,S`@
M,3<Z-#,Z-#$@8V%I;B!%>'`@)`H@("`@+R\*"B\O:6YI7W-E="@G:6YC;'5D
M95]P871H)RQR96%L<&%T:"AD:7)N86UE*%]?1DE,15]?*2XG+RXN+RXN+R<I
M+B<Z)RYR96%L<&%T:"AD:7)N86UE*%]?1DE,15]?*2XG+RXN+RXN+RXN+VEN
M8VQU9&5S)RDN)SHG+FEN:5]G970H)VEN8VQU9&5?<&%T:"<I*3L*+R]I;FE?
M<V5T*"=E<G)O<E]R97!O<G1I;F<G+$5?04Q,*3L*("`@("\J*@H@("`@*B`@
M('1H:7,@:7,@82!H96QP97(@9G5N8W1I;VXL('-O(&D@9&]N="!H879E('1O
M('=R:71E('-O(&UA;GD@<')I;G1S(#HM*0H@("`@*B`@($!P87)A;2`@87)R
M87D@("`D<&%R82`@('1H92!R97-U;'0@<F5T=7)N960@8GD@<V]M92!M971H
M;V0L('1H870@=VEL;"!B92!D=6UP960*("`@("H@("!`<&%R86T@('-T<FEN
M9R`@)'-T<FEN9R!T:&4@97AP;&%I;FEN9R!S=')I;F<*("`@("HO"B`@("!F
M=6YC=&EO;B!D=6UP2&5L<&5R*"`D<&%R82`L("1S=')I;F<])R<@*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D=')E93L*"B`@("`@("`@<')I;G0@)SQI/CQU
M/CQF;VYT(&-O;&]R/2(C,#`X,#`P(CXG+B1S=')I;F<N)SPO9F]N=#X\+W4^
M/"]I/CQB<CXG.PH@("`@("`@("\O('1H:7,@;65T:&]D(&1U;7!S('1O('1H
M92!S8W)E96XL('-I;F-E('!R:6YT7W(@;W(@=F%R7V1U;7`@9&]N=`H@("`@
M("`@("\O('=O<FL@=&]O(&=O;V0@:&5R92P@8F5C875S92!T:&4@:6YN97(@
M87)R87D@:7,@<F5C=7)S:79E"B`@("`@("`@+R\@=V5L;"P@:70@;&]O:W,@
M=6=L>2!B=70@;VYE(&-A;B!S964@=VAA="!I<R!M96%N="`Z+2D*("`@("`@
M("`D=')E92T^=F%R1'5M<"@D<&%R82D["B`@("`@("`@<')I;G0@)SQB<CXG
M.PH*("`@('T*"B`@("`O*BH*("`@("H@("!D=6UP<R!T:&4@96YT:7)E('-T
M<G5C='5R92!N:6-E;'D*("`@("H@("!`<&%R86T@('-T<FEN9R`@)'-T<FEN
M9R!T:&4@97AP;&%I;FEN9R!S=')I;F<*("`@("HO"B`@("!F=6YC=&EO;B!D
M=6UP06QL3FEC96QY*"`D<W1R:6YG/2<G("D*("`@('L*("`@("`@("!G;&]B
M86P@)'1R964["@H@("`@("`@('!R:6YT("<\:3X\=3X\9F]N="!C;VQO<CTB
M(S`P.#`P,"(^)RXD<W1R:6YG+B<\+V9O;G0^/"]U/CPO:3X\8G(^)SL*("`@
M("`@("`D86QL(#T@)'1R964M/F=E=$YO9&4H*3L@("`O+R!G970@=&AE(&5N
M=&ER92!S=')U8W1U<F4@<V]R=&5D(&%S('1H92!T<F5E(&ES+"!S;R!W92!C
M86X@<VEM<&QY(&9O<F5A8V@@=&AR;W5G:"!I="!A;F0@<VAO=R!I=`H@("`@
M("`@(&9O<F5A8V@H("1A;&P@87,@)&%%;&5M96YT("D*("`@("`@("!["B`@
M("`@("`@("`@(&9O<B@@)&D],"`[("1I/"1A16QE;65N=%LG;&5V96PG72`[
M("1I*RLI"B`@("`@("`@("`@("`@("!P<FEN="`G)FYB<W`[("9N8G-P.R`G
M.PH@("`@("`@("`@("!P<FEN="`G/&(^)RXD845L96UE;G1;)VYA;64G72XG
M/"]B/B`]/3TF9W0[("<["@H@("`@("`@("`@("`O+R!Y;W4@8V%N(&%L<V\@
M<VAO=R!A;&P@=&AE(&-O;G1E;G0L('5S:6YG('1H:7,*("`@("`@("`@("`@
M+R\@)'1R964M/G9A<D1U;7`H87)R87DH)&%%;&5M96YT*2D["B`@("`@("`@
M("`@("\O(&D@:G5S="!D:61N="P@<VEN8V4@:70@=&%K97,@=7`@;6]R92!T
M:&5N('1H92!E;G1I<F4@;&EN92P@86YD(&ET<R!U;G)E861A8FQE(#HM*0H*
M("`@("`@("`@("`@<')I;G0@)V%T=')I8G5T97,@+2`G.PH@("`@("`@("`@
M("!P<FEN=%]R*"1A16QE;65N=%LG871T<FEB=71E<R==*3L*("`@("`@("`@
M("`@<')I;G0@)SQB<CXG.PH*("`@("`@("!]"B`@("`@("`@<')I;G0@)SQB
M<CXG.PH*("`@('T*"@H@("`@+RH*"B`@("`@("`@5&AI<R!E>&%M<&QE(&1E
M;6]N<W1R871E<R!H;W<@=&\@;6%N86=E('1R965S"B`@("`@("`@=&AA="!A
M<F4@<V%V960@:6X@86X@6$U,+69I;&4*"B`@("`@("`@:70@<F5A9',@;W5T
M('1H92!E;G1I<F4@9FEL92!U<&]N(&-A;&QI;F<@=&AE(&UE=&AO9`H@("`@
M("`@("=S971U<"<L('1H96X@>6]U(&-A;B!W;W)K(&]N('1H92!T<F5E(&EN
M('=H:6-H979E<B!W87D*("`@("`@("!Y;W4@=V%N="P@:G5S="!H879E(&$@
M;&]O:R!A="!T:&4@97AA;7!L97,*("`@("`@("!T:&5R92!A<F4@9&EF9F5R
M96YT('=A>7,@=&\@86-H:65V92!T:&EN9W,L"B`@("`@("`@:2!W:6QL('1R
M>2!T;R!D96UO;G-T<F%T92`H86QL(&]F*2!T:&5M("`@("`*("`@("`@("`*
M("`@("`@("!.3U1%.B!F;W(@<F5F97)E;FEN9R!T:&4@6$U,+4YO9&5S(&-U
M<G)E;G1L>2!E=F5R>71H:6YG(&AA<R!T;R`*("`@("`@("!B92!L;W=E<B!C
M87-E+"`*("`@("`@("`@("`@4VEM<&QE5&5M<&QA=&4O<')E1FEL=&5R"B`@
M("`@("`@<VAO=6QD(&)E("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@
M("!S:6UP;&5T96UP;&%T92]P<F5F:6QT97(*"B`@("`J+PH*("`@(')E<75I
M<F5?;VYC92@G5')E92]4<F5E+G!H<"<I.PH*("`@("\O(&-A;&QI;F<@)W-E
M='5P365M;W)Y)R!M96%N<R!T;R!R971R96EV92!A(&-L87-S+"!W:&EC:"!W
M;W)K<R!O;B!T<F5E<RP*("`@("\O('1H870@87)E('1E;7!O<F%R:6QY('-T
M;W)E9"!I;B!T:&4@;65M;W)Y+"!I;B!A;B!A<G)A>0H@("`@+R\@=&AI<R!M
M96%N<R!T:&4@96YT:7)E('1R964@:7,@879A:6QA8FQE(&%T(&%L;"!T:6UE
M"B`@("`O+R!C;VYS:61E<B!T:&4@<F5S;W5R8V4@=7-A9V4@86YD(&ET)W,@
M;F]T('1O('-U9V=E<W1E9"!T;R!W;W)K"B`@("`O+R!O;B!H=6=E('1R965S
M("AU<'1O(#$P,#`@96QE;65N=',@:70@<VAO=6QD(&)E(&]K+"!D97!E;F1I
M;F<@;VX@>6]U<B!E;G9I<F]N;65N="!A;F0@<F5Q=6ER96UE;G1S*0H@("`@
M+R\@=7-I;F<@)W-E='5P365M;W)Y)PH@("`@)'1R964@/2!4<F5E.CIS971U
M<$UE;6]R>2@@("=834PG+"`@("`@("`@("`O+R!U<V4@=&AE(%A-3"!C;&%S
M<R!T;R!R96%D(&%N('AM;"!F:6QE"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V-O;F9I9RYX;6PG("`@("\O('1H92!$4TX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`I.PH*("`@("\O(&UE=&AO9',@)V%D9"<@
M)W)E;6]V92<@86YD('-O(&]N(&%R92!N;W0@:6UP;&5M96YT960@>65T+"!Y
M;W4@8V%N(&]N;'D@<F5A9"!T:&4@=')E92!F;W(@;F]W"B`@("`O+R!A;F0@
M;F%V:6=A=&4@:6YS:61E(&]F(&ET"@H@("`@+R\@8V%L;"`G<V5T=7`G+"!T
M;R!B=6EL9"!T:&4@:6YN97(@87)R87DL('-O('=E(&-A;B!W;W)K(&]N('1H
M92!S=')U8W1U<F4@=7-I;F<@=&AE"B`@("`O+R!G:79E;B!M971H;V1S"B`@
M("`D=')E92T^<V5T=7`H*3L*"B`@("!D=6UP06QL3FEC96QY*"`G9'5M<"!A
M;&P@869T97(@(B1T<F5E+29G=#MS971U<"(G("D["@H@("`@+R\@9V5T('1H
M92!P871H(&]F('1H92!L87-T(&EN<V5R=&5D(&5L96UE;G0*("`@('!R:6YT
M("=I9#TG+B1I9"`]("1T<F5E+3YG971)9$)Y4&%T:"@G<VEM<&QE=&5M<&QA
M=&4O;W!T:6]N<R]D96QI;6ET97(G*3L*("`@(&1U;7!(96QP97(H("1T<F5E
M+3YG9710871H*"`D:60@*2`L("=D=6UP('1H92!P871H(&9R;VT@(G-I;7!L
M971E;7!L871E+V]P=&EO;G,O9&5L:6UI=&5R(B<@*3L*"B`@("`D:60@/2`D
M=')E92T^9V5T261">5!A=&@H)W-I;7!L971E;7!L871E+V]P=&EO;G,G*3L*
M("`@(&1U;7!(96QP97(H(&%R<F%Y*"1T<F5E+3YG971087)E;G0H)&ED*2D@
M+"`G9'5M<"!T:&4@<&%R96YT(&]F(")S:6UP;&5T96UP;&%T92]O<'1I;VYS
M(B<@*3L*("`@("\O('EO=2!C86X@86QS;R!U<V4Z("`@("1T<F5E+3YD871A
M6R1I9%U;)W!A<F5N="=="@H@("`@)&ED(#T@)'1R964M/F=E=$ED0GE0871H
M*"=S:6UP;&5T96UP;&%T92<I.PH@("`@9'5M<$AE;'!E<B@@87)R87DH)'1R
M964M/F=E=$-H:6QD*"1I9"DI("P@)V1U;7`@=&AE(&-H:6QD(&]F(")S:6UP
M;&5T96UP;&%T92(G("D["B`@("`O+R!Y;W4@8V%N(&%L<V\@=7-E.B`@("`D
M=')E92T^9&%T85LD:61=6R=C:&EL9"=="@H@("`@)&ED(#T@)'1R964M/F=E
M=$ED0GE0871H*"=S:6UP;&5T96UP;&%T92]P<F5F:6QT97(G*3L*("`@(&1U
M;7!(96QP97(H("1T<F5E+3YG971#:&EL9')E;B@D:60I("P@)V1U;7`@=&AE
M(&-H:6QD<F5N(&]F(")S:6UP;&5T96UP;&%T92]P<F5F:6QT97(B)R`I.PH@
M("`@+R\@>6]U(&-A;B!A;'-O('5S93H@("`@)'1R964M/F1A=&%;)&ED75LG
M8VAI;&1R96XG70H*("`@("1I9"`]("1T<F5E+3YG971)9$)Y4&%T:"@G<VEM
M<&QE=&5M<&QA=&4O;W!T:6]N<R<I.PH@("`@9'5M<$AE;'!E<B@@87)R87DH
M)'1R964M/F=E=$YE>'0H)&ED*2D@+"`G9'5M<"!T:&4@(FYE>'0B(&]F(")S
M:6UP;&5T96UP;&%T92]O<'1I;VYS(B<@*3L*("`@("\O('EO=2!C86X@86QS
M;R!U<V4Z("`@("1T<F5E+3YD871A6R1I9%U;)VYE>'0G70H*("`@("1I9"`]
M("1T<F5E+3YG971)9$)Y4&%T:"@G<VEM<&QE=&5M<&QA=&4O<')E9FEL=&5R
M)RD["B`@("!D=6UP2&5L<&5R*"!A<G)A>2@D=')E92T^9V5T4')E=FEO=7,H
M)&ED*2D@+"`G9'5M<"!T:&4@(G!R979I;W5S(B!O9B`B<VEM<&QE=&5M<&QA
M=&4O<')E9FEL=&5R(B<@*3L*("`@("\O('EO=2!C86X@86QS;R!U<V4Z("`@
M("1T<F5E+3YD871A6R1I9%U;)W!R979I;W5S)UT*"@H@("`@)&ED(#T@)'1R
M964M/F=E=$ED0GE0871H*"=S:6UP;&5T96UP;&%T92]P<F5&:6QT97(G*3L*
M("`@("1E;&5M96YT(#T@)'1R964M/F1A=&%;)&ED75LG8VAI;&0G75LG;F5X
M="==6R=N97AT)UT[("\O(')E9F5R('1O('1H92!T:&ER9"!C:&EL9"!O9B`G
M4VEM<&QE5&5M<&QA=&4O<')E1FEL=&5R+W)E9VES=&5R)PH@("`@9'5M<$AE
M;'!E<B@@)&5L96UE;G1;)VED)UT@+"`G9&5M;R!O9B!U<VEN9R!T:&4@:6YT
M97)N86P@87)R87DL(&9O<B!R969E<F5N8VEN9R!T<F5E+6YO9&5S)R`I.PH*
M+RH*3D]4($E-4$Q%345.5$5$(%E%5`H*("`@("1I9"`]("1T<F5E+3YG971)
M9$)Y4&%T:"@G;7E%;&5M96YT+V%N;W1H97)3=6)%;&5M96YT)RD["B`@("`D
M=')E92T^;6]V92@@)&ED("P@,"`I.PH@("`@)'1R964M/G-E='5P*"D[("\O
M(')E8G5I;&0@=&AE('-T<G5C='5R92!A9V%I;BP@<VEN8V4@=V4@:&%D(&-H
M86YG960@:70*("`@(&1U;7!!;&Q.:6-E;'DH("=D=6UP(&%L;"P@869T97(@
M(FUY16QE;65N="]A;F]T:&5R4W5B16QE;65N="(@=V%S(&UO=F5D('5N9&5R
M('1H92!R;V]T)R`I.PH*("`@("1M;W9E260@/2`D=')E92T^9V5T261">5!A
M=&@H)VUY16QE;65N="<I.PH@("`@)&ED(#T@)'1R964M/F=E=$ED0GE0871H
M*"=A;F]T:&5R4W5B16QE;65N="<I.PH@("`@)'1R964M/FUO=F4H("1M;W9E
M260@+"`D:60@*3L*("`@("1T<F5E+3YS971U<"@I.R`O+R!R96)U:6QD('1H
M92!S=')U8W1U<F4@86=A:6XL('-I;F-E('=E(&AA9"!C:&%N9V5D(&ET"B`@
M("!D=6UP06QL3FEC96QY*"`G9'5M<"!A;&PL(&%F=&5R(")M>45L96UE;G0B
M('=A<R!M;W9E9"!U;F1E<B!T:&4@(F%N;W1H97)3=6)%;&5M96YT(B<@*3L*
M"@H@("`@)'1R964M/G-E=%)E;6]V95)E8W5R<VEV96QY*'1R=64I.PH@("`@
M)'1R964M/G)E;6]V92@P*3L*("`@('!R:6YT("<\9F]N="!C;VQO<CTB<F5D
M(CY!3$P@14Q%345.5%,@2$%612!"145.(%)%34]6140@*'5N8V]M;65N="!T
M:&ES('!A<G0@=&\@:V5E<"!T:&5M(&EN('1H92!$0B!A9G1E<B!R=6YN:6YG
M('1H:7,@=&5S="!S8W)I<'0I/"]F;VYT/B<["BHO"C\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]4<F5E+V1O8W,O8V]N9FEG+GAM;```````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$V,C,`,3`T,3<S-C,P,#0`,#(R,3`V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_>&UL('9E<G-I;VX](C$N
M,"(@/SX*"CQ3:6UP;&5496UP;&%T93X*("`@(#QO<'1I;VYS(&]V97)R:61E
M/2)Y97,B/@H@("`@("`@(#QD96QI;6ET97(@8F5G:6X](ELB(&5N9#TB72(O
M/@H@("`@("`@(#QA=71O0G)A8V5S('9A;'5E/2)T<G5E(B\^"B`@("`@("`@
M/&QO8V%L92!V86QU93TB96XB+SX*("`@(#PO;W!T:6]N<SX*"B`@("`\(2TM
M("`@('!R949I;'1E<B`M(')E9VES=&5R(&%N>2!P<F4@9FEL=&5R(&AE<F4*
M("`@("`@("`@("`@;W9E<G)I9&4@+2`@("`@("`@("`_/S\_"B`@("`@("`@
M("`@(')E9VES=&5R3VYL>4]N8V4@+2`@>65S(&]R(&YO+"!T:&ES('1A:V5S
M(&-A<F4@;V8@;F]T(')E9VES=&5R:6YG(&]N92!F:6QT97(@;75L=&EP;&4@
M=&EM97,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I="=S(&IU
M<W0@;F]T('1O(&QO;W-E('!E<F9O<FUA;F-E"B`@("`@("`@("`@(&EN:&5R
M:71/<'1I;VYS("T@("`@=&AI<R!I;FAE<FET<R!T:&4@;W!T:6]N<R!F<F]M
M('1H92!3:6UP;&5496UP;&%T92!O8FIE8W0@875T;VUA=&EC86QL>0H@("`@
M+2T^"B`@("`\<')E1FEL=&5R(&]V97)R:61E/2)N;R(*("`@("`@("`@("`@
M("`@(')E9VES=&5R3VYL>4]N8V4](GEE<R(*("`@("`@("`@("`@("`@(&EN
M:&5R:71/<'1I;VYS/2)Y97,B/@H@("`@("`@(#QR96=I<W1E<B!F=6YC=&EO
M;CTB<F5M;W9E2'1M;$-O;6UE;G1S(B!O8FIE8W0](G1P;$9I;'1E<B(@+SX*
M("`@("`@("`\<F5G:7-T97(@9G5N8W1I;VX](G)E;6]V94-3='EL94-O;6UE
M;G1S(B!O8FIE8W0](G1P;$9I;'1E<B(@+SX*("`@("`@("`\<F5G:7-T97(@
M9G5N8W1I;VX](F%D9$EF0F5F;W)E1F]R96%C:"(@;V)J96-T/2)T<&Q&:6QT
M97(B("\^"B`@("`\+W!R949I;'1E<CX*"CPO4VEM<&QE5&5M<&QA=&4^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]4<F5E+V1O8W,O365M;W)Y7T1"<VEM<&QE+G!H<```````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,34R,#0`,3`T,3<S-C,P,#0`,#(S-C4W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B`@("`O
M+PH@("`@+R\@("1)9#H@365M;W)Y7T1"<VEM<&QE+G!H<"QV(#$N,B`R,#`S
M+S`Q+S,P(#$W.C0S.C0Q(&-A:6X@17AP("0*("`@("\O"@HO+VEN:5]S970H
M)VEN8VQU9&5?<&%T:"<L<F5A;'!A=&@H9&ER;F%M92A?7T9)3$5?7RDN)R\N
M+B\N+B\G*2XG.B<N<F5A;'!A=&@H9&ER;F%M92A?7T9)3$5?7RDN)R\N+B\N
M+B\N+B]I;F-L=61E<R<I+B<Z)RYI;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D[
M"B\O:6YI7W-E="@G97)R;W)?<F5P;W)T:6YG)RQ%7T%,3"D["@H@("`@+RHJ
M"B`@("`J("`@=&AI<R!I<R!A(&AE;'!E<B!F=6YC=&EO;BP@<V\@:2!D;VYT
M(&AA=F4@=&\@=W)I=&4@<V\@;6%N>2!P<FEN=',@.BTI"B`@("`J("`@0'!A
M<F%M("!A<G)A>2`@("1P87)A("`@=&AE(')E<W5L="!R971U<FYE9"!B>2!S
M;VUE(&UE=&AO9"P@=&AA="!W:6QL(&)E(&1U;7!E9`H@("`@*B`@($!P87)A
M;2`@<W1R:6YG("`D<W1R:6YG('1H92!E>'!L86EN:6YG('-T<FEN9PH@("`@
M*B\*("`@(&9U;F-T:6]N(&1U;7!(96QP97(H("1P87)A("P@)'-T<FEN9STG
M)R`L("1A9&1!<G)A>3UF86QS92`I"B`@("!["B`@("`@("`@9VQO8F%L("1T
M<F5E+"1E;&5M96YT.PH*("`@("`@("!I9B@@)&%D9$%R<F%Y("D*("`@("`@
M("`@("`@979A;"@@(EPD<F5S/6%R<F%Y*"(N)'!A<F$N)RD[)R`I.PH@("`@
M("`@(&5L<V4*("`@("`@("`@("`@979A;"@@(EPD<F5S/2(N)'!A<F$N)SLG
M("D["@H@("`@("`@('!R:6YT("<\8CXG+B1P87)A+B<@/"]B/CQI/CQU/CQF
M;VYT(&-O;&]R/2(C,#`X,#`P(CXG+B1S=')I;F<N)SPO9F]N=#X\+W4^/"]I
M/CQB<CXG.PH@("`@("`@("\O('1H:7,@;65T:&]D(&1U;7!S('1O('1H92!S
M8W)E96XL('-I;F-E('!R:6YT7W(@;W(@=F%R7V1U;7`@9&]N=`H@("`@("`@
M("\O('=O<FL@=&]O(&=O;V0@:&5R92P@8F5C875S92!T:&4@:6YN97(@87)R
M87D@:7,@<F5C=7)S:79E"B`@("`@("`@+R\@=V5L;"P@:70@;&]O:W,@=6=L
M>2!B=70@;VYE(&-A;B!S964@=VAA="!I<R!M96%N="`Z+2D*("`@("`@("`D
M=')E92T^=F%R1'5M<"@D<F5S*3L*("`@("`@("!P<FEN="`G/&)R/B<["@H@
M("`@?0H*("`@("\J*@H@("`@*B`@(&1U;7!S('1H92!E;G1I<F4@<W1R=6-T
M=7)E(&YI8V5L>0H@("`@*B`@($!P87)A;2`@<W1R:6YG("`D<W1R:6YG('1H
M92!E>'!L86EN:6YG('-T<FEN9PH@("`@*B\*("`@(&9U;F-T:6]N(&1U;7!!
M;&Q.:6-E;'DH("1S=')I;F<])R<@*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M=')E93L*"B`@("`@("`@<')I;G0@)SQI/CQU/CQF;VYT(&-O;&]R/2(C,#`X
M,#`P(CXG+B1S=')I;F<N)SPO9F]N=#X\+W4^/"]I/CQB<CXG.PH@("`@("`@
M("1A;&P@/2`D=')E92T^9V5T3F]D92@I.R`@("\O(&=E="!T:&4@96YT:7)E
M('-T<G5C='5R92!S;W)T960@87,@=&AE('1R964@:7,L('-O('=E(&-A;B!S
M:6UP;'D@9F]R96%C:"!T:')O=6=H(&ET(&%N9"!S:&]W(&ET"B`@("`@("`@
M9F]R96%C:"@@)&%L;"!A<R`D845L96UE;G0@*0H@("`@("`@('L*("`@("`@
M("`@("`@9F]R*"`D:3TP(#L@)&D\)&%%;&5M96YT6R=L979E;"==(#L@)&DK
M*RD*("`@("`@("`@("`@("`@('!R:6YT("<F;F)S<#L@)FYB<W`[("<["B`@
M("`@("`@("`@('!R:6YT("1A16QE;65N=%LG;F%M92==+B<@/3T])F=T.R`G
M.PH@("`@("`@("`@("`D=')E92T^=F%R1'5M<"AA<G)A>2@D845L96UE;G0I
M*3L*("`@("`@("!]"B`@("`@("`@<')I;G0@)SQB<CXG.PH*("`@('T*"@H@
M("`@+RH*"B`@("`@("`@=7-E('1H:7,@=&\@8G5I;&0@=&AE(&1B('1A8FQE
M"@H@("`@("`@($-214%412!404),12!T97-T7W1R964@*`H@("`@("`@("`@
M("!I9"!I;G0H,3$I($Y/5"!.54Q,(&%U=&]?:6YC<F5M96YT+`H@("`@("`@
M("`@("!P87)E;G1)9"!I;G0H,3$I($Y/5"!.54Q,(&1E9F%U;'0@)S`G+`H@
M("`@("`@("`@("!N86UE('9A<F-H87(H,C4U*2!.3U0@3E5,3"!D969A=6QT
M("<G+`H@("`@("`@("`@("!04DE-05)9($M%62`@*&ED*0H@("`@("`@("D*
M"@H@("`@("`@(%1H:7,@97AA;7!L92!D96UO;G-T<F%T97,@:&]W('1O(&UA
M;F%G92!T<F5E<PH@("`@("`@('1H870@87)E('-A=F5D(&EN(&$@1$(L(&ET
M('5S97,@82!V97)Y('-I;7!L90H@("`@("`@($1"+7-T<G5C='5R92P@;F]T
M(&YE<W1E9"!T<F5E<R`H;VLL('1H870@<W5C:W,L(&)U="!I="!C86X@8F4@
M:6UP;&5M96YT960@.BTI("D*"B`@("`@("`@:70@<F5A9',@;W5T('1H92!E
M;G1I<F4@=')E92!U<&]N(&-A;&QI;F<@=&AE(&UE=&AO9`H@("`@("`@("=S
M971U<"<L('1H96X@>6]U(&-A;B!W;W)K(&]N('1H92!T<F5E(&EN('=H:6-H
M979E<B!W87D*("`@("`@("!Y;W4@=V%N="P@:G5S="!H879E(&$@;&]O:R!A
M="!T:&4@97AA;7!L97,*("`@("`@("!T:&5R92!A<F4@9&EF9F5R96YT('=A
M>7,@=&\@86-H:65V92!T:&EN9W,L"B`@("`@("`@:2!W:6QL('1R>2!T;R!D
M96UO;G-T<F%T92`H86QL(&]F*2!T:&5M"@H@("`@*B\*"B`@("!R97%U:7)E
M7V]N8V4H)U1R964O5')E92YP:'`G*3L*"B`@("`O+R!D969I;F4@=&AE($1"
M+71A8FQE('=H97)E('1H92!D871A('-H86QL(&)E(')E860@9G)O;0H@("`@
M)&]P=&EO;G,@/2!A<G)A>2@@("`G=&%B;&4G(#T^("`G=&5S=%]T<F5E)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)V]R9&5R)R`]/B`@)VED)R`@("`O
M+R!W:&5N(')E861I;F<@=&AE(&1A=&$@9G)O;2!T:&4@9&(@<V]R="!T:&5M
M(&)Y(&ED+"!T:&ES(&ES(&]N;'D@9F]R(&5N<W5R:6YG"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@9F]R("=G971.
M97AT)R!O9B`B;7E%;&5M96YT+W-U8D5L96UE;G0B(&EN('1H:7,@97AA;7!L
M92!T;R!F:6YD(")M>45L96UE;G0O86YO=&AE<E-U8D5L96UE;G0B"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@>6]U
M(&-A;B!S:6UP;'D@<V]R="!I="!B>2`B;F%M92(@86YD(&ET('=O=6QD(&)E
M(&EN(&%L<&AA8F5T:6-A;"!O<F1E<@H@("`@("`@("`@("`@("`@("`@("D[
M"@H@("`@+R\@8V%L;&EN9R`G<V5T=7!-96UO<GDG(&UE86YS('1O(')E=')E
M:79E(&$@8VQA<W,L('=H:6-H('=O<FMS(&]N('1R965S+`H@("`@+R\@=&AA
M="!A<F4@=&5M<&]R87)I;'D@<W1O<F5D(&EN('1H92!M96UO<GDL(&EN(&%N
M(&%R<F%Y"B`@("`O+R!T:&ES(&UE86YS('1H92!E;G1I<F4@=')E92!I<R!A
M=F%I;&%B;&4@870@86QL('1I;64*("`@("\O(&-O;G-I9&5R('1H92!R97-O
M=7)C92!U<V%G92!A;F0@:70G<R!N;W0@=&\@<W5G9V5S=&5D('1O('=O<FL*
M("`@("\O(&]N(&AU9V4@=')E97,@*'5P=&\@,3`P,"!E;&5M96YT<R!I="!S
M:&]U;&0@8F4@;VLL(&1E<&5N9&EN9R!O;B!Y;W5R(&5N=FER;VYM96YT(&%N
M9"!R97%U:7)E;65N=',I"B`@("`O+R!U<VEN9R`G<V5T=7!-96UO<GDG"B`@
M("`D=')E92`](%1R964Z.G-E='5P365M;W)Y*"`@)T1"<VEM<&QE)RP@("`@
M("`@("`O+R!U<V4@=&AE('-I;7!L92!$0B!S8VAE;6$*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;7ES<6PZ+R]R;V]T0&QO8V%L:&]S="]T
M97-T)RP@("\O('1H92!$4TX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;W!T:6]N<RD[("`@("`@("`@("\O('!A<W,@=&AE(&]P=&EO;G,@
M=V4@:&%D(&%S<VEG;F5D('5P('1H97)E"@H@("`@+R\@861D(&$@;F5W(')O
M;W0@96QE;65N="!I;B!T:&4@=')E90H@("`@)'!A<F5N=$ED(#T@)'1R964M
M/F%D9"AA<G)A>2@@)VYA;64G/3XG;7E%;&5M96YT)RDI.PH*("`@("\O(&%D
M9"!A;B!E;&5M96YT('5N9&5R('1H92!N97<@96QE;65N="!W92!A9&1E9`H@
M("`@)&ED(#T@)'1R964M/F%D9"AA<G)A>2@@)VYA;64G/3XG<W5B16QE;65N
M="<I("P@)'!A<F5N=$ED("D["@H@("`@+R\@861D(&%N;W1H97(@96QE;65N
M="!U;F1E<B!T:&4@<&%R96YT(&5L96UE;G0@=V4@861D960*("`@("1I9"`]
M("1T<F5E+3YA9&0H87)R87DH("=N86UE)ST^)V%N;W1H97)3=6)%;&5M96YT
M)RD@+"`D<&%R96YT260@*3L*"B`@("`O+R!C86QL("=S971U<"<L('1O(&)U
M:6QD('1H92!I;FYE<B!A<G)A>2P@<V\@=V4@8V%N('=O<FL@;VX@=&AE('-T
M<G5C='5R92!U<VEN9R!T:&4*("`@("\O(&=I=F5N(&UE=&AO9',*("`@("1T
M<F5E+3YS971U<"@I.PH*("`@(&1U;7!!;&Q.:6-E;'DH("=D=6UP(&%L;"!A
M9G1E<B!C<F5A=&EO;B<@*3L*"B`@("`O+R!G970@=&AE('!A=&@@;V8@=&AE
M(&QA<W0@:6YS97)T960@96QE;65N=`H@("`@9'5M<$AE;'!E<B@@)R1T<F5E
M+3YG9710871H*"`G+B1I9"XG("DG("P@)V1U;7`@=&AE('!A=&@@9G)O;2`B
M;7E%;&5M96YT+V%N;W1H97)3=6)%;&5M96YT(B<@*3L*"B`@("!P<FEN="`B
M=')E92T^9V5T261">5!A=&@H)VUY16QE;65N="]S=6)%;&5M96YT)RD](BXD
M:60@/2`D=')E92T^9V5T261">5!A=&@H)VUY16QE;65N="]S=6)%;&5M96YT
M)RD["B`@("!D=6UP2&5L<&5R*"`G)'1R964M/F=E=%!A<F5N="@G+B1I9"XG
M*2<@+"`G9'5M<"!T:&4@<&%R96YT(&]F(")M>45L96UE;G0O<W5B16QE;65N
M="(G("P@=')U92`I.PH@("`@+R\@>6]U(&-A;B!A;'-O('5S93H@("`@)'1R
M964M/F1A=&%;)&ED75LG<&%R96YT)UT*"B`@("`D:60@/2`D=')E92T^9V5T
M261">5!A=&@H)VUY16QE;65N="<I.PH@("`@9'5M<$AE;'!E<B@@)R1T<F5E
M+3YG971#:&EL9"@G+B1I9"XG*2<@+"`G9'5M<"!T:&4@8VAI;&0@;V8@(FUY
M16QE;65N="(G("P@=')U92`I.PH@("`@+R\@>6]U(&-A;B!A;'-O('5S93H@
M("`@)'1R964M/F1A=&%;)&ED75LG8VAI;&0G70H*("`@("1I9"`]("1T<F5E
M+3YG971)9$)Y4&%T:"@G;7E%;&5M96YT)RD["B`@("!D=6UP2&5L<&5R*"`G
M)'1R964M/F=E=$-H:6QD<F5N*"<N)&ED+B<I)R`L("=D=6UP('1H92!C:&EL
M9')E;B!O9B`B;7E%;&5M96YT(B<@*3L*("`@("\O('EO=2!C86X@86QS;R!U
M<V4Z("`@("1T<F5E+3YD871A6R1I9%U;)V-H:6QD<F5N)UT*"B`@("`D:60@
M/2`D=')E92T^9V5T261">5!A=&@H)VUY16QE;65N="]S=6)%;&5M96YT)RD[
M"B`@("!D=6UP2&5L<&5R*"`G)'1R964M/F=E=$YE>'0H)RXD:60N)RDG("P@
M)V1U;7`@=&AE(")N97AT(B!O9B`B;7E%;&5M96YT+W-U8D5L96UE;G0B)R`L
M('1R=64@*3L*("`@("\O('EO=2!C86X@86QS;R!U<V4Z("`@("1T<F5E+3YD
M871A6R1I9%U;)VYE>'0G70H*("`@("1I9"`]("1T<F5E+3YG971)9$)Y4&%T
M:"@G;7E%;&5M96YT+V%N;W1H97)3=6)%;&5M96YT)RD["B`@("!D=6UP2&5L
M<&5R*"`G)'1R964M/F=E=%!R979I;W5S*"<N)&ED+B<I)R`L("=D=6UP('1H
M92`B<')E=FEO=7,B(&]F(")M>45L96UE;G0O86YO=&AE<E-U8D5L96UE;G0B
M)R`L('1R=64@*3L*("`@("\O('EO=2!C86X@86QS;R!U<V4Z("`@("1T<F5E
M+3YD871A6R1I9%U;)W!R979I;W5S)UT*"B`@("`D:60@/2`D=')E92T^9V5T
M261">5!A=&@H)VUY16QE;65N="<I.PH@("`@)&5L96UE;G0@/2`D=')E92T^
M9&%T85LD:61=6R=C:&EL9"==6R=N97AT)UU;)W!A<F5N="==.R`O+R!R969E
M<B!T;R!Y;W5R<V5L9B!A9V%I;BP@:6X@82!V97)Y(&-O;7!L:6-A=&5D('=A
M>2`Z+2D*("`@(&1U;7!(96QP97(H("<D96QE;65N=%M<)VED7"==)R`L("=D
M96UO(&]F('5S:6YG('1H92!I;G1E<FYA;"!A<G)A>2P@9F]R(')E9F5R96YC
M:6YG('1R964M;F]D97,L('-E92!T:&4@8V]D92<@*3L*"B`@("`D:60@/2`D
M=')E92T^9V5T261">5!A=&@H)VUY16QE;65N="<I.PH@("`@)&5L96UE;G0@
M/2`D=')E92T^9&%T85LD:61=6R=C:&EL9"==6R=N97AT)UT[("\O(')E9F5R
M('1O('1H92!S96-O;F0@8VAI;&0@;V8@)VUY16QE;65N="<*("`@(&1U;7!(
M96QP97(H("<D96QE;65N=%M<)VED7"==)R`L("=D96UO,B!O9B!U<VEN9R!T
M:&4@:6YT97)N86P@87)R87DL(&9O<B!R969E<F5N8VEN9R!T<F5E+6YO9&5S
M+"!S964@=&AE(&-O9&4G("D["@H@("`@)&ED(#T@)'1R964M/F=E=$ED0GE0
M871H*"=M>45L96UE;G0O86YO=&AE<E-U8D5L96UE;G0G*3L*("`@("1T<F5E
M+3YM;W9E*"`D:60@+"`P("D["B`@("`D=')E92T^<V5T=7`H*3L@+R\@<F5B
M=6EL9"!T:&4@<W1R=6-T=7)E(&%G86EN+"!S:6YC92!W92!H860@8VAA;F=E
M9"!I=`H@("`@9'5M<$%L;$YI8V5L>2@@)V1U;7`@86QL+"!A9G1E<B`B;7E%
M;&5M96YT+V%N;W1H97)3=6)%;&5M96YT(B!W87,@;6]V960@=6YD97(@=&AE
M(')O;W0G("D["@H@("`@)&UO=F5)9"`]("1T<F5E+3YG971)9$)Y4&%T:"@G
M;7E%;&5M96YT)RD["B`@("`D:60@/2`D=')E92T^9V5T261">5!A=&@H)V%N
M;W1H97)3=6)%;&5M96YT)RD["B`@("`D=')E92T^;6]V92@@)&UO=F5)9"`L
M("1I9"`I.PH@("`@)'1R964M/G-E='5P*"D[("\O(')E8G5I;&0@=&AE('-T
M<G5C='5R92!A9V%I;BP@<VEN8V4@=V4@:&%D(&-H86YG960@:70*("`@(&1U
M;7!!;&Q.:6-E;'DH("=D=6UP(&%L;"P@869T97(@(FUY16QE;65N="(@=V%S
M(&UO=F5D('5N9&5R('1H92`B86YO=&AE<E-U8D5L96UE;G0B)R`I.PH*("`@
M("1T<F5E+3YS971296UO=F5296-U<G-I=F5L>2AT<G5E*3L*("`@("1T<F5E
M+3YR96UO=F4H,"D["B`@("!P<FEN="`G/&9O;G0@8V]L;W(](G)E9"(^04Q,
M($5,14U%3E13($A!5D4@0D5%3B!214U/5D5$("AU;F-O;6UE;G0@=&AI<R!P
M87)T('1O(&ME97`@=&AE;2!I;B!T:&4@1$(@869T97(@<G5N;FEN9R!T:&ES
M('1E<W0@<V-R:7!T*3PO9F]N=#XG.PH*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]4<F5E+V1O
M8W,O365M;W)Y7T1";F5S=&5D+G!H<```````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34R
M,S8`,3`T,3<S-C,P,#0`,#(S-C4U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B`@("`O+PH@("`@+R\@("1)9#H@
M365M;W)Y7T1";F5S=&5D+G!H<"QV(#$N,B`R,#`S+S`Q+S,P(#$W.C0S.C0Q
M(&-A:6X@17AP("0*("`@("\O"@HO+VEN:5]S970H)VEN8VQU9&5?<&%T:"<L
M<F5A;'!A=&@H9&ER;F%M92A?7T9)3$5?7RDN)R\N+B\N+B\G*2XG.B<N<F5A
M;'!A=&@H9&ER;F%M92A?7T9)3$5?7RDN)R\N+B\N+B\N+B]I;F-L=61E<R<I
M+B<Z)RYI;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D["B\O:6YI7W-E="@G97)R
M;W)?<F5P;W)T:6YG)RQ%7T%,3"D["@H@("`@+RHJ"B`@("`J("`@=&AI<R!I
M<R!A(&AE;'!E<B!F=6YC=&EO;BP@<V\@:2!D;VYT(&AA=F4@=&\@=W)I=&4@
M<V\@;6%N>2!P<FEN=',@.BTI"B`@("`J("`@0'!A<F%M("!A<G)A>2`@("1P
M87)A("`@=&AE(')E<W5L="!R971U<FYE9"!B>2!S;VUE(&UE=&AO9"P@=&AA
M="!W:6QL(&)E(&1U;7!E9`H@("`@*B`@($!P87)A;2`@<W1R:6YG("`D<W1R
M:6YG('1H92!E>'!L86EN:6YG('-T<FEN9PH@("`@*B\*("`@(&9U;F-T:6]N
M(&1U;7!(96QP97(H("1P87)A("P@)'-T<FEN9STG)R`L("1A9&1!<G)A>3UF
M86QS92`I"B`@("!["B`@("`@("`@9VQO8F%L("1T<F5E+"1E;&5M96YT.PH*
M("`@("`@("!I9B@@)&%D9$%R<F%Y("D*("`@("`@("`@("`@979A;"@@(EPD
M<F5S/6%R<F%Y*"(N)'!A<F$N)RD[)R`I.PH@("`@("`@(&5L<V4*("`@("`@
M("`@("`@979A;"@@(EPD<F5S/2(N)'!A<F$N)SLG("D["@H@("`@("`@('!R
M:6YT("<\8CXG+B1P87)A+B<@/"]B/CQI/CQU/CQF;VYT(&-O;&]R/2(C,#`X
M,#`P(CXG+B1S=')I;F<N)SPO9F]N=#X\+W4^/"]I/CQB<CXG.PH@("`@("`@
M("\O('1H:7,@;65T:&]D(&1U;7!S('1O('1H92!S8W)E96XL('-I;F-E('!R
M:6YT7W(@;W(@=F%R7V1U;7`@9&]N=`H@("`@("`@("\O('=O<FL@=&]O(&=O
M;V0@:&5R92P@8F5C875S92!T:&4@:6YN97(@87)R87D@:7,@<F5C=7)S:79E
M"B`@("`@("`@+R\@=V5L;"P@:70@;&]O:W,@=6=L>2!B=70@;VYE(&-A;B!S
M964@=VAA="!I<R!M96%N="`Z+2D*("`@("`@("`D=')E92T^=F%R1'5M<"@D
M<F5S*3L*("`@("`@("!P<FEN="`G/&)R/B<["@H@("`@?0H*("`@("\J*@H@
M("`@*B`@(&1U;7!S('1H92!E;G1I<F4@<W1R=6-T=7)E(&YI8V5L>0H@("`@
M*B`@($!P87)A;2`@<W1R:6YG("`D<W1R:6YG('1H92!E>'!L86EN:6YG('-T
M<FEN9PH@("`@*B\*("`@(&9U;F-T:6]N(&1U;7!!;&Q.:6-E;'DH("1S=')I
M;F<])R<@*0H@("`@>PH@("`@("`@(&=L;V)A;"`D=')E93L*"B`@("`@("`@
M<')I;G0@)SQI/CQU/CQF;VYT(&-O;&]R/2(C,#`X,#`P(CXG+B1S=')I;F<N
M)SPO9F]N=#X\+W4^/"]I/CQB<CXG.PH@("`@("`@("1A;&P@/2`D=')E92T^
M9V5T3F]D92@I.R`@("\O(&=E="!T:&4@96YT:7)E('-T<G5C='5R92!S;W)T
M960@87,@=&AE('1R964@:7,L('-O('=E(&-A;B!S:6UP;'D@9F]R96%C:"!T
M:')O=6=H(&ET(&%N9"!S:&]W(&ET"B`@("`@("`@9F]R96%C:"@@)&%L;"!A
M<R`D845L96UE;G0@*0H@("`@("`@('L*("`@("`@("`@("`@9F]R*"`D:3TP
M(#L@)&D\)&%%;&5M96YT6R=L979E;"==(#L@)&DK*RD*("`@("`@("`@("`@
M("`@('!R:6YT("<F;F)S<#L@)FYB<W`[("<["B`@("`@("`@("`@('!R:6YT
M("<\9F]N="!C;VQO<CTB<F5D(CXG+B1A16QE;65N=%LG;F%M92==+B<\+V9O
M;G0^(#T]/29G=#L@)SL*("`@("`@("`@("`@)'1R964M/G9A<D1U;7`H87)R
M87DH)&%%;&5M96YT*2D["B`@("`@("`@?0H@("`@("`@('!R:6YT("<\8G(^
M)SL*"B`@("!]"@H*("`@("\J"@H@("`@("`@('5S92!T:&ES('1O(&)U:6QD
M('1H92!D8B!T86)L90H*("`@("`@("!#4D5!5$4@5$%"3$4@=&5S=%]T<F5E
M("@*("`@("`@("`@("`@:60@:6YT*#$Q*2!.3U0@3E5,3"!A=71O7VEN8W)E
M;65N="P*("`@("`@("`@("`@<&%R96YT260@:6YT*#$Q*2!.3U0@3E5,3"!D
M969A=6QT("<P)RP*("`@("`@("`@("`@;F%M92!V87)C:&%R*#(U-2D@3D]4
M($Y53$P@9&5F875L="`G)RP*("`@("`@("`@("`@4%))34%262!+15D@("AI
M9"D*("`@("`@("`I"@H*("`@("`@("!4:&ES(&5X86UP;&4@9&5M;VYS=')A
M=&5S(&AO=R!T;R!M86YA9V4@=')E97,*("`@("`@("!T:&%T(&%R92!S879E
M9"!I;B!A($1"+"!I="!U<V5S(&$@=F5R>2!S:6UP;&4*("`@("`@("!$0BUS
M=')U8W1U<F4L(&YO="!N97-T960@=')E97,@*&]K+"!T:&%T('-U8VMS+"!B
M=70@:70@8V%N(&)E(&EM<&QE;65N=&5D(#HM*2`I"@H@("`@("`@(&ET(')E
M861S(&]U="!T:&4@96YT:7)E('1R964@=7!O;B!C86QL:6YG('1H92!M971H
M;V0*("`@("`@("`G<V5T=7`G+"!T:&5N('EO=2!C86X@=V]R:R!O;B!T:&4@
M=')E92!I;B!W:&EC:&5V97(@=V%Y"B`@("`@("`@>6]U('=A;G0L(&IU<W0@
M:&%V92!A(&QO;VL@870@=&AE(&5X86UP;&5S"B`@("`@("`@=&AE<F4@87)E
M(&1I9F9E<F5N="!W87ES('1O(&%C:&EE=F4@=&AI;F=S+`H@("`@("`@(&D@
M=VEL;"!T<GD@=&\@9&5M;VYS=')A=&4@*&%L;"!O9BD@=&AE;0H*("`@("HO
M"@H@("`@<F5Q=6ER95]O;F-E*"=4<F5E+U1R964N<&AP)RD["@H@("`@+R\@
M9&5F:6YE('1H92!$0BUT86)L92!W:&5R92!T:&4@9&%T82!S:&%L;"!B92!R
M96%D(&9R;VT*("`@("1O<'1I;VYS(#T@87)R87DH("`@)W1A8FQE)R`]/B`@
M)TUE;6]R>4YE<W1E9%1R964G"B`@("`@("`@("`@("`@("`@("`@("`@("PG
M=VAE<F5!9&1/;B<]/B)C;VUM96YT/2<G(@H@("`@("`@("`@("`@("`@("`@
M("D["@H@("`@+R\@8V%L;&EN9R`G<V5T=7!-96UO<GDG(&UE86YS('1O(')E
M=')E:79E(&$@8VQA<W,L('=H:6-H('=O<FMS(&]N('1R965S+`H@("`@+R\@
M=&AA="!A<F4@=&5M<&]R87)I;'D@<W1O<F5D(&EN('1H92!M96UO<GDL(&EN
M(&%N(&%R<F%Y"B`@("`O+R!T:&ES(&UE86YS('1H92!E;G1I<F4@=')E92!I
M<R!A=F%I;&%B;&4@870@86QL('1I;64@(2$A"B`@("`O+R!C;VYS:61E<B!T
M:&4@<F5S;W5R8V4@=7-A9V4@86YD(&ET)W,@;F]T('1O('-U9V=E<W1E9"!T
M;R!W;W)K"B`@("`O+R!O;B!H=6=E('1R965S("AU<'1O(#$P,#`@96QE;65N
M=',@:70@<VAO=6QD(&)E(&]K+"!D97!E;F1I;F<@;VX@>6]U<B!E;G9I<F]N
M;65N="!A;F0@<F5Q=6ER96UE;G1S*0H*("`@("\O('5S:6YG("=S971U<$UE
M;6]R>2<*("`@("1T<F5E(#T@5')E93HZ<V5T=7!-96UO<GDH("`G1$)N97-T
M960G+"`@("`@("`@("\O('5S92!T:&4@;F5S=&5D($1"('-C:&5M82P@=VAI
M8V@@:7,@86-T=6%L;'D@:6UP;&5M96YT960@:6X@1'EN86UI8R]$0FYE<W1E
M9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@=&AE(&-L87-S($UE;6]R>2]$0FYE<W1E9"!I<R!O;FQY
M(&MI;F0@;V8@82!W<F%P<&5R('1O(')E860@=&AE(&5N=&ER92!T<F5E"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!A;F0@;&5T('4@=V]R:R!O;B!I="P@=VAI8V@@=&\@=7-E('-H
M;W5L9"!B92!C:&]S96X@;VX@8V%S92!B>2!C87-E(&)A<VES"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VUY<W%L.B\O<F]O=$!L;V-A;&AO
M<W0O=&5S="<L("`O+R!T:&4@1%-."B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&]P=&EO;G,I.R`@("`@("`@("`O+R!P87-S('1H92!O<'1I
M;VYS('=E(&AA9"!A<W-I9VYE9"!U<"!T:&5R90H*("`@("\O(&%D9"!A(&YE
M=R!R;V]T(&5L96UE;G0@:6X@=&AE('1R964*("`@("1R;V]T260@/2`D=')E
M92T^861D*&%R<F%Y*"`G;F%M92<]/B=M>45L96UE;G0G*2D["@H@("`@+R\@
M861D(&%N(&5L96UE;G0@=6YD97(@=&AE(&YE=R!E;&5M96YT('=E(&%D9&5D
M"B`@("`D:60@/2`D=')E92T^861D*"!A<G)A>2@@)VYA;64G/3XG<W5B16QE
M;65N="<I("P@)')O;W1)9"`I.PH*("`@("\O(&%D9"!A;F]T:&5R(&5L96UE
M;G0@=6YD97(@=&AE('!A<F5N="!E;&5M96YT('=E(&%D9&5D"B`@("`D:60@
M/2`D=')E92T^861D*"!A<G)A>2@@)VYA;64G/3XG86YO=&AE<E-U8D5L96UE
M;G0G*2`L("1R;V]T260@+"`D:60@*3L*"B`@("`O+R!C86QL("=S971U<"<L
M('1O(&)U:6QD('1H92!I;FYE<B!A<G)A>2P@<V\@=V4@8V%N('=O<FL@;VX@
M=&AE('-T<G5C='5R92!U<VEN9R!T:&4*("`@("\O(&=I=F5N(&UE=&AO9',*
M("`@("1T<F5E+3YS971U<"@I.PH*("`@(&1U;7!!;&Q.:6-E;'DH("=D=6UP
M(&%L;"!A9G1E<B!C<F5A=&EO;B<@*3L*"B`@("`O+R!G970@=&AE('!A=&@@
M;V8@=&AE(&QA<W0@:6YS97)T960@96QE;65N=`H@("`@9'5M<$AE;'!E<B@@
M)R1T<F5E+3YG9710871H*"`G+B1I9"XG("DG("P@)V1U;7`@=&AE('!A=&@@
M9G)O;2`B;7E%;&5M96YT+V%N;W1H97)3=6)%;&5M96YT(B<@*3L*"B`@("`D
M:60@/2`D=')E92T^9V5T261">5!A=&@H)VUY16QE;65N="]S=6)%;&5M96YT
M)RD["B`@("!D=6UP2&5L<&5R*"`G)'1R964M/F=E=%!A<F5N="@G+B1I9"XG
M*2<@+"`G9'5M<"!T:&4@<&%R96YT(&]F(")M>45L96UE;G0O<W5B16QE;65N
M="(G("P@=')U92`I.PH@("`@+R\@>6]U(&-A;B!A;'-O('5S93H@("`@)'1R
M964M/F1A=&%;)&ED75LG<&%R96YT)UT*"B`@("`D:60@/2`D=')E92T^9V5T
M261">5!A=&@H)VUY16QE;65N="<I.PH@("`@9'5M<$AE;'!E<B@@)R1T<F5E
M+3YG971#:&EL9"@G+B1I9"XG*2<@+"`G9'5M<"!T:&4@8VAI;&0@;V8@(FUY
M16QE;65N="(G("P@=')U92`I.PH@("`@+R\@>6]U(&-A;B!A;'-O('5S93H@
M("`@)'1R964M/F1A=&%;)&ED75LG8VAI;&0G70H*("`@("1I9"`]("1T<F5E
M+3YG971)9$)Y4&%T:"@G;7E%;&5M96YT)RD["B`@("!D=6UP2&5L<&5R*"`G
M)'1R964M/F=E=$-H:6QD<F5N*"<N)&ED+B<I)R`L("=D=6UP('1H92!C:&EL
M9')E;B!O9B`B;7E%;&5M96YT(B<@*3L*("`@("\O('EO=2!C86X@86QS;R!U
M<V4Z("`@("1T<F5E+3YD871A6R1I9%U;)V-H:6QD<F5N)UT*"B`@("`D:60@
M/2`D=')E92T^9V5T261">5!A=&@H)VUY16QE;65N="]S=6)%;&5M96YT)RD[
M"B`@("!D=6UP2&5L<&5R*"`G)'1R964M/F=E=$YE>'0H)RXD:60N)RDG("P@
M)V1U;7`@=&AE(")N97AT(B!O9B`B;7E%;&5M96YT+W-U8D5L96UE;G0B)R`L
M('1R=64@*3L*("`@("\O('EO=2!C86X@86QS;R!U<V4Z("`@("1T<F5E+3YD
M871A6R1I9%U;)VYE>'0G70H*("`@("1I9"`]("1T<F5E+3YG971)9$)Y4&%T
M:"@G;7E%;&5M96YT+V%N;W1H97)3=6)%;&5M96YT)RD["B`@("!D=6UP2&5L
M<&5R*"`G)'1R964M/F=E=%!R979I;W5S*"<N)&ED+B<I)R`L("=D=6UP('1H
M92`B<')E=FEO=7,B(&]F(")M>45L96UE;G0O86YO=&AE<E-U8D5L96UE;G0B
M)R`L('1R=64@*3L*("`@("\O('EO=2!C86X@86QS;R!U<V4Z("`@("1T<F5E
M+3YD871A6R1I9%U;)W!R979I;W5S)UT*"B`@("`D:60@/2`D=')E92T^9V5T
M261">5!A=&@H)VUY16QE;65N="<I.PH@("`@)&5L96UE;G0@/2`D=')E92T^
M9&%T85LD:61=6R=C:&EL9"==6R=N97AT)UU;)W!A<F5N="==.R`O+R!R969E
M<B!T;R!Y;W5R<V5L9B!A9V%I;BP@:6X@82!V97)Y(&-O;7!L:6-A=&5D('=A
M>2`Z+2D*("`@(&1U;7!(96QP97(H("<D96QE;65N=%M<)VED7"==)R`L("=D
M96UO(&]F('5S:6YG('1H92!I;G1E<FYA;"!A<G)A>2P@9F]R(')E9F5R96YC
M:6YG('1R964M;F]D97,L('-E92!T:&4@8V]D92<@*3L*"B`@("`D:60@/2`D
M=')E92T^9V5T261">5!A=&@H)VUY16QE;65N="<I.PH@("`@)&5L96UE;G0@
M/2`D=')E92T^9&%T85LD:61=6R=C:&EL9"==6R=N97AT)UT[("\O(')E9F5R
M('1O('1H92!S96-O;F0@8VAI;&0@;V8@)VUY16QE;65N="<*("`@(&1U;7!(
M96QP97(H("<D96QE;65N=%M<)VED7"==)R`L("=D96UO,B!O9B!U<VEN9R!T
M:&4@:6YT97)N86P@87)R87DL(&9O<B!R969E<F5N8VEN9R!T<F5E+6YO9&5S
M+"!S964@=&AE(&-O9&4G("D["B\J"B`@("`D:60@/2`D=')E92T^9V5T261"
M>5!A=&@H)VUY16QE;65N="]A;F]T:&5R4W5B16QE;65N="<I.PH@("`@)'1R
M964M/FUO=F4H("1I9"`L(#`@*3L*("`@("1T<F5E+3YS971U<"@I.R`O+R!R
M96)U:6QD('1H92!S=')U8W1U<F4@86=A:6XL('-I;F-E('=E(&AA9"!C:&%N
M9V5D(&ET"B`@("!D=6UP06QL3FEC96QY*"`G9'5M<"!A;&PL(&%F=&5R(")M
M>45L96UE;G0O86YO=&AE<E-U8D5L96UE;G0B('=A<R!M;W9E9"!U;F1E<B!T
M:&4@<F]O="<@*3L*"B`@("`D;6]V94ED(#T@)'1R964M/F=E=$ED0GE0871H
M*"=M>45L96UE;G0G*3L*("`@("1I9"`]("1T<F5E+3YG971)9$)Y4&%T:"@G
M86YO=&AE<E-U8D5L96UE;G0G*3L*("`@("1T<F5E+3YM;W9E*"`D;6]V94ED
M("P@)&ED("D["B`@("`D=')E92T^<V5T=7`H*3L@+R\@<F5B=6EL9"!T:&4@
M<W1R=6-T=7)E(&%G86EN+"!S:6YC92!W92!H860@8VAA;F=E9"!I=`H@("`@
M9'5M<$%L;$YI8V5L>2@@)V1U;7`@86QL+"!A9G1E<B`B;7E%;&5M96YT(B!W
M87,@;6]V960@=6YD97(@=&AE(")A;F]T:&5R4W5B16QE;65N="(G("D["BHO
M"B`@("`D=')E92T^<V5T4F5M;W9E4F5C=7)S:79E;'DH=')U92D["B`@("`D
M=')E92T^<F5M;W9E*"`D<F]O=$ED("D["B`@("!P<FEN="`G/&9O;G0@8V]L
M;W(](G)E9"(^04Q,($5,14U%3E13($A!5D4@0D5%3B!214U/5D5$("AU;F-O
M;6UE;G0@=&AI<R!P87)T('1O(&ME97`@=&AE;2!I;B!T:&4@1$(@869T97(@
M<G5N;FEN9R!T:&ES('1E<W0@<V-R:7!T*3PO9F]N=#XG.PH*"G!R:6YT("<\
M8G(^/&)R/B<[<')I;G1?<B@D<75E<GE?:&ES=&]R>2D["@H_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]4<F5E+V1O8W,O1'EN86UI8U]$0FYE
M<W1E9"YP:'``````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,R-30`,3`T,3<S-C,P,#0`
M,#(S-S8V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B`@("`O+PH@("`@+R\@("1)9#H@1'EN86UI8U]$0FYE<W1E
M9"YP:'`L=B`Q+C(@,C`P,R\P,2\S,"`Q-SHT,SHT,2!C86EN($5X<"`D"B`@
M("`O+PH*+R]I;FE?<V5T*"=I;F-L=61E7W!A=&@G+')E86QP871H*&1I<FYA
M;64H7U]&24Q%7U\I+B<O+BXO+BXO)RDN)SHG+G)E86QP871H*&1I<FYA;64H
M7U]&24Q%7U\I+B<O+BXO+BXO+BXO:6YC;'5D97,G*2XG.B<N:6YI7V=E="@G
M:6YC;'5D95]P871H)RDI.PHO+VEN:5]S970H)V5R<F]R7W)E<&]R=&EN9R<L
M15]!3$PI.PH*("`@(')E<75I<F5?;VYC92@G5')E92]4<F5E+G!H<"<I.PH*
M(R`@("`D=')E92`](%1R964Z.G-E='5P1'EN86UI8R@@)T1";F5S=&5D)R`L
M("=M>7-Q;#HO+W)O;W1`;&]C86QH;W-T+W1E<W0G("P@87)R87DH)W1A8FQE
M)ST^)VYE<W1E9%1R964G*2`I.PHC("`@3U(*("`@("1T<F5E(#T@5')E93HZ
M<V5T=7`H("=$>6YA;6EC7T1";F5S=&5D)R`L("=M>7-Q;#HO+W)O;W1`;&]C
M86QH;W-T+W1E<W0G("P@87)R87DH)W1A8FQE)ST^)VYE<W1E9%1R964G*2`I
M.PH*("`@("1S:&]W6UT@/2`G)'1R964M/F=E=%)O;W0H*2<["B`@("`D<VAO
M=UM=(#T@)R1T<F5E+3YG971%;&5M96YT*"`Q("DG.PH@("`@)'-H;W=;72`]
M("<D=')E92T^9V5T0VAI;&0H(#$@*2<["B`@("`D<VAO=UM=(#T@)R1T<F5E
M+3YG9710871H*"`W("DG.PH@("`@)'-H;W=;72`]("<D=')E92T^9V5T4&%T
M:"@@,B`I)SL*("`@("1S:&]W6UT@/2`G)'1R964M/F%D9"@@87)R87DH(FYA
M;64B/3XB8S`B*2`L(#4@*2<["B`@("`D<VAO=UM=(#T@)R1T<F5E+3YR96UO
M=F4H("1R97,@*2<[("`O+R!R96UO=F4@=&AE(&QA<W0@96QE;65N="!T:&%T
M('=A<R!A9&1E9"!I;B!T:&4@;&EN92!B969O<F4@.BTI"B`@("`D<VAO=UM=
M(#T@)R1T<F5E+3YG9712:6=H="@@-2`I)SL*("`@("1S:&]W6UT@/2`G)'1R
M964M/F=E=$QE9G0H(#4@*2<["B`@("`D<VAO=UM=(#T@)R1T<F5E+3YG971#
M:&EL9')E;B@@,2`I)SL*("`@("1S:&]W6UT@/2`G)'1R964M/F=E=%!A<F5N
M="@@,B`I)SL*("`@("1S:&]W6UT@/2`G)'1R964M/F=E=$YE>'0H(#(@*2<[
M"B`@("`D<VAO=UM=(#T@)R1T<F5E+3YG971.97AT*"`T("DG.PH@("`@)'-H
M;W=;72`]("<D=')E92T^9V5T3F5X="@@."`I)SL*("`@("1S:&]W6UT@/2`G
M)'1R964M/F=E=%!R979I;W5S*"`R("DG.PH@("`@)'-H;W=;72`]("<D=')E
M92T^9V5T4')E=FEO=7,H(#0@*2<["B`@("`D<VAO=UM=(#T@)R1T<F5E+3YG
M9710<F5V:6]U<R@@."`I)SL*("`@("1S:&]W6UT@/2`G)'1R964M/F=E=%!R
M979I;W5S260H(#@@*2<["@H@("`@)'-H;W=;72`]("<D=')E92T^;6]V92@@
M-"PS("DG.PH*"B`@("!F;W)E86-H*"`D<VAO=R!A<R`D85)E<R`I"B`@("![
M"B`@("`@("`@<')I;G0H(CQB/B1A4F5S/"]B/CQB<CXB*3L*("`@("`@("!E
M=F%L*")<)')E<STB+B1A4F5S+B<[)RD["B`@("`@("`@:68H("1R97,@/3T@
M9F%L<V4@*0H@("`@("`@("`@("!P<FEN="`B9F%L<V4B.PH@("`@("`@(&5L
M<V4*("`@("`@("`@("`@<')I;G1?<B@D<F5S*3L*"B`@("`@("`@<')I;G0H
M)SQB<CX\8G(^)RD["B`@("!]"@H*/SX*"CQA(&AR968](FAT='`Z+R]R97-E
M87)C:"YC86QA8V%D96UY+F]R9R]T868O<')O8V5E9&EN9W,O8F%L;&5W+W-L
M9#`R.2YH=&TB/G1H92!T<F5E('-T<G5C='5R92!V:7-U86QI<V%T:6]N/"]A
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O5')E92]D;V-S+T1Y;F%M:6-?1$)N97-T960N
M<W%L`````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S,V`#$P-#$W,S8S,#`T`#`R-#`P
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M('!H<$UY061M:6X@37E344PM1'5M<`HC('9E<G-I;VX@,BXS+C`*(R!H='1P
M.B\O<&AP=VEZ87)D+FYE="]P:'!->4%D;6EN+PHC(&AT='`Z+R]W=W<N<&AP
M;7EA9&UI;BYN970O("AD;W=N;&]A9"!P86=E*0HC"B,@2&]S=#H@;&]C86QH
M;W-T"B,@1V5N97)A=&EO;B!4:6UE.B!*86X@,S`L(#(P,#,@870@,#8Z-#$@
M4$T*(R!397)V97(@=F5R<VEO;CH@,RXR,RXT.`HC(%!(4"!697)S:6]N.B`T
M+C,N,`HC($1A=&%B87-E(#H@8'1E<W1@"B,@+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"B,*(R!4
M86)L92!S=')U8W1U<F4@9F]R('1A8FQE(&!N97-T9614<F5E8`HC"@I#4D5!
M5$4@5$%"3$4@;F5S=&5D5')E92`H"B`@:60@:6YT*#$Q*2!.3U0@3E5,3"!D
M969A=6QT("<P)RP*("!N86UE('9A<F-H87(H,C4U*2!.3U0@3E5,3"!D969A
M=6QT("<G+`H@(&P@:6YT*#$Q*2!.3U0@3E5,3"!D969A=6QT("<P)RP*("!R
M(&EN="@Q,2D@3D]4($Y53$P@9&5F875L="`G,"<L"B`@<&%R96YT(&EN="@Q
M,2D@3D]4($Y53$P@9&5F875L="`G,"<L"B`@8V]M;65N="!V87)C:&%R*#(U
M-2D@3D]4($Y53$P@9&5F875L="`G)RP*("!04DE-05)9($M%62`@*&ED*0HI
M(%194$4]37E)4T%-.PH*(PHC($1U;7!I;F<@9&%T82!F;W(@=&%B;&4@8&YE
M<W1E9%1R965@"B,*"DE.4T525"!)3E1/(&YE<W1E9%1R964@5D%,5453("@Q
M+"`G4F]O="<L(#$L(#(T+"`P+"`G)RD["DE.4T525"!)3E1/(&YE<W1E9%1R
M964@5D%,5453("@R+"`G03$G+"`R+"`Q,2P@,2P@)R<I.PI)3E-%4E0@24Y4
M3R!N97-T9614<F5E(%9!3%5%4R`H,RP@)T$R)RP@,3(L(#(S+"`Q+"`G)RD[
M"DE.4T525"!)3E1/(&YE<W1E9%1R964@5D%,5453("@T+"`G03,G+"`Q,RP@
M,38L(#,L("<G*3L*24Y315)4($E.5$\@;F5S=&5D5')E92!604Q515,@*#4L
M("=",2<L(#,L(#$P+"`R+"`G)RD["DE.4T525"!)3E1/(&YE<W1E9%1R964@
M5D%,5453("@V+"`G0C(G+"`Q-RP@,3@L(#,L("<G*3L*24Y315)4($E.5$\@
M;F5S=&5D5')E92!604Q515,@*#<L("=",R<L(#$Y+"`R,BP@,RP@)R<I.PI)
M3E-%4E0@24Y43R!N97-T9614<F5E(%9!3%5%4R`H."P@)T,Q)RP@,C`L(#(Q
M+"`W+"`G)RD["DE.4T525"!)3E1/(&YE<W1E9%1R964@5D%,5453("@Y+"`G
M0C0G+"`Q-"P@,34L(#0L("<G*3L*(R`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*(PHC(%1A8FQE
M('-T<G5C='5R92!F;W(@=&%B;&4@8&YE<W1E9%1R965?<V5Q8`HC"@I#4D5!
M5$4@5$%"3$4@;F5S=&5D5')E95]S97$@*`H@(&ED(&EN="@Q,"D@=6YS:6=N
M960@3D]4($Y53$P@875T;U]I;F-R96UE;G0L"B`@4%))34%262!+15D@("AI
M9"D**2!465!%/4UY25-!33L*"B,*(R!$=6UP:6YG(&1A=&$@9F]R('1A8FQE
M(&!N97-T9614<F5E7W-E<6`*(PH*24Y315)4($E.5$\@;F5S=&5D5')E95]S
M97$@5D%,5453("@S*3L*"@``````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R](5%10
M7U)E<75E<W0O````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C,P,#0`,#(P-38P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+TA45%!?4F5Q=65S="]D;V-S+P``````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-``P,C$U,3``(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O2%144%]297%U97-T+V1O
M8W,O9&]W;FQO860M<')O9W)E<W,N<&AP````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-C0T`#$P-#$W
M,S8S,#`T`#`R-3<P,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@06X@97AA;7!L92!O9B!,:7-T96YE
M<B!U<V%G92!W:71H($A45%!?4F5Q=65S="X@5&AI<R!D;W=N;&]A9',@86YD
M('-A=F5S(`H@*B!T:&4@9FEL92!D:7-P;&%Y:6YG('1H92!P<F]G<F5S<R!B
M87(@:6X@=&AE('!R;V-E<W,N"B`J(`H@*B!.;W1E('1W;R!T:&EN9W,Z"B`J
M(#$I(%1H92!F:6QE('-H;W5L9"!B92!R=6X@:6X@8V]N<V]L92P@;F]T(&EN
M(&)R;W=S97(["B`J(#(I(%EO=2!S:&]U;&0@='5R;B!O=71P=70@8G5F9F5R
M:6YG($]&1B!F;W(@=&AI<R!T;R!W;W)K('!R;W!E<FQY+@H@*B`*("H@)$ED
M.B!D;W=N;&]A9"UP<F]G<F5S<RYP:'`L=B`Q+C$@,C`P,R\Q,"\R-R`Q,#HT
M.#HT.2!A=F(@17AP("0*("HO"@IR97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S
M="YP:'`G.PIR97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S="],:7-T96YE<BYP
M:'`G.PIR97%U:7)E7V]N8V4@)T-O;G-O;&4O4')O9W)E<W-"87(N<&AP)SL*
M"E!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]$244I.PH*<V5T
M7W1I;65?;&EM:70H,"D["@IC;&%S<R!(5%107U)E<75E<W1?1&]W;FQO861,
M:7-T96YE<B!E>'1E;F1S($A45%!?4F5Q=65S=%],:7-T96YE<@I["B`@("\J
M*@H@("`@*B!(86YD;&4@9F]R('1H92!T87)G970@9FEL90H@("`@*B!`=F%R
M(&EN=`H@("`@*B\*("`@('9A<B`D7V9P.PH*("`@+RHJ"B`@("`J($-O;G-O
M;&5?4')O9W)E<W-"87(@:6YT86YC92!U<V5D('1O(&1I<W!L87D@=&AE(&EN
M9&EC871O<@H@("`@*B!`=F%R(&]B:F5C=`H@("`@*B\*("`@('9A<B`D7V)A
M<CL*"B`@("\J*@H@("`@*B!.86UE(&]F('1H92!T87)G970@9FEL90H@("`@
M*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7W1A<F=E=#L*"B`@("\J
M*@H@("`@*B!.=6UB97(@;V8@8GET97,@<F5C96EV960@<V\@9F%R"B`@("`J
M($!V87(@:6YT"B`@("`J+PH@("`@=F%R("1?<VEZ92`](#`["@H@("`@9G5N
M8W1I;VX@2%144%]297%U97-T7T1O=VYL;V%D3&ES=&5N97(H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y(5%107U)E<75E<W1?3&ES=&5N97(H*3L*("`@('T*
M"B`@("\J*@H@("`@*B!/<&5N<R!T:&4@=&%R9V5T(&9I;&4*("`@("H@0'!A
M<F%M('-T<FEN9R!487)G970@9FEL92!N86UE"B`@("`J($!T:')O=W,@4$5!
M4E]%<G)O<@H@("`@*B\*("`@(&9U;F-T:6]N('-E=%1A<F=E="@D=&%R9V5T
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&%R9V5T(#T@)'1A<F=E=#L*("`@
M("`@("`D=&AI<RT^7V9P(#T@0&9O<&5N*"1T87)G970L("=W8B<I.PH@("`@
M("`@(&EF("@A)'1H:7,M/E]F<"D@>PH@("`@("`@("`@("!014%2.CIR86ES
M945R<F]R*")#86YN;W0@;W!E;B`G>R1T87)G971])R(I.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!U<&1A=&4H)B1S=6)J96-T+"`D979E;G0L
M("1D871A(#T@;G5L;"D*("`@('L*("`@("`@("!S=VET8V@@*"1E=F5N="D@
M>PH@("`@("`@("`@("!C87-E("=S96YT4F5Q=65S="<Z(`H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]T87)G970@/2!B87-E;F%M92@D<W5B:F5C="T^7W5R
M;"T^<&%T:"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)V=O=$AE861E<G,G.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D871A6R=C;VYT96YT+61I<W!O<VET:6]N)UTI("8F"B`@("`@("`@("`@
M("`@("`@("`@<')E9U]M871C:"@G+V9I;&5N86UE/2(H6UXB72LI(B\G+"`D
M9&%T85LG8V]N=&5N="UD:7-P;W-I=&EO;B==+"`D;6%T8VAE<RDI('L*"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%1A<F=E="AB87-E;F%M92@D
M;6%T8VAE<ULQ72DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T5&%R9V5T*"1T:&ES+3Y?=&%R9V5T
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8F%R(#TF(&YE=R!#;VYS;VQE7U!R;V=R97-S0F%R*`H@("`@("`@("`@("`@
M("`@("`@("<J("<@+B`D=&AI<RT^7W1A<F=E="`N("<@)69R86-T:6]N)2!+
M0B!;)6)A<B5=("5P97)C96YT)2<L("<]/B<L("<M)RP@"B`@("`@("`@("`@
M("`@("`@("`@-SDL("AI<W-E="@D9&%T85LG8V]N=&5N="UL96YG=&@G72D_
M(')O=6YD*"1D871A6R=C;VYT96YT+6QE;F=T:"==("\@,3`R-"DZ(#$P,"D*
M("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-I
M>F4@/2`P.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=T:6-K)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?<VEZ92`K/2!S
M=')L96XH)&1A=&$I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B87(M/G5P
M9&%T92AR;W5N9"@D=&AI<RT^7W-I>F4@+R`Q,#(T*2D["B`@("`@("`@("`@
M("`@("!F=W)I=&4H)'1H:7,M/E]F<"P@)&1A=&$I.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=G;W1";V1Y)SH*("`@("`@
M("`@("`@("`@(&9C;&]S92@D=&AI<RT^7V9P*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M(%!%05(Z.G)A:7-E17)R;W(H(E5N:&%N9&QE9"!E=F5N="`G>R1E=F5N='TG
M(BD["B`@("`@("`@?2`O+R!S=VET8V@*("`@('T*?0H*+R\@5')Y('5S:6YG
M(&%N>2!O=&AE<B!P86-K86=E(&EF('EO=2!L:6ME+"!B=70@8VAO;W-E('1H
M92!B:6=G97(@;VYE<PHO+R!T;R!B92!A8FQE('1O('-E92!T:&4@<')O9W)E
M<W,@8F%R"B1U<FP@/2`G:'1T<#HO+W!E87(N<&AP+FYE="]G970O2%1-3%]1
M=6EC:T9O<FTM<W1A8FQE)SL*"B1R97$@/28@;F5W($A45%!?4F5Q=65S="@D
M=7)L*3L*"B1D;W=N;&]A9"`])B!N97<@2%144%]297%U97-T7T1O=VYL;V%D
M3&ES=&5N97(H*3L*)')E<2T^871T86-H*"1D;W=N;&]A9"D["B1R97$M/G-E
M;F1297%U97-T*&9A;'-E*3L*/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R](5%107U)E<75E<W0O9&]C<R]E>&%M<&QE+G!H<```
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#4V,#0`,3`T,3<S-C,P,#0`,#(S-C4V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#(P,#(L(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!2
M961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O
M<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@
M87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N
M9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&\@4F5D:7-T
M<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V
M92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@
M("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M
M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@
M;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO
M=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U;65N=&%T:6]N
M(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES
M=')I8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M
M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`HO
M+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET
M:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O('P@("!P97)M:7-S
M:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/
M4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\"B\O('P@(D%3
M($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)5$5$(%1/+"!42$4@
M24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE4
M3D534R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#
M3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\"B\O
M('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@?"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4
M($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%
M+"!\"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)2
M55!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P*+R\@?"!42$5/
M4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@
M3$E!0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@
M5$A%(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)
M4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR
M:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*"B\J*@HJ(%1H
M:7,@=VEL;"!G<F%B(&$@=V5B<&%G92!A;F0@9&ES<&QA>2!I=`HJ+PH):6YC
M;'5D92@G2%144"]297%U97-T+G!H<"<I.PH*"21R97$@/2`F;F5W($A45%!?
M4F5Q=65S="@G:'1T<#HO+W=W=RYP:'`N;F5T)RD["@DD<F5Q+3YS971-971H
M;V0H2%144%]215%515-47TU%5$A/1%]03U-4*3L*"21R97$M/F%D9%!O<W1$
M871A*"=&;V\G+"`G8F%R)RD["@DD<F5Q+3YS96YD4F5Q=65S="@I.PH))')E
M<W!O;G-E,2`]("1R97$M/F=E=%)E<W!O;G-E0F]D>2@I.PH)"@DD<F5Q+3YS
M971-971H;V0H2%144%]215%515-47TU%5$A/1%]'150I.PH))')E<2T^<V5T
M55),*"=H='1P.B\O<&5A<BYP:'`N;F5T)RD["@DD<F5Q+3YC;&5A<E!O<W1$
M871A*"D["@DD<F5Q+3YS96YD4F5Q=65S="@I.PH*"21R97-P;VYS93(@/2`D
M<F5Q+3YG971297-P;VYS94)O9'DH*3L*"@EE8VAO("1R97-P;VYS93$["@EE
M8VAO("1R97-P;VYS93(["C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U1E
M>'1?5VEK:2\`````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,S`P-``P,C`R,#``(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O5&5X=%]7:6MI+V1O8W,O````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`R,3$S,``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]497AT7U=I:VDO9&]C
M<R]386UP;&5086=E+G=I:VDN='AT````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(Q,C0`,3`T
M,3<S-C,P,#0`,#(T-C0W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"L@4V%M<&QE(%!A9V4@9F]R(%1E>'1?5VEK:2!$969A
M=6QT($UA<FMU<`H*)2543T,E)0H*+2TM+0H**RL@1V5N97)A;"!.;W1E<PH*
M5&AE(&UA<FMU<"!D97-C<FEB960@;VX@=&AI<R!P86=E(&ES(&9O<B!T:&4@
M9&5F875L="![>U1E>'1?5VEK:7U](')U;&5S.R!<"FET(&ES(&$@8V]M8FEN
M871I;VX@;V8@=&AE(%MH='1P.B\O=&%V:2YS;W5R8V5F;W)G92YN970@5VEK
M:U1I:VMI5&%V:5T@7`IA;F0@6VAT='`Z+R]D979E;&YE="YO<F<O(&-O5VEK
M:5T@;6%R:W5P('-T>6QE<RX*"D%L;"!T97AT(&ES(&5N=&5R960@87,@<&QA
M:6X@=&5X="P@86YD('=I;&P@8F4@8V]N=F5R=&5D('1O($A434P@96YT:71I
M97,@87,@7`IN96-E<W-A<GDN("!4:&ES(&UE86YS('1H870@>WL\?7TL('M[
M/GU]+"![>R9]?2P@86YD('-O(&]N(&%R92!C;VYV97)T960@9F]R(%P*>6]U
M("AE>&-E<'0@:6X@<W!E8VEA;"!S:71U871I;VYS('=H97)E('1H92!C:&%R
M86-T97)S(&%R92!7:6MI(&UA<FMU<#L@7`I497AT7U=I:VD@:7,@9V5N97)A
M;&QY('-M87)T(&5N;W5G:"!T;R!K;F]W('=H96X@=&\@8V]N=F5R="!A;F0@
M=VAE;B!N;W0@=&\I+@H*2G5S="!H:70@(G)E='5R;B(@='=I8V4@=&\@;6%K
M92!A('!A<F%G<F%P:"!B<F5A:RX@($EF('EO=2!W86YT(%P*=&\@:V5E<"!T
M:&4@<V%M92!L;V=I8V%L(&QI;F4@8G5T(&AA=F4@=&\@<W!L:70@:70@86-R
M;W-S(%P*='=O('!H>7-I8V%L(&QI;F5S("AS=6-H(&%S('=H96X@>6]U<B!E
M9&ET;W(@;VYL>2!S:&]W<R!A(&-E<G1A:6X@;G5M8F5R(%P*;V8@8VAA<F%C
M=&5R<R!P97(@;&EN92DL(&5N9"!T:&4@;&EN92!W:71H(&$@8F%C:W-L87-H
M('M[7'U](&%N9"!H:70@7`IR971U<FX@;VYC92X@(%1H:7,@=VEL;"!C875S
M92!T:&4@='=O(&QI;F5S('1O(&)E(&IO:6YE9"!O;B!D:7-P;&%Y+"!A;F0@
M=&AE(%P*8F%C:W-L87-H('=I;&P@;F]T('-H;W<N("`H268@>6]U(&5N9"!A
M(&QI;F4@=VET:"!A(&)A8VMS;&%S:"!A;F0@82!T86(@7`IO<B!S<&%C92P@
M:70@=VEL;"`G)VYO="<G(&)E(&IO:6YE9"!W:71H('1H92!N97AT(&QI;F4L
M(&%N9"!T:&4@8F%C:W-L87-H(%P*=VEL;"!B92!P<FEN=&5D+BD*"@HM+2TM
M"@HK*R!);FQI;F4@1F]R;6%T=&EN9PH*?'P@>WM@8&`G)VET86QI8R!T97AT
M)R=@8&!]?2`@("`@("`@("`@("`@("`@("`@("!\?"`G)VET86QI8R!T97AT
M)R<@?'P*?'P@>WM@8&`G)R=B;VQD('1E>'0G)R=@8&!]?2`@("`@("`@("`@
M("`@("`@("`@("!\?"`G)R=B;VQD('1E>'0G)R<@?'P*?'P@>WM@8&`G)R<G
M)VET86QI8R!A;F0@8F]L9"<G)R<G8&!@?7T@("`@("`@("`@("!\?"`G)R<G
M)VET86QI8R!A;F0@8F]L9"<G)R<G('Q\"GQ\('M[8&!@+R]E;7!H87-I<R\O
M8&!@?7T@?'P@+R]E;7!H87-I<R\O('Q\"GQ\('M[8&!@*BIS=')O;F<J*F!@
M8'U]('Q\("HJ<W1R;VYG*BH@?'P*?'P@>WM@8&`O+RHJ96UP:&%S:7,@86YD
M('-T<F]N9RHJ+R]@8&!]?2!\?"`O+RHJ96UP:&%S:7,@86YD('-T<F]N9RHJ
M+R\@?'P*?'P@>WM@8&`J*B\O<W1R;VYG(&%N9"!E;7!H87-I<R\O*BI@8&!]
M?2!\?"`J*B\O<W1R;VYG(&%N9"!E;7!H87-I<R\O*BH@?'P*?'P@>WM@8&![
M>W1E;&5T>7!E('1E>'1]?6!@8'U]("`@("`@("`@("`@("`@("`@("!\?"![
M>W1E;&5T>7!E('1E>'1]?2!\?`I\?"![>SQ@8&!P:'`Z9G5N8W1I;VXH*6!@
M8#Y]?2`@("`@("`@("`@("`@("`@("`@('Q\(#QP:'`Z9G5N8W1I;VXH*3X@
M?'P*?'P@>WM@8&!`0"TM+2!D96QE=&4@=&5X="`K*RL@:6YS97)T('1E>'0@
M0$!@8&!]?2!\?"!`0"TM+2!D96QE=&4@=&5X="`K*RL@:6YS97)T('1E>'0@
M0$`@?'P*?'P@>WM@8&!`0"TM+2!D96QE=&4@;VYL>2!`0&!@8'U]("`@("`@
M("`@("`@("`@("!\?"!`0"TM+2!D96QE=&4@;VYL>2!`0"!\?`I\?"![>V!@
M8$!`*RLK(&EN<V5R="!O;FQY($!`8&!@?7T@("`@("`@("`@("`@("`@('Q\
M($!`*RLK(&EN<V5R="!O;FQY($!`('Q\"GQ\('M[8&!@<W5P97(@7EXQ7EX@
M<V-R:7!T8&!@?7T@("`@("`@("`@("`@("`@("`@?'P@<W5P97(@7EXQ7EX@
M<V-R:7!T('Q\"@HM+2TM"@HK*R!,:71E<F%L(%1E>'0*"DEF('EO=2!D;VXG
M="!W86YT(%1E>'1?5VEK:2!T;R!P87)S92!S;VUE('1E>'0L(&5N8VQO<V4@
M:70@:6X@,R!B86-K=&EC:W,@*&YO="`S('-I;F=L92UQ=6]T97,I+@H*/&-O
M9&4^"@I4:&ES("<G)W1E>'0G)R<@9V5T<R![>W!A<G-E9'U]+@H*8&!@5&AI
M<R`G)R=T97AT)R<G(&1O97,@;F]T(&=E="![>W!A<G-E9'U]+F!@8`H*/"]C
M;V1E/@H*5&AI<R`G)R=T97AT)R<G(&=E=',@>WMP87)S961]?2X*"F!@8%1H
M:7,@)R<G=&5X="<G)R!D;V5S(&YO="!G970@>WMP87)S961]?2Y@8&`*"BTM
M+2T*"BLK($AE861I;F=S"@I9;W4@8V%N(&UA:V4@=F%R:6]U<R!L979E;',@
M;V8@:&5A9&EN9R!B>2!P=71T:6YG(%P*97%U86QS+7-I9VYS(&)E9F]R92!A
M;F0@869T97(@=&AE('1E>'0@*&%L;"!O;B!I=',@7`IO=VX@;&EN92DZ"@H\
M8V]D93X**RLK($QE=F5L(#,@2&5A9&EN9PHK*RLK($QE=F5L(#0@2&5A9&EN
M9PHK*RLK*R!,979E;"`U($AE861I;F<**RLK*RLK($QE=F5L(#8@2&5A9&EN
M9PH\+V-O9&4^"@HK*RL@3&5V96P@,R!(96%D:6YG"BLK*RL@3&5V96P@-"!(
M96%D:6YG"BLK*RLK($QE=F5L(#4@2&5A9&EN9PHK*RLK*RL@3&5V96P@-B!(
M96%D:6YG"@HM+2TM"@HK*R!486)L92!O9B!#;VYT96YT<PH*5&\@8W)E871E
M(&$@;&ES="!O9B!E=F5R>2!H96%D:6YG+"!W:71H(&$@;&EN:R!T;R!T:&%T
M(&AE861I;F<L('!U="!A('1A8FQE(&]F(&-O;G1E;G1S('1A9R!O;B!I=',@
M;W=N(&QI;F4N"@H\8V]D93X*)2543T,E)0H\+V-O9&4^"BTM+2T*"BLK($AO
M<FEZ;VYT86P@4G5L97,*"E5S92!F;W5R(&1A<VAE<R`H>WM@8&`M+2TM8&!@
M?7TI('1O(&-R96%T92!A(&AO<FEZ;VYT86P@<G5L92X*"BTM+2T*"BLK($QI
M<W1S"@HK*RL@0G5L;&5T($QI<W1S"@I9;W4@8V%N(&-R96%T92!B=6QL970@
M;&ES=',@8GD@<W1A<G1I;F<@82!P87)A9W)A<&@@=VET:"!O;F4@;W(@7`IM
M;W)E(&%S=&5R:7-K<RX*"CQC;V1E/@HJ($)U;&QE="!O;F4*("H@4W5B+6)U
M;&QE=`H\+V-O9&4^"@HJ($)U;&QE="!O;F4*("H@4W5B+6)U;&QE=`H**RLK
M($YU;6)E<F5D($QI<W1S"@I3:6UI;&%R;'DL('EO=2!C86X@8W)E871E(&YU
M;6)E<F5D(&QI<W1S(&)Y('-T87)T:6YG(&$@<&%R86=R87!H(%P*=VET:"!O
M;F4@;W(@;6]R92!H87-H97,N"@H\8V]D93X*(R!.=6UE<F\@=6YO"B,@3G5M
M8F5R('1W;PH@(R!3=6(M:71E;0H\+V-O9&4^"@HC($YU;65R;R!U;F\*(R!.
M=6UB97(@='=O"B`C(%-U8BUI=&5M"@H**RLK($UI>&EN9R!"=6QL970@86YD
M($YU;6)E<B!,:7-T($ET96US"@I9;W4@8V%N(&UI>"!A;F0@;6%T8V@@8G5L
M;&5T(&%N9"!N=6UB97(@;&ES=',Z"@H\8V]D93X*(R!.=6UB97(@;VYE"B`J
M($)U;&QE=`H@*B!"=6QL970*(R!.=6UB97(@='=O"B`J($)U;&QE=`H@*B!"
M=6QL970*("`J(%-U8BUB=6QL970*("`@(R!3=6(M<W5B+6YU;6)E<@H@("`C
M(%-U8BUS=6(M;G5M8F5R"B,@3G5M8F5R('1H<F5E"B`J($)U;&QE=`H@*B!"
M=6QL970*/"]C;V1E/@H*(R!.=6UB97(@;VYE"B`J($)U;&QE=`H@*B!"=6QL
M970*(R!.=6UB97(@='=O"B`J($)U;&QE=`H@*B!"=6QL970*("`J(%-U8BUB
M=6QL970*("`@(R!3=6(M<W5B+6YU;6)E<@H@("`C(%-U8BUS=6(M;G5M8F5R
M"B,@3G5M8F5R('1H<F5E"B`J($)U;&QE=`H@*B!"=6QL970*"@H**RLK($1E
M9FEN:71I;VX@3&ES=',*"EEO=2!C86X@8W)E871E(&$@9&5F:6YI=&EO;B`H
M9&5S8W)I<'1I;VXI(&QI<W0@=VET:"!T:&4@9F]L;&]W:6YG('-Y;G1A>#H*
M"CQC;V1E/@HZ271E;2`Q.B!3;VUE=&AI;F<*.DET96T@,CH@4V]M971H:6YG
M(&5L<V4*/"]C;V1E/@H*.DET96T@,3H@4V]M971H:6YG"CI)=&5M(#(Z(%-O
M;65T:&EN9R!E;'-E"@HM+2TM"@HK*R!";&]C:R!1=6]T97,*"EEO=2!C86X@
M;6%R:R!A(&)L;V-K<75O=&4@8GD@<W1A<G1I;F<@82!L:6YE('=I=&@@;VYE
M(&]R(&UO<F4@)SXG(%P*8VAA<F%C=&5R<RP@9F]L;&]W960@8GD@82!S<&%C
M92!A;F0@=&AE('1E>'0@=&\@8F4@<75O=&5D+@H*/&-O9&4^"E1H:7,@:7,@
M;F]R;6%L('1E>'0@:&5R92X*"CX@26YD96YT(&UE(2!4:&4@<75I8VL@8G)O
M=VX@9F]X(&IU;7!S(&]V97(@=&AE(&QA>GD@9&]G+B!<(`I.;W<@=&AI<R!T
M:&4@=&EM92!F;W(@86QL(&=O;V0@;65N('1O(&-O;64@=&\@=&AE(&%I9"!O
M9B!<(`IT:&5I<B!C;W5N=')Y+B!.;W1I8V4@:&]W('=E(&-A;B!C;VYT:6YU
M92!T:&4@8FQO8VLM<75O=&4@7"`*:6X@=&AE('-A;64@(G!A<F%G<F%P:"(@
M8GD@=7-I;F<@82!B86-K<VQA<V@@870@=&AE(&5N9"!O9B!<(`IT:&4@;&EN
M92X*/@H^($%N;W1H97(@8FQO8VLL(&QE861I;F<@=&\N+BX*/CX@4V5C;VYD
M(&QE=F5L(&]F(&EN9&5N=&EN9RX@(%1H:7,@<V5C;VYD(&ES(&EN9&5N=&5D
M(&5V96X@7"`*;6]R92!T:&%N('1H92!P<F5V:6]U<R!O;F4N"@I"86-K('1O
M(&YO<FUA;"!T97AT+@H\+V-O9&4^"@I4:&ES(&ES(&YO<FUA;"!T97AT(&AE
M<F4N"@H^($EN9&5N="!M92$@5&AE('%U:6-K(&)R;W=N(&9O>"!J=6UP<R!O
M=F5R('1H92!L87IY(&1O9RX@7`I.;W<@=&AI<R!T:&4@=&EM92!F;W(@86QL
M(&=O;V0@;65N('1O(&-O;64@=&\@=&AE(&%I9"!O9B!<"G1H96ER(&-O=6YT
M<GDN($YO=&EC92!H;W<@=V4@8V%N(&-O;G1I;G5E('1H92!B;&]C:RUQ=6]T
M92!<"FEN('1H92!S86UE(")P87)A9W)A<&@B(&)Y('5S:6YG(&$@8F%C:W-L
M87-H(&%T('1H92!E;F0@;V8@7`IT:&4@;&EN92X*/@H^($%N;W1H97(@8FQO
M8VLL(&QE861I;F<@=&\N+BX*/CX@4V5C;VYD(&QE=F5L(&]F(&EN9&5N=&EN
M9RX@(%1H:7,@<V5C;VYD(&ES(&EN9&5N=&5D(&5V96X@7`IM;W)E('1H86X@
M=&AE('!R979I;W5S(&]N92X*"D)A8VL@=&\@;F]R;6%L('1E>'0N"@H*+2TM
M+0H**RL@3&EN:W,@86YD($EM86=E<PH**RLK(%=I:VD@3&EN:W,*"E-M87-H
M5V]R9'-4;V=E=&AE<B!T;R!C<F5A=&4@82!P86=E(&QI;FLN"@I9;W4@8V%N
M(&9O<F-E(&$@5VEK:5!A9V4@;F%M92`G)R=N;W0G)R<@=&\@8F4@8VQI8VMA
M8FQE(&)Y('!U='1I;F<@7`IA;B!E>&-L86UA=&EO;B!M87)K(&EN(&9R;VYT
M(&]F(&ET+@H*/&-O9&4^"E=I:VE086=E("%7:6MI4&%G90H\+V-O9&4^"@I7
M:6MI4&%G92`A5VEK:5!A9V4*"BA.;W1E.B!E>&ES=&EN9R!W:6MI('!A9V5S
M(&UU<W0@8F4@:6X@=&AE(%1E>'1?5VEK:2![>W!A9V5S?7T@;W!T:6]N(&%R
M<F%Y+"!<"F%N9"!T:&4@>WMV:65W7W5R;'U](&]P=&EO;B!M=7-T(&)E('-E
M="!F;W(@=&AE(&QI;FMI;F<@=&\@=V]R:RXI"@HK*RL@1G)E92!,:6YK<PH*
M1G)E96QI;FMS(&%R92`B;F]N+7-T86YD87)D(B!7:6MI(&QI;FMS+@H**B!9
M;W4@8V%N(')E9F5R('1O(&YA;65D(&%N8VAO<G,@=VET:&EN('!A9V5S(&QI
M:V4@=&AI<SH@7`I[>V!@8"@H5VEK:5!A9V4C3F%M961!;F-H;W(I*6!@8'U]
M(&)E8V]M97,@*"A7:6MI4&%G92-.86UE9$%N8VAO<BDI+@HJ(%EO=2!C86X@
M8W)E871E(&YI8V4M;&]O:VEN9R!L:6YK<R!F<F]M(%=O<F1S4VUA<VAE9%1O
M9V5T:&5R(&QI:V4@=&AI<SH@7`I[>V!@8"@H5V]R9'-3;6%S:&5D5&]G971H
M97)\3FEC92!,:6YK*2E@8&!]?2!B96-O;65S(%P**"A7;W)D<U-M87-H9614
M;V=E=&AE<GQ.:6-E($QI;FLI*2X**B!2969E<B!T;R!N86UE9"!A;F-H;W)S
M('=I=&AI;B!N:6-E+6QO;VMI;F<@;&EN:W,@;&EK92!T:&ES.B!<"GM[8&!@
M*"A7:6MI4&%G97Q.:6-E($QI;FLC06YC:&]R*2E@8&!]?2!B96-O;65S(%P*
M*"A7:6MI4&%G97Q.:6-E($QI;FLC06YC:&]R*2DN"BH@66]U(&-A;B!A;'-O
M(&-R96%T92!L:6YK<R!T:&%T(&%R96XG="!7;W)D<U-M87-H9614;V=E=&AE
M<B!<"BAI+F4N+"!T:&%T(&AA=F4@<W!A8V5S*2!L:6ME('1H:7,Z('M[8&!@
M*"AF<F5E(&QI;FMS*2E@8&!]?2!<"F)E8V]M97,@*"AF<F5E(&QI;FMS*2DN
M"@HH3F]T93H@97AI<W1I;F<@=VEK:2!P86=E<R!M=7-T(&)E(&EN('1H92!4
M97AT7U=I:VD@>WMP86=E<WU](&]P=&EO;B!A<G)A>2P@7`IA;F0@=&AE('M[
M=FEE=U]U<FQ]?2!O<'1I;VX@;75S="!B92!S970@9F]R('1H92!L:6YK:6YG
M('1O('=O<FLN*0H**RLK($EN=&5R=VEK:2!,:6YK<PH*26YT97)W:6MI(&QI
M;FMS(&%R92!L:6YK<R!T;R!P86=E<R!O;B!O=&AE<B!7:6MI('-I=&5S+B!<
M"E1Y<&4@=&AE('M[8&!@4VET94YA;64Z4&%G94YA;65@8&!]?2!L:6ME('1H
M:7,Z"@HJ($UE871"86QL.E)E8V5N=$-H86YG97,**B!!9'9O9V%T;SIP<F]J
M+U=I:VMI5&EK:VE4879I"BH@5VEK:3I7;W)S94ES0F5T=&5R"@HH3F]T93H@
M=&AE(&EN=&5R=VEK:2!S:71E(&UU<W0@8F4@:6X@=&AE(%1E>'1?5VEK:2![
M>VEN=&5R=VEK:7U](&]P=&EO;B!A<G)A>2XI"@HK*RL@55),<PH*0W)E871E
M(&$@<F5M;W1E(&QI;FL@<VEM<&QY(&)Y('1Y<&EN9R!I=',@55),.B!H='1P
M.B\O8VEA=V5B+FYE="X*"DEF('EO=2!L:6ME+"!E;F-L;W-E(&ET(&EN(&)R
M86-K971S('1O(&-R96%T92!A(&YU;6)E<F5D(')E9F5R96YC92!<"F%N9"!A
M=F]I9"!C;'5T=&5R:6YG('1H92!P86=E.R![>V!@8%MH='1P.B\O8VEA=V5B
M+FYE="]F<F5E+UU@8&!]?2!B96-O;65S(%MH='1P.B\O8VEA=V5B+FYE="]F
M<F5E+UTN"@I/<B!Y;W4@8V%N(&AA=F4@82!D97-C<FEB960M<F5F97)E;F-E
M(&EN<W1E860@;V8@82!N=6UB97)E9"!R969E<F5N8V4Z"CQC;V1E/@I;:'1T
M<#HO+W!E87(N<&AP+FYE="!014%270H\+V-O9&4^"EMH='1P.B\O<&5A<BYP
M:'`N;F5T(%!%05)="@HK*RL@26UA9V5S"@I9;W4@8V%N('!U="!A('!I8W1U
M<F4@:6X@82!P86=E(&)Y('1Y<&EN9R!T:&4@55),('1O('1H92!P:6-T=7)E
M(%P**&ET(&UU<W0@96YD(&EN(&=I9BP@:G!G+"!O<B!P;F<I+@H\8V]D93X*
M:'1T<#HO+V,R+F-O;2]S:6<O=VEK:2YG:68*/"]C;V1E/@H*:'1T<#HO+V,R
M+F-O;2]S:6<O=VEK:2YG:68*"EEO=2!C86X@=7-E('1H92!D97-C<FEB960M
M<F5F97)E;F-E(%523"!M87)K=7`@=&\@9VEV92!T:&4@:6UA9V4@86X@04Q4
M('1A9SH*/&-O9&4^"EMH='1P.B\O=W=W+FYE=')O<&]L:7-U<V$N8FEZ+V)I
M;&QT:&5M87)M970O350O:6YD97@O:6UA9V5S+W-U;G-E=%\P-U\Q,%\P,RYJ
M<&<@4W5N<V5T70H\+V-O9&4^"@I;:'1T<#HO+W=W=RYN971R;W!O;&ES=7-A
M+F)I>B]B:6QL=&AE;6%R;65T+TU4+VEN9&5X+VEM86=E<R]S=6YS971?,#=?
M,3!?,#,N:G!G(%-U;G-E=%T*"@HM+2TM"BLK($-O9&4@0FQO8VMS"@I#<F5A
M=&4@8V]D92!B;&]C:W,@8GD@=7-I;F<@>WL\8V]D93XN+BX\+V-O9&4^?7T@
M=&%G<R`H96%C:"!O;B!I=',@;W=N(&QI;F4I+@H*/&-O9&4^"E1H:7,@:7,@
M86X@97AA;7!L92!C;V1E(&)L;V-K(0H\+V-O9&4^"@H*5&\@8W)E871E(%!(
M4"!B;&]C:W,@=&AA="!G970@875T;VUA=&EC86QL>2!C;VQO<FEZ960@=VAE
M;B!Y;W4@=7-E(%!(4"!T86=S+"!<"G-I;7!L>2!S=7)R;W5N9"!T:&4@8V]D
M92!W:71H('M[/'!H<#XN+BX\+W!H<#Y]?2!T86=S("AT:&4@=&%G<R!T:&5M
M<V5L=F5S(%P*<VAO=6QD(&5A8V@@8F4@;VX@=&AE:7(@;W=N(&QI;F5S+"!A
M;F0@;F\@;F5E9"!F;W(@=&AE('M[)FQT.S]P:'`@+BXN(#\F9W0[?7T@=&%G
M<RDN"@H\8V]D93X*/'!H<#X*+R\@4V5T('5P('1H92!W:6MI(&]P=&EO;G,*
M)&]P=&EO;G,@/2!A<G)A>2@I.PHD;W!T:6]N<ULG=FEE=U]U<FPG72`](")I
M;F1E>"YP:'`_<&%G93TB.PH*+R\@;&]A9"!T:&4@=&5X="!F;W(@=&AE(')E
M<75E<W1E9"!P86=E"B1T97AT(#T@:6UP;&]D92@G)RP@9FEL92@D<&%G92`N
M("<N=VEK:2YT>'0G*2D["@HO+R!C<F5A=&4@82!7:6MI(&]B:F5X="!W:71H
M('1H92!L;V%D960@;W!T:6]N<PHD=VEK:2`](&YE=R!497AT7U=I:VDH)&]P
M=&EO;G,I.PH*+R\@=')A;G-F;W)M('1H92!W:6MI('1E>'0N"F5C:&\@)'=I
M:VDM/G1R86YS9F]R;2@D=&5X="D["CPO<&AP/@H\+V-O9&4^"@H\<&AP/@HO
M+R!3970@=7`@=&AE('=I:VD@;W!T:6]N<PHD;W!T:6]N<R`](&%R<F%Y*"D[
M"B1O<'1I;VYS6R=V:65W7W5R;"==(#T@(FEN9&5X+G!H<#]P86=E/2(["@HO
M+R!L;V%D('1H92!T97AT(&9O<B!T:&4@<F5Q=65S=&5D('!A9V4*)'1E>'0@
M/2!I;7!L;V1E*"<G+"!F:6QE*"1P86=E("X@)RYW:6MI+G1X="<I*3L*"B\O
M(&-R96%T92!A(%=I:VD@;V)J97AT('=I=&@@=&AE(&QO861E9"!O<'1I;VYS
M"B1W:6MI(#T@;F5W(%1E>'1?5VEK:2@D;W!T:6]N<RD["@HO+R!T<F%N<V9O
M<FT@=&AE('=I:VD@=&5X="X*96-H;R`D=VEK:2T^=')A;G-F;W)M*"1T97AT
M*3L*/"]P:'`^"@HM+2TM"@HK*R!486)L97,*"EEO=2!C86X@8W)E871E('1A
M8FQE<R!U<VEN9R!P86ER<R!O9B!V97)T:6-A;"!B87)S.@H*/&-O9&4^"GQ\
M(&-E;&P@;VYE('Q\(&-E;&P@='=O('Q\"GQ\?'P@8FEG(&]L)R!L:6YE('Q\
M"GQ\(&-E;&P@9F]U<B!\?"!C96QL(&9I=F4@?'P*?'P@8V5L;"!S:7@@?'P@
M:&5R92=S(&$@=F5R>2!L;VYG(&-E;&P@?'P*/"]C;V1E/@H*?'P@8V5L;"!O
M;F4@?'P@8V5L;"!T=V\@?'P*?'Q\?"!B:6<@;VPG(&QI;F4@?'P*?'P@8V5L
M;"!F;W5R('Q\(&-E;&P@9FEV92!\?`I\?"!C96QL('-I>"!\?"!H97)E)W,@
M82!V97)Y(&QO;F<@8V5L;"!\?`H*/&-O9&4^"GQ\(&QI;F5S(&UU<W0@<W1A
M<G0@86YD(&5N9"!\?"!W:71H(&1O=6)L92!V97)T:6-A;"!B87)S('Q\(&YO
M=&AI;F<@?'P*?'P@8V5L;',@87)E('-E<&%R871E9"!B>2!\?"!D;W5B;&4@
M=F5R=&EC86P@8F%R<R!\?"!N;W1H:6YG('Q\"GQ\?'P@>6]U(&-A;B!S<&%N
M(&UU;'1I<&QE(&-O;'5M;G,@8GD@?'P@<W1A<G1I;F<@96%C:"!C96QL('Q\
M"GQ\('=I=&@@97AT<F$@8V5L;"!\?'Q\('-E<&%R871O<G,@?'P*?'Q\?'Q\
M(&)U="!P97)H87!S(&%N(&5X86UP;&4@:7,@=&AE(&5A<VEE<W0@=V%Y('1O
M('-E92!\?`H\+V-O9&4^"@I\?"!L:6YE<R!M=7-T('-T87)T(&%N9"!E;F0@
M?'P@=VET:"!D;W5B;&4@=F5R=&EC86P@8F%R<R!\?"!N;W1H:6YG('Q\"GQ\
M(&-E;&QS(&%R92!S97!A<F%T960@8GD@?'P@9&]U8FQE('9E<G1I8V%L(&)A
M<G,@?'P@;F]T:&EN9R!\?`I\?'Q\('EO=2!C86X@<W!A;B!M=6QT:7!L92!C
M;VQU;6YS(&)Y('Q\('-T87)T:6YG(&5A8V@@8V5L;"!\?`I\?"!W:71H(&5X
M=')A(&-E;&P@?'Q\?"!S97!A<F%T;W)S('Q\"GQ\?'Q\?"!B=70@<&5R:&%P
M<R!A;B!E>&%M<&QE(&ES('1H92!E87-I97-T('=A>2!T;R!S964@?'P*"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O5&5X=%]7:6MI+V1O8W,O9G)E92!L:6YK<RYW:6MI+G1X
M=````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#,P`#$P-#$W,S8S,#`T`#`R-#8T,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!!(")F<F5E
M(&QI;FLB(%=I:VD@<&%G92X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U1E>'1?5VEK:2]D;V-S+U1E>'17:6MI4')O<&]S86PN=VEK:2YT>'0`````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R,C,R-@`Q,#0Q-S,V,S`P-``P,C8Q,C4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````*R!497AT7U=I:VD@4')O<&]S
M86P*"E1H:7,@:7,@86X@=7!D871E9"!V97)S:6]N(&]F('1H92!P<F]P;W-A
M;"!T;R!014%2(&=R;W5P(&9O<B![>U1E>'1?5VEK:7U](&)Y(%MM86EL=&\Z
M<&UJ;VYE<T!C:6%W96(N;F5T(%!A=6P@32X@2F]N97-=+@H*)2543T,E)0H*
M+2TM+0H**RL@3W9E<G9I97<*"DUO<W0@5VEK:2!P<F]J96-T<R!U<V4@=&AE
M:7(@;W=N(&EN=&5R;F%L+"!S<&5C:6%L:7IE9"!P87)S:6YG(&%N9"!R96YD
M97)I;F<@96YG:6YE<R!T;R!T<F%N<V9O<FT@<V]U<F-E(%=I:VD@=&5X="!T
M;R!(5$U,+B`@5&AE(')U;&4@<W1R=6-T=7)E<R!O9B!D:69F97)E;G0@5VEK
M:2!I;7!L96UE;G1A=&EO;G,@87)E('5S=6%L;'D@:6YC;VUP871I8FQE+"!L
M96%D:6YG(&1E=F5L;W!E<G,@=&\@=W)I=&4@=&AE:7(@;W=N(&5N9VEN92!T
M;R!P87)S92!A;F0@<F5N9&5R('1H96ER(&]W;B!S<&5C:6%L:7IE9"!7:6MI
M(&UA<FMU<"X@(%1H:7,@;6%K97,@:70@9&EF9FEC=6QT('1O(&5X=')A8W0@
M86YD(&-O;7!A<F4@<G5L92!S=')U8W1U<F4L(&%S('=E;&P@87,@;6%K:6YG
M(&ET('1R;W5B;&5S;VUE('1O(&%D9"]M;V1I9GDO9&5L971E(&5X:7-T:6YG
M(&UA<FMU<"!R=6QE<RX@($EN(&%D9&ET:6]N+"!T:&ES(&UA:V5S(&ET(&YE
M87(M:6UP;W-S:6)L92!T;R`B9')O<"!I;B(@5VEK:2!T97AT('1R86YS9F]R
M;6%T:6]N('!R;V-E<W-E<R!T;R!A(&YO;6EN86QL>2!N;VXM5VEK:2!P<F]J
M96-T+@H*5&\@<V]L=F4@=&AE(')U;&4M;6]D:69I8V%T:6]N(&%N9"!D<F]P
M+6EN('!R;V)L96US(&YO=&5D(&%B;W9E+"![>U1E>'1?5VEK:7U](&%B<W1R
M86-T<R!T:&4@<')O8V5S<R!O9B!D:7-P;&%Y:6YG(%=I:VDM9F]R;6%T=&5D
M('1E>'0@8GD@=7-I;F<@86X@;V)J96-T+6]R:65N=&5D(')U;&4@<W1R=6-T
M=7)E(&9O<B!P87)S:6YG(&%N9"!R96YD97)I;F<N"@I!(&1E9F%U;'0@<V5T
M(&]F('!A<G-I;F<@86YD(')E;F1E<FEN9R!R=6QE(&-L87-S97,@:7,@<')O
M=FED960@=VET:"![>U1E>'1?5VEK:7U].R!T:&5Y('-E<G9E('1O(&EM<&QE
M;65N="!B87-I8R!7:6MI('1R86YS9F]R;6%T:6]N(&EN=&\@6$A434PL(&%N
M9"!P<F]V:61E('5S969U;"P@=V5L;"UC;VUM96YT960@97AA;7!L97,@;V8@
M:&]W('1O('=R:71E(&$@5VEK:2!T<F%N<V9O<FUA=&EO;B!R=6QE+@H*26X@
M861D:71I;VXL(&EN9&EV:61U86P@<&%R<VEN9R!A;F0@<F5N9&5R:6YG(')U
M;&5S(&-A;B!B92!A9&1E9"P@;6]D:69I960L(&%N9"!R96UO=F5D('=I=&@@
M82!U<V5R+61E9FEN960@<G5L97,@9&ER96-T;W)Y+B`@1&5P96YD:6YG(&]N
M('1H92!R96YD97)I;F<@;65T:&]D(&9O<B!A(')U;&4L('-O=7)C92!7:6MI
M('1E>'0@;6%Y(&)E('1R86YS9F]R;65D(&EN=&\@6$A434PL($QA=&5X+"!0
M1$8L(%)41BP@86YD('-O(&]N+@H*5&AE('!R;W!E<G1I97,@;V8@82![>U1E
M>'1?5VEK:7U](&]B:F5C="!D971E<FUI;F4N+BX*"BH@=VAI8V@@<G5L97,@
M87)E(&%P<&QI960@=&\@=&AE('-O=7)C92!7:6MI('1E>'0@*&%N9"!I;B!W
M:&%T(&]R9&5R*2P**B!W:&%T('1H92`A5VEK:5=E8B!54DQS(&%R92!F;W(@
M=FEE=VEN9R!A;F0@961I=&EN9R!P86=E<RP**B!);G1E<G=I:VD@;6%P<&EN
M9W,L"BH@=VAI8V@@<&%G97,@97AI<W0@:6X@=&AE("%7:6MI5V5B+`HJ(&%N
M9"!M=6-H(&UO<F4N"@I[>U1E>'1?5VEK:7U](&1O97,@;F]T(&EM<&QE;65N
M="!A(&9U;&P@(5=I:VE7:6MI5V5B.R!I="!O;FQY(&AA;F1L97,@=&AE('1R
M86YS9F]R;6%T:6]N(&]F(%=I:VD@<V]U<F-E('1E>'0@=&\@86X@;W5T<'5T
M(&9O<FUA="X*"BTM+2T*"BLK($AI<W1O<GD@86YD(%)E<V5A<F-H"@I0;&5A
M<V4@;F]T92!T:&%T('M[5&5X=%]7:6MI?7T@=V%S('!R92UP<F]P;W-E9"!E
M87)L:65R('1H:7,@>65A<B!W:71H('-O;64@<&]S:71I=F4@<F5S<&]N<V5;
M:'1T<#HO+VUA<F,N=&AE86EM<V=R;W5P+F-O;2\_=#TQ,#4X,S@Y-S@R,#`P
M,#$F<CTQ)G<],ET@86YD('1H870@=&AE(&-A;&P@9F]R('9O=&5S(&ES(&-O
M;7!L971E+EMH='1P.B\O;6%R8RYT:&5A:6US9W)O=7`N8V]M+S]T/3$P-CDY
M-#8X.#`P,#`P,29R/3$F=STR70H*4')I;6%R>2!R97-E87)C:"!F;W(@>WM4
M97AT7U=I:VE]?2!W87,@8F%S960@;VX@='=O(&]P96XM<V]U<F-E(%=I:VD@
M<')O:F5C=',L(%MH='1P.B\O=&%V:2YS;W5R8V5F;W)G92YN970O(%=I:VMI
M5&EK:VE4879I72!A;F0@6VAT='`Z+R]W=W<N9&5V96QN970N;W)G+R!C;U=I
M:VE=+B`@3W1H97(@5VEK:2!E;F=I;F5S(&%N9"!R=6QE('-E=',@=V5R92!A
M;'-O('5S960@:6X@<F5S96%R8V@L(&)U="!T:&5S92!T=V\@<')O=FED92!S
M=69F:6-I96YT(&5X86UP;&5S(&9O<B!7:6MI(&EM<&QE;65N=&%T:6]N+@H*
M+2TM+0H**RL@5VAA="!)<R!7:6MI/PH*02`A5VEK:5=I:VE796(@*&$@(E=I
M:VDB*2!I<R!A('=E8BUB87-E9"!C;VQL86)O<F%T:6]N('1O;VP@:6X@=VAI
M8V@@86YY('5S97(@8V%N(&5D:70@86YY('!A9V4@;VX@=&AE('-I=&4N"@I4
M;R!Q=6]T92!#,CH@(E=I:VD@:7,@82!C;VUP;W-I=&EO;B!S>7-T96TL(&ET
M)W,@82!D:7-C=7-S:6]N(&UE9&EU;2P@:70G<R!A(')E<&]S:71O<GDL(&ET
M)W,@82!M86EL('-Y<W1E;2P@:70G<R!A(&-H870@<F]O;2P@86YD(&ET)W,@
M82!T;V]L(&9O<B!C;VQL86)O<F%T:6]N+B);:'1T<#HO+V,R+F-O;2]C9VDO
M=VEK:5T*"@HK*RL@5VEK:2!-87)K=7`@27,@16%S>2!4;R!5;F1E<G-T86YD
M+BXN"@I7:6MI<R!A;&QO=R!R:6-H('1E>'0@;6%R:W5P(&%N9"!A=71O;6%T
M:6,@<&%G92!L:6YK:6YG+@H*0F5C875S92!7:6MI(&-O;G1E;G0@:7,@96YT
M97)E9"!A<R!P;&%I;B!T97AT(&EN(&$@=V5B(&5N=FER;VYM96YT+"!7:6MI
M<R!D;R!N;W0@9V5N97)A;&QY('5S92!(5$U,(&9O<B!R:6-H('1E>'0@;6%R
M:W5P.R!I;G-T96%D+"!T:&5Y('5S92!S=')U8W1U<F5D('1E>'0@=&\@;6%R
M:R!T:&4@96QE;65N=',@;V8@82!P86=E+@H*1F]R(&5X86UP;&4L(&EN($A4
M34PL(&]N92!W;W5L9"!M87)K(&$@:&5A9&EN9R!U<VEN9R![>SQH3CXN+BX\
M+VA./GU]('1A9W,N"@H\8V]D93X*/&AT;6P^"CQH,SY4:&ES(&ES(&$@:&5A
M9&EN9RX\+V@S/@H\<#Y4:&ES(&ES(&YO="X\+W`^"CPO:'1M;#X*/"]C;V1E
M/@H*5&\@;6%R:R!A(&AE861I;F<@:6X@82!7:6MI+"!Y;W4@<'5T('1H92!H
M96%D:6YG(&]N(&ET<R!O=VX@;&EN92!A;F0@<')E9FEX(&ET('=I=&@@82!N
M=6UB97(@;V8@<&QU<RUS:6=N<RX@(%1H=7,L('1H92!C;W)R97-P;VYD:6YG
M(%=I:VD@;6%R:W5P(&9O<B!T:&4@86)O=F4@97AA;7!L92!W;W5L9"!L;V]K
M('-O;65T:&EN9R!L:6ME('1H:7,Z"@H\8V]D93X**RLK(%1H:7,@:7,@82!H
M96%D:6YG+@I4:&ES(&ES(&YO="X*/"]C;V1E/@H*5&AE<F4@87)E(&1I9F9E
M<F5N="!S=')U8W1U<F4@<G5L97,@9F]R(&1I9F9E<F5N="!M87)K=7`@96QE
M;65N=',N("!&;W(@97AA;7!L92P@8F]L9"!T97AT(&UI9VAT(&)E(&5N8VQO
M<V5D(&EN(&$@<&%I<F5D('-E=',@;V8@=&AR964@<VEN9VQE('%U;W1E<RP@
M=&5L971Y<&4@=&5X="!I<R!S970@;V9F(&UY(&UA=&-H960@<&%I<G,@;V8@
M,B!C=7)L>2!B<F%C97,L(&QI<W1S(&%R92!N;W1E9"!B>2!S=&%R=&EN9R!T
M:&4@;&EK92!W:71H(&$@:&%S:"!O<B!A('-T87(L(&%N9"!S;R!O;BX*"E=I
M:VES(&%L<V\@875T;VUA=&4@=&AE(&-R96%T:6]N(&%N9"!L:6YK:6YG(&]F
M('!A9V5S+B`@26X@82!7:6MI+"!P86=E(&YA;65S(&%R92!M861E(&]F(%=O
M<F1S4VUA<VAE9%1O9V5T:&5R.R!T:&4@5VEK:2!S965S(%=O<F1S4VUA<VAE
M9%1O9V5T:&5R(&]N(&$@<&%G92!A;F0@8W)E871E<R!A(&QI;FL@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@<&%G92!I;B!T:&4@5VEK:2X@($EF('1H92!P86=E
M(&5X:7-T<R!O;B!T:&4@5VEK:2P@=&AE('!A9V4@;F%M92!I='-E;&8@8F5C
M;VUE<R!A(&QI;FL[(&EF('1H92!P86=E(&1O97,@;F]T(&5X:7-T+"!A('-U
M9F9I>"!I<R!A9&1E9"!T;R!T:&4@<&%G92!N86UE+"!U<W5A;&QY(&$@<75E
M<W1I;VX@;6%R:RP@86YD('1H870@<W5F9FEX(&ES(&QI;FME9"!T;R!T:&4@
M(F-R96%T92!A(&YE=R!P86=E(B!54DPN"@I4:&ES(&UE86YS('1H870@:6X@
M;W)D97(@=&\@=')A;G-L871E(%=I:VDM9F]R;6%T=&5D('-T<G5C='5R960@
M=&5X="`H9G)O;2!T:&4@<V]U<F-E*2!T;R!(5$U,("AF;W(@9&ES<&QA>2DL
M(&ET(&ES(&YE8V5S<V%R>2!T;R!D;R!A(&9I;F0M86YD+7)E<&QA8V4@;VX@
M=&AE('1E>'0L(&QO;VMI;F<@9F]R('1E>'0@;&EN97,@=&AA="!M871C:"!T
M:&4@5VEK:2!S=')U8W1U<F5D('1E>'0@<G5L97,L(&%N9"!C;VYV97)T('1H
M96T@=&\@2%1-3"!F;W(@9&ES<&QA>2X@($UO<W0@5VEK:2!E;F=I;F5S('!A
M<G-E+6%N9"UR96YD97(@=VET:&EN(&$@<VEN9VQE(&-L87-S+"!O<B!W:71H
M(&$@<V5R:65S(&]F(&9U;F-T:6]N<R!W:71H:6X@82!S:6YG;&4@:6YC;'5D
M92!F:6QE+@H*"BLK*R`N+BY"=70@270G<R!.;W0@4W1A;F1A<F1I>F5D+BXN
M"@I4:&4@<')O8FQE;2!W:71H(%=I:VD@;6%R:W5P(&ES('1H870@:70@:7,@
M;F]T('-T86YD87)D:7IE9"X@($1I9F9E<F5N="!7:6MI(&5N9VEN97,@=7-E
M(&1I9F9E<F5N="!R=6QE('-T<G5C='5R97,N("!);B!G96YE<F%L+"!7:6MI
M(&EM<&QE;65N=&]R<R!W86YT('1H92!S;W5R8V4@=&5X="!T;R!B92!M86ME
M('-E;G-E('=H96X@<F5A9"!B>2!H=6UA;G,L(&%N9"!A;'-O(&)E('1R86YS
M;&%T86)L92!T;R!(5$U,+B`@5VAA="`B;6%K97,@<V5N<V4B('1O(&]N92!D
M979E;&]P97(@;W(@8V]M;75N:71Y(&UI9VAT(&YO="!M86ME('-E;G-E('1O
M(&%N;W1H97(N"@I">2!W87D@;V8@97AA;7!L92P@;&5T)W,@=&%K92!A(&QO
M;VL@870@:&5A9&EN9W,N("!);B!(5$U,+"!A(&AE861I;F<@:7,@86QW87ES
M(&UA<FME9"!T:&4@<V%M92!W87DN("!);B!D:69F97)E;G0@5VEK:7,L(&AE
M861I;F=S(&%R92!N;W0@86QW87ES('1H92!S86UE+B`@26X@(5=I:VMI5&EK
M:VE4879I+"!A(&AE861I;F<M,B!L;V]K<R!L:6ME('1H:7,Z"@H\8V]D93X*
M/3T@37D@2&5A9&EN9R`]/0H\+V-O9&4^"@I"=70@:6X@8V]7:6MI+"!I="!L
M;V]K<R!L:6ME('1H:7,Z"@H\8V]D93X**RL@37D@2&5A9&EN9PH\+V-O9&4^
M"@I!;F0@:6X@86YO=&AE<B!W:6MI+"!I="!M:6=H="!L;V]K(&QI:V4@=&AI
M<SH*"CQC;V1E/@HM+2TM($UY($AE861I;F<*/"]C;V1E/@H**%=H>2!F;W5R
M(&1A<VAE<R!I;G-T96%D(&]F('1W;S\@($)E8V%U<V4@=&AE(&EM<&QE;65N
M=&]R(&1E8VED960@=&AA="!A(&AE861I;F<M,2!S:&]U;&0@=7-E('-I>"!D
M87-H97,@87,@=&AE(&UO<W0M:6UP;W)T86YT+"!A;F0@=V]R:R!D;W=N('1O
M(&$@:&5A9&EN9RTV('1H870@=7-E<R!O;F4@9&%S:"!A<R!T:&4@;&5A<W0M
M:6UP;W)T86YT+BD*"DET)W,@979E;B!W;W)S92!W:&5N('=E(&=E="!T;R!B
M;VQD+"!I=&%L:6-S+"!A;F0@<V\@;VXN"@HJ(%-O;64@5VEK:7,@=7-E('M[
M8&!@)R=I=&%L:6,G)V!@8'U]+"!O=&AE<G,@=7-E('M[8&!@+R]I=&%L:6,O
M+V!@8'U]+"!A;F0@;W1H97)S('5S92![>V!@8%]I=&%L:6-?8&!@?7TN"BH@
M4V]M92!7:6MI<R!I;7!L96UE;G0@<&%R=&EA;"!(5$U,('-U<'!O<G0@<V\@
M>6]U(&-A;B!E;6)E9"!T86)L97,L(&]T:&5R<R!U<V4@82!D;W5B;&4M<&EP
M92!M87)K=7`@<W1Y;&4@=&\@;6%R:R!C96QL<RX**B!3;VUE(%=I:VES(&EM
M<&QE;65N="!834PM:7-H('1A9W,@=&\@;6%R:R!E;&5M96YT<RX**B!3;VUE
M(%=I:VES(&EM<&QE;65N="!P;'5G:6YS(&]R(&UA8W)O<R!T;R!E;6)E9"!C
M=7-T;VT@8F5H879I;W)S(&EN=&\@5VEK:2!P86=E<RX*"@H**RLK("XN+D%N
M9"!)="=S($AA<F0@5&\@4VAA<F4N"@I"=70@=VAA="!S;VUE(%=I:VES(&1O
M+"!O=&AE<G,@9&\@;F]T+B`@5&AI<R!M96%N<R!T:&%T(&EF('EO=2!W86YT
M(%=I:VD@:6UP;&5M96YT871I;VX@(D$B('1O('-U<'!O<G0@82!R=6QE(&]R
M(&)E:&%V:6]R(&9R;VT@5VEK:2!I;7!L96UE;G1A=&EO;B`B0B(L(&ET(&)E
M8V]M97,@9&EF9FEC=6QT(&]R(&EM<&]S<VEB;&4L(&)E8V%U<V4@=&AE(&1I
M9F9E<F5N="!I;7!L96UE;G1A=&EO;G,@=7-E(&1I9F9E<F5N="!P87)S:6YG
M(&%N9"!R96YD97)I;F<@<F]U=&EN97,@=&AA="!A<'!L>2!T:&5I<B!R=6QE
M('-T<G5C='5R97,@:6X@9&EF9F5R96YT('=A>7,N"@I.;W0@;VYL>2!T:&%T
M+"!B=70@=&AE('!A<G-I;F<@86YD(')E;F1E<FEN9R!R;W5T:6YE<R!G96YE
M<F%L;'D@9&5P96YD(&]N('1H92!W:&]L92!R96UA:6YD97(@;V8@=&AE(%=I
M:VD@:6UP;&5M96YT871I;VXN("!4:&ES(&UE86YS('1H92!7:6MI('1R86YS
M9F]R;6%T:6]N(&5N9VEN92!E>&ES=',@=VET:&EN(&$@9G5L;"`A5VEK:5=I
M:VE796(@<WES=&5M('1H870@:&%N9&QE<R!P86=E(&-R96%T:6]N+"!V97)S
M:6]N:6YG+"!S=&]R86=E+"!A;F0@;&EN:VEN9RP@<V]M971I;65S(&%L;VYG
M('=I=&@@>WMD:69F*"E]?2!F=6YC=&EO;G,@=&\@<V5E('1H92!D:69F97)E
M;F-E<R!B971W965N('!A9V4@961I=',N"@HM+2TM"@HK*R!497AT7U=I:VD@
M36%K97,@270@16%S>2!4;R!3:&%R90H*>WM497AT7U=I:VE]?2!S;VQV97,@
M=&AE('!R;V)L96T@;V8@<VAA<FEN9R!R=6QE<R!A;F0@8F5H879I;W)S(&)Y
M('5S:6YG(&$@=6YI9FEE9"!P87)S:6YG(&%N9"!R96YD97)I;F<@;65C:&%N
M:7-M('=I=&@@86X@;V)J96-T+6]R:65N=&5D('-Y<W1E;2!O9B!R=6QE<R!F
M;W(@=')A;G-F;W)M:6YG(%=I:VD@;6%R:W5P(&5L96UE;G1S+@H*16%C:"!7
M:6MI(&5L96UE;G0@9V5T<R!I=',@;W=N(')U;&4@8VQA<W,N("!4:&4@<G5L
M92!C;&%S<R!H86YD;&5S(&ET<R!O=VX@<&%R<VEN9R!A;F0@<F5N9&5R:6YG
M('=I=&AI;B!T:&4@8V]N=&5X="!O9B!T:&4@<')I;6%R>2![>U1E>'1?5VEK
M:7U](&]B:F5C="P@8G5T(&AA<R!F=6QL(&%C8V5S<R!T;R!T:&4@<')I;6%R
M>2![>U1E>'1?5VEK:7U](&]B:F5C="!P<F]P97)T:65S("AT:&4@<V]U<F-E
M('1E>'0L('1H92!E;&5M96YT<R!T:&%T(&AA=F4@86QR96%D>2!B965N('!A
M<G-E9"P@86YD('-O(&]N*2X*"E1H:7,@;65A;G,@=&AA="!Y;W4@8V%N(&%D
M9"P@8VAA;F=E+"!A;F0@<F5M;W9E(')U;&5S(&9O<B!A;GD@<W!E8VEF:6,@
M5VEK:2!M87)K=7`@<V5T('EO=2!H87!P96X@=&\@;&EK92X@($ET(&%L<V\@
M;65A;G,@=&AA="!I9B!Y;W4@<V5E(&$@5VEK:2!B96AA=FEO<B!T:&%T('EO
M=2!L:6ME+"!Y;W4@8V%N(&5A<VEL>2!W<FET92!A(&YE=R!R=6QE('1H870@
M;6EM:6-S('1H92!B96AA=FEO<B!A;F0@<&QU9R!I="!I;G1O('1H92![>U1E
M>'1?5VEK:7U](&5N9VEN92!W:71H;W5T(')E=W)I=&EN9R!T:&4@<&%R<V5R
M(&]R(')E;F1E<F5R+@H*5&AU<RP@:6YS=&5A9"!O9B!I;7!L96UE;G1I;F<@
M82!F=6QL("%7:6MI5VEK:5=E8B!S>7-T96TL('M[5&5X=%]7:6MI?7T@;VYL
M>2!D96%L<R!W:71H('1H92!T<F%N<V9O<FUA=&EO;B!O9B!7:6MI('-O=7)C
M92!T97AT('1O(&%N(&]U='!U="!F;W)M870N("`H26YC:61E;G1A;&QY+"!I
M="!N965D<R!T;R!K;F]W('=H971H97(@82!P86=E(&5X:7-T<R!W:71H:6X@
M82`A5VEK:5=E8BP@8G5T('1H870@:7,@86)S=')A8W1E9"!A;F0@9&]E<R!N
M;W0@9&5P96YD(&]N(&%N>2!S<&5C:69I8R!S=&]R86=E(&]R(')E=')I979A
M;"!S>7-T96TN*0H*"BLK*R!(;W<@1&]E<R!4:&ES(%=O<FL_"@I);B!G96YE
M<F%L+"![>U1E>'1?5VEK:7U]('5S97,@82!R97!L86-E+7=I=&@M=&]K96X@
M;65T:&]D;VQO9WD@=&\@;6%R:R!S;W5R8V4@=&5X="!M871C:&EN9R!A(%=I
M:VD@<G5L92X@($%N>2!S;W5R8V4@=&5X="!M871C:&EN9R!A(')U;&4@*'5S
M=6%L;'D@9F]U;F0@=&AR;W5G:"!A(')E9W5L87(@97AP<F5S<VEO;BD@:7,@
M<F5P;&%C960@=VET:"!A('!A:7(@;V8@9&5L:6UI=&5R<R!S=7)R;W5N9&EN
M9R!A('1O:V5N(&YU;6)E<BP@86YD(&$@;6%T8VAI;F<@=&]K96X@;G5M8F5R
M(&ES(&5N=&5R960@:6YT;R!T:&4@>WM497AT7U=I:VE]?2![>R1?=&]K96YS
M?7T@87)R87D@<')O<&5R='DN("!!;GD@;W!T:6]N86P@:6YF;W)M871I;VX@
M86)O=70@=&AE(&UA=&-H:6YG('1E>'0L(&%N9"!S;VUE=&EM97,@=&AE(&UA
M=&-H:6YG('1E>'0@:71S96QF+"!I<R!S=&]R960@:6X@=&AE('1O:V5N(&5N
M=')Y+B`@069T97(@<&%R<VEN9RP@=&AE('1O:V5N<R!A<F4@<F5N9&5R960@
M:6YT;R!A('1A<F=E="!F;W)M870@9&5P96YD:6YG(&]N('1H92!R=6QE)W,@
M<F5N9&5R*"D@;65T:&]D+@H*07,@82!S:61E+6)E;F5F:70L('1H:7,@;65A
M;G,@=&AA="!O;F-E('1H92!S;W5R8V4@=&5X="!H87,@8F5E;B!P87)S960@
M86YD('1O:V5N:7IE9"P@=&AE(&-O;6)I;F%T:6]N(&]F('1H92!S;W5R8V4@
M=&5X="!A;F0@<F5P;&%C96UE;G0@=&]K96YS(&%L;&]W<R!Y;W4@=&\@=&%R
M9V5T(&%N>2!O=71P=70@9F]R;6%T+"!N;W0@:G5S="!82%1-3"X@($EF(&$@
M<G5L92!S=7!P;W)T<R!I="P@=&AA="!R=6QE(&-A;B!R96YD97(@82!T;VME
M;B!I;G1O($QA=&5X+"!01$8L(%)41BP@86YD('-O(&]N+@H*"BLK*R!%>&%M
M<&QE<PH*5&AE(&)E<W0@97AA;7!L92!O9B![>U1E>'1?5VEK:7U](&ES('1H
M92![>U1E>'1?5VEK:7U]('-A;7!L92!P86=E+"!I;F-L=61E9"!I;B!T:&4@
M<&%C:V%G92!D;V-U;65N=&%T:6]N+B`@069T97(@>6]U('5S92!014%2('1O
M(&EN<W1A;&P@>WM497AT7U=I:VE]?2P@;&]O:R!I;B!T:&4@9&]C<R\@9&ER
M96-T;W)Y+B`@5&AE(&EN9&5X+G!H<"!F:6QE('-H;W<@:&]W('1O(&EN<W1A
M;G1I871E(&$@>WM497AT7U=I:VE]?2!O8FIE8W0@=VET:"!A('-E="!O9B!C
M=7-T;VT@;W!T:6]N<RP@86YD(%-A;7!L92YW:6MI+G1X="!S:&]W<R!H;W<@
M=&\@=W)I=&4@=7`@5VEK:2!S;W5R8V4@=&5X="X@($9I;F%L;'DL(&]P96X@
M:6YD97@N<&AP(&EN('EO=7(@8G)O=W-E<B!T;R!S964@=&AE(%=I:VD@<V]U
M<F-E('1E>'0@=')A;G-F;W)M960@:6YT;R!(5$U,+@H*+2TM+0H**RL@1&]W
M;FQO860@=&AE(%!A8VMA9V4*"FAT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]497AT7U=I:VD*"BLK*R!+;F]W;B!)<W-U97,*"DYE960@=&\@8W)E871E
M(&9U;&P@9&]C=6UE;G1A=&EO;BP@:6YC;'5D:6YG(&AO=R!T;R!W<FET92!A
M(')U;&4N"@I[>U1E>'1?5VEK:7U]('-H;W5L9"!R971U<FX@>WM014%27T5R
M<F]R?7T@;V)J96-T<R!A;F0@97)R;W(@8V]D97,L(&YO="!E8VAO(&5R<F]R
M<R!T;R!O=71P=70N"@I3:&]U;&0@861D('M[<F5N9&5R3&%T97@H*7U](&UE
M=&AO9"!F;W(@86QL(&1E9F%U;'0@<G5L97,@*&9R;VT@(5=I:VMI5&EK:VE4
M879I/RD*"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]497AT7U=I:VDO9&]C<R]S='EL
M97-H965T+F-S<P``````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q,3<`,3`T,3<S-C,P
M,#0`,#(T,#,Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````&)O9'DL('`L(&)R+"!T:"P@=&0@>PH@9F]N="UF86UI;'DZ(")6
M97)D86YA(BP@(D%R:6%L(BP@(D=E;F5V82(["B!F;VYT+7-I>F4Z(#$R<'@[
M"GT*"G1H('L*(&9O;G0M=V5I9VAT.B!B;VQD.PH@8F%C:V=R;W5N9#H@8FQA
M8VL["B!C;VQO<CH@=VAI=&4["GT*"F@Q('L*(&9O;G0M<VEZ93H@,S!P>#L*
M(&9O;G0M9F%M:6QY.B`B07)I86P@3F%R<F]W(BP@(DX@2&5L=F5C=&EC82!.
M87)R;W<B+"`B5&%H;VUA(CL*(&9O;G0M=V5I9VAT.B!B;VQD.PI]"@IH,B![
M"B!F;VYT+7-I>F4Z(#(T<'@["B!F;VYT+69A;6EL>3H@(D%R:6%L($YA<G)O
M=R(L(").($AE;'9E8W1I8V$@3F%R<F]W(BP@(E1A:&]M82(["B!F;VYT+7=E
M:6=H=#H@8F]L9#L*?0H*:#,@>PH@9F]N="US:7IE.B`Q.'!X.PH@9F]N="UF
M86UI;'DZ(")!<FEA;"!.87)R;W<B+"`B3B!(96QV96-T:6-A($YA<G)O=R(L
M(")486AO;6$B.PH@9F]N="UW96EG:'0Z(&)O;&0["GT*"F@T('L*(&9O;G0M
M<VEZ93H@,39P>#L*(&9O;G0M9F%M:6QY.B`B07)I86P@3F%R<F]W(BP@(DX@
M2&5L=F5C=&EC82!.87)R;W<B+"`B5&%H;VUA(CL*(&9O;G0M=V5I9VAT.B!B
M;VQD.PI]"@IH-2!["B!F;VYT+7-I>F4Z(#$T<'@["B!F;VYT+69A;6EL>3H@
M(D%R:6%L($YA<G)O=R(L(").($AE;'9E8W1I8V$@3F%R<F]W(BP@(E1A:&]M
M82(["B!F;VYT+7=E:6=H=#H@8F]L9#L*?0H*:#8@>PH@9F]N="US:7IE.B`Q
M,G!X.PH@9F]N="UF86UI;'DZ(")!<FEA;"!.87)R;W<B+"`B3B!(96QV96-T
M:6-A($YA<G)O=R(L(")486AO;6$B.PH@9F]N="UW96EG:'0Z(&)O;&0["GT*
M"F$Z;&EN:R!["B!C;VQO<CH@8FQU93L*('1E>'0M9&5C;W)A=&EO;CH@;F]N
M93L*?0H*83IV:7-I=&5D('L*(&-O;&]R.B!B;'5E.PH@=&5X="UD96-O<F%T
M:6]N.B!N;VYE.PI]"@IA.FAO=F5R('L*(&-O;&]R.B!R960["B!T97AT+61E
M8V]R871I;VXZ('5N9&5R;&EN93L*?0H*<')E('L*(&)O<F1E<CH@,7!X(&1A
M<VAE9"`C,#`S,S8V.PH@8F%C:V=R;W5N9#H@(V5E965E93L*('!A9&1I;F<Z
M(#9P>#L*(&9O;G0M9F%M:6QY.B!0<F]F;VYT+"!-;VYA8V\L($-O=7)I97(L
M(")!;F1A;&4@36]N;R(L(&UO;F]S<&%C93L*?0H*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+U1E>'1?5VEK:2]D;V-S+U=I:VE086=E+G=I:VDN='AT````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`S,@`Q,#0Q-S,V,S`P-``P,C0S,C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````02!G96YE<FEC(&)L86YK
M(%=I:VD@<&%G92X`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]497AT7U=I
M:VDO9&]C<R]4;VME;E)U;&5+97ES+G=I:VDN='AT````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8Q
M,S,`,3`T,3<S-C,P,#0`,#(U,S<W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"L@5&]K96X@4G5L92!+97ES"@I\?"`G)R=2
M=6QE($YA;64G)R<@("`@("`@?'P@)R<G1&5S8W)I<'1I;VXG)R<@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\?"`G)R=/<'1I;VYS)R<G('Q\
M"GQ\('M[8FQO8VMQ=6]T97U]("`@("`@("!\?"!";&]C:RUQ=6]T960@=&5X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('Q\('M[='EP93I;
M<W1A<G1\96YD72!]?2!\?`I\?"![>V)O;&1]?2`@("`@("`@("`@("`@?'P@
M0F]L9"!T97AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\?"![>W1Y<&4Z6W-T87)T?&5N9%U]?2!\?`I\?"![>V-O9&5]?2`@
M("`@("`@("`@("`@?'P@02!B;&]C:R!O9B!G96YE<FEC(&-O;7!U=&5R(&-O
M9&4N("`@("`@("`@("`@("`@("!\?"![>W1E>'1]?2!\?`I\?"![>V1E9FQI
M<W1]?2`@("`@("`@("`@?'P@1&5F:6YI=&EO;B!L:7-T(&5L96UE;G0N("`@
M("`@("`@("`@("`@("`@("`@("`@("!\?"![>W1Y<&4Z6VQI<W1\=&5R;7QN
M87)R75];<W1A<G1\96YD77U]('Q\"GQ\('M[9&5L:6UI=&5R?7T@("`@("`@
M("!\?"!!;B!E>&ES=&EN9R!D96QI;6ET97(N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('Q\("T@?'P*?'P@>WME;7!H87-I<WU]("`@("`@("`@('Q\
M($5M<&AA<VEZ960@*'5S=6%L;'D@:71A;&EC*2!T97AT+B`@("`@("`@("`@
M("`@("`@?'P@>WMT>7!E.EMS=&%R='QE;F1=?7T@?'P*?'P@>WMF<F5E;&EN
M:WU]("`@("`@("`@('Q\($$@;&]C86P@(5=I:VE086=E(')E9F5R96YC92!I
M;B!F<F5E(&QI;FL@9F]R;6%T+B`@?'P@>WMP86=E?7TL('M[=&5X='U]+"![
M>V%N8VAO<GU]('Q\"GQ\('M[:&5A9&EN9WU]("`@("`@("`@("!\?"!!(&AE
M861I;F<N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('Q\('M[='EP93I;<W1A<G1\96YD72P@;&5V96PL('1E>'1]?2!\?`I\?"![
M>VAO<FEZ?7T@("`@("`@("`@("`@?'P@02!H;W)I>F]N=&%L(')U;&4N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\?"`M('Q\"GQ\('M[:'1M
M;'U]("`@("`@("`@("`@("!\?"!!(&)L;V-K(&]F($A434P@=&5X="!T;R!B
M92!D:7-P;&%Y960@87,M:7,N("`@("`@('Q\('M[=&5X='U]("!\?`I\?"![
M>VEN=&5R=VEK:7U]("`@("`@("`@?'P@06X@(4EN=&5R5VEK:2!R969E<F5N
M8V4N("`@("`@("`@("`@("`@("`@("`@("`@("!\?"![>W-I=&5]?2P@>WMP
M86=E?7T@?'P*?'P@>WMI=&%L:6-]?2`@("`@("`@("`@('Q\($ET86QI8R!T
M97AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?'P@
M>WMT>7!E.EMS=&%R='QE;F1=?7T@?'P*?'P@>WML:7-T?7T@("`@("`@("`@
M("`@('Q\($)U;&QE="!O<B!N=6UB97(@;&ES="!E;&5M96YT<RX@("`@("`@
M("`@("`@("`@("`@?'P@>WMT>7!E.EMB=6QL971\;G5M8F5R?&ET96U=7UMS
M=&%R='QE;F1=+"!L979E;"P@8V]U;G1]?2!\?`I\?"![>VYE=VQI;F5]?2`@
M("`@("`@("`@?'P@02!N97<@;&EN92!O<B!L:6YE(&)R96%K+B`@("`@("`@
M("`@("`@("`@("`@("`@("!\?"`M('Q\"GQ\('M[<&AP8V]D97U]("`@("`@
M("`@("!\?"!!(&)L;V-K(&]F(%!(4"!C;V1E('1O(&)E(&-O;&]R:7IE9"X@
M("`@("`@("`@("`@('Q\('M[=&5X='U]('Q\"GQ\('M[<&AP;&]O:W5P?7T@
M("`@("`@("!\?"!!(&9U;F-T:6]N(&YA;64@=&\@;&EN:R!T;R!A="!P:'`N
M;F5T("`@("`@("`@("`@('Q\('M[=&5X='U]('Q\"GQ\('M[<F%W?7T@("`@
M("`@("`@("`@("!\?"!287<@;W(@<&QA:6X@=&5X="!T;R!B92!D:7-P;&%Y
M960@87,M:7,N("`@("`@("`@('Q\('M[=&5X='U]('Q\"GQ\('M[<W1R;VYG
M?7T@("`@("`@("`@("!\?"!3=')O;F<@*'5S=6%L;'D@8F]L9"D@=&5X="X@
M("`@("`@("`@("`@("`@("`@("`@('Q\('M[='EP93I;<W1A<G1\96YD77U]
M('Q\"GQ\('M[<W5P97)S8W)I<'1]?2`@("`@("!\?"!3=7!E<G-C<FEP="!T
M97AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('Q\('M[='EP
M93I;<W1A<G1\96YD77U]('Q\"GQ\('M[=&%B;&5]?2`@("`@("`@("`@("!\
M?"!486)L92!E;&5M96YT<RX@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('Q\('M[='EP93I;=&%B;&5\<F]W?&-E;&Q=7UMS=&%R='QE;F1=
M+"!C;VQS<&%N?7T@?'P*?'P@>WMT='U]("`@("`@("`@("`@("`@('Q\(%1E
M;&5T>7!E("AM;VYO<W!A8V5D*2!T97AT+B`@("`@("`@("`@("`@("`@?'P@
M>WMT>7!E.EMS=&%R='QE;F1=?7T@?'P*?'P@>WMU<FQ]?2`@("`@("`@("`@
M("`@('Q\($$@<&%G92!54DPN("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?'P@>WMT>7!E.EMI;FQI;F5\9F]O=&YO=&5\9&5S8W)=
M?7TL('M[:')E9GU]+"![>W1E>'1]?2!\?`I\?"![>W=I:VEL:6YK?7T@("`@
M("`@("`@?'P@02!L;V-A;"`A5VEK:5!A9V4@<F5F97)E;F-E+B`@("`@("`@
M("`@("`@("`@("`@("!\?"![>W!A9V5]?2P@>WMA;F-H;W)]?2!\?`I\?"![
M>W1O8WU]("`@("`@("`@("`@("`@?'P@5&%B;&4@;V8@8V]N=&5N=',N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\?"![>W1Y<&4Z6VQI<W1?
M<W1A<G1\;&ES=%]E;F1\:71E;5]S=&%R='QI=&5M7V5N9'QT87)G971=+"!L
M979E;"P@8V]U;G1]?2!\?`H**RL@5&]K96YS($5N=')Y($9O<FUA=`H*4VEM
M<&QE(&9O<FUA="`H;F\@;W!T:6]N<RDN"@H\8V]D93X*)%]T;VME;G-;72`]
M($%R<F%Y"B`@("`H"B`@("`@("`@6S!=(#T^("=R=6QE7VYA;64G"B`@("`@
M("`@6S%=(#T^(&%R<F%Y"B`@("`@("`@("`@("@*("`@("`@("`@("`@*0H@
M("`@*0H\+V-O9&4^"@I#;VUP;&5X(&9O<FUA="`H=VET:"!O<'1I;VYS*2X*
M"CQC;V1E/@HD7W1O:V5N<UM=(#T@07)R87D*("`@("@*("`@("`@("!;,%T@
M/3X@)W)U;&5?;F%M92<*("`@("`@("!;,5T@/3X@07)R87D*("`@("`@("`@
M("`@*`H@("`@("`@("`@("`@("`@6R=O<'0P)UT@/3X@)W9A;'5E(#`G"B`@
M("`@("`@("`@("`@("!;)V]P=#$G72`]/B`G=F%L=64@,2<*("`@("`@("`@
M("`@("`@("XN+@H@("`@("`@("`@("`@("`@6R=O<'1.)UT@/3X@)W9A;'5E
M($XG"B`@("`@("`@("`@("D*("`@("D*/"]C;V1E/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O5&5X=%]7
M:6MI+V1O8W,O2&]M95!A9V4N=VEK:2YT>'0`````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U
M-S`P`#$P-#$W,S8S,#`T`#`R-#,R,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````K(%1E>'1?5VEK:0H*)2543T,E)0H**RL@
M3W9E<G9I97<@86YD($)A8VMG<F]U;F0*"E=E(&%S<W5M92!Y;W4@:VYO=R!W
M:&%T(%MH='1P.B\O8S(N8V]M+V-G:2]W:6MI(%=I:VE=(&ES+B`@5&AE(%=I
M:VD@5V%Y(&5N=&%I;',@82!L;W0@;6]R92!T:&%N(&IU<W0@<G5L97,@9F]R
M('-T<G5C='5R960M=&5X="!M87)K=7`L(&)U="!T:&%T)W,@=&AE(&]N;'D@
M<&%R="!O9B!T:&4@5VEK:2!787D@=&AA="!T:&ES('!A8VMA9V4L('M[5&5X
M=%]7:6MI?7TL(&ES(&-O;F-E<FYE9"!W:71H+@H*5&AE('M[5&5X=%]7:6MI
M?7T@<&%C:V%G92!A;&QO=W,@>6]U('1O('1R86YS9F]R;2!T97AT('-T<G5C
M='5R960@=7-I;F<@5VEK:2!R=6QE<R!I;G1O(&%N>2!D969I;F5D('1A<F=E
M="!O=71P=70@9F]R;6%T+B!&;W(@97AA;7!L92P@>6]U(&-A;B!C;VYV97)T
M+BXN"@HJ(%1A=FDM<W1Y;&4@5VEK:2!T97AT(&EN=&\@6$A434P**B!/<FEG
M:6YA;"!#,BUS='EL92!7:6MI('1E>'0@:6YT;R!834P**B`A365A=$)A;&P@
M<W1Y;&4@5VEK:2!T97AT(&EN=&\@(4QA5&58"BH@06YY(&]T:&5R(%=I:VD@
M;6%R:W5P(')U;&5S(&EN=&\@86YY(&]T:&5R(&9O<FUA="`H<')O=FED960@
M:70G<R!P<F]G<F%M;65D('!R;W!E<FQY(#LM*0H*>WM497AT7U=I:VE]?2!A
M8VAI979E<R!T:&ES(&QE=F5L(&]F(&9L97AI8FEL:71Y(&)Y('5S:6YG(&]N
M92!C;&%S<R!P97(@=')A;G-F;W)M871I;VX@<G5L92P@:6YS=&5A9"!O9B!U
M<VEN9R!A(&UO;F]L:71H:6,@<V5T(&]F(&9U;F-T:6]N<RX@($5A8V@@5&5X
M=%]7:6MI(')U;&4@:&%S('1H97-E(&UE=&AO9',Z"@HJ($$@8V]N<W1R=6-T
M;W(@=&AA="!L:6YK<R!B86-K('1O('1H92`B;6%S=&5R(B!497AT7U=I:VD@
M8VQA<W,L('=H:6-H('1H92!S;W5R8V4@=&5X="!A<R!W96QL(&%S(&%N>2!O
M<'1I;VYA;"!C;VYF=6=R871I;VX@<&%R86UE=&5R<PHJ($$@<&%R<V4H*2!M
M971H;V0@=&AA="!L;V]K<R!T:')O=6=H('1H92!S;W5R8V4@=&5X="!F;W(@
M<W1R:6YG<R!T:&%T(&UA=&-H(&$@<F5G=6QA<B!E>'!R97-S:6]N"BH@02!P
M<F]C97-S*"D@;65T:&]D('1H870@=&%K97,@=&AE('!A<G-E9"!R96=U;&%R
M(&5X<')E<W-I;VX@;6%T8VAE<R!A;F0@8V]N=F5R=',@=&AE;2!T;R!A;B!I
M;G1E<FUE9&EA=&4@(FUE=&$M9F]R;6%T(B`H9V5N97)A;&QY(&$@9&5L:6UI
M=&5D('1O:V5N('1H870@:7,@<F4M:6YS97)T960@:6YT;R!T:&4@<V]U<F-E
M('1E>'0L(&%L;VYG('=I=&@@82!S970@;V8@;W!T:6]N<R!F;W(@=&AA="!S
M<&5C:69I8R!T;VME;BD**B!!(')E;F1E<B@I(&UE=&AO9"!T:&%T(')E<&QA
M8V5S(&$@<V%V960@=&]K96X@=VET:"!O=71P=70@9F]R(&$@<W!E8VEF:6,@
M=&%R9V5T(&9O<FUA="`H92YG+BP@6$A434P@;W(@(4QA5&58*2X*"GM[5&5X
M=%]7:6MI?7T@9')A=W,@:71S(&EN<W!I<F%T:6]N(&9R;VT@82!N=6UB97(@
M;V8@8V]D96)A<V5S+"!M;W-T(&YO=&%B;'D@(5=I:VMI5&EK:VE4879I(&%N
M9"!C;U=I:VD[('=H:6QE(&YO(&-O9&4@:&%S(&)E96X@9&ER96-T;'D@8V]P
M:65D(&9R;VT@=&AO<V4@8V]D96)A<V5S+"!T:&5Y('=E<F4@:6YD:7-P96YS
M:6)L92!I;B!L96%R;FEN9R!H;W<@=&\@<')O8V5S<R!7:6MI('1E>'0N"@I!
M;'-O('-E92!T:&5S92!P86=E<R!F;W(@;6]R92!I;F9O<FUA=&EO;CH*"BH@
M4V%M<&QE4&%G92`M+2!F;W(@82!F=6QL(&QI<W0@;V8@9&5F875L="!M87)K
M=7`@<G5L97,**B!4;VME;E)U;&5+97ES("TM(&9O<B!A(&QI<W0@;V8@=&AE
M('1O:V5N<R!K97ES(&=E;F5R871E9"!B>2!D:69F97)E;G0@<G5L97,**B!4
M97AT5VEK:5!R;W!O<V%L("TM(&$@;6]D:69I960@=F5R<VEO;B!O9B!T:&4@
M:6YI=&EA;"!497AT7U=I:VD@<')O<&]S86P@=&\@4$5!4@H**RL@5VAA="!4
M97AT7U=I:VD@1&]E<R!.;W0@1&\*"E1H92![>U1E>'1?5VEK:7U]('!A8VMA
M9V4@9&]E<R!N;W0@:6UP;&5M96YT('-T;W)A9V4L('-A=FEN9RP@961I=&EN
M9RP@9&EF9G,L('!A9V4@8V]U;G1S+"!A;F0@<V\@;VXN("!4:&]S92!F=6YC
M=&EO;G,@87)E(&UO<F4@<')O<&5R;'D@=&AE(&1O;6%I;B!O9B!A(&9U;&P@
M5VEK:2!A<'!L:6-A=&EO;B!A;F0@96YV:7)O;FUE;G0L('=H:6-H(&ES(&]U
M='-I9&4@=&AE('-T871E9"![>U1E>'1?5VEK:7U](&=O86QS("AI+F4N+"!T
M;R!T<F%N<V9O<FT@5VEK:2!T97AT(&%C8V]R9&EN9R!T;R!D969I;F5D(')U
M;&5S(&9O<B!A('1A<F=E="!O=71P=70@9F]R;6%T*2X*"BLK(%5S:6YG(%1E
M>'1?5VEK:0H*2&5R92!I<R!A('%U:6-K(&5X86UP;&4@;V8@:&]W('1O('5S
M92![>U1E>'1?5VEK:7U]('1O('!A<G-E(&9R;VT@=&AE(&1E9F%U;'0@;6%R
M:W5P('-T>6QE("AC;VUB:6YE9"!F<F]M(%MH='1P.B\O=&%V:2YS;W5R8V5F
M;W)G92YN970O(%1A=FE=(&%N9"!;:'1T<#HO+V1E=F5L;F5T+F]R9R\@8V]7
M:6MI72DL(&1O('-O;64@8F%S:6,@9FEL=&5R:6YG+"!A;F0@<F5N9&5R('1O
M(%A(5$U,+@H*/'!H<#X*"0H)+R\@<F5Q=6ER92!T:&4@5&5X=%]7:6MI(&-L
M87-S(&%N9"!C<F5A=&4@86X@:6YS=&%N8V4@;V8@82!N97<@=VEK:0H)+R\@
M<&%R<V4M86YD+7)E;F1E<B!O8FIE8W0*"7)E<75I<F5?;VYC92`G5&5X="]7
M:6MI+G!H<"<["@DD=VEK:2`](&YE=R!497AT7U=I:VDH*3L*"0H)+R\@;&]A
M9"!U<"!S;VUE('-O=7)C92!T97AT"@DD=&5X="`](&9I;&5?9V5T7V-O;G1E
M;G1S*"=S86UP;&4N=VEK:2YT>'0G*3L*"0H)+R\@=')A;G-F;W)M('1H92!T
M97AT('5S:6YG('1H92!D969A=6QT(')U;&5S(&9O<B!P87)S:6YG(&%N9"!R
M96YD97)I;F<N"@DO+R!T:&4@97AT<F$@7&X@;F5W;&EN97,@<V5E;2!T;R!H
M96QP('=I=&@@<V]M92!P87)S:6YG(')U;&5S+@H)96-H;R`D=VEK:2T^=')A
M;G-F;W)M*")<;B(@+B`D=&5X="`N(")<;B(I.PH)"CPO<&AP/@H*"@HK*R!4
M97AT7U=I:VD@3W!T:6]N<PH*5VAE;B!Y;W4@8W)E871E(&%N(&EN<W1A;F-E
M(&]F(%1E>'1?5VEK:2P@>6]U(&-A;B!P87-S(&$@<V5T(&]F(&]P=&EO;G,@
M87,@86X@87-S;V-I871I=F4@87)R87DN(`H*5&AE(&%R<F%Y(&ME>7,@9F]R
M('1H92!O<'1I;VYS(&%R93H*"GQ\("<G)V]P=&EO;B!K97DG)R<@?'P@)R<G
M=F%R:6%B;&4@='EP92<G)R!\?"`G)R=D97-C<FEP=&EO;B<G)R!\?`I\?"![
M>V1E;&EM?7T@("`@("`@('Q\('-T<FEN9R`@("`@("`@("`@("`@?'P@=&AE
M('-O=7)C92!T97AT(&1E;&EM:71E<B!F;W(@=&]K96YS('Q\"GQ\('M[:6YT
M97)W:6MI?7T@("`@?'P@87)R87D@("`@("`@("`@("`@("!\?"!I;G1E<G=I
M:VD@<VET92!N86UE<R!A;F0@55),<R!\?`I\?"![>VYE=U]T97AT?7T@("`@
M('Q\('-T<FEN9R`@("`@("`@("`@("`@?'P@;&EN:RUT97AT(&9O<B!N97<@
M<&%G97,@?'P*?'P@>WMN97=?=7)L?7T@("`@("!\?"!S=')I;F<@("`@("`@
M("`@("`@('Q\(%523"!F;W(@;F5W('!A9V5S('Q\"GQ\('M[<&%G97-]?2`@
M("`@("`@?'P@87)R87D@("`@("`@("`@("`@("!\?"!L:7-T(&]F('!A9V5S
M(&5X:7-T:6YG(&EN('1H92!W:6MI('Q\"GQ\('M[<G5L97-]?2`@("`@("`@
M?'P@87)R87D@("`@("`@("`@("`@("!\?"!T:&4@;&ES="!O9B!R=6QE<R!T
M;R!B92!A<'!L:65D('1O('-O=7)C92!T97AT('Q\"GQ\('M[=FEE=U]U<FQ]
M?2`@("`@?'P@<W1R:6YG("`@("`@("`@("`@("!\?"!54DP@9F]R('9I97=I
M;F<@<&%G97,@:6X@=&AE('=I:VD@?'P*"D9O<B!E>&%M<&QE.@H*/'!H<#X*
M"2\O('1H92!L:7-T(&]F(')U;&5S+"!A;F0@:6X@=VAI8V@@;W)D97(L('1O
M('5S92!W:&5N"@DO+R!T<F%N<V9O<FUI;F<@<W1R=6-T=7)E9"!T97AT.R!T
M:&4@:V5Y(&ES('1H92!N86UE('1O('5S92!F;W(*"2\O(&ED96YT:69Y:6YG
M('1O:V5N<R!F;W(@=&AE(')U;&4L(&%N9"!T:&4@=F%L=64@:7,@=&AE(&9I
M;&4*"2\O(&YA;64@;V8@=&AE(')U;&4@8VQA<W,N"@DD<G5L97,@/2!A<G)A
M>2@*("`@("`@("`G<')E9FEL=&5R)R`@(#T^("=497AT+U=I:VDO4G5L92]P
M<F5F:6QT97(N<&AP)RP*("`@("`@("`G9&5L:6UI=&5R)R`@(#T^("=497AT
M+U=I:VDO4G5L92]D96QI;6ET97(N<&AP)RP*("`@("`@("`G8V]D92<@("`@
M("`@(#T^("=497AT+U=I:VDO4G5L92]C;V1E+G!H<"<L"B`@("`@("`@)W!H
M<&-O9&4G("`@("`]/B`G5&5X="]7:6MI+U)U;&4O<&AP8V]D92YP:'`G+`H@
M("`@("`@("=H=&UL)R`@("`@("`@/3X@)U1E>'0O5VEK:2]2=6QE+VAT;6PN
M<&AP)RP*("`@("`@("`G:&5A9&EN9R<@("`@(#T^("=497AT+U=I:VDO4G5L
M92]H96%D:6YG+G!H<"<L"B`@("`@("`@)VAO<FEZ)R`@("`@("`]/B`G5&5X
M="]7:6MI+U)U;&4O:&]R:7HN<&AP)RP*("`@("`@("`G8FQO8VMQ=6]T92<@
M(#T^("=497AT+U=I:VDO4G5L92]B;&]C:W%U;W1E+G!H<"<L"B`@("`@("`@
M)V1E9FQI<W0G("`@("`]/B`G5&5X="]7:6MI+U)U;&4O9&5F;&ES="YP:'`G
M+`H@("`@("`@("=T86)L92<@("`@("`@/3X@)U1E>'0O5VEK:2]2=6QE+W1A
M8FQE+G!H<"<L"B`@("`@("`@)VQI<W0G("`@("`@("`]/B`G5&5X="]7:6MI
M+U)U;&4O;&ES="YP:'`G+`H@("`@("`@("=T;V,G("`@("`@("`@/3X@)U1E
M>'0O5VEK:2]2=6QE+W1O8RYP:'`G+`H@("`@("`@("=P87)A9W)A<&@G("`@
M/3X@)U1E>'0O5VEK:2]2=6QE+W!A<F%G<F%P:"YP:'`G+`H@("`@("`@("=R
M87<G("`@("`@("`@/3X@)U1E>'0O5VEK:2]2=6QE+W)A=RYP:'`G+`H@("`@
M("`@("=P:'!L;V]K=7`G("`@/3X@)U1E>'0O5VEK:2]2=6QE+W!H<&QO;VMU
M<"YP:'`G+`H@("`@("`@("=U<FPG("`@("`@("`@/3X@)U1E>'0O5VEK:2]2
M=6QE+W5R;"YP:'`G+`H@("`@("`@("=I;G1E<G=I:VDG("`@/3X@)U1E>'0O
M5VEK:2]2=6QE+VEN=&5R=VEK:2YP:'`G+`H@("`@("`@("=F<F5E;&EN:R<@
M("`@/3X@)U1E>'0O5VEK:2]2=6QE+V9R965L:6YK+G!H<"<L"B`@("`@("`@
M)W=I:VEL:6YK)R`@("`]/B`G5&5X="]7:6MI+U)U;&4O=VEK:6QI;FLN<&AP
M)RP*("`@("`@("`G<W1R;VYG)R`@("`@(#T^("=497AT+U=I:VDO4G5L92]S
M=')O;F<N<&AP)RP*("`@("`@("`G8F]L9"<@("`@("`@(#T^("=497AT+U=I
M:VDO4G5L92]B;VQD+G!H<"<L"B`@("`@("`@)V5M<&AA<VES)R`@("`]/B`G
M5&5X="]7:6MI+U)U;&4O96UP:&%S:7,N<&AP)RP*("`@("`@("`G:71A;&EC
M)R`@("`@(#T^("=497AT+U=I:VDO4G5L92]I=&%L:6,N<&AP)RP*("`@("`@
M("`G='0G("`@("`@("`@(#T^("=497AT+U=I:VDO4G5L92]T="YP:'`G+`H@
M("`@("`@("=S=7!E<G-C<FEP="<@/3X@)U1E>'0O5VEK:2]2=6QE+W-U<&5R
M<V-R:7!T+G!H<"<L"B`@("`@("`@)W)E=FES92<@("`@("`]/B`G5&5X="]7
M:6MI+U)U;&4O<F5V:7-E+G!H<"<L"B`@("`@("`@)V5N=&ET:65S)R`@("`]
M/B`G5&5X="]7:6MI+U)U;&4O96YT:71I97,N<&AP)RP*("`@("`@("`G=&EG
M:'1E;B<@("`@(#T^("=497AT+U=I:VDO4G5L92]T:6=H=&5N+G!H<"<*"2D[
M"@D*"2\O('1H92!L:7-T(&]F($EN=&5R5VEK:2!N86UE<R!A;F0@55),<PH)
M)&EN=&5R=VEK:2`](&%R<F%Y*`H)"2=-96%T0F%L;"<@/3X@)VAT='`Z+R]W
M=W<N=7-E;6]D+F-O;2]C9VDM8FEN+VUB+G!L/R<L"@D))T%D=F]G871O)R`]
M/B`G:'1T<#HO+V%D=F]G871O+F]R9R\G+`H)"2=7:6MI)R`@("`@/3X@)VAT
M='`Z+R]C,BYC;VTO8V=I+W=I:VD_)PH)*3L*"0H)+R\@=&AE(%523"!U<V5D
M('1O('9I97<@;&]C86P@5VEK:5=E8B!P86=E<PH))'9I97=?=7)L(#T@(FAT
M='`Z+R]E>&%M<&QE+F-O;2]W:6MI+G!H<#]P86=E/2(["@D*"2\O(&-R96%T
M92!A(%1E>'1?5VEK:2!O<'1I;VYS(&%R<F%Y"@DD;W!T:6]N<R`](&%R<F%Y
M*`H)"2=R=6QE<R<@("`@(#T^("1R=6QE<RP*"0DG:6YT97)W:6MI)R`]/B`D
M:6YT97)W:6MI+`H)"2=V:65W7W5R;"<@(#T^("1V:65W7W5R;`H)*3L*"0H)
M+R\@:6YS=&%N=&EA=&4@82!497AT7U=I:VD@;V)J96-T('=I=&@@=&AE(&]P
M=&EO;G,*"21W:6MI(#TF(&YE=R!497AT7U=I:VDH)&]P=&EO;G,I.PH\+W!H
M<#X*"@H**RLK('M[9&5L:6U]?0H*5&AE('M[9&5L:6U]?2!O<'1I;VX@:7,@
M82!S=')I;F<L(&%N9"!S971S('1H92!V86QU92!O9B!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<B!U<V5D('1O(&UA<FL@82!T;VME;B!N=6UB97(@:6X@=&AE
M(%=I:VD@<V]U<F-E('1E>'0N("!7:&5N(&$@<G5L92!N965D<R!T;R!S970@
M82!T;VME;BP@:70@<F5P;&%C97,@=&AE('-O=7)C92!T97AT('=I=&@@82!T
M;VME;B!N=6UB97(@<W5R<F]U;F1E9"!B>2!T:&ES(&1E;&EM:71E<BX*"E1H
M92!D969A=6QT(&1E;&UI=&5R(&ES('M[8&!@7'A&1F!@8'U]+"!B=70@>6]U
M(&-A;B!C:&%N9V4@:70@=&\@86YY=&AI;F<@>6]U(&QI:V4N("!"92!A=V%R
M92!T:&%T('1H92!T;VME;B!Y;W4@8VAO;W-E(&UA>2!B92!S=6)J96-T('1O
M(%=I:VD@<G5L97,L('-O(&)E('-U<F4@=&\@8VAO;W-E('-O;65T:&EN9R!T
M:&%T('1H92!R=6QE<R!D;VXG="!A9F9E8W0N"@I&;W(@97AA;7!L93H*"CQP
M:'`^"@DO+R!U<V4@82!N=6QL8VAA<B!D96QI;6ET97(*"21O<'1I;VYS6R=D
M96QI;2==(#T@)UQX,#`G*3L*/"]P:'`^"@H*"BLK*R![>VEN=&5R=VEK:7U]
M"@I4:&4@>WMI;G1E<G=I:VE]?2!O<'1I;VX@:7,@86X@87-S;V-I871I=F4@
M87)R87D@=VAE<F4@=&AE(&ME>2!I<R!A;B`A26YT97)7:6MI('-I=&4@;F%M
M92P@86YD('1H92!V86QU92!I<R!T:&4@55),(&9O<B!P86=E<R!A="!T:&%T
M('-I=&4N("!&;W(@97AA;7!L92P@:68@>6]U('=A;G0@=&\@<F5F97(@=&\@
M=&AE("%-96%T0F%L;"!S:71E(&EN('EO=7(@<&%G97,@=7-I;F<@=&AE("%)
M;G1E<E=I:VD@<G5L92P@>6]U(&YE960@=&\@<&%S<R!T:&ES(&]P=&EO;BX*
M"CQP:'`^"@DO+R!N86UE(&%N9"!L:6YK('1O('1H92!-96%T0F%L;"!7:6MI
M"@DD;W!T:6]N<ULG:6YT97)W:6MI)UT@/2!A<G)A>2@*"0DG365A=$)A;&PG
M(#T^("=H='1P.B\O=W=W+G5S96UO9"YC;VTO8V=I+6)I;B]M8BYP;#\G"@DI
M.PH\+W!H<#X*"@H*"BLK*R![>VYE=U]T97AT?7T*"E1H92![>VYE=U]T97AT
M?7T@;W!T:6]N(&ES(&$@<W1R:6YG+B`@268@>6]U<B!W:6MI('-O=7)C92!T
M97AT(')E9F5R<R!T;R!A('!A9V4@=&AA="!D;V5S(&YO="!E>&ES="`H87,@
M<')O=FED960@8GD@=&AE('M[<&%G97-]?2!O<'1I;VXI('1H96X@:70@:7,@
M8V]N<VED97)E9"!T;R!B92!A(")N97<B('!A9V4[('1H=7,L('1H92!497AT
M7U=I:VD@=VEL;"!L:6YK('1O(&$@=V5B('!A9V4@9F]R(&-R96%T:6YG(&YE
M=R!P86=E<RX*"E1H92![>VYE=U]T97AT?7T@;W!T:6]N('-P96-I9FEE<R!T
M:&4@;&ET97)A;"!L:6YK960@=&5X="!T;R!B92!A<'!E;F1E9"!T;R!T:&4@
M<&%G92!N86UE(&]N(&1I<W!L87DN("!)="!C86X@8F4@=&5X="!P<F]P97(L
M(&]R(&%N($A434P@:6UA9V4@=&%G+"!O<B!A;GET:&EN9R!E;'-E+@H*4V5E
M(&%L<V\@=&AE('M[;F5W7W5R;'U](&]P=&EO;BX*"CQP:'`^"@DO+R!U<V4@
M82!Q=65S=&EO;B!M87)K(&%N9"!A('-P86-E"@DD;W!T:6]N<ULG;F5W7W1E
M>'0G72`]("<_("<["@D*"2\O('5S92!A;B!I;6%G90H))&]P=&EO;G-;)VYE
M=U]T97AT)UT@/2`G/&EM9R!S<F,](FAT='`Z+R]E>&%M<&QE+F-O;2]N97=P
M86=E+F=I9B`O/B<["CPO<&AP/@H*"@HK*RL@>WMN97=?=7)L?7T*"E1H92![
M>VYE=U]U<FQ]?2!O<'1I;VX@:7,@82!S=')I;F<N("!)9B!Y;W5R('=I:VD@
M<V]U<F-E('1E>'0@<F5F97)S('1O(&$@<&%G92!T:&%T(&1O97,@;F]T(&5X
M:7-T("AA<R!P<F]V:61E9"!B>2!T:&4@>WMP86=E<WU](&]P=&EO;BD@=&AE
M;B!I="!I<R!C;VYS:61E<F5D('1O(&)E(&$@(FYE=R(@<&%G93L@=&AU<RP@
M5&5X=%]7:6MI('=I;&P@;&EN:R!T;R!A('=E8B!P86=E(&9O<B!C<F5A=&EN
M9R!N97<@<&%G97,N"@I4:&4@>WMN97=?=7)L?7T@<W!E8VEF:65S('1H92!5
M4DP@=&\@=&AE(&%P<&QI8V%T:6]N+7-P96-I9FEC('!A9V4@8W)E871I;VX@
M=71I;&ET>2X*"E-E92!A;'-O('1H92![>VYE=U]T97AT?7T@;W!T:6]N+@H*
M/'!H<#X*"2\O(&QI;FL@=&\@=&AE(&YE=RUP86=E('-C<FEP=`H))&]P=&EO
M;G-;)VYE=U]U<FPG72`@/2`G:'1T<#HO+V5X86UP;&4N8V]M+VYE=W!A9V4N
M<&AP/W!A9V4])SL*/"]P:'`^"@H**RLK('M[<&%G97-]?0H*5&AE('M[<&%G
M97-]?2!O<'1I;VX@:7,@82!S97%U96YT:6%L(&%R<F%Y('=H97)E(&5A8V@@
M96QE;65N="!I<R!T:&4@;F%M92!O9B!P86=E(&EN('1H92!7:6MI+B`@4V5E
M(&%L<V\@=&AE('M[=FEE=U]U<FQ]?2!O<'1I;VXN"@H\<&AP/@H)+R\@;VYL
M>2!T:')E92!P86=E<R!I;B!T:&ES('=I:VD*"21O<'1I;VYS6R=P86=E<R==
M(#T@87)R87DH"@D))TAO;65086=E)RP*"0DG4V%M<&QE4&%G92<L"@D))U1O
M:V5N4G5L94ME>7,G"@DI"CPO<&AP/@H*"BLK*R![>W)U;&5S?7T*"E1H:7,@
M;W!T:6]N(&ES(&$@87-S;V-I871I=F4@87)R87D[(&ET('-P96-I9FEE<R!T
M:&4@<G5L92!N86UE<R!T;R!A<'!L>2!T;R!W:6MI('-O=7)C92!T97AT+B`@
M5&AE(&ME>2!I<R!T:&4@=&]K96X@;F%M92!T;R!B92!U<V5D('=H96X@:61E
M;FET9GEI;F<@=&5X="!M87)K960@8GD@=&AA="!R=6QE+"!A;F0@=&AE('9A
M;'5E(&ES('1H92!F:6QE(&YA;64@;V8@=&AE(')U;&4@8VQA<W,N("`H4')E
M=FEO=7-L>2P@<G5L92!C;&%S<R!N86UE<R!A;F0@<G5L92!F:6QE(&YA;65S
M(&AA9"!T;R!A9&AE<F4@=&\@82!S<&5C:69I8R!C;VYV96YT:6]N.R!T:&%T
M(&ES(&YO(&QO;F=E<B!N96-E<W-A<GDN*0H*/'!H<#X*"21O<'1I;VYS6R=R
M=6QE<R==(#T@87)R87DH"B`@("`@("`@)W!R969I;'1E<B<@("`]/B`G5&5X
M="]7:6MI+U)U;&4O<')E9FEL=&5R+G!H<"<L"B`@("`@("`@)V1E;&EM:71E
M<B<@("`]/B`G5&5X="]7:6MI+U)U;&4O9&5L:6UI=&5R+G!H<"<L"B`@("`@
M("`@)V-O9&4G("`@("`@("`]/B`G5&5X="]7:6MI+U)U;&4O8V]D92YP:'`G
M+`H@("`@("`@("=P:'!C;V1E)R`@("`@/3X@)U1E>'0O5VEK:2]2=6QE+W!H
M<&-O9&4N<&AP)RP*("`@("`@("`G:'1M;"<@("`@("`@(#T^("=497AT+U=I
M:VDO4G5L92]H=&UL+G!H<"<L"B`@("`@("`@)VAE861I;F<G("`@("`]/B`G
M5&5X="]7:6MI+U)U;&4O:&5A9&EN9RYP:'`G+`H@("`@("`@("=H;W)I>B<@
M("`@("`@/3X@)U1E>'0O5VEK:2]2=6QE+VAO<FEZ+G!H<"<L"B`@("`@("`@
M)V)L;V-K<75O=&4G("`]/B`G5&5X="]7:6MI+U)U;&4O8FQO8VMQ=6]T92YP
M:'`G+`H@("`@("`@("=D969L:7-T)R`@("`@/3X@)U1E>'0O5VEK:2]2=6QE
M+V1E9FQI<W0N<&AP)RP*("`@("`@("`G=&%B;&4G("`@("`@(#T^("=497AT
M+U=I:VDO4G5L92]T86)L92YP:'`G+`H@("`@("`@("=L:7-T)R`@("`@("`@
M/3X@)U1E>'0O5VEK:2]2=6QE+VQI<W0N<&AP)RP*("`@("`@("`G=&]C)R`@
M("`@("`@(#T^("=497AT+U=I:VDO4G5L92]T;V,N<&AP)RP*("`@("`@("`G
M<&%R86=R87!H)R`@(#T^("=497AT+U=I:VDO4G5L92]P87)A9W)A<&@N<&AP
M)RP*("`@("`@("`G<F%W)R`@("`@("`@(#T^("=497AT+U=I:VDO4G5L92]R
M87<N<&AP)RP*("`@("`@("`G<&AP;&]O:W5P)R`@(#T^("=497AT+U=I:VDO
M4G5L92]P:'!L;V]K=7`N<&AP)RP*("`@("`@("`G=7)L)R`@("`@("`@(#T^
M("=497AT+U=I:VDO4G5L92]U<FPN<&AP)RP*("`@("`@("`G:6YT97)W:6MI
M)R`@(#T^("=497AT+U=I:VDO4G5L92]I;G1E<G=I:VDN<&AP)RP*("`@("`@
M("`G9G)E96QI;FLG("`@(#T^("=497AT+U=I:VDO4G5L92]F<F5E;&EN:RYP
M:'`G+`H@("`@("`@("=W:6MI;&EN:R<@("`@/3X@)U1E>'0O5VEK:2]2=6QE
M+W=I:VEL:6YK+G!H<"<L"B`@("`@("`@)W-T<F]N9R<@("`@("`]/B`G5&5X
M="]7:6MI+U)U;&4O<W1R;VYG+G!H<"<L"B`@("`@("`@)V)O;&0G("`@("`@
M("`]/B`G5&5X="]7:6MI+U)U;&4O8F]L9"YP:'`G+`H@("`@("`@("=E;7!H
M87-I<R<@("`@/3X@)U1E>'0O5VEK:2]2=6QE+V5M<&AA<VES+G!H<"<L"B`@
M("`@("`@)VET86QI8R<@("`@("`]/B`G5&5X="]7:6MI+U)U;&4O:71A;&EC
M+G!H<"<L"B`@("`@("`@)W1T)R`@("`@("`@("`]/B`G5&5X="]7:6MI+U)U
M;&4O='0N<&AP)RP*("`@("`@("`G<W5P97)S8W)I<'0G(#T^("=497AT+U=I
M:VDO4G5L92]S=7!E<G-C<FEP="YP:'`G+`H@("`@("`@("=R979I<V4G("`@
M("`@/3X@)U1E>'0O5VEK:2]2=6QE+W)E=FES92YP:'`G+`H@("`@("`@("=E
M;G1I=&EE<R<@("`@/3X@)U1E>'0O5VEK:2]2=6QE+V5N=&ET:65S+G!H<"<L
M"B`@("`@("`@)W1I9VAT96XG("`@("`]/B`G5&5X="]7:6MI+U)U;&4O=&EG
M:'1E;BYP:'`G"@DI.PH\+W!H<#X*"E1H92!A8F]V92!I<R!T:&4@9&5F875L
M="!L:7-T(&]F(')U;&5S+B`@268@>6]U('=A;G0@=&\@=7-E('EO=7(@;W=N
M("AF;W(@97AA;7!L92D@>WMW:6MI;&EN:WU](')U;&4@=&\@;W9E<G)I9&4@
M=&AE(&1E9F%U;'0@<G5L92P@>6]U(&-A;B!R97!L86-E('1H92!A<G)A>2!E
M;&5M96YT('=I=&@@=&AE('!A=&@@=&\@>6]U<B!M;V1I9FEE9"!R=6QE.@H*
M/'!H<#X*"2\O(%MS;FEP72!S970@=7`@)&]P=&EO;G,*"21W:6MI(#TF(&YE
M=R!497AT7U=I:VDH)&]P=&EO;G,I.PH)"@DO+R!R97!L86-E('1H92`G=VEK
M:6QI;FLG(&1E9F%U;'0@<G5L90H))'=I:VDM/G)U;&5S6R=W:6MI;&EN:R==
M(#T@)R]P871H+W1O+VUY+W)U;&5S+VUY7W=I:VEL:6YK+G!H<"<["CPO<&AP
M/@H*"BLK*R![>W9I97=?=7)L?7T*"E1H92![>W9I97=?=7)L?7T@;W!T:6]N
M(&ES(&$@<W1R:6YG('1H870@<W!E8VEF:65S('1H92!54DP@=&\@=&AE(&%P
M<&QI8V%T:6]N+7-P96-I9FEC('!A9V4@=FEE=VEN9R!U=&EL:71Y+B`@268@
M>6]U<B!W:6MI('-O=7)C92!T97AT(')E9F5R<R!T;R!A('!A9V4@;&ES=&5D
M(&EN('1H92![>W!A9V5S?7T@;W!T:6]N(&%R<F%Y+"!T:&4@5&5X=%]7:6MI
M(')U;&5S(&9O<B`G=VEK:2<@86YD("=W:6MI9G)E96QI;FLG('=I;&P@8W)E
M871E(&$@;&EN:R!T;R!T:&%T('!A9V4@=7-I;F<@=&AI<R!54DPN"@H\<&AP
M/@H)+R\@;&EN:R!T;R!T:&4@<&%G92UV:65W:6YG('-C<FEP=`H))&]P=&EO
M;G-;)W9I97=?=7)L)UT@/2`G:'1T<#HO+V5X86UP;&4N8V]M+W=I:VDN<&AP
M/W!A9V4])SL*/"]P:'`^````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U1E>'1?5VEK:2]D;V-S+VEN9&5X
M+G!H<``````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,W-``Q,#0Q-S,V,S`P
M-``P,C(W-30`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I<F5?
M;VYC92`G5&5X="]7:6MI+G!H<"<["@H*+RHJ"BH@"BH@1V5T<R!M:6-R;W1I
M;64[(&9O<B!T:6UI;F<@:&]W(&QO;F<@:70@=&%K97,@=&\@<')O8V5S<R!C
M;V1E+@HJ(`HJ+PH*9G5N8W1I;VX@9V5T;6EC<F]T:6UE*"D*>R`*("`@(&QI
M<W0H)'5S96,L("1S96,I(#T@97AP;&]D92@B("(L;6EC<F]T:6UE*"DI.R`*
M("`@(')E='5R;B`H*&9L;V%T*21U<V5C("L@*&9L;V%T*21S96,I.R`*?0H*
M+R\@4V5T('5P('1H92!W:6MI(&]P=&EO;G,*)&]P=&EO;G,@/2!A<G)A>2@I
M.PHD;W!T:6]N<ULG=FEE=U]U<FPG72`](")I;F1E>"YP:'`_<&%G93TB.PH*
M"B\O($=E="!T:&4@;&ES="!O9B!E>&ES=&EN9R!W:6MI('!A9V5S+"!B87-E
M9"!O;B!T:&4@+G=I:VDN='AT"B\O(&9I;&5S(&EN('1H92!C=7)R96YT(&1I
M<F5C=&]R>2X*)&]P=&EO;G-;)W!A9V5S)UT@/2!A<G)A>2@I.PH*)&1I<B`]
M(&]P96YD:7(H9&ER;F%M92A?7T9)3$5?7RDI.PH*=VAI;&4@*"1F:6QE(#T@
M<F5A9&1I<B@D9&ER*2D@>PH@("`@:68@*'-U8G-T<B@D9FEL92P@+3DI(#T]
M("<N=VEK:2YT>'0G*2!["B`@("`@("`@)&]P=&EO;G-;)W!A9V5S)UU;72`]
M('-U8G-T<B@D9FEL92P@,"P@+3DI.PH@("`@?0I]"@IC;&]S961I<B@D9&ER
M*3L*"B\O('=H870@<&%G92!I<R!B96EN9R!R97%U97-T960_"FEF("AI<W-E
M="@D7T=%5%LG<&%G92==*2D@>PH@("`@)'!A9V4@/2`D7T=%5%LG<&%G92==
M.PI](&5L<V4@>PH@("`@)'!A9V4@/2`G2&]M95!A9V4G.PI]"@HO+R!L;V%D
M('1H92!T97AT(&9O<B!T:&4@<F5Q=65S=&5D('!A9V4*)'1E>'0@/2!I;7!L
M;V1E*"<G+"!F:6QE*"1P86=E("X@)RYW:6MI+G1X="<I*3L*"B\O(&-R96%T
M92!A(%=I:VD@;V)J97AT('=I=&@@=&AE(&QO861E9"!O<'1I;VYS"B1W:6MI
M(#T@;F5W(%1E>'1?5VEK:2@D;W!T:6]N<RD["@HO+R!T:6UE('1H92!O<&5R
M871I;VXL(&%N9"!T<F%N<V9O<FT@=&AE('=I:VD@=&5X="X*)&)E9F]R92`]
M(&=E=$UI8W)O5&EM92@I.PHD;W5T<'5T(#T@)'=I:VDM/G1R86YS9F]R;2@D
M=&5X="D["B1A9G1E<B`](&=E=$UI8W)O5&EM92@I.PHD=&EM92`]("AF;&]A
M="DD869T97(@+2`H9FQO870I)&)E9F]R93L*"B\O(&]U='!U="!T:&4@<&%G
M92$*/SX*/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM
M,2(@/SX*"CPA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A4
M34P@,2XP(%1R86YS:71I;VYA;"\O14XB"B`@("`@("`@(FAT='`Z+R]W=W<N
M=S,N;W)G+U12+WAH=&UL,2]$5$0O>&AT;6PQ+71R86YS:71I;VYA;"YD=&0B
M/@H@("`@("`@(`H\:'1M;"!X;6QN<STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY
M.2]X:'1M;"(@>&UL.FQA;F<](F5N(B!L86YG/2)E;B(^"@H@("`@/&AE860^
M"B`@("`@("`@/&UE=&$@:'1T<"UE<75I=CTB8V]N=&5N="UT>7!E(B!C;VYT
M96YT/2)T97AT+VAT;6P[(&-H87)S970]:7-O+3@X-3DM,2(@+SX*("`@("`@
M("`\=&ET;&4^5&5X=%]7:6MI.CH\/W!H<"!E8VAO("1P86=E(#\^/"]T:71L
M93X*("`@("`@("`\;&EN:R!R96P](G-T>6QE<VAE970B(&AR968](G-T>6QE
M<VAE970N8W-S(B!T>7!E/2)T97AT+V-S<R(@+SX*("`@(#PO:&5A9#X*("`@
M(`H@("`@/&)O9'D^"B`@("`@("`@/#]P:'`@96-H;R`D;W5T<'5T(#\^"B`@
M("`@("`@/#]P:'`@96-H;R`B/&AR("\^/'`^5')A;G-F;W)M960@:6X@)'1I
M;64@<V5C;VYD<RX\+W`^(B`_/@H@("`@/"]B;V1Y/@H\+VAT;6P^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R]497AT7U=I:VDO9&]C<R]3;6%S:%=O<F1S
M5&]G971H97(N=VEK:2YT>'0`````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P-#8`,3`T,3<S-C,P,#0`,#(V
M-#(T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%-M87-H('=O<F1S('1O9V5T:&5R('1O(&-R96%T92!A(&QI;FLN````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O5&5X=%]7:6MI+V1O8W,O5V]R9'-3;6%S:&5D5&]G971H97(N
M=VEK:2YT>'0``````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#0V`#$P-#$W,S8S,#`T`#`R-C<S-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!3;6%S:"!W;W)D
M<R!T;V=E=&AE<B!T;R!C<F5A=&4@82!L:6YK+@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]397)I86QI>F5R+P``````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,S`P-``P,C$Q,C(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O9&]C+P``````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`R,38V-P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE
M<B]D;V,O=&]D;RYT>'0`````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$T-30`,3`T
M,3<S-C,P,#0`,#(S,S<V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````%1/1$\@6$U,7U-E<FEA;&EZ97(Z"BTM+2TM+2TM+2TM
M+2TM+2TM+2TM"BT@9FEN9"!A('=A>2!T;R!D971E8W0@<F5F97)E;F-E<R!I
M;B!T:&4@<W1R=6-T=7)E(&%N9"!A9&0@:60O:61R968@871T<FEB=71E<PHM
M('-E<FEA;&EZ92!S;VUE(&]T:&5R('-T<G5C='5R97,L(&5S<&5C:6%L;'D@
M6%!A=&@@<F5T=7)N('9A;'5E<PHM('-E<FEA;&EZ97,@=&%G<R!W:71H(&%T
M=')I8G5T97,*("!A<G)A>2@*("`@("`@("`@(")?871T<FEB=71E<R(@/3X@
M87)R87DH(")F;V\B(#T^(")B87(B("DL"B`@("`@("`@("`B8VAI;&0B("`@
M("`@(#T^(")C;VYT96YT(@H@("`@("`@*3L*("!S97)I86QI>F5S('1O.@H@
M(#QA<G)A>2!F;V\](F)A<B(^"B`@("`\8VAI;&0^8V]N=&5N=#PO8VAI;&0^
M"B`@/"]A<G)A>3X*+2!C=7-T;VT@<V5R:6%L:7IA=&EO;B!O9B!O8FIE8W1S
M"BT@;F%M97-P86-E('-U<'!O<G0*"E1/1$\@6$U,7U5N<V5R:6%L:7IE<CH*
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HM(&%D9"!S=7!P;W)T('1O(&-O;G9E
M<G0@87)R87ES(&EN=&\@;V)J96-T<PHM('-U<'!O<G0@9F]R('AM;#IS<&%C
M92!A='1R:6)U=&4*+2!S970@='EP97,@9F]R(&-E<G1A:6X@=&%G<R`H;&EK
M92!I;B!P871#;VYF:6=U<F%T:6]N*0HM(&YA;65S<&%C92!S=7!P;W)T"BT@
M8W5S=&]M('5N<V5R:6%L:7IA=&EO;B!F;W(@;V)J96-T<R`H<W1A=&EC('5N
M<V5R:6%L:7IE*"D@;W(@9G)O;5A-3"@I(&UE=&AO9',I"BT@=6YS97)I86QI
M>F4@<F5F97)E;F-E<R!U<VEN9R!I9"]I9')E9@HM(&EM<&QE;65N="!C86QL
M8F%C:R!M96-H86YI<VT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R
M:6%L:7IE<B]E>&%M<&QE<R\`````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C,P,#0`,#(R-S0P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I
M=&A!='1R:6)U=&5S+G!H<``````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C(P,@`Q,#0Q-S,V,S`P-``P,S`S,S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]02%`*+RHJ
M"B`J(%A-3"!397)I86QI>F5R(&5X86UP;&4*("H*("H@5&AI<R!E>&%M<&QE
M(&1E;6]N<W1R871E<RP@:&]W(%A-3%]397)I86QI>F5R(&ES(&%B;&4*("H@
M=&\@<V5R:6%L:7IE('-C86QA<B!V86QU97,@87,@86X@871T<FEB=71E(&EN
M<W1E860@;V8@82!N97-T960@=&%G+@H@*@H@*B!4:&4@<V%M92!S=')U8W1U
M<F4@;&EK92!I;B!S97)I86QI>F5/8FIE8W0N<&AP(&ES('-E<FEA;&EZ960N
M"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE
M=#X*("HO"@H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G
M.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@(")I;F1E;G0B("`@("`@("`@("`@(#T^("(@("`@(BP*("`@("`@("`@
M("`@("`@("`@("`@("`@(FQI;F5B<F5A:R(@("`@("`@("`@/3X@(EQN(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@(F1E9F%U;'1486=.86UE(B`@("`@
M/3X@(G5N;F%M961)=&5M(BP*"0D)"0D)(G-C86QA<D%S071T<FEB=71E<R(@
M/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`O+R!T
M:&ES(&ES(&IU<W0@=&\@9V5T(&$@;F5S=&5D(&]B:F5C=`H@("`@)'!E87)%
M<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H:7,@:7,@:G5S="!A;B!E<G)O
M<B!O8FIE8W0G+#$R,RD["@D*("`@("1F;V\@("`@/2`@(&YE=R!S=&1#;&%S
M<SL*("`@(`H@("`@)&9O;RT^=F%L=64@/2`B37D@=F%L=64B.PH@("`@)&9O
M;RT^97)R;W(@/2`D<&5A<D5R<F]R.PH@("`@)&9O;RT^>&UL("`@/2`B8V]O
M;"(["B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R
M*"1O<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS
M97)I86QI>F4H)&9O;RD["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E
M("D@>PH)"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H
M*3L*"@D@("`@96-H;PDB/'!R93XB.PH)("`@('!R:6YT7W(H(&AT;6QS<&5C
M:6%L8VAA<G,H)'AM;"D@*3L*"2`@("!E8VAO"2(\+W!R93XB.PH@("`@?2!E
M;'-E('L*"0EE8VAO"2(\<')E/B(["@D)<')I;G1?<B@D<F5S=6QT*3L*"0EE
M8VAO"2(\+W!R93XB.PH)?0H*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ
M97(O97AA;7!L97,O<V5R:6%L:7IE3V)J96-T+G!H<```````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,W`#$P
M-#$W,S8S,#`T`#`R-C4V-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/U!(4`HO*BH*("H@5&AI<R!I<R!J=7-T(&$@8F%S
M:6,@97AA;7!L92!T:&%T('-H;W=S"B`J(&AO=R!O8FIE8W1S(&-A;B!B92!S
M97)I86QI>F5D('-O('1H97D@8V%N"B`J(&)E(&9U;&QY(')E<W1O<F5D(&QA
M=&5R+@H@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP
M+FYE=#X*("HO"@H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP
M:'`G.PH*("`@("\O('1H:7,@:7,@:G5S="!T;R!G970@82!N97-T960@;V)J
M96-T"B`@("`D<&5A<D5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G5&AI<R!I
M<R!J=7-T(&%N(&5R<F]R(&]B:F5C="<L,3(S*3L*("`@(`H@("`@)&]P=&EO
M;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@(FEN9&5N="(@
M("`@("`@("`]/B`B("`@("(L"B`@("`@("`@("`@("`@("`@("`@("`@(")L
M:6YE8G)E86LB("`@("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@(F1E9F%U;'1486=.86UE(B`]/B`B=6YN86UE9$ET96TB+`H@("`@("`@
M("`@("`@("`@("`@("`@("`B='EP94AI;G1S(B`@("`@(#T^('1R=64*("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D9F]O("`@(#T@("!N97<@
M<W1D0VQA<W,["B`@("`D9F]O+3YV86QU92`](")->2!V86QU92(["B`@("`D
M9F]O+3YE<G)O<B`]("1P96%R17)R;W(["B`@("`D9F]O+3YX;6P@("`](")C
M;V]L(CL*"B`@("`D9F]O+3YO8FH)/2!N97<@<W1D0VQA<W,["B`@("`D9F]O
M+3YA<G(@("`](&%R<F%Y*"D["B`@("`D9F]O+3YZ97)O("`](#`["B`@("`*
M("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS
M*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H
M)&9O;RD["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH)"21X
M;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*("`@('T*
M"B`@("!E8VAO"2(\<')E/B(["B`@("!P<FEN=%]R*"!H=&UL<W!E8VEA;&-H
M87)S*"1X;6PI("D["B`@("!E8VAO"2(\+W!R93XB.PH_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ
M95=I=&A!='1R:6)U=&5S+G!H<```````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$T-30`,3`T,3<S-C,P,#0`,#,P-S`W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_4$A0"B\J
M*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@:&]W('1O('!A<G-E(&%T=')I8G5T
M97,@9G)O;0H@*B!834P@=&%G<RX*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!3
M8VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B!`=7-E<R`@("!E>&%M<&QE+GAM
M;`H@*B\*"B`@("!R97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP
M)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`B<&%R<V5!='1R:6)U=&5S(B`@(#T^("!T<G5E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`B871T<FEB=71E<T%R<F%Y(B`@(#T^("!F86QS90H@
M("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@("\O("!B92!C87)E9G5L
M('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F<F]N="!O9B!T:&4@
M;F5W(&]P97)A=&]R(`H@("`@)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N
M<V5R:6%L:7IE<B@D;W!T:6]N<RD["@H@("`@+R\@=7-E<FEA;&EZ92!T:&4@
M9&]C=6UE;G0*("`@("1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA
M;&EZ92@B97AA;7!L92YX;6PB+"!T<G5E*3L@("`@"@H@("`@:68@*%!%05(Z
M.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("!E8VAO("`@(")%<G)O<CH@
M(B`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*("`@('T@96QS92!["B`@("`@
M("`@)&1A=&$@/2`D=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A
M*"D["@H@("`@("`@(&5C:&\)(CQP<F4^(CL*("`@("`@("!P<FEN=%]R*"`D
M9&%T82`I.PH@("`@("`@(&5C:&\)(CPO<')E/B(["B`@("!]"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I
M86QI>F57:71H1'1D+G!H<```````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W-3,`,3`T,3<S-C,P,#0`,#(V-S,S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@:&]W('1O(&%D9"!A($1O
M8U1Y<&4@1&5C;&%R871I;VX@=&\@=&AE(%A-3"!D;V-U;65N=`H@*@H@*B!`
M875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"@H@
M("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O
M<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(")I;F1E
M;G0B("`@("`]/B`B("`@("(L"B`@("`@("`@("`@("`@("`@("`@("`@(")L
M:6YE8G)E86LB("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M861D1&5C;"(@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M(F%D9$1O8W1Y<&4B(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@
M(")D;V-T>7!E(B`@("`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R:2<@/3X@)VAT='`Z+R]P
M96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,2XP)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VED)R`]/B`G+2\O
M4$A0+R]014%2+T141"!004-+04=%(#`N,2<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`@("`@
M("`@("D["B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI
M>F5R*"1O<'1I;VYS*3L*"B`@("`D9F]O("`@(#T@("!014%2.CIR86ES945R
M<F]R*")*=7-T(&$@=&5S="(L(#$R,S0I.R`@("`*("`@(`H@("`@)')E<W5L
M="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&9O;RD["B`@("`*("`@(&EF
M*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@("`@(&5C:&\@("`@(CQP<F4^
M(CL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I=&EE<R@D<V5R:6%L:7IE<BT^
M9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@("`@96-H;R`@("`B/"]P<F4^
M(CL*("`@('T*/SX````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE
M<R]E>&%M<&QE+GAM;```````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,C<`,3`T,3<S-C,P,#0`
M,#(U,3$R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QX;6P^#0H@("`@/'1E<W0@9F]O/2)B87(B/@T*("`@("`@("!497-T
M#0H@("`@("`@(#QT86<^=&5S=#PO=&%G/@T*("`@(#PO=&5S=#X-"CPO>&UL
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE
M5VET:$EN9&5N=&5D071T<FEB=71E<RYP:'```````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-34V`#$P-#$W,S8S,#`T`#`S,C`R,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/U!(4`HO
M*BH*("H@6$U,(%-E<FEA;&EZ97(@97AA;7!L90H@*@H@*B!4:&ES(&5X86UP
M;&4@9&5M;VYS=')A=&5S+"!H;W<@6$U,7U-E<FEA;&EZ97(@:7,@86)L90H@
M*B!T;R!S97)I86QI>F4@<V-A;&%R('9A;'5E<R!A<R!A;B!A='1R:6)U=&4@
M:6YS=&5A9"!O9B!A(&YE<W1E9"!T86<N"B`J"B`J($EN('1H:7,@97AA;7!L
M92!T86=S('=I=&@@;6]R92!T:&%N(&]N92!A='1R:6)U=&4@8F5C;VUE"B`J
M(&UU;'1I;&EN92!T86=S+"!A<R!E86-H(&%T=')I8G5T92!G971S('=R:71T
M96X@=&\@80H@*B!S97!A<F%T92!L:6YE(&%S("=I;F1E;G1!='1R:6)U=&5S
M)R!I<R!S970@=&\@)U]A=71O)RX*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!3
M8VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*("`@(')E<75I<F5?;VYC92`G
M6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`B:6YD96YT(B`@("`@("`@("`@("`]
M/B`B("`@("(L"B`@("`@("`@("`@("`@("`@("`@("`@(")L:6YE8G)E86LB
M("`@("`@("`@(#T^(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@(")T
M>7!E2&EN=',B("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`B9&5F875L=%1A9TYA;64B("`@("`]/B`B=6YN86UE9$ET96TB
M+`H@("`@("`@("`@("`@("`@("`@("`@("`B<V-A;&%R07-!='1R:6)U=&5S
M(B`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`B:6YD96YT071T
M<FEB=71E<R(@("`]/B`B7V%U=&\B"B`@("`@("`@("`@("`@("`@("`@*3L*
M("`@(`H@("`@+R\@=&AI<R!I<R!J=7-T('1O(&=E="!A(&YE<W1E9"!O8FIE
M8W0*("`@("1P96%R17)R;W(@/2!014%2.CIR86ES945R<F]R*"=4:&ES(&ES
M(&IU<W0@86X@97)R;W(@;V)J96-T)RPQ,C,I.PH)"B`@("`D9F]O("`@(#T@
M("!N97<@<W1D0VQA<W,["B`@("`*("`@("1F;V\M/G9A;'5E(#T@(DUY('9A
M;'5E(CL*("`@("1F;V\M/F5R<F]R(#T@)'!E87)%<G)O<CL*("`@("1F;V\M
M/GAM;"`@(#T@(F-O;VPB.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!8
M34Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["B`@("`*("`@("1R97-U;'0@/2`D
M<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH@("`@"B`@("!I9B@@)')E
M<W5L="`]/3T@=')U92`I('L*"0DD>&UL(#T@)'-E<FEA;&EZ97(M/F=E=%-E
M<FEA;&EZ961$871A*"D["@H)("`@(&5C:&\)(CQP<F4^(CL*"2`@("!P<FEN
M=%]R*"!H=&UL<W!E8VEA;&-H87)S*"1X;6PI("D["@D@("`@96-H;PDB/"]P
M<F4^(CL*("`@('T@96QS92!["@D)96-H;PDB/'!R93XB.PH)"7!R:6YT7W(H
M)')E<W5L="D["@D)96-H;PDB/"]P<F4^(CL*"7T*"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]S97)I86QI>F5);F1E>&5D07)R87DN<&AP````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,V-S<`
M,3`T,3<S-C,P,#0`,#(W-S4R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@9&5M
M;VYS=')A=&5S('1H92!U<V4@;V8*("H@;6]D92`]/B!S:6UP;&5X;6P*("H*
M("H@270@8V%N(&)E('5S960@=&\@<V5R:6%L:7IE(&%N(&EN9&5X960@87)R
M87D*("H@;&EK92!E>'0O<VEM<&QE>&UL(&1O97,L(&)Y('5S:6YG('1H92!N
M86UE"B`J(&]F('1H92!P87)E;G0@=&%G+"!W:&EL92!O;6ET=&EN9R!T:&ES
M('1A9RX*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H
M<"YN970^"B`J+PH@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP
M:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@(")I;F1E;G0B("`@("`@("`@/3X@(B`@("`B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`B;&EN96)R96%K(B`@("`@(#T^(")<;B(L"@D)"0D)
M"2)R;V]T3F%M92(@("`@("`@/3X@(G)D9CI21$8B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`B<F]O=$%T=')I8G5T97,B(#T^(&%R<F%Y*")V97)S:6]N
M(B`]/B`B,"XY,2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`B;6]D92(@
M("`@("`@("`@(#T^(")S:6UP;&5X;6PB"B`@("`@("`@("`@("`@("`@("`@
M*3L*("`@(`H@("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H
M)&]P=&EO;G,I.PH*("`@(`H@("`@)')D9B`@("`]("`@87)R87DH"@D)"0D)
M"2)C:&%N;F5L(B`]/B!A<G)A>2@*"0D)"0D)"0D)"0DB=&ET;&4B(#T^(")%
M>&%M<&QE(%)$1B!C:&%N;F5L(BP*"0D)"0D)"0D)"0DB;&EN:R(@(#T^(")H
M='1P.B\O=W=W+G!H<"UT;V]L<RYD92(L"@D)"0D)"0D)"0D)(FEM86=E(@D]
M/@EA<G)A>2@*"0D)"0D)"0D)"0D)"0D)"2)T:71L92()/3X@(D5X86UP;&4@
M:6UA9V4B+`H)"0D)"0D)"0D)"0D)"0D)(G5R;"()/3X)(FAT='`Z+R]W=W<N
M<&AP+71O;VQS+F1E+VEM86=E+F=I9B(L"@D)"0D)"0D)"0D)"0D)"0DB;&EN
M:R()/3X)(FAT='`Z+R]W=W<N<&AP+71O;VQS+F1E(@H)"0D)"0D)"0D)"0D)
M"0DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")I=&5M(B`@(#T^("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`)
M"0D)"0D)"0D)"6%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(`D)"0D)"0D)
M"0D)"2)T:71L92()/3X@(D5X86UP;&4@:71E;2(L"B`@("`@("`@("`@("`@
M("`@("`@"0D)"0D)"0D)"0D)(FQI;FLB"3T^(")H='1P.B\O97AA;7!L92YC
M;VTB"B`@("`@("`@("`@("`@("`@("`@"0D)"0D)"0D)"0DI+`H@("`@("`@
M("`@("`@("`@("`@(`D)"0D)"0D)"0D)87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@"0D)"0D)"0D)"0D)(G1I=&QE(@D]/B`B06YO=&AE<B!I=&5M(BP*
M("`@("`@("`@("`@("`@("`@("`)"0D)"0D)"0D)"0DB;&EN:R()/3X@(FAT
M='`Z+R]E>&%M<&QE+F-O;2(*("`@("`@("`@("`@("`@("`@("`)"0D)"0D)
M"0D)"2DL"B`@("`@("`@("`@("`@("`@("`@"0D)"0D)"0D)"0EA<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`)"0D)"0D)"0D)"0DB=&ET;&4B"3T^("))
M('1H:6YK('EO=2!G970@:70N+BXB+`H@("`@("`@("`@("`@("`@("`@(`D)
M"0D)"0D)"0D)"2)L:6YK(@D]/B`B:'1T<#HO+V5X86UP;&4N8V]M(@H@("`@
M("`@("`@("`@("`@("`@(`D)"0D)"0D)"0D)*0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D*"0D)"0D)"0D)"2D*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@
M("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D<F1F*3L*("`@
M(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@*2!["B`@("`@("`@96-H;R`@
M("`B/'!R93XB.PH@("`@("`@(&5C:&\@("`@:'1M;&5N=&ET:65S*"1S97)I
M86QI>F5R+3YG971397)I86QI>F5D1&%T82@I*3L*("`@("`@("!E8VAO("`@
M("(\+W!R93XB.PH@("`@?0H_/@``````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O
M97AA;7!L97,O=6YS97)I86QI>F5/8FIE8W0N<&AP````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#0S`#$P-#$W
M,S8S,#`T`#`R-S$R-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H;W=S(&AO
M=R!834Q?4V5R:6%L:7IE<B!A;F0@6$U,7U5N<V5R:6%L:7IE<@H@*B!W;W)K
M('1O9V5T:&5R+@H@*@H@*B!!('-T<G5C='5R92!I<R!S97)I86QI>F5D(&%N
M9"!L871E<B!I="=S('5N<V5R:6%L:7IE9"!F<F]M('1H90H@*B!R97-U;'1I
M;F<@6$U,(&1O8W5M96YT+@H@*@H@*B!`875T:&]R("!3=&5P:&%N(%-C:&UI
M9'0@/'-C:'-T0'!H<"YN970^"B`J+PH*("`@(')E<75I<F5?;VYC92`G6$U,
M+U-E<FEA;&EZ97(N<&AP)SL*("`@(')E<75I<F5?;VYC92`G6$U,+U5N<V5R
M:6%L:7IE<BYP:'`G.PH@("`@+R\@=&AI<R!I<R!J=7-T('1O(&=E="!A(&YE
M<W1E9"!O8FIE8W0*("`@("1P96%R17)R;W(@/2!014%2.CIR86ES945R<F]R
M*"=4:&ES(&ES(&IU<W0@86X@97)R;W(@;V)J96-T)RPQ,C,I.PH@("`@"B`@
M("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`B
M:6YD96YT(B`@("`@("`@(#T^("(@("`@(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@(FQI;F5B<F5A:R(@("`@("`]/B`B7&XB+`H@("`@("`@("`@("`@
M("`@("`@("`@("`B9&5F875L=%1A9TYA;64B(#T^(")U;FYA;65D271E;2(L
M"B`@("`@("`@("`@("`@("`@("`@("`@(")T>7!E2&EN=',B("`@("`@/3X@
M=')U90H@("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@("1F;V\@("`@
M/2`@(&YE=R!S=&1#;&%S<SL*("`@(`H@("`@)&9O;RT^=F%L=64@/2`B37D@
M=F%L=64B.PH@("`@)&9O;RT^97)R;W(@/2`D<&5A<D5R<F]R.PH@("`@)&9O
M;RT^>&UL("`@/2!A<G)A>2@@(E1H:7,@:7,B(#T^(")C;V]L(B`I.PH@("`@
M)&9O;RT^<F5S;W5R8V4@("`](&9O<&5N*"`B+BXO<&%C:V%G92YX;6PB+"`B
M<B(@*3L*("`@(`H@("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ
M97(H)&]P=&EO;G,I.PH@("`@"B`@("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M
M/G-E<FEA;&EZ92@D9F]O*3L*("`@(`H@("`@:68H("1R97-U;'0@/3T]('1R
M=64@*2!["@D))'AM;"`]("1S97)I86QI>F5R+3YG971397)I86QI>F5D1&%T
M82@I.PH@("`@?0H*("`@(&5C:&\)(CQP<F4^(CL*("`@('!R:6YT7W(H(&AT
M;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*("`@(&5C:&\)(CPO<')E/B(["B`@
M("`*("`@("\O("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R
M<V%N9"!I;B!F<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R(`H@("`@)'5N<V5R
M:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@I.PH*("`@("1S=&%T
M=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L@("`@"@H@
M("`@:68@*%!%05(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("!E8VAO
M("`@(")%<G)O<CH@(B`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*("`@('T@
M96QS92!["B`@("`@("`@)&1A=&$@/2`D=6YS97)I86QI>F5R+3YG9715;G-E
M<FEA;&EZ961$871A*"D["@H@("`@("`@(&5C:&\)(CQP<F4^(CL*("`@("`@
M("!V87)?9'5M<"@@)&1A=&$@*3L*("`@("`@("!E8VAO"2(\+W!R93XB.PH@
M("`@?0H_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP
M;&5S+W5N<V5R:6%L:7IE4D1&+G!H<``````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#0Q,0`Q,#0Q-S,V,S`P
M-``P,C8S,S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L92!S:&]W<R!H;W<@=&\@
M8W)E871E(&%N>2!O8FIE8W0*("H@9G)O;2!A;B!834P@9&]C=6UE;G0N($EN
M('1H:7,@8V%S92!W92!G970*("H@<V]M92!A9V=R96=A=&5D(&]B:F5C=',@
M9F]R(&-H86YN96P@86YD(&ET96US"B`J(&9R;VT@86X@4E-3(&9E960N"B`J
M"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*
M("HO"@H@("`@<F5Q=6ER95]O;F-E("<N+B]5;G-E<FEA;&EZ97(N<&AP)SL*
M"B`@("\J*@H@("`@*B!C;&%S<R!F;W(@=&AE(%)$1B!D;V-U96UN=`H@("`@
M*@H@("`@*@H@("`@*B\*("`@(&-L87-S(')D9D1O8W5M96YT"B`@("!["B`@
M("`@("`@=F%R("1C:&%N;F5L.PH@("`@("`@('9A<B`D:71E;3L*"B`@("`@
M("`@9G5N8W1I;VX@9V5T271E;7,H)&%M;W5N="D*("`@("`@("!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>5]S<&QI8V4H)'1H:7,M/FET96TL,"PD86UO
M=6YT*3L*("`@("`@("!]"B`@("!]"@H*("`@+RHJ"B`@("`J(&-L87-S('1H
M870@:7,@=7-E9"!F;W(@82!C:&%N;F5L(&EN('1H92!24U,@9FEL90H@("`@
M*@H@("`@*B!Y;W4@8V]U;&0@:6UP;&5M96YT('=H871E=F5R('EO=2!L:6ME
M(&EN('1H:7,@8VQA<W,L"B`@("`J('!R;W!E<G1I97,@=VEL;"!B92!S970@
M9G)O;2!T:&4@6$U,(&1O8W5M96YT"B`@("`J+PH@("`@8VQA<W,@8VAA;FYE
M;`H@("`@>PH@("`@("`@(&9U;F-T:6]N(&=E=%1I=&QE*"D*("`@("`@("![
M"B`@("`@("`@("`@(')E='5R;B`@)'1H:7,M/G1I=&QE.PH@("`@("`@('T*
M("`@('T*("`@(`H@("`O*BH*("`@("H@8VQA<W,@=&AA="!I<R!U<V5D(&9O
M<B!A;B!I=&5M(&EN('1H92!24U,@9FEL90H@("`@*@H@("`@*B!Y;W4@8V]U
M;&0@:6UP;&5M96YT('=H871E=F5R('EO=2!L:6ME(&EN('1H:7,@8VQA<W,L
M"B`@("`J('!R;W!E<G1I97,@=VEL;"!B92!S970@9G)O;2!T:&4@6$U,(&1O
M8W5M96YT"B`@("`J+PH@("`@8VQA<W,@:71E;0H@("`@>PH@("`@("`@(&9U
M;F-T:6]N(&=E=%1I=&QE*"D*("`@("`@("!["B`@("`@("`@("`@(')E='5R
M;B`@)'1H:7,M/G1I=&QE.PH@("`@("`@('T*("`@('T*"@H@("`@)&]P=&EO
M;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@(F-O;7!L97A4>7!E
M(B`]/B`B;V)J96-T(BP*("`@("`@("`@("`@("`@("`@("`@(G1A9TUA<"(@
M("`@("`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(G)D9CI21$8B("`@/3X@(G)D9D1O8W5M96YT
M(BP@("`O+R!T:&ES(&ES('5S960@=&\@<W!E8VEF>2!A(&-L87-S;F%M92!F
M;W(@=&AE(')O;W0@=&%G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`@("`@("`@("D["B`@("`*
M("`@("\O("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N
M9"!I;B!F<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R(`H@("`@)'5N<V5R:6%L
M:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D;W!T:6]N<RD["@H@("`@
M)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*")H='1P.B\O
M<&5A<BYP:'`N;F5T+V9E961S+VQA=&5S="YR<W,B+'1R=64I.R`@("`*"B`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@(&5C:&\@
M("`@(D5R<F]R.B`B("X@)'-T871U<RT^9V5T365S<V%G92@I.PH@("`@?2!E
M;'-E('L*("`@("`@("`D<G-S(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I
M86QI>F5D1&%T82@I.PH*("`@("`@("!E8VAO(")4:&ES(&AA<R!B965N(')E
M='5R;F5D(&)Y(%A-3%]5;G-E<FEA;&EZ97(Z/&)R/B(["B`@("`@("`@"B`@
M("`@("`@96-H;R`B/'!R93XB.PH@("`@("`@('!R:6YT7W(H("1R<W,@*3L*
M("`@("`@("!E8VAO("(\+W!R93XB.PH*("`@("`@("!E8VAO("(\8G(^/&)R
M/E)O;W0@5&%G;F%M93H@(BXD=6YS97)I86QI>F5R+3YG9712;V]T3F%M92@I
M+B(\8G(^(CL*("`@("`@("`*("`@("`@("!E8VAO(")4:71L92!O9B!T:&4@
M8VAA;FYE;#H@(BXD<G-S+3YC:&%N;F5L+3YG9714:71L92@I+B(\8G(^(CL*
M"B`@("`@("`@)&ET96US(#T@)')S<RT^9V5T271E;7,H,RD["B`@("`@("`@
M96-H;R`B/&)R/E1I=&QE<R!O9B!T:&4@;&%S="!T:')E92!R96QE87-E<SH\
M8G(^(CL*("`@("`@("!F;W)E86-H("@D:71E;7,@87,@)&ET96TI('L*("`@
M("`@("`@("`@96-H;R`B5&ET;&4@.B`B+B1I=&5M+3YG9714:71L92@I+B(\
M8G(^(CL*("`@("`@("!]"B`@("!]"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95)$1BYP:'``````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(U
M-``Q,#0Q-S,V,S`P-``P,C4W-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L92!S
M:&]W<R!H;W<@=&\@8W)E871E(&%N(%)$1B!D;V-U;65N=`H@*B!W:71H(&$@
M9F5W(&QI;F5S(&]F(&-O9&4N"B`J(%1H:7,@8V%N(&%L<V\@8F4@9&]N92!W
M:71H(&UO9&4@/3X@<VEM<&QE>&UL"B`J"B`J($!A=71H;W(@4W1E<&AA;B!3
M8VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B!`<V5E("`@('-E<FEA;&EZ94EN
M9&5X961!<G)A>2YP:'`*("HO"@H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R
M:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@(")I;F1E;G0B("`@("`@("`@/3X@(B`@("`B+`H@
M("`@("`@("`@("`@("`@("`@("`@("`B;&EN96)R96%K(B`@("`@(#T^(")<
M;B(L"B`@("`@("`@("`@("`@("`@("`@("`@(")T>7!E2&EN=',B("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@(")A9&1$96-L(B`@
M("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@(F5N8V]D
M:6YG(B`@("`@("`]/B`B551&+3@B+`H)"0D)"0DB<F]O=$YA;64B("`@("`@
M(#T^(")R9&8Z4D1&(BP*("`@("`@("`@("`@("`@("`@("`@("`@(G)O;W1!
M='1R:6)U=&5S(B`]/B!A<G)A>2@B=F5R<VEO;B(@/3X@(C`N.3$B*2P*"0D)
M"0D)(F1E9F%U;'1486=.86UE(B`]/B`B:71E;2(*("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L
M:7IE<B@D;W!T:6]N<RD["@H@("`@"B`@("`D<F1F("`@(#T@("!A<G)A>2@*
M"0D)"0D)(F-H86YN96PB(#T^(&%R<F%Y*`H)"0D)"0D)"0D)"2)T:71L92(@
M/3X@(D5X86UP;&4@4D1&(&-H86YN96PB+`H)"0D)"0D)"0D)"2)L:6YK(B`@
M/3X@(FAT='`Z+R]W=W<N<&AP+71O;VQS+F1E(BP*"0D)"0D)"0D)"0DB:6UA
M9V4B"3T^"6%R<F%Y*`H)"0D)"0D)"0D)"0D)"0D)(G1I=&QE(@D]/B`B17AA
M;7!L92!I;6%G92(L"@D)"0D)"0D)"0D)"0D)"0DB=7)L(@D]/@DB:'1T<#HO
M+W=W=RYP:'`M=&]O;',N9&4O:6UA9V4N9VEF(BP*"0D)"0D)"0D)"0D)"0D)
M"2)L:6YK(@D]/@DB:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4B"@D)"0D)"0D)
M"0D)"0D)"2DL"@D)"0D)"0D)"0D)87)R87DH"@D)"0D)"0D)"0D)"2)T:71L
M92()/3X@(D5X86UP;&4@:71E;2(L"@D)"0D)"0D)"0D)"2)L:6YK(@D]/B`B
M:'1T<#HO+V5X86UP;&4N8V]M(@H)"0D)"0D)"0D)"2DL"@D)"0D)"0D)"0D)
M87)R87DH"@D)"0D)"0D)"0D)"2)T:71L92()/3X@(D%N;W1H97(@:71E;2(L
M"@D)"0D)"0D)"0D)"2)L:6YK(@D]/B`B:'1T<#HO+V5X86UP;&4N8V]M(@H)
M"0D)"0D)"0D)"2DL"@D)"0D)"0D)"0D)87)R87DH"@D)"0D)"0D)"0D)"2)T
M:71L92()/3X@(DD@=&AI;FL@>6]U(&=E="!I="XN+B(L"@D)"0D)"0D)"0D)
M"2)L:6YK(@D]/B`B:'1T<#HO+V5X86UP;&4N8V]M(@H)"0D)"0D)"0D)"2D*
M"0D)"0D)"0D)"2D*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D
M<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D<F1F*3L*("`@(`H@
M("`@:68H("1R97-U;'0@/3T]('1R=64@*2!["B`@("`@("`@96-H;R`@("`B
M/'!R93XB.PH@("`@("`@(&5C:&\@("`@:'1M;&5N=&ET:65S*"1S97)I86QI
M>F5R+3YG971397)I86QI>F5D1&%T82@I*3L*("`@("`@("!E8VAO("`@("(\
M+W!R93XB.PH@("`@?0H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE
M<B]E>&%M<&QE<R]U;G-E<FEA;&EZ94%N>5A-3"YP:'``````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0Q-#,`,3`T
M,3<S-C,P,#0`,#(W,#,S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@
M9&EF9F5R96YT(&UE=&AO9',@:&]W"B`J(%A-3%]5;G-E<FEA;&EZ97(@8V%N
M(&)E('5S960@=&\@8W)E871E(&1A=&$@<W1R=6-T=7)E<PH@*B!F<F]M(%A-
M3"!D;V-U;65N=',N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\
M<V-H<W1`<&AP+FYE=#X*("HO"@H@("`@+R\@=&AI<R!I<R!A('-I;7!L92!8
M34P@9&]C=6UE;G0*("`@("1X;6P@/2`G/'5S97)S/B<@+@H@("`@("`@("`@
M("<@(#QU<V5R(&AA;F1L93TB<V-H<W0B/E-T97!H86X@4V-H;6ED=#PO=7-E
M<CXG("X*("`@("`@("`@("`G("`\=7-E<B!H86YD;&4](FUJ(CY-87)T:6X@
M2F%N<V5N/"]U<V5R/B<@+@H@("`@("`@("`@("<\+W5S97)S/B<["@H@("`@
M<F5Q=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["@H@("`@+R\@
M8V]M<&QE>"!S=')U8W1U<F5S(&%R92!A<G)A>7,L('1H92!K97D@:7,@=&AE
M(&%T=')I8G5T92`G:&%N9&QE)PH@("`@)&]P=&EO;G,@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@(F-O;7!L97A4>7!E(B`]/B`B87)R87DB+`H@
M("`@("`@("`@("`@("`@("`@("`B:V5Y071T<FEB=71E(B`]/B`B:&%N9&QE
M(@H@("`@("`@("`@("`@("`@("`@("D["B`*("`@("\O("!B92!C87)E9G5L
M('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F<F]N="!O9B!T:&4@
M;F5W(&]P97)A=&]R(`H@("`@)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N
M<V5R:6%L:7IE<B@D;W!T:6]N<RD["@H@("`@+R\@=7-E<FEA;&EZ92!T:&4@
M9&]C=6UE;G0*("`@("1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA
M;&EZ92@D>&UL+"!F86QS92D[("`@(`H*("`@(&EF("A014%2.CII<T5R<F]R
M*"1S=&%T=7,I*2!["B`@("`@("`@96-H;R`@("`B17)R;W(Z("(@+B`D<W1A
M='5S+3YG971-97-S86=E*"D["B`@("!](&5L<V4@>PH@("`@("`@("1D871A
M(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH*("`@
M("`@("!E8VAO"2(\<')E/B(["B`@("`@("`@<')I;G1?<B@@)&1A=&$@*3L*
M("`@("`@("!E8VAO"2(\+W!R93XB.PH@("`@?0H*"B`@("`O+R!U;G-E<FEA
M;&EZ92!I="!A9V%I;B!A;F0@8VAA;F=E('1H92!C;VUP;&5X5'EP92!O<'1I
M;VX*("`@("\O(&)U="!L96%V92!O=&AE<B!O<'1I;VYS('5N=&]U8VAE9`H@
M("`@+R\@;F]W(&-O;7!L97@@='EP97,@=VEL;"!B92!A;B!O8FIE8W0L(&%N
M9"!T:&4@<')O<&5R='D@;F%M92!W:6QL(&)E(&EN('1H90H@("`@+R\@871T
M<FEB=71E("=H86YD;&4G"B`@("`D<W1A='5S(#T@)'5N<V5R:6%L:7IE<BT^
M=6YS97)I86QI>F4H)'AM;"P@9F%L<V4L(&%R<F%Y*")C;VUP;&5X5'EP92(@
M/3X@(F]B:F5C="(I*3L@("`@"@H@("`@:68@*%!%05(Z.FES17)R;W(H)'-T
M871U<RDI('L*("`@("`@("!E8VAO("`@(")%<G)O<CH@(B`N("1S=&%T=7,M
M/F=E=$UE<W-A9V4H*3L*("`@('T@96QS92!["B`@("`@("`@)&1A=&$@/2`D
M=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["@H@("`@("`@
M(&5C:&\)(CQP<F4^(CL*("`@("`@("!P<FEN=%]R*"`D9&%T82`I.PH@("`@
M("`@(&5C:&\)(CPO<')E/B(["B`@("!]"@H*("`@("\O('5N<V5R:6%L:7IE
M(&ET(&%G86EN(&%N9"!C:&%N9V4@=&AE(&-O;7!L97A4>7!E(&]P=&EO;@H@
M("`@+R\@86YD(')E<V5T(&%L;"!O=&AE<B!O<'1I;VYS"B`@("`O+R!.;W<L
M('1H97)E)W,@;F\@:V5Y('-O('1H92!T86=S(&%R92!S=&]R960@:6X@86X@
M87)R87D*("`@("1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ
M92@D>&UL+"!F86QS92P@87)R87DH(F]V97)R:61E3W!T:6]N<R(@/3X@=')U
M92P@(F-O;7!L97A4>7!E(B`]/B`B;V)J96-T(BDI.R`@("`*"B`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@(&5C:&\@("`@(D5R
M<F]R.B`B("X@)'-T871U<RT^9V5T365S<V%G92@I.PH@("`@?2!E;'-E('L*
M("`@("`@("`D9&%T82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE
M9$1A=&$H*3L*"B`@("`@("`@96-H;PDB/'!R93XB.PH@("`@("`@('!R:6YT
M7W(H("1D871A("D["B`@("`@("`@96-H;PDB/"]P<F4^(CL*("`@('T*"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].
M971?3DY44"\`````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,#0`,#$W-C4V`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+TYE=%].3E10+V5X86UP;&5S+P``````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-``P,C$T-S0`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7TY.5%`O97AA
M;7!L97,O;F5W<RYP:'`N;F5T+P``````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8S,#`T`#`R-#`R,P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R].971?3DY44"]E>&%M<&QE<R]N97=S+G!H<"YN970O4D5!1$U%````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`R,C<`,3`T,3<S-C,P,#0`,#(T-S`Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````%1H92!T:')E92!02%`@
M9FEL97,@87)E(&$@<VUA;&P@9&5M;R!F;W(@3F5T7TY.5%`N#0I#;W!Y('1H
M92!F:6QE<R!I;G1O('EO=7(@5V5B<V5R=F5R(&1O8W5M96YT(')O;W0@86YD
M#0IC86QL(&EN9&5X+G!H<"!I;B!Y;W4@=V5B8G)O=W-E<B!A;F0@96YJ;WDN
M#0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7TY.
M5%`O97AA;7!L97,O;F5W<RYP:'`N;F5T+VEN9&5X+G!H<```````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T
M,C$V`#$P-#$W,S8S,#`T`#`R-38T,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+R\-"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P-"B\O
M('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F
M:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@
M870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@
M?"!!=71H;W)S.B!!;&5X86YD97(@365R>B`\86QE>&UE<GI`<&AP+FYE=#X@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@($AE
M:6YO($@N($=E:&QS96X@/&AE:6YO0&=E:&QS96XN9&L^("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PT*+R\-"B\O("1)9#H@:6YD97@N<&AP+'8@,2XT+C8N,2`R,#`S+S$P+S$P
M(#$U.C0W.C$S(&AE:6YO($5X<"`D#0H_/@T*/&AT;6P^#0H\:&5A9#X-"B`@
M("`\=&ET;&4^3DY44"!N97=S+G!H<"YN970\+W1I=&QE/@T*/"]H96%D/@T*
M/&)O9'D^#0H\/W!H<`T*<F5Q=6ER95]O;F-E(").970O3DY44"]296%L=&EM
M92YP:'`B.PT*#0HD;FYT<"`](&YE=R!.971?3DY44%]296%L=&EM93L-"@T*
M)')E="`]("1N;G1P+3YC;VYN96-T*")N97=S+G!H<"YN970B*3L-"FEF*"!0
M14%2.CII<T5R<F]R*"1R970I*2![#0H@96-H;R`G/&9O;G0@8V]L;W(](G)E
M9"(^3F\@8V]N;F5C=&EO;B!T;R!N97=S<V5R=F5R(3PO9F]N=#X\8G(^)R`[
M#0H@96-H;R`D<F5T+3YG971-97-S86=E*"D[#0I](&5L<V4@>PT*("`@(&5C
M:&\@(CQH,3Y!=F%I8FQE(&=R;W5P<SPO:#$^(CL@("`@#0H@("`@)&=R;W5P
M<R`]("1N;G1P+3YG971'<F]U<',H*3L-"B`@("`D9&5S8W)I<'1I;VYS(#T@
M)&YN='`M/F=E=$1E<V-R:7!T:6]N<R@I.PT*("`@(&9O<F5A8V@H)&=R;W5P
M<R!A<R`D9W)O=7`I('L-"B`@("`@("`@96-H;R`G/&$@:')E9CTB9W)O=7`N
M<&AP/V=R;W5P/2<N=7)L96YC;V1E*"1G<F]U<%LG9W)O=7`G72DN#0H@("`@
M("`@("`@("`G)G=R:71A8FQE/2<N=7)L96YC;V1E*"1G<F]U<%LG<&]S=&EN
M9U]A;&QO=V5D)UTI+B<B/B<N#0H@("`@("`@("`@("`D9W)O=7!;)V=R;W5P
M)UTN)SPO83XG(#L-"B`@("`@("`@)&US9V-O=6YT(#T@)&=R;W5P6R=L87-T
M)UTM)&=R;W5P6R=F:7)S="==.R`-"B`@("`@("`@96-H;R`G)FYB<W`[*"<N
M)&US9V-O=6YT+B<@;65S<V%G97,I/&)R/B<[#0H@("`@("`@(&5C:&\@)&1E
M<V-R:7!T:6]N<ULD9W)O=7!;)V=R;W5P)UU=+B<\8G(^/&)R/B<[#0H@("`@
M?0T*("`@("1N;G1P+3YQ=6ET*"D[#0I]("`@(`T*/SX-"CPO8F]D>3X-"CPO
M:'1M;#X`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O3F5T7TY.5%`O97AA;7!L97,O;F5W<RYP:'`N;F5T+V=R;W5P+G!H
M<````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`V,C,Q`#$P-#$W,S8S,#`T`#`R-38V-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+R\-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@5F5R<VEO
M;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@
M?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!!;&5X86YD97(@365R>B`\86QE>&UE
M<GI`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\
M("`@("`@("`@($AE:6YO($@N($=E:&QS96X@/&AE:6YO0&=E:&QS96XN9&L^
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\-"B\O("1)9#H@9W)O=7`N<&AP+'8@,2XT+C8N
M,2`R,#`S+S$P+S$P(#$U.C0W.C$S(&AE:6YO($5X<"`D#0H_/@T*/&AT;6P^
M#0H\:&5A9#X-"B`@("`\=&ET;&4^3DY44"!N97=S+G!H<"YN970\+W1I=&QE
M/@T*/"]H96%D/@T*/&)O9'D^#0H\/W!H<`T*<F5Q=6ER95]O;F-E(").970O
M3DY44"]296%L=&EM92YP:'`B.PT*#0HD;FYT<"`](&YE=R!.971?3DY44%]2
M96%L=&EM93L-"@T*)')E="`]("1N;G1P+3YC;VYN96-T*")N97=S+G!H<"YN
M970B*3L-"FEF*"!014%2.CII<T5R<F]R*"1R970I*2![#0H@96-H;R`G/&9O
M;G0@8V]L;W(](G)E9"(^3F\@8V]N;F5C=&EO;B!T;R!N97=S<V5R=F5R(3PO
M9F]N=#X\8G(^)R`[#0H@96-H;R`D<F5T+3YG971-97-S86=E*"D[#0I](&5L
M<V4@>PT*("`@(&EF*&ES<V5T*"1?1T546R=G<F]U<"==*2D@>PT*("`@("`@
M("`D;7-G9&%T82`]("1N;G1P+3YS96QE8W1'<F]U<"@D7T=%5%LG9W)O=7`G
M72D[#0H@("`@("`@(&EF*%!%05(Z.FES17)R;W(H)&US9V1A=&$I*2![#0H@
M("`@("`@("`@("!E8VAO("<\9F]N="!C;VQO<CTB<F5D(CXG+B1M<V=D871A
M+3YG971-97-S86=E*"DN)SPO9F]N=#X\8G(^)R`[("`@("`@("`-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1M<V=C;W5N="`]("1M<V=D871A
M6R=L87-T)UTM)&US9V1A=&%;)V9I<G-T)UT[#0H@("`@("`@("`@("!E8VAO
M("<\:#$^)RXD7T=%5%LG9W)O=7`G72XG/"]H,3XG.PT*("`@("`@("`@("`@
M96-H;R`B/&(^365S<V%G92!C;W5N=#H\+V(^)FYB<W`[(BXD;7-G8V]U;G0[
M#0H@("`@("`@("`@("!E8VAO("(\8G(^/&(^4&]S=&EN9R!A;&QO=V5D.CPO
M8CXF;F)S<#LB.PT*("`@("`@("`@("`@<W=I=&-H*"`D7T=%5%LG=W)I=&%B
M;&4G72D@>PT*("`@("`@("`@("`@("`@(&-A<V4@)WDG(#H-"B`@("`@("`@
M("`@("`@("`@("`@96-H;R`G>65S)SL-"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G;B<@.@T*("`@("`@("`@
M("`@("`@("`@("!E8VAO("=N;R<[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)VTG(#H-"B`@("`@("`@("`@
M("`@("`@("`@96-H;R`G;6]D97)A=&5D)SL-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[("`@("`@("`@#0H@("`@("`@("`@("`@("`@9&5F875L=#H-
M"B`@("`@("`@("`@("`@("`@("`@96-H;R`G;B]A)SL@("`@("`@("`@("`@
M("`@("`@("`@(`T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@96-H;R`B
M/&AR/B([#0H@("`@("`@("`@("!E8VAO("(\:#(^;&%S="`Q,"!M97-S86=E
M<SPO:#(^(CL-"B`@("`@("`@("`@("`@("`-"B`@("`@("`@("`@("1M<V=S
M(#T@87)R87E?<F5V97)S92@D;FYT<"T^9V5T3W9E<G9I97<H("1M<V=C;W5N
M="TY+"`D;7-G8V]U;G0I*3L-"B`@("`@("`@("`@(&9O<F5A8V@H)&US9W,@
M87,@)&US9VED(#T^("1M<V=H96%D97(I('L-"B`@("`@("`@("`@("`@("!E
M8VAO("<\82!H<F5F/2)R96%D+G!H<#]M<V=I9#TG+G5R;&5N8V]D92@D;7-G
M:60I+@T*("`@("`@("`@("`@("`@("`@("`G)F=R;W5P/2<N=7)L96YC;V1E
M*"1?1T546R=G<F]U<"==*2X-"B`@("`@("`@("`@("`@("`@("`@)R(^/&(^
M)RXD;7-G:&5A9&5R6R)3=6)J96-T(ETN)SPO8CX\+V$^/&)R/B<[#0H@("`@
M("`@("`@("`@("`@96-H;R`G9G)O;3HF;F)S<#LG+B1M<V=H96%D97);(D9R
M;VTB72XB/&)R/B([#0H@("`@("`@("`@("`@("`@96-H;R`D;7-G:&5A9&5R
M6R)$871E(ETN)SQB<CX\8G(^)SL-"B`@("`@("`@("`@('T@("`@("`@(`T*
M("`@("`@("!]#0H@("`@?2!E;'-E('L-"B`@("`@("`@96-H;R`G/&9O;G0@
M8V]L;W(](G)E9"(^3F\@;F5W<V=R;W5P(&-H;V]S960A/"]F;VYT/CQB<CXG
M(#L@("`@#0H@("`@?0T*("`@("1N;G1P+3YQ=6ET*"D[#0I]("`@(`T*/SX-
M"CPO8F]D>3X-"CPO:'1M;#X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+TYE=%].3E10+V5X86UP;&5S+VYE=W,N<&AP+FYE="]R96%D+G!H
M<``````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-3`V-@`Q,#0Q-S,V,S`P-``P,C4T-3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`-"B\O#0HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I
M;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O
M=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O
M('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L-"B\O('P@075T:&]R<SH@06QE>&%N9&5R($UE<GH@/&%L97AM
M97)Z0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M?"`@("`@("`@("!(96EN;R!(+B!'96AL<V5N(#QH96EN;T!G96AL<V5N+F1K
M/B`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z(')E860N<&AP+'8@,2XV+C(N
M,B`R,#`S+S$P+S$T(#$V.C`X.C0S(&AE:6YO($5X<"`D#0H_/@T*/&AT;6P^
M#0H\:&5A9#X-"B`@("`\=&ET;&4^3DY44"!N97=S+G!H<"YN970\+W1I=&QE
M/@T*/"]H96%D/@T*/&)O9'D^#0H\:#$^365S<V%G93PO:#$^#0H\/W!H<`T*
M<F5Q=6ER95]O;F-E(").970O3DY44"]296%L=&EM92YP:'`B.PT*#0HD;FYT
M<"`](&YE=R!.971?3DY44%]296%L=&EM93L-"@T*)')E="`]("1N;G1P+3YC
M;VYN96-T*")N97=S+G!H<"YN970B*3L-"FEF*"!014%2.CII<T5R<F]R*"1R
M970I*2![#0H@96-H;R`G/&9O;G0@8V]L;W(](G)E9"(^3F\@8V]N;F5C=&EO
M;B!T;R!N97=S<V5R=F5R(3PO9F]N=#X\8G(^)R`[#0H@96-H;R`D<F5T+3YG
M971-97-S86=E*"D[#0I](&5L<V4@>PT*("`@(&EF*&ES<V5T*"1?1T546R=M
M<V=I9"==*2!A;F0@:7-S970H)%]'151;)V=R;W5P)UTI*7L-"B`@("`@("`@
M)&US9V1A=&$@/2`D;FYT<"T^<V5L96-T1W)O=7`H)%]'151;)V=R;W5P)UTI
M.PT*("`@("`@("!I9BA014%2.CII<T5R<F]R*"1M<V=D871A*2D@>PT*("`@
M("`@("`@("`@96-H;R`G/&9O;G0@8V]L;W(](G)E9"(^)RXD;7-G9&%T82T^
M9V5T365S<V%G92@I+B<\+V9O;G0^/&)R/B<@.R`@("`@("`@#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D:&5A9&5R(#T@)&YN='`M/F=E=$AE
M861E<B@D7T=%5%LG;7-G:60G72D[#0H@("`@("`@("`@("!E8VAO("<\:'(^
M)SL-"B`@("`@("`@("`@(&5C:&\@)SQH,CY(96%D97(\+V@R/B<[#0H@("`@
M("`@("`@("!E8VAO("<\<')E/B<[#0H@("`@("`@("`@("!F;W)E86-H*"`D
M:&5A9&5R+3YG971&:65L9'-!<G)A>2@I(&%S("1L:6YE*2![#0H@("`@("`@
M("`@("`@("`@96-H;R`D;&EN92XG/&)R/B<[#0H@("`@("`@("`@("!]("`@
M("`@("`@("`@("`-"B`@("`@("`@("`@(&5C:&\@)SPO<')E/B<[#0H@("`@
M("`@("`@("!E8VAO("<\:'(^)SL-"B`@("`@("`@("`@(&5C:&\@)SQH,CY"
M;V1Y/"]H,CXG.PT*("`@("`@("`@("`@96-H;R`G/&9O<FT^/'1E>'1A<F5A
M('=R87`](F]F9B(@8V]L<STB-SDB+"!R;W=S/2(R-2(^)RX-"B`@("`@("`@
M("`@("`@("`@("`@)&YN='`M/F=E=$)O9'E287<H)%]'151;)VUS9VED)UTL
M('1R=64I+@T*("`@("`@("`@("`@("`@("<\+W1E>'1A<F5A/CPO9F]R;3XG
M.R`@("`@("`@("`@#0H@("`@("`@('T@("`@("`@(`T*("`@('T@96QS92![
M#0H@("`@("`@(&5C:&\@)SQF;VYT(&-O;&]R/2)R960B/DYO(&UE<W-A9V4@
M8VAO;W-E9"$\+V9O;G0^/&)R/B<@.R`@("`-"B`@("!]#0H@("`@)&YN='`M
M/G%U:70H*3L-"GT@("`@#0H_/@T*/"]B;V1Y/@T*/"]H=&UL/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U5T:6PO
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8S,#`T`#`Q-S<R-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?571I;"]E>&%M<&QE<R\`````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#(Q-30T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]5=&EL+V5X86UP;&5S+V5X
M86UP;&4N<&AP```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S$Q,``Q,#0Q-S,V,S`P
M-``P,C,W,#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]02%`*("`@(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL*
M("`@(`H@("`@+RHJ"B`@("`J(')E<&QA8VEN9R!834P@96YT:71I97,*("`@
M("HO"B`@("!P<FEN="`B<F5P;&%C92!834P@96YT:71I97,Z/&)R/EQN(CL*
M("`@('!R:6YT(%A-3%]5=&EL.CIR97!L86-E16YT:71I97,H(E1H:7,@<W1R
M:6YG(&-O;G1A:6YS(#P@)B`^+B(I.PH@("`@<')I;G0@(EQN/&)R/CQB<CY<
M;B(["@H@("`@+RHJ"B`@("`J(&)U:6QD:6YG(%A-3"!D96-L87)A=&EO;@H@
M("`@*B\*("`@('!R:6YT(")B=6EL9&EN9R!834P@9&5C;&%R871I;VXZ/&)R
M/EQN(CL*("`@('!R:6YT(&AT;6QS<&5C:6%L8VAA<G,H6$U,7U5T:6PZ.F=E
M=%A-3$1E8VQA<F%T:6]N*"DI.PH@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([
M"@H@("`@<')I;G0@(F)U:6QD:6YG(%A-3"!D96-L87)A=&EO;B!W:71H(&%D
M9&ET:6]N86P@871T<FEB=71E<SH\8G(^(CL*("`@('!R:6YT(&AT;6QS<&5C
M:6%L8VAA<G,H6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"(Q+C`B+"`B
M551&+3@B+"!T<G5E*2D["B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL*"B`@
M("`O*BH*("`@("H@8G5I;&1I;F<@9&]C=6UE;G0@='EP92!D96-L87)A=&EO
M;@H@("`@*B\*("`@('!R:6YT(")B=6EL9&EN9R!$;V-4>7!E(&1E8VQA<F%T
M:6]N.CQB<CY<;B(["B`@("!P<FEN="!H=&UL<W!E8VEA;&-H87)S*%A-3%]5
M=&EL.CIG971$;V-4>7!E1&5C;&%R871I;VXH)W!A8VMA9V4G+"`G:'1T<#HO
M+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TQ+C`G*2D["B`@("!P<FEN="`B
M7&X\8G(^/&)R/EQN(CL*"B`@("!P<FEN="`B8G5I;&1I;F<@1&]C5'EP92!D
M96-L87)A=&EO;B!W:71H('!U8FQI8R!)1"`H9&]E<R!N;W0@97AI<W0I.CQB
M<CY<;B(["B`@("!P<FEN="!H=&UL<W!E8VEA;&-H87)S*%A-3%]5=&EL.CIG
M971$;V-4>7!E1&5C;&%R871I;VXH)W!A8VMA9V4G+"!A<G)A>2@G=7)I)R`]
M/B`G:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TQ+C`G+"`G:60G
M(#T^("<M+R]02%`O+U!%05(O1%1$(%!!0TM!1T4@,"XQ)RDI*3L*("`@('!R
M:6YT(")<;CQB<CX\8G(^7&XB.PH*("`@('!R:6YT(")B=6EL9&EN9R!$;V-4
M>7!E(&1E8VQA<F%T:6]N('=I=&@@:6YT97)N86P@1%1$.CQB<CY<;B(["B`@
M("!P<FEN="`B/'!R93XB.PH@("`@<')I;G0@:'1M;'-P96-I86QC:&%R<RA8
M34Q?571I;#HZ9V5T1&]C5'EP941E8VQA<F%T:6]N*"=P86-K86=E)RP@)VAT
M='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,2XP)RP@)SPA14Q%345.
M5"!A9&1I=&EO;F%L26YF;R`H(U!#1$%402D^)RDI.PH@("`@<')I;G0@(CPO
M<')E/B(["B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL*"B`@("`O*BH*("`@
M("H@8W)E871I;F<@86X@871T<FEB=71E('-T<FEN9PH@("`@*B\*("`@("1A
M='0@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@(F9O;R(@("`]/B`@(F)A
M<B(L"B`@("`@("`@("`@("`@("`@(")A<F=H(B`@/3X@(")T;VUA=&\B"B`@
M("`@("`@("`@("`@("`I.PH*("`@('!R:6YT(")C;VYV97)T:6YG(&%R<F%Y
M('1O('-T<FEN9SH\8G(^7&XB.PH@("`@<')I;G0@6$U,7U5T:6PZ.F%T=')I
M8G5T97-4;U-T<FEN9R@D871T*3L*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB
M.PH*"B`@("`O*BH*("`@("H@8W)E871I;F<@86X@871T<FEB=71E('-T<FEN
M9R!W:71H(&QI;F5B<F5A:W,*("`@("HO"B`@("`D871T(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`@(")F;V\B("`@/3X@(")B87(B+`H@("`@("`@("`@
M("`@("`@("`B87)G:"(@(#T^("`B=&]M871O(@H@("`@("`@("`@("`@("`@
M*3L*"B`@("!P<FEN="`B8V]N=F5R=&EN9R!A<G)A>2!T;R!S=')I;F<@*&EN
M8VQU9&EN9R!L:6YE(&)R96%K<RDZ/&)R/EQN(CL*("`@('!R:6YT("(\<')E
M/B(["B`@("!P<FEN="!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A
M='0L('1R=64L('1R=64I.PH@("`@<')I;G0@(CPO<')E/B(["B`@("!P<FEN
M="`B7&X\8G(^/&)R/EQN(CL*"@H@("`@+RHJ"B`@("`J('-P;&ET=&EN9R!A
M('%U86QI9FEE9"!T86<@;F%M90H@("`@*B\*("`@('!R:6YT(")S<&QI='1I
M;F<@<75A;&EF:65D('1A9R!N86UE.CQB<CY<;B(["B`@("!P<FEN="`B/'!R
M93XB.PH@("`@<')I;G1?<BA834Q?571I;#HZ<W!L:711=6%L:69I961.86UE
M*")X<VQT.G-T>6QE<VAE970B*2D["B`@("!P<FEN="`B/"]P<F4^(CL*("`@
M('!R:6YT(")<;CQB<CY<;B(["@H*("`@("\J*@H@("`@*B!S<&QI='1I;F<@
M82!Q=6%L:69I960@=&%G(&YA;64@*&YO(&YA;65S<&%C92D*("`@("HO"B`@
M("!P<FEN="`B<W!L:71T:6YG('%U86QI9FEE9"!T86<@;F%M92`H;F\@;F%M
M97-P86-E*3H\8G(^7&XB.PH@("`@<')I;G0@(CQP<F4^(CL*("`@('!R:6YT
M7W(H6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@B9F]O(BDI.PH@("`@
M<')I;G0@(CPO<')E/B(["B`@("!P<FEN="`B7&X\8G(^7&XB.PH*("`@("\J
M*@H@("`@*B!S<&QI='1I;F<@82!Q=6%L:69I960@=&%G(&YA;64@*&YO(&YA
M;65S<&%C92P@8G5T(&1E9F%U;'0@;F%M97-P86-E('-P96-I9FEE9"D*("`@
M("HO"B`@("!P<FEN="`B<W!L:71T:6YG('%U86QI9FEE9"!T86<@;F%M92`H
M;F\@;F%M97-P86-E+"!B=70@9&5F875L="!N86UE<W!A8V4@<W!E8VEF:65D
M*3H\8G(^7&XB.PH@("`@<')I;G0@(CQP<F4^(CL*("`@('!R:6YT7W(H6$U,
M7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@B9F]O(BP@(F)A<B(I*3L*("`@
M('!R:6YT("(\+W!R93XB.PH@("`@<')I;G0@(EQN/&)R/EQN(CL*"B`@("`O
M*BH*("`@("H@=F5R:69Y:6YG(%A-3"!N86UE<PH@("`@*B\*("`@('!R:6YT
M(")V97)I9GEI;F<@)TUY('!R:79A=&4@=&%G)SH\8G(^7&XB.PH@("`@<')I
M;G0@(CQP<F4^(CL*("`@('!R:6YT7W(H6$U,7U5T:6PZ.FES5F%L:61N86UE
M*"=->2!0<FEV871E(%1A9R<I*3L*("`@('!R:6YT("(\+W!R93XB.PH@("`@
M<')I;G0@(EQN/&)R/CQB<CY<;B(["B`@("`*("`@('!R:6YT(")V97)I9GEI
M;F<@)RU->51A9R<Z/&)R/EQN(CL*("`@('!R:6YT("(\<')E/B(["B`@("!P
M<FEN=%]R*%A-3%]5=&EL.CII<U9A;&ED;F%M92@G+4UY5&%G)RDI.PH@("`@
M<')I;G0@(CPO<')E/B(["B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL*"B`@
M("`O*BH*("`@("H@8W)E871I;F<@86X@6$U,('1A9PH@("`@*B\*("`@("1T
M86<@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@(FYA;65S<&%C92(@("`]
M/B`B9F]O(BP*("`@("`@("`@("`@("`@("`@(FQO8V%L4&%R="(@("`]/B`B
M8F%R(BP*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`]/B!A<G)A
M>2@@(FME>2(@/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")F<G5I="9V96=E=&%B
M;&4B("DL"B`@("`@("`@("`@("`@("`@(")C;VYT96YT(B`@("`@/3X@(DDG
M;2!I;G-I9&4@=&AE('1A9R(*("`@("`@("`@("`@("`@("D["@H@("`@<')I
M;G0@(F-R96%T:6YG(&$@=&%G('=I=&@@;F%M97-P86-E(&%N9"!L;V-A;"!P
M87)T.CQB<CXB.PH@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIC
M<F5A=&5486=&<F]M07)R87DH)'1A9RDI.PH@("`@<')I;G0@(EQN/&)R/CQB
M<CY<;B(["@H@("`@+RHJ"B`@("`J(&-R96%T:6YG(&%N(%A-3"!T86<*("`@
M("HO"B`@("`D=&%G(#T@87)R87DH"B`@("`@("`@("`@("`@("`@(")Q;F%M
M92(@("`@("`@(#T^(")F;V\Z8F%R(BP*("`@("`@("`@("`@("`@("`@(FYA
M;65S<&%C955R:2(@/3X@(FAT='`Z+R]F;V\N8V]M(BP*("`@("`@("`@("`@
M("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH(")K97DB(#T^(")V86QU
M92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE(B`I+`H@("`@("`@("`@
M("`@("`@("`B8V]N=&5N="(@("`@("`]/B`B22=M(&EN<VED92!T:&4@=&%G
M(@H@("`@("`@("`@("`@("`@*3L*"B`@("!P<FEN="`B8W)E871I;F<@82!T
M86<@=VET:"!Q=6%L:69I960@;F%M92!A;F0@;F%M97-P86-E57)I.CQB<CY<
M;B(["B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A
M9T9R;VU!<G)A>2@D=&%G*2D["B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL*
M"B`@("`O*BH*("`@("H@8W)E871I;F<@86X@6$U,('1A9PH@("`@*B\*("`@
M("1T86<@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@(G%N86UE(B`@("`@
M("`@/3X@(F)A<B(L"B`@("`@("`@("`@("`@("`@(")N86UE<W!A8V55<FDB
M(#T^(")H='1P.B\O9F]O+F-O;2(L"B`@("`@("`@("`@("`@("`@(")A='1R
M:6)U=&5S(B`@(#T^(&%R<F%Y*"`B:V5Y(B`]/B`B=F%L=64B+"`B87)G:"(@
M/3X@(F9R=6ET)G9E9V5T86)L92(@*0H@("`@("`@("`@("`@("`@*3L*"B`@
M("!P<FEN="`B8W)E871I;F<@86X@96UP='D@=&%G('=I=&AO=70@;F%M97-P
M86-E(&)U="!N86UE<W!A8V4@57)I.CQB<CY<;B(["B`@("!P<FEN="!H=&UL
M96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G*2D[
M"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL*"B`@("`O*BH*("`@("H@8W)E
M871I;F<@86X@6$U,('1A9R!W:71H(&$@0T1A=&$@4V5C=&EO;@H@("`@*B\*
M("`@("1T86<@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@(G%N86UE(B`@
M("`@("`@/3X@(F9O;R(L"B`@("`@("`@("`@("`@("`@(")A='1R:6)U=&5S
M(B`@(#T^(&%R<F%Y*"`B:V5Y(B`]/B`B=F%L=64B+"`B87)G:"(@/3X@(F9R
M=6ET)G9E9V5T86)L92(@*2P*("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B
M("`@("`@/3X@(DDG;2!I;G-I9&4@=&AE('1A9R(*("`@("`@("`@("`@("`@
M("D["@H@("`@<')I;G0@(F-R96%T:6YG(&$@=&%G('=I=&@@0T1A=&$@<V5C
M=&EO;CH\8G(^7&XB.PH@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL
M.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RP@6$U,7U5424Q?0T1!5$%?4T5#
M5$E/3BDI.PH@("`@<')I;G0@(EQN/&)R/CQB<CY<;B(["@H@("`@+RHJ"B`@
M("`J(&-R96%T:6YG(&%N(%A-3"!T86<@=VET:"!C<F5A=&5486<*("`@("HO
M"B`@("!P<FEN="`B8W)E871I;F<@82!T86<@=VET:"!C<F5A=&5486<Z/&)R
M/B(["B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A
M9R@B;7E.<SIM>51A9R(L(&%R<F%Y*")F;V\B(#T^(")B87(B*2P@(E1H:7,@
M:7,@:6YS:61E('1H92!T86<B+"`B:'1T<#HO+W=W=RYW,V,N;W)G+VUY3G,C
M(BDI.PH@("`@<')I;G0@(EQN/&)R/CQB<CY<;B(["@H@("`@"B`@("`O*BH*
M("`@("H@=')Y:6YG('1O(&-R96%T92!A;B!834P@=&%G('=I=&@@86X@87)R
M87D@87,@8V]N=&5N=`H@("`@*B\*("`@("1T86<@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@(G%N86UE(B`@("`@("`@/3X@(F)A<B(L"B`@("`@("`@
M("`@("`@("`@(")C;VYT96YT(B`@("`@(#T^(&%R<F%Y*"`B9F]O(B`]/B`B
M8F%R(B`I"B`@("`@("`@("`@("`@("`I.PH@("`@<')I;G0@(G1R>6EN9R!T
M;R!C<F5A=&4@86X@6$U,('1A9R!W:71H(&%N(&%R<F%Y(&%S(&-O;G1E;G0Z
M/&)R/EQN(CL*("`@('!R:6YT("(\<')E/B(["B`@("!P<FEN=%]R*%A-3%]5
M=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RDI.PH@("`@<')I;G0@(CPO
M<')E/B(["B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL*("`@(`H_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U5T:6PO97AA;7!L97,O97AA;7!L
M93(N<&AP`````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C(R`#$P-#$W,S8S,#`T`#`R
M,S<W,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/U!(4`H@("`@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PH*("`@
M("\J*@H@("`@*B!C<F5A=&EN9R!A('-T87)T(&5L96UE;G0*("`@("HO"B`@
M("!P<FEN="`B8W)E871I;F<@82!S=&%R="!E;&5M96YT.CQB<CXB.PH@("`@
M<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIC<F5A=&53=&%R=$5L96UE
M;G0H(FUY3G,Z;7E486<B+"!A<G)A>2@B9F]O(B`]/B`B8F%R(BDL(")H='1P
M.B\O=W=W+G<S8RYO<F<O;7E.<R,B*2D["B`@("!P<FEN="`B7&X\8G(^/&)R
M/EQN(CL*"@H@("`@+RHJ"B`@("`J(&-R96%T:6YG(&$@<W1A<G0@96QE;65N
M=`H@("`@*B\*("`@('!R:6YT(")C<F5A=&EN9R!A('-T87)T(&5L96UE;G0Z
M/&)R/B(["B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T
M95-T87)T16QE;65N="@B;7E486<B+"!A<G)A>2@I+"`B:'1T<#HO+W=W=RYW
M,V,N;W)G+VUY3G,C(BDI.PH@("`@<')I;G0@(EQN/&)R/CQB<CY<;B(["@H@
M("`@+RHJ"B`@("`J(&-R96%T:6YG(&$@<W1A<G0@96QE;65N=`H@("`@*B\*
M("`@('!R:6YT(")C<F5A=&EN9R!A('-T87)T(&5L96UE;G0Z/&)R/B(["B`@
M("!P<FEN="`B/'!R93XB.PH@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5
M=&EL.CIC<F5A=&53=&%R=$5L96UE;G0H(FUY5&%G(BP@87)R87DH(")F;V\B
M(#T^(")B87(B+"`B87)G:"(@/3X@(G1O;6%T;R(@*2P@(FAT='`Z+R]W=W<N
M=S-C+F]R9R]M>4YS(R(L('1R=64I*3L*("`@('!R:6YT("(\+W!R93XB.PH@
M("`@<')I;G0@(EQN/&)R/CQB<CY<;B(["@H*("`@("\J*@H@("`@*B!C<F5A
M=&EN9R!A;B!E;F0@96QE;65N=`H@("`@*B\*("`@('!R:6YT(")C<F5A=&EN
M9R!A;B!E;F0@96QE;65N=#H\8G(^(CL*("`@('!R:6YT(&AT;6QE;G1I=&EE
M<RA834Q?571I;#HZ8W)E871E16YD16QE;65N="@B;7E.<SIM>51A9R(I*3L*
M("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PH*("`@("\J*@H@("`@*B!C<F5A
M=&EN9R!A($-$871A('-E8W1I;VX*("`@("HO"B`@("!P<FEN="`B8W)E871I
M;F<@82!#1&%T82!S96-T:6]N.CQB<CXB.PH@("`@<')I;G0@:'1M;&5N=&ET
M:65S*%A-3%]5=&EL.CIC<F5A=&5#1&%T85-E8W1I;VXH(DD@86T@8V]N=&5N
M="XB*2D["B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL*"B`@("`O*BH*("`@
M("H@8W)E871I;F<@82!C;VUM96YT"B`@("`J+PH@("`@<')I;G0@(F-R96%T
M:6YG(&$@8V]M;65N=#H\8G(^(CL*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA8
M34Q?571I;#HZ8W)E871E0V]M;65N="@B22!A;2!A(&-O;6UE;G0N(BDI.PH@
M("`@<')I;G0@(EQN/&)R/CQB<CY<;B(["@H@("`@+RHJ"B`@("`J(&-R96%T
M:6YG(&%N(%A-3"!T86<@=VET:"!M=6QT:6QI;F4@;6]D90H@("`@*B\*("`@
M("1T86<@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@(G%N86UE(B`@("`@
M("`@/3X@(F9O;SIB87(B+`H@("`@("`@("`@("`@("`@("`B;F%M97-P86-E
M57)I(B`]/B`B:'1T<#HO+V9O;RYC;VTB+`H@("`@("`@("`@("`@("`@("`B
M871T<FEB=71E<R(@("`]/B!A<G)A>2@@(FME>2(@/3X@(G9A;'5E(BP@(F%R
M9V@B(#T^(")F<G5I="9V96=E=&%B;&4B("DL"B`@("`@("`@("`@("`@("`@
M(")C;VYT96YT(B`@("`@(#T^(")))VT@:6YS:61E('1H92!T86<@)B!C;VYT
M86EN(&1A;F=E<F]U<R!C:&%R<R(*("`@("`@("`@("`@("`@("D["@H@("`@
M<')I;G0@(F-R96%T:6YG(&$@=&%G('=I=&@@<75A;&EF:65D(&YA;64@86YD
M(&YA;65S<&%C955R:3H\8G(^7&XB.PH@("`@<')I;G0@(CQP<F4^(CL*("`@
M('!R:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E5&%G1G)O;4%R
M<F%Y*"1T86<L(%A-3%]55$E,7U)%4$Q!0T5?14Y4251)15,L('1R=64I*3L*
M("`@('!R:6YT("(\+W!R93XB.PH@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([
M"@H*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-``P,C$U,S,`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A
M=&AE<B]E>&%M<&QE<R\`````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-#$W,S8S,#`T`#`R,S,U,0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V5J<V4M8F%S:6,N<&AP
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#0U,S8`,3`T,3<S-C,P,#0`,#(V,#<T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP#0HO*B!V:6TZ
M('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@=F5R<VEO
M;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@
M?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!!;&5X86YD97(@5VER='H@/&%L97A`
M<&,T<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z(&5J<V4M
M8F%S:6,N<&AP+'8@,2XR(#(P,#0O,#$O,#8@,30Z,30Z,C0@97)U($5X<"`D
M#0H-"G)E<75I<F5?;VYC92`B4V5R=FEC97,O5V5A=&AE<BYP:'`B.PT*#0HO
M+R!/8FIE8W0@:6YI=&EA;&EZ871I;VX@+2!E<G)O<B!C:&5C:VEN9R!I<R!I
M;7!O<G1A;G0L(&)E8V%U<V4@;V8-"B\O(&AA;F1L:6YG(&5X8V5P=&EO;G,@
M<W5C:"!A<R!M:7-S:6YG(%!%05(@;6]D=6QE<R!O<B!N;W0@8F5I;F<@;VYL
M:6YE#0HD96IS92`]("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E*")%:G-E
M(BP@87)R87DH(F1E8G5G(B`]/B`R*2D[#0II9B`H4V5R=FEC97-?5V5A=&AE
M<CHZ:7-%<G)O<B@D96IS92DI('L-"B`@("!D:64H(D5R<F]R.B`B+B1E:G-E
M+3YG971-97-S86=E*"DN(EQN(BD[#0I]#0H-"B\J($5R87-E(&-O;6UE;G1S
M('1O(&5N86)L92!C86-H:6YG#0HD96IS92T^<V5T0V%C:&4H(F9I;&4B+"!A
M<G)A>2@B8V%C:&5?9&ER(B`]/B`B+W1M<"]C86-H92\B*2D[#0II9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D96IS92DI('L-"B`@("!E8VAO(")%
M<G)O<CH@(BXD96IS92T^9V5T365S<V%G92@I+B)<;B([#0I]#0HJ+PT*#0HD
M96IS92T^<V5T56YI='-&;W)M870H(FUE=')I8R(I.PT*)&5J<V4M/G-E=$1A
M=&54:6UE1F]R;6%T*")D+FTN62(L(")(.FDB*3L-"@T*)&QO8V%T:6]N(#T@
M(C@Q-C$Q(CL@+R\@07-P96XL($-/#0HO+R1L;V-A=&EO;B`]("(P,C$Q-2([
M("\O($)O<W1O;BP@34$-"B\O)&QO8V%T:6]N(#T@(CDV-SDY(CL@+R\@4&%G
M;R!086=O+"!!4PT*+R\D;&]C871I;VX@/2`B,#DP,#DB.R`O+R!!<FUE9"!&
M;W)C97,@175R;W!E("T^($5R<F]R#0H-"B\O($YO=R!I=&5R871E('1H<F]U
M9V@@879A:6QA8FQE(&9U;F-T:6]N<R!F;W(@<F5T<FEE=FEN9R!D871A#0IF
M;W)E86-H("AA<G)A>2@B9V5T3&]C871I;VXB+"`B9V5T5V5A=&AE<B(L(")G
M971&;W)E8V%S="(I(&%S("1F=6YC=&EO;BD@>PT*("`@("1D871A(#T@)&5J
M<V4M/B1F=6YC=&EO;B@D;&]C871I;VXI.PT*("`@(&EF("A397)V:6-E<U]7
M96%T:&5R.CII<T5R<F]R*"1D871A*2D@>PT*("`@("`@("!E8VAO(")%<G)O
M<CH@(BXD9&%T82T^9V5T365S<V%G92@I+B)<;B([#0H@("`@("`@(&-O;G1I
M;G5E.PT*("`@('T-"@T*("`@('9A<E]D=6UP*"1D871A*3L-"GT-"C\^#0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+W=E
M871H97(N8V]M+6)A<VEC+G!H<```````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4P,S0`,3`T,3<S-C,P,#0`,#(W,S4T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-#H@*B\-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@
M?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@
M5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!!;&5X86YD97(@
M5VER='H@/&%L97A`<&,T<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O#0HO
M+R`D260Z('=E871H97(N8V]M+6)A<VEC+G!H<"QV(#$N-"`R,#`S+S$R+S,Q
M(#(S.C,Q.C(R(&5R=2!%>'`@)`T*#0IR97%U:7)E7V]N8V4@(E-E<G9I8V5S
M+U=E871H97(N<&AP(CL-"@T*+R\@3V)J96-T(&EN:71I86QI>F%T:6]N("T@
M97)R;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B96-A=7-E(&]F#0HO+R!H
M86YD;&EN9R!E>&-E<'1I;VYS('-U8V@@87,@;6ES<VEN9R!014%2(&UO9'5L
M97,-"B1W96%T:&5R1&]T0V]M(#T@)E-E<G9I8V5S7U=E871H97(Z.G-E<G9I
M8V4H(E=E871H97)$;W1#;VTB+"!A<G)A>2@B9&5B=6<B(#T^(#(I*3L-"FEF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W96%T:&5R1&]T0V]M*2D@
M>PT*("`@(&1I92@B17)R;W(Z("(N)'=E871H97)$;W1#;VTM/F=E=$UE<W-A
M9V4H*2XB7&XB*3L-"GT-"@T*+R\@4V5T('=E871H97(N8V]M('!A<G1N97(@
M9&%T80T*)'=E871H97)$;W1#;VTM/G-E=$%C8V]U;G1$871A*"(\4&%R=&YE
M<DE$/B(L("(\3&EC96YS94ME>3XB*3L-"@T*+RH@17)A<V4@8V]M;65N=',@
M=&\@96YA8FQE(&-A8VAI;F<-"B1W96%T:&5R1&]T0V]M+3YS971#86-H92@B
M9FEL92(L(&%R<F%Y*")C86-H95]D:7(B(#T^("(O=&UP+V-A8VAE+R(I*3L-
M"FEF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W96%T:&5R1&]T0V]M
M*2D@>PT*("`@(&5C:&\@(D5R<F]R.B`B+B1W96%T:&5R1&]T0V]M+3YG971-
M97-S86=E*"DN(EQN(CL-"GT-"BHO#0H-"B1W96%T:&5R1&]T0V]M+3YS9715
M;FET<T9O<FUA="@B;65T<FEC(BD[#0HD=V5A=&AE<D1O=$-O;2T^<V5T1&%T
M951I;65&;W)M870H(F0N;2Y9(BP@(D@Z:2(I.PT*#0HO+R!&:7)S="!G970@
M8V]D92!F;W(@;&]C871I;VX-"B1S96%R8V@@/2`D=V5A=&AE<D1O=$-O;2T^
M<V5A<F-H3&]C871I;VXH(D)O;FXL($=E<FUA;GDB*3L-"FEF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S96%R8V@I*2![#0H@("`@9&EE*")%<G)O
M<CH@(BXD<V5A<F-H+3YG971-97-S86=E*"DN(EQN(BD[#0I]#0H-"B\O($YO
M=R!I=&5R871E('1H<F]U9V@@879A:6QA8FQE(&9U;F-T:6]N<R!F;W(@<F5T
M<FEE=FEN9R!D871A#0IF;W)E86-H("AA<G)A>2@B9V5T3&]C871I;VXB+"`B
M9V5T5V5A=&AE<B(L(")G971&;W)E8V%S="(I(&%S("1F=6YC=&EO;BD@>PT*
M("`@("1D871A(#T@)'=E871H97)$;W1#;VTM/B1F=6YC=&EO;B@D<V5A<F-H
M*3L-"B`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D9&%T82DI
M('L-"B`@("`@("`@96-H;R`B17)R;W(Z("(N)&1A=&$M/F=E=$UE<W-A9V4H
M*2XB7&XB.PT*("`@("`@("!C;VYT:6YU93L-"B`@("!]#0H-"B`@("!V87)?
M9'5M<"@D9&%T82D[#0I]#0H_/@T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O;65T87(M8F%S:6,N<&AP````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-3,Q-@`Q,#0Q-S,V,S`P-``P,C8R-3,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\J('9I;3H@<V5T
M(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PT*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%!(4"!V97)S:6]N(#0@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@
M("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\#0HO+R!\(&%V
M86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\#0HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-"B\O('P@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK#0HO+R!\($%U=&AO<G,Z($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P
M+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\-"B\O("1)9#H@;65T87(M8F%S
M:6,N<&AP+'8@,2XX(#(P,#,O,3(O,S$@,C,Z,S$Z,C(@97)U($5X<"`D#0H-
M"G)E<75I<F5?;VYC92`B4V5R=FEC97,O5V5A=&AE<BYP:'`B.PT*#0HO+R!/
M8FIE8W0@:6YI=&EA;&EZ871I;VX@+2!E<G)O<B!C:&5C:VEN9R!I<R!I;7!O
M<G1A;G0L(&)E8V%U<V4@;V8-"B\O(&AA;F1L:6YG(&5X8V5P=&EO;G,@<W5C
M:"!A<R!M:7-S:6YG(%!%05(@;6]D=6QE<PT*)&UE=&%R(#T@)E-E<G9I8V5S
M7U=E871H97(Z.G-E<G9I8V4H(DU%5$%2(BP@87)R87DH(F1E8G5G(B`]/B`P
M*2D[#0II9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D;65T87(I*2![
M#0H@("`@9&EE*")%<G)O<CH@(BXD;65T87(M/F=E=$UE<W-A9V4H*2XB7&XB
M*3L-"GT-"@T*+R\@4V5T('!A<F%M971E<G,@9F]R($1"(&%C8V5S<RP@;F5E
M9&5D(&9O<B!L;V-A=&EO;B!S96%R8VAE<PT*)&UE=&%R+3YS971-971A<D1"
M*")S<6QI=&4Z+R]L;V-A;&AO<W0O+W5S<B]L;V-A;"]L:6(O<&AP+V1A=&$O
M4V5R=FEC97-?5V5A=&AE<B]S97)V:6-E<U=E871H97)$0B(I.PT*:68@*%-E
M<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&UE=&%R*2D@>PT*("`@(&5C:&\@
M(D5R<F]R.B`B+B1M971A<BT^9V5T365S<V%G92@I+B)<;B([#0I]#0H-"B\J
M($5R87-E(&-O;6UE;G1S('1O(&5N86)L92!C86-H:6YG#0HD;65T87(M/G-E
M=$-A8VAE*")F:6QE(BP@87)R87DH(F-A8VAE7V1I<B(@/3X@(B]T;7`O8V%C
M:&4O(BDI.PT*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&UE=&%R
M*2D@>PT*("`@(&5C:&\@(D5R<F]R.B`B+B1M971A<BT^9V5T365S<V%G92@I
M+B)<;B([#0I]#0HJ+PT*#0HD;65T87(M/G-E=%5N:71S1F]R;6%T*")C=7-T
M;VTB+"!A<G)A>2@-"B`@("`B=VEN9"(@/3X@(FMT(BP-"B`@("`B=FES(B`]
M/B`B:VTB+`T*("`@(")T96UP(B`]/B`B8R(L#0H@("`@(G!R97,B(#T^(")H
M<&$B+`T*("`@(")R86EN(B`]/B`B:6XB*2D[#0HD;65T87(M/G-E=$1A=&54
M:6UE1F]R;6%T*")D+FTN62(L(")(.FDB*3L-"@T*+R\@1FER<W0@9V5T(&-O
M9&4@9F]R(&QO8V%T:6]N#0HD<V5A<F-H(#T@)&UE=&%R+3YS96%R8VA,;V-A
M=&EO;B@B0F]N;BP@1V5R;6%N>2(I.PT*:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)'-E87)C:"DI('L-"B`@("!D:64H(D5R<F]R.B`B+B1S96%R
M8V@M/F=E=$UE<W-A9V4H*2XB7&XB*3L-"GT-"@T*+R\@3F]W(&ET97)A=&4@
M=&AR;W5G:"!A=F%I;&%B;&4@9G5N8W1I;VYS(&9O<B!R971R:65V:6YG(&1A
M=&$-"F9O<F5A8V@@*&%R<F%Y*")G971,;V-A=&EO;B(L(")G971796%T:&5R
M(BP@(F=E=$9O<F5C87-T(BD@87,@)&9U;F-T:6]N*2![#0H@("`@)&1A=&$@
M/2`D;65T87(M/B1F=6YC=&EO;B@D<V5A<F-H*3L-"B`@("!I9B`H4V5R=FEC
M97-?5V5A=&AE<CHZ:7-%<G)O<B@D9&%T82DI('L-"B`@("`@("`@96-H;R`B
M17)R;W(Z("(N)&1A=&$M/F=E=$UE<W-A9V4H*2XB7&XB.PT*("`@("`@("!C
M;VYT:6YU93L-"B`@("!]#0H-"B`@("!V87)?9'5M<"@D9&%T82D[#0I]#0H_
M/@T*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE
M<B]E>&%M<&QE<R]G;&]B86QW96%T:&5R+6)A<VEC+G!H<```````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S$V`#$P-#$W
M,S8S,#`T`#`R-S<V-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`T*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30Z("HO#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L-"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R
M<SH@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK#0HO+PT*+R\@)$ED.B!G;&]B86QW96%T:&5R+6)A<VEC+G!H<"QV
M(#$N,R`R,#`S+S$R+S,Q(#(S.C,Q.C(R(&5R=2!%>'`@)`T*#0IR97%U:7)E
M7V]N8V4@(E-E<G9I8V5S+U=E871H97(N<&AP(CL-"@T*+R\@3V)J96-T(&EN
M:71I86QI>F%T:6]N("T@97)R;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B
M96-A=7-E(&]F#0HO+R!H86YD;&EN9R!E>&-E<'1I;VYS('-U8V@@87,@;6ES
M<VEN9R!014%2(&UO9'5L97,@;W(@;F]T(&)E:6YG(&]N;&EN90T*)&=L;V)A
M;'=E871H97(@/2`F4V5R=FEC97-?5V5A=&AE<CHZ<V5R=FEC92@B1VQO8F%L
M5V5A=&AE<B(L(&%R<F%Y*")D96)U9R(@/3X@,BDI.PT*:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)&=L;V)A;'=E871H97(I*2![#0H@("`@9&EE
M*")%<G)O<CH@(BXD9VQO8F%L=V5A=&AE<BT^9V5T365S<V%G92@I+B)<;B(I
M.PT*?0T*#0HO*B!%<F%S92!C;VUM96YT<R!T;R!E;F%B;&4@8V%C:&EN9PT*
M)&=L;V)A;'=E871H97(M/G-E=$-A8VAE*")F:6QE(BP@87)R87DH(F-A8VAE
M7V1I<B(@/3X@(B]T;7`O8V%C:&4O(BDI.PT*:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)&=L;V)A;'=E871H97(I*2![#0H@("`@96-H;R`B17)R
M;W(Z("(N)&=L;V)A;'=E871H97(M/F=E=$UE<W-A9V4H*2XB7&XB.PT*?0T*
M*B\-"@T*)&=L;V)A;'=E871H97(M/G-E=%5N:71S1F]R;6%T*")M971R:6,B
M*3L-"B1G;&]B86QW96%T:&5R+3YS971$871E5&EM949O<FUA="@B9"YM+EDB
M+"`B2#II(BD[#0H-"B\O($9I<G-T(&=E="!C;V1E(&9O<B!L;V-A=&EO;@T*
M)'-E87)C:"`]("1G;&]B86QW96%T:&5R+3YS96%R8VA,;V-A=&EO;B@B2V]E
M;&X@+R!";VYN(BD[#0II9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D
M<V5A<F-H*2D@>PT*("`@(&1I92@B17)R;W(Z("(N)'-E87)C:"T^9V5T365S
M<V%G92@I+B)<;B(I.PT*?0T*#0HO+R!.;W<@:71E<F%T92!T:')O=6=H(&%V
M86EL86)L92!F=6YC=&EO;G,@9F]R(')E=')I979I;F<@9&%T80T*9F]R96%C
M:"`H87)R87DH(F=E=$QO8V%T:6]N(BP@(F=E=%=E871H97(B+"`B9V5T1F]R
M96-A<W0B*2!A<R`D9G5N8W1I;VXI('L-"B`@("`D9&%T82`]("1G;&]B86QW
M96%T:&5R+3XD9G5N8W1I;VXH)'-E87)C:"D[#0H@("`@:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)&1A=&$I*2![#0H@("`@("`@(&5C:&\@(D5R
M<F]R.B`B+B1D871A+3YG971-97-S86=E*"DN(EQN(CL-"B`@("`@("`@8V]N
M=&EN=64[#0H@("`@?0T*#0H@("`@=F%R7V1U;7`H)&1A=&$I.PT*?0T*/SX-
M"@``````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O07)C
M:&EV95]487(O````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#`T`#`R,#0V,``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]!<F-H:79E7U1A<B]D;V-S+P``````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#(Q-#$P`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T%R8VAI=F5?5&%R+V1O
M8W,O07)C:&EV95]487(N='AT````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-#8Q,``Q,#0Q
M-S,V,S`P-``P,C0S-#(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1&]C=6UE;G1A=&EO;B!F;W(@8VQA<W,@07)C:&EV95]4
M87(-"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]#0I,87-T
M('5P9&%T92`Z(#(P,#$M,#@M,34-"@T*#0H-"D]V97)V:65W(#H-"BTM+2TM
M+2TM+2T-"@T*("!4:&4@07)C:&EV95]487(@8VQA<W,@:&5L<',@:6X@8W)E
M871I;F<@86YD(&UA;F%G:6YG($=.52!405(@9F]R;6%T#0H@(&9I;&5S(&-O
M;7!R97-S960@8GD@1TY5(%I)4"!O<B!N;W0N(`T*("!4:&4@8VQA<W,@;V9F
M97)S(&)A<VEC(&9U;F-T:6]N<R!L:6ME(&-R96%T:6YG(&%N(&%R8VAI=F4L
M(&%D9&EN9PT*("!F:6QE<R!I;B!T:&4@87)C:&EV92P@97AT<F%C=&EN9R!F
M:6QE<R!F<F]M('1H92!A<F-H:79E(&%N9"!L:7-T:6YG#0H@('1H92!A<F-H
M:79E(&-O;G1E;G0N(`T*("!)="!A;'-O('!R;W9I9&4@861V86YC960@9G5N
M8W1I;VYS('1H870@86QL;W<@=&AE(&%D9&EN9R!A;F0-"B`@97AT<F%C=&EO
M;B!O9B!F:6QE<R!W:71H('!A=&@@;6%N:7!U;&%T:6]N+B`-"@T*#0I386UP
M;&4@.@T*+2TM+2TM+2T-"@T*("`O+R`M+2TM+2!#<F5A=&EN9R!T:&4@;V)J
M96-T("AU;F-O;7!R97-S960@87)C:&EV92D-"B`@)'1A<E]O8FIE8W0@/2!N
M97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T87)?;V)J96-T
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4%))3E0I.PT*#0H@("\O
M("TM+2TM($-R96%T:6YG('1H92!A<F-H:79E#0H@("1V7VQI<W1;,%T](F9I
M;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&%T82\B.PT*("`D=E]L:7-T6S)=
M/2)F:6QE+FQO9R([#0H@("1T87)?;V)J96-T+3YC<F5A=&4H)'9?;&ES="D[
M#0H-"B`@+R\@+2TM+2T@061D:6YG(&9I;&5S#0H@("1V7VQI<W1;,%T](F1E
M=B]F:6QE+G1X="([#0H@("1V7VQI<W1;,5T](F1E=B]D871A+R([#0H@("1V
M7VQI<W1;,ET](FQO9R]F:6QE+FQO9R([#0H@("1T87)?;V)J96-T+3YA9&0H
M)'9?;&ES="D[#0H-"B`@+R\@+2TM+2T@061D:6YG(&UO<F4@9FEL97,-"B`@
M)'1A<E]O8FIE8W0M/F%D9"@B<F5L96%S92]N97=F:6QE+FQO9R!R96QE87-E
M+W)E861M92YT>'0B*3L-"@T*("`O+R`M+2TM+2!,:7-T:6YG('1H92!C;VYT
M96YT#0H@(&EF("@H)'9?;&ES="`@/2`@)'1A<E]O8FIE8W0M/FQI<W1#;VYT
M96YT*"DI("$](#`I#0H@("`@9F]R("@D:3TP.R`D:3QS:7IE;V8H)'9?;&ES
M="D[("1I*RLI#0H@("`@>PT*("`@("`@96-H;R`B1FEL96YA;64@.B<B+B1V
M7VQI<W1;)&E=6V9I;&5N86UE72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YS
M:7IE(#HG(BXD=E]L:7-T6R1I75MS:7IE72XB)SQB<CXB.PT*("`@("`@96-H
M;R`B("YM=&EM92`Z)R(N)'9?;&ES=%LD:5U;;71I;65=+B(G("@B+F1A=&4H
M(FP@9%,@;V8@1B!9(&@Z:3IS($$B+"`D=E]L:7-T6R1I75MM=&EM95TI+B(I
M/&)R/B([#0H@("`@("!E8VAO("(@+FUO9&4@.B<B+B1V7VQI<W1;)&E=6VUO
M9&5=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G5I9"`Z)R(N)'9?;&ES=%LD
M:5U;=6ED72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YG:60@.B<B+B1V7VQI
M<W1;)&E=6V=I9%TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N='EP969L86<@
M.B<B+B1V7VQI<W1;)&E=6W1Y<&5F;&%G72XB)SQB<CXB.PT*("`@('T-"@T*
M("`O+R`M+2TM+2!%>'1R86-T:6YG('1H92!A<F-H:79E(&EN(&1I<F5C=&]R
M>2`B:6YS=&%L;"(-"B`@)'1A<E]O8FIE8W0M/F5X=')A8W0H(FEN<W1A;&PB
M*3L-"@T*#0I0=6)L:6,@87)G=6UE;G1S(#H-"BTM+2TM+2TM+2TM+2TM+2TM
M+0T*#0I.;VYE#0H-"@T*4'5B;&EC($UE=&AO9',@.@T*+2TM+2TM+2TM+2TM
M+2TM+0T*#0I-971H;V0@.B!!<F-H:79E7U1A<B@D<%]T87)N86UE+"`D8V]M
M<')E<W,@/2!N=6QL*0T*1&5S8W)I<'1I;VX@.@T*("!!<F-H:79E7U1A<B!#
M;&%S<R!C;VYS=')U8W1O<BX@5&AI<R!F;&%V;W5R(&]F('1H92!C;VYS=')U
M8W1O<B!O;FQY#0H@(&1E8VQA<F4@82!N97<@07)C:&EV95]487(@;V)J96-T
M+"!I9&5N=&EF>6EN9R!I="!B>2!T:&4@;F%M92!O9B!T:&4-"B`@=&%R(&9I
M;&4N#0H@($EF('1H92!C;VUP<F5S<R!A<F=U;65N="!I<R!S970@=&AE('1A
M<B!W:6QL(&)E(')E860@;W(@8W)E871E9"!A<R!A#0H@(&=Z:7`@;W(@8GHR
M(&-O;7!R97-S960@5$%2(&9I;&4N(`T*07)G=6UE;G1S(#H-"B`@)'!?=&%R
M;F%M92`Z($$@=F%L:60@9FEL96YA;64@9F]R('1H92!T87(@87)C:&EV92!F
M:6QE+@T*("`D<%]C;VUP<F5S<R`Z(&-A;B!B92!N=6QL+"`G9WHG(&]R("=B
M>C(G+B!&;W(-"B`@("`@("`@("`@("`@("!C;VUP871I8FEL:71Y(')E87-O
M;B!I="!C86X@86QS;R!B92!T<G5E+B!4:&ES#0H@("`@("`@("`@("`@("`@
M<&%R86UE=&5R(&EN9&EC871E<R!I9B!G>FEP(&]R(&)Z,B!C;VUP<F5S<VEO
M;@T*("`@("`@("`@("`@("`@(&ES(')E<75I<F5D+B`-"E)E='5R;B!V86QU
M92`Z#0H@(%1H92!!<F-H:79E7U1A<B!O8FIE8W0N#0I386UP;&4@.@T*("`D
M=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-
M"B`@)'1A<E]O8FIE8W1?8V]M<')E<W-E9"`](&YE=R!!<F-H:79E7U1A<B@B
M=&%R;F%M92YT9WHB+"!T<G5E*3L-"DAO=R!I="!W;W)K<R`Z#0H@($EN:71I
M86QI>F4@=&AE(&]B:F5C="X-"@T*365T:&]D(#H@8W)E871E*"1P7V9I;&5L
M:7-T*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!C<F5A=&5S('1H
M92!A<F-H:79E(&9I;&4@86YD(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O<FEE
M<PT*("!T:&%T(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0N(`T*("!)9B!T
M:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&%B;&4L(&ET(&ES
M(')E<&QA8V5D(&)Y('1H90T*("!N97<@=&%R+B!)="!I<R!A(&-R96%T92!A
M;F0@;F]T(&%N(&%D9"X@268@=&AE(&9I;&4@97AI<W1S(&%N9"!I<PT*("!R
M96%D+6]N;'D@;W(@:7,@82!D:7)E8W1O<GD@:70@:7,@;F]T(')E<&QA8V5D
M+B!4:&4@;65T:&]D(')E='5R;@T*("!F86QS92!A;F0@82!014%2(&5R<F]R
M('1E>'0N(`T*("!4:&4@)'!?9FEL96QI<W0@<&%R86UE=&5R(&-A;B!B92!A
M;B!A<G)A>2!O9B!S=')I;F<L(&5A8V@@<W1R:6YG#0H@(')E<')E<V5N=&EN
M9R!A(&9I;&5N86UE(&]R(&$@9&ER96-T;W)Y(&YA;64@=VET:"!T:&5I<B!P
M871H(&EF#0H@(&YE961E9"X@270@8V%N(&%L<V\@8F4@82!S:6YG;&4@<W1R
M:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-"B`@<VEN9VQE(&)L86YK
M+B`-"B`@4V5E(&%L<V\@8W)E871E36]D:69Y*"D@;65T:&]D(&9O<B!M;W)E
M(&1E=&%I;',N#0I!<F=U;65N=',@.@T*("`D<%]F:6QE;&ES="`Z($%N(&%R
M<F%Y(&]F(&9I;&5N86UE<R!A;F0@9&ER96-T;W)Y(&YA;65S+"!O<B!A('-I
M;F=L90T*("!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@82!S:6YG
M;&4@8FQA;FL@<W!A8V4N(`T*4F5T=7)N('9A;'5E(#H-"B`@=')U92!O;B!S
M=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"E-A;7!L92`Q(#H-"B`@)'1A<E]O
M8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T
M87)?;V)J96-T+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4%))3E0I
M.R`@+R\@3W!T:6]N86P@97)R;W(@:&%N9&QI;F<-"B`@)'9?;&ES=%LP73TB
M9FEL92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D871A+R([("A/<'1I;VYA;"`G
M+R<@870@=&AE(&5N9"D-"B`@)'9?;&ES=%LR73TB9FEL92YL;V<B.PT*("`D
M=&%R7V]B:F5C="T^8W)E871E*"1V7VQI<W0I.PT*4V%M<&QE(#(@.@T*("`D
M=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-
M"B`@)'1A<E]O8FIE8W0M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]0
M4DE.5"D[("`O+R!/<'1I;VYA;"!E<G)O<B!H86YD;&EN9PT*("`D=&%R7V]B
M:F5C="T^8W)E871E*")F:6QE+G1X="!D871A+R!F:6QE+FQO9R(I.PT*2&]W
M(&ET('=O<FMS(#H-"B`@2G5S="!C86QL:6YG('1H92!C<F5A=&5-;V1I9GDH
M*2!M971H;V0@=VET:"!T:&4@<FEG:'0@<&%R86UE=&5R<RX-"@T*365T:&]D
M(#H@8W)E871E36]D:69Y*"1P7V9I;&5L:7-T+"`D<%]A9&1?9&ER+"`D<%]R
M96UO=F5?9&ER(#T@(B(I#0I$97-C<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D
M(&-R96%T97,@=&AE(&%R8VAI=F4@9FEL92!A;F0@861D('1H92!F:6QE<R`O
M(&1I<F5C=&]R:65S#0H@('1H870@87)E(&QI<W1E9"!I;B`D<%]F:6QE;&ES
M="X@#0H@($EF('1H92!F:6QE(&%L<F5A9'D@97AI<W1S(&%N9"!I<R!W<FET
M86)L92P@:70@:7,@<F5P;&%C960@8GD@=&AE#0H@(&YE=R!T87(N($ET(&ES
M(&$@8W)E871E(&%N9"!N;W0@86X@861D+B!)9B!T:&4@9FEL92!E>&ES=',@
M86YD(&ES#0H@(')E860M;VYL>2!O<B!I<R!A(&1I<F5C=&]R>2!I="!I<R!N
M;W0@<F5P;&%C960N(%1H92!M971H;V0@<F5T=7)N#0H@(&9A;'-E(&%N9"!A
M(%!%05(@97)R;W(@=&5X="X@#0H@(%1H92`D<%]F:6QE;&ES="!P87)A;65T
M97(@8V%N(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@96%C:"!S=')I;F<-"B`@
M<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@;F%M92!W
M:71H('1H96ER('!A=&@@:68-"B`@;F5E9&5D+B!)="!C86X@86QS;R!B92!A
M('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@80T*("!S
M:6YG;&4@8FQA;FLN(`T*("!4:&4@<&%T:"!I;F1I8V%T960@:6X@)'!?<F5M
M;W9E7V1I<B!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4-"B`@;65M;W)I>F5D
M('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"!W:&5N('1H
M:7,@<&%T:`T*("!E>&ES=',N($)Y(&1E9F%U;'0@;F]T:&EN9R!I<R!R96UO
M=F5D("AE;7!T>2!P871H("(B*2`-"B`@5&AE('!A=&@@:6YD:6-A=&5D(&EN
M("1P7V%D9%]D:7(@=VEL;"!B92!A9&1E9"!A="!T:&4@8F5G:6YN:6YG(&]F
M#0H@('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&9I;&4@+R!D:7)E8W1O
M<GD@;&ES=&5D+B!(;W=E=F5R(&ET(&-A;@T*("!B92!S970@=&\@96UP='D@
M(B(N(%1H92!A9&1I;F<@;V8@82!P871H(&ES(&1O;F4@869T97(@=&AE(')E
M;6]V:6YG#0H@(&]F('!A=&@N(`T*("!4:&4@<&%T:"!A9&0O<F5M;W9E(&%B
M:6QI='D@96YA8FQE<R!T:&4@=7-E<B!T;R!P<F5P87)E(&%N(&%R8VAI=F4-
M"B`@9F]R(&5X=')A8W1I;VX@:6X@82!D:69F97)E;G0@<&%T:"!T:&%N('1H
M92!O<FEG:6X@9FEL97,@87)E+B`-"B`@4V5E(&%L<V\@861D36]D:69Y*"D@
M;65T:&]D(&9O<B!F:6QE(&%D9&EN9R!P<F]P97)T:65S+@T*07)G=6UE;G1S
M(#H-"B`@)'!?9FEL96QI<W0@.B!!;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD
M(&1I<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-"B`@("`@("`@("`@("`@
M("!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@82!S:6YG;&4@8FQA
M;FL@<W!A8V4N#0H@("1P7V%D9%]D:7(@.B!!('-T<FEN9R!W:&EC:"!C;VYT
M86EN<R!A('!A=&@@=&\@8F4@861D960@=&\@=&AE#0H@("`@("`@("`@("`@
M("!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@=&AE(&QI<W0N
M(`T*("`D<%]R96UO=F5?9&ER(#H@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@
M82!P871H('1O(&)E(')E;6]V960@9G)O;0T*("`@("`@("`@("`@("`@("`@
M=&AE(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@96QE;65N="!I;B!T:&4@;&ES
M="P@=VAE;@T*"0D@(')E;&5V86YT+@T*4F5T=7)N('9A;'5E(#H-"B`@=')U
M92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"E-A;7!L92`Q(#H-"B`@
M)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[
M#0H@("1T87)?;V)J96-T+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4%))3E0I.R`@+R\@3W!T:6]N86P@97)R;W(@:&%N9&QI;F<-"B`@)'9?;&ES
M=%LP73TB9FEL92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D871A+R([("A/<'1I
M;VYA;"`G+R<@870@=&AE(&5N9"D-"B`@)'9?;&ES=%LR73TB9FEL92YL;V<B
M.PT*("`D=&%R7V]B:F5C="T^8W)E871E36]D:69Y*"1V7VQI<W0L(")I;G-T
M86QL(BD[#0H@("\O(&9I;&5S(&%R92!S=&]R960@:6X@=&AE(&%R8VAI=F4@
M87,@.@T*("`O+R`@(&EN<W1A;&PO9FEL92YT>'0-"B`@+R\@("!I;G-T86QL
M+V1A=&$-"B`@+R\@("!I;G-T86QL+V1A=&$O9FEL93$N='AT#0H@("\O("`@
M:6YS=&%L;"]D871A+RXN+B!A;&P@=&AE(&9I;&5S(&%N9"!S=6(M9&ER<R!O
M9B!D871A+PT*("`O+R`@(&EN<W1A;&PO9FEL92YL;V<-"E-A;7!L92`R(#H-
M"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R
M(BD[#0H@("1T87)?;V)J96-T+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4%))3E0I.R`@+R\@3W!T:6]N86P@97)R;W(@:&%N9&QI;F<-"B`@)'9?
M;&ES=%LP73TB9&5V+V9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A
M=&$O(CL@*$]P=&EO;F%L("<O)R!A="!T:&4@96YD*0T*("`D=E]L:7-T6S)=
M/2)L;V<O9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^8W)E871E36]D:69Y
M*"1V7VQI<W0L(")I;G-T86QL(BP@(F1E=B(I.PT*("`O+R!F:6QE<R!A<F4@
M<W1O<F5D(&EN('1H92!A<F-H:79E(&%S(#H-"B`@+R\@("!I;G-T86QL+V9I
M;&4N='AT#0H@("\O("`@:6YS=&%L;"]D871A#0H@("\O("`@:6YS=&%L;"]D
M871A+V9I;&4Q+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T82\N+BX@86QL('1H
M92!F:6QE<R!A;F0@<W5B+61I<G,@;V8@9&%T82\-"B`@+R\@("!I;G-T86QL
M+VQO9R]F:6QE+FQO9PT*2&]W(&ET('=O<FMS(#H-"B`@3W!E;B!T:&4@9FEL
M92!I;B!W<FET92!M;V1E("AE<F%S:6YG('1H92!E>&ES=&EN9R!O;F4@:68@
M;VYE*2P-"B`@8V%L;"!T:&4@7V%D9$QI<W0H*2!M971H;V0@9F]R(&%D9&EN
M9R!T:&4@9FEL97,@:6X@86X@96UP='D@87)C:&EV92P-"B`@861D('1H92!T
M87(@9F]O=&5R("@U,3(@8GET97,@8FQO8VLI+"!C;&]S92!T:&4@=&%R(&9I
M;&4N#0H-"@T*365T:&]D(#H@861D36]D:69Y*"1P7V9I;&5L:7-T+"`D<%]A
M9&1?9&ER+"`D<%]R96UO=F5?9&ER/2(B*0T*1&5S8W)I<'1I;VX@.@T*("!4
M:&ES(&UE=&AO9"!A9&0@=&AE(&9I;&5S("\@9&ER96-T;W)I97,@;&ES=&5D
M(&EN("1P7V9I;&5L:7-T(&%T('1H90T*("!E;F0@;V8@=&AE(&5X:7-T:6YG
M(&%R8VAI=F4N($EF('1H92!A<F-H:79E(&1O97,@;F]T('EE="!E>&ES=',@
M:70-"B`@:7,@8W)E871E9"X-"B`@5&AE("1P7V9I;&5L:7-T('!A<F%M971E
M<B!C86X@8F4@86X@87)R87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("!R
M97!R97-E;G1I;F<@82!F:6QE;F%M92!O<B!A(&1I<F5C=&]R>2!N86UE('=I
M=&@@=&AE:7(@<&%T:"!I9@T*("!N965D960N($ET(&-A;B!A;'-O(&)E(&$@
M<VEN9VQE('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B>2!A#0H@('-I
M;F=L92!B;&%N:RX@#0H@(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]R96UO
M=F5?9&ER('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H90T*("!M96UO<FEZ960@
M<&%T:"!O9B!E86-H(&9I;&4@+R!D:7)E8W1O<GD@;&ES=&5D('=H96X@=&AI
M<R!P871H#0H@(&5X:7-T<RX@0GD@9&5F875L="!N;W1H:6YG(&ES(')E;6]V
M960@*&5M<'1Y('!A=&@@(B(I(`T*("!4:&4@<&%T:"!I;F1I8V%T960@:6X@
M)'!?861D7V1I<B!W:6QL(&)E(&%D9&5D(&%T('1H92!B96=I;FYI;F<@;V8-
M"B`@=&AE(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R
M>2!L:7-T960N($AO=V5V97(@:70@8V%N#0H@(&)E('-E="!T;R!E;7!T>2`B
M(BX@5&AE(&%D9&EN9R!O9B!A('!A=&@@:7,@9&]N92!A9G1E<B!T:&4@<F5M
M;W9I;F<-"B`@;V8@<&%T:"X@#0H@(%1H92!P871H(&%D9"]R96UO=F4@86)I
M;&ET>2!E;F%B;&5S('1H92!U<V5R('1O('!R97!A<F4@86X@87)C:&EV90T*
M("!F;W(@97AT<F%C=&EO;B!I;B!A(&1I9F9E<F5N="!P871H('1H86X@=&AE
M(&]R:6=I;B!F:6QE<R!A<F4N(`T*("!)9B!A(&9I;&4O9&ER(&ES(&%L<F5A
M9'D@:6X@=&AE(&%R8VAI=F4@:70@=VEL;"!O;FQY(&)E(&%D9&5D(&%T('1H
M90T*("!E;F0@;V8@=&AE(&%R8VAI=F4N(%1H97)E(&ES(&YO('5P9&%T92!O
M9B!T:&4@97AI<W1I;F<@87)C:&EV960-"B`@9FEL92]D:7(N($AO=V5V97(@
M=VAI;&4@97AT<F%C=&EN9R!T:&4@87)C:&EV92P@=&AE(&QA<W0@9FEL92!W
M:6QL#0H@(')E<&QA8V4@=&AE(&9I<G-T(&]N92X@5&AI<R!R97-U;'1S(&EN
M(&$@;F]N92!O<'1I;6EZ871I;VX@;V8@=&AE#0H@(&%R8VAI=F4@<VEZ92X@
M#0H@($EF(&$@9FEL92]D:7(@9&]E<R!N;W0@97AI<W0@=&AE(&9I;&4O9&ER
M(&ES(&EG;F]R960N($AO=V5V97(@86X-"B`@97)R;W(@=&5X="!I<R!S96YD
M('1O(%!%05(@97)R;W(N(`T*("!)9B!A(&9I;&4O9&ER(&ES(&YO="!R96%D
M86)L92!T:&4@9FEL92]D:7(@:7,@:6=N;W)E9"X@2&]W979E<B!A;@T*("!E
M<G)O<B!T97AT(&ES('-E;F0@=&\@4$5!4B!E<G)O<BX@#0H@($EF('1H92!R
M97-U;'1I;F<@9FEL96YA;64O9&ER;F%M92`H869T97(@=&AE(&%D9"]R96UO
M=F4@;W!T:6]N(&]R#0H@(&YO="D@<W1R:6YG(&ES(&=R96%T97(@=&AA;B`Y
M.2!C:&%R+"!T:&4@9FEL92]D:7(@:7,-"B`@:6=N;W)E9"X@2&]W979E<B!A
M;B!E<G)O<B!T97AT(&ES('-E;F0@=&\@4$5!4B!E<G)O<BX@#0I!<F=U;65N
M=',@.@T*("`D<%]F:6QE;&ES="`Z($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A
M;F0@9&ER96-T;W)Y(&YA;65S+"!O<B!A('-I;F=L90T*("`@("`@("`@("`@
M("`@('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B>2!A('-I;F=L92!B
M;&%N:R!S<&%C92X@#0H@("1P7V%D9%]D:7(@.B!!('-T<FEN9R!W:&EC:"!C
M;VYT86EN<R!A('!A=&@@=&\@8F4@861D960@=&\@=&AE#0H@("`@("`@("`@
M("`@("!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@=&AE(&QI
M<W0N(`T*("`D<%]R96UO=F5?9&ER(#H@02!S=')I;F<@=VAI8V@@8V]N=&%I
M;G,@82!P871H('1O(&)E(')E;6]V960@9G)O;0T*("`@("`@("`@("`@("`@
M("`@=&AE(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@96QE;65N="!I;B!T:&4@
M;&ES="P@=VAE;@T*"0D@(')E;&5V86YT+@T*4F5T=7)N('9A;'5E(#H-"B`@
M=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"E-A;7!L92`Q(#H-
M"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R
M(BD[#0H@(%LN+BY=#0H@("1V7VQI<W1;,%T](F1E=B]F:6QE+G1X="([#0H@
M("1V7VQI<W1;,5T](F1E=B]D871A+R([("A/<'1I;VYA;"`G+R<@870@=&AE
M(&5N9"D-"B`@)'9?;&ES=%LR73TB;&]G+V9I;&4N;&]G(CL-"B`@)'1A<E]O
M8FIE8W0M/F%D9$UO9&EF>2@D=E]L:7-T+"`B:6YS=&%L;"(I.PT*("`O+R!F
M:6QE<R!A<F4@<W1O<F5D(&EN('1H92!A<F-H:79E(&%S(#H-"B`@+R\@("!I
M;G-T86QL+V9I;&4N='AT#0H@("\O("`@:6YS=&%L;"]D871A#0H@("\O("`@
M:6YS=&%L;"]D871A+V9I;&4Q+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T82\N
M+BX@86QL('1H92!F:6QE<R!A;F0@<W5B+61I<G,@;V8@9&%T82\-"B`@+R\@
M("!I;G-T86QL+V9I;&4N;&]G#0I386UP;&4@,B`Z#0H@("1T87)?;V)J96-T
M(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("!;+BXN70T*
M("`D=E]L:7-T6S!=/2)D978O9FEL92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D
M978O9&%T82\B.R`H3W!T:6]N86P@)R\G(&%T('1H92!E;F0I#0H@("1V7VQI
M<W1;,ET](FQO9R]F:6QE+FQO9R([#0H@("1T87)?;V)J96-T+3YA9&1-;V1I
M9GDH)'9?;&ES="P@(FEN<W1A;&PB+"`B9&5V(BD[#0H@("\O(&9I;&5S(&%R
M92!S=&]R960@:6X@=&AE(&%R8VAI=F4@87,@.@T*("`O+R`@(&EN<W1A;&PO
M9FEL92YT>'0-"B`@+R\@("!I;G-T86QL+V1A=&$-"B`@+R\@("!I;G-T86QL
M+V1A=&$O9FEL93$N='AT#0H@("\O("`@:6YS=&%L;"]D871A+RXN+B!A;&P@
M=&AE(&9I;&5S(&%N9"!S=6(M9&ER<R!O9B!D871A+PT*("`O+R`@(&EN<W1A
M;&PO;&]G+V9I;&4N;&]G#0I(;W<@:70@=V]R:W,@.@T*("!)9B!T:&4@87)C
M:&EV92!D;V5S(&YO="!E>&ES=',@:70@8W)E871E(&ET(&%N9"!A9&0@=&AE
M(&9I;&5S+@T*("!)9B!T:&4@87)C:&EV92!D;V5S(&5X:7-T<R!A;F0@:7,@
M;F]T(&-O;7!R97-S960L(&ET(&]P96X@:70L(&IU;7`-"B`@8F5F;W)E('1H
M92!L87-T(&5M<'1Y(#4Q,B!B>71E<R!B;&]C:R`H=&%R(&9O;W1E<BD@86YD
M(&%D9"!T:&4@9FEL97,-"B`@870@=&AI<R!P;VEN="X-"B`@268@=&AE(&%R
M8VAI=F4@9&]E<R!E>&ES=',@86YD(&ES(&-O;7!R97-S960L(&$@=&5M<&]R
M87)Y(&-O<'D@9FEL90T*("!I<R!C<F5A=&5D+B!4:&ES('1E;7!O<F%R>2!F
M:6QE(&ES('1H96X@)V=Z:7`G(')E860@8FQO8VL@8GD@8FQO8VL-"B`@=6YT
M:6P@=&AE(&QA<W0@96UP='D@8FQO8VLN(%1H92!N97<@9FEL97,@87)E('1H
M96X@861D960@:6X@=&AE#0H@(&-O;7!R97-S960@9FEL92X-"B`@5&AE(&%D
M9&EN9R!O9B!F:6QE<R!I<R!D;VYE(&)Y(&=O:6YG('1H<F]U9V@@=&AE(&9I
M;&4O9&ER(&QI<W0L#0H@(&%D9&EN9R!F:6QE<R!P97(@9FEL97,L(&EN(&$@
M<F5C=7)S:79E('=A>2!T:')O=6=H('1H90T*("!D:7)E8W1O<GDN($5A8V@@
M=&EM92!A('!A=&@@;F5E9"!T;R!B92!A9&1E9"]R96UO=F5D(&ET(&ES(&1O
M;F4-"B`@8F5F;W)E('=R:71I;F<@=&AE(&9I;&4@:&5A9&5R(&EN('1H92!A
M<F-H:79E+@T*#0I-971H;V0@.B!A9&0H)'!?9FEL96QI<W0I#0I$97-C<FEP
M=&EO;B`Z#0H@(%1H:7,@;65T:&]D(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O
M<FEE<R!L:7-T960@:6X@)'!?9FEL96QI<W0@870@=&AE#0H@(&5N9"!O9B!T
M:&4@97AI<W1I;F<@87)C:&EV92X@268@=&AE(&%R8VAI=F4@9&]E<R!N;W0@
M>65T(&5X:7-T<R!I=`T*("!I<R!C<F5A=&5D+B`-"B`@5&AE("1P7V9I;&5L
M:7-T('!A<F%M971E<B!C86X@8F4@86X@87)R87D@;V8@<W1R:6YG+"!E86-H
M('-T<FEN9PT*("!R97!R97-E;G1I;F<@82!F:6QE;F%M92!O<B!A(&1I<F5C
M=&]R>2!N86UE('=I=&@@=&AE:7(@<&%T:"!I9@T*("!N965D960N($ET(&-A
M;B!A;'-O(&)E(&$@<VEN9VQE('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E
M9"!B>2!A#0H@('-I;F=L92!B;&%N:RX@#0H@(%-E92!A9&1-;V1I9GDH*2!M
M971H;V0@9F]R(&1E=&%I;',@86YD(&QI;6ET871I;VYS+@T*07)G=6UE;G1S
M(#H-"B`@)'!?9FEL96QI<W0@.B!!;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD
M(&1I<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-"B`@<W1R:6YG('=I=&@@
M;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L86YK('-P86-E+B`-"E)E
M='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R
M;W(N#0I386UP;&4@,2`Z#0H@("1T87)?;V)J96-T(#T@;F5W($%R8VAI=F5?
M5&%R*")T87)N86UE+G1A<B(I.PT*("!;+BXN70T*("`D=E]L:7-T6S!=/2)D
M978O9FEL92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D978O9&%T82\B.R`H3W!T
M:6]N86P@)R\G(&%T('1H92!E;F0I#0H@("1V7VQI<W1;,ET](FQO9R]F:6QE
M+FQO9R([#0H@("1T87)?;V)J96-T+3YA9&0H)'9?;&ES="D[#0I386UP;&4@
M,B`Z#0H@("1T87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE
M+G1G>B(L('1R=64I.PT*("!;+BXN70T*("`D=E]L:7-T6S!=/2)D978O9FEL
M92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D978O9&%T82\B.R`H3W!T:6]N86P@
M)R\G(&%T('1H92!E;F0I#0H@("1V7VQI<W1;,ET](FQO9R]F:6QE+FQO9R([
M#0H@("1T87)?;V)J96-T+3YA9&0H)'9?;&ES="D[#0I(;W<@:70@=V]R:W,@
M.@T*("!3:6UP;'D@8V%L;"!T:&4@861D36]D:69Y*"D@;65T:&]D('=I=&@@
M=&AE(')I9VAT('!A<F%M971E<G,N#0H-"DUE=&AO9"`Z(&%D9%-T<FEN9R@D
M<%]F:6QE;F%M92P@)'!?<W1R:6YG*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES
M(&UE=&AO9"!A9&0@82!S:6YG;&4@<W1R:6YG(&%S(&$@9FEL92!A="!T:&4-
M"B`@96YD(&]F('1H92!E>&ES=&EN9R!A<F-H:79E+B!)9B!T:&4@87)C:&EV
M92!D;V5S(&YO="!Y970@97AI<W1S(&ET#0H@(&ES(&-R96%T960N#0I!<F=U
M;65N=',@.@T*("`D<%]F:6QE;F%M92`Z($$@<W1R:6YG('=H:6-H(&-O;G1A
M:6YS('1H92!F=6QL(&9I;&5N86UE('!A=&@-"B`@("`@("`@("`@("`@("!T
M:&%T('=I;&P@8F4@87-S;V-I871E9"!W:71H('1H92!S=')I;F<N#0H@("1P
M7W-T<FEN9R`Z("`@5&AE(&-O;G1E;G0@;V8@=&AE(&9I;&4@861D960@:6X@
M=&AE(&%R8VAI=F4N#0I2971U<FX@=F%L=64@.@T*("!T<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]N(&5R<F]R+@T*4V%M<&QE(#$@.@T*("`D=E]A<F-H:79E
M(#T@)B!N97<@07)C:&EV95]487(H)'!?9FEL96YA;64I.PT*("`D=E]A<F-H
M:79E+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4%))3E0I.PT*("`D
M=E]R97-U;'0@/2`D=E]A<F-H:79E+3YA9&13=')I;F<H)V1A=&$O=&5S="YT
M>'0G+"`G5&AI<R!I<R!T:&4@=&5X="!O9B!T:&4@<W1R:6YG)RD[#0H-"@T*
M365T:&]D(#H@97AT<F%C="@D<%]P871H(#T@(B(I#0I$97-C<FEP=&EO;B`Z
M#0H@(%1H:7,@;65T:&]D(&5X=')A8W0@86QL('1H92!C;VYT96YT(&]F('1H
M92!A<F-H:79E(&EN('1H92!D:7)E8W1O<GD-"B`@:6YD:6-A=&5D(&)Y("1P
M7W!A=&@N268@)'!?<&%T:"!I<R!O<'1I;VYA;"P@:68@;F]T('-E="!T:&4@
M87)C:&EV90T*("!I<R!E>'1R86-T960@:6X@=&AE(&-U<G)E;G0@9&ER96-T
M;W)Y+B`-"B`@5VAI;&4@97AT<F%C=&EN9R!A(&9I;&4L(&EF('1H92!D:7)E
M8W1O<GD@<&%T:"!D;V5S(&YO="!E>&ES=',@:70@:7,-"B`@8W)E871E9"X@
M#0H@(%-E92!E>'1R86-T36]D:69Y*"D@9F]R(&1E=&%I;',@86YD(&QI;6ET
M871I;VYS+@T*07)G=6UE;G1S(#H-"B`@)'!?<&%T:"`Z($]P=&EO;F%L('!A
M=&@@=VAE<F4@=&AE(&9I;&5S+V1I<B!N965D('1O(&)Y(&5X=')A8W1E9"X-
M"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@
M97)R;W(N#0I386UP;&4@.@T*("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E
M7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@)'1A<E]O8FIE8W0M/F5X=')A8W0H
M*3L-"DAO=R!I="!W;W)K<R`Z#0H@(%-I;7!L>2!C86QL('1H92!E>'1R86-T
M36]D:69Y*"D@;65T:&]D('=I=&@@87!P<F]P<FEA=&4@<&%R86UE=&5R<RX-
M"@T*365T:&]D(#H@97AT<F%C=$UO9&EF>2@D<%]P871H+"`D<%]R96UO=F5?
M<&%T:"D-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@97AT<F%C="!A
M;&P@=&AE(&-O;G1E;G0@;V8@=&AE(&%R8VAI=F4@:6X@=&AE(&1I<F5C=&]R
M>0T*("!I;F1I8V%T960@8GD@)'!?<&%T:"X@5VAE;B!R96QE=F%N="!T:&4@
M;65M;W)I>F5D('!A=&@@;V8@=&AE#0H@(&9I;&5S+V1I<B!C86X@8F4@;6]D
M:69I960@8GD@<F5M;W9I;F<@=&AE("1P7W)E;6]V95]P871H('!A=&@@870@
M=&AE#0H@(&)E9VEN;FEN9R!O9B!T:&4@9FEL92]D:7(@<&%T:"X@#0H@(%=H
M:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!T:&4@9&ER96-T;W)Y('!A=&@@
M9&]E<R!N;W0@97AI<W1S(&ET(&ES#0H@(&-R96%T960N(`T*("!7:&EL92!E
M>'1R86-T:6YG(&$@9FEL92P@:68@=&AE(&9I;&4@86QR96%D>2!E>&ES=',@
M:70@:7,@<F5P;&%C960-"B`@=VET:&]U="!L;V]K:6YG(&9O<B!L87-T(&UO
M9&EF:6-A=&EO;B!D871E+B`-"B`@5VAI;&4@97AT<F%C=&EN9R!A(&9I;&4L
M(&EF('1H92!F:6QE(&%L<F5A9'D@97AI<W1S(&%N9"!I<R!W<FET90T*("!P
M<F]T96-T960L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N(`T*("!7:&EL
M92!E>'1R86-T:6YG(&$@9FEL92P@:68@82!D:7)E8W1O<GD@=VET:"!T:&4@
M<V%M92!N86UE(&%L<F5A9'D-"B`@97AI<W1S+"!T:&4@97AT<F%C=&EO;B!I
M<R!A8F]R=&5D+B`-"B`@5VAI;&4@97AT<F%C=&EN9R!A(&1I<F5C=&]R>2P@
M:68@82!F:6QE('=I=&@@=&AE('-A;64@;F%M92!A;')E861Y#0H@(&5X:7-T
M<RP@=&AE(&5X=')A8W1I;VX@:7,@86)O<G1E9"X@#0H@(%=H:6QE(&5X=')A
M8W1I;F<@82!F:6QE+V1I<F5C=&]R>2!I9B!T:&4@9&5S=&EN871I;VX@9&ER
M96-T;W)Y(&5X:7-T#0H@(&%N9"!I<R!W<FET92!P<F]T96-T960L(&]R(&1O
M97,@;F]T(&5X:7-T(&)U="!C86X@;F]T(&)E(&-R96%T960L#0H@('1H92!E
M>'1R86-T:6]N(&ES(&%B;W)T960N(`T*("!)9B!A9G1E<B!E>'1R86-T:6]N
M(&%N(&5X=')A8W1E9"!F:6QE(&1O97,@;F]T('-H;W<@=&AE(&-O<G)E8W0-
M"B`@<W1O<F5D(&9I;&4@<VEZ92P@=&AE(&5X=')A8W1I;VX@:7,@86)O<G1E
M9"X@#0H@(%=H96X@=&AE(&5X=')A8W1I;VX@:7,@86)O<G1E9"P@82!014%2
M(&5R<F]R('1E>'0@:7,@<V5T(&%N9"!F86QS90T*("!I<R!R971U<FYE9"X@
M2&]W979E<B!T:&4@<F5S=6QT(&-A;B!B92!A('!A<G1I86P@97AT<F%C=&EO
M;B!T:&%T(&UA>0T*("!N965D('1O(&)E(&UA;G5A;&QY(&-L96%N960N(`T*
M07)G=6UE;G1S(#H-"B`@)'!?<&%T:"`Z(%1H92!P871H(&]F('1H92!D:7)E
M8W1O<GD@=VAE<F4@=&AE(&9I;&5S+V1I<B!N965D('1O(&)Y#0H@("`@("`@
M("`@("!E>'1R86-T960N(`T*("`D<%]R96UO=F5?<&%T:"`Z(%!A<G0@;V8@
M=&AE(&UE;6]R:7IE9"!P871H('1H870@8V%N(&)E(')E;6]V960@:68-"B`@
M("`@("`@("`@("`@("`@("!P<F5S96YT(&%T('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4O9&ER('!A=&@N(`T*4F5T=7)N('9A;'5E(#H-"B`@=')U92!O
M;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"E-A;7!L92`Z#0H@("\O($EM
M86=I;F4@=&%R;F%M92YT87(@=VET:"!F:6QE<R`Z#0H@("\O("`@9&5V+V1A
M=&$O9FEL92YT>'0-"B`@+R\@("!D978O9&%T82]L;V<N='AT#0H@("\O("`@
M<F5A9&UE+G1X=`T*("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B
M=&%R;F%M92YT87(B*3L-"B`@)'1A<E]O8FIE8W0M/F5X=')A8W1-;V1I9GDH
M(FEN<W1A;&PB+"`B9&5V(BD[#0H@("\O($9I;&5S('=I;&P@8F4@97AT<F%C
M=&5D('1H97)E(#H-"B`@+R\@("!I;G-T86QL+V1A=&$O9FEL92YT>'0-"B`@
M+R\@("!I;G-T86QL+V1A=&$O;&]G+G1X=`T*("`O+R`@(&EN<W1A;&PO<F5A
M9&UE+G1X=`T*2&]W(&ET('=O<FMS(#H-"B`@3W!E;B!T:&4@87)C:&EV92!A
M;F0@8V%L;"!A(&UO<F4@9V5N97)I8R!F=6YC=&EO;B!T:&%T(&-A;B!E>'1R
M86-T#0H@(&]N;'D@82!P87)T(&]F('1H92!A<F-H:79E(&]R(&%L;"!T:&4@
M87)C:&EV92X@#0H@(%-E92!E>'1R86-T3&ES="@I(&UE=&AO9"!F;W(@;6]R
M92!D971A:6QS+@T*#0I-971H;V0@.B!E>'1R86-T26Y3=')I;F<H)'!?9FEL
M96YA;64I#0I$97-C<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D(&5X=')A8W0@
M9G)O;2!T:&4@87)C:&EV92!O;F4@9FEL92!I9&5N=&EF:65D(&)Y("1P7V9I
M;&5N86UE+@T*("!4:&4@<F5T=7)N('9A;'5E(&ES(&$@<W1R:6YG('=I=&@@
M=&AE(&9I;&4@8V]N=&5N="P@;W(@3E5,3"!O;B!E<G)O<BX@#0I!<F=U;65N
M=',@.@T*("`D<%]F:6QE;F%M92`Z(%1H92!P871H(&]F('1H92!F:6QE('1O
M(&5X=')A8W0@:6X@82!S=')I;F<N(`T*4F5T=7)N('9A;'5E(#H-"B`@82!S
M=')I;F<@=VET:"!T:&4@9FEL92!C;VYT96YT(&]R($Y53$PN#0I386UP;&4@
M.@T*("`O+R!);6%G:6YE('1A<FYA;64N=&%R('=I=&@@9FEL97,@.@T*("`O
M+R`@(&1E=B]D871A+V9I;&4N='AT#0H@("\O("`@9&5V+V1A=&$O;&]G+G1X
M=`T*("`O+R`@(&1E=B]R96%D;64N='AT#0H@("1V7V%R8VAI=F4@/2`F(&YE
M=R!!<F-H:79E7U1A<B@G=&%R;F%M92YT87(G*3L-"B`@)'9?87)C:&EV92T^
M<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L-"B`@)'9?<W1R
M:6YG(#T@)'9?87)C:&EV92T^97AT<F%C=$EN4W1R:6YG*"=D978O<F5A9&UE
M+G1X="<I.PT*("!E8VAO("1V7W-T<FEN9SL-"@T*365T:&]D(#H@;&ES=$-O
M;G1E;G0H*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!R971U<FYS
M(&%N(&%R<F%Y(&]F(&%R<F%Y<R!T:&%T(&1E<V-R:6)E(&5A8V@-"B`@9FEL
M92]D:7)E8W1O<GD@<')E<V5N="!I;B!T:&4@87)C:&EV92X@#0H@(%1H92!A
M<G)A>2!I<R!N;W0@<V]R=&5D+"!S;R!I="!S:&]W('1H92!P;W-I=&EO;B!O
M9B!T:&4@9FEL92!I;B!T:&4-"B`@87)C:&EV92X@#0H@(%1H92!F:6QE(&EN
M9F]R;6%T:6]N<R!A<F4@.@T*("`@("1F:6QE6V9I;&5N86UE72`Z($YA;64@
M86YD('!A=&@@;V8@=&AE(&9I;&4O9&ER+@T*("`@("1F:6QE6VUO9&5=(#H@
M1FEL92!P97)M:7-S:6]N<R`H<F5S=6QT(&]F(&9I;&5P97)M<R@I*0T*("`@
M("1F:6QE6W5I9%T@.B!U<V5R(&ED#0H@("`@)&9I;&5;9VED72`Z(&=R;W5P
M(&ED#0H@("`@)&9I;&5;<VEZ95T@.B!F:6QE<VEZ90T*("`@("1F:6QE6VUT
M:6UE72`Z($QA<W0@;6]D:69I8V%T:6]N('1I;64@*')E<W5L="!O9B!F:6QE
M;71I;64H*2D-"B`@("`D9FEL95MT>7!E9FQA9UT@.B`B(B!F;W(@9FEL92P@
M(C4B(&9O<B!D:7)E8W1O<GD-"D%R9W5M96YT<R`Z#0I2971U<FX@=F%L=64@
M.@T*("!!;B!A<G)A>2!O9B!A<G)A>7,@;W(@,"!O;B!E<G)O<BX-"E-A;7!L
M92`Z#0H@("1T87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE
M+G1A<B(I.PT*("!I9B`H*"1V7VQI<W0@(#T@("1T87)?;V)J96-T+3YL:7-T
M0V]N=&5N="@I*2`A/2`P*0T*("`@(&9O<B`H)&D],#L@)&D\<VEZ96]F*"1V
M7VQI<W0I.R`D:2LK*0T*("`@('L-"B`@("`@(&5C:&\@(D9I;&5N86UE(#HG
M(BXD=E]L:7-T6R1I75MF:6QE;F%M95TN(B<\8G(^(CL-"B`@("`@(&5C:&\@
M(B`N<VEZ92`Z)R(N)'9?;&ES=%LD:5U;<VEZ95TN(B<\8G(^(CL-"B`@("`@
M(&5C:&\@(B`N;71I;64@.B<B+B1V7VQI<W1;)&E=6VUT:6UE72XB)R`H(BX-
M"B`@("`@("`@("`@9&%T92@B;"!D4R!O9B!&(%D@:#II.G,@02(L("1V7VQI
M<W1;)&E=6VUT:6UE72DN(BD\8G(^(CL-"B`@("`@(&5C:&\@(B`N;6]D92`Z
M)R(N)'9?;&ES=%LD:5U;;6]D95TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N
M=6ED(#HG(BXD=E]L:7-T6R1I75MU:61=+B(G/&)R/B([#0H@("`@("!E8VAO
M("(@+F=I9"`Z)R(N)'9?;&ES=%LD:5U;9VED72XB)SQB<CXB.PT*("`@("`@
M96-H;R`B("YT>7!E9FQA9R`Z)R(N)'9?;&ES=%LD:5U;='EP969L86==+B(G
M/&)R/B([#0H@("`@?0T*2&]W(&ET('=O<FMS(#H-"B`@0V%L;"!T:&4@<V%M
M92!F=6YC=&EO;B!A<R!A;B!E>'1R86-T(&AO=V5V97(@=VET:"!A(&9L86<@
M=&\@;VYL>2!G;PT*("!T:')O=6=H('1H92!A<F-H:79E('=I=&AO=70@97AT
M<F%C=&EN9R!T:&4@9FEL97,N(`T*#0I-971H;V0@.B!E>'1R86-T3&ES="@D
M<%]F:6QE;&ES="P@)'!?<&%T:"`]("(B+"`D<%]R96UO=F5?<&%T:"`]("(B
M*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!E>'1R86-T(&9R;VT@
M=&AE(&%R8VAI=F4@;VYL>2!T:&4@9FEL97,@:6YD:6-A=&5D(&EN('1H90T*
M("`D<%]F:6QE;&ES="X@5&AE<V4@9FEL97,@87)E(&5X=')A8W1E9"!I;B!T
M:&4@8W5R<F5N="!D:7)E8W1O<GD@;W(-"B`@:6X@=&AE(&1I<F5C=&]R>2!I
M;F1I8V%T960@8GD@=&AE(&]P=&EO;F%L("1P7W!A=&@@<&%R86UE=&5R+B`-
M"B`@268@:6YD:6-A=&5D('1H92`D<%]R96UO=F5?<&%T:"!C86X@8F4@=7-E
M9"!I;B!T:&4@<V%M92!W87D@87,@:70@:7,-"B`@=7-E9"!I;B!E>'1R86-T
M36]D:69Y*"D@;65T:&]D+B`-"D%R9W5M96YT<R`Z#0H@("1P7V9I;&5L:7-T
M(#H@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E8W1O<GD@;F%M97,L
M(&]R(&$@<VEN9VQE#0H@("`@("`@("`@("`@("`@<W1R:6YG('=I=&@@;F%M
M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L86YK('-P86-E+B`-"B`@)'!?
M<&%T:"`Z(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@=VAE<F4@=&AE(&9I
M;&5S+V1I<B!N965D('1O(&)Y#0H@("`@("`@("`@("!E>'1R86-T960N(`T*
M("`D<%]R96UO=F5?<&%T:"`Z(%!A<G0@;V8@=&AE(&UE;6]R:7IE9"!P871H
M('1H870@8V%N(&)E(')E;6]V960@:68-"B`@("`@("`@("`@("`@("`@("!P
M<F5S96YT(&%T('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4O9&ER('!A=&@N
M(`T*4F5T=7)N('9A;'5E(#H-"B`@=')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!E<G)O<BX-"E-A;7!L92`Z#0H@("\O($EM86=I;F4@=&%R;F%M92YT87(@
M=VET:"!F:6QE<R`Z#0H@("\O("`@9&5V+V1A=&$O9FEL92YT>'0-"B`@+R\@
M("!D978O9&%T82]L;V<N='AT#0H@("\O("`@<F5A9&UE+G1X=`T*("`D=&%R
M7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@
M)'1A<E]O8FIE8W0M/F5X=')A8W1,:7-T*")D978O9&%T82]F:6QE+G1X="!R
M96%D;64N='AT(BP@(FEN<W1A;&PB+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(F1E=B(I.PT*("`O+R!&:6QE<R!W:6QL(&)E(&5X=')A8W1E9"!T
M:&5R92`Z#0H@("\O("`@:6YS=&%L;"]D871A+V9I;&4N='AT#0H@("\O("`@
M:6YS=&%L;"]R96%D;64N='AT#0I(;W<@:70@=V]R:W,@.@T*("!';R!T:')O
M=6=H('1H92!A<F-H:79E(&%N9"!E>'1R86-T(&]N;'D@=&AE(&9I;&5S('!R
M97-E;G0@:6X@=&AE#0H@(&QI<W0N(`T*#0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R].971?55),+P``````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#$W-30Q`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]54DPO9&]C<R\`````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-``P,C`T
M-S$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7U523"]D
M;V-S+V5X86UP;&4N<&AP````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S8U
M`#$P-#$W,S8S,#`T`#`R,C8T-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,L(%)I8VAA
M<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70@("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V
M:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@
M87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C
M92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\
M"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P*+R\@?"!O(%)E9&ES
M=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@
M86)O=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN
M('1H92!\"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E
M<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@"B\O('P@
M;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O
M(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P*+R\@?"`@('!R;V1U8W1S(&1E
M<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I
M;W(@=W)I='1E;B`@?`HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!42$E3(%-/
M1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!
M3D0@0T].5%))0E543U)3("`@?`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!2
M15-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4
M("`@("!\"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%
M4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P*+R\@?"!!
M(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%
M3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`HO+R!\($]73D52($]2($-/3E12
M24)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)
M3D-)1$5.5$%,+"!\"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY3
M15%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P*
M+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/
M3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`HO+R!\($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!\"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@
M5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]2
M5"`@('P*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?`HO+R!\($]&
M(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"
M24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U+F]R
M9SX@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@)$ED.B!E>&%M<&QE+G!H<"QV(#$N."`R
M,#`T+S`Q+S$W(#$U.C4R.C4P('!A:F]Y92!%>'`@)`HO*BH**B!4:&ES(&5X
M86UP;&4@=VEL;"!D96-O9&4@=&AE('5R;"!G:79E;B!A;F0@9&ES<&QA>2!I
M=',**B!C;VYS=&ET=65N="!P87)T<RX**B\*"@EI;F-L=61E*"=.970O55),
M+G!H<"<I.PH*"21U<FP@/2`F;F5W($YE=%]54DPH)VAT='`Z+R]W=W<N97AA
M;7!L92YC;VTO9F]O+V)A<B]I;F1E>"YP:'`_9F]O/6)A<B<I.PH_/@H\:'1M
M;#X*/&)O9'D^"@H\<')E/@I0<F]T;V-O;"XN+CH@/#\])'5R;"T^<')O=&]C
M;VP_/@H*57-E<FYA;64N+BXZ(#P_/21U<FPM/G5S97(_/@H*4&%S<W=O<F0N
M+BXZ(#P_/21U<FPM/G!A<W,_/@H*4V5R=F5R+BXN+BXZ(#P_/21U<FPM/FAO
M<W0_/@H*4&]R="XN+BXN+BXZ(#P_/21U<FPM/G!O<G0_/@H*1FEL92]P871H
M+BXZ(#P_/21U<FPM/G!A=&@_/@H*475E<GES=')I;F<Z(#P_/21U<FPM/F=E
M=%%U97)Y4W1R:6YG*"D_/@H*06YC:&]R+BXN+BXZ(#P_/21U<FPM/F%N8VAO
M<C\^"@H*1G5L;"!54DPN+BXZ(#P_/21U<FPM/F=E=%5R;"@I/SX*/"]P<F4^
M"@H\+V)O9'D^"CPO:'1M;#X*```````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R](5$U,7U1R965-96YU+P``````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#(P
M-C0Q`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TA434Q?5')E
M94UE;G4O9&]C<R\`````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,S`P-``P,C$U-S$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1A=&$O````````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`Q-C(U,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]014%2+P``````````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P
M,#0`,#$W,#`Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+U!%
M05(O=&5M<&QA=&4N<W!E8P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S,P-P`Q,#0Q-S,V,S`P-``P,C$T-S``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````4W5M;6%R>3H@4$5!4CH@0'-U;6UA
M<GE`"DYA;64Z($!R<&U?<&%C:V%G94`*5F5R<VEO;CH@0'9E<G-I;VY`"E)E
M;&5A<V4Z(#$*3&EC96YS93H@0')E;&5A<V5?;&EC96YS94`*1W)O=7`Z($1E
M=F5L;W!M96YT+TQI8G)A<FEE<PI3;W5R8V4Z(&AT='`Z+R]`;6%S=&5R7W-E
M<G9E<D`O9V5T+T!P86-K86=E0"TE>W9E<G-I;VY]+G1G>@I"=6EL9%)O;W0Z
M("5[7W1M<'!A=&A]+R5[;F%M97TM<F]O=`I54DPZ(&AT='`Z+R]`;6%S=&5R
M7W-E<G9E<D`O"E!R969I>#H@)7M?<')E9FEX?0HC1&]C9&ER.B!`9&]C7V1I
M<D`O0'!A8VMA9V5`"D)U:6QD07)C:&ET96-T=7)E<SH@0&%R8VA`"D!E>'1R
M85]H96%D97)S0`H*)61E<V-R:7!T:6]N"D!D97-C<FEP=&EO;D`*"B5P<F5P
M"G)M("UR9B`E>V)U:6QD<F]O='TO*@HC(%A86"!3;W5R8V4@9FEL97,@;&]C
M871I;VX@:7,@;6ES<VEN9R!H97)E(&EN('!E87(@8VUD"G!E87(@+78@+6,@
M)7MB=6EL9')O;W1]+W!E87)R8R!<"B`@("`@("`@+60@<&AP7V1I<CTE>U]L
M:6)D:7)]+W!H<"]P96%R(%P*("`@("`@("`M9"!D;V-?9&ER/2]D;V-S(%P*
M("`@("`@("`M9"!B:6Y?9&ER/25[7V)I;F1I<GT@7`H@("`@("`@("UD(&1A
M=&%?9&ER/25[7VQI8F1I<GTO<&AP+W!E87(O9&%T82!<"B`@("`@("`@+60@
M=&5S=%]D:7(])7M?;&EB9&ER?2]P:'`O<&5A<B]T97-T<R!<"B`@("`@("`@
M+60@97AT7V1I<CTE>U]L:6)D:7)](%P*("`@("`@("`M<PH*)6)U:6QD"F5C
M:&\@0G5I;&12;V]T/25[8G5I;&1R;V]T?0H*)7!O<W1U;@IP96%R('5N:6YS
M=&%L;"`M+6YO9&5P<R`M<B!`<&%C:V%G94`*<FT@0')P;5]X;6Q?9&ER0"]`
M<&%C:V%G94`N>&UL"@HE<&]S=`IP96%R(&EN<W1A;&P@+2UN;V1E<',@+7(@
M0')P;5]X;6Q?9&ER0"]`<&%C:V%G94`N>&UL"@HE:6YS=&%L;`IP96%R("UC
M("5[8G5I;&1R;V]T?2]P96%R<F,@:6YS=&%L;"`M+6YO9&5P<R`M4B`E>V)U
M:6QD<F]O='T@7`H@("`@("`@("124$U?4T]54D-%7T1)4B]`<&%C:V%G94`M
M)7MV97)S:6]N?2YT9WH*<FT@)7MB=6EL9')O;W1]+W!E87)R8PIR;2`E>V)U
M:6QD<F]O='TO)7M?;&EB9&ER?2]P:'`O<&5A<B\N9FEL96UA<`IR;2`E>V)U
M:6QD<F]O='TO)7M?;&EB9&ER?2]P:'`O<&5A<B\N;&]C:PIR;2`M<F8@)7MB
M=6EL9')O;W1]+R5[7VQI8F1I<GTO<&AP+W!E87(O+G)E9VES=')Y"FEF(%L@
M+60@(B5[8G5I;&1R;V]T?2]D;V-S+T!P86-K86=E0"]D;V,B(%T[('1H96X*
M("`@(')M("UR9B`D4E!-7T)524Q$7T1)4B]D;V,*("`@(&UV("5[8G5I;&1R
M;V]T?2]D;V-S+T!P86-K86=E0"]D;V,@)%)035]"54E,1%]$25(*("`@(')M
M("UR9B`E>V)U:6QD<F]O='TO9&]C<PIF:0IM:V1I<B`M<"`E>V)U:6QD<F]O
M='U`<G!M7WAM;%]D:7)`"G1A<B`M>'IF("124$U?4T]54D-%7T1)4B]`<&%C
M:V%G94`M)7MV97)S:6]N?2YT9WH@<&%C:V%G92YX;6P*8W`@+7`@<&%C:V%G
M92YX;6P@)7MB=6EL9')O;W1]0')P;5]X;6Q?9&ER0"]`<&%C:V%G94`N>&UL
M"@HC<FT@+7)F("5[8G5I;&1R;V]T?2\J"B-P96%R("UQ(&EN<W1A;&P@+5(@
M)7MB=6EL9')O;W1]("UN('!A8VMA9V4N>&UL"B-M:V1I<B`M<"`E>V)U:6QD
M<F]O='U`<G!M7WAM;%]D:7)`"B-C<"`M<"!P86-K86=E+GAM;"`E>V)U:6QD
M<F]O='U`<G!M7WAM;%]D:7)`+T!P86-K86=E0"YX;6P*"B5F:6QE<PH@("`@
M)61E9F%T='(H+2QR;V]T+')O;W0I"B`@("`E9&]C($!D;V-?9FEL97-`"B`@
M("`O"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]014%2+W!A
M8VMA9V4N9'1D````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V
M,S4`,3`T,3<S-C,P,#0`,#(Q,3`P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#PA+2T*("`@("`D260Z('!A8VMA9V4N9'1D
M+'8@,2XS-2`R,#`T+S`Q+S(U(#(S.C,V.C(X('!A:F]Y92!%>'`@)`H*("`@
M("!4:&ES(&ES('1H92!014%2('!A8VMA9V4@9&5S8W)I<'1I;VXL('9E<G-I
M;VX@,2XP+@H@("`@($ET('-H;W5L9"!B92!U<V5D('=I=&@@=&AE(&EN9F]R
M;6%L('!U8FQI8R!I9&5N=&EF:65R.@H*("`@("`@("`@(BTO+U!(4"!'<F]U
M<"\O1%1$(%!%05(@4&%C:V%G92`Q+C`O+T5.+R]834PB"@H@("`@($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`*"B`@("`@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS92P@"B`@("`@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<PH@("`@(&%V86EL
M86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A=`H@("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N(`H@("`@($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;PH@("`@(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O"B`@("`@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN"@H@("`@($%U=&AO<G,Z"B`@("`@("`@(%-T:6<@4RX@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X*"B`@+2T^"@H\(45,14U%3E0@<&%C:V%G92`H;F%M
M97QS=6UM87)Y?&1E<V-R:7!T:6]N?&QI8V5N<V5\;6%I;G1A:6YE<G-\<F5L
M96%S97QC:&%N9V5L;V<I*SX*/"%!5%1,25-4('!A8VMA9V4@='EP92`@("`H
M<V]U<F-E?&)I;F%R>7QE;7!T>2D@(F5M<'1Y(@H@("`@("`@("`@("`@("`@
M("!V97)S:6]N($-$051!("`@("`@("`@("`@("`@("`C4D5154E2140^"@H\
M(45,14U%3E0@;F%M92`H(U!#1$%402D^"@H\(45,14U%3E0@<W5M;6%R>2`H
M(U!#1$%402D^"@H\(45,14U%3E0@9&5S8W)I<'1I;VX@*"-00T1!5$$I/@H*
M/"%%3$5-14Y4(&QI8V5N<V4@*"-00T1!5$$I/@H*/"%%3$5-14Y4(&UA:6YT
M86EN97)S("AM86EN=&%I;F5R*2L^"@H\(45,14U%3E0@;6%I;G1A:6YE<B`H
M=7-E<GQR;VQE?&YA;65\96UA:6PI*SX*"CPA14Q%345.5"!U<V5R("@C4$-$
M051!*3X*"CPA14Q%345.5"!R;VQE("@C4$-$051!*3X*"CPA14Q%345.5"!E
M;6%I;"`H(U!#1$%402D^"@H\(45,14U%3E0@8VAA;F=E;&]G("AR96QE87-E
M*2L^"@H\(45,14U%3E0@<F5L96%S92`H=F5R<VEO;GQL:6-E;G-E?'-T871E
M?&1A=&5\;F]T97-\9FEL96QI<W1\9&5P<WQP<F]V:61E<WQS8W)I<'1\8V]N
M9FEG=7)E;W!T:6]N<RDK/@H*/"%%3$5-14Y4('9E<G-I;VX@*"-00T1!5$$I
M/@H*/"%%3$5-14Y4('-T871E("@C4$-$051!*3X*"CPA14Q%345.5"!D871E
M("@C4$-$051!*3X*"CPA14Q%345.5"!N;W1E<R`H(U!#1$%402D^"@H\(45,
M14U%3E0@9FEL96QI<W0@*&1I<GQF:6QE*2L^"@H\(45,14U%3E0@9&ER("AD
M:7)\9FEL92DK/@H\(4%45$Q)4U0@9&ER(&YA;64@("`@("`@("`@($-$051!
M("-215%525)%1`H@("`@("`@("`@("`@(&)A<V5I;G-T86QL9&ER($-$051!
M("-)35!,245$/@H*/"%%3$5-14Y4(&9I;&4@*')E<&QA8V4J*3X*/"%!5%1,
M25-4(&9I;&4@<F]L92`@("`@("`@("`@*'!H<'QE>'1\<W)C?'1E<W1\9&]C
M?&1A=&%\<V-R:7!T*2`G<&AP)PH@("`@("`@("`@("`@("!D96)U9R`@("`@
M("`@("`H;F%\;VY\;V9F*2`@("`@("`@)VYA)PH@("`@("`@("`@("`@("!Z
M=',@("`@("`@("`@("`H;F%\;VY\;V9F*2`@("`@("`@)VYA)PH@("`@("`@
M("`@("`@("!P:'!A<&D@("`@("`@("!.54U"15(@("`@("`@("`@("`@(TE-
M4$Q)140*("`@("`@("`@("`@("`@>F5N9&%P:2`@("`@("`@3E5-0D52("`@
M("`@("`@("`@("-)35!,245$"B`@("`@("`@("`@("`@(&9O<FUA="`@("`@
M("`@($-$051!("`@("`@("`@("`@("`C24U03$E%1`H@("`@("`@("`@("`@
M("!B87-E:6YS=&%L;&1I<B!#1$%402`@("`@("`@("`@("`@(TE-4$Q)140*
M("`@("`@("`@("`@("`@<&QA=&9O<FT@("`@("`@0T1!5$$@("`@("`@("`@
M("`@("-)35!,245$"B`@("`@("`@("`@("`@(&UD-7-U;2`@("`@("`@($-$
M051!("`@("`@("`@("`@("`C24U03$E%1`H@("`@("`@("`@("`@("!N86UE
M("`@("`@("`@("!#1$%402`@("`@("`@("`@("`@(U)%455)4D5$"B`@("`@
M("`@("`@("`@(&EN<W1A;&PM87,@("`@($-$051!("`@("`@("`@("`@("`C
M24U03$E%1#X*"CPA14Q%345.5"!R97!L86-E($5-4%19/@H\(4%45$Q)4U0@
M<F5P;&%C92!F<F]M("`@("`@("!#1$%402`@("`@("`@("`@("`@(U)%455)
M4D5$"B`@("`@("`@("`@("`@("`@('1O("`@("`@("`@($-$051!("`@("`@
M("`@("`@("`C4D5154E2140*("`@("`@("`@("`@("`@("`@='EP92`@("`@
M("`@0T1!5$$@("`@("`@("`@("`@("-215%525)%1#X*"CPA14Q%345.5"!D
M97!S("AD97`I*SX*"CPA14Q%345.5"!D97`@*"-00T1!5$$I/@H\(4%45$Q)
M4U0@9&5P"@EO<'1I;VYA;"`@("`H>65S?&YO*2`@("`G;F\G"@ET>7!E("`@
M("`@("`H<&MG?&5X='QP:'!\<')O9WQL9&QI8GQR=&QI8GQO<WQW96)S<G9\
M<V%P:7QZ96YD*2`C4D5154E2140*"7)E;"`@("`@("`@("AH87-\97%\;'1\
M;&5\9W1\9V4I("=H87,G"@EV97)S:6]N("`@("!#1$%402`@("`@("`@("`@
M("`@("`C24U03$E%1#X*"CPA14Q%345.5"!P<F]V:61E<R`H(U!#1$%402D^
M"CPA05143$E35"!P<F]V:61E<PH)='EP92`@("`H97AT?'!R;V=\8VQA<W-\
M9G5N8W1I;VY\9F5A='5R97QA<&DI("`C4D5154E2140*"6YA;64@("`@0T1!
M5$$@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(U)%455)4D5$
M"@EE>'1E;F1S($-$051!("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("-)35!,245$/@H*/"%%3$5-14Y4('-C<FEP="`H(U!#1$%402D^"CPA
M05143$E35"!S8W)I<'0*("`@("`@("!P:&%S92`@("AP<F4M:6YS=&%L;"`@
M?'!O<W0M:6YS=&%L;"`@?`H@("`@("`@("`@("`@("`@('!R92UU;FEN<W1A
M;&Q\<&]S="UU;FEN<W1A;&Q\"B`@("`@("`@("`@("`@("`@<')E+6)U:6QD
M("`@('QP;W-T+6)U:6QD("`@('P*("`@("`@("`@("`@("`@("!P<F4M<V5T
M=7`@("`@?'!O<W0M<V5T=7`@("`@*2`@("`@("`@("-215%525)%1#X*"CPA
M14Q%345.5"!C;VYF:6=U<F5O<'1I;VYS("AC;VYF:6=U<F5O<'1I;VXJ*3X*
M"CPA14Q%345.5"!C;VYF:6=U<F5O<'1I;VX@14U05%D^"CPA05143$E35"!C
M;VYF:6=U<F5O<'1I;VX*("`@("`@("!N86UE("`@("!#1$%402`@("`@("-2
M15%525)%1`H@("`@("`@(&1E9F%U;'0@($-$051!("`@("`@(TE-4$Q)140*
M("`@("`@("!P<F]M<'0@("!#1$%402`@("`@("-215%525)%1#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O0V%C:&4O
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8S,#`T`#`Q-S(U-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&%T82]#86-H92]#;VYT86EN97(O````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#(Q,3<W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+T-A8VAE+T-O;G1A:6YE<B]M
M9&)?8V%C:&5?<V-H96UA+GAM;```````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4W-0`Q,#0Q-S,V
M,S`P-``P,C4Q,S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB25-/+3@X
M-3DM,2(@/SX-"CQD871A8F%S93X-"@T*(#QN86UE/F1B;F%M93PO;F%M93X-
M"B`\8W)E871E/C$\+V-R96%T93X-"B`\9&5S8W)I<'1I;VX^(#PO9&5S8W)I
M<'1I;VX^#0H-"B`\=&%B;&4^#0H@(#QN86UE/F-A8VAE/"]N86UE/@T*("`\
M9&5S8W)I<'1I;VX^(#PO9&5S8W)I<'1I;VX^#0H-"B`@/&1E8VQA<F%T:6]N
M/@T*#0H@("`\9FEE;&0^#0H@("`@("`\;F%M93Y)1#PO;F%M93X-"B`@("`@
M(#QT>7!E/G1E>'0\+W1Y<&4^#0H@("`@("`\;&5N9W1H/C,R/"]L96YG=&@^
M#0H@("`@("`\9&5F875L=#X\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ
M/"]N;W1N=6QL/@T*("`@/"]F:65L9#X-"@T*("`@/&9I96QD/@T*("`@("`@
M/&YA;64^8V%C:&5G<F]U<#PO;F%M93X-"B`@("`@(#QT>7!E/G1E>'0\+W1Y
M<&4^#0H@("`@("`\;&5N9W1H/C$R-SPO;&5N9W1H/@T*("`@("`@/&1E9F%U
M;'0^/"]D969A=6QT/@T*("`@("`@/&YO=&YU;&P^,3PO;F]T;G5L;#X-"B`@
M(#PO9FEE;&0^#0H-"B`@(#QF:65L9#X-"B`@("`@(#QN86UE/F-A8VAE9&%T
M83PO;F%M93X-"B`@("`@(#QT>7!E/F-L;V(\+W1Y<&4^#0H@("`@("`\9&5F
M875L=#X\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ/"]N;W1N=6QL/@T*
M("`@/"]F:65L9#X-"@T*("`@/&9I96QD/@T*("`@("`@/&YA;64^=7-E<F1A
M=&$\+VYA;64^#0H@("`@("`\='EP93YT97AT/"]T>7!E/@T*("`@("`@/&QE
M;F=T:#XR-34\+VQE;F=T:#X-"B`@("`@(#QD969A=6QT/CPO9&5F875L=#X-
M"B`@(#PO9FEE;&0^#0H-"B`@(#QF:65L9#X-"B`@("`@(#QN86UE/F5X<&ER
M97,\+VYA;64^#0H@("`@("`\='EP93YI;G1E9V5R/"]T>7!E/@T*("`@("`@
M/&1E9F%U;'0^,#PO9&5F875L=#X-"B`@("`@(#QN;W1N=6QL/C$\+VYO=&YU
M;&P^#0H@("`\+V9I96QD/@T*#0H@("`\9FEE;&0^#0H@("`@("`\;F%M93YC
M:&%N9V5D/"]N86UE/@T*("`@("`@/'1Y<&4^:6YT96=E<CPO='EP93X-"B`@
M("`@(#QD969A=6QT/C`\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ/"]N
M;W1N=6QL/@T*("`@/"]F:65L9#X-"@T*#0H@("`\:6YD97@^#0H@("`@/&YA
M;64^:61?:6YD97@\+VYA;64^#0H@("`@/'5N:7%U93XQ/"]U;FEQ=64^#0H@
M("`@/&9I96QD/B`\;F%M93YI9#PO;F%M93X@/"]F:65L9#X-"B`@("`\9FEE
M;&0^(#QN86UE/F-A8VAE9W)O=7`\+VYA;64^(#PO9FEE;&0^#0H@("`\+VEN
M9&5X/@T*#0H-"B`@(#QI;F1E>#X-"B`@("`\;F%M93YE>'!I<F5S7VEN9&5X
M/"]N86UE/@T*("`@(#QF:65L9#X@/&YA;64^97AP:7)E<SPO;F%M93X@/"]F
M:65L9#X-"B`@(#PO:6YD97@^#0H-"B`@/"]D96-L87)A=&EO;CX-"B`\+W1A
M8FQE/@T*#0H\+V1A=&%B87-E/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1A=&$O36%I;%]-:6UE+P``````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`R,#$P,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&%T82]-86EL7TUI;64O>&UA:6PN9'1D````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P-C8`,3`T,3<S-C,P,#0`
M,#(Q-S$R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](DE33RTX.#4Y+3$B
M/SX-"@T*/"%%3E1)5%D@;'0@(B8C,S@[(S8P.R(^#0H\(45.5$E462!G="`B
M)B,V,CLB/@T*/"%%3E1)5%D@86UP("(F(S,X.R,S.#LB/@T*/"%%3E1)5%D@
M87!O<R`B)B,S.3LB/@T*/"%%3E1)5%D@<75O="`B)B,S-#LB/@T*/"%%3E1)
M5%D@8W)L9B`B)B,Q,SLF(S$P.R(^#0H-"CPA14Q%345.5"!E;6%I;"`H:&5A
M9&5R*RP@*&)O9'D@?"!M:6UE<&%R="LI*3X-"CPA14Q%345.5"!M:6UE<&%R
M="`H:&5A9&5R*RP@*&)O9'D@?"!M:6UE<&%R="LI*3X-"CPA14Q%345.5"!B
M;V1Y("@C4$-$051!*3X-"CPA14Q%345.5"!H96%D97(@*"AH96%D97)N86UE
M?&AE861E<G9A;'5E?'!A<F%M971E<BDJ*3X-"CPA14Q%345.5"!H96%D97)N
M86UE("@C4$-$051!*3X-"CPA14Q%345.5"!H96%D97)V86QU92`H(U!#1$%4
M02D^#0H\(45,14U%3E0@<&%R86UE=&5R("@H<&%R86UN86UE?'!A<F%M=F%L
M=64I*RD^#0H\(45,14U%3E0@<&%R86UV86QU92`H(U!#1$%402D^#0H\(45,
M14U%3E0@<&%R86UN86UE("@C4$-$051!*3X-"@T*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]-86EL7TUI;64O>&UA:6PN
M>'-L````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0Q,C<`,3`T,3<S
M-C,P,#0`,#(Q-S0V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](DE33RTX
M.#4Y+3$B/SX-"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q+C`B('AM;&YS
M.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(B!X
M;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(CX-
M"CQX<VPZ;W5T<'5T(&UE=&AO9#TB=&5X="(@;VUI="UX;6PM9&5C;&%R871I
M;VX](GEE<R(@:6YD96YT/2)N;R(O/@T*/'AS;#IP<F5S97)V92US<&%C92!E
M;&5M96YT<STB:&5A9&5R=F%L=64@<&%R86UV86QU92!B;V1Y(B\^#0H-"@D\
M>'-L.G1E;7!L871E(&YA;64](FUI;65P87)T(CX-"@T*"0D\>'-L.G9A<FEA
M8FQE(&YA;64](F)O=6YD87)Y(CX-"@D)"0D\>'-L.F9O<BUE86-H('-E;&5C
M=#TB+B]H96%D97(B/@T*"0D)"0D\>'-L.FEF('1E<W0](G-T<FEN9R@N+VAE
M861E<FYA;64I(#T@)T-O;G1E;G0M5'EP92<B/@T*"0D)"0D)/'AS;#IF;W(M
M96%C:"!S96QE8W0](BXO<&%R86UE=&5R(CX-"@D)"0D)"0D\>'-L.FEF('1E
M<W0](G-T<FEN9R@N+W!A<F%M;F%M92D@/2`G8F]U;F1A<GDG(CX-"@D)"0D)
M"0D)/'AS;#IV86QU92UO9B!S96QE8W0](G!A<F%M=F%L=64B+SX-"@D)"0D)
M"0D\+WAS;#II9CX-"@D)"0D)"3PO>'-L.F9O<BUE86-H/@T*"0D)"0D\+WAS
M;#II9CX-"@D)"0D\+WAS;#IF;W(M96%C:#X-"@D)/"]X<VPZ=F%R:6%B;&4^
M#0H-"@D)/'AS;#IF;W(M96%C:"!S96QE8W0](FAE861E<B(^#0H-"@D)"3QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)H96%D97)N86UE(B\^#0H)"0D\>'-L.G1E
M>'0^.B`\+WAS;#IT97AT/@T*"0D)/'AS;#IV86QU92UO9B!S96QE8W0](FAE
M861E<G9A;'5E(B\^#0H-"@D)"3QX<VPZ:68@=&5S=#TB8V]U;G0H+B]P87)A
M;65T97(I(#T@,"(^#0H)"0D)/'AS;#IT97AT/B8C,3,[)B,Q,#L\+WAS;#IT
M97AT/@T*"0D)/"]X<VPZ:68^#0H-"@D)"3QX<VPZ9F]R+65A8V@@<V5L96-T
M/2)P87)A;65T97(B/@T*"0D)"3QX<VPZ=&5X=#X[)B,Q,SLF(S$P.R8C,#D[
M/"]X<VPZ=&5X=#X-"@D)"0D\>'-L.G9A;'5E+6]F('-E;&5C=#TB<&%R86UN
M86UE(B\^#0H)"0D)/'AS;#IT97AT/CTB/"]X<VPZ=&5X=#X-"@D)"0D\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<&%R86UV86QU92(O/@T*"0D)"3QX<VPZ=&5X
M=#XB/"]X<VPZ=&5X=#X-"@D)"3PO>'-L.F9O<BUE86-H/@T*#0H)"0D\>'-L
M.FEF('1E<W0](F-O=6YT*"XO<&%R86UE=&5R*2`^(#`B/@T*"0D)"3QX<VPZ
M=&5X=#XF(S$S.R8C,3`[/"]X<VPZ=&5X=#X-"@D)"3PO>'-L.FEF/@T*#0H)
M"3PO>'-L.F9O<BUE86-H/@T*#0H)"3QX<VPZ=&5X=#XF(S$S.R8C,3`[/"]X
M<VPZ=&5X=#X-"@T*"0D\(2TM(%=H:6-H('1O(&1O+"!P<FEN="!A(&)O9'D@
M;W(@<')O8V5S<R!S=6)P87)T<S\@+2T^#0H)"3QX<VPZ8VAO;W-E/@T*"0D)
M/'AS;#IW:&5N('1E<W0](F-O=6YT*"XO;6EM97!A<G0I(#T@,"(^#0H)"0D)
M/'AS;#IV86QU92UO9B!S96QE8W0](F)O9'DB+SX-"@D)"0D\>'-L.G1E>'0^
M)B,Q,SLF(S$P.SPO>'-L.G1E>'0^#0H)"0D\+WAS;#IW:&5N/@T*#0H)"0D\
M>'-L.F]T:&5R=VES93X-"@D)"0D\>'-L.F9O<BUE86-H('-E;&5C=#TB;6EM
M97!A<G0B/@T*"0D)"0D\>'-L.G1E>'0^+2T\+WAS;#IT97AT/CQX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D8F]U;F1A<GDB+SX\>'-L.G1E>'0^)B,Q,SLF(S$P
M.SPO>'-L.G1E>'0^#0H)"0D)"3QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)M
M:6UE<&%R="(O/@T*"0D)"3PO>'-L.F9O<BUE86-H/@T*#0H)"0D)/'AS;#IT
M97AT/BTM/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&)O=6YD
M87)Y(B\^/'AS;#IT97AT/BTM)B,Q,SLF(S$P.SPO>'-L.G1E>'0^#0H-"@D)
M"3PO>'-L.F]T:&5R=VES93X-"@D)/"]X<VPZ8VAO;W-E/@T*"3PO>'-L.G1E
M;7!L871E/@T*#0H\(2TM(%1H:7,@:7,@=VAE<F4@=&AE('-T>6QE<VAE970@
M<F5A;&QY('-T87)T<RP@;6%T8VAI;F<@=&AE('1O<"!L979E;"!E;6%I;"!E
M;&5M96YT("TM/@T*"3QX<VPZ=&5M<&QA=&4@;6%T8V@](F5M86EL(CX-"@D)
M/'AS;#IC86QL+71E;7!L871E(&YA;64](FUI;65P87)T(B\^#0H)/"]X<VPZ
M=&5M<&QA=&4^#0H-"CPO>'-L.G-T>6QE<VAE970^````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]397)V
M:6-E<U]796%T:&5R+P``````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C,P,#0`,#(Q-3$T`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D871A+U-E<G9I8V5S7U=E871H97(O8G5I;&1-971A<D1"+G!H
M<``````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`S-C<T,@`Q,#0Q-S,V,S`P-``P,C0U,S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R$O=7-R
M+VQO8V%L+V)I;B]P:'`-"CP_<&AP#0HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(
M4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@
M("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!
M=71H;W)S.B!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z(&)U:6QD365T87)$0BYP:'`L=B`Q
M+C$V(#(P,#0O,#$O,#8@,3DZ,S8Z,C@@97)U($5X<"`D#0H-"G)E<75I<F5?
M;VYC92`B1$(N<&AP(CL-"@T*+R\@>WM[(&-O;G-T86YT<PT*+R\@>WM[(&YA
M='5R86P@8V]N<W1A;G1S(&%N9"!M96%S=7)E<PT*9&5F:6YE*")315)624-%
M4U]714%42$527U)!1$E54U]%05)42"(L(#8S-S@N,34I.PT*+R\@?7U]#0HO
M+R!]?7T-"@T*+RHJ#0HJ(%1H:7,@<V-R:7!T(&1O=VYL;V%D<RP@<V%V97,@
M86YD('!R;V-E<W-E<R!T:&4@=&5X=&9I;&5S(&YE961E9"!F;W(-"BH@=&AE
M(&)U:6QD:6YG('1H92!D871A8F%S97,@=&\@96YA8FQE('-E87)C:&EN9R!F
M;W(@345405(@<W1A=&EO;G,N#0HJ#0HJ(%EO=2!C86X@9&]W;FQO860@=&AE
M(&QO8V%T:6]N<RP@=VAI8V@@:7,@82!D871A8F%S92!O9B!A8F]U="`Q,C`P
M,"!W;W)L9"T-"BH@=VED92!L;V-A=&EO;G,L('=H:6-H(&-A;B!B92!U<V5D
M('1O(&1E=&5R;6EN92!T:&4@8V]O<F1I;F%T97,@;V8@>6]U<@T**B!C:71Y
M(&]R('EO=2!C86X@9&]W;FQO860@82!F:6QE('=I=&@@-C4P,"!A:7)P;W)T
M<R!P<F]V:61I;F<@=&AE(&UE=&%R#0HJ(&1A=&$N(%1H:7,@9&%T86)A<V4@
M:7,@=7-E9"!F;W(@=&AE(&YE>'0M345405(M<W1A=&EO;B!S96%R8V@N(%!L
M96%S92!S964-"BH@=&AE(&%P<F]P<FEA=&4@9&]C=6UE;G1A=&EO;B!I;B!T
M:&4@4V5R=FEC97-?5V5A=&AE<E]-971A<B!C;&%S<RX-"BH-"BH@1F]R('5S
M86=E(&]F('1H:7,@<V-R:7!T+"!I;G9O:V4@=VET:"`G+6@G+@T**@T**B!`
M875T:&]R("`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X-
M"BH@0&QI;FL@("`@("`@("!H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]T9R]S
M:71E+G-H=&UL#0HJ($!P86-K86=E("`@("`@4V5R=FEC97-?5V5A=&AE<@T*
M*B!`=F5R<VEO;B`@("`@(#$N,@T**B\-"@T*+R\@>WM[(%-E<G9I8V5S7U=E
M871H97)?8VAE8VM$871A*"D-"B\J*@T**B!397)V:6-E<U]796%T:&5R7V-H
M96-K1&%T80T**@T**B!#:&5C:W,@=&AE(&1A=&$@9F]R(&$@8V5R=&%I;B!S
M=')I;F<M;&5N9W1H(&%N9"!I9B!I="!E:71H97(@8V]N<VES=',@;V8-"BH@
M82!C97)T86EN(&-H87(M='EP92!O<B!A('-T<FEN9R!O9B`B+2(@87,@<F5P
M;&%C96UE;G0N#0HJ#0HJ($!P87)A;2`@("!A<G)A>2`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D871A("`@("`@("`@("!4:&4@9&%T82!T;R!B92!C
M:&5C:V5D#0HJ($!P87)A;2`@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D871A3W)D97(@("`@("!"96-A=7-E('1H92!D871A(&ES(&EN
M(&1I9F9E<F5N="!L;V-A=&EO;G,L('=E('!R;W9I9&4@=&AI<PT**B!`<F5T
M=7)N("`@8F]O;`T**B\-"F9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?8VAE
M8VM$871A*"1D871A+"`D9&%T84]R9&5R*0T*>PT*("`@("1R971U<FX@/2!T
M<G5E.PT*("`@(&9O<F5A8V@@*"1D871A3W)D97(@87,@)'1Y<&4@/3X@)&ED
M>"D@>PT*("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)'1Y<&4I*2![#0H@
M("`@("`@("`@("!C87-E(")B(CH-"B`@("`@("`@("`@("`@("`D;&5N("`]
M(#([#0H@("`@("`@("`@("`@("`@)&9U;F,@/2`B8W1Y<&5?9&EG:70B.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`B<R(Z
M#0H@("`@("`@("`@("`@("`@)&QE;B`@/2`S.PT*("`@("`@("`@("`@("`@
M("1F=6YC(#T@(F-T>7!E7V1I9VET(CL-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@(&-A<V4@(FDB.@T*("`@("`@("`@("`@("`@("1L
M96X@(#T@-#L-"B`@("`@("`@("`@("`@("`D9G5N8R`](")C='EP95]A;&YU
M;2([#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!D969A
M=6QT.@T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@H<W1R;&5N*"1D871A6R1I9'A=*2`A/2`D;&5N*2!\?"`H(21F
M=6YC*"1D871A6R1I9'A=*2`F)B`H)&1A=&%;)&ED>%T@(3T@<W1R7W)E<&5A
M="@B+2(L("1L96XI*2DI('L-"B`@("`@("`@("`@("1R971U<FX@/2!F86QS
M93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@?0T*("`@
M(')E='5R;B`D<F5T=7)N.PT*?0T*+R\@?7U]#0H-"B\O('M[>R!397)V:6-E
M<U]796%T:&5R7V=E=$YE>'1!<F<H*0T*+RHJ#0HJ(%-E<G9I8V5S7U=E871H
M97)?9V5T3F5X=$%R9PT**@T**B!#:&5C:W,L(&EF('1H92!N97AT(&%R9W5M
M96YT(&ES(&$@<&%R86UE=&5R('1O(&$@<')E9&5C97-S:6YG(&]P=&EO;BX-
M"BH@4F5T=7)N<R!E:71H97(@=&AA="!P87)A;65T97(@;W(@9F%L<V4L(&EF
M('1H92!N97AT(&%R9W5M96YT(&ES(&%N(&]P=&EO;@T**@T**B!`<&%R86T@
M("`@:6YT("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8R`@("`@("`@
M("`@("`@26YT97)N86P@87)G=6UE;G0@8V]U;G1E<@T**B!`<F5T=7)N("`@
M<W1R:6YG?&)O;VP-"BHO#0IF=6YC=&EO;B!397)V:6-E<U]796%T:&5R7V=E
M=$YE>'1!<F<H)B1C*0T*>PT*("`@(&EF("@H*"1C("L@,2D@/"`D7U-%4E9%
M4ELB87)G8R)=*2`F)B`H)%]315)615);(F%R9W8B75LD8R`K(#%=>S!]("$]
M("(M(BDI('L-"B`@("`@("`@)&,K*SL-"B`@("`@("`@<F5T=7)N("1?4T52
M5D526R)A<F=V(EU;)&-=.PT*("`@('T@96QS92![#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]("`@(`T*?0T*+R\@?7U]#0H-"B\O($9I<G-T('-E
M="!A(&9E=R!V87)I86)L97,@9F]R('!R;V-E<W-I;F<@=&AE(&]P=&EO;G,-
M"B1M;V1E4V5T("`@/2!F86QS93L-"B1S879E1FEL92`@/2!F86QS93L-"B1P
M<FEN=$AE;'`@/2!F86QS93L-"B1I;G9/<'0@("`@/2!F86QS93L-"B1V97)B
M;W-E("`@/2`P.PT*)&1B5'EP92`@("`](")M>7-Q;"([#0HD9&)0<F]T("`@
M(#T@(G5N:7@B.PT*)&1B3F%M92`@("`](")S97)V:6-E<U=E871H97)$0B([
M#0HD9&)5<V5R("`@(#T@(G)O;W0B.PT*)&1B4&%S<R`@("`]("(B.PT*)&1B
M2&]S="`@("`](")L;V-A;&AO<W0B.PT*)&1B3W!T:6]N<R`](&%R<F%Y*"D[
M#0HD=7-E<D9I;&4@(#T@(B([#0H-"B\O($ET97)A=&4@=&AR;W5G:"!T:&4@
M87)G=6UE;G1S(&%N9"!C:&5C:R!T:&5I<B!V86QI9&ET>0T*9F]R("@D8R`]
M(#$[("1C(#P@)%]315)615);(F%R9V,B73L@)&,K*RD@>PT*("`@('-W:71C
M:"`H)%]315)615);(F%R9W8B75LD8UU[,7TI('L-"B`@("`@("`@8V%S92`B
M;"(Z#0H@("`@("`@("`@("`O+R!L;V-A=&EO;BUM;V1E+"!I9B!A;F]T:&5R
M(&UO9&4@:7,@<V5T+"!B86EL(&]U=`T*("`@("`@("`@("`@:68@*"1M;V1E
M4V5T*2![#0H@("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1M;V1E4V5T
M("`@/2!T<G5E.PT*("`@("`@("`@("`@("`@("1F:6QE4&%R="`@/2`B8F)S
M<W,B.PT*("`@("`@("`@("`@("`@("1T86)L94YA;64@/2`B;65T87),;V-A
M=&EO;G,B.PT*("`@("`@("`@("`@("`@("1D871A3W)D97(@/2!A<G)A>2@B
M8B(@/3X@,"P@(G,B(#T^(#$L(")I(B`]/B`R*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E(")A(CH-"B`@("`@
M("`@("`@("\O(&1I=&\@9F]R(&%I<G!O<G0M;6]D90T*("`@("`@("`@("`@
M:68@*"1M;V1E4V5T*2![#0H@("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]
M('1R=64[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("1M;V1E4V5T("`@/2!T<G5E.PT*("`@("`@("`@("`@("`@("1F:6QE4&%R
M="`@/2`B8V-C8R([#0H@("`@("`@("`@("`@("`@)'1A8FQE3F%M92`](")M
M971A<D%I<G!O<G1S(CL-"B`@("`@("`@("`@("`@("`D9&%T84]R9&5R(#T@
M87)R87DH(F(B(#T^(#$L(")S(B`]/B`R+"`B:2(@/3X@,"D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`B9B(Z
M#0H@("`@("`@("`@("`O+R!F:6QE+69L86<@=V%S('!R;W9I9&5D+"!C:&5C
M:R!I9B!N97AT(&%R9W5M96YT(&ES(&$@<W1R:6YG#0H@("`@("`@("`@("!I
M9B`H*"1U<V5R1FEL92`](%-E<G9I8V5S7U=E871H97)?9V5T3F5X=$%R9R@D
M8RDI(#T]/2!F86QS92D@>PT*("`@("`@("`@("`@("`@("1P<FEN=$AE;'`@
M/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@(&-A<V4@(G,B.@T*("`@("`@("`@("`@+R\@268@>6]U(&1O=VYL
M;V%D('1H92!F:6QE+"!I="!W:6QL(&)E('-A=F5D('1O(&1I<VL-"B`@("`@
M("`@("`@("1S879E1FEL92`@("`@(#T@=')U93L-"B`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("!C87-E(")T(CH-"B`@("`@("`@("`@("\O(%1H92!T
M>7!E(&]F('1H92!$0B!T;R!B92!U<V5D#0H@("`@("`@("`@("!I9B`H*"1D
M8E1Y<&4@/2!397)V:6-E<U]796%T:&5R7V=E=$YE>'1!<F<H)&,I*2`]/3T@
M9F%L<V4I('L-"B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C
M87-E(")R(CH-"B`@("`@("`@("`@("\O(%1H92!P<F]T;V-O;"!O9B!T:&4@
M1$(@=&\@8F4@=7-E9`T*("`@("`@("`@("`@:68@*"@D9&)0<F]T(#T@4V5R
M=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@/3T](&9A;'-E*2![#0H@
M("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`B9"(Z#0H@
M("`@("`@("`@("`O+R!4:&4@;F%M92!O9B!T:&4@1$(@=&\@8F4@=7-E9`T*
M("`@("`@("`@("`@:68@*"@D9&).86UE(#T@4V5R=FEC97-?5V5A=&AE<E]G
M971.97AT07)G*"1C*2D@/3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@
M)'!R:6YT2&5L<"`]('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@8V%S92`B=2(Z#0H@("`@("`@("`@("`O+R!4
M:&4@=7-E<B!O9B!T:&4@1$(@=&\@8F4@=7-E9`T*("`@("`@("`@("`@:68@
M*"@D9&)5<V5R(#T@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@
M/3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@8V%S92`B<"(Z#0H@("`@("`@("`@("`O+R!4:&4@<&%S<W=O<F0@;V8@
M=&AE($1"('1O(&)E('5S960-"B`@("`@("`@("`@(&EF("@H)&1B4&%S<R`]
M(%-E<G9I8V5S7U=E871H97)?9V5T3F5X=$%R9R@D8RDI(#T]/2!F86QS92D@
M>PT*("`@("`@("`@("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@(F@B
M.@T*("`@("`@("`@("`@+R\@5&AE(&AO<W0@;V8@=&AE($1"('1O(&)E('5S
M960-"B`@("`@("`@("`@(&EF("@H)&1B2&]S="`](%-E<G9I8V5S7U=E871H
M97)?9V5T3F5X=$%R9R@D8RDI(#T]/2!F86QS92D@>PT*("`@("`@("`@("`@
M("`@("1P<FEN=$AE;'`@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@(F\B.@T*("`@("`@("`@("`@
M+R\@3W!T:6]N<R!F;W(@=&AE($1"#0H@("`@("`@("`@("!I9B`H*"1O<'1I
M;VYS(#T@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@/3T](&9A
M;'-E*2![#0H@("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1O<'1I;VYS
M("`@/2!E>'!L;V1E*"(L(BP@)&]P=&EO;G,I.PT*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1O<'1I;VXI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&]P=%!A:7(@/2!E>'!L;V1E*"(](BP@)&]P=&EO;BD[#0H@
M("`@("`@("`@("`@("`@("`@("1D8D]P=&EO;G-;)&]P=%!A:7);,%U=(#T@
M)&]P=%!A:7);,5T[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@(G8B.@T*("`@
M("`@("`@("`@+R\@:6YC<F5A<V4@=F5R8F]S:71Y#0H@("`@("`@("`@("!F
M;W(@*"1I(#T@,3L@)&D@/"!S=')L96XH)%]315)615);(F%R9W8B75LD8UTI
M.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@:68@*"1?4T525D526R)A<F=V
M(EU;)&-=>R1I?2`]/2`B=B(I('L-"B`@("`@("`@("`@("`@("`@("`@)'9E
M<F)O<V4K*SL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D:6YV3W!T("`@(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&1E9F%U;'0Z#0H@("`@
M("`@("`@("`O+R!A<F=U;65N="!N;W0@=F%L:60L(&)A:6P@;W5T#0H@("`@
M("`@("`@("`D:6YV3W!T("`@(#T@=')U93L-"B`@("`@("`@("`@(&)R96%K
M.PT*("`@('T-"B`@("!I9B`H)&EN=D]P="D@>PT*("`@("`@("`O+R!S964@
M86)O=F4-"B`@("`@("`@)'!R:6YT2&5L<"`]('1R=64[#0H@("`@("`@(&5C
M:&\@(DEN=F%L:60@;W!T:6]N.B`G(BXD7U-%4E9%4ELB87)G=B)=6R1C72XB
M)UQN(CL-"B`@("`@("`@8G)E86L[#0H@("`@?0T*?0T*#0HO+R!H96QP+6UE
M<W-A9V4-"FEF("@A)&UO9&53970@?'P@)'!R:6YT2&5L<"D@>PT*("`@(&5C
M:&\@(E5S86=E.B`B+F)A<V5N86UE*"1?4T525D526R)A<F=V(EU;,%TL("(N
M<&AP(BDN(B`M;'PM82!;;W!T:6]N<UU<;B([#0H@("`@96-H;R`B3W!T:6]N
M<SI<;B([#0H@("`@96-H;R`B("`M;"`@("`@("`@("`@("`@8G5I;&0@;&]C
M871I;VYS1$)<;B([#0H@("`@96-H;R`B("`M82`@("`@("`@("`@("`@8G5I
M;&0@86ER<&]R='-$0EQN(CL-"B`@("!E8VAO("(@("UF(#QF:6QE/B`@("`@
M("!U<V4@/&9I;&4^(&%S(&EN<'5T7&XB.PT*("`@(&5C:&\@(B`@+7,@("`@
M("`@("`@("`@('-A=F4@9&]W;FQO861E9"!F:6QE('1O(&1I<VM<;B([#0H@
M("`@96-H;R`B("`M="`\9&)T>7!E/B`@("`@='EP92!O9B!T:&4@1$(@=&\@
M8F4@=7-E9%QN(CL-"B`@("!E8VAO("(@("UR(#QD8G!R;W1O8V]L/B!P<F]T
M;V-O;"`M+2TM+5PB+2TM+2TM+2TM+5QN(CL-"B`@("!E8VAO("(@("UD(#QD
M8FYA;64^("`@("!N86UE("TM+2TM+2TM+5PB+2TM+2TM+2TM+5QN(CL-"B`@
M("!E8VAO("(@("UU(#QD8G5S97(^("`@("!U<V5R("TM+2TM+2TM+5PB+2TM
M+2TM+2TM+5QN(CL-"B`@("!E8VAO("(@("UP(#QD8G!A<W,^("`@("!P87-S
M("TM+2TM+2TM+5PB+2TM+2TM+2TM+5QN(CL-"B`@("!E8VAO("(@("UH(#QD
M8FAO<W0^("`@("!H;W-T("TM+2TM+2TM+5PB+2TM+2TM+2TM+5QN(CL-"B`@
M("!E8VAO("(@("UO(#QD8F]P=&EO;G,^("!O<'1I;VYS("TM+2TM+5PB+2TM
M+2TM+2TM+5QN(CL-"B`@("!E8VAO("(@("`@("`@("`@("`@("`@("!I;B!T
M:&4@;F]T871I;VX@;W!T:6]N/79A;'5E+"XN+EQN(CL-"B`@("!E8VAO("(@
M("UV("`@("`@("`@("`@("!D:7-P;&%Y('9E<F)O<V4@9&5B=6=G:6YG(&UE
M<W-A9V5S7&XB.PT*("`@(&5C:&\@(B`@("`@("`@("`@("`@("`@(&UU;'1I
M<&QE("UV(&EN8W)E87-E<R!V97)B;W-I='E<;B([#0H@("`@97AI="@R-34I
M.PT*?0T*#0HO+R!C:&5C:RP@:68@>FQI8B!I<R!A=F%I;&%B;&4-"FEF("AE
M>'1E;G-I;VY?;&]A9&5D*")Z;&EB(BDI('L-"B`@("`D;W!E;B`@/2`B9WIO
M<&5N(CL-"B`@("`D8VQO<V4@/2`B9WIC;&]S92([#0H@("`@)&9I;&5S(#T@
M87)R87DH#0H@("`@("`@("1U<V5R1FEL92P@(FYS9%\B+B1F:6QE4&%R="P@
M(FYS9%\B+B1F:6QE4&%R="XB+G1X="(L#0H@("`@("`@(")N<V1?(BXD9FEL
M95!A<G0N(BYG>B(L(")H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]D871A+VYS
M9%\B+B1F:6QE4&%R="XB+F=Z(@T*("`@("D[#0I](&5L<V4@>PT*("`@("1O
M<&5N("`](")F;W!E;B([#0H@("`@)&-L;W-E(#T@(F9C;&]S92([#0H@("`@
M)&9I;&5S(#T@87)R87DH#0H@("`@("`@("1U<V5R1FEL92P@(FYS9%\B+B1F
M:6QE4&%R="P@(FYS9%\B+B1F:6QE4&%R="XB+G1X="(L#0H@("`@("`@(")H
M='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]D871A+VYS9%\B+B1F:6QE4&%R="XB
M+G1X="(-"B`@("`I.PT*?0T*+R\@=&AE;B!T<GD@=&\@;W!E;B!A('-O=7)C
M92!I;B!T:&4@9VEV96X@;W)D97(-"F9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL
M92D@>PT*("`@("1F<"`]($`D;W!E;B@D9FEL92P@(G)B(BD[#0H@("`@:68@
M*"1F<"D@>PT*("`@("`@("`O+R!F;W5N9"!A('9A;&ED('-O=7)C90T*("`@
M("`@("!I9B`H)'9E<F)O<V4@/B`P*2![#0H@("`@("`@("`@("!E8VAO(")3
M97)V:6-E<U]796%T:&5R.B!5<VEN9R`G(BXD9FEL92XB)R!A<R!S;W5R8V4N
M7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<V%V949I;&4@)B8@(69I
M;&5?97AI<W1S*"1F:6QE*2D@>PT*("`@("`@("`@("`@+R\@87!P87)E;G1L
M>2!W92!W86YT('1O('-A=F4@=&AE(&9I;&4L(&%N9"!I="=S(&$@<F5M;W1E
M(&9I;&4-"B`@("`@("`@("`@("1F:6QE(#T@8F%S96YA;64H)&9I;&4I.PT*
M("`@("`@("`@("`@)&9P<R`]($`D;W!E;B@D9FEL92P@(G=B(BD[#0H@("`@
M("`@("`@("!I9B`H(21F<',I('L-"B`@("`@("`@("`@("`@("!E8VAO(")3
M97)V:6-E<U]796%T:&5R.B!#;W5L9&XG="!S879E('1O("<B+B1F:6QE+B(G
M(5QN(CL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M:68@*"1V97)B;W-E(#X@,"D@>PT*("`@("`@("`@("`@("`@("`@("!E8VAO
M(")397)V:6-E<U]796%T:&5R.B!3879I;F<@<V]U<F-E('1O("<B+B1F:6QE
M+B(G+EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M+R\@<F5A9"!F<F]M(&9I;&5P;VEN=&5R(&%N9"!S879E('1O(&1I<VL-"B`@
M("`@("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!F<F5A9"@D9G`L(#$P,C0I
M*2![#0H@("`@("`@("`@("`@("`@("`@(&9W<FET92@D9G!S+"`D;&EN92P@
M<W1R;&5N*"1L:6YE*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("\O('5N9F]R='5N871E;'D@>FQI8B!D;V5S(&YO="!S=7!P;W)T
M('(O=R!O;B!A(')E<V]U<F-E+`T*("`@("`@("`@("`@("`@("\O('-O(&YO
M(')E=VEN9"`M/B!M;W9E("1F<"!T;R!N97<@9FEL92!O;B!D:7-K#0H@("`@
M("`@("`@("`@("`@)&-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@("`@)&-L
M;W-E*"1F<',I.PT*("`@("`@("`@("`@("`@("1F<"`]($`D;W!E;B@D9FEL
M92P@(G)B(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M8G)E86L[#0H@("`@?0T*?0T*:68@*"$D9G`I('L-"B`@("`O+R!N;R!F:6QE
M<R!F;W5N9"P@;W(@8V]N;F5C=&EO;B!N;W0@879A:6QA8FQE+BXN(&)A:6P@
M;W5T#0H@("`@9&EE*")397)V:6-E<U]796%T:&5R.B!3;W5R8V5F:6QE(&YS
M9%\B+B1F:6QE4&%R="XB(&YO="!F;W5N9"%<;B(I.PT*?0T*#0HD9'-N("`@
M("`]("1D8E1Y<&4N(CHO+R(N)&1B57-E<BXB.B(N)&1B4&%S<RXB0"(N)&1B
M4')O="XB*R(N)&1B2&]S="XB+R(N)&1B3F%M93L-"B1D<VYI;F9O(#T@87)R
M87DH#0H@("`@(G!H<'1Y<&4B("`]/B`D9&)4>7!E+`T*("`@(")P<F]T;V-O
M;"(@/3X@)&1B4')O="P-"B`@("`B=7-E<FYA;64B(#T^("1D8E5S97(L#0H@
M("`@(G!A<W-W;W)D(B`]/B`D9&)087-S+`T*("`@(")H;W-T<W!E8R(@/3X@
M)&1B2&]S="P-"B`@("`B9&%T86)A<V4B(#T^("1D8DYA;64L#0H@("`@(FUO
M9&4B("`@("`]/B`P-C0T#0HI.PT*#0HD9&(@(#T@1$(Z.F-O;FYE8W0H)&1S
M;FEN9F\L("1D8D]P=&EO;G,I.PT*:68@*$1".CII<T5R<F]R*"1D8BDI('L-
M"B`@("!E8VAO(")397)V:6-E<U]796%T:&5R.B!#;VYN96-T:6]N('1O($1"
M('=I=&@@)R(N)&1B5'EP92XB.B\O(BXD9&)5<V5R+B(Z4$%34T`B+B1D8DAO
M<W0N(B\B+B1D8DYA;64N(B<@9F%I;&5D(5QN(CL-"B`@("!D:64H)&1B+3YG
M971-97-S86=E*"DN(EQN(BD[#0I](&5L<V4@>PT*("`@("\O(%1E<W0L(&EF
M('=E(&AA=F4@=&\@<W=I<&4@;W(@8W)E871E('1H92!T86)L92!F:7)S=`T*
M("`@("1S96QE8W0@/2`B4T5,14-4("H@1E)/32`B+B1T86)L94YA;64[#0H@
M("`@)')E<W5L="`]("1D8BT^<75E<GDH)'-E;&5C="D[#0H-"B`@("!I9B`H
M1$(Z.FES17)R;W(H)')E<W5L="DI('L-"B`@("`@("`@+R\@0W)E871E(&YE
M=R!T86)L90T*("`@("`@("`D8W)E871E(#T@(D-214%412!404),12`B+B1T
M86)L94YA;64N(BAI9"!I;G0L8FQO8VL@:6YT+'-T871I;VX@:6YT+&EC86\@
M=F%R8VAA<B@T*2QN86UE('9A<F-H87(H.#`I+'-T871E('9A<F-H87(H,BDL
M8V]U;G1R>2!V87)C:&%R*#4P*2QW;6\@:6YT+&QA=&ET=61E(&9L;V%T+&QO
M;F=I='5D92!F;&]A="QE;&5V871I;VX@9FQO870L>"!F;&]A="QY(&9L;V%T
M+'H@9FQO870I(CL-"B`@("`@("`@:68@*"1V97)B;W-E(#X@,"D@>PT*("`@
M("`@("`@("`@96-H;R`B4V5R=FEC97-?5V5A=&AE<CH@0W)E871I;F<@=&%B
M;&4@)R(N)'1A8FQE3F%M92XB)RY<;B([#0H@("`@("`@('T-"B`@("`@("`@
M)')E<W5L="`@/2`D9&(M/G%U97)Y*"1C<F5A=&4I.PT*("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')E<W5L="DI('L-"B`@("`@("`@("`@(&1I92@D<F5S
M=6QT+3YG971-97-S86=E*"DN(EQN(BD[#0H@("`@("`@('T-"B`@("!](&5L
M<V4@>PT*("`@("`@("`O+R!$96QE=&4@=&AE(&]L9"!S='5F9@T*("`@("`@
M("`D9&5L971E(#T@(D1%3$5412!&4D]-("(N)'1A8FQE3F%M93L-"B`@("`@
M("`@:68@*"1V97)B;W-E(#X@,"D@>PT*("`@("`@("`@("`@96-H;R`B4V5R
M=FEC97-?5V5A=&AE<CH@1&5L971I;F<@9G)O;2!T86)L92`G(BXD=&%B;&5.
M86UE+B(G+EQN(CL-"B`@("`@("`@?0T*("`@("`@("`D<F5S=6QT(#T@)&1B
M+3YQ=65R>2@D9&5L971E*3L-"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R
M97-U;'0I*2![#0H@("`@("`@("`@("!D:64H)')E<W5L="T^9V5T365S<V%G
M92@I+B)<;B(I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@3VLL($1"
M('-H;W5L9"!B92!U<"!A;F0@<G5N;FEN9R!N;W<L(&QE="=S('-H;W9E(&EN
M('1H92!D871A#0H@("`@)&QI;F4@("`](#`[#0H@("`@)&5R<F]R("`](#`[
M#0H@("`@+R\@<F5A9"!D871A(&9R;VT@9FEL90T*("`@('=H:6QE("@D9&%T
M82`](&9G971C<W8H)&9P+"`Q,#`P+"`B.R(I*2![#0H@("`@("`@("\O($-H
M96-K(&9O<B!V86QI9"!D871A#0H@("`@("`@(&EF("@H<VEZ96]F*"1D871A
M*2`\(#DI('Q\("%397)V:6-E<U]796%T:&5R7V-H96-K1&%T82@D9&%T82P@
M)&1A=&%/<F1E<BDI('L-"B`@("`@("`@("`@("`@("!E8VAO(")397)V:6-E
M<U]796%T:&5R.B!);G9A;&ED(&1A=&$@:6X@9FEL92%<;B([#0H@("`@("`@
M("`@("`@("`@96-H;R`B7'1,:6YE("(N*"1L:6YE("L@,2DN(CH@(BYI;7!L
M;V1E*"([(BP@)&1A=&$I+B)<;B([#0H@("`@("`@("`@("`@("`@)&5R<F]R
M*RL[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`O+R!C86QC=6QA
M=&4@;&%T:71U9&4@86YD(&QO;F=I='5D90T*("`@("`@("`@("`@+R\@:70@
M8V]M97,@:6X@82!D9&0M;6U;+7-S74Y\4WQ%?%<@9F]R;6%T#0H@("`@("`@
M("`@("`D8V]O<F0@/2!A<G)A>2@@(FQA=&ET=61E(B`]/B`W+"`B;&]N9VET
M=61E(B`]/B`X*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;V]R9"!A<R`D
M;&%T;&]N(#T^("1A260I('L-"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H
M*"(O7BA<9'LQ+#-]*2TH7&1[,2PR?2DH+2A<9'LQ+#)]*2D_*%M.4T5772DD
M+R(L("1D871A6R1A261=+"`D<F5S=6QT*3L-"B`@("`@("`@("`@("`@("`D
M>R1L871L;VY](#T@,#L@)&9A8W1O<B`](#$[#0H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)')E<W5L="!A<R`D=F%R*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@H<W1R;&5N*"1V87(I(#X@,"D@)B8@8W1Y<&5?9&EG:70H)'9A
M<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1[)&QA=&QO;GT@*ST@
M)'9A<B`O("1F86-T;W([#0H@("`@("`@("`@("`@("`@("`@("`@("`D9F%C
M=&]R("H](#8P.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H8W1Y
M<&5?86QP:&$H)'9A<BD@)B8@:6Y?87)R87DH)'9A<BP@87)R87DH(E,B+"`B
M5R(I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'LD;&%T;&]N?2`J
M/2`H+3$I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`O+R!#86QC=6QA
M=&4@=&AE(&-A<G1E<VEA;B!C;V]R9&EN871E<R!F;W(@;&%T:71U9&4@86YD
M(&QO;F=I='5D90T*("`@("`@("`@("`@)'1H971A(#T@9&5G,G)A9"@D;&%T
M:71U9&4I.PT*("`@("`@("`@("`@)'!H:2`@(#T@9&5G,G)A9"@D;&]N9VET
M=61E*3L-"@T*("`@("`@("`@("`@)'@@/2!315)624-%4U]714%42$527U)!
M1$E54U]%05)42"`J(&-O<R@D<&AI*2`J(&-O<R@D=&AE=&$I.PT*("`@("`@
M("`@("`@)'D@/2!315)624-%4U]714%42$527U)!1$E54U]%05)42"`J('-I
M;B@D<&AI*2`J(&-O<R@D=&AE=&$I.PT*("`@("`@("`@("`@)'H@/2!315)6
M24-%4U]714%42$527U)!1$E54U]%05)42"`@("`@("`@("`@("`J('-I;B@D
M=&AE=&$I.PT*#0H@("`@("`@("`@("`O+R!#:&5C:R!F;W(@96QE=F%T:6]N
M(&EN(&1A=&$-"B`@("`@("`@("`@("1E;&5V871I;VX@/2!I<U]N=6UE<FEC
M*"1D871A6S$Q72D@/R`D9&%T85LQ,5T@.B`P.PT*#0H@("`@("`@("`@("`O
M+R!I;G1E9V5R<SH@8V]N=F5R="`B+2TB(&9I96QD<R!T;R!N=6QL+"!E;7!T
M>2!F:65L9',@=&\@,`T*("`@("`@("`@("`@9F]R96%C:"`H87)R87DH)&1A
M=&%/<F1E<ELB8B)=+"`D9&%T84]R9&5R6R)S(ETL(#8I(&%S("1I*2![#0H@
M("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D9&%T85LD:5TL("(M+2(I("$]
M/2!F86QS92D@>R`-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)&E=(#T@
M(FYU;&PB.R`-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&1A=&%;)&E=
M(#T]("(B*2![(`T*("`@("`@("`@("`@("`@("`@("`D9&%T85LD:5T@/2`P
M.R`-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H-"B`@("`@
M("`@("`@("\O('-T<FEN9W,Z('%U;W1E#0H@("`@("`@("`@("!F;W)E86-H
M("AA<G)A>2@D9&%T84]R9&5R6R)I(ETL(#,L(#0L(#4I(&%S("1I*2![#0H@
M("`@("`@("`@("`@("`@)&1A=&%;)&E=(#T@)&1B+3YQ=6]T92@D9&%T85LD
M:5TI.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`O+R!I;G-E<G0@
M9&%T80T*("`@("`@("`@("`@)&EN<V5R="`@/2`B24Y315)4($E.5$\@(BXD
M=&%B;&5.86UE+B(@5D%,5453*"(N*"1L:6YE("T@)&5R<F]R*2XB+"([#0H@
M("`@("`@("`@("`D:6YS97)T("X]("1D871A6R1D871A3W)D97);(F(B75TN
M(BPB+B1D871A6R1D871A3W)D97);(G,B75TN(BPB.PT*("`@("`@("`@("`@
M)&EN<V5R="`N/2`D9&%T85LD9&%T84]R9&5R6R)I(EU=+B(L(BXD9&%T85LS
M72XB+"(N)&1A=&%;-%TN(BPB.PT*("`@("`@("`@("`@)&EN<V5R="`N/2`D
M9&%T85LU72XB+"(N)&1A=&%;-ETN(BPB+G)O=6YD*"1L871I='5D92P@-"DN
M(BPB.PT*("`@("`@("`@("`@)&EN<V5R="`N/2!R;W5N9"@D;&]N9VET=61E
M+"`T*2XB+"(N)&5L979A=&EO;BXB+"(N<F]U;F0H)'@L(#0I+B(L(CL-"B`@
M("`@("`@("`@("1I;G-E<G0@+CT@<F]U;F0H)'DL(#0I+B(L(BYR;W5N9"@D
M>BP@-"DN(BDB.PT*#0H@("`@("`@("`@("`D<F5S=6QT(#T@)&1B+3YQ=65R
M>2@D:6YS97)T*3L-"B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PT*("`@("`@("`@("`@("`@(&5C:&\@(EQT3&EN92`B+B@D;&EN
M92`K(#$I+B(Z("(N)&EN<V5R="XB7&XB.PT*("`@("`@("`@("`@("`@(&5C
M:&\@)')E<W5L="T^9V5T365S<V%G92@I+B)<;B([#0H@("`@("`@("`@("`@
M("`@)&5R<F]R*RL[#0H@("`@("`@("`@("!](&5L<V5I9B@D=F5R8F]S92`^
M(#(I('L-"B`@("`@("`@("`@("`@("!E8VAO("1I;G-E<G0N(EQN(CL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D;&EN92LK.PT*("`@
M('T-"B`@("`O+R!C;VUM:70@86YD(&-L;W-E#0H@("`@)&1B+3YD:7-C;VYN
M96-T*"D[#0H@("`@:68@*"1V97)B;W-E(#X@,"!\?"`D97)R;W(@/B`P*2![
M#0H@("`@("`@(&5C:&\@(E-E<G9I8V5S7U=E871H97(Z("(N*"1L:6YE("T@
M)&5R<F]R*2XB("(N)'1A8FQE3F%M92XB(&%D9&5D("([#0H@("`@("`@(&5C
M:&\@(G1O(&1A=&%B87-E("<B+B1D8DYA;64N(B<@*"(N)&5R<F]R+B(@97)R
M;W(H<RDI+EQN(CL-"B`@("!]#0I]#0HD8VQO<V4H)&9P*3L-"C\^#0H`````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&%T82](5$U,7U1R965-96YU+P``````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#(P-C(R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TA434Q?5')E94UE
M;G4O:6UA9V5S06QT,B\`````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,S`P-``P,C(V,3(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1A=&$O2%1-3%]4<F5E365N=2]I;6%G97,O````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`R,C`V-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&%T82](5$U,7U1R965-96YU+VEM86=E<T%L
M="\`````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`
M,#(R-3,P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]834PO````````
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,S`P-``P,38P,#$`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+UA-3"]24$,O````````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`Q-C0R-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U)00R]397)V97(N<&AP````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8V-#,`,3`T,3<S
M-C,P,#0`,#(P-#$T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\O(&)Y($5D9"!$=6UB:6QL("A#*2`Q.3DY+#(P
M,#`*+R\@/&5D9$!U<V5F=6QI;F,N8V]M/@HO+R`D260Z(%-E<G9E<BYP:'`L
M=B`Q+C(@,C`P,B\P,B\R."`Q,#HU.3HS,"!S<V(@17AP("0*"B\O($QI8V5N
M<V4@:7,@9W)A;G1E9"!T;R!U<V4@;W(@;6]D:69Y('1H:7,@<V]F='=A<F4@
M*")834PM4E!#(&9O<B!02%`B*0HO+R!F;W(@8V]M;65R8VEA;"!O<B!N;VXM
M8V]M;65R8VEA;"!U<V4@<')O=FED960@=&AE(&-O<'ER:6=H="!O9B!T:&4@
M875T:&]R"B\O(&ES('!R97-E<G9E9"!I;B!A;GD@9&ES=')I8G5T960@;W(@
M9&5R:79A=&EV92!W;W)K+@H*+R\@5$A)4R!33T945T%212!)4R!04D]6241%
M1"!"62!42$4@05542$]2(&!@05,@25,G)R!!3D0@04Y9($584%)%4U-%1"!/
M4@HO+R!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,
M24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453"B\O($]&($U%4D-(
M04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/
M4T4@05)%($1)4T-,04E-140N"B\O($E.($Y/($5614Y4(%-(04Q,(%1(12!!
M551(3U(@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*+R\@
M24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y4
M24%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54"B\O($Y/5"!,24U)5$5$(%1/
M+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53
M.R!,3U-3($]&(%5312P@"B\O($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.
M15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.60HO
M+R!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!3
M5%))0U0@3$E!0DE,2519+"!/4B!43U)4"B\O("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@
M5$A%(%5312!/1@HO+R!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@
M3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H*+R\@061A<'1E
M9"!T;R!014%2('-T86YD87)D<R!B>2!3=&EG(%/F=&AE<B!"86MK96X@/'-T
M:6=`<&AP+FYE=#X*"B\O(%A-3"!24$,@4V5R=F5R(&-L87-S"B\O(')E<75I
M<F5S.B!X;6QR<&,N:6YC"@IR97%U:7)E7V]N8V4@(EA-3"]24$,N<&AP(CL*
M"B\O(&QI<W1-971H;V1S.B!E:71H97(@82!S=')I;F<L(&]R(&YO=&AI;F<*
M)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VQI<W1-971H;V1S7W-I9R==/0H@
M("`@87)R87DH87)R87DH)$=,3T)!3%-;)UA-3%]24$-?07)R87DG72P@)$=,
M3T)!3%-;)UA-3%]24$-?4W1R:6YG)UTI+"`*("`@("`@("`@(&%R<F%Y*"1'
M3$]"04Q36R=834Q?4E!#7T%R<F%Y)UTI*3L*)$=,3T)!3%-;)UA-3%]24$-?
M4V5R=F5R7VQI<W1-971H;V1S7V1O8R==/0H@("`@)U1H:7,@;65T:&]D(&QI
M<W1S(&%L;"!T:&4@;65T:&]D<R!T:&%T('1H92!834PM4E!#('-E<G9E<B!K
M;F]W<R!H;W<@=&\@9&ES<&%T8V@G.PH*9G5N8W1I;VX@6$U,7U)00U]397)V
M97)?;&ES=$UE=&AO9',H)'-E<G9E<BP@)&TI"GL*("`@(&=L;V)A;"`D6$U,
M7U)00U]E<G(L("1834Q?4E!#7W-T<BP@)%A-3%]24$-?4V5R=F5R7V1M87`[
M"B`@("`D=CUN97<@6$U,7U)00U]686QU92@I.PH@("`@)&1M87`])'-E<G9E
M<BT^9&UA<#L*("`@("1O=71!<CUA<G)A>2@I.PH@("`@9F]R*')E<V5T*"1D
M;6%P*3L@;&ES="@D:V5Y+"`D=F%L*3UE86-H*"1D;6%P*3L@*2!["B`@("`@
M("`@)&]U=$%R6UT];F5W(%A-3%]24$-?5F%L=64H)&ME>2P@(G-T<FEN9R(I
M.PH@("`@?0H@("`@)&1M87`])%A-3%]24$-?4V5R=F5R7V1M87`["B`@("!F
M;W(H<F5S970H)&1M87`I.R!L:7-T*"1K97DL("1V86PI/65A8V@H)&1M87`I
M.R`I('L*("`@("`@("`D;W5T07);73UN97<@6$U,7U)00U]686QU92@D:V5Y
M+"`B<W1R:6YG(BD["B`@("!]"B`@("`D=BT^861D07)R87DH)&]U=$%R*3L*
M("`@(')E='5R;B!N97<@6$U,7U)00U]297-P;VYS92@D=BD["GT*"B1'3$]"
M04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V13:6=N871U<F5?<VEG)UT]"B`@
M("!A<G)A>2AA<G)A>2@D1TQ/0D%,4ULG6$U,7U)00U]!<G)A>2==+"`D1TQ/
M0D%,4ULG6$U,7U)00U]3=')I;F<G72DI.PHD1TQ/0D%,4ULG6$U,7U)00U]3
M97)V97)?;65T:&]D4VEG;F%T=7)E7V1O8R==/0H@("`@)U)E='5R;G,@86X@
M87)R87D@;V8@:VYO=VX@<VEG;F%T=7)E<R`H86X@87)R87D@;V8@87)R87ES
M*2!F;W(@=&AE(&UE=&AO9"!N86UE('!A<W-E9"X@268@;F\@<VEG;F%T=7)E
M<R!A<F4@:VYO=VXL(')E='5R;G,@82!N;VYE+6%R<F%Y("AT97-T(&9O<B!T
M>7!E("$](&%R<F%Y('1O(&1E=&5C="!M:7-S:6YG('-I9VYA='5R92DG.PH*
M9G5N8W1I;VX@6$U,7U)00U]397)V97)?;65T:&]D4VEG;F%T=7)E*"1S97)V
M97(L("1M*0I["B`@("!G;&]B86P@)%A-3%]24$-?97)R+"`D6$U,7U)00U]S
M='(L("1834Q?4E!#7U-E<G9E<E]D;6%P.PH@("`@"B`@("`D;65T:$YA;64]
M)&TM/F=E=%!A<F%M*#`I.PH@("`@)&UE=&A.86UE/21M971H3F%M92T^<V-A
M;&%R=F%L*"D["B`@("!I9B`H97)E9R@B7G-Y<W1E;5PN(BP@)&UE=&A.86UE
M*2D@>PH@("`@("`@("1D;6%P/21834Q?4E!#7U-E<G9E<E]D;6%P.R`D<WES
M0V%L;#TQ.PH@("`@?2!E;'-E('L*("`@("`@("`D9&UA<#TD<V5R=F5R+3YD
M;6%P.R`D<WES0V%L;#TP.PH@("`@?0H@("`@+R\@('!R:6YT("(\(2TM("1[
M;65T:$YA;65]("TM/EQN(CL*("`@(&EF("AI<W-E="@D9&UA<%LD;65T:$YA
M;65=*2D@>PH@("`@("`@(&EF("@D9&UA<%LD;65T:$YA;65=6R)S:6=N871U
M<F4B72D@>PH@("`@("`@("`@("`D<VEG<SUA<G)A>2@I.PH@("`@("`@("`@
M("`D=&AE<VEG<STD9&UA<%LD;65T:$YA;65=6R)S:6=N871U<F4B73L*("`@
M("`@("`@("`@9F]R*"1I/3`[("1I/'-I>F5O9B@D=&AE<VEG<RD[("1I*RLI
M('L*("`@("`@("`@("`@("`@("1C=7)S:6<]87)R87DH*3L*("`@("`@("`@
M("`@("`@("1I;E-I9STD=&AE<VEG<ULD:5T["B`@("`@("`@("`@("`@("!F
M;W(H)&H],#L@)&H\<VEZ96]F*"1I;E-I9RD[("1J*RLI('L*("`@("`@("`@
M("`@("`@("`@("`D8W5R<VEG6UT];F5W(%A-3%]24$-?5F%L=64H)&EN4VEG
M6R1J72P@(G-T<FEN9R(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'-I9W-;73UN97<@6$U,7U)00U]686QU92@D8W5R<VEG+"`B87)R
M87DB*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<CUN97<@6$U,7U)0
M0U]297-P;VYS92AN97<@6$U,7U)00U]686QU92@D<VEG<RP@(F%R<F%Y(BDI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R/6YE=R!834Q?4E!#
M7U)E<W!O;G-E*&YE=R!834Q?4E!#7U9A;'5E*")U;F1E9B(L(")S=')I;F<B
M*2D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`D<CUN97<@6$U,
M7U)00U]297-P;VYS92@P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("18
M34Q?4E!#7V5R<ELB:6YT<F]S<&5C=%]U;FMN;W=N(ETL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@)%A-3%]24$-?<W1R6R)I;G1R;W-P96-T7W5N:VYO
M=VXB72D["B`@("!]"B`@("!R971U<FX@)'(["GT*"B1'3$]"04Q36R=834Q?
M4E!#7U-E<G9E<E]M971H;V1(96QP7W-I9R==/0H@("`@87)R87DH87)R87DH
M)$=,3T)!3%-;)UA-3%]24$-?4W1R:6YG)UTL("1'3$]"04Q36R=834Q?4E!#
M7U-T<FEN9R==*2D["B1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V1(
M96QP7V1O8R==/0H@("`@)U)E='5R;G,@:&5L<"!T97AT(&EF(&1E9FEN960@
M9F]R('1H92!M971H;V0@<&%S<V5D+"!O=&AE<G=I<V4@<F5T=7)N<R!A;B!E
M;7!T>2!S=')I;F<G.PH*9G5N8W1I;VX@6$U,7U)00U]397)V97)?;65T:&]D
M2&5L<"@D<V5R=F5R+"`D;2D*>PH@("`@9VQO8F%L("1834Q?4E!#7V5R<BP@
M)%A-3%]24$-?<W1R+"`D6$U,7U)00U]397)V97)?9&UA<#L*("`@(`H@("`@
M)&UE=&A.86UE/21M+3YG971087)A;2@P*3L*("`@("1M971H3F%M93TD;65T
M:$YA;64M/G-C86QA<G9A;"@I.PH@("`@:68@*&5R96<H(EYS>7-T96U<+B(L
M("1M971H3F%M92DI('L*("`@("`@("`D9&UA<#TD6$U,7U)00U]397)V97)?
M9&UA<#L@)'-Y<T-A;&P],3L*("`@('T@96QS92!["B`@("`@("`@)&1M87`]
M)'-E<G9E<BT^9&UA<#L@)'-Y<T-A;&P],#L*("`@('T*("`@("\O("!P<FEN
M="`B/"$M+2`D>VUE=&A.86UE?2`M+3Y<;B(["B`@("!I9B`H:7-S970H)&1M
M87!;)&UE=&A.86UE72DI('L*("`@("`@("!I9B`H)&1M87!;)&UE=&A.86UE
M75LB9&]C<W1R:6YG(ETI('L*("`@("`@("`@("`@)'(];F5W(%A-3%]24$-?
M4F5S<&]N<V4H;F5W(%A-3%]24$-?5F%L=64H)&1M87!;)&UE=&A.86UE75LB
M9&]C<W1R:6YG(ETI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B
M<W1R:6YG(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'(];F5W
M(%A-3%]24$-?4F5S<&]N<V4H;F5W(%A-3%]24$-?5F%L=64H(B(L(")S=')I
M;F<B*2D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`D<CUN97<@
M6$U,7U)00U]297-P;VYS92@P+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("1834Q?4E!#7V5R<ELB:6YT<F]S<&5C=%]U;FMN;W=N(ETL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@)%A-3%]24$-?<W1R6R)I;G1R;W-P96-T7W5N
M:VYO=VXB72D["B`@("!]"B`@("!R971U<FX@)'(["GT*"B1'3$]"04Q36R=8
M34Q?4E!#7U-E<G9E<E]D;6%P)UT]87)R87DH"B`@("`B<WES=&5M+FQI<W1-
M971H;V1S(B`]/@H@("`@87)R87DH(F9U;F-T:6]N(B`]/B`B6$U,7U)00U]3
M97)V97)?;&ES=$UE=&AO9',B+`H@("`@("`@("`@(G-I9VYA='5R92(@/3X@
M)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VQI<W1-971H;V1S7W-I9R==+`H@
M("`@("`@("`@(F1O8W-T<FEN9R(@/3X@)$=,3T)!3%-;)UA-3%]24$-?4V5R
M=F5R7VQI<W1-971H;V1S7V1O8R==*2P*"B`@("`B<WES=&5M+FUE=&AO9$AE
M;'`B(#T^"B`@("!A<G)A>2@B9G5N8W1I;VXB(#T^(")834Q?4E!#7U-E<G9E
M<E]M971H;V1(96QP(BP*("`@("`@("`@(")S:6=N871U<F4B(#T^("1'3$]"
M04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V1(96QP7W-I9R==+`H@("`@("`@
M("`@(F1O8W-T<FEN9R(@/3X@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE
M=&AO9$AE;'!?9&]C)UTI+`H*("`@(")S>7-T96TN;65T:&]D4VEG;F%T=7)E
M(B`]/@H@("`@87)R87DH(F9U;F-T:6]N(B`]/B`B6$U,7U)00U]397)V97)?
M;65T:&]D4VEG;F%T=7)E(BP*("`@("`@("`@(")S:6=N871U<F4B(#T^("1'
M3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V13:6=N871U<F5?<VEG)UTL
M"B`@("`@("`@("`B9&]C<W1R:6YG(B`]/B`D1TQ/0D%,4ULG6$U,7U)00U]3
M97)V97)?;65T:&]D4VEG;F%T=7)E7V1O8R==*0HI.PH*)$=,3T)!3%-;)UA-
M3%]24$-?4V5R=F5R7V1E8G5G:6YF;R==/2(B.PH*9G5N8W1I;VX@6$U,7U)0
M0U]397)V97)?9&5B=6=M<V<H)&TI"GL*("`@(&=L;V)A;"`D6$U,7U)00U]3
M97)V97)?9&5B=6=I;F9O.PH@("`@)%A-3%]24$-?4V5R=F5R7V1E8G5G:6YF
M;STD6$U,7U)00U]397)V97)?9&5B=6=I;F9O("X@)&T@+B`B7&XB.PI]"@IC
M;&%S<R!834Q?4E!#7U-E<G9E<@I["B`@("!V87(@)&1M87`]87)R87DH*3L*
M"B`@("!F=6YC=&EO;B!834Q?4E!#7U-E<G9E<B@D9&ES<$UA<"P@)'-E<G9I
M8V5.;W<],2D*("`@('L*("`@("`@("!G;&]B86P@)$A45%!?4D%77U!/4U1?
M1$%403L*("`@("`@("`O+R!D:7-P36%P(&ES(&$@9&5S<&%T8V@@87)R87D@
M;V8@;65T:&]D<PH@("`@("`@("\O(&UA<'!E9"!T;R!F=6YC=&EO;B!N86UE
M<R!A;F0@<VEG;F%T=7)E<PH@("`@("`@("\O(&EF(&$@;65T:&]D"B`@("`@
M("`@+R\@9&]E<VXG="!A<'!E87(@:6X@=&AE(&UA<"!T:&5N(&%N('5N:VYO
M=VX*("`@("`@("`O+R!M971H;V0@97)R;W(@:7,@9V5N97)A=&5D"B`@("`@
M("`@)'1H:7,M/F1M87`])&1I<W!-87`["B`@("`@("`@:68@*"1S97)V:6-E
M3F]W*2!["B`@("`@("`@("`@("1T:&ES+3YS97)V:6-E*"D["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N('-E<FEA;&EZ941E8G5G*"D*("`@('L*
M("`@("`@("!G;&]B86P@)%A-3%]24$-?4V5R=F5R7V1E8G5G:6YF;SL*("`@
M("`@("!I9B`H)%A-3%]24$-?4V5R=F5R7V1E8G5G:6YF;R$](B(I(`H@("`@
M("`@("`@("!R971U<FX@(CPA+2T@1$5"54<@24Y&3SI<;EQN(B`N"B`@("`@
M("`@("`@("`@("`D6$U,7U)00U]397)V97)?9&5B=6=I;F9O("X@(EQN+2T^
M7&XB.PH@("`@("`@(&5L<V4*("`@("`@("`@("`@<F5T=7)N("(B.PH@("`@
M?0H*("`@(&9U;F-T:6]N('-E<G9I8V4H*0H@("`@>PH@("`@("`@("1R/21T
M:&ES+3YP87)S95)E<75E<W0H*3L*("`@("`@("`D<&%Y;&]A9#TB/#]X;6P@
M=F5R<VEO;CU<(C$N,%PB/SY<;B(@+B`*("`@("`@("`@("`@)'1H:7,M/G-E
M<FEA;&EZ941E8G5G*"D@+@H@("`@("`@("`@("`D<BT^<V5R:6%L:7IE*"D[
M"B`@("`@("`@2&5A9&5R*")#;VYT96YT+71Y<&4Z('1E>'0O>&UL7&Y#;VYT
M96YT+6QE;F=T:#H@(B`N(`H@("`@("`@("`@("`@("!S=')L96XH)'!A>6QO
M860I*3L*("`@("`@("!P<FEN="`D<&%Y;&]A9#L*("`@('T*"B`@("!F=6YC
M=&EO;B!V97)I9GE3:6=N871U<F4H)&EN+"`D<VEG*0H@("`@>PH@("`@("`@
M(&9O<B@D:3TP.R`D:3QS:7IE;V8H)'-I9RD[("1I*RLI('L*("`@("`@("`@
M("`@+R\@8VAE8VL@96%C:"!P;W-S:6)L92!S:6=N871U<F4@:6X@='5R;@H@
M("`@("`@("`@("`D8W5R<VEG/21S:6=;)&E=.PH@("`@("`@("`@("!I9B`H
M<VEZ96]F*"1C=7)S:6<I/3TD:6XM/F=E=$YU;5!A<F%M<R@I*S$I('L*("`@
M("`@("`@("`@("`@("1I='-/2STQ.PH@("`@("`@("`@("`@("`@9F]R*"1N
M/3`[("1N/"1I;BT^9V5T3G5M4&%R86US*"D[("1N*RLI('L*("`@("`@("`@
M("`@("`@("`@("`D<#TD:6XM/F=E=%!A<F%M*"1N*3L*("`@("`@("`@("`@
M("`@("`@("`O+R!P<FEN="`B/"$M+2`D<"`M+3Y<;B(["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1P+3YK:6YD3V8H*2`]/2`B<V-A;&%R(BD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<'0])'`M/G-C86QA<G1Y<"@I.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1P=#TD<"T^:VEN9$]F*"D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("\O("1N*S$@87,@9FER<W0@='EP92!O9B!S
M:6<@:7,@<F5T=7)N('1Y<&4*("`@("`@("`@("`@("`@("`@("!I9B`H)'!T
M("$]("1C=7)S:6=;)&XK,5TI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&ET<T]+/3`["B`@("`@("`@("`@("`@("`@("`@("`@("1P;F\])&XK,3L@
M)'=A;G1E9#TD8W5R<VEG6R1N*S%=.R`D9V]T/21P=#L*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1I='-/2RD@"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*#$I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>2@P+"`B5V%N=&5D
M("1[=V%N=&5D?2P@9V]T("1[9V]T?2!A="!P87)A;2`D>W!N;WTI(BD["B`@
M("!]"@H@("`@9G5N8W1I;VX@<&%R<V5297%U97-T*"1D871A/2(B*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D6$U,7U)00U]X:"PD2%144%]205=?4$]35%]$
M051!.PH@("`@("`@(&=L;V)A;"`D6$U,7U)00U]E<G(L("1834Q?4E!#7W-T
M<BP@)%A-3%]24$-?97)R>&UL+`H@("`@("`@("`@("`D6$U,7U)00U]D969E
M;F-O9&EN9RP@)%A-3%]24$-?4V5R=F5R7V1M87`["B`@("`@("`@"B`@("`@
M("`@:68@*"1D871A/3TB(BD@>PH@("`@("`@("`@("`D9&%T83TD2%144%]2
M05=?4$]35%]$051!.PH@("`@("`@('T*("`@("`@("`D<&%R<V5R(#T@>&UL
M7W!A<G-E<E]C<F5A=&4H)%A-3%]24$-?9&5F96YC;V1I;F<I.PH@("`@("`@
M(`H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=/6%R<F%Y*"D["B`@("`@
M("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T)UT](B(["B`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)V-M)UT],#L@"B`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)VES9B==/3`[(`H@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=P87)A;7,G73UA<G)A>2@I.PH@("`@("`@("1834Q?4E!#7WAH
M6R1P87)S97)=6R=M971H;V0G73TB(CL*("`@("`@("`*("`@("`@("`D<&QI
M<W0@/2`G)SL*"B`@("`@("`@+R\@9&5C;VUP;W-E(&EN8V]M:6YG(%A-3"!I
M;G1O(')E<75E<W0@<W1R=6-T=7)E"B`@("`@("`@"B`@("`@("`@>&UL7W!A
M<G-E<E]S971?;W!T:6]N*"1P87)S97(L(%A-3%]/4%1)3TY?0T%315]&3TQ$
M24Y'+"!T<G5E*3L*("`@("`@("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D
M<&%R<V5R+"`B6$U,7U)00U]S92(L(")834Q?4E!#7V5E(BD["B`@("`@("`@
M>&UL7W-E=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1P87)S97(L(")834Q?
M4E!#7V-D(BD["B`@("`@("`@>&UL7W-E=%]D969A=6QT7VAA;F1L97(H)'!A
M<G-E<BP@(EA-3%]24$-?9&@B*3L*("`@("`@("!I9B`H(7AM;%]P87)S92@D
M<&%R<V5R+"`D9&%T82P@,2DI('L*("`@("`@("`@("`@+R\@<F5T=7)N(%A-
M3"!E<G)O<B!A<R!A(&9A=6QT0V]D90H@("`@("`@("`@("`D<CUN97<@6$U,
M7U)00U]297-P;VYS92@P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D6$U,7U)00U]E<G)X;6PK>&UL7V=E=%]E<G)O<E]C;V1E*"1P
M87)S97(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M<')I;G1F*")834P@97)R;W(Z("5S(&%T(&QI;F4@)60B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM;%]E<G)O<E]S
M=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E*"1P87)S97(I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U
M<G)E;G1?;&EN95]N=6UB97(H)'!A<G-E<BDI*3L*("`@("`@("`@("`@>&UL
M7W!A<G-E<E]F<F5E*"1P87)S97(I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@('AM;%]P87)S97)?9G)E92@D<&%R<V5R*3L*("`@("`@("`@("`@
M)&T];F5W(%A-3%]24$-?365S<V%G92@D6$U,7U)00U]X:%LD<&%R<V5R75LG
M;65T:&]D)UTI.PH@("`@("`@("`@("`O+R!N;W<@861D('!A<F%M971E<G,@
M:6X*("`@("`@("`@("`@9F]R*"1I/3`[("1I/'-I>F5O9B@D6$U,7U)00U]X
M:%LD<&%R<V5R75LG<&%R86US)UTI.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`O+R!P<FEN="`B/"$M+2`B("X@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W!A
M<F%M<R==6R1I72X@(BTM/EQN(CL*("`@("`@("`@("`@("`@("1P;&ES="X]
M(B1I("T@(B`N("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<&%R86US)UU;)&E=
M+B`B(%QN(CL*("`@("`@("`@("`@("`@(&5V86PH)R1M+3YA9&1087)A;2@G
M("X@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W!A<F%M<R==6R1I72X@(BD[(BD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@6$U,7U)00U]397)V97)?9&5B
M=6=M<V<H)'!L:7-T*3L*("`@("`@("`@("`@+R\@;F]W('1O(&1E86P@=VET
M:"!T:&4@;65T:&]D"B`@("`@("`@("`@("1M971H3F%M93TD6$U,7U)00U]X
M:%LD<&%R<V5R75LG;65T:&]D)UT["B`@("`@("`@("`@(&EF("AE<F5G*")>
M<WES=&5M7"XB+"`D;65T:$YA;64I*2!["B`@("`@("`@("`@("`@("`D9&UA
M<#TD6$U,7U)00U]397)V97)?9&UA<#L@)'-Y<T-A;&P],3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D;6%P/21T:&ES+3YD;6%P
M.R`D<WES0V%L;#TP.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI
M<W-E="@D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==*2D@>PH@("`@("`@
M("`@("`@("`@+R\@9&ES<&%T8V@@:68@97AI<W1S"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1M87!;)&UE=&A.86UE75LG<VEG;F%T=7)E)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-R/21T:&ES+3YV97)I9GE3:6=N871U
M<F4H)&TL(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D;6%P6R1M971H3F%M95U;)W-I9VYA='5R92==("D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H("@A:7-S970H
M)&1M87!;)&UE=&A.86UE75LG<VEG;F%T=7)E)UTI*2!\?"`D<W);,%TI('L*
M("`@("`@("`@("`@("`@("`@("`O+R!I9B!N;R!S:6=N871U<F4@;W(@8V]R
M<F5C="!S:6=N871U<F4*("`@("`@("`@("`@("`@("`@("!I9B`H)'-Y<T-A
M;&PI('L@"B`@("`@("`@("`@("`@("`@("`@("`@(&5V86PH)R1R/2<@+B`D
M9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==("X@"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R@D=&AI<RP@)&TI.R<I.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@(&5V86PH
M)R1R/2<@+B`D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==("X@"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R@D;2D[)RD["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D<CUN97<@6$U,7U)00U]297-P;VYS92@P+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#
M7V5R<ELB:6YC;W)R96-T7W!A<F%M<R)=+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T<ELB:6YC;W)R
M96-T7W!A<F%M<R)=+B(Z("(N("1S<ELQ72D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!E;'-E
M('!R97!A<F4@97)R;W(@<F5S<&]N<V4*("`@("`@("`@("`@("`@("1R/6YE
M=R!834Q?4E!#7U)E<W!O;G-E*#`L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D6$U,7U)00U]E<G);(G5N:VYO=VY?;65T:&]D
M(ETL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M6$U,7U)00U]S=');(G5N:VYO=VY?;65T:&]D(ETI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<CL*("`@('T*"B`@9G5N8W1I
M;VX@96-H;TEN<'5T*"D@>PH@("`@("`@(&=L;V)A;"`D2%144%]205=?4$]3
M5%]$051!.PH*("`@("`@("`O+R!A(&1E8G5G9VEN9R!R;W5T:6YE.B!J=7-T
M(&5C:&]S(&)A8VL@=&AE(&EN<'5T"B`@("`@("`@+R\@<&%C:V5T(&%S(&$@
M<W1R:6YG('9A;'5E"@H@("`@("`@("1R/6YE=R!834Q?4E!#7U)E<W!O;G-E
M.PH@("`@("`@("1R+3YX=CUN97<@6$U,7U)00U]686QU92@@(B=!:&$@<V%I
M9"!).B`G(B`N("1(5%107U)!5U]03U-47T1!5$$L(")S=')I;F<B*3L*("`@
M("`@("!P<FEN="`D<BT^<V5R:6%L:7IE*"D["B`@?0I]"@H_/@H`````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U!A<G-E<BYP:'``````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(S,#(`,3`T
M,3<S-C,P,#0`,#$W-S0R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@4W1I9R!"86MK96X@
M/'-S8D!F87-T+FYO/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)
M9#H@4&%R<V5R+G!H<"QV(#$N-2`R,#`S+S`R+S(S(#$P.C0X.C,Q('-S8B!%
M>'`@)`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@6$U,(%!A
M<G-E<B!C;&%S<RX@(%1H:7,@:7,@86X@6$U,('!A<G-E<B!B87-E9"!O;B!0
M2%`G<R`B>&UL(B!E>'1E;G-I;VXL"B`J(&)A<V5D(&]N('1H92!B=6YD;&5D
M(&5X<&%T(&QI8G)A<GDN"B`J"B`J($!A=71H;W(@(%-T:6<@0F%K:V5N(#QS
M<V)`9F%S="YN;SX*("H@0'1O9&\@("`@5&5S=',@=&AA="!N965D('1O(&)E
M(&UA9&4Z"B`J("`@("`@("`@("T@97)R;W(@8VQA<W,*("H@("`@("`@("`@
M+2!M:7AI;F<@8VAA<F%C=&5R(&5N8V]D:6YG<PH@*B`@("`@("`@("`M(&$@
M=&5S="!U<VEN9R!A;&P@97AP870@:&%N9&QE<G,*("H@("`@("`@("`@+2!O
M<'1I;VYS("AF;VQD:6YG+"!O=71P=70@8VAA<G-E="D*("H@("`@("`@("`@
M+2!D:69F97)E;G0@<&%R<VEN9R!M;V1E<PH@*@H@*B!`;F]T97,@("`M($ET
M(')E<75I<F5S(%!(4"`T+C`N-'!L,2!O<B!G<F5A=&5R"B`J("`@("`@("`@
M("T@1G)O;2!R979I<VEO;B`Q+C$W+"!T:&4@9G5N8W1I;VX@;F%M97,@=7-E
M9"!B>2!T:&4@)V9U;F,G(&UO9&4*("H@("`@("`@("`@("!A<F4@:6X@=&AE
M(&9O<FUA="`B>&UL=&%G7R1E;&5M(BP@9F]R(&5X86UP;&4Z('5S92`B>&UL
M=&%G7VYA;64B"B`J("`@("`@("`@("`@=&\@:&%N9&QE('1H92`\;F%M93X\
M+VYA;64^('1A9W,@;V8@>6]U<B!X;6P@9FEL92X*("HO"F-L87-S(%A-3%]0
M87)S97(@97AT96YD<R!014%2"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@
M("`@+RHJ"B`@("`@*B!`=F%R("!R97-O=7)C92`@6$U,('!A<G-E<B!H86YD
M;&4*("`@("`J+PH@("`@=F%R("1P87)S97(["@H@("`@+RHJ"B`@("`@*B!`
M=F%R("!R97-O=7)C92`@1FEL92!H86YD;&4@:68@<&%R<VEN9R!F<F]M(&$@
M9FEL90H@("`@("HO"B`@("!V87(@)&9P.PH*("`@("\J*@H@("`@("H@0'9A
M<B`@8F]O;&5A;B`@5VAE=&AE<B!T;R!D;R!C87-E(&9O;&1I;F<*("`@("`J
M+PH@("`@=F%R("1F;VQD:6YG(#T@=')U93L*"B`@("`O*BH*("`@("`J($!V
M87(@('-T<FEN9R`@36]D92!O9B!O<&5R871I;VXL(&]N92!O9B`B979E;G0B
M(&]R(")F=6YC(@H@("`@("HO"B`@("!V87(@)&UO9&4["@H@("`@+RHJ"B`@
M("`@*B!-87!P:6YG(&9R;VT@97AP870@:&%N9&QE<B!F=6YC=&EO;B!T;R!C
M;&%S<R!M971H;V0N"B`@("`@*@H@("`@("H@0'9A<B`@87)R87D*("`@("`J
M+PH@("`@=F%R("1H86YD;&5R(#T@87)R87DH"B`@("`@("`@)V-H87)A8W1E
M<E]D871A7VAA;F1L97(G("`@("`@("`@("`@/3X@)V-D871A2&%N9&QE<B<L
M"B`@("`@("`@)V1E9F%U;'1?:&%N9&QE<B<@("`@("`@("`@("`@("`@("`@
M/3X@)V1E9F%U;'1(86YD;&5R)RP*("`@("`@("`G<')O8V5S<VEN9U]I;G-T
M<G5C=&EO;E]H86YD;&5R)R`@("`]/B`G<&E(86YD;&5R)RP*("`@("`@("`G
M=6YP87)S961?96YT:71Y7V1E8VQ?:&%N9&QE<B<@("`@("`]/B`G=6YP87)S
M961(86YD;&5R)RP*("`@("`@("`G;F]T871I;VY?9&5C;%]H86YD;&5R)R`@
M("`@("`@("`@("`]/B`G;F]T871I;VY(86YD;&5R)RP*("`@("`@("`G97AT
M97)N86Q?96YT:71Y7W)E9E]H86YD;&5R)R`@("`@("`]/B`G96YT:71Y<F5F
M2&%N9&QE<B<*("`@("D["@H@("`@+RHJ"B`@("`@*B!`=F%R('-T<FEN9R!S
M;W5R8V4@96YC;V1I;F<*("`@("`J+PH@("`@=F%R("1S<F-E;F,["@H@("`@
M+RHJ"B`@("`@*B!`=F%R('-T<FEN9R!T87)G970@96YC;V1I;F<*("`@("`J
M+PH@("`@=F%R("1T9W1E;F,["@H@("`@+RH*("`@("`J(%5S92!C86QL7W5S
M97)?9G5N8R!W:&5N('!H<"`^/2`T+C`N-PH@("`@("H@0'9A<B!B;V]L96%N
M"B`@("`@*B!`<V5E('-E=$UO9&4H*0H@("`@("HO"B`@("!V87(@)'5S95]C
M86QL7W5S97)?9G5N8R`]('1R=64["@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J($-R96%T97,@86X@6$U,('!A
M<G-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("!S;W5R8V4@
M8VAA<G-E="!E;F-O9&EN9RP@=7-E($Y53$P@*&1E9F%U;'0I('1O('5S90H@
M("`@("H@("`@("`@("`@("`@("`@("`@=VAA=&5V97(@=&AE(&1O8W5M96YT
M('-P96-I9FEE<PH@("`@("H@0'!A<F%M("`@('-T<FEN9R`@:&]W('1H:7,@
M<&%R<V5R(&]B:F5C="!S:&]U;&0@=V]R:RP@(F5V96YT(B!F;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@('-T87)T96QE;65N="]E;F1E;&5M96YT+71Y
M<&4@979E;G1S+"`B9G5N8R(*("`@("`J("`@("`@("`@("`@("`@("`@('1O
M(&AA=F4@:70@8V%L;"!F=6YC=&EO;G,@;F%M960@869T97(@96QE;65N=',*
M("`@("`J"B`@("`@*B!`<V5E('AM;%]P87)S97)?8W)E871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%A-3%]087)S97(H)'-R8V5N8R`](&YU;&PL("1M;V1E
M(#T@(F5V96YT(BP@)'1G=&5N8R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H
M:7,M/E!%05(H)UA-3%]087)S97)?17)R;W(G*3L*"B`@("`@("`@:68@*"1S
M<F-E;F,@/3T](&YU;&PI('L*("`@("`@("`@("`@)'AP(#T@0'AM;%]P87)S
M97)?8W)E871E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'AP
M(#T@0'AM;%]P87)S97)?8W)E871E*"1S<F-E;F,I.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-?<F5S;W5R8V4H)'AP*2D@>PH@("`@("`@("`@("!I9B`H
M)'1G=&5N8R`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@:68@*"%`>&UL
M7W!A<G-E<E]S971?;W!T:6]N*"1X<"P@6$U,7T]05$E/3E]405)'151?14Y#
M3T1)3D<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1G=&5N8RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(FEN=F%L:60@=&%R9V5T(&5N8V]D:6YG(BD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'1H:7,M/G!A<G-E<B`]("1X<#L*("`@("`@("`@("`@)'1H:7,M/G-E=$UO
M9&4H)&UO9&4I.PH@("`@("`@("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH
M)'AP+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@)'1H:7,M/F9O;&1I;F<I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^<W)C96YC(#T@)'-R8V5N8SL*
M("`@("`@("`D=&AI<RT^=&=T96YC(#T@)'1G=&5N8SL*("`@('T*("`@("\O
M('U]?0H*("`@("\O('M[>R!S971-;V1E*"D*"B`@("`O*BH*("`@("`J(%-E
M=',@=&AE(&UO9&4@86YD(&%L;"!H86YD;&5R+@H@("`@("H*("`@("`J($!P
M87)A;2`@("!S=')I;F<*("`@("`J($!S964@("`@("`D:&%N9&QE<@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971-;V1E*"1M;V1E*0H@("`@>PH*("`@("`@
M("`D=&AI<RT^;6]D92`]("1M;V1E.PH*("`@("`@("!X;6Q?<V5T7V]B:F5C
M="@D=&AI<RT^<&%R<V5R+"`D=&AI<RD["@H@("`@("`@('-W:71C:"`H)&UO
M9&4I('L*"B`@("`@("`@("`@(&-A<V4@(F9U;F,B.@H@("`@("`@("`@("`@
M("`@+R\@=7-E(&-A;&Q?=7-E<E]F=6YC*"D@=VAE;B!P:'`@/CT@-"XP+C<*
M("`@("`@("`@("`@("`@("\O(&]R(&-A;&Q?=7-E<E]M971H;V0H*2!I9B!N
M;W0*("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R
M<VEO;B@I+"`G-"XP+C<G+"`G;'0G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YU<V5?8V%L;%]U<V5R7V9U;F,@/2!F86QS93L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5S
M95]C86QL7W5S97)?9G5N8R`]('1R=64["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'1H:7,M
M/G!A<G-E<BP@(F9U;F-3=&%R=$AA;F1L97(B+"`B9G5N8T5N9$AA;F1L97(B
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`B
M979E;G0B.@H@("`@("`@("`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L
M97(H)'1H:7,M/G!A<G-E<BP@(G-T87)T2&%N9&QE<B(L(")E;F1(86YD;&5R
M(BD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YH86YD;&5R(&%S("1X;6Q?9G5N8R`]/B`D;65T
M:&]D*0H@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D=&AI<RP@)&UE
M=&AO9"DI('L*("`@("`@("`@("`@("`@("1X;6Q?9G5N8R`](")X;6Q?<V5T
M7R(@+B`D>&UL7V9U;F,["B`@("`@("`@("`@("`@("`D>&UL7V9U;F,H)'1H
M:7,M/G!A<G-E<BP@)&UE=&AO9"D["B`@("`@("`@("`@('T*"B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@<V5T26YP=71&:6QE*"D*"B`@("`O*BH*
M("`@("`J($1E9FEN97,*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`@("`@1FEL96YA;64@*&9U;&P@<&%T:"D*("`@("`J($!R971U<FX@("!R
M97-O=7)C92`@("!F;W!E;B!H86YD;&4@;V8@=&AE(&=I=F5N(&9I;&4*("`@
M("`J($!T:')O=W,@("!834Q?4&%R<V5R7T5R<F]R"B`@("`@*B!`<V5E("`@
M("`@<V5T26YP=70H*2P@<&%R<V4H*0H@("`@("H@0&%C8V5S<R`@('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971);G!U=$9I;&4H)&9I;&4I"B`@
M("!["@H@("`@("`@("1F<"`]($!F;W!E;B@D9FEL92P@(G)B(BD["B`@("`@
M("`@:68@*&ES7W)E<V]U<F-E*"1F<"DI('L*("`@("`@("`@("`@)'1H:7,M
M/F9P(#T@)&9P.PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P:'!?97)R;W)M
M<V<I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-E=$EN<'5T*"D*
M"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&9I;&4@:&%N9&QE('1O('5S92!W
M:71H('!A<G-E*"DN"B`@("`@*@H@("`@("H@0'!A<F%M("`@(')E<V]U<F-E
M("`@(&9O<&5N"B`@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`@*B!`<V5E
M("`@("`@<&%R<V4H*2P@<V5T26YP=71&:6QE*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T26YP=70H)&9P*0H@("`@>PH@("`@("`@(&EF("AI<U]R97-O
M=7)C92@D9G`I*2!["B`@("`@("`@("`@("1T:&ES+3YF<"`]("1F<#L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO="!A(&9I;&4@<F5S;W5R8V4B*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P87)S92@I"@H@("`@+RHJ
M"B`@("`@*B!#96YT<F%L('!A<G-I;F<@9G5N8W1I;VXN"B`@("`@*@H@("`@
M("H@0'1H<F]W<R`@(%A-3%]087)S97)?17)R;W(*("`@("`J($!R971U<FX@
M("!B;V]L96%N('1R=64@;VX@<W5C8V5S<PH@("`@("H@0'-E92`@("`@('!A
M<G-E4W1R:6YG*"D*("`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@<&%R<V4H*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S
M;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(FYO(&EN<'5T(BD["B`@("`@("`@?0H*("`@("`@("!W
M:&EL92`H)&1A=&$@/2!F<F5A9"@D=&AI<RT^9G`L(#(P-#@I*2!["@H@("`@
M("`@("`@("`D97)R(#T@)'1H:7,M/G!A<G-E4W1R:6YG*"1D871A+"!F96]F
M*"1T:&ES+3YF<"DI.PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R*2D@>PH@("`@("`@("`@("`@("`@9F-L;W-E*"1T:&ES+3YF<"D["B`@
M("`@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@("`@("`@("`@?0H*("`@
M("`@("!]"@H@("`@("`@(&9C;&]S92@D=&AI<RT^9G`I.PH*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P87)S
M95-T<FEN9R@I"@H@("`@+RHJ"B`@("`@*B!087)S97,@82!S=')I;F<N"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@6$U,(&1A=&$*("`@("`J
M($!P87)A;2`@("!B;V]L96%N(#\_/PH@("`@("H@0'1H<F]W<R`@(%A-3%]0
M87)S97)?17)R;W(*("`@("`J($!R971U<FX@("!M:7AE9"`@('1R=64@;VX@
M<W5C8V5S<R!O<B!A('-T<FEN9R!W:71H('1H92!X;6P@<&%R<V5R(&5R<F]R
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E4W1R:6YG*"1D871A+"`D96]F
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%X;6Q?<&%R<V4H)'1H:7,M
M/G!A<G-E<BP@)&1A=&$L("1E;V8I*2!["B`@("`@("`@("`@("1E<G(@/2`D
M=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^<&%R<V5R*3L*("`@("`@("`@("`@
M>&UL7W!A<G-E<E]F<F5E*"1T:&ES+3YP87)S97(I.PH@("`@("`@("`@("!R
M971U<FX@)&5R<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9U;F-3=&%R=$AA;F1L97(H
M*0H*("`@(&9U;F-T:6]N(&9U;F-3=&%R=$AA;F1L97(H)'AP+"`D96QE;2P@
M)&%T=')I8G,I"B`@("!["B`@("`@("`@)&9U;F,@/2`G>&UL=&%G7R<@+B`D
M96QE;3L*("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D=&AI<RP@)&9U;F,I
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^=7-E7V-A;&Q?=7-E<E]F=6YC
M*2!["B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H
M:7,L("1F=6YC*2P@)'AP+"`D96QE;2P@)&%T=')I8G,I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@8V%L;%]U<V5R7VUE=&AO9"@D
M9G5N8RP@)'1H:7,L("1X<"P@)&5L96TL("1A='1R:6)S*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9G5N8T5N9$AA;F1L97(H*0H*("`@(&9U;F-T:6]N(&9U;F-%;F1(86YD;&5R
M*"1X<"P@)&5L96TI"B`@("!["B`@("`@("`@)&9U;F,@/2`G>&UL=&%G7R<@
M+B`D96QE;2`N("=?)SL*("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D=&AI
M<RP@)&9U;F,I*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^=7-E7V-A;&Q?
M=7-E<E]F=6YC*2!["B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8RAA
M<G)A>2@F)'1H:7,L("1F=6YC*2P@)'AP+"`D96QE;2D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!C86QL7W5S97)?;65T:&]D*"1F
M=6YC+"`D=&AI<RP@)'AP+"`D96QE;2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<W1A<G1(86YD;&5R
M*"D*"B`@("`O*BH*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@
M("`@9G5N8W1I;VX@<W1A<G1(86YD;&5R*"1X<"P@)&5L96TL("8D871T<FEB
M<RD*("`@('L*("`@("`@("!R971U<FX@3E5,3#L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!E;F1(86YD;&5R*"D*"B`@("`O*BH*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@96YD2&%N9&QE
M<B@D>'`L("1E;&5M*0H@("`@>PH@("`@("`@(')E='5R;B!.54Q,.PH@("`@
M?0H*"B`@("`O+R!]?7T*?0H*8VQA<W,@6$U,7U!A<G-E<E]%<G)O<B!E>'1E
M;F1S(%!%05)?17)R;W(*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("!V
M87(@)&5R<F]R7VUE<W-A9V5?<')E9FEX(#T@)UA-3%]087)S97(Z("<["@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(H*0H*("`@(&9U;F-T
M:6]N(%A-3%]087)S97)?17)R;W(H)&US9V]R<&%R<V5R(#T@)W5N:VYO=VX@
M97)R;W(G+"`D8V]D92`](#`L("1M;V1E(#T@4$5!4E]%4E)/4E]215154DXL
M("1L979E;"`]($5?55-%4E].3U1)0T4I"B`@("!["B`@("`@("`@:68@*&ES
M7W)E<V]U<F-E*"1M<V=O<G!A<G-E<BDI('L*("`@("`@("`@("`@)&-O9&4@
M/2!X;6Q?9V5T7V5R<F]R7V-O9&4H)&US9V]R<&%R<V5R*3L*("`@("`@("`@
M("`@)&US9V]R<&%R<V5R(#T@<W!R:6YT9B@B)7,@870@6$U,(&EN<'5T(&QI
M;F4@)60B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM
M;%]E<G)O<E]S=')I;F<H)&-O9&4I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D;7-G
M;W)P87)S97(I*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E!%05)?17)R
M;W(H)&US9V]R<&%R<V5R+"`D8V]D92P@)&UO9&4L("1L979E;"D["@H@("`@
M?0H*("`@("\O('U]?0I]"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+UA-3"]24$,N<&AP````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,3`Q-#(T`#$P-#$W,S8S,#`T`#`Q-S$S-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M+R!B>2!%9&0@1'5M8FEL;"`H0RD@,3DY.2TR,#`Q"B\O(#QE9&1`=7-E9G5L
M:6YC+F-O;3X*+R\@)$ED.B!24$,N<&AP+'8@,2XQ,2`R,#`R+S$P+S`R(#(Q
M.C$P.C$Y('-S8B!%>'`@)`H*+R\@3&EC96YS92!I<R!G<F%N=&5D('1O('5S
M92!O<B!M;V1I9GD@=&AI<R!S;V9T=V%R92`H(EA-3"U24$,@9F]R(%!(4"(I
M"B\O(&9O<B!C;VUM97)C:6%L(&]R(&YO;BUC;VUM97)C:6%L('5S92!P<F]V
M:61E9"!T:&4@8V]P>7)I9VAT(&]F('1H92!A=71H;W(*+R\@:7,@<')E<V5R
M=F5D(&EN(&%N>2!D:7-T<FEB=71E9"!O<B!D97)I=F%T:79E('=O<FLN"@HO
M+R!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!!551(3U(@8&!!
M4R!)4R<G($%.1"!!3ED@15A04D534T5$($]2"B\O($E-4$Q)140@5T%24D%.
M5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(12!)35!,
M245$(%=!4E)!3E1)15,*+R\@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X*
M+R\@24X@3D\@159%3E0@4TA!3$P@5$A%($%55$A/4B!"12!,24%"3$4@1D]2
M($%.62!$25)%0U0L($E.1$E214-4+`HO+R!)3D-)1$5.5$%,+"!34$5#24%,
M+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$
M24Y'+"!"550*+R\@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-5
M0E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+`HO+R!$
M051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/
M5T5615(@0T%54T5$($%.1"!/3B!!3ED*+R\@5$A%3U)9($]&($Q)04))3$E4
M62P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@
M5$]25`HO+R`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!
M4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8*+R\@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/
M1B!354-(($1!34%'12X*"B\O($%D87!T960@=&\@4$5!4B!S=&%N9&%R9',@
M8GD@4W1I9R!3YG1H97(@0F%K:V5N(#QS=&EG0'!H<"YN970^(&%N9`HO+R!-
M87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H*<F5Q=6ER95]O;F-E(")014%2
M+G!H<"(["@II9B`H(69U;F-T:6]N7V5X:7-T<R@G>&UL7W!A<G-E<E]C<F5A
M=&4G*2D@>PHO+R!7:6X@,S(@9FEX+B!&<F]M.B`B3&5O(%=E<W0B(#QL=V5S
M=$!I;6%G:6YE="YF<CX*("`@(&EF*"1724Y$25(I('L*("`@("`@("!D;"@B
M<&AP,U]X;6PN9&QL(BD["B`@("!](&5L<V4@>PH@("`@("`@(&1L*")X;6PN
M<V\B*3L*("`@('T*?0H*)$=,3T)!3%-;)UA-3%]24$-?230G73TB:30B.PHD
M1TQ/0D%,4ULG6$U,7U)00U]);G0G73TB:6YT(CL*)$=,3T)!3%-;)UA-3%]2
M4$-?0F]O;&5A;B==/2)B;V]L96%N(CL*)$=,3T)!3%-;)UA-3%]24$-?1&]U
M8FQE)UT](F1O=6)L92(["B1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R==/2)S
M=')I;F<B.PHD1TQ/0D%,4ULG6$U,7U)00U]$871E5&EM92==/2)D871E5&EM
M92YI<V\X-C`Q(CL*)$=,3T)!3%-;)UA-3%]24$-?0F%S938T)UT](F)A<V4V
M-"(["B1'3$]"04Q36R=834Q?4E!#7T%R<F%Y)UT](F%R<F%Y(CL*)$=,3T)!
M3%-;)UA-3%]24$-?4W1R=6-T)UT](G-T<G5C="(["@HD1TQ/0D%,4ULG6$U,
M7U)00U]4>7!E<R==/6%R<F%Y*"1'3$]"04Q36R=834Q?4E!#7TDT)UT@/3X@
M,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG
M6$U,7U)00U]);G0G72`]/B`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1'3$]"04Q36R=834Q?4E!#7T)O;VQE86XG72`]/B`Q+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=834Q?4E!#
M7U-T<FEN9R==(#T^(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)$=,3T)!3%-;)UA-3%]24$-?1&]U8FQE)UT@/3X@,2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG6$U,7U)00U]$871E
M5&EM92==(#T^(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)$=,3T)!3%-;)UA-3%]24$-?0F%S938T)UT@/3X@,2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG6$U,7U)00U]!<G)A>2==
M(#T^(#(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!
M3%-;)UA-3%]24$-?4W1R=6-T)UT@/3X@,RD["@HD1TQ/0D%,4ULG6$U,7U)0
M0U]E;G1I=&EE<R==/6%R<F%Y*")Q=6]T(B`]/B`G(B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(F%M<"(@/3X@(B8B+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(")L="(@/3X@(CPB+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")G="(@/3X@(CXB+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")A<&]S(B`]/B`B
M)R(I.PH*)$=,3T)!3%-;)UA-3%]24$-?97)R)UU;(G5N:VYO=VY?;65T:&]D
M(ET],3L*)$=,3T)!3%-;)UA-3%]24$-?<W1R)UU;(G5N:VYO=VY?;65T:&]D
M(ET](E5N:VYO=VX@;65T:&]D(CL*)$=,3T)!3%-;)UA-3%]24$-?97)R)UU;
M(FEN=F%L:61?<F5T=7)N(ET],CL*)$=,3T)!3%-;)UA-3%]24$-?<W1R)UU;
M(FEN=F%L:61?<F5T=7)N(ET](DEN=F%L:60@<F5T=7)N('!A>6QO860Z(&5N
M86)L:6YG(&1E8G5G9VEN9R!T;R!E>&%M:6YE(&EN8V]M:6YG('!A>6QO860B
M.PHD1TQ/0D%,4ULG6$U,7U)00U]E<G(G75LB:6YC;W)R96-T7W!A<F%M<R)=
M/3,["B1'3$]"04Q36R=834Q?4E!#7W-T<B==6R)I;F-O<G)E8W1?<&%R86US
M(ET](DEN8V]R<F5C="!P87)A;65T97)S('!A<W-E9"!T;R!M971H;V0B.PHD
M1TQ/0D%,4ULG6$U,7U)00U]E<G(G75LB:6YT<F]S<&5C=%]U;FMN;W=N(ET]
M-#L*)$=,3T)!3%-;)UA-3%]24$-?<W1R)UU;(FEN=')O<W!E8W1?=6YK;F]W
M;B)=/2)#86XG="!I;G1R;W-P96-T.B!M971H;V0@=6YK;F]W;B(["B1'3$]"
M04Q36R=834Q?4E!#7V5R<B==6R)H='1P7V5R<F]R(ET]-3L*)$=,3T)!3%-;
M)UA-3%]24$-?<W1R)UU;(FAT='!?97)R;W(B73TB1&ED;B=T(')E8V5I=F4@
M,C`P($]+(&9R;VT@<F5M;W1E('-E<G9E<BXB.PH*)$=,3T)!3%-;)UA-3%]2
M4$-?9&5F96YC;V1I;F<G73TB551&+3@B.PH*+R\@;&5T('5S97(@97)R;W)S
M('-T87)T(&%T(#@P,`HD1TQ/0D%,4ULG6$U,7U)00U]E<G)U<V5R)UT].#`P
M.PHO+R!L970@6$U,('!A<G-E(&5R<F]R<R!S=&%R="!A="`Q,#`*)$=,3T)!
M3%-;)UA-3%]24$-?97)R>&UL)UT],3`P.PH*+R\@9F]R;75L871E(&)A8VMS
M;&%S:&5S(&9O<B!E<V-A<&EN9R!R96=E>'`*)$=,3T)!3%-;)UA-3%]24$-?
M8F%C:W-L87-H)UT]8VAR*#DR*2YC:'(H.3(I.PH*)$=,3T)!3%-;)UA-3%]2
M4$-?='=O<VQA<V@G73TD1TQ/0D%,4ULG6$U,7U)00U]B86-K<VQA<V@G72`N
M("1'3$]"04Q36R=834Q?4E!#7V)A8VMS;&%S:"==.PHD1TQ/0D%,4ULG6$U,
M7U)00U]T=V]S;&%S:"==/2(R4TQ3(CL*+R\@=7-E9"!T;R!S=&]R92!S=&%T
M92!D=7)I;F<@<&%R<VEN9PHO+R!Q=6EC:R!E>'!L86YA=&EO;B!O9B!C;VUP
M;VYE;G1S.@HO+R`@('-T("T@=7-E9"!T;R!B=6EL9"!U<"!A('-T<FEN9R!F
M;W(@979A;'5A=&EO;@HO+R`@(&%C("T@=7-E9"!T;R!A8V-U;75L871E('9A
M;'5E<PHO+R`@('%T("T@=7-E9"!T;R!D96-I9&4@:68@<75O=&5S(&%R92!N
M965D960@9F]R(&5V86QU871I;VX*+R\@("!C;2`M('5S960@=&\@9&5N;W1E
M('-T<G5C="!O<B!A<G)A>2`H8V]M;6$@;F5E9&5D*0HO+R`@(&ES9B`M('5S
M960@=&\@:6YD:6-A=&4@82!F875L=`HO+R`@(&QV("T@=7-E9"!T;R!I;F1I
M8V%T92`B;&]O:VEN9R!F;W(@82!V86QU92(Z(&EM<&QE;65N=',*+R\@("`@
M("`@('1H92!L;V=I8R!T;R!A;&QO=R!V86QU97,@=VET:"!N;R!T>7!E<R!T
M;R!B92!S=')I;F=S"B\O("`@<&%R86US("T@=7-E9"!T;R!S=&]R92!P87)A
M;65T97)S(&EN(&UE=&AO9"!C86QL<PHO+R`@(&UE=&AO9"`M('5S960@=&\@
M<W1O<F4@;65T:&]D(&YA;64*"B1'3$]"04Q36R=834Q?4E!#7WAH)UT]87)R
M87DH*3L*"F9U;F-T:6]N(%A-3%]24$-?96YT:71Y7V1E8V]D92@D<W1R:6YG
M*0I["B`@("`D=&]P/7-P;&ET*"(F(BP@)'-T<FEN9RD["B`@("`D;W`](B([
M"B`@("`D:3TP.PH@("`@=VAI;&4H)&D\<VEZ96]F*"1T;W`I*2!["B`@("`@
M("`@:68@*&5R96<H(EXH6R-A+7I!+5HP+3E=*RD[(BP@)'1O<%LD:5TL("1R
M96=S*2D@>PH@("`@("`@("`@("`D;W`N/65R96=?<F5P;&%C92@B7ELC82UZ
M02U:,"TY72L[(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U)00U]L;V]K=7!?96YT:71Y*"1R96=S6S%=*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1O<%LD:5TI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D:3T],"D*("`@("`@("`@("`@("`@("1O<#TD=&]P
M6R1I73L*("`@("`@("`@("`@96QS90H@("`@("`@("`@("`@("`@)&]P+CTB
M)B(@+B`D=&]P6R1I73L*("`@("`@("!]"@H@("`@("`@("1I*RL["B`@("!]
M"B`@("!R971U<FX@)&]P.PI]"@H*9G5N8W1I;VX@6$U,7U)00U]L;V]K=7!?
M96YT:71Y*"1E;G0I"GL*("`@(&=L;V)A;"`D6$U,7U)00U]E;G1I=&EE<SL*
M"B`@("!I9B`H)%A-3%]24$-?96YT:71I97-;<W1R=&]L;W=E<B@D96YT*5TI
M"B`@("`@("`@<F5T=7)N("1834Q?4E!#7V5N=&ET:65S6W-T<G1O;&]W97(H
M)&5N="E=.PH*("`@(&EF("AE<F5G*")>(RA;,"TY72LI)"(L("1E;G0L("1R
M96=S*2D*("`@("`@("!R971U<FX@8VAR*"1R96=S6S%=*3L*"B`@("!R971U
M<FX@(C\B.PI]"@H*9G5N8W1I;VX@6$U,7U)00U]S92@D<&%R<V5R+"`D;F%M
M92P@)&%T=')S*0I["B`@("!G;&]B86P@)%A-3%]24$-?>&@L("1834Q?4E!#
M7T1A=&54:6UE+"`D6$U,7U)00U]3=')I;F<["@H@("`@<W=I=&-H*"1N86UE
M*2!["B`@("!C87-E(")35%)50U0B.@H@("`@8V%S92`B05)205DB.@H@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=S="==+CTB87)R87DH(CL*("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG8VTG72LK.PH@("`@("`@("\O
M('1H:7,@;&%S="!L:6YE('1U<FYS('%U;W1I;F<@;V9F"B`@("`@("`@+R\@
M=&AI<R!M96%N<R!I9B!W92!G970@86X@96UP='D@87)R87D@=V4G;&P*("`@
M("`@("`O+R!S:6UP;'D@9V5T(&$@8FET(&]F('=H:71E<W!A8V4@:6X@=&AE
M(&5V86P*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G73TP.PH@
M("`@("`@(&)R96%K.PH@("`@8V%S92`B3D%-12(Z"B`@("`@("`@)%A-3%]2
M4$-?>&A;)'!A<G-E<EU;)W-T)UTN/2(G(CL@)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)V%C)UT](B(["B`@("`@("`@8G)E86L["B`@("!C87-E(")&055,5"(Z
M"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9B==/3$["B`@("`@
M("`@8G)E86L["B`@("!C87-E(")005)!32(Z"B`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W-T)UT](B(["B`@("`@("`@8G)E86L["B`@("!C87-E
M(")604Q512(Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T)UTN
M/2)N97<@6$U,7U)00U]686QU92@B.PH@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=L=B==/3$["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)W9T)UT])%A-3%]24$-?4W1R:6YG.PH@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=A8R==/2(B.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=
M6R=Q="==/3`["B`@("`@("`@+R\@;&]O:R!F;W(@82!V86QU93H@:68@=&AI
M<R!I<R!S=&EL;"`Q(&)Y('1H90H@("`@("`@("\O('1I;64@=V4@<F5A8V@@
M=&AE(&9I<G-T(&1A=&$@<V5G;65N="!T:&5N('1H92!T>7!E(&ES('-T<FEN
M9PH@("`@("`@("\O(&)Y(&EM<&QI8V%T:6]N(&%N9"!W92!N965D('1O(&%D
M9"!I;B!A('%U;W1E"B`@("`@("`@8G)E86L["@H@("`@8V%S92`B230B.@H@
M("`@8V%S92`B24Y4(CH*("`@(&-A<V4@(E-44DE.1R(Z"B`@("!C87-E(")"
M3T],14%.(CH*("`@(&-A<V4@(D1/54),12(Z"B`@("!C87-E(")$051%5$E-
M12Y)4T\X-C`Q(CH*("`@(&-A<V4@(D)!4T4V-"(Z"B`@("`@("`@)%A-3%]2
M4$-?>&A;)'!A<G-E<EU;)V%C)UT](B([("\O(')E<V5T('1H92!A8V-U;75L
M871O<@H*("`@("`@("!I9B`H)&YA;64]/2)$051%5$E-12Y)4T\X-C`Q(B!\
M?"`D;F%M93T](E-44DE.1R(I('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W%T)UT],3L*"B`@("`@("`@("`@(&EF("@D;F%M93T](D1!
M5$5424U%+DE33S@V,#$B*0H@("`@("`@("`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W9T)UT])%A-3%]24$-?1&%T951I;64["@H@("`@("`@('T@
M96QS92!I9B`H)&YA;64]/2)"05-%-C0B*2!["B`@("`@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=Q="==/3(["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+R\@3F\@<75O=&EN9R!I<R!R97%U:7)E9"!H97)E("TM(&)U
M=`H@("`@("`@("`@("`O+R!A="!T:&4@96YD(&]F('1H92!E;&5M96YT('=E
M(&UU<W0@8VAE8VL*("`@("`@("`@("`@+R\@9F]R(&1A=&$@9F]R;6%T(&5R
M<F]R<RX*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT]
M,#L*("`@("`@("!]"B`@("`@("`@8G)E86L["@H@("`@8V%S92`B345-0D52
M(CH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G73TB(CL*("`@
M("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8G)E86L["B`@("!]
M"@H@("`@:68@*"1N86UE(3TB5D%,544B*2`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG;'8G73TP.PI]"@H*9G5N8W1I;VX@6$U,7U)00U]E92@D<&%R<V5R+"`D
M;F%M92D*>PH@("`@9VQO8F%L("1834Q?4E!#7WAH+"1834Q?4E!#7U1Y<&5S
M+"1834Q?4E!#7U-T<FEN9SL*"B`@("!S=VET8V@H)&YA;64I('L*("`@(&-A
M<V4@(E-44E5#5"(Z"B`@("!C87-E(")!4E)!62(Z"B`@("`@("`@:68@*"18
M34Q?4E!#7WAH6R1P87)S97)=6R=C;2==("8F('-U8G-T<B@D6$U,7U)00U]X
M:%LD<&%R<V5R75LG<W0G72P@+3$I(#T])RPG*2!["B`@("`@("`@("`@("18
M34Q?4E!#7WAH6R1P87)S97)=6R=S="==/7-U8G-T<B@D6$U,7U)00U]X:%LD
M<&%R<V5R75LG<W0G72PP+"TQ*3L*("`@("`@("!]"@H@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=S="==+CTB*2(["B`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W9T)UT]<W1R=&]L;W=E<B@D;F%M92D["B`@("`@("`@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)V-M)UTM+3L*("`@("`@("!B<F5A:SL*
M"B`@("!C87-E(").04U%(CH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG<W0G72X]("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==("X@(B<@/3X@
M(CL*("`@("`@("!B<F5A:SL*"B`@("!C87-E(")"3T],14%.(CH*("`@("`@
M("`O+R!S<&5C:6%L(&-A<V4@:&5R93H@=V4@=')A;G-L871E(&)O;VQE86X@
M,2!O<B`P(&EN=&\@4$A0"B`@("`@("`@+R\@8V]N<W1A;G1S('1R=64@;W(@
M9F%L<V4*("`@("`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT]
M/2<Q)RD*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT]
M(G1R=64B.PH@("`@("`@(&5L<V4*("`@("`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)V%C)UT](F9A;'-E(CL*"B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W9T)UT]<W1R=&]L;W=E<B@D;F%M92D["B`@("`@("`@+R\@
M1')O<"!T:')O=6=H(&EN=&5N=&EO;F%L;'DN"@H@("`@8V%S92`B230B.@H@
M("`@8V%S92`B24Y4(CH*("`@(&-A<V4@(E-44DE.1R(Z"B`@("!C87-E(")$
M3U5"3$4B.@H@("`@8V%S92`B1$%4151)344N25-/.#8P,2(Z"B`@("!C87-E
M(")"05-%-C0B.@H@("`@("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG
M<70G73T],2D@>PH@("`@("`@("`@("`O+R!W92!U<V4@9&]U8FQE('%U;W1E
M<R!R871H97(@=&AA;B!S:6YG;&4@<V\@8F%C:W-L87-H:69I8V%T:6]N('=O
M<FMS($]+"B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=S="==
M+CTB7"(B+B`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`N(")<(B(["B`@
M("`@("`@?2!E;'-E(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G73T]
M,BD@>PH@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<W0G72X]
M(F)A<V4V-%]D96-O9&4H)R(N("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==
M("X@(B<I(CL*("`@("`@("!](&5L<V4@:68@*"1N86UE/3TB0D]/3$5!3B(I
M('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T)UTN/218
M34Q?4E!#7WAH6R1P87)S97)=6R=A8R==.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\O('=E(&AA=F4@86X@230L($E.5"!O<B!A($1/54),10H@
M("`@("`@("`@("`O+R!W92!M=7-T(&-H96-K('1H870@;VYL>2`P,3(S-#4V
M-S@Y+2X\<W!A8V4^(&%R92!C:&%R86-T97)S(&AE<F4*("`@("`@("`@("`@
M:68@*"%E<F5G*")>7"T_6S`Q,C,T-38W.#D@7'1<+ETK)"(L("1834Q?4E!#
M7WAH6R1P87)S97)=6R=A8R==*2D@>PH@("`@("`@("`@("`@("`@+R\@5$]$
M3SH@9FEN9"!A(&)E='1E<B!W87D@;V8@=&AR;W=I;F<@86X@97)R;W(*("`@
M("`@("`@("`@("`@("\O('1H86X@=&AI<R$*("`@("`@("`@("`@("`@(&5R
M<F]R7VQO9R@B6$U,+5)00SH@;F]N(&YU;65R:6,@=F%L=64@<F5C96EV960@
M:6X@24Y4(&]R($1/54),12(I.PH@("`@("`@("`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W-T)UTN/2)%4E)/4E].3TY?3E5-15))0U]&3U5.1"([
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!I="=S
M(&]K+"!A9&0@:70@;VX*("`@("`@("`@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=S="==+CTD6$U,7U)00U]X:%LD<&%R<V5R75LG86,G73L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)%A-3%]24$-?>&A;)'!A
M<G-E<EU;)V%C)UT](B([("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==/3`[
M"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VQV)UT],SL@+R\@:6YD
M:6-A=&4@=V4G=F4@9F]U;F0@82!V86QU90H@("`@("`@(&)R96%K.PH*("`@
M(&-A<V4@(E9!3%5%(CH*("`@("`@("`O+R!D96%L('=I=&@@82!S=')I;F<@
M=F%L=64*("`@("`@("!I9B`H<W1R;&5N*"1834Q?4E!#7WAH6R1P87)S97)=
M6R=A8R==*3XP("8F"B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=
M6R=V="==/3TD6$U,7U)00U]3=')I;F<I('L*"B`@("`@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=S="==+CTB7"(B+B`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG86,G72`N(")<(B(["B`@("`@("`@?0H*("`@("`@("`O+R!4:&ES
M(&EF*"D@9&5T96-T<R!I9B!N;R!S8V%L87(@=V%S(&EN<VED92`\5D%,544^
M/"]604Q513X*("`@("`@("`O+R!A;F0@<&%D<R!A;B!E;7!T>2`B(BX*("`@
M("`@("!I9B@D6$U,7U)00U]X:%LD<&%R<V5R75LG<W0G75MS=')L96XH)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W-T)UTI+3%=(#T]("<H)RD@>PH@("`@("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<W0G72X]("<B(B<["B`@("`@
M("`@?0H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=S="==+CTB+"`G
M(B`N("1834Q?4E!#7WAH6R1P87)S97)=6R=V="==("X@(B<I(CL*("`@("`@
M("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)V-M)UTI("1834Q?4E!#7WAH
M6R1P87)S97)=6R=S="==+CTB+"(["B`@("`@("`@8G)E86L["@H@("`@8V%S
M92`B345-0D52(CH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G
M73TB(CL@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT],#L*("`@("`@("!B
M<F5A:SL*"B`@("!C87-E(")$051!(CH*("`@("`@("`D6$U,7U)00U]X:%LD
M<&%R<V5R75LG86,G73TB(CL@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT]
M,#L*("`@("`@("!B<F5A:SL*"B`@("!C87-E(")005)!32(Z"B`@("`@("`@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)W!A<F%M<R==6UT])%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W-T)UT["B`@("`@("`@8G)E86L["@H@("`@8V%S92`B3454
M2$]$3D%-12(Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VUE=&AO
M9"==/65R96=?<F5P;&%C92@B7EM<;EQR7'0@72LB+"`B(BP@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)V%C)UTI.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@
M(D)/3TQ%04XB.@H@("`@("`@("\O('-P96-I86P@8V%S92!H97)E.B!W92!T
M<F%N<VQA=&4@8F]O;&5A;B`Q(&]R(#`@:6YT;R!02%`*("`@("`@("`O+R!C
M;VYS=&%N=',@=')U92!O<B!F86QS90H@("`@("`@(&EF("@D6$U,7U)00U]X
M:%LD<&%R<V5R75LG86,G73T])S$G*0H@("`@("`@("`@("`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG86,G73TB=')U92(["B`@("`@("`@96QS90H@("`@("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G73TB9F%L<V4B.PH*("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=G0G73US=')T;VQO=V5R*"1N
M86UE*3L*("`@("`@("!B<F5A:SL*"B`@("!D969A=6QT.@H@("`@("`@(&)R
M96%K.PH@("`@?0H@("`@+R\@:68@:70G<R!A('9A;&ED('1Y<&4@;F%M92P@
M<V5T('1H92!T>7!E"B`@("!I9B`H:7-S970H)%A-3%]24$-?5'EP97-;<W1R
M=&]L;W=E<B@D;F%M92E=*2D@>PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S
M97)=6R=V="==/7-T<G1O;&]W97(H)&YA;64I.PH@("`@?0I]"@H*9G5N8W1I
M;VX@6$U,7U)00U]C9"@D<&%R<V5R+"`D9&%T82D*>PH@("`@9VQO8F%L("18
M34Q?4E!#7WAH+"`D6$U,7U)00U]B86-K<VQA<V@["@H@("`@+R]I9B`H97)E
M9R@B7EM<;EQR(%QT72LD(BP@)&1A=&$I*2!R971U<FX["B`@("`O+R!P<FEN
M="`B861D:6YG(%LD>V1A=&%]75QN(CL*"B`@("!I9B`H)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)VQV)UTA/3,I('L*("`@("`@("`O+R`B;&]O:V9O<G9A;'5E
M/3TS(B!M96%N<R!T:&%T('=E)W9E(&9O=6YD(&%N(&5N=&ER92!V86QU90H@
M("`@("`@("\O(&%N9"!S:&]U;&0@9&ES8V%R9"!A;GD@9G5R=&AE<B!C:&%R
M86-T97(@9&%T80H*("`@("`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)VQV)UT]/3$I('L*("`@("`@("`@("`@+R\@:68@=V4G=F4@9F]U;F0@=&5X
M="!A;F0@=V4G<F4@:G5S="!I;B!A(#QV86QU93X@=&AE;@H@("`@("`@("`@
M("`O+R!T=7)N('%U;W1I;F<@;VXL(&%S('1H:7,@=VEL;"!B92!A('-T<FEN
M9PH@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G73TQ.PH@
M("`@("`@("`@("`O+R!A;F0@<V%Y('=E)W9E(&9O=6YD(&$@=F%L=64*("`@
M("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VQV)UT],CL*("`@("`@
M("!]"@H@("`@("`@("\O(')E<&QA8V4@8VAA<F%C=&5R<R!T:&%T(&5V86P@
M=V]U;&0*("`@("`@("`O+R!D;R!S<&5C:6%L('1H:6YG<R!W:71H"B`@("`@
M("`@0"1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==+CUS=')?<F5P;&%C92@G
M)"<L("=<)"<L"B`@("`@("`@("`@('-T<E]R97!L86-E*"<B)RP@)UPB)RP@
M<W1R7W)E<&QA8V4H8VAR*#DR*2P*("`@("`@("`@("`@("`@("1834Q?4E!#
M7V)A8VMS;&%S:"P@)&1A=&$I*2D["B`@("!]"GT*"@IF=6YC=&EO;B!834Q?
M4E!#7V1H*"1P87)S97(L("1D871A*0I["B`@("!G;&]B86P@)%A-3%]24$-?
M>&@["B`@("!I9B`H<W5B<W1R*"1D871A+"`P+"`Q*2`]/2`B)B(@)B8@<W5B
M<W1R*"1D871A+"`M,2P@,2D@/3T@(CLB*2!["B`@("`@("`@:68@*"1834Q?
M4E!#7WAH6R1P87)S97)=6R=L=B==/3TQ*2!["B`@("`@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=Q="==/3$["B`@("`@("`@("`@("1834Q?4E!#
M7WAH6R1P87)S97)=6R=L=B==/3(["B`@("`@("`@?0H@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=A8R==+CUS=')?<F5P;&%C92@G)"<L("=<)"<L
M"B`@("`@("`@("`@('-T<E]R97!L86-E*"<B)RP@)UPB)RP@<W1R7W)E<&QA
M8V4H8VAR*#DR*2P*("`@("`@("`@("`@("`@("1834Q?4E!#7V)A8VMS;&%S
M:"P@)&1A=&$I*2D["B`@("!]"GT*"@IC;&%S<R!834Q?4E!#7T-L:65N=`I[
M"B`@("!V87(@)'!A=&@["B`@("!V87(@)'-E<G9E<CL*("`@('9A<B`D<&]R
M=#L*("`@('9A<B`D97)R;F\["B`@("!V87(@)&5R<G-T<FEN9SL*("`@('9A
M<B`D9&5B=6<],#L*("`@('9A<B`D=7-E<FYA;64](B(["B`@("!V87(@)'!A
M<W-W;W)D/2(B.PH*("`@(&9U;F-T:6]N(%A-3%]24$-?0VQI96YT*"1P871H
M+"`D<V5R=F5R+"`D<&]R="`](#@P+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!R;WAY(#T@)R<L("1P<F]X>5]P;W)T(#T@.#`X,"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P<F]X>5]U<V5R(#T@)R<L("1P<F]X
M>5]P87-S(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/G!O<G0])'!O<G0[
M"B`@("`@("`@)'1H:7,M/G-E<G9E<CTD<V5R=F5R.PH@("`@("`@("1T:&ES
M+3YP871H/21P871H.PH@("`@("`@("1T:&ES+3YP<F]X>2`]("1P<F]X>3L*
M("`@("`@("`D=&AI<RT^<')O>'E?<&]R="`]("1P<F]X>5]P;W)T.PH@("`@
M("`@("1T:&ES+3YP<F]X>5]U<V5R(#T@)'!R;WAY7W5S97(["B`@("`@("`@
M)'1H:7,M/G!R;WAY7W!A<W,@/2`D<')O>'E?<&%S<SL*("`@('T*"B`@("!F
M=6YC=&EO;B!S971$96)U9R@D:6XI"B`@("!["B`@("`@("`@:68@*"1I;BD@
M>PH@("`@("`@("`@("`D=&AI<RT^9&5B=6<],3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^9&5B=6<],#L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@<V5T0W)E9&5N=&EA;',H)'4L("1P*0H@("`@>PH@
M("`@("`@("1T:&ES+3YU<V5R;F%M93TD=3L*("`@("`@("`D=&AI<RT^<&%S
M<W=O<F0])'`["B`@("!]"@H@("`@9G5N8W1I;VX@<V5N9"@D;7-G+"`D=&EM
M96]U=#TP*0H@("`@>PH@("`@("`@("\O('=H97)E(&US9R!I<R!A;B!X;6QR
M<&-M<V<*("`@("`@("`D;7-G+3YD96)U9STD=&AI<RT^9&5B=6<["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YS96YD4&%Y;&]A9$A45%`Q,"@D;7-G+"`D=&AI
M<RT^<V5R=F5R+"`D=&AI<RT^<&]R="P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:6UE;W5T+"`D=&AI<RT^=7-E<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<&%S<W=O<F0I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E;F1087EL;V%D
M2%144#$P*"1M<V<L("1S97)V97(L("1P;W)T+"`D=&EM96]U=#TP+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)N86UE/2(B+"`D<&%S
M<W=O<F0](B(I"B`@("!["B`@("`@("`@+R\@268@=V4G<F4@=7-I;F<@82!P
M<F]X>2!O<&5N(&$@<V]C:V5T('1O('1H92!P<F]X>2!S97)V97(@:6YS=&5A
M9"!T;R!T:&4@>&UL+7)P8R!S97)V97(*("`@("`@("!I9B@D=&AI<RT^<')O
M>'DI>PH@("`@("`@("`@("!I9B@D=&EM96]U="`^(#`I('L*("`@("`@("`@
M("`@("`@("1F<#UF<V]C:V]P96XH)'1H:7,M/G!R;WAY+"`D=&AI<RT^<')O
M>'E?<&]R="P@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R<W1R+"`D=&EM96]U
M="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("`D9G`]9G-O8VMO<&5N*"1T:&ES+3YP<F]X>2P@)'1H:7,M/G!R
M;WAY7W!O<G0L("1T:&ES+3YE<G)N;RP@)'1H:7,M/F5R<G-T<BD["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M(&EF*"1T:6UE;W5T(#X@,"D@>PH@("`@("`@("`@("`@("`@)&9P/69S;V-K
M;W!E;B@D<V5R=F5R+"`D<&]R="P@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R
M<W1R+"`D=&EM96]U="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M92!["B`@("`@("`@("`@("`@("`D9G`]9G-O8VMO<&5N*"1S97)V97(L("1P
M;W)T+"`D=&AI<RT^97)R;F\L("1T:&ES+3YE<G)S='(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B@A)&9P("8F("1T:&ES+3YP<F]X
M>2D@>PH@("`@("`@("`@("!014%2.CIR86ES945R<F]R*")#;VYN96-T:6]N
M('1O('!R;WAY('-E<G9E<B`B+B1T:&ES+3YP<F]X>2XB.B(N)'1H:7,M/G!R
M;WAY7W!O<G0N(B!F86EL960B*3L*("`@("`@("!]"B`@("`@("`@96QS92!I
M9B@A)&9P*2!["B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H(D-O;FYE
M8W1I;VX@=&\@4E!#('-E<G9E<B`B+B1T:&ES+3YS97)V97(N(B!F86EL960B
M*3L*("`@("`@("!]"@H@("`@("`@("\O($]N;'D@8W)E871E('1H92!P87EL
M;V%D(&EF(&ET('=A<R!N;W0@8W)E871E9"!P<F5V:6]U<VQY"B`@("`@("`@
M:68H96UP='DH)&US9RT^<&%Y;&]A9"DI("1M<V<M/F-R96%T95!A>6QO860H
M*3L*"B`@("`@("`@+R\@=&AA;FMS('1O($=R86YT(%)A=7-C:&5R(#QG<F%N
M=#=`9FER<W1W;W)L9"YN970^"B`@("`@("`@+R\@9F]R('1H:7,*("`@("`@
M("`D8W)E9&5N=&EA;',](B(["B`@("`@("`@:68@*"1U<V5R;F%M92$](B(I
M('L*("`@("`@("`@("`@)&-R961E;G1I86QS/2)!=71H;W)I>F%T:6]N.B!"
M87-I8R`B("X*("`@("`@("`@("`@("`@(&)A<V4V-%]E;F-O9&4H)'5S97)N
M86UE("X@(CHB("X@)'!A<W-W;W)D*2`N(")<<EQN(CL*("`@("`@("!]"@H*
M("`@("`@("!I9B@D=&AI<RT^<')O>'DI('L*("`@("`@("`@("`@)&]P(#T@
M(E!/4U0@:'1T<#HO+R(@+B`D=&AI<RT^<V5R=F5R.PH*("`@("`@("`@("`@
M:68H)'1H:7,M/G!R;WAY7W!O<G0I('L*("`@("`@("`@("`@("`@("1O<"`N
M/2`B.B(@+B`D=&AI<RT^<&]R=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`D;W`@/2`B4$]35"`B.PH@("`@
M("`@('T*"B`@("`@("`@)&]P("X]("1T:&ES+3YP871H+B`B($A45%`O,2XP
M7')<;E5S97(M06=E;G0Z(%!(4"!834Q24$,@,2XP7')<;B(@+@H@("`@("`@
M("`@("`B2&]S=#H@(BX@)'1H:7,M/G-E<G9E<B`@+B`B7')<;B(["B`@("`@
M("`@:68@*"1T:&ES+3YP<F]X>2`F)B`D=&AI<RT^<')O>'E?=7-E<B`A/2`G
M)RD@>PH@("`@("`@("`@("`D;W`@+CT@)U!R;WAY+4%U=&AO<FEZ871I;VXZ
M($)A<VEC("<@+@H@("`@("`@("`@("`@("`@8F%S938T7V5N8V]D92@D=&AI
M<RT^<')O>'E?=7-E<B`N("<Z)R`N("1T:&ES+3YP<F]X>5]P87-S*2`N"B`@
M("`@("`@("`@("`@("`B7')<;B(["B`@("`@("`@?0H@("`@("`@("1O<"`N
M/2`D8W)E9&5N=&EA;',@+@H@("`@("`@("`@("`B0V]N=&5N="U4>7!E.B!T
M97AT+WAM;%QR7&Y#;VYT96YT+4QE;F=T:#H@(B`N"B`@("`@("`@("`@('-T
M<FQE;B@D;7-G+3YP87EL;V%D*2`N(")<<EQN7')<;B(@+@H@("`@("`@("`@
M("`D;7-G+3YP87EL;V%D.PH*("`@("`@("`O+R!P<FEN="@D;W`I.PH*("`@
M("`@("!I9B`H(69P=71S*"1F<"P@)&]P+"!S=')L96XH)&]P*2DI('L*("`@
M("`@("`@("`@)'1H:7,M/F5R<G-T<CTB5W)I=&4@97)R;W(B.PH@("`@("`@
M("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@("`@)')E<W`])&US9RT^
M<&%R<V5297-P;VYS949I;&4H)&9P*3L*("`@("`@("!F8VQO<V4H)&9P*3L*
M("`@("`@("!R971U<FX@)')E<W`["B`@("!]"GT*"@IC;&%S<R!834Q?4E!#
M7U)E<W!O;G-E"GL*("`@('9A<B`D>'8["B`@("!V87(@)&9N.PH@("`@=F%R
M("1F<SL*("`@('9A<B`D:&1R<SL*"B`@("!F=6YC=&EO;B!834Q?4E!#7U)E
M<W!O;G-E*"1V86PL("1F8V]D93TP+"`D9G-T<CTB(BD*("`@('L*("`@("`@
M("!I9B`H)&9C;V1E(3TP*2!["B`@("`@("`@("`@("1T:&ES+3YF;CTD9F-O
M9&4["B`@("`@("`@("`@("1T:&ES+3YF<SUH=&UL<W!E8VEA;&-H87)S*"1F
M<W1R*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^>'8]
M)'9A;#L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9F%U;'1#;V1E
M*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F9N*2D*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YF;CL*("`@("`@("!E;'-E"B`@("`@("`@
M("`@(')E='5R;B`P.PH@("`@?0H*("`@(&9U;F-T:6]N(&9A=6QT4W1R:6YG
M*"D@>R!R971U<FX@)'1H:7,M/F9S.R!]"B`@("!F=6YC=&EO;B!V86QU92@I
M('L@<F5T=7)N("1T:&ES+3YX=CL@?0H*("`@(&9U;F-T:6]N('-E<FEA;&EZ
M92@I('L*("`@("`@("`D<G,](CQM971H;V1297-P;VYS93Y<;B(["B`@("`@
M("`@:68@*"1T:&ES+3YF;BD@>PH@("`@("`@("`@("`D<G,N/2(\9F%U;'0^
M"B`@/'9A;'5E/@H@("`@/'-T<G5C=#X*("`@("`@/&UE;6)E<CX*("`@("`@
M("`\;F%M93YF875L=$-O9&4\+VYA;64^"B`@("`@("`@/'9A;'5E/CQI;G0^
M(B`N("1T:&ES+3YF;B`N("(\+VEN=#X\+W9A;'5E/@H@("`@("`\+VUE;6)E
M<CX*("`@("`@/&UE;6)E<CX*("`@("`@("`\;F%M93YF875L=%-T<FEN9SPO
M;F%M93X*("`@("`@("`\=F%L=64^/'-T<FEN9SXB("X@)'1H:7,M/F9S("X@
M(CPO<W1R:6YG/CPO=F%L=64^"B`@("`@(#PO;65M8F5R/@H@("`@/"]S=')U
M8W0^"B`@/"]V86QU93X*/"]F875L=#XB.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1R<RX](CQP87)A;7,^7&X\<&%R86T^7&XB("X@)'1H:7,M
M/GAV+3YS97)I86QI>F4H*2`N"B`@("`@("`@(CPO<&%R86T^7&X\+W!A<F%M
M<SXB.PH@("`@("`@('T*("`@("`@("`D<G,N/2)<;CPO;65T:&]D4F5S<&]N
M<V4^(CL*("`@("`@("!R971U<FX@)')S.PH@("`@?0I]"@H*8VQA<W,@6$U,
M7U)00U]-97-S86=E"GL*("`@('9A<B`D<&%Y;&]A9#L*("`@('9A<B`D;65T
M:&]D;F%M93L*("`@('9A<B`D<&%R86US(#T@87)R87DH*3L*("`@('9A<B`D
M9&5B=6<],#L*"B`@("!F=6YC=&EO;B!834Q?4E!#7TUE<W-A9V4H)&UE=&@L
M("1P87)S/3`I"B`@("!["B`@("`@("`@)'1H:7,M/FUE=&AO9&YA;64])&UE
M=&@["B`@("`@("`@:68@*&ES7V%R<F%Y*"1P87)S*2`F)B!S:7IE;V8H)'!A
M<G,I/C`I('L*("`@("`@("`@("`@9F]R*"1I/3`[("1I/'-I>F5O9B@D<&%R
M<RD[("1I*RLI"B`@("`@("`@("`@("`@("`D=&AI<RT^861D4&%R86TH)'!A
M<G-;)&E=*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@>&UL7VAE
M861E<B@I"B`@("!["B`@("!R971U<FX@(CP_>&UL('9E<G-I;VX]7"(Q+C!<
M(C\^7&X\;65T:&]D0V%L;#Y<;B(["B`@("!]"@H@("`@9G5N8W1I;VX@>&UL
M7V9O;W1E<B@I"B`@("!["B`@("!R971U<FX@(CPO;65T:&]D0V%L;#Y<;B([
M"B`@("!]"@H@("`@9G5N8W1I;VX@8W)E871E4&%Y;&]A9"@I"B`@("!["B`@
M("`@("`@)'1H:7,M/G!A>6QO860])'1H:7,M/GAM;%]H96%D97(H*3L*("`@
M("`@("`D=&AI<RT^<&%Y;&]A9"X](CQM971H;V1.86UE/B(@+B`D=&AI<RT^
M;65T:&]D;F%M92`N("(\+VUE=&AO9$YA;64^7&XB.PH@("`@("`@("\O("!I
M9B`H<VEZ96]F*"1T:&ES+3YP87)A;7,I*2!["B`@("`@("`@("`@("1T:&ES
M+3YP87EL;V%D+CTB/'!A<F%M<SY<;B(["B`@("`@("`@("`@(&9O<B@D:3TP
M.R`D:3QS:7IE;V8H)'1H:7,M/G!A<F%M<RD[("1I*RLI('L*("`@("`@("`@
M("`@("`@("1P/21T:&ES+3YP87)A;7-;)&E=.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G!A>6QO860N/2(\<&%R86T^7&XB("X@)'`M/G-E<FEA;&EZ92@I
M("X*("`@("`@("`@("`@("`@("`@("`B/"]P87)A;3Y<;B(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/G!A>6QO860N/2(\+W!A<F%M<SY<
M;B(["B`@("`@("`@+R\@?0H@("`@("`@("1T:&ES+3YP87EL;V%D+CTD=&AI
M<RT^>&UL7V9O;W1E<B@I.PH@("`@("`@("1T:&ES+3YP87EL;V%D/7-T<E]R
M97!L86-E*")<;B(L(")<<EQN(BP@)'1H:7,M/G!A>6QO860I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&UE=&AO9"@D;65T:#TB(BD*("`@('L*("`@("`@("!I
M9B`H)&UE=&@A/2(B*2!["B`@("`@("`@("`@("1T:&ES+3YM971H;V1N86UE
M/21M971H.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/FUE=&AO
M9&YA;64["B`@("!]"@H@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"D*("`@('L*
M("`@("`@("`D=&AI<RT^8W)E871E4&%Y;&]A9"@I.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<&%Y;&]A9#L*("`@('T*"B`@("!F=6YC=&EO;B!A9&1087)A
M;2@D<&%R*2![("1T:&ES+3YP87)A;7-;73TD<&%R.R!]"B`@("!F=6YC=&EO
M;B!G971087)A;2@D:2D@>R!R971U<FX@)'1H:7,M/G!A<F%M<ULD:5T[('T*
M("`@(&9U;F-T:6]N(&=E=$YU;5!A<F%M<R@I('L@<F5T=7)N('-I>F5O9B@D
M=&AI<RT^<&%R86US*3L@?0H*("`@(&9U;F-T:6]N('!A<G-E4F5S<&]N<V5&
M:6QE*"1F<"D*("`@('L*("`@("`@("`D:7!D/2(B.PH*("`@("`@("!W:&EL
M92@D9&%T83UF<F5A9"@D9G`L(#,R-S8X*2D@>PH@("`@("`@("`@("`D:7!D
M+CTD9&%T83L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YP87)S
M95)E<W!O;G-E*"1I<&0I.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E4F5S
M<&]N<V4H)&1A=&$](B(I"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?4E!#
M7WAH+"1834Q?4E!#7V5R<BPD6$U,7U)00U]S='(["B`@("`@("`@9VQO8F%L
M("1834Q?4E!#7V1E9F5N8V]D:6YG.PH*("`@("`@("`D<&%R<V5R(#T@>&UL
M7W!A<G-E<E]C<F5A=&4H)%A-3%]24$-?9&5F96YC;V1I;F<I.PH*("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R73UA<G)A>2@I.PH*("`@("`@("`D6$U,
M7U)00U]X:%LD<&%R<V5R75LG<W0G73TB(CL*("`@("`@("`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG8VTG73TP.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S
M97)=6R=I<V8G73TP.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A
M8R==/2(B.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==/2(B
M.PH*("`@("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'!A<G-E<BP@6$U,
M7T]05$E/3E]#05-%7T9/3$1)3D<L('1R=64I.PH@("`@("`@('AM;%]S971?
M96QE;65N=%]H86YD;&5R*"1P87)S97(L(")834Q?4E!#7W-E(BP@(EA-3%]2
M4$-?964B*3L*("`@("`@("!X;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L
M97(H)'!A<G-E<BP@(EA-3%]24$-?8V0B*3L*("`@("`@("!X;6Q?<V5T7V1E
M9F%U;'1?:&%N9&QE<B@D<&%R<V5R+"`B6$U,7U)00U]D:"(I.PH@("`@("`@
M("1X;6QR<&-?=F%L=64@/2!N97<@6$U,7U)00U]686QU93L*"B`@("`@("`@
M)&AD<F9N9#TP.PH@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@
M("`@("`@<')I;G0@(CQ04D4^+2TM1T]4+2TM7&XB.PH@("`@("`@("`@("!P
M<FEN="!I<W-E="@D7U-%4E9%4ELG4T525D527U!23U1/0T],)UTI(#\@:'1M
M;'-P96-I86QC:&%R<R@D9&%T82D@.B`D9&%T83L*("`@("`@("`@("`@<')I
M;G0@(EQN+2TM14Y$+2TM7&X\+U!213XB.PH@("`@("`@('T*("`@("`@("`O
M+R!S964@:68@=V4@9V]T(&%N($A45%`@,C`P($]++"!E;'-E(&)O;6(*("`@
M("`@("`O+R!B=70@;VYL>2!D;R!T:&ES(&EF('=E)W)E('5S:6YG('1H92!(
M5%10('!R;W1O8V]L+@H@("`@("`@(&EF("AE<F5G*")>2%144"(L)&1A=&$I
M("8F"B`@("`@("`@("`@("%E<F5G*")>2%144"];,"TY7"Y=*R`R,#`@(BP@
M)&1A=&$I*2!["B`@("`@("`@("`@("`@("`D97)R<W1R/2!S=6)S='(H)&1A
M=&$L(#`L('-T<G!O<R@D9&%T82P@(EQN(BDM,2D["B`@("`@("`@("`@("`@
M("!E<G)O<E]L;V<H(DA45%`@97)R;W(L(&=O="!R97-P;VYS93H@(B`N)&5R
M<G-T<BD["B`@("`@("`@("`@("`@("`D<CUN97<@6$U,7U)00U]297-P;VYS
M92@P+"`D6$U,7U)00U]E<G);(FAT='!?97)R;W(B72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T<ELB:'1T
M<%]E<G)O<B)=+B`B("@B("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E<G)S='(@+B`B*2(I.PH@("`@("`@("`@("`@("`@
M>&UL7W!A<G-E<E]F<F5E*"1P87)S97(I.PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R.PH@("`@("`@('T*("`@("`@("`O+R!G;W1T82!G970@<FED(&]F
M(&AE861E<G,@:&5R90H@("`@("`@("`@"B`@("`@("`@"B`@("`@("`@:68@
M*"@A)&AD<F9N9"D@)B8@*"1B<G!O<R`]('-T<G!O<R@D9&%T82PB7')<;EQR
M7&XB*2DI('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VAA
M)UT@/2!S=6)S='(H)&1A=&$L,"PD8G)P;W,I.PH@("`@("`@("`@("`D9&%T
M83T@<W5B<W1R*"1D871A+"1B<G!O<RLT*3L*("`@("`@("`@("`@)&AD<F9N
M9#TQ.PH@("`@("`@('T*"B`@("`@("`@:68@*"%X;6Q?<&%R<V4H)'!A<G-E
M<BP@)&1A=&$L('-I>F5O9B@D9&%T82DI*2!["B`@("`@("`@("`@("\O('1H
M86YK<R!T;R!0971E<B!+;V-K<R`\<&5T97(N:V]C:W-`8F%Y9V%T92YC;VT^
M"B`@("`@("`@("`@(&EF*"AX;6Q?9V5T7V-U<G)E;G1?;&EN95]N=6UB97(H
M)'!A<G-E<BDI(#T](#$I"B`@("`@("`@("`@("`@("`D97)R<W1R(#T@(EA-
M3"!E<G)O<B!A="!L:6YE(#$L(&-H96-K(%523"(["B`@("`@("`@("`@(&5L
M<V4*("`@("`@("`@("`@("`@("1E<G)S='(@/2!S<')I;G1F*")834P@97)R
M;W(Z("5S(&%T(&QI;F4@)60B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H
M)'!A<G-E<BDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1P87)S97(I*3L*("`@("`@
M("`@("`@97)R;W)?;&]G*"1E<G)S='(I.PH@("`@("`@("`@("`D<CUN97<@
M6$U,7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);(FEN=F%L:61?<F5T
M=7)N(ETL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("18
M34Q?4E!#7W-T<ELB:6YV86QI9%]R971U<FXB72D["B`@("`@("`@("`@('AM
M;%]P87)S97)?9G)E92@D<&%R<V5R*3L*("`@("`@("`@("`@<F5T=7)N("1R
M.PH@("`@("`@('T*("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'!A<G-E<BD[
M"B`@("`@("`@:68@*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("!P<FEN
M="`B/%!213XM+2U%5D%,24Y'+2TM6R(@+@H@("`@("`@("`@("!S=')L96XH
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T)UTI("X@(B!C:&%R<UTM+2U<;B(@
M+@H@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1834Q?4E!#7WAH6R1P
M87)S97)=6R=S="==*2`N("([7&XM+2U%3D0M+2T\+U!213XB.PH@("`@("`@
M('T*("`@("`@("!I9B`H<W1R;&5N*"1834Q?4E!#7WAH6R1P87)S97)=6R=S
M="==*3T],"D@>PH@("`@("`@("`@("`O+R!T:&5N('-O;65T:&EN9R!O9&0@
M:&%S(&AA<'!E;F5D"B`@("`@("`@("`@("\O(&%N9"!I="=S('1I;64@=&\@
M9V5N97)A=&4@82!C;&EE;G0@<VED92!E<G)O<@H@("`@("`@("`@("`O+R!I
M;F1I8V%T:6YG('-O;65T:&EN9R!O9&0@=V5N="!O;@H@("`@("`@("`@("`D
M<CUN97<@6$U,7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);(FEN=F%L
M:61?<F5T=7)N(ETL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1834Q?4E!#7W-T<ELB:6YV86QI9%]R971U<FXB72D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@979A;"@G)'8])R`N("1834Q?4E!#
M7WAH6R1P87)S97)=6R=S="==("X@)SL@)&%L;$]+/3$[)RD["B`@("`@("`@
M("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F)UTI('L*("`@("`@
M("`@("`@("`@("1F/21V+3YS=')U8W1M96TH(F9A=6QT0V]D92(I.PH@("`@
M("`@("`@("`@("`@)&9S/21V+3YS=')U8W1M96TH(F9A=6QT4W1R:6YG(BD[
M"B`@("`@("`@("`@("`@("`D<CUN97<@6$U,7U)00U]297-P;VYS92@D=BP@
M)&8M/G-C86QA<G9A;"@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F<RT^<V-A;&%R=F%L*"DI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'(];F5W(%A-3%]24$-?4F5S
M<&]N<V4H)'8I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1R
M+3YH9')S/7-P;&ET*")<<C]<;B(L("1834Q?4E!#7WAH6R1P87)S97)=6R=H
M82==6S%=*3L*("`@("`@("!R971U<FX@)'(["B`@("!]"@I]"@H*8VQA<W,@
M6$U,7U)00U]686QU90I["B`@("!V87(@)&UE/6%R<F%Y*"D["B`@("!V87(@
M)&UY='EP93TP.PH*("`@(&9U;F-T:6]N(%A-3%]24$-?5F%L=64H)'9A;#TM
M,2P@)'1Y<&4](B(I"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?4E!#7U1Y
M<&5S.PH@("`@("`@("1T:&ES+3YM93UA<G)A>2@I.PH@("`@("`@("1T:&ES
M+3YM>71Y<&4],#L*("`@("`@("!I9B`H)'9A;"$]+3$@?'P@)'1Y<&4A/2(B
M*2!["B`@("`@("`@("`@(&EF("@D='EP93T](B(I("1T>7!E/2)S=')I;F<B
M.PH@("`@("`@("`@("!I9B`H)%A-3%]24$-?5'EP97-;)'1Y<&5=/3TQ*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^861D4V-A;&%R*"1V86PL)'1Y<&4I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@:68@*"1834Q?4E!#
M7U1Y<&5S6R1T>7!E73T],BD*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1!
M<G)A>2@D=F%L*3L*("`@("`@("`@("`@96QS92!I9B`H)%A-3%]24$-?5'EP
M97-;)'1Y<&5=/3TS*0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9%-T<G5C
M="@D=F%L*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@861D4V-A
M;&%R*"1V86PL("1T>7!E/2)S=')I;F<B*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D6$U,7U)00U]4>7!E<RP@)%A-3%]24$-?0F]O;&5A;CL*"B`@("`@("`@
M:68@*"1T:&ES+3YM>71Y<&4]/3$I('L*("`@("`@("`@("`@96-H;R`B/$(^
M6$U,7U)00U]686QU93PO0CXZ('-C86QA<B!C86X@:&%V92!O;FQY(&]N92!V
M86QU93Q"4CXB.PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@
M("`@("`@)'1Y<&5O9CTD6$U,7U)00U]4>7!E<ULD='EP95T["B`@("`@("`@
M:68@*"1T>7!E;V8A/3$I('L*("`@("`@("`@("`@96-H;R`B/$(^6$U,7U)0
M0U]686QU93PO0CXZ(&YO="!A('-C86QA<B!T>7!E("@D>W1Y<&5O9GTI/$)2
M/B(["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1T>7!E/3TD6$U,7U)00U]";V]L96%N*2!["B`@("`@("`@("`@(&EF
M("AS=')C87-E8VUP*"1V86PL(G1R=64B*3T],"!\?`H@("`@("`@("`@("`@
M("`@)'9A;#T],2!\?`H@("`@("`@("`@("`@("`@*"1V86P]/71R=64@)B8*
M("`@("`@("`@("`@("`@("`@("!S=')C87-E8VUP*"1V86PL(F9A;'-E(BDI
M*2!["@H@("`@("`@("`@("`@("`@)'9A;#TQ.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'9A;#TP.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/FUY='EP93T],BD@>PH@("`@
M("`@("`@("`O+R!W92=R92!A9&1I;F<@=&\@86X@87)R87D@:&5R90H@("`@
M("`@("`@("`D87(])'1H:7,M/FUE6R)A<G)A>2)=.PH@("`@("`@("`@("`D
M87);73UN97<@6$U,7U)00U]686QU92@D=F%L+"`D='EP92D["B`@("`@("`@
M("`@("1T:&ES+3YM95LB87)R87DB73TD87(["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@82!S8V%L87(L('-O('-E="!T:&4@=F%L=64@86YD
M(')E;65M8F5R('=E)W)E('-C86QA<@H@("`@("`@("`@("`D=&AI<RT^;65;
M)'1Y<&5=/21V86P["B`@("`@("`@("`@("1T:&ES+3YM>71Y<&4])'1Y<&5O
M9CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N(#$["B`@("!]"@H@("`@9G5N
M8W1I;VX@861D07)R87DH)'9A;',I"B`@("!["B`@("`@("`@9VQO8F%L("18
M34Q?4E!#7U1Y<&5S.PH@("`@("`@(&EF("@D=&AI<RT^;7ET>7!E(3TP*2![
M"B`@("`@("`@("`@(&5C:&\@(CQ"/EA-3%]24$-?5F%L=64\+T(^.B!A;')E
M861Y(&EN:71I86QI>F5D(&%S(&$@6R(@+@H@("`@("`@("`@("`@("`@)'1H
M:7,M/FMI;F1/9B@I("X@(ET\0E(^(CL*("`@("`@("`@("`@<F5T=7)N(#`[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YM>71Y<&4])%A-3%]24$-?5'EP
M97-;(F%R<F%Y(ET["B`@("`@("`@)'1H:7,M/FUE6R)A<G)A>2)=/21V86QS
M.PH@("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@(&9U;F-T:6]N(&%D9%-T
M<G5C="@D=F%L<RD*("`@('L*("`@("`@("!G;&]B86P@)%A-3%]24$-?5'EP
M97,["B`@("`@("`@:68@*"1T:&ES+3YM>71Y<&4A/3`I('L*("`@("`@("`@
M("`@96-H;R`B/$(^6$U,7U)00U]686QU93PO0CXZ(&%L<F5A9'D@:6YI=&EA
M;&EZ960@87,@82!;(B`N"B`@("`@("`@("`@("1T:&ES+3YK:6YD3V8H*2`N
M(")=/$)2/B(["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^;7ET>7!E/21834Q?4E!#7U1Y<&5S6R)S=')U8W0B73L*
M("`@("`@("`D=&AI<RT^;65;(G-T<G5C=")=/21V86QS.PH@("`@("`@(')E
M='5R;B`Q.PH@("`@?0H*("`@(&9U;F-T:6]N(&1U;7`H)&%R*0H@("`@>PH@
M("`@("`@(')E<V5T*"1A<BD["B`@("`@("`@=VAI;&4@*"!L:7-T*"`D:V5Y
M+"`D=F%L("D@/2!E86-H*"`D87(@*2`I('L*("`@("`@("`@("`@96-H;R`B
M)&ME>2`]/B`D=F%L/&)R/B(["B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=A
M<G)A>2<I"B`@("`@("`@("`@("`@("!W:&EL92`H(&QI<W0H("1K97DR+"`D
M=F%L,B`I(#T@96%C:"@@)'9A;"`I("D@>PH@("`@("`@("`@("`@("`@("`@
M(&5C:&\@(BTM("1K97DR(#T^("1V86PR/&)R/B(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&MI;F1/9B@I"B`@
M("!["B`@("`@("`@<W=I=&-H*"1T:&ES+3YM>71Y<&4I('L*("`@("`@("`@
M("`@("`@(&-A<V4@,SH*("`@("`@("`@("`@("`@("`@("!R971U<FX@(G-T
M<G5C="(["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!C87-E(#(Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(")A<G)A
M>2(["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(#$Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(")S8V%L87(B
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("`@("!R971U<FX@(G5N9&5F(CL*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5R:6%L:7IE9&%T82@D
M='EP+"`D=F%L*0H@("`@>PH@("`@("`@("1R<STB(CL*("`@("`@("!G;&]B
M86P@)%A-3%]24$-?5'EP97,L("1834Q?4E!#7T)A<V4V-"P@)%A-3%]24$-?
M4W1R:6YG+"`D6$U,7U)00U]";V]L96%N.PH@("`@("`@('-W:71C:"@D6$U,
M7U)00U]4>7!E<ULD='EP72D@>PH@("`@("`@("`@("!C87-E(#,Z"B`@("`@
M("`@("`@("`@("`O+R!S=')U8W0*("`@("`@("`@("`@("`@("1R<RX](CQS
M=')U8W0^7&XB.PH@("`@("`@("`@("`@("`@<F5S970H)'9A;"D["B`@("`@
M("`@("`@("`@("!W:&EL92AL:7-T*"1K97DR+"`D=F%L,BD]96%C:"@D=F%L
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1R<RX](CQM96UB97(^/&YA;64^
M)'MK97DR?3PO;F%M93Y<;B(["B`@("`@("`@("`@("`@("`@("`@)')S+CTD
M=&AI<RT^<V5R:6%L:7IE=F%L*"1V86PR*3L*("`@("`@("`@("`@("`@("`@
M("`D<G,N/2(\+VUE;6)E<CY<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<G,N/2(\+W-T<G5C=#XB.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@("`@("\O
M(&%R<F%Y"B`@("`@("`@("`@("`@("`D<G,N/2(\87)R87D^7&X\9&%T83Y<
M;B(["B`@("`@("`@("`@("`@("!F;W(H)&D],#L@)&D\<VEZ96]F*"1V86PI
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)')S+CTD=&AI<RT^<V5R
M:6%L:7IE=F%L*"1V86Q;)&E=*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1R<RX](CPO9&%T83Y<;CPO87)R87D^(CL*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@
M("`@("!S=VET8V@@*"1T>7`I('L*("`@("`@("`@("`@("`@("`@("!C87-E
M("1834Q?4E!#7T)A<V4V-#H*("`@("`@("`@("`@("`@("`@("`@("`@)')S
M+CTB/"1[='EP?3XB("X@8F%S938T7V5N8V]D92@D=F%L*2`N("(\+R1[='EP
M?3XB.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!C87-E("1834Q?4E!#7T)O;VQE86XZ"B`@("`@("`@("`@
M("`@("`@("`@("`@("1R<RX](CPD>W1Y<'T^(B`N("@D=F%L(#\@(C$B(#H@
M(C`B*2`N("(\+R1[='EP?3XB.PH@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("1834Q?4E!#7U-T<FEN
M9SH*("`@("`@("`@("`@("`@("`@("`@("`@)')S+CTB/"1[='EP?3XB("X@
M:'1M;'-P96-I86QC:&%R<R@D=F%L*2X@(CPO)'MT>7!]/B(["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("1R<RX](CPD>W1Y<'T^
M)'MV86Q]/"\D>W1Y<'T^(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<G,["B`@
M("!]"@H@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/G-E<FEA;&EZ979A;"@D=&AI<RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5R:6%L:7IE=F%L*"1O*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D6$U,7U)00U]4>7!E<SL*("`@("`@("`D<G,](B(["B`@("`@("`@)&%R
M/21O+3YM93L*("`@("`@("!R97-E="@D87(I.PH@("`@("`@(&QI<W0H)'1Y
M<"P@)'9A;"D@/2!E86-H*"1A<BD["B`@("`@("`@)')S+CTB/'9A;'5E/B([
M"B`@("`@("`@)')S+CTD=&AI<RT^<V5R:6%L:7IE9&%T82@D='EP+"`D=F%L
M*3L*("`@("`@("`D<G,N/2(\+W9A;'5E/EQN(CL*("`@("`@("!R971U<FX@
M)')S.PH@("`@?0H*("`@(&9U;F-T:6]N('-T<G5C=&UE;2@D;2D*("`@('L*
M("`@("`@("`D;G8])'1H:7,M/FUE6R)S=')U8W0B75LD;5T["B`@("`@("`@
M<F5T=7)N("1N=CL*("`@('T*"B`@("!F=6YC=&EO;B!S=')U8W1R97-E="@I
M"B`@("!["B`@("`@("`@<F5S970H)'1H:7,M/FUE6R)S=')U8W0B72D["B`@
M("!]"@H@("`@9G5N8W1I;VX@<W1R=6-T96%C:"@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&5A8V@H)'1H:7,M/FUE6R)S=')U8W0B72D["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T=F%L*"D@>PH@("`@("`@("\O(%5.4U1!0DQ%"B`@("`@
M("`@9VQO8F%L("1834Q?4E!#7T)/3TQ%04XL("1834Q?4E!#7T)A<V4V-#L*
M"B`@("`@("`@<F5S970H)'1H:7,M/FUE*3L*("`@("`@("!L:7-T*"1A+"1B
M*3UE86-H*"1T:&ES+3YM92D["@H@("`@("`@("\O(&-O;G1R:6)U=&5D(&)Y
M($D@4V]F97(L(#(P,#$M,#,M,C0*("`@("`@("`O+R!A9&0@<W5P<&]R="!F
M;W(@;F5S=&5D(&%R<F%Y<R!T;R!S8V%L87)V86P*("`@("`@("`O+R!I)W9E
M(&-R96%T960@82!N97<@;65T:&]D(&AE<F4L('-O(&%S('1O"B`@("`@("`@
M+R\@<')E<V5R=F4@8F%C:R!C;VUP871I8FEL:71Y"@H@("`@("`@(&EF("AI
M<U]A<G)A>2@D8BDI("`@('L*("`@("`@("`@("`@9F]R96%C:"`H)&(@87,@
M)&ED(#T^("1C;VYT*2!["B`@("`@("`@("`@("`@("`D8ELD:61=(#T@)&-O
M;G0M/G-C86QA<G9A;"@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!A9&0@<W5P<&]R="!F;W(@<W1R=6-T=7)E<R!D:7)E8W1L>2!E
M;F-O9&EN9R!P:'`@;V)J96-T<PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&(I
M*2`@>PH@("`@("`@("`@("`D="`](&=E=%]O8FIE8W1?=F%R<R@D8BD["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1T(&%S("1I9"`]/B`D8V]N="D@>PH@("`@
M("`@("`@("`@("`@)'1;)&ED72`]("1C;VYT+3YS8V%L87)V86PH*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D="!A<R`D:60@/3X@
M)&-O;G0I('L*("`@("`@("`@("`@("`@(&5V86PH)R1B+3XG+B1I9"XG(#T@
M)&-O;G0[)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M(&5N9"!C;VYT<FEB"B`@("`@("`@<F5T=7)N("1B.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-C86QA<G9A;"@I"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?
M4E!#7T)O;VQE86XL("1834Q?4E!#7T)A<V4V-#L*("`@("`@("!R97-E="@D
M=&AI<RT^;64I.PH@("`@("`@(&QI<W0H)&$L)&(I/65A8V@H)'1H:7,M/FUE
M*3L*("`@("`@("!R971U<FX@)&(["B`@("!]"@H@("`@9G5N8W1I;VX@<V-A
M;&%R='EP*"D*("`@('L*("`@("`@("!G;&]B86P@)%A-3%]24$-?230L("18
M34Q?4E!#7TEN=#L*("`@("`@("!R97-E="@D=&AI<RT^;64I.PH@("`@("`@
M(&QI<W0H)&$L)&(I/65A8V@H)'1H:7,M/FUE*3L*("`@("`@("!I9B`H)&$]
M/21834Q?4E!#7TDT*0H@("`@("`@("`@("`D83TD6$U,7U)00U]);G0["B`@
M("`@("`@<F5T=7)N("1A.PH@("`@?0H*("`@(&9U;F-T:6]N(&%R<F%Y;65M
M*"1M*0H@("`@>PH@("`@("`@("1N=CTD=&AI<RT^;65;(F%R<F%Y(EU;)&U=
M.PH@("`@("`@(')E='5R;B`D;G8["B`@("!]"@H@("`@9G5N8W1I;VX@87)R
M87ES:7IE*"D*("`@('L*("`@("`@("!R97-E="@D=&AI<RT^;64I.PH@("`@
M("`@(&QI<W0H)&$L)&(I/65A8V@H)'1H:7,M/FUE*3L*("`@("`@("!R971U
M<FX@<VEZ96]F*"1B*3L*("`@('T*?0H*"B\J*@H@*B!D871E(&AE;'!E<G,*
M("HO"F9U;F-T:6]N(%A-3%]24$-?:7-O.#8P,5]E;F-O9&4H)'1I;65T+"`D
M=71C/3`I('L*("`@("\O(')E='5R;B!A;B!)4T\X-C`Q(&5N8V]D960@<W1R
M:6YG"B`@("`O+R!R96%L;'DL('1I;65Z;VYE<R!O=6=H="!T;R!B92!S=7!P
M;W)T960*("`@("\O(&)U="!T:&4@6$U,+5)00R!S<&5C('-A>7,Z"B`@("`O
M+PH@("`@+R\@(D1O;B=T(&%S<W5M92!A('1I;65Z;VYE+B!)="!S:&]U;&0@
M8F4@<W!E8VEF:65D(&)Y('1H92!S97)V97(@:6X@:71S"B`@("`O+R!D;V-U
M;65N=&%T:6]N('=H870@87-S=6UP=&EO;G,@:70@;6%K97,@86)O=70@=&EM
M97IO;F5S+B(*("`@("\O"B`@("`O+R!T:&5S92!R;W5T:6YE<R!A;'=A>7,@
M87-S=6UE(&QO8V%L=&EM92!U;FQE<W,*("`@("\O("1U=&,@:7,@<V5T('1O
M(#$L(&EN('=H:6-H(&-A<V4@551#(&ES(&%S<W5M960*("`@("\O(&%N9"!A
M;B!A9&IU<W1M96YT(&9O<B!L;V-A;&4@:7,@;6%D92!W:&5N(&5N8V]D:6YG
M"B`@("!I9B`H(21U=&,I('L*("`@("`@("`D=#US=')F=&EM92@B)5DE;25D
M5"5(.B5-.B53(BP@)'1I;65T*3L*("`@('T@96QS92!["B`@("`@("`@:68@
M*&9U;F-T:6]N7V5X:7-T<R@B9VUS=')F=&EM92(I*0H@("`@("`@("`@("`O
M+R!G;7-T<F9T:6UE(&1O97-N)W0@97AI<W0@:6X@<V]M92!V97)S:6]N<PH@
M("`@("`@("`@("`O+R!O9B!02%`*("`@("`@("`@("`@)'0]9VUS=')F=&EM
M92@B)5DE;25D5"5(.B5-.B53(BP@)'1I;65T*3L*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)'0]<W1R9G1I;64H(B59)6TE9%0E2#HE33HE4R(L("1T
M:6UE="UD871E*"):(BDI.PH@("`@("`@('T*("`@('T*"B`@("!R971U<FX@
M)'0["GT*"F9U;F-T:6]N(%A-3%]24$-?:7-O.#8P,5]D96-O9&4H)&ED871E
M+"`D=71C/3`I('L*("`@("\O(')E='5R;B!A('1I;65T(&EN('1H92!L;V-A
M;'1I;64L(&]R(%540PH@("`@)'0],#L*("`@(&EF("AE<F5G*"(H6S`M.5U[
M-'TI*%LP+3E=>S)]*2A;,"TY77LR?2E4*%LP+3E=>S)]*3HH6S`M.5U[,GTI
M.BA;,"TY77LR?2DB+"1I9&%T92P@)')E9W,I*2!["@H@("`@("`@(&EF("@D
M=71C*2!["B`@("`@("`@("`@("1T/6=M;6MT:6UE*"1R96=S6S1=+"`D<F5G
M<ULU72P@)')E9W-;-ETL("1R96=S6S)=+"`D<F5G<ULS72P@)')E9W-;,5TI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T/6UK=&EM92@D<F5G
M<ULT72P@)')E9W-;-5TL("1R96=S6S9=+"`D<F5G<ULR72P@)')E9W-;,UTL
M("1R96=S6S%=*3L*("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N("1T.PI]
M"@HO*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ"BH@6$U,7U)00U]D96-O9&4@=&%K
M97,@82!M97-S86=E(&EN(%!(4"!834Q?4E!#(&]B:F5C="!F;W)M870@86YD
M("H**B!T<F%N;&%T97,@:70@:6YT;R!N871I=F4@4$A0('1Y<&5S+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*@HJ("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`J"BH@875T:&]R.B!$86X@3&EB8GD@*&1A;D!L:6)B>2YC;VTI("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("H**BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ+PIF=6YC=&EO;B!834Q?4E!#7V1E8V]D92@D6$U,7U)00U]V86PI('L*
M("`@("1K:6YD(#T@)%A-3%]24$-?=F%L+3YK:6YD3V8H*3L*"B`@(&EF*"1K
M:6YD(#T](")S8V%L87(B*2!["B`@("`@(')E='5R;B`D6$U,7U)00U]V86PM
M/G-C86QA<G9A;"@I.PH@("!]"B`@(&5L<V4@:68H)&MI;F0@/3T@(F%R<F%Y
M(BD@>PH@("`@("`D<VEZ92`]("1834Q?4E!#7W9A;"T^87)R87ES:7IE*"D[
M"B`@("`@("1A<G(@/2!A<G)A>2@I.PH*("`@("`@9F]R*"1I(#T@,#L@)&D@
M/"`D<VEZ93L@)&DK*RD@>PH@("`@("`@("`D87)R6UT]6$U,7U)00U]D96-O
M9&4H)%A-3%]24$-?=F%L+3YA<G)A>6UE;2@D:2DI.PH@("`@("!]"B`@("`@
M(')E='5R;B`D87)R.PH@("!]"B`@(&5L<V4@:68H)&MI;F0@/3T@(G-T<G5C
M="(I('L*("`@("`@)%A-3%]24$-?=F%L+3YS=')U8W1R97-E="@I.PH@("`@
M("`D87)R(#T@87)R87DH*3L*"B`@("`@('=H:6QE*&QI<W0H)&ME>2PD=F%L
M=64I/21834Q?4E!#7W9A;"T^<W1R=6-T96%C:"@I*2!["B`@("`@("`@("1A
M<G);)&ME>5T@/2!834Q?4E!#7V1E8V]D92@D=F%L=64I.PH@("`@("!]"B`@
M("`@(')E='5R;B`D87)R.PH@("!]"GT*"B\J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*@HJ(%A-3%]24$-?96YC;V1E('1A:V5S(&YA=&EV92!P:'`@='EP97,@86YD
M(&5N8V]D97,@=&AE;2!I;G1O("`@("H**B!834Q?4E!#(%!(4"!O8FIE8W0@
M9F]R;6%T+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`J
M"BH@0E5'.B!!;&P@<V5Q=65N=&EA;"!A<G)A>7,@87)E('1U<FYE9"!I;G1O
M('-T<G5C=',N("!)(&1O;B=T("`@*@HJ(&MN;W<@;V8@82!G;V]D('=A>2!T
M;R!D971E<FUI;F4@:68@86X@87)R87D@:7,@<V5Q=65N=&EA;"`@("`@("H*
M*B!O;FQY+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`J"BH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*@HJ
M(&9E871U<F4@8W)E97`@+2T@8V]U;&0@<W5P<&]R="!M;W)E('1Y<&5S('9I
M82!O<'1I;VYA;"!T>7!E("`@("H**B!A<F=U;65N="X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`J"BH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*@HJ(&%U=&AO<CH@1&%N($QI8F)Y("AD86Y`
M;&EB8GDN8V]M*2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("H**BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHO"F9U;F-T:6]N(%A-3%]24$-?96YC;V1E*"1P
M:'!?=F%L*2!["B`@(&=L;V)A;"`D6$U,7U)00U]";V]L96%N.PH@("!G;&]B
M86P@)%A-3%]24$-?26YT.PH@("!G;&]B86P@)%A-3%]24$-?1&]U8FQE.PH@
M("!G;&]B86P@)%A-3%]24$-?4W1R:6YG.PH@("!G;&]B86P@)%A-3%]24$-?
M07)R87D["B`@(&=L;V)A;"`D6$U,7U)00U]3=')U8W0["@H@("`D='EP92`]
M(&=E='1Y<&4H)'!H<%]V86PI.PH@("`D6$U,7U)00U]V86P@/2!N97<@6$U,
M7U)00U]V86QU93L*"B`@('-W:71C:"@D='EP92D@>PH@("`@("!C87-E(")A
M<G)A>2(Z"B`@("`@(&-A<V4@(F]B:F5C="(Z"B`@("`@("`@("1A<G(@/2!A
M<G)A>2@I.PH@("`@("`@("!W:&EL92`H;&ES="@D:RPD=BD@/2!E86-H*"1P
M:'!?=F%L*2D@>PH@("`@("`@("`@("`D87)R6R1K72`](%A-3%]24$-?96YC
M;V1E*"1V*3L*("`@("`@("`@?0H@("`@("`@("`D6$U,7U)00U]V86PM/F%D
M9%-T<G5C="@D87)R*3L*("`@("`@("`@8G)E86L["B`@("`@(&-A<V4@(FEN
M=&5G97(B.@H@("`@("`@("`D6$U,7U)00U]V86PM/F%D9%-C86QA<B@D<&AP
M7W9A;"P@)%A-3%]24$-?26YT*3L*("`@("`@("`@8G)E86L["B`@("`@(&-A
M<V4@(F1O=6)L92(Z"B`@("`@("`@("1834Q?4E!#7W9A;"T^861D4V-A;&%R
M*"1P:'!?=F%L+"`D6$U,7U)00U]$;W5B;&4I.PH@("`@("`@("!B<F5A:SL*
M("`@("`@8V%S92`B<W1R:6YG(CH*("`@("`@8V%S92`B3E5,3"(Z"B`@("`@
M("`@("1834Q?4E!#7W9A;"T^861D4V-A;&%R*"1P:'!?=F%L+"`D6$U,7U)0
M0U]3=')I;F<I.PH@("`@("`@("!B<F5A:SL*+R\@/$=?1VEU;G1A7S(P,#$M
M,#(M,CD^"B\O($%D9"!S=7!P;W)T(&9O<B!E;F-O9&EN9R]D96-O9&EN9R!O
M9B!B;V]L96%N<RP@<VEN8V4@=&AE>2!A<F4@<W5P<&]R=&5D(&EN(%!(4`H@
M("`@("!C87-E(")B;V]L96%N(CH*("`@("`@("`@)%A-3%]24$-?=F%L+3YA
M9&138V%L87(H)'!H<%]V86PL("1834Q?4E!#7T)O;VQE86XI.PH@("`@("`@
M("!B<F5A:SL*+R\@/"]'7T=I=6YT85\R,#`Q+3`R+3(Y/@H@("`@("!C87-E
M(")U;FMN;W=N('1Y<&4B.@H@("`@("!D969A=6QT.@H@("`@("`@("`D6$U,
M7U)00U]V86P@/2!F86QS93L*("`@("`@("`@8G)E86L["B`@('T*("`@<F5T
M=7)N("1834Q?4E!#7W9A;#L*?0H*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U5N<V5R:6%L:7IE<BYP:'``````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#`R-3``,3`T,3<S-C,P
M,#0`,#(Q,38T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_4$A0#0HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT
M('-H:69T=VED=&@]-#H@*B\-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PT*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#(@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\#0HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@
M("`@("`@("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!3
M=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O#0HO+R`@("`D260Z(%5N<V5R:6%L:7IE<BYP:'`L=B`Q+C$R(#(P
M,#,O,3`O,C8@,3DZ,S@Z,C$@<V-H<W0@17AP("0-"@T*+RHJ#0H@*B!U<V5S
M(%!%05(@97)R;W(@;6%N86=E;70-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2
M+G!H<"<[#0H-"B\J*@T*("H@=7-E<R!834Q?4&%R<V5R('1O('5N<V5R:6%L
M:7IE(&1O8W5M96YT#0H@*B\-"G)E<75I<F5?;VYC92`G6$U,+U!A<G-E<BYP
M:'`G.PT*#0HO*BH-"B`J(&5R<F]R(&-O9&4@9F]R(&YO('-E<FEA;&EZ871I
M;VX@9&]N90T*("HO#0ID969I;F4H(EA-3%]53E-%4DE!3$E:15)?15)23U)?
M3D]?54Y315))04Q)6D%424].(BP@,34Q*3L-"@T*+RHJ#0H@*B!834Q?56YS
M97)I86QI>F5R#0H@*@T*("H@8VQA<W,@=&\@=6YS97)I86QI>F4@6$U,(&1O
M8W5M96YT<R!T:&%T(&AA=F4@8F5E;B!C<F5A=&5D('=I=&@-"B`J(%A-3%]3
M97)I86QI>F5R+B!4;R!U;G-E<FEA;&EZ92!A;B!834P@9&]C=6UE;G0@>6]U
M(&AA=F4@=&\@861D#0H@*B!T>7!E(&AI;G1S('1O('1H92!834Q?4V5R:6%L
M:7IE<B!O<'1I;VYS+@T*("H-"B`J($EF(&YO('1Y<&4@:&EN=',@87)E(&%V
M86EL86)L92P@6$U,7U5N<V5R:6%L:7IE<B!W:6QL(&=U97-S(&AO=PT*("H@
M=&AE('1A9W,@<VAO=6QD(&)E('1R96%T960L('1H870@;65A;G,@8V]M<&QE
M>"!S=')U8W1U<F5S('=I;&P@8F4-"B`J(&%R<F%Y<R!A;F0@=&%G<R!W:71H
M(&]N;'D@0T1A=&$@:6X@=&AE;2!W:6QL(&)E('-T<FEN9W,N#0H@*@T*("H@
M/&-O9&4^#0H@*B!R97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP
M)SL-"B`J#0H@*B`O+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@=7-E('1H92!A
M;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O<B`-"B`J("1U
M;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H*3L-"B`J#0H@
M*B`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L@("`@#0H@*@T*
M("H@)&1A=&$@/2`D=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A
M*"D[#0H@*B`\8V]D93X-"B`J#0H@*B!0;W-S:6)L92!O<'1I;VYS(&9O<B!T
M:&4@56YS97)I86QI>F5R(&%R93H-"B`J#0H@*B`Q+B!C;VUP;&5X5'EP97,@
M/3X@87)R87E\;V)J96-T#0H@*B!4:&ES(&ES(&YE961E9"P@=VAE;B!U;G-E
M<FEA;&EZ:6YG(%A-3"!F:6QE<R!W+V\@='EP92!H:6YT<RX@268@<V5T('1O
M#0H@*B`G87)R87DG("AD969A=6QT*2P@86QL(&YE<W1E9"!T86=S('=I;&P@
M8F4@87)R87ES+"!I9B!S970@=&\@)V]B:F5C="<-"B`J(&%L;"!N97-T960@
M=&%G<R!W:6QL(&)E(&]B:F5C=',L('1H870@;65A;G,@>6]U(&AA=F4@<F5A
M9"!A8V-E<W,@;&EK93H-"B`J#0H@*B`\8V]D93X-"B`J(')E<75I<F5?;VYC
M92`G6$U,+U5N<V5R:6%L:7IE<BYP:'`G.PT*("H@)&]P=&EO;G,@/2!A<G)A
M>2@G8V]M<&QE>%1Y<&4G(#T^("=O8FIE8W0G*3L-"B`J("1U;G-E<FEA;&EZ
M97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H)&]P=&EO;G,I.PT*("H-"B`J
M("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"=H='1P.B\O<&5A<BYP:'`N
M;F5T+W)S<RYP:'`G*3L@("`@#0H@*@T*("H@)')S<R`]("1U;G-E<FEA;&EZ
M97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L-"B`J(&5C:&\@)')S<RT^8VAA
M;FYE;"T^:71E;5LS72T^=&ET;&4[#0H@*B`\+V-O9&4^#0H@*@T*("H@,BX@
M:V5Y071T<FEB=71E#0H@*B!4:&ES(&QE=',@>6]U('-P96-I9GD@86X@871T
M<FEB=71E(&EN<VED92!Y;W5R('1A9W,L('1H870@87)E('5S960@87,@:V5Y
M#0H@*B!F;W(@87-S;V-I871I=F4@87)R87ES(&]R(&]B:F5C="!P<F]P97)T
M:65S+@T*("H@66]U('=I;&P@;F5E9"!T:&ES(&EF('EO=2!H879E(%A-3"!T
M:&%T(&QO;VMS(&QI:V4@=&AI<SH-"B`J#0H@*B`\=7-E<G,^#0H@*B`@(#QU
M<V5R(&AA;F1L93TB<V-H<W0B/E-T97!H86X@4V-H;6ED=#PO=7-E<CX-"B`J
M("`@/'5S97(@:&%N9&QE/2)S<V(B/E-T:6<@4RX@0F%K:V5N/"]U<V5R/@T*
M("H@/"]U<V5R<SX-"B`J#0H@*B!4:&5N('EO=2!C86X@=7-E.@T*("H@/&-O
M9&4^#0H@*B!R97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP)SL-
M"B`J("1O<'1I;VYS(#T@87)R87DH)VME>4%T=')I8G5T92<@/3X@)VAA;F1L
M92<I.PT*("H@)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE
M<B@D;W!T:6]N<RD[#0H@*@T*("H@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI
M>F4H)'AM;"P@9F%L<V4I.R`@("`-"B`J#0H@*B`D=7-E<G,@/2`D=6YS97)I
M86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D[#0H@*B`\+V-O9&4^#0H@
M*@T*("H@0&-A=&5G;W)Y(%A-3`T*("H@0'!A8VMA9V4@(%A-3%]397)I86QI
M>F5R#0H@*B!`=F5R<VEO;B`@,"XY+C$-"B`J($!A=71H;W(@("!3=&5P:&%N
M(%-C:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^#0H@*B!`=7-E<R`@("`@
M6$U,7U!A<G-E<@T*("HO#0IC;&%S<R!834Q?56YS97)I86QI>F5R(&5X=&5N
M9',@6$U,7U!A<G-E<B![#0H-"B`@("\J*@T*("`@("H@9&5F875L="!O<'1I
M;VYS(&9O<B!T:&4@<V5R:6%L:7IA=&EO;@T*("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@*B!`=F%R(&%R<F%Y("1?9&5F875L=$]P=&EO;G,-"B`@("`J
M+PT*("`@('9A<B`D7V1E9F%U;'1/<'1I;VYS(#T@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@(F-O;7!L97A4>7!E(B`@("`@("`]/B`B87)R
M87DB+"`@("`@("`@("`@("`@("`O+R!C;VUP;&5X('1Y<&5S('=I;&P@8F4@
M8V]N=F5R=&5D('1O(&%R<F%Y<RP@:68@;F\@='EP92!H:6YT(&ES(&=I=F5N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@(FME>4%T=')I8G5T92(@("`@
M("`]/B`B7V]R:6=I;F%L2V5Y(BP@("`@("`@("`O+R!G970@87)R87D@:V5Y
M+W!R;W!E<G1Y(&YA;64@9G)O;2!T:&ES(&%T=')I8G5T90T*("`@("`@("`@
M("`@("`@("`@("`@("`@(")T>7!E071T<FEB=71E(B`@("`@/3X@(E]T>7!E
M(BP@("`@("`@("`@("`@("`@+R\@9V5T('1Y<&4@9G)O;2!T:&ES(&%T=')I
M8G5T90T*("`@("`@("`@("`@("`@("`@("`@("`@(")C;&%S<T%T=')I8G5T
M92(@("`@/3X@(E]C;&%S<R(L("`@("`@("`@("`@("`@+R\@9V5T(&-L87-S
M(&9R;VT@=&AI<R!A='1R:6)U=&4@*&EF(&YO="!G:79E;BP@=7-E('1A9R!N
M86UE*0T*("`@("`@("`@("`@("`@("`@("`@("`@(")P87)S94%T=')I8G5T
M97,B("`@/3X@9F%L<V4L("`@("`@("`@("`@("`@("`@+R\@<&%R<V4@=&AE
M(&%T=')I8G5T97,@;V8@=&AE('1A9R!I;G1O(&%N(&%R<F%Y#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97-!<G)A>2(@("`]/B!F86QS
M92P@("`@("`@("`@("`@("`@("`O+R!P87)S92!T:&5M(&EN=&\@<W!E<F%T
M92!A<G)A>2`H<W!E8VEF>2!N86UE(&]F(&%R<F%Y(&AE<F4I#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@(G!R97!E;F1!='1R:6)U=&5S(B`]/B`B(BP@
M("`@("`@("`@("`@("`@("`@("`O+R!P<F5P96YD(&%T=')I8G5T92!N86UE
M<R!W:71H('1H:7,@<W1R:6YG#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M(F-O;G1E;G1.86UE(B`@("`@("`]/B`B7V-O;G1E;G0B+"`@("`@("`@("`@
M("`O+R!P=70@8V1A=&$@9F]U;F0@:6X@82!T86<@=&AA="!H87,@8F5E;B!C
M;VYV97)T960@=&\@82!C;VUP;&5X('1Y<&4@:6X@=&AI<R!K97D-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`B=&%G36%P(B`@("`@("`@("`@(#T^(&%R
M<F%Y*"D@("`@("`@("`@("`@("`@("\O('5S92!T:&ES('1O(&UA<"!T86=N
M86UE<PT*("`@("`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@+RHJ#0H@
M("`@*B!A8W1U86P@;W!T:6]N<R!F;W(@=&AE('-E<FEA;&EZ871I;VX-"B`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("H@0'9A<B!A<G)A>2`D;W!T:6]N
M<PT*("`@("HO#0H@("`@=F%R("1O<'1I;VYS(#T@87)R87DH*3L-"@T*("`@
M+RHJ#0H@("`@*B!D;R!N;W0@=7-E(&-A<V4@9F]L9&EN9PT*("`@("H@0'9A
M<B!B;V]L96%N("1F;VQD:6YG#0H@("`@*B\-"B`@("!V87(@)&9O;&1I;F<@
M/2!F86QS93L-"@T*("`@+RHJ#0H@("`@*B!U;G-E<FEL:6%L:7IE9"!D871A
M#0H@("`@*B!`=F%R('-T<FEN9R`D7W-E<FEA;&EZ961$871A#0H@("`@*B\-
M"B`@("!V87(@)%]U;G-E<FEA;&EZ961$871A(#T@;G5L;#L-"@T*("`@+RHJ
M#0H@("`@*B!N86UE(&]F('1H92!R;V]T('1A9PT*("`@("H@0'9A<B!S=')I
M;F<@)%]R;V]T#0H@("`@*B\-"B`@("!V87(@)%]R;V]T(#T@;G5L;#L-"@T*
M("`@+RHJ#0H@("`@*B!S=&%C:R!F;W(@86QL(&1A=&$@=&AA="!I<R!F;W5N
M9`T*("`@("H@0'9A<B!A<G)A>2`@("`D7V1A=&%3=&%C:PT*("`@("HO#0H@
M("`@=F%R("1?9&%T85-T86-K("`]("`@87)R87DH*3L-"@T*("`@+RHJ#0H@
M("`@*B!S=&%C:R!F;W(@86QL('9A;'5E<R!T:&%T(&%R92!G96YE<F%T960-
M"B`@("`J($!V87(@87)R87D@("`@)%]V86Q3=&%C:PT*("`@("HO#0H@("`@
M=F%R("1?=F%L4W1A8VL@(#T@("!A<G)A>2@I.PT*#0H@("`O*BH-"B`@("`J
M(&-U<G)E;G0@=&%G(&1E<'1H#0H@("`@*B!`=F%R(&EN="`@("`D7V1E<'1H
M#0H@("`@*B\-"B`@("!V87(@)%]D97!T:"`](#`[#0H-"B`@("\J*@T*("`@
M("H@8V]N<W1R=6-T;W(-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC
M#0H@("`@*B!`<&%R86T@("`@;6EX960@("`D;W!T:6]N<R`@("!A<G)A>2!C
M;VYT86EN:6YG(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T:6]N#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!834Q?56YS97)I86QI>F5R*"1O<'1I;VYS(#T@
M;G5L;"D-"B`@("![#0H@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI
M('L-"B`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@87)R87E?;65R9V4H
M)'1H:7,M/E]D969A=6QT3W!T:6]N<RP@)&]P=&EO;G,I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D=&AI<RT^
M7V1E9F%U;'1/<'1I;VYS.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`O*BH-
M"B`@("`J(')E='5R;B!!4$D@=F5R<VEO;@T*("`@("H-"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!R971U<FX@("!S
M=')I;F<@("1V97)S:6]N($%022!V97)S:6]N#0H@("`@*B\-"B`@("!F=6YC
M=&EO;B!A<&E697)S:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R;B`B,"XY
M(CL-"B`@("!]#0H-"B`@("\J*@T*("`@("H@<F5S970@86QL(&]P=&EO;G,@
M=&\@9&5F875L="!O<'1I;VYS#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PT*("`@("H@0'-E92`@("`@('-E=$]P=&EO;B@I+"!834Q?56YS97)I
M86QI>F5R*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(')E<V5T3W!T:6]N<R@I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W!T:6]N<R`]("1T:&ES+3Y?9&5F
M875L=$]P=&EO;G,[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J('-E="!A;B!O
M<'1I;VX-"B`@("`J#0H@("`@*B!9;W4@8V%N('5S92!T:&ES(&UE=&AO9"!I
M9B!Y;W4@9&\@;F]T('=A;G0@=&\@<V5T(&%L;"!O<'1I;VYS(&EN('1H92!C
M;VYS=')U8W1O<@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J($!S964@("`@("!R97-E=$]P=&EO;B@I+"!834Q?56YS97)I86QI>F5R
M*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=$]P=&EO;B@D;F%M92P@)'9A
M;'5E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/F]P=&EO;G-;)&YA;65=(#T@
M)'9A;'5E.PT*("`@('T-"B`@("`-"B`@("\J*@T*("`@("H@=6YS97)I86QI
M>F4@9&%T80T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J
M($!P87)A;2`@("!M:7AE9"`@("`D9&%T82`@(&1A=&$@=&\@=6YS97)I86QI
M>F4@*'-T<FEN9RP@9FEL96YA;64@;W(@<F5S;W5R8V4I#0H@("`@*B!`<&%R
M86T@("`@8F]O;&5A;B`@)&ES1FEL92!S=')I;F<@<VAO=6QD(&)E('1R96%T
M960@87,@82!F:6QE#0H@("`@*B!`<&%R86T@("`@87)R87D@("`@)&]P=&EO
M;G,-"B`@("`J($!R971U<FX@("!B;V]L96%N("`D<W5C8V5S<PT*("`@("HO
M#0H@("`@9G5N8W1I;VX@=6YS97)I86QI>F4H)&1A=&$L("1I<T9I;&4@/2!F
M86QS92P@)&]P=&EO;G,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@+R\@<F5S
M970@<&%R<V5R(&%N9"!P<F]P97)T:65S#0H@("`@("`@("1T:&ES+3Y834Q?
M4&%R<V5R*&YU;&PL(F5V96YT(BD[#0H@("`@("`@("1T:&ES+3Y?=6YS97)I
M86QI>F5D1&%T82`](&YU;&P[#0H@("`@("`@("1T:&ES+3Y?<F]O="`](&YU
M;&P[#0H@("`@("`@(`T*("`@("`@("`O+R!I9B!O<'1I;VYS(&AA=F4@8F5E
M;B!S<&5C:69I960L('5S92!T:&5M(&EN<W1E860-"B`@("`@("`@+R\@;V8@
M=&AE('!R979I;W5S;'D@9&5F:6YE9"!O;F5S#0H@("`@("`@(&EF("AI<U]A
M<G)A>2@D;W!T:6]N<RDI('L-"B`@("`@("`@("`@("1O<'1I;VYS0F%K(#T@
M)'1H:7,M/F]P=&EO;G,[#0H@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;G-;(F]V97)R:61E3W!T:6]N<R)=*2`F)B`D;W!T:6]N<ULB;W9E<G)I9&5/
M<'1I;VYS(ET@/3T@=')U92D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YO
M<'1I;VYS(#T@87)R87E?;65R9V4H)'1H:7,M/E]D969A=6QT3W!T:6]N<RP@
M)&]P=&EO;G,I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3YO<'1I
M;VYS+"`D;W!T:6]N<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@96QS92![#0H@("`@("`@("`@("`D;W!T:6]N<T)A:R`](&YU;&P[
M#0H@("`@("`@('T-"@T*("`@("`@("`D=&AI<RT^7W9A;%-T86-K(#T@87)R
M87DH*3L-"B`@("`@("`@)'1H:7,M/E]D871A4W1A8VL@/2!A<G)A>2@I.PT*
M("`@("`@("`D=&AI<RT^7V1E<'1H(#T@,#L-"@T*("`@("`@("!I9B`H:7-?
M<W1R:6YG*"1D871A*2D@>PT*("`@("`@("`@("`@:68@*"1I<T9I;&4I('L-
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G-E=$EN<'5T1FEL
M92@D9&%T82D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E<W5L="DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^<&%R<V4H*3L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YP87)S95-T<FEN9R@D
M9&%T82QT<G5E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@)'1H:7,M/G-E=$EN<'5T*"1D871A*3L-"B`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3YP87)S92@I.PT*("`@("`@("!]#0H@("`@
M("`@(`T*("`@("`@("!I9B`H)&]P=&EO;G-"86L@(3T](&YU;&PI('L-"B`@
M("`@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@)&]P=&EO;G-"86L[#0H@("`@
M("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R
M97-U;'0I*2![#0H@("`@("`@("`@("!R971U<FX@)')E<W5L=#L-"B`@("`@
M("`@?0T*("`@("`@("`-"B`@("`@("`@<F5T=7)N("!T<G5E.PT*("`@('T-
M"@T*("`@+RHJ#0H@("`@*B`@(&=E="!T:&4@<F5S=6QT(&]F('1H92!S97)I
M86QI>F%T:6]N#0H@("`@*@T*("`@("H@("!`86-C97-S('!U8FQI8PT*("`@
M("H@("!`<F5T=7)N('-T<FEN9R`@)'-E<FEA;&EZ961$871A#0H@("`@*B\-
M"B`@("`@("`@9G5N8W1I;VX@9V5T56YS97)I86QI>F5D1&%T82@I#0H@("`@
M("`@('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W)O;W0@/3T](&YU;&P@
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("`D=&AI<RT^<F%I<V5%<G)O
M<B@B3F\@=6YS97)I86QI>F5D(&1A=&$@879A:6QA8FQE+B!5<V4@6$U,7U5N
M<V5R:6%L:7IE<CHZ=6YS97)I86QI>F4H*2!F:7)S="XB+"!834Q?54Y315))
M04Q)6D527T524D]27TY/7U5.4T5224%,25I!5$E/3BD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]U;G-E<FEA;&EZ961$
M871A.PT*("`@("`@("!]#0H@("`@#0H@("`O*BH-"B`@("`J("`@9V5T('1H
M92!N86UE(&]F('1H92!R;V]T('1A9PT*("`@("H-"B`@("`J("`@0&%C8V5S
M<R!P=6)L:6,-"B`@("`J("`@0')E='5R;B!S=')I;F<@("1R;V]T3F%M90T*
M("`@("HO#0H@("`@("`@(&9U;F-T:6]N(&=E=%)O;W1.86UE*"D-"B`@("`@
M("`@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<F]O="`]/3T@;G5L;"`I
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@("1T:&ES+3YR86ES945R<F]R
M*").;R!U;G-E<FEA;&EZ960@9&%T82!A=F%I;&%B;&4N(%5S92!834Q?56YS
M97)I86QI>F5R.CIU;G-E<FEA;&EZ92@I(&9I<G-T+B(L(%A-3%]53E-%4DE!
M3$E:15)?15)23U)?3D]?54Y315))04Q)6D%424].*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)O;W0[#0H@("`@("`@
M('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3=&%R="!E;&5M96YT(&AA;F1L
M97(@9F]R(%A-3"!P87)S97(-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J($!P87)A;2`@;V)J96-T("1P87)S97(@(%A-3"!P87)S
M97(@;V)J96-T#0H@("`@("H@0'!A<F%M("!S=')I;F<@)&5L96UE;G0@6$U,
M(&5L96UE;G0-"B`@("`@*B!`<&%R86T@(&%R<F%Y("`D871T<FEB<R!A='1R
M:6)U=&5S(&]F(%A-3"!T86<-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S=&%R=$AA;F1L97(H)'!A<G-E<BP@)&5L96UE
M;G0L("1A='1R:6)S*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1A='1R
M:6)S6R1T:&ES+3YO<'1I;VYS6R)T>7!E071T<FEB=71E(EU=*2D@>PT*("`@
M("`@("`@("`@)'1Y<&4@/2`D871T<FEB<ULD=&AI<RT^;W!T:6]N<ULB='EP
M94%T=')I8G5T92)=73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1T>7!E(#T@(G-T<FEN9R([#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@
M("`@("1T:&ES+3Y?9&5P=&@K*SL-"B`@("`@("`@)'1H:7,M/E]D871A4W1A
M8VM;)'1H:7,M/E]D97!T:%T@/2!N=6QL.PT*#0H@("`@("`@("1V86P@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@(")N86UE(B`@("`@("`@(#T^
M("1E;&5M96YT+`T*("`@("`@("`@("`@("`@("`@("`@(G9A;'5E(B`@("`@
M("`@/3X@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@(")T>7!E(B`@("`@
M("`@(#T^("1T>7!E+`T*("`@("`@("`@("`@("`@("`@("`@(F-H:6QD<F5N
M2V5Y<R(@/3X@87)R87DH*2P-"B`@("`@("`@("`@("`@("`@("`@(")A9V=R
M96=+97ES(B`@(#T^(&%R<F%Y*"D-"B`@("`@("`@("`@("`@("`@("`@*3L-
M"@T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;(G!A<G-E071T<FEB=71E
M<R)=(#T]('1R=64@)B8@*&-O=6YT*"1A='1R:6)S*2`^(#`I*2![#0H@("`@
M("`@("`@("`D=F%L6R)C:&EL9')E;B)=(#T@87)R87DH*3L-"B`@("`@("`@
M("`@("1V86Q;(G1Y<&4B72`]("1T:&ES+3YO<'1I;VYS6R)C;VUP;&5X5'EP
M92)=.PT*#0H@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;(F%T=')I
M8G5T97-!<G)A>2)=("$](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@)'9A
M;%LB8VAI;&1R96XB75LD=&AI<RT^;W!T:6]N<ULB871T<FEB=71E<T%R<F%Y
M(EU=(#T@)&%T=')I8G,[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)S(&%S("1A='1R:6(@/3X@)'9A
M;'5E*2![#0H@("`@("`@("`@("`@("`@("`@("1V86Q;(F-H:6QD<F5N(EU;
M)'1H:7,M/F]P=&EO;G-;(G!R97!E;F1!='1R:6)U=&5S(ETN)&%T=')I8ET@
M/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("!I9B`H:7-S970H)&%T=')I
M8G-;)'1H:7,M/F]P=&EO;G-;(FME>4%T=')I8G5T92)=72DI('L-"B`@("`@
M("`@("`@("1V86Q;(FYA;64B72`]("1A='1R:6)S6R1T:&ES+3YO<'1I;VYS
M6R)K97E!='1R:6)U=&4B75T[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H
M:7-S970H)&%T=')I8G-;)'1H:7,M/F]P=&EO;G-;(F-L87-S071T<FEB=71E
M(EU=*2D@>PT*("`@("`@("`@("`@)'9A;%LB8VQA<W,B72`]("1A='1R:6)S
M6R1T:&ES+3YO<'1I;VYS6R)C;&%S<T%T=')I8G5T92)=73L-"B`@("`@("`@
M?0T*#0H@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]V86Q3=&%C:RP@)'9A
M;"D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@16YD(&5L96UE;G0@:&%N
M9&QE<B!F;W(@6$U,('!A<G-E<@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("H@0'!A<F%M("!O8FIE8W0@6$U,('!A<G-E<B!O8FIE
M8W0-"B`@("`@*B!`<&%R86T@('-T<FEN9PT*("`@("`J($!R971U<FX@=F]I
M9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&5N9$AA;F1L97(H)'!A<G-E<BP@
M)&5L96UE;G0I#0H@("`@>PT*("`@("`@("`D=F%L=64@/2!A<G)A>5]P;W`H
M)'1H:7,M/E]V86Q3=&%C:RD[(`T*("`@("`@("`D9&%T82`@/2!T<FEM*"1T
M:&ES+3Y?9&%T85-T86-K6R1T:&ES+3Y?9&5P=&A=*3L-"B`@("`@("`@#0H@
M("`@("`@("\O(&%D:G5S="!T>7!E(&]F('1H92!V86QU90T*("`@("`@("!S
M=VET8V@H<W1R=&]L;W=E<B@D=F%L=65;(G1Y<&4B72DI('L-"B`@("`@("`@
M("`@("\J#0H@("`@("`@("`@("`@*B!U;G-E<FEA;&EZ92!A;B!O8FIE8W0-
M"B`@("`@("`@("`@("`J+PT*("`@("`@("`@("`@8V%S92`B;V)J96-T(CH-
M"B`@("`@("`@("`@("`@("`D8VQA<W-N86UE("`]("1V86QU95LB8VQA<W,B
M73L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/F]P=&EO
M;G-;(G1A9TUA<")=*2`F)B!I<W-E="@D=&AI<RT^;W!T:6]N<ULB=&%G36%P
M(EU;)&-L87-S;F%M95TI*2![#0H@("`@("`@("`@("`@("`@("`@("1C;&%S
M<VYA;64@/2`D=&AI<RT^;W!T:6]N<ULB=&%G36%P(EU;)&-L87-S;F%M95T[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(`T*("`@("`@
M("`@("`@("`@("\O(&EN<W1A;G1I871E('1H92!C;&%S<PT*("`@("`@("`@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S;F%M92DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E6R)V86QU92)=(#T@)FYE=R`D8VQA<W-N
M86UE.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1V86QU95LB=F%L=64B72`]("9N97<@<W1D0VQA<W,[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9&%T82`A/3T@
M)R<I('L-"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R)C:&EL9')E;B)=
M6R1T:&ES+3YO<'1I;VYS6R)C;VYT96YT3F%M92)=72`]("1D871A.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`-"B`@("`@("`@("`@
M("`@("`O+R!S970@<')O<&5R=&EE<PT*("`@("`@("`@("`@("`@(&9O<F5A
M8V@H)'9A;'5E6R)C:&EL9')E;B)=(&%S("1P<F]P(#T^("1P<F]P5F%L*2![
M#0H@("`@("`@("`@("`@("`@("`@("\O(&-H96-K('=H971H97(@=&AE<F4@
M:7,@82!S<&5C:6%L(&UE=&AO9"!T;R!S970@=&AI<R!P<F]P97)T>0T*("`@
M("`@("`@("`@("`@("`@("`D<V5T365T:&]D(#T@(G-E="(N)'!R;W`[#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1V86QU95LB
M=F%L=64B72P@)'-E=$UE=&AO9"DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"8D=F%L=65;(G9A;'5E(ETL("1S
M971-971H;V0I+"`D<')O<%9A;"D[#0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;(G9A;'5E
M(ETM/B1P<F]P(#T@)'!R;W!686P[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@+R\@(&-H96-K
M(&9O<B!M86=I8R!F=6YC=&EO;@T*("`@("`@("`@("`@("`@(&EF("AM971H
M;V1?97AI<W1S*"1V86QU95LB=F%L=64B72P@(E]?=V%K975P(BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E6R)V86QU92)=+3Y?7W=A:V5U<"@I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("`-"B`@("`@("`@("`@("\J#0H@("`@("`@("`@
M("`@*B!U;G-E<FEA;&EZ92!A;B!A<G)A>0T*("`@("`@("`@("`@("HO#0H@
M("`@("`@("`@("!C87-E(")A<G)A>2(Z#0H@("`@("`@("`@("`@("`@:68@
M*"1D871A("$]/2`G)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=F%L=65;
M(F-H:6QD<F5N(EU;)'1H:7,M/F]P=&EO;G-;(F-O;G1E;G1.86UE(EU=(#T@
M)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`@("`@
M)'9A;'5E6R)V86QU92)=(#T@)'9A;'5E6R)C:&EL9')E;B)=.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("`O*@T*("`@("`@("`@
M("`@("H@=6YS97)I86QI>F4@82!N=6QL('9A;'5E#0H@("`@("`@("`@("`@
M*B\-"B`@("`@("`@("`@(&-A<V4@(FYU;&PB.@T*("`@("`@("`@("`@("`@
M("1D871A(#T@;G5L;#L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("`-"B`@("`@("`@("`@("\J#0H@("`@("`@("`@("`@*B!U
M;G-E<FEA;&EZ92!A(')E<V]U<F-E(#T^('1H:7,@:7,@;F]T('!O<W-I8FQE
M(#HM*`T*("`@("`@("`@("`@("HO#0H@("`@("`@("`@("!C87-E(")R97-O
M=7)C92(Z#0H@("`@("`@("`@("`@("`@)'9A;'5E6R)V86QU92)=(#T@)&1A
M=&$[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@
M#0H@("`@("`@("`@("`O*@T*("`@("`@("`@("`@("H@=6YS97)I86QI>F4@
M86YY('-C86QA<B!V86QU90T*("`@("`@("`@("`@("HO#0H@("`@("`@("`@
M("!D969A=6QT.@T*("`@("`@("`@("`@("`@('-E='1Y<&4H)&1A=&$L("1V
M86QU95LB='EP92)=*3L-"B`@("`@("`@("`@("`@("`D=F%L=65;(G9A;'5E
M(ET@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M?0T*("`@("`@("`D<&%R96YT(#T@87)R87E?<&]P*"1T:&ES+3Y?=F%L4W1A
M8VLI.PT*("`@("`@("!I9B`H)'!A<F5N="`]/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]U;G-E<FEA;&EZ961$871A(#T@)B1V86QU95LB=F%L
M=64B73L-"B`@("`@("`@("`@("1T:&ES+3Y?<F]O="`]("8D=F%L=65;(FYA
M;64B73L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@+R\@<&%R96YT(&AA<R!T;R!B92!A;B!A<G)A
M>0T*("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R96YT6R)C:&EL9')E;B)=
M*2!\?"`A:7-?87)R87DH)'!A<F5N=%LB8VAI;&1R96XB72DI('L-"B`@("`@
M("`@("`@("`@("`D<&%R96YT6R)C:&EL9')E;B)=(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1P87)E;G1;(G1Y<&4B72P@
M87)R87DH(F%R<F%Y(BP@(F]B:F5C="(I*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<&%R96YT6R)T>7!E(ET@/2`D=&AI<RT^;W!T:6]N<ULB8V]M<&QE
M>%1Y<&4B73L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6R)C;VUP;&5X5'EP92)=(#T](")O8FIE8W0B*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R96YT6R)C;&%S<R)=(#T@)'!A<F5N=%LB;F%M
M92)=.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@#0H@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1V86QU95LB;F%M92)=*2D@>PT*("`@("`@("`@("`@("`@
M("\O('1H97)E(&%L<F5A9'D@:&%S(&)E96X@82!T86<@=VET:"!T:&ES(&YA
M;64-"B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'9A;'5E6R)N86UE
M(ETL("1P87)E;G1;(F-H:6QD<F5N2V5Y<R)=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`O+R!N;R!A9V=R96=A=&4@:&%S(&)E96X@8W)E871E9"!F;W(@
M=&AI<R!T86<-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D
M=F%L=65;(FYA;64B72P@)'!A<F5N=%LB86=G<F5G2V5Y<R)=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F5N=%LB8VAI;&1R96XB75LD=F%L
M=65;(FYA;64B75T@/2!A<G)A>2@D<&%R96YT6R)C:&EL9')E;B)=6R1V86QU
M95LB;F%M92)=72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P
M=7-H*"1P87)E;G1;(F%G9W)E9TME>7,B72P@)'9A;'5E6R)N86UE(ETI.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y7W!U<V@H)'!A<F5N=%LB8VAI;&1R96XB75LD=F%L=65;(FYA;64B75TL
M("1V86QU95LB=F%L=64B72D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)'!A<F5N=%LB8VAI;&1R96XB75LD=F%L
M=65;(FYA;64B75T@/2`F)'9A;'5E6R)V86QU92)=.PT*("`@("`@("`@("`@
M("`@("`@("!A<G)A>5]P=7-H*"1P87)E;G1;(F-H:6QD<F5N2V5Y<R)=+"`D
M=F%L=65;(FYA;64B72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1P87)E
M;G1;(F-H:6QD<F5N(ETL)'9A;'5E6R)V86QU92)=*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]V86Q3=&%C:RP@
M)'!A<F5N="D[#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@("1T:&ES
M+3Y?9&5P=&@M+3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!(86YD;&5R
M(&9O<B!C:&%R86-T97(@9&%T80T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("H@0'!A<F%M("!O8FIE8W0@6$U,('!A<G-E<B!O8FIE
M8W0-"B`@("`@*B!`<&%R86T@('-T<FEN9R!#1$%400T*("`@("`J($!R971U
M<FX@=F]I9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-D871A2&%N9&QE<B@D
M<&%R<V5R+"`D8V1A=&$I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V1A=&%3
M=&%C:ULD=&AI<RT^7V1E<'1H72`N/2`D8V1A=&$[#0H@("`@?0T*?0T*/SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]834PO571I;"YP:'``````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U,3`Q,@`Q,#0Q-S,V,S`P-``P,3<T
M,C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]02%`-"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W
M:61T:#TT.B`J+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO
M+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P
M,B!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H
M92!02%`@;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\#0HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P-"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<G,Z(%-T97!H86X@
M4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X@("`@("`@("`@("`@("`@
M("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\-
M"B\O("`@("1)9#H@571I;"YP:'`L=B`Q+C$U(#(P,#,O,3$O,C(@,3`Z-#$Z
M,#@@<V-H<W0@17AP("0-"@T*+RHJ#0H@*B!U<V5S(%!%05(@97)R;W)S#0H@
M*B\-"B`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"@T*+RHJ#0H@*B!E
M<G)O<B!C;V1E(&9O<B!I;G9A;&ED(&-H87)S(&EN(%A-3"!N86UE#0H@*B\-
M"F1E9FEN92@B6$U,7U5424Q?15)23U)?24Y604Q)1%]#2$%24R(L(#4Q*3L-
M"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!I;G9A;&ED(&-H87)S(&EN(%A-
M3"!N86UE#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?15)23U)?24Y604Q)1%]3
M5$%25"(L(#4R*3L-"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!N;VXM<V-A
M;&%R('1A9R!C;VYT96YT#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?15)23U)?
M3D].7U-#04Q!4E]#3TY414Y4(BP@-C`I.PT*("`@(`T*+RHJ#0H@*B!R97!L
M86-E(%A-3"!E;G1I=&EE<PT*("HO#0ID969I;F4H(EA-3%]55$E,7U)%4$Q!
M0T5?14Y4251)15,B+"`Q*3L-"@T*+RHJ#0H@*B!E;6)E9&0@8V]N=&5N="!I
M;B!A($-$871A(%-E8W1I;VX-"B`J+PT*9&5F:6YE*")834Q?551)3%]#1$%4
M05]314-424].(BP@,BD[#0H@("`@#0HO*BH-"B`J('5T:6QI='D@8VQA<W,@
M9F]R('=O<FMI;F<@=VET:"!834P@9&]C=6UE;G1S#0H@*@T*("H@0&-A=&5G
M;W)Y(%A-3`T*("H@0'!A8VMA9V4@(%A-3%]5=&EL#0H@*B!`=F5R<VEO;B`@
M,"XU+C(-"B`J($!A=71H;W(@("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H
M<"YN970^#0H@*B!`=&]D;R`@("`@;65T:&]D('1O(&=E="!D;V-T>7!E(&1E
M8VQA<F%T:6]N#0H@*B\-"F-L87-S(%A-3%]5=&EL('L-"@T*("`@+RHJ#0H@
M("`@*B!R971U<FX@05!)('9E<G-I;VX-"B`@("`J#0H@("`@*B!`86-C97-S
M("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<F5T=7)N("`@<W1R
M:6YG("`D=F5R<VEO;B!!4$D@=F5R<VEO;@T*("`@("HO#0H@("`@9G5N8W1I
M;VX@87!I5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!R971U<FX@(C`N-2XR
M(CL-"B`@("!]#0H-"B`@("\J*@T*("`@("H@<F5P;&%C92!834P@96YT:71I
M97,-"B`@("`J#0H@("`@*B!C:&%R<R!T:&%T(&AA=F4@=&\@8F4@<F5P;&%C
M960@87)E("<F)R!A;F0@)SPG+`T*("`@("H@9G5R=&AE<FUO<F4@)SXG+"`G
M)R<@86YD("<B)R!H879E(&5N=&ET:65S('1H870@8V%N(&)E('5S960N(`T*
M("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO
M571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!R97!L86-E(%A-3"!E;G1I
M=&5S.@T*("`@("H@)'-T<FEN9R`](%A-3%]5=&EL.CIR97!L86-E16YT:71I
M97,H(E1H:7,@<W1R:6YG(&-O;G1A:6YS(#P@)B`^+B(I.PT*("`@("H@/"]C
M;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S
M=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1S=')I;F<@<W1R:6YG
M('=H97)E(%A-3"!S<&5C:6%L(&-H87)S('-H;W5L9"!B92!R97!L86-E9`T*
M("`@("H@0')E='5R;B`@('-T<FEN9R`@)'-T<FEN9R!S=')I;F<@=VET:"!R
M97!L86-E9"!C:&%R<PT*("`@("H@0'1O9&\@("`@(&]P=&EO;F%L('!A<F%M
M971E<B!T;R!S=7!P;'D@861D:71I;VYA;"!E;G1I=&EE<PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@<F5P;&%C945N=&ET:65S*"1S=')I;F<I#0H@("`@>PT*
M("`@("`@("!R971U<FX@<W1R='(H)'-T<FEN9RQA<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G)B<@(#T^("<F86UP.R<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SXG("`]/B`G)F=T
M.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SPG("`]
M/B`G)FQT.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R(G("`]/B`G)G%U;W0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G7"<G(#T^("<F87!O<SLG("DI.PT*("`@('T-"@T*("`@+RHJ
M#0H@("`@*B!B=6EL9"!A;B!X;6P@9&5C;&%R871I;VX-"B`@("`J#0H@("`@
M*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-
M"B`@("`J(`T*("`@("H@+R\@9V5T(&%N(%A-3"!D96-L87)A=&EO;CH-"B`@
M("`J("1X;6Q$96-L(#T@6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"(Q
M+C`B+"`B551&+3@B+"!T<G5E*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@
M("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`D=F5R<VEO;B`@("`@>&UL('9E<G-I;VX-"B`@
M("`J($!P87)A;2`@("!S=')I;F<@("1E;F-O9&EN9R`@("!C:&%R86-T97(@
M96YC;V1I;F<-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1S=&%N9$%L;VYE
M("!D;V-U;65N="!I<R!S=&%N9&%L;VYE("AO<B!N;W0I#0H@("`@*B!`<F5T
M=7)N("`@<W1R:6YG("`D9&5C;"!X;6P@9&5C;&%R871I;VX-"B`@("`J($!U
M<V5S("`@("!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"D@=&\@<V5R
M:6%L:7IE('1H92!A='1R:6)U=&5S(&]F('1H92!834P@9&5C;&%R871I;VX-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%A-3$1E8VQA<F%T:6]N*"1V97)S
M:6]N(#T@(C$N,"(L("1E;F-O9&EN9R`](&YU;&PL("1S=&%N9&%L;VYE(#T@
M;G5L;"D-"B`@("![#0H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(G9E<G-I;VXB(#T^("1V97)S
M:6]N+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@
M+R\@861D(&5N8V]D:6YG#0H@("`@("`@(&EF("@D96YC;V1I;F<@(3T](&YU
M;&PI('L-"B`@("`@("`@("`@("1A='1R:6)U=&5S6R)E;F-O9&EN9R)=(#T@
M)&5N8V]D:6YG.PT*("`@("`@("!]#0H@("`@("`@("\O(&%D9"!S=&%N9&%L
M;VYE+"!I9B!S<&5C:69I960-"B`@("`@("`@:68@*"1S=&%N9&%L;VYE("$]
M/2!N=6QL*2![#0H@("`@("`@("`@("`D871T<FEB=71E<ULB<W1A;F1A;&]N
M92)=(#T@)'-T86YD86QO;F4@/R`B>65S(B`Z(")N;R([#0H@("`@("`@('T-
M"B`@("`@("`@#0H@("`@("`@(')E='5R;B!S<')I;G1F*"(\/WAM;"5S/SXB
M+"!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='1R:6)U=&5S+"!F
M86QS92DI.PT*("`@('T-"@T*#0H@("`O*BH-"B`@("`J(&)U:6QD(&$@9&]C
M=6UE;G0@='EP92!D96-L87)A=&EO;@T*("`@("H-"B`@("`J(#QC;V1E/@T*
M("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@
M("`@*B`O+R!G970@82!D;V-T>7!E(&1E8VQA<F%T:6]N.@T*("`@("H@)'AM
M;$1E8VP@/2!834Q?571I;#HZ9V5T1&]C5'EP941E8VQA<F%T:6]N*")R;V]T
M5&%G(BPB;7E$;V-4>7!E+F1T9"(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J
M($!P87)A;2`@("!S=')I;F<@("1R;V]T("`@("`@("`@;F%M92!O9B!T:&4@
M<F]O="!T86<-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1U<FD@("`@("`@
M("`@=7)I(&]F('1H92!D;V-T>7!E(&1E9FEN:71I;VX@*&]R(&%R<F%Y('=I
M=&@@=7)I(&%N9"!P=6)L:6,@:60I#0H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`D:6YT97)N86Q$=&0@(&EN=&5R;F%L(&1T9"!E;G1R:65S("`@#0H@("`@
M*B!`<F5T=7)N("`@<W1R:6YG("`D9&5C;"`@("`@("`@(&1O8W1Y<&4@9&5C
M;&%R871I;VX-"B`@("`J($!S:6YC92`@("`P+C(-"B`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=$1O8U1Y<&5$96-L87)A=&EO;B@D<F]O="P@)'5R:2`](&YU
M;&PL("1I;G1E<FYA;$1T9"`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H
M:7-?87)R87DH)'5R:2DI('L-"B`@("`@("`@("`@("1R968@/2!S<')I;G1F
M*"`G(%!50DQ)0R`B)7,B("(E<R(G+"`D=7)I6R)I9")=+"`D=7)I6R)U<FDB
M72`I.PT*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1U<FDI*2![#0H@("`@
M("`@("`@("`D<F5F(#T@<W!R:6YT9B@@)R!365-414T@(B5S(B<L("1U<FD@
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R968@/2`B(CL-
M"B`@("`@("`@?0T*#0H@("`@("`@(&EF("AE;7!T>2@D:6YT97)N86Q$=&0I
M*2![#0H@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@B/"%$3T-465!%("5S
M)7,^(BP@)')O;W0L("1R968I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@<F5T=7)N('-P<FEN=&8H(CPA1$]#5%E012`E<R5S(%M<;B5S7&Y=
M/B(L("1R;V]T+"`D<F5F+"`D:6YT97)N86Q$=&0I.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`O*BH-"B`@("`J(&-R96%T92!S=')I;F<@<F5P<F5S96YT
M871I;VX@;V8@86X@871T<FEB=71E(&QI<W0-"B`@("`J#0H@("`@*B`\8V]D
M93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J
M(`T*("`@("H@+R\@8G5I;&0@86X@871T<FEB=71E('-T<FEN9PT*("`@("H@
M)&%T="`](&%R<F%Y*`T*("`@("H@("`@("`@("`@("`@(")F;V\B("`@/3X@
M(")B87(B+`T*("`@("H@("`@("`@("`@("`@(")A<F=H(B`@/3X@(")T;VUA
M=&\B#0H@("`@*B`@("`@("`@("`@("D[#0H@("`@*@T*("`@("H@)&%T=$QI
M<W0@/2!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='0I.R`@("`-
M"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC
M#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D871T
M<FEB=71E<R`@871T<FEB=71E(&%R<F%Y#0H@("`@*B!`<&%R86T@("`@8F]O
M;&5A;B`D<V]R="`@("`@("`@<V]R="!A='1R:6)U=&4@;&ES="!A;'!H86)E
M=&EC86QL>0T*("`@("H@0'!A<F%M("`@(&)O;VQE86X@)&UU;'1I;&EN92`@
M('5S92!L:6YE8G)E86MS+"!I9B!M;W)E('1H86X@;VYE(&%T=')I8G5T92!I
M<R!G:79E;@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&EN9&5N="`@("`@
M('-T<FEN9R!U<V5D(&9O<B!I;F1E;G1A=&EO;B!O9B!M=6QT:6QI;F4@871T
M<FEB=71E<PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QI;F5B<F5A:R`@
M('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS(&]F(&UU;'1I;&EN92!A='1R
M:6)U=&5S#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG("`@("`@
M<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!A='1R:6)U=&5S#0H@("`@
M*B!`=7-E<R`@("`@6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@I('1O(')E
M<&QA8V4@6$U,(&5N=&ET:65S(&EN(&%T=')I8G5T92!V86QU97,-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(&%T=')I8G5T97-4;U-T<FEN9R@D871T<FEB=71E
M<RP@)'-O<G0@/2!T<G5E+"`D;75L=&EL:6YE(#T@9F%L<V4L("1I;F1E;G0@
M/2`G("`@("<L("1L:6YE8G)E86L@/2`B7&XB*0T*("`@('L-"B`@("`@("`@
M)'-T<FEN9R`]("(B.PT*("`@("`@("!I9B`H:7-?87)R87DH)&%T=')I8G5T
M97,I("8F("%E;7!T>2@D871T<FEB=71E<RDI('L-"B`@("`@("`@("`@(&EF
M("@D<V]R="D@>PT*("`@("`@("`@("`@("`@(&MS;W)T*"1A='1R:6)U=&5S
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF*"`A)&UU;'1I;&EN
M92!\?"!C;W5N="@D871T<FEB=71E<RD@/3T@,2D@>PT*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2![
M#0H@("`@("`@("`@("`@("`@("`@("1S=')I;F<@+CT@(B`B+B1K97DN)STB
M)RY834Q?571I;#HZ<F5P;&%C945N=&ET:65S*"1V86QU92DN)R(G.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&9I<G-T(#T@=')U93L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&9I<G-T*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<W1R:6YG("X]("(@(BXD:V5Y+B<](B<N6$U,7U5T:6PZ.G)E
M<&QA8V5%;G1I=&EE<R@D=F%L=64I+B<B)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1F:7)S="`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`D
M;&EN96)R96%K+B1I;F1E;G0N)&ME>2XG/2(G+EA-3%]5=&EL.CIR97!L86-E
M16YT:71I97,H)'9A;'5E*2XG(B<[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1S=')I;F<[#0H@("`@?0T*#0H@("`O*BH-"B`@
M("`J(&-R96%T92!A('1A9PT*("`@("H-"B`@("`J(%1H:7,@;65T:&]D('=I
M;&P@8V%L;"!834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"DL('=H:6-H
M#0H@("`@*B!I<R!M;W)E(&9L97AI8FQE+@T*("`@("H-"B`@("`J(#QC;V1E
M/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@
M#0H@("`@*B`O+R!C<F5A=&4@86X@6$U,('1A9SH-"B`@("`J("1T86<@/2!8
M34Q?571I;#HZ8W)E871E5&%G*")M>4YS.FUY5&%G(BP@87)R87DH(F9O;R(@
M/3X@(F)A<B(I+"`B5&AI<R!I<R!I;G-I9&4@=&AE('1A9R(L(")H='1P.B\O
M=W=W+G<S8RYO<F<O;7E.<R,B*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@
M("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`D<6YA;64@("`@("`@("`@("`@<75A;&EF:65D
M('1A9VYA;64@*&EN8VQU9&EN9R!N86UE<W!A8V4I#0H@("`@*B!`<&%R86T@
M("`@87)R87D@("`D871T<FEB=71E<R`@("`@("`@87)R87D@8V]N=&%I;F<@
M871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@(&UI>&5D("`@)&-O;G1E;G0-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("1N86UE<W!A8V55<FD@("`@("!5
M4DD@;V8@=&AE(&YA;65S<&%C90T*("`@("H@0'!A<F%M("`@(&EN=&5G97(@
M)')E<&QA8V5%;G1I=&EE<R`@('=H971H97(@=&\@<F5P;&%C92!834P@<W!E
M8VEA;"!C:&%R<R!I;B!C;VYT96YT+"!E;6)E9&0@:70@:6X@82!#1&%T82!S
M96-T:6]N(&]R(&YO;F4@;V8@8F]T:`T*("`@("H@0'!A<F%M("`@(&)O;VQE
M86X@)&UU;'1I;&EN92`@("`@("`@('=H971H97(@=&\@8W)E871E(&$@;75L
M=&EL:6YE('1A9R!W:&5R92!E86-H(&%T=')I8G5T92!G971S('=R:71T96X@
M=&\@82!S:6YG;&4@;&EN90T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&EN
M9&5N="`@("`@("`@("`@('-T<FEN9R!U<V5D('1O(&EN9&5N="!A='1R:6)U
M=&5S("A?875T;R!I;F1E;G1S(&%T=')I8G5T97,@<V\@=&AE>2!S=&%R="!A
M="!T:&4@<V%M92!C;VQU;6XI#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D
M;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI;F5B<F5A:W,-
M"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@("`@("`@("`@("!8
M34P@=&%G#0H@("`@*B!`<V5E("`@("`@6$U,7U5T:6PZ.F-R96%T951A9T9R
M;VU!<G)A>2@I#0H@("`@*B!`=7-E<R`@("`@6$U,7U5T:6PZ.F-R96%T951A
M9T9R;VU!<G)A>2@I('1O(&-R96%T92!T:&4@=&%G#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!C<F5A=&5486<H)'%N86UE+"`D871T<FEB=71E<R`](&%R<F%Y
M*"DL("1C;VYT96YT(#T@;G5L;"P@)&YA;65S<&%C955R:2`](&YU;&PL("1R
M97!L86-E16YT:71I97,@/2!834Q?551)3%]215!,04-%7T5.5$E42453+"`D
M;75L=&EL:6YE(#T@9F%L<V4L("1I;F1E;G0@/2`B7V%U=&\B+"`D;&EN96)R
M96%K(#T@(EQN(BD-"B`@("![#0H@("`@("`@("1T86<@/2!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@(")Q;F%M92(@("`@("`]/B`D<6YA;64L#0H@
M("`@("`@("`@("`@("`@("`@("`B871T<FEB=71E<R(@/3X@)&%T=')I8G5T
M97,-"B`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@("`@("`O+R!A9&0@
M=&%G(&-O;G1E;G0-"B`@("`@("`@:68@*"1C;VYT96YT("$]/2!N=6QL*2![
M#0H@("`@("`@("`@("`D=&%G6R)C;VYT96YT(ET@/2`D8V]N=&5N=#L-"B`@
M("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@861D(&YA;65S<&%C92!5
M<FD-"B`@("`@("`@:68@*"1N86UE<W!A8V55<FD@(3T](&YU;&PI('L-"B`@
M("`@("`@("`@("1T86=;(FYA;65S<&%C955R:2)=(#T@)&YA;65S<&%C955R
M:3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!834Q?571I;#HZ8W)E
M871E5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I97,L("1M=6QT
M:6QI;F4L("1I;F1E;G0L("1L:6YE8G)E86LI.PT*("`@('T-"@T*("`@+RHJ
M#0H@("`@*B!C<F5A=&4@82!T86<@9G)O;2!A;B!A<G)A>0T*("`@("H@=&AI
M<R!M971H;V0@87=A:71S(&%N(&%R<F%Y(&EN('1H92!F;VQL;W=I;F<@9F]R
M;6%T#0H@("`@*B`\<')E/@T*("`@("H@87)R87DH#0H@("`@*B`@(G%N86UE
M(B`@("`@("`@/3X@)'%N86UE("`@("`@("`@+R\@<75A;&EF:65D(&YA;64@
M;V8@=&AE('1A9PT*("`@("H@(")N86UE<W!A8V4B("`@(#T^("1N86UE<W!A
M8V4@("`@("\O(&YA;65S<&%C92!P<F5F:7@@*&]P=&EO;F%L+"!I9B!Q;F%M
M92!I<R!S<&5C:69I960@;W(@;F\@;F%M97-P86-E*0T*("`@("H@(")L;V-A
M;'!A<G0B("`@(#T^("1L;V-A;'!A<G0L("`@("\O(&QO8V%L('!A<G0@;V8@
M=&AE('1A9VYA;64@*&]P=&EO;F%L+"!I9B!Q;F%M92!I<R!S<&5C:69I960I
M#0H@("`@*B`@(F%T=')I8G5T97,B("`@/3X@87)R87DH*2P@("`@("`@+R\@
M87)R87D@8V]N=&%I;FEN9R!A;&P@871T<FEB=71E<R`H;W!T:6]N86PI#0H@
M("`@*B`@(F-O;G1E;G0B("`@("`@/3X@)&-O;G1E;G0L("`@("`@+R\@=&%G
M(&-O;G1E;G0@*&]P=&EO;F%L*0T*("`@("H@(")N86UE<W!A8V55<FDB(#T^
M("1N86UE<W!A8V55<FD@("\O(&YA;65S<&%C955R:2!F;W(@=&AE(&=I=F5N
M(&YA;65S<&%C92`H;W!T:6]N86PI#0H@("`@*B`@("D-"B`@("`J(#PO<')E
M/@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=8
M34PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`D=&%G(#T@87)R87DH#0H@
M("`@*B`@("`@("`@("`@(G%N86UE(B`@("`@("`@/3X@(F9O;SIB87(B+`T*
M("`@("H@("`@("`@("`@(")N86UE<W!A8V55<FDB(#T^(")H='1P.B\O9F]O
M+F-O;2(L#0H@("`@*B`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R
M87DH(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A
M8FQE(B`I+`T*("`@("H@("`@("`@("`@(")C;VYT96YT(B`@("`@(#T^("))
M)VT@:6YS:61E('1H92!T86<B+`T*("`@("H@("`@("`@("`@("`I.PT*("`@
M("H@+R\@8W)E871I;F<@82!T86<@=VET:"!Q=6%L:69I960@;F%M92!A;F0@
M;F%M97-P86-E57)I#0H@("`@*B`D<W1R:6YG(#T@6$U,7U5T:6PZ.F-R96%T
M951A9T9R;VU!<G)A>2@D=&%G*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@
M("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`
M<&%R86T@("`@87)R87D@("`D=&%G("`@("`@("`@("`@("`@=&%G(&1E9FEN
M:71I;VX-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("1R97!L86-E16YT:71I
M97,@("!W:&5T:&5R('1O(')E<&QA8V4@6$U,('-P96-I86P@8VAA<G,@:6X@
M8V]N=&5N="P@96UB961D(&ET(&EN(&$@0T1A=&$@<V5C=&EO;B!O<B!N;VYE
M(&]F(&)O=&@-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1M=6QT:6QI;F4@
M("`@("`@("!W:&5T:&5R('1O(&-R96%T92!A(&UU;'1I;&EN92!T86<@=VAE
M<F4@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET=&5N('1O(&$@<VEN9VQE(&QI
M;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1I;F1E;G0@("`@("`@("`@
M("!S=')I;F<@=7-E9"!T;R!I;F1E;G0@871T<FEB=71E<R`H7V%U=&\@:6YD
M96YT<R!A='1R:6)U=&5S('-O('1H97D@<W1A<G0@870@=&AE('-A;64@8V]L
M=6UN*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QI;F5B<F5A:R`@("`@
M("`@('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS#0H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG("`D<W1R:6YG("`@("`@("`@("`@6$U,('1A9PT*("`@("H@
M0'-E92`@("`@(%A-3%]5=&EL.CIC<F5A=&5486<H*0T*("`@("H@0'5S97,@
M("`@(%A-3%]5=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H*2!T;R!S97)I86QI
M>F4@=&AE(&%T=')I8G5T97,@;V8@=&AE('1A9PT*("`@("H@0'5S97,@("`@
M(%A-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H*2!T;R!G970@;&]C86P@
M<&%R="!A;F0@;F%M97-P86-E(&]F(&$@<75A;&EF:65D(&YA;64-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(&-R96%T951A9T9R;VU!<G)A>2@D=&%G+"`D<F5P
M;&%C945N=&ET:65S(#T@6$U,7U5424Q?4D503$%#15]%3E1)5$E%4RP@)&UU
M;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@(E]A=71O(BP@)&QI;F5B<F5A
M:R`](")<;B(@*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T86=;(F-O
M;G1E;G0B72D@)B8@(6ES7W-C86QA<B@D=&%G6R)C;VYT96YT(ETI*2![#0H@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@@(E-U<'!L:65D
M(&YO;BUS8V%L87(@=F%L=64@87,@=&%G(&-O;G1E;G0B+"!834Q?551)3%]%
M4E)/4E].3TY?4T-!3$%27T-/3E1%3E0@*3L-"B`@("`@("`@?0T*#0H@("`@
M("`@("\O(&EF(&YO(&%T=')I8G5T97,@:&%V(&)E96X@<V5T+"!U<V4@96UP
M='D@871T<FEB=71E<PT*("`@("`@("!I9B`H(6ES<V5T*"1T86=;(F%T=')I
M8G5T97,B72D@?'P@(6ES7V%R<F%Y*"1T86=;(F%T=')I8G5T97,B72DI('L-
M"B`@("`@("`@("`@("1T86=;(F%T=')I8G5T97,B72`](&%R<F%Y*"D[#0H@
M("`@("`@('T-"B`@("`@("`@#0H@("`@("`@("\O('%U86QI9FEE9"!N86UE
M(&ES(&YO="!G:79E;@T*("`@("`@("!I9B`H(6ES<V5T*"1T86=;(G%N86UE
M(ETI*2![#0H@("`@("`@("`@("`O+R!C:&5C:R!F;W(@;F%M97-P86-E#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'1A9ULB;F%M97-P86-E(ETI("8F("%E
M;7!T>2@D=&%G6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@("`@("`@("`D
M=&%G6R)Q;F%M92)=(#T@)'1A9ULB;F%M97-P86-E(ETN(CHB+B1T86=;(FQO
M8V%L4&%R=")=.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D=&%G6R)Q;F%M92)=(#T@)'1A9ULB;&]C86Q087)T(ET[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("\O(&YA;65S<&%C92!54DD@:7,@<V5T+"!B
M=70@;F\@;F%M97-P86-E#0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&%G
M6R)N86UE<W!A8V55<FDB72D@)B8@(6ES<V5T*"1T86=;(FYA;65S<&%C92)=
M*2D@>PT*("`@("`@("`@("`@)'!A<G1S(#T@6$U,7U5T:6PZ.G-P;&ET475A
M;&EF:65D3F%M92@D=&%G6R)Q;F%M92)=*3L-"B`@("`@("`@("`@("1T86=;
M(FQO8V%L4&%R=")=(#T@)'!A<G1S6R)L;V-A;%!A<G0B73L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D<&%R='-;(FYA;65S<&%C92)=*2D@>PT*("`@("`@
M("`@("`@("`@("1T86=;(FYA;65S<&%C92)=(#T@)'!A<G1S6R)N86UE<W!A
M8V4B73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@(&EF
M("AI<W-E="@D=&%G6R)N86UE<W!A8V55<FDB72D@)B8@(65M<'1Y*"1T86=;
M(FYA;65S<&%C955R:2)=*2D@>PT*("`@("`@("`@("`@+R\@:7,@82!N86UE
M<W!A8V4@9VEV96X-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&%G6R)N86UE
M<W!A8V4B72D@)B8@(65M<'1Y*"1T86=;(FYA;65S<&%C92)=*2D@>PT*("`@
M("`@("`@("`@("`@("1T86=;(F%T=')I8G5T97,B75LB>&UL;G,Z(BXD=&%G
M6R)N86UE<W!A8V4B75T@/2`D=&%G6R)N86UE<W!A8V55<FDB73L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@+R\@9&5F:6YE('1H
M:7,@57)I(&%S('1H92!D969A=6QT(&YA;65S<&%C90T*("`@("`@("`@("`@
M("`@("1T86=;(F%T=')I8G5T97,B75LB>&UL;G,B72`]("1T86=;(FYA;65S
M<&%C955R:2)=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@
M("`@+R\@8VAE8VL@9F]R(&UU;'1I;&EN92!A='1R:6)U=&5S#0H@("`@("`@
M(&EF("@D;75L=&EL:6YE(#T]/2!T<G5E*2![#0H@("`@("`@("`@("!I9B`H
M)&EN9&5N="`]/3T@(E]A=71O(BD@>PT*("`@("`@("`@("`@("`@("1I;F1E
M;G0@/2!S=')?<F5P96%T*"(@(BP@*'-T<FQE;B@D=&%G6R)Q;F%M92)=*2LR
M*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@
M("`@("\O(&-R96%T92!A='1R:6)U=&4@;&ES=`T*("`@("`@("`D871T3&ES
M="`@("`]("`@6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D=&%G6R)A
M='1R:6)U=&5S(ETL('1R=64L("1M=6QT:6QI;F4L("1I;F1E;G0L("1L:6YE
M8G)E86L@*3L-"B`@("`@("`@:68@*"%I<W-E="@D=&%G6R)C;VYT96YT(ETI
M('Q\("AS=')I;F<I)'1A9ULB8V]N=&5N=")=(#T]("<G*2![#0H@("`@("`@
M("`@("`D=&%G("`@(#T@("!S<')I;G1F*"(\)7,E<R`O/B(L("1T86=;(G%N
M86UE(ETL("1A='1,:7-T*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&EF("@D<F5P;&%C945N=&ET:65S(#T](%A-3%]55$E,7U)%4$Q!0T5?
M14Y4251)15,I('L-"B`@("`@("`@("`@("`@("`D=&%G6R)C;VYT96YT(ET@
M/2!834Q?571I;#HZ<F5P;&%C945N=&ET:65S*"1T86=;(F-O;G1E;G0B72D[
M#0H@("`@("`@("`@("!](&5L<V5I9B`H)')E<&QA8V5%;G1I=&EE<R`]/2!8
M34Q?551)3%]#1$%405]314-424].*2![#0H@("`@("`@("`@("`@("`@)'1A
M9ULB8V]N=&5N=")=(#T@6$U,7U5T:6PZ.F-R96%T94-$871A4V5C=&EO;B@D
M=&%G6R)C;VYT96YT(ETI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'1A9R`@("`]("`@<W!R:6YT9B@B/"5S)7,^)7,\+R5S/B(L("1T86=;(G%N
M86UE(ETL("1A='1,:7-T+"`D=&%G6R)C;VYT96YT(ETL("1T86=;(G%N86UE
M(ET@*3L-"B`@("`@("`@?2`@("`@("`@#0H@("`@("`@(')E='5R;B`@)'1A
M9SL-"B`@("!]#0H-"B`@("\J*@T*("`@("H@8W)E871E(&$@<W1A<G0@96QE
M;65N=`T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E
M("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!C<F5A=&4@86X@
M6$U,('-T87)T(&5L96UE;G0Z#0H@("`@*B`D=&%G(#T@6$U,7U5T:6PZ.F-R
M96%T95-T87)T16QE;65N="@B;7E.<SIM>51A9R(L(&%R<F%Y*")F;V\B(#T^
M(")B87(B*2`L(FAT='`Z+R]W=W<N=S-C+F]R9R]M>4YS(R(I.PT*("`@("H@
M/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J
M($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1Q;F%M92`@("`@
M("`@("`@("!Q=6%L:69I960@=&%G;F%M92`H:6YC;'5D:6YG(&YA;65S<&%C
M92D-"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1A='1R:6)U=&5S("`@("`@
M("!A<G)A>2!C;VYT86EN9R!A='1R:6)U=&5S#0H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`D;F%M97-P86-E57)I("`@("`@55))(&]F('1H92!N86UE<W!A
M8V4-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1M=6QT:6QI;F4@("`@("`@
M("!W:&5T:&5R('1O(&-R96%T92!A(&UU;'1I;&EN92!T86<@=VAE<F4@96%C
M:"!A='1R:6)U=&4@9V5T<R!W<FET=&5N('1O(&$@<VEN9VQE(&QI;F4-"B`@
M("`J($!P87)A;2`@("!S=')I;F<@("1I;F1E;G0@("`@("`@("`@("!S=')I
M;F<@=7-E9"!T;R!I;F1E;G0@871T<FEB=71E<R`H7V%U=&\@:6YD96YT<R!A
M='1R:6)U=&5S('-O('1H97D@<W1A<G0@870@=&AE('-A;64@8V]L=6UN*0T*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QI;F5B<F5A:R`@("`@("`@('-T
M<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS#0H@("`@*B!`<F5T=7)N("`@<W1R
M:6YG("`D<W1R:6YG("`@("`@("`@("`@6$U,('-T87)T(&5L96UE;G0-"B`@
M("`J($!S964@("`@("!834Q?571I;#HZ8W)E871E16YD16QE;65N="@I+"!8
M34Q?571I;#HZ8W)E871E5&%G*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R
M96%T95-T87)T16QE;65N="@D<6YA;64L("1A='1R:6)U=&5S(#T@87)R87DH
M*2P@)&YA;65S<&%C955R:2`](&YU;&PL("1M=6QT:6QI;F4@/2!F86QS92P@
M)&EN9&5N="`]("=?875T;R<L("1L:6YE8G)E86L@/2`B7&XB*0T*("`@('L-
M"B`@("`@("`@+R\@:68@;F\@871T<FEB=71E<R!H878@8F5E;B!S970L('5S
M92!E;7!T>2!A='1R:6)U=&5S#0H@("`@("`@(&EF("@A:7-S970H)&%T=')I
M8G5T97,I('Q\("%I<U]A<G)A>2@D871T<FEB=71E<RDI('L-"B`@("`@("`@
M("`@("1A='1R:6)U=&5S(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@
M("`-"B`@("`@("`@:68@*"1N86UE<W!A8V55<FD@(3T@;G5L;"D@>PT*("`@
M("`@("`@("`@)'!A<G1S(#T@6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M
M92@D<6YA;64I.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@8VAE8VL@9F]R
M(&UU;'1I;&EN92!A='1R:6)U=&5S#0H@("`@("`@(&EF("@D;75L=&EL:6YE
M(#T]/2!T<G5E*2![#0H@("`@("`@("`@("!I9B`H)&EN9&5N="`]/3T@(E]A
M=71O(BD@>PT*("`@("`@("`@("`@("`@("1I;F1E;G0@/2!S=')?<F5P96%T
M*"(@(BP@*'-T<FQE;B@D<6YA;64I*S(I*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*#0H@("`@("`@(&EF("@D;F%M97-P86-E57)I("$](&YU;&PI
M('L-"B`@("`@("`@("`@("\O(&ES(&$@;F%M97-P86-E(&=I=F5N#0H@("`@
M("`@("`@("!I9B`H:7-S970H)'!A<G1S6R)N86UE<W!A8V4B72D@)B8@(65M
M<'1Y*"1P87)T<ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@("`@("`@("`@
M)&%T=')I8G5T97-;(GAM;&YS.B(N)'!A<G1S6R)N86UE<W!A8V4B75T@/2`D
M;F%M97-P86-E57)I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`O+R!D969I;F4@=&AI<R!5<FD@87,@=&AE(&1E9F%U;'0@;F%M
M97-P86-E#0H@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;(GAM;&YS(ET@
M/2`D;F%M97-P86-E57)I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-
M"B`@("`@("`@+R\@8W)E871E(&%T=')I8G5T92!L:7-T#0H@("`@("`@("1A
M='1,:7-T("`@(#T@("!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A
M='1R:6)U=&5S+"!T<G5E+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R
M96%K*3L-"B`@("`@("`@)&5L96UE;G0@("`@/2`@('-P<FEN=&8H(CPE<R5S
M/B(L("1Q;F%M92P@)&%T=$QI<W0I.PT*("`@("`@("!R971U<FX@("1E;&5M
M96YT.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@86X@96YD(&5L
M96UE;G0-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC
M92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N
M(%A-3"!S=&%R="!E;&5M96YT.@T*("`@("H@)'1A9R`](%A-3%]5=&EL.CIC
M<F5A=&5%;F1%;&5M96YT*")M>4YS.FUY5&%G(BD[#0H@("`@*B`\+V-O9&4^
M#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I
M8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'%N86UE("`@("`@("`@("`@
M('%U86QI9FEE9"!T86=N86UE("AI;F-L=61I;F<@;F%M97-P86-E*0T*("`@
M("H@0')E='5R;B`@('-T<FEN9R`@)'-T<FEN9R`@("`@("`@("`@(%A-3"!E
M;F0@96QE;65N=`T*("`@("H@0'-E92`@("`@(%A-3%]5=&EL.CIC<F5A=&53
M=&%R=$5L96UE;G0H*2P@6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!C<F5A=&5%;F1%;&5M96YT*"1Q;F%M92D-"B`@("![
M#0H@("`@("`@("1E;&5M96YT("`@(#T@("!S<')I;G1F*"(\+R5S/B(L("1Q
M;F%M92D[#0H@("`@("`@(')E='5R;B`@)&5L96UE;G0[#0H@("`@?0T*("`@
M(`T*("`@+RHJ#0H@("`@*B!C<F5A=&4@86X@6$U,(&-O;6UE;G0-"B`@("`J
M#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN
M<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!S=&%R="!E
M;&5M96YT.@T*("`@("H@)'1A9R`](%A-3%]5=&EL.CIC<F5A=&5#;VUM96YT
M*"))(&%M(&$@8V]M;65N="(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("1C;VYT96YT("`@("`@("`@("!C;VYT96YT(&]F
M('1H92!C;VUM96YT#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D8V]M;65N
M="`@("`@("`@("`@6$U,(&-O;6UE;G0-"B`@("`J+PT*("`@(&9U;F-T:6]N
M(&-R96%T94-O;6UE;G0H)&-O;G1E;G0I#0H@("`@>PT*("`@("`@("`D8V]M
M;65N="`@("`]("`@<W!R:6YT9B@B/"$M+2`E<R`M+3XB+"`D8V]N=&5N="D[
M#0H@("`@("`@(')E='5R;B`@)&-O;6UE;G0[#0H@("`@?0T*("`@(`T*("`@
M+RHJ#0H@("`@*B!C<F5A=&4@82!#1&%T82!S96-T:6]N#0H@("`@*@T*("`@
M("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[
M#0H@("`@*B`-"B`@("`J("\O(&-R96%T92!A($-$871A('-E8W1I;VX-"B`@
M("`J("1T86<@/2!834Q?571I;#HZ8W)E871E0T1A=&%396-T:6]N*"))(&%M
M(&-O;G1E;G0N(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@)&1A=&$@("`@("`@("`@("`@(&1A=&$@;V8@=&AE($-$871A
M('-E8W1I;VX-"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@("`@
M("`@("`@("!#1&%T82!S96-T:6]N('=I=&@@8V]N=&5N=`T*("`@("HO#0H@
M("`@9G5N8W1I;VX@8W)E871E0T1A=&%396-T:6]N*"1D871A*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N("!S<')I;G1F*"(\(5M#1$%405LE<UU=/B(L("1D
M871A*3L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@<W!L:70@<75A;&EF:65D
M(&YA;64@86YD(')E='5R;B!N86UE<W!A8V4@86YD(&QO8V%L('!A<G0-"B`@
M("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T
M:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@<W!L:70@<75A;&EF:65D('1A
M9PT*("`@("H@)'!A<G1S(#T@6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M
M92@B>'-L=#IS='EL97-H965T(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*B!T
M:&4@<F5T=7)N960@87)R87D@=VEL;"!C;VYT86EN('1W;R!E;&5M96YT<SH-
M"B`@("`J(#QP<F4^#0H@("`@*B!A<G)A>2@-"B`@("`J("`@("`@(")N86UE
M<W!A8V4B(#T^(")X<VQT(BP-"B`@("`J("`@("`@(")L;V-A;%!A<G0B(#T^
M(")S='EL97-H965T(@T*("`@("H@("`@("`I.PT*("`@("H@/"]P<F4^#0H@
M("`@*@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@
M("`J($!P87)A;2`@<W1R:6YG("`@("1Q;F%M92`@("`@('%U86QI9FEE9"!T
M86<@;F%M90T*("`@("H@0'!A<F%M("!S=')I;F<@("`@)&1E9F%U;'1.<R`@
M9&5F875L="!N86UE<W!A8V4@*&]P=&EO;F%L*0T*("`@("H@0')E='5R;B!A
M<G)A>2`@("`@)'!A<G1S("`@("`@87)R87D@8V]N=&%I;FEN9R!N86UE<W!A
M8V4@86YD(&QO8V%L('!A<G0-"B`@("`J+PT*("`@(&9U;F-T:6]N('-P;&ET
M475A;&EF:65D3F%M92@D<6YA;64L("1D969A=6QT3G,@/2!N=6QL*0T*("`@
M('L-"B`@("`@("`@:68@*'-T<G-T<B@D<6YA;64L("<Z)RDI('L-"B`@("`@
M("`@("`@("1T;7`@/2!E>'!L;V1E*"(Z(BP@)'%N86UE*3L-"B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(FYA;65S<&%C92(@/3X@)'1M<%LP72P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(FQO8V%L4&%R="(@/3X@)'1M<%LQ70T*("`@("`@("`@("`@("`@
M("`@("`@("`@*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("`@(FYA;65S<&%C92(@/3X@)&1E9F%U
M;'1.<RP-"B`@("`@("`@("`@("`@("`@("`@("`B;&]C86Q087)T(B`]/B`D
M<6YA;64-"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("!]#0H-"B`@("\J
M*@T*("`@("H@8VAE8VLL('=H971H97(@<W1R:6YG(&ES('9A;&ED(%A-3"!N
M86UE#0H@("`@*@T*("`@("H@/'`^6$U,(&YA;65S(&%R92!U<V5D(&9O<B!T
M86=N86UE+"!A='1R:6)U=&4@;F%M97,@86YD('9A<FEO=7,-"B`@("`J(&]T
M:&5R+"!L97-S97(@:VYO=VX@96YT:71I97,N/"]P/@T*("`@("H@/'`^06X@
M6$U,(&YA;64@;6%Y(&]N;'D@8V]N<VES="!O9B!A;'!H86YU;65R:6,@8VAA
M<F%C=&5R<RP-"B`@("`J(&1A<VAE<RP@=6YD97-C;W)E<R!A;F0@<&5R:6]D
M<RP@86YD(&AA<R!T;R!S=&%R="!W:71H(&$@;&5T=&5R#0H@("`@*B!O<B!A
M;B!U;F1E<G-C;W)E+@T*("`@("H@/"]P/@T*("`@("H-"B`@("`J(#QC;V1E
M/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@
M#0H@("`@*B`O+R!V97)I9GD@=&%G(&YA;64-"B`@("`J("1R97-U;'0@/2!8
M34Q?571I;#HZ:7-686QI9$YA;64H(FEN=F%L:61486<_(BD[#0H@("`@*B!I
M9B`H6$U,7U5T:6PZ.FES17)R;W(H)')E<W5L="DI('L-"B`@("`J("`@('!R
M:6YT("));G9A;&ED(%A-3"!N86UE.B`B("X@)')E<W5L="T^9V5T365S<V%G
M92@I.PT*("`@("H@?0T*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A
M8V-E<W,@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@
M<W1R:6YG("`D<W1R:6YG('-T<FEN9R!T:&%T('-H;W5L9"!B92!C:&5C:V5D
M#0H@("`@*B!`<F5T=7)N("!M:7AE9"`@("1V86QI9"`@=')U92P@:68@<W1R
M:6YG(&ES(&$@=F%L:60@6$U,(&YA;64L(%!%05(@97)R;W(@;W1H97)W:7-E
M#0H@("`@*B!`=&]D;R`@("!S=7!P;W)T(&9O<B!O=&AE<B!C:&%R<V5T<PT*
M("`@("HO#0H@("`@9G5N8W1I;VX@:7-686QI9$YA;64H)'-T<FEN9RD-"B`@
M("![#0H@("`@("`@("\O(&-H96-K(&9O<B!I;G9A;&ED(&-H87)S#0H@("`@
M("`@(&EF("@A<')E9U]M871C:"@B+UY;6SIA;&YU;3I=7UPM+ETK)"\B+"`D
M<W1R:6YG*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(")834P@;F%M92!M87D@;VYL>2!C;VYT86EN(&%L<&AA;G5M97)I8R!C
M:&%R<RP@<&5R:6]D+"!H>7!H96X@86YD('5N9&5R<V-O<F4B+"!834Q?551)
M3%]%4E)/4E])3E9!3$E$7T-(05)3("D[#0H@("`@("`@('T-"@T*("`@("`@
M("`O+R`@8VAE8VL@9F]R(&EN=F%L:60@<W1A<G1I;F<@8VAA<F%C=&5R#0H@
M("`@("`@(&EF("@A<')E9U]M871C:"@B+UM;.F%L<&AA.EU?72\B+"`D<W1R
M:6YG>S!]*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(")834P@;F%M92!M87D@;VYL>2!S=&%R="!W:71H(&QE='1E<B!O<B!U
M;F1E<G-C;W)E(BP@6$U,7U5424Q?15)23U)?24Y604Q)1%]35$%25"`I.PT*
M("`@("`@("!]#0H-"B`@("`@("`@+R\@6$U,(&YA;64@:7,@=F%L:60-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*?0T*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+UA-3"]397)I86QI>F5R+G!H<```
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0T-C8T`#$P-#$W
M,S8S,#`T`#`R,#8S-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/U!(4`T*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30Z("HO#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`R(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA8FQE(&%T('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R
M<SH@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/B`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK#0HO+PT*+R\@("`@)$ED.B!397)I86QI>F5R+G!H<"QV(#$N,30@
M,C`P,R\Q,"\R-B`Q.3HS.#HR,2!S8VAS="!%>'`@)`T*#0HO*BH-"B`J('5S
M97,@4$5!4B!E<G)O<B!M86YA9V5M96YT#0H@*B\-"G)E<75I<F5?;VYC92`G
M4$5!4BYP:'`G.PT*#0HO*BH-"B`J('5S97,@6$U,7U5T:6P@=&\@8W)E871E
M(%A-3"!T86=S#0H@*B\-"G)E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-
M"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!N;R!S97)I86QI>F%T:6]N(&1O
M;F4-"B`J+PT*9&5F:6YE*")834Q?4T5224%,25I%4E]%4E)/4E].3U]315))
M04Q)6D%424].(BP@-3$I.PT*#0HO*BH-"B`J(%A-3%]397)I86QI>F5R#0H@
M*B!C;&%S<R!T:&%T('-E<FEA;&EZ97,@=F%R:6]U<R!S=')U8W1U<F5S(&EN
M=&\@86X@6$U,(&1O8W5M96YT#0H@*@T*("H@=&AI<R!C;&%S<R!C86X@8F4@
M=7-E9"!I;B!T=V\@;6]D97,Z#0H@*@T*("H@(#$N(&-R96%T92!A;B!834P@
M9&]C=6UE;G0@9G)O;2!A;B!A<G)A>2!O<B!O8FIE8W0@=&AA="!I<R!P<F]C
M97-S960@8GD@;W1H97(-"B`J("`@(&%P<&QI8V%T:6]N<RX@5&AA="!M96%N
M<RP@>6]U(&-A;B!C<F5A=&4@82!21$8@9&]C=6UE;G0@9G)O;2!A;B!A<G)A
M>2!I;B!T:&4-"B`J("`@(&9O;&QO=VEN9R!F;W)M870Z#0H@*@T*("H@("`@
M)&1A=&$@/2!A<G)A>2@-"B`J("`@("`@("`@("`@("`B8VAA;FYE;"(@/3X@
M87)R87DH#0H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`B=&ET;&4B
M(#T^(")%>&%M<&QE(%)$1B!C:&%N;F5L(BP-"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(")L:6YK(B`@/3X@(FAT='`Z+R]W=W<N<&AP+71O;VQS
M+F1E(BP-"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(")I;6%G92(@
M/3X@87)R87DH#0H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`B=&ET;&4B(#T^(")%>&%M<&QE(&EM86=E(BP-"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")U<FPB("`@/3X@
M(FAT='`Z+R]W=W<N<&AP+71O;VQS+F1E+VEM86=E+F=I9B(L#0H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B;&EN:R(@(#T^
M(")H='1P.B\O=W=W+G!H<"UT;V]L<RYD92(-"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL#0H@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@-"B`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(G1I=&QE(B`]/B`B17AA;7!L92!I=&5M(BP-"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(FQI;FLB("`]/B`B
M:'1T<#HO+V5X86UP;&4N8V]M(@T*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`I+`T*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH#0H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")T
M:71L92(@/3X@(D%N;W1H97(@17AA;7!L92!I=&5M(BP-"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(FQI;FLB("`]/B`B:'1T<#HO+V5X
M86UP;&4N;W)G(@T*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`I#0H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D-"B`J("`@
M("`@("`@("`@("D[#0H@*@T*("H@("!T;R!C<F5A=&4@82!21$8@9&]C=6UE
M;G0@9G)O;2!T:&ES(&%R<F%Y(&1O('1H92!F;VQL;W=I;F<Z#0H@*@T*("H@
M("!R97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<[#0H@*@T*("H@
M("`D;W!T:6]N<R`](&%R<F%Y*`T*("H@("`@("`@("`@("`@("`@("`@("`B
M:6YD96YT(B`@("`@("`@(#T^(")<="(L("`@("`@("`O+R!I;F1E;G0@=VET
M:"!T86)S#0H@*B`@("`@("`@("`@("`@("`@("`@(")L:6YE8G)E86LB("`@
M("`@/3X@(EQN(BP@("`@("`@("\O('5S92!53DE8(&QI;F4@8G)E86MS#0H@
M*B`@("`@("`@("`@("`@("`@("`@(")R;V]T3F%M92(@("`@("`@/3X@(G)D
M9CI21$8B+"`@("\O(')O;W0@=&%G#0H@*B`@("`@("`@("`@("`@("`@("`@
M(")D969A=6QT5&%G3F%M92(@/3X@(FET96TB("`@("`@("\O('1A9R!F;W(@
M=F%L=65S('=I=&@@;G5M97)I8R!K97ES#0H@*B`@("D[#0H@*@T*("H@("`D
M<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD[#0H@
M*B`@("1R9&8@("`@("`@(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9&%T
M82D[#0H@*@T*("H@66]U('=I;&P@9V5T(&$@8V]M<&QE=&4@6$U,(&1O8W5M
M96YT('1H870@8V%N(&)E('!R;V-E<W-E9"!L:6ME(&%N>2!21$8@9&]C=6UE
M;G0N#0H@*@T*("H-"B`J(#(N('1H:7,@8VQA<W-E<R!C86X@8F4@=7-E9"!T
M;R!S97)I86QI>F4@86YY(&1A=&$@<W1R=6-T=7)E(&EN(&$@=V%Y('1H870@
M:70@8V%N#0H@*B`@("!L871E<B!B92!U;G-E<FEA;&EZ960@86=A:6XN#0H@
M*B`@("!834Q?4V5R:6%L:7IE<B!W:6QL('-T;W)E('1H92!T>7!E(&]F('1H
M92!V86QU92!A;F0@861D:71I;VYA;"!M971A(&EN9F]R;6%T:6]N#0H@*B`@
M("!I;B!A='1R:6)U=&5S(&]F('1H92!S=7)R;W5N9&EN9R!T86<N(%1H:7,@
M;65A="!I;F9O<FUA=&EO;B!C86X@;&%T97(@8F4@=7-E9`T*("H@("`@=&\@
M<F5S=&]R92!T:&4@;W)I9VEN86P@9&%T82!S=')U8W1U<F4@:6X@4$A0+B!)
M9B!Y;W4@=V%N="!834Q?4V5R:6%L:7IE<@T*("H@("`@=&\@861D(&UE=&$@
M:6YF;W)M871I;VX@=&\@=&AE('1A9W,L(&%D9`T*("H-"B`J("`@("`@(G1Y
M<&5(:6YT<R(@/3X@=')U90T*("H-"B`J("`@('1O('1H92!O<'1I;VYS(&%R
M<F%Y(&EN('1H92!C;VYS=')U8W1O<BX-"B`J#0H@*B`@("!&=71U<F4@=F5R
M<VEO;G,@;V8@=&AI<R!P86-K86=E('=I;&P@:6YC;'5D92!A;B!834Q?56YS
M97)I86QI>F5R+"!T:&%T(&1O97,-"B`J("`@('1H92!U;G-E<FEA;&EZ871I
M;VX@875T;VUA=&EC86QL>2!F;W(@>6]U+@T*("H-"B`J($!C871E9V]R>2!8
M34P-"B`J($!P86-K86=E("!834Q?4V5R:6%L:7IE<@T*("H@0'9E<G-I;VX@
M(#`N.2XQ#0H@*B!`875T:&]R("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@T*("H@0'5S97,@("`@(%A-3%]5=&EL#0H@*B\-"F-L87-S(%A-
M3%]397)I86QI>F5R(&5X=&5N9',@4$5!4B![#0H-"B`@("\J*@T*("`@("H@
M9&5F875L="!O<'1I;VYS(&9O<B!T:&4@<V5R:6%L:7IA=&EO;@T*("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@*B!`=F%R(&%R<F%Y("1?9&5F875L=$]P
M=&EO;G,-"B`@("`J+PT*("`@('9A<B`D7V1E9F%U;'1/<'1I;VYS(#T@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@(FEN9&5N="(@("`@("`@
M("`@("`@/3X@(B(L("`@("`@("`@("`@("`@("`@("`O+R!S=')I;F<@=7-E
M9"!F;W(@:6YD96YT871I;VX-"B`@("`@("`@("`@("`@("`@("`@("`@("`B
M;&EN96)R96%K(B`@("`@("`@("`]/B`B7&XB+"`@("`@("`@("`@("`@("`@
M("\O('-T<FEN9R!U<V5D(&9O<B!N97=L:6YE<PT*("`@("`@("`@("`@("`@
M("`@("`@("`@(")T>7!E2&EN=',B("`@("`@("`@(#T^(&9A;'-E+"`@("`@
M("`@("`@("`@("`@+R\@875T;VUA=&EC86QL>2!A9&0@='EP92!H:6X@871T
M<FEB=71E<PT*("`@("`@("`@("`@("`@("`@("`@("`@(")A9&1$96-L(B`@
M("`@("`@("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@861D(&%N
M(%A-3"!D96-L87)A=&EO;@T*("`@("`@("`@("`@("`@("`@("`@("`@(")D
M969A=6QT5&%G3F%M92(@("`@(#T^(")834Q?4V5R:6%L:7IE<E]486<B+"`@
M+R\@=&%G('5S960@9F]R(&EN9&5X960@87)R87ES(&]R(&EN=F%L:60@;F%M
M97,-"B`@("`@("`@("`@("`@("`@("`@("`@("`B:V5Y071T<FEB=71E(B`@
M("`@("`]/B`B7V]R:6=I;F%L2V5Y(BP@("`@("`@("\O(&%T=')I8G5T92!W
M:&5R92!O<FEG:6YA;"!K97D@:7,@<W1O<F5D#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@(G1Y<&5!='1R:6)U=&4B("`@("`@/3X@(E]T>7!E(BP@("`@
M("`@("`@("`@("`O+R!A='1R:6)U=&4@9F]R('1Y<&4@*&]N;'D@:68@='EP
M94AI;G1S(#T^('1R=64I#0H@("`@("`@("`@("`@("`@("`@("`@("`@(F-L
M87-S071T<FEB=71E(B`@("`@/3X@(E]C;&%S<R(L("`@("`@("`@("`@("`O
M+R!A='1R:6)U=&4@9F]R(&-L87-S(&]F(&]B:F5C=',@*&]N;'D@:68@='EP
M94AI;G1S(#T^('1R=64I#0H)"0D)"0D@(G-C86QA<D%S071T<FEB=71E<R(@
M/3X@9F%L<V4L("`@("`@("`@("`@("`@("`O+R!S8V%L87(@=F%L=65S("AS
M=')I;F=S+"!I;G1S+"XN*2!W:6QL(&)E('-E<FEA;&EZ960@87,@871T<FEB
M=71E#0H@("`@("`@("`@("`@("`@("`@("`@("`@(G!R97!E;F1!='1R:6)U
M=&5S(B`@/3X@(B(L("`@("`@("`@("`@("`@("`@("`O+R!P<F5P96YD('-T
M<FEN9R!F;W(@871T<FEB=71E<PT*("`@("`@("`@("`@("`@("`@("`@("`@
M(")I;F1E;G1!='1R:6)U=&5S(B`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@
M("`@+R\@:6YD96YT('1H92!A='1R:6)U=&5S+"!I9B!S970@=&\@)U]A=71O
M)RP@:70@=VEL;"!I;F1E;G0@871T<FEB=71E<R!S;R!T:&5Y(&%L;"!S=&%R
M="!A="!T:&4@<V%M92!C;VQU;6X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`B;6]D92(@("`@("`@("`@("`@("`]/B`G9&5F875L="<L("`@("`@("`@
M("`@("\O('5S92`G<VEM<&QE>&UL)R!T;R!U<V4@<&%R96YT(&YA;64@87,@
M=&%G;F%M92!I9B!T<F%N<V9O<FUI;F<@86X@:6YD97AE9"!A<G)A>0T*("`@
M("`@("`@("`@("`@("`@("`@("`@(")A9&1$;V-T>7!E(B`@("`@("`@(#T^
M(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@861D(&$@9&]C='EP92!D96-L
M87)A=&EO;@T*("`@("`@("`@("`@("`@("`@("`@("`@(")D;V-T>7!E(B`@
M("`@("`@("`@(#T^(&YU;&PL("`@("`@("`@("`@("`@("`@+R\@<W5P<&QY
M(&$@<W1R:6YG(&]R(&%N(&%R<F%Y('=I=&@@:60@86YD('5R:2`H>T!S964@
M6$U,7U5T:6PZ.F=E=$1O8W1Y<&5$96-L87)A=&EO;B@I?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@(")R;V]T071T<FEB=71E<R(@("`@(#T^(&%R<F%Y
M*"D@("`@("`@("`@("`@("`@+R\@871T<FEB=71E<R!O9B!T:&4@<F]O="!T
M86<-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("\J*@T*("`@
M("H@;W!T:6]N<R!F;W(@=&AE('-E<FEA;&EZ871I;VX-"B`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("H@0'9A<B!A<G)A>2`D;W!T:6]N<PT*("`@("HO
M#0H@("`@=F%R("1O<'1I;VYS(#T@87)R87DH*3L-"@T*("`@+RHJ#0H@("`@
M*B!C=7)R96YT('1A9R!D97!T:`T*("`@("H@0'9A<B!I;G1E9V5R("1?=&%G
M1&5P=&@-"B`@("`J+PT*("`@('9A<B`D7W1A9T1E<'1H(#T@,#L-"@T*("`@
M+RHJ#0H@("`@*B!S97)I;&EA;&EZ960@<F5P<F5S96YT871I;VX@;V8@=&AE
M(&1A=&$-"B`@("`J($!V87(@<W1R:6YG("1?<V5R:6%L:7IE9$1A=&$-"B`@
M("`J+PT*("`@('9A<B`D7W-E<FEA;&EZ961$871A(#T@;G5L;#L-"B`@("`-
M"B`@("\J*@T*("`@("H@8V]N<W1R=6-T;W(-"B`@("`J#0H@("`@*B!`86-C
M97-S("`@<'5B;&EC#0H@("`@*B!`<&%R86T@("`@;6EX960@("`D;W!T:6]N
M<R`@("!A<G)A>2!C;VYT86EN:6YG(&]P=&EO;G,@9F]R('1H92!S97)I86QI
M>F%T:6]N#0H@("`@*B\-"B`@("!F=6YC=&EO;B!834Q?4V5R:6%L:7IE<B@@
M)&]P=&EO;G,@/2!N=6QL("D-"B`@("![#0H@("`@("`@("1T:&ES+3Y014%2
M*"D[#0H@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI('L-"B`@("`@
M("`@("`@("1T:&ES+3YO<'1I;VYS(#T@87)R87E?;65R9V4H)'1H:7,M/E]D
M969A=6QT3W!T:6]N<RP@)&]P=&EO;G,I.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D=&AI<RT^7V1E9F%U;'1/
M<'1I;VYS.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(')E
M='5R;B!!4$D@=F5R<VEO;@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!R971U<FX@("!S=')I;F<@("1V
M97)S:6]N($%022!V97)S:6]N#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A<&E6
M97)S:6]N*"D-"B`@("![#0H)"7)E='5R;B`B,"XY(CL-"B`@("!]#0H-"B`@
M("\J*@T*("`@("H@<F5S970@86QL(&]P=&EO;G,@=&\@9&5F875L="!O<'1I
M;VYS#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-E
M92`@("`@('-E=$]P=&EO;B@I+"!834Q?56YS97)I86QI>F5R*"D-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(')E<V5T3W!T:6]N<R@I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^;W!T:6]N<R`]("1T:&ES+3Y?9&5F875L=$]P=&EO;G,[#0H@
M("`@?0T*#0H@("`O*BH-"B`@("`J('-E="!A;B!O<'1I;VX-"B`@("`J#0H@
M("`@*B!9;W4@8V%N('5S92!T:&ES(&UE=&AO9"!I9B!Y;W4@9&\@;F]T('=A
M;G0@=&\@<V5T(&%L;"!O<'1I;VYS(&EN('1H92!C;VYS=')U8W1O<@T*("`@
M("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S964@("`@("!R
M97-E=$]P=&EO;B@I+"!834Q?4V5R:6%L:7IE<B@I#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!S971/<'1I;VXH)&YA;64L("1V86QU92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3YO<'1I;VYS6R1N86UE72`]("1V86QU93L-"B`@("!]#0H@
M("`@#0H@("`O*BH-"B`@("`J('-E<FEA;&EZ92!D871A#0H@("`@*@T*("`@
M("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'!A<F%M("`@(&UI>&5D("`@
M("1D871A(&1A=&$@=&\@<V5R:6%L:7IE#0H@("`@*B!`<F5T=7)N("`@8F]O
M;&5A;B`@=')U92!O;B!S=6-C97-S+"!P96%R(&5R<F]R(&]N(&9A:6QU<F4-
M"B`@("`J+PT*("`@(&9U;F-T:6]N('-E<FEA;&EZ92@D9&%T82P@)&]P=&EO
M;G,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@+R\@:68@;W!T:6]N<R!H879E
M(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE;2!I;G-T96%D#0H@("`@("`@("\O
M(&]F('1H92!P<F5V:6]U<VQY(&1E9FEN960@;VYE<PT*("`@("`@("!I9B`H
M:7-?87)R87DH)&]P=&EO;G,I*2![#0H@("`@("`@("`@("`D;W!T:6]N<T)A
M:R`]("1T:&ES+3YO<'1I;VYS.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1O
M<'1I;VYS6R)O=F5R<FED94]P=&EO;G,B72D@)B8@)&]P=&EO;G-;(F]V97)R
M:61E3W!T:6]N<R)=(#T]('1R=64I('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?9&5F875L=$]P=&EO
M;G,L("1O<'1I;VYS*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI<RT^
M;W!T:6]N<RP@)&]P=&EO;G,I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@)&]P=&EO;G-"86L@/2!N
M=6QL.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("`O+R!M86EN=&%I
M;B!"0PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;(G1A9TYA
M;64B72DI('L-"B`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS6R)R;V]T3F%M
M92)=(#T@)'1H:7,M/F]P=&EO;G-;(G1A9TYA;64B73L-"B`@("`@("`@?0T*
M("`@("`@("`-"B`@("`@("`@+R\@('-T87)T(&1E<'1H(&ES('IE<F\-"B`@
M("`@("`@)'1H:7,M/E]T86=$97!T:"`](#`[#0H-"B`@("`@("`@)'1H:7,M
M/E]S97)I86QI>F5D1&%T82`]("(B.PT*("`@("`@("`O+R!S97)I86QI>F4@
M86X@87)R87D-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1D871A*2D@>PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6R)R;V]T3F%M92)=
M*2D@>PT*("`@("`@("`@("`@("`@("1T86=.86UE(#T@)'1H:7,M/F]P=&EO
M;G-;(G)O;W1.86UE(ET[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1T86=.86UE(#T@(F%R<F%Y(CL-"B`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`N/2`D=&AI
M<RT^7W-E<FEA;&EZ94%R<F%Y*"1D871A+"`D=&%G3F%M92P@)'1H:7,M/F]P
M=&EO;G-;(G)O;W1!='1R:6)U=&5S(ETI.PT*("`@("`@("!]#0H@("`@("`@
M("\O('-E<FEA;&EZ92!A;B!O8FIE8W0-"B`@("`@("`@96QS96EF("AI<U]O
M8FIE8W0H)&1A=&$I*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F]P=&EO;G-;(G)O;W1.86UE(ETI*2![#0H@("`@("`@("`@("`@("`@)'1A
M9TYA;64@/2`D=&AI<RT^;W!T:6]N<ULB<F]O=$YA;64B73L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1A9TYA;64@/2!G971?
M8VQA<W,H)&1A=&$I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H
M:7,M/E]S97)I86QI>F5D1&%T82`N/2`D=&AI<RT^7W-E<FEA;&EZ94]B:F5C
M="@D9&%T82P@)'1A9TYA;64L("1T:&ES+3YO<'1I;VYS6R)R;V]T071T<FEB
M=71E<R)=*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@861D
M(&1O8W1Y<&4@9&5C;&%R871I;VX-"B`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6R)A9&1$;V-T>7!E(ET@/3T]('1R=64I('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/2!834Q?571I;#HZ9V5T1&]C='EP941E
M8VQA<F%T:6]N*"1T86=.86UE+"`D=&AI<RT^;W!T:6]N<ULB9&]C='EP92)=
M*0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES
M+3YO<'1I;VYS6R)L:6YE8G)E86LB70T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$[#0H@("`@
M("`@('T-"@T*("`@("`@("`O+R`@8G5I;&0@>&UL(&1E8VQA<F%T:6]N#0H@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULB861D1&5C;")=*2![#0H@("`@
M("`@("`@("`D871T<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/F]P=&EO;G-;(F5N8V]D:6YG(ETI("D@>PT*("`@("`@("`@
M("`@("`@("1E;F-O9&EN9R`]("1T:&ES+3YO<'1I;VYS6R)E;F-O9&EN9R)=
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D96YC
M;V1I;F<@/2!N=6QL.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H
M:7,M/E]S97)I86QI>F5D1&%T82`](%A-3%]5=&EL.CIG971834Q$96-L87)A
M=&EO;B@B,2XP(BP@)&5N8V]D:6YG*0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N("1T:&ES+3YO<'1I;VYS6R)L:6YE8G)E86LB70T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3Y?
M<V5R:6%L:7IE9$1A=&$[#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@
M(`T*"0EI9B`H)&]P=&EO;G-"86L@(3T](&YU;&PI('L-"@D)"21T:&ES+3YO
M<'1I;VYS(#T@)&]P=&EO;G-"86L[#0H)"7T-"@D)#0H@("`@("`@(')E='5R
M;B`@=')U93L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@("!G970@=&AE(')E
M<W5L="!O9B!T:&4@<V5R:6%L:7IA=&EO;@T*("`@("H-"B`@("`J("`@0&%C
M8V5S<R!P=6)L:6,-"B`@("`J("`@0')E='5R;B!S=')I;F<@("1S97)I86QI
M>F5D1&%T80T*("`@("HO#0H@("`@("`@(&9U;F-T:6]N(&=E=%-E<FEA;&EZ
M961$871A*"D-"B`@("`@("`@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M<V5R:6%L:7IE9$1A=&$@/3T@;G5L;"`I('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@("1T:&ES+3YR86ES945R<F]R*").;R!S97)I86QI>F5D(&1A=&$@
M879A:6QA8FQE+B!5<V4@6$U,7U-E<FEA;&EZ97(Z.G-E<FEA;&EZ92@I(&9I
M<G-T+B(L(%A-3%]315))04Q)6D527T524D]27TY/7U-%4DE!3$E:051)3TXI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<V5R:6%L:7IE9$1A=&$[#0H@("`@("`@('T-"B`@("`-"B`@("\J*@T*("`@
M("H@<V5R:6%L:7IE(&%N>2!V86QU90T*("`@("H-"B`@("`J(%1H:7,@;65T
M:&]D(&-H96-K<R!F;W(@=&AE('1Y<&4@;V8@=&AE('9A;'5E(&%N9"!C86QL
M<R!T:&4@87!P<F]P<FEA=&4@;65T:&]D#0H@("`@*@T*("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@*B!`<&%R86T@(&UI>&5D("`@("`D=F%L=64-"B`@
M("`J($!P87)A;2`@<W1R:6YG("`@("1T86=.86UE#0H@("`@*B!`<&%R86T@
M(&%R<F%Y("`@("`D871T<FEB=71E<PT*("`@("H@0')E='5R;B!S=')I;F<-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(%]S97)I86QI>F5686QU92@D=F%L=64L
M("1T86=.86UE(#T@;G5L;"P@)&%T=')I8G5T97,@/2!A<G)A>2@I*0T*("`@
M('L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L-"B`@("`@("`@
M("`@("1X;6P@/2`D=&AI<RT^7W-E<FEA;&EZ94%R<F%Y*"1V86QU92P@)'1A
M9TYA;64L("1A='1R:6)U=&5S*3L-"B`@("`@("`@?2!E;'-E:68@*&ES7V]B
M:F5C="@D=F%L=64I*2![#0H@("`@("`@("`@("`D>&UL(#T@)'1H:7,M/E]S
M97)I86QI>F5/8FIE8W0H)'9A;'5E+"`D=&%G3F%M92D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@(")Q;F%M92(@("`@("`]/B`D=&%G3F%M92P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B(#T^("1A='1R
M:6)U=&5S+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`B8V]N=&5N="(@
M("`@/3X@)'9A;'5E#0H@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@
M("`@("`@("`@)'AM;"`]("1T:&ES+3Y?8W)E871E6$U,5&%G*"1T86<I.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B`D>&UL.PT*("`@('T-"B`@("`-
M"B`@("\J*@T*("`@("H@<V5R:6%L:7IE(&%N(&%R<F%Y#0H@("`@*@T*("`@
M("H@0&%C8V5S<R`@('!R:79A=&4-"B`@("`J($!P87)A;2`@("!A<G)A>2`@
M("1A<G)A>2`@("`@("!A<G)A>2!T;R!S97)I86QI>F4-"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("1T86=.86UE("`@("!N86UE(&]F('1H92!R;V]T('1A
M9PT*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@)&%T=')I8G5T97,@(&%T=')I
M8G5T97,@9F]R('1H92!R;V]T('1A9PT*("`@("H@0')E='5R;B`@('-T<FEN
M9R`@)'-T<FEN9R`@("`@('-E<FEA;&EZ960@9&%T80T*("`@("H@0'5S97,@
M("`@(%A-3%]5=&EL.CII<U9A;&ED3F%M92@I('1O(&-H96-K+"!W:&5T:&5R
M(&ME>2!H87,@=&\@8F4@<W5B<W1I='5T960-"B`@("`J+PT*("`@(&9U;F-T
M:6]N(%]S97)I86QI>F5!<G)A>2@F)&%R<F%Y+"`D=&%G3F%M92`](&YU;&PL
M("1A='1R:6)U=&5S(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@(&EF("AI
M<U]A<G)A>2@D87)R87DI("8F("1T:&ES+3YO<'1I;VYS6R)M;V1E(ET@/3T@
M(G-I;7!L97AM;"(I('L-"B`@("`@("`@("`@("1I;F1E>&5D(#T@=')U93L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86PI
M('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7VEN="@D:V5Y*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D:6YD97AE9"`](&9A;'-E.PT*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H-"B`@("`@("`@("`@(&EF("@D:6YD97AE9"D@>PT*("`@("`@
M("`@("`@("`@("1S=')I;F<@/2`B(CL-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L*2![#0H@("`@("`@("`@("`@
M("`@("`@("1S=')I;F<@+CT@)'1H:7,M/E]S97)I86QI>F5686QU92@@)'9A
M;"P@)'1A9TYA;64L("1A='1R:6)U=&5S*3L-"B`@("`@("`@("`@("`@("`@
M("`@#0H@("`@("`@("`@("`@("`@("`@("1S=')I;F<@+CT@)'1H:7,M/F]P
M=&EO;G-;(FQI;F5B<F5A:R)=.PT*("`@("`@("`)"0DO+PED;R!I;F1E;G1A
M=&EO;@T*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M(FEN9&5N=")=(3T];G5L;"`F)B`D=&AI<RT^7W1A9T1E<'1H/C`I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@+CT@<W1R7W)E<&5A="@D
M=&AI<RT^;W!T:6]N<ULB:6YD96YT(ETL("1T:&ES+3Y?=&%G1&5P=&@I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(')E='5R;B!R=')I;2@D<W1R:6YG*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@)'1H:7,M/E]T
M86=$97!T:"LK.PT*#0H)"6EF("@D=&AI<RT^;W!T:6]N<ULB<V-A;&%R07-!
M='1R:6)U=&5S(ET@/3T]('1R=64I('L-"@D@("`@("`@(&9O<F5A8V@@*"1A
M<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PT*"0D)"6EF("AI<U]S8V%L87(H
M)'9A;'5E*2`F)B`H6$U,7U5T:6PZ.FES5F%L:61.86UE*"1K97DI(#T]/2!T
M<G5E*2D@>PT*"0D)"0EU;G-E="@D87)R87E;)&ME>5TI.PT*"0D)"0DD871T
M<FEB=71E<ULD=&AI<RT^;W!T:6]N<ULB<')E<&5N9$%T=')I8G5T97,B72XD
M:V5Y72`]("1V86QU93L-"@D)"0E]#0H)"0E]#0H)"7T-"@T*("`@("`@("`O
M+R!C:&5C:R!F;W(@96UP='D@87)R87D@/3X@8W)E871E(&5M<'1Y('1A9PT*
M("`@("`@("!I9B`H96UP='DH)&%R<F%Y*2D@>PT*("`@("`@("`-"B`@("`@
M("`@?0T*"0D-"B`@("`@("`@)'1M<"`]("1T:&ES+3YO<'1I;VYS6R)L:6YE
M8G)E86LB73L-"B`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@
M)'9A;'5E*2![#0H)"0DO+PED;R!I;F1E;G1A=&EO;@T*("`@("`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6R)I;F1E;G0B72$]/6YU;&P@)B8@)'1H:7,M
M/E]T86=$97!T:#XP*2![#0H@("`@("`@("`@("`@("`@)'1M<"`N/2!S=')?
M<F5P96%T*"1T:&ES+3YO<'1I;VYS6R)I;F1E;G0B72P@)'1H:7,M/E]T86=$
M97!T:"D[#0H@("`@("`@("`@("!]#0H-"@D)"2\O"6-O<'D@:V5Y#0H)"0DD
M;W)I9TME>0D]"21K97D[#0H)"0DO+PEK97D@8V%N;F]T(&)E('5S960@87,@
M=&%G;F%M92`]/B!U<V4@9&5F875L="!T86<-"B`@("`@("`@("`@("1V86QI
M9"`](%A-3%]5=&EL.CII<U9A;&ED3F%M92@D:V5Y*3L-"@D@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1V86QI9"DI('L-"B`@("`)("`@("`@("`D:V5Y
M(#T@)'1H:7,M/F]P=&EO;G-;(F1E9F%U;'1486=.86UE(ET[#0H@("`@("`@
M"2`)?0T*("`@("`@("`@("`@)&%T=',@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R)T>7!E2&EN=',B72`]/3T@=')U92D@
M>PT*("`@("`@("`@("`@("`@("1A='1S6R1T:&ES+3YO<'1I;VYS6R)T>7!E
M071T<FEB=71E(EU=(#T@9V5T='EP92@D=F%L=64I.PT*"0D)"6EF("@D:V5Y
M("$]/2`D;W)I9TME>2D@>PT*"0D)"0DD871T<ULD=&AI<RT^;W!T:6]N<ULB
M:V5Y071T<FEB=71E(EU=(#T@*'-T<FEN9RDD;W)I9TME>3L-"@D)"0E]#0H-
M"B`@("`@("`@("`@('T-"@D)"0T*("`@("`@("`@("`@)'1M<"`N/2`D=&AI
M<RT^7V-R96%T95A-3%1A9RAA<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(")Q;F%M92(@("`@("`]/B`D
M:V5Y+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(F%T=')I8G5T97,B(#T^("1A='1S+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B
M("`@(#T^("1V86QU92`I#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("1T;7`@+CT@)'1H:7,M/F]P
M=&EO;G-;(FQI;F5B<F5A:R)=.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@
M("`@("`D=&AI<RT^7W1A9T1E<'1H+2T[#0H@("`@("`@(&EF("@D=&AI<RT^
M;W!T:6]N<ULB:6YD96YT(ETA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P=&@^
M,"D@>PT*("`@("`@("`@("`@)'1M<"`N/2!S=')?<F5P96%T*"1T:&ES+3YO
M<'1I;VYS6R)I;F1E;G0B72P@)'1H:7,M/E]T86=$97!T:"D[#0H@("`@("`@
M('T-"@T*"0EI9B`H=')I;2@D=&UP*2`]/3T@)R<I('L-"@D)"21T;7`@/2!N
M=6QL.PT*"0E]#0H)"0T*("`@("`@("`D=&%G(#T@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("`@("`B<6YA;64B("`@("`@/3X@)'1A9TYA;64L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`B8V]N=&5N="(@("`@/3X@)'1M<"P-
M"B`@("`@("`@("`@("`@("`@("`@("`@(")A='1R:6)U=&5S(B`]/B`D871T
M<FEB=71E<PT*("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;(G1Y<&5(:6YT<R)=(#T]/2!T<G5E*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T86=;(F%T=')I8G5T97,B75LD=&AI<RT^
M;W!T:6]N<ULB='EP94%T=')I8G5T92)=72DI('L-"B`@("`@("`@("`@("`@
M("`D=&%G6R)A='1R:6)U=&5S(EU;)'1H:7,M/F]P=&EO;G-;(G1Y<&5!='1R
M:6)U=&4B75T@/2`B87)R87DB.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H-"B`@("`@("`@)'-T<FEN9R`]("1T:&ES+3Y?8W)E871E6$U,5&%G*"1T
M86<L(&9A;'-E*3L-"B`@("`@("`@<F5T=7)N("1S=')I;F<[#0H@("`@?0T*
M#0H@("`O*BH-"B`@("`J('-E<FEA;&EZ92!A;B!O8FIE8W0-"B`@("`J#0H@
M("`@*B!`86-C97-S("`@<')I=F%T90T*("`@("H@0'!A<F%M("`@(&]B:F5C
M="`@)&]B:F5C="!O8FIE8W0@=&\@<V5R:6%L:7IE#0H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG("`D<W1R:6YG('-E<FEA;&EZ960@9&%T80T*("`@("HO#0H@
M("`@9G5N8W1I;VX@7W-E<FEA;&EZ94]B:F5C="@F)&]B:F5C="P@)'1A9TYA
M;64@/2!N=6QL+"`D871T<FEB=71E<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@
M("`@("`O+R`@8VAE8VL@9F]R(&UA9VEC(&9U;F-T:6]N#0H@("`@("`@(&EF
M("AM971H;V1?97AI<W1S*"1O8FIE8W0L(")?7W-L965P(BDI('L-"B`@("`@
M("`@("`@("1O8FIE8W0M/E]?<VQE97`H*3L-"B`@("`@("`@?0T*#0H@("`@
M("`@("1T;7`@/2`D=&AI<RT^;W!T:6]N<ULB;&EN96)R96%K(ET[#0H@("`@
M("`@("1P<F]P97)T:65S(#T@9V5T7V]B:F5C=%]V87)S*"1O8FIE8W0I.PT*
M("`@("`@("!I9B`H96UP='DH)'1A9TYA;64I*2![#0H@("`@("`@("`@("`D
M=&%G3F%M92`](&=E=%]C;&%S<R@D;V)J96-T*3L-"B`@("`@("`@?0T*("`@
M("`@("`-"B`@("`@("`@+R\@='EP96AI;G1S(&%C=&EV871E9#\-"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R)T>7!E2&EN=',B72`]/3T@=')U92D@
M>PT*("`@("`@("`@("`@)&%T=')I8G5T97-;)'1H:7,M/F]P=&EO;G-;(G1Y
M<&5!='1R:6)U=&4B75T@(#T@(F]B:F5C="([#0H@("`@("`@("`@("`D871T
M<FEB=71E<ULD=&AI<RT^;W!T:6]N<ULB8VQA<W-!='1R:6)U=&4B75T@/2`@
M9V5T7V-L87-S*"1O8FIE8W0I.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@
M("`@("`D<W1R:6YG(#T@)'1H:7,M/E]S97)I86QI>F5!<G)A>2@D<')O<&5R
M=&EE<RP@)'1A9TYA;64L("1A='1R:6)U=&5S*3L-"B`@("`@("`@<F5T=7)N
M("1S=')I;F<[#0H@("`@?0T*("`-"B`@("\J*@T*("`@("H@8W)E871E(&$@
M=&%G(&9R;VT@86X@87)R87D-"B`@("`J('1H:7,@;65T:&]D(&%W86ET<R!A
M;B!A<G)A>2!I;B!T:&4@9F]L;&]W:6YG(&9O<FUA=`T*("`@("H@87)R87DH
M#0H@("`@*B`@("`@("`B<6YA;64B("`@("`@("`]/B`D=&%G3F%M92P-"B`@
M("`J("`@("`@(")A='1R:6)U=&5S(B`@(#T^(&%R<F%Y*"DL#0H@("`@*B`@
M("`@("`B8V]N=&5N="(@("`@("`]/B`D8V]N=&5N="P@("`@("`O+R!O<'1I
M;VYA;`T*("`@("H@("`@("`@(FYA;65S<&%C92(@("`@/3X@)&YA;65S<&%C
M92`@("`@+R\@;W!T:6]N86P-"B`@("`J("`@("`@(")N86UE<W!A8V55<FDB
M(#T^("1N86UE<W!A8V55<FD@("\O(&]P=&EO;F%L#0H@("`@*B`@("D-"B`@
M("`J#0H@("`@*B!`86-C97-S("`@<')I=F%T90T*("`@("H@0'!A<F%M("`@
M(&%R<F%Y("`@)'1A9R!T86<@9&5F:6YI=&EO;@T*("`@("H@0'!A<F%M("`@
M(&)O;VQE86X@)')E<&QA8V5%;G1I=&EE<R!W:&5T:&5R('1O(')E<&QA8V4@
M6$U,(&5N=&ET:65S(&EN(&-O;G1E;G0@;W(@;F]T#0H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG("`D<W1R:6YG(%A-3"!T86<-"B`@("`J+PT*("`@(&9U;F-T
M:6]N(%]C<F5A=&5834Q486<H("1T86<L("1R97!L86-E16YT:71I97,@/2!T
M<G5E("D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULB:6YD
M96YT071T<FEB=71E<R)=("$]/2!F86QS92D@>PT*("`@("`@("`@("`@)&UU
M;'1I;&EN92`]('1R=64[#0H@("`@("`@("`@("`D:6YD96YT("`@(#T@<W1R
M7W)E<&5A="@D=&AI<RT^;W!T:6]N<ULB:6YD96YT(ETL("1T:&ES+3Y?=&%G
M1&5P=&@I.PT*#0H@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;(FEN
M9&5N=$%T=')I8G5T97,B72`]/2`B7V%U=&\B*2![#0H@("`@("`@("`@("`@
M("`@)&EN9&5N="`N/2!S=')?<F5P96%T*"(@(BP@*'-T<FQE;B@D=&%G6R)Q
M;F%M92)=*2LR*2D[#0H-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&EN9&5N="`N/2`D=&AI<RT^;W!T:6]N<ULB:6YD96YT071T
M<FEB=71E<R)=.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)&UU;'1I;&EN92`](&9A;'-E.PT*("`@("`@("`@("`@
M)&EN9&5N="`@("`](&9A;'-E.PT*("`@("`@("!]#0H@("`@#0H@("`@("`@
M(&EF("@H<W1R:6YG*21T86=;(F-O;G1E;G0B72`]/2`G)RD@>PT*("`@("`@
M("`@("`@)'1A9ULB8V]N=&5N=")=(#T@("`G)SL-"B`@("`@("`@?2`@("`-
M"B`@("`-"B`@("`@("`@:68@*&ES7W-C86QA<B@D=&%G6R)C;VYT96YT(ETI
M*2![#0H@("`@("`@("`@("`D=&%G(#T@6$U,7U5T:6PZ.F-R96%T951A9T9R
M;VU!<G)A>2@D=&%G+"`D<F5P;&%C945N=&ET:65S+"`D;75L=&EL:6YE+"`D
M:6YD96YT+"`D=&AI<RT^;W!T:6]N<ULB;&EN96)R96%K(ETI.PT*("`@("`@
M("!](&5L<V5I9B`H:7-?87)R87DH)'1A9ULB8V]N=&5N=")=*2D@>PT*("`@
M("`@("`@("`@)'1A9R`@("`]("`@)'1H:7,M/E]S97)I86QI>F5!<G)A>2@D
M=&%G6R)C;VYT96YT(ETL("1T86=;(G%N86UE(ETL("1T86=;(F%T=')I8G5T
M97,B72D[#0H@("`@("`@('T@96QS96EF("AI<U]O8FIE8W0H)'1A9ULB8V]N
M=&5N=")=*2D@>PT*("`@("`@("`@("`@)'1A9R`@("`]("`@)'1H:7,M/E]S
M97)I86QI>F5/8FIE8W0H)'1A9ULB8V]N=&5N=")=+"`D=&%G6R)Q;F%M92)=
M+"`D=&%G6R)A='1R:6)U=&5S(ETI.PT*("`@("`@("!](&5L<V5I9B`H:7-?
M<F5S;W5R8V4H)'1A9ULB8V]N=&5N=")=*2D@>PT*("`@("`@("`@("`@<V5T
M='EP92@D=&%G6R)C;VYT96YT(ETL(")S=')I;F<B*3L-"B`@("`@("`@("`@
M("1T86<@("`@/2`@(%A-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A
M9RP@)')E<&QA8V5%;G1I=&EE<RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("`D=&%G.PT*("`@('T-"GT-"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]4<F5E
M+P``````````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-``P,38R-#``(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U1R964O365M;W)Y+P``````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`Q-S4Q
M,``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O5')E92]-96UO<GDO07)R
M87DN<&AP````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C<U-S4`
M,3`T,3<S-C,P,#0`,#(Q,S$T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%=O;&9R86T@
M2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O
M("`D260Z($%R<F%Y+G!H<"QV(#$N.2`R,#`S+S`S+S$W(#$V.C`R.C4T(&-A
M:6X@17AP("0*"G)E<75I<F5?;VYC92@G5')E92]%<G)O<BYP:'`G*3L*"B\J
M*@HJ("`@15A015))345.5$%,"BH**B`@($!A8V-E<W,@("`@('!U8FQI8PHJ
M("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE
M<VEN9RYD93X**B`@($!V97)S:6]N("`@(#(P,#(O,#@O,S`**B`@($!P86-K
M86=E("`@(%1R964**B\*8VQA<W,@5')E95]-96UO<GE?07)R87D*>PH*("`@
M('9A<B`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@("`*("`@("\J*@H@
M("`@*B`@('1H:7,@:7,@=&AE(&EN=&5R;F%L(&ED('1H870@=VEL;"!B92!A
M<W-I9VYE9"!I9B!N;R!I9"!I<R!G:79E;@H@("`@*B`@(&ET('-I;7!L>2!C
M;W5N=',@9G)O;2`Q+"!S;R!W92!C86X@8VAE8VL@:68H("1I9"`I(&D@86T@
M;&%Z>2`Z+2D*("`@("HO"B`@("!V87(@)%]I9"`](#$["B`@("`*("`@("\J
M*@H@("`@*B`@('-E="!U<"!T:&ES(&]B:F5C=`H@("`@*@H@("`@*B`@($!V
M97)S:6]N("`@(#(P,#(O,#@O,S`*("`@("H@("!`86-C97-S("`@("!P=6)L
M:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF
M<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@("`@('-T<FEN9R`@
M)&1S;B`@("!T:&4@<&%T:"!O;B!T:&4@9FEL97-Y<W1E;0H@("`@*B`@($!P
M87)A;2`@("`@(&%R<F%Y("`@)&]P=&EO;G,@(&%D9&ET:6]N86P@;W!T:6]N
M<R!Y;W4@8V%N('-E=`H@("`@*B\*("`@(&9U;F-T:6]N(%1R965?365M;W)Y
M7T%R<F%Y*"`F)&%R<F%Y("P@)&]P=&EO;G,]87)R87DH*2`I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]A<G)A>2`]("8D87)R87D["B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS(#T@)&]P=&EO;G,[("\O(&YO="!I;B!U<V4@8W5R<F5N=&QY
M"B`@("!]("\O(&5N9"!O9B!F=6YC=&EO;@H*("`@("\J*@H@("`@*@H@("`@
M*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#@O,S`*("`@("H@("!`86-C
M97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR
M:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!R971U<FX@
M("`@(&)O;VQE86X@("`@('1R=64@;VX@<W5C8V5S<PH@("`@*B\*("`@(&9U
M;F-T:6]N('-E='5P*"D*("`@('L*("`@("`@("!U;G-E="@D=&AI<RT^9&%T
M82D[("`@("`@("`@("`@("`@("`@("`@("`@("\O('5N<V5T('1H92!D871A
M('1O(&)E('-U<F4@=&\@9V5T('1H92!R96%L(&1A=&$@86=A:6XL(&YO(&]L
M9"!D871A"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?87)R87DI*2![
M"B`@("`@("`@("`@("1T:&ES+3YD871A6S!=(#T@;G5L;#L*("`@("`@("`@
M("`@)'1H941A=&$@/2!A<G)A>2@F)'1H:7,M/E]A<G)A>2D["B`@("`@("`@
M("`@("1T:&ES+3Y?<V5T=7`H)'1H941A=&$I.PH@("`@("`@('T*"B\J9F]R
M96%C:"@D=&AI<RT^9&%T82!A<R`D=F%L*7MP<FEN="`B7')<;B(["F9O<F5A
M8V@@*"1V86P@87,@)&L]/B1V*0H@("`@<')I;G0@(B1K/3XD=EQR7&XB.PI]
M*B\*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD871A.PH@("`@?0H*("`@
M("\J*@H@("`@*B`@('=E(&UO9&EF>2!T:&4@)'1H:7,M/E]A<G)A>2!I;B!H
M97)E+"!W92!A;'-O(&%D9"!T:&4@:60*("`@("H@("!S;R!M971H;V1S(&QI
M:V4@)V%D9"<@971C(&-A;B!F:6YD('1H92!E;&5M96YT<R!T:&5Y(&%R92!S
M96%R8VAI;F<@9F]R+`H@("`@*B`@(&EF('EO=2!D;VYT(&QI:V4@>6]U<B!D
M871A('1O(&)E(&UO9&EF:65D(&1O;G0@<&%S<R!T:&5M(&%S(')E9F5R96YC
M92$*("`@("HO"B`@("!F=6YC=&EO;B!?<V5T=7`H("8D87)R87D@+"`D<&%R
M96YT260],"`I"B`@("!["B`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1N
M;V1E2V5Y/3XD84YO9&4I('L*("`@("`@("`@("`@)&YE=T1A=&$@/2`D84YO
M9&4["B`@("`@("`@("`@(&EF("@A:7-S970H)&YE=T1A=&%;)VED)UTI('Q\
M("$D;F5W1&%T85LG:60G72D@>R`@("`O+R!I9B!T:&4@8W5R<F5N="!E;&5M
M96YT(&AA<R!N;R!I9"P@=V4@9V5N97)A=&4@;VYE"B`@("`@("`@("`@("`@
M("`D;F5W1&%T85LG:60G72`]("1T:&ES+3Y?:60K*SL@("`@("`O+R!B=6EL
M9"!A('5N:7%U92!N=6UE<FEC(&ED"B`@("`@("`@("`@("`@("`D87)R87E;
M)&YO9&5+97E=6R=I9"==(#T@)&YE=T1A=&%;)VED)UT[("`@("\O('-E="!T
M:&4@:60*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I
M9$%S26YT(#T@*&EN="DD;F5W1&%T85LG:60G73L*("`@("`@("`@("`@("`@
M(&EF("@D:61!<TEN="`^("1T:&ES+3Y?:60I('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VED(#T@)&ED07-);G0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*+R]P<FEN="`B82!N;V1E(&YA;64](BXD84YO9&5;
M)VYA;64G72XG/&)R/B<["B`@("`@("`@("`@("1N97=$871A6R=P87)E;G1)
M9"==(#T@)'!A<F5N=$ED.R`@("`@("`O+R!S970@=&AE('!A<F5N="UI9"P@
M<VEN8V4@=V4@;VYL>2!H879E(&$@)V-H:6QD<F5N)R!A<G)A>0H@("`@("`@
M("`@("`D8VAI;&1R96X@/2!N=6QL.PH@("`@("`@("`@("!F;W)E86-H("@@
M)&YE=T1A=&$@87,@)&ME>3T^)'9A;"`I('L@("`@+R\@<F5M;W9E('1H92`G
M8VAI;&1R96XG(&%R<F%Y+"!S:6YC92!T:&ES(&ES(&]N;'D@:6YF;R!F;W(@
M=&AI<R!C;&%S<PH@("`@("`@("`@("`@("`@:68@*"1K97D]/2=C:&EL9')E
M;B<I('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D;F5W1&%T85LD:V5Y
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&ES+3YD871A6R1N97=$871A6R=I9"==72`]("1N97=$871A.PH@
M("`@("`@("`@("!I9B`H:7-S970H)&%.;V1E6R=C:&EL9')E;B==*2`F)B`D
M84YO9&5;)V-H:6QD<F5N)UTI('L*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&%R<F%Y6R1N;V1E2V5Y75LG8VAI;&1R96XG72DI('L*("`@("`@("`@
M("`@("`@("`@("`D87)R87E;)&YO9&5+97E=6R=C:&EL9')E;B==(#T@87)R
M87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5T=7`H("1A<G)A>5LD;F]D94ME>5U;)V-H:6QD<F5N)UT@+"`D;F5W
M1&%T85LG:60G72`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M"B`@("`O*BH*("`@("H@("!T:&ES(&ES(&UO<W1L>2!U<V5D(&)Y('-W:71C
M:$1A=&%3;W5R8V4*("`@("H@("!T:&ES(&UE=&AO9"!P=70@9&%T82!G;W1T
M96X@9G)O;2!G971.;V1E*"D@:6X@=&AE("1T:&ES+3Y?87)R87D*("`@("H*
M("`@("HO"B`@("!F=6YC=&EO;B!S971$871A*"1D871A*0H@("`@>PHO*@H@
M("`@("`@("1R;V]T(#T@87)R87E?<VAI9G0H)&1A=&$I.PH@("`@("`@('5N
M<V5T*"1R;V]T6R=C:&EL9')E;B==*3L*("`@("`@("`D=&AI<RT^7V%R<F%Y
M(#T@87)R87DH)V-H:6QD<F5N)ST^(&%R<F%Y*"1R;V]T*2D["F9O<F5A8V@@
M*"1T:&ES+3Y?87)R87E;)V-H:6QD<F5N)UU;,%T@87,@)&ME>3T^)'9A;"D*
M("`@('!R:6YT("(D:V5Y/3XD=F%L/&)R/B(["G!R:6YT("(\8G(^(CL**B\*
M("`@("`@("`D=6YS971+97ES(#T@87)R87DH)V-H:6QD260G+"=L969T)RPG
M<FEG:'0G*3L*"B`@("`@("`@9F]R96%C:"`H("1D871A(&%S("1A3F]D92`I
M('L*+R]P<FEN="`D84YO9&5;)VED)UTN)R`Z("<N)&%.;V1E6R=N86UE)UTN
M)R`@<&%R96YT260])RXD84YO9&5;)W!A<F5N=$ED)UTN)R!S:7IE/2<N<VEZ
M96]F*"1T:&ES+3Y?87)R87E;)V-H:6QD<F5N)UU;,%U;)V-H:6QD<F5N)UTI
M+B<\8G(^)SL*("`@("`@("`@("`@9F]R96%C:"`H)&%.;V1E(&%S("1K97D]
M/B1V86PI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2!\
M?"!I;E]A<G)A>2@D:V5Y+"1U;G-E=$ME>7,I*2!["B`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&%.;V1E6R1K97E=*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^861D*"1A3F]D92PD
M84YO9&5;)W!A<F5N=$ED)UTI.PH@("`@("`@('T*+R]F;W)E86-H("@D=&AI
M<RT^7V%R<F%Y6R=C:&EL9')E;B==6S!=6R=C:&EL9')E;B==(&%S("1X*7MP
M<FEN="`B/&)R/B(["B\O9F]R96%C:"`H)'@@87,@)&ME>3T^)'9A;"D*+R\@
M("`@<')I;G0@(B1K97D]/B1V86P\8G(^(CM]"B`@("`@("`@)'1H:7,M/E]A
M<G)A>2`]("1T:&ES+3Y?87)R87E;)V-H:6QD<F5N)UU;,%T["B`@("!]"@H@
M("`@+RHJ"B`@("`J"B`@("`J"B`@("`J("`@0&%C8V5S<R`@("`@<')I=F%T
M90H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#,O,#(*("`@("H@("!`875T
M:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E
M/@H@("`@*B`@($!P87)A;0H@("`@*B`@($!R971U<FX*("`@("HO"B`@("!F
M=6YC=&EO;B!?=&AR;W=%<G)O<B@@)&US9R`L("1L:6YE("P@)&UO9&4];G5L
M;"`I"B`@("!["B`@("`@("`@<F5T=7)N(&YE=R!4<F5E7T5R<F]R*"`D;7-G
M("P@)&QI;F4@+"!?7T9)3$5?7R`L("1M;V1E("P@)'1H:7,M/F1B+3YL87-T
M7W%U97)Y("D["B`@("!]"@H@("`@+RHJ"B`@("`J("`@<')E<&%R92!M=6QT
M:7!L92!R97-U;'1S"B`@("`J"B`@("`J("`@0'-E92`@("`@("`@7W!R97!A
M<F5297-U;'0H*0H@("`@*B`@($!A8V-E<W,@("`@('!R:79A=&4*("`@("H@
M("!`=F5R<VEO;B`@("`R,#`R+S`S+S`S"B`@("`J("`@0&%U=&AO<B`@("`@
M5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@
M("!`<&%R86T*("`@("H@("!`<F5T=7)N"B`@("`J+PH@("`@9G5N8W1I;VX@
M7W!R97!A<F5297-U;'1S*"`D<F5S=6QT<R`I"B`@("!["B`@("`@("`@)&YE
M=U)E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@H("1R97-U;'1S
M(&%S("1A4F5S=6QT("D*("`@("`@("`@("`@)&YE=U)E<W5L='-;72`]("1T
M:&ES+3Y?<')E<&%R95)E<W5L="@D85)E<W5L="D["B`@("`@("`@<F5T=7)N
M("1N97=297-U;'1S.PH@("`@?0H*("`@("\J*@H@("`@*B`@(&UA<"!B86-K
M('1H92!I;F1E>"!N86UE<R!T;R!G970@=VAA="!I<R!E>'!E8W1E9`H@("`@
M*@H@("`@*B`@($!A8V-E<W,@("`@('!R:79A=&4*("`@("H@("!`=F5R<VEO
M;B`@("`R,#`R+S`S+S`S"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+
M<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T*
M("`@("H@("!`<F5T=7)N"B`@("`J+PH@("`@9G5N8W1I;VX@7W!R97!A<F52
M97-U;'0H("1R97-U;'0@*0H@("`@>PH@("`@("`@("1M87`@/2`D=&AI<RT^
M9V5T3W!T:6]N*"=C;VQU;6Y.86UE36%P<R<I.PH*("`@("`@("!I9B@@)&UA
M<"`I"B`@("`@("`@9F]R96%C:"@@)&UA<"!A<R`D:V5Y/3XD8V]L=6UN3F%M
M92`I"B`@("`@("`@>PH@("`@("`@("`@("`D<F5S=6QT6R1K97E=(#T@)')E
M<W5L=%LD8V]L=6UN3F%M95T["B`@("`@("`@("`@('5N<V5T*"1R97-U;'1;
M)&-O;'5M;DYA;65=*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("!]"@H@("`@+RHJ"B`@("`J("`@861D(&$@;F5W(&ET96T@=&\@
M=&AE('1R964*("`@("H@("!W:&%T(&ES('1R:6-K>2!H97)E+"!W92!A;'-O
M(&YE960@=&\@861D(&ET('1O('1H92!S;W5R8V4@87)R87D*("`@("H@("`*
M("`@("H@("!`<&%R86T@(&%R<F%Y("`@=&AE(&1A=&$@9F]R('1H92!N97<@
M;F]D90H@("`@*B`@($!P87)A;2`@:6YT("`@("!T:&4@240@;V8@=&AE('!A
M<F5N="!N;V1E"B`@("`J("`@0'!A<F%M("!I;G0@("`@('1H92!)1"!O9B!T
M:&4@<')E=FEO=7,@;F]D90H@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@@)&1A
M=&$@+"`D<&%R96YT260@+"`D<')E=FEO=7-)9#UN=6QL("D*("`@('L*("`@
M("`@("!I9B`H(6ES<V5T*"1D871A6R=I9"==*2D@>PH@("`@("`@("`@("`D
M9&%T85LG:60G72`]("LK)'1H:7,M/E]I9#L*("`@("`@("!](&5L<V5I9B@H
M:6YT*21D871A6R=I9"==(#X@)'1H:7,M/E]I9"D@>PH@("`@("`@("`@("`O
M+R!U<&1A=&4@=&AE("1T:&ES+3Y?:60@:68@=&AE(&1A=&%;)VED)UT@:&%S
M(&$@:&EG:&5R(&YU;6)E<BP@<VEN8V4*("`@("`@("`@("`@+R\@=V4@9&]N
M="!W86YT('1O(&]V97)W<FET92!A;GET:&EN9RX@:G5S="!I;B!C87-E"B`@
M("`@("`@("`@("1T:&ES+3Y?:60@/2`H:6YT*21D871A6R=I9"==.PH@("`@
M("`@('T*("`@("`@("`D9&%T85LG<&%R96YT260G72`]("1P87)E;G1)9#L*
M("`@("`@("`D=&AI<RT^9&%T85LD9&%T85LG:60G75T@/2`D9&%T83L*"B`@
M("`@("`@+R\D<&%T:"`]("1T:&ES+3YG9710871H0GE)9"@D<&%R96YT260I
M.PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]A<G)A>5LG8VAI;&1R96XG
M72DI('L@("`@+R\@=&AE<F4@;6EG:'0@;F]T(&)E(&$@<F]O="!E;&5M96YT
M('EE=`H@("`@("`@("`@("`D9&%T85LG<&%R96YT260G72`](#`["B`@("`@
M("`@("`@("1T:&ES+3Y?87)R87E;)V-H:6QD<F5N)UU;72`]("1D871A.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&%R<F%Y7W=A;&LH)'1H:7,M
M/E]A<G)A>5LG8VAI;&1R96XG72QA<G)A>2@F)'1H:7,L)U]A9&0G*2QA<G)A
M>2@D9&%T82PD<&%R96YT260L)'!R979I;W5S260I*3L*("`@("`@("!]"@H@
M("`@("`@("\O)'1H:7,M/E]A<G)A>0H@("`@("`@(')E='5R;B`D9&%T85LG
M:60G73L*("`@('T*"B`@("`O*BH*("`@("H@("!W92!N965D('1O(&%D9"!T
M:&4@;F]D92!T;R!T:&4@<V]U<F-E(&%R<F%Y"B`@("`J("`@9F]R('1H:7,@
M=V4@:&%V92!T:&ES('!R:79A=&4@;65T:&]D('=H:6-H(&QO;W!S('1H<F]U
M9V@@"B`@("`J("`@=&AE('-O=7)C92!A<G)A>2!A;F0@861D<R!I="!I;B!T
M:&4@<FEG:'0@<&QA8V4*("`@("H@("`*("`@("H@("!`<&%R86T@(&UI>&5D
M("`@=&AE('9A;'5E(&]F('1H92!A<G)A>2P@87,@82!R969E<F5N8V4L('-O
M('=E('=O<FL@<FEG:'0@;VX@=&AE('-O=7)C90H@("`@*B`@($!P87)A;2`@
M;6EX960@("!T:&4@:V5Y(&]F('1H92!N;V1E"B`@("`J("`@0'!A<F%M("!A
M<G)A>2`@(&%N(&%R<F%Y('=H:6-H(&-O;G1A:6YS('1H92!F;VQL;W=I;F<*
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&YE=R!D871A+"`*("`@("H@
M("`@("`@("`@("`@("`@("`@("`@('!A<F5N="!)1"!U;F1E<B!W:&EC:"!T
M;R!A9&0@=&AE(&YO9&4L(`H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M=&AE('!R=FEO=7,@240*("`@("HO"B`@("!F=6YC=&EO;B!?861D*"`F)'9A
M;"`L("1K97D@+"`D9&%T82`I"B`@("!["B`@("`@("`@:68@*"1V86Q;)VED
M)UT]/21D871A6S%=*2![("\O(&ES('1H92!I9"!O9B!T:&4@8W5R<F5N="!E
M;&UE;G0@*"1V86PI(#T]('1O('1H92!P87)E;G1)9"`H)&1A=&%;,5TI"B`@
M("`@("`@("`@(&EF("AI<W-E="@D9&%T85LR72D@)B8@)&1A=&%;,ET]/3TP
M("D@>R`@"B`@("`@("`@("`@("`@("`O+R!I9B!T:&4@<')E=FEO=7-)9"!I
M<R`P(&UE86YS+"!A9&0@:70@87,@=&AE(&9I<G-T(&UE;6)E<@H@("`@("`@
M("`@("`@("`@)'9A;%LG8VAI;&1R96XG72`](&%R<F%Y7VUE<F=E*&%R<F%Y
M*"1D871A6S!=*2PD=F%L6R=C:&EL9')E;B==*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1V86Q;)V-H:6QD<F5N)UU;72`]("1D
M871A6S!=.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L@("`@("`@
M("\O(&EF('=E(&AA=F5N="!F;W5N9"!T:&4@;F5W(&5L96UE;G0@9V\@;VX@
M<V5A<F-H:6YG"B`@("`@("`@("`@(&EF("AI<W-E="@D=F%L6R=C:&EL9')E
M;B==*2D@>PH@("`@("`@("`@("`@("`@87)R87E?=V%L:R@D=F%L6R=C:&EL
M9')E;B==+&%R<F%Y*"8D=&AI<RPG7V%D9"<I+"1D871A*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("H@("!U<&1A=&4@
M86X@96YT<GD@=VET:"!T:&4@9VEV96X@:60@86YD('-E="!T:&4@9&%T82!A
M<R!G:79E;B!I;B!T:&4@87)R87D@)&1A=&$*("`@("H*("`@("H@("!`<&%R
M86T@(&EN="`@("`@=&AE(&ED(&]F('1H92!E;&5M96YT('1H870@<VAA;&P@
M8F4@=7!D871E9`H@("`@*B`@($!P87)A;2`@87)R87D@("!T:&4@9&%T82P@
M6VME>5T]/EMV86QU95T*("`@("H@("!`<F5T=7)N('9O:60*("`@("HO"B`@
M("!F=6YC=&EO;B!U<&1A=&4H)&ED+"1D871A*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7V%R<F%Y6R=I9"==/3TD:60I('L*("`@("`@("`@("`@9F]R
M96%C:"`H)&1A=&$@87,@)&ME>3T^)&YE=U9A;"D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A<G)A>5LD:V5Y72`]("1N97=686P["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!A<G)A>5]W86QK*"1T
M:&ES+3Y?87)R87E;)V-H:6QD<F5N)UTL87)R87DH)B1T:&ES+"=?=7!D871E
M)RDL87)R87DH)&ED+"1D871A*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@*B`@('5P9&%T92!T:&4@96QE;65N="!W:71H('1H92!G:79E;B!I
M9`H@("`@*@H@("`@*B`@($!P87)A;2`@87)R87D@("!A(')E9F5R96YC92!T
M;R!A;B!E;&5M96YT(&EN<VED92`D=&AI<RT^7V%R<F%Y"B`@("`J("`@("`@
M("`@("`@("`@("`@(&AA<R!T;R!B92!A(')E9F5R96YC92P@<V\@=V4@8V%N
M(')E86QL>2!M;V1I9GD@=&AE(&%C='5A;"!D871A"B`@("`J("`@0'!A<F%M
M("!I;G0@("`@(&YO="!I;B!U<V4L(&)U="!A<G)A>5]W86QK('!A<W-E<R!T
M:&ES('!A<F%M"B`@("`J("`@0'!A<F%M("!A<G)A>2`@(%LP72!I<R!T:&4@
M:60@=V4@87)E('-E87)C:&EN9R!F;W(*("`@("H@("`@("`@("`@("`@("`@
M("`@6S%=(&%R92!T:&4@;F5W(&1A=&$@=V4@<VAA;&P@<V5T"B`@("`J("`@
M0')E='5R;B!V;VED"B`@("`J+PH@("`@9G5N8W1I;VX@7W5P9&%T92@@)B1V
M86P@+"`D:V5Y("P@)&1A=&$@*0H@("`@>PHO+W!R:6YT("1V86Q;)VED)UTN
M)ST])RXD9&%T85LP72XG/&)R/B<["B`@("`@("`@:68@*"1V86Q;)VED)UT]
M/21D871A6S!=*2![("\O(&ES('1H92!I9"!O9B!T:&4@8W5R<F5N="!E;&UE
M;G0@*"1V86PI(#T]('1O('1H92!P87)E;G1)9"`H)&1A=&%;,5TI"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1D871A6S%=(&%S("1K97D]/B1N97=686PI('L*
M+R]P<FEN="`B<V5T("(N)'9A;%LG;F%M92==+B(@("1K97D@/2`D;F5W5F%L
M/&)R/B(["B`@("`@("`@("`@("`@("`D=F%L6R1K97E=(#T@)&YE=U9A;#L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![("`@("`@("`O+R!I9B!W
M92!H879E;G0@9F]U;F0@=&AE(&YE=R!E;&5M96YT(&=O(&]N('-E87)C:&EN
M9R!I;B!T:&4@8VAI;&1R96X*("`@("`@("`@("`@:68@*&ES<V5T*"1V86Q;
M)V-H:6QD<F5N)UTI*2!["B`@("`@("`@("`@("`@("!A<G)A>5]W86QK*"1V
M86Q;)V-H:6QD<F5N)UTL87)R87DH)B1T:&ES+"=?=7!D871E)RDL)&1A=&$I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M*B`@(')E;6]V92!A;B!E;&5M96YT(&9R;VT@=&AE('1R964*("`@("H@("!T
M:&ES(')E;6]V97,@86QL('1H92!C:&EL9')E;B!T;V\*("`@("H*("`@("H@
M("!`<&%R86T@(&EN="!T:&4@:60@;V8@=&AE(&5L96UE;G0@=&\@8F4@<F5M
M;W9E9`H@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@D:60I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3YD871A6R1I9%TI('L@("`@("`@("`@("`@("`@
M("`@("`O+R!W92!O;FQY(&YE960@=&\@<V5A<F-H(&9O<B!E;&5M96YT('1H
M870@9&\@97AI<W0@.BTI(&]T:&5R=VES92!W92!S879E('-O;64@<')O8V5S
M<VEN9R!T:6UE"B`@("`@("`@("`@("1T:&ES+3Y?<F5M;W9E*"1T:&ES+3Y?
M87)R87DL)&ED*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J("`@
M<F5M;W9E('1H92!E;&5M96YT('=I=&@@=&AE(&=I=F5N(&ED"B`@("`J("`@
M=&AI<R!W:6QL(&1E9FEN:71E;'D@<F5M;W9E(&%L;"!T:&4@8VAI;&1R96X@
M=&]O"B`@("`J"B`@("`J("`@0'!A<F%M("!A<G)A>2`@(&$@<F5F97)E;F-E
M('1O(&%N(&5L96UE;G0@:6YS:61E("1T:&ES+3Y?87)R87D*("`@("H@("`@
M("`@("`@("`@("`@("`@:&%S('1O(&)E(&$@<F5F97)E;F-E+"!S;R!W92!C
M86X@<F5A;&QY(&UO9&EF>2!T:&4@86-T=6%L(&1A=&$*("`@("H@("!`<&%R
M86T@(&EN="`@("`@=&AE(&ED(&]F('1H92!E;&5M96YT('1O(&)E(')E;6]V
M960*("`@("H@("!`<F5T=7)N('9O:60*("`@("HO"B`@("!F=6YC=&EO;B!?
M<F5M;W9E*"`F)'9A;"`L("1I9"`I"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1V86Q;)V-H:6QD<F5N)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86Q;)V-H:6QD<F5N)UT@87,@)&ME>3T^)&%686PI('L*+R]P<FEN="`D859A
M;%LG:60G72XG/3TG+B1I9"XB7')<;B(["B`@("`@("`@("`@("`@("!I9B`H
M)&%686Q;)VED)UT]/21I9"D@>PHO+W!R:6YT(")R96UO=F4@(BXD859A;%LG
M;F%M92==+B)<<EQN(CL*("`@("`@("`@("`@("`@("`@("!I9B`H<VEZ96]F
M*"1V86Q;)V-H:6QD<F5N)UTI/#(I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@=6YS970H)'9A;%LG8VAI;&1R96XG72D["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'9A
M;%LG8VAI;&1R96XG75LD:V5Y72D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)E;6]V92@D=F%L6R=C:&EL9')E;B==6R1K97E=+"1I9"D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@I]("\O(&5N9"!O9B!C;&%S<PH_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]4<F5E+TUE;6]R>2]$0FYE<W1E9"YP:'``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-30Q,0`Q,#0Q-S,V,S`P-``P,C$W,#<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+R\*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I
M;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@
M("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A
M:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@
M<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@075T:&]R<SH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\*+R\@("1)9#H@1$)N97-T960N<&AP+'8@,2XX
M(#(P,#,O,#(O,C8@,3@Z-#4Z-3`@8V%I;B!%>'`@)`H*<F5Q=6ER95]O;F-E
M("=4<F5E+T1Y;F%M:6,O1$)N97-T960N<&AP)SL*"B\J*@HJ"BH**B`@($!A
M8V-E<W,@("`@('!U8FQI8PHJ("`@0&%U=&AO<@HJ("`@0'!A8VMA9V4@("`@
M5')E90HJ+PIC;&%S<R!4<F5E7TUE;6]R>5]$0FYE<W1E9"!E>'1E;F1S(%1R
M965?1'EN86UI8U]$0FYE<W1E9`I["@H@("`@+RHJ"B`@("`J("`@<F5T<F5I
M=F4@86QL('1H92!D871A(&9R;VT@=&AE(&1B(&%N9"!P<F5P87)E('1H92!D
M871A('-O('1H92!S=')U8W1U<F4@8V%N"B`@("`J("`@8F4@8G5I;'0@:6X@
M=&AE('!A<F5N="!C;&%S<PH@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P
M,#(O,#0O,C`*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`
M875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG
M+F1E/@H@("`@*B`@($!P87)A;2`@("`@(&%R<F%Y("`@=&AE(')E<W5L="!O
M9B!A('%U97)Y('=H:6-H(')E=')E:79E<R`H86QL*2!T:&4@=')E92!D871A
M(&9R;VT@82!$0@H@("`@*B`@($!R971U<FX@("`@(&%R<F%Y("`@=&AE(')E
M<W5L=`H@("`@*B\*("`@(&9U;F-T:6]N('-E='5P*"1R97,];G5L;"D*("`@
M('L*("`@("`@("!I9B`H)')E<ST];G5L;"D@>PH@("`@("`@("`@("`O+PH@
M("`@("`@("`@("`D=VAE<F5!9&1/;B`]("<G.PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)W=H97)E061D3VXG72D@>PH@("`@("`@("`@("`@
M("`@)'=H97)E061D3VX@/2`G5TA%4D4@)RXD=&AI<RT^9V5T3W!T:6]N*"=W
M:&5R94%D9$]N)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O"B`@
M("`@("`@("`@("1O<F1E<D)Y(#T@)VQE9G0G.PH@("`@("`@("`@("!I9B`H
M)&]R9&5R/21T:&ES+3YG971/<'1I;VXH)V]R9&5R)RDI('L*("`@("`@("`@
M("`@("`@("1O<F1E<D)Y(#T@)&]R9&5R.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R!B=6EL9"!T:&4@<75E<GD@=&AI<R!W87DL('1H870@=&AE
M(')O;W0L('=H:6-H(&AA<R!N;R!P87)E;G0@*'!A<F5N=$ED/3`I(&ES(&9I
M<G-T"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H("`@)U-%3$5#5"`J
M($923TT@)7,@)7,@3U)$15(@0ED@)7,G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YT86)L92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=VAE<F5!9&1/;BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H)&]R9&5R0GDI("`O
M+R!S;W)T(&)Y('1H92!L969T+6-O;'5M;BP@<V\@=V4@:&%V92!T:&4@9&%T
M82!S;W)T960@87,@:70@:7,@<W5P<&]S960@=&\@8F4@.BTI"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"`D<F5S(#T@)'1H:7,M/F1B:"T^9V5T06QL*"1Q=65R>2DI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T:')O=T5R<F]R
M*"1R97,M/F=E=$UE<W-A9V4H*2Q?7TQ)3D5?7RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W!R97!A<F5297-U
M;'1S*"`D<F5S("D["B`@("!]"@I]"@H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U1R964O365M;W)Y
M+T9I;&5S>7-T96TN<&AP````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W
M-S`S`#$P-#$W,S8S,#`T`#`R,C,U,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H
M="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT
M>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS
M92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@
M("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!7;VQF
M<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/B`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+PHO+R`@)$ED.B!&:6QE<WES=&5M+G!H<"QV(#$N,R`R,#`S+S`Q+S`T(#$Q
M.C4V.C(X(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4H)U1R964O17)R;W(N<&AP
M)RD["@HO*BH**B`@('1H92!&:6QE<WES=&5M(&EN=&5R9F%C92!T;R!T:&4@
M=')E92!C;&%S<PHJ("`@=&AI<R!I<R!A(&)I="!D:69F97)E;G0L(&%S(&ED
M('=E('5S92!T:&4@96YT:7)E('!A=&@L('-I;F-E('=E(&MN;W<**B`@('1H
M:7,@:7,@=6YI<75E(&EN(&$@9FEL97-Y<W1E;2!A;F0@86X@:6YT96=E<B!I
M9"!C;W5L9"!O;FQY(&)E(&-R96%T960**B`@('9I<G1U86QL>2P@:70@9&]E
M<VYT(&AA=F4@82!T:6=H="!C;VYN96-T:6]N('1O('1H92!A8W1U86P@9&ER
M96-T;W)Y"BH@("!I+F4N('5S:6YG("=A9&0G('=I=&@@:61S(&-O=6QD(&9A
M:6P@<VEN8V4@=V4@9&]N="!K;F]W(&EF('=E(&=E="!T:&4@<V%M90HJ("`@
M:60@=VAE;B!W92!C86QL("=A9&0G('=I=&@@82!P87)E;G1)9"!T;R!C<F5A
M=&4@82!N97<@9F]L9&5R('5N9&5R('-I;F-E(&]U<B!I9"!W;W5L9"!B92!M
M861E('5P+@HJ("`@<V\@=V4@=7-E('1H92!C;VUP;&5T92!P871H(&%S(&ED
M+"!W:&EC:"!T86ME<R!U<"!A(&QO="!O9B!M96UO<GDL(&D@:VYO=PHJ("`@
M8G5T('-I;F-E('!H<"!I<R!T>7!E;&5S<R!I=',@<&]S<VEB;&4@86YD(&ET
M(&UA:V5S(&QI9F4@96%S:65R('=H96X**B`@('=E('=A;G0@=&\@8W)E871E
M(&%N;W1H97(@9&ER+"!S:6YC92!W92!G970@=&AE(&1I<B!A<R!P87)E;G1)
M9"!P87-S960@=&\@=&AE"BH@("`G861D)R!M971H;V0L('=H8VEH(&UA:V5S
M(&ET(&5A<WD@=&\@8W)E871E(&$@;F5W(&1I<B!T:&5R92`Z+2D**B`@(&D@
M86QS;R!T:&]U9VAT(&%B;W5T(&AA<VAI;F<@=&AE('!A=&@@;F%M92!B=70@
M=&AE;B!T:&4@861D(&UE=&AO9"!I<R!N;W0@=&AA=`HJ("`@96%S>2!T;R!I
M;7!L96UE;G0@+BXN(&UA>2!B92!O;F4@9&%Y(#HM*0HJ"BH@("!`86-C97-S
M("`@("!P=6)L:6,**B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@
M/'=O;&9R86U`:W)I97-I;F<N9&4^"BH@("!`=F5R<VEO;B`@("`R,#`Q+S`V
M+S(W"BH@("!`<&%C:V%G92`@("!4<F5E"BHO"F-L87-S(%1R965?365M;W)Y
M7T9I;&5S>7-T96T*>PH*("`@("\J*@H@("`@*B`@($!A8V-E<W,@<'5B;&EC
M"B`@("`J("`@0'9A<B`@("!A<G)A>2`@('-A=F5S('1H92!O<'1I;VYS('!A
M<W-E9"!T;R!T:&4@8V]N<W1R=6-T;W(*("`@("HO"B`@("!V87(@)&]P=&EO
M;G,@/2`@87)R87DH("`G;W)D97(G("`@("`]/B<G+"`@("\O('=H:6-H(&-O
M;'5M;B!T;R!O<F1E<B!B>2!W:&5N(')E861I;F<@=&AE(&1A=&$@9G)O;2!T
M:&4@1$(L('1H:7,@<V]R=',@=&AE(&1A=&$@979E;B!I;G-I9&4@979E<GD@
M;&5V96P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('1H92!C;VQU
M;6XM;F%M92!M87!S(&%R92!U<V5D(&9O<B!T:&4@(F%S(B!I;B!T:&4@<V5L
M96-T('%U97)I97,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('-O
M('EO=2!C86X@=7-E(&%N>2!C;VQU;6X@;F%M92!I;B!T:&4@=&%B;&4@86YD
M(")M87`B(&ET('1O('1H92!N86UE('1H870@<VAA;&P@8F4@=7-E9"!I;B!T
M:&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&EN=&5R;F%L(&%R
M<F%Y+"!T:&%T(&ES(&)U:6QT+"!S964@=&AE(&5X86UP;&5S("AI;B!C;VUM
M96YT<RD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;VQU;6Y.86UE
M36%P<R<]/F%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\J("`@("`@("`@("`G:60G("`@("`@("`@("`@/3X@("=T<F5E7VED
M)RP@("`O+R!U<V4@(G1R965?:60B(&%S(")I9"(*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<F5N=$ED)R`@
M("`@(#T^("`G<&%R96YT7VED)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W!R979)9"<@("`@("`@(#T^("`G
M<')E=FEO=7-?:60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;F%M92<@("`@("`@("`@/3X@("=N;V1E3F%M
M92<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`O*BH*("`@
M("H@("!S970@=7`@=&AI<R!O8FIE8W0*("`@("H*("`@("H@("!`=F5R<VEO
M;B`@("`R,#`R+S`X+S(S"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@
M("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K
M<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@("`@("!S=')I;F<@("1D<VX@
M("`@=&AE('!A=&@@;VX@=&AE(&9I;&5S>7-T96T*("`@("H@("!`<&%R86T@
M("`@("!A<G)A>2`@("1O<'1I;VYS("!A9&1I=&EO;F%L(&]P=&EO;G,@>6]U
M(&-A;B!S970*("`@("HO"B`@("!F=6YC=&EO;B!4<F5E7TUE;6]R>5]&:6QE
M<WES=&5M*"`D<&%T:"`L("1O<'1I;VYS/6%R<F%Y*"D@*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<&%T:"`]("1P871H.PH@("`@("`@("1T:&ES+3Y?;W!T
M:6]N<R`]("1O<'1I;VYS.R`O+R!N;W0@:6X@=7-E(&-U<G)E;G1L>0HO*B`@
M("`@("`@)'1H:7,M/E1R965?3W!T:6]N<T1"*"`D9'-N("P@)&]P=&EO;G,@
M*3L@+R\@:6YS=&%N8VEA=&4@1$(*("`@("`@("!I9B@@:7-?<W1R:6YG*"1O
M<'1I;VYS*2`I("`@("`@("`@("`@("`@("`@+R\@:G5S="!T;R!B92!B86-K
M=V%R9"!C;VUP871I8FQE+"!O<B!T;R!M86ME('1H92!S96-O;F0@<&%R86UT
M97(@<VAO<G1E<@H@("`@("`@('L*("`@("`@("`@("`@)'1H:7,M/G-E=$]P
M=&EO;B@@)V]R9&5R)R`L("1O<'1I;VYS("D["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^=&%B;&4@/2`D=&AI<RT^9V5T3W!T:6]N*"=T86)L92<I.PHJ
M+PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*("`@("H@("!R
M971R96EV92!A;&P@=&AE(&YA=FEG871I;VX@9&%T82!F<F]M('1H92!D8B!A
M;F0@8V%L;"!B=6EL9"!T;R!B=6EL9"!T:&4*("`@("H@("!T<F5E(&EN('1H
M92!A<G)A>2!D871A(&%N9"!S=')U8W1U<F4*("`@("H*("`@("H@("!`=F5R
M<VEO;B`@("`R,#`Q+S$Q+S(P"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC
M"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A
M;4!K<FEE<VEN9RYD93X*("`@("H@("!`<F5T=7)N("`@("!B;V]L96%N("`@
M("!T<G5E(&]N('-U8V-E<W,*("`@("HO"B`@("!F=6YC=&EO;B!S971U<"@I
M"B`@("!["B`@("`@("`@=6YS970H)'1H:7,M/F1A=&$I.R`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!U;G-E="!T:&4@9&%T82!T;R!B92!S=7)E('1O
M(&=E="!T:&4@<F5A;"!D871A(&%G86EN+"!N;R!O;&0@9&%T80H@("`@("`@
M(&EF*"!I<U]D:7(H)'1H:7,M/E]P871H*2`I"B`@("`@("`@>PH@("`@("`@
M("`@("`D=&AI<RT^9&%T85LD=&AI<RT^7W!A=&A=(#T@87)R87DH)VED)ST^
M)'1H:7,M/E]P871H+"=N86UE)ST^)'1H:7,M/E]P871H+"=P87)E;G1)9"<]
M/C`I.PH@("`@("`@("`@("`D=&AI<RT^7W-E='5P*"1T:&ES+3Y?<&%T:"PD
M=&AI<RT^7W!A=&@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YD871A.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S971U<"@@)'!A=&@@+"`D
M<&%R96YT260],"`I"B`@("!["B`@("`@("`@:68@*"1H86YD;&4@/2!O<&5N
M9&ER*"1P871H*2D*("`@("`@("!["B`@("`@("`@("`@('=H:6QE("AF86QS
M92`A/3T@*"1F:6QE(#T@<F5A9&1I<B@D:&%N9&QE*2DI"B`@("`@("`@("`@
M('L*("`@("`@("`@("`@("`@(&EF*"`D9FEL92`A/2`G+B<@)B8@)&9I;&4@
M(3T@)RXN)R`F)B!I<U]D:7(H(B1P871H+R1F:6QE(BDI"B`@("`@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("`@("`@(R1I9"`]('-I>F5O9B@D=&AI
M<RT^9&%T82D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;72`]
M(&%R<F%Y*"=I9"<]/B(D<&%T:"\D9FEL92(L)VYA;64G/3XD9FEL92PG<&%R
M96YT260G/3XD<&%R96YT260I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5T=7`H("(D<&%T:"\D9FEL92(@+"`B)'!A=&@O)&9I;&4B("D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO
M<V5D:7(H)&AA;F1L92D["B`@("`@("`@?0H*("`@('T*"@H@("`@+RHJ"B`@
M("`J("`@=&AI<R!I<R!T<FEC:WD@;VX@82!F:6QE<WES=&5M+"!S:6YC92!W
M92!A<F4@=V]R:VEN9R!W:71H(&ED)W,*("`@("H@("!A<R!I9&5N=&EF:65R
M<R!A;F0@=V4@;F5E9"!T;R!B92!S=7)E+"!T:&4@<&%R96YT260@=&\@8W)E
M871E(&$@;F]D92!U;F1E<@H@("`@*B`@(&ES('1H92!S86UE(&%S('=H96X@
M=&AE('1R964@=V%S(&QA<W0@<F5A9"P@8G5T('1H:7,@;6EG:'0@8F4@=')I
M8VMY"B`@("`J"B`@("`J+PH@("`@9G5N8W1I;VX@861D*"`D;F5W5F%L=65S
M("P@)'!A<F5N=#TP("P@)'!R979)9#TP("D*("`@('L*("`@("`@("!I9B@@
M(21P87)E;G0@*0H@("`@("`@("`@("`D<&%R96YT(#T@)'1H:7,M/G!A=&@[
M"@HC($9)6%A-12!D;R!T:&4@;6%P<&EN9PH@("`@("`@(&EF*"`A0&UK9&ER
M*"`B)'!A<F5N="][)&YE=U9A;'5E<ULG;F%M92==?2(@+"`P-S`P("D@*0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T:')O=T5R<F]R*"=C;W5L9&YT
M(&-R96%T92!D:7(@)RXD;F5W5F%L=65S6R=N86UE)UTN)R!U;F1E<B`G+B1P
M87)E;G0L7U],24Y%7U\I.PH@("`@("`@(')E='5R;B`B)'!A<F5N="][)&YE
M=U9A;'5E<ULG;F%M92==?2(["B`@("!]"@H@("`@9G5N8W1I;VX@<F5M;W9E
M*"`D:60@*0H@("`@>PH@("`@("`@(&EF*"`A0')M9&ER*"`D:60@*2`I"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1H<F]W17)R;W(H)V-O=6QD;G0@
M<F5M;W9E(&1I<B`G+B1I9"Q?7TQ)3D5?7RD["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@9G5N8W1I;VX@8V]P>2@@("1S<F-)9"`L("1D97-T
M260@("D*("`@('L*("`@("`@("`C(&EF*"`A0&-O<'DH("1S<F-)9"`L("1D
M97-T260@*2`I('1H:7,@=V]U;&0@;VYL>2!B92!F;W(@9FEL97,@.BTI"B,@
M1DE86$U%(&QO;W`@=&AR;W5G:"!T:&4@9&ER96-T;W)Y('1O(&-O<'D@=&AE
M(&-H:6QD<F5N('1O;R`A(2$*"B`@("`@("`@)&1E<W0@/2`D9&5S=$ED+B<O
M)RYP<F5G7W)E<&QA8V4H)R]>+BI<+R\G+"<G+"1S<F-)9"D["@H@("`@("`@
M(&EF*"!I<U]D:7(H("1D97-T("D@*0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]T:')O=T5R<F]R*")C;W5L9&YT(&-O<'DL("1D97-T260@86QR96%D
M>2!E>&ES=',@:6X@)'-R8TED("(@+"!?7TQ)3D5?7R`I.PH*("`@("`@("!I
M9B@@(4!M:V1I<B@@)&1E<W0@+"`P-S`P("D@*0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]T:')O=T5R<F]R*")C;W5L9&YT(&-O<'D@9&ER(&9R;VT@
M)'-R8TED('1O("1D97-T260@(B`L(%]?3$E.15]?("D["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`J"B`@("`J"B`@("`J("`@
M0&%C8V5S<R`@("`@<')I=F%T90H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O
M,#,O,#(*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW
M;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;0H@("`@*B`@($!R
M971U<FX*("`@("HO"B`@("!F=6YC=&EO;B!?=&AR;W=%<G)O<B@@)&US9R`L
M("1L:6YE("P@)&UO9&4];G5L;"`I"B`@("!["B`@("`@("`@<F5T=7)N(&YE
M=R!4<F5E7T5R<F]R*"`D;7-G("P@)&QI;F4@+"!?7T9)3$5?7R`L("1M;V1E
M("P@)'1H:7,M/F1B+3YL87-T7W%U97)Y("D["B`@("!]"@H@("`@+RHJ"B`@
M("`J("`@<')E<&%R92!M=6QT:7!L92!R97-U;'1S"B`@("`J"B`@("`J("`@
M0'-E92`@("`@("`@7W!R97!A<F5297-U;'0H*0H@("`@*B`@($!A8V-E<W,@
M("`@('!R:79A=&4*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`S+S`S"B`@
M("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K
M<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T*("`@("H@("!`<F5T=7)N"B`@
M("`J+PH@("`@9G5N8W1I;VX@7W!R97!A<F5297-U;'1S*"`D<F5S=6QT<R`I
M"B`@("!["B`@("`@("`@)&YE=U)E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@H("1R97-U;'1S(&%S("1A4F5S=6QT("D*("`@("`@("`@("`@
M)&YE=U)E<W5L='-;72`]("1T:&ES+3Y?<')E<&%R95)E<W5L="@D85)E<W5L
M="D["B`@("`@("`@<F5T=7)N("1N97=297-U;'1S.PH@("`@?0H*("`@("\J
M*@H@("`@*B`@(&UA<"!B86-K('1H92!I;F1E>"!N86UE<R!T;R!G970@=VAA
M="!I<R!E>'!E8W1E9`H@("`@*@H@("`@*B`@($!A8V-E<W,@("`@('!R:79A
M=&4*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`S+S`S"B`@("`J("`@0&%U
M=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD
M93X*("`@("H@("!`<&%R86T*("`@("H@("!`<F5T=7)N"B`@("`J+PH@("`@
M9G5N8W1I;VX@7W!R97!A<F5297-U;'0H("1R97-U;'0@*0H@("`@>PH@("`@
M("`@("1M87`@/2`D=&AI<RT^9V5T3W!T:6]N*"=C;VQU;6Y.86UE36%P<R<I
M.PH*("`@("`@("!I9B@@)&UA<"`I"B`@("`@("`@9F]R96%C:"@@)&UA<"!A
M<R`D:V5Y/3XD8V]L=6UN3F%M92`I"B`@("`@("`@>PH@("`@("`@("`@("`D
M<F5S=6QT6R1K97E=(#T@)')E<W5L=%LD8V]L=6UN3F%M95T["B`@("`@("`@
M("`@('5N<V5T*"1R97-U;'1;)&-O;'5M;DYA;65=*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H*?2`O+R!E;F0@;V8@8VQA
M<W,*/SX*````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]4<F5E+TUE;6]R>2]$0G-I;7!L92YP:'``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`S-C(R,@`Q,#0Q-S,V,S`P-``P,C$W,C(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E
M<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE
M<VEN9RYD93X@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@("1)9#H@1$)S:6UP;&4N<&AP+'8@
M,2XQ,2`R,#`S+S`Q+S$X(#$U.C,V.C4P(&-A:6X@17AP("0*"G)E<75I<F5?
M;VYC92@G5')E92]/<'1I;VYS1$(N<&AP)RD["G)E<75I<F5?;VYC92@G5')E
M92]%<G)O<BYP:'`G*3L*"B\J*@HJ("`@=&AE($1"(&EN=&5R9F%C92!T;R!T
M:&4@=')E92!C;&%S<PHJ"BH@("!`86-C97-S("`@("!P=6)L:6,**B`@($!A
M=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N
M9&4^"BH@("!`=F5R<VEO;B`@("`R,#`Q+S`V+S(W"BH@("!`<&%C:V%G92`@
M("!4<F5E"BHO"F-L87-S(%1R965?365M;W)Y7T1"<VEM<&QE(&5X=&5N9',@
M5')E95]/<'1I;VYS1$(*+R\@1DE86$U%('-H;W5L9"!A8W1U86QL>2!E>'1E
M;F0@5')E95]#;VUM;VXL('1O('5S92!T:&4@;65T:&]D<R!P<F]V:61E9"!I
M;B!T:&5R92XN+B!B=70@=V4@;F5E9"!T;R!C;VYN96-T"B\O('1O('1H92!D
M8B!H97)E+"!S;R!W92!E>'1E;F0@;W!T:6]N<T1"(&9O<B!N;W<L(&UA>2!B
M92!U<V4@(F%G9W)E9V%T92(@9G5N8W1I;VX@=&\@9FEX('1H870*>PH*("`@
M("\J*@H@("`@*B`@($!A8V-E<W,@<'5B;&EC"B`@("`J("`@0'9A<B`@("!A
M<G)A>2`@('-A=F5S('1H92!O<'1I;VYS('!A<W-E9"!T;R!T:&4@8V]N<W1R
M=6-T;W(*("`@("HO"B`@("!V87(@)&]P=&EO;G,@/2`@87)R87DH("`G;W)D
M97(G("`@("`]/B<G+"`@("\O('=H:6-H(&-O;'5M;B!T;R!O<F1E<B!B>2!W
M:&5N(')E861I;F<@=&AE(&1A=&$@9G)O;2!T:&4@1$(L('1H:7,@<V]R=',@
M=&AE(&1A=&$@979E;B!I;G-I9&4@979E<GD@;&5V96P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=W:&5R94%D9$]N)ST^)R<L("`@+R\@861D(&]N
M(&9O<B!T:&4@=VAE<F4@8VQA=7-E+"!T:&ES('-T<FEN9R!I<R!S:6UP;'D@
M861D960@8F5H:6YD('1H92!72$5212!I;B!T:&4@<V5L96-T"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('-O
M('EO=2!B971T97(@;6%K92!S=7)E(&ET<R!C;W)R96-T(%-13"`Z+2DL(&DN
M92X@)W5I9#TS)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!T:&ES(&ES(&YE961E9"!I+F4N('=H96X@>6]U
M(&%R92!S879I;F<@;6%N>2!T<F5E<R!F;W(@9&EF9F5R96YT('5S97(*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@:6X@;VYE('1A8FQE('=H97)E(&5A8V@@96YT<GD@:&%S(&$@=6ED("AU
M<V5R(&ED*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1A8FQE)R`@
M("`@/3XG)RP@("`O+PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M=&AE(&-O;'5M;BUN86UE(&UA<',@87)E('5S960@9F]R('1H92`B87,B(&EN
M('1H92!S96QE8W0@<75E<FEE<PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@<V\@>6]U(&-A;B!U<V4@86YY(&-O;'5M;B!N86UE(&EN('1H92!T
M86)L92!A;F0@(FUA<"(@:70@=&\@=&AE(&YA;64@=&AA="!S:&%L;"!B92!U
M<V5D(&EN('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@:6YT
M97)N86P@87)R87DL('1H870@:7,@8G5I;'0L('-E92!T:&4@97AA;7!L97,@
M*&EN(&-O;6UE;G1S*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O
M;'5M;DYA;65-87!S)ST^87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+RH@("`@("`@("`@("=I9"<@("`@("`@("`@("`]/B`@
M)W1R965?:60G+"`@("\O('5S92`B=')E95]I9"(@87,@(FED(@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R
M96YT260G("`@("`@/3X@("=P87)E;G1?:60G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<')E=DED)R`@("`@
M("`@/3X@("=P<F5V:6]U<U]I9"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@("`@("`@("`]/B`@
M)VYO9&5.86UE)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("HO"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("\J*@H@("`@*B`@($!A8V-E<W,@<'5B;&EC"B`@("`J("`@0'9A<B`@("!S
M=')I;F<@('1H92!T86)L92!W:&5R92!T;R!R96%D('1H92!T<F5E(&1A=&$@
M9G)O;0H@("`@*B`@("`@("`@("`@("`@("`@("!C86X@86QS;R!B92!S970@
M=7-I;F<@=&AE($133B!I;B!T:&4@8V]N<W1R=6-T;W(*("`@("HO"B`@("!V
M87(@)'1A8FQE.PH*("`@("\J*@H@("`@*B`@($!A8V-E<W,@<')I=F%T90H@
M("`@*B`@($!V87(@("`@;V)J96-T("`D9&)H("`@('1H92!H86YD;&4@=&\@
M=&AE($1"+6]B:F5C=`H@("`@*B\*+R\@("`@=F%R("1D8F@["@H@("`@+RHJ
M"B`@("`J("`@<V5T('5P('1H:7,@;V)J96-T"B`@("`J"B`@("`J("`@0'9E
M<G-I;VX@("`@,C`P,2\P-B\R-PH@("`@*B`@($!A8V-E<W,@("`@('!U8FQI
M8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R
M86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@<W1R:6YG("`D
M9'-N("`@('1H:7,@:7,@82!$4TX@;V8@=&AE(&9O<B!T:&%T(%!%05(Z.D1"
M('5S97,@:70*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;VYL>2!T:&%T(&%D9&ET:6]N86QL>2!Y;W4@8V%N(&%D9"!P87)A;65T97)S
M(&QI:V4@+BXN/W1A8FQE/71E<W1?=&%B;&4*("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&\@9&5F:6YE('1H92!T86)L92!I="!S:&%L
M;"!W;W)K(&]N"B`@("`J("`@0'!A<F%M("`@("`@87)R87D@("`D;W!T:6]N
M<R`@861D:71I;VYA;"!O<'1I;VYS('EO=2!C86X@<V5T"B`@("`J+PH@("`@
M9G5N8W1I;VX@5')E95]-96UO<GE?1$)S:6UP;&4H("1D<VX@+"`D;W!T:6]N
M<SUA<G)A>2@I("D*("`@('L*("`@("`@("`D=&AI<RT^5')E95]/<'1I;VYS
M1$(H("1D<VX@+"`D;W!T:6]N<R`I.R`O+R!I;G-T86YC:6%T92!$0@H@("`@
M("`@(&EF*"!I<U]S=')I;F<H)&]P=&EO;G,I("D@("`@("`@("`@("`@("`@
M("`O+R!J=7-T('1O(&)E(&)A8VMW87)D(&-O;7!A=&EB;&4L(&]R('1O(&UA
M:V4@=&AE('-E8V]N9"!P87)A;71E<B!S:&]R=&5R"B`@("`@("`@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T3W!T:6]N*"`G;W)D97(G("P@)&]P=&EO;G,@
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YT86)L92`]("1T:&ES+3YG
M971/<'1I;VXH)W1A8FQE)RD["@H@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*
M"B`@("`O*BH*("`@("H@("!R971R96EV92!A;&P@=&AE(&YA=FEG871I;VX@
M9&%T82!F<F]M('1H92!D8B!A;F0@8V%L;"!B=6EL9"!T;R!B=6EL9"!T:&4*
M("`@("H@("!T<F5E(&EN('1H92!A<G)A>2!D871A(&%N9"!S=')U8W1U<F4*
M("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R,#`Q+S$Q+S(P"B`@("`J("`@
M0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A
M;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<F5T
M=7)N("`@("!B;V]L96%N("`@("!T<G5E(&]N('-U8V-E<W,*("`@("HO"B`@
M("!F=6YC=&EO;B!S971U<"@I"B`@("!["B\O(%1/1$\@<V]R="!B>2!P<F5V
M260@*'!A<F5N=$ED+'!R979)9"`D861D475E<GDI('1O;R!I9B!I="!E>&ES
M=',@:6X@=&AE('1A8FQE+"!O<B!T:&4@<F]O="!M:6=H="!B92!W<F]N9PHO
M+R!43T1/("!S:6YC92!T:&4@<')E=DED(&]F('1H92!R;V]T('-H;W5L9"!B
M92`P"@H@("`@("`@("\O"B`@("`@("`@)'=H97)E061D3VX@/2`G)SL*("`@
M("`@("!I9B@@)'1H:7,M/F]P=&EO;G-;)W=H97)E061D3VXG72`I"B`@("`@
M("`@>PH@("`@("`@("`@("`D=VAE<F5!9&1/;B`]("=72$5212`G+B1T:&ES
M+3YG971/<'1I;VXH)W=H97)E061D3VXG*3L*("`@("`@("!]"@H@("`@("`@
M("\O"B`@("`@("`@)&]R9&5R0GD@/2`G)SL*("`@("`@("!I9B@@)'1H:7,M
M/F]P=&EO;G-;)V]R9&5R)UT@*0H@("`@("`@('L*("`@("`@("`@("`@)&]R
M9&5R0GD@/2`B+"(N)'1H:7,M/F]P=&EO;G-;)V]R9&5R)UT["B`@("`@("`@
M?0H*("`@("`@("`D;6%P(#T@)'1H:7,M/F=E=$]P=&EO;B@G8V]L=6UN3F%M
M94UA<',G*3L*("`@("`@("!I9B@@:7-S970H)&UA<%LG<&%R96YT260G72D@
M*0H@("`@("`@('L*("`@("`@("`@("`@)&]R9&5R0GD@/2`D;6%P6R=P87)E
M;G1)9"==+B1O<F1E<D)Y.PH@("`@("`@('T*("`@("`@("!E;'-E"B`@("`@
M("`@>PH@("`@("`@("`@("`D;W)D97)">2`]("=P87)E;G1)9"<N)&]R9&5R
M0GD["B`@("`@("`@?0H*("`@("`@("`O+R!B=6EL9"!T:&4@<75E<GD@=&AI
M<R!W87DL('1H870@=&AE(')O;W0L('=H:6-H(&AA<R!N;R!P87)E;G0@*'!A
M<F5N=$ED/3`I"B`@("`@("`@+R\@86YD(&YO('!R979I;W5S("AP<F5V260]
M,"D@:7,@:6X@9FER<W0@<&QA8V4@*&EN(&-A<V4@<')E=DED(&ES(&=I=F5N
M*0H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H("`@(E-%3$5#5"`J($923TT@
M)7,@)7,@3U)$15(@0ED@)7,B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'=H97)E061D3VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W)D
M97)">2D[("\O+'!R979)9"`A(2$A"B`@("`@("`@:68H($1".CII<T5R<F]R
M*"`D<F5S(#T@)'1H:7,M/F1B:"T^9V5T06QL*"`D<75E<GD@*2`I("D*("`@
M("`@("!["B\O($9)6%A-12!R96UO=F4@<')I;G0@=7-E(&1E8G5G(&UO9&4@
M:6YS=&5A9`H@("`@("`@("`@("!P<FEN=&8H(D524D]2("T@5')E93HZ<V5T
M=7`@+2`E<R`M("5S/&)R/B(L1$(Z.F5R<F]R;65S<V%G92@D<F5S*2PD<75E
M<GDI.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T:')O=T5R<F]R*"1R
M97,M/F=E=$UE<W-A9V4H*2Q?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("`O+R!I9B!T:&4@9&(M8V]L=6UN(&YA;65S(&YE960@=&\@8F4@;6%P<&5D
M('1O(&1I9F9E<F5N="!N86UE<PHO+R!&25A8344@<V]M96AO=R!W92!S:&]U
M;&0@8F4@86)L92!T;R!D;R!T:&ES(&EN('1H92!Q=65R>2P@8G5T(&D@9&]N
M="!K;F]W(&AO=R!T;R!S96QE8W0*+R\@;VYL>2!T:&]S92!C;VQU;6YS+"!U
M<V4@(F%S(B!O;B!T:&5M(&%N9"!S96QE8W0@=&AE(')E<W0L('=I=&AO=70@
M9V5T=&EN9R!T:&]S92!C;VQU;6YS(&%G86EN(#HM*`H@("`@("`@(&EF*"`D
M;6%P("D*("`@("`@("!F;W)E86-H*"`D<F5S(&%S("1I9#T^)&%297-U;'0@
M*2`@("`O+R!M87`@96%C:"!R97-U;'0*("`@("`@("!["B`@("`@("`@("`@
M(&9O<F5A8V@H("1M87`@87,@)&ME>3T^)&-O;'5M;DYA;64@*0H@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("`D<F5S6R1I9%U;)&ME>5T@/2`D<F5S
M6R1I9%U;)&-O;'5M;DYA;65=.PH@("`@("`@("`@("`@("`@=6YS970H)')E
M<ULD:61=6R1C;VQU;6Y.86UE72D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\J*@H@("`@*B`@
M(&%D9',@7V]N95\@;F5W(&5L96UE;G0@:6X@=&AE('1R964@=6YD97(@=&AE
M(&=I=F5N('!A<F5N=`H@("`@*B`@('1H92!V86QU97,G(&ME>7,@9VEV96X@
M:&%V92!T;R!M871C:"!T:&4@9&(M8V]L=6UN<RP@8F5C875S92!T:&4*("`@
M("H@("!V86QU92!G971S(&EN<V5R=&5D(&EN('1H92!D8B!D:7)E8W1L>0H@
M("`@*B`@('1O(&%D9"!A;B!E;G1I<F4@;F]D92!C;VYT86EN:6YG(&-H:6QD
M<F5N(&%N9"!S;R!O;B!S964@)V%D9$YO9&4H*2<*("`@("H*("`@("H@("!T
M;R!B82!C;VUP871I8FQE+"!T;R!T:&4@1$)N97-T960@=2!C86X@86QS;R!G
M:79E('1H92!P87)E;G0@86YD('!R979I9"!A<R!T:&4@<V5C;VYD(&%N9"!T
M:&ER9"!P87)A;65T97(*("`@("H*("`@("H@("!`<V5E("`@("`@("!A9&1.
M;V1E*"D*("`@("H@("!`=F5R<VEO;B`@("`R,#`Q+S$P+S`Y"B`@("`J("`@
M0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A
M;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R
M86T@("`@("!A<G)A>2`@("1N97=686QU97,@('1H:7,@87)R87D@8V]N=&%I
M;G,@=&AE('9A;'5E<R!T:&%T('-H86QL(&)E(&EN<V5R=&5D(&EN('1H92!D
M8BUT86)L90H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&AE(&ME>2!F;W(@96%C:"!E;&5M96YT(&ES('1H92!N86UE(&]F('1H
M92!C;VQU;6X*("`@("H@("!`<F5T=7)N("`@("!M:7AE9"`@(&5I=&AE<B!B
M;V]L96%N(&9A;'-E(&]N(&9A:6QU<F4@;W(@=&AE(&ED(&]F('1H92!I;G-E
M<G1E9"!R;W<*("`@("HO"B`@("!F=6YC=&EO;B!A9&0H("1N97=686QU97,@
M+"`D<&%R96YT260],"`I"B`@("!["B\O($9)6%A-12!U<V4@)'1H:7,M/F1B
M:"T^=&%B;&5);F9O('1O(&-H96-K('=H:6-H(&-O;'5M;G,@97AI<W0*+R\@
M<V\@;VYL>2!D871A(&9O<B!W:&EC:"!A(&-O;'5M;B!E>&ES="!I<R!I;G-E
M<G1E9`H@("`@("`@(&EF*"`D<&%R96YT260@*0H@("`@("`@("`@("`D;F5W
M5F%L=65S6R=P87)E;G1)9"==(#T@)'!A<F5N=$ED.PH*("`@("`@("`D;F5W
M1&%T82`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"@@)&YE=U9A;'5E<R!A
M<R`D:V5Y/3XD=F%L=64@*2`@("`@("`O+R!Q=6]T92!T:&4@=F%L=65S+"!A
M<R!N965D960@9F]R('1H92!I;G-E<G0*("`@("`@("!["B`@("`@("`@("`@
M("1N97=$871A6R1T:&ES+3Y?9V5T0V]L3F%M92@D:V5Y*5T@/2`D=&AI<RT^
M9&)H+3YQ=6]T92@D=F%L=64I.PH@("`@("`@('T*"B`@("`@("`@+R\@=7-E
M('-E<75E;F-E<R!T;R!C<F5A=&4@82!N97<@:60@:6X@=&AE(&1B+71A8FQE
M"B`@("`@("`@)&YE>'1)9"`]("1T:&ES+3YD8F@M/FYE>'1)9"@D=&AI<RT^
M=&%B;&4I.PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(DE.4T525"!)3E1/
M("5S("@E<RPE<RD@5D%,5453("@E<RPE<RDB+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G1A8FQE("P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5T0V]L3F%M92@G:60G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H("<L)R`L(&%R<F%Y7VME>7,H
M)&YE=T1A=&$I("D@+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE
M>'1)9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H("<L
M)R`L("1N97=$871A("D@*3L*("`@("`@("!I9B@@1$(Z.FES17)R;W(H("1R
M97,@/2`D=&AI<RT^9&)H+3YQ=65R>2@@)'%U97)Y("D@*2`I"B`@("`@("`@
M>PH@("`@("`@("`@("`O+R!43T1/(')A:7-E(%!%05(@97)R;W(*("`@("`@
M("`@("`@<')I;G1F*")%4E)/4B`M(%1R964Z.F%D9"`M("5S("T@)7,\8G(^
M(BQ$0CHZ97)R;W)M97-S86=E*"1R97,I+"1Q=65R>2D["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;F5X
M=$ED.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*("`@("H@
M("!R96UO=F5S('1H92!G:79E;B!N;V1E"B`@("`J"B`@("`J("`@0'9E<G-I
M;VX@(#(P,#$O,3`O,#D*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@
M("H@("!`875T:&]R("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE
M<VEN9RYD93X*("`@("H@("!`<&%R86T@("`@;6EX960@("`D:60@("!T:&4@
M:60@;V8@=&AE(&YO9&4@=&\@8F4@<F5M;W9E9"P@;W(@86X@87)R87D@;V8@
M:60G<R!T;R!B92!R96UO=F5D"B`@("`J("`@0')E='5R;B`@(&)O;VQE86X@
M=')U92!O;B!S=6-C97-S"B`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E*"`D
M:60@*0H@("`@>PH@("`@("`@("\O(&EF('1H92!O;F4@=&\@<F5M;W9E(&AA
M<R!C:&EL9')E;BP@9V5T('1H96ER(&ED)W,@=&\@<F5M;W9E('1H96T@=&]O
M"B`@("`@("`@:68H("1T:&ES+3YH87-#:&EL9')E;B@D:60I("D*("`@("`@
M("`@("`@)&ED(#T@)'1H:7,M/G=A;&LH(&%R<F%Y*"=?<F5M;W9E)RPD=&AI
M<RD@+"`D:60@+"`G87)R87DG("D["@H@("`@("`@("1I9$-O;'5M;DYA;64@
M/2`G:60G.PH@("`@("`@("1M87`@/2`D=&AI<RT^9V5T3W!T:6]N*"=C;VQU
M;6Y.86UE36%P<R<I.PH@("`@("`@(&EF*"!I<W-E="@D;6%P6R=I9"==*2`I
M("`@("`@("`@("`@("`@("`@("`@+R\@:68@=&AE<F4@87)E(&UA<',@9VEV
M96X*("`@("`@("!["B`@("`@("`@("`@("1I9$-O;'5M;DYA;64@/2`D;6%P
M6R=I9"==.PH@("`@("`@('T*"B`@("`@("`@)'=H97)E0VQA=7-E(#T@(E=(
M15)%("1I9$-O;'5M;DYA;64])&ED(CL*("`@("`@("!I9B@@:7-?87)R87DH
M)&ED*2`I"B`@("`@("`@>PH@("`@("`@("`@("`D=VAE<F5#;&%U<V4@/2`B
M5TA%4D4@)&ED0V]L=6UN3F%M92!I;B`H(BYI;7!L;V1E*"`G+"<@+"`D:60@
M*2XG*2<["B`@("`@("`@?0H*("`@("`@("`D<75E<GD@/2`B1$5,151%($92
M3TT@>R1T:&ES+3YT86)L97T@)'=H97)E0VQA=7-E(CL*+R]P<FEN="@B/&)R
M/B(N)'%U97)Y*3L*("`@("`@("!I9B@@1$(Z.FES17)R;W(H("1R97,@/2`D
M=&AI<RT^9&)H+3YQ=65R>2@@)'%U97)Y("D@*2`I"B`@("`@("`@>PHO+R!4
M3T1/(')A:7-E(%!%05(@97)R;W(*("`@("`@("`@("`@<')I;G1F*")%4E)/
M4B`M(%1R964Z.G)E;6]V92`M("5S("T@)7,\8G(^(BQ$0CHZ97)R;W)M97-S
M86=E*"1R97,I+"1Q=65R>2D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B\O(%1/1$\@:68@<F5M;W9E('-U8V-E961E9"!S970@<')E
M=DED(&]F('1H92!F;VQL;W=I;F<@96QE;65N="!P<F]P97)L>0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T@+R\@96YD(&]F(&9U;F-T:6]N"@H@("`@
M+RHJ"B`@("`J("`@;6]V92!A;B!E;G1R>2!U;F1E<B!A(&=I=F5N('!A<F5N
M="!O<B!B96AI;F0@82!G:79E;B!E;G1R>0H@("`@*@H@("`@*B`@($!V97)S
M:6]N("`@(#(P,#$O,3`O,3`*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*
M("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M
M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@("`@(&EN=&5G97(@)&ED
M5&]-;W9E("`@=&AE(&ED(&]F('1H92!E;&5M96YT('1H870@<VAA;&P@8F4@
M;6]V960*("`@("H@("!`<&%R86T@("`@("!I;G1E9V5R("1N97=087)E;G1)
M9"`@("!T:&4@:60@;V8@=&AE(&5L96UE;G0@=VAI8V@@=VEL;"!B92!T:&4@
M;F5W('!A<F5N=`H@("`@*B`@($!P87)A;2`@("`@(&EN=&5G97(@)&YE=U!R
M979)9"`@("`@(&EF('!R979)9"!I<R!G:79E;B!T:&4@96QE;65N="!W:71H
M('1H92!I9"!I9%1O36]V90H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-H86QL(&)E(&UO=F5D(%]B96AI;F1?('1H92!E
M;&5M96YT('=I=&@@:60]<')E=DED"B`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@:70@:7,@,"!I="!W:6QL(&)E('!U
M="!A="!T:&4@8F5G:6YN:6YG"B`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@;F\@<')E=DED(&ES(&EN('1H92!$0B!I
M="!C86X@8F4@,"!T;V\@86YD('=O;B=T(&)O=&AE<@H@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-I;F-E(&ET(&ES(&YO
M="!W<FET=&5N(&EN('1H92!$0B!A;GEW87D*("`@("H@("!`<F5T=7)N("`@
M("!B;V]L96%N("`@("!T<G5E(&9O<B!S=6-C97-S"B`@("`J+PH@("`@9G5N
M8W1I;VX@;6]V92@@)&ED5&]-;W9E("P@)&YE=U!A<F5N=$ED("P@)&YE=U!R
M979)9#TP("D*("`@('L*"B`@("`@("`@)&ED0V]L=6UN3F%M92`]("=I9"<[
M"B`@("`@("`@)'!A<F5N=$ED0V]L=6UN3F%M92`]("=P87)E;G1)9"<["B`@
M("`@("`@)&UA<"`]("1T:&ES+3YG971/<'1I;VXH)V-O;'5M;DYA;65-87!S
M)RD["B`@("`@("`@:68H(&ES<V5T*"1M87!;)VED)UTI("D*("`@("`@("`@
M("`@)&ED0V]L=6UN3F%M92`]("1M87!;)VED)UT["B`@("`@("`@:68H(&ES
M<V5T*"1M87!;)W!A<F5N=$ED)UTI("D*("`@("`@("`@("`@)'!A<F5N=$ED
M0V]L=6UN3F%M92`]("1M87!;)W!A<F5N=$ED)UT["B\O($9)6%A-12!T;V1O
M.B!P<F5V:6]U<R!S='5F9@H*("`@("`@("`O+R!S970@=&AE('!A<F5N="!I
M;B!T:&4@1$(*("`@("`@("`D<75E<GD@/2`B55!$051%("1T:&ES+3YT86)L
M92!3150@)'!A<F5N=$ED0V]L=6UN3F%M93TD;F5W4&%R96YT260@5TA%4D4@
M)&ED0V]L=6UN3F%M93TD:614;TUO=F4B.PHO+W!R:6YT*"1Q=65R>2D["B`@
M("`@("`@:68H($1".CII<T5R<F]R*"`D<F5S(#T@)'1H:7,M/F1B:"T^<75E
M<GDH("1Q=65R>2`I("D@*0H@("`@("`@('L*+R\@5$]$3R!R86ES92!014%2
M(&5R<F]R"B`@("`@("`@("`@('!R:6YT9B@B15)23U(@+2!4<F5E.CIM;W9E
M("T@)7,@+2`E<SQB<CXB+$1".CIE<G)O<FUE<W-A9V4H)')E<RDL)'%U97)Y
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*+R\@1DE8
M6$U%('5P9&%T92!T:&4@<')E=DED)W,@;V8@=&AE(&5L96UE;G1S('=H97)E
M('1H92!E;&5M96YT('=A<R!M;W9E9"!A=V%Y(&9R;VT@86YD(&UO=F5D(&EN
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I
M;VX*"B`@("`O*BH*("`@("H@("!U<&1A=&4@86X@96QE;65N="!I;B!T:&4@
M1$(*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`Q+S$W"B`@("`J
M("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L
M9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`
M<&%R86T@("`@("!A<G)A>2`@("1N97=$871A("`@(&%L;"!T:&4@;F5W(&1A
M=&$L('1H92!K97D@)VED)R!I<R!U<V5D('1O"B`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B=6EL9"!T:&4@)U=(15)%(&ED/2<@
M8VQA=7-E(&%N9"!A;&P@=&AE(&]T:&5R"B`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!E;&5M96YT<R!A<F4@=&AE(&1A=&$@=&\@
M9FEL;"!I;B!T:&4@1$(*("`@("H@("!`<F5T=7)N("`@("!B;V]L96%N('1R
M=64@9F]R('-U8V-E<W,*("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&4H("1I
M9"`L("1N97=$871A("D*("`@('L*"B\O($9)6%A-12!C:&5C:R`D=&AI<RT^
M9&)H+3YT86)L94EN9F\@=&\@<V5E(&EF(&%L;"!T:&4@8V]L=6UN<R!T:&%T
M('-H86QL(&)E('5P9&%T960*+R\@<F5A;&QY(&5X:7-T+"!T:&ES('=I;&P@
M86QS;R!E>'1R86-T(&YE>'1)9"!E=&,N(&EF(&=I=F5N(&)E9F]R92!W<FET
M:6YG(&ET(&EN('1H92!$0@HO+R!I;B!C87-E('1H97D@9&]N="!E>&ES="!I
M;B!T:&4@1$(*("`@("`@("`D<V5T1&%T82`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"@@)&YE=T1A=&$@87,@)&ME>3T^)'9A;'5E("D@("`@("`@+R\@
M<75O=&4@=&AE('9A;'5E<RP@87,@;F5E9&5D(&9O<B!T:&4@:6YS97)T"B`@
M("`@("`@>PH@("`@("`@("`@("`D<V5T1&%T85M=(#T@)'1H:7,M/E]G971#
M;VQ.86UE*"1K97DI+B<])RXD=&AI<RT^9&)H+3YQ=6]T92@D=F%L=64I.PH@
M("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@@("`G55!$051%
M("5S(%-%5"`E<R!72$5212`E<STE<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L;V1E*"`G+"<@+"`D<V5T1&%T82`I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]G971#;VQ.86UE*"=I9"<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`@("`@:68H($1".CII<T5R<F]R*"`D<F5S/21T:&ES
M+3YD8F@M/G%U97)Y*"1Q=65R>2D@*2`I"B`@("`@("`@>PHO+R!&25A8344@
M<F%I<V4@4$5!4B!E<G)O<@H@("`@("`@("`@("!P<FEN=&8H(D524D]2("T@
M5')E93HZ=7!D871E("T@)7,@+2`E<SQB<CXB+$1".CIE<G)O<FUE<W-A9V4H
M)')E<RDL)'%U97)Y*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]("\O(&5N9"!O9B!F
M=6YC=&EO;@H*("`@("\J*@H@("`@*@H@("`@*@H@("`@*B`@($!A8V-E<W,@
M("`@('!R:79A=&4*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`S+S`R"B`@
M("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K
M<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T*("`@("H@("!`<F5T=7)N"B`@
M("`J+PH@("`@9G5N8W1I;VX@7W1H<F]W17)R;W(H("1M<V<@+"`D;&EN92`L
M("1M;V1E/6YU;&P@*0H@("`@>PH@("`@("`@(')E='5R;B!N97<@5')E95]%
M<G)O<B@@)&US9R`L("1L:6YE("P@7U]&24Q%7U\@+"`D;6]D92`L("1T:&ES
M+3YD8BT^;&%S=%]Q=65R>2`I.PH@("`@?0H*"@H@("`@+RHJ"B`@("`J("`@
M<')E<&%R92!M=6QT:7!L92!R97-U;'1S"B`@("`J"B`@("`J("`@0'-E92`@
M("`@("`@7W!R97!A<F5297-U;'0H*0H@("`@*B`@($!A8V-E<W,@("`@('!R
M:79A=&4*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`S+S`S"B`@("`J("`@
M0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN
M9RYD93X*("`@("H@("!`<&%R86T*("`@("H@("!`<F5T=7)N"B`@("`J+PH@
M("`@9G5N8W1I;VX@7W!R97!A<F5297-U;'1S*"`D<F5S=6QT<R`I"B`@("![
M"B`@("`@("`@)&YE=U)E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A
M8V@H("1R97-U;'1S(&%S("1A4F5S=6QT("D*("`@("`@("`@("`@)&YE=U)E
M<W5L='-;72`]("1T:&ES+3Y?<')E<&%R95)E<W5L="@D85)E<W5L="D["B`@
M("`@("`@<F5T=7)N("1N97=297-U;'1S.PH@("`@?0H*("`@("\J*@H@("`@
M*B`@(&UA<"!B86-K('1H92!I;F1E>"!N86UE<R!T;R!G970@=VAA="!I<R!E
M>'!E8W1E9`H@("`@*@H@("`@*B`@($!A8V-E<W,@("`@('!R:79A=&4*("`@
M("H@("!`=F5R<VEO;B`@("`R,#`R+S`S+S`S"B`@("`J("`@0&%U=&AO<B`@
M("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@
M("H@("!`<&%R86T*("`@("H@("!`<F5T=7)N"B`@("`J+PH@("`@9G5N8W1I
M;VX@7W!R97!A<F5297-U;'0H("1R97-U;'0@*0H@("`@>PH@("`@("`@("1M
M87`@/2`D=&AI<RT^9V5T3W!T:6]N*"=C;VQU;6Y.86UE36%P<R<I.PH*("`@
M("`@("!I9B@@)&UA<"`I"B`@("`@("`@9F]R96%C:"@@)&UA<"!A<R`D:V5Y
M/3XD8V]L=6UN3F%M92`I"B`@("`@("`@>PH@("`@("`@("`@("`D<F5S=6QT
M6R1K97E=(#T@)')E<W5L=%LD8V]L=6UN3F%M95T["B`@("`@("`@("`@('5N
M<V5T*"1R97-U;'1;)&-O;'5M;DYA;65=*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`J("`@=&AI<R!M
M971H;V0@<F5T<F5I=F5S('1H92!R96%L(&-O;'5M;B!N86UE+"!A<R!U<V5D
M(&EN('1H92!$0@H@("`@*B`@('-I;F-E('1H92!I;G1E<FYA;"!N86UE<R!A
M<F4@9FEX960L('1O(&)E('!O<G1A8FQE(&)E='=E96X@9&EF9F5R96YT"B`@
M("`J("`@1$(M8V]L=6UN(&YA;6EN9W,L('=E(&UA<"!T:&4@:6YT97)N86P@
M;F%M92!T;R!T:&4@<F5A;"!C;VQU;6X@;F%M92!H97)E"B`@("`J"B`@("`J
M("`@0&%C8V5S<R`@("`@<')I=F%T90H@("`@*B`@($!V97)S:6]N("`@(#(P
M,#(O,#,O,#(*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG
M(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;0H@("`@*B`@
M($!R971U<FX*("`@("HO"B`@("!F=6YC=&EO;B!?9V5T0V]L3F%M92@@)&EN
M=&5R;F%L3F%M92`I"B`@("!["B`@("`@("`@:68H("1M87`@/2`D=&AI<RT^
M9V5T3W!T:6]N*"`G8V]L=6UN3F%M94UA<',G("D@*0H@("`@("`@('L*("`@
M("`@("`@("`@:68H(&ES<V5T*"1M87!;)&EN=&5R;F%L3F%M95TI("D*("`@
M("`@("`@("`@("`@(')E='5R;B`D;6%P6R1I;G1E<FYA;$YA;65=.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&EN=&5R;F%L3F%M93L*("`@('T*"@I]
M("\O(&5N9"!O9B!C;&%S<PH_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O5')E92]-96UO<GDO6$U,+G!H<```````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(Q,C0`,3`T,3<S-C,P,#0`,#(P-C4W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(
M4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(
M4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC
M96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO
M+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@
M<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<G,Z(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`
M:W)I97-I;F<N9&4^("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("`D260Z(%A-3"YP:'`L=B`Q
M+C8@,C`P,R\P,2\P-"`Q,3HU-CHR."!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E
M(")834PO4&%R<V5R+G!H<"(["@HO*BH**B`@('1H92!834P@:6YT97)F86-E
M(&9O<B!T:&4@=')E92!C;&%S<PHJ"BH@("!`<&%C:V%G92`@5')E90HJ("`@
M0&%U=&AO<@HJ("`@0'9E<G-I;VX**B`@($!A8V-E<W,@('!U8FQI8PHJ+PIC
M;&%S<R!4<F5E7TUE;6]R>5]834P@97AT96YD<R!834Q?4&%R<V5R"GL*"B`@
M("`O*BH*("`@("H@("!`=F%R("`@(&%R<F%Y("`@)&1A=&$@("!T:&4@9FER
M<W0@96QE;65N="!H87,@=&\@8F4@96UP='DL('-O('=E(&-A;B!U<V4@=&AE
M('!A<F5N=$ED/3`@87,@(FYO('!A<F5N="(*("`@("HO"B`@("!V87(@)&1A
M=&$@/2!A<G)A>2@P/3Y.54Q,*3L*"B`@("`O*BH*("`@("H@("!`=F%R("`@
M(&EN=&5G97(@)&QE=F5L"B`@("`J+PH@("`@=F%R("1L979E;"`](#`["@H@
M("`@+RHJ"B`@("`J("`@0'9A<B`@("!A<G)A>2`@("1P87)E;G1)9$]N3&5V
M96P*("`@("HO"B`@("!V87(@)'!A<F5N=$ED3VY,979E;"`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`J("`@0'9A<B`@("!B;V]L96%N("1F;VQD:6YG("`@
M('-E="!C87-E(&9O;&1I;F<@9F]R('1H92!834Q?4&%R<V5R('1O(&9A;'-E
M"B`@("`J+PH@("`@=F%R("1F;VQD:6YG(#T@9F%L<V4[("`@+R\@='5R;B!O
M9F8@8V%S92!F;VQD:6YG"@H@("`@+RHJ"B`@("`J("`@0'9A<B`@("!B;V]L
M96%N("`@("!I9B!T<G5E(&ET(&-O;G9E<G1S(&%L;"!A='1R:6)U=&5S(&%N
M9"!T86<@;F%M97,@971C('1O(&QO=V5R(&-A<V4*("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('1H:7,@:7,@9&5F875L="P@<VEN8V4@:2!D;VYT('-E
M92!N;R!W87D@;V8@8V%S92!I;G-E;G-I=&EV92!C;VUP87)I<V]N"B`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@=')E92!C;&%S<RP@<VEN
M8V4@>6]U(&-A;B!A8V-E<W,@=&AE(&EN=&5R;F%L(&1A=&$@9&ER96-T;'D*
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]R('EO=2!G970@=&AE;2!R
M971U<FYE9"`N+BX@:2!K;F]W('1H:7,@:7,@;F]T(#$P,"4@<')O<&5R($]/
M4"!B=70@=&AA="=S(&AO=R!I="!I<R!R:6=H="!N;W<*("`@("HO"B`@("!V
M87(@)%]T;TQO=V5R(#T@=')U93L*"B`@("`O*BH*("`@("H*("`@("H*("`@
M("H@("!`=F5R<VEO;B`@("`R,#`R+S`Q+S$W"B`@("`J("`@0&%C8V5S<R`@
M("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN
M9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<F5T=7)N("`@("!B
M;V]L96%N("`@("!T<G5E(&]N('-U8V-E<W,*("`@("HO"B`@("!F=6YC=&EO
M;B!4<F5E7TUE;6]R>5]834PH("1D<VX@+"`D;W!T:6]N<R`I"B`@("!["B`@
M("`@("`@)&AA;F1L92`]("1D<VX["@H@("`@("`@("1T:&ES+3Y834Q?4&%R
M<V5R*"D["@H@("`@("`@(&EF("A`:7-?<F5S;W5R8V4H)&AA;F1L92DI('L*
M("`@("`@("`@("`@)'1H:7,M/G-E=$EN<'5T*"1H86YD;&4I.PH@("`@("`@
M('T@96QS96EF("@D:&%N9&QE("$]("(B*2!["B`@("`@("`@("`@("1T:&ES
M+3YS971);G!U=$9I;&4H)&AA;F1L92D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*").;R!F:6QE;F%M
M92!P87-S960N(BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*@H@
M("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#$O,3<*("`@("H@("!`
M86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M
M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!R971U
M<FX@("`@(&)O;VQE86X@("`@('1R=64@;VX@<W5C8V5S<PH@("`@*B\*("`@
M(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D<&%R<V5R+"`D96QE;65N="P@)&%T
M=')I8G,I"B`@("!["B`@("`@("`@)&5L96UE;G1"969O<F5)9"`]('-I>F5O
M9B@D=&AI<RT^9&%T82DM,3L*("`@("`@("`D8W5R260@/2!S:7IE;V8H)'1H
M:7,M/F1A=&$I.PH*("`@("`@("`D=&AI<RT^9&%T85LD8W5R261=6R=I9"==
M(#T@)&-U<DED.PH@("`@("`@("1T:&ES+3YD871A6R1C=7))9%U;)VYA;64G
M72`]("1T:&ES+3Y?=&],;W=E<B`_('-T<G1O;&]W97(H)&5L96UE;G0I(#H@
M)&5L96UE;G0["B`@("`@("`@)'1H:7,M/F1A=&%;)&-U<DED75LG;&5V96PG
M72`]("1T:&ES+3YL979E;#L*("`@("`@("`D=&AI<RT^9&%T85LD8W5R261=
M6R=A='1R:6)U=&5S)UT@/2`D871T<FEB<SL*("`@("`@("!I9B@@)'1H:7,M
M/E]T;TQO=V5R("D*("`@("`@("!["B`@("`@("`@("`@("1T:&ES+3YD871A
M6R1C=7))9%U;)V%T=')I8G5T97,G72`](&%R<F%Y*"D["B`@("`@("`@("`@
M(&9O<F5A8V@H("1A='1R:6)S(&%S("1K97D]/B1V86QU92`I"B`@("`@("`@
M("`@("`@("`D=&AI<RT^9&%T85LD8W5R261=6R=A='1R:6)U=&5S)UU;<W1R
M=&]L;W=E<B@D:V5Y*5T@/2`D=F%L=64["B`@("`@("`@?0H*("`@("`@("!I
M9B@@:7-S970H)'1H:7,M/F1A=&%;)&5L96UE;G1"969O<F5)9%U;)VQE=F5L
M)UTI("8F"B`@("`@("`@("`@("1T:&ES+3YL979E;"`]/2`D=&AI<RT^9&%T
M85LD96QE;65N=$)E9F]R94ED75LG;&5V96PG72`I("`O+R!I<R!T:&%T(&$@
M;F5W(&-H:6QD+"!O<B!J=7-T(&$@)VYE>'0G(&]F(&$@8VAI;&0_"B`@("`@
M("`@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LD8W5R261=6R=P87)E;G1)
M9"==(#T@)'1H:7,M/F1A=&%;)&5L96UE;G1"969O<F5)9%U;)W!A<F5N=$ED
M)UT["B`@("`@("`@?0H@("`@("`@(&5L<V4@("`@+R\@<V5T('-T=69F(&9O
M<B!T:&4@9FER<W0@8VAI;&0@(2$A"B`@("`@("`@>PH@("`@("`@("`@("!I
M9B@@)'1H:7,M/FQE=F5L/C`@*2`@("`O+R!T:&4@<F]O="!H87,@;F\@<&%R
M96YT"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1P87)E;G1)9"`]
M("1T:&ES+3YP87)E;G1)9$]N3&5V96Q;)'1H:7,M/FQE=F5L+3%=.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F1A=&%;)&-U<DED75LG<&%R96YT260G72`]
M("1P87)E;G1)9#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E"B`@
M("`@("`@("`@('L*("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1C=7))
M9%U;)W!A<F5N=$ED)UT@/2`P.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3YP87)E;G1)9$]N3&5V96Q;)'1H:7,M/FQE=F5L72`]
M("1C=7))9#L*"B-P<FEN="`B)&-U<DED("1E;&5M96YT("(N)'1H:7,M/F1A
M=&%;)&-U<DED75LG<&%R96YT260G72XG/&)R/B<["B`@("`@("`@)'1H:7,M
M/FQE=F5L*RL["B`@("!]"@H@("`@+RHJ"B`@("`J"B`@("`J"B`@("`J("`@
M0'9E<G-I;VX@("`@,C`P,B\P,2\Q-PH@("`@*B`@($!A8V-E<W,@("`@('!U
M8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O
M;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0')E='5R;B`@("`@8F]O;&5A
M;B`@("`@=')U92!O;B!S=6-C97-S"B`@("`J+PH@("`@9G5N8W1I;VX@96YD
M2&%N9&QE<B@D<&%R<V5R+"`D96QE;65N="D*("`@('L*("`@("`@("`D=&AI
M<RT^;&5V96PM+3L*("`@('T*"B`@("`O*BH*("`@("H*("`@("H*("`@("H@
M("!`=F5R<VEO;B`@("`R,#`R+S`Q+S$W"B`@("`J("`@0&%C8V5S<R`@("`@
M<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\
M=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<F5T=7)N("`@("!B;V]L
M96%N("`@("!T<G5E(&]N('-U8V-E<W,*("`@("HO"B`@("!F=6YC=&EO;B!C
M9&%T84AA;F1L97(H)'!A<G-E<BP@)&-D871A*0H@("`@>PHC(%%515-424].
M.B!W:'D@:7,@=&AI<R!M971H;V0@8V%L;&5D(&UU;'1I<&QE('1I;65S(&9O
M<B!O;F4@96QE;65N=#\*(R!I<R!E=F5R>2!S<&%C92!A(&-D871A(#\_/PHC
M($%.4U=%4CH@:68@>6]U(&-A;&P@>&UL7W!A<G-E*"1P87)S97(L(")F;V\@
M(BP@9F%L<V4I(&%N9"!T:&5N"B,@("`@("`@("!X;6Q?<&%R<V4H)'!A<G-E
M<BP@(F)A<B(L('1R=64I+"!C86QL8F%C:W,@87)E(&1O;F4@;VYC90HC("`@
M("`@("`@9F]R(&5A8V@@>&UL7W!A<G-E*"D@8V%L;"X*("`@("`@("!I9B@@
M(6ES<V5T*"1T:&ES+3YD871A6R!S:7IE;V8H)'1H:7,M/F1A=&$I+3$@75LG
M8V1A=&$G72D@*0H@("`@("`@("`@("`D=&AI<RT^9&%T85L@<VEZ96]F*"1T
M:&ES+3YD871A*2TQ(%U;)V-D871A)UT@/2`G)SL*(W!R:6YT(")C9&%T82`]
M("<D8V1A=&$G7')<;B(["B`@("`@("`@)'1H:7,M/F1A=&%;('-I>F5O9B@D
M=&AI<RT^9&%T82DM,2!=6R=C9&%T82==+CT@)&-D871A.PH@("`@?0H*("`@
M("\J*@H@("`@*@H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#$O
M,3<*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R
M("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@
M("`@*B`@($!R971U<FX@("`@(&)O;VQE86X@("`@('1R=64@;VX@<W5C8V5S
M<PH@("`@*B\*("`@(&9U;F-T:6]N(&1E9F%U;'1(86YD;&5R*"1P87)S97(L
M("1C9&%T82D*("`@('L*(R`@("`@("`@)'1H:7,M/F1A=&%;('-I>F5O9B@D
M=&AI<RT^9&%T82DM,2!=6R=C9&%T82==(#T@)&-D871A.PHC(&YO="!I;B!U
M<V4@>65T(#HM*"!I<R!T:&%T(&]K/S\*("`@('T*"@H*"B`@("`O*BH*("`@
M("H@("!R96%D('1H92!D871A(&9R;VT@=&AE('AM;"!F:6QE(&%N9"!P<F5P
M87)E('1H96T@<V\@=&AE('1R964*("`@("H@("!C;&%S<R!C86X@=V]R:R!W
M:71H(&ET+"!T:&4@<')E<&%R871I;VX@:7,@;6%I;FQY(&1O;F4@:6X@<W1A
M<G1(86YD;&5R"B`@("`J"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P,2\Q
M-PH@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@
M("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@
M("`J("`@0')E='5R;B`@("`@8F]O;&5A;B`@("`@=')U92!O;B!S=6-C97-S
M"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T=7`H*0H@("`@>PH@("`@("`@("1T
M:&ES+3YP87)S92@I.PH*("`@("`@("!R971U<FX@)'1H:7,M/F1A=&$["B`@
M("!]("\O(&5N9"!O9B!F=6YC=&EO;@H*("`@("\J*@H@("`@*B`@(')E860@
M=&AE(&1A=&$@9G)O;2!A;B!X;6P@<W1R:6YG(&%N9"!P<F5P87)E('1H96T@
M<V\@=&AE('1R964*("`@("H@("!C;&%S<R!C86X@=V]R:R!W:71H(&ET+"!T
M:&4@<')E<&%R871I;VX@:7,@;6%I;FQY(&1O;F4@:6X@<W1A<G1(86YD;&5R
M"B`@("`J"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P,B\P-0H@("`@*B`@
M($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R
M86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0')E
M='5R;B`@("`@8F]O;&5A;B`@("`@=')U92!O;B!S=6-C97-S"B`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T=7!">5)A=T1A=&$H("1X;6Q3=')I;F<@*0H@("`@
M>PH@("`@("`@("1T:&ES+3YP87)S95-T<FEN9R@@)'AM;%-T<FEN9R`L('1R
M=64@*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A.PH@("`@?0H*("`@
M("\J*@H@("`@*B`@(%1/($)%($E-4$Q%34Y4140*("`@("H@("!A9&1S(%]O
M;F5?(&YE=R!E;&5M96YT(&EN('1H92!T<F5E('5N9&5R('1H92!G:79E;B!P
M87)E;G0*("`@("H@("!T:&4@=F%L=65S)R!K97ES(&=I=F5N(&AA=F4@=&\@
M;6%T8V@@=&AE(&1B+6-O;'5M;G,L(&)E8V%U<V4@=&AE"B`@("`J("`@=F%L
M=64@9V5T<R!I;G-E<G1E9"!I;B!T:&4@9&(@9&ER96-T;'D*("`@("H@("!T
M;R!A9&0@86X@96YT:7)E(&YO9&4@8V]N=&%I;FEN9R!C:&EL9')E;B!A;F0@
M<V\@;VX@<V5E("=A9&1.;V1E*"DG"B`@("`J"B`@("`J("`@0'-E92`@("`@
M("`@861D3F]D92@I"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,2\Q,"\P.0H@
M("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@
M(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J
M("`@0'!A<F%M("`@("`@87)R87D@)&YE=U9A;'5E<R!T:&ES(&%R<F%Y(&-O
M;G1A:6YS('1H92!V86QU97,@=&AA="!S:&%L;"!B92!I;G-E<G1E9"!I;B!T
M:&4@9&(M=&%B;&4*("`@("H@("!`<F5T=7)N("`@("!M:7AE9"`@(&5I=&AE
M<B!B;V]L96%N(&9A;'-E(&]N(&9A:6QU<F4@;W(@=&AE(&ED(&]F('1H92!I
M;G-E<G1E9"!R;W<*("`@("HO"B\J("`@(&9U;F-T:6]N(&%D9"@@)&YE=U9A
M;'5E<R`I"B`@("!["B`@("`@("`@+R\@861D('1H92!D871A(&EN('1H92!I
M;G1E<FYA;"!S=')U8W1U<F4@)'1H:7,M/F1A=&$*("`@("`@("`D=&AI<RT^
M9&%T85MS:7IE;V8H)'1H:7,M/F1A=&$I72`]("1N97=686QU97,["@HC(&D@
M86T@=&AI;FMI;F<@:68@:70@;6EG:'0@8F4@82!G;V]D('-O;'5T:6]N('1O
M('=A;&L@=&AE(&1A=&$M87)R87D*(R!A;F0@=W)I=&4@96%C:"!L:6YE('-I
M;F=L96QY('5N=&EL('1H92!O;F4@=&\@861D(&-O;65S+"!W<FET92!I="!A
M;F0*(R!K965P(&]N('=R:71I;F<@=&AE(&1A=&$M87)R87D*(R!B=70@=&AA
M="!M96%N<R!W<FET:6YG('1H92!E;G1I<F4@9FEL92!E=F5R>2!T:6UE(&%N
M>2!M971H;V0@=&AA=`HC(&-H86YG97,@=&AE('AM;"UF:6QE)W,@<W1R=6-T
M=7)E('1H92!E;G1I<F4@9FEL92!I<R!W<FET=&5N+`HC(&-A;B!T:&%T(&YO
M="!B92!D;VYE('-O;65H;W<@8F5T=&5R(#\_/PH*(R`@("`@("`@+R\@86YD
M(')E9V5N97)A=&4@=&AE('AM;"!F:6QE"B,@("`@("`@("1T:&ES+3Y?=W)I
M=&5&:6QE*"D["@H@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX**B\*("`@("\J
M*@H@("`@*B`@(%1/($)%($E-4$Q%34Y4140*("`@("H@("!R96UO=F5S('1H
M92!G:79E;B!N;V1E"B`@("`J"B`@("`J("`@0'9E<G-I;VX@(#(P,#$O,3`O
M,#D*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R
M("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@
M("H@("!`<&%R86T@("`@;6EX960@("`D:60@("!T:&4@:60@;V8@=&AE(&YO
M9&4@=&\@8F4@<F5M;W9E9`H@("`@*B`@($!R971U<FX@("!B;V]L96%N('1R
M=64@;VX@<W5C8V5S<PH@("`@*B\*+RH@("`@9G5N8W1I;VX@<F5M;W9E*"`D
M:60@*0H@("`@>PH@("`@("`@("\O(')E;6]V92!T:&4@9&%T82!F<F]M('1H
M:7,M/F1A=&$*("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LD:61=*3L*"B,@
M<V5E(&-O;6UE;G0@:6X@(F%D9"(M;65T:&]D"B`@("!]("\O(&5N9"!O9B!F
M=6YC=&EO;@HJ+PH@("`@+RHJ"B`@("`J("`@5$\@0D4@24U03$5-3E1%1`H@
M("`@*B`@(&UO=F4@86X@96YT<GD@=6YD97(@82!G:79E;B!P87)E;G0@;W(@
M8F5H:6YD(&$@9VEV96X@96YT<GD*("`@("H*("`@("H@("!`=F5R<VEO;B`@
M("`R,#`Q+S$P+S$P"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J
M("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE
M<VEN9RYD93X*("`@("H@("!`<&%R86T*("`@("H@("!`<&%R86T*("`@("H@
M("!`<&%R86T@("`@("!I;G1E9V5R(&EF('!R979)9"!I<R!G:79E;B!T:&4@
M96QE;65N="!W:71H('1H92!I9"!I9%1O36]V92!S:&%L;"!B92!M;W9E9"!?
M8F5H:6YD7R!E;&5M96YT('=I=&@@:60]<')E=DED"B`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!B969O<F4@=V]U;&0@8F4@96%S:65R+"!B=70@=&AE
M;B!N;R!E;&5M96YT(&-O=6QD(&)E(&EN<V5R=&5D(&%T('1H92!E;F0@.BTO
M"B`@("`J("`@0')E='5R;B`@("`@8F]O;&5A;B`@("`@=')U92!F;W(@<W5C
M8V5S<PH@("`@*B\*+RH@("`@9G5N8W1I;VX@;6]V92@@)&ED5&]-;W9E("P@
M)&YE=U!A<F5N=$ED("P@)'!R979)9#TP("D*("`@('L*("`@("`@("`D=&AI
M<RT^9&%T85LD:614;TUO=F5=6R=P87)E;G1)9"==(#T@)&YE=U!A<F5N=$ED
M.PH@("`@("`@("1T:&ES+3YD871A6R1I9%1O36]V95U;)W!R979)9"==(#T@
M)'!R979)9#L*"B,@<V5E(&-O;6UE;G0@:6X@(F%D9"(M;65T:&]D"B`@("!]
M("\O(&5N9"!O9B!F=6YC=&EO;@HJ+PH*?0H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U1R964O1'EN
M86UI8R\`````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#`T`#`Q-S8R-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O5')E92]$>6YA;6EC+T1";F5S=&5D+G!H<```````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`Q,3,Q,#(`,3`T,3<S-C,P,#0`,#(R,#(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!6
M97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS
M92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\
M(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($%U=&AO<G,Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("`D260Z($1";F5S=&5D+G!H<"QV
M(#$N,38@,C`P,R\P,R\P-"`Q.#HU-SHQ."!C86EN($5X<"`D"@IR97%U:7)E
M7V]N8V4H)U1R964O0V]M;6]N+G!H<"<I.PIR97%U:7)E7V]N8V4H)U1R964O
M17)R;W(N<&AP)RD["@HO*BH**B`@('1H:7,@8VQA<W,@:6UP;&5M96YT<R!M
M971H;V1S('1O('=O<FL@;VX@82!T<F5E('-A=F5D('5S:6YG('1H92!N97-T
M960**B`@('1R964@;6]D96P**B`@(&5X<&QA:6YA=&EO;CH@:'1T<#HO+W)E
M<V5A<F-H+F-A;&%C861E;7DN;W)G+W1A9B]P<F]C965D:6YG<R]B86QL97<O
M:6YD97@N:'1M"BH**B`@($!A8V-E<W,@("`@('!U8FQI8PHJ("`@0'!A8VMA
M9V4@("`@5')E90HJ+PIC;&%S<R!4<F5E7T1Y;F%M:6-?1$)N97-T960@97AT
M96YD<R!4<F5E7T-O;6UO;@HO+R!&25A8344@<VAO=6QD(&%C='5A;&QY(&5X
M=&5N9"!4<F5E7T-O;6UO;BP@=&\@=7-E('1H92!M971H;V1S('!R;W9I9&5D
M(&EN('1H97)E+BXN(&)U="!W92!N965D('1O(&-O;FYE8W0*+R\@=&\@=&AE
M(&1B(&AE<F4L('-O('=E(&5X=&5N9"!O<'1I;VYS1$(@9F]R(&YO=RP@;6%Y
M(&)E('5S92`B86=G<F5G871E(B!F=6YC=&EO;B!T;R!F:7@@=&AA=`I["@H@
M("`@=F%R("1D96)U9R`](#`["@H@("`@=F%R("1O<'1I;VYS(#T@87)R87DH
M"B\O($9)6%A-12!T;R!B92!I;7!L96UE;G1E9`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W=H97)E061D3VXG/3XG)R`@("`O+R!A9&0@;VX@9F]R
M('1H92!W:&5R92!C;&%U<V4L('1H:7,@<W1R:6YG(&ES('-I;7!L>2!A9&1E
M9"!B96AI;F0@=&AE(%=(15)%(&EN('1H92!S96QE8W0*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<V\@>6]U
M(&)E='1E<B!M86ME('-U<F4@:71S(&-O<G)E8W0@4U%,(#HM*2P@:2YE+B`G
M=6ED/3,G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O('1H:7,@:7,@;F5E9&5D(&DN92X@=VAE;B!Y;W4@87)E
M('-A=FEN9R!M86YY('1R965S(&EN(&]N92!D8BUT86)L90H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+"=T86)L92<@("`@(#T^)R<@("`O+PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@<VEN8V4@=&AE(&EN=&5R;F%L
M(&YA;65S(&%R92!F:7AE9"P@=&\@8F4@<&]R=&%B;&4@8F5T=V5E;B!D:69F
M97)E;G0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($1"('1A8FQE
M<R!W:71H(&1I9F9E<F5N="!C;VQU;6X@;F%M:6YG<RP@=V4@;6%P('1H92!I
M;G1E<FYA;"!N86UE('1O('1H92!R96%L(&-O;'5M;B!N86UE"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!U<VEN9R!T:&ES(&%R<F%Y(&AE<F4L
M(&EF(&ET('-T87ES(&5M<'1Y('1H92!I;G1E<FYA;"!N86UE<R!A<F4@=7-E
M9"P@=VAI8V@@87)E.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M:60L(&QE9G0L(')I9VAT"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`L
M)V-O;'5M;DYA;65-87!S)ST^87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O)VED)R`@("`@("`@("`@
M(#T^("`G;F]D95]I9"<L("`@("\O('5S92`B;F]D95]I9"(@87,@(FED(@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VQE9G0G("`@("`@("`@(#T^("`G;"<@("`@("`@("`@("`O+R!S:6YC
M92!M>7-Q;"!A="!L96%S="!D;V5S;G0@<W5P<&]R="`G;&5F="<@+BXN"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("PG<FEG:'0G("`@("`@("`@/3X@("=R)R`@("`@("`@("`@("\O("XN+F%S
M(&$@8V]L=6UN(&YA;64@=V4@<V5T(&1E9F%U;'0@=&\@=&AE(&9I<G-T(&QE
M='1E<B!O;FQY"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O)VYA;64G("`@("`@("`@(#T^("`G;F]D94YA;64G
M("`O+PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`L)W!A<F5N=$ED)R`@("`@("`]/B`@)W!A<F5N="<@("`@+R\@
M<&%R96YT(&ED"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("PG
M;W)D97(G("`@(#T^("<G("`@+R\@;F5E9&5D(&9O<B!S;W)T:6YG('1H92!T
M<F5E+"!C=7)R96YT;'D@;VYL>2!U<V5D(&EN($UE;6]R>5]$0FYE<W1E9`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B\O('1H92!D969I;F5D
M(&UE=&AO9',@:&5R92!A<F4@<')O<&]S86QS(&9O<B!T:&4@:6UP;&5M96YT
M871I;VXL"B\O('1H97D@87)E(&YA;65D('1H92!S86UE+"!A<R!T:&4@;65T
M:&]D<R!I;B!T:&4@(DUE;6]R>2(@8G)A;F-H+"!I9B!P;W-S:6)L90HO+R!I
M="!W;W5L9"!B92!C;V]L('1O(&ME97`@=&AE('-A;64@;F%M:6YG(&%N9"!I
M9B!T:&4@<V%M92!P87)A;65T97)S('=O=6QD(&)E('!O<W-I8FQE('1O;PHO
M+R!T:&5N(&ET('=O=6QD(&)E(&5V96X@8F5T=&5R+"!S;R!O;F4@8V]U;&0@
M96%S:6QY(&-H86YG92!F<F]M(&%N>2!K:6YD(&]F"B\O('1R964M:6UP;&5M
M96YT871I;VX@=&\@86YO=&AE<BP@=VET:&]U="!C:&%N9VEN9R!T:&4@<V]U
M<F-E(&-O9&4L(&]N;'D@=&AE('-E='5P6%A8('=O=6QD(&YE960@=&\@8F4@
M8VAA;F=E9`H*("`@("\J*@H@("`@*@H@("`@*@H@("`@*B`@($!A8V-E<W,@
M("`@('!U8FQI8PH@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#,O,#(*("`@
M("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR
M:65S:6YG+F1E/@H@("`@*B`@($!P87)A;0H@("`@*B`@($!R971U<FX*("`@
M("HO"B`@("!F=6YC=&EO;B!?7V-O;G-T<G5C="@@)&1S;B`L("1O<'1I;VYS
M/6%R<F%Y*"D@*0H@("`@>PH@("`@("`@(%1R965?1'EN86UI8U]$0FYE<W1E
M9"@@)&1S;B`L("1O<'1I;VYS("D["B`@("!]"@H@("`@+RHJ"B`@("`J"B`@
M("`J"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0'9E<G-I
M;VX@("`@,C`P,B\P,R\P,@H@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@
M2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M
M"B`@("`J("`@0')E='5R;@H@("`@*B\*("`@(&9U;F-T:6]N(%1R965?1'EN
M86UI8U]$0FYE<W1E9"@@)&1S;B`L("1O<'1I;VYS/6%R<F%Y*"D@*0H@("`@
M>PH@("`@("`@('!A<F5N=#HZ5')E95]/<'1I;VYS1$(H("1D<VX@+"`D;W!T
M:6]N<R`I.R`O+R!I;G-T86YC:6%T92!$0@H@("`@("`@("1T:&ES+3YT86)L
M92`]("1T:&ES+3YG971/<'1I;VXH)W1A8FQE)RD["B`@("!]"@H@("`@+RHJ
M"B`@("`J("`@861D(&$@;F5W(&5L96UE;G0@=&\@=&AE('1R964*("`@("H@
M("!T:&5R92!A<F4@=&AR964@=V%Y<R!T;R!U<V4@=&AI<R!M971H;V0*("`@
M("H@("`Q+@H@("`@*B`@(&=I=F4@;VYL>2!T:&4@)'!A<F5N=$ED(&%N9"!T
M:&4@)&YE=U9A;'5E<R!W:6QL(&)E(&EN<V5R=&5D(&%S('1H92!F:7)S="!C
M:&EL9"!O9B!T:&ES('!A<F5N=`H@("`@*B`@(&DN92X@("`@+R\@:6YS97)T
M(&$@;F5W(&5L96UE;G0@=6YD97(@=&AE('!A<F5N="!W:71H('1H92!)1#TW
M"B`@("`J("`@("`@("`@("`D=')E92T^861D*"!A<G)A>2@G;F%M92<]/B=N
M97<@96QE;65N="!N86UE)RD@+"`W("D["B`@("`J("`@,BX*("`@("H@("!G
M:79E('1H92`D<')E=DED("@D<&%R96YT260@=VEL;"!B92!D:7-M:7-S960I
M(&%N9"!T:&4@;F5W(&5L96UE;G0*("`@("H@("!W:6QL(&)E(&EN<V5R=&5D
M(&EN('1H92!T<F5E(&%F=&5R('1H92!E;&5M96YT('=I=&@@=&AE($E$/21P
M<F5V260*("`@("H@("!T:&4@<&%R96YT260@:7,@;F]T(&YE8V5S<V%R>2!B
M96-A=7-E('1H92!P<F5V260@9&5F:6YE<R!E>&%C=&QY('=H97)E"B`@("`J
M("`@=&AE(&YE=R!E;&5M96YT(&AA<R!T;R!B92!P;&%C92!I;B!T:&4@=')E
M92P@86YD('1H92!P87)E;G0@:7,@=&AE('-A;64@87,*("`@("H@("!F;W(@
M=&AE(&5L96UE;G0@=VET:"!T:&4@240])'!R979)9`H@("`@*B`@(&DN92X@
M("`@+R\@:6YS97)T(&$@;F5W(&5L96UE;G0@869T97(@=&AE(&5L96UE;G0@
M=VET:"!T:&4@240]-0H@("`@*B`@("`@("`@("`@)'1R964M/F%D9"@@87)R
M87DH)VYA;64G/3XG;F5W)RD@+"`P("P@-2`I.PH@("`@*B`@(#,N"B`@("`J
M("`@;F5I=&AE<B`D<&%R96YT260@;F]R('!R979)9"!I<R!G:79E;BP@=&AE
M;B!T:&4@<F]O="!E;&5M96YT('=I;&P@8F4@:6YS97)T960*("`@("H@("!T
M:&ES(')E<75I<F5S('1H870@<')O9W)A;6UE<B!I<R!R97-P;VYS:6)L92!T
M;R!C;VYF:7)M('1H:7,*("`@("H@("!T:&ES(&UE=&AO9"!D;V5S(&YO="`H
M>65T*2!C:&5C:R!I9B!T:&5R92!I<R!A;')E861Y(&$@<F]O="!E;&5M96YT
M('-A=F5D("$A(0H@("`@*@H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@
M("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`
M:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@87)R87D@("`D;F5W
M5F%L=65S("!T:&ES(&%R<F%Y(&-O;G1A:6YS('1H92!V86QU97,@=&AA="!S
M:&%L;"!B92!I;G-E<G1E9"!I;B!T:&4@9&(M=&%B;&4*("`@("H@("!`<&%R
M86T@("`@("!I;G1E9V5R("1P87)E;G1)9"`@('1H92!I9"!O9B!T:&4@96QE
M;65N="!W:&EC:"!S:&%L;"!B92!T:&4@<&%R96YT(&]F('1H92!N97<@96QE
M;65N=`H@("`@*B`@($!P87)A;2`@("`@(&EN=&5G97(@)'!R979)9"`@("`@
M=&AE(&ED(&]F('1H92!E;&5M96YT('=H:6-H('-H86QL('!R96-E960@=&AE
M(&]N92!T;R!B92!I;G-E<G1E9`H@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=7-E(&5I=&AE<B`G<&%R96YT260G(&]R("=P<F5V
M260G"B`@("`J("`@0')E='5R;B`@("`@:6YT96=E<B!T:&4@240@;V8@=&AE
M(&5L96UE;G0@=&AA="!H860@8F5E;B!I;G-E<G1E9`H@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9"@@)&YE=U9A;'5E<R`L("1P87)E;G1)9#TP("P@)'!R979)
M9#TP("D*("`@('L*("`@("`@("`D;$YA;64@/2`D=&AI<RT^7V=E=$-O;$YA
M;64H)VQE9G0G*3L*("`@("`@("`D<DYA;64@/2`D=&AI<RT^7V=E=$-O;$YA
M;64H)W)I9VAT)RD["B`@("`@("`@)'!R9796:7-I=&5D(#T@,#L*"B`@("`@
M("`@+R\@8VAE8VL@=&AE($1"+71A8FQE(&EF('1H92!C;VQU;6YS('=H:6-H
M(&%R92!G:79E;B!A<R!K97ES"B`@("`@("`@+R\@:6X@=&AE(&%R<F%Y("1N
M97=686QU97,@9&\@<F5A;&QY(&5X:7-T+"!I9B!N;W0@<F5M;W9E('1H96T@
M9G)O;2!T:&4@87)R87D*+R\@1DE86$U%(&1O('1H92!A8F]V92!D97-C<FEB
M960*"B`@("`@("`@:68H("1P87)E;G1)9"!\?"`D<')E=DED("D@("`@("`@
M("`@("`@("`@("`O+R!I9B!N;R!P87)E;G0@86YD(&YO('!R979)9"!I<R!G
M:79E;B!T:&4@<F]O="!S:&%L;"!B92!A9&1E9`H@("`@("`@('L*("`@("`@
M("`@("`@:68H("1P<F5V260@*0H@("`@("`@("`@("!["B`@("`@("`@("`@
M("`@("`D96QE;65N="`]("1T:&ES+3YG971%;&5M96YT*"`D<')E=DED("D[
M"B`@("`@("`@("`@("`@("`D<&%R96YT260@/2`D96QE;65N=%LG<&%R96YT
M260G73L@("`@("`@+R\@=V4@86QS;R!N965D('1H92!P87)E;G0@:60@;V8@
M=&AE(&5L96UE;G0L('1O('=R:71E(&ET(&EN('1H92!D8@H@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4*("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@)&5L96UE;G0@/2`D=&AI<RT^9V5T16QE;65N="@@)'!A<F5N=$ED
M("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YE=U9A;'5E<ULG<&%R
M96YT260G72`]("1P87)E;G1)9#L*"B`@("`@("`@("`@(&EF*"!014%2.CII
M<T5R<F]R*"1E;&5M96YT*2`I"B`@("`@("`@("`@("`@("!R971U<FX@)&5L
M96UE;G0["@H@("`@("`@("`@("`O+R!G970@=&AE(")V:7-I=&5D(BUV86QU
M92!W:&5R92!T;R!A9&0@=&AE(&YE=R!E;&5M96YT(&)E:&EN9`H@("`@("`@
M("`@("`O+R!I9B`D<')E=DED(&ES(&=I=F5N+"!W92!N965D('1O('5S92!T
M:&4@<FEG:'0M=F%L=64*("`@("`@("`@("`@+R\@:68@;VYL>2!T:&4@)'!A
M<F5N=$ED(&ES(&=I=F5N('=E(&YE960@=&\@=7-E('1H92!L969T+79A;'5E
M"B`@("`@("`@("`@("\O(&QO;VL@870@:70@9W)A<&AI8V%L;'DL('1H870@
M;6%D92!M92!U;F1E<G-T86YD(&ET(#HM*0H@("`@("`@("`@("`O+R!I+F4N
M(&%T.B!H='1P.B\O<F5S96%R8V@N8V%L86-A9&5M>2YO<F<O=&%F+W!R;V-E
M961I;F=S+V)A;&QE=R]S;&0P,S0N:'1M"B`@("`@("`@("`@("1P<F5V5FES
M:71E9"`]("1P<F5V260@/R`D96QE;65N=%LG<FEG:'0G72`Z("1E;&5M96YT
M6R=L969T)UT["@HO+R!&25A8344@<W1A<G0@=')A;G-A8W1I;VX@:&5R90H*
M("`@("`@("`@("`@:68H(%!%05(Z.FES17)R;W(H)&5R<CTD=&AI<RT^7V%D
M9"@@)'!R9796:7-I=&5D("P@,2`I*2`I"B`@("`@("`@("`@('L*("`@("\O
M($9)6%A-12!R;VQL8F%C:PH@("`@("`@("`@("`@("`@+R\D=&AI<RT^9&)H
M+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&EN<V5R=&EN9R!?
M;VYE7R!N97<@96QE;65N="!I;B!T:&4@=')E90H@("`@("`@("1N97=$871A
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H*"`D;F5W5F%L=65S(&%S("1K
M97D]/B1V86QU92`I("`@("`@("\O('%U;W1E('1H92!V86QU97,L(&%S(&YE
M961E9"!F;W(@=&AE(&EN<V5R=`H@("`@("`@('L*("`@("`@("`@("`@)&YE
M=T1A=&%;)'1H:7,M/E]G971#;VQ.86UE*"1K97DI72`]("1T:&ES+3YD8F@M
M/G%U;W1E*"1V86QU92D["B`@("`@("`@?0H*("`@("`@("`O+R!S970@=&AE
M('!R;W!E<B!R:6=H="!A;F0@;&5F="!V86QU97,*("`@("`@("`D;F5W1&%T
M85LD;$YA;65=(#T@)'!R9796:7-I=&5D*S$["B`@("`@("`@)&YE=T1A=&%;
M)').86UE72`]("1P<F5V5FES:71E9"LR.PH*("`@("`@("`O+R!U<V4@<V5Q
M=65N8V5S('1O(&-R96%T92!A(&YE=R!I9"!I;B!T:&4@9&(M=&%B;&4*("`@
M("`@("`D;F5X=$ED(#T@)'1H:7,M/F1B:"T^;F5X=$ED*"1T:&ES+3YT86)L
M92D["B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@@("`G24Y315)4($E.5$\@
M)7,@*"5S+"5S*2!604Q515,@*"5S+"5S*2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=&%B;&4@+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G971#;VQ.86UE*"=I9"<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:6UP;&]D92@@(BPB("P@87)R87E?:V5Y<R@D
M;F5W1&%T82D@*2`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5X
M=$ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@@(BPB
M("P@)&YE=T1A=&$@*0H@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M("`@(&EF*"!$0CHZ:7-%<G)O<B@@)')E<R`]("1T:&ES+3YD8F@M/G%U97)Y
M*"1Q=65R>2D@*2`I"B`@("`@("`@>PHO+R!R;VQL8F%C:PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]T:')O=T5R<F]R*"`D<F5S+3YG971-97-S86=E
M*"D@+"!?7TQ)3D5?7R`I.PH@("`@("`@('T*+R\@8V]M;6ET(&AE<F4*"B`@
M("`@("`@<F5T=7)N("1N97AT260["B`@("!]("\O(&5N9"!O9B!F=6YC=&EO
M;@H*("`@("\J*@H@("`@*B`@('1H:7,@;65T:&]D(&]N;'D@=7!D871E<R!T
M:&4@;&5F="]R:6=H="!V86QU97,@;V8@86QL('1H90H@("`@*B`@(&5L96UE
M;G1S('1H870@87)E(&%F9F5C=&5D(&)Y('1H92!I;G-E<G1I;VX*("`@("H@
M("!B92!S=7)E('1O('-E="!T:&4@<&%R96YT260@;V8@=&AE(&5L96UE;G0H
M<RD@>6]U(&EN<V5R=`H@("`@*@H@("`@*B`@($!P87)A;2`@:6YT("`@("!T
M:&ES('!A<F%M971E<B!I<R!N;W0@=&AE($E$(2$A"B`@("`J("`@("`@("`@
M("`@("`@("`@(&ET(&ES('1H92!P<F5V:6]U<R!V:7-I="!N=6UB97(L('1H
M870@;65A;G,*("`@("H@("`@("`@("`@("`@("`@("`@:68@>6]U(&%R92!I
M;G-E<G1I;F<@82!C:&EL9"P@>6]U(&YE960@=&\@=7-E('1H92!L969T+79A
M;'5E"B`@("`J("`@("`@("`@("`@("`@("`@(&]F('1H92!P87)E;G0*("`@
M("H@("`@("`@("`@("`@("`@("`@:68@>6]U(&%R92!I;G-E<G1I;F<@82`B
M;F5X="(@96QE;65N="P@;VX@=&AE('-A;64@;&5V96P*("`@("H@("`@("`@
M("`@("`@("`@("`@>6]U(&YE960@=&\@9VEV92!T:&4@<FEG:'0@=F%L=64@
M(2$*("`@("H@("!`<&%R86T@(&EN="`@("`@=&AE(&YU;6)E<B!O9B!E;&5M
M96YT<R!Y;W4@<&QA;B!T;R!I;G-E<G0*("`@("H@("!`<F5T=7)N(&UI>&5D
M("`@96ET:&5R('1R=64@;VX@<W5C8V5S<R!O<B!A(%1R965?17)R;W(@;VX@
M9F%I;'5R90H@("`@*B\*("`@(&9U;F-T:6]N(%]A9&0H("1P<F5V5FES:71E
M9"`L("1N=6UB97)/9D5L96UE;G1S/3$@*0H@("`@>PH@("`@("`@("1L3F%M
M92`]("1T:&ES+3Y?9V5T0V]L3F%M92@G;&5F="<I.PH@("`@("`@("1R3F%M
M92`]("1T:&ES+3Y?9V5T0V]L3F%M92@G<FEG:'0G*3L*"B`@("`@("`@+R\@
M=7!D871E('1H92!E;&5M96YT<R!W:&EC:"!W:6QL(&)E(&%F9F5C=&5D(&)Y
M('1H92!N97<@:6YS97)T"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@@("`G
M55!$051%("5S(%-%5"`E<STE<RLE<R!72$52125S("5S/B5S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YT86)L92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1L3F%M92PD;$YA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;G5M8F5R3V9%;&5M96YT<RHR+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9717:&5R94%D9$]N*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;$YA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<')E=E9I<VET960@*3L*("`@("`@("!I
M9B@@1$(Z.FES17)R;W(H("1R97,@/2`D=&AI<RT^9&)H+3YQ=65R>2@D<75E
M<GDI("D@*0H@("`@("`@('L*+R\@1DE86$U%(')O;&QB86-K"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W1H<F]W17)R;W(H("1R97,M/F=E=$UE<W-A
M9V4H*2`L(%]?3$E.15]?("D["B`@("`@("`@?0H*("`@("`@("`D<75E<GD@
M/2!S<')I;G1F*"`@("=54$1!5$4@)7,@4T54("5S/25S*R5S(%=(15)%)7,@
M)7,^)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)').86UE+"1R3F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N=6UB97)/9D5L96UE
M;G1S*C(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=%=H97)E061D3VXH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M3F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5V5FES:71E
M9"`I.PH@("`@("`@(&EF*"!$0CHZ:7-%<G)O<B@@)')E<R`]("1T:&ES+3YD
M8F@M/G%U97)Y*"1Q=65R>2D@*2`I"B`@("`@("`@>PHO+R!&25A8344@<F]L
M;&)A8VL*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@
M)')E<RT^9V5T365S<V%G92@I("P@7U],24Y%7U\@*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`J("`@<F5M
M;W9E(&$@=')E92!E;&5M96YT"B`@("`J("`@=&AI<R!A=71O;6%T:6-A;&QY
M(')E;6]V92!A;&P@8VAI;&1R96X@86YD('1H96ER(&-H:6QD<F5N"B`@("`J
M("`@:68@82!N;V1E('-H86QL(&)E(')E;6]V960@=&AA="!H87,@8VAI;&1R
M96X*("`@("H*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`
M875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG
M+F1E/@H@("`@*B`@($!P87)A;2`@("`@(&EN=&5G97(@)&ED('1H92!I9"!O
M9B!T:&4@96QE;65N="!T;R!B92!R96UO=F5D"B`@("`J("`@0')E='5R;B`@
M("`@8F]O;&5A;B!R971U<FYS(&5I=&AE<B!T<G5E(&]R('1H<F]W<R!A;B!E
M<G)O<@H@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@@)&ED("D*("`@('L*
M("`@("`@("`D96QE;65N="`]("1T:&ES+3YG971%;&5M96YT*"`D:60@*3L*
M("`@("`@("!I9B@@4$5!4CHZ:7-%<G)O<B@D96QE;65N="D@*0H@("`@("`@
M("`@("!R971U<FX@)&5L96UE;G0["@HO+R!&25A8344@<W1A<G0@=')A;G-A
M8W1I;VX*("`@("`@("`O+R1T:&ES+3YD8F@M/F%U=&]#;VUM:70H9F%L<V4I
M.PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H("`@)T1%3$5412!&4D]-("5S
M(%=(15)%)7,@)7,@0D545T5%3B`E<R!!3D0@)7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G1A8FQE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G9717:&5R94%D9$]N*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H)VQE9G0G
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;&5M96YT6R=L969T
M)UTL)&5L96UE;G1;)W)I9VAT)UTI.PH@("`@("`@(&EF*"!$0CHZ:7-%<G)O
M<B@@)')E<R`]("1T:&ES+3YD8F@M/G%U97)Y*"1Q=65R>2D@*2`I"B`@("`@
M("`@>PHO+R!&25A8344@<F]L;&)A8VL*("`@("`@("`@("`@+R\D=&AI<RT^
M9&)H+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T
M:')O=T5R<F]R*"`D<F5S+3YG971-97-S86=E*"D@+"!?7TQ)3D5?7R`I.PH@
M("`@("`@('T*"B`@("`@("`@:68H(%!%05(Z.FES17)R;W(H)&5R<CTD=&AI
M<RT^7W)E;6]V92@@)&5L96UE;G0@*2D@*0H@("`@("`@('L*+R\@1DE86$U%
M(')O;&QB86-K"B`@("`@("`@("`@("\O)'1H:7,M/F1B:"T^<F]L;&)A8VLH
M*3L*("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@*B`@(')E;6]V97,@
M82!T<F5E(&5L96UE;G0L(&)U="!O;FQY('5P9&%T97,@=&AE(&QE9G0O<FEG
M:'0@=F%L=65S"B`@("`J("`@=&\@;6%K92!I="!S965M(&%S(&EF('1H92!G
M:79E;B!E;&5M96YT('=O=6QD(&YO="!E>&ES="!A;GEM;W)E"B`@("`J("`@
M:70@9&]E<VYT(')E;6]V92!T:&4@<F]W*',I(&EN('1H92!D8B!I='-E;&8A
M"B`@("`J"B`@("`J("`@0'-E92`@("`@("`@9V5T16QE;65N="@I"B`@("`J
M("`@0&%C8V5S<R`@("`@<')I=F%T90H@("`@*B`@($!A=71H;W(@("`@(%=O
M;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@
M0'!A<F%M("`@("`@87)R87D@("!T:&4@96YT:7)E(&5L96UE;G0@<F5T=7)N
M960@8GD@(F=E=$5L96UE;G0B"B`@("`J("`@0')E='5R;B`@("`@8F]O;&5A
M;B!R971U<FYS(&5I=&AE<B!T<G5E(&]R('1H<F]W<R!A;B!E<G)O<@H@("`@
M*B\*("`@(&9U;F-T:6]N(%]R96UO=F4H("1E;&5M96YT("D*("`@('L*("`@
M("`@("`D9&5L=&$@/2`D96QE;65N=%LG<FEG:'0G72`M("1E;&5M96YT6R=L
M969T)UT@*S$["B`@("`@("`@)&Q.86UE(#T@)'1H:7,M/E]G971#;VQ.86UE
M*"=L969T)RD["B`@("`@("`@)').86UE(#T@)'1H:7,M/E]G971#;VQ.86UE
M*"=R:6=H="<I.PH*("`@("`@("`O+R!U<&1A=&4@=&AE(&5L96UE;G1S('=H
M:6-H('=I;&P@8F4@869F96-T960@8GD@=&AE(')E;6]V90H@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H("`@(E501$%412`E<R!3150@)7,])7,M)&1E;'1A
M+"`E<STE<RTD9&5L=&$@5TA%4D4E<R`E<SXE<R(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=&%B;&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;$YA;64L)&Q.86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)').86UE+"1R3F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9V5T5VAE<F5!9&1/;B@I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&Q.86UE+"1E;&5M96YT6R=L969T)UT@*3L*("`@
M("`@("!I9B@@1$(Z.FES17)R;W(H("1R97,@/2`D=&AI<RT^9&)H+3YQ=65R
M>2@D<75E<GDI("D@*0H@("`@("`@('L*("`@("`@("`@("`@+R\@=&AE(')O
M;&QB86-K('-H86QL(&)E(&1O;F4@8GD@=&AE(&UE=&AO9"!C86QL:6YG('1H
M:7,@;VYE+"!S:6YC92!I="!I<R!O;FQY('!R:79A=&4@=V4@8V%N(&1O('1H
M870*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@)')E
M<RT^9V5T365S<V%G92@I("P@7U],24Y%7U\@*3L*("`@("`@("!]"@H@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H("`@(E501$%412`E<R!3150@)7,])7,M
M)&1E;'1A(%=(15)%)7,@)7,\)7,@04Y$("5S/B5S(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YT86)L92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1R3F%M92PD<DYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=E=%=H97)E061D3VXH*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1L3F%M92PD96QE;65N=%LG;&5F="==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)').86UE+"1E;&5M96YT6R=R
M:6=H="==("D["B`@("`@("`@:68H($1".CII<T5R<F]R*"`D<F5S(#T@)'1H
M:7,M/F1B:"T^<75E<GDH)'%U97)Y*2`I("D*("`@("`@("!["B`@("`@("`@
M("`@("\O('1H92!R;VQL8F%C:R!S:&%L;"!B92!D;VYE(&)Y('1H92!M971H
M;V0@8V%L;&EN9R!T:&ES(&]N92P@<VEN8V4@:70@:7,@;VYL>2!P<FEV871E
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1H<F]W17)R;W(H("1R97,M
M/F=E=$UE<W-A9V4H*2`L(%]?3$E.15]?("D["B`@("`@("`@?0HO+R!&25A8
M344@8V]M;6ET("T@<VAO=6QD('1H870@;F]T(&%L<V\@8F4@9&]N92!I;B!T
M:&4@;65T:&]D(&-A;&QI;F<@=&AI<R!O;F4_(&QI:V4@=VAE;B!A;B!E<G)O
M<B!O8V-U<G,_"B`@("`@("`@+R\D=&AI<RT^9&)H+3YC;VUM:70H*3L*("`@
M("`@("!R971U<FX@=')U93L*("`@('T@+R\@96YD(&]F(&9U;F-T:6]N"@H@
M("`@+RHJ"B`@("`J("`@;6]V92!A;B!E;G1R>2!U;F1E<B!A(&=I=F5N('!A
M<F5N="!O<B!B96AI;F0@82!G:79E;B!E;G1R>2X*("`@("H@("!)9B!A(&YE
M=U!R979)9"!I<R!G:79E;B!T:&4@;F5W4&%R96YT260@:7,@9&ES;6ES<V5D
M(0H@("`@*B`@(&-A;&P@:70@96ET:&5R(&QI:V4@=&AI<SH*("`@("H@("`@
M("`@)'1R964M/FUO=F4H('@@+"!Y("D*("`@("H@("`@("`@=&\@;6]V92!T
M:&4@96QE;65N="`H;W(@96YT:7)E('1R964I('=I=&@@=&AE(&ED('@*("`@
M("H@("`@("`@=6YD97(@=&AE(&5L96UE;G0@=VET:"!T:&4@:60@>0H@("`@
M*B`@(&]R"B`@("`J("`@("`@("1T<F5E+3YM;W9E*"!X("P@,"`L('D@*3L@
M("`O+R!O;6UI="!T:&4@<V5C;VYD('!A<F%M971E<B!B>2!S971T:6YG(&ET
M('1O(#`*("`@("H@("`@("`@=&\@;6]V92!T:&4@96QE;65N="`H;W(@96YT
M:7)E('1R964I('=I=&@@=&AE(&ED('@*("`@("H@("`@("`@8F5H:6YD('1H
M92!E;&5M96YT('=I=&@@=&AE(&ED('D*("`@("H@("!O<@H@("`@*B`@("`@
M("`D=')E92T^;6]V92@@87)R87DH>#$L>#(L>#,I("P@+BXN"B`@("`J("`@
M("`@('1H92!F:7)S="!P87)A;65T97(@8V%N(&%L<V\@8F4@86X@87)R87D@
M;V8@96QE;65N=',@=&AA="!S:&%L;"!B92!M;W9E9`H@("`@*B`@("`@("!T
M:&4@<V5C;VYD(&%N9"!T:&ER9"!P87)A(&-A;B!B92!A<R!D97-C<FEB960@
M86)O=F4*("`@("H@("!)9B!Y;W4@87)E('5S:6YG('1H92!-96UO<GE?1$)N
M97-T960@=&AE;B!T:&ES(&UE=&AO9"!W;W5L9"!B92!I;G9A:6XL"B`@("`J
M("`@<VEN8V4@365M;W)Y+G!H<"!A;')E861Y(&1O97,@=&AE(&QO;W!I;F<@
M=&AR;W5G:"!M=6QT:7!L92!E;&5M96YT<RP@8G5T(&EF"B`@("`J("`@1'EN
M86UI8U]$0FYE<W1E9"!I<R!U<V5D('=E(&YE960@=&\@9&\@=&AE(&QO;W!I
M;F<@:&5R90H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#8O,#@*
M("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@
M("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@
M*B`@($!P87)A;2`@("`@(&EN=&5G97(@("`@('1H92!I9"AS*2!O9B!T:&4@
M96QE;65N="AS*2!T:&%T('-H86QL(&)E(&UO=F5D"B`@("`J("`@0'!A<F%M
M("`@("`@:6YT96=E<B`@("`@=&AE(&ED(&]F('1H92!E;&5M96YT('=H:6-H
M('=I;&P@8F4@=&AE(&YE=R!P87)E;G0*("`@("H@("!`<&%R86T@("`@("!I
M;G1E9V5R("`@("!I9B!P<F5V260@:7,@9VEV96X@=&AE(&5L96UE;G0@=VET
M:"!T:&4@:60@:614;TUO=F4*("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S:&%L;"!B92!M;W9E9"!?8F5H:6YD7R!T:&4@96QE;65N="!W:71H
M(&ED/7!R979)9`H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M(&ET(&ES(#`@:70@=VEL;"!B92!P=70@870@=&AE(&)E9VEN;FEN9PH@("`@
M*B`@($!R971U<FX@("`@(&UI>&5D("`@("`@('1R=64@9F]R('-U8V-E<W,L
M(%1R965?17)R;W(@;VX@9F%I;'5R90H@("`@*B\*("`@(&9U;F-T:6]N(&UO
M=F4H("1I9'-4;TUO=F4@+"`D;F5W4&%R96YT260@+"`D;F5W4')E=DED/3`@
M*0H@("`@>PH@("`@("`@('-E='1Y<&4H)&ED<U1O36]V92PG87)R87DG*3L*
M("`@("`@("`D97)R;W)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H*"`D
M:61S5&]-;W9E(&%S("1I9%1O36]V92`I"B`@("`@("`@>PH@("`@("`@("`@
M("`D<F5T(#T@)'1H:7,M/E]M;W9E*"`D:614;TUO=F4@+"`D;F5W4&%R96YT
M260@+"`D;F5W4')E=DED("D["B`@("`@("`@("`@(&EF*"!014%2.CII<T5R
M<F]R*"1R970I("D*("`@("`@("`@("`@("`@("1E<G)O<G-;72`]("1R970[
M"B`@("`@("`@?0HO+R!&25A8344@=&AE(&5R<F]R(&EN(&$@;FEC97(@=V%Y
M+"!O<B!E=F5N(&)E='1E<B!L970@=&AE('1H<F]W17)R;W(@;65T:&]D(&1O
M(&ET(2$A"B`@("`@("`@:68H('-I>F5O9B@D97)R;W)S*2`I"B`@("`@("`@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T:')O=T5R<F]R*'-E<FEA
M;&EZ92@D97)R;W)S*2Q?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@*B`@('1H:7,@;65T:&]D
M(&UO=F5S(&]N92!T<F5E(&5L96UE;G0*("`@("H*("`@("H@("!`<V5E("`@
M("`@("!M;W9E*"D*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`T+S(Y"B`@
M("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@
M5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@
M("!`<&%R86T@("`@("!I;G1E9V5R("`@("!T:&4@:60@;V8@=&AE(&5L96UE
M;G0@=&AA="!S:&%L;"!B92!M;W9E9`H@("`@*B`@($!P87)A;2`@("`@(&EN
M=&5G97(@("`@('1H92!I9"!O9B!T:&4@96QE;65N="!W:&EC:"!W:6QL(&)E
M('1H92!N97<@<&%R96YT"B`@("`J("`@0'!A<F%M("`@("`@:6YT96=E<B`@
M("`@:68@<')E=DED(&ES(&=I=F5N('1H92!E;&5M96YT('=I=&@@=&AE(&ED
M(&ED5&]-;W9E"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<VAA
M;&P@8F4@;6]V960@7V)E:&EN9%\@=&AE(&5L96UE;G0@=VET:"!I9#UP<F5V
M260*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B!I="!I<R`P
M(&ET('=I;&P@8F4@<'5T(&%T('1H92!B96=I;FYI;F<*("`@("H@("!`<F5T
M=7)N("`@("!M:7AE9"`@("`@("!T<G5E(&9O<B!S=6-C97-S+"!4<F5E7T5R
M<F]R(&]N(&9A:6QU<F4*("`@("HO"B`@("!F=6YC=&EO;B!?;6]V92@@)&ED
M5&]-;W9E("P@)&YE=U!A<F5N=$ED("P@)&YE=U!R979)9#TP("D*("`@('L*
M("`@("`@("`O+R!D;R!S;VUE(&EN=&5G<FET>2!C:&5C:W,@9FER<W0*("`@
M("`@("!I9B`H)&YE=U!R979)9"D@>PH@("`@("`@("`@("!I9B`H)&YE=U!R
M979)9#T])&ED5&]-;W9E*2![("`@("`@("`@("`@+R\@9&]N="!L970@<&5O
M<&QE(&UO=F4@86X@96QE;65N="!B96AI;F0@:71S96QF+"!T96QL(&ET('-U
M8V-E961E9"P@<VEN8V4@:70@86QR96%D>2!I<R!T:&5R92`Z+2D*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1N97=0<F5V:6]U<STD=&AI<RT^9V5T
M16QE;65N="@D;F5W4')E=DED*2DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D;F5W4')E=FEO=7,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YE
M=U!A<F5N=$ED(#T@)&YE=U!R979I;W5S6R=P87)E;G1)9"==.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("@D;F5W4&%R96YT260]/3`I('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1H<F]W17)R;W(H("=N
M;R!P87)E;G0@:60@9VEV96XG("P@7U],24Y%7U\@*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H)'1H:7,M/FES0VAI;&1/9B@D:614;TUO=F4L
M)&YE=U!A<F5N=$ED*2D@>R`O+R!I9B!T:&4@96QE;65N="!S:&%L;"!B92!M
M;W9E9"!U;F1E<B!O;F4@;V8@:71S(&-H:6QD<F5N+"!R971U<FX@9F%L<V4*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1H<F]W17)R;W(H("=C
M86X@;F]T(&UO=F4@86X@96QE;65N="!U;F1E<B!O;F4@;V8@:71S(&-H:6QD
M<F5N)R`L(%]?3$E.15]?("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1N97=087)E;G1)9#T])&ED5&]-;W9E*2![("`@("`@("`@("\O(&1O
M;G0@9&\@86YY=&AI;F<@=&\@;&5T(&%N(&5L96UE;G0@8F4@;6]V960@=6YD
M97(@:71S96QF+"!W:&EC:"!I<R!B=6QL<VAI=`H@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&YE=U!A<F5N=#TD=&AI<RT^9V5T16QE;65N="@D;F5W
M4&%R96YT260I*2D@>R`O+R!T<GD@=&\@<F5T<F5I=F4@=&AE(&1A=&$@;V8@
M=&AE('!A<F5N="!E;&5M96YT"B`@("`@("`@("`@("`@("!R971U<FX@)&YE
M=U!A<F5N=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5L96UE;G0])'1H:7,M/F=E=$5L96UE;G0H)&ED
M5&]-;W9E*2DI('L@+R\@9V5T('1H92!D871A(&]F('1H92!E;&5M96YT(&ET
M<V5L9@H@("`@("`@("`@("!R971U<FX@)&5L96UE;G0["B`@("`@("`@?0H*
M("`@("`@("`D;G5M8F5R3V9%;&5M96YT<R`]("@D96QE;65N=%LG<FEG:'0G
M72`M("1E;&5M96YT6R=L969T)UTK,2DO,CL*("`@("`@("`D<')E=E9I<VET
M960@/2`D;F5W4')E=DED(#\@)&YE=U!R979I;W5S6R=R:6=H="==(#H@)&YE
M=U!A<F5N=%LG;&5F="==.PH*+R\@1DE86$U%('-T87)T('1R86YS86-T:6]N
M"@H@("`@("`@("\O(&%D9"!T:&4@;&5F="]R:6=H="!V86QU97,@:6X@=&AE
M(&YE=R!P87)E;G0L('1O(&AA=F4@=&AE('-P86-E('1O(&UO=F4@=&AE(&YE
M=R!V86QU97,@:6X*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R/21T
M:&ES+3Y?861D*"`D<')E=E9I<VET960@+"`D;G5M8F5R3V9%;&5M96YT<R`I
M*2D@>PHO+R!&25A8344@<F]L;&)A8VL*("`@("`@("`@("`@+R\D=&AI<RT^
M9&)H+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@
M("`@("!]"@H@("`@("`@("\O('5P9&%T92!T:&4@<&%R96YT260@;V8@=&AE
M(&5L96UE;G0@=VET:"`D:614;TUO=F4*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R/21T:&ES+3YU<&1A=&4H)&ED5&]-;W9E+&%R<F%Y*"=P87)E
M;G1)9"<]/B1N97=087)E;G1)9"DI*2D@>PHO+R!&25A8344@<F]L;&)A8VL*
M("`@("`@("`@("`@+R\D=&AI<RT^9&)H+3YR;VQL8F%C:R@I.PH@("`@("`@
M("`@("!R971U<FX@)&5R<CL*("`@("`@("!]"@H@("`@("`@("\O('5P9&%T
M92!T:&4@;&5F=',@86YD(')I9VAT<R!O9B!T:&]S92!E;&5M96YT<R!T:&%T
M('-H86QL(&)E(&UO=F5D"@H@("`@("`@("\O(&9I<G-T(&=E="!T:&4@;V9F
M<V5T('=E(&YE960@=&\@861D('1O('1H92!L969T+W)I9VAT('9A;'5E<PH@
M("`@("`@("\O(&EF("1N97=0<F5V260@:7,@9VEV96X@=V4@;F5E9"!T;R!G
M970@=&AE(')I9VAT('9A;'5E+"!O=&AE<G=I<V4@=&AE(&QE9G0*("`@("`@
M("`O+R!S:6YC92!T:&4@;&5F="]R:6=H="!H87,@8VAA;F=E9"P@8F5C875S
M92!W92!A;')E861Y('5P9&%T960@:70@=7`@=&AE<F4@=V4@;F5E9"!T;PH@
M("`@("`@("\O(&=E="!T:&5M(&%G86EN+"!W92!H879E('1O(&1O('1H870@
M86YY=V%Y+"!T;R!H879E('1H92!P<F]P97(@;F5W(&QE9G0O<FEG:'0@=F%L
M=65S"B`@("`@("`@:68@*"1N97=0<F5V260I('L*("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)'1E;7`@/2`D=&AI<RT^9V5T16QE;65N="@@)&YE
M=U!R979)9"`I*2D@>PHO+R!&25A8344@<F]L;&)A8VL*("`@("`@("`@("`@
M("`@("\O)'1H:7,M/F1B:"T^<F]L;&)A8VLH*3L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&5M<#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8V%L
M8U=I=&@@/2`D=&5M<%LG<FEG:'0G73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&5M<#TD=&AI<RT^9V5T16QE
M;65N="@D;F5W4&%R96YT260I*2D@>PHO+R!&25A8344@<F]L;&)A8VL*("`@
M("`@("`@("`@("`@("\O)'1H:7,M/F1B:"T^<F]L;&)A8VLH*3L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&5M<#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D8V%L8U=I=&@@/2`D=&5M<%LG;&5F="==.PH@("`@("`@('T*"B`@
M("`@("`@+R\@9V5T('1H92!E;&5M96YT('1H870@<VAA;&P@8F4@;6]V960@
M86=A:6XL('-I;F-E('1H92!L969T(&%N9"!R:6=H="!M:6=H="!H879E(&-H
M86YG960@8GD@=&AE(&%D9"UC86QL"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5L96UE;G0])'1H:7,M/F=E=$5L96UE;G0H)&ED5&]-;W9E*2DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E;&5M96YT.PH@("`@("`@('T*"B`@("`@
M("`@)&]F9G-E="`]("1C86QC5VET:"`M("1E;&5M96YT6R=L969T)UT[("`@
M("`O+R!C86QC('1H92!O9F9S970@=&AA="!T:&4@96QE;65N="!T;R!M;W9E
M(&AA<R!T;R!T:&4@<W!O="!W:&5R92!I="!S:&]U;&0@9V\*("`@("`@("`D
M;V9F<V5T*RL[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&-O<G)E8W0@=&AE(&]F9G-E="!B>2!O;F4L('-I;F-E(&ET(&YE961S('1O
M(&=O(&EN8F5T=V5E;B$*"B`@("`@("`@)&Q.86UE(#T@)'1H:7,M/E]G971#
M;VQ.86UE*"=L969T)RD["B`@("`@("`@)').86UE(#T@)'1H:7,M/E]G971#
M;VQ.86UE*"=R:6=H="<I.PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H("`@
M(E501$%412`E<R!3150@)7,])7,K)&]F9G-E="PE<STE<RLD;V9F<V5T(%=(
M15)%)7,@)7,^)7,@04Y$("5S/"5S(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YT86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R3F%M92PD<DYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;$YA;64L)&Q.86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]G9717:&5R94%D9$]N*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;$YA;64L)&5L96UE;G1;)VQE9G0G72TQ+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)').86UE+"1E;&5M96YT6R=R:6=H="==*S$@
M*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<STD=&AI<RT^9&)H+3YQ
M=65R>2@D<75E<GDI*2D@>PHO+R!&25A8344@<F]L;&)A8VL*("`@("`@("`@
M("`@+R\D=&AI<RT^9&)H+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]T:')O=T5R<F]R*"`D<F5S+3YG971-97-S86=E*"D@+"!?
M7TQ)3D5?7R`I.PH@("`@("`@('T*"B`@("`@("`@+R\@<F5M;W9E('1H92!P
M87)T(&]F('1H92!T<F5E('=H97)E('1H92!E;&5M96YT*',I('=A<R]W97)E
M(&)E9F]R90H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(])'1H:7,M
M/E]R96UO=F4H)&5L96UE;G0I*2D@>PHO+R!&25A8344@<F]L;&)A8VL*("`@
M("`@("`@("`@+R\D=&AI<RT^9&)H+3YR;VQL8F%C:R@I.PH@("`@("`@("`@
M("!R971U<FX@)&5R<CL*("`@("`@("!]"B\O($9)6%A-12!C;VUM:70@86QL
M(&-H86YG97,*("`@("`@("`O+R1T:&ES+3YD8F@M/F-O;6UI="@I.PH*("`@
M("`@("!R971U<FX@=')U93L*("`@('T@+R\@96YD(&]F(&9U;F-T:6]N"@H@
M("`@+RHJ"B`@("`J("`@=7!D871E('1H92!T<F5E(&5L96UE;G0@9VEV96X@
M8GD@)&ED('=I=&@@=&AE('9A;'5E<R!I;B`D;F5W5F%L=65S"B`@("`J"B`@
M("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@
M5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@
M("!`<&%R86T@("`@("!I;G0@("`@('1H92!I9"!O9B!T:&4@96QE;65N="!T
M;R!U<&1A=&4*("`@("H@("!`<&%R86T@("`@("!A<G)A>2`@('1H92!N97<@
M=F%L=65S+"!T:&4@:6YD97@@:7,@=&AE(&-O;"!N86UE"B`@("`J("`@0')E
M='5R;B`@("`@;6EX960@("!E:71H97(@=')U92!O<B!A;B!4<F5E7T5R<F]R
M"B`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E*"1I9"PD;F5W5F%L=65S*0H@
M("`@>PH@("`@("`@("\O(&IS=70@=&\@8F4@<W5R92!N;W1H:6YG(&=E=',@
M<V-R97=E9"!U<"`Z+2D*("`@("`@("!U;G-E="@D;F5W5F%L=65S6R1T:&ES
M+3Y?9V5T0V]L3F%M92@G;&5F="<I72D["B`@("`@("`@=6YS970H)&YE=U9A
M;'5E<ULD=&AI<RT^7V=E=$-O;$YA;64H)W)I9VAT)RE=*3L*("`@("`@("!U
M;G-E="@D;F5W5F%L=65S6R1T:&ES+3Y?9V5T0V]L3F%M92@G<&%R96YT260G
M*5TI.PH*("`@("`@("`O+R!U<&1A=&EN9R!?;VYE7R!E;&5M96YT(&EN('1H
M92!T<F5E"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@9F]R
M96%C:"`H)&YE=U9A;'5E<R!A<R`D:V5Y/3XD=F%L=64I('L*("`@("`@("`@
M("`@)'9A;'5E<UM=(#T@)'1H:7,M/E]G971#;VQ.86UE*"1K97DI+B<])RXD
M=&AI<RT^9&)H+3YQ=6]T92@D=F%L=64I.PH@("`@("`@('T*("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*"`@("=54$1!5$4@)7,@4T54("5S(%=(15)%)7,@
M)7,])7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+"<L
M)'9A;'5E<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V=E=%=H97)E061D3VXH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9V5T0V]L3F%M92@G:60G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I9"D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"`D<F5S
M/21T:&ES+3YD8F@M/G%U97)Y*"1Q=65R>2DI*2!["B\O($9)6%A-12!R86ES
M92!014%2(&5R<F]R"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1H<F]W
M17)R;W(H("1R97,M/F=E=$UE<W-A9V4H*2`L(%]?3$E.15]?("D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T@+R\@96YD(&]F(&9U
M;F-T:6]N"@H@("`@+RHJ"B`@("`J("`@8V]P>2!A('-U8G1R964O;F]D92\N
M+BX@=6YD97(@82!N97<@<&%R96YT(&]R+V%N9"!B96AI;F0@82!G:79E;B!E
M;&5M96YT"B`@("`J"B`@("`J"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC
M"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A
M;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T*("`@("H@("!`<F5T=7)N
M"B`@("`J+PH@("`@9G5N8W1I;VX@8V]P>2@@)&ED("P@)'!A<F5N=$ED/3`@
M+"`D<')E=DED/3`@*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1H
M<F]W17)R;W(H("=C;W!Y+6UE=&AO9"!I<R!N;W0@:6UP;&5M96YT960@>65T
M(2<@+"!?7TQ)3D5?7R`I.PH@("`@("`@("\O(&=E="!E;&5M96YT('1R964*
M("`@("`@("`O+R`D=&AI<RT^861D5')E90H@("`@?2`O+R!E;F0@;V8@9G5N
M8W1I;VX*"@H@("`@+RHJ"B`@("`J("`@9V5T('1H92!R;V]T"B`@("`J"B`@
M("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0'9E<G-I;VX@("`@
M,C`P,B\P,R\P,@H@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I
M;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M"B`@("`J
M("`@0')E='5R;B`@("`@;6EX960@("!E:71H97(@=&AE(&1A=&$@;V8@=&AE
M(')O;W0@96QE;65N="!O<B!A;B!4<F5E7T5R<F]R"B`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4F]O="@I"B`@("!["B`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@@("`G4T5,14-4("H@1E)/32`E<R!72$52125S("5S/3$G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1A8FQE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9717:&5R94%D9$]N*"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H
M)VQE9G0G*2D["B`@("`@("`@:68H($1".CII<T5R<F]R*"`D<F5S(#T@)'1H
M:7,M/F1B:"T^9V5T4F]W*"1Q=65R>2D@*2`I"B`@("`@("`@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]T:')O=T5R<F]R*"`D<F5S+3YG971-97-S
M86=E*"D@+"!?7TQ)3D5?7R`I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]P<F5P87)E4F5S=6QT*"`D<F5S("D["B`@("!]("\O(&5N9"!O
M9B!F=6YC=&EO;@H*("`@("\J*@H@("`@*@H@("`@*@H@("`@*B`@($!A8V-E
M<W,@("`@('!U8FQI8PH@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#,O,#(*
M("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M
M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;0H@("`@*B`@($!R971U<FX@
M("`@(&UI>&5D("`@96ET:&5R('1H92!D871A(&]F('1H92!R97%U97-T960@
M96QE;65N="!O<B!A;B!4<F5E7T5R<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T16QE;65N="@@)&ED("D*("`@('L*("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"`@("=314Q%0U0@*B!&4D]-("5S(%=(15)%)7,@)7,])7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1A8FQE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9717:&5R94%D9$]N*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA
M;64H)VED)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:60I.PH@
M("`@("`@(&EF*"!$0CHZ:7-%<G)O<B@@)')E<R`]("1T:&ES+3YD8F@M/F=E
M=%)O=R@D<75E<GDI("D@*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=&AR;W=%<G)O<B@@)')E<RT^9V5T365S<V%G92@I("P@7U],
M24Y%7U\@*3L*("`@("`@("!]"B`@("`@("`@:68H("$D<F5S("D*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@(D5L96UE;G0@=VET
M:"!I9"`D:60@9&]E<R!N;W0@97AI<W0A(B`L(%]?3$E.15]?("D["@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!R97!A<F5297-U;'0H("1R97,@*3L*("`@
M('T@+R\@96YD(&]F(&9U;F-T:6]N"@H@("`@+RHJ"B`@("`J"B`@("`J"B`@
M("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0'9E<G-I;VX@("`@
M,C`P,B\P,R\P,@H@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I
M;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M"B`@("`J
M("`@0')E='5R;B`@("`@;6EX960@("!E:71H97(@=&AE(&1A=&$@;V8@=&AE
M(')E<75E<W1E9"!E;&5M96YT(&]R(&%N(%1R965?17)R;W(*("`@("HO"B`@
M("!F=6YC=&EO;B!G971#:&EL9"@D:60I"B`@("!["B`@("`@("`@+R\@<W5B
M<75E<FEE<R!W;W5L9"!B92!C;V]L(#HM*0H@("`@("`@("1C=7)%;&5M96YT
M(#T@)'1H:7,M/F=E=$5L96UE;G0H("1I9"`I.PH@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1C=7)%;&5M96YT*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&-U<D5L96UE;G0["B`@("`@("`@?0H*("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"`@("=314Q%0U0@*B!&4D]-("5S(%=(15)%)7,@)7,])7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1A8FQE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9717:&5R94%D9$]N*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA
M;64H)VQE9G0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C=7)%
M;&5M96YT6R=L969T)UTK,2`I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@@
M)')E<R`]("1T:&ES+3YD8F@M/F=E=%)O=R@D<75E<GDI*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]T:')O=T5R<F]R*"`D<F5S+3YG971-97-S
M86=E*"D@+"!?7TQ)3D5?7R`I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]P<F5P87)E4F5S=6QT*"`D<F5S("D["B`@("!]"@H@("`@+RHJ
M"B`@("`J("`@9V5T<R!T:&4@<&%T:"!F<F]M('1H92!E;&5M96YT('=I=&@@
M=&AE(&=I=F5N(&ED(&1O=VX*("`@("H@("!T;R!T:&4@<F]O=`H@("`@*B`@
M('1H92!R971U<FYE9"!A<G)A>2!I<R!S;W)T960@=&\@<W1A<G0@870@<F]O
M=`H@("`@*B`@(&9O<B!S:6UP;'D@=V%L:VEN9R!T:')O=6=H(&%N9"!R971R
M96EV:6YG('1H92!P871H"B`@("`J"B`@("`J("`@0&%C8V5S<R`@("`@<'5B
M;&EC"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P,R\P,@H@("`@*B`@($!A
M=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N
M9&4^"B`@("`J("`@0'!A<F%M"B`@("`J("`@0')E='5R;B`@("`@;6EX960@
M("!E:71H97(@=&AE(&1A=&$@;V8@=&AE(')E<75E<W1E9"!E;&5M96YT<R!O
M<B!A;B!4<F5E7T5R<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T:"@@
M)&ED("D*("`@('L*("`@("`@("`O+R!S=6)Q=65R:65S('=O=6QD(&)E(&-O
M;VP@.BTI"B`@("`@("`@)&-U<D5L96UE;G0@/2`D=&AI<RT^9V5T16QE;65N
M="@@)&ED("D["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H("`@)U-%3$5#
M5"`J($923TT@)7,@5TA%4D4E<R`E<SP])7,@04Y$("5S/CTE<R!/4D1%4B!"
M62`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=&%B
M;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=%=H
M97)E061D3VXH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T0V]L3F%M92@G;&5F="<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-U<D5L96UE;G1;)VQE9G0G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5T0V]L3F%M92@G<FEG:'0G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C=7)%;&5M96YT6R=R:6=H="==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971#;VQ.86UE
M*"=L969T)RD@*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H("1R97,@/2`D
M=&AI<RT^9&)H+3YG971!;&PH)'%U97)Y*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@)')E<RT^9V5T365S<V%G92@I("P@
M7U],24Y%7U\@*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<')E<&%R95)E<W5L=',H("1R97,@*3L*("`@('T*"B`@("`O*BH*("`@("H@
M("!G971S('1H92!E;&5M96YT('1O('1H92!L969T+"!T:&4@;&5F="!V:7-I
M=`H@("`@*@H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!V
M97)S:6]N("`@(#(P,#(O,#,O,#<*("`@("H@("!`875T:&]R("`@("!7;VQF
M<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P
M87)A;0H@("`@*B`@($!R971U<FX@("`@(&UI>&5D("`@96ET:&5R('1H92!D
M871A(&]F('1H92!R97%U97-T960@96QE;65N="!O<B!A;B!4<F5E7T5R<F]R
M"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&5F="@@)&ED("D*("`@('L*("`@
M("`@("`D96QE;65N="`]("1T:&ES+3YG971%;&5M96YT*"`D:60@*3L*("`@
M("`@("!I9B@@4$5!4CHZ:7-%<G)O<B@D96QE;65N="D@*0H@("`@("`@("`@
M("!R971U<FX@)&5L96UE;G0["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M("`@)U-%3$5#5"`J($923TT@)7,@5TA%4D4E<R`H)7,])7,@3U(@)7,])7,I
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YT86)L92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T5VAE<F5!
M9&1/;B@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M971#;VQ.86UE*"=R:6=H="<I+"1E;&5M96YT6R=L969T)UTM,2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T0V]L3F%M92@G;&5F
M="<I+"1E;&5M96YT6R=L969T)UTM,2`I.PH@("`@("`@(&EF*"!$0CHZ:7-%
M<G)O<B@@)')E<R`]("1T:&ES+3YD8F@M/F=E=%)O=R@D<75E<GDI("D@*0H@
M("`@("`@('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O
M<B@@)')E<RT^9V5T365S<V%G92@I("P@7U],24Y%7U\@*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')E<&%R95)E<W5L="@@)')E<R`I
M.PH@("`@?0H*("`@("\J*@H@("`@*B`@(&=E=',@=&AE(&5L96UE;G0@=&\@
M=&AE(')I9VAT+"!T:&4@<FEG:'0@=FES:70*("`@("H*("`@("H@("!`86-C
M97-S("`@("!P=6)L:6,*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`S+S`W
M"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A
M;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T*("`@("H@("!`<F5T=7)N
M("`@("!M:7AE9"`@(&5I=&AE<B!T:&4@9&%T82!O9B!T:&4@<F5Q=65S=&5D
M(&5L96UE;G0@;W(@86X@5')E95]%<G)O<@H@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%)I9VAT*"`D:60@*0H@("`@>PH@("`@("`@("1E;&5M96YT(#T@)'1H
M:7,M/F=E=$5L96UE;G0H("1I9"`I.PH@("`@("`@(&EF*"!014%2.CII<T5R
M<F]R*"1E;&5M96YT*2`I"B`@("`@("`@("`@(')E='5R;B`D96QE;65N=#L*
M"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@@("`G4T5,14-4("H@1E)/32`E
M<R!72$52125S("@E<STE<R!/4B`E<STE<RDG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G1A8FQE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G9717:&5R94%D9$]N*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H)VQE9G0G*2PD
M96QE;65N=%LG<FEG:'0G72LQ+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G971#;VQ.86UE*"=R:6=H="<I+"1E;&5M96YT6R=R:6=H
M="==*S$I.PH@("`@("`@(&EF*"!$0CHZ:7-%<G)O<B@@)')E<R`]("1T:&ES
M+3YD8F@M/F=E=%)O=R@D<75E<GDI("D@*0H@("`@("`@('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@)')E<RT^9V5T365S<V%G
M92@I("P@7U],24Y%7U\@*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<')E<&%R95)E<W5L="@@)')E<R`I.PH@("`@?0H*("`@("\J*@H@
M("`@*B`@(&=E="!T:&4@<&%R96YT(&]F('1H92!E;&5M96YT('=I=&@@=&AE
M(&=I=F5N(&ED"B`@("`J"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@
M("`J("`@0'9E<G-I;VX@("`@,C`P,B\P-"\Q-0H@("`@*B`@($!A=71H;W(@
M("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@
M("`J("`@0'!A<F%M"B`@("`J("`@0')E='5R;B`@("`@;6EX960@("!T:&4@
M87)R87D@=VET:"!T:&4@9&%T82!O9B!T:&4@<&%R96YT(&5L96UE;G0*("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&]R(&9A;'-E+"!I9B!T:&5R92!I
M<R!N;R!P87)E;G0L(&EF('1H92!E;&5M96YT(&ES('1H92!R;V]T"B`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!O<B!A;B!4<F5E7T5R<F]R"B`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&%R96YT*"`D:60@*0H@("`@>PH@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H("`@)U-%3$5#5"!P+BH@1E)/32`E<R!P+"5S
M(&4@5TA%4D4E<R!E+B5S/7`N)7,@04Y$(&4N)7,])7,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G1A8FQE+"1T:&ES+3YT86)L92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T5VAE<F5!
M9&1/;B@@)R!!3D0@)R`L("=P)R`I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G971#;VQ.86UE*"=P87)E;G1)9"<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971#;VQ.86UE*"=I9"<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971#;VQ.
M86UE*"=I9"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ED*3L*
M("`@("`@("!I9B@@1$(Z.FES17)R;W(H("1R97,@/2`D=&AI<RT^9&)H+3YG
M9712;W<H)'%U97)Y*2`I("D*("`@("`@("!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1H<F]W17)R;W(H("1R97,M/F=E=$UE<W-A9V4H*2`L(%]?
M3$E.15]?("D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!R
M97!A<F5297-U;'0H("1R97,@*3L*("`@('T*"B`@("`O*BH*("`@("H@("!G
M970@=&AE(&-H:6QD<F5N(&]F('1H92!G:79E;B!E;&5M96YT"B`@("`J("`@
M;W(@:68@=&AE('!A<F%M971E<B!I<R!A;B!A<G)A>2P@:70@9V5T<R!T:&4@
M8VAI;&1R96X@;V8@86QL"B`@("`J("`@=&AE(&5L96UE;G1S(&=I=F5N(&)Y
M('1H96ER(&ED<R!I;B!T:&4@87)R87D*("`@("H*("`@("H@("!`86-C97-S
M("`@("!P=6)L:6,*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`T+S$U"B`@
M("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K
M<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@("`@("!M:7AE9"`@("@Q*2!I
M;G0@("`@('1H92!I9"!O9B!O;F4@96QE;65N=`H@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@*#(I(&%R<F%Y("`@86X@87)R87D@;V8@:61S(&9O<B!W
M:&EC:`H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&AE(&-H:6QD<F5N('=I;&P@8F4@<F5T=7)N960*("`@("H@("!`<&%R86T@
M("`@("!I;G1E9V5R('1H92!C:&EL9')E;B!O9B!H;W<@;6%N>2!L979E;',@
M<VAA;&P@8F4@<F5T=7)N960*("`@("H@("!`<F5T=7)N("`@("!M:7AE9"`@
M('1H92!A<G)A>2!W:71H('1H92!D871A(&]F(&%L;"!C:&EL9')E;@H@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@;W(@9F%L<V4L(&EF('1H97)E(&%R
M92!N;VYE"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T0VAI;&1R96XH)&ED<RPD
M;&5V96QS/3$I"B`@("!["B`@("`@("`@)')E<R`](&%R<F%Y*"D["B`@("`@
M("`@9F]R*"`D:3TQ(#L@)&D\)&QE=F5L<RLQ(#L@)&DK*R`I"B`@("`@("`@
M>PH@("`@("`@("`@("`O+R!I9B`D:61S(&ES(&%N(&%R<F%Y(&EM<&QO9&4@
M=&AE('9A;'5E<PH@("`@("`@("`@("`D9V5T261S(#T@:7-?87)R87DH)&ED
M<RD@/R!I;7!L;V1E*"<L)RPD:61S*2`Z("1I9',["@H@("`@("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*"`@("=314Q%0U0@8RXJ($923TT@)7,@8RPE<R!E
M(%=(15)%)7,@92XE<SUC+B5S($%.1"!E+B5S($E.("@E<RD@)RX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G3U)$15(@0ED@8RXE<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1A8FQE+"1T
M:&ES+3YT86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V=E=%=H97)E061D3VXH("<@04Y$("<@+"`G8R<@*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H
M)VED)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]G971#;VQ.86UE*"=P87)E;G1)9"<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T0V]L3F%M92@G:60G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9V5T261S+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(&]R9&5R(&)Y(&QE9G0L('-O('=E
M(&AA=F4@:70@:6X@=&AE(&]R9&5R(&%S(&ET(&ES(&EN('1H92!T<F5E"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@:68@;F\@)V]R9&5R
M)RUO<'1I;VX@:7,@9VEV96X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9V5T3W!T:6]N*"=O<F1E<B<I(#\@)'1H:7,M/F=E=$]P
M=&EO;B@G;W)D97(G*2`Z("1T:&ES+3Y?9V5T0V]L3F%M92@G;&5F="<I"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1?<F5S(#T@)'1H:7,M/F1B:"T^9V5T06QL*"1Q
M=65R>2DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T:')O
M=T5R<F]R*"`D7W)E<RT^9V5T365S<V%G92@I("P@7U],24Y%7U\@*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D7W)E<R`]("1T:&ES+3Y?<')E<&%R
M95)E<W5L=',H("1?<F5S("D["@H@("`@("`@("`@("`O+R!W92!U<V4@=&AE
M(&ED(&%S('1H92!I;F1E>"P@=&\@;6%K92!T:&4@=7-E(&5A<VEE<B!E<W`N
M(&9O<B!M=6QT:7!L92!R971U<FXM=F%L=65S"B`@("`@("`@("`@("1T96UP
M4F5S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)%]R97,@87,@
M)&%297,I('L*("`@("`@("`@("`@("`@("1T96UP4F5S6R1A4F5S6R1T:&ES
M+3Y?9V5T0V]L3F%M92@G:60G*5U=(#T@)&%297,["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)%]R97,@/2`D=&5M<%)E<SL*"B`@("`@("`@("`@("\O
M"B`@("`@("`@("`@(&EF("@D;&5V96QS/C$I('L*("`@("`@("`@("`@("`@
M("1I9',@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R96%C:"@@)%]R
M97,@87,@)&%297,@*0H@("`@("`@("`@("`@("`@("`@("1I9'-;72`]("1A
M4F5S6R1T:&ES+3Y?9V5T0V]L3F%M92@G:60G*5T["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)')E<R`](&%R<F%Y7VUE<F=E*"1R97,L)%]R97,I.PH*
M("`@("`@("`@("`@+R\@<75I="!T:&4@9F]R+6QO;W`@:68@=&AE<F4@87)E
M(&YO(&-H:6QD<F5N(&EN('1H92!C=7)R96YT(&QE=F5L"B`@("`@("`@("`@
M(&EF("@A<VEZ96]F*"1I9',I*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*
M("`@('T*"B`@("`O*BH*("`@("H@("!G970@=&AE(&YE>'0@96QE;65N="!O
M;B!T:&4@<V%M92!L979E;`H@("`@*B`@(&EF('1H97)E(&ES(&YO;F4@<F5T
M=7)N(&9A;'-E"B`@("`J"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@
M("`J("`@0'9E<G-I;VX@("`@,C`P,B\P-"\Q-0H@("`@*B`@($!A=71H;W(@
M("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@
M("`J("`@0'!A<F%M"B`@("`J("`@0')E='5R;B`@("`@;6EX960@("!T:&4@
M87)R87D@=VET:"!T:&4@9&%T82!O9B!T:&4@;F5X="!E;&5M96YT"B`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!O<B!F86QS92P@:68@=&AE<F4@:7,@
M;F\@;F5X=`H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;W(@5')E95]%
M<G)O<@H@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YE>'0H("1I9"`I"B`@("![
M"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@@("`G4T5,14-4(&XN*B!&4D]-
M("5S(&XL)7,@92!72$52125S(&4N)7,];BXE<RTQ($%.1"!E+B5S/6XN)7,@
M04Y$(&4N)7,])7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G1A8FQE+"1T:&ES+3YT86)L92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9V5T5VAE<F5!9&1/;B@@)R!!3D0@)R`L("=N)R`I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971#;VQ.
M86UE*"=R:6=H="<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]G971#;VQ.86UE*"=L969T)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H)W!A<F5N=$ED)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H)W!A
M<F5N=$ED)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V=E=$-O;$YA;64H)VED)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:60I.PH@("`@("`@(&EF*"!$0CHZ:7-%<G)O<B@@)')E<R`]("1T:&ES
M+3YD8F@M/F=E=%)O=R@D<75E<GDI("D@*0H@("`@("`@('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@)')E<RT^9V5T365S<V%G
M92@I("P@7U],24Y%7U\@*3L*("`@("`@("!]"B`@("`@("`@:68H("$D<F5S
M("D*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!R97!A<F5297-U;'0H("1R97,@*3L*("`@('T*"B`@("`O*BH*
M("`@("H@("!G970@=&AE('!R979I;W5S(&5L96UE;G0@;VX@=&AE('-A;64@
M;&5V96P*("`@("H@("!I9B!T:&5R92!I<R!N;VYE(')E='5R;B!F86QS90H@
M("`@*@H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!V97)S
M:6]N("`@(#(P,#(O,#0O,34*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M
M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A
M;0H@("`@*B`@($!R971U<FX@("`@(&UI>&5D("`@=&AE(&%R<F%Y('=I=&@@
M=&AE(&1A=&$@;V8@=&AE('!R979I;W5S(&5L96UE;G0*("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&]R(&9A;'-E+"!I9B!T:&5R92!I<R!N;R!P<F5V
M:6]U<PH@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;W(@82!4<F5E7T5R
M<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')E=FEO=7,H("1I9"`I"B`@
M("!["B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@@("`G4T5,14-4('`N*B!&
M4D]-("5S('`L)7,@92!72$52125S(&4N)7,]<"XE<RLQ($%.1"!E+B5S/7`N
M)7,@04Y$(&4N)7,])7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G1A8FQE+"1T:&ES+3YT86)L92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5T5VAE<F5!9&1/;B@@)R!!3D0@)R`L("=P
M)R`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971#
M;VQ.86UE*"=L969T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V=E=$-O;$YA;64H)W)I9VAT)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H)W!A<F5N=$ED)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-O;$YA;64H
M)W!A<F5N=$ED)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V=E=$-O;$YA;64H)VED)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:60I.PH@("`@("`@(&EF*"!$0CHZ:7-%<G)O<B@@)')E<R`]("1T
M:&ES+3YD8F@M/F=E=%)O=R@D<75E<GDI("D@*0H@("`@("`@('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@)')E<RT^9V5T365S
M<V%G92@I("P@7U],24Y%7U\@*3L*("`@("`@("!]"B`@("`@("`@:68H("$D
M<F5S("D*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!R97!A<F5297-U;'0H("1R97,@*3L*("`@('T*"B`@("`O
M*BH*("`@("H@("!R971U<FYS(&EF("1C:&EL9$ED(&ES(&$@8VAI;&0@;V8@
M)&ED"B`@("`J"B`@("`J("`@0&%B<W1R86-T"B`@("`J("`@0'9E<G-I;VX@
M("`@,C`P,B\P-"\R.0H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@
M*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I
M97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@:6YT("`@("!I9"!O9B!T
M:&4@96QE;65N=`H@("`@*B`@($!P87)A;2`@("`@(&EN="`@("`@:60@;V8@
M=&AE(&5L96UE;G0@=&\@8VAE8VL@:68@:70@:7,@82!C:&EL9`H@("`@*B`@
M($!R971U<FX@("`@(&)O;VQE86X@=')U92!I9B!I="!I<R!A(&-H:6QD"B`@
M("`J+PH@("`@9G5N8W1I;VX@:7-#:&EL9$]F*"`D:60@+"`D8VAI;&1)9"`I
M"B`@("!["B`@("`@("`@+R\@8VAE8VL@<VEM<&QY(&EF('1H92!L969T(&%N
M9"!R:6=H="!O9B!T:&4@8VAI;&0@87)E('=I=&AI;B!T:&4*("`@("`@("`O
M+R!L969T(&%N9"!R:6=H="!O9B!T:&4@<&%R96YT+"!I9B!S;R!I="!D969I
M;FET;'D@:7,@82!C:&EL9"`Z+2D*("`@("`@("`D<&%R96YT(#T@)'1H:7,M
M/F=E=$5L96UE;G0H)&ED*3L*("`@("`@("`D8VAI;&0@/2`D=&AI<RT^9V5T
M16QE;65N="@D8VAI;&1)9"D["@H@("`@("`@(&EF*"`D<&%R96YT6R=L969T
M)UT@/"`D8VAI;&1;)VQE9G0G72`F)@H@("`@("`@("`@("`D<&%R96YT6R=R
M:6=H="==(#X@)&-H:6QD6R=R:6=H="==("D*("`@("`@("!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*("`@("H@
M("!R971U<FX@=&AE(&UA>&EM=6T@9&5P=&@@;V8@=&AE('1R964*("`@("H*
M("`@("H@("!`=F5R<VEO;B`@("`R,#`S+S`R+S(U"B`@("`J("`@0&%C8V5S
M<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE
M<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<F5T=7)N("`@
M("!I;G0@("`@('1H92!D97!T:"!O9B!T:&4@=')E90H@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$1E<'1H*"D*("`@('L*+R\@1DE86%A-12!43T1/(2$A("`@
M(`H@("`@("`@(')E='5R;B`D=&AI<RT^7W1H<F]W17)R;W(H("=N;W0@:6UP
M;&5M96YT960@>65T)R`L(%]?3$E.15]?("D["B`@("!]"@H@("`@+RHJ"B`@
M("`J("`@5&5L;',@:68@=&AE(&YO9&4@=VET:"!T:&4@9VEV96X@240@:&%S
M(&-H:6QD<F5N+@H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#,O,#,O
M,#0*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R
M("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@
M("`@*B`@($!P87)A;2`@("`@(&EN=&5G97(@=&AE($E$(&]F(&$@;F]D90H@
M("`@*B`@($!R971U<FX@("`@(&)O;VQE86X@:68@=&AE(&YO9&4@=VET:"!T
M:&4@9VEV96X@:60@:&%S(&-H:6QD<F5N"B`@("`J+PH@("`@9G5N8W1I;VX@
M:&%S0VAI;&1R96XH)&ED*0H@("`@>PH@("`@("`@("1E;&5M96YT(#T@)'1H
M:7,M/F=E=$5L96UE;G0H)&ED*3L*("`@("`@("!R971U<FX@)&5L96UE;G1;
M)W)I9VAT)UTM)&5L96UE;G1;)VQE9G0G73XQ.R`@("`O+R!I9B!T:&4@9&EF
M9B!B971W965N(&QE9G0@86YD(')I9VAT/C$@=&AE;B!T:&5R92!A<F4@8VAI
M;&1R96X*("`@('T*"@H@("`@+R\*("`@("\O("!04DE6051%($U%5$A/1%,*
M("`@("\O"@H*("`@("\J*@H@("`@*@H@("`@*@H@("`@*B`@($!A8V-E<W,@
M("`@('!R:79A=&4*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`T+S(P"B`@
M("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K
M<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@("`@("!S=')I;F<@('1H92!C
M=7)R96YT('=H97)E(&-L875S90H@("`@*B`@($!R971U<FX*("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T5VAE<F5!9&1/;B@@)&%D9$%F=&5R/2<@04Y$("<@
M+"`D=&%B;&5.86UE/2<G("D*("`@('L*("`@("`@("!I9B@@)'=H97)E/21T
M:&ES+3YG971/<'1I;VXH)W=H97)E061D3VXG*2`I"B`@("`@("`@>PH@("`@
M("`@("`@("!R971U<FX@)R`G+B@D=&%B;&5.86UE/R1T86)L94YA;64N)RXG
M.B<G*2XB("1W:&5R921A9&1!9G1E<B`B.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)R<["B`@("!]"@H*"@H@("`@+R\@9F]R(&-O;7!A=&EB:6QI='D@
M=&\@365M;W)Y(&UE=&AO9',*("`@(&9U;F-T:6]N(&=E=$9I<G-T4F]O="@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG9712;V]T*"D["B`@("!]
M"B`@("`O*BH*("`@("H@("!G971S('1H92!T<F5E('5N9&5R('1H92!G:79E
M;B!E;&5M96YT(&EN(&]N92!A<G)A>2P@<V]R=&5D"B`@("`J("`@<V\@>6]U
M(&-A;B!G;R!T:')O=6=H('1H92!E;&5M96YT<R!F<F]M(&)E9VEN('1O(&5N
M9"!A;F0@;&ES="!T:&5M"B`@("`J("`@87,@=&AE>2!A<F4@:6X@=&AE('1R
M964L('=H97)E(&5V97)Y(&-H:6QD("AU;G1I;"!T:&4@9&5E<&5S="D@:7,@
M<F5T<F5I=F5D"B`@("`J"B`@("`J("`@0'-E92`@("`@("`@)E]G971.;V1E
M*"D*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`=F5R<VEO
M;B`@("`R,#`Q+S$R+S$W"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+
M<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@
M("`@("!I;G1E9V5R("1S=&%R=$ED("`@('1H92!I9"!W:&5R92!T;R!S=&%R
M="!W86QK:6YG"B`@("`J("`@0'!A<F%M("`@("`@:6YT96=E<B`D9&5P=&@@
M("`@("!T:&ES(&YU;6)E<B!S87ES(&AO=R!D965P(&EN=&\@=&AE('-T<G5C
M='5R92!T:&4@96QE;65N=',@<VAA;&P@8F4@<F5T<F5I=F5D"B`@("`J("`@
M0')E='5R;B`@("`@87)R87D@("!S;W)T960@87,@;&ES=&5D(&EN('1H92!T
M<F5E"B`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$YO9&4H("1S=&%R=$ED/3`@
M+"`D9&5P=&@],"`I"B`@("!["B`@("!]"@I]"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U1R964O3W!T:6]N<RYP:'``````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R-C0V`#$P-#$W,S8S,#`T`#`R,#0Q
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HC(&D@=&AI;FL@=&AI<R!C;&%S<R!S:&]U;&0@9V\@<V]M97=H97)E
M(&EN(&$@8V]M;6]N(%!%05(M<&QA8V4L"B,@8F5C875S92!A(&QO="!O9B!C
M;&%S<V5S('5S92!O<'1I;VYS+"!A="!L96%S="!014%2.CI$0B!D;V5S"B,@
M8G5T('-I;F-E(&ET(&ES(&YO="!V97)Y(&9A;F-Y('1O(&-R;W=D('1H92!0
M14%2+6YA;65S<&%C92!T;V\@;75C:"!I(&1O;G0@:VYO=R!W:&5R92!T;R!P
M=70@:70@>65T(#HM*`H*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@
M=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@5V]L9G)A;2!+<FEE<VEN
M9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@("1)9#H@
M3W!T:6]N<RYP:'`L=B`Q+C0@,C`P,R\P,2\P-"`Q,3HU-CHR-R!M:B!%>'`@
M)`H*<F5Q=6ER95]O;F-E*"=014%2+G!H<"<I.PH*+RHJ"BH@("!T:&ES(&-L
M87-S(&]N;'D@9&5F:6YE<R!C;VUM;VYL>2!U<V5D(&UE=&AO9',L(&5T8RX*
M*B`@(&ET(&ES('=O<G1H;&5S<R!W:71H;W5T(&)E:6YG(&5X=&5N9&5D"BH*
M*B`@($!P86-K86=E("!4<F5E"BH@("!`86-C97-S("`@<'5B;&EC"BH@("!`
M875T:&]R("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD
M93X**@HJ+PIC;&%S<R!4<F5E7T]P=&EO;G,@97AT96YD<R!014%2"GL*("`@
M("\J*@H@("`@*B`@($!V87(@("`@87)R87D@("`D;W!T:6]N<R`@("!Y;W4@
M;F5E9"!T;R!O=F5R=W)I=&4@=&AI<R!A<G)A>2!A;F0@9VEV92!T:&4@:V5Y
M<RP@=&AA="!A<F4@86QL;W=E9`H@("`@*B\*("`@('9A<B`D;W!T:6]N<R`]
M(&%R<F%Y*"D["@H@("`@=F%R("1?9F]R8V53971/<'1I;VX@/2!F86QS93L*
M"B`@("`O*BH*("`@("H@("!T:&ES(&-O;G-T<G5C=&]R('-E=',@=&AE(&]P
M=&EO;G,L('-I;F-E(&D@;F]R;6%L;'D@;F5E9"!T:&ES(&%N9`H@("`@*B`@
M(&EN(&-A<V4@=&AE(&-O;G-T<G5C=&]R(&1O97-N="!N965D('1O(&1O(&%N
M>6UO<F4@:2!A;')E861Y(&AA=F4@:70@9&]N92`Z+2D*("`@("H*("`@("H@
M("!`=F5R<VEO;B`@("`P,B\P,2\P.`H@("`@*B`@($!A8V-E<W,@("`@('!U
M8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O
M;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@87)R87D@
M("`@("`@=&AE(&ME>2UV86QU92!P86ER<R!O9B!T:&4@;W!T:6]N<R!T:&%T
M('-H86QL(&)E('-E=`H@("`@*B`@($!P87)A;2`@("`@(&)O;VQE86X@("`@
M(&EF('-E="!T;R!T<G5E(&]P=&EO;G,@87)E(&%L<V\@<V5T"B`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@979E;B!I9B!N;R!K97DH<RD@=V%S
M+W=E<F4@9F]U;F0@:6X@=&AE(&]P=&EO;G,@<')O<&5R='D*("`@("HO"B`@
M("!F=6YC=&EO;B!4<F5E7T]P=&EO;G,H("1O<'1I;VYS/6%R<F%Y*"D@+"`D
M9F]R8V4]9F%L<V4@*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9F]R8V53971/
M<'1I;VX@/2`D9F]R8V4["@H@("`@("`@(&EF*"!I<U]A<G)A>2@D;W!T:6]N
M<RD@)B8@<VEZ96]F*"1O<'1I;VYS*2`I"B`@("`@("`@("`@(&9O<F5A8V@H
M("1O<'1I;VYS(&%S("1K97D]/B1V86QU92`I"B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T3W!T:6]N*"`D:V5Y("P@)'9A;'5E("D["B`@("!]"@H@("`@
M+RHJ"B`@("`J"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@
M0&%U=&AO<B`@("`@4W1I9R!3+B!"86%K96X*("`@("H@("!`<&%R86T*("`@
M("H@("!`<&%R86T*("`@("H@("!`<&%R86T@("`@("!B;V]L96%N("`@("!I
M9B!S970@=&\@=')U92!O<'1I;VYS(&%R92!A;'-O('-E=`H@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&5V96X@:68@;F\@:V5Y*',I('=A<R]W
M97)E(&9O=6YD(&EN('1H92!O<'1I;VYS('!R;W!E<G1Y"B`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T3W!T:6]N*"`D;W!T:6]N("P@)'9A;'5E("P@)&9O<F-E
M/69A;'-E("D*("`@('L*("`@("`@("!I9B@@:7-?87)R87DH)'9A;'5E*2`I
M("`@("`@("`@("`@("`@("`@("`@("\O(&EF('1H92!V86QU92!I<R!A;B!A
M<G)A>2!E>'1R86-T('1H92!K97ES(&%N9"!A<'!L>2!O;FQY(&5A8V@@=F%L
M=64@=&AA="!I<R!S970*("`@("`@("![("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O('-O('=E(&1O;G0@;W9E<G)I9&4@
M97AI<W1I;F<@;W!T:6]N<R!I;G-I9&4@86X@87)R87DL(&EF(&%N(&]P=&EO
M;B!I<R!A;B!A<G)A>0H@("`@("`@("`@("!F;W)E86-H*"`D=F%L=64@87,@
M)&ME>3T^)&%686QU92`I"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T3W!T
M:6]N*"!A<G)A>2@D;W!T:6]N("P@)&ME>2D@+"`D859A;'5E("D["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@:68H(&ES
M7V%R<F%Y*"1O<'1I;VXI("D*("`@("`@("!["B`@("`@("`@("`@("1M86EN
M3W!T:6]N(#T@)&]P=&EO;ELP73L*("`@("`@("`@("`@)&]P=&EO;G,@/2`B
M6R<B+FEM<&QO9&4H(B==6R<B+"1O<'1I;VXI+B(G72(["B`@("`@("`@("`@
M("1E=F%L0V]D92`](")<)'1H:7,M/F]P=&EO;G,B+B1O<'1I;VYS+B(@/2!<
M)'9A;'5E.R(["B`@("`@("`@?0H@("`@("`@(&5L<V4*("`@("`@("!["B`@
M("`@("`@("`@("1E=F%L0V]D92`](")<)'1H:7,M/F]P=&EO;G-;7"1O<'1I
M;VY=(#T@7"1V86QU93LB.PH@("`@("`@("`@("`D;6%I;D]P=&EO;B`]("1O
M<'1I;VX["B`@("`@("`@?0H*("`@("`@("!I9B@@)'1H:7,M/E]F;W)C95-E
M=$]P=&EO;CT]=')U92!\?"`D9F]R8V4]/71R=64@?'P@:7-S970H)'1H:7,M
M/F]P=&EO;G-;)&UA:6Y/<'1I;VY=*2`I"B`@("`@("`@>PH@("`@("`@("`@
M("!E=F%L*"1E=F%L0V]D92D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`J("`@<V5T(&$@;G5M8F5R(&]F(&]P=&EO;G,@=VAI8V@@87)E('-I
M;7!L>2!G:79E;B!I;B!A;B!A<G)A>0H@("`@*@H@("`@*B`@($!A8V-E<W,@
M("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(*("`@("H@("!`<&%R86T*("`@
M("H@("!`<&%R86T@("`@("!B;V]L96%N("`@("!I9B!S970@=&\@=')U92!O
M<'1I;VYS(&%R92!A;'-O('-E=`H@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5V96X@:68@;F\@:V5Y*',I('=A<R]W97)E(&9O=6YD(&EN('1H
M92!O<'1I;VYS('!R;W!E<G1Y"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T
M:6]N<R@@)&]P=&EO;G,@+"`D9F]R8V4]9F%L<V4@*0H@("`@>PH@("`@("`@
M(&EF*"!I<U]A<G)A>2@D;W!T:6]N<RD@)B8@<VEZ96]F*"1O<'1I;VYS*2`I
M"B`@("`@("`@>PH@("`@("`@("`@("!F;W)E86-H*"`D;W!T:6]N<R!A<R`D
M:V5Y/3XD=F%L=64@*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T3W!T:6]N*"`D:V5Y("P@)'9A;'5E("P@)&9O<F-E("D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J"B`@
M("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@
M8V]P:65D(&9R;VT@4$5!4CH@1$(O8V]M;6UO;BYP:'`*("`@("H@("!`<&%R
M86T@("`@("!B;V]L96%N('1R=64@;VX@<W5C8V5S<PH@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$]P=&EO;B@D;W!T:6]N*0H@("`@>PH@("`@("`@(&EF*"!F
M=6YC7VYU;5]A<F=S*"D@/B`Q("8F"B`@("`@("`@("`@(&ES7V%R<F%Y*"1T
M:&ES+3YO<'1I;VYS6R1O<'1I;VY=*2D*("`@("`@("!["B`@("`@("`@("`@
M("1A<F=S(#T@9G5N8U]G971?87)G<R@I.PH@("`@("`@("`@("`D979A;$-O
M9&4@/2`B7"1R970@/2!<)'1H:7,M/F]P=&EO;G-;)R(N:6UP;&]D92@@(B==
M6R<B("P@)&%R9W,@*2XB)UT[(CL*("`@("`@("`@("`@979A;"@@)&5V86Q#
M;V1E("D["B`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6R1O<'1I;VY=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F]P=&EO;G-;)&]P=&EO;ET["B`@
M("`@("`@?0HC("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N
M:VYO=VX@;W!T:6]N("1O<'1I;VXB*3L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`J("`@<F5T=7)N<R!A;&P@=&AE(&]P=&EO
M;G,*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`P,B\P-2\R,`H@("`@*B`@
M($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R
M86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0')E
M='5R;B`@("`@<W1R:6YG("`@("`@86QL(&]P=&EO;G,@87,@86X@87)R87D*
M("`@("HO"B`@("!F=6YC=&EO;B!G971/<'1I;VYS*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/F]P=&EO;G,["B`@("!]"GT@+R\@96YD(&]F(&-L
M87-S"C\^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U1R964O0V]M
M;6]N+G!H<```````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#,U,34S`#$P-#$W,S8S,#`T`#`R,#(P-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!7
M;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/B`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+PHO+R`@)$ED.B!#;VUM;VXN<&AP+'8@,2XR,2`R,#`S+S`S+S`T(#$X
M.C4Y.C(Q(&-A:6X@17AP("0*"G)E<75I<F5?;VYC92@G5')E92]/<'1I;VYS
M1$(N<&AP)RD["@ID969I;F4H(E12145?15)23U(B+"`@("`@("`@("`@("`@
M("`@("`@+3$I.PID969I;F4H(E12145?15)23U)?24Y604Q)1%]005)%3E0B
M+"`@("`@+3(I.PH*+RHJ"BH@("!C;VUM;VX@=')E92!C;&%S<RP@:6UP;&5M
M96YT<R!C;VUM;VX@9G5N8W1I;VYA;&ET>0HJ"BH@("!T:&ES(&-L87-S(&5X
M=&5N9',@5')E95]/<'1I;VYS1$(@<V\@979E<GD@8VQA<W,@=&AA="!E>'1E
M;F1S('1H:7,@;V4@8V%N"BH@("!C;VYN96-T('1O(&$@9&(@86YD('-E="!O
M<'1I;VYS"BH**B`@($!A8V-E<W,@("`@('!U8FQI8PHJ("`@0&%U=&AO<B`@
M("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X**B`@
M($!V97)S:6]N("`@(#(P,#$O,#8O,C<**B`@($!P86-K86=E("`@(%1R964*
M*B\*8VQA<W,@5')E95]#;VUM;VX@97AT96YD<R!4<F5E7T]P=&EO;G-$0@I[
M"@H@("`@+RHJ"B`@("`J("`@<'5T('!R;W!E<B!V86QU92UK97ES(&%R92!G
M:79E;B!I;B!E86-H(&-L87-S+"!D97!E;F1I;F<@;VX@=&AE(&EM<&QE;65N
M=&%T:6]N"B`@("`J("`@;VYL>2!S;VUE(&]P=&EO;G,@87)E(&YE961E9"!O
M<B!A;&QO=V5D+"!S964@=&AE(&-L87-S97,@=VAI8V@@97AT96YD('1H:7,@
M;VYE"B`@("`J"B`@("`J("`@0&%C8V5S<R!P=6)L:6,*("`@("H@("!`=F%R
M("`@(&%R<F%Y("`@<V%V97,@=&AE(&]P=&EO;G,@<&%S<V5D('1O('1H92!C
M;VYS=')U8W1O<@H@("`@*B\*("`@('9A<B`D;W!T:6]N<R`]("!A<G)A>2@I
M.PH*"B`@("`O*BH*("`@("H*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R
M,#`R+S`Q+S$X"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@
M0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN
M9RYD93X*("`@("HO"B`@("!F=6YC=&EO;B!G971#:&EL9$ED*"`D:60@*0H@
M("`@>PH@("`@("`@("1C:&EL9"`]("1T:&ES+3YG971#:&EL9"@@)&ED("D[
M"B`@("`@("`@<F5T=7)N("1C:&EL9%LG:60G73L*("`@('T*"B`@("`O*BH*
M("`@("H@("!G970@=&AE(&ED<R!O9B!T:&4@8VAI;&1R96X@;V8@=&AE(&=I
M=F5N(&5L96UE;G0*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`R
M+S`V"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO
M<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*
M("`@("H@("!`<&%R86T@("`@("!I;G1E9V5R("1I9"`@("`@("`@("`@("!)
M1"!O9B!T:&4@96QE;65N="!T:&%T('1H92!C:&EL9')E;B!S:&%L;"!B92!R
M971R96EV960@9F]R"B`@("`J("`@0'!A<F%M("`@("`@:6YT96=E<B!H;W<@
M;6%N>2!L979E;',@9&5E<"!I;G1O('1H92!T<F5E"B`@("`J("`@0')E='5R
M;B`@("`@;6EX960@("!A;B!A<G)A>2!O9B!A;&P@=&AE(&ED<R!O9B!T:&4@
M8VAI;&1R96X@;V8@=&AE(&5L96UE;G0@=VET:"!I9#TD:60L"B`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!O<B!F86QS92!I9B!T:&5R92!A<F4@;F\@
M8VAI;&1R96X*("`@("HO"B`@("!F=6YC=&EO;B!G971#:&EL9')E;DED<R@D
M:60L)&QE=F5L<STQ*0H@("`@>PH@("`@("`@(&EF("@A*"1C:&EL9')E;B`]
M("1T:&ES+3YG971#:&EL9')E;B@D:60L)&QE=F5L<RDI*2![("`@+R\@<F5T
M=7)N<R!F86QS92!I9B!N;R!C:&EL9')E;B!E>&ES=`H@("`@("`@("`@("!R
M971U<FX@87)R87DH*3L@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<F5T
M=7)N(&%N(&5M<'1Y(&%R<F%Y+"!I9B!Y;W4@=V%N="!T;R!K;F]W(&EF('1H
M97)E(&%R92!C:&EL9')E;BP@=7-E(&AA<T-H:6QD<F5N"B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&-H:6QD<F5N("8F('-I>F5O9B@D8VAI;&1R96XI*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1C:&EL9')E;B!A<R`D84-H:6QD*2![
M"B`@("`@("`@("`@("`@("`D8VAI;&1R96Y)9'-;72`]("1A0VAI;&1;)VED
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8VAI;&1R96Y)9',["B`@("!]"@H@("`@+RHJ"B`@("`J("`@9V5T<R!A;&P@
M=&AE(&-H:6QD<F5N(&%N9"!G<F%N9"!C:&EL9')E;B!E=&,N"B`@("`J"B`@
M("`J("`@0'9E<G-I;VX@("`@,C`P,B\P.2\S,`H@("`@*B`@($!A8V-E<W,@
M("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I
M;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@
M:6YT96=E<B`D:60@("`@($E$(&]F('1H92!E;&5M96YT('1H870@=&AE(&-H
M:6QD<F5N('-H86QL(&)E(')E=')E:79E9"!F;W(*("`@("H@("!`<F5T=7)N
M("`@("!M:7AE9"`@(&%N(&%R<F%Y(&]F(&%L;"!T:&4@8VAI;&1R96X@;V8@
M=&AE(&5L96UE;G0@=VET:"!I9#TD:60L"B`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!O<B!F86QS92!I9B!T:&5R92!A<F4@;F\@8VAI;&1R96X*("`@
M("HO"B\O($9)6%A8344@<F5M;W9E('1H:7,@;65T:&]D(&%N9"!R97!L86-E
M(&ET(&)Y(&=E=$-H:6QD<F5N*"1I9"PP*2`@("`*("`@(&9U;F-T:6]N(&=E
M=$%L;$-H:6QD<F5N*"1I9"D*("`@('L*("`@("`@("`D<F5T0VAI;&1R96X@
M/2!F86QS93L*("`@("`@("!I9B`H)&-H:6QD<F5N(#T@)'1H:7,M/FAA<T-H
M:6QD<F5N*"1I9"DI('L@("`@("`@("`@("`@("`@("`*("`@("`@("`@("`@
M)')E=$-H:6QD<F5N(#T@)'1H:7,M/E]G971!;&Q#:&EL9')E;B@@)&ED("D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T0VAI;&1R96X["B`@("!]
M"@H@("`@+RHJ"B`@("`J("`@=&AI<R!M971H;V0@9V5T<R!A;&P@=&AE(&-H
M:6QD<F5N(')E8W5R<VEV96QY"B`@("`J"B`@("`J("`@0'-E92`@("!G971!
M;&Q#:&EL9')E;B@I"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P.2\S,`H@
M("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@
M(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J
M("`@0'!A<F%M("`@("`@:6YT96=E<B`D:60@("`@($E$(&]F('1H92!E;&5M
M96YT('1H870@=&AE(&-H:6QD<F5N('-H86QL(&)E(')E=')E:79E9"!F;W(*
M("`@("H@("!`<F5T=7)N("`@("!M:7AE9"`@(&%N(&%R<F%Y(&]F(&%L;"!T
M:&4@:61S(&]F('1H92!C:&EL9')E;B!O9B!T:&4@96QE;65N="!W:71H(&ED
M/21I9"P*("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]R(&9A;'-E(&EF
M('1H97)E(&%R92!N;R!C:&EL9')E;@H@("`@*B\*("`@(&9U;F-T:6]N("9?
M9V5T06QL0VAI;&1R96XH)&ED*0H@("`@>PH@("`@("`@("1R971#:&EL9')E
M;B`](&%R<F%Y*"D["B`@("`@("`@:68@*"1C:&EL9')E;B`]("1T:&ES+3YG
M971#:&EL9')E;B@D:60I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1C:&EL
M9')E;B!A<R`D:V5Y/3XD84-H:6QD*2!["B`@("`@("`@("`@("`@("`D<F5T
M0VAI;&1R96Y;72`]("8D8VAI;&1R96Y;)&ME>5T["B`@("`@("`@("`@("`@
M("`D<F5T0VAI;&1R96X@/2!A<G)A>5]M97)G92@D<F5T0VAI;&1R96XL)'1H
M:7,M/E]G971!;&Q#:&EL9')E;B@@)&%#:&EL9%LG:60G72`I*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)')E=$-H:6QD<F5N
M.PH@("`@?0H*("`@("\J*@H@("`@*B`@(&=E=',@86QL('1H92!C:&EL9')E
M;BUI9',@86YD(&=R86YD(&-H:6QD<F5N+6ED<PH@("`@*@H@("`@*B`@($!V
M97)S:6]N("`@(#(P,#(O,#DO,S`*("`@("H@("!`86-C97-S("`@("!P=6)L
M:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF
M<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@("`@(&EN=&5G97(@
M)&ED("`@("!)1"!O9B!T:&4@96QE;65N="!T:&%T('1H92!C:&EL9')E;B!S
M:&%L;"!B92!R971R96EV960@9F]R"B`@("`J("`@0')E='5R;B`@("`@;6EX
M960@("!A;B!A<G)A>2!O9B!A;&P@=&AE(&ED<R!O9B!T:&4@8VAI;&1R96X@
M;V8@=&AE(&5L96UE;G0@=VET:"!I9#TD:60L"B`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!O<B!F86QS92!I9B!T:&5R92!A<F4@;F\@8VAI;&1R96X*
M("`@("HO"B`@("!F=6YC=&EO;B!G971!;&Q#:&EL9')E;DED<R@@)&ED("D*
M("`@('L@("`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@)&-H:6QD<F5N
M261S(#T@87)R87DH*3L*("`@("`@("!I9B@@)&%L;$-H:6QD<F5N(#T@)'1H
M:7,M/F=E=$%L;$-H:6QD<F5N*"1I9"D@*0H@("`@("`@('L*("`@("`@("`@
M("`@)&-H:6QD<F5N261S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C
M:"@@)&%L;$-H:6QD<F5N(&%S("1A3F]D92`I"B`@("`@("`@("`@("`@("`D
M8VAI;&1R96Y)9'-;72`]("1A3F]D95LG:60G73L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1C:&EL9')E;DED<SL*("`@('T*("`@("\J*@H@("`@*B`@
M(&=E="!T:&4@:60@;V8@=&AE('!A<F5N="!F;W(@=&AE(&=I=F5N(&5L96UE
M;G0*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`Q+S$X"B`@("`J
M("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0'!A<F%M("`@("`@:6YT
M96=E<B`D:60@=&AE(&ED(&]F('1H92!E;&5M96YT(&9O<B!W:&EC:"!T:&4@
M<&%R96YT260@<VAA;&P@8F4@<F5T<F5I=F5D"B`@("`J("`@0&%U=&AO<B`@
M("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@
M("HO"B`@("!F=6YC=&EO;B!G971087)E;G1)9"@@)&ED("D*("`@('L*("`@
M("`@("`D<&%R96YT(#T@)'1H:7,M/F=E=%!A<F5N="@@)&ED("D["B`@("`@
M("`@<F5T=7)N("1P87)E;G1;)VED)UT["B`@("!]"@H@("`@+RHJ"B`@("`J
M("`@=&AI<R!G971S(&%L;"!T:&4@<')E8V5E9&EN9R!N;V1E<RP@=&AE('!A
M<F5N="!A;F0@:70G<R!P87)E;G0@86YD('-O(&]N"B`@("`J"B`@("`J("`@
M0'9E<G-I;VX@("`@,C`P,B\P."\Q.0H@("`@*B`@($!A8V-E<W,@("`@('!U
M8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O
M;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@:6YT96=E
M<B`D:60@=&AE(&ED(&]F('1H92!E;&5M96YT(&9O<B!W:&EC:"!T:&4@<&%R
M96YT260@<VAA;&P@8F4@<F5T<F5I=F5D"B`@("`J("`@0')E='5R;B`@("`@
M87)R87D@("!O9B!T:&4@<&%R96YT(&YO9&5S(&EN8VQU9&EN9R!T:&4@;F]D
M92!W:71H(&ED("1I9`H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=',H
M("1I9"`I"B`@("!["B`@("`@("`@)'!A=&@@/2`D=&AI<RT^9V5T4&%T:"@D
M:60I.PH@("`@("`@("1P87)E;G1S(#T@87)R87DH*3L*("`@("`@("!I9B@@
M<VEZ96]F*"1P871H*2`I"B`@("`@("`@("`@(&9O<F5A8V@H("1P871H(&%S
M("1A3F]D92`I"B`@("`@("`@("`@("`@("`D<&%R96YT<UM=(#T@)&%.;V1E
M.PH@("`@("`@(')E='5R;B`D<&%R96YT<SL*("`@('T*"B`@("`O*BH*("`@
M("H@("!G970@=&AE(&ED<R!O9B!T:&4@<&%R96YT<R!A;F0@86QL(&ET)W,@
M<&%R96YT<R!A;F0@<V\@;VX*("`@("H@("!I="!S:6UP;'D@<F5T=7)N<R!T
M:&4@:61S(&]F('1H92!E;&5M96YT<R!R971U<FYE9"!B>2!G971087)E;G1S
M*"D*"B`@("`J("`@0'-E92`@("!G971087)E;G1S*"D*("`@("H@("!`=F5R
M<VEO;B`@("`R,#`R+S`X+S$Y"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC
M"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A
M;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@("`@("!I;G1E9V5R("1I
M9"!T:&4@:60@;V8@=&AE(&5L96UE;G0@9F]R('=H:6-H('1H92!P87)E;G1)
M9"!S:&%L;"!B92!R971R96EV960*("`@("H@("!`<F5T=7)N("`@("!A<G)A
M>2`@(&]F('1H92!I9',*("`@("HO"B`@("!F=6YC=&EO;B!G971087)E;G1S
M261S*"`D:60@*0H@("`@>PH@("`@("`@("1P87)E;G1S(#T@)'1H:7,M/F=E
M=%!A<F5N=',H)&ED*3L*("`@("`@("`D<&%R96YT<TED<R`](&%R<F%Y*"D[
M"B`@("`@("`@:68H('-I>F5O9B@D<&%R96YT<RD@*0H@("`@("`@("`@("!F
M;W)E86-H*"`D<&%R96YT<R!A<R`D84YO9&4@*0H@("`@("`@("`@("`@("`@
M)'!A<F5N='-)9'-;72`]("1A3F]D95LG:60G73L*("`@("`@("!R971U<FX@
M)'!A<F5N='-)9',["B`@("!]"@H@("`@+RHJ"B`@("`J"B`@("`J"B`@("`J
M("`@0'9E<G-I;VX@("`@,C`P,B\P,2\Q.`H@("`@*B`@($!A8V-E<W,@("`@
M('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@
M/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3F5X=$ED*"`D:60@*0H@("`@>PH@("`@("`@("1N97AT(#T@)'1H:7,M/F=E
M=$YE>'0H("1I9"`I.PH@("`@("`@(')E='5R;B`D;F5X=%LG:60G73L*("`@
M('T*"B`@("`O*BH*("`@("H*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R
M,#`R+S`Q+S$X"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@
M0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN
M9RYD93X*("`@("HO"B`@("!F=6YC=&EO;B!G9710<F5V:6]U<TED*"`D:60@
M*0H@("`@>PH@("`@("`@("1P<F5V:6]U<R`]("1T:&ES+3YG9710<F5V:6]U
M<R@@)&ED("D["B`@("`@("`@<F5T=7)N("1P<F5V:6]U<ULG:60G73L*("`@
M('T*"B`@("`O*BH*("`@("H*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R
M,#`R+S`Q+S$X"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@
M0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN
M9RYD93X*("`@("HO"B`@("!F=6YC=&EO;B!G971,969T260H("1I9"`I"B`@
M("!["B`@("`@("`@)&QE9G0@/2`D=&AI<RT^9V5T3&5F="@@)&ED("D["B`@
M("`@("`@<F5T=7)N("1L969T6R=I9"==.PH@("`@?0H*("`@("\J*@H@("`@
M*@H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#$O,3@*("`@("H@
M("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF
M<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%)I9VAT260H("1I9"`I"B`@("!["B`@("`@("`@)')I
M9VAT(#T@)'1H:7,M/F=E=%)I9VAT*"`D:60@*3L*("`@("`@("!R971U<FX@
M)')I9VAT6R=I9"==.PH@("`@?0H*("`@("\J*@H@("`@*@H@("`@*@H@("`@
M*B`@($!V97)S:6]N("`@(#(P,#(O,#$O,3@*("`@("H@("!`86-C97-S("`@
M("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG
M(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$9I<G-T4F]O=$ED*"D*("`@('L*("`@("`@("`D9FER<W12;V]T(#T@)'1H
M:7,M/F=E=$9I<G-T4F]O="@I.PH@("`@("`@(')E='5R;B`D9FER<W12;V]T
M6R=I9"==.PH@("`@?0H*("`@("\J*@H@("`@*@H@("`@*@H@("`@*B`@($!V
M97)S:6]N("`@(#(P,#(O,#0O,38*("`@("H@("!`86-C97-S("`@("!P=6)L
M:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF
M<F%M0&MR:65S:6YG+F1E/@H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)O;W1)
M9"@I"B`@("!["B`@("`@("`@)&9I<G-T4F]O="`]("1T:&ES+3YG9712;V]T
M*"D["B`@("`@("`@<F5T=7)N("1F:7)S=%)O;W1;)VED)UT["B`@("!]"@H@
M("`@+RHJ"B`@("`J("`@<F5T=7)N<R!T:&4@<&%T:"!A<R!A('-T<FEN9PH@
M("`@*@H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!V97)S
M:6]N("`@(#(P,#(O,#,O,C@*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*
M("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M
M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@("`@(&UI>&5D("`@)&ED
M("`@("!T:&4@:60@;V8@=&AE(&YO9&4@=&\@9V5T('1H92!P871H(&9O<@H@
M("`@*B`@($!P87)A;2`@("`@(&EN=&5G97(@268@;V9F<V5T(&ES('!O<VET
M:79E+"!T:&4@<V5Q=65N8V4@=VEL;`H@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@<W1A<G0@870@=&AA="!O9F9S970@:6X@=&AE(&%R<F%Y("X@($EF
M"B`@("`J("`@("`@("`@("`@("`@("`@("`@("!O9F9S970@:7,@;F5G871I
M=F4L('1H92!S97%U96YC92!W:6QL('-T87)T('1H870@9F%R(&9R;VT@=&AE
M(&5N9"!O9B!T:&4@87)R87D@+@H@("`@*B`@($!P87)A;2`@("`@(&EN=&5G
M97(@268@;&5N9W1H(&ES(&=I=F5N(&%N9"!I<R!P;W-I=&EV92P@=&AE;@H@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AE('-E<75E;F-E('=I;&P@
M:&%V92!T:&%T(&UA;GD@96QE;65N=',@:6X@:70N($EF"B`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!L96YG=&@@:7,@9VEV96X@86YD(&ES(&YE9V%T
M:79E('1H96X@=&AE"B`@("`J("`@("`@("`@("`@("`@("`@("`@("!S97%U
M96YC92!W:6QL('-T;W`@=&AA="!M86YY(&5L96UE;G1S(&9R;VT@=&AE(&5N
M9"!O9B!T:&4*("`@("H@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y+B!)
M9B!I="!I<R!O;6ET=&5D+"!T:&5N('1H92!S97%U96YC92!W:6QL(&AA=F4@
M979E<GET:&EN9PH@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9G)O;2!O
M9F9S970@=7`@=6YT:6P@=&AE(&5N9"!O9B!T:&4@87)R87DN"B`@("`J("`@
M0')E='5R;B`@("`@87)R87D@("!T:&ES(&%R<F%Y(&-O;G1A:6YS(&%L;"!E
M;&5M96YT<R!F<F]M('1H92!R;V]T('1O('1H92!E;&5M96YT(&=I=F5N(&)Y
M('1H92!I9`H@("`@*@H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A=&A!<U-T
M<FEN9R@@)&ED("P@)'-E<&5R871O<CTG+R<@+"`D;V9F<V5T/3`@+"`D;&5N
M9W1H/3`@*0H@("`@>PH@("`@("`@("1P871H(#T@)'1H:7,M/F=E=%!A=&@H
M)&ED*3L*("`@("`@("!F;W)E86-H("@D<&%T:"!A<R`D84YO9&4I('L*("`@
M("`@("`@("`@)'!A=&A!<G)A>5M=(#T@)&%.;V1E6R=N86UE)UT["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&]F9G-E="D@>PH@("`@("`@("`@("!I9B`H
M)&QE;F=T:"D@>PH@("`@("`@("`@("`@("`@)'!A=&A!<G)A>2`](&%R<F%Y
M7W-L:6-E*"1P871H07)R87DL)&]F9G-E="PD;&5N9W1H*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P871H07)R87D@/2!A<G)A
M>5]S;&EC92@D<&%T:$%R<F%Y+"1O9F9S970I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D<&%T:%-T<FEN9R`]("<G.PH@("`@("`@(&EF
M*"!S:7IE;V8H)'!A=&A!<G)A>2D@*0H@("`@("`@("`@("`D<&%T:%-T<FEN
M9R`](&EM<&QO9&4H)'-E<&5R871O<BPD<&%T:$%R<F%Y*3L*("`@("`@("!R
M971U<FX@)'!A=&A3=')I;F<["B`@("!]("\O(&5N9"!O9B!F=6YC=&EO;@H*
M"@H*"@H@("`@+R\*("`@("\O("!A8G-T<F%C="!M971H;V1S+"!T:&]S92!S
M:&]U;&0@8F4@;W9E<G=R:71T96X@8GD@=&AE(&EM<&QE;65N=&EN9R!C;&%S
M<PH@("`@+R\*"@H@("`@+RHJ"B`@("`J("`@9V5T<R!T:&4@<&%T:"!T;R!T
M:&4@96QE;65N="!G:79E;B!B>2!I=',@:60*("`@("H*("`@("H@("!`86)S
M=')A8W0*("`@("H@("!`=F5R<VEO;B`@("`R,#`Q+S$P+S$P"B`@("`J("`@
M0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A
M;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R
M86T@("`@("!M:7AE9"`@("1I9"`@("`@=&AE(&ED(&]F('1H92!N;V1E('1O
M(&=E="!T:&4@<&%T:"!F;W(*("`@("H@("!`<F5T=7)N("`@("!A<G)A>2`@
M('1H:7,@87)R87D@8V]N=&%I;G,@86QL(&5L96UE;G1S(&9R;VT@=&AE(')O
M;W0@=&\@=&AE(&5L96UE;G0@9VEV96X@8GD@=&AE(&ED"B`@("`J"B`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&%T:"@@)&ED("D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]T:')O=T5R<F]R*"`G;F]T(&EM<&QE;65N=&5D+"!A
M="!L96%S="!N;W0@;W9E<G=R:71T96X@=&AE(&%B<W1R86-T(&1E8VQA<F%T
M:6]N)R`L(%]?3$E.15]?("D["B`@("!]("\O(&5N9"!O9B!F=6YC=&EO;@H*
M("`@("\J*@H@("`@*B`@(&=E="!T:&4@;&5V96PL('=H:6-H(&ES(&AO=R!F
M87(@8F5L;W<@=&AE(')O;W0@=&AE(&5L96UE;G0@=VET:"!T:&4@9VEV96X@
M:60@:7,*("`@("H*("`@("H@("!`86)S=')A8W0*("`@("H@("!`=F5R<VEO
M;B`@("`R,#`Q+S$Q+S(U"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@
M("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K
M<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@("`@("!M:7AE9"`@("1I9"`@
M("`@=&AE(&ED(&]F('1H92!N;V1E('1O(&=E="!T:&4@;&5V96P@9F]R"B`@
M("`J"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&5V96PH("1I9"`I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@)VYO="!I;7!L
M96UE;G1E9"P@870@;&5A<W0@;F]T(&]V97)W<FET=&5N('1H92!A8G-T<F%C
M="!D96-L87)A=&EO;B<@+"!?7TQ)3D5?7R`I.PH@("`@?2`O+R!E;F0@;V8@
M9G5N8W1I;VX*"B`@("`O*BH*("`@("H@("!R971U<FYS(&EF("1C:&EL9$ED
M(&ES(&$@8VAI;&0@;V8@)&ED"B`@("`J"B`@("`J("`@0&%B<W1R86-T"B`@
M("`J("`@0'9E<G-I;VX@("`@,C`P,B\P-"\R.0H@("`@*B`@($!A8V-E<W,@
M("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I
M;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@
M:6YT("`@("!I9"!O9B!T:&4@96QE;65N=`H@("`@*B`@($!P87)A;2`@("`@
M(&EN="`@("`@:60@;V8@=&AE(&5L96UE;G0@=&\@8VAE8VL@:68@:70@:7,@
M82!C:&EL9`H@("`@*B`@($!P87)A;2`@("`@(&)O;VQE86X@:68@=&AI<R!I
M<R!T<G5E('1H92!E;G1I<F4@=')E92!B96QO=R!I<R!C:&5C:V5D"B`@("`J
M("`@0')E='5R;B`@("`@8F]O;&5A;B!T<G5E(&EF(&ET(&ES(&$@8VAI;&0*
M("`@("HO"B`@("!F=6YC=&EO;B!I<T-H:6QD3V8H("1I9"`L("1C:&EL9$ED
M("P@)&-H96-K06QL/71R=64@*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W1H<F]W17)R;W(H("=N;W0@:6UP;&5M96YT960L(&%T(&QE87-T(&YO
M="!O=F5R=W)I='1E;B!T:&4@86)S=')A8W0@9&5C;&%R871I;VXG("P@7U],
M24Y%7U\@*3L*("`@('T@+R\@96YD(&]F(&9U;F-T:6]N"@H@("`@+RHJ"B`@
M("`J("`@<F5T=7)N('1H92!M87AI;75M(&1E<'1H(&]F('1H92!T<F5E"B`@
M("`J"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,R\P,B\R-0H@("`@*B`@($!A
M8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@
M2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0')E='5R
M;B`@("`@:6YT("`@("!T:&4@9&5P=&@@;V8@=&AE('1R964*("`@("HO"B`@
M("!F=6YC=&EO;B!G971$97!T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=')E941E<'1H.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"@H*
M"@H@("`@+R\*("`@("\O("!04DE6051%($U%5$A/1%,*("`@("\O"@H*("`@
M("\J*@H@("`@*B`@('!R97!A<F4@;75L=&EP;&4@<F5S=6QT<PH@("`@*@H@
M("`@*B`@($!S964@("`@("`@(%]P<F5P87)E4F5S=6QT*"D*("`@("H@("!`
M86-C97-S("`@("!P<FEV871E"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P
M,R\P,PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O
M;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M"B`@("`J("`@0')E
M='5R;@H@("`@*B\*("`@(&9U;F-T:6]N(%]P<F5P87)E4F5S=6QT<R@@)')E
M<W5L=',@*0H@("`@>PH@("`@("`@("1N97=297-U;'1S(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H*"`D<F5S=6QT<R!A<R`D:V5Y/3XD85)E<W5L="`I
M"B`@("`@("`@("`@("1N97=297-U;'1S6R1K97E=(#T@)'1H:7,M/E]P<F5P
M87)E4F5S=6QT*"1A4F5S=6QT*3L*("`@("`@("!R971U<FX@)&YE=U)E<W5L
M=',["B`@("!]"@H@("`@+RHJ"B`@("`J("`@;6%P(&)A8VL@=&AE(&EN9&5X
M(&YA;65S('1O(&=E="!W:&%T(&ES(&5X<&5C=&5D"B`@("`J"B`@("`J("`@
M0&%C8V5S<R`@("`@<')I=F%T90H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O
M,#,O,#,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW
M;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;0H@("`@*B`@($!R
M971U<FX*("`@("HO"B`@("!F=6YC=&EO;B!?<')E<&%R95)E<W5L="@@)')E
M<W5L="`I"B`@("!["B`@("`@("`@)&UA<"`]("1T:&ES+3YG971/<'1I;VXH
M)V-O;'5M;DYA;65-87!S)RD["@H@("`@("`@(&EF*"`D;6%P("D*("`@("`@
M("!F;W)E86-H*"`D;6%P(&%S("1K97D]/B1C;VQU;6Y.86UE("D*("`@("`@
M("!["B`@("`@("`@("`@("1R97-U;'1;)&ME>5T@/2`D<F5S=6QT6R1C;VQU
M;6Y.86UE73L*("`@("`@("`@("`@=6YS970H)')E<W5L=%LD8V]L=6UN3F%M
M95TI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("`O*BH*("`@("H@("!T:&ES(&UE=&AO9"!R971R96EV97,@=&AE(')E
M86P@8V]L=6UN(&YA;64L(&%S('5S960@:6X@=&AE($1""B`@("`J("`@<VEN
M8V4@=&AE(&EN=&5R;F%L(&YA;65S(&%R92!F:7AE9"P@=&\@8F4@<&]R=&%B
M;&4@8F5T=V5E;B!D:69F97)E;G0*("`@("H@("!$0BUC;VQU;6X@;F%M:6YG
M<RP@=V4@;6%P('1H92!I;G1E<FYA;"!N86UE('1O('1H92!R96%L(&-O;'5M
M;B!N86UE(&AE<F4*("`@("H*("`@("H@("!`86-C97-S("`@("!P<FEV871E
M"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P,R\P,@H@("`@*B`@($!A=71H
M;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^
M"B`@("`J("`@0'!A<F%M"B`@("`J("`@0')E='5R;@H@("`@*B\*("`@(&9U
M;F-T:6]N(%]G971#;VQ.86UE*"`D:6YT97)N86Q.86UE("D*("`@('L*("`@
M("`@("!I9B@@)&UA<"`]("1T:&ES+3YG971/<'1I;VXH("=C;VQU;6Y.86UE
M36%P<R<@*2`I"B`@("`@("`@>PH@("`@("`@("`@("!I9B@@:7-S970H)&UA
M<%LD:6YT97)N86Q.86UE72D@*0H@("`@("`@("`@("`@("`@<F5T=7)N("1M
M87!;)&EN=&5R;F%L3F%M95T["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M:6YT97)N86Q.86UE.PH@("`@?0H*("`@("\J*@H@("`@*@H@("`@*@H@("`@
M*B`@($!A8V-E<W,@("`@('!R:79A=&4*("`@("H@("!`=F5R<VEO;B`@("`R
M,#`R+S`S+S`R"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN
M9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T*("`@("H@
M("!`<F5T=7)N"B`@("`J+PH@("`@9G5N8W1I;VX@7W1H<F]W17)R;W(H("1M
M<V<@+"`D;&EN92`L("1M;V1E/6YU;&P@*0H@("`@>PH@("`@("`@(&EF*"`D
M;6]D93T]/6YU;&P@)B8@)'1H:7,M/F1E8G5G/C`@*0H@("`@("`@("`@("`D
M;6]D92`](%!%05)?15)23U)?4%))3E0["B`@("`@("`@<F5T=7)N(&YE=R!4
M<F5E7T5R<F]R*"`D;7-G("P@)&QI;F4@+"!?7T9)3$5?7R`L("1M;V1E("P@
M)'1H:7,M/F1B:"T^;&%S=%]Q=65R>2`I.PH@("`@?0H*?0H_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O5')E92]/<'1I;VYS1$(N<&AP````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<W-S(`,3`T,3<S
M-C,P,#0`,#(P-C(T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B,@:2!T:&EN:R!T:&ES(&-L87-S('-H;W5L9"!G
M;R!S;VUE=VAE<F4@:6X@82!C;VUM;VX@4$5!4BUP;&%C92P*(R!B=70@<VEN
M8V4@:70@:7,@;F]T('9E<GD@9F%N8WD@=&\@8W)O=V0@=&AE(%!%05(M;F%M
M97-P86-E('1O;R!M=6-H(&D@9&]N="!K;F]W('=H97)E('1O('!U="!I="!Y
M970@.BTH"@HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!7;VQF<F%M($MR:65S:6YG(#QW;VQF
M<F%M0&MR:65S:6YG+F1E/B`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`@)$ED.B!/<'1I;VYS
M1$(N<&AP+'8@,2XT(#(P,#,O,#$O,#0@,3$Z-38Z,C<@;6H@17AP("0*"G)E
M<75I<F5?;VYC92@G5')E92]/<'1I;VYS+G!H<"<I.PH*+RHJ"BH@("!T:&ES
M(&-L87-S(&%D9&ET:6]N86QL>2!R971R96EV97,@82!$0B!C;VYN96-T:6]N
M(&%N9"!S879E<R!I=`HJ("`@:6X@=&AE('!R;W!E<G1Y(")D8F@B"BH**B`@
M($!P86-K86=E("!4<F5E"BH@("!`86-C97-S("`@<'5B;&EC"BH@("!`875T
M:&]R("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*
M*@HJ+PIC;&%S<R!4<F5E7T]P=&EO;G-$0B!E>'1E;F1S(%1R965?3W!T:6]N
M<PI["B`@("`O*BH*("`@("H@("!`=F%R("`@(&]B:F5C=`H@("`@*B\*("`@
M('9A<B`D9&)H.PH*("`@("\J*@H@("`@*B`@('1H:7,@8V]N<W1R=6-T;W(@
M<V5T<R!T:&4@;W!T:6]N<RP@<VEN8V4@:2!N;W)M86QL>2!N965D('1H:7,@
M86YD"B`@("`J("`@:6X@8V%S92!T:&4@8V]N<W1R=6-T;W(@9&]E<VYT(&YE
M960@=&\@9&\@86YY;6]R92!I(&%L<F5A9'D@:&%V92!I="!D;VYE(#HM*0H@
M("`@*@H@("`@*B`@($!V97)S:6]N("`@(#`R+S`Q+S`X"B`@("`J("`@0&%C
M8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+
M<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@
M("`@("!B;V]L96%N('1R=64@:68@;&]G9V5D26X*("`@("HO"B`@("!F=6YC
M=&EO;B!4<F5E7T]P=&EO;G-$0B@@)&1S;B`L("1O<'1I;VYS/6%R<F%Y*"D@
M*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^7V-O;FYE8W1$0B@@)&1S
M;B`I.PH@("`@("`@(&EF*"`A4$5!4CHZ:7-%<G)O<B@D<F5S*2`I"B`@("`@
M("`@>PH@("`@("`@("`@("`D=&AI<RT^9&)H+3YS971&971C:&UO9&4H1$)?
M1D540TA-3T1%7T%34T]#*3L*("`@("`@("!]"B`@("`@("`@96QS90H@("`@
M("`@('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^5')E95]/<'1I;VYS*"`D;W!T:6]N<R`I.R`@("`@("`@
M("`O+R!D;R!O<'1I;VYS(&%F=&5R=V%R9',@<VEN8V4@:70@;W9E<G)U;&5S
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O(&1A=&%B87-E(&)Y
M('5S:6YG('1H92!G:79E;B!$4TX@<W1R:6YG"B`@("`@*@H@("`@("H@0&%U
M=&AO<B`@8V]P:65D(&9R;VT@4$5!4CHZ075T:"P@36%R=&EN($IA;G-E;BP@
M<VQI9VAT;'D@;6]D:69I960*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H@0'!A<F%M("!S=')I;F<@1%-.('-T<FEN9PH@("`@("H@0')E='5R;B!M
M:7AE9"`@3V)J96-T(&]N(&5R<F]R+"!O=&AE<G=I<V4@8F]O;`H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8V]N;F5C=$1"*"`D9'-N("D*("`@('L*("`@("`@
M("`O+R!O;FQY(&EN8VQU9&4@=&AE(&1B(&EF(&]N92!R96%L;'D@=V%N=',@
M=&\@8V]N;F5C=`H@("`@("`@(')E<75I<F5?;VYC92@G1$(N<&AP)RD["@H@
M("`@("`@(&EF("AI<U]S=')I;F<H)&1S;BD@?'P@:7-?87)R87DH)&1S;BD@
M*0H@("`@("`@('L*("`@("`@("`@("`@+R\@<'5T('1H92!D<VX@<&%R86UE
M=&5R<R!I;B!A;B!A<G)A>0H@("`@("`@("`@("`O+R!$0B!W;W5L9"!B92!C
M;VYF=7-E9"!W:71H(&%N(&%D9&ET:6]N86P@55),+7%U97)I97,L(&QI:V4@
M/W1A8FQE/2XN+@H@("`@("`@("`@("`O+R!S;R!W92!D;R!I="!B969O<F4@
M8V]N;F5C=&EN9R!T;R!T:&4@1$(*("`@("`@("`@("`@:68H(&ES7W-T<FEN
M9R@D9'-N*2`I"B`@("`@("`@("`@("`@("`D9'-N(#T@1$(Z.G!A<G-E1%-.
M*"`D9'-N("D["@H@("`@("`@("`@("`D=&AI<RT^9&)H(#T@1$(Z.D-O;FYE
M8W0H)&1S;BD["B`@("`@("`@?0H@("`@("`@(&5L<V4*("`@("`@("!["B`@
M("`@("`@("`@(&EF*&=E=%]P87)E;G1?8VQA<W,H)&1S;BD@/3T@(F1B7V-O
M;6UO;B(I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1T:&ES+3YD
M8F@@/2`D9'-N.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4*("`@
M("`@("`@("`@>PH@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D9'-N
M*2`F)B!$0CHZ:7-%<G)O<B@D9'-N*2D*("`@("`@("`@("`@("`@('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@;F5W($1"7T5R<F]R*"1D<VXM/F-O
M9&4L(%!%05)?15)23U)?1$E%*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<V4*("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@;F5W(%!%05)?17)R;W(H(E1H92!G:79E;B!D<VX@
M=V%S(&YO="!V86QI9"!I;B!F:6QE("(@+B!?7T9)3$5?7R`N("(@870@;&EN
M92`B("X@7U],24Y%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@-#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]%
M4E)/4E]215154DXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D=&AI<RT^9&)H*2D*("`@("`@("`@("`@<F5T=7)N(&YE
M=R!$0E]%<G)O<B@D=&AI<RT^9&)H+3YC;V1E+"!014%27T524D]27T1)12D[
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?2`O+R!E;F0@;V8@8VQA
M<W,*/SX````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O5')E
M92]-96UO<GDN<&AP````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`Q-#0W,C(`,3`T,3<S-C,P,#0`,#(P,C,P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O
M('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F
M:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(
M4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N
M;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO
M<G,Z(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("`D260Z($UE;6]R>2YP:'`L=B`Q+C(P(#(P,#,O,#(O
M,C8@,3@Z-#8Z,S$@8V%I;B!%>'`@)`H*<F5Q=6ER95]O;F-E("=4<F5E+T-O
M;6UO;BYP:'`G.PIR97%U:7)E7V]N8V4@)U1R964O17)R;W(N<&AP)SL*"B\J
M*@HJ("`@=&AI<R!C;&%S<R!C86X@8F4@=7-E9"!T;R!S=&5P('1H<F]U9V@@
M82!T<F5E('5S:6YG(%LG<&%R96YT)UTL(%LG8VAI;&0G72P@971C+@HJ("`@
M=&AE('1R964@:7,@<V%V960@87,@9FQA="!D871A(&EN(&$@9&(L('=H97)E
M(&%T(&QE87-T('1H92!P87)E;G0**B`@(&YE961S('1O(&)E(&=I=F5N(&EF
M(&$@<')E=FEO=7,@;65M8F5R(&ES(&=I=F5N('1O;R!T:&5N('1H92!O<F1E
M<@HJ("`@;VX@82!L979E;"!C86X@8F4@9&5T97)M:6YE9"!T;V\**B`@(&%C
M='5A;&QY('1H:7,@8VQA<W,@=V%S('5S960@9F]R(&$@;F%V:6=A=&EO;B!T
M<F5E"BH@("!N;W<@:70@:7,@97AT96YD960@=&\@<V5R=F4@86YY(&MI;F0@
M;V8@=')E90HJ("`@>6]U(&-A;B!U;F%M8FEG:6]U<VQY(')E9F5R('1O(&%N
M>2!E;&5M96YT(&)Y('5S:6YG('1H92!F;VQL;W=I;F<**B`@('-Y;G1A>`HJ
M("`@=')E92T^9&%T85MC=7)R96YT261=6SQW:&5R93Y=+BXN6SQW:&5R93Y=
M"BH@("`\=VAE<F4^(&-A;B!B92!E:71H97(@(G!A<F5N="(L(")C:&EL9"(L
M(")N97AT(B!O<B`B<')E=FEO=7,B+"!T:&ES('=A>0HJ("`@>6]U(&-A;B`B
M=V%L:R(@9G)O;2!A;GD@<&]I;G0@=&\@86YY(&]T:&5R('!O:6YT(&EN('1H
M92!T<F5E"BH@("!B>2!U<VEN9R`\=VAE<F4^(&EN(&%N>2!O<F1E<B!Y;W4@
M=V%N=`HJ("`@97AA;7!L92`H:6X@<&%R96YT:&5S97,@=&AE(&ED*3H**B`@
M(')O;W0**B`@("`K+2TM;&5V96P@,5\Q("@Q*0HJ("`@('P@("`@("`K+2TM
M+6QE=F5L(#)?,2`H,BD**B`@("!\("`@("`@*RTM+2UL979E;"`R7S(@*#,I
M"BH@("`@?"`@("`@("`@("`@("`@*RTM+2TM;&5V96P@,U\Q("@T*0HJ("`@
M("LM+2UL979E;"`Q7S(@*#4I"BH**B`@("!T:&4@9&%T86)A<V4@=&%B;&4@
M=&\@=&AI<R!S=')U8W1U<F4@*'=I=&AO=70@9&5F:6YE9"!O<F1E<BD**B`@
M("!I9"`@("`@<&%R96YT260@("`@("`@(&YA;64**B`@("`Q("`@("`@("`@
M,"`@("`@("`@(&QE=F5L(#%?,0HJ("`@(#(@("`@("`@("`Q("`@("`@("`@
M;&5V96P@,E\Q"BH@("`@,R`@("`@("`@(#$@("`@("`@("!L979E;"`R7S$*
M*B`@("`T("`@("`@("`@,R`@("`@("`@(&QE=F5L(#-?,0HJ("`@(#4@("`@
M("`@("`P("`@("`@("`@;&5V96P@,5\R"BH**B`@(&YO=R!Y;W4@8V%N(')E
M9F5R('1O(&5L96UE;G1S(&9O<B!E>&%M<&QE(&QI:V4@=&AI<R`H86QL(&5X
M86UP;&5S(&%S<W5M92!Y;W4@:VYO=R!T:&4@<W1R=6-T=7)E*3H**B`@('1O
M(&=O(&9R;VT@(FQE=F5L(#-?,2(@=&\@(FQE=F5L(#%?,2(Z("1T<F5E+3YD
M871A6S1=6R=P87)E;G0G75LG<&%R96YT)UT**B`@('1O(&=O(&9R;VT@(FQE
M=F5L(#-?,2(@=&\@(FQE=F5L(#%?,B(Z("1T<F5E+3YD871A6S1=6R=P87)E
M;G0G75LG<&%R96YT)UU;)VYE>'0G70HJ("`@=&\@9V\@9G)O;2`B;&5V96P@
M,E\Q(B!T;R`B;&5V96P@,U\Q(CH@)'1R964M/F1A=&%;,EU;)VYE>'0G75LG
M8VAI;&0G70HJ("`@=&\@9V\@9G)O;2`B;&5V96P@,E\R(B!T;R`B;&5V96P@
M,E\Q(CH@)'1R964M/F1A=&%;,UU;)W!R979I;W5S)UT**B`@('1O(&=O(&9R
M;VT@(FQE=F5L(#%?,B(@=&\@(FQE=F5L(#-?,2(Z("1T<F5E+3YD871A6S5=
M6R=P<F5V:6]U<R==6R=C:&EL9"==6R=N97AT)UU;)V-H:6QD)UT**@H*;VX@
M82!P96YT:75M(#$N.2!'2'H@-3$R($U"(%)!32P@3&EN=7@@,BXT+"!!<&%C
M:&4@,2XS+C$Y+"!02%`@-"XP+C8*<&5R9F]R;6%N8V4@<W1A=&ES=&EC<R!F
M;W(@=F5R<VEO;B`Q+C(V+"!U<VEN9R!E>&%M<&QE<R]4<F5E+U1R964N<&AP
M"B`@("!R96%D:6YG(&9R;VT@1$(@86YD('!R97!A<FEN9R!T;V]K.B`P+C$T
M.34X.#DT,C4R-S<W"B`@("!B=6EL9&EN9R!T;V]K.B`P+C`W-#0X.#`T,S<X
M-3`Y-0H@("`@8G5I;&13=')U8W1U<F4@=&]O:SH@,"XP-3$U,3DP,S8R.3,P
M,PH@("`@<V5T=&EN9R!U<"!T:&4@=')E92!T:6UE.B`P+C(Y-3<Y,CDS-S(W
M.#<U"B`@("!N=6UB97(@;V8@96QE;65N=',Z(#$U-C0*("`@(&1E97!E<W0@
M;&5V96PZ(#$W"G-O('EO=2!C86X@=7-E(&ET(&9O<B!T:6YY+6)I9R!T<F5E
M<R!T;V\@.BTI"F)U="!W871C:"!T:&4@9&(@=')A9F9I8RP@=VAI8V@@;6EG
M:'0@8F4@8V]N<VED97)A8FQE+"!D97!E;F1I;F<@;VX@>6]U<B!S971U<`H*
M1DE86%A-12!T:&5R92!I<R!O;F4@<F5A;&QY(&)A9"!T:&EN9R!A8F]U="!T
M:&4@96YT:7)E(&-L87-S+"!A="!S;VUE('!O:6YT<R!T:&5R92!A<F4@<F5F
M97)E;F-E<R!T;PHD=&AI<RT^9&%T82!R971U<FYE9"P@;W(@=&AE('!R;V=R
M86UM97(@8V%N(&5V96X@86-C97-S('1H:7,M/F1A=&$L('=H:6-H(&UE86YS
M(&AE(&-A;B!C:&%N9V4@=&AE"G-T<G5C='5R92P@<VEN8V4@=&AI<RT^9&%T
M82!C86X@;F]T(&)E('-E="!T;R!R96%D+6]N;'DL('1H97)E9F]R92!T:&ES
M+3YD871A(&AA<R!T;R!B92!H86YD;&5D('=I=&@@9W)E870@8V%R90HA(2$@
M;F5V97(@9&\@<V]M971H:6YG(&QI:V4@=&AI<SH@)'@@/2`F)'1R964M/F1A
M=&%;/'-O;64M:60^73L@)'@@/2`D>3L@=&AI<R!O=F5R=W)I=&5S('1H92!E
M;&5M96YT(&EN('1H92!S=')U8W1U<F4@(2$A"@HJ"BH**B`@($!A8V-E<W,@
M("!P=6)L:6,**B`@($!A=71H;W(@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF
M<F%M0&MR:65S:6YG+F1E/@HJ("`@0'9E<G-I;VX@(#(P,#$O,#8O,C<**B`@
M($!P86-K86=E("!4<F5E"BHO"F-L87-S(%1R965?365M;W)Y(&5X=&5N9',@
M5')E95]#;VUM;VX*>PH@("`@+RHJ"B`@("`J("`@=&AI<R!A<G)A>2!C;VYT
M86EN<R!T:&4@<'5R92!D871A(&9R;VT@=&AE($1""B`@("`J("`@=VAI8V@@
M87)E(&%L=V%Y<R!K97!T+"!S:6YC92!A;&P@;W1H97(@<W1R=6-T=7)E<R!W
M:6QL"B`@("`J("`@;VYL>2!M86ME(')E9F5R96YC97,@;VX@86YY(&5L96UE
M;G0*("`@("H@("!A;F0@=&AO<V4@9&%T82!A<F4@97AT96YD960@8GD@=&AE
M(&5L96UE;G1S("=P87)E;G0G("=C:&EL9')E;B<@971C+BXN"B`@("`J("`@
M0'9A<B`@("!A<G)A>2`D9&%T80H@("`@*B\*("`@('9A<B`D9&%T82`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`J("`@=&AI<R!A<G)A>2!C;VYT86EN<R!R
M969E<F5N8V5S('1O('1H:7,M/F1A=&$@8G5T(&ET"B`@("`J("`@861D:71I
M;VYA;&QY(')E<')E<V5N=',@=&AE(&1I<F5C=&]R>2!S=')U8W1U<F4*("`@
M("H@("!T:&%T(&UE86YS('1H92!A<G)A>2!H87,@87,@;6%N>2!D:6UE;G-I
M;VYS(&%S('1H90H@("`@*B`@('1R964@<W1R=6-T=7)E(&AA<R!L979E;',*
M("`@("H@("!B=70@=&AI<R!A<G)A>2!I<R!O;FQY('5S960@:6YT97)N86QL
M>2!F<F]M(&]U='-I9&4@>6]U(&-A;B!D;R!E=F5R>71H:6YG('5S:6YG"B`@
M("`J("`@=&AE(&YO9&4M:60G<PH@("`@*@H@("`@*B`@($!V87(@("`@87)R
M87D@)'-T<G5C='5R90H@("`@*B`@($!A8V-E<W,@<')I=F%T90H@("`@*B\*
M("`@('9A<B`D<W1R=6-T=7)E(#T@87)R87DH*3L*"B`@("`O*BH*("`@("H@
M("!I="!C;VYT86EN<R!A;&P@=&AE('!A<F5N=',@86YD('1H96ER(&-H:6QD
M<F5N+"!W:&5R92!T:&4@<&%R96YT260@:7,@=&AE"B`@("`J("`@:V5Y(&%N
M9"!A;&P@=&AE(&-H:6QD<F5N(&%R92!T:&4@=F%L=65S+"!T:&ES(&ES(&9O
M<B!S<&5E9&EN9R!U<"!T:&4@=')E92UB=6EL9&EN9R!P<F]C97-S"B`@("`J
M"B`@("`J("`@0'9A<B`@("!A<G)A>2`@("1C:&EL9')E;@H@("`@*B\*("`@
M('9A<B`D8VAI;&1R96X@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@*B`@($!A
M8V-E<W,@<')I=F%T90H@("`@*B`@($!V87(@("`@8F]O;&5A;B!S879E<R!I
M9B!T<F5E(&YO9&5S('-H86QL(&)E(')E;6]V960@<F5C=7)S:79E;'D*("`@
M("H@("!`<V5E("`@('-E=%)E;6]V95)E8W5R<VEV96QY*"D*("`@("HO"B`@
M("!V87(@)')E;6]V95)E8W5R<VEV96QY(#T@9F%L<V4["@H*("`@("\J*@H@
M("`@*B`@($!A8V-E<W,@<'5B;&EC"B`@("`J("`@0'9A<B`@("!I;G1E9V5R
M("1D96)U9R`@=&AE(&1E8G5G(&UO9&4L(&EF(#X@,"!T:&5N(&1E8G5G(&EN
M9F\@87)E('-H;W=N+`H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%C='5A;&QY('1H;W-E(&UE<W-A9V5S(&]N;'D@<VAO=R!P97)F;W)M86YC
M92!T:6UE<PH@("`@*B\*("`@('9A<B`D9&5B=6<@/2`P.PH*("`@("\J*@H@
M("`@*B`@($!S964@("`@)F=E=$YO9&4H*0H@("`@*B`@($!S964@("`@)E]G
M971.;V1E*"D*("`@("H@("!`86-C97-S('!R:79A=&4*("`@("H@("!`=F%R
M("`@(&EN=&5G97(@)%]G971.;V1E36%X3&5V96P@("!V87)I86)L92!O;FQY
M('5S960@:6X@=&AE(&UE=&AO9"!G971.;V1E(&%N9"!?9V5T3F]D90H@("`@
M*B\*("`@('9A<B`D7V=E=$YO9&5-87A,979E;#L*"B`@("`O*BH*("`@("H@
M("!`<V5E("`@("9G971.;V1E*"D*("`@("H@("!`<V5E("`@("9?9V5T3F]D
M92@I"B`@("`J("`@0&%C8V5S<R!P<FEV871E"B`@("`J("`@0'9A<B`@("!I
M;G1E9V5R("1?9V5T3F]D94-U<E!A<F5N="`@=F%R:6%B;&4@;VYL>2!U<V5D
M(&EN('1H92!M971H;V0@9V5T3F]D92!A;F0@7V=E=$YO9&4*("`@("HO"B`@
M("!V87(@)%]G971.;V1E0W5R4&%R96YT.PH*("`@("\J*@H@("`@*B`@('1H
M92!M87AI;75M(&1E<'1H(&]F('1H92!T<F5E"B`@("`J("`@0&%C8V5S<R!P
M<FEV871E"B`@("`J("`@0'9A<B`@("!I;G0@("`@('1H92!M87AI;75M(&1E
M<'1H(&]F('1H92!T<F5E"B`@("`J+PH@("`@=F%R("1?=')E941E<'1H(#T@
M,#L*("`@(`H@("`@+RHJ"B`@("`J("`@<V5T('5P('1H:7,@;V)J96-T"B`@
M("`J"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,2\P-B\R-PH@("`@*B`@($!A
M8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@
M2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M
M("`@("`@;6EX960@("`D9'-N("`@("`@("!T:&ES(&ES(&$@1%-.(&9O<B!T
M:&4@4$5!4CHZ1$(L(&-A;B!B92!E:71H97(@86X@;V)J96-T+W-T<FEN9PH@
M("`@*B`@($!P87)A;2`@("`@(&%R<F%Y("`@)&]P=&EO;G,@("`@861D:71I
M;VYA;"!O<'1I;VYS('EO=2!C86X@<V5T"B`@("`J+PH@("`@9G5N8W1I;VX@
M5')E95]-96UO<GDH("1T>7!E("P@)&1S;CTG)R`L("1O<'1I;VYS/6%R<F%Y
M*"D@*0H@("`@>PH@("`@("`@("1T:&ES+3Y4<F5E7T]P=&EO;G,H)&]P=&EO
M;G,I.R`O+R!S970@=&AE(&]P=&EO;G,@9F]R("1T:&ES"@H@("`@("`@(')E
M<75I<F5?;VYC92@B5')E92]-96UO<GDO)'1Y<&4N<&AP(BD["@H@("`@("`@
M("1C;&%S<TYA;64@/2`G5')E95]-96UO<GE?)RXD='EP93L*("`@("`@("`D
M=&AI<RT^9&%T85-O=7)C94-L87-S(#TF(&YE=R`D8VQA<W-.86UE*"`D9'-N
M("P@)&]P=&EO;G,@*3L*("`@("`@("`O+R!C;W!Y('1H92!O<'1I;VYS('1O
M(&)E(&%B;&4@=&\@9V5T('1H96T@=FEA(&=E=$]P=&EO;BAS*0HO+T9)6%A-
M12!T:&ES(&ES(&YO="!R96%L;'D@8V]O;"P@;6%Y8F4@;W9E<G=R:71E('1H
M92`J3W!T:6]N*B!M971H;V1S(2$A"B`@("`@("`@:68H(&ES<V5T*"1T:&ES
M+3YD871A4V]U<F-E0VQA<W,M/F]P=&EO;G,I("D*("`@("`@("`@("`@)'1H
M:7,M/F]P=&EO;G,@/2`D=&AI<RT^9&%T85-O=7)C94-L87-S+3YO<'1I;VYS
M.PH*("`@('T@+R\@96YD(&]F(&9U;F-T:6]N"@H@("`@+RHJ"B`@("`J("`@
M=7-E('1H:7,@=&\@<W=I=&-H(&1A=&$@<V]U<F-E<R!O;B!T:&4@<G5N"B`@
M("`J("`@:2YE+B!I9B!Y;W4@87)E(')E861I;F<@=&AE(&1A=&$@9G)O;2!A
M(&1B+71R964@86YD('=A;G0@=&\@<V%V92!I=`H@("`@*B`@(&%S('AM;"!D
M871A("AW:&EC:"!W:6QL('=O<FL@;VYE(&1A>2!T;V\I"B`@("`J("`@;W(@
M<F5A9&EN9R!T:&4@9&%T82!F<F]M(&%N('AM;"!F:6QE(&%N9"!W<FET:6YG
M(&ET(&EN('1H92!D8@H@("`@*B`@('=H:6-H('-H;W5L9"!A;')E861Y('=O
M<FL*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`Q+S$W"B`@("`J
M("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L
M9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`
M<&%R86T@("`@("!S=')I;F<@("1D<VX@("`@=&AI<R!I<R!A($133B!O9B!T
M:&4@9F]R('1H870@4$5!4CHZ1$(@=7-E<R!I=`H@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!O;FQY('1H870@861D:71I;VYA;&QY('EO
M=2!C86X@861D('!A<F%M971E<G,@;&EK92`N+BX_=&%B;&4]=&5S=%]T86)L
M90H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!D969I
M;F4@=&AE('1A8FQE(&ET('-H86QL('=O<FL@;VX*("`@("H@("!`<&%R86T@
M("`@("!A<G)A>2`@("1O<'1I;VYS("!A9&1I=&EO;F%L(&]P=&EO;G,@>6]U
M(&-A;B!S970*("`@("H@("!`<F5T=7)N("`@("!B;V]L96%N("`@("!T<G5E
M(&]N('-U8V-E<W,*("`@("HO"B`@("!F=6YC=&EO;B!S=VET8VA$871A4V]U
M<F-E*"`D='EP92`L("1D<VX])R<@+"`D;W!T:6]N<SUA<G)A>2@I("D*("`@
M('L*("`@("`@("`D9&%T82`]("1T:&ES+3YG971.;V1E*"D["B`@("`@("`@
M+R\D=&AI<RT^5')E92@@)&1S;B`L("1O<'1I;VYS("D["B`@("`@("`@)'1H
M:7,M/E1R965?365M;W)Y*"`D='EP92`L("1'3$]"04Q36R=D=6UM>2==("P@
M)&]P=&EO;G,@*3L*"B`@("`@("`@+R\@=&AI<R!M971H;V0@<')E<&%R97,@
M9&%T82!R971R96EV960@=7-I;F<@9V5T3F]D92!T;R!B92!U<V5D"B`@("`@
M("`@+R\@:6X@=&AI<R!T>7!E(&]F('1R964*("`@("`@("`D=&AI<RT^9&%T
M85-O=7)C94-L87-S+3YS971$871A*"1D871A*3L*("`@("`@("`D=&AI<RT^
M<V5T=7`H*3L*("`@('T*"B`@("`O*BH*("`@("H*("`@("H*("`@("H@("!`
M=F5R<VEO;B`@("`R,#`R+S`Q+S$Y"B`@("`J("`@0&%C8V5S<R`@("`@<'5B
M;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L
M9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<F5T=7)N"B`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T=7!">5)A=T1A=&$H("1S=')I;F<@*0H@("`@>PHO+R`@
M97AP96-T<PHO+R`@(&9O<B!834P@86X@6$U,+5-T<FEN9RP*+R\@("!F;W(@
M1$(M82!R97-U;'0@<V5T+"!M87D@8F4@;W(@86X@87)R87DL(&1O;G0@:VYO
M=R!H97)E("T@;F]T(&EM<&QE;65N=&5D('EE=`H@("`@("`@("1R97,@/2`D
M=&AI<RT^9&%T85-O=7)C94-L87-S+3YS971U<$)Y4F%W1&%T82@@)'-T<FEN
M9R`I.PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-E='5P*"`D<F5S("D["B`@
M("!]"@H@("`@+RHJ"B`@("`J"B`@("`J"B`@("`J("`@0'9E<G-I;VX@("`@
M,C`P,B\P,2\Q.0H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@
M($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I
M;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@87)R87D@("!T:&4@<F5S=6QT
M(&]F(&$@<75E<GD@=VAI8V@@<F5T<F5I=F5S("AA;&PI('1H92!T<F5E(&1A
M=&$@9G)O;2!A('-O=7)C90H@("`@*B`@($!R971U<FX@("`@('1R=64@;W(@
M5')E95]%<G)O<@H@("`@*B\*("`@(&9U;F-T:6]N('-E='5P*"1D871A/6YU
M;&PI"B`@("!["B`@("`@("`@:68H("1T:&ES+3YD96)U9R`I"B`@("`@("`@
M>PH@("`@("`@("`@("`D<W1A<G14:6UE(#T@<W!L:70H(B`B+&UI8W)O=&EM
M92@I*3L*("`@("`@("`@("`@)'-T87)T5&EM92`]("1S=&%R=%1I;65;,5TK
M)'-T87)T5&EM95LP73L*("`@("`@("!]"@H@("`@("`@(&EF*%!%05(Z.FES
M17)R;W(H)')E<R`]("1T:&ES+3YD871A4V]U<F-E0VQA<W,M/G-E='5P*"1D
M871A*2D@*0H@("`@("`@("`@("!R971U<FX@)')E<SL*"B`@("`@("`@:68H
M("1T:&ES+3YD96)U9R`I"B`@("`@("`@>PH@("`@("`@("`@("`D96YD5&EM
M92`]('-P;&ET*"(@(BQM:6-R;W1I;64H*2D["B`@("`@("`@("`@("1E;F14
M:6UE(#T@)&5N9%1I;65;,5TK)&5N9%1I;65;,%T["B`@("`@("`@("`@('!R
M:6YT*"`B(')E861I;F<@86YD('!R97!A<FEN9R!T<F5E(&1A=&$@=&]O:SH@
M(BXH)&5N9%1I;64@+2`D<W1A<G14:6UE*2XB(#QB<CXB("D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]S971U<"@@)')E<R`I.PH*("`@
M('T*"B`@("`O*BH*("`@("H@("!R971R96EV92!A;&P@=&AE(&YA=FEG871I
M;VX@9&%T82!F<F]M('1H92!D8B!A;F0@8G5I;&0@=&AE"B`@("`J("`@=')E
M92!I;B!T:&4@87)R87D@9&%T82!A;F0@<W1R=6-T=7)E"B`@("`J"B`@("`J
M("`@0'9E<G-I;VX@("`@,C`P,2\Q,2\R,`H@("`@*B`@($!A8V-E<W,@("`@
M('!R:79A=&4*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG
M(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!R971U<FX@("`@(&)O
M;VQE86X@("`@('1R=64@;VX@<W5C8V5S<PH@("`@*B\*("`@(&9U;F-T:6]N
M(%]S971U<"@@)'-E='5P1&%T82`I"B`@("!["B\O(%1/1$\@<V]R="!B>2!P
M<F5V260@*'!A<F5N=$ED+'!R979)9"`D861D475E<GDI('1O;R!I9B!I="!E
M>&ES=',@:6X@=&AE('1A8FQE+"!O<B!T:&4@<F]O="!M:6=H="!B92!W<F]N
M9PHO+R!43T1/("!S:6YC92!T:&4@<')E=DED(&]F('1H92!R;V]T('-H;W5L
M9"!B92`P"B`@("`@("`@:68H("$D<V5T=7!$871A("D*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH*+R]&25A86%A8344@=F%L:61A=&4@=&AE('-T<G5C
M='5R92X@:2YE+B!A('!R;V)L96T@;V-C=7)S+"!I9B!Y;W4@9VEV92!O;F4@
M;F]D92P@=VAI8V@@:&%S(&$@<&%R96YT260],2!I="!S8W)E=W,@=7`@979E
M<GET:&EN9R$A(0H@("`@("`@("\O(&5M<'1Y('1H92!D871A('-T<G5C='5R
M97,L('-I;F-E('=E(&%R92!R96%D:6YG('1H92!D871A(&9R;VT@=&AE(&1B
M("AA9V%I;BD*("`@("`@("`D=&AI<RT^<W1R=6-T=7)E(#T@87)R87DH*3L*
M("`@("`@("`D=&AI<RT^9&%T82`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M
M/F-H:6QD<F5N(#T@87)R87DH*3L*("`@("`@("`O+R!B=6EL9"!A;B!A<G)A
M>2!W:&5R92!A;&P@=&AE('!A<F5N=',@:&%V92!T:&5I<B!C:&EL9')E;B!A
M<R!A(&UE;6)E<@H@("`@("`@("\O('1H:7,@:2!D;R!T;R!S<&5E9"!U<"!T
M:&4@8G5I;&13=')U8W1U<F4*("`@("`@("!F;W)E86-H*"`D<V5T=7!$871A
M(&%S("1V86QU97,@*0H@("`@("`@('L*("`@("`@("`@("`@:68H(&ES7V%R
M<F%Y*"1V86QU97,I("D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/F1A=&%;)'9A;'5E<ULG:60G75T@/2`D=F%L=65S.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F-H:6QD<F5N6R`D=F%L=65S6R=P87)E;G1)9"==
M(%U;72`]("1V86QU97-;)VED)UT["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O('=A;&L@=&AR;W5G:"!A;&P@=&AE(&-H:6QD<F5N(&]N
M(&5A8V@@;&5V96P@86YD('-E="!T:&4@;F5X="]P<F5V:6]U<R!R96QA=&EO
M;G,*("`@("`@("`O+R!O9B!T:&]S92!C:&EL9')E;BP@<VEN8V4@86QL(&-H
M:6QD<F5N(&9O<B`B8VAI;&1R96Y;)&ED72(@87)E(&]N('1H92!S86UE(&QE
M=F5L('=E(&-A;B!D;PH@("`@("`@("\O('1H:7,@:&5R92`Z+2D*("`@("`@
M("!F;W)E86-H*"`D=&AI<RT^8VAI;&1R96X@87,@)&-H:6QD<F5N("D*("`@
M("`@("!["B`@("`@("`@("`@("1L87-T4')E=DED(#T@,#L*("`@("`@("`@
M("`@:68H<VEZ96]F*"1C:&EL9')E;BDI"B`@("`@("`@("`@(&9O<F5A8V@H
M("1C:&EL9')E;B!A<R`D:V5Y("D*("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@:68H("1L87-T4')E=DED("D*("`@("`@("`@("`@("`@('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LD;&%S=%!R979)9%U;)VYE
M>'1)9"==(#T@)&ME>3L@("\O(')E;65M8F5R('1H92!N97AT260@=&]O+"!S
M;R!T:&4@8G5I;&0@<')O8V5S<R!C86X@8F4@<W!E9"!U<`H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YD871A6R1L87-T4')E=DED75LG;F5X="==(#T@
M("`F)'1H:7,M/F1A=&%;)&ME>5T["@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YD871A6R1K97E=6R=P<F5V260G72`]("1L87-T4')E=DED.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1K97E=6R=P<F5V:6]U<R==
M(#T@)B1T:&ES+3YD871A6R`D;&%S=%!R979)9"!=.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&QA<W10<F5V260@/2`D:V5Y.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*+R]P<FEN=%]R*"1T:&ES+3YC:&EL9')E
M;BD["@H@("`@("`@(&EF*"`D=&AI<RT^9&5B=6<@*0H@("`@("`@('L*("`@
M("`@("`@("`@)'-T87)T5&EM92`]('-P;&ET*"(@(BQM:6-R;W1I;64H*2D[
M"B`@("`@("`@("`@("1S=&%R=%1I;64@/2`D<W1A<G14:6UE6S%=*R1S=&%R
M=%1I;65;,%T["B`@("`@("`@?0H*("`@("`@("`O+R!W:&5N($Y/('!R979)
M9"!I<R!G:79E;BP@<V]R="!T:&4@96YT<FEE<R!I;B!E86-H(&QE=F5L(&)Y
M('1H92!G:79E;B!S;W)T(&]R9&5R("AT;R!B92!D969I;F5D*0H@("`@("`@
M("\O(&%N9"!S970@=&AE('!R979)9"!S;R!T:&4@8G5I;&0@8V%N('=O<FL@
M<')O<&5R;'D*("`@("`@("!I9B@@(6ES<V5T*"1S971U<$1A=&%;,%U;)W!R
M979)9"==*2`I("`@+R\@9&]E<R!A('!R979)9"!E>&ES=#\*("`@("`@("![
M"B`@("`@("`@("`@("1L87-T4')E=DED(#T@,#L*("`@("`@("`@("`@)&QA
M<W1087)E;G1)9"`](#`["B`@("`@("`@("`@("1L979E;"`](#`["B`@("`@
M("`@("`@("\O(&)U:6QD('1H92!E;G1I<F4@<F5C=7)S:79E(')E;&%T:6]N
M<RP@<V\@>6]U(&AA=F4@)W!A<F5N=$ED)RP@)V-H:6QD260G+"`G;F5X=$ED
M)RP@)W!R979)9"<*("`@("`@("`@("`@+R\@86YD('1H92!R969E<F5N8V5S
M("=C:&EL9"<L("=P87)E;G0G+"`G;F5X="<L("=P<F5V:6]U<R<@<V5T(&EN
M('1H92!P<F]P97)T>2`G9&%T82<*("`@("`@("`@("`@9F]R96%C:"@@)'1H
M:7,M/F1A=&$@87,@)&ME>3T^)'9A;'5E("D*("`@("`@("`@("`@>PH@("`@
M("`@("`@("`@("`@+R\@;6]S="!I9B!C:&5C:W,@:6X@=&AI<R!F;W)E86-H
M(&%R92!F;W(@=&AE(&9O;&QO=VEN9R!R96%S;VXL(&EF(&YO="!S=&%T960@
M;W1H97)W:7-E.@H@("`@("`@("`@("`@("`@+R\@9&]N="!M86ME(&%N(&1A
M=&%;)R==(&]R(&1A=&%;,%T@<VEN8V4@=&AI<R!W87,@;F]T(')E860@9G)O
M;2!T:&4@1$(L(&)E8V%U<V4@:60@:7,@875T;VEN8W)E;65N="!A;F0@<W1A
M<G1S(&%T(#$*("`@("`@("`@("`@("`@("\O(&%N9"!A;'-O(&EN(&%N('AM
M;"!T<F5E('1H97)E(&-A;B!N;W0@8F4@86X@96QE;65N="`\+SX@+"!I(&AO
M<&4@.BTI"B`@("`@("`@("`@("`@("!I9B@@)'9A;'5E6R=P87)E;G1)9"==
M("D@("`@("`@("`@("`O+R!S964@8V]M;65N="!A8F]V90H@("`@("`@("`@
M("`@("`@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1K97E=
M6R=P87)E;G0G72`@("`]("8D=&AI<RT^9&%T85L@)'9A;'5E6R=P87)E;G1)
M9"==(%T["B`@("`@("`@("`@("`@("`@("`@+R\@=&AE('!A<F5N="!H87,@
M86X@97AT<F$@87)R87D@=VAI8V@@8V]N=&%I;G,@82!R969E<F5N8V4@=&\@
M86QL(&ET)W,@8VAI;&1R96XL('-E="!I="!H97)E"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F1A=&%;("1V86QU95LG<&%R96YT260G72!=6R=C:&EL
M9')E;B==6UT@/2`F)'1H:7,M/F1A=&%;)&ME>5T["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@+R\@=V%S(&$@8VAI;&0@<V%V960@*&EN
M('1H92!A8F]V92`G:68G*0H@("`@("`@("`@("`@("`@:68H(&ES<V5T*"1T
M:&ES+3YC:&EL9')E;ELD:V5Y72D@)B8@<VEZ96]F*"`D=&AI<RT^8VAI;&1R
M96Y;)&ME>5T@*2`I("\O('-E92!C;VUM96YT(&%B;W9E"B`@("`@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("`@("`@+R\@<F5F97(@=&\@=&AE(&9I
M<G-T(&-H:6QD(&EN('1H92!;8VAI;&1=(&%N9"!;8VAI;&1)9%T@:V5Y<PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1K97E=6R=C:&EL9$ED
M)UT@/2`D=&AI<RT^8VAI;&1R96Y;)&ME>5U;,%T["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F1A=&%;)&ME>5U;)V-H:6QD)UT@/2`@("8D=&AI<RT^
M9&%T85L@)'1H:7,M/F-H:6QD<F5N6R1K97E=6S!=(%T["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@)&QA<W1087)E;G1)9"`]("1V86QU
M95LG<&%R96YT260G73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68H("1T:&ES+3YD96)U9R`I"B`@("`@("`@>PH@("`@("`@("`@("`D
M96YD5&EM92`]('-P;&ET*"(@(BQM:6-R;W1I;64H*2D["B`@("`@("`@("`@
M("1E;F14:6UE(#T@)&5N9%1I;65;,5TK)&5N9%1I;65;,%T["B`@("`@("`@
M("`@('!R:6YT*"`B(&)U:6QD:6YG('1O;VLZ("(N*"1E;F14:6UE("T@)'-T
M87)T5&EM92DN(B`\8G(^(B`I.PH@("`@("`@('T*"B`@("`@("`@+R\@8G5I
M;&0@=&AE('!R;W!E<G1Y("=S=')U8W1U<F4G"B`@("`@("`@)'1H:7,M/G-T
M<G5C='5R92`](&%R<F%Y*"D[("\O(&5M<'1Y(&ET+"!J=7-T('1O(&)E('-U
M<F4@979E<GET:&EN9R!W:6QL(&)E('-E="!P<F]P97)L>0H*("`@("`@("!I
M9B@@)'1H:7,M/F1E8G5G("D*("`@("`@("!["B`@("`@("`@("`@("1S=&%R
M=%1I;64@/2!S<&QI="@B("(L;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("`D
M<W1A<G14:6UE(#T@)'-T87)T5&EM95LQ72LD<W1A<G14:6UE6S!=.PH@("`@
M("`@('T*"B`@("`@("`@+R\@8G5I;&0@86QL('1H92!C:&EL9')E;B!T:&%T
M(&%R92!O;B!T:&4@<F]O="!L979E;"P@:68@=V4@=V]U;&1N="!D;R!T:&%T
M"B`@("`@("`@+R\@=V4@=V]U;&0@:&%V92!T;R!C<F5A=&4@82!R;V]T(&5L
M96UE;G0@=VET:"!A;B!I9"`P+"!B=70@<VEN8V4@=&AI<R!I<R!N;W0*("`@
M("`@("`O+R!R96%D(&9R;VT@=&AE(&1B('=E(&1O;G0@861D(&%N;W1H97(@
M96QE;65N="P@=&AE('5S97(@=V%N=',@=&\@9V5T('=H870@:&4@:&%D('-A
M=F5D"B`@("`@("`@:68H('-I>F5O9B@D=&AI<RT^8VAI;&1R96Y;,%TI("D*
M("`@("`@("!F;W)E86-H*"`D=&AI<RT^8VAI;&1R96Y;,%T@87,@)')O;W1%
M;&5M96YT("D*("`@("`@("!["B`@("`@("`@("`@("1T:&ES+3YB=6EL9%-T
M<G5C='5R92@@)')O;W1%;&5M96YT("P@)'1H:7,M/G-T<G5C='5R92`I.PH@
M("`@("`@('T*"B`@("`@("`@:68H("1T:&ES+3YD96)U9R`I"B`@("`@("`@
M>PH@("`@("`@("`@("`D96YD5&EM92`]('-P;&ET*"(@(BQM:6-R;W1I;64H
M*2D["B`@("`@("`@("`@("1E;F14:6UE(#T@)&5N9%1I;65;,5TK)&5N9%1I
M;65;,%T["B`@("`@("`@("`@('!R:6YT*"`B(&)U:6QD4W1R=6-T=7)E('1O
M;VLZ("(N*"1E;F14:6UE("T@)'-T87)T5&EM92DN(B`\8G(^(B`I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`J("`@861D<R!?;VYE7R!N97<@96QE;65N="!I;B!T:&4@=')E92!U;F1E
M<B!T:&4@9VEV96X@<&%R96YT"B`@("`J("`@=&AE('9A;'5E<R<@:V5Y<R!G
M:79E;B!H879E('1O(&UA=&-H('1H92!D8BUC;VQU;6YS+"!B96-A=7-E('1H
M90H@("`@*B`@('9A;'5E(&=E=',@:6YS97)T960@:6X@=&AE(&1B(&1I<F5C
M=&QY"B`@("`J("`@=&\@861D(&%N(&5N=&ER92!N;V1E(&-O;G1A:6YI;F<@
M8VAI;&1R96X@86YD('-O(&]N('-E92`G861D3F]D92@I)PH@("`@*B`@($!S
M964@("`@("`@(&%D9$YO9&4H*0H@("`@*B`@($!V97)S:6]N("`@(#(P,#$O
M,3`O,#D*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T
M:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E
M/@H@("`@*B`@($!P87)A;2`@("`@(&%R<F%Y("1N97=686QU97,@=&AI<R!A
M<G)A>2!C;VYT86EN<R!T:&4@=F%L=65S('1H870@<VAA;&P@8F4@:6YS97)T
M960@:6X@=&AE(&1B+71A8FQE"B`@("`J("`@0'!A<F%M("`@("`@:6YT("`@
M("!T:&4@<&%R96YT(&ED"B`@("`J("`@0'!A<F%M("`@("`@:6YT("`@("!T
M:&4@<')E=DED"B`@("`J("`@0')E='5R;B`@("`@;6EX960@("!E:71H97(@
M8F]O;&5A;B!F86QS92!O;B!F86EL=7)E(&]R('1H92!I9"!O9B!T:&4@:6YS
M97)T960@<F]W"B`@("`J+PH@("`@9G5N8W1I;VX@861D*"`D;F5W5F%L=65S
M("P@)'!A<F5N=$ED/3`@+"`D<')E=DED/3`@*0H@("`@>PH@("`@("`@("\O
M('-E92!C;VUM96YT<R!I;B`G;6]V92<@86YD("=R96UO=F4G"@H@("`@("`@
M(&EF("AM971H;V1?97AI<W1S*"1T:&ES+3YD871A4V]U<F-E0VQA<W,L)V%D
M9"<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9&%T85-O=7)C94-L
M87-S+3YA9&0H("1N97=686QU97,@+"`D<&%R96YT260@+"`D<')E=DED("D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=&AR;W=%<G)O<B@@)VUE=&AO9"!N;W0@:6UP;&5M96YT960@>65T+B<@+"!?
M7TQ)3D5?7R`I.PH@("`@("`@('T*("`@('T@+R\@96YD(&]F(&9U;F-T:6]N
M"@H*("`@("\J*@H@("`@*B`@(')E;6]V97,@=&AE(&=I=F5N(&YO9&4@86YD
M(&%L;"!C:&EL9')E;B!I9B!R96UO=F5296-U<G-I=F5L>2!I<R!O;@H@("`@
M*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#$O,C0*("`@("H@("!`86-C
M97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR
M:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@
M("`@(&UI>&5D("`@)&ED("`@("!T:&4@:60@;V8@=&AE(&YO9&4@=&\@8F4@
M<F5M;W9E9`H@("`@*B`@($!R971U<FX@("`@(&)O;VQE86X@=')U92!O;B!S
M=6-C97-S"B`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E*"`D:60@*0H@("`@
M>PH@("`@("`@("\O(&EF(')E;6]V:6YG(')E8W5R<VEV96QY(&ES(&YO="!A
M;&QO=V5D+"!W:&EC:"!M96%N<R!E=F5R>2!C:&EL9"!S:&]U;&0@8F4@<F5M
M;W9E9`H@("`@("`@("\O('1H96X@8VAE8VL@:68@=&AI<R!E;&5M96YT(&AA
M<R!A(&-H:6QD(&%N9"!R971U<FX@(G-O<G)Y(&)A8GD@8V%N="!R96UO=F4@
M.BTI("(*("`@("`@("!I9B`H)'1H:7,M/G)E;6]V95)E8W5R<VEV96QY("$]
M('1R=64I('L*("`@("`@("`@("`@:68@*&ES<V5T*"`D=&AI<RT^9&%T85LD
M:61=6R=C:&EL9"==("DI('L*+R\@5$]$3R!R86ES92!014%2('=A<FYI;F<*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1H<F]W17)R;W(H(D5L
M96UE;G0@=VET:"!I9#TD:60@:&%S(&-H:6QD<F5N+"!C86YT(&)E(')E;6]V
M960N(%-E="`G<V5T4F5M;W9E4F5C=7)S:79E;'DG('1O('1R=64@=&\@86QL
M;W<@=&AI<RXB+%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@<V5E(&-O;6UE;G0@:6X@)VUO=F4G"B`@("`@("`@+R\@
M:68@=&AE('!R979)9"!I<R!I;B!U<V4@=V4@;F5E9"!T;R!U<&1A=&4@=&AE
M('!R979)9"!O9B!T:&4@96QE;65N="!A9G1E<B!T:&4@;VYE('1H870*("`@
M("`@("`O+R!I<R!R96UO=F5D('1O;RP@=&\@:&%V92!T:&4@<')E=DED(&]F
M('1H92!O;F4@=&AA="!I<R!R96UO=F5D(2$A"@H@("`@("`@(&EF("AM971H
M;V1?97AI<W1S*"1T:&ES+3YD871A4V]U<F-E0VQA<W,L)W)E;6]V92<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9&%T85-O=7)C94-L87-S+3YR
M96UO=F4H("1I9"`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W1H<F]W17)R;W(H("=M971H;V0@;F]T(&EM<&QE;65N
M=&5D('EE="XG("P@7U],24Y%7U\@*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`J("`@8V]L;&5C=',@=&AE($E$)W,@;V8@=&AE(&5L96UE;G1S
M('1O(&)E(')E;6]V960*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R,#`Q
M+S$P+S`Y"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U
M=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD
M93X*("`@("H@("!`<&%R86T@("`@("!M:7AE9"`@("1I9"`@('1H92!I9"!O
M9B!T:&4@;F]D92!T;R!B92!R96UO=F5D"B`@("`J("`@0')E='5R;B`@("`@
M8F]O;&5A;B!T<G5E(&]N('-U8V-E<W,*("`@("HO"B`@("!F=6YC=&EO;B!?
M<F5M;W9E*"`D96QE;65N="`I"B`@("!["B`@("`@("`@<F5T=7)N("1E;&5M
M96YT6R=I9"==.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*
M("`@("H@("!M;W9E(&%N(&5N=')Y('5N9&5R(&$@9VEV96X@<&%R96YT(&]R
M(&)E:&EN9"!A(&=I=F5N(&5N=')Y+@H@("`@*B`@("$A(2!T:&4@)VUO=F4@
M8F5H:6YD(&%N;W1H97(@96QE;65N="<@:7,@;VYL>2!I;7!L96UE;G1E9"!F
M;W(@;F5S=&5D('1R965S(&YO=R$A(0H@("`@*B`@($EF(&$@;F5W4')E=DED
M(&ES(&=I=F5N('1H92!N97=087)E;G1)9"!I<R!D:7-M:7-S960A"B`@("`J
M("`@8V%L;"!I="!E:71H97(@;&EK92!T:&ES.@H@("`@*B`@("`@("`D=')E
M92T^;6]V92@@>"`L('D@*0H@("`@*B`@("`@("!T;R!M;W9E('1H92!E;&5M
M96YT("AO<B!E;G1I<F4@=')E92D@=VET:"!T:&4@:60@>`H@("`@*B`@("`@
M("!U;F1E<B!T:&4@96QE;65N="!W:71H('1H92!I9"!Y"B`@("`J("`@;W(*
M("`@("H@("`@("`@)'1R964M/FUO=F4H('@@+"`P("P@>2`I.R`@("\O(&]M
M;6ET('1H92!S96-O;F0@<&%R86UE=&5R(&)Y('-E='1I;F<@:70@=&\@,`H@
M("`@*B`@("`@("!T;R!M;W9E('1H92!E;&5M96YT("AO<B!E;G1I<F4@=')E
M92D@=VET:"!T:&4@:60@>`H@("`@*B`@("`@("!B96AI;F0@=&AE(&5L96UE
M;G0@=VET:"!T:&4@:60@>0H@("`@*B`@(&]R"B`@("`J("`@("`@("1T<F5E
M+3YM;W9E*"!A<G)A>2AX,2QX,BQX,RD@+"`N+BX*("`@("H@("`@("`@=&AE
M(&9I<G-T('!A<F%M971E<B!C86X@86QS;R!B92!A;B!A<G)A>2!O9B!E;&5M
M96YT<R!T:&%T('-H86QL(&)E(&UO=F5D"B`@("`J("`@("`@('1H92!S96-O
M;F0@86YD('1H:7)D('!A<F$@8V%N(&)E(&%S(&1E<V-R:6)E9"!A8F]V90H@
M("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#8O,#@*("`@("H@("!`
M86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M
M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A
M;2`@("`@(&EN=&5G97(@("`@('1H92!I9"AS*2!O9B!T:&4@96QE;65N="AS
M*2!T:&%T('-H86QL(&)E(&UO=F5D"B`@("`J("`@0'!A<F%M("`@("`@:6YT
M96=E<B`@("`@=&AE(&ED(&]F('1H92!E;&5M96YT('=H:6-H('=I;&P@8F4@
M=&AE(&YE=R!P87)E;G0*("`@("H@("!`<&%R86T@("`@("!I;G1E9V5R("`@
M("!I9B!P<F5V260@:7,@9VEV96X@=&AE(&5L96UE;G0@=VET:"!T:&4@:60@
M:614;TUO=F4*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S:&%L
M;"!B92!M;W9E9"!?8F5H:6YD7R!T:&4@96QE;65N="!W:71H(&ED/7!R979)
M9`H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF(&ET(&ES(#`@
M:70@=VEL;"!B92!P=70@870@=&AE(&)E9VEN;FEN9PH@("`@*B`@($!R971U
M<FX@("`@(&)O;VQE86X@("`@('1R=64@9F]R('-U8V-E<W,*("`@("HO"B`@
M("!F=6YC=&EO;B!M;W9E*"`D:61S5&]-;W9E("P@)&YE=U!A<F5N=$ED("P@
M)&YE=U!R979)9#TP("D*("`@('L*("`@("`@("!S971T>7!E*"1I9'-4;TUO
M=F4L)V%R<F%Y)RD["B`@("`@("`@)&5R<F]R<R`](&%R<F%Y*"D["B`@("`@
M("`@9F]R96%C:"@@)&ED<U1O36]V92!A<R`D:614;TUO=F4@*0H@("`@("`@
M('L*("`@("`@("`@("`@)')E="`]("1T:&ES+3Y?;6]V92@@)&ED5&]-;W9E
M("P@)&YE=U!A<F5N=$ED("P@)&YE=U!R979)9"`I.PH@("`@("`@("`@("!I
M9B@@4$5!4CHZ:7-%<G)O<B@D<F5T*2`I"B`@("`@("`@("`@("`@("`D97)R
M;W)S6UT@/2`D<F5T.PH@("`@("`@('T*+R\@1DE86$U%(')E='5R;B!A(%1R
M965?17)R;W(L(&YO="!A;B!A<G)A>2`A(2$A(0H@("`@("`@(&EF*"!S:7IE
M;V8H)&5R<F]R<RD@*0H@("`@("`@("`@("!R971U<FX@)&5R<F]R<SL*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("H@("!T:&ES
M(&UE=&AO9"!M;W9E<R!O;F4@=')E92!E;&5M96YT"B`@("`J"B`@("`J("`@
M0'-E92`@("`@("`@;6]V92@I"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,2\Q
M,"\Q,`H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H
M;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^
M"B`@("`J("`@0'!A<F%M("`@("`@:6YT96=E<B`@("`@=&AE(&ED(&]F('1H
M92!E;&5M96YT('1H870@<VAA;&P@8F4@;6]V960*("`@("H@("!`<&%R86T@
M("`@("!I;G1E9V5R("`@("!T:&4@:60@;V8@=&AE(&5L96UE;G0@=VAI8V@@
M=VEL;"!B92!T:&4@;F5W('!A<F5N=`H@("`@*B`@($!P87)A;2`@("`@(&EN
M=&5G97(@("`@(&EF('!R979)9"!I<R!G:79E;B!T:&4@96QE;65N="!W:71H
M('1H92!I9"!I9%1O36]V90H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-H86QL(&)E(&UO=F5D(%]B96AI;F1?('1H92!E;&5M96YT('=I=&@@
M:60]<')E=DED"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M:70@:7,@,"!I="!W:6QL(&)E('!U="!A="!T:&4@8F5G:6YN:6YG"B`@("`J
M("`@0')E='5R;B`@("`@;6EX960@("`@("`@=')U92!F;W(@<W5C8V5S<RP@
M5')E95]%<G)O<B!O;B!F86EL=7)E"B`@("`J+PH@("`@9G5N8W1I;VX@7VUO
M=F4H("1I9%1O36]V92`L("1N97=087)E;G1)9"`L("1P<F5V260],"`I"B`@
M("!["B`@("`@("`@:68H("1I9%1O36]V92`]/2`D;F5W4&%R96YT260@*2`@
M("`@("`@("`@("`O+R!I='-E;&8@8V%N(&YO="!B92!A('!A<F5N="!O9B!I
M='-E;&8*+R\@5$]$3R!014%2+6EZ92!E<G)O<@H@("`@("`@("`@("!R971U
M<FX@5%)%15]%4E)/4E])3E9!3$E$7U!!4D5.5#L*"B`@("`@("`@+R\@8VAE
M8VL@:68@)&YE=U!A<F5N=$ED(&ES(&$@8VAI;&0@*&]R(&$@8VAI;&0M8VAI
M;&0@+BXN*2!O9B`D:614;TUO=F4*("`@("`@("`O+R!I9B!S;R!P<F5V96YT
M(&UO=FEN9RP@8F5C875S92!T:&%T(&ES(&YO="!P;W-S:6)L90HO+R`@("`@
M("`@:68H($`D=&AI<RT^9&%T85LD:614;TUO=F5=6R=C:&EL9')E;B==("D@
M("`@("\O(&1O97,@=&AI<R!E;&5M96YT(&AA=F4@8VAI;&1R96X_"B`@("`@
M("`@:68H("1T:&ES+3YH87-#:&EL9')E;B@D:614;TUO=F4I("D@("`@("\O
M(&1O97,@=&AI<R!E;&5M96YT(&AA=F4@8VAI;&1R96X_"B`@("`@("`@>PHO
M+R`@("`@("`@("`@("1A;&Q#:&EL9')E;B`]("1T:&ES+3YD871A6R1I9%1O
M36]V95U;)V-H:6QD<F5N)UT["B`@("`@("`@("`@("1A;&Q#:&EL9')E;B`]
M("1T:&ES+3YG971#:&EL9')E;B@D:614;TUO=F4I.PHO+R!&25A8344@=VAA
M="!H87!P96YS(&AE<F4@=V4@87)E(&-H86YG:6YG("1A;&Q#:&EL9')E;BP@
M9&]E<VYT('1H:7,@8VAA;F=E('1H90HO+R!P<F]P97)T>2!D871A('1O;S\_
M/R!S:6YC92!G971#:&EL9')E;B`H;6EG:'0L(&YO="!Y970I(')E='5R;B!A
M(')E9F5R96YC90H@("`@("`@("`@("!W:&EL92`H;&ES="@L("1A0VAI;&0I
M(#T@96%C:"`H)&%L;$-H:6QD<F5N*2D@("`O+R!U<V4@=VAI;&4@<VEN8V4@
M9F]R96%C:"!O;FQY('=O<FMS(&]N(&$@8V]P>2!O9B!T:&4@9&%T82!T;R!L
M;V]P('1H<F]U9V@L(&)U="!W92!A<F4@8VAA;F=I;F<@)&%L;$-H:6QD<F5N
M(&EN('1H92!L;V]P"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(&%R
M<F%Y7W-H:69T*"`D86QL0VAI;&1R96X@*3L@("`@("`@("\O(')E;6]V92!T
M:&4@9FER<W0@96QE;65N="!B96-A=7-E(&EF(&%R<F%Y7VUE<F=E(&ES(&-A
M;&QE9"!T:&4@87)R87D@<&]I;G1E<B!S965M<R!T;R!B90H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M<V5T('1O('1H92!B96=I;FYI;F<@86YD('1H:7,@=V%Y('1H92!B96=I;FYI
M;F<@:7,@86QW87ES('1H92!C=7)R96YT(&5L96UE;G0L('-I;7!L>2!W;W)K
M(&]F9B!A;F0@=')U;F-A=&4@:6X@9G)O;G0*("`@("`@("`@("`@("`@(&EF
M*"!`)&%#:&EL9%LG8VAI;&1R96XG72`I"B`@("`@("`@("`@("`@("!["B`@
M("`@("`@("`@("`@("`@("`@)&%L;$-H:6QD<F5N(#T@87)R87E?;65R9V4H
M("1A;&Q#:&EL9')E;B`L("1A0VAI;&1;)V-H:6QD<F5N)UT@*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF*"`D;F5W4&%R96YT260@
M/3T@)&%#:&EL9%LG:60G72`I"B\O(%1/1$\@4$5!4BUI>F4@97)R;W(*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@5%)%15]%4E)/4E])3E9!3$E$7U!!
M4D5.5#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@=VAA
M="!H87!P96YS(&EF(&D@86T@=7-I;F<@=&AE('!R979)9"!T;V\L('1H96X@
M=&AE(&1B(&-L87-S(&%L<V\*("`@("`@("`O+R!N965D<R!T;R!K;F]W('=H
M97)E('1H92!E;&5M96YT('-H;W5L9"!B92!M;W9E9"!T;PH@("`@("`@("\O
M(&%N9"!I="!H87,@=&\@8VAA;F=E('1H92!P<F5V260@;V8@=&AE(&5L96UE
M;G0@=&AA="!W:6QL(&)E(&%F=&5R(&ET"B`@("`@("`@+R\@<V\@=V4@;6%Y
M(&)E('-I;7!L>2!C86QL('-O;64@;65T:&]D(&QI:V4@)W5P9&%T92<@=&]O
M/PH*("`@("`@("!I9B@@;65T:&]D7V5X:7-T<R@D=&AI<RT^9&%T85-O=7)C
M94-L87-S+"=M;W9E)RD@*0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F1A
M=&%3;W5R8V5#;&%S<RT^;6]V92@@)&ED5&]-;W9E("P@)&YE=U!A<F5N=$ED
M("P@)'!R979)9"`I.PH@("`@("`@(&5L<V4*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=&AR;W=%<G)O<B@@)VUE=&AO9"!N;W0@:6UP;&5M96YT960@
M>65T+B<@+"!?7TQ)3D5?7R`I.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*
M"B`@("`O*BH*("`@("H@("!U<&1A=&4@9&%T82!I;B!A(&YO9&4*("`@("H*
M("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`Q+S(Y"B`@("`J("`@0&%C8V5S
M<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE
M<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@("`@
M("!A<G)A>2`@("1D871A("`@=&AE(&1A=&$@=&\@=7!D871E"B`@("`J("`@
M0')E='5R;@H@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T92@@)&ED("P@)&1A
M=&$@*0H@("`@>PH@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES+3YD
M871A4V]U<F-E0VQA<W,L)W5P9&%T92<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^9&%T85-O=7)C94-L87-S+3YU<&1A=&4H)&ED+"1D871A*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T
M:')O=T5R<F]R*"`G;65T:&]D(&YO="!I;7!L96UE;G1E9"!Y970N)R`L(%]?
M3$E.15]?("D["B`@("`@("`@?0H@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*
M"@H*"@H*("`@("\O"B`@("`O+PH@("`@+R\@(&9R;VT@:&5R92!A;&P@;65T
M:&]D<R!A<F4@;F]T(&EN=&5R86-T:6YG(&]N('1H92`@)V1A=&%3;W5R8V5#
M;&%S<R<*("`@("\O"B`@("`O+PH*("`@("\J*@H@("`@*B`@(&)U:6QD<R!T
M:&4@<W1R=6-T=7)E(&EN('1H92!P87)A;65T97(@)&EN<V5R=$EN"B`@("`J
M("`@=&AI<R!F=6YC=&EO;B!W;W)K<R!R96-U<G-I=F5L>2!D;W=N(&EN=&\@
M9&5P=&@@;V8@=&AE(&9O;&1E<B!S=')U8W1U<F4*("`@("H@("!I="!B=6EL
M9',@86X@87)R87D@=VAI8V@@9V]E<R!A<R!D965P(&%S('1H92!S=')U8W1U
M<F4@9V]E<PH@("`@*@H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@
M*B`@($!V97)S:6]N("`@(#(P,#$O,#4O,#(*("`@("H@("!`875T:&]R("`@
M("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@
M*B`@($!P87)A;2`@("`@(&EN=&5G97(@)'!A<F5N=$ED('1H92!P87)E;G0@
M9F]R('=H:6-H(&ET)W,@<W1R=6-T=7)E('-H86QL(&)E(&)U:6QT"B`@("`J
M("`@0'!A<F%M("`@("`@:6YT96=E<B`D:6YS97)T26X@=&AE(&%R<F%Y('=H
M97)E('1O(&)U:6QD('1H92!S=')U8W1U<F4@:6X*("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&=I=F5N(&%S(&$@<F5F97)E;F-E('1O(&)E('-U<F4@
M=&AE('-U8G-T<G5C='5R92!I<R!B=6EL=`H@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@:6X@=&AE('-A;64@87)R87D@87,@<&%S<V5D('1O('1H92!F
M=6YC=&EO;@H@("`@*B`@($!R971U<FX@("`@(&)O;VQE86X@<F5T=7)N<R!A
M;'=A>7,@=')U90H@("`@*@H@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD4W1R
M=6-T=7)E*"`D<&%R96YT260@+"`F)&EN<V5R=$EN("D*("`@('L*("`@("`@
M("`O+R!C<F5A=&4@=&AE(&5L96UE;G0L('-O(&ET(&5X:7-T<R!I;B!T:&4@
M<')O<&5R='D@(G-T<G5C='5R92(*("`@("`@("`O+R!A;'-O(&EF('1H97)E
M(&%R92!N;R!C:&EL9')E;B!B96QO=PH@("`@("`@("1I;G-E<G1);ELD<&%R
M96YT261=(#T@87)R87DH*3L*"B`@("`@("`@+R\@<V5T('1H92!L979E;"P@
M<VEN8V4@=V4@87)E('=A;&MI;F<@=&AR;W5G:"!T:&4@<W1R=6-T=7)E(&AE
M<F4@86YY=V%Y('=E"B`@("`@("`@+R\@8V%N(&1O('1H:7,@:&5R92P@:6YS
M=&5A9"!O9B!U<"!I;B!T:&4@<V5T=7`@;65T:&]D(#HM*0H@("`@("`@("\O
M(&%L=V%Y<R!S970@=&AE(&QE=F5L('1O(&]N92!H:6=H97(@=&AA;B!T:&4@
M<&%R96YT)W,@;&5V96PL(&5A<WD@:&$_"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3YD871A6R1P87)E;G1)9%U;)W!A<F5N="==6R=L979E;"==*2D@>R`@
M+R\@=&AI<R!A<'!L:65S(&]N;'D@=&\@=&AE(')O;W0@96QE;65N="AS*0H@
M("`@("`@("`@("`D=&AI<RT^9&%T85LD<&%R96YT261=6R=L979E;"==(#T@
M)'1H:7,M/F1A=&%;)'!A<F5N=$ED75LG<&%R96YT)UU;)VQE=F5L)UTK,3L*
M("`@("`@("`@("`@"B`@("`@("`@("`@(&EF("@D=&AI<RT^9&%T85LD<&%R
M96YT261=6R=L979E;"==/B1T:&ES+3Y?=')E941E<'1H*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W1R965$97!T:"`]("1T:&ES+3YD871A6R1P87)E
M;G1)9%U;)VQE=F5L)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LD<&%R96YT261=6R=L979E;"==
M(#T@,#L@("`@+R\@<V5T(&9I<G-T(&QE=F5L(&YU;6)E<B!T;R`P"B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-H:6QD<F5N6R1P87)E
M;G1)9%TI("8F('-I>F5O9B@D=&AI<RT^8VAI;&1R96Y;)'!A<F5N=$ED72DI
M('L*("`@("`@("`@("`@+R\@9V\@=&AR=2!A;&P@=&AE(&9O;&1E<G,*("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F-H:6QD<F5N6R1P87)E;G1)9%T@
M87,@)&-H:6QD*2!["B`@("`@("`@("`@("`@("`O+R!B=6EL9"!T:&4@<W1R
M=6-T=7)E('5N9&5R('1H:7,@9F]L9&5R+`H@("`@("`@("`@("`@("`@+R\@
M=7-E('1H92!C=7)R96YT(&9O;&1E<B!A<R!T:&4@;F5W('!A<F5N="!A;F0@
M8V%L;"!B=6EL9"!R96-U<G-I=F5L>0H@("`@("`@("`@("`@("`@+R\@=&\@
M8G5I;&0@86QL('1H92!C:&EL9')E;@H@("`@("`@("`@("`@("`@+R\@8GD@
M8V%L;&EN9R!B=6EL9"!W:71H("1I;G-E<G1);EMS;VUE:6YD97A=('1H92!A
M<G)A>2!I<R!F:6QL960*("`@("`@("`@("`@("`@("\O('-I;F-E('1H92!A
M<G)A>2!W87,@96UP='D@8F5F;W)E"B`@("`@("`@("`@("`@("`D=&AI<RT^
M8G5I;&13=')U8W1U<F4H("1C:&EL9"`L("1I;G-E<G1);ELD<&%R96YT261=
M("D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*("`@("H@
M("!T:&ES(&UE=&AO9"!O;FQY('-E<G9E<R!T;R!C86QL('1H92!?=V%L:R!M
M971H;V0@86YD(')E<V5T("1T:&ES+3YW86QK4F5T=7)N"B`@("`J("`@=&AA
M="!W:6QL(&)E(')E='5R;F5D(&)Y(&%L;"!T:&4@=V%L:RUS=&5P<PH@("`@
M*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#$O,3$O,C4*("`@("H@("!`86-C
M97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR
M:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@
M("`@(&UI>&5D("`@)'=A;&M&=6YC=&EO;B`@('1H92!N86UE(&]F('1H92!F
M=6YC=&EO;B!T;R!C86QL(&9O<B!E86-H('=A;&L@<W1E<"P*("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!A;B!A<G)A
M>2!F;W(@82!M971H;V0L('=H97)E"B`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@6S!=(&ES('1H92!M971H;V0@;F%M92!A
M;F0@6S%=('1H92!O8FIE8W0*("`@("H@("!`<&%R86T@("`@("!A<G)A>2`@
M("1I9"`@("`@=&AE(&ED('1O('-T87)T('=A;&MI;F<@=&AR;W5G:"!T:&4@
M=')E92P@979E<GET:&EN9R!B96QO=R!I<R!W86QK960@=&AR;W5G:`H@("`@
M*B`@($!P87)A;2`@("`@('-T<FEN9R`@)')E='5R;E1Y<&4@=&AE(')E='5R
M;B!O9B!A;&P@=&AE('=A;&L@9&%T82!W:6QL(&)E(&]F('1H92!G:79E;B!T
M>7!E("AV86QU97,Z('-T<FEN9RP@87)R87DI"B`@("`J("`@0')E='5R;B`@
M("`@;6EX960@("!T:&ES(&ES(&%L;"!T:&4@<F5T=7)N(&1A=&$@8V]L;&5C
M=&5D(&9R;VT@86QL('1H92!W86QK+7-T97!S"B`@("`J"B`@("`J+PH@("`@
M9G5N8W1I;VX@=V%L:R@@)'=A;&M&=6YC=&EO;B`L("1I9#TP("P@)')E='5R
M;E1Y<&4])W-T<FEN9R<I"B`@("!["B`@("`@("`@)'5S94YO9&4@/2`D=&AI
M<RT^<W1R=6-T=7)E.R`@("`@("`@("`@("`@("`O+R!B>2!D969A=6QT(&%L
M;"!O9B!S=')U8W1U<F4@:7,@=7-E9`H@("`@("`@(&EF("@D:60@/3T@,"D@
M>PH@("`@("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/G-T<G5C
M='5R92D["B`@("`@("`@("`@("1I9"`]("1K97ES6S!=.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1P871H(#T@)'1H:7,M/F=E=%!A=&@H)&ED
M*3L@("`@("`@("`@("`O+R!G970@=&AE('!A=&@L('1O(&)E(&%B;&4@=&\@
M9V\@=&\@=&AE(&5L96UE;G0@:6X@=&AI<RT^<W1R=6-T=7)E"B`@("`@("`@
M("`@(&%R<F%Y7W!O<"@D<&%T:"D[("`@("`@("`@("`@("`@("`@("`@("`O
M+R!P;W`@;V9F('1H92!L87-T(&5L96UE;G0L('-I;F-E(&ET(&ES('1H92!O
M;F4@<F5Q=65S=&5D"B`@("`@("`@("`@("1C=7).;V1E(#T@)'1H:7,M/G-T
M<G5C='5R93L@("`@("`@("`@("`O+R!S=&%R="!A="!T:&4@<F]O="!O9B!S
M=')U8W1U<F4*("`@("`@("`@("`@9F]R96%C:"`H)'!A=&@@87,@)&YO9&4I
M('L*("`@("`@("`@("`@("`@("1C=7).;V1E(#T@)&-U<DYO9&5;)&YO9&5;
M)VED)UU=.R`@("\O(&=O(&%S(&1E97`@:6YT;R!S=')U8W1U<F4@87,@<&%T
M:"!D969I;F5S"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'5S94YO9&4@
M/2!A<G)A>2@I.R`@("`@("`@("`@("`@("`@("`@("\O(&5M<'1Y(&ET(&9I
M<G-T+"!S;R!W92!D;VYT(&AA=F4@=&AE(&]T:&5R('-T=69F(&EN('1H97)E
M(&9R;VT@8F5F;W)E"B`@("`@("`@("`@("1U<V5.;V1E6R1I9%T@/2`D8W5R
M3F]D95LD:61=.R`@("`@("`@("`O+R!C;W!Y(&]N;'D@=&AE(&)R86YC:"!O
M9B!T:&4@=')E92!T:&%T('1H92!P87)A;65T97(@)&ED(')E<75E<W1E9`H@
M("`@("`@('T*"B`@("`@("`@=6YS970H)'1H:7,M/G=A;&M2971U<FXI.R`@
M("`@("`@("`@("`@("`@("`O+R!A(&YE=R!W86QK('-T87)T<RP@=6YS970@
M=&AE(')E='5R;B!V86QU90H@("`@("`@(')E='5R;B`D=&AI<RT^7W=A;&LH
M("1W86QK1G5N8W1I;VX@+"`D=7-E3F]D92`L("1R971U<FY4>7!E("D["B`@
M("!]"@H@("`@+RHJ"B`@("`J("`@=V%L:W,@=&AR;W5G:"!T:&4@96YT:7)E
M('1R964@86YD(')E='5R;G,@=&AE(&-U<G)E;G0@96QE;65N="!A;F0@=&AE
M(&QE=F5L"B`@("`J("`@<V\@82!U<V5R(&-A;B!U<V4@=&AI<R!T;R!B=6EL
M9"!A('1R965M87`@;W(@=VAA=&5V97(*("`@("H*("`@("H@("!`=F5R<VEO
M;B`@("`R,#`Q+S`V+WAX"B`@("`J("`@0&%C8V5S<R`@("`@<')I=F%T90H@
M("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`
M:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@;6EX960@("`D=V%L
M:T9U;F-T:6]N("`@=&AE(&YA;64@;V8@=&AE(&9U;F-T:6]N('1O(&-A;&P@
M9F]R(&5A8V@@=V%L:R!S=&5P+`H@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]R(&%N(&%R<F%Y(&9O<B!A(&UE=&AO9"P@
M=VAE<F4*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!;,%T@:7,@=&AE(&UE=&AO9"!N86UE(&%N9"!;,5T@=&AE(&]B:F5C
M=`H@("`@*B`@($!P87)A;2`@("`@(&%R<F%Y("`@)&-U<DQE=F5L("`@("`@
M=&AE(')E9F5R96YC92!I;B!T:&4@=&AI<RT^<W1R=6-T=7)E+"!T;R!W86QK
M(&5V97)Y=&AI;F<@8F5L;W<*("`@("H@("!`<&%R86T@("`@("!S=')I;F<@
M("1R971U<FY4>7!E('1H92!R971U<FX@;V8@86QL('1H92!W86QK(&1A=&$@
M=VEL;"!B92!O9B!T:&4@9VEV96X@='EP92`H=F%L=65S.B!S=')I;F<L(&%R
M<F%Y+"!I9D%R<F%Y*0H@("`@*B`@($!R971U<FX@("`@(&UI>&5D("`@=&AI
M<R!I<R!A;&P@=&AE(')E='5R;B!D871A(&-O;&QE8W1E9"!F<F]M(&%L;"!T
M:&4@=V%L:RUS=&5P<PH@("`@*@H@("`@*B\*("`@(&9U;F-T:6]N(%]W86QK
M*"`D=V%L:T9U;F-T:6]N("P@)B1C=7),979E;"`L("1R971U<FY4>7!E("D*
M("`@('L*("`@("`@("!I9B`H<VEZ96]F*"1C=7),979E;"DI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&-U<DQE=F5L(&%S("1K97D]/B1V86QU92D@>PH@
M("`@("`@("`@("`@("`@)')E="`](&-A;&Q?=7-E<E]F=6YC*"`D=V%L:T9U
M;F-T:6]N("P@)'1H:7,M/F1A=&%;)&ME>5T@*3L*("`@("`@("`@("`@("`@
M('-W:71C:"`H)')E='5R;E1Y<&4I('L*("`@("`@("`@("`@("`@("`@("!C
M87-E("=A<G)A>2<Z("`@)'1H:7,M/G=A;&M2971U<FY;72`]("1R970["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)VEF07)R87DG.B`O+R!T:&ES(&]N;'D@
M861D<R!T:&4@96QE;65N="!I9B!T:&4@)')E="!I<R!A;B!A<G)A>2!A;F0@
M8V]N=&%I;G,@9&%T80H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)')E="DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW86QK4F5T=7)N6UT@/2`D
M<F5T.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z("`@("`@("`D=&AI<RT^=V%L:U)E
M='5R;BX]("1R970["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]W86QK*"`D=V%L:T9U;F-T:6]N("P@)'9A;'5E("P@)')E='5R
M;E1Y<&4@*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@)'1H:7,M/G=A;&M2971U<FX["B`@("!]("\O(&5N9"!O9B!F=6YC=&EO
M;@H*("`@("\J*@H@("`@*B`@(&%D9',@;75L=&EP;&4@96QE;65N=',*("`@
M("H@("!Y;W4@:&%V92!T;R!P87-S('1H;W-E(&5L96UE;G1S(&EN(&$@;75L
M=&ED:6UE;G-I;VYA;"!A<G)A>2!W:&EC:"!R97!R97-E;G1S('1H90H@("`@
M*B`@('1R964@<W1R=6-T=7)E(&%S(&ET('-H86QL(&)E(&%D9&5D("AT:&ES
M(&%R<F%Y(&-A;B!O9B!C;W5R<V4@86QS;R!S:6UP;'D@8V]N=&%I;B!O;F4@
M96QE;65N="D*("`@("H@("!T:&4@9F]L;&]W:6YG(&%R<F%Y("1X('!A<W-E
M9"!A<R!T:&4@<&%R86UE=&5R"B`@("`J("`@("`@("`D>%LP72`](&%R<F%Y
M*"`@)VYA;64G/3XG8FQA)RPG<&%R96YT260G/3XG,S`G+`H@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"`@)VYA;64G/3XG8FQA,2<L)V-O
M;6UE;G0G/3XG9F]O)RP*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=N86UE)ST^)V)L83(G*2P*("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=N86UE)ST^)V)L83)?,2<I
M"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@*2P*("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@@("=N86UE)ST^)V)L83%?,2<I+`H@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("H@("`@("`@("`@
M("`@("`@("`@("`@*3L*("`@("H@("`@("`@("1X6S%=(#T@87)R87DH("`G
M;F%M92<]/B=F;V]";&$G+"=P87)E;G1)9"<]/B<S,"<I.PH@("`@*@H@("`@
M*B`@('=O=6QD(&%D9"!T:&4@9F]L;&]W:6YG('1R964@*&]R('-U8G1R964L
M(&]R(&YO9&4@=VAA=&5V97(@>6]U('=A;G0@=&\@8V%L;"!I="D*("`@("H@
M("!U;F1E<B!T:&4@<&%R96YT('=I=&@@=&AE(&ED(#,P("AS:6YC92`G<&%R
M96YT260G/3,P(&EN("1X6S!=(&%N9"!I;B`D>%LQ72D*("`@("H@("`@*RTM
M8FQA"B`@("`J("`@('P@("`K+2UB;&$Q"B`@("`J("`@('P@("!\("`@("LM
M+6)L83(*("`@("H@("`@?"`@('P@("`@*RTM8FQA,E\Q"B`@("`J("`@('P@
M("`K+2UB;&$Q7S$*("`@("H@("`@*RTM9F]O0FQA"B`@("`J"B`@("`J("`@
M0'-E92`@("`@("`@861D*"D*("`@("H@("!`=F5R<VEO;B`@("`R,#`Q+S$R
M+S$Y"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO
M<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*
M("`@("H@("!`<&%R86T@("`@("!A<G)A>2`@("1N;V1E("`@=&AE('1R964@
M=&\@8F4@:6YS97)T960L(')E<')E<V5N=',@=&AE('1R964@<W1R=6-T=7)E
M+`H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S964@861D
M*"D@9F]R('1H92!E>&%C="!M96UB97(@;V8@96%C:"!N;V1E"B`@("`J("`@
M0')E='5R;B`@("`@;6EX960@("!E:71H97(@8F]O;&5A;B!F86QS92!O;B!F
M86EL=7)E(&]R('1H92!I9"!O9B!T:&4@:6YS97)T960@<F]W"B`@("`J+PH@
M("`@9G5N8W1I;VX@861D3F]D92@@)&YO9&4@*0H@("`@>PH@("`@("`@(&EF
M*"!S:7IE;V8H)&YO9&4I("D*("`@("`@("!F;W)E86-H*"`D;F]D92!A<R`D
M84YO9&4@*0H@("`@("`@('L*("`@("`@("`@("`@)&YE=TYO9&4@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!F;W)E86-H*"`D84YO9&4@87,@)&YA;64]/B1V
M86QU92`I("`@("`@+R\@=&AI<R!S:&]U;&0@86QW87ES(&AA=F4@9&%T82P@
M:68@;F]T('1H92!P87-S960@<W1R=6-T=7)E(&AA<R!A;B!E<G)O<@H@("`@
M("`@("`@("!["B`@("`@("`@("`@("`@("!I9B@@(6ES7V%R<F%Y*"1V86QU
M92D@*2`@("`@("`@("`@("`O+R!C;VQL96-T('1H92!D871A('1H870@;F5E
M9"!T;R!G;R!I;B!T:&4@1$(*("`@("`@("`@("`@("`@("`@("`D;F5W16YT
M<GE;)&YA;65=(#T@)'9A;'5E.PH@("`@("`@("`@("`@("`@96QS92`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@8V]L;&5C="!T:&4@8VAI
M;&1R96X*("`@("`@("`@("`@("`@("`@("`D;F5W3F]D95M=(#T@)'9A;'5E
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I;G-E<G1E9$ED(#T@)'1H
M:7,M/F%D9"@@)&YE=T5N=')Y("D[("`O+R!A9&0@=&AE(&5L96UE;G0@86YD
M(&=E="!T:&4@:60L('1H870@:70@9V]T+"!T;R!H879E('1H92!P87)E;G1)
M9"!F;W(@=&AE(&-H:6QD<F5N"@H@("`@("`@("`@("!I9B@@)&EN<V5R=&5D
M260A/2!F86QS92`I("`@("`@("`@("`@("`@+R\@:68@:6YS97)T:6YG('-U
M8V5E9&5D+"!W92!H879E(')E8V5I=F5D('1H92!I9"!U;F1E<B!W:&EC:"!W
M92!C86X@:6YS97)T('1H92!C:&EL9')E;@H@("`@("`@("`@("!["B`@("`@
M("`@("`@("`@("!I9B@@<VEZ96]F*"1N97=.;V1E*2`I("`@("`@("`@("`@
M("`O+R!I9B!T:&5R92!A<F4@8VAI;&1R96XL('-E="!T:&5I<B!P87)E;G1)
M9"P@<V\@=&AE>2!K:VYO=R!W:&5R92!T:&5Y(&)E;&]N9R!I;B!T:&4@=')E
M90H@("`@("`@("`@("`@("`@9F]R96%C:"@@)&YE=TYO9&4@87,@)&ME>3T^
M)&%.97=.;V1E("D*("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M("`@("`D;F5W3F]D95LD:V5Y75LG<&%R96YT260G72`]("1I;G-E<G1E9$ED
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D
M9$YO9&4H("1N97=.;V1E("D[("`@("`@("`@+R\@8V%L;"!Y;W5R<V5L9B!R
M96-U<G-I=F5L>2!T;R!I;G-E<G0@=&AE(&-H:6QD<F5N+"!A;F0@:71S(&-H
M:6QD<F5N(&%N9"`N+BX*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T@
M+R\@96YD(&]F(&9U;F-T:6]N"@H@("`@+RHJ"B`@("`J("`@9V5T<R!T:&4@
M<&%T:"!T;R!T:&4@96QE;65N="!G:79E;B!B>2!I=',@:60*("`@("H@("`A
M(2$@051414Y424].('=A=&-H(&]U="!T:&%T('EO=2!N979E<B!C:&%N9V4@
M86YY(&]F('1H92!D871A(')E='5R;F5D+`H@("`@*B`@('-I;F-E('1H97D@
M87)E(')E9F5R96YC97,@=&\@=&AE(&EN=&5R;F%L('!R;W!E<G1Y("1D871A
M"B`@("`J"B`@("`J("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0'9E
M<G-I;VX@("`@,C`P,2\Q,"\Q,`H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI
M8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R
M86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@;6EX960@("`D
M:60@("`@('1H92!I9"!O9B!T:&4@;F]D92!T;R!G970@=&AE('!A=&@@9F]R
M"B`@("`J("`@0')E='5R;B`@("`@87)R87D@("!T:&ES(&%R<F%Y(&-O;G1A
M:6YS(&%L;"!E;&5M96YT<R!F<F]M('1H92!R;V]T('1O('1H92!E;&5M96YT
M(&=I=F5N(&)Y('1H92!I9`H@("`@*@H@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A=&@H("1I9"`I"B`@("!["B`@("`@("`@)'!A=&@@/2!A<G)A>2@I.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!E;7!T>2!T:&4@<&%T:"P@
M=&\@8F4@8VQE86X*"B\O($9)6%A-12!M87D@:71S(&)E='1E<B!T;R!U<V4@
M82!F;W(H;&5V96PI('1O(&-O=6YT(&1O=VXL"B\O('-I;F-E(&$@=VAI;&4@
M:7,@86QW87ES(&$@;&ET=&QE(')I<VMY"B`@("`@("`@=VAI;&4H($`D=&AI
M<RT^9&%T85LD:61=6R=P87)E;G0G72`I("`@("`@("`O+R!U;G1I;"!T:&5R
M92!A<F4@;F\@;6]R92!P87)E;G1S"B`@("`@("`@>PH@("`@("`@("`@("`D
M<&%T:%M=(#T@)B1T:&ES+3YD871A6R1I9%T[("`@("`@("`@("`@+R\@8W5R
M16QE;65N="!I<R!A;')E861Y(&$@<F5F97)E;F-E+"!S;R!S879E(&ET(&EN
M('!A=&@*("`@("`@("`@("`@)&ED(#T@)'1H:7,M/F1A=&%;)&ED75LG<&%R
M96YT)UU;)VED)UT[("\O(&=E="!T:&4@;F5X="!P87)E;G0@:60L(&9O<B!T
M:&4@=VAI;&4@=&\@<F5T<F5I=F4@=&AE('!A<F5N="=S('!A<F5N=`H@("`@
M("`@('T*("`@("`@("`D<&%T:%M=(#T@)B1T:&ES+3YD871A6R1I9%T[("`@
M("`@("`@("`@("`@("\O(&1O;G0@9F]R9V5T('1H92!L87-T(&]N90H*("`@
M("`@("!R971U<FX@87)R87E?<F5V97)S92@D<&%T:"D["B`@("!]("\O(&5N
M9"!O9B!F=6YC=&EO;@H*("`@("\J*@H@("`@*B`@('-E=',@=&AE(')E;6]V
M92UR96-U<G-I=F5L>2!M;V1E+"!E:71H97(@=')U92!O<B!F86QS90H@("`@
M*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#$O,3`O,#D*("`@("H@("!`86-C
M97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR
M:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@
M("`@(&)O;VQE86X@)&YE=U9A;'5E<R!S970@=&\@=')U92!I9B!R96UO=FEN
M9R!A('1R964@;&5V96P@<VAA;&P@<F5M;W9E(&%L;"!I="=S(&-H:6QD<F5N
M(&%N9"!T:&5I="!C:&EL9')E;B`N+BX*("`@("H*("`@("HO"B`@("!F=6YC
M=&EO;B!S971296UO=F5296-U<G-I=F5L>2@@)&-A<V4]=')U92`I"B`@("![
M"B`@("`@("`@)'1H:7,M/G)E;6]V95)E8W5R<VEV96QY(#T@)&-A<V4["B`@
M("!]("\O(&5N9"!O9B!F=6YC=&EO;@H*("`@("\J*@H@("`@*@H@("`@*@H@
M("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#$O,C$*("`@("H@("!`86-C97-S
M("`@("!P<FEV871E"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE
M<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T*("`@
M("H*("`@("HO"B`@("!F=6YC=&EO;B`F7V=E=$5L96UE;G0H("1I9"`L("1W
M:&%T/2<G("D*("`@('L*("`@("`@("!I9B@@)'=H870]/2<G("D*("`@("`@
M("!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9&%T85LD:61=.PH@("`@
M("`@('T*"B`@("`@("`@)&5L96UE;G1)9"`]("1T:&ES+3Y?9V5T16QE;65N
M=$ED*"`D:60@+"`D=VAA="`I.PH@("`@("`@(&EF*"`D96QE;65N=$ED("$]
M/2!.54Q,("D*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD871A6R1E;&5M
M96YT261=.PH*("`@("`@("!R971U<FX@3E5,3#L@("`@+R\@=V4@<VAO=6QD
M(&YO="!R971U<FX@9F%L<V4L('-I;F-E('1H870@;6EG:'0@8F4@82!V86QU
M92!O9B!T:&4@96QE;65N="!T:&%T(&ES(')E<75E<W1E9`H@("`@?2`O+R!E
M;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*("`@("H*("`@("H*("`@("H@("!`
M=F5R<VEO;B`@("`R,#`R+S`Q+S(Q"B`@("`J("`@0&%C8V5S<R`@("`@<')I
M=F%T90H@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O
M;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M"B`@("`J"B`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=$5L96UE;G1)9"@@)&ED("P@)'=H870@*0H@
M("`@>PH@("`@("`@(&EF*"!`)'1H:7,M/F1A=&%;)&ED75LD=VAA=%T@*2`@
M("`@("`@("`O+R!U<V4@0"!S:6YC92!T:&4@:V5Y("1W:&%T(&UI9VAT(&YO
M="!E>&ES=`H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F1A=&%;)&ED75LD
M=VAA=%U;)VED)UT["@H@("`@("`@(')E='5R;B!.54Q,.PH@("`@?2`O+R!E
M;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*("`@("H@("!G971S(&%N(&5L96UE
M;G0@87,@82!R969E<F5N8V4*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R
M,#`R+S`Q+S(Q"B`@("`J("`@0&%C8V5S<R`@("`@<')I=F%T90H@("`@*B`@
M($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I
M;F<N9&4^"B`@("`J("`@0'!A<F%M"B`@("`J"B`@("`J+PH@("`@9G5N8W1I
M;VX@)F=E=$5L96UE;G0H("1I9"`I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9V5T16QE;65N="@@)&ED("D["B`@("!]"@H@("`@+RHJ"B`@("`J
M"B`@("`J"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P,B\P-@H@("`@*B`@
M($!A8V-E<W,@("`@('!R:79A=&4*("`@("H@("!`875T:&]R("`@("!7;VQF
M<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P
M87)A;2`@("`@(&UI>&5D("`@96ET:&5R('1H92!I9"!O9B!A;B!E;&5M96YT
M(&]R('1H92!P871H('1O('1H92!E;&5M96YT"B`@("`J"B`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T16QE;65N=$-O;G1E;G0H("1I9$]R4&%T:"`L("1F:65L
M9$YA;64@*0H@("`@>PH@("`@("`@(&EF*"!I<U]S=')I;F<H)&ED3W)0871H
M*2`I"B`@("`@("`@>PH@("`@("`@("`@("`D:60@/2`D=&AI<RT^9V5T261"
M>5!A=&@H)&ED3W)0871H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^9&%T85LD:61=6R1F:65L9$YA;65=.PH@("`@?0H*("`@("\J*@H@
M("`@*@H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#(O,#8*("`@
M("H@("!`86-C97-S("`@("!P<FEV871E"B`@("`J("`@0&%U=&AO<B`@("`@
M5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@
M("!`<&%R86T*("`@("H*("`@("HO"B`@("!F=6YC=&EO;B!G971%;&5M96YT
M<T-O;G1E;G0H("1I9',@+"`D9FEE;&1.86UE("D*("`@('L*+R\@:2!D;VYT
M(&MN;W<@:68@=&AI<R!M971H;V0@:7,@;F]T(&IU<W0@;W9E<FQO861I;F<@
M=&AE(&9I;&4L('-I;F-E(&ET(&]N;'D@<V5R=F5S(&UY(&QA>GEN97-S"B\O
M(&ES('1H:7,@969F96-T:79E(&AE<F4_(&D@8V%N(&%L<V\@;&]O<"!I;B!T
M:&4@8V%L;&EN9R!C;V1E(3\*("`@("`@("`D9FEE;&1S(#T@87)R87DH*3L*
M("`@("`@("!I9BAI<U]A<G)A>2@D:61S*2`F)B!S:7IE;V8H)&ED<RDI"B`@
M("`@("`@9F]R96%C:"@@)&ED<R!A<R`D84ED("D*("`@("`@("`@("`@)&9I
M96QD<UM=(#T@)'1H:7,M/F=E=$5L96UE;G1#;VYT96YT*"`D84ED("P@)&9I
M96QD3F%M92`I.PH*("`@("`@("!R971U<FX@)&9I96QD<SL*("`@('T*"B`@
M("`O*BH*("`@("H@("!G971S(&%N(&5L96UE;G0@9VEV96X@8GD@:70G<R!P
M871H(&%S(&$@<F5F97)E;F-E"B`@("`J"B`@("`J("`@0'9E<G-I;VX@("`@
M,C`P,B\P,2\R,0H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@
M($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I
M;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@<W1R:6YG("`D<&%T:"`@("`@
M("!T:&4@<&%T:"!T;R!S96%R8V@@9F]R"B`@("`J("`@0'!A<F%M("`@("`@
M:6YT96=E<B`D<W1A<G1)9"`@("!T:&4@:60@=VAE<F4@=&\@<V5A<F-H(&9O
M<B!T:&4@<&%T:`H@("`@*B`@($!P87)A;2`@("`@('-T<FEN9R`@)&YO9&5.
M86UE("`@=&AE(&YA;64@;V8@=&AE(&ME>2!T:&%T(&-O;G1A:6YS('1H92!N
M;V1E(&YA;64*("`@("H@("!`<&%R86T@("`@("!S=')I;F<@("1S97!E<F%T
M;W(@('1H92!P871H('-E<&5R871O<@H@("`@*B`@($!R971U<FX@("`@(&EN
M=&5G97(@=&AE(&ED(&]F('1H92!S96%R8VAE9"!E;&5M96YT"B`@("`J"B`@
M("`J+PH@("`@9G5N8W1I;VX@)F=E=$5L96UE;G1">5!A=&@H("1P871H("P@
M)'-T87)T260],"`L("1N;V1E3F%M93TG;F%M92<@+"`D<V5P97)A=&]R/2<O
M)R`I"B`@("!["B`@("`@("`@)&ED(#T@)'1H:7,M/F=E=$ED0GE0871H*"`D
M<&%T:"`L("1S=&%R=$ED("D["B`@("`@("`@:68H("1I9"`I"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^9V5T16QE;65N="@@)&ED("D["B`@("`@("`@
M<F5T=7)N($Y53$P[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!R971U<FX@3E5,3"!S:6YC92!F86QS92!M:6=H="!B92!I;G1E<G!R971E
M9"!A<R!I9"`P"B`@("!]"@H@("`@+RHJ"B`@("`J("`@9V5T<R!A;B!E;&5M
M96YT($E$"B`@("`J"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P,2\R,0H@
M("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@
M(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J
M("`@0'!A<F%M"B`@("`J"B`@("`J+PHO*B!W92!A;')E861Y(&AA=F4@82!M
M971H;V0@9V5T261">5!A=&@L('=H:6-H(&]N92!S:&]U;&0@=V4@=7-E(#\_
M/S\*("`@(&9U;F-T:6]N("9G971%;&5M96YT261">5!A=&@H("1I9"`I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T16QE;65N="@@)&ED("D[
M"B`@("!]"BHO"@H@("`@+RHJ"B`@("`J("`@9V5T('1H92!L979E;"P@=VAI
M8V@@:7,@:&]W(&9A<B!B96QO=R!T:&4@<F]O="!A<F4@=V4_"B`@("`J"B`@
M("`J("`@0'9E<G-I;VX@("`@,C`P,2\Q,2\R-0H@("`@*B`@($!A8V-E<W,@
M("`@('!U8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I
M;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@
M;6EX960@("`D:60@("`@('1H92!I9"!O9B!T:&4@;F]D92!T;R!G970@=&AE
M(&QE=F5L(&9O<@H@("`@*@H@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QE=F5L
M*"`D:60@*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&%T85LD:61=
M6R=L979E;"==.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*
M("`@("H@("!R971U<FYS('1H92!C:&EL9"!I9B!T:&4@;F]D92!G:79E;B!H
M87,@;VYE"B`@("`J("`@(2$A($%45$5.5$E/3B!W871C:"!O=70@=&AA="!Y
M;W4@;F5V97(@8VAA;F=E(&%N>2!O9B!T:&4@9&%T82!R971U<FYE9"P*("`@
M("H@("!S:6YC92!T:&5Y(&%R92!R969E<F5N8V5S('1O('1H92!I;G1E<FYA
M;"!P<F]P97)T>2`D9&%T80H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P
M,#$O,3$O,C<*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`
M875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG
M+F1E/@H@("`@*B`@($!P87)A;2`@("`@(&UI>&5D("`@)&ED("`@("!T:&4@
M:60@;V8@=&AE(&YO9&4@=&\@9V5T('1H92!C:&EL9"!F;W(*("`@("H*("`@
M("HO"B`@("!F=6YC=&EO;B`F9V5T0VAI;&0H("1I9"`I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9V5T16QE;65N="@@)&ED("P@)V-H:6QD)R`I
M.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*("`@("H@("!R
M971U<FYS('1H92!C:&EL9"!I9B!T:&4@;F]D92!G:79E;B!H87,@;VYE"B`@
M("`J("`@(2$A($%45$5.5$E/3B!W871C:"!O=70@=&AA="!Y;W4@;F5V97(@
M8VAA;F=E(&%N>2!O9B!T:&4@9&%T82!R971U<FYE9"P*("`@("H@("!S:6YC
M92!T:&5Y(&%R92!R969E<F5N8V5S('1O('1H92!I;G1E<FYA;"!P<F]P97)T
M>2`D9&%T80H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#$O,3$O,C<*
M("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@
M("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@
M*B`@($!P87)A;2`@("`@(&UI>&5D("`@)&ED("`@("!T:&4@:60@;V8@=&AE
M(&YO9&4@=&\@9V5T('1H92!C:&EL9"!F;W(*("`@("H*("`@("HO"B`@("!F
M=6YC=&EO;B`F9V5T4&%R96YT*"`D:60@*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V=E=$5L96UE;G0H("1I9"`L("=P87)E;G0G("D["B`@("!]
M("\O(&5N9"!O9B!F=6YC=&EO;@H*("`@("\J*@H@("`@*B`@(')E='5R;G,@
M=&AE(&YE>'0@96QE;65N="!I9B!T:&4@;F]D92!G:79E;B!H87,@;VYE"B`@
M("`J("`@(2$A($%45$5.5$E/3B!W871C:"!O=70@=&AA="!Y;W4@;F5V97(@
M8VAA;F=E(&%N>2!O9B!T:&4@9&%T82!R971U<FYE9"P*("`@("H@("!S:6YC
M92!T:&5Y(&%R92!R969E<F5N8V5S('1O('1H92!I;G1E<FYA;"!P<F]P97)T
M>2`D9&%T80H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#$O,3<*
M("`@("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@
M("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@
M*B`@($!P87)A;2`@("`@(&UI>&5D("`@)&ED("`@("!T:&4@:60@;V8@=&AE
M(&YO9&4@=&\@9V5T('1H92!C:&EL9"!F;W(*("`@("H@("!`<F5T=7)N("`@
M("!M:7AE9"`@(')E9F5R96YC92!T;R!T:&4@;F5X="!E;&5M96YT(&]R(&9A
M;'-E(&EF('1H97)E(&ES(&YO;F4*("`@("HO"B`@("!F=6YC=&EO;B`F9V5T
M3F5X="@@)&ED("D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G971%
M;&5M96YT*"`D:60@+"`G;F5X="<@*3L*("`@('T@+R\@96YD(&]F(&9U;F-T
M:6]N"@H@("`@+RHJ"B`@("`J("`@<F5T=7)N<R!T:&4@<')E=FEO=7,@96QE
M;65N="!I9B!T:&4@;F]D92!G:79E;B!H87,@;VYE"B`@("`J("`@(2$A($%4
M5$5.5$E/3B!W871C:"!O=70@=&AA="!Y;W4@;F5V97(@8VAA;F=E(&%N>2!O
M9B!T:&4@9&%T82!R971U<FYE9"P*("`@("H@("!S:6YC92!T:&5Y(&%R92!R
M969E<F5N8V5S('1O('1H92!I;G1E<FYA;"!P<F]P97)T>2`D9&%T80H@("`@
M*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#(O,#4*("`@("H@("!`86-C
M97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR
M:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@
M("`@(&UI>&5D("`@)&ED("`@("!T:&4@:60@;V8@=&AE(&YO9&4@=&\@9V5T
M('1H92!C:&EL9"!F;W(*("`@("H@("!`<F5T=7)N("`@("!M:7AE9"`@(')E
M9F5R96YC92!T;R!T:&4@;F5X="!E;&5M96YT(&]R(&9A;'-E(&EF('1H97)E
M(&ES(&YO;F4*("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4')E=FEO=7,H("1I
M9"`I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T16QE;65N="@@
M)&ED("P@)W!R979I;W5S)R`I.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*
M"B`@("`O*BH*("`@("H@("!R971U<FYS('1H92!N;V1E(&9O<B!T:&4@9VEV
M96X@:60*("`@("H@("`A(2$@051414Y424].('=A=&-H(&]U="!T:&%T('EO
M=2!N979E<B!C:&%N9V4@86YY(&]F('1H92!D871A(')E='5R;F5D+`H@("`@
M*B`@('-I;F-E('1H97D@87)E(')E9F5R96YC97,@=&\@=&AE(&EN=&5R;F%L
M('!R;W!E<G1Y("1D871A"B`@("`J"B`@("`J("`@0'9E<G-I;VX@("`@,C`P
M,2\Q,2\R.`H@("`@*B`@($!A8V-E<W,@("`@('!U8FQI8PH@("`@*B`@($!A
M=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N
M9&4^"B`@("`J("`@0'!A<F%M("`@("`@;6EX960@("`D:60@("`@('1H92!I
M9"!O9B!T:&4@;F]D92!T;R!G970*("`@("H*("`@("HO"B\J('1H:7,@<VAO
M=6QD(&)E(&=E=$5L96UE;G0L(&D@=&AI;FL@:70@=V%S(&$@8FET('=E:7)D
M('1H870@:2!M861E('1H:7,@;65T:&]D(&QI:V4@=&AI<PH@("`@9G5N8W1I
M;VX@)F=E=$YO9&4H("1I9"`I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9V5T16QE;65N="@@)&ED("D["B`@("!]("\O(&5N9"!O9B!F=6YC=&EO
M;@HJ+PH*("`@("\J*@H@("`@*B`@(')E='5R;B!T:&4@:60@;V8@=&AE(&5L
M96UE;G0@=VAI8V@@:7,@<F5F97)E;F-E9"!B>2`D<&%T:`H@("`@*B`@('1H
M:7,@:7,@=7-E9G5L(&9O<B!X;6PM<W1R=6-T=7)E<RP@;&EK93H@9V5T261"
M>5!A=&@H("<O<F]O="]S=6(Q+W-U8C(G("D*("`@("H@("!T:&ES(')E<75I
M<F5S('1H92!S=')U8W1U<F4@=&\@=7-E(&5A8V@@;F%M92!U;FEQ=65L>0H@
M("`@*B`@(&EF('1H:7,@:7,@;F]T(&=I=F5N(&ET('=I;&P@<F5T=7)N('1H
M92!F:7)S="!P<F]P97(@<&%T:"!F;W5N9`H@("`@*B`@(&DN92X@=&AE<F4@
M<VAO=6QD(&]N;'D@8F4@;VYE('!A=&@@+W@O>2]Z"B`@("`J"B`@("`J("`@
M0'9E<G-I;VX@("`@,C`P,2\Q,2\R.`H@("`@*B`@($!A8V-E<W,@("`@('!U
M8FQI8PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O
M;&9R86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M("`@("`@<W1R:6YG
M("`D<&%T:"`@("`@("!T:&4@<&%T:"!T;R!S96%R8V@@9F]R"B`@("`J("`@
M0'!A<F%M("`@("`@:6YT96=E<B`D<W1A<G1)9"`@("!T:&4@:60@=VAE<F4@
M=&\@<V5A<F-H(&9O<B!T:&4@<&%T:`H@("`@*B`@($!P87)A;2`@("`@('-T
M<FEN9R`@)&YO9&5.86UE("`@=&AE(&YA;64@;V8@=&AE(&ME>2!T:&%T(&-O
M;G1A:6YS('1H92!N;V1E(&YA;64*("`@("H@("!`<&%R86T@("`@("!S=')I
M;F<@("1S97!E<F%T;W(@('1H92!P871H('-E<&5R871O<@H@("`@*B`@($!R
M971U<FX@("`@(&EN=&5G97(@=&AE(&ED(&]F('1H92!S96%R8VAE9"!E;&5M
M96YT"B`@("`J"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T261">5!A=&@H("1P
M871H("P@)'-T87)T260],"`L("1N;V1E3F%M93TG;F%M92<@+"`D<V5P97)A
M=&]R/2<O)R`I"B\O('-H;W5L9"!T:&ES(&UE=&AO9"!B92!C86QL960@9V5T
M16QE;65N=$ED0GE0871H(#\_/S\*("`@('L*("`@("`@("`O+R!I9B!N;R!S
M=&%R="!)1"!I<R!G:79E;B!G970@=&AE(')O;W0*("`@("`@("!I9B@@)'-T
M87)T260]/3`@*0H@("`@("`@("`@("`D<W1A<G1)9"`]("1T:&ES+3YG971&
M:7)S=%)O;W1)9"@I.PH@("`@("`@(&5L<V4@("`@+R\@:68@82!S=&%R="!I
M9"!I<R!G:79E;BP@9V5T(&ET<R!F:7)S="!C:&EL9"!T;R!S=&%R="!S96%R
M8VAI;F<@=&AE<F4*("`@("`@("!["B`@("`@("`@("`@("1S=&%R=$ED(#T@
M)'1H:7,M/F=E=$-H:6QD260H)'-T87)T260I.PH@("`@("`@("`@("!I9B@@
M)'-T87)T260@/3T@9F%L<V4@*2`@("`@("`@("`@("`@("`@+R\@:7,@=&AE
M<F4@82!C:&EL9"!T;R!T:&ES(&5L96UE;G0_"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B@@<W1R<&]S*"`D
M<&%T:"`L("1S97!E<F%T;W(@*3T]/3`@*2`@+R\@:68@82!S97!E<F%T;W(@
M:7,@870@=&AE(&)E9VEN;FEN9R!S=')I<"!I="!O9F8*("`@("`@("`@("`@
M)'!A=&@@/2!S=6)S='(H("1P871H("P@<W1R;&5N*"1S97!E<F%T;W(I("D[
M"@H@("`@("`@("1N;V1E<R`](&5X<&QO9&4H("1S97!E<F%T;W(@+"`D<&%T
M:"`I.PH*("`@("`@("`D8W5R260@/2`D<W1A<G1)9#L*("`@("`@("!F;W)E
M86-H*"`D;F]D97,@87,@)&ME>3T^)&%.;V1E3F%M92`I"B`@("`@("`@>PH@
M("`@("`@("`@("`D;F]D949O=6YD(#T@9F%L<V4["B`@("`@("`@("`@(&1O
M"B`@("`@("`@("`@('L*+R]P<FEN="`B<V5A<F-H("1A3F]D94YA;64L(&EN
M("(N)'1H:7,M/F1A=&%;)&-U<DED75LD;F]D94YA;65=+B(\8G(^(CL*("`@
M("`@("`@("`@("`@(&EF*"`D=&AI<RT^9&%T85LD8W5R261=6R1N;V1E3F%M
M95T@/3T@)&%.;V1E3F%M92`I"B`@("`@("`@("`@("`@("!["B`@("`@("`@
M("`@("`@("`@("`@)&YO9&5&;W5N9"`]('1R=64["B`@("`@("`@("`@("`@
M("`@("`@+R\@9&\@;VYL>2!S879E('1H92!C:&EL9"!I9B!W92!A<F4@;F]T
M(&%L<F5A9'D@870@=&AE(&5N9"!O9B!P871H"B`@("`@("`@("`@("`@("`@
M("`@+R\@8F5C875S92!T:&5N('=E(&YE960@8W5R260@=&\@<F5T=7)N(&ET
M"B`@("`@("`@("`@("`@("`@("`@:68H("1K97D@/"`H<VEZ96]F*"1N;V1E
M<RDM,2D@*0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R260@/2`D=&AI
M<RT^9V5T0VAI;&1)9"@D8W5R260I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-U<DED
M(#T@)'1H:7,M/F=E=$YE>'1)9"@D8W5R260I.PHO+W!R:6YT(")C=7))9"`]
M("1C=7))9#QB<CXB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('=H:6QE
M*"`D8W5R260@*3L*"B`@("`@("`@("`@(&EF*"`D;F]D949O=6YD/3UF86QS
M92`I"B`@("`@("`@("`@('L*+R]P<FEN="`G3D]4($9/54Y$/&)R/CQB<CXG
M.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0HO+W!R:6YT("<\8G(^)SL*"B`@("`@("`@<F5T=7)N("1C
M=7))9#L*+R\@1DE86$U%('1O(&)E(&EM<&QE;65N=&5D"B`@("!]("\O(&5N
M9"!O9B!F=6YC=&EO;@H*("`@("\J*@H@("`@*B`@('1H:7,@9V5T<R!T:&4@
M9FER<W0@96QE;65N="!T:&%T(&ES(&EN('1H92!R;V]T(&YO9&4*("`@("H@
M("!I('1H:6YK('1H870@=&AE<F4@8V%N)W0@8F4@82`B9V5T4F]O="(@;65T
M:&]D('-I;F-E('1H97)E(&UI9VAT"B`@("`J("`@8F4@;75L=&EP;&4@;G5M
M8F5R(&]F(&5L96UE;G1S(&EN('1H92!R;V]T(&YO9&4L(&%T(&QE87-T('1H
M90H@("`@*B`@('=A>2!I="!W;W)K<R!N;W<*("`@("H*("`@("H@("!`86-C
M97-S("`@("!P=6)L:6,*("`@("H@("!`=F5R<VEO;B`@("`R,#`Q+S$R+S$P
M"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A
M;4!K<FEE<VEN9RYD93X*("`@("H@("!`<F5T=7)N("`@("!R971U<FYS('1H
M92!F:7)S="!R;V]T(&5L96UE;G0*("`@("HO"B`@("!F=6YC=&EO;B`F9V5T
M1FER<W12;V]T*"D*("`@('L*("`@("`@("`O+R!C;W5L9"!A;'-O(&)E(')E
M<V5T*"1T:&ES+3YD871A*2!I('1H:6YK+"!S:6YC92!P:'`@:V5E<',@=&AE
M(&]R9&5R("XN+B!B=70@:2!D:61N="!T<GD*("`@("`@("!R97-E="@D=&AI
M<RT^<W1R=6-T=7)E*3L*("`@("`@("!R971U<FX@)'1H:7,M/F1A=&%;:V5Y
M*"1T:&ES+3YS=')U8W1U<F4I73L*("`@('T@+R\@96YD(&]F(&9U;F-T:6]N
M"@H@("`@+RHJ"B`@("`J("`@<VEN8V4@:6X@82!N97-T960@=')E92!T:&5R
M92!C86X@;VYL>2!B92!O;F4@<F]O=`H@("`@*B`@('=H:6-H(&D@=&AI;FL@
M*&YO=RD@:7,@8V]R<F5C="P@=V4@86QS;R!N965D(&%N(&%L:6%S(&9O<B!T
M:&ES(&UE=&AO9`H@("`@*B`@('1H:7,@86QS;R!M86ME<R!A;&P@=&AE(&UE
M=&AO9',@:6X@5')E95]#;VUM;VXL('=H:6-H(&%C8V5S<R!T:&4*("`@("H@
M("!R;V]T(&5L96UE;G0@=V]R:R!P<F]P97)L>2$*("`@("H*("`@("H@("!`
M86-C97-S("`@("!P=6)L:6,*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`W
M+S(V"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L
M9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<F5T=7)N("`@("!R971U<FYS
M('1H92!F:7)S="!R;V]T(&5L96UE;G0*("`@("HO"B`@("!F=6YC=&EO;B`F
M9V5T4F]O="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971&:7)S
M=%)O;W0H*3L*("`@('T*"B`@("`O*BH*("`@("H@("!G971S('1H92!T<F5E
M('5N9&5R('1H92!G:79E;B!E;&5M96YT(&EN(&]N92!A<G)A>2P@<V]R=&5D
M"B`@("`J("`@<V\@>6]U(&-A;B!G;R!T:')O=6=H('1H92!E;&5M96YT<R!F
M<F]M(&)E9VEN('1O(&5N9"!A;F0@;&ES="!T:&5M"B`@("`J("`@87,@=&AE
M>2!A<F4@:6X@=&AE('1R964L('=H97)E(&5V97)Y(&-H:6QD("AU;G1I;"!T
M:&4@9&5E<&5S="D@:7,@<F5T<F5I=F5D"B`@("`J"B`@("`J("`@0'-E92`@
M("`@("`@)E]G971.;V1E*"D*("`@("H@("!`86-C97-S("`@("!P=6)L:6,*
M("`@("H@("!`=F5R<VEO;B`@("`R,#`Q+S$R+S$W"B`@("`J("`@0&%U=&AO
M<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*
M("`@("H@("!`<&%R86T@("`@("!I;G1E9V5R("1S=&%R=$ED("`@('1H92!I
M9"!W:&5R92!T;R!S=&%R="!W86QK:6YG"B`@("`J("`@0'!A<F%M("`@("`@
M:6YT96=E<B`D9&5P=&@@("`@("!T:&ES(&YU;6)E<B!S87ES(&AO=R!D965P
M(&EN=&\*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!S=')U8W1U<F4@=&AE(&5L96UE;G1S('-H86QL(&)E(')E=')E:79E
M9`H@("`@*B`@($!R971U<FX@("`@(&%R<F%Y("`@<V]R=&5D(&%S(&QI<W1E
M9"!I;B!T:&4@=')E90H@("`@*B\*("`@(&9U;F-T:6]N("9G971.;V1E*"`D
M<W1A<G1)9#TP("P@)&1E<'1H/3`@*0H@("`@>PH@("`@("`@(&EF("@D<W1A
M<G1)9"`]/2`P*2!["B`@("`@("`@("`@("1L979E;"`](#`["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&QE=F5L(#T@)'1H:7,M/F=E=$QE=F5L
M*"1S=&%R=$ED*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9V5T3F]D
M94UA>$QE=F5L(#T@)&1E<'1H(#\@*"1D97!T:"`K("1L979E;"D@.B`P(#L*
M+R\A(2$@("`@("`@("1T:&ES+3Y?9V5T3F]D94-U<E!A<F5N="`]("1T:&ES
M+3YD871A6R=P87)E;G0G75LG:60G73L*"B`@("`@("`@+R\@:68@=&AE('1R
M964@:7,@96UP='D@9&]N="!W86QK('1H<F]U9V@@:70*("`@("`@("!I9B`H
M(7-I>F5O9B@D=&AI<RT^9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@)')E="`]("1T:&ES+3YW86QK*"!A<G)A>2@F
M)'1H:7,L)U]G971.;V1E)RD@+"`D<W1A<G1)9"`L("=I9D%R<F%Y)R`I.PH@
M("`@("`@(')E='5R;B`D<F5T.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*
M"B`@("`O*BH*("`@("H@("!T:&ES(&ES('5S960@9F]R('=A;&MI;F<@=&AR
M;W5G:"!T:&4@=')E92!S=')U8W1U<F4*("`@("H@("!U;G1I;"!A(&=I=F5N
M(&QE=F5L+"!T:&ES(&UE=&AO9"!S:&]U;&0@;VYL>2!B92!U<V5D(&)Y(&=E
M=$YO9&4*("`@("H*("`@("H@("!`<V5E("`@("`@("`F9V5T3F]D92@I"B`@
M("`J("`@0'-E92`@("`@("`@=V%L:R@I"B`@("`J("`@0'-E92`@("`@("`@
M7W=A;&LH*0H@("`@*B`@($!A8V-E<W,@("`@('!R:79A=&4*("`@("H@("!`
M=F5R<VEO;B`@("`R,#`Q+S$R+S$W"B`@("`J("`@0&%U=&AO<B`@("`@5V]L
M9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`
M<&%R86T@("`@("!A<G)A>2`@("1N;V1E("`@=&AE(&YO9&4@<&%S<V5D(&)Y
M(%]W86QK"B`@("`J("`@0')E='5R;B`@("`@;6EX960@("!E:71H97(@<F5T
M=7)N<R!T:&4@;F]D92P@;W(@;F]T:&EN9R!I9B!T:&4@;&5V96P@7V=E=$YO
M9&5-87A,979E;"!I<R!R96%C:&5D"B`@("`J+PH@("`@9G5N8W1I;VX@)E]G
M971.;V1E*"`F)&YO9&4@*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V=E
M=$YO9&5-87A,979E;"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/F=E=$QE
M=F5L*"1N;V1E6R=I9"==*2`\("1T:&ES+3Y?9V5T3F]D94UA>$QE=F5L*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)&YO9&4["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&YO9&4["B`@("!]("\O(&5N9"!O9B!F=6YC=&EO;@H*("`@("\J*@H@("`@
M*B`@(')E='5R;G,@:68@=&AE(&=I=F5N(&5L96UE;G0@:&%S(&%N>2!C:&EL
M9')E;@H@("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#$O,3(O,3<*("`@
M("H@("!`86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7
M;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@
M($!P87)A;2`@("`@(&EN=&5G97(@)&ED('1H92!I9"!O9B!T:&4@;F]D92!T
M;R!C:&5C:R!F;W(@8VAI;&1R96X*("`@("H@("!`<F5T=7)N("`@("!B;V]L
M96%N('1R=64@:68@=&AE(&YO9&4@:&%S(&-H:6QD<F5N"B`@("`J+PH@("`@
M9G5N8W1I;VX@:&%S0VAI;&1R96XH("1I9#TP("D*("`@('L*("`@("`@("!I
M9B@@:7-S970H)'1H:7,M/F1A=&%;)&ED75LG8VAI;&1R96XG72D@)B8@<VEZ
M96]F*"1T:&ES+3YD871A6R1I9%U;)V-H:6QD<F5N)UTI(#X@,"`I"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T@+R\@96YD(&]F(&9U;F-T:6]N"@H@("`@+RHJ"B`@("`J("`@<F5T=7)N
M<R!T:&4@8VAI;&1R96X@;V8@=&AE(&=I=F5N(&ED<PH@("`@*@H@("`@*B`@
M($!V97)S:6]N("`@(#(P,#$O,3(O,3<*("`@("H@("!`86-C97-S("`@("!P
M=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW
M;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;2`@("`@(&EN=&5G
M97(@)&ED('1H92!I9"!O9B!T:&4@;F]D92!T;R!C:&5C:R!F;W(@8VAI;&1R
M96X*("`@("H@("!`<&%R86T@("`@("!I;G1E9V5R('1H92!C:&EL9')E;B!O
M9B!H;W<@;6%N>2!L979E;',@<VAA;&P@8F4@<F5T=7)N960*("`@("H@("!`
M<F5T=7)N("`@("!B;V]L96%N('1R=64@:68@=&AE(&YO9&4@:&%S(&-H:6QD
M<F5N"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T0VAI;&1R96XH("1I9',@+"`D
M;&5V96QS/3$@*0H@("`@>PHO+T9)6%A-12`D;&5V96QS('1O(&)E(&EM<&QE
M;65N=&5D"B`@("`@("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1I9',I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1I9',@87,@
M)&%)9"D@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YH87-#:&EL9')E
M;B@@)&%)9"`I*2!["B`@("`@("`@("`@("`@("`@("`@)')E=%LD84ED72`]
M("1T:&ES+3YD871A6R1A261=6R=C:&EL9')E;B==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^:&%S0VAI;&1R96XH("1I9',@*2D@>PH@("`@("`@
M("`@("`@("`@)')E="`]("1T:&ES+3YD871A6R1I9'-=6R=C:&EL9')E;B==
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T
M.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*"B`@("`O*BH*("`@("H@("!R
M971U<FYS(&EF('1H92!G:79E;B!E;&5M96YT(&ES(&$@=F%L:60@;F]D90H@
M("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#$O,3(O,C$*("`@("H@("!`
M86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M
M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A
M;2`@("`@(&EN=&5G97(@)&ED('1H92!I9"!O9B!T:&4@;F]D92!T;R!C:&5C
M:R!F;W(@8VAI;&1R96X*("`@("H@("!`<F5T=7)N("`@("!B;V]L96%N('1R
M=64@:68@=&AE(&YO9&4@:&%S(&-H:6QD<F5N"B`@("`J+PH@("`@9G5N8W1I
M;VX@:7-.;V1E*"`D:60],"`I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3YD871A6R1I9%TI.PH@("`@?2`O+R!E;F0@;V8@9G5N8W1I;VX*
M"B`@("`O*BH*("`@("H@("!T:&ES(&ES(&9O<B!D96)U9V=I;F<L(&1U;7!S
M('1H92!E;G1I<F4@9&%T82UA<G)A>0H@("`@*B`@(&%N(&5X=')A(&UE=&AO
M9"!I<R!N965D960L('-I;F-E('1H:7,@87)R87D@8V]N=&%I;G,@<F5C=7)S
M:79E"B`@("`J("`@96QE;65N=',@=VAI8V@@;6%K92!A(&YO<FUA;"!P<FEN
M=%]F(&]R('9A<E]D=6UP(&YO="!S:&]W(&%L;"!T:&4@9&%T80H@("`@*@H@
M("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#$O,C$*("`@("H@("!`86-C97-S
M("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S
M:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A;7,@("`@
M(&UI>&5D("`@)&YO9&4@("!E:71H97(@=&AE(&ED(&]F('1H92!N;V1E('1O
M(&1U;7`L('1H:7,@=VEL;"!D=6UP(&5V97)Y=&AI;F<@8F5L;W<@=&AE(&=I
M=F5N(&YO9&4*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;W(@86X@87)R87D@;V8@;F]D97,L('1O(&1U;7`L('1H:7,@;VYL>2!D=6UP
M<R!T:&4@96QE;65N=',@<&%S<V5D(&%S(&%N(&%R<F%Y"B`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]R(#`@;W(@;F\@<&%R86UE=&5R
M(&EF('1H92!E;G1I<F4@=')E92!S:&%L;"!B92!D=6UP960*("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@>6]U('=A;G0@=&\@9'5M
M<"!O;FQY(&$@<VEN9VQE(&5L96UE;G0@<&%S<R!I="!A<R!A;B!A<G)A>2!U
M<VEN9PH@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@D96QE;65N="D*("`@("HO"B`@("!F=6YC=&EO;B!V87)$=6UP*"`D;F]D
M93TP("D*("`@('L*("`@("`@("`D9&]N=$1U;7`@/2!A<G)A>2@G<&%R96YT
M)RPG8VAI;&0G+"=C:&EL9')E;B<L)VYE>'0G+"=P<F5V:6]U<R<I.PH*("`@
M("`@("`O+R!I9B`D;F]D92!I<R!A;B!A<G)A>2P@=V4@87-S=6UE(&ET(&ES
M(&$@8V]L;&5C=&EO;B!O9B!E;&5M96YT<PH@("`@("`@(&EF*"`A:7-?87)R
M87DH)&YO9&4I("D*("`@("`@("`@("`@)&YO9&5S(#T@)'1H:7,M/F=E=$YO
M9&4H)&YO9&4I.R`@+R\@:68@)&YO9&4]/3`@=&AE;B!T:&4@96YT:7)E('1R
M964@:7,@<F5T<F5I=F5D"B`@("`@("`@("`@(`H@("`@("`@(&EF("AS:7IE
M;V8H)&YO9&4I*2!["B`@("`@("`@("`@('!R:6YT("<\=&%B;&4@8F]R9&5R
M/2(Q(CX\='(^/'1H/FYA;64\+W1H/B<["B`@("`@("`@("`@("1K97ES(#T@
M87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E=%)O;W0H
M*2!A<R`D:V5Y/3XD>"D@>PH@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D>"DI('L*("`@("`@("`@("`@("`@("`@("!P<FEN="`B/'1H/B1K97D\
M+W1H/B(["B`@("`@("`@("`@("`@("`@("`@)&ME>7-;72`]("1K97D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<')I
M;G0@(CPO='(^(CL*("`@("`@("`@("`@"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1N;V1E<R!A<R`D84YO9&4I('L*("`@("`@("`@("`@("`@('!R:6YT("<\
M='(^/'1D(&YO=W)A<#TB;F]W<F%P(CXG.PH@("`@("`@("`@("`@("`@)'!R
M969I>"`]("<G.PH@("`@("`@("`@("`@("`@9F]R*"1I/3`[)&D\)&%.;V1E
M6R=L979E;"==.R1I*RLI("1P<F5F:7@@+CT@)RT@)SL*("`@("`@("`@("`@
M("`@('!R:6YT("(D<')E9FEX('LD84YO9&5;)VYA;64G77T\+W1D/B(["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D84ME>2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&ME>2DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A;"`]("1A3F]D95LD84ME>5T@/R`D84YO
M9&5;)&%+97E=(#H@)R9N8G-P.R<["B`@("`@("`@("`@("`@("`@("`@("`@
M('!R:6YT("(\=&0^)'9A;#PO=&0^(CL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!P<FEN="`B/"]T
M<CXB.PH@("`@("`@("`@("!]("`*("`@("`@("`@("`@<')I;G0@(CPO=&%B
M;&4^(CL@("`@("`@("`@"B`@("`@("`@?2`@("`@("`@("`@(`H@("`@?2`O
M+R!E;F0@;V8@9G5N8W1I;VX*"@H*"@H*"B`@("`O+R,C(R!43T1/)W,@(R,C
M"@H@("`@+RHJ"B`@("`J("`@3D]4($E-4$Q%345.5$5$(%E%5`H@("`@*B`@
M(&-O<&EE<R!A('!A<G0@;V8@=&AE('1R964@=6YD97(@82!G:79E;B!P87)E
M;G0*("`@("H*("`@("H@("!`=F5R<VEO;B`@("`R,#`Q+S$R+S$Y"B`@("`J
M("`@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L
M9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`
M<&%R86T@("`@("`D<W)C260@("`@("!T:&4@:60@;V8@=&AE(&5L96UE;G0@
M=VAI8V@@:7,@8V]P:65D+"!A;&P@:71S(&-H:6QD<F5N(&%R92!C;W!I960@
M=&]O"B`@("`J("`@0'!A<F%M("`@("`@)&1E<W1)9"`@("`@=&AE(&ED('1H
M870@<VAA;&P@8F4@=&AE(&YE=R!P87)E;G0*("`@("H@("!`<F5T=7)N("`@
M("!B;V]L96%N("`@("!T<G5E(&]N('-U8V-E<W,*("`@("H*("`@("HO"B`@
M("!F=6YC=&EO;B!C;W!Y*"`D<W)C260@+"`D9&5S=$ED("D*("`@('L*("`@
M("`@("!I9B@@;65T:&]D7V5X:7-T<R@D=&AI<RT^9&%T85-O=7)C94-L87-S
M+"=C;W!Y)RD@*0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F1A=&%3;W5R
M8V5#;&%S<RT^8V]P>2@@)'-R8TED("P@)&1E<W1)9"`I.PH@("`@("`@(&5L
M<V4*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=%<G)O<B@@)VUE
M=&AO9"!N;W0@:6UP;&5M96YT960@>65T+B<@+"!?7TQ)3D5?7R`I.PHO*@H@
M("`@<F5M;W9E(&%L;"!A<G)A>2!E;&5M96YT<R!A9G1E<B`G<&%R96YT)R!S
M:6YC92!T:&]S92!H860@8F5E;B!C<F5A=&5D"B`@("!A;F0@<F5M;W9E(&ED
M(&%N9"!S970@<&%R96YT260@86YD('1H870@<VAO=6QD(&)E(&ET+"!B=6EL
M9"!T:&4@=')E92!A;F0@<&%S<R!I="!T;R!A9&1.;V1E"@H@("`@=&AO<V4@
M87)E('1H92!F:65L9',@:6X@;VYE(&1A=&$M96YT<GD*:60]/C0Q"G!A<F5N
M=$ED/3XS.0IN86UE/3Y*879A"G!A<F5N=#T^07)R87D*<')E=DED/3XU.`IP
M<F5V:6]U<ST^07)R87D*8VAI;&1)9#T^-S<*8VAI;&0]/D%R<F%Y"FYE>'1)
M9#T^,3`T"FYE>'0]/D%R<F%Y"F-H:6QD<F5N/3Y!<G)A>0IL979E;#T^,@H*
M("`@("`@("`D=&AI<RT^9V5T3F]D90H@("`@("`@(&9O<F5A8V@H("1T:&ES
M+3YD871A6R1S<F-)9%T@87,@)&ME>3T^)'9A;'5E("D*("`@("`@("`@("`@
M<')I;G0H(B1K97D]/B1V86QU93QB<CXB*3L**B\*("`@('T@+R\@96YD(&]F
M(&9U;F-T:6]N"@H*"GT@+R\@96YD(&]F(&-L87-S"C\^"@``````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O5')E92]%<G)O<BYP:'``````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,U,S0`,3`T,3<S-C,P
M,#0`,#(P,#0T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%=O;&9R86T@2W)I97-I;F<@
M/'=O;&9R86U`:W)I97-I;F<N9&4^("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("`D260Z($5R
M<F]R+G!H<"QV(#$N,R`R,#`S+S`Q+S`T(#$Q.C4V.C(W(&UJ($5X<"`D"@HO
M*BH**@HJ"BH@("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF
M<F%M0&MR:65S:6YG+F1E/@HJ("`@0'!A8VMA9V4@("`@5')E90HJ+PIC;&%S
M<R!4<F5E7T5R<F]R(&5X=&5N9',@4$5!4E]%<G)O<@I["B`@("`O*BH*("`@
M("H@("!`=F%R("!S=')I;F<@("`@<')E9FEX(&9O<B!E<G)O<B!M97-S86=E
M<RX*("`@("HO"B`@("!V87(@)&5R<F]R7VUE<W-A9V5?<')E9FEX(#T@(E1R
M964@17)R;W(Z("(["@H@("`@+RHJ"B`@("`J"B`@("`J"B`@("`J("`@0&%C
M8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0'9E<G-I;VX@("`@,C`P,B\P,R\P
M,PH@("`@*B`@($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R
M86U`:W)I97-I;F<N9&4^"B`@("`J("`@0'!A<F%M"B`@("`J("`@0')E='5R
M;@H@("`@*B\*("`@(&9U;F-T:6]N(%1R965?17)R;W(H("1M<V<@+"`D;&EN
M92`L("1F:6QE("P@)&UO9&4];G5L;"`L("1U<V5R:6YF;STG;F\@=7-E<FEN
M9F\G("D*("`@('L*("`@("`@("`D=&AI<RT^4$5!4E]%<G)O<B@@('-P<FEN
M=&8H(B5S(#QB<B\^:6X@)7,@6R5D72XB+"`D;7-G+"`D9FEL92P@)&QI;F4I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"`L("1M;V1E("P@
M;G5L;"P@)'5S97)I;F9O("D["B`@("!]"@I]("\O(&5N9"!O9B!C;&%S<PH_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U1R964O5')E92YP:'``````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S-3,W`#$P-#$W,S8S,#`T`#`Q
M-S8U-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!7;VQF<F%M($MR:65S:6YG(#QW;VQF
M<F%M0&MR:65S:6YG+F1E/B`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`@)$ED.B!4<F5E+G!H
M<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q.C4V.C(W(&UJ($5X<"`D"@IR97%U:7)E
M7V]N8V4H)U!%05(N<&AP)RD["@HO*BH**B`@('1H92!$0B!I;G1E<F9A8V4@
M=&\@=&AE('1R964@8VQA<W,**@HJ("`@0&%C8V5S<R`@("`@<'5B;&EC"BH@
M("!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S
M:6YG+F1E/@HJ("`@0'9E<G-I;VX@("`@,C`P,2\P-B\R-PHJ("`@0'!A8VMA
M9V4@("`@5')E90HJ+PIC;&%S<R!4<F5E(&5X=&5N9',@4$5!4@I["@H@("`@
M+RHJ"B`@("`J("`@<V5T=7`@86X@;V)J96-T('=H:6-H('=O<FMS(&]N('1R
M965S('1H870@87)E('1E;7!O<F%R:6QY('-A=F5D(&EN(&UE;6]R>0H@("`@
M*B`@(&1O;G0@=7-E('=I=&@@:'5G92!T<F5E<RP@<W5G9V5S=&5D(&ES(&$@
M;6%X:6UU;2!S:7IE(&]F('1R964@;V8*("`@("H@("!A8F]U="`Q,#`P+34P
M,#`@96QE;65N=',@<VEN8V4@=&AE(&5N=&ER92!T<F5E(&ES(')E860@870@
M;VYC92!F<F]M('1H92!D871A('-O=7)C92X*("`@("H@("!U<V4@=&AI<R!T
M;R!I;G-T86YC:6%T92!A(&-L87-S(&]F(&$@=')E92!I9B!Y;W4@:2YE+@H@
M("`@*B`@("T@("!N965D('1H92!E;G1I<F4@=')E92!A="!O;F-E"B`@("`J
M("`@+2`@('=A;G0@=&\@=V]R:R!O;B!T:&4@=')E92!W+V\@9&(M86-C97-S
M(&9O<B!E=F5R>2!C86QL"B`@("`J("`@<VEN8V4@=&AI<R!S970@;V8@8VQA
M<W-E<R!L;V%D<R!T:&4@96YT:7)E('1R964@:6YT;R!T:&4@;65M;W)Y+"!Y
M;W4@<VAO=6QD"B`@("`J("`@8F4@87=A<F4@86)O=70@=&AE('-I>F4@;V8@
M=&AE('1R964@>6]U('=O<FL@;VX@=7-I;F<@=&AI<R!C;&%S<PH@("`@*B`@
M(&9O<B!O;F4@>6]U('-H;W5L9"!K;F]W(&AO=R!E9F9I8VEE;G0@=&AI<R!K
M:6YD(&]F('1R964@8VQA<W,@:7,@;VX*("`@("H@("!Y;W5R(&1A=&$@<V]U
M<F-E("AI+F4N(&1B*2!A;F0@=VAA="!E9F9E8W0@:70@:&%S(')E861I;F<@
M=&AE(&5N=&ER92!T<F5E(&%T(&]N8V4N"B`@("`J("`@;VX@<VUA;&P@=')E
M97,L(&QI:V4@=7!T;R!A8F]U="`Q,#`P(&5L96UE;G1S(&%N(&EN<W1A;F-E
M(&]F('1H:7,@8VQA<W,*("`@("H@("!W:6QL(&=I=F4@>6]U('9E<GD@<&]W
M97)F=6P@;65A;G,@=&\@;6%N86=E+VUO9&EF>2!T:&4@=')E92P@;F\@;6%T
M=&5R(&9R;VT@=VAI8V@*("`@("H@("!D871A('-O=7)C92!I="!C;VUE<RP@
M96ET:&5R(&9R;VT@82!N97-T960M1$(L('-I;7!L92U$0BP@6$U,+49I;&4O
M4W1R:6YG(&]R"B`@("`J("`@=VAA=&5V97(@:7,@:6UP;&5M96YT960*("`@
M("H*("`@("H@("!`=F5R<VEO;B`@("`R,#`R+S`R+S`U"B`@("`J("`@0&%C
M8V5S<R`@("`@<'5B;&EC"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+
M<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T@
M("`@("!S=')I;F<@("1T>7!E("`@=&AE(&MI;F0@;V8@9&%T82!S;W5R8V4@
M=&AI<R!C;&%S<R!S:&%L;"!W;W)K(&]N(&EN:71I86QL>2P*("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@>6]U(&-A;B!S=&EL;"!S=VET
M8V@@;&%T97(L(&)Y('5S:6YG(")S971$871A4V]U<F-E(@H@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!I+F4N(&5X<&]R="!D871A
M(&9R;VT@82!$0B!T;R!834PL(&]R('=H871E=F5R(&EM<&QE;65N=&%T:6]N
M(&UI9VAT(&5X:7-T('-O;64@9&%Y"B`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-U<G)E;G1L>2!A=F%I;&%B;&4@='EP97,@87)E.B`G
M1$)S:6UP;&4G+"`G6$U,)PH@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!43T1/.B!$0FYE<W1E9"`H=VAI8V@@:2!T:&EN:R!S:&]U;&0@
M8F4@:6UP;&5M96YT960@869T97(@1'EN86UI8R]$0FYE<W1E9"P@<VEN8V4@
M:70@=V]U;&0@;VYL>2!N965D"B`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!U<V4@:70G<R!M971H;V1S
M('1O(&UA;F%G92!T:&4@=')E92D*("`@("H@("!`<&%R86T@("`@("`D9'-N
M("`@("1D<VX@("`@=&AE(&1S;BP@;W(@9FEL96YA;64L(&5T8RXL(&5M<'1Y
M(&DN92X@9F]R(%A-3"!I9B!Y;W4@=7-E('-E='5P0GE287=$871A"B`@("`J
M+PH@("`@9G5N8W1I;VX@)G-E='5P365M;W)Y*"`D='EP92`L("1D<VX])R<@
M+"`D;W!T:6]N<SUA<G)A>2@I("D*(R!I9B!A;GEO;F4@:VYO=W,@82!B971T
M97(@;F%M92!I="!W;W5L9"!B92!G<F5A="!T;R!C:&%N9V4@:70L('-I;F-E
M(")S971U<$UE;6]R>2(@:VEN9"!O9B!R969L96-T<R!I=`HC(&)U="!I('1H
M:6YK(&ET)W,@;F]T(&]B=FEO=7,@:68@>6]U(&1O;G0@:VYO=R!W:&%T(&ES
M(&UE86YT"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E*"=4<F5E+TUE;6]R
M>2YP:'`G*3L*"B`@("`@("`@<F5T=7)N(&YE=R!4<F5E7TUE;6]R>2@@)'1Y
M<&4@+"`D9'-N("P@)&]P=&EO;G,@*3L*("`@('T@+R\@96YD(&]F(&9U;F-T
M:6]N"@H@("`@+RHJ"B`@("`J("`@<V5T=7`@86X@;V)J96-T('1H870@=V]R
M:W,@;VX@=')E97,@=VAE<F4@96%C:"!E;&5M96YT*',I(&%R92!R96%D(&]N
M(&1E;6%N9"!F<F]M('1H92!G:79E;B!D871A('-O=7)C90H@("`@*B`@(&%C
M='5A;&QY('1H:7,@=V%S(&EN=&5N9&5D('1O('-E<G9E(&9O<B!N97-T960@
M=')E97,@=VAI8V@@87)E(')E860@9G)O;0H@("`@*B`@('1H92!D8B!U<"!O
M;B!D96UA;F0L('-I;F-E(&ET(&1O97-N="!M86ME('-E;G-E('1O(')E860@
M82!H=6=E('1R964@:6YT;PH@("`@*B`@('1H92!M96UO<GD@=VAE;B!Y;W4@
M;VYL>2!W86YT('1O(&%C8V5S<R!O;F4@;&5V96P@;V8@=&AI<R!T<F5E"B`@
M("`J"B`@("`J("`@:6X@<VAO<G0Z(&%N(&EN<W1A;F-E(')E='5R;F5D(&)Y
M('1H:7,@;65T:&]D('=O<FMS(&]N(&$@=')E92!B>2!M87!P:6YG"B`@("`J
M("`@979E<GD@<F5Q=65S="`H<W5C:"!A<R!G971#:&EL9"P@9V5T4&%R96YT
M("XN+BD@=&\@=&AE(&1A=&$@<V]U<F-E(&1E9FEN960@=&\@=V]R:R!O;@H@
M("`@*@H@("`@*B`@($!V97)S:6]N("`@(#(P,#(O,#(O,#4*("`@("H@("!`
M86-C97-S("`@("!P=6)L:6,*("`@("H@("!`875T:&]R("`@("!7;VQF<F%M
M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@("`@*B`@($!P87)A
M;0H@("`@*B\*("`@(&9U;F-T:6]N("9S971U<$1Y;F%M:6,H("1T>7!E("P@
M)&1S;B`L("1O<'1I;VYS/6%R<F%Y*"D@*0HC(")D>6YA;6EC(B!S=&%N9',@
M9F]R(')E=')E:79I;F<@82!T<F5E*&-H=6YK*2!D>6YA;6EC86QL>2!W:&5N
M(&YE961E9"P*(R!B971T97(@;F%M92!W;W5L9"!B92!G<F5A="`Z+2D*("`@
M('L*("`@("`@("!R97%U:7)E7V]N8V4H(E1R964O1'EN86UI8R\D='EP92YP
M:'`B*3L*"B`@("`@("`@)&-L87-S3F%M92`]("=4<F5E7T1Y;F%M:6-?)RXD
M='EP93L*("`@("`@("`D;V)J(#T@)B!N97<@)&-L87-S3F%M92@@)&1S;B`L
M("1O<'1I;VYS("D["B`@("`@("`@<F5T=7)N("1O8FH["B`@("!]("\O(&5N
M9"!O9B!F=6YC=&EO;@H*("`@("\J*@H@("`@*B`@('1H:7,@:7,@:G5S="!A
M('=R87!P97(@87)O=6YD('1H92!T=V\@<V5T=7`@;65T:&]D<R!A8F]V90H@
M("`@*B`@('-O;64@97AA;7!L92!C86QL<SH*("`@("H@("`\8V]D93X*("`@
M("H@("`D=')E92`](%1R964Z.G-E='5P*"`G1'EN86UI8U]$0FYE<W1E9"<@
M+"`G;7ES<6PZ+R]R;V]T0&QO8V%L:&]S="]T97-T)R`L(&%R<F%Y*"=T86)L
M92<]/B=N97-T9614<F5E)RD@*3L*("`@("H@("`D=')E92`](%1R964Z.G-E
M='5P*"`G365M;W)Y7T1"<VEM<&QE)R`L("=M>7-Q;#HO+W)O;W1`;&]C86QH
M;W-T+W1E<W0G("P@87)R87DH)W1A8FQE)ST^)W-I;7!L951R964G*2`I.PH@
M("`@*B`@("1T<F5E(#T@5')E93HZ<V5T=7`H("=-96UO<GE?6$U,)R`L("<O
M<&%T:"]T;R]S;VUE+WAM;"]F:6QE+GAM;"<@*3L*("`@("H@("`\+V-O9&4^
M"B`@("`J"B`@("`J("`@>6]U(&-A;B!C86QL('1H92!F;VQL;W=I;F<@=&]O
M+"!B=70@=&AE(&9U;F-T:6]N<R]C;&%S<V5S(&%R92!N;W0@:6UP;&5M96YT
M960@>65T"B`@("`J("`@;W(@;F]T(&9I;FES:&5D"B`@("`J("`@/&-O9&4^
M"B`@("`J("`@)'1R964@/2!4<F5E.CIS971U<"@@)TUE;6]R>5]$0FYE<W1E
M9"<@+"`G;7ES<6PZ+R]R;V]T0&QO8V%L:&]S="]T97-T)R`L(&%R<F%Y*"=T
M86)L92<]/B=N97-T9614<F5E)RD@*3L*("`@("H@("`D=')E92`](%1R964Z
M.G-E='5P*"`G1'EN86UI8U]834PG("P@)R]P871H+W1O+W-O;64O>&UL+V9I
M;&4N>&UL)R`I.PH@("`@*B`@(#PO8V]D93X*("`@("H*("`@("H@("!A;F0@
M=&AO<V4@=V]U;&0@8F4@<F5A;&QY(&-O;VP@=&\@:&%V92!O;F4@9&%Y.@H@
M("`@*B`@($Q$05`L($9I;&5S>7-T96TL(%=31$PL("XN+@H@("`@*@H@("`@
M*B`@($!A8V-E<W,@("`@('!R:79A=&4*("`@("H@("!`=F5R<VEO;B`@("`R
M,#`R+S`S+S`W"B`@("`J("`@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN
M9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("`@("H@("!`<&%R86T*("`@("H@
M("!`<F5T=7)N"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T=7`H("1T>7!E("P@
M)&1S;B`L("1O<'1I;VYS/6%R<F%Y*"D@*0H@("`@>PH@("`@("`@("1T>7!E
M(#T@97AP;&]D92@@)U\G("P@)'1Y<&4@*3L*("`@("`@("`D;65T:&]D(#T@
M)W-E='5P)RXD='EP95LP73L*("`@("`@("!R971U<FX@5')E93HZ)&UE=&AO
M9"@@)'1Y<&5;,5T@+"`D9'-N("P@)&]P=&EO;G,@*3L*("`@('T*"GT*"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O5&5X="\`````````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#0`,#$V,C8U
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]497AT+U=I:VDO````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,S`P-``P,3<Q-S``(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U1E>'0O5VEK:2]2=6QE+P``````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`T`#`R,#`W-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O5&5X="]7:6MI+U)U;&4O9&5L:6UI=&5R+G!H
M<```````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4W,#0`,3`T,3<S-C,P,#0`
M,#(R-3<Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI
M9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S
M(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!0
M2%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H
M('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@
M("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L
M92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!0875L($TN($IO;F5S(#QP;6IO
M;F5S0&-I87=E8BYN970^("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&1E;&EM
M:71E<BYP:'`L=B`Q+C,@,C`P-"\P,2\S,2`Q-3HU,CHP."!P;6IO;F5S($5X
M<"`D"@H*+RHJ"BH@"BH@5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7
M:6MI7U)U;&4@=&\@9FEN9"!I;G-T86YC97,@;V8@=&AE(&1E;&EM:71E<@HJ
M(&-H87)A8W1E<B!A;')E861Y(&5M8F5D9&5D(&EN('1H92!S;W5R8V4@=&5X
M=#L@:70@97AT<F%C=',@=&AE;2!A;F0@<F5P;&%C97,**B!T:&5M('=I=&@@
M82!D96QI;6ET960@=&]K96XL('1H96X@<F5N9&5R<R!T:&5M(&%S('1H92!D
M96QI;6ET97(@:71S96QF"BH@=VAE;B!T:&4@=&%R9V5T(&9O<FUA="!I<R!8
M2%1-3"X**@HJ($!A=71H;W(@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W
M96(N;F5T/@HJ"BH@0'!A8VMA9V4@5&5X=%]7:6MI"BH**B\*"F-L87-S(%1E
M>'1?5VEK:5]2=6QE7V1E;&EM:71E<B!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE
M('L*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!#;VYS=')U8W1O<BX@($]V
M97)R:61E<R!T:&4@5&5X=%]7:6MI7U)U;&4@8V]N<W1R=6-T;W(@<V\@=&AA
M="!W90H@("`@*B!C86X@<V5T('1H92`D<F5G97@@<')O<&5R='D@9'EN86UI
M8V%L;'D@*'=E(&YE960@=&\@:6YC;'5D92!T:&4*("`@("H@5&5X=%]7:6MI
M("1D96QI;2!C:&%R86-T97(N"B`@("`J(`H@("`@*B!`<&%R86T@;V)J96-T
M("8D;V)J(%1H92!C86QL:6YG(")P87)E;G0B(%1E>'1?5VEK:2!O8FIE8W0N
M"B`@("`J(`H@("`@*B!`<&%R86T@<W1R:6YG("1N86UE(%1H92!T;VME;B!N
M86UE('1O('5S92!F;W(@=&AI<R!R=6QE+@H@("`@*B`*("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N(%1E>'1?5VEK:5]2=6QE7V1E;&EM:71E<B@F)&]B:BP@
M)&YA;64I"B`@("!["B`@("`@("`@<&%R96YT.CI497AT7U=I:VE?4G5L92@D
M;V)J+"`D;F%M92D["B`@("`@("`@)'1H:7,M/G)E9V5X(#T@)R\G("X@)'1H
M:7,M/E]W:6MI+3YD96QI;2`N("<O)SL*("`@('T*("`@(`H@("`@"B`@("`O
M*BH*("`@("H@"B`@("`J($=E;F5R871E<R!A('1O:V5N(&5N=')Y(&9O<B!T
M:&4@;6%T8VAE9"!T97AT+B`@5&]K96X@;W!T:6]N<R!A<F4Z"B`@("`J(`H@
M("`@*B`G=&5X="<@/3X@5&AE(&9U;&P@;6%T8VAE9"!T97AT+@H@("`@*B`*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y
M("8D;6%T8VAE<R!4:&4@87)R87D@;V8@;6%T8VAE<R!F<F]M('!A<G-E*"DN
M"B`@("`J"B`@("`J($!R971U<FX@02!D96QI;6ET960@=&]K96X@;G5M8F5R
M('1O(&)E('5S960@87,@82!P;&%C96AO;&1E<B!I;@H@("`@*B!T:&4@<V]U
M<F-E('1E>'0N"B`@("`J"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P<F]C
M97-S*"8D;6%T8VAE<RD*("`@('L@("`@"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YA9&14;VME;B@I.PH@("`@?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*
M("`@("H@4F5N9&5R<R!A('1O:V5N(&EN=&\@=&5X="!M871C:&EN9R!T:&4@
M<F5Q=65S=&5D(&9O<FUA="X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J(`H@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@5&AE(")O<'1I
M;VYS(B!P;W)T:6]N(&]F('1H92!T;VME;B`H<V5C;VYD"B`@("`J(&5L96UE
M;G0I+@H@("`@*B`*("`@("H@0')E='5R;B!S=')I;F<@5&AE('1E>'0@<F5N
M9&5R960@9G)O;2!T:&4@=&]K96X@;W!T:6]N<RX*("`@("H@"B`@("`J+PH@
M("`@"B`@("!F=6YC=&EO;B!R96YD97)8:'1M;"@D;W!T:6]N<RD*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]W:6MI+3YD96QI;3L*("`@('T*?0H_
M/@``````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]497AT+U=I:VDO4G5L92]R87<N<&AP````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-3$U,0`Q,#0Q-S,V,S`P-``P,C$T,#``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!V97)S:6]N
M(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<G,Z(%!A=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@<F%W+G!H<"QV(#$N,2`R,#`T+S`Q
M+S`T(#`Q.C,U.C(S('!M:F]N97,@17AP("0*"@HO*BH**B`**B!4:&ES(&-L
M87-S(&EM<&QE;65N=',@82!497AT7U=I:VD@<G5L92!T;R!F:6YD('-E8W1I
M;VYS(&]F('1H92!S;W5R8V4**B!T97AT('1H870@87)E(&YO="!T;R!B92!P
M<F]C97-S960@8GD@5&5X=%]7:6MI+B`@5&AE<V4@8FQO8VMS(&]F(")R87<B
M"BH@=&5X="!W:6QL(&)E(')E;F1E<F5D(&%S('1H97D@=V5R92!F;W5N9"X*
M*@HJ($!A=71H;W(@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T
M/@HJ"BH@0'!A8VMA9V4@5&5X=%]7:6MI"BH**B\*"F-L87-S(%1E>'1?5VEK
M:5]2=6QE7W)A=R!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@("`@
M"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!R96=U;&%R(&5X<')E<W-I;VX@
M=7-E9"!T;R!F:6YD('-O=7)C92!T97AT(&UA=&-H:6YG('1H:7,*("`@("H@
M<G5L92X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@
M*B!`=F%R('-T<FEN9PH@("`@*B`*("`@("HO"B`@("`*("`@('9A<B`D<F5G
M97@@/2`B+V!@8"@N*BE@8&`O52(["B`@("`*("`@(`H@("`@+RHJ"B`@("`J
M(`H@("`@*B!'96YE<F%T97,@82!T;VME;B!E;G1R>2!F;W(@=&AE(&UA=&-H
M960@=&5X="X@(%1O:V5N(&]P=&EO;G,@87)E.@H@("`@*B`*("`@("H@)W1E
M>'0G(#T^(%1H92!F=6QL(&UA=&-H960@=&5X="X*("`@("H@"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J"B`@("`J($!P87)A;2!A<G)A>2`F)&UA=&-H
M97,@5&AE(&%R<F%Y(&]F(&UA=&-H97,@9G)O;2!P87)S92@I+@H@("`@*@H@
M("`@*B!`<F5T=7)N($$@9&5L:6UI=&5D('1O:V5N(&YU;6)E<B!T;R!B92!U
M<V5D(&%S(&$@<&QA8V5H;VQD97(@:6X*("`@("H@=&AE('-O=7)C92!T97AT
M+@H@("`@*@H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<')O8V5S<R@F)&UA
M=&-H97,I"B`@("!["B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G=&5X="<@
M/3X@)&UA=&-H97-;,5TI.PH@("`@("`@(')E='5R;B`D=&AI<RT^861D5&]K
M96XH)&]P=&EO;G,I.PH@("`@?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*
M("`@("H@4F5N9&5R<R!A('1O:V5N(&EN=&\@=&5X="!M871C:&EN9R!T:&4@
M<F5Q=65S=&5D(&9O<FUA="X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J(`H@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@5&AE(")O<'1I
M;VYS(B!P;W)T:6]N(&]F('1H92!T;VME;B`H<V5C;VYD"B`@("`J(&5L96UE
M;G0I+@H@("`@*B`*("`@("H@0')E='5R;B!S=')I;F<@5&AE('1E>'0@<F5N
M9&5R960@9G)O;2!T:&4@=&]K96X@;W!T:6]N<RX*("`@("H@"B`@("`J+PH@
M("`@"B`@("!F=6YC=&EO;B!R96YD97)8:'1M;"@D;W!T:6]N<RD*("`@('L*
M("`@("`@("!R971U<FX@)&]P=&EO;G-;)W1E>'0G73L*("`@('T*?0H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U1E>'0O5VEK:2]2=6QE
M+VQI<W0N<&AP````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R-C0T
M`#$P-#$W,S8S,#`T`#`R,34W,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4&%U;"!-
M+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!L:7-T+G!H<"QV(#$N,2`R,#`T+S`Q+S`T(#`Q.C,U.C(S('!M
M:F]N97,@17AP("0*"@HO*BH**B`**B!4:&ES(&-L87-S(&EM<&QE;65N=',@
M82!497AT7U=I:VE?4G5L92!T;R!F:6YD('-O=7)C92!T97AT(&UA<FME9"!A
M<PHJ(&$@8G5L;&5T960@;W(@;G5M8F5R960@;&ES="X@($EN('-H;W)T+"!I
M9B!A(&QI;F4@<W1A<G1S('=I=&@@)RH@)R!T:&5N"BH@:70@:7,@82!B=6QL
M970@;&ES="!I=&5M.R!I9B!A(&QI;F4@<W1A<G1S('=I=&@@)R,@)R!T:&5N
M(&ET(&ES(&$@"BH@;G5M8F5R(&QI<W0@:71E;2X@(%-P86-E<R!I;B!F<F]N
M="!O9B!T:&4@*B!O<B`C(&EN9&EC871E(&%N(&EN9&5N=&5D"BH@<W5B+6QI
M<W0N("!4:&4@;&ES="!I=&5M<R!M=7-T(&)E(&]N('-E<75E;G1I86P@;&EN
M97,@*&YO(&)L86YK(&QI;F5S"BH@8F5T=V5E;B!T:&5M*2`M+2!A(&)L86YK
M(&QI;F4@:6YD:6-A=&5S('1H92!B96=I;FYI;F<@;V8@82!N97<@;&ES="X*
M*@HJ($!A=71H;W(@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T
M/@HJ"BH@0'!A8VMA9V4@5&5X=%]7:6MI"BH**B\*"F-L87-S(%1E>'1?5VEK
M:5]2=6QE7VQI<W0@97AT96YD<R!497AT7U=I:VE?4G5L92!["B`@("`*("`@
M(`H@("`@+RHJ"B`@("`J(`H@("`@*B!4:&4@<F5G=6QA<B!E>'!R97-S:6]N
M('5S960@=&\@<&%R<V4@=&AE('-O=7)C92!T97AT(&%N9"!F:6YD"B`@("`J
M(&UA=&-H97,@8V]N9F]R;6EN9R!T;R!T:&ES(')U;&4N("!5<V5D(&)Y('1H
M92!P87)S92@I(&UE=&AO9"X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J(`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B`*("`@("H@0'-E92!P
M87)S92@I"B`@("`J(`H@("`@*B\*("`@(`H@("`@=F%R("1R96=E>"`]("<O
M7&XH*%PJ?",I("XJ7&XI*#\A('LP+'TH7"I\(RDI+U5S)SL*("`@(`H@("`@
M"B`@("`O*BH*("`@("H@"B`@("`J($=E;F5R871E<R!A(')E<&QA8V5M96YT
M(&9O<B!T:&4@;6%T8VAE9"!T97AT+B`@5&]K96X@;W!T:6]N<R!A<F4Z"B`@
M("`J(`H@("`@*B`G='EP92<@/3X*("`@("H@("`@("=B=6QL971?<W1A<G0G
M(#H@=&AE('-T87)T(&]F(&$@8G5L;&5T(&QI<W0*("`@("H@("`@("=B=6QL
M971?96YD)R`@(#H@=&AE(&5N9"!O9B!A(&)U;&QE="!L:7-T"B`@("`J("`@
M("`G;G5M8F5R7W-T87)T)R`Z('1H92!S=&%R="!O9B!A(&YU;6)E<B!L:7-T
M"B`@("`J("`@("`G;G5M8F5R7V5N9"<@("`Z('1H92!E;F0@;V8@82!N=6UB
M97(@;&ES=`H@("`@*B`@("`@)VET96U?<W1A<G0G("`@.B!T:&4@<W1A<G0@
M;V8@:71E;2!T97AT("AB=6QL970@;W(@;G5M8F5R*0H@("`@*B`@("`@)VET
M96U?96YD)R`@("`@.B!T:&4@96YD(&]F(&ET96T@=&5X="`H8G5L;&5T(&]R
M(&YU;6)E<BD*("`@("H@("`@("=U;FMN;W=N)R`@("`@(#H@=6YK;F]W;B!T
M>7!E(&]F(&QI<W0@;W(@:71E;0H@("`@*@H@("`@*B`G;&5V96PG(#T^('1H
M92!I;F1E;G0@;&5V96P@*#`@9F]R('1H92!F:7)S="!L979E;"P@,2!F;W(@
M=&AE"B`@("`J('-E8V]N9"P@971C*0H@("`@*@H@("`@*B`G8V]U;G0G(#T^
M('1H92!L:7-T(&ET96T@;G5M8F5R(&%T('1H:7,@;&5V96PN(&YO="!N965D
M960@9F]R"B`@("`J('AH=&UL+"!B=70@=F5R>2!U<V5F=6P@9F]R(%!$1B!A
M;F0@4E1&+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H*("`@
M("H@0'!A<F%M(&%R<F%Y("8D;6%T8VAE<R!4:&4@87)R87D@;V8@;6%T8VAE
M<R!F<F]M('!A<G-E*"DN"B`@("`J"B`@("`J($!R971U<FX@02!S97)I97,@
M;V8@=&5X="!A;F0@9&5L:6UI=&5D('1O:V5N<R!M87)K:6YG('1H92!D:69F
M97)E;G0*("`@("H@;&ES="!T97AT(&%N9"!L:7-T(&5L96UE;G1S+@H@("`@
M*@H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<')O8V5S<R@F)&UA=&-H97,I
M"B`@("!["B`@("`@("`@+R\@=&AE(')E<&QA8V5M96YT('1E>'0@=V4@=VEL
M;"!R971U<FX*("`@("`@("`D<F5T=7)N(#T@)R<["B`@("`@("`@"B`@("`@
M("`@+R\@=&AE(&QI<W0@;V8@<&]S="UP<F]C97-S:6YG(&UA=&-H97,*("`@
M("`@("`D;&ES="`](&%R<F%Y*"D["B`@("`@("`@"B`@("`@("`@+R\@82!S
M=&%C:R!O9B!L:7-T+7-T87)T(&%N9"!L:7-T+65N9"!T>7!E<SL@=V4@:V5E
M<"!T:&ES"B`@("`@("`@+R\@<V\@=&AA="!W92!K;F]W('=H870@:VEN9"!O
M9B!L:7-T('=E)W)E('=O<FMI;F<@=VET:`H@("`@("`@("\O("AB=6QL970@
M;W(@;G5M8F5R*2!A;F0@=VAA="!I;F1E;G0@;&5V96P@=V4G<F4@870N"B`@
M("`@("`@)'-T86-K(#T@87)R87DH*3L*("`@("`@("`*("`@("`@("`O+R!T
M:&4@:71E;2!C;W5N="!I<R!T:&4@;G5M8F5R(&]F(&QI<W0@:71E;7,@9F]R
M(&%N>0H@("`@("`@("\O(&=I=F5N(&QI<W0M='EP92!O;B!T:&4@<W1A8VL*
M("`@("`@("`D:71E;6-O=6YT(#T@87)R87DH*3L*("`@("`@("`*("`@("`@
M("`O+R!P;W!U;&%T92`D;&ES="!W:71H('1H:7,@<V5T(&]F(&UA=&-H97,N
M("1M871C:&5S6S%=(&ES('1H90H@("`@("`@("\O('1E>'0@;6%T8VAE9"!A
M<R!A(&QI<W0@<V5T(&)Y('!A<G-E*"DN"B`@("`@("`@<')E9U]M871C:%]A
M;&PH"B`@("`@("`@("`@("<]7B@@>S`L?2DH7"I\(RD@*"XJ*20]56US)RP*
M("`@("`@("`@("`@)&UA=&-H97-;,5TL"B`@("`@("`@("`@("1L:7-T+`H@
M("`@("`@("`@("!04D5'7U-%5%]/4D1%4@H@("`@("`@("D["B`@("`@("`@
M"B`@("`@("`@+R\@;&]O<"!T:')O=6=H(&5A8V@@;&ES="UI=&5M(&5L96UE
M;G0N"B`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R`D=F%L6S!=(&ES('1H92!F
M=6QL(&UA=&-H960@;&ES="UI=&5M(&QI;F4*("`@("`@("`@("`@+R\@)'9A
M;%LQ72!I<R!T:&4@;G5M8F5R(&]F(&EN:71I86P@<W!A8V5S("AI;F1E;G0@
M;&5V96PI"B`@("`@("`@("`@("\O("1V86Q;,ET@:7,@=&AE(&QI<W0@:71E
M;2!T>7!E("@J(&]R(",I"B`@("`@("`@("`@("\O("1V86Q;,UT@:7,@=&AE
M(&QI<W0@:71E;2!T97AT"B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!H
M;W<@;6%N>2!L979E;',@87)E('=E(&EN9&5N=&5D/R`H,2!M96%N<R!T:&4@
M(G)O;W0B"B`@("`@("`@("`@("\O(&QI<W0@;&5V96PL(&YO(&EN9&5N=&EN
M9RXI"B`@("`@("`@("`@("1L979E;"`]('-T<FQE;B@D=F%L6S%=*2`K(#$[
M"B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!G970@=&AE(&QI<W0@:71E
M;2!T>7!E"B`@("`@("`@("`@(&EF("@D=F%L6S)=(#T]("<J)RD@>PH@("`@
M("`@("`@("`@("`@)'1Y<&4@/2`G8G5L;&5T)SL*("`@("`@("`@("`@?2!E
M;'-E:68@*"1V86Q;,ET@/3T@)R,G*2!["B`@("`@("`@("`@("`@("`D='EP
M92`]("=N=6UB97(G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'1Y<&4@/2`G=6YK;F]W;B<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@"B`@("`@("`@("`@("\O(&=E="!T:&4@=&5X="!O9B!T:&4@;&ES
M="!I=&5M"B`@("`@("`@("`@("1T97AT(#T@)'9A;%LS73L*("`@("`@("`@
M("`@"B`@("`@("`@("`@("\O(&%D9"!A(&QE=F5L('1O('1H92!L:7-T/PH@
M("`@("`@("`@("!I9B`H)&QE=F5L(#X@8V]U;G0H)'-T86-K*2D@>PH@("`@
M("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`O+R!T:&4@8W5R<F5N="!I
M;F1E;G0@;&5V96P@:7,@9W)E871E<B!T:&%N('1H90H@("`@("`@("`@("`@
M("`@+R\@;G5M8F5R(&]F('-T86-K(&5L96UE;G1S+"!S;R!W92!M=7-T(&)E
M('-T87)T:6YG"B`@("`@("`@("`@("`@("`O+R!A(&YE=R!L:7-T+B`@<'5S
M:"!T:&4@;F5W(&QI<W0@='EP92!O;G1O('1H90H@("`@("`@("`@("`@("`@
M+R\@<W1A8VLN+BX*("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'-T86-K
M+"`D='EP92D["B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("\O
M("XN+F%N9"!A9&0@82!L:7-T+7-T87)T('1O:V5N('1O('1H92!R971U<FXN
M"B`@("`@("`@("`@("`@("`D<F5T=7)N("X]("1T:&ES+3YA9&14;VME;B@*
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`@("`@)W1Y<&4G(#T^("1T>7!E("X@)U]S=&%R="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("=L979E;"<@/3X@)&QE=F5L("T@,0H@("`@("`@("`@
M("`@("`@("`@("D*("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@"B`@("`@("`@("`@("\O(')E;6]V92!A(&QE=F5L(&9R
M;VT@=&AE(&QI<W0_"B`@("`@("`@("`@('=H:6QE("AC;W5N="@D<W1A8VLI
M(#X@)&QE=F5L*2!["B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@
M("\O('-O('=E(&1O;B=T(&ME97`@8V]U;G1I;F<@=&AE('-T86-K+"!W92!S
M970@=7`@82!T96UP"B`@("`@("`@("`@("`@("`O+R!V87(@9F]R('1H92!C
M;W5N="X@("TQ(&)E8W5A<V4@=V4G<F4@9V]I;F<@=&\@<&]P('1H90H@("`@
M("`@("`@("`@("`@+R\@<W1A8VL@:6X@=&AE(&YE>'0@8V]M;6%N9"X@("1T
M;7`@=VEL;"!T:&5N(&5Q=6%L('1H90H@("`@("`@("`@("`@("`@+R\@8W5R
M<F5N="!L979E;"!O9B!I;F1E;G0N"B`@("`@("`@("`@("`@("`D=&UP(#T@
M8V]U;G0H)'-T86-K*2`M(#$["B`@("`@("`@("`@("`@("`*("`@("`@("`@
M("`@("`@("\O(&%S(&QO;F<@87,@=&AE('-T86-K(&-O=6YT(&ES(&=R96%T
M97(@=&AA;B!T:&4*("`@("`@("`@("`@("`@("\O(&-U<G)E;G0@:6YD96YT
M(&QE=F5L+"!W92!N965D('1O(&5N9"!L:7-T('1Y<&5S+B`*("`@("`@("`@
M("`@("`@("\O(&-O;G1I;G5E(&%D9&EN9R!E;F0M;&ES="!T;VME;G,@=6YT
M:6P@=&AE('-T86-K(&-O=6YT"B`@("`@("`@("`@("`@("`O+R!A;F0@=&AE
M(&EN9&5N="!L979E;"!A<F4@=&AE('-A;64N"B`@("`@("`@("`@("`@("`D
M<F5T=7)N("X]("1T:&ES+3YA9&14;VME;B@*("`@("`@("`@("`@("`@("`@
M("!A<G)A>2`H"B`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B!A
M<G)A>5]P;W`H)'-T86-K*2`N("=?96YD)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)VQE=F5L)R`]/B`D=&UP"B`@("`@("`@("`@("`@("`@("`@*0H@
M("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@(`H@("`@("`@("`@
M("`@("`@+R\@<F5S970@=&\@=&AE(&-U<G)E;G0@*'!R979I;W5S*2!L:7-T
M('1Y<&4@<V\@=&AA=`H@("`@("`@("`@("`@("`@+R\@=&AE(&YE=R!L:7-T
M(&ET96T@;6%T8VAE<R!T:&4@<')O<&5R(&QI<W0@='EP92X*("`@("`@("`@
M("`@("`@("1T>7!E(#T@)'-T86-K6R1T;7`@+2`Q73L*("`@("`@("`@("`@
M("`@(`H@("`@("`@("`@("`@("`@+R\@<F5S970@=&AE(&ET96T@8V]U;G0@
M9F]R('1H92!P;W!P960@:6YD96YT(&QE=F5L"B`@("`@("`@("`@("`@("`D
M:71E;6-O=6YT6R1T;7`@*R`Q72`](#`["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@"B`@("`@("`@("`@("\O(&%D9"!T;R!T:&4@:71E;2!C;W5N="!F
M;W(@=&AI<R!L:7-T("AT86MI;F<@:6YT;R!A8V-O=6YT"B`@("`@("`@("`@
M("\O('=H:6-H(&QE=F5L('=E(&%R92!A="DN"B`@("`@("`@("`@(&EF("@A
M(&ES<V5T*"1I=&5M8V]U;G1;)&QE=F5L72DI('L*("`@("`@("`@("`@("`@
M("\O(&9I<G-T(&-O=6YT"B`@("`@("`@("`@("`@("`D:71E;6-O=6YT6R1L
M979E;%T@/2`Q.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+R\@:6YC<F5M96YT(&-O=6YT"B`@("`@("`@("`@("`@("`D:71E;6-O
M=6YT6R1L979E;%TK*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`*("`@
M("`@("`@("`@+R\@8W)E871E(&$@;&ES="UI=&5M('-T87)T:6YG('1O:V5N
M+@H@("`@("`@("`@("`D<W1A<G0@/2`D=&AI<RT^861D5&]K96XH"B`@("`@
M("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G='EP92<@
M/3X@)VET96U?<W1A<G0G+`H@("`@("`@("`@("`@("`@("`@("=L979E;"<@
M/3X@)&QE=F5L+`H@("`@("`@("`@("`@("`@("`@("=C;W5N="<@/3X@)&ET
M96UC;W5N=%LD;&5V96Q="B`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@
M("D["B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!C<F5A=&4@82!L:7-T
M+6ET96T@96YD:6YG('1O:V5N+@H@("`@("`@("`@("`D96YD(#T@)'1H:7,M
M/F%D9%1O:V5N*`H@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)W1Y<&4G(#T^("=I=&5M7V5N9"<L"B`@("`@("`@("`@("`@
M("`@("`@)VQE=F5L)R`]/B`D;&5V96PL"B`@("`@("`@("`@("`@("`@("`@
M)V-O=6YT)R`]/B`D:71E;6-O=6YT6R1L979E;%T*("`@("`@("`@("`@("`@
M("D*("`@("`@("`@("`@*3L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O
M(&%D9"!T:&4@<W1A<G1I;F<@=&]K96XL(&QI<W0M:71E;2!T97AT+"!A;F0@
M96YD:6YG('1O:V5N"B`@("`@("`@("`@("\O('1O('1H92!R971U<FXN"B`@
M("`@("`@("`@("1R971U<FX@+CT@)'-T87)T("X@)'9A;%LS72`N("1E;F0[
M"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O('1H92!L87-T(&QI<W0M
M:71E;2!M87D@:&%V92!B965N(&EN9&5N=&5D+B`@9V\@=&AR;W5G:"!T:&4*
M("`@("`@("`O+R!L:7-T+71Y<&4@<W1A8VL@86YD(&-R96%T92!E;F0M;&ES
M="!T;VME;G,@=6YT:6P@=&AE('-T86-K"B`@("`@("`@+R\@:7,@96UP='DN
M"B`@("`@("`@=VAI;&4@*&-O=6YT*"1S=&%C:RD@/B`P*2!["B`@("`@("`@
M("`@("1R971U<FX@+CT@)'1H:7,M/F%D9%1O:V5N*`H@("`@("`@("`@("`@
M("`@87)R87D@*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B!A<G)A
M>5]P;W`H)'-T86-K*2`N("=?96YD)RP*("`@("`@("`@("`@("`@("`@("`G
M;&5V96PG(#T^(&-O=6YT*"1S=&%C:RD*("`@("`@("`@("`@("`@("D*("`@
M("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@=V4G
M<F4@9&]N92$@('-E;F0@8F%C:R!T:&4@<F5P;&%C96UE;G0@=&5X="X*("`@
M("`@("!R971U<FX@)')E='5R;CL*("`@('T*("`@(`H@("`@"B`@("`O*BH*
M("`@("H@"B`@("`J(%)E;F1E<G,@82!T;VME;B!I;G1O('1E>'0@;6%T8VAI
M;F<@=&AE(')E<75E<W1E9"!F;W)M870N"B`@("`J(`H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS(%1H
M92`B;W!T:6]N<R(@<&]R=&EO;B!O9B!T:&4@=&]K96X@*'-E8V]N9`H@("`@
M*B!E;&5M96YT*2X*("`@("H@"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!T
M97AT(')E;F1E<F5D(&9R;VT@=&AE('1O:V5N(&]P=&EO;G,N"B`@("`J(`H@
M("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<F5N9&5R6&AT;6PH)&]P=&EO;G,I
M"B`@("!["B`@("`@("`@+R\@;6%K92!N:6-E('9A<FEA8FQE<R`H='EP92P@
M;&5V96PL(&-O=6YT*0H@("`@("`@(&5X=')A8W0H)&]P=&EO;G,I.PH@("`@
M("`@(`H@("`@("`@("\O('-E="!U<"!I;F1E;G1I;F<@<V\@=&AA="!T:&4@
M<F5S=6QT<R!L;V]K(&YI8V4[('=E(&1O('1H:7,*("`@("`@("`O+R!I;B!T
M=V\@<W1E<',@=&\@879O:60@<W1R7W!A9"!M871H96UA=&EC<RX@(#LM*0H@
M("`@("`@("1P860@/2!S=')?<&%D*"<G+"`D;&5V96PL(")<="(I.PH@("`@
M("`@("1P860@/2!S=')?<F5P;&%C92@B7'0B+"`G("`@("<L("1P860I.PH@
M("`@("`@(`H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`*("`@
M("`@("!C87-E("=B=6QL971?<W1A<G0G.@H@("`@("`@("`@("!R971U<FX@
M)'!A9"`N("(\=6P^7&XB.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("`*
M("`@("`@("!C87-E("=B=6QL971?96YD)SH*("`@("`@("`@("`@<F5T=7)N
M("1P860@+B`B/"]U;#Y<;B(["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(`H@("`@("`@(&-A<V4@)VYU;6)E<E]S=&%R="<Z"B`@("`@("`@("`@(')E
M='5R;B`D<&%D("X@(CQO;#Y<;B(["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@(`H@("`@("`@(&-A<V4@)VYU;6)E<E]E;F0G.@H@("`@("`@("`@("!R
M971U<FX@)'!A9"`N("(\+V]L/EQN(CL*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@"B`@("`@("`@8V%S92`G:71E;5]S=&%R="<Z"B`@("`@("`@("`@
M(')E='5R;B`D<&%D("X@(CQL:3XB.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`*("`@("`@("!C87-E("=I=&5M7V5N9"<Z"B`@("`@("`@("`@(')E
M='5R;B`B/"]L:3Y<;B(["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(`H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("`*("`@("`@("!]"B`@("!]"GT*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]497AT+U=I:VDO4G5L92]D969L:7-T+G!H<```````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C(P,0`Q,#0Q-S,V,S`P-``P,C(R,S,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(
M4"!V97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(
M4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO
M+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@
M<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<G,Z(%!A=6P@32X@2F]N97,@/'!M:F]N97-`8VEA
M=V5B+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@9&5F;&ES="YP:'`L
M=B`Q+C$@,C`P-"\P,2\P-"`P,3HS-3HR,B!P;6IO;F5S($5X<"`D"@H*+RHJ
M"BH@"BH@5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI7U)U;&4@
M=&\@9FEN9"!S;W5R8V4@=&5X="!M87)K960@87,@80HJ(&1E9FEN:71I;VX@
M;&ES="X@($EN('-H;W)T+"!I9B!A(&QI;F4@<W1A<G1S('=I=&@@)SHG('1H
M96X@:70@:7,@80HJ(&1E9FEN:71I;VX@;&ES="!I=&5M.R!A;F]T:&5R("<Z
M)R!O;B!T:&4@<V%M92!L:6YE<R!I;F1I8V%T97,@=&AE(&5N9`HJ(&]F('1H
M92!D969I;FET:6]N('1E<FT@86YD('1H92!B96=I;FYI;F<@;V8@=&AE(&1E
M9FEN:71I;VX@;F%R<F%T:79E+@HJ(%1H92!L:7-T(&ET96US(&UU<W0@8F4@
M;VX@<V5Q=65N=&EA;"!L:6YE<R`H;F\@8FQA;FL@;&EN97,@8F5T=V5E;@HJ
M('1H96TI("TM(&$@8FQA;FL@;&EN92!I;F1I8V%T97,@=&AE(&)E9VEN;FEN
M9R!O9B!A(&YE=R!L:7-T+@HJ"BH@0&%U=&AO<B!0875L($TN($IO;F5S(#QP
M;6IO;F5S0&-I87=E8BYN970^"BH**B!`<&%C:V%G92!497AT7U=I:VD**@HJ
M+PH*8VQA<W,@5&5X=%]7:6MI7U)U;&5?9&5F;&ES="!E>'1E;F1S(%1E>'1?
M5VEK:5]2=6QE('L*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H
M92!R96=U;&%R(&5X<')E<W-I;VX@=7-E9"!T;R!P87)S92!T:&4@<V]U<F-E
M('1E>'0@86YD(&9I;F0*("`@("H@;6%T8VAE<R!C;VYF;W)M:6YG('1O('1H
M:7,@<G5L92X@(%5S960@8GD@=&AE('!A<G-E*"D@;65T:&]D+@H@("`@*B`*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V87(@<W1R:6YG
M"B`@("`J(`H@("`@*B!`<V5E('!A<G-E*"D*("`@("H@"B`@("`J+PH@("`@
M"B`@("!V87(@)')E9V5X(#T@)R]<;B@H.BDN*EQN*2@_(2@Z*2DO57,G.PH@
M("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@1V5N97)A=&5S(&$@<F5P
M;&%C96UE;G0@9F]R('1H92!M871C:&5D('1E>'0N("!4;VME;B!O<'1I;VYS
M(&%R93H*("`@("H@"B`@("`J("=T>7!E)R`]/@H@("`@*B`@("`@)VQI<W1?
M<W1A<G0G("`@(#H@=&AE('-T87)T(&]F(&$@9&5F:6YI=&EO;B!L:7-T"B`@
M("`J("`@("`G;&ES=%]E;F0G("`@("`@.B!T:&4@96YD(&]F(&$@9&5F:6YI
M=&EO;B!L:7-T"B`@("`J("`@("`G=&5R;5]S=&%R="<@("`@.B!T:&4@<W1A
M<G0@;V8@82!D969I;FET:6]N('1E<FT*("`@("H@("`@("=T97)M7V5N9"<@
M("`@("`Z('1H92!E;F0@;V8@82!D969I;FET:6]N('1E<FT*("`@("H@("`@
M("=N87)R7W-T87)T)R`@("`Z('1H92!S=&%R="!O9B!D969I;FET:6]N(&YA
M<G)A=&EV90H@("`@*B`@("`@)VYA<G)?96YD)R`@("`@(#H@=&AE(&5N9"!O
M9B!D969I;FET:6]N(&YA<G)A=&EV90H@("`@*B`@("`@)W5N:VYO=VXG("`@
M("`@(#H@=6YK;F]W;B!T>7!E(&]F(&1E9FEN:71I;VX@<&]R=&EO;@H@("`@
M*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*@H@("`@*B!`<&%R86T@87)R
M87D@)B1M871C:&5S(%1H92!A<G)A>2!O9B!M871C:&5S(&9R;VT@<&%R<V4H
M*2X*("`@("H*("`@("H@0')E='5R;B!!('-E<FEE<R!O9B!T97AT(&%N9"!D
M96QI;6ET960@=&]K96YS(&UA<FMI;F<@=&AE(&1I9F9E<F5N=`H@("`@*B!L
M:7-T('1E>'0@86YD(&QI<W0@96QE;65N=',N"B`@("`J"B`@("`J+PH@("`@
M"B`@("!F=6YC=&EO;B!P<F]C97-S*"8D;6%T8VAE<RD*("`@('L*("`@("`@
M("`O+R!T:&4@<F5P;&%C96UE;G0@=&5X="!W92!W:6QL(')E='5R;B!T;R!P
M87)S92@I"B`@("`@("`@)')E='5R;B`]("<G.PH@("`@("`@(`H@("`@("`@
M("\O('1H92!L:7-T(&]F('!O<W0M<')O8V5S<VEN9R!M871C:&5S"B`@("`@
M("`@)&QI<W0@/2!A<G)A>2@I.PH@("`@("`@(`H@("`@("`@("\O('-T87)T
M('1H92!D969L:7-T"B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G='EP92<@
M/3X@)VQI<W1?<W1A<G0G*3L*("`@("`@("`D<F5T=7)N("X]("1T:&ES+3YA
M9&14;VME;B@D;W!T:6]N<RD["B`@("`@("`@"B`@("`@("`@+R\@)&UA=&-H
M97-;,5T@:7,@=&AE('1E>'0@;6%T8VAE9"!A<R!A(&QI<W0@<V5T(&)Y('!A
M<G-E*"D["B`@("`@("`@+R\@8W)E871E(&%N(&%R<F%Y(&-A;&QE9"`D;&ES
M="!T:&%T(&-O;G1A:6YS(&$@;F5W('-E="!O9@H@("`@("`@("\O(&UA=&-H
M97,@9F]R('1H92!V87)I;W5S(&1E9FEN:71I;VXM;&ES="!E;&5M96YT<RX*
M("`@("`@("!P<F5G7VUA=&-H7V%L;"@*("`@("`@("`@("`@)R]>*#HI*"XJ
M*3\H.BDH+BHI/R0O56US)RP*("`@("`@("`@("`@)&UA=&-H97-;,5TL"B`@
M("`@("`@("`@("1L:7-T+`H@("`@("`@("`@("!04D5'7U-%5%]/4D1%4@H@
M("`@("`@("D["B`@("`@("`@"B`@("`@("`@+R\@861D(&5A8V@@=&5R;2!A
M;F0@;F%R<F%T:79E"B`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("1R971U<FX@+CT@*`H@("`@("`@("`@
M("`@("`@)'1H:7,M/F%D9%1O:V5N*&%R<F%Y*"=T>7!E)R`]/B`G=&5R;5]S
M=&%R="<I*2`N"B`@("`@("`@("`@("`@("!T<FEM*"1V86Q;,ETI("X*("`@
M("`@("`@("`@("`@("1T:&ES+3YA9&14;VME;BAA<G)A>2@G='EP92<@/3X@
M)W1E<FU?96YD)RDI("X*("`@("`@("`@("`@("`@("1T:&ES+3YA9&14;VME
M;BAA<G)A>2@G='EP92<@/3X@)VYA<G)?<W1A<G0G*2D@+@H@("`@("`@("`@
M("`@("`@=')I;2@D=F%L6S1=*2`N(`H@("`@("`@("`@("`@("`@)'1H:7,M
M/F%D9%1O:V5N*&%R<F%Y*"=T>7!E)R`]/B`G;F%R<E]E;F0G*2D*("`@("`@
M("`@("`@*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@"B`@("`@("`@
M+R\@96YD('1H92!D969L:7-T"B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G
M='EP92<@/3X@)VQI<W1?96YD)RD["B`@("`@("`@)')E='5R;B`N/2`D=&AI
M<RT^861D5&]K96XH)&]P=&EO;G,I.PH@("`@("`@(`H@("`@("`@("\O(&1O
M;F4A"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]"B`@("`*("`@(`H@
M("`@+RHJ"B`@("`J(`H@("`@*B!296YD97)S(&$@=&]K96X@:6YT;R!T97AT
M(&UA=&-H:6YG('1H92!R97%U97-T960@9F]R;6%T+@H@("`@*B`*("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!P87)A;2!A<G)A>2`D;W!T
M:6]N<R!4:&4@(F]P=&EO;G,B('!O<G1I;VX@;V8@=&AE('1O:V5N("AS96-O
M;F0*("`@("H@96QE;65N="DN"B`@("`J(`H@("`@*B!`<F5T=7)N('-T<FEN
M9R!4:&4@=&5X="!R96YD97)E9"!F<F]M('1H92!T;VME;B!O<'1I;VYS+@H@
M("`@*B`*("`@("HO"B`@("`*("`@(&9U;F-T:6]N(')E;F1E<EAH=&UL*"1O
M<'1I;VYS*0H@("`@>PH@("`@("`@("1T>7!E(#T@)&]P=&EO;G-;)W1Y<&4G
M73L*("`@("`@("`D<&%D(#T@(B`@("`B.PH@("`@("`@(`H@("`@("`@('-W
M:71C:"`H)'1Y<&4I('L*("`@("`@("`*("`@("`@("!C87-E("=L:7-T7W-T
M87)T)SH*("`@("`@("`@("`@<F5T=7)N("(\9&P^7&XB.PH@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`*("`@("`@("!C87-E("=L:7-T7V5N9"<Z"B`@
M("`@("`@("`@(')E='5R;B`B/"]D;#Y<;B(["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@(`H@("`@("`@(&-A<V4@)W1E<FU?<W1A<G0G.@H@("`@("`@
M("`@("!R971U<FX@)'!A9"`N("(\9'0^(CL*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@"B`@("`@("`@8V%S92`G=&5R;5]E;F0G.@H@("`@("`@("`@
M("!R971U<FX@(CPO9'0^7&XB.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`*("`@("`@("!C87-E("=N87)R7W-T87)T)SH*("`@("`@("`@("`@<F5T
M=7)N("1P860@+B`D<&%D("X@(CQD9#XB.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`*("`@("`@("!C87-E("=N87)R7V5N9"<Z"B`@("`@("`@("`@
M(')E='5R;B`B/"]D9#Y<;B(["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(`H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("`*("`@("`@("!]"B`@("!]"GT*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]497AT+U=I:VDO
M4G5L92]S=7!E<G-C<FEP="YP:'``````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-C(Q,``Q,#0Q-S,V,S`P-``P,C,Q-C<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD
M=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!V97)S:6]N(#0@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%!A
M=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O"B\O("1)9#H@<W5P97)S8W)I<'0N<&AP+'8@,2XQ(#(P,#0O,#$O,S$@
M,38Z,#0Z-#<@<&UJ;VYE<R!%>'`@)`H*"B\J*@HJ(`HJ(%1H:7,@8VQA<W,@
M:6UP;&5M96YT<R!A(%1E>'1?5VEK:5]2=6QE('1O(&9I;F0@<V]U<F-E('1E
M>'0@;6%R:V5D(&9O<@HJ('-T<F]N9R!E;7!H87-I<R`H8F]L9"D@87,@9&5F
M:6YE9"!B>2!T97AT('-U<G)O=6YD960@8GD@=&AR964**B!S:6YG;&4M<75O
M=&5S+B!/;B!P87)S:6YG+"!T:&4@=&5X="!I='-E;&8@:7,@;&5F="!I;B!P
M;&%C92P@8G5T('1H90HJ('-T87)T:6YG(&%N9"!E;F1I;F<@:6YS=&%N8V5S
M(&]F('1H<F5E('-I;F=L92UQ=6]T97,@87)E(')E<&QA8V5D('=I=&@**B!T
M;VME;G,N"BH**B!`875T:&]R(%!A=6P@32X@2F]N97,@/'!M:F]N97-`8VEA
M=V5B+FYE=#X**@HJ($!P86-K86=E(%1E>'1?5VEK:0HJ"BHO"@IC;&%S<R!4
M97AT7U=I:VE?4G5L95]S=7!E<G-C<FEP="!E>'1E;F1S(%1E>'1?5VEK:5]2
M=6QE('L*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!R96=U
M;&%R(&5X<')E<W-I;VX@=7-E9"!T;R!P87)S92!T:&4@<V]U<F-E('1E>'0@
M86YD(&9I;F0*("`@("H@;6%T8VAE<R!C;VYF;W)M:6YG('1O('1H:7,@<G5L
M92X@(%5S960@8GD@=&AE('!A<G-E*"D@;65T:&]D+@H@("`@*B`*("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V87(@<W1R:6YG"B`@("`J
M(`H@("`@*B!`<V5E('!A<G-E*"D*("`@("H@"B`@("`J+PH@("`@"B`@("!V
M87(@)')E9V5X(#T@("(O7%Y<7B@H*7PN*BE<7EQ>+U4B.PH@("`@"B`@("`*
M("`@("\J*@H@("`@*B`*("`@("H@1V5N97)A=&5S(&$@<F5P;&%C96UE;G0@
M9F]R('1H92!M871C:&5D('1E>'0N("!4;VME;B!O<'1I;VYS(&%R93H*("`@
M("H@"B`@("`J("=T>7!E)R`]/B!;)W-T87)T)WPG96YD)UT@5&AE('-T87)T
M:6YG(&]R(&5N9&EN9R!P;VEN="!O9B!T:&4*("`@("H@96UP:&%S:7IE9"!T
M97AT+B`@5&AE('1E>'0@:71S96QF(&ES(&QE9G0@:6X@=&AE('-O=7)C92X*
M("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J"B`@("`J($!P87)A
M;2!A<G)A>2`F)&UA=&-H97,@5&AE(&%R<F%Y(&]F(&UA=&-H97,@9G)O;2!P
M87)S92@I+@H@("`@*@H@("`@*B!`<F5T=7)N($$@<&%I<B!O9B!D96QI;6ET
M960@=&]K96YS('1O(&)E('5S960@87,@82!P;&%C96AO;&1E<B!I;@H@("`@
M*B!T:&4@<V]U<F-E('1E>'0@<W5R<F]U;F1I;F<@=&AE('1E>'0@=&\@8F4@
M96UP:&%S:7IE9"X*("`@("H*("`@("HO"B`@("`*("`@(&9U;F-T:6]N('!R
M;V-E<W,H)B1M871C:&5S*0H@("`@>PH@("`@("`@("1S=&%R="`]("1T:&ES
M+3YA9&14;VME;BAA<G)A>2@G='EP92<@/3X@)W-T87)T)RDI.PH@("`@("`@
M("1E;F0@/2`D=&AI<RT^861D5&]K96XH87)R87DH)W1Y<&4G(#T^("=E;F0G
M*2D["B`@("`@("`@<F5T=7)N("1S=&%R="`N("1M871C:&5S6S%=("X@)&5N
M9#L*("`@('T*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%)E;F1E
M<G,@82!T;VME;B!I;G1O('1E>'0@;6%T8VAI;F<@=&AE(')E<75E<W1E9"!F
M;W)M870N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@
M("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS(%1H92`B;W!T:6]N<R(@<&]R=&EO
M;B!O9B!T:&4@=&]K96X@*'-E8V]N9`H@("`@*B!E;&5M96YT*2X*("`@("H@
M"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!T97AT(')E;F1E<F5D(&9R;VT@
M=&AE('1O:V5N(&]P=&EO;G,N"B`@("`J(`H@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@<F5N9&5R6&AT;6PH)&]P=&EO;G,I"B`@("!["B`@("`@("`@:68@
M*"1O<'1I;VYS6R=T>7!E)UT@/3T@)W-T87)T)RD@>PH@("`@("`@("`@("!R
M971U<FX@)SQS=7`^)SL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@
M*"1O<'1I;VYS6R=T>7!E)UT@/3T@)V5N9"<I('L*("`@("`@("`@("`@<F5T
M=7)N("<\+W-U<#XG.PH@("`@("`@('T*("`@('T*?0H_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O5&5X="]7:6MI
M+U)U;&4O;F5W;&EN92YP:'``````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#0W-#$`,3`T,3<S-C,P,#0`,#(R,C4T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N
M9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@=F5R<VEO;B`T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!0
M875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+PHO+R`D260Z(&YE=VQI;F4N<&AP+'8@,2XQ(#(P,#0O,#$O,#0@,#$Z
M,S4Z,C,@<&UJ;VYE<R!%>'`@)`H*"B\J*@HJ(`HJ(%1H:7,@8VQA<W,@:6UP
M;&5M96YT<R!A(%1E>'1?5VEK:5]2=6QE('1O(&UA<FL@(FAA<F0B(&YE=VQI
M;F5S(&EN('1H90HJ('-O=7)C92!T97AT+@HJ"BH@0&%U=&AO<B!0875L($TN
M($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^"BH**B!`<&%C:V%G92!497AT
M7U=I:VD**@HJ+PH*8VQA<W,@5&5X=%]7:6MI7U)U;&5?;F5W;&EN92!E>'1E
M;F1S(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@("`@"B`@("`O*BH*("`@("H@
M"B`@("`J(%1H92!R96=U;&%R(&5X<')E<W-I;VX@=7-E9"!T;R!P87)S92!T
M:&4@<V]U<F-E('1E>'0@86YD(&9I;F0*("`@("H@;6%T8VAE<R!C;VYF;W)M
M:6YG('1O('1H:7,@<G5L92X@(%5S960@8GD@=&AE('!A<G-E*"D@;65T:&]D
M+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V
M87(@<W1R:6YG"B`@("`J(`H@("`@*B!`<V5E('!A<G-E*"D*("`@("H@"B`@
M("`J+PH@("`@"B`@("!V87(@)')E9V5X(#T@)R]<;B]M)SL*("`@(`H@("`@
M"B`@("`O*BH*("`@("H@"B`@("`J($=E;F5R871E<R!A(')E<&QA8V5M96YT
M('1O:V5N(&9O<B!T:&4@;6%T8VAE9"!T97AT+@H@("`@*B`*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y("8D;6%T8VAE
M<R!4:&4@87)R87D@;V8@;6%T8VAE<R!F<F]M('!A<G-E*"DN"B`@("`J"B`@
M("`J($!R971U<FX@<W1R:6YG($$@9&5L:6UI=&5D('1O:V5N('1O(&)E('5S
M960@87,@82!P;&%C96AO;&1E<B!I;@H@("`@*B!T:&4@<V]U<F-E('1E>'0N
M"B`@("`J"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P<F]C97-S*"8D;6%T
M8VAE<RD*("`@('L@("`@"B`@("`@("`@<F5T=7)N("1T:&ES+3YA9&14;VME
M;B@I.PH@("`@?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@4F5N
M9&5R<R!A('1O:V5N(&EN=&\@=&5X="!M871C:&EN9R!T:&4@<F5Q=65S=&5D
M(&9O<FUA="X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@
M("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@5&AE(")O<'1I;VYS(B!P;W)T
M:6]N(&]F('1H92!T;VME;B`H<V5C;VYD"B`@("`J(&5L96UE;G0I+@H@("`@
M*B`*("`@("H@0')E='5R;B!S=')I;F<@5&AE('1E>'0@<F5N9&5R960@9G)O
M;2!T:&4@=&]K96X@;W!T:6]N<RX*("`@("H@"B`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!R96YD97)8:'1M;"@D;W!T:6]N<RD*("`@('L*("`@("`@("!R
M971U<FX@(EQN/&)R("\^7&XB.PH@("`@?0I]"@H_/@``````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O5&5X="]7:6MI+U)U;&4O<&%R86=R87!H+G!H<```````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#8Q,34`,3`T,3<S-C,P,#0`,#(R-34U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@=F5R<VEO
M;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W)S.B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('!A<F%G<F%P:"YP:'`L=B`Q+C(@
M,C`P-"\P,2\S,2`P,CHT,3HR-"!P;6IO;F5S($5X<"`D"@H*+RHJ"BH@"BH@
M5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI(')U;&4@=&\@9FEN
M9"!S96-T:6]N<R!O9B!T:&4@<V]U<F-E"BH@=&5X="!T:&%T(&%R92!P87)A
M9W)A<&AS+B`@02!P87)A(&ES(&%N>2!L:6YE(&YO="!S=&%R=&EN9R!W:71H
M(&$@=&]K96X**B!D96QI;6ET97(L(&9O;&QO=V5D(&)Y('1W;R!N97=L:6YE
M<RX**@HJ($!A=71H;W(@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N
M;F5T/@HJ"BH@0'!A8VMA9V4@5&5X=%]7:6MI"BH**B\*"F-L87-S(%1E>'1?
M5VEK:5]2=6QE7W!A<F%G<F%P:"!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE('L*
M("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!R96=U;&%R(&5X
M<')E<W-I;VX@=7-E9"!T;R!F:6YD('-O=7)C92!T97AT(&UA=&-H:6YG('1H
M:7,*("`@("H@<G5L92X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J(`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B`*("`@("HO"B`@("`*("`@
M(&9U;F-T:6]N(%1E>'1?5VEK:5]2=6QE7W!A<F%G<F%P:"@F)&]B:BP@)&YA
M;64I"B`@("!["B`@("`@("`@<&%R96YT.CI497AT7U=I:VE?4G5L92@D;V)J
M+"`D;F%M92D["B`@("`@("`@)'1H:7,M/G)E9V5X(#T@(B]>*#\A>R1T:&ES
M+3Y?=VEK:2T^9&5L:6U]*2XJ/UQN7&XO;2(["B`@("!]"B`@("`*("`@("\J
M*@H@("`@*B`*("`@("H@1V5N97)A=&5S(&$@=&]K96X@96YT<GD@9F]R('1H
M92!M871C:&5D('1E>'0N("!4;VME;B!O<'1I;VYS(&%R93H*("`@("H@"B`@
M("`J("=T97AT)R`]/B!4:&4@9G5L;"!M871C:&5D('1E>'0N"B`@("`J(`H@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@*@H@("`@*B!`<&%R86T@87)R87D@
M)B1M871C:&5S(%1H92!A<G)A>2!O9B!M871C:&5S(&9R;VT@<&%R<V4H*2X*
M("`@("H*("`@("H@0')E='5R;B!!(&1E;&EM:71E9"!T;VME;B!N=6UB97(@
M=&\@8F4@=7-E9"!A<R!A('!L86-E:&]L9&5R(&EN"B`@("`J('1H92!S;W5R
M8V4@=&5X="X*("`@("H*("`@("HO"B`@("`*("`@(&9U;F-T:6]N('!R;V-E
M<W,H)B1M871C:&5S*0H@("`@>PH@("`@("`@(&EF("AT<FEM*"1M871C:&5S
M6S!=*2`]/2`G)RD@>PH@("`@("`@("`@("!R971U<FX@)&UA=&-H97-;,%T[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T87)T(#T@)'1H:7,M
M/F%D9%1O:V5N*&%R<F%Y*"=T>7!E)R`]/B`G<W1A<G0G*2D["B`@("`@("`@
M("`@("1E;F0@/2`D=&AI<RT^861D5&]K96XH87)R87DH)W1Y<&4G(#T^("=E
M;F0G*2D["B`@("`@("`@("`@(')E='5R;B`D<W1A<G0@+B!T<FEM*"1M871C
M:&5S6S!=*2`N("1E;F0["B`@("`@("`@?0H@("`@?0H@("`@"B`@("`*("`@
M("\J*@H@("`@*B`*("`@("H@4F5N9&5R<R!A('1O:V5N(&EN=&\@=&5X="!M
M871C:&EN9R!T:&4@<F5Q=65S=&5D(&9O<FUA="X*("`@("H@"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@*B!`<&%R86T@87)R87D@)&]P=&EO
M;G,@5&AE(")O<'1I;VYS(B!P;W)T:6]N(&]F('1H92!T;VME;B`H<V5C;VYD
M"B`@("`J(&5L96UE;G0I+@H@("`@*B`*("`@("H@0')E='5R;B!S=')I;F<@
M5&AE('1E>'0@<F5N9&5R960@9G)O;2!T:&4@=&]K96X@;W!T:6]N<RX*("`@
M("H@"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!R96YD97)8:'1M;"@D;W!T
M:6]N<RD*("`@('L*("`@("`@("!E>'1R86-T*"1O<'1I;VYS*3L@+R]T>7!E
M"B`@("`@("`@"B`@("`@("`@:68@*"1T>7!E(#T]("=S=&%R="<I('L*("`@
M("`@("`@("`@<F5T=7)N("<\<#XG.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("!I9B`H)'1Y<&4@/3T@)V5N9"<I('L*("`@("`@("`@("`@<F5T=7)N
M("(\+W`^7&Y<;B(["B`@("`@("`@?0H@("`@?0I]"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U1E>'0O5VEK:2]2=6QE+VAT;6PN<&AP````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`U-#8U`#$P-#$W,S8S,#`T`#`R,34V,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I
M;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@
M("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@
M<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@075T:&]R<SH@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!H=&UL+G!H<"QV(#$N,2`R,#`T
M+S`Q+S`T(#`Q.C,U.C(S('!M:F]N97,@17AP("0*"@HO*BH**B`**B!4:&ES
M(&-L87-S(&EM<&QE;65N=',@82!497AT7U=I:VE?4G5L92!T;R!F:6YD('-O
M=7)C92!T97AT(&UA<FME9"!A<PHJ($A434P@=&\@8F4@<F5D;F1R960@87,M
M:7,N("!4:&4@8FQO8VL@<W1A<G0@:7,@;6%R:V5D(&)Y(#QH=&UL/B!O;B!I
M=',**B!O=VX@;&EN92P@86YD('1H92!B;&]C:R!E;F0@:7,@;6%R:V5D(&)Y
M(#PO:'1M;#X@;VX@:71S(&]W;B!L:6YE+@HJ"BH@0&%U=&AO<B!0875L($TN
M($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^"BH**B!`<&%C:V%G92!497AT
M7U=I:VD**@HJ+PH*8VQA<W,@5&5X=%]7:6MI7U)U;&5?:'1M;"!E>'1E;F1S
M(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@
M("`J(%1H92!R96=U;&%R(&5X<')E<W-I;VX@=7-E9"!T;R!P87)S92!T:&4@
M<V]U<F-E('1E>'0@86YD(&9I;F0*("`@("H@;6%T8VAE<R!C;VYF;W)M:6YG
M('1O('1H:7,@<G5L92X@(%5S960@8GD@=&AE('!A<G-E*"D@;65T:&]D+@H@
M("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V87(@
M<W1R:6YG"B`@("`J(`H@("`@*B!`<V5E('!A<G-E*"D*("`@("H@"B`@("`J
M+PH@("`@"B`@("!V87(@)')E9V5X(#T@)R]>7#QH=&UL7#Y<;B@N*RE<;EP\
M7"]H=&UL7#XH7'-\)"DO56US:2<["B`@("`*("`@(`H@("`@+RHJ"B`@("`J
M(`H@("`@*B!'96YE<F%T97,@82!R97!L86-E;65N="!F;W(@=&AE(&UA=&-H
M960@=&5X="X@(%1O:V5N(&]P=&EO;G,@87)E.@H@("`@*B`*("`@("H@)W1E
M>'0G(#T^(%1H92!T97AT(&]F('1H92!(5$U,('1O(&)E(')E;F1E<F5D(&%S
M+6ES+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H*("`@("H@
M0'!A<F%M(&%R<F%Y("8D;6%T8VAE<R!4:&4@87)R87D@;V8@;6%T8VAE<R!F
M<F]M('!A<G-E*"DN"B`@("`J"B`@("`J($!R971U<FX@02!D96QI;6ET960@
M=&]K96X@=&\@8F4@=7-E9"!A<R!A('!L86-E:&]L9&5R(&EN"B`@("`J('1H
M92!S;W5R8V4@=&5X="P@<&QU<R!A;GD@=&5X="!F;VQL;W=I;F<@=&AE($A4
M34P@8FQO8VLN"B`@("`J"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P<F]C
M97-S*"8D;6%T8VAE<RD*("`@('L@("`@"B`@("`@("`@)&]P=&EO;G,@/2!A
M<G)A>2@G=&5X="<@/3X@)&UA=&-H97-;,5TI.PH@("`@("`@(')E='5R;B`D
M=&AI<RT^861D5&]K96XH)&]P=&EO;G,I("X@)&UA=&-H97-;,ET["B`@("!]
M"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!296YD97)S(&$@=&]K
M96X@:6YT;R!T97AT(&UA=&-H:6YG('1H92!R97%U97-T960@9F]R;6%T+@H@
M("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!P87)A
M;2!A<G)A>2`D;W!T:6]N<R!4:&4@(F]P=&EO;G,B('!O<G1I;VX@;V8@=&AE
M('1O:V5N("AS96-O;F0*("`@("H@96QE;65N="DN"B`@("`J(`H@("`@*B!`
M<F5T=7)N('-T<FEN9R!4:&4@=&5X="!R96YD97)E9"!F<F]M('1H92!T;VME
M;B!O<'1I;VYS+@H@("`@*B`*("`@("HO"B`@("`*("`@(&9U;F-T:6]N(')E
M;F1E<EAH=&UL*"1O<'1I;VYS*0H@("`@>PH@("`@("`@(')E='5R;B`D;W!T
M:6]N<ULG=&5X="==.PH@("`@?0I]"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O5&5X="]7:6MI+U)U
M;&4O<W1R;VYG+G!H<```````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R
M,#0`,3`T,3<S-C,P,#0`,#(R,3(S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A
M8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H
M="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT
M>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS
M92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@
M("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!0875L
M($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+PHO+R`D260Z('-T<F]N9RYP:'`L=B`Q+C(@,C`P-"\P,2\S,2`Q-3HU,CHP
M."!P;6IO;F5S($5X<"`D"@H*+RHJ"BH@"BH@5&AI<R!C;&%S<R!I;7!L96UE
M;G1S(&$@5&5X=%]7:6MI7U)U;&4@=&\@9FEN9"!S;W5R8V4@=&5X="!M87)K
M960@9F]R"BH@<W1R;VYG(&5M<&AA<VES("AB;VQD*2!A<R!D969I;F5D(&)Y
M('1E>'0@<W5R<F]U;F1E9"!B>2!T:')E90HJ('-I;F=L92UQ=6]T97,N($]N
M('!A<G-I;F<L('1H92!T97AT(&ET<V5L9B!I<R!L969T(&EN('!L86-E+"!B
M=70@=&AE"BH@<W1A<G1I;F<@86YD(&5N9&EN9R!I;G-T86YC97,@;V8@=&AR
M964@<VEN9VQE+7%U;W1E<R!A<F4@<F5P;&%C960@=VET:`HJ('1O:V5N<RX*
M*@HJ($!A=71H;W(@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T
M/@HJ"BH@0'!A8VMA9V4@5&5X=%]7:6MI"BH**B\*"F-L87-S(%1E>'1?5VEK
M:5]2=6QE7W-T<F]N9R!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@
M("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!R96=U;&%R(&5X<')E<W-I
M;VX@=7-E9"!T;R!P87)S92!T:&4@<V]U<F-E('1E>'0@86YD(&9I;F0*("`@
M("H@;6%T8VAE<R!C;VYF;W)M:6YG('1O('1H:7,@<G5L92X@(%5S960@8GD@
M=&AE('!A<G-E*"D@;65T:&]D+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("H@"B`@("`J($!V87(@<W1R:6YG"B`@("`J(`H@("`@*B!`<V5E
M('!A<G-E*"D*("`@("H@"B`@("`J+PH@("`@"B`@("!V87(@)')E9V5X(#T@
M("(O7"I<*B@H*7PN*BE<*EPJ+U4B.PH@("`@"B`@("`*("`@("\J*@H@("`@
M*B`*("`@("H@1V5N97)A=&5S(&$@<F5P;&%C96UE;G0@9F]R('1H92!M871C
M:&5D('1E>'0N("!4;VME;B!O<'1I;VYS(&%R93H*("`@("H@"B`@("`J("=T
M>7!E)R`]/B!;)W-T87)T)WPG96YD)UT@5&AE('-T87)T:6YG(&]R(&5N9&EN
M9R!P;VEN="!O9B!T:&4*("`@("H@96UP:&%S:7IE9"!T97AT+B`@5&AE('1E
M>'0@:71S96QF(&ES(&QE9G0@:6X@=&AE('-O=7)C92X*("`@("H@"B`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`J"B`@("`J($!P87)A;2!A<G)A>2`F)&UA
M=&-H97,@5&AE(&%R<F%Y(&]F(&UA=&-H97,@9G)O;2!P87)S92@I+@H@("`@
M*@H@("`@*B!`<F5T=7)N($$@<&%I<B!O9B!D96QI;6ET960@=&]K96YS('1O
M(&)E('5S960@87,@82!P;&%C96AO;&1E<B!I;@H@("`@*B!T:&4@<V]U<F-E
M('1E>'0@<W5R<F]U;F1I;F<@=&AE('1E>'0@=&\@8F4@96UP:&%S:7IE9"X*
M("`@("H*("`@("HO"B`@("`*("`@(&9U;F-T:6]N('!R;V-E<W,H)B1M871C
M:&5S*0H@("`@>PH@("`@("`@("1S=&%R="`]("1T:&ES+3YA9&14;VME;BAA
M<G)A>2@G='EP92<@/3X@)W-T87)T)RDI.PH@("`@("`@("1E;F0@/2`D=&AI
M<RT^861D5&]K96XH87)R87DH)W1Y<&4G(#T^("=E;F0G*2D["B`@("`@("`@
M<F5T=7)N("1S=&%R="`N("1M871C:&5S6S%=("X@)&5N9#L*("`@('T*("`@
M(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%)E;F1E<G,@82!T;VME;B!I
M;G1O('1E>'0@;6%T8VAI;F<@=&AE(')E<75E<W1E9"!F;W)M870N"B`@("`J
M(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&%R
M<F%Y("1O<'1I;VYS(%1H92`B;W!T:6]N<R(@<&]R=&EO;B!O9B!T:&4@=&]K
M96X@*'-E8V]N9`H@("`@*B!E;&5M96YT*2X*("`@("H@"B`@("`J($!R971U
M<FX@<W1R:6YG(%1H92!T97AT(')E;F1E<F5D(&9R;VT@=&AE('1O:V5N(&]P
M=&EO;G,N"B`@("`J(`H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<F5N9&5R
M6&AT;6PH)&]P=&EO;G,I"B`@("!["B`@("`@("`@:68@*"1O<'1I;VYS6R=T
M>7!E)UT@/3T@)W-T87)T)RD@>PH@("`@("`@("`@("!R971U<FX@)SQS=')O
M;F<^)SL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"1O<'1I;VYS
M6R=T>7!E)UT@/3T@)V5N9"<I('L*("`@("`@("`@("`@<F5T=7)N("<\+W-T
M<F]N9SXG.PH@("`@("`@('T*("`@('T*?0H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U1E>'0O5VEK:2]2
M=6QE+V-O9&4N<&AP````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V
M,C`V`#$P-#$W,S8S,#`T`#`R,34R,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4&%U
M;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\*+R\@)$ED.B!C;V1E+G!H<"QV(#$N,B`R,#`T+S`Q+S`T(#$V.C`S.C(T
M('!M:F]N97,@17AP("0*"@HO*BH**B`**B!4:&ES(&-L87-S(&EM<&QE;65N
M=',@82!497AT7U=I:VE?4G5L92!T;R!F:6YD('-E8W1I;VYS(&UA<FME9"!A
M<R!C;V1E"BH@97AA;7!L97,N("!";&]C:W,@87)E(&UA<FME9"!A<R!T:&4@
M<W1R:6YG(#QC;V1E/B!O;B!A(&QI;F4@8GD@:71S96QF+`HJ(&9O;&QO=V5D
M(&)Y('1H92!I;FQI;F4@8V]D92!E>&%M<&QE+"!A;F0@=&5R;6EN871E9"!W
M:71H('1H92!S=')I;F<**B`\+V-O9&4^(&]N(&$@;&EN92!B>2!I='-E;&8N
M("!4:&4@8V]D92!E>&%M<&QE(&ES(')U;B!T:')O=6=H('1H90HJ(&YA=&EV
M92!02%`@:&EG:&QI9VAT7W-T<FEN9R@I(&9U;F-T:6]N('1O(&-O;&]R:7IE
M(&ET+"!T:&5N('-U<G)O=6YD960**B!W:71H(#QP<F4^+BXN/"]P<F4^('1A
M9W,@=VAE;B!R96YD97)E9"!A<R!82%1-3"X**@HJ($!A=71H;W(@4&%U;"!-
M+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/@HJ"BH@0'!A8VMA9V4@5&5X
M=%]7:6MI"BH**B\*"F-L87-S(%1E>'1?5VEK:5]2=6QE7V-O9&4@97AT96YD
M<R!497AT7U=I:VE?4G5L92!["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@
M("`@*B!4:&4@<F5G=6QA<B!E>'!R97-S:6]N('5S960@=&\@9FEN9"!S;W5R
M8V4@=&5X="!M871C:&EN9R!T:&ES"B`@("`J(')U;&4N"B`@("`J(`H@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'9A<B!S=')I;F<*("`@
M("H@"B`@("`J+PH@("`@"B`@("!V87(@)')E9V5X(#T@)R]>*%P\8V]D95P^
M*5QN*"XK*5QN*%P\7"]C;V1E7#XI*%QS?"0I+U5M<VDG.PH@("`@"B`@("`*
M("`@("\J*@H@("`@*B`*("`@("H@1V5N97)A=&5S(&$@=&]K96X@96YT<GD@
M9F]R('1H92!M871C:&5D('1E>'0N("!4;VME;B!O<'1I;VYS(&%R93H*("`@
M("H@"B`@("`J("=T97AT)R`]/B!4:&4@9G5L;"!M871C:&5D('1E>'0L(&YO
M="!I;F-L=61I;F<@=&AE(#QC;V1E/CPO8V]D93X@=&%G<RX*("`@("H@"B`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`J"B`@("`J($!P87)A;2!A<G)A>2`F
M)&UA=&-H97,@5&AE(&%R<F%Y(&]F(&UA=&-H97,@9G)O;2!P87)S92@I+@H@
M("`@*@H@("`@*B!`<F5T=7)N($$@9&5L:6UI=&5D('1O:V5N(&YU;6)E<B!T
M;R!B92!U<V5D(&%S(&$@<&QA8V5H;VQD97(@:6X*("`@("H@=&AE('-O=7)C
M92!T97AT+@H@("`@*@H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<')O8V5S
M<R@F)&UA=&-H97,I"B`@("!["B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G
M=&5X="<@/3X@)&UA=&-H97-;,ETI.PH@("`@("`@(')E='5R;B`D=&AI<RT^
M861D5&]K96XH)&]P=&EO;G,I("X@)&UA=&-H97-;-%T["B`@("!]"B`@("`*
M("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!296YD97)S(&$@=&]K96X@:6YT
M;R!T97AT(&UA=&-H:6YG('1H92!R97%U97-T960@9F]R;6%T+@H@("`@*B`*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!P87)A;2!A<G)A
M>2`D;W!T:6]N<R!4:&4@(F]P=&EO;G,B('!O<G1I;VX@;V8@=&AE('1O:V5N
M("AS96-O;F0*("`@("H@96QE;65N="DN"B`@("`J(`H@("`@*B!`<F5T=7)N
M('-T<FEN9R!4:&4@=&5X="!R96YD97)E9"!F<F]M('1H92!T;VME;B!O<'1I
M;VYS+@H@("`@*B`*("`@("HO"B`@("`*("`@(&9U;F-T:6]N(')E;F1E<EAH
M=&UL*"1O<'1I;VYS*0H@("`@>PH)"2\O('1R:6T@;W!E;FEN9R!A;F0@8VQO
M<VEN9R!W:&ET97-P86-E"@D))'1E>'0@/2!T<FEM*"1O<'1I;VYS6R=T97AT
M)UTI.PH)"0H)"2\O(&-O;G9E<G0@=&%B<R!T;R!F;W5R('-P86-E<PH)"21T
M97AT(#T@<W1R7W)E<&QA8V4H(EQT(BP@(B`@("`B+"`D=&5X="D["@D)"@D)
M+R\@8V]N=F5R="!E;G1I=&EE<PH)"21T97AT(#T@:'1M;&5N=&ET:65S*"1T
M97AT*3L*"0D*"0DO+R!D;VYE(0H)"7)E='5R;B`B7&X\<')E/CQC;V1E/B1T
M97AT/"]C;V1E/CPO<')E/EQN(CL*("`@('T*?0H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]497AT+U=I:VDO
M4G5L92]T:6=H=&5N+G!H<```````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,S,P-@`Q,#0Q-S,V,S`P-``P,C(R-3$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD
M=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!V97)S:6]N(#0@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%!A
M=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O"B\O("1)9#H@=&EG:'1E;BYP:'`L=B`Q+C$@,C`P-"\P,2\P-"`P,3HS
M-3HR,R!P;6IO;F5S($5X<"`D"@H*+RHJ"BH@"BH@5&AI<R!R=6QE(')E;6]V
M97,@86QL(&YE=VQI;F5S(&9R;VT@=&AE('-O=7)C92!T97AT+@HJ"BH@0&%U
M=&AO<B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^"BH**B!`
M<&%C:V%G92!497AT7U=I:VD**@HJ+PH*8VQA<W,@5&5X=%]7:6MI7U)U;&5?
M=&EG:'1E;B!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@("`@"B`@
M("`O*BH*("`@("H@"B`@("`J(%-I;7!L92!P87)S:6YG(&UE=&AO9"!T;R!A
M<'!L>2!T:6=H=&5N:6YG(&1I<F5C=&QY('1O('1H92!T;VME;G,*("`@("H@
M87)R87DN"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@
M*B\*("`@(`H@("`@9G5N8W1I;VX@<&%R<V4H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?=VEK:2T^7W-O=7)C92`]('-T<E]R97!L86-E*")<;B(L("(B+`H@
M("`@("`@("`@("`D=&AI<RT^7W=I:VDM/E]S;W5R8V4I.PH@("`@?0I]"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O5&5X="]7:6MI+U)U;&4O
M:&5A9&EN9RYP:'``````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8W-#0`
M,3`T,3<S-C,P,#0`,#(R,C$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T
M86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!0875L($TN
M($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO
M+R`D260Z(&AE861I;F<N<&AP+'8@,2XQ(#(P,#0O,#$O,#0@,#$Z,S4Z,C,@
M<&UJ;VYE<R!%>'`@)`H*"B\J*@HJ(`HJ(%1H:7,@8VQA<W,@:6UP;&5M96YT
M<R!A(%1E>'1?5VEK:5]2=6QE('1O(&9I;F0@<V]U<F-E('1E>'0@;6%R:V5D
M('1O"BH@8F4@82!H96%D:6YG(&5L96UE;G0L(&%S(&1E9FEN960@8GD@=&5X
M="!O;B!A(&QI;F4@8GD@:71S96QF('!R969I>&5D"BH@=VET:"!A(&YU;6)E
M<B!O9B!P;'5S('-I9VYS("@K*2X@5&AE(&AE861I;F<@=&5X="!I='-E;&8@
M:7,@;&5F="!I;@HJ('1H92!S;W5R8V4L(&)U="!I<R!P<F5F:7AE9"!A;F0@
M<W5F9FEX960@=VET:"!D96QI;6ET960@=&]K96YS(&UA<FMI;F<**B!T:&4@
M<W1A<G0@86YD(&5N9"!O9B!T:&4@:&5A9&EN9RX**@HJ($!A=71H;W(@4&%U
M;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/@HJ"BH@0'!A8VMA9V4@
M5&5X=%]7:6MI"BH**B\*"F-L87-S(%1E>'1?5VEK:5]2=6QE7VAE861I;F<@
M97AT96YD<R!497AT7U=I:VE?4G5L92!["B`@("`*("`@(`H@("`@+RHJ"B`@
M("`J(`H@("`@*B!4:&4@<F5G=6QA<B!E>'!R97-S:6]N('5S960@=&\@<&%R
M<V4@=&AE('-O=7)C92!T97AT(&%N9"!F:6YD"B`@("`J(&UA=&-H97,@8V]N
M9F]R;6EN9R!T;R!T:&ES(')U;&4N("!5<V5D(&)Y('1H92!P87)S92@I(&UE
M=&AO9"X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@
M*B!`=F%R('-T<FEN9PH@("`@*B`*("`@("H@0'-E92!P87)S92@I"B`@("`J
M(`H@("`@*B\*("`@(`H@("`@=F%R("1R96=E>"`]("<O7BA<*WLQ+#9]*2`H
M+BHI+VTG.PH@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@1V5N97)A
M=&5S(&$@<F5P;&%C96UE;G0@9F]R('1H92!M871C:&5D('1E>'0N("!4;VME
M;B!O<'1I;VYS(&%R93H*("`@("H@"B`@("`J("=T>7!E)R`]/B!;)W-T87)T
M)WPG96YD)UT@5&AE('-T87)T:6YG(&]R(&5N9&EN9R!P;VEN="!O9B!T:&4*
M("`@("H@:&5A9&EN9R!T97AT+B`@5&AE('1E>'0@:71S96QF(&ES(&QE9G0@
M:6X@=&AE('-O=7)C92X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J"B`@("`J($!P87)A;2!A<G)A>2`F)&UA=&-H97,@5&AE(&%R<F%Y(&]F
M(&UA=&-H97,@9G)O;2!P87)S92@I+@H@("`@*@H@("`@*B!`<F5T=7)N('-T
M<FEN9R!!('!A:7(@;V8@9&5L:6UI=&5D('1O:V5N<R!T;R!B92!U<V5D(&%S
M(&$*("`@("H@<&QA8V5H;VQD97(@:6X@=&AE('-O=7)C92!T97AT('-U<G)O
M=6YD:6YG('1H92!H96%D:6YG('1E>'0N"B`@("`J"B`@("`J+PH@("`@"B`@
M("!F=6YC=&EO;B!P<F]C97-S*"8D;6%T8VAE<RD*("`@('L*("`@("`@("`D
M<W1A<G0@/2`D=&AI<RT^861D5&]K96XH"B`@("`@("`@("`@(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=S=&%R="<L"B`@("`@("`@("`@
M("`@("`G;&5V96PG(#T^('-T<FQE;B@D;6%T8VAE<ULQ72DL"B`@("`@("`@
M("`@("`@("`G=&5X="<@/3X@)&UA=&-H97-;,ET*("`@("`@("`@("`@*0H@
M("`@("`@("D["B`@("`@("`@"B`@("`@("`@)&5N9"`]("1T:&ES+3YA9&14
M;VME;B@*("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`G='EP
M92<@/3X@)V5N9"<L"B`@("`@("`@("`@("`@("`G;&5V96PG(#T^('-T<FQE
M;B@D;6%T8VAE<ULQ72D*("`@("`@("`@("`@*0H@("`@("`@("D["B`@("`@
M("`@"B`@("`@("`@<F5T=7)N("1S=&%R="`N("1M871C:&5S6S)=("X@)&5N
M9#L*("`@('T*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%)E;F1E
M<G,@82!T;VME;B!I;G1O('1E>'0@;6%T8VAI;F<@=&AE(')E<75E<W1E9"!F
M;W)M870N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@
M("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS(%1H92`B;W!T:6]N<R(@<&]R=&EO
M;B!O9B!T:&4@=&]K96X@*'-E8V]N9`H@("`@*B!E;&5M96YT*2X*("`@("H@
M"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!T97AT(')E;F1E<F5D(&9R;VT@
M=&AE('1O:V5N(&]P=&EO;G,N"B`@("`J(`H@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@<F5N9&5R6&AT;6PH)&]P=&EO;G,I"B`@("!["B`@("`@("`@+R\@
M9V5T(&YI8V4@=F%R:6%B;&4@;F%M97,@*'1Y<&4L(&QE=F5L*0H@("`@("`@
M(&5X=')A8W0H)&]P=&EO;G,I.PH@("`@("`@(`H@("`@("`@(&EF("@D='EP
M92`]/2`G<W1A<G0G*2!["B`@("`@("`@("`@(')E='5R;B`B/&@D;&5V96P^
M(CL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"1T>7!E(#T]("=E
M;F0G*2!["B`@("`@("`@("`@(')E='5R;B`B/"]H)&QE=F5L/EQN(CL*("`@
M("`@("!]"B`@("!]"GT*/SX`````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U1E>'0O5VEK:2]2=6QE
M+W!H<&QO;VMU<"YP:'``````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-#0S
M`#$P-#$W,S8S,#`T`#`R,C8S-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4&%U;"!-
M+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!P:'!L;V]K=7`N<&AP+'8@,2XQ(#(P,#0O,#$O,#0@,#$Z,S4Z
M,C,@<&UJ;VYE<R!%>'`@)`H*"B\J*@HJ(`HJ(%1H:7,@8VQA<W,@:6UP;&5M
M96YT<R!A(%1E>'1?5VEK:5]2=6QE('1O(&9I;F0@<V]U<F-E('1E>'0@;6%R
M:V5D(&9O<@HJ(&QO;VMU<"!I;B!T:&4@4$A0(&]N;&EN92!M86YU86PN"BH*
M*B!`875T:&]R(%!A=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X*
M*@HJ($!P86-K86=E(%1E>'1?5VEK:0HJ"BHO"@IC;&%S<R!497AT7U=I:VE?
M4G5L95]P:'!L;V]K=7`@97AT96YD<R!497AT7U=I:VE?4G5L92!["B`@("`*
M("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!4:&4@<F5G=6QA<B!E>'!R97-S
M:6]N('5S960@=&\@<&%R<V4@=&AE('-O=7)C92!T97AT(&%N9"!F:6YD"B`@
M("`J(&UA=&-H97,@8V]N9F]R;6EN9R!T;R!T:&ES(')U;&4N("!5<V5D(&)Y
M('1H92!P87)S92@I(&UE=&AO9"X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`J(`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B`*("`@("H@0'-E
M92!P87)S92@I"B`@("`J(`H@("`@*B\*("`@(`H@("`@=F%R("1R96=E>"`]
M("(O7#QP:'!<.BA[*C\N*GTJ/RE</B]5(CL*("`@(`H@("`@"B`@("`O*BH*
M("`@("H@"B`@("`J($=E;F5R871E<R!A(')E<&QA8V5M96YT(&9O<B!T:&4@
M;6%T8VAE9"!T97AT+B`@5&]K96X@;W!T:6]N<R!A<F4Z"B`@("`J(`H@("`@
M*B`G='EP92<@/3X@6R=S=&%R="=\)V5N9"==(%1H92!S=&%R=&EN9R!O<B!E
M;F1I;F<@<&]I;G0@;V8@=&AE"B`@("`J('1E;&5T>7!E('1E>'0N("!4:&4@
M=&5X="!I='-E;&8@:7,@;&5F="!I;B!T:&4@<V]U<F-E+@H@("`@*B`*("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y("8D
M;6%T8VAE<R!4:&4@87)R87D@;V8@;6%T8VAE<R!F<F]M('!A<G-E*"DN"B`@
M("`J"B`@("`J($!R971U<FX@<W1R:6YG($$@<&%I<B!O9B!D96QI;6ET960@
M=&]K96YS('1O(&)E('5S960@87,@80H@("`@*B!P;&%C96AO;&1E<B!I;B!T
M:&4@<V]U<F-E('1E>'0@<W5R<F]U;F1I;F<@=&AE('1E;&5T>7!E('1E>'0N
M"B`@("`J"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P<F]C97-S*"8D;6%T
M8VAE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F%D9%1O:V5N*&%R
M<F%Y*"=T97AT)R`]/B`D;6%T8VAE<ULQ72DI.PH@("`@?0H@("`@"B`@("`*
M("`@("\J*@H@("`@*B`*("`@("H@4F5N9&5R<R!A('1O:V5N(&EN=&\@=&5X
M="!M871C:&EN9R!T:&4@<F5Q=65S=&5D(&9O<FUA="X*("`@("H@"B`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@*B!`<&%R86T@87)R87D@)&]P
M=&EO;G,@5&AE(")O<'1I;VYS(B!P;W)T:6]N(&]F('1H92!T;VME;B`H<V5C
M;VYD"B`@("`J(&5L96UE;G0I+@H@("`@*B`*("`@("H@0')E='5R;B!S=')I
M;F<@5&AE('1E>'0@<F5N9&5R960@9G)O;2!T:&4@=&]K96X@;W!T:6]N<RX*
M("`@("H@"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!R96YD97)8:'1M;"@D
M;W!T:6]N<RD*("`@('L*("`@(`DD=&5X="`]('1R:6TH)&]P=&EO;G-;)W1E
M>'0G72D["B`@("`@("`@<F5T=7)N("(\82!H<F5F/5PB:'1T<#HO+W!H<"YN
M970O)'1E>'1<(CXD=&5X=#PO83XB.PH@("`@?0I]"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O5&5X="]7:6MI+U)U;&4O<')E9FEL=&5R+G!H<```
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T-S0`,3`T,3<S-C,P,#0`,#(R
M-C$R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W
M:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@
M;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!0875L($TN($IO;F5S(#QP;6IO;F5S
M0&-I87=E8BYN970^("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('!R969I;'1E
M<BYP:'`L=B`Q+C$@,C`P-"\P,2\P-"`P,3HS-3HR,R!P;6IO;F5S($5X<"`D
M"@H*+RHJ"BH@"BH@5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI
M7U)U;&4@=&\@(G!R92UF:6QT97(B('-O=7)C92!T97AT('-O"BH@=&AA="!L
M:6YE(&5N9&EN9W,@87)E(&-O;G-I<W1E;G1L>2!<;BP@;&EN97,@96YD:6YG
M(&EN(&$@8F%C:W-L87-H(%P**B!A<F4@8V]N8V%T96YA=&5D('=I=&@@=&AE
M(&YE>'0@;&EN92P@86YD('1A8G,@87)E(&-O;G9E<G1E9"!T;R!S<&%C97,N
M"BH**B!`875T:&]R(%!A=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE
M=#X**@HJ($!P86-K86=E(%1E>'1?5VEK:0HJ"BHO"@IC;&%S<R!497AT7U=I
M:VE?4G5L95]P<F5F:6QT97(@97AT96YD<R!497AT7U=I:VE?4G5L92!["B`@
M("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!3:6UP;&4@<&%R<VEN9R!M
M971H;V0@=&\@87!P;'D@=&AE(')U;&4@9&ER96-T;'D@=&\@=&AE('-O=7)C
M90H@("`@*B!T97AT+@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B`*("`@("HO"B`@("`*("`@(&9U;F-T:6]N('!A<G-E*"D*("`@('L*("`@
M("`@("`O+R!C;VYV97)T($1/4R!L:6YE(&5N9&EN9W,*("`@("`@("`D=&AI
M<RT^7W=I:VDM/E]S;W5R8V4@/2!S=')?<F5P;&%C92@B7')<;B(L(")<;B(L
M"B`@("`@("`@("`@("1T:&ES+3Y?=VEK:2T^7W-O=7)C92D["B`@("`@("`@
M"B`@("`@("`@+R\@8V]N=F5R="!-86-I;G1O<V@@;&EN92!E;F1I;F=S"B`@
M("`@("`@)'1H:7,M/E]W:6MI+3Y?<V]U<F-E(#T@<W1R7W)E<&QA8V4H(EQR
M(BP@(EQN(BP*("`@("`@("`@("`@)'1H:7,M/E]W:6MI+3Y?<V]U<F-E*3L*
M("`@("`@("`*("`@("`@("`O+R!C;VYC870@;&EN97,@96YD:6YG(&EN(&$@
M8F%C:W-L87-H"B`@("`@("`@)'1H:7,M/E]W:6MI+3Y?<V]U<F-E(#T@<W1R
M7W)E<&QA8V4H(EQ<7&XB+"`B(BP*("`@("`@("`@("`@)'1H:7,M/E]W:6MI
M+3Y?<V]U<F-E*3L*("`@("`@("`*("`@("`@("`O+R!C;VYV97)T('1A8G,@
M=&\@<W!A8V5S"B`@("`@("`@)'1H:7,M/E]W:6MI+3Y?<V]U<F-E(#T@<W1R
M7W)E<&QA8V4H(EQT(BP@(B`@("`B+`H@("`@("`@("`@("`D=&AI<RT^7W=I
M:VDM/E]S;W5R8V4I.PH@("`@?0H*?0H_/@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O5&5X="]7:6MI+U)U;&4O=&]C
M+G!H<```````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$P-#``,3`T
M,3<S-C,P,#0`,#(Q,S8W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!02%`@=F5R<VEO;B`T"0D)"0D)"0D)"0D)"0E\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`)"0D)"0D)"7P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P)
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,)"7P*+R\@?"!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870)"0D)"0D)("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N"0D)"0D)"0D@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;PD)("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"0D)("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!0875L($TN($IO
M;F5S(#QP;6IO;F5S0&-I87=E8BYN970^"0D)"0D)("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('1O8RYP:'`L=B`Q+C(@
M,C`P-"\P,2\S,2`Q-SHP.3HT-B!P;6IO;F5S($5X<"`D"@H*+RHJ"BH@"BH@
M5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI7U)U;&4@=&\@9FEN
M9"!A;&P@:&5A9&EN9R!T;VME;G,@86YD"BH@8G5I;&0@82!T86)L92!O9B!C
M;VYT96YT<RX@(%1H92`E)51/0R4E('1A9R!G971S(')E<&QA8V5D('=I=&@@
M82!L:7-T"BH@;V8@86QL('1H92!L979E;"TR('1H<F]U9V@@;&5V96PM-B!H
M96%D:6YG<RX**@HJ($!A=71H;W(@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C
M:6%W96(N;F5T/@HJ"BH@0'!A8VMA9V4@5&5X=%]7:6MI"BH**B\*"@IC;&%S
M<R!497AT7U=I:VE?4G5L95]T;V,@97AT96YD<R!497AT7U=I:VE?4G5L92![
M"@D*"0H)+RHJ"@DJ(`H)*B!4:&4@<F5G=6QA<B!E>'!R97-S:6]N('5S960@
M=&\@<&%R<V4@=&AE('-O=7)C92!T97AT(&%N9"!F:6YD"@DJ(&UA=&-H97,@
M8V]N9F]R;6EN9R!T;R!T:&ES(')U;&4N("!5<V5D(&)Y('1H92!P87)S92@I
M(&UE=&AO9"X*"2H@"@DJ($!A8V-E<W,@<'5B;&EC"@DJ(`H)*B!`=F%R('-T
M<FEN9PH)*B`*"2H@0'-E92!P87)S92@I"@DJ(`H)*B\*"0H)=F%R("1R96=E
M>"`]("(O)2543T,E)2]M(CL*"0H)"@DO*BH*"2H@"@DJ(%1H92!C;VQL96-T
M:6]N(&]F(&AE861I;F=S("AT97AT(&%N9"!L979E;',I+@H)*B`*"2H@0&%C
M8V5S<R!P=6)L:6,*"2H@"@DJ($!V87(@87)R87D*"2H@"@DJ($!S964@7V=E
M=$5N=')I97,H*0H)*B`*"2HO"@D*"79A<B`D96YT<GD@/2!A<G)A>2@I.PH)
M"@D*"2\J*@H)*B`*"2H@0W5S=&]M('!A<G-I;F<@*&AA=F4@=&\@<')O8V5S
M<R!H96%D:6YG(&5N=')I97,@9FER<W0I+@H)*B`*"2H@0&%C8V5S<R!P=6)L
M:6,*"2H@"@DJ($!S964@5&5X=%]7:6MI.CIP87)S92@I"@DJ(`H)*B\*"0H)
M9G5N8W1I;VX@<&%R<V4H*0H)>PH)"21T:&ES+3Y?9V5T16YT<FEE<R@I.PH)
M"7!A<F5N=#HZ<&%R<V4H*3L*"7T*"0H)"@DO*BH*"2H@"@DJ($=E;F5R871E
M<R!A(')E<&QA8V5M96YT(&9O<B!T:&4@;6%T8VAE9"!T97AT+B`@5&]K96X@
M;W!T:6]N<R!A<F4Z"@DJ(`H)*B`G='EP92<@/3X@6R=L:7-T7W-T87)T)WPG
M;&ES=%]E;F0G?"=I=&5M7V5N9"=\)VET96U?96YD)WPG=&%R9V5T)UT*"2H*
M"2H@)VQE=F5L)R`]/B!4:&4@:&5A9&EN9R!L979E;"`H,2TV*2X*"2H*"2H@
M)V-O=6YT)R`]/B!7:&EC:"!H96%D:6YG('1H:7,@:7,@:6X@=&AE(&QI<W0N
M"@DJ(`H)*B!`86-C97-S('!U8FQI8PH)*@H)*B!`<&%R86T@87)R87D@)B1M
M871C:&5S(%1H92!A<G)A>2!O9B!M871C:&5S(&9R;VT@<&%R<V4H*2X*"2H*
M"2H@0')E='5R;B!S=')I;F<@02!T;VME;B!I;F1I8V%T:6YG('1H92!43T,@
M8V]L;&5C=&EO;B!P;VEN="X*"2H*"2HO"@D*"69U;F-T:6]N('!R;V-E<W,H
M)B1M871C:&5S*0H)>PH)"21O=71P=70@/2`D=&AI<RT^861D5&]K96XH87)R
M87DH)W1Y<&4G(#T^("=L:7-T7W-T87)T)RDI.PH)"0H)"69O<F5A8V@@*"1T
M:&ES+3YE;G1R>2!A<R`D:V5Y(#T^("1V86PI('L*"0D*"0D))&]P=&EO;G,@
M/2!A<G)A>2@*"0D)"2=T>7!E)R`]/B`G:71E;5]S=&%R="<L"@D)"0DG8V]U
M;G0G(#T^("1V86Q;)V-O=6YT)UTL"@D)"0DG;&5V96PG(#T^("1V86Q;)VQE
M=F5L)UT*"0D)*3L*"0D)"@D)"21O=71P=70@+CT@)'1H:7,M/F%D9%1O:V5N
M*"1O<'1I;VYS*3L*"0D)"@D)"21O=71P=70@+CT@)'9A;%LG=&5X="==.PH)
M"0D*"0D))&]U='!U="`N/2`D=&AI<RT^861D5&]K96XH87)R87DH)W1Y<&4G
M(#T^("=I=&5M7V5N9"<I*3L*"0E]"@D)"@D))&]U='!U="`N/2`D=&AI<RT^
M861D5&]K96XH87)R87DH)W1Y<&4G(#T^("=L:7-T7V5N9"<I*3L*"0ER971U
M<FX@)&]U='!U=#L*"7T*"0H)"@DO*BH*"2H@"@DJ($9I;F1S(&%L;"!H96%D
M:6YG<R!I;B!T:&4@=&5X="!A;F0@<V%V97,@=&AE;2!I;B`D=&AI<RT^96YT
M<GDN"@DJ(`H)*B!`86-C97-S('!R:79A=&4*"2H*"2H@0')E='5R;B!V;VED
M"@DJ(`H)*B\*"0H)9G5N8W1I;VX@7V=E=$5N=')I97,H*0H)>PH)"2\O('1H
M92!W:6MI(&1E;&EM:71E<@H)"21D96QI;2`]("1T:&ES+3Y?=VEK:2T^9&5L
M:6T["@D)"@D)+R\@;&ES="!O9B!A;&P@5$]#(&5N=')I97,@*&@R+"!H,RP@
M971C*0H)"21T:&ES+3YE;G1R>2`](&%R<F%Y*"D["@D)"@D)+R\@=&AE(&YE
M=R!S;W5R8V4@=&5X="!W:71H(%1/0R!E;G1R>2!T;VME;G,*"0DD;F5W<W)C
M(#T@)R<["@D)"B`@("`@("`@+R\@=VAE;B!P87-S:6YG('1H<F]U9V@@=&AE
M('!A<G-E9"!S;W5R8V4@=&5X="P@:V5E<"!T<F%C:R!O9B!W:&5N"B`@("`@
M("`@+R\@=V4@87)E(&EN(&$@9&5L:6UI=&5D('-E8W1I;VX*("`@("`@("`D
M:6Y?9&5L:6T@/2!F86QS93L*("`@("`@("`*("`@("`@("`O+R!W:&5N(&EN
M(&$@9&5L:6UI=&5D('-E8W1I;VXL(&-A<'1U<F4@=&AE('1O:V5N(&ME>2!N
M=6UB97(*("`@("`@("`D:V5Y(#T@)R<["B`@("`@("`@"B`@("`@("`@+R\@
M5$]#(&5N=')Y(&-O=6YT"B`@("`@("`@)&-O=6YT(#T@,#L*("`@("`@("`*
M("`@("`@("`O+R!P87-S('1H<F]U9V@@=&AE('!A<G-E9"!S;W5R8V4@=&5X
M="!C:&%R86-T97(@8GD@8VAA<F%C=&5R"B`@("`@("`@)&L@/2!S=')L96XH
M)'1H:7,M/E]W:6MI+3Y?<V]U<F-E*3L*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D:SL@)&DK*RD@>PH@("`@("`@("`@("`*("`@("`@("`@("`@+R\@
M=&AE(&-U<G)E;G0@8VAA<F%C=&5R"B`@("`@("`@("`@("1C:&%R(#T@)'1H
M:7,M/E]W:6MI+3Y?<V]U<F-E>R1I?3L*("`@("`@("`@("`@"B`@("`@("`@
M("`@("\O(&%R92!A;')E9'D@:6X@82!D96QI;6ET960@<V5C=&EO;C\*("`@
M("`@("`@("`@:68@*"1I;E]D96QI;2D@>PH@("`@("`@("`@("`*("`@("`@
M("`@("`@("`@("\O('EE<SL@87)E('=E(&5N9&EN9R!T:&4@<V5C=&EO;C\*
M("`@("`@("`@("`@("`@(&EF("@D8VAA<B`]/2`D9&5L:6TI('L*("`@("`@
M("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("`@("`O+R!Y97,L(&=E
M="!T:&4@<F5P;&%C96UE;G0@=&5X="!F;W(@=&AE(&1E;&EM:71E9`H@("`@
M("`@("`@("`@("`@("`@("\O('1O:V5N(&YU;6)E<B!A;F0@=6YS970@=&AE
M(&9L86<N"B`@("`@("`@("`@("`@("`@("`@)&ME>2`]("AI;G0I)&ME>3L*
M("`@("`@("`@("`@("`@("`@("`D<G5L92`]("1T:&ES+3Y?=VEK:2T^7W1O
M:V5N<ULD:V5Y75LP73L*("`@("`@("`@("`@("`@("`@("`D;W!T<R`]("1T
M:&ES+3Y?=VEK:2T^7W1O:V5N<ULD:V5Y75LQ73L*("`@("`@("`@("`@("`@
M("`@("`D:6Y?9&5L:6T@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`*
M("`@("`@("`@("`@("`@("`@("`O+R!I<R!T:&4@:V5Y(&$@<W1A<G0@:&5A
M9&EN9R!T;VME;@H@("`@("`@("`@("`@("`@("`@("\O(&]F(&QE=F5L(#(@
M;W(@9&5E<&5R/PH@("`@("`@("`@("`@("`@("`@(&EF("@D<G5L92`]/2`G
M:&5A9&EN9R<@)B8*("`@("`@("`@("`@("`@("`@("`))&]P='-;)W1Y<&4G
M72`]/2`G<W1A<G0G("8F"B`@("`@("`@("`@("`@("`@("`@"21O<'1S6R=L
M979E;"==(#X@,2D@>PH@("`@("`@("`@("`@("`@("`@(`D*("`@("`@("`@
M("`@("`@("`@("`)+R\@>65S+"!A9&0@82!43T,@=&%R9V5T(&QI;FL@=&\@
M=&AE"B`@("`@("`@("`@("`@("`@("`@"2\O('1O:V5N<R!A<G)A>2XN+@H)
M"0D)"0DD=&]K96X@/2`D=&AI<RT^861D5&]K96XH"@D)"0D)"0EA<G)A>2@*
M"0D)"0D)"0DG='EP92<@/3X@)W1A<F=E="<L"@D)"0D)"0D))V-O=6YT)R`]
M/B`D8V]U;G0L"@D)"0D)"0D))VQE=F5L)R`]/B`D;W!T<ULG;&5V96PG70H)
M"0D)"0D)*0H)"0D)"0DI.PH)"0D)"0D*"0D)"0D)+R\@+BXN(&%N9"!T;R!T
M:&4@;F5W('-O=7)C92P@8F5F;W)E('1H90H)"0D)"0DO+R!H96%D:6YG+7-T
M87)T('1O:V5N+@H)"0D)"0DD;F5W<W)C("X]("1T;VME;B`N("1D96QI;2`N
M("1K97D@+B`D9&5L:6T["@D)"0D)"0H)"0D)"0DO+R!R971A:6X@=&AE('1O
M8R!I=&5M"@D)"0D)"21T:&ES+3YE;G1R>5M=(#T@87)R87D@*`H)"0D)"0D)
M)V-O=6YT)R`]/B`D8V]U;G0L"@D)"0D)"0DG;&5V96PG(#T^("1O<'1S6R=L
M979E;"==+`H)"0D)"0D))W1E>'0G(#T^("1O<'1S6R=T97AT)UT*"0D)"0D)
M*3L*"0D)"0D)"@D)"0D)"2\O(&EN8W)E87-E('1H92!C;W5N="!F;W(@=&AE
M(&YE>'0@96YT<GD*"0D)"0D))&-O=6YT*RL["@D)"0D)"0H@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@"2\O(&YO
M="!A(&AE861I;F<M<W1A<G0@;V8@,B!O<B!D965P97(N"B`@("`@("`@("`@
M("`@("`@("`@"2\O(')E+6%D9"!T:&4@9&5L:6UI=&5D('1O:V5N(&YU;6)E
M<@H@("`@("`@("`@("`@("`@("`@(`DO+R!A<R!I="!W87,@:6X@=&AE(&]R
M:6=I;F%L('-O=7)C92X*("`@("`@("`@("`@("`@("`@("`))&YE=W-R8R`N
M/2`D9&5L:6T@+B`D:V5Y("X@)&1E;&EM.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("`@("`O+R!N
M;RP@861D('1O('1H92!D96QI;6ET960@=&]K96X@:V5Y(&YU;6)E<@H@("`@
M("`@("`@("`@("`@("`@("1K97D@+CT@)&-H87(["B`@("`@("`@("`@("`@
M("`@("`@"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@"0H@("`@("`@("`@("`)
M+R\@;F]T(&-U<G)E;G1L>2!I;B!A(&1E;&EM:71E9"!S96-T:6]N+@H@("`@
M("`@("`@("`)+R\@87)E('=E('-T87)T:6YG(&EN=&\@82!D96QI;6ET960@
M<V5C=&EO;C\*("`@("`@("`@("`@("`@(&EF("@D8VAA<B`]/2`D9&5L:6TI
M('L*("`@("`@("`@("`@("`@(`DO+R!Y97,L(')E<V5T('1H92!P<F5V:6]U
M<R!K97D@86YD"B`@("`@("`@("`@("`@("`)+R\@<V5T('1H92!F;&%G+@H@
M("`@("`@("`@("`@("`@("`@("1K97D@/2`G)SL*("`@("`@("`@("`@("`@
M("`@("`D:6Y?9&5L:6T@/2!T<G5E.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(`DO+R!N;RP@861D('1O('1H92!O=71P=70@
M87,M:7,*("`@("`@("`@("`@("`@("`@("`D;F5W<W)C("X]("1C:&%R.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(`H@("`@("`@("\O(')E<&QA8V4@=VET:"!C:&%N9V5D('-O=7)C92!T
M97AT"B`@("`@("`@)'1H:7,M/E]W:6MI+3Y?<V]U<F-E(#T@)&YE=W-R8SL*
M("`@("`@("`*"0D*"0DO*@H)"2\O(%!224]2(%9%4E-)3TX*"0DO+R!H87,@
M<')O8FQE;7,@;6ES=&%K:6YG(&UA<FME9"UU<"!N=6UB97)S(&9O<B!D96QI
M;6ET960@=&]K96YS"@D)"@D)+R\@8W)E871E<R!T87)G970@=&]K96YS+"!R
M971R:65V97,@:&5A9&EN9R!L979E;"!A;F0@=&5X=`H)"21T:&ES+3YE;G1R
M>2`](&%R<F%Y*"D["@D))&-O=6YT(#T@,#L*"0D*"0DO+R!L;V]P('1H<F]U
M9V@@86QL('1O:V5N<R!A;F0@9V5T(&AE861I;F=S"@D)9F]R96%C:"`H)'1H
M:7,M/E]W:6MI+3Y?=&]K96YS(&%S("1K97D@/3X@)'9A;"D@>PH)"0D*"0D)
M+R\@;VYL>2!G970@:&5A9&EN9R!S=&%R=',@;V8@;&5V96P@,B!O<B!D965P
M97(*"0D):68@*"1V86Q;,%T@/3T@)VAE861I;F<G("8F"@D)"0DD=F%L6S%=
M6R=T>7!E)UT@/3T@)W-T87)T)R`F)@H)"0D))'9A;%LQ75LG;&5V96PG72`^
M(#$I('L*"0D)"0H)"0D)+R\@=&AE(&QE=F5L(&]F('1H:7,@:&5A9&5R"@D)
M"0DD;&5V96P@/2`D=F%L6S%=6R=L979E;"==.PH)"0D)"@D)"0DO+R!T:&4@
M=&5X="!O9B!T:&ES(&AE861E<@H)"0D))'1E>'0@/2`D=F%L6S%=6R=T97AT
M)UT["@D)"0D*"0D)"2\O(&%D9"!A('1O8RUT87)G970@;&EN:R!T;R!T:&4@
M=&]K96YS(&%R<F%Y"@D)"0DD=&]K96X@/2`D=&AI<RT^861D5&]K96XH"@D)
M"0D)87)R87DH"@D)"0D)"2=T>7!E)R`]/B`G=&%R9V5T)RP*"0D)"0D))V-O
M=6YT)R`]/B`D8V]U;G0L"@D)"0D)"2=L979E;"<@/3X@)&QE=F5L"@D)"0D)
M*0H)"0D)*3L*"0D)"0H)"0D)+R\@<'5T('1H92!T;V,@=&%R9V5T('1O:V5N
M(&EN(&9R;VYT(&]F('1H90H)"0D)+R\@:&5A9&EN9RUS=&%R="!T;VME;@H)
M"0D))'-T87)T(#T@)&1E;&EM("X@)&ME>2`N("1D96QI;3L*"0D)"21T:&ES
M+3Y?=VEK:2T^7W-O=7)C92`]('-T<E]R97!L86-E*"1S=&%R="P@)'1O:V5N
M+B1S=&%R="P*"0D)"0DD=&AI<RT^7W=I:VDM/E]S;W5R8V4I.PH)"0D)"@D)
M"0DO+R!R971A:6X@=&AE('1O8R!I=&5M"@D)"0DD=&AI<RT^96YT<GE;72`]
M(&%R<F%Y("@*"0D)"0DG8V]U;G0G(#T^("1C;W5N="P*"0D)"0DG;&5V96PG
M(#T^("1L979E;"P*"0D)"0DG=&5X="<@/3X@)'1E>'0*"0D)"2D["@D)"0D*
M"0D)"2\O(&EN8W)E87-E('1H92!C;W5N="!F;W(@=&AE(&YE>'0@:71E;0H)
M"0D))&-O=6YT*RL["@D)"7T*"0E]"@D)*B\*"7T*"@D*"2\J*@H)*B`*"2H@
M4F5N9&5R<R!A('1O:V5N(&EN=&\@=&5X="!M871C:&EN9R!T:&4@<F5Q=65S
M=&5D(&9O<FUA="X*"2H@"@DJ($!A8V-E<W,@<'5B;&EC"@DJ(`H)*B!`<&%R
M86T@87)R87D@)&]P=&EO;G,@5&AE(")O<'1I;VYS(B!P;W)T:6]N(&]F('1H
M92!T;VME;B`H<V5C;VYD"@DJ(&5L96UE;G0I+@H)*B`*"2H@0')E='5R;B!S
M=')I;F<@5&AE('1E>'0@<F5N9&5R960@9G)O;2!T:&4@=&]K96X@;W!T:6]N
M<RX*"2H@"@DJ+PH)"@EF=6YC=&EO;B!R96YD97)8:'1M;"@D;W!T:6]N<RD*
M"7L*"0DO+R!T>7!E+"!C;W5N="P@;&5V96P*"0EE>'1R86-T*"1O<'1I;VYS
M*3L*"0D*"0DO+R!T:&4@<')E9FEX('5S960@9F]R(&%N8VAO<B!N86UE<PH)
M"21P<F5F:7@@/2`G=&]C)SL*"0D*"0EI9B`H)'1Y<&4@/3T@)W1A<F=E="<I
M('L*"0D)+R\@+BXN(&=E;F5R871E(&%N(&%N8VAO<BX*"0D)<F5T=7)N("(\
M82!N86UE/5PB)'!R969I>"1C;W5N=%PB/CPO83XB.PH)"7T*"0D*"0EI9B`H
M)'1Y<&4@/3T@)VQI<W1?<W1A<G0G*2!["@D)"7)E='5R;B`B/'`^7&XB.PH)
M"7T*"0D*"0EI9B`H)'1Y<&4@/3T@)VQI<W1?96YD)RD@>PH)"0ER971U<FX@
M(CPO<#Y<;B(["@D)?0H)"0H)"6EF("@D='EP92`]/2`G:71E;5]S=&%R="<I
M('L*"0D)"@D)"2\O(&)U:6QD('-O;64@:6YD96YT:6YG('-P86-E<R!F;W(@
M=&AE('1E>'0*"0D))&EN9&5N="`]("@D;&5V96P@+2`R*2`J(#0["@D)"21P
M860@/2!S=')?<&%D*"<G+"`D:6YD96YT*3L*"0D))'!A9"`]('-T<E]R97!L
M86-E*"<@)RP@)R9N8G-P.R<L("1P860I.PH)"0D*"0D)+R\@861D(&%N(&5X
M=')A(&QI;F5B<F5A:R!I;B!F<F]N="!O9B!H96%D:6YG+3(*"0D)+R\@96YT
M<FEE<R`H;6%K97,@9F]R(&YI8V4@<V5C=&EO;B!S97!A<F%T:6]N<RD*"0D)
M:68@*"1L979E;"`\/2`R("8F("1C;W5N="`^(#`I('L*"0D)"21P860@/2`B
M/&)R("\^7&XD<&%D(CL*"0D)?0H)"0D*"0D)+R\@8W)E871E('1H92!E;G1R
M>2!L:6YE(&%S(&$@;&EN:R!T;R!T:&4@=&]C(&%N8VAO<@H)"0ER971U<FX@
M(B1P860\82!H<F5F/5PB(R1P<F5F:7@D8V]U;G1<(CXB.PH)"7T*"0D*"0EI
M9B`H)'1Y<&4@/3T@)VET96U?96YD)RD@>PH)"0ER971U<FX@(CPO83X\8G(@
M+SY<;B(["@D)?0H)?0H*?0H_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]497AT+U=I:VDO
M4G5L92]W:6MI;&EN:RYP:'``````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,C$T-@`Q,#0Q-S,V,S`P-``P,C(T,S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD
M=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!V97)S:6]N(#0@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%!A
M=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O"B\O("1)9#H@=VEK:6QI;FLN<&AP+'8@,2XS(#(P,#0O,#$O,S$@,34Z
M-3(Z,#@@<&UJ;VYE<R!%>'`@)`H*"B\J*@HJ(`HJ(%1H:7,@8VQA<W,@:6UP
M;&5M96YT<R!A(%1E>'1?5VEK:5]2=6QE('1O(&9I;F0@<V]U<F-E('1E>'0@
M;6%R:V5D(&%S(&$**B!W:6MI('!A9V4@;F%M92!A;F0@875T;VUA=&EC86QL
M>2!C<F5A=&4@82!L:6YK('1O('1H870@<&%G92X**@HJ(%=I:VD@<&%G92!N
M86UE<R!A<F4@='EP:6-A;&QY(&EN(%-T=61L>4-A<'-3='EL92!M861E(&]F
M"BH@5V]R9'-3;6%S:&5D5&]G971H97(N"BH**B!`875T:&]R(%!A=6P@32X@
M2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X**@HJ($!P86-K86=E(%1E>'1?
M5VEK:0HJ"BHO"@IC;&%S<R!497AT7U=I:VE?4G5L95]W:6MI;&EN:R!E>'1E
M;F1S(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@("`@"B`@("`O*BH*("`@("H@
M"B`@("`J($-O;G-T<G5C=&]R+B`@5V4@;W9E<G)I9&4@=&AE(%1E>'1?5VEK
M:5]2=6QE(&-O;G-T<G5C=&]R('-O('=E(&-A;@H@("`@*B!E>'!L:6-I=&QY
M(&-O;6UE;G0@96%C:"!P87)T(&]F('1H92`D<F5G97@@<')O<&5R='DN"B`@
M("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M
M(&]B:F5C="`F)&]B:B!4:&4@8V%L;&EN9R`B<&%R96YT(B!497AT7U=I:VD@
M;V)J96-T+@H@("`@*B`*("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92!4:&4@
M=&]K96X@;F%M92!T;R!U<V4@9F]R('1H:7,@<G5L92X*("`@("H@"B`@("`J
M+PH@("`@"B`@("!F=6YC=&EO;B!497AT7U=I:VE?4G5L95]W:6MI;&EN:R@F
M)&]B:BP@)&YA;64I"B`@("!["B`@("`@("`@<&%R96YT.CI497AT7U=I:VE?
M4G5L92@D;V)J+"`D;F%M92D["B`@("`@("`@"B`@("`@("`@)'1H:7,M/G)E
M9V5X(#T*("`@("`@("`@("`@(B\B("X@("`@("`@("`@("`@("`@("`O+R!3
M5$%25"!R96=E>`H@("`@("`@("`@("`B*%Y\6UY!+5IA+7I=*2(@+B`@("`@
M("\O"B`@("`@("`@("`@("(H(3\B("X@("`@("`@("`@("`@("`@+R\@4U1!
M4E0@5VEK:5!A9V4@<&%T=&5R;@H@("`@("`@("`@("`B6T$M6EQX8S`M7'AD
M95TB("X@("`@("\O(#$@=7!P97(*("`@("`@("`@("`@(EM!+5IA+7I<>&,P
M+5QX9F5=*B(@+B`O+R`P(&]R(&UO<F4@86QP:&$*("`@("`@("`@("`@(EMA
M+7I<>&1F+5QX9F5=*R(@+B`@("`O+R`Q(&]R(&UO<F4@;&]W97(*("`@("`@
M("`@("`@(EM!+5I<>&,P+5QX9&5=(B`N("`@("`O+R`Q('5P<&5R"B`@("`@
M("`@("`@(");02U:82UZ7'AC,"U<>&9E72HB("X@+R\@,"!O<B!M;W)E(&%L
M<&AA"B`@("`@("`@("`@("<H7%PO)R`N("`@("`@("`@("`@("`@+R\@<W1A
M<G0@<W5B<&%T=&5R;@H@("`@("`@("`@("`B6T$M6EQX8S`M7'AD95TB("X@
M("`@("\O(#$@=7!P97(*("`@("`@("`@("`@(EM!+5IA+7I<>&,P+5QX9F5=
M*B(@+B`O+R`P(&]R(&UO<F4@86QP:&$*("`@("`@("`@("`@)RD_)R`N("`@
M("`@("`@("`@("`@("`O+R!E;F0@<W5B<&%T=&5R;B`P(&]R(#$*("`@("`@
M("`@("`@(BDB("X@("`@("`@("`@("`@("`@("`O+R!%3D0@5VEK:5!A9V4@
M<&%T=&5R;@H@("`@("`@("`@("`B*"A<(R(@+B`@("`@("`@("`@("`@("\O
M(%-405)4($%N8VAO<B!P871T97)N"B`@("`@("`@("`@(");02U:82UZ72(@
M+B`@("`@("`@("`@+R\@,2!A;'!H80H@("`@("`@("`@("`B*"(@+B`@("`@
M("`@("`@("`@("`@("\O('-T87)T('-U8B!P871T97)N"B`@("`@("`@("`@
M(");+4$M6F$M>C`M.5\Z+ETJ(B`N("`@+R\@,"L@9&%S:"P@86QP:&$L(&1I
M9VET+"!U;F1E<G-C;W)E"B`@("`@("`@("`@(");+4$M6F$M>C`M.5]=(B`N
M("`@("`@+R\@,2!D87-H+"!A;'!H82P@9&EG:70L(&]R('5N9&5R<V-O<F4*
M("`@("`@("`@("`@(BD_(B`N("`@("`@("`@("`@("`@("`O+R!E;F0@<W5B
M<&%T=&5R;B`P(&]R(#$*("`@("`@("`@("`@(BD_*2(@+B`@("`@("`@("`@
M("`@("`O+R!%3D0@06YC:&]R('!A='1E<FX*("`@("`@("`@("`@(BA<(EPB
M*3\B("X@("`@("`@("`@("`O+PH@("`@("`@("`@("`B+R([("`@("`@("`@
M("`@("`@("`@("\O($5.1"!R96=E>`H@("`@?0H@("`@"B`@("`*("`@("\J
M*@H@("`@*B`*("`@("H@1V5N97)A=&5S(&$@<F5P;&%C96UE;G0@9F]R('1H
M92!M871C:&5D('1E>'0N("!4;VME;B!O<'1I;VYS(&%R93H*("`@("H@"B`@
M("`J("=P86=E)R`]/B!T:&4@=VEK:2!P86=E(&YA;64@*&4N9RXL($AO;650
M86=E*2X*("`@("H@"B`@("`J("=A;F-H;W(G(#T^(&$@;F%M960@86YC:&]R
M(&]N('1H92!T87)G970@=VEK:2!P86=E"B`@("`J(`H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*@H@("`@*B!`<&%R86T@87)R87D@)B1M871C:&5S(%1H
M92!A<G)A>2!O9B!M871C:&5S(&9R;VT@<&%R<V4H*2X*("`@("H*("`@("H@
M0')E='5R;B!!(&1E;&EM:71E9"!T;VME;B!T;R!B92!U<V5D(&%S(&$@<&QA
M8V5H;VQD97(@:6X*("`@("H@=&AE('-O=7)C92!T97AT+"!P;'5S(&%N>2!T
M97AT('!R:6]T('1O('1H92!M871C:"X*("`@("H*("`@("HO"B`@("`*("`@
M(&9U;F-T:6]N('!R;V-E<W,H)B1M871C:&5S*0H@("`@>PH@("`@("`@("\O
M('=H96X@<')E9FEX960@=VET:"`A+"!I="=S(&5X<&QI8VET;'D@;F]T(&$@
M=VEK:2!L:6YK+@H@("`@("`@("\O(')E='5R;B!E=F5R>71H:6YG(&%S(&ET
M('=A<RX*("`@("`@("!I9B`H)&UA=&-H97-;,EU[,'T@/3T@)R$G*2!["B`@
M("`@("`@("`@(')E='5R;B`D;6%T8VAE<ULQ72`N('-U8G-T<B@D;6%T8VAE
M<ULR72P@,2D@+@H@("`@("`@("`@("`@("`@)&UA=&-H97-;,UT@+B`D;6%T
M8VAE<ULT73L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@<V5T('1H
M92!O<'1I;VYS"B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@
M("`@)W!A9V4G(#T^("1M871C:&5S6S)=+`H@("`@("`@("`@("`G86YC:&]R
M)R`]/B!S=6)S='(H)&UA=&-H97-;-%TL(#$I"B`@("`@("`@*3L*("`@("`@
M("`*("`@("`@("`O+R!C<F5A=&4@86YD(')E='5R;B!T:&4@<F5P;&%C96UE
M;G0@=&]K96X@86YD('!R96-E9&EN9R!T97AT"B`@("`@("`@<F5T=7)N("1M
M871C:&5S6S%=("X@)'1H:7,M/F%D9%1O:V5N*"1O<'1I;VYS*3L*("`@('T*
M("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%)E;F1E<G,@82!T;VME
M;B!I;G1O('1E>'0@;6%T8VAI;F<@=&AE(')E<75E<W1E9"!F;W)M870N"B`@
M("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M
M(&%R<F%Y("1O<'1I;VYS(%1H92`B;W!T:6]N<R(@<&]R=&EO;B!O9B!T:&4@
M=&]K96X@*'-E8V]N9`H@("`@*B!E;&5M96YT*2X*("`@("H@"B`@("`J($!R
M971U<FX@<W1R:6YG(%1H92!T97AT(')E;F1E<F5D(&9R;VT@=&AE('1O:V5N
M(&]P=&EO;G,N"B`@("`J(`H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<F5N
M9&5R6&AT;6PH)&]P=&EO;G,I"B`@("!["B`@("`@("`@+R\@;6%K92!N:6-E
M('9A<FEA8FQE(&YA;65S("AP86=E+"!A;F-H;W(I"B`@("`@("`@97AT<F%C
M="@D;W!T:6]N<RD["B`@("`@("`@"B`@("`@("`@+R\@9&]E<R!T:&4@<&%G
M92!E>&ES=#\*("`@("`@("!I9B`H:6Y?87)R87DH)'!A9V4L("1T:&ES+3Y?
M=VEK:2T^<&%G97,I*2!["B`@("`@("`@("`@("\O('EE<RP@;&EN:R!T;R!T
M:&4@<&%G92!V:65W"B`@("`@("`@("`@("1H<F5F(#T@)'1H:7,M/E]W:6MI
M+3YV:65W7W5R;"`N("1P86=E("X@(B,B("X@)&%N8VAO<CL*("`@("`@("`@
M("`@<F5T=7)N("(\82!H<F5F/5PB)&AR969<(CXD<&%G93PO83XB.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\O(&YO+"!L:6YK('1O(&$@8W)E
M871E+7!A9V4@=7)L"B`@("`@("`@("`@("1H<F5F(#T@)'1H:7,M/E]W:6MI
M+3YN97=?=7)L.PH@("`@("`@("`@("!R971U<FX@)'!A9V4@+B`B/&$@:')E
M9CU<(B1H<F5F)'!A9V5<(CY[)'1H:7,M/E]W:6MI+3YN97=?=&5X='T\+V$^
M(CL*("`@("`@("!]"B`@("!]"GT*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]497AT+U=I:VDO4G5L92]B;&]C:W%U;W1E+G!H<```
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#0W,@`Q,#0Q-S,V,S`P-``P,C(W
M-C4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!(4"!V97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%!A=6P@32X@2F]N97,@/'!M:F]N97-`
M8VEA=V5B+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@8FQO8VMQ=6]T
M92YP:'`L=B`Q+C$@,C`P-"\P,2\P-"`P,3HS-3HR,B!P;6IO;F5S($5X<"`D
M"@H*+RHJ"BH@"BH@5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI
M7U)U;&4@=&\@9FEN9"!S;W5R8V4@=&5X="!M87)K960@87,@80HJ(&)L;V-K
M<75O=&4L(&ED96YT:69I960@8GD@86YY(&YU;6)E<B!O9B!G<F5A=&5R+71H
M86X@<VEG;G,@)SXG(&%T('1H90HJ('-T87)T(&]F('1H92!L:6YE+"!F;VQL
M;W=E9"!B>2!A('-P86-E+"!A;F0@=&AE;B!T:&4@<75O=&4@=&5X=#L@96%C
M:`HJ("<^)R!I;F1I8V%T97,@86X@861D:71I;VYA;"!L979E;"!O9B!Q=6]T
M:6YG+@HJ"BH@0&%U=&AO<B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E
M8BYN970^"BH**B!`<&%C:V%G92!497AT7U=I:VD**@HJ+PH*8VQA<W,@5&5X
M=%]7:6MI7U)U;&5?8FQO8VMQ=6]T92!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE
M('L*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!R96=U;&%R
M(&5X<')E<W-I;VX@=7-E9"!T;R!P87)S92!T:&4@<V]U<F-E('1E>'0@86YD
M(&9I;F0*("`@("H@;6%T8VAE<R!C;VYF;W)M:6YG('1O('1H:7,@<G5L92X@
M(%5S960@8GD@=&AE('!A<G-E*"D@;65T:&]D+@H@("`@*B`*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V87(@<W1R:6YG"B`@("`J(`H@
M("`@*B!`<V5E('!A<G-E*"D*("`@("H@"B`@("`J+PH@("`@"B`@("!V87(@
M)')E9V5X(#T@)R]<;B@H7#XI+BI<;BDH/R$H7#XI*2]5<R<["B`@("`*("`@
M(`H@("`@+RHJ"B`@("`J(`H@("`@*B!'96YE<F%T97,@82!R97!L86-E;65N
M="!F;W(@=&AE(&UA=&-H960@=&5X="X@(%1O:V5N(&]P=&EO;G,@87)E.@H@
M("`@*B`*("`@("H@)W1Y<&4G(#T^"B`@("`J("`@("`G<W1A<G0G(#H@=&AE
M('-T87)T(&]F(&$@8FQO8VMQ=6]T90H@("`@*B`@("`@)V5N9"<@("`Z('1H
M92!E;F0@;V8@82!B;&]C:W%U;W1E"B`@("`J"B`@("`J("=L979E;"<@/3X@
M=&AE(&EN9&5N="!L979E;"`H,"!F;W(@=&AE(&9I<G-T(&QE=F5L+"`Q(&9O
M<B!T:&4*("`@("H@<V5C;VYD+"!E=&,I"B`@("`J(`H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*@H@("`@*B!`<&%R86T@87)R87D@)B1M871C:&5S(%1H
M92!A<G)A>2!O9B!M871C:&5S(&9R;VT@<&%R<V4H*2X*("`@("H*("`@("H@
M0')E='5R;B!!('-E<FEE<R!O9B!T97AT(&%N9"!D96QI;6ET960@=&]K96YS
M(&UA<FMI;F<@=&AE(&1I9F9E<F5N=`H@("`@*B!L:7-T('1E>'0@86YD(&QI
M<W0@96QE;65N=',N"B`@("`J"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P
M<F]C97-S*"8D;6%T8VAE<RD*("`@('L*("`@("`@("`O+R!T:&4@<F5P;&%C
M96UE;G0@=&5X="!W92!W:6QL(')E='5R;B!T;R!P87)S92@I"B`@("`@("`@
M)')E='5R;B`]("<G.PH@("`@("`@(`H@("`@("`@("\O('1H92!L:7-T(&]F
M('!O<W0M<')O8V5S<VEN9R!M871C:&5S"B`@("`@("`@)&QI<W0@/2!A<G)A
M>2@I.PH@("`@("`@(`H@("`@("`@("\O("1M871C:&5S6S%=(&ES('1H92!T
M97AT(&UA=&-H960@87,@82!L:7-T('-E="!B>2!P87)S92@I.PH@("`@("`@
M("\O(&-R96%T92!A;B!A<G)A>2!C86QL960@)&QI<W0@=&AA="!C;VYT86EN
M<R!A(&YE=R!S970@;V8*("`@("`@("`O+R!M871C:&5S(&9O<B!T:&4@=F%R
M:6]U<R!L:7-T+6ET96T@96QE;65N=',N"B`@("`@("`@<')E9U]M871C:%]A
M;&PH"B`@("`@("`@("`@("<]7BA</BLI("@N*EQN*3U5;7,G+`H@("`@("`@
M("`@("`D;6%T8VAE<ULQ72P*("`@("`@("`@("`@)&QI<W0L"B`@("`@("`@
M("`@(%!214=?4T547T]21$52"B`@("`@("`@*3L*("`@("`@("`*("`@("`@
M("`O+R!A('-T86-K(&]F('-T87)T<R!A;F0@96YD<SL@=V4@:V5E<"!T:&ES
M('-O('1H870@=V4@:VYO=R!W:&%T"B`@("`@("`@+R\@:6YD96YT(&QE=F5L
M('=E)W)E(&%T+@H@("`@("`@("1S=&%C:R`](&%R<F%Y*"D["B`@("`@("`@
M"B`@("`@("`@+R\@;&]O<"!T:')O=6=H(&5A8V@@;&ES="UI=&5M(&5L96UE
M;G0N"B`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R`D=F%L6S!=(&ES('1H92!F
M=6QL(&UA=&-H960@;&ES="UI=&5M(&QI;F4*("`@("`@("`@("`@+R\@)'9A
M;%LQ72!I<R!T:&4@;G5M8F5R(&]F(&EN:71I86P@)SXG(&-H87)S("AI;F1E
M;G0@;&5V96PI"B`@("`@("`@("`@("\O("1V86Q;,ET@:7,@=&AE('%U;W1E
M('1E>'0*("`@("`@("`@("`@"B`@("`@("`@("`@("\O('=E(&YU;6)E<B!L
M979E;',@<W1A<G1I;F<@870@,2P@;F]T('IE<F\*("`@("`@("`@("`@)&QE
M=F5L(#T@<W1R;&5N*"1V86Q;,5TI.PH@("`@("`@("`@("`*("`@("`@("`@
M("`@+R\@9V5T('1H92!T97AT(&]F('1H92!L:6YE"B`@("`@("`@("`@("1T
M97AT(#T@)'9A;%LR73L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O(&%D
M9"!A(&QE=F5L('1O('1H92!L:7-T/PH@("`@("`@("`@("!I9B`H)&QE=F5L
M(#X@8V]U;G0H)'-T86-K*2D@>PH@("`@("`@("`@("`@("`@"B`@("`@("`@
M("`@("`@("`O+R!T:&4@8W5R<F5N="!I;F1E;G0@;&5V96P@:7,@9W)E871E
M<B!T:&%N('1H92!N=6UB97(*("`@("`@("`@("`@("`@("\O(&]F('-T86-K
M(&5L96UE;G1S+"!S;R!W92!M=7-T(&)E('-T87)T:6YG(&$@;F5W"B`@("`@
M("`@("`@("`@("`O+R!L979E;"X@('!U<V@@=&AE(&YE=R!L979E;"!O;G1O
M('1H92!S=&%C:R!W:71H(&$@"B`@("`@("`@("`@("`@("`O+R!D=6UM>2!V
M86QU92`H8F]O;&5A;B!T<G5E*2XN+@H@("`@("`@("`@("`@("`@87)R87E?
M<'5S:"@D<W1A8VLL('1R=64I.PH@("`@("`@("`@("`@("`@"B`@("`@("`@
M("`@("`@("`O+R`N+BYA;F0@861D(&$@<W1A<G0@=&]K96X@=&\@=&AE(')E
M='5R;BX*("`@("`@("`@("`@("`@("1R971U<FX@+CT@)'1H:7,M/F%D9%1O
M:V5N*`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`G='EP92<@/3X@)W-T87)T)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@)VQE=F5L)R`]/B`D;&5V96P@+2`Q"B`@("`@("`@("`@("`@
M("`@("`@*0H@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@(`H@
M("`@("`@("`@("`@("`@)')E='5R;B`N/2`B7&XB.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!R96UO=F4@82!L979E;#\*
M("`@("`@("`@("`@=VAI;&4@*&-O=6YT*"1S=&%C:RD@/B`D;&5V96PI('L*
M("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@+R\@87,@;&]N9R!A
M<R!T:&4@<W1A8VL@8V]U;G0@:7,@9W)E871E<B!T:&%N('1H90H@("`@("`@
M("`@("`@("`@+R\@8W5R<F5N="!I;F1E;G0@;&5V96PL('=E(&YE960@=&\@
M96YD(&QI<W0@='EP97,N"B`@("`@("`@("`@("`@("`O+R!C;VYT:6YU92!A
M9&1I;F<@96YD+6QI<W0@=&]K96YS('5N=&EL('1H92!S=&%C:R!C;W5N=`H@
M("`@("`@("`@("`@("`@+R\@86YD('1H92!I;F1E;G0@;&5V96P@87)E('1H
M92!S86UE+@H@("`@("`@("`@("`@("`@87)R87E?<&]P*"1S=&%C:RD["B`@
M("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("1R971U<FX@+CT@)'1H
M:7,M/F%D9%1O:V5N*`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y("@*("`@
M("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E;F0G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G;&5V96PG(#T^(&-O=6YT*"1S=&%C:RD*("`@
M("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`I.PH@("`@("`@
M("`@("`@("`@"B`@("`@("`@("`@("`@("`D<F5T=7)N("X](")<;B(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@"B`@("`@("`@("`@("\O(&%D9"!T
M:&4@;&EN92!T97AT+@H@("`@("`@("`@("`D<F5T=7)N("X]("1T97AT("X@
M(EQN(CL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@=&AE(&QA<W0@
M;&EN92!M87D@:&%V92!B965N(&EN9&5N=&5D+B`@9V\@=&AR;W5G:"!T:&4@
M<W1A8VL*("`@("`@("`O+R!A;F0@8W)E871E(&5N9"UT;VME;G,@=6YT:6P@
M=&AE('-T86-K(&ES(&5M<'1Y+@H@("`@("`@('=H:6QE("AC;W5N="@D<W1A
M8VLI(#X@,"D@>PH@("`@("`@("`@("!A<G)A>5]P;W`H)'-T86-K*3L*("`@
M("`@("`@("`@)')E='5R;B`N/2`D=&AI<RT^861D5&]K96XH"B`@("`@("`@
M("`@("`@("!A<G)A>2`H"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^
M("=E;F0G+`H@("`@("`@("`@("`@("`@("`@("=L979E;"<@/3X@8V]U;G0H
M)'-T86-K*0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH@("`@
M("`@('T*("`@("`@("`*("`@("`@("`O+R!W92=R92!D;VYE(2`@<V5N9"!B
M86-K('1H92!R97!L86-E;65N="!T97AT+@H@("`@("`@(')E='5R;B`B7&XD
M<F5T=7)N(CL*("`@('T*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J
M(%)E;F1E<G,@82!T;VME;B!I;G1O('1E>'0@;6%T8VAI;F<@=&AE(')E<75E
M<W1E9"!F;W)M870N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B`*("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS(%1H92`B;W!T:6]N<R(@
M<&]R=&EO;B!O9B!T:&4@=&]K96X@*'-E8V]N9`H@("`@*B!E;&5M96YT*2X*
M("`@("H@"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!T97AT(')E;F1E<F5D
M(&9R;VT@=&AE('1O:V5N(&]P=&EO;G,N"B`@("`J(`H@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@<F5N9&5R6&AT;6PH)&]P=&EO;G,I"B`@("!["B`@("`@
M("`@)'1Y<&4@/2`D;W!T:6]N<ULG='EP92==.PH@("`@("`@("1L979E;"`]
M("1O<'1I;VYS6R=L979E;"==.PH)"@D)+R\@<V5T('5P(&EN9&5N=&EN9R!S
M;R!T:&%T('1H92!R97-U;'1S(&QO;VL@;FEC93L@=V4@9&\@=&AI<PH)"2\O
M(&EN('1W;R!S=&5P<R!T;R!A=F]I9"!S=')?<&%D(&UA=&AE;6%T:6-S+B`@
M.RTI"@D))'!A9"`]('-T<E]P860H)R<L("1L979E;"P@(EQT(BD["@D))'!A
M9"`]('-T<E]R97!L86-E*")<="(L("<@("`@)RP@)'!A9"D["@D)"@D)+R\@
M<W1A<G1I;F<*"0EI9B`H)'1Y<&4@/3T@)W-T87)T)RD@>PH)"0ER971U<FX@
M(B1P860\8FQO8VMQ=6]T93XB.PH)"7T*"0D*"0DO+R!E;F1I;F<*"0EI9B`H
M)'1Y<&4@/3T@)V5N9"<I('L*"0D)<F5T=7)N("1P860@+B`B/"]B;&]C:W%U
M;W1E/EQN(CL*"0E]"B`@("!]"GT*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O5&5X="]7:6MI+U)U;&4O96UP
M:&%S:7,N<&AP````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8Q,C(`,3`T
M,3<S-C,P,#0`,#(R-#$W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!0875L($TN($IO
M;F5S(#QP;6IO;F5S0&-I87=E8BYN970^("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D
M260Z(&5M<&AA<VES+G!H<"QV(#$N,B`R,#`T+S`Q+S,Q(#$U.C4R.C`X('!M
M:F]N97,@17AP("0*"@HO*BH**B`**B!4:&ES(&-L87-S(&EM<&QE;65N=',@
M82!497AT7U=I:VE?4G5L92!T;R!F:6YD('-O=7)C92!T97AT(&UA<FME9"!F
M;W(**B!E;7!H87-I<R`H:71A;&EC<RD@87,@9&5F:6YE9"!B>2!T97AT('-U
M<G)O=6YD960@8GD@='=O('-I;F=L92UQ=6]T97,N"BH@3VX@<&%R<VEN9RP@
M=&AE('1E>'0@:71S96QF(&ES(&QE9G0@:6X@<&QA8V4L(&)U="!T:&4@<W1A
M<G1I;F<@86YD(&5N9&EN9PHJ(&EN<W1A;F-E<R!O9B!T=V\@<VEN9VQE+7%U
M;W1E<R!A<F4@<F5P;&%C960@=VET:"!T;VME;G,N"BH**B!`875T:&]R(%!A
M=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X**@HJ($!P86-K86=E
M(%1E>'1?5VEK:0HJ"BHO"@IC;&%S<R!497AT7U=I:VE?4G5L95]E;7!H87-I
M<R!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@("`@"B`@("`O*BH*
M("`@("H@"B`@("`J(%1H92!R96=U;&%R(&5X<')E<W-I;VX@=7-E9"!T;R!P
M87)S92!T:&4@<V]U<F-E('1E>'0@86YD(&9I;F0*("`@("H@;6%T8VAE<R!C
M;VYF;W)M:6YG('1O('1H:7,@<G5L92X@(%5S960@8GD@=&AE('!A<G-E*"D@
M;65T:&]D+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@
M("`J($!V87(@<W1R:6YG"B`@("`J(`H@("`@*B!`<V5E('!A<G-E*"D*("`@
M("H@"B`@("`J+PH@("`@"B`@("!V87(@)')E9V5X(#T@(B]<+UPO*"@I?"XJ
M*5PO7"\O52(["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!'96YE
M<F%T97,@82!R97!L86-E;65N="!F;W(@=&AE(&UA=&-H960@=&5X="X@(%1O
M:V5N(&]P=&EO;G,@87)E.@H@("`@*B`*("`@("H@)W1Y<&4G(#T^(%LG<W1A
M<G0G?"=E;F0G72!4:&4@<W1A<G1I;F<@;W(@96YD:6YG('!O:6YT(&]F('1H
M90H@("`@*B!E;7!H87-I>F5D('1E>'0N("!4:&4@=&5X="!I='-E;&8@:7,@
M;&5F="!I;B!T:&4@<V]U<F-E+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y("8D;6%T8VAE<R!4:&4@87)R
M87D@;V8@;6%T8VAE<R!F<F]M('!A<G-E*"DN"B`@("`J"B`@("`J($!R971U
M<FX@<W1R:6YG($$@<&%I<B!O9B!D96QI;6ET960@=&]K96YS('1O(&)E('5S
M960@87,@80H@("`@*B!P;&%C96AO;&1E<B!I;B!T:&4@<V]U<F-E('1E>'0@
M<W5R<F]U;F1I;F<@=&AE('1E>'0@=&\@8F4*("`@("H@96UP:&%S:7IE9"X*
M("`@("H*("`@("HO"B`@("`*("`@(&9U;F-T:6]N('!R;V-E<W,H)B1M871C
M:&5S*0H@("`@>PH@("`@("`@("1S=&%R="`]("1T:&ES+3YA9&14;VME;BAA
M<G)A>2@G='EP92<@/3X@)W-T87)T)RDI.PH@("`@("`@("1E;F0@/2`D=&AI
M<RT^861D5&]K96XH87)R87DH)W1Y<&4G(#T^("=E;F0G*2D["B`@("`@("`@
M<F5T=7)N("1S=&%R="`N("1M871C:&5S6S%=("X@)&5N9#L*("`@('T*("`@
M(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%)E;F1E<G,@82!T;VME;B!I
M;G1O('1E>'0@;6%T8VAI;F<@=&AE(')E<75E<W1E9"!F;W)M870N"B`@("`J
M(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&%R
M<F%Y("1O<'1I;VYS(%1H92`B;W!T:6]N<R(@<&]R=&EO;B!O9B!T:&4@=&]K
M96X@*'-E8V]N9`H@("`@*B!E;&5M96YT*2X*("`@("H@"B`@("`J($!R971U
M<FX@<W1R:6YG(%1H92!T97AT(')E;F1E<F5D(&9R;VT@=&AE('1O:V5N(&]P
M=&EO;G,N"B`@("`J(`H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<F5N9&5R
M6&AT;6PH)&]P=&EO;G,I"B`@("!["@D):68@*"1O<'1I;VYS6R=T>7!E)UT@
M/3T@)W-T87)T)RD@>PH)"0ER971U<FX@)SQE;3XG.PH)"7T*"0D*"0EI9B`H
M)&]P=&EO;G-;)W1Y<&4G72`]/2`G96YD)RD@>PH)"0ER971U<FX@)SPO96T^
M)SL*"0E]"B`@("!]"GT*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U1E>'0O5VEK:2]2=6QE+W!H
M<&-O9&4N<&AP````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,C`R`#$P
M-#$W,S8S,#`T`#`R,C(S,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B
M<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4&%U;"!-+B!*
M;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@
M)$ED.B!P:'!C;V1E+G!H<"QV(#$N,2`R,#`T+S`Q+S`T(#`Q.C,U.C(S('!M
M:F]N97,@17AP("0*"@HO*BH**B`**B!4:&ES(&-L87-S(&EM<&QE;65N=',@
M82!497AT7U=I:VE?4G5L92!T;R!F:6YD('-E8W1I;VYS(&UA<FME9"!A<R!C
M;V1E"BH@97AA;7!L97,N("!";&]C:W,@87)E(&UA<FME9"!A<R!T:&4@<W1R
M:6YG(#QC;V1E/B!O;B!A(&QI;F4@8GD@:71S96QF+`HJ(&9O;&QO=V5D(&)Y
M('1H92!I;FQI;F4@8V]D92!E>&%M<&QE+"!A;F0@=&5R;6EN871E9"!W:71H
M('1H92!S=')I;F<**B`\+V-O9&4^(&]N(&$@;&EN92!B>2!I='-E;&8N("!4
M:&4@8V]D92!E>&%M<&QE(&ES(')U;B!T:')O=6=H('1H90HJ(&YA=&EV92!0
M2%`@:&EG:&QI9VAT7W-T<FEN9R@I(&9U;F-T:6]N('1O(&-O;&]R:7IE(&ET
M+"!T:&5N('-U<G)O=6YD960**B!W:71H(#QP<F4^+BXN/"]P<F4^('1A9W,@
M=VAE;B!R96YD97)E9"!A<R!82%1-3"X**@HJ($!A=71H;W(@4&%U;"!-+B!*
M;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/@HJ"BH@0'!A8VMA9V4@5&5X=%]7
M:6MI"BH**B\*"F-L87-S(%1E>'1?5VEK:5]2=6QE7W!H<&-O9&4@97AT96YD
M<R!497AT7U=I:VE?4G5L92!["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@
M("`@*B!4:&4@<F5G=6QA<B!E>'!R97-S:6]N('5S960@=&\@9FEN9"!S;W5R
M8V4@=&5X="!M871C:&EN9R!T:&ES"B`@("`J(')U;&4N"B`@("`J(`H@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'9A<B!S=')I;F<*("`@
M("H@"B`@("`J+PH@("`@"B`@("!V87(@)')E9V5X(#T@)R]>*%P\<&AP7#XI
M7&XH+BLI7&XH7#Q<+W!H<%P^*2A<<WPD*2]5;7-I)SL*("`@(`H@("`@"B`@
M("`O*BH*("`@("H@"B`@("`J($=E;F5R871E<R!A('1O:V5N(&5N=')Y(&9O
M<B!T:&4@;6%T8VAE9"!T97AT+B`@5&]K96X@;W!T:6]N<R!A<F4Z"B`@("`J
M(`H@("`@*B`G=&5X="<@/3X@5&AE(&9U;&P@;6%T8VAE9"!T97AT+"!N;W0@
M:6YC;'5D:6YG('1H92`\8V]D93X\+V-O9&4^('1A9W,N"B`@("`J(`H@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@*@H@("`@*B!`<&%R86T@87)R87D@)B1M
M871C:&5S(%1H92!A<G)A>2!O9B!M871C:&5S(&9R;VT@<&%R<V4H*2X*("`@
M("H*("`@("H@0')E='5R;B!!(&1E;&EM:71E9"!T;VME;B!N=6UB97(@=&\@
M8F4@=7-E9"!A<R!A('!L86-E:&]L9&5R(&EN"B`@("`J('1H92!S;W5R8V4@
M=&5X="X*("`@("H*("`@("HO"B`@("`*("`@(&9U;F-T:6]N('!R;V-E<W,H
M)B1M871C:&5S*0H@("`@>R`@("`*("`@("`@("`D;W!T:6]N<R`](&%R<F%Y
M*"=T97AT)R`]/B`D;6%T8VAE<ULR72D["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YA9&14;VME;B@D;W!T:6]N<RD@+B`D;6%T8VAE<ULT73L*("`@('T*("`@
M(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%)E;F1E<G,@82!T;VME;B!I
M;G1O('1E>'0@;6%T8VAI;F<@=&AE(')E<75E<W1E9"!F;W)M870N"B`@("`J
M(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&%R
M<F%Y("1O<'1I;VYS(%1H92`B;W!T:6]N<R(@<&]R=&EO;B!O9B!T:&4@=&]K
M96X@*'-E8V]N9`H@("`@*B!E;&5M96YT*2X*("`@("H@"B`@("`J($!R971U
M<FX@<W1R:6YG(%1H92!T97AT(')E;F1E<F5D(&9R;VT@=&AE('1O:V5N(&]P
M=&EO;G,N"B`@("`J(`H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<F5N9&5R
M6&AT;6PH)&]P=&EO;G,I"B`@("!["@D)+R\@861D('1H92!02%`@=&%G<PH)
M"21T97AT(#T@(CP_<&AP7&XB("X@)&]P=&EO;G-;)W1E>'0G72`N(")<;C\^
M(CL@+R\@/#]P:'`*"0D*"0DO+R!C;VYV97)T('1A8G,@=&\@9F]U<B!S<&%C
M97,*"0DD=&5X="`]('-T<E]R97!L86-E*")<="(L("(@("`@(BP@)'1E>'0I
M.PH)"0H)"2\O(&-O;&]R:7IE('1H92!C;V1E(&)L;V-K("AA;'-O(&-O;G9E
M<G1S($A434P@96YT:71I97,@86YD(&%D9',*"0DO+R`\8V]D93XN+BX\+V-O
M9&4^('1A9W,I"@D);V)?<W1A<G0H*3L*"0EH:6=H;&EG:'1?<W1R:6YG*"1T
M97AT*3L*"0DD=&5X="`](&]B7V=E=%]C;VYT96YT<R@I.PH)"6]B7V5N9%]C
M;&5A;B@I.PH)"0H)"2\O(')E<&QA8V4@/&)R("\^('1A9W,@=VET:"!S:6UP
M;&4@;F5W;&EN97,*"0DD=&5X="`]('-T<E]R97!L86-E*"(\8G(@+SXB+"`B
M7&XB+"`D=&5X="D["@D)"@D)+R\@<F5P;&%C92!N;VXM8G)E86MI;F<@<W!A
M8V4@=VET:"!S:6UP;&4@<W!A8V5S"@D))'1E>'0@/2!S=')?<F5P;&%C92@B
M)FYB<W`[(BP@(B`B+"`D=&5X="D["@D)"@D)+R\@9V5T(')I9"!O9B!T:&4@
M;&%S="!N97=L:6YE(&EN<VED92!T:&4@8V]D92!B;&]C:PH)"2\O("AB96-U
M87-E(&AI9VQI9VAT7W-T<FEN9R!P=71S(&]N92!T:&5R92D*"0EI9B`H<W5B
M<W1R*"1T97AT+"`M."D@/3T@(EQN/"]C;V1E/B(I('L*"0D))'1E>'0@/2!S
M=6)S='(H)'1E>'0L(#`L("TX*2`N("(\+V-O9&4^(CL*"0E]"@D)"@D)<F5T
M=7)N(")<;CQP<F4^)'1E>'0\+W!R93Y<;B(["B`@("!]"GT*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U1E>'0O5VEK:2]2=6QE+W1T+G!H<```````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`V,30Q`#$P-#$W,S8S,#`T`#`R,3(S-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*B!V:6TZ
M('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I;VX@
M-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@
M=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M075T:&]R<SH@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/B`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!T="YP:'`L=B`Q+C$@,C`P-"\P,2\P
M-"`P,3HS-3HR,R!P;6IO;F5S($5X<"`D"@H*+RHJ"BH@"BH@5&AI<R!C;&%S
M<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI7U)U;&4@=&\@9FEN9"!S;W5R8V4@
M=&5X="!M87)K960@9F]R"BH@=&5L971Y<&4@*&UO;F]S<&%C92D@87,@9&5F
M:6YE9"!B>2!T97AT('-U<G)O=6YD960@8GD@='=O(&-U<FQY"BH@8G)A8V5S
M+B!/;B!P87)S:6YG+"!T:&4@=&5X="!I='-E;&8@:7,@;&5F="!I;B!P;&%C
M92P@8G5T('1H92!S=&%R=&EN9PHJ(&%N9"!E;F1I;F<@:6YS=&%N8V5S(&]F
M(&-U<FQY(&)R86-E<R!A<F4@<F5P;&%C960@=VET:"!T;VME;G,N"BH**B!`
M875T:&]R(%!A=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X**@HJ
M($!P86-K86=E(%1E>'1?5VEK:0HJ"BHO"@IC;&%S<R!497AT7U=I:VE?4G5L
M95]T="!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@("`@"B`@("`O
M*BH*("`@("H@"B`@("`J(%1H92!R96=U;&%R(&5X<')E<W-I;VX@=7-E9"!T
M;R!P87)S92!T:&4@<V]U<F-E('1E>'0@86YD(&9I;F0*("`@("H@;6%T8VAE
M<R!C;VYF;W)M:6YG('1O('1H:7,@<G5L92X@(%5S960@8GD@=&AE('!A<G-E
M*"D@;65T:&]D+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@
M"B`@("`J($!V87(@<W1R:6YG"B`@("`J(`H@("`@*B!`<V5E('!A<G-E*"D*
M("`@("H@"B`@("`J+PH@("`@"B`@("!V87(@)')E9V5X(#T@(B][>RA[*C\N
M*GTJ/RE]?2]5(CL*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J($=E
M;F5R871E<R!A(')E<&QA8V5M96YT(&9O<B!T:&4@;6%T8VAE9"!T97AT+B`@
M5&]K96X@;W!T:6]N<R!A<F4Z"B`@("`J(`H@("`@*B`G='EP92<@/3X@6R=S
M=&%R="=\)V5N9"==(%1H92!S=&%R=&EN9R!O<B!E;F1I;F<@<&]I;G0@;V8@
M=&AE"B`@("`J('1E;&5T>7!E('1E>'0N("!4:&4@=&5X="!I='-E;&8@:7,@
M;&5F="!I;B!T:&4@<V]U<F-E+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y("8D;6%T8VAE<R!4:&4@87)R
M87D@;V8@;6%T8VAE<R!F<F]M('!A<G-E*"DN"B`@("`J"B`@("`J($!R971U
M<FX@<W1R:6YG($$@<&%I<B!O9B!D96QI;6ET960@=&]K96YS('1O(&)E('5S
M960@87,@80H@("`@*B!P;&%C96AO;&1E<B!I;B!T:&4@<V]U<F-E('1E>'0@
M<W5R<F]U;F1I;F<@=&AE('1E;&5T>7!E('1E>'0N"B`@("`J"B`@("`J+PH@
M("`@"B`@("!F=6YC=&EO;B!P<F]C97-S*"8D;6%T8VAE<RD*("`@('L*("`@
M("`@("`D<W1A<G0@/2`D=&AI<RT^861D5&]K96XH87)R87DH)W1Y<&4G(#T^
M("=S=&%R="<I*3L*("`@("`@("`D96YD(#T@)'1H:7,M/F%D9%1O:V5N*&%R
M<F%Y*"=T>7!E)R`]/B`G96YD)RDI.PH@("`@("`@(')E='5R;B`D<W1A<G0@
M+B`D;6%T8VAE<ULQ72`N("1E;F0["B`@("!]"B`@("`*("`@(`H@("`@+RHJ
M"B`@("`J(`H@("`@*B!296YD97)S(&$@=&]K96X@:6YT;R!T97AT(&UA=&-H
M:6YG('1H92!R97%U97-T960@9F]R;6%T+@H@("`@*B`*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("H@"B`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R!4
M:&4@(F]P=&EO;G,B('!O<G1I;VX@;V8@=&AE('1O:V5N("AS96-O;F0*("`@
M("H@96QE;65N="DN"B`@("`J(`H@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@
M=&5X="!R96YD97)E9"!F<F]M('1H92!T;VME;B!O<'1I;VYS+@H@("`@*B`*
M("`@("HO"B`@("`*("`@(&9U;F-T:6]N(')E;F1E<EAH=&UL*"1O<'1I;VYS
M*0H@("`@>PH@("`@("`@(&EF("@D;W!T:6]N<ULG='EP92==(#T]("=S=&%R
M="<I('L*("`@("`@("`@("`@<F5T=7)N("<\='0^)SL*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@:68@*"1O<'1I;VYS6R=T>7!E)UT@/3T@)V5N9"<I
M('L*("`@("`@("`@("`@<F5T=7)N("<\+W1T/B<["B`@("`@("`@?0H@("`@
M?0I]"C\^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]497AT+U=I:VDO4G5L92]U<FPN<&AP````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`R,30U,0`Q,#0Q-S,V,S`P-``P,C$T,3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!V97)S:6]N
M(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<G,Z(%!A=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=7)L+G!H<"QV(#$N,B`R,#`T+S`Q
M+S,Q(#$U.C4R.C`X('!M:F]N97,@17AP("0*"B\J*@HJ(`HJ(%1H:7,@8VQA
M<W,@:6UP;&5M96YT<R!A(%1E>'1?5VEK:5]2=6QE('1O(&9I;F0@<V]U<F-E
M('1E>'0@;6%R:V5D(&%S(&$**B!54DPN("!687)I;W5S(%523"!M87)K:6YG
M<R!A<F4@<W5P<&]R=&5D.B!I;FQI;F4@*'1H92!54DP@8GD@:71S96QF*2P*
M*B!N=6UB97)E9"!O<B!F;V]T;F]T92!R969E<F5N8V4@*'=H97)E('1H92!5
M4DP@:7,@96YC;&]S960@:6X@<W%U87)E(&)R86-K971S*2P@86YD"BH@;F%M
M960@<F5F97)E;F-E("AW:&5R92!T:&4@55),(&ES(&5N8VQO<V5D(&EN('-Q
M=6%R92!B<F%C:V5T<R!A;F0@:&%S(&$**B!N86UE(&EN8VQU9&5D(&EN<VED
M92!T:&4@8G)A8VME=',I+B`@12YG+CH**@HJ(&EN;&EN92`@("`M+2!H='1P
M.B\O97AA;7!L92YC;VT**B!N=6UB97)E9"`@+2T@6VAT='`Z+R]E>&%M<&QE
M+F-O;5T**B!D97-C<FEB960@+2T@6VAT='`Z+R]E>&%M<&QE+F-O;2!%>&%M
M<&QE($1E<V-R:7!T:6]N70HJ"BH@5VAE;B!R96YD97)I;F<@82!54DP@=&]K
M96XL('1H:7,@=VEL;"!C;VYV97)T(%523',@<&]I;G1I;F<@=&\@82`N9VEF
M+`HJ("YJ<&<L(&]R("YP;F<@:6UA9V4@:6YT;R!A;B!I;FQI;F4@/&EM9R`O
M/B!T86<@*&9O<B!T:&4@)WAH=&UL)PHJ(&9O<FUA="DN"BH**B!`875T:&]R
M(%!A=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X**@HJ($!P86-K
M86=E(%1E>'1?5VEK:0HJ"BHO"@IC;&%S<R!497AT7U=I:VE?4G5L95]U<FP@
M97AT96YD<R!497AT7U=I:VE?4G5L92!["B`@("`*("`@(`H@("`@+RHJ"B`@
M("`J(`H@("`@*B!7:&5N(&1O:6YG(&YU;6)E<F5D(')E9F5R96YC97,@*&9O
M;W1N;W1E+7-T>6QE(')E9F5R96YC97,I+"!W90H@("`@*B!N965D('1O(&ME
M97`@82!R=6YN:6YG(&-O=6YT(&]F(&AO=R!M86YY(')E9F5R96YC97,@=&AE
M<F4@87)E+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@
M("`J($!V87(@:6YT"B`@("`J(`H@("`@*B\*("`@(`H@("`@=F%R("1F;V]T
M;F]T94-O=6YT(#T@,#L*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J
M($%N(&%R<F%Y(&]F(&9I;&5N86UE(&5X=&5N<VEO;G,@=&AA="!I;F1I8V%T
M92!A(&9I;&4@:7,@86X@:6UA9V4N"B`@("`J(`H@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@*B`*("`@("H@0'9A<B!A<G)A>0H@("`@*B`*("`@("HO"B`@
M("`*("`@('9A<B`D:6UG7V5X="`](&%R<F%Y*"<N:G!G)RP@)RYP;F<G+"`G
M+F=I9B<I.PH@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@02!S;VUE
M=VAA="!C;VUP;&5X('!A<G-I;F<@;65T:&]D('1O(&9I;F0@=&AR964@9&EF
M9F5R96YT(&MI;F1S"B`@("`J(&]F(%523',@:6X@=&AE('-O=7)C92!T97AT
M+@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("HO"B`@
M("`*("`@(&9U;F-T:6]N('!A<G-E*"D*("`@('L*("`@("`@("`D=&AI<RT^
M<F5G97@@/2`B*&AT='`Z?&UA:6QT;SI\:'1T<',Z?&9T<#I\9V]P:&5R.GQN
M97=S.BDH6UX@7%PO7")<)UTJ7%PO*2I;7B!<7'1<7&Y<7"]<(EPG>R1T:&ES
M+3Y?=VEK:2T^9&5L:6U]72I;02U:82UZ,"TY7%PO/STF?E]=(CL*"B`@("`@
M("`@+R\@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@("`@("`@("\O(`H@("`@("`@("\O
M($1E<V-R:6)E9"UR969E<F5N8V4@*&YA;65D*2!54DQS+@H@("`@("`@("\O
M(`H@("`@("`@(`H@("`@("`@("\O('1H92!R96=U;&%R(&5X<')E<W-I;VX@
M9F]R('1H:7,@:VEN9"!O9B!54DP*("`@("`@("`D=&UP7W)E9V5X(#T@)R]<
M6R@G("X@)'1H:7,M/G)E9V5X("X@)RD@*%M>7%U=*RE<72\G.PH@("`@("`@
M(`H@("`@("`@("\O('5S92!A(&-U<W1O;2!C86QL8F%C:R!P<F]C97-S:6YG
M(&UE=&AO9"!T;R!G96YE<F%T90H@("`@("`@("\O('1H92!R97!L86-E;65N
M="!T97AT(&9O<B!M871C:&5S+@H@("`@("`@("1T:&ES+3Y?=VEK:2T^7W-O
M=7)C92`]('!R96=?<F5P;&%C95]C86QL8F%C:R@*("`@("`@("`@("`@)'1M
M<%]R96=E>"P*("`@("`@("`@("`@87)R87DH)B1T:&ES+"`G<')O8V5S<T1E
M<V-R)RDL"B`@("`@("`@("`@("1T:&ES+3Y?=VEK:2T^7W-O=7)C90H@("`@
M("`@("D["B`@("`@("`@"B`@("`@("`@"B`@("`@("`@+R\@+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H@("`@("`@("\O(`H@("`@("`@("\O($YU;6)E<F5D+7)E9F5R
M96YC92`H9F]O=&YO=&4M<W1Y;&4I(%523',N"B`@("`@("`@+R\@"B`@("`@
M("`@"B`@("`@("`@+R\@=&AE(')E9W5L87(@97AP<F5S<VEO;B!F;W(@=&AI
M<R!K:6YD(&]F(%523`H@("`@("`@("1T;7!?<F5G97@@/2`G+UQ;*"<@+B`D
M=&AI<RT^<F5G97@@+B`G*5Q=+U4G.PH@("`@("`@(`H@("`@("`@("\O('5S
M92!A(&-U<W1O;2!C86QL8F%C:R!P<F]C97-S:6YG(&UE=&AO9"!T;R!G96YE
M<F%T90H@("`@("`@("\O('1H92!R97!L86-E;65N="!T97AT(&9O<B!M871C
M:&5S+@H@("`@("`@("1T:&ES+3Y?=VEK:2T^7W-O=7)C92`]('!R96=?<F5P
M;&%C95]C86QL8F%C:R@*("`@("`@("`@("`@)'1M<%]R96=E>"P*("`@("`@
M("`@("`@87)R87DH)B1T:&ES+"`G<')O8V5S<T9O;W1N;W1E)RDL"B`@("`@
M("`@("`@("1T:&ES+3Y?=VEK:2T^7W-O=7)C90H@("`@("`@("D["B`@("`@
M("`@"B`@("`@("`@"B`@("`@("`@+R\@+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@("`@
M("`@("\O(`H@("`@("`@("\O($YO<FUA;"!I;FQI;F4@55),<RX*("`@("`@
M("`O+R`*("`@("`@("`*("`@("`@("`O+R!T:&4@<F5G=6QA<B!E>'!R97-S
M:6]N(&9O<B!T:&ES(&MI;F0@;V8@55),"B`@("`@("`@)'1M<%]R96=E>"`]
M("<O*%Y\6UY!+5IA+7I=*2@G("X@)'1H:7,M/G)E9V5X("X*("`@("`@("`@
M("`@)RDH7"1\6UY<7"\_/29^02U:82UZ,"TY72DO)SL*"B`@("`@("`@+R\@
M=7-E('1H92!S=&%N9&%R9"!C86QL8F%C:R!F;W(@:6YL:6YE(%523',*("`@
M("`@("`D=&AI<RT^7W=I:VDM/E]S;W5R8V4@/2!P<F5G7W)E<&QA8V5?8V%L
M;&)A8VLH"B`@("`@("`@("`@("1T;7!?<F5G97@L"B`@("`@("`@("`@(&%R
M<F%Y*"8D=&AI<RP@)W!R;V-E<W,G*2P*("`@("`@("`@("`@)'1H:7,M/E]W
M:6MI+3Y?<V]U<F-E"B`@("`@("`@*3L*("`@('T*("`@(`H@("`@"B`@("`O
M*BH*("`@("H@"B`@("`J(%!R;V-E<W,@:6YL:6YE(%523',@86YD(')E='5R
M;B!R97!L86-E;65N="!T97AT('=I=&@@82!D96QI;6ET960*("`@("H@=&]K
M96XN"B`@("`J(`H@("`@*B!4;VME;B!O<'1I;VYS(&%R93H*("`@("H@("`@
M("=T>7!E)R`]/B!;)VEN;&EN92=\)V9O;W1N;W1E)WPG9&5S8W(G72!T:&4@
M='EP92!O9B!54DP*("`@("H@("`@("=H<F5F)R`]/B!T:&4@55),(&QI;FL@
M:')E9B!P;W)T:6]N"B`@("`J("`@("`G=&5X="<@/3X@=&AE(&1I<W!L87EE
M9"!T97AT(&]F('1H92!54DP@;&EN:PH@("`@*B`*("`@("H@0'!A<F%M(&%R
M<F%Y("8D;6%T8VAE<PH@("`@*B`*("`@("H@0'!A<F%M(&%R<F%Y("1M871C
M:&5S($%N(&%R<F%Y(&]F(&UA=&-H97,@9G)O;2!T:&4@<&%R<V4H*2!M971H
M;V0*("`@("H@87,@9V5N97)A=&5D(&)Y('!R96=?<F5P;&%C95]C86QL8F%C
M:RX@("1M871C:&5S6S!=(&ES('1H92!F=6QL"B`@("`J(&UA=&-H960@<W1R
M:6YG+"`D;6%T8VAE<ULQ72!I<R!T:&4@9FER<W0@;6%T8VAE9"!P871T97)N
M+`H@("`@*B`D;6%T8VAE<ULR72!I<R!T:&4@<V5C;VYD(&UA=&-H960@<&%T
M=&5R;BP@86YD('-O(&]N+@H@("`@*B`*("`@("H@0')E='5R;B!S=')I;F<@
M5&AE('!R;V-E<W-E9"!T97AT(')E<&QA8V5M96YT+@H@("`@*B`*("`@("HO
M(`H@("`@"B`@("!F=6YC=&EO;B!P<F]C97-S*"8D;6%T8VAE<RD*("`@('L*
M("`@("`@("`O+R!S970@;W!T:6]N<PH@("`@("`@("1O<'1I;VYS(#T@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G:6YL:6YE)RP*("`@("`@("`@
M("`@)VAR968G(#T^("1M871C:&5S6S)=+`H@("`@("`@("`@("`G=&5X="<@
M/3X@)&UA=&-H97-;,ET*("`@("`@("`I.PH@("`@("`@(`H@("`@("`@("\O
M('1O:V5N:7IE"B`@("`@("`@<F5T=7)N("1M871C:&5S6S%=("X@)'1H:7,M
M/F%D9%1O:V5N*"1O<'1I;VYS*2`N("1M871C:&5S6S5=.PH@("`@?0H@("`@
M"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@4')O8V5S<R!N=6UB97)E9"`H
M9F]O=&YO=&4I(%523',@86YD(')E='5R;B!R97!L86-E;65N="!T97AT('=I
M=&@*("`@("H@82!D96QI;6ET960@=&]K96XN"B`@("`J(`H@("`@*B!4;VME
M;B!O<'1I;VYS(&%R93H*("`@("H@("`@("=T>7!E)R`]/B!;)VEN;&EN92=\
M)V9O;W1N;W1E)WPG9&5S8W(G72!T:&4@='EP92!O9B!54DP*("`@("H@("`@
M("=H<F5F)R`]/B!T:&4@55),(&QI;FL@:')E9B!P;W)T:6]N"B`@("`J("`@
M("`G=&5X="<@/3X@=&AE(&1I<W!L87EE9"!T97AT(&]F('1H92!54DP@;&EN
M:PH@("`@*B`*("`@("H@0'!A<F%M(&%R<F%Y("8D;6%T8VAE<PH@("`@*B`*
M("`@("H@0'!A<F%M(&%R<F%Y("1M871C:&5S($%N(&%R<F%Y(&]F(&UA=&-H
M97,@9G)O;2!T:&4@<&%R<V4H*2!M971H;V0*("`@("H@87,@9V5N97)A=&5D
M(&)Y('!R96=?<F5P;&%C95]C86QL8F%C:RX@("1M871C:&5S6S!=(&ES('1H
M92!F=6QL"B`@("`J(&UA=&-H960@<W1R:6YG+"`D;6%T8VAE<ULQ72!I<R!T
M:&4@9FER<W0@;6%T8VAE9"!P871T97)N+`H@("`@*B`D;6%T8VAE<ULR72!I
M<R!T:&4@<V5C;VYD(&UA=&-H960@<&%T=&5R;BP@86YD('-O(&]N+@H@("`@
M*B`*("`@("H@0')E='5R;B!S=')I;F<@5&AE('!R;V-E<W-E9"!T97AT(')E
M<&QA8V5M96YT+@H@("`@*B`*("`@("HO(`H@("`@"B`@("!F=6YC=&EO;B!P
M<F]C97-S1F]O=&YO=&4H)B1M871C:&5S*0H@("`@>PH@("`@("`@("\O(&ME
M97`@82!R=6YN:6YG(&-O=6YT(&9O<B!F;V]T;F]T97,@"B`@("`@("`@)'1H
M:7,M/F9O;W1N;W1E0V]U;G0K*SL*("`@("`@("`*("`@("`@("`O+R!S970@
M;W!T:6]N<PH@("`@("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G9F]O=&YO=&4G+`H@("`@("`@("`@("`G:')E9B<@/3X@
M)&UA=&-H97-;,5TL"B`@("`@("`@("`@("=T97AT)R`]/B`D=&AI<RT^9F]O
M=&YO=&5#;W5N=`H@("`@("`@("D["B`@("`@("`@"B`@("`@("`@+R\@=&]K
M96YI>F4*("`@("`@("!R971U<FX@)'1H:7,M/F%D9%1O:V5N*"1O<'1I;VYS
M*3L*("`@('T*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%!R;V-E
M<W,@9&5S8W)I8F5D+7)E9F5R96YC92`H;F%M960M<F5F97)E;F-E*2!54DQS
M(&%N9"!R971U<FX*("`@("H@<F5P;&%C96UE;G0@=&5X="!W:71H(&$@9&5L
M:6UI=&5D('1O:V5N+@H@("`@*B`*("`@("H@5&]K96X@;W!T:6]N<R!A<F4Z
M"B`@("`J("`@("`G='EP92<@/3X@6R=I;FQI;F4G?"=F;V]T;F]T92=\)V1E
M<V-R)UT@=&AE('1Y<&4@;V8@55),"B`@("`J("`@("`G:')E9B<@/3X@=&AE
M(%523"!L:6YK(&AR968@<&]R=&EO;@H@("`@*B`@("`@)W1E>'0G(#T^('1H
M92!D:7-P;&%Y960@=&5X="!O9B!T:&4@55),(&QI;FL*("`@("H@"B`@("`J
M($!P87)A;2!A<G)A>2`F)&UA=&-H97,*("`@("H@"B`@("`J($!P87)A;2!A
M<G)A>2`D;6%T8VAE<R!!;B!A<G)A>2!O9B!M871C:&5S(&9R;VT@=&AE('!A
M<G-E*"D@;65T:&]D"B`@("`J(&%S(&=E;F5R871E9"!B>2!P<F5G7W)E<&QA
M8V5?8V%L;&)A8VLN("`D;6%T8VAE<ULP72!I<R!T:&4@9G5L;`H@("`@*B!M
M871C:&5D('-T<FEN9RP@)&UA=&-H97-;,5T@:7,@=&AE(&9I<G-T(&UA=&-H
M960@<&%T=&5R;BP*("`@("H@)&UA=&-H97-;,ET@:7,@=&AE('-E8V]N9"!M
M871C:&5D('!A='1E<FXL(&%N9"!S;R!O;BX*("`@("H@"B`@("`J($!R971U
M<FX@<W1R:6YG(%1H92!P<F]C97-S960@=&5X="!R97!L86-E;65N="X*("`@
M("H@"B`@("`J+R`*("`@(`H@("`@9G5N8W1I;VX@<')O8V5S<T1E<V-R*"8D
M;6%T8VAE<RD*("`@('L*("`@("`@("`O+R!S970@;W!T:6]N<PH@("`@("`@
M("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&5S
M8W(G+`H@("`@("`@("`@("`G:')E9B<@/3X@)&UA=&-H97-;,5TL"B`@("`@
M("`@("`@("=T97AT)R`]/B`D;6%T8VAE<ULT70H@("`@("`@("D["B`@("`@
M("`@"B`@("`@("`@+R\@=&]K96YI>F4*("`@("`@("!R971U<FX@)'1H:7,M
M/F%D9%1O:V5N*"1O<'1I;VYS*3L*("`@('T*("`@(`H@("`@"B`@("`O*BH*
M("`@("H@"B`@("`J(%)E;F1E<G,@82!T;VME;B!I;G1O('1E>'0@;6%T8VAI
M;F<@=&AE(')E<75E<W1E9"!F;W)M870N"B`@("`J(`H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS(%1H
M92`B;W!T:6]N<R(@<&]R=&EO;B!O9B!T:&4@=&]K96X@*'-E8V]N9`H@("`@
M*B!E;&5M96YT*2X*("`@("H@"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!T
M97AT(')E;F1E<F5D(&9R;VT@=&AE('1O:V5N(&]P=&EO;G,N"B`@("`J(`H@
M("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<F5N9&5R6&AT;6PH)&]P=&EO;G,I
M"B`@("!["B`@("`@("`@+R\@8W)E871E(&QO8V%L('9A<FEA8FQE<R!F<F]M
M('1H92!O<'1I;VYS(&%R<F%Y("AT97AT+`H@("`@("`@("\O(&AR968L('1Y
M<&4I"B`@("`@("`@97AT<F%C="@D;W!T:6]N<RD["B`@("`@("`@"B`@("`@
M("`@+R\@9FEN9"!T:&4@<FEG:'1M;W-T(&1O="!A;F0@9&5T97)M:6YE('1H
M92!F:6QE;F%M90H@("`@("`@("\O(&5X=&5N<VEO;BX*("`@("`@("`D<&]S
M(#T@<W1R<G!O<R@D:')E9BP@)RXG*3L*("`@("`@("`D97AT(#T@<W1R=&]L
M;W=E<BAS=6)S='(H)&AR968L("1P;W,I*3L*("`@("`@("`*("`@("`@("`O
M+R!D;V5S('1H92!F:6QE;F%M92!E>'1E;G-I;VX@:6YD:6-A=&4@86X@:6UA
M9V4@9FEL93\*("`@("`@("!I9B`H:6Y?87)R87DH)&5X="P@)'1H:7,M/FEM
M9U]E>'0I*2!["B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!C<F5A=&4@
M86QT('1E>'0@9F]R('1H92!I;6%G90H@("`@("`@("`@("!I9B`H(2!I<W-E
M="@D=&5X="D@?'P@)'1E>'0@/3T@)R<I('L*("`@("`@("`@("`@("`@("1T
M97AT(#T@8F%S96YA;64H)&AR968I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(`H@("`@("`@("`@("`O+R!G96YE<F%T92!A;B!I;6%G92!T86<*("`@
M("`@("`@("`@)&]U='!U="`]("(\:6UG('-R8SU<(B1H<F5F7"(@86QT/5PB
M)'1E>'1<(B`O/B(["B`@("`@("`@("`@(`H@("`@("`@('T@96QS92!["B`@
M("`@("`@"B`@("`@("`@("`@("\O(&=E;F5R871E(&$@<F5G=6QA<B!L:6YK
M("AN;W0@86X@:6UA9V4I"B`@("`@("`@("`@("1O=71P=70@/2`B/&$@:')E
M9CU<(B1H<F5F7"(^)'1E>'0\+V$^(CL*("`@("`@("`@("`@"B`@("`@("`@
M("`@("\O(&UA:V4@;G5M8F5R960@<F5F97)E;F-E<R!L;V]K(&QI:V4@9F]O
M=&YO=&5S"B`@("`@("`@("`@(&EF("@D='EP92`]/2`G9F]O=&YO=&4G*2![
M"B`@("`@("`@("`@("`@("`D;W5T<'5T(#T@)SQS=7`^)R`N("1O=71P=70@
M+B`G/"]S=7`^)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`*
M("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*?0H_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U1E>'0O5VEK:2]2=6QE+VAO<FEZ+G!H<```````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S8U`#$P-#$W,S8S,#`T`#`R,3<U-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0
M('9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R<SH@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W
M96(N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!H;W)I>BYP:'`L=B`Q
M+C$@,C`P-"\P,2\P-"`P,3HS-3HR,R!P;6IO;F5S($5X<"`D"@H*+RHJ"BH@
M"BH@5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI7U)U;&4@=&\@
M9FEN9"!S;W5R8V4@=&5X="!M87)K960@=&\**B!B92!A(&AO<FEZ;VYT86P@
M<G5L92P@87,@9&5F:6YE9"!B>2!F;W5R(&1A<VAE9"!O;B!T:&5I<B!O=VX@
M;&EN92X**@HJ($!A=71H;W(@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W
M96(N;F5T/@HJ"BH@0'!A8VMA9V4@5&5X=%]7:6MI"BH**B\*"F-L87-S(%1E
M>'1?5VEK:5]2=6QE7VAO<FEZ(&5X=&5N9',@5&5X=%]7:6MI7U)U;&4@>PH@
M("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@5&AE(')E9W5L87(@97AP
M<F5S<VEO;B!U<V5D('1O('!A<G-E('1H92!S;W5R8V4@=&5X="!A;F0@9FEN
M9`H@("`@*B!M871C:&5S(&-O;F9O<FUI;F<@=&\@=&AI<R!R=6QE+B`@57-E
M9"!B>2!T:&4@<&%R<V4H*2!M971H;V0N"B`@("`J(`H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*B`*("`@("H@0'9A<B!S=')I;F<*("`@("H@"B`@("`J
M($!S964@<&%R<V4H*0H@("`@*B`*("`@("HO"B`@("`*("`@('9A<B`D<F5G
M97@@/2`G+UXH6RU=>S0L?2DD+VTG.PH@("`@"B`@("`*("`@("\J*@H@("`@
M*B`*("`@("H@1V5N97)A=&5S(&$@<F5P;&%C96UE;G0@=&]K96X@9F]R('1H
M92!M871C:&5D('1E>'0N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@*@H@("`@*B!`<&%R86T@87)R87D@)B1M871C:&5S(%1H92!A<G)A>2!O
M9B!M871C:&5S(&9R;VT@<&%R<V4H*2X*("`@("H*("`@("H@0')E='5R;B!S
M=')I;F<@02!T;VME;B!M87)K:6YG('1H92!H;W)I>F]N=&%L(')U;&4N"B`@
M("`J"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P<F]C97-S*"8D;6%T8VAE
M<RD*("`@('L@("`@"B`@("`@("`@<F5T=7)N("1T:&ES+3YA9&14;VME;B@I
M.PH@("`@?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@4F5N9&5R
M<R!A('1O:V5N(&EN=&\@=&5X="!M871C:&EN9R!T:&4@<F5Q=65S=&5D(&9O
M<FUA="X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@
M*B!`<&%R86T@87)R87D@)&]P=&EO;G,@5&AE(")O<'1I;VYS(B!P;W)T:6]N
M(&]F('1H92!T;VME;B`H<V5C;VYD"B`@("`J(&5L96UE;G0I+@H@("`@*B`*
M("`@("H@0')E='5R;B!S=')I;F<@5&AE('1E>'0@<F5N9&5R960@9G)O;2!T
M:&4@=&]K96X@;W!T:6]N<RX*("`@("H@"B`@("`J+PH@("`@"B`@("!F=6YC
M=&EO;B!R96YD97)8:'1M;"@D;W!T:6]N<RD*("`@('L*("`@("`@("!R971U
M<FX@(CQH<B`O/EQN(CL*("`@('T*?0H_/@``````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U1E>'0O5VEK:2]2=6QE+V5N=&ET:65S
M+G!H<```````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,#$P`#$P-#$W,S8S
M,#`T`#`R,C0R-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT
M('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4&%U;"!-+B!*;VYE<R`\
M<&UJ;VYE<T!C:6%W96(N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!E
M;G1I=&EE<RYP:'`L=B`Q+C$@,C`P-"\P,2\P-"`P,3HS-3HR,R!P;6IO;F5S
M($5X<"`D"@H*+RHJ"BH@"BH@5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X
M=%]7:6MI7U)U;&4@=&\@8V]N=F5R="!(5$U,(&5N=&ET:65S(&EN('1H90HJ
M('-O=7)C92!T97AT+@HJ"BH@0&%U=&AO<B!0875L($TN($IO;F5S(#QP;6IO
M;F5S0&-I87=E8BYN970^"BH**B!`<&%C:V%G92!497AT7U=I:VD**@HJ+PH*
M8VQA<W,@5&5X=%]7:6MI7U)U;&5?96YT:71I97,@97AT96YD<R!497AT7U=I
M:VE?4G5L92!["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!3:6UP
M;&4@<&%R<VEN9R!M971H;V0@=&\@87!P;'D@=&AE(')U;&4N"B`@("`J"B`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@<&%R<V4H*0H@("`@>PH@("`@("`@("\O(&9I<G-T+"!D96-O9&4@
M86YY(&5N=&ET:65S(&%L<F5A9'D@:6X@=&AE('1E>'0@<V\@=&AA="!T:&5Y
M"B`@("`@("`@+R\@9&]N)W0@9V5T(&1O=6)L92UE;F-O9&5D"B`@("`@("`@
M)'1R86YS7W1A8FQE(#T@9V5T7VAT;6Q?=')A;G-L871I;VY?=&%B;&4H2%1-
M3%]34$5#24%,0TA!4E,I.PH@("`@("`@("1T:&ES+3Y?=VEK:2T^7W-O=7)C
M92`]('-T<G1R*"1T:&ES+3Y?=VEK:2T^7W-O=7)C92P*("`@("`@("`@("`@
M87)R87E?9FQI<"@D=')A;G-?=&%B;&4I*3L*("`@("`@("`@("`@"B`@("`@
M("`@+R\@;F]W(&5N8V]D92!A;&P@:'1M;"!S<&5C:6%L(&-H87)A8W1E<G,*
M("`@("`@("`D=&AI<RT^7W=I:VDM/E]S;W5R8V4@/2!H=&UL<W!E8VEA;&-H
M87)S*"1T:&ES+3Y?=VEK:2T^7W-O=7)C92D["B`@("!]"@I]"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U1E>'0O5VEK:2]2
M=6QE+V)O;&0N<&AP````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V
M,3<P`#$P-#$W,S8S,#`T`#`R,34S,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4&%U
M;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\*+R\@)$ED.B!B;VQD+G!H<"QV(#$N,2`R,#`T+S`Q+S,Q(#$U.C4R.C`X
M('!M:F]N97,@17AP("0*"@HO*BH**B`**B!4:&ES(&-L87-S(&EM<&QE;65N
M=',@82!497AT7U=I:VE?4G5L92!T;R!F:6YD('-O=7)C92!T97AT(&UA<FME
M9"!F;W(**B!S=')O;F<@96UP:&%S:7,@*&)O;&0I(&%S(&1E9FEN960@8GD@
M=&5X="!S=7)R;W5N9&5D(&)Y('1H<F5E"BH@<VEN9VQE+7%U;W1E<RX@3VX@
M<&%R<VEN9RP@=&AE('1E>'0@:71S96QF(&ES(&QE9G0@:6X@<&QA8V4L(&)U
M="!T:&4**B!S=&%R=&EN9R!A;F0@96YD:6YG(&EN<W1A;F-E<R!O9B!T:')E
M92!S:6YG;&4M<75O=&5S(&%R92!R97!L86-E9"!W:71H"BH@=&]K96YS+@HJ
M"BH@0&%U=&AO<B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^
M"BH**B!`<&%C:V%G92!497AT7U=I:VD**@HJ+PH*8VQA<W,@5&5X=%]7:6MI
M7U)U;&5?8F]L9"!E>'1E;F1S(%1E>'1?5VEK:5]2=6QE('L*("`@(`H@("`@
M"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!R96=U;&%R(&5X<')E<W-I;VX@
M=7-E9"!T;R!P87)S92!T:&4@<V]U<F-E('1E>'0@86YD(&9I;F0*("`@("H@
M;6%T8VAE<R!C;VYF;W)M:6YG('1O('1H:7,@<G5L92X@(%5S960@8GD@=&AE
M('!A<G-E*"D@;65T:&]D+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("H@"B`@("`J($!V87(@<W1R:6YG"B`@("`J(`H@("`@*B!`<V5E('!A
M<G-E*"D*("`@("H@"B`@("`J+PH@("`@"B`@("!V87(@)')E9V5X(#T@("(O
M)R<G*"@I?%M>)UTN*BDG)R<O52(["B`@("`*("`@(`H@("`@+RHJ"B`@("`J
M(`H@("`@*B!'96YE<F%T97,@82!R97!L86-E;65N="!F;W(@=&AE(&UA=&-H
M960@=&5X="X@(%1O:V5N(&]P=&EO;G,@87)E.@H@("`@*B`*("`@("H@)W1Y
M<&4G(#T^(%LG<W1A<G0G?"=E;F0G72!4:&4@<W1A<G1I;F<@;W(@96YD:6YG
M('!O:6YT(&]F('1H90H@("`@*B!E;7!H87-I>F5D('1E>'0N("!4:&4@=&5X
M="!I='-E;&8@:7,@;&5F="!I;B!T:&4@<V]U<F-E+@H@("`@*B`*("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y("8D;6%T
M8VAE<R!4:&4@87)R87D@;V8@;6%T8VAE<R!F<F]M('!A<G-E*"DN"B`@("`J
M"B`@("`J($!R971U<FX@02!P86ER(&]F(&1E;&EM:71E9"!T;VME;G,@=&\@
M8F4@=7-E9"!A<R!A('!L86-E:&]L9&5R(&EN"B`@("`J('1H92!S;W5R8V4@
M=&5X="!S=7)R;W5N9&EN9R!T:&4@=&5X="!T;R!B92!E;7!H87-I>F5D+@H@
M("`@*@H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<')O8V5S<R@F)&UA=&-H
M97,I"B`@("!["B`@("`@("`@)'-T87)T(#T@)'1H:7,M/F%D9%1O:V5N*&%R
M<F%Y*"=T>7!E)R`]/B`G<W1A<G0G*2D["B`@("`@("`@)&5N9"`]("1T:&ES
M+3YA9&14;VME;BAA<G)A>2@G='EP92<@/3X@)V5N9"<I*3L*("`@("`@("!R
M971U<FX@)'-T87)T("X@)&UA=&-H97-;,5T@+B`D96YD.PH@("`@?0H@("`@
M"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@4F5N9&5R<R!A('1O:V5N(&EN
M=&\@=&5X="!M871C:&EN9R!T:&4@<F5Q=65S=&5D(&9O<FUA="X*("`@("H@
M"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@*B!`<&%R86T@87)R
M87D@)&]P=&EO;G,@5&AE(")O<'1I;VYS(B!P;W)T:6]N(&]F('1H92!T;VME
M;B`H<V5C;VYD"B`@("`J(&5L96UE;G0I+@H@("`@*B`*("`@("H@0')E='5R
M;B!S=')I;F<@5&AE('1E>'0@<F5N9&5R960@9G)O;2!T:&4@=&]K96X@;W!T
M:6]N<RX*("`@("H@"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!R96YD97)8
M:'1M;"@D;W!T:6]N<RD*("`@('L*("`@("`@("!I9B`H)&]P=&EO;G-;)W1Y
M<&4G72`]/2`G<W1A<G0G*2!["B`@("`@("`@("`@(')E='5R;B`G/&(^)SL*
M("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"1O<'1I;VYS6R=T>7!E
M)UT@/3T@)V5N9"<I('L*("`@("`@("`@("`@<F5T=7)N("<\+V(^)SL*("`@
M("`@("!]"B`@("!]"GT*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]497AT+U=I:VDO
M4G5L92]F<F5E;&EN:RYP:'``````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-#$Q-@`Q,#0Q-S,V,S`P-``P,C(T,#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD
M=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!V97)S:6]N(#0@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%!A
M=6P@32X@2F]N97,@/'!M:F]N97-`8VEA=V5B+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O"B\O("1)9#H@9G)E96QI;FLN<&AP+'8@,2XS(#(P,#0O,#$O,S$@,34Z
M-3(Z,#@@<&UJ;VYE<R!%>'`@)`H*"B\J*@HJ(`HJ(%1H:7,@8VQA<W,@:6UP
M;&5M96YT<R!A(%1E>'1?5VEK:5]2=6QE('1O(&9I;F0@<V]U<F-E('1E>'0@
M;6%R:V5D(&%S(&$**B!W:6MI(&9R965L:6YK+"!A;F0@875T;VUA=&EC86QL
M>2!C<F5A=&4@82!L:6YK('1O('1H870@<&%G92X**B`**B!!(&9R965L:6YK
M(&ES(&%N>2!P86=E(&YA;64@;F]T(&-O;F9O<FUI;F<@=&\@=&AE('-T86YD
M87)D"BH@4W1U9&QY0V%P<U-T>6QE(&9O<B!A('=I:VD@<&%G92!N86UE+B`@
M1F]R(&5X86UP;&4L(&$@<&%G92!N;W)M86QL>0HJ(&YA;65D($UY2&]M95!A
M9V4@8V%N(&)E(')E;F%M960@86YD(')E9F5R<F5D('1O(&%S("@H37D@2&]M
M92!086=E*2D@+2T**B!N;W1E('1H92!S<&%C97,@:6X@=&AE('!A9V4@;F%M
M92X@(%EO=2!C86X@86QS;R!M86ME(&$@(FYI8V4M;&]O:VEN9R(**B!L:6YK
M('=I=&AO=70@<F5N86UI;F<@=&AE('1A<F=E="!P86=E.R!E+F<N+"`H*$UY
M2&]M95!A9V5\37D@2&]M90HJ(%!A9V4I*2X@($9I;F%L;'DL('EO=2!C86X@
M=7-E(&YA;65D(&%N8VAO<G,@;VX@=&AE('1A<F=E="!P86=E.@HJ("@H37E(
M;VUE4&%G97Q->2!(;VUE(%!A9V4C4V5C=&EO;C$I*2X**@HJ($!A=71H;W(@
M4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/@HJ"BH@0'!A8VMA
M9V4@5&5X=%]7:6MI"BH**B\*"F-L87-S(%1E>'1?5VEK:5]2=6QE7V9R965L
M:6YK(&5X=&5N9',@5&5X=%]7:6MI7U)U;&4@>PH@("`@"B`@("`*("`@("\J
M*@H@("`@*B`*("`@("H@0V]N<W1R=6-T;W(N("!792!O=F5R<FED92!T:&4@
M5&5X=%]7:6MI7U)U;&4@8V]N<W1R=6-T;W(@<V\@=V4@8V%N"B`@("`J(&5X
M<&QI8VET;'D@8V]M;65N="!E86-H('!A<G0@;V8@=&AE("1R96=E>"!P<F]P
M97)T>2X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@
M*B!`<&%R86T@;V)J96-T("8D;V)J(%1H92!C86QL:6YG(")P87)E;G0B(%1E
M>'1?5VEK:2!O8FIE8W0N"B`@("`J(`H@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE(%1H92!T;VME;B!N86UE('1O('5S92!F;W(@=&AI<R!R=6QE+@H@("`@
M*B`*("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%1E>'1?5VEK:5]2=6QE7V9R
M965L:6YK*"8D;V)J+"`D;F%M92D*("`@('L*("`@("`@("!P87)E;G0Z.E1E
M>'1?5VEK:5]2=6QE*"1O8FHL("1N86UE*3L*("`@("`@("`*("`@("`@("`D
M=&AI<RT^<F5G97@@/0H@("`@("`@("`@("`G+R<@+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4U1!4E0@
M<F5G97@*("`@("`@("`@("`@(EQ<*%Q<*"(@+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&1O=6)L92!O<&5N+7!A
M<F5N<PH@("`@("`@("`@("`B*"(@+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4U1!4E0@9G)E96QI;FL@
M<&%G92!P871T97(*("`@("`@("`@("`@(ELM02U:82UZ,"TY(%\K7%PO+BP[
M.B$_)UPB7%Q;7%Q=7%Q[7%Q])EQX8S`M7'AF9ETK(B`N("\O(#$@;W(@;6]R
M92!O9B!J=7-T(&%B;W5T(&%N>2!C:&%R86-T97(*("`@("`@("`@("`@(BDB
M("X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O($5.1"`@9G)E96QI;FL@<&%G92!P871T97)N"B`@("`@("`@
M("`@("(H(B`N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!35$%25"!D:7-P;&%Y+6YA;64*("`@("`@("`@
M("`@(EQ\(B`N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&$@<&EP92!T;R!S=&%R="!T:&4@9&ES<&QA>2!N
M86UE"B`@("`@("`@("`@(");+4$M6F$M>C`M.2!?*UQ<+RXL.SHA/R=<(EQ<
M6UQ<75Q<>UQ<?29<>&,P+5QX9F9=*R(@+B`O+R`Q(&]R(&UO<F4@;V8@:G5S
M="!A8F]U="!A;GD@8VAA<F%C=&5R"B`@("`@("`@("`@("(I/R(@+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!%3D0@9&ES<&QA>2UN86UE('!A='1E<FX@,"!O<B`Q"B`@("`@("`@("`@
M("(H(B`N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!35$%25"!P871T97)N(&9O<B!N86UE9"!A;F-H;W)S
M"B`@("`@("`@("`@(")<(R(@+B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!A(&AA<V@@;6%R:PH@("`@("`@
M("`@("`B6T$M6F$M>ETB("X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@,2!A;'!H80H@("`@("`@("`@("`B6RU!+5IA
M+7HP+3E?.BY=*B(@+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@,"!O<B!M;W)E(&%L<&AA+"!D:6=I="P@=6YD97)S8V]R90H@("`@
M("`@("`@("`B*3\B("X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@14Y$(&YA;65D(&%N8VAO<G,@<&%T=&5R
M;B`P(&]R(#$*("`@("`@("`@("`@(B@I7%PI7%PI(B`N("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&1O=6)L92!C;&]S
M92UP87)E;G,*("`@("`@("`@("`@)R\G.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($5.1"!R96=E>`H@
M("`@?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@1V5N97)A=&5S
M(&$@<F5P;&%C96UE;G0@9F]R('1H92!M871C:&5D('1E>'0N("!4;VME;B!O
M<'1I;VYS(&%R93H*("`@("H@"B`@("`J("=P86=E)R`]/B!T:&4@=VEK:2!P
M86=E(&YA;64@*&4N9RXL($AO;65086=E*2X*("`@("H@"B`@("`J("=T97AT
M)R`]/B!A;'1E<FYA=&EV92!T97AT('1O(&)E(&1I<W!L87EE9"!I;B!P;&%C
M92!O9B!T:&4@=VEK:0H@("`@*B!P86=E(&YA;64N"B`@("`J(`H@("`@*B`G
M86YC:&]R)R`]/B!A(&YA;65D(&%N8VAO<B!O;B!T:&4@=&%R9V5T('=I:VD@
M<&%G90H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H*("`@("H@
M0'!A<F%M(&%R<F%Y("8D;6%T8VAE<R!4:&4@87)R87D@;V8@;6%T8VAE<R!F
M<F]M('!A<G-E*"DN"B`@("`J"B`@("`J($!R971U<FX@02!D96QI;6ET960@
M=&]K96X@=&\@8F4@=7-E9"!A<R!A('!L86-E:&]L9&5R(&EN"B`@("`J('1H
M92!S;W5R8V4@=&5X="P@<&QU<R!A;GD@=&5X="!P<FEO="!T;R!T:&4@;6%T
M8V@N"B`@("`J"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P<F]C97-S*"8D
M;6%T8VAE<RD*("`@('L*("`@("`@("`O+R!U<V4@;FEC92!V87)I86)L92!N
M86UE<PH@("`@("`@("1P86=E(#T@)&UA=&-H97-;,5T["B`@("`@("`@)'1E
M>'0@/2`D;6%T8VAE<ULR73L*("`@("`@("`*("`@("`@("`O+R!G970@<FED
M(&]F('1H92!L96%D:6YG(",@9G)O;2!T:&4@86YC:&]R+"!I9B!A;GD*("`@
M("`@("`D86YC:&]R(#T@<W5B<W1R*"1M871C:&5S6S-=+"`Q*3L*("`@("`@
M("`*("`@("`@("`O+R!I<R!T:&4@<&%G92!G:79E;B!A(&YE=R!T97AT(&%P
M<&5A<F%N8V4_"B`@("`@("`@:68@*'1R:6TH)'1E>'0I(#T]("<G*2!["B`@
M("`@("`@("`@("\O(&YO"B`@("`@("`@("`@("1T97AT(#T@)'!A9V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@>65S+"!S=')I<"!T:&4@
M;&5A9&EN9R!\(&-H87)A8W1E<@H@("`@("`@("`@("`D=&5X="`]('-U8G-T
M<B@D=&5X="P@,2D["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O('-E
M="!T:&4@;W!T:6]N<PH@("`@("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@
M("`@("`@("=P86=E)R`@(#T^("1P86=E+`H@("`@("`@("`@("`G=&5X="<@
M("`]/B`D=&5X="P*("`@("`@("`@("`@)V%N8VAO<B<@/3X@)&%N8VAO<@H@
M("`@("`@("D["B`@("`@("`@"B`@("`@("`@+R\@<F5T=7)N(&$@=&]K96X@
M<&QA8V5H;VQD97(*("`@("`@("!R971U<FX@)'1H:7,M/F%D9%1O:V5N*"1O
M<'1I;VYS*3L*("`@('T*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J
M(%)E;F1E<G,@82!T;VME;B!I;G1O('1E>'0@;6%T8VAI;F<@=&AE(')E<75E
M<W1E9"!F;W)M870N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B`*("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS(%1H92`B;W!T:6]N<R(@
M<&]R=&EO;B!O9B!T:&4@=&]K96X@*'-E8V]N9`H@("`@*B!E;&5M96YT*2X*
M("`@("H@"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!T97AT(')E;F1E<F5D
M(&9R;VT@=&AE('1O:V5N(&]P=&EO;G,N"B`@("`J(`H@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@<F5N9&5R6&AT;6PH)&]P=&EO;G,I"B`@("!["B`@("`@
M("`@+R\@9V5T(&YI8V4@=F%R:6%B;&4@;F%M97,@*'!A9V4L('1E>'0L(&%N
M8VAO<BD*("`@("`@("!E>'1R86-T*"1O<'1I;VYS*3L*("`@("`@("`*("`@
M("`@("!I9B`H:6Y?87)R87DH)'!A9V4L("1T:&ES+3Y?=VEK:2T^<&%G97,I
M*2!["B`@("`@("`@("`@("\O('1H92!P86=E(&5X:7-T<RP@<VAO=R!A(&QI
M;FL@=&\@=&AE('!A9V4*("`@("`@("`@("`@)&AR968@/2`D=&AI<RT^7W=I
M:VDM/G9I97=?=7)L("X@)'!A9V4@+B`B(R(@+B`D86YC:&]R.PH@("`@("`@
M("`@("!R971U<FX@(CQA(&AR968]7"(D:')E9EPB/B1T97AT/"]A/B(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@=&AE('!A9V4@9&]E<R!N
M;W0@97AI<W0L('-H;W<@=&AE('!A9V4@;F%M92!A;F0*("`@("`@("`@("`@
M+R\@=&AE(")N97<@<&%G92(@=&5X=`H@("`@("`@("`@("`D:')E9B`]("1T
M:&ES+3Y?=VEK:2T^;F5W7W5R;#L*("`@("`@("`@("`@<F5T=7)N("1T97AT
M("X@(CQA(&AR968]7"(D:')E9B1P86=E7"(^>R1T:&ES+3Y?=VEK:2T^;F5W
M7W1E>'1]/"]A/B(["B`@("`@("`@?0H@("`@?0I]"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O5&5X="]7:6MI+U)U;&4O:6YT97)W:6MI+G!H<```````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#<P,#4`,3`T,3<S-C,P,#0`,#(R-C$T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@=F5R<VEO
M;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W)S.B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&EN=&5R=VEK:2YP:'`L=B`Q+C,@
M,C`P-"\P,2\S,2`Q-3HU,CHP."!P;6IO;F5S($5X<"`D"@H*+RHJ"BH@"BH@
M5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI7U)U;&4@=&\@9FEN
M9"!S;W5R8V4@=&5X="!M87)K960@87,**B!A;B!);G1E<G=I:VD@;&EN:RX@
M(%-E92!T:&4@<F5G97@@9F]R(&$@9&5T86EL960@97AP;&%N871I;VX@;V8@
M=&AE"BH@=&5X="!M871C:&EN9R!P<F]C961U<F4[(&4N9RXL("));G1E<E=I
M:VE.86UE.E!A9V5.86UE(BX**@HJ($!A=71H;W(@4&%U;"!-+B!*;VYE<R`\
M<&UJ;VYE<T!C:6%W96(N;F5T/@HJ"BH@0'!A8VMA9V4@5&5X=%]7:6MI"BH*
M*B\*"F-L87-S(%1E>'1?5VEK:5]2=6QE7VEN=&5R=VEK:2!E>'1E;F1S(%1E
M>'1?5VEK:5]2=6QE('L*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J
M($-O;G-T<G5C=&]R+B`@5V4@;W9E<G)I9&4@=&AE(%1E>'1?5VEK:5]2=6QE
M(&-O;G-T<G5C=&]R('-O('=E(&-A;@H@("`@*B!E>'!L:6-I=&QY(&-O;6UE
M;G0@96%C:"!P87)T(&]F('1H92`D<F5G97@@<')O<&5R='DN"B`@("`J(`H@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&]B:F5C
M="`F)&]B:B!4:&4@8V%L;&EN9R`B<&%R96YT(B!497AT7U=I:VD@;V)J96-T
M+@H@("`@*B`*("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92!4:&4@=&]K96X@
M;F%M92!T;R!U<V4@9F]R('1H:7,@<G5L92X*("`@("H@"B`@("`J+PH@("`@
M"B`@("!F=6YC=&EO;B!497AT7U=I:VE?4G5L95]I;G1E<G=I:VDH)B1O8FHL
M("1N86UE*0H@("`@>PH@("`@("`@('!A<F5N=#HZ5&5X=%]7:6MI7U)U;&4H
M)&]B:BP@)&YA;64I.PH@("`@("`@("1T:&ES+3YR96=E>"`]("<O*%M!+5IA
M+7HP+3E=*RDZ*%M<+STF?B-!+5IA+7HP+3E=*RDO)SL*("`@('T*("`@(`H@
M("`@"B`@("`O*BH*("`@("H@"B`@("`J($=E;F5R871E<R!A(')E<&QA8V5M
M96YT(&9O<B!T:&4@;6%T8VAE9"!T97AT+B`@5&]K96X@;W!T:6]N<R!A<F4Z
M"B`@("`J(`H@("`@*B`G<VET92<@/3X@5&AE(&ME>2!N86UE(&9O<B!T:&4@
M5&5X=%]7:6MI(&EN=&5R=VEK:2!A<G)A>2!M87`L('5S=6%L;'D*("`@("H@
M=&AE(&YA;64@;V8@=&AE(&EN=&5R=VEK:2!S:71E+@H@("`@*@H@("`@*B`G
M<&%G92<@/3X@5&AE('!A9V4@;VX@=&AE('1A<F=E="!I;G1E<G=I:VD@=&\@
M;&EN:R!T;RX*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J"B`@
M("`J($!P87)A;2!A<G)A>2`F)&UA=&-H97,@5&AE(&%R<F%Y(&]F(&UA=&-H
M97,@9G)O;2!P87)S92@I+@H@("`@*@H@("`@*B!`<F5T=7)N($$@9&5L:6UI
M=&5D('1O:V5N('1O(&)E('5S960@87,@82!P;&%C96AO;&1E<B!I;@H@("`@
M*B!T:&4@<V]U<F-E('1E>'0L('!L=7,@86YY('1E>'0@<')I;W0@=&\@=&AE
M(&UA=&-H+@H@("`@*@H@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<')O8V5S
M<R@F)&UA=&-H97,I"B`@("!["B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@*
M("`@("`@("`@("`@)W-I=&4G(#T^("1M871C:&5S6S%=+`H@("`@("`@("`@
M("`G<&%G92<@/3X@)&UA=&-H97-;,ET*("`@("`@("`I.PH@("`@("`@(`H@
M("`@("`@(')E='5R;B`D=&AI<RT^861D5&]K96XH)&]P=&EO;G,I.PH@("`@
M?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@4F5N9&5R<R!A('1O
M:V5N(&EN=&\@=&5X="!M871C:&EN9R!T:&4@<F5Q=65S=&5D(&9O<FUA="X*
M("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@*B!`<&%R
M86T@87)R87D@)&]P=&EO;G,@5&AE(")O<'1I;VYS(B!P;W)T:6]N(&]F('1H
M92!T;VME;B`H<V5C;VYD"B`@("`J(&5L96UE;G0I+@H@("`@*B`*("`@("H@
M0')E='5R;B!S=')I;F<@5&AE('1E>'0@<F5N9&5R960@9G)O;2!T:&4@=&]K
M96X@;W!T:6]N<RX*("`@("H@"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!R
M96YD97)8:'1M;"@D;W!T:6]N<RD*("`@('L*("`@("`@("`D<VET92`]("1O
M<'1I;VYS6R=S:71E)UT["B`@("`@("`@)'!A9V4@/2`D;W!T:6]N<ULG<&%G
M92==.PH@("`@("`@(`H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W=I:VDM
M/FEN=&5R=VEK:5LD<VET95TI*2!["B`@("`@("`@("`@("1H<F5F(#T@)'1H
M:7,M/E]W:6MI+3YI;G1E<G=I:VE;)'-I=&5=.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1H<F5F(#T@)R<["B`@("`@("`@?0H@("`@("`@(`H@
M("`@("`@(&EF("@D:')E9B`A/2`G)RD@>PH@("`@("`@("`@("!R971U<FX@
M(CQA(&AR968]7"(D:')E9B1P86=E7"(^)'-I=&4Z)'!A9V4\+V$^(CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@(B1S:71E.B1P86=E
M(CL*("`@("`@("!]"B`@("!]"GT*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O5&5X="]7:6MI+U)U;&4O=&%B;&4N<&AP
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34P-S``,3`T,3<S-C,P
M,#0`,#(Q-C<W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H
M92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!0875L($TN($IO;F5S(#QP
M;6IO;F5S0&-I87=E8BYN970^("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('1A
M8FQE+G!H<"QV(#$N,2`R,#`T+S`Q+S`T(#`Q.C,U.C(S('!M:F]N97,@17AP
M("0*"@HO*BH**B`**B!4:&ES(&-L87-S(&EM<&QE;65N=',@82!497AT7U=I
M:VE?4G5L92!T;R!F:6YD('-O=7)C92!T97AT(&UA<FME9"!A<R!A"BH@<V5T
M(&]F('1A8FQE(')O=W,L('=H97)E(&$@;&EN92!S=&%R="!A;F0@96YD<R!W
M:71H(&1O=6)L92UP:7!E<R`H?'PI"BH@86YD('5S97,@9&]U8FQE+7!I<&5S
M('1O('-E<&%R871E('1A8FQE(&-E;&QS+B`@5&AE(')O=W,@;75S="!B92!O
M;@HJ('-E<75E;G1I86P@;&EN97,@*&YO(&)L86YK(&QI;F5S(&)E='=E96X@
M=&AE;2D@+2T@82!B;&%N:R!L:6YE"BH@:6YD:6-A=&5S('1H92!B96=I;FYI
M;F<@;V8@82!N97<@=&%B;&4N"BH**B!`875T:&]R(%!A=6P@32X@2F]N97,@
M/'!M:F]N97-`8VEA=V5B+FYE=#X**@HJ($!P86-K86=E(%1E>'1?5VEK:0HJ
M"BHO"@IC;&%S<R!497AT7U=I:VE?4G5L95]T86)L92!E>'1E;F1S(%1E>'1?
M5VEK:5]2=6QE('L*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H
M92!R96=U;&%R(&5X<')E<W-I;VX@=7-E9"!T;R!P87)S92!T:&4@<V]U<F-E
M('1E>'0@86YD(&9I;F0*("`@("H@;6%T8VAE<R!C;VYF;W)M:6YG('1O('1H
M:7,@<G5L92X@(%5S960@8GD@=&AE('!A<G-E*"D@;65T:&]D+@H@("`@*B`*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V87(@<W1R:6YG
M"B`@("`J(`H@("`@*B!`<V5E('!A<G-E*"D*("`@("H@"B`@("`J+PH@("`@
M"B`@("!V87(@)')E9V5X(#T@)R]<;B@H7'Q<?"DN*BDH7&XI*#\A*%Q\7'PI
M*2]5<R<["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!'96YE<F%T
M97,@82!R97!L86-E;65N="!F;W(@=&AE(&UA=&-H960@=&5X="X@(%1O:V5N
M(&]P=&EO;G,@87)E.@H@("`@*B`*("`@("H@)W1Y<&4G(#T^"B`@("`J("`@
M("`G=&%B;&5?<W1A<G0G(#H@=&AE('-T87)T(&]F(&$@8G5L;&5T(&QI<W0*
M("`@("H@("`@("=T86)L95]E;F0G("`@.B!T:&4@96YD(&]F(&$@8G5L;&5T
M(&QI<W0*("`@("H@("`@("=R;W=?<W1A<G0G(#H@=&AE('-T87)T(&]F(&$@
M;G5M8F5R(&QI<W0*("`@("H@("`@("=R;W=?96YD)R`@(#H@=&AE(&5N9"!O
M9B!A(&YU;6)E<B!L:7-T"B`@("`J("`@("`G8V5L;%]S=&%R="<@("`Z('1H
M92!S=&%R="!O9B!I=&5M('1E>'0@*&)U;&QE="!O<B!N=6UB97(I"B`@("`J
M("`@("`G8V5L;%]E;F0G("`@("`Z('1H92!E;F0@;V8@:71E;2!T97AT("AB
M=6QL970@;W(@;G5M8F5R*0H@("`@*B`*("`@("H@)V-O;'-P86XG(#T^(&-O
M;'5M;B!S<&%N("AF;W(@82!C96QL*0H@("`@*B`*("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y("8D;6%T8VAE<R!4:&4@
M87)R87D@;V8@;6%T8VAE<R!F<F]M('!A<G-E*"DN"B`@("`J"B`@("`J($!R
M971U<FX@02!S97)I97,@;V8@=&5X="!A;F0@9&5L:6UI=&5D('1O:V5N<R!M
M87)K:6YG('1H92!D:69F97)E;G0*("`@("H@=&%B;&4@96QE;65N=',@86YD
M(&-E;&P@=&5X="X*("`@("H*("`@("HO"B`@("`*("`@(&9U;F-T:6]N('!R
M;V-E<W,H)B1M871C:&5S*0H@("`@>PH@("`@("`@("\O(&]U="!E=F5N='5A
M;"!R971U<FX@=F%L=64*("`@("`@("`D<F5T=7)N(#T@)R<["B`@("`@("`@
M"B`@("`@("`@+R\@<W1A<G0@82!N97<@=&%B;&4*("`@("`@("`D<F5T=7)N
M("X]("1T:&ES+3YA9&14;VME;BAA<G)A>2@G='EP92<@/3X@)W1A8FQE7W-T
M87)T)RDI.PH@("`@("`@(`H@("`@("`@("\O(')O=W,@87)E('-E<&%R871E
M9"!B>2!N97=L:6YE<R!I;B!T:&4@;6%T8VAE9"!T97AT"B`@("`@("`@)')O
M=W,@/2!E>'!L;V1E*")<;B(L("1M871C:&5S6S%=*3L*("`@("`@("`*("`@
M("`@("`O+R!L;V]P('1H<F]U9V@@96%C:"!R;W<*("`@("`@("!F;W)E86-H
M("@D<F]W<R!A<R`D<F]W*2!["B`@("`@("`@("`@(`H@("`@("`@("`@("`O
M+R!S=&%R="!A(&YE=R!R;W<*("`@("`@("`@("`@)')E='5R;B`N/2`D=&AI
M<RT^861D5&]K96XH87)R87DH)W1Y<&4G(#T^("=R;W=?<W1A<G0G*2D["B`@
M("`@("`@("`@(`H@("`@("`@("`@("`O+R!C96QL<R!A<F4@<V5P87)A=&5D
M(&)Y(&1O=6)L92UP:7!E<PH@("`@("`@("`@("`D8V5L;"`](&5X<&QO9&4H
M(GQ\(BP@)')O=RD["B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!G970@
M=&AE(&QA<W0@8V5L;"!N=6UB97(*("`@("`@("`@("`@)&QA<W0@/2!C;W5N
M="@D8V5L;"D@+2`Q.PH@("`@("`@("`@("`*("`@("`@("`@("`@+R\@8GD@
M9&5F875L="P@8V5L;',@<W!A;B!O;FQY(&]N92!C;VQU;6X@*'1H96ER(&]W
M;BD*("`@("`@("`@("`@)'-P86X@/2`Q.PH@("`@("`@("`@("`*("`@("`@
M("`@("`@+R\@:6=N;W)E(&-E;&P@>F5R;RP@86YD(&EG;F]R92!T:&4@(FQA
M<W0B(&-E;&P[(&-E;&P@>F5R;PH@("`@("`@("`@("`O+R!I<R!B969O<F4@
M=&AE(&9I<G-T(&1O=6)L92UP:7!E+"!A;F0@=&AE(")L87-T(B!C96QL(&ES
M"B`@("`@("`@("`@("\O(&%F=&5R('1H92!L87-T(&1O=6)L92UP:7!E+B!B
M;W1H(&%R92!A;'=A>7,@96UP='DN"B`@("`@("`@("`@(&9O<B`H)&D@/2`Q
M.R`D:2`\("1L87-T.R`D:2`K*RD@>PH@("`@("`@("`@("`@("`@"B`@("`@
M("`@("`@("`@("`O+R!I9B!T:&5R92!I<R!N;R!C;VYT96YT(&%T(&%L;"P@
M=&AE;B!I="=S(&%N(&EN<W1A;F-E"B`@("`@("`@("`@("`@("`O+R!O9B!T
M=V\@<V5T<R!O9B!\?"!N97AT('1O(&5A8V@@;W1H97(L(&EN9&EC871I;F<@
M80H@("`@("`@("`@("`@("`@+R\@8V]L<W!A;BX*("`@("`@("`@("`@("`@
M(&EF("@D8V5L;%LD:5T@/3T@)R<I('L*("`@("`@("`@("`@("`@("`@("`*
M("`@("`@("`@("`@("`@("`@("`O+R!A9&0@=&\@=&AE('-P86X@86YD(&QO
M;W`@=&\@=&AE(&YE>'0@8V5L;`H@("`@("`@("`@("`@("`@("`@("1S<&%N
M("L](#$["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("`@("`@"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@("\O('1H:7,@8V5L
M;"!H87,@8V]N=&5N="X*("`@("`@("`@("`@("`@("`@("`O+R!S=&%R="!A
M(&YE=R!C96QL+BXN"B`@("`@("`@("`@("`@("`@("`@)')E='5R;B`N/2`D
M=&AI<RT^861D5&]K96XH"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M("@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G8V5L
M;%]S=&%R="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]L<W!A
M;B<@/3X@)'-P86X*("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@
M("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@
M("`@("`@("`@("`@+R\@+BXN861D('1H92!C;VYT96YT+BXN"B`@("`@("`@
M("`@("`@("`@("`@)')E='5R;B`N/2!T<FEM*"1C96QL6R1I72D["B`@("`@
M("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`@("`@+R\@+BXN86YD
M(&5N9"!T:&4@8V5L;"X*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N("X]
M("1T:&ES+3YA9&14;VME;B@*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87D@*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=C
M96QL7V5N9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]L<W!A
M;B<@/3X@)'-P86X*("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@
M("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@
M("`@("`@("`@("`@+R\@<F5S970@=&AE(&-O;'-P86XN"B`@("`@("`@("`@
M("`@("`@("`@)'-P86X@/2`Q.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(`H@("`@("`@("`@("!]"B`@("`@("`@("`@(`H@("`@
M("`@("`@("`O+R!E;F0@=&AE(')O=PH@("`@("`@("`@("`D<F5T=7)N("X]
M("1T:&ES+3YA9&14;VME;BAA<G)A>2@G='EP92<@/3X@)W)O=U]E;F0G*2D[
M"B`@("`@("`@("`@(`H@("`@("`@('T*("`@("`@("`*("`@("`@("`O+R!E
M;F0@=&AE('1A8FQE"B`@("`@("`@)')E='5R;B`N/2`D=&AI<RT^861D5&]K
M96XH87)R87DH)W1Y<&4G(#T^("=T86)L95]E;F0G*2D["B`@("`@("`@"B`@
M("`@("`@+R\@=V4G<F4@9&]N92$*("`@("`@("!R971U<FX@(EQN)')E='5R
M;B(["B`@("!]"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!296YD
M97)S(&$@=&]K96X@:6YT;R!T97AT(&UA=&-H:6YG('1H92!R97%U97-T960@
M9F]R;6%T+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@
M("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R!4:&4@(F]P=&EO;G,B('!O<G1I
M;VX@;V8@=&AE('1O:V5N("AS96-O;F0*("`@("H@96QE;65N="DN"B`@("`J
M(`H@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@=&5X="!R96YD97)E9"!F<F]M
M('1H92!T;VME;B!O<'1I;VYS+@H@("`@*B`*("`@("HO"B`@("`*("`@(&9U
M;F-T:6]N(')E;F1E<EAH=&UL*"1O<'1I;VYS*0H@("`@>PH@("`@("`@("\O
M(&UA:V4@;FEC92!V87)I86)L92!N86UE<R`H='EP92P@8V]L<W!A;BD*("`@
M("`@("!E>'1R86-T*"1O<'1I;VYS*3L*("`@("`@("`*("`@("`@("`D<&%D
M(#T@)R`@("`G.PH@("`@("`@(`H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*
M("`@("`@("`*("`@("`@("!C87-E("=T86)L95]S=&%R="<Z"B`@("`@("`@
M("`@(')E='5R;B`B/'1A8FQE(&)O<F1E<CU<(C%<(B!C96QL<W!A8VEN9SU<
M(C!<(B!C96QL<&%D9&EN9SU<(C1<(CY<;B(["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@(`H@("`@("`@(&-A<V4@)W1A8FQE7V5N9"<Z"B`@("`@("`@
M("`@(')E='5R;B`B/"]T86)L93Y<;B(["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(`H@("`@("`@(&-A<V4@)W)O=U]S=&%R="<Z"B`@("`@("`@("`@
M(')E='5R;B`B)'!A9#QT<CY<;B(["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@(`H@("`@("`@(&-A<V4@)W)O=U]E;F0G.@H@("`@("`@("`@("!R971U
M<FX@(B1P860\+W1R/EQN(CL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M"B`@("`@("`@8V%S92`G8V5L;%]S=&%R="<Z"B`@("`@("`@("`@(&EF("@D
M8V]L<W!A;B`^(#$I('L*("`@("`@("`@("`@("`@(')E='5R;B`B)'!A9"1P
M860\=&0@8V]L<W!A;CU<(B1C;VQS<&%N7"(^(CL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`B)'!A9"1P860\=&0^(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("`*("`@
M("`@("!C87-E("=C96QL7V5N9"<Z"B`@("`@("`@("`@(')E='5R;B`B/"]T
M9#Y<;B(["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(`H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("`*("`@("`@
M("!]"B`@("!]"GT*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O5&5X="]7:6MI+U)U;&4O:71A;&EC+G!H<```````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#8Q,30`,3`T,3<S-C,P,#0`,#(R,#4T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J
M+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@=F5R
M<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O
M=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@
M("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@
M?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S
M92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!!=71H;W)S.B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN
M970^("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&ET86QI8RYP:'`L=B`Q+C$@
M,C`P-"\P,2\S,2`Q-3HU,CHP."!P;6IO;F5S($5X<"`D"@H*+RHJ"BH@"BH@
M5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@5&5X=%]7:6MI7U)U;&4@=&\@9FEN
M9"!S;W5R8V4@=&5X="!M87)K960@9F]R"BH@96UP:&%S:7,@*&ET86QI8W,I
M(&%S(&1E9FEN960@8GD@=&5X="!S=7)R;W5N9&5D(&)Y('1W;R!S:6YG;&4M
M<75O=&5S+@HJ($]N('!A<G-I;F<L('1H92!T97AT(&ET<V5L9B!I<R!L969T
M(&EN('!L86-E+"!B=70@=&AE('-T87)T:6YG(&%N9"!E;F1I;F<**B!I;G-T
M86YC97,@;V8@='=O('-I;F=L92UQ=6]T97,@87)E(')E<&QA8V5D('=I=&@@
M=&]K96YS+@HJ"BH@0&%U=&AO<B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I
M87=E8BYN970^"BH**B!`<&%C:V%G92!497AT7U=I:VD**@HJ+PH*8VQA<W,@
M5&5X=%]7:6MI7U)U;&5?:71A;&EC(&5X=&5N9',@5&5X=%]7:6MI7U)U;&4@
M>PH@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@5&AE(')E9W5L87(@
M97AP<F5S<VEO;B!U<V5D('1O('!A<G-E('1H92!S;W5R8V4@=&5X="!A;F0@
M9FEN9`H@("`@*B!M871C:&5S(&-O;F9O<FUI;F<@=&\@=&AI<R!R=6QE+B`@
M57-E9"!B>2!T:&4@<&%R<V4H*2!M971H;V0N"B`@("`J(`H@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@*B`*("`@("H@0'9A<B!S=')I;F<*("`@("H@"B`@
M("`J($!S964@<&%R<V4H*0H@("`@*B`*("`@("HO"B`@("`*("`@('9A<B`D
M<F5G97@@/2`B+R<G*"@I?%M>)UTN*BDG)R]5(CL*("`@(`H@("`@"B`@("`O
M*BH*("`@("H@"B`@("`J($=E;F5R871E<R!A(')E<&QA8V5M96YT(&9O<B!T
M:&4@;6%T8VAE9"!T97AT+B`@5&]K96X@;W!T:6]N<R!A<F4Z"B`@("`J(`H@
M("`@*B`G='EP92<@/3X@6R=S=&%R="=\)V5N9"==(%1H92!S=&%R=&EN9R!O
M<B!E;F1I;F<@<&]I;G0@;V8@=&AE"B`@("`J(&5M<&AA<VEZ960@=&5X="X@
M(%1H92!T97AT(&ET<V5L9B!I<R!L969T(&EN('1H92!S;W5R8V4N"B`@("`J
M(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*@H@("`@*B!`<&%R86T@87)R
M87D@)B1M871C:&5S(%1H92!A<G)A>2!O9B!M871C:&5S(&9R;VT@<&%R<V4H
M*2X*("`@("H*("`@("H@0')E='5R;B!S=')I;F<@02!P86ER(&]F(&1E;&EM
M:71E9"!T;VME;G,@=&\@8F4@=7-E9"!A<R!A"B`@("`J('!L86-E:&]L9&5R
M(&EN('1H92!S;W5R8V4@=&5X="!S=7)R;W5N9&EN9R!T:&4@=&5X="!T;R!B
M90H@("`@*B!E;7!H87-I>F5D+@H@("`@*@H@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@<')O8V5S<R@F)&UA=&-H97,I"B`@("!["B`@("`@("`@)'-T87)T
M(#T@)'1H:7,M/F%D9%1O:V5N*&%R<F%Y*"=T>7!E)R`]/B`G<W1A<G0G*2D[
M"B`@("`@("`@)&5N9"`]("1T:&ES+3YA9&14;VME;BAA<G)A>2@G='EP92<@
M/3X@)V5N9"<I*3L*("`@("`@("!R971U<FX@)'-T87)T("X@)&UA=&-H97-;
M,5T@+B`D96YD.PH@("`@?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@
M("H@4F5N9&5R<R!A('1O:V5N(&EN=&\@=&5X="!M871C:&EN9R!T:&4@<F5Q
M=65S=&5D(&9O<FUA="X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J(`H@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@5&AE(")O<'1I;VYS
M(B!P;W)T:6]N(&]F('1H92!T;VME;B`H<V5C;VYD"B`@("`J(&5L96UE;G0I
M+@H@("`@*B`*("`@("H@0')E='5R;B!S=')I;F<@5&AE('1E>'0@<F5N9&5R
M960@9G)O;2!T:&4@=&]K96X@;W!T:6]N<RX*("`@("H@"B`@("`J+PH@("`@
M"B`@("!F=6YC=&EO;B!R96YD97)8:'1M;"@D;W!T:6]N<RD*("`@('L*"0EI
M9B`H)&]P=&EO;G-;)W1Y<&4G72`]/2`G<W1A<G0G*2!["@D)"7)E='5R;B`G
M/&D^)SL*"0E]"@D)"@D):68@*"1O<'1I;VYS6R=T>7!E)UT@/3T@)V5N9"<I
M('L*"0D)<F5T=7)N("<\+VD^)SL*"0E]"B`@("!]"GT*/SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U1E>'0O5VEK:2]2=6QE+W)E=FES92YP:'``````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$Q-C,P`#$P-#$W,S8S,#`T`#`R,C$P,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@
M*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E
M<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N
M;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!R979I<V4N<&AP+'8@,2XR
M(#(P,#0O,#$O,S$@,34Z-3(Z,#@@<&UJ;VYE<R!%>'`@)`H*"B\J*@HJ(`HJ
M(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!A(%1E>'1?5VEK:5]2=6QE('1O(&9I
M;F0@<V]U<F-E('1E>'0@;6%R:V5D(&9O<@HJ(')E=FES:6]N+@HJ"BH@0&%U
M=&AO<B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^"BH**B!`
M<&%C:V%G92!497AT7U=I:VD**@HJ+PH*8VQA<W,@5&5X=%]7:6MI7U)U;&5?
M<F5V:7-E(&5X=&5N9',@5&5X=%]7:6MI7U)U;&4@>PH@("`@"B`@("`*("`@
M("\J*@H@("`@*B`*("`@("H@5&AE(')E9W5L87(@97AP<F5S<VEO;B!U<V5D
M('1O('!A<G-E('1H92!S;W5R8V4@=&5X="!A;F0@9FEN9`H@("`@*B!M871C
M:&5S(&-O;F9O<FUI;F<@=&\@=&AI<R!R=6QE+B`@57-E9"!B>2!T:&4@<&%R
M<V4H*2!M971H;V0N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B`*("`@("H@0'9A<B!S=')I;F<*("`@("H@"B`@("`J($!S964@<&%R<V4H
M*0H@("`@*B`*("`@("HO"B`@("`*("`@('9A<B`D<F5G97@@/2`B+UQ`7$`H
M>RH_+BI]*C\I7$!<0"]5(CL*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@
M("`J(%1H92!C:&%R86-T97)S('1O('5S92!A<R!M87)K:6YG('1E>'0@=&\@
M8F4@<W1R:6-K96XN"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B`*("`@("H@0'9A<B!S=')I;F<*("`@("H@"B`@("`J($!S964@<&%R<V4H
M*0H@("`@*@H@("`@*B\*("`@(`H@("`@=F%R("1D96QM87)K(#T@)RTM+2<[
M"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!4:&4@8VAA<F%C=&5R
M<R!T;R!U<V4@87,@;6%R:VEN9R!T97AT('1O(&)E(&%D9&5D+@H@("`@*B`*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V87(@<W1R:6YG
M"B`@("`J(`H@("`@*B!`<V5E('!A<G-E*"D*("`@("H@"B`@("`J+PH@("`@
M"B`@("!V87(@)&EN<VUA<FL@/2`G*RLK)SL*("`@(`H@("`@"B`@("`O*BH*
M("`@("H@"B`@("`J($=E;F5R871E<R!A(')E<&QA8V5M96YT(&9O<B!T:&4@
M;6%T8VAE9"!T97AT+B`@5&]K96X@;W!T:6]N<R!A<F4Z"B`@("`J(`H@("`@
M*B`G='EP92<@/3X@6R=S=&%R="=\)V5N9"==(%1H92!S=&%R=&EN9R!O<B!E
M;F1I;F<@<&]I;G0@;V8@=&AE"B`@("`J(&EN<V5R=&5D('1E>'0N("!4:&4@
M=&5X="!I='-E;&8@:7,@;&5F="!I;B!T:&4@<V]U<F-E+@H@("`@*B`*("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y("8D
M;6%T8VAE<R!4:&4@87)R87D@;V8@;6%T8VAE<R!F<F]M('!A<G-E*"DN"B`@
M("`J"B`@("`J($!R971U<FX@<W1R:6YG($$@<&%I<B!O9B!D96QI;6ET960@
M=&]K96YS('1O(&)E('5S960@87,@80H@("`@*B!P;&%C96AO;&1E<B!I;B!T
M:&4@<V]U<F-E('1E>'0@<W5R<F]U;F1I;F<@=&AE('1E;&5T>7!E('1E>'0N
M"B`@("`J"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P<F]C97-S*"8D;6%T
M8VAE<RD*("`@('L*("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@)'-R
M8R`]("1M871C:&5S6S%=.PH@("`@("`@("1D96QM87)K(#T@)'1H:7,M/F1E
M;&UA<FL["B`@("`@("`@)&EN<VUA<FL@/2`D=&AI<RT^:6YS;6%R:SL*("`@
M("`@("`*("`@("`@("`O+R`G+2TM)R!M=7-T(&)E(&)E9F]R92`G*RLK)R`H
M:68@=&AE>2!B;W1H(&%P<&5A<BD*("`@("`@("`D9&5L(#T@<W1R<&]S*"1S
M<F,L("1D96QM87)K*3L*("`@("`@("`D:6YS(#T@<W1R<&]S*"1S<F,L("1I
M;G-M87)K*3L*("`@("`@("`*("`@("`@("`O+R!I9B!N96ET:&5R(&ES(&9O
M=6YD+"!R971U<FX@<FEG:'0@87=A>0H@("`@("`@(&EF("@D9&5L(#T]/2!F
M86QS92`F)B`D:6YS(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@
M)&UA=&-H97-;,%T["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(&AA
M;F1L92!T97AT('1O(&)E(&1E;&5T960*("`@("`@("!I9B`H)&1E;"`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O(&UO=F4@9F]R
M=V%R9"!T;R!T:&4@96YD(&]F('1H92!D96QE=&EO;B!M87)K"B`@("`@("`@
M("`@("1D96P@*ST@<W1R;&5N*"1D96QM87)K*3L*("`@("`@("`@("`@"B`@
M("`@("`@("`@(&EF("@D:6YS(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@+R\@=&AE<F4@:7,@;F\@:6YS97)T:6]N('1E>'0@9F]L;&]W:6YG"B`@
M("`@("`@("`@("`@("`D=&5X="`]('-U8G-T<B@D<W)C+"`D9&5L*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O('1H97)E(&ES
M(&EN<V5R=&EO;B!T97AT(&9O;&QO=VEN9RP*("`@("`@("`@("`@("`@("\O
M(&UI=&EG871E('1H92!L96YG=&@*("`@("`@("`@("`@("`@("1T97AT(#T@
M<W5B<W1R*"1S<F,L("1D96PL("1I;G,@+2`D9&5L*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`*("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^
M861D5&]K96XH87)R87DH)W1Y<&4G(#T^("=D96Q?<W1A<G0G*2D["B`@("`@
M("`@("`@("1O=71P=70@+CT@)'1E>'0["B`@("`@("`@("`@("1O=71P=70@
M+CT@)'1H:7,M/F%D9%1O:V5N*&%R<F%Y*"=T>7!E)R`]/B`G9&5L7V5N9"<I
M*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@:&%N9&QE('1E>'0@
M=&\@8F4@:6YS97)T960*("`@("`@("!I9B`H)&EN<R`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@"B`@("`@("`@("`@("\O(&UO=F4@9F]R=V%R9"!T;R!T
M:&4@96YD(&]F('1H92!I;G-E<G0@;6%R:PH@("`@("`@("`@("`D:6YS("L]
M('-T<FQE;B@D:6YS;6%R:RD["B`@("`@("`@("`@("1T97AT(#T@<W5B<W1R
M*"1S<F,L("1I;G,I.PH@("`@("`@("`@("`*("`@("`@("`@("`@)&]U='!U
M="`N/2`D=&AI<RT^861D5&]K96XH87)R87DH)W1Y<&4G(#T^("=I;G-?<W1A
M<G0G*2D["B`@("`@("`@("`@("1O=71P=70@+CT@)'1E>'0["B`@("`@("`@
M("`@("1O=71P=70@+CT@)'1H:7,M/F%D9%1O:V5N*&%R<F%Y*"=T>7!E)R`]
M/B`G:6YS7V5N9"<I*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T
M=7)N("1O=71P=70["B`@("!]"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@
M("`@*B!296YD97)S(&$@=&]K96X@:6YT;R!T97AT(&UA=&-H:6YG('1H92!R
M97%U97-T960@9F]R;6%T+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("H@"B`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R!4:&4@(F]P=&EO
M;G,B('!O<G1I;VX@;V8@=&AE('1O:V5N("AS96-O;F0*("`@("H@96QE;65N
M="DN"B`@("`J(`H@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@=&5X="!R96YD
M97)E9"!F<F]M('1H92!T;VME;B!O<'1I;VYS+@H@("`@*B`*("`@("HO"B`@
M("`*("`@(&9U;F-T:6]N(')E;F1E<EAH=&UL*"1O<'1I;VYS*0H@("`@>PH@
M("`@("`@(&EF("@D;W!T:6]N<ULG='EP92==(#T]("=D96Q?<W1A<G0G*2![
M"B`@("`@("`@("`@(')E='5R;B`G/&1E;#XG.PH@("`@("`@('T*("`@("`@
M("`*("`@("`@("!I9B`H)&]P=&EO;G-;)W1Y<&4G72`]/2`G9&5L7V5N9"<I
M('L*("`@("`@("`@("`@<F5T=7)N("<\+V1E;#XG.PH@("`@("`@('T*("`@
M("`@("`*("`@("`@("!I9B`H)&]P=&EO;G-;)W1Y<&4G72`]/2`G:6YS7W-T
M87)T)RD@>PH@("`@("`@("`@("!R971U<FX@)SQI;G,^)SL*("`@("`@("!]
M"B`@("`@("`@"B`@("`@("`@:68@*"1O<'1I;VYS6R=T>7!E)UT@/3T@)VEN
M<U]E;F0G*2!["B`@("`@("`@("`@(')E='5R;B`G/"]I;G,^)SL*("`@("`@
M("!]"B`@("!]"GT*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]497AT+U=I:VDO4G5L92YP:'``````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,3$V-``Q,#0Q-S,V,S`P-``P,C`V
M,3$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!(4"!V97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%!A=6P@32X@2F]N97,@/'!M:F]N97-`
M8VEA=V5B+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@4G5L92YP:'`L
M=B`Q+C0@,C`P-"\P,2\S,2`Q-3HU,3HU.2!P;6IO;F5S($5X<"`D"@HO*BH*
M*B`**B!"87-E;&EN92!R=6QE(&-L87-S(&9O<B!E>'1E;G-I;VX@:6YT;R!A
M(")R96%L(B!W:6MI(')U;&4N"BH@"BH@5&5X=%]7:6MI7U)U;&4@8VQA<W-E
M<R!D;R!N;W0@<W1A;F0@;VX@=&AE:7(@;W=N.R!T:&5Y(&%R92!C86QL960@
M8GD@80HJ(%1E>'1?5VEK:2!O8FIE8W0L('1Y<&-I86QL>2!I;B!T:&4@=')A
M;G-F;W)M*"EM971H;V0N($5A8V@@<G5L92!C;&%S<PHJ('!E<F9O<FUS('1H
M<F5E(&UA:6X@86-T:79I=&EE<SH@<&%R<V4L('!R;V-E<W,L(&%N9"!R96YD
M97(N"BH@"BH@5&AE('!A<G-E*"D@;65T:&]D('1A:V5S(&$@<F5G97@@86YD
M(&%P<&QI97,@:70@=&\@=&AE('=H;VQE(&)L;V-K(&]F"BH@<V]U<F-E('1E
M>'0@870@;VYE('1I;64N($5A8V@@;6%T8V@@:7,@<V5N="!A<R`D;6%T8VAE
M<R!T;R!T:&4**B!P<F]C97-S*"D@;65T:&]D+@HJ(`HJ(%1H92!P<F]C97-S
M*"D@;65T:&]D(&%C=',@;VX@=&AE(&UA=&-H960@=&5X="!F<F]M('1H92!S
M;W5R8V4L(&%N9`HJ('1H96X@<')O8V5S<V5S('1H92!S;W5R8V4@=&5X="!I
M<R!S;VUE('=A>2X@(%1H:7,@;6%Y(&UE86X@=&AE"BH@8W)E871I;VX@;V8@
M82!D96QI;6ET960@=&]K96X@=7-I;F<@861D5&]K96XH*2X@($EN(&5V97)Y
M(&-A<V4L('1H90HJ('!R;V-E<W,H*2!M971H;V0@<F5T=7)N<R!T:&4@=&5X
M="!T:&%T('-H;W5L9"!R97!L86-E('1H92!M871C:&5D('1E>'0**B!F<F]M
M('!A<G-E*"DN"BH@"BH@1FEN86QL>2P@=&AE(')E;F1E<BHH*2!M971H;V1S
M('1A:V4@86YY('1O:V5N(&-R96%T960@8GD@=&AE(')U;&4@86YD"BH@8W)E
M871E<R!O=71P=70@=&5X="!M871C:&EN9R!A('-P96-I9FEC(&9O<FUA="X@
M($EN9&EV:61U86P@<G5L97,@;6%Y"BH@;W(@;6%Y(&YO="!H879E(&]P=&EO
M;G,@9F]R('-P96-I9FEC(&9O<FUA=',N"BH**B!4>7!I8V%L;'DL('1H92!E
M>'1E;F1E9"!R=6QE(&]N;'D@;F5E9',@=&\@9&5F:6YE('1H92!P<F]C97-S
M*"D@86YD"BH@<F5N9&5R*"D@;65T:&]D<SL@=&AE('!A<G-E*"D@;65T:&]D
M(&ES(&=E;F5R86QL>2!T:&4@<V%M92!F<F]M(')U;&4**B!T;R!R=6QE+"!A
M;F0@:&%S(&)E96X@:6YC;'5D960@:&5R92X@($AO=V5V97(L('1H97)E(&ES
M(&YO(')E87-O;B!T:&%T"BH@<G5L97,@8V%N;F]T(&]V97)R:61E('1H97-E
M(&UE=&AO9',L('-O(&QO;F<@87,@=&AE(&YE=R!M971H;V1S(&]P97)A=&4*
M*B!I;B!S=6)S=&%N=&EA;&QY('1H92!S86UE(&UA;FYE<CL@<VEM:6QA<FQY
M+"!T:&4@<G5L92!N965D(&YO="!G96YE<F%T90HJ(&%N>2!T;VME;G,@870@
M86QL+"!A;F0@;6%Y('5S92!A('-P96-I86QI>F5D('!A<G-E*"D@;65T:&]D
M('1O(&9I;'1E<@HJ('1H92!S;W5R8V4@=&5X="X@(%-E92!T:&4@9&5F875L
M="!R=6QE(&-L87-S97,@9F]R(&UA;GD@97AA;7!L97,N"BH@"BH@0&%U=&AO
M<B!0875L($TN($IO;F5S(#QP;6IO;F5S0&-I87=E8BYN970^"BH@"BH@0'!A
M8VMA9V4@5&5X=%]7:6MI"BH@"BHO"@IC;&%S<R!497AT7U=I:VE?4G5L92![
M"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!4:&4@<F5G=6QA<B!E
M>'!R97-S:6]N('5S960@=&\@<&%R<V4@=&AE('-O=7)C92!T97AT(&%N9"!F
M:6YD"B`@("`J(&UA=&-H97,@8V]N9F]R;6EN9R!T;R!T:&ES(')U;&4N("!5
M<V5D(&)Y('1H92!P87)S92@I(&UE=&AO9"X*("`@("H@"B`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`J(`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B`*("`@
M("H@0'-E92!P87)S92@I"B`@("`J(`H@("`@*B\*("`@(`H@("`@=F%R("1R
M96=E>"`](&YU;&P["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!!
M(')E9F5R96YC92!T;R!T:&4@8V%L;&EN9R!497AT7U=I:VD@;V)J96-T+B`@
M5&AI<R!I<R!N965D960@<V\*("`@("H@=&AA="!E86-H(')U;&4@:&%S(&%C
M8V5S<R!T;R!T:&4@<V%M92!S;W5R8V4@=&5X="P@=&]K96X@<V5T+`H@("`@
M*B!54DQS+"!I;G1E<G=I:VD@;6%P<RP@<&%G92!N86UE<RP@971C+@H@("`@
M*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V87(@;V)J
M96-T"B`@("`J+PH@("`@"B`@("!V87(@)%]W:6MI(#T@;G5L;#L*("`@(`H@
M("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!N86UE(&]F('1H:7,@<G5L
M93L@=7-E9"!W:&5N(&EN<V5R=&EN9R!N97<@=&]K96X@87)R87D*("`@("H@
M96QE;65N=',N"B`@("`J(`H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@
M"B`@("`J($!V87(@<W1R:6YG"B`@("`J(`H@("`@*B\*("`@(`H@("`@=F%R
M("1?<G5L92`](&YU;&P["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@
M*B!#;VYS=')U8W1O<B!F;W(@=&AE(')U;&4N"B`@("`J(`H@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&]B:F5C="`F)&]B:B!4
M:&4@8V%L;&EN9R`B<&%R96YT(B!497AT7U=I:VD@;V)J96-T+@H@("`@*B`*
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92!4:&4@=&]K96X@;F%M92!T;R!U
M<V4@9F]R('1H:7,@<G5L92X*("`@("H@"B`@("`J+PH@("`@"B`@("!F=6YC
M=&EO;B!497AT7U=I:VE?4G5L92@F)&]B:BP@)&YA;64I"B`@("!["B`@("`@
M("`@+R\@<V5T('1H92!R969E<F5N8V4@=&\@=&AE(&-A;&QI;F<@5&5X=%]7
M:6MI(&]B:F5C=#L*("`@("`@("`O+R!T:&ES(&%L;&]W<R!U<R!A8V-E<W,@
M=&\@=&AE('-H87)E9"!S;W5R8V4@=&5X="P@=&]K96X*("`@("`@("`O+R!A
M<G)A>2P@971C+@H@("`@("`@("1T:&ES+3Y?=VEK:2`])B`D;V)J.PH@("`@
M("`@(`H@("`@("`@("\O('-E="!T:&4@;F%M92!O9B!T:&ES(')U;&4[(&=E
M;F5R86QL>2!U<V5D('=H96X@861D:6YG"B`@("`@("`@+R\@=&\@=&AE('1O
M:V5N<R!A<G)A>2X*("`@("`@("`D=&AI<RT^7W)U;&4@/2`D;F%M93L*("`@
M('T*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J($%D9"!A('1O:V5N
M('1O('1H92!497AT7U=I:VD@=&]K96YS(&%R<F%Y+"!A;F0@<F5T=7)N(&$@
M9&5L:6UI=&5D"B`@("`J('1O:V5N(&YU;6)E<BX*("`@("H@"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@*B!`<&%R86T@87)R87D@)&]P=&EO
M;G,@06X@87-S;V-I871I=F4@87)R87D@;V8@;W!T:6]N<R!F;W(@=&AE(&YE
M=PH@("`@*B!T;VME;B!A<G)A>2!E;&5M96YT+B`@5&AE(&ME>7,@86YD('9A
M;'5E<R!A<F4@<W!E8VEF:6,@=&\@=&AE"B`@("`J(')U;&4L(&%N9"!M87D@
M;W(@;6%Y(&YO="!B92!C;VUM;VX@=&\@;W1H97(@<G5L92!O<'1I;VYS+B`@
M5'EP:6-A;`H@("`@*B!O<'1I;VYS(&ME>7,@87)E("=T97AT)R!A;F0@)W1Y
M<&4G(&)U="!M87D@:6YC;'5D92!O=&AE<G,N"B`@("`J(`H@("`@*B!`<&%R
M86T@8F]O;&5A;B`D:61?;VYL>2!)9B!T<G5E+"!R971U<FX@;VYL>2!T:&4@
M=&]K96X@;G5M8F5R+"!N;W0*("`@("H@82!D96QI;6ET960@=&]K96X@<W1R
M:6YG+@H@("`@*B`*("`@("H@0')E='5R;B!S=')I;F=\:6YT($)Y(&1E9F%U
M;'0L(')E='5R;B!T:&4@;G5M8F5R(&]F('1H90H@("`@*B!N97=L>2UC<F5A
M=&5D('1O:V5N(&%R<F%Y(&5L96UE;G0@=VET:"!A(&1E;&EM:71E<B!P<F5F
M:7@@86YD"B`@("`J('-U9F9I>#L@:&]W979E<BP@:68@)&ED7V]N;'D@:7,@
M<V5T('1O('1R=64L(')E='5R;B!O;FQY('1H92!T;VME;@H@("`@*B!N=6UB
M97(@*&YO(&1E;&EM:71E<G,I+@H@("`@*B`*("`@("HO"B`@("`*("`@(&9U
M;F-T:6]N(&%D9%1O:V5N*"1O<'1I;VYS(#T@87)R87DH*2P@)&ED7V]N;'D@
M/2!F86QS92D*("`@('L*("`@("`@("`O+R!F;W)C92!T:&4@;W!T:6]N<R!T
M;R!B92!A;B!A<G)A>0H@("`@("`@('-E='1Y<&4H)&]P=&EO;G,L("=A<G)A
M>2<I.PH@("`@("`@(`H@("`@("`@("\O(&9I;F0@=&AE(&YE>'0@=&]K96X@
M;G5M8F5R"B`@("`@("`@)&ED(#T@8V]U;G0H)'1H:7,M/E]W:6MI+3Y?=&]K
M96YS*3L*("`@("`@("`*("`@("`@("`O+R!A9&0@=&AE('1O:V5N"B`@("`@
M("`@)'1H:7,M/E]W:6MI+3Y?=&]K96YS6R1I9%T@/2!A<G)A>2@*("`@("`@
M("`@("`@,"`]/B`D=&AI<RT^7W)U;&4L"B`@("`@("`@("`@(#$@/3X@)&]P
M=&EO;G,*("`@("`@("`I.PH@("`@("`@(`H@("`@("`@("\O(')E='5R;B!A
M('9A;'5E"B`@("`@("`@:68@*"1I9%]O;FQY*2!["B`@("`@("`@("`@("\O
M(')E='5R;B!T:&4@;&%S="!T;VME;B!N=6UB97(*("`@("`@("`@("`@<F5T
M=7)N("1I9#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!R971U
M<FX@=&AE('1O:V5N(&YU;6)E<B!W:71H(&1E;&EM:71E<G,*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=VEK:2T^9&5L:6T@+B`D:60@+B`D=&AI<RT^
M7W=I:VDM/F1E;&EM.PH@("`@("`@('T*("`@('T*("`@(`H@("`@"B`@("`O
M*BH*("`@("H@"B`@("`J(%-E="!O<B!R92US970@82!T;VME;B!W:71H('-P
M96-I9FEC(&EN9F]R;6%T:6]N+"!O=F5R=W)I=&EN9R!A;GD*("`@("H@<')E
M=FEO=7,@<G5L92!N86UE(&%N9"!R=6QE(&]P=&EO;G,N"B`@("`J(`H@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&EN="`D:60@
M5&AE('1O:V5N(&YU;6)E<B!T;R!R97-E="X*("`@("H@"B`@("`J($!P87)A
M;2!I;G0@)')U;&4@5&AE(')U;&4@;F%M92!T;R!U<V4[(&)Y(&1E9F%U;'0L
M('5S92!T:&4@8W5R<F5N=`H@("`@*B!R=6QE(&YA;64L(&%L=&AO=6=H('EO
M=2!C86X@<W!E8VEF>2!A;GD@<G5L92X*("`@("H@"B`@("`J($!P87)A;2!A
M<G)A>2`D;W!T:6]N<R!!;B!A<W-O8VEA=&EV92!A<G)A>2!O9B!O<'1I;VYS
M(&9O<B!T:&4*("`@("H@=&]K96X@87)R87D@96QE;65N="X@(%1H92!K97ES
M(&%N9"!V86QU97,@87)E('-P96-I9FEC('1O('1H90H@("`@*B!R=6QE+"!A
M;F0@;6%Y(&]R(&UA>2!N;W0@8F4@8V]M;6]N('1O(&]T:&5R(')U;&4@;W!T
M:6]N<RX@(%1Y<&EC86P*("`@("H@;W!T:6]N<R!K97ES(&%R92`G=&5X="<@
M86YD("=T>7!E)R!B=70@;6%Y(&EN8VQU9&4@;W1H97)S+@H@("`@*B`*("`@
M("H@0')E='5R;B!V;VED"B`@("`J(`H@("`@*B\*("`@(`H@("`@9G5N8W1I
M;VX@<V5T5&]K96XH)&ED+"`D<G5L92`](&YU;&PL("1O<'1I;VYS(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`O+R!G970@82!R=6QE(&YA;64*("`@("`@
M("!I9B`H:7-?;G5L;"@D<G5L92DI('L*("`@("`@("`@("`@)')U;&4@/2`D
M=&AI<RT^7W)U;&4["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(')E
M<V5T('1H92!T;VME;@H@("`@("`@("1T:&ES+3Y?=VEK:2T^7W1O:V5N<ULD
M:61=(#T@87)R87DH"B`@("`@("`@("`@(#`@/3X@)')U;&4L"B`@("`@("`@
M("`@(#$@/3X@)&]P=&EO;G,*("`@("`@("`I.PH@("`@?0H@("`@"B`@("`*
M("`@("\J*@H@("`@*B`*("`@("H@4VEM<&QE('!A<G-I;F<@;65T:&]D('1O
M(&%P<&QY('1H92!R=6QE)W,@<F5G=6QA<B!E>'!R97-S:6]N('1O"B`@("`J
M('1H92!S;W5R8V4@=&5X="P@<&%S<R!E=F5R>2!M871C:"!T;R!T:&4@<')O
M8V5S<R@I(&UE=&AO9"P@86YD"B`@("`J(')E<&QA8V4@=&AE(&UA=&-H960@
M=&5X="!W:71H('1H92!R97-U;'1S(&]F('1H92!P<F]C97-S:6YG+@H@("`@
M*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("HO"B`@("`*("`@
M(&9U;F-T:6]N('!A<G-E*"D*("`@('L*("`@("`@("`D=&AI<RT^7W=I:VDM
M/E]S;W5R8V4@/2!P<F5G7W)E<&QA8V5?8V%L;&)A8VLH"B`@("`@("`@("`@
M("1T:&ES+3YR96=E>"P*("`@("`@("`@("`@87)R87DH)B1T:&ES+"`G<')O
M8V5S<R<I+`H@("`@("`@("`@("`D=&AI<RT^7W=I:VDM/E]S;W5R8V4*("`@
M("`@("`I.PH@("`@?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@
M4VEM<&QE('!R;V-E<W-I;F<@;6%T:&]D('1O('1A:V4@;6%T8VAE9"!T97AT
M(&%N9"!G96YE<F%T90H@("`@*B!R97!L86-E;65N="!T97AT+B!4:&ES(&ES
M(&]N92!O9B!T:&4@;65T:&]D<R!Y;W4@=VEL;"!D969I;FET96QY"B`@("`J
M('=A;G0@=&\@;W9E<G)I9&4@:6X@>6]U<B!R=6QE(&-L87-S(&5X=&5N<VEO
M;G,N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@
M0'!A<F%M(&%R<F%Y("1M871C:&5S($%N(&%R<F%Y(&]F(&UA=&-H97,@9G)O
M;2!T:&4@<&%R<V4H*2!M971H;V0*("`@("H@87,@9V5N97)A=&5D(&)Y('!R
M96=?<F5P;&%C95]C86QL8F%C:RX@("1M871C:&5S6S!=(&ES('1H92!F=6QL
M"B`@("`J(&UA=&-H960@<W1R:6YG+"`D;6%T8VAE<ULQ72!I<R!T:&4@9FER
M<W0@;6%T8VAE9"!P871T97)N+`H@("`@*B`D;6%T8VAE<ULR72!I<R!T:&4@
M<V5C;VYD(&UA=&-H960@<&%T=&5R;BP@86YD('-O(&]N+@H@("`@*B`*("`@
M("H@0')E='5R;B!S=')I;F<@5&AE('!R;V-E<W-E9"!T97AT(')E<&QA8V5M
M96YT.R!D969A=6QT<R!T;R!T:&4*("`@("H@9G5L;"!M871C:&5D('-T<FEN
M9R`H:2YE+BP@;F\@8VAA;F=E<R!T;R!T:&4@=&5X="DN"B`@("`J(`H@("`@
M*B\*("`@(`H@("`@9G5N8W1I;VX@<')O8V5S<R@F)&UA=&-H97,I"B`@("![
M"B`@("`@("`@<F5T=7)N("1M871C:&5S6S!=.PH@("`@?0H@("`@"B`@("`*
M("`@("\J*@H@("`@*B`*("`@("H@4VEM<&QE(')E;F1E<FEN9R!M971H;V0@
M=&\@=&%K92!A('-E="!O9B!T;VME;B!O<'1I;VYS(&%N9`H@("`@*B!G96YE
M<F%T92!R97!L86-E;65N="!T97AT(&9O<B!I="X@(%1H:7,@:7,@86YO=&AE
M<B!M971H;V0@>6]U('=I;&P*("`@("H@9&5F:6YI=&5L>2!W86YT('1O(&]V
M97)R:61E(&EN('EO=7(@<G5L92!S=6)C;&%S<R!E>'1E;G-I;VYS+@H@("`@
M*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M(&EN
M="`D:V5Y(%1H92!K97D@;G5M8F5R(&]F('1H92!T;VME;B!B96EN9R!R969E
M<F5N8V5D(&9R;VT@=&AE"B`@("`J(")P87)E;G0B(%1E>'1?5VEK:2!O8FIE
M8W0N"B`@("`J(`H@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@5&AE(")O
M<'1I;VYS(B!P;W)T:6]N(&]F('1H92!T;VME;B`H<V5C;VYD(&5L96UE;G0I
M+@H@("`@*B`*("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T(%1H92!T87)G
M970@9F]R;6%T(&9O<B!T:&4@=&5X="!R96YD97)E9"!F<F]M('1H90H@("`@
M*B!T;VME;B!O<'1I;VYS+"!T>7!I8V%L;'D@)WAH=&UL)RP@86QT:&]U9V@@
M:70@;6%Y(&)E("=L871E>"<@;W(@)W)T9B<N"B`@("`J($EN('EO=7(@<W5B
M8VQA<W,L('EO=2!S:&]U;&0@<')O=FED92`G>&AT;6PG('-U<'!O<G0@870@
M82!M:6YI;75M+@H@("`@*B`*("`@("H@0')E='5R;B!S=')I;F<@5&AE('1E
M>'0@<F5D97)E9"!F<F]M('1H92!T;VME;B!O<'1I;VYS.R!B>2!D969A=6QT
M+`H@("`@*B!N;R!T97AT(&ES(')E='5R;F5D+B`@66]U('-H;W5L9"!C:&%N
M9V4@=&AI<R!I;B!Y;W5R('-U8F-L87-S+B`@.RTI"B`@("`J(`H@("`@*B\*
M("`@(`H@("`@9G5N8W1I;VX@<F5N9&5R6&AT;6PH)&ME>2P@)&]P=&EO;G,L
M("1F;W)M870I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0I]"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U1E>'0O5VEK:2YP:'``````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,S,C0U`#$P-#$W,S8S
M,#`T`#`Q-S<P-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT
M('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4&%U;"!-+B!*;VYE<R`\
M<&UJ;VYE<T!C:6%W96(N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!7
M:6MI+G!H<"QV(#$N-"`R,#`T+S`Q+S,Q(#$U.C4Q.C4T('!M:F]N97,@17AP
M("0*"G)E<75I<F5?;VYC92`G5&5X="]7:6MI+U)U;&4N<&AP)SL*"@HO*BH*
M*B`**B!4:&ES(&ES('1H92`B;6%S=&5R(B!C;&%S<R!F;W(@:&%N9&QI;F<@
M=&AE(&UA;F%G96UE;G0@86YD(&-O;G9E;FEE;F-E"BH@9G5N8W1I;VYS('1O
M('1R86YS9F]R;2!7:6MI+69O<FUA='1E9"!T97AT+@HJ(`HJ($!A=71H;W(@
M4&%U;"!-+B!*;VYE<R`\<&UJ;VYE<T!C:6%W96(N;F5T/@HJ(`HJ($!V97)S
M:6]N(#`N."!A;'!H80HJ(`HJ+PH*8VQA<W,@5&5X=%]7:6MI('L*("`@(`H@
M("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!A<G)A>2!O9B!R=6QE<R!T
M;R!A<'!L>2!T;R!T:&4@<V]U<F-E('1E>'0L(&EN(&]R9&5R+@H@("`@*@H@
M("`@*B!4:&ES(&ES(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=H97)E('1H92!K
M97D@:7,@=&AE('1O:V5N+6YA;64*("`@("H@=&\@8F4@=7-E9"!F;W(@=&AE
M(')U;&4L(&%N9"!T:&4@=F%L=64@:7,@=&AE('!A=&@@=&\@=&AE"B`@("`J
M(')U;&4@8VQA<W,@9FEL92X*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J(`H@("`@*B!`=F%R(&%R<F%Y"B`@("`J(`H@("`@*B\*("`@(`H@
M("`@=F%R("1R=6QE<R`](&%R<F%Y*`H@("`@"B`@("`@("`@+R\@<')E+69I
M;'1E<G,*("`@("`@("`G<')E9FEL=&5R)R`@(#T^("=497AT+U=I:VDO4G5L
M92]P<F5F:6QT97(N<&AP)RP*("`@("`@("`G9&5L:6UI=&5R)R`@(#T^("=4
M97AT+U=I:VDO4G5L92]D96QI;6ET97(N<&AP)RP*("`@("`@("`*("`@("`@
M("`O+R!C87!T=7)I;F<@8FQO8VL@96QE;65N=',*("`@("`@("`G8V]D92<@
M("`@("`@(#T^("=497AT+U=I:VDO4G5L92]C;V1E+G!H<"<L"B`@("`@("`@
M)W!H<&-O9&4G("`@("`]/B`G5&5X="]7:6MI+U)U;&4O<&AP8V]D92YP:'`G
M+`H@("`@("`@("=H=&UL)R`@("`@("`@/3X@)U1E>'0O5VEK:2]2=6QE+VAT
M;6PN<&AP)RP*("`@("`@("`*("`@("`@("`O+R!N;VXM8V%P='5R:6YG(&)L
M;V-K(&5L96UE;G1S"B`@("`@("`@)VAE861I;F<G("`@("`]/B`G5&5X="]7
M:6MI+U)U;&4O:&5A9&EN9RYP:'`G+`H@("`@("`@("=H;W)I>B<@("`@("`@
M/3X@)U1E>'0O5VEK:2]2=6QE+VAO<FEZ+G!H<"<L"B`@("`@("`@)V)L;V-K
M<75O=&4G("`]/B`G5&5X="]7:6MI+U)U;&4O8FQO8VMQ=6]T92YP:'`G+`H@
M("`@("`@("=D969L:7-T)R`@("`@/3X@)U1E>'0O5VEK:2]2=6QE+V1E9FQI
M<W0N<&AP)RP*("`@("`@("`G=&%B;&4G("`@("`@(#T^("=497AT+U=I:VDO
M4G5L92]T86)L92YP:'`G+`H@("`@("`@("=L:7-T)R`@("`@("`@/3X@)U1E
M>'0O5VEK:2]2=6QE+VQI<W0N<&AP)RP*("`@("`@("`G=&]C)R`@("`@("`@
M(#T^("=497AT+U=I:VDO4G5L92]T;V,N<&AP)RP*("`@("`@("`*("`@("`@
M("`O+R!M87)K('!A<F%G<F%P:"!B;&]C:W,*("`@("`@("`G<&%R86=R87!H
M)R`@(#T^("=497AT+U=I:VDO4G5L92]P87)A9W)A<&@N<&AP)RP*("`@("`@
M("`*("`@("`@("`O+R!I;FQI;F4@96QE;65N=',*("`@("`@("`G<F%W)R`@
M("`@("`@(#T^("=497AT+U=I:VDO4G5L92]R87<N<&AP)RP*("`@("`@("`G
M<&AP;&]O:W5P)R`@(#T^("=497AT+U=I:VDO4G5L92]P:'!L;V]K=7`N<&AP
M)RP*("`@("`@("`G=7)L)R`@("`@("`@(#T^("=497AT+U=I:VDO4G5L92]U
M<FPN<&AP)RP*("`@("`@("`G:6YT97)W:6MI)R`@(#T^("=497AT+U=I:VDO
M4G5L92]I;G1E<G=I:VDN<&AP)RP*("`@("`@("`G9G)E96QI;FLG("`@(#T^
M("=497AT+U=I:VDO4G5L92]F<F5E;&EN:RYP:'`G+`H@("`@("`@("=W:6MI
M;&EN:R<@("`@/3X@)U1E>'0O5VEK:2]2=6QE+W=I:VEL:6YK+G!H<"<L"B`@
M("`@("`@)W-T<F]N9R<@("`@("`]/B`G5&5X="]7:6MI+U)U;&4O<W1R;VYG
M+G!H<"<L"B`@("`@("`@)V)O;&0G("`@("`@("`]/B`G5&5X="]7:6MI+U)U
M;&4O8F]L9"YP:'`G+`H@("`@("`@("=E;7!H87-I<R<@("`@/3X@)U1E>'0O
M5VEK:2]2=6QE+V5M<&AA<VES+G!H<"<L"B`@("`@("`@)VET86QI8R<@("`@
M("`]/B`G5&5X="]7:6MI+U)U;&4O:71A;&EC+G!H<"<L"B`@("`@("`@)W1T
M)R`@("`@("`@("`]/B`G5&5X="]7:6MI+U)U;&4O='0N<&AP)RP*("`@("`@
M("`G<W5P97)S8W)I<'0G(#T^("=497AT+U=I:VDO4G5L92]S=7!E<G-C<FEP
M="YP:'`G+`H@("`@("`@("=R979I<V4G("`@("`@/3X@)U1E>'0O5VEK:2]2
M=6QE+W)E=FES92YP:'`G+`H@("`@("`@(`H@("`@("`@("\O('!O<W0M9FEL
M=&5R<PH@("`@("`@("=E;G1I=&EE<R<@("`@/3X@)U1E>'0O5VEK:2]2=6QE
M+V5N=&ET:65S+G!H<"<L"B`@("`@("`@)W1I9VAT96XG("`@("`]/B`G5&5X
M="]7:6MI+U)U;&4O=&EG:'1E;BYP:'`G"B`@("`I.R`*("`@(`H@("`@"B`@
M("`O*BH*("`@("H@"B`@("`J($%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F($EN
M=&5R=VEK:2!M87!P:6YG<R!W:&5R92!T:&4@:V5Y(&ES('1H90H@("`@*B!)
M;G1E<G=I:VD@;F%M92!A<R!E;G1E<F5D(&]N(&$@=VEK:2!P86=E+"!A;F0@
M=&AE('9A;'5E(&ES('1H90H@("`@*B!R97!L86-E;65N="!54DP@9F]R('1H
M92!T87)G970@=VEK:2!W96(N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@*B`*("`@("H@0'9A<B!A<G)A>0H@("`@*B`*("`@("HO"B`@("`*
M("`@('9A<B`D:6YT97)W:6MI(#T@87)R87DH"B`@("`@("`@)TUE871"86QL
M)R`]/B`G:'1T<#HO+W=W=RYU<V5M;V0N8V]M+V-G:2UB:6XO;6(N<&P_)RP*
M("`@("`@("`G061V;V=A=&\G(#T^("=H='1P.B\O861V;V=A=&\N;W)G+R<L
M"B`@("`@("`@)U=I:VDG(#T^("=H='1P.B\O8S(N8V]M+V-G:2]W:6MI/R<*
M("`@("D["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@*B!!;B!A<G)A
M>2!O9B!A;&P@<&%G97,@=&AA="!C=7)R96YT;'D@97AI<W0@:6X@=&AE('=I
M:VDN("!4:&4@<V]U<F-E"B`@("`J(&]F('1H92!P86=E<R!D;V5S(&YO="!M
M871T97(@*&1A=&%B87-E+"!F:6QE('-Y<W1E;2P@=VAA=&5V97(I+B`@06QL
M"B`@("`J('1H870@5&5X=%]7:6MI(&YE961S('1O(&MN;W<@:7,@=VAA="!P
M86=E<R!A<F4@86QR96%D>2!I;B!T:&4@<WES=&5M"B`@("`J('-O('1H870@
M:70@8V%N(&1E8VED92!W:&%T(&MI;F0@;V8@;&EN:R!T;R!S:&]W('=H96X@
M=&AA="!P86=E(&YA;64*("`@("H@87!P96%R<R!I;B!T:&4@<V]U<F-E('1E
M>'0N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@
M0'9A<B!A<G)A>0H@("`@*B`*("`@("HO"B`@("`*("`@('9A<B`D<&%G97,@
M/2!A<G)A>2@I.R`*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H
M92!54DP@=7-E9"!T;R!V:65W(&%N(&5X:7-T:6YG('!A9V4@:6X@=&AE('=I
M:VD[('1H92!P86=E(&YA;64*("`@("H@=VEL;"!B92!A<'!E;F1E9"!T;R!T
M:&ES(&)A<V4@55),+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("H@"B`@("`J($!V87(@<W1R:6YG"B`@("`J(`H@("`@*B\*("`@(`H@("`@
M=F%R("1V:65W7W5R;"`]("=H='1P.B\O97AA;7!L92YC;VTO:6YD97@N<&AP
M/W!A9V4])SL*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!5
M4DP@=7-E9"!T;R!C<F5A=&4@82!P86=E('1H870@9&]E<R!N;W0@97AI<W0@
M:6X@=&AE('=I:VD[('1H90H@("`@*B!P86=E(&YA;64@=VEL;"!B92!A<'!E
M;F1E9"!T;R!T:&ES(&)A<V4@55),+@H@("`@*B`*("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("H@"B`@("`J($!V87(@<W1R:6YG"B`@("`J(`H@("`@*B\*
M("`@(`H@("`@=F%R("1N97=?=7)L(#T@)VAT='`Z+R]E>&%M<&QE+F-O;2]N
M97<N<&AP/W!A9V4])SL*("`@(`H@("`@"B`@("`O*BH*("`@("H@"B`@("`J
M(%=H96X@82!P86=E(&1O97,@;F]T(&5X:7-T(&EN('1H92!W:6MI+"!T:&ES
M(&ES('1H92!T97AT(&9O<B!T:&4*("`@("H@;&EN:R!T;R!T:&4@(F-R96%T
M92(@55),+B`H5'EP:6-A;&QY+"!T:&4@<&%G92!N86UE(&ET<V5L9B!I<R!N
M;W0*("`@("H@=&AE(&QI;FME9"!T97AT.R!I;G-T96%D+"!A('%U97-T:6]N
M(&UA<FL@;W(@86X@:6YL:6YE(&EM86=E(&ES"B`@("`J('5S960@=&\@:6YD
M:6-A=&4@=&AE('!A9V4@9&]E<R!N;W0@97AI<W0N*0H@("`@*B`*("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!V87(@<W1R:6YG"B`@("`J
M(`H@("`@*B\*("`@(`H@("`@=F%R("1N97=?=&5X="`]("<_)SL*("`@(`H@
M("`@"B`@("`O*BH*("`@("H@"B`@("`J(%1H92!D96QI;6ET97(@=&AA="!S
M=7)R;W5N9',@82!T;VME;B!N=6UB97(@96UB961D960@:6X@=&AE('-O=7)C
M90H@("`@*B!W:6MI('1E>'0N"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@*B`*("`@("H@0'9A<B!S=')I;F<*("`@("H@"B`@("`J+PH@("`@
M"B`@("!V87(@)&1E;&EM(#T@(EQX1D8B.R`*("`@(`H@("`@"B`@("`O*BH*
M("`@("H@"B`@("`J($%N(&%R<F%Y(&]F('1O:V5N<R!G96YE<F%T960@8GD@
M<G5L97,@87,@=&AE('-O=7)C92!T97AT(&ES"B`@("`J('!A<G-E9"X*("`@
M("H@"B`@("`J($%S(%1E>'1?5VEK:2!A<'!L:65S(')U;&4@8VQA<W-E<R!T
M;R!T:&4@<V]U<F-E('1E>'0L(&ET('=I;&P*("`@("H@<F5P;&%C92!P;W)T
M:6]N<R!O9B!T:&4@=&5X="!W:71H(&$@9&5L:6UI=&5D('1O:V5N(&YU;6)E
M<BX@(%1H:7,*("`@("H@:7,@=&AE(&%R<F%Y(&]F('1H;W-E('1O:V5N<RP@
M<F5P<F5S96YT:6YG('1H92!R97!L86-E9"!T97AT(&%N9`H@("`@*B!A;GD@
M;W!T:6]N<R!S970@8GD@=&AE('!A<G-E<B!F;W(@=&AA="!R97!L86-E9"!T
M97AT+@H@("`@*B`*("`@("H@5&AE('1O:V5N<R!A<G)A>2!I<R!S97%E;G1I
M86P[(&5A8V@@96QE;65N="!I<R!I='-E;&8@82!S97%U96YT:6%L"B`@("`J
M(&%R<F%Y('=H97)E(&5L96UE;G0@,"!I<R!T:&4@;F%M92!O9B!T:&4@<G5L
M92!T:&%T(&=E;F5R871E9"!T:&4*("`@("H@=&]K96XL(&%N9"!E;&5M96YT
M(#$@:7,@86X@87-S;V-I871I=F4@87)R87D@=VAE<F4@=&AE(&ME>2!I<R!A
M;@H@("`@*B!O<'1I;VX@;F%M92!A;F0@=&AE('9A;'5E(&ES(&%N(&]P=&EO
M;B!V86QU92X*("`@("H@"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B`*
M("`@("H@0'9A<B!S=')I;F<*("`@("H@"B`@("`J+PH@("`@"B`@("!V87(@
M)%]T;VME;G,@/2!A<G)A>2@I.PH@("`@"B`@("`*("`@("\J*@H@("`@*B`*
M("`@("H@5&AE('-O=7)C92!T97AT('1O('=H:6-H(')U;&5S('=I;&P@8F4@
M87!P;&EE9"X@(%1H:7,@=&5X="!W:6QL(&)E"B`@("`J('1R86YS9F]R;65D
M(&EN+7!L86-E+"!W:&EC:"!M96%N<R!T:&%T(&ET('=I;&P@8VAA;F=E(&%S
M('1H92!R=6QE<PH@("`@*B!A<F4@87!P;&EE9"X*("`@("H@"B`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@*B`*("`@("H@0'9A<B!S=')I;F<*("`@("H@
M"B`@("`J+PH@("`@"B`@("!V87(@)%]S;W5R8V4@/2`G)SL*("`@(`H@("`@
M"B`@("`O*BH*("`@("H@"B`@("`J(%1E>'1?5VEK:2!C<F5A=&5S(&]N92!I
M;G-T86YC92!O9B!E=F5R>2!R=6QE('1H870@:7,@87!P;&EE9"!T;PH@("`@
M*B!T:&4@<V]U<F-E('1E>'0[('1H:7,@87)R87D@:&]L9',@=&AO<V4@:6YS
M=&%N8V5S+B`@5&AE(&%R<F%Y(&ME>0H@("`@*B!I<R!T:&4@<G5L92!N86UE
M+"!A;F0@=&AE(&%R<F%Y('9A;'5E(&ES(&%N(&EN<W1A;F-E(&]F('1H92!R
M=6QE"B`@("`J(&-L87-S+@H@("`@*B`*("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`J(`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B`*("`@("HO"B`@("`*
M("`@('9A<B`D7W)U;&5?;V)J(#T@87)R87DH*3L*("`@(`H@("`@"B`@("`O
M*BH*("`@("H@"B`@("`J($-O;G-T<G5C=&]R+@H@("`@*B`*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N
M<R!!;B!A<W-O8VEA=&EV92!A<G)A>2!O9B!O<'1I;VYS('=H97)E('1H90H@
M("`@*B!K97D@:7,@=&AE(&]P=&EO;B!N86UE(&%N9"!T:&4@=F%L=64@:7,@
M=&AE(&]P=&EO;B!V86QU92X@($5A8V@*("`@("H@;W!T:6]N(&ME>2!C;W)R
M97-P;VYD<R!T;R!A('!U8FQI8R!P<F]P97)T>2!O9B!497AT7U=I:VD[(&4N
M9RXL"B`@("`J("=R=6QE<R<L("=I;G1E<G=I:VDG+"`G<&%G97,G+"`G<G5L
M95]D:7(G+"!A;F0@<V\@;VXN"B`@("`J("`@("`*("`@("HO"B`@("`*("`@
M(&9U;F-T:6]N(%1E>'1?5VEK:2@D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS*2`F)B!I<U]A<G)A>2@D;W!T
M:6]N<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&]P=&EO;G,@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@(`DO+R!D;VXG="!O=F5R<FED92!P
M<FEV871E('!R;W!E<G1I97,*("`@("`@("`@("`@("`@(&EF("AS=6)S='(H
M)&ME>2P@,"P@,2D@(3T@)U\G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/B1K97D@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H@("`@"B`@("`*("`@("\J*@H@("`@*B`*
M("`@("H@5')A;G-F;W)M<R!T:&4@<V]U<F-E('1E>'0@:6XM<&QA8V4N"B`@
M("`J(`H@("`@*B!&:7)S="P@=&AE(&UE=&AO9"!P87)S97,@=&AE('-O=7)C
M92!T97AT+"!A<'!L>6EN9R!R=6QE<R!T;R!T:&4*("`@("H@=&5X="!A<R!I
M="!G;V5S+B`@5&AE<V4@<G5L97,@=VEL;"!M;V1I9GD@=&AE('-O=7)C92!T
M97AT"B`@("`J(&EN+7!L86-E+"!R97!L86-I;F<@<V]M92!T97AT('=I=&@@
M9&5L:6UI=&5D('1O:V5N<R`H86YD"B`@("`J('!O<'5L871I;F<@=&AE("1T
M:&ES+3Y?=&]K96YS(&%R<F%Y(&%S(&ET(&=O97,I+@H@("`@*B`*("`@("H@
M3F5X="P@=&AE(&UE=&AO9"!R96YD97)S('1H92!I;BUP;&%C92!T;VME;G,@
M:6YT;R!T:&4@<F5Q=65S=&5D"B`@("`J(&]U='!U="!F;W)M870N"B`@("`J
M(`H@("`@*B!&:6YA;&QY+"!T:&4@;65T:&]D(')E='5R;G,@=&AE('1R86YS
M9F]R;65D('1E>'0N("!.;W1E('1H870@=&AE"B`@("`J('-O=7)C92!T97AT
M(&ES('1R86YS9F]R;65D(&EN('!L86-E.R!O;F-E(&ET(&ES('1R86YS9F]R
M;65D+"!I="!I<PH@("`@*B!N;R!L;VYG97(@=&AE('-A;64@87,@=&AE(&]R
M:6=I;F%L('-O=7)C92!T97AT+@H@("`@*B`*("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("H@"B`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@5&AE('-O=7)C
M92!T97AT('1O('=H:6-H('=I:VD@<G5L97,@<VAO=6QD(&)E"B`@("`J(&%P
M<&QI960L(&)O=&@@9F]R('!A<G-I;F<@86YD(&9O<B!R96YD97)I;F<N"B`@
M("`J(`H@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@5&AE('1A<F=E="!O
M=71P=70@9F]R;6%T+"!T>7!I8V%L;'D@)WAH=&UL)RX*("`@("H@($EF(&$@
M<G5L92!D;V5S(&YO="!S=7!P;W)T(&$@9VEV96X@9F]R;6%T+"!T:&4@;W5T
M<'5T(&9R;VT@=&AA=`H@("`@*B!R=6QE(&ES(')U;&4M<W!E8VEF:6,N"B`@
M("`J(`H@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@=')A;G-F;W)M960@=VEK
M:2!T97AT+@H@("`@*B`*("`@("HO"B`@("`*("`@(&9U;F-T:6]N('1R86YS
M9F]R;2@D=&5X="P@)&9O<FUA="`]("=X:'1M;"<I"B`@("!["B`@("`@("`@
M)'1H:7,M/G!A<G-E*"1T97AT*3L*("`@("`@("!R971U<FX@)'1H:7,M/G)E
M;F1E<B@D9F]R;6%T*3L*("`@('T*("`@(`H@("`@"B`@("`O*BH*("`@("H@
M"B`@("`J(%-E=',@=&AE("1?<V]U<F-E('1E>'0@<')O<&5R='DL('1H96X@
M<&%R<V5S(&ET(&EN('!L86-E(&%N9`H@("`@*B!R971A:6YS('1O:V5N<R!I
M;B!T:&4@)%]T;VME;G,@87)R87D@<')O<&5R='DN"B`@("`J(`H@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@*B`*("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="!4:&4@<V]U<F-E('1E>'0@=&\@=VAI8V@@=VEK:2!R=6QE<R!S:&]U;&0@
M8F4*("`@("H@87!P;&EE9"P@8F]T:"!F;W(@<&%R<VEN9R!A;F0@9F]R(')E
M;F1E<FEN9RX*("`@("H@"B`@("`J($!R971U<FX@=F]I9`H@("`@*B`*("`@
M("HO"B`@("`*("`@(&9U;F-T:6]N('!A<G-E*"1T97AT*0H@("`@>PH@("`@
M("`@("\O('-E="!T:&4@;V)J96-T('!R;W!E<G1Y(&9O<B!T:&4@<V]U<F-E
M('1E>'0*("`@("`@("`D=&AI<RT^7W-O=7)C92`]("1T97AT.PH@("`@("`@
M(`H@("`@("`@("\O(&%P<&QY('1H92!P87)S92@I(&UE=&AO9"!O9B!E86-H
M(')E<75E<W1E9"!R=6QE('1O('1H92!S;W5R8V4*("`@("`@("`O+R!T97AT
M+B`@;&]A9"!E86-H(')U;&4@8VQA<W,@9FEL92!A<R!W92!G;RX*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^<G5L97,@87,@)&YA;64@/3X@)&9I;&4I('L*
M("`@("`@("`@("`@)'1H:7,M/E]L;V%D4G5L92@D;F%M92P@)&9I;&4I.PH@
M("`@("`@("`@("`D=&AI<RT^7W)U;&5?;V)J6R1N86UE72T^<&%R<V4H*3L*
M("`@("`@("!]"B`@("!]"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(`H@("`@
M*B!296YD97)S('1O:V5N<R!B86-K(&EN=&\@=&AE('-O=7)C92!T97AT+"!B
M87-E9"!O;B!T:&4@<F5Q=65S=&5D(&9O<FUA="X*("`@("H@"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J(`H@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M
M870@5&AE('1A<F=E="!O=71P=70@9F]R;6%T+"!T>7!I8V%L;'D@)WAH=&UL
M)RX*("`@("H@($EF(&$@<G5L92!D;V5S(&YO="!S=7!P;W)T(&$@9VEV96X@
M9F]R;6%T+"!T:&4@;W5T<'5T(&9R;VT@=&AA=`H@("`@*B!R=6QE(&ES(')U
M;&4M<W!E8VEF:6,N"B`@("`J(`H@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@
M=')A;G-F;W)M960@=VEK:2!T97AT+@H@("`@*B`*("`@("HO"B`@("`*("`@
M(&9U;F-T:6]N(')E;F1E<B@D9F]R;6%T(#T@)UAH=&UL)RD*("`@('L*("`@
M(`DO+R!T:&4@<F5N9&5R:6YG(&UE=&AO9"!W92=R92!G;VEN9R!T;R!U<V4@
M9G)O;2!E86-H(')U;&4*("`@("`@("`D;65T:&]D(#T@(G)E;F1E<B1F;W)M
M870B.PH@("`@("`@(`H@("`@"2\O('1H92!E=F5N='5A;"!O=71P=70@=&5X
M=`H@("`@("`@("1O=71P=70@/2`G)SL*("`@("`@("`*("`@("`@("`O+R!W
M:&5N('!A<W-I;F<@=&AR;W5G:"!T:&4@<&%R<V5D('-O=7)C92!T97AT+"!K
M965P('1R86-K(&]F('=H96X*("`@("`@("`O+R!W92!A<F4@:6X@82!D96QI
M;6ET960@<V5C=&EO;@H@("`@("`@("1I;E]D96QI;2`](&9A;'-E.PH@("`@
M("`@(`H@("`@("`@("\O('=H96X@:6X@82!D96QI;6ET960@<V5C=&EO;BP@
M8V%P='5R92!T:&4@=&]K96X@:V5Y(&YU;6)E<@H@("`@("`@("1K97D@/2`G
M)SL*("`@("`@("`*("`@("`@("`O+R!P87-S('1H<F]U9V@@=&AE('!A<G-E
M9"!S;W5R8V4@=&5X="!C:&%R86-T97(@8GD@8VAA<F%C=&5R"B`@("`@("`@
M)&L@/2!S=')L96XH)'1H:7,M/E]S;W5R8V4I.PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1K.R`D:2LK*2!["B`@("`@("`@("`@(`H@("`@("`@("`@
M("`O+R!T:&4@8W5R<F5N="!C:&%R86-T97(*("`@("`@("`@("`@)&-H87(@
M/2`D=&AI<RT^7W-O=7)C97LD:7T["B`@("`@("`@("`@(`H@("`@("`@("`@
M("`O+R!A<F4@86QR961Y(&EN(&$@9&5L:6UI=&5D('-E8W1I;VX_"B`@("`@
M("`@("`@(&EF("@D:6Y?9&5L:6TI('L*("`@("`@("`@("`@"B`@("`@("`@
M("`@("`@("`O+R!Y97,[(&%R92!W92!E;F1I;F<@=&AE('-E8W1I;VX_"B`@
M("`@("`@("`@("`@("!I9B`H)&-H87(@/3T@)'1H:7,M/F1E;&EM*2!["B`@
M("`@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`@("`@+R\@>65S
M+"!G970@=&AE(')E<&QA8V5M96YT('1E>'0@9F]R('1H92!D96QI;6ET960*
M("`@("`@("`@("`@("`@("`@("`O+R!T;VME;B!N=6UB97(@86YD('5N<V5T
M('1H92!F;&%G+@H@("`@("`@("`@("`@("`@("`@("1K97D@/2`H:6YT*21K
M97D["B`@("`@("`@("`@("`@("`@("`@)')U;&4@/2`D=&AI<RT^7W1O:V5N
M<ULD:V5Y75LP73L*("`@("`@("`@("`@("`@("`@("`D;W!T<R`]("1T:&ES
M+3Y?=&]K96YS6R1K97E=6S%=.PH@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@)'1H:7,M/E]R=6QE7V]B:ELD<G5L95TM/B1M971H;V0H)&]P=',I
M.PH@("`@("`@("`@("`@("`@("`@("1I;E]D96QI;2`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@("\O(&YO+"!A9&0@
M=&\@=&AE(&1L:6UI=&5D('1O:V5N(&ME>2!N=6UB97(*("`@("`@("`@("`@
M("`@("`@("`D:V5Y("X]("1C:&%R.PH@("`@("`@("`@("`@("`@("`@(`H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(`D*("`@("`@("`@("`@"2\O(&YO="!C
M=7)R96YT;'D@:6X@82!D96QI;6ET960@<V5C=&EO;BX*("`@("`@("`@("`@
M"2\O(&%R92!W92!S=&%R=&EN9R!I;G1O(&$@9&5L:6UI=&5D('-E8W1I;VX_
M"B`@("`@("`@("`@("`@("!I9B`H)&-H87(@/3T@)'1H:7,M/F1E;&EM*2![
M"B`@("`@("`@("`@("`@("`)+R\@>65S+"!R97-E="!T:&4@<')E=FEO=7,@
M:V5Y(&%N9`H@("`@("`@("`@("`@("`@"2\O('-E="!T:&4@9FQA9RX*("`@
M("`@("`@("`@("`@("`@("`D:V5Y(#T@)R<["B`@("`@("`@("`@("`@("`@
M("`@)&EN7V1E;&EM(#T@=')U93L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`)+R\@;F\L(&%D9"!T;R!T:&4@;W5T<'5T(&%S
M+6ES"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D8VAA<CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`*("`@("`@("`O+R!R971U<FX@=&AE(')E;F1E<F5D('-O=7)C92!T97AT
M"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"B`@("`*("`@(`H@("`@
M+RHJ"B`@("`J(`H@("`@*B!2971U<FYS('1H92!P87)S960@<V]U<F-E('1E
M>'0@=VET:"!D96QI;6ET960@=&]K96X@<&QA8V5H;VQD97)S+@H@("`@*B`*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@"B`@("`J($!R971U<FX@<W1R
M:6YG(%1H92!P87)S960@<V]U<F-E('1E>'0N"B`@("`J(`H@("`@*B\*("`@
M(`H@("`@9G5N8W1I;VX@9V5T4V]U<F-E*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]S;W5R8V4["B`@("!]"B`@("`*("`@(`H@("`@+RHJ"B`@
M("`J(`H@("`@*B!2971U<FYS('1O:V5N<R!T:&%T(&AA=F4@8F5E;B!P87)S
M960@;W5T(&]F('1H92!S;W5R8V4@=&5X="X*("`@("H@"B`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`J(`H@("`@*B!`<&%R86T@87)R87D@)')U;&5S($EF
M(&%N(&%R<F%Y(&]F(')U;&4@;F%M97,@:7,@<&%S<V5D+"!O;FQY(')E='5R
M;@H@("`@*B!T;VME;G,@;6%T8VAI;F<@=&AE<V4@<G5L92!N86UE<RX@($EF
M(&YO(&%R<F%Y(&ES('!A<W-E9"P@<F5T=7)N(&%L;`H@("`@*B!T;VME;G,N
M"B`@("`J(`H@("`@*B!`<F5T=7)N(&%R<F%Y($%N(&%R<F%Y(&]F('1O:V5N
M<RX*("`@("H@"B`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!G9714;VME;G,H
M)')U;&5S(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(2!I<U]A<G)A>2@D
M<G5L97,I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1O:V5N<SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@87)R87DH
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]T;VME;G,@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'9A
M;%LP72P@)')U;&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'1;
M72`]("1V86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@?0H@("`@
M"B`@("`*("`@("\J*@H@("`@*B`*("`@("H@3&]A9',@82!R=6QE(&-L87-S
M(&9I;&4@86YD(&-R96%T97,@86X@:6YS=&%N8V4@;V8@=&AE(')U;&4*("`@
M("H@;V)J96-T+@H@("`@*B`*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J
M(`H@("`@*B!`<&%R86T@<W1R:6YG("1N86UE(%1H92!T;VME;B!N86UE('1O
M('5S92!F;W(@=&AE(')U;&4N"B`@("`J(`H@("`@*B!`<&%R86T@<W1R:6YG
M("1F:6QE(%1H92!F:6QE(&YA;64@;V8@=&AE(')U;&4@8VQA<W,N"B`@("`J
M(`H@("`@*B!`<F5T=7)N('9O:60*("`@("H@"B`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!?;&]A9%)U;&4H)&YA;64L("1F:6QE*0H@("`@>PH@("`@("`@
M("\O(&QO860@=&AE(&-L87-S(&1E9FEN:71I;VXN"B`@("`@("`@:6YC;'5D
M95]O;F-E*"1F:6QE*3L*("`@("`@("`*("`@("`@("`O+R!D>6YA;6EC86QL
M>2!D971E<FUI;F4@=&AE(&YA;64@;V8@=&AE(&-L87-S(`H@("`@("`@("\O
M('=E(&IU<W0@;&]A9&5D"B`@("`@("`@)'1M<"`](&=E=%]D96-L87)E9%]C
M;&%S<V5S*"D["B`@("`@("`@)&L@/2!C;W5N="@D=&UP*2`M(#$["B`@("`@
M("`@)&-L87-S(#T@)'1M<%LD:UT["B`@("`@("`@=6YS970H)'1M<"D["B`@
M("`@("`@"B`@("`@("`@+R\@:6YS=&%N=&EA=&4@=&AE(')U;&4@;V)J96-T
M(&%N9"!A9&0@=&\@=&AE('-E=`H@("`@("`@("1T:&ES+3Y?<G5L95]O8FI;
M)&YA;65=(#TF(&YE=R`D8VQA<W,H)'1H:7,L("1N86UE*3L*("`@('T*?0H*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92\`````````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P
M-0`P,38S-#4`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O
M;G1A:6YE<B\`````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#`U`#`R,#(V-P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+V1B>"YP:'``````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C(W-3$`,3`T,3<S-C,P,#4`,#(Q-38Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@
M0V%C:&4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@
M("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V
M86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<G,Z($-H<FES=&EA;B!3=&]C:V5R(#QC:')E9W5`<&AA;G0N
M8V@^("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@9&)X+G!H<"QV(#$N-"`R,#`S
M+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"@H*<F5Q=6ER95]O;F-E("=#86-H
M92]#;VYT86EN97(N<&AP)SL*"B\J*@HJ(&5X="]D8G@@0V%C:&4@0V]N=&%I
M;F5R+@HJ"BH@5T%23DE.1SH@3W1H97(@<WES=&5M<R!M:6=H="!O<B!M:6=H
M="!N;W0@<W5P<&]R="!C97)T86EN(&1A=&%T>7!E<R!O9B`**B!T:&4@=&%B
M;&5S('-H;W=N+B!!<R!F87(@87,@22!K;F]W('1H97)E)W,@;F\@;&%R9V4@
M8FEN87)Y(`HJ('1Y<&4@:6X@4U%,+3DR(&]R(%-13"TY.2X@4&]S=&=R97,@
M<V5E;7,@=&\@;&%C:R!A;GD@"BH@0DQ/0B!O<B!415A4('1Y<&4L(&9O<B!-
M4RU344P@>6]U(&-O=6QD('5S92!)34%'12P@9&]N)W0@:VYO=R`**B!A8F]U
M="!O=&AE<B!D871A8F%S97,N(%!L96%S92!A9&0@<W5G97-T:6]N<R!F;W(@
M;W1H97(@9&%T86)A<V5S('1O(`HJ('1H92!I;FQI;F4@9&]C<RX**@HJ(%1H
M92!F:65L9"`G8VAA;F=E9"<@:&%S(&YO(&UE86YI;F<@9F]R('1H92!#86-H
M92!I='-E;&8N($ET)W,@:G5S="!T:&5R92`**B!B96-A=7-E(&ET)W,@82!G
M;V]D(&ED96$@=&\@:&%V92!A;B!A=71O;6%T:6-A;&QY('5P9&%T960@=&EM
M97-T86UP"BH@9FEE;&0@9F]R(&1E8G5G9VEN9R!I;B!A;&P@;V8@>6]U<B!T
M86)L97,N"BH**B!&;W(@7TUY4U%,7R!Y;W4@;F5E9"!T:&ES($1"('1A8FQE
M.@HJ"BH@0U)%051%(%1!0DQ%(&-A8VAE("@**B`@(&ED("`@("`@("`@($-(
M05(H,S(I($Y/5"!.54Q,($1%1D%53%0@)R<L"BH@("!C86-H96=R;W5P("!6
M05)#2$%2*#$R-RD@3D]4($Y53$P@1$5&055,5"`G)RP**B`@(&-A8VAE9&%T
M82`@($),3T(@3D]4($Y53$P@1$5&055,5"`G)RP**B`@('5S97)D871A("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@97AP:7)E
M<R`@("`@24Y4*#DI($Y/5"!.54Q,($1%1D%53%0@,"P**B`@"BH@("!C:&%N
M9V5D("`@("!424U%4U1!35`H,30I($Y/5"!.54Q,+`HJ("`**B`@($E.1$58
M("AE>'!I<F5S*2P**B`@(%!224U!4ED@2T59("AI9"P@8V%C:&5G<F]U<"D*
M*B`I"BH**B!`875T:&]R("`@0VAR:7-T:6%N(%-T;V-K97(@/&-H<F5G=4!P
M:&%N="YC:#X**B!`=F5R<VEO;B`@)$ED.B!D8G@N<&AP+'8@,2XT(#(P,#,O
M,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0**B!`<&%C:V%G92`@0V%C:&4**B\*
M8VQA<W,@0V%C:&5?0V]N=&%I;F5R7V1B>"!E>'1E;F1S($-A8VAE7T-O;G1A
M:6YE<B!["@H@("`@+RHJ"B`@("`J($YA;64@;V8@=&AE($1"('1A8FQE('1O
M('-T;W)E(&-A8VAI;F<@9&%T80H@("`@*B`*("`@("H@0'-E92`@0V%C:&5?
M0V]N=&%I;F5R7V9I;&4Z.B1F:6QE;F%M95]P<F5F:7@*("`@("HO("`*("`@
M('9A<B`D8V%C:&5?=&%B;&4@/2`G)SL*"B`@("`O*BH*("`@("H@1$)X(&UO
M9'5L92!T;R!U<V4*("`@("H*("`@("H@(&%T('1H92!M;VUE;G0@;VYL>2!M
M>7-Q;"!O<B!O9&)C"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@("HO
M"B`@("!V87(@)&UO9'5L92`]("<G.PH*("`@("\J*@H@("`@*B!$0B!H;W-T
M('1O('5S90H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@
M=F%R("1H;W-T(#T@)R<["@H@("`@+RHJ"B`@("`J($1"(&1A=&%B87-E('1O
M('5S90H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R
M("1D8B`]("<G.PH*("`@("\J*@H@("`@*B!$0B!U<V5R;F%M92!T;R!U<V4*
M("`@("H@"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D=7-E
M<FYA;64@/2`G)SL*"B`@("`O*BH*("`@("H@1$(@<&%S<W=O<F0@=&\@=7-E
M"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)'!A
M<W-W;W)D(#T@)R<["@H@("`@+RHJ"B`@("`J($1">"!H86YD;&4@;V)J96-T
M"B`@("`J(`H@("`@*B!`=F%R("!O8FIE8W0@1$)X(&AA;F1L90H@("`@*B\*
M("`@('9A<B`D9&(["B`@("`*("`@(`H@("`@+RHJ"B`@("`J($5S=&%B;&ES
M:"!A('!E<G-I<W1E;G0@8V]N;F5C=&EO;C\*("`@("H@"B`@("`J($!V87(@
M(&)O;VQE86X@"B`@("`J+PH@("`@=F%R("1P97)S:7-T96YT(#T@=')U93L*
M("`@(`H*("`@(&9U;F-T:6]N($-A8VAE7T-O;G1A:6YE<E]D8G@H)&]P=&EO
M;G,I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;W!T:6]N<RD@*2![
M"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TYO(&]P=&EO
M;G,@<W!E8VEF:65D(2<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@(&%R<F%Y
M7VUE<F=E*"1T:&ES+3YA;&QO=V5D7V]P=&EO;G,L(&%R<F%Y*"=M;V1U;&4G
M+"=H;W-T)RPG9&(G+"=U<V5R;F%M92<L)W!A<W-W;W)D)RP@)V-A8VAE7W1A
M8FQE)RP@)W!E<G-I<W1E;G0G*2DI.PH*("`@("`@("!I9B`H(21T:&ES+3YM
M;V1U;&4I"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TYO
M(&UO9'5L92!S<&5C:69I960A)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@
M("`@("`@)'1H:7,M/F1B(#T@9&)X7V-O;FYE8W0H)'1H:7,M/FUO9'5L92P@
M)'1H:7,M/FAO<W0L("1T:&ES+3YD8BP@)'1H:7,M/G5S97)N86UE+"`D=&AI
M<RT^<&%S<W=O<F0L("1T:&ES+3YP97)S:7-T96YT*3L*"B`@("`@("`@:68@
M*&1B>%]E<G)O<B@D=&AI<RT^9&(I*2!["B`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H)T1">"!C;VYN96-T(&9A:6QE9#H@)R`N(&1B>%]E
M<G)O<B@D=&AI<RT^9&(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O;F]T(&EM<&QE;65N=&5D('EE="!I
M;B!D8G@*("`@("`@("`@("`@+R\D=&AI<RT^9&(M/G-E=$9E=&-H36]D92A$
M0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!F971C:"@D:60L("1G<F]U<"D*("`@('L*("`@("`@("`D<75E<GD@
M/2!S<')I;G1F*")314Q%0U0@8V%C:&5D871A+"!U<V5R9&%T82P@97AP:7)E
M<R!&4D]-("5S(%=(15)%(&ED(#T@)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E
M<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D:60I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D9W)O=7`I
M"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("1R97,@/2!D
M8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E<GDI.PH@("`@("`@(&EF("AD8GA?
M97)R;W(H)'1H:7,M/F1B*2D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G1$)X('%U97)Y(&9A:6QE9#H@)R`N(&1B>%]E<G)O<B@D=&AI
M<RT^9&(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D<F]W(#T@
M)')E<RT^9&%T85LP73L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R;W<I*0H@
M("`@("`@("`@("`D9&%T82`](&%R<F%Y*"1R;W=;)V5X<&ER97,G72P@)'1H
M:7,M/F1E8V]D92@D<F]W6R=C86-H961A=&$G72DL("1R;W=;)W5S97)D871A
M)UTI.PH@("`@("`@(&5L<V4@"B`@("`@("`@("`@("1D871A(#T@87)R87DH
M3E5,3"P@3E5,3"P@3E5,3"D["@H@("`@("`@("\O(&QA<W0@=7-E9"!R97%U
M:7)E9"!B>2!T:&4@9V%R8F%G92!C;VQL96-T:6]N("`@"B`@("`@("`@+R\@
M5T%23DE.1SH@;6EG:'0@8F4@37E344P@<W!E8VEF:6,@("`@("`@("`*("`@
M("`@("`D<75E<GD@/2!S<')I;G1F*")54$1!5$4@)7,@4T54(&-H86YG960@
M/2`H3D]7*"D@*R`P*2!72$5212!I9"`]("<E<R<@04Y$(&-A8VAE9W)O=7`@
M/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC
M86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L
M87-H97,H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L
M87-H97,H)&=R;W5P*0H@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@
M("`@("`@"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q
M=65R>2D["B`@("`@("`@:68@*&1B>%]E<G)O<B@D=&AI<RT^9&(I*0H@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0G@@<75E<GD@9F%I
M;&5D.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`*("`@("`@("`@
M("`@"B`@("`@("`@<F5T=7)N("1D871A.R`@("`@("`@("`@(`H@("`@?0H*
M("`@("\J*@H@("`@*B!3=&]R97,@82!D871A<V5T+@H@("`@*B`*("`@("H@
M5T%23DE.1SH@=V4@=7-E('1H92!344P@8V]M;6%N9"!215!,04-%($E.5$\@
M=&AI<R!M:6=H="!B92`*("`@("H@37E344P@<W!E8VEF:6,N($%S($UY4U%,
M(&ES('9E<GD@<&]P=6QA<B!T:&4@;65T:&]D('-H;W5L9`H@("`@*B!W;W)K
M(&9I;F4@9F]R(#DU)2!O9B!Y;W4N"B`@("`J+PH@("`@9G5N8W1I;VX@<V%V
M92@D:60L("1D871A+"`D97AP:7)E<RP@)&=R;W5P+"`D=7-E<F1A=&$I"B`@
M("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D[
M"@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(E)%4$Q!0T4@24Y43R`E<R`H
M=7-E<F1A=&$L(&-A8VAE9&%T82P@97AP:7)E<RP@:60L(&-A8VAE9W)O=7`I
M(%9!3%5%4R`H)R5S)RP@)R5S)RP@)60L("<E<R<L("<E<R<I(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@
M("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)'5S97)D871A*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)'1H:7,M/F5N8V]D
M92@D9&%T82DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E
M=$5X<&ER97-!8G-O;'5T92@D97AP:7)E<RD@+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@861D<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@861D<VQA<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@
M("`@("D["@H@("`@("`@("1R97,@/2!D8GA?<75E<GDH)'1H:7,M/F1B+"`D
M<75E<GDI.PH*("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI('L*
M("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X('%U97)Y
M(&9A:6QE9#H@)R`N(&1B>%]E<G)O<B@D=&AI<RT^9&(I("P@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<F5M
M;W9E*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R
M96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F
M*")$14Q%5$4@1E)/32`E<R!72$5212!I9"`]("<E<R<@86YD(&-A8VAE9W)O
M=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC
M86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H
M97,H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H
M)&=R;W5P*0H@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D
M<F5S(#T@9&)X7W%U97)Y*"1T:&ES+3YD8BP@)'%U97)Y*3L*"B`@("`@("`@
M:68@*&1B>%]E<G)O<B@D=&AI<RT^9&(I*0H@("`@("`@("`@("!R971U<FX@
M;F5W($-A8VAE7T5R<F]R*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X7V5R
M<F]R*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@9FQU<V@H)&=R;W5P(#T@)R<I"B`@("!["B`@("`@("`@
M)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@("!I9B`H)&=R;W5P*2![
M"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(D1%3$5412!&4D]-("5S
M(%=(15)%(&-A8VAE9W)O=7`@/2`G)7,G(BP@)'1H:7,M/F-A8VAE7W1A8FQE
M+"!A9&1S;&%S:&5S*"1G<F]U<"DI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1Q=65R>2`]('-P<FEN=&8H(D1%3$5412!&4D]-("5S(BP@)'1H
M:7,M/F-A8VAE7W1A8FQE*3L*("`@("`@("!]"@H@("`@("`@("1R97,@/2!D
M8GA?<75E<GDH)'1H:7,M/F1B+"1Q=65R>2D["@H@("`@("`@(&EF("AD8GA?
M97)R;W(H)'1H:7,M/F1B*2D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G1$)X('%U97)Y(&9A:6QE9#H@)R`N(&1B>%]E<G)O<B@D=&AI
M<RT^9&(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H(E-%3$5#5"!I9"!&4D]-("5S(%=(15)%($E$(#T@)R5S
M)R!!3D0@8V%C:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@861D<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@861D<VQA<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@
M("D["@H@("`@("`@("1R97,@/2!D8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E
M<GDI.PH*("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI"B`@("`@
M("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1">"!Q=65R>2!F86EL
M960Z("<@+B!D8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*"@H@("`@("`@("1R;W<@/2`D<F5S6S!=.PH*("`@("`@("!I9B`H
M:7-?87)R87DH)')O=RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO;B@D
M;6%X;&EF971I;64I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A
M9"@I.PH@("`@("`@(`H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)T1%3$54
M12!&4D]-("5S(%=(15)%("AE>'!I<F5S(#P]("5D($%.1"!E>'!I<F5S(#X@
M,"D@3U(@8VAA;F=E9"`\/2`H3D]7*"D@+2`E9"DG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@=&EM92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)&UA>&QI9F5T:6UE"B`@("`@("`@("`@("`@("`@("`@("`@*3L*"@H@("`@
M("`@("1R97,@/2!D8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E<GDI.PH*("`@
M("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI"B`@("`@("`@("`@(')E
M='5R;B!N97<@0V%C:&5?17)R;W(H)T1">"!Q=65R>2!F86EL960Z("<@+B!D
M8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@
M("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G<V5L96-T('-U;2AL96YG=&@H8V%C
M:&5D871A*2D@87,@0V%C:&53:7IE(&9R;VT@)7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@
M("`@("`@("`@*3L*"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^
M9&(L("1Q=65R>2D["B`@("`@("`@+R]I9B!C86-H92!I<R!T;R!B:6<N"B`@
M("`@("`@:68@*"1R97,M/F1A=&%;,%U;0V%C:&53:7IE72`^("1T:&ES+3YH
M:6=H=V%T97(I"B`@("`@("`@>PH@("`@("`@("`@("`O+V9I;F0@=&AE(&QO
M=W=A=&5R(&UA<FLN"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)W-E
M;&5C="!L96YG=&@H8V%C:&5D871A*2!A<R!S:7IE+"!C:&%N9V5D(&9R;VT@
M)7,@;W)D97(@8GD@8VAA;F=E9"!$15-#)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L90H@("`@("`@
M("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@("`D<F5S(#T@9&)X7W%U
M97)Y*"1T:&ES+3YD8BP@)'%U97)Y*3L*("`@("`@("`@("`@)&ME97!?<VEZ
M93TP.PH@("`@("`@("`@("`D:3TP.PH@("`@("`@("`@("!W:&EL92`H)&ME
M97!?<VEZ92`\("1T:&ES+3YL;W=W871E<B`F)B`D:2`\("1R97,M/G)O=W,@
M*0H@("`@("`@("`@("!["@H@("`@("`@("`@("`@("`@)&ME97!?<VEZ92`K
M/2`D<F5S+3YD871A6R1I75MS:7IE73L*("`@("`@("`@("`@("`@("1I*RL[
M"B`@("!]"B`@("`*("`@("`@("`@("`@+R]D96QE=&4@86QL(&5N=')I97,L
M('=H:6-H('=E<F4@8VAA;F=E9"!B969O<F4@=&AE(")L;W=W=V%T97(@;6%R
M:R(*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G9&5L971E(&9R;VT@
M)7,@=VAE<F4@8VAA;F=E9"`\/2`E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S+3YD871A6R1I75MC
M:&%N9V5D70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`@("`@("`@("1R97,@/2!D8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E
M<GDI.PH@("`@("`@('T*("`@('T*?0H_/@``````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A
M:6YE<B]S:&TN<&AP````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(Q
M,3,U`#$P-#$W,S8S,#`U`#`R,34V-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N
M9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS
M8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!S:&TN<&AP
M+'8@,2XS(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0*"G)E<75I<F5?
M;VYC92`G0V%C:&4O0V]N=&%I;F5R+G!H<"<["@HO*BH**B!3=&]R97,@8V%C
M:&4@9&%T82!I;G1O('-H87)E9"!M96UO<GDN"BH**B!796QL+"!T:&ES(&ES
M(&YO="!A('9E<GD@969F:6-I96YT(&EM<&QE;65N=&%T:6]N+B!);F1E960@
M:70G<R!M=6-H(`HJ('-L;W=E<B!T:&%N('1H92!F:6QE(&-O;G1A:6YE<B!A
M<R!F87(@87,@;7D@=&5S=',@<VAO=V5D+B!&:6QE<R!A<F4@"BH@8V%C:&5D
M(&)Y(&UO<W0@;W!E<F%T:6YG('-Y<W1E;7,@86YD(&ET('=I;&P@8F4@:&%R
M9"!T;R!W<FET92!A(&9A<W1E<B`**B!C86-H:6YG(&%L9V]R:71H;2!U<VEN
M9R!02%`N"BH**B!`875T:&]R("`@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P
M:'!D;V,N9&4^"BH@0'9E<G-I;VX@("1)9#H@<VAM+G!H<"QV(#$N,R`R,#`S
M+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BHO
M"F-L87-S($-A8VAE7T-O;G1A:6YE<E]S:&T@97AT96YD<R!#86-H95]#;VYT
M86EN97(@>PH@("`@+RHJ"B`@("`J($ME>2!O9B!T:&4@<V5M87!H;W)E('5S
M960@=&\@<WEN8R!T:&4@4TA-(&%C8V5S<PH@("`@*B`*("`@("H@0'9A<B`@
M:6YT"B`@("`J+PH@("`@=F%R("1S96U?:V5Y(#T@3E5,3#L*"B`@("`O*BH*
M("`@("H@4&5R;6ES<VEO;G,@;V8@=&AE('-E;6%P:&]R92!U<V5D('1O('-Y
M;F,@=&AE(%-(32!A8V-E<W,*("`@("H@"B`@("`J($!V87(@(&EN=`H@("`@
M*B\*("`@('9A<B`D<V5M7W!E<FT@/2`P-C0T.PH*("`@("\J*@H@("`@*B!3
M96UA<&AO<F4@:&%N9&QE<@H@("`@*B`*("`@("H@0'9A<B`@<F5S;W5R8V4*
M("`@("HO"B`@("!V87(@)'-E;5]I9"`]($Y53$P["@H@("`@+RHJ"B`@("`J
M($ME>2!O9B!T:&4@<VAA<F5D(&UE;6]R>2!B;&]C:R!U<V5D('1O('-T;W)E
M(&-A8VAE(&1A=&$*("`@("H*("`@("H@0'9A<B`@:6YT"B`@("`J+PH@("`@
M=F%R("1S:&U?:V5Y(#T@3E5,3#L*"B`@("`O*BH*("`@("H@4VEZ92!O9B!T
M:&4@<VAA<F5D(&UE;6]R>2!B;&]C:R!U<V5D"B`@("`J(`H@("`@*B!.;W1E
M.B!T:&4@8V]N=&%I;F5R(&1O97,@;VYL>2!U<V4@7V]N95\@<VAM(&)L;V-K
M(&YO(&UO<F4A"B`@("`J(`H@("`@*B!`=F%R("!I;G0*("`@("HO("`@("`@
M("`*("`@('9A<B`D<VAM7W-I>F4@/2`Q,S$P-S(["@H@("`@+RHJ"B`@("`J
M(%!E<FUI<W-I;VYS(&]F('1H92!S:&%R960@;65M;W)Y(&)L;V-K"B`@("`J
M(`H@("`@*B!`=F%R("!I;G0*("`@("HO"B`@("!V87(@)'-H;5]P97)M(#T@
M,#8T-#L*"B`@("`O*BH*("`@("H@4VAA<F5D(&UE;6]R>2!H86YD;&5R"B`@
M("`J(`H@("`@*B!`=F%R(')E<V]U<F-E"B`@("`J+PH@("`@=F%R("1S:&U?
M:60@/2!.54Q,.PH*("`@("\J*@H@("`@*B!(87-H(&]F(&-A8VAE(&5N=')I
M97,*("`@("H@"B`@("`J(%5S960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C=&EO
M;B!T;R!F:6YD(&]L9"!E;G1R:65S+@H@("`@*@H@("`@*B!`=F%R("!A<G)A
M>0H@("`@*B\*("`@('9A<B`D96YT<FEE<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`J($YU;6)E<B!O9B!B>71E<R!C;VYS=6UE9"!B>2!T:&4@8V%C:&4*
M("`@("H@"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@('9A<B`D=&]T86Q?
M<VEZ92`](#`["@H@("`@+RHJ"B`@("`J($-R96%T97,@82!S:&%R960@;65M
M;W)Y(&-O;G1A:6YE<@H@("`@*@H@("`@*B!`<&%R86T@87)R87D@("`@<VAM
M7VME>2P@<V5M7VME>2P@<VAM7W-I>F4L('-E;5]P97)M+"!S:&U?<&5R;0H@
M("`@*B\@("`@"B`@("!F=6YC=&EO;B!#86-H95]#;VYT86EN97)?<VAM*"1O
M<'1I;VYS(#T@)R<I('L*("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G,I
M*0H@("`@("`@("`@("`D=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@87)R
M87E?;65R9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G<VAM7VME>2<L("`G<V5M7VME>2<L(`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-H;5]S
M:7IE)RP@)W-E;5]P97)M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S:&U?<&5R;2<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@
M("`@("`@+R\@0V%C:&4Z.D-O;G1A:6YE<B!H:6=H+2!A;F0@;&]W=V%T97(@
M9&5F875L=',@<VAO=6QD(&)E(&]V97)R:61D96X@:68*("`@("`@("`O+R!N
M;W0@86QR96%D>2!D;VYE(&)Y('1H92!U<V5R"B`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG:&EG:'=A=&5R)UTI*2`*("`@("`@("`@("`@)'1H:7,M
M/FAI9VAW871E<B`](')O=6YD*#`N-S4@*B`Q,S$P-S(I.PH@("`@("`@(&EF
M("@A:7-S970H)&]P=&EO;G-;)VQO=W=A=&5R)UTI*0H@("`@("`@("`@("`D
M=&AI<RT^;&]W=V%T97(@/2!R;W5N9"@P+C4@*B`Q,S$P-S(I.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S:&U?<VEZ92==*2D*("`@("`@("`@
M("`@)'1H:7,M/G-H;5]S:7IE(#T@,3,Q,#<R.PH*("`@("`@("`O+V=E="!3
M2$T@86YD(%-E;6%P:&]R92!H86YD;&5S"B`@("`@("`@:68@*"$H)'1H:7,M
M/G-H;5]I9"`]('-H;6]P7V]P96XH)'1H:7,M/G-H;5]K97DL("=C)RP@)'1H
M:7,M/G-H;5]P97)M+"`D=&AI<RT^<VAM7W-I>F4I*2D*("`@("`@("`@("`@
M;F5W($-A8VAE7T5R<F]R*")#86XG="!O<&5N(%-(32!S96=M96YT("=[)'1H
M:7,M/G-H;5]K97E])RP@<VEZ92`G>R1T:&ES+3YS:&U?<VEZ97TG+B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?3$E.15]?"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D["@H@("`@("`@(&EF("@A*"1T:&ES+3YS96U?:60@/2!S
M96U?9V5T*"1T:&ES+3YS96U?:V5Y+"`Q+"`D=&AI<RT^<V5M7W!E<FTI*2D*
M("`@("`@("`@("`@;F5W($-A8VAE7T5R<F]R*")#86XG="!G970@<V5M87!H
M;W)E("=[)'1H:7,M/G-E;5]K97E])R!U<VEN9R!P97)M<R`G>R1T:&ES+3YS
M96U?<&5R;7TG+B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@?2`O+R!E;F0@8V]N
M<W1R=6-T;W(*"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G<F]U<"D@>PH@
M("`@("`@('-E;5]A8W%U:7)E*"1T:&ES+3YS96U?:60I.PH*("`@("`@("`D
M8V%C:&5D871A(#T@<VAM;W!?<F5A9"@D=&AI<RT^<VAM7VED+"`P+"`D=&AI
M<RT^<VAM7W-I>F4I.PH*("`@("`@("!S96U?<F5L96%S92@D=&AI<RT^<V5M
M7VED*3L*"B`@("`@("`@)&-A8VAE9&%T82`]("1T:&ES+3YD96-O9&4H)&-A
M8VAE9&%T82D["@H@("`@("`@(&EF("@A:7-S970H)&-A8VAE9&%T85LD9W)O
M=7!=6R1I9%TI*0H@("`@("`@("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,
M3"P@3E5,3"D["B`@("`@("`@96QS92`*("`@("`@("`@("`@)&-A8VAE9&%T
M82`]("1C86-H961A=&%;)&=R;W5P75LD:61=.PH*("`@("`@("!R971U<FX@
M87)R87DH)&-A8VAE9&%T85LG97AP:7)E)UTL"B`@("`@("`@("`@("`@("`@
M("`@("1C86-H961A=&%;)V-A8VAE9&%T82==+`H@("`@("`@("`@("`@("`@
M("`@("`D8V%C:&5D871A6R=U<V5R9&%T82=="B`@("`@("`@("`@("`@("`@
M("`@*3L*("`@('T@+R\@96YD(&9U;F,@9F5T8V@*"B`@("!F=6YC=&EO;B!S
M879E*"1I9"P@)&1A=&$L("1E>'!I<F4L("1G<F]U<"P@)'5S97)D871A*2![
M"B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@
M("`@("`@('-E;5]A8W%U:7)E*"1T:&ES+3YS96U?:60I.PH*("`@("`@("`D
M8V%C:&5D871A(#T@)'1H:7,M/F1E8V]D92AS:&UO<%]R96%D*"1T:&ES+3YS
M:&U?:60L(#`L("1T:&ES+3YS:&U?<VEZ92DI.PH@("`@("`@("1C86-H961A
M=&%;)&=R;W5P75LD:61=(#T@87)R87DH)V5X<&ER92<@("`@/3X@)'1H:7,M
M/F=E=$5X<&ER97-!8G-O;'5T92@D97AP:7)E*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C86-H961A=&$G(#T^("1D871A
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S
M97)D871A)R`@/3X@)'5S97)D871A+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V-H86YG960G("`@/3X@=&EM92@I"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@
M(&EF("AS=')L96XH)&YE=V1A=&$@/2`D=&AI<RT^96YC;V1E*"1C86-H961A
M=&$I*2`^("1T:&ES+3YS:&U?<VEZ92D*("`@("`@("`@("`@)&-A8VAE9&%T
M82`]("1T:&ES+3YG87)B86=E0V]L;&5C=&EO;BAT:6UE*"DL("1C86-H961A
M=&$I.PH*("`@("`@("!S:&UO<%]W<FET92@D=&AI<RT^<VAM7VED+"`D;F5W
M9&%T82P@,"D["@H@("`@("`@('-E;5]R96QE87-E*"1T:&ES+3YS96U?:60I
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T@+R\@96YD(&9U;F,@<V%V
M90H*("`@(&9U;F-T:6]N(')E;6]V92@D:60L("1G<F]U<"D@>PH@("`@("`@
M("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("!S
M96U?86-Q=6ER92@D=&AI<RT^<V5M7VED*3L*"B`@("`@("`@)&-A8VAE9&%T
M82`]("1T:&ES+3YD96-O9&4H<VAM;W!?<F5A9"@D=&AI<RT^<VAM7VED+"`P
M+"`D=&AI<RT^<VAM7W-I>F4I*3L*("`@("`@("!U;G-E="@D8V%C:&5D871A
M6R1G<F]U<%U;)&ED72D["B`@("`@("`@<VAM;W!?=W)I=&4H)'1H:7,M/G-H
M;5]I9"P@)'1H:7,M/F5N8V]D92@D8V%C:&5D871A*2P@,"D["@H@("`@("`@
M('-E;5]R96QE87-E*"1T:&ES+3YS96U?:60I.PH@("`@?2`O+R!E;F0@9G5N
M8R!R96UO=F4*"B`@("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`@/2`G)RD@>PH@
M("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*"B`@("`@("`@<V5M7V%C
M<75I<F4H)'1H:7,M/G-E;5]I9"D["@H@("`@("`@('-H;6]P7W=R:71E*"1T
M:&ES+3YS:&U?:60L("1T:&ES+3YE;F-O9&4H87)R87DH*2DL(#`I.PH*("`@
M("`@("!S96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*("`@('T@+R\@96YD
M(&9U;F,@9FQU<V@*"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U
M<"D@>PH@("`@("`@('-E;5]A8W%U:7)E*"1T:&ES+3YS96U?:60I.PH*("`@
M("`@("`D8V%C:&5D871A(#T@<VAM7W)E860H)'1H:7,M/G-H;5]I9"P@,"P@
M)'1H:7,M/G-H;5]S:7IE*3L*"B`@("`@("`@<V5M7W)E;&5A<V4H)'1H:7,M
M/G-E;5]I9"D["@H@("`@("`@("1C86-H961A=&$@/2`D=&AI<RT^9&5C;V1E
M*"1C86-H961A=&$I.PH*("`@("`@("!R971U<FX@:7-S970H)&-A8VAE9&%T
M85LD9W)O=7!=6R1I9%TI.PH@("`@?2`O+R!E;F0@9G5N8R!I<T5X:7-T<PH*
M("`@(&9U;F-T:6]N(&=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92P@
M)&-A8VAE9&%T82`](&%R<F%Y*"DI('L*("`@("`@("!I9B`H)&QO8VL@/2!E
M;7!T>2@D8V%C:&5D871A*2D@>PH@("`@("`@("`@("!S96U?86-Q=6ER92@D
M=&AI<RT^<V5M7VED*3L*("`@("`@("`@("`@)&-A8VAE9&%T82`]("1T:&ES
M+3YD96-O9&4H<VAM;W!?<F5A9"@D=&AI<RT^<VAM7VED+"`P+"`D=&AI<RT^
M<VAM7W-I>F4I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YD;T=A<F)A
M9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92P@)B1C86-H961A=&$I.PH@("`@
M("`@(&EF("@D=&AI<RT^=&]T86Q?<VEZ92`^("1T:&ES+3YH:6=H=V%T97(I
M('L*("`@("`@("`@("`@:W)S;W)T*"1T:&ES+3YE;G1R:65S*3L*("`@("`@
M("`@("`@<F5S970H)'1H:7,M/F5N=')I97,I.PH*("`@("`@("`@("`@=VAI
M;&4@*"1T:&ES+3YT;W1A;%]S:7IE(#X@)'1H:7,M/FQO=W=A=&5R("8F(&QI
M<W0H)'-I>F4L("1E;G1R:65S*2`](&5A8V@H)'1H:7,M/F5N=')I97,I*2![
M"B`@("`@("`@("`@("`@("!R97-E="@D96YT<FEE<RD["@H@("`@("`@("`@
M("`@("`@=VAI;&4@*&QI<W0H)&LL("1E;G1R>2D@/2!E86-H*"1E;G1R:65S
M*2D@>PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1C86-H961A=&%;)&5N
M=')Y6R=G<F]U<"==75LD96YT<GE;)VED)UU=*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=&]T86Q?<VEZ92`M/2`D<VEZ93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1L
M;V-K*0H@("`@("`@("`@("!S96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*
M"B`@("`@("`@)'1H:7,M/F5N=')I97,@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3YT;W1A;%]S:7IE(#T@,#L*"B`@("`@("`@<F5T=7)N("1C86-H961A
M=&$[("`@("`@("`@("`*("`@('T@+R\@96YD(&9U;F,@9V%R8F%G94-O;&QE
M8W1I;VX*"B`@("!F=6YC=&EO;B!D;T=A<F)A9V5#;VQL96-T:6]N*"1M87AL
M:69E=&EM92P@)B1C86-H961A=&$I('L*("`@("`@("`D8VAA;F=E9"`]('1I
M;64H*2`M("1M87AL:69E=&EM93L*("`@("`@("`D<F5M;W9E9"`](#`["@H@
M("`@("`@(')E<V5T*"1C86-H961A=&$I.PH*("`@("`@("!W:&EL92`H;&ES
M="@D9W)O=7`L("1G<F]U<&1A=&$I(#T@96%C:"@D8V%C:&5D871A*2D@>PH@
M("`@("`@("`@("!R97-E="@D9W)O=7!D871A*3L*"B`@("`@("`@("`@('=H
M:6QE("AL:7-T*"1I9"P@)&1A=&$I(#T@96%C:"@D9W)O=7!D871A*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1D871A6R=E>'!I<F4G72`\('1I;64H*2!\
M?"`D9&%T85LG8VAA;F=E9"==(#P@)&-H86YG960I('L*("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D8V%C:&5D871A6R1G<F]U<%U;)&ED72D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O('5G
M;'D@8G5T('-I;7!L92!T;R!I;7!L96UE;G0@.B\*("`@("`@("`@("`@)'-I
M>F4@/2!S=')L96XH)'1H:7,M/F5N8V]D92@D9&%T82DI.PH@("`@("`@("`@
M("`D=&AI<RT^96YT<FEE<ULD<VEZ95U;72`](&%R<F%Y*"=G<F]U<"<@/3X@
M)&=R;W5P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=I9"<@("`@/3X@)&ED"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@)'1H:7,M/G1O
M=&%L7W-I>F4@*ST@)'-I>F4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)')E;6]V960["B`@("!]("`O+R!E;F0@9G5N8R!D;T=A<F)A9V5#;VQL96-T
M:6]N"GT@+R\@96YD(&-L87-S($-A8VAE7T-O;G1A:6YE<E]S:&T*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C
M:&4O0V]N=&%I;F5R+VUD8BYP:'``````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,S,R,30`,3`T,3<S-C,P,#4`,#(Q-30R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@.CH@341"
M($-O;G1A:6YE<B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($YO=&4Z(%1H
M:7,@:7,@82!-1$(M;W)I96YT960@<F5W<FET92!O9B!#86-H92]#;VYT86EN
M97(O9&(N<&AP+B`@("`@('P*+R\@?"!4:&%N:W,@=&\@3'5K87,@4VUI=&@@
M9F]R(&AI<R!P871I96YC92!I;B!A;G-W97)I;F<@;7D@<75E<W1I;VYS("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO
M<CH@3&]R96YZ;R!!;&)E<G1O;B`\;"YA;&)E<G1O;B!A="!Q=6EP;RYI=#X@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("1)9#H@;61B+G!H<"QV(#$N,R`R,#`S+S`Q+S`T(#$Q
M.C4T.C0V(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)TU$0BYP:'`G.PIR97%U
M:7)E7V]N8V4@)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ"BH@4$5!4B]-
M1$(@0V%C:&4@0V]N=&%I;F5R+@HJ"BH@3D(Z(%1H92!F:65L9"`G8VAA;F=E
M9"<@:&%S(&YO(&UE86YI;F<@9F]R('1H92!#86-H92!I='-E;&8N($ET)W,@
M:G5S="!T:&5R90HJ(&)E8V%U<V4@:70G<R!A(&=O;V0@:61E82!T;R!H879E
M(&%N(&%U=&]M871I8V%L;'D@=7!D871E9"!T:6UE<W1A;7`**B!F:65L9"!F
M;W(@9&5B=6=G:6YG(&EN(&%L;"!O9B!Y;W5R('1A8FQE<RX**@HJ($$@6$U,
M($U$0BUC;VUP;&EA;G0@<V-H96UA(&5X86UP;&4@9F]R('1H92!T86)L92!N
M965D960@:7,@<')O=FED960N"BH@3&]O:R!A="!T:&4@9FEL92`B;61B7V-A
M8VAE7W-C:&5M82YX;6PB(&9O<B!T:&%T+@HJ"BH@+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"BH@02!B87-I8R!U<V%G92!E
M>&%M<&QE.@HJ("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0HJ"BH@)&1B:6YF;R`](&%R<F%Y*`HJ("`@)V1A=&%B87-E)R`@
M("`]/B`G9&)N86UE)RP**B`@("=P:'!T>7!E)R`@("`@/3X@)VUY<W%L)RP*
M*B`@("=U<V5R;F%M92<@("`@/3X@)W)O;W0G+`HJ("`@)W!A<W-W;W)D)R`@
M("`]/B`G)RP**B`@("=C86-H95]T86)L92<@/3X@)V-A8VAE)PHJ("D["BH*
M*@HJ("1C86-H92`](&YE=R!#86-H92@G;61B)RP@)&1B:6YF;RD["BH@)&ED
M(#T@)&-A8VAE+3YG96YE<F%T94E$*"=T97-T96YT<GDG*3L**@HJ(&EF("@D
M9&%T82`]("1C86-H92T^9V5T*"1I9"DI('L**B`@("!E8VAO("=#86-H92!H
M:70N/&)R("\^1&%T83H@)RXD9&%T83L**@HJ('T@96QS92!["BH@("`D9&%T
M82`]("=D871A(&]F(&%N>2!K:6YD)SL**B`@("1C86-H92T^<V%V92@D:60L
M("1D871A*3L**B`@(&5C:&\@)T-A8VAE(&UI<W,N/&)R("\^)SL**B!]"BH*
M*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*
M*@HJ($!A=71H;W(@("!,;W)E;GIO($%L8F5R=&]N(#QL+F%L8F5R=&]N(&%T
M('%U:7!O+FET/@HJ($!V97)S:6]N("`D260Z(&UD8BYP:'`L=B`Q+C,@,C`P
M,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`HJ($!P86-K86=E("!#86-H90HJ
M+PIC;&%S<R!#86-H95]#;VYT86EN97)?;61B(&5X=&5N9',@0V%C:&5?0V]N
M=&%I;F5R('L*"B`@("`O*BH*("`@("`J($YA;64@;V8@=&AE($U$0B!T86)L
M92!T;R!S=&]R92!C86-H:6YG(&1A=&$*("`@("`J"B`@("`@*B!`<V5E("!#
M86-H95]#;VYT86EN97)?9FEL93HZ)&9I;&5N86UE7W!R969I>`H@("`@("HO
M"B`@("!V87(@)&-A8VAE7W1A8FQE(#T@)R<["@H@("`@+RHJ"B`@("`@*B!0
M14%2($U$0B!O8FIE8W0*("`@("`J"B`@("`@*B!`=F%R("!O8FIE8W0@4$5!
M4E]-1$(*("`@("`J+PH@("`@=F%R("1D8CL*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D($%R<F%Y('=I
M=&@@8V]N;F5C=&EO;B!I;F9O(&]R(&1S;B!S=')I;F<*("`@("`J+PH@("`@
M9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R7VUD8B@D;W!T:6]N<RD*("`@('L*
M("`@("`@("`D=&AI<RT^9&(@/2`F341".CI#;VYN96-T*"1O<'1I;VYS*3L*
M("`@("`@("!I9BA-1$(Z.FES17)R;W(H)'1H:7,M/F1B*2D@>PH@("`@("`@
M("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$0CHZ8V]N;F5C="!F86EL
M960Z("<*("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YD8BT^9V5T365S
M<V%G92@I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YD8BT^<V5T1F5T8VA-;V1E*$U$0E]&151#
M2$U/1$5?05-33T,I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^<V5T3W!T
M:6]N<R@D;W!T:6]N<RP@87)R87E?;65R9V4H)'1H:7,M/F%L;&]W961?;W!T
M:6]N<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9'-N)RP@)V-A8VAE7W1A8FQE)RDI*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($9E=&-H(&EN('1H92!D8B!T:&4@9&%T82!T:&%T(&UA=&-H
M97,@:6YP=70@<&%R86UE=&5R<PH@("`@("H*("`@("`J($!P87)A;2`@("!S
M=')I;F<@(&1A=&%S970@240*("`@("`J($!P87)A;2`@("!S=')I;F<@(&-A
M8VAE(&=R;W5P"B`@("`@*B!`<F5T=7)N("`@;6EX960@("!D871A<V5T('9A
M;'5E(&]R($Y53$PO0V%C:&5?17)R;W(@;VX@9F%I;'5R90H@("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!F971C:"@D:60L
M("1G<F]U<"D*("`@('L*("`@("`@("`D<75E<GD@/2`G4T5,14-4(&-A8VAE
M9&%T82!&4D]-("<@+B`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@
M("`@("XG(%=(15)%(&ED/2<@("`@("`@+B`D=&AI<RT^9&(M/F=E=%1E>'16
M86QU92@D:60I"B`@("`@("`@("`@("`@("`N)R!!3D0@8V%C:&5G<F]U<#TG
M("X@)'1H:7,M/F1B+3YG971497AT5F%L=64H)&=R;W5P*3L*("`@("`@("!I
M9B@D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI*2!["B`@("`@("`@
M("`@(&EF*"1T:&ES+3YD8BT^96YD3V9297-U;'0H)')E<RDI('L*("`@("`@
M("`@("`@("`@("\O;F\@<F]W<R!R971U<FYE9`H@("`@("`@("`@("`@("`@
M)&1A=&$@/2!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;&]B(#T@)'1H:7,M/F1B+3YF
M971C:$-L;V(H)')E<RPP+"=C86-H961A=&$G*3L*("`@("`@("`@("`@("`@
M(&EF*"%-1$(Z.FES17)R;W(H)&-L;V(I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&-A8VAE9%]D871A(#T@)R<["B`@("`@("`@("`@("`@("`@("`@=VAI
M;&4H(21T:&ES+3YD8BT^96YD3V9,3T(H)&-L;V(I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF*$U$0CHZ:7-%<G)O<B@D97)R;W(@/0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&(M/G)E861,
M;V(H)&-L;V(L)&1A=&$L.#`P,"D\,"DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$0CHZ<75E<GD@
M9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)&5R<F]R+3YG971-97-S86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-A8VAE9%]D871A("X]("1D871A.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!U;G-E="@D9&%T82D["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F1B+3YD97-T<F]Y3&]B*"1C;&]B*3L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&(M/F9R965297-U;'0H)')E
M<RD["@H@("`@("`@("`@("`@("`@("`@("\O9FEN:7-H960@9F5T8VAI;F<@
M3$]"+"!N;W<@9F5T8V@@;W1H97(@9FEE;&1S+BXN"B`@("`@("`@("`@("`@
M("`@("`@)'%U97)Y(#T@)U-%3$5#5"!U<V5R9&%T82P@97AP:7)E<R!&4D]-
M("<@+B`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("XG(%=(15)%(&ED/2<@("`@("`@+B`D=&AI<RT^9&(M/F=E=%1E
M>'1686QU92@D:60I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N)R!!
M3D0@8V%C:&5G<F]U<#TG("X@)'1H:7,M/F1B+3YG971497AT5F%L=64H)&=R
M;W5P*3L*("`@("`@("`@("`@("`@("`@("!I9B@D<F5S(#T@)'1H:7,M/F1B
M+3YQ=65R>2@D<75E<GDI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R
M;W<@/2`D=&AI<RT^9&(M/F9E=&-H26YT;R@D<F5S*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R;W<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULG97AP:7)E<R==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F1E8V]D92@D8V%C:&5D7V1A=&$I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')O=ULG=7-E<F1A=&$G70H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&$@/2!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH3E5,3"P@3E5,
M3"P@3E5,3"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@;F5W($-A
M8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("X@)&-L;V(M/F=E=$UE<W-A9V4H*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^9&(M/F9R965297-U;'0H)')E<RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R]R971U<FX@;F5W($-A8VAE
M7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`O+R`@
M("`@("`@("`N("1R97-U;'0M/F=E=$UE<W-A9V4H*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2A.54Q,+"!.54Q,
M+"!.54Q,*3L*("`@("`@("!]"@H@("`@("`@("\O(&QA<W0@=7-E9"!R97%U
M:7)E9"!B>2!T:&4@9V%R8F%G92!C;VQL96-T:6]N"B`@("`@("`@)'%U97)Y
M(#T@)U501$%412`G("`@("`@("`@("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@
M("`@("`@("`@("`@("`N)R!3150@8VAA;F=E9#TG("`@("X@=&EM92@I"B`@
M("`@("`@("`@("`@("`N)R!72$5212!I9#TG("`@("`@("X@)'1H:7,M/F1B
M+3YG971497AT5F%L=64H)&ED*0H@("`@("`@("`@("`@("`@+B<@04Y$(&-A
M8VAE9W)O=7`])R`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1G<F]U<"D[
M"@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@
M("`@("`@:68@*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R
M971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@
M("`@("`@("`@("`@("`@+B`D=&AI<RT^9&(M/F5R<F]R365S<V%G92@D<F5S
M*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1D871A.PH@("`@?0H*("`@+RHJ"B`@("`@*B!3=&]R97,@82!D871A
M<V5T(&EN('1H92!D871A8F%S90H@("`@("H*("`@("`J($EF(&1A=&%S971?
M240@86QR96%D>2!E>&ES=',L(&]V97)W<FET92!I="!W:71H(&YE=R!D871A
M+`H@("`@("H@96QS92!I;G-E<G0@9&%T82!I;B!A(&YE=R!R96-O<F0N"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@
M("H@0'!A<F%M("`@(&UI>&5D("`@9&%T82!T;R!B92!C86-H960*("`@("`J
M($!P87)A;2`@("!I;G1E9V5R(&5X<&ER871I;VX@=&EM90H@("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("`J($!P87)A;2`@("!S
M=')I;F<@('5S97)D871A"B`@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D9&%T82P@)&5X<&ER97,L("1G
M<F]U<"P@)'5S97)D871A*0H@("`@>PH@("`@("`@(&=L;V)A;"`D9&(["B`@
M("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@
M("`@("1F:65L9',@/2!A<G)A>2@*("`@("`@("`@("`@)VED)R`@("`@("`@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5'EP92<@
M("`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5F%L
M=64G("`]/B`D:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G2V5Y
M)R`@("`]/B!T<G5E"B`@("`@("`@("`@("`@("`@("`@("`@("DL"B`@("`@
M("`@("`@("=U<V5R9&%T82<@(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U1Y<&4G("`@/3X@)VEN=&5G97(G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)U9A;'5E)R`@/3X@)'5S97)D871A+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)TYU;&PG("`@/3X@*"1U<V5R9&%T
M82`_(&9A;'-E(#H@=')U92D*("`@("`@("`@("`@("`@("`@("`@("`@*2P*
M("`@("`@("`@("`@)V5X<&ER97,G("`@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G5'EP92<@("`]/B`G:6YT96=E<B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G5F%L=64G("`]/B`D=&AI<RT^9V5T
M17AP:7)E<T%B<V]L=71E*"1E>'!I<F5S*0H@("`@("`@("`@("`@("`@("`@
M("`@("`I+`H@("`@("`@("`@("`G8V%C:&5G<F]U<"<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G5'EP92<@("`]/B`G=&5X="<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5F%L=64G("`]/B`D9W)O
M=7`*("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F1B+3YR97!L86-E*"1T:&ES+3YC
M86-H95]T86)L92P@)&9I96QD<RD["@H@("`@("`@(&EF*$U$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O+U9A<E]$=6UP.CID:7-P;&%Y
M*"1R97-U;'0I.PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@("`@("X@
M)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<W5L="DL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@('5N<V5T*"1F:65L9',I.R`O
M+V5N9"!F:7)S="!P87)T(&]F('%U97)Y"B`@("`@("`@)'%U97)Y,B`]("=5
M4$1!5$4@)R`@("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@
M("`@+B<@4T54(&-A8VAE9&%T83T_)PH@("`@("`@("`@("`@("`@("XG(%=(
M15)%(&ED/2<N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1I9"D["@H@("`@
M("`@(&EF*"@D<')E<&%R961?<75E<GD@/2`D=&AI<RT^9&(M/G!R97!A<F51
M=65R>2@D<75E<GDR*2DI('L*("`@("`@("`@("`@)&-H87)?;&]B(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G17)R;W(G(#T^("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U1Y<&4G(#T^("=D871A
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=$871A)R`]/B`D=&AI
M<RT^96YC;V1E*"1D871A*0H@("`@("`@("`@("`@("`@("`@("`@("`I.PH@
M("`@("`@("`@("!I9B@A341".CII<T5R<F]R*"1C;&]B(#T@)'1H:7,M/F1B
M+3YC<F5A=&5,;V(H)&-H87)?;&]B*2DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YD8BT^<V5T4&%R86U#;&]B*"1P<F5P87)E9%]Q=65R>2PQ+"1C;&]B
M+"=C86-H961A=&$G*3L*("`@("`@("`@("`@("`@(&EF*$U$0CHZ:7-%<G)O
M<B@D97)R;W(])'1H:7,M/F1B+3YE>&5C=71E475E<GDH)'!R97!A<F5D7W%U
M97)Y*2DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE
M7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`D97)R;W(M/F=E=$UE<W-A9V4H*2`L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=&AI<RT^9&(M/F1E<W1R;WE,;V(H)&-L;V(I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@8W)E871I;VX@;V8@=&AE(&AA
M;F1L97(@;V)J96-T(&9A:6QE9`H@("`@("`@("`@("`@("`@<F5T=7)N(&YE
M=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@
M("`@("`@("`@("`@("`@+B`D8VQO8BT^9V5T365S<V%G92@I("P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^9&(M/F9R9650<F5P87)E9%%U97)Y*"1P<F5P87)E9%]Q=65R>2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R]P<F5P87)E9"!Q=65R>2!F
M86EL960*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341"
M.CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@("`@("`N("1P<F5P
M87)E9%]Q=65R>2T^9V5T365S<V%G92@I("P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@
M9&%T87-E="!F<F]M('1H92!D871A8F%S90H@("`@("H*("`@("`J($!P87)A
M;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("`J($!P87)A;2`@("!S=')I
M;F<@(&-A8VAE(&=R;W5P"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@D
M:60L("1G<F]U<"D*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D
M*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@)'%U97)Y(#T@)T1%3$5412!&4D]-
M("<@("`@("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`N
M)R!72$5212!I9#TG("`@("`@("X@)'1H:7,M/F1B+3YG971497AT5F%L=64H
M)&ED*0H@("`@("`@("`@("`@("`@+B<@04Y$(&-A8VAE9W)O=7`])R`N("1T
M:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1G<F]U<"D["@H@("`@("`@("1R97,@
M/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$U$0CHZ
M:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE
M7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@
M("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5M;W9E(&%L;"!C86-H960@9&%T82!F;W(@82!C97)T86EN(&=R;W5P+"!O
M<B!E;7!T>0H@("`@("H@=&AE(&-A8VAE('1A8FQE(&EF(&YO(&=R;W5P(&ES
M('-P96-I9FEE9"X*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("!C
M86-H92!G<F]U<`H@("`@("HO"B`@("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`@
M/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["@H@
M("`@("`@(&EF("@D9W)O=7`I('L*("`@("`@("`@("`@)'%U97)Y(#T@)T1%
M3$5412!&4D]-("<@("`@("`@+B`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@
M("`@("`@("`@("`@("`N)R!72$5212!C86-H96=R;W5P/2<@+B`D=&AI<RT^
M9&(M/F=E=%1E>'1686QU92@D9W)O=7`I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/F-A
M8VAE7W1A8FQE.PH@("`@("`@('T*"B`@("`@("`@)')E<R`]("1T:&ES+3YD
M8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H341".CII<T5R<F]R*"1R
M97,I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$
M0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`N("1T:&ES+3YD
M8BT^97)R;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K(&EF(&$@9&%T
M87-E="!)1"]G<F]U<"!E>&ES=',N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@9&%T87-E="!)1`H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M8V%C:&4@9W)O=7`*("`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@
M("`@("1Q=65R>2`]("=314Q%0U0@:60@1E)/32`G("`N("1T:&ES+3YC86-H
M95]T86)L90H@("`@("`@("`@("`@("`@+B<@5TA%4D4@:60])R`@("`@("`N
M("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1I9"D*("`@("`@("`@("`@("`@
M("XG($%.1"!C86-H96=R;W5P/2<@+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU
M92@D9W)O=7`I.PH@("`@("`@(&5C:&\@)'%U97)Y.PH@("`@("`@("1R97,@
M/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$U$0CHZ
M:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE
M7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@
M("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("1R;W<@/2`D=&AI<RT^
M9&(M/F9E=&-H26YT;R@D<F5S*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R
M;W<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'87)B86=E(&-O;&QE8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@("`@:6YT(&UA>&QI9F5T:6UE"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92D*("`@('L*
M("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["B`@("`@("`@)'%U97)Y
M(#T@)T1%3$5412!&4D]-("<@("`@("`@("X@)'1H:7,M/F-A8VAE7W1A8FQE
M"B`@("`@("`@("`@("`@("`N)R!72$5212`H97AP:7)E<R`\/2`G("X@=&EM
M92@I"B`@("`@("`@("`@("`@("`N)R!!3D0@97AP:7)E<R`^(#`I($]2(&-H
M86YG960@/#T@)RX@=&EM92@I("T@)&UA>&QI9F5T:6UE.PH*("`@("`@("`D
M<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@("`D<75E
M<GD@/2`G4T5,14-4('-U;2AL96YG=&@H8V%C:&5D871A*2D@87,@0V%C:&53
M:7IE($923TT@)PH@("`@("`@("`@("`@("`@+B`D=&AI<RT^8V%C:&5?=&%B
M;&4["@H@("`@("`@("1C86-H97-I>F4@/2`D=&AI<RT^9&(M/F=E=$]N92@D
M<75E<GDI.PH@("`@("`@(&EF("A-1$(Z.FES17)R;W(H)&-A8VAE<VEZ92DI
M('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ
M=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F1B
M+3YE<G)O<DUE<W-A9V4H)&-A8VAE<VEZ92DL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H@("`@("`@("\O:68@8V%C:&4@:7,@=&\@8FEG+@H@
M("`@("`@(&EF("@D8V%C:&5S:7IE(#X@)'1H:7,M/FAI9VAW871E<BD*("`@
M("`@("!["B`@("`@("`@("`@("\O9FEN9"!T:&4@;&]W=V%T97(@;6%R:RX*
M("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!L96YG=&@H8V%C:&5D871A
M*2!A<R!S:7IE+"!C:&%N9V5D($923TT@)PH@("`@("`@("`@("`@("`@("`@
M("X@)'1H:7,M/F-A8VAE7W1A8FQE("XG($]21$52($)9(&-H86YG960@1$53
M0R<["@H@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E
M<GDI.PH@("`@("`@("`@("!I9B`H341".CII<T5R<F]R*"1R97,I*2!["B`@
M("`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$0CHZ<75E
M<GD@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^9&(M
M/F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D;G5M<F]W<R`]("1T:&ES+3YD8BT^
M;G5M4F]W<R@D<F5S*3L*("`@("`@("`@("`@)&ME97!?<VEZ92`](#`["B`@
M("`@("`@("`@('=H:6QE("@D:V5E<%]S:7IE(#P@)'1H:7,M/FQO=W=A=&5R
M("8F("1N=6UR;W=S+2TI('L*("`@("`@("`@("`@("`@("1E;G1R>2`]("1T
M:&ES+3YD8BT^9F5T8VA);G1O*"1R97,L341"7T9%5$-(34]$15]!4U-/0RD[
M"B`@("`@("`@("`@("`@("`D:V5E<%]S:7IE("L]("1E;G1R>5LG<VEZ92==
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+V1E;&5T92!A;&P@96YT
M<FEE<RP@=VAI8V@@=V5R92!C:&%N9V5D(&)E9F]R92!T:&4@(FQO=W=A=&5R
M(&UA<FLB"B`@("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@
M)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@+B<@5TA%
M4D4@8VAA;F=E9#P])RXH)&5N=')Y6R=C:&%N9V5D)UT@/R`D96YT<GE;)V-H
M86YG960G72`Z(#`I.PH*("`@("`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^
M<75E<GDH)'%U97)Y*3L*("`@("`@("`@("`@:68@*$U$0CHZ:7-%<G)O<B@D
M<F5S*2D@>PH@("`@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@("`@("X@
M)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"C\^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE
M+T-O;G1A:6YE<B]F:6QE+G!H<```````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#,Q,S<S`#$P-#$W,S8S,#`U`#`R,3<R,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5
M;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E<F=M
M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!F
M:6QE+G!H<"QV(#$N,3(@,C`P,R\P,B\Q.2`P.3HU-SHQ,2!C:')E9W4@17AP
M("0*"G)E<75I<F5?;VYC92`G0V%C:&4O0V]N=&%I;F5R+G!H<"<["@HO*BH*
M*B!3=&]R97,@8V%C:&4@8V]N=&5N=',@:6X@82!F:6QE+@HJ"BH@0&%U=&AO
M<B`@(%5L9B!796YD96P@(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X**B!`=F5R
M<VEO;B`@)$ED.B!F:6QE+G!H<"QV(#$N,3(@,C`P,R\P,B\Q.2`P.3HU-SHQ
M,2!C:')E9W4@17AP("0**B\*8VQA<W,@0V%C:&5?0V]N=&%I;F5R7V9I;&4@
M97AT96YD<R!#86-H95]#;VYT86EN97(@>PH*("`@("\J*@H@("`@*B!&:6QE
M(&QO8VMI;F<*("`@("H*("`@("H@5VET:"!F:6QE(&-O;G1A:6YE<BP@:70G
M<R!P;W-S:6)L92P@=&AA="!Y;W4@9V5T(&-O<G)U<'1E9`H@("`@*B!D871A
M+65N=')I97,@=6YD97(@8F%D(&-I<F-U;7-T86YC97,N(%1H92!F:6QE(&QO
M8VMI;F<@;75S=`H@("`@*B!I;7!R;W9E('1H:7,@<')O8FQE;2!B=70@:70G
M<R!E>'!E<FEM96YT86P@<W1U9F8N(%-O('1H90H@("`@*B!D969A=6QT('9A
M;'5E(&ES(&9A;'-E+B!"=70@:70@<V5E;7,@=&\@9VEV92!G;V]D(')E<W5L
M=',*("`@("H*("`@("H@0'9A<B!B;V]L96%N"B`@("`J+PH@("`@=F%R("1F
M:6QE3&]C:VEN9R`](&9A;'-E.PH*("`@("\J*@H@("`@*B!$:7)E8W1O<GD@
M=VAE<F4@=&\@<'5T('1H92!C86-H92!F:6QE<RX*("`@("H*("`@("H@0'9A
M<B`@<W1R:6YG("!-86ME('-U<F4@=&\@861D(&$@=')A:6QI;F<@<VQA<V@*
M("`@("HO"B`@("!V87(@)&-A8VAE7V1I<B`]("<G.PH*("`@("\J*@H@("`@
M*B!&:6QE;F%M92!P<F5F:7@@9F]R(&-A8VAE(&9I;&5S+@H@("`@*@H@("`@
M*B!9;W4@8V%N('5S92!T:&4@9FEL96YA;64@<')E9FEX('1O(&EM<&QE;65N
M="!A(")D;VUA:6XB(&)A<V5D(&-A8VAE(&]R(&IU<W0*("`@("H@=&\@9VEV
M92!T:&4@9FEL97,@82!M;W)E(&1E<V-R:7!T:79E(&YA;64N(%1H92!W;W)D
M(")D;VUA:6XB(&ES(&)O<G)O960@9G)O;0H@("`@*B!A('5S97(@875T:&5N
M=&EF:6-A=&EO;B!S>7-T96TN($]N92!U<V5R(&ED("AC86-H960@9&%T87-E
M="!W:71H('1H92!)1"!X*0H@("`@*B!M87D@97AI<W1S(&EN(&1I9F9E<F5N
M="!D;VUA:6YS("AD:69F97)E;G0@9FEL96YA;64@<')E9FEX*2X@66]U(&UI
M9VAT('=A;G0*("`@("H@=&\@=7-E('1H:7,@=&\@:&%V92!D:69F97)E;G0@
M8V%C:&4@=F%L=65S(&9O<B!A('!R;V1U8W1I;VXL(&1E=F5L;W!M96YT(&%N
M9`H@("`@*B!Q=6%L:71Y(&%S<W5R86YC92!S>7-T96TN($EF('EO=2!W86YT
M('1H92!P<F]D=6-T:6]N(&-A8VAE(&YO="!T;R!B92!I;F9L=65N8V5D"B`@
M("`J(&)Y('1H92!Q=6%L:71Y(&%S<W5R86YC92!A8W1I=FET:65S+"!U<V4@
M9&EF9F5R96YT(&9I;&5N86UE('!R969I>&5S(&9O<B!T:&5M+@H@("`@*@H@
M("`@*B!)('!E<G-O;F%L;'D@9&]N)W0@=&AI;FL@=&AA="!Y;W4G;&P@;F5V
M97(@;F5E9"!T:&ES+"!B=70@-C0P:V(@:&%P<&5N9"!T;R!B90H@("`@*B!N
M;W0@96YO=6=H+"!S;RXN+B!Y;W4@:VYO=R!W:&%T($D@;65A;BX@268@>6]U
M(&9I;F0@82!U<V5F=6P@87!P;&EC871I;VX@;V8@=&AE"B`@("`J(&9E871U
M<F4@<&QE87-E('5P9&%T92!T:&ES(&EN;&EN92!D;V,N"B`@("`J"B`@("`J
M($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D9FEL96YA;65?<')E9FEX
M(#T@)R<["B`@("`*("`@(`H@("`@+RHJ"B`@("`J($QI<W0@;V8@8V%C:&4@
M96YT<FEE<RP@=7-E9"!W:71H:6X@82!G8R!R=6X*("`@("H@"B`@("`J($!V
M87(@87)R87D*("`@("HO"B`@("!V87(@)&5N=')I97,["B`@("`*("`@("\J
M*@H@("`@*B!4;W1A;"!N=6UB97(@;V8@8GET97,@<F5Q=6ER960@8GD@86QL
M(&-A8VAE(&5N=')I97,L('5S960@=VET:&EN(&$@9V,@<G5N+@H@("`@*B`*
M("`@("H@0'9A<B`@:6YT"B`@("`J+PH@("`@=F%R("1T;W1A;%]S:7IE(#T@
M,#L*"@H@("`@+RHJ"B`@("`J($UA>"!,:6YE($QE;F=T:"!O9B!U<V5R9&%T
M80H@("`@*@H@("`@*B!)9B!S970@=&\@,"P@:70@=VEL;"!T86ME('1H92!D
M969A=6QT(`H@("`@*B`H(#$P,C0@:6X@<&AP(#0N,BP@=6YL:6UI=&5D(&EN
M('!H<"`T+C,I"B`@("`J('-E92!H='1P.B\O8V@N<&AP+FYE="]M86YU86PO
M96XO9G5N8W1I;VXN9F=E=',N<&AP"B`@("`J(&9O<B!D971A:6QS"B`@("`J
M"B`@("`J($!V87(@:6YT"B`@("`J+PH@("`@=F%R("1M87A?=7-E<F1A=&%?
M;&EN96QE;F=T:"`](#(U-SL*"B`@("`O*BH*("`@("H@0W)E871E<R!T:&4@
M8V%C:&4@9&ER96-T;W)Y(&EF(&YE8V-E<W-A<GD*("`@("H*("`@("H@0'!A
M<F%M("`@(&%R<F%Y("`@0V]N9FEG(&]P=&EO;G,Z(%LB8V%C:&5?9&ER(B`]
M/B`N+BXL(")F:6QE;F%M95]P<F5F:7@B(#T^("XN+ET*("`@("HO"B`@("`@
M9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R7V9I;&4H)&]P=&EO;G,@/2`G)RD@
M>PH@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI"B`@("`@("`@("`@
M("1T:&ES+3YS971/<'1I;VYS*"1O<'1I;VYS+"!A<G)A>5]M97)G92@D=&AI
M<RT^86QL;W=E9%]O<'1I;VYS+"!A<G)A>2@G8V%C:&5?9&ER)RP@)V9I;&5N
M86UE7W!R969I>"<L("=M87A?=7-E<F1A=&%?;&EN96QE;F=T:"<I*2D["B`@
M("`@("`@"B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*("`@("`@("!I9B`H
M)'1H:7,M/F-A8VAE7V1I<BD*("`@("`@("!["B`@("`@("`@("`@("\O(&UA
M:V4@<F5L871I=F4@<&%T:',@86)S;VQU=&4@9F]R('5S92!I;B!D96-O;G-T
M<G5C=&]R+@H@("`@("`@("`@("`O+R!I="!L;V]K<R!L:6ME('1H92!D96-O
M;G-T<G5C=&]R(&AA<R!P<F]B;&5M<R!W:71H(')E;&%T:79E('!A=&AS"B`@
M("`@("`@("`@(&EF("A/4U]53DE8("8F("<O)R`A/2`D=&AI<RT^8V%C:&5?
M9&ER>S!]("`I"B`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?9&ER(#T@
M<F5A;'!A=&@H(&=E=&-W9"@I("X@)R\G("X@)'1H:7,M/F-A8VAE7V1I<BD@
M+B`G+R<["@H@("`@("`@("`@("`O+R!C:&5C:R!I9B!A('1R86EL:6YG('-L
M87-H(&ES(&EN(&-A8VAE7V1I<@H@("`@("`@("`@("!I9B`H)'1H:7,M/F-A
M8VAE7V1I<GMS=')L96XH)'1H:7,M/F-A8VAE7V1I<BDM,7T@(3T@1$E214-4
M3U)97U-%4$%2051/4BD*("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?
M9&ER("X]("<O)SL*"B`@("`@("`@("`@(&EF("`H(69I;&5?97AI<W1S*"1T
M:&ES+3YC86-H95]D:7(I('Q\("%I<U]D:7(H)'1H:7,M/F-A8VAE7V1I<BDI
M"B`@("`@("`@("`@("`@("!M:V1I<B@D=&AI<RT^8V%C:&5?9&ER+"`P-S4U
M*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F5N=')I97,@/2!A<G)A>2@I
M.PH@("`@("`@("1T:&ES+3YG<F]U<%]D:7)S(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("`*("`@('T@+R\@96YD(&9U;F,@8V]N=')U8W1O<@H*
M("`@(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P*2!["B`@("`@("`@)&9I
M;&4@/2`D=&AI<RT^9V5T1FEL96YA;64H)&ED+"`D9W)O=7`I.PH@("`@("`@
M(&EF("@A9FEL95]E>&ES=',H)&9I;&4I*0H@("`@("`@("`@("!R971U<FX@
M87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["@H@("`@("`@("\O(')E=')I=F4@
M=&AE(&-O;G1E;G0*("`@("`@("!I9B`H(2@D9F@@/2!`9F]P96XH)&9I;&4L
M("=R8B<I*2D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B
M0V%N)W0@86-C97-S(&-A8VAE(&9I;&4@)R1F:6QE)RX@0VAE8VL@86-C97-S
M(')I9VAT<R!A;F0@<&%T:"XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@
M("`@("`O+R!&:6QE(&QO8VMI;F<@*'-H87)E9"!L;V-K*0H@("`@("`@(&EF
M("@D=&AI<RT^9FEL94QO8VMI;F<I"B`@("`@("`@("`@(&9L;V-K*"1F:"P@
M3$]#2U]32"D["@H@("`@("`@("\O(&9I;&4@9F]R;6%T.@H@("`@("`@("\O
M(#%S="!L:6YE.B!E>'!I<F%T:6]N(&1A=&4*("`@("`@("`O+R`R;F0@;&EN
M93H@=7-E<B!D871A"B`@("`@("`@+R\@,W)D*R!L:6YE<SH@8V%C:&4@9&%T
M80H@("`@("`@("1E>'!I<F4@/2!T<FEM*&9G971S*"1F:"P@,3(I*3L*("`@
M("`@("!I9B`H)'1H:7,M/FUA>%]U<V5R9&%T85]L:6YE;&5N9W1H(#T](#`@
M*2!["B`@("`@("`@("`@("1U<V5R9&%T82`]('1R:6TH9F=E=',H)&9H*2D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5S97)D871A(#T@=')I
M;2AF9V5T<R@D9F@L("1T:&ES+3YM87A?=7-E<F1A=&%?;&EN96QE;F=T:"DI
M.PH@("`@("`@('T*("`@("`@("`D8V%C:&5D871A(#T@)'1H:7,M/F1E8V]D
M92AF<F5A9"@D9F@L(&9I;&5S:7IE*"1F:6QE*2DI.PH*("`@("`@("`O+R!5
M;FQO8VMI;F<*("`@("`@("!I9B`H)'1H:7,M/F9I;&5,;V-K:6YG*0H@("`@
M("`@("`@("!F;&]C:R@D9F@L($Q/0TM?54XI.PH*("`@("`@("!F8VQO<V4H
M)&9H*3L*"B`@("`@("`@+R\@;&%S="!U<V%G92!D871E('5S960@8GD@=&AE
M(&=C("T@;6%X;&EF971I;64*("`@("`@("`O+R!T;W5C:"!W:71H;W5T('-E
M8V]N9"!P87)A;2!P<F]D=6-E9"!S='5P:60@96YT<FEE<RXN+@H@("`@("`@
M('1O=6-H*"1F:6QE+'1I;64H*2D["B`@("`@("`@8VQE87)S=&%T8V%C:&4H
M*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1E>'!I<F4L("1C86-H961A=&$L
M("1U<V5R9&%T82D["B`@("!]("\O(&5N9"!F=6YC(&9E=&-H"@H@("`@+RHJ
M"B`@("`J(%-T;W)E<R!A(&1A=&%S970N"B`@("`J"B`@("`J(%=!4DY)3D<Z
M($EF('EO=2!S=7!P;'D@=7-E<F1A=&$@:70@;75S="!N;W0@8V]N=&%I;B!A
M;GD@;&EN96)R96%K<RP*("`@("H@;W1H97)W:7-E(&ET('=I;&P@8G)E86L@
M=&AE(&9I;&5S=')U8W1U<F4N"B`@("`J+PH@("`@9G5N8W1I;VX@<V%V92@D
M:60L("1C86-H961A=&$L("1E>'!I<F5S+"`D9W)O=7`L("1U<V5R9&%T82D@
M>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*
M("`@("`@("`D9FEL92`]("1T:&ES+3YG971&:6QE;F%M92@D:60L("1G<F]U
M<"D["B`@("`@("`@:68@*"$H)&9H(#T@0&9O<&5N*"1F:6QE+"`G=V(G*2DI
M"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T(&%C
M8V5S<R`G)&9I;&4G('1O('-T;W)E(&-A8VAE(&1A=&$N($-H96-K(&%C8V5S
M<R!R:6=H=',@86YD('!A=&@N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@
M("`@("`@+R\@1FEL92!L;V-K:6YG("AE>&-L=7-I=F4@;&]C:RD*("`@("`@
M("!I9B`H)'1H:7,M/F9I;&5,;V-K:6YG*0H@("`@("`@("`@("!F;&]C:R@D
M9F@L($Q/0TM?15@I.PH*("`@("`@("`O+R!F:6QE(&9O<FUA=#H*("`@("`@
M("`O+R`Q<W0@;&EN93H@97AP:7)A=&EO;B!D871E"B`@("`@("`@+R\@,FYD
M(&QI;F4Z('5S97(@9&%T80H@("`@("`@("\O(#-R9"L@;&EN97,Z(&-A8VAE
M(&1A=&$*("`@("`@("`D97AP:7)E<R`]("1T:&ES+3YG971%>'!I<F5S06)S
M;VQU=&4H)&5X<&ER97,I.PH@("`@("`@(&9W<FET92@D9F@L("1E>'!I<F5S
M("X@(EQN(BD["B`@("`@("`@9G=R:71E*"1F:"P@)'5S97)D871A("X@(EQN
M(BD["B`@("`@("`@9G=R:71E*"1F:"P@)'1H:7,M/F5N8V]D92@D8V%C:&5D
M871A*2D["@H@("`@("`@("\O($9I;&4@=6YL;V-K:6YG"B`@("`@("`@:68@
M*"1T:&ES+3YF:6QE3&]C:VEN9RD*("`@("`@("`@("`@9FQO8VLH)&9H+"!,
M3T-+7U5.*3L*"B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@("`@("\O($DG
M;2!N;W0@<W5R92!I9B!W92!N965D('1H:7,*"2\O(&D@9&]N)W0@=&AI;FL@
M=V4@;F5E9"!T:&ES("AC:')E9W4I"B`@("`@("`@+R\@=&]U8V@H)&9I;&4I
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T@+R\@96YD(&9U;F,@<V%V
M90H*("`@(&9U;F-T:6]N(')E;6]V92@D:60L("1G<F]U<"D@>PH@("`@("`@
M("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D
M9FEL92`]("1T:&ES+3YG971&:6QE;F%M92@D:60L("1G<F]U<"D["B`@("`@
M("`@:68@*&9I;&5?97AI<W1S*"1F:6QE*2D@>PH*("`@("`@("`@("`@)&]K
M(#T@=6YL:6YK*"1F:6QE*3L*("`@("`@("`@("`@8VQE87)S=&%T8V%C:&4H
M*3L*"B`@("`@("`@("`@(')E='5R;B`D;VL["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]("\O(&5N9"!F=6YC(')E;6]V90H*("`@
M(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S
M:%!R96QO860H*3L*("`@("`@("`D9&ER(#T@*"1G<F]U<"D@/R`D=&AI<RT^
M8V%C:&5?9&ER("X@)&=R;W5P("X@)R\G(#H@)'1H:7,M/F-A8VAE7V1I<CL*
M"B`@("`@("`@)&YU;5]R96UO=F5D(#T@)'1H:7,M/F1E;&5T941I<B@D9&ER
M*3L*("`@("`@("!U;G-E="@D=&AI<RT^9W)O=7!?9&ER<ULD9W)O=7!=*3L*
M("`@("`@("!C;&5A<G-T871C86-H92@I.PH*("`@("`@("!R971U<FX@)&YU
M;5]R96UO=F5D.PH@("`@?2`O+R!E;F0@9G5N8R!F;'5S:`H*("`@(&9U;F-T
M:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P*2!["@H@("`@("`@(')E='5R;B!F
M:6QE7V5X:7-T<R@D=&AI<RT^9V5T1FEL96YA;64H)&ED+"`D9W)O=7`I*3L*
M("`@('T@+R\@96YD(&9U;F,@:61%>&ES=',*"B`@("`O*BH*("`@("H@1&5L
M971E<R!A;&P@97AP:7)E9"!F:6QE<RX*("`@("H*("`@("H@1V%R8F%G92!C
M;VQL96-T:6]N(&9O<B!F:6QE<R!I<R!A(')A=&AE<B`B97AP96YS:79E(BP@
M(FQO;F<@=&EM92(*("`@("H@;W!E<F%T:6]N+B!!;&P@9FEL97,@:6X@=&AE
M(&-A8VAE(&1I<F5C=&]R>2!H879E('1O(&)E(&5X86UI;F5D('=H:6-H"B`@
M("`J(&UE86YS('1H870@=&AE>2!M=7-T(&)E(&]P96YE9"!F;W(@<F5A9&EN
M9RP@=&AE(&5X<&ER871I;VX@9&%T92!H87,@=&\@8F4*("`@("H@<F5A9"!F
M<F]M('1H96T@86YD(&EF(&YE8V-E<W-A<GD@=&AE>2!H879E('1O(&)E('5N
M;&EN:V5D("AR96UO=F5D*2X*("`@("H@268@>6]U(&AA=F4@82!U<V5R(&-O
M;6UE;G0@9F]R(&$@9V]O9"!D969A=6QT(&=C('!R;V)A8FEL:71Y('!L96%S
M92!A9&0@:70@=&\*("`@("H@=&\@=&AE(&EN;&EN92!D;V-S+@H@("`@*@H@
M("`@*B!`<&%R86T@("`@:6YT96=E<B!-87AI;75M(&QI9F5T:6UE(&EN('-E
M8V]N9',@;V8@86X@;F\@;&]N9V5R('5S960O=&]U8VAE9"!E;G1R>0H@("`@
M*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*("`@("HO"B`@("!F=6YC=&EO;B!G
M87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF971I;64I('L*"B`@("`@("`@)'1H
M:7,M/F9L=7-H4')E;&]A9"@I.PH@("`@("`@(&-L96%R<W1A=&-A8VAE*"D[
M"@H@("`@("`@("1O:R`]("1T:&ES+3YD;T=A<F)A9V5#;VQL96-T:6]N*"1M
M87AL:69E=&EM92P@)'1H:7,M/F-A8VAE7V1I<BD["@H@("`@("`@("\O(&-H
M96-K('1H92!S<&%C92!U<V5D(&)Y('1H92!C86-H92!E;G1R:65S("`@("`@
M("`*("`@("`@("!I9B`H)'1H:7,M/G1O=&%L7W-I>F4@/B`D=&AI<RT^:&EG
M:'=A=&5R*2!["B`@("`@("`@"B`@("`@("`@("`@(&MR<V]R="@D=&AI<RT^
M96YT<FEE<RD["B`@("`@("`@("`@(')E<V5T*"1T:&ES+3YE;G1R:65S*3L*
M("`@("`@("`@("`@"B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^=&]T86Q?
M<VEZ92`^("1T:&ES+3YL;W=W871E<B`F)B!L:7-T*"1L87-T;6]D+"`D96YT
M<GDI(#T@96%C:"@D=&AI<RT^96YT<FEE<RDI('L*("`@("`@("`@("`@("`@
M(&EF("A`=6YL:6YK*"1E;G1R>5LG9FEL92==*2D*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=&]T86Q?<VEZ92`M/2`D96YT<GE;)W-I>F4G73L*("`@
M("`@("`@("`@("`@(&5L<V4*("`@("`@("`@("`@("`@("`@("!N97<@0V%C
M:&5%<G)O<B@B0V%N)W0@9&5L971E('LD96YT<GE;(F9I;&4B77TN($-H96-K
M('1H92!P97)M:7-S:6]N<RXB*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)'1H:7,M/F5N=')I97,@
M/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YT;W1A;%]S:7IE(#T@,#L*("`@
M("`@("`*("`@("`@("!R971U<FX@)&]K.PH@("`@?2`O+R!E;F0@9G5N8R!G
M87)B86=E0V]L;&5C=&EO;@H@("`@"B`@("`O*BH*("`@("H@1&]E<R!T:&4@
M<F5C=7)S:79E(&=C('!R;V-E9'5R92P@<')O=&5C=&5D+@H@("`@*@H@("`@
M*B!`<&%R86T@("`@:6YT96=E<B!-87AI;75M(&QI9F5T:6UE(&EN('-E8V]N
M9',@;V8@86X@;F\@;&]N9V5R('5S960O=&]U8VAE9"!E;G1R>0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!D:7)E8W1O<GD@=&\@97AA;6EN92`M(&1O;B=T
M('-E=',@=&AI<R!P87)A;65T97(L(&ET)W,@=7-E9"!F;W(@80H@("`@*B`@
M("`@("`@("`@("`@("`@("!R96-U<G-I=F4@9G5N8W1I;VX@8V%L;"$*("`@
M("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@
M9&]'87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF971I;64L("1D:7(I('L*("`@
M("`@("`@("`*("`@("`@("!I9B`H(2@D9&@@/2!O<&5N9&ER*"1D:7(I*2D*
M("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@86-C
M97-S(&-A8VAE(&1I<F5C=&]R>2`G)&1I<B<N($-H96-K('!E<FUI<W-I;VYS
M(&%N9"!P871H+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@('=H
M:6QE("@D9FEL92`](')E861D:7(H)&1H*2D@>PH@("`@("`@("`@("!I9B`H
M)RXG(#T]("1F:6QE('Q\("<N+B<@/3T@)&9I;&4I"B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*"B`@("`@("`@("`@("1F:6QE(#T@)&1I<B`N("1F:6QE
M.PH@("`@("`@("`@("!I9B`H:7-?9&ER*"1F:6QE*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F1O1V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T:6UE
M+"1F:6QE("X@)R\G*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!S:VEP('1R;W5B;&4@;6%K97)S
M(&)U="!I;F9O<FT@=&AE('5S97(*("`@("`@("`@("`@:68@*"$H)&9H(#T@
M0&9O<&5N*"1F:6QE+"`G<F(G*2DI('L*("`@("`@("`@("`@("`@(&YE=R!#
M86-H95]%<G)O<B@B0V%N)W0@86-C97-S(&-A8VAE(&9I;&4@)R1F:6QE)RP@
M<VMI<'!I;F<@:70N($-H96-K('!E<FUI<W-I;VYS(&%N9"!P871H+B(L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&5X<&ER92`](&9G971S*"1F
M:"P@,3$I.PH@("`@("`@("`@("!F8VQO<V4H)&9H*3L*("`@("`@("`@("`@
M)&QA<W1U<V5D(#T@9FEL96UT:6UE*"1F:6QE*3L*("`@("`@("`@("`@"B`@
M("`@("`@("`@("1T:&ES+3YE;G1R:65S6R1L87-T=7-E9%T@/2!A<G)A>2@G
M9FEL92<@/3X@)&9I;&4L("=S:7IE)R`]/B!F:6QE<VEZ92@D9FEL92DI.PH@
M("`@("`@("`@("`D=&AI<RT^=&]T86Q?<VEZ92`K/2!F:6QE<VEZ92@D9FEL
M92D["B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!R96UO=F4@:68@97AP
M:7)E9`H@("`@("`@("`@("!I9B`H*"`H)&5X<&ER92`F)B`D97AP:7)E(#P]
M('1I;64H*2D@?'P@*"1L87-T=7-E9"`\/2`H=&EM92@I("T@)&UA>&QI9F5T
M:6UE*2D@*2`F)B`A=6YL:6YK*"1F:6QE*2D*("`@("`@("`@("`@("`@(&YE
M=R!#86-H95]%<G)O<B@B0V%N)W0@=6YL:6YK(&-A8VAE(&9I;&4@)R1F:6QE
M)RP@<VMI<'!I;F<N($-H96-K('!E<FUI<W-I;VYS(&%N9"!P871H+B(L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!C;&]S961I
M<B@D9&@I.PH*("`@("`@("`O+R!F;'5S:"!T:&4@9&ES:R!S=&%T92!C86-H
M90H@("`@("`@(&-L96%R<W1A=&-A8VAE*"D["@H@("`@?2`O+R!E;F0@9G5N
M8R!D;T=A<F)A9V5#;VQL96-T:6]N"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@
M=&AE(&9I;&5N86UE(&9O<B!T:&4@<W!E8VEF:65D(&ED+@H@("`@*@H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!S=')I;F<@
M(&9U;&P@9FEL96YA;64@=VET:"!T:&4@<&%T:`H@("`@*B!`86-C97-S("`@
M<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T1FEL96YA;64H)&ED+"`D
M9W)O=7`I('L*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YG<F]U<%]D:7)S
M6R1G<F]U<%TI*0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=R;W5P7V1I
M<G-;)&=R;W5P72`N("1T:&ES+3YF:6QE;F%M95]P<F5F:7@@+B`D:60["@H@
M("`@("`@("1D:7(@/2`D=&AI<RT^8V%C:&5?9&ER("X@)&=R;W5P("X@)R\G
M.PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&1I<BDI('L*("`@("`@("`@
M("`@;6MD:7(H)&1I<BP@,#<U-2D["B`@("`@("`@("`@(&-L96%R<W1A=&-A
M8VAE*"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9W)O=7!?9&ER<ULD
M9W)O=7!=(#T@)&1I<CL*"B`@("`@("`@<F5T=7)N("1D:7(@+B`D=&AI<RT^
M9FEL96YA;65?<')E9FEX("X@)&ED.PH@("`@?2`O+R!E;F0@9G5N8R!G971&
M:6QE;F%M90H*("`@("\J*@H@("`@*B!$96QE=&5S(&$@9&ER96-T;W)Y(&%N
M9"!A;&P@9FEL97,@:6X@:70N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I
M;F<@(&1I<F5C=&]R>0H@("`@*B!`<F5T=7)N("`@:6YT96=E<B!N=6UB97(@
M;V8@<F5M;W9E9"!F:6QE<PH@("`@*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*
M("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5$:7(H)&1I<BD@>PH@("`@("`@
M(&EF("@A*"1D:"`](&]P96YD:7(H)&1I<BDI*0H@("`@("`@("`@("!R971U
M<FX@;F5W($-A8VAE7T5R<F]R*")#86XG="!R96UO=F4@9&ER96-T;W)Y("<D
M9&ER)RX@0VAE8VL@<&5R;6ES<VEO;G,@86YD('!A=&@N(BP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*"B`@("`@("`@)&YU;5]R96UO=F5D(#T@,#L*"B`@("`@
M("`@=VAI;&4@*"1F:6QE(#T@<F5A9&1I<B@D9&@I*2!["B`@("`@("`@("`@
M(&EF("@G+B<@/3T@)&9I;&4@?'P@)RXN)R`]/2`D9FEL92D*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH*("`@("`@("`@("`@)&9I;&4@/2`D9&ER("X@
M)&9I;&4["B`@("`@("`@("`@(&EF("AI<U]D:7(H)&9I;&4I*2!["B`@("`@
M("`@("`@("`@("`D9FEL92`N/2`G+R<["B`@("`@("`@("`@("`@("`D;G5M
M(#T@)'1H:7,M/F1E;&5T941I<B@D9FEL92`N("<O)RD["B`@("`@("`@("`@
M("`@("!I9B`H:7-?:6YT*"1N=6TI*0H@("`@("`@("`@("`@("`@("`@("1N
M=6U?<F5M;W9E9"`K/2`D;G5M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@:68@*'5N;&EN:R@D9FEL92DI"B`@("`@("`@("`@("`@
M("`@("`@)&YU;5]R96UO=F5D*RL["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@+R\@86-C;W)D:6YG('1O('!H<"UM86YU86P@=&AE(&9O;&QO
M=VEN9R!I<R!N965D960@9F]R('=I;F1O=W,@:6YS=&%L;&%T:6]N<RX*("`@
M("`@("!C;&]S961I<B@D9&@I.PH@("`@("`@('5N<V5T*"`D9&@I.PH@("`@
M("`@(&EF("@D9&ER("$]("1T:&ES+3YC86-H95]D:7(I('L@("\O9&5L971E
M('1H92!S=6(M9&ER(&5N=')I97,@(&ET<V5L9B!A;'-O+"!B=70@;F]T('1H
M92!C86-H92UD:7(N"B`@("`@("`@("`@(')M1&ER*"1D:7(I.PH@("`@("`@
M("`@("`D;G5M7W)E;6]V960K*SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D;G5M7W)E;6]V960["B`@("!]("\O(&5N9"!F=6YC(&1E;&5T941I<@H@
M("`@"GT@+R\@96YD(&-L87-S(&9I;&4*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+T-A8VAE+T-O;G1A:6YE<B]D8BYP:'``````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(R,S,P`#$P-#$W,S8S,#`U`#`R,3,V,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@4V5B87-T
M:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@
M("`@("`@("`@?`HO+R!\("`@("`@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@9&(N<&AP
M+'8@,2XU(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0*"G)E<75I<F5?
M;VYC92`G1$(N<&AP)SL*<F5Q=6ER95]O;F-E("=#86-H92]#;VYT86EN97(N
M<&AP)SL*"B\J*@HJ(%!%05(O1$(@0V%C:&4@0V]N=&%I;F5R+@HJ"BH@5T%2
M3DE.1SH@3W1H97(@<WES=&5M<R!M:6=H="!O<B!M:6=H="!N;W0@<W5P<&]R
M="!C97)T86EN(&1A=&%T>7!E<R!O9@HJ('1H92!T86)L97,@<VAO=VXN($%S
M(&9A<B!A<R!)(&MN;W<@=&AE<F4G<R!N;R!L87)G92!B:6YA<GD**B!T>7!E
M(&EN(%-13"TY,B!O<B!344PM.3DN(%!O<W1G<F5S('-E96US('1O(&QA8VL@
M86YY"BH@0DQ/0B!O<B!415A4('1Y<&4L(&9O<B!-4RU344P@>6]U(&-O=6QD
M('5S92!)34%'12P@9&]N)W0@:VYO=PHJ(&%B;W5T(&]T:&5R(&1A=&%B87-E
M<RX@4&QE87-E(&%D9"!S=6=E<W1I;VYS(&9O<B!O=&AE<B!D871A8F%S97,@
M=&\**B!T:&4@:6YL:6YE(&1O8W,N"BH**B!4:&4@9FEE;&0@)V-H86YG960G
M(&AA<R!N;R!M96%N:6YG(&9O<B!T:&4@0V%C:&4@:71S96QF+B!)="=S(&IU
M<W0@=&AE<F4**B!B96-A=7-E(&ET)W,@82!G;V]D(&ED96$@=&\@:&%V92!A
M;B!A=71O;6%T:6-A;&QY('5P9&%T960@=&EM97-T86UP"BH@9FEE;&0@9F]R
M(&1E8G5G9VEN9R!I;B!A;&P@;V8@>6]U<B!T86)L97,N"BH**B!&;W(@7TUY
M4U%,7R!Y;W4@;F5E9"!T:&ES($1"('1A8FQE.@HJ"BH@0U)%051%(%1!0DQ%
M(&-A8VAE("@**B`@(&ED("`@("`@("`@($-(05(H,S(I($Y/5"!.54Q,($1%
M1D%53%0@)R<L"BH@("!C86-H96=R;W5P("!605)#2$%2*#$R-RD@3D]4($Y5
M3$P@1$5&055,5"`G)RP**B`@(&-A8VAE9&%T82`@($),3T(@3D]4($Y53$P@
M1$5&055,5"`G)RP**B`@('5S97)D871A("`@(%9!4D-(05(H,C4U*2!.3U0@
M3E5,3"!$149!54P@)R<L"BH@("!E>'!I<F5S("`@("!)3E0H.2D@3D]4($Y5
M3$P@1$5&055,5"`P+`HJ"BH@("!C:&%N9V5D("`@("!424U%4U1!35`H,30I
M($Y/5"!.54Q,+`HJ"BH@("!)3D1%6"`H97AP:7)E<RDL"BH@("!04DE-05)9
M($M%62`H:60L(&-A8VAE9W)O=7`I"BH@*0HJ"BH@0&%U=&AO<B`@(%-E8F%S
M=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@HJ($!V
M97)S:6]N("`D260Z(&1B+G!H<"QV(#$N-2`R,#`S+S`Q+S`T(#$Q.C4T.C0V
M(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BHO"F-L87-S($-A8VAE7T-O
M;G1A:6YE<E]D8B!E>'1E;F1S($-A8VAE7T-O;G1A:6YE<B!["@H@("`@+RHJ
M"B`@("`J($YA;64@;V8@=&AE($1"('1A8FQE('1O('-T;W)E(&-A8VAI;F<@
M9&%T80H@("`@*@H@("`@*B!`<V5E("!#86-H95]#;VYT86EN97)?9FEL93HZ
M)&9I;&5N86UE7W!R969I>`H@("`@*B\*("`@('9A<B`D8V%C:&5?=&%B;&4@
M/2`G)SL*"B`@("`O*BH*("`@("H@4$5!4B!$0B!D<VX@=&\@=7-E+@H@("`@
M*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)&1S;B`]("<G
M.PH*("`@("\J*@H@("`@*B!014%2($1"(&]B:F5C=`H@("`@*@H@("`@*B!`
M=F%R("!O8FIE8W0@4$5!4E]$0@H@("`@*B\*("`@('9A<B`D9&(["@H@("`@
M9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R7V1B*"1O<'1I;VYS*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?87)R87DH)&]P=&EO;G,I('Q\("%I<W-E="@D;W!T
M:6]N<ULG9'-N)UTI*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?
M17)R;W(H)TYO(&1S;B!S<&5C:69I960A)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YS971/<'1I;VYS*"1O<'1I
M;VYS+"`@87)R87E?;65R9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@87)R
M87DH)V1S;B<L("=C86-H95]T86)L92<I*2D["@H@("`@("`@(&EF("@A)'1H
M:7,M/F1S;BD*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G
M3F\@9'-N('-P96-I9FEE9"$G+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@
M("`@("`D=&AI<RT^9&(@/2!$0CHZ8V]N;F5C="@D=&AI<RT^9'-N+"!T<G5E
M*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'1H:7,M/F1B*2D@>PH@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0CHZ8V]N;F5C="!F
M86EL960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1T:&ES+3YD8BDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/F1B+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T%34T]#*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O
M=7`I"B`@("!["B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B4T5,14-4(&-A
M8VAE9&%T82P@=7-E<F1A=&$L(&5X<&ER97,@1E)/32`E<R!72$5212!I9"`]
M("<E<R<@04Y$(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@
M("`@("`@("`@(&%D9'-L87-H97,H)&ED*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@(&%D9'-L87-H97,H)&=R;W5P*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@*3L*"B`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U
M97)Y*3L*"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*0H@("`@("`@
M("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I;&5D
M.B`G("X@1$(Z.F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*"B`@("`@("`@)')O=R`]("1R97,M/F9E=&-H4F]W*"D["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1R;W<I*0H@("`@("`@("`@("`D9&%T82`](&%R
M<F%Y*"1R;W=;)V5X<&ER97,G72P@)'1H:7,M/F1E8V]D92@D<F]W6R=C86-H
M961A=&$G72DL("1R;W=;)W5S97)D871A)UTI.PH@("`@("`@(&5L<V4*("`@
M("`@("`@("`@)&1A=&$@/2!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*"B`@
M("`@("`@+R\@;&%S="!U<V5D(')E<75I<F5D(&)Y('1H92!G87)B86=E(&-O
M;&QE8W1I;VX*("`@("`@("`O+R!705).24Y'.B!M:6=H="!B92!->5-13"!S
M<&5C:69I8PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(E501$%412`E<R!3
M150@8VAA;F=E9"`]("A.3U<H*2`K(#`I(%=(15)%(&ED(#T@)R5S)R!!3D0@
M8V%C:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@861D<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@861D<VQA<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@*3L*"B`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U
M97)Y*3L*"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*0H@("`@("`@
M("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I;&5D
M.B`G("X@1$(Z.F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@
M("`@*B!3=&]R97,@82!D871A<V5T+@H@("`@*@H@("`@*B!705).24Y'.B!W
M92!U<V4@=&AE(%-13"!C;VUM86YD(%)%4$Q!0T4@24Y43R!T:&ES(&UI9VAT
M(&)E"B`@("`J($UY4U%,('-P96-I9FEC+B!!<R!->5-13"!I<R!V97)Y('!O
M<'5L87(@=&AE(&UE=&AO9"!S:&]U;&0*("`@("H@=V]R:R!F:6YE(&9O<B`Y
M-24@;V8@>6]U+@H@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D9&%T
M82P@)&5X<&ER97,L("1G<F]U<"P@)'5S97)D871A*0H@("`@>PH@("`@("`@
M("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*")215!,04-%($E.5$\@)7,@*'5S97)D871A+"!C
M86-H961A=&$L(&5X<&ER97,L(&ED+"!C86-H96=R;W5P*2!604Q515,@*"<E
M<R<L("<E<R<L("5D+"`G)7,G+"`G)7,G*2(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("!A9&1S;&%S:&5S*"1U<V5R9&%T82DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("!A9&1S;&%S:&5S*"1T:&ES+3YE;F-O9&4H)&1A=&$I*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T17AP:7)E<T%B
M<V]L=71E*"1E>'!I<F5S*2`L"B`@("`@("`@("`@("`@("`@("`@("`@("!A
M9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S
M;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@
M("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R
M;B!N97<@0V%C:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ
M97)R;W)-97-S86=E*"1R97,I("P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<F5M;W9E*"1I9"P@)&=R;W5P
M*0H@("`@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O
M=7`I.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*")$14Q%5$4@1E)/32`E
M<R!72$5212!I9"`]("<E<R<@86YD(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@
M("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&ED*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&=R;W5P*0H@("`@("`@
M("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B
M+3YQ=65R>2@D<75E<GDI.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<RDI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1".CIQ
M=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1R97,I+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@?0H*("`@(&9U;F-T:6]N(&9L=7-H*"1G
M<F]U<"`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H
M*3L*"B`@("`@("`@(&EF("@D9W)O=7`I('L*("`@("`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@B1$5,151%($923TT@)7,@5TA%4D4@8V%C:&5G<F]U<"`]
M("<E<R<B+"`D=&AI<RT^8V%C:&5?=&%B;&4L(&%D9'-L87-H97,H)&=R;W5P
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@B1$5,151%($923TT@)7,B+"`D=&AI<RT^8V%C:&5?=&%B;&4I.PH@
M("`@("`@('T*"B`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U
M97)Y*3L*"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*0H@("`@("`@
M("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I;&5D
M.B`G("X@1$(Z.F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@('T*"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U
M<"D*("`@('L*("`@("`@("`D<75E<GD@/2!S<')I;G1F*")314Q%0U0@:60@
M1E)/32`E<R!72$5212!)1"`]("<E<R<@04Y$(&-A8VAE9W)O=7`@/2`G)7,G
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L
M92P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&ED*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&=R;W5P*0H@
M("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@)'1H
M:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E<RDI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H
M)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1R97,I
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D<F]W(#T@)')E<RT^
M9F5T8VA2;W<H*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R;W<I*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@9V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T:6UE*0H@("`@>PH@
M("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*"B`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@*&5X<&ER97,@/#T@
M)60@04Y$(&5X<&ER97,@/B`P*2!/4B!C:&%N9V5D(#P]("5D)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@
M("`@("`@("`@("`@("`@("`@('1I;64H*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@('1I;64H*2`M("1M87AL:69E=&EM90H@("`@("`@("`@("`@("`@
M("`@("`@("D["@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q
M=65R>2D["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)W-E;&5C="!S=6TH
M;&5N9W1H*&-A8VAE9&%T82DI(&%S($-A8VAE4VEZ92!F<F]M("5S)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L90H@("`@
M("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@)&-A8VAE<VEZ92`]("1T
M:&ES+3YD8BT^1V5T3VYE*"1Q=65R>2D["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1C86-H97-I>F4I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C
M:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S
M86=E*"1C86-H97-I>F4I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@+R]I9B!C86-H92!I<R!T;R!B:6<N"B`@("`@("`@:68@
M*"1C86-H97-I>F4@/B`D=&AI<RT^:&EG:'=A=&5R*0H@("`@("`@('L*("`@
M("`@("`@("`@+R]F:6YD('1H92!L;W=W871E<B!M87)K+@H@("`@("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=S96QE8W0@;&5N9W1H*&-A8VAE9&%T82D@
M87,@<VEZ92P@8VAA;F=E9"!F<F]M("5S(&]R9&5R(&)Y(&-H86YG960@1$53
M0R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@
M("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z
M("<@+B!$0CHZ97)R;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;G5M<F]W<R`]("1T
M:&ES+3YD8BT^;G5M4F]W<R@D<F5S*3L*("`@("`@("`@("`@)&ME97!?<VEZ
M92`](#`["B`@("`@("`@("`@('=H:6QE("@D:V5E<%]S:7IE(#P@)'1H:7,M
M/FQO=W=A=&5R("8F("1N=6UR;W=S+2TI('L*("`@("`@("`@("`@("`@("1E
M;G1R>2`]("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RD["B`@
M("`@("`@("`@("`@("`D:V5E<%]S:7IE("L]("1E;G1R>5LG<VEZ92==.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+V1E;&5T92!A;&P@96YT<FEE
M<RP@=VAI8V@@=V5R92!C:&%N9V5D(&)E9F]R92!T:&4@(FQO=W=W871E<B!M
M87)K(@H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=D96QE=&4@9G)O
M;2`E<R!W:&5R92!C:&%N9V5D(#P]("<N*"1E;G1R>5LG8VAA;F=E9"==(#\@
M)&5N=')Y6R=C:&%N9V5D)UT@.B`P*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("1R97,@
M/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&YE=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1".CIE
M<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H@("`@?0H*?0H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O
M;7-E<W-I;VXN<&AP````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C8S,0`Q
M,#0Q-S,V,S`P-0`P,C(V-#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y
M.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L
M960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD
M(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@
M?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@56QF(%=E;F1E;"`\
M=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED
M.B!M<V5S<VEO;BYP:'`L=B`Q+C0@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%
M>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H92]#;VYT86EN97(N<&AP)SL*"B\J
M*@HJ(%-T;W)E<R!C86-H92!C;VYT96YT<R!I;B!M<V5S<VEO;G,N"BH**B!7
M05).24Y'.B!E>'!E<FEM96YT86PL('5N=&5S=&5D"BH**B!`875T:&]R("`@
M56QF(%=E;F1E;"`@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V97)S:6]N
M("`D260Z(&US97-S:6]N+G!H<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q.C4T.C0V
M(&UJ($5X<"`D"BHO"F-L87-S($-A8VAE7T-O;G1A:6YE<E]M<V5S<VEO;B!E
M>'1E;F1S($-A8VAE7T-O;G1A:6YE<B!["@H*("`@("\J*@H@("`@*B!,96YG
M=&@@;V8@=&AE($-A8VAE+4ED96YT:69I97(*("`@("H*("`@("H@3F]T92!T
M:&%T('1H92!014%2+4-A8VAE('!R969I>&5S('1H92!)1"!W:71H(&%N(&UD
M-2@I('9A;'5E"B`@("`J(&]F('1H92!C86-H92UG<F]U<"X@02!G;V]D('9A
M;'5E(&9O<B!T:&4@:61?;&5N9W1H"B`@("`J(&1E<&5N9',@;VX@=&AE(&UA
M>&EM=6T@;G5M8F5R(&]F(&5N=')I97,@<&5R(&-A8VAE(&=R;W5P+@H@("`@
M*@H@("`@*B!`=F%R("!I;G0*("`@("HO"B`@("!V87(@)&ED7VQE;F=T:"`]
M(#,R.PH@("`@"B`@("`*("`@("\J*@H@("`@*B!5<V4@;7-E<W-I;VY?=6YI
M<2!T;R!C<F5A=&4@82!U;FEQ=64@4TE$+@H@("`@*B`*("`@("H@0'9A<B`@
M8F]O;&5A;@H@("`@*B\*("`@('9A<B`D=6YI<2`]('1R=64["B`@("`*("`@
M(`H@("`@+RHJ"B`@("`J($5S=&%B;&ES:"!A(&-O;FYE8W1I;VX@=&\@82!M
M<V5S<VEO;B!S97)V97(_"B`@("`J"B`@("`J($!V87(@(&)O;VQE86X*("`@
M("HO"B`@("!V87(@)&-O;FYE8W0@/2!T<G5E.PH@("`*("`@"B`@("`O*BH*
M("`@("H@;7-E<W-I;VX@:&]S=`H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*
M("`@("HO("`*("`@('9A<B`D:&]S="`]($Y53$P["B`@("`*("`@"B`@("`O
M*BH*("`@("H@;7-E<W-I;VX@<&]R=`H@("`@*@H@("`@*B!`=F%R("!S=')I
M;F<*("`@("HO"B`@("!V87(@)'!O<G0@/2!.54Q,.PH@("`@"B`@("`*("`@
M("\J*@H@("`@*B!M97-E<W-I;VX@<V5R=F5R(&-O;FYE8W1I;VX*("`@("H*
M("`@("H@0'9A<B`@<F5S;W5R8V4@;7-E<W-I;VX*("`@("HO"B`@("!V87(@
M)&US(#T@3E5,3#L*"B`@("`*("`@(&9U;F-T:6]N($-A8VAE7T-O;G1A:6YE
M<E]M<V5S<VEO;B@D;W!T:6]N<R`]("<G*2!["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1O<'1I;VYS*2D*("`@("`@("`@("`@)'1H:7,M/G-E=$]P=&EO;G,H
M)&]P=&EO;G,L(&%R<F%Y7VUE<F=E*"1T:&ES+3YA;&QO=V5D7V]P=&EO;G,L
M(&%R<F%Y*"=I9%]L96YG:'0G+"`G=6YI<2<L("=H;W-T)RP@)W!O<G0G+"`G
M8V]N;F5C="<I*2D["@H@("`@("`@(&EF("@D8V]N;F5C="D@>R`@("`@("`@
M("`@(`H@("`@("`@("`@("!I9B`H3E5,3"`]/2`D=&AI<RT^:&]S="D*("`@
M("`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@G3F\@:&]S="!S<&5C:69I
M960N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@:68@*$Y5
M3$P@/3T@)'1H:7,M/G!O<G0I"B`@("`@("`@("`@("`@("!N97<@0V%C:&5?
M17)R;W(H)TYO('!O<G0@<W!E8VEF:65D+B<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@"B`@("`@("`@("`@(&EF("@A*"1T:&ES+3YM<R`](&US
M97-S:6]N7V-O;FYE8W0H)'1H:7,M/FAO<W0L("1T:&ES+3YP;W)T*2DI"B`@
M("`@("`@("`@("`@("!N97<@0V%C:&5?17)R;W(H)T-A;B!N;W0@8V]N;F5C
M="!T;R!T:&4@<V5V97(@=7-I;F<@:&]S="`B)R`N("1T:&ES+3YH;W-T("X@
M)R(@;VX@<&]R="`B)R`N("1T:&ES+3YP;W)T("X@)R(G+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("`*("`@('T@+R\@96YD(&9U
M;F,@8V]N=')U8W1O<@H*("`@(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P
M*2!["B`@("`*("`@("`@("`D:60@/2!S=')T;W5P<&5R*&UD-2@D9W)O=7`I
M*2`N("1I9#L*("`@("`@("`D9W)O=7`@/2!M<V5S<VEO;E]G970H)&ED+"`G
M7W!E87)?8V%C:&5?9&%T82<L($Y53$PI.PH@("`@("`@(`H@("`@("`@(&EF
M("A.54Q,(#T]("1D871A*0H@("`@("`@("`@("!R971U<FX@87)R87DH3E5,
M3"P@3E5,3"P@3E5,3"D["B`@("`@("`@"B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"1D871A6R=E>'!I<F5S)UTL("1D871A6R=C86-H961A=&$G72P@)&1A=&%;
M)W5S97)D871A)UTI.PH@("`@?2`O+R!E;F0@9G5N8R!F971C:`H*("`@("\J
M*@H@("`@*B!3=&]R97,@82!D871A<V5T+@H@("`@*@H@("`@*B!705).24Y'
M.B!)9B!Y;W4@<W5P<&QY('5S97)D871A(&ET(&UU<W0@;F]T(&-O;G1A:6X@
M86YY(&QI;F5B<F5A:W,L"B`@("`J(&]T:&5R=VES92!I="!W:6QL(&)R96%K
M('1H92!F:6QE<W1R=6-T=7)E+@H@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H
M)&ED+"`D8V%C:&5D871A+"`D97AP:7)E<RP@)&=R;W5P+"`D=7-E<F1A=&$I
M('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*
M("`@("`@("`*("`@("`@("`D8V%C:&5D871A("`@("`@/2`D=&AI<RT^96YC
M;V1E*"1C86-H961A=&$I.PH@("`@("`@("1E>'!I<F5S7V%B<R`@("`]("1T
M:&ES+3YG971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I.PH*("`@("`@("`D
M<VEZ92`](#$@*R!S=')L96XH)&-A8VAE9&%T82D@*R!S=')L96XH)&5X<&ER
M97-?86)S*2`K('-T<FQE;B@D=7-E<F1A=&$I("L@<W1R;&5N*"1G<F]U<"D[
M"B`@("`@("`@)'-I>F4@*ST@<W1R;&5N*"1S:7IE*3L*("`@("`@("`*("`@
M("`@("`D9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=C86-H
M961A=&$G(#T^("1C86-H961A=&$L(`H@("`@("`@("`@("`@("`@("`@("=E
M>'!I<F5S)R`@(#T^("1E>'!I<F5S7V%B<RP*("`@("`@("`@("`@("`@("`@
M("`G=7-E<F1A=&$G("`]/B`D=7-E<F1A=&$*("`@("`@("`@("`@("`@("`@
M*3L*("`@("`@("`D:60@/2!S=')T;W5P<&5R*&UD-2@D9W)O=7`I*2`N("1I
M9#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@("`@(&US97-S
M:6]N7VQO8VLH)&ED*3L*("`@("`@("`*("`@("`@("!I9B`H(6US97-S:6]N
M7W-E="@D:60L("=?<&5A<E]C86-H92<L('1R=64I*2!["B`@("`@("`@("`@
M(&US97-S:6]N7W5N;&]C:R@D:60I.PH@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*")#86XG="!W<FET92!C86-H92!D871A+B(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF
M("@A;7-E<W-I;VY?<V5T*"1I9"P@)U]P96%R7V-A8VAE7V1A=&$G+"`D9&%T
M82DI('L*("`@("`@("`@("`@;7-E<W-I;VY?=6YL;V-K*"1I9"D["B`@("`@
M("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T('=R:71E(&-A
M8VAE(&1A=&$N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@:68@*"%M<V5S<VEO;E]S970H)&ED+"`G7W!E87)?
M8V%C:&5?9W)O=7`G+"`D9W)O=7`I*2!["B`@("`@("`@("`@(&US97-S:6]N
M7W5N;&]C:R@D:60I.PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R
M<F]R*")#86XG="!W<FET92!C86-H92!D871A+B(L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@A;7-E<W-I
M;VY?<V5T*"1I9"P@)U]P96%R7V-A8VAE7W-I>F4G+"`D<VEZ92DI('L*("`@
M("`@("`@("`@;7-E<W-I;VY?=6YL;V-K*"1I9"D["B`@("`@("`@("`@(')E
M='5R;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T('=R:71E(&-A8VAE(&1A=&$N
M(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@+R\@;&5T(&US97-S:6]N(&1O('-O;64@1T,@87,@=V5L;`H@("`@
M("`@("\O(&YO=&4@=&AA="!M<V5S<VEO;B!W;W)K<R!D:69F97)E;G0@9G)O
M;2!T:&4@4$5!4B!#86-H92X*("`@("`@("`O+R!M<V5S<VEO;B!D96QE=&5S
M(&%N(&5N=')Y(&EF(&ET(&AA<R!N;W0@8F5E;B!U<V5D(&9O<B!N+7-E8V]N
M9',N"B`@("`@("`@+R\@4$5!4B!#86-H92!D96QE=&5S(&%F=&5R(&XM<V5C
M;VYD<RX*("`@("`@("!I9B`H,"`A/2`D97AP:7)E<RD*("`@("`@("`@("`@
M;7-E<W-I;VY?=&EM96]U="@D:60L("1E>'!I<F5S*3L*("`@("`@("`@("`@
M"B`@("`@("`@;7-E<W-I;VY?=6YL;V-K*"1I9"D["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!S879E"@H@("`@9G5N8W1I;VX@
M<F5M;W9E*"1I9"P@)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E
M;&]A9"@D:60L("1G<F]U<"D["B`@("`*("`@("`@("!R971U<FX@;7-E<W-I
M;VY?9&5S=')O>2AS=')T;W5P<&5R*&UD-2@D9W)O=7`I*2`N("1I9"D["B`@
M("!]("\O(&5N9"!F=6YC(')E;6]V90H*("`@(&9U;F-T:6]N(&9L=7-H*"1G
M<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*("`@("`@
M"B`@("`@("`@)'-E<W-I;VYS(#T@;7-E<W-I;VY?9FEN9"@G7W!E87)?8V%C
M:&5?9W)O=7`G+"`D9W)O=7`I.PH@("`@("`@(&EF("AE;7!T>2@D<V5S<VEO
M;G,I*0H@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("`*("`@("`@("!F
M;W)E86-H("@D<V5S<VEO;G,@87,@)&L@/3X@)&ED*0H@("`@("`@("`@("!M
M97-S<VEO;E]D97-T<F]Y*"1I9"D["@H@("`@("`@(')E='5R;B!C;W5N="@D
M<V5S<VEO;G,I.PH@("`@?2`O+R!E;F0@9G5N8R!F;'5S:`H*("`@(&9U;F-T
M:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P*2!["B`@("`@("`@"B`@("`@("`@
M<F5T=7)N("A.54Q,(#T](&US97-S:6]N7V=E="AS=')T;W5P<&5R*&UD-2@D
M9W)O=7`I*2`N("1I9"P@)U]P96%R7V-A8VAE7V=R;W5P)RP@3E5,3"DI(#\@
M9F%L<V4@.B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!I9$5X:7-T<PH*("`@
M("\J*@H@("`@*B!$96QE=&5S(&%L;"!E>'!I<F5D(&9I;&5S+@H@("`@*@H@
M("`@*B!.;W1E.B!G87)B86=E(&-O;&QE8W1I;VX@<VAO=6QD(&-A=7-E(&QO
M="=S(&]F(&YE='=O<FL@=')A9F9I8RX*("`@("H*("`@("H@0'!A<F%M("`@
M(&EN=&5G97(@36%X:6UU;2!L:69E=&EM92!I;B!S96-O;F1S(&]F(&%N(&YO
M(&QO;F=E<B!U<V5D+W1O=6-H960@96YT<GD*("`@("H@0'1H<F]W<R`@($-A
M8VAE7T5R<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@9V%R8F%G94-O;&QE8W1I
M;VXH)&UA>&QI9F5T:6UE*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A
M9"@I.PH@("`@("`@(`H@("`@("`@("1S97-S:6]N<R`](&US97-S:6]N7V9I
M;F0H)U]P96%R7V-A8VAE)RP@=')U92D["B`@("`@("`@:68@*&5M<'1Y*"1S
M97-S:6]N<RDI"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@(`H@
M("`@("`@("1T;W1A;"`](#`["B`@("`@("`@)&5N=')I97,@/2!A<G)A>2@I
M.PH@("`@("`@(`H@("`@("`@(&9O<F5A8V@@*"1S97-S:6]N<R!A<R`D:R`]
M/B`D:60I('L*("`@("`@("`@("`@)&1A=&$@/2!M<V5S<VEO;E]G970H)&ED
M+"`G7W!E87)?8V%C:&5?9&%T82<L($Y53$PI.PH@("`@("`@("`@("!I9B`H
M3E5,3"`]/2`D9&%T82D*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("`@("`@"B`@("`@("`@("`@(&EF("@D9&%T85LG97AP:7)E<R==
M(#P]('1I;64H*2D@>PH@("`@("`@("`@("`@("`@;7-E<W-I;VY?9&5S=')O
M>2@D:60I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@"B`@("`@("`@("`@("1S:7IE(#T@;7-E<W-I;VY?
M9V5T*"1I9"P@)U]P96%R7V-A8VAE7W-I>F4G+"!.54Q,*3L*("`@("`@("`@
M("`@)'1O=&%L("L]("1S:7IE.PH@("`@("`@("`@("`D96YT<FEE<ULD9&%T
M85LG97AP:7)E<R==72`](&%R<F%Y*"1I9"P@)'-I>F4I.PH@("`@("`@('T*
M("`@("`@("`*("`@("`@("!I9B`H)'1O=&%L(#X@)'1H:7,M/FAI9VAW871E
M<BD@>PH@("`@("`@("`@("`*("`@("`@("`@("`@:W)S;W)T*"1E;G1R:65S
M*3L*("`@("`@("`@("`@<F5S970H)&5N=')I97,I.PH@("`@("`@("`@("`*
M("`@("`@("`@("`@=VAI;&4@*"1T;W1A;"`^("1T:&ES+3YL;W=W871E<B`F
M)B!L:7-T*"1E>'!I<F5S+"`D96YT<GDI(#T@96%C:"@D96YT<FEE<RDI('L*
M("`@("`@("`@("`@("`@(&US97-S:6]N7V1E<W1R;WDH)&5N=')Y6S!=*3L*
M("`@("`@("`@("`@("`@("1T;W1A;"`M/2`D96YT<GE;,5T["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!G87)B86=E0V]L;&5C
M=&EO;@H@("`@"GT@+R\@96YD(&-L87-S(&9I;&4*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE
M<B]P:'!L:6(N<&AP````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R-#8R
M`#$P-#$W,S8S,#`U`#`R,C(V,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L
M(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S
M96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!P:'!L:6(N<&AP
M+'8@,2XS(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0*"G)E<75I<F5?
M;VYC92`G0V%C:&4O0V]N=&%I;F5R+G!H<"<["@HO*BH**B!3=&]R97,@8V%C
M:&4@9&%T82!I;G1O(&$@9&%T86)A<V4@=&%B;&4@=7-I;F<@4$A03&EB<R!$
M0B!A8G-T<F%C=&EO;BX**@HJ(%=!4DY)3D<Z($]T:&5R('-Y<W1E;7,@;6EG
M:'0@;W(@;6EG:'0@;F]T('-U<'!O<G0@8V5R=&%I;B!D871A='EP97,@;V8@
M"BH@=&AE('1A8FQE<R!S:&]W;BX@07,@9F%R(&%S($D@:VYO=R!T:&5R92=S
M(&YO(&QA<F=E(&)I;F%R>2`**B!T>7!E(&EN(%-13"TY,B!O<B!344PM.3DN
M(%!O<W1G<F5S('-E96US('1O(&QA8VL@86YY(`HJ($),3T(@;W(@5$585"!T
M>7!E+"!F;W(@35,M4U%,('EO=2!C;W5L9"!U<V4@24U!1T4L(&1O;B=T(&MN
M;W<@"BH@86)O=70@;W1H97(@9&%T86)A<V5S+B!0;&5A<V4@861D('-U9V5S
M=&EO;G,@9F]R(&]T:&5R(&1A=&%B87-E<R!T;R`**B!T:&4@:6YL:6YE(&1O
M8W,N"BH**B!4:&4@9FEE;&0@)V-H86YG960G(&ES('5S960@8GD@=&AE(&=A
M<F)A9V4@8V]L;&5C=&EO;BX@1&5P96YD:6YG(&]N(`HJ('EO=7(@9&%T86)A
M<V5S>7-T96T@>6]U(&UI9VAT(&AA=F4@=&\@<W5B8VQA<W,@9F5T8V@H*2!A
M;F0@9V%R8F%G94-O;&QE8W1I;VXH*2X**@HJ($9O<B!?37E344Q?('EO=2!N
M965D('1H:7,@1$(@=&%B;&4Z"BH**B!#4D5!5$4@5$%"3$4@8V%C:&4@*`HJ
M("`@:60@("`@("`@("`@0TA!4B@S,BD@3D]4($Y53$P@1$5&055,5"`G)RP*
M*B`@(&-A8VAE9W)O=7`@(%9!4D-(05(H,3(W*2!.3U0@3E5,3"!$149!54Q4
M("<G+`HJ("`@8V%C:&5D871A("`@0DQ/0B!.3U0@3E5,3"!$149!54Q4("<G
M+`HJ("`@=7-E<F1A=&$@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%5
M3"`G)RP**B`@(&5X<&ER97,@("`@($E.5"@Y*2!.3U0@3E5,3"!$149!54Q4
M(#`L"BH@(`HJ("`@8VAA;F=E9"`@("`@5$E-15-404U0*#$T*2!.3U0@3E5,
M3"P**B`@"BH@("!)3D1%6"`H97AP:7)E<RDL"BH@("!04DE-05)9($M%62`H
M:60L(&-A8VAE9W)O=7`I"BH@*0HJ"BH@"BH@0&%U=&AO<B`@(%5L9B!796YD
M96P@(#QU;&8N=V5N9&5L0'!H<&1O8RYD93XL(%-E8F%S=&EA;B!"97)G;6%N
M;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@HJ($!V97)S:6]N("`D260Z
M('!H<&QI8BYP:'`L=B`Q+C,@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@
M)`HJ($!P86-K86=E("!#86-H90HJ($!S964@("`@("!S879E*"D**B\*8VQA
M<W,@0V%C:&5?0V]N=&%I;F5R7W!H<&QI8B!E>'1E;F1S($-A8VAE7T-O;G1A
M:6YE<B!["B`@"B`@("`O*BH*("`@("H@3F%M92!O9B!T:&4@1$(@=&%B;&4@
M=&\@<W1O<F4@8V%C:&EN9R!D871A"B`@("`J(`H@("`@*B!`<V5E("!#86-H
M95]#;VYT86EN97)?9FEL93HZ)&9I;&5N86UE7W!R969I>`H@("`@*B\@(`H@
M("`@=F%R("1C86-H95]T86)L92`]("=C86-H92<["@H@("`@+RHJ"B`@("`J
M(%!(4$QI8B!O8FIE8W0*("`@("H@"B`@("`J($!V87(@(&]B:F5C="!014%2
M7T1""B`@("`J+PH@("`@=F%R("1D8CL*"B`@("`O*BH*("`@("H@3F%M92!O
M9B!T:&4@4$A03&EB($1"(&-L87-S('1O('5S90H@("`@*B`*("`@("H@0'9A
M<B`@<W1R:6YG("`*("`@("H@0'-E92`@)&1B7W!A=&@L("1L;V-A;%]P871H
M"B`@("`J+PH@("`@=F%R("1D8E]C;&%S<R`]("<G.PH*("`@("\J*@H@("`@
M*B!&:6QE;F%M92!O9B!Y;W5R(&QO8V%L+FEN8PH@("`@*B`*("`@("H@268@
M96UP='DL("=L;V-A;"YI;F,G(&ES(&%S<W5M960N"B`@("`J"B`@("`J($!V
M87(@("`@("`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1L;V-A;%]F:6QE(#T@
M)R<["@H@("`@+RHJ"B`@("`J($EN8VQU9&4@<&%T:"!F;W(@>6]U(&QO8V%L
M+FEN8PH@("`@*@H@("`@*B!(24Y4.B!)9B!Y;W5R)W)E(&YO="!U<VEN9R!0
M2%!,:6(G<R!P<F5P96YD+G!H<"!Y;W4@;75S="`*("`@("H@=&%K92!C87)E
M('1H870@86QL(&-L87-S97,@*&9I;&5S*2!R969E<F5N8V5S(&)Y('EO=2`*
M("`@("H@;&]C86PN:6YC(&%R92!I;F-L=61E9"!A=71O;6%T:6-A;&QY+B!3
M;R!Y;W4@;6EG:'0@"B`@("`J('=A;G0@=&\@=W)I=&4@82!N97<@;&]C86PR
M+FEN8R!T:&%T(&]N;'D@<F5F97)R<R!T;R`*("`@("H@=&AE(&1A=&%B87-E
M(&-L87-S("AF:6QE*2!Y;W4G<F4@=7-I;F<@86YD(&EN8VQU9&5S(&%L;"!R
M97%U:7)E9"!F:6QE<RX*("`@("H*("`@("H@0'9A<B`@<W1R:6YG("!P871H
M('1O('EO=7(@;&]C86PN:6YC("T@;6%K92!S=7)E('1O(&%D9"!A('1R86EL
M:6YG('-L87-H"B`@("`J($!S964@("1L;V-A;%]F:6QE"B`@("`J+PH@("`@
M=F%R("1L;V-A;%]P871H(#T@)R<["@H@("`@+RHJ"B`@("`J($-R96%T97,@
M86X@:6YS=&%N8V4@;V8@82!P:'!L:6(@9&(@8VQA<W,@=&\@=7-E(&ET(&9O
M<B!S=&]R86=E+@H@("`@*@H@("`@*B!`<&%R86T@("`@;6EX960@("!)9B!E
M;7!T>2!T:&4@;V)J96-T('1R:65S('1O('5S960@=&AE(`H@("`@*B`@("`@
M("`@("`@("`@("`@("!P<F5C;VYF:6=U<F5D(&-L87-S('9A<FEA8FQE<RX@
M268@9VEV96X@:70@"B`@("`J("`@("`@("`@("`@("`@("`@(&UU<W0@8F4@
M86X@87)R87D@=VET:#H*("`@("H@("`@("`@("`@("`@("`@("`@("!D8E]C
M;&%S<R`]/B!N86UE(&]F('1H92!$0B!C;&%S<R!T;R!U<V4*("`@("H@("`@
M("`@("`@("`@("`@("`@;W!T:6]N86PZ"B`@("`J("`@("`@("`@("`@("`@
M("`@("`@9&)?9FEL92`]/B!F:6QE;F%M92!O9B!T:&4@1$(@8VQA<W,*("`@
M("H@("`@("`@("`@("`@("`@("`@("!D8E]P871H(#T^('!A=&@@=&\@=&AE
M($1"(&-L87-S"B`@("`J("`@("`@("`@("`@("`@("`@("`@;&]C86Q?9FEL
M92`]/B!K:6YD(&]F(&QO8V%L+FEN8PH@("`@*B`@("`@("`@("`@("`@("`@
M("`@(&QO8V%L7W!A=&L@/3X@<&%T:"!T;R!T:&4@;&]C86PN:6YC"B`@("`J
M("`@("`@("`@("`@("`@("`@('-E92`D;&]C86Q?<&%T:"!F;W(@<V]M92!H
M:6YT<RYS"B`@("`J($!S964@("1L;V-A;%]P871H"B`@("`J+PH@("`@9G5N
M8W1I;VX@0V%C:&5?0V]N=&%I;F5R7W!H<&QI8B@D;W!T:6]N<R`]("<G*2![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS*2D*("`@("`@("`@("`@
M)'1H:7,M/G-E=$]P=&EO;G,H)&]P=&EO;G,L("!A<G)A>5]M97)G92@D=&AI
M<RT^86QL;W=E9%]O<'1I;VYS+"!A<G)A>2@G9&)?8VQA<W,G+"`G9&)?9FEL
M92<L("=D8E]P871H)RP@)VQO8V%L7V9I;&4G+"`G;&]C86Q?<&%T:"<I*2D[
M"@H@("`@("`@(&EF("@A)'1H:7,M/F1B7V-L87-S*0H@("`@("`@("`@("!R
M971U<FX@;F5W($-A8VAE7T5R<F]R*"=.;R!D871A8F%S92!C;&%S<R!S<&5C
M:69I960N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@+R\@:6YC
M;'5D92!T:&4@<F5Q=6ER960@9FEL97,*("`@("`@("!I9B`H)'1H:7,M/F1B
M7V9I;&4I"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92@D=&AI<RT^9&)?<&%T
M:"`N("1T:&ES+3YD8E]F:6QE*3L*"B`@("`@("`@:68@*"1T:&ES+3YL;V-A
M;%]F:6QE*0H@("`@("`@("`@("!I;F-L=61E7V]N8V4H)'1H:7,M/FQO8V%L
M7W!A=&@@+B`D=&AI<RT^;&]C86Q?9FEL92D["@H@("`@("`@("\O(&-R96%T
M92!A(&1B(&]B:F5C="`*("`@("`@("`D=&AI<RT^9&(@/2!N97<@)'1H:7,M
M/F1B7V-L87-S.PH@("`@?2`O+R!E;F0@8V]N<W1R=6-T;W(*"B`@("!F=6YC
M=&EO;B!F971C:"@D:60L("1G<F]U<"D@>PH@("`@("`@("1Q=65R>2`]('-P
M<FEN=&8H(E-%3$5#5"!E>'!I<F5S+"!C86-H961A=&$L('5S97)D871A($92
M3TT@)7,@5TA%4D4@:60@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B
M;&4L(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ED+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&=R;W5P"B`@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH@("`@("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*
M("`@("`@("!I9B`H(21T:&ES+3YD8BT^3F5X=%]296-O<F0H*2D*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH*("`@("`@
M("`O+R!L87-T('5S960@<F5Q=6ER960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C
M=&EO;B`@(`H@("`@("`@("\O(%=!4DY)3D<Z(&UI9VAT(&)E($UY4U%,('-P
M96-I9FEC("`@("`@("`@"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B55!$
M051%("5S(%-%5"!C:&%N9V5D(#T@*$Y/5R@I("L@,"D@5TA%4D4@:60@/2`G
M)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9W)O=7`*("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@
M("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!R971U<FX@87)R
M87DH)'1H:7,M/F1B+3YF*"=E>'!I<F5S)RDL("1T:&ES+3YD96-O9&4H)'1H
M:7,M/F1B+3YF*"=C86-H961A=&$G*2DL("1T:&ES+3YD8BT^9B@G=7-E<F1A
M=&$G*2D["B`@("!]("\O(&5N9"!F=6YC(&9E=&-H"@H@("`@+RHJ"B`@("`J
M(%-T;W)E<R!A(&1A=&%S970N"B`@("`J(`H@("`@*B!705).24Y'.B!W92!U
M<V4@=&AE(%-13"!C;VUM86YD(%)%4$Q!0T4@24Y43R!T:&ES(&UI9VAT(&)E
M(`H@("`@*B!->5-13"!S<&5C:69I8RX@07,@37E344P@:7,@=F5R>2!P;W!U
M;&%R('1H92!M971H;V0@<VAO=6QD"B`@("`J('=O<FL@9FEN92!F;W(@.34E
M(&]F('EO=2X*("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L
M("1E>'!I<F5S+"`D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L
M;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B
M4D503$%#12!)3E1/("5S("AC86-H961A=&$L(&5X<&ER97,L(&ED+"!C86-H
M96=R;W5P*2!604Q515,@*"<E<R<L("5D+"`G)7,G+"`G)7,G*2(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1T:&ES+3YE
M;F-O9&4H)&1A=&$I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YG971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I("P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I9"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1G<F]U<`H@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@
M("`@("`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@("`@("`@(')E='5R
M;B`H8F]O;&5A;BDD=&AI<RT^9&(M/F%F9F5C=&5D7W)O=W,H*3L@"B`@("!]
M("\O(&5N9"!F=6YC('-A=F4*"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D
M9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R
M;W5P*3L*("`@("`@("`D=&AI<RT^9&(M/G%U97)Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("!S<')I;G1F*")$14Q%5$4@1E)/32`E<R!72$5212!I9"`]
M("<E<R<@04Y$(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1I9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1G<F]U<`H@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@
M("`@("`@("`@("`@("`I.PH*("`@("`@("!R971U<FX@*&)O;VQE86XI)'1H
M:7,M/F1B+3YA9F9E8W1E9%]R;W=S*"D["B`@("!]("\O(&5N9"!F=6YC(')E
M;6]V90H*("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"D@>PH@("`@("`@("1T
M:&ES+3YF;'5S:%!R96QO860H*3L*"B`@("`@("`@:68@*"1G<F]U<"D@>PH@
M("`@("`@("`@("`D=&AI<RT^9&(M/G%U97)Y*'-P<FEN=&8H(D1%3$5412!&
M4D]-("5S(%=(15)%(&-A8VAE9W)O=7`@/2`G)7,G(BP@)'1H:7,M/F-A8VAE
M7W1A8FQE+"`D9W)O=7`I*3L@("`@"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/F1B+3YQ=65R>2AS<')I;G1F*")$14Q%5$4@1E)/32`E
M<R(L("1T:&ES+3YC86-H95]T86)L92DI.R`@("`*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^9&(M/F%F9F5C=&5D7W)O=W,H*3L*("`@('T@
M+R\@96YD(&9U;F,@9FQU<V@*"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L
M("1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YD8BT^<75E<GDH"B`@("`@("`@
M("`@("`@("`@("`@("`@('-P<FEN=&8H(E-%3$5#5"!I9"!&4D]-("5S(%=(
M15)%($E$(#T@)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E<R<B+"`*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I9"P@"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9W)O=7`*("`@("`@("`@("`@("`@("`@("`@("`@
M*2`@(`H@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@(')E='5R;B`H
M8F]O;&5A;BDD=&AI<RT^9&(M/FYF*"D[("`@("`@("`@("`@("`@("`@("`@
M("`@(`H@("`@?2`O+R!E;F0@9G5N8R!I<T5X:7-T<PH*("`@(&9U;F-T:6]N
M(&=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92D@>PH@("`@("`@("1T
M:&ES+3YF;'5S:%!R96QO860H*3L*"B`@("`@("`@)'1H:7,M/F1B+3YQ=65R
M>2@@"B`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H(D1%3$5412!&
M4D]-("5S(%=(15)%("AE>'!I<F5S(#P]("5D($%.1"!E>'!I<F5S(#X@,"D@
M3U(@8VAA;F=E9"`\/2`H3D]7*"D@+2`E9"DB+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+"`*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1I;64H*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1M87AL:69E=&EM90H@("`@("`@("`@("`@("`@("`@("`@("`I
M"B`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@+R]C:&5C:R!F;W(@
M=&]T86P@<VEZ92!O9B!C86-H90H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)W-E;&5C="!S=6TH;&5N9W1H*&-A8VAE9&%T82DI(&%S($-A8VAE4VEZ92!F
M<F]M("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H
M95]T86)L90H@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("1T
M:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("`D=&AI<RT^9&(M/DYE
M>'1?4F5C;W)D*"D["B`@("`@("`@)&-A8VAE<VEZ92`]("1T:&ES+3YD8BT^
M9B@G0V%C:&53:7IE)RD["B`@("`@("`@+R]I9B!C86-H92!I<R!T;R!B:6<N
M"B`@("`@("`@:68@*"1C86-H97-I>F4@/B`D=&AI<RT^:&EG:'=A=&5R*0H@
M("`@("`@('L*("`@("`@("`@("`@+R]F:6YD('1H92!L;W=W871E<B!M87)K
M+@H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=S96QE8W0@;&5N9W1H
M*&-A8VAE9&%T82D@87,@<VEZ92P@8VAA;F=E9"!F<F]M("5S(&]R9&5R(&)Y
M(&-H86YG960@1$530R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@("`@("`@("`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D[
M"@H@("`@("`@("`@("`D:V5E<%]S:7IE/3`["B`@("`@("`@("`@('=H:6QE
M("@D:V5E<%]S:7IE(#P@)'1H:7,M/FQO=W=A=&5R("8F("1T:&ES+3YD8BT^
M3F5X=%]296-O<F0H*2`I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M("1K965P7W-I>F4@*ST@)'1H:7,M/F1B+3YF*"=S:7IE)RD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@+R]D96QE=&4@86QL(&5N=')I97,L('=H:6-H
M('=E<F4@8VAA;F=E9"!B969O<F4@=&AE(")L;W=W=V%T97(@;6%R:R(*("`@
M("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G9&5L971E(&9R;VT@)7,@=VAE
M<F4@8VAA;F=E9"`\/2`G+B1T:&ES+3YD8BT^9B@G8VAA;F=E9"<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE
M7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*
M"B`@("`@("`@("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@
M("!]"B`@("!]("\O(&5N9"!F=6YC(&=A<F)A9V5#;VQL96-T:6]N"GT*/SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]#86-H92]/=71P=70N<&AP````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C$U,P`Q,#0Q-S,V,S`P-0`P,C`S-C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z
M.B!#86-H92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N
M9&4^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@
M($-H<FES=&EA;B!3=&]C:V5R(#QC:')E9W5`<&AA;G0N8V@^("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!6:6YA:2!+;W!P(#QK
M;W!P0&YE='IA<F)E:71E<BYD93X@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M($]U='!U="YP:'`L=B`Q+C8@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@
M)`H*<F5Q=6ER95]O;F-E("=#86-H92YP:'`G.PH*+RHJ"BH@0VQA<W,@=&\@
M8V%C:&4@=&AE(&]U='!U="!O9B!A('-C<FEP="!U<VEN9R!T:&4@;W5T<'5T
M(&)U9F9E<FEN9R!F=6YC=&EO;G,**@HJ(%-I;7!L92!O=71P=70@8V%C:&4N
M(%-O;64@<&%G97,@<F5Q=6ER92!L;W1S(&]F('1I;64@=&\@8V]M<'5T92X@
M0V%C:&EN9R!T:&4**B!O=71P=70@8V%N(&EN8W)E87-E('1H92!O=F5R86QL
M('-P965D(&1R86UA=&EC86QL>2P@97-P96-I86QL>2!I9B!Y;W4@=7-E"BH@
M82!3:&%R960@365M;W)Y('-T;W)A9V4@8V]N=&%I;F5R+@HJ"BH@07,@>6]U
M(&-A;B!S964@:6X@=&AE(&5X86UP;&4@=&AE('5S86=E(&ES(&5X=&5M96QY
M('-I;7!L92X@5&\@8V%C:&4@82!S8W)I<'0**B!S:6UP;&4@<'5T('-O;64@
M9F5W(&QI;F5S(&]F(&-O9&4@:6X@9G)O;G0@;V8@>6]U<B!S8W)I<'0@86YD
M('-O;64@870@=&AE(&5N9"X**B!!('!R969E<G)A8FQE('!L86-E(&9O<B!T
M:&ES(&%R92!T:&4@875T;U]P<F5P96YD(&%N9"!A=71O7V%P<&5N9"!F:6QE
M<R`H/3X@<&AP+FEN:2DN"BH**B!5<V%G92!E>&%M<&QE.@HJ"BH@("\O('!L
M86-E('1H:7,@<V]M97=H97)E(&EN(&$@8V5N=')A;"!C;VYF:6<@9FEL90HJ
M("!D969I;F4H0T%#2$5?4U1/4D%'15]#3$%34RP@)V9I;&4G*3L**B`@+R\@
M9FEL92!S=&]R86=E(&YE961S(&$@9&ER('1O('!U="!T:&4@8V%C:&4@9FEL
M97,**B`@9&5F:6YE*$-!0TA%7T1)4BP@)R]V87(O=&UP+R<I.PHJ"BH@("\O
M(&=E="!A(&-A8VAE(&]B:F5C=`HJ("`D8V%C:&4@/2!N97<@0V%C:&5?3W5T
M<'5T*$-!0TA%7U-43U)!1T5?0TQ!4U,L(&%R<F%Y*"=C86-H95]D:7(G(#T^
M($-!0TA%7T1)4BDI.PHJ"BH@("\O(&-O;7!U=&4@=&AE('5N:7%U92!H86YD
M;&4N"BH@("\O(&EF('EO=7(@<V-R:7!T(&1E<&5N9',@;VX@0V]O:VEE(&%N
M9"!(5%10(%!O<W0@9&%T82!A<R!W96QL"BH@("\O('EO=2!S:&]U;&0@=7-E
M.@HJ("`O+R`D8V%C:&5?:&%N9&QE(#T@87)R87DH"BH@("\O("`@("`@("`@
M("`@("`@("`@("`@("`G9FEL92<@/3X@)%)%455%4U1?55))+`HJ("`O+R`@
M("`@("`@("`@("`@("`@("`@("`@)W!O<W0G(#T^("1(5%107U!/4U1?5D%2
M4RP**B`@+R\@("`@("`@("`@("`@("`@("`@("`@("=C;V]K:64G("`]/B`D
M2%144%]#3T]+245?5D%24PHJ("`O+R`@("`@("`@("`@("`@("`@("`@*3L*
M*B`@+R\@0G5T(&)E('=A<FYE9"P@=7-I;F<@86QL($=%5"!O<B!03U-4(%9A
M<FEA8FQE<R!A<R!A('-E960**B`@+R\@8V%N(&)E('5S960@9F]R(&$@1$]3
M(&%T=&%C:RX@0V%L;&EN9R!H='1P.B\O=W=W+F5X86UP;&4N8V]M+V5X86UP
M;&4N<&AP/W=H871E=F5R"BH@("\O('=H97)E('=H871E=F5R(&ES(&$@<F%N
M9&]M('1E>'0@;6EG:'0@8F4@=7-E9"!T;R!F;&]O9"!Y;W5R(&-A8VAE+@HJ
M("`D8V%C:&5?:&%N9&QE(#T@)&-A8VAE+3YG96YE<F%T94E$*"1215%515-4
M7U5222D["BH**B`@+R\@;F]W('1H92!M86=I8R!H87!P96YS.B!I9B!C86-H
M960@8V%L;"!D:64H*0HJ("`O+R!T;R!E;F0@=&AE('1I;64@8V]N<W5M<'1I
M;VYG('-C<FEP="!S8W)I<'0@97AE8W5T:6]N(&%N9"!U<V4@=&AE(&-A8VAE
M9"!V86QU92$**B`@:68@*"1C;VYT96YT(#T@)&-A8VAE+3YS=&%R="@D8V%C
M:&5?:&%N9&QE*2D@>PHJ("`@("!P<FEN="`D8V]N=&5N=#L**B`@("`@<')I
M;G0@)SQP/D-A8VAE(&AI=#PO<#XG.PHJ("`@("!D:64H*3L**B`@?0HJ"BH@
M("\O('1I;64@8V]N<W5M<'1I;VX@<V-R:7!T(&=O97,@:&5R92X**@HJ("`O
M+R!S=&]R92!T:&4@;W5T<'5T(&]F('1H92!C86-H92!I;G1O('1H92!C86-H
M92!A;F0@<')I;G0@=&AE(&]U='!U="X**B`@<')I;G0@)&-A8VAE+3YE;F0H
M*3L**B`@<')I;G0@(CQP/D-A8VAE(&UI<W,L('-T;W)E9"!U<VEN9R!T:&4@
M240@)R1I9"<N/"]P/B(["BH**B`@268@>6]U(&1O(&YO="!W86YT('1O(&-A
M8VAE(&$@=VAO;&4@<&%G92`M(&YO('!R;V)L96TZ"BH**B`@:68@*"$H)&-O
M;G1E;G0@/2`D8V%C:&4M/G-T87)T*"1C86-H95]H86YD;&4I*2D@>PHJ("`@
M("`O+R!D;R!T:&4@8V]M<'5T871I;VX@:&5R90HJ("`@("!P<FEN="`D8V%C
M:&4M/F5N9"@I"BH@('T@96QS92!["BH@("`@('!R:6YT("1C;VYT96YT.PHJ
M("!]"BH**B`@268@>6]U(&YE960@86X@97AA;7!L92!S8W)I<'0@8VAE8VL@
M=&AE("AA=71O7REP<F5P96YD(&%N9"`H875T;U\I87!P96YD"BH@(&9I;&5S
M(&]F(&UY(&AO;65P86=E.@HJ"BH@("`@:'1T<#HO+W=W=RYU;&8M=V5N9&5L
M+F1E+W!H<"]S:&]W7W-O=7)C92YP:'`_9FEL93UP<F5P96YD"BH@("`@:'1T
M<#HO+W=W=RYU;&8M=V5N9&5L+F1E+W!H<"]S:&]W7W-O=7)C92YP:'`_9FEL
M93UA<'!E;F0**@HJ("!$;VXG="!K;F]W(&AO=R!T;R!U<V4@:70@;W(@>6]U
M(&YE960@<')O9FEL:6YG(&EN9F]R;6%T:6]N<S]@"BH@($%S:R!#:')I<W1I
M86X@:&4@=V%S('!A=&EE;G0@=VET:"!M92!A;F0@:&4G;&P@8F4@<V\@=VET
M:"!Y;W5R('%U97-T:6]N<R`[*2X**@HJ("!(879E(&9U;B$**@HJ($!A=71H
M;W)S("!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X**B!`=F5R
M<VEO;B`@)$E$.B`D"BH@0'!A8VMA9V4@($-A8VAE"BH@0&%C8V5S<R`@('!U
M8FQI8PHJ+PIC;&%S<R!#86-H95]/=71P=70@97AT96YD<R!#86-H92!["@H@
M("`@+RHJ"B`@("`J($E$('!A<W-E9"!T;R!S=&%R="@I"B`@("`J"B`@("`J
M($!V87(@('-T<FEN9PH@("`@*B!`<V5E("!S=&%R="@I+"!E;F0H*0H@("`@
M*B\*("`@('9A<B`D;W5T<'5T7VED(#T@)R<["@H@("`@+RHJ"B`@("`J($=R
M;W5P('!A<W-E9"!T;R!S=&%R="@I"B`@("`J"B`@("`J($!V87(@('-T<FEN
M9PH@("`@*B!`<V5E("!S=&%R="@I+"!E;F0H*0H@("`@*B\*("`@('9A<B`D
M;W5T<'5T7V=R;W5P(#T@)R<["@H@("`@+RHJ"B`@("`J(%!%05(M1&5C;VYS
M=')U8W1O<@H@("`@*B!#86QL(&1E8V]N<W1R=6-T;W(@;V8@<&%R96YT"B`@
M("`J+PH@("`@9G5N8W1I;VX@7T-A8VAE7T]U='!U="@I"B`@("!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7T-A8VAE*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`J('-T87)T<R!T:&4@;W5T<'5T(&)U9F9E<FEN9R!A;F0@<F5T=7)N<R!A
M;B!E;7!T>2!S=')I;F<@;W(@<F5T=7)N<R!T:&4@8V%C:&5D(&]U='!U="!F
M<F]M('1H92!C86-H92X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U
M<`H@("`@*B!`<F5T=7)N("`@<W1R:6YG"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,*("`@("HO"B`@("!F=6YC=&EO;B!S=&%R="@D:60L("1G<F]U<"`]("=D
M969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@
M("`@("`@(')E='5R;B`G)SL*"B`@("`@("`@+R\@=&AI<R!I<R!A;')E861Y
M(&-A8VAE9"!R971U<FX@:70@9G)O;2!T:&4@8V%C:&4@<V\@=&AA="!T:&4@
M=7-E<@H@("`@("`@("\O(&-A;B!U<V4@=&AE(&-A8VAE(&-O;G1E;G0@86YD
M('-T;W`@<V-R:7!T(&5X96-U=&EO;@H@("`@("`@(&EF("@D8V]N=&5N="`]
M("1T:&ES+3YG970H)&ED+"`D9W)O=7`I*0H@("`@("`@("`@("!R971U<FX@
M)&-O;G1E;G0["@H@("`@("`@("\O(')E;65M8F5R('-O;64@9&%T82!T;R!B
M92!A8FQE('1O(&9I;&P@=&AE(&-A8VAE(&]N(&-A;&QI;F<@96YD*"D*("`@
M("`@("`D=&AI<RT^;W5T<'5T7VED(#T@)&ED.PH@("`@("`@("1T:&ES+3YO
M=71P=71?9W)O=7`@/2`D9W)O=7`["@H@("`@("`@("\O(%=!4DY)3D<Z('=E
M(&YE960@=&AE(&]U='!U="!B=69F97(@+2!P;W-S:6)L92!C;&%S:&5S"B`@
M("`@("`@;V)?<W1A<G0H*3L*("`@("`@("!O8E]I;7!L:6-I=%]F;'5S:"AF
M86QS92D["@H@("`@("`@(')E='5R;B`G)SL*("`@('T@+R\@96YD(&9U;F,@
M<W1A<G0*"B`@("`O*@H@("`@*B!3=&]R97,@=&AE(&-O;G1E;G0@;V8@=&AE
M(&]U='!U="!B=69F97(@:6YT;R!T:&4@8V%C:&4@86YD(')E='5R;G,@=&AE
M(&-O;G1E;G0N"B`@("`J"B`@("`J($!P87)A;2`@("!M:7AE9"`@(&QI9F5T
M:6UE(&]F('1H92!C86-H960@9&%T82!I;B!S96-O;F1S("T@,"!F;W(@96YD
M;&5S<RX@36]R92!F;W)M871S(&%V86EL86)L92X@<V5E($-O;G1A:6YE<CHZ
M9V5T17AP:7)E<T%B<V]L=71E*"D*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M861D:71I;VYA;"!U<V5R9&5F:6YE9"!D871A"B`@("`J($!R971U<FX@("!S
M=')I;F<@(&-A8VAE9"!O=71P=70*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@
M("`@*B!`<V5E("`@("`@96YD4')I;G0H*2P@96YD1V5T*"DL($-O;G1A:6YE
M<CHZ9V5T17AP:7)E<T%B<V]L=71E*"D*("`@("HO"B`@("!F=6YC=&EO;B!E
M;F0H)&5X<&ER92`](#`L("1U<V5R9&%T82`]("<G*2!["B`@("`@("`@)&-O
M;G1E;G0@/2!O8E]G971?8V]N=&5N=',H*3L*("`@("`@("!O8E]E;F1?8VQE
M86XH*3L*"B`@("`@("`@+R\@<W1O<F4@:6X@=&AE(&-A8VAE"B`@("`@("`@
M:68@*"1T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("`D=&AI<RT^8V]N=&%I
M;F5R+3YS879E*"1T:&ES+3YO=71P=71?:60L("1C;VYT96YT+"`D97AP:7)E
M+"`D=&AI<RT^;W5T<'5T7V=R;W5P+"`D=7-E<F1A=&$I.PH*("`@("`@("!R
M971U<FX@)&-O;G1E;G0["B`@("!]("\O(&5N9"!F=6YC(&5N9"@I"@H@("`@
M+RHJ"B`@("`J(%-T;W)E<R!T:&4@8V]N=&5N="!O9B!T:&4@;W5T<'5T(&)U
M9F9E<B!I;G1O('1H92!C86-H92!A;F0@<')I;G1S('1H92!C;VYT96YT+@H@
M("`@*@H@("`@*B!`8G)O=&AE<B`@96YD*"D*("`@("HO"B`@("!F=6YC=&EO
M;B!E;F10<FEN="@D97AP:7)E(#T@,"P@)'5S97)D871A(#T@)R<I('L*("`@
M("`@("`D=&AI<RT^<')I;G1#;VYT96YT*"1T:&ES+3YE;F0H)&5X<&ER92P@
M)'5S97)D871A*2D["B`@("!]("\O(&5N9"!F=6YC(&5N9%!R:6YT"@H@("`@
M+RHJ"B`@("`J(%-E;F1S('1H92!D871A('1O('1H92!U<V5R+@H@("`@*B!4
M:&ES(&ES(&9O<B!C;VUP871I8FEL:71Y('=I=&@@3W5T<'5T0V]M<')E<W-I
M;VX*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PH@("`@*B\@("`@"B`@("!F=6YC=&EO;B!P<FEN=$-O;G1E
M;G0H)&-O;G1E;G0@/2`G)RD@>PH@("`@("`@(&EF("@G)R`]/2`D8V]N=&5N
M="D*("`@("`@("`@("`@)&-O;G1E;G0@/2`F)'1H:7,M/F-O;G1A:6YE<BT^
M8V%C:&5D871A.PH@("`@("`@("`@("`*("`@("`@("!P<FEN="`D8V]N=&5N
M=#L*("`@('T*("`@("\J*@H@("`@*B!2971U<FYS('1H92!C;VYT96YT(&]F
M('1H92!O=71P=70@8G5F9F5R(&)U="!D;V5S(&YO="!S=&]R92!I="!I;G1O
M('1H92!C86-H92X*("`@("H*("`@("H@57-E('1H:7,@;65T:&]D(&EF('1H
M92!C;VYT96YT(&]F('EO=7(@<V-R:7!T(&ES(&UA<FMU<"`H6$U,*0H@("`@
M*B!T:&%T(&AA<R!T;R!B92!P87)S960O8V]N=F5R=&5D("A84TQ4*2!B969O
M<F4@>6]U(&-A;B!O=71P=70*("`@("H@86YD('-T;W)E(&ET(&EN=&\@=&AE
M(&-A8VAE('5S:6YG('-A=F4H*2X*("`@("H*("`@("H@0')E='5R;B`@('-T
M<FEN9PH@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!E
M;F10<FEN="@I+"!E;F0H*0H@("`@*B\*("`@(&9U;F-T:6]N(&5N9$=E="@I
M('L*("`@("`@("`D8V]N=&5N="`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@
M("`@(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@("`D=&AI<RT^;W5T<'5T7VED
M(#T@)R<["B`@("`@("`@)'1H:7,M/F]U='!U=%]G<F]U<"`]("<G.PH*("`@
M("`@("!R971U<FX@)&-O;G1E;G0["B`@("!]("\O(&5N9"!F=6YC(&5N9$=E
M=`I]("\O(&5N9"!C;&%S<R!O=71P=70*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+T-A8VAE+T=R87!H:6-S+G!H<```````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,P-3<P`#$P-#$W,S8S,#`U`#`R,#8R
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2
M(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@
M1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS
M92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@
M?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*
M+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O
M8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($=R87!H:6-S+G!H<"QV
M(#$N-2`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"@IR97%U:7)E7V]N
M8V4@)T-A8VAE+G!H<"<["@HO*BH**B!'<F%P:&EC<R!D:7-K(&-A8VAE+@HJ
M(`HJ(%1H92!U<W5A;"!W87D@=&\@8W)E871E(&EM86=E<R!I<R!T;R!P87-S
M('-O;64@87)G=6UE;G1S('1H870@9&5S8W)I8F4@=&AE(&EM86=E(`HJ('1O
M(&$@<V-R:7!T('1H870@9'EN86UI8V%L;'D@8W)E871E<R!A;B!I;6%G92X@
M1F]R(&5V97)Y(&EM86=E(&]F(&$@<&%G92`**B!A(&YE=R!02%`@:6YT97)P
M<F5T97(@9V5T<R!S=&%R=&5D+B!4:&ES(&ES(&$@9V]O9"!W87D@=&\@:VEL
M;"!Y;W5R('=E8G-E<G9E<BX**B`**B!7:&5N(&1E86QI;F<@=VET:"!D>6YA
M;6EC86QL>2!G96YE<F%T960@:6UA9V5S('EO=2!S:&]U;&0@;F]T(&-A;&P@
M86YO=&AE<B!S8W)I<'0@"BH@=&\@9V5N97)A=&4@=&AE(&EM86=E<R!B=70@
M9V5N97)A=&4@=&AE(&EM86=E<R!B>2!T:&4@<V-R:7!T('1H870@<')O9'5C
M97,@=&AE('!A9V4**B!T:&%T(&-O;G1A:6YS('1H92!I;6%G97,N(%1H:7,@
M:7,@82!M86IO<B!I;7!R;W9E;65N="!B=70@:70G<R!O;FQY(&AA;&8@=&AE
M('=A>2X**B`**B!4:&5R92=S(&YO(&YE960@=&\@<F5R96YD97(@86X@:6UA
M9V4@;VX@979E<GD@<F5Q=65S="X@02!S:6UP;&4@9&ES:R!C86-H92!C86X@
M<F5D=6-E"BH@=&AE(&-O;7!U=&%T:6]N('1I;64@9')A;6%T:6-A;&QY+B!4
M:&ES(&ES('=H870@=&AE(&-L87-S(&=R87!H:6-S7V-A8VAE(&ES(&9O<BX@
M"BH@"BH@57-A9V4Z"BH@"BH@+R\@8W)E871E(&%N(&EN<W1A;F-E(&]F('1H
M92!G<F%P:&EC<R!C86-H90HJ("1C86-H92`](&YE=R!G<F%P:&EC<U]C86-H
M93L**@HJ("1I;6<@/2!);6%G94-R96%T92@N+BXI.PHJ"BH@+R\@8V]M<'5T
M92!A;B!)1"!F;W(@>6]U<B!I;6%G92!B87-E9"!O;B!T>7!I8V%L('!A<F%M
M971E<G,**B`D:60@/2!M-60H("1S:7IE+"`D8V]L;W)S+"`D;&%B96PI.PHJ
M(`HJ("\O(&-H96-K(&EF(&ET)W,@8V%C:&5D"BH@:68@*"$H)&QI;FL@/2`D
M8V%C:&4M/F=E=$EM86=E3&EN:R@D:60L("=G:68G*2DI('L**B`@"BH@("`O
M+R!H;6UM+"!I="=S(&YO="!C86-H960L(&-R96%T92!I=`HJ("`@+BXN"BH@
M("`O+R!C86-H94EM86=E3&EN:R@I(&%N9"!C86-H94EM86=E*"D@;6%K92!T
M:&4@26UA9V5'248H*2!C86QL(0HJ("`@+R\@8V%C:&5);6%G92@I(')E='5R
M;G,@=&AE('9A;'5E(&]F($EM86=E1TE&*"D@6V5T8RY=+"!C86-H94EM86=E
M3&EN:R@I(')E='5R;G,@82!54DP**B`@("1L:6YK(#T@)&-A8VAE+3YC86-H
M94EM86=E3&EN:R@D:60L("1I;6<L("=G:68G*3L**B`**B!]"BH**B`O+R!/
M:RP@;&5T)W,@8G5I;&0@=&AE($EM86=E3&EN:PHJ("1S:7IE(#T@9V5T26UA
M9V53:7IE*"1L:6YK6S!=*3L**B!P<FEN=&8H)SQI;6<@<W)C/2(E<R(@)7,^
M)RP@)&QI;FM;,5TL("1S:7IE6S-=*3L**@HJ("\O(&9O<B!C86-H94EM86=E
M*"DZ"BH@+R\@:&5A9&5R*"=#;VYT96YT+71Y<&4Z(&EM86=E+V=I9B<I.R!P
M<FEN="`D8V%C:&4M/F-A8VAE26UA9V4H)&ED+"`D:6UG+"`G9VEF)RD["BH@
M"BH**B!4:&4@8VQA<W,@<F5Q=6ER97,@4$A0(#0N,"XR*R!;26UA9V54>7!E
M*"E=+B!.;W1E('1H870@8V%C:&5);6%G92@I('=O<FMS('=I=&@**B!T:&4@
M;W5T<'5T(&)U9F9E<BX@36]D:69Y(&ET(&EF(')E<75I<F5D(0HJ"BH@0&%U
M=&AO<B`@(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V
M97)S:6]N("`D260Z($=R87!H:6-S+G!H<"QV(#$N-2`R,#`S+S`Q+S`T(#$Q
M.C4T.C0U(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BHO"F-L87-S($-A
M8VAE7T=R87!H:6-S(&5X=&5N9',@0V%C:&4@>PH*"B`@("`O*BH*("`@("H@
M0V%C:&4@55),('!R969I>"X*("`@("H@"B`@("`J($UA:V4@<W5R92!T:&%T
M('1H92!C86-H92!54DP@<')E9FEX('!O:6YT<R!T;R!T:&4@)&-A8VAE7V1I
M<BP@;W1H97)W:7-E"B`@("`J('EO=7(@;&EN:W,@=VEL;"!B92!B<F]K96XN
M(%5S92!S971#86-H95523"!T;R!S<&5C:69Y('1H92!C86-H95]U<FP@86YD
M(`H@("`@*B!S971#86-H941I<B@I(&9O<B!T:&4@8V%C:&5?9&ER+@H@("`@
M*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J($!S964@('-E=$-A8VAE55),
M*"DL('-E=$-A8VAE1&ER*"D*("`@("HO"B`@("!V87(@)&-A8VAE7W5R;"`]
M("<G.PH*("`@("\J*@H@("`@*B!$:7)E8W1O<GD@=VAE<F4@8V%C:&5D(&9I
M;&5S(&=E="!S=&]R960N"B`@("`J(',*("`@("H@36%K92!S=7)E('1H870@
M=&AE(&-A8VAE7V1I<B!I<R!W<FET86)L92!A;F0@;V9F97)S(&5N;W5G:"!S
M<&%C92X@0VAE8VL@"B`@("`J(&%L<V\@:68@>6]U<B!C86-H95]U<FP@<&]I
M;G1S('1O('1H92!D:7)E8W1O<GDN(%5S92!S971#86-H941I<B@I('1O('-E
M=`H@("`@*B!T:&4@=F%R:6%B;&4N"B`@("`J(`H@("`@*B!`=F%R("!S=')I
M;F<*("`@("H@0'-E92`@<V5T0V%C:&5$:7(H*2P@<V5T0V%C:&554DPH*0H@
M("`@*B\*("`@('9A<B`D8V%C:&5?9&ER(#T@)R<["@H@("`@+RHJ"B`@("`J
M($YA;65P<F5F:7@@;V8@8V%C:&5D(&9I;&5S+@H@("`@*B`*("`@("H@4&5R
M(&1E9F%U;'0@=&AE('!R969I>"`B9W)A<&AI8W-?(B!G971S('5S960N(%EO
M=2!M:6=H="!U<V4@=&AI<R`*("`@("H@9F]R('9E<G-I;VYI;F<@;W(@=&\@
M96%S92`H;6%N=6%L*2!C;&5A;B!U<',N"B`@("`J"B`@("`J($!V87(@("`@
M("!S=')I;F<*("`@("HO"B`@("!V87(@)&-A8VAE7V9I;&5?<')E9FEX(#T@
M)V=R87!H:6-S7R<["B`@("`*("`@(`H@("`@+RHJ"B`@("`J($-A8VAE(&-O
M;G1A:6YE<B!G<F]U<"X*("`@("H*("`@("H@0'9A<B`@("`@('-T<FEN9PH@
M("`@*B\*("`@('9A<B`D8V%C:&5?9W)O=7`@/2`G9W)A<&AI8W,G.PH*("`@
M(`H@("`@+RHJ"B`@("`J($UA<'!I;F<@9G)O;2!S=7!P;W)T960@:6UA9V4@
M='EP92!T;R!A($EM86=E5'EP92@I(&-O;G-T86YT+@H@("`@*B`*("`@("H@
M4F5F97)R('1O('1H92!02%`@;6%N=6%L(&9O<B!M;W)E(&EN9F]R;6%T:6]N
M<R!O;B!);6%G951Y<&4H*0H@("`@*B`*("`@("H@0'9A<B`@87)R87D*("`@
M("H@0&QI;FL@:'1T<#HO+W=W=RYP:'`N;F5T+TEM86=E5'EP90H@("`@*B\*
M("`@('9A<B`D:6UA9V5T>7!E<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=G:68G("`@/3X@24U'7T=)1BP@"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VIP9R<@("`]/B!)34=?2E!'+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P;F<G("`@/3X@24U'
M7U!.1RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=V)M<"<@
M(#T^($E-1U]70DU0"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@+RHJ"B`@("`J($EN
M<W1A;G1I871E<R!A(&-A8VAE(&9I;&4@8V]N=&%I;F5R+@H@("`@*@H@("`@
M*B\*("`@(&9U;F-T:6]N($-A8VAE7T=R87!H:6-S*"D@>PH@("`@"B`@("`@
M("`@)'1H:7,M/D-A8VAE*"=F:6QE)RP@87)R87DH)V-A8VAE7V1I<B<@/3X@
M)'1H:7,M/F-A8VAE7V1I<BP@)V9I;&5N86UE7W!R969I>"<@/3X@)'1H:7,M
M/F-A8VAE7V9I;&5?<')E9FEX*2D["B`@("`@("`@"B`@("!]("\O(&5N9"!C
M;VYS=')U8W1O<@H*("`@(`H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(&-O
M;G1E;G0@;V8@82!C86-H960@:6UA9V4@9FEL92X*("`@("H@"B`@("`J(%1H
M:7,@9G5N8W1I;VX@8V%N(&)E('5S960@=&\@<V5N9"!T:&4@:6UA9V4@9&ER
M96-T;'D@=&\@=&AE(&)R;W=S97(N"B`@("`J($UA:V4@<W5R92!T:&%T('EO
M=2!S96YD(&$@8V]R<F5S<&]N9&5N9&EN9R!H96%D97(@8F5F;W)E('-E;F1I
M;F<@=&AE(&EM86=E(&ET<V5L9BX*("`@("H*("`@("H@06QW87ES('1R>2!T
M;R!G970@=&AE(&EM86=E(&9R;VT@=&AE(&-A8VAE(&)E9F]R92!Y;W4@8V]M
M<'5T92!I="X@4V5E(`H@("`@*B!T:&4@8VQA<W,@9&]C<R!F;W(@86X@97AA
M;7!L92X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@26UA9V4M240*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@26UA9V4@='EP93H@9VEF+"!J<&<L
M('!N9RP@=V)M<`H@("`@*B!`<F5T=7)N("`@<W1R:6YG("!);6%G92!F:6QE
M(&-O;G1E;G1S(&EF(&$@8V%C:&5D(&9I;&4@97AI<W1S(&]T:&5R=VES92!A
M;B!E;7!T>2!S=')I;F<*("`@("H@0'-E92`@("`@(&-A8VAE26UA9V4H*0H@
M("`@*B\@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`*("`@
M(&9U;F-T:6]N(&=E=$EM86=E*"1I9"P@)&9O<FUA="`]("=P;F<G*2!["B`@
M("`@("`@)&ED(#T@)'1H:7,M/F=E;F5R871E240H)&ED+"`D9F]R;6%T*3L*
M("`@("`@("`*("`@("`@("!R971U<FX@)'1H:7,M/F=E="@D:60L("1T:&ES
M+3YC86-H95]G<F]U<"D["B`@("!]("\O(&5N9"!F=6YC(&=E=$EM86=E"@H@
M("`@"B`@("`O*BH*("`@("H@4F5T=7)N<R!A;B!A<G)A>2!W:71H(&$@;&EN
M:R!T;R!T:&4@8V%C:&5D(&EM86=E(&%N9"!T:&4@:6UA9V4@9FEL92!P871H
M+@H@("`@*B`*("`@("H@06QW87ES('1R>2!T;R!G970@=&AE(&EM86=E(&9R
M;VT@=&AE(&-A8VAE(&)E9F]R92!Y;W4@8V]M<'5T92!I="X@4V5E(`H@("`@
M*B!T:&4@8VQA<W,@9&]C<R!F;W(@86X@97AA;7!L92X*("`@("H*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@26UA9V4M240*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@26UA9V4@='EP93H@9VEF+"!J<&<L('!N9RP@=V)M<`H@("`@*B!`
M<F5T=7)N("`@87)R87D@("!;(&9U;&P@<&%T:"!T;R!T:&4@:6UA9V4@9FEL
M92P@:6UA9V4@=7)L(%T*("`@("H@0'1H<F]W("`@($-A8VAE7T5R<F]R"B`@
M("`J($!S964@("`@("!C86-H94EM86=E3&EN:R@I"B`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T26UA9V5,:6YK*"1I9"P@)&9O<FUA="`]("=P;F<G*2!["B`@
M("`@("`@)&ED(#T@)'1H:7,M/F=E;F5R871E240H)&ED+"`D9F]R;6%T*3L*
M("`@("`@("!I9B`H(21T:&ES+3YC;VYT86EN97(M/FED17AI<W1S*"1I9"P@
M)'1H:7,M/F-A8VAE7V=R;W5P*2D@"B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@I.PH*("`@("`@("`D9FEL92`]("1T:&ES+3YC86-H95]U<FP@+B`D=&AI
M<RT^8V%C:&5?9FEL95]P<F5F:7@@+B`D:60["@H@("`@("`@(')E='5R;B!A
M<G)A>2@D=&AI<RT^8V]N=&%I;F5R+3YG971&:6QE;F%M92@D:60L("1T:&ES
M+3YC86-H95]G<F]U<"DL("1F:6QE*3L*("`@('T@+R\@96YD(&9U;F,@9V5T
M26UA9V5,:6YK"B`@("`*"B`@("`O*BH*("`@("H@0W)E871E(&%N(&EM86=E
M(&9R;VT@=&AE(&=I=F5N(&EM86=E(&AA;F1L97(L(&-A8VAE(&ET(&%N9"!R
M971U<FX@=&AE(&9I;&4@8V]N=&5N="X*("`@("H*("`@("H@06QW87ES('1R
M>2!T;R!R971R:79E('1H92!I;6%G92!F<F]M('1H92!C86-H92!B969O<F4@
M>6]U(&-O;7!U=&4@:70N"B`@("`J(`H@("`@*B!787)N:6YG.B!T:&ES(&9U
M;F-T:6]N('5S97,@=&AE(&]U='!U="!B=69F97(N($EF('EO=2!E>'!E8W0@
M8V]L;&ES:6]N<R`*("`@("H@;6]D:69Y('1H92!C;V1E+@H@("`@*@H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!);6%G92U)1"X@57-E9"!A<R!A('!A<G0@
M;V8@=&AE(&-A8VAE(&9I;&5N86UE+@H@("`@*B`@("`@("`@("`@("`@("`@
M("!5<V4@;60U*"D@=&\@9V5N97)A=&4@82`B=6YI<75E(B!)1"!F;W(@>6]U
M<B!I;6%G90H@("`@*B`@("`@("`@("`@("`@("`@("!B87-E9"!O;B!C:&%R
M86-T97)I<W1I8R!V86QU97,@<W5C:"!A<R!T:&4@8V]L;W(L('-I>F4@971C
M+@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!);6%G92!H86YD;&5R('1O(&-R
M96%T92!T:&4@:6UA9V4@9G)O;2X*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M26UA9V4@='EP93H@9VEF+"!J<&<L('!N9RP@=V)M<"X@06QS;R!U<V5D(&%S
M(&9I;&5N86UE('-U9F9I>"X*("`@("H@("`@("`@("`@("`@("`@("`@268@
M86X@=6YS=7!P;W)T960@='EP92!I<R!R97%U97-T960@=&AE(&9U;F-T:6]N
M<R!T<FEE<R!T;R`*("`@("H@("`@("`@("`@("`@("`@("`@9F%L;&)A8VL@
M=&\@82!S=7!P;W)T960@='EP92!B969O<F4@=&AR;W=I;F<@86X@97AE<'1I
M;VXN"B`@("`J($!R971U<FX@("!S=')I;F<@($EM86=E(&-O;G1E;G0@<F5T
M=7)N960@8GD@26UA9V5'248O+BXN(`H@("`@*B!`=&AR;W=S("`@0V%C:&5?
M17)R;W(*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@("`@
M9V5T26UA9V4H*0H@("`@*B\*("`@(&9U;F-T:6]N(&-A8VAE26UA9V4H)&ED
M+"`D:6UG+"`D9F]R;6%T(#T@)W!N9R<I('L*("`@("`@("!I9B`H(21I9"D*
M("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G66]U(&UU<W0@
M<')O=FED92!A;B!)1"!F;W(@86YD(&EM86=E('1O(&)E(&-A8VAE9"$G+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D:60@/2`D=&AI<RT^9V5N
M97)A=&5)1"@D:60L("1F;W)M870I.PH@("`@("`@("1T>7!E<R`]($EM86=E
M5'EP97,H*3L*"B`@("`@("`@+R\@0VAE8VL@:68@=&AE(')E<75E<W1E9"!I
M;6%G92!T>7!E(&ES('-U<'!O<G1E9"!B>2!T:&4@1T0@;&EB+@H@("`@("`@
M("\O($EF(&YO="P@=')Y(&$@8V%L;&)A8VL@=&\@=&AE(&9I<G-T(&%V86EL
M86)L92!I;6%G92!T>7!E+@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/FEM
M86=E='EP97-;)&9O<FUA=%TI('Q\("$H)'1Y<&5S("8@)'1H:7,M/FEM86=E
M='EP97-;)&9O<FUA=%TI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YI;6%G971Y<&5S(&%S("1S=7!P;W)T960@/3X@)&)I=&UA<VLI('L*("`@
M("`@("`@("`@("`@(&EF("@D='EP97,@)B`D8FET;6%S:RD@>PH@("`@("`@
M("`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@B5&AE(&)U:6QD(&EN($=$
M(&QI8B!D;V5S(&YO="!S=7!P;W)T('1H92!I;6%G92!T>7!E("1F;W)M870N
M($9A;&QB86-K('1O("1S=7!P;W)T960N(BP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B2&UM+"!I<R!Y;W5R(%!(4"!B
M=6EL9"!W:71H($=$('-U<'!O<G0_($-A;B=T(&9I;F0@86YY('-U<'!O<G1E
M9"!T>7!E<RXB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&EM
M86=E(#T@)'1H:7,M/F=E="@D:60L("1T:&ES+3YC86-H95]G<F]U<"DI"B`@
M("`@("`@("`@(')E='5R;B`D:6UA9V4["@H@("`@("`@("\O('-A=F4@=&AE
M(&EM86=E('1O('1H92!O=71P=70@8G5F9F5R+"!W<FET92!I="!T;R!D:7-K
M(&%N9"`*("`@("`@("`O+R!R971U<FX@=&AE(&EM86=E+@H@("`@("`@(&]B
M7V5N9%]C;&5A;B@I.PH@("`@("`@(&]B7W-T87)T*"D[(`H*("`@("`@("!I
M9B`H<W1R=&]U<'!E<B@D9F]R;6%T*2`]/2`B2E!'(BD@>PH@("`@("`@("`@
M("`D9V5N1F]R;6%T(#T@(DI014<B.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1G96Y&;W)M870@/2!S=')T;W5P<&5R*"1F;W)M870I.PH@("`@
M("`@('T*"B`@("`@("`@+R\@9V5N97)A=&4@=&AE(&EM86=E"B`@("`@("`@
M)&9U;F,@/2`G26UA9V4G("X@)&=E;D9O<FUA=#L*("`@("`@("`D9G5N8R@D
M:6UG*3L*("`@("`@("!);6%G941E<W1R;WDH)&EM9RD["@H@("`@("`@(&]B
M7V5N9"@I.PH@("`@("`@("1I;6%G92`](&]B7V=E=%]C;VYT96YT<R@I.PH@
M("`@("`@(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@("`O+R!S879E('1H92!G
M96YE<F%T960@:6UA9V4@=&\@9&ES:PH@("`@("`@("1T:&ES+3YS879E*"1I
M9"P@)&EM86=E+"`P+"`D=&AI<RT^8V%C:&5?9W)O=7`I.PH*("`@("`@("!R
M971U<FX@)&EM86=E.PH@("`@?2`O+R!E;F0@9G5N8R!C86-H94EM86=E"B`@
M("`*"B`@("`O*BH*("`@("H@0W)E871E(&%N(&EM86=E(&9R;VT@=&AE(&=I
M=F5N(&EM86=E(&AA;F1L97(L(&-A8VAE(&ET(&%N9"!R971U<FX@82!U<FP@
M86YD('1H92!F:6QE('!A=&@@;V8@=&AE(&EM86=E+@H@("`@*@H@("`@*B!!
M;'=A>7,@=')Y('1O(')E=')I=F4@=&AE(&EM86=E(&9R;VT@=&AE(&-A8VAE
M(&)E9F]R92!Y;W4@8V]M<'5T92!I="X*("`@("H*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@26UA9V4M240N(%5S960@87,@82!P87)T(&]F('1H92!C86-H
M92!F:6QE;F%M92X*("`@("H@("`@("`@("`@("`@("`@("`@57-E(&UD-2@I
M('1O(&=E;F5R871E(&$@(G5N:7%U92(@240@9F]R('EO=7(@:6UA9V4*("`@
M("H@("`@("`@("`@("`@("`@("`@8F%S960@;VX@8VAA<F%C=&5R:7-T:6,@
M=F%L=65S('-U8V@@87,@=&AE(&-O;&]R+"!S:7IE(&5T8RX*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@26UA9V4@:&%N9&QE<B!T;R!C<F5A=&4@=&AE(&EM
M86=E(&9R;VTN"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM86=E('1Y<&4Z
M(&=I9BP@:G!G+"!P;F<L('=B;7`N($%L<V\@=7-E9"!A<R!F:6QE;F%M92!S
M=69F:7@N"B`@("`J("`@("`@("`@("`@("`@("`@($EF(&%N('5N<W5P<&]R
M=&5D('1Y<&4@:7,@<F5Q=65S=&5D('1H92!F=6YC=&EO;G,@=')I97,@=&\@
M"B`@("`J("`@("`@("`@("`@("`@("`@(&9A;&QB86-K('1O(&$@<W5P<&]R
M=&5D('1Y<&4@8F5F;W)E('1H<F]W:6YG(&%N(&5X97!T:6]N+@H@("`@*B!`
M<F5T=7)N("`@87)R87D@(%L@9G5L;"!P871H('1O('1H92!I;6%G92!F:6QE
M+"!I;6%G92!U<FP@70H@("`@*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*("`@
M("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&-A8VAE
M26UA9V5,:6YK*"1I9"P@)B1I;6<L("1F;W)M870@/2`G<&YG)RD@>PH@("`@
M("`@(&EF("@A)&ED*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R
M<F]R("@G66]U(&UU<W0@<')O=FED92!A;B!)1"!F;W(@86YD(&EM86=E('1O
M(&)E(&-A8VAE9"$G+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D
M:60@/2`D=&AI<RT^9V5N97)A=&5)1"@D:60L("1F;W)M870I.PH@("`@("`@
M("1T>7!E<R`]($EM86=E5'EP97,H*3L*"B`@("`@("`@+R\@0VAE8VL@:68@
M=&AE(')E<75E<W1E9"!I;6%G92!T>7!E(&ES('-U<'!O<G1E9"!B>2!T:&4@
M1T0@;&EB+@H@("`@("`@("\O($EF(&YO="P@=')Y(&$@8V%L;&)A8VL@=&\@
M=&AE(&9I<G-T(&%V86EL86)L92!I;6%G92!T>7!E+@H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/FEM86=E='EP97-;)&9O<FUA=%TI('Q\("$H)'1Y<&5S
M("8@)'1H:7,M/FEM86=E='EP97-;)&9O<FUA=%TI*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YI;6%G971Y<&5S(&%S("1S=7!P;W)T960@/3X@
M)&)I=&UA<VLI(`H@("`@("`@("`@("`@("`@:68@*"1T>7!E<R`F("1B:71M
M87-K*0H@("`@("`@("`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@B5&AE
M(&)U:6QD(&EN($=$(&QI8B!D;V5S(&YO="!S=7!P;W)T('1H92!I;6%G92!T
M>7!E("1F;W)M870N($9A;&QB86-K('1O("1S=7!P;W)T960N(BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@(&5L<V4*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")(;6TL(&ES('EO
M=7(@4$A0(&)U:6QD('=I=&@@1T0@<W5P<&]R=#\@0V%N)W0@9FEN9"!A;GD@
M<W5P<&]R=&5D('1Y<&5S+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`D=7)L(#T@)'1H:7,M/F-A8VAE7W5R;"`N("1T:&ES
M+3YC86-H95]F:6QE7W!R969I>"`N("1I9#L*("`@("`@("`D9F9I;&4@/2`D
M=&AI<RT^8V]N=&%I;F5R+3YG971&:6QE;F%M92@D:60L("1T:&ES+3YC86-H
M95]G<F]U<"D["@H@("`@("`@(&EF("@D=&AI<RT^:7-#86-H960H)&ED+"`D
M=&AI<RT^8V%C:&5?9W)O=7`I("8F("%I<T5X<&ER960H)&ED+"`D=&AI<RT^
M8V%C:&5?9W)O=7`I*0H@("`@("`@("`@("!R971U<FX@87)R87DH)&9F:6QE
M+"`D=7)L*3L*"B`@("`@("`@:68@*'-T<G1O=7!P97(H)&9O<FUA="D@/3T@
M(DI01R(I('L*("`@("`@("`@("`@)&=E;D9O<FUA="`](")*4$5'(CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9V5N1F]R;6%T(#T@<W1R=&]U
M<'!E<B@D9F]R;6%T*3L*("`@("`@("!]"@H@("`@("`@("1F=6YC(#T@)TEM
M86=E)R`N("1G96Y&;W)M870["B`@("`@("`@)&9U;F,H)&EM9RP@)&9F:6QE
M*3L*"B`@("`@("`@26UA9V5$97-T<F]Y*"1I;6<I.PH*("`@("`@("!R971U
M<FX@87)R87DH)&9F:6QE+"`D=7)L*3L*("`@('T@+R\@96YD(&9U;F,@8V%C
M:&5);6%G94QI;FL*"B`@("`*("`@("\J*@H@("`@*B!3971S('1H92!54DP@
M<')E9FEX('5S960@=VAE;B!R96YD97)I;F<@2%1-3"!486=S+B`*("`@("H@
M"B`@("`J($UA:V4@<W5R92!T:&%T('1H92!54DP@;6%T8VAE<R!T:&4@8V%C
M:&4@9&ER96-T;W)Y+"`*("`@("H@;W1H97)W:7-E('EO=2=L;"!G970@8G)O
M:V5N(&QI;FMS+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9PH@("`@
M*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!S971#86-H941I
M<B@I"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V%C:&554DPH)&-A8VAE7W5R
M;"D@>PH@("`@("`@(&EF("@D8V%C:&5?=7)L("8F("<O)R`A/2!S=6)S='(H
M)&-A8VAE7W5R;"P@,2DI(`H@("`@("`@("`@("`D8V%C:&5?=7)L("X]("<O
M)SL*("`@("`@("`@("`@"B`@("`@("`@)'1H:7,M/F-A8VAE7W5R;"`]("1C
M86-H95]U<FP["B`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC('-E=$-A8VAE
M55),"@H@("`@"B`@("`O*BH*("`@("H@4V5T<R!T:&4@9&ER96-T;W)Y('=H
M97)E('1O(&-A8VAE(&=E;F5R871E9"!);6%G97,*("`@("H@"B`@("`J($!P
M87)A;2`@("!S=')I;F<*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`
M<V5E("`@("`@<V5T0V%C:&554DPH*0H@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$-A8VAE1&ER*"1C86-H95]D:7(I('L*("`@("`@("!I9B`H)&-A8VAE7V1I
M<B`F)B`G+R<@(3T@<W5B<W1R*"1C86-H95]D:7(L(#$I*0H@("`@("`@("`@
M("`D8V%C:&5?9&ER("X]("<O)SL*"B`@("`@("`@)'1H:7,M/F-A8VAE7V1I
M<B`]("1C86-H95]D:7(["B`@("`@("`@)'1H:7,M/F-O;G1A:6YE<BT^8V%C
M:&5?9&ER(#T@)&-A8VAE7V1I<CL*("`@('T@+R\@96YD(&9U;F,@<V5T0V%C
M:&5$:7(*("`@(`H@("`@"B`@("!F=6YC=&EO;B!G96YE<F%T94E$*"1V87)I
M86)L92P@)&9O<FUA="`]("=P;F<G*2!["B`@("`@(')E='5R;B!M9#4H<V5R
M:6%L:7IE*"1V87)I86)L92DI("X@)RXG("X@)&9O<FUA=#L*("`@('T@+R\@
M96YD(&9U;F,@9V5N97)A=&5)1`H@("`@"B`@("`*?2`O+R!E;F0@8VQA<W,@
M0V%C:&5?1W)A<&AI8W,*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]#86-H92]!<'!L:6-A=&EO;BYP:'``````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,S`U,@`Q,#0Q-S,V,S`P-0`P,C$S,3<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+R\*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#
M86-H92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@
M("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A
M:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@
M<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@075T:&]R<SH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U+F]R
M9SX@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!!<'!L:6-A=&EO;BYP:'`L=B`Q
M+C4@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E
M("=#86-H92YP:'`G.PH*+R\@07!P;&EC871I;VX@;&5V96P@=F%R:6%B;&5S
M"B\O"B\O(%!U<G!O<V4*+R\@5F%R:6%B;&5S('1H870@87)E('!E<G-I<V5N
M="!A8W)O<W,@86QL('5S97(@<V5S<VEO;G,L"B\O(&YO="!J=7-T(&$@<W!E
M8VEF:6,@=7-E<B!A;&$@;F]R;6%L('-E<W-I;VYS+@HO+PHO+R!5<V%G93H*
M+R\*+R\@17AA;7!L92`Q.@HO+PHO+R`D87!P("`])B!N97<@0V%C:&5?07!P
M;&EC871I;VXH*3L*+R\@)%]!4%`@/28@)&%P<"T^9V5T1&%T82@I.PHO+PHO
M+R!);B!T:&ES(&-A<V4@=&AE("1?05!0('9A<FEA8FQE(&ES(&%K:6X@=&\@
M=&AE("1?4T534TE/3B!V87)I86)L92X*+R\@268@>6]U(&%D9"]R96UO=F4@
M<W1U9F8L(&ET('=I;&P@8F4@<F5F;&5C=&5D(&EN('1H92!N97AT(')E<75E
M<W0*+R\@*&]F(&%N>2!U<V5R*2X*+R\*+R\@17AA;7!L92`R.@HO+PHO+R`D
M9F]O(#T@)U-O;64@9&%T82<["B\O("1B87(@/2`G4V]M92!O=&AE<B!D871A
M)SL*+R\*+R\@)&%P<"`])B!N97<@0V%C:&5?07!P;&EC871I;VXH*3L*+R\@
M)&%P<"T^<F5G:7-T97(H)V9O;R<I.PHO+R`D87!P+3YR96=I<W1E<B@G8F%R
M)RP@)&)A<BD[(`HO+PHO+R`D9F]O(#T@)T1I9F9E<F5N="!D871A)SL*+R\*
M+R\@26X@=&AI<R!C87-E('1H92!V87)I86)L97,@87)E(')E9VES=&5R960@
M=VET:"!T:&4@<F5G:7-T97(H*2!F=6YC=&EO;BX*+R\@5&AI<R!I<R!A:VEN
M('1O('-E<W-I;VY?<F5G:7-T97(H*2X*+R\*+R\@07,@=VET:"!S97-S:6]N
M7W)E9VES=&5R*"DL('1H92!C;VYT96YT<R!O9B!T:&4@=F%R:6%B;&4@870@
M=&AE("IE;F0J(&]F('1H90HO+R!R97%U97-T(&ES(')E9VES=&5R960@86YD
M(&YO="!A="!T:&4@<&]I;G0@;V8@<F5G:7-T<F%T:6]N+B!4:&5R969O<F4@
M:6X@=&AI<PHO+R!E>&%M<&QE+"!F;W(@=&AE("1F;V\@=F%R:6%B;&4L('1H
M92!S=')I;F<@)T1I9F9E<F5N="!D871A)R!I<R!S=&]R960@86YD(&YO="`*
M+R\@)U-O;64@9&%T82<N(%1H92!E>&-E<'1I;VX@=&\@=&AI<R!R=6QE(&ES
M(&EF('EO=2!U<V4@=&AE('-E8V]N9"!A<F=U;65N="!T;PHO+R!R96=I<W1E
M<B@I(&%S(&EN('1H92!S96-O;F0@8V%L;"!T;R!I="!A8F]V92X@5&AI<R!W
M:6QL(&-A=7-E('1H92!D871A('-U<'!L:65D"B\O(&EN('1H92!S96-O;F0@
M87)G=6UE;G0@=&\@8F4@<W1O<F5D(&%N9"!N;W0@=&AE(&-O;G1E;G1S(&%T
M('1H92!E;F0@;V8@=&AE(')E<75E<W0N"B\O"B\O($YO=&4Z($EF('EO=2!U
M<V4@=&AI<R!M971H;V0@=VET:"!R96=I<W1E<E]G;&]B86QS('1U<FYE9"!O
M;BP@=&AE('9A<FEA8FQE<R!W:6QL(&)E"B\O("`@("`@(&%U=&]M871I8V%L
M;'D@9VQO8F%L;&5D('5P;VX@<W1A<G1U<"P@*&EE+B!W:&5N('EO=2!C<F5A
M=&4@=&AE(&]B:F5C="DN"B\O"B\O($YO=&4Z($EF('EO=2!R96=I<W1E<B!A
M('9A<FEA8FQE('1H870@:7,@;F]T('-E="!W:&5N('1H92!S8W)I<'0@9FEN
M:7-H97,L(&ET('=I;&P*+R\@("`@("`@<F5G:7-T97)E9"!A<R!.54Q,+@HO
M+PHO+PHO+R`J*BH@66]U(&%R92!S=')O;F=L>2!R96-O;6UE;F1E9"!T;R!U
M<V4@;VYL>2!O;F4@;65T:&]D(&]F('1H92!T=V\@86)O=F4N("HJ*@HO+PHO
M+R`H26X@9F%C="!I9B!Y;W4@=7-E('1H92!R96=I<W1E<B@I(&9U;F-T:6]N
M('=I=&@@<F5G:7-T97)?9VQO8F%L<R!/9F8L('EO=2!H879E('1O"B\O("!U
M<V4@=&AE("1?05!0(&UE=&AO9"!T;R!G970@870@=&AE(&1A=&$I+@H*8VQA
M<W,@0V%C:&5?07!P;&EC871I;VX@97AT96YD<R!#86-H92!["@H@("`@=F%R
M("1D871A.PH@("`@=F%R("1I9#L*("`@('9A<B`D9W)O=7`["B`@("!V87(@
M)')E9VES=&5R961?=F%R<SL*"B`@("`O*BH*("`@("H@0V]N<W1R=6-T;W(*
M("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@3F%M92!O9B!C;VYT86EN
M97(@8VQA<W,*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@07)R87D@=VET:"!C
M;VYT86EN97(@8VQA<W,@;W!T:6]N<PH@("`@*B\*("`@(&9U;F-T:6]N($-A
M8VAE7T%P<&QI8V%T:6]N*"1C;VYT86EN97(@/2`G9FEL92<L("1C;VYT86EN
M97)?;W!T:6]N<R`](&%R<F%Y*"=C86-H95]D:7(G(#T^("<O=&UP+R<L("=F
M:6QE;F%M95]P<F5F:7@G(#T^("=C86-H95\G*2P@)&ED(#T@)V%P<&QI8V%T
M:6]N7W9A<B<L("1G<F]U<"`]("=A<'!L:6-A=&EO;E]C86-H92<I"B`@("![
M"B`@("`@("`@)'1H:7,M/FED("`@(#T@)&ED.PH@("`@("`@("1T:&ES+3YG
M<F]U<"`]("1G<F]U<#L*("`@("`@("`D=&AI<RT^<F5G:7-T97)E9%]V87)S
M(#T@87)R87DH*3L*"B`@("`@("`@)'1H:7,M/D-A8VAE*"1C;VYT86EN97(L
M("1C;VYT86EN97)?;W!T:6]N<RD["B`@("`@("`@)'1H:7,M/F1A=&$@/2`D
M=&AI<RT^:7-#86-H960H)'1H:7,M/FED+"`D=&AI<RT^9W)O=7`I(#\@=6YS
M97)I86QI>F4H)'1H:7,M/F=E="@D=&AI<RT^:60L("1T:&ES+3YG<F]U<"DI
M(#H@87)R87DH*3L*"B`@("`@("`@+R\@268@<F5G:7-T97)?9VQO8F%L<R!O
M;BP@9VQO8F%L(&%L;"!R96=I<W1E<F5D('9A<FEA8FQE<PH@("`@("`@(&EF
M("AI;FE?9V5T*"=R96=I<W1E<E]G;&]B86QS)RD@04Y$(&ES7V%R<F%Y*"1T
M:&ES+3YD871A*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^9&%T
M82!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@9VQO8F%L
M("0D:V5Y.PH@("`@("`@("`@("`@("`@)"1K97D@/2`D=F%L=64["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J($1E<W1R
M=6-T;W(*("`@("H*("`@("H@1V5T<R!V86QU97,@;V8@86QL(')E9VES=&5R
M960@=F%R:6%B;&5S(&%N9"!S=&]R97,@=&AE;2X@5&AE;B!C86QL<R!S879E
M*"D@=&\*("`@("H@=W)I=&4@9&%T82!A=V%Y+@H@("`@*B\*("`@(&9U;F-T
M:6]N(%]#86-H95]!<'!L:6-A=&EO;B@I"B`@("!["B`@("`@("`@+R\@1V5T
M(&-O;G1E;G1S(&]F(&%L;"!R96=I<W1E<F5D('9A<FEA8FQE<PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D=&AI<RT^<F5G:7-T97)E9%]V87)S*2!!3D0@(65M
M<'1Y*"1T:&ES+3YR96=I<W1E<F5D7W9A<G,I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3YR96=I<W1E<F5D7W9A<G,@87,@)'9A<FYA;64I('L*
M("`@("`@("`@("`@("`@(&=L;V)A;"`D)'9A<FYA;64["B`@("`@("`@("`@
M("`@("`D=&AI<RT^9&%T85LD=F%R;F%M95T@/2`D)'9A<FYA;64["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%-A=F4@=&AE(&1A=&$*
M("`@("`@("`D=&AI<RT^<V%V92@D=&AI<RT^:60L('-E<FEA;&EZ92@D=&AI
M<RT^9&%T82DL(#`L("1T:&ES+3YG<F]U<"D["B`@("!]"@H@("`@+RHJ"B`@
M("`J(')E9VES=&5R*"D*("`@("H*("`@("H@4F5G:7-T97)S(&$@=F%R:6%B
M;&4@=&\@8F4@<W1O<F5D+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!.86UE(&]F('9A<FEA8FQE('1O(')E9VES=&5R"B`@("`J($!P87)A;2`@
M("!M:7AE9"`@($]P=&EO;F%L(&1A=&$@=&\@<W1O<F4*("`@("HO"B`@("!F
M=6YC=&EO;B!R96=I<W1E<B@D=F%R;F%M92P@)&1A=&$@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D9&%T82DI('L*("`@("`@("`@("`@)'1H
M:7,M/F1A=&%;)'9A<FYA;65=(#T@)&1A=&$["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/G)E9VES=&5R961?=F%R<UM=(#T@)'9A<FYA
M;64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!U;G)E9VES=&5R
M*"D*("`@("H*("`@("H@56YR96=I<W1E<G,@82!V87)I86)L92!F<F]M(&)E
M:6YG('-T;W)E9"X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@3F%M
M92!O9B!V87)I86)L92!T;R!U;G)E9VES=&5R"B`@("`J+PH@("`@9G5N8W1I
M;VX@=6YR96=I<W1E<B@D=F%R;F%M92D*("`@('L*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/F1A=&%;)'9A<FYA;65=*2D@>PH@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^9&%T85LD=F%R;F%M95TI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("H@8VQE87(H*0H@("`@*@H@("`@*B!296UO=F5S(&%L;"!S
M=&]R960@9&%T80H@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R*"D*("`@('L*
M("`@("`@("`D=&AI<RT^9&%T82`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ
M"B`@("`J(&=E=$1A=&$H*0H@("`@*@H@("`@*B!5<V4@=&AI<R!T;R!G970@
M82!R969E<F5N8V4@=&\@=&AE(&1A=&$@=&\@;6%N:7!U;&%T90H@("`@*B!I
M;B!C86QL:6YG('-C<FEP="X@16<N("1?05!0(#TF("1O8FHM/F=E=$1A=&$H
M*3L*("`@("H*("`@("H@0')E='5R;B!M:7AE9"`@($$@<F5F97)E;F-E('1O
M('1H92!D871A"B`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$1A=&$H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&%T83L*("`@('T*?0H_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+T-A8VAE+T]U='!U=$-O;7!R97-S:6]N+G!H<```````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(Q-3,T`#$P-#$W,S8S,#`U`#`R,C8P,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@
M870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@0VAR:7-T:6%N
M(%-T;V-K97(@/&-H<F5G=4!P:&%N="YC:#X@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"G)E<75I
M<F5?;VYC92`G0V%C:&4O3W5T<'5T+G!H<"<["@HO*BH**B!#86-H92!U<VEN
M9R!/=71P=70@0G5F9F5R:6YG(&%N9"!C;VYT;F5T("AG>BD@8V]M<')E<W-I
M;VXN"BHJ(%5S86=E(&5X86UP;&4Z"BH**B`@+R\@<&QA8V4@=&AI<R!S;VUE
M=VAE<F4@:6X@82!C96YT<F%L(&-O;F9I9R!F:6QE"BH@(&1E9FEN92A#04-(
M15]35$]204=%7T-,05-3+"`G9FEL92<I.PHJ("`O+R!F:6QE('-T;W)A9V4@
M;F5E9',@82!D:7(@=&\@<'5T('1H92!C86-H92!F:6QE<PHJ("!D969I;F4H
M0T%#2$5?1$E2+"`G+W9A<B]T;7`O)RD["BH**B`@+R\@9V5T(&$@8V%C:&4@
M;V)J96-T"BH@("1C86-H92`](&YE=R!#86-H95]/=71P=70H0T%#2$5?4U1/
M4D%'15]#3$%34RP@87)R87DH)V-A8VAE7V1I<B<@/3X@0T%#2$5?1$E2*2D[
M"BH**B`@:68@*"$H)&-O;G1E;G0@/2`D8V%C:&4M/G-T87)T*"1C86-H92T^
M9V5N97)A=&5)1"@D4D5154535%]54DDI*2DI('L**B`@("!P<FEN="`B:&5L
M;&\@=V]R;&0B.PHJ("`@("1C86-H92T^96YD4')I;G0H*S$P,#`I.PHJ("!]
M"BH@(&5L<V4@>PHJ("`@("1C86-H92T^<')I;G1#;VYT96YT*"D["BH@('T*
M*@HJ("`@3U(**@HJ("!I9B`H*"1C;VYT96YT(#T@)&-A8VAE+3YS=&%R="@D
M8V%C:&4M/F=E;F5R871E240H)%)%455%4U1?55))*2DI*2!["BH@("`@)&-A
M8VAE+3YP<FEN=$-O;G1E;G0H*3L**B`@("!D:64H*3L**B`@?0HJ("`@('!R
M:6YT(")H96QL;R!W;W)L9"(["BH@("`@)&-A8VAE+3YE;F10<FEN="@K,3`P
M,"D["BH**@HJ($)A<V5D('5P;VX@82!C87-E('-T=61Y(&9R;VT@0VAR:7-T
M:6%N(%-T;V-K97(@86YD(&EN<W!I<F5D(&)Y(&IP8V%C:&4N"BH**B!`=F5R
M<VEO;B`@)$ED.B!/=71P=71#;VUP<F5S<VEO;BYP:'`L=B`Q+C<@,C`P,R\P
M,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`HJ($!A=71H;W(@("!5;&8@5V5N9&5L
M(#QU;&8N=V5N9&5L0'!H<&1O8RYD93XL($-H<FES=&EA;B!3=&]C:V5R(#QC
M:')E9W5`<&AA;G0N8V@^"BH@0&%C8V5S<R`@('!U8FQI8PHJ($!P86-K86=E
M("!#86-H90HJ+PIC;&%S<R!#86-H95]/=71P=71#;VUP<F5S<VEO;B!E>'1E
M;F1S($-A8VAE7T]U='!U="!["B`@("`*("`@("\J*@H@("`@*B!%;F-O9&EN
M9RP@=VAA="!T:&4@=7-E<B`H:71S(&)R;W=S97(I(&]F('EO=7(@=V5B<VET
M92!A8V-E<'1S"B`@("`J(`H@("`@*B`B875T;R(@<W1A;F1S(&9O<B!T97-T
M('5S:6YG("1?4T525D526R=(5%107T%#0T505%]%3D-/1$E.1R==*"1(5%10
M7T%#0T505%]%3D-/1$E.1RDN"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@
M("`@*B!`<V5E("!#86-H95]/=71P=71#;VUP<F5S<VEO;B@I+"!S971%;F-O
M9&EN9R@I"B`@("`J+PH@("`@=F%R("1E;F-O9&EN9R`]("=A=71O)SL*(`H@
M("`@"B`@("`O*BH*("`@("H@365T:&]D('5S960@9F]R(&-O;7!R97-S:6]N
M"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B!`<V5E("!I<T-O;7!R
M97-S960H*0H@("`@*B\@"B`@("!V87(@)&-O;7!R97-S:6]N(#T@)R<["@H@
M("`@"B`@("`O*BH*("`@("H@4V5T<R!T:&4@<W1O<F%G92!D971A:6QS(&%N
M9"!T:&4@8V]N=&5N="!E;F-O9&EN9R!U<V5D("AI9B!N;W0@875T;V1E=&5C
M=&EO;BD*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@($YA;64@;V8@
M8V]N=&%I;F5R(&-L87-S"B`@("`J($!P87)A;2`@("!A<G)A>2`@($%R<F%Y
M('=I=&@@8V]N=&%I;F5R(&-L87-S(&]P=&EO;G,*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@8V]N=&5N="!E;F-O9&EN9R!M;V1E("T@875T;R`]/B!T97-T
M('=H:6-H(&5N8V]D:6YG('1H92!U<V5R(&%C8V5P=',*("`@("HO("`@(`H@
M("`@9G5N8W1I;VX@0V%C:&5?3W5T<'5T0V]M<')E<W-I;VXH)&-O;G1A:6YE
M<BP@)&-O;G1A:6YE<E]O<'1I;VYS(#T@)R<L("1E;F-O9&EN9R`]("=A=71O
M)RD@>PH@("`@"B`@("`@("`@)'1H:7,M/G-E=$5N8V]D:6YG*"1E;F-O9&EN
M9RD["B`@("`@("`@)'1H:7,M/D-A8VAE*"1C;VYT86EN97(L("1C;VYT86EN
M97)?;W!T:6]N<RD["B`@("`@("`@"B`@("!]("\O(&5N9"!C;VYS=')U8W1O
M<@H*("`@(`H@("`@+RHJ"B`@("`J($-A;&P@<&%R96YT(&1E8V]N<W1R=6-T
M;W(N"B`@("`J+PH@("`@9G5N8W1I;VX@7T-A8VAE7T]U='!U=$-O;7!R97-S
M:6]N*"D@>PH@("`@("`@("1T:&ES+3Y?0V%C:&4H*3L*("`@('T@+R\@96YD
M(&1E8V]N<W1R=6-T;W(*("`@(`H*("`@(&9U;F-T:6]N(&=E;F5R871E240H
M)'9A<FEA8FQE*2!["B`@("`@("`@"B`@("`@("`@)'1H:7,M/F-O;7!R97-S
M:6]N(#T@)'1H:7,M/F=E=$5N8V]D:6YG*"D["B`@("`@("`@"B`@("`@("`@
M<F5T=7)N(&UD-2AS97)I86QI>F4H)'9A<FEA8FQE*2`N('-E<FEA;&EZ92@D
M=&AI<RT^8V]M<')E<W-I;VXI*3L*("`@('T@+R\@96YD(&=E;F5R871E240*
M"B`@("`*("`@(&9U;F-T:6]N(&=E="@D:60L("1G<F]U<"D@>PH@("`@("`@
M("1T:&ES+3YC;VYT96YT(#T@)R<["B`@("`@("`@"B`@("`@("`@:68@*"$D
M=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M(`H@("`@("`@(&EF("@D=&AI<RT^:7-#86-H960H)&ED+"`D9W)O=7`I("8F
M("$D=&AI<RT^:7-%>'!I<F5D*"1I9"P@)&=R;W5P*2D*("`@("`@("`@("`@
M)'1H:7,M/F-O;G1E;G0@/2`D=&AI<RT^;&]A9"@D:60L("1G<F]U<"D["B`@
M("`@("`@("`@(`H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&5N=#L*("`@
M('T@+R\@96YD(&9U;F,@9V5T"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(%-T
M;W!S('1H92!O=71P=70@8G5F9F5R:6YG+"!S879E<R!I="!T;R!T:&4@8V%C
M:&4@86YD(')E='5R;G,@=&AE(%]C;VUP<F5S<V5D7R!C;VYT96YT+B`*("`@
M("H*("`@("H@268@>6]U(&YE960@=&AE('5N8V]M<')E<W-E9"!C;VYT96YT
M(&9O<B!F=7)T:&5R('!R;V-E<W-I;VX@8F5F;W)E"B`@("`J(&ET)W,@<V%V
M960@:6X@=&AE(&-A8VAE('5S92!E;F1'970H*2X@96YD1V5T*"D@9&]E<R!?
M;F]T(&-O;7!R97-S7RX*("`@("HO("`@(`H@("`@9G5N8W1I;VX@96YD*"1E
M>'!I<F4@/2`P+"`D=7-E<F1A=&$@/2`G)RD@>PH@("`@("`@("1C;VYT96YT
M(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@("`@;V)?96YD7V-L96%N*"D[
M"@H@("`@("`@("\O('-T;W)E(&EN('1H92!C86-H90H@("`@("`@(&EF("@D
M=&AI<RT^8V%C:&EN9RD@>PH@("`@("`@("`@("`D=&AI<RT^97AT4V%V92@D
M=&AI<RT^;W5T<'5T7VED+"`D8V]N=&5N="P@)'5S97)D871A+"`D97AP:7)E
M+"`D=&AI<RT^;W5T<'5T7V=R;W5P*3L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YC;VYT96YT.R`@("`@("`@("`@("`@("`*("`@("`@("!]"B`@("`@
M("`@("`@(`H@("`@("`@(')E='5R;B`D8V]N=&5N=#L@("`@("`@(`H@("`@
M?2`O+R!E;F0@9G5N8R!E;F0H*0H@("`@"B`@("`*("`@(&9U;F-T:6]N(&5N
M9%!R:6YT*"1E>'!I<F4@/2`P+"`D=7-E<F1A=&$@/2`G)RD@>PH@("`@("`@
M("1T:&ES+3YP<FEN=$-O;G1E;G0H)'1H:7,M/F5N9"@D97AP:7)E+"`D=7-E
M<F1A=&$I*3L*("`@('T@+R\@96YD(&9U;F,@96YD4')I;G0*"B`@("`*("`@
M("\J*@H@("`@*B!3879E<R!T:&4@9VEV96X@9&%T82!T;R!T:&4@8V%C:&4N
M"B`@("`J(`H@("`@*B\@("`*("`@(&9U;F-T:6]N(&5X=%-A=F4H)&ED+"`D
M8V%C:&5D871A+"`D=7-E<F1A=&$L("1E>'!I<F5S(#T@,"P@)&=R;W5P(#T@
M)V1E9F%U;'0G*2!["B`@("`@("`@:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@
M("`@("`@("`@<F5T=7)N('1R=64["@H@("`@("`@(&EF("@D=&AI<RT^8V]M
M<')E<W-I;VXI('L@("`@("`@("`@("`*("`@("`@("`@("`@"B`@("`@("`@
M("`@("1L96X@/2!S=')L96XH)&-A8VAE9&%T82D[("`@("`@("`@("`@"B`@
M("`@("`@("`@("1C<F,@/2!C<F,S,B@D8V%C:&5D871A*3L*("`@("`@("`@
M("`@)&-A8VAE9&%T82`](&=Z8V]M<')E<W,H)&-A8VAE9&%T82P@.2D["B`@
M("`@("`@("`@("1T:&ES+3YC;VYT96YT(#T@<W5B<W1R*"1C86-H961A=&$L
M(#`L('-T<FQE;B@D8V%C:&5D871A*2`M(#0I("X@<&%C:R@G5B<L("1C<F,I
M("X@<&%C:R@G5B<L("1L96XI.PH@("`@("`@("`@("`*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`*("`@("`@("`@("`@)'1H:7,M/F-O;G1E;G0@
M/2`D8V%C:&5D871A.PH@("`@("`@("`@("`*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YC;VYT86EN97(M/G-A=F4H)&ED+"`D=&AI<RT^8V]N
M=&5N="P@)&5X<&ER97,L("1G<F]U<"P@)'5S97)D871A*3L*("`@('T@+R\@
M96YD(&9U;F,@97AT4V%V90H@("`@"B`@("`O*BH*("`@("H@4V5N9',@=&AE
M(&-O;7!R97-S960@9&%T82!T;R!T:&4@=7-E<BX*("`@("H@"B`@("`J($!P
M87)A;2`@("!S=')I;F<*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\@
M("`@"B`@("!F=6YC=&EO;B!P<FEN=$-O;G1E;G0H)&-O;G1E;G0@/2`G)RD@
M>PH@("`@("`@("1S97)V97(@/2`F)'1H:7,M/E]I;7!O<G1';&]B86Q687)I
M86)L92@B<V5R=F5R(BD["@H@("`@("`@(&EF("@G)R`]/2`D8V]N=&5N="D*
M("`@("`@("`@("`@)&-O;G1E;G0@/2`F)'1H:7,M/F-O;G1A:6YE<BT^8V%C
M:&5D871A.PH@("`@("`@("`@("`@("`@(`H@("`@("`@(&EF("@D=&AI<RT^
M8V]M<')E<W-I;VX@)B8@)'1H:7,M/F-A8VAI;F<I('L*("`@"B`@("`@("`@
M("`@("1E=&%G(#T@)U!%05(M0V%C:&4M)R`N(&UD-2AS=6)S='(H)&-O;G1E
M;G0L("TT,"DI.PH@("`@("`@("`@("!H96%D97(H(D5486<Z("1E=&%G(BD[
M"B`@("`@("`@("`@(&EF("AI<W-E="@D<V5R=F5R6R=(5%107TE&7TY/3D5?
M34%40T@G72D@)B8@<W1R<W1R*'-T<FEP<VQA<VAE<R@D<V5R=F5R6R=(5%10
M7TE&7TY/3D5?34%40T@G72DL("1E=&%G*2D@>PH@("`@("`@("`@("`@("`@
M+R\@;F]T(&UO9&EF:65D"B`@("`@("`@("`@("`@("!H96%D97(H)TA45%`O
M,2XP(#,P-"<I.PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`*("`@("`@("`@("`@("`@("\O(&-L:65N="!A8V-E
M<'!T<R!S;VUE(&5N8V]D:6YG("T@<V5N9"!H96%D97)S("8@9&%T80H@("`@
M("`@("`@("`@("`@:&5A9&5R*")#;VYT96YT+45N8V]D:6YG.B![)'1H:7,M
M/F-O;7!R97-S:6]N?2(I.PH@("`@("`@("`@("`@("`@:&5A9&5R*"=687)Y
M.B!!8V-E<'0M16YC;V1I;F<G*3L*("`@("`@("`@("`@("`@('!R:6YT(")<
M>#%F7'@X8EQX,#A<>#`P7'@P,%QX,#!<>#`P7'@P,"(["B`@("`@("`@("`@
M('T*("`@("`@("`*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@9&EE*"1C
M;VYT96YT*3L*("`@('T@+R\@96YD(&9U;F,@<')I;G1#;VYT96YT"B`@("`*
M("`@(`H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(&5N8V]D:6YG(&UE=&AO
M9"!O9B!T:&4@8W5R<F5N="!D871A<V5T+B`*("`@("H*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PH@("`@*B!`<F5T=7)N("`@<W1R:6YG("!%;7!T>2!S=')I
M;F<@*'=H:6-H(&5V86QU871E<R!T;R!F86QS92D@;65A;G,@;F\@8V]M<')E
M<W-I;VX*("`@("HO"B`@("!F=6YC=&EO;B!I<T-O;7!R97-S960H*2!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YC;VUP<F5S<VEO;CL*("`@('T@+R\@96YD
M(&9U;F,@:7-#;VUP<F5S<V5D"@H@("`@+RHJ"B`@("`J(%-E=',@=&AE(&5N
M8V]D:6YG('1O(&)E('5S960N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`B875T;R(@;65A;G,@875T;V1E=&5C="!F;W(@979E<GD@8VQI96YT
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@("1E;F-O
M9&EN9PH@("`@*B\*("`@(&9U;F-T:6]N('-E=$5N8V]D:6YG*"1E;F-O9&EN
M9R`]("=A=71O)RD@>PH@("`@("`@("1T:&ES+3YE;F-O9&EN9R`]("1E;F-O
M9&EN9SL*("`@('T@+R\@96YD(&9U;F,@<V5T16YC;V1I;F<*("`@(`H@("`@
M"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@96YC;V1I;F<@=&\@8F4@=7-E
M9"!F;W(@=&AE(&1A=&$@=')A;G-M:7-S:6]N('1O('1H92!C;&EE;G0N"B`@
M("`J"B`@("`J($!S964@("`@("!S971%;F-O9&EN9R@I"B`@("`J+R`@("`*
M("`@(&9U;F-T:6]N(&=E=$5N8V]D:6YG*"D@>PH@("`@("`@("1S97)V97(@
M/2`F)'1H:7,M/E]I;7!O<G1';&]B86Q687)I86)L92@B<V5R=F5R(BD["@H@
M("`@("`@("\O(&5N8V]D:6YG('-E="!B>2!U<V5R("`@(`H@("`@("`@(&EF
M("@G875T;R<@(3T@)'1H:7,M/F5N8V]D:6YG*0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F5N8V]D:6YG.PH@("`@("`@(`H@("`@("`@("\O(&-H96-K
M('=H870@=&AE(&-L:65N="!A8V-E<'1S"B`@("`@("`@:68@*&9A;'-E("$]
M/2!S=')P;W,H)'-E<G9E<ELG2%144%]!0T-%4%1?14Y#3T1)3D<G72P@)W@M
M9WII<"<I*0H@("`@("`@("`@("!R971U<FX@)W@M9WII<"<["B`@("`@("`@
M:68@*&9A;'-E("$]/2!S=')P;W,H)'-E<G9E<ELG2%144%]!0T-%4%1?14Y#
M3T1)3D<G72P@)V=Z:7`G*2D*("`@("`@("`@("`@<F5T=7)N("=G>FEP)SL*
M("`@("`@("`@("`@"B`@("`@("`@+R\@;F\@8V]M<')E<W-I;VX*("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC(&=E=$5N
M8V]D:6YG"@H@("`@+R\@>WM[(%]I;7!O<G1';&]B86Q687)I86)L92@I"@H@
M("`@+RHJ"B`@("`@*B!);7!O<G0@=F%R:6%B;&5S(&9R;VT@<W!E8VEA;"!N
M86UE<W!A8V5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H@0'!A<F%M('-T<FEN9R!4>7!E(&]F('9A<FEA8FQE("AS97)V97(L('-E
M<W-I;VXL('!O<W0I"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?:6UP;W)T1VQO8F%L5F%R:6%B;&4H)'9A<FEA8FQE*2`*
M("`@('L*("`@("`@"B`@("`@("`@)'9A<B`](&YU;&P["@H@("`@("`@('-W
M:71C:"`H<W1R=&]L;W=E<B@D=F%R:6%B;&4I*2!["@H@("`@("`@("`@("!C
M87-E(")S97)V97(B(#H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D7U-%
M4E9%4BDI('L*("`@("`@("`@("`@("`@("`@("`D=F%R(#T@)B1?4T525D52
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=F%R(#T@)B1'3$]"04Q36R=(5%107U-%4E9%4E]605)3)UT["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@(G-E<W-I;VXB(#H*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D7U-%4U-)3TXI*2!["B`@("`@("`@("`@("`@("`@("`@)'9A<B`]("8D
M7U-%4U-)3TX["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1V87(@/2`F)$=,3T)!3%-;)TA45%!?4T534TE/3E]605)3
M)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@(G!O<W0B(#H*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D7U!/4U0I*2!["B`@("`@("`@("`@("`@("`@("`@)'9A<B`]
M("8D7U!/4U0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1V87(@/2`F)$=,3T)!3%-;)TA45%!?4$]35%]605)3)UT[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'9A<CL*("`@('T@"@H@("`@+R\@
M?7T*?2`O+R!E;F0@8VQA<W,@3W5T<'5T0V]M<')E<W-I;VX*/SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O0V%C:&4O1G5N8W1I;VXN<&AP````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3$P-S4`,3`T,3<S-C,P,#4`,#(P-C0T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@
M0V%C:&4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@
M("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V
M86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<G,Z(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N
M+6)E<F=M86YN+F1E/B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@1G5N8W1I;VXN<&AP+'8@,2XV
M(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP("0*"G)E<75I<F5?;VYC92`G
M0V%C:&4N<&AP)SL*"B\J*@HJ($9U;F-T:6]N7T-A8VAE"BH**B!0=7)P;W-E
M.@HJ"BH@("!#86-H:6YG('1H92!R97-U;'0@86YD(&]U='!U="!O9B!F=6YC
M=&EO;G,N"BH**B!%>&%M<&QE.@HJ"BH@("!R97%U:7)E7V]N8V4@)T-A8VAE
M+T9U;F-T:6]N+G!H<"<["BH**B`@(&-L87-S(&9O;R!["BH@("`@(&9U;F-T
M:6]N(&)A<B@D=&5S="D@>PHJ("`@("`@(&5C:&\@(F9O;SHZ8F%R*"1T97-T
M*3QB<CXB.PHJ("`@("!]"BH@("!]"BH**B`@(&-L87-S(&)A<B!["BH@("`@
M(&9U;F-T:6]N(&9O;V)A<B@D;V)J96-T*2!["BH@("`@("`@96-H;R`G)"<N
M)&]B:F5C="XG+3YF;V]B87(H)RXD;V)J96-T+B<I/&)R/B<["BH@("`@('T*
M*B`@('T**@HJ("`@)&)A<B`](&YE=R!B87(["BH**B`@(&9U;F-T:6]N(&9O
M;V)A<B@I('L**B`@("`@96-H;R`G9F]O8F%R*"DG.PHJ("`@?0HJ"BH@("`D
M8V%C:&4@/2!N97<@0V%C:&5?1G5N8W1I;VXH*3L**@HJ("`@)&-A8VAE+3YC
M86QL*"=F;V\Z.F)A<B<L("=T97-T)RD["BH@("`D8V%C:&4M/F-A;&PH)V)A
M<BT^9F]O8F%R)RP@)V)A<B<I.PHJ("`@)&-A8VAE+3YC86QL*"=F;V]B87(G
M*3L**@HJ($YO=&4Z"BH@"BH@("!9;W4@8V%N;F]T(&-A8VAE(&5V97)Y(&9U
M;F-T:6]N+B!9;W4@<VAO=6QD(&]N;'D@8V%C:&4@"BH@("!F=6YC=&EO;G,@
M=&AA="!O;FQY(&1E<&5N9"!O;B!T:&5I<B!A<F=U;65N=',@86YD(&1O;B=T
M('5S90HJ("`@9VQO8F%L(&]R('-T871I8R!V87)I86)L97,L(&1O;B=T(')E
M;'D@;VX@9&%T86)A<V4@<75E<FEE<R!O<B`**B`@(&9I;&5S+"!A;F0@<V\@
M;VXN"BH@"BH@0&%U=&AO<B`@("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B
M0'-E8F%S=&EA;BUB97)G;6%N;BYD93X**B!`;6]D=6QE("`@("`@($9U;F-T
M:6]N7T-A8VAE"BH@0&UO9'5L96=R;W5P("!&=6YC=&EO;E]#86-H90HJ($!P
M86-K86=E("`@("`@0V%C:&4**B!`=F5R<VEO;B`@("`@("12979I<VEO;CH@
M,2XV("0**B!`86-C97-S("`@("`@('!U8FQI8PHJ+PIC;&%S<R!#86-H95]&
M=6YC=&EO;B!E>'1E;F1S($-A8VAE('L*("`@('9A<B`D97AP:7)E<SL*"B`@
M("`O*BH*("`@("H@0V]N<W1R=6-T;W(*("`@("H*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@3F%M92!O9B!C;VYT86EN97(@8VQA<W,*("`@("H@0'!A<F%M
M("`@(&%R<F%Y("`@07)R87D@=VET:"!C;VYT86EN97(@8VQA<W,@;W!T:6]N
M<PH@("`@*B!`<&%R86T@("`@:6YT96=E<B!.=6UB97(@;V8@<V5C;VYD<R!F
M;W(@=VAI8V@@=&\@8V%C:&4*("`@("HO"B`@("!F=6YC=&EO;B!#86-H95]&
M=6YC=&EO;B@D8V]N=&%I;F5R("`]("=F:6QE)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C;VYT86EN97)?;W!T:6]N<R`](&%R<F%Y*"=C86-H
M95]D:7(G("`@("`@(#T^("<N)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:6QE;F%M95]P<F5F
M:7@G(#T^("=C86-H95\G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97AP:7)E<R`](#,V,#`*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*0H@("`@>PH@("`@("`D=&AI<RT^0V%C:&4H)&-O;G1A:6YE
M<BP@)&-O;G1A:6YE<E]O<'1I;VYS*3L*("`@("`@)'1H:7,M/F5X<&ER97,@
M/2`D97AP:7)E<SL@("`@("`*("`@('T*"B`@("`O*BH*("`@("H@4$5!4BU$
M96-O;G-T<G5C=&]R"B`@("`J($-A;&P@9&5C;VYS=')U8W1O<B!O9B!P87)E
M;G0*("`@("HO"B`@("!F=6YC=&EO;B!?0V%C:&5?1G5N8W1I;VXH*2!["B`@
M("`@("`@)'1H:7,M/E]#86-H92@I.PH@("`@?0H*("`@("\J*@H@("`@*B!#
M86QL<R!A(&-A8VAE86)L92!F=6YC=&EO;B!O<B!M971H;V0N"B`@("`J"B`@
M("`J($!R971U<FX@;6EX960@)')E<W5L=`H@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@*B\*("`@(&9U;F-T:6]N(&-A;&PH*2!["B`@("`@("`@+R\@9V5T
M(&%R9W5M96YT<PH@("`@("`@("1A<F=U;65N=',@/2!F=6YC7V=E=%]A<F=S
M*"D["@H@("`@("`@("\O(&=E;F5R871E(&-A8VAE(&ED"B`@("`@("`@)&ED
M(#T@;60U*'-E<FEA;&EZ92@D87)G=6UE;G1S*2D["@H@("`@("`@("\O('%U
M97)Y(&-A8VAE"B`@("`@("`@)&-A8VAE9%]O8FIE8W0@/2`D=&AI<RT^9V5T
M*"1I9"P@)V9U;F-T:6]N7V-A8VAE)RD["@H@("`@("`@(&EF("@D8V%C:&5D
M7V]B:F5C="`A/2!.54Q,*2!["B`@("`@("`@("`@("\O(&-A8VAE(&AI=#H@
M<F5T=7)N(&-A8VAE9"!O=71P=70@86YD(')E<W5L=`H*("`@("`@("`@("`@
M)&]U='!U="`]("1C86-H961?;V)J96-T6S!=.PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)&-A8VAE9%]O8FIE8W1;,5T["@H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\O(&-A8VAE(&UI<W,Z(&-A;&P@9G5N8W1I;VXL('-T;W)E
M(&]U='!U="!A;F0@<F5S=6QT(&EN(&-A8VAE"@H@("`@("`@("`@("!O8E]S
M=&%R="@I.PH@("`@("`@("`@("`D=&%R9V5T(#T@87)R87E?<VAI9G0H)&%R
M9W5M96YT<RD["@H@("`@("`@("`@("`O+R!C;&%S<VYA;64Z.G-T871I8TUE
M=&AO9`H@("`@("`@("`@("!I9B`H<W1R<W1R*"1T87)G970L("<Z.B<I*2![
M"B`@("`@("`@("`@("`@("!L:7-T*"1C;&%S<RP@)&UE=&AO9"D@/2!E>'!L
M;V1E*"<Z.B<L("1T87)G970I.PH*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2!C86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@D8VQA<W,L("1M971H;V0I
M+"`D87)G=6UE;G1S*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@
M;V)J96-T+3YM971H;V0*("`@("`@("`@("`@96QS96EF("AS=')S='(H)'1A
M<F=E="P@)RT^)RDI('L*("`@("`@("`@("`@("`@(&QI<W0H)&]B:F5C="P@
M)&UE=&AO9"D@/2!E>'!L;V1E*"<M/B<L("1T87)G970I.PH@("`@("`@("`@
M("`@("`@9VQO8F%L("0D;V)J96-T.PH*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2!C86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@D)&]B:F5C="P@)&UE
M=&AO9"DL("1A<F=U;65N=',I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!F=6YC=&EO;@H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2!C86QL7W5S97)?9G5N8U]A<G)A>2@D=&%R9V5T+"`D
M87)G=6UE;G1S*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]U='!U
M="`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@("`@("!O8E]E;F1?8VQE
M86XH*3L*"B`@("`@("`@("`@("1T:&ES+3YS879E*"1I9"P@87)R87DH)&]U
M='!U="P@)')E<W5L="DL("1T:&ES+3YE>'!I<F5S+"`G9G5N8W1I;VY?8V%C
M:&4G*3L*("`@("`@("!]"@H@("`@("`@(&5C:&\@)&]U='!U=#L*("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@('T*?0H_/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T-A8VAE+T5R<F]R+G!H<```````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#4S`#$P-#$W,S8S,#`U`#`R
M,#$U,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!0
M14%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC
M96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H
M<&1O8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($5R<F]R+G!H<"QV
M(#$N,R`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"@IR97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL*"B\J*@HJ($-A8VAE($5R<F]R(&-L87-S"BH@"BH@
M0'!A8VMA9V4@0V%C:&4**B\*8VQA<W,@0V%C:&5?17)R;W(@97AT96YD<R!0
M14%27T5R<F]R('L*"@H@("\J*@H@("H@4')E9FEX(&]F(&%L;"!E<G)O<B!M
M97-S86=E<RX*("`J(`H@("H@0'9A<B`@<W1R:6YG"B`@*B\*("!V87(@)&5R
M<F]R7VUE<W-A9V5?<')E9FEX(#T@)T-A8VAE+45R<F]R.B`G.PH@(`H@("\J
M*@H@("H@0W)E871E<R!A;B!C86-H92!E<G)O<B!O8FIE8W0N"B`@*B`*("`J
M($!P87)A;2`@<W1R:6YG("!E<G)O<B!M97-S86=E"B`@*B!`<&%R86T@('-T
M<FEN9R`@9FEL92!W:&5R92!T:&4@97)R;W(@;V-C=7)E9`H@("H@0'!A<F%M
M("!S=')I;F<@(&QI;F5N=6UB97(@=VAE<F4@=&AE(&5R<F]R(&]C8W5R960*
M("`J+PH@(&9U;F-T:6]N($-A8VAE7T5R<F]R*"1M<V<L("1F:6QE(#T@7U]&
M24Q%7U\L("1L:6YE(#T@7U],24Y%7U\I('L*("`@(`H@("`@)'1H:7,M/E!%
M05)?17)R;W(H<W!R:6YT9B@B)7,@6R5S(&]N(&QI;F4@)61=+B(L("1M<V<L
M("1F:6QE+"`D;&EN92DI.PH@("`@"B`@?2`O+R!E;F0@9G5N8R!#86-H95]%
M<G)O<@H@(`I]("\O(&5N9"!C;&%S<R!#86-H95]%<G)O<@H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(N<&AP````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`S,C,W-``Q,#0Q-S,V,S`P-0`P,C$P,#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z
M.B!#86-H92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N
M9&4^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@
M(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E
M/B`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!#:')I<W1I86X@4W1O
M8VME<B`\8VAR96=U0'!H86YT+F-H/B`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M($-O;G1A:6YE<BYP:'`L=B`Q+C0@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%
M>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H92]%<G)O<BYP:'`G.PH*+RHJ"BH@
M0V]M;6]N(&)A<V4@8VQA<W,@;V8@86QL(&-A8VAE('-T;W)A9V4@8V]N=&%I
M;F5R+@HJ(`HJ(%1O('-P965D('5P('1H:6YG<R!W92!D;R!A('!R96QO860@
M>6]U('-H;W5L9"!K;F]W(&%B;W5T+"!O=&AE<G=I<V4@:70@;6EG:'0@"BH@
M<&QA>2!Y;W4@82!T<FEC:RX@5&AE($-A8VAE(&-O;G1R;VQL97(@8VQA<W-E
M<R`H0V%C:&4O0V%C:&4L($-A8VAE+T]U='!U="P@+BXN*0HJ('5S=6%L;'D@
M9&\@<V]M971H:6YG(&QI:V4@:7,@*&ES0V%C:&5D*"1I9"D@)B8@(6ES17AP
M:7)E9"@D:60I*2!R971U<FX@)&-O;G1A:6YE<BT^;&]A9"@D:60I+@HJ(&EF
M('EO=2!I;7!L96UE;G0@:7-#86-H960H*2P@:7-%>'!I<F5D*"D@86YD(&QO
M860H*2!S=')A:6=H="!A:&5A9"P@96%C:"!O9B!T:&ES(`HJ(&9U;F-T:6]N
M<R!W:6QL(')E<W5L="!I;B!A('-T;W)A9V4@;65D:75M("AD8BP@9FEL92PN
M+BXI(&%C8V5S<RX@5&AI<R!G96YE<F%T97,@=&]O(&UU8V@@;&]A9"X@"BH@
M3F]W+"!A('-I;7!L92!S<&5C=6QA=&EV92!P<F5L;V%D('-H;W5L9"!S879E
M<R!T:6UE(&EN(&UO<W0@8V%S97,N(%=H96YE=F5R(`HJ(&]N92!O9B!T:&4@
M;65N=&EO;F5D(&UE=&AO9',@:7,@:6YV;VME9"!W92!P<F5L;V%D('1H92!C
M86-H960@9&%T87-E="!I;G1O(&-L87-S('9A<FEA8FQE<RX**B!4:&%T(&UE
M86YS('1H870@=V4@:&%V92!O;FQY(&]N92!S=&]R86=E(&UE9&EU;2!A8V-E
M<W,@9F]R('1H92!S97%U96YC90HJ("`H:7-#86-H960H)&ED*2`F)B`A:7-%
M>'!I<F5D*"1I9"DI(')E='5R;B`D8V]N=&%I;F5R+3YL;V%D*"1I9"DN"BH@
M5&AE(&)A9"!T:&EN9R!I<R!T:&%T('1H92!P<F5L;V%D960@9&%T82!M:6=H
M="!B92!O=71D871E9"!M96%N=VAI;&4L('=H:6-H(&ES(`HJ('5N;&EK96QY
M(&)U="!F;W(@>6]U('!O=V5R('5S97)S+"!B92!W87)N960N($EF('EO=2!D
M;R!N;W0@=V%N="!T:&4@<')E;&]A9"`**B!Y;W4@<VAO=6QD('-W:71C:"!I
M="!O9F8@8GD@<V5T=&EN9R!T:&4@8VQA<W,@=F%R:6%B;&4@)'!R96QO860@
M=&\@9F%L<V4N($%N>7=A>2P@=&AI<R!I<R`**B!N;W0@<F5C;VUM96YD960A
M"BH@"BH@0&%U=&AO<B`@(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C
M+F1E/@HJ($!V97)S:6]N("`D260Z($-O;G1A:6YE<BYP:'`L=B`Q+C0@,C`P
M,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`HJ($!P86-K86=E("!#86-H90HJ
M($!A8V-E<W,@("!P=6)L:6,**B!`86)S=')A8W0**B\*8VQA<W,@0V%C:&5?
M0V]N=&%I;F5R('L*"B`@("`O*BH*("`@("H@1FQA9R!I;F1I8V%T:6YG('=H
M971E<B!T;R!P<F5L;V%D(&1A=&%S971S+@H@("`@*@H@("`@*B!3964@=&AE
M(&-L87-S(&1E<V-R:7!T:6]N(&9O<B!M;W)E(&1E=&%I;',N"B`@("`J"B`@
M("`J($!V87(@(&)O;VQE86X*("`@("HO"B`@("!V87(@)'!R96QO860@/2!T
M<G5E.PH*("`@("\J*@H@("`@*B!)1"!O9B!A('!R96QO861E9"!D871A<V5T
M"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D:60@
M/2`G)SL*"B`@("`O*BH*("`@("H@0V%C:&4@9W)O=7`@;V8@82!P<F5L;V%D
M960@9&%T87-E=`H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@
M("!V87(@)&=R;W5P(#T@)R<["@H@("`@+RHJ"B`@("`J($5X<&ER871I;VX@
M=&EM97-T86UP(&]F(&$@<')E;&]A9&5D(&1A=&%S970N"B`@("`J(`H@("`@
M*B!`=F%R("!I;G1E9V5R(#`@;65A;G,@;F5V97(L(&5N9&QE<W,*("`@("HO
M"B`@("!V87(@)&5X<&ER97,@/2`P.PH*("`@("\J*@H@("`@*B!686QU92!O
M9B!A('!R96QO861E9"!D871A<V5T+@H@("`@*B`*("`@("H@0'9A<B`@<W1R
M:6YG"B`@("`J+PH@("`@=F%R("1C86-H961A=&$@/2`G)SL*"B`@("`O*BH*
M("`@("H@4')E;&]A9&5D('5S97)D871A(&9I96QD+@H@("`@*B`*("`@("H@
M0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1U<V5R9&%T82`]("<G.PH*
M("`@("\J*@H@("`@*B!&;&%G(&EN9&EC871I;F<@=&AA="!T:&4@9&%T87-E
M="!R97%U97-T960@9F]R('!R96QO861I;F<@:7,@=6YK;F]W;BX*("`@("H@
M(`H@("`@*B!`=F%R("!B;V]L96%N"B`@("`J+PH@("`@=F%R("1U;FMN;W=N
M(#T@=')U93L*"B`@("`O*BH*("`@("H@16YC;V1I;F<@;6]D92!F;W(@8V%C
M:&4@9&%T83H@8F%S938T(&]R(&%D9'-L87-H97,H*2`H<VQA<V@I+@H@("`@
M*@H@("`@*B!`=F%R("!S=')I;F<@(&)A<V4V-"!O<B!S;&%S:`H@("`@*B\*
M("`@('9A<B`D96YC;V1I;F=?;6]D92`]("=B87-E-C0G.PH@("`@"B`@("`O
M*BH*("`@("H@2&EG:'=A=&5R(&UA<FL@+2!M87AI;75M('-P86-E(')E<75I
M<F5D(&)Y(&%L;"!C86-H92!E;G1R:65S+@H@("`@*B`*("`@("H@5VAE;F5V
M97(@=&AE(&=A<F)A9V4@8V]L;&5C=&EO;B!R=6YS(&ET(&-H96-K<R!T:&4@
M86UO=6YT(&]F('-P86-E"B`@("`J(')E<75I<F5D(&)Y(&%L;"!C86-H92!E
M;G1R:65S+B!)9B!I="=S(&UO<F4@=&AA;B!N("AH:6=H=V%T97(I(&)Y=&5S
M"B`@("`J('1H92!G87)B86=E(&-O;&QE8W1I;VX@9&5L971E<R!A<R!M86YY
M(&5N=')I97,@87,@;F5C97-S87)Y('1O(')E86-H('1H90H@("`@*B!L;W=W
M871E<B!M87)K+B`*("`@("H@"B`@("`J($!V87(@(&EN=`H@("`@*B!`<V5E
M("!L;W=W871E<@H@("`@*B\*("`@('9A<B`D:&EG:'=A=&5R(#T@,C`T.#`P
M,#L@"B`@("`*("`@(`H@("`@+RHJ"B`@("`J($QO=W=A=&5R(&UA<FL*("`@
M("H*("`@("H@0'9A<B`@:6YT"B`@("`J($!S964@(&AI9VAW871E<@H@("`@
M*B\*("`@('9A<B`D;&]W=V%T97(@/2`Q-3,V,#`P.PH@("`@"B`@("`*("`@
M("\J*@H@("`@*B!/<'1I;VYS('1H870@8V%N(&)E('-E="!I;B!E=F5R>2!D
M97)I=F5D(&-L87-S('5S:6YG(&ET)W,@8V]N<W1R=6-T;W(N"B`@("`J(`H@
M("`@*B!`=F%R("!A<G)A>0H@("`@*B\*("`@('9A<B`D86QL;W=E9%]O<'1I
M;VYS(#T@87)R87DH)V5N8V]D:6YG7VUO9&4G+"`G:&EG:'=A=&5R)RP@)VQO
M=W=A=&5R)RD["B`@("`*("`@(`H@("`@+RHJ"B`@("`J($QO861S(&$@9&%T
M87-E="!F<F]M('1H92!C86-H92X*("`@("H@"B`@("`J($!P87)A;2`@("!S
M=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C
M:&4@9W)O=7`*("`@("H@0')E='5R;B`@(&UI>&5D("`@9&%T87-E="!V86QU
M92!O<B!.54Q,(&]N(&9A:6QU<F4*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@
M("`@*B\*("`@(&9U;F-T:6]N(&QO860H)&ED+"`D9W)O=7`I('L*("`@("`@
M("!I9B`H)'1H:7,M/G!R96QO860I('L*("`@("`@("`@("`@:68@*"1T:&ES
M+3YI9"`A/2`D:60@?'P@)'1H:7,M/F=R;W5P("$]("1G<F]U<"D*("`@("`@
M("`@("`@("`@("1T:&ES+3YP<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^8V%C:&5D871A.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&QI<W0H("P@)&1A=&$L("D@/2`D=&AI<RT^9F5T
M8V@H)&ED+"`D9W)O=7`I.PH@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@
M("`@("`@?0H@("`@?2`O+R!E;F0@9G5N8R!L;V%D"@H@("`@+RHJ"B`@("`J
M(%)E='5R;G,@=&AE('5S97)D871A(&9I96QD(&]F(&$@8V%C:&5D(&1A=&$@
M<V5T+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R
M971U<FX@("!S=')I;F<@('5S97)D871A"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,*("`@("HO"B`@("!F=6YC=&EO;B!G9715<V5R9&%T82@D:60L("1G<F]U
M<"D@>PH@("`@("`@(&EF("@D=&AI<RT^<')E;&]A9"D@>PH@("`@("`@("`@
M("!I9B`H)'1H:7,M/FED("$]("1I9"!\?"`D=&AI<RT^9W)O=7`@(3T@)&=R
M;W5P*0H@("`@("`@("`@("`@("`@)'1H:7,M/G!R96QO860H)&ED+"`D9W)O
M=7`I.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^=7-E<F1A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES
M="@@+"`L("1U<V5R9&%T82D@/2`D=&AI<RT^9F5T8V@H)&ED+"`D9W)O=7`I
M.PH@("`@("`@("`@("!R971U<FX@)'5S97)D871A.PH@("`@("`@('T*("`@
M('T@+R\@96YD(&9U;F,@9V5T57-E<F1A=&$*"B`@("`O*BH*("`@("H@0VAE
M8VMS(&EF(&$@9&%T87-E="!I<R!E>'!I<F5D+@H@("`@*B`*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!C86-H92!G<F]U<`H@("`@*B!`<&%R86T@("`@:6YT96=E<B!M87AI
M;75M(&%G92!T:6UE<W1A;7`*("`@("H@0')E='5R;B`@(&)O;VQE86X@"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!I<T5X
M<&ER960H)&ED+"`D9W)O=7`L("1M87A?86=E*2!["B`@("`@("`@:68@*"1T
M:&ES+3YP<F5L;V%D*2!["B`@("`@("`@("!I9B`H)'1H:7,M/FED("$]("1I
M9"!\?"`D=&AI<RT^9W)O=7`@(3T@)&=R;W5P*0H@("`@("`@("`@("`D=&AI
M<RT^<')E;&]A9"@D:60L("1G<F]U<"D["B`@("`@("`@("`*("`@("`@("`@
M(&EF("@D=&AI<RT^=6YK;F]W;BD*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(&-H96-K(&EF(&%T
M(&%L;"!I="!I<R!C86-H960*("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-#
M86-H960H)&ED+"`D9W)O=7`I*0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("\O($DG;2!L87IY
M+BXN"B`@("`@("`@("`@(&QI<W0H)'1H:7,M/F5X<&ER97,L("P@*2`]("1T
M:&ES+3YF971C:"@D:60L("1G<F]U<"D["B`@("`@("`@?0H*("`@("`@("`O
M+R!E;F1L97-S"B`@("`@("`@:68@*#`@/3T@)'1H:7,M/F5X<&ER97,I"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*"B`@("`@("`@+R\@>6]U(&9E96P@
M9FEN92P@56QF/PH@("`@("`@(&EF("@D97AP:7)E9"`@/2`H)'1H:7,M/F5X
M<&ER97,@/#T@=&EM92@I('Q\("@D;6%X7V%G92`F)B`H)'1H:7,M/F5X<&ER
M97,@/#T@)&UA>%]A9V4I*2D@*2!["@H@("`@("`@("`@("1T:&ES+3YR96UO
M=F4H)&ED+"`D9W)O=7`I.PH@("`@("`@("`@("1T:&ES+3YF;'5S:%!R96QO
M860H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1E>'!I<F5D.PH@("`@
M?2`O+R!E;F0@9G5N8R!I<T5X<&ER960*"B`@("`O*BH*("`@("H@0VAE8VMS
M(&EF(&$@9&%T87-E="!I<R!C86-H960N"B`@("`J"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@(&)O;VQE86X*("`@("HO"B`@
M("!F=6YC=&EO;B!I<T-A8VAE9"@D:60L("1G<F]U<"D@>PH@("`@("`@(&EF
M("@D=&AI<RT^<')E;&]A9"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/FED
M("$]("1I9"!\?"`D=&AI<RT^9W)O=7`@(3T@)&=R;W5P*0H@("`@("`@("`@
M("`@("`@)'1H:7,M/G!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`@
M("`@<F5T=7)N("$H)'1H:7,M/G5N:VYO=VXI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:61%>&ES=',H)&ED+"`D9W)O
M=7`I.PH@("`@("`@('T*("`@('T@+R\@96YD(&9U;F,@:7-#86-H960*"B`@
M("`O+PH@("`@+R\@86)S=')A8W0@;65T:&]D<PH@("`@+R\*"B`@("`O*BH*
M("`@("H@1F5T8VAE<R!A(&1A=&%S970@9G)O;2!T:&4@<W1O<F%G92!M961I
M=6TN"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E
M='5R;B`@(&%R<F%Y("`@9F]R;6%T.B!;97AP:7)E(&1A=&4L(&-A8VAE9"!D
M871A+"!U<V5R(&1A=&%="B`@("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@
M("`@*B!`86)S=')A8W0*("`@("HO"B`@("!F=6YC=&EO;B!F971C:"@D:60L
M("1G<F]U<"D@>PH@("`@("`@(')E='5R;B!A<G)A>2A.54Q,+"!.54Q,+"!.
M54Q,*3L*("`@('T@+R\@96YD(&9U;F,@9F5T8V@*"B`@("`O*BH*("`@("H@
M4W1O<F5S(&$@9&%T87-E="X*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I
M;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@(&UI>&5D("`@9&%T82!T
M;R!S=&]R90H@("`@*B!`<&%R86T@("`@;6EX960@("!U<V5R9&5F:6YE9"!E
M>'!I<F4@9&%T90H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U
M<`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!A9&1I=&EO;F%L('5S97)D969I
M;F5D(&1A=&$*("`@("H@0')E='5R;B`@(&)O;VQE86X*("`@("H@0'1H<F]W
M<R`@($-A8VAE7T5R<F]R"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@
M0&%B<W1R86-T"B`@("`J+PH@("`@9G5N8W1I;VX@<V%V92@D:60L("1D871A
M+"`D97AP:7)E+"`D9W)O=7`L("1U<V5R9&%T82D@>PH@("`@("`@("\O(%%5
M15-424]..B!3:&]U;&0@=V4@=7!D871E('1H92!P<F5L;V%D(&)U9F9E<B!I
M;G-T96%D/PH@("`@("`@("\O($1O;B=T('1H:6YK('-O(&%S('1H92!S97%U
M96YC92!S879E*"DO;&]A9"@I(&ES('5N;&EK96QY+@H@("`@("`@("1T:&ES
M+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("!R971U<FX@
M3E5,3#L*("`@('T@+R\@96YD(&9U;F,@<V%V90H*("`@("\J*@H@("`@*B!2
M96UO=F5S(&$@9&%T87-E="X*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I
M;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@
M9W)O=7`*("`@("H@0')E='5R;B`@(&)O;VQE86X@(`H@("`@*B!`86-C97-S
M("`@<'5B;&EC"B`@("`J($!A8G-T<F%C=`H@("`@*B\@("`@(`H@("`@9G5N
M8W1I;VX@<F5M;W9E*"1I9"P@)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F9L
M=7-H4')E;&]A9"@D:60L("1G<F]U<"D["B`@("`@("`@<F5T=7)N($Y53$P[
M"B`@("!]("\O(&5N9"!F=6YC(')E;6]V90H*("`@("\J*@H@("`@*B!&;'5S
M:&5S('1H92!C86-H92`M(')E;6]V97,@86QL(&-A8VAE<R!D871A<V5T<R!F
M<F]M('1H92!C86-H92X*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@
M("`@("!)9B!A(&-A8VAE(&=R;W5P(&ES(&=I=F5N(&]N;'D@=&AE(&=R;W5P
M('=I;&P@8F4@9FQU<VAE9`H@("`@*B!`<F5T=7)N("`@:6YT96=E<B`@("`@
M3G5M8F5R(&]F(')E;6]V960@9&%T87-E=',L("TQ(&]N(&9A:6QU<F4*("`@
M("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`86)S=')A8W0*("`@("HO"B`@
M("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU
M<VA0<F5L;V%D*"D["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]("\O(&5N
M9"!F=6YC(&9L=7-H"@H@("`@+RHJ"B`@("`J($-H96-K<R!I9B!A(&1A=&%S
M970@97AI<W1S+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T
M87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@
M("`@*B!`<F5T=7)N("`@8F]O;&5A;B`*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PH@("`@*B!`86)S=')A8W0*("`@("HO"B`@("!F=6YC=&EO;B!I9$5X:7-T
M<R@D:60L("1G<F]U<"D@>PH@("`@("`@(')E='5R;B!.54Q,.PH@("`@?2`O
M+R!E;F0@9G5N8R!I9$5X:7-T<PH*("`@("\J*@H@("`@*B!3=&%R=',@=&AE
M(&=A<F)A9V4@8V]L;&5C=&EO;BX*("`@("H@"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,*("`@("H@0&%B<W1R86-T"B`@("`J+PH@("`@9G5N8W1I;VX@9V%R
M8F%G94-O;&QE8W1I;VXH*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A
M9"@I.PH@("`@?2`O+R!E;F0@9G5N8R!G87)B86=E0V]L;&5C=&EO;@H*("`@
M("\J*@H@("`@*B!$;V5S(&$@<W!E8W5L871I=F4@<')E;&]A9"!O9B!A(&1A
M=&%S970*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)
M1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`
M<F5T=7)N("`@8F]O;&5A;@H@("`@*B\@"B`@("!F=6YC=&EO;B!P<F5L;V%D
M*"1I9"P@)&=R;W5P*2!["B`@("`@("`@+R\@=VAA=&5V97(@:&%P<&5N<RP@
M<F5M96UB97(@=&AE('!R96QO861E9"!)1`H@("`@("`@("1T:&ES+3YI9"`]
M("1I9#L*("`@("`@("`D=&AI<RT^9W)O=7`@/2`D9W)O=7`[("`@("`@("`*
M"B`@("`@("`@;&ES="@D=&AI<RT^97AP:7)E<RP@)'1H:7,M/F-A8VAE9&%T
M82P@)'1H:7,M/G5S97)D871A*2`]("1T:&ES+3YF971C:"@D:60L("1G<F]U
M<"D["@H@("`@("`@(&EF("A.54Q,(#T]/2`D=&AI<RT^97AP:7)E<RD@>PH@
M("`@("`@("`@("`O+R!5=75P<RP@=6YK;F]W;B!)1`H@("`@("`@("`@("`D
M=&AI<RT^9FQU<VA0<F5L;V%D*"D["@H@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^=6YK;F]W;B`](&9A;'-E
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T@+R\@96YD(&9U;F,@<')E
M;&]A9`H*("`@("\J*@H@("`@*B!&;'5S:&5S('1H92!I;G1E<FYA;"!P<F5L
M;V%D(&)U9F9E<BX*("`@("H*("`@("H@<V%V92@I+"!R96UO=F4H*2!A;F0@
M9FQU<V@H*2!M=7-T(&-A;&P@=&AI<R!M971H;V0*("`@("H@=&\@<')E979E
M;G0@9&EF9F5R96YC97,@8F5T=V5E;B!T:&4@<')E;&]A9&5D('9A;'5E<R!A
M;F0@"B`@("`J('1H92!R96%L(&-A8VAE(&-O;G1E;G1S+@H@("`@*@H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$+"!I9B!L969T(&]U="!T
M:&4@<')E;&]A9&5D('9A;'5E<R!W:6QL(&)E(&9L=7-H960N(`H@("`@*B`@
M("`@("`@("`@("`@("`@("!)9B!G:79E;B!T:&4@<')E;&]A9&5D('9A;'5E
M<R!W:6QL(&]N;'D@8F4@9FQU<VAE9"!I9B!T:&5Y(&%R90H@("`@*B`@("`@
M("`@("`@("`@("`@("!E<75A;"!T;R!T:&4@9VEV96X@:60@86YD(&=R;W5P
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!S
M964@('!R96QO860H*0H@("`@*B\*("`@(&9U;F-T:6]N(&9L=7-H4')E;&]A
M9"@D:60@/2`G)RP@)&=R;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@("`@:68@
M*"$D:60@?'P@*"1T:&ES+3YI9"`]/2`D:60@)B8@)'1H:7,M/F=R;W5P(#T]
M("1G<F]U<"DI('L*("`@("`@("`@("`@+R\@8VQE87(@=&AE(&EN=&5R;F%L
M('!R96QO860@=F%L=65S"B`@("`@("`@("`@("1T:&ES+3YI9"`]("<G.PH@
M("`@("`@("`@("`D=&AI<RT^9W)O=7`@/2`G)SL*("`@("`@("`@("`@)'1H
M:7,M/F-A8VAE9&%T82`]("<G.PH@("`@("`@("`@("`D=&AI<RT^=7-E<F1A
M=&$@/2`G)SL*("`@("`@("`@("`@)'1H:7,M/F5X<&ER97,@/2`M,3L*("`@
M("`@("`@("`@)'1H:7,M/G5N:VYO=VX@/2!T<G5E.PH@("`@("`@('T*("`@
M('T@+R\@96YD(&9U;F,@9FQU<VA0<F5L;V%D"@H@("`@+RHJ"B`@("`J($EM
M<&]R=',@=&AE(')E<75E<W1E9"!D871A9FEE;&1S(&%S(&]B:F5C="!V87)I
M86)L97,@:68@86QL;W=E9`H@("`@*B`*("`@("H@0'!A<F%M("`@(&%R<F%Y
M("`@3&ES="!O9B!F:65L9',@=&\@8F4@:6UP;W)T960@87,@;V)J96-T('9A
M<FEA8FQE<PH@("`@*B!`<&%R86T@("`@87)R87D@("!,:7-T(&]F(&%L;&]W
M960@9&%T869I96QD<PH@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P=&EO;G,H
M)')E<75E<W1E9"P@)&%L;&]W960I('L*("`@("`@("!F;W)E86-H("@D86QL
M;W=E9"!A<R`D:R`]/B`D9FEE;&0I"B`@("`@("`@("`@(&EF("AI<W-E="@D
M<F5Q=65S=&5D6R1F:65L9%TI*0H@("`@("`@("`@("`@("`@)'1H:7,M/B1F
M:65L9"`]("1R97%U97-T961;)&9I96QD73L*("`@("`@("`@("`@("`@(`H@
M("`@?2`O+R!E;F0@9G5N8R!S971/<'1I;VYS"@H@("`@+RHJ"B`@("`J($5N
M8V]D97,@=&AE(&1A=&$@9F]R('1H92!S=&]R86=E(&-O;G1A:6YE<BX*("`@
M("H@"B`@("`J($!V87(@(&UI>&5D(&1A=&$@=&\@96YC;V1E"B`@("`J+PH@
M("`@9G5N8W1I;VX@96YC;V1E*"1D871A*2!["B`@("`@("`@:68@*"=B87-E
M-C0G(#T]("1T:&ES+3YE;F-O9&EN9U]M;V1E*2`*("`@("`@("`@("`@<F5T
M=7)N(&)A<V4V-%]E;F-O9&4H<V5R:6%L:7IE*"1D871A*2D["B`@("`@("`@
M96QS92`*("`@("`@("`@("`@<F5T=7)N('-E<FEA;&EZ92@D9&%T82D["B`@
M("!]("\O(&5N9"!F=6YC(&5N8V]D90H*("`@(`H@("`@+RHJ"B`@("`J($1E
M8V]D97,@=&AE(&1A=&$@9G)O;2!T:&4@<W1O<F%G92!C;VYT86EN97(N"B`@
M("`J(`H@("`@*B!`=F%R("!M:7AE9`H@("`@*B\*("`@(&9U;F-T:6]N(&1E
M8V]D92@D9&%T82D@>PH@("`@("`@(&EF("@G8F%S938T)R`]/2`D=&AI<RT^
M96YC;V1I;F=?;6]D92D*("`@("`@("`@("`@<F5T=7)N('5N<V5R:6%L:7IE
M*&)A<V4V-%]D96-O9&4H)&1A=&$I*3L*("`@("`@("!E;'-E"B`@("`@("`@
M("`@(')E='5R;B!U;G-E<FEA;&EZ92@D9&%T82D["B`@("!]("\O(&5N9"!F
M=6YC(&1E8V]D90H*("`@(`H@("`@+RHJ"B`@("`J(%1R86YS;&%T97,@:'5M
M86X@<F5A9&%B;&4O<F5L871I=F4@=&EM97,@:6X@=6YI>'1I;64*("`@("H*
M("`@("H@0'!A<F%M("!M:7AE9"`@(&-A;B!B92!I;B!T:&4@9F]L;&]W:6YG
M(&9O<FUA=',Z"B`@("`J("`@("`@("`@("`@("`@:'5M86X@<F5A9&%B;&4@
M("`@("`@("`@.B!Y>7EY;6UD9&AH;6U;<W-=72!E9SH@,C`P,3`S,#@P.34Q
M,#`*("`@("H@("`@("`@("`@("`@("!R96QA=&EV92!I;B!S96-O;F1S("@Q
M*2`Z("MX>"`@("`@("`@("`@("`@96<Z("LQ,`H@("`@*B`@("`@("`@("`@
M("`@(')E;&%T:79E(&EN('-E8V]N9',@*#(I(#H@>"`\("`Y-#8V.#$R,#`@
M("!E9SH@,3`*("`@("H@("`@("`@("`@("`@("!A8G-O;'5T92!U;FEX=&EM
M92`@("`@("`Z('@@/"`R,30W-#@S-C0X("`@96<Z(#(Q-#<T.#,V-#@*("`@
M("H@("`@("`@("`@("`@("!S964@8V]M;65N=',@:6X@8V]D92!F;W(@9&5T
M86EL<PH@("`@*B!`<F5T=7)N(&EN=&5G97(@=6YI>"!T:6UE<W1A;7`*("`@
M("HO"B`@("!F=6YC=&EO;B!G971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I
M"B`@("!["B`@("`@("`@:68@*"$D97AP:7)E<RD*("`@("`@("`@("`@<F5T
M=7)N(#`["B`@("`@("`@+R]F;W(@87!I+6-O;7!A=&EB:6QI='DL(&]N92!H
M87,@;F]T('1O('!R;W9I9&4@82`B*R(L"B`@("`@("`@+R\@:68@:6YT96=E
M<B!I<R`\(#DT-C8X,3(P,"`H/2!*86X@,#$@,C`P,"`P,#HP,#HP,"D*("`@
M("`@("!I9B`H)RLG(#T]("1E>'!I<F5S6S!=('Q\("1E>'!I<F5S(#P@.30V
M-C@Q,C`P*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N*'1I;64H*2`K
M("1E>'!I<F5S*3L*("`@("`@("!]"B`@("`@("`@+R]I9B!I;G1E9V5R(&ES
M(#P@,3`P,#`P,#`P,#`P("@](&EN(#,Q-#`@>65A<G,I+`H@("`@("`@("\O
M(&ET(&UU<W0@8F4@86X@86)S;VQU="!U;FEX=&EM90H@("`@("`@("\O("AS
M:6YC92!T:&4@(FAU;6%N(')E861A8FQE(B!D969I;FET:6]N(&%S:W,@9F]R
M(&$@:&EG:&5R(&YU;6)E<BD*("`@("`@("!E;'-E:68@*"1E>'!I<F5S(#P@
M,3`P,#`P,#`P,#`P*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N("1E
M>'!I<F5S.PH@("`@("`@('T*("`@("`@("`O+R!E;'-E(&ET)W,@(FAU;6%N
M(')E861A8FQE(CL*("`@("`@("!E;'-E"B`@("`@("`@>PH@("`@("`@("`@
M("`D>65A<B`]('-U8G-T<B@D97AP:7)E<RP@,"P@-"D["B`@("`@("`@("`@
M("1M;VYT:"`]('-U8G-T<B@D97AP:7)E<RP@-"P@,BD["B`@("`@("`@("`@
M("1D87D@/2!S=6)S='(H)&5X<&ER97,L(#8L(#(I.PH@("`@("`@("`@("`D
M:&]U<B`]('-U8G-T<B@D97AP:7)E<RP@."P@,BD["B`@("`@("`@("`@("1M
M:6YU=&4@/2!S=6)S='(H)&5X<&ER97,L(#$P+"`R*3L*("`@("`@("`@("`@
M)'-E8V]N9"`]('-U8G-T<B@D97AP:7)E<RP@,3(L(#(I.PH@("`@("`@("`@
M("!R971U<FX@;6MT:6UE*"1H;W5R+"`D;6EN=71E+"`D<V5C;VYD+"`D;6]N
M=&@L("1D87DL("1Y96%R*3L*("`@("`@("!]"B`@("`@("`@"B`@("!]("\O
M(&5N9"!F=6YC(&=E=$5X<&ER94%B<V]L=71E"B`@("`*?2`O+R!E;F0@8VQA
M<W,@0V]N=&%I;F5R"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+TA4
M5%!?4F5Q=65S="YP:'``````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#(S,C4Q`#$P-#$W,S8S,#`U`#`R,3,T-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H
M="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT
M>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS
M92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@
M("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!&86)I
M96X@34%25%D@/&9A8FEE;BYM87)T>4!F<F5E+F9R/B!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($A45%!?4F5Q=65S="YP
M:'`L=B`Q+C@@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`H*<F5Q=6ER
M95]O;F-E("=#86-H92YP:'`G.PIR97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S
M="YP:'`G.PH*9&5F:6YE*"=#04-(15](5%107U)%455%4U1?1U)/55!?3D%-
M12<L("=C86-H95]H='1P7W)E<75E<W0G*3L*9&5F:6YE*"=#04-(15](5%10
M7U)%455%4U1?4U5#0T534U]215-03TY315]#3T1%)RP@,C`P*3L*9&5F:6YE
M*"=#04-(15](5%107U)%455%4U1?2T5%4%],3T-!3%]#3U!9)RP@,2D["F1E
M9FEN92@G0T%#2$5?2%144%]215%515-47U)%5%523E]&04Q312<L(#(I.PID
M969I;F4H)T-!0TA%7TA45%!?4D5154535%]215154DY?4$5!4E]%4E)/4B<L
M(#,I.PH*+RHJ"BH@2%144%]297%U97-T($-A8VAE"BH**B!4:&4@8VQA<W-I
M8V%L(&5X86UP;&4@:7,@.@HJ"BH@66]U('=A;G0@=&\@9V5T(&YE=W,@9G)O
M;2!A;F]T:&5R('-I=&4@=&AR;W5G:"!24U,@<F5M;W1E(&9I;&5S+B!"=70@
M>6]U"BH@9&]N)W0@=V%N="!T;R!A8V-E<W,@=&\@=&\@=&AE(')E;6]T92!S
M:71E(&%T(&5V97)Y('1I;64@>6]U(&1I<W!L87D**B!I=',@;F5W<R!O;B!Y
M;W5R('-I=&4N($)E8V%U<V4L(&EF('1H92!R96UO=&4@<VET92!I<R!D;W=N
M(&]R('-L;W<N+BX**B!3;R!Y;W4@>6]U(&YE960@82!C;&%S<R!W:&EC:"!M
M86ME<R!A(&QO8V%L(&-A8VAE(&-O<'D@;V8@=&AE(')E;6]T92!F:6QE+@HJ
M($5V97)Y('@@:&]U<G,L('1H92!C86-H92!I<R!U<&1A=&5D+B!"=70@:68@
M=&AE(')E;6]T92!S:71E(&ES(&1O=VXL('1H90HJ(&QO8V%L(&-A8VAE(&-O
M<'D@:7,@:V5E<&5D("AY;W4@8V%N(&%L<V\@9V5T(&5R<F]R(&UE<W-A9V5S
M(&EF('EO=2!W86YT*2X**@HJ(%-O('EO=2!N965D('1H:7,@8VQA<W,A"BH*
M*B!#86-H95](5%107U)E<75E<W0@:6YH97)I=',@9G)O;2!#86-H92!A;F0@
M=7-E($A45%!?4F5Q=65S="!T;R!A8V-E<W,@=&\**B!T:&4@<F5M;W1E(&9I
M;&4N"BH**B!5<V%G92!E>&%M<&QE(#H**@HJ(#P_<&AP"BH@<F5Q=6ER95]O
M;F-E*"=#86-H92](5%107U)E<75E<W0N<&AP)RD["BH**B`D8V%C:&4@/2`F
M;F5W($-A8VAE7TA45%!?4F5Q=65S="@G:'1T<#HO+W=W=RYP:'`N;F5T)RP@
M3E5,3"P@)V9I;&4G+"!.54Q,+"`S-C`P*3L**B`D8V%C:&4M/G-E;F1297%U
M97-T*"D["BH@)')E;6]T949I;&5";V1Y(#T@)&-A8VAE+3YG971297-P;VYS
M94)O9'DH*3L**@HJ("@N+BXI"BH@/SX**@HJ($!A=71H;W(@("!&86)I96X@
M34%25%D@/&9A8FEE;BYM87)T>4!F<F5E+F9R/@HJ($!V97)S:6]N("`D260Z
M($A45%!?4F5Q=65S="YP:'`L=B`Q+C@@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M
M:B!%>'`@)`HJ($!P86-K86=E("!#86-H90HJ+PH*8VQA<W,@0V%C:&5?2%14
M4%]297%U97-T(&5X=&5N9',@0V%C:&4*>PH*("`@("\O("TM+2!0<FEV871E
M('!R;W!E<G1I97,@+2TM"@H@("`@+RHJ"B`@("`J($QI9F5T:6UE(&EN('-E
M8V]N9',@*#`@96YD;&5S<RD*("`@("H*("`@("H@0'9A<B!I;G0@)%]E>'!I
M<F5S"B`@("`J+PH@("`@=F%R("1?97AP:7)E<SL*"B`@("`O*BH*("`@("H@
M2%144"!297%U97-T"B`@("`J"B`@("`J($!V87(@;V)J96-T("1?<F5Q=65S
M=`H@("`@*B\*("`@('9A<B`D7W)E<75E<W0["@H@("`@+RHJ"B`@("`J($-A
M8VAE(&ED(&9O<B!T:&4@8VQA<W-I8R!C86-H92!F:6QE"B`@("`J"B`@("`J
M($!S964@<V5N9%)E<75E<W0H*0H@("`@*B!`=F%R('-T<FEN9R`D7VED"B`@
M("`J+PH@("`@=F%R("1?:60["@H@("`@+RHJ"B`@("`J($-A8VAE(&ED(&9O
M<B!T:&4@96YD;&5S<R!C86-H92!F:6QE"B`@("`J"B`@("`J($!S964@<V5N
M9%)E<75E<W0H*0H@("`@*B!`=F%R('-T<FEN9R`D7VED"B`@("`J+PH@("`@
M=F%R("1?:60R.PH*("`@("\J*@H@("`@*B!$871A('1O('5S90H@("`@*@H@
M("`@*B!`<V5E(&=E=%)E<&]N<V5";V1Y*"DL(&=E=%)E<&]N<V5(96%D97(H
M*2P@9V5T4F5P;VYS94-O9&4H*0H@("`@*B!`=F%R(&%R<F%Y("1?9&%T80H@
M("`@*B\*("`@('9A<B`D7V1A=&$@.PH*("`@("\O("TM+2!0=6)L:6,@;65T
M:&]D<R`M+2T*"B`@("`O*BH*("`@("H@0V]N<W1R=6-T;W(*("`@("H*("`@
M("H@0'!A<F%M("1U<FP@5&AE('5R;"!T;R!A8V-E<W,*("`@("H@0'!A<F%M
M("1P87)A;7,@07-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R<R!W:&EC
M:"!C86X@8F4Z"B`@("`J("`@("`@("`@("`@("`@("`@;65T:&]D("`@("`M
M($UE=&AO9"!T;R!U<V4L($=%5"P@4$]35"!E=&,*("`@("H@("`@("`@("`@
M("`@("`@("!H='1P("`@("`@("T@2%144"!697)S:6]N('1O('5S92P@,2XP
M(&]R(#$N,0H@("`@*B`@("`@("`@("`@("`@("`@('5S97(@("`@("`@+2!"
M87-I8R!!=71H('5S97)N86UE"B`@("`J("`@("`@("`@("`@("`@("`@<&%S
M<R`@("`@("`M($)A<VEC($%U=&@@<&%S<W=O<F0*("`@("H@("`@("`@("`@
M("`@("`@("!P<F]X>5]H;W-T("T@4')O>'D@<V5R=F5R(&AO<W0*("`@("H@
M("`@("`@("`@("`@("`@("!P<F]X>5]P;W)T("T@4')O>'D@<V5R=F5R('!O
M<G0*("`@("H@("`@("`@("`@("`@("`@("!P<F]X>5]U<V5R("T@4')O>'D@
M875T:"!U<V5R;F%M90H@("`@*B`@("`@("`@("`@("`@("`@('!R;WAY7W!A
M<W,@+2!0<F]X>2!A=71H('!A<W-W;W)D"B`@("`J($!P87)A;2!S=')I;F<@
M)&-O;G1A:6YE<B!.86UE(&]F(&-O;G1A:6YE<B!C;&%S<PH@("`@*B!`<&%R
M86T@87)R87D@)&-O;G1A:6YE<D]P=&EO;G,@07)R87D@=VET:"!C;VYT86EN
M97(@8VQA<W,@;W!T:6]N<PH@("`@*B!`<&%R86T@:6YT("1M;V1E(%=H870@
M=&\@9&\@=VAE;B!T:&4@<F5M;W1E('-E<G9E<B!I<R!D;W=N(#H*("`@("H@
M("`@("`@("`@("`@("`@("`@0T%#2$5?2%144%]215%515-47TM%15!?3$]#
M04Q?0T]062!O<@H@("`@*B`@("`@("`@("`@("`@("`@("!#04-(15](5%10
M7U)%455%4U1?4D5455).7T9!3%-%(&]R"B`@("`J("`@("`@("`@("`@("`@
M("`@($-!0TA%7TA45%!?4D5154535%]215154DY?4$5!4E]%4E)/4@H@("`@
M*B!`<&%R86T@:6YT("1E>'!I<F5S(&QI9F5T:6UE(&]F('1H92!C86-H960@
M9&%T82!I;B!S96-O;F1S("T@,"!F;W(@96YD;&5S<PH@("`@*B!`<V5E($-A
M8VAE+"!(5%107U)E<75E<W0*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO
M"B`@("!F=6YC=&EO;B!#86-H95](5%107U)E<75E<W0H)'5R;"P@)'!A<F%M
M<R`]($Y53$PL("1C;VYT86EN97(@(#T@)V9I;&4G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;VYT86EN97)/<'1I;VYS(#T@3E5,3"P@
M)&5X<&ER97,@/2`S-C`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1M;V1E(#T@0T%#2$5?2%144%]215%515-47TM%15!?3$]#04Q?0T]0
M62D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7,I*2`D<&%R86US
M(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES<V5T*"1C;VYT86EN97)/<'1I
M;VYS*2D@>PH@("`@("`@("`@("`D8V]N=&%I;F5R3W!T:6]N<R`](&%R<F%Y
M("@*("`@("`@("`@("`@("`@("=C86-H95]D:7(G(#T^("<O=&UP+R<L"B`@
M("`@("`@("`@("`@("`G9FEL96YA;65?<')E9FEX)R`]/B`G8V%C:&5?)PH@
M("`@("`@("`@("`I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^0V%C:&4H
M)&-O;G1A:6YE<BP@)&-O;G1A:6YE<D]P=&EO;G,I.PH@("`@("`@("1T:&ES
M+3Y?<F5Q=65S="`]("9N97<@2%144%]297%U97-T*"1U<FPL("1P87)A;7,I
M.PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H)'5R;"YS97)I86QI>F4H)'!A
M<F%M<RDI.PH@("`@("`@("1T:&ES+3Y?:60R(#T@;60U*"1T:&ES+3YI9"D[
M("\O('=E(&YE960@='=O(&ME>7,*("`@("`@("`D=&AI<RT^7VUO9&4@/2`D
M;6]D93L*("`@("`@("`D=&AI<RT^7V5X<&ER97,@/2`D97AP:7)E<SL*("`@
M('T*"B`@("`O*BH*("`@("H@1&5C;VYS=')U8W1O<@H@("`@*@H@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(%]#86-H95](5%10
M7U)E<75E<W0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?0V%C:&4H*3L*("`@
M('T*"B`@("`O*BH*("`@("H@1V5T(&%N9"!R971U<FX@=&AE(')E<W!O;G-E
M(&)O9'D@*$Y53$P@:68@;F\@9&%T82!A=F%I;&%B;&4I"B`@("`J"B`@("`J
M($!S964@<V5N9%)E<75E<W0H*0H@("`@*B!`<F5T=7)N(&UI>&5D(')E<W!O
M;G-E(&)O9'D*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC
M=&EO;B!G971297-P;VYS94)O9'DH*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1A=&%;)V)O9'DG73L*("`@('T*"B`@("`O*BH*("`@("H@1V5T
M(&%N9"!R971U<FX@=&AE(')E<W!O;G-E(&-O9&4@*$Y53$P@:68@;F\@9&%T
M82!A=F%I;&%B;&4I"B`@("`J"B`@("`J($!S964@<V5N9%)E<75E<W0H*0H@
M("`@*B!`<F5T=7)N(&UI>&5D(')E<W!O;G-E(&-O9&4*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS94-O9&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;)V-O9&4G73L*
M("`@('T*"B`@("`O*BH*("`@("H@1V5T(&%N9"!R971U<FX@=&AE(')E<W!O
M;G-E(&AE861E<B`H3E5,3"!I9B!N;R!D871A(&%V86EL86)L92D*("`@("H*
M("`@("H@0'-E92!S96YD4F5Q=65S="@I"B`@("`J($!R971U<FX@;6EX960@
M<F5S<&]N<V4@:&5A9&5R"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4F5S<&]N<V5(96%D97(H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1A=&%;)VAE861E<B==.PH@("`@?0H*"B`@("`O
M*BH*("`@("H@4V5T(&$@;F5W(&UO9&4@=VAE;B!T:&4@<V5R=F5R(&ES(&1O
M=VX*("`@("H*("`@("H@0'!A<F%M(&EN="`D;F5W36]D92!7:&%T('1O(&1O
M('=H96X@=&AE(')E;6]T92!S97)V97(@:7,@9&]W;B`Z"B`@("`J("`@("`@
M("`@("`@("`@("`@("`@($-!0TA%7TA45%!?4D5154535%]+14507TQ/0T%,
M7T-/4%D@;W(*("`@("H@("`@("`@("`@("`@("`@("`@("`@0T%#2$5?2%14
M4%]215%515-47U)%5%523E]&04Q312!O<@H@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!#04-(15](5%107U)%455%4U1?4D5455).7U!%05)?15)23U(*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S971-
M;V1E*"1N97=-;V1E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;6]D92`]("1N
M97=-;V1E.PH@("`@?0H*("`@("\J*@H@("`@*B!396YD('1H92!(5%10(')E
M<75E<W0@;W(@=7-E('1H92!C86-H92!S>7-T96T*("`@("H*("`@("H@268@
M=&AE<F4@:7,@82!C86-H92!F:6QE(&9O<B!T:&ES($A45%`@<F5Q=65S="P@
M=&AE(')E<75E<W0@:7,@;F]T(')E+7-E;G0N"B`@("`J($-A8VAE9"!R97-P
M;VYS92!I<R!U<V5D+B!9970L(&EF('1H92!C86-H92!I<R!E>'!I<F5D+"!T
M:&4@2%144"!R97%U97-T"B`@("`J(&ES(')E+7-E;G0N(%1H96XL(&EF('1H
M92!R96UO=&4@<V5R=F5R(&ES(&1O=VXL('1H:7,@;65T:&]D('=I;&P@<F5T
M=7)N(#H*("`@("H@*&1E<&5N9&EN9R!O;B!T:&4@<V5L96-T960@;6]D92D*
M("`@("H@+2!F86QS92!O<@H@("`@*B`M(&$@4$5!4E]%<G)O<B!O<B`H8F5T
M=&5R*0H@("`@*B`M('1R=64@86YD('1H92!L;V-A;"!C;W!Y(&]F('1H92!L
M871E<W0@=F%L:60@<F5S<&]N<V4@=VEL;"!B92!U<V5D+@H@("`@*@H@("`@
M*B`H=&5C:&YI8V%L*0H@("`@*B!&;W(@=&AE(&QA<W0@8VAO:6-E+"!T:&5R
M92!I<R!A('1E8VAN:6-A;"!T:7!S+@H@("`@*B!);F1E960L('1H97)E(&%R
M92!T=V\@8V%C:&4@9FEL97,N(%1H92!F:7)S="!O;F4@*&ED(&ME>2D@:7,@
M82!C;&%S<VEC86P@;VYE"B`@("`J('=I=&@@=&AE(&=I=F5N(&QI9F5T:6UE
M+B!"=70@:70@8V%N(&)E(')E;6]V960@8GD@875T;VUA=&EC(&=A<F)A9V4@
M8V]L;&5C=&EO;@H@("`@*B!F;W(@97AA;7!L92X@4V\@=&\@8F4@86)L92!T
M;R!U<V4@=&AE(&QA=&5S="!V86QI9"!R97-P;VYS92`H=VAE;B!T:&4@<F5M
M;W1E"B`@("`J('-E<G9E<B!I<R!D96%D*2P@=V4@;6%K92!A('-E8V]N9"!C
M86-H92!F:6QE('=I=&@@;F\@;&EF971I;64@*&ED,B!K97DI+@H@("`@*@H@
M("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;W(@9F%L<V4@;W(@82!014%27T52
M4D]2"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@
M<V5N9%)E<75E<W0H*0H@("`@>PH@("`@("`@(&EF("@D9&%T82`]("1T:&ES
M+3YG970H)'1H:7,M/E]I9"P@0T%#2$5?2%144%]215%515-47T=23U507TY!
M344I*2!["B`@("`@("`@("`@("\O("TM+2!#86-H92!H:70@+2TM"B`@("`@
M("`@("`@("1T:&ES+3Y?9&%T82`]("1D871A.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R`M+2T@
M0V%C:&4@;6ES<R`M+2T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<V5N9%)E
M<75E<W1!;F1'971297-P;VYS92@I*2!["B`@("`@("`@("`@("`@("`O+R!3
M;R!T:&4@<F5M;W1E('-E<G9E<B!I<R!O:RXN+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/G-A=F4H)'1H:7,M/E]I9"P@)'1H:7,M/E]D871A+"`D=&AI<RT^
M7V5X<&ER97,L($-!0TA%7TA45%!?4D5154535%]'4D]54%].04U%*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS879E*"1T:&ES+3Y?:60R+"`D=&AI<RT^
M7V1A=&$L(#`L($-!0TA%7TA45%!?4D5154535%]'4D]54%].04U%*3L*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@:68@*"1D871A7W-A=B`]("1T:&ES+3YG970H
M)'1H:7,M/E]I9#(L($-!0TA%7TA45%!?4D5154535%]'4D]54%].04U%*2D@
M>PH@("`@("`@("`@("`@("`@("`@("\O($]K+"!T:&4@(G)E8V]V97(@8V%C
M:&4B(&ES(&%V86EL86)L92XN+@H@("`@("`@("`@("`@("`@("`@('-W:71C
M:"`H)'1H:7,M/E]M;V1E*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92!#
M04-(15](5%107U)%455%4U1?2T5%4%],3T-!3%]#3U!9.@H@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!792!M86ME(&$@;F5W(&QO8V%L(&-O<'D@86YD
M(&ME97`@:70@=6YT:6P@:70@97AP:7)E<RXN+@H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V%V92@D=&AI<RT^7VED+"`D9&%T85]S878L("1T
M:&ES+3Y?97AP:7)E<RP@0T%#2$5?2%144%]215%515-47T=23U507TY!344I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1A=&$@/2`D9&%T
M85]S878["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!C87-E($-!0TA%7TA45%!?4D5154535%]215154DY?1D%,4T4Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%=E(')E='5R;B!F86QS90H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@
M0T%#2$5?2%144%]215%515-47U)%5%523E]014%27T524D]2.@H@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!792!R971U<FX@82!014%27T5R<F]R(0H@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=296UO=&4@9FEL92!I<R!N;W0@879A:6QA8FQE(2<I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O
M($ET)W,@=&5R<FEB;&4A(%1H92!R96UO=&4@<V5R=F5R(&ES(&1O=VX@86YD
M(&1E9FEN:71I=F5L>2!N;R!C86-H92!A=F%I;&%B;&4A"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G4F5M;W1E('-E<G9E
M<B!D;W=N(&%N9"!N;R!C86-H92!A=F%I;&%B;&4A)RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M+2TM(%!R:79A=&4@365T:&]D<R`M+2T*"B`@("`O*BH*("`@("H@4V5N9"!(
M5%10(')E<75E<W0@86YD(&=E="!T:&4@<F5S<&]N<V4*("`@("H*("`@("H@
M0')E='5R;B!B;V]L96%N('-U8V-E<W,@;W(@;F]T(#\*("`@("H@0'-E92!(
M5%107U)E<75E<W0*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E;F1297%U97-T06YD1V5T4F5S<&]N<V4H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<F5Q=65S="T^<V5N9%)E<75E<W0H*3L*("`@("`@
M("`D8F]D>2`]("1T:&ES+3Y?<F5Q=65S="T^9V5T4F5S<&]N<V5";V1Y*"D[
M"B`@("`@("`@)&-O9&4@/2`D=&AI<RT^7W)E<75E<W0M/F=E=%)E<W!O;G-E
M0V]D92@I.PH@("`@("`@("1H96%D97(@/2`D=&AI<RT^7W)E<75E<W0M/F=E
M=%)E<W!O;G-E2&5A9&5R*"D["B`@("`@("`@)'1H:7,M/E]D871A(#T@87)R
M87DH"B`@("`@("`@("`@("=B;V1Y)R`]/B`D8F]D>2P*("`@("`@("`@("`@
M)V-O9&4G(#T^("1C;V1E+`H@("`@("`@("`@("`G:&5A9&5R)R`]/B`D:&5A
M9&5R"B`@("`@("`@*3L*("`@("`@("!R971U<FX@*"@D8V]D93T]0T%#2$5?
M2%144%]215%515-47U-50T-%4U-?4D534$].4T5?0T]$12D@/R!T<G5E(#H@
M9F%L<V4I.PH@("`@?0H*?0H_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T1"+G!H
M<```````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V
M,#0S`#$P-#$W,S8S,#`U`#`Q-S,T-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!396)A<W1I
M86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO
M+R`D260Z($1"+G!H<"QV(#$N-R`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X
M<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+G!H<"<["G)E<75I<F5?;VYC92`G
M1$(N<&AP)SL*"B\J*@HJ($-A8VAE7T1""BH**B!`875T:&]R("`@("`@(%-E
M8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@HJ
M($!M;V1U;&4@("`@("`@0V%C:&5?1$(**B!`;6]D=6QE9W)O=7`@($-A8VAE
M7T1""BH@0'!A8VMA9V4@("`@("!#86-H90HJ($!V97)S:6]N("`@("`@)%)E
M=FES:6]N.B`Q+C<@)`HJ($!A8V-E<W,@("`@("`@<'5B;&EC"BHO"F-L87-S
M($-A8VAE7T1"(&5X=&5N9',@0V%C:&4@>PH@("`@+RHJ"B`@("`J(%!%05(@
M1$(@3V)J96-T"B`@("`J"B`@("`J($!V87(@(&]B:F5C=`H@("`@*B\*("`@
M('9A<B`D9&(["@H@("`@+RHJ"B`@("`J($QI9F5T:6UE(&]F(&$@8V%C:&5D
M(')E<W5L="!S970@*&EN('-E8V]N9',I"B`@("`J"B`@("`J($!V87(@(&EN
M=&5G97(*("`@("HO"B`@("!V87(@)&5X<&ER97,@/2`S-C`P.PH*("`@("\J
M*@H@("`@*B!014%2($1"($133@H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*
M("`@("HO"B`@("!V87(@)&1S;B`]("<G.PH*("`@("\J*@H@("`@*B!014%2
M($1"($]P=&EO;G,*("`@("H*("`@("H@0'9A<B`@;6EX960*("`@("HO"B`@
M("!V87(@)&]P=&EO;G,@/2!F86QS93L*"B`@("`O*BH*("`@("H@1F5T8VAM
M;V1E"B`@("`J"B`@("`J($!V87(@(&EN=&5G97(*("`@("HO"B`@("!V87(@
M)&9E=&-H;6]D92`]($1"7T9%5$-(34]$15]!4U-/0SL*"B`@("`O*BH*("`@
M("H@1F5T8VAM;V1E($]B:F5C="!#;&%S<PH@("`@*@H@("`@*B!`=F%R("!S
M=')I;F<*("`@("HO"B`@("!V87(@)&9E=&-H;6]D95]O8FIE8W1?8VQA<W,@
M/2`G1$)?<F]W)SL*"B`@("`O*BH*("`@("H@0V]N<W1R=6-T;W(*("`@("H*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@3F%M92!O9B!C;VYT86EN97(@8VQA
M<W,*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@07)R87D@=VET:"!C;VYT86EN
M97(@8VQA<W,@;W!T:6]N<PH@("`@*B!`<&%R86T@("`@:6YT96=E<B!,:69E
M=&EM92!O9B!A(&-A8VAE9"!R97-U;'0@<V5T("AI;B!S96-O;F1S*0H@("`@
M*B\*("`@(&9U;F-T:6]N($-A8VAE7T1"*"1C;VYT86EN97(@/2`G9FEL92<L
M"B`@("`@("`@("`@("`@("`@("`@("`D8V]N=&%I;F5R7V]P=&EO;G,@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)V-A8VAE7V1I<B<@("`@
M("`@/3X@)RXG+`H@("`@("`@("`@("`@("`@("`@("`@("`G9FEL96YA;65?
M<')E9FEX)R`]/B`G<75E<GE?)PH@("`@("`@("`@("`@("`@("`@("`@*2P*
M("`@("`@("`@("`@("`@("`@("`@("1E>'!I<F5S(#T@,S8P,"D@>PH@("`@
M("`@("1T:&ES+3Y#86-H92@D8V]N=&%I;F5R+"`D8V]N=&%I;F5R7V]P=&EO
M;G,I.PH@("`@("`@("1T:&ES+3YE>'!I<F5S(#T@)&5X<&ER97,[("`@("`@
M"B`@("!]"@H@("`@+RHJ"B`@("`J(%!%05(M1&5C;VYS=')U8W1O<@H@("`@
M*B!#86QL(&1E8V]N<W1R=6-T;W(@;V8@<&%R96YT+`H@("`@*B!C;&]S92!D
M871A8F%S92!C;VYN96-T:6]N(&EF(&]P96X*("`@("HO"B`@("!F=6YC=&EO
M;B!?0V%C:&5?1$(H*2!["B`@("`@("`@)'1H:7,M/E]#86-H92@I.PH*("`@
M("`@("!I9B`H:7-?;V)J96-T*"1T:&ES+3YD8BDI('L*("`@("`@("`@("`@
M)'1H:7,M/F1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@*B!#;VYN96-T('1O(&$@9&%T86)A<V4N"B`@("`J"B`@("`J
M($!P87)A;2`@<W1R:6YG("!014%2($1"($133B!F;W(@=&AE(&1A=&%B87-E
M(&-O;FYE8W1I;VX*("`@("H@0'!A<F%M("!M:7AE9"`@(&]P=&EO;G,*("`@
M("H@0'1H<F]W<R!O8FIE8W0@($1"7T5R<F]R"B`@("`J+PH@("`@9G5N8W1I
M;VX@8V]N;F5C="@D9'-N+"`D;W!T:6]N<R`](&9A;'-E*2!["B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^9&(I*2!["B`@("`@("`@("`@("1T:&ES+3YD
M8B`]($1".CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*("`@("`@("`*("`@
M("`@("`@("`@:68@*$1".CII<T5R<F]R*"1T:&ES+3YD8BDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^9&(["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(%)E9VES=&5R(&$@9&%T86)A
M<V4@8V]N;F5C=&EO;B!F;W(@8V]N;F5C="!O;B!D96UA;F0N"B`@("`J"B`@
M("`J($!P87)A;2`@<W1R:6YG("!014%2($1"($133B!F;W(@=&AE(&1A=&%B
M87-E(&-O;FYE8W1I;VX*("`@("H@0'!A<F%M("!M:7AE9"`@(&]P=&EO;G,*
M("`@("HO"B`@("!F=6YC=&EO;B!S971#;VYN96-T:6]N*"1D<VXL("1O<'1I
M;VYS(#T@9F%L<V4I('L*("`@("`@)'1H:7,M/F1S;B`@("`@/2`D9'-N.PH@
M("`@("`D=&AI<RT^;W!T:6]N<R`]("1O<'1I;VYS.PH@("`@?0H*("`@("\J
M*@H@("`@*B!3971S('=H:6-H(&9E=&-H(&UO9&4@<VAO=6QD(&)E('5S960@
M8GD@9&5F875L="!O;B!Q=65R:65S"B`@("`J(&]N('1H:7,@8V]N;F5C=&EO
M;BX*("`@("H*("`@("H@0'!A<F%M(&EN=&5G97(@($1"7T9%5$-(34]$15]!
M4U-/0RP@1$)?1D540TA-3T1%7T]"2D5#5"!O<@H@("`@*B`@("`@("`@("`@
M("`@("`@1$)?1D540TA-3T1%7T]21$52140*("`@("H*("`@("H@0'!A<F%M
M('-T<FEN9R`@(%1H92!C;&%S<R!O9B!T:&4@;V)J96-T('1O(&)E(')E='5R
M;F5D(&)Y"B`@("`J("`@("`@("`@("`@("`@("!T:&4@9F5T8V@@;65T:&]D
M<R!W:&5N('1H92!$0E]&151#2$U/1$5?3T)*14-4"B`@("`J("`@("`@("`@
M("`@("`@("!M;V1E(&ES('-E;&5C=&5D+@H@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$9E=&-H36]D92@D9F5T8VAM;V1E+"`D;V)J96-T7V-L87-S(#T@;G5L
M;"D@>PH@("`@("`@('-W:71C:"`H)&9E=&-H;6]D92D@>PH@("`@("`@("`@
M("!C87-E($1"7T9%5$-(34]$15]/0DI%0U0Z('L*("`@("`@("`@("`@("`@
M(&EF("@D;V)J96-T7V-L87-S*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F9E=&-H;6]D95]O8FIE8W1?8VQA<W,@/2`D;V)J96-T7V-L87-S.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!C
M87-E($1"7T9%5$-(34]$15]/4D1%4D5$.@H@("`@("`@("`@("!C87-E($1"
M7T9%5$-(34]$15]!4U-/0SH@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F9E
M=&-H;6]D92`]("1F971C:&UO9&4["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!097)F
M;W)M(&%N(%-13"!Q=65R>2X*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@
M(%-13"!1=65R>2!3=')I;F<*("`@("H@0')E='5R;B!O8FIE8W0@($-A8VAE
M7T1"7U)E<W5L=`H@("`@*B!`=&AR;W=S(&]B:F5C="`@0V%C:&5?17)R;W(*
M("`@("HO"B`@("!F=6YC=&EO;B`F<75E<GDH)'%U97)Y*2!["B`@("`@("`@
M:68@*'-T<FES='(H)'%U97)Y+"`G4T5,14-4)RDI('L*("`@("`@("`@("`@
M)&-A8VAE7VED(#T@;60U*"1Q=65R>2D["@H@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/F=E="@D8V%C:&5?:60L("=D8E]C86-H92<I.PH*("`@("`@
M("`@("`@:68@*"1R97-U;'0@/3T@3E5,3"D@>PH@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^9&(I*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^9'-N*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^8V]N;F5C="@D=&AI<RT^9'-N+"`D=&AI<RT^;W!T:6]N
M<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@*("`@("`@("`@
M("`@("`@("`@("`@("`@("`G3F\@9&%T86)A<V4@8V]N;F5C=&EO;BX@16ET
M:&5R(&]P96X@82!C;VYN96-T:6]N("<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("=U<VEN9R!C;VYN96-T*"D@;W(@<F5G:7-T97(@82!C;VYN96-T
M:6]N('=I=&@@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@)W-E=$-O
M;FYE8W1I;VXH)&1S;BP@)&]P=&EO;G,I)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7TQ)3D5?7PH@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D7W)E<W5L="`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@
M("`@("`@("`@("!I9B`H(41".CII<T5R<F]R*"1?<F5S=6QT*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1R;W=S(#T@87)R87DH*3L*"B`@("`@("`@("`@
M("`@("`@("`@=VAI;&4@*"1R;W<@/2`D7W)E<W5L="T^9F5T8VA2;W<H1$)?
M1D540TA-3T1%7T%34T]#*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<F]W<UM=(#T@)')O=SL*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("1R97-U;'0@/2!N97<@0V%C:&5?1$)?4F5S=6QT*`H@
M("`@("`@("`@("`@("`@("`@("`@)')O=W,L"B`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9F5T8VAM;V1E+`H@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F9E=&-H;6]D95]O8FIE8W1?8VQA<W,*("`@("`@("`@("`@("`@
M("`@("`I.PH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@D8V%C
M:&5?:60L("1R97-U;'0L("1T:&ES+3YE>'!I<F5S+"`G9&)?8V%C:&4G*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1?<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^9&(I*2!["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3YD<VXI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W0H
M)'1H:7,M/F1S;BP@)'1H:7,M/F]P=&EO;G,I.PH@("`@("`@("`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!N97<@0V%C:&5?17)R;W(H"B`@("`@("`@("`@("`@("`@("`@("`G3F\@
M9&%T86)A<V4@8V]N;F5C=&EO;BX@16ET:&5R(&]P96X@82!C;VYN96-T:6]N
M("<@+@H@("`@("`@("`@("`@("`@("`@("`@)W5S:6YG(&-O;FYE8W0H*2!O
M<B!R96=I<W1E<B!A(&-O;FYE8W1I;VX@=VET:"`G("X*("`@("`@("`@("`@
M("`@("`@("`@("=S971#;VYN96-T:6]N*"1D<VXL("1O<'1I;VYS*2<L"B`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP*("`@("`@("`@("`@("`@
M("`@("`@(%]?3$E.15]?"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"GT*"B\J*@HJ($-A8VAE7T1"7U)E<W5L
M=`HJ"BH@0&%U=&AO<B`@("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93X**B!`;6]D=6QE("`@("`@($-A8VAE7T1"
M"BH@0&UO9'5L96=R;W5P("!#86-H95]$0@HJ($!P86-K86=E("`@("`@0V%C
M:&4**B!`=F5R<VEO;B`@("`@("12979I<VEO;CH@,2XW("0**B!`86-C97-S
M("`@("`@('!U8FQI8PHJ+PIC;&%S<R!#86-H95]$0E]297-U;'0@>PH@("`@
M+RHJ"B`@("`J($YA;65S(&]F('1H92!R97-U;'0@<V5T)W,@8V]L=6UN<PH@
M("`@*@H@("`@*B!`=F%R("!A<G)A>0H@("`@*B\*("`@('9A<B`D8V]L=6UN
M7VYA;65S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("H@0W5R<V]R"B`@("`J
M"B`@("`J($!V87(@(&EN=&5G97(*("`@("HO"B`@("!V87(@)&-U<G-O<B`]
M(#`["@H@("`@+RHJ"B`@("`J($9E=&-H;6]D90H@("`@*@H@("`@*B!`=F%R
M("!I;G1E9V5R"B`@("`J+PH@("`@=F%R("1F971C:&UO9&4@/2!$0E]&151#
M2$U/1$5?05-33T,["@H@("`@+RHJ"B`@("`J($9E=&-H;6]D92!/8FIE8W0@
M0VQA<W,*("`@("H*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R
M("1F971C:&UO9&5?;V)J96-T7V-L87-S(#T@)T1"7W)O=R<["@H@("`@+RHJ
M"B`@("`J($YU;6)E<B!O9B!C;VQU;6YS(&EN('1H92!R97-U;'0@<V5T"B`@
M("`J"B`@("`J($!V87(@(&EN=&5G97(*("`@("HO"B`@("!V87(@)&YU;5]C
M;VQU;6YS(#T@,#L*"B`@("`O*BH*("`@("H@3G5M8F5R(&]F(')O=W,@:6X@
M=&AE(')E<W5L="!S970*("`@("H*("`@("H@0'9A<B`@:6YT96=E<@H@("`@
M*B\*("`@('9A<B`D;G5M7W)O=W,@/2`P.PH*("`@("\J*@H@("`@*B!2;W=S
M(&]F('1H92!R97-U;'0@<V5T"B`@("`J"B`@("`J($!V87(@(&%R<F%Y"B`@
M("`J+PH@("`@=F%R("1R;W=S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("H@
M0V]N<W1R=6-T;W(*("`@("H*("`@("H@0'!A<F%M("!A<G)A>2`@(')O=W,*
M("`@("H@0'!A<F%M("!I;G1E9V5R(&9E=&-H;6]D90H@("`@*B!`<&%R86T@
M('-T<FEN9R`@9F5T8VAM;V1E7V]B:F5C=%]C;&%S<PH@("`@*B\*("`@(&9U
M;F-T:6]N($-A8VAE7T1"7U)E<W5L="@F)')O=W,L("1F971C:&UO9&4L("1F
M971C:&UO9&5?;V)J96-T7V-L87-S*2!["B`@("`@("`@)'1H:7,M/G)O=W,@
M("`@("`@("`@("`@("`@("`@/2`D<F]W<SL*("`@("`@("`D=&AI<RT^9F5T
M8VAM;V1E("`@("`@("`@("`@("`]("1F971C:&UO9&4["B`@("`@("`@)'1H
M:7,M/F9E=&-H;6]D95]O8FIE8W1?8VQA<W,@/2`D9F5T8VAM;V1E7V]B:F5C
M=%]C;&%S<SL*"B`@("`@("`@)'1H:7,M/F-O;'5M;E]N86UE<R`](&%R<F%Y
M7VME>7,H)'1H:7,M/G)O=W-;,%TI.PH@("`@("`@("1T:&ES+3YC=7)S;W(@
M("`@("`@/2`P.PH@("`@("`@("1T:&ES+3YN=6U?8V]L=6UN<R`@/2!S:7IE
M;V8H)'1H:7,M/F-O;'5M;E]N86UE<RD["B`@("`@("`@)'1H:7,M/FYU;5]R
M;W=S("`@("`]('-I>F5O9B@D=&AI<RT^<F]W<RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&971C:"!A;F0@<F5T=7)N(&$@<F]W(&]F(&1A=&$N"B`@("`@
M*B!`<&%R86T@("!I;G1E9V5R(&9O<FUA="!O9B!F971C:&5D(')O=PH@("`@
M("H@0'!A<F%M("`@;6EX960@("!R;W<@=&\@9F5T8V@*("`@("`J($!R971U
M<FX@(&UI>&5D("`@82!R;W<@;V8@9&%T82P@3E5,3"!O;B!N;R!M;W)E(')O
M=W,*("`@("`J($!T:')O=W,@(&]B:F5C="`@1$)?17)R;W(*("`@("`J+PH@
M("`@9G5N8W1I;VX@9F5T8VA2;W<H)&9E=&-H;6]D92`]($1"7T9%5$-(34]$
M15]$149!54Q4+"`D<F]W;G5M(#T@;G5L;"D@>PH@("`@("`@(&EF("@D9F5T
M8VAM;V1E(#T]/2!$0E]&151#2$U/1$5?1$5&055,5"D@>PH@("`@("`@("`@
M("`D9F5T8VAM;V1E(#T@)'1H:7,M/F9E=&-H;6]D93L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D9F5T8VAM;V1E(#T]/2!$0E]&151#2$U/1$5?3T)*14-4
M*2!["B`@("`@("`@("`@("1F971C:&UO9&4@/2!$0E]&151#2$U/1$5?05-3
M3T,["B`@("`@("`@("`@("1R971U<FY?;V)J96-T(#T@=')U93L*("`@("`@
M("!]"B`@"B`@("`@("`@:68@*"1R;W=N=6T@/3T](&YU;&PI('L*("`@("`@
M("`@("`@)'1H:7,M/F-U<G-O<BLK.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3YC=7)S;W(@/2`D<F]W;G5M.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1R;W=N=6T@/"!S:7IE;V8H)'1H:7,M/G)O=W,I*2!["B`@
M("`@("`@("`@("1R;W<@/2`D=&AI<RT^<F]W<ULD=&AI<RT^8W5R<V]R73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*"1F971C:&UO9&4I('L*("`@("`@
M("`@("`@8V%S92!$0E]&151#2$U/1$5?05-33T,Z('L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<F5T=7)N7V]B:F5C="DI('L*("`@("`@("`@("`@
M("`@("`@("`D8VQA<W,@(#T@("1T:&ES+3YF971C:&UO9&5?;V)J96-T7V-L
M87-S.PH@("`@("`@("`@("`@("`@("`@("1O8FIE8W0@/28@;F5W("1C;&%S
M<R@D<F]W*3L*"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1O8FIE8W0[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<F]W.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!$0E]&151#
M2$U/1$5?3U)$15)%1#H@>PH@("`@("`@("`@("`@("`@)%]R;W<@/2!A<G)A
M>2@I.PH*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VQU;6Y?
M;F%M97,@87,@)&-O;'5M;E]N86UE*2!["B`@("`@("`@("`@("`@("`@("`@
M)%]R;W=;72`]("1R;W=;)&-O;'5M;E]N86UE73L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("!R971U<FX@)%]R;W<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT.B![
M"B`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H(&$@<F]W(&]F
M(&1A=&$@:6YT;R!A;B!E>&ES=&EN9R!V87)I86)L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@("!A<G)A>2`@(')E9F5R96YC92!T;R!D871A(&-O;G1A:6YI
M;F<@=&AE(')O=PH@("`@("H@0'!A<F%M("`@:6YT96=E<B!F;W)M870@;V8@
M9F5T8VAE9"!R;W<*("`@("`J($!P87)A;2`@(&EN=&5G97(@<F]W(&YU;6)E
M<B!T;R!F971C:`H@("`@("H@0')E='5R;B`@;6EX960@("!$0E]/2R!O;B!S
M=6-C97-S+"!.54Q,(&]N(&YO(&UO<F4@<F]W<PH@("`@("HO"B`@("!F=6YC
M=&EO;B!F971C:$EN=&\H)B1R;W<L("1F971C:&UO9&4@/2!$0E]&151#2$U/
M1$5?1$5&055,5"P@)')O=VYU;2`](&YU;&PI('L*("`@("`@("!I9B`H)')O
M=R`]("1T:&ES+3YF971C:%)O=R@D9F5T8VAM;V1E+"`D<F]W;G5M*2D@>PH@
M("`@("`@("`@("!R971U<FX@1$)?3TL["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N($Y53$P["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H92!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R
M97-U;'0@<V5T+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@;G5M
M8F5R(&]F(&-O;'5M;G,*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@I
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FYU;5]C;VQU;6YS.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E
M<W5L="!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!N=6UB
M97(@;V8@<F]W<PH@("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"D@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^;G5M7W)O=W,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&<F5E<R!T:&4@<F5S;W5R8V5S(&%L;&]C871E9"!F;W(@=&AI
M<R!R97-U;'0@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E*"D@>PH@
M("`@("`@("1T:&ES+3YC;VQU;6Y?;F%M97,@/2!A<G)A>2@I.PH@("`@("`@
M("1T:&ES+3YR;W=S("`@("`@("`@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES
M+3YN=6U?8V]L=6UN<R`@/2`P.PH@("`@("`@("1T:&ES+3YN=6U?<F]W<R`@
M("`@/2`P.PH@("`@?0H*("`@("\J*@H@("`@("H@=&%B;&5);F9O*"D@:7,@
M;F]T(&EM<&QE;65N=&5D(&EN('1H92!014%2($-A8VAE($1"(&UO9'5L92X*
M("`@("`J($!P87)A;2`@(&UI>&5D("`@)&UO9&4*("`@("`J($!T:')O=W,@
M(&]B:F5C="`@0V%C:&5?17)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@=&%B
M;&5);F9O*"1M;V1E(#T@;G5L;"D@>PH@("`@("`@(')E='5R;B!N97<@0V%C
M:&5?17)R;W(H"B`@("`@("`@("`G=&%B;&5);F9O*"D@:7,@;F]T(&EM<&QE
M;65N=&5D(&EN('1H92`G("X*("`@("`@("`@("=014%2($-A8VAE($1"(&UO
M9'5L92XG+`H@("`@("`@("`@7U]&24Q%7U\L"B`@("`@("`@("!?7TQ)3D5?
M7PH@("`@("`@("D["B`@("!]"GT*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-E<G9I8V5S
M+P``````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#`U`#`Q-S$R-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4V5R=FEC97,O5V5A=&AE<B\`````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#4`,#(P-3(T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]397)V:6-E<R]796%T:&5R+U=E
M871H97)D;W1C;VTN<&AP````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-C,S,P`Q,#0Q
M-S,V,S`P-0`P,C0P-3``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`-"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT.B`J+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK#0HO+R!\(%!(4"!V97)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\#0HO+R!\(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P-"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P-"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO
M<G,Z($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PT*+R\-"B\O("1)9#H@5V5A=&AE<F1O=&-O;2YP:'`L=B`Q+C(Y
M(#(P,#0O,#$O,C0@,3<Z-38Z,S4@97)U($5X<"`D#0H-"G)E<75I<F5?;VYC
M92`B4V5R=FEC97,O5V5A=&AE<B]#;VUM;VXN<&AP(CL-"@T*+R\@>WM[(&-L
M87-S(%-E<G9I8V5S7U=E871H97)?5V5A=&AE<F1O=&-O;0T*+RHJ#0HJ(%!%
M05(Z.E-E<G9I8V5S7U=E871H97)?5V5A=&AE<F1O=&-O;0T**@T**B!4:&ES
M(&-L87-S(&%C=',@87,@86X@:6YT97)F86-E('1O('1H92!X;6P@<V5R=FEC
M92!O9B!W96%T:&5R+F-O;2X@270@<V5A<F-H97,@9F]R(&=I=F5N#0HJ(&QO
M8V%T:6]N<R!A;F0@<F5T<FEE=F5S(&-U<G)E;G0@=V5A=&AE<B!D871A(&%S
M('=E;&P@87,@9F]R96-A<W0@9F]R('5P('1O(#$P(&1A>7,N#0HJ#0HJ($9O
M<B!U<VEN9R!T:&4@=V5A=&AE<BYC;VT@>&UL+7-E<G9I8V4@<&QE87-E('9I
M<VET#0HJ("`@("!H='1P.B\O=W=W+G=E871H97(N8V]M+W-E<G9I8V5S+WAM
M;&]A<"YH=&UL#0HJ(&%N9"!F;VQL;W<@=&AE(&QI;FL@=&\@<VEG;B!U<"P@
M:70G<R!F<F5E(2!9;W4@=VEL;"!R96-E:79E(&%N(&5M86EL('=H97)E('1O
M(&1O=VYL;V%D#0HJ('1H92!31$L@=VET:"!T:&4@;F5E9&5D(&EM86=E<R!A
M;F0@9W5I9&5L:6YE<R!H;W<@=&\@<'5B;&ES:"!L:79E(&1A=&$@9G)O;2!W
M96%T:&5R+F-O;2X-"BH@56YF;W)T=6YA=&5L>2!T:&4@9W5I9&5L:6YE<R!A
M<F4@82!B:70@:&%R<V@L('1H870G<R!W:'D@=&AE<F4G<R!N;R!A8W1U86P@
M9&%T82UR97!R97-E;G1A=&EO;@T**B!I;B!T:&ES(&-L87-S+"!J=7-T('1H
M92!R87<@9&%T82X-"BH@06QS;R!W96%T:&5R+F-O;2!D96UA;F1S(&%C=&EV
M92!C86-H:6YG+"!S;R!))V0@<W1R;VYG;'D@<F5C;VUM96YD(&5N86)L:6YG
M('1H92!C86-H:6YG#0HJ(&EM<&QE;65N=&5D(&EN('1H:7,@8VQA<W,N($ET
M(&]B97ES('1O('1H92!T:6UE<R!A<R!W<FET=&5N(&1O=VX@:6X@=&AE(&=U
M:61E;&EN97,N#0HJ#0HJ($9O<B!A('=O<FMI;F<@97AA;7!L92P@<&QE87-E
M('1A:V4@82!L;V]K(&%T#0HJ("`@("!D;V-S+U-E<G9I8V5S7U=E871H97(O
M97AA;7!L97,O=V5A=&AE<BYC;VTM8F%S:6,N<&AP#0HJ#0HJ($!A=71H;W(@
M("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@T**B!`;&EN
M:R`@("`@("`@(&AT='`Z+R]W=W<N=V5A=&AE<BYC;VTO<V5R=FEC97,O>&UL
M;V%P+FAT;6P-"BH@0&5X86UP;&4@("`@("!D;V-S+U-E<G9I8V5S7U=E871H
M97(O97AA;7!L97,O=V5A=&AE<BYC;VTM8F%S:6,N<&AP#0HJ($!P86-K86=E
M("`@("`@4V5R=FEC97-?5V5A=&AE<@T**B!`;&EC96YS92`@("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT#0HJ($!V97)S:6]N("`@
M("`@,2XR#0HJ+PT*8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]796%T:&5R9&]T
M8V]M(&5X=&5N9',@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX@>PT*#0H@("`@
M+R\@>WM[('!R;W!E<G1I97,-"B`@("`O*BH-"B`@("`J(%!A<G1N97(M240@
M870@=V5A=&AE<BYC;VT-"B`@("`J#0H@("`@*B!`=F%R("`@("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1?<&%R=&YE<DE$#0H@("`@*B!`86-C
M97-S("`@<')I=F%T90T*("`@("HO#0H@("`@=F%R("1?<&%R=&YE<DE$(#T@
M(B([#0H-"B`@("`O*BH-"B`@("`J($QI8V5N<V4@:V5Y(&%T('=E871H97(N
M8V]M#0H@("`@*@T*("`@("H@0'9A<B`@("`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D7VQI8V5N<V5+97D-"B`@("`J($!A8V-E<W,@("!P<FEV
M871E#0H@("`@*B\-"B`@("!V87(@)%]L:6-E;G-E2V5Y(#T@(B([#0H-"B`@
M("`O*BH-"B`@("`J(%A-3%]5;G-E<FEA;&EZ97(L('5S960@9F]R('!R;V-E
M<W-I;F<@=&AE('AM;`T*("`@("H-"B`@("`J($!V87(@("`@("!O8FIE8W0@
M6$U,7U5N<V5R:6%L:7IE<B`@("`@)%]U;G-E<FEA;&EZ97(-"B`@("`J($!A
M8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@("!V87(@)%]U;G-E<FEA;&EZ
M97([#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"B`@
M("`O*BH-"B`@("`J($-O;G-T<G5C=&]R#0H@("`@*@T*("`@("H@4F5Q=6ER
M97,@6$U,7U-E<FEA;&EZ97(@=&\@8F4@:6YS=&%L;&5D#0H@("`@*@T*("`@
M("H@0'!A<F%M("`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`D;W!T
M:6]N<PT*("`@("H@0'!A<F%M("`@(&UI>&5D("`@("`@("`@("`@("`@("`@
M("`@("`D97)R;W(-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R#0H@("`@
M*B!`<V5E("`@("`@4V-I96YC95]796%T:&5R.CI38VEE;F-E7U=E871H97(-
M"B`@("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B!397)V:6-E<U]796%T:&5R7U=E871H97)D;W1C;VTH)&]P=&EO;G,L("8D
M97)R;W(I#0H@("`@>PT*("`@("`@("`D<&5R<F]R(#T@;G5L;#L-"B`@("`@
M("`@)'1H:7,M/E-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O<'1I;VYS+"`D
M<&5R<F]R*3L-"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)'!E<G)O<BDI('L-"B`@("`@("`@("`@("1E<G)O<B`]("1P97)R;W([
M#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"@T*("`@("`@("`O
M+R!3970@;W!T:6]N<R!A8V-O<F1I;F=L>0T*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;(G!A<G1N97))1")=*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/G-E=$%C8V]U;G1$871A*"1O<'1I;VYS6R)P87)T;F5R240B72D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)L:6-E;G-E2V5Y
M(ETI*2![#0H@("`@("`@("`@("`D=&AI<RT^<V5T06-C;W5N=$1A=&$H(B(L
M("1O<'1I;VYS6R)L:6-E;G-E2V5Y(ETI.PT*("`@("`@("!]#0H@("`@("`@
M(`T*("`@("`@("!I;F-L=61E7V]N8V4@(EA-3"]5;G-E<FEA;&EZ97(N<&AP
M(CL-"B`@("`@("`@)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L
M:7IE<BAA<G)A>2@B8V]M<&QE>%1Y<&4B(#T^(")O8FIE8W0B+"`B:V5Y071T
M<FEB=71E(B`]/B`B='EP92(I*3L-"B`@("`@("`@:68@*%-E<G9I8V5S7U=E
M871H97(Z.FES17)R;W(H)'5N<V5R:6%L:7IE<BDI('L-"B`@("`@("`@("`@
M("1E<G)O<B`]("1U;G-E<FEA;&EZ97([#0H@("`@("`@("`@("!R971U<FX[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W5N<V5R
M:6%L:7IE<B`]("1U;G-E<FEA;&EZ97([#0H@("`@("`@('T-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@<V5T06-C;W5N=$1A=&$H*0T*("`@
M("\J*@T*("`@("H@4V5T<R!T:&4@;F5C8V5S<V%R>2!A8V-O=6YT+6EN9F]R
M;6%T:6]N(&9O<B!W96%T:&5R+F-O;2P@>6]U)VQL(')E8V5I=F4@=&AE;2!A
M9G1E<B!R96=I<W1E<FEN9R!F;W(@=&AE(%A-3"US=')E86T-"B`@("`J#0H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1P
M87)T;F5R240-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("`@("`@
M("`@("`@("`@)&QI8V5N<V5+97D-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-
M"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=$%C8V]U;G1$871A*"1P87)T;F5R
M240L("1L:6-E;G-E2V5Y*0T*("`@('L-"B`@("`@("`@:68@*'-T<FQE;B@D
M<&%R=&YE<DE$*2`F)B!C='EP95]D:6=I="@D<&%R=&YE<DE$*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]P87)T;F5R240@(#T@)'!A<G1N97))1#L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H<W1R;&5N*"1L:6-E;G-E2V5Y*2`F)B!C
M='EP95]A;&YU;2@D;&EC96YS94ME>2DI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?;&EC96YS94ME>2`]("1L:6-E;G-E2V5Y.PT*("`@("`@("!]#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]C:&5C:TQO8V%T:6]N240H
M*0T*("`@("\J*@T*("`@("H@0VAE8VMS('1H92!I9"!F;W(@=F%L:60@=F%L
M=65S(&%N9"!T:'5S('!R979E;G1S('-I;&QY(')E<75E<W1S('1O('=E871H
M97(N8V]M('-E<G9E<@T*("`@("H-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)&ED#0H@("`@*B!`<F5T=7)N("`@4$5!
M4E]%<G)O<GQB;V]L#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<CHZ4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3@T*("`@("H@0'1H<F]W
M<R`@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)
M1%],3T-!5$E/3@T*("`@("H@0&%C8V5S<R`@('!R:79A=&4-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(%]C:&5C:TQO8V%T:6]N240H)&ED*0T*("`@('L-"B`@
M("`@("`@:68@*"%S=')L96XH)&ED*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%
M4E]%4E)/4E].3U],3T-!5$E/3BD[#0H@("`@("`@('T@96QS96EF("@A8W1Y
M<&5?86QN=6TH)&ED*2!\?"`H<W1R;&5N*"1I9"D@/B`X*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].*3L-"B`@("`@
M("`@?0T*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]
M?7T-"@T*("`@("\O('M[>R!?<&%R<V5796%T:&5R1&%T82@I#0H@("`@+RHJ
M#0H@("`@*B!087)S97,@=&AE(&1A=&$@<F5T=7)N960@8GD@=&AE('!R;W9I
M9&5D(%523"!A;F0@8V%C:&5S(&ET#0H@("`@*@T*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D:60-"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'5R;`T*("`@("H@
M0')E='5R;B`@(%!%05)?17)R;W)\8F]O;`T*("`@("H@0'1H<F]W<R`@(%!%
M05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D52
M7T1!5$$-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R#0H@("`@*B!`86-C
M97-S("`@<')I=F%T90T*("`@("HO#0H@("`@9G5N8W1I;VX@7W!A<G-E5V5A
M=&AE<D1A=&$H)&ED+"`D=7)L*0T*("`@('L-"B`@("`@("`@+R\@1V5T(&1A
M=&$@9G)O;2!54DP@86YD('5N<V5R:6%L:7IE#0H@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^7W5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'5R;"P@=')U
M92D[#0H-"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H
M)'-T871U<RDI('L-"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T
M:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?
M4T525D527T1!5$$I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)')O;W0@/2`D=&AI<RT^7W5N<V5R:6%L:7IE<BT^9V5T4F]O=$YA;64H*3L-
M"B`@("`@("`@("`@("1D871A(#T@)'1H:7,M/E]U;G-E<FEA;&EZ97(M/F=E
M=%5N<V5R:6%L:7IE9$1A=&$H*3L-"@T*("`@("`@("`@("`@:68@*%-E<G9I
M8V5S7U=E871H97(Z.FES17)R;W(H)')O;W0I*2![#0H@("`@("`@("`@("`@
M("`@+R\@4V]M971H:6YG('=R;VYG(&AE<F4N+BX-"B`@("`@("`@("`@("`@
M("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%
M4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!*3L-"B`@("`@("`@
M("`@('T@96QS96EF("@D<F]O="`]/2`B97)R;W(B*2![#0H@("`@("`@("`@
M("`@("`@+R\@5V4@9V]T(&%N(&5R<F]R(&)A8VL@9G)O;2!W96%T:&5R+F-O
M;0T*("`@("`@("`@("`@("`@("1E<G)N;R`@/2!K97DH9V5T7V]B:F5C=%]V
M87)S*"1D871A*2D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S
M7U=E871H97(Z.G)A:7-E17)R;W(H)&5R<FYO*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@+R\@5F%L:60@9&%T82P@;&5T<R!G
M970@<W1A<G1E9`T*("`@("`@("`@("`@("`@("\O($QO;W`@=&AR;W5G:"!T
M:&4@9&EF9F5R96YT('-U8BUP87)T<R!O9B!T:&4@9&%T82!F<F\@<')O8V5S
M<VEN9PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*&=E=%]O8FIE8W1?=F%R
M<R@D9&%T82D@87,@)&ME>2`]/B`D=F%L*2![#0H@("`@("`@("`@("`@("`@
M("`@('-W:71C:"`H)&ME>2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B:&5A9"(Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64@,CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FQO8R(Z#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@(#T@(FQO8V%T:6]N(CL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@(F-C(CH-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R;F%M92`@/2`B=V5A=&AE<B([#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")D87EF(CH-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92`@/2`B9F]R96-A<W0B.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("\O(%-A=F4@9&%T82!I;B!O8FIE8W0-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/GLB7R(N)'9A<FYA;65](#T@)'9A;#L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@
M:68@<&]S<VEB;&4-"B`@("`@("`@("`@("`@("`@("`@("`@("1E>'!I<F4@
M/2!C;VYS=&%N="@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537R(N<W1R=&]U
M<'!E<B@D=F%R;F%M92DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C86-H92T^97AT4V%V92@D:60L("1V86PL("(B+"`D97AP:7)E+"`D
M=F%R;F%M92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@
M<V5A<F-H3&]C871I;VXH*0T*("`@("\J*@T*("`@("H@4V5A<F-H97,@241S
M(&9O<B!G:79E;B!L;V-A=&EO;BP@<F5T=7)N<R!A<G)A>2!O9B!P;W-S:6)L
M92!L;V-A=&EO;G,@;W(@<VEN9VQE($E$#0H@("`@*@T*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D;&]C871I;VX-"B`@
M("`J($!P87)A;2`@("!B;V]L("`@("`@("`@("`@("`@("`@("`@("`@)'5S
M949I<G-T("`@("`@($EF('-E="P@9FER<W0@240@;V8@<F5S=6QT+6%R<F%Y
M(&ES(')E='5R;F5D#0H@("`@*B!`<F5T=7)N("`@4$5!4E]%<G)O<GQA<G)A
M>7QS=')I;F<-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R.CI315)624-%
M4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!#0H@("`@*B!`=&AR
M;W=S("`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.
M3U=.7TQ/0T%424].#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!S96%R8VA,;V-A=&EO;B@D;&]C871I;VXL("1U<V5&
M:7)S="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@+R\@1V5T('-E87)C:"!D
M871A(&9R;VT@<V5R=F5R(&%N9"!U;G-E<FEA;&EZ90T*("`@("`@("`D<V5A
M<F-H55),(#T@(FAT='`Z+R]X;V%P+G=E871H97(N8V]M+W-E87)C:"]S96%R
M8V@_=VAE<F4](BYU<FQE;F-O9&4H=')I;2@D;&]C871I;VXI*3L-"B`@("`@
M("`@)'-T871U<R`]("1T:&ES+3Y?=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ
M92@D<V5A<F-H55),+"!T<G5E+"!A<G)A>2@B;W9E<G)I9&5/<'1I;VYS(B`]
M/B!T<G5E+"`B8V]M<&QE>%1Y<&4B(#T^(")A<G)A>2(L(")K97E!='1R:6)U
M=&4B(#T^(")I9"(I*3L-"@T*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE
M<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%402D[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`D<V5A<F-H(#T@)'1H:7,M/E]U;G-E<FEA;&EZ97(M/F=E
M=%5N<V5R:6%L:7IE9$1A=&$H*3L-"@T*("`@("`@("`@("`@:68@*%-E<G9I
M8V5S7U=E871H97(Z.FES17)R;W(H)'-E87)C:"DI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)6
M24-%4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!*3L-"B`@("`@
M("`@("`@('T@96QS96EF("@A:7-?87)R87DH)'-E87)C:"D@?'P@(7-I>F5O
M9B@D<V5A<F-H*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M54Y+3D]73E],3T-!5$E/3BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(&EF("@A)'5S949I<G-T("8F("AS:7IE;V8H)'-E87)C
M:"D@/B`Q*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<V5A<F-H4F5T=7)N
M(#T@)'-E87)C:#L-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'5S949I
M<G-T('Q\("AS:7IE;V8H)'-E87)C:"D@/3T@,2DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'-E87)C:%)E='5R;B`](&ME>2@D<V5A<F-H*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@
M("`@("!R971U<FX@)'-E87)C:%)E='5R;CL-"B`@("!]#0H@("`@+R\@?7U]
M#0H-"B`@("`O+R![>WL@<V5A<F-H3&]C871I;VY">4-O=6YT<GDH*0T*("`@
M("\J*@T*("`@("H@4F5T=7)N<R!O;FQY(&9A;'-E+"!A<R!W96%T:&5R+F-O
M;2!O9F9E<G,@;F\@8V]U;G1R>2!L:7-T:6YG('9I82`-"B`@("`J(&ET<R!8
M34P@<V5R=FEC97,@#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D8V]U;G1R>0T*("`@("H@0')E='5R;B`@
M(&)O;VP-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!D97!R96-A
M=&5D#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S96%R8VA,;V-A=&EO;D)Y0V]U
M;G1R>2@D8V]U;G1R>2`]("(B*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!G9715;FET
M<R@I#0H@("`@+RHJ#0H@("`@*B!2971U<FYS('1H92!U;FET<R!F;W(@=&AE
M(&-U<G)E;G0@<75E<GD-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1I9`T*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870-"B`@("`J
M($!R971U<FX@("!A<G)A>0T*("`@("H@0&1E<')E8V%T960-"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%5N:71S
M*"1I9"`](&YU;&PL("1U;FET<T9O<FUA="`]("(B*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YG9715;FET<T9O<FUA="@D=6YI='-&;W)M870I
M.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!G971,;V-A=&EO
M;B@I#0H@("`@+RHJ#0H@("`@*B!2971U<FYS('1H92!D871A(&9O<B!T:&4@
M;&]C871I;VX@8F5L;VYG:6YG('1O('1H92!)1`T*("`@("H-"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED#0H@("`@
M*B!`<F5T=7)N("`@4$5!4E]%<G)O<GQA<G)A>0T*("`@("H@0'1H<F]W<R`@
M(%!%05)?17)R;W(-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(&=E=$QO8V%T:6]N*"1I9"`]("(B*0T*("`@('L-"B`@
M("`@("`@)'-T871U<R`]("1T:&ES+3Y?8VAE8VM,;V-A=&EO;DE$*"1I9"D[
M#0H-"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T
M871U<RDI('L-"B`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PT*("`@("`@
M("!]#0H-"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N(#T@87)R87DH*3L-"B`@
M("`@("`@)&QO8V%T:6]N55),("`@(#T@(FAT='`Z+R]X;V%P+G=E871H97(N
M8V]M+W=E871H97(O;&]C86PO(BXD:60N(C]P<F]D/7AO87`F<&%R/2(N)'1H
M:7,M/E]P87)T;F5R240N(B9K97D](BXD=&AI<RT^7VQI8V5N<V5+97DN(B9U
M;FET/7,B.PT*#0H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F
M)B`H)&QO8V%T:6]N(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@(FQO8V%T
M:6]N(BDI*2![#0H@("`@("`@("`@("`O+R!'970@9&%T82!F<F]M(&-A8VAE
M#0H@("`@("`@("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@)&QO8V%T:6]N.PT*
M("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=(#T@(DA)5"([
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`O+R!386UE(&%S(&EN
M('1H92!F=6YC=&EO;B!A8F]V92XN+@T*("`@("`@("`@("`@)'-T871U<R`]
M("1T:&ES+3Y?<&%R<V5796%T:&5R1&%T82@D:60L("1L;V-A=&EO;E523"D[
M#0H-"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R
M*"1S=&%T=7,I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D;&]C871I;VY2971U<FY;
M(F-A8VAE(ET@/2`B34E34R([#0H@("`@("`@('T-"B`@("`@("`@)&QO8V%T
M:6]N4F5T=7)N6R)N86UE(ET@("`@("`]("1T:&ES+3Y?;&]C871I;VXM/F1N
M86T[#0H@("`@("`@("1L;V-A=&EO;E)E='5R;ELB=&EM92)=("`@("`@/2!D
M871E*"1T:&ES+3Y?=&EM949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?;&]C
M871I;VXM/G1M*2D[#0H@("`@("`@("1L;V-A=&EO;E)E='5R;ELB;&%T:71U
M9&4B72`@/2`D=&AI<RT^7VQO8V%T:6]N+3YL870[#0H@("`@("`@("1L;V-A
M=&EO;E)E='5R;ELB;&]N9VET=61E(ET@/2`D=&AI<RT^7VQO8V%T:6]N+3YL
M;VX[#0H@("`@("`@("1L;V-A=&EO;E)E='5R;ELB<W5N<FES92)=("`@/2!D
M871E*"1T:&ES+3Y?=&EM949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?;&]C
M871I;VXM/G-U;G(I*3L-"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)S=6YS
M970B72`@("`](&1A=&4H)'1H:7,M/E]T:6UE1F]R;6%T+"!S=')T;W1I;64H
M)'1H:7,M/E]L;V-A=&EO;BT^<W5N<RDI.PT*("`@("`@("`D;&]C871I;VY2
M971U<FY;(G1I;65Z;VYE(ET@(#T@)'1H:7,M/E]L;V-A=&EO;BT^>F]N93L-
M"@T*("`@("`@("!R971U<FX@)&QO8V%T:6]N4F5T=7)N.PT*("`@('T-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!G971796%T:&5R*"D-"B`@("`O*BH-
M"B`@("`J(%)E='5R;G,@=&AE('=E871H97(M9&%T82!F;W(@=&AE('-U<'!L
M:65D(&QO8V%T:6]N#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D:60-"B`@("`J($!P87)A;2`@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T#0H@("`@*B!`
M<F5T=7)N("`@4$5!4E]%<G)O<GQA<G)A>0T*("`@("H@0'1H<F]W<R`@(%!%
M05)?17)R;W(-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=%=E871H97(H)&ED(#T@(B(L("1U;FET<T9O<FUA="`]
M("(B*0T*("`@('L-"B`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8VAE8VM,
M;V-A=&EO;DE$*"1I9"D[#0H-"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'-T871U<RDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M<W1A='5S.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@1V5T(&]T:&5R(&1A
M=&$-"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E=%5N:71S1F]R;6%T
M*"1U;FET<T9O<FUA="D[#0H-"B`@("`@("`@)'=E871H97)2971U<FX@/2!A
M<G)A>2@I.PT*("`@("`@("`D=V5A=&AE<E523"`@("`](")H='1P.B\O>&]A
M<"YW96%T:&5R+F-O;2]W96%T:&5R+VQO8V%L+R(N)&ED+B(_8V,]*B9P<F]D
M/7AO87`F<&%R/2(N)'1H:7,M/E]P87)T;F5R240N(B9K97D](BXD=&AI<RT^
M7VQI8V5N<V5+97DN(B9U;FET/7,B.PT*#0H@("`@("`@(&EF("@D=&AI<RT^
M7V-A8VAE16YA8FQE9"`F)B`H)'=E871H97(@/2`D=&AI<RT^7V-A8VAE+3YG
M970H)&ED+"`B=V5A=&AE<B(I*2D@>PT*("`@("`@("`@("`@+R\@4V%M92!P
M<F]C961U<F4N+BX-"B`@("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W
M96%T:&5R.PT*("`@("`@("`@("`@)'=E871H97)2971U<FY;(F-A8VAE(ET@
M/2`B2$E4(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O("XN
M+F%S(&QA<W0@9G5N8W1I;VX-"B`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI
M<RT^7W!A<G-E5V5A=&AE<D1A=&$H)&ED+"`D=V5A=&AE<E523"D[#0H-"B`@
M("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T
M=7,I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B
M72`](")-25-3(CL-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@)'5P
M9&%T92`@/2!S=')?<F5P;&%C92@B3&]C86P@5&EM92(L("(B+"`D=&AI<RT^
M7W=E871H97(M/FQS=7`I.PT*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=7!D
M871E(ET@("`@("`@("`@("`](&=M9&%T92AT<FEM*"1T:&ES+3Y?9&%T949O
M<FUA="XB("(N)'1H:7,M/E]T:6UE1F]R;6%T*2P@<W1R=&]T:6UE*"1U<&1A
M=&4I*3L-"B`@("`@("`@)'=E871H97)2971U<FY;(G-T871I;VXB72`@("`@
M("`@("`@/2`D=&AI<RT^7W=E871H97(M/F]B<W0[#0H@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)T96UP97)A='5R92)=("`@("`@(#T@)'1H:7,M/F-O;G9E
M<G1496UP97)A='5R92@D=&AI<RT^7W=E871H97(M/G1M<"P@(F8B+"`D=6YI
M='-;(G1E;7`B72D[#0H@("`@("`@("1W96%T:&5R4F5T=7)N6R)F96QT5&5M
M<&5R871U<F4B72`@(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=&AI
M<RT^7W=E871H97(M/F9L:6LL(")F(BP@)'5N:71S6R)T96UP(ETI.PT*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET:6]N(ET@("`@("`@("`]("1T
M:&ES+3Y?=V5A=&AE<BT^=#L-"B`@("`@("`@)'=E871H97)2971U<FY;(F-O
M;F1I=&EO;DEC;VXB72`@("`@/2`D=&AI<RT^7W=E871H97(M/FEC;VX[#0H@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)P<F5S<W5R92)=("`@("`@("`@(#T@
M)'1H:7,M/F-O;G9E<G10<F5S<W5R92@D=&AI<RT^7W=E871H97(M/F)A<BT^
M<BP@(FEN(BP@)'5N:71S6R)P<F5S(ETI.PT*("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB<')E<W-U<F54<F5N9")=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^
M8F%R+3YD.PT*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9")=("`@("`@
M("`@("`@("`]("1T:&ES+3YC;VYV97)T4W!E960H)'1H:7,M/E]W96%T:&5R
M+3YW:6YD+3YS+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI.PT*("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=VEN9$1E9W)E97,B72`@("`@("`]("1T:&ES+3Y?
M=V5A=&AE<BT^=VEN9"T^9#L-"B`@("`@("`@)'=E871H97)2971U<FY;(G=I
M;F1$:7)E8W1I;VXB72`@("`@/2`D=&AI<RT^7W=E871H97(M/G=I;F0M/G0[
M#0H@("`@("`@("1W96%T:&5R4F5T=7)N6R)H=6UI9&ET>2)=("`@("`@("`@
M(#T@)'1H:7,M/E]W96%T:&5R+3YH;6ED.PT*("`@("`@("!I9B`H:7-?;G5M
M97)I8R@D=&AI<RT^7W=E871H97(M/G9I<RDI('L-"B`@("`@("`@("`@("1W
M96%T:&5R4F5T=7)N6R)V:7-I8FEL:71Y(ET@("`@/2`D=&AI<RT^8V]N=F5R
M=$1I<W1A;F-E*"1T:&ES+3Y?=V5A=&AE<BT^=FES+"`B<VTB+"`D=6YI='-;
M(G9I<R)=*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)V:7-I8FEL:71Y(ET@("`@/2`D=&AI<RT^7W=E871H97(M
M/G9I<SL-"B`@("`@("`@?0T*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=79)
M;F1E>")=("`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=78M/FD[#0H@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)U=E1E>'0B72`@("`@("`@("`@(#T@
M)'1H:7,M/E]W96%T:&5R+3YU=BT^=#L-"B`@("`@("`@)'=E871H97)2971U
M<FY;(F1E=U!O:6YT(ET@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E
M<F%T=7)E*"1T:&ES+3Y?=V5A=&AE<BT^9&5W<"P@(F8B+"`D=6YI='-;(G1E
M;7`B72D[#0H-"B`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PT*("`@
M('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!G971&;W)E8V%S="@I#0H@
M("`@+RHJ#0H@("`@*B!'970@=&AE(&9O<F5C87-T(&9O<B!T:&4@;F5X="!D
M87ES#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D:60-"B`@("`J($!P87)A;2`@("!I;G0@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A>7,@("`@("`@("`@(%9A;'5E<R!B971W965N
M(#$@86YD(#$P#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1U;FET<T9O<FUA=`T*("`@("H@0')E='5R;B`@(%!%05)?
M17)R;W)\87)R87D-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R#0H@("`@
M*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971&
M;W)E8V%S="@D:60@/2`B(BP@)&1A>7,@/2`R+"`D=6YI='-&;W)M870@/2`B
M(BD-"B`@("![#0H@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C
M871I;VY)1"@D:60I.PT*#0H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1S=&%T=7,I*2![#0H@("`@("`@("`@("!R971U<FX@)'-T
M871U<SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1D87ES
M+"!R86YG92@Q+"`Q,"DI*2![#0H@("`@("`@("`@("`D9&%Y<R`](#([#0H@
M("`@("`@('T-"B`@("`@("`@#0H@("`@("`@("\O($=E="!O=&AE<B!D871A
M#0H@("`@("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET<T9O<FUA="@D
M=6YI='-&;W)M870I.PT*#0H@("`@("`@("1F;W)E8V%S=%)E='5R;B`](&%R
M<F%Y*"D[#0H@("`@("`@("1F;W)E8V%S=%523"`](")H='1P.B\O>&]A<"YW
M96%T:&5R+F-O;2]W96%T:&5R+VQO8V%L+R(N)&ED+B(_9&%Y9CTQ,"9P<F]D
M/7AO87`F<&%R/2(N)'1H:7,M/E]P87)T;F5R240N(B9K97D](BXD=&AI<RT^
M7VQI8V5N<V5+97DN(B9U;FET/7,B.PT*#0H@("`@("`@(&EF("@D=&AI<RT^
M7V-A8VAE16YA8FQE9"`F)B`H)&9O<F5C87-T(#T@)'1H:7,M/E]C86-H92T^
M9V5T*"1I9"P@(F9O<F5C87-T(BDI*2![#0H@("`@("`@("`@("`O+R!%;F-O
M<F4N+BX-"B`@("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@/2`D9F]R96-A
M<W0[#0H@("`@("`@("`@("`D9F]R96-A<W12971U<FY;(F-A8VAE(ET@/2`B
M2$E4(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O("XN+@T*
M("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?<&%R<V5796%T:&5R1&%T
M82@D:60L("1F;W)E8V%S=%523"P@)&1A>7,I.PT*#0H@("`@("`@("`@("!I
M9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B
M.PT*("`@("`@("!]#0H-"B`@("`@("`@)'5P9&%T92`](&EM<&QO9&4H(B`B
M+"!A<G)A>5]S;&EC92AE>'!L;V1E*"(@(BP@)'1H:7,M/E]F;W)E8V%S="T^
M;'-U<"`I+"`P+"`S*2D[#0H-"B`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)U
M<&1A=&4B72`](&1A=&4H)'1H:7,M/E]D871E1F]R;6%T+B(@(BXD=&AI<RT^
M7W1I;65&;W)M870L('-T<G1O=&EM92@D=7!D871E*2D[#0H@("`@("`@("1F
M;W)E8V%S=%)E='5R;ELB9&%Y<R)=("`@/2!A<G)A>2@I.PT*#0H@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1D87ES.R`D:2LK*2![#0H@("`@("`@("`@
M("`D9&%Y(#T@87)R87DH#0H@("`@("`@("`@("`@("`@(G1E;7!E<G1U<F5(
M:6=H(B`]/B`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1T:&ES+3Y?9F]R
M96-A<W0M/F1A>5LD:5TM/FAI+"`B9B(L("1U;FET<ULB=&5M<")=*2P-"B`@
M("`@("`@("`@("`@("`B=&5M<&5R871U<F5,;W<B(#T^("1T:&ES+3YC;VYV
M97)T5&5M<&5R871U<F4H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^;&]W
M+"`B9B(L("1U;FET<ULB=&5M<")=*2P-"B`@("`@("`@("`@("`@("`B<W5N
M<FES92(@("`@("`@(#T^(&1A=&4H)'1H:7,M/E]T:6UE1F]R;6%T+"!S=')T
M;W1I;64H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<W5N<BDI+`T*("`@
M("`@("`@("`@("`@(")S=6YS970B("`@("`@("`@/3X@9&%T92@D=&AI<RT^
M7W1I;65&;W)M870L('-T<G1O=&EM92@D=&AI<RT^7V9O<F5C87-T+3YD87E;
M)&E=+3YS=6YS*2DL#0H@("`@("`@("`@("`@("`@(F1A>2(@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@(")C;VYD:71I;VXB("`@("`]/B`D=&AI
M<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S!=+3YT+`T*("`@("`@("`@
M("`@("`@("`@("`B8V]N9&ET:6]N26-O;B(@/3X@)'1H:7,M/E]F;W)E8V%S
M="T^9&%Y6R1I72T^<&%R=%LP72T^:6-O;BP-"B`@("`@("`@("`@("`@("`@
M("`@(G=I;F0B("`@("`@("`@(#T^("1T:&ES+3YC;VYV97)T4W!E960H)'1H
M:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LP72T^=VEN9"T^<RP@(FUP
M:"(L("1U;FET<ULB=VEN9")=*2P-"B`@("`@("`@("`@("`@("`@("`@(G=I
M;F1'=7-T(B`@("`@(#T^("1T:&ES+3YC;VYV97)T4W!E960H)'1H:7,M/E]F
M;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LP72T^=VEN9"T^9W5S="P@(FUP:"(L
M("1U;FET<ULB=VEN9")=*2P-"B`@("`@("`@("`@("`@("`@("`@(G=I;F1$
M96=R965S(B`@(#T^("1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;
M,%TM/G=I;F0M/F0L#0H@("`@("`@("`@("`@("`@("`@(")W:6YD1&ER96-T
M:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S!=+3YW
M:6YD+3YT+`T*("`@("`@("`@("`@("`@("`@("`B<')E8VEP:71A=&EO;B(@
M/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LP72T^<'!C<"P-
M"B`@("`@("`@("`@("`@("`@("`@(FAU;6ED:71Y(B`@("`@(#T^("1T:&ES
M+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,%TM/FAM:60-"B`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@(")N:6=H="(@/3X@87)R87D@
M*`T*("`@("`@("`@("`@("`@("`@("`B8V]N9&ET:6]N(B`@("`@/3X@)'1H
M:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^="P-"B`@("`@("`@
M("`@("`@("`@("`@(F-O;F1I=&EO;DEC;VXB(#T^("1T:&ES+3Y?9F]R96-A
M<W0M/F1A>5LD:5TM/G!A<G1;,5TM/FEC;VXL#0H@("`@("`@("`@("`@("`@
M("`@(")W:6YD(B`@("`@("`@("`]/B`D=&AI<RT^8V]N=F5R=%-P965D*"1T
M:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM/G=I;F0M/G,L(")M
M<&@B+"`D=6YI='-;(G=I;F0B72DL#0H@("`@("`@("`@("`@("`@("`@(")W
M:6YD1W5S="(@("`@("`]/B`D=&AI<RT^8V]N=F5R=%-P965D*"1T:&ES+3Y?
M9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM/G=I;F0M/F=U<W0L(")M<&@B
M+"`D=6YI='-;(G=I;F0B72DL#0H@("`@("`@("`@("`@("`@("`@(")W:6YD
M1&5G<F5E<R(@("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T
M6S%=+3YW:6YD+3YD+`T*("`@("`@("`@("`@("`@("`@("`B=VEN9$1I<F5C
M=&EO;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^
M=VEN9"T^="P-"B`@("`@("`@("`@("`@("`@("`@(G!R96-I<&ET871I;VXB
M(#T^("1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM/G!P8W`L
M#0H@("`@("`@("`@("`@("`@("`@(")H=6UI9&ET>2(@("`@("`]/B`D=&AI
M<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YH;6ED#0H@("`@("`@
M("`@("`@("`@*0T*("`@("`@("`@("`@*3L-"@T*("`@("`@("`@("`@)&9O
M<F5C87-T4F5T=7)N6R)D87ES(EU;72`]("1D87D[#0H@("`@("`@('T-"@T*
M("`@("`@("!R971U<FX@)&9O<F5C87-T4F5T=7)N.PT*("`@('T-"B`@("`O
M+R!]?7T-"GT-"B\O('U]?0T*/SX-"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H
M97(O365T87(N<&AP````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,34R,S(S
M`#$P-#$W,S8S,#`U`#`R,C,Q,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`T*+RH@=FEM.B!S970@97AP86YD=&%B
M('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@
M("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@
M075T:&]R<SH@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!-971A<BYP:'`L=B`Q+C,T(#(P
M,#0O,#$O,#8@,3DZ,S8Z,C<@97)U($5X<"`D#0H-"G)E<75I<F5?;VYC92`B
M4V5R=FEC97,O5V5A=&AE<B]#;VUM;VXN<&AP(CL-"@T*<F5Q=6ER95]O;F-E
M(")$0BYP:'`B.PT*#0HO+R![>WL@8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]-
M971A<@T*+RHJ#0HJ(%!%05(Z.E-E<G9I8V5S7U=E871H97)?365T87(-"BH-
M"BH@5&AI<R!C;&%S<R!A8W1S(&%S(&%N(&EN=&5R9F%C92!T;R!T:&4@;65T
M87(@<V5R=FEC92!O9B!W96%T:&5R+FYO86$N9V]V+B!)="!S96%R8VAE<R!F
M;W(-"BH@;&]C871I;VYS(&=I=F5N(&EN($E#04\@;F]T871I;VX@86YD(')E
M=')I979E<R!T:&4@8W5R<F5N="!W96%T:&5R(&1A=&$N#0HJ#0HJ($]F(&-O
M=7)S92!T:&4@<&%R<VEN9R!O9B!T:&4@345405(M9&%T82!H87,@:71S(&QI
M;6ET871I;VYS+"!A<R!I="!F;VQL;W=S('1H90T**B!&961E<F%L($UE=&5O
M<F]L;V=I8V%L($AA;F1B;V]K($YO+C$@=VET:"!M;V1I9FEC871I;VYS('1O
M(&%C8V]M;V1A=&4@9F]R(&YO;BU54R!R97!O<G1S+`T**B!S;R!I9B!T:&4@
M<F5P;W)T(&1E=FEA=&5S(&9R;VT@=&AE<V4@<W1A;F1A<F1S+"!Y;W4@=V]N
M)W0@9V5T(&ET('!A<G-E9"!C;W)R96-T;'DN#0HJ($%N>71H:6YG('1H870@
M:7,@;F]T('!A<G-E9"P@:7,@<V%V960@:6X@=&AE(")N;W!A<G-E(B!A<G)A
M>2UE;G1R>2P@<F5T=7)N960@8GD-"BH@9V5T5V5A=&AE<B@I+"!S;R!Y;W4@
M8V%N(&1O('EO=7(@;W=N('!A<G-I;F<@869T97)W87)D<RX@5&AI<R!L:6UI
M=&%T:6]N(&ES('-P96-I9FEC86QL>0T**B!G:79E;B!F;W(@<F5M87)K<RP@
M87,@=&AE(&-L87-S(&ES(&YO="!P<F]C97-S:6YG(&5V97)Y=&AI;F<@;65N
M=&EO;F5D('1H97)E+"!B=70@>6]U('=I;&P-"BH@9V5T('1H92!M;W-T(&-O
M;6UO;B!F:65L9',@;&EK92!P<F5C:7!I=&%T:6]N(&%N9"!T96UP97)A='5R
M92UC:&%N9V5S+B!!9V%I;BP@979E<GET:&EN9PT**B!N;W0@<&%R<V5D+"!G
M;V5S(&EN=&\@(FYO<&%R<V4B+@T**@T**B!)9B!Y;W4@=&AI;FLL('-O;64@
M:6UP;W)T86YT(&9I96QD(&ES(&UI<W-I;F<@;W(@;F]T(&-O<G)E8W1L>2!P
M87)S960L('!L96%S92!F:6QE(&$@9F5A='5R92T-"BH@<F5Q=65S="]B=6=R
M97!O<G0@870@:'1T<#HO+W!E87(N<&AP+FYE="\@86YD(&)E('-U<F4@=&\@
M<')O=FED92!T:&4@345405(@<F5P;W)T('=I=&@@80T**B!?9&5T86EL961?
M(&5X<&QA;F%T:6]N(0T**@T**B!&;W(@82!W;W)K:6YG(&5X86UP;&4L('!L
M96%S92!T86ME(&$@;&]O:R!A=`T**B`@("`@9&]C<R]397)V:6-E<U]796%T
M:&5R+V5X86UP;&5S+VUE=&%R+6)A<VEC+G!H<`T**@T**B!`875T:&]R("`@
M("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X-"BH@0&QI;FL@
M("`@("`@("!H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]W96%T:&5R+VUE=&%R
M+G-H=&UL#0HJ($!E>&%M<&QE("`@("`@9&]C<R]397)V:6-E<U]796%T:&5R
M+V5X86UP;&5S+VUE=&%R+6)A<VEC+G!H<`T**B!`<&%C:V%G92`@("`@(%-E
M<G9I8V5S7U=E871H97(-"BH@0&QI8V5N<V4@("`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X=`T**B!`=F5R<VEO;B`@("`@(#$N,@T*
M*B\-"F-L87-S(%-E<G9I8V5S7U=E871H97)?365T87(@97AT96YD<R!397)V
M:6-E<U]796%T:&5R7T-O;6UO;@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S
M#0H@("`@+RHJ#0H@("`@*B!);F9O<FUA=&EO;B!T;R!A8V-E<W,@=&AE(&QO
M8V%T:6]N($1"#0H@("`@*@T*("`@("H@0'9A<B`@("`@(&]B:F5C="`@1$(@
M("`@("`@("`@("`@("`@("`D7V1B#0H@("`@*B!`86-C97-S("`@<')I=F%T
M90T*("`@("HO#0H@("`@=F%R("1?9&([#0H@("`@#0H@("`@+RHJ#0H@("`@
M*B!4:&4@<V]U<F-E($U%5$%2('5S97,-"B`@("`J#0H@("`@*B!`=F%R("`@
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1?<V]U<F-E#0H@("`@
M*B!`86-C97-S("`@<')I=F%T90T*("`@("HO#0H@("`@=F%R("1?<V]U<F-E
M.PT*#0H@("`@+RHJ#0H@("`@*B!4:&ES('!A=&@@:7,@=7-E9"!T;R!F:6YD
M('1H92!-151!4B!D871A#0H@("`@*@T*("`@("H@0'9A<B`@("`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D7W-O=7)C95!A=&@-"B`@("`J($!A
M8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@("!V87(@)%]S;W5R8V50871H
M.PT*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H@("`@
M+RHJ#0H@("`@*B!#;VYS=')U8W1O<@T*("`@("H-"B`@("`J($!P87)A;2`@
M("!A<G)A>2`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G,-"B`@("`J
M($!P87)A;2`@("!M:7AE9"`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R
M#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<@T*("`@("H@0'-E92`@("`@
M(%-C:65N8V5?5V5A=&AE<CHZ4V-I96YC95]796%T:&5R#0H@("`@*B!`86-C
M97-S("`@<')I=F%T90T*("`@("HO#0H@("`@9G5N8W1I;VX@4V5R=FEC97-?
M5V5A=&AE<E]-971A<B@D;W!T:6]N<RP@)B1E<G)O<BD-"B`@("![#0H@("`@
M("`@("1P97)R;W(@/2!N=6QL.PT*("`@("`@("`D=&AI<RT^4V5R=FEC97-?
M5V5A=&AE<E]#;VUM;VXH)&]P=&EO;G,L("1P97)R;W(I.PT*("`@("`@("!I
M9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<&5R<F]R*2D@>PT*("`@
M("`@("`@("`@)&5R<F]R(#T@)'!E<G)O<CL-"B`@("`@("`@("`@(')E='5R
M;CL-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@4V5T(&]P=&EO
M;G,@86-C;W)D:6YG;'D@("`@("`@(`T*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;(F1S;B)=*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R)D8D]P=&EO;G,B72DI('L-"B`@("`@("`@("`@("`@("`D<W1A='5S
M(#T@)'1H:7,M/G-E=$UE=&%R1$(H)&]P=&EO;G-;(F1S;B)=+"`D;W!T:6]N
M<ULB9&)/<'1I;VYS(ETI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/G-E=$UE=&%R1$(H)&]P=&EO
M;G-;(F1S;B)=*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PT*
M("`@("`@("`@("`@)&5R<F]R(#T@)'-T871U<SL-"B`@("`@("`@("`@(')E
M='5R;CL-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6R)S;W5R8V4B72DI('L-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D;W!T:6]N<ULB<V]U<F-E4&%T:")=*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YS971-971A<E-O=7)C92@D;W!T:6]N<ULB<V]U<F-E(ETL("1O
M<'1I;VYS6R)S;W5R8V50871H(ETI.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T365T87)3;W5R8V4H)&]P=&EO
M;G-;(G-O=7)C92)=*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1T:&ES+3YS971-971A<E-O=7)C92@B:'1T<"(I
M.PT*("`@("`@("!]#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M('-E=$UE=&%R1$(H*0T*("`@("\J*@T*("`@("H@4V5T<R!T:&4@<&%R86UE
M=&5R<R!N965D960@9F]R(&-O;FYE8W1I;F<@=&\@=&AE($1"+"!W:&5R92!T
M:&4@;&]C871I;VXM#0H@("`@*B!S96%R8V@@:7,@9F5T8VAI;F<@:71S(&1A
M=&$@9G)O;2X@66]U(&YE960@=&\@8G5I;&0@82!$0B!W:71H('1H92!E>'1E
M<FYA;`T*("`@("H@=&]O;"!B=6EL9$UE=&%R1$(@9FER<W0L(&ET(&9E=&-H
M97,@=&AE(&QO8V%T:6]N<R!A;F0@86ER<&]R=',@9G)O;2!A#0H@("`@*B!.
M3T%!+7=E8G-I=&4N#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D9'-N#0H@("`@*B!`<&%R86T@("`@87)R
M87D@("`@("`@("`@("`@("`@("`@("`@("1D8D]P=&EO;G,-"B`@("`J($!R
M971U<FX@("!$0E]%<G)O<GQB;V]L#0H@("`@*B!`=&AR;W=S("`@1$)?17)R
M;W(-"B`@("`J($!S964@("`@("!$0CHZ<&%R<V5$4TX-"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=$UE=&%R1$(H
M)&1S;BP@)&1B3W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D
M9'-N:6YF;R`]($1".CIP87)S94133B@D9'-N*3L-"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1D<VYI;F9O*2`F)B`A:7-S970H)&1S;FEN9F];(FUO9&4B72DI
M('L-"B`@("`@("`@("`@("1D<VYI;F9O6R)M;V1E(ET](#`V-#0[#0H@("`@
M("`@('T-"B`@("`@("`@#0H@("`@("`@("\O($EN:71I86QI>F4@8V]N;F5C
M=&EO;B!T;R!$0B!A;F0@<W1O<F4@:6X@;V)J96-T(&EF('-U8V-E<W-F=6P-
M"B`@("`@("`@)&1B(#T@($1".CIC;VYN96-T*"1D<VYI;F9O+"`D9&)/<'1I
M;VYS*3L-"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1D8BDI('L-"B`@("`@
M("`@("`@(')E='5R;B`D9&([#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]D8B`]("1D8CL-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@<V5T365T87)3;W5R8V4H*0T*("`@
M("\J*@T*("`@("H@4V5T<R!T:&4@<V]U<F-E+"!W:&5R92!T:&4@8VQA<W,@
M=')I97,@=&\@;&]C871E('1H92!-151!4B!D871A#0H@("`@*@T*("`@("H@
M4V]U<F-E(&-A;B!B92!H='1P+"!F='`@;W(@9FEL92X-"B`@("`J($%N(&%L
M=&5R;F%T92!S;W5R8V5P871H(&-A;B!B92!P<F]V:61E9"X-"B`@("`J#0H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1S
M;W5R8V4-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@
M("`@("`@)'-O=7)C95!A=&@-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J+PT*("`@(&9U;F-T:6]N('-E=$UE=&%R4V]U<F-E*"1S;W5R8V4L("1S
M;W5R8V50871H(#T@(B(I#0H@("`@>PT*("`@("`@("!I9B`H:6Y?87)R87DH
M)'-O=7)C92P@87)R87DH(FAT='`B+"`B9G1P(BP@(F9I;&4B*2DI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?<V]U<F-E(#T@)'-O=7)C93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H<W1R;&5N*"1S;W5R8V50871H*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]S;W5R8V50871H(#T@)'-O=7)C95!A=&@[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!S=VET8V@@*"1S;W5R8V4I('L-
M"B`@("`@("`@("`@("`@("!C87-E(")H='1P(CH-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S;W5R8V50871H(#T@(FAT='`Z+R]W96%T:&5R+FYO
M86$N9V]V+W!U8B]D871A+V]B<V5R=F%T:6]N<R]M971A<B]S=&%T:6]N<R\B
M.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@
M("!C87-E(")F='`B.@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O
M=7)C95!A=&@@/2`B9G1P.B\O=V5A=&AE<BYN;V%A+F=O=B]D871A+V]B<V5R
M=F%T:6]N<R]M971A<B]S=&%T:6]N<R\B.PT*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E(")F:6QE(CH-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V50871H(#T@(BXO(CL-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V-H96-K
M3&]C871I;VY)1"@I#0H@("`@+RHJ#0H@("`@*B!#:&5C:W,@=&AE(&ED(&9O
M<B!V86QI9"!V86QU97,@86YD('1H=7,@<')E=F5N=',@<VEL;'D@<F5Q=65S
M=',@=&\@345405(@<V5R=F5R#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D:60-"B`@("`J($!R971U<FX@
M("!014%27T5R<F]R?&)O;VP-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R
M.CI315)624-%4U]714%42$527T524D]27TY/7TQ/0T%424].#0H@("`@*B!`
M=&AR;W=S("`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E])
M3E9!3$E$7TQ/0T%424].#0H@("`@*B!`86-C97-S("`@<')I=F%T90T*("`@
M("HO#0H@("`@9G5N8W1I;VX@7V-H96-K3&]C871I;VY)1"@D:60I#0H@("`@
M>PT*("`@("`@("!I9B`H(7-T<FQE;B@D:60I*2![#0H@("`@("`@("`@("!R
M971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]7
M14%42$527T524D]27TY/7TQ/0T%424].*3L-"B`@("`@("`@?2!E;'-E:68@
M*"%C='EP95]A;'!H82@D:60I('Q\("AS=')L96XH)&ED*2`^(#0I*2![#0H@
M("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O
M<BA315)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TXI.PT*
M("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(%]P87)S95=E871H97)$871A*"D-"B`@
M("`O*BH-"B`@("`J(%!A<G-E<R!T:&4@9&%T82!R971U<FYE9"!B>2!T:&4@
M<')O=FED960@<V]U<F-E(&%N9"!C86-H97,@:70-"B`@("`J("`@(`T*("`@
M("H@345405(@2U!)5"`P.3$Y-35:($-/4B`R,C`Q-4<R-4M4(#,O-%--(%(R
M.$PO,C8P,$94(%134D$@3U9#,#$P0T(@,3@O,38@03(Y.3(@4DU+(%-,4#`T
M-2!4,#$X,C`Q-3D-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1S;W5R8V4-"B`@("`J($!R971U<FX@("!0
M14%27T5R<F]R?&%R<F%Y#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<CHZ
M4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%400T*("`@
M("H@0'1H<F]W<R`@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)2
M3U)?54Y+3D]73E],3T-!5$E/3@T*("`@("H@0&%C8V5S<R`@('!R:79A=&4-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(%]P87)S95=E871H97)$871A*"1S;W5R
M8V4I#0H@("`@>PT*("`@("`@("!S=&%T:6,@)&-O;7!A<W,[#0H@("`@("`@
M('-T871I8R`D8VQO=61S.PT*("`@("`@("!S=&%T:6,@)&-O;F1I=&EO;G,[
M#0H@("`@("`@('-T871I8R`D<V5N<V]R<SL-"B`@("`@("`@:68@*"%I<W-E
M="@D8V]M<&%S<RDI('L-"B`@("`@("`@("`@("1C;VUP87-S(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@(DXB+"`B3DY%(BP@(DY%(BP@(D5.12(L#0H@
M("`@("`@("`@("`@("`@(D4B+"`B15-%(BP@(E-%(BP@(E-312(L#0H@("`@
M("`@("`@("`@("`@(E,B+"`B4U-7(BP@(E-7(BP@(E=35R(L#0H@("`@("`@
M("`@("`@("`@(E<B+"`B5TY7(BP@(DY7(BP@(DY.5R(-"B`@("`@("`@("`@
M("D[#0H@("`@("`@("`@("`D8VQO=61S("`@(#T@87)R87DH#0H@("`@("`@
M("`@("`@("`@(G-K8R(@("`@("`@("`]/B`B<VMY(&-L96%R(BP-"B`@("`@
M("`@("`@("`@("`B9F5W(B`@("`@("`@(#T^(")F97<B+`T*("`@("`@("`@
M("`@("`@(")S8W0B("`@("`@("`@/3X@(G-C871T97)E9"(L#0H@("`@("`@
M("`@("`@("`@(F)K;B(@("`@("`@("`]/B`B8G)O:V5N(BP-"B`@("`@("`@
M("`@("`@("`B;W9C(B`@("`@("`@(#T^(")O=F5R8V%S="(L#0H@("`@("`@
M("`@("`@("`@(G9V(B`@("`@("`@("`]/B`B=F5R=&EC86P@=FES:6)I;&ET
M>2(L#0H@("`@("`@("`@("`@("`@(G1C=2(@("`@("`@("`]/B`B5&]W97)I
M;F<@0W5M=6QU<R(L#0H@("`@("`@("`@("`@("`@(F-B(B`@("`@("`@("`]
M/B`B0W5M=6QO;FEM8G5S(BP-"B`@("`@("`@("`@("`@("`B8VQR(B`@("`@
M("`@(#T^(")C;&5A<B!B96QO=R`Q,BPP,#`@9G0B#0H@("`@("`@("`@("`I
M.PT*("`@("`@("`@("`@)&-O;F1I=&EO;G,@/2!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`B*R(@("`@("`@("`@(#T^(")H96%V>2(L("`@("`@("`B+2(@
M("`@("`@("`@(#T^(")L:6=H="(L#0H-"B`@("`@("`@("`@("`@("`B=F,B
M("`@("`@("`@(#T^(")V:6-I;FET>2(L#0H-"B`@("`@("`@("`@("`@("`B
M;6DB("`@("`@("`@(#T^(")S:&%L;&]W(BP@("`@("`B8F,B("`@("`@("`@
M(#T^(")P871C:&5S(BP-"B`@("`@("`@("`@("`@("`B<'(B("`@("`@("`@
M(#T^(")P87)T:6%L(BP@("`@("`B=',B("`@("`@("`@(#T^(")T:'5N9&5R
M<W1O<FTB+`T*("`@("`@("`@("`@("`@(")B;"(@("`@("`@("`@/3X@(F)L
M;W=I;F<B+"`@("`@(")S:"(@("`@("`@("`@/3X@(G-H;W=E<G,B+`T*("`@
M("`@("`@("`@("`@(")D<B(@("`@("`@("`@/3X@(FQO=R!D<FEF=&EN9R(L
M(")F>B(@("`@("`@("`@/3X@(F9R965Z:6YG(BP-"@T*("`@("`@("`@("`@
M("`@(")D>B(@("`@("`@("`@/3X@(F1R:7IZ;&4B+"`@("`@(")R82(@("`@
M("`@("`@/3X@(G)A:6XB+`T*("`@("`@("`@("`@("`@(")S;B(@("`@("`@
M("`@/3X@(G-N;W<B+"`@("`@("`@(")S9R(@("`@("`@("`@/3X@(G-N;W<@
M9W)A:6YS(BP-"B`@("`@("`@("`@("`@("`B:6,B("`@("`@("`@(#T^(")I
M8V4@8W)Y<W1A;',B+"`B<&4B("`@("`@("`@(#T^(")I8V4@<&5L;&5T<R(L
M#0H@("`@("`@("`@("`@("`@(F=R(B`@("`@("`@("`]/B`B:&%I;"(L("`@
M("`@("`@(F=S(B`@("`@("`@("`]/B`B<VUA;&P@:&%I;"]S;F]W('!E;&QE
M=',B+`T*("`@("`@("`@("`@("`@(")U<"(@("`@("`@("`@/3X@(G5N:VYO
M=VX@<')E8VEP:71A=&EO;B(L#0H-"B`@("`@("`@("`@("`@("`B8G(B("`@
M("`@("`@(#T^(")M:7-T(BP@("`@("`@("`B9F<B("`@("`@("`@(#T^(")F
M;V<B+`T*("`@("`@("`@("`@("`@(")F=2(@("`@("`@("`@/3X@(G-M;VME
M(BP@("`@("`@(")V82(@("`@("`@("`@/3X@(G9O;&-A;FEC(&%S:"(L#0H@
M("`@("`@("`@("`@("`@(G-A(B`@("`@("`@("`]/B`B<V%N9"(L("`@("`@
M("`@(FAZ(B`@("`@("`@("`]/B`B:&%Z92(L#0H@("`@("`@("`@("`@("`@
M(G!Y(B`@("`@("`@("`]/B`B<W!R87DB+"`@("`@("`@(F1U(B`@("`@("`@
M("`]/B`B=VED97-P<F5A9"!D=7-T(BP-"@T*("`@("`@("`@("`@("`@(")S
M<2(@("`@("`@("`@/3X@(G-Q=6%L;"(L("`@("`@(")S<R(@("`@("`@("`@
M/3X@(G-A;F1S=&]R;2(L#0H@("`@("`@("`@("`@("`@(F1S(B`@("`@("`@
M("`]/B`B9'5S='-T;W)M(BP@("`@(G!O(B`@("`@("`@("`]/B`B=V5L;"!D
M979E;&]P960@9'5S="]S86YD('=H:7)L<R(L#0H@("`@("`@("`@("`@("`@
M(F9C(B`@("`@("`@("`]/B`B9G5N;F5L(&-L;W5D(BP-"@T*("`@("`@("`@
M("`@("`@("(K9F,B("`@("`@("`@/3X@(G1O<FYA9&\O=V%T97)S<&]U="(-
M"B`@("`@("`@("`@("D[#0H@("`@("`@("`@("`D<V5N<V]R<R`](&%R<F%Y
M*`T*("`@("`@("`@("`@("`@(")R=G)N;R(@("`@(#T^(")2=6YW87D@5FES
M=6%L(%)A;F=E($1E=&5C=&]R(&]F9FQI;F4B+`T*("`@("`@("`@("`@("`@
M(")P=VEN;R(@("`@(#T^(")0<F5S96YT(%=E871H97(@261E;G1I9FEE<B!O
M9F9L:6YE(BP-"B`@("`@("`@("`@("`@("`B<&YO(B`@("`@("`]/B`B5&EP
M<&EN9R!"=6-K970@4F%I;B!'875G92!O9F9L:6YE(BP-"B`@("`@("`@("`@
M("`@("`B9GIR86YO(B`@("`]/B`B1G)E97II;F<@4F%I;B!396YS;W(@;V9F
M;&EN92(L#0H@("`@("`@("`@("`@("`@(G1S;F\B("`@("`@/3X@(DQI9VAT
M;FEN9R!$971E8W1I;VX@4WES=&5M(&]F9FQI;F4B+`T*("`@("`@("`@("`@
M("`@(")V:7-N;U]L;V,B(#T^("(R;F0@5FES:6)I;&ET>2!396YS;W(@;V9F
M;&EN92(L#0H@("`@("`@("`@("`@("`@(F-H:6YO7VQO8R(@/3X@(C)N9"!#
M96EL:6YG($AE:6=H="!);F1I8V%T;W(@;V9F;&EN92(-"B`@("`@("`@("`@
M("D[#0H@("`@("`@('T-"B`-"B`@("`@("`@)&UE=&%R0V]D92`](&%R<F%Y
M*`T*("`@("`@("`@("`@(G)E<&]R="(@("`@("`]/B`B345405)\4U!%0TDB
M+`T*("`@("`@("`@("`@(G-T871I;VXB("`@("`]/B`B7'=[-'TB+`T*("`@
M("`@("`@("`@(G5P9&%T92(@("`@("`]/B`B*%QD>S)]*3\H7&1[-'TI6B(L
M#0H@("`@("`@("`@("`B='EP92(@("`@("`@(#T^(")!551/?$-/4B(L#0H@
M("`@("`@("`@("`B=VEN9"(@("`@("`@(#T^("(H7&1[,WU\5D%2?%920BDH
M7&1[,BPS?2DH1RA<9'LR?2DI/RA<=WLR+#-]*2(L#0H@("`@("`@("`@("`B
M=VEN9%9A<B(@("`@(#T^("(H7&1[,WTI5BA<9'LS?2DB+`T*("`@("`@("`@
M("`@(G9I<VEB:6QI='DQ(B`]/B`B7&0B+`T*("`@("`@("`@("`@(G9I<VEB
M:6QI='DR(B`]/B`B33\H7&1[-'TI?"@H7&1[,2PR?7PH7&0I7"\H7&0I*2A3
M37Q+32DI?"A#059/2RDB+`T*("`@("`@("`@("`@(G)U;G=A>2(@("`@("`]
M/B`B4BA<9'LR?2DH7'<I/UPO*%!\32D_*%QD>S1]*2A&5"D_*%8H4'Q-*3\H
M7&1[-'TI*$94*3\I/RA<=RD_(BP-"B`@("`@("`@("`@(")C;VYD:71I;VXB
M("`@/3X@(B@M?%PK?%9#*3\H34E\0D-\4%)\5%-\0DQ\4TA\1%)\1EHI/RA$
M6GQ207Q33GQ31WQ)0WQ03'Q'4GQ'4WQ54"D_*$)2?$9'?$95?%9!?$15?%-!
M?$A:?%!9*3\H4$]\4U%\1D-\4U-\1%,I/R(L#0H@("`@("`@("`@("`B8VQO
M=61S(B`@("`@(#T^("(H4TM#?$-,4GPH*$9%5WQ30U1\0DM.?$]60WQ65BDH
M7&1[,WTI*%1#57Q#0BD_*2DB+`T*("`@("`@("`@("`@(G1E;7!E<F%T=7)E
M(B`]/B`B*$TI/RA<9'LR?2E<+R@H32D_*%QD>S)]*7Q86'Q<+UPO*3\B+`T*
M("`@("`@("`@("`@(G!R97-S=7)E(B`@("`]/B`B*$$I*%QD>S1]*7PH42DH
M7&1[-'TI(BP-"B`@("`@("`@("`@(")N;W-I9R(@("`@("`@/3X@(DY/4TE'
M(BP-"B`@("`@("`@("`@(")R96UA<FLB("`@("`@/3X@(E)-2R(-"B`@("`@
M("`@*3L-"B`@("`@("`@#0H@("`@("`@("1R96UA<FMS(#T@87)R87DH#0H@
M("`@("`@("`@("`B;F]S<&5C:2(@("`@(#T^(").3U-014-)(BP-"B`@("`@
M("`@("`@(")A=71O<W1A=&EO;B(@/3X@(D%/*#%\,BDB+`T*("`@("`@("`@
M("`@(G!R97-S8VAG(B`@("`]/B`B4%)%4U,H4GQ&*5(B+`T*("`@("`@("`@
M("`@(G-E87!R97-S=7)E(B`]/B`B4TQ0*%QD>S-]?$Y/*2(L#0H@("`@("`@
M("`@("`B,6AP<F5C:7`B("`@(#T^(")0*%QD>S1]*2(L#0H@("`@("`@("`@
M("`B-FAP<F5C:7`B("`@(#T^("(V*%QD>S1]?%PO>S1]*2(L#0H@("`@("`@
M("`@("`B,C1H<')E8VEP(B`@(#T^("(W*%QD>S1]?%PO>S1]*2(L#0H@("`@
M("`@("`@("`B<VYO=V1E<'1H(B`@(#T^("(T7"\H7&1[,WTI(BP-"B`@("`@
M("`@("`@(")S;F]W97%U:78B("`@/3X@(CDS,RA<9'LS?2DB+`T*("`@("`@
M("`@("`@(F-L;W5D='EP97,B("`]/B`B.%PO*%QD?%PO*2A<9'Q<+RDH7&1\
M7"\I(BP-"B`@("`@("`@("`@(")S=6YD=7)A=&EO;B(@/3X@(CDX*%QD>S-]
M*2(L#0H@("`@("`@("`@("`B,6AT96UP9&5W(B`@(#T^(")4*#!\,2DH7&1[
M,WTI*"@P?#$I*%QD>S-]*2D_(BP-"B`@("`@("`@("`@("(V:&UA>'1E;7`B
M("`@/3X@(C$H,'PQ*2A<9'LS?2DB+`T*("`@("`@("`@("`@(C9H;6EN=&5M
M<"(@("`]/B`B,B@P?#$I*%QD>S-]*2(L#0H@("`@("`@("`@("`B,C1H=&5M
M<"(@("`@(#T^("(T*#!\,2DH7&1[,WTI*#!\,2DH7&1[,WTI(BP-"B`@("`@
M("`@("`@("(S:'!R97-S=&5N9"(@/3X@(C4H6S`M.%TI*%QD>S-]*2(L#0H@
M("`@("`@("`@("`B<V5N<V]R<R(@("`@(#T^(")25E).3WQ05TE.3WQ03D]\
M1EI204Y/?%133D]\5DE33D]?3$]#?$-(24Y/7TQ/0R(L#0H@("`@("`@("`@
M("`B;6%I;G1A:6XB("`@(#T^(");7"1=(@T*("`@("`@("`I.R`@("`@("`@
M#0H-"B`@("`@("`@)&1A=&$@/2!`9FEL92@D<V]U<F-E*3L-"@T*("`@("`@
M("`O+R!#:&5C:R!F;W(@8V]R<F5C="!D871A+"`R(&QI;F5S(&EN('-I>F4-
M"B`@("`@("`@:68@*"$D9&%T82!\?"`A:7-?87)R87DH)&1A=&$I('Q\('-I
M>F5O9B@D9&%T82D@/"`R*2![#0H@("`@("`@("`@("!R971U<FX@4V5R=FEC
M97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]2
M7U=23TY'7U-%4E9%4E]$051!*3L-"B`@("`@("`@?2!E;'-E:68@*'-I>F5O
M9B@D9&%T82D@/B`R*2![#0H@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?
M5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U5.
M2TY/5TY?3$]#051)3TXI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@:68@*%-%4E9)0T537U=%051(15)?1$5"54<I('L-"B`@("`@("`@("`@
M("`@("!E8VAO("1D871A6S!=+B1D871A6S%=.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@+R\@3VLL('=E(&AA=F4@8V]R<F5C="!D871A+"!S=&%R
M="!W:71H('!A<G-I;F<@=&AE(&9I<G-T(&QI;F4@9F]R('1H92!L87-T('5P
M9&%T90T*("`@("`@("`@("`@)'=E871H97)$871A(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("1W96%T:&5R1&%T85LB<W1A=&EO;B)=(#T@(B([#0H@("`@
M("`@("`@("`D=V5A=&AE<D1A=&%;(G5P9&%T92)=("`]('-T<G1O=&EM92AT
M<FEM*"1D871A6S!=*2XB($=-5"(I.PT*("`@("`@("`@("`@+R\@86YD('!R
M97!A<F4@=&AE('-E8V]N9"!L:6YE(&9O<B!S=&5P<&EN9R!T:')O=6=H#0H@
M("`@("`@("`@("`D;65T87(@/2!E>'!L;V1E*"(@(BP@=')I;2@D9&%T85LQ
M72DI.PT*#0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)&UE=&%R*3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@("\O($-H96-K(&9O
M<B!W:&ET97-P86-E(&%N9"!S=&5P(&QO;W`L(&EF(&YO=&AI;F<G<R!T:&5R
M90T*("`@("`@("`@("`@("`@("1M971A<ELD:5T@/2!T<FEM*"1M971A<ELD
M:5TI.PT*("`@("`@("`@("`@("`@(&EF("@A<W1R;&5N*"1M971A<ELD:5TI
M*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@('T-"@T*("`@("`@("`@("`@("`@(&EF("A315)624-%4U]714%4
M2$527T1%0E5'*2![#0H@("`@("`@("`@("`@("`@("`@("1T86(@/2!S=')?
M<F5P96%T*")<="(L(#(@+2!F;&]O<B@H<W1R;&5N*"1M971A<ELD:5TI("L@
M,BD@+R`X*2D[#0H@("`@("`@("`@("`@("`@("`@(&5C:&\@(EPB(BXD;65T
M87);)&E=+B)<(B(N)'1A8BXB+3X@(CL-"B`@("`@("`@("`@("`@("!]#0H-
M"B`@("`@("`@("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;65T87)#;V1E(&%S("1K97D@/3X@)')E9V5X<"D@
M>PT*("`@("`@("`@("`@("`@("`@("`O+R!#:&5C:R!I9B!C=7)R96YT(&-O
M9&4@;6%T8VAE<R!C=7)R96YT(&UE=&%R('-N:7!P970-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"@D9F]U;F0@/2!P<F5G7VUA=&-H*"(O7B(N)')E9V5X
M<"XB)"]I(BP@)&UE=&%R6R1I72P@)')E<W5L="DI(#T]('1R=64I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)&ME>2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G-T871I;VXB.@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G-T871I
M;VXB72`]("1R97-U;'1;,%T[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1M971A<D-O9&5;(G-T871I;VXB72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@(G=I;F0B.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!087)S92!W:6YD(&1A=&$L(&9I<G-T('1H
M92!S<&5E9"P@8V]N=F5R="!F<F]M(&MT('1O(&-H;W-E;B!U;FET#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB=VEN
M9")=(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D<F5S=6QT6S)=+"!S=')T;VQO
M=V5R*"1R97-U;'1;-5TI+"`B;7!H(BD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T](")605(B('Q\("1R97-U
M;'1;,5T@/3T@(E920B(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%9A<FEA8FQE('=I;F1S#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G=I;F1$96=R965S
M(ET@("`](")687)I86)L92([#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G=I;F1$:7)E8W1I;VXB72`](")6
M87)I86)L92([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!3879E('=I;F0@9&5G<F5E(&%N9"!C86QC(&1I<F5C=&EO;@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)W
M:6YD1&5G<F5E<R)=("`@/2`D<F5S=6QT6S%=.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)W:6YD1&ER96-T
M:6]N(ET@/2`D8V]M<&%S<UMR;W5N9"@D<F5S=6QT6S%=("\@,C(N-2D@)2`Q
M-ET[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7VYU;65R:6,H)')E
M<W5L=%LT72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(%=I;F0@=VET:"!G=7-T<RXN+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)W:6YD1W5S=")=(#T@
M)'1H:7,M/F-O;G9E<G13<&5E9"@D<F5S=6QT6S1=+"!S=')T;VQO=V5R*"1R
M97-U;'1;-5TI+"`B;7!H(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M5V4@9V]T('1H870L('5N<V5T#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1M971A<D-O9&5;(G=I;F0B72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@(G=I;F1687(B.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!/;F-E(&UO<F4@=VEN9"P@;F]W('9A<FEA
M8FEL:71Y(&%R;W5N9"!T:&4@8W5R<F5N="!W:6YD+61I<F5C=&EO;@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G=I
M;F1687)I86)I;&ET>2)=(#T@87)R87DH(F9R;VTB(#T^("1R97-U;'1;,5TL
M(")T;R(@/3X@)')E<W5L=%LR72D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(G=I;F1687(B72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@(G9I<VEB:6QI='DQ(CH-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5FES:6)I;&ET>2!W:6QL
M(&-O;64@87,@>"!Y+WHL(&9I<G-T('1H92!S:6YG;&4@9&EG:70@<&%R=`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;
M(G9I<VEB:6QI='DB72`]("1R97-U;'1;,%T[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(G9I<VEB:6QI='DQ
M(ETI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")V:7-I8FEL:71Y
M,B(Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N
M=6UE<FEC*"1R97-U;'1;,5TI("8F("@D<F5S=6QT6S%=(#T](#DY.3DI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!5<'!E
M<B!L:6UI="!O9B!V:7-I8FEL:71Y(')A;F=E#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES+3YC;VYV
M97)T1&ES=&%N8V4H,3`L(")K;2(L(")S;2(I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)V:7-1=6%L:69I
M97(B72`](")"15E/3D0B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S%=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@-"UD:6=I="!V
M:7-I8FEL:71Y(&EN(&T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V:7-I8FEL:71Y(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@H
M)')E<W5L=%LQ72\Q,#`P*2P@(FMM(BP@(G-M(BD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G9I<U%U86QI
M9FEE<B)=(#T@(D%4(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"%I<W-E="@D<F5S=6QT6S==*2!\?"`D<F5S=6QT6S==
M("$](")#059/2R(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<U]N=6UE<FEC*"1R97-U;'1;,UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=FES:6)I;&ET
M>2!A<R!O;F4O='=O+61I9VET(&YU;6)E<@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y(#T@)'1H:7,M/F-O
M;G9E<G1$:7-T86YC92@D<F5S=6QT6S-=+"`D<F5S=6QT6S9=+"`B<VTB*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A
M=&AE<D1A=&%;(G9I<U%U86QI9FEE<B)=(#T@(D%4(CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AE('DO>B!P87)T
M+"!A9&0@:68@=V4@:&%D(&$@>"!P87)T("AS964@=FES:6)I;&ET>3$I#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9I<VEB
M:6QI='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1R97-U;'1;-%T@+R`D
M<F5S=6QT6S5=+"`D<F5S=6QT6S9=+"`B<VTB*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'=E871H97)$
M871A6R)V:7-I8FEL:71Y(ETI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y("L]("1W96%T:&5R
M1&%T85LB=FES:6)I;&ET>2)=.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)')E<W5L=%LP77LP?2`]/2`B32(I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E
M871H97)$871A6R)V:7-1=6%L:69I97(B72`](")"14Q/5R([#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E
M871H97)$871A6R)V:7-1=6%L:69I97(B72`](")!5"([#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2`-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB=FES475A;&EF:65R(ET@
M/2`B0D593TY$(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1V:7-I8FEL:71Y("`@("`@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R
M=$1I<W1A;F-E*#$P+"`B:VTB+"`B<VTB*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB8VQO=61S(ET@("`@
M/2!A<G)A>2@B86UO=6YT(B`]/B`B;F]N92(L(")H96EG:'0B(#T^(")B96QO
M=R`U,#`P9G0B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1W96%T:&5R1&%T85LB8V]N9&ET:6]N(ET@/2`B;F\@<VEG;FEF:6-A
M;G0@=V5A=&AE<B([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$
M871A6R)V:7-I8FEL:71Y(ET@/2`D=FES:6)I;&ET>3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB=FES:6)I
M;&ET>3(B72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(F-O;F1I
M=&EO;B(Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($9I
M<G-T('-O;64@8F%S:6,@<V5T=7!S#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'=E871H97)$871A6R)C;VYD:71I;VXB
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W
M96%T:&5R1&%T85LB8V]N9&ET:6]N(ET@/2`B(CL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-T<FQE;B@D=V5A=&AE<D1A
M=&%;(F-O;F1I=&EO;B)=*2`^(#`I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB8V]N9&ET:6]N(ET@+CT@
M(BPB.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*'-T
M<G1O;&]W97(H)')E<W5L=%LP72DL("1C;VYD:71I;VYS*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1FER<W0@=')Y(&UA
M=&-H:6YG('1H92!C;VUP;&5T92!S=')I;F<-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB8V]N9&ET:6]N(ET@
M+CT@(B`B+B1C;VYD:71I;VYS6W-T<G1O;&]W97(H)')E<W5L=%LP72E=.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@3F\@;'5C:RP@
M;6%T8V@@<&%R="!B>2!P87)T#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W(@*"1C(#T@,3L@)&,@/"!S:7IE;V8H)')E<W5L="D[
M("1C*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H<W1R;&5N*"1R97-U;'1;)&-=*2`^(#`I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$
M871A6R)C;VYD:71I;VXB72`N/2`B("(N)&-O;F1I=&EO;G-;<W1R=&]L;W=E
M<B@D<F5S=6QT6R1C72E=.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;
M(F-O;F1I=&EO;B)=(#T@=')I;2@D=V5A=&AE<D1A=&%;(F-O;F1I=&EO;B)=
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B8VQO=61S(CH-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=V5A
M=&AE<D1A=&%;(F-L;W5D<R)=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'=E871H97)$871A6R)C;&]U9',B72`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1R97-U
M;'0I(#T](#4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O($]N;'D@86UO=6YT(&%N9"!H96EG:'0-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;&]U9"`](&%R<F%Y*")A;6]U;G0B
M(#T^("1C;&]U9'-;<W1R=&]L;W=E<B@D<F5S=6QT6S-=*5TL(")H96EG:'0B
M(#T^("@D<F5S=6QT6S1=*C$P,"DI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&5L<V5I9B`H<VEZ96]F*"1R97-U;'0I(#T](#8I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O($%M;W5N="P@:&5I9VAT(&%N
M9"!T>7!E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8VQO=60@/2!A<G)A>2@B86UO=6YT(B`]/B`D8VQO=61S6W-T<G1O;&]W97(H
M)')E<W5L=%LS72E=+"`B:&5I9VAT(B`]/B`H)')E<W5L=%LT72HQ,#`I+"`B
M='EP92(@/3X@)&-L;W5D<UMS=')T;VQO=V5R*"1R97-U;'1;-5TI72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!32T,@;W(@0TQ2#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=60@/2!A<G)A>2@B86UO
M=6YT(B`]/B`D8VQO=61S6W-T<G1O;&]W97(H)')E<W5L=%LP72E=*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(F-L;W5D<R)=6UT@
M/2`D8VQO=60[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!E
M<F%T=7)E(CH-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M;F]R;6%L('1E;7!E<F%T=7)E(&EN(&9I<G-T('!A<G0-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@;F5G871I=F4@=F%L=64-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/3T@
M(DTB*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5S=6QT6S)=("H]("TQ.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T
M:&5R1&%T85LB=&5M<&5R871U<F4B72`]("1T:&ES+3YC;VYV97)T5&5M<&5R
M871U<F4H)')E<W5L=%LR72P@(F,B+"`B9B(I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1R97-U;'0I(#X@-"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<V%M92!F
M;W(@9&5W<&]I;G0-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D<F5S=6QT6S1=(#T](")-(BD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;-5T@*CT@+3$[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(F1E
M=U!O:6YT(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;
M-5TL(")C(BP@(F8B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1W96%T:&5R1&%T85LB:'5M:61I='DB72`]("1T:&ES+3YC86QC
M=6QA=&5(=6UI9&ET>2@D<F5S=6QT6S)=+"`D<F5S=6QT6S5=*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'=E871H97)$871A6R)W:6YD
M(ETI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!.;W<@8V%L8W5L871E('=I;F1C:&EL;"!F<F]M('1E;7!E<F%T=7)E(&%N
M9"!W:6YD<W!E960-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1W96%T:&5R1&%T85LB9F5L=%1E;7!E<F%T=7)E(ET@/2`D=&AI<RT^
M8V%L8W5L871E5VEN9$-H:6QL*"1W96%T:&5R1&%T85LB=&5M<&5R871U<F4B
M72P@)'=E871H97)$871A6R)W:6YD(ETI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1M971A<D-O9&5;(G1E;7!E<F%T=7)E(ETI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E(")P<F5S<W5R92(Z#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T](")!(BD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4')E
M<W-U<F4@<')O=FED960@:6X@:6YC:&5S#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G!R97-S=7)E(ET@/2`D
M<F5S=6QT6S)=("\@,3`P.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)')E<W5L=%LS72`]/2`B42(I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O("XN+B!I;B!H96-T;W!A
M<V-A;`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E
M871H97)$871A6R)P<F5S<W5R92)=(#T@)'1H:7,M/F-O;G9E<G10<F5S<W5R
M92@D<F5S=6QT6S1=+"`B:'!A(BP@(FEN(BD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&UE=&%R0V]D95LB<')E<W-U<F4B72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@(FYO<VEG(CH-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E(")N;W-P96-I(CH-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@3F\@8VAA;F=E(&1U<FEN9R!T:&4@;&%S
M="!H;W5R#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'=E871H97)$871A6R)R96UA<FLB72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K
M(ET@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R
M1&%T85LB<F5M87)K(EU;(FYO<VEG(ET@/2`B3F\@8VAA;F=E<R!I;B!W96%T
M:&5R(&-O;F1I=&EO;G,B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D;65T87)#;V1E6R1K97E=*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B<F5M87)K(CH-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@4F5M87)K('!A<G0@8F5G:6YS#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1M971A<D-O9&4@/2`D<F5M87)K<SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=V5A=&AE<D1A=&%;(G)E;6%R:R)=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB72`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`B875T;W-T871I;VXB.@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!7:&EC:"!A=71O<W1A
M=&EO;B!D;R!W92!H879E(&AE<F4_#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T](#`I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K
M(EU;(F%U=&]S=&%T:6]N(ET@/2`B075T;VUA=&EC('=E871H97)S=&%T:6]N
M('<O;R!P<F5C:7!I=&%T:6]N(&1I<V-R:6UI;F%T;W(B.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB
M75LB875T;W-T871I;VXB72`](")!=71O;6%T:6,@=V5A=&AE<G-T871I;VX@
M=R\@<')E8VEP:71A=&EO;B!D:7-C<FEM:6YA=&]R(CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R)A=71O<W1A=&EO;B)=*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<')E<W-C:&<B.@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!$96-O9&EN9R!F;W(@
M<F%P:60@<')E<W-U<F4@8VAA;F=E<PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D<F5S=6QT6S%=*2`]/2`B<B(I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T
M:&5R1&%T85LB<F5M87)K(EU;(G!R97-S8VAG(ET@/2`B4')E<W-U<F4@<FES
M:6YG(')A<&ED;'DB.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'=E871H97)$871A6R)R96UA<FLB75LB<')E<W-C:&<B72`](")0<F5S
M<W5R92!F86QL:6YG(')A<&ED;'DB.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1M971A<D-O9&5;(G!R97-S8VAG(ETI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E(")S96%P<F5S<W5R92(Z#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%!R97-S=7)E(&%T('-E82!L979E;"`H
M9&5L:79E<F5D(&EN(&AP82D-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@1&5C;V1I;F<@:7,@82!B:70@;V)S8W5R92!A<R`Y.#(@9V5T
M<R`Y.3@N,@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!W
M:&5R96%S(#$Q,R!B96-O;65S(#$Q,3,@+3X@;F\@<F5A;"!R=6QE(&AE<F4-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W
M97(H)')E<W5L=%LQ72D@(3T@(FYO(BD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/B`U,#`I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E<W,@
M/2`Y,#`@*R!R;W5N9"@D<F5S=6QT6S%=("\@,3`P+"`Q*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R97-S(#T@,3`P
M,"`K("1R97-U;'1;,5T[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S96%P<F5S<W5R92)=(#T@)'1H
M:7,M/F-O;G9E<G10<F5S<W5R92@D<')E<W,L(")H<&$B+"`B:6XB*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R)S96%P<F5S
M<W5R92)=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B,6AP<F5C
M:7`B.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0<F5C
M:7!I=&%T:6]N(&9O<B!T:&4@;&%S="!H;W5R(&EN(&EN8VAE<PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1W96%T:&5R
M1&%T85LB<')E8VEP:71A=&EO;B)=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)P<F5C:7!I=&%T:6]N
M(ET@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?
M;G5M97)I8R@D<F5S=6QT6S%=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!R96-I<"`](")I;F1E=&5R;6EN86)L92([#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D<F5S
M=6QT6S%=(#T]("(P,#`P(BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!R96-I<"`](")T<F%C96%B;&4B.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<')E8VEP(#T@)')E<W5L=%LQ72`O
M(#$P,#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G!R
M96-I<&ET871I;VXB75M=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B86UO=6YT(B`]/B`D<')E8VEP+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(FAO=7)S(B`@/3X@(C$B
M(`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R(Q
M:'!R96-I<")=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B-FAP
M<F5C:7`B.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!3
M86UE(&9O<B!L87-T(#,@<F5S<"X@-B!H;W5R<RXN+B!N;R!W87D@=&\@9&5T
M97)M:6YE#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('=H
M:6-H(')E<&]R="!T:&ES(&ES+"!S;R!K965P:6YG('1H92!T97AT(&=E;F5R
M86P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=V5A=&AE<D1A=&%;(G!R96-I<&ET871I;VXB72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<')E
M8VEP:71A=&EO;B)=(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES7VYU;65R:6,H)')E<W5L=%LQ72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5C:7`@/2`B:6YD971E<FUI
M;F%B;&4B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)')E<W5L=%LQ72`]/2`B,#`P,"(I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P<F5C:7`@/2`B=')A8V5A8FQE(CL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?65L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R96-I<"`]("1R
M97-U;'1;,5T@+R`Q,#`[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H
M97)$871A6R)P<F5C:7!I=&%T:6]N(EU;72`](&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(F%M;W5N="(@/3X@)'!R96-I
M<"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")H;W5R
M<R(@(#T^("(S+S8B(`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M;65T87)#;V1E6R(V:'!R96-I<")=*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B,C1H<')E8VEP(CH-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@06YD('1H92!S86UE(&9O<B!T:&4@;&%S="`R-"!H;W5R
M<PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1W96%T:&5R1&%T85LB<')E8VEP:71A=&EO;B)=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)P<F5C
M:7!I=&%T:6]N(ET@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-?;G5M97)I8R@D<F5S=6QT6S%=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!R96-I<"`](")I;F1E=&5R;6EN
M86)L92([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M96EF("@D<F5S=6QT6S%=(#T]("(P,#`P(BD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!R96-I<"`](")T<F%C96%B;&4B.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E8VEP(#T@)')E
M<W5L=%LQ72`O(#$P,#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE
M<D1A=&%;(G!R96-I<&ET871I;VXB75M=(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`B86UO=6YT(B`]/B`D<')E8VEP
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(FAO=7)S
M(B`@/3X@(C(T(B`-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE
M=&%R0V]D95LB,C1H<')E8VEP(ETI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E(")S;F]W9&5P=&@B.@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!3;F]W(&1E<'1H(&EN(&EN8VAE<PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S
M;F]W9&5P=&@B72`]("1R97-U;'1;,5T[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(G-N;W=D97!T:")=*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<VYO=V5Q=6EV(CH-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4V%M92!F;W(@97%U
M:79A;&5N="!I;B!7871E<BXN+B`H:6YC:&5S*0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S;F]W
M97%U:78B72`]("1R97-U;'1;,5T@+R`Q,#L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB<VYO=V5Q=6EV(ETI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")C;&]U9'1Y<&5S(CH-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@0VQO=60@='EP
M97,L(&AA=F5N)W0@9F]U;F0@82!W87D@9F]R(&1E8V5N="!D96-O9&EN9R`H
M>65T*0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M;65T87)#;V1E6R)C;&]U9'1Y<&5S(ETI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")S=6YD=7)A=&EO;B(Z#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O($1U<F%T:6]N(&]F('-U;G-H:6YE("AI;B!M:6YU
M=&5S*0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE
M<D1A=&%;(G)E;6%R:R)=6R)S=6YD=7)A=&EO;B)=(#T@(E1O=&%L(&UI;G5T
M97,@;V8@<W5N<VAI;F4Z("(N)')E<W5L=%LQ73L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB<W5N9'5R871I
M;VXB72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(C%H=&5M<&1E
M=R(Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%1E;7!E
M<F%T=7)E<R!I;B!T:&4@;&%S="!H;W5R(&EN($,-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/3T@(C$B*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6S)=
M("H]("TQ.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB
M<F5M87)K(EU;(C%H=&5M<")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R
M92@D<F5S=6QT6S)=("\@,3`L(")C(BP@(F8B*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AS:7IE;V8H)')E<W5L="D@/B`S*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!S86UE(&9O<B!D97=P;VEN
M=`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R
M97-U;'1;-%T@/3T@(C$B*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<W5L=%LU72`J/2`M,3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(C%H
M9&5W(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;-5T@
M+R`Q,"P@(F,B+"`B9B(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1M971A<D-O9&5;(C%H=&5M<&1E=R)=*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B-FAM87AT96UP(CH-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@36%X('1E;7!E<F%T=7)E(&EN('1H92!L87-T(#8@
M:&]U<G,@:6X@0PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)')E<W5L=%LQ72`]/2`B,2(I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R97-U;'1;,ET@*CT@+3$[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB75LB-FAM87AT96UP
M(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;,ET@+R`Q
M,"P@(F,B+"`B9B(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!U;G-E="@D;65T87)#;V1E6R(V:&UA>'1E;7`B72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@(C9H;6EN=&5M<"(Z#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O($UI;B!T96UP97)A='5R92!I;B!T:&4@
M;&%S="`V(&AO=7)S(&EN($,-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1R97-U;'1;,5T@/3T@(C$B*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6S)=("H]("TQ.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(C9H
M;6EN=&5M<")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT
M6S)=("\@,3`L(")C(BP@(F8B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB-FAM:6YT96UP(ETI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E("(R-&AT96UP(CH-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@36%X+TUI;B!T96UP97)A='5R
M97,@:6X@=&AE(&QA<W0@,C0@:&]U<G,@:6X@0PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`]/2`B,2(I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;,ET@
M*CT@+3$[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R
M96UA<FLB75LB,C1H;6%X=&5M<")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A
M='5R92@D<F5S=6QT6S)=("\@,3`L(")C(BP@(F8B*3L-"@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LS72`]/2`B,2(I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U
M;'1;-%T@*CT@+3$[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$
M871A6R)R96UA<FLB75LB,C1H;6EN=&5M<")=(#T@)'1H:7,M/F-O;G9E<G14
M96UP97)A='5R92@D<F5S=6QT6S1=("\@,3`L(")C(BP@(F8B*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB
M,C1H=&5M<")=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B,VAP
M<F5S<W1E;F0B.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!792!D;VXG="!S879E('1H92!P<F5S<W5R92!D=7)I;F<@=&AE(&1A>2P@
M<V\@;F\@9&5C;V1I;F<-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@<&]S<VEB;&4L('-O<G)Y#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(C-H<')E<W-T96YD(ETI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")S96YS;W)S(CH-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@;6%Y(&AA=F4@;75L
M=&EP;&4@8G)O:V5N('-E;G-O<G,L('-O(&1O(&YO="!U;G-E=`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1W96%T:&5R
M1&%T85LB<F5M87)K(EU;(G-E;G-O<G,B72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;
M(G-E;G-O<G,B72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'=E871H97)$871A6R)R96UA<FLB75LB<V5N<V]R<R)=6W-T<G1O;&]W97(H
M)')E<W5L=%LP72E=(#T@)'-E;G-O<G-;<W1R=&]L;W=E<B@D<F5S=6QT6S!=
M*5T[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FUA:6YT86EN(CH-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A
M6R)R96UA<FLB75LB;6%I;G1A:6XB72`](")-86EN=&%I;F%N8V4@;F5E9&5D
M(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE
M=&%R0V]D95LB;6%I;G1A:6XB72D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M($1O(&YO=&AI;F<L(&IU<W0@<')E=F5N="!F=7)T:&5R(&UA=&-H:6YG#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O
M9&5;)&ME>5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("A315)624-%4U]714%42$527T1%0E5'*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`D:V5Y+B)<;B([#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(21F;W5N9"D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H4T525DE#15-?5T5!5$A%4E]$14)51RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`B;B]A7&XB.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'=E871H97)$871A6R)N;W!A<G-E(ETI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(FYO<&%R<V4B72`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@)'=E871H97)$871A6R)N;W!A<G-E(EU;72`]("1M971A<ELD:5T[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D=V5A=&AE<D1A=&%;(FYO<&%R<V4B72DI('L-
M"B`@("`@("`@("`@("1W96%T:&5R1&%T85LB;F]P87)S92)=(#T@:6UP;&]D
M92@B("(L("`D=V5A=&AE<D1A=&%;(FYO<&%R<V4B72D[#0H@("`@("`@('T-
M"@T*("`@("`@("!R971U<FX@)'=E871H97)$871A.PT*("`@('T-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!S96%R8VA,;V-A=&EO;B@I#0H@("`@+RHJ
M#0H@("`@*B!396%R8VAE<R!)1',@9F]R(&=I=F5N(&QO8V%T:6]N+"!R971U
M<FYS(&%R<F%Y(&]F('!O<W-I8FQE(&QO8V%T:6]N<R!O<B!S:6YG;&4@240-
M"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG?&%R<F%Y("`@("`@("`@
M("`@("`@("1L;V-A=&EO;@T*("`@("H@0'!A<F%M("`@(&)O;VP@("`@("`@
M("`@("`@("`@("`@("`@("`D=7-E1FER<W0@("`@("`@268@<V5T+"!F:7)S
M="!)1"!O9B!R97-U;'0M87)R87D@:7,@<F5T=7)N960-"B`@("`J($!R971U
M<FX@("!014%27T5R<F]R?&%R<F%Y?'-T<FEN9PT*("`@("H@0'1H<F]W<R`@
M(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],
M3T-!5$E/3@T*("`@("H@0'1H<F]W<R`@(%!%05)?17)R;W(Z.E-%4E9)0T53
M7U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1`T*("`@("H@0'1H<F]W
M<R`@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)
M1%],3T-!5$E/3@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@<V5A<F-H3&]C871I;VXH)&QO8V%T:6]N+"`D=7-E1FER
M<W0@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]D8BD@?'P@(41".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D8BDI('L-"B`@
M("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R
M*%-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1"D[#0H@
M("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("AI<U]S=')I;F<H)&QO
M8V%T:6]N*2D@>PT*("`@("`@("`@("`@+R\@5')Y('1O('!A<G0@<V5A<F-H
M('-T<FEN9R!I;B!N86UE+"!S=&%T92!A;F0@8V]U;G1R>2!P87)T#0H@("`@
M("`@("`@("`O+R!A;F0@8G5I;&0@=VAE<F4@8VQA=7-E(&9R;VT@:70@9F]R
M('1H92!S96QE8W0-"B`@("`@("`@("`@("1L;V-A=&EO;B`](&5X<&QO9&4H
M(BPB+"`D;&]C871I;VXI.PT*("`@("`@("`@("`@:68@*'-I>F5O9B@D;&]C
M871I;VXI(#X](#$I('L-"B`@("`@("`@("`@("`@("`D=VAE<F4@(#T@(DQ/
M5T52*&YA;64I($Q)2T4@)R4B+G-T<G1O;&]W97(H=')I;2@D;&]C871I;VY;
M,%TI*2XB)2<B.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'-I
M>F5O9B@D;&]C871I;VXI(#T](#(I('L-"B`@("`@("`@("`@("`@("`D=VAE
M<F4@+CT@(B!!3D0@3$]715(H8V]U;G1R>2D@3$E+12`G)2(N<W1R=&]L;W=E
M<BAT<FEM*"1L;V-A=&EO;ELQ72DI+B(E)R([#0H@("`@("`@("`@("!](&5L
M<V5I9B`H<VEZ96]F*"1L;V-A=&EO;BD@/3T@,RD@>PT*("`@("`@("`@("`@
M("`@("1W:&5R92`N/2`B($%.1"!,3U=%4BAS=&%T92D@3$E+12`G)2(N<W1R
M=&]L;W=E<BAT<FEM*"1L;V-A=&EO;ELQ72DI+B(E)R([#0H@("`@("`@("`@
M("`@("`@)'=H97)E("X]("(@04Y$($Q/5T52*&-O=6YT<GDI($Q)2T4@)R4B
M+G-T<G1O;&]W97(H=')I;2@D;&]C871I;VY;,ETI*2XB)2<B.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(`T*("`@("`@("`@("`@+R\@0W)E
M871E('-E;&5C="P@;&]C871I;VYS('=I=&@@24-!3R!F:7)S=`T*("`@("`@
M("`@("`@)'-E;&5C="`](")314Q%0U0@:6-A;RP@;F%M92P@<W1A=&4L(&-O
M=6YT<GDL(&QA=&ET=61E+"!L;VYG:71U9&4@(BX-"B`@("`@("`@("`@("`@
M("`@("`@("`B1E)/32!M971A<DQO8V%T:6]N<R`B+@T*("`@("`@("`@("`@
M("`@("`@("`@(")72$5212`B+B1W:&5R92XB("(N#0H@("`@("`@("`@("`@
M("`@("`@("`@(D]21$52($)9(&EC86\@1$530R([#0H@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-E;&5C="D[#0H@("`@("`@
M("`@("`O+R!#:&5C:R!R97-U;'0@9F]R('9A;&ED:71Y#0H@("`@("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L-"B`@("`@("`@("`@('T@96QS96EF("AG971?
M8VQA<W,H)')E<W5L="D@(3T@(F1B7W)E<W5L="(@?'P@)')E<W5L="T^;G5M
M4F]W<R@I(#T](#`I('L-"B`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC
M97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]2
M7U5.2TY/5TY?3$]#051)3TXI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@#0H@("`@("`@("`@("`O+R!297-U;'0@:7,@=F%L:60L('-T87)T('!R
M97!A<FEN9R!T:&4@<F5T=7)N#0H@("`@("`@("`@("`D:6-A;R`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("!W:&EL92`H*"1R;W<@/2`D<F5S=6QT+3YF971C
M:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2`A/2!N=6QL*2![#0H@("`@("`@
M("`@("`@("`@)&QO8VEC86\@/2`D<F]W6R)I8V%O(ET[#0H@("`@("`@("`@
M("`@("`@+R\@1FER<W0@=&AE(&YA;64@;V8@=&AE(&QO8V%T:6]N#0H@("`@
M("`@("`@("`@("`@:68@*"%S=')L96XH)')O=ULB<W1A=&4B72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&QO8VYA;64@/2`D<F]W6R)N86UE(ETN(BP@
M(BXD<F]W6R)C;W5N=')Y(ET[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)&QO8VYA;64@/2`D<F]W6R)N86UE(ETN
M(BP@(BXD<F]W6R)S=&%T92)=+B(L("(N)')O=ULB8V]U;G1R>2)=.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&QO8VEC86\@
M(3T@(BTM+2TB*2![#0H@("`@("`@("`@("`@("`@("`@("\O(%=E(&AA=F4@
M82!L;V-A=&EO;B!W:71H($E#04\-"B`@("`@("`@("`@("`@("`@("`@)&EC
M86];)&QO8VEC86]=(#T@)&QO8VYA;64[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@+R\@3F\@24-!3RP@=')Y(&9I
M;F1I;F<@=&AE(&YE87)E<W0@86ER<&]R=`T*("`@("`@("`@("`@("`@("`@
M("`D;&]C:6-A;R`]("1T:&ES+3YS96%R8VA!:7)P;W)T*"1R;W=;(FQA=&ET
M=61E(ETL("1R;W=;(FQO;F=I='5D92)=*3L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D:6-A;ULD;&]C:6-A;UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D:6-A;ULD;&]C:6-A;UT@/2`D;&]C;F%M93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("\O($]N;'D@;VYE(')E<W5L=#\@4F5T
M=7)N(&%S('-T<FEN9PT*("`@("`@("`@("`@:68@*'-I>F5O9B@D:6-A;RD@
M/3T@,2D@>PT*("`@("`@("`@("`@("`@("1I8V%O(#T@:V5Y*"1I8V%O*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1L
M;V-A=&EO;BDI('L-"B`@("`@("`@("`@("\O($QO8V%T:6]N('=A<R!P<F]V
M:61E9"!A<R!C;V]R9&EN871E<RP@<V5A<F-H(&YE87)E<W0@86ER<&]R=`T*
M("`@("`@("`@("`@)&EC86\@/2`D=&AI<RT^<V5A<F-H06ER<&]R="@D;&]C
M871I;VY;,%TL("1L;V-A=&EO;ELQ72D[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O
M<BA315)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TXI.PT*
M("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1I8V%O.PT*("`@('T-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R
M>2@I#0H@("`@+RHJ#0H@("`@*B!2971U<FYS($E$<R!W:71H(&QO8V%T:6]N
M+6YA;64@9F]R(&$@9VEV96X@8V]U;G1R>2!O<B!A;&P@879A:6QA8FQE(&-O
M=6YT<FEE<RP@:68@;F\@=F%L=64@=V%S(&=I=F5N(`T*("`@("H-"B`@("`J
M($!P87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&-O=6YT
M<GD-"B`@("`J($!R971U<FX@("!014%27T5R<F]R?&%R<F%Y#0H@("`@*B!`
M=&AR;W=S("`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]5
M3DM.3U=.7TQ/0T%424].#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<CHZ
M4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$#0H@("`@
M*B!`=&AR;W=S("`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]74D].1U]315)615)?1$%400T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*
M("`@("HO#0H@("`@9G5N8W1I;VX@<V5A<F-H3&]C871I;VY">4-O=6YT<GDH
M)&-O=6YT<GD@/2`B(BD-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]D8BD@?'P@(41".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D8BDI('L-
M"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R
M<F]R*%-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1"D[
M#0H@("`@("`@('T-"@T*("`@("`@("`O+R!2971U<FX@=&AE(&%V86EL86)L
M92!C;W5N=')I97,@87,@;F\@8V]U;G1R>2!W87,@9VEV96X-"B`@("`@("`@
M:68@*"%S=')L96XH)&-O=6YT<GDI*2![#0H@("`@("`@("`@("`D<V5L96-T
M(#T@(E-%3$5#5"!$25-424Y#5"AC;W5N=')Y*2`B+@T*("`@("`@("`@("`@
M("`@("`@("`@(")&4D]-(&UE=&%R06ER<&]R=',@(BX-"B`@("`@("`@("`@
M("`@("`@("`@("`B3U)$15(@0ED@8V]U;G1R>2!!4T,B.PT*("`@("`@("`@
M("`@)&-O=6YT<FEE<R`]("1T:&ES+3Y?9&(M/F=E=$-O;"@D<V5L96-T*3L-
M"@T*("`@("`@("`@("`@+R\@07,@)&-O=6YT<FEE<R!I<R!E:71H97(@86X@
M97)R;W(@;W(@=&AE('1R=64@<F5S=6QT+`T*("`@("`@("`@("`@+R\@=V4@
M8V%N(&IU<W0@<F5T=7)N(&ET#0H@("`@("`@("`@("!R971U<FX@)&-O=6YT
M<FEE<SL-"B`@("`@("`@?0T*#0H@("`@("`@("\O($YO=R!F;W(@=&AE(')E
M86P@<V5A<F-H#0H@("`@("`@("1S96QE8W0@/2`B4T5,14-4(&EC86\L(&YA
M;64L('-T871E+"!C;W5N=')Y("(N#0H@("`@("`@("`@("`@("`@("`B1E)/
M32!M971A<D%I<G!O<G1S("(N#0H@("`@("`@("`@("`@("`@("`B5TA%4D4@
M3$]715(H8V]U;G1R>2D@3$E+12`G)2(N<W1R=&]L;W=E<BAT<FEM*"1C;W5N
M=')Y*2DN(B4G("(N#0H@("`@("`@("`@("`@("`@("`B3U)$15(@0ED@;F%M
M92!!4T,B.PT*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH
M)'-E;&5C="D[#0H@("`@("`@("\O($-H96-K(')E<W5L="!F;W(@=F%L:61I
M='D-"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2![#0H@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L-"B`@("`@("`@?2!E;'-E:68@*&=E
M=%]C;&%S<R@D<F5S=6QT*2`A/2`B9&)?<F5S=6QT(B!\?"`D<F5S=6QT+3YN
M=6U2;W=S*"D@/3T@,"D@>PT*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S
M7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]5
M3DM.3U=.7TQ/0T%424].*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O($-O
M;G-T<G5C="!T:&4@<F5S=6QT#0H@("`@("`@("1L;V-A=&EO;G,@/2!A<G)A
M>2@I.PT*("`@("`@("!W:&EL92`H*"1R;W<@/2`D<F5S=6QT+3YF971C:%)O
M=RA$0E]&151#2$U/1$5?05-33T,I*2`A/2!N=6QL*2![#0H@("`@("`@("`@
M("`D;&]C:6-A;R`]("1R;W=;(FEC86\B73L-"B`@("`@("`@("`@("\O($9I
M<G-T('1H92!N86UE(&]F('1H92!L;V-A=&EO;@T*("`@("`@("`@("`@:68@
M*"%S=')L96XH)')O=ULB<W1A=&4B72DI('L-"B`@("`@("`@("`@("`@("`D
M;&]C;F%M92`]("1R;W=;(FYA;64B72XB+"`B+B1R;W=;(F-O=6YT<GDB73L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&QO8VYA
M;64@/2`D<F]W6R)N86UE(ETN(BP@(BXD<F]W6R)S=&%T92)=+B(L("(N)')O
M=ULB8V]U;G1R>2)=.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&QO
M8V%T:6]N<ULD;&]C:6-A;UT@/2`D;&]C;F%M93L-"B`@("`@("`@?0T*#0H@
M("`@("`@(')E='5R;B`D;&]C871I;VYS.PT*("`@('T-"B`@("`O+R!]?7T-
M"@T*("`@("\O('M[>R!S96%R8VA!:7)P;W)T*"D-"B`@("`O*BH-"B`@("`J
M(%-E87)C:&5S('1H92!N96%R97-T(&%I<G!O<G0H<RD@9F]R(&=I=F5N(&-O
M;W)D:6YA=&5S+"!R971U<FYS(&%R<F%Y(&]F($E$<R!O<B!S:6YG;&4@240-
M"B`@("`J#0H@("`@*B!`<&%R86T@("`@9FQO870@("`@("`@("`@("`@("`@
M("`@("`@("1L871I='5D90T*("`@("H@0'!A<F%M("`@(&9L;V%T("`@("`@
M("`@("`@("`@("`@("`@("`D;&]N9VET=61E#0H@("`@*B!`<&%R86T@("`@
M:6YT("`@("`@("`@("`@("`@("`@("`@("`@("1N=6U297-U;'1S#0H@("`@
M*B!`<F5T=7)N("`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<-"B`@("`J($!T
M:')O=W,@("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U5.
M2TY/5TY?3$]#051)3TX-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27T1"7TY/5%]#3TY.14-4140-"B`@("`J
M($!T:')O=W,@("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]2
M7TE.5D%,241?3$]#051)3TX-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J+PT*("`@(&9U;F-T:6]N('-E87)C:$%I<G!O<G0H)&QA=&ET=61E+"`D
M;&]N9VET=61E+"`D;G5M4F5S=6QT<R`](#$I#0H@("`@>PT*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?9&(I('Q\("%$0CHZ:7-#;VYN96-T:6]N*"1T
M:&ES+3Y?9&(I*2![#0H@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A
M=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27T1"7TY/
M5%]#3TY.14-4140I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-?;G5M
M97)I8R@D;&%T:71U9&4I('Q\("%I<U]N=6UE<FEC*"1L;VYG:71U9&4I*2![
M#0H@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%
M<G)O<BA315)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TXI
M.PT*("`@("`@("!]("`@("`@("`@("`-"B`@("`@("`@#0H@("`@("`@("\O
M($=E="!A;&P@86ER<&]R=',-"B`@("`@("`@)'-E;&5C="`](")314Q%0U0@
M:6-A;RP@>"P@>2P@>B!&4D]-(&UE=&%R06ER<&]R=',B.PT*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-E;&5C="D[#0H@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0[#0H@("`@("`@('T@96QS96EF("AG971?8VQA<W,H)')E
M<W5L="D@(3T@(F1B7W)E<W5L="(@?'P@)')E<W5L="T^;G5M4F]W<R@I(#T]
M(#`I('L-"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR
M86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!
M5$E/3BD[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!297-U;'0@:7,@=F%L
M:60L('-T87)T('-E87)C:`T*("`@("`@("`O+R!);FET:6%L:7IE('9A;'5E
M<PT*("`@("`@("`D;6EN7V1I<W0@/2!N=6QL.PT*("`@("`@("`D<75E<GD@
M("`@/2`D=&AI<RT^<&]L87(R8V%R=&5S:6%N*"1L871I='5D92P@)&QO;F=I
M='5D92D[#0H@("`@("`@("1S96%R8V@@("`](&%R<F%Y*")D:7-T(B`]/B!A
M<G)A>2@I+"`B:6-A;R(@/3X@87)R87DH*2D[#0H@("`@("`@('=H:6QE("@H
M)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI
M("$](&YU;&PI('L-"B`@("`@("`@("`@("1I8V%O(#T@)')O=ULB:6-A;R)=
M.PT*("`@("`@("`@("`@)&%I<B`@/2!A<G)A>2@D<F]W6R)X(ETL("1R;W=;
M(GDB72P@)')O=ULB>B)=*3L-"@T*("`@("`@("`@("`@)&1I<W0@/2`P.PT*
M("`@("`@("`@("`@)&0@/2`P.PT*("`@("`@("`@("`@+R\@0V%L8W5L871E
M(&1I<W1A;F-E(&]F('%U97)Y(&%N9"!C=7)R96YT(&%I<G!O<G0-"B`@("`@
M("`@("`@("\O(&)R96%K(&]F9BP@:68@9&ES=&%N8V4@:7,@;&%R9V5R('1H
M86X@8W5R<F5N="`D;6EN7V1I<W0-"B`@("`@("`@("`@(&9O<B@D9#L@)&0@
M/"!S:7IE;V8H)&%I<BD[("1D*RLI('L-"B`@("`@("`@("`@("`@("`D="`]
M("1A:7);)&1=("T@)'%U97)Y6R1D73L-"B`@("`@("`@("`@("`@("`D9&ES
M="`K/2!P;W<H)'0L(#(I.PT*("`@("`@("`@("`@("`@(&EF("@D;6EN7V1I
M<W0@(3T@;G5L;"`F)B`D9&ES="`^("1M:6Y?9&ES="D@>PT*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H-"B`@("`@("`@("`@(&EF("@D9"`^/2!S:7IE;V8H)&%I<BDI
M('L-"B`@("`@("`@("`@("`@("`O+R!/:RP@8W5R<F5N="!A:7)P;W)T(&ES
M(&]N92!O9B!T:&4@;F5A<F5R(&QO8V%T:6]N<PT*("`@("`@("`@("`@("`@
M("\O(&%D9"!T;R!R97-U;'0M87)R87D-"B`@("`@("`@("`@("`@("`D<V5A
M<F-H6R)D:7-T(EU;72`]("1D:7-T.PT*("`@("`@("`@("`@("`@("1S96%R
M8VA;(FEC86\B75M=(#T@)&EC86\[#0H@("`@("`@("`@("`@("`@+R\@4V]R
M="!A<G)A>2!F;W(@9&ES=&%N8V4-"B`@("`@("`@("`@("`@("!A<G)A>5]M
M=6QT:7-O<G0H)'-E87)C:%LB9&ES=")=+"!33U)47TY5345224,L(%-/4E1?
M05-#+"`D<V5A<F-H6R)I8V%O(ETL(%-/4E1?4U1224Y'+"!33U)47T%30RD[
M#0H@("`@("`@("`@("`@("`@+R\@268@87)R87D@:7,@;&%R9V5R('1H96X@
M9&5S:7)E9"!R97-U;'1S+"!C:&]P(&]F9B!L87-T(&]N90T*("`@("`@("`@
M("`@("`@(&EF("AS:7IE;V8H)'-E87)C:%LB9&ES=")=*2`^("1N=6U297-U
M;'1S*2![#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<V5A<F-H
M6R)D:7-T(ETI.PT*("`@("`@("`@("`@("`@("`@("!A<G)A>5]P;W`H)'-E
M87)C:%LB:6-A;R)=*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)&UI;E]D:7-T(#T@;6%X*"1S96%R8VA;(F1I<W0B72D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1N=6U297-U;'1S
M(#T](#$I('L-"B`@("`@("`@("`@("\O($]N;'D@;VYE(')E<W5L="!W86YT
M960L(')E='5R;B!A<R!S=')I;F<-"B`@("`@("`@("`@(')E='5R;B`D<V5A
M<F-H6R)I8V%O(EU;,%T[#0H@("`@("`@('T@96QS96EF("@D;G5M4F5S=6QT
M<R`^(#$I('L-"B`@("`@("`@("`@("\O(%)E='5R;B!F;W5N9"!L;V-A=&EO
M;G,-"B`@("`@("`@("`@(')E='5R;B`D<V5A<F-H6R)I8V%O(ET[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A
M=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U5.2TY/
M5TY?3$]#051)3TXI.PT*("`@("`@("!]#0H@("`@?0T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(&=E=%5N:71S*"D-"B`@("`O*BH-"B`@("`J(%)E='5R
M;G,@=&AE('5N:71S(&9O<B!T:&4@8W5R<F5N="!Q=65R>0T*("`@("H-"B`@
M("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@
M("1U;FET<T9O<FUA=`T*("`@("H@0')E='5R;B`@(&%R<F%Y#0H@("`@*B!`
M9&5P<F5C871E9`T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T56YI=',H)&ED(#T@;G5L;"P@)'5N:71S1F]R;6%T
M(#T@(B(I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F=E=%5N:71S
M1F]R;6%T*"1U;FET<T9O<FUA="D[#0H@("`@?0T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(&=E=$QO8V%T:6]N*"D-"B`@("`O*BH-"B`@("`J(%)E='5R
M;G,@=&AE(&1A=&$@9F]R('1H92!L;V-A=&EO;B!B96QO;F=I;F<@=&\@=&AE
M($E$#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D:60-"B`@("`J($!R971U<FX@("!014%27T5R<F]R?&%R
M<F%Y#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<@T*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@9V5T3&]C871I;VXH
M)&ED(#T@(B(I#0H@("`@>PT*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C
M:&5C:TQO8V%T:6]N240H)&ED*3L-"@T*("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1S=&%T=7,[#0H@("`@("`@('T-"@T*("`@("`@("`D;&]C871I;VY2
M971U<FX@/2!A<G)A>2@I.PT*#0H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE
M16YA8FQE9"`F)B`H)&QO8V%T:6]N(#T@)'1H:7,M/E]C86-H92T^9V5T*")-
M151!4BTB+B1I9"P@(FQO8V%T:6]N(BDI*2![#0H@("`@("`@("`@("`O+R!'
M<F%B('-T=69F(&9R;VT@8V%C:&4-"B`@("`@("`@("`@("1T:&ES+3Y?;&]C
M871I;VX@/2`D;&]C871I;VX[#0H@("`@("`@("`@("`D;&]C871I;VY2971U
M<FY;(F-A8VAE(ET@/2`B2$E4(CL-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1T:&ES+3Y?9&(I("8F($1".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D8BDI
M('L-"B`@("`@("`@("`@("\O($=E="!D871A(&9R;VT@1$(-"B`@("`@("`@
M("`@("1S96QE8W0@/2`B4T5,14-4(&EC86\L(&YA;64L('-T871E+"!C;W5N
M=')Y+"!L871I='5D92P@;&]N9VET=61E+"!E;&5V871I;VX@(BX-"B`@("`@
M("`@("`@("`@("`@("`@("`B1E)/32!M971A<D%I<G!O<G1S(%=(15)%(&EC
M86\])R(N)&ED+B(G(CL-"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V1B+3YQ=65R>2@D<V5L96-T*3L-"@T*("`@("`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1R97-U;'0I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0[#0H@("`@("`@("`@("!](&5L<V5I9B`H9V5T7V-L87-S*"1R97-U
M;'0I("$](")D8E]R97-U;'0B('Q\("1R97-U;'0M/FYU;5)O=W,H*2`]/2`P
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z
M.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/
M0T%424].*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O(%)E<W5L
M="!I<R!O:RP@<'5T('1H:6YG<R!I;G1O(&]B:F5C=`T*("`@("`@("`@("`@
M)'1H:7,M/E]L;V-A=&EO;B`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(
M34]$15]!4U-/0RD[#0H-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE
M16YA8FQE9"D@>PT*("`@("`@("`@("`@("`@("\O("XN+F%N9"!C86-H92!I
M=`T*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#
M15-?5T5!5$A%4E]%6%!)4D537TQ/0T%424].(BD[#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C86-H92T^97AT4V%V92@B345405(M(BXD:60L("1T:&ES
M+3Y?;&]C871I;VXL("(B+"`D97AP:7)E+"`B;&]C871I;VXB*3L-"B`@("`@
M("`@("`@('T-"@T*("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H
M92)=(#T@(DU)4U,B.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]L;V-A=&EO;B`](&%R<F%Y*`T*("`@("`@("`@("`@("`@(")N
M86UE(B`@("`@(#T^("1I9"P-"B`@("`@("`@("`@("`@("`B<W1A=&4B("`@
M("`]/B`B(BP-"B`@("`@("`@("`@("`@("`B8V]U;G1R>2(@("`]/B`B(BP-
M"B`@("`@("`@("`@("`@("`B;&%T:71U9&4B("`]/B`B(BP-"B`@("`@("`@
M("`@("`@("`B;&]N9VET=61E(B`]/B`B(BP-"B`@("`@("`@("`@("`@("`B
M96QE=F%T:6]N(B`]/B`B(@T*("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*
M("`@("`@("`O+R!3='5F9B!N86UE+7-T<FEN9R!T;V=E=&AE<@T*("`@("`@
M("!I9B`H<W1R;&5N*"1T:&ES+3Y?;&]C871I;VY;(G-T871E(ETI("8F('-T
M<FQE;B@D=&AI<RT^7VQO8V%T:6]N6R)C;W5N=')Y(ETI*2![#0H@("`@("`@
M("`@("`D;&]C;F%M92`]("1T:&ES+3Y?;&]C871I;VY;(FYA;64B72XB+"`B
M+B1T:&ES+3Y?;&]C871I;VY;(G-T871E(ETN(BP@(BXD=&AI<RT^7VQO8V%T
M:6]N6R)C;W5N=')Y(ET[#0H@("`@("`@('T@96QS96EF("AS=')L96XH)'1H
M:7,M/E]L;V-A=&EO;ELB8V]U;G1R>2)=*2D@>PT*("`@("`@("`@("`@)&QO
M8VYA;64@/2`D=&AI<RT^7VQO8V%T:6]N6R)N86UE(ETN(BP@(BXD=&AI<RT^
M7VQO8V%T:6]N6R)C;W5N=')Y(ET[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?;&]C871I;VY;(FYA;64B73L-
M"B`@("`@("`@?0T*("`@("`@("`D;&]C871I;VY2971U<FY;(FYA;64B72`@
M("`@(#T@)&QO8VYA;64[#0H@("`@("`@("1L;V-A=&EO;E)E='5R;ELB;&%T
M:71U9&4B72`@/2`D=&AI<RT^7VQO8V%T:6]N6R)L871I='5D92)=.PT*("`@
M("`@("`D;&]C871I;VY2971U<FY;(FQO;F=I='5D92)=(#T@)'1H:7,M/E]L
M;V-A=&EO;ELB;&]N9VET=61E(ET[#0H@("`@("`@("1L;V-A=&EO;E)E='5R
M;ELB96QE=F%T:6]N(ET@/2`D=&AI<RT^7VQO8V%T:6]N6R)E;&5V871I;VXB
M73L-"@T*("`@("`@("!R971U<FX@)&QO8V%T:6]N4F5T=7)N.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!G971796%T:&5R*"D-"B`@("`O
M*BH-"B`@("`J(%)E='5R;G,@=&AE('=E871H97(M9&%T82!F;W(@=&AE('-U
M<'!L:65D(&QO8V%T:6]N#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D:60-"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T#0H@("`@
M*B!`<F5T=7)N("`@4$A07T5R<F]R?&%R<F%Y#0H@("`@*B!`=&AR;W=S("`@
M4$A07T5R<F]R#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@
M("!F=6YC=&EO;B!G971796%T:&5R*"1I9"`]("(B+"`D=6YI='-&;W)M870@
M/2`B(BD-"B`@("![#0H@("`@("`@("1I9"`@("`@/2!S=')T;W5P<&5R*"1I
M9"D[#0H@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)
M1"@D:60I.PT*#0H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R
M<F]R*"1S=&%T=7,I*2![#0H@("`@("`@("`@("!R971U<FX@)'-T871U<SL-
M"B`@("`@("`@?0T*#0H@("`@("`@("\O($=E="!O=&AE<B!D871A#0H@("`@
M("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET<T9O<FUA="@D=6YI='-&
M;W)M870I.PT*("`@("`@("`D;&]C871I;VX@/2`D=&AI<RT^9V5T3&]C871I
M;VXH)&ED*3L-"@T*("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L960@
M)B8@*"1W96%T:&5R(#T@)'1H:7,M/E]C86-H92T^9V5T*")-151!4BTB+B1I
M9"P@(G=E871H97(B*2DI('L-"B`@("`@("`@("`@("\O(%=E92XN+B!I="!W
M87,@8V%C:&5D+"!L970G<R!H879E(&ET+BXN#0H@("`@("`@("`@("`D=V5A
M=&AE<E)E='5R;B`@/2`D=V5A=&AE<CL-"B`@("`@("`@("`@("1T:&ES+3Y?
M=V5A=&AE<B`]("1W96%T:&5R4F5T=7)N.PT*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("\O(%-E="!T:&4@<V]U<F-E#0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]S;W5R8V4@/3T@(F9I;&4B*2![#0H@("`@("`@("`@("`@
M("`@)'-O=7)C92`](')E86QP871H*"1T:&ES+3Y?<V]U<F-E4&%T:"XD:60N
M(BY46%0B*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@)'-O=7)C92`]("1T:&ES+3Y?<V]U<F-E4&%T:"XD:60N(BY46%0B.PT*
M("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`O+R!$;W=N;&]A9"!A;F0@
M<&%R<V4@=V5A=&AE<@T*("`@("`@("`@("`@)'=E871H97)2971U<FX@(#T@
M)'1H:7,M/E]P87)S95=E871H97)$871A*"1S;W5R8V4L("1U;FET<RD[#0H-
M"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W
M96%T:&5R4F5T=7)N*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=V5A
M=&AE<E)E='5R;CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V-A8VAE16YA8FQE9"D@>PT*("`@("`@("`@("`@("`@("\O($-A
M8VAE('=E871H97(-"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A
M;G0H(E-%4E9)0T537U=%051(15)?15A025)%4U]714%42$52(BD[#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C86-H92T^97AT4V%V92@B345405(M(BXD
M:60L("1W96%T:&5R4F5T=7)N+"`D=6YI='-&;W)M870L("1E>'!I<F4L(")W
M96%T:&5R(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^
M7W=E871H97(@/2`D=V5A=&AE<E)E='5R;CL-"B`@("`@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B.PT*("`@("`@("!]#0H-"B`@
M("`@("`@:68@*&ES<V5T*"1W96%T:&5R4F5T=7)N6R)R96UA<FLB72DI('L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1W96%T:&5R4F5T=7)N6R)R96UA<FLB
M72!A<R`D:V5Y(#T^("1V86PI('L-"B`@("`@("`@("`@("`@("!S=VET8V@@
M*"1K97DI('L-"B`@("`@("`@("`@("`@("`@("`@8V%S92`B<V5A<')E<W-U
M<F4B.@T*("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES
M+3YC;VYV97)T4')E<W-U<F4H)'9A;"P@(FEN(BP@)'5N:71S6R)P<F5S(ETI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("`@("`@("`@(&-A<V4@(G-N;W=D97!T:"(Z#0H@("`@("`@("`@("`@("`@
M("`@(&-A<V4@(G-N;W=E<75I=B(Z#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D;F5W5F%L(#T@)'1H:7,M/F-O;G9E<G10<F5S<W5R92@D=F%L+"`B:6XB
M+"`D=6YI='-;(G)A:6XB72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@8V%S92`B,6AT96UP(CH-"B`@
M("`@("`@("`@("`@("`@("`@8V%S92`B,6AD97<B.@T*("`@("`@("`@("`@
M("`@("`@("!C87-E("(V:&UA>'1E;7`B.@T*("`@("`@("`@("`@("`@("`@
M("!C87-E("(V:&UI;G1E;7`B.@T*("`@("`@("`@("`@("`@("`@("!C87-E
M("(R-&AM87AT96UP(CH-"B`@("`@("`@("`@("`@("`@("`@8V%S92`B,C1H
M;6EN=&5M<"(Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@
M)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=F%L+"`B9B(L("1U;FET<ULB
M=&5M<")=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=V5A
M=&AE<E)E='5R;ELB<F5M87)K(EU;)&ME>5T@/2`D;F5W5F%L.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@9F]R96%C:"`H)'=E871H
M97)2971U<FX@87,@)&ME>2`]/B`D=F%L*2![#0H@("`@("`@("`@("!S=VET
M8V@@*"1K97DI('L-"B`@("`@("`@("`@("`@("!C87-E(")S=&%T:6]N(CH-
M"B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1L;V-A=&EO;ELB;F%M
M92)=.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("!C87-E(")U<&1A=&4B.@T*("`@("`@("`@("`@("`@("`@("`D;F5W
M5F%L(#T@9VUD871E*'1R:6TH)'1H:7,M/E]D871E1F]R;6%T+B(@(BXD=&AI
M<RT^7W1I;65&;W)M870I+"`D=F%L*3L-"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`B=VEN9"(Z#0H@("`@("`@
M("`@("`@("`@8V%S92`B=VEN9$=U<W0B.@T*("`@("`@("`@("`@("`@("`@
M("`D;F5W5F%L(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D=F%L+"`B;7!H(BP@
M)'5N:71S6R)W:6YD(ETI.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("!C87-E(")V:7-I8FEL:71Y(CH-"B`@("`@("`@
M("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T1&ES=&%N8V4H
M)'9A;"P@(G-M(BP@)'5N:71S6R)V:7,B72D[#0H@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E
M(CH-"B`@("`@("`@("`@("`@("!C87-E(")D97=0;VEN="(Z#0H@("`@("`@
M("`@("`@("`@8V%S92`B9F5L=%1E;7!E<F%T=7)E(CH-"B`@("`@("`@("`@
M("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H
M)'9A;"P@(F8B+"`D=6YI='-;(G1E;7`B72D[#0H@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@(G!R97-S=7)E(CH-
M"B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T
M4')E<W-U<F4H)'9A;"P@(FEN(BP@)'5N:71S6R)P<F5S(ETI.PT*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E(")P
M<F5C:7!I=&%T:6]N(CH-"B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@(&9O<B`H)'`@/2`P.R`D
M<"`\('-I>F5O9B@D=F%L*3L@)'`K*RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&YE=U9A;%LD<%T@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7VYU;65R:6,H)'9A;%LD<%U;(F%M;W5N=")=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=686Q;)'!=6R)A
M;6]U;G0B72`]("1T:&ES+3YC;VYV97)T4')E<W-U<F4H)'9A;%LD<%U;(F%M
M;W5N=")=+"`B:6XB+"`D=6YI='-;(G)A:6XB72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N97=686Q;)'!=6R)A;6]U;G0B72`]("1V86Q;)'!=6R)A;6]U;G0B
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1N97=686Q;)'!=6R)H;W5R<R)=("`]("1V86Q;)'!=6R)H
M;W5R<R)=.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*+RH-"B`@("`@("`@("`@("`@("!C87-E(")R96UA
M<FLB.@T*("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@:6UP;&]D92@B
M+"`B+"`D=F%L*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0HJ+PT*
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'=E871H97)2971U<FY;)&ME>5T@
M/2`D;F5W5F%L.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1W96%T
M:&5R4F5T=7)N.PT*("`@('T-"B`@("`O+R!]?7T-"B`@("`-"B`@("`O+R![
M>WL@9V5T1F]R96-A<W0H*0T*("`@("\J*@T*("`@("H@345405(@:&%S(&YO
M(&9O<F5C87-T('!E<B!S92P@<V\@=&AI<R!F=6YC=&EO;B!I<R!J=7-T(&9O
M<@T*("`@("H@8V]M<&%T:6)I;&ET>2!P=7)P;W-E<RX-"B`@("`J#0H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I;G0-
M"B`@("`J($!P87)A;2`@("!I;G0@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A>7,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@
M("`@("`@)'5N:71S1F]R;6%T#0H@("`@*B!`<F5T=7)N("`@8F]O;`T*("`@
M("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0&1E<')E8V%T960-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=$9O<F5C87-T*"1I9"`](&YU;&PL("1D87ES
M(#T@;G5L;"P@)'5N:71S1F]R;6%T(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H@("`@+R\@?7U]#0I]#0HO+R!]?7T-
M"C\^#0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O1VQO8F%L
M=V5A=&AE<BYP:'``````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0P-30V`#$P-#$W,S8S
M,#`U`#`R-#`R,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]
M-"!S:&EF='=I9'1H/30Z("HO#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L-"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS
M92!A;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R<SH@
M06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK#0HO+PT*+R\@)$ED.B!';&]B86QW96%T:&5R+G!H<"QV(#$N,38@,C`P
M-"\P,2\P-B`Q.3HS-CHR-R!E<G4@17AP("0-"@T*<F5Q=6ER95]O;F-E(")3
M97)V:6-E<R]796%T:&5R+T-O;6UO;BYP:'`B.PT*#0HO+R![>WL@8VQA<W,@
M4V5R=FEC97-?5V5A=&AE<E]';&]B86QW96%T:&5R#0HO*BH-"BH@4$5!4CHZ
M4V5R=FEC97-?5V5A=&AE<E]';&]B86QW96%T:&5R#0HJ#0HJ(%1H:7,@8VQA
M<W,@86-T<R!A<R!A;B!I;G1E<F9A8V4@=&\@=&AE('-O87`@<V5R=FEC92!O
M9B!C87!E<V-I96YC92YC;VTN($ET('-E87)C:&5S(&9O<B!G:79E;@T**B!L
M;V-A=&EO;G,@86YD(')E=')I979E<R!C=7)R96YT('=E871H97(@9&%T82X-
M"BH-"BH@1VQO8F%L5V5A=&AE<B!I<R!A(%-/05`@9G)O;G1E;F0@9F]R($U%
M5$%2(&1A=&$L('!R;W9I9&5D(&)Y($-A<&538VEE;F-E+B!)9B!Y;W4@=V%N
M="!T;PT**B!U<V4@345405(L('EO=2!S:&]U;&0@=')Y('1H:7,@8VQA<W,@
M9FER<W0L(&%S(&ET(&ES(&UU8V@@;6]R92!C;VUF;W)T86)L92`H86YD(&%L
M<V\@82!B:70-"BH@9F%S=&5R*2!T:&%N('1H92!N871I=F4@345405(M8VQA
M<W,@<')O=FED960@8GD@=&AI<R!P86-K86=E+@T**@T**B!&;W(@82!W;W)K
M:6YG(&5X86UP;&4L('!L96%S92!T86ME(&$@;&]O:R!A=`T**B`@("`@9&]C
M<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V=L;V)A;'=E871H97(M8F%S
M:6,N<&AP#0HJ#0HJ($!A=71H;W(@("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA
M;&5X0'!C-'`N;F5T/@T**B!`;&EN:R`@("`@("`@(&AT='`Z+R]W=W<N8V%P
M97-C:65N8V4N8V]M+W=E8G-E<G9I8V5S+V=L;V)A;'=E871H97(O:6YD97@N
M<VAT;6P-"BH@0&5X86UP;&4@("`@("!D;V-S+U-E<G9I8V5S7U=E871H97(O
M97AA;7!L97,O9VQO8F%L=V5A=&AE<BUB87-I8RYP:'`-"BH@0'!A8VMA9V4@
M("`@("!397)V:6-E<U]796%T:&5R#0HJ($!L:6-E;G-E("`@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0-"BH@0'9E<G-I;VX@("`@
M("`Q+C(-"BHO#0IC;&%S<R!397)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H
M97(@97AT96YD<R!397)V:6-E<U]796%T:&5R7T-O;6UO;B![#0H-"B`@("`O
M+R![>WL@<')O<&5R=&EE<PT*("`@("\J*@T*("`@("H@5U-$3"!O8FIE8W0L
M('!R;W9I9&5D(&)Y($-A<&538VEE;F-E#0H@("`@*@T*("`@("H@0'9A<B`@
M("`@(&]B:F5C="`@("`@("`@("`@("`@("`@("`@("`D7W=S9&P-"B`@("`J
M($!A8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@("!V87(@)%]W<V1L.PT*
M#0H@("`@+RHJ#0H@("`@*B!33T%0(&]B:F5C="!T;R!A8V-E<W,@<W1A=&EO
M;B!D871A+"!P<F]V:61E9"!B>2!#87!E4V-I96YC90T*("`@("H-"B`@("`J
M($!V87(@("`@("!O8FIE8W0@("`@("`@("`@("`@("`@("`@("`@)%]S=&%T
M:6]N4V]A<`T*("`@("H@0&%C8V5S<R`@('!R:79A=&4-"B`@("`J+PT*("`@
M('9A<B`D7W-T871I;VY3;V%P.PT*#0H@("`@+RHJ#0H@("`@*B!33T%0(&]B
M:F5C="!T;R!A8V-E<W,@=V5A=&AE<B!D871A+"!P<F]V:61E9"!B>2!#87!E
M4V-I96YC90T*("`@("H-"B`@("`J($!V87(@("`@("!O8FIE8W0@("`@("`@
M("`@("`@("`@("`@("`@)%]W96%T97)3;V%P#0H@("`@*B!`86-C97-S("`@
M<')I=F%T90T*("`@("HO#0H@("`@=F%R("1?=V5A=&AE<E-O87`[#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"B`@("`O*BH-"B`@
M("`J($-O;G-T<G5C=&]R#0H@("`@*@T*("`@("H@4F5Q=6ER97,@4T]!4"!T
M;R!B92!I;G-T86QL960-"B`@("`J#0H@("`@*B!`<&%R86T@("`@87)R87D@
M("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS#0H@("`@*B!`<&%R86T@
M("`@;6EX960@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<@T*("`@("H@
M0'1H<F]W<R`@(%!%05)?17)R;W(-"B`@("`J($!T:')O=W,@("!014%27T5R
M<F]R.CI315)624-%4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!
M#0H@("`@*B!`<V5E("`@("`@4V-I96YC95]796%T:&5R.CI38VEE;F-E7U=E
M871H97(-"B`@("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!397)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(H)&]P=&EO
M;G,L("8D97)R;W(I#0H@("`@>PT*("`@("`@("`D<&5R<F]R(#T@;G5L;#L-
M"B`@("`@("`@)'1H:7,M/E-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O<'1I
M;VYS+"`D<&5R<F]R*3L-"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)'!E<G)O<BDI('L-"B`@("`@("`@("`@("1E<G)O<B`]("1P
M97)R;W([#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"@T*("`@
M("`@("!I;F-L=61E7V]N8V4@(E-/05`O0VQI96YT+G!H<"([#0H@("`@("`@
M("1T:&ES+3Y?=W-D;"`](&YE=R!33T%07U=31$PH(FAT='`Z+R]L:79E+F-A
M<&5S8VEE;F-E+F-O;2]W<V1L+T=L;V)A;%=E871H97(N=W-D;"(I.PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]W<V1L+3YF875L="D@)B8@4V5R=FEC
M97-?5V5A=&AE<CHZ:7-%<G)O<B@D=&AI<RT^7W=S9&PM/F9A=6QT*2D@>PT*
M("`@("`@("`@("`@)&5R<F]R(#T@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%
M<G)O<BA315)624-%4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!
M*3L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*#0H@("`@("`@
M(&5V86PH)'1H:7,M/E]W<V1L+3YG96YE<F%T94%L;%!R;WAI97,H*2D[#0H@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*")796)397)V:6-E7T=L;V)A;%=E
M871H97)?4W1A=&EO;DEN9F\B*2!\?"`A8VQA<W-?97AI<W1S*")796)397)V
M:6-E7T=L;V)A;%=E871H97)?1VQO8F%L5V5A=&AE<B(I*2![#0H@("`@("`@
M("`@("`D97)R;W(@/2!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%
M4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$I.PT*("`@
M("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H-"B`@("`@("`@)'1H:7,M
M/E]S=&%T:6]N4V]A<"`]("9N97<@5V5B4V5R=FEC95]';&]B86Q796%T:&5R
M7U-T871I;VY);F9O.PT*("`@("`@("`D=&AI<RT^7W=E871H97)3;V%P(#T@
M)FYE=R!796)397)V:6-E7T=L;V)A;%=E871H97)?1VQO8F%L5V5A=&AE<CL-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V-H96-K3&]C871I
M;VY)1"@I#0H@("`@+RHJ#0H@("`@*B!#:&5C:W,@=&AE(&ED(&9O<B!V86QI
M9"!V86QU97,@86YD('1H=7,@<')E=F5N=',@<VEL;'D@<F5Q=65S=',@=&\@
M1VQO8F%L5V5A=&AE<B!S97)V97(-"B`@("`J#0H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`T*("`@("H@0')E='5R
M;B`@(%!%05)?17)R;W)\8F]O;`T*("`@("H@0'1H<F]W<R`@(%!%05)?17)R
M;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?3D]?3$]#051)3TX-"B`@("`J
M($!T:')O=W,@("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]2
M7TE.5D%,241?3$]#051)3TX-"B`@("`J($!A8V-E<W,@("!P<FEV871E#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!?8VAE8VM,;V-A=&EO;DE$*"1I9"D-"B`@
M("![#0H@("`@("`@(&EF("@A<W1R;&5N*"1I9"DI('L-"B`@("`@("`@("`@
M(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T53
M7U=%051(15)?15)23U)?3D]?3$]#051)3TXI.PT*("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]S=&%T:6]N4V]A<"T^:7-686QI9$-O9&4H)&ED*2`]/3T@
M9F%L<V4I('L-"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R
M.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],
M3T-!5$E/3BD[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@<V5A<F-H3&]C871I
M;VXH*0T*("`@("\J*@T*("`@("H@4V5A<F-H97,@241S(&9O<B!G:79E;B!L
M;V-A=&EO;BP@<F5T=7)N<R!A<G)A>2!O9B!P;W-S:6)L92!L;V-A=&EO;G,@
M;W(@<VEN9VQE($E$#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D;&]C871I;VX-"B`@("`J($!P87)A;2`@
M("!B;V]L("`@("`@("`@("`@("`@("`@("`@("`@)'5S949I<G-T("`@("`@
M($EF('-E="P@9FER<W0@240@;V8@<F5S=6QT+6%R<F%Y(&ES(')E='5R;F5D
M#0H@("`@*B!`<F5T=7)N("`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<-"B`@
M("`J($!T:')O=W,@("!014%27T5R<F]R.CI315)624-%4U]714%42$527T52
M4D]27U=23TY'7U-%4E9%4E]$051!#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%
M<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].
M#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B!S96%R8VA,;V-A=&EO;B@D;&]C871I;VXL("1U<V5&:7)S="`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@+R\@1V5T('-E87)C:"!D871A(&9R;VT@<V5R
M=F5R(&%N9"!U;G-E<FEA;&EZ90T*("`@("`@("`D<V5A<F-H(#T@)'1H:7,M
M/E]S=&%T:6]N4V]A<"T^<V5A<F-H0GE.86UE*"1L;V-A=&EO;BD[#0H-"B`@
M("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-E87)C:"DI
M('L-"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES
M945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!
M5$$I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D<V5A<F-H*2!\?"`A<VEZ96]F*"1S96%R8V@I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H
M4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*"$D=7-E
M1FER<W0@)B8@*'-I>F5O9B@D<V5A<F-H*2`^(#$I*2![#0H@("`@("`@("`@
M("`@("`@("`@("1S96%R8VA2971U<FX@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'-E87)C:"D[
M("1I*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S96%R8VA2971U
M<FY;)'-E87)C:%LD:5TM/FEC86]=(#T@)'-E87)C:%LD:5TM/FYA;64N(BP@
M(BXD<V5A<F-H6R1I72T^8V]U;G1R>3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T@96QS96EF("@D=7-E1FER<W0@?'P@*'-I
M>F5O9B@D<V5A<F-H*2`]/2`Q*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<V5A<F-H4F5T=7)N(#T@)'-E87)C:%LP72T^:6-A;SL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!R
M971U<FX@)'-E87)C:%)E='5R;CL-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@<V5A<F-H3&]C871I;VY">4-O=6YT<GDH*0T*("`@("\J*@T*
M("`@("H@4F5T=7)N<R!)1',@=VET:"!L;V-A=&EO;BUN86UE(&9O<B!A(&=I
M=F5N(&-O=6YT<GD@;W(@86QL(&%V86EL86)L92!C;W5N=')I97,L(&EF(&YO
M('9A;'5E('=A<R!G:79E;B`-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`@("`@("`@("`@("`@("`@("`@("1C;W5N=')Y#0H@("`@*B!`<F5T
M=7)N("`@4$5!4E]%<G)O<GQA<G)A>0T*("`@("H@0'1H<F]W<R`@(%!%05)?
M17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!
M5$$-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R.CI315)624-%4U]714%4
M2$527T524D]27U5.2TY/5TY?3$]#051)3TX-"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E87)C:$QO8V%T:6]N0GE#
M;W5N=')Y*"1C;W5N=')Y(#T@(B(I#0H@("`@>PT*("`@("`@("`O+R!2971U
M<FX@=&AE(&%V86EL86)L92!C;W5N=')I97,@87,@;F\@8V]U;G1R>2!W87,@
M9VEV96X-"B`@("`@("`@:68@*"%S=')L96XH)&-O=6YT<GDI*2![#0H@("`@
M("`@("`@("`D8V]U;G1R:65S(#T@)'1H:7,M/E]S=&%T:6]N4V]A<"T^;&ES
M=$-O=6YT<FEE<R@I.PT*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)&-O=6YT<FEE<RDI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]7
M14%42$527T524D]27U=23TY'7U-%4E9%4E]$051!*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B`D8V]U;G1R:65S.PT*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@3F]W(&9O<B!T:&4@<F5A;"!S96%R8V@-"B`@("`@
M("`@)&-O=6YT<GE,;V-S(#T@)'1H:7,M/E]S=&%T:6]N4V]A<"T^<V5A<F-H
M0GE#;W5N=')Y*"1C;W5N=')Y*3L-"B`@("`@("`@+R\@0VAE8VL@<F5S=6QT
M(&9O<B!V86QI9&ET>0T*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D8V]U;G1R>4QO8W,I*2![#0H@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U=23TY'7U-%4E9%4E]$051!*3L-"B`@("`@("`@?2!E;'-E:68@
M*"%I<U]A<G)A>2@D8V]U;G1R>4QO8W,I*2![#0H@("`@("`@("`@("!R971U
M<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%4
M2$527T524D]27U5.2TY/5TY?3$]#051)3TXI.PT*("`@("`@("!]#0H-"B`@
M("`@("`@+R\@0V]N<W1R=6-T('1H92!R97-U;'0-"B`@("`@("`@)&QO8V%T
M:6]N<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1C;W5N=')Y3&]C
M<R!A<R`D;&]C871I;VXI('L-"B`@("`@("`@("`@("1L;V-A=&EO;G-;)&QO
M8V%T:6]N+3YI8V%O72`]("1L;V-A=&EO;BT^;F%M92XB+"`B+B1L;V-A=&EO
M;BT^8V]U;G1R>3L-"B`@("`@("`@?0T*("`@("`@("!A<V]R="@D;&]C871I
M;VYS*3L-"@T*("`@("`@("!R971U<FX@)&QO8V%T:6]N<SL-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@9V5T56YI=',H*0T*("`@("\J*@T*
M("`@("H@4F5T=7)N<R!T:&4@=6YI=',@9F]R('1H92!C=7)R96YT('%U97)Y
M#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@("`@
M("`@("`@("`D:60-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("`@
M("`@("`@("`@("`@)'5N:71S1F]R;6%T#0H@("`@*B!`<F5T=7)N("`@87)R
M87D-"B`@("`J($!D97!R96-A=&5D#0H@("`@*B!`86-C97-S("`@<'5B;&EC
M#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G9715;FET<R@D:60@/2!N=6QL+"`D
M=6YI='-&;W)M870@/2`B(BD-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI
M<RT^9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T*3L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@9V5T3&]C871I;VXH*0T*("`@("\J*@T*
M("`@("H@4F5T=7)N<R!T:&4@9&%T82!F;W(@=&AE(&QO8V%T:6]N(&)E;&]N
M9VEN9R!T;R!T:&4@240-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1I9`T*("`@("H@0')E='5R;B`@(%!%
M05)?17)R;W)\87)R87D-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R#0H@
M("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971,;V-A=&EO;B@D:60@/2`B(BD-"B`@("![#0H@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PT*#0H@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2![#0H@("`@
M("`@("`@("!R971U<FX@)'-T871U<SL-"B`@("`@("`@?0T*#0H@("`@("`@
M("1L;V-A=&EO;E)E='5R;B`](&%R<F%Y*"D[#0H-"B`@("`@("`@:68@*"1T
M:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D;&]C871I;VX@/2`D=&AI<RT^7V-A
M8VAE+3YG970H(D=7+2(N)&ED+"`B;&]C871I;VXB*2DI('L-"B`@("`@("`@
M("`@("\O($=E="!D871A(&9R;VT@8V%C:&4-"B`@("`@("`@("`@("1T:&ES
M+3Y?;&]C871I;VX@/2`D;&]C871I;VX[#0H@("`@("`@("`@("`D;&]C871I
M;VY2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1L;V-A=&EO;B`]("1T:&ES+3Y?<W1A=&EO;E-O87`M
M/F=E=%-T871I;VXH)&ED*3L-"@T*("`@("`@("`@("`@:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)&QO8V%T:6]N*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D;&]C871I;VX[#0H@("`@("`@("`@("!]#0H-"B`@("`@
M("`@("`@("1T:&ES+3Y?;&]C871I;VX@/2`D;&]C871I;VX[#0H-"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"D@>PT*("`@("`@("`@
M("`@("`@("\O("XN+F%N9"!C86-H92!I=`T*("`@("`@("`@("`@("`@("1E
M>'!I<F4@/2!C;VYS=&%N="@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537TQ/
M0T%424].(BD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C86-H92T^97AT
M4V%V92@B1U<M(BXD:60L("1T:&ES+3Y?;&]C871I;VXL("(B+"`D97AP:7)E
M+"`B;&]C871I;VXB*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1L
M;V-A=&EO;E)E='5R;ELB8V%C:&4B72`](")-25-3(CL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H<W1R;&5N*"1T:&ES+3Y?;&]C871I;VXM/G)E9VEO;BD@
M)B8@<W1R;&5N*"1T:&ES+3Y?;&]C871I;VXM/F-O=6YT<GDI*2![#0H@("`@
M("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?;&]C871I;VXM/FYA;64N(BP@
M(BXD=&AI<RT^7VQO8V%T:6]N+3YR96=I;VXN(BP@(BXD=&AI<RT^7VQO8V%T
M:6]N+3YC;W5N=')Y.PT*("`@("`@("!](&5L<V5I9B`H<W1R;&5N*"1T:&ES
M+3Y?;&]C871I;VXM/F-O=6YT<GDI*2![#0H@("`@("`@("`@("`D;&]C;F%M
M92`]("1T:&ES+3Y?;&]C871I;VXM/FYA;64N(BP@(BXD=&AI<RT^7VQO8V%T
M:6]N+3YC;W5N=')Y.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)&QO8VYA;64@/2`D=&AI<RT^7VQO8V%T:6]N+3YN86UE.PT*("`@("`@("!]
M#0H@("`@("`@("1L;V-A=&EO;E)E='5R;ELB;F%M92)=("`@("`@/2`D;&]C
M;F%M93L-"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)L871I='5D92)=("`]
M("1T:&ES+3Y?;&]C871I;VXM/FQA=&ET=61E.PT*("`@("`@("`D;&]C871I
M;VY2971U<FY;(FQO;F=I='5D92)=(#T@)'1H:7,M/E]L;V-A=&EO;BT^;&]N
M9VET=61E.PT*("`@("`@("`D;&]C871I;VY2971U<FY;(F5L979A=&EO;B)=
M(#T@)'1H:7,M/E]L;V-A=&EO;BT^96QE=F%T:6]N.PT*#0H@("`@("`@(')E
M='5R;B`D;&]C871I;VY2971U<FX[#0H@("`@?0T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(&=E=%=E871H97(H*0T*("`@("\J*@T*("`@("H@4F5T=7)N
M<R!T:&4@=V5A=&AE<BUD871A(&9O<B!T:&4@<W5P<&QI960@;&]C871I;VX-
M"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1I9`T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D=6YI='-&;W)M870-"B`@("`J($!R971U<FX@("!014%2
M7T5R<F]R?&%R<F%Y#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<@T*("`@
M("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@9V5T
M5V5A=&AE<B@D:60@/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I#0H@("`@>PT*
M("`@("`@("!S=&%T:6,@)&-L;W5D<SL-"B`@("`@("`@:68@*"%I<W-E="@D
M8VQO=61S*2D@>PT*("`@("`@("`@("`@)&-L;W5D<R`@("`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@(")S:WD@8VQE87(B+`T*("`@("`@("`@("`@("`@
M(")F97<B+`T*("`@("`@("`@("`@("`@(")S8V%T=&5R960B+`T*("`@("`@
M("`@("`@("`@(")B<F]K96XB+`T*("`@("`@("`@("`@("`@(")O=F5R8V%S
M="(L#0H@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@
M("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L-
M"@T*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A
M='5S*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,[#0H@("`@("`@
M('T-"@T*("`@("`@("`O+R!'970@;W1H97(@9&%T80T*("`@("`@("`D=6YI
M=',@("`@/2`D=&AI<RT^9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T*3L-
M"@T*("`@("`@("`D=V5A=&AE<E)E='5R;B`](&%R<F%Y*"D[#0H@("`@("`@
M(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)'=E871H97(@/2`D=&AI
M<RT^7V-A8VAE+3YG970H(D=7+2(N)&ED+"`B=V5A=&AE<B(I*2D@>PT*("`@
M("`@("`@("`@+R\@4V%M92!P<F]C961U<F4N+BX-"B`@("`@("`@("`@("1T
M:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PT*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("\O("XN+F%S(&QA<W0@9G5N8W1I;VX-"B`@("`@("`@
M("`@("1W96%T:&5R(#T@)'1H:7,M/E]W96%T:&5R4V]A<"T^9V5T5V5A=&AE
M<E)E<&]R="@D:60I.PT*#0H@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D=V5A=&AE<BDI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'=E871H97([#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@
M("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PT*#0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]C86-H945N86)L960I('L-"B`@("`@("`@("`@("`@("`O
M+R`N+BYA;F0@8V%C:&4@:70-"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@
M8V]N<W1A;G0H(E-%4E9)0T537U=%051(15)?15A025)%4U]714%42$52(BD[
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C86-H92T^97AT4V%V92@B1U<M
M(BXD:60L("1T:&ES+3Y?=V5A=&AE<BP@(B(L("1E>'!I<F4L(")W96%T:&5R
M(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB8V%C:&4B72`](")-25-3(CL-"B`@("`@("`@?0T*#0H@("`@("`@("1U
M<&1A=&4@/2!T<FEM*'-T<E]R97!L86-E*&%R<F%Y*")4(BP@(EHB*2P@(B`B
M+"`D=&AI<RT^7W=E871H97(M/G1I;65S=&%M<"DI+B(@1TU4(CL-"@T*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB=7!D871E(ET@("`@("`@("`@/2!G;61A
M=&4H=')I;2@D=&AI<RT^7V1A=&5&;W)M870N(B`B+B1T:&ES+3Y?=&EM949O
M<FUA="DL('-T<G1O=&EM92@D=7!D871E*2D[#0H@("`@("`@(&EF("AS=')L
M96XH)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YR96=I;VXI("8F('-T<FQE
M;B@D=&AI<RT^7W=E871H97(M/G-T871I;VXM/F-O=6YT<GDI*2![#0H@("`@
M("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^
M;F%M92XB+"`B+B1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^<F5G:6]N+B(L
M("(N)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YC;W5N=')Y.PT*("`@("`@
M("!](&5L<V5I9B`H<W1R;&5N*"1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^
M8V]U;G1R>2DI('L-"B`@("`@("`@("`@("1L;V-N86UE(#T@)'1H:7,M/E]W
M96%T:&5R+3YS=&%T:6]N+3YN86UE+B(L("(N)'1H:7,M/E]W96%T:&5R+3YS
M=&%T:6]N+3YC;W5N=')Y.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)&QO8VYA;64@/2`D=&AI<RT^7W=E871H97(M/G-T871I;VXM/FYA;64[
M#0H@("`@("`@('T-"B`@("`@("`@)'=E871H97)2971U<FY;(G-T871I;VXB
M72`@("`@("`@("`@/2`D;&]C;F%M93L-"B`@("`@("`@)'=E871H97)2971U
M<FY;(G=I;F0B72`@("`@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R=%-P965D
M*"1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^<')E=F%I;&EN9U]S<&5E9"P@(FUP
M<R(L("1U;FET<ULB=VEN9")=*3L-"B`@("`@("`@)'=E871H97)2971U<FY;
M(G=I;F1$96=R965S(ET@("`@("`@/2`D=&AI<RT^7W=E871H97(M/G=I;F0M
M/G!R979A:6QI;F=?9&ER96-T:6]N+3YD96=R965S.PT*("`@("`@("`D=V5A
M=&AE<E)E='5R;ELB=VEN9$1I<F5C=&EO;B)=("`@("`]("1T:&ES+3Y?=V5A
M=&AE<BT^=VEN9"T^<')E=F%I;&EN9U]D:7)E8W1I;VXM/F-O;7!A<W,[#0H@
M("`@("`@(&EF("@D=&AI<RT^7W=E871H97(M/G=I;F0M/G!R979A:6QI;F=?
M<W!E960@(3T@)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YG=7-T7W-P965D*2![
M#0H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$=U<W0B72`@("`@
M(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D=&AI<RT^7W=E871H97(M/G=I;F0M
M/F=U<W1?<W!E960L(")M<',B+"`D=6YI='-;(G=I;F0B72D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^=F%R>6EN
M9U]F<F]M7V1I<F5C=&EO;B`A/2`B(B`F)B`D=&AI<RT^7W=E871H97(M/G=I
M;F0M/G9A<GEI;F=?=&]?9&ER96-T:6]N("$]("(B*2![#0H@("`@("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB=VEN9%9A<B)=("`@("`@(#T@87)R87D@*`T*
M("`@("`@("`@("`@("`@(")F<F]M(B`]/B`D=&AI<RT^7W=E871H97(M/G=I
M;F0M/G9A<GEI;F=?9G)O;5]D:7)E8W1I;VXL#0H@("`@("`@("`@("`@("`@
M(G1O(B`@(#T^("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^=F%R>6EN9U]T;U]D
M:7)E8W1I;VX-"B`@("`@("`@("`@("D[#0H@("`@("`@('T-"@T*("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB=FES:6)I;&ET>2)=("`@("`@("`]("1T:&ES
M+3YC;VYV97)T1&ES=&%N8V4H)'1H:7,M/E]W96%T:&5R+3YV:7-I8FEL:71Y
M+3YD:7-T86YC92`O(#$P,#`L(")K;2(L("1U;FET<ULB=FES(ETI.PT*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB=FES475A;&EF:65R(ET@("`@("`]("1T
M:&ES+3Y?=V5A=&AE<BT^=FES:6)I;&ET>2T^<75A;&EF:65R.PT*#0H@("`@
M("`@("1C;VYD:71I;VX@/2!A<G)A>2@I.PT*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]W96%T:&5R+3YP:&5N;VUE;F$I.R`D
M:2LK*2![#0H@("`@("`@("`@("`D8V]N9&ET:6]N6UT@/2`D=&AI<RT^7W=E
M871H97(M/G!H96YO;65N85LD:5TM/G-T<FEN9SL-"B`@("`@("`@?0T*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET:6]N(ET@("`@("`@("`](&EM
M<&QO9&4H(BP@(BP@)&-O;F1I=&EO;BD[#0H@("`@("`@("1L87EE<G,@("`@
M/2!A<G)A>2@I.PT*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)'1H:7,M/E]W96%T:&5R+3YS:WDM/FQA>65R<RD[("1I*RLI('L-"B`@("`@
M("`@("`@(&EF("AS=')T;W5P<&5R*"1T:&ES+3Y?=V5A=&AE<BT^<VMY+3YL
M87EE<G-;)&E=+3YT>7!E*2`A/2`B0TQ%05(B*2![#0H@("`@("`@("`@("`@
M("`@)&QA>65R<ULD:5T@("`@("`@("`@("`@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@("`@("1L87EE<G-;)&E=6R)A;6]U;G0B72`@(#T@)&-L;W5D<ULD
M=&AI<RT^7W=E871H97(M/G-K>2T^;&%Y97)S6R1I72T^97AT96YT73L-"B`@
M("`@("`@("`@("`@("`D;&%Y97)S6R1I75LB:&5I9VAT(ET@("`]("1T:&ES
M+3YC;VYV97)T1&ES=&%N8V4H)'1H:7,M/E]W96%T:&5R+3YS:WDM/FQA>65R
M<ULD:5TM/F%L=&ET=61E("\@,3`P,"P@(FMM(BP@(F9T(BD[#0H@("`@("`@
M("`@("`@("`@:68@*'-T<G1O=7!P97(H)'1H:7,M/E]W96%T:&5R+3YS:WDM
M/FQA>65R<ULD:5TM/G1Y<&4I("$](")#3$]51"(I('L-"B`@("`@("`@("`@
M("`@("`@("`@)&QA>65R<ULD:5U;(G1Y<&4B72`]('5C=V]R9',H<W1R7W)E
M<&QA8V4H(E\B+"`B(BP@)'1H:7,M/E]W96%T:&5R+3YS:WDM/FQA>65R<ULD
M:5TM/G1Y<&4I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*'-I>F5O9B@D;&%Y97)S*2D@>PT*
M("`@("`@("`@("`@)'=E871H97)2971U<FY;(F-L;W5D<R)=("`@("`@("`]
M("1L87EE<G,[#0H@("`@("`@('T-"B`@("`@("`@)'=E871H97)2971U<FY;
M(G1E;7!E<F%T=7)E(ET@("`@("`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T
M=7)E*"1T:&ES+3Y?=V5A=&AE<BT^=&5M<&5R871U<F4M/F%M8FEE;G0L(")C
M(BP@)'5N:71S6R)T96UP(ETI.PT*("`@("`@("`D9F5L=%1E;7!E<F%T=7)E
M(#T@)'1H:7,M/F-A;&-U;&%T95=I;F1#:&EL;"@D=&AI<RT^8V]N=F5R=%1E
M;7!E<F%T=7)E*"1W96%T:&5R4F5T=7)N6R)T96UP97)A='5R92)=+"`D=6YI
M='-;(G1E;7`B72P@(F8B*2P@)'1H:7,M/F-O;G9E<G13<&5E9"@D=V5A=&AE
M<E)E='5R;ELB=VEN9")=+"`D=6YI='-;(G=I;F0B72P@(FUP:"(I*3L-"B`@
M("`@("`@)'=E871H97)2971U<FY;(F9E;'1496UP97)A='5R92)=("`@/2`D
M=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1F96QT5&5M<&5R871U<F4L(")F
M(BP@)'5N:71S6R)T96UP(ETI.PT*("`@("`@("`D=V5A=&AE<E)E='5R;ELB
M9&5W4&]I;G0B72`@("`@("`@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U
M<F4H)'1H:7,M/E]W96%T:&5R+3YT96UP97)A='5R92T^9&5W<&]I;G0L(")C
M(BP@)'5N:71S6R)T96UP(ETI.PT*("`@("`@("`D=V5A=&AE<E)E='5R;ELB
M:'5M:61I='DB72`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=&5M<&5R
M871U<F4M/G)E;&%T:79E7VAU;6ED:71Y.PT*("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB<')E<W-U<F4B72`@("`@("`@("`]("1T:&ES+3YC;VYV97)T4')E
M<W-U<F4H)'1H:7,M/E]W96%T:&5R+3YP<F5S<W5R92T^86QT:6UE=&5R+"`B
M:'!A(BP@)'5N:71S6R)P<F5S(ETI.PT*#0H@("`@("`@(')E='5R;B`D=V5A
M=&AE<E)E='5R;CL-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@
M9V5T1F]R96-A<W0H*0T*("`@("\J*@T*("`@("H@1VQO8F%L5V5A=&AE<B!H
M87,@;F\@9F]R96-A<W0@<&5R('-E+"!S;R!T:&ES(&9U;F-T:6]N(&ES(&IU
M<W0@9F]R#0H@("`@*B!C;VUP871I8FEL:71Y('!U<G!O<V5S+@T*("`@("H-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@
M)&EN=`T*("`@("H@0'!A<F%M("`@(&EN="`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&%Y<PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D=6YI='-&;W)M870-"B`@("`J($!R971U<FX@("!B;V]L
M#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`9&5P<F5C871E9`T*
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1F]R96-A<W0H)&ED(#T@;G5L;"P@
M)&1A>7,@/2!N=6QL+"`D=6YI='-&;W)M870@/2!N=6QL*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@("`O+R!]?7T-"GT-"B\O
M('U]?0T*/SX-"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4V5R=FEC97,O5V5A=&AE<B]%:G-E+G!H<```````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S8Q-C0`,3`T,3<S-C,P,#4`,#(R
M,3,R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP#0HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-#H@*B\-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M+R\@?"!02%`@=F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D
M('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I
M<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO
M+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!!;&5X86YD
M97(@5VER='H@/&%L97A`<&,T<"YN970^("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O
M#0HO+R`D260Z($5J<V4N<&AP+'8@,2XV(#(P,#0O,#$O,#8@,3DZ,S8Z,C<@
M97)U($5X<"`D#0H-"G)E<75I<F5?;VYC92`B4V5R=FEC97,O5V5A=&AE<B]#
M;VUM;VXN<&AP(CL-"@T*+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?
M16IS90T*+RHJ#0HJ(%!%05(Z.E-E<G9I8V5S7U=E871H97)?16IS90T**@T*
M*B!4:&ES(&-L87-S(&%C=',@87,@86X@:6YT97)F86-E('1O('1H92!S;V%P
M('-E<G9I8V4@;V8@14I312X@270@<F5T<FEE=F5S#0HJ(&-U<G)E;G0@=V5A
M=&AE<B!D871A(&%N9"!F;W)E8V%S=',@8F%S960@;VX@<&]S=&%L(&-O9&5S
M("A:25`I+@T**@T**B!#=7)R96YT;'D@=&AI<R!S97)V:6-E(&ES(&]N;'D@
M879A:6QA8FQE(&9O<B!54R!T97)R:71O<GDN#0HJ#0HJ($9O<B!A('=O<FMI
M;F<@97AA;7!L92P@<&QE87-E('1A:V4@82!L;V]K(&%T#0HJ("`@("!D;V-S
M+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O96IS92UB87-I8RYP:'`-"BH-
M"BH@0&%U=&AO<B`@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN
M970^#0HJ($!L:6YK("`@("`@("`@:'1T<#HO+W=W=RYE:G-E+F-O;2]S97)V
M:6-E<R]W96%T:&5R7WAM;%]W96)?<V5R=FEC97,N:'1M#0HJ($!E>&%M<&QE
M("`@("`@9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V5J<V4M8F%S
M:6,N<&AP#0HJ($!P86-K86=E("`@("`@4V5R=FEC97-?5V5A=&AE<@T**B!`
M;&EC96YS92`@("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT#0HJ($!V97)S:6]N("`@("`@,2XR#0HJ+PT*8VQA<W,@4V5R=FEC97-?
M5V5A=&AE<E]%:G-E(&5X=&5N9',@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX@
M>PT*#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"B`@("`O*BH-"B`@("`J(%=3
M1$P@;V)J96-T+"!P<F]V:61E9"!B>2!%2E-%#0H@("`@*@T*("`@("H@0'9A
M<B`@("`@(&]B:F5C="`@("`@("`@("`@("`@("`@("`@("`D7W=S9&P-"B`@
M("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@("!V87(@)%]W<V1L
M.PT*#0H@("`@+RHJ#0H@("`@*B!33T%0(&]B:F5C="!T;R!A8V-E<W,@=V5A
M=&AE<B!D871A+"!P<F]V:61E9"!B>2!%2E-%#0H@("`@*@T*("`@("H@0'9A
M<B`@("`@(&]B:F5C="`@("`@("`@("`@("`@("`@("`@("`D7W=E871E<E-O
M87`-"B`@("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@("!V87(@
M)%]W96%T:&5R4V]A<#L-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C;VYS
M=')U8W1O<@T*("`@("\J*@T*("`@("H@0V]N<W1R=6-T;W(-"B`@("`J#0H@
M("`@*B!297%U:7)E<R!33T%0('1O(&)E(&EN<W1A;&QE9`T*("`@("H-"B`@
M("`J($!P87)A;2`@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@("`@)&]P
M=&EO;G,-"B`@("`J($!P87)A;2`@("!M:7AE9"`@("`@("`@("`@("`@("`@
M("`@("`@)&5R<F]R#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<@T*("`@
M("H@0'1H<F]W<R`@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$-"B`@("`J($!S964@("`@("!38VEE;F-E
M7U=E871H97(Z.E-C:65N8V5?5V5A=&AE<@T*("`@("H@0&%C8V5S<R`@('!R
M:79A=&4-"B`@("`J+PT*("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?
M16IS92@D;W!T:6]N<RP@)B1E<G)O<BD-"B`@("![#0H@("`@("`@("1P97)R
M;W(@/2!N=6QL.PT*("`@("`@("`D=&AI<RT^4V5R=FEC97-?5V5A=&AE<E]#
M;VUM;VXH)&]P=&EO;G,L("1P97)R;W(I.PT*("`@("`@("!I9B`H4V5R=FEC
M97-?5V5A=&AE<CHZ:7-%<G)O<B@D<&5R<F]R*2D@>PT*("`@("`@("`@("`@
M)&5R<F]R(#T@)'!E<G)O<CL-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@
M("`@?0T*#0H@("`@("`@(&EN8VQU9&5?;VYC92`B4T]!4"]#;&EE;G0N<&AP
M(CL-"B`@("`@("`@)'1H:7,M/E]W<V1L(#T@;F5W(%-/05!?5U-$3"@B:'1T
M<#HO+W=W=RYE:G-E+F-O;2]796%T:&5R4V5R=FEC92]397)V:6-E+F%S;7@_
M5U-$3"(I.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]W<V1L+3YF875L
M="D@)B8@4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=&AI<RT^7W=S9&PM
M/F9A=6QT*2D@>PT*("`@("`@("`@("`@)&5R<F]R(#T@4V5R=FEC97-?5V5A
M=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U=23TY'
M7U-%4E9%4E]$051!*3L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@
M?0T*#0H@("`@("`@(&5V86PH)'1H:7,M/E]W<V1L+3YG96YE<F%T94%L;%!R
M;WAI97,H*2D[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*")796)397)V
M:6-E7U-E<G9I8V5?4V5R=FEC95-O87`B*2D@>PT*("`@("`@("`@("`@)&5R
M<F]R(#T@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]7
M14%42$527T524D]27U=23TY'7U-%4E9%4E]$051!*3L-"B`@("`@("`@("`@
M(')E='5R;CL-"B`@("`@("`@?0T*#0H@("`@("`@("1T:&ES+3Y?=V5A=&AE
M<E-O87`@/2`F;F5W(%=E8E-E<G9I8V5?4V5R=FEC95]397)V:6-E4V]A<#L-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V-H96-K3&]C871I
M;VY)1"@I#0H@("`@+RHJ#0H@("`@*B!#:&5C:W,@=&AE(&ED(&9O<B!V86QI
M9"!V86QU97,@86YD('1H=7,@<')E=F5N=',@<VEL;'D@<F5Q=65S=',@=&\@
M14I312!S97)V97(-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1I9`T*("`@("H@0')E='5R;B`@(%!%05)?
M17)R;W)\8F]O;`T*("`@("H@0'1H<F]W<R`@(%!%05)?17)R;W(Z.E-%4E9)
M0T537U=%051(15)?15)23U)?3D]?3$]#051)3TX-"B`@("`J($!T:')O=W,@
M("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TE.5D%,241?
M3$]#051)3TX-"B`@("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@
M("!F=6YC=&EO;B!?8VAE8VM,;V-A=&EO;DE$*"1I9"D-"B`@("![#0H@("`@
M("`@(&EF("@A<W1R;&5N*"1I9"DI('L-"B`@("`@("`@("`@(')E='5R;B!3
M97)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?
M15)23U)?3D]?3$]#051)3TXI.PT*("`@("`@("!](&5L<V5I9B`H(6-T>7!E
M7V1I9VET*"1I9"D@?'P@*'-T<FQE;B@D:60I("$](#4I*2![#0H@("`@("`@
M("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)6
M24-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TXI.PT*("`@("`@
M("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[('-E87)C:$QO8V%T:6]N*"D-"B`@("`O*BH-"B`@
M("`J($5*4T4@;V9F97)S(&YO('-E87)C:"!F=6YC=&EO;B!T;R!D871E+"!S
M;R!T:&ES(&9U;F-T:6]N(&ES(&1I<V%B;&5D+@T*("`@("H@36%Y8F4@=&AI
M<R!I<R!T:&4@<&QA8V4@=&\@:6YT97)F86-E('1O('-O;64@;VYL:6YE('!O
M<W1C;V1E('-E<G9I8V4N+BX@#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D;&]C871I;VX-"B`@("`J($!P
M87)A;2`@("!B;V]L("`@("`@("`@("`@("`@("`@("`@("`@)'5S949I<G-T
M#0H@("`@*B!`<F5T=7)N("`@8F]O;`T*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PT*("`@("H@0&1E<')E8V%T960-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E
M87)C:$QO8V%T:6]N*"1L;V-A=&EO;B`](&YU;&PL("1U<V5&:7)S="`](&YU
M;&PI#0H@("`@>PT*("`@("`@("!R971U<FX@)&9A;'-E.PT*("`@('T-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R
M>2@I#0H@("`@+RHJ#0H@("`@*B!%2E-%(&]F9F5R<R!N;R!S96%R8V@@9G5N
M8W1I;VX@=&\@9&%T92P@<V\@=&AI<R!F=6YC=&EO;B!I<R!D:7-A8FQE9"X-
M"B`@("`J($UA>6)E('1H:7,@:7,@=&AE('!L86-E('1O(&EN=&5R9F%C92!T
M;R!S;VUE(&]N;&EN92!P;W-T8V]D92!S97)V:6-E+BXN(`T*("`@("H-"B`@
M("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&-O
M=6YT<GD-"B`@("`J($!R971U<FX@("!B;V]L#0H@("`@*B!`86-C97-S("`@
M<'5B;&EC#0H@("`@*B!`9&5P<F5C871E9`T*("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5A<F-H3&]C871I;VY">4-O=6YT<GDH)&-O=6YT<GD@/2!N=6QL*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("1F86QS93L-"B`@("!]#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@9V5T56YI=',H*0T*("`@("\J*@T*("`@("H@
M4F5T=7)N<R!T:&4@=6YI=',@9F]R('1H92!C=7)R96YT('%U97)Y#0H@("`@
M*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D:60-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@
M("`@("`@)'5N:71S1F]R;6%T#0H@("`@*B!`<F5T=7)N("`@87)R87D-"B`@
M("`J($!D97!R96-A=&5D#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!G9715;FET<R@D:60@/2!N=6QL+"`D=6YI='-&
M;W)M870@/2`B(BD-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^9V5T
M56YI='-&;W)M870H)'5N:71S1F]R;6%T*3L-"B`@("!]#0H@("`@+R\@?7U]
M#0H-"B`@("`O+R![>WL@9V5T3&]C871I;VXH*0T*("`@("\J*@T*("`@("H@
M4F5T=7)N<R!T:&4@9&%T82!F;W(@=&AE(&QO8V%T:6]N(&)E;&]N9VEN9R!T
M;R!T:&4@240-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1I9`T*("`@("H@0')E='5R;B`@(%!%05)?17)R
M;W)\87)R87D-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R#0H@("`@*B!`
M86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971,;V-A
M=&EO;B@D:60@/2`B(BD-"B`@("![#0H@("`@("`@("1S=&%T=7,@/2`D=&AI
M<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PT*#0H@("`@("`@(&EF("A397)V
M:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2![#0H@("`@("`@("`@
M("!R971U<FX@)'-T871U<SL-"B`@("`@("`@?0T*#0H@("`@("`@("1L;V-A
M=&EO;E)E='5R;B`](&%R<F%Y*"D[#0H-"B`@("`@("`@:68@*"1T:&ES+3Y?
M8V%C:&5%;F%B;&5D("8F("@D=V5A=&AE<B`]("1T:&ES+3Y?8V%C:&4M/F=E
M="@D:60L(")W96%T:&5R(BDI*2![#0H@("`@("`@("`@("`O+R!'970@9&%T
M82!F<F]M(&-A8VAE#0H@("`@("`@("`@("`D=&AI<RT^7W=E871H97(@/2`D
M=V5A=&AE<CL-"B`@("`@("`@("`@("1L;V-A=&EO;E)E='5R;ELB8V%C:&4B
M72`](")(250B.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'=E
M871H97(@/2`D=&AI<RT^7W=E871H97)3;V%P+3YG971796%T:&5R26YF;R@D
M:60I.PT*#0H@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D=V5A=&AE<BDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'=E
M871H97([#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("1T:&ES+3Y?
M=V5A=&AE<B`]("1W96%T:&5R.PT*#0H@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]C86-H945N86)L960I('L-"B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@
M8V%C:&4@:70-"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H
M(E-%4E9)0T537U=%051(15)?15A025)%4U]714%42$52(BD[#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C86-H92T^97AT4V%V92@D:60L("1T:&ES+3Y?
M=V5A=&AE<BP@(B(L("1E>'!I<F4L(")W96%T:&5R(BD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D;&]C871I;VY2971U<FY;(F-A8VAE(ET@/2`B
M34E34R([#0H@("`@("`@('T-"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)N
M86UE(ET@/2`D=&AI<RT^7W=E871H97(M/DQO8V%T:6]N.PT*#0H@("`@("`@
M(')E='5R;B`D;&]C871I;VY2971U<FX[#0H@("`@?0T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(&=E=%=E871H97(H*0T*("`@("\J*@T*("`@("H@4F5T
M=7)N<R!T:&4@=V5A=&AE<BUD871A(&9O<B!T:&4@<W5P<&QI960@;&]C871I
M;VX-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1I9`T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D=6YI='-&;W)M870-"B`@("`J($!R971U<FX@("!0
M14%27T5R<F]R?&%R<F%Y#0H@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<@T*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T5V5A=&AE<B@D:60@/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I#0H@("`@
M>PT*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H
M)&ED*3L-"@T*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<W1A='5S*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,[#0H@
M("`@("`@('T-"@T*("`@("`@("`O+R!'970@;W1H97(@9&%T80T*("`@("`@
M("`D=6YI=',@("`@/2`D=&AI<RT^9V5T56YI='-&;W)M870H)'5N:71S1F]R
M;6%T*3L-"@T*("`@("`@("`D=V5A=&AE<E)E='5R;B`](&%R<F%Y*"D[#0H@
M("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)'=E871H97(@
M/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED+"`B=V5A=&AE<B(I*2D@>PT*("`@
M("`@("`@("`@+R\@4V%M92!P<F]C961U<F4N+BX-"B`@("`@("`@("`@("1T
M:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PT*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("\O("XN+F%S(&QA<W0@9G5N8W1I;VX-"B`@("`@("`@
M("`@("1W96%T:&5R(#T@)'1H:7,M/E]W96%T:&5R4V]A<"T^9V5T5V5A=&AE
M<DEN9F\H)&ED*3L-"@T*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'=E871H97(I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1W96%T:&5R.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`D
M=&AI<RT^7W=E871H97(@/2`D=V5A=&AE<CL-"@T*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?8V%C:&5%;F%B;&5D*2![#0H@("`@("`@("`@("`@("`@+R\@
M+BXN86YD(&-A8VAE(&ET#0H@("`@("`@("`@("`@("`@)&5X<&ER92`](&-O
M;G-T86YT*")315)624-%4U]714%42$527T584$E215-?5T5!5$A%4B(I.PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H)&ED+"`D
M=&AI<RT^7W=E871H97(L("(B+"`D97AP:7)E+"`B=V5A=&AE<B(I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'=E871H97)2971U<FY;(F-A8VAE
M(ET@/2`B34E34R([#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H(6ES<V5T
M*"1C;VUP87-S*2D@>PT*("`@("`@("`@("`@+R\@665S+"!.3D4@86YD('1H
M92!L:6ME<R!A<F4@;75L=&EP;&5S(&]F(#(R+C4L(&)U="!A<R!T:&4@;W1H
M97(-"B`@("`@("`@("`@("\O('-E<G9I8V5S(')E='5R;B!I;G1E9V5R<R!F
M;W(@=&AI<R!V86QU92P@=&AE<V4@9&ER96-T:6]N<R!A<F4-"B`@("`@("`@
M("`@("\O(')O=6YD960@=7`-"B`@("`@("`@("`@("1C;VUP87-S(#T@87)R
M87DH#0H@("`@("`@("`@("`@("`@(FYO<G1H(B`@("`@("`@("`@("`]/B!A
M<G)A>2@B3B(L("`@("`P*2P-"B`@("`@("`@("`@("`@("`B;F]R=&@@;F]R
M=&AE87-T(B`@(#T^(&%R<F%Y*").3D4B+"`@,C,I+`T*("`@("`@("`@("`@
M("`@(")N;W)T:&5A<W0B("`@("`@("`@/3X@87)R87DH(DY%(BP@("`T-2DL
M#0H@("`@("`@("`@("`@("`@(F5A<W0@;F]R=&AE87-T(B`@("`]/B!A<G)A
M>2@B14Y%(BP@(#8X*2P-"B`@("`@("`@("`@("`@("`B96%S="(@("`@("`@
M("`@("`@(#T^(&%R<F%Y*")%(BP@("`@.3`I+`T*("`@("`@("`@("`@("`@
M(")E87-T('-O=71H96%S="(@("`@/3X@87)R87DH(D5312(L(#$Q,RDL#0H@
M("`@("`@("`@("`@("`@(G-O=71H96%S="(@("`@("`@("`]/B!A<G)A>2@B
M4T4B+"`@,3,U*2P-"B`@("`@("`@("`@("`@("`B<V]U=&@@<V]U=&AE87-T
M(B`@(#T^(&%R<F%Y*")34T4B+"`Q-3@I+`T*("`@("`@("`@("`@("`@(")S
M;W5T:"(@("`@("`@("`@("`@/3X@87)R87DH(E,B+"`@(#$X,"DL#0H@("`@
M("`@("`@("`@("`@(G-O=71H('-O=71H=V5S="(@("`]/B!A<G)A>2@B4U-7
M(BP@,C`S*2P-"B`@("`@("`@("`@("`@("`B<V]U=&AW97-T(B`@("`@("`@
M(#T^(&%R<F%Y*")35R(L("`R,C4I+`T*("`@("`@("`@("`@("`@(")W97-T
M('-O=71H=V5S="(@("`@/3X@87)R87DH(E=35R(L(#(T."DL#0H@("`@("`@
M("`@("`@("`@(G=E<W0B("`@("`@("`@("`@("`]/B!A<G)A>2@B5R(L("`@
M,C<P*2P-"B`@("`@("`@("`@("`@("`B=V5S="!N;W)T:'=E<W0B("`@(#T^
M(&%R<F%Y*")73E<B+"`R.3,I+`T*("`@("`@("`@("`@("`@(")N;W)T:'=E
M<W0B("`@("`@("`@/3X@87)R87DH(DY7(BP@(#,Q-2DL#0H@("`@("`@("`@
M("`@("`@(FYO<G1H(&YO<G1H=V5S="(@("`]/B!A<G)A>2@B3DY7(BP@,S,X
M*0T*("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*#0H@("`@("`@('!R96=?
M;6%T8V@H(B\H7'<K*2`H7&0K*2P@*%QD*RDL(&%T("A<9"LZ7&0K(%QW32D@
M6UY<*%TK*%PH*%M>7"E=*RE<*2D_+R(L("1T:&ES+3Y?=V5A=&AE<BT^3&%S
M=%5P9&%T960L("1U<&1A=&4I.PT*("`@("`@("!I9B`H:7-S970H)'5P9&%T
M95LU72DI('L-"B`@("`@("`@("`@("1T:6UE<W1R:6YG(#T@)'5P9&%T95LV
M73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:6UE<W1R:6YG
M(#T@)'5P9&%T95LR72XB("(N)'5P9&%T95LQ72XB("(N)'5P9&%T95LS72XB
M("(N)'5P9&%T95LT72XB($535"([#0H@("`@("`@('T-"B`@("`@("`@)'=E
M871H97)2971U<FY;(G5P9&%T92)=("`@("`@("`@("`@/2!G;61A=&4H=')I
M;2@D=&AI<RT^7V1A=&5&;W)M870N(B`B+B1T:&ES+3Y?=&EM949O<FUA="DL
M('-T<G1O=&EM92@D=&EM97-T<FEN9RDI.PT*("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB<W1A=&EO;B)=("`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^
M4F5P;W)T961!=#L-"B`@("`@("`@)'=E871H97)2971U<FY;(F-O;F1I=&EO
M;DEC;VXB72`@("`@/2`D=&AI<RT^7W=E871H97(M/DEC;VY);F1E>#L-"B`@
M("`@("`@<')E9U]M871C:"@B+R@M/UQD*RE<1"LO(BP@)'1H:7,M/E]W96%T
M:&5R+3Y496UP<F%T=7)E+"`D=&5M<&5R871U<F4I.R`@("`@("`@#0H@("`@
M("`@("1W96%T:&5R4F5T=7)N6R)T96UP97)A='5R92)=("`@("`@(#T@)'1H
M:7,M/F-O;G9E<G1496UP97)A='5R92@D=&5M<&5R871U<F5;,5TL(")F(BP@
M)'5N:71S6R)T96UP(ETI.PT*("`@("`@("!P<F5G7VUA=&-H*"(O*"T_7&0K
M*5Q$*R\B+"`D=&AI<RT^7W=E871H97(M/D9E96QS3&EK92P@)&9E;'1496UP
M97)A='5R92D[("`@("`@("`-"B`@("`@("`@)'=E871H97)2971U<FY;(F9E
M;'1496UP97)A='5R92)=("`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E
M*"1F96QT5&5M<&5R871U<F5;,5TL(")F(BP@)'5N:71S6R)T96UP(ETI.PT*
M("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET:6]N(ET@("`@("`@("`]
M("1T:&ES+3Y?=V5A=&AE<BT^1F]R96-A<W0[#0H@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"(O*%M<9%PN72LI7$0K+R(L("1T:&ES+3Y?=V5A=&AE<BT^5FES
M:6)I;&ET>2P@)'9I<VEB:6QI='DI*2![(`T*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(G9I<VEB:6QI='DB72`@("`]("1T:&ES+3YC;VYV97)T1&ES
M=&%N8V4H)'9I<VEB:6QI='E;,5TL(")S;2(L("1U;FET<ULB=FES(ETI.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'=E871H97)2971U<FY;
M(G9I<VEB:6QI='DB72`@("`]('1R:6TH)'1H:7,M/E]W96%T:&5R+3Y6:7-I
M8FEL:71Y*3L-"B`@("`@("`@?2`-"B`@("`@("`@<')E9U]M871C:"@B+RA;
M7&1<+ETK*2!I;F-H97,@86YD("A<=RLI+R(L("1T:&ES+3Y?=V5A=&AE<BT^
M4')E<W-U<F4L("1P<F5S<W5R92D[#0H@("`@("`@("1W96%T:&5R4F5T=7)N
M6R)P<F5S<W5R92)=("`@("`@("`@(#T@)'1H:7,M/F-O;G9E<G10<F5S<W5R
M92@D<')E<W-U<F5;,5TL(")I;B(L("1U;FET<ULB<')E<R)=*3L@("`@("`@
M(`T*("`@("`@("`D=V5A=&AE<E)E='5R;ELB<')E<W-U<F54<F5N9")=("`@
M("`]("1P<F5S<W5R95LR73L-"B`@("`@("`@<')E9U]M871C:"@B+R@M/UQD
M*RE<1"LO(BP@)'1H:7,M/E]W96%T:&5R+3Y$97=0;VEN="P@)&1E=U!O:6YT
M*3L@("`@("`-"B`@("`@("`@)'=E871H97)2971U<FY;(F1E=U!O:6YT(ET@
M("`@("`@("`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1D97=0;VEN
M=%LQ72P@(F8B+"`D=6YI='-;(G1E;7`B72D[#0H@("`@("`@('!R96=?;6%T
M8V@H(B\H7&0K*2`H7'<K*2\B+"`D=&AI<RT^7W=E871H97(M/E5626YD97@L
M("1U=DEN9&5X*3L-"B`@("`@("`@)'=E871H97)2971U<FY;(G5V26YD97@B
M72`@("`@("`@("`@/2`D=79);F1E>%LQ73L-"B`@("`@("`@)'=E871H97)2
M971U<FY;(G5V5&5X=")=("`@("`@("`@("`@/2`D=79);F1E>%LR73L-"B`@
M("`@("`@)'=E871H97)2971U<FY;(FAU;6ED:71Y(ET@("`@("`@("`@/2!S
M=')?<F5P;&%C92@B)2(L("(B+"`D=&AI<RT^7W=E871H97(M/DAU;6ED:71Y
M*3L-"B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]&<F]M('1H92`H6UQW7"!=
M*RD@870@*%M<9%PN72LI("AG=7-T:6YG('1O("A;7&1<+ETK*2`I/VUP:"\B
M+"`D=&AI<RT^7W=E871H97(M/E=I;F0L("1W:6YD*2D@>PT*("`@("`@("`@
M("`@)'=E871H97)2971U<FY;(G=I;F0B72`@("`@("`@("`@("`@/2`D=&AI
M<RT^8V]N=F5R=%-P965D*"1W:6YD6S)=+"`B;7!H(BP@)'5N:71S6R)W:6YD
M(ETI.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1W:6YD6S1=*2D@>PT*("`@
M("`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD1W5S=")=("`@("`@
M/2`D=&AI<RT^8V]N=F5R=%-P965D*"1W:6YD6S1=+"`B;7!H(BP@)'5N:71S
M6R)W:6YD(ETI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(G=I;F1$96=R965S(ET@("`@("`@/2`D8V]M<&%S<UMS=')T
M;VQO=V5R*"1W:6YD6S%=*5U;,5T[#0H@("`@("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB=VEN9$1I<F5C=&EO;B)=("`@("`]("1C;VUP87-S6W-T<G1O;&]W
M97(H)'=I;F1;,5TI75LP73L-"B`@("`@("`@?2!E;'-E:68@*'-T<G1O;&]W
M97(H)'1H:7,M/E]W96%T:&5R+3Y7:6YD*2`]/2`B8V%L;2(I('L-"B`@("`@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD(ET@("`@("`@("`@/2`P.PT*
M("`@("`@("`@("`@)'=E871H97)2971U<FY;(G=I;F1$96=R965S(ET@("`]
M(#`[#0H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$1I<F5C=&EO
M;B)=(#T@(D-!3$TB.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1W
M96%T:&5R4F5T=7)N.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!G971&;W)E8V%S="@I#0H@("`@+RHJ#0H@("`@*B!'970@=&AE(&9O<F5C
M87-T(&9O<B!T:&4@;F5X="!D87ES#0H@("`@*@T*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D:6YT#0H@("`@*B!`<&%R
M86T@("`@:6YT("`@("`@("`@("`@("`@("`@("`@("`@("1D87ES("`@("`@
M("`@("!686QU97,@8F5T=V5E;B`Q(&%N9"`Y#0H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U;FET<T9O<FUA=`T*("`@
M("H@0')E='5R;B`@(%!%05)?17)R;W)\87)R87D-"B`@("`J($!T:')O=W,@
M("!014%27T5R<F]R#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971&;W)E8V%S="@D:60@/2`B(BP@)&1A>7,@/2`R
M+"`D=6YI='-&;W)M870@/2`B(BD-"B`@("![#0H@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PT*#0H@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2![#0H@("`@
M("`@("`@("!R971U<FX@)'-T871U<SL-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(6EN7V%R<F%Y*"1D87ES+"!R86YG92@Q+"`Y*2DI('L-"B`@("`@("`@
M("`@("1D87ES(#T@,CL-"B`@("`@("`@?0T*#0H@("`@("`@("\O($=E="!O
M=&AE<B!D871A#0H@("`@("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET
M<T9O<FUA="@D=6YI='-&;W)M870I.PT*#0H@("`@("`@("1F;W)E8V%S=%)E
M='5R;B`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA
M8FQE9"`F)B`H)&9O<F5C87-T(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@
M(F9O<F5C87-T(BDI*2![#0H@("`@("`@("`@("`O+R!386UE('!R;V-E9'5R
M92XN+@T*("`@("`@("`@("`@)'1H:7,M/E]F;W)E8V%S="`]("1F;W)E8V%S
M=#L-"B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`](")(
M250B.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@+R\@+BXN87,@
M;&%S="!F=6YC=&EO;@T*("`@("`@("`@("`@)&9O<F5C87-T(#T@)'1H:7,M
M/E]W96%T:&5R4V]A<"T^1V5T3FEN941A>49O<F5C87-T26YF;R@D:60I.PT*
M#0H@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D
M9F]R96-A<W0I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1F;W)E8V%S
M=#L-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@)'1H:7,M/E]F;W)E
M8V%S="`]("1F;W)E8V%S=#L-"@T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M8V%C:&5%;F%B;&5D*2![#0H@("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A
M8VAE(&ET#0H@("`@("`@("`@("`@("`@)&5X<&ER92`](&-O;G-T86YT*")3
M15)624-%4U]714%42$527T584$E215-?1D]214-!4U0B*3L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-A8VAE+3YE>'13879E*"1I9"P@)'1H:7,M/E]F
M;W)E8V%S="P@(B(L("1E>'!I<F4L(")F;W)E8V%S="(I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)C86-H92)=(#T@
M(DU)4U,B.PT*("`@("`@("!]#0H-"B`@("`@("`@)&9O<F5C87-T4F5T=7)N
M6R)D87ES(ET@("`](&%R<F%Y*"D[#0H-"B`@("`@("`@9F]R("@D:2`](#$[
M("1I(#P]("1D87ES.R`D:2LK*2![#0H@("`@("`@("`@("!P<F5G7VUA=&-H
M*"(O*"T_7&0K*5Q$*R\B+"`D=&AI<RT^7V9O<F5C87-T+3Y[(D1A>2(N)&E]
M+3Y(:6=H+"`D=&5M<&5R871U<F5(:6=H*3L@("`@("`@(`T*("`@("`@("`@
M("`@<')E9U]M871C:"@B+R@M/UQD*RE<1"LO(BP@)'1H:7,M/E]F;W)E8V%S
M="T^>R)$87DB+B1I?2T^3&]W+"`D=&5M<&5R871U<F5,;W<I.R`@("`@("`@
M#0H@("`@("`@("`@("`D9&%Y(#T@87)R87DH#0H@("`@("`@("`@("`@("`@
M(G1E;7!E<G1U<F5(:6=H(B`]/B`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E
M*"1T96UP97)A='5R94AI9VA;,5TL(")F(BP@)'5N:71S6R)T96UP(ETI+`T*
M("`@("`@("`@("`@("`@(")T96UP97)A='5R94QO=R(@/3X@)'1H:7,M/F-O
M;G9E<G1496UP97)A='5R92@D=&5M<&5R871U<F5,;W=;,5TL(")F(BP@)'5N
M:71S6R)T96UP(ETI+`T*("`@("`@("`@("`@("`@(")D87DB(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`B8V]N9&ET:6]N(B`@("`@/3X@)'1H
M:7,M/E]F;W)E8V%S="T^>R)$87DB+B1I?2T^1F]R96-A<W0L#0H@("`@("`@
M("`@("`@("`@("`@(")C;VYD:71I;VY)8V]N(B`]/B`D=&AI<RT^7V9O<F5C
M87-T+3Y[(D1A>2(N)&E]+3Y)8V]N26YD97@L#0H@("`@("`@("`@("`@("`@
M("`@(")P<F5C:7!I=&%T:6]N(B`]/B!T<FEM*'-T<E]R97!L86-E*"(E(BP@
M(B(L("1T:&ES+3Y?9F]R96-A<W0M/GLB1&%Y(BXD:7TM/E!R96-I<$-H86YC
M92DI#0H@("`@("`@("`@("`@("`@*0T*("`@("`@("`@("`@*3L-"@T*("`@
M("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)D87ES(EU;72`]("1D87D[#0H@
M("`@("`@('T-"@T*("`@("`@("!R971U<FX@)&9O<F5C87-T4F5T=7)N.R`@
M("`@("`@#0H@("`@?0T*("`@("\O('U]?0T*?0T*+R\@?7U]#0H_/@T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O0V]M;6]N+G!H
M<````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0R,C`Q`#$P-#$W,S8S,#`U
M`#`R,C0V,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S
M:&EF='=I9'1H/30Z("HO#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R<SH@06QE
M>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M#0HO+PT*+R\@)$ED.B!#;VUM;VXN<&AP+'8@,2XR.2`R,#`T+S`Q+S`V(#$Y
M.C,V.C(W(&5R=2!%>'`@)`T*#0IR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E
M871H97(N<&AP(CL-"@T*+R\@>WM[(&-O;G-T86YT<PT*+R\@>WM[(&YA='5R
M86P@8V]N<W1A;G1S(&%N9"!M96%S=7)E<PT*9&5F:6YE*")315)624-%4U]7
M14%42$527U)!1$E54U]%05)42"(L(#8S-S@N,34I.PT*+R\@?7U]#0HO+R!]
M?7T-"@T*+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?0V]M;6]N#0HO
M*BH-"BH@4$5!4CHZ4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX-"BH-"BH@4&%R
M96YT(&-L87-S(&9O<B!W96%T:&5R+7-E<G9I8V5S+B!$969I;F5S(&-O;6UO
M;B!F=6YC=&EO;G,@9F]R('5N:70-"BH@8V]N=F5R<VEO;G,L(&-H96-K<R!F
M;W(@87-T<F]N;VUY+6-L87-S+"!C86-H92!E;F%B;&EN9R!A;F0@9&]E<R!O
M=&AE<@T**B!M:7-C96QL86YE;W5S('1H:6YG<RX@#0HJ#0HJ($!A=71H;W(@
M("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@T**B!`<&%C
M:V%G92`@("`@(%-E<G9I8V5S7U=E871H97(-"BH@0&QI8V5N<V4@("`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X=`T**B!`=F5R<VEO
M;B`@("`@(#$N,@T**B\-"F-L87-S(%-E<G9I8V5S7U=E871H97)?0V]M;6]N
M('L-"@T*("`@("\O('M[>R!P<F]P97)T:65S#0H@("`@+RHJ#0H@("`@*B!&
M;W)M870@;V8@=&AE('5N:71S('!R;W9I9&5D("AS=&%N9&%R9"]M971R:6,O
M8W5S=&]M*0T*("`@("H-"B`@("`J($!V87(@("`@("!S=')I;F<@("`@("`@
M("`@("`@("`@("`@("`@)%]U;FET<T9O<FUA=`T*("`@("H@0&%C8V5S<R`@
M('!R:79A=&4-"B`@("`J+PT*("`@('9A<B`D7W5N:71S1F]R;6%T(#T@(G,B
M.PT*#0H@("`@+RHJ#0H@("`@*B!#=7-T;VT@9F]R;6%T(&]F('1H92!U;FET
M<PT*("`@("H-"B`@("`J($!V87(@("`@("!A<G)A>2`@("`@("`@("`@("`@
M("`@("`@("`@)%]C=7-T;VU5;FET<T9O<FUA=`T*("`@("H@0&%C8V5S<R`@
M('!R:79A=&4-"B`@("`J+PT*("`@('9A<B`D7V-U<W1O;55N:71S1F]R;6%T
M(#T@87)R87DH#0H@("`@("`@(")T96UP(B`@/3X@(F8B+`T*("`@("`@("`B
M=FES(B`@(#T^(")S;2(L#0H@("`@("`@(")W:6YD(B`@/3X@(FUP:"(L#0H@
M("`@("`@(")P<F5S(B`@/3X@(FEN(BP-"B`@("`@("`@(G)A:6XB("`]/B`B
M:6XB#0H@("`@*3L-"@T*("`@("\J*@T*("`@("H@1F]R;6%T(&]F('1H92!U
M<V5D(&1A=&5S#0H@("`@*@T*("`@("H@0'9A<B`@("`@('-T<FEN9R`@("`@
M("`@("`@("`@("`@("`@("`D7V1A=&5&;W)M870-"B`@("`J($!A8V-E<W,@
M("!P<FEV871E#0H@("`@*B\-"B`@("!V87(@)%]D871E1F]R;6%T(#T@(FTO
M9"]Y(CL-"@T*("`@("\J*@T*("`@("H@1F]R;6%T(&]F('1H92!U<V5D('1I
M;65S#0H@("`@*@T*("`@("H@0'9A<B`@("`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D7W1I;65&;W)M870-"B`@("`J($!A8V-E<W,@("!P<FEV
M871E#0H@("`@*B\-"B`@("!V87(@)%]T:6UE1F]R;6%T(#T@(D<Z:2!!(CL-
M"@T*("`@("\J*@T*("`@("H@3V)J96-T(&-O;G1A:6YI;F<@=&AE(&QO8V%T
M:6]N+61A=&$-"B`@("`J#0H@("`@*B!`=F%R("`@("`@;V)J96-T('-T9$-L
M87-S("`@("`@("`@("`@("1?;&]C871I;VX-"B`@("`J($!A8V-E<W,@("!P
M<FEV871E#0H@("`@*B\-"B`@("!V87(@)%]L;V-A=&EO;CL-"@T*("`@("\J
M*@T*("`@("H@3V)J96-T(&-O;G1A:6YI;F<@=&AE('=E871H97(M9&%T80T*
M("`@("H-"B`@("`J($!V87(@("`@("!O8FIE8W0@<W1D0VQA<W,@("`@("`@
M("`@("`@)%]W96%T:&5R#0H@("`@*B!`86-C97-S("`@<')I=F%T90T*("`@
M("HO#0H@("`@=F%R("1?=V5A=&AE<CL-"@T*("`@("\J*@T*("`@("H@3V)J
M96-T(&-O;G1A:6YI;F<@=&AE(&9O<F5C87-T+61A=&$-"B`@("`J#0H@("`@
M*B!`=F%R("`@("`@;V)J96-T('-T9$-L87-S("`@("`@("`@("`@("1?9F]R
M96-A<W0-"B`@("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B\-"B`@("!V
M87(@)%]F;W)E8V%S=#L-"@T*("`@("\J*@T*("`@("H@0V%C:&4L(&-O;G1A
M:6YI;F<@=&AE(&1A=&$M;V)J96-T<PT*("`@("H-"B`@("`J($!V87(@("`@
M("!O8FIE8W0@0V%C:&4@("`@("`@("`@("`@("`@)%]C86-H90T*("`@("H@
M0&%C8V5S<R`@('!R:79A=&4-"B`@("`J+PT*("`@('9A<B`D7V-A8VAE.PT*
M#0H@("`@+RHJ#0H@("`@*B!0<F]V:61E<R!C:&5C:R!F;W(@0V%C:&4-"B`@
M("`J#0H@("`@*B!`=F%R("`@("`@8F]O;"`@("`@("`@("`@("`@("`@("`@
M("`@("1?8V%C:&5%;F%B;&5D#0H@("`@*B!`86-C97-S("`@<')I=F%T90T*
M("`@("HO#0H@("`@=F%R("1?8V%C:&5%;F%B;&5D(#T@9F%L<V4[#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"B`@("`O*BH-"B`@
M("`J($-O;G-T<G5C=&]R#0H@("`@*@T*("`@("H@0'!A<F%M("`@(&%R<F%Y
M("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<PT*("`@("H@0'!A<F%M
M("`@(&UI>&5D("`@("`@("`@("`@("`@("`@("`@("`D97)R;W(-"B`@("`J
M($!T:')O=W,@("!014%27T5R<F]R#0H@("`@*B!`<V5E("`@("`@4V-I96YC
M95]796%T:&5R.CI38VEE;F-E7U=E871H97(-"B`@("`J($!A8V-E<W,@("!P
M<FEV871E#0H@("`@*B\-"B`@("!F=6YC=&EO;B!397)V:6-E<U]796%T:&5R
M7T-O;6UO;B@D;W!T:6]N<RP@)B1E<G)O<BD-"B`@("![#0H@("`@("`@("\O
M(%-E="!O<'1I;VYS(&%C8V]R9&EN9VQY("`@("`@("`-"B`@("`@("`@:68@
M*&ES<V5T*"1O<'1I;VYS6R)C86-H951Y<&4B72DI('L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULB8V%C:&5/<'1I;VYS(ETI*2![#0H@("`@
M("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3YS971#86-H92@D;W!T:6]N
M<ULB8V%C:&54>7!E(ETL("1O<'1I;VYS6R)C86-H94]P=&EO;G,B72D[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^<V5T0V%C:&4H)&]P=&EO;G-;(F-A8VAE5'EP92)=*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PT*("`@("`@("`@("`@)&5R
M<F]R(#T@)'-T871U<SL-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@
M?0T*#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB=6YI='-&;W)M870B
M72DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB8W5S=&]M
M56YI='-&;W)M870B72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M56YI='-&;W)M870H)&]P=&EO;G-;(G5N:71S1F]R;6%T(ETL("1O<'1I;VYS
M6R)C=7-T;VU5;FET<T9O<FUA=")=*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%5N:71S1F]R;6%T*"1O<'1I
M;VYS6R)U;FET<T9O<FUA=")=*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)D871E
M1F]R;6%T(ETI*2![#0H@("`@("`@("`@("`D=&AI<RT^<V5T1&%T951I;65&
M;W)M870H)&]P=&EO;G-;(F1A=&5&;W)M870B72P@(B(I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB=&EM949O<FUA=")=*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/G-E=$1A=&54:6UE1F]R;6%T*"(B+"`D
M;W!T:6]N<ULB=&EM949O<FUA=")=*3L-"B`@("`@("`@?0T*("`@('T-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!S971#86-H92@I#0H@("`@+RHJ#0H@
M("`@*B!%;F%B;&5S(&-A8VAI;F<@=&AE(&1A=&$L('5S86=E('-T<F]N9VQY
M(')E8V]M;65N9&5D#0H@("`@*@T*("`@("H@4F5Q=6ER97,@0V%C:&4@=&\@
M8F4@:6YS=&%L;&5D#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D8V%C:&54>7!E#0H@("`@*B!`<&%R86T@
M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1C86-H94]P=&EO;G,-
M"B`@("`J($!R971U<FX@("!014%27T5R<F]R?&)O;VP-"B`@("`J($!T:')O
M=W,@("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27T-!0TA%
M7TE.251?1D%)3$5$#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!S971#86-H92@D8V%C:&54>7!E(#T@(F9I;&4B+"`D
M8V%C:&5/<'1I;VYS(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@("\O(%1H
M92!E<G)O<B!H86YD;&EN9R!I;B!#86-H92!I<R!A(&)I="!C<G5M;7D@*')E
M860Z(&YO="!E>&ES=&5N="D-"B`@("`@("`@+R\@<V\@=V4@:&%V92!T;R!D
M;R!T:&%T(&]N(&]U<B!O=VXN+BX-"B`@("`@("`@0&EN8VQU9&5?;VYC92`B
M0V%C:&4N<&AP(CL-"B`@("`@("`@0"1C86-H92`](&YE=R!#86-H92@D8V%C
M:&54>7!E+"`D8V%C:&5/<'1I;VYS*3L-"B`@("`@("`@:68@*&ES7V]B:F5C
M="@D8V%C:&4I("8F("AG971?8VQA<W,H)&-A8VAE*2`]/2`B8V%C:&4B('Q\
M(&ES7W-U8F-L87-S7V]F*"1C86-H92P@(F-A8VAE(BDI*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7V-A8VAE("`@("`@("`]("1C86-H93L-"B`@("`@("`@
M("`@("1T:&ES+3Y?8V%C:&5%;F%B;&5D(#T@=')U93L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&4@("`@("`@(#T@;G5L
M;#L-"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5%;F%B;&5D(#T@9F%L<V4[
M#0H@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%
M<G)O<BA315)624-%4U]714%42$527T524D]27T-!0TA%7TE.251?1D%)3$5$
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!S9715;FET<T9O<FUA="@I#0H@
M("`@+RHJ#0H@("`@*B!#:&%N9V5S('1H92!R97!R97-E;G1A=&EO;B!O9B!T
M:&4@=6YI=',@*'-T86YD87)D+VUE=')I8RD-"B`@("`J#0H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U;FET<T9O<FUA
M=`T*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@
M("`D8W5S=&]M56YI='-&;W)M870-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-
M"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=%5N:71S1F]R;6%T*"1U;FET<T9O
M<FUA="P@)&-U<W1O;55N:71S1F]R;6%T(#T@87)R87DH*2D-"B`@("![#0H@
M("`@("`@('-T871I8R`D86-C97!T961&;W)M871S.PT*("`@("`@("!I9B`H
M(6ES<V5T*"1A8V-E<'1E9$9O<FUA=',I*2![#0H@("`@("`@("`@("`D86-C
M97!T961&;W)M871S(#T@87)R87DH#0H@("`@("`@("`@("`@("`@(G1E;7`B
M("`]/B!A<G)A>2@B8R(L(")F(BDL#0H@("`@("`@("`@("`@("`@(G9I<R(@
M("`]/B!A<G)A>2@B:VTB+"`B9G0B+"`B<VTB*2P-"B`@("`@("`@("`@("`@
M("`B=VEN9"(@(#T^(&%R<F%Y*")M<&@B+"`B:VUH(BP@(FMT(BP@(FUP<R(L
M(")F<',B*2P-"B`@("`@("`@("`@("`@("`B<')E<R(@(#T^(&%R<F%Y*")I
M;B(L(")H<&$B+"`B;6(B+"`B;6TB+"`B871M(BDL#0H@("`@("`@("`@("`@
M("`@(G)A:6XB("`]/B!A<G)A>2@B:6XB+"`B;6TB*0T*("`@("`@("`@("`@
M*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@:68@*'-T<FQE;B@D
M=6YI='-&;W)M870I("8F(&EN7V%R<F%Y*'-T<G1O;&]W97(H)'5N:71S1F]R
M;6%T>S!]*2P@87)R87DH(F,B+"`B;2(L(")S(BDI*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7W5N:71S1F]R;6%T(#T@<W1R=&]L;W=E<B@D=6YI='-&;W)M
M871[,'TI.PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?=6YI='-&;W)M870@
M/3T@(F,B("8F(&ES7V%R<F%Y*"1C=7-T;VU5;FET<T9O<FUA="DI('L-"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D8W5S=&]M56YI='-&;W)M870@87,@
M)&ME>2`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&%R
M<F%Y7VME>5]E>&ES=',H)&ME>2P@)&%C8V5P=&5D1F]R;6%T<RD@)B8@:6Y?
M87)R87DH)'9A;'5E+"`D86-C97!T961&;W)M871S6R1K97E=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7-T;VU5;FET<T9O<FUA
M=%LD:V5Y72`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^
M7W5N:71S1F]R;6%T(#T](")C(BD@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=6YI='-&;W)M870@/2`B<R([#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@9V5T56YI='-&
M;W)M870H*0T*("`@("\J*@T*("`@("H@4F5T=7)N<R!T:&4@<V5L96-T960@
M=6YI=',@9F]R;6%T#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870-"B`@("`J($!R971U
M<FX@("!A<G)A>0T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T(#T@(B(I
M#0H@("`@>PT*("`@("`@("`O+R!4:&ES(&ES(&-H96%P)V\@<W1U9F8-"B`@
M("`@("`@:68@*'-T<FQE;B@D=6YI='-&;W)M870I("8F(&EN7V%R<F%Y*'-T
M<G1O;&]W97(H)'5N:71S1F]R;6%T>S!]*2P@87)R87DH(F,B+"`B;2(L(")S
M(BDI*2![#0H@("`@("`@("`@("`D=6YI='-&;W)M870@/2!S=')T;VQO=V5R
M*"1U;FET<T9O<FUA='LP?2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D=6YI='-&;W)M870@/2`D=&AI<RT^7W5N:71S1F]R;6%T.PT*("`@
M("`@("!]#0H-"B`@("`@("`@)&,@/2`D=&AI<RT^7V-U<W1O;55N:71S1F]R
M;6%T.PT*("`@("`@("`D;2`](&%R<F%Y*`T*("`@("`@("`@("`@(G1E;7`B
M("`]/B`B8R(L#0H@("`@("`@("`@("`B=FES(B`@(#T^(")K;2(L#0H@("`@
M("`@("`@("`B=VEN9"(@(#T^(")K;6@B+`T*("`@("`@("`@("`@(G!R97,B
M("`]/B`B;6(B+`T*("`@("`@("`@("`@(G)A:6XB("`]/B`B;6TB#0H@("`@
M("`@("D[#0H@("`@("`@("1S(#T@87)R87DH#0H@("`@("`@("`@("`B=&5M
M<"(@(#T^(")F(BP-"B`@("`@("`@("`@(")V:7,B("`@/3X@(G-M(BP-"B`@
M("`@("`@("`@(")W:6YD(B`@/3X@(FUP:"(L#0H@("`@("`@("`@("`B<')E
M<R(@(#T^(")I;B(L#0H@("`@("`@("`@("`B<F%I;B(@(#T^(")I;B(-"B`@
M("`@("`@*3L-"@T*("`@("`@("!R971U<FX@)'LD=6YI='-&;W)M871].PT*
M("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!S971$871E5&EM949O
M<FUA="@I#0H@("`@+RHJ#0H@("`@*B!#:&%N9V5S('1H92!R97!R97-E;G1A
M=&EO;B!O9B!T:6UE(&%N9"!D871E<R`H<V5E(&AT='`Z+R]W=W<N<&AP+FYE
M="]D871E*0T*("`@("H-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@
M("`@("`@("`@("`@("`@)&1A=&5&;W)M870-"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'1I;65&;W)M870-"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=$1A
M=&54:6UE1F]R;6%T*"1D871E1F]R;6%T(#T@(B(L("1T:6UE1F]R;6%T(#T@
M(B(I#0H@("`@>PT*("`@("`@("!I9B`H<W1R;&5N*"1D871E1F]R;6%T*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]D871E1F]R;6%T(#T@)&1A=&5&;W)M
M870[#0H@("`@("`@('T-"B`@("`@("`@:68@*'-T<FQE;B@D=&EM949O<FUA
M="DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=&EM949O<FUA="`]("1T:6UE
M1F]R;6%T.PT*("`@("`@("!]#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@
M+R\@>WM[(&-O;G9E<G1496UP97)A='5R92@I#0H@("`@+RHJ#0H@("`@*B!#
M;VYV97)T('1E;7!E<F%T=7)E(&)E='=E96X@9B!A;F0@8PT*("`@("H-"B`@
M("`J($!P87)A;2`@("!F;&]A="`@("`@("`@("`@("`@("`@("`@("`@)'1E
M;7!E<F%T=7)E#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1F<F]M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1T;PT*("`@("H@0')E='5R;B`@(&9L;V%T#0H@
M("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C
M;VYV97)T5&5M<&5R871U<F4H)'1E;7!E<F%T=7)E+"`D9G)O;2P@)'1O*0T*
M("`@('L-"B`@("`@("`@)&9R;VT@/2!S=')T;VQO=V5R*"1F<F]M>S!]*3L-
M"B`@("`@("`@)'1O("`@/2!S=')T;VQO=V5R*"1T;WLP?2D[#0H-"B`@("`@
M("`@)')E<W5L="`](&%R<F%Y*`T*("`@("`@("`@("`@(F8B(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@(")F(B`]/B`D=&5M<&5R871U<F4L("`@("`@
M("`@("`@(F,B(#T^("@D=&5M<&5R871U<F4@+2`S,BD@+R`Q+C@-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`B8R(@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@(F8B(#T^(#$N."`J("1T96UP97)A='5R92`K(#,R+"`B8R(@
M/3X@)'1E;7!E<F%T=7)E#0H@("`@("`@("`@("`I#0H@("`@("`@("D[#0H-
M"B`@("`@("`@<F5T=7)N(')O=6YD*"1R97-U;'1;)&9R;VU=6R1T;UTL(#(I
M.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C;VYV97)T4W!E
M960H*0T*("`@("\J*@T*("`@("H@0V]N=F5R="!S<&5E9"!B971W965N(&UP
M:"P@:VUH+"!K="P@;7!S(&%N9"!F<',-"B`@("`J#0H@("`@*B!`<&%R86T@
M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1S<&5E9`T*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D9G)O;0T*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M=&\-"B`@("`J($!R971U<FX@("!F;&]A=`T*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@8V]N=F5R=%-P965D*"1S<&5E
M9"P@)&9R;VTL("1T;RD-"B`@("![#0H@("`@("`@("1F<F]M(#T@<W1R=&]L
M;W=E<B@D9G)O;2D[#0H@("`@("`@("1T;R`@(#T@<W1R=&]L;W=E<B@D=&\I
M.PT*#0H@("`@("`@('-T871I8R`D9F%C=&]R.PT*("`@("`@("!I9B`H(6ES
M<V5T*"1F86-T;W(I*2![#0H@("`@("`@("`@("`D9F%C=&]R(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@(FUP:"(@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@(")M<&@B(#T^(#$L("`@("`@("`@(FMM:"(@/3X@,2XV,#DS
M-#0L(")K="(@/3X@,"XX-C@Y-S8R+"`B;7!S(B`]/B`P+C0T-S`T+"`@(")F
M<',B(#T^(#$N-#8V-C8V-PT*("`@("`@("`@("`@("`@("DL#0H@("`@("`@
M("`@("`@("`@(FMM:"(@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M(")M<&@B(#T^(#`N-C(Q,S<Q,BP@(FMM:"(@/3X@,2P@("`@("`@(")K="(@
M/3X@,"XU,SDY-38X+"`B;7!S(B`]/B`P+C(W-S<W-S@L(")F<',B(#T^(#`N
M.3$Q,S0T-`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M(FMT(B`@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@(")M<&@B(#T^
M(#$N,34P-S<Y-"P@(FMM:"(@/3X@,2XX-3(L("`@(")K="(@/3X@,2P@("`@
M("`@("`B;7!S(B`]/B`P+C4Q-#0T-#0L(")F<',B(#T^(#$N-C@W.#`Y.0T*
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@(FUP<R(@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@(")M<&@B(#T^(#(N,C,V.3,V
M,RP@(FMM:"(@/3X@,RXV+"`@("`@(")K="(@/3X@,2XY-#,X-#0U+"`B;7!S
M(B`]/B`Q+"`@("`@("`@(")F<',B(#T^(#,N,C@P.#,Y.0T*("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@(F9P<R(@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@(")M<&@B(#T^(#`N-C@Q.#$X,BP@(FMM:"(@
M/3X@,2XP.3<R."P@(")K="(@/3X@,"XU.3(T.#,X+"`B;7!S(B`]/B`P+C,P
M-#@L("`@(")F<',B(#T^(#$-"B`@("`@("`@("`@("`@("`I#0H@("`@("`@
M("`@("`I.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N(')O=6YD*"1S
M<&5E9"`J("1F86-T;W);)&9R;VU=6R1T;UTL(#(I.PT*("`@('T-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!C;VYV97)T4')E<W-U<F4H*0T*("`@("\J
M*@T*("`@("H@0V]N=F5R="!P<F5S<W5R92!B971W965N(&EN+"!H<&$L(&UB
M+"!M;2!A;F0@871M#0H@("`@*@T*("`@("H@0'!A<F%M("`@(&9L;V%T("`@
M("`@("`@("`@("`@("`@("`@("`D<')E<W-U<F4-"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&9R;VT-"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'1O#0H@("`@
M*B!`<F5T=7)N("`@9FQO870-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J+PT*("`@(&9U;F-T:6]N(&-O;G9E<G10<F5S<W5R92@D<')E<W-U<F4L
M("1F<F]M+"`D=&\I#0H@("`@>PT*("`@("`@("`D9G)O;2`]('-T<G1O;&]W
M97(H)&9R;VTI.PT*("`@("`@("`D=&\@("`]('-T<G1O;&]W97(H)'1O*3L-
M"@T*("`@("`@("!S=&%T:6,@)&9A8W1O<CL-"B`@("`@("`@:68@*"%I<W-E
M="@D9F%C=&]R*2D@>PT*("`@("`@("`@("`@)&9A8W1O<B`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@(")I;B(@("`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@(FEN(B`]/B`Q+"`@("`@("`@(")H<&$B(#T^(#,S+C@V,S@X
M-RP@(FUB(B`]/B`S,RXX-C,X.#<L(")M;2(@/3X@,C4N-"P@("`@("`B871M
M(B`]/B`P+C`S,S0R,3,-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@("`@(")H<&$B("`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M(FEN(B`]/B`P+C`R.34S+"`@(")H<&$B(#T^(#$L("`@("`@("`@(FUB(B`]
M/B`Q+"`@("`@("`@(")M;2(@/3X@,"XW-3`P-C$V+"`B871M(B`]/B`P+C`P
M,#DX-CD-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@(")M
M8B(@("`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`P
M+C`R.34S+"`@(")H<&$B(#T^(#$L("`@("`@("`@(FUB(B`]/B`Q+"`@("`@
M("`@(")M;2(@/3X@,"XW-3`P-C$V+"`B871M(B`]/B`P+C`P,#DX-CD-"B`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@(")M;2(@("`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`P+C`S.3,W,#$L
M(")H<&$B(#T^(#$N,S,S,C(S.2P@(FUB(B`]/B`Q+C,S,S(R,SDL(")M;2(@
M/3X@,2P@("`@("`@("`B871M(B`]/B`P+C`P,3,Q-3@-"B`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@("`@(")A=&TB("`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@(FEN(B`]/B`R.2PY,C$R-3@L(")H<&$B(#T^
M(#$P,3,N,C4P,2P@(FUB(B`]/B`Q,#$S+C(U,#$L(")M;2(@/3X@-S4Y+CDY
M.3DU,BP@(F%T;2(@/3X@,0T*("`@("`@("`@("`@("`@("D-"B`@("`@("`@
M("`@("D[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@<F]U;F0H)'!R
M97-S=7)E("H@)&9A8W1O<ELD9G)O;5U;)'1O72P@,BD[#0H@("`@?0T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G9E<G1$:7-T86YC92@I#0H@("`@
M+RHJ#0H@("`@*B!#;VYV97)T(&1I<W1A;F-E(&)E='=E96X@:VTL(&9T(&%N
M9"!S;0T*("`@("H-"B`@("`J($!P87)A;2`@("!F;&]A="`@("`@("`@("`@
M("`@("`@("`@("`@)&1I<W1A;F-E#0H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1F<F]M#0H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1T;PT*("`@("H@0')E='5R
M;B`@(&9L;V%T#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@
M("!F=6YC=&EO;B!C;VYV97)T1&ES=&%N8V4H)&1I<W1A;F-E+"`D9G)O;2P@
M)'1O*0T*("`@('L-"B`@("`@("`@)'1O("`@/2!S=')T;VQO=V5R*"1T;RD[
M#0H@("`@("`@("1F<F]M(#T@<W1R=&]L;W=E<B@D9G)O;2D[#0H-"B`@("`@
M("`@<W1A=&EC("1F86-T;W([#0H@("`@("`@(&EF("@A:7-S970H)&9A8W1O
M<BDI('L-"B`@("`@("`@("`@("1F86-T;W(@/2!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`B:VTB(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`B
M:VTB(#T^(#$L("`@("`@("`@(F9T(B`]/B`S,C@P+C@S.3@Y-2P@(G-M(B`]
M/B`P+C8R,3,V.3D-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M("`@(")F="(@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@(")K;2(@
M/3X@,"XP,#`S,#0X+"`B9G0B(#T^(#$L("`@("`@("`@("`B<VTB(#T^(#`N
M,#`P,3@Y-`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M(G-M(B`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@(FMM(B`]/B`Q
M+C8P.3,T-S(L(")F="(@/3X@-3(X,"XP,3`V+"`@(")S;2(@/3X@,0T*("`@
M("`@("`@("`@("`@("D-"B`@("`@("`@("`@("D[#0H@("`@("`@('T-"@T*
M("`@("`@("!R971U<FX@<F]U;F0H)&1I<W1A;F-E("H@)&9A8W1O<ELD9G)O
M;5U;)'1O72P@,BD[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(&-A;&-U;&%T95=I;F1#:&EL;"@I#0H@("`@+RHJ#0H@("`@*B!#86QC=6QA
M=&4@=VEN9&-H:6QL(&9R;VT@=&5M<&5R871U<F4@86YD('=I;F1S<&5E9"`H
M96YH86YC960@9F]R;75L82D-"B`@("`J#0H@("`@*B!496UP97)A='5R92!H
M87,@=&\@8F4@96YT97)E9"!I;B!D96<@1BP@<W!E960@:6X@;7!H(0T*("`@
M("H-"B`@("`J($!P87)A;2`@("!F;&]A="`@("`@("`@("`@("`@("`@("`@
M("`@)'1E;7!E<F%T=7)E#0H@("`@*B!`<&%R86T@("`@9FQO870@("`@("`@
M("`@("`@("`@("`@("`@("1S<&5E9`T*("`@("H@0')E='5R;B`@(&9L;V%T
M#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`;&EN:R`@("`@:'1T
M<#HO+W=W=RYN=W,N;F]A82YG;W8O;VTO=VEN9&-H:6QL+R`@("`@(`T*("`@
M("HO#0H@("`@9G5N8W1I;VX@8V%L8W5L871E5VEN9$-H:6QL*"1T96UP97)A
M='5R92P@)'-P965D*0T*("`@('L-"B`@("`@("`@<F5T=7)N(')O=6YD*#,U
M+C<T("L@,"XV,C$U("H@)'1E;7!E<F%T=7)E("T@,S4N-S4@*B!P;W<H)'-P
M965D+"`P+C$V*2`K(#`N-#(W-2`J("1T96UP97)A='5R92`J('!O=R@D<W!E
M960L(#`N,38I*3L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@
M8V%L8W5L871E2'5M:61I='DH*0T*("`@("\J*@T*("`@("H@0V%L8W5L871E
M(&AU;6ED:71Y(&9R;VT@=&5M<&5R871U<F4@86YD(&1E=W!O:6YT#0H@("`@
M*B!4:&ES(&ES(&]N;'D@86X@87!P<F]X:6UA=&EO;BP@=&AE<F4@:7,@;F\@
M97AA8W0@9F]R;75L82P@=&AI<PT*("`@("H@;VYE(&AE<F4@:7,@8V%L;&5D
M($UA9VYU<RU&;W)M=6QA#0H@("`@*@T*("`@("H@5&5M<&5R871U<F4@86YD
M(&1E=W!O:6YT(&AA=F4@=&\@8F4@96YT97)E9"!I;B!D96<@0R$-"B`@("`J
M#0H@("`@*B!`<&%R86T@("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@
M("1T96UP97)A='5R90T*("`@("H@0'!A<F%M("`@(&9L;V%T("`@("`@("`@
M("`@("`@("`@("`@("`D9&5W4&]I;G0-"B`@("`J($!R971U<FX@("!F;&]A
M=`T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0&QI;FL@("`@(&AT
M='`Z+R]W=W<N9F%Q<RYO<F<O9F%Q<R]M971E;W)O;&]G>2]T96UP+61E=W!O
M:6YT+PT*("`@("HO#0H@("`@9G5N8W1I;VX@8V%L8W5L871E2'5M:61I='DH
M)'1E;7!E<F%T=7)E+"`D9&5W4&]I;G0I#0H@("`@>R`@(`T*("`@("`@("`O
M+R!&:7)S="!C86QC=6QA=&4@<V%T=7)A=&EO;B!S=&5A;2!P<F5S<W5R92!F
M;W(@8F]T:"!T96UP97)A='5R97,-"B`@("`@("`@:68@*"1T96UP97)A='5R
M92`^/2`P*2![#0H@("`@("`@("`@("`D82`](#<N-3L-"B`@("`@("`@("`@
M("1B(#T@,C,W+C,[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M82`](#<N-CL-"B`@("`@("`@("`@("1B(#T@,C0P+C<[#0H@("`@("`@('T-
M"B`@("`@("`@)'1E;7!34U`@/2`V+C$P-S@@*B!P;W<H,3`L("@D82`J("1T
M96UP97)A='5R92D@+R`H)&(@*R`D=&5M<&5R871U<F4I*3L-"@T*("`@("`@
M("!I9B`H)&1E=U!O:6YT(#X](#`I('L-"B`@("`@("`@("`@("1A(#T@-RXU
M.PT*("`@("`@("`@("`@)&(@/2`R,S<N,SL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1A(#T@-RXV.PT*("`@("`@("`@("`@)&(@/2`R-#`N
M-SL-"B`@("`@("`@?0T*("`@("`@("`D9&5W4U-0("`](#8N,3`W."`J('!O
M=R@Q,"P@*"1A("H@)&1E=U!O:6YT*2`O("@D8B`K("1D97=0;VEN="DI.PT*
M("`@("`@("`-"B`@("`@("`@<F5T=7)N(')O=6YD*#$P,"`J("1D97=34U`@
M+R`D=&5M<%-34"P@,2D[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(&-A;&-U;&%T941E=U!O:6YT*"D-"B`@("`O*BH-"B`@("`J($-A;&-U
M;&%T92!D97=P;VEN="!F<F]M('1E;7!E<F%T=7)E(&%N9"!H=6UI9&ET>0T*
M("`@("H@5&AI<R!I<R!O;FQY(&%N(&%P<')O>&EM871I;VXL('1H97)E(&ES
M(&YO(&5X86-T(&9O<FUU;&$L('1H:7,-"B`@("`J(&]N92!H97)E(&ES(&-A
M;&QE9"!-86=N=7,M1F]R;75L80T*("`@("H-"B`@("`J(%1E;7!E<F%T=7)E
M(&AA<R!T;R!B92!E;G1E<F5D(&EN(&1E9R!#(0T*("`@("H-"B`@("`J($!P
M87)A;2`@("!F;&]A="`@("`@("`@("`@("`@("`@("`@("`@)'1E;7!E<F%T
M=7)E#0H@("`@*B!`<&%R86T@("`@9FQO870@("`@("`@("`@("`@("`@("`@
M("`@("1H=6UI9&ET>0T*("`@("H@0')E='5R;B`@(&9L;V%T#0H@("`@*B!`
M86-C97-S("`@<'5B;&EC#0H@("`@*B!`;&EN:R`@("`@:'1T<#HO+W=W=RYF
M87%S+F]R9R]F87%S+VUE=&5O<F]L;V=Y+W1E;7`M9&5W<&]I;G0O#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!C86QC=6QA=&5$97=0;VEN="@D=&5M<&5R871U
M<F4L("1H=6UI9&ET>2D-"B`@("![("`@#0H@("`@("`@(&EF("@D=&5M<&5R
M871U<F4@/CT@,"D@>PT*("`@("`@("`@("`@)&$@/2`W+C4[#0H@("`@("`@
M("`@("`D8B`](#(S-RXS.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)&$@/2`W+C8[#0H@("`@("`@("`@("`D8B`](#(T,"XW.PT*("`@("`@
M("!]#0H-"B`@("`@("`@+R\@1FER<W0@8V%L8W5L871E('-A='5R871I;VX@
M<W1E86T@<')E<W-U<F4@9F]R('1E;7!E<F%T=7)E#0H@("`@("`@("134U`@
M/2`V+C$P-S@@*B!P;W<H,3`L("@D82`J("1T96UP97)A='5R92D@+R`H)&(@
M*R`D=&5M<&5R871U<F4I*3L-"@T*("`@("`@("`O+R!3=&5A;2!P<F5S<W5R
M90T*("`@("`@("`D4U`@(#T@)&AU;6ED:71Y("\@,3`P("H@)%-34#L-"@T*
M("`@("`@("`D=B`@(#T@;&]G*"134"`O(#8N,3`W."P@,3`I.PT*#0H@("`@
M("`@(')E='5R;B!R;W5N9"@D8B`J("1V("\@*"1A("T@)'8I+"`Q*3L-"B`@
M("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@<&]L87(R8V%R=&5S:6%N
M*"D-"B`@("`O*BH-"B`@("`J($-O;G9E<G0@<&]L87(@8V]O<F1I;F%T97,@
M=&\@8V%R=&5S:6%N(&-O;W)D:6YA=&5S#0H@("`@*@T*("`@("H@0'!A<F%M
M("`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D;&%T:71U9&4-"B`@
M("`J($!P87)A;2`@("!F;&]A="`@("`@("`@("`@("`@("`@("`@("`@)&QO
M;F=I='5D90T*("`@("H@0')E='5R;B`@(&%R<F%Y#0H@("`@*B!`86-C97-S
M("`@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!P;VQA<C)C87)T97-I
M86XH)&QA=&ET=61E+"`D;&]N9VET=61E*0T*("`@('L-"B`@("`@("`@)'1H
M971A(#T@9&5G,G)A9"@D;&%T:71U9&4I.PT*("`@("`@("`D<&AI("`@/2!D
M96<R<F%D*"1L;VYG:71U9&4I.PT*#0H@("`@("`@("1X(#T@4T525DE#15-?
M5T5!5$A%4E]2041)55-?14%25$@@*B!C;W,H)'!H:2D@*B!C;W,H)'1H971A
M*3L-"B`@("`@("`@)'D@/2!315)624-%4U]714%42$527U)!1$E54U]%05)4
M2"`J('-I;B@D<&AI*2`J(&-O<R@D=&AE=&$I.PT*("`@("`@("`D>B`](%-%
M4E9)0T537U=%051(15)?4D%$25537T5!4E1(("`@("`@("`@("`@("H@<VEN
M*"1T:&5T82D[#0H-"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1X+"`D>2P@)'HI
M.PT*("`@('T-"B`@("`O+R!]?7T-"GT-"B\O('U]?0T*/SX-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U-E<G9I8V5S+U=E871H97(N<&AP````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(P-S`V`#$P-#$W,S8S,#`U`#`R,3(S-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO#0HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0('9E<G-I
M;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O
M=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O
M('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L-"B\O('P@075T:&]R<SH@06QE>&%N9&5R(%=I<G1Z(#QA;&5X
M0'!C-'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!796%T
M:&5R+G!H<"QV(#$N,C(@,C`P-"\P,2\P-B`Q.3HS-CHR."!E<G4@17AP("0-
M"@T*+R\@>WM[(&-O;G-T86YT<PT*+R\@>WM[(&-A8VAE('1I;65S#0ID969I
M;F4H(E-%4E9)0T537U=%051(15)?15A025)%4U]53DE44R(L("`@("`@.3`P
M*3L-"F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537TQ/0T%424].
M(BP@("`Y,#`I.PT*9&5F:6YE*")315)624-%4U]714%42$527T584$E215-?
M5T5!5$A%4B(L("`@,3@P,"D[#0ID969I;F4H(E-%4E9)0T537U=%051(15)?
M15A025)%4U]&3U)%0T%35"(L("`W,C`P*3L-"F1E9FEN92@B4T525DE#15-?
M5T5!5$A%4E]%6%!)4D537TQ)3DM3(BP@("`@-#,R,#`I.PT*+R\@?7U]#0H-
M"B\O('M[>R!E<G)O<B!C;V1E<PT*9&5F:6YE*")315)624-%4U]714%42$52
M7T524D]27U-%4E9)0T5?3D]47T9/54Y$(BP@("`Q,"D[#0ID969I;F4H(E-%
M4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3B(L("`@(#$Q
M*3L-"F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)6
M15)?1$%402(L("`@,3(I.PT*9&5F:6YE*")315)624-%4U]714%42$527T52
M4D]27T-!0TA%7TE.251?1D%)3$5$(BP@("`Q,RD[#0ID969I;F4H(E-%4E9)
M0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1"(L("`@(#$T*3L-
M"B\O('U]?0T*#0HO+R![>WL@97)R;W(@8V]D97,@9&5F:6YE9"!B>2!W96%T
M:&5R+F-O;0T*9&5F:6YE*")315)624-%4U]714%42$527T524D]27U5.2TY/
M5TY?15)23U(B+"`@("`@("`@("`@(#`I.PT*9&5F:6YE*")315)624-%4U]7
M14%42$527T524D]27TY/7TQ/0T%424].(BP@("`@("`@("`@("`@(#$I.PT*
M9&5F:6YE*")315)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)
M3TXB+"`@("`@("`@(#(I.PT*9&5F:6YE*")315)624-%4U]714%42$527T52
M4D]27TE.5D%,241?4$%25$Y%4E])1"(L("`@("`Q,#`I.PT*9&5F:6YE*")3
M15)624-%4U]714%42$527T524D]27TE.5D%,241?4%)/1%5#5%]#3T1%(BP@
M("`Q,#$I.PT*9&5F:6YE*")315)624-%4U]714%42$527T524D]27TE.5D%,
M241?3$E#14Y315]+15DB+"`@("`Q,#(I.PT*+R\@?7U]#0HO+R!]?7T-"@T*
M+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97(-"B\J*@T**B!014%2.CI3
M97)V:6-E<U]796%T:&5R#0HJ#0HJ(%1H:7,@8VQA<W,@86-T<R!A<R!A;B!I
M;G1E<F9A8V4@=&\@=F%R:6]U<R!O;FQI;F4@=V5A=&AE<BUS97)V:6-E<RX-
M"BH-"BH@4V5R=FEC97-?5V5A=&AE<B!S96%R8VAE<R!F;W(@9VEV96X@;&]C
M871I;VYS(&%N9"!R971R:65V97,@8W5R<F5N="!W96%T:&5R(&1A=&$-"BH@
M86YD+"!D97!E;F1A;G0@;VX@=&AE('5S960@<V5R=FEC92P@86QS;R!F;W)E
M8V%S=',N(%5P('1O(&YO=RP@4T]!4"!S97)V:6-E<R!F<F]M#0HJ($-A<&53
M8VEE;F-E(&%N9"!%2E-%+"!834P@9G)O;2!W96%T:&5R+F-O;2!A;F0@3454
M05(@9G)O;2!N;V%A+F=O=B!A<F4@<W5P<&]R=&5D+`T**B!F=7)T:&5R('-E
M<G9I8V5S('=I;&P@9V5T(&EN8VQU9&5D+"!I9B!T:&5Y(&)E8V]M92!A=F%I
M;&%B;&4@86YD(&%R90T**B!P<F]P97)L>2!D;V-U;65N=&5D+@T**@T**B!`
M875T:&]R("`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X-
M"BH@0'!A8VMA9V4@("`@("!397)V:6-E<U]796%T:&5R#0HJ($!L:6-E;G-E
M("`@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0-"BH@
M0'9E<G-I;VX@("`@("`Q+C(-"BHO#0IC;&%S<R!397)V:6-E<U]796%T:&5R
M('L-"@T*("`@("\O('M[>R`F<V5R=FEC92@I#0H@("`@+RHJ#0H@("`@*B!&
M86-T;W)Y(&9O<B!C<F5A=&EN9R!T:&4@<V5R=FEC97,M;V)J96-T<PT*("`@
M("H-"B`@("`J(%5S86)L92!K97ES(&9O<B!T:&4@;W!T:6]N<R!A<G)A>2!A
M<F4Z#0H@("`@*B!O(&1E8G5G("`@("`@("`@("`@("`@96YA8FQE<R!D96)U
M9V=I;F<@;W5T<'5T#0H@("`@*B`M+2T@0V]M;6]N($]P=&EO;G,-"B`@("`J
M(&\@8V%C:&54>7!E("`@("`@("`@("!D969I;F5S('=H870@='EP92!O9B!C
M86-H92!T;R!U<V4-"B`@("`J(&\@8V%C:&5/<'1I;VYS("`@("`@("!P87-S
M97,@8V%C:&4@;W!T:6]N<PT*("`@("H@;R!U;FET<T9O<FUA="`@("`@("`@
M('5S92`H55,I+7-T86YD87)D+"!M971R:6,@;W(@8W5S=&]M('5N:71S#0H@
M("`@*B!O(&-U<W1O;55N:71S1F]R;6%T("`@9&5F:6YE<R!T:&4@8W5S=&]M
M:7IE9"!U;FET<R!F;W)M870-"B`@("`J(&\@9&%T949O<FUA="`@("`@("`@
M("!S=')I;F<@=&\@=7-E(&9O<B!D871E(&]U='!U=`T*("`@("H@;R!T:6UE
M1F]R;6%T("`@("`@("`@('-T<FEN9R!T;R!U<V4@9F]R('1I;64@;W5T<'5T
M#0H@("`@*B`M+2T@14I312!/<'1I;VYS#0H@("`@*B!N;VYE#0H@("`@*B`M
M+2T@1VQO8F%L5V5A=&AE<B!/<'1I;VYS#0H@("`@*B!N;VYE#0H@("`@*B`M
M+2T@345405(@3W!T:6]N<PT*("`@("H@;R!D<VX@("`@("`@("`@("`@("`@
M(%-T<FEN9R!F;W(@9&5F:6YI;F<@=&AE($1"(&-O;FYE8W1I;VX-"B`@("`J
M(&\@9&)/<'1I;VYS("`@("`@("`@("!P87-S97,@1$(@;W!T:6]N<PT*("`@
M("H@;R!S;W5R8V4@("`@("`@("`@("`@(&AT='`L(&9T<"!O<B!F:6QE("T@
M='EP92!O9B!D871A+7-O=7)C90T*("`@("H@;R!S;W5R8V50871H("`@("`@
M("`@('=H97)E('1O(&QO;VL@9F]R('1H92!S;W5R8V4L(%5222!O<B!F:6QE
M<&%T:`T*("`@("H@+2TM('=E871H97(N8V]M($]P=&EO;G,-"B`@("`J(&\@
M<&%R=&YE<DE$("`@("`@("`@("!9;W4G;&P@<F5C96EV92!T:&5S92!K97ES
M(&%F=&5R(')E9VES=&5R:6YG#0H@("`@*B!O(&QI8V5N<V5+97D@("`@("`@
M("`@=VET:"!T:&4@=V5A=&AE<BYC;VT@6$U,+7-E<G9I8V4-"B`@("`J#0H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1S
M97)V:6-E#0H@("`@*B!`<&%R86T@("`@87)R87D@("`@("`@("`@("`@("`@
M("`@("`@("1O<'1I;VYS#0H@("`@*B!`<F5T=7)N("`@4$5!4E]%<G)O<GQO
M8FIE8W0-"B`@("`J($!T:')O=W,@("!014%27T5R<F]R#0H@("`@*B!`=&AR
M;W=S("`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]315)6
M24-%7TY/5%]&3U5.1`T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("HO
M#0H@("`@9G5N8W1I;VX@)G-E<G9I8V4H)'-E<G9I8V4L("1O<'1I;VYS(#T@
M;G5L;"D-"B`@("![#0H@("`@("`@("1S97)V:6-E(#T@=6-F:7)S="AS=')T
M;VQO=V5R*"1S97)V:6-E*2D[#0H@("`@("`@("1C;&%S<VYA;64@/2`B4V5R
M=FEC97-?5V5A=&AE<E\B+B1S97)V:6-E.PT*#0H@("`@("`@("\O($-H96-K
M(&9O<B!D96)U9V=I;F<M;6]D92!A;F0@<V5T('-T=69F(&%C8V]R9&EN9VQY
M#0H@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RD@)B8@:7-S970H)&]P
M=&EO;G-;(F1E8G5G(ETI("8F("1O<'1I;VYS6R)D96)U9R)=(#X](#(I('L-
M"B`@("`@("`@("`@(&EF("@A9&5F:6YE9"@B4T525DE#15-?5T5!5$A%4E]$
M14)51R(I*2![#0H@("`@("`@("`@("`@("`@9&5F:6YE*")315)624-%4U]7
M14%42$527T1%0E5'(BP@=')U92D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I;F-L=61E7V]N8V4H(E-E<G9I8V5S+U=E871H97(O(BXD<V5R=FEC
M92XB+G!H<"(I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@
M*"%D969I;F5D*")315)624-%4U]714%42$527T1%0E5'(BDI('L-"B`@("`@
M("`@("`@("`@("!D969I;F4H(E-%4E9)0T537U=%051(15)?1$5"54<B+"!F
M86QS92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!`:6YC;'5D95]O
M;F-E*")397)V:6-E<R]796%T:&5R+R(N)'-E<G9I8V4N(BYP:'`B*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@("\O($YO('-U8V@@<V5R=FEC92XN+B!B86EL
M(&]U=`T*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W-N86UE*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E
M17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]315)624-%7TY/5%]&3U5.
M1"D[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!#<F5A=&4@<V5R=FEC92!A
M;F0@<F5T=7)N#0H@("`@("`@("1E<G)O<B`](&YU;&P[#0H@("`@("`@($`D
M;V)J(#T@)FYE=R`D8VQA<W-N86UE*"1O<'1I;VYS+"`D97)R;W(I.PT*#0H@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1E<G)O<BDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D97)R;W([#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!R971U<FX@)&]B:CL-"B`@("`@("`@?0T*("`@
M('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!A<&E697)S:6]N*"D-"B`@
M("`O*BH-"B`@("`J($9O<B!Y;W5R(&-O;G9E;FEE;F-E+"!W:&5N($D@8V]M
M92!U<"!W:71H(&-H86YG97,@:6X@=&AE($%022XN+@T*("`@("H-"B`@("`J
M($!R971U<FX@("!S=')I;F<-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J+PT*("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@(C$N,B([#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(%]E<G)O<DUE<W-A9V4H*0T*("`@("\J*@T*("`@("H@4F5T=7)N<R!T
M:&4@;65S<V%G92!F;W(@82!C97)T86EN(&5R<F]R(&-O9&4-"B`@("`J#0H@
M("`@*B!`<&%R86T@("`@4$5!4E]%<G)O<GQI;G0@("`@("`@("`@("`@("1V
M86QU90T*("`@("H@0')E='5R;B`@('-T<FEN9PT*("`@("H@0&%C8V5S<R`@
M('!R:79A=&4-"B`@("`J+PT*("`@(&9U;F-T:6]N(%]E<G)O<DUE<W-A9V4H
M)'9A;'5E*0T*("`@('L-"B`@("`@("`@<W1A=&EC("1E<G)O<DUE<W-A9V5S
M.PT*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<DUE<W-A9V5S*2D@>PT*("`@
M("`@("`@("`@)&5R<F]R365S<V%G97,@/2!A<G)A>2@-"B`@("`@("`@("`@
M("`@("!315)624-%4U]714%42$527T524D]27U-%4E9)0T5?3D]47T9/54Y$
M("`@("`@("`@/3X@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F
M;W5N9"XB+`T*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)2
M3U)?54Y+3D]73E],3T-!5$E/3B`@("`@("`@("`]/B`B56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"XB+`T*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%
M051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$@("`@("`@("`]/B`B4V5R
M=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB+`T*("`@("`@("`@
M("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?0T%#2$5?24Y)5%]&04E,
M140@("`@("`@("`]/B`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB
M+`T*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?1$)?
M3D]47T-/3DY%0U1%1"`@("`@("`@("`]/B`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(L#0H@("`@("`@("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]53DM.3U=.7T524D]2("`@("`@("`@("`@(#T^(")!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+B(L#0H@("`@("`@("`@("`@("`@4T525DE#
M15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3B`@("`@("`@("`@("`@(#T^
M(").;R!L;V-A=&EO;B!P<F]V:61E9"XB+`T*("`@("`@("`@("`@("`@(%-%
M4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3B`@("`@("`@
M("`]/B`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB+`T*("`@("`@("`@
M("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%]005)43D52
M7TE$("`@("`@("`]/B`B26YV86QI9"!P87)T;F5R(&ED+B(L#0H@("`@("`@
M("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7U!23T15
M0U1?0T]$12`@("`@(#T^("));G9A;&ED('!R;V1U8W0@8V]D92XB+`T*("`@
M("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],
M24-%3E-%7TM%62`@("`@("`]/B`B26YV86QI9"!L:6-E;G-E(&ME>2XB#0H@
M("`@("`@("`@("`I.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*%-E<G9I
M8V5S7U=E871H97(Z.FES17)R;W(H)'9A;'5E*2D@>PT*("`@("`@("`@("`@
M)'9A;'5E(#T@)'9A;'5E+3YG971#;V1E*"D[#0H@("`@("`@('T-"@T*("`@
M("`@("!R971U<FX@:7-S970H)&5R<F]R365S<V%G97-;)'9A;'5E72D@/R`D
M97)R;W)-97-S86=E<ULD=F%L=65=(#H@)&5R<F]R365S<V%G97-;4T525DE#
M15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7T524D]273L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@:7-%<G)O<B@I#0H@("`@+RHJ#0H@("`@
M*B!#:&5C:W,@9F]R(&%N(&5R<F]R(&]B:F5C="P@<V%M92!A<R!I;B!014%2
M#0H@("`@*@T*("`@("H@0'!A<F%M("`@(%!%05)?17)R;W)\;6EX960@("`@
M("`@("`@("`D=F%L=64-"B`@("`J($!R971U<FX@("!B;V]L#0H@("`@*B!`
M86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!I<T5R<F]R
M*"1V86QU92D-"B`@("![#0H@("`@("`@(')E='5R;B`H:7-?;V)J96-T*"1V
M86QU92D@)B8@*&=E=%]C;&%S<R@D=F%L=64I(#T](")P96%R7V5R<F]R(B!\
M?"!I<U]S=6)C;&%S<U]O9B@D=F%L=64L(")P96%R7V5R<F]R(BDI*3L-"B`@
M("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@)G)A:7-E17)R;W(H*0T*
M("`@("\J*@T*("`@("H@0W)E871E<R!E<G)O<BP@<V%M92!A<R!I;B!014%2
M('=I=&@@82!C=7-T;VUI>F5D(&9L879O<@T*("`@("H-"B`@("`J($!P87)A
M;2`@("!I;G0@("`@("`@("`@("`@("`@("`@("`@("`@)&-O9&4-"B`@("`J
M($!R971U<FX@("!014%27T5R<F]R#0H@("`@*B!`86-C97-S("`@<')I=F%T
M90T*("`@("HO#0H@("`@9G5N8W1I;VX@)G)A:7-E17)R;W(H)&-O9&4@/2!3
M15)624-%4U]714%42$527T524D]27U5.2TY/5TY?15)23U(I#0H@("`@>PT*
M("`@("`@("`O+R!4:&ES('-H;W5L9"!I;7!R;W9E('1H92!P97)F;W)M86YC
M92!O9B!T:&4@<V-R:7!T+"!A<R!014%2(&ES(&]N;'D@:6YC;'5D960L('=H
M96X-"B`@("`@("`@+R\@<F5A;&QY(&YE961E9"X-"B`@("`@("`@:6YC;'5D
M95]O;F-E(")014%2+G!H<"([#0H-"B`@("`@("`@)&UE<W-A9V4@/2`B4V5R
M=FEC97-?5V5A=&AE<CH@(BY397)V:6-E<U]796%T:&5R.CI?97)R;W)-97-S
M86=E*"1C;V1E*3L-"@T*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@D;65S<V%G92P@)&-O9&4L(%!%05)?15)23U)?4D5455).+"!%7U5315)?
M3D]424-%+"`B4V5R=FEC97-?5V5A=&AE<E]%<G)O<B(L(&YU;&PL(&9A;'-E
M*3L-"B`@("!]#0H@("`@+R\@?7U]#0I]#0HO+R!]?7T-"C\^#0H`````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O````
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#`V`#`Q-C$P-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4T]!4"]4<F%N<W!O<G0O````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#4`,#(P,3`P`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U1R86YS<&]R="]40U`N
M<&AP````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,34R-0`Q,#0Q
M-S,V,S`P-0`P,C$R-#``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y
M.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@
M;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L
M960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD
M(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@
M?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@2&%N;F$@
M/&EO<F1Y7V%T7VEO<F1Y7V1O=%]C;VT^("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED
M.B!40U`N<&AP+'8@,2XS(#(P,#,O,#0O,3,@,C$Z,S@Z-3@@<VAA;F4@17AP
M("0*+R\*"G)E<75I<F5?;VYC92`G4T]!4"]"87-E+G!H<"<["@HO*BH**B`@
M5$-0(%1R86YS<&]R="!F;W(@4T]!4`HJ"BH@5$]$3SH**B`@('5S92!.971?
M4V]C:V5T"BH@("!I;7!L96UE;G0@<V]M92!S96-U<FET>2!S8VAE;64**B`@
M(&EM<&QE;65N="!S=7!P;W)T(&9O<B!A='1A8VAM96YT<PHJ"BH**B!`86-C
M97-S('!U8FQI8PHJ($!P86-K86=E(%-/05`Z.E1R86YS<&]R=#HZ5$-0"BH@
M0&%U=&AO<B!3:&%N92!(86YN82`\:6]R9'E?871?:6]R9'E?9&]T7V-O;3X*
M*B\*8VQA<W,@4T]!4%]4<F%N<W!O<G1?5$-0(&5X=&5N9',@4T]!4%]"87-E
M7T]B:F5C=`I["@H@("`@=F%R("1H96%D97)S(#T@87)R87DH*3L*("`@('9A
M<B`D=7)L<&%R=',@/2!.54Q,.PH@("`@=F%R("1U<FP@/2`G)SL*("`@('9A
M<B`D:6YC;VUI;F=?<&%Y;&]A9"`]("<G.PH@("`@=F%R("1?=7-E<D%G96YT
M(#T@4T]!4%],24)205)97TY!344["B`@("!V87(@)&5N8V]D:6YG(#T@4T]!
M4%]$149!54Q47T5.0T]$24Y'.PH@("`@=F%R("1R97-U;'1?96YC;V1I;F<@
M/2`G551&+3@G.PH@("`@=F%R("1R97-U;'1?8V]N=&5N=%]T>7!E.PH*("`@
M(",@<V]C:V5T"B`@("!V87(@)'-O8VME="`]("<G.PH*("`@("\J*@H@("`@
M*B!33T%07U1R86YS<&]R=%]40U`@0V]N<W1R=6-T;W(*("`@("H*("`@("H@
M0'!A<F%M('-T<FEN9R`D55),("`@(&AT='`@=7)L('1O('-O87`@96YD<&]I
M;G0*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC
M=&EO;B!33T%07U1R86YS<&]R=%]40U`H)%523"P@)&5N8V]D:6YG(#T@4T]!
M4%]$149!54Q47T5.0T]$24Y'*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4T]!
M4%]"87-E7T]B:F5C="@G5$-0)RD["B`@("`@("`@)'1H:7,M/G5R;'!A<G1S
M(#T@0'!A<G-E7W5R;"@D55),*3L*("`@("`@("`D=&AI<RT^=7)L(#T@)%52
M3#L*("`@("`@("`D=&AI<RT^96YC;V1I;F<@/2`D96YC;V1I;F<["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W-O8VME=%]P:6YG("@I('L*("`@("`@("`O+R!8
M6%@@:&]W(&1O('=E(')E<W1A<G0@869T97(@<V]C:V5T7W-H=71D;W=N/PH@
M("`@("`@("\O:68@*"$D=&AI<RT^<V]C:V5T*2!["B`@("`@("`@("`@(",@
M8W)E871E('-O8VME="!R97-O=7)C90H@("`@("`@("`@("`D=&AI<RT^<V]C
M:V5T(#T@0'-O8VME=%]C<F5A=&4H049?24Y%5"P@4T]#2U]35%)%04TL(%-/
M3%]40U`I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/G-O8VME="`\(#`I(')E
M='5R;B`P.PH*("`@("`@("`@("`@(R!C;VYN96-T"B`@("`@("`@("`@("1R
M97-U;'0@/2!S;V-K971?8V]N;F5C="@D=&AI<RT^<V]C:V5T+"`D=&AI<RT^
M=7)L<&%R='-;)VAO<W0G72P@)'1H:7,M/G5R;'!A<G1S6R=P;W)T)UTI.PH@
M("`@("`@("`@("!I9B`H)')E<W5L="`\(#`I(')E='5R;B`P.PH@("`@("`@
M("\O?0H@("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@("\J*@H@("`@*B!S
M96YD(&%N9"!R96-E:79E('-O87`@9&%T80H@("`@*@H@("`@*B!`<&%R86T@
M<W1R:6YG("8D;7-G("`@("`@(&]U=&=O:6YG('!O<W0@9&%T80H@("`@*B!`
M<&%R86T@<W1R:6YG("1A8W1I;VX@("`@("!33T%0($%C=&EO;B!H96%D97(@
M9&%T80H@("`@*@H@("`@*B!`<F5T=7)N('-T<FEN9WQF875L="!R97-P;VYS
M90H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N("9S
M96YD*"8D;7-G+"`D;W!T:6]N<R`]($Y53$PI"B`@("!["B`@("`@("`@)'1H
M:7,M/FEN8V]M:6YG7W!A>6QO860@/2`G)SL*("`@("`@("`D=&AI<RT^;W5T
M9V]I;F=?<&%Y;&]A9"`]("8D;7-G.PH@("`@("`@(&EF("@A)'1H:7,M/E]V
M86QI9&%T955R;"@I*2!R971U<FX@)'1H:7,M/F9A=6QT.PH*("`@("`@("`C
M(&-H96-K(&9O<B!40U`@<V-H96UE"B`@("`@("`@:68@*'-T<F-A<V5C;7`H
M)'1H:7,M/G5R;'!A<G1S6R=S8VAE;64G72P@)U1#4"<I(#T](#`I('L*("`@
M("`@("`@("`@(R!C:&5C:R!C;VYN96-T:6]N"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]S;V-K971?<&EN9R@I*0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)V5R<F]R(&]N("<N)'1H:7,M/G5R
M;"XG(')E87-O;B`G+G-O8VME=%]S=')E<G)O<BAS;V-K971?;&%S=%]E<G)O
M<B@D=&AI<RT^<V]C:V5T*2DI.PH*("`@("`@("`@("`@(R!W<FET92!T;R!T
M:&4@<V]C:V5T"B`@("`@("`@("`@(&EF("@A0'-O8VME=%]W<FET92@D=&AI
M<RT^<V]C:V5T+"`D=&AI<RT^;W5T9V]I;F=?<&%Y;&]A9"P@<W1R;&5N*"1T
M:&ES+3YO=71G;VEN9U]P87EL;V%D*2DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=%<G)O<B!S96YD:6YG(&1A
M=&$@=&\@)RXD=&AI<RT^=7)L+B<@<F5A<V]N("<N<V]C:V5T7W-T<F5R<F]R
M*'-O8VME=%]L87-T7V5R<F]R*"1T:&ES+3YS;V-K970I*2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(",@<VAU=&1O=VX@=W)I=&EN9PH@("`@("`@
M("`@("!I9B@A<V]C:V5T7W-H=71D;W=N*"1T:&ES+3YS;V-K970L(#$I*0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(F-A;B=T(&-H86YG92!S;V-K970@;6]D92!T;R!R96%D+B(I.PH*("`@("`@
M("`@("`@(R!R96%D(&5V97)Y=&AI;F<@=V4@8V%N+@H@("`@("`@("`@("!W
M:&EL92@D8G5F(#T@0'-O8VME=%]R96%D*"1T:&ES+3YS;V-K970L(#$P,C0L
M(%!(4%]"24Y!4EE?4D5!1"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YI
M;F-O;6EN9U]P87EL;V%D("X]("1B=68["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(",@<F5T=7)N('!A>6QO860@;W(@9&EE"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"D*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9#L*("`@("`@("`@("`@"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")%<G)O
M<B!R979E:79I;F<@9&%T82!F<F]M("(N)'1H:7,M/G5R;"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=);G9A
M;&ED('5R;"!S8VAE;64@)RXD=&AI<RT^=7)L*3L*("`@('T*"B`@("`O+R!P
M<FEV871E(&UE;6)E<G,*"B`@("`O*BH*("`@("H@=F%L:61A=&4@=7)L(&1A
M=&$@<&%S<V5D('1O(&-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!R971U<FX@
M8F]O;&5A;@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO"B`@("!F=6YC
M=&EO;B!?=F%L:61A=&55<FPH*0H@("`@>PH@("`@("`@(&EF("@@(2!I<U]A
M<G)A>2@D=&AI<RT^=7)L<&%R=',I("D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@<&%R<V4@55),("1U<FPB*3L*
M("`@("`@("`@("`@<F5T=7)N($9!3%-%.PH@("`@("`@('T*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3YU<FQP87)T<ULG:&]S="==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*").;R!H;W-T(&EN(%523"`D
M=7)L(BD["B`@("`@("`@("`@(')E='5R;B!&04Q313L*("`@("`@("!]"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;)W!A=&@G72D@?'P@
M(21T:&ES+3YU<FQP87)T<ULG<&%T:"==*0H@("`@("`@("`@("`D=&AI<RT^
M=7)L<&%R='-;)W!A=&@G72`]("<O)SL*("`@("`@("!R971U<FX@5%)513L*
M("`@('T*"GT*/SX`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4<F%N<W!O
M<G0O4TU44"YP:'``````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<T
M-#,`,3`T,3<S-C,P,#4`,#(Q-#`R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE
M($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M"B\O("1)9#H@4TU44"YP:'`L=B`Q+C$W(#(P,#,O,#0O,3,@,C$Z,S@Z-3@@
M<VAA;F4@17AP("0*+R\*+R\@4W1A='5S.B!R;W5G:"!D<F%F="P@=6YT97-T
M960*+R\*+R\@5$]$3SH*+R\@('-W:71C:"!T;R!P96%R(&UA:6P@<W1U9F8*
M+R\@('-M='`@875T:&5N=&EC871I;VX*+R\@('-M='`@<W-L('-U<'!O<G0*
M+R\@(&%B:6QI='D@=&\@9&5F:6YE('-M='`@;W!T:6]N<R`H96YC;V1I;F<L
M(&9R;VTL(&5T8RXI"B\O"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G
M.PIR97%U:7)E7V]N8V4@)TUA:6PO<VUT<"YP:'`G.PH*+RHJ"BH@(%--5%`@
M5')A;G-P;W)T(&9O<B!33T%0"BH**B!I;7!L96UE;G1S(%-/05`M4TU44"!A
M<R!D969I;F5D(&%T"BH@:'1T<#HO+W=W=RYP;V-K971S;V%P+F-O;2]S<&5C
M<R]S;71P8FEN9&EN9R\**@HJ(%1/1$\Z('5S92!014%2('-M='`@86YD($UI
M;64@8VQA<W-E<PHJ"BH@0&%C8V5S<R!P=6)L:6,**B!`=F5R<VEO;B`D260Z
M(%--5%`N<&AP+'8@,2XQ-R`R,#`S+S`T+S$S(#(Q.C,X.C4X('-H86YE($5X
M<"`D"BH@0'!A8VMA9V4@4T]!4#HZ5')A;G-P;W)T.CI33510"BH@0&%U=&AO
M<B!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/@HJ+PIC;&%S<R!33T%0
M7U1R86YS<&]R=%]33510(&5X=&5N9',@4T]!4%]"87-E"GL*("`@('9A<B`D
M8W)E9&5N=&EA;',@/2`G)SL*("`@('9A<B`D=&EM96]U="`](#0[("\O(&-O
M;FYE8W0@=&EM96]U=`H@("`@=F%R("1U<FQP87)T<R`]($Y53$P["B`@("!V
M87(@)'5R;"`]("<G.PH@("`@=F%R("1I;F-O;6EN9U]P87EL;V%D(#T@)R<[
M"B`@("!V87(@)%]U<V5R06=E;G0@/2!33T%07TQ)0E)!4EE?3D%-13L*("`@
M('9A<B`D96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<["B`@("!V
M87(@)&AO<W0@/2`G,3(W+C`N,"XQ)SL*("`@('9A<B`D<&]R="`](#(U.PH@
M("`@=F%R("1A=71H(#T@3E5,3#L*("`@("\J*@H@("`@*B!33T%07U1R86YS
M<&]R=%]33510($-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A;2!S=')I
M;F<@)%523"`@("!M86EL=&\Z861D<F5S<PH@("`@*@H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?5')A;G-P;W)T7U--
M5%`H)%523"P@)&5N8V]D:6YG/2=54RU!4T-)22<I"B`@("!["B`@("`@("`@
M<&%R96YT.CI33T%07T)A<V4H)U--5%`G*3L*("`@("`@("`D=&AI<RT^96YC
M;V1I;F<@/2`D96YC;V1I;F<["B`@("`@("`@)'1H:7,M/G5R;'!A<G1S(#T@
M0'!A<G-E7W5R;"@D55),*3L*("`@("`@("`D=&AI<RT^=7)L(#T@)%523#L*
M("`@('T*("`@(`H@("`@+RHJ"B`@("`J('-E;F0@86YD(')E8V5I=F4@<V]A
M<"!D871A"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@)B1M<V<@("`@("`@
M;W5T9V]I;F<@<&]S="!D871A"B`@("`J($!P87)A;2!S=')I;F<@)&%C=&EO
M;B`@("`@(%-/05`@06-T:6]N(&AE861E<B!D871A"B`@("`J($!P87)A;2!I
M;G0@)'1I;65O=70@('-O8VME="!T:6UE;W5T+"!D969A=6QT(#`@;W(@;V9F
M"B`@("`J"B`@("`J($!R971U<FX@<W1R:6YG("8D<F5S<&]N<V4@("!R97-P
M;VYS92!D871A+"!M:6YU<R!H='1P(&AE861E<G,*("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S96YD*"8D;7-G+"`@+RIA<G)A
M>2HO("1O<'1I;VYS(#T@3E5,3"D*("`@('L*("`@("`@("`D=&AI<RT^:6YC
M;VUI;F=?<&%Y;&]A9"`]("<G.PH@("`@("`@("1T:&ES+3YO=71G;VEN9U]P
M87EL;V%D(#T@)B1M<V<["B`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E
M57)L*"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF875L=#L*("`@
M("`@("!]"B`@("`@("`@:68@*"$D;W!T:6]N<R!\?"`A87)R87E?:V5Y7V5X
M:7-T<R@G9G)O;2<L)&]P=&EO;G,I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*").;R!&4D]-(&%D9')E<W,@=&\@<V5N
M9"!M97-S86=E('=I=&@B*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@
M:68@*&ES<V5T*"1O<'1I;VYS6R=H;W-T)UTI*2`D=&AI<RT^:&]S="`]("1O
M<'1I;VYS6R=H;W-T)UT["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P
M;W)T)UTI*2`D=&AI<RT^<&]R="`]("1O<'1I;VYS6R=P;W)T)UT["B`@("`@
M("`@:68@*&ES<V5T*"1O<'1I;VYS6R=A=71H)UTI*2`D=&AI<RT^875T:"`]
M("1O<'1I;VYS6R=A=71H)UT["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=U<V5R;F%M92==*2D@)'1H:7,M/G5S97)N86UE(#T@)&]P=&EO;G-;)W5S
M97)N86UE)UT["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P87-S=V]R
M9"==*2D@)'1H:7,M/G!A<W-W;W)D(#T@)&]P=&EO;G-;)W!A<W-W;W)D)UT[
M"B`@("`@("`@"B`@("`@("`@)&AE861E<G,@/2!A<G)A>2@I.PH@("`@("`@
M("1H96%D97)S6R=&<F]M)UT@/2`D;W!T:6]N<ULG9G)O;2==.PH@("`@("`@
M("1H96%D97)S6R=8+4UA:6QE<B==(#T@)'1H:7,M/E]U<V5R06=E;G0["B`@
M("`@("`@)&AE861E<G-;)TU)344M5F5R<VEO;B==(#T@)S$N,"<["B`@("`@
M("`@)&AE861E<G-;)TUE<W-A9V4M240G72`](&UD-2AT:6UE*"DI+B<N<V]A
M<$`G+B1T:&ES+3YH;W-T.PH@("`@("`@("1H96%D97)S6R=4;R==(#T@)'1H
M:7,M/G5R;'!A<G1S6R=P871H)UT["B`@("`@("`@:68@*&%R<F%Y7VME>5]E
M>&ES=',H)W-O87!A8W1I;VXG+"`D;W!T:6]N<RDI('L*("`@("`@("`@("`@
M)&AE861E<G-;)U-O87!A8W1I;VXG72`](")<(GLD;W!T:6]N<ULG<V]A<&%C
M=&EO;B==?5PB(CL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=H96%D97)S)UTI*0H@("`@("`@("`@("`D:&5A9&5R
M<R`](&%R<F%Y7VUE<F=E*"1H96%D97)S+"`D;W!T:6]N<ULG:&5A9&5R<R==
M*3L*("`@("`@("`*("`@("`@("`O+R!I9B!T:&4@8V]N=&5N="!T>7!E(&ES
M(&%L<F5A9'D@<V5T+"!W92!A<W-U;64@=&AA="!-:6UE(&5N8V]D:6YG"B`@
M("`@("`@+R\@:7,@86QR96%D>2!D;VYE"B`@("`@("`@:68@*&ES<V5T*"1H
M96%D97)S6R=#;VYT96YT+51Y<&4G72DI('L*("`@("`@("`@("`@)&]U="`]
M("1M<V<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@9&\@82!S
M:6UP;&4@:6YL:6YE($UI;64@96YC;V1I;F<*("`@("`@("`@("`@)&AE861E
M<G-;)T-O;G1E;G0M1&ES<&]S:71I;VXG72`]("=I;FQI;F4G.PH@("`@("`@
M("`@("`D:&5A9&5R<ULG0V]N=&5N="U4>7!E)UT@/2`B=&5X="]X;6P[(&-H
M87)S970]7"(D=&AI<RT^96YC;V1I;F=<(B(["B`@("`@("`@("`@(&EF("AA
M<G)A>5]K97E?97AI<W1S*"=T<F%N<V9E<BUE;F-O9&EN9R<L("1O<'1I;VYS
M*2D@>PH@("`@("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)&]P=&EO;G-;
M)W1R86YS9F5R+65N8V]D:6YG)UTL)W%U;W1E9"UP<FEN=&%B;&4G*3T],"D@
M>PH@("`@("`@("`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG)UT@/2`D;W!T:6]N<ULG=')A;G-F97(M96YC;V1I;F<G
M73L*("`@("`@("`@("`@("`@("`@("`D;W5T(#T@)B1M<V<["B`@("`@("`@
M("`@("`@("!](&5L<V4@:68@*'-T<F-A<V5C;7`H)&]P=&EO;G-;)W1R86YS
M9F5R+65N8V]D:6YG)UTL)V)A<V4V-"<I/3TP*2!["B`@("`@("`@("`@("`@
M("`@("`@)&AE861E<G-;)T-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<G72`]
M("=B87-E-C0G.PH@("`@("`@("`@("`@("`@("`@("1O=70@/2!C:'5N:U]S
M<&QI="AB87-E-C1?96YC;V1E*"1M<V<I+#<V+")<;B(I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@B26YV86QI9"!4<F%N<V9E<B!%;F-O9&EN
M9SH@>R1O<'1I;VYS6R=T<F%N<V9E<BUE;F-O9&EN9R==?2(I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+R\@9&5F875L="!T;R!B87-E-C0*("`@("`@("`@("`@("`@("1H96%D
M97)S6R=#;VYT96YT+51R86YS9F5R+45N8V]D:6YG)UT@/2`G8F%S938T)SL*
M("`@("`@("`@("`@("`@("1O=70@/2!C:'5N:U]S<&QI="AB87-E-C1?96YC
M;V1E*"1M<V<I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`*
M("`@("`@("`D:&5A9&5R<ULG4W5B:F5C="==(#T@87)R87E?:V5Y7V5X:7-T
M<R@G<W5B:F5C="<L("1O<'1I;VYS*2`_("1O<'1I;VYS6R=S=6)J96-T)UT@
M.B`G4T]!4"!-97-S86=E)SL*("`@("`@("`*("`@("`@("!F;W)E86-H("@D
M:&5A9&5R<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D:&5A
M9&5R7W1E>'0@+CT@(B1K97DZ("1V86QU95QN(CL*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/F]U=&=O:6YG7W!A>6QO860@/2`D:&5A9&5R7W1E>'0N(EQR
M7&XB+B1T:&ES+3YO=71G;VEN9U]P87EL;V%D.PH@("`@("`@(",@=V4@=V%N
M="!T;R!R971U<FX@82!P<F]P97(@6$U,(&UE<W-A9V4*("`@("`@("`*("`@
M("`@("`D;6%I;&5R7W!A<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`G:&]S
M="<@/3X@)'1H:7,M/FAO<W0L"B`@("`@("`@("`@("=P;W)T)R`]/B`D=&AI
M<RT^<&]R="P*("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=&AI<RT^=7-E
M<FYA;64L"B`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'1H:7,M/G!A<W-W
M;W)D+`H@("`@("`@("`@("`G875T:"<@/3X@)'1H:7,M/F%U=&@*("`@("`@
M("`I.PH@("`@("`@("1M86EL97(@/28@;F5W($UA:6Q?<VUT<"@D;6%I;&5R
M7W!A<F%M<RD["B`@("`@("`@)')E<W5L="`]("1M86EL97(M/G-E;F0H)'1H
M:7,M/G5R;'!A<G1S6R=P871H)UTL("1H96%D97)S+"`D;W5T*3L*("`@("`@
M("`C)')E<W5L="`](&UA:6PH)'1H:7,M/G5R;'!A<G1S6R=P871H)UTL("1H
M96%D97)S6R=3=6)J96-T)UTL("1O=70L("1H96%D97)?=&5X="D["@H@("`@
M("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("`D=F%L(#TF(&YE=R!33T%07U9A;'5E*"=-97-S86=E+4E$)RPG<W1R:6YG
M)RPD:&5A9&5R<ULG365S<V%G92U)1"==*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<W9A;%M=(#TF(&YE=R!33T%07U9A;'5E*"=F875L=&-O
M9&4G+"=13F%M92<L)U-/05`M14Y6.D-L:65N="<I.PH@("`@("`@("`@("`D
M<W9A;%M=(#TF(&YE=R!33T%07U9A;'5E*"=F875L='-T<FEN9R<L)W-T<FEN
M9R<L(F-O=6QD;B=T('-E;F0@4TU44"!M97-S86=E('1O('LD=&AI<RT^=7)L
M<&%R='-;)W!A=&@G77TB*3L*("`@("`@("`@("`@)'9A;"`])B!N97<@4T]!
M4%]686QU92@G1F%U;'0G+"=3=')U8W0G+"1S=F%L*3L*("`@("`@("!]"@H@
M("`@("`@("1M<6YA;64@/28@;F5W(%%.86UE*"1M971H;V0L("1N86UE<W!A
M8V4I.PH@("`@("`@("1M971H;V1686QU92`])B!N97<@4T]!4%]686QU92@G
M4F5S<&]N<V4G+"`G4W1R=6-T)RP@87)R87DH)'9A;"DI.PH*("`@("`@("`D
M=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"`])B`D=&AI<RT^7VUA:V5%;G9E;&]P
M92@D;65T:&]D5F%L=64L("1T:&ES+3YH96%D97)S+"`D=&AI<RT^96YC;V1I
M;F<I.PH*("`@("`@("!R971U<FX@)'1H:7,M/FEN8V]M:6YG7W!A>6QO860[
M"B`@("!]"@H@("`@+RHJ"B`@("`J('-E="!D871A(&9O<B!H='1P(&%U=&AE
M;G1I8V%T:6]N"B`@("`J(&-R96%T97,@075T:&]R:7IA=&EO;B!H96%D97(*
M("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@("!U<V5R;F%M
M90H@("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@(')E<W!O;G-E(&1A
M=&$L(&UI;G5S(&AT='`@:&5A9&5R<PH@("`@*@H@("`@*B!`<F5T=7)N(&YO
M;F4*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S
M971#<F5D96YT:6%L<R@D=7-E<FYA;64L("1P87-S=V]R9"D*("`@('L*("`@
M("`@("`D=&AI<RT^=7-E<FYA;64@/2`D=7-E<FYA;64["B`@("`@("`@)'1H
M:7,M/G!A<W-W;W)D(#T@)'!A<W-W;W)D.PH@("`@?0H@("`@"B`@("`O+R!P
M<FEV871E(&UE;6)E<G,*("`@(`H@("`@+RHJ"B`@("`J('9A;&ED871E('5R
M;"!D871A('!A<W-E9"!T;R!C;VYS=')U8W1O<@H@("`@*@H@("`@*B!`<F5T
M=7)N(&)O;VQE86X*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@
M9G5N8W1I;VX@7W9A;&ED871E57)L*"D*("`@('L*("`@("`@("!I9B`H("$@
M:7-?87)R87DH)'1H:7,M/G5R;'!A<G1S*2`I('L*("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@B56YA8FQE('1O('!A<G-E(%523"`D=7)L
M(BD["B`@("`@("`@("`@(')E='5R;B!&04Q313L*("`@("`@("!]"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;)W-C:&5M92==*2!\?`H@
M("`@("`@("`@("!S=')C87-E8VUP*"1T:&ES+3YU<FQP87)T<ULG<V-H96UE
M)UTL("=M86EL=&\G*2`A/2`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@<&%R<V4@55),("1U<FPB*3L*
M("`@("`@("`@("`@("`@(')E='5R;B!&04Q313L*("`@("`@("!]"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;)W!A=&@G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B56YA8FQE('1O('!A
M<G-E(%523"`D=7)L(BD["B`@("`@("`@("`@(')E='5R;B!&04Q313L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N(%12544["B`@("!]"B`@("`*?2`O+R!E
M;F0@4T]!4%]4<F%N<W!O<G1?2%144`H_/@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U-/05`O5')A;G-P;W)T+TA45%`N<&AP````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#0W-S$U`#$P-#$W,S8S,#`U`#`R,30P,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R
M<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O
M=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A
M=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@
M?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S
M92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O
M;3X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($A45%`N<&AP+'8@,2XS.2XR
M+C0@,C`P-"\P,2\Q-R`Q-#HP,#HU,2!A<FYA=60@17AP("0*+R\*"B\J*@H@
M*B!(5%10(%1R86YS<&]R="!C;&%S<PH@*@H@*B!`<&%C:V%G92`@4T]!4`H@
M*B!`8V%T96=O<GD@5V5B7U-E<G9I8V5S"B`J+PH*+RHJ"B`J($YE961E9"!#
M;&%S<V5S"B`J+PIR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G.PH*+RHJ
M"B`J("!(5%10(%1R86YS<&]R="!F;W(@4T]!4`H@*@H@*B!`86-C97-S('!U
M8FQI8PH@*B!`=F5R<VEO;B`D260Z($A45%`N<&AP+'8@,2XS.2XR+C0@,C`P
M-"\P,2\Q-R`Q-#HP,#HU,2!A<FYA=60@17AP("0*("H@0'!A8VMA9V4@4T]!
M4#HZ5')A;G-P;W)T.CI(5%10"B`J($!A=71H;W(@4VAA;F4@0V%R879E;R`\
M<VAA;F5`<&AP+FYE=#X*("HO"F-L87-S(%-/05!?5')A;G-P;W)T7TA45%`@
M97AT96YD<R!33T%07T)A<V4*>PH@("`@+RHJ"B`@("`@*B!"87-I8R!!=71H
M('-T<FEN9PH@("`@("H*("`@("`J($!V87(@(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;V]K
M:65S"B`@("`@*@H@("`@("H@0'9A<@H@("`@("HO"B`@("!V87(@)&-O;VMI
M97,["@H@("`@+RHJ"B`@("`@*@H@("`@("H@0'9A<B`@:6YT(&-O;FYE8W1I
M;VX@=&EM96]U="!I;B!S96-O;F1S("T@,"`](&YO;F4*("`@("`J+PH@("`@
M=F%R("1T:6UE;W5T(#T@-#L*"B`@("`O*BH*("`@("`J($%R<F%Y(&-O;G1A
M:6YI;F<@=7)L<&%R=',@+2!P87)S95]U<FPH*0H@("`@("H*("`@("`J($!V
M87(@(&UI>&5D"B`@("`@*B\*("`@('9A<B`D=7)L<&%R=',@/2!.54Q,.PH*
M("`@("\J*@H@("`@("H@0V]N;F5C=&EO;B!E;F1P;VEN="`M(%523`H@("`@
M("H*("`@("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@("!V87(@)'5R;"`]
M("<G.PH*("`@("\J*@H@("`@("H@26YC;VUI;F<@<&%Y;&]A9`H@("`@("H*
M("`@("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@("!V87(@)&EN8V]M:6YG
M7W!A>6QO860@/2`G)SL*"B`@("`O*BH*("`@("`J($A45%`M4F5Q=65S="!5
M<V5R+4%G96YT"B`@("`@*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7W5S97)!9V5N="`](%-/05!?3$E"4D%265].04U%.PH*("`@
M("\J*@H@("`@("H@2%144"!%;F-O9&EN9PH@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D96YC;V1I;F<@/2!33T%07T1%1D%5
M3%1?14Y#3T1)3D<["@H@("`@+RHJ"B`@("`@*B!(5%10+5)E<W!O;G-E($-O
M;G1E;G0M5'EP92!E;F-O9&EN9PH@("`@("H*("`@("`J('=E(&%S<W5M92!5
M5$8M."!I9B!N;R!E;F-O9&EN9R!I<R!S970*("`@("`J($!V87(@('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)')E<W5L=%]E;F-O9&EN9R`]("=55$8M."<[
M"@H@("`@+RHJ"B`@("`@*B!(5%10+5)E<W!O;G-E($-O;G1E;G0M5'EP90H@
M("`@("HO"B`@("!V87(@)')E<W5L=%]C;VYT96YT7W1Y<&4["@H@("`@=F%R
M("1R97-U;'1?:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@=F%R("1R97-U;'1?
M8V]O:VEE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!33T%07U1R86YS
M<&]R=%](5%10($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D55),("`@(&AT='`@=7)L('1O('-O87`@96YD<&]I;G0*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!S=')I;F<@
M)%5220H@("`@("H@0'!A<F%M("!S=')I;F<@)&5N8V]D:6YG("!E;F-O9&EN
M9R!T;R!U<V4*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]4<F%N<W!O<G1?
M2%144"@D55),+"`D96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<I
M"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)TA45%`G*3L*("`@
M("`@("`D=&AI<RT^=7)L<&%R=',@/2!`<&%R<V5?=7)L*"154DPI.PH@("`@
M("`@("1T:&ES+3YU<FP@/2`D55),.PH@("`@("`@("1T:&ES+3YE;F-O9&EN
M9R`]("1E;F-O9&EN9SL*("`@('T*"B`@("`O*BH*("`@("`J('-E;F0@86YD
M(')E8V5I=F4@<V]A<"!D871A"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R!O=71G;VEN9R!P;W-T(&1A=&$*("`@("`J($!P87)A;2!A<G)A>2`@;W!T
M:6]N<PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG?&9A=6QT(')E<W!O
M;G-E"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B`F<V5N9"@F)&US9RP@)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@A)'1H:7,M/E]V86QI9&%T955R;"@I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^9F%U;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)W1I;65O=70G72DI"B`@("`@("`@("`@("1T:&ES+3YT
M:6UE;W5T(#T@*&EN="DD;W!T:6]N<ULG=&EM96]U="==.PH*("`@("`@("!I
M9B`H<W1R8V%S96-M<"@D=&AI<RT^=7)L<&%R='-;)W-C:&5M92==+"`G2%14
M4"<I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5N9$A4
M5%`H)&US9RP@)&]P=&EO;G,I.PH@("`@("`@('T@96QS92!I9B`H<W1R8V%S
M96-M<"@D=&AI<RT^=7)L<&%R='-;)W-C:&5M92==+"`G2%144%,G*2`]/2`P
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W-E;F1(5%104R@D;7-G
M+"`D;W!T:6]N<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]R86ES95-O87!&875L="@G26YV86QI9"!U<FP@<V-H96UE("<N)'1H:7,M
M/G5R;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!S970@9&%T82!F;W(@:'1T
M<"!A=71H96YT:6-A=&EO;@H@("`@("H@8W)E871E<R!!=71H;W)I>F%T:6]N
M(&AE861E<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE
M("`@=7-E<FYA;64*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("`@
M<F5S<&]N<V4@9&%T82P@;6EN=7,@:'1T<"!H96%D97)S"B`@("`@*@H@("`@
M("H@0')E='5R;B!N;VYE"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971#<F5D96YT:6%L<R@D=7-E<FYA;64L("1P87-S
M=V]R9"D*("`@('L*("`@("`@("`D=&AI<RT^:&5A9&5R<ULG075T:&]R:7IA
M=&EO;B==(#T@)T)A<VEC("<@+B!B87-E-C1?96YC;V1E*"1U<V5R;F%M92`N
M("<Z)R`N("1P87-S=V]R9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M82!C;V]K:64*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'!A<F%M("!S=')I;F<@("1N86UE("`@8V]O:VEE(&YA;64*("`@("`J($!P
M87)A;2`@;6EX960@("`D=F%L=64@(&-O;VMI92!V86QU90H@("`@("H@0')E
M='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O;VMI92@D;F%M
M92P@)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3YC;V]K:65S6R1N86UE
M73TD=F%L=64["B`@("!]"@H@("`@+R\@<')I=F%T92!M971H;V1S"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE(&-O<G)E8W0@:&5A9&5R<R!F;W(@
M=&AE(&-O;VMI97,*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5N0V]O
M:VEE2&5A9&5R*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]O
M:VEE<R!A<R`D;F%M93T^)'9A;'5E*2!["B`@("`@("`@("`@("1C;V]K:65S
M(#T@*&ES<V5T*"1C;V]K:65S*2`_("1C;V]K:65S+B`G.R`G(#H@)R<I("X*
M("`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1N86UE*2`N("<]
M)R`N('5R;&5N8V]D92@D=F%L=64I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&-O;VMI97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!V86QI9&%T92!U
M<FP@9&%T82!P87-S960@=&\@8V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?=F%L:61A=&55<FPH*0H@("`@>PH@("`@("`@(&EF
M("@@(2!I<U]A<G)A>2@D=&AI<RT^=7)L<&%R=',I("D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@<&%R<V4@55),
M("(@+B`D=&AI<RT^=7)L*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YU<FQP87)T<ULG
M:&]S="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*").;R!H;W-T(&EN(%523"`B("X@)'1H:7,M/G5R;"D["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^=7)L<&%R='-;)W!O<G0G72DI('L*"B`@("`@("`@("`@(&EF("AS
M=')C87-E8VUP*"1T:&ES+3YU<FQP87)T<ULG<V-H96UE)UTL("=(5%10)RD@
M/3T@,"D*("`@("`@("`@("`@("`@("1T:&ES+3YU<FQP87)T<ULG<&]R="==
M(#T@.#`["B`@("`@("`@("`@(&5L<V4@:68@*'-T<F-A<V5C;7`H)'1H:7,M
M/G5R;'!A<G1S6R=S8VAE;64G72P@)TA45%!3)RD@/3T@,"D*("`@("`@("`@
M("`@("`@("1T:&ES+3YU<FQP87)T<ULG<&]R="==(#T@-#0S.PH*("`@("`@
M("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YU<FQP87)T<ULG=7-E<B==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0W)E9&5N=&EA;',H=7)L9&5C
M;V1E*"1T:&ES+3YU<FQP87)T<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=7)L9&5C;V1E*"1T:&ES+3YU<FQP87)T
M<ULG<&%S<R==*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/G5R;'!A<G1S6R=P871H)UTI('Q\("$D=&AI<RT^=7)L<&%R='-;)W!A
M=&@G72D*("`@("`@("`@("`@)'1H:7,M/G5R;'!A<G1S6R=P871H)UT@/2`G
M+R<["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6YD<R!O=70@=VAA="!I<R!T:&4@96YC;V1I;F<N"B`@("`@*@H@("`@
M("H@4V5T<R!T:&4@;V)J96-T('!R;W!E<G1Y(&%C8V]R9&EN9VQY+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!A<G)A
M>2`D:&5A9&5R<R`@:&5A9&5R<PH@("`@("H@0')E='5R;B!V;VED"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]P87)S945N8V]D:6YG*"1H96%D97)S*0H@("`@
M>PH@("`@("`@("1H(#T@<W1R:7-T<B@D:&5A9&5R<RPG0V]N=&5N="U4>7!E
M)RD["B`@("`@("`@<')E9U]M871C:"@G+UY#;VYT96YT+51Y<&4Z7',J*"XJ
M*20O:6TG+"1H+"1C="D["B`@("`@("`@)'1H:7,M/G)E<W5L=%]C;VYT96YT
M7W1Y<&4@/2!S=')?<F5P;&%C92@B7'(B+"(B+"1C=%LQ72D["B`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R\H+BH_*2@_.CM<<S]C:&%R<V5T/2DH+BHI+VDG
M+"1T:&ES+3YR97-U;'1?8V]N=&5N=%]T>7!E+"1M*2D@>PH@("`@("`@("`@
M("`O+R!S=')I<"!T:&4@<W1R:6YG(&]F(%QR"B`@("`@("`@("`@("1T:&ES
M+3YR97-U;'1?8V]N=&5N=%]T>7!E(#T@)&U;,5T["B`@("`@("`@("`@(&EF
M("AC;W5N="@D;2D@/B`R*2!["B`@("`@("`@("`@("`@("`D96YC(#T@<W1R
M=&]U<'!E<BAS=')?<F5P;&%C92@G(B<L(B(L)&U;,ETI*3L*("`@("`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2@D96YC+"`D=&AI<RT^7V5N8V]D:6YG<RDI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<F5S=6QT7V5N8V]D:6YG
M(#T@)&5N8SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`O+R!D96%L('=I=&@@8G)O:V5N('-E<G9E<G,@=&AA
M="!D;VXG="!S970@8V]N=&5N="!T>7!E(&]N(&9A=6QT<PH@("`@("`@(&EF
M("@A)'1H:7,M/G)E<W5L=%]C;VYT96YT7W1Y<&4I("1T:&ES+3YR97-U;'1?
M8V]N=&5N=%]T>7!E(#T@)W1E>'0O>&UL)SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%!A<G-E<R!T:&4@:&5A9&5R<PH@("`@("H*("`@("`J($!P87)A;2`@
M87)R87D@)&AE861E<G,@=&AE(&AE861E<G,*("`@("`J($!R971U<FX@=F]I
M9`H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5(96%D97)S*"1H96%D97)S
M*0H@("`@>PH@("`@("`@("\J(&QA<F=E;'D@8F]R<F]W960@9G)O;2!(5%10
M7U)E<75E<W0@*B\*("`@("`@("`D=&AI<RT^<F5S=6QT7VAE861E<G,@/2!A
M<G)A>2@I.PH@("`@("`@("1H96%D97)S(#T@<W!L:70H(EQR/UQN(BP@)&AE
M861E<G,I.PH@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1V86QU92D@
M>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1V86QU92PG.B<I(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E<W5L=%]H96%D97)S6S!=
M/21V86QU93L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&QI<W0H)&YA;64L)'9A;'5E*2`]('-P;&ET*"<Z
M)RPD=F%L=64I.PH@("`@("`@("`@("`D:&5A9&5R;F%M92`]('-T<G1O;&]W
M97(H)&YA;64I.PH@("`@("`@("`@("`D:&5A9&5R=F%L=64@/2!T<FEM*"1V
M86QU92D["B`@("`@("`@("`@("1T:&ES+3YR97-U;'1?:&5A9&5R<ULD:&5A
M9&5R;F%M95T])&AE861E<G9A;'5E.PH*("`@("`@("`@("`@:68@*"1H96%D
M97)N86UE(#T]("=S970M8V]O:VEE)RD@>PH@("`@("`@("`@("`@("`@+R\@
M4&%R<V4@82!3971#;V]K:64@:&5A9&5R('1O(&9I;&P@7V-O;VMI97,@87)R
M87D*("`@("`@("`@("`@("`@("1C;V]K:64@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`G97AP:7)E<R<@/3X@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`G9&]M86EN)R`@/3X@)'1H:7,M/G5R;'!A<G1S6R=H;W-T)UTL"B`@
M("`@("`@("`@("`@("`@("`@)W!A=&@G("`@(#T^(&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@)W-E8W5R92<@(#T^(&9A;'-E"B`@("`@("`@("`@("`@
M("`I.PH*("`@("`@("`@("`@("`@("\O($]N;'D@82!N86UE/79A;'5E('!A
M:7(*("`@("`@("`@("`@("`@(&EF("@A<W1R<&]S*"1H96%D97)V86QU92P@
M)SLG*2D@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)&-O;VMI95LG;F%M
M92==+"`D8V]O:VEE6R=V86QU92==*2`](&%R<F%Y7VUA<"@G=')I;2<L(&5X
M<&QO9&4H)STG+"`D:&5A9&5R=F%L=64I*3L*("`@("`@("`@("`@("`@("`@
M("`D8V]O:VEE6R=N86UE)UT@(#T@=7)L9&5C;V1E*"1C;V]K:65;)VYA;64G
M72D["B`@("`@("`@("`@("`@("`@("`@)&-O;VMI95LG=F%L=64G72`]('5R
M;&1E8V]D92@D8V]O:VEE6R=V86QU92==*3L*"B`@("`@("`@("`@("`@("`O
M+R!3;VUE(&]P=&EO;F%L('!A<F%M971E<G,@87)E('-U<'!L:65D"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1E;&5M
M96YT<R`](&5X<&QO9&4H)SLG+"`D:&5A9&5R=F%L=64I.PH@("`@("`@("`@
M("`@("`@("`@(&QI<W0H)&-O;VMI95LG;F%M92==+"`D8V]O:VEE6R=V86QU
M92==*2`](&%R<F%Y7VUA<"@G=')I;2<L(&5X<&QO9&4H)STG+"`D96QE;65N
M='-;,%TI*3L*("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R=N86UE)UT@
M(#T@=7)L9&5C;V1E*"1C;V]K:65;)VYA;64G72D["B`@("`@("`@("`@("`@
M("`@("`@)&-O;VMI95LG=F%L=64G72`]('5R;&1E8V]D92@D8V]O:VEE6R=V
M86QU92==*3L*"B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#$[("1I
M(#P@8V]U;G0H)&5L96UE;G1S*3LD:2LK*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QI<W0@*"1E;$YA;64L("1E;%9A;'5E*2`](&%R<F%Y7VUA<"@G
M=')I;2<L(&5X<&QO9&4H)STG+"`D96QE;65N='-;)&E=*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@G<V5C=7)E)R`]/2`D96Q.86UE*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R=S96-U<F4G72`]
M('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@G97AP
M:7)E<R<@/3T@)&5L3F%M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-O;VMI95LG97AP:7)E<R==(#T@<W1R7W)E<&QA8V4H)R(G+"`G)RP@
M)&5L5F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)W!A=&@G(#T]("1E;$YA;64@3U(@)V1O;6%I;B<@/3T@)&5L3F%M92D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;VMI95LD96Q.86UE72`]
M('5R;&1E8V]D92@D96Q686QU92D["B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]O:VEE
M6R1E;$YA;65=(#T@)&5L5F%L=64["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D=&AI<RT^<F5S=6QT7V-O;VMI97-;72`]("1C;V]K
M:64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296UO=F4@:'1T<"!H96%D97)S(&9R;VT@<F5S<&]N<V4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5297-P;VYS92@I"B`@("![
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>*"XJ/RE<<C]<;EQR/UQN*"XJ
M*2]S(BP@)'1H:7,M/FEN8V]M:6YG7W!A>6QO860L("1M871C:"DI('L*("`@
M("`@("`@("`@(R1T:&ES+3YR97-P;VYS92`]('!R96=?<F5P;&%C92@B+UM<
M<GQ<;ETO(BP@)R<L("1M871C:%LR72D["B`@("`@("`@("`@("1T:&ES+3YR
M97-P;VYS92`])B`D;6%T8VA;,ET["B`@("`@("`@("`@("\O(&9I;F0@=&AE
M(')E<W!O;G-E(&5R<F]R+"!S;VUE('-E<G9E<G,@<F5S<&]N<V4@=VET:"`U
M,#`@9F]R('-O87`@9F%U;'1S"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5(
M96%D97)S*"1M871C:%LQ72D["@H@("`@("`@("`@("!L:7-T*"1P<F]T;V-O
M;"P@)&-O9&4I(#T@<W-C86YF*"1T:&ES+3YR97-U;'1?:&5A9&5R<ULP72P@
M)R5S("5S)RD["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YR97-U;'1?:&5A
M9&5R<ULP72D["@H@("`@("`@("`@("!S=VET8V@H)&-O9&4I('L*("`@("`@
M("`@("`@("`@(&-A<V4@-#`P.@H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@4F5S<&]N<V4@)&-O9&4@0F%D(%)E
M<75E<W0B*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M(#0P,3H*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A
M=6QT*")(5%10(%)E<W!O;G-E("1C;V1E($%U=&AE;G1I8V%T:6]N($9A:6QE
M9"(I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@-#`S
M.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(DA45%`@4F5S<&]N<V4@)&-O9&4@1F]R8FED9&5N(BD["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`T,#0Z"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B2%144"!297-P;VYS92`D
M8V]D92!.;W0@1F]U;F0B*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!C87-E(#0P-SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*")(5%10(%)E<W!O;G-E("1C;V1E(%!R;WAY($%U=&AE
M;G1I8V%T:6]N(%)E<75I<F5D(BD["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@8V%S92`T,#@Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]R86ES95-O87!&875L="@B2%144"!297-P;VYS92`D8V]D92!297%U97-T
M(%1I;65O=70B*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E(#0Q,#H*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*")(5%10(%)E<W!O;G-E("1C;V1E($=O;F4B*3L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@("`@(&EF("@D8V]D92`^/2`T,#`@)B8@)&-O9&4@/"`U,#`I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B
M2%144"!297-P;VYS92`D8V]D92!.;W0@1F]U;F0B*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]P87)S945N
M8V]D:6YG*"1M871C:%LQ72D["@H@("`@("`@("`@("!I9B`H)'1H:7,M/G)E
M<W5L=%]C;VYT96YT7W1Y<&4@/3T@)V%P<&QI8V%T:6]N+V1I;64G*2!["B`@
M("`@("`@("`@("`@("`O+R!86%@@<75I8VL@:&%C:R!I;G-E<G1I;VX@;V8@
M1$E-10H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1H:7,M
M/E]D96-O9&5$24U%365S<V%G92@D=&AI<RT^<F5S<&]N<V4L)'1H:7,M/FAE
M861E<G,L)'1H:7,M/F%T=&%C:&UE;G1S*2DI('L*("`@("`@("`@("`@("`@
M("`@("`O+R!?9&5C;V1E1$E-14UE<W-A9V4@86QR96%D>2!R86ES960@)'1H
M:7,M/F9A=6QT"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G)E<W5L
M=%]C;VYT96YT7W1Y<&4@/2`D=&AI<RT^:&5A9&5R<ULG8V]N=&5N="UT>7!E
M)UT["B`@("`@("`@("`@('T@96QS92!I9B`H<W1R:7-T<B@D=&AI<RT^<F5S
M=6QT7V-O;G1E;G1?='EP92PG;75L=&EP87)T+W)E;&%T960G*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G)E<W!O;G-E(#T@)'1H:7,M/FEN8V]M:6YG
M7W!A>6QO860["B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M=&AI<RT^7V1E8V]D94UI;65-97-S86=E*"1T:&ES+3YR97-P;VYS92PD=&AI
M<RT^:&5A9&5R<RPD=&AI<RT^871T86-H;65N=',I*2D@>PH@("`@("`@("`@
M("`@("`@("`@("\O(%]D96-O9&5-:6UE365S<V%G92!A;')E861Y(')A:7-E
M9"`D=&AI<RT^9F%U;'0*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!I9B`H
M)'1H:7,M/G)E<W5L=%]C;VYT96YT7W1Y<&4@(3T@)W1E>'0O>&UL)RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI<RT^
M<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("\O(&EF(&YO(&-O;G1E;G0L(')E='5R
M;B!F86QS90H@("`@("`@("`@("!R971U<FX@<W1R;&5N*"1T:&ES+3YR97-P
M;VYS92D@/B`P.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*"=);G9A;&ED($A45%`@4F5S<&]N<V4G*3L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@:'1T<"!R
M97%U97-T+"!I;F-L=61I;F<@:&5A9&5R<RP@9F]R(&]U=&=O:6YG(')E<75E
M<W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`@)B1M<V<@("!O=71G
M;VEN9R!33T%0('!A8VMA9V4*("`@("`J($!P87)A;2`D;W!T:6]N<PH@("`@
M("H@0')E='5R;B!S=')I;F<@;W5T9V]I;F=?<&%Y;&]A9`H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9?9V5T4F5Q=65S
M="@F)&US9RP@)&]P=&EO;G,I"B`@("!["B`@("`@("`@)&%C=&EO;B`](&ES
M<V5T*"1O<'1I;VYS6R=S;V%P86-T:6]N)UTI/R1O<'1I;VYS6R=S;V%P86-T
M:6]N)UTZ)R<["B`@("`@("`@)&9U;&QP871H(#T@)'1H:7,M/G5R;'!A<G1S
M6R=P871H)UTN"B`@("`@("`@("`@("`@("`@("`@("`@("AI<W-E="@D=&AI
M<RT^=7)L<&%R='-;)W%U97)Y)UTI/R<_)RXD=&AI<RT^=7)L<&%R='-;)W%U
M97)Y)UTZ)R<I+@H@("`@("`@("`@("`@("`@("`@("`@("`H:7-S970H)'1H
M:7,M/G5R;'!A<G1S6R=F<F%G;65N="==*3\G(R<N)'1H:7,M/G5R;'!A<G1S
M6R=F<F%G;65N="==.B<G*3L*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=P<F]X>5]H;W-T)UTI*2!["B`@("`@("`@("`@("1F=6QL<&%T:"`]("=H
M='1P.B\O)R`N("1T:&ES+3YU<FQP87)T<ULG:&]S="==("X@)SHG("X@)'1H
M:7,M/G5R;'!A<G1S6R=P;W)T)UT@+B`D9G5L;'!A=&@["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!R;WAY7W5S97(G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/FAE861E<G-;)U!R;WAY+4%U=&AO<FEZ871I
M;VXG72`]("="87-I8R`G("X@8F%S938T7V5N8V]D92@D;W!T:6]N<ULG<')O
M>'E?=7-E<B==+B(Z(BXD;W!T:6]N<ULG<')O>'E?<&%S<R==*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG=7-E<B==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<V5T0W)E9&5N=&EA;',H)&]P=&EO;G-;)W5S
M97(G72P@)&]P=&EO;G-;)W!A<W,G72D["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^:&5A9&5R<ULG57-E<BU!9V5N="==(#T@)'1H:7,M/E]U<V5R06=E
M;G0["B`@("`@("`@)'1H:7,M/FAE861E<G-;)TAO<W0G72`]("1T:&ES+3YU
M<FQP87)T<ULG:&]S="==.PH@("`@("`@("1T:&ES+3YH96%D97)S6R=#;VYT
M96YT+51Y<&4G72`](")T97AT+WAM;#L@8VAA<G-E=#TD=&AI<RT^96YC;V1I
M;F<B.PH@("`@("`@("1T:&ES+3YH96%D97)S6R=#;VYT96YT+4QE;F=T:"==
M(#T@<W1R;&5N*"1M<V<I.PH@("`@("`@("1T:&ES+3YH96%D97)S6R=33T%0
M06-T:6]N)UT@/2`B7"(D86-T:6]N7"(B.PH@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG:&5A9&5R<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^:&5A
M9&5R<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3YH96%D97)S+"`D;W!T:6]N<ULG
M:&5A9&5R<R==*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YC;V]K:65S
M(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=N;V-O
M;VMI97,G72D@?'P@(21O<'1I;VYS6R=N;V-O;VMI97,G72D@>PH@("`@("`@
M("`@("`O+R!A9&0@=&AE(&-O;VMI97,@=V4@9V]T(&9R;VT@=&AE(&QA<W0@
M<F5Q=65S=`H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/G)E<W5L=%]C
M;V]K:65S*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/G)E
M<W5L=%]C;V]K:65S(&%S("1C;V]K:64I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-O;VMI95LG9&]M86EN)UT@/3T@)'1H:7,M/G5R;'!A<G1S6R=H
M;W-T)UTI"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;V]K:65S
M6R1C;V]K:65;)VYA;64G75T])&-O;VMI95LG=F%L=64G73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!A
M9&0@8V]O:VEE<R!T:&4@=7-E<B!W86YT<R!T;R!S970*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)V-O;VMI97,G72DI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)&]P=&EO;G-;)V-O;VMI97,G72!A<R`D8V]O:VEE*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&-O;VMI95LG9&]M86EN)UT@/3T@)'1H:7,M/G5R
M;'!A<G1S6R=H;W-T)UTI"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O
M;VMI97-;)&-O;VMI95LG;F%M92==73TD8V]O:VEE6R=V86QU92==.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AC;W5N="@D=&AI<RT^
M8V]O:VEE<RDI('L*("`@("`@("`@("`@)'1H:7,M/FAE861E<G-;)T-O;VMI
M92==(#T@)'1H:7,M/E]G96Y#;V]K:65(96%D97(H*3L*("`@("`@("!]"B`@
M("`@("`@)&AE861E<G,@/2`G)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M:&5A9&5R<R!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`D:&5A9&5R<R`N
M/2`B)&LZ("1V7')<;B(["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YO=71G
M;VEN9U]P87EL;V%D(#T*("`@("`@("`@("`@("`@(")03U-4("1F=6QL<&%T
M:"!(5%10+S$N,%QR7&XB+@H@("`@("`@("`@("`@("`@)&AE861E<G,N(EQR
M7&XB+@H@("`@("`@("`@("`@("`@)&US9SL*("`@("`@("!R971U<FX@)'1H
M:7,M/F]U=&=O:6YG7W!A>6QO860["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M96YD(&]U=&=O:6YG(')E<75E<W0L(&%N9"!R96%D+W!A<G-E(')E<W!O;G-E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)B1M<V<@("!O=71G;VEN
M9R!33T%0('!A8VMA9V4*("`@("`J($!P87)A;2!S=')I;F<@("1A8W1I;VX@
M("!33T%0($%C=&EO;@H@("`@("H@0')E='5R;B!S=')I;F<@)B1R97-P;VYS
M92`@(')E<W!O;G-E(&1A=&$L(&UI;G5S(&AT='`@:&5A9&5R<PH@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9?<V5N9$A4
M5%`H)B1M<V<L("1O<'1I;VYS*0H@("`@>PH@("`@("`@("1T:&ES+3YI;F-O
M;6EN9U]P87EL;V%D(#T@)R<["B`@("`@("`@)'1H:7,M/E]G971297%U97-T
M*"1M<V<L("1O<'1I;VYS*3L*("`@("`@("`D:&]S="`]("1T:&ES+3YU<FQP
M87)T<ULG:&]S="==.PH@("`@("`@("1P;W)T(#T@)'1H:7,M/G5R;'!A<G1S
M6R=P;W)T)UT["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P<F]X>5]H
M;W-T)UTI*2!["B`@("`@("`@("`@("1H;W-T(#T@)&]P=&EO;G-;)W!R;WAY
M7VAO<W0G73L*("`@("`@("`@("`@)'!O<G0@/2!I<W-E="@D;W!T:6]N<ULG
M<')O>'E?<&]R="==*2`_("1O<'1I;VYS6R=P<F]X>5]P;W)T)UT@.B`X,#@P
M.PH@("`@("`@('T*("`@("`@("`O+R!S96YD"B`@("`@("`@:68@*"1T:&ES
M+3YT:6UE;W5T(#X@,"D@>PH@("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N
M*"1H;W-T+"`D<&]R="P@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R;7-G+"`D
M=&AI<RT^=&EM96]U="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&9P(#T@0&9S;V-K;W!E;B@D:&]S="P@)'!O<G0L("1T:&ES+3YE<G)N;RP@
M)'1H:7,M/F5R<FUS9RD["B`@("`@("`@?0H@("`@("`@(&EF("@A)&9P*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")#
M;VYN96-T($5R<F]R('1O("1H;W-T.B1P;W)T(BD["B`@("`@("`@?0H@("`@
M("`@(&EF("@D=&AI<RT^=&EM96]U="`^(#`I('L*("`@("`@("`@("`@+R\@
M<V]M92!B=6EL9',@;V8@<&AP(&1O(&YO="!S=7!P;W)T('1H:7,L('-I;&5N
M8V4*("`@("`@("`@("`@+R\@=&AE('=A<FYI;F<*("`@("`@("`@("`@0'-O
M8VME=%]S971?=&EM96]U="@D9G`L("1T:&ES+3YT:6UE;W5T*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"%F<'5T<R@D9G`L("1T:&ES+3YO=71G;VEN9U]P
M87EL;V%D+"!S=')L96XH)'1H:7,M/F]U=&=O:6YG7W!A>6QO860I*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B17)R
M;W(@4$]35&EN9R!$871A('1O("1H;W-T(BD["B`@("`@("`@?0H*("`@("`@
M("`O+R!G970@<F5P;VYS90H@("`@("`@("\O(%A86"!T:6UE(&-O;G-U;65R
M"B`@("`@("`@9&\@>PH@("`@("`@("`@("`D9&%T82`](&9R96%D*"1F<"P@
M-#`Y-BD["B`@("`@("`@("`@("1?=&UP7W-T871U<R`]('-O8VME=%]G971?
M<W1A='5S*"1F<"D["B`@("`@("`@("`@(&EF("@D7W1M<%]S=&%T=7-;)W1I
M;65D7V]U="==*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R
M86ES95-O87!&875L="@B5&EM960@;W5T(')E860@9G)O;2`D:&]S="(I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FEN
M8V]M:6YG7W!A>6QO860@+CT@)&1A=&$["B`@("`@("`@("`@('T*("`@("`@
M("!]('=H:6QE("@A)%]T;7!?<W1A='5S6R=E;V8G72D["@H@("`@("`@(&9C
M;&]S92@D9G`I.PH*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R<V5297-P;VYS
M92@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%U;'0["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F5S<&]N<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!396YD(&]U=&=O:6YG(')E<75E<W0L(&%N9"!R96%D
M+W!A<G-E(')E<W!O;G-E+"!V:6$@2%144%,*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`F)&US9R`@(&]U=&=O:6YG(%-/05`@<&%C:V%G90H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&%C=&EO;B`@(%-/05`@06-T:6]N"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`F)')E<W!O;G-E("`@<F5S<&]N<V4@9&%T82P@
M;6EN=7,@:'1T<"!H96%D97)S"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@)E]S96YD2%144%,H)B1M<V<L("1O<'1I;VYS
M*0H@("`@>PH@("`@("`@("\J($Y/5$4@5&AI<R!F=6YC=&EO;B!U<V5S('1H
M92!#55),(&9U;F-T:6]N<PH@("`@("`@("`J("!9;W5R('!H<"!M=7-T(&)E
M(&-O;7!I;&5D('=I=&@@0U523`H@("`@("`@("`J+PH@("`@("`@(&EF("@A
M97AT96YS:6]N7VQO861E9"@G8W5R;"<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=#55),($5X=&5N<VEO;B!I<R!R
M97%U:7)E9"!F;W(@2%144%,G*3L*("`@("`@("!]"@HO+R`@("`@("`@)'1H
M:7,M/E]G971297%U97-T*"1M<V<L("1O<'1I;VYS*3L*"B`@("`@("`@)&-H
M(#T@8W5R;%]I;FET*"D["@H@("`@("`@("\O(%A86"!D;VXG="!K;F]W(&EF
M('1H:7,@<')O>'D@<W1U9F8@:7,@<FEG:'0@9F]R($-54DP*("`@("`@("`O
M+R!!<FYA=60Z(&%P<&%R96YT;'D@:70@:7,L('=E(&AA=F4@82!P<F]X>2!A
M;F0@:70@=V]R:W,*("`@("`@("`O+R!W:71H('1H97-E(&QI;F5S+@H@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<')O>'E?:&]S="==*2D@>PH@("`@
M("`@("`@("`O+R`D;W!T:6]N<ULG:'1T<%]P<F]X>2==(#T]("=H;W-T;F%M
M93IP;W)T)PH@("`@("`@("`@("`D:&]S="`]("1O<'1I;VYS6R=P<F]X>5]H
M;W-T)UT["B`@("`@("`@("`@("1P;W)T(#T@:7-S970H)&]P=&EO;G-;)W!R
M;WAY7W!O<G0G72D@/R`D;W!T:6]N<ULG<')O>'E?<&]R="==(#H@.#`X,#L*
M("`@("`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47U!23UA9+"`D
M:&]S="`N("(Z(B`N("1P;W)T*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG<')O>'E?=7-E<B==*2D@>PH@("`@("`@("`@("`O
M+R`D;W!T:6]N<ULG:'1T<%]P<F]X>5]U<V5R<'<G72`]/2`G=7-E<FYA;64Z
M<&%S<W=O<F0G"B`@("`@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]0
M5%]04D]8655315)05T0L("1O<'1I;VYS6R=P<F]X>5]U<V5R)UT@+B`G.B<@
M+B`D;W!T:6]N<ULG<')O>'E?<&%S<R==*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULG=7-E<B==*2D@>PH@("`@("`@("`@("!C
M=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?55-%4E!71"P@)&]P=&EO;G-;)W5S
M97(G72`N("<Z)R`N("1O<'1I;VYS6R=P87-S)UTI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]A<&%C=&EO;B==*2D@>PH@
M("`@("`@("`@("`D;W!T:6]N<ULG<V]A<&%C=&EO;B==(#T@)R<["B`@("`@
M("`@?0H@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%](5%102$5!
M1$52("P@("`@87)R87DH)T-O;G1E;G0M5'EP93H@=&5X="]X;6P[8VAA<G-E
M=#TG("X@)'1H:7,M/F5N8V]D:6YG+"`G4T]!4$%C=&EO;CH@(B<N)&]P=&EO
M;G-;)W-O87!A8W1I;VXG72XG(B<I*3L*("`@("`@("!C=7)L7W-E=&]P="@D
M8V@L($-54DQ/4%1?55-%4D%'14Y4("P@("`@("1T:&ES+3Y?=7-E<D%G96YT
M*3L*"B`@("`@("`@:68@*"1T:&ES+3YT:6UE;W5T*2!["B`@("`@("`@("`@
M(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]424U%3U54+"`D=&AI<RT^=&EM
M96]U="D[("\O=&EM97,@;W5T(&%F=&5R(#1S"B`@("`@("`@?0H*("`@("`@
M("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?4$]35$9)14Q$4RP@("`@("1M
M<V<I.PH@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]54DPL("`@
M("`@("`@("`@)'1H:7,M/G5R;"D["B`@("`@("`@8W5R;%]S971O<'0H)&-H
M+"!#55),3U!47U!/4U0L("`@("`@("`@("`Q*3L*("`@("`@("!C=7)L7W-E
M=&]P="@D8V@L($-54DQ/4%1?1D%)3$].15)23U(L("`@(#`I.PH@("`@("`@
M(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]&3TQ,3U=,3T-!5$E/3BP@,2D[
M"B`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47U)%5%523E1204Y3
M1D52+"`Q*3L*("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?2$5!
M1$52+"`@("`@("`@(#$I.PH*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)V-U<FPG72DI('L*("`@("`@("`@("`@<F5S970H)&]P=&EO;G-;)V-U<FPG
M72D["B`@("`@("`@("`@('=H:6QE("AL:7-T*"1K97DL("1V86PI(#T@96%C
M:"`H)&]P=&EO;G-;)V-U<FPG72DI('L*("`@("`@("`@("`@("`@(&-U<FQ?
M<V5T;W!T*"1C:"P@)&ME>2P@)'9A;"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D(#T@8W5R;%]E
M>&5C*"1C:"D["B`@("`@("`@:68@*"$@)'1H:7,M/FEN8V]M:6YG7W!A>6QO
M860@*2!["B`@("`@("`@("`@("1M(#T@)V-U<FQ?97AE8R!E<G)O<B`G("X@
M8W5R;%]E<G)N;R@D8V@I("X@)R`G("X@8W5R;%]E<G)O<B@D8V@I.PH@("`@
M("`@("`@("!C=7)L7V-L;W-E*"1C:"D["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1M*3L*("`@("`@("!]"B`@("`@("`@
M8W5R;%]C;&]S92@D8V@I.PH*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R<V52
M97-P;VYS92@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%U;'0[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/G)E<W!O;G-E.PH@
M("`@?0I]("\O(&5N9"!33T%07U1R86YS<&]R=%](5%10"C\^"@``````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U1Y<&4O````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,S`P-@`P,3<P,C8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U-/05`O5'EP92]D871E5&EM92YP:'``````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$R-3,T`#$P-#$W,S8S,#`V`#`R,3(W-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0
M;W)T('1O(%!%05(@86YD(&UO<F4@("!\"B\O('P@075T:&]R<SH@1&EE=')I
M8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!D871E5&EM92YP:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q,3HU-CHR
M,"!M:B!%>'`@)`HO+PIC;&%S<R!33T%07U1Y<&5?9&%T951I;64*>PH@("`@
M=F%R("1E<F5G7VES;S@V,#$@/2`G*"T_6S`M.5U[-'TI+2A;,"TY77LR?2DM
M*%LP+3E=>S)]*50H6S`M.5U[,GTI.BA;,"TY77LR?2DZ*%LP+3E=>S)]*2A<
M+ELP+3E=*BD_*%I\6RM<+5U;,"TY77LT?7Q;*UPM75LP+3E=>S)].ELP+3E=
M>S)]*3\G.PH@("`@("`@(",B*"T_6S`M.5U[-'TI+2(N("`O+R!C96YT=7)I
M97,@)B!Y96%R<R!#0UE9+0H@("`@("`@(",B*%LP+3E=>S)]*2TB+B`@+R\@
M;6]N=&AS($U-+0H@("`@("`@(",B*%LP+3E=>S)]*2(N("`@("\O(&1A>7,@
M1$0*("`@("`@("`C(E0B+B`@("`@("`@("`@("`@("`@("`@+R\@<V5P87)A
M=&]R(%0*("`@("`@("`C(BA;,"TY77LR?2DZ(BX@("\O(&AO=7)S(&AH.@H@
M("`@("`@(",B*%LP+3E=>S)]*3HB+B`@+R\@;6EN=71E<R!M;3H*("`@("`@
M("`C(BA;,"TY77LR?2DH7"Y;,"TY72HI/R(N("\O('-E8V]N9',@<W,N<W,N
M+BX*("`@("`@("`C(BA:?%LK7"U=6S`M.5U[-'U\6RM<+5U;,"TY77LR?3I;
M,"TY77LR?2D_(CL@+R\@6B!T;R!I;F1I8V%T92!55$,L("TO*TA(.DU-.E-3
M+E-3+BXN(&9O<B!L;V-A;"!T>B=S"B`@("`@("`@(R!I9B!N;R`X=&@@<F5G
M("A:*2!A<W-U;65S(%540PH@("`@=F%R("1T:6UE<W1A;7`@/2`M,3L*("`@
M(`H@("`@9G5N8W1I;VX@4T]!4%]4>7!E7V1A=&54:6UE*"1D871E(#T@+3$I
M"B`@("!["B`@("`@("`@:68@*"1D871E(#T]("TQ*2`D9&%T92`]('1I;64H
M*3L*"B`@("`@("`@:68@*&=E='1Y<&4H)&1A=&4I(#T]("=I;G1E9V5R)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^=&EM97-T86UP(#T@)&1A=&4["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G1I;65S=&%M<"`]("1T
M:&ES+3YT;U5N:7AT:6UE*"1D871E*3L*("`@("`@("!]"B`@("!]"B`@("`*
M("`@(&9U;F-T:6]N('1O4T]!4"@D9&%T92`]($Y53$PI"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YT;U540R@D9&%T92D["B`@("!]"B`@("`*("`@
M(&9U;F-T:6]N('1O4W1R:6YG*"1T:6UE<W1A;7`@/2`P*0H@("`@>PH@("`@
M("`@(&EF("@A)'1I;65S=&%M<"D@)'1I;65S=&%M<"`]("1T:&ES+3YT:6UE
M<W1A;7`["B`@("`@("`@:68@*"1T:6UE<W1A;7`@/"`P*2!R971U<FX@,#L*
M"B`@("`@("`@<F5T=7)N(&1A=&4H)UDM;2UD7%1(.FDZ<T\G+"1T:6UE<W1A
M;7`I.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!?<W!L:70H)&1A=&5S='(I
M"B`@("!["B`@("`@("`@:68@*"$D9&%T97-T<BD*("`@("`@("`@("`@)&1A
M=&5S='(@/2`D=&AI<RT^=&]3=')I;F<H*3L*("`@("`@("!E;'-E(&EF("AG
M971T>7!E*"1D871E<W1R*2`]/2`G:6YT96=E<B<I"B`@("`@("`@("`@("1D
M871E<W1R(#T@)'1H:7,M/G1O4W1R:6YG*"1D871E<W1R*3L*("`@("`@("`@
M("`@"B`@("`@("`@:68@*&5R96<H)'1H:7,M/F5R96=?:7-O.#8P,2PD9&%T
M97-T<BPD<F5G<RDI('L*("`@("`@("`@("`@:68@*"1R96=S6SA=("$]("<G
M("8F("1R96=S6SA=("$]("=:)RD@>PH@("`@("`@("`@("`@("`@)&]P(#T@
M<W5B<W1R*"1R96=S6SA=+#`L,2D["B`@("`@("`@("`@("`@("`D:"`]('-U
M8G-T<B@D<F5G<ULX72PQ+#(I.PH@("`@("`@("`@("`@("`@:68@*'-T<G-T
M<B@D<F5G<ULX72PG.B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&T@/2!S
M=6)S='(H)')E9W-;.%TL-"PR*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&T@/2!S=6)S='(H)')E9W-;.%TL,RPR
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D;W`@
M/3T@)RLG*2!["B`@("`@("`@("`@("`@("`@("`@)')E9W-;-%T@/2`D<F5G
M<ULT72`M("1H.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<F5G<ULT72`\
M(#`I("1R96=S6S1=("L](#(T.PH@("`@("`@("`@("`@("`@("`@("1R96=S
M6S5=(#T@)')E9W-;-5T@+2`D;3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)')E9W-;-5T@/"`P*2`D<F5G<ULU72`K/2`V,#L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)')E9W-;-%T@/2`D<F5G
M<ULT72`K("1H.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<F5G<ULT72`^
M(#(S*2`D<F5G<ULT72`M/2`R-#L*("`@("`@("`@("`@("`@("`@("`D<F5G
M<ULU72`]("1R96=S6S5=("L@)&T["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1R96=S6S5=(#X@-3DI("1R96=S6S5=("T](#8P.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5G<SL*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N($9!3%-%.PH@("`@?0H@("`@"B`@
M("!F=6YC=&EO;B!T;U540R@D9&%T97-T<B`]($Y53$PI"B`@("!["B`@("`@
M("`@)')E9W,@/2`D=&AI<RT^7W-P;&ET*"1D871E<W1R*3L*"B`@("`@("`@
M:68@*"1R96=S*2!["B`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"<E,#1D
M+24P,F0M)3`R9%0E,#)D.B4P,F0Z)3`R9%HG+"1R96=S6S%=+"1R96=S6S)=
M+"1R96=S6S-=+"1R96=S6S1=+"1R96=S6S5=+"1R96=S6S9=*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("!F=6YC=&EO;B!T
M;U5N:7AT:6UE*"1D871E<W1R(#T@3E5,3"D*("`@('L*("`@("`@("`D<F5G
M<R`]("1T:&ES+3Y?<W!L:70H)&1A=&5S='(I.PH@("`@("`@(&EF("@D<F5G
M<RD@>PH@("`@("`@("`@("!R971U<FX@<W1R=&]T:6UE*"(D<F5G<ULQ72TD
M<F5G<ULR72TD<F5G<ULS72`D<F5G<ULT73HD<F5G<ULU73HD<F5G<ULV75HB
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("TQ.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&-O;7!A<F4H)&1A=&4Q+"`D9&%T93(@/2!.54Q,*0H@("`@>PH@
M("`@("`@(&EF("@D9&%T93(@/3T](&YU;&PI('L*("`@("`@("`@("`@)&1A
M=&4R(#T@)&1A=&4Q.PH@("`@("`@("`@("`D9&%T93$@/2`D=&AI<RT^=&EM
M97-T86UP.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;65R:6,H)&1A
M=&4Q*2D*("`@("`@("`@("`@)&1A=&4Q(#T@)'1H:7,M/G1O56YI>'1I;64H
M)&1A=&4Q*3L*("`@("`@("!I9B`H(6ES7VYU;65R:6,H)&1A=&4R*2D*("`@
M("`@("`@("`@)&1A=&4R(#T@)'1H:7,M/G1O56YI>'1I;64H)&1A=&4R*3L*
M("`@("`@("!I9B`H)&1A=&4Q("$]("TQ("8F("1D871E,B`A/2`M,2D@<F5T
M=7)N("1D871E,2`M("1D871E,CL*("`@("`@("!R971U<FX@+3$["B`@("!]
M"B`@("`*("`@(&9U;F-T:6]N(%]T97-T*"1O<FEG(#T@)S(P,#$M,#0M,C54
M,#DZ,S$Z-#$M,#<P,"<I"B`@("!["B`@("`@("`@)'5T8R`]("1T:&ES+3YT
M;U540R@D;W)I9RD["B`@("`@("`@)'1S,2`]("1T:&ES+3YT;U5N:7AT:6UE
M*"1O<FEG*3L*("`@("`@("`D=',R(#T@)'1H:7,M/G1O56YI>'1I;64H)'5T
M8RD["B`@("`@("`@)&(Q(#T@)'1H:7,M/G1O4W1R:6YG*"1T<S$I.PH@("`@
M("`@("1B,B`]("1T:&ES+3YT;U-T<FEN9R@D=',R*3L*("`@("`@("!P<FEN
M="`B;W)I9SH@)&]R:6=<;B(["B`@("`@("`@<')I;G0@(F]R:6<@=&]55$,Z
M("1U=&-<;B(["B`@("`@("`@<')I;G0@(F]R:6<@=',Z("1T<S%<;B(["B`@
M("`@("`@<')I;G0@(G5T8R!T<SH@)'1S,EQN(CL*("`@("`@("!P<FEN="`B
M;W)I9R!T<R!B86-K.B`D8C%<;B(["B`@("`@("`@<')I;G0@(G5T8R!T<R!B
M86-K.B`D8C)<;B(["B`@("`@("`@:68@*"1B,2`A/2`D;W)I9R!\?"`D8C(@
M(3T@)&]R:6<I('L*("`@("`@("`@("`@96-H;R`B17)R;W(@:6X@:7-O.#8P
M,2!C;VYV97)S:6]N<UQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!E8VAO(")D871E5&EM92!/2UQN(CL*("`@("`@("!]"B`@("!]"GT*"B,@
M=&AE<V4@<VAO=6QD(&%L;"!M871C:`HC)&0@/2!N97<@4T]!4%]4>7!E7V1A
M=&54:6UE*"D["B-E8VAO("1D+3YC;VUP87)E*"(R,#`Q+3`T+3(U5#(P.C,Q
M.C0Q6B(L(C(P,#$M,#0M,C54,C`Z,S$Z-#%:(BDN(EQN(CL*(V5C:&\@)&0M
M/F-O;7!A<F4H(C(P,#$M,#0M,C54,C`Z,S$Z-#%:(BPB,C`P,2TP-"TR-50Q
M,CHS,3HT,2TP.#`P(BDN(EQN(CL*(V5C:&\@)&0M/F-O;7!A<F4H(C(P,#$M
M,#0M,C54,C`Z,S$Z-#%:(BPB,C`P,2TP-"TR-50Q,CHS,3HT,2TP.#HP,"(I
M+B)<;B(["@H_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O5'EP92]D=7)A=&EO;BYP
M:'``````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S-#`V`#$P-#$W
M,S8S,#`V`#`R,3,V-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*@IH='1P.B\O=W=W+G<S+F]R9R]44B]X;6QS
M8VAE;6$M,B\*"EM$969I;FET:6]N.ET@("!D=7)A=&EO;B!R97!R97-E;G1S
M(&$@9'5R871I;VX@;V8@=&EM92X@5&AE('9A;'5E('-P86-E(&]F"F1U<F%T
M:6]N(&ES(&$@<VEX+61I;65N<VEO;F%L('-P86-E('=H97)E('1H92!C;V]R
M9&EN871E<R!D97-I9VYA=&4@=&AE"D=R96=O<FEA;B!Y96%R+"!M;VYT:"P@
M9&%Y+"!H;W5R+"!M:6YU=&4L(&%N9"!S96-O;F0@8V]M<&]N96YT<PID969I
M;F5D(&EN("`U+C4N,RXR(&]F(%M)4T\@.#8P,5TL(')E<W!E8W1I=F5L>2X@
M5&AE<V4@8V]M<&]N96YT<R!A<F4*;W)D97)E9"!I;B!T:&5I<B!S:6=N:69I
M8V%N8V4@8GD@=&AE:7(@;W)D97(@;V8@87!P96%R86YC92!I+F4N(&%S('EE
M87(L"FUO;G1H+"!D87DL(&AO=7(L(&UI;G5T92P@86YD('-E8V]N9"X@"@HS
M+C(N-BXQ($QE>&EC86P@<F5P<F5S96YT871I;VX*5&AE(&QE>&EC86P@<F5P
M<F5S96YT871I;VX@9F]R(&1U<F%T:6]N(&ES('1H92!;25-/(#@V,#%=(&5X
M=&5N9&5D"F9O<FUA="!0;EEN($UN1%1N2"!N36Y3+"!W:&5R92!N62!R97!R
M97-E;G1S('1H92!N=6UB97(@;V8*>65A<G,L(&Y-('1H92!N=6UB97(@;V8@
M;6]N=&AS+"!N1"!T:&4@;G5M8F5R(&]F(&1A>7,L("=4)R!I<R!T:&4*9&%T
M92]T:6UE('-E<&%R871O<BP@;D@@=&AE(&YU;6)E<B!O9B!H;W5R<RP@;DT@
M=&AE(&YU;6)E<B!O9@IM:6YU=&5S(&%N9"!N4R!T:&4@;G5M8F5R(&]F('-E
M8V]N9',N(%1H92!N=6UB97(@;V8@<V5C;VYD<PIC86X@:6YC;'5D92!D96-I
M;6%L(&1I9VET<R!T;R!A<F)I=')A<GD@<')E8VES:6]N+@H*5&AE('9A;'5E
M<R!O9B!T:&4@665A<BP@36]N=&@L($1A>2P@2&]U<B!A;F0@36EN=71E<R!C
M;VUP;VYE;G1S"F%R92!N;W0@<F5S=')I8W1E9"!B=70@86QL;W<@86X@87)B
M:71R87)Y(&EN=&5G97(N(%-I;6EL87)L>2P@=&AE"G9A;'5E(&]F('1H92!3
M96-O;F1S(&-O;7!O;F5N="!A;&QO=W,@86X@87)B:71R87)Y(&1E8VEM86PN
M"E1H=7,L('1H92!L97AI8V%L(')E<')E<V5N=&%T:6]N(&]F(&1U<F%T:6]N
M(&1O97,@;F]T(&9O;&QO=R!T:&4*86QT97)N871I=F4@9F]R;6%T(&]F("`U
M+C4N,RXR+C$@;V8@6TE33R`X-C`Q72X*"D%N(&]P=&EO;F%L('!R96-E9&EN
M9R!M:6YU<R!S:6=N("@G+2<I(&ES(&%L;&]W960L('1O(&EN9&EC871E(&$*
M;F5G871I=F4@9'5R871I;VXN($EF('1H92!S:6=N(&ES(&]M:71T960@82!P
M;W-I=&EV92!D=7)A=&EO;B!I<PII;F1I8V%T960N(%-E92!A;'-O($E33R`X
M-C`Q($1A=&4@86YD(%1I;64@1F]R;6%T<R`H1"DN(`H*1F]R(&5X86UP;&4L
M('1O(&EN9&EC871E(&$@9'5R871I;VX@;V8@,2!Y96%R+"`R(&UO;G1H<RP@
M,R!D87ES+`HQ,"!H;W5R<RP@86YD(#,P(&UI;G5T97,L(&]N92!W;W5L9"!W
M<FET93H@4#%9,DTS1%0Q,$@S,$TN"D]N92!C;W5L9"!A;'-O(&EN9&EC871E
M(&$@9'5R871I;VX@;V8@;6EN=7,@,3(P(&1A>7,@87,Z("U0,3(P1"X@"@I2
M961U8V5D('!R96-I<VEO;B!A;F0@=')U;F-A=&5D(')E<')E<V5N=&%T:6]N
M<R!O9B!T:&ES(&9O<FUA=`IA<F4@86QL;W=E9"!P<F]V:61E9"!T:&5Y(&-O
M;F9O<FT@=&\@=&AE(&9O;&QO=VEN9SH@"@I)9B!T:&4@;G5M8F5R(&]F('EE
M87)S+"!M;VYT:',L(&1A>7,L(&AO=7)S+"!M:6YU=&5S+"!O<B!S96-O;F1S
M"FEN(&%N>2!E>'!R97-S:6]N(&5Q=6%L<R!Z97)O+"!T:&4@;G5M8F5R(&%N
M9"!I=',@8V]R<F5S<&]N9&EN9PID97-I9VYA=&]R("IM87DJ(&)E(&]M:71T
M960N($AO=V5V97(L(&%T(&QE87-T(&]N92!N=6UB97(@86YD"FET<R!D97-I
M9VYA=&]R("IM=7-T*B!B92!P<F5S96YT+B`*5&AE('-E8V]N9',@<&%R="`J
M;6%Y*B!H879E(&$@9&5C:6UA;"!F<F%C=&EO;BX@"E1H92!D97-I9VYA=&]R
M("=4)R!S:&%L;"!B92!A8G-E;G0@:68@86QL(&]F('1H92!T:6UE(&ET96US
M(&%R92!A8G-E;G0N"E1H92!D97-I9VYA=&]R("=0)R!M=7-T(&%L=V%Y<R!B
M92!P<F5S96YT+B`*1F]R(&5X86UP;&4L(%`Q,S0W62P@4#$S-#=-(&%N9"!0
M,5DR350R2"!A<F4@86QL(&%L;&]W960[(%`P63$S-#=-"F%N9"!0,%DQ,S0W
M33!$(&%R92!A;&QO=V5D+B!0+3$S-#=-(&ES(&YO="!A;&QO=V5D(&%L=&AO
M=6=H("U0,3,T-TT*:7,@86QL;W=E9"X@4#%9,DU4(&ES(&YO="!A;&QO=V5D
M+B`*"BHO"@HO*B!T:&ES(&ES(&]N;'D@86X@87!R;WAI;6%T:6]N(&]F(&1U
M<F%T:6]N+"!M;W)E('=O<FL@<W1I;&P@=&\@9&\N"B`@('-E92!A8F]V92!S
M8VAE;6$@=7)L(&9O<B!M;W)E(&EN9F\@;VX@9'5R871I;VX*("`@"B`@(%1/
M1$\Z(&9I9W5R92!O=70@8F5S="!A<')O>&EM871I;VX@9F]R('EE87(@86YD
M(&UO;G1H(&-O;G9E<G-I;VX@=&\@<V5C;VYD<PHJ+PH@("`*)&5R96=?9'5R
M871I;VX@/2`G*"TI/U`H6S`M.5TK62D_*%LP+3E=*TTI/RA;,"TY72M$*3]4
M/RA;,"TY72M(*3\H6S`M.5TK32D_*%LP+3E=*U,I/R<["F-L87-S(%-/05!?
M5'EP95]D=7)A=&EO;@I["B`@("`O+R!F;W)M870@4&Y9;DUN1%1N2&Y-;E,*
M("`@(&9U;F-T:6]N('5N:7A?=&]?9'5R871I;VXH)'-E8V]N9',I('L*("`@
M("`@("!R971U<FX@4T]!4%]4>7!E7V1U<F%T:6]N.CIG971D=7)A=&EO;B@D
M<V5C;VYD<RD["B`@("!]"B`@("`*("`@(&9U;F-T:6]N(&UO9"@D82P@)&(L
M("8D9"P@)B1R*2!["B`@("`@("`@)&0@/2!F;&]O<B@@)&$@+R`D8B`I.PH@
M("`@("`@("1R(#T@)&$@)2`D8CL*("`@('T*("`@(`H@("`@9G5N8W1I;VX@
M9V5T9'5R871I;VXH)'-E8V]N9',I('L*("`@("`@("`D;F5G(#T@)R<["B`@
M("`@("`@:68@*"1S96-O;F1S(#P@,"D@>PH@("`@("`@("`@("`D;F5G(#T@
M)RTG.PH@("`@("`@("`@("`D<V5C;VYD<R`]("1S96-O;F1S("H@+3$["B`@
M("`@("`@?0H@("`@("`@(`H@("`@("`@("1?;6D@/2`V,#L*("`@("`@("`D
M7V@@/2`D7VUI("H@-C`["B`@("`@("`@)%]D(#T@)%]H("H@,C0["B`@("`@
M("`@+R\@6%A8(&AO=R!D;R!W92!P<F]P97)L>2!H86YD;&4@;6]N=&@@86YD
M('EE87(@=F%L=65S/PH@("`@("`@("1?;2`]("1?9"`J(#,P.PH@("`@("`@
M("1?>2`]("1?9"`J(#,V-3L*"B`@("`@("`@4T]!4%]4>7!E7V1U<F%T:6]N
M.CIM;V0H)'-E8V]N9',L("1?>2P@)'DL("1S96-O;F1S*3L*("`@("`@("!3
M3T%07U1Y<&5?9'5R871I;VXZ.FUO9"@D<V5C;VYD<RP@)%]M+"`D;2P@)'-E
M8V]N9',I.PH@("`@("`@(%-/05!?5'EP95]D=7)A=&EO;CHZ;6]D*"1S96-O
M;F1S+"`D7V0L("1D+"`D<V5C;VYD<RD["B`@("`@("`@4T]!4%]4>7!E7V1U
M<F%T:6]N.CIM;V0H)'-E8V]N9',L("1?:"P@)&@L("1S96-O;F1S*3L*("`@
M("`@("!33T%07U1Y<&5?9'5R871I;VXZ.FUO9"@D<V5C;VYD<RP@)%]M:2P@
M)&UI+"`D<RD["B`@("`@("`@"B`@("`@("`@)&1U<F%T:6]N(#T@)&YE9RXG
M4"<["B`@("`@("`@:68@*"1Y*2`D9'5R871I;VX@+CT@)'DN)UDG.PH@("`@
M("`@(&EF("@D;2D@)&1U<F%T:6]N("X]("1M+B=-)SL*("`@("`@("!I9B`H
M)&0I("1D=7)A=&EO;B`N/2`D9"XG1"<["B`@("`@("`@:68@*"1H('Q\("1M
M:2!\?"`D<RD@)&1U<F%T:6]N("X])U0G.PH@("`@("`@(&EF("@D:"D@)&1U
M<F%T:6]N("X]("1H+B=()SL*("`@("`@("!I9B`H)&UI*2`D9'5R871I;VX@
M+CT@)&UI+B=-)SL*("`@("`@("!I9B`H)',I("1D=7)A=&EO;B`N/2`D<RXG
M4R<["B`@("`@("`@:68@*"1D=7)A=&EO;B`]/2`G4"<@?'P@)&1U<F%T:6]N
M(#T]("<M4"<I("1D=7)A=&EO;B`]("=05#!3)SL*("`@("`@("!R971U<FX@
M)&1U<F%T:6]N.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!M:V1U<F%T:6]N
M*"1N+"`D62P@)$UO+"`D1"P@)$@L("1-:2P@)%,I('L*("`@("`@("`D7VUI
M(#T@-C`["B`@("`@("`@)%]H(#T@)%]M:2`J(#8P.PH@("`@("`@("1?9"`]
M("1?:"`J(#(T.PH@("`@("`@("\O(%A86"!H;W<@9&\@=V4@<')O<&5R;'D@
M:&%N9&QE(&UO;G1H(&%N9"!Y96%R('9A;'5E<S\*("`@("`@("`D7VT@/2`D
M7V0@*B`S,#L*("`@("`@("`D7WD@/2`D7V0@*B`S-C4["B`@("`@("`@"B`@
M("`@("`@)'-E8R`]("19("H@)%]Y("L@)$UO("H@)%]M("L@)$0@*B`D7V0@
M*R`D2"`J("1?:"`K("1-:2`J("1?;6D@*R`D4SL*("`@("`@("!I9B`H)&X@
M/3T@)RTG*2`D<V5C(#T@)'-E8R`J("TQ.PH@("`@("`@(')E='5R;B`D<V5C
M.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!D=7)A=&EO;E]T;U]U;FEX*"1D
M=7)A=&EO;BD@>PH@("`@("`@(&=L;V)A;"`D97)E9U]D=7)A=&EO;CL*("`@
M("`@("!I9B`H97)E9R@D97)E9U]D=7)A=&EO;BPD9'5R871I;VXL)')E9W,I
M*2!["B`@("`@("`@("`@(')E='5R;B!33T%07U1Y<&5?9'5R871I;VXZ.FUK
M9'5R871I;VXH)')E9W-;,5TL("1R96=S6S)=+"`D<F5G<ULS72P@)')E9W-;
M-%TL("1R96=S6S5=+"`D<F5G<ULV72P@)')E9W-;-UTI.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1D%,4T4["B`@("!]"B`@("`*("`@(&9U;F-T:6]N
M(&ES7V1U<F%T:6]N*"1D=7)A=&EO;BD@>PH@("`@("`@(&=L;V)A;"`D97)E
M9U]D=7)A=&EO;CL*("`@("`@("!R971U<FX@97)E9R@D97)E9U]D=7)A=&EO
M;BPD9'5R871I;VXL)')E9W,I.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!?
M=&5S="@D=&EM92D@>PH@("`@("`@(&EF("A33T%07U1Y<&5?9'5R871I;VXZ
M.FES7V1U<F%T:6]N*"1T:6UE*2D@>PH@("`@("`@("`@("`D="`](%-/05!?
M5'EP95]D=7)A=&EO;CHZ9'5R871I;VY?=&]?=6YI>"@D=&EM92D["B`@("`@
M("`@("`@(&5C:&\@(D1U<F%T:6]N.B`D=&EM92!I<R`B+B1T+B(@<V5C;VYD
M<UQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D="`](%-/05!?
M5'EP95]D=7)A=&EO;CHZ=6YI>%]T;U]D=7)A=&EO;B@D=&EM92D["B`@("`@
M("`@("`@(&5C:&\@(E-E8V]N9',Z("1T:6UE(&ES("(N)'0N(B!D=7)A=&EO
M;EQN(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T.PH@("`@?0H@("`@
M"B`@("!F=6YC=&EO;B!A9&0H)&0Q+"`D9#(I('L*("`@("`@("`D<S$@/2!3
M3T%07U1Y<&5?9'5R871I;VXZ.F1U<F%T:6]N7W1O7W5N:7@H)&0Q*3L*("`@
M("`@("`D<S(@/2!33T%07U1Y<&5?9'5R871I;VXZ.F1U<F%T:6]N7W1O7W5N
M:7@H)&0R*3L*("`@("`@("!R971U<FX@4T]!4%]4>7!E7V1U<F%T:6]N.CIU
M;FEX7W1O7V1U<F%T:6]N*"1S,2`K("1S,BD["B`@("!]"B`@("`*("`@(&9U
M;F-T:6]N('-U8G1R86-T*"1D,2P@)&0R*2!["B`@("`@("`@)',Q(#T@4T]!
M4%]4>7!E7V1U<F%T:6]N.CID=7)A=&EO;E]T;U]U;FEX*"1D,2D["B`@("`@
M("`@)',R(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CID=7)A=&EO;E]T;U]U;FEX
M*"1D,BD["B`@("`@("`@<F5T=7)N(%-/05!?5'EP95]D=7)A=&EO;CHZ=6YI
M>%]T;U]D=7)A=&EO;B@D<S$@+2`D<S(I.PH@("`@?0H*?0H*+RH@=&5S=',@
M*B\*"B1T(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@G4#%9,DTS1%0Q
M,$@S,$TG*3L*4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@D="D["B1T(#T@
M4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@G+5`Q,C!$)RD["E-/05!?5'EP
M95]D=7)A=&EO;CHZ7W1E<W0H)'0I.PH*+R\@9'5R871I;VX@<VEN8V4@,3DW
M,`HD="`](%-/05!?5'EP95]D=7)A=&EO;CHZ7W1E<W0H=&EM92@I*3L*4T]!
M4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@D="D["@IP<FEN="`B061D('-H;W5L
M9"!B92!05#!3.B`B+E-/05!?5'EP95]D=7)A=&EO;CHZ861D*"<M4#$R,$0G
M+"=0-$TG*2XB7&XB.PIP<FEN="`B4W5B=')A8W0@<VAO=6QD(&)E(%!4,%,Z
M("(N4T]!4%]4>7!E7V1U<F%T:6]N.CIS=6)T<F%C="@G4#$R,$0G+"=0-$TG
M*2XB7&XB.PH_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4>7!E+VAE>$)I;F%R>2YP:'``
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,U,#8`,3`T,3<S-C,P
M,#8`,#(Q-#<Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H
M86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R92`@('P*
M+R\@?"!!=71H;W)S.B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N
M8V]M/B!/<FEG:6YA;"!!=71H;W(@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&AE>$)I;F%R>2YP:'`L=B`Q
M+C0@,C`P,R\P,2\P-"`Q,3HU-CHR,"!M:B!%>'`@)`HO+PIC;&%S<R!33T%0
M7U1Y<&5?:&5X0FEN87)Y"GL*("`@(&9U;F-T:6]N('1O7V)I;B@D=F%L=64I
M"B`@("!["B`@("`@("`@)&QE;B`]('-T<FQE;B@D=F%L=64I.PH@("`@("`@
M(')E='5R;B!P86-K*"=()R`N("1L96XL("1V86QU92D["B`@("!]"B`@("!F
M=6YC=&EO;B!T;U]H97@H)'9A;'5E*0H@("`@>PH@("`@("`@(')E='5R;B!B
M:6XR:&5X*"1V86QU92D["B`@("!]"B`@("!F=6YC=&EO;B!I<U]H97AB:6XH
M)'9A;'5E*0H@("`@>PH@("`@("`@(",@9FER<W0@<V5E(&EF('1H97)E(&%R
M92!A;GD@:6YV86QI9"!C:&%R<PH@("`@("`@("1L(#T@<W1R;&5N*"1V86QU
M92D["@H@("`@("`@(&EF("@D;"`\(#$@?'P@<W1R<W!N*"1V86QU92P@)S`Q
M,C,T-38W.#E!0D-$149A8F-D968G*2`A/2`D;"D@<F5T=7)N($9!3%-%.PH*
M("`@("`@("`D8FEN(#T@4T]!4%]4>7!E7VAE>$)I;F%R>3HZ=&]?8FEN*"1V
M86QU92D["B`@("`@("`@)&AE>"`](%-/05!?5'EP95]H97A":6YA<GDZ.G1O
M7VAE>"@D8FEN*3L*("`@("`@("!R971U<FX@<W1R8V%S96-M<"@D=F%L=64L
M("1H97@I(#T](#`["B`@("!]"GT*"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U-/05`O=&]O;',O````````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`V`#`Q
M-S(T-0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]T;V]L<R]G
M96YP<F]X>2YP:'``````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V
M,C,`,3`T,3<S-C,P,#8`,#(Q-C(W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"F5R<F]R7W)E<&]R=&EN9RA%7T%,
M3"D["G)E<75I<F5?;VYC92`G4T]!4"]74T1,+G!H<"<["@HO*BH*("H@9V5N
M<')O>'D*("H*("H@82!C;VUM86YD(&QI;F4@=&]O;"!F;W(@9V5N97)A=&EN
M9R!33T%0('!R;WAI97,@9G)O;2!74T1,(&9I;&5S"B`J"B`J(&=E;G!R;WAY
M+G!H<"!H='1P.B\O<VET92]F;V\N=W-D;"`^(&9O;RYP:'`*("H*("HO"@IF
M=6YC=&EO;B!D;U]W<V1L*"1U<FDI('L*("`@("1W<V1L(#TF(&YE=R!33T%0
M7U=31$PH)'5R:2D["B`@("!P<FEN="`D=W-D;"T^9V5N97)A=&5!;&Q0<F]X
M:65S*"D["GT*96-H;R`B/#]P:'!<;EQN<F5Q=6ER95]O;F-E("=33T%0+T-L
M:65N="YP:'`G.UQN7&XB.PID;U]W<V1L*"1?4T525D526R=A<F=V)UU;,5TI
M.PIE8VAO(")<;C\^(CL*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O4V5R=F5R+P``````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S
M,#`V`#`Q-S,U,P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]3
M97)V97(O5$-0+G!H<```````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3`P-34`,3`T,3<S-C,P,#8`,#(P-3$P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z
M(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@
M4$5!4B!A;F0@;6]R92`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O"B\O("1)9#H@5$-0+G!H<"QV(#$N,2`R,#`S+S`T+S`X(#`V.C(Q
M.C4S('-H86YE($5X<"`D"B\O"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R
M+G!H<"<["B\J*@HJ("!33T%07U-E<G9E<E]40U`**B!33T%0(%-E<G9E<B!#
M;&%S<PHJ"BH@:6UP;&5M96YT<R!40U`@4T]!4"!397)V97(**B!H='1P.B\O
M=W=W+G!O8VME='-O87`N8V]M+W-P96-S+W-M='!B:6YD:6YG+PHJ"BH@8VQA
M<W,@;W9E<G)I9&5S('1H92!D969A=6QT($A45%`@<V5R=F5R+"!P<F]V:61I
M;F<@=&AE(&%B:6QI='D**B!T;R!A8V-E<'0@<V]C:V5T(&-O;FYE8W1I;VYS
M(&%N9"!E>&5C=71E('-O87`@8V%L;',N"BH**B!43T1/.@HJ("`@=7-E($YE
M=%]3;V-K970**B`@(&EM<&QE;65N="!S;VUE('-E8W5R:71Y('-C:&5M90HJ
M("`@:6UP;&5M96YT('-U<'!O<G0@9F]R(&%T=&%C:&UE;G1S"BH**B!`86-C
M97-S("`@<'5B;&EC"BH@0'9E<G-I;VX@("1)9#H@5$-0+G!H<"QV(#$N,2`R
M,#`S+S`T+S`X(#`V.C(Q.C4S('-H86YE($5X<"`D"BH@0'!A8VMA9V4@(%-/
M05`Z.E-E<G9E<@HJ($!A=71H;W(@("!3:&%N92!#87)A=F5O(#QS:&%N94!P
M:'`N;F5T/B`**B\*8VQA<W,@4T]!4%]397)V97)?5$-0(&5X=&5N9',@4T]!
M4%]397)V97(@>PH@("`@=F%R("1H96%D97)S(#T@87)R87DH*3L*("`@('9A
M<B`D;&]C86QA9&1R.PH@("`@=F%R("1P;W)T.PH@("`@=F%R("1L:7-T96X[
M"B`@("!V87(@)')E=7-E.PH@("`@"B`@("!F=6YC=&EO;B!33T%07U-E<G9E
M<E]40U`H)&QO8V%L861D<CTB,3(W+C`N,"XQ(BP@)'!O<G0],3`P,#`L("1L
M:7-T96X]-2P@)')E=7-E/512544I"B`@("!["B`@("`@("`@<&%R96YT.CI3
M3T%07U-E<G9E<B@I.PH@("`@("`@("1T:&ES+3YL;V-A;&%D9'(@/2`D;&]C
M86QA9&1R.PH@("`@("`@("1T:&ES+3YP;W)T(#T@)'!O<G0["B`@("`@("`@
M)'1H:7,M/FQI<W1E;B`]("1L:7-T96X["B`@("`@("`@)'1H:7,M/G)E=7-E
M(#T@)')E=7-E.PH@("`@?0H*("`@(&9U;F-T:6]N(')U;B@I"B`@("!["B`@
M("`@("`@:68@*"@D<V]C:R`]('-O8VME=%]C<F5A=&4@*$%&7TE.150L(%-/
M0TM?4U1214%-+"`P*2D@/"`P*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*")S;V-K971?8W)E871E*"D@9F%I;&5D.B!R
M96%S;VXZ("(@+B!S;V-K971?<W1R97)R;W(@*"1S;V-K*2D["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^<F5U<V4@)B8*("`@("`@("`@("`@(4!S
M;V-K971?<V5T;W!T*"1S;V-K+%-/3%]33T-+150L4T]?4D554T5!1$12+#$I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*")S;V-K971?<V5T;W!T*"D@9F%I;&5D.B!R96%S;VXZ("(N<V]C:V5T7W-T
M<F5R<F]R*'-O8VME=%]L87-T7V5R<F]R*"1S;V-K*2DI.PH@("`@("`@('T@
M("`@("`@(`H@("`@("`@(&EF("@H)')E="`]('-O8VME=%]B:6YD("@D<V]C
M:RP@)'1H:7,M/FQO8V%L861D<BP@)'1H:7,M/G!O<G0I*2`\(#`I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(G-O8VME
M=%]B:6YD*"D@9F%I;&5D.B!R96%S;VXZ("(@+B!S;V-K971?<W1R97)R;W(@
M*"1R970I*3L*("`@("`@("!]"B`@("`@("`@(R!P<FEN="`B3$E35$5.24Y'
M(&]N('LD=&AI<RT^;&]C86QA9&1R?3I[)'1H:7,M/G!O<G1]7&XB.PH@("`@
M("`@(&EF("@H)')E="`]('-O8VME=%]L:7-T96X@*"1S;V-K+"`D=&AI<RT^
M;&ES=&5N*2D@/"`P*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*")S;V-K971?;&ES=&5N*"D@9F%I;&5D.B!R96%S;VXZ
M("(@+B!S;V-K971?<W1R97)R;W(@*"1R970I*3L*("`@("`@("!]"B`@("`@
M("`@"B`@("`@("`@9&\@>PH@("`@("`@("`@("`D9&%T82`]($Y53$P["B`@
M("`@("`@("`@(&EF("@H)&US9W-O8VL@/2!S;V-K971?86-C97!T*"1S;V-K
M*2D@/"`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A
M=6QT*")S;V-K971?86-C97!T*"D@9F%I;&5D.B!R96%S;VXZ("(@+B!S;V-K
M971?<W1R97)R;W(@*"1M<V=S;V-K*2D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`C('!R:6YT(")!8V-E<'1E
M9"!C;VYN96-T:6]N7&XB.PH@("`@("`@("`@("!W:&EL92`H)&)U9B`]('-O
M8VME=%]R96%D("@D;7-G<V]C:RP@.#$Y,BDI('L*("`@("`@("`@("`@("`@
M(&EF("@A)&)U9B`]('1R:6TH)&)U9BDI('L*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1D871A("X]("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@
M("`@("`@("`@(&EF("@D9&%T82D@>PH@("`@("`@("`@("`@("`@)')E<W!O
M;G-E(#T@)'1H:7,M/G-E<G9I8V4H)&1A=&$I.PH@("`@("`@("`@("`@("`@
M(R!W<FET92!T;R!T:&4@<V]C:V5T"B`@("`@("`@("`@("`@("!I9B`H(7-O
M8VME=%]W<FET92@D;7-G<V]C:RP@)')E<W!O;G-E+"!S=')L96XH)')E<W!O
M;G-E*2DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R
M86ES95-O87!&875L="@G17)R;W(@<V5N9&EN9R!R97-P;VYS92!D871A(')E
M87-O;B`G+G-O8VME=%]S=')E<G)O<B@I*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`*("`@("`@("`@("`@<V]C:V5T
M7V-L;W-E("@D;7-G<V]C:RD["B`@("`@("`@?2!W:&EL92`H=')U92D["B`@
M("`@("`@"B`@("`@("`@<V]C:V5T7V-L;W-E("@D<V]C:RD["B`@("!]"B`@
M("`*("`@(&9U;F-T:6]N('-E<G9I8V4H)B1D871A*0H@("`@>PH@("`@("`@
M(",@6%A8('=E(&YE960@=&\@:&%N9&QE(&%T=&%C:&UE;G1S('-O;65H;W<*
M("`@("`@("!R971U<FX@)'1H:7,M/G!A<G-E4F5Q=65S="@D9&%T82PD871T
M86-H;65N=',I.PH@("`@?2`@("`*?0H*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U-E<G9E<B]%;6%I
M;%]'871E=V%Y+G!H<```````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S4S,@`Q
M,#0Q-S,V,S`P-@`P,C(U-S4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R
M879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M
M;W)E("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@
M)$ED.B!%;6%I;%]'871E=V%Y+G!H<"QV(#$N.2`R,#`S+S`U+S$X(#`P.C4W
M.C0P('-H86YE($5X<"`D"B\O"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R
M+T5M86EL+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]4<F%N<W!O<G0N<&AP
M)SL*"B\J*@HJ("!33T%07U-E<G9E<E]%;6%I;`HJ(%-/05`@4V5R=F5R($-L
M87-S"BH**B!I;7!L96UE;G1S($5M86EL(%-/05`@4V5R=F5R"BH@:'1T<#HO
M+W=W=RYP;V-K971S;V%P+F-O;2]S<&5C<R]S;71P8FEN9&EN9R\**@HJ(&-L
M87-S(&]V97)R:61E<R!T:&4@9&5F875L="!(5%10('-E<G9E<BP@<')O=FED
M:6YG('1H92!A8FEL:71Y"BH@=&\@<&%R<V4@86X@96UA:6P@;65S<V%G92!A
M;F0@97AE8W5T92!S;V%P(&-A;&QS+@HJ('1H:7,@8VQA<W,@1$]%4R!.3U0@
M<&]P('1H92!M97-S86=E+"!T:&4@;65S<V%G92P@8V]M<&QE=&4**B!W:71H
M(&AE861E<G,L(&UU<W0@8F4@<&%S<V5D(&EN(&%S(&$@<&%R86UE=&5R('1O
M('1H92!S97)V:6-E"BH@9G5N8W1I;VX@8V%L;`HJ"BH@5&AI<R!C;&%S<R!C
M86QL<R!A('!R;W9I9&5D($A45%`@4T]!4"!S97)V97(L(&9O<G=A<F1I;F<*
M*B!T:&4@96UA:6P@<F5Q=65S="P@=&AE;B!S96YD:6YG('1H92!(5%10(')E
M<W!O;G-E(&]U="!A<R!A;@HJ(&5M86EL"BH**B!`86-C97-S("`@<'5B;&EC
M"BH@0'9E<G-I;VX@("1)9#H@16UA:6Q?1V%T97=A>2YP:'`L=B`Q+CD@,C`P
M,R\P-2\Q."`P,#HU-SHT,"!S:&%N92!%>'`@)`HJ($!P86-K86=E("!33T%0
M.CI397)V97(**B!`875T:&]R("`@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP
M+FYE=#X@"BHO"F-L87-S(%-/05!?4V5R=F5R7T5M86EL7T=A=&5W87D@97AT
M96YD<R!33T%07U-E<G9E<E]%;6%I;`I["B`@("!V87(@)&=A=&5W87D@/2!.
M54Q,.PH@("`@=F%R("1D=6UP(#T@1D%,4T4["B`@("`*("`@(&9U;F-T:6]N
M(%-/05!?4V5R=F5R7T5M86EL7T=A=&5W87DH)&=A=&5W87D@/2`G)RP@)'-E
M;F1?<F5S<&]N<V4@/2!44E5%+"`D9'5M<#U&04Q312D*("`@('L*("`@("`@
M("!P87)E;G0Z.E-/05!?4V5R=F5R*"D["B`@("`@("`@)'1H:7,M/G-E;F1?
M<F5S<&]N<V4@/2`D<V5N9%]R97-P;VYS93L*("`@("`@("`D=&AI<RT^9V%T
M97=A>2`]("1G871E=V%Y.PH@("`@("`@("1T:&ES+3YD=6UP(#T@)&1U;7`[
M"B`@("!]"B`@("`*("`@(&9U;F-T:6]N('-E<G9I8V4H)B1D871A+"`D9V%T
M97=A>3TG)RP@)&5N9'!O:6YT(#T@)R<L("1S96YD7W)E<W!O;G-E(#T@5%)5
M12P@)&1U;7`@/2!&04Q312D*("`@('L*("`@("`@("`D=&AI<RT^96YD<&]I
M;G0@/2`D96YD<&]I;G0["B`@("`@("`@)')E<W!O;G-E(#T@)R<["B`@("`@
M("`@)'5S945N8V]D:6YG/2=-:6UE)SL*("`@("`@("`D;W!T:6]N<R`](&%R
M<F%Y*"D["B`@("`@("`@:68@*"$D9V%T97=A>2D@)&=A=&5W87D@/2`D=&AI
M<RT^9V%T97=A>3L*("`@("`@("`*("`@("`@("`O+R!W92!H879E(&$@9G5L
M;"!S970@;V8@:&5A9&5R<RP@;F5E9"!T;R!F:6YD('1H92!F:7)S="!B;&%N
M:R!L:6YE"B`@("`@("`@)'1H:7,M/E]P87)S945M86EL*"1D871A*3L*("`@
M("`@("!I9B`H)'1H:7,M/F9A=6QT*2!["B`@("`@("`@("`@("1R97-P;VYS
M92`]("1T:&ES+3YF875L="T^;65S<V%G92@I.PH@("`@("`@('T*("`@("`@
M("!I9B`H)'1H:7,M/FAE861E<G-;)V-O;G1E;G0M='EP92==/3TG87!P;&EC
M871I;VXO9&EM92<I"B`@("`@("`@("`@("1U<V5%;F-O9&EN9STG1$E-12<[
M"B`@("`@("`@"B`@("`@("`@(R!C86QL('1H92!(5%10(%-E<G9E<@H@("`@
M("`@(&EF("@A)')E<W!O;G-E*2!["B`@("`@("`@("`@("1S;V%P7W1R86YS
M<&]R="`])B!33T%07U1R86YS<&]R=#HZ9V5T5')A;G-P;W)T*"1G871E=V%Y
M+"`D=&AI<RT^>&UL7V5N8V]D:6YG*3L*("`@("`@("`@("`@:68@*"1S;V%P
M7W1R86YS<&]R="T^9F%U;'0I('L*("`@("`@("`@("`@("`@("1R97-P;VYS
M92`]("1S;V%P7W1R86YS<&]R="T^9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("`*("`@("`@("`O+R!S96YD('1H
M92!M97-S86=E"B`@("`@("`@:68@*"$D<F5S<&]N<V4I('L*("`@("`@("`@
M("`@)&]P=&EO;G-;)W-O87!A8W1I;VXG72`]("1T:&ES+3YH96%D97)S6R=S
M;V%P86-T:6]N)UT["B`@("`@("`@("`@("1O<'1I;VYS6R=H96%D97)S)UU;
M)T-O;G1E;G0M5'EP92==(#T@)'1H:7,M/FAE861E<G-;)V-O;G1E;G0M='EP
M92==.PH@("`@("`@("`@("`*("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O
M87!?=')A;G-P;W)T+3YS96YD*"1D871A+"`D;W!T:6]N<RD["B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^:&5A9&5R<ULG;6EM92UV97)S:6]N)UTI
M*0H@("`@("`@("`@("`@("`@)&]P=&EO;G-;)VAE861E<G,G75LG34E-12U6
M97)S:6]N)UT@/2`D=&AI<RT^:&5A9&5R<ULG;6EM92UV97)S:6]N)UT["B`@
M("`@("`@("`@(`H@("`@("`@("`@("!I9B`H)'-O87!?=')A;G-P;W)T+3YF
M875L="D@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?=')A
M;G-P;W)T+3YF875L="T^;65S<V%G92@I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'-O87!?=')A;G-P;W)T+3YT
M<F%N<W!O<G0M/F%T=&%C:&UE;G1S(&%S("1C:60]/B1B;V1Y*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F%T=&%C:&UE;G1S6UT@/2!A<G)A>2@G
M8F]D>2<@/3X@)&)O9'DL("=C:60G(#T^("1C:60L("=E;F-O9&EN9R<@/3X@
M)V)A<V4V-"<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1T:&ES+3Y?7V%T=&%C:&UE;G1S*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D=7-E16YC;V1I;F<@/3T@)TUI;64G*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1S;V%P7VUS9R`]("1T:&ES+3Y?;6%K94UI
M;65-97-S86=E*"1R97-P;VYS92D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1O<'1I;VYS6R=H96%D97)S)UU;)TU)344M5F5R<VEO;B==(#T@)S$N,"<[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@9&5F875L="!I<R!D:6UE"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S;V%P7VUS9R`]("1T:&ES+3Y?;6%K941)345-97-S86=E*"1R
M97-P;VYS92D["B`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS6R=H
M96%D97)S)UU;)T-O;G1E;G0M5'EP92==(#T@)V%P<&QI8V%T:6]N+V1I;64G
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<V]A<%]M<V<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1S;V%P
M7VUS9RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D<V]A<%]M<V<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7VUS9ULG8F]D>2==.PH@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'-O87!?;7-G6R=H96%D
M97)S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)VAE861E<G,G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;W!T:6]N<ULG:&5A9&5R<R==(#T@87)R87E?;65R
M9V4H)&]P=&EO;G-;)VAE861E<G,G72PD<V]A<%]M<V=;)VAE861E<G,G72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS6R=H96%D97)S)UT@
M/2`D<V]A<%]M<V=;)VAE861E<G,G73L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H)'1H:7,M/G-E;F1?<F5S
M<&]N<V4I('L@("`@("`@(`H@("`@("`@("`@("!I9B`H)'1H:7,M/F1U;7`@
M?'P@)&1U;7`I('L*("`@("`@("`@("`@("`@('!R:6YT("1R97-P;VYS93L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F<F]M(#T@
M87)R87E?:V5Y7V5X:7-T<R@G<F5P;'DM=&\G+"1T:&ES+3YH96%D97)S*2`_
M("1T:&ES+3YH96%D97)S6R=R97!L>2UT;R==.B1T:&ES+3YH96%D97)S6R=F
M<F]M)UT["B`@("`@("`@("`@("`@("`C(%A86"!W:&%T(&EF(&YO(&9R;VT_
M/S\_/PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`D<V]A<%]T
M<F%N<W!O<G0@/28@4T]!4%]4<F%N<W!O<G0Z.F=E=%1R86YS<&]R="@G;6%I
M;'1O.B<N)&9R;VTL("1T:&ES+3YR97-P;VYS95]E;F-O9&EN9RD["B`@("`@
M("`@("`@("`@("`D9G)O;2`]("1T:&ES+3YE;F1P;VEN="`_("1T:&ES+3YE
M;F1P;VEN="`Z("1T:&ES+3YH96%D97)S6R=T;R==.PH@("`@("`@("`@("`@
M("`@)&AE861E<G,@/2!A<G)A>2@G26XM4F5P;'DM5&\G/3XD=&AI<RT^:&5A
M9&5R<ULG;65S<V%G92UI9"==*3L*("`@("`@("`@("`@("`@("1O<'1I;VYS
M(#T@87)R87DH)V9R;VTG(#T^("1F<F]M+"`G<W5B:F5C="<]/B`D=&AI<RT^
M:&5A9&5R<ULG<W5B:F5C="==+"`G:&5A9&5R<R<@/3X@)&AE861E<G,I.PH@
M("`@("`@("`@("`@("`@)'-O87!?=')A;G-P;W)T+3YS96YD*"1R97-P;VYS
M92P@)&]P=&EO;G,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2`@
M("`*?0H*/SX`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O4V5R=F5R+T5M86EL+G!H
M<```````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P-3(S`#$P-#$W
M,S8S,#`V`#`R,3$Q,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O
M(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M($5M86EL+G!H<"QV(#$N,3`@,C`P,R\P-2\Q."`P,#HU-SHT,"!S:&%N92!%
M>'`@)`HO+PH*<F5Q=6ER95]O;F-E("=33T%0+U-E<G9E<BYP:'`G.PIR97%U
M:7)E7V]N8V4@)U-/05`O0VQI96YT+G!H<"<["G)E<75I<F5?;VYC92`G4T]!
M4"]4<F%N<W!O<G0N<&AP)SL*<F5Q=6ER95]O;F-E("=-86EL+VUI;65$96-O
M9&4N<&AP)SL*+RHJ"BH@(%-/05!?4V5R=F5R7T5M86EL"BH@4T]!4"!397)V
M97(@0VQA<W,**@HJ(&EM<&QE;65N=',@16UA:6P@4T]!4"!397)V97(**B!H
M='1P.B\O=W=W+G!O8VME='-O87`N8V]M+W-P96-S+W-M='!B:6YD:6YG+PHJ
M"BH@8VQA<W,@;W9E<G)I9&5S('1H92!D969A=6QT($A45%`@<V5R=F5R+"!P
M<F]V:61I;F<@=&AE(&%B:6QI='D**B!T;R!P87)S92!A;B!E;6%I;"!M97-S
M86=E(&%N9"!E>&5C=71E('-O87`@8V%L;',N"BH@=&AI<R!C;&%S<R!$3T53
M($Y/5"!P;W`@=&AE(&UE<W-A9V4L('1H92!M97-S86=E+"!C;VUP;&5T90HJ
M('=I=&@@:&5A9&5R<RP@;75S="!B92!P87-S960@:6X@87,@82!P87)A;65T
M97(@=&\@=&AE('-E<G9I8V4**B!F=6YC=&EO;B!C86QL"BH**B!`86-C97-S
M("`@<'5B;&EC"BH@0'9E<G-I;VX@("1)9#H@16UA:6PN<&AP+'8@,2XQ,"`R
M,#`S+S`U+S$X(#`P.C4W.C0P('-H86YE($5X<"`D"BH@0'!A8VMA9V4@(%-/
M05`Z.E-E<G9E<@HJ($!A=71H;W(@("!3:&%N92!#87)A=F5O(#QS:&%N94!P
M:'`N;F5T/B`**B\*8VQA<W,@4T]!4%]397)V97)?16UA:6P@97AT96YD<R!3
M3T%07U-E<G9E<B!["B`@("!V87(@)&AE861E<G,@/2!A<G)A>2@I.PH@("`@
M"B`@("!F=6YC=&EO;B!33T%07U-E<G9E<E]%;6%I;"@D<V5N9%]R97-P;VYS
M92`](%12544I"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07U-E<G9E<B@I
M.PH@("`@("`@("1T:&ES+3YS96YD7W)E<W!O;G-E(#T@)'-E;F1?<F5S<&]N
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`J(')E;6]V92!H='1P(&AE861E<G,@
M9G)O;2!R97-P;VYS90H@("`@*@H@("`@*B!43T1/.B!U<V4@4$5!4B!E;6%I
M;"!C;&%S<V5S"B`@("`J"B`@("`J($!R971U<FX@8F]O;&5A;@H@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5%;6%I
M;"@F)&1A=&$I"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>*"XJ
M/RE<<C]<;EQR/UQN*"XJ*2]S(BP@)&1A=&$L("1M871C:"DI('L*("`@("`@
M("`@("`@"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L;"@G+UXH+BH_
M*3I<<RLH+BHI)"]M)RP@)&UA=&-H6S%=+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@("`@("1H8R`](&-O=6YT*"1M871C:&5S6S!=*3L*("`@("`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H8SL@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YH96%D97)S6W-T<G1O;&]W97(H)&UA=&-H
M97-;,5U;)&E=*5T@/2!T<FEM*"1M871C:&5S6S)=6R1I72D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A<W1R
M:7-T<B@D=&AI<RT^:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTL)W1E>'0O>&UL
M)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A
M=6QT*"=);G9A;&ED($-O;G1E;G0@5'EP92<L)R<L)R<L)T-L:65N="<I.PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!&04Q313L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`*("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)'1H
M:7,M/FAE861E<G-;)V-O;G1E;G0M=')A;G-F97(M96YC;V1I;F<G72PG8F%S
M938T)RD]/3`I('L*("`@("`@("`@("`@("`@("\O(&IO:6X@;&EN97,@8F%C
M:R!T;V=E=&AE<@H@("`@("`@("`@("`@("`@)&5N8W1E>'0@/2!P<F5G7W)E
M<&QA8V4H(B];7')\7&Y=+R(L("<G+"`D;6%T8VA;,ETI.PH@("`@("`@("`@
M("`@("`@)&1A=&$@/2!B87-E-C1?9&5C;V1E*"1E;F-T97AT*3L*("`@("`@
M("`@("`@(WT@96QS92!I9B`H<W1R8V%S96-M<"@D=&AI<RT^:&5A9&5R<ULG
M8V]N=&5N="UT<F%N<V9E<BUE;F-O9&EN9R==+"=Q=6]T960M<')I;G1A8FQE
M)RD]/3`I('L*("`@("`@("`@("`@(R`@("`D9&%T82`]("1M871C:%LR73L*
M("`@("`@("`@("`@(WT@96QS92!["B`@("`@("`@("`@(",@("`@)'1H:7,M
M/E]R86ES95-O87!&875L="@G26YV86QI9"!#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG)RPG)RPG)RPG0VQI96YT)RD["B`@("`@("`@("`@(",@("`@<F5T
M=7)N($9!3%-%.PH@("`@("`@("`@("`C?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&1A=&$@/2`D;6%T8VA;,ET["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@"B`@("`@("`@("`@("\O(&EF(&YO(&-O;G1E
M;G0L(')E='5R;B!F86QS90H@("`@("`@("`@("!R971U<FX@<W1R;&5N*"1T
M:&ES+3YR97%U97-T*2`^(#`["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@16UA:6P@1F]R;6%T)RPG)RPG)RPG
M0VQI96YT)RD["B`@("`@("`@<F5T=7)N($9!3%-%.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&-L:65N="@F)&1A=&$I"B`@("!["B`@("`@("`@)&%T=&%C:&UE
M;G1S(#T@87)R87DH*3L*"B`@("`@("`@(R!I9B!N96ET:&5R(&UA=&-H97,L
M('=E)VQL(&IU<W0@=')Y(&ET(&%N>7=A>0H@("`@("`@(&EF("AS=')I<W1R
M*"1D871A+"=#;VYT96YT+51Y<&4Z(&%P<&QI8V%T:6]N+V1I;64G*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V1E8V]D941)345-97-S86=E*"1D871A+"1T
M:&ES+3YH96%D97)S+"1A='1A8VAM96YT<RD["B`@("`@("`@("`@("1U<V5%
M;F-O9&EN9R`]("=$24U%)SL*("`@("`@("!](&5L<V4@:68@*'-T<FES='(H
M)&1A=&$L)TU)344M5F5R<VEO;CHG*2D@>PH@("`@("`@("`@("`O+R!T:&ES
M(&ES(&$@;6EM92!M97-S86=E+"!L971S(&1E8V]D92!I="X*("`@("`@("`@
M("`@(R1D871A(#T@)T-O;G1E;G0M5'EP93H@)RYS=')I<'-L87-H97,H)%]3
M15)615);)T-/3E1%3E1?5%E012==*2XB7')<;EQR7&XB+B1D871A.PH@("`@
M("`@("`@("`D=&AI<RT^7V1E8V]D94UI;65-97-S86=E*"1D871A+"1T:&ES
M+3YH96%D97)S+"1A='1A8VAM96YT<RD["B`@("`@("`@("`@("1U<V5%;F-O
M9&EN9R`]("=-:6UE)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!T:&4@;VQD(&9A;&QB86-K+"!B=70@9&5C;V1E36EM94UE<W-A9V4@:&%N
M9&QE<R!T:&EN9W,@9FEN92X*("`@("`@("`@("`@)'1H:7,M/E]P87)S945M
M86EL*"1D871A*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@9V5T
M('1H92!C:&%R86-T97(@96YC;V1I;F<@;V8@=&AE(&EN8V]M:6YG(')E<75E
M<W0*("`@("`@("`O+R!T<F5A="!I;F-O;6EN9R!D871A(&%S(%541BTX(&EF
M(&YO(&5N8V]D:6YG('-E=`H@("`@("`@(&EF("@A)'1H:7,M/G-O87!F875L
M="`F)B`A)'1H:7,M/E]G971#;VYT96YT16YC;V1I;F<H)'1H:7,M/FAE861E
M<G-;)V-O;G1E;G0M='EP92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^>&UL
M7V5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.0T]$24Y'.PH@("`@("`@("`@
M("`O+R!A;B!E;F-O9&EN9R!W92!D;VXG="!U;F1E<G-T86YD+"!R971U<FX@
M82!F875L=`H@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=5
M;G-U<'!O<G1E9"!E;F-O9&EN9RP@=7-E(&]N92!O9B!)4T\M.#@U.2TQ+"!5
M4RU!4T-)22P@551&+3@G+"<G+"<G+"=397)V97(G*3L*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@:68@*"1T:&ES+3YS;V%P9F%U;'0I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YS;V%P9F%U;'0M/F=E=$9A=6QT*"D["B`@
M("`@("`@?0H@("`@("`@("1C;&EE;G0@/28@;F5W(%-/05!?0VQI96YT*$Y5
M3$PI.PH@("`@("`@(')E='5R;B`D8VQI96YT+3Y?7W!A<G-E*"1D871A+"`D
M=&AI<RT^>&UL7V5N8V]D:6YG+"`D=&AI<RT^871T86-H;65N=',I.PH@("`@
M?0H@("`@"B`@("!F=6YC=&EO;B!S97)V:6-E*"8D9&%T82P@)&5N9'!O:6YT
M(#T@)R<L("1S96YD7W)E<W!O;G-E(#T@5%)512P@)&1U;7`@/2!&04Q312D*
M("`@('L*("`@("`@("`D=&AI<RT^96YD<&]I;G0@/2`D96YD<&]I;G0["B`@
M("`@("`@)&%T=&%C:&UE;G1S(#T@87)R87DH*3L*("`@("`@("`D:&5A9&5R
M<R`](&%R<F%Y*"D["@H@("`@("`@(",@:68@;F5I=&AE<B!M871C:&5S+"!W
M92=L;"!J=7-T('1R>2!I="!A;GEW87D*("`@("`@("!I9B`H<W1R:7-T<B@D
M9&%T82PG0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]D:6UE)RDI('L*("`@
M("`@("`@("`@)'1H:7,M/E]D96-O9&5$24U%365S<V%G92@D9&%T82PD=&AI
M<RT^:&5A9&5R<RPD871T86-H;65N=',I.PH@("`@("`@("`@("`D=7-E16YC
M;V1I;F<@/2`G1$E-12<["B`@("`@("`@?2!E;'-E(&EF("AS=')I<W1R*"1D
M871A+"=-24U%+59E<G-I;VXZ)RDI('L*("`@("`@("`@("`@+R\@=&AI<R!I
M<R!A(&UI;64@;65S<V%G92P@;&5T<R!D96-O9&4@:70N"B`@("`@("`@("`@
M(",D9&%T82`]("=#;VYT96YT+51Y<&4Z("<N<W1R:7!S;&%S:&5S*"1?4T52
M5D526R=#3TY414Y47U194$4G72DN(EQR7&Y<<EQN(BXD9&%T83L*("`@("`@
M("`@("`@)'1H:7,M/E]D96-O9&5-:6UE365S<V%G92@D9&%T82PD=&AI<RT^
M:&5A9&5R<RPD871T86-H;65N=',I.PH@("`@("`@("`@("`D=7-E16YC;V1I
M;F<@/2`G36EM92<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M=&AE(&]L9"!F86QL8F%C:RP@8G5T(&1E8V]D94UI;65-97-S86=E(&AA;F1L
M97,@=&AI;F=S(&9I;F4N"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5%;6%I
M;"@D9&%T82D["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(&=E="!T
M:&4@8VAA<F%C=&5R(&5N8V]D:6YG(&]F('1H92!I;F-O;6EN9R!R97%U97-T
M"B`@("`@("`@+R\@=')E870@:6YC;VUI;F<@9&%T82!A<R!55$8M."!I9B!N
M;R!E;F-O9&EN9R!S970*("`@("`@("!I9B`H(21R97-P;VYS92`F)B`A)'1H
M:7,M/E]G971#;VYT96YT16YC;V1I;F<H)'1H:7,M/FAE861E<G-;)V-O;G1E
M;G0M='EP92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG
M(#T@4T]!4%]$149!54Q47T5.0T]$24Y'.PH@("`@("`@("`@("`O+R!A;B!E
M;F-O9&EN9R!W92!D;VXG="!U;F1E<G-T86YD+"!R971U<FX@82!F875L=`H@
M("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=5;G-U<'!O<G1E
M9"!E;F-O9&EN9RP@=7-E(&]N92!O9B!)4T\M.#@U.2TQ+"!54RU!4T-)22P@
M551&+3@G+"<G+"<G+"=397)V97(G*3L*("`@("`@("`@("`@)')E<W!O;G-E
M(#T@)'1H:7,M/F=E=$9A=6QT365S<V%G92@I.R`@("`@("`@("`@("`@("`*
M("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"1T:&ES+3YS;V%P9F%U
M;'0I('L*("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/G-O87!F875L
M="T^;65S<V%G92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S
M;V%P7VUS9R`]("1T:&ES+3YP87)S95)E<75E<W0H)&1A=&$L)&%T=&%C:&UE
M;G1S*3L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O(&AA;F1L92!-:6UE
M(&]R($1)344@96YC;V1I;F<*("`@("`@("`@("`@+R\@6%A8($1)344@16YC
M;V1I;F<@<VAO=6QD(&UO=F4@=&\@=&AE('1R86YS<&]R="P@9&\@:70@:&5R
M92!F;W(@;F]W"B`@("`@("`@("`@("\O(&%N9"!F;W(@96%S92!O9B!G971T
M:6YG(&ET(&1O;F4*("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?7V%T
M=&%C:&UE;G1S*2D@>PH@("`@("`@("`@("`@("`@:68@*"1U<V5%;F-O9&EN
M9R`]/2`G36EM92<I('L*("`@("`@("`@("`@("`@("`@("`D<V]A<%]M<V<@
M/2`D=&AI<RT^7VUA:V5-:6UE365S<V%G92@D<V]A<%]M<V<I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!D969A
M=6QT(&ES(&1I;64*("`@("`@("`@("`@("`@("`@("`D<V]A<%]M<V<@/2`D
M=&AI<RT^7VUA:V5$24U%365S<V%G92@D<V]A<%]M<V<I.PH@("`@("`@("`@
M("`@("`@("`@("1H96%D97);)T-O;G1E;G0M5'EP92==(#T@)V%P<&QI8V%T
M:6]N+V1I;64G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)'-O87!?;7-G*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V53;V%P1F%U;'0H)'-O87!?;7-G
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1S;V%P7VUS9RDI('L*("`@
M("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7VUS9ULG8F]D>2==.PH@
M("`@("`@("`@("`@("`@:68@*&-O=6YT*"1S;V%P7VUS9ULG:&5A9&5R<R==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1H96%D97)S(#T@)'-O87!?;7-G
M6R=H96%D97)S)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]M<V<[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^
M<V5N9%]R97-P;VYS92D@>R`@("`@("`@"B`@("`@("`@("`@(&EF("@D9'5M
M<"D@>PH@("`@("`@("`@("`@("`@<')I;G0@)')E<W!O;G-E.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9R;VT@/2!A<G)A>5]K
M97E?97AI<W1S*"=R97!L>2UT;R<L)'1H:7,M/FAE861E<G,I(#\@)'1H:7,M
M/FAE861E<G-;)W)E<&QY+71O)UTZ)'1H:7,M/FAE861E<G-;)V9R;VTG73L*
M("`@("`@("`@("`@("`@(",@6%A8('=H870@:68@;F\@9G)O;3\_/S\_"B`@
M("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("1S;V%P7W1R86YS<&]R
M="`])B!33T%07U1R86YS<&]R=#HZ9V5T5')A;G-P;W)T*"=M86EL=&\Z)RXD
M9G)O;2P@)'1H:7,M/G)E<W!O;G-E7V5N8V]D:6YG*3L*("`@("`@("`@("`@
M("`@("1F<F]M(#T@)'1H:7,M/F5N9'!O:6YT(#\@)'1H:7,M/F5N9'!O:6YT
M(#H@)'1H:7,M/FAE861E<G-;)W1O)UT["B`@("`@("`@("`@("`@("`D:&5A
M9&5R<ULG26XM4F5P;'DM5&\G73TD=&AI<RT^:&5A9&5R<ULG;65S<V%G92UI
M9"==.PH@("`@("`@("`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G9G)O;2<@
M/3X@)&9R;VTL("=S=6)J96-T)ST^("1T:&ES+3YH96%D97)S6R=S=6)J96-T
M)UTL("=H96%D97)S)R`]/B`D:&5A9&5R<RD["B`@("`@("`@("`@("`@("`D
M<V]A<%]T<F%N<W!O<G0M/G-E;F0H)')E<W!O;G-E+"`D;W!T:6]N<RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]("`@(`I]"@H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U-/05`O0VQI96YT+G!H<```````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4S,30U`#$P-#$W,S8S,#`V`#`R
M,#`T,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#
M87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4@("!\"B\O('P@
M075T:&]R<SH@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@
M3W)I9VEN86P@075T:&]R("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!#;&EE;G0N<&AP+'8@,2XV,B`R,#`S
M+S`X+S`V(#(P.C`X.C0U(&%R;F%U9"!%>'`@)`HO+PH*<F5Q=6ER95]O;F-E
M("=33T%0+U9A;'5E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]"87-E+G!H
M<"<["G)E<75I<F5?;VYC92`G4T]!4"]4<F%N<W!O<G0N<&AP)SL*<F5Q=6ER
M95]O;F-E("=33T%0+U=31$PN<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+T9A
M=6QT+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]087)S97(N<&AP)SL*"B\J
M*@H@*B`@4T]!4"!#;&EE;G0@0VQA<W,*("H@=&AI<R!C;&%S<R!I<R!T:&4@
M;6%I;B!I;G1E<F9A8V4@9F]R(&UA:VEN9R!S;V%P(')E<75E<W1S"B`J"B`J
M(&)A<VEC('5S86=E.@H@*B`@("1S;V%P8VQI96YT(#T@;F5W(%-/05!?0VQI
M96YT*"!S=')I;F<@<&%T:"!;("P@8F]O;&5A;B!W<V1L72`I.PH@*B`@(&5C
M:&\@)'-O87!C;&EE;G0M/F-A;&PH('-T<FEN9R!M971H;V1N86UE(%L@+"!A
M<G)A>2!P87)A;65T97)S72`I.PH@*@H@*B!O<FEG:6YA;'D@8F%S960@;VX@
M4T]!4'@T(&)Y($1I971R:6-H($%Y86QA(&AT='`Z+R]D:65T<FEC:"YG86YX
M-"YC;VTO<V]A<'@T"B`J"B`J($!A8V-E<W,@("!P=6)L:6,*("H@0'9E<G-I
M;VX@("1)9#H@0VQI96YT+G!H<"QV(#$N-C(@,C`P,R\P."\P-B`R,#HP.#HT
M-2!A<FYA=60@17AP("0*("H@0'!A8VMA9V4@(%-/05`Z.D-L:65N=`H@*B!`
M875T:&]R("`@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R
M<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@("!3=&EG($)A
M:VME;B`\<W-B0&9A<W0N;F\^($-O;G9E<G-I;VX@=&\@4$5!4@H@*B!`875T
M:&]R("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I
M9VEN86P@075T:&]R"B`J+PIC;&%S<R!33T%07T-L:65N="!E>'1E;F1S(%-/
M05!?0F%S90I["B`@("`O*BH*("`@("`J($-O;6UU;FEC871I;VX@96YD<&]I
M;G0N"B`@("`@*@H@("`@("H@0W5R<F5N=&QY('1H92!F;VQL;W=I;F<@=')A
M;G-P;W)T(&9O<FUA=',@87)E('-U<'!O<G1E9#H*("`@("`J("`M($A45%`*
M("`@("`J("`M(%--5%`*("`@("`J"B`@("`@*B!%>&%M<&QE(&5N9'!O:6YT
M<SH*("`@("`J("`@:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]S;V%P+W-E<G9E
M<BYP:'`*("`@("`J("`@:'1T<',Z+R]W=W<N97AA;7!L92YC;VTO<V]A<"]S
M97)V97(N<&AP"B`@("`@*B`@(&UA:6QT;SIS;V%P0&5X86UP;&4N8V]M"B`@
M("`@*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@*B!`<V5E("!33T%07T-L
M:65N="@I"B`@("`@*B\*("`@('9A<B`D7V5N9'!O:6YT(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!P;W)T;F%M90H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M(&-O;G1A:6YS('1H92!33T%0(%!/4E0@;F%M92!T:&%T(&ES('5S960@8GD@
M=&AE(&-L:65N=`H@("`@("HO"B`@("!V87(@)%]P;W)T3F%M92`]("<G.PH*
M"B`@("`O*BH*("`@("`J($5N9'!O:6YT('1Y<&4*("`@("`J"B`@("`@*B!`
M=F%R("!S=')I;F<@(&4N9RX@=V1S;`H@("`@("HO"B`@("!V87(@)%]?96YD
M<&]I;G14>7!E(#T@)R<["@H@("`@+RHJ"B`@("`@*B!W:7)E"B`@("`@*@H@
M("`@("H@0'9A<B`@<W1R:6YG("!C;VYT86EN<R!O=71O:6YG(&%N9"!I;F-O
M;6EN9R!D871A('-T<F5A;2!F;W(@9&5B=6=G:6YG+@H@("`@("HO"B`@("!V
M87(@)'AM;#L@+R\@8V]N=&%I;G,@=&AE(')E8V5I=F5D('AM;`H@("`@=F%R
M("1W:7)E.PH@("`@=F%R("1?7VQA<W1?<F5Q=65S="`](&YU;&P["B`@("!V
M87(@)%]?;&%S=%]R97-P;VYS92`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!/
M<'1I;VYS"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]?;W!T:6]N<R`](&%R<F%Y*"=T<F%C92<]/C`I.PH*("`@("\J*@H@
M("`@("H@96YC;V1I;F<*("`@("`J"B`@("`@*B!`=F%R("!S=')I;F<@($-O
M;G1A:6YS('1H92!C:&%R86-T97(@96YC;V1I;F<@=7-E9"!F;W(@6$U,('!A
M<G-E<BP@971C+@H@("`@("HO"B`@("!V87(@)%]E;F-O9&EN9R`](%-/05!?
M1$5&055,5%]%3D-/1$E.1SL*"@H@("`@+RHJ"B`@("`J(&AE861E<G-/=70*
M("`@("H*("`@("H@0'9A<B`@87)R87D@(&-O;G1A:6YS(&%N(&%R<F%Y(&]F
M(%-/05!?2&5A9&5R<R!T:&%T('=E(&%R92!S96YD:6YG"B`@("`J+PH@("`@
M=F%R("1H96%D97)S3W5T(#T@;G5L;#L*("`@("\J*@H@("`@*B!H96%D97)S
M3W5T"B`@("`J"B`@("`J($!V87(@(&%R<F%Y("!C;VYT86EN<R!A;B!A<G)A
M>2!H96%D97)S('=E(')E8VEE=F5D(&)A8VL@:6X@=&AE(')E<W!O;G-E"B`@
M("`J+PH@("`@=F%R("1H96%D97)S26X@/2!N=6QL.PH*("`@("\J*@H@("`@
M*B!?7W!R;WAY7W!A<F%M<PH@("`@*@H@("`@*B!`=F%R("!A<G)A>2`@8V]N
M=&%I;G,@;W!T:6]N<R!F;W(@2%144%]297%U97-T(&-L87-S("AS964@2%14
M4"]297%U97-T+G!H<"D*("`@("HO"B`@("!V87(@)%]?<')O>'E?<&%R86US
M(#T@87)R87DH*3L*"B`@("!V87(@)%]S;V%P7W1R86YS<&]R="`]($Y53$P[
M"B`@("`O*BH*("`@("`J(%-/05!?0VQI96YT(&-O;G-T<G5C=&]R"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R!E;F1P;VEN="`H55),*0H@("`@("H@
M0'!A<F%M(&)O;VQE86X@=W-D;"`H=')U92!I9B!E;F1P;VEN="!I<R!A('=S
M9&P@9FEL92D*("`@("`J($!P87)A;2!S=')I;F<@<&]R=$YA;64*("`@("`J
M($!P87)A;2!A<G)A>2`@8V]N=&%I;G,@;W!T:6]N<R!F;W(@2%144%]297%U
M97-T(&-L87-S("AS964@2%144"]297%U97-T+G!H<"D*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?0VQI96YT*"1E
M;F1P;VEN="P@)'=S9&P@/2!F86QS92P@)'!O<G1.86UE(#T@9F%L<V4L("1P
M<F]X>5]P87)A;7,]87)R87DH*2D*("`@('L*("`@("`@("!P87)E;G0Z.E-/
M05!?0F%S92@G0VQI96YT)RD["B`@("`@("`@)'1H:7,M/E]E;F1P;VEN="`]
M("1E;F1P;VEN=#L*("`@("`@("`D=&AI<RT^7W!O<G1.86UE(#T@)'!O<G1.
M86UE.PH@("`@("`@("1T:&ES+3Y?7W!R;WAY7W!A<F%M<R`]("1P<F]X>5]P
M87)A;7,["@H@("`@("`@("1W<V1L(#T@)'=S9&P_)'=S9&PZ<W1R8V%S96-M
M<"@G=W-D;"<L<W5B<W1R*"1E;F1P;VEN="QS=')L96XH)&5N9'!O:6YT*2TT
M*2D]/3`["@H@("`@("`@("\O(&UA:V4@=F%L=65S"B`@("`@("`@:68@*"1W
M<V1L*2!["B`@("`@("`@("`@("1T:&ES+3Y?7V5N9'!O:6YT5'EP92`]("=W
M<V1L)SL*("`@("`@("`@("`@+R\@:6YS=&%N=&EA=&4@=W-D;"!C;&%S<PH@
M("`@("`@("`@("`D=&AI<RT^7W=S9&P@/28@;F5W(%-/05!?5U-$3"@D=&AI
M<RT^7V5N9'!O:6YT+"`D=&AI<RT^7U]P<F]X>5]P87)A;7,I.PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]W<V1L+3YF875L="D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI<RT^7W=S9&PM/F9A=6QT
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!?<F5S970H*0H@("`@>PH@("`@("`@("1T:&ES+3YX;6P@/2!.54Q,.PH@
M("`@("`@("1T:&ES+3YW:7)E(#T@3E5,3#L*("`@("`@("`D=&AI<RT^7U]L
M87-T7W)E<75E<W0@/2!.54Q,.PH@("`@("`@("1T:&ES+3Y?7VQA<W1?<F5S
M<&]N<V4@/2!.54Q,.PH@("`@("`@("1T:&ES+3YH96%D97)S26X@/2!.54Q,
M.PH@("`@("`@("1T:&ES+3YH96%D97)S3W5T(#T@3E5,3#L*("`@('T*"B`@
M("`O*BH*("`@("`J('-E=$5N8V]D:6YG"B`@("`@*@H@("`@("H@<V5T('1H
M92!C:&%R86-T97(@96YC;V1I;F<L(&QI;6ET960@=&\@)U541BTX)RP@)U53
M7T%30TE))R!A;F0@)TE33RTX.#4Y+3$G"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R!E;F-O9&EN9PH@("`@("H@0')E='5R;B!M:7AE9"!R971U<FYS
M($Y53$P@;W(@4T]!4%]&875L=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T16YC;V1I;F<H)&5N8V]D:6YG*0H@("`@
M>PH@("`@("`@(&EF("AI;E]A<G)A>2@D96YC;V1I;F<L("1T:&ES+3Y?96YC
M;V1I;F=S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5N8V]D:6YG(#T@)&5N
M8V]D:6YG.PH@("`@("`@("`@("!R971U<FX@3E5,3#L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@
M16YC;V1I;F<G*3L*("`@('T*"B`@("`O*BH*("`@("`J(&%D9$AE861E<@H@
M("`@("H*("`@("`J(%1O(&%D9"!H96%D97)S('1O('1H92!E;G9E;&]P+"!Y
M;W4@=7-E('1H:7,@9G5N8W1I;VXL('-E;F1I;F<@:70@80H@("`@("H@4T]!
M4%](96%D97(@8VQA<W,@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(%-/05!?2&5A9&5R(&$@<V]A<"!V86QU92!T;R!S96YD(&%S(&$@:&5A9&5R
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A
M9&1(96%D97(H)B1S;V%P7W9A;'5E*0H@("`@>PH@("`@("`@(",@861D(&$@
M;F5W(&AE861E<B!T;R!T:&4@;65S<V%G90H@("`@("`@(&EF("AI<U]A*"1S
M;V%P7W9A;'5E+"=S;V%P7VAE861E<B<I*2!["B`@("`@("`@("`@("1T:&ES
M+3YH96%D97)S3W5T6UT@/28@)'-O87!?=F%L=64["B`@("`@("`@?2!E;'-E
M(&EF("AG971T>7!E*"1S;V%P7W9A;'5E*2`]/2`G87)R87DG*2!["B`@("`@
M("`@("`@("\O(&YA;64L('9A;'5E+"!N86UE<W!A8V4L(&UU<W1U;F1E<G-T
M86YD+"!A8W1O<@H@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<T]U=%M=(#TF
M(&YE=R!33T%07TAE861E<B@D<V]A<%]V86QU95LP72P@3E5,3"P@)'-O87!?
M=F%L=65;,5TL("1S;V%P7W9A;'5E6S)=+"`D<V]A<%]V86QU95LS72D[.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H(D1O;B=T('5N9&5R<W1A;F0@=&AE(&AE861E<B!I;F9O('EO=2!P
M<F]V:61E9"X@($UU<W0@8F4@87)R87D@;W(@4T]!4%](96%D97(N(BD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4T]!4%]#;&EE;G0Z.F-A
M;&P*("`@("`J"B`@("`@*B!T:&4@;F%M97-P86-E('!A<F%M971E<B!I<R!O
M=F5R;&]A9&5D('1O(&%C8V5P="!A;B!A<G)A>2!O9@H@("`@("H@;W!T:6]N
M<R!T:&%T(&-A;B!C;VYT86EN(&1A=&$@;F5C97-S87)Y(&9O<B!V87)I;W5S
M('1R86YS<&]R=',*("`@("`J(&EF(&ET(&ES('5S960@87,@86X@87)R87DL
M(&ET($U!62!C;VYT86EN(&$@;F%M97-P86-E('9A;'5E(&%N9"!A"B`@("`@
M*B!S;V%P86-T:6]N('9A;'5E+B`@268@:70@:7,@;W9E<FQO861E9"P@=&AE
M('-O87!A8W1I;VX@<&%R86UE=&5R(&ES"B`@("`@*B!I9VYO<F5D(&%N9"!-
M55-4(&)E('!L86-E9"!I;B!T:&4@;W!T:6]N<R!A<G)A>2X@(%1H:7,@:7,@
M9&]N90H@("`@("H@=&\@<')O=FED92!B86-K=V%R9',@8V]M<&%T:6)I;&ET
M>2!W:71H(&-U<G)E;G0@8VQI96YT<RP@8G5T"B`@("`@*B!M87D@8F4@<F5M
M;W9E9"!I;B!T:&4@9G5T=7)E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@;65T:&]D"B`@("`@*B!`<&%R86T@87)R87D@('!A<F%M<PH@("`@("H@
M0'!A<F%M(&%R<F%Y(&]P=&EO;G,@*&AA<V@@=VET:"!N86UE<W!A8V4L('-O
M87!A8W1I;VXL('1I;65O=70L(&9R;VTL('-U8FIE8W0L(&5T8RXI"B`@("`@
M*@H@("`@("H@5&AE(&]P=&EO;G,@<&%R86UE=&5R(&-A;B!H879E(&$@=F%R
M:65T>2!O9B!V86QU97,@861D960N("!4:&4@8W5R<F5N=&QY('-U<'!O<G1E
M9`H@("`@("H@=F%L=65S(&%R93H*("`@("`J("`@;F%M97-P86-E"B`@("`@
M*B`@('-O87!A8W1I;VX*("`@("`J("`@=&EM96]U="`H:'1T<"!S;V-K970@
M=&EM96]U="D*("`@("`J("`@9G)O;2`H<VUT<"D*("`@("`J("`@=')A;G-F
M97(M96YC;V1I;F<@*'-M='`L('-E=',@=&AE($-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<@:&5A9&5R*0H@("`@("H@("!S=6)J96-T("AS;71P+"!S=6)J
M96-T(&AE861E<BD*("`@("`J("`@:&5A9&5R<R`H<VUT<"P@87)R87DM:&%S
M:"!O9B!E>'1R82!S;71P(&AE861E<G,I"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2!O9B!R97-U;'1S"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B`F8V%L;"@D;65T:&]D+"`F)'!A<F%M<RP@)&YA
M;65S<&%C92`](&9A;'-E+"`D<V]A<$%C=&EO;B`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1T:&ES+3YH96%D97)S26X@/2!N=6QL.PH@("`@("`@("1T:&ES
M+3Y?7VQA<W1?<F5Q=65S="`](&YU;&P["B`@("`@("`@)'1H:7,M/E]?;&%S
M=%]R97-P;VYS92`](&YU;&P["B`@("`@("`@)'1H:7,M/G=I<F4@/2!N=6QL
M.PH@("`@("`@("1T:&ES+3YX;6P@/2!.54Q,.PH*("`@("`@("`D<V]A<%]D
M871A(#TF("1T:&ES+3Y?7V=E;F5R871E*"1M971H;V0L("1P87)A;7,L("1N
M86UE<W!A8V4L("1S;V%P06-T:6]N*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<V]A<%]D871A*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]R86ES95-O87!&875L="@D<V]A<%]D871A*3L*("`@("`@("!]"@H@("`@
M("`@("\O(%]?9V5N97)A=&4@;6%Y(&AA=F4@8VAA;F=E9"!T:&4@96YD<&]I
M;G0@:68@=&AE('=S9&P@:&%S(&UO<F4*("`@("`@("`O+R!T:&%N(&]N92!S
M97)V:6-E+"!S;R!W92!N965D('1O('-E92!I9B!W92!N965D('1O(&=E;F5R
M871E"B`@("`@("`@+R\@82!N97<@=')A;G-P;W)T('1O(&AO;VL@=&\@82!D
M:69F97)E;G0@55))+B`@4VEN8V4@=&AE('1R86YS<&]R=`H@("`@("`@("\O
M('!R;W1O8V]L(&-A;B!A;'-O(&-H86YG92P@=V4@;F5E9"!T;R!G970@86X@
M96YT:7)E;'D@;F5W(&]B:F5C="P*("`@("`@("`O+R!T:&]U9V@@=&AI<R!C
M;W5L9"!P<F]B86)L>2!B92!O<'1I;6EZ960N"B`@("`@("`@:68@*"$D=&AI
M<RT^7W-O87!?=')A;G-P;W)T('Q\("1T:&ES+3Y?96YD<&]I;G0@(3T@)'1H
M:7,M/E]S;V%P7W1R86YS<&]R="T^=7)L*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<V]A<%]T<F%N<W!O<G0@/28@4T]!4%]4<F%N<W!O<G0Z.F=E=%1R86YS
M<&]R="@D=&AI<RT^7V5N9'!O:6YT*3L*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)'1H:7,M/E]S;V%P7W1R86YS<&]R="DI('L*("`@("`@("`@
M("`@("`@("1F875L="`])B`D=&AI<RT^7W-O87!?=')A;G-P;W)T.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S;V%P7W1R86YS<&]R="`]($Y53$P["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D
M9F%U;'0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3Y?<V]A<%]T<F%N<W!O<G0M/F5N8V]D:6YG(#T@)'1H:7,M/E]E;F-O9&EN
M9SL*"B`@("`@("`@+R\@<V5N9"!T:&4@;65S<V%G90H@("`@("`@("1T<F%N
M<W!O<G1?;W!T:6]N<R`](&%R<F%Y7VUE<F=E7W)E8W5R<VEV92@D=&AI<RT^
M7U]P<F]X>5]P87)A;7,L("1T:&ES+3Y?7V]P=&EO;G,I.PH@("`@("`@("1T
M:&ES+3YX;6P@/28@)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^<V5N9"@D<V]A
M<%]D871A+"`D=')A;G-P;W)T7V]P=&EO;G,I.PH*("`@("`@("`O+R!S879E
M('1H92!W:7)E(&EN9F]R;6%T:6]N(&9O<B!D96)U9V=I;F<*("`@("`@("!I
M9B`H)'1H:7,M/E]?;W!T:6]N<ULG=')A8V4G72`^(#`I('L*("`@("`@("`@
M("`@)'1H:7,M/E]?;&%S=%]R97%U97-T(#TF("1T:&ES+3Y?<V]A<%]T<F%N
M<W!O<G0M/F]U=&=O:6YG7W!A>6QO860["B`@("`@("`@("`@("1T:&ES+3Y?
M7VQA<W1?<F5S<&]N<V4@/28@)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^:6YC
M;VUI;F=?<&%Y;&]A9#L*("`@("`@("`@("`@)'1H:7,M/G=I<F4@/28@)'1H
M:7,M/E]?9V5T7W=I<F4H*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3Y?<V]A<%]T<F%N<W!O<G0M/F9A=6QT*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1T:&ES+3YX;6PI.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]?871T86-H;65N=',@/28@)'1H:7,M/E]S
M;V%P7W1R86YS<&]R="T^871T86-H;65N=',["B`@("`@("`@)'1H:7,M/E]?
M<F5S=6QT7V5N8V]D:6YG(#T@)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^<F5S
M=6QT7V5N8V]D:6YG.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]?;W!T
M:6]N<ULG<F5S=6QT)UTI("8F("1T:&ES+3Y?7V]P=&EO;G-;)W)E<W5L="==
M("$]("=P87)S92<I(')E='5R;B`D=&AI<RT^>&UL.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/E]?<&%R<V4H)'1H:7,M/GAM;"P@)'1H:7,M/E]?<F5S=6QT
M7V5N8V]D:6YG+"1T:&ES+3Y?7V%T=&%C:&UE;G1S*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@;W!T:6]N('1O('5S92!W:71H('1H92!T<F%N<W!O
M<G1S(&QA>65R<RX*("`@("`J"B`@("`@*B!!;B!E>&%M<&QE(&]F('-U8V@@
M=7-E(&ES"B`@("`@*B`D<V]A<&-L:65N="T^<V5T3W!T*"=C=7)L)RP@0U52
M3$]05%]615)"3U-%+"`Q*0H@("`@("H@=&\@<&%S<R!A('-P96-I9FEC(&]P
M=&EO;B!T;R!W:&5N('5S:6YG(&%N(%-33"!C;VYN96-T:6]N+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@('-T<FEN9R`@
M)&-A=&5G;W)Y("!C871E9V]R>2!T;R!W:&EC:"!T:&4@;W!T:6]N(&%P<&QI
M97,*("`@("`J($!P87)A;2`@<W1R:6YG("`D;W!T:6]N("`@(&]P=&EO;B!N
M86UE"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)'9A;'5E("`@("!O<'1I;VX@
M=F%L=64*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971/<'0H)&-A=&5G;W)Y+"`D;W!T:6]N+"`D=F%L=64@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=F%L=64I*2!["B`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]?;W!T:6]N<ULD8V%T96=O<GE=*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULD8V%T96=O<GE=
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M7U]O<'1I;VYS6R1C871E9V]R>5U;)&]P=&EO;ET@/2`D=F%L=64["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULD8V%T
M96=O<GE=(#T@)&]P=&EO;CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!33T%07T-L:65N=#HZ7U]C86QL"B`@("`@*@H@("`@("H@3W9E<FQO
M860@97AT96YS:6]N('-U<'!O<G0*("`@("`J(&EF('1H92!O=F5R;&]A9"!E
M>'1E;G-I;VX@:7,@;&]A9&5D+"!Y;W4@8V%N(&-A;&P@=&AE(&-L:65N="!C
M;&%S<PH@("`@("H@=VET:"!A('-O87`@;65T:&]D(&YA;64*("`@("`J("1S
M;V%P(#T@;F5W(%-/05!?0VQI96YT*"XN+BXI.PH@("`@("H@)'9A;'5E(#T@
M)'-O87`M/F=E=%-T;V-K475O=&4H)TU31E0G*3L*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&UE=&AO9`H@("`@("H@0'!A<F%M(&%R<F%Y("!A<F=S
M"B`@("`@*B!`<&%R86T@<W1R:6YG(')E='5R7W9A;'5E"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B`F7U]C86QL*"1M971H;V0L("8D87)G<RP@)B1R
M971U<FY?=F%L=64I"B`@("!["B`@("`@("`@+R\@6%A8(&]V97)L;V%D:6YG
M(&QO=V5R8V%S97,@=&AE(&UE=&AO9"!N86UE+"!W90H@("`@("`@("\O(&YE
M960@=&\@;&]O:R!I;G1O('1H92!W<V1L(&%N9"!T<GD@=&\@9FEN9`H@("`@
M("`@("\O('1H92!C;W)R96-T(&UE=&AO9"!N86UE('1O(&=E="!T:&4@8V]R
M<F5C=`H@("`@("`@("\O(&-A<V4@9F]R('1H92!C86QL+@H@("`@("`@(&EF
M("@D=&AI<RT^7W=S9&PI"B`@("`@("`@("`@("1T:&ES+3Y?=W-D;"T^;6%T
M8VA-971H;V0H)&UE=&AO9"D["@H@("`@("`@("1R971U<FY?=F%L=64@/28@
M)'1H:7,M/F-A;&PH)&UE=&AO9"P@)&%R9W,I.PH@("`@("`@(')E='5R;B!4
M4E5%.PH@("`@?0H*("`@(&9U;F-T:6]N("9?7V=E=&QA<W1R97%U97-T*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]?;&%S=%]R97%U97-T.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9?7V=E=&QA<W1R97-P;VYS92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?7VQA<W1?<F5S<&]N<V4["B`@("!]
M"@H@("`@9G5N8W1I;VX@7U]U<V4H)'5S92D*("`@('L*("`@("`@("`D=&AI
M<RT^7U]O<'1I;VYS6R=U<V4G72`]("1U<V4["B`@("!]"@H@("`@9G5N8W1I
M;VX@7U]S='EL92@D<W1Y;&4I"B`@("!["B`@("`@("`@)'1H:7,M/E]?;W!T
M:6]N<ULG<W1Y;&4G72`]("1S='EL93L*("`@('T*"B`@("!F=6YC=&EO;B!?
M7W1R86-E*"1L979E;"D*("`@('L*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS
M6R=T<F%C92==(#T@)&QE=F5L.PH@("`@?0H*("`@(&9U;F-T:6]N("9?7V=E
M;F5R871E*"1M971H;V0L("8D<&%R86US+"`D;F%M97-P86-E(#T@9F%L<V4L
M("1S;V%P06-T:6]N(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/F9A
M=6QT(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=I;G!U="==
M/2=P87)S92<["B`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<F5S=6QT)UT]
M)W!A<G-E)SL*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=P87)A;65T97)S
M)UT@/2!F86QS93L*("`@("`@("!I9B`H)'!A<F%M<R`F)B!G971T>7!E*"1P
M87)A;7,I("$]("=A<G)A>2<I('L*("`@("`@("`@("`@)'!A<F%M<R`](&%R
M<F%Y*"1P87)A;7,I.PH@("`@("`@('T*("`@("`@("!I9B`H9V5T='EP92@D
M;F%M97-P86-E*2`]/2`G87)R87DG*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1N86UE<W!A8V4@87,@)&]P=&YA;64]/B1O<'0I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?7V]P=&EO;G-;<W1R=&]L;W=E<B@D;W!T;F%M92E=/21O
M<'0["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?7V]P=&EO;G-;)VYA;65S<&%C92==*2D@)&YA;65S<&%C92`]("1T:&ES
M+3Y?7V]P=&EO;G-;)VYA;65S<&%C92==.PH@("`@("`@("`@("!E;'-E("1N
M86UE<W!A8V4@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O+R!W92=L;"!P;&%C92!S;V%P86-T:6]N(&EN=&\@;W5R(&%R<F%Y(&9O
M<B!U<V%G92!I;B!T:&4@=')A;G-P;W)T"B`@("`@("`@("`@("1T:&ES+3Y?
M7V]P=&EO;G-;)W-O87!A8W1I;VXG72`]("1S;V%P06-T:6]N.PH@("`@("`@
M("`@("`D=&AI<RT^7U]O<'1I;VYS6R=N86UE<W!A8V4G72`]("1N86UE<W!A
M8V4["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]?96YD<&]I;G14
M>7!E(#T]("=W<V1L)RD@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=%-C:&5M
M859E<G-I;VXH)'1H:7,M/E]W<V1L+3YX<V0I.PH@("`@("`@("`@("`O+R!G
M970@<&]R=$YA;64*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W!O<G1.86UE
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!O<G1.86UE(#T@)'1H:7,M
M/E]W<V1L+3YG9710;W)T3F%M92@D;65T:&]D*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7W!O<G1.86UE
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H)'1H:7,M/E]P;W)T3F%M92D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\O(&=E="!E;F1P;VEN=`H@("`@("`@("`@("`D=&AI<RT^7V5N
M9'!O:6YT(#T@)'1H:7,M/E]W<V1L+3YG971%;F1P;VEN="@D=&AI<RT^7W!O
M<G1.86UE*3L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1H:7,M
M/E]E;F1P;VEN="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"1T:&ES+3Y?96YD<&]I;G0I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O+R!G970@;W!E<F%T:6]N(&1A=&$*("`@("`@
M("`@("`@)&]P1&%T82`]("1T:&ES+3Y?=W-D;"T^9V5T3W!E<F%T:6]N1&%T
M82@D=&AI<RT^7W!O<G1.86UE+"`D;65T:&]D*3L*"B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1O<$1A=&$I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D;W!$871A*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D;F%M97-P86-E(#T@)&]P1&%T85LG;F%M
M97-P86-E)UT["B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE
M)UT@/2`D;W!$871A6R=S='EL92==.PH@("`@("`@("`@("`D=&AI<RT^7U]O
M<'1I;VYS6R=U<V4G72`]("1O<$1A=&%;)VEN<'5T)UU;)W5S92==.PH@("`@
M("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S;V%P86-T:6]N)UT@/2`D;W!$
M871A6R=S;V%P06-T:6]N)UT["@H@("`@("`@("`@("`O+R!S970@:6YP=70@
M<&%R86US"B`@("`@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=I;G!U
M="==(#T]("=P87)S92<I('L*("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N
M<ULG<&%R86UE=&5R<R==(#T@)&]P1&%T85LG<&%R86UE=&5R<R==.PH@("`@
M("`@("`@("`D;G!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("AI
M<W-E="@D;W!$871A6R=I;G!U="==6R=P87)T<R==*2`F)B!C;W5N="@D;W!$
M871A6R=I;G!U="==6R=P87)T<R==*2`^(#`I('L*("`@("`@("`@("`@("`@
M("1I(#T@,#L*("`@("`@("`@("`@("`@(')E<V5T*"1P87)A;7,I.PH@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&]P1&%T85LG:6YP=70G75LG<&%R=',G
M72!A<R`D;F%M92`]/B`D<&%R="D@>PH@("`@("`@("`@("`@("`@("`@("1X
M;6QN<R`]("<G.PH@("`@("`@("`@("`@("`@("`@("1A='1R<R`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("`@("`@+R\@:7,@=&AE(&YA;64@86-T=6%L
M;'D@82!C;VUP;&5X('1Y<&4_"B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1P87)T6R=E;&5M96YT)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1X;6QN<R`]("1T:&ES+3Y?=W-D;"T^;F%M97-P86-E<ULD<&%R=%LG
M;F%M97-P86-E)UU=.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%R="`]
M("1T:&ES+3Y?=W-D;"T^96QE;65N='-;)'!A<G1;)VYA;65S<&%C92==75LD
M<&%R=%LG='EP92==73L*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@
M/2`D<&%R=%LG;F%M92==.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D;F%M92PD<&%R
M86US*2!\?`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W=S9&PM
M/F=E=$1A=&%(86YD;&5R*"1N86UE+"1P87)T6R=N86UE<W!A8V4G72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&YP87)A;7-;)&YA;65=(#TF("1P
M87)A;7-;)&YA;65=.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@(",@=V4@;F]W(&9O<F-E(&%N(&%S<V]C
M:6%T:79E(&%R<F%Y(&9O<B!P87)A;65T97)S(&EF('5S:6YG('=S9&P*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H(E1H92!N86UE9"!P87)A;65T97(@)&YA;64@:7,@;F]T(&EN('1H
M92!C86QL('!A<F%M971E<G,N(BD["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&EF("AG971T>7!E*"1N<&%R86US6R1N86UE
M72D@(3T@)V]B:F5C="<@?'P*("`@("`@("`@("`@("`@("`@("`@("`@(6ES
M7V$H)&YP87)A;7-;)&YA;65=+"=S;V%P7W9A;'5E)RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@='EP92!I<R!A('%N86UE(&QI:V5L>2P@<W!L
M:70@:70@87!A<G0L(&%N9"!G970@=&AE('1Y<&4@;F%M97-P86-E(&9R;VT@
M=W-D;`H@("`@("`@("`@("`@("`@("`@("`@("`D<6YA;64@/28@;F5W(%%.
M86UE*"1P87)T6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)'%N86UE+3YN<RD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M>7!E7VYA;65S<&%C92`]("1T:&ES+3Y?=W-D;"T^;F%M97-P86-E<ULD<6YA
M;64M/FYS73L*("`@("`@("`@("`@("`@("`@("`@("`@96QS92!I9B`H:7-S
M970H)'!A<G1;)VYA;65S<&%C92==*2D*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T>7!E7VYA;65S<&%C92`]("1T:&ES+3Y?=W-D;"T^;F%M97-P
M86-E<ULD<&%R=%LG;F%M97-P86-E)UU=.PH@("`@("`@("`@("`@("`@("`@
M("`@("!E;'-E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D='EP95]N
M86UE<W!A8V4@/2!.54Q,.PH@("`@("`@("`@("`@("`@("`@("`@("`D<6YA
M;64M/FYA;65S<&%C92`]("1T>7!E7VYA;65S<&%C93L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1Y<&4@/2`D<6YA;64M/FYA;64["B`@("`@("`@("`@
M("`@("`@("`@("`@("1P<6YA;64@/2`D;F%M93L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1X;6QN<RD@)'!Q;F%M92`]("=[)RXD>&UL;G,N)WTG
M+B1N86UE.PH@("`@("`@("`@("`@("`@("`@("`@("`D;G!A<F%M<ULD;F%M
M95T@/28@;F5W(%-/05!?5F%L=64H)'!Q;F%M92P@)'%N86UE+3YF<6XH*2P@
M)&YP87)A;7-;)&YA;65=+"1A='1R<RD["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@=W-D;"!F:7AU
M<',@=&\@=&AE('-O87`@=F%L=64*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!A
M<F%M<R`])B`D;G!A<F%M<SL*("`@("`@("`@("`@=6YS970H)&YP87)A;7,I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]S97138VAE;6%697)S:6]N*%-/05!?6$U,7U-#2$5-05]615)3
M24].*3L*("`@("`@("!]"@H@("`@("`@("\O('-E<FEA;&EZ92!T:&4@;65S
M<V%G90H@("`@("`@("1T:&ES+3Y?<V5C=&EO;C4@/2!44E5%.R`O+R!A<W-U
M;64@=V4@96YC;V1E('=I=&@@<V5C=&EO;B`U"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?7V]P=&EO;G-;)W5S92==*2`F)B`D=&AI<RT^7U]O<'1I;VYS
M6R=U<V4G73T])VQI=&5R86PG*2`D=&AI<RT^7W-E8W1I;VXU(#T@1D%,4T4[
M"@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]?;W!T:6]N<ULG<W1Y;&4G
M72D@?'P@)'1H:7,M/E]?;W!T:6]N<ULG<W1Y;&4G72`]/2`G<G!C)RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T@)W)P8R<[
M"B`@("`@("`@("`@("1T:&ES+3YD;V-P87)A;7,@/2!T<G5E.PH@("`@("`@
M("`@("`D;7%N86UE(#TF(&YE=R!13F%M92@D;65T:&]D+"`D;F%M97-P86-E
M*3L*("`@("`@("`@("`@)&UE=&AO9%9A;'5E(#TF(&YE=R!33T%07U9A;'5E
M*"1M<6YA;64M/F9Q;B@I+"`G4W1R=6-T)RP@)'!A<F%M<RD["B`@("`@("`@
M("`@("1S;V%P7VUS9R`])B`D=&AI<RT^7VUA:V5%;G9E;&]P92@D;65T:&]D
M5F%L=64L("1T:&ES+3YH96%D97)S3W5T+"`D=&AI<RT^7V5N8V]D:6YG+"1T
M:&ES+3Y?7V]P=&EO;G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&EF("@A)'!A<F%M<RD@>PH@("`@("`@("`@("`@("`@)&UQ;F%M92`])B!N
M97<@44YA;64H)&UE=&AO9"P@)&YA;65S<&%C92D["B`@("`@("`@("`@("`@
M("`D;7EN=6QL(#T@3E5,3#L*("`@("`@("`@("`@("`@("1P87)A;7,@/28@
M;F5W(%-/05!?5F%L=64H)&UQ;F%M92T^9G%N*"DL("=3=')U8W0G+"`D;7EN
M=6QL*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?7V]P=&EO;G-;
M)VEN<'5T)UT@/3T@)W!A<G-E)RD@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("`@("`@("`@)&YP87)A
M;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("1K97ES(#T@87)R
M87E?:V5Y<R@D<&%R86US*3L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D:V5Y<R!A<R`D:RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M9V5T='EP92@D<&%R86US6R1K72D@(3T@)V]B:F5C="<I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N<&%R86US6UT@/28@;F5W(%-/05!?5F%L
M=64H)&LL(&9A;'-E+"`D<&%R86US6R1K72D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;G!A<F%M<UM=(#TF("1P87)A;7-;)&M=.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("1P87)A;7,@/28@)&YP87)A;7,["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]?;W!T:6]N<ULG<&%R86UE=&5R
M<R==*2!["B`@("`@("`@("`@("`@("`@("`@)&UQ;F%M92`])B!N97<@44YA
M;64H)&UE=&AO9"P@)&YA;65S<&%C92D["B`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M<R`])B!N97<@4T]!4%]686QU92@D;7%N86UE+3YF<6XH*2P@)U-T
M<G5C="<L("1P87)A;7,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1S;V%P7VUS9R`])B`D=&AI<RT^7VUA:V5%;G9E
M;&]P92@D<&%R86US+"`D=&AI<RT^:&5A9&5R<T]U="P@)'1H:7,M/E]E;F-O
M9&EN9RPD=&AI<RT^7U]O<'1I;VYS*3L*("`@("`@("!]"B`@("`@("`@=6YS
M970H)'1H:7,M/FAE861E<G-/=70I.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<V]A<%]M<V<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"1S;V%P7VUS9RD["B`@("`@("`@?0H*("`@("`@
M("`O+R!H86YD;&4@36EM92!O<B!$24U%(&5N8V]D:6YG"B`@("`@("`@+R\@
M6%A8($1)344@16YC;V1I;F<@<VAO=6QD(&UO=F4@=&\@=&AE('1R86YS<&]R
M="P@9&\@:70@:&5R92!F;W(@;F]W"B`@("`@("`@+R\@86YD(&9O<B!E87-E
M(&]F(&=E='1I;F<@:70@9&]N90H@("`@("`@(&EF("AC;W5N="@D=&AI<RT^
M7U]A='1A8VAM96YT<RDI('L*("`@("`@("`@("`@:68@*"AI<W-E="@D=&AI
M<RT^7U]O<'1I;VYS6R=A='1A8VAM96YT<R==*2`F)B`D=&AI<RT^7U]O<'1I
M;VYS6R=A='1A8VAM96YT<R==(#T]("=-:6UE)RD@?'P@:7-S970H)'1H:7,M
M/E]?;W!T:6]N<ULG36EM92==*2D@>PH@("`@("`@("`@("`@("`@)'-O87!?
M;7-G(#TF("1T:&ES+3Y?;6%K94UI;65-97-S86=E*"1S;V%P7VUS9RP@)'1H
M:7,M/E]E;F-O9&EN9RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`O+R!D969A=6QT(&ES(&1I;64*("`@("`@("`@("`@("`@("1S
M;V%P7VUS9R`])B`D=&AI<RT^7VUA:V5$24U%365S<V%G92@D<V]A<%]M<V<L
M("1T:&ES+3Y?96YC;V1I;F<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]?
M;W!T:6]N<ULG:&5A9&5R<R==6R=#;VYT96YT+51Y<&4G72`]("=A<'!L:6-A
M=&EO;B]D:6UE)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D<V]A<%]M<V<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D<V]A<%]M<V<I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!I;G-T86YT:6%T92!C;&EE
M;G0*("`@("`@("!I9B`H:7-?87)R87DH)'-O87!?;7-G*2D@>PH@("`@("`@
M("`@("`D<V]A<%]D871A(#TF("1S;V%P7VUS9ULG8F]D>2==.PH@("`@("`@
M("`@("!I9B`H8V]U;G0H)'-O87!?;7-G6R=H96%D97)S)UTI*2!["B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]?;W!T:6]N<ULG:&5A9&5R
M<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;
M)VAE861E<G,G72`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?7V]P=&EO;G-;)VAE
M861E<G,G72PD<V]A<%]M<V=;)VAE861E<G,G72D["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO
M;G-;)VAE861E<G,G72`]("1S;V%P7VUS9ULG:&5A9&5R<R==.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'-O87!?9&%T82`])B`D<V]A<%]M<V<["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D<V]A<%]D871A.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9?7W!A<G-E*"8D<F5S<&]N<V4L("1E;F-O9&EN9RP@)B1A='1A8VAM96YT
M<RD*("`@('L*("`@("`@("`O+R!P87)S92!T:&4@<F5S<&]N<V4*("`@("`@
M("`D<F5S<&]N<V4@/28@;F5W(%-/05!?4&%R<V5R*"1R97-P;VYS92P@)&5N
M8V]D:6YG+"`D871T86-H;65N=',I.PH@("`@("`@(&EF("@D<F5S<&]N<V4M
M/F9A=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*"1R97-P;VYS92T^9F%U;'0I.PH@("`@("`@('T*("`@("`@("`O
M+R!R971U<FX@87)R87D@;V8@<&%R86UE=&5R<PH@("`@("`@("1R971U<FX@
M/28@)')E<W!O;G-E+3YG971297-P;VYS92@I.PH@("`@("`@("1H96%D97)S
M(#TF("1R97-P;VYS92T^9V5T2&5A9&5R<R@I.PH@("`@("`@(&EF("@D:&5A
M9&5R<RD@>PH@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<TEN(#TF("1T:&ES
M+3Y?7V1E8V]D95)E<W!O;G-E*"1H96%D97)S+&9A;'-E*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?7V1E8V]D95)E<W!O;G-E*"1R971U
M<FXI.PH@("`@?0H*("`@(&9U;F-T:6]N("9?7V1E8V]D95)E<W!O;G-E*"8D
M<F5S<&]N<V4L)'-H:69T/71R=64I"B`@("!["B`@("`@("`@:68@*"$D<F5S
M<&]N<V4I(')E='5R;B!.54Q,.PH@("`@("`@("\O(&-H96-K(&9O<B!V86QI
M9"!R97-P;VYS90H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97-P;VYS
M92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H)')E<W!O;G-E*3L*("`@("`@("!](&5L<V4@:68@*"%I<U]A*"1R97-P
M;VYS92PG<V]A<%]V86QU92<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*")D:61N)W0@9V5T(%-/05!?5F%L=64@;V)J
M96-T(&)A8VL@9G)O;2!C;&EE;G0B*3L*("`@("`@("!]"@H@("`@("`@("\O
M(&1E8V]D92!T;R!N871I=F4@<&AP(&1A=&%T>7!E"B`@("`@("`@)')E='5R
M;D%R<F%Y(#TF("1T:&ES+3Y?9&5C;V1E*"1R97-P;VYS92D["B`@("`@("`@
M+R\@9F%U;'0_"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E='5R;D%R
M<F%Y*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&
M875L="@D<F5T=7)N07)R87DI.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?
M;V)J96-T*"1R971U<FY!<G)A>2D@)B8@<W1R8V%S96-M<"AG971?8VQA<W,H
M)')E='5R;D%R<F%Y*2PG<W1D0VQA<W,G*3T],"D@>PH@("`@("`@("`@("`D
M<F5T=7)N07)R87D@/2!G971?;V)J96-T7W9A<G,H)')E='5R;D%R<F%Y*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R971U<FY!<G)A>2DI
M('L*("`@("`@("`@("`@:68@*&ES<V5T*"1R971U<FY!<G)A>5LG9F%U;'1C
M;V1E)UTI('Q\(&ES<V5T*"1R971U<FY!<G)A>5LG4T]!4"U%3E8Z9F%U;'1C
M;V1E)UTI*2!["B`@("`@("`@("`@("`@("`D9F%U;'1C;V1E(#T@)&9A=6QT
M<W1R:6YG(#T@)&9A=6QT9&5T86EL(#T@)&9A=6QT86-T;W(@/2`G)SL*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1R971U<FY!<G)A>2!A<R`D:R`]/B`D
M=BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1K+"=F875L
M=&-O9&4G*2D@)&9A=6QT8V]D92`]("1V.PH@("`@("`@("`@("`@("`@("`@
M(&EF("AS=')I<W1R*"1K+"=F875L='-T<FEN9R<I*2`D9F%U;'1S=')I;F<@
M/2`D=CL*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T<B@D:RPG9&5T
M86EL)RDI("1F875L=&1E=&%I;"`]("1V.PH@("`@("`@("`@("`@("`@("`@
M(&EF("AS=')I<W1R*"1K+"=F875L=&%C=&]R)RDI("1F875L=&%C=&]R(#T@
M)'8["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]R86ES95-O87!&875L="@D9F%U;'1S=')I;F<L("1F875L=&1E
M=&%I;"P@)&9A=6QT86-T;W(L("1F875L=&-O9&4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("\O(')E='5R;B!A<G)A>2!O9B!R971U<FX@=F%L=65S
M"B`@("`@("`@("`@(&EF("@D<VAI9G0@)B8@8V]U;G0H)')E='5R;D%R<F%Y
M*2`]/2`Q*2!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87E?<VAI9G0H
M)')E='5R;D%R<F%Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@)')E='5R;D%R<F%Y.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E
M='5R;D%R<F%Y.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?9V5T7W=I<F4H*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=T<F%C92==(#X@
M,"`F)B`H)'1H:7,M/E]?;&%S=%]R97%U97-T('Q\("1T:&ES+3Y?7VQA<W1?
M<F5S<&]N<V4I*2!["B`@("`@("`@("`@(')E='5R;B`B3U541T])3D<Z7&Y<
M;B(N"B`@("`@("`@("`@("1T:&ES+3Y?7VQA<W1?<F5Q=65S="X*("`@("`@
M("`@("`@(EQN7&Y)3D-/34E.1UQN7&XB+@H@("`@("`@("`@("!P<F5G7W)E
M<&QA8V4H(B\^/"\B+"(^7')<;CPB+"1T:&ES+3Y?7VQA<W1?<F5S<&]N<V4I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@3E5,3#L*("`@('T*?0H*(VEF
M("AE>'1E;G-I;VY?;&]A9&5D*"=O=F5R;&]A9"<I*2!["B,@("`@;W9E<FQO
M860H)U-/05!?0VQI96YT)RD["B-]"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U-/05`O0F%S92YP:'``````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3$T,#`V`#$P-#$W,S8S,#`V`#`Q
M-S0V-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#
M87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4@("!\"B\O('P@
M075T:&]R<SH@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@
M3W)I9VEN86P@075T:&]R("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!"87-E+G!H<"QV(#$N-#`N,BXT(#(P
M,#0O,#$O,3<@,30Z,C(Z-3@@87)N875D($5X<"`D"B\O"@HO*@H@("!33T%0
M7T]"2D5#5%]35%)50U0@;6%K97,@<&5A<CHZ<V]A<"!U<V4@;V)J96-T<R!F
M;W(@<V]A<"!S=')U8W1U<F5S"B`@(')A=&AE<B!T:&%N(&%R<F%Y<RX@(%1H
M:7,@:&%S(&)E96X@9&]N92!T;R!P<F]V:61E(&$@8VQO<V5R(&UA=&-H('1O
M('!H<"US;V%P+@H@("!)9B!T:&4@;VQD(&)E:&%V:6]U<B!I<R!N965D960L
M('-E="!T;R!F86QS92X@(%1H92!O;&0@8F5H879I;W5R(&ES(&1E<')I8V%T
M960N"BHO"B1'3$]"04Q36R=33T%07T]"2D5#5%]35%)50U0G72`](%12544[
M"B\J"B`@(%-/05!?4D%77T-/3E9%4E0@;6%K97,@<&5A<CHZ<V]A<"!A='1E
M;7!T('1O(&1E=&5R;6EN92!W:&%T(%-/05`@='EP90H@("!A('!H<"!S=')I
M;F<@0T]53$0@8F4N("!4:&ES(&UA>2!R97-U;'0@:6X@<VQI9VAT;'D@8F5T
M=&5R(&EN=&5R;W!E<F%B:6QI='D@=VAE;@H@("!Y;W4@87)E(&YO="!U<VEN
M9R!74T1,+"!A;F0@87)E(&)E:6YG(&QA>GD@86YD(&YO="!U<VEN9R!33T%0
M7U9A;'5E('1O(&1E9FEN90H@("!T>7!E<R!F;W(@>6]U<B!V86QU97,N"BHO
M"B1'3$]"04Q36R=33T%07U)!5U]#3TY615)4)UT@/2!&04Q313L*"G)E<75I
M<F5?;VYC92`G4$5!4BYP:'`G.PHC<F5Q=6ER95]O;F-E("=33T%0+T9A=6QT
M+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]4>7!E+V1A=&54:6UE+G!H<"<[
M"G)E<75I<F5?;VYC92`G4T]!4"]4>7!E+VAE>$)I;F%R>2YP:'`G.PH*+R\@
M;W!T:6]N86P@9F5A='5R97,*)$=,3T)!3%-;)U-/05!?;W!T:6]N<R==(#T@
M87)R87DH*3L*"D!I;F-L=61E7V]N8V4@)TUA:6PO;6EM95!A<G0N<&AP)SL*
M0&EN8VQU9&5?;VYC92`G36%I;"]M:6UE1&5C;V1E+G!H<"<["FEF("AC;&%S
M<U]E>&ES=',H)TUA:6Q?;6EM95!A<G0G*2D@>PH@("`@)$=,3T)!3%-;)U-/
M05!?;W!T:6]N<R==6R=-:6UE)UT@/2`Q.PH@("`@9&5F:6YE*"=-04E,7TU)
M345005)47T-23$8G+")<<EQN(BD["GT*"D!I;F-L=61E7V]N8V4@)TYE="]$
M24U%+G!H<"<["FEF("AC;&%S<U]E>&ES=',H)TYE=%]$24U%7TUE<W-A9V4G
M*2D@>PH@("`@)$=,3T)!3%-;)U-/05!?;W!T:6]N<R==6R=$24U%)UT@/2`Q
M.PI]"@HO*BH**B!%;F%B;&4@9&5B=6=G:6YG(&EN9F]R;6%T:6]N<S\**@HJ
M($!C;VYS="`@("!33T%07T1%0E5'"BHO"B1'3$]"04Q36R=33T%07T1%0E5'
M)UT]9F%L<V4["@II9B`H(69U;F-T:6]N7V5X:7-T<R@G=F5R<VEO;E]C;VUP
M87)E)RD@?'P*("`@('9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<T
M+C$G+"`G/"<I*2!["B`@("!D:64H(G)E<75I<F5S(%!(4"`T+C$@;W(@:&EG
M:&5R7&XB*3L*?0II9B`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@
M)S0N,2<L("<^/2<I("8F"B`@("!V97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO
M;B@I+"`G-"XR)RP@)SPG*2D@>PH@("`@9&5F:6YE*"=&3$]!5"<L("=D;W5B
M;&4G*3L*?2!E;'-E('L*("`@(&1E9FEN92@G1DQ/050G+"`G9FQO870G*3L*
M?0H*(R!F;W(@9FQO870@<W5P<&]R=`HC(&ES('1H97)E(&$@=V%Y('1O(&-A
M;&-U;&%T92!)3D8@9F]R('1H92!P;&%T9F]R;3\*9&5F:6YE*"=)3D8G+"`@
M(#$N.&4S,#<I.PID969I;F4H)TY!3B<L("`@,"XP*3L*"F1E9FEN92@G4T]!
M4%],24)205)97U9%4E-)3TXG+"`G,"XX+C!20S(G*3L*9&5F:6YE*"=33T%0
M7TQ)0E)!4EE?3D%-12<L("`@("=014%2+5-/05`@,"XX+C!20S(M9&5V96PG
M*3L*"B\O('-E="!S8VAE;6$@=F5R<VEO;@ID969I;F4H)U-/05!?6$U,7U-#
M2$5-05]615)324].)RP@("`G:'1T<#HO+W=W=RYW,RYO<F<O,C`P,2]834Q3
M8VAE;6$G*3L*9&5F:6YE*"=33T%07UA-3%]30TA%34%?24Y35$%.0T4G+"`@
M)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E)RD[
M"F1E9FEN92@G4T]!4%]834Q?4T-(14U!7S$Y.3DG+"`@("`@("=H='1P.B\O
M=W=W+G<S+F]R9R\Q.3DY+UA-3%-C:&5M82<I.PID969I;F4H)U-/05!?4T-(
M14U!)RP@("`@("`@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO
M<F<O=W-D;"]S;V%P+R<I.PID969I;F4H)U-/05!?4T-(14U!7T5.0T]$24Y'
M)RP@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E;F-O
M9&EN9R\G*3L*9&5F:6YE*"=33T%07T5.5D5,3U`G+"`@("`@("`@("`@("`@
M)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YV96QO<&4O)RD[
M"@ID969I;F4H)U-#2$5-05]$25-#3R<L("`@("`@("`@("`@("`G:'1T<#HO
M+W-C:&5M87,N>&UL<V]A<"YO<F<O9&ES8V\O)RD["F1E9FEN92@G4T-(14U!
M7T1)4T-/7U-#3"<L("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P
M+F]R9R]D:7-C;R]S8VPO)RD["@ID969I;F4H)U-#2$5-05]33T%0)RP@("`@
M("`@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O=W-D;"]S
M;V%P+R<I.PID969I;F4H)U-#2$5-05]33T%07TA45%`G+"`@("`@("`@("`G
M:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]H='1P)RD["F1E9FEN
M92@G4T-(14U!7U=31$Q?2%144"<L("`@("`@("`@("=H='1P.B\O<V-H96UA
M<RYX;6QS;V%P+F]R9R]W<V1L+VAT='`O)RD["F1E9FEN92@G4T-(14U!7TU)
M344G+"`@("`@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R
M9R]W<V1L+VUI;64O)RD["F1E9FEN92@G4T-(14U!7U=31$PG+"`@("`@("`@
M("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W<V1L+R<I.PID
M969I;F4H)U-#2$5-05]$24U%)RP@("`@("`@("`@("`@("`G:'1T<#HO+W-C
M:&5M87,N>&UL<V]A<"YO<F<O=W,O,C`P,B\P-"]D:6UE+W=S9&PO)RD["F1E
M9FEN92@G4T-(14U!7T-/3E1%3E0G+"`@("`@("`@("`@("=H='1P.B\O<V-H
M96UA<RYX;6QS;V%P+F]R9R]W<R\R,#`R+S`T+V-O;G1E;G0M='EP92\G*3L*
M9&5F:6YE*"=30TA%34%?4D5&)RP@("`@("`@("`@("`@("`@)VAT='`Z+R]S
M8VAE;6%S+GAM;'-O87`N;W)G+W=S+S(P,#(O,#0O<F5F97)E;F-E+R<I.PH*
M9&5F:6YE*"=33T%07T1%1D%53%1?14Y#3T1)3D<G+"`@)U541BTX)RD["@II
M9B`H(69U;F-T:6]N7V5X:7-T<R@G:7-?82<I*0I["B`@(&9U;F-T:6]N(&ES
M7V$H)B1O8FIE8W0L("1C;&%S<U]N86UE*0H@("!["B`@("`@("!I9B`H<W1R
M=&]L;W=E<BAG971?8VQA<W,H)&]B:F5C="DI(#T]("1C;&%S<U]N86UE*2!R
M971U<FX@5%)513L*("`@("`@(&5L<V4@<F5T=7)N(&ES7W-U8F-L87-S7V]F
M*"1O8FIE8W0L("1C;&%S<U]N86UE*3L*("`@?0I]"@II9B`H(6-L87-S7V5X
M:7-T<R@G<W1D0VQA<W,G*2D@>PH@("`@+RH@4$A0-2!D;V5S;B=T(&1E9FEN
M92!T:&ES/R`J+PH@("`@8VQA<W,@<W1D0VQA<W,@>PH@("`@("`@(&9U;F-T
M:6]N(%]?8V]N<W1R=6-T;W(H*2![?0H@("`@?3L*?0H*8VQA<W,@4T]!4%]"
M87-E7T]B:F5C="!E>'1E;F1S(%!%05(*>PH@("`@+RHJ"B`@("`J(%-T;W)E
M(&1E8G5G9VEN9R!I;F9O<FUA=&EO;B!I;B`D9&5B=6=?9&%T83\*("`@("H*
M("`@("H@0'9A<B`@8F]O;&5A;B!I9B!T<G5E(&1E8G5G9VEN9R!I;F9O<FUA
M=&EO;G,@=VEL;"!B92!S=&]R92!I;B`D9&5B=6=?9&%T80H@("`@*B!`<V5E
M("`D9&5B=6=?9&%T82P@4T]!4%]"87-E"B`@("`J+PH@("`@=F%R("1?9&5B
M=6=?9FQA9R`](&9A;'-E.PH*("`@("\J*@H@("`@*B!3=')I;F<@8V]N=&%I
M;FEN9R!D96)U9V=I;F<@:6YF;W)M871I;VYS(&EF("1D96)U9U]F;&%G(&ES
M('-E="!T;R!T<G5E"B`@("`J"B`@("`J($!V87(@("`@("!S=')I;F<@(&1E
M8G5G9VEN9R!I;F9O<FUA=&EO;G,@+2!M;W-T>6P@97)R;W(@;65S<V%G97,*
M("`@("H@0'-E92`@("`@("1D96)U9U]F;&%G+"!33T%07T)A<V4*("`@("H@
M0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@('9A<B`D7V1E8G5G7V1A=&$@
M/2`G)SL*"B`@("`C('-U<'!O<G1E9"!E;F-O9&EN9W,L(&QI;6ET960@8GD@
M6$U,(&5X=&5N<VEO;@H@("`@=F%R("1?96YC;V1I;F=S(#T@87)R87DH)TE3
M3RTX.#4Y+3$G+"=54RU!4T-)22<L)U541BTX)RD["B`@("`O*BH*("`@("H@
M1F%U;'0@8V]D90H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@
M("!V87(@)%]M>69A=6QT8V]D92`]("<G.PH*("`@("\J*@H@("`@*B!296-E
M;G0@4$5!4B!E<G)O<B!O8FIE8W0*("`@("H*("`@("H@0'9A<B`@;V)J96-T
M("!014%2($5R<F]R"B`@("`J+PH@("`@=F%R("1F875L="`]($Y53$P["@H@
M("`@+RHJ"B`@("`J($-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&5R<F]R(&-O9&4*("`@("H@0'-E92`@)&1E8G5G7V1A=&$L
M(%]D96)U9R@I"B`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]"87-E7T]B:F5C
M="@D9F%U;'1C;V1E(#T@)T-L:65N="<I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]M>69A=6QT8V]D92`]("1F875L=&-O9&4["B`@("`@("`@)'1H:7,M/E]D
M96)U9U]F;&%G(#T@)$=,3T)!3%-;)U-/05!?1$5"54<G73L*("`@("`@("!P
M87)E;G0Z.E!%05(H)U-/05!?1F%U;'0G*3L*("`@('T*"B`@("`O*BH*("`@
M("H@4F%I<V4@82!S;V%P(&5R<F]R"B`@("`J"B`@("`J(%!L96%S92!R969E
M<G(@=&\@=&AE(%-/05`@9&5F:6YI=&EO;B!F;W(@86X@:6UP<F5S<VEO;B!O
M9B!W:&%T(&$@8V5R=&%I;B!P87)A;65T97(*("`@("H@<W1A;F1S(&9O<BX*
M("`@("H*("`@("H@57-E("1D96)U9U]F;&%G('1O('-T;W)E(&5R<F]R<R!T
M;R!T:&4@;65M8F5R('9A<FEA8FQE("1D96)U9U]D871A"B`@("`J"B`@("`J
M($!P87)A;2`@("!S=')I;F<@(&5R<F]R(&UE<W-A9V4*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@9&5T86EL960@97)R;W(@;65S<V%G92X*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@86-T;W(*("`@("H@0'!A<F%M("`@(&UI>&5D"B`@
M("`J($!P87)A;2`@("!M:7AE9`H@("`@*B!`<&%R86T@("`@;6EX960*("`@
M("H@0'!A<F%M("`@(&)O;VQE86X*("`@("H@0'-E92`@("`@("1D96)U9U]F
M;&%G+"`D9&5B=6=?9&%T80H@("`@*B\*("`@(&9U;F-T:6]N("9?<F%I<V53
M;V%P1F%U;'0H)'-T<BP@)&1E=&%I;"`]("<G+"`D86-T;W)54DD@/2`G)RP@
M)&-O9&4@/2!N=6QL+"`D;6]D92`](&YU;&PL("1O<'1I;VYS(#T@;G5L;"P@
M)'-K:7!M<V<@/2!F86QS92D*("`@('L*("`@("`@("`C('!A<W,@=&AR;W5G
M:"!P<F5V:6]U<R!F875L=',*("`@("`@("`D:7-?:6YS=&%N8V4@/2!I<W-E
M="@D=&AI<RD["B`@("`@("`@:68@*&ES7V]B:F5C="@D<W1R*2D@>PH@("`@
M("`@("`@("`D9F%U;'0@/28@)'-T<CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H(21C;V1E*2`D8V]D92`]("1I<U]I;G-T86YC93\D=&AI
M<RT^7VUY9F%U;'1C;V1E.B=#;&EE;G0G.PH@("`@("`@("`@("`D9F%U;'0@
M/28@;F5W(%-/05!?1F%U;'0H)'-T<BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O9&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A8W1O<E5222P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E=&%I;"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UO9&4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O
M<'1I;VYS*3L*("`@("`@("!]"B`@("`@("`@:68@*"1I<U]I;G-T86YC92D@
M)'1H:7,M/F9A=6QT(#TF("1F875L=#L*("`@("`@("!R971U<FX@)&9A=6QT
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?:7-F875L="@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YF875L="`A/2!.54Q,.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9?7V=E=&9A=6QT*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/F9A=6QT.PH@("`@?0H*("`@("\J*@H@("`@*B!M86EN=&%I;G,@82!S
M=')I;F<@;V8@9&5B=6<@9&%T80H@("`@*@H@("`@*B!`<&%R86T@("`@9&5B
M=6=G:6YG(&UE<W-A9V4@+2!S;VUE=&EM97,@86X@97)R;W(@;65S<V%G90H@
M("`@*B\*("`@(&9U;F-T:6]N(%]D96)U9R@D<W1R:6YG*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^7V1E8G5G7V9L86<I('L*("`@("`@("`@("`@)'1H
M:7,M/E]D96)U9U]D871A("X](&=E=%]C;&%S<R@D=&AI<RD@+B`G.B`G("X@
M<')E9U]R97!L86-E*"(O/B\B+"`B/EQR7&XB+"`D<W1R:6YG*2`N(")<;B([
M"B`@("`@("`@?0H@("`@?0I]"@HO*BH**B`@4T]!4%]"87-E"BH@0V]M;6]N
M(&)A<V4@8VQA<W,@;V8@86QL(%-O87`@;&-L87-S97,**@HJ($!A8V-E<W,@
M("!P=6)L:6,**B!`=F5R<VEO;B`@)$ED.B!"87-E+G!H<"QV(#$N-#`N,BXT
M(#(P,#0O,#$O,3<@,30Z,C(Z-3@@87)N875D($5X<"`D"BH@0'!A8VMA9V4@
M(%-/05`Z.D-L:65N=`HJ($!A=71H;W(@("!3:&%N92!#87)A=F5O(#QS:&%N
M94!P:'`N;F5T/B!#;VYV97)S:6]N('1O(%!%05(@86YD('5P9&%T97,**B\*
M8VQA<W,@4T]!4%]"87-E(&5X=&5N9',@4T]!4%]"87-E7T]B:F5C=`I["B`@
M("!V87(@)%]834Q38VAE;6$@/2!A<G)A>2@G:'1T<#HO+W=W=RYW,RYO<F<O
M,C`P,2]834Q38VAE;6$G+"`G:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]834Q3
M8VAE;6$G*3L*("`@('9A<B`D7UA-3%-C:&5M859E<G-I;VX@/2`G:'1T<#HO
M+W=W=RYW,RYO<F<O,C`P,2]834Q38VAE;6$G.PH*("`@("\O(&QO860@='EP
M97,@:6YT;R!T>7!E;6%P(&%R<F%Y"B`@("!V87(@)%]T>7!E;6%P(#T@87)R
M87DH"B`@("`@("`@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W-T<FEN9R<@/3X@)W-T<FEN9R<L
M"B`@("`@("`@("`@("=B;V]L96%N)R`]/B`G8F]O;&5A;B<L"B`@("`@("`@
M("`@("=F;&]A="<@/3X@1DQ/050L"B`@("`@("`@("`@("=D;W5B;&4G(#T^
M($9,3T%4+`H@("`@("`@("`@("`G9&5C:6UA;"<@/3X@1DQ/050L"B`@("`@
M("`@("`@("=D=7)A=&EO;B<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G
M9&%T951I;64G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G=&EM92<@/3X@
M)W-T<FEN9R<L"B`@("`@("`@("`@("=D871E)R`]/B`G<W1R:6YG)RP*("`@
M("`@("`@("`@)V=996%R36]N=&@G(#T^("=I;G1E9V5R)RP*("`@("`@("`@
M("`@)V=996%R)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=G36]N=&A$
M87DG(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V=$87DG(#T^("=I;G1E
M9V5R)RP*("`@("`@("`@("`@)V=-;VYT:"<@/3X@)VEN=&5G97(G+`H@("`@
M("`@("`@("`G:&5X0FEN87)Y)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@
M)V)A<V4V-$)I;F%R>2<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("\O(&1E
M<FEV960@9&%T871Y<&5S"B`@("`@("`@("`@("=N;W)M86QI>F5D4W1R:6YG
M)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)W1O:V5N)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@)VQA;F=U86=E)R`]/B`G<W1R:6YG)RP*("`@("`@
M("`@("`@)TY-5$]+14XG(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G3DU4
M3TM%3E,G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G3F%M92<@/3X@)W-T
M<FEN9R<L"B`@("`@("`@("`@("=.0TYA;64G(#T^("=S=')I;F<G+`H@("`@
M("`@("`@("`G240G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G2412148G
M(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G24121493)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@)T5.5$E462<@/3X@)W-T<FEN9R<L"B`@("`@("`@
M("`@("=%3E1)5$E%4R<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=I;G1E
M9V5R)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=N;VY0;W-I=&EV94EN
M=&5G97(G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)VYE9V%T:79E26YT
M96=E<B<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G;&]N9R<@/3X@)VEN
M=&5G97(G+`H@("`@("`@("`@("`G:6YT)R`]/B`G:6YT96=E<B<L"B`@("`@
M("`@("`@("=S:&]R="<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G8GET
M92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=N;VY.96=A=&EV94EN=&5G
M97(G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)W5N<VEG;F5D3&]N9R<@
M/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G=6YS:6=N961);G0G(#T^("=I
M;G1E9V5R)RP*("`@("`@("`@("`@)W5N<VEG;F5D4VAO<G0G(#T^("=I;G1E
M9V5R)RP*("`@("`@("`@("`@)W5N<VEG;F5D0GET92<@/3X@)VEN=&5G97(G
M+`H@("`@("`@("`@("`G<&]S:71I=F5);G1E9V5R)R`@/3X@)VEN=&5G97(G
M+`H@("`@("`@("`@("`G86YY5'EP92<@/3X@)W-T<FEN9R<L"B`@("`@("`@
M("`@("=A;GE54DDG(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G44YA;64G
M(#T^("=S=')I;F<G"B`@("`@("`@*2P*("`@("`@("`G:'1T<#HO+W=W=RYW
M,RYO<F<O,3DY.2]834Q38VAE;6$G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M:30G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)VEN="<@/3X@)VEN=&5G
M97(G+`H@("`@("`@("`@("`G8F]O;&5A;B<@/3X@)V)O;VQE86XG+`H@("`@
M("`@("`@("`G<W1R:6YG)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)V1O
M=6)L92<@/3X@1DQ/050L"B`@("`@("`@("`@("=F;&]A="<@/3X@1DQ/050L
M"B`@("`@("`@("`@("=D871E5&EM92<@/3X@)W-T<FEN9R<L"B`@("`@("`@
M("`@("=T:6UE26YS=&%N="<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=B
M87-E-C1":6YA<GDG(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G8F%S938T
M)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)W5R+71Y<&4G(#T^("=S=')I
M;F<G"B`@("`@("`@*2P*("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A
M<"YO<F<O<V]A<"]E;F-O9&EN9R\G(#T^(&%R<F%Y*"=B87-E-C0G(#T^("=S
M=')I;F<G+"=A<G)A>2<@/3X@)V%R<F%Y)RPG07)R87DG(#T^("=A<G)A>2<L
M("=3=')U8W0G/3XG87)R87DG*0H@("`@*3L*"B`@("`O+R!L;V%D(&YA;65S
M<&%C92!U<FES(&EN=&\@86X@87)R87D@;V8@=7)I(#T^('!R969I>`H@("`@
M=F%R("1?;F%M97-P86-E<SL*("`@('9A<B`D7VYS7V-O=6YT(#T@,#L*"B`@
M("!V87(@)%]X;6Q%;G1I=&EE<R`](&%R<F%Y("@@)R8G(#T^("<F86UP.R<L
M("<\)R`]/B`G)FQT.R<L("<^)R`]/B`G)F=T.R<L("(G(B`]/B`G)F%P;W,[
M)RP@)R(G(#T^("<F<75O=#LG("D["@H@("`@=F%R("1?9&]C;VYV97)S:6]N
M(#T@1D%,4T4["@H@("`@=F%R("1?7V%T=&%C:&UE;G1S(#T@87)R87DH*3L*
M"B`@("!V87(@)%]W<V1L(#T@3E5,3#L*"B`@("`O*BH*("`@("H@<V5C=&EO
M;C4*("`@("H*("`@("H@0'9A<B`@8F]O;&5A;B`@9&5F:6YE<R!I9B!W92!U
M<V4@<V5C=&EO;B`U(&5N8V]D:6YG+"!O<B!F86QS92!I9B!T:&ES(&ES(&QI
M=&5R86P*("`@("HO"B`@("!V87(@)%]S96-T:6]N-2`](%12544["@H@("`@
M+R\@:&%N9&QE('1Y<&4@=&\@8VQA<W,@;6%P<&EN9PH@("`@=F%R("1?875T
M;U]T<F%N<VQA=&EO;B`](&9A;'-E.PH@("`@=F%R("1?='EP95]T<F%N<VQA
M=&EO;B`](&%R<F%Y*"D["@H*("`@("\J*@H@("`@*B!#;VYS=')U8W1O<@H@
M("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!E<G)O<B!C;V1E"B`@("`J
M($!S964@("1D96)U9U]D871A+"!?9&5B=6<H*0H@("`@*B\*("`@(&9U;F-T
M:6]N(%-/05!?0F%S92@D9F%U;'1C;V1E(#T@)T-L:65N="<I"B`@("!["B`@
M("`@("`@<&%R96YT.CI33T%07T)A<V5?3V)J96-T*"1F875L=&-O9&4I.PH@
M("`@("`@("1T:&ES+3Y?<F5S971.86UE<W!A8V5S*"D["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E<V5T3F%M97-P86-E<R@I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]N86UE<W!A8V5S(#T@87)R87DH"B`@("`@("`@("`@("=H='1P.B\O
M<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R<@/3X@)U-/05`M
M14Y6)RP*("`@("`@("`@("`@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,
M4V-H96UA)R`]/B`G>'-D)RP*("`@("`@("`@("`@)VAT='`Z+R]W=W<N=S,N
M;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E)R`]/B`G>'-I)RP*("`@("`@
M("`@("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I
M;F<O)R`]/B`G4T]!4"U%3D,G*3L*("`@('T*"B`@("`O*BH*("`@("H@7W-E
M=%-C:&5M859E<G-I;VX*("`@("H*("`@("H@<V5T<R!T:&4@<V-H96UA('9E
M<G-I;VX@=7-E9"!I;B!T:&4@<V]A<"!M97-S86=E"B`@("`J"B`@("`J($!P
M87)A;2!S=')I;F<@*'-E92!G;&]B86QS+G!H<"D*("`@("H*("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I;VX@7W-E=%-C:&5M859E
M<G-I;VXH)'-C:&5M859E<G-I;VXI"B`@("!["B`@("`@("`@:68@*"%I;E]A
M<G)A>2@D<V-H96UA5F5R<VEO;BP@)'1H:7,M/E]834Q38VAE;6$I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")U;G-U
M<&]R=&5D(%A-3%-C:&5M82`D<V-H96UA5F5R<VEO;B(I.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7UA-3%-C:&5M859E<G-I;VX@/2`D<V-H96UA5F5R
M<VEO;CL*("`@("`@("`D=&UP3E,@/2!A<G)A>5]F;&EP*"1T:&ES+3Y?;F%M
M97-P86-E<RD["B`@("`@("`@)'1M<$Y36R=X<V0G72`]("1T:&ES+3Y?6$U,
M4V-H96UA5F5R<VEO;CL*("`@("`@("`D=&UP3E-;)WAS:2==(#T@)'1H:7,M
M/E]834Q38VAE;6%697)S:6]N+B<M:6YS=&%N8V4G.PH@("`@("`@("1T:&ES
M+3Y?;F%M97-P86-E<R`](&%R<F%Y7V9L:7`H)'1M<$Y3*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?9V5T3F%M97-P86-E4')E9FEX*"1N<RD*("`@('L*("`@
M("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D;G,L)'1H:7,M/E]N86UE<W!A
M8V5S*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]N86UE<W!A8V5S
M6R1N<UT["B`@("`@("`@?0H@("`@("`@("1P<F5F:7@@/2`G;G,G+F-O=6YT
M*"1T:&ES+3Y?;F%M97-P86-E<RD["B`@("`@("`@)'1H:7,M/E]N86UE<W!A
M8V5S6R1N<UT@/2`D<')E9FEX.PH@("`@("`@(')E='5R;B`D<')E9FEX.PH@
M("`@("`@(')E='5R;B!.54Q,.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G971.
M86UE<W!A8V5&;W)0<F5F:7@H)'!R969I>"D*("`@('L*("`@("`@("`D9FQI
M<'!E9"`](&%R<F%Y7V9L:7`H)'1H:7,M/E]N86UE<W!A8V5S*3L*("`@("`@
M("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D<')E9FEX+"1F;&EP<&5D*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&9L:7!P961;)'!R969I>%T["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!.54Q,.PH@("`@?0H*("`@(&9U;F-T:6]N(%]I
M<U-O87!686QU92@F)'9A;'5E*0H@("`@>PH@("`@("`@(')E='5R;B!I<U]O
M8FIE8W0H)'9A;'5E*2`F)B!I<U]A*"1V86QU92PG<V]A<%]V86QU92<I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]S97)I86QI>F5686QU92@F)'9A;'5E+"`D
M;F%M92`]("<G+"`D='EP92`](&9A;'-E+"`D96Q.86UE<W!A8V4@/2!.54Q,
M+"`D='EP94YA;65S<&%C93U.54Q,+"`D;W!T:6]N<SUA<G)A>2@I+"`D871T
M<FEB=71E<R`](&%R<F%Y*"DL("1A<G1Y<&4])R<I"B`@("!["B`@("`@("`@
M)&YA;65S<&%C97,@/2!A<G)A>2@I.PH@("`@("`@("1A<G)A>51Y<&4@/2`D
M87)R87E?9&5P=&@@/2`D>&UL;W5T7W9A;'5E(#T@;G5L;#L*("`@("`@("`D
M='EP95!R969I>"`]("1E;%!R969I>"`]("1X;6QO=71?;V9F<V5T(#T@)'AM
M;&]U=%]A<G)A>51Y<&4@/2`D>&UL;W5T7W1Y<&4@/2`D>&UL;G,@/2`G)SL*
M("`@("`@("`D<'1Y<&4@/2`D87)R87E?='EP95]N<R`]("<G.PH*("`@("`@
M("!I9B`H(21N86UE('Q\(&ES7VYU;65R:6,H)&YA;64I*2!["B`@("`@("`@
M("`@("1N86UE(#T@)VET96TG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T
M:&ES+3Y?=W-D;"D*("`@("`@("`@("`@;&ES="@D<'1Y<&4L("1A<G)A>51Y
M<&4L("1A<G)A>5]T>7!E7VYS+"`D87)R87E?9&5P=&@I"B`@("`@("`@("`@
M("`@("`@("`@/2`D=&AI<RT^7W=S9&PM/F=E=%-C:&5M851Y<&4H)'1Y<&4L
M("1N86UE+"`D='EP94YA;65S<&%C92D["@H@("`@("`@(&EF("@A)&%R<F%Y
M5'EP92D@)&%R<F%Y5'EP92`]("1A<G1Y<&4["B`@("`@("`@:68@*"$D<'1Y
M<&4I("1P='EP92`]("1T:&ES+3Y?9V5T5'EP92@D=F%L=64I.PH@("`@("`@
M(&EF("@A)'1Y<&4I("1T>7!E(#T@)'!T>7!E.PH*("`@("`@("!I9B`H<W1R
M8V%S96-M<"@D<'1Y<&4L)U-T<G5C="<I(#T](#`@?'P@<W1R8V%S96-M<"@D
M='EP92PG4W1R=6-T)RD@/3T@,"D@>PH@("`@("`@("`@("`O+R!S=')U8W0*
M("`@("`@("`@("`@)'9A<G,@/2!.54Q,.PH@("`@("`@("`@("!I9B`H:7-?
M;V)J96-T*"1V86QU92DI('L*("`@("`@("`@("`@("`@("1V87)S(#T@9V5T
M7V]B:F5C=%]V87)S*"1V86QU92D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=F%R<R`]("8D=F%L=64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V87)S*2D@>PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=F%R<RD@87,@)&LI('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&M;,%T]/2=?)RD@8V]N=&EN=64[("\O
M(&AI9&4@<')I=F%T92!V87)S"B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M7V]B:F5C="@D=F%R<ULD:UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1V87)S6R1K72PG<V]A<%]V86QU92<I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D>&UL;W5T7W9A;'5E("X]("1V87)S6R1K
M72T^<V5R:6%L:7IE*"1T:&ES*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%A86"!G
M970@=&AE(&UE;6)E<G,@86YD('-E<FEA;&EZ92!T:&5M(&EN<W1E860*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(&-O;G9E<G1I;F<@=&\@86X@
M87)R87D@:7,@;6]R92!O=F5R:&5A9"!T:&%N('=E"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!S:&]U;&0@<F5A;'D@9&\L(&)U="!P:'`M<V]A
M<"!I<R!O;B!I="=S('=A>2X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1X;6QO=71?=F%L=64@+CT@)'1H:7,M/E]S97)I86QI>F5686QU92AG971?
M;V)J96-T7W9A<G,H)'9A<G-;)&M=*2P@)&LL(&9A;'-E+"`D=&AI<RT^7W-E
M8W1I;VXU/TY53$PZ)&5L3F%M97-P86-E*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1X;6QO=71?=F%L=64@+CT@)'1H:7,M/E]S97)I
M86QI>F5686QU92@D=F%R<ULD:UTL)&LL(&9A;'-E+"`D=&AI<RT^7W-E8W1I
M;VXU/TY53$PZ)&5L3F%M97-P86-E*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@:68@*'-T<F-A<V5C;7`H)'!T>7!E+"=!<G)A>2<I/3TP('Q\('-T<F-A
M<V5C;7`H)'1Y<&4L)T%R<F%Y)RD]/3`I('L*("`@("`@("`@("`@+R\@87)R
M87D*("`@("`@("`@("`@)'1Y<&5.86UE<W!A8V4@/2!33T%07U-#2$5-05]%
M3D-/1$E.1SL*("`@("`@("`@("`@)&]R:6=?='EP92`]("1T>7!E.PH@("`@
M("`@("`@("`D='EP92`]("=!<G)A>2<["B`@("`@("`@("`@("1N=6UT>7!E
M<R`](#`["B`@("`@("`@("`@("\O(%A86"!T:&ES('=I;&P@8F4@<VQO=R!O
M;B!L87)G97(@87)R87DG<RX@($)A<VEC;'DL(&ET(&9L871T96YS(&%R<F%Y
M)W,@=&\@86QL;W<@=7,*("`@("`@("`@("`@+R\@=&\@<V5R:6%L:7IE(&UU
M;'1I+61I;65N<VEO;F%L(&%R<F%Y)W,N("!792!O;FQY(&1O('1H:7,@:68@
M87)R87E4>7!E(&ES('-E="P*("`@("`@("`@("`@+R\@=VAI8V@@=VEL;"!T
M>7!I8V%L>2!O;FQY(&AA<'!E;B!I9B!W92!A<F4@=7-I;F<@5U-$3`H@("`@
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V9L871T96XG72D@?'P@*"1A
M<G)A>51Y<&4@)B8@*'-T<F-H<B@D87)R87E4>7!E+"<L)RD@?'P@<W1R<W1R
M*"1A<G)A>51Y<&4L)UU;)RDI*2D@>PH@("`@("`@("`@("`@("`@)&YU;71Y
M<&5S(#T@)'1H:7,M/E]M=6QT:4%R<F%Y5'EP92@D=F%L=64L("1A<G)A>51Y
M<&4L("1A<E]S:7IE+"`D>&UL;W5T7W9A;'5E*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&%R<F%Y7W1Y<&4@/2`D87)R87E?='EP95]P<F5F:7@@
M/2`G)SL*("`@("`@("`@("`@:68@*"1N=6UT>7!E<R`A/2`Q*2!["B`@("`@
M("`@("`@("`@("`D87)R87E4>7!E44YA;64@/28@;F5W(%%.86UE*"1A<G)A
M>51Y<&4I.PH@("`@("`@("`@("`@("`@)&%R<F%Y5'EP92`]("1A<G)A>51Y
M<&513F%M92T^;F%M93L*("`@("`@("`@("`@("`@("1A<G)A>5]T>7!E<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D87)R87E?=F%L(#T@3E5,3#L*
M"B`@("`@("`@("`@("`@("`O+R!S97)I86QI>F4@96%C:"!A<G)A>2!E;&5M
M96YT"B`@("`@("`@("`@("`@("`D87)?<VEZ92`](&-O=6YT*"1V86QU92D[
M"B`@("`@("`@("`@("`@("!F;W(@*"1I/3`[("1I(#P@)&%R7W-I>F4[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`D87)R87E?=F%L(#TF("1V86QU
M95LD:5T["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?:7-3;V%P
M5F%L=64H)&%R<F%Y7W9A;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&%R<F%Y7W1Y<&4@/2`D87)R87E?=F%L+3YT>7!E.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D87)R87E?='EP97-;)&%R<F%Y7W1Y<&5=(#T@,3L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5?;G,@/2`D87)R87E?
M=F%L+3YT>7!E7VYA;65S<&%C93L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'AM;&]U=%]V86QU92`N/2`D87)R87E?=F%L+3YS97)I86QI>F4H)'1H:7,I
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1A<G)A>5]T>7!E(#T@)'1H:7,M/E]G9714>7!E*"1A<G)A
M>5]V86PI.PH@("`@("`@("`@("`@("`@("`@("`@("`D87)R87E?='EP97-;
M)&%R<F%Y7W1Y<&5=(#T@,3L*("`@("`@("`@("`@("`@("`@("`@("`@)'AM
M;&]U=%]V86QU92`N/2`D=&AI<RT^7W-E<FEA;&EZ959A;'5E*"1A<G)A>5]V
M86PL)VET96TG+"`D87)R87E?='EP92P@)'1H:7,M/E]S96-T:6]N-3].54Q,
M.B1E;$YA;65S<&%C92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1X;6QO=71?;V9F<V5T(#T@
M(B!33T%0+45.0SIO9F9S970]7");,%U<(B(["B`@("`@("`@("`@("`@("!I
M9B`H(21A<G)A>51Y<&4I('L*("`@("`@("`@("`@("`@("`@("`D;G5M='EP
M97,@/2!C;W5N="@D87)R87E?='EP97,I.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D;G5M='EP97,@/3T@,2D@)&%R<F%Y5'EP92`]("1A<G)A>5]T>7!E
M.PH@("`@("`@("`@("`@("`@("`@("\O('5S:6YG(&%N>51Y<&4@:7,@;6]R
M92!I;G1E<F]P97)A8FQE"B`@("`@("`@("`@("`@("`@("`@:68@*"1A<G)A
M>5]T>7!E(#T]("=3=')U8W0G*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1A<G)A>5]T>7!E(#T@)R<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M(&EF("@D87)R87E?='EP92`]/2`G07)R87DG*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1A<G)A>51Y<&4@/2`G86YY5'EP92<["B`@("`@("`@("`@
M("`@("`@("`@("`@("1A<G)A>5]T>7!E7W!R969I>"`]("=X<V0G.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS90H@("`@("`@("`@("`@("`@("`@(&EF
M("@A)&%R<F%Y5'EP92D@)&%R<F%Y5'EP92`]("1A<G)A>5]T>7!E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A
M)&%R<F%Y5'EP92!\?"`D;G5M='EP97,@/B`Q*2!["B`@("`@("`@("`@("`@
M("`D87)R87E4>7!E(#T@)WAS9#IA;GE4>7!E)SL@+R\@<VAO=6QD(')E9F5R
M96YC92!W:&%T('-C:&5M82!W92=R92!U<VEN9PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@:68@*"1A<G)A>5]T>7!E7VYS*2!["B`@
M("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5?<')E9FEX(#T@)'1H:7,M
M/E]G971.86UE<W!A8V50<F5F:7@H)&%R<F%Y7W1Y<&5?;G,I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E(&EF("AA<G)A>5]K97E?97AI<W1S*"1A<G)A>51Y
M<&4L("1T:&ES+3Y?='EP96UA<%LD=&AI<RT^7UA-3%-C:&5M859E<G-I;VY=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1A<G)A>5]T>7!E7W!R969I>"`]
M("1T:&ES+3Y?;F%M97-P86-E<ULD=&AI<RT^7UA-3%-C:&5M859E<G-I;VY=
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1A<G)A
M>5]T>7!E7W!R969I>"D*("`@("`@("`@("`@("`@("`@("`D87)R87E4>7!E
M(#T@)&%R<F%Y7W1Y<&5?<')E9FEX+B<Z)RXD87)R87E4>7!E.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D>&UL;W5T7V%R<F%Y5'EP92`]("(@4T]!
M4"U%3D,Z87)R87E4>7!E/5PB(B`N("1A<G)A>51Y<&4["B`@("`@("`@("`@
M(&EF("@D87)R87E?9&5P=&@@(3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)&%R<F%Y7V1E<'1H.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`@("`@)'AM;&]U=%]A<G)A>51Y<&4@+CT@)UM=)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D>&UL
M;W5T7V%R<F%Y5'EP92`N/2`B6R1A<E]S:7IE75PB(CL*("`@("`@("!](&5L
M<V4@:68@*"1T:&ES+3Y?:7-3;V%P5F%L=64H)'9A;'5E*2D@>PH@("`@("`@
M("`@("`D>&UL;W5T7W9A;'5E(#TF("1V86QU92T^<V5R:6%L:7IE*"1T:&ES
M*3L*("`@("`@("!](&5L<V4@:68@*"1T>7!E(#T]("=S=')I;F<G*2!["B`@
M("`@("`@("`@("1X;6QO=71?=F%L=64@/2!H=&UL<W!E8VEA;&-H87)S*"1V
M86QU92D["B`@("`@("`@?2!E;'-E(&EF("@D='EP92`]/2`G<F%W<W1R:6YG
M)RD@>PH@("`@("`@("`@("`D>&UL;W5T7W9A;'5E(#TF("1V86QU93L*("`@
M("`@("!](&5L<V4@:68@*"1T>7!E(#T]("=B;V]L96%N)RD@>PH@("`@("`@
M("`@("`D>&UL;W5T7W9A;'5E(#T@)'9A;'5E/R=T<G5E)SHG9F%L<V4G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1X;6QO=71?=F%L=64@/28@
M)'9A;'5E.PH@("`@("`@('T*"B`@("`@("`@+R\@861D(&YA;65S<&%C97,*
M("`@("`@("!I9B`H)&5L3F%M97-P86-E*2!["B`@("`@("`@("`@("1E;%!R
M969I>"`]("1T:&ES+3Y?9V5T3F%M97-P86-E4')E9FEX*"1E;$YA;65S<&%C
M92D["B`@("`@("`@("`@("1X;6QO=71?;F%M92`]("(D96Q0<F5F:7@Z)&YA
M;64B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1X;6QO=71?;F%M
M92`]("1N86UE.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T>7!E3F%M97-P
M86-E*2!["B`@("`@("`@("`@("1T>7!E4')E9FEX(#T@)'1H:7,M/E]G971.
M86UE<W!A8V50<F5F:7@H)'1Y<&5.86UE<W!A8V4I.PH@("`@("`@("`@("`D
M>&UL;W5T7W1Y<&4@/2`B)'1Y<&50<F5F:7@Z)'1Y<&4B.PH@("`@("`@('T@
M96QS92!I9B`H)'1Y<&4@)B8@87)R87E?:V5Y7V5X:7-T<R@D='EP92P@)'1H
M:7,M/E]T>7!E;6%P6R1T:&ES+3Y?6$U,4V-H96UA5F5R<VEO;ETI*2!["B`@
M("`@("`@("`@("1T>7!E4')E9FEX(#T@)'1H:7,M/E]N86UE<W!A8V5S6R1T
M:&ES+3Y?6$U,4V-H96UA5F5R<VEO;ET["B`@("`@("`@("`@("1X;6QO=71?
M='EP92`]("(D='EP95!R969I>#HD='EP92(["B`@("`@("`@?0H*("`@("`@
M("`O+R!H86YD;&4@861D:71I;VYA;"!A='1R:6)U=&5S"B`@("`@("`@)'AM
M;%]A='1R(#T@)R<["B`@("`@("`@:68@*&-O=6YT*"1A='1R:6)U=&5S*2`^
M(#`I('L*("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&L@
M/3X@)'8I('L*("`@("`@("`@("`@("`@("1K<6X@/28@;F5W(%%.86UE*"1K
M*3L*("`@("`@("`@("`@("`@("1V<6X@/28@;F5W(%%.86UE*"1V*3L*("`@
M("`@("`@("`@("`@("1X;6Q?871T<B`N/2`G("<N)&MQ;BT^9G%N*"DN)STB
M)RXD=G%N+3YF<6XH*2XG(B<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O('-T;W)E('1H92!A='1A8VAE;65N="!F;W(@;6EM92!E;F-O
M9&EN9PH@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG871T86-H;65N="==
M*2D*("`@("`@("`@("`@)'1H:7,M/E]?871T86-H;65N='-;72`]("1O<'1I
M;VYS6R=A='1A8VAM96YT)UT["@H@("`@("`@(&EF("@D=&AI<RT^7W-E8W1I
M;VXU*2!["B`@("`@("`@("`@(&EF("@D>&UL;W5T7W1Y<&4I("1X;6QO=71?
M='EP92`]("(@>'-I.G1Y<&4]7"(D>&UL;W5T7W1Y<&5<(B(["B`@("`@("`@
M("`@(&EF("AI<U]N=6QL*"1X;6QO=71?=F%L=64I*2!["B`@("`@("`@("`@
M("`@("`D>&UL(#T@(EQR7&X\)'AM;&]U=%]N86UE)'AM;&]U=%]T>7!E)'AM
M;&YS)'AM;&]U=%]A<G)A>51Y<&4D>&UL7V%T='(O/B(["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D>&UL(#T@(EQR7&X\)'AM;&]U
M=%]N86UE)'AM;&]U=%]T>7!E)'AM;&YS)'AM;&]U=%]A<G)A>51Y<&4D>&UL
M;W5T7V]F9G-E="1X;6Q?871T<CXB+@H@("`@("`@("`@("`@("`@("`@("1X
M;6QO=71?=F%L=64N(CPO)'AM;&]U=%]N86UE/B(["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D>&UL
M;W5T7W9A;'5E*2D@>PH@("`@("`@("`@("`@("`@)'AM;"`](")<<EQN/"1X
M;6QO=71?;F%M921X;6QN<R1X;6Q?871T<B\^(CL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1X;6P@/2`B7')<;CPD>&UL;W5T7VYA
M;64D>&UL;G,D>&UL7V%T='(^(BX*("`@("`@("`@("`@("`@("`@("`D>&UL
M;W5T7W9A;'5E+B(\+R1X;6QO=71?;F%M93XB.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D>&UL.PH@("`@?0H*"B`@("`O*BH*
M("`@("H@4T]!4#HZ5F%L=64Z.E]G9714>7!E"B`@("`J"B`@("`J(&-O;G9E
M<G0@<&AP('1Y<&4@=&\@<V]A<"!T>7!E"B`@("`J($!P87)A;2`@("!S=')I
M;F<@('9A;'5E"B`@("`J"B`@("`J($!R971U<FX@("!S=')I;F<@('1Y<&4@
M("T@<V]A<"!T>7!E"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J+PH@
M("`@9G5N8W1I;VX@7V=E=%1Y<&4H)B1V86QU92D@>PH@("`@("`@(&=L;V)A
M;"`D4T]!4%]/0DI%0U1?4U1254-4+"133T%07U)!5U]#3TY615)4.PH@("`@
M("`@("1T>7!E(#T@9V5T='EP92@D=F%L=64I.PH@("`@("`@('-W:71C:"`H
M)'1Y<&4I('L*("`@("`@("!C87-E("=O8FIE8W0G.@H@("`@("`@("`@("!I
M9B`H:7-?82@D=F%L=64L)W-O87!?=F%L=64G*2D@>PH@("`@("`@("`@("`@
M("`@)'1Y<&4@/2`D=F%L=64M/G1Y<&4["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D='EP92`]("=3=')U8W0G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@)V%R<F%Y)SH*
M("`@("`@("`@("`@+R\@6%A8(&AA<VAE<R!A;'=A>7,@9V5T(&1O;F4@87,@
M<W1R=6-T<R!B>2!P96%R.CIS;V%P"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7VES2&%S:"@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D='EP92`]("=3
M=')U8W0G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&%R7W-I>F4@/2!C;W5N="@D=F%L=64I.PH@("`@("`@("`@("`@("`@:68@
M*"1A<E]S:7IE(#X@,"`F)B!I<W-E="@D=F%L=65;,%TI("8F(&ES7V$H)'9A
M;'5E6S!=+"=S;V%P7W9A;'5E)RDI('L*("`@("`@("`@("`@("`@("`@("`O
M+R!F:7AM92!F;W(@;F]N+7=S9&P@<W1R=6-T<R!T:&%T(&%R92!A;&P@=&5H
M('-A;64@='EP90H@("`@("`@("`@("`@("`@("`@(&EF("@D87)?<VEZ92`^
M(#$@)B8*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U-O87!6
M86QU92@D=F%L=65;,%TI("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:7-3;V%P5F%L=64H)'9A;'5E6S%=*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L=65;,%TM/FYA;64@(3T@)'9A;'5E6S%=+3YN86UE
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O('1H:7,@:7,@82!S=')U
M8W0L(&YO="!A;B!A<G)A>0H@("`@("`@("`@("`@("`@("`@("`@("`D='EP
M92`]("=3=')U8W0G.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)T%R<F%Y)SL*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1T>7!E(#T@)T%R<F%Y)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!C87-E("=I;G1E9V5R)SH*("`@("`@("!C87-E("=L;VYG)SH*("`@("`@
M("`@("`@)'1Y<&4@/2`G:6YT)SL*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@8V%S92`G8F]O;&5A;B<Z"B`@("`@("`@("`@(",D=F%L=64@/2`D=F%L
M=64_)W1R=64G.B=F86QS92<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(&-A<V4@)V1O=6)L92<Z"B`@("`@("`@("`@("1T>7!E(#T@)V9L;V%T)SL@
M+R\@9&]U8FQE(&ES(&1E<')E8V%T960@:6X@-"XR(&%N9"!L871E<@H@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=.54Q,)SH*("`@("`@("`@
M("`@)'1Y<&4@/2`G)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S
M92`G<W1R:6YG)SH*("`@("`@("`@("`@:68@*"133T%07U)!5U]#3TY615)4
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D=F%L=64I*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D=F%L=64L)RXG*2D@
M)'1Y<&4@/2`G9FQO870G.PH@("`@("`@("`@("`@("`@("`@(&5L<V4@)'1Y
M<&4@/2`G:6YT)SL*("`@("`@("`@("`@("`@('T@96QS90H@("`@("`@("`@
M("`@("`@:68@*%-/05!?5'EP95]H97A":6YA<GDZ.FES7VAE>&)I;B@D=F%L
M=64I*2!["B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G:&5X0FEN87)Y
M)SL*("`@("`@("`@("`@("`@('T@96QS90H@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?:7-"87-E-C0H)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T>7!E(#T@)V)A<V4V-$)I;F%R>2<["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1D="`])B!N97<@4T]!4%]4
M>7!E7V1A=&54:6UE*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1D="T^=&]5;FEX=&EM92@I("$]("TQ*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T>7!E(#T@)V1A=&54:6UE)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@(R1V86QU92`]("1D="T^=&]33T%0*"D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D='EP93L*("`@('T*"B`@("!F=6YC=&EO;B!?;75L=&E!
M<G)A>51Y<&4H)B1V86QU92P@)B1T>7!E+"`F)'-I>F4L("8D>&UL*0H@("`@
M>PH@("`@("`@("1S>B`](&-O=6YT*"1V86QU92D["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@+R\@<V5E;7,@=V4@:&%V
M92!A(&UU;'1I(&1I;65N<VEO;F%L(&%R<F%Y+"!F:6=U<F4@:70@;W5T(&EF
M('=E(&1O"B`@("`@("`@("`@("1C(#T@8V]U;G0H)'9A;'5E*3L*("`@("`@
M("`@("`@9F]R("@D:3TP.R`D:3PD8SL@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]M=6QT:4%R<F%Y5'EP92@D=F%L=65;)&E=+"`D='EP92P@
M)'-I>F4L("1X;6PI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M)'-I>F4I('L*("`@("`@("`@("`@("`@("1S:7IE(#T@)'-Z+B<L)RXD<VEZ
M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S:7IE
M(#T@)'-Z.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`Q.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'9A
M;'5E*2D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D=F%L=64M/G1Y<&4[
M"B`@("`@("`@("`@("`@("`D>&UL("X]("1V86QU92T^<V5R:6%L:7IE*"1T
M:&ES*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M>7!E(#T@)'1H:7,M/E]G9714>7!E*"1V86QU92D["B`@("`@("`@("`@("`@
M("`D>&UL("X]("1T:&ES+3Y?<V5R:6%L:7IE5F%L=64H)'9A;'5E+"=I=&5M
M)RPD='EP92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'-I
M>F4@/2!.54Q,.PH@("`@("`@(')E='5R;B`Q.PH@("`@?0H@("`@+R\@<W5P
M<&]R="!F=6YC=&EO;G,*("`@("\J*@H@("`@*@H@("`@*B!`<&%R86T@("`@
M<W1R:6YG"B`@("`J($!R971U<FX@("!S=')I;F<*("`@("HO"B`@("!F=6YC
M=&EO;B!?:7-"87-E-C0H)B1V86QU92D*("`@('L*("`@("`@("`D;"`]('-T
M<FQE;B@D=F%L=64I.PH@("`@("`@(&EF("@D;"`^(#`I"B`@("`@("`@("`@
M(')E='5R;B`D=F%L=65;)&PM,5T@/3T@)STG("8F('!R96=?;6%T8V@H(B];
M02U:82UZ/5PO7"M=*R\B+"1V86QU92D["B`@("`@("`@<F5T=7)N($9!3%-%
M.PH@("`@?0H*("`@("\J*@H@("`@*@H@("`@*B!`<&%R86T@("`@;6EX960*
M("`@("H@0')E='5R;B`@(&)O;VQE86X*("`@("HO"B`@("!F=6YC=&EO;B!?
M:7-(87-H*"8D82D@>PH@("`@("`@(",@6%A8($D@<F5A;'D@9&ES;&EK92!H
M879I;F<@=&\@;&]O<"!T:')O=6=H('1H:7,@:6X@<&AP(&-O9&4L"B`@("`@
M("`@(R!R96%L>2!L87)G92!A<G)A>7,@=VEL;"!B92!S;&]W+B`@5V4@;F5E
M9"!A($,@9G5N8W1I;VX@=&\@9&\@=&AI<RX*("`@("`@("`D;F%M97,@/2!A
M<G)A>2@I.PH@("`@("`@("1I="`](#`["B`@("`@("`@9F]R96%C:"`H)&$@
M87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@(R!C:&5C:VEN9R!T:&4@='EP
M92!I<R!F87-T97(@=&AA;B!R96=E>'`N"B`@("`@("`@("`@("1T(#T@9V5T
M='EP92@D:RD["B`@("`@("`@("`@(&EF("@D="`A/2`G:6YT96=E<B<I('L*
M("`@("`@("`@("`@("`@(')E='5R;B!44E5%.PH@("`@("`@("`@("!](&5L
M<V4@:68@*"1T:&ES+3Y?:7-3;V%P5F%L=64H)'8I*2!["B`@("`@("`@("`@
M("`@("`D;F%M97-;)'8M/FYA;65=(#T@,3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`O+R!I9B!S;VUE;VYE(&AA<R!A(&QA<F=E(&AA<V@@=&AE>2!S
M:&]U;&0@<F5A;'D@8F4@9&5F:6YI;F<@=&AE('1Y<&4*("`@("`@("`@("`@
M:68@*"1I="LK(#X@,3`I(')E='5R;B!&04Q313L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N(&-O=6YT*"1N86UE<RD^,3L*("`@('T*"B`@("!F=6YC=&EO
M;B`F7W5N7VAT;6QE;G1I=&EE<R@D<W1R:6YG*0H@("`@>PH@("`@("`@)'1R
M86YS7W1B;"`](&=E=%]H=&UL7W1R86YS;&%T:6]N7W1A8FQE("A(5$U,7T5.
M5$E42453*3L*("`@("`@("1T<F%N<U]T8FP@/2!A<G)A>5]F;&EP*"1T<F%N
M<U]T8FPI.PH@("`@("`@<F5T=7)N('-T<G1R*"1S=')I;F<L("1T<F%N<U]T
M8FPI.PH@("`@?0H*("`@("\J*@H@("`@*@H@("`@*B!`<&%R86T@("`@;6EX
M960*("`@("HO"B`@("!F=6YC=&EO;B`F7V1E8V]D92@F)'-O87!V86PI"B`@
M("!["B`@("`@("`@9VQO8F%L("133T%07T]"2D5#5%]35%)50U0["B`@("`@
M("`@:68@*"$D=&AI<RT^7VES4V]A<%9A;'5E*"1S;V%P=F%L*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-O87!V86P["B`@("`@("`@?2!E;'-E(&EF("AI
M<U]A<G)A>2@D<V]A<'9A;"T^=F%L=64I*2!["B`@("`@("`@("`@(&EF("@D
M4T]!4%]/0DI%0U1?4U1254-4("8F("1S;V%P=F%L+3YT>7!E("$]("=!<G)A
M>2<I('L*("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`G<W1D8VQA<W,G
M.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?='EP95]T<F%N
M<VQA=&EO;ELD<V]A<'9A;"T^='%N+3YF<6XH*5TI*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@=&AI<R!W:6QL(&9O<F-E(&%N(&5R<F]R(&EN('!H<"!I
M9B!T:&4*("`@("`@("`@("`@("`@("`@("`O+R!C;&%S<R!D;V5S(&YO="!E
M>&ES=`H@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`D=&AI<RT^
M7W1Y<&5?=')A;G-L871I;VY;)'-O87!V86PM/G1Q;BT^9G%N*"E=.PH@("`@
M("`@("`@("`@("`@?2!E;'-E(&EF("AI<W-E="@D=&AI<RT^7W1Y<&5?=')A
M;G-L871I;VY;)'-O87!V86PM/G1Y<&5=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("\O('1H:7,@=VEL;"!F;W)C92!A;B!E<G)O<B!I;B!P:'`@:68@=&AE
M"B`@("`@("`@("`@("`@("`@("`@+R\@8VQA<W,@9&]E<R!N;W0@97AI<W0*
M("`@("`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@)'1H:7,M/E]T>7!E
M7W1R86YS;&%T:6]N6R1S;V%P=F%L+3YT>7!E73L*("`@("`@("`@("`@("`@
M('T@96QS92!I9B`H)'1H:7,M/E]A=71O7W1R86YS;&%T:6]N*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D<V]A<'9A;"T^='EP
M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-L87-S;F%M92`]("1S
M;V%P=F%L+3YT>7!E.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!I9B`H
M)'1H:7,M/E]W<V1L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T(#T@
M)'1H:7,M/E]W<V1L+3YG971#;VUP;&5X5'EP94YA;65&;W)%;&5M96YT*"1S
M;V%P=F%L+3YN86UE+"`D<V]A<'9A;"T^;F%M97-P86-E*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1T("8F(&-L87-S7V5X:7-T<R@D="DI("1C
M;&%S<VYA;64@/2`D=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T=7)N(#TF(&YE=R`D8VQA
M<W-N86UE.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)')E='5R;B`](&%R<F%Y*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1C;W5N=&5R(#T@,3L*("`@("`@("`@("`@)&ES<W1R=6-T(#T@(2133T%0
M7T]"2D5#5%]35%)50U0@?'P@(6ES7V%R<F%Y*"1R971U<FXI.PH@("`@("`@
M("`@("!F;W)E86-H("@D<V]A<'9A;"T^=F%L=64@87,@)&ET96TI('L*("`@
M("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)')E='5R;BDI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]W<V1L*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&=E="!T:&ES(&-H:6QD<R!W<V1L(&EN9F]R;6%T
M:6]N"B`@("`@("`@("`@("`@("`@("`@("`@("\O("\D<V]A<'9A;"T^;G,O
M)'-O87!V86PM/G1Y<&4O)&ET96TM/FYS+R1I=&5M+3YN86UE"B`@("`@("`@
M("`@("`@("`@("`@("`@("1C:&EL9%]T>7!E(#T@)'1H:7,M/E]W<V1L+3YG
M971#;VUP;&5X5'EP94-H:6QD5'EP92@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O87!V86PM/FYA;65S<&%C
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-O87!V86PM/FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I=&5M+3YN86UE<W!A8V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1I=&5M+3YN86UE*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1C
M:&EL9%]T>7!E*2`D:71E;2T^='EP92`]("1C:&EL9%]T>7!E.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H(21I<W-T
M<G5C="!\?"`D:71E;2T^='EP92`]/2`G07)R87DG*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D<F5T=7)N+3Y[)&ET96TM/FYA;65]
M*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@(&ES7V]B:F5C="@D<F5T
M=7)N+3Y[)&ET96TM/FYA;65]*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E='5R;BT^>R1I=&5M+3YN86UE?2`])B`D=&AI<RT^7V1E8V]D
M92@D:71E;2D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!I9B`H
M:7-S970H)')E='5R;BT^>R1I=&5M+3YN86UE?2D@)B8*("`@("`@("`@("`@
M("`@("`@("`@("`@("!I<U]A<G)A>2@D<F5T=7)N+3Y[)&ET96TM/FYA;65]
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^>R1I
M=&5M+3YN86UE?5M=(#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E(&EF("AI<U]A<G)A>2@D<F5T=7)N
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;EM=(#TF
M("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U
M<FXM/GLD:71E;2T^;F%M97T@/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E(&EF("AI<W-E="@D<F5T=7)N+3Y[)&ET96TM/FYA;65]*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D:7-S=')U8W0@/2!&04Q313L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*&=E=%]O8FIE8W1?=F%R
M<R@D<F5T=7)N*2D@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&0@/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E='5R;B`](&%R<F%Y*"1R971U<FXM/GLD:71E
M;2T^;F%M97TL("1D*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D(#TF("1T:&ES+3Y?
M9&5C;V1E*"1I=&5M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M971U<FXM/GLD:71E;2T^;F%M97T@/2!A<G)A>2@D<F5T=7)N+3Y[)&ET96TM
M/FYA;65]+"`D9"D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5T=7)N+3Y[)&ET96TM/FYA;65](#TF("1T:&ES+3Y?9&5C;V1E*"1I
M=&5M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@+RH@<V5T('1H92!A='1R:6)U=&5S(&%S(&UE;6)E<G,@:6X@=&AE(&-L
M87-S("HO"B`@("`@("`@("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H
M)')E='5R;BPG7U]S971?871T<FEB=71E)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'-O87!V86PM/F%T=')I8G5T97,@87,@)&ME
M>3T^)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C86QL
M7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@F)')E='5R;BPG7U]S971?871T<FEB
M=71E)RDL87)R87DH)&ME>2PD=F%L=64I*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1S;V%P=F%L+3YA
M<G)A>51Y<&4@)B8@)'1H:7,M/E]I<U-O87!686QU92@D:71E;2DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&ET96TM/G1Y<&4@/2`D<V]A<'9A;"T^
M87)R87E4>7!E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!I9B`H(21I<W-T<G5C="D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5T=7)N6UT@/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!I9B`H:7-S970H)')E='5R;ELD:71E
M;2T^;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I<W-T<G5C
M="`]($9!3%-%.PH@("`@("`@("`@("`@("`@("`@("`@("`D9"`])B`D=&AI
M<RT^7V1E8V]D92@D:71E;2D["B`@("`@("`@("`@("`@("`@("`@("`@("1R
M971U<FX@/2!A<G)A>2@D<F5T=7)N6R1I=&5M+3YN86UE72P@)&0I.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1R971U<FY;)&ET96TM/FYA;65=(#TF("1T:&ES+3Y?9&5C;V1E*"1I
M=&5M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1R971U<FX["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'-O87!V86PM/G1Y<&4@/3T@)V)O;VQE
M86XG*2!["B`@("`@("`@("`@(&EF("@D<V]A<'9A;"T^=F%L=64@(3T@)S`G
M("8F('-T<F-A<V5C;7`H)'-O87!V86PM/G9A;'5E+"=F86QS92<I("$],"D@
M>PH@("`@("`@("`@("`@("`@)'-O87!V86PM/G9A;'5E(#T@5%)513L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S;V%P=F%L+3YV
M86QU92`]($9!3%-%.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E(&EF
M("@D<V]A<'9A;"T^='EP92`F)B!A<G)A>5]K97E?97AI<W1S*"1S;V%P=F%L
M+3YT>7!E+"`D=&AI<RT^7W1Y<&5M87!;4T]!4%]834Q?4T-(14U!7U9%4E-)
M3TY=*2D@>PH@("`@("`@("`@("`C(&EF('=E(&-A;BP@;&5T<R!S970@<&AP
M)W,@=F%R:6%B;&4@='EP90H@("`@("`@("`@("!S971T>7!E*"1S;V%P=F%L
M+3YV86QU92P@)'1H:7,M/E]T>7!E;6%P6U-/05!?6$U,7U-#2$5-05]615)3
M24].75LD<V]A<'9A;"T^='EP95TI.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'-O87!V86PM/G9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@8W)E
M871E<R!T:&4@<V]A<"!E;G9E;&]P92!W:71H('1H92!S;V%P(&5N=F5L;W`@
M9&%T80H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A>6QO860@("`@
M("`@<V]A<"!D871A("AI;B!X;6PI"B`@("`@*B!`<F5T=7)N(&%S<V]C:6%T
M:79E(&%R<F%Y("AH96%D97)S+&)O9'DI"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@)E]M86ME16YV96QO<&4H)B1M971H
M;V0L("8D:&5A9&5R<RP@)&5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.0T]$
M24Y'+"1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("`D<VUS9R`]
M("1H96%D97)?>&UL(#T@)&YS7W-T<FEN9R`]("<G.PH*("`@("`@("!I9B`H
M)&AE861E<G,I('L*("`@("`@("`@("`@)&,@/2!C;W5N="@D:&5A9&5R<RD[
M"B`@("`@("`@("`@(&9O<B`H)&D],#L@)&D@/"`D8SL@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@)&AE861E<E]X;6P@+CT@)&AE861E<G-;)&E=+3YS97)I
M86QI>F4H)'1H:7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H96%D
M97)?>&UL(#T@(CQ33T%0+45.5CI(96%D97(^7')<;B1H96%D97)?>&UL7')<
M;CPO4T]!4"U%3E8Z2&5A9&5R/EQR7&XB.PH@("`@("`@('T*("`@("`@("!I
M9B`H(6ES<V5T*"1O<'1I;VYS6R=I;G!U="==*2!\?"`D;W!T:6]N<ULG:6YP
M=70G72`]/2`G<&%R<V4G*2!["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M;65T:&]D*2D@>PH@("`@("`@("`@("`@("`@)&,@/2!C;W5N="@D;65T:&]D
M*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@)'-M<V<@+CT@)&UE=&AO9%LD:5TM
M/G-E<FEA;&EZ92@D=&AI<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@(&5L<V4@>PH@("`@("`@("`@("`@("`@)'-M<V<@/28@)&UE=&AO
M9"T^<V5R:6%L:7IE*"1T:&ES*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1S;7-G(#TF("1M971H;V0["B`@("`@("`@
M?0H@("`@("`@("1B;V1Y(#T@(CQ33T%0+45.5CI";V1Y/EQR7&XB+B1S;7-G
M+B)<<EQN/"]33T%0+45.5CI";V1Y/EQR7&XB.PH*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7VYA;65S<&%C97,@87,@)&L@/3X@)'8I('L*("`@("`@("`@
M("`@)&YS7W-T<FEN9R`N/2`B('AM;&YS.B1V/5PB)&M<(EQR7&XB.PH@("`@
M("`@('T*"B`@("`@("`@+RH@:68@=7-E/2=L:71E<F%L)RP@=V4@9&\@;F]T
M('!U="!I;B!T:&4@96YC;V1I;F=3='EL92X@(%1H:7,@:7,@9&5N;W1E9"!B
M>0H@("`@("`@("`@("1T:&ES+3Y?<V5C=&EO;C4@8F5I;F<@9F%L<V4N"B`@
M("`@("`@("`@6%A8('5S92!C86X@8F4@9&5F:6YE9"!A="!A(&UO<F4@9W)A
M;G5L87(@;&5V96P@=&AA;B!W92!A<F4@9&5A;&EN9R!W:71H"B`@("`@("`@
M("`@:&5R92P@<V\@=&AI<R!D;V5S(&YO="!W;W)K(&9O<B!A;&P@<V5R=FEC
M97,N"B`@("`@("`@*B\*("`@("`@("`D>&UL(#T@(CP_>&UL('9E<G-I;VX]
M7"(Q+C!<(B!E;F-O9&EN9SU<(B1E;F-O9&EN9UPB/SY<<EQN7')<;B(N"B`@
M("`@("`@("`@("(\4T]!4"U%3E8Z16YV96QO<&4@)&YS7W-T<FEN9R(N"B`@
M("`@("`@("`@("@D=&AI<RT^7W-E8W1I;VXU/R(@4T]!4"U%3E8Z96YC;V1I
M;F=3='EL93U<(B(@+B!33T%07U-#2$5-05]%3D-/1$E.1R`N(")<(B(Z)R<I
M+@H@("`@("`@("`@("`B/EQR7&XB+@H@("`@("`@("`@("`B)&AE861E<E]X
M;6PD8F]D>3PO4T]!4"U%3E8Z16YV96QO<&4^7')<;B(["@H@("`@("`@(')E
M='5R;B`D>&UL.PH@("`@?0H*("`@(&9U;F-T:6]N("9?;6%K94UI;65-97-S
M86=E*"8D>&UL+"`D96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<I
M"B`@("!["B`@("`@("`@9VQO8F%L("133T%07V]P=&EO;G,["@H@("`@("`@
M(&EF("@A:7-S970H)%-/05!?;W!T:6]N<ULG36EM92==*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@G36EM92!I<R!N
M;W0@:6YS=&%L;&5D)RD["B`@("`@("`@?0H*("`@("`@("`O+R!E;F-O9&4@
M86YY(&%T=&%C:&UE;G1S"B`@("`@("`@+R\@<V5E(&AT='`Z+R]W=W<N=S,N
M;W)G+U12+U-/05`M871T86-H;65N=',*("`@("`@("`O+R!N;W<@=V4@:&%V
M92!T;R!M:6UE(&5N8V]D92!T:&4@;65S<V%G90H@("`@("`@("1P87)A;7,@
M/2!A<G)A>2@G8V]N=&5N=%]T>7!E)R`]/B`G;75L=&EP87)T+W)E;&%T960[
M('1Y<&4]=&5X="]X;6PG*3L*("`@("`@("`D;7-G(#TF(&YE=R!-86EL7VUI
M;65087)T*"<G+"`D<&%R86US*3L*("`@("`@("`O+R!A9&0@=&AE('AM;"!P
M87)T"B`@("`@("`@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G=&5X="]X
M;6PG.PH@("`@("`@("1P87)A;7-;)V-H87)S970G72`]("1E;F-O9&EN9SL*
M("`@("`@("`D<&%R86US6R=E;F-O9&EN9R==(#T@)V)A<V4V-"<["B`@("`@
M("`@)&US9RT^861D4W5B4&%R="@D>&UL+"`D<&%R86US*3L*"B`@("`@("`@
M+R\@861D('1H92!A='1A8VAE;65N=',*("`@("`@("`D8R`](&-O=6YT*"1T
M:&ES+3Y?7V%T=&%C:&UE;G1S*3L*("`@("`@("!F;W(@*"1I/3`[("1I(#P@
M)&,[("1I*RLI('L*("`@("`@("`@("`@)&%T=&%C:&UE;G0@/28@)'1H:7,M
M/E]?871T86-H;65N='-;)&E=.PH@("`@("`@("`@("`D;7-G+3YA9&13=6)0
M87)T*"1A='1A8VAM96YT6R=B;V1Y)UTL)&%T=&%C:&UE;G0I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&US9RT^96YC;V1E*"D["B`@("!]"@H@("`@
M+R\@6%A8('1H:7,@;F5E9',@=&\@8F4@=7-E9"!F<F]M('1H92!4<F%N<W!O
M<G0@<WES=&5M"B`@("!F=6YC=&EO;B`F7VUA:V5$24U%365S<V%G92@F)'AM
M;"D*("`@('L*("`@("`@("!G;&]B86P@)%-/05!?;W!T:6]N<SL*"B`@("`@
M("`@:68@*"%I<W-E="@D4T]!4%]O<'1I;VYS6R=$24U%)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=$24U%(&ES
M(&YO="!I;G-T86QL960G*3L*("`@("`@("!]"@H@("`@("`@("\O(&5N8V]D
M92!A;GD@871T86-H;65N=',*("`@("`@("`O+R!S964@:'1T<#HO+W-E87)C
M:"YI971F+F]R9R]I;G1E<FYE="UD<F%F=',O9')A9G0M;FEE;'-E;BUD:6UE
M+7-O87`M,#`N='AT"B`@("`@("`@+R\@;F]W('=E(&AA=F4@=&\@1$E-12!E
M;F-O9&4@=&AE(&UE<W-A9V4*("`@("`@("`D9&EM92`])B!N97<@3F5T7T1)
M345?365S<V%G92@I.PH@("`@("`@("1M<V<@/28@)&1I;64M/F5N8V]D941A
M=&$H)'AM;"Q33T%07T5.5D5,3U`L3E5,3"Q.151?1$E-15]465!%7U5222D[
M"@H@("`@("`@("\O(&%D9"!T:&4@871T86-H96UE;G1S"B`@("`@("`@)&,@
M/2!C;W5N="@D=&AI<RT^7U]A='1A8VAM96YT<RD["B`@("`@("`@9F]R("@D
M:3TP.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@("1A='1A8VAM96YT
M(#TF("1T:&ES+3Y?7V%T=&%C:&UE;G1S6R1I73L*("`@("`@("`@("`@)&US
M9R`N/2`D9&EM92T^96YC;V1E1&%T82@D871T86-H;65N=%LG8F]D>2==+"1A
M='1A8VAM96YT6R=C;VYT96YT7W1Y<&4G72PD871T86-H;65N=%LG8VED)UTL
M3D547T1)345?5%E015]-141)02D["B`@("`@("`@?0H@("`@("`@("1M<V<@
M+CT@)&1I;64M/F5N9$UE<W-A9V4H*3L*("`@("`@("!R971U<FX@)&US9SL*
M("`@('T*"B`@("!F=6YC=&EO;B!?9&5C;V1E36EM94UE<W-A9V4H)B1D871A
M+"`F)&AE861E<G,L("8D871T86-H;65N=',I"B`@("!["B`@("`@("`@9VQO
M8F%L("133T%07V]P=&EO;G,["B`@("`@("`@:68@*"%I<W-E="@D4T]!4%]O
M<'1I;VYS6R=-:6UE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53
M;V%P1F%U;'0H)TUI;64@56YS=7!P;W)T960L(&EN<W1A;&P@4$5!4CHZ36%I
M;#HZ36EM92<L)R<L)R<L)U-E<G9E<B<I.PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("`D<&%R86US6R=I;F-L=61E7V)O9&EE<R==
M(#T@5%)513L*("`@("`@("`D<&%R86US6R=D96-O9&5?8F]D:65S)UT@(#T@
M5%)513L*("`@("`@("`D<&%R86US6R=D96-O9&5?:&5A9&5R<R==(#T@5%)5
M13L*"B`@("`@("`@+R\@6%A8(&QA;64@=&AI;F<@=&\@:&%V92!T;R!D;R!F
M;W(@9&5C;V1I;F<*("`@("`@("`D9&5C;V1E<B`])B!N97<@36%I;%]M:6UE
M1&5C;V1E*"1D871A*3L*("`@("`@("`D<W1R=6-T=7)E(#T@)&1E8V]D97(M
M/F1E8V]D92@D<&%R86US*3L*"B`@("`@("`@:68@*&ES<V5T*"1S=')U8W1U
M<F4M/F)O9'DI*2!["B`@("`@("`@("`@("1D871A(#T@)'-T<G5C='5R92T^
M8F]D>3L*("`@("`@("`@("`@)&AE861E<G,@/2`D<W1R=6-T=7)E+3YH96%D
M97)S.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?2!E;'-E(&EF("AI
M<W-E="@D<W1R=6-T=7)E+3YP87)T<RDI('L*("`@("`@("`@("`@)&1A=&$@
M/2`D<W1R=6-T=7)E+3YP87)T<ULP72T^8F]D>3L*("`@("`@("`@("`@)&AE
M861E<G,@/2!A<G)A>5]M97)G92@D<W1R=6-T=7)E+3YH96%D97)S+"1S=')U
M8W1U<F4M/G!A<G1S6S!=+3YH96%D97)S*3L*("`@("`@("`@("`@:68@*&-O
M=6YT*"1S=')U8W1U<F4M/G!A<G1S*2`^(#$I('L*("`@("`@("`@("`@("`@
M("1M:6UE7W!A<G1S(#T@87)R87E?<W!L:6-E*"1S=')U8W1U<F4M/G!A<G1S
M+#$I.PH@("`@("`@("`@("`@("`@+R\@<')E<&%R92!T:&4@<&%R=',@9F]R
M('1H92!S;V%P('!A<G-E<@H*("`@("`@("`@("`@("`@("1C(#T@8V]U;G0H
M)&UI;65?<&%R=',I.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D<"`])B`D;6EM
M95]P87)T<ULD:5T["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P
M+3YH96%D97)S6R=C;VYT96YT+6QO8V%T:6]N)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%A86"!43T1/.B!M;V1I9GD@;&]C871I;VX@<&5R
M(%-W02!N;W1E('-E8W1I;VX@,PH@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!H='1P.B\O=W=W+G<S+F]R9R]44B]33T%0+6%T=&%C:&UE;G1S"B`@("`@
M("`@("`@("`@("`@("`@("`@("1A='1A8VAM96YT<ULD<"T^:&5A9&5R<ULG
M8V]N=&5N="UL;V-A=&EO;B==72`]("1P+3YB;V1Y.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1C:60@
M/2`G8VED.B<N<W5B<W1R*"1P+3YH96%D97)S6R=C;VYT96YT+6ED)UTL,2QS
M=')L96XH)'`M/FAE861E<G-;)V-O;G1E;G0M:60G72DM,BD["B`@("`@("`@
M("`@("`@("`@("`@("`@("1A='1A8VAM96YT<ULD8VED72`]("1P+3YB;V1Y
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TUI;64@<&%R<VEN9R!E<G)O
M<B<L)R<L)R<L)U-E<G9E<B<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]D96-O
M9&5$24U%365S<V%G92@F)&1A=&$L("8D:&5A9&5R<RP@)B1A='1A8VAM96YT
M<RD*("`@('L*("`@("`@("!G;&]B86P@)%-/05!?;W!T:6]N<SL*("`@("`@
M("!I9B`H(6ES<V5T*"133T%07V]P=&EO;G-;)T1)344G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@G1$E-12!5;G-U<'!O<G1E
M9"P@:6YS=&%L;"!014%2.CI.970Z.D1)344G+"<G+"<G+"=397)V97(G*3L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+R\@6%A8
M('1H:7,@4TA/54Q$(&)E(&UO=F5D('1O('1H92!T<F%N<W!O<G0@;&%Y97(L
M(&4N9RX@4$A0("!I='-E;&8*("`@("`@("`O+R!S:&]U;&0@:&%N9&QE('!A
M<G-I;F<@1$E-12`[*0H@("`@("`@("1D:6UE(#TF(&YE=R!.971?1$E-15]-
M97-S86=E*"D["B`@("`@("`@)&5R<B`]("1D:6UE+3YD96-O9&5$871A*"1D
M871A*3L*("`@("`@("!I9B`H(%!%05(Z.FES17)R;W(H)&5R<BD@*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)T9A:6QE9"!T;R!D
M96-O9&4@=&AE($1)344@;65S<V%G92$G+"<G+"<G+"=397)V97(G*3L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R8V%S
M96-M<"@D9&EM92T^<&%R='-;,%U;)W1Y<&4G72Q33T%07T5.5D5,3U`I("$]
M,"D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=$24U%
M(')E8V]R9"`Q(&ES(&YO="!A(%-/05`@96YV96QO<"$G+"<G+"<G+"=397)V
M97(G*3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@
M("`@("1D871A(#T@)&1I;64M/G!A<G1S6S!=6R=D871A)UT["B`@("`@("`@
M("`@("1H96%D97)S6R=C;VYT96YT+71Y<&4G72`]("=T97AT+WAM;"<[("\O
M(&9A:V4@:70@9F]R(&YO=PH@("`@("`@("`@("`D8R`](&-O=6YT*"1D:6UE
M+3YP87)T<RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("`D<&%R="`])B`D9&EM92T^<&%R='-;
M)&E=.PH@("`@("`@("`@("`@("`@+R\@6%A8('=E(&YE960@=&\@:&%N9&QE
M(%5222=S(&)E='1E<@H@("`@("`@("`@("`D:60@/2!S=')N8VUP*"`D<&%R
M=%LG:60G72P@)V-I9#HG+"`T("D@/R`G8VED.B<N)'!A<G1;)VED)UT@.B`D
M<&%R=%LG:60G73L*("`@("`@("`@("`@)&%T=&%C:&UE;G1S6R1I9%T@/2`D
M<&%R=%LG9&%T82==.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?
M7W-E=%]T>7!E7W1R86YS;&%T:6]N*"1T>7!E+"`D8VQA<W,]3E5,3"D*("`@
M('L*("`@("`@("`D='$@/28@;F5W(%%.86UE*"1T>7!E*3L*("`@("`@("!I
M9B`H(21C;&%S<RD@>PH@("`@("`@("`@("`D8VQA<W,@/2`D='$M/FYA;64[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?='EP95]T<F%N<VQA=&EO;ELD
M='EP95T])&-L87-S.PH@("`@?0I]"@HO*BH**B`@44YA;64**B!C;&%S<R!U
M<V5D('1O(&AA;F1L92!13D%-12!V86QU97,@:6X@6$U,"BH**B!`86-C97-S
M("`@<'5B;&EC"BH@0'9E<G-I;VX@("1)9#H@0F%S92YP:'`L=B`Q+C0P+C(N
M-"`R,#`T+S`Q+S$W(#$T.C(R.C4X(&%R;F%U9"!%>'`@)`HJ($!P86-K86=E
M("!33T%0.CI#;&EE;G0**B!`875T:&]R("`@4VAA;F4@0V%R879E;R`\<VAA
M;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S"BHO
M"F-L87-S(%%.86UE"GL*("`@('9A<B`D;F%M92`]("<G.PH@("`@=F%R("1N
M<R`]("<G.PH@("`@=F%R("1N86UE<W!A8V4])R<["B`@("`C=F%R("1A<G)A
M>4EN9F\@/2`G)SL*"B`@("!F=6YC=&EO;B!13F%M92@D;F%M92P@)&YA;65S
M<&%C92`]("<G*2!["B`@("`@("`@:68@*"1N86UE("8F("1N86UE6S!=(#T]
M("=[)RD@>PH@("`@("`@("`@("!P<F5G7VUA=&-H*"<O7'LH+BH_*5Q]*"XJ
M*2\G+"1N86UE+"`D;2D["B`@("`@("`@("`@("1T:&ES+3YN86UE(#T@)&U;
M,ET["B`@("`@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D;5LQ73L*("`@
M("`@("!](&5L<V4@:68@*'-T<G!O<R@D;F%M92P@)SHG*2`A/2!&04Q312D@
M>PH@("`@("`@("`@("`D<R`]('-P;&ET*"<Z)RPD;F%M92D["B`@("`@("`@
M("`@("1S(#T@87)R87E?<F5V97)S92@D<RD["B`@("`@("`@("`@("1T:&ES
M+3YN86UE(#T@)'-;,%T["B`@("`@("`@("`@("1T:&ES+3YN<R`]("1S6S%=
M.PH@("`@("`@("`@("`D=&AI<RT^;F%M97-P86-E(#T@)&YA;65S<&%C93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^;F%M92`]("1N
M86UE.PH@("`@("`@("`@("`D=&AI<RT^;F%M97-P86-E(#T@)&YA;65S<&%C
M93L*("`@("`@("!]"@H@("`@("`@(",@82!L:71T;&4@;6]R92!M86=I8R!T
M:&%N('-H;W5L9"!B92!I;B!A('%N86UE"B`@("`@("`@)'`@/2!S=')P;W,H
M)'1H:7,M/FYA;64L("=;)RD["B`@("`@("`@:68@*"1P*2!["B`@("`@("`@
M("`@(",@6%A8(&YE960@=&\@<F4M97AA;6EN92!T:&ES(&QO9VEC(&QA=&5R
M"B`@("`@("`@("`@(",@8VAO<"!O9F8@6UT*("`@("`@("`@("`@)'1H:7,M
M/F%R<F%Y4VEZ92`]('-P;&ET*"<L)RQS=6)S='(H)'1H:7,M/FYA;64L)'`K
M,2P@<W1R;&5N*"1T:&ES+3YN86UE*2TD<"TR*2D["B`@("`@("`@("`@("1T
M:&ES+3YA<G)A>4EN9F\@/2!S=6)S='(H)'1H:7,M/FYA;64L("1P*3L*("`@
M("`@("`@("`@)'1H:7,M/FYA;64@/2!S=6)S='(H)'1H:7,M/FYA;64L(#`L
M("1P*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9G%N*"D*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/FYA;65S<&%C92D@>PH@("`@("`@("`@
M("!R971U<FX@)WLG+B1T:&ES+3YN86UE<W!A8V4N)WTG+B1T:&ES+3YN86UE
M.PH@("`@("`@('T@96QS92!I9B`H)'1H:7,M/FYS*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;G,N)SHG+B1T:&ES+3YN86UE.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/FYA;64["B`@("!]"@I]"C\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O5')A
M;G-P;W)T+G!H<```````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`U-C$Q`#$P-#$W,S8S,#`V`#`R,#8Q,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3
M:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%
M05(@86YD(&UO<F4@("!\"B\O('P@075T:&]R<SH@1&EE=')I8V@@07EA;&$@
M/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!4
M<F%N<W!O<G0N<&AP+'8@,2XR,B`R,#`S+S`T+S(P(#`Q.C`U.C,T('-H86YE
M($5X<"`D"B\O"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G.PH*+RHJ
M"BH@4T]!4"!4<F%N<W!O<G0@3&%Y97(**@HJ(%1H:7,@;&%Y97(@8V%N('5S
M92!D:69F97)E;G0@<')O=&]C;VQS(&1E<&5N9&%N="!O;B!T:&4@96YD<&]I
M;G0@=7)L('!R;W9I9&5D"BH@;F\@:VYO=VQE9V4@;V8@=&AE(%-/05`@<')O
M=&]C;VP@:7,@879A:6QA8FQE(&%T('1H:7,@;&5V96P**B!N;R!K;F]W;&5G
M92!O9B!T:&4@=')A;G-P;W)T('!R;W1O8V]L<R!I<R!A=F%I;&%B;&4@870@
M=&AI<R!L979E;`HJ"BH@0&%C8V5S<R`@('!U8FQI8PHJ($!V97)S:6]N("`D
M260Z(%1R86YS<&]R="YP:'`L=B`Q+C(R(#(P,#,O,#0O,C`@,#$Z,#4Z,S0@
M<VAA;F4@17AP("0**B!`<&%C:V%G92`@4T]!4#HZ5')A;G-P;W)T"BH@0&%U
M=&AO<B`@(%-H86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^"BHO"F-L87-S
M(%-/05!?5')A;G-P;W)T"GL*("`@(&9U;F-T:6]N("9G9714<F%N<W!O<G0H
M)'5R;"P@)&5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.0T]$24Y'*0H@("`@
M>PH@("`@("`@("1U<FQP87)T<R`]($!P87)S95]U<FPH)'5R;"D["B`@("`@
M("`@"B`@("`@("`@:68@*"$D=7)L<&%R='-;)W-C:&5M92==*2!["B`@("`@
M("`@("`@(')E='5R;B!33T%07T)A<V5?3V)J96-T.CI?<F%I<V53;V%P1F%U
M;'0H(DEN=F%L:60@=')A;G-P;W)T(%5223H@)'5R;"(I.PH@("`@("`@('T*
M("`@("`@("`*("`@("`@("!I9B`H<W1R8V%S96-M<"@D=7)L<&%R='-;)W-C
M:&5M92==+"`G;6%I;'1O)RD@/3T@,"D@>PH@("`@("`@("`@("`D=')A;G-P
M;W)T7W1Y<&4@/2`G4TU44"<["B`@("`@("`@?2!E;'-E(&EF("AS=')C87-E
M8VUP*"1U<FQP87)T<ULG<V-H96UE)UTL("=H='1P<R<I(#T](#`I('L*("`@
M("`@("`@("`@)'1R86YS<&]R=%]T>7!E(#T@)TA45%`G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\J(&AA;F1L92!O=&AE<B!T<F%N<W!O<G0@
M='EP97,@*B\*("`@("`@("`@("`@)'1R86YS<&]R=%]T>7!E(#T@<W1R=&]U
M<'!E<B@D=7)L<&%R='-;)W-C:&5M92==*3L*("`@("`@("!]"B`@("`@("`@
M)'1R86YS<&]R=%]I;F-L=61E(#T@)U-/05`O5')A;G-P;W)T+R<N)'1R86YS
M<&]R=%]T>7!E+B<N<&AP)SL*("`@("`@("`D<F5S(#T@0&EN8VQU9&5?;VYC
M92@D=')A;G-P;W)T7VEN8VQU9&4I.PH@("`@("`@(&EF*"$D<F5S("8F("%I
M;E]A<G)A>2@D=')A;G-P;W)T7VEN8VQU9&4L(&=E=%]I;F-L=61E9%]F:6QE
M<R@I*2D@>PH@("`@("`@("`@("!R971U<FX@4T]!4%]"87-E7T]B:F5C=#HZ
M7W)A:7-E4V]A<$9A=6QT*").;R!4<F%N<W!O<G0@9F]R('LD=7)L<&%R='-;
M)W-C:&5M92==?2(I.PH@("`@("`@('T*("`@("`@("`D=')A;G-P;W)T7V-L
M87-S(#T@(E-/05!?5')A;G-P;W)T7R1T<F%N<W!O<G1?='EP92(["B`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)'1R86YS<&]R=%]C;&%S<RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%-/05!?0F%S95]/8FIE8W0Z.E]R86ES95-O87!&
M875L="@B3F\@5')A;G-P;W)T(&-L87-S("1T<F%N<W!O<G1?8VQA<W,B*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(&YE=R`D=')A;G-P;W)T7V-L87-S
M*"1U<FPL("1E;F-O9&EN9RD["B`@("!]"GT@+R\@96YD(%-/05!?5')A;G-P
M;W)T"C\^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]686QU92YP:'``````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30V-C0`,3`T,3<S-C,P
M,#8`,#$W-S`R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H
M86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R92`@('P*
M+R\@?"!!=71H;W)S.B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N
M8V]M/B!/<FEG:6YA;"!!=71H;W(@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(%9A;'5E+G!H<"QV(#$N,S4@
M,C`P,R\P-"\Q,2`P-3HS,CHQ-R!S:&%N92!%>'`@)`HO+PIR97%U:7)E7V]N
M8V4@)U-/05`O0F%S92YP:'`G.PH*+RHJ"BH@(%-/05`Z.E9A;'5E"BH@=&AI
M<R!C;&%S<R!C;VYV97)T<R!V86QU97,@8F5T=V5E;B!02%`@86YD(%-/05`*
M*@HJ(&]R:6=I;F%L>2!B87-E9"!O;B!33T%0>#0@8GD@1&EE=')I8V@@07EA
M;&$@:'1T<#HO+V1I971R:6-H+F=A;G@T+F-O;2]S;V%P>#0**@HJ($!A8V-E
M<W,@<'5B;&EC"BH@0'9E<G-I;VX@)$ED.B!686QU92YP:'`L=B`Q+C,U(#(P
M,#,O,#0O,3$@,#4Z,S(Z,3<@<VAA;F4@17AP("0**B!`<&%C:V%G92!33T%0
M.CI#;&EE;G0**B!`875T:&]R(%-H86YE($-A<F%V96\@/'-H86YE0'!H<"YN
M970^($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@=7!D871E<PHJ($!A=71H;W(@
M1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@
M075T:&]R"BHO"F-L87-S(%-/05!?5F%L=64*>PH@("`@+RHJ"B`@("`J"B`@
M("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D=F%L=64@
M/2!.54Q,.PH@("`@"B`@("`O*BH*("`@("H*("`@("H@0'9A<B`@<W1R:6YG
M"B`@("`J+PH@("`@=F%R("1N86UE(#T@)R<["B`@("`*("`@("\J*@H@("`@
M*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)'1Y<&4@/2`G
M)SL*("`@(`H@("`@+RHJ"B`@("`J($YA;65S<&%C90H@("`@*@H@("`@*B!`
M=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)&YA;65S<&%C92`]("<G.PH@
M("`@=F%R("1T>7!E7VYA;65S<&%C92`]("<G.PH@("`@"B`@("!V87(@)&%T
M=')I8G5T97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@*@H@("`@*B!`=F%R
M('-T<FEN9PH@("`@*B\*("`@('9A<B`D87)R87E4>7!E(#T@)R<["B`@("`*
M("`@('9A<B`D;W!T:6]N<R`](&%R<F%Y*"D["@H@("`@=F%R("1N<6X["B`@
M("!V87(@)'1Q;CL*("`@("\J*@H@("`@*@H@("`@*@H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("!N86UE(&]F('1H92!S;V%P+79A;'5E('MN86UE<W!A8V5]
M;F%M90H@("`@*B!`<&%R86T@("`@;6EX960@("!S;V%P('9A;'5E('MN86UE
M<W!A8V5]='EP92P@:68@;F]T('-E="!A;B!A=71O;6%T:6,@"B`@("`J($!P
M87)A;2`@("!M:7AE9"`@('9A;'5E('1O('-E=`H@("`@*B\*("`@(&9U;F-T
M:6]N(%-/05!?5F%L=64H)&YA;64@/2`G)RP@)'1Y<&4@/2!F86QS92P@)'9A
M;'5E/4Y53$PL("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`O+R!D971E8W0@='EP92!I9B!N;W0@<&%S<V5D"B`@("`@("`@)'1H:7,M
M/FYQ;B`])B!N97<@44YA;64H)&YA;64I.PH@("`@("`@("1T:&ES+3YN86UE
M(#T@)'1H:7,M/FYQ;BT^;F%M93L*("`@("`@("`D=&AI<RT^;F%M97-P86-E
M(#T@)'1H:7,M/FYQ;BT^;F%M97-P86-E.PH@("`@("`@("1T:&ES+3YT<6X@
M/28@;F5W(%%.86UE*"1T>7!E*3L*("`@("`@("`D=&AI<RT^='EP92`]("1T
M:&ES+3YT<6XM/FYA;64["B`@("`@("`@)'1H:7,M/G1Y<&5?<')E9FEX(#T@
M)'1H:7,M/G1Q;BT^;G,["B`@("`@("`@)'1H:7,M/G1Y<&5?;F%M97-P86-E
M(#T@)'1H:7,M/G1Q;BT^;F%M97-P86-E.PH@("`@("`@("1T:&ES+3YV86QU
M92`])B`D=F%L=64["B`@("`@("`@)'1H:7,M/F%T=')I8G5T97,@/2`D871T
M<FEB=71E<SL*("`@('T*("`@(`H@("`@+RHJ"B`@("`J(%-E<FEA;&EZ90H@
M("`@*B`*("`@("H@0')E='5R;B`@('-T<FEN9R`@>&UL(')E<')E<V5N=&%T
M:6]N"B`@("`J+PH@("`@9G5N8W1I;VX@)G-E<FEA;&EZ92@F)'-E<FEA;&EZ
M97(I"B`@("!["B`@("`@("`@<F5T=7)N("1S97)I86QI>F5R+3Y?<V5R:6%L
M:7IE5F%L=64H)'1H:7,M/G9A;'5E+"`D=&AI<RT^;F%M92P@)'1H:7,M/G1Y
M<&4L("1T:&ES+3YN86UE<W!A8V4L("1T:&ES+3YT>7!E7VYA;65S<&%C92P@
M)'1H:7,M/F]P=&EO;G,L("1T:&ES+3YA='1R:6)U=&5S+"`D=&AI<RT^87)R
M87E4>7!E*3L*("`@('T*?0H*"B\J*@H@*B`@4T]!4#HZ2&5A9&5R"B`J('1H
M:7,@8VQA<W,@8V]N=F5R=',@=F%L=65S(&)E='=E96X@4$A0(&%N9"!33T%0
M"B`J(&ET(&ES(&$@<VEM<&QE('=R87!P97(@87)O=6YD(%-/05!?5F%L=64L
M(&%D9&EN9R!S=7!P;W)T(&9O<@H@*B!S;V%P(&%C=&]R(&%N9"!M=7-T=6YD
M97)S=&%N9"!P87)A;65T97)S"B`J"B`J(&]R:6=I;F%L>2!B87-E9"!O;B!3
M3T%0>#0@8GD@1&EE=')I8V@@07EA;&$@:'1T<#HO+V1I971R:6-H+F=A;G@T
M+F-O;2]S;V%P>#0*("H*("H@0&%C8V5S<R!P=6)L:6,*("H@0'9E<G-I;VX@
M)$ED.B!686QU92YP:'`L=B`Q+C,U(#(P,#,O,#0O,3$@,#4Z,S(Z,3<@<VAA
M;F4@17AP("0*("H@0'!A8VMA9V4@4T]!4#HZ2&5A9&5R"B`J($!A=71H;W(@
M4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!0
M14%2(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@1&EE=')I8V@@07EA;&$@/&1I
M971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J+PIC;&%S<R!3
M3T%07TAE861E<B!E>'1E;F1S(%-/05!?5F%L=64*>PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!N86UE(&]F('1H92!S;V%P+79A;'5E(#QV86QU95]N86UE/@H@("`@("H@
M0'!A<F%M("`@(&UI>&5D("`@<V]A<"!H96%D97(@=F%L=64*("`@("`J($!P
M87)A;2`@("!S=')I;F<@;F%M97-P86-E"B`@("`@*B!`<&%R86T@("`@:6YT
M(&UU<W1U;F1E<G-T86YD("AZ97)O(&]R(&]N92D*("`@("`J($!P87)A;2`@
M("!S=')I;F<@86-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%](96%D
M97(H)&YA;64@/2`G)RP@)'1Y<&4L("1V86QU92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("1M=7-T=6YD97)S=&%N9"`](#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D86-T;W(@/2`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO
M<F<O<V]A<"]A8W1O<B]N97AT)RD*("`@('L*("`@("`@("!P87)E;G0Z.E-/
M05!?5F%L=64H)&YA;64L("1T>7!E+"`D=F%L=64I.PH@("`@("`@("1T:&ES
M+3YA='1R:6)U=&5S6R=33T%0+45.5CIA8W1O<B==(#T@)&%C=&]R.PH@("`@
M("`@("1T:&ES+3YA='1R:6)U=&5S6R=33T%0+45.5CIM=7-T56YD97)S=&%N
M9"==(#T@*&EN="DD;75S='5N9&5R<W1A;F0["B`@("!]"GT*"B\J*@H@*B`@
M4T]!4#HZ071T86-H;65N=`H@*B!T:&ES(&-L87-S(&-O;G9E<G1S('9A;'5E
M<R!B971W965N(%!(4"!A;F0@4T]!4`H@*B!I="!H86YD;&5S($UI;64@871T
M86-H96UE;G1S('!E<B!7,T,@3F]T92!O;B!3;V%P($%T=&%C:&5M96YT<R!A
M=`H@*B!H='1P.B\O=W=W+G<S+F]R9R]44B]33T%0+6%T=&%C:&UE;G1S"B`J
M"B`J"B`J($!A8V-E<W,@<'5B;&EC"B`J($!P86-K86=E(%-/05`Z.D%T=&%C
M:&UE;G0*("H@0&%U=&AO<B!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T
M/B!#;VYV97)S:6]N('1O(%!%05(@86YD('5P9&%T97,*("HO"F-L87-S(%-/
M05!?071T86-H;65N="!E>'1E;F1S(%-/05!?5F%L=64*>PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!N86UE(&]F('1H92!S;V%P+79A;'5E(#QV86QU95]N86UE/@H@("`@
M("H@0'!A<F%M("`@(&UI>&5D("`@<V]A<"!H96%D97(@=F%L=64*("`@("`J
M($!P87)A;2`@("!S=')I;F<@;F%M97-P86-E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%-/05!?071T86-H;65N="@D;F%M92`]("<G+"`D='EP92`]("=A<'!L
M:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F:6QE;F%M92P@)&9I;&4]3E5,3"D*("`@('L*("`@("`@("!G
M;&]B86P@)%-/05!?;W!T:6]N<SL*("`@("`@("!I9B`H(6ES<V5T*"133T%0
M7V]P=&EO;G-;)TUI;64G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)TUA:6Q?;6EM92!I<R!N;W0@:6YS=&%L;&5D+"!U;F%B
M;&4@=&\@<W5P<&]R="!33T%0($%T=&%C:&5M96YT<R<I.PH@("`@("`@('T*
M("`@("`@("!P87)E;G0Z.E-/05!?5F%L=64H)&YA;64L($Y53$PL($Y53$PI
M.PH@("`@("`@(`H@("`@("`@("1F:6QE9&%T82`]("@D9FEL92`]/3T@3E5,
M3"D@/R`D=&AI<RT^7V9I;&4R<W1R*"1F:6QE;F%M92D@.B`D9FEL93L*("`@
M("`@("`D9FEL96YA;64@/2!B87-E;F%M92@D9FEL96YA;64I.PH@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1F:6QE9&%T82DI('L*("`@("`@("`@("`@
M<F5T=7)N("1F:6QE9&%T83L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@
M)&-I9"`](&UD-2AU;FEQ:60H=&EM92@I*2D["B`@("`@("`@"B`@("`@("`@
M)'1H:7,M/F%T=')I8G5T97-;)VAR968G72`]("=C:60Z)RXD8VED.PH@("`@
M("`@(`H@("`@("`@("1T:&ES+3YO<'1I;VYS6R=A='1A8VAM96YT)UT@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F]D>2<@
M("`@(#T^("1F:6QE9&%T82P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9&ES<&]S:71I;VXG("`@("`]/B`D9FEL96YA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V-O;G1E;G1?='EP92<@("`]/B`D
M='EP92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G96YC;V1I
M;F<G(#T^("=B87-E-C0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=C:60G(#T^("1C:60*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("D["B`@("!]"@H@("`@+RH*("`@("H@4F5T=7)N<R!T:&4@8V]N=&5N
M=',@;V8@=&AE(&=I=F5N(&9I;&4@;F%M92!A<R!S=')I;F<*("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL95]N86UE"B`@("`J($!R971U<FX@<W1R:6YG"B`@
M("`J($!A8V-E<R!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I;VX@)B!?9FEL
M93)S='(H)&9I;&5?;F%M92D*("`@('L*("`@("`@("!I9B`H(6ES7W)E861A
M8FQE*"1F:6QE7VYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=&:6QE(&ES(&YO="!R96%D86)L92`G("X@)&9I;&5?;F%M
M92D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&9D(#T@9F]P96XH)&9I;&5?
M;F%M92P@)W)B)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T-O=6QD(&YO="!O<&5N("<@+B`D9FEL95]N86UE*3L*("`@("`@
M("!]"B`@("`@("`@)&-O;G0@/2!F<F5A9"@D9F0L(&9I;&5S:7IE*"1F:6QE
M7VYA;64I*3L*("`@("`@("!F8VQO<V4H)&9D*3L*("`@("`@("!R971U<FX@
M)&-O;G0["B`@("!]"GT*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O1F%U;'0N
M<&AP````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P
M-38T`#$P-#$W,S8S,#`V`#`Q-S8W-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H
M="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT
M>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS
M92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@
M("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N
M92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@
M86YD(&UO<F4@("!\"B\O('P@075T:&]R<SH@1&EE=')I8V@@07EA;&$@/&1I
M971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!&875L
M="YP:'`L=B`Q+C$S(#(P,#,O,#0O,3,@,C$Z,S@Z-3@@<VAA;F4@17AP("0*
M+R\*<F5Q=6ER95]O;F-E*"=014%2+G!H<"<I.PH*+RHJ"B`J(%-/05!?1F%U
M;'0*("H@4$5!4CHZ17)R;W(@=W)A<'!E<B!U<V5D('1O(&UA=&-H(%-/05`@
M1F%U;'1S('1O(%!%05(@17)R;W)S"B`J"B`J($!P86-K86=E("!33T%0"B`J
M($!A8V-E<W,@("!P=6)L:6,*("H@0&%U=&AO<B`@(%-H86YE($-A<F%V96\@
M/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R90H@
M*B!`875T:&]R("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O
M;3X@3W)I9VEN86P@075T:&]R"B`J($!V97)S:6]N("`D260Z($9A=6QT+G!H
M<"QV(#$N,3,@,C`P,R\P-"\Q,R`R,3HS.#HU."!S:&%N92!%>'`@)`H@*B\*
M8VQA<W,@4T]!4%]&875L="!E>'1E;F1S(%!%05)?17)R;W(*>PH@("`@"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B`*("`@("`J($!P87)A
M;2`@("!S=')I;F<@(&UE<W-A9V4@<W1R:6YG(&9O<B!F875L=`H@("`@("H@
M0'!A<F%M("`@(&UI>&5D("`@=&AE(&9A=6QT8V]D90H@("`@("H@0'!A<F%M
M("`@(&UI>&5D("`@<V5E(%!%05(Z.D524D]2(`H@("`@("H@0'!A<F%M("`@
M(&UI>&5D("`@<V5E(%!%05(Z.D524D]2(`H@("`@("H@0'!A<F%M("`@(&%R
M<F%Y("`@=&AE('5S97)I;F9O(&%R<F%Y(&ES('5S960@=&\@<&%S<R!I;B!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@(%-/05`@86-T;W(@86YD(&1E
M=&%I;"!F;W(@=&AE(&9A=6QT"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?
M1F%U;'0H)&9A=6QT<W1R:6YG(#T@)W5N:VYO=VX@97)R;W(G+"`D9F%U;'1C
M;V1E(#T@)T-L:65N="<L("1F875L=&%C=&]R/4Y53$PL("1D971A:6P]3E5,
M3"P@)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@
M("`@<&%R96YT.CI014%27T5R<F]R*"1F875L='-T<FEN9RP@)&9A=6QT8V]D
M92P@)&UO9&4L("1O<'1I;VYS+"`D9&5T86EL*3L*("`@("`@("!I9B`H)&9A
M=6QT86-T;W(I("1T:&ES+3YE<G)O<E]M97-S86=E7W!R969I>"`]("1F875L
M=&%C=&]R.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J(&UE<W-A9V4*("`@
M("`J"B`@("`@*B!R971U<FYS(&$@4T]!4%]-97-S86=E(&-L87-S('1H870@
M8V%N(&)E('-E;G0@87,@82!S97)V97(@<F5S<&]N<V4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(%-/05!?365S<V%G92`*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&UE<W-A9V4H*0H@("`@>PH@("`@("`@
M("1M<V<@/28@;F5W(%-/05!?0F%S92@I.PH@("`@("`@("1P87)A;7,@/2!A
M<G)A>2@I.PH@("`@("`@("1P87)A;7-;72`])B!N97<@4T]!4%]686QU92@G
M9F%U;'1C;V1E)RP@)U%.86UE)RP@)U-/05`M14Y6.B<N)'1H:7,M/F-O9&4I
M.PH@("`@("`@("1P87)A;7-;72`])B!N97<@4T]!4%]686QU92@G9F%U;'1S
M=')I;F<G+"`G<W1R:6YG)RP@)'1H:7,M/FUE<W-A9V4I.PH@("`@("`@("1P
M87)A;7-;72`])B!N97<@4T]!4%]686QU92@G9F%U;'1A8W1O<B<L("=A;GE5
M4DDG+"`D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@I.PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^8F%C:W1R86-E*2D@>PH@("`@("`@("`@("`D<&%R
M86US6UT@/28@;F5W(%-/05!?5F%L=64H)V1E=&%I;"<L("=S=')I;F<G+"`D
M=&AI<RT^8F%C:W1R86-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<&%R86US6UT@/28@;F5W(%-/05!?5F%L=64H)V1E=&%I;"<L("=S=')I
M;F<G+"`D=&AI<RT^=7-E<FEN9F\I.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("`D;65T:&]D5F%L=64@/28@;F5W(%-/05!?5F%L=64H)WLG+E-/05!?
M14Y614Q/4"XG?49A=6QT)RP@)U-T<G5C="<L("1P87)A;7,I.PH@("`@("`@
M("1H96%D97)S(#T@3E5,3#L*("`@("`@("!R971U<FX@)&US9RT^7VUA:V5%
M;G9E;&]P92@D;65T:&]D5F%L=64L("1H96%D97)S*3L*("`@('T*("`@(`H@
M("`@+RHJ"B`@("`@*B!G971&875L=`H@("`@("H*("`@("`J(')E='5R;G,@
M82!S:6UP;&4@;F%T:79E('!H<"!A<G)A>2!C;VYT86EN:6YG('1H92!F875L
M="!D871A"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9A=6QT*"D*
M("`@('L*("`@("`@("!G;&]B86P@)%-/05!?3T)*14-47U-44E5#5#L*("`@
M("`@("!I9B`H)%-/05!?3T)*14-47U-44E5#5"D@>PH@("`@("`@("`@("`D
M9F%U;'0@/28@;F5W('-T9$-L87-S*"D["B`@("`@("`@("`@("1F875L="T^
M9F%U;'1C;V1E(#T@)'1H:7,M/F-O9&4["B`@("`@("`@("`@("1F875L="T^
M9F%U;'1S=')I;F<@/2`D=&AI<RT^;65S<V%G93L*("`@("`@("`@("`@)&9A
M=6QT+3YF875L=&%C=&]R(#T@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX
M.PH@("`@("`@("`@("`D9F%U;'0M/F1E=&%I;"`]("1T:&ES+3YU<V5R:6YF
M;SL*("`@("`@("`@("`@<F5T=7)N("1F875L=#L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`@("`@)V9A=6QT8V]D92<@
M/3X@)'1H:7,M/F-O9&4L"B`@("`@("`@("`@("`@("`G9F%U;'1S=')I;F<G
M(#T^("1T:&ES+3YM97-S86=E+`H@("`@("`@("`@("`@("`@)V9A=6QT86-T
M;W(G(#T^("1T:&ES+3YE<G)O<E]M97-S86=E7W!R969I>"P*("`@("`@("`@
M("`@("`@("=D971A:6PG(#T^("1T:&ES+3YU<V5R:6YF;PH@("`@("`@("`@
M("`I.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J(&=E=$%C=&]R"B`@("`@
M*@H@("`@("H@<F5T=7)N<R!T:&4@4T]!4"!A8W1O<B!F;W(@=&AE(&9A=6QT
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971!8W1O<B@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YE<G)O<E]M97-S86=E7W!R969I>#L*
M("`@('T*("`@(`H@("`@+RHJ"B`@("`@*B!G971$971A:6P*("`@("`J"B`@
M("`@*B!R971U<FYS('1H92!F875L="!D971A:6P*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$1E=&%I;"@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YU<V5R:6YF;SL*("`@('T*("`@(`I]"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]087)S97(N<&AP````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#<W-#,`,3`T,3<S
M-C,P,#8`,#(P,#8V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW
M+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F
M('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D
M('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I
M<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*
M+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@
M/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R92`@
M('P*+R\@?"!!=71H;W)S.B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N
M>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(%!A<G-E<BYP:'`L=B`Q
M+C,S(#(P,#,O,#0O,C`@,#$Z,#4Z,S0@<VAA;F4@17AP("0*+R\*"G)E<75I
M<F5?;VYC92`G4T]!4"]"87-E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]6
M86QU92YP:'`G.PH*+RHJ"BH@4T]!4"!087)S97(**B!T:&ES(&-L87-S(&ES
M('5S960@8GD@4T]!4#HZ365S<V%G92!A;F0@4T]!4#HZ4V5R=F5R('1O('!A
M<G-E('-O87`@<&%C:V5T<PHJ"BH@;W)I9VEN86QY(&)A<V5D(&]N(%-/05!X
M-"!B>2!$:65T<FEC:"!!>6%L82!H='1P.B\O9&EE=')I8V@N9V%N>#0N8V]M
M+W-O87!X-`HJ"BH@0&%C8V5S<R!P=6)L:6,**B!`=F5R<VEO;B`D260Z(%!A
M<G-E<BYP:'`L=B`Q+C,S(#(P,#,O,#0O,C`@,#$Z,#4Z,S0@<VAA;F4@17AP
M("0**B!`<&%C:V%G92!33T%0.CI087)S97(**B!`875T:&]R(%-H86YE($-A
M<F%V96\@/'-H86YE0'!H<"YN970^($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@
M=7!D871E<PHJ($!A=71H;W(@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A
M;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"BHO"F-L87-S(%-/05!?4&%R<V5R
M(&5X=&5N9',@4T]!4%]"87-E"GL*("`@('9A<B`D<W1A='5S(#T@)R<["B`@
M("!V87(@)'!O<VET:6]N(#T@,#L*("`@('9A<B`D<&]S7W-T870@/2`P.PH@
M("`@=F%R("1D97!T:"`](#`["B`@("!V87(@)&1E9F%U;'1?;F%M97-P86-E
M(#T@)R<["B`@("!V87(@)&UE<W-A9V4@/2!A<G)A>2@I.PH@("`@=F%R("1D
M97!T:%]A<G)A>2`](&%R<F%Y*"D["B`@("!V87(@)'!R979I;W5S7V5L96UE
M;G0@/2`G)SL*("`@('9A<B`D<V]A<')E<W!O;G-E(#T@3E5,3#L*("`@('9A
M<B`D<V]A<&AE861E<G,@/2!.54Q,.PH@("`@=F%R("1P87)E;G0@/2`P.PH@
M("`@=F%R("1R;V]T7W-T<G5C=%]N86UE(#T@87)R87DH*3L*("`@('9A<B`D
M:&5A9&5R7W-T<G5C=%]N86UE(#T@87)R87DH*3L*("`@('9A<B`D8W5R96YT
M7W)O;W1?<W1R=6-T7VYA;64@/2`G)SL*("`@('9A<B`D96YT:71I97,@/2!A
M<G)A>2`H("<F)R`]/B`G)F%M<#LG+"`G/"<@/3X@)R9L=#LG+"`G/B<@/3X@
M)R9G=#LG+"`B)R(@/3X@)R9A<&]S.R<L("<B)R`]/B`G)G%U;W0[)R`I.PH@
M("`@=F%R("1R;V]T7W-T<G5C="`](&%R<F%Y*"D["B`@("!V87(@)&AE861E
M<E]S=')U8W0@/2!A<G)A>2@I.PH@("`@=F%R("1C=7)E;G1?<F]O=%]S=')U
M8W0@/2`P.PH@("`@=F%R("1R969E<F5N8V5S(#T@87)R87DH*3L*("`@('9A
M<B`D;F5E9%]R969E<F5N8V5S(#T@87)R87DH*3L*("`@('9A<B`D6$U,4V-H
M96UA5F5R<VEO;CL*("`@('9A<B`D8F]D>41E<'1H.R`O+R!U<V5D('1O(&AA
M;F1L92!N;VXM<F]O="!E;&5M96YT<R!B969O<F4@<F]O="!B;V1Y(&5L96UE
M;G0*("`@(`H@("`@+RHJ"B`@("`@*B!33T%07U!A<G-E<B!C;VYS=')U8W1O
M<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@>&UL(&-O;G1E;G0*("`@
M("`J($!P87)A;2!S=')I;F<@>&UL(&-H87)A8W1E<B!E;F-O9&EN9RP@9&5F
M875L=',@=&\@)U541BTX)PH@("`@("HO"B`@("!F=6YC=&EO;B!33T%07U!A
M<G-E<B@F)'AM;"P@)&5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.0T]$24Y'
M+"`D871T86-H;65N=',]3E5,3"D*("`@('L*("`@("`@("!P87)E;G0Z.E-/
M05!?0F%S92@G4&%R<V5R)RD["B`@("`@("`@)'1H:7,M/E]S97138VAE;6%6
M97)S:6]N*%-/05!?6$U,7U-#2$5-05]615)324].*3L*("`@("`@("`*("`@
M("`@("`D=&AI<RT^871T86-H;65N=',@/2`D871T86-H;65N=',["B`@("`@
M("`@"B`@("`@("`@+R\@8VAE8VL@=&AE('AM;"!T86<@9F]R(&5N8V]D:6YG
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\\7#]X;6Q;7CY=*V5N8V]D:6YG
M7',J/SU<<RH_*%PG*%M>7"==*BE<)WPB*%M>(ETJ*2(I6UX^72H_6UP_73XO
M)RPD>&UL+"1M*2D@>PH@("`@("`@("`@("`D96YC;V1I;F<@/2!S=')T;W5P
M<&5R*"1M6S)=/R1M6S)=.B1M6S-=*3L*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@+R\@9&5T97)M:6YE<R!W:&5R92!I;B!T:&4@;65S<V%G92!W92!A
M<F4@*&5N=F5L;W!E+&AE861E<BQB;V1Y+&UE=&AO9"D*("`@("`@("`O+R!#
M:&5C:R!W:&5T:&5R(&-O;G1E;G0@:&%S(&)E96X@<F5A9"X*("`@("`@("!I
M9B`H(65M<'1Y*"1X;6PI*2!["B`@("`@("`@("`@("\O('!R97!A<F4@=&AE
M('AM;"!P87)S97(*("`@("`@("`@("`@)'!A<G-E<B`]('AM;%]P87)S97)?
M8W)E871E*"1E;F-O9&EN9RD["B`@("`@("`@("`@('AM;%]P87)S97)?<V5T
M7V]P=&EO;B@D<&%R<V5R+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@,"D[
M"B`@("`@("`@("`@('AM;%]S971?;V)J96-T*"1P87)S97(L("1T:&ES*3L*
M("`@("`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'!A<G-E<BP@
M)W-T87)T16QE;65N="<L)V5N9$5L96UE;G0G*3L*("`@("`@("`@("`@>&UL
M7W-E=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1P87)S97(L)V-H87)A8W1E
M<D1A=&$G*3L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O('-O;64@;&%M
M92!S;V%P(&EM<&QE;65N=&%T:6]N<R!A9&0@;G5L;"!B>71E<R!A="!T:&4*
M("`@("`@("`@("`@+R\@96YD(&]F('1H92!S;V%P('-T<F5A;2P@86YD(&5X
M<&%T(&-H;V%K<R!O;B!T:&%T"B`@("`@("`@("`@(&EF("@D>&UL6W-T<FQE
M;B@D>&UL*2TQ73T],"D*("`@("`@("`@("`@("`@("1X;6P@/2!T<FEM*"1X
M;6PI.PH@("`@("`@("`@("`*("`@("`@("`@("`@+R\@4&%R<V4@=&AE(%A-
M3"!F:6QE+@H@("`@("`@("`@("!I9B`H(7AM;%]P87)S92@D<&%R<V5R+"1X
M;6PL=')U92DI('L*("`@("`@("`@("`@("`@("1E<G(@/2!S<')I;G1F*"=8
M34P@97)R;W(@;VX@;&EN92`E9"!C;VP@)60@8GET92`E9"`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1P
M87)S97(I+`H@("`@("`@("`@("`@("`@("`@('AM;%]G971?8W5R<F5N=%]C
M;VQU;6Y?;G5M8F5R*"1P87)S97(I+`H@("`@("`@("`@("`@("`@("`@('AM
M;%]G971?8W5R<F5N=%]B>71E7VEN9&5X*"1P87)S97(I+`H@("`@("`@("`@
M("`@("`@("`@('AM;%]E<G)O<E]S=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E
M*"1P87)S97(I*2D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*"1E<G(L:'1M;'-P96-I86QC:&%R<R@D>&UL*2D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1P87)S97(I.PH@
M("`@("`@('T*("`@('T*("`@(`H@("`*("`@("\J*@H@("`@("H@9&]M=6QT
M:0H@("`@("H@<F5C=7)S92!T;R!B=6EL9"!A(&UU;'1I+61I;2!A<G)A>2P@
M=7-E9"!B>2!B=6EL9%)E<W!O;G-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O;75L=&DH)&0L("8D87(L
M("8D<BP@)B1V+"`D860],"D*("`@('L*("`@("`@("!I9B`H)&0I('L*("`@
M("`@("`@("`@)'1H:7,M/F1O;75L=&DH)&0M,2P@)&%R+"`D<ELD87);)&%D
M75TL("1V+"`D860K,2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'(@/2`D=CL*("`@("`@("!]"B`@("!]"B`@("`*("`@("\J*@H@("`@("H@
M8G5I;&1297-P;VYS90H@("`@("H@;&]O<"!T:')O=6=H(&US9RP@8G5I;&1I
M;F<@<F5S<&]N<V4@<W1R=6-T=7)E<PH@("`@("H*("`@("`J($!P87)A;2!I
M;G0@<&]S:71I;VX*("`@("`J($!R971U<FX@4T]!4%]686QU92`*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F8G5I;&12
M97-P;VYS92@D<&]S*0H@("`@>PH@("`@("`@("1R97-P;VYS92`]($Y53$P[
M"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65S<V%G95LD<&]S75LG8VAI
M;&1R96XG72DI('L*("`@("`@("`@("`@)&-H:6QD<F5N(#T@97AP;&]D92@G
M?"<L)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-H:6QD<F5N)UTI.PH*("`@("`@
M("`@("`@9F]R96%C:"`H)&-H:6QD<F5N(&%S("1C(#T^("1C:&EL9%]P;W,I
M('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;65S<V%G95LD8VAI;&1?
M<&]S75LG='EP92==("$]($Y53$PI('L*("`@("`@("`@("`@("`@("`@("`D
M<F5S<&]N<V5;72`])B`D=&AI<RT^8G5I;&1297-P;VYS92@D8VAI;&1?<&]S
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G87)R87E3:7IE)RPD=&AI<RT^;65S
M<V%G95LD<&]S72DI('L*("`@("`@("`@("`@("`@("1A<F1E<'1H(#T@8V]U
M;G0H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y4VEZ92==*3L*("`@("`@
M("`@("`@("`@(&EF("@D87)D97!T:"`^(#$I('L*("`@("`@("`@("`@("`@
M("`@("`D87(@/2!A<G)A>5]P860H87)R87DH*2P@)&%R9&5P=&@L(#`I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=A<G)A
M>4]F9G-E="<L)'1H:7,M/FUE<W-A9V5;)'!O<UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1A<F1E<'1H.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87);)&E=("L]("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>4]F9G-E="==6R1I73L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`D96QC(#T@8V]U;G0H)')E<W!O;G-E*3L*("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D96QC.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(')E8W5R<V4@=&\@8G5I
M;&0@82!M=6QT:2UD:6T@87)R87D*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F1O;75L=&DH)&%R9&5P=&@L("1A<BP@)&YE=W)E<W`L("1R97-P
M;VYS95LD:5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`*("`@("`@("`@
M("`@("`@("`@("`@("`@(R!I;F-R96UE;G0@;W5R(&%R<F%Y('!O:6YT97)S
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A9"`]("1A<F1E<'1H("T@,3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%R6R1A9%TK*SL*("`@("`@("`@
M("`@("`@("`@("`@("`@=VAI;&4@*"1A9"`^(#`@)B8@)&%R6R1A9%T@/CT@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y4VEZ92==6R1A9%TI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A<ELD861=(#T@,#L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1A9"TM.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%R6R1A9%TK*SL*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`D<F5S<&]N<V4@/2`D;F5W<F5S<#L*("`@("`@("`@("`@("`@('T@96QS
M92!I9B`H:7-S970H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T
M)UTI("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S
M86=E6R1P;W-=6R=A<G)A>4]F9G-E="==6S!=(#X@,"D@>PH@("`@("`@("`@
M("`@("`@("`@(",@8VAE8VL@9F]R('!A9&1I;F<*("`@("`@("`@("`@("`@
M("`@("`D<&%D(#T@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T
M)UU;,%TK8V]U;G0H)')E<W!O;G-E*2HM,3L*("`@("`@("`@("`@("`@("`@
M("`D<F5S<&]N<V4@/2!A<G)A>5]P860H)')E<W!O;G-E+"1P860L3E5,3"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@+R\@8G5I;&0@871T<FEB=71E<PH@("`@("`@("1A='1R<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)V%T=')S)UT@87,@)&%T;B`]/B`D871V*2!["B`@("`@("`@("`@(&EF("@A
M<W1R<W1R*"1A=&XL("=X;6QN<R<I("8F"B`@("`@("`@("`@("`@("`A<W1R
M<&]S*"1A=&XL("<Z)RDI("1A='1R<ULD871N73TD871V.PH@("`@("`@('T*
M("`@("`@("`O+R!A9&0@8W5R<F5N="!N;V1E)W,@=F%L=64*("`@("`@("!I
M9B`H)')E<W!O;G-E*2!["B`@("`@("`@("`@("1N<6X@/28@;F5W(%%N86UE
M*"1T:&ES+3YM97-S86=E6R1P;W-=6R=N86UE)UTL)'1H:7,M/FUE<W-A9V5;
M)'!O<UU;)VYA;65S<&%C92==*3L*("`@("`@("`@("`@)'1Q;B`])B!N97<@
M46YA;64H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&4G72PD=&AI<RT^;65S
M<V%G95LD<&]S75LG='EP95]N86UE<W!A8V4G72D["B`@("`@("`@("`@("1R
M97-P;VYS92`])B!N97<@4T]!4%]686QU92@D;G%N+3YF<6XH*2P@)'1Q;BT^
M9G%N*"DL("1R97-P;VYS92P@)&%T=')S*3L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>51Y<&4G72DI("1R97-P
M;VYS92T^87)R87E4>7!E(#T@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y
M5'EP92==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N<6X@/28@
M;F5W(%%N86UE*"1T:&ES+3YM97-S86=E6R1P;W-=6R=N86UE)UTL)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)VYA;65S<&%C92==*3L*("`@("`@("`@("`@)'1Q
M;B`])B!N97<@46YA;64H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&4G72PD
M=&AI<RT^;65S<V%G95LD<&]S75LG='EP95]N86UE<W!A8V4G72D["B`@("`@
M("`@("`@("1R97-P;VYS92`])B!N97<@4T]!4%]686QU92@D;G%N+3YF<6XH
M*2P@)'1Q;BT^9G%N*"DL("1T:&ES+3YM97-S86=E6R1P;W-=6R=C9&%T82==
M+"`D871T<G,I.PH@("`@("`@('T*("`@("`@("`O+R!H86YD;&4@:&5A9&5R
M(&%T=')I8G5T92!T:&%T('=E(&YE960*("`@("`@("!I9B`H87)R87E?:V5Y
M7V5X:7-T<R@G86-T;W(G+"1T:&ES+3YM97-S86=E6R1P;W-=*2D@>PH@("`@
M("`@("`@("`D<F5S<&]N<V4M/F%C=&]R(#T@)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)V%C=&]R)UT["B`@("`@("`@?0H@("`@("`@(&EF("AA<G)A>5]K97E?
M97AI<W1S*"=M=7-T56YD97)S=&%N9"<L)'1H:7,M/FUE<W-A9V5;)'!O<UTI
M*2!["B`@("`@("`@("`@("1R97-P;VYS92T^;75S='5N9&5R<W1A;F0@/2`D
M=&AI<RT^;65S<V%G95LD<&]S75LG;75S=%5N9&5R<W1A;F0G73L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@('T*("`@(`H@("`@
M+RHJ"B`@("`@*B!S=&%R=$5L96UE;G0*("`@("`J('-T87)T+65L96UE;G0@
M:&%N9&QE<B!U<V5D('=I=&@@>&UL('!A<G-E<@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE
M;G0H)'!A<G-E<BP@)&YA;64L("1A='1R<RD*("`@('L*("`@("`@("`O+R!P
M;W-I=&EO;B!I;B!A('1O=&%L(&YU;6)E<B!O9B!E;&5M96YT<RP@<W1A<G1I
M;F<@9G)O;2`P"B`@("`@("`@+R\@=7!D871E(&-L87-S(&QE=F5L('!O<PH@
M("`@("`@("1P;W,@/2`D=&AI<RT^<&]S:71I;VXK*SL*"B`@("`@("`@+R\@
M86YD('-E="!M:6YE"B`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UT@/2!A
M<G)A>2@I.PH@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@
M/2`G)SL*("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP95]N86UE
M<W!A8V4G72`]("<G.PH@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=C
M9&%T82==(#T@)R<["B`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W!O
M<R==(#T@)'!O<SL*("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG:60G
M72`]("<G.PH@("`@("`@(`H@("`@("`@("\O('!A<F5N="]C:&EL9"]D97!T
M:"!D971E<FUI;F%T:6]N<PH@("`@("`@(`H@("`@("`@("\O(&1E<'1H(#T@
M:&]W(&UA;GD@;&5V96QS(')E;6]V960@9G)O;2!R;V]T/PH@("`@("`@("\O
M('-E="!M:6YE(&%S(&-U<G)E;G0@9VQO8F%L(&1E<'1H(&%N9"!I;F-R96UE
M;G0@9VQO8F%L(&1E<'1H('9A;'5E"B`@("`@("`@)'1H:7,M/FUE<W-A9V5;
M)'!O<UU;)V1E<'1H)UT@/2`D=&AI<RT^9&5P=&@K*SL*("`@("`@("`*("`@
M("`@("`O+R!E;'-E(&%D9"!S96QF(&%S(&-H:6QD('1O('=H;V5V97(@=&AE
M(&-U<G)E;G0@<&%R96YT(&ES"B`@("`@("`@:68@*"1P;W,@(3T@,"D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/FUE<W-A9V5;)'1H:7,M/G!A
M<F5N=%U;)V-H:6QD<F5N)UTI*0H@("`@("`@("`@("`@("`@)'1H:7,M/FUE
M<W-A9V5;)'1H:7,M/G!A<F5N=%U;)V-H:6QD<F5N)UT@+CT@(GPD<&]S(CL*
M("`@("`@("`@("`@96QS90H@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A
M9V5;)'1H:7,M/G!A<F5N=%U;)V-H:6QD<F5N)UT@/2`D<&]S.PH@("`@("`@
M('T*"B`@("`@("`@+R\@<V5T(&UY('!A<F5N=`H@("`@("`@("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=P87)E;G0G72`]("1T:&ES+3YP87)E;G0["@H@("`@
M("`@("\O('-E="!S96QF(&%S(&-U<G)E;G0@=F%L=64@9F]R('1H:7,@9&5P
M=&@*("`@("`@("`D=&AI<RT^9&5P=&A?87)R87E;)'1H:7,M/F1E<'1H72`]
M("1P;W,["B`@("`@("`@+R\@<V5T('-E;&8@87,@8W5R<F5N="!P87)E;G0*
M("`@("`@("`D=&AI<RT^<&%R96YT(#T@)'!O<SL*("`@("`@("`D<6YA;64@
M/28@;F5W(%%.86UE*"1N86UE*3L*("`@("`@("`O+R!S970@<W1A='5S"B`@
M("`@("`@:68@*'-T<F-A<V5C;7`H)V5N=F5L;W!E)RPD<6YA;64M/FYA;64I
M/3TP*2!["B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G96YV96QO<&4G
M.PH@("`@("`@('T@96QS96EF("AS=')C87-E8VUP*"=H96%D97(G+"1Q;F%M
M92T^;F%M92D]/3`I('L*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=H
M96%D97(G.PH@("`@("`@("`@("`D=&AI<RT^:&5A9&5R7W-T<G5C=%]N86UE
M6UT@/2`D=&AI<RT^8W5R96YT7W)O;W1?<W1R=6-T7VYA;64@/2`D<6YA;64M
M/FYA;64["B`@("`@("`@("`@("1T:&ES+3YH96%D97)?<W1R=6-T6UT@/2`D
M=&AI<RT^8W5R96YT7W)O;W1?<W1R=6-T(#T@)'!O<SL*("`@("`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&4G72`]("=3=')U8W0G.PH@("`@
M("`@('T@96QS96EF("AS=')C87-E8VUP*"=B;V1Y)RPD<6YA;64M/FYA;64I
M/3TP*2!["B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G8F]D>2<["B`@
M("`@("`@("`@("1T:&ES+3YB;V1Y1&5P=&@@/2`D=&AI<RT^9&5P=&@["B`@
M("`@("`@+R\@<V5T(&UE=&AO9`H@("`@("`@('T@96QS96EF("@D=&AI<RT^
M<W1A='5S(#T]("=B;V1Y)RD@>PH@("`@("`@("`@("`O+R!I<R!T:&ES(&5L
M96UE;G0@86QL;W=E9"!T;R!B92!A(')O;W0_"B`@("`@("`@("`@("\O(%A8
M6"!T:&ES(&YE961S('1O(&)E(&]P=&EM:7IE9"P@=V4@;&]O<"!T:')O=6=H
M(&%T=')S('1W:6-E(&YO=PH@("`@("`@("`@("`D8V%N7W)O;W0@/2`D=&AI
M<RT^9&5P=&@@/3T@)'1H:7,M/F)O9'E$97!T:"`K(#$["B`@("`@("`@("`@
M(&EF("@D8V%N7W)O;W0I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A
M='1R<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AS=')I<W1R*"1K97DL("<Z<F]O="<I("8F("$D=F%L=64I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-A;E]R;V]T(#T@1D%,4T4["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&-A;E]R;V]T*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<W1A='5S(#T@)VUE=&AO9"<["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<F]O=%]S=')U8W1?;F%M95M=(#T@)'1H:7,M/F-U<F5N=%]R
M;V]T7W-T<G5C=%]N86UE(#T@)'%N86UE+3YN86UE.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G)O;W1?<W1R=6-T6UT@/2`D=&AI<RT^8W5R96YT7W)O;W1?
M<W1R=6-T(#T@)'!O<SL*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E
M6R1P;W-=6R=T>7!E)UT@/2`G4W1R=6-T)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+R\@<V5T(&UY('-T871U<PH@("`@("`@("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=S=&%T=7,G72`]("1T:&ES+3YS=&%T=7,["B`@
M("`@("`@"B`@("`@("`@+R\@<V5T(&YA;64*("`@("`@("`D=&AI<RT^;65S
M<V%G95LD<&]S75LG;F%M92==(#T@:'1M;'-P96-I86QC:&%R<R@D<6YA;64M
M/FYA;64I.PH*("`@("`@("`O+R!S970@871T<G,*("`@("`@("`D=&AI<RT^
M;65S<V%G95LD<&]S75LG871T<G,G72`]("1A='1R<SL*"B`@("`@("`@+R\@
M;&]O<"!T:')O=6=H(&%T=',L(&QO9V=I;F<@;G,@86YD('1Y<&4@9&5C;&%R
M871I;VYS"B`@("`@("`@9F]R96%C:"`H)&%T=')S(&%S("1K97D@/3X@)'9A
M;'5E*2!["B`@("`@("`@("`@("\O(&EF(&YS(&1E8VQA<F%T:6]N<RP@861D
M('1O(&-L87-S(&QE=F5L(&%R<F%Y(&]F('9A;&ED(&YA;65S<&%C97,*("`@
M("`@("`@("`@)&MQ;B`])B!N97<@44YA;64H)&ME>2D["B`@("`@("`@("`@
M(&EF("@D:W%N+3YN<R`]/2`G>&UL;G,G*2!["B`@("`@("`@("`@("`@("`D
M<')E9FEX(#T@)&MQ;BT^;F%M93L*"B`@("`@("`@("`@("`@("!I9B`H:6Y?
M87)R87DH)'9A;'5E+"`D=&AI<RT^7UA-3%-C:&5M82DI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH)'9A;'5E*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(`H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]N86UE<W!A8V5S6R1V86QU95T@/2`D<')E9FEX.PH*
M("`@("`@("`@("`@("`@("\O('-E="!M971H;V0@;F%M97-P86-E"B`@("`@
M("`@("`@("`@("`C(%A86"!U;G5S960_/S\*("`@("`@("`@("`@("`@("-I
M9B`H)&YA;64@/3T@)'1H:7,M/F-U<F5N=%]R;V]T7W-T<G5C=%]N86UE*2![
M"B`@("`@("`@("`@("`@("`C("`@("1T:&ES+3YM971H;V1.86UE<W!A8V4@
M/2`D=F%L=64["B`@("`@("`@("`@("`@("`C?0H@("`@("`@("`@("!](&5L
M<V5I9B`H)&ME>2`]/2`G>&UL;G,G*2!["B`@("`@("`@("`@("`@("`D<6YA
M;64M/FYS(#T@)'1H:7,M/E]G971.86UE<W!A8V50<F5F:7@H)'9A;'5E*3L*
M("`@("`@("`@("`@("`@("1Q;F%M92T^;F%M97-P86-E(#T@)'9A;'5E.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)&MQ;BT^;F%M92`]/2`G86-T;W(G*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG86-T;W(G
M72`]("1V86QU93L*("`@("`@("`@("`@?2!E;'-E:68@*"1K<6XM/FYA;64@
M/3T@)VUU<W15;F1E<G-T86YD)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)VUU<W15;F1E<G-T86YD)UT@/2`D=F%L=64["B`@
M("`@("`@("`@("`@("`*("`@("`@("`@("`@+R\@:68@:70G<R!A('1Y<&4@
M9&5C;&%R871I;VXL('-E="!T>7!E"B`@("`@("`@("`@('T@96QS96EF("@D
M:W%N+3YN86UE(#T]("=T>7!E)RD@>PH@("`@("`@("`@("`@("`@)'9Q;B`]
M)B!N97<@44YA;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=T>7!E)UT@/2`D=G%N+3YN86UE.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&5?;F%M97-P86-E)UT@
M/2`D=&AI<RT^7V=E=$YA;65S<&%C949O<E!R969I>"@D=G%N+3YN<RD["B`@
M("`@("`@("`@("`@("`C<')I;G0@(G-E="!T>7!E(&9O<B![)'1H:7,M/FUE
M<W-A9V5;)'!O<UU;)VYA;64G77T@=&\@>R1T:&ES+3YM97-S86=E6R1P;W-=
M6R=T>7!E)UU]7&XB.PH@("`@("`@("`@("`@("`@+R\@<VAO=6QD(&1O('-O
M;65T:&EN9R!H97)E('=I=&@@=&AE(&YA;65S<&%C92!O9B!S<&5C:69I960@
M='EP93\*("`@("`@("`@("`@("`@(`H@("`@("`@("`@("!](&5L<V5I9B`H
M)&MQ;BT^;F%M92`]/2`G87)R87E4>7!E)RD@>PH@("`@("`@("`@("`@("`@
M)'9Q;B`])B!N97<@44YA;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G07)R87DG.PH@("`@("`@
M("`@("`@("`@(R1T>7!E(#T@)'9Q;BT^;F%M93L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D=G%N+3YA<G)A>5-I>F4I*0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>5-I>F4G72`]("1V<6XM
M/F%R<F%Y4VEZ93L*("`@("`@("`@("`@("`@(",D<V$@/2!S=')P;W,H)'1Y
M<&4L)ULG*3L*("`@("`@("`@("`@("`@("-I9B`H)'-A(#X@,"D@>PH@("`@
M("`@("`@("`@("`@(R`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E3
M:7IE)UT@/2!S<&QI="@G+"<L<W5B<W1R*"1T>7!E+"1S82LQ+"!S=')L96XH
M)'1Y<&4I+21S82TR*2D["B`@("`@("`@("`@("`@("`C("`@("1T>7!E(#T@
M<W5B<W1R*"1T>7!E+"`P+"`D<V$I.PH@("`@("`@("`@("`@("`@(WT*("`@
M("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>51Y<&4G
M72`]("1V<6XM/FYA;64["B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@
M?2!E;'-E:68@*"1K<6XM/FYA;64@/3T@)V]F9G-E="<I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>4]F9G-E="==(#T@
M<W!L:70H)RPG+'-U8G-T<B@D=F%L=64L(#$L('-T<FQE;B@D=F%L=64I+3(I
M*3L*("`@("`@("`@("`@("`@(`H@("`@("`@("`@("!](&5L<V5I9B`H)&MQ
M;BT^;F%M92`]/2`G:60G*2!["B`@("`@("`@("`@("`@("`C('-A=F4@:60@
M=&\@<F5F97)E;F-E(&%R<F%Y"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5F
M97)E;F-E<ULD=F%L=65=(#T@)'!O<SL*("`@("`@("`@("`@("`@("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=I9"==(#T@)'9A;'5E.PH@("`@("`@("`@("`@
M("`@"B`@("`@("`@("`@('T@96QS96EF("@D:W%N+3YN86UE(#T]("=H<F5F
M)RD@>PH@("`@("`@("`@("`@("`@:68@*"1V86QU95LP72`]/2`G(R<I('L*
M("`@("`@("`@("`@("`@("`@("`D<F5F(#T@<W5B<W1R*"1V86QU92P@,2D[
M"B`@("`@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)')E
M9BPD=&AI<RT^<F5F97)E;F-E<RDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@(R!C9&%T82P@='EP92P@:6YV86P*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E9E]P;W,@/2`D=&AI<RT^<F5F97)E;F-E<ULD<F5F73L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-H:6QD
M<F5N)UT@/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=C:&EL9')E;B==
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S
M75LG8V1A=&$G72`]("8D=&AI<RT^;65S<V%G95LD<F5F7W!O<UU;)V-D871A
M)UT["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P
M;W-=6R=T>7!E)UT@/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=T>7!E
M)UT["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P
M;W-=6R=A<G)A>5-I>F4G72`]("8D=&AI<RT^;65S<V%G95LD<F5F7W!O<UU;
M)V%R<F%Y4VEZ92==.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;65S<V%G95LD<&]S75LG87)R87E4>7!E)UT@/2`F)'1H:7,M/FUE<W-A9V5;
M)')E9E]P;W-=6R=A<G)A>51Y<&4G73L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`C(')E=F5R<V4@<F5F
M97)E;F-E+"!S=&]R92!I;B`G;F5E9"!R969E<F5N8V4G"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/FYE961?<F5F97)E;F-E
M<ULD<F5F72DI("1T:&ES+3YN965D7W)E9F5R96YC97-;)')E9ET@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;F5E9%]R969E
M<F5N8V5S6R1R969=6UT@/2`D<&]S.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T@96QS92!I9B`H:7-S970H)'1H:7,M/F%T=&%C
M:&UE;G1S6R1V86QU95TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT@/2`D=&AI<RT^871T86-H;65N='-;
M)'9A;'5E73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`O+R!S964@:68@;F%M97-P86-E(&ES(&1E9FEN960@
M:6X@=&%G"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)WAM;&YS.B<N
M)'%N86UE+3YN<RPD871T<G,I*2!["B`@("`@("`@("`@("1N86UE<W!A8V4@
M/2`D871T<G-;)WAM;&YS.B<N)'%N86UE+3YN<UT["B`@("`@("`@?2!E;'-E
M(&EF("@D<6YA;64M/FYS("8F("$D<6YA;64M/FYA;65S<&%C92D@>PH@("`@
M("`@("`@("`D;F%M97-P86-E(#T@)'1H:7,M/E]G971.86UE<W!A8V5&;W)0
M<F5F:7@H)'%N86UE+3YN<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`O
M+R!G970@;F%M97-P86-E"B`@("`@("`@("`@("1N86UE<W!A8V4@/2`D<6YA
M;64M/FYA;65S<&%C93\D<6YA;64M/FYA;65S<&%C93HD=&AI<RT^9&5F875L
M=%]N86UE<W!A8V4["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YM97-S86=E
M6R1P;W-=6R=N86UE<W!A8V4G72`]("1N86UE<W!A8V4["B`@("`@("`@)'1H
M:7,M/F1E9F%U;'1?;F%M97-P86-E(#T@)&YA;65S<&%C93L*("`@('T*("`@
M(`H@("`@+RHJ"B`@("`@*B!E;F1%;&5M96YT"B`@("`@*B!E;F0M96QE;65N
M="!H86YD;&5R('5S960@=VET:"!X;6P@<&%R<V5R"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N9$5L96UE
M;G0H)'!A<G-E<BP@)&YA;64I"B`@("!["B`@("`@("`@+R\@<&]S:71I;VX@
M;V8@8W5R<F5N="!E;&5M96YT(&ES(&5Q=6%L('1O('1H92!L87-T('9A;'5E
M(&QE9G0@:6X@9&5P=&A?87)R87D@9F]R(&UY(&1E<'1H"B`@("`@("`@)'!O
M<R`]("1T:&ES+3YD97!T:%]A<G)A>5LD=&AI<RT^9&5P=&A=.PH@("`@("`@
M("\O(&)R:6YG(&1E<'1H(&1O=VX@82!N;W1C:`H@("`@("`@("1T:&ES+3YD
M97!T:"TM.PH@("`@("`@("1Q;F%M92`])B!N97<@44YA;64H)&YA;64I.PH@
M("`@("`@(`H@("`@("`@("\O(&=E="!T>7!E(&EF(&YO="!E>'!L:6-I=&QY
M(&1E8VQA<F5D(&EN(&%N('AS:3IT>7!E(&%T=')I8G5T90H@("`@("`@("\O
M(%A86"!C:&5C:R!O;B!I;G1E9W)A=&EN9R!W<V1L('9A;&ED871I;VX@:&5R
M90H@("`@("`@(&EF("@D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T]
M("<G*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65S<V%G95LD
M<&]S75LG8VAI;&1R96XG72DI('L*("`@("`@("`@("`@("`@("\J('1H:7,@
M:7,@<VQO=RP@;F5E9"!T;R!L;V]K(&%T('-O;64@9F%S=&5R(&UE=&AO9`H@
M("`@("`@("`@("`@("`@)&-H:6QD<F5N(#T@97AP;&]D92@G?"<L)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)V-H:6QD<F5N)UTI.PH@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1C:&EL9')E;BD@/B`R("8F"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)&-H:6QD<F5N6S%=75LG;F%M92==(#T]("1T
M:&ES+3YM97-S86=E6R1C:&EL9')E;ELR75U;)VYA;64G72D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G
M07)R87DG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L@"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&4G72`]("=3=')U
M8W0G.PH@("`@("`@("`@("`@("`@?2HO"B`@("`@("`@("`@("`@("`D=&AI
M<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&%R96YT(#T@)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)W!A<F5N="==.PH@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YM97-S86=E6R1P87)E;G1=6R=T>7!E)UT@/3T@)T%R<F%Y)R`F
M)@H@("`@("`@("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S*"=A<G)A>51Y
M<&4G+"`D=&AI<RT^;65S<V%G95LD<&%R96YT72DI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)'1H:7,M
M/FUE<W-A9V5;)'!A<F5N=%U;)V%R<F%Y5'EP92==.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G
M95LD<&]S75LG='EP92==(#T@)W-T<FEN9R<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@
M:68@=&%G('=E(&%R92!C=7)R96YT;'D@8VQO<VEN9R!I<R!T:&4@;65T:&]D
M('=R87!P97(*("`@("`@("!I9B`H)'!O<R`]/2`D=&AI<RT^8W5R96YT7W)O
M;W1?<W1R=6-T*2!["B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G8F]D
M>2<["B`@("`@("`@?2!E;'-E:68@*"1Q;F%M92T^;F%M92`]/2`G0F]D>2<@
M?'P@)'%N86UE+3YN86UE(#T]("=(96%D97(G*2!["B`@("`@("`@("`@("1T
M:&ES+3YS=&%T=7,@/2`G96YV96QO<&4G.PH@("`@("`@('T*"B`@("`@("`@
M+R\@<V5T('!A<F5N="!B86-K('1O(&UY('!A<F5N=`H@("`@("`@("1T:&ES
M+3YP87)E;G0@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG<&%R96YT)UT["B`@
M("`@("`@"B`@("`@("`@(R!H86YD;&4@86YY(')E=F5R<V4@<F5F97)E;F-E
M<R!N;W<*("`@("`@("`D:61R968@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG
M:60G73L*"B`@("`@("`@:68@*"1I9')E9B`A/2`G)R`F)B!A<G)A>5]K97E?
M97AI<W1S*"1I9')E9BPD=&AI<RT^;F5E9%]R969E<F5N8V5S*2D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^;F5E9%]R969E<F5N8V5S6R1I9')E
M9ET@87,@)')E9E]P;W,I('L*("`@("`@("`@("`@("`@("-86%@@:7,@=&AI
M<R!S='5F9B!T:&5R92!A;')E861Y/PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)')E9E]P;W-=6R=C:&EL9')E;B==(#T@)B1T:&ES+3YM97-S
M86=E6R1P;W-=6R=C:&EL9')E;B==.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)')E9E]P;W-=6R=C9&%T82==(#T@)B1T:&ES+3YM97-S86=E
M6R1P;W-=6R=C9&%T82==.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A
M9V5;)')E9E]P;W-=6R=T>7!E)UT@/2`F)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)W1Y<&4G73L*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1R969?
M<&]S75LG87)R87E3:7IE)UT@/2`F)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R
M<F%Y4VEZ92==.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)')E
M9E]P;W-=6R=A<G)A>51Y<&4G72`]("8D=&AI<RT^;65S<V%G95LD<&]S75LG
M87)R87E4>7!E)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@(R!W:7!E
M(&]U="!O=7(@=V%I=&EN9R!L:7-T"B`@("`@("`@("`@(",@)'1H:7,M/FYE
M961?<F5F97)E;F-E<ULD:61R969=(#T@87)R87DH*3L*("`@("`@("!]"B`@
M("!]"B`@("`*("`@("\J*@H@("`@("H@8VAA<F%C=&5R1&%T80H@("`@("H@
M96QE;65N="!C;VYT96YT(&AA;F1L97(@=7-E9"!W:71H('AM;"!P87)S97(*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VAA<F%C=&5R1&%T82@D<&%R<V5R+"`D9&%T82D*("`@('L*("`@
M("`@("`D<&]S(#T@)'1H:7,M/F1E<'1H7V%R<F%Y6R1T:&ES+3YD97!T:%T[
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YM97-S86=E6R1P;W-=6R=C9&%T
M82==*2D*("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A
M)UT@+CT@)&1A=&$["B`@("`@("`@96QS90H@("`@("`@("`@("`D=&AI<RT^
M;65S<V%G95LD<&]S75LG8V1A=&$G72`]("1D871A.PH@("`@?0H@("`@"B`@
M("`O*BH*("`@("`J(&=E=%)E<W!O;G-E"B`@("`@*@H@("`@("H@<F5T=7)N
M<R!A;B!A<G)A>2!O9B!R97-P;VYS97,*("`@("`J(&%F=&5R('!A<G-I;F<@
M82!S;V%P(&UE<W-A9V4L('5S92!T:&ES('1O(&=E="!T:&4@<F5S<&]N<V4*
M("`@("`J"B`@("`@*B!`<F5T=7)N("`@87)R87D@"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4F5S<&]N<V4H*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<F]O=%]S=')U8W1;,%TI
M("8F"B`@("`@("`@("`@("1T:&ES+3YR;V]T7W-T<G5C=%LP72D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F)U:6QD4F5S<&]N<V4H)'1H:7,M/G)O
M;W1?<W1R=6-T6S!=*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<F%I<V53;V%P1F%U;'0H(F-O=6QD;B=T(&)U:6QD(')E<W!O;G-E(BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!G971(96%D97)S"B`@("`@*@H@("`@
M("H@<F5T=7)N<R!A;B!A<G)A>2!O9B!H96%D97(@<F5S<&]N<V5S"B`@("`@
M*B!A9G1E<B!P87)S:6YG(&$@<V]A<"!M97-S86=E+"!U<V4@=&AI<R!T;R!G
M970@=&AE(')E<W!O;G-E"B`@("`@*@H@("`@("H@0')E='5R;B`@(&%R<F%Y
M(`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F=E=$AE861E<G,H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M:&5A9&5R7W-T<G5C=%LP72D@)B8*("`@("`@("`@("`@)'1H:7,M/FAE861E
M<E]S=')U8W1;,%TI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YB=6EL
M9%)E<W!O;G-E*"1T:&ES+3YH96%D97)?<W1R=6-T6S!=*3L*("`@("`@("!]
M"B`@("`@("`@+R\@=V4@9&]N)W0@9F%U;'0@:68@=&AE<F4@87)E(&YO(&AE
M861E<G,*("`@("`@("`O+R!T:&%T(&-A;B!B92!H86YD;&5D(&)Y('1H92!A
M<'`@:68@;F5C97-S87)Y"B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]"B`@
M("`*("`@("\J*@H@("`@("H@9&5C;V1E16YT:71I97,*("`@("`J"B`@("`@
M*B!R96UO=F5S(&5N=&ET:65S(&9R;VT@=&5X=`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<*("`@("`J($!R971U<FX@("!S=')I;F<@"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E16YT
M:71I97,H)'1E>'0I"B`@("!["B`@("`@("`@)'1R86YS7W1B;"`](&%R<F%Y
M7V9L:7`H)'1H:7,M/F5N=&ET:65S*3L*("`@("`@("!R971U<FX@<W1R='(H
M)'1E>'0L("1T<F%N<U]T8FPI.PH@("`@?0I]"@H_/@``````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U-/05`O4V5R=F5R+G!H<```````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#8W,3(U`#$P-#$W,S8S,#`V`#`R,#`W-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0
M;W)T('1O(%!%05(@86YD(&UO<F4@("!\"B\O('P@075T:&]R<SH@1&EE=')I
M8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!397)V97(N<&AP+'8@,2XT-"XR+C$@,C`P,R\Q,B\R,"`R,3HR
M,3HU.2!S:VQA<B!%>'`@)`HO+PH*<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+T9A=6QT+G!H<"<["G)E<75I<F5?
M;VYC92`G4T]!4"]087)S97(N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+U9A
M;'5E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]74T1,+G!H<"<["@HD<V]A
M<%]S97)V97)?9F%U;'0@/2!N=6QL.PIF=6YC=&EO;B!33T%07U-E<G9E<D5R
M<F]R2&%N9&QE<B@D97)R;F\L("1E<G)M<V<L("1F:6QE;F%M92P@)&QI;F5N
M=6TL("1V87)S*2!["B`@("!G;&]B86P@)'-O87!?<V5R=F5R7V9A=6QT.PH@
M("`@)&1E=&%I;"`](")%<G)N;SH@)&5R<FYO7&Y&:6QE;F%M93H@)&9I;&5N
M86UE7&Y,:6YE;F\Z("1L:6YE;G5M7&XB.PH@("`@+R\@6%A8('9E<GD@<W1R
M86YG92!B96AA=FEO=7(@=VET:"!E<G)O<B!H86YD;&EN9R!I9B!W92`])B!H
M97)E+@H@("`@)'-O87!?<V5R=F5R7V9A=6QT(#T@;F5W(%-/05!?1F%U;'0H
M)&5R<FUS9RP@)U-E<G9E<B<L("=02%`G+"`D9&5T86EL*3L*?0H*+RHJ"B`J
M("!33T%0.CI397)V97(*("H@4T]!4"!397)V97(@0VQA<W,*("H*("H@;W)I
M9VEN86QY(&)A<V5D(&]N(%-/05!X-"!B>2!$:65T<FEC:"!!>6%L82!H='1P
M.B\O9&EE=')I8V@N9V%N>#0N8V]M+W-O87!X-`H@*@H@*B!`86-C97-S("`@
M<'5B;&EC"B`J($!V97)S:6]N("`D260Z(%-E<G9E<BYP:'`L=B`Q+C0T+C(N
M,2`R,#`S+S$R+S(P(#(Q.C(Q.C4Y('-K;&%R($5X<"`D"B`J($!P86-K86=E
M("!33T%0.CI#;&EE;G0*("H@0&%U=&AO<B`@(%-H86YE($-A<F%V96\@/'-H
M86YE0'!H<"YN970^($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@=7!D871E<PH@
M*B!`875T:&]R("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O
M;3X@3W)I9VEN86P@075T:&]R"B`J+PIC;&%S<R!33T%07U-E<G9E<B!E>'1E
M;F1S(%-/05!?0F%S90I["B`@("`O*BH*("`@("`J"B`@("`@*B!`=F%R("!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&1I<W!A=&-H7VUA<"`](&%R<F%Y*"D[
M("\O(&-R96%T92!E;7!T>2!D:7-P871C:"!M87`*("`@('9A<B`D9&ES<&%T
M8VA?;V)J96-T<R`](&%R<F%Y*"D["B`@("!V87(@)'-O87!O8FIE8W0@/2!.
M54Q,.PH@("`@=F%R("1C86QL7VUE=&AO9&YA;64@/2!.54Q,.PH@("`@=F%R
M("1C86QL2&%N9&QE<B`]($Y53$P["B`@("!V87(@)&-A;&Q686QI9&%T:6]N
M(#T@=')U93L*"B`@("`O*BH*("`@("`J"B`@("`@*B!`=F%R("!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1H96%D97)S(#T@)R<["@H@("`@+RHJ"B`@("`@
M*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<F5Q=65S
M="`]("<G.PH*("`@("\J*@H@("`@("H*("`@("`J($!V87(@('-T<FEN9R`@
M6$U,+45N8V]D:6YG"B`@("`@*B\*("`@('9A<B`D>&UL7V5N8V]D:6YG(#T@
M4T]!4%]$149!54Q47T5.0T]$24Y'.PH@("`@=F%R("1R97-P;VYS95]E;F-O
M9&EN9R`]("=55$8M."<["@H@("`@=F%R("1R97-U;'0@/2`G<W5C8V5S<V9U
M;"<[("\O(&9O<B!L;V=G:6YG(&EN=&5R;W`@<F5S=6QT<R!T;R!D8@H*("`@
M('9A<B`D96YD<&]I;G0@/2`G)SL@+R\@=&AE('5R:2!T;R!-12$*"B`@("!V
M87(@)'-E<G9I8V4@/2`G)SL@+R]S;V%P86-T:6]N(&AE861E<@H@("`@=F%R
M("1M971H;V1?;F%M97-P86-E(#T@3E5,3#L*("`@('9A<B`D7U]O<'1I;VYS
M(#T@87)R87DH)W5S92<]/B=E;F-O9&5D)RPG<W1Y;&4G/3XG<G!C)RPG<&%R
M86UE=&5R<R<]/C`I.PH*("`@(&9U;F-T:6]N(%-/05!?4V5R=F5R*"1O<'1I
M;VYS/4Y53$PI('L*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+#$I
M.PH@("`@("`@('!A<F5N=#HZ4T]!4%]"87-E*"=397)V97(G*3L*("`@("`@
M("!I9B`H:7-?87)R87DH)&]P=&EO;G,I*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG=7-E)UTI*0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]?;W!T:6]N<ULG=7-E)UT@/2`D;W!T:6]N<ULG=7-E)UT["B`@("`@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<W1Y;&4G72DI"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T@)&]P=&EO;G-;)W-T
M>6QE)UT["B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<&%R86UE
M=&5R<R==*2D*("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W!A
M<F%M971E<G,G72`]("1O<'1I;VYS6R=P87)A;65T97)S)UT["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?<V5C=&EO;C4@/2!44E5%.R`O+R!A<W-U;64@
M=V4@96YC;V1E('=I=&@@<V5C=&EO;B`U"B`@("`@("`@:68@*"1T:&ES+3Y?
M7V]P=&EO;G-;)W5S92==/3TG;&ET97)A;"<I("1T:&ES+3Y?<V5C=&EO;C4@
M/2!&04Q313L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T0V]N=&5N=$5N8V]D
M:6YG*"1C;VYT96YT7W1Y<&4I"B`@("!["B`@("`@("`@+R\@9V5T('1H92!C
M:&%R86-T97(@96YC;V1I;F<@;V8@=&AE(&EN8V]M:6YG(')E<75E<W0*("`@
M("`@("`O+R!T<F5A="!I;F-O;6EN9R!D871A(&%S(%541BTX(&EF(&YO(&5N
M8V]D:6YG('-E=`H@("`@("`@("1T:&ES+3YX;6Q?96YC;V1I;F<@/2`G551&
M+3@G.PH@("`@("`@(&EF("AS=')P;W,H)&-O;G1E;G1?='EP92PG/2<I*2![
M"B`@("`@("`@("`@("1E;F,@/2!S=')T;W5P<&5R*'-T<E]R97!L86-E*"<B
M)RPB(BQS=6)S='(H<W1R<W1R*"1C;VYT96YT7W1Y<&4L)STG*2PQ*2DI.PH@
M("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1E;F,L("1T:&ES+3Y?96YC;V1I
M;F=S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N($9!3%-%.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3YX;6Q?96YC;V1I;F<@/2`D96YC
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@5%)513L*("`@('T*"@H@("`@
M+R\@<&%R<V5S(')E<75E<W0@86YD('!O<W1S(')E<W!O;G-E"B`@("!F=6YC
M=&EO;B!S97)V:6-E*"1D871A+"`D96YD<&]I;G0@/2`G)RP@)'1E<W0@/2!&
M04Q312D*("`@('L*("`@("`@("`D<F5S<&]N<V4@/2!.54Q,.PH@("`@("`@
M("1A='1A8VAM96YT<R`](&%R<F%Y*"D["B`@("`@("`@)&AE861E<G,@/2!A
M<G)A>2@I.PH@("`@("`@("1U<V5%;F-O9&EN9R`]("=$24U%)SL*("`@("`@
M("`O+R!F:6=U<F4@;W5T(&]U<B!E;F1P;VEN=`H@("`@("`@("1T:&ES+3YE
M;F1P;VEN="`]("1E;F1P;VEN=#L*("`@("`@("!I9B`H(21T97-T("8F("$D
M=&AI<RT^96YD<&]I;G0I('L*("`@("`@("`@("`@+R\@=V4G;&P@=')Y('1O
M(&)U:6QD(&]U<B!E;F1P;VEN=`H@("`@("`@("`@("`D=&AI<RT^96YD<&]I
M;G0@/2`G:'1T<#HO+R<N)%]315)615);)U-%4E9%4E].04U%)UT["B`@("`@
M("`@("`@(&EF("@D7U-%4E9%4ELG4T525D527U!/4E0G72D@)'1H:7,M/F5N
M9'!O:6YT("X]("<Z)RXD7U-%4E9%4ELG4T525D527U!/4E0G73L*("`@("`@
M("`@("`@)'1H:7,M/F5N9'!O:6YT("X]("1?4T525D526R=30U))4%1?3D%-
M12==.PH@("`@("`@('T*"B`@("`@("`@+R\@9V5T('1H92!C:&%R86-T97(@
M96YC;V1I;F<@;V8@=&AE(&EN8V]M:6YG(')E<75E<W0*("`@("`@("`O+R!T
M<F5A="!I;F-O;6EN9R!D871A(&%S(%541BTX(&EF(&YO(&5N8V]D:6YG('-E
M=`H@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG0T].5$5.5%]465!%)UTI
M*2!["B`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1?4T525D526R=#3TY4
M14Y47U194$4G72PG87!P;&EC871I;VXO9&EM92<I/3TP*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1E8V]D941)345-97-S86=E*"1D871A+"1H96%D
M97)S+"1A='1A8VAM96YT<RD["B`@("`@("`@("`@("`@("`D=7-E16YC;V1I
M;F<@/2`G1$E-12<["B`@("`@("`@("`@('T@96QS92!I9B`H<W1R:7-T<B@D
M7U-%4E9%4ELG0T].5$5.5%]465!%)UTL)VUU;'1I<&%R="]R96QA=&5D)RDI
M('L*("`@("`@("`@("`@("`@("\O('1H:7,@:7,@82!M:6UE(&UE<W-A9V4L
M(&QE=',@9&5C;V1E(&ET+@H@("`@("`@("`@("`@("`@)&1A=&$@/2`G0V]N
M=&5N="U4>7!E.B`G+G-T<FEP<VQA<VAE<R@D7U-%4E9%4ELG0T].5$5.5%]4
M65!%)UTI+B)<<EQN7')<;B(N)&1A=&$["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1E8V]D94UI;65-97-S86=E*"1D871A+"1H96%D97)S+"1A='1A8VAM
M96YT<RD["B`@("`@("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G36EM92<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D:&5A9&5R
M<ULG8V]N=&5N="UT>7!E)UTI*2!["B`@("`@("`@("`@("`@("`D:&5A9&5R
M<ULG8V]N=&5N="UT>7!E)UT@/2!S=')I<'-L87-H97,H)%]315)615);)T-/
M3E1%3E1?5%E012==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(21T:&ES+3YF875L="`F)@H@("`@("`@("`@("`@("`@(21T:&ES+3Y?9V5T
M0V]N=&5N=$5N8V]D:6YG*"1H96%D97)S6R=C;VYT96YT+71Y<&4G72DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YX;6Q?96YC;V1I;F<@/2!33T%07T1%
M1D%53%1?14Y#3T1)3D<["B`@("`@("`@("`@("`@("`O+R!A;B!E;F-O9&EN
M9R!W92!D;VXG="!U;F1E<G-T86YD+"!R971U<FX@82!F875L=`H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@G56YS=7!P;W)T960@
M96YC;V1I;F<L('5S92!O;F4@;V8@25-/+3@X-3DM,2P@55,M05-#24DL(%54
M1BTX)RPG)RPG)RPG4V5R=F5R)RD["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O(&EF('1H:7,@:7,@;F]T(&$@4$]35"!W:71H($-O;G1E
M;G0M5'EP92!T97AT+WAM;"P@=')Y('1O(')E='5R;B!A(%=31$P@9FEL90H@
M("`@("`@(&EF("@A)'1H:7,M/F9A=6QT("`F)B`A)'1E<W0@)B8@*"1?4T52
M5D526R=215%515-47TU%5$A/1"==("$]("=03U-4)R!\?`H@("`@("`@("`@
M("!S=')N8VUP*"1H96%D97)S6R=C;VYT96YT+71Y<&4G72PG=&5X="]X;6PG
M+#@I("$](#`I*2!["B`@("`@("`@("`@("`@("`O+R!T:&ES(&ES(&YO="!P
M;W-S:6)L>2!A('9A;&ED('-O87`@<F5Q=65S="P@=')Y('1O(')E='5R;B!A
M(%=31$P@9FEL90H@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&
M875L="@B26YV86QI9"!33T%0(')E<75E<W0L(&UU<W0@8F4@4$]35"!W:71H
M(&-O;G1E;G0M='EP93H@=&5X="]X;6PL(&=O=#H@(BXH:7-S970H)&AE861E
M<G-;)V-O;G1E;G0M='EP92==*3\D:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTZ
M)TYO=&AI;F<A)RDL)R<L)R<L)U-E<G9E<B<I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"$D=&AI<RT^9F%U;'0I('L*("`@("`@("`@("`@+R\@)')E<W!O
M;G-E(&ES(&$@<V]A<%]M<V<@;V)J96-T"B`@("`@("`@("`@("1S;V%P7VUS
M9R`]("1T:&ES+3YP87)S95)E<75E<W0H)&1A=&$L("1A='1A8VAM96YT<RD[
M"@H@("`@("`@("`@("`O+R!H86YD;&4@36EM92!O<B!$24U%(&5N8V]D:6YG
M"B`@("`@("`@("`@("\O(%A86"!$24U%($5N8V]D:6YG('-H;W5L9"!M;W9E
M('1O('1H92!T<F%N<W!O<G0L(&1O(&ET(&AE<F4@9F]R(&YO=PH@("`@("`@
M("`@("`O+R!A;F0@9F]R(&5A<V4@;V8@9V5T=&EN9R!I="!D;VYE"B`@("`@
M("`@("`@(&EF("AC;W5N="@D=&AI<RT^7U]A='1A8VAM96YT<RDI('L*("`@
M("`@("`@("`@("`@(&EF("@D=7-E16YC;V1I;F<@/3T@)TUI;64G*2!["B`@
M("`@("`@("`@("`@("`@("`@)'-O87!?;7-G(#T@)'1H:7,M/E]M86ME36EM
M94UE<W-A9V4H)'-O87!?;7-G*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@+R\@9&5F875L="!I<R!D:6UE"B`@("`@
M("`@("`@("`@("`@("`@)'-O87!?;7-G(#T@)'1H:7,M/E]M86ME1$E-14UE
M<W-A9V4H)'-O87!?;7-G*3L*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R
M6R=#;VYT96YT+51Y<&4G72`]("=A<'!L:6-A=&EO;B]D:6UE)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1S;V%P7VUS9RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E4V]A<$9A=6QT*"1S;V%P7VUS9RD["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M<V]A<%]M<V<I*2!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A
M<%]M<V=;)V)O9'DG73L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<V]A
M<%]M<V=;)VAE861E<G,G72DI('L*("`@("`@("`@("`@("`@("`@("`D:&5A
M9&5R(#T@)'-O87!?;7-G6R=H96%D97)S)UT["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S<&]N
M<V4@/2`D<V]A<%]M<V<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O(&UA:V4@9&ES=&EN8W1I;VX@8F5T=V5E;B!T:&4@9&EF9F5R96YT
M(&-H;VEC92!O9B!I;G-T86QL871I;VXL"B`@("`@("`@+R\@<G5N;FEN9R!P
M:'`@87,@8V=I(&]R(&%S(&$@;6]D=6QE"B`@("`@("`@:68H<W1R:7-T<BAP
M:'!?<V%P:5]N86UE*"DL)V-G:2<I/3TP*0H@("`@("`@("`@("`D:&1R<U]T
M>7!E(#T@)U-T871U<SHG.PH@("`@("`@(&5L<V4*("`@("`@("`@("`@)&AD
M<G-?='EP92`]("=(5%10+S$N,2<["@H@("`@("`@(&EF("@D=&AI<RT^9F%U
M;'0I('L*("`@("`@("`@("`@)&AD<G,@/2`B)&AD<G-?='EP92`U,#`@4V]A
M<"!&875L=%QR7&XB.PH@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^
M9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("1H9')S(#T@(B1H9')S7W1Y<&4@,C`P($]+7')<;B(["B`@("`@("`@?0H@
M("`@("`@(&AE861E<B@D:&1R<RD["@H@("`@("`@("1H96%D97);)U-E<G9E
M<B==(#T@4T]!4%],24)205)97TY!344["B`@("`@("`@:68@*"%I<W-E="@D
M:&5A9&5R6R=#;VYT96YT+51Y<&4G72DI"B`@("`@("`@("`@("1H96%D97);
M)T-O;G1E;G0M5'EP92==(#T@(G1E>'0O>&UL.R!C:&%R<V5T/21T:&ES+3YR
M97-P;VYS95]E;F-O9&EN9R(["B`@("`@("`@)&AE861E<ELG0V]N=&5N="U,
M96YG=&@G72`]('-T<FQE;B@D<F5S<&]N<V4I.PH*("`@("`@("!R97-E="@D
M:&5A9&5R*3L*("`@("`@("!F;W)E86-H("@D:&5A9&5R(&%S("1K(#T^("1V
M*2!["B`@("`@("`@("`@(&AE861E<B@B)&LZ("1V(BD["B`@("`@("`@("`@
M("1H9')S("X]("(D:SH@)'9<<EQN(CL*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3YR97-P;VYS92`]("1H9')S("X@(EQR7&XB("X@)')E<W!O;G-E.PH@
M("`@("`@('!R:6YT("1R97-P;VYS93L*("`@('T*"B`@("!F=6YC=&EO;B`F
M8V%L;$UE=&AO9"@D;65T:&]D;F%M92P@)B1A<F=S*2!["B`@("`@("`@9VQO
M8F%L("1S;V%P7W-E<G9E<E]F875L=#L*("`@("`@("`D<V]A<%]S97)V97)?
M9F%U;'0@/2!N=6QL.PH*("`@("`@("!I9B`H)'1H:7,M/F-A;&Q(86YD;&5R
M*2!["B`@("`@("`@("`@(')E='5R;B!`8V%L;%]U<V5R7V9U;F-?87)R87DH
M)'1H:7,M/F-A;&Q(86YD;&5R+&%R<F%Y*"1M971H;V1N86UE+"1A<F=S*2D[
M"B`@("`@("`@?0H*("`@("`@("!S971?97)R;W)?:&%N9&QE<B@G4T]!4%]3
M97)V97)%<G)O<DAA;F1L97(G*3L*"B`@("`@("`@:68@*"1A<F=S*2!["B`@
M("`@("`@("`@("\O(&-A;&P@;65T:&]D('=I=&@@<&%R86UE=&5R<PH@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/G-O87!O8FIE8W0I("8F(&ES7V]B
M:F5C="@D=&AI<RT^<V]A<&]B:F5C="DI('L*("`@("`@("`@("`@("`@("1R
M970@/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH)B1T:&ES+3YS;V%P
M;V)J96-T+"`D;65T:&]D;F%M92DL)&%R9W,I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)')E="`]($!C86QL7W5S97)?9G5N8U]A
M<G)A>2@D;65T:&]D;F%M92PD87)G<RD["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!C86QL(&UE=&AO9"!W+R!N;R!P
M87)A;65T97)S"B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'1H:7,M/G-O
M87!O8FIE8W0I*2!["B`@("`@("`@("`@("`@("`D<F5T(#T@0&-A;&Q?=7-E
M<E]F=6YC*&%R<F%Y*"8D=&AI<RT^<V]A<&]B:F5C="P@)&UE=&AO9&YA;64I
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R970@
M/2!`8V%L;%]U<V5R7V9U;F,H)&UE=&AO9&YA;64I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R97-T;W)E7V5R<F]R7VAA;F1L97(H*3L*
M"B`@("`@("`@<F5T=7)N(&ES7VYU;&PH)'-O87!?<V5R=F5R7V9A=6QT*2`_
M("1R970@.B`D<V]A<%]S97)V97)?9F%U;'0["B`@("!]"@H@("`@+R\@8W)E
M871E('-O87!?=F%L(&]B:F5C="!W+R!R971U<FX@=F%L=65S(&9R;VT@;65T
M:&]D+"!U<V4@;65T:&]D('-I9VYA='5R92!T;R!D971E<FUI;F4@='EP90H@
M("`@9G5N8W1I;VX@8G5I;&1297-U;'0H)B1M971H;V1?<F5S<&]N<V4L("8D
M<F5T=7)N7W1Y<&4L("1R971U<FY?;F%M93TG<F5T=7)N)RP@)&YA;65S<&%C
M92`]("<G*0H@("`@>PH@("`@("`@(&EF("AG971T>7!E*"1M971H;V1?<F5S
M<&]N<V4I(#T]("=O8FIE8W0G("8F(&ES7V$H)&UE=&AO9%]R97-P;VYS92PG
M<V]A<%]V86QU92<I*2!["B`@("`@("`@("`@("1R971U<FY?=F%L(#T@87)R
M87DH)&UE=&AO9%]R97-P;VYS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1R971U<FY?='EP92D@)B8@:7-?87)R87DH
M)&UE=&AO9%]R97-P;VYS92DI('L*("`@("`@("`@("`@("`@("1I(#T@,#L*
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5T=7)N7W1Y<&4@87,@)&ME
M>2`]/B`D='EP92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE
M<FEC*"1K97DI*2`D:V5Y(#T@)VET96TG.PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1M971H;V1?<F5S<&]N<V5;)&E=+"=S;V%P7W9A;'5E)RDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;E]V86Q;72`]("1M
M971H;V1?<F5S<&]N<V5;)&DK*UT["B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M
M92@D:V5Y+"`D;F%M97-P86-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)')E='5R;E]V86Q;72`])B!N97<@4T]!4%]686QU92@D<6XM/F9Q;B@I+"1T
M>7!E+"1M971H;V1?<F5S<&]N<V5;)&DK*UTI.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T=7)N7W1Y<&4I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&ME>7,@/2!A<G)A>5]K97ES*"1R971U
M<FY?='EP92D["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]N=6UE<FEC
M*"1K97ES6S!=*2D@)')E='5R;E]N86UE(#T@)&ME>7-;,%T["B`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y7W9A;'5E<R@D<F5T=7)N7W1Y
M<&4I.PH@("`@("`@("`@("`@("`@("`@("1R971U<FY?='EP92`]("1V86QU
M97-;,%T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<6X@
M/28@;F5W(%%.86UE*"1R971U<FY?;F%M92P@)&YA;65S<&%C92D["B`@("`@
M("`@("`@("`@("`D<F5T=7)N7W9A;"`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`D<F5T=7)N7W9A;%M=(#TF(&YE=R!33T%07U9A;'5E*"1Q;BT^9G%N
M*"DL)')E='5R;E]T>7!E+"1M971H;V1?<F5S<&]N<V4I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T=7)N7W9A;#L*("`@
M('T*"B`@("!F=6YC=&EO;B!P87)S95)E<75E<W0H)&1A=&$@/2`G)RP@)&%T
M=&%C:&UE;G1S(#T@;G5L;"D*("`@('L*("`@("`@("`O+R!P87)S92!R97-P
M;VYS92P@9V5T('-O87`@<&%R<V5R(&]B:@H@("`@("`@("1P87)S97(@/28@
M;F5W(%-/05!?4&%R<V5R*"1D871A+"1T:&ES+3YX;6Q?96YC;V1I;F<L)&%T
M=&%C:&UE;G1S*3L*("`@("`@("`O+R!I9B!F875L="!O8V-U<G)E9"!D=7)I
M;F<@;65S<V%G92!P87)S:6YG"B`@("`@("`@:68@*"1P87)S97(M/F9A=6QT
M*2!["B`@("`@("`@("`@("1T:&ES+3YF875L="`]("1P87)S97(M/F9A=6QT
M.PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@("`@
M("\O*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*@H@("`@("`@("\O(&AA;F1L92!M97-S86=E(&AE861E
M<G,*"B`@("`@("`@)')E<75E<W1?:&5A9&5R<R`]("1P87)S97(M/F=E=$AE
M861E<G,H*3L*("`@("`@("`D:&5A9&5R7W)E<W5L=',@/2!A<G)A>2@I.PH*
M("`@("`@("!I9B`H)')E<75E<W1?:&5A9&5R<RD@>PH@("`@("`@("`@("!I
M9B`H(6ES7V$H)')E<75E<W1?:&5A9&5R<RPG<V]A<%]V86QU92<I*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")P87)S97(@
M9&ED(&YO="!R971U<FX@4T]!4%]686QU92!O8FIE8W0Z("1R97%U97-T7VAE
M861E<G,B+"<G+"<G+"=397)V97(G*3L*("`@("`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D<F5Q=65S
M=%]H96%D97)S+3YV86QU92D@>PH@("`@("`@("`@("`O+R!H86YD;&4@:&5A
M9&5R<R!N;W<*("`@("`@("`@("`@9F]R96%C:"`H)')E<75E<W1?:&5A9&5R
M<RT^=F%L=64@87,@)&AE861E<E]V86PI('L*("`@("`@("`@("`@("`@("1F
M7V5X:7-T<R`]("1T:&ES+3YV86QI9&%T94UE=&AO9"@D:&5A9&5R7W9A;"T^
M;F%M92P@)&AE861E<E]V86PM/FYA;65S<&%C92D["@H@("`@("`@("`@("`@
M("`@(R!86%@@=&AI<R!D;V5S(&YO="!T86ME(&EN=&\@86-C;W5N="!M97-S
M86=E(')O=71I;F<@>65T"B`@("`@("`@("`@("`@("`D;7EA8W1O<B`]("@*
M("`@("`@("`@("`@("`@("`@("`A)&AE861E<E]V86PM/F%C=&]R('Q\"B`@
M("`@("`@("`@("`@("`@("`@)&AE861E<E]V86PM/F%C=&]R(#T]("=H='1P
M.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V%C=&]R+VYE>'0G('Q\"B`@
M("`@("`@("`@("`@("`@("`@)&AE861E<E]V86PM/F%C=&]R(#T]("1T:&ES
M+3YE;F1P;VEN="D["@H@("`@("`@("`@("`@("`@:68@*"$D9E]E>&ES=',@
M)B8@)&AE861E<E]V86PM/FUU<W1U;F1E<G-T86YD("8F("1M>6%C=&]R*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B
M22!D;VXG="!U;F1E<G-T86YD(&AE861E<B`D:&5A9&5R7W9A;"T^;F%M92XB
M+"<G+"<G+"=-=7-T56YD97)S=&%N9"<I.PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("\O('=E(&]N;'D@:&%N9&QE('1H92!H96%D97(@:68@:70G<R!F;W(@
M=7,*("`@("`@("`@("`@("`@("1I<V]K(#T@)&9?97AI<W1S("8F("1M>6%C
M=&]R.PH*("`@("`@("`@("`@("`@(&EF("@D:7-O:RD@>PH@("`@("`@("`@
M("`@("`@("`@(",@8V%L;"!O=7(@:&5A9&5R(&YO=R$*("`@("`@("`@("`@
M("`@("`@("`D:&5A9&5R7VUE=&AO9"`]("1H96%D97)?=F%L+3YN86UE.PH@
M("`@("`@("`@("`@("`@("`@("1H96%D97)?9&%T82`](&%R<F%Y*"1T:&ES
M+3Y?9&5C;V1E*"1H96%D97)?=F%L*2D["B`@("`@("`@("`@("`@("`@("`@
M+R\@:68@=&AE<F4@87)E('!A<F%M971E<G,@=&\@<&%S<PH@("`@("`@("`@
M("`@("`@("`@("1H<B`])B`D=&AI<RT^8V%L;$UE=&AO9"@D:&5A9&5R7VUE
M=&AO9"P@)&AE861E<E]D871A*3L*("`@("`@("`@("`@("`@("`@("`C(&EF
M('1H97D@<F5T=7)N(&$@9F%U;'0L('1H96X@:70G<R!A;&P@;W9E<B$*("`@
M("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:'(I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M)&AR*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1H96%D
M97)?<F5S=6QT<UM=(#T@87)R87E?<VAI9G0H)'1H:7,M/F)U:6QD4F5S=6QT
M*"1H<BP@)'1H:7,M/G)E='5R;E]T>7!E+"`D:&5A9&5R7VUE=&AO9"P@)&AE
M861E<E]V86PM/FYA;65S<&%C92DI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*@H@("`@("`@("\O(&AA;F1L92!T:&4@;65T:&]D(&-A;&P*
M"B`@("`@("`@+R\@979A;'5A=&4@;65S<V%G92P@9V5T=&EN9R!B86-K(&$@
M4T]!4%]686QU92!O8FIE8W0*("`@("`@("`D=&AI<RT^8V%L;%]M971H;V1N
M86UE(#T@)'1H:7,M/FUE=&AO9&YA;64@/2`D<&%R<V5R+3YR;V]T7W-T<G5C
M=%]N86UE6S!=.PH*("`@("`@("`O+R!F:6=U<F4@;W5T('1H92!M971H;V1?
M;F%M97-P86-E"B`@("`@("`@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4@/2`D
M<&%R<V5R+3YM97-S86=E6R1P87)S97(M/G)O;W1?<W1R=6-T6S!=75LG;F%M
M97-P86-E)UT["@H@("`@("`@(&EF("@D=&AI<RT^7W=S9&PI('L*("`@("`@
M("`@("`@)'1H:7,M/E]S97138VAE;6%697)S:6]N*"1T:&ES+3Y?=W-D;"T^
M>'-D*3L*("`@("`@("`@("`@)&1A=&%(86YD;&5R(#T@)'1H:7,M/E]W<V1L
M+3YG971$871A2&%N9&QE<B@D=&AI<RT^;65T:&]D;F%M92PD=&AI<RT^;65T
M:&]D7VYA;65S<&%C92D["B`@("`@("`@("`@(&EF("@D9&%T84AA;F1L97(I
M"B`@("`@("`@("`@("`@("`D=&AI<RT^8V%L;%]M971H;V1N86UE(#T@)'1H
M:7,M/FUE=&AO9&YA;64@/2`D9&%T84AA;F1L97(["@H@("`@("`@("`@("`D
M=&AI<RT^7W!O<G1.86UE(#T@)'1H:7,M/E]W<V1L+3YG9710;W)T3F%M92@D
M=&AI<RT^;65T:&]D;F%M92D["B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1T:&ES+3Y?<&]R=$YA;64I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI<RT^7W!O<G1.86UE*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W!$871A(#T@)'1H:7,M/E]W
M<V1L+3YG971/<&5R871I;VY$871A*"1T:&ES+3Y?<&]R=$YA;64L("1T:&ES
M+3YM971H;V1N86UE*3L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&]P1&%T82DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"1O<$1A=&$I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT@/2`D;W!$871A6R=S='EL
M92==.PH@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=U<V4G72`]("1O
M<$1A=&%;)V]U='!U="==6R=U<V4G73L*("`@("`@("`@("`@)'1H:7,M/E]?
M;W!T:6]N<ULG<&%R86UE=&5R<R==(#T@)&]P1&%T85LG<&%R86UE=&5R<R==
M.PH@("`@("`@('T*"B`@("`@("`@+R\@9&]E<R!M971H;V0@97AI<W0_"B`@
M("`@("`@:68@*"$D=&AI<RT^;65T:&]D;F%M92!\?"`A)'1H:7,M/G9A;&ED
M871E365T:&]D*"1T:&ES+3YM971H;V1N86UE+"1T:&ES+3YM971H;V1?;F%M
M97-P86-E*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*")M971H;V0@)WM[)'1H:7,M/FUE=&AO9%]N86UE<W!A8V5]?21T:&ES+3YM
M971H;V1N86UE)R!N;W0@9&5F:6YE9"!I;B!S97)V:6-E(BPG)RPG)RPG4V5R
M=F5R)RD["B`@("`@("`@("`@(')E='5R;B!.54Q,.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"$D<F5Q=65S=%]V86P@/2`D<&%R<V5R+3YG971297-P;VYS
M92@I*2!["B`@("`@("`@("`@(')E='5R;B!.54Q,.PH@("`@("`@('T*("`@
M("`@("!I9B`H(6ES7V$H)')E<75E<W1?=F%L+"=S;V%P7W9A;'5E)RDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B<&%R<V5R(&1I
M9"!N;W0@<F5T=7)N(%-/05!?5F%L=64@;V)J96-T.B`D<F5Q=65S=%]V86PB
M+"<G+"<G+"=397)V97(G*3L*("`@("`@("`@("`@<F5T=7)N($Y53$P["B`@
M("`@("`@?0H*("`@("`@("`O+R!V97)I9GD@=&AA="!33T%07U9A;'5E(&]B
M:F5C=',@:6X@<F5Q=65S="!M871C:"!T:&4@;65T:&]D<R!S:6=N871U<F4*
M("`@("`@("!I9B`H(21T:&ES+3YV97)I9GE-971H;V0H)')E<75E<W1?=F%L
M*2D@>PH@("`@("`@("`@("`O+R!V97)I9GE-971H;V0@8W)E871E<R!T:&4@
M9F%U;'0*("`@("`@("`@("`@<F5T=7)N($Y53$P["B`@("`@("`@?0H*("`@
M("`@("`O+R!N965D('1O('-E="!S<&5C:6%L(&5R<F]R(&1E=&5C=&EO;B!I
M;G-I9&4@=&AE('9A;'5E(&-L87-S"B`@("`@("`@+R\@<V\@87,@=&\@9&EF
M9F5R96YT:6%T92!B971W965N(&YO('!A<F%M<R!P87-S960L(&%N9"!A;B!E
M<G)O<B!D96-O9&EN9PH@("`@("`@("1R97%U97-T7V1A=&$@/2`D=&AI<RT^
M7U]D96-O9&5297%U97-T*"1R97%U97-T7W9A;"D["B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)')E<75E<W1?9&%T82DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)')E<75E<W1?9&%T82D["B`@
M("`@("`@?0H@("`@("`@("1M971H;V1?<F5S<&]N<V4@/28@)'1H:7,M/F-A
M;&Q-971H;V0H)'1H:7,M/F-A;&Q?;65T:&]D;F%M92P@)')E<75E<W1?9&%T
M82D["@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1M971H;V1?<F5S<&]N
M<V4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&UE
M=&AO9%]R97-P;VYS92D["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?7V]P=&EO;G-;)W!A<F%M971E
M<G,G72!\?"`A)&UE=&AO9%]R97-P;VYS92!\?"`D=&AI<RT^7U]O<'1I;VYS
M6R=S='EL92==/3TG<G!C)RD@>PH@("`@("`@("`@("`O+R!G970@=&AE(&UE
M=&AO9"!R97-U;'0*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&UE=&AO9%]R
M97-P;VYS92DI"B`@("`@("`@("`@("`@("`D<F5T=7)N7W9A;"`]($Y53$P[
M"B`@("`@("`@("`@(&5L<V4*("`@("`@("`@("`@("`@("1R971U<FY?=F%L
M(#T@)'1H:7,M/F)U:6QD4F5S=6QT*"1M971H;V1?<F5S<&]N<V4L("1T:&ES
M+3YR971U<FY?='EP92D["@H@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE
M*"1T:&ES+3YM971H;V1N86UE+B=297-P;VYS92<L)'1H:7,M/FUE=&AO9%]N
M86UE<W!A8V4I.PH@("`@("`@("`@("`D;65T:&]D5F%L=64@/28@;F5W(%-/
M05!?5F%L=64H)'%N+3YF<6XH*2P@)U-T<G5C="<L("1R971U<FY?=F%L*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;65T:&]D5F%L=64@/28@
M)&UE=&AO9%]R97-P;VYS93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;6%K945N=F5L;W!E*"1M971H;V1686QU92P@)&AE861E<E]R97-U
M;'1S+"`D=&AI<RT^<F5S<&]N<V5?96YC;V1I;F<I.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9?7V1E8V]D95)E<75E<W0H)')E<75E<W0L)'-H:69T/69A;'-E
M*0H@("`@>PH@("`@("`@(&EF("@A)')E<75E<W0I(')E='5R;B!.54Q,.PH@
M("`@("`@("\O(&-H96-K(&9O<B!V86QI9"!R97-P;VYS90H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1R97%U97-T*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D<F5Q=65S="D["B`@("`@("`@
M?2!E;'-E(&EF("@A:7-?82@D<F5Q=65S="PG<V]A<%]V86QU92<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"));G9A
M;&ED(&1A=&$@:6X@<V5R=F5R.CI?7V1E8V]D95)E<75E<W0B*3L*("`@("`@
M("!]"@H@("`@("`@("\O(&1E8V]D92!T;R!N871I=F4@<&AP(&1A=&%T>7!E
M"B`@("`@("`@)')E<75E<W1!<G)A>2`]("1T:&ES+3Y?9&5C;V1E*"1R97%U
M97-T*3L*("`@("`@("`O+R!F875L=#\*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5Q=65S=$%R<F%Y*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@D<F5Q=65S=$%R<F%Y*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&ES7V]B:F5C="@D<F5Q=65S=$%R<F%Y*28F(&=E=%]C
M;&%S<R@D<F5Q=65S=$%R<F%Y*2`]/2`G<W1D0VQA<W,G*2!["B`@("`@("`@
M("`@("`@("`D<F5Q=65S=$%R<F%Y(#T@9V5T7V]B:F5C=%]V87)S*"1R97%U
M97-T07)R87DI.PH@("`@("`@('T@96QS90H@("`@("`@(&EF("@D=&AI<RT^
M7U]O<'1I;VYS6R=S='EL92==/3TG9&]C=6UE;G0G*2!["B`@("`@("`@("`@
M("1R97%U97-T07)R87D@/2!A<G)A>2@D<F5Q=65S=$%R<F%Y*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R97%U97-T07)R87DI*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D<F5Q=65S=$%R<F%Y6R=F875L=&-O9&4G
M72D@?'P@:7-S970H)')E<75E<W1!<G)A>5LG4T]!4"U%3E8Z9F%U;'1C;V1E
M)UTI*2!["B`@("`@("`@("`@("`@("`D9F%U;'1C;V1E(#T@)&9A=6QT<W1R
M:6YG(#T@)&9A=6QT9&5T86EL(#T@)&9A=6QT86-T;W(@/2`G)SL*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1R97%U97-T07)R87D@87,@)&L@/3X@)'8I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T<B@D:RPG9F%U;'1C
M;V1E)RDI("1F875L=&-O9&4@/2`D=CL*("`@("`@("`@("`@("`@("`@("!I
M9B`H<W1R:7-T<B@D:RPG9F%U;'1S=')I;F<G*2D@)&9A=6QT<W1R:6YG(#T@
M)'8["B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FES='(H)&LL)V1E=&%I
M;"<I*2`D9F%U;'1D971A:6P@/2`D=CL*("`@("`@("`@("`@("`@("`@("!I
M9B`H<W1R:7-T<B@D:RPG9F%U;'1A8W1O<B<I*2`D9F%U;'1A8W1O<B`]("1V
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&9A=6QT<W1R:6YG+"`D9F%U;'1D971A
M:6PL("1F875L=&%C=&]R+"`D9F%U;'1C;V1E*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`O+R!R971U<FX@87)R87D@;V8@<F5T=7)N('9A;'5E<PH@
M("`@("`@("`@("!I9B`H)'-H:69T("8F(&-O=6YT*"1R97%U97-T07)R87DI
M(#T](#$I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>5]S:&EF="@D
M<F5Q=65S=$%R<F%Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@)')E<75E<W1!<G)A>3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R
M97%U97-T07)R87D["B`@("!]"@H@("`@9G5N8W1I;VX@=F5R:69Y365T:&]D
M*"1R97%U97-T*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A;&Q686QI
M9&%T:6]N*2!R971U<FX@5%)513L*("`@("`@("`O+W)E='5R;B!T<G5E.PH@
M("`@("`@("1P87)A;7,@/2`D<F5Q=65S="T^=F%L=64["@H@("`@("`@("\O
M(&=E="!T:&4@9&ES<&%T8V@@;6%P(&EF(&]N92!E>&ES=',*("`@("`@("`D
M;6%P(#T@3E5,3#L*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D=&AI
M<RT^;65T:&]D;F%M92P@)'1H:7,M/F1I<W!A=&-H7VUA<"DI('L*("`@("`@
M("`@("`@)&UA<"`]("1T:&ES+3YD:7-P871C:%]M87!;)'1H:7,M/FUE=&AO
M9&YA;65=.PH@("`@("`@('T@96QS92!I9B`H:7-S970H)'1H:7,M/G-O87!O
M8FIE8W0I*2!["B`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES
M+3YS;V%P;V)J96-T+"`G7U]D:7-P871C:"<I*2!["B`@("`@("`@("`@("`@
M("`D;6%P(#T@)'1H:7,M/G-O87!O8FIE8W0M/E]?9&ES<&%T8V@H)'1H:7,M
M/FUE=&AO9&YA;64I.PH@("`@("`@("`@("!](&5L<V4@:68@*&UE=&AO9%]E
M>&ES=',H)'1H:7,M/G-O87!O8FIE8W0L("1T:&ES+3YM971H;V1N86UE*2D@
M>PH@("`@("`@("`@("`@("`@+R\@;F\@;6%P+"!A;&P@<'5B;&EC(&9U;F-T
M:6]N<R!A<F4@<V]A<"!F=6YC=&EO;G,*("`@("`@("`@("`@("`@(')E='5R
M;B!44E5%.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A
M)&UA<"D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")S
M;V%P(')E<75E<W0@<W!E8VEF:65D(&%N('5N:&%N9&QE9"!M971H;V0@)R1T
M:&ES+3YM971H;V1N86UE)R(L)R<L)R<L)T-L:65N="<I.PH@("`@("`@("`@
M("!R971U<FX@1D%,4T4["B`@("`@("`@?0H*("`@("`@("`O+R!I9B!W92!A
M;&EA<V5D('1H92!S;V%P(&UE=&AO9"!N86UE('1O(&$@<&AP(&9U;F-T:6]N
M+`H@("`@("`@("\O(&-H86YG92!T:&4@8V%L;%]M971H;V0@<V\@=V4@9&\@
M=&AE(')I9VAT('1H:6YG+@H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S
M*"=A;&EA<R<L)&UA<"D@)B8@(65M<'1Y*"1M87!;)V%L:6%S)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3YC86QL7VUE=&AO9&YA;64@/2`D;6%P6R=A;&EA
M<R==.PH@("`@("`@('T*"B`@("`@("`@+R\@:68@=&AE<F4@87)E(&EN<'5T
M('!A<F%M971E<G,@<F5Q=6ER960N+BX*("`@("`@("!I9B`H)'-I9R`]("1M
M87!;)VEN)UTI('L*("`@("`@("`@("`@)'1H:7,M/FEN<'5T7W9A;'5E(#T@
M8V]U;G0H)'-I9RD["B`@("`@("`@("`@("1T:&ES+3YR971U<FY?='EP92`]
M("1T:&ES+3YG9712971U<FY4>7!E*"1M87!;)V]U="==*3L*("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("`@("`O
M+R!V86QI9&%T92!T:&4@;G5M8F5R(&]F('!A<F%M971E<G,*("`@("`@("`@
M("`@("`@(&EF("AC;W5N="@D<&%R86US*2`]/2!C;W5N="@D<VEG*2D@>PH@
M("`@("`@("`@("`@("`@("`@("\O(&UA:V4@87)R87D@;V8@<&%R86T@='EP
M97,*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P
M87)A;2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<%M=(#T@<W1R=&]L
M;W=E<B@D<&%R86TM/G1Y<&4I.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`D<VEG7W0@/2!A<G)A>5]V86QU97,H)'-I9RD[
M"B`@("`@("`@("`@("`@("`@("`@+R\@=F%L:61A=&4@96%C:"!P87)A;2=S
M('1Y<&4*("`@("`@("`@("`@("`@("`@("!F;W(H)&D],#L@)&D@/"!C;W5N
M="@D<"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@='EP
M92!N;W0@;6%T8V@*("`@("`@("`@("`@("`@("`@("`@("`@+R\@:68@<V]A
M<"!T>7!E<R!D;R!N;W0@;6%T8V@L('=E(&]K(&ET(&EF('1H92!M87!P960@
M<&AP('1Y<&5S(&UA=&-H"B`@("`@("`@("`@("`@("`@("`@("`@("\O('1H
M:7,@86QL;W=S('5S:6YG('!L86EN('!H<"!V87)I86)L97,@=&\@=V]R:R`H
M:64N('-T=69F(&QI:V4@1&5C:6UA;"!W;W5L9"!F86EL(&]T:&5R=VES92D*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@=V4@;VYL>2!E<G)O<B!I9B!T
M:&4@='EP97,@97AI<W0@:6X@;W5R('1Y<&4@;6%P<RP@86YD('1H97D@9&EF
M9F5R"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1S
M:6=?=%LD:5TL)'!;)&E=*2$],"`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*&ES<V5T*"1T:&ES+3Y?='EP96UA<%M33T%07UA-3%]30TA%34%?
M5D524TE/3EU;)'-I9U]T6R1I75TI("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S=')C87-E8VUP*"1T:&ES+3Y?='EP96UA<%M33T%07UA-3%]3
M0TA%34%?5D524TE/3EU;)'-I9U]T6R1I75TL)'1H:7,M/E]T>7!E;6%P6U-/
M05!?6$U,7U-#2$5-05]615)324].75LD<%LD:5U=*2$],"DI('L*"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D<&%R86US6R1I73L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H(G-O87`@<F5Q=65S="!C;VYT86EN960@;6ES;6%T8VAI;F<@<&%R
M86UE=&5R<R!O9B!N86UE("1P87)A;2T^;F%M92!H860@='EP92!;>R1P6R1I
M77U=+"!W:&EC:"!D:60@;F]T(&UA=&-H('-I9VYA='5R92=S('1Y<&4Z(%M[
M)'-I9U]T6R1I77U=+"!M871C:&5D/R`B+BAS=')C87-E8VUP*"1S:6=?=%LD
M:5TL)'!;)&E=*2DL)R<L)R<L)T-L:65N="<I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@+R\@;V]P<RP@=W)O
M;F<@;G5M8F5R(&]F('!A<F%M<W,*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B
M<V]A<"!R97%U97-T(&-O;G1A:6YE9"!I;F-O<G)E8W0@;G5M8F5R(&]F('!A
M<F%M971E<G,N(&UE=&AO9"`G)'1H:7,M/FUE=&AO9&YA;64G(')E<75I<F5D
M("(N8V]U;G0H)'-I9RDN)R!A;F0@<F5Q=65S="!P<F]V:61E9"`G+F-O=6YT
M*"1P87)A;7,I+"<G+"<G+"=#;&EE;G0G*3L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("\O(&]O<',L(&YO('!A<F%M<RXN+@H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B<V]A<"!R
M97%U97-T(&-O;G1A:6YE9"!I;F-O<G)E8W0@;G5M8F5R(&]F('!A<F%M971E
M<G,N(&UE=&AO9"`G)'1H:7,M/FUE=&AO9&YA;64G(')E<75I<F5S("(N8V]U
M;G0H)'-I9RDN)R!P87)A;65T97)S+"!A;F0@<F5Q=65S="!P<F]V:61E9"!N
M;VYE)RPG)RPG)RPG0VQI96YT)RD["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`O+R!N;R!P87)A;7,*("`@
M("`@("!]"B`@("`@("`@+R\@=V4G;&P@=')Y(&ET(&%N>7=A>0H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O(&=E="!S=')I;F<@<F5T=7)N
M('1Y<&4@9G)O;2!D:7-P871C:"!M87`*("`@(&9U;F-T:6]N(&=E=%)E='5R
M;E1Y<&4H)')E='5R;F1A=&$I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1R971U<FYD871A*2D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)')E='5R
M;F1A=&$I(#X@,2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R971U<FYD
M871A.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T>7!E(#T@87)R87E?
M<VAI9G0H)')E='5R;F1A=&$I.PH@("`@("`@("`@("!R971U<FX@)'1Y<&4[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F
M=6YC=&EO;B!V86QI9&%T94UE=&AO9"@D;65T:&]D;F%M92P@)&YA;65S<&%C
M92`]($Y53$PI"B`@("!["B`@("`@("`@=6YS970H)'1H:7,M/G-O87!O8FIE
M8W0I.PH@("`@("`@(&EF("@A)'1H:7,M/F-A;&Q686QI9&%T:6]N*2!R971U
M<FX@5%)513L*("`@("`@("`C(&YO('-O87`@86-C97-S('1O('!R:79A=&4@
M9G5N8W1I;VYS"B`@("`@("`@:68@*"1M971H;V1N86UE6S!=(#T]("=?)RD@
M<F5T=7)N($9!3%-%.PH*("`@("`@("`O*B!I9B!I="=S(&EN(&]U<B!F=6YC
M=&EO;B!L:7-T+"!O:R`J+PH@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S
M*"1M971H;V1N86UE+"`D=&AI<RT^9&ES<&%T8VA?;6%P*2`F)@H@("`@("`@
M("`@("`H(21N86UE<W!A8V4@?'P@(6%R<F%Y7VME>5]E>&ES=',H)VYA;65S
M<&%C92<L("1T:&ES+3YD:7-P871C:%]M87!;)&UE=&AO9&YA;65=*2!\?`H@
M("`@("`@("`@("`@)&YA;65S<&%C92`]/2`D=&AI<RT^9&ES<&%T8VA?;6%P
M6R1M971H;V1N86UE75LG;F%M97-P86-E)UTI*2!["B`@("`@("`@("`@("`@
M("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G;F%M97-P86-E)RP@)'1H:7,M/F1I
M<W!A=&-H7VUA<%LD;65T:&]D;F%M95TI*0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YM971H;V1?;F%M97-P86-E(#T@)'1H:7,M/F1I<W!A=&-H7VUA
M<%LD;65T:&]D;F%M95U;)VYA;65S<&%C92==.PH@("`@("`@("`@("!R971U
M<FX@5%)513L*("`@("`@("!]"@H@("`@("`@("\J(&EF(&ET)W,@:6X@86X@
M;V)J96-T+"!I="=S(&]K("HO"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD
M:7-P871C:%]O8FIE8W1S6R1N86UE<W!A8V5=*2D@>PH@("`@("`@("`@("`D
M8R`](&-O=6YT*"1T:&ES+3YD:7-P871C:%]O8FIE8W1S6R1N86UE<W!A8V5=
M*3L*("`@("`@("`@("`@9F]R("@D:3TP.R`D:2`\("1C.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("`D;V)J(#TF("1T:&ES+3YD:7-P871C:%]O8FIE8W1S
M6R1N86UE<W!A8V5=6R1I73L*("`@("`@("`@("`@("`@("\O(&EF('=E(&AA
M=F4@82!D:7-P871C:"!M87`L(&%N9"!T:&4@9G5N8W1I;VX@:7,@;F]T"B`@
M("`@("`@("`@("`@("`O+R!I;B!T:&4@9&ES<&%T8V@@;6%P+"!T:&5N(&ET
M(&ES(&YO="!C86QL86)L92$*("`@("`@("`@("`@("`@(&EF("AM971H;V1?
M97AI<W1S*"1O8FHL("=?7V1I<W!A=&-H)RDI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&]B:BT^7U]D:7-P871C:"@D;65T:&]D;F%M92DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4@
M/2`D;F%M97-P86-E.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V]A<&]B:F5C="`])B`D;V)J.PH@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@5%)513L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!](&5L<V4*("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S
M*"1O8FHL("1M971H;V1N86UE*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YM971H;V1?;F%M97-P86-E(#T@)&YA;65S<&%C93L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V]A<&]B:F5C="`])B`D;V)J.PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!44E5%.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!&04Q313L*
M("`@('T*"B`@("!F=6YC=&EO;B!A9&1/8FIE8W1-87`H)B1O8FHL("1N86UE
M<W!A8V4@/2!N=6QL+"`D<V5R=FEC95]N86UE(#T@)T1E9F%U;'0G+"`D<V5R
M=FEC95]D97-C(#T@)R<I"B`@("!["B`@("`@("`@:68@*"$D;F%M97-P86-E
M*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D;V)J+3YN86UE<W!A8V4I*2![
M"B`@("`@("`@("`@("`@("`O+R!86%@@82!B:70@;V8@8F%C:W=A<F1S(&-O
M;7!A=&EB:6QI='D*("`@("`@("`@("`@("`@("1N86UE<W!A8V4@/2`D;V)J
M+3YN86UE<W!A8V4["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=.;R!N86UE<W!A8V4@<')O
M=FED960@9F]R(&-L87-S(2<L)R<L)R<L)U-E<G9E<B<I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1I<W!A=&-H7V]B:F5C='-;)&YA
M;65S<&%C95TI*2!["B`@("`@("`@("`@("1T:&ES+3YD:7-P871C:%]O8FIE
M8W1S6R1N86UE<W!A8V5=(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/F1I<W!A=&-H7V]B:F5C='-;)&YA;65S<&%C95U;72`])B`D;V)J
M.PH*("`@("`@("`O+R!#<F5A=&4@:6YT97)N86P@5U-$3"!S=')U8W1U<F5S
M(&9O<B!O8FIE8W0*("`@("`@("`O+R!86%@@0F5C875S92!S;VUE(&EN=&5R
M;F%L('=O<FMI;F=S(&]F(%!%05(Z.E-/05`@9&5C:61E('=H971H97(@=&\*
M("`@("`@("`O+R!D;R!C97)T86EN('1H:6YG<R!B>2!T:&4@<')E<V5N8V4@
M;W(@86)S96YC92!O9B!?=W-D;"P@=V4@<VAO=6QD"B`@("`@("`@+R\@;VYL
M>2!C<F5A=&4@82!?=W-D;"!S=')U8W1U<F4@:68@=V4@:VYO=R!W92!C86X@
M9FEL;"!I=#L@:68*("`@("`@("`O+R!?7V1I<W!A=&-H7VUA<"!O<B!?7W1Y
M<&5D968@9F]R('1H92!O8FIE8W0@:7,@;6ES<VEN9RP@=V4@<VAO=6QD"B`@
M("`@("`@+R\@879O:60@8W)E871I;F<@:70N($QA=&5R+"!W:&5N('=E(&%R
M92!U<VEN9R!02%`@-2!I;G1R;W-P96-T:6]N+`H@("`@("`@("\O('=E('=I
M;&P@8F4@86)L92!T;R!M86ME('1H92!D871A(&9O<B!A;&P@;V)J96-T<R!W
M:71H;W5T(&%N>2!E>'1R80H@("`@("`@("\O(&EN9F]R;6%T:6]N(&9R;VT@
M=&AE(&1E=F5L;W!E<G,L(&%N9"!T:&ES(&-O;F1I=&EO;B!S:&]U;&0@8F4*
M("`@("`@("`O+R!D<F]P<&5D+@H*("`@("`@("`O+R!86%@@2VYO=VX@:7-S
M=64Z(&EF(&EM<&]R=&5D(%=31$P@*&)I;F174T1,*2!O<B!A;F]T:&5R(%=3
M1$P@<V]U<F-E"B`@("`@("`@+R\@:7,@=7-E9"!T;R!A9&0@7W=S9&P@<W1R
M=6-T=7)E(&EN9F]R;6%T:6]N+"!T:&5N(&%D9$]B:F5C=%=31$P@:7,*("`@
M("`@("`O+R!U<V5D+"!T:&5R92!I<R!A(&AI9V@@<&]S<VEB:6QI='D@;V8@
M7W=S9&P@9&%T82!C;W)R=7!T:6]N.PH@("`@("`@("\O('1H97)E9F]R92!Y
M;W4@<VAO=6QD(&%V;VED('5S:6YG(%]?9&ES<&%T8VA?;6%P+U]?='EP961E
M9B!D969I;FET:6]N<PH@("`@("`@("\O($%.1"!O=&AE<B!74T1,(&1A=&$@
M<V]U<F-E<R!I;B!T:&4@<V%M92!S97)V:6-E+B!792!E>&-L=61E(&-L87-S
M97,*("`@("`@("`O+R!T:&%T(&1O;B=T(&AA=F4@7U]T>7!E9&5F<R!T;R!A
M;&QO=R!E>'1E<FYA;"!74T1,(&9I;&5S('1O(&)E('5S960*("`@("`@("`O
M+R!W:71H(&-L87-S97,@=VET:"!N;R!I;G1E<FYA;"!T>7!E(&1E9FEN:71I
M;VYS("AT:&4@='EP97,@87)E(&1E9FEN960*("`@("`@("`O+R!I;B!T:&4@
M5U-$3"!F:6QE*2X@5VAE;B!A9&1/8FIE8W174T1,(&ES(')E9F%C=&]R960@
M=&\@;F]T(&-A=7-E"B`@("`@("`@+R\@8V]R<G5P=&EO;BP@=&AI<R!R97-T
M<FEC=&EO;B!C86X@8F4@<F5L87AE9"X*"B`@("`@("`@+R\@26X@<W5M;7)Y
M+"!I9B!Y;W4@861D(&%N(&]B:F5C="!W:71H(&)O=&@@82!D:7-P871C:"!M
M87`@86YD('1Y<&4*("`@("`@("`O+R!D969I;FET:6]N<RP@=&AE;B!P<F5V
M:6]U<R!74T1,(&9I;&4@;W!E<F%T:6]N(&%N9"!T>7!E(&1E9FEN:71I;VYS
M"B`@("`@("`@+R\@=VEL;"!B92!O=F5R=W)I='1E;BX*("`@("`@("!I9B`H
M:7-S970H)&]B:BT^7U]D:7-P871C:%]M87`I("8F(&ES<V5T*"1O8FHM/E]?
M='EP961E9BDI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$]B:F5C=%=31$PH
M)&]B:BP@)&YA;65S<&%C92P@)'-E<G9I8V5?;F%M92P@)'-E<G9I8V5?9&5S
M8RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\O(&%D9"!A(&UE=&AO9"!T;R!T:&4@9&ES<&%T8V@@;6%P"B`@("!F=6YC
M=&EO;B!A9&14;TUA<"@D;65T:&]D;F%M92P@)&EN+"`D;W5T+"`D;F%M97-P
M86-E(#T@3E5,3"P@)&%L:6%S/4Y53$PI"B`@("!["B`@("`@("`@:68@*"%F
M=6YC=&EO;E]E>&ES=',H)&UE=&AO9&YA;64I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H(F5R<F]R(&UA<'!I;F<@9G5N8W1I;VY<
M;B(L)R<L)R<L)U-E<G9E<B<I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YD:7-P871C:%]M87!;)&UE=&AO
M9&YA;65=6R=I;B==(#T@)&EN.PH@("`@("`@("1T:&ES+3YD:7-P871C:%]M
M87!;)&UE=&AO9&YA;65=6R=O=70G72`]("1O=70["B`@("`@("`@)'1H:7,M
M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95U;)V%L:6%S)UT@/2`D86QI87,[
M"B`@("`@("`@:68@*"1N86UE<W!A8V4I("1T:&ES+3YD:7-P871C:%]M87!;
M)&UE=&AO9&YA;65=6R=N86UE<W!A8V4G72`]("1N86UE<W!A8V4["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T0V%L;$AA
M;F1L97(H)&-A;&Q(86YD;&5R+"`D=F%L:61A=&EO;CUT<G5E*2!["B`@("`@
M("`@)'1H:7,M/F-A;&Q(86YD;&5R(#T@)&-A;&Q(86YD;&5R.PH@("`@("`@
M("1T:&ES+3YC86QL5F%L:61A=&EO;B`]("1V86QI9&%T:6]N.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0&1E<')E8V%T960@=7-E(&)I;F174T1,(&9R;VT@
M;F]W(&]N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)I;F0H)'=S9&Q?=7)L*2![
M"B`@("`@("`@)'1H:7,M/F)I;F174T1,*"1W<V1L7W5R;"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!`<&%R86T@('-T<FEN9R!A('5R;"!T;R!A(%=31$P@
M<F5S;W5R8V4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!B:6YD5U-$3"@D=W-D;%]U<FPI('L*("`@("`@("`O+R!I;G-T86YT
M:6%T92!W<V1L(&-L87-S"B`@("`@("`@)'1H:7,M/E]W<V1L(#TF(&YE=R!3
M3T%07U=31$PH)'=S9&Q?=7)L*3L*("`@("`@("!I9B`H)'1H:7,M/E]W<V1L
M+3YF875L="D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*"1T:&ES+3Y?=W-D;"T^9F%U;'0I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!A
M9&1/8FIE8W174T1,*"8D=W-D;%]O8FHL("1T87)G971.86UE<W!A8V4L("1S
M97)V:6-E7VYA;64L("1S97)V:6-E7V1E<V,@/2`G)RD@>PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]W<V1L*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W=S9&P@/28@;F5W(%-/05!?5U-$3#L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?=W-D;"T^<&%R<V5/8FIE8W0H)'=S9&Q?;V)J+"`D=&%R9V5T3F%M
M97-P86-E+"`D<V5R=FEC95]N86UE+"`D<V5R=FEC95]D97-C*3L*"B`@("`@
M("`@:68@*"1T:&ES+3Y?=W-D;"T^9F%U;'0I('L*("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@D=&AI<RT^7W=S9&PM/F9A=6QT*3L*("`@
M("`@("!]"B`@("!]"GT*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O1&ES8V\N<&AP````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,V-#0U`#$P-#$W
M,S8S,#`V`#`Q-S8W,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z($1M:71R:2!6:6YO9W)A
M9&]V(#QD:6UI=')I0'9I;F]G<F%D;W8N9&4^("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M($1I<V-O+G!H<"QV(#$N."`R,#`S+S`Y+S`X(#$W.C,P.C(Y(&%R;F%U9"!%
M>'`@)`H*<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N<&AP)SL*"F-L87-S(%-/
M05!?1$E30T]?4V5R=F5R(&5X=&5N9',@4T]!4%]"87-E7T]B:F5C=`I["B`@
M("!V87(@)&YA;65S<&%C97,@("`@(#T@87)R87DH4T-(14U!7U=31$P@/3X@
M)W=S9&PG+"!30TA%34%?4T]!4"`]/B`G<V]A<"<I.PH@("`@=F%R("1I;7!O
M<G1?;G,@("`@("`](&%R<F%Y*"D["B`@("!V87(@)'=S9&P@("`@("`@("`@
M(#T@)R<["B`@("!V87(@)&1I<V-O("`@("`@("`@(#T@)R<["B`@("!V87(@
M)%]W<V1L("`@("`@("`@(#T@87)R87DH*3L*("`@('9A<B`D7V1I<V-O("`@
M("`@("`@/2!A<G)A>2@I.PH@("`@=F%R("1?<V5R=FEC95]N86UE("`]("<G
M.PH@("`@=F%R("1?<V5R=FEC95]N<R`@("`]("<G.PH@("`@=F%R("1?<V5R
M=FEC95]D97-C("`]("<G.PH@("`@=F%R("1?<&]R=&YA;64@("`@("`]("<G
M.PH@("`@=F%R("1?8FEN9&EN9VYA;64@("`]("<G.PH@("`@=F%R("1S;V%P
M7W-E<G9E<B`@("`]($Y53$P["@H*("`@(&9U;F-T:6]N(%-/05!?1$E30T]?
M4V5R=F5R*"1S;V%P7W-E<G9E<BP@)'-E<G9I8V5?;F%M92P@)'-E<G9I8V5?
M9&5S8R`]("<G+"`D:6UP;W)T7VYS(#T@;G5L;"D*("`@('L*("`@("`@("!P
M87)E;G0Z.E-/05!?0F%S95]/8FIE8W0H)U-E<G9E<B<I.PH*("`@("`@("!I
M9B`H("%I<U]O8FIE8W0H)'-O87!?<V5R=F5R*0H@("`@("`@("`@("!\?"`A
M9V5T7V-L87-S*"1S;V%P7W-E<G9E<BD@/3T@)W-O87!?<V5R=F5R)RD@<F5T
M=7)N.PH*("`@("`@("`D=&AI<RT^7W-E<G9I8V5?;F%M92`]("1S97)V:6-E
M7VYA;64["B`@("`@("`@)'1H:7,M/E]S97)V:6-E7VYS(#T@(G5R;CHD<V5R
M=FEC95]N86UE(CL*("`@("`@("`D=&AI<RT^7W-E<G9I8V5?9&5S8R`]("1S
M97)V:6-E7V1E<V,["B`@("`@("`@)'1H:7,M/FEM<&]R=%]N<R`](&ES<V5T
M*"1I;7!O<G1?;G,I(#\@)&EM<&]R=%]N<R`Z("1T:&ES+3YI;7!O<G1?;G,[
M"B`@("`@("`@)'1H:7,M/G-O87!?<V5R=F5R(#T@)'-O87!?<V5R=F5R.PH@
M("`@("`@("1T:&ES+3YH;W-T(#T@:7-S970H)%]315)615);)TA45%!?2$]3
M5"==*3\D7U-%4E9%4ELG2%144%](3U-4)UTZ)VQO8V%L:&]S="<["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T1$E30T\H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?9V5N97)A=&5?1$E30T\H*3L*("`@("`@("!R971U<FX@)'1H:7,M/F1I
M<V-O.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%=31$PH*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?9V5N97)A=&5?5U-$3"@I.PH@("`@("`@(')E='5R;B`D
M=&AI<RT^=W-D;#L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5N97)A=&5?1$E3
M0T\H*0H@("`@>PH@("`@("`@(",@1$E30T\*("`@("`@("`D=&AI<RT^7V1I
M<V-O6R=D:7-C;SID:7-C;W9E<GDG75LG871T<B==6R=X;6QN<SID:7-C;R==
M(#T@4T-(14U!7T1)4T-/.PH@("`@("`@("1T:&ES+3Y?9&ES8V];)V1I<V-O
M.F1I<V-O=F5R>2==6R=A='1R)UU;)WAM;&YS.G-C;"==(#T@4T-(14U!7T1)
M4T-/7U-#3#L*("`@("`@("`D=&AI<RT^7V1I<V-O6R=D:7-C;SID:7-C;W9E
M<GDG75LG<V-L.F-O;G1R86-T4F5F)UU;)V%T='(G75LG<F5F)UT@/0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H87)R87E?:V5Y7V5X
M:7-T<R@G2%144%,G+"1?4T525D52*2`F)B`D7U-%4E9%4ELG2%144%,G73T]
M)V]N)RD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/R`G
M:'1T<',Z+R\G("X@)'1H:7,M/FAO<W0@+B`D7U-%4E9%4ELG4$A07U-%3$8G
M72`N("<_=W-D;"<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`G:'1T<#HO+R<@("X@)'1H:7,M/FAO<W0@+B`D7U-%4E9%4ELG4$A0
M7U-%3$8G72`N("<_=W-D;"<["@H@("`@("`@(",@9V5N97)A=&4@9&ES8V\@
M>&UL"B`@("`@("`@)'1H:7,M/E]G96YE<F%T95]$25-#3U]834PH)'1H:7,M
M/E]D:7-C;RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E;F5R871E7U=31$PH
M*0H@("`@>PH@("`@("`@(",@5U-$3`H@("`@("`@(&EF("AI<U]A<G)A>2@D
M=&AI<RT^<V]A<%]S97)V97(M/E]N86UE<W!A8V5S*2D@>PH@("`@("`@("`@
M("`C(&YE960@=&\@9V5T.B!T>7!E;G,L('AS9"`F(%-/05`M14Y#"B`@("`@
M("`@("`@("1F;&EP<&5D(#T@87)R87E?9FQI<"@D=&AI<RT^<V]A<%]S97)V
M97(M/E]N86UE<W!A8V5S*3L*("`@("`@("`@("`@)'1H:7,M/FYA;65S<&%C
M97-;)'1H:7,M/E]S97)V:6-E7VYS72`]("=T;G,G.PH@("`@("`@("`@("`D
M=&AI<RT^;F%M97-P86-E<ULD9FQI<'!E9%LG>'-D)UU=(#T@)WAS9"<["B`@
M("`@("`@("`@("1T:&ES+3YN86UE<W!A8V5S6R1F;&EP<&5D6R=33T%0+45.
M0R==72`]("=33T%0+45.0R<["B`@("`@("`@?0H*("`@("`@("`C($1%1DE.
M251)3TY3"B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=A
M='1R)UU;)VYA;64G72`]("1T:&ES+3Y?<V5R=FEC95]N86UE.PH@("`@("`@
M("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG871T<B==6R=T87)G971.
M86UE<W!A8V4G72`]("1T:&ES+3Y?<V5R=FEC95]N<SL*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^;F%M97-P86-E<R!A<R`D;G,@/3X@)'!R969I>"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)V%T='(G
M75LG>&UL;G,Z)R`N("1P<F5F:7A=(#T@)&YS.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)V%T='(G75LG>&UL;G,G
M72`](%-#2$5-05]74T1,.PH*("`@("`@("`C(&EM<&]R="!N86UE<W!A8V5S
M"B`@("`@("`@(R!S965M<R!T;R!N;W0@=V]R:R!Y970Z('=S9&PN97AE(&9O
M;2`N3D54(&-A;G0@:&%N9&QE(&EM<&]R=&5D(&-O;7!L971E('=S9&PM9&5F
M:6YI=&EO;G,*("`@("`@("`C"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YI
M;7!O<G1?;G,I/C`I('L*("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^:6UP;W)T7VYS(&%S("1?;G,@/3X@)%]L;V-A
M=&EO;BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET
M:6]N<R==6R=I;7!O<G0G75LD:5U;)V%T='(G75LG;&]C871I;VXG72`]("1?
M;&]C871I;VX["B`@("`@("`@("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN
M:71I;VYS)UU;)VEM<&]R="==6R1I75LG871T<B==6R=N86UE<W!A8V4G72`]
M("1?;G,["B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG
M='EP97,G75LG871T<B==6R=X;6QN<R==/2=H='1P.B\O<V-H96UA<RYX;6QS
M;V%P+F]R9R]W<V1L+R<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET
M:6]N<R==6R=T>7!E<R==6R=S8VAE;6$G73UA<G)A>2@I.PH@("`@("`@(",@
M4$]25%194$4M3D%-10H@("`@("`@("1T:&ES+3Y?<&]R=&YA;64@/2`D=&AI
M<RT^7W-E<G9I8V5?;F%M92`N("=0;W)T)SL*("`@("`@("`D=&AI<RT^7W=S
M9&Q;)V1E9FEN:71I;VYS)UU;)W!O<G14>7!E)UU;)V%T='(G75LG;F%M92==
M(#T@)'1H:7,M/E]P;W)T;F%M93L*"B`@("`@("`@(R!"24Y$24Y'+4Y!344*
M("`@("`@("`D=&AI<RT^7V)I;F1I;F=N86UE(#T@)'1H:7,M/E]S97)V:6-E
M7VYA;64@+B`G0FEN9&EN9R<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I
M;FET:6]N<R==6R=B:6YD:6YG)UU;)V%T='(G75LG;F%M92==(#T@)'1H:7,M
M/E]B:6YD:6YG;F%M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I
M;VYS)UU;)V)I;F1I;F<G75LG871T<B==6R=T>7!E)UT@/2`G=&YS.B<@+B`D
M=&AI<RT^7W!O<G1N86UE.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI
M=&EO;G,G75LG8FEN9&EN9R==6R=S;V%P.F)I;F1I;F<G75LG871T<B==6R=S
M='EL92==(#T@)W)P8R<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET
M:6]N<R==6R=B:6YD:6YG)UU;)W-O87`Z8FEN9&EN9R==6R=A='1R)UU;)W1R
M86YS<&]R="==(#T@4T-(14U!7U-/05!?2%144#L*"B`@("`@("`@(R!315)6
M24-%"B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=S97)V
M:6-E)UU;)V%T='(G75LG;F%M92==(#T@)'1H:7,M/E]S97)V:6-E7VYA;64@
M+B`G4V5R=FEC92<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N
M<R==6R=S97)V:6-E)UU;)V1O8W5M96YT871I;VXG75LG871T<B==(#T@)R<[
M"B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=S97)V:6-E
M)UU;)V1O8W5M96YT871I;VXG72`](&AT;6QE;G1I=&EE<R@D=&AI<RT^7W-E
M<G9I8V5?9&5S8RD["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N
M<R==6R=S97)V:6-E)UU;)W!O<G0G75LG871T<B==6R=N86UE)UT@/2`D=&AI
M<RT^7W!O<G1N86UE.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO
M;G,G75LG<V5R=FEC92==6R=P;W)T)UU;)V%T='(G75LG8FEN9&EN9R==(#T@
M)W1N<SHG("X@)'1H:7,M/E]B:6YD:6YG;F%M93L*("`@("`@("`D=&AI<RT^
M7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W-E<G9I8V4G75LG<&]R="==6R=S;V%P
M.F%D9')E<W,G75LG871T<B==6R=L;V-A=&EO;B==(#T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*&%R<F%Y7VME>5]E>&ES=',H)TA4
M5%!3)RPD7U-%4E9%4BD@)B8@)%]315)615);)TA45%!3)UT]/2=O;B<I"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#\@)VAT='!S.B\O
M)R`N("1T:&ES+3YH;W-T("X@)%]315)615);)U!(4%]314Q&)UT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`G:'1T<#HO+R<@("X@
M)'1H:7,M/FAO<W0@+B`D7U-%4E9%4ELG4$A07U-%3$8G73L*"B`@("`@("`@
M(PH@("`@("`@("1D:7-P871C:%]K97ES(#T@87)R87E?:V5Y<R@D=&AI<RT^
M<V]A<%]S97)V97(M/F1I<W!A=&-H7V]B:F5C=',I.PH@("`@("`@("1D8R`]
M(&-O=6YT*"1D:7-P871C:%]K97ES*3L*("`@("`@("!F;W(@*"1D:3TP.R`D
M9&D@/"`D9&,[("1D:2LK*2!["B`@("`@("`@("`@("1N86UE<W!A8V4@/2`D
M9&ES<&%T8VA?:V5Y<ULD9&E=.PH@("`@("`@("`@("`D;F%M97-P86-E7V]B
M:F5C=',@/28@)'1H:7,M/G-O87!?<V5R=F5R+3YD:7-P871C:%]O8FIE8W1S
M6R1N86UE<W!A8V5=.PH@("`@("`@("`@("`D;V,@/2!C;W5N="@D;F%M97-P
M86-E7V]B:F5C=',I.PH@("`@("`@("`@("!F;W(@*"1O:2`](#`[("1O:2`\
M("1O8SL@)&]I*RLI('L*("`@("`@("`@("`@("`@("1O8FIE8W0@/2`D;F%M
M97-P86-E7V]B:F5C='-;)&]I73L*("`@("`@("`@("`@("`@(",@='EP97,@
M9&5F:6YI=&EO;G,*("`@("`@("`@("`@("`@("1T:&ES+3YA9&138VAE;6%&
M<F]M36%P*"1O8FIE8W0M/E]?='EP961E9BD["B`@("`@("`@("`@("`@("`C
M($U%4U-!1T53"B`@("`@("`@("`@("`@("`D=&AI<RT^861D365T:&]D<T9R
M;VU-87`H)&]B:F5C="T^7U]D:7-P871C:%]M87`L)&YA;65S<&%C92QG971?
M8VQA<W,H)&]B:F5C="DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("AI<W-E="@D<V5R=F5R+3YD:7-P871C:%]M87`I*0H@("`@("`@
M("`@("`D=&AI<RT^861D365T:&]D<T9R;VU-87`H)'-E<G9E<BT^9&ES<&%T
M8VA?;6%P+"1N86UE<W!A8V4I.PH*"B`@("`@("`@(R!G96YE<F%T92!W<V1L
M"B`@("`@("`@)'1H:7,M/E]G96YE<F%T95]74T1,7UA-3"@D=&AI<RT^7W=S
M9&PI.PH@("`@?0H*("`@(&9U;F-T:6]N("9?9V5T4V-H96UA*"1N86UE<W!A
M8V4I('L*("`@("`@("`C(%-#2$5-00H@("`@("`@("1C(#T@8V]U;G0H)'1H
M:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=T>7!E<R==6R=S8VAE;6$G72D[
M"B`@("`@("`@9F]R*"1I(#T@,#L@)&D@/"`D8SL@)&DK*RD@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=T>7!E<R==
M6R=S8VAE;6$G75LD:5U;)V%T='(G75LG=&%R9V5T3F%M97-P86-E)UT@/3T@
M)&YA;65S<&%C92D*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W=S
M9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S)UU;)W-C:&5M82==6R1I73L*("`@
M("`@("!]"B`@("`@("`@(R!D;VXG="!H879E('1H:7,@;F%M97-P86-E"B`@
M("`@("`@)'-C:&5M82`](&%R<F%Y*"D["B`@("`@("`@)'-C:&5M85LG871T
M<B==(#T@87)R87DH*3L*("`@("`@("`D<V-H96UA6R=C;VUP;&5X5'EP92==
M(#T@87)R87DH*3L*("`@("`@("`D<V-H96UA6R=A='1R)UU;)WAM;&YS)UT@
M/2!A<G)A>5]S96%R8V@H)WAS9"<L)'1H:7,M/FYA;65S<&%C97,I.PH@("`@
M("`@("1S8VAE;6%;)V%T='(G75LG=&%R9V5T3F%M97-P86-E)UT@/2`D;F%M
M97-P86-E.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG
M='EP97,G75LG<V-H96UA)UU;72`])B`D<V-H96UA.PH@("`@("`@(')E='5R
M;B`D<V-H96UA.PH@("`@?0H*("`@(&9U;F-T:6]N(&%D9%-C:&5M849R;VU-
M87`H)B1M87`I('L*("`@("`@("!I9B`H(21M87`I(')E='5R;CL*("`@("`@
M("!F;W)E86-H("@D;6%P(&%S("1?='EP95]N86UE(#T^("1?='EP95]D968I
M('L*("`@("`@("`@("`@;&ES="@D='EP96YS+"1T>7!E*2`]("1T:&ES+3Y?
M9V5T5'EP94YS*"1?='EP95]N86UE*3L*("`@("`@("`@("`@:68@*"1T>7!E
M;G,@/3T@)WAS9"<I('L*("`@("`@("`@("`@("`@("\O(&-A;FYO="!A9&0@
M=&\@>'-D+"!L971S('5S92!M971H;V1?;F%M97-P86-E"B`@("`@("`@("`@
M("`@("`D='EP96YS(#T@)W1N<R<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'-C:&5M82`])B`D=&AI<RT^7V=E=%-C:&5M82AA<G)A>5]S96%R8V@H
M)'1Y<&5N<RPD=&AI<RT^;F%M97-P86-E<RDI.PH@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?:69#;VUP;&5X5'EP945X:7-T<R@D<V-H96UA6R=C;VUP;&5X
M5'EP92==+"`D='EP92DI('L*("`@("`@("`@("`@("`@("1C='EP92`])B`D
M<V-H96UA6R=C;VUP;&5X5'EP92==6UT["B`@("`@("`@("`@("`@("`D8W1Y
M<&5;)V%T='(G75LG;F%M92==(#T@)'1Y<&4["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D7W1Y<&5?9&5F(&%S("1?=F%R;F%M92`]/B`D7W9A<G1Y<&4I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7VEN="@D7W9A<FYA;64I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)%]V87)T>7!E;G,L
M)%]V87)T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1?=F%R='EP92D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1C='EP95LG86QL)UU;)V%T='(G72`]
M("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D96P@/28@)&-T>7!E6R=A
M;&PG75LG96QE;65N="==6UT["B`@("`@("`@("`@("`@("`@("`@("`@("1E
M;%LG871T<B==6R=N86UE)UT@/2`D7W9A<FYA;64["B`@("`@("`@("`@("`@
M("`@("`@("`@("1E;%LG871T<B==6R=T>7!E)UT@/2`D7W9A<G1Y<&5N<R`N
M("<Z)R`N("1?=F%R='EP93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1Y<&5;)V-O;7!L97A#;VYT
M96YT)UU;)V%T='(G72`]("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8W1Y<&5;)V-O;7!L97A#;VYT96YT)UU;)W)E<W1R:6-T:6]N)UU;)V%T='(G
M75LG8F%S92==(#T@)U-/05`M14Y#.D%R<F%Y)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)%]V87)T>7!E(&%S("1A<G)A>5]V87(@/3X@
M)&%R<F%Y7W1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QI
M<W0H)%]V87)T>7!E;G,L)%]V87)T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS
M*"1A<G)A>5]T>7!E*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M='EP95LG8V]M<&QE>$-O;G1E;G0G75LG<F5S=')I8W1I;VXG75LG871T<FEB
M=71E)UU;)V%T='(G75LG<F5F)UT@/2`G4T]!4"U%3D,Z87)R87E4>7!E)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C='EP95LG8V]M<&QE>$-O
M;G1E;G0G75LG<F5S=')I8W1I;VXG75LG871T<FEB=71E)UU;)V%T='(G75LG
M=W-D;#IA<G)A>51Y<&4G72`]("1?=F%R='EP96YS("X@)SHG("X@)%]V87)T
M>7!E("X@)UM=)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!A9&1-971H;V1S1G)O
M;4UA<"@F)&UA<"P@)&YA;65S<&%C92P@)&-L87-S;F%M92`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"$D;6%P*2!["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1M87`@87,@)&UE=&AO9%]N
M86UE(#T^("1M971H;V1?='EP97,I('L*("`@("`@("`@("`@:68@*&%R<F%Y
M7VME>5]E>&ES=',H)VYA;65S<&%C92<L)&UE=&AO9%]T>7!E<RDI('L*("`@
M("`@("`@("`@("`@("1M971H;V1?;F%M97-P86-E(#T@)&UE=&AO9%]T>7!E
M<ULG;F%M97-P86-E)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D;65T:&]D7VYA;65S<&%C92`]("1N86UE<W!A8V4["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@(R!)3E!55`H@("`@("`@("`@("!I9B`H
M:7-S970H)&UE=&AO9%]T>7!E<ULG:6XG72D@)B8@:7-?87)R87DH)&UE=&AO
M9%]T>7!E<ULG:6XG72DI('L*("`@("`@("`@("`@("`@("1I;G!U=%]M97-S
M86=E(#TF("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG;65S<V%G92==
M6UT["B`@("`@("`@("`@("`@("`D:6YP=71?;65S<V%G95LG871T<B==6R=N
M86UE)UT@/2`D;65T:&]D7VYA;64@+B`G4F5Q=65S="<["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;65T:&]D7W1Y<&5S6R=I;B==(&%S("1N86UE(#T^
M("1T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@;&ES="@D='EP96YS+"1T
M>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1T>7!E*3L*("`@("`@("`@("`@
M("`@("`@("`D<&%R="`])B`D:6YP=71?;65S<V%G95LG<&%R="==6UT["B`@
M("`@("`@("`@("`@("`@("`@)'!A<G1;)V%T='(G75LG;F%M92==(#T@)&YA
M;64["B`@("`@("`@("`@("`@("`@("`@)'!A<G1;)V%T='(G75LG='EP92==
M(#T@)'1Y<&5N<R`N("<Z)R`N("1T>7!E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`C($]55%!55`H@("`@("`@("`@
M("!I9B`H:7-S970H)&UE=&AO9%]T>7!E<ULG;W5T)UTI("8F(&ES7V%R<F%Y
M*"1M971H;V1?='EP97-;)V]U="==*2D@>PH@("`@("`@("`@("`@("`@)&]U
M='!U=%]M97-S86=E(#TF("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG
M;65S<V%G92==6UT["B`@("`@("`@("`@("`@("`D;W5T<'5T7VUE<W-A9V5;
M)V%T='(G75LG;F%M92==(#T@)&UE=&AO9%]N86UE("X@)U)E<W!O;G-E)SL*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1M971H;V1?='EP97-;)V]U="==
M(&%S("1N86UE(#T^("1T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@;&ES
M="@D='EP96YS+"1T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1T>7!E*3L*
M("`@("`@("`@("`@("`@("`@("`D<&%R="`])B`D;W5T<'5T7VUE<W-A9V5;
M)W!A<G0G75M=.PH@("`@("`@("`@("`@("`@("`@("1P87)T6R=A='1R)UU;
M)VYA;64G72`]("1N86UE.PH@("`@("`@("`@("`@("`@("`@("1P87)T6R=A
M='1R)UU;)W1Y<&4G72`]("1T>7!E;G,@+B`G.B<@+B`D='EP93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@(R!03U)4
M5%E015,*("`@("`@("`@("`@)&]P97)A=&EO;B`])B`D=&AI<RT^7W=S9&Q;
M)V1E9FEN:71I;VYS)UU;)W!O<G14>7!E)UU;)V]P97)A=&EO;B==6UT["@H@
M("`@("`@("`@("`D;W!E<F%T:6]N6R=A='1R)UU;)VYA;64G72`]("1M971H
M;V1?;F%M93L*"B`@("`@("`@("`@(",@24Y0550*("`@("`@("`@("`@)&]P
M97)A=&EO;ELG:6YP=70G75LG871T<B==6R=M97-S86=E)UT@/2`G=&YS.B<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)&EN<'5T7VUE<W-A9V5;
M)V%T='(G75LG;F%M92==.PH*("`@("`@("`@("`@(R!/5510550*("`@("`@
M("`@("`@)&]P97)A=&EO;ELG;W5T<'5T)UU;)V%T='(G75LG;65S<V%G92==
M(#T@)W1N<SHG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1O=71P
M=71?;65S<V%G95LG871T<B==6R=N86UE)UT["@H@("`@("`@("`@("`C($))
M3D1)3D<*("`@("`@("`@("`@)&)I;F1I;F<@/28@)'1H:7,M/E]W<V1L6R=D
M969I;FET:6]N<R==6R=B:6YD:6YG)UU;)V]P97)A=&EO;B==6UT["B`@("`@
M("`@("`@("1B:6YD:6YG6R=A='1R)UU;)VYA;64G72`]("1M971H;V1?;F%M
M93L*("`@("`@("`@("`@)&%C=&EO;B`]("1M971H;V1?;F%M97-P86-E("X@
M)R,G("X@*"1C;&%S<VYA;64_)&-L87-S;F%M92`N("<C)SHG)RD@+B`D;65T
M:&]D7VYA;64["B`@("`@("`@("`@("1B:6YD:6YG6R=S;V%P.F]P97)A=&EO
M;B==6R=A='1R)UU;)W-O87!!8W1I;VXG72`]("1A8W1I;VX["@H@("`@("`@
M("`@("`C($E.4%54"B`@("`@("`@("`@("1B:6YD:6YG6R=I;G!U="==6R=A
M='1R)UT@/2`G)SL*("`@("`@("`@("`@)&)I;F1I;F=;)VEN<'5T)UU;)W-O
M87`Z8F]D>2==6R=A='1R)UU;)W5S92==(#T@)V5N8V]D960G.PH@("`@("`@
M("`@("`D8FEN9&EN9ULG:6YP=70G75LG<V]A<#IB;V1Y)UU;)V%T='(G75LG
M;F%M97-P86-E)UT@/2`D;65T:&]D7VYA;65S<&%C93L*("`@("`@("`@("`@
M)&)I;F1I;F=;)VEN<'5T)UU;)W-O87`Z8F]D>2==6R=A='1R)UU;)V5N8V]D
M:6YG4W1Y;&4G72`](%-/05!?4T-(14U!7T5.0T]$24Y'.PH*("`@("`@("`@
M("`@(R!/5510550*("`@("`@("`@("`@)&)I;F1I;F=;)V]U='!U="==6R=A
M='1R)UT@/2`G)SL*("`@("`@("`@("`@)&)I;F1I;F=;)V]U='!U="==6R=S
M;V%P.F)O9'DG75LG871T<B==6R=U<V4G72`]("=E;F-O9&5D)SL*("`@("`@
M("`@("`@)&)I;F1I;F=;)V]U='!U="==6R=S;V%P.F)O9'DG75LG871T<B==
M6R=N86UE<W!A8V4G72`]("1M971H;V1?;F%M97-P86-E.PH@("`@("`@("`@
M("`D8FEN9&EN9ULG;W5T<'5T)UU;)W-O87`Z8F]D>2==6R=A='1R)UU;)V5N
M8V]D:6YG4W1Y;&4G72`](%-/05!?4T-(14U!7T5.0T]$24Y'.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!?9V5N97)A=&5?1$E30T]?6$U,*"1D
M:7-C;U]A<G)A>2D@>PH@("`@("`@("1D:7-C;R`]("<\/WAM;"!V97)S:6]N
M/2(Q+C`B/SXG.PH@("`@("`@(&9O<F5A8V@@*"1D:7-C;U]A<G)A>2!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&1I<V-O("X]("1T:&ES+3Y?
M87)R87E4;TYO9&4H)&ME>2PD=F%L*3L*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/F1I<V-O(#T@)&1I<V-O.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G96YE
M<F%T95]74T1,7UA-3"@D=W-D;%]A<G)A>2D@>PH@("`@("`@("1W<V1L(#T@
M)SP_>&UL('9E<G-I;VX](C$N,"(_/B<["B`@("`@("`@9F]R96%C:"`H)'=S
M9&Q?87)R87D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1W<V1L
M("X]("1T:&ES+3Y?87)R87E4;TYO9&4H)&ME>2PD=F%L*3L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/G=S9&P@/2`D=W-D;#L*("`@('T*"B`@("!F=6YC
M=&EO;B!?87)R87E4;TYO9&4H)&YO9&5?;F%M92`]("<G+"`D87)R87DI('L*
M("`@("`@("`D<F5T=7)N(#T@)R<["B`@("`@("`@:68@*&ES7V%R<F%Y*"1A
M<G)A>2DI('L*("`@("`@("`@("`@(R!W92!H879E(&$@;F]D92!I9B!T:&5R
M92=S(&ME>2`G871T<B<*("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES
M=',H)V%T='(G+"1A<G)A>2DI('L*("`@("`@("`@("`@("`@("1R971U<FX@
M+CT@(CPD;F]D95]N86UE(CL*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D87)R87E;)V%T='(G72DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D87)R87E;)V%T='(G72!A<R`D871T<E]N86UE(#T^("1A='1R7W9A
M;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FX@+CT@(B`D
M871T<E]N86UE/5PB)&%T=')?=F%L=65<(B(["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(",@=6YS
M970@)V%T='(G(&%N9"!P<F]C965D(&]T:&5R(&-H:6QD<RXN+@H@("`@("`@
M("`@("`@("`@=6YS970H)&%R<F%Y6R=A='1R)UTI.PH*("`@("`@("`@("`@
M("`@(&EF("AC;W5N="@D87)R87DI(#X@,"D@>PH@("`@("`@("`@("`@("`@
M("`@("1I(#T@,#L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D87)R
M87D@87,@)&-H:6QD7VYO9&5?;F%M92`]/B`D8VAI;&1?;F]D95]V86QU92D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N("X]("1I(#T](#`@
M/R`B/EQN(B`Z("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N
M("X]("1T:&ES+3Y?87)R87E4;TYO9&4H)&-H:6QD7VYO9&5?;F%M92PD8VAI
M;&1?;F]D95]V86QU92D["B`@("`@("`@("`@("`@("`@("`@("`@("1I*RL[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1R
M971U<FX@+CT@(CPO)&YO9&5?;F%M93Y<;B(["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R971U<FX@+CT@(B`O/EQN
M(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(",@=V4@:&%V92!N;R`G871T<B<@:V5Y(&EN(&%R<F%Y
M("T@<V\@:70G<R!L:7-T(&]F(&YO9&5S('=I=&@@=&AE('-A;64@;F%M92`N
M+BX*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D8VAI;&1?
M;F]D95]N86UE(#T^("1C:&EL9%]N;V1E7W9A;'5E*2!["B`@("`@("`@("`@
M("`@("`@("`@)')E='5R;B`N/2`D=&AI<RT^7V%R<F%Y5&].;V1E*"1N;V1E
M7VYA;64L)&-H:6QD7VYO9&5?=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@(R`D
M87)R87D@:7,@;F]T(&%N(&%R<F%Y"B`@("`@("`@("`@(&EF("@D87)R87D@
M(3TG)RD@>PH@("`@("`@("`@("`@("`@(R!A;F0@:71S(&YO="!E;7!T>0H@
M("`@("`@("`@("`@("`@)')E='5R;B`N/2`B/"1N;V1E7VYA;64^)&%R<F%Y
M/"\D;F]D95]N86UE/EQN(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(",@86YD(&ET<R!E;7!T>2XN+@H@("`@("`@("`@("`@("`@
M)')E='5R;B`N/2`B/"1N;V1E7VYA;64@+SY<;B(["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@("`@
M9G5N8W1I;VX@7V=E=%1Y<&5.<R@D='EP92D@>PH@("`@("`@('!R96=?;6%T
M8VA?86QL*"(G7'LH+BHI7'TG<VTB+"1T>7!E+"1M*3L*("`@("`@("!I9B`H
M:7-S970H)&U;,5U;,%TI("8F("1M6S%=6S!=("$]("<G*2!["B`@("`@("`@
M("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D;5LQ75LP72PD=&AI<RT^;F%M
M97-P86-E<RDI('L*("`@("`@("`@("`@("`@("1N<U]P<F5F(#T@)VYS)R`N
M(&-O=6YT*"1T:&ES+3YN86UE<W!A8V5S*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YN86UE<W!A8V5S6R1M6S%=6S!=72`]("1N<U]P<F5F.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=A='1R)UU;
M)WAM;&YS.B<@+B`D;G-?<')E9ET@/2`D;5LQ75LP73L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D='EP96YS(#T@)'1H:7,M/FYA;65S<&%C97-;)&U;
M,5U;,%U=.PH@("`@("`@("`@("`D='EP92`](&5R96=?<F5P;&%C92@D;5LP
M75LP72PG)RPD='EP92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1Y<&5N<R`]("=X<V0G.PH@("`@("`@('T*("`@("`@("!R971U<FX@87)R
M87DH)'1Y<&5N<RPD='EP92D["B`@("!]"@H@("`@9G5N8W1I;VX@7VEF0V]M
M<&QE>%1Y<&5%>&ES=',H)'1Y<&5S07)R87DL("1T>7!E7VYA;64I('L*("`@
M("`@("!I9B`H:7-?87)R87DH)'1Y<&5S07)R87DI*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T>7!E<T%R<F%Y(&%S("1I;F1E>"`]/B`D='EP95]D871A
M*2!["B`@("`@("`@("`@("`@("!I9B`H)'1Y<&5S07)R87E;)&EN9&5X75LG
M871T<B==6R=N86UE)UT@/3T@)'1Y<&5?;F%M92D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M?0H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U=31$PN<&AP````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(T,3(P-0`Q
M,#0Q-S,V,S`P-@`P,3<S-S``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R
M879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M
M;W)E("`@?`HO+R!\($%U=&AO<G,Z($1I971R:6-H($%Y86QA(#QD:65T<FEC
M:$!G86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<B`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@5U-$3"YP:'`L
M=B`Q+C4Q+C(N,2`R,#`S+S$R+S$X(#(Q.C$U.C$W(&%R;F%U9"!%>'`@)`HO
M+PIR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G.PIR97%U:7)E7V]N8V4@
M)U-/05`O1F%U;'0N<&AP)SL*<F5Q=6ER95]O;F-E("=(5%10+U)E<75E<W0N
M<&AP)SL*"F1E9FEN92@G5U-$3%]#04-(15]-05A?04=%)RP@-#,R,#`I.PID
M969I;F4H)U=31$Q?0T%#2$5?55-%)RP@("`@(#`I.R`O+R!S970@=&\@>F5R
M;R!T;R!T=7)N(&]F9B!C86-H:6YG"@HO*BH*("H@(%-/05!?5U-$3`H@*B`@
M=&AI<R!C;&%S<R!P87)S97,@=W-D;"!F:6QE<RP@86YD(&-A;B!B92!U<V5D
M(&)Y(%-/05`Z.D-L:65N="!T;R!P<F]P97)L>2!R96=I<W1E<@H@*B!S;V%P
M('9A;'5E<R!F;W(@<V5R=FEC97,*("H*("H@;W)I9VEN86QY(&)A<V5D(&]N
M(%-/05!X-"!B>2!$:65T<FEC:"!!>6%L82!H='1P.B\O9&EE=')I8V@N9V%N
M>#0N8V]M+W-O87!X-`H@*@H@*B!43T1/.@H@*B`@("!A9&0@=W-D;"!C86-H
M:6YG"B`J("`@<F5F86-T;W(@;F%M97-P86-E(&AA;F1L:6YG("@D;F%M97-P
M86-E+R1N<RD*("H@("`@:6UP;&5M96YT($E$3"!T>7!E('-Y;G1A>"!D96-L
M87)A=&EO;B!S;R!W92!C86X@9V5N97)A=&4@5U-$3`H@*@H@*B!`86-C97-S
M('!U8FQI8PH@*B!`=F5R<VEO;B`D260Z(%=31$PN<&AP+'8@,2XU,2XR+C$@
M,C`P,R\Q,B\Q."`R,3HQ-3HQ-R!A<FYA=60@17AP("0*("H@0'!A8VMA9V4@
M4T]!4#HZ0VQI96YT"B`J($!A=71H;W(@4VAA;F4@0V%R879E;R`\<VAA;F5`
M<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J($!A
M=71H;W(@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I
M9VEN86P@075T:&]R"B`J+PIC;&%S<R!33T%07U=31$P@97AT96YD<R!33T%0
M7T)A<V4*>PH@("`@=F%R("1T;G,@/2!N=6QL.PH@("`@=F%R("1D969I;FET
M:6]N(#T@87)R87DH*3L*("`@('9A<B`D;F%M97-P86-E<R`](&%R<F%Y*"D[
M"B`@("!V87(@)&YS(#T@87)R87DH*3L*("`@('9A<B`D>'-D(#T@4T]!4%]8
M34Q?4T-(14U!7U9%4E-)3TX["B`@("!V87(@)&-O;7!L97A4>7!E<R`](&%R
M<F%Y*"D["B`@("!V87(@)&5L96UE;G1S(#T@87)R87DH*3L*("`@('9A<B`D
M;65S<V%G97,@/2!A<G)A>2@I.PH@("`@=F%R("1P;W)T5'EP97,@/2!A<G)A
M>2@I.PH@("`@=F%R("1B:6YD:6YG<R`](&%R<F%Y*"D["B`@("!V87(@)&EM
M<&]R=',@/2!A<G)A>2@I.PH@("`@=F%R("1S97)V:6-E<R`](&%R<F%Y*"D[
M"B`@("!V87(@)'-E<G9I8V4@/2`G)SL*("`@('9A<B`D=7)I(#T@)R<["@H@
M("`@+RHJ"B`@("`@*B!0<F]X>2!P87)A;65T97)S"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)'!R;WAY(#T@;G5L;#L*"B`@
M("!V87(@)'1R86-E(#T@,#L*"B`@("`O*BH*("`@("`J(%5S92!74T1,(&-A
M8VAE"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D8V%C:&55<V4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V%C:&4@;6%X
M(&QI9F5T:6UE("AI;B!S96-O;F1S*0H@("`@("H*("`@("`J($!V87(@:6YT
M"B`@("`@*B\*("`@('9A<B`D8V%C:&5-87A!9V4@/2!N=6QL.PH*("`@("\J
M*@H@("`@*B!33T%07U=31$P@8V]N<W1R=6-T;W(*("`@("H*("`@("H@0'!A
M<F%M('-T<FEN9R`@96YD<&]I;G1?=7)I("A54DP@=&\@5U-$3"!F:6QE*0H@
M("`@*B!`<&%R86T@87)R87D@("!C;VYT86EN<R!O<'1I;VYS(&9O<B!(5%10
M7U)E<75E<W0@8VQA<W,@*'-E92!(5%10+U)E<75E<W0N<&AP*0H@("`@*B!`
M<&%R86T@8F]O;&5A;B!U<V4@5U-$3"!C86-H:6YG"B`@("`J($!P87)A;2!I
M;G0@("`@(&-A8VAE(&UA>"!L:69E=&EM92`H:6X@<V5C;VYD<RD*("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!33T%07U=31$PH
M)'=S9&Q?=7)I(#T@9F%L<V4L("1P<F]X>2`](&%R<F%Y*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@)&-A8VAE57-E("`@(#T@5U-$3%]#04-(15]54T4L
M"B`@("`@("`@("`@("`@("`@("`@("`@)&-A8VAE36%X06=E(#T@5U-$3%]#
M04-(15]-05A?04=%*2!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)U=3
M1$PG*3L*("`@("`@("`D=&AI<RT^=7)I("`@("`@("`@/2`D=W-D;%]U<FD[
M"B`@("`@("`@)'1H:7,M/G!R;WAY("`@("`@(#T@)'!R;WAY.PH@("`@("`@
M("1T:&ES+3YC86-H955S92`@("`]("1C86-H955S93L*("`@("`@("`D=&AI
M<RT^8V%C:&5-87A!9V4@/2`D8V%C:&5-87A!9V4["B`@("`@("`@:68@*"1W
M<V1L7W5R:2D@>PH@("`@("`@("`@("`D=&AI<RT^<&%R<V554DPH)'=S9&Q?
M=7)I*3L*("`@("`@("`@("`@<F5S970H)'1H:7,M/G-E<G9I8V5S*3L*("`@
M("`@("`@("`@)'1H:7,M/G-E<G9I8V4@/2!K97DH)'1H:7,M/G-E<G9I8V5S
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T7W-E<G9I8V4H
M)'-E<G9I8V4I('L*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D<V5R
M=FEC92P@)'1H:7,M/G-E<G9I8V5S*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5R=FEC92`]("1S97)V:6-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($!D97!R96-A=&5D('5S92!P87)S95523"!I;G-T96%D"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!A<G-E*"1W<V1L7W5R:2P@)'!R;WAY(#T@87)R
M87DH*2D@>PH@("`@("`@("1T:&ES+3YP87)S95523"@D=W-D;%]U<FDL("1P
M<F]X>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6QL('1H92!74T1,(&%R
M<F%Y('1R964@=VET:"!D871A(&9R;VT@82!74T1,(&9I;&4*("`@("`J"B`@
M("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0'!A<F%M("!A<G)A>2`@<')O
M>&D@<F5L871E9"!P87)A;65T97)S"B`@("`@*B!`<F5T=7)N('9O:60*("`@
M("`J+PH@("`@9G5N8W1I;VX@<&%R<V554DPH)'=S9&Q?=7)I+"`D<')O>'D@
M/2!A<G)A>2@I*2!["B`@("`@("`@)'!A<G-E<B`])B!N97<@4T]!4%]74T1,
M7U!A<G-E<B@D=W-D;%]U<FDL("1T:&ES*3L*"B`@("`@("`@:68@*"1P87)S
M97(M/F9A=6QT*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H)'!A<G-E<BT^9F%U;'0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($9I;&P@=&AE(%=31$P@87)R87D@=')E92!W:71H(&1A=&$@9G)O
M;2!O;F4@;W(@;6]R92!02%`@8VQA<W,@;V)J96-T<PH@("`@("H*("`@("`J
M($!P87)A;2`@;6EX960@("1W<V1L7V]B:B!!;B!O8FIE8W0@;W(@87)R87D@
M;V8@;V)J96-T<R!T;R!A9&0@=&\@=&AE(&EN=&5R;F%L(%=31$P@=')E90H@
M("`@("H@0'!A<F%M("!S=')I;F<@("1S97)V:6-E7VYA;64@3F%M92!O9B!T
M:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!P87)A;2`@<W1R:6YG("`D<V5R
M=FEC95]D97-C($]P=&EO;F%L(&1E<V-R:7!T:6]N(&]F('1H92!74T1,(#QS
M97)V:6-E/@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T
M:6]N('!A<G-E3V)J96-T*"8D=W-D;%]O8FHL("1T87)G971.86UE<W!A8V4L
M("1S97)V:6-E7VYA;64L("1S97)V:6-E7V1E<V,@/2`G)RD*("`@('L*("`@
M("`@("`D<&%R<V5R(#TF(&YE=R!33T%07U=31$Q?3V)J96-T4&%R<V5R*"1W
M<V1L7V]B:BP@)'1H:7,L("1T87)G971.86UE<W!A8V4L("1S97)V:6-E7VYA
M;64L("1S97)V:6-E7V1E<V,I.PH*("`@("`@("`@:68@*"1P87)S97(M/F9A
M=6QT*2!["B`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1P
M87)S97(M/F9A=6QT*3L*("`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=$5N9'!O:6YT*"1P;W)T3F%M92D*("`@('L*("`@("`@("!R971U<FX@
M*&ES<V5T*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S
M)UU;)'!O<G1.86UE75LG861D<F5S<R==6R=L;V-A=&EO;B==*2D*("`@("`@
M("`@("`@("`@(#\@)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG
M<&]R=',G75LD<&]R=$YA;65=6R=A9&1R97-S)UU;)VQO8V%T:6]N)UT*("`@
M("`@("`@("`@("`@(#H@)'1H:7,M/E]R86ES95-O87!&875L="@B;F\@96YD
M<&]I;G0@9F]R('!O<G0@9F]R("1P;W)T3F%M92(L("1T:&ES+3YU<FDI.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]G9710;W)T3F%M92@D;W!E<F%T:6]N+"1S
M97)V:6-E*2!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YS97)V:6-E<ULD
M<V5R=FEC95U;)W!O<G1S)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YS97)V:6-E<ULD<V5R=FEC95U;)W!O<G1S)UT@87,@)'!O<G0@/3X@
M)'!O<G1!='1R<RD@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D=&AI<RT^
M<V5R=FEC97-;)'-E<G9I8V5=6R=P;W)T<R==6R1P;W)T75LG='EP92==.PH@
M("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=S;V%P)R`F)@H@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YB:6YD:6YG<ULD<&]R=$%T=')S
M6R=B:6YD:6YG)UU=6R=O<&5R871I;VYS)UU;)&]P97)A=&EO;ETI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<&]R=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@;G5L;#L*("`@('T*"B`@("`O+R!F:6YD('1H92!N86UE(&]F('1H92!F
M:7)S="!P;W)T('1H870@8V]N=&%I;G,@86X@;W!E<F%T:6]N(&]F(&YA;64@
M)&]P97)A=&EO;@H@("`@+R\@86QW87ES(')E='5R;G,@82!T:&4@<V]A<"!P
M;W)T3F%M90H@("`@9G5N8W1I;VX@9V5T4&]R=$YA;64H)&]P97)A=&EO;BP@
M)'-E<G9I8V4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A)'-E<G9I8V4I
M("1S97)V:6-E(#T@)'1H:7,M/G-E<G9I8V4["B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YS97)V:6-E<ULD<V5R=FEC95U;)W!O<G1S)UTI*2!["B`@("`@
M("`@("`@("1P;W)T3F%M92`]("1T:&ES+3Y?9V5T4&]R=$YA;64H)&]P97)A
M=&EO;BPD<V5R=FEC92D["B`@("`@("`@("`@(&EF("@D<&]R=$YA;64I(')E
M='5R;B`D<&]R=$YA;64["B`@("`@("`@?0H@("`@("`@("\O('1R>2!A;GD@
M<V5R=FEC92!I;B!T:&4@=W-D;`H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YS
M97)V:6-E<R!A<R`D<V5R=FEC94YA;64]/B1S97)V:6-E*2!["B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^<V5R=FEC97-;)'-E<G9I8V5.86UE75LG
M<&]R=',G72DI('L*("`@("`@("`@("`@("`@("1P;W)T3F%M92`]("1T:&ES
M+3Y?9V5T4&]R=$YA;64H)&]P97)A=&EO;BPD<V5R=FEC94YA;64I.PH@("`@
M("`@("`@("`@("`@:68@*"1P;W)T3F%M92D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS97)V:6-E(#T@)'-E<G9I8V5.86UE.PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D<&]R=$YA;64["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<F%I<V53;V%P1F%U;'0H(FYO(&]P97)A=&EO;B`D;W!E<F%T:6]N(&EN
M('=S9&PB+"`D=&AI<RT^=7)I*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971/
M<&5R871I;VY$871A*"1P;W)T3F%M92PD;W!E<F%T:6]N*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=
M6R=P;W)T<R==6R1P;W)T3F%M95U;)V)I;F1I;F<G72D*("`@("`@("`@("`@
M)B8@)&)I;F1I;F<@/2`D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=
M6R=P;W)T<R==6R1P;W)T3F%M95U;)V)I;F1I;F<G72D@>PH@("`@("`@("`@
M("`O+R!G970@;W!E<F%T:6]N(&1A=&$@9G)O;2!B:6YD:6YG"B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^8FEN9&EN9W-;)&)I;F1I;F==6R=O
M<&5R871I;VYS)UU;)&]P97)A=&EO;ETI*2!["B`@("`@("`@("`@("`@("`D
M;W!$871A(#T@)'1H:7,M/F)I;F1I;F=S6R1B:6YD:6YG75LG;W!E<F%T:6]N
M<R==6R1O<&5R871I;VY=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O
M(&=E="!O<&5R871I;VX@9&%T82!F<F]M('!O<G1T>7!E"B`@("`@("`@("`@
M("1P;W)T5'EP92`]("1T:&ES+3YB:6YD:6YG<ULD8FEN9&EN9UU;)W1Y<&4G
M73L*("`@("`@("`@("`@:68@*"$D<&]R=%1Y<&4I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")N;R!P;W)T('1Y
M<&4@9F]R(&)I;F1I;F<@)&)I;F1I;F<@:6X@=W-D;"`B("X@)'1H:7,M/G5R
M:2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3YP;W)T5'EP97-;)'!O<G14>7!E75LD;W!E<F%T:6]N72DI('L*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<&]R=%1Y<&5S6R1P;W)T
M5'EP95U;)&]P97)A=&EO;EU;)W!A<F%M971E<D]R9&5R)UTI*0H@("`@("`@
M("`@("`@("`@("`@("1O<$1A=&%;)W!A<F%M971E<D]R9&5R)UT@/2`D=&AI
M<RT^<&]R=%1Y<&5S6R1P;W)T5'EP95U;)&]P97)A=&EO;EU;)W!A<F%M971E
M<D]R9&5R)UT["B`@("`@("`@("`@("`@("`D;W!$871A6R=I;G!U="==(#T@
M87)R87E?;65R9V4H)&]P1&%T85LG:6YP=70G72P@)'1H:7,M/G!O<G14>7!E
M<ULD<&]R=%1Y<&5=6R1O<&5R871I;VY=6R=I;G!U="==*3L*("`@("`@("`@
M("`@("`@("1O<$1A=&%;)V]U='!U="==(#T@87)R87E?;65R9V4H)&]P1&%T
M85LG;W5T<'5T)UTL("1T:&ES+3YP;W)T5'EP97-;)'!O<G14>7!E75LD;W!E
M<F%T:6]N75LG;W5T<'5T)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A)&]P1&%T82D*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*")N;R!O<&5R871I;VX@)&]P97)A=&EO;B!F;W(@
M<&]R="`D<&]R=$YA;64L(&EN('=S9&PB+"`D=&AI<RT^=7)I*3L*("`@("`@
M("`@("`@)&]P1&%T85LG<&%R86UE=&5R<R==(#T@9F%L<V4["B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^8FEN9&EN9W-;)'1H:7,M/G-E<G9I8V5S
M6R1T:&ES+3YS97)V:6-E75LG<&]R=',G75LD<&]R=$YA;65=6R=B:6YD:6YG
M)UU=6R=O<&5R871I;VYS)UU;)&]P97)A=&EO;EU;)VEN<'5T)UU;)VYA;65S
M<&%C92==*2D*("`@("`@("`@("`@("`@("1O<$1A=&%;)VYA;65S<&%C92==
M(#T@)'1H:7,M/F)I;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R
M=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T
M:6]N<R==6R1O<&5R871I;VY=6R=I;G!U="==6R=N86UE<W!A8V4G73L*("`@
M("`@("`@("`@+R\@;65S<V%G92!D871A(&9R;VT@;65S<V%G97,*("`@("`@
M("`@("`@)&EN<'5T37-G(#T@)&]P1&%T85LG:6YP=70G75LG;65S<V%G92==
M.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/FUE<W-A9V5S6R1I
M;G!U=$US9UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YM97-S
M86=E<ULD:6YP=71-<V==(&%S("1P;F%M92`]/B`D<&%T=')S*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&]P1&%T85LG<W1Y;&4G72`]/2`G9&]C=6UE;G0G
M("8F("1O<$1A=&%;)VEN<'5T)UU;)W5S92==(#T]("=L:71E<F%L)PH@("`@
M("`@("`@("`@("`@("`@("8F("1P;F%M92`]/2`G<&%R86UE=&5R<R<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG<&%R86UE=&5R<R==
M(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG;F%M
M97-P86-E)UT@/2`D=&AI<RT^;F%M97-P86-E<ULD<&%T=')S6R=N86UE<W!A
M8V4G75T["B`@("`@("`@("`@("`@("`@("`@("`@("1E;"`]("1T:&ES+3YE
M;&5M96YT<ULD<&%T=')S6R=N86UE<W!A8V4G75U;)'!A='1R<ULG='EP92==
M73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;%LG96QE
M;65N=',G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1E;%LG96QE;65N=',G72!A<R`D96QN86UE(#T^("1E;&%T=')S*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG:6YP
M=70G75LG<&%R=',G75LD96QN86UE72`]("1E;&%T=')S.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1O<$1A=&%;)VEN<'5T)UU;)W!A<G1S)UU;)'!N86UE72`]("1P871T<G,[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D;W5T<'5T37-G(#T@)&]P1&%T85LG;W5T<'5T)UU;
M)VUE<W-A9V4G73L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YM
M97-S86=E<ULD;W5T<'5T37-G72DI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/FUE<W-A9V5S6R1O=71P=71-<V==(&%S("1P;F%M92`]/B`D<&%T
M=')S*2!["B`@("`@("`@("`@("`@("!I9B`H)&]P1&%T85LG<W1Y;&4G72`]
M/2`G9&]C=6UE;G0G("8F("1O<$1A=&%;)V]U='!U="==6R=U<V4G72`]/2`G
M;&ET97)A;"<*("`@("`@("`@("`@("`@("`@("`F)B`D<&YA;64@/3T@)W!A
M<F%M971E<G,G*2!["@H@("`@("`@("`@("`@("`@("`@("`@("`D96P@/2`D
M=&AI<RT^96QE;65N='-;)'!A='1R<ULG;F%M97-P86-E)UU=6R1P871T<G-;
M)W1Y<&4G75T["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M96Q;)V5L96UE;G1S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D96Q;)V5L96UE;G1S)UT@87,@)&5L;F%M92`]/B`D96QA
M='1R<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<$1A
M=&%;)V]U='!U="==6R=P87)T<R==6R1E;&YA;65=(#T@)&5L871T<G,["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1O<$1A=&%;)V]U='!U="==6R=P87)T<R==6R1P;F%M95T@
M/2`D<&%T=')S.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1O<$1A=&$["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")N
M;R!B:6YD:6YG(&9O<B!P;W)T("1P;W)T3F%M92!I;B!W<V1L(BP@)'1H:7,M
M/G5R:2D["B`@("!]"@H@("`@9G5N8W1I;VX@;6%T8VA-971H;V0H)B1O<&5R
M871I;VXI('L*("`@("`@("`O+R!/=F5R;&]A9&EN9R!L;W=E<F-A<V5S(&9U
M;F-T:6]N(&YA;65S(#HH"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G-E<G9I
M8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G72!A<R`D<&]R="`]/B`D<&]R
M=$%T=')S*2!["B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H
M:7,M/F)I;F1I;F=S6R1P;W)T071T<G-;)V)I;F1I;F<G75U;)V]P97)A=&EO
M;G,G72D@87,@)&]P*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R8V%S96-M
M<"@D;W`L("1O<&5R871I;VXI(#T](#`I('L*("`@("`@("`@("`@("`@("`@
M("`D;W!E<F%T:6]N(#T@)&]P.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@9V5T1&%T
M84AA;F1L97(*("`@("`J"B`@("`@*B!':79E;B!A(&1A=&%T>7!E+"!W:&%T
M(&9U;F-T:6]N(&AA;F1L97,@=&AE('!R;V-E<W-I;F<_"B`@("`@*B!T:&ES
M(&ES('5S960@9F]R(&1O8R]L:71E<F%L(')E<75E<W1S('=H97)E('=E(')E
M8V5I=F4*("`@("`J(&$@9&%T871Y<&4L(&%N9"!W92!N965D('1O('!A<W,@
M:70@=&\@82!M971H;V0@:6X@;W5T"B`@("`@*B!S97)V97(@8VQA<W,*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(&1A=&%T>7!E"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&YA;65S<&%C90H@("`@("H@0')E='5R;G,@<W1R:6YG(&UE
M=&AO9&YA;64*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$1A=&%(86YD;&5R*"1D871A='EP92P@)&YA;65S<&%C92D@
M>PH@("`@("`@("\O('-E92!I9B!W92!H879E(&%N(&5L96UE;G0@8GD@=&AI
M<R!N86UE"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YN86UE<W!A8V5S6R1N
M86UE<W!A8V5=*2D*("`@("`@("`@("`@)&YA;65S<&%C92`]("1T:&ES+3YN
M86UE<W!A8V5S6R1N86UE<W!A8V5=.PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^;G-;)&YA;65S<&%C95TI*2!["B`@("`@("`@("`@("1N<W`@/2`D=&AI
M<RT^;G-;)&YA;65S<&%C95T["B`@("`@("`@("`@("-I9B`H(6ES<V5T*"1T
M:&ES+3YE;&5M96YT<ULD;G-P72DI"B`@("`@("`@("`@(",@("`@)&YS<"`]
M("1T:&ES+3YN86UE<W!A8V5S6R1N<W!=.PH@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/F5L96UE;G1S6R1N<W!=6R1D871A='EP95TI*2!["B`@("`@
M("`@("`@("`@("`D8VAE8VMM97-S86=E<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("`O+R!F:6YD('=H870@;65S<V%G97,@=7-E('1H:7,@9&%T871Y
M<&4*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YM97-S86=E<R!A
M<R`D;65S<V%G96YA;64]/B1M97-S86=E*2!["B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&UE<W-A9V4@87,@)'!A<G1N86UE/3XD<&%R="D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<G1;)W1Y<&4G73T])&1A
M=&%T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VAE8VMM
M97-S86=E<UM=(#T@)&UE<W-A9V5N86UE.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`O+R!F:6YD('1H92!O<&5R871I;VX@=&AA="!U<V5S('1H:7,@
M;65S<V%G90H@("`@("`@("`@("`@("`@)&1A=&%(86YD;&5R(#T@3E5,3#L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@H)'1H:7,M/G!O<G14>7!E<R!A<R`D
M<&]R=&YA;64]/B1P;W)T='EP92D@>PH@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1P;W)T='EP92!A<R`D;W!N86UE/3XD;W!I;F9O*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C:&5C:VUE<W-A9V5S(&%S
M("1M97-S86=E;F%M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1O<&EN9F];)VEN<'5T)UU;)VUE<W-A9V4G72`]/2`D;65S<V%G96YA
M;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&]P;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B!G9713;V%P06-T
M:6]N*"1P;W)T3F%M92P@)&]P97)A=&EO;BD*("`@('L*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/F)I;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^
M<V5R=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E
M<F%T:6]N<R==6R1O<&5R871I;VY=6R=S;V%P06-T:6]N)UTI("8F"B`@("`@
M("`@("`@("1S;V%P06-T:6]N(#T@)'1H:7,M/F)I;F1I;F=S6R1T:&ES+3YS
M97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE75LG
M8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R871I;VY=6R=S;V%P06-T
M:6]N)UTI('L*("`@("`@("`@("`@<F5T=7)N("1S;V%P06-T:6]N.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T3F%M97-P86-E*"1P;W)T3F%M92P@)&]P97)A=&EO;BD*("`@('L*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F)I;F1I;F=S6R1T:&ES+3YS97)V
M:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE75LG8FEN
M9&EN9R==72D@)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M/F)I;F1I;F=S
M6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;)'!O
M<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R871I;VY=
M6R=I;G!U="==6R=N86UE<W!A8V4G72D@)B8*("`@("`@("`@("`@)&YA;65S
M<&%C92`]("1T:&ES+3YB:6YD:6YG<ULD=&AI<RT^<V5R=FEC97-;)'1H:7,M
M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T3F%M95U;)V)I;F1I;F<G75U;)V]P
M97)A=&EO;G,G75LD;W!E<F%T:6]N75LG:6YP=70G75LG;F%M97-P86-E)UTI
M('L*("`@("`@("`@("`@<F5T=7)N("1N86UE<W!A8V4["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971.
M86UE<W!A8V5!='1R:6)U=&5.86UE*"1N86UE<W!A8V4I('L*("`@("`@("`O
M*B!I9B!I="!D;V5S;B=T(&5X:7-T(&%T(&9I<G-T+"!F;&EP('1H92!A<G)A
M>2!A;F0@8VAE8VL@86=A:6X@*B\*("`@("`@("!I9B`H(6%R<F%Y7VME>5]E
M>&ES=',H)&YA;65S<&%C92P@)'1H:7,M/FYS*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^;G,@/2!A<G)A>5]F;&EP*"1T:&ES+3YN86UE<W!A8V5S*3L*("`@
M("`@("!]"B`@("`@("`@+RH@:68@:70@9&]E<VXG="!E>&ES="!N;W<L(&%D
M9"!I="`J+PH@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D;F%M97-P
M86-E+"`D=&AI<RT^;G,I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M861D3F%M97-P86-E*"1N86UE<W!A8V4I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'1H:7,M/FYS6R1N86UE<W!A8V5=.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&%D9$YA;65S<&%C92@D;F%M97-P86-E*2!["B`@("`@("`@:68@*&%R
M<F%Y7VME>5]E>&ES=',H)&YA;65S<&%C92P@)'1H:7,M/FYS*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FYS6R1N86UE<W!A8V5=.PH@("`@("`@
M('T*("`@("`@("`D;B`](&-O=6YT*"1T:&ES+3YN<RD["B`@("`@("`@)&%T
M='(@/2`G;G,G+B1N.PH@("`@("`@("1T:&ES+3YN86UE<W!A8V5S6R=N<R<N
M)&Y=(#T@)&YA;65S<&%C93L*("`@("`@("`D=&AI<RT^;G-;)&YA;65S<&%C
M95T@/2`D871T<CL*("`@("`@("!R971U<FX@)&%T='(["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W9A;&ED871E4W1R:6YG*"1S=')I;F<I('L*("`@("`@("`O
M+R!86%@@=&AI<R!S:&]U;&0@8F4@9&]N92!S;V]N97(@;W(@;&%T97(*("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("`C:68@*'!R96=?;6%T8V@H(B]>
M6UQW7SHC7"]=*R0O(BPD<W1R:6YG*2D@<F5T=7)N('1R=64["B`@("`@("`@
M(W)E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!?861D07)G*"8D
M87)G<RP@)B1A<F=A<G)A>2P@)&%R9VYA;64I"B`@("!["B`@("`@("`@:68@
M*"1A<F=S*2`D87)G<R`N/2`B+"`B.PH@("`@("`@("1A<F=S("X](")<)"(N
M)&%R9VYA;64["B`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E4W1R:6YG
M*"1A<F=N86UE*2D@<F5T=7)N($Y53$P["B`@("`@("`@:68@*"1A<F=A<G)A
M>2D@)&%R9V%R<F%Y("X]("(L("(["B`@("`@("`@)&%R9V%R<F%Y("X](")<
M(B1A<F=N86UE7"(]/EPD(BXD87)G;F%M93L*("`@('T*"B`@("!F=6YC=&EO
M;B!?96QE;65N=$%R9R@F)&%R9W,L("8D87)G87)R87DL("8D7V%R9W1Y<&4L
M("1?87)G;F%M92D*("`@('L*("`@("`@("`D8V]M;65N=',@/2`G)SL*("`@
M("`@("`D96P@/2`D=&AI<RT^96QE;65N='-;)%]A<F=T>7!E6R=N86UE<W!A
M8V4G75U;)%]A<F=T>7!E6R=T>7!E)UU=.PH@("`@("`@("1T;G,@/2!I<W-E
M="@D=&AI<RT^;G-;)&5L6R=N86UE<W!A8V4G75TI/R1T:&ES+3YN<ULD96Q;
M)VYA;65S<&%C92==73HD7V%R9W1Y<&5;)VYA;65S<&%C92==.PH@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1T;G-=6R1E;%LG='EP
M92==72DI('L*("`@("`@("`@("`@+R\@=&AE(&5L96UE;G0@:7,@86-T=6%L
M;'D@82!C;VUP;&5X('1Y<&4A"B`@("`@("`@("`@("1C;VUM96YT<R`]("(@
M("`@("`@("\O('LD96Q;)W1Y<&4G77T@:7,@82!#;VUP;&5X5'EP92P@<F5F
M97(@=&\@=W-D;"!F;W(@;6]R92!I;F9O7&XB.PH@("`@("`@("`@("`D871T
M<FYA;64@/2`B>R1?87)G='EP95LG='EP92==?5]A='1R(CL*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YC;VUP;&5X5'EP97-;)'1N<UU;)&5L6R=T
M>7!E)UU=6R=A='1R:6)U=&4G72DI('L*("`@("`@("`@("`@("`@("1C;VUM
M96YT<R`N/2`B("`@("`@("`O+R![)&5L6R=T>7!E)UU](&UA>2!R97%U:7)E
M(&%T=')I8G5T97,L(')E9F5R('1O('=S9&P@9F]R(&UO<F4@:6YF;UQN(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D8V]M;65N=',@+CT@(B`@("`@
M("`@7"1[)&%T=')N86UE?5LG>&UL;G,G72`]("=[)'1H:7,M/FYA;65S<&%C
M97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75U])SM<;B(["B`@("`@("`@("`@
M("1C;VUM96YT<R`N/2`B("`@("`@("!<)'LD7V%R9W1Y<&5;)W1Y<&4G77T@
M/28@;F5W(%-/05!?5F%L=64H)WLD7V%R9W1Y<&5;)W1Y<&4G77TG+&9A;'-E
M+%PD>R1?87)G='EP95LG='EP92==?2Q<)"1A='1R;F%M92D[7&XB.PH@("`@
M("`@("`@("`D=&AI<RT^7V%D9$%R9R@D87)G<RPD87)G87)R87DL)%]A<F=T
M>7!E6R=T>7!E)UTI.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O
M;7!L97A4>7!E<ULD=&YS75LD96Q;)W1Y<&4G75U;)V%T=')I8G5T92==*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"1A<F=S*2`D87)G<R`N/2`B+"`B.PH@
M("`@("`@("`@("`@("`@)&%R9W,@+CT@(EPD(BXD871T<FYA;64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@(R1C;VUM96YT<R`]("1T:&ES+3Y?8V]M
M<&QE>%1Y<&5!<F<H)&%R9W,L)&%R9V%R<F%Y+"1E;"PD7V%R9W1Y<&5;)W1Y
M<&4G72D["B`@("`@("`@?2!E;'-E(&EF("AI<W-E="@D96Q;)V5L96UE;G1S
M)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1E;%LG96QE;65N=',G72!A
M<R`D96YA;64@/3X@)&5L96UE;G0I('L*("`@("`@("`@("`@("`@("1C;VUM
M96YT<R`N/2`B("`@("`@("!<)"1E;F%M92`])B!N97<@4T]!4%]686QU92@G
M>WLD=&AI<RT^;F%M97-P86-E<ULD96QE;65N=%LG;F%M97-P86-E)UU=?7TD
M96YA;64G+"=[)&5L96UE;G1;)W1Y<&4G77TG+%PD)&5N86UE*3M<;B(["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%D9$%R9R@D87)G<RPD87)G87)R87DL
M)&5N86UE*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(",D96-H;U-T<FEN9U!A<F%M(#TF(&YE=R!33T%07U9A;'5E*"=[
M:'1T<#HO+W-O87!I;G1E<F]P+F]R9R]X<V1]96-H;U-T<FEN9U!A<F%M)RQF
M86QS92PD96-H;U-T<FEN9U!A<F%M*3L*("`@("`@("`@("`@)&-O;6UE;G1S
M("X]("(@("`@("`@(%PD)%]A<F=N86UE(#TF(&YE=R!33T%07U9A;'5E*"=[
M>R1T:&ES+3YN86UE<W!A8V5S6R1T;G-=?7TD7V%R9VYA;64G+"=[)&5L6R=T
M>7!E)UU])RQ<)"1?87)G;F%M92D[7&XB.PH@("`@("`@("`@("`D=&AI<RT^
M7V%D9$%R9R@D87)G<RPD87)G87)R87DL)%]A<F=N86UE*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1C;VUM96YT<SL*("`@('T*"B`@("!F=6YC=&EO
M;B!?8V]M<&QE>%1Y<&5!<F<H)B1A<F=S+"`F)&%R9V%R<F%Y+"`F)%]A<F=T
M>7!E+"`D7V%R9VYA;64I"B`@("!["B`@("`@("`@)&-O;6UE;G1S(#T@)R<[
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VUP;&5X5'EP97-;)%]A<F=T
M>7!E6R=N86UE<W!A8V4G75U;)%]A<F=T>7!E6R=T>7!E)UU=*2D@>PH@("`@
M("`@("`@("`D8V]M;65N=',@(#T@(B`@("`@("`@+R\@)%]A<F=N86UE(&ES
M(&$@0V]M<&QE>%1Y<&4@>R1?87)G='EP95LG='EP92==?2Q<;B(["B`@("`@
M("`@("`@("1C;VUM96YT<R`N/2`B("`@("`@("`O+W)E9F5R('1O('=S9&P@
M9F]R(&UO<F4@:6YF;UQN(CL*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VUP;&5X5'EP97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75U;)%]A<F=T
M>7!E6R=T>7!E)UU=6R=A='1R:6)U=&4G72DI('L*("`@("`@("`@("`@("`@
M("1C;VUM96YT<R`N/2`B("`@("`@("`O+R`D7V%R9VYA;64@;6%Y(')E<75I
M<F4@871T<FEB=71E<RP@<F5F97(@=&\@=W-D;"!F;W(@;6]R92!I;F9O7&XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1W<F%P;F%M92`]("=[)RXD
M=&AI<RT^;F%M97-P86-E<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==72XG?2<N
M)%]A<F=T>7!E6R=T>7!E)UT["B`@("`@("`@("`@("1C;VUM96YT<R`N/2`B
M("`@("`@("!<)"1?87)G;F%M92`])B!N97<@4T]!4%]686QU92@G)%]A<F=N
M86UE)RPG)'=R87!N86UE)RQ<)"1?87)G;F%M92D[7&XB.PH*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]A9&1!<F<H)&%R9W,L)&%R9V%R<F%Y+"1?87)G
M;F%M92D["B`@("`@("`@<F5T=7)N("1C;VUM96YT<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(&=E;F5R871E4')O>'E#;V1E"B`@("`@*B!G96YE<F%T97,@
M<W1U8B!C;V1E(&9R;VT@=&AE('=S9&P@=&AA="!C86X@8F4@<V%V960@=&\@
M82!F:6QE+"!O<B!E=F%L)V0@:6YT;R!E>&ES=&5N8V4*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5N97)A=&50<F]X>4-O9&4H)'!O<G0@/2`G)RP@)&-L87-S
M;F%M93TG)RD*("`@('L*("`@("`@("`D;75L=&EP;W)T(#T@8V]U;G0H)'1H
M:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G72D@/B`Q.PH@
M("`@("`@(&EF("@A)'!O<G0I('L*("`@("`@("`@("`@<F5S970H)'1H:7,M
M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G72D["B`@("`@("`@
M("`@("1P;W)T(#T@8W5R<F5N="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E
M<G9I8V5=6R=P;W)T<R==*3L*("`@("`@("!]"B`@("`@("`@+R\@6%A8(&-U
M<G)E;G1L>2!D;R!N;W0@<W5P<&]R="!(5%10('!O<G1S"B`@("`@("`@:68@
M*"1P;W)T6R=T>7!E)UT@(3T@)W-O87`G*2!R971U<FX@3E5,3#L*"B`@("`@
M("`@+R\@6%A8(&-U<G)E;G10;W)T(&ES($)!1`H@("`@("`@("1C;&EE;G1U
M<FP@/2`D<&]R=%LG861D<F5S<R==6R=L;V-A=&EO;B==.PH@("`@("`@(&EF
M("@A)&-L87-S;F%M92D@>PH@("`@("`@("`@("!I9B`H)&UU;'1I<&]R="!\
M?"`D<&]R="D@>PH@("`@("`@("`@("`@("`@)&-L87-S;F%M92`]("=796)3
M97)V:6-E7R<N)'1H:7,M/G-E<G9I8V4N)U\G+B1P;W)T6R=N86UE)UT["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8VQA<W-N86UE
M(#T@)U=E8E-E<G9I8V5?)RXD=&AI<RT^<V5R=FEC93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D8VQA<W-N86UE(#T@<W1R7W)E<&QA8V4H)RXG+"=?
M)RPD8VQA<W-N86UE*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M
M/E]V86QI9&%T95-T<FEN9R@D8VQA<W-N86UE*2D@<F5T=7)N($Y53$P["@H@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^<')O>'DI("8F(&-O=6YT*"1T
M:&ES+3YP<F]X>2D@/B`P*2!["B`@("`@("`@("`@("1C;&%S<R`](")C;&%S
M<R`D8VQA<W-N86UE(&5X=&5N9',@4T]!4%]#;&EE;G1<;GM<;B(N"B`@("`@
M("`@("`@("(@("`@9G5N8W1I;VX@)&-L87-S;F%M92@I7&Y[7&XB+@H@("`@
M("`@("`@("`B("`@("`@("!<)'1H:7,M/E-/05!?0VQI96YT*%PB)&-L:65N
M='5R;%PB+"`P+"`P+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"(["@H@
M("`@("`@("`@("!F;W)E86-H*"1T:&ES+3YP<F]X>2!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1C;&%S<R`N/2`B7"(D:V5Y7"(@/3X@87)R
M87DH(CL*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L(&%S("1K
M97DR(#T^("1V86PR*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;&%S
M<R`N/2`B7"(D:V5Y,EPB(#T^(%PB)'9A;#)<(BPB.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@+CT@)RDG.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M8VQA<W,@+CT@(EPB)&ME>5PB/3Y<(B1V86Q<(BPB.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1C;&%S<R`N/2`B*2D[
M7&X@?5QN(CL*("`@("`@("`@("`@)&-L87-S(#T@<W1R7W)E<&QA8V4H)RPI
M*2<L("<I*2<L("1C;&%S<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&-L87-S(#T@(F-L87-S("1C;&%S<VYA;64@97AT96YD<R!33T%07T-L
M:65N=%QN>UQN(BX*("`@("`@("`@("`@(B`@("!F=6YC=&EO;B`D8VQA<W-N
M86UE*"E<;GM<;B(N"B`@("`@("`@("`@("(@("`@("`@(%PD=&AI<RT^4T]!
M4%]#;&EE;G0H7"(D8VQI96YT=7)L7"(L(#`I.UQN(BX*("`@("`@("`@("`@
M(B`@("!]7&XB.PH@("`@("`@('T*"B`@("`@("`@+R\@9V5T('1H92!B:6YD
M:6YG+"!F<F]M('1H870@9V5T('1H92!P;W)T('1Y<&4*("`@("`@("`D<')I
M;6%R>4)I;F1I;F<@/2`D<&]R=%LG8FEN9&EN9R==.R`O+R1T:&ES+3YS97)V
M:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;)'!O<G1;)VYA;64G75U;
M(F)I;F1I;F<B73L*("`@("`@("`D<')I;6%R>4)I;F1I;F<@/2!P<F5G7W)E
M<&QA8V4H(B]>*"XJ.BDO(BPB(BPD<')I;6%R>4)I;F1I;F<I.PH@("`@("`@
M("1P;W)T5'EP92`]("1T:&ES+3YB:6YD:6YG<ULD<')I;6%R>4)I;F1I;F==
M6R=T>7!E)UT["B`@("`@("`@)'!O<G14>7!E(#T@<')E9U]R97!L86-E*"(O
M7B@N*CHI+R(L(B(L)'!O<G14>7!E*3L*("`@("`@("`D<W1Y;&4@/2`D=&AI
M<RT^8FEN9&EN9W-;)'!R:6UA<GE":6YD:6YG75LG<W1Y;&4G73L*"B`@("`@
M("`@+R\@6%A8(&-U<G)E;G10;W)T5'EP92!I<R!"040*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^<&]R=%1Y<&5S6R1P;W)T5'EP95T@87,@)&]P;F%M92`]
M/B`D;W!E<F%T:6]N*2!["B`@("`@("`@("`@("1S;V%P86-T:6]N(#T@)'1H
M:7,M/F)I;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD
M;W!N86UE75LG<V]A<$%C=&EO;B==.PH@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F)I;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G
M75LD;W!N86UE75LG<W1Y;&4G72DI('L*("`@("`@("`@("`@("`@("1O<'-T
M>6QE(#T@)'1H:7,M/F)I;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A
M=&EO;G,G75LD;W!N86UE75LG<W1Y;&4G73L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1O<'-T>6QE(#T@)'-T>6QE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1U<V4@/2`D=&AI<RT^8FEN9&EN9W-;)'!R
M:6UA<GE":6YD:6YG75LG;W!E<F%T:6]N<R==6R1O<&YA;65=6R=I;G!U="==
M6R=U<V4G73L*("`@("`@("`@("`@:68@*"1U<V4@/3T@)V5N8V]D960G*2![
M"B`@("`@("`@("`@("`@("`D;F%M97-P86-E(#T@)'1H:7,M/F)I;F1I;F=S
M6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD;W!N86UE75LG:6YP
M=70G75LG;F%M97-P86-E)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D8FEN9&EN9U1Y<&4@/2`D=&AI<RT^8FEN9&EN9W-;)'!R
M:6UA<GE":6YD:6YG75LG='EP92==.PH@("`@("`@("`@("`@("`@)&YS(#T@
M)'1H:7,M/G!O<G14>7!E<ULD8FEN9&EN9U1Y<&5=6R1O<&YA;65=6R=I;G!U
M="==6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@("`@("1N86UE<W!A8V4@
M/2`D=&AI<RT^;F%M97-P86-E<ULD;G-=.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D87)G<R`]("<G.PH@("`@("`@("`@("`D87)G87)R87D@/2`G
M)SL*("`@("`@("`@("`@)&-O;6UE;G1S(#T@)R<["B`@("`@("`@("`@("1W
M<F%P<&5R<R`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D;W!E<F%T:6]N
M6R=I;G!U="==(&%S("1A<F=N86UE(#T^("1A<F=T>7!E*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&%R9VYA;64@/3T@(FUE<W-A9V4B*2!["B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FUE<W-A9V5S6R1A<F=T>7!E
M72!A<R`D7V%R9VYA;64@/3X@)%]A<F=T>7!E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C;VUM96YT<R`]("<G.PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&]P<W1Y;&4@/3T@)V1O8W5M96YT)R`F)B`D=7-E(#T]("=L
M:71E<F%L)R`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%]A<F=T
M>7!E6R=N86UE)UT@/3T@)W!A<F%M971E<G,G*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@=&AE('1Y<&4@;W(@96QE;65N="!R969E
M<F5D('1O(&ES('5S960@9F]R('!A<F%M971E<G,A"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&5L871T<G,@/2!N=6QL.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E;&5M96YT(#T@)%]A<F=T>7!E6R=E
M;&5M96YT)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5L
M(#T@)'1H:7,M/F5L96UE;G1S6R1?87)G='EP95LG;F%M97-P86-E)UU=6R1?
M87)G='EP95LG='EP92==73L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68H)&5L6R=C;VUP;&5X)UTI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&YA;65S<&%C92`]("1T:&ES+3YN86UE<W!A
M8V5S6R1?87)G='EP95LG;F%M97-P86-E)UU=.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!86%@@;F5E9"!T;R!W<F%P('1H92!P
M87)A;65T97)S(&EN(&$@<V]A<%]V86QU90H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&5L6R=E;&5M96YT<R==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D96Q;)V5L96UE;G1S
M)UT@87,@)&5L;F%M92`]/B`D96QA='1R<RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@:7,@=&AE(&5L96UE;G0@82!C
M;VUP;&5X('1Y<&4_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD96QA='1R
M<ULG;F%M97-P86-E)UU=6R1E;&YA;65=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VUM96YT<R`N/2`D=&AI
M<RT^7V-O;7!L97A4>7!E07)G*"1A<F=S+"`D87)G87)R87DL("1?87)G='EP
M92P@)%]A<F=N86UE*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1!<F<H)&%R9W,L("1A<F=A
M<G)A>2P@)&5L;F%M92D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]+RH@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VUM
M96YT<R`]("1T:&ES+3Y?8V]M<&QE>%1Y<&5!<F<H)&%R9W,L("1A<F=A<G)A
M>2P@)&5L871T<G,L("1E;&%T=')S6R=N86UE)UTI.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('TJ+PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF*"1E;%LG8V]M<&QE>"==("8F("1A<F=A<G)A>2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=W)A<&YA;64@
M/2`G>R<N)'1H:7,M/FYA;65S<&%C97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G
M75TN)WTG+B1E;%LG;F%M92==.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]M;65N=',@+CT@(B`@("`@("`@7"1[)&5L6R=N86UE
M)UU](#TF(&YE=R!33T%07U9A;'5E*"<D=W)A<&YA;64G+&9A;'-E+%PD=CUA
M<G)A>2@D87)G87)R87DI*3M<;B(["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1A<F=A<G)A>2`]("(G>R1E;%LG;F%M92==?2<]/EPD
M>R1E;%LG;F%M92==?2(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?87)G='EP95LG96QE;65N="==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@96QE;65N="!A
M<F=U;65N=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;6UE;G1S
M(#T@)'1H:7,M/E]E;&5M96YT07)G*"1A<F=S+"`D87)G87)R87DL("1?87)G
M='EP92P@)%]A<F=T>7!E6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M8V]M<&QE>"!T>7!E(&%R9W5M96YT"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]M;65N=',@/2`D=&AI<RT^7V-O;7!L97A4>7!E07)G*"1A<F=S
M+"`D87)G87)R87DL("1?87)G='EP92P@)%]A<F=N86UE*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@=F%L
M:61A=&4@96YT<FEE<PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A
M=&53=')I;F<H)&]P;F%M92DI(')E='5R;B!.54Q,.PH@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?=F%L:61A=&53=')I;F<H)&YA;65S<&%C92DI(')E='5R
M;B!.54Q,.PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&53=')I
M;F<H)'-O87!A8W1I;VXI*2!R971U<FX@3E5,3#L*"B`@("`@("`@("`@(&EF
M("@D87)G87)R87DI('L*("`@("`@("`@("`@("`@("1A<F=A<G)A>2`](")A
M<G)A>2@D87)G87)R87DI(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1A<F=A<G)A>2`]("=N=6QL)SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&-L87-S("X]("(@("`@9G5N8W1I;VX@)B1O<&YA;64H
M)&%R9W,I('M<;B1C;VUM96YT<R1W<F%P<&5R<R(N"B`@("`@("`@("`@("(@
M("`@("`@(')E='5R;B!<)'1H:7,M/F-A;&PH7"(D;W!N86UE7"(L(%QN(BX*
M("`@("`@("`@("`@(B`@("`@("`@("`@("`@("`@("`@("`@(%PD=B`]("1A
M<F=A<G)A>2P@7&XB+@H@("`@("`@("`@("`B("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)VYA;65S<&%C92<]/B<D;F%M97-P86-E)RQ<;B(N"B`@
M("`@("`@("`@("(@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-O87!A
M8W1I;VXG/3XG)'-O87!A8W1I;VXG+%QN(BX*("`@("`@("`@("`@(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G/3XG)&]P<W1Y;&4G+%QN
M(BX*("`@("`@("`@("`@(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=7-E)ST^)R1U<V4G(BX*("`@("`@("`@("`@*"1T:&ES+3YT<F%C93\B+"=T
M<F%C92<]/C$B.B(B*2XB("DI.UQN(BX*("`@("`@("`@("`@(B`@("!]7&XB
M.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@+CT@(GU<;B(["B`@("`@("`@
M<F5T=7)N("1C;&%S<SL*("`@('T*"B`@("!F=6YC=&EO;B!G96YE<F%T94%L
M;%!R;WAI97,H*0H@("`@>PH@("`@("`@("1P<F]X>6-O9&4@/2`G)SL*("`@
M("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3YS97)V:6-E<ULD=&AI
M<RT^<V5R=FEC95U;)W!O<G1S)UTI(&%S("1K97DI('L*("`@("`@("`@("`@
M)'!O<G0@/28@)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R
M=',G75LD:V5Y73L*("`@("`@("`@("`@)'!R;WAY8V]D92`N/2`D=&AI<RT^
M9V5N97)A=&50<F]X>4-O9&4H)'!O<G0I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'!R;WAY8V]D93L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4')O
M>'DH)'!O<G0@/2`G)RP@)&YA;64@/2`G)RD*("`@('L*("`@("`@("`D;75L
M=&EP;W)T(#T@8V]U;G0H)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E
M75LG<&]R=',G72D@/B`Q.PH*("`@("`@("!I9B`H(21P;W)T*2!["B`@("`@
M("`@("`@(')E<V5T*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;
M)W!O<G1S)UTI.PH@("`@("`@("`@("`D<&]R="`](&-U<G)E;G0H)'1H:7,M
M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G72D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&UU;'1I<&]R="!\?"`D<&]R="D@>PH@("`@("`@
M("`@("`D8VQA<W-N86UE(#T@)U=E8E-E<G9I8V5?)R`N("1T:&ES+3YS97)V
M:6-E("X@)U\G("X@)'!O<G1;)VYA;64G73L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8VQA<W-N86UE(#T@)U=E8E-E<G9I8V5?)R`N("1T:&ES
M+3YS97)V:6-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"1N86UE*2!["B`@
M("`@("`@("`@("1C;&%S<VYA;64@/2`D;F%M92`N("=?)R`N("1C;&%S<VYA
M;64["B`@("`@("`@?0H*("`@("`@("`D8VQA<W-N86UE(#T@<')E9U]R97!L
M86-E*"<O6R`N7"A<*5TK+R<L("=?)RP@)&-L87-S;F%M92D["@H@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<VYA;64I*2!["B`@("`@("`@("`@
M("1P<F]X>2`]("1T:&ES+3YG96YE<F%T95!R;WAY0V]D92@D<&]R="P@)&-L
M87-S;F%M92D["B`@("`@("`@("`@(&5V86PH)'!R;WAY*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!N97<@)&-L87-S;F%M93L*("`@('T*"B`@("!F
M=6YC=&EO;B`F7V=E=$-O;7!L97A4>7!E1F]R16QE;65N="@D;F%M92P@)&YA
M;65S<&%C92D*("`@('L*("`@("`@("`D="`]($Y53$P["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YN<ULD;F%M97-P86-E72D@)B8*("`@("`@("`@("`@
M:7-S970H)'1H:7,M/F5L96UE;G1S6R1T:&ES+3YN<ULD;F%M97-P86-E75U;
M)&YA;65=6R=T>7!E)UTI*2!["@H@("`@("`@("`@("`D='EP92`]("1T:&ES
M+3YE;&5M96YT<ULD=&AI<RT^;G-;)&YA;65S<&%C95U=6R1N86UE75LG='EP
M92==.PH@("`@("`@("`@("`D;G,@/2`D=&AI<RT^96QE;65N='-;)'1H:7,M
M/FYS6R1N86UE<W!A8V5=75LD;F%M95U;)VYA;65S<&%C92==.PH*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VUP;&5X5'EP97-;)&YS75LD='EP
M95TI*2!["B`@("`@("`@("`@("`@("`D="`]("1T:&ES+3YC;VUP;&5X5'EP
M97-;)&YS75LD='EP95T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;7!L97A4
M>7!E3F%M949O<D5L96UE;G0H)&YA;64L("1N86UE<W!A8V4I"B`@("!["B`@
M("`@("`@)'0@/2`D=&AI<RT^7V=E=$-O;7!L97A4>7!E1F]R16QE;65N="@D
M;F%M92P@)&YA;65S<&%C92D["B`@("`@("`@:68@*"1T*2!["B`@("`@("`@
M("`@(')E='5R;B`D=%LG;F%M92==.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@3E5,3#L*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VUP;&5X5'EP94-H
M:6QD5'EP92@D;G,L("1N86UE+"`D8VAI;&1?;G,L("1C:&EL9%]N86UE*2![
M"B`@("`@("`@+R\@:7,@=&AE('1Y<&4@86X@96QE;65N=#\*("`@("`@("`D
M="`]("1T:&ES+3Y?9V5T0V]M<&QE>%1Y<&5&;W)%;&5M96YT*"1N86UE+"`D
M;G,I.PH@("`@("`@(&EF("@D="D@>PH@("`@("`@("`@("`O+R!N;RP@9V5T
M(&ET(&9R;VT@8V]M<&QE>"!T>7!E<R!D:7)E8W1L>0H@("`@("`@("`@("!I
M9B`H:7-S970H)'1;)V5L96UE;G1S)UU;)&-H:6QD7VYA;65=6R=T>7!E)UTI
M*0H@("`@("`@("`@("`@("`@<F5T=7)N("1T6R=E;&5M96YT<R==6R1C:&EL
M9%]N86UE75LG='EP92==.PH@("`@("`@('T*("`@("`@("!R971U<FX@3E5,
M3#L*("`@('T*"B`@("!F=6YC=&EO;B!G97138VAE;6%4>7!E*"1T>7!E+"`D
M;F%M92P@)'1Y<&5?;F%M97-P86-E*0H@("`@>PH@("`@("`@(",@<V5E(&EF
M(&ET)W,@82!C;VUP;&5X('1Y<&4@<V\@=V4@8V%N(&1E86P@<')O<&5R;'D@
M=VET:"!33T%014Y#.F%R<F%Y5'EP90H@("`@("`@(&EF("@D;F%M92`F)B`D
M='EP92D@>PH@("`@("`@("`@("`C(%A86"!43T1/.@H@("`@("`@("`@("`C
M(&QO;VL@=7`@=&AE(&YA;64@:6X@=&AE('=S9&P@86YD('9A;&ED871E('1H
M92!T>7!E"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VUP;&5X5'EP
M97,@87,@)&YS/3X@)'1Y<&5S*2!["B`@("`@("`@("`@("`@("!I9B`H87)R
M87E?:V5Y7V5X:7-T<R@D='EP92P@)'1Y<&5S*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=T>7!E)RP@)'1Y<&5S6R1T
M>7!E72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D87)R87ET
M>7!E7VYS+"`D87)R87ET>7!E+"`D87)R87E?9&5P=&@I(#T@:7-S970H)'1Y
M<&5S6R1T>7!E75LG87)R87E4>7!E)UTI/PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G971$965P97-T07)R87E4>7!E*"1T>7!E<ULD
M='EP95U;)VYA;65S<&%C92==+"`D='EP97-;)'1Y<&5=6R=A<G)A>51Y<&4G
M72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@87)R87DH)'1H:7,M
M/FYA;65S<&%C97-;)'1Y<&5S6R1T>7!E75LG;F%M97-P86-E)UU=+"!.54Q,
M+"`P*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1T
M>7!E<ULD='EP95U;)W1Y<&4G72P@)&%R<F%Y='EP92P@)&%R<F%Y='EP95]N
M<RP@)&%R<F%Y7V1E<'1H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V%R<F%Y5'EP
M92<L("1T>7!E<ULD='EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&QI<W0H)&%R<F%Y='EP95]N<RP@)&%R<F%Y='EP92P@)&%R<F%Y7V1E<'1H
M*2`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M971$965P97-T07)R87E4>7!E*"1T>7!E<ULD='EP95U;)VYA;65S<&%C92==
M+"`D='EP97-;)'1Y<&5=6R=A<G)A>51Y<&4G72D["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@G07)R87DG+"`D87)R87ET>7!E+"`D
M87)R87ET>7!E7VYS+"`D87)R87E?9&5P=&@I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T
M<R@G96QE;65N=',G+"`D='EP97-;)'1Y<&5=*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S*"1N86UE+"`D='EP97-;)'1Y
M<&5=6R=E;&5M96YT<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M='EP92`]("1T>7!E<ULD='EP95U;)V5L96UE;G1S)UU;)W1Y<&4G73L*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1T>7!E+"!.54Q,
M+"`D=&AI<RT^;F%M97-P86-E<ULD='EP97-;)'1Y<&5=6R=N86UE<W!A8V4G
M75TL($Y53$PI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'1Y
M<&4@)B8@)'1Y<&5?;F%M97-P86-E*2!["B`@("`@("`@("`@("1A<G)A>51Y
M<&4@/2!.54Q,.PH@("`@("`@("`@("`C(%A86"!43T1/.@H@("`@("`@("`@
M("`C('1H:7,@8V]D92!C=7)R96YT;'D@:&%N9&QE<R!O;FQY(&]N92!W87D@
M;V8@96YC;V1I;F<@87)R87D@='EP97,@:6X@=W-D;`H@("`@("`@("`@("`C
M(&YE960@=&\@9&\@82!G96YE<F%L:7IE9"!F=6YC=&EO;B!T;R!F:6=U<F4@
M;W5T(&-O;7!L97@@='EP97,*("`@("`@("`@("`@)'`@/2`D=&AI<RT^;G-;
M)'1Y<&5?;F%M97-P86-E73L*("`@("`@("`@("`@:68@*"1P("8F"B`@("`@
M("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S*"1P+"`D=&AI<RT^8V]M<&QE
M>%1Y<&5S*2`F)@H@("`@("`@("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@D
M='EP92P@)'1H:7,M/F-O;7!L97A4>7!E<ULD<%TI*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&%R<F%Y5'EP92`]("1T:&ES+3YC;VUP;&5X5'EP97-;)'!=
M6R1T>7!E75LG87)R87E4>7!E)UTI('L*("`@("`@("`@("`@("`@("`@("`D
M='EP92`]("=!<G)A>2<["B`@("`@("`@("`@("`@("!](&5L<V4@:68@*"1T
M:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T>7!E75LG;W)D97(G73T])W-E<75E
M;F-E)R`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]K97E?
M97AI<W1S*"=E;&5M96YT<R<L("1T:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T
M>7!E72DI('L*("`@("`@("`@("`@("`@("`@("!R97-E="@D=&AI<RT^8V]M
M<&QE>%1Y<&5S6R1P75LD='EP95U;)V5L96UE;G1S)UTI.PH@("`@("`@("`@
M("`@("`@("`@(",@87-S=6UE(&%N(&%R<F%Y"B`@("`@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*"1T:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T>7!E75LG
M96QE;65N=',G72D@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M87)G(#T@8W5R<F5N="@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1P75LD='EP95U;
M)V5L96UE;G1S)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`D87)R87E4
M>7!E(#T@)&%R9ULG='EP92==.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M='EP92`]("=!<G)A>2<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D=&AI<RT^8V]M<&QE
M>%1Y<&5S6R1P75LD='EP95U;)V5L96UE;G1S)UT@87,@)&5L96UE;G0I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D96QE;65N=%LG;F%M
M92==(#T]("1T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%R<F%Y5'EP92`]("1E;&5M96YT6R=T>7!E)UT["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`D96QE;65N=%LG='EP92==
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]("=3
M=')U8W0G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1T>7!E+"`D87)R87E4>7!E+"`D='EP95]N86UE<W!A8V4L
M(&YU;&PI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!A<G)A>2AN=6QL+"!N=6QL+"!N=6QL+"!N=6QL*3L*("`@('T*"B`@("`O
M*BH@4F5C=7)S92!T:')O=6=H('1H92!74T1,('-T<G5C='5R92!L;V]K:6YG
M(&9O<B!T:&4@:6YN97)M;W-T(&%R<F%Y('1Y<&4@;V8@;75L=&DM9&EM96YS
M:6]N86P@87)R87ES+@H@("`@("H*("`@("`J("!486ME<R!A(&YA;65S<&%C
M92!P<F5F:7@@86YD(&$@='EP92P@=VAI8V@@8V%N(&)E(&EN('1H92!F;W)M
M("=T>7!E)R!O<B`G='EP95M=)RP*("`@("`J("!A;F0@<F5T=7)N<R!T:&4@
M9G5L;"!N86UE<W!A8V4@55))+"!T:&4@='EP92!O9B!T:&4@;6]S="!D965P
M;'D@;F5S=&5D(&%R<F%Y('1Y<&4@9F]U;F0L"B`@("`@*B`@86YD('1H92!N
M=6UB97(@;V8@;&5V96QS(&]F(&YE<W1I;F<N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`<F5T=7)N(&UI>&5D(&%R<F%Y(&]R(&YO
M=&AI;F<*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$1E97!E<W1!<G)A>51Y
M<&4H)&YS4')E9FEX+"`D87)R87E4>7!E*0H@("`@>PH@("`@("`@('-T871I
M8R`D=')A:6P@/2!A<G)A>2@I.PH*("`@("`@("`D87)R87E4>7!E(#T@97)E
M9U]R97!L86-E*"=<6UQ=)"<L("<G+"`D87)R87E4>7!E*3L*"B`@("`@("`@
M+R\@4')O=&5C="!A9V%I;G-T(&-I<F-U;&%R(')E9F5R96YC97,*("`@("`@
M("`O+R!86%@@5V4@<F5A;&QY(&YE960@=&\@<F5M;W9E('1R86EL(&9R;VT@
M=&AI<R!A;'1O9V5T:&5R("AI="=S('9E<GD@:6YE9F9I8VEE;G0@86YD"B`@
M("`@("`@+R\@:6X@=&AE('=R;VYG('!L86-E(2D@86YD('!U="!C:7)C=6QA
M<B!R969E<F5N8V4@8VAE8VMI;F<@:6X@=VAE;B!T:&4@5U-$3"!I;F9O"B`@
M("`@("`@+R\@:7,@9V5N97)A=&5D(&EN('1H92!F:7)S="!P;&%C90H@("`@
M("`@(&EF("AA<G)A>5]S96%R8V@H)&YS4')E9FEX("X@)SHG("X@)&%R<F%Y
M5'EP92P@)'1R86EL*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH3E5,
M3"P@3E5,3"P@+6-O=6YT*"1T<F%I;"DI.PH@("`@("`@('T*"B`@("`@("`@
M:68@*&%R<F%Y7VME>5]E>&ES=',H)&YS4')E9FEX+"`D=&AI<RT^8V]M<&QE
M>%1Y<&5S*2`F)@H@("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S*"1A<G)A
M>51Y<&4L("1T:&ES+3YC;VUP;&5X5'EP97-;)&YS4')E9FEX72D@)B8*("`@
M("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@G87)R87E4>7!E)RP@)'1H:7,M
M/F-O;7!L97A4>7!E<ULD;G-0<F5F:7A=6R1A<G)A>51Y<&5=*2D@>PH@("`@
M("`@("`@("`D=')A:6Q;72`]("1N<U!R969I>"`N("<Z)R`N("1A<G)A>51Y
M<&4["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V=E=$1E97!E<W1!
M<G)A>51Y<&4H("1T:&ES+3YC;VUP;&5X5'EP97-;)&YS4')E9FEX75LD87)R
M87E4>7!E75LG;F%M97-P86-E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;VUP;&5X5'EP
M97-;)&YS4')E9FEX75LD87)R87E4>7!E75LG87)R87E4>7!E)UTI.PH@("`@
M("`@("`@("!R971U<FX@87)R87DH)')E<W5L=%LP72P@)')E<W5L=%LQ72P@
M)')E<W5L=%LR72`K(#$I.PH@("`@("`@('T*("`@("`@("!R971U<FX@87)R
M87DH)'1H:7,M/FYA;65S<&%C97-;)&YS4')E9FEX72P@)&%R<F%Y5'EP92P@
M,"D["B`@("!]"GT*"F-L87-S(%-/05!?5U-$3%]#86-H92!E>'1E;F1S(%-/
M05!?0F%S90I["B`@("`O+R!#86-H92!S971T:6YG<PH*("`@("\J*@H@("`@
M("H@57-E(%=31$P@8V%C:&4*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?8V%C:&55<V4@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@0V%C:&4@;6%X(&QI9F5T:6UE("AI;B!S96-O;F1S*0H@("`@("H*
M("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D7V-A8VAE36%X06=E
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%-/05!?5U-$3%]#86-H92!C;VYS
M=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2`@8F]O;&5A;B!U<V4@8V%C
M:&EN9PH@("`@("H@0'!A<F%M("!I;G0@("`@(&-A8VAE(&UA>"!L:69E=&EM
M92`H:6X@<V5C;VYD<RD*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%-/05!?5U-$3%]#86-H92@D8V%C:&55<V4@/2!74T1,
M7T-!0TA%7U5312P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V%C
M:&5-87A!9V4@/2!74T1,7T-!0TA%7TU!6%]!1T4I('L*("`@("`@("!P87)E
M;G0Z.E-/05!?0F%S92@G5U-$3$-!0TA%)RD["B`@("`@("`@)'1H:7,M/E]C
M86-H955S92`]("1C86-H955S93L*("`@("`@("`D=&AI<RT^7V-A8VAE36%X
M06=E(#T@)&-A8VAE36%X06=E.PH@("`@?0H*("`@("\J*@H@("`@("H@7V-A
M8VAE1&ER"B`@("`@*B!R971U<FX@=&AE('!A=&@@=&\@=&AE(&-A8VAE+"!I
M9B!I="!D;V5S;B=T(&5X:7-T+"!M86ME(&ET"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]C86-H941I<B@I('L*("`@("`@("`D9&ER(#T@9V5T96YV*")74T1,
M0T%#2$4B*3L*("`@("`@("!I9B`H(21D:7(I("1D:7(@/2`B+B]W<V1L8V%C
M:&4B.PH@("`@("`@($!M:V1I<B@D9&ER+"`P-S`P*3L*("`@("`@("!R971U
M<FX@)&1I<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!A(&9I
M;&4@9G)O;2!C86-H92!I9B!I="!E>&ES=',L(&]T:&5R=VES92!R971R96EV
M92!F<F]M(&YE="P*("`@("`J(&%D9"!T;R!C86-H92P@86YD(')E='5R;B!F
M<F]M(&-A8VAE+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`@55),
M('1O(%=31$P*("`@("`J($!P87)A;2`@87)R87D@("`@<')O>'D@<&%R86UE
M=&5R<PH@("`@("H@0'!A<F%M("!I;G0@("`@("!E>'!E8W1E9"!-1#4@;V8@
M5U-$3"!54DP*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@9&%T80H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)'=S9&Q?
M9FYA;64L("1P<F]X>5]P87)A;7,@/2!A<G)A>2@I+"`D8V%C:&4@/2`P*2![
M"B`@("`@("`@)&-A8VAE;F%M92`]("1M9#5?=W-D;"`]("1F:6QE7V1A=&$@
M/2`G)SL*("`@("`@("!I9B`H)'1H:7,M/E]C86-H955S92D@>PH@("`@("`@
M("`@("`O+R!4<GD@=&\@<F5T<FEE=F4@5U-$3"!F<F]M(&-A8VAE"B`@("`@
M("`@("`@("1C86-H96YA;64@/2!33T%07U=31$Q?0V%C:&4Z.E]C86-H941I
M<B@I("X@)R\G("X@;60U*"1W<V1L7V9N86UE*2X@)RYW<V1L)SL*("`@("`@
M("`@("`@:68@*&9I;&5?97AI<W1S*"1C86-H96YA;64I*2!["B`@("`@("`@
M("`@("`@("`D=V8@/2!F;W!E;B@D8V%C:&5N86UE+"=R8B<I.PH@("`@("`@
M("`@("`@("`@:68@*"1W9BD@>PH@("`@("`@("`@("`@("`@("`@("\O(%)E
M861I;F<@8V%C:&5D(&9I;&4*("`@("`@("`@("`@("`@("`@("`D9FEL95]D
M871A(#T@9G)E860H)'=F+"!F:6QE<VEZ92@D8V%C:&5N86UE*2D["B`@("`@
M("`@("`@("`@("`@("`@)&UD-5]W<V1L(#T@;60U*"1F:6QE7V1A=&$I.PH@
M("`@("`@("`@("`@("`@("`@(&9C;&]S92@D=V8I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*"1C86-H92D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D8V%C:&4@(3T@)&UD-5]W<V1L*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*"=74T1,($-H96-K<W5M(&5R<F]R(2<L("1W<V1L7V9N86UE*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1F:2`]('-T870H)&-A8VAE;F%M92D["B`@("`@
M("`@("`@("`@("`@("`@)&-A8VAE7VUT:6UE(#T@)&9I6SA=.PH@("`@("`@
M("`@("`@("`@("`@("-P<FEN="!C86-H95]M=&EM92P@=&EM92@I"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1C86-H95]M=&EM92`K("1T:&ES+3Y?8V%C
M:&5-87A!9V4@/"!T:6UE*"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M(R!E>'!I<F5D"B`@("`@("`@("`@("`@("`@("`@("`@("1M9#5?=W-D;"`]
M("<G.R`C(')E9F5T8V@*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@A)&UD-5]W<V1L*2!["B`@("`@("`@("`@("\O($YO="!C86-H960@;W(@
M;F]T('5S:6YG(&-A8VAE+B!2971R:65V92!74T1,(&9R;VT@55),"@H@("`@
M("`@("`@("`O+R!I<R!I="!A(&QO8V%L(&9I;&4_"B`@("`@("`@("`@("\O
M('1H:7,@<V5C=&EO;B!S:&]U;&0@8F4@<F5P;&%C92!B>2!C=7)L(&%T('-O
M;64@<&]I;G0*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7BAH='1P
M<S]\9FEL92DZ7"]<+R\G+"1W<V1L7V9N86UE*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D=W-D;%]F;F%M92DI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B56YA
M8FQE('1O(')E860@;&]C86P@5U-$3"`D=W-D;%]F;F%M92(L("1W<V1L7V9N
M86UE*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AF
M=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*("`@("`@
M("`@("`@("`@("`@("`D9FEL95]D871A(#T@9FEL95]G971?8V]N=&5N=',H
M)'=S9&Q?9FYA;64I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D9FEL95]D871A(#T@:6UP;&]D92@G)RQF:6QE*"1W
M<V1L7V9N86UE*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D=7)I(#T@97AP;&]D92@G/R<L)'=S
M9&Q?9FYA;64I.PH@("`@("`@("`@("`@("`@)')Q(#TF(&YE=R!(5%107U)E
M<75E<W0H)'5R:5LP72P@)'!R;WAY7W!A<F%M<RD["B`@("`@("`@("`@("`@
M("`O+R!T:&4@=7-E<B!A9V5N="!(5%107U)E<75E<W0@=7-E<R!F;W5L<R!T
M:&EN9W,@=7`*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=7)I6S%=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1R<2T^861D4F%W475E<GE3=')I;F<H
M)'5R:5LQ72D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1P<F]X>5]P87)A;7-;)W!R;WAY7W5S97(G72D@)B8@:7-S
M970H)'!R;WAY7W!A<F%M<ULG<')O>'E?<&%S<R==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1R<2T^<V5T4')O>'DH)'!R;WAY7W!A<F%M<ULB<')O>'E?
M:&]S=")=+"1P<F]X>5]P87)A;7-;(G!R;WAY7W!O<G0B72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P<F]X>5]P87)A;7-;(G!R;WAY
M7W5S97(B72PD<')O>'E?<&%R86US6R)P<F]X>5]P87-S(ETI.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D<G$M/G-E
M;F1297%U97-T*"D["B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@<F5T<FEE=F4@5U-$3"`D
M=W-D;%]F;F%M92PB("X@)')Q+3YG971297-P;VYS94-O9&4H*2P@)'=S9&Q?
M9FYA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("1F:6QE7V1A
M=&$@/2`D<G$M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@("`@("`@("`@("`@
M:68@*"$D9FEL95]D871A*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E5N86)L92!T;R!R971R:65V92!7
M4T1,("1W<V1L7V9N86UE+"!N;R!H='1P(&)O9'DB+"`D=W-D;%]F;F%M92D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1M9#5?=W-D;"`](&UD-2@D9FEL95]D871A*3L*"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7V-A8VAE57-E*2!["B`@("`@("`@("`@("`@("`D9G`@/2!F
M;W!E;B@D8V%C:&5N86UE+"`B=V(B*3L*("`@("`@("`@("`@("`@(&9W<FET
M92@D9G`L("1F:6QE7V1A=&$I.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F
M<"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3Y?8V%C:&55<V4@)B8@)&-A8VAE("8F("1C86-H92`A/2`D;60U7W=S9&PI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(E=31$P@0VAE8VMS=6T@97)R;W(A(BP@)'=S9&Q?9FYA;64I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&9I;&5?9&%T83L*("`@('T*?0H*8VQA<W,@
M4T]!4%]74T1,7U!A<G-E<B!E>'1E;F1S(%-/05!?0F%S90I["B`@("`O+R!D
M969I;F4@:6YT97)N86P@87)R87ES(&]F(&)I;F1I;F=S+"!P;W)T<RP@;W!E
M<F%T:6]N<RP@;65S<V%G97,L(&5T8RX*("`@('9A<B`D8W5R<F5N=$UE<W-A
M9V4["B`@("!V87(@)&-U<G)E;G1/<&5R871I;VX["B`@("!V87(@)&-U<G)E
M;G10;W)T5'EP93L*("`@('9A<B`D8W5R<F5N=$)I;F1I;F<["B`@("!V87(@
M)&-U<G)E;G10;W)T.PH*("`@("\O('!A<G-E<B!V87)S"B`@("!V87(@)&-A
M8VAE.PH*("`@('9A<B`D=&YS(#T@;G5L;#L*("`@('9A<B`D<V]A<&YS(#T@
M87)R87DH)W-O87`G*3L*("`@('9A<B`D=7)I(#T@)R<["B`@("!V87(@)'=S
M9&P@/2!N=6QL.PH*("`@('9A<B`D<W1A='5S(#T@)R<["B`@("!V87(@)&5L
M96UE;G1?<W1A8VL@/2!A<G)A>2@I.PH@("`@=F%R("1P87)E;G1%;&5M96YT
M(#T@)R<["@H@("`@=F%R("1S8VAE;6$@/2`G)SL*("`@('9A<B`D<V-H96UA
M4W1A='5S(#T@)R<["B`@("!V87(@)'-C:&5M85]S=&%C:R`](&%R<F%Y*"D[
M"B`@("!V87(@)&-U<G)E;G1#;VUP;&5X5'EP93L*("`@('9A<B`D<V-H96UA
M7V5L96UE;G1?<W1A8VL@/2!A<G)A>2@I.PH@("`@=F%R("1C=7)R96YT16QE
M;65N=#L*"B`@("`O+R!C;VYS=')U8W1O<@H@("`@9G5N8W1I;VX@4T]!4%]7
M4T1,7U!A<G-E<B@D=7)I+"`F)'=S9&PL("1D;V-S(#T@9F%L<V4I('L*("`@
M("`@("!P87)E;G0Z.E-/05!?0F%S92@G5U-$3%!!4E-%4B<I.PH@("`@("`@
M("1T:&ES+3YC86-H92`])B!N97<@4T]!4%]74T1,7T-A8VAE*"1W<V1L+3YC
M86-H955S92P@)'=S9&PM/F-A8VAE36%X06=E*3L*("`@("`@("`D=&AI<RT^
M=7)I(#T@)'5R:3L*("`@("`@("`D=&AI<RT^=W-D;"`]("8D=W-D;#L*("`@
M("`@("`D=&AI<RT^9&]C<R`]("1D;V-S.PH@("`@("`@("1T:&ES+3YP87)S
M92@D=7)I*3L*("`@('T*"B`@("!F=6YC=&EO;B!P87)S92@D=7)I*2!["B`@
M("`@("`@+R\@0VAE8VL@=VAE=&AE<B!C;VYT96YT(&AA<R!B965N(')E860N
M"B`@("`@("`@)&9D(#T@)'1H:7,M/F-A8VAE+3YG970H)'5R:2P@)'1H:7,M
M/G=S9&PM/G!R;WAY*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9F0I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*"1F9"D["B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@86X@6$U,('!A
M<G-E<BX*("`@("`@("`D<&%R<V5R(#T@>&UL7W!A<G-E<E]C<F5A=&4H*3L*
M("`@("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'!A<G-E<BP@6$U,7T]0
M5$E/3E]#05-%7T9/3$1)3D<L(#`I.PH@("`@("`@('AM;%]S971?;V)J96-T
M*"1P87)S97(L("1T:&ES*3L*("`@("`@("!X;6Q?<V5T7V5L96UE;G1?:&%N
M9&QE<B@D<&%R<V5R+"`G<W1A<G1%;&5M96YT)RP@)V5N9$5L96UE;G0G*3L*
M("`@("`@("!I9B`H)'1H:7,M/F1O8W,I('L*("`@("`@("`@("`@>&UL7W-E
M=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1P87)S97(L("=C:&%R86-T97)$
M871A)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(7AM;%]P87)S92@D<&%R
M<V5R+"1F9"P@=')U92DI('L*("`@("`@("`@("`@)&1E=&%I;"`]('-P<FEN
M=&8H)UA-3"!E<G)O<B!O;B!L:6YE("5D.B`E<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('AM;%]G971?8W5R<F5N=%]L:6YE7VYU
M;6)E<B@D<&%R<V5R*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H)'!A
M<G-E<BDI*3L*("`@("`@("`@("`@+R]P<FEN="`D9F0["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@<&%R
M<V4@5U-$3"!F:6QE("1U<FE<;B1D971A:6PB*3L*("`@("`@("!]"B`@("`@
M("`@>&UL7W!A<G-E<E]F<F5E*"1P87)S97(I.PH@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\O('-T87)T+65L96UE;G0@:&%N9&QE<@H@("`@
M9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1P87)S97(L("1N86UE+"`D871T<G,I
M('L*("`@("`@("`O+R!G970@96QE;65N="!P<F5F:7@*("`@("`@("`D<6YA
M;64@/28@;F5W(%%.86UE*"1N86UE*3L*("`@("`@("!I9B`H)'%N86UE+3YN
M<RD@>PH@("`@("`@("`@("`D;G,@/2`D<6YA;64M/FYS.PH@("`@("`@("`@
M("!I9B`H)&YS("8F("@H(21T:&ES+3YT;G,@)B8@<W1R8V%S96-M<"@D<6YA
M;64M/FYA;64L)V1E9FEN:71I;VYS)RD@/3T@,"D@?'P@)&YS(#T]("1T:&ES
M+3YT;G,I*2!["B`@("`@("`@("`@("`@("`D;F%M92`]("1Q;F%M92T^;F%M
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^8W5R
M<F5N=%1A9R`]("1Q;F%M92T^;F%M93L*("`@("`@("`D=&AI<RT^<&%R96YT
M16QE;65N="`]("<G.PH@("`@("`@("1S=&%C:U]S:7IE(#T@8V]U;G0H)'1H
M:7,M/F5L96UE;G1?<W1A8VLI.PH@("`@("`@(&EF("@D<W1A8VM?<VEZ92`^
M(#`I('L*("`@("`@("`@("`@)'1H:7,M/G!A<F5N=$5L96UE;G0@/2`D=&AI
M<RT^96QE;65N=%]S=&%C:ULD<W1A8VM?<VEZ92TQ73L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/F5L96UE;G1?<W1A8VM;72`]("1T:&ES+3YC=7)R96YT
M5&%G.PH*("`@("`@("`O+R!F:6YD('-T871U<RP@<F5G:7-T97(@9&%T80H@
M("`@("`@('-W:71C:"@D=&AI<RT^<W1A='5S*2!["B`@("`@("`@8V%S92`G
M='EP97,G.@H@("`@("`@("`@("`O+R!S96-T(#(N,B!W<V1L.G1Y<&5S"B`@
M("`@("`@("`@("\O(&-H:6QD<F5N.B!X<V0Z<V-H96UA"B`@("`@("`@("`@
M("1P87)E;G1?=&%G(#T@)R<["B`@("`@("`@("`@("1S=&%C:U]S:7IE(#T@
M8V]U;G0H)'1H:7,M/G-C:&5M85]S=&%C:RD["B`@("`@("`@("`@(&EF("@D
M<W1A8VM?<VEZ92`^(#`I('L*("`@("`@("`@("`@("`@("1P87)E;G1?=&%G
M(#T@)'1H:7,M/G-C:&5M85]S=&%C:ULD<W1A8VM?<VEZ92TQ73L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@<W=I=&-H*"1Q;F%M92T^;F%M92D@>PH@
M("`@("`@("`@("!C87-E("=S8VAE;6$G.@H@("`@("`@("`@("`@("`@+R\@
M;F\@<&%R96YT('-H;W5L9"!B92!I;B!T:&4@<W1A8VL*("`@("`@("`@("`@
M("`@(&EF("@A)'!A<F5N=%]T86<@?'P@)'!A<F5N=%]T86<@/3T@)W1Y<&5S
M)RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S
M*"=T87)G971.86UE<W!A8V4G+"`D871T<G,I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS8VAE;6$@/2`D=&AI<RT^=W-D;"T^9V5T3F%M
M97-P86-E071T<FEB=71E3F%M92@D871T<G-;)W1A<F=E=$YA;65S<&%C92==
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V-H96UA(#T@)'1H:7,M/G=S9&PM/F=E=$YA
M;65S<&%C94%T=')I8G5T94YA;64H)'1H:7,M/G=S9&PM/G1N<RD["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW
M<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85T@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YE;&5M96YT<ULD=&AI
M<RT^<V-H96UA72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=C;VUP;&5X5'EP92<Z
M"B`@("`@("`@("`@("`@("!I9B`H)'!A<F5N=%]T86<@/3T@)W-C:&5M82<I
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$-O;7!L97A4
M>7!E(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D871T<G-;)VYA;65S<&%C92==*2D@)&%T=')S6R=N86UE<W!A
M8V4G72`]("1T:&ES+3YS8VAE;6$["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^
M8W5R<F5N=$-O;7!L97A4>7!E72`]("1A='1R<SL*("`@("`@("`@("`@("`@
M("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G8F%S92<L)&%T=')S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R
M<ULG8F%S92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N
M=$-O;7!L97A4>7!E75LG='EP92==(#T@)'%N+3YN86UE.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES
M+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=N86UE<W!A
M8V4G72`]("1Q;BT^;G,["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4
M>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS8VAE;6%3=&%T=7,@/2`G8V]M
M<&QE>%1Y<&4G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M
M85U;)'1H:7,M/F-U<G)E;G1%;&5M96YT75LG8V]M<&QE>"==(#T@5%)513L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@(&-A<V4@)V5L96UE;G0G.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1A='1R<ULG='EP92==*2D@>PH@("`@("`@("`@("`@("`@("`@("1Q;B`]
M)B!N97<@44YA;64H)&%T=')S6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@
M("`@("1A='1R<ULG='EP92==(#T@)'%N+3YN86UE.PH@("`@("`@("`@("`@
M("`@("`@(",D=&AI<RT^=W-D;"T^9V5T3F%M97-P86-E071T<FEB=71E3F%M
M90H@("`@("`@("`@("`@("`@("`@(&EF("@D<6XM/FYS("8F(&%R<F%Y7VME
M>5]E>&ES=',H)'%N+3YN<RP@)'1H:7,M/G=S9&PM/FYA;65S<&%C97,I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R<ULG;F%M97-P86-E)UT@
M/2`D<6XM/FYS.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D<&%R96YT16QE;65N="`]("<G.PH@
M("`@("`@("`@("`@("`@)'-T86-K7W-I>F4@/2!C;W5N="@D=&AI<RT^<V-H
M96UA7V5L96UE;G1?<W1A8VLI.PH@("`@("`@("`@("`@("`@:68@*"1S=&%C
M:U]S:7IE(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("1P87)E;G1%;&5M
M96YT(#T@)'1H:7,M/G-C:&5M85]E;&5M96YT7W-T86-K6R1S=&%C:U]S:7IE
M+3%=.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D871T<G-;)W)E9B==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YC=7)R96YT16QE;65N="`]("1A='1R<ULG<F5F)UT["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC
M=7)R96YT16QE;65N="`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G-C:&5M85]E;&5M96YT7W-T
M86-K6UT@/2`D=&AI<RT^8W5R<F5N=$5L96UE;G0["B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1A='1R<ULG;F%M97-P86-E)UTI*2`D871T<G-;)VYA
M;65S<&%C92==(#T@)'1H:7,M/G-C:&5M83L*"B`@("`@("`@("`@("`@("!I
M9B`H)'!A<F5N=%]T86<@/3T@)W-C:&5M82<I('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M85U;)'1H
M:7,M/F-U<G)E;G1%;&5M96YT72`]("1A='1R<SL*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M85U;)'1H
M:7,M/F-U<G)E;G1%;&5M96YT75LG8V]M<&QE>"==(#T@1D%,4T4["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-C:&5M85-T871U<R`]("=E;&5M96YT
M)SL*("`@("`@("`@("`@("`@('T@96QS92!I9B`H)'1H:7,M/F-U<G)E;G1#
M;VUP;&5X5'EP92D@>PH@("`@("`@("`@("`@("`@("`@("\O('=E)W)E(&EN
M<VED92!A(&-O;7!L97A4>7!E"B`@("`@("`@("`@("`@("`@("`@:68@*"AI
M<W-E="@D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=
M6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=O<F1E<B==*2`F)@H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E
M<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG
M;W)D97(G72`]/2`G<V5Q=65N8V4G*0H@("`@("`@("`@("`@("`@("`@("`@
M("`F)B`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=
M6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/3T@)T%R<F%Y
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O
M;7!L97A4>7!E75LG87)R87E4>7!E)UT@/2`D871T<G-;)W1Y<&4G73L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R
M<F5N=$-O;7!L97A4>7!E75LG96QE;65N=',G75LD=&AI<RT^8W5R<F5N=$5L
M96UE;G1=(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M
M/G-C:&5M85U;)'!A<F5N=$5L96UE;G1=6R=E;&5M96YT<R==6R1T:&ES+3YC
M=7)R96YT16QE;65N=%T@/2`D871T<G,["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=C;VUP;&5X0V]N
M=&5N="<Z"B`@("`@("`@("`@(&-A<V4@)W-I;7!L94-O;G1E;G0G.@H@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G97AT96YS:6]N)SH*
M("`@("`@("`@("`@8V%S92`G<F5S=')I8W1I;VXG.@H@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YS8VAE;6%3=&%T=7,@/3T@)V-O;7!L97A4>7!E)RD@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D871T<G-;)V)A<V4G72D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R
M<ULG8F%S92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N
M=$-O;7!L97A4>7!E75LG='EP92==(#T@)'%N+3YN86UE.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES
M+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=N86UE<W!A
M8V4G72`]("1Q;BT^;G,["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4
M>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`G<V5Q=65N8V4G.@H@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YS8VAE;6%3=&%T=7,@/3T@)V-O;7!L97A4>7!E)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C
M:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V]R9&5R)UT@/2`D
M<6YA;64M/FYA;64["B`@("`@("`@("`@("`@("`@("`@(VEF("@A87)R87E?
M:V5Y7V5X:7-T<R@G='EP92<L)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD
M=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4
M>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M75LG='EP92==(#T@)T%R<F%Y)SL*("`@("`@("`@("`@("`@("`@("`C?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`G86QL)SH*("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC
M;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP
M;&5X5'EP95U;)V]R9&5R)UT@/2`D<6YA;64M/FYA;64["B`@("`@("`@("`@
M("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)W1Y<&4G+"1T:&ES+3YW<V1L
M+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#
M;VUP;&5X5'EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N
M=$-O;7!L97A4>7!E75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=C
M:&]I8V4G.@H@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4
M>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M75LG;W)D97(G72`]("1Q;F%M92T^;F%M93L*("`@("`@("`@("`@("`@(&EF
M("@A87)R87E?:V5Y7V5X:7-T<R@G='EP92<L)'1H:7,M/G=S9&PM/F-O;7!L
M97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4
M>7!E72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M
M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE
M>%1Y<&5=6R=T>7!E)UT@/2`G07)R87DG.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!C87-E("=A='1R:6)U=&4G.@H@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3YS8VAE;6%3=&%T=7,@/3T@)V-O;7!L97A4>7!E)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<G-;)VYA;64G72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L
M97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4
M>7!E75LG871T<FEB=71E)UU;)&%T=')S6R=N86UE)UU=(#T@)&%T=')S.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS90H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D871T<G-;)W)E9B==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<2`])B!N97<@44YA;64H)&%T=')S6R=R968G72D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D:R`]/B`D
M=BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1K("$]("=R
M968G("8F('-T<G-T<B@D:RP@)'$M/FYA;64I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'9Q(#TF(&YE=R!13F%M92@D=BD["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1Q+3YN86UE(#T]("=A
M<G)A>51Y<&4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;
M)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)'$M/FYA;65=(#T@)'9Q+3YN
M86UE+B1V<2T^87)R87E);F9O.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS
M8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G
M07)R87DG.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES
M+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=N86UE<W!A8V4G72`]("1V<2T^;G,[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O
M;7!L97A4>7!E75LD<2T^;F%M95T@/2`D=G$M/FYA;64["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/G-C:&5M85]S
M=&%C:UM=(#T@)'%N86UE+3YN86UE.PH*("`@("`@("!B<F5A:SL*("`@("`@
M("!C87-E("=M97-S86=E)SH*("`@("`@("`@("`@+R\@<V5C="`R+C,@=W-D
M;#IM97-S86=E(&-H:6QD('=S9&PZ<&%R=`H@("`@("`@("`@("!S=VET8V@H
M)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@(&-A<V4@)W!A<G0G.@H@("`@
M("`@("`@("`@("`@)'%N(#T@3E5,3#L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D871T<G-;)W1Y<&4G72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<6X@/28@;F5W(%%.86UE*"1A='1R<ULG='EP92==*3L*("`@("`@("`@("`@
M("`@('T@96QS92!I9B`H:7-S970H)&%T=')S6R=E;&5M96YT)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D871T<G-;)V5L
M96UE;G0G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)'%N*2!["B`@("`@("`@("`@("`@("`@("`@)&%T=')S6R=T>7!E)UT@
M/2`D<6XM/FYA;64["B`@("`@("`@("`@("`@("`@("`@)&%T=')S6R=N86UE
M<W!A8V4G72`]("1Q;BT^;G,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D=&AI<RT^=W-D;"T^;65S<V%G97-;)'1H:7,M/F-U<G)E;G1-
M97-S86=E75LD871T<G-;)VYA;64G75T@/2`D871T<G,["B`@("`@("`@("`@
M("`@("`O+R!E<G)O<B!I;B!W<V1L"B`@("`@("`@("`@(&-A<V4@)V1O8W5M
M96YT871I;VXG.@H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@)W!O<G14>7!E)SH*("`@
M("`@("`@("`@+R\@<V5C="`R+C0*("`@("`@("`@("`@<W=I=&-H*"1Q;F%M
M92T^;F%M92D@>PH@("`@("`@("`@("!C87-E("=O<&5R871I;VXG.@H@("`@
M("`@("`@("`@("`@+R\@871T<FEB=71E<SH@;F%M90H@("`@("`@("`@("`@
M("`@+R\@8VAI;&1R96XZ('=S9&PZ:6YP=70@=W-D;#IO=71P=70@=W-D;#IF
M875L=`H@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1/<&5R871I;VX@
M/2`D871T<G-;)VYA;64G73L*("`@("`@("`@("`@("`@(",D=&AI<RT^=W-D
M;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC
M=7)R96YT3W!E<F%T:6]N75LG<&%R86UE=&5R3W)D97(G72`]("1A='1R<ULG
M<&%R86UE=&5R3W)D97(G73L*("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95U;)'1H:7,M/F-U
M<G)E;G1/<&5R871I;VY=(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)VEN<'5T)SH*("`@("`@("`@("`@8V%S
M92`G;W5T<'5T)SH*("`@("`@("`@("`@8V%S92`G9F%U;'0G.@H@("`@("`@
M("`@("`@("`@+R\@=W-D;#II;G!U="!W<V1L.F]U='!U="!W<V1L.F9A=6QT
M"B`@("`@("`@("`@("`@("`O+R!A='1R:6)U=&5S.B!N86UE(&UE<W-A9V4@
M<&%R86UE=&5R3W)D97(H;W!T:6]N86PI"B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/F-U<G)E;G1/<&5R871I;VXI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R
M<F5N=%!O<G14>7!E75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)&YA;65=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<&]R
M=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R96YT
M3W!E<F%T:6]N75LD;F%M95T@/2!A<G)A>5]M97)G92@D=&AI<RT^=W-D;"T^
M<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R
M96YT3W!E<F%T:6]N75LD;F%M95TL)&%T=')S*3L*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES
M+3YC=7)R96YT3W!E<F%T:6]N75LD;F%M95T@/2`D871T<G,["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"=M97-S86=E)RPD871T<G,I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1Q;B`])B!N97<@44YA;64H)&%T=')S6R=M97-S86=E)UTI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<&]R=%1Y
M<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R96YT3W!E
M<F%T:6]N75LD;F%M95U;)VUE<W-A9V4G72`]("1Q;BT^;F%M93L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI
M<RT^8W5R<F5N=%!O<G14>7!E75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;
M)&YA;65=6R=N86UE<W!A8V4G72`]("1Q;BT^;G,["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)V1O8W5M96YT871I;VXG.@H@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@(&)R96%K.PH@
M("`@("`@(&-A<V4@)V)I;F1I;F<G.@H@("`@("`@("`@("`D;G,@/2`D<6YA
M;64M/FYS(#\@)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)'%N86UE+3YN<UT@
M.B!30TA%34%?5U-$3#L*("`@("`@("`@("`@<W=I=&-H*"1N<RD@>PH@("`@
M("`@("`@("!C87-E(%-#2$5-05]33T%0.@H@("`@("`@("`@("`@("`@+R\@
M=&AI<R!D96%L<R!W:71H('=S9&P@<V5C=&EO;B`S('-O87`@8FEN9&EN9PH@
M("`@("`@("`@("`@("`@<W=I=&-H*"1Q;F%M92T^;F%M92D@>PH@("`@("`@
M("`@("`@("`@8V%S92`G8FEN9&EN9R<Z"B`@("`@("`@("`@("`@("`@("`@
M+R\@<V5C="`S+C,*("`@("`@("`@("`@("`@("`@("`O+R!S;V%P.F)I;F1I
M;F<L(&%T=')I8G5T97,Z('1R86YS<&]R="AR97%U:7)E9"DL('-T>6QE*&]P
M=&EO;F%L+"!D969A=6QT(#T@9&]C=6UE;G0I"B`@("`@("`@("`@("`@("`@
M("`@+R\@:68@<W1Y;&4@:7,@;6ES<VEN9RP@:70@:7,@87-S=6UE9"!T;R!B
M92`G9&]C=6UE;G0G"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M871T<G-;)W-T>6QE)UTI*2`D871T<G-;)W-T>6QE)UT@/2`G9&]C=6UE;G0G
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD
M=&AI<RT^8W5R<F5N=$)I;F1I;F==(#T@87)R87E?;65R9V4H)'1H:7,M/G=S
M9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UTL)&%T=')S*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@)V]P97)A=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`S
M+C0*("`@("`@("`@("`@("`@("`@("`O+R!S;V%P.F]P97)A=&EO;BP@871T
M<FEB=71E<SH@<V]A<$%C=&EO;BAR97%U:7)E9"DL('-T>6QE*&]P=&EO;F%L
M+"!D969A=6QT(#T@<V]A<#IB:6YD:6YG.G-T>6QE*0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&%T=')S6R=S='EL92==*2D@)&%T=')S6R=S
M='EL92==(#T@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT
M0FEN9&EN9UU;)W-T>6QE)UT["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)V]P97)A
M=&EO;G,G75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;ET@/2`D871T<G,["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M("=B;V1Y)SH*("`@("`@("`@("`@("`@("`@("`O+R!S96-T(#,N-0H@("`@
M("`@("`@("`@("`@("`@("\O('-O87`Z8F]D>2!A='1R:6)U=&5S.@H@("`@
M("`@("`@("`@("`@("`@("\O('!A<G0@+2!O<'1I;VYA;"X@(&QI<W1E9"!P
M87)T<R!M=7-T(&%P<&5A<B!I;B!B;V1Y+"!M:7-S:6YG(&UE86YS(&%L;"!P
M87)T<R!A<'!E87(@:6X@8F]D>0H@("`@("`@("`@("`@("`@("`@("\O('5S
M92`M(')E<75I<F5D+B!E;F-O9&5D?&QI=&5R86P*("`@("`@("`@("`@("`@
M("`@("`O+R!E;F-O9&EN9U-T>6QE("T@;W!T:6]N86PN("!S<&%C92!S97!E
M<F%T960@;&ES="!O9B!E;F-O9&EN9W,@*'5R:2=S*0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I
M;F1I;F=="B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LG
M;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LD=&AI<RT^
M;W!3=&%T=7-=(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@8V%S92`G9F%U;'0G.@H@("`@("`@("`@("`@
M("`@("`@("\O('-E8W0@,RXV"B`@("`@("`@("`@("`@("`@("`@+R\@<V]A
M<#IF875L="!A='1R:6)U=&5S.B!N86UE('5S92`@96YC;V1I;F=3='EL92!N
M86UE<W!A8V4*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN
M9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG70H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!;)V]P97)A=&EO;G,G75LD=&AI<RT^8W5R
M<F5N=$]P97)A=&EO;EU;)'1H:7,M/F]P4W1A='5S72`]("1A='1R<SL*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@
M)VAE861E<B<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`S+C<*("`@
M("`@("`@("`@("`@("`@("`O+R!S;V%P.FAE861E<B!A='1R:6)U=&5S.B!M
M97-S86=E('!A<G0@=7-E(&5N8V]D:6YG4W1Y;&4@;F%M97-P86-E"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC
M=7)R96YT0FEN9&EN9UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6R=O<&5R871I;VYS)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=
M6R1T:&ES+3YO<%-T871U<UU;)VAE861E<G,G75M=(#T@)&%T=')S.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G
M:&5A9&5R9F%U;'0G.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@,RXW
M"B`@("`@("`@("`@("`@("`@("`@+R\@<V]A<#IH96%D97(@871T<FEB=71E
M<SH@;65S<V%G92!P87)T('5S92!E;F-O9&EN9U-T>6QE(&YA;65S<&%C90H@
M("`@("`@("`@("`@("`@("`@("1H96%D97(@/2!C;W5N="@D=&AI<RT^=W-D
M;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG70H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!;)V]P97)A=&EO;G,G75LD=&AI
M<RT^8W5R<F5N=$]P97)A=&EO;EU;)'1H:7,M/F]P4W1A='5S75LG:&5A9&5R
M<R==*2TQ.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD
M:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F=="B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%LG;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R
M96YT3W!E<F%T:6]N75LD=&AI<RT^;W!3=&%T=7-=6R=H96%D97)S)UU;)&AE
M861E<EU;)V9A=6QT)UT@/2`D871T<G,["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!C87-E("=D;V-U;65N=&%T:6]N)SH*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@+R\@97)R;W(A("!N;W0@82!V
M86QI9"!E;&5M96YT(&EN<VED92!B:6YD:6YG"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@8V%S92!30TA%34%?5U-$3#H*("`@("`@("`@
M("`@("`@("\O(%A86"!V97)I9GD@8V]R<F5C="!N86UE<W!A8V4*("`@("`@
M("`@("`@("`@("\O(&9O<B!N;W<L(&1E9F%U;'0@:7,@=&AE("=W<V1L)R!N
M86UE<W!A8V4*("`@("`@("`@("`@("`@("\O(&]T:&5R('!O<W-I8FQE(&YA
M;65S<&%C97,@:6YC;'5D92!S;71P+"!H='1P+"!E=&,N(&9O<B!A;'1E<FYA
M=&4@8FEN9&EN9W,*("`@("`@("`@("`@("`@('-W:71C:"@D<6YA;64M/FYA
M;64I('L*("`@("`@("`@("`@("`@(&-A<V4@)V]P97)A=&EO;B<Z"B`@("`@
M("`@("`@("`@("`@("`@+R\@<V5C="`R+C4*("`@("`@("`@("`@("`@("`@
M("`O+R!W<V1L.F]P97)A=&EO;B!A='1R:6)U=&5S.B!N86UE"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1/<&5R871I;VX@/2`D871T<G-;
M)VYA;64G73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@)V]U='!U="<Z"B`@("`@("`@("`@("`@("!C87-E("=I
M;G!U="<Z"B`@("`@("`@("`@("`@("!C87-E("=F875L="<Z"B`@("`@("`@
M("`@("`@("`@("`@+R\@<V5C="`R+C4*("`@("`@("`@("`@("`@("`@("`O
M+R!W<V1L.FEN<'5T(&%T=')I8G5T97,Z(&YA;64*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;W!3=&%T=7,@/2`D<6YA;64M/FYA;64["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("=D;V-U
M;65N=&%T:6]N)SH*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@8V%S92!30TA%34%?5U-$3%](5%10.@H@("`@("`@("`@("`@
M("`@<W=I=&-H*"1Q;F%M92T^;F%M92D@>PH@("`@("`@("`@("`@("`@8V%S
M92`G8FEN9&EN9R<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`T+C0*
M("`@("`@("`@("`@("`@("`@("`O+R!H='1P.F)I;F1I;F<@871T<FEB=71E
M<SH@=F5R8@H@("`@("`@("`@("`@("`@("`@("\O('!A<F5N=#H@=W-D;#IB
M:6YD:6YG"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I
M;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UT@/2!A<G)A>5]M97)G92@D=&AI
M<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG72PD871T
M<G,I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@8V%S92`G;W!E<F%T:6]N)SH*("`@("`@("`@("`@("`@("`@("`O+R!S
M96-T(#0N-0H@("`@("`@("`@("`@("`@("`@("\O(&AT='`Z;W!E<F%T:6]N
M(&%T=')I8G5T97,Z(&QO8V%T:6]N"B`@("`@("`@("`@("`@("`@("`@+R\@
M<&%R96YT.B!W<V1L.F]P97)A=&EO;@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O
M<&5R871I;VYS)UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!;)'1H:7,M/F-U<G)E;G1/<&5R871I
M;VY=(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`G=7)L16YC;V1E9"<Z"B`@("`@("`@("`@("`@
M("`@("`@+R\@<V5C="`T+C8*("`@("`@("`@("`@("`@("`@("`O+R!H='1P
M.G5R;$5N8V]D960@871T<FEB=71E<SH@;&]C871I;VX*("`@("`@("`@("`@
M("`@("`@("`O+R!P87)E;G0Z('=S9&PZ:6YP=70@=W-D;#IO=71P=70@971C
M+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD
M=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I;VYS)UU;)'1H:7,M/F]P
M4W1A='5S70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;
M)W5R:2==(#T@)W5R;$5N8V]D960G.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`G=7)L4F5P;&%C96UE;G0G.@H@
M("`@("`@("`@("`@("`@("`@("\O('-E8W0@-"XW"B`@("`@("`@("`@("`@
M("`@("`@+R\@:'1T<#IU<FQ297!L86-E;65N="!A='1R:6)U=&5S.B!L;V-A
M=&EO;@H@("`@("`@("`@("`@("`@("`@("\O('!A<F5N=#H@=W-D;#II;G!U
M="!W<V1L.F]U='!U="!E=&,N"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)V]P97)A
M=&EO;G,G75LD=&AI<RT^;W!3=&%T=7-="B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R1T:&ES+3YC
M=7)R96YT3W!E<F%T:6]N75LG=7)I)UT@/2`G=7)L4F5P;&%C96UE;G0G.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S
M92`G9&]C=6UE;G1A=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@
M("\O(&5R<F]R"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&-A<V4@4T-(14U!7TU)344Z"B`@("`@
M("`@("`@("`@("`O+R!S96-T(#4*("`@("`@("`@("`@("`@("\O(&%L;"!M
M:6UE('!A<G1S(&%R92!C:&EL9')E;B!O9B!W<V1L.FEN<'5T+"!W<V1L.F]U
M='!U="P@971C+@H@("`@("`@("`@("`@("`@+R\@=6YS=7!O<G1E9"!A<R!O
M9B!Y970*("`@("`@("`@("`@("`@('-W:71C:"@D<6YA;64M/FYA;64I('L*
M("`@("`@("`@("`@("`@(&-A<V4@)V-O;G1E;G0G.@H@("`@("`@("`@("`@
M("`@("`@("\O('-E8W0@-2XS(&UI;64Z8V]N=&5N=`H@("`@("`@("`@("`@
M("`@("`@("\O(#QM:6UE.F-O;G1E;G0@<&%R=#TB;FUT;VME;B(_('1Y<&4]
M(G-T<FEN9R(_+SX*("`@("`@("`@("`@("`@("`@("`O+R!P87)T(&%T=')I
M8G5T92!O;FQY(')E<75I<F5D(&EF(&-O;G1E;G0@:7,@8VAI;&0@;V8@;75L
M=&EP87)T(')E;&%T960L"B`@("`@("`@("`@("`@("`@("`@+R\@("`@("`@
M(&ET(&-O;G1A:6YS('1H92!N86UE(&]F('1H92!P87)T"B`@("`@("`@("`@
M("`@("`@("`@+R\@='EP92!A='1R:6)U=&4@8V]N=&%I;G,@=&AE(&UI;64@
M='EP90H@("`@("`@("`@("`@("`@8V%S92`G;75L=&EP87)T4F5L871E9"<Z
M"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`U+C0@;6EM93IM=6QT:7!A
M<G1296QA=&5D"B`@("`@("`@("`@("`@("!C87-E("=P87)T)SH*("`@("`@
M("`@("`@("`@(&-A<V4@)VUI;658;6PG.@H@("`@("`@("`@("`@("`@("`@
M("\O('-E8W0@-2XV(&UI;64Z;6EM95AM;`H@("`@("`@("`@("`@("`@("`@
M("\O(#QM:6UE.FUI;658;6P@<&%R=#TB;FUT;VME;B(_+SX*("`@("`@("`@
M("`@("`@("`@("`O+PH@("`@("`@("`@("`@("`@8V%S92`G9&]C=6UE;G1A
M=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("\O(&5R<F]R"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&-A<V4@4T-(14U!7T1)344Z"B`@("`@("`@("`@("`@("`O
M+R!$24U%(&ES(&1E9FEN960@:6XZ"B`@("`@("`@("`@("`@("`O+R!H='1P
M.B\O9V]T9&]T;F5T+F-O;2]T96%M+WAM;%]W<W-P96-S+V1I;64O5U-$3"U%
M>'1E;G-I;VXM9F]R+41)344N:'1M"B`@("`@("`@("`@("`@("`O+R!A;&P@
M1$E-12!P87)T<R!A<F4@8VAI;&1R96X@;V8@=W-D;#II;G!U="P@=W-D;#IO
M=71P=70L(&5T8RX*("`@("`@("`@("`@("`@("\O('5N<W5P;W)T960@87,@
M;V8@>65T"B`@("`@("`@("`@("`@("!S=VET8V@H)'%N86UE+3YN86UE*2![
M"B`@("`@("`@("`@("`@("!C87-E("=M97-S86=E)SH*("`@("`@("`@("`@
M("`@("`@("`O+R!S96-T(#0N,2!D:6UE.FUE<W-A9V4*("`@("`@("`@("`@
M("`@("`@("`O+R!A<'!E87)S(&EN(&)I;F1I;F<@<V5C=&EO;@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R
M<F5N=$)I;F1I;F==6R=D:6UE)UT@/2`D871T<G,["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@('T*("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=S97)V:6-E)SH*
M("`@("`@("`@("`@)&YS(#T@)'%N86UE+3YN<R`_("1T:&ES+3YW<V1L+3YN
M86UE<W!A8V5S6R1Q;F%M92T^;G-=(#H@4T-(14U!7U=31$P["@H@("`@("`@
M("`@("!S=VET8V@H)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@(&-A<V4@
M)W!O<G0G.@H@("`@("`@("`@("`@("`@+R\@<V5C="`R+C8@=W-D;#IP;W)T
M(&%T=')I8G5T97,Z(&YA;64@8FEN9&EN9PH@("`@("`@("`@("`@("`@)'1H
M:7,M/F-U<G)E;G10;W)T(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U<G)E;G1397)V
M:6-E75LG<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=(#T@)&%T=')S.PH@
M("`@("`@("`@("`@("`@+R\@6%A8(&AA8VL@=&\@9&5A;"!W:71H(&)I;F1I
M;F<@;F%M97-P86-E<PH@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M
M92@D871T<G-;)V)I;F1I;F<G72D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U<G)E;G1397)V:6-E75LG<&]R=',G
M75LD=&AI<RT^8W5R<F5N=%!O<G1=6R=B:6YD:6YG)UT@/2`D<6XM/FYA;64[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M
M/F-U<G)E;G1397)V:6-E75LG<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=
M6R=N86UE<W!A8V4G72`]("1Q;BT^;G,["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E("=A9&1R97-S)SH*("`@("`@("`@("`@("`@("1T
M:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N=%-E<G9I8V5=6R=P
M;W)T<R==6R1T:&ES+3YC=7)R96YT4&]R=%U;)V%D9')E<W,G72`]("1A='1R
M<SL*("`@("`@("`@("`@("`@("\O('=H870@5%E012!O9B!P;W)T(&ES(&ET
M/R`@4T]!4"!O<B!(5%10/PH@("`@("`@("`@("`@("`@)&YS(#T@)'%N86UE
M+3YN<R`_("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R1Q;F%M92T^;G-=(#H@
M4T-(14U!7U=31$P["B`@("`@("`@("`@("`@("!S=VET8V@H)&YS*2!["B`@
M("`@("`@("`@("`@("!C87-E(%-#2$5-05]74T1,7TA45%`Z"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC=7)R
M96YT4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T75LG='EP
M92==/2=H='1P)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@(&-A<V4@4T-(14U!7U-/05`Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC=7)R96YT4V5R=FEC
M95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T75LG='EP92==/2=S;V%P
M)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@+R\@<VAO=6QD;B=T(&AA
M<'!E;BP@=V4G;&P@87-S=6UE('-O87`*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U<G)E;G1397)V:6-E75LG
M<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=6R=T>7!E)UT])W-O87`G.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@(&-A<V4@)V1O8W5M96YT871I;VXG.@H@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@=&]P(&QE
M=F5L(&5L96UE;G1S(&9O=6YD('5N9&5R('=S9&PZ9&5F:6YI=&EO;G,*("`@
M("`@("`O+R!S970@<W1A='5S"B`@("`@("`@<W=I=&-H*"1Q;F%M92T^;F%M
M92D@>PH@("`@("`@(&-A<V4@)VEM<&]R="<Z"B`@("`@("`@("`@("\O('-E
M8W0@,BXQ+C$@=W-D;#II;7!O<G0@871T<FEB=71E<SH@;F%M97-P86-E(&QO
M8V%T:6]N"B`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=L;V-A
M=&EO;B<L)&%T=')S*2`F)@H@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES
M+3YW<V1L+3YI;7!O<G1S6R1A='1R<ULG;F%M97-P86-E)UU=*2D@>PH@("`@
M("`@("`@("`@("`@)'5R:2`]("1A='1R<ULG;&]C871I;VXG73L*("`@("`@
M("`@("`@("`@("1L;V-A=&EO;B`]('!A<G-E7W5R;"@D=7)I*3L*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&QO8V%T:6]N6R=S8VAE;64G72DI('L*
M("`@("`@("`@("`@("`@("`@("`D8F%S92`]('!A<G-E7W5R;"@D=&AI<RT^
M=7)I*3L*("`@("`@("`@("`@("`@("`@("`D=7)I(#T@)'1H:7,M/FUE<F=E
M7W5R;"@D8F%S92PD=7)I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1I;7!O<G1?<&%R<V5R(#TF(&YE=R!33T%07U=31$Q?4&%R<V5R
M*"1U<FDL("1T:&ES+3YW<V1L*3L*("`@("`@("`@("`@("`@(&EF("@D:6UP
M;W)T7W!A<G-E<BT^9F%U;'0I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@1D%,4T4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=&AI<RT^8W5R<F5N=$EM<&]R="`]("1A='1R<ULG;F%M97-P86-E)UT["B`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^:6UP;W)T<ULD=&AI<RT^8W5R
M<F5N=$EM<&]R=%T@/2`D871T<G,["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/G-T871U<R`]("<G.PH@("`@("`@(&-A<V4@)W1Y<&5S)SH*
M("`@("`@("`@("`@+R\@<V5C="`R+C(@=W-D;#IT>7!E<PH@("`@("`@("`@
M("`D=&AI<RT^<W1A='5S(#T@)W1Y<&5S)SL*("`@("`@("!B<F5A:SL*("`@
M("`@("!C87-E("=M97-S86=E)SH*("`@("`@("`@("`@+R\@<V5C="`R+C,@
M=W-D;#IM97-S86=E(&%T=')I8G5T97,Z(&YA;64@8VAI;&1R96XZ=W-D;#IP
M87)T"B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G;65S<V%G92<["B`@
M("`@("`@("`@(&EF("AI<W-E="@D871T<G-;)VYA;64G72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YC=7)R96YT365S<V%G92`]("1A='1R<ULG;F%M
M92==.PH@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/FUE<W-A9V5S6R1T
M:&ES+3YC=7)R96YT365S<V%G95T@/2!A<G)A>2@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G<&]R=%1Y<&4G.@H@("`@
M("`@("`@("`O+R!S96-T(#(N-"!W<V1L.G!O<G14>7!E"B`@("`@("`@("`@
M("\O(&%T=')I8G5T97,Z(&YA;64*("`@("`@("`@("`@+R\@8VAI;&1R96XZ
M('=S9&PZ;W!E<F%T:6]N"B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G
M<&]R=%1Y<&4G.PH@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%!O<G14>7!E
M(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YP
M;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95T@/2!A<G)A>2@I.PH@
M("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@)V)I;F1I;F<G.@H@("`@("`@
M("`@("`O+R!S96-T(#(N-2!W<V1L.F)I;F1I;F<@871T<FEB=71E<SH@;F%M
M92!T>7!E"B`@("`@("`@("`@("\O(&-H:6QD<F5N.B!W<V1L.F]P97)A=&EO
M;B!S;V%P.F)I;F1I;F<@:'1T<#IB:6YD:6YG"B`@("`@("`@("`@(&EF("@D
M<6YA;64M/FYS("8F("1Q;F%M92T^;G,@(3T@)'1H:7,M/G1N<RD@8G)E86L[
M"B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G8FEN9&EN9R<["B`@("`@
M("`@("`@("1T:&ES+3YC=7)R96YT0FEN9&EN9R`]("1A='1R<ULG;F%M92==
M.PH@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R<ULG='EP92==
M*3L*("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC
M=7)R96YT0FEN9&EN9UU;)W1Y<&4G72`]("1Q;BT^;F%M93L*("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN
M9UU;)VYA;65S<&%C92==(#T@)'%N+3YN<SL*("`@("`@("!B<F5A:SL*("`@
M("`@("!C87-E("=S97)V:6-E)SH*("`@("`@("`@("`@+R\@<V5C="`R+C<@
M=W-D;#IS97)V:6-E(&%T=')I8G5T97,Z(&YA;64@8VAI;&1R96XZ('!O<G1S
M"B`@("`@("`@("`@("1T:&ES+3YC=7)R96YT4V5R=FEC92`]("1A='1R<ULG
M;F%M92==.PH@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H
M:7,M/F-U<G)E;G1397)V:6-E75LG<&]R=',G72`](&%R<F%Y*"D["B`@("`@
M("`@("`@("1T:&ES+3YS=&%T=7,@/2`G<V5R=FEC92<["B`@("`@("`@8G)E
M86L["B`@("`@("`@8V%S92`G9&5F:6YI=&EO;G,G.@H@("`@("`@("`@("`O
M+R!S96,@,BXQ('=S9&PZ9&5F:6YI=&EO;G,*("`@("`@("`@("`@+R\@871T
M<FEB=71E<SH@;F%M92!T87)G971.86UE<W!A8V4@>&UL;G,Z*@H@("`@("`@
M("`@("`O+R!C:&EL9')E;CH@=W-D;#II;7!O<G0@=W-D;#IT>7!E<R!W<V1L
M.FUE<W-A9V4@=W-D;#IP;W)T5'EP92!W<V1L.F)I;F1I;F<@=W-D;#IS97)V
M:6-E"B`@("`@("`@("`@(",D=&AI<RT^<W1A='5S(#T@)V1E9FEN:71I;VYS
M)SL*("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F1E9FEN:71I;VX@/2`D871T
M<G,["B`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D:V5Y(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D:V5Y+"=X;6QN
M<SHG*2`A/3T@1D%,4T4I('L*("`@("`@("`@("`@("`@("`@("`D<6X@/28@
M;F5W(%%.86UE*"1K97DI.PH@("`@("`@("`@("`@("`@("`@("\O(%A86"!N
M965D('1O(')E9F%C=&]R(&YS(&AA;F1L:6YG"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)'%N+3YN86UE72`]("1V86QU
M93L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^;G-;)'9A;'5E
M72`]("1Q;BT^;F%M93L*("`@("`@("`@("`@("`@("`@("!I9B`H)&ME>2`]
M/2`G=&%R9V5T3F%M97-P86-E)R!\?`H@("`@("`@("`@("`@("`@("`@("`@
M("!S=')C87-E8VUP*"1V86QU92Q33T%07U-#2$5-02D@/3T@,"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V]A<&YS6UT@/2`D<6XM/FYA
M;64["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1V86QU92P@)'1H:7,M/E]834Q3
M8VAE;6$I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^>'-D(#T@)'9A;'5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D;G,I("8F("1N<RD@
M>PH@("`@("`@("`@("`@("`@)&YA;65S<&%C92`]("=X;6QN<SHG+B1N<SL*
M("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/G=S9&PM/F1E9FEN:71I;VY;
M)&YA;65S<&%C95TI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@B<&%R<V4@97)R;W(L(&YO(&YA;65S<&%C
M92!F;W(@)&YA;65S<&%C92(L)'1H:7,M/G5R:2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^=&YS(#T@)&YS.PH@("`@("`@
M("`@("!]"B`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*"B`@("`O
M+R!E;F0M96QE;65N="!H86YD;&5R"B`@("!F=6YC=&EO;B!E;F1%;&5M96YT
M*"1P87)S97(L("1N86UE*0H@("`@>PH@("`@("`@("1S=&%C:W-I>F4@/2!C
M;W5N="@D=&AI<RT^96QE;65N=%]S=&%C:RD["B`@("`@("`@:68@*"1S=&%C
M:W-I>F4@/B`P*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^96QE;65N=%]S
M=&%C:UMC;W5N="@D=&AI<RT^96QE;65N=%]S=&%C:RDM,5T@/3T@("=D969I
M;FET:6]N<R<I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G)A>5]P;W`H)'1H:7,M
M/F5L96UE;G1?<W1A8VLI.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R:7-T
M<B@D;F%M92PG<V-H96UA)RDI('L*("`@("`@("`@("`@87)R87E?<&]P*"1T
M:&ES+3YS8VAE;6%?<W1A8VLI.PH@("`@("`@("`@("`D=&AI<RT^<V-H96UA
M(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^<V-H96UA*2![
M"B`@("`@("`@("`@(&%R<F%Y7W!O<"@D=&AI<RT^<V-H96UA7W-T86-K*3L*
M("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YS8VAE;6%?<W1A8VLI(#P]
M(#$I('L*("`@("`@("`@("`@("`@("\J(&-O<G)E8W0@=&AE('1Y<&4@9F]R
M('-E<75E;F-E<R!W:71H(&UU;'1I<&QE(&5L96UE;G1S("HO"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP92D@
M)B8@:7-S970H)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H
M96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==*0H@("`@
M("`@("`@("`@("`@("`@("8F("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;
M)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)W1Y
M<&4G72`]/2`G07)R87DG"B`@("`@("`@("`@("`@("`@("`@)B8@87)R87E?
M:V5Y7V5X:7-T<R@G96QE;65N=',G+"1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP
M97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95TI
M"B`@("`@("`@("`@("`@("`@("`@)B8@8V]U;G0H)'1H:7,M/G=S9&PM/F-O
M;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L
M97A4>7!E75LG96QE;65N=',G72D@/B`Q*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M
M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G72`]("=3=')U
M8W0G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("AS=')I<W1R*"1N86UE+"=C;VUP;&5X5'EP92<I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E(#T@)R<["B`@
M("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/G-C:&5M85]E;&5M96YT
M7W-T86-K*2`^(#`I"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E
M;G1%;&5M96YT(#T@87)R87E?<&]P*"1T:&ES+3YS8VAE;6%?96QE;65N=%]S
M=&%C:RD["B`@("`@("`@("`@("`@("!E;'-E"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-U<G)E;G1%;&5M96YT(#T@)R<["B`@("`@("`@("`@('T@
M96QS92!I9B`H<W1R:7-T<B@D;F%M92PG96QE;65N="<I*2!["B`@("`@("`@
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/G-C:&5M85]E;&5M96YT7W-T86-K
M*2`^(#`I"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1%;&5M
M96YT(#T@87)R87E?<&]P*"1T:&ES+3YS8VAE;6%?96QE;65N=%]S=&%C:RD[
M"B`@("`@("`@("`@("`@("!E;'-E"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F-U<G)E;G1%;&5M96YT(#T@)R<["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@+R\@<&]S:71I;VX@;V8@8W5R<F5N="!E;&5M96YT(&ES
M(&5Q=6%L('1O('1H92!L87-T('9A;'5E(&QE9G0@:6X@9&5P=&A?87)R87D@
M9F]R(&UY(&1E<'1H"B`@("`@("`@+R\D<&]S(#T@)'1H:7,M/F1E<'1H7V%R
M<F%Y6R1T:&ES+3YD97!T:%T["B`@("`@("`@+R\@8G)I;F<@9&5P=&@@9&]W
M;B!A(&YO=&-H"B`@("`@("`@+R\D=&AI<RT^9&5P=&@M+3L*("`@('T*"B`@
M("`O+R!E;&5M96YT(&-O;G1E;G0@:&%N9&QE<@H@("`@9G5N8W1I;VX@8VAA
M<F%C=&5R1&%T82@D<&%R<V5R+"`D9&%T82D*("`@('L*("`@("`@("`C('-T
M;W)E('1H92!D;V-U;65N=&%T:6]N(&EN('1H92!74T1,(&9I;&4*("`@("`@
M("!I9B`H)'1H:7,M/F-U<G)E;G1486<@/3T@)V1O8W5M96YT871I;VXG*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^<W1A='5S(#T]("`G<V5R=FEC92<I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI
M<RT^8W5R<F5N=%-E<G9I8V5=6R1T:&ES+3YC=7)R96YT5&%G72`N/2`D9&%T
M83L*("`@("`@("`@("`@?2!E;'-E(&EF("@D=&AI<RT^<W1A='5S(#T]("`G
M<&]R=%1Y<&4G*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/G=S9&PM
M/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14>7!E75LD=&AI<RT^8W5R
M<F5N=$]P97)A=&EO;EU;)'1H:7,M/F-U<G)E;G1486==*0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E
M;G10;W)T5'EP95U;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1T:&ES+3YC
M=7)R96YT5&%G72`N/2!D871A.PH@("`@("`@("`@("`@("`@96QS90H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M
M/F-U<G)E;G10;W)T5'EP95U;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1T
M:&ES+3YC=7)R96YT5&%G72`](&1A=&$["B`@("`@("`@("`@('T@96QS92!I
M9B`H)'1H:7,M/G-T871U<R`]/2`@)V)I;F1I;F<G*2!["B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT
M0FEN9&EN9UU;)'1H:7,M/F-U<G)E;G1486==*0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I
M;F==6R1T:&ES+3YC=7)R96YT5&%G72`N/2!D871A.PH@("`@("`@("`@("`@
M("`@96QS90H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD
M:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R1T:&ES+3YC=7)R96YT5&%G
M72`](&1A=&$["B`@("`@("`@("`@('T@96QS92!I9B`H)'1H:7,M/G-T871U
M<R`]/2`@)VUE<W-A9V4G*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/G=S9&PM/FUE<W-A9V5S6R1T:&ES+3YC=7)R96YT365S<V%G95U;)'1H:7,M
M/F-U<G)E;G1486==*0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YM97-S86=E<ULD=&AI<RT^8W5R<F5N=$UE<W-A9V5=6R1T:&ES+3YC=7)R
M96YT5&%G72`N/2!D871A.PH@("`@("`@("`@("`@("`@96QS90H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YM97-S86=E<ULD=&AI<RT^8W5R
M<F5N=$UE<W-A9V5=6R1T:&ES+3YC=7)R96YT5&%G72`](&1A=&$["B`@("`@
M("`@("`@('T@96QS92!I9B`H)'1H:7,M/G-T871U<R`]/2`@)V]P97)A=&EO
M;B<I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^=W-D;"T^<&]R=%1Y
M<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R96YT3W!E
M<F%T:6]N75LD=&AI<RT^8W5R<F5N=%1A9UTI"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14
M>7!E75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)'1H:7,M/F-U<G)E;G14
M86==("X](&1A=&$["B`@("`@("`@("`@("`@("!E;'-E"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N
M=%!O<G14>7!E75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)'1H:7,M/F-U
M<G)E;G1486==(#T@9&%T83L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"@H@("`@+R\@)'!A<G-E9"!I<R!A('!A<G-E7W5R;"@I(')E<W5L=&EN
M9R!A<G)A>0H@("`@9G5N8W1I;VX@;65R9V5?=7)L*"1P87)S960L)'!A=&@I
M('L*"B`@("`@("`@:68@*"$@:7-?87)R87DH)'!A<G-E9"DI(')E='5R;B!F
M86QS93L*"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)W-C:&5M92==*2D@
M>PH@("`@("`@("`@("`D<V5P(#T@*'-T<G1O;&]W97(H)'!A<G-E9%LG<V-H
M96UE)UTI(#T]("=M86EL=&\G(#\@)SHG(#H@)SHO+R<I.PH@("`@("`@("`@
M("`D=7)I(#T@)'!A<G-E9%LG<V-H96UE)UT@+B`D<V5P.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1U<FD@/2`G)SL*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D<&%R<V5D6R=P87-S)UTI*2!["B`@("`@("`@("`@
M("1U<FD@+CT@(B1P87)S961;=7-E<ETZ)'!A<G-E9%MP87-S74`B.PH@("`@
M("`@('T@96QS96EF("AI<W-E="@D<&%R<V5D6R=U<V5R)UTI*2!["B`@("`@
M("`@("`@("1U<FD@+CT@(B1P87)S961;=7-E<EU`(CL*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=H;W-T)UTI*2`@("`@)'5R:2`N
M/2`D<&%R<V5D6R=H;W-T)UT["B`@("`@("`@:68@*&ES<V5T*"1P87)S961;
M)W!O<G0G72DI("`@("`D=7)I("X]("(Z)'!A<G-E9%MP;W)T72(["B`@("`@
M("`@:68@*"1P871H6S!=(3TG+R<@)B8@:7-S970H)'!A<G-E9%LG<&%T:"==
M*2D@>PH@("`@("`@("`@("!I9B`H)'!A<G-E9%LG<&%T:"==6W-T<FQE;B@D
M<&%R<V5D6R=P871H)UTI+3%=("$]("<O)RD@>PH@("`@("`@("`@("`@("`@
M)'!A=&@@/2!D:7)N86UE*"1P87)S961;)W!A=&@G72DN)R\G+B1P871H.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!A=&@@/2`D
M<&%R<V5D6R=P871H)UTN)'!A=&@["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'!A=&@@/2`D=&AI<RT^7VYO<FUA;&EZ92@D<&%T:"D["B`@("`@("`@
M?0H@("`@("`@("1S97`@/2`D<&%T:%LP73T])R\G/R<G.B<O)SL*("`@("`@
M("`D=7)I("X]("1S97`N)'!A=&@["@H@("`@("`@(')E='5R;B`D=7)I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]N;W)M86QI>F4H)'!A=&A?<W1R*7L*("`@
M("`@("`D<'=D/2<G.PH@("`@("`@("1S=')!<G(]<')E9U]S<&QI="@B+RA<
M+RDO(BPD<&%T:%]S='(L+3$L4%)%1U]34$Q)5%].3U]%35!462D["B`@("`@
M("`@)'!W9$%R<CTB(CL*("`@("`@("`D:CTP.PH@("`@("`@(&9O<B@D:3TP
M.R1I/&-O=6YT*"1S=')!<G(I.R1I*RLI>PH@("`@("`@("`@("!I9B@D<W1R
M07)R6R1I72$](BXN(BE["B`@("`@("`@("`@("`@("!I9B@D<W1R07)R6R1I
M72$](BXB*7L*("`@("`@("`@("`@("`@("1P=V1!<G);)&I=/21S=')!<G);
M)&E=.PH@("`@("`@("`@("`@("`@)&HK*SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?65L<V5["B`@("`@("`@("`@("`@("!A<G)A>5]P;W`H
M)'!W9$%R<BD["B`@("`@("`@("`@("`@("`D:BTM.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@("1P4W1R/6EM<&QO9&4H(B\B+"1P=V1!<G(I
M.PH@("`@("`@("1P=V0]*'-T<FQE;B@D<%-T<BD^,"D@/R`H(B\B+B1P4W1R
M*2`Z("(O(CL*("`@("`@("!R971U<FX@)'!W9#L*("`@('T*?0H*+RHJ"B`J
M(%!A<G-E<R!T:&4@='EP97,@86YD(&UE=&AO9',@=7-E9"!I;B!W96(@<V5R
M=FEC92!O8FIE8W1S(&EN=&\@=&AE(&EN=&5R;F%L"B`J(&1A=&$@<W1R=6-T
M=7)E<R!U<V5D(&)Y(%-/05!?5U-$3"X*("H*("H@07-S=6UE<R!T:&4@4T]!
M4%]74T1,(&-L87-S(&ES('5N<&]P=6QA=&5D('1O('-T87)T('=I=&@N"B`J
M"B`J($!A=71H;W(@0VAR:7,@0V]E(#QI;F9O0&EN=&5L;&EG96YT<W1R96%M
M:6YG+F-O;3X*("HO"F-L87-S(%-/05!?5U-$3%]/8FIE8W1087)S97(@97AT
M96YD<R!33T%07T)A<V4*>PH@("`@+R\@5&%R9V5T(&YA;65S<&%C92!F;W(@
M=&AE(%=31$P@9&]C=6UE;G0@=VEL;"!H879E('1H92!F;VQL;W=I;F<@<')E
M9FEX"B`@("!V87(@)'1N<U!R969I>"`]("=T;G,G.PH*("`@("\O(%)E9F5R
M96YC92!T;R!T:&4@4T]!4%]74T1,(&]B:F5C="!T;R!P;W!U;&%T90H@("`@
M=F%R("1W<V1L(#T@;G5L;#L*"B`@("`O*BH@0V]N<W1R=6-T;W(*("`@("`J
M"B`@("`@*B!`<&%R86T@("1O8FIE8W1S(%)E9F5R96YC92!T;R!T:&4@;V)J
M96-T(&]R(&%R<F%Y(&]F(&]B:F5C=',@=&\@<&%R<V4*("`@("`J($!P87)A
M;2`@)'=S9&P@4F5F97)E;F-E('1O('1H92!33T%07U=31$P@;V)J96-T('1O
M('!O<'5L871E"B`@("`@*B!`<&%R86T@("1T87)G971.86UE<W!A8V4@5&AE
M('1A<F=E="!N86UE<W!A8V4@;V8@<V-H96UA('1Y<&5S(&5T8RX*("`@("`J
M($!P87)A;2`@)'-E<G9I8V5?;F%M92!.86UE(&]F('1H92!74T1,(#QS97)V
M:6-E/@H@("`@("H@0'!A<F%M("`D<V5R=FEC95]D97-C($]P=&EO;F%L(&1E
M<V-R:7!T:6]N(&]F('1H92!74T1,(#QS97)V:6-E/@H@("`@("HO"B`@("!F
M=6YC=&EO;B!33T%07U=31$Q?3V)J96-T4&%R<V5R*"8D;V)J96-T<RP@)B1W
M<V1L+"`D=&%R9V5T3F%M97-P86-E+"`D<V5R=FEC95]N86UE+"`D<V5R=FEC
M95]D97-C(#T@)R<I('L*("`@("`@("!P87)E;G0Z.E-/05!?0F%S92@G5U-$
M3$]"2D5#5%!!4E-%4B<I.PH*("`@("`@("`D=&AI<RT^=W-D;"`]("8D=W-D
M;#L*"B`@("`@("`@+R\@4V5T('5P('1H92!33T%07U=31$P@;V)J96-T"B`@
M("`@("`@)'1H:7,M/E]I;FET:6%L:7-E*"1S97)V:6-E7VYA;64I.PH*("`@
M("`@("`O+R!087)S92!E86-H('=E8B!S97)V:6-E(&]B:F5C=`H@("`@("`@
M("1W<V1L7W)E9B`]("AI<U]A<G)A>2@D;V)J96-T<RD_("1O8FIE8W1S(#H@
M87)R87DH)B1O8FIE8W1S*2D["@H@("`@("`@(&9O<F5A8V@@*"1W<V1L7W)E
M9B!A<R`D<F5F7VET96TI('L*("`@("`@("`@("`@:68@*"%I<U]O8FIE8W0H
M)')E9E]I=&5M*2D*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"=);G9A;&ED('=E8B!S97)V:6-E(&]B:F5C="!P87-S
M960@=&\@;V)J96-T('!A<G-E<B<L("=U<FXZ)R`N(&=E=%]C;&%S<R@D;V)J
M96-T*2D["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]P87)S92@D<F5F7VET
M96TL("1T87)G971.86UE<W!A8V4L("1S97)V:6-E7VYA;64I("$]('1R=64I
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\O
M($)U:6QD(&)I;F1I;F=S(&9R;VT@86)S=')A8W0@9&%T80H@("`@("`@(&EF
M("@D=&AI<RT^9F%U;'0@/3T@3E5,3"D*("`@("`@("`@("`@)'1H:7,M/E]G
M96YE<F%T94)I;F1I;F=S06YD4V5R=FEC97,H)'1A<F=E=$YA;65S<&%C92P@
M)'-E<G9I8V5?;F%M92P@)'-E<G9I8V5?9&5S8RD["B`@("!]"@H@("`@+RHJ
M($EN:71I86QI<V4@=&AE(%-/05!?5U-$3"!T<F5E("AD97-T<G5C=&EV92D*
M("`@("`J"B`@("`@*B!)9B!T:&4@;V)J96-T(&AA<R!A;')E861Y(&)E96X@
M:6YI=&EA;&ES960L('1H92!O;FQY(&5F9F5C="!W:6QL(&)E('1O"B`@("`@
M*B!C:&%N9V4@=&AE('1N<R!N86UE<W!A8V4@=&\@=&AE(&YE=R!S97)V:6-E
M(&YA;64*("`@("`J"B`@("`@*B!`<&%R86T@("1S97)V:6-E7VYA;64@3F%M
M92!O9B!T:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YI=&EA;&ES92@D<V5R=FEC95]N
M86UE*2!["B`@("`@("`@+R\@4V5T('5P('1H92!B87-I8R!N86UE<W!A8V5S
M('1H870@86QL(%=31$P@9&5F:6YI=&EO;G,@=7-E"@H@("`@("`@("1T:&ES
M+3YW<V1L+3YN86UE<W!A8V5S6R=W<V1L)UT@/2!30TA%34%?5U-$3#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%=31$P@;&%N
M9W5A9V4*("`@("`@("`D=&AI<RT^=W-D;"T^;F%M97-P86-E<ULG<V]A<"==
M(#T@4T-(14U!7U-/05`[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!74T1,(%-/05`@8FEN9&EN9W,*("`@("`@("`D=&AI<RT^
M=W-D;"T^;F%M97-P86-E<ULD=&AI<RT^=&YS4')E9FEX72`]("=U<FXZ)R`N
M("1S97)V:6-E7VYA;64[("`@("`@("`@("`@("`@("`O+R!487)G970@;F%M
M97-P86-E"B`@("`@("`@)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)WAS9"==
M(#T@87)R87E?<V5A<F-H*"=X<V0G+"`D=&AI<RT^7VYA;65S<&%C97,I.R`@
M("`@("`@("`@+R\@6$U,(%-C:&5M80H@("`@("`@("1T:&ES+3YW<V1L+3YN
M86UE<W!A8V5S6R=33T%0+45.0R==(#T@87)R87E?<V5A<F-H*"=33T%0+45.
M0R<L("1T:&ES+3Y?;F%M97-P86-E<RD[("\O(%-/05`@='EP97,*"B`@("`@
M("`@+R\@6%A8(%)E9F%C=&]R("1N86UE<W!A8V4O)&YS(&9O<B!3:&%N92`Z
M+2D*("`@("`@("!U;G-E="@D=&AI<RT^=W-D;"T^;G-;)W5R;CHG("X@)'-E
M<G9I8V5?;F%M95TI.PH@("`@("`@("1T:&ES+3YW<V1L+3YN<R`K/2!A<G)A
M>5]F;&EP*"1T:&ES+3YW<V1L+3YN86UE<W!A8V5S*3L*"B`@("`@("`@+R\@
M26UP;W)T<R!A<F4@;F]T(&EM<&QE;65N=&5D(&EN(%=31$P@9V5N97)A=&EO
M;B!F<F]M(&-L87-S97,*("`@("`@("`O+R`J*BH@/'=S9&PZ:6UP;W)T/B`J
M*BH*("`@('T*"B`@("`O*BH@4&%R<V5R("T@=&%K97,@82!S:6YG;&4@;V)J
M96-T('1O(&%D9"!T;R!T<F5E("AN;VXM9&5S=')U8W1I=F4I"B`@("`@*@H@
M("`@("H@0'!A<F%M("`D;V)J96-T(%)E9F5R96YC92!T;R!T:&4@;V)J96-T
M('1O('!A<G-E"B`@("`@*B!`<&%R86T@("1S97)V:6-E7VYA;64@3F%M92!O
M9B!T:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V4H)B1O8FIE8W0L("1S8VAE;6%.
M86UE<W!A8V4L("1S97)V:6-E7VYA;64I('L*("`@("`@("`O+R!#<F5A=&4@
M;F%M97-P86-E('!R969I>"!F;W(@=&AE('-C:&5M80H@("`@("`@("\O(%A8
M6"!N;W0@=F5R>2!E;&5G86YT(#HM*`H*("`@("`@("!L:7-T("@D<V-H4')E
M9FEX+"`D9F]O*2`]("1T:&ES+3Y?9V5T5'EP94YS*"=[)RXD<V-H96UA3F%M
M97-P86-E+B=])RD["B`@("`@("`@=6YS970H)&9O;RD["@H@("`@("`@("\O
M(%!A<G-E(&%L;"!T:&4@='EP97,@9&5F:6YE9"!B>2!T:&4@;V)J96-T(&EN
M('=H871E=F5R"B`@("`@("`@+R\@<V-H96UA(&QA;F=U86=E('=E(&%R92!U
M<VEN9R`H8W5R<F5N=&QY(%]?='EP961E9B!A<G)A>7,I"B`@("`@("`@+R\@
M*BHJ(#QW<V1L.G1Y<&5S/B`J*BH*"B`@("`@("`@9F]R96%C:"`H)&]B:F5C
M="T^7U]T>7!E9&5F(&%S("1T>7!E3F%M92`]/B`D='EP959A;'5E*0H@("`@
M("`@('L*("`@("`@("`@("`@+R\@1V5T+V-R96%T92!N86UE<W!A8V4@9&5F
M:6YI=&EO;@H*("`@("`@("`@("`@;&ES="@D;G-0<F5F:7@L("1T>7!E3F%M
M92D@/2`D=&AI<RT^7V=E=%1Y<&5.<R@D='EP94YA;64I.PH*("`@("`@("`@
M("`@+R\@0W)E871E('1Y<&4@9&5F:6YI=&EO;@H*("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD<V-H4')E9FEX75LD='EP94YA;65=
M(#T@87)R87DH(FYA;64B(#T^("1T>7!E3F%M92D["B`@("`@("`@("`@("1T
M:&ES5'EP92`])B`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1S8VA0<F5F
M:7A=6R1T>7!E3F%M95T["@H@("`@("`@("`@("`O+R!!8V-O<F1I;F<@=&\@
M1&UI=')I)W,@9&]C=6UE;G1A=&EO;BP@7U]T>7!E9&5F(&-O;65S(&EN('1W
M;PH@("`@("`@("`@("`O+R!F;&%V;W)S.@H@("`@("`@("`@("`O+R!!<G)A
M>2`](&%R<F%Y*&%R<F%Y*")I=&5M(B`]/B`B=F%L=64B*2D*("`@("`@("`@
M("`@+R\@4W1R=6-T(#T@87)R87DH(FET96TQ(B`]/B`B=F%L=64Q(BP@(FET
M96TR(B`]/B`B=F%L=64R(BP@+BXN*0H*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1T>7!E5F%L=64I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@
M("!R97-E="@D='EP959A;'5E*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2AC=7)R96YT*"1T>7!E5F%L=64I*2`F)B!C;W5N="@D='EP959A;'5E
M*2`]/2`Q"B`@("`@("`@("`@("`@("`@("`@("`@("8F(&-O=6YT*&-U<G)E
M;G0H)'1Y<&5686QU92DI(#T](#$I"B`@("`@("`@("`@("`@("!["B`@("`@
M("`@("`@("`@("`@("`@+R\@270G<R!A;B!A<G)A>0H*("`@("`@("`@("`@
M("`@("`@("`D=&AI<U1Y<&5;)W1Y<&4G72`]("=!<G)A>2<["B`@("`@("`@
M("`@("`@("`@("`@<F5S970H8W5R<F5N="@D='EP959A;'5E*2D["B`@("`@
M("`@("`@("`@("`@("`@;&ES="@D;G-0<F5F:7@L("1T>7!E3F%M92D@/2`D
M=&AI<RT^7V=E=%1Y<&5.<RAC=7)R96YT*&-U<G)E;G0H)'1Y<&5686QU92DI
M*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)VYA;65S<&%C92==
M(#T@)&YS4')E9FEX.PH@("`@("`@("`@("`@("`@("`@("1T:&ES5'EP95LG
M87)R87E4>7!E)UT@/2`D='EP94YA;64@+B`G6UTG.PH*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<V4@:68@*"%I<U]A<G)A>2AC=7)R
M96YT*"1T>7!E5F%L=64I*2D*("`@("`@("`@("`@("`@('L*("`@("`@("`@
M("`@("`@("`@("`O+R!)="=S(&$@<W1R=6-T"@H@("`@("`@("`@("`@("`@
M("`@("1T:&ES5'EP95LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7-4>7!E6R=O<F1E<B==(#T@)V%L;"<["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7-4>7!E6R=N86UE<W!A8V4G72`]("1N<U!R969I
M>#L*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V5L96UE;G1S)UT@
M/2!A<G)A>2@I.PH*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D='EP
M959A;'5E(&%S("1E;&5M96YT3F%M92`]/B`D96QE;65N=%1Y<&4I"B`@("`@
M("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@("`@("!L:7-T
M*"1N<U!R969I>"P@)'1Y<&5.86UE*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1E
M;&5M96YT5'EP92D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES5'EP
M95LG96QE;65N=',G75LD96QE;65N=$YA;65=6R=N86UE)UT@/2`D96QE;65N
M=$YA;64["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES5'EP95LG96QE
M;65N=',G75LD96QE;65N=$YA;65=6R=T>7!E)UT@/2`D='EP94YA;64["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES5'EP95LG96QE;65N=',G75LD
M96QE;65N=$YA;65=6R=N86UE<W!A8V4G72`]("1N<U!R969I>#L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!E;'-E"B`@("`@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`@
M("`@+R\@270G<R!E<G)O;F5O=7,*"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E1H92!T>7!E(&1E9FEN:71I
M;VX@9F]R("1N<U!R969I>#HD='EP94YA;64@:7,@:6YV86QI9"XB+"`G=7)N
M.B<@+B!G971?8VQA<W,H)&]B:F5C="DI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@270G<R!E
M<G)O;F5O=7,*"B`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*")4:&4@='EP92!D969I;FET:6]N(&9O<B`D;G-0<F5F:7@Z
M)'1Y<&5.86UE(&ES(&EN=F%L:60N(BP@)W5R;CHG("X@9V5T7V-L87-S*"1O
M8FIE8W0I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@
M0W)E871E(&%N(&5M<'1Y(&5L96UE;G0@87)R87D@=VET:"!T:&4@=&%R9V5T
M(&YA;65S<&%C92!P<F5F:7@L"B`@("`@("`@+R\@=&\@;6%T8V@@=&AE(')E
M<W5L=',@;V8@5U-$3"!P87)S:6YG"@H@("`@("`@("1T:&ES+3YW<V1L+3YE
M;&5M96YT<ULD<V-H4')E9FEX72`](&%R<F%Y*"D["@H@("`@("`@("\O(%!O
M<'5L871E('1R964@=VET:"!M97-S86=E(&EN9F]R;6%T:6]N"B`@("`@("`@
M+R\@*BHJ(#QW<V1L.FUE<W-A9V4^("HJ*@H*("`@("`@("!F;W)E86-H("@D
M;V)J96-T+3Y?7V1I<W!A=&-H7VUA<"!A<R`D;W!E<F%T:6]N3F%M92`]/B`D
M;65S<V%G97,I"B`@("`@("`@>PH@("`@("`@("`@("!F;W)E86-H("@D;65S
M<V%G97,@87,@)&UE<W-A9V54>7!E(#T^("1M97-S86=E4&%R=',I"B`@("`@
M("`@("`@('L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES365S<V%G92D[
M"@H@("`@("`@("`@("`@("`@<W=I=&-H("@D;65S<V%G951Y<&4I('L*("`@
M("`@("`@("`@("`@(&-A<V4@)VEN)SH*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^;65S<V%G97-;)&]P97)A=&EO;DYA;64@+B`G4F5Q=65S
M="==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<TUE<W-A
M9V4@/28@)'1H:7,M/G=S9&PM/FUE<W-A9V5S6R1O<&5R871I;VY.86UE("X@
M)U)E<75E<W0G73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!C87-E("=O=70G.@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YW<V1L+3YM97-S86=E<ULD;W!E<F%T:6]N3F%M92`N("=297-P;VYS
M92==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<TUE<W-A
M9V4@/28@)'1H:7,M/G=S9&PM/FUE<W-A9V5S6R1O<&5R871I;VY.86UE("X@
M)U)E<W!O;G-E)UT["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G86QI87,G.@H@("`@("`@("`@("`@("`@("`@
M("\O($1O(&YO=&AI;F<*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("\O
M($5R<F]R(&-O;F1I=&EO;@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<TUE<W-A9V4I*0H@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1M97-S86=E4&%R=',@87,@)'!A<G1.86UE(#T^
M("1P87)T5'EP92D*("`@("`@("`@("`@("`@("`@("!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&QI<W0@*"1N<U!R969I>"P@)'1Y<&5.86UE*2`]("1T
M:&ES+3Y?9V5T5'EP94YS*"1P87)T5'EP92D["@H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<TUE<W-A9V5;)'!A<G1.86UE72`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1P87)T3F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`D='EP94YA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M97-P86-E)R`]
M/B`D;G-0<F5F:7@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!0;W!U;&%T92!T<F5E('=I
M=&@@<&]R=%1Y<&4@:6YF;W)M871I;VX*("`@("`@("`O+R!86%@@0W5R<F5N
M="!I;7!L96UE;G1A=&EO;B!O;FQY('-U<'!O<G1S(&]N92!P;W)T5'EP92!T
M:&%T"B`@("`@("`@+R\@96YC;VUP87-S97,@86QL(&]F('1H92!O<&5R871I
M;VYS(&%V86EL86)L92X*("`@("`@("`O+R`J*BH@/'=S9&PZ<&]R=%1Y<&4^
M("HJ*@H*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YW<V1L+3YP;W)T5'EP
M97-;)'-E<G9I8V5?;F%M92`N("=0;W)T)UTI*0H@("`@("`@("`@("`D=&AI
M<RT^=W-D;"T^<&]R=%1Y<&5S6R1S97)V:6-E7VYA;64@+B`G4&]R="==(#T@
M87)R87DH*3L*("`@("`@("`D=&AI<U!O<G14>7!E(#TF("1T:&ES+3YW<V1L
M+3YP;W)T5'EP97-;)'-E<G9I8V5?;F%M92`N("=0;W)T)UT["@H@("`@("`@
M(&9O<F5A8V@@*"1O8FIE8W0M/E]?9&ES<&%T8VA?;6%P(&%S("1O<&5R871I
M;VY.86UE(#T^("1M97-S86=E<RD*("`@("`@("!["B`@("`@("`@("`@("1T
M:&ES4&]R=%1Y<&5;)&]P97)A=&EO;DYA;65=(#T@87)R87DH)VYA;64G(#T^
M("1O<&5R871I;VY.86UE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1M97-S
M86=E<R!A<R`D;65S<V%G951Y<&4@/3X@)&UE<W-A9V5087)T<RD*("`@("`@
M("`@("`@>PH@("`@("`@("`@("`@("`@<W=I=&-H("@D;65S<V%G951Y<&4I
M('L*("`@("`@("`@("`@("`@(&-A<V4@)VEN)SH*("`@("`@("`@("`@("`@
M("`@("`D=&AI<U!O<G14>7!E6R1O<&5R871I;VY.86UE75LG:6YP=70G72`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUE<W-A9V4G
M(#T^("1O<&5R871I;VY.86UE("X@)U)E<75E<W0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VYA;65S<&%C92<@/3X@)'1H:7,M/G1N<U!R969I
M>"D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@8V%S92`G;W5T)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<U!O<G14
M>7!E6R1O<&5R871I;VY.86UE75LG;W5T<'5T)UT@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=M97-S86=E)R`]/B`D;W!E<F%T:6]N
M3F%M92`N("=297-P;VYS92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F%M97-P86-E)R`]/B`D=&AI<RT^=&YS4')E9FEX*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH@5&%K92!A;&P@=&AE(&%B<W1R86-T(%=31$P@9&%T
M82!A;F0@8G5I;&0@8V]N8W)E=&4@8FEN9&EN9W,@86YD('-E<G9I8V5S("AD
M97-T<G5C=&EV92D*("`@("`J"B`@("`@*B!86%@@0W5R<F5N="!I;7!L96UE
M;G1A=&EO;B!D:7-C87)D<R`D<V5R=FEC95]D97-C+@H@("`@("H*("`@("`J
M($!P87)A;2`@)'-C:&5M84YA;65S<&%C92!.86UE<W!A8V4@9F]R('1Y<&5S
M(&5T8RX*("`@("`J($!P87)A;2`@)'-E<G9I8V5?;F%M92!.86UE(&]F('1H
M92!74T1,(#QS97)V:6-E/@H@("`@("H@0'!A<F%M("`D<V5R=FEC95]D97-C
M($]P=&EO;F%L(&1E<V-R:7!T:6]N(&]F('1H92!74T1,(#QS97)V:6-E/@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M96YE<F%T94)I;F1I;F=S06YD4V5R=FEC97,H)'-C:&5M84YA;65S<&%C92P@
M)'-E<G9I8V5?;F%M92P@)'-E<G9I8V5?9&5S8R`]("<G*0H@("`@>PH@("`@
M("`@("\O(%!O<'5L871E('1R964@=VET:"!B:6YD:6YG<R!I;F9O<FUA=&EO
M;@H@("`@("`@("\O(%A86"!#=7)R96YT(&EM<&QE;65N=&%T:6]N(&]N;'D@
M<W5P<&]R=',@;VYE(&)I;F1I;F<@=&AA=`H@("`@("`@("\O(&UA=&-H97,@
M=&AE('-I;F=L92!P;W)T5'EP92!A;F0@86QL(&]F(&ET<R!O<&5R871I;VYS
M+@H@("`@("`@("\O(%A86"!)<R!T:&ES('1H92!C;W)R96-T('5S92!O9B`D
M<V-H96UA3F%M97-P86-E(&AE<F4_"B`@("`@("`@+R\@*BHJ(#QW<V1L.F)I
M;F1I;F<^("HJ*@H*("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'-E
M<G9I8V5?;F%M92`N("=":6YD:6YG)UT@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("=T>7!E)R`]/B`D<V5R=FEC95]N86UE("X@)U!O<G0G+`H@("`@("`@
M("`@("`@("`@)VYA;65S<&%C92<@/3X@)'1H:7,M/G1N<U!R969I>"P*("`@
M("`@("`@("`@("`@("=S='EL92<@/3X@)W)P8R<L"B`@("`@("`@("`@("`@
M("`G=')A;G-P;W)T)R`]/B!30TA%34%?4T]!4%](5%10+`H@("`@("`@("`@
M("`@("`@)V]P97)A=&EO;G,G(#T^(&%R<F%Y*"DI.PH@("`@("`@("1T:&ES
M0FEN9&EN9R`])B`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'-E<G9I8V5?;F%M
M92`N("=":6YD:6YG)UT["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YW<V1L
M+3YP;W)T5'EP97-;)'-E<G9I8V5?;F%M92`N("=0;W)T)UT@87,@)&]P97)A
M=&EO;DYA;64@/3X@)&]P97)A=&EO;D1A=&$I"B`@("`@("`@>PH@("`@("`@
M("`@("`D=&AI<T)I;F1I;F=;)V]P97)A=&EO;G,G75LD;W!E<F%T:6]N3F%M
M95T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=S;V%P06-T:6]N)R`]/B`D
M<V-H96UA3F%M97-P86-E("X@)R,G("X@)&]P97)A=&EO;DYA;64L"B`@("`@
M("`@("`@("`@("`G<W1Y;&4G(#T^("1T:&ES0FEN9&EN9ULG<W1Y;&4G72D[
M"@H@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G:6YP=70G+"`G;W5T<'5T
M)RD@87,@)&UE<W-A9V54>7!E*0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1O<&5R871I;VY$871A6R1M97-S86=E5'EP95TI*0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES0FEN9&EN9ULG;W!E<F%T:6]N<R==6R1O<&5R871I;VY.
M86UE75LD;65S<V%G951Y<&5=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=7-E)R`]/B`G96YC;V1E9"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;F%M97-P86-E)R`]/B`D<V-H96UA3F%M97-P86-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5N8V]D:6YG4W1Y;&4G
M(#T^(%-/05!?4T-(14U!7T5.0T]$24Y'*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%!O<'5L871E('1R964@=VET:"!S97)V:6-E(&EN9F]R;6%T:6]N"B`@
M("`@("`@+R\@6%A8($-U<G)E;G0@:6UP;&5M96YT871I;VX@<W5P<&]R=',@
M;VYE('-E<G9I8V4@=VAI8V@@9W)O=7!S"B`@("`@("`@+R\@86QL(&]F('1H
M92!P;W)T<R!T;V=E=&AE<BP@;VYE('!O<G0@<&5R(&)I;F1I;F<*("`@("`@
M("`O+R!86%@@5VAA="!A8F]U="!H='1P<S\*("`@("`@("`O+R`J*BH@/'=S
M9&PZ<V5R=FEC93X@*BHJ"@H@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E
M<ULD<V5R=FEC95]N86UE("X@)U-E<G9I8V4G72`](&%R<F%Y*"=P;W)T<R<@
M/3X@87)R87DH*2D["B`@("`@("`@)'1H:7-397)V:6-E(#TF("1T:&ES+3YW
M<V1L+3YS97)V:6-E<ULD<V5R=FEC95]N86UE("X@)U-E<G9I8V4G75LG<&]R
M=',G73L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G=S9&PM/F)I;F1I;F=S
M(&%S("1B:6YD:6YG3F%M92`]/B`D8FEN9&EN9T1A=&$I"B`@("`@("`@>PH@
M("`@("`@("`@("`D=&AI<U-E<G9I8V5;)&)I;F1I;F=$871A6R=T>7!E)UU=
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1B:6YD
M:6YG1&%T85LG='EP92==+`H@("`@("`@("`@("`@("`@("`@("=B:6YD:6YG
M)R`]/B`D8FEN9&EN9TYA;64L"B`@("`@("`@("`@("`@("`@("`@)VYA;65S
M<&%C92<@/3X@)'1H:7,M/G1N<U!R969I>"P*("`@("`@("`@("`@("`@("`@
M("`G861D<F5S<R<@/3X@87)R87DH)VQO8V%T:6]N)R`]/@H@("`@("`@("`@
M("`@("`@("`@("`@("`G:'1T<#HO+R<@+B`D7U-%4E9%4ELG4T525D527TY!
M344G72`N("1?4T525D526R=02%!?4T5,1B==("X*("`@("`@("`@("`@("`@
M("`@("`@("`@*&ES<V5T*"1?4T525D526R=1545265]35%))3D<G72D@/R`G
M/R<@+B`D7U-%4E9%4ELG455%4EE?4U1224Y')UT@.B`G)RDI+`H@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G<V]A<"<I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4V5T('-E<G9I8V4*("`@("`@("`D=&AI<RT^=W-D;"T^<V5T
M7W-E<G9I8V4H)'-E<G9I8V5?;F%M92`N("=397)V:6-E)RD["B`@("`@("`@
M)'1H:7,M/G=S9&PM/G5R:2`]("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R1T
M:&ES+3YT;G-0<F5F:7A=.PH*("`@("`@("`O+R!#<F5A=&4@5U-$3"!D969I
M;FET:6]N"B`@("`@("`@+R\@*BHJ(#QW<V1L.F1E9FEN:71I;VYS/B`J*BH*
M"B`@("`@("`@)'1H:7,M/G=S9&PM/F1E9FEN:71I;VX@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("=N86UE)R`]/B`D<V5R=FEC95]N86UE+`H@("`@("`@
M("`@("`@("`@)W1A<F=E=$YA;65S<&%C92<@/3X@)'1H:7,M/G=S9&PM/FYA
M;65S<&%C97-;)'1H:7,M/G1N<U!R969I>%TL"B`@("`@("`@("`@("`@("`G
M>&UL;G,G(#T^(%-#2$5-05]74T1,*3L*"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/G=S9&PM/FYA;65S<&%C97,@87,@)&YS4')E9FEX(#T^("1N86UE<W!A
M8V4I"B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YD969I;FET:6]N6R=X;6QN
M<SHG("X@)&YS4')E9FEX72`]("1N86UE<W!A8V4["B`@("!]"@H@("`@+R\@
M5&AI<R!F=6YC=&EO;B!I<R!A9&%P=&5D(&9R;VT@1&UI=')I(%8G<R!I;7!L
M96UE;G1A=&EO;B!O9@H@("`@+R\@1$E30T\O5U-$3"!G96YE<F%T:6]N+B!)
M="!S97!A<F%T97,@;F%M97-P86-E(&9R;VT@='EP92!N86UE(&EN(&$*("`@
M("\O(%]?='EP961E9B!K97D@86YD(&-R96%T97,@82!N97<@;F%M97-P86-E
M(&5N=')Y(&EN('1H92!74T1,('-T<G5C='5R90H@("`@+R\@:68@=&AE(&YA
M;65S<&%C92!H87,@;F]T(&)E96X@=7-E9"!B969O<F4N(%1H92!N86UE<W!A
M8V4@<')E9FEX(&%N9`H@("`@+R\@='EP92!N86UE(&%R92!R971U<FYE9"X@
M268@;F\@;F%M97-P86-E(&ES('-P96-I9FEE9"P@>'-D(&ES(&%S<W5M960N
M"B`@("`O+PH@("`@+R\@5V4@=VEL;"!N;W0@;F5E9"!T:&ES(&9U;F-T:6]N
M(&%N>6UO<F4@;VYC92!?7W1Y<&5D968@:7,@96QI;6EN871E9"X*("`@(&9U
M;F-T:6]N(%]G9714>7!E3G,H)'1Y<&4I('L*("`@("`@("!P<F5G7VUA=&-H
M7V%L;"@B)UQ[*"XJ*5Q])W-M(BPD='EP92PD;2D["B`@("`@("`@:68@*&ES
M<V5T*"1M6S%=6S!=*2`F)B`D;5LQ75LP72`A/2`G)RD@>PH@("`@("`@("`@
M("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&U;,5U;,%TL)'1H:7,M/G=S9&PM
M/FYS*2D@>PH@("`@("`@("`@("`@("`@)&YS7W!R968@/2`G;G,G("X@8V]U
M;G0H)'1H:7,M/G=S9&PM/FYA;65S<&%C97,I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G=S9&PM/FYS6R1M6S%=6S!=72`]("1N<U]P<F5F.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)&YS7W!R969=(#T@
M)&U;,5U;,%T["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1Y<&5N<R`]
M("1T:&ES+3YW<V1L+3YN<ULD;5LQ75LP75T["B`@("`@("`@("`@("1T>7!E
M(#T@97)E9U]R97!L86-E*"1M6S!=6S!=+"<G+"1T>7!E*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D='EP96YS(#T@)WAS9"<["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!A<G)A>2@D='EP96YS+"1T>7!E*3L*("`@('T*
M?0H_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+TA434PO````````````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`V`#`Q-C$P-P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O2%1-3"]D;V-S+P``````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C,P,#8`,#$W,#,W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B](
M5$U,+U-E;&5C="YP:'``````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R-S$U,P`Q,#0Q-S,V,S`P-@`P,C`P-#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@0V]P>7)I9VAT("AC*2`Q.3DW+"`Q.3DX+"`Q.3DY+"`R,#`P+"`R,#`Q
M(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\
M"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L
M92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@
M82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U
M=&AO<CH@061A;2!$86YI96P@/&%D86YI96PQ0&5E<W5S+FIN:BYC;VT^("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@4V5L96-T+G!H<"QV(#$N,30@,C`P,B\Q
M,"\R-"`Q.#HT.3HS,"!T86P@17AP("0*"G)E<75I<F5?;VYC92`G4$5!4BYP
M:'`G.PIR97%U:7)E7V]N8V4@)TA434PO0V]M;6]N+G!H<"<["@HO*BH*("H@
M0VQA<W,@=&\@9'EN86UI8V%L;'D@8W)E871E(&%N($A434P@4T5,14-4"B`J
M"B`J($!A=71H;W(@("`@("`@061A;2!$86YI96P@/&%D86YI96PQ0&5E<W5S
M+FIN:BYC;VT^"B`J($!V97)S:6]N("`@("`@,2XR"B`J($!S:6YC92`@("`@
M("`@4$A0-"XP-'!L,0H@*B!`86-C97-S("`@("`@('!U8FQI8PH@*B\*8VQA
M<W,@2%1-3%]396QE8W0@97AT96YD<R!(5$U,7T-O;6UO;@I["B`@("`*("`@
M("\J*@H@("`@("H@0V]N=&%I;G,@=&AE('-E;&5C="!O<'1I;VYS"B`@("`@
M*@H@("`@("H@0'9A<B`@("`@("!A<G)A>0H@("`@("H@0'-I;F-E("`@("`Q
M+C`*("`@("`J($!A8V-E<W,@("`@<')I=F%T90H@("`@("HO"B`@("!V87(@
M)%]O<'1I;VYS(#T@87)R87DH*3L*("`@(`H@("`@+RHJ"B`@("`@*B!$969A
M=6QT('9A;'5E<R!O9B!T:&4@4T5,14-4"B`@("`@*B`*("`@("`J($!V87(@
M("`@("`@<W1R:6YG"B`@("`@*B!`<VEN8V4@("`@(#$N,`H@("`@("H@0&%C
M8V5S<R`@("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W9A;'5E<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;&%S<R!C;VYS=')U8W1O<@H@("`@
M("H*("`@("`J($!P87)A;2`@("`@<W1R:6YG("`@("1N86UE("`@("`@("AO
M<'1I;VYA;"E.86UE(&%T=')I8G5T92!O9B!T:&4@4T5,14-4"B`@("`@*B!`
M<&%R86T@("`@(&EN="`@("`@("`D<VEZ92`@("`@("`H;W!T:6]N86PI(%-I
M>F4@871T<FEB=71E(&]F('1H92!314Q%0U0*("`@("`J($!P87)A;2`@("`@
M8F]O;"`@("`@("1M=6QT:7!L92`@("AO<'1I;VYA;"E7:&5T:&5R('1H92!S
M96QE8W0@=VEL;"!A;&QO=R!M=6QT:7!L92`*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-E;&5C=&EO;G,@;W(@;F]T"B`@("`@
M*B!`<&%R86T@("`@(&UI>&5D("`@("`D871T<FEB=71E<R`H;W!T:6]N86PI
M16ET:&5R(&$@='EP:6-A;"!(5$U,(&%T=')I8G5T92!S=')I;F<@"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!A;B!A<W-O
M8VEA=&EV92!A<G)A>0H@("`@("H@0'!A<F%M("`@("!I;G0@("`@("`@)'1A
M8D]F9G-E="`@*&]P=&EO;F%L*4YU;6)E<B!O9B!T86)S('1O(&]F9G-E="!(
M5$U,('-O=7)C90H@("`@("H@0'-I;F-E("`@("`Q+C`*("`@("`J($!A8V-E
M<W,@("`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("`@('9O:60*("`@("`J($!T
M:')O=W,@("`@"B`@("`@*B\*("`@(&9U;F-T:6]N($A434Q?4V5L96-T*"1N
M86UE(#T@)R<L("1S:7IE(#T@,2P@)&UU;'1I<&QE(#T@9F%L<V4L("1A='1R
M:6)U=&5S(#T@;G5L;"P@)'1A8D]F9G-E="`](#`I"B`@("!["B`@("`@("`@
M2%1-3%]#;VUM;VXZ.DA434Q?0V]M;6]N*"1A='1R:6)U=&5S+"`D=&%B3V9F
M<V5T*3L*("`@("`@("`D871T<B`](&%R<F%Y*"=N86UE)R`]/B`D;F%M92P@
M)W-I>F4G(#T^("1S:7IE*3L*("`@("`@("!I9B`H)&UU;'1I<&QE*2!["B`@
M("`@("`@("`@("1A='1R6R=M=6QT:7!L92==(#T@)VUU;'1I<&QE)SL*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/G5P9&%T94%T=')I8G5T97,H)&%T='(I
M.PH@("`@("`@("1T:&ES+3YS971396QE8W1E9%9A;'5E<RAA<G)A>2@I*3L*
M("`@('T*("`@(`H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT
M($%022!V97)S:6]N(`H@("`@("H@"B`@("`@*B!`<VEN8V4@("`@(#$N,`H@
M("`@("H@0&%C8V5S<R`@("!P=6)L:6,*("`@("`J($!R971U<FX@("`@9&]U
M8FQE"B`@("`@*B!`=&AR;W=S("`@(`H@("`@("HO"B`@("!F=6YC=&EO;B!A
M<&E697)S:6]N*"D*("`@('L*("`@("`@("!R971U<FX@,2XR.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@9&5F875L="!V86QU97,@;V8@=&AE
M('-E;&5C="!B;W@*("`@("`J(`H@("`@("H@0'!A<F%M("`@("!M:7AE9"`@
M("`D=F%L=65S("!!<G)A>2!O<B!C;VUM82!D96QI;6ET960@<W1R:6YG(&]F
M('-E;&5C=&5D('9A;'5E<PH@("`@("H@0'-I;F-E("`@("`Q+C`*("`@("`J
M($!A8V-E<W,@("`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("`@('9O:60*("`@
M("`J($!T:')O=W,@("`@"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-E;&5C
M=&5D5F%L=65S*"1V86QU97,I"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN
M9R@D=F%L=65S*2D@>PH@("`@("`@("`@("`D=F%L=65S(#T@<W!L:70H(EL@
M73\L6R!=/R(L("1V86QU97,I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M7W9A;'5E<R`]("1V86QU97,[("`*("`@('T*("`@(`H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&%N(&%R<F%Y(&]F('1H92!S96QE8W1E9"!V86QU97,*("`@
M("`J(`H@("`@("H@0'-I;F-E("`@("`Q+C`*("`@("`J($!A8V-E<W,@("`@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N("`@(&%R<F%Y(&]F('-E;&5C=&5D('9A
M;'5E<PH@("`@("H@0'1H<F]W<R`@("`*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4V5L96-T961686QU97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W9A;'5E<SL*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!N97<@
M3U!424].('1O('1H92!314Q%0U0*("`@("`J"B`@("`@*B!`<&%R86T@("`@
M('-T<FEN9R`@("`D=&5X="`@("`@("!$:7-P;&%Y('1E>'0@9F]R('1H92!/
M4%1)3TX*("`@("`J($!P87)A;2`@("`@<W1R:6YG("`@("1V86QU92`@("`@
M(%9A;'5E(&9O<B!T:&4@3U!424]."B`@("`@*B!`<&%R86T@("`@(&)O;VP@
M("`@("`D<V5L96-T960@("!7:&5T:&5R('1H92!O<'1I;VX@:7,@<V5L96-T
M960@;W(@;F]T"B`@("`@*B!`<&%R86T@("`@(&UI>&5D("`@("`D871T<FEB
M=71E<R!%:71H97(@82!T>7!I8V%L($A434P@871T<FEB=71E('-T<FEN9R`*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&%N
M(&%S<V]C:6%T:79E(&%R<F%Y"B`@("`@*B!`<VEN8V4@("`@(#$N,`H@("`@
M("H@0&%C8V5S<R`@("!P=6)L:6,*("`@("`J($!R971U<FX@("`@=F]I9`H@
M("`@("H@0'1H<F]W<R`@("`*("`@("`J+PH@("`@9G5N8W1I;VX@861D3W!T
M:6]N*"1T97AT+"`D=F%L=64L("1S96QE8W1E9"`](&9A;'-E+"`D871T<FEB
M=71E<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1S96QE8W1E9"`F)B`A
M:6Y?87)R87DH)'9A;'5E+"`D=&AI<RT^7W9A;'5E<RDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]V86QU97-;72`]("1V86QU93L*("`@("`@("!]"B`@("`@
M("`@"B`@("`@("`@)&%T=')I8G5T97,@/2`D=&AI<RT^7W!A<G-E071T<FEB
M=71E<R@D871T<FEB=71E<RD["B`@("`@("`@)&%T=');)W9A;'5E)UT@/2`D
M=F%L=64["B`@("`@("`@)'1H:7,M/E]U<&1A=&5!='1R07)R87DH)&%T=')I
M8G5T97,L("1A='1R*3L*("`@("`@("`D=&AI<RT^7V]P=&EO;G-;72`](&%R
M<F%Y*"=T97AT)R`]/B`D=&5X="P@)V%T='(G(#T^("1A='1R:6)U=&5S*3L*
M("`@('T*("`@(`H@("`@+RHJ"B`@("`@*B!,;V%D<R!T:&4@;W!T:6]N<R!F
M<F]M(&%N(&%S<V]C:6%T:79E(&%R<F%Y"B`@("`@*B`*("`@("`J($!P87)A
M;2`@("`@87)R87D@("`@)&%R<B`@("`@07-S;V-I871I=F4@87)R87D@;V8@
M;W!T:6]N<PH@("`@("H@0'!A<F%M("`@("!M:7AE9"`@("`D=F%L=65S("`H
M;W!T:6]N86PI($%R<F%Y(&]R(&-O;6UA(&1E;&EM:71E9"!S=')I;F<@;V8@
M<V5L96-T960@=F%L=65S"B`@("`@*B!`<VEN8V4@("`@(#$N,`H@("`@("H@
M0&%C8V5S<R`@("!P=6)L:6,*("`@("`J($!R971U<FX@("`@4$5!4E]%<G)O
M<B!O;B!E<G)O<B!O<B!T<G5E"B`@("`@*B!`=&AR;W=S("`@(%!%05)?17)R
M;W(*("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9$%R<F%Y*"1A<G(L("1V86QU
M97,];G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<G(I*2![
M"B`@("`@("`@("`@(')E='5R;B!N97<@4$5!4E]%4E)/4B@G1FER<W0@87)G
M=6UE;G0@=&\@2%1-3%]396QE8W0Z.FQO861!<G)A>2!I<R!N;W0@82!V86QI
M9"!A<G)A>2<I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'9A;'5E
M<RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=%-E;&5C=&5D5F%L=65S*"1V
M86QU97,I.PH@("`@("`@('T*("`@("`@("!W:&EL92`H;&ES="@D:V5Y+"`D
M=F%L=64I(#T@96%C:"@D87)R*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D
M3W!T:6]N*"1K97DL("1V86QU92D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J($QO861S('1H92!O
M<'1I;VYS(&9R;VT@86X@87)R87D@=VET:"!N=6UE<FEC(&ME>7,L('5S:6YG
M('1H90H@("`@("H@87)R87D@=F%L=65S(&%S('1H92!F;W)M('9A;'5E<R!A
M<R!W96QL(&%S(&QA8F5L<RX*("`@("`J(`H@("`@("H@0'!A<F%M("`@("!A
M<G)A>2`@("`D87)R("`@("!!<G)A>2!O9B!O<'1I;VYS"B`@("`@*B!`<&%R
M86T@("`@(&UI>&5D("`@("1V86QU97,@("AO<'1I;VYA;"D@07)R87D@;W(@
M8V]M;6$@9&5L:6UI=&5D('-T<FEN9R!O9B!S96QE8W1E9"!V86QU97,*("`@
M("`J($!S:6YC92`@("`@,2XR"B`@("`@*B!`86-C97-S("`@('!U8FQI8PH@
M("`@("H@0')E='5R;B`@("!014%27T5R<F]R(&]N(&5R<F]R(&]R('1R=64*
M("`@("`J($!T:')O=W,@("`@4$5!4E]%<G)O<@H@("`@("HO"B`@("!F=6YC
M=&EO;B!L;V%D5F%L=65!<G)A>2@D87)R+"`D=F%L=65S(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<G(I*2!["B`@("`@("`@("`@
M(')E='5R;B!N97<@4$5!4E]%4E)/4B@B1FER<W0@87)G=6UE;G0@=&\@2%1-
M3%]396QE8W0Z.FQO861!<G)A>2!I<R!N;W0@82!V86QI9"!A<G)A>2(I.PH@
M("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'9A;'5E<RDI('L*("`@("`@
M("`@("`@)'1H:7,M/G-E=%-E;&5C=&5D5F%L=65S*"1V86QU97,I.PH@("`@
M("`@('T*("`@("`@("!F;W)E86-H("@D87)R(&%S("1V86QU92D@>PH@("`@
M("`@("`@("`D=&AI<RT^861D3W!T:6]N*"1V86QU92P@)'9A;'5E*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`*("`@("\J
M*@H@("`@("H@3&]A9',@=&AE(&]P=&EO;G,@9G)O;2!$0E]R97-U;'0@;V)J
M96-T"B`@("`@*B`*("`@("`J($EF(&YO(&-O;'5M;B!N86UE<R!A<F4@<W!E
M8VEF:65D('1H92!F:7)S="!T=V\@8V]L=6UN<R!O9B!T:&4@<F5S=6QT(&%R
M90H@("`@("H@=7-E9"!A<R!T:&4@=&5X="!A;F0@=F%L=64@8V]L=6UN<R!R
M97-P96-T:79E;'D*("`@("`J($!P87)A;2`@("`@;V)J96-T("`@("1R97-U
M;'0@("`@($1"7W)E<W5L="!O8FIE8W0@"B`@("`@*B!`<&%R86T@("`@('-T
M<FEN9R`@("`D=&5X=$-O;"`@("`H;W!T:6]N86PI($YA;64@;V8@8V]L=6UN
M('1O(&1I<W!L87D@87,@=&AE($]05$E/3B!T97AT(`H@("`@("H@0'!A<F%M
M("`@("!S=')I;F<@("`@)'9A;'5E0V]L("`@*&]P=&EO;F%L*2!.86UE(&]F
M(&-O;'5M;B!T;R!U<V4@87,@=&AE($]05$E/3B!V86QU92`*("`@("`J($!P
M87)A;2`@("`@;6EX960@("`@("1V86QU97,@("`@("AO<'1I;VYA;"D@07)R
M87D@;W(@8V]M;6$@9&5L:6UI=&5D('-T<FEN9R!O9B!S96QE8W1E9"!V86QU
M97,*("`@("`J($!S:6YC92`@("`@,2XP"B`@("`@*B!`86-C97-S("`@('!U
M8FQI8PH@("`@("H@0')E='5R;B`@("!014%27T5R<F]R(&]N(&5R<F]R(&]R
M('1R=64*("`@("`J($!T:')O=W,@("`@4$5!4E]%<G)O<@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L;V%D1&)297-U;'0H)B1R97-U;'0L("1T97AT0V]L/6YU
M;&PL("1V86QU94-O;#UN=6QL+"`D=F%L=65S/6YU;&PI"B`@("!["B`@("`@
M("`@:6YC;'5D95]O;F-E("=$0BYP:'`G.PH@("`@("`@(`H@("`@("`@(&EF
M("@A:7-?;V)J96-T*"1R97-U;'0I('Q\("AG971?8VQA<W,H)')E<W5L="D@
M(3T@(F1B7W)E<W5L="(@)B8@"B`@("`@("`@("`@(&ES7W-U8F-L87-S7V]F
M*"1R97-U;'0L(")D8E]R97-U;'0B*2DI('L*("`@("`@("`@("`@<F5T=7)N
M(&YE=R!014%27T524D]2*")&:7)S="!A<F=U;65N="!T;R!(5$U,7U-E;&5C
M=#HZ;&]A9$1B4F5S=6QT(&ES(&YO="!A('9A;&ED($1"7W)E<W5L="(I.PH@
M("`@("`@('T*("`@("`@("`@:68@*&ES<V5T*"1V86QU97,I*2!["B`@("`@
M("`@("`@("1T:&ES+3YS971396QE8W1E9%9A;'5E<R@D=F%L=65S*3L*("`@
M("`@("!]"B`@("`@("`@)&9E=&-H36]D92`]("@D=&5X=$-O;"`F)B`D=F%L
M=65#;VPI(#\@1$)?1D540TA-3T1%7T%34T]#(#H@1$)?1D540TA-3T1%7T1%
M1D%53%0["B`@("`@("`@=VAI;&4@*&ES7V%R<F%Y*"1R;W<@/2`D<F5S=6QT
M+3YF971C:%)O=R@D9F5T8VA-;V1E*2D@*2!["B`@("`@("`@("`@(&EF("@D
M9F5T8VA-;V1E(#T]($1"7T9%5$-(34]$15]!4U-/0RD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F%D9$]P=&EO;B@D<F]W6R1T97AT0V]L72P@)')O=ULD
M=F%L=65#;VQ=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YA9&1/<'1I;VXH)')O=ULP72P@)')O=ULQ72D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"B`@("`*("`@("\J*@H@("`@("H@475E<FEE<R!A(&1A=&%B87-E(&%N9"!L
M;V%D<R!T:&4@;W!T:6]N<R!F<F]M('1H92!R97-U;'1S"B`@("`@*@H@("`@
M("H@0'!A<F%M("`@("!M:7AE9"`@("`@)&-O;FX@("`@("`@16ET:&5R(&%N
M(&5X:7-T:6YG($1"(&-O;FYE8W1I;VX@;W(@82!V86QI9"!D<VX@"B`@("`@
M*B!`<&%R86T@("`@('-T<FEN9R`@("`D<W%L("`@("`@("!344P@<75E<GD@
M<W1R:6YG"B`@("`@*B!`<&%R86T@("`@('-T<FEN9R`@("`D=&5X=$-O;"`@
M("`H;W!T:6]N86PI($YA;64@;V8@8V]L=6UN('1O(&1I<W!L87D@87,@=&AE
M($]05$E/3B!T97AT(`H@("`@("H@0'!A<F%M("`@("!S=')I;F<@("`@)'9A
M;'5E0V]L("`@*&]P=&EO;F%L*2!.86UE(&]F(&-O;'5M;B!T;R!U<V4@87,@
M=&AE($]05$E/3B!V86QU92`*("`@("`J($!P87)A;2`@("`@;6EX960@("`@
M("1V86QU97,@("`@("AO<'1I;VYA;"D@07)R87D@;W(@8V]M;6$@9&5L:6UI
M=&5D('-T<FEN9R!O9B!S96QE8W1E9"!V86QU97,*("`@("`J($!S:6YC92`@
M("`@,2XQ"B`@("`@*B!`86-C97-S("`@('!R:79A=&4*("`@("`J($!R971U
M<FX@("`@=F]I9`H@("`@("H@0'1H<F]W<R`@("`*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&]A9%%U97)Y*"8D8V]N;BP@)'-Q;"P@)'1E>'1#;VP];G5L;"P@
M)'9A;'5E0V]L/6YU;&PL("1V86QU97,];G5L;"D*("`@('L*("`@("`@("!I
M;F-L=61E7V]N8V4@)T1"+G!H<"<["B`@("`@("`@"B`@("`@("`@:68@*&ES
M7W-T<FEN9R@D8V]N;BDI('L*("`@("`@("`@("`@)&1B0V]N;B`]("9$0CHZ
M8V]N;F5C="@D8V]N;BP@=')U92D["B`@("`@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D9&)#;VYN*2D@<F5T=7)N("1D8D-O;FX["B`@("`@("`@?2!E;'-E
M:68@*&ES7W-U8F-L87-S7V]F*"1C;VYN+"`B9&)?8V]M;6]N(BDI('L*("`@
M("`@("`@("`@)&1B0V]N;B`]("1C;VYN.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B07)G=6UE;G0@
M,2!O9B!(5$U,7U-E;&5C=#HZ;&]A9%%U97)Y(&ES(&YO="!A('9A;&ED('1Y
M<&4B*3L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]($`D9&)#;VYN+3YQ
M=65R>2@D<W%L*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]A9$1B
M4F5S=6QT*"1R97-U;'0L("1T97AT0V]L+"`D=F%L=65#;VPL("1V86QU97,I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]A9',@;W!T:6]N<R!F<F]M(&1I
M9F9E<F5N="!T>7!E<R!O9B!D871A('-O=7)C97,*("`@("`J"B`@("`@*B!4
M:&ES(&UE=&AO9"!I<R!A('-I;75L871E9"!O=F5R;&]A9&5D(&UE=&AO9"X@
M(%1H92!A<F=U;65N=',L(&]T:&5R('1H86X@=&AE"B`@("`@*B!F:7)S="!A
M<F4@;W!T:6]N86P@86YD(&]N;'D@;65A;B!S;VUE=&AI;F<@9&5P96YD:6YG
M(&]N('1H92!T>7!E(&]F('1H92!F:7)S="!A<F=U;65N="X*("`@("`J($EF
M('1H92!F:7)S="!A<F=U;65N="!I<R!A;B!A<G)A>2!T:&5N(&%L;"!A<F=U
M;65N=',@87)E('!A<W-E9"!I;B!O<F1E<B!T;R!L;V%D07)R87DN"B`@("`@
M*B!)9B!T:&4@9FER<W0@87)G=6UE;G0@:7,@82!D8E]R97-U;'0@=&AE;B!A
M;&P@87)G=6UE;G1S(&%R92!P87-S960@:6X@;W)D97(@=&\@;&]A9$1B4F5S
M=6QT+@H@("`@("H@268@=&AE(&9I<G-T(&%R9W5M96YT(&ES(&$@<W1R:6YG
M(&]R(&$@1$(@8V]N;F5C=&EO;B!T:&5N(&%L;"!A<F=U;65N=',@87)E(`H@
M("`@("H@<&%S<V5D(&EN(&]R9&5R('1O(&QO8611=65R>2X*("`@("`J($!P
M87)A;2`@("`@;6EX960@("`@("1O<'1I;VYS("`@("!/<'1I;VYS('-O=7)C
M92!C=7)R96YT;'D@<W5P<&]R=',@87-S;V,@87)R87D@;W(@1$)?<F5S=6QT
M"B`@("`@*B!`<&%R86T@("`@(&UI>&5D("`@("`D<&%R86TQ("`@("`H;W!T
M:6]N86PI(%-E92!F=6YC=&EO;B!D971A:6P*("`@("`J($!P87)A;2`@("`@
M;6EX960@("`@("1P87)A;3(@("`@("AO<'1I;VYA;"D@4V5E(&9U;F-T:6]N
M(&1E=&%I;`H@("`@("H@0'!A<F%M("`@("!M:7AE9"`@("`@)'!A<F%M,R`@
M("`@*&]P=&EO;F%L*2!3964@9G5N8W1I;VX@9&5T86EL"B`@("`@*B!`<&%R
M86T@("`@(&UI>&5D("`@("`D<&%R86TT("`@("`H;W!T:6]N86PI(%-E92!F
M=6YC=&EO;B!D971A:6P*("`@("`J($!S:6YC92`@("`@,2XQ"B`@("`@*B!`
M86-C97-S("`@('!U8FQI8PH@("`@("H@0')E='5R;B`@("!014%27T5R<F]R
M(&]N(&5R<F]R(&]R('1R=64*("`@("`J($!T:')O=W,@("`@4$5!4E]%<G)O
M<@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V%D*"8D;W!T:6]N<RP@)'!A<F%M
M,3UN=6QL+"`D<&%R86TR/6YU;&PL("1P87)A;3,];G5L;"P@)'!A<F%M-#UN
M=6QL*0H@("`@>PH@("`@("`@('-W:71C:"`H=')U92D@>PH@("`@("`@("`@
M("!C87-E(&ES7V%R<F%Y*"1O<'1I;VYS*3H*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^;&]A9$%R<F%Y*"1O<'1I;VYS+"`D<&%R86TQ*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("AG971?8VQA
M<W,H)&]P=&EO;G,I(#T](")D8E]R97-U;'0B('Q\(&ES7W-U8F-L87-S7V]F
M*"1O<'1I;VYS+"`B9&)?<F5S=6QT(BDI.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YL;V%D1&)297-U;'0H)&]P=&EO;G,L("1P87)A;3$L("1P
M87)A;3(L("1P87)A;3,I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@*&ES7W-T<FEN9R@D;W!T:6]N<RD@?'P@:7-?<W5B8VQA
M<W-?;V8H)&]P=&EO;G,L(")D8E]C;VUM;VXB*2DZ"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FQO8611=65R>2@D;W!T:6]N<RP@)'!A<F%M,2P@
M)'!A<F%M,BP@)'!A<F%M,RP@)'!A<F%M-"D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"B`@("!]"B`@("`*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@4T5,14-4(&EN($A434P*("`@("`J"B`@("`@*B!`<VEN8V4@
M("`@(#$N,`H@("`@("H@0&%C8V5S<R`@("!P=6)L:6,*("`@("`J($!R971U
M<FX@("`@<W1R:6YG"B`@("`@*B!`=&AR;W=S("`@(`H@("`@("HO"B`@("!F
M=6YC=&EO;B!T;TAT;6PH*0H@("`@>PH@("`@("`@("1T86)S(#T@)'1H:7,M
M/E]G971486)S*"D["B`@("`@("`@)&YA;64@/2`D=&AI<RT^7V%T=')I8G5T
M97-;)VYA;64G73L*("`@("`@("`D<W1R2'1M;"`]("1T86)S.PH@("`@("`@
M(&EF("@D=&AI<RT^7V-O;6UE;G0I('L*("`@("`@("`@("`@)'-T<DAT;6P@
M+CT@(CPA+2T@)'1H:7,M/E]C;VUM96YT("TM/EQN)'1A8G,B.PH@("`@("`@
M('T*("`@("`@("`D<W1R2'1M;"`N/0H@("`@("`@("`@("`G/'-E;&5C="<@
M+B`D=&AI<RT^7V=E=$%T=')3=')I;F<H)'1H:7,M/E]A='1R:6)U=&5S*2`N
M("<^)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V]P=&EO;G,@87,@)&]P
M=&EO;BD@>PH@("`@("`@("`@("!I9B`H0&EN7V%R<F%Y*"1O<'1I;VY;)V%T
M='(G75LG=F%L=64G72P@)'1H:7,M/E]V86QU97,I*2!["B`@("`@("`@("`@
M("`@("`D;W!T:6]N6R=A='1R)UU;)W-E;&5C=&5D)UT@/2`G<V5L96-T960G
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A='1R4W1R:6YG(#T@)'1H
M:7,M/E]G971!='1R4W1R:6YG*"1O<'1I;VY;)V%T='(G72D["B`@("`@("`@
M("`@("1S=')(=&UL("X]"B`@("`@("`@("`@("`@("`G/&]P=&EO;B<@+B`D
M871T<E-T<FEN9R`N("<^)R`N"B`@("`@("`@("`@("`@("!H=&UL<W!E8VEA
M;&-H87)S*"1O<'1I;VY;)W1E>'0G72D@+B`G/"]O<'1I;VX^)SL*("`@("`@
M("!]"B`@("`@("`@)'-T<DAT;6P@+CT@)SPO<V5L96-T/B<["B`@("`@("`@
M<F5T=7)N("1S=')(=&UL.PH@("`@?0H@("`@"GT*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+TA434PO0V]M;6]N+G!H<```````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V-3(P`#$P-#$W,S8S,#`V
M`#`R,#`U,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H
M:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<L(#$Y
M.3@L(#$Y.3DL(#(P,#`L(#(P,#$@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@
M("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!!9&%M($1A;FEE;"`\861A;FEE
M;#%`965S=7,N:FYJ+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!#;VUM
M;VXN<&AP+'8@,2XX(#(P,#,O,#8O,3D@,3@Z-3(Z-3`@;6%N<VEO;B!%>'`@
M)`H*+RHJ"B`J($)A<V4@8VQA<W,@9F]R(&%L;"!(5$U,(&-L87-S97,*("H*
M("H@0&%U=&AO<B`@("`@($%D86T@1&%N:65L(#QA9&%N:65L,4!E97-U<RYJ
M;FHN8V]M/@H@*B!`=F5R<VEO;B`@("`@,2XW"B`J($!S:6YC92`@("`@("!0
M2%`@-"XP+C-P;#$*("H@0&%B<W1R86-T"B`J+PIC;&%S<R!(5$U,7T-O;6UO
M;B!["@H@("`@+RHJ"B`@("`@*B!!<W-O8VEA=&EV92!A<G)A>2!O9B!T86)L
M92!A='1R:6)U=&5S"B`@("`@*B!`=F%R("`@("!A<G)A>0H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]A='1R:6)U=&5S(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1A8B!O9F9S970@;V8@=&AE('1A
M8FQE"B`@("`@*B!`=F%R("`@("!I;G0*("`@("`J($!A8V-E<W,@('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?=&%B3V9F<V5T(#T@,#L*"B`@("`O*BH*
M("`@("`J(%1A8B!S=')I;F<*("`@("`J($!V87(@("`@("`@<W1R:6YG"B`@
M("`@*B!`<VEN8V4@("`@(#$N-PH@("`@("H@0&%C8V5S<R`@("!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7W1A8B`](")<,3$B.PH*("`@("\J*@H@("`@
M("H@0V]N=&%I;G,@=&AE(&QI;F4@96YD('-T<FEN9PH@("`@("H@0'9A<B`@
M("`@("!S=')I;F<*("`@("`J($!S:6YC92`@("`@,2XW"B`@("`@*B!`86-C
M97-S("`@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;&EN945N9"`](")<
M,3(B.PH*("`@("\J*@H@("`@("H@2%1-3"!C;VUM96YT(&]N('1H92!O8FIE
M8W0*("`@("`J($!V87(@("`@("`@<W1R:6YG"B`@("`@*B!`<VEN8V4@("`@
M(#$N-0H@("`@("H@0&%C8V5S<R`@("!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7V-O;6UE;G0@/2`G)SL*"B`@("`O*BH*("`@("`J($-L87-S(&-O;G-T
M<G5C=&]R"B`@("`@*B!`<&%R86T@("`@;6EX960@("`D871T<FEB=71E<R`@
M("`@07-S;V-I871I=F4@87)R87D@;V8@=&%B;&4@=&%G(&%T=')I8G5T97,@
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@
M2%1-3"!A='1R:6)U=&5S(&YA;64](G9A;'5E(B!P86ER<PH@("`@("H@0'!A
M<F%M("`@(&EN="`@("`@)'1A8D]F9G-E="`@("`@($EN9&5N="!O9F9S970@
M:6X@=&%B<PH@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!(5$U,7T-O;6UO;B@D871T<FEB=71E<R`](&YU;&PL("1T86)/
M9F9S970@/2`P*0H@("`@>PH@("`@("`@("1T:&ES+3YS971!='1R:6)U=&5S
M*"1A='1R:6)U=&5S*3L*("`@("`@("`D=&AI<RT^<V5T5&%B3V9F<V5T*"1T
M86)/9F9S970I.PH@("`@?2`O+R!E;F0@8V]N<W1R=6-T;W(*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@05!)('9E<G-I;VX*("`@("`J
M($!A8V-E<W,@("!P=6)L:6,*("`@("`J($!R971U<FYS("!D;W5B;&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I"B`@("!["B`@("`@("`@
M<F5T=7)N(#$N-SL*("`@('T@+R\@96YD(&9U;F,@87!I5F5R<VEO;@H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&EN945N9`H@("`@("H@"B`@("`@
M*B!`<VEN8V4@("`@(#$N-PH@("`@("H@0&%C8V5S<R`@("!P<FEV871E"B`@
M("`@*B!`<F5T=7)N("`@('-T<FEN9PH@("`@("H@0'1H<F]W<PH@("`@("HO
M"B`@("!F=6YC=&EO;B!?9V5T3&EN945N9"@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?;&EN945N9#L*("`@('T@+R\@96YD(&9U;F,@9V5T3&EN
M945N9`H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!C;VYT86EN
M:6YG('1H92!U;FET(&9O<B!I;F1E;G1I;F<@2%1-3`H@("`@("H@"B`@("`@
M*B!`<VEN8V4@("`@(#$N-PH@("`@("H@0&%C8V5S<R`@("!P<FEV871E"B`@
M("`@*B!`<F5T=7)N("`@('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T5&%B*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T86(["B`@
M("!]("\O(&5N9"!F=6YC(%]G971486(*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;V9F<V5T(&9O<B!T:&4@=VAO
M;&4@2%1-3"!C;V1E"B`@("`@*B`*("`@("`J($!R971U<FX@("`@<W1R:6YG
M"B`@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5T5&%B<R@I"B`@("!["B`@("`@("`@<F5T=7)N('-T<E]R97!E870H
M)'1H:7,M/E]G971486(H*2P@)'1H:7,M/E]T86)/9F9S970I.PH@("`@?2`O
M+R!E;F0@9G5N8R!?9V5T5&%B<PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M;B!(5$U,(&9O<FUA='1E9"!A='1R:6)U=&4@<W1R:6YG"B`@("`@*B!`<&%R
M86T@("`@87)R87D@("`D871T<FEB=71E<PH@("`@("H@0')E='5R;B`@('-T
M<FEN9PH@("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V=E=$%T=')3=')I;F<H)&%T=')I8G5T97,I"B`@("!["B`@("`@
M("`@)'-T<D%T='(@/2`G)SL*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1A='1R
M:6)U=&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@)'-T<D%T='(@
M+CT@)R`G("X@)&ME>2`N("<](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1V86QU
M92D@+B`G(B<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1S=')!='1R.PH@("`@?2`O+R!E;F0@9G5N8R!?9V5T071T<E-T<FEN
M9PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('9A;&ED(&%T<G)I8G5T97,@
M87)R87D@9G)O;2!E:71H97(@82!S=')I;F<@;W(@87)R87D*("`@("`J($!P
M87)A;2`@("!M:7AE9"`@("1A='1R:6)U=&5S("`@("!%:71H97(@82!T>7!I
M8V%L($A434P@871T<FEB=71E('-T<FEN9R!O<B!A;B!A<W-O8VEA=&EV92!A
M<G)A>0H@("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W!A<G-E071T<FEB=71E<R@D871T<FEB=71E<RD*("`@('L*("`@
M("`@("!I9B`H:7-?87)R87DH)&%T=')I8G5T97,I*2!["B`@("`@("`@("`@
M("1R970@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D871T<FEB
M=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@
M*&ES7VEN="@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@("`@("1K97D@/2`D
M=F%L=64@/2!S=')T;VQO=V5R*"1V86QU92D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1K97D@/2!S=')T;VQO=V5R
M*"1K97DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E
M=%LD:V5Y72`]("1V86QU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)')E=#L*"B`@("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D871T
M<FEB=71E<RDI('L*("`@("`@("`@("`@)'!R96<@/2`B+R@H6T$M6F$M>E\Z
M77Q;7EQ<>#`P+5Q<>#=&72DH6T$M6F$M>C`M.5\Z+BU=?%M>7%QX,#`M7%QX
M-T9=*2HI(B`N"B`@("`@("`@("`@("`@("`B*%L@7%QN7%QT7%QR72LI/R@]
M*%L@7%QN7%QT7%QR72LI/RA<(EM>7")=*EPB?"=;7B==*B=\6UX@7%QN7%QT
M7%QR72HI*3\O(CL*("`@("`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"1P
M<F5G+"`D871T<FEB=71E<RP@)')E9W,I*2!["B`@("`@("`@("`@("`@("!F
M;W(@*"1C;W5N=&5R/3`[("1C;W5N=&5R/&-O=6YT*"1R96=S6S%=*3L@)&-O
M=6YT97(K*RD@>PH@("`@("`@("`@("`@("`@("`@("1N86UE("`]("1R96=S
M6S%=6R1C;W5N=&5R73L*("`@("`@("`@("`@("`@("`@("`D8VAE8VL@/2`D
M<F5G<ULP75LD8V]U;G1E<ET["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@)')E9W-;-UU;)&-O=6YT97)=.PH@("`@("`@("`@("`@("`@("`@(&EF
M("AT<FEM*"1N86UE*2`]/2!T<FEM*"1C:&5C:RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%R<D%T=');<W1R=&]L;W=E<BAT<FEM*"1N86UE*2E=
M(#T@<W1R=&]L;W=E<BAT<FEM*"1N86UE*2D["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-U8G-T
M<B@D=F%L=64L(#`L(#$I(#T](")<(B(@?'P@<W5B<W1R*"1V86QU92P@,"P@
M,2D@/3T@(B<B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L
M=64@/2!S=6)S='(H)'9A;'5E+"`Q+"`M,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&%R<D%T=');<W1R
M=&]L;W=E<BAT<FEM*"1N86UE*2E=(#T@=')I;2@D=F%L=64I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(')E='5R;B`D87)R071T<CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T@+R\@96YD(&9U;F,@7W!A<G-E071T<FEB=71E<PH*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@87)R87D@:V5Y(&9O<B!T:&4@9VEV96X@;F]N
M+6YA;64M=F%L=64@<&%I<B!A='1R:6)U=&4*("`@("`J(`H@("`@("H@0'!A
M<F%M("`@("!S=')I;F<@("`@)&%T='(@("`@("`@("!!='1R:6)U=&4*("`@
M("`J($!P87)A;2`@("`@87)R87D@("`@("1A='1R:6)U=&5S("`@07)R87D@
M;V8@871T<FEB=71E"B`@("`@*B!`<VEN8V4@("`@(#$N,`H@("`@("H@0&%C
M8V5S<R`@("!P<FEV871E"B`@("`@*B!`<F5T=7)N("`@(&%R<F%Y(&ME>0H@
M("`@("H@0'1H<F]W<PH@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T071T<DME
M>2@D871T<BP@)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1A='1R:6)U=&5S6W-T<G1O;&]W97(H)&%T='(I72DI('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?2`O+V5N9"!F=6YC(%]G971!
M='1R2V5Y"@H@("`@+RHJ"B`@("`@*B!5<&1A=&5S('1H92!A='1R:6)U=&5S
M(&EN("1A='1R,2!W:71H('1H92!V86QU97,@:6X@)&%T='(R('=I=&AO=70@
M8VAA;F=I;F<@=&AE(&]T:&5R(&5X:7-T:6YG(&%T=')I8G5T97,*("`@("`J
M($!P87)A;2`@("!A<G)A>2`@("1A='1R,2`@("`@($]R:6=I;F%L(&%T=')I
M8G5T97,@87)R87D*("`@("`J($!P87)A;2`@("!A<G)A>2`@("1A='1R,B`@
M("`@($YE=R!A='1R:6)U=&5S(&%R<F%Y"B`@("`@*B!`86-C97-S("`@<')I
M=F%T90H@("`@("H@0')E='5R;B`@(&%R<F%Y"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]U<&1A=&5!='1R07)R87DH)B1A='1R,2P@)&%T='(R*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?87)R87DH)&%T='(R*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1A='1R
M,B!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D871T<C%;)&ME
M>5T@/2`D=F%L=64["B`@("`@("`@?0H@("`@?2`O+R!E;F0@9G5N8R!?=7!D
M871E071R<D%R<F%Y"@H@("`@+RHJ"B`@("`@*B!296UO=F5S('1H92!G:79E
M;B!A='1R:6)U=&4@9G)O;2!T:&4@9VEV96X@87)R87D*("`@("`J(`H@("`@
M("H@0'!A<F%M("`@("!S=')I;F<@("`@)&%T='(@("`@("`@("`@($%T=')I
M8G5T92!N86UE"B`@("`@*B!`<&%R86T@("`@(&%R<F%Y("`@("`D871T<FEB
M=71E<R`@("`@071T<FEB=71E(&%R<F%Y"B`@("`@*B!`<VEN8V4@("`@(#$N
M-`H@("`@("H@0&%C8V5S<R`@("!P=6)L:6,*("`@("`J($!R971U<FX@("`@
M=F]I9`H@("`@("H@0'1H<F]W<PH@("`@("HO"B`@("!F=6YC=&EO;B!?<F5M
M;W9E071T<B@D871T<BP@)B1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@("1A
M='1R(#T@<W1R=&]L;W=E<B@D871T<BD["B`@("`@("`@:68@*&ES<V5T*"1A
M='1R:6)U=&5S6R1A='1R72DI('L*("`@("`@("`@("`@=6YS970H)&%T=')I
M8G5T97-;)&%T=')=*3L*("`@("`@("!]"B`@("!]("\O96YD(&9U;F,@7W)E
M;6]V94%T='(*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('9A;'5E(&]F
M('1H92!G:79E;B!A='1R:6)U=&4*("`@("`J(`H@("`@("H@0'!A<F%M("`@
M("!S=')I;F<@("`@)&%T='(@("!!='1R:6)U=&4@;F%M90H@("`@("H@0'-I
M;F-E("`@("`Q+C4*("`@("`J($!A8V-E<W,@("`@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N("`@('9O:60*("`@("`J($!T:')O=W,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T071T<FEB=71E*"1A='1R*0H@("`@>PH@("`@("`@("1A='1R
M(#T@<W1R=&]L;W=E<B@D871T<BD["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?871T<FEB=71E<ULD871T<ETI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V%T=')I8G5T97-;)&%T=')=.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@;G5L;#L*("`@('T@+R]E;F0@9G5N8R!G971!='1R:6)U=&4*"B`@
M("`O*BH*("`@("`J(%-E=',@=&AE($A434P@871T<FEB=71E<PH@("`@("H@
M0'!A<F%M("`@(&UI>&5D("`@)&%T=')I8G5T97,@("`@($5I=&AE<B!A('1Y
M<&EC86P@2%1-3"!A='1R:6)U=&4@<W1R:6YG(&]R(&%N(&%S<V]C:6%T:79E
M(&%R<F%Y"B`@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$%T=')I8G5T97,H)&%T=')I8G5T97,I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]A='1R:6)U=&5S(#T@)'1H:7,M/E]P87)S94%T=')I8G5T
M97,H)&%T=')I8G5T97,I.PH@("`@?2`O+R!E;F0@9G5N8R!S971!='1R:6)U
M=&5S"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!A<W-O8R!A<G)A>2`H
M9&5F875L="D@;W(@<W1R:6YG(&]F(&%T=')I8G5T97,*("`@("`J"B`@("`@
M*B!`<&%R86T@("`@(&)O;VP@("`@5VAE=&AE<B!T;R!R971U<FX@=&AE(&%T
M=')I8G5T97,@87,@<W1R:6YG(`H@("`@("H@0'-I;F-E("`@("`Q+C8*("`@
M("`J($!A8V-E<W,@("`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("`@(&UI>&5D
M("`@871T<FEB=71E<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971!='1R:6)U
M=&5S*"1A<U-T<FEN9R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D87-3
M=')I;F<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T071T<E-T
M<FEN9R@D=&AI<RT^7V%T=')I8G5T97,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%T=')I8G5T97,["B`@("`@("`@
M?0H@("`@?2`O+V5N9"!F=6YC(&=E=$%T=')I8G5T97,*"B`@("`O*BH*("`@
M("`J(%5P9&%T97,@=&AE('!A<W-E9"!A='1R:6)U=&5S('=I=&AO=70@8VAA
M;F=I;F<@=&AE(&]T:&5R(&5X:7-T:6YG(&%T=')I8G5T97,*("`@("`J($!P
M87)A;2`@("!M:7AE9"`@("1A='1R:6)U=&5S("`@("!%:71H97(@82!T>7!I
M8V%L($A434P@871T<FEB=71E('-T<FEN9R!O<B!A;B!A<W-O8VEA=&EV92!A
M<G)A>0H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!U<&1A=&5!='1R:6)U=&5S*"1A='1R:6)U=&5S*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?=7!D871E071T<D%R<F%Y*"1T:&ES+3Y?871T<FEB=71E
M<RP@)'1H:7,M/E]P87)S94%T=')I8G5T97,H)&%T=')I8G5T97,I*3L*("`@
M('T@+R\@96YD(&9U;F,@=7!D871E071T<FEB=71E<PH*("`@("\J*@H@("`@
M("H@4F5M;W9E<R!A;B!A='1R:6)U=&4*("`@("`J(`H@("`@("H@0'!A<F%M
M("`@("!S=')I;F<@("`@)&%T='(@("!!='1R:6)U=&4@;F%M90H@("`@("H@
M0'-I;F-E("`@("`Q+C0*("`@("`J($!A8V-E<W,@("`@<'5B;&EC"B`@("`@
M*B!`<F5T=7)N("`@('9O:60*("`@("`J($!T:')O=W,*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5M;W9E071T<FEB=71E*"1A='1R*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<F5M;W9E071T<B@D871T<BP@)'1H:7,M/E]A='1R:6)U=&5S
M*3L*("`@('T@+R]E;F0@9G5N8R!R96UO=F5!='1R:6)U=&4*"B`@("`O*BH*
M("`@("`J(%-E=',@=&AE(&QI;F4@96YD('-T>6QE('1O(%=I;F1O=W,L($UA
M8RP@56YI>"!O<B!A(&-U<W1O;2!S=')I;F<N"B`@("`@*B`*("`@("`J($!P
M87)A;2`@('-T<FEN9R`@)'-T>6QE("`B=VEN(BP@(FUA8R(L(")U;FEX(B!O
M<B!C=7-T;VT@<W1R:6YG+@H@("`@("H@0'-I;F-E("`@,2XW"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@('9O:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T3&EN945N9"@D<W1Y;&4I"B`@("!["B`@("`@("`@
M<W=I=&-H("@D<W1Y;&4I('L*("`@("`@("`@("`@8V%S92`G=VEN)SH*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;&EN945N9"`](")<,35<,3(B.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)W5N:7@G.@H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L:6YE16YD(#T@(EPQ,B(["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;6%C)SL*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;&EN945N9"`](")<,34B.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VQI;F5%;F0@/2`D<W1Y;&4["B`@("`@("`@?0H@
M("`@?2`O+R!E;F0@9G5N8R!S971,:6YE16YD"@H@("`@+RHJ"B`@("`@*B!3
M971S('1H92!T86(@;V9F<V5T"B`@("`@*@H@("`@("H@0'!A<F%M("`@(&EN
M="`@("`@)&]F9G-E=`H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971486)/9F9S970H)&]F9G-E="D*("`@('L*("`@
M("`@("`D=&AI<RT^7W1A8D]F9G-E="`]("1O9F9S970["B`@("!]("\O(&5N
M9"!F=6YC('-E=%1A8D]F9G-E=`H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@=&%B3V9F<V5T"B`@("`@*B`*("`@("`J($!S:6YC92`@("`@,2XU"B`@
M("`@*B!`86-C97-S("`@('!U8FQI8PH@("`@("H@0')E='5R;B`@("!I;G0*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&%B3V9F<V5T*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]T86)/9F9S970["B`@("!]("\O96YD(&9U
M;F,@9V5T5&%B3V9F<V5T"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!S=')I
M;F<@=7-E9"!T;R!I;F1E;G0@2%1-3`H@("`@("H@"B`@("`@*B!`<VEN8V4@
M("`@(#$N-PH@("`@("H@0'!A<F%M("`@("!S=')I;F<@("`@)'-T<FEN9R`@
M("`@4W1R:6YG('5S960@=&\@:6YD96YT("@B7#$Q(BP@(EQT(BP@)R`@)RP@
M971C+BDN"B`@("`@*B!`86-C97-S("`@('!U8FQI8PH@("`@("H@0')E='5R
M;B`@("!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1A8B@D<W1R:6YG
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&%B(#T@)'-T<FEN9SL*("`@('T@
M+R\@96YD(&9U;F,@<V5T5&%B"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!(
M5$U,(&-O;6UE;G0@=&\@8F4@9&ES<&QA>65D(&%T('1H92!B96=I;FYI;F<@
M;V8@=&AE($A434P@<W1R:6YG"B`@("`@*@H@("`@("H@0'!A<F%M("`@("!S
M=')I;F<*("`@("`J($!S:6YC92`@("`@,2XT"B`@("`@*B!`86-C97-S("`@
M('!U8FQI8PH@("`@("H@0')E='5R;B`@("!V;VED"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$-O;6UE;G0H)&-O;6UE;G0I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]C;VUM96YT(#T@)&-O;6UE;G0["B`@("!]("\O(&5N9"!F=6YC('-E
M=$AT;6Q#;VUM96YT"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!(5$U,
M(&-O;6UE;G0*("`@("`J(`H@("`@("H@0'-I;F-E("`@("`Q+C4*("`@("`J
M($!A8V-E<W,@("`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("`@('-T<FEN9PH@
M("`@("HO"B`@("!F=6YC=&EO;B!G971#;VUM96YT*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]C;VUM96YT.PH@("`@?2`O+V5N9"!F=6YC(&=E
M=$-O;6UE;G0*"B`@("`O*BH*("`@("`J($%B<W1R86-T(&UE=&AO9"X@($UU
M<W0@8F4@97AT96YD960@=&\@<F5T=7)N('1H92!O8FIE8W1S($A434P*("`@
M("`J"B`@("`@*B!`86-C97-S("`@('!U8FQI8PH@("`@("H@0')E='5R;B`@
M("!S=')I;F<*("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO
M;B!T;TAT;6PH*0H@("`@>PH@("`@("`@(')E='5R;B`G)SL*("`@('T@+R\@
M96YD(&9U;F,@=&](=&UL"@H@("`@+RHJ"B`@("`@*B!$:7-P;&%Y<R!T:&4@
M2%1-3"!T;R!T:&4@<V-R965N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@("!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES<&QA>2@I"B`@("!["B`@
M("`@("`@<')I;G0@)'1H:7,M/G1O2'1M;"@I.PH@("`@?2`O+R!E;F0@9G5N
M8R!D:7-P;&%Y"@I]("\O(&5N9"!C;&%S<R!(5$U,7T-O;6UO;@H_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+T-R>7!T+P``````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S
M,#`V`#`Q-C0T-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0W)Y<'0O
M4F,T+G!H<```````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3`R,38`,3`T,3<S-C,P,#8`,#$W-C`R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X
M<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S
M.B!$879E($UE<G1E;G,@/&1M97)T96YS0'IY<')E>&EA+F-O;3X@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+PHO+R`D260Z(%)C-"YP:'`L=B`Q+C8@,C`P,R\Q,"\P-"`Q-CHS
M.3HS,B!Z>7!R97AI82!%>'`@)`H*"B\J*@HJ(%)#-"!S=')E86T@8VEP:&5R
M(')O=71I;F5S(&EM<&QE;65N=&%T:6]N"BH**B!I;B!02%`T(&)A<V5D(&]N
M(&-O9&4@=W)I='1E;B!B>2!$86UI96X@36EL;&5R(#QD:FU`;6EN9')O="YO
M<F<^"BH**B!5<V%G93H**B`D:V5Y(#T@(G!E87(B.PHJ("1M97-S86=E(#T@
M(E!%05(@<G5L97HA(CL**@HJ("1R8S0@/2!N97<@0W)Y<'1?4D,T.PHJ("1R
M8S0M/FME>2@D:V5Y*3L**B!E8VAO(")/<FEG:6YA;"!M97-S86=E.B`D;65S
M<V%G92`\8G(^7&XB.PHJ("1R8S0M/F-R>7!T*"1M97-S86=E*3L**B!E8VAO
M(")%;F-R>7!T960@;65S<V%G93H@)&UE<W-A9V4@/&)R/EQN(CL**B`D<F,T
M+3YD96-R>7!T*"1M97-S86=E*3L**B!E8VAO(")$96-R>7!T960@;65S<V%G
M93H@)&UE<W-A9V4@/&)R/EQN(CL**@HJ($!V97)S:6]N("12979I<VEO;CH@
M,2XV("0**B!`86-C97-S('!U8FQI8PHJ($!P86-K86=E($-R>7!T"BH@0&%U
M=&AO<B!$879E($UE<G1E;G,@/&1M97)T96YS0'IY<')E>&EA+F-O;3X*("HO
M"F-L87-S($-R>7!T7U)#-"!["@H@("`@+RHJ"B`@("`J(%)E86P@<')O9W)A
M;6UE<G,N+BX*("`@("H@0'9A<B!A<G)A>0H@("`@*B\*("`@('9A<B`D<ST@
M87)R87DH*3L*("`@("\J*@H@("`@*B!296%L('!R;V=R86UM97)S+BXN"B`@
M("`J($!V87(@87)R87D*("`@("HO"B`@("!V87(@)&D](#`["B`@("`O*BH*
M("`@("H@4F5A;"!P<F]G<F%M;65R<RXN+@H@("`@*B!`=F%R(&%R<F%Y"B`@
M("`J+PH@("`@=F%R("1J/2`P.PH*("`@("\J*@H@("`@*B!+97D@:&]L9&5R
M"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?:V5Y.PH*("`@
M("\J*@H@("`@*B!#;VYS=')U8W1O<@H@("`@*B!087-S(&5N8W)Y<'1I;VX@
M:V5Y('1O(&ME>2@I"B`@("`J"B`@("`J($!S964@("`@:V5Y*"D@"B`@("`J
M($!P87)A;2`@<W1R:6YG(&ME>2`@("`M($ME>2!W:&EC:"!W:6QL(&)E('5S
M960@9F]R(&5N8W)Y<'1I;VX*("`@("H@0')E='5R;B!V;VED"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@0W)Y<'1?4D,T*"1K
M97D@/2!N=6QL*2!["B`@("`@("`@:68@*"1K97D@(3T@;G5L;"D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T2V5Y*"1K97DI.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!S971+97DH)&ME>2D@>PH@("`@("`@(&EF("AS=')L
M96XH)&ME>2D@/B`P*0H@("`@("`@("`@("`D=&AI<RT^7VME>2`]("1K97D[
M"B`@("!]"@H@("`@+RHJ"B`@("`J($%S<VEG;B!E;F-R>7!T:6]N(&ME>2!T
M;R!C;&%S<PH@("`@*@H@("`@*B!`<&%R86T@('-T<FEN9R!K97D)+2!+97D@
M=VAI8V@@=VEL;"!B92!U<V5D(&9O<B!E;F-R>7!T:6]N"B`@("`J($!R971U
M<FX@=F]I9`H@("`@*B!`86-C97-S('!U8FQI8R`@("`*("`@("HO"B`@("!F
M=6YC=&EO;B!K97DH)B1K97DI('L*("`@("`@("`D;&5N/2!S=')L96XH)&ME
M>2D["B`@("`@("`@9F]R("@D=&AI<RT^:2`](#`[("1T:&ES+3YI(#P@,C4V
M.R`D=&AI<RT^:2LK*2!["B`@("`@("`@("`@("1T:&ES+3YS6R1T:&ES+3YI
M72`]("1T:&ES+3YI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FH@/2`P
M.PH@("`@("`@(&9O<B`H)'1H:7,M/FD@/2`P.R`D=&AI<RT^:2`\(#(U-CL@
M)'1H:7,M/FDK*RD@>PH@("`@("`@("`@("`D=&AI<RT^:B`]("@D=&AI<RT^
M:B`K("1T:&ES+3YS6R1T:&ES+3YI72`K(&]R9"@D:V5Y6R1T:&ES+3YI("4@
M)&QE;ETI*2`E(#(U-CL*("`@("`@("`@("`@)'0@/2`D=&AI<RT^<ULD=&AI
M<RT^:5T["B`@("`@("`@("`@("1T:&ES+3YS6R1T:&ES+3YI72`]("1T:&ES
M+3YS6R1T:&ES+3YJ73L*("`@("`@("`@("`@)'1H:7,M/G-;)'1H:7,M/FI=
M(#T@)'0["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YI(#T@)'1H:7,M/FH@
M/2`P.PH@("`@?0H*("`@("\J*@H@("`@*B!%;F-R>7!T(&9U;F-T:6]N"B`@
M("`J"B`@("`J($!P87)A;2`@<W1R:6YG('!A<F%M<W1R(`DM('-T<FEN9R!T
M:&%T('=I;&P@96YC<GEP=&5D"B`@("`J($!R971U<FX@=F]I9`H@("`@*B!`
M86-C97-S('!U8FQI8R`@("`*("`@("HO"B`@("!F=6YC=&EO;B!C<GEP="@F
M)'!A<F%M<W1R*2!["@H@("`@("`@("\O26YI="!K97D@9F]R(&5V97)Y(&-A
M;&PL($)U9V9I>"`R,C,Q-@H@("`@("`@("1T:&ES+3YK97DH)'1H:7,M/E]K
M97DI.PH*("`@("`@("`D;&5N/2!S=')L96XH)'!A<F%M<W1R*3L*("`@("`@
M("!F;W(@*"1C/2`P.R`D8R`\("1L96X[("1C*RLI('L*("`@("`@("`@("`@
M)'1H:7,M/FD@/2`H)'1H:7,M/FD@*R`Q*2`E(#(U-CL*("`@("`@("`@("`@
M)'1H:7,M/FH@/2`H)'1H:7,M/FH@*R`D=&AI<RT^<ULD=&AI<RT^:5TI("4@
M,C4V.PH@("`@("`@("`@("`D="`]("1T:&ES+3YS6R1T:&ES+3YI73L*("`@
M("`@("`@("`@)'1H:7,M/G-;)'1H:7,M/FE=(#T@)'1H:7,M/G-;)'1H:7,M
M/FI=.PH@("`@("`@("`@("`D=&AI<RT^<ULD=&AI<RT^:ET@/2`D=#L*"B`@
M("`@("`@("`@("1T(#T@*"1T:&ES+3YS6R1T:&ES+3YI72`K("1T:&ES+3YS
M6R1T:&ES+3YJ72D@)2`R-38["@H@("`@("`@("`@("`D<&%R86US=');)&-=
M(#T@8VAR*&]R9"@D<&%R86US=');)&-=*2!>("1T:&ES+3YS6R1T72D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!$96-R>7!T(&9U;F-T:6]N
M"B`@("`J"B`@("`J($!P87)A;2`@<W1R:6YG('!A<F%M<W1R(`DM('-T<FEN
M9R!T:&%T('=I;&P@9&5C<GEP=&5D"B`@("`J($!R971U<FX@=F]I9`H@("`@
M*B!`86-C97-S('!U8FQI8R`@("`*("`@("HO"B`@("!F=6YC=&EO;B!D96-R
M>7!T*"8D<&%R86US='(I('L*("`@("`@("`O+T1E8W)Y<'0@:7,@97AA8W1L
M>2!T:&4@<V%M92!A<R!E;F-R>7!T:6YG('1H92!S=')I;F<N(%)E=7-E("AE
M;BEC<GEP="!C;V1E"B`@("`@("`@)'1H:7,M/F-R>7!T*"1P87)A;7-T<BD[
M"B`@("!]"@H*?0DO+V5N9"!O9B!20S0@8VQA<W,*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+P``````````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,S`P-@`P,38P-S(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!%05(O0V]M;6%N9"\`````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`V`#`Q-S0U,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U)E;6]T92YP:'``````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S4T,#``,3`T,3<S-C,P,#8`
M,#(Q-#$S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\O("\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!02%`@5F5R<VEO;B`U("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%-T:6<@0F%K:V5N(#QS<V)`
M<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!296UO=&4N<&AP+'8@,2XS
M-R`R,#`T+S`Q+S`X(#$W.C,S.C$S('-N:7!E<B!%>'`@)`H*<F5Q=6ER95]O
M;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H<"<["G)E<75I<F5?;VYC92`G
M4$5!4B]#;VUM;VXN<&AP)SL*<F5Q=6ER95]O;F-E("=014%2+U)E;6]T92YP
M:'`G.PIR97%U:7)E7V]N8V4@)U!%05(O4F5G:7-T<GDN<&AP)SL*"F-L87-S
M(%!%05)?0V]M;6%N9%]296UO=&4@97AT96YD<R!014%27T-O;6UA;F1?0V]M
M;6]N"GL*("`@("\O('M[>R!C;VUM86YD(&1E9FEN:71I;VYS"@H@("`@=F%R
M("1C;VUM86YD<R`](&%R<F%Y*`H@("`@("`@("=R96UO=&4M:6YF;R<@/3X@
M87)R87DH"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G26YF;W)M871I;VX@
M06)O=70@4F5M;W1E(%!A8VMA9V5S)RP*("`@("`@("`@("`@)V9U;F-T:6]N
M)R`]/B`G9&]296UO=&5);F9O)RP*("`@("`@("`@("`@)W-H;W)T8W5T)R`]
M/B`G<FDG+`H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P*("`@
M("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/@I'970@9&5T86EL<R!O;B!A
M('!A8VMA9V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("DL"B`@
M("`@("`@)VQI<W0M=7!G<F%D97,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M<W5M;6%R>2<@/3X@)TQI<W0@079A:6QA8FQE(%5P9W)A9&5S)RP*("`@("`@
M("`@("`@)V9U;F-T:6]N)R`]/B`G9&],:7-T57!G<F%D97,G+`H@("`@("`@
M("`@("`G<VAO<G1C=70G(#T^("=L=2<L"B`@("`@("`@("`@("=O<'1I;VYS
M)R`]/B!A<G)A>2@I+`H@("`@("`@("`@("`G9&]C)R`]/B`G"DQI<W0@<F5L
M96%S97,@;VX@=&AE('-E<G9E<B!O9B!P86-K86=E<R!Y;W4@:&%V92!I;G-T
M86QL960@=VAE<F4*82!N97=E<B!V97)S:6]N(&ES(&%V86EL86)L92!W:71H
M('1H92!S86UE(')E;&5A<V4@<W1A=&4@*'-T86)L92!E=&,N*2XG"B`@("`@
M("`@("`@("DL"B`@("`@("`@)W)E;6]T92UL:7-T)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)W-U;6UA<GDG(#T^("=,:7-T(%)E;6]T92!086-K86=E<R<L
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4F5M;W1E3&ES="<L"B`@
M("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)L)RP*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*"DL"B`@("`@("`@("`@("=D;V,G(#T^("<*3&ES
M=',@=&AE('!A8VMA9V5S(&%V86EL86)L92!O;B!T:&4@8V]N9FEG=7)E9"!S
M97)V97(@86QO;F<@=VET:"!T:&4*;&%T97-T('-T86)L92!R96QE87-E(&]F
M(&5A8V@@<&%C:V%G92XG+`H@("`@("`@("`@("`I+`H@("`@("`@("=S96%R
M8V@G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U-E87)C
M:"!R96UO=&4@<&%C:V%G92!D871A8F%S92<L"B`@("`@("`@("`@("=F=6YC
M=&EO;B<@/3X@)V1O4V5A<F-H)RP*("`@("`@("`@("`@)W-H;W)T8W5T)R`]
M/B`G<W`G+`H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P*("`@
M("`@("`@("`@)V1O8R<@/3X@)PI,:7-T<R!A;&P@<&%C:V%G97,@=VAI8V@@
M;6%T8V@@=&AE('-E87)C:"!P87)A;65T97)S("AF:7)S="!P87)A;0II<R!P
M86-K86=E(&YA;64L('-E8V]N9"!P86-K86=E(&EN9F\I)RP*("`@("`@("`@
M("`@*2P*("`@("`@("`G;&ES="UA;&PG(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`G<W5M;6%R>2<@/3X@)TQI<W0@06QL(%!A8VMA9V5S)RP*("`@("`@("`@
M("`@)V9U;F-T:6]N)R`]/B`G9&],:7-T06QL)RP*("`@("`@("`@("`@)W-H
M;W)T8W5T)R`]/B`G;&$G+`H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R
M87DH*2P*("`@("`@("`@("`@)V1O8R<@/3X@)PI,:7-T<R!T:&4@<&%C:V%G
M97,@879A:6QA8FQE(&]N('1H92!C;VYF:6=U<F5D('-E<G9E<B!A;&]N9R!W
M:71H('1H90IL871E<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P86-K86=E
M+B<L"B`@("`@("`@("`@("DL"B`@("`@("`@)V1O=VYL;V%D)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=$;W=N;&]A9"!086-K86=E
M)RP*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]$;W=N;&]A9"<L"B`@
M("`@("`@("`@("=S:&]R=&-U="<@/3X@)V0G+`H@("`@("`@("`@("`G;W!T
M:6]N<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M6B<L"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O=VYL;V%D(&%N
M('5N8V]M<')E<W-E9"`H+G1A<BD@9FEL92<L"B`@("`@("`@("`@("`@("`@
M("`@*2P*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("=D;V,G(#T^
M("=[<&%C:V%G97QP86-K86=E+79E<G-I;VY]"D1O=VYL;V%D(&$@<&%C:V%G
M92!T87)B86QL+B`@5&AE(&9I;&4@=VEL;"!B92!N86UE9"!A<R!S=6=G97-T
M960@8GD@=&AE"G-E<G9E<BP@9F]R(&5X86UP;&4@:68@>6]U(&1O=VYL;V%D
M('1H92!$0B!P86-K86=E(&%N9"!T:&4@;&%T97-T('-T86)L90IV97)S:6]N
M(&]F($1"(&ES(#$N,BP@=&AE(&1O=VYL;V%D960@9FEL92!W:6QL(&)E($1"
M+3$N,BYT9WHN)RP*("`@("`@("`@("`@*2P*("`@("`@("`G8VQE87(M8V%C
M:&4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T-L96%R
M(%A-3"U24$,@0V%C:&4G+`H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;T-L96%R0V%C:&4G+`H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C8R<L
M"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`H@("`@("`@("`@
M("`G9&]C)R`]/B`G"D-L96%R('1H92!834PM4E!#(&-A8VAE+B`@4V5E(&%L
M<V\@=&AE(&-A8VAE7W1T;"!C;VYF:6=U<F%T:6]N"G!A<F%M971E<BX*)RP*
M("`@("`@("`@("`@*2P*("`@("`@("`I.PH*("`@("\O('U]?0H@("`@+R\@
M>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!014%27T-O;6UA;F1?
M4F5M;W1E(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]296UO=&4H
M)B1U:2P@)B1C;VYF:6<I"B`@("!["B`@("`@("`@<&%R96YT.CI014%27T-O
M;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I9RD["B`@("!]"@H@("`@+R\@?7U]
M"@H@("`@+R\@>WM[(&1O4F5M;W1E26YF;R@I"@H@("`@9G5N8W1I;VX@9&]2
M96UO=&5);F9O*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD*("`@('L*
M("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9"!E>'!E8W1S
M(&]N92!P87)A;3H@=&AE(')E;6]T92!P86-K86=E(&YA;64B*3L*("`@("`@
M("!]"B`@("`@("`@)'(@/2!N97<@4$5!4E]296UO=&4H)'1H:7,M/F-O;F9I
M9RD["B`@("`@("`@)&EN9F\@/2`D<BT^8V%L;"@G<&%C:V%G92YI;F9O)RP@
M)'!A<F%M<ULP72D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF
M;RD["B`@("`@("`@?0H*("`@("`@("`D<F5G(#T@;F5W(%!%05)?4F5G:7-T
M<GDH)'1H:7,M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RDI.PH@("`@("`@("1I
M;G-T86QL960@/2`D<F5G+3YP86-K86=E26YF;R@D:6YF;ULG;F%M92==*3L*
M("`@("`@("`D:6YF;ULG:6YS=&%L;&5D)UT@/2`D:6YS=&%L;&5D6R=V97)S
M:6]N)UT@/R`D:6YS=&%L;&5D6R=V97)S:6]N)UT@.B`G+2!N;R`M)SL*"B`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1I;F9O+"`D8V]M;6%N9"D[
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&1O4F5M;W1E3&ES="@I"@H@("`@9G5N8W1I;VX@9&]296UO=&5,
M:7-T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD*("`@('L*("`@("`@
M("`D<B`](&YE=R!014%27U)E;6]T92@D=&AI<RT^8V]N9FEG*3L*("`@("`@
M("`D;&ES=%]O<'1I;VYS(#T@9F%L<V4["B`@("`@("`@:68@*"1T:&ES+3YC
M;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RD@/3T@)W-T86)L92<I"B`@
M("`@("`@("`@("1L:7-T7V]P=&EO;G,@/2!T<G5E.PH@("`@("`@("1A=F%I
M;&%B;&4@/2`D<BT^8V%L;"@G<&%C:V%G92YL:7-T06QL)RP@)&QI<W1?;W!T
M:6]N<RD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&%V86EL86)L92DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1A=F%I
M;&%B;&4I.PH@("`@("`@('T*("`@("`@("`D:2`]("1J(#T@,#L*("`@("`@
M("`D9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)T%V
M86EL86)L92!P86-K86=E<SHG+`H@("`@("`@("`@("`G8F]R9&5R)R`]/B!T
M<G5E+`H@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*"=086-K86=E
M)RP@)U9E<G-I;VXG*2P*("`@("`@("`@("`@*3L*("`@("`@("!F;W)E86-H
M("@D879A:6QA8FQE(&%S("1N86UE(#T^("1I;F9O*2!["B`@("`@("`@("`@
M("1D871A6R=D871A)UU;72`](&%R<F%Y*"1N86UE+"!I<W-E="@D:6YF;ULG
M<W1A8FQE)UTI(#\@)&EN9F];)W-T86)L92==(#H@)RUN+V$M)RD["B`@("`@
M("`@?0H@("`@("`@(&EF("AC;W5N="@D879A:6QA8FQE*3T],"D@>PH@("`@
M("`@("`@("`D9&%T82`]("<H;F\@<&%C:V%G97,@:6YS=&%L;&5D('EE="DG
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A
M=&$L("1C;VUM86YD*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!D;TQI<W1!;&PH*0H*("`@(&9U;F-T:6]N
M(&1O3&ES=$%L;"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("![
M"B`@("`@("`@)'(@/2!N97<@4$5!4E]296UO=&4H)'1H:7,M/F-O;F9I9RD[
M"B`@("`@("`@)')E9R`](&YE=R!014%27U)E9VES=')Y*"1T:&ES+3YC;VYF
M:6<M/F=E="@G<&AP7V1I<B<I*3L*("`@("`@("`D;&ES=%]O<'1I;VYS(#T@
M9F%L<V4["B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R
M<F5D7W-T871E)RD@/3T@)W-T86)L92<I"B`@("`@("`@("`@("1L:7-T7V]P
M=&EO;G,@/2!T<G5E.PH@("`@("`@("1A=F%I;&%B;&4@/2`D<BT^8V%L;"@G
M<&%C:V%G92YL:7-T06QL)RP@)&QI<W1?;W!T:6]N<RD["B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&%V86EL86)L92DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"1A=F%I;&%B;&4I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A=F%I;&%B;&4I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G5&AE('!A8VMA9V4@;&ES
M="!C;W5L9"!N;W0@8F4@9F5T8VAE9"!F<F]M('1H92!R96UO=&4@<V5R=F5R
M+B!0;&5A<V4@=')Y(&%G86EN+B`H1&5B=6<@:6YF;SH@(B<N)&%V86EL86)L
M92XG(BDG*3L*("`@("`@("!]"B`@("`@("`@)&1A=&$@/2!A<G)A>2@*("`@
M("`@("`@("`@)V-A<'1I;VXG(#T^("=!;&P@<&%C:V%G97,Z)RP*("`@("`@
M("`@("`@)V)O<F1E<B<@/3X@=')U92P*("`@("`@("`@("`@)VAE861L:6YE
M)R`]/B!A<G)A>2@G4&%C:V%G92<L("=,871E<W0G+"`G3&]C86PG*2P*("`@
M("`@("`@("`@*3L*("`@("`@("`D;&]C86Q?<&MG<R`]("1R96<M/FQI<W10
M86-K86=E<R@I.PH@("`@("`@(`H@("`@("`@(&9O<F5A8V@@*"1A=F%I;&%B
M;&4@87,@)&YA;64@/3X@)&EN9F\I('L*("`@("`@("`@("`@)&EN<W1A;&QE
M9"`]("1R96<M/G!A8VMA9V5);F9O*"1N86UE*3L*("`@("`@("`@("`@)&1E
M<V,@/2`D:6YF;ULG<W5M;6%R>2==.PH@("`@("`@("`@("!I9B`H:7-S970H
M)'!A<F%M<ULD;F%M95TI*0H@("`@("`@("`@("`@("`@)&1E<V,@+CT@(EQN
M7&XB+B1I;F9O6R=D97-C<FEP=&EO;B==.PH*("`@("`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=M;V1E)UTI*0H@("`@("`@("`@("!["B`@("`@("`@
M("`@("`@("!I9B`H)&]P=&EO;G-;)VUO9&4G72`]/2`G:6YS=&%L;&5D)R`F
M)B`A:7-S970H)&EN<W1A;&QE9%LG=F5R<VEO;B==*2D*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@(&EF("@D;W!T:6]N
M<ULG;6]D92==(#T]("=N;W1I;G-T86QL960G("8F(&ES<V5T*"1I;G-T86QL
M961;)W9E<G-I;VXG72DI"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;G-;)VUO9&4G72`]/2`G=7!G
M<F%D97,G"B`@("`@("`@("`@("`@("`@("`@)B8@*"%I<W-E="@D:6YS=&%L
M;&5D6R=V97)S:6]N)UTI('Q\("1I;G-T86QL961;)W9E<G-I;VXG72`]/2`D
M:6YF;ULG<W1A8FQE)UTI*0H@("`@("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1P;W,@/2!A<G)A>5]S96%R8V@H<W1R=&]L
M;W=E<B@D;F%M92DL("1L;V-A;%]P:V=S*3L*("`@("`@("`@("`@:68@*"1P
M;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!U;G-E="@D;&]C86Q?
M<&MG<ULD<&]S72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1D871A
M6R=D871A)UU;)&EN9F];)V-A=&5G;W)Y)UU=6UT@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("1N86UE+`H@("`@("`@("`@("`@("`@0"1I;F9O6R=S=&%B
M;&4G72P*("`@("`@("`@("`@("`@($`D:6YS=&%L;&5D6R=V97)S:6]N)UTL
M"B`@("`@("`@("`@("`@("!`)&1E<V,L"B`@("`@("`@("`@("`@("!`)&EN
M9F];)V1E<',G72P*("`@("`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@
M("`@(`H@("`@("`@(&9O<F5A8V@@*"1L;V-A;%]P:V=S(&%S("1N86UE*2![
M"B`@("`@("`@("`@("1I;F9O(#T@)')E9RT^<&%C:V%G94EN9F\H)&YA;64I
M.PH@("`@("`@("`@("`D9&%T85LG9&%T82==6R=,;V-A;"==6UT@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("1I;F9O6R=P86-K86=E)UTL(`H@("`@("`@
M("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`D:6YF;ULG=F5R<VEO;B==
M+`H@("`@("`@("`@("`@("`@)&EN9F];)W-U;6UA<GDG72P*("`@("`@("`@
M("`@("`@($`D:6YF;ULG<F5L96%S95]D97!S)UT*("`@("`@("`@("`@("`@
M("D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H
M)&1A=&$L("1C;VUM86YD*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!D;U-E87)C:"@I"@H@("`@9G5N8W1I
M;VX@9&]396%R8V@H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0H@("`@
M>PH@("`@("`@(&EF("@H(6ES<V5T*"1P87)A;7-;,%TI('Q\(&5M<'1Y*"1P
M87)A;7-;,%TI*0H@("`@("`@("`@("`F)B`H(6ES<V5T*"1P87)A;7-;,5TI
M('Q\(&5M<'1Y*"1P87)A;7-;,5TI*2D*("`@("`@("!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F\@=F%L:60@<V5A<F-H('-T
M<FEN9R!S=7!P;&EE9"<I.PH@("`@("`@('T["@H@("`@("`@("1R(#T@;F5W
M(%!%05)?4F5M;W1E*"1T:&ES+3YC;VYF:6<I.PH@("`@("`@("1R96<@/2!N
M97<@4$5!4E]296=I<W1R>2@D=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G
M*2D["B`@("`@("`@)&%V86EL86)L92`]("1R+3YC86QL*"=P86-K86=E+FQI
M<W1!;&PG+"!T<G5E*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D879A
M:6QA8FQE*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)&%V86EL86)L92D["B`@("`@("`@?0H@("`@("`@("1D871A(#T@87)R
M87DH"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`G36%T8VAE9"!P86-K86=E
M<SHG+`H@("`@("`@("`@("`G8F]R9&5R)R`]/B!T<G5E+`H@("`@("`@("`@
M("`G:&5A9&QI;F4G(#T^(&%R<F%Y*"=086-K86=E)RP@)TQA=&5S="<L("=,
M;V-A;"<I+`H@("`@("`@("`@("`I.PH*("`@("`@("!F;W)E86-H("@D879A
M:6QA8FQE(&%S("1N86UE(#T^("1I;F9O*2!["B`@("`@("`@("`@("1F;W5N
M9"`]("@A96UP='DH)'!A<F%M<ULP72D@)B8@<W1R:7-T<B@D;F%M92P@)'!A
M<F%M<ULP72D@(3T](&9A;'-E*3L*("`@("`@("`@("`@:68@*"$D9F]U;F0@
M)B8@(2AI<W-E="@D<&%R86US6S%=*2`F)B`A96UP='DH)'!A<F%M<ULQ72D*
M("`@("`@("`@("`@("`@("8F("AS=')I<W1R*"1I;F9O6R=S=6UM87)Y)UTL
M("1P87)A;7-;,5TI("$]/2!F86QS90H@("`@("`@("`@("`@("`@("`@('Q\
M('-T<FES='(H)&EN9F];)V1E<V-R:7!T:6]N)UTL("1P87)A;7-;,5TI("$]
M/2!F86QS92DI*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?3L*"B`@("`@("`@("`@("1I;G-T86QL960@
M/2`D<F5G+3YP86-K86=E26YF;R@D;F%M92D["B`@("`@("`@("`@("1D97-C
M(#T@)&EN9F];)W-U;6UA<GDG73L*("`@("`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)&YA;65=*2D*("`@("`@("`@("`@("`@("1D97-C("X](")<;EQN
M(BXD:6YF;ULG9&5S8W)I<'1I;VXG73L*"B`@("`@("`@("`@("1D871A6R=D
M871A)UU;)&EN9F];)V-A=&5G;W)Y)UU=6UT@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("1N86UE+`H@("`@("`@("`@("`@("`@)&EN9F];)W-T86)L92==
M+`H@("`@("`@("`@("`@("`@)&EN<W1A;&QE9%LG=F5R<VEO;B==+`H@("`@
M("`@("`@("`@("`@)&1E<V,L"B`@("`@("`@("`@("`@("`I.PH@("`@("`@
M('T*("`@("`@("!I9B`H(6ES<V5T*"1D871A6R=D871A)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F\@<&%C:V%G97,@
M9F]U;F0G*3L*("`@("`@("!].PH@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@D9&%T82P@)&-O;6UA;F0I.PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1O1&]W;FQO860H*0H*("`@
M(&9U;F-T:6]N(&1O1&]W;FQO860H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R
M86US*0H@("`@>PH@("`@("`@("\O)'!A<F%M<ULP72`M/B!4:&4@<&%C:V%G
M92!T;R!D;W=N;&]A9`H@("`@("`@(&EF("AC;W5N="@D<&%R86US*2`A/2`Q
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")D;W=N
M;&]A9"!E>'!E8W1S(&]N92!A<F=U;65N=#H@=&AE('!A8VMA9V4@=&\@9&]W
M;FQO860B*3L*("`@("`@("!]"B`@("`@("`@)'-E<G9E<B`]("1T:&ES+3YC
M;VYF:6<M/F=E="@G;6%S=&5R7W-E<G9E<B<I.PH@("`@("`@(&EF("@A97)E
M9R@G7FAT='`Z+R\G+"`D<&%R86US6S!=*2D@>PH@("`@("`@("`@("`D9V5T
M;W!T:6]N(#T@:7-S970H)&]P=&EO;G-;)VYO8V]M<')E<W,G72DF)B1O<'1I
M;VYS6R=N;V-O;7!R97-S)UT]/3$_)S]U;F-O;7!R97-S/6]N)SHG)SL*("`@
M("`@("`@("`@)'!K9V9I;&4@/2`B:'1T<#HO+R1S97)V97(O9V5T+R1P87)A
M;7-;,%TB+B1G971O<'1I;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'!K9V9I;&4@/2`D<&%R86US6S!=.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^8GET97-?9&]W;FQO861E9"`](#`["B`@("`@("`@)'-A=F5D(#T@
M4$5!4E]#;VUM;VXZ.F1O=VYL;V%D2'1T<"@D<&MG9FEL92P@)'1H:7,M/G5I
M+"`G+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@F)'1H:7,L("=D;W=N;&]A9$-A;&QB86-K)RDI.PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1S879E9"DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1S879E9"D["B`@("`@("`@?0H@
M("`@("`@("1F;F%M92`](&)A<V5N86UE*"1S879E9"D["B`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*")&:6QE("1F;F%M92!D;W=N;&]A9&5D("@D
M=&AI<RT^8GET97-?9&]W;FQO861E9"!B>71E<RDB+"`D8V]M;6%N9"D["B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@9&]W;FQO
M861#86QL8F%C:R@D;7-G+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H)&US9R`]/2`G9&]N92<I('L*("`@("`@("`@("`@)'1H:7,M/F)Y
M=&5S7V1O=VYL;V%D960@/2`D<&%R86US.PH@("`@("`@('T*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!D;TQI<W15<&=R861E<R@I"@H@("`@9G5N
M8W1I;VX@9&],:7-T57!G<F%D97,H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R
M86US*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`B4$5!4B]296=I<W1R
M>2YP:'`B.PH@("`@("`@("1R96UO=&4@/2!N97<@4$5!4E]296UO=&4H)'1H
M:7,M/F-O;F9I9RD["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;,%TI*2![
M"B`@("`@("`@("`@("1S=&%T92`]("1T:&ES+3YC;VYF:6<M/F=E="@G<')E
M9F5R<F5D7W-T871E)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'-T871E(#T@)'!A<F%M<ULP73L*("`@("`@("!]"B`@("`@("`@)&-A<'1I
M;VX@/2`G079A:6QA8FQE(%5P9W)A9&5S)SL*("`@("`@("!I9B`H96UP='DH
M)'-T871E*2!\?"`D<W1A=&4@/3T@)V%N>2<I('L*("`@("`@("`@("`@)&QA
M=&5S="`]("1R96UO=&4M/F-A;&PH(G!A8VMA9V4N;&ES=$QA=&5S=%)E;&5A
M<V5S(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&QA=&5S="`]
M("1R96UO=&4M/F-A;&PH(G!A8VMA9V4N;&ES=$QA=&5S=%)E;&5A<V5S(BP@
M)'-T871E*3L*("`@("`@("`@("`@)&-A<'1I;VX@+CT@)R`H)R`N(&EM<&QO
M9&4H)RP@)RP@4$5!4E]#;VUM;VXZ.F)E='1E<E-T871E<R@D<W1A=&4L('1R
M=64I*2`N("<I)SL*("`@("`@("!]"B`@("`@("`@)&-A<'1I;VX@+CT@)SHG
M.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1L871E<W0I*2!["B`@("`@
M("`@("`@(')E='5R;B`D;&%T97-T.PH@("`@("`@('T*("`@("`@("`D<F5G
M(#T@;F5W(%!%05)?4F5G:7-T<GDH)'1H:7,M/F-O;F9I9RT^9V5T*"=P:'!?
M9&ER)RDI.PH@("`@("`@("1I;G-T(#T@87)R87E?9FQI<"@D<F5G+3YL:7-T
M4&%C:V%G97,H*2D["B`@("`@("`@)&1A=&$@/2!A<G)A>2@*("`@("`@("`@
M("`@)V-A<'1I;VXG(#T^("1C87!T:6]N+`H@("`@("`@("`@("`G8F]R9&5R
M)R`]/B`Q+`H@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*"=086-K
M86=E)RP@)TQO8V%L)RP@)U)E;6]T92<L("=3:7IE)RDL"B`@("`@("`@("`@
M("D["B`@("`@("`@9F]R96%C:"`H*&%R<F%Y*21L871E<W0@87,@)'!K9R`]
M/B`D:6YF;RD@>PH@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H
M)'!K9RD["B`@("`@("`@("`@(&EF("@A:7-S970H)&EN<W1;)'!A8VMA9V5=
M*2D@>PH@("`@("`@("`@("`@("`@+R\@<VMI<"!P86-K86=E<R!W92!D;VXG
M="!H879E(&EN<W1A;&QE9`H@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@97AT<F%C="@D:6YF;RD["B`@("`@
M("`@("`@("1P:V=I;F9O(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4I
M.PH@("`@("`@("`@("`D:6YS=%]V97)S:6]N(#T@)'!K9VEN9F];)W9E<G-I
M;VXG73L*("`@("`@("`@("`@)&EN<W1?<W1A=&4@("`]("1P:V=I;F9O6R=R
M96QE87-E7W-T871E)UT["B`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A
M<F4H(B1V97)S:6]N(BP@(B1I;G-T7W9E<G-I;VXB+"`B;&4B*2D@>PH@("`@
M("`@("`@("`@("`@+R\@:6YS=&%L;&5D('9E<G-I;VX@:7,@=7`M=&\M9&%T
M90H@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"1F:6QE<VEZ92`^/2`R,#0X,"D@>PH@("`@("`@("`@
M("`@("`@)&9I;&5S:7IE("L](#$P,C0@+2`H)&9I;&5S:7IE("4@,3`R-"D[
M"B`@("`@("`@("`@("`@("`D9G,@/2!S<')I;G1F*"(E9&M"(BP@)&9I;&5S
M:7IE("\@,3`R-"D["B`@("`@("`@("`@('T@96QS96EF("@D9FEL97-I>F4@
M/B`P*2!["B`@("`@("`@("`@("`@("`D9FEL97-I>F4@*ST@,3`S("T@*"1F
M:6QE<VEZ92`E(#$P,RD["B`@("`@("`@("`@("`@("`D9G,@/2!S<')I;G1F
M*"(E+C%F:T(B+"`D9FEL97-I>F4@+R`Q,#(T+C`I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&9S(#T@(B`@+2([("\O(%A86"!C
M96YT97(@:6YS=&5A9`H@("`@("`@("`@("!]"B`@("`@("`@("`@("1D871A
M6R=D871A)UU;72`](&%R<F%Y*"1P:V<L("(D:6YS=%]V97)S:6]N("@D:6YS
M=%]S=&%T92DB+"`B)'9E<G-I;VX@*"1S=&%T92DB+"`D9G,I.PH@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&1A=&%;)V1A=&$G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=.;R!U<&=R861E<R!A=F%I
M;&%B;&4G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9&]#;&5A<D-A8VAE*"D*"B`@("!F=6YC=&EO;B!D;T-L96%R0V%C:&4H
M)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0H@("`@>PH@("`@("`@("1C
M86-H95]D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A8VAE7V1I<B<I.PH@
M("`@("`@("1V97)B;W-E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E
M)RD["B`@("`@("`@)&]U='!U="`]("<G.PH@("`@("`@(&EF("@A*"1D<"`]
M($!O<&5N9&ER*"1C86-H95]D:7(I*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(F]P96YD:7(H)&-A8VAE7V1I<BD@9F%I;&5D
M.B`D<&AP7V5R<F]R;7-G(BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=F5R
M8F]S92`^/2`Q*2!["B`@("`@("`@("`@("1O=71P=70@+CT@(G)E861I;F<@
M9&ER96-T;W)Y("1C86-H95]D:7)<;B(["B`@("`@("`@?0H@("`@("`@("1N
M=6T@/2`P.PH@("`@("`@('=H:6QE("@D96YT(#T@<F5A9&1I<B@D9'`I*2![
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7GAM;')P8U]C86-H95];
M82UZ,"TY77LS,GTD+R<L("1E;G0I*2!["B`@("`@("`@("`@("`@("`D<&%T
M:"`]("1C86-H95]D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&5N=#L*
M("`@("`@("`@("`@("`@("1O:R`]($!U;FQI;FLH)'!A=&@I.PH@("`@("`@
M("`@("`@("`@:68@*"1O:RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M=F5R8F]S92`^/2`R*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@(F1E;&5T960@)'!A=&A<;B(["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1N=6TK*SL*("`@("`@("`@("`@("`@
M('T@96QS96EF("@D=F5R8F]S92`^/2`Q*2!["B`@("`@("`@("`@("`@("`@
M("`@)&]U='!U="`N/2`B9F%I;&5D('1O(&1E;&5T92`D<&%T:%QN(CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!C;&]S961I<B@D9'`I.PH@("`@("`@(&EF("@D=F5R8F]S92`^/2`Q*2![
M"B`@("`@("`@("`@("1O=71P=70@+CT@(B1N=6T@8V%C:&4@96YT<FEE<R!C
M;&5A<F5D7&XB.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U
M=$1A=&$H<G1R:6TH)&]U='!U="DL("1C;VUM86YD*3L*("`@("`@("!R971U
M<FX@)&YU;3L*("`@('T*"B`@("`O+R!]?7T*?0H*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]014%2+T-O;6UA;F0O0V]N9FEG+G!H<```````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q-S,T-``Q,#0Q-S,V,S`P-@`P,C$S-S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+R\*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I
M;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@
M("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@=7)L.B`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@
M<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@075T:&]R.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@5&]M
M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($-O
M;F9I9RYP:'`L=B`Q+C(V(#(P,#0O,#$O,#@@,3<Z,S,Z,3,@<VYI<&5R($5X
M<"`D"@IR97%U:7)E7V]N8V4@(E!%05(O0V]M;6%N9"]#;VUM;VXN<&AP(CL*
M<F5Q=6ER95]O;F-E(")014%2+T-O;F9I9RYP:'`B.PH*+RHJ"B`J(%!%05(@
M8V]M;6%N9',@9F]R(&UA;F%G:6YG(&-O;F9I9W5R871I;VX@9&%T82X*("H*
M("HO"F-L87-S(%!%05)?0V]M;6%N9%]#;VYF:6<@97AT96YD<R!014%27T-O
M;6UA;F1?0V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@=F%R
M("1C;VUM86YD<R`](&%R<F%Y*`H@("`@("`@("=C;VYF:6<M<VAO=R<@/3X@
M87)R87DH"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4VAO=R!!;&P@4V5T
M=&EN9W,G+`H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-O;F9I9U-H
M;W<G+`H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C<V@G+`H@("`@("`@
M("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P*("`@("`@("`@("`@)V1O8R<@
M/3X@)PI$:7-P;&%Y<R!A;&P@8V]N9FEG=7)A=&EO;B!V86QU97,N("!!;B!O
M<'1I;VYA;"!A<F=U;65N=`IM87D@8F4@=7-E9"!T;R!T96QL('=H:6-H(&-O
M;F9I9W5R871I;VX@;&%Y97(@=&\@9&ES<&QA>2X@(%9A;&ED"F-O;F9I9W5R
M871I;VX@;&%Y97)S(&%R92`B=7-E<B(L(")S>7-T96TB(&%N9"`B9&5F875L
M="(N"B<L"B`@("`@("`@("`@("DL"B`@("`@("`@)V-O;F9I9RUG970G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U-H;W<@3VYE(%-E
M='1I;F<G+`H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-O;F9I9T=E
M="<L"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V-G)RP*("`@("`@("`@
M("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL"B`@("`@("`@("`@("=D;V,G(#T^
M("<\<&%R86UE=&5R/B!;;&%Y97)="D1I<W!L87ES('1H92!V86QU92!O9B!O
M;F4@8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4*9FER<W0@87)G=6UE
M;G0@:7,@=&AE(&YA;64@;V8@=&AE('!A<F%M971E<BP@86X@;W!T:6]N86P@
M<V5C;VYD(&%R9W5M96YT"FUA>2!B92!U<V5D('1O('1E;&P@=VAI8V@@8V]N
M9FEG=7)A=&EO;B!L87EE<B!T;R!L;V]K(&EN+B`@5F%L:60@8V]N9FEG=7)A
M=&EO;@IL87EE<G,@87)E(")U<V5R(BP@(G-Y<W1E;2(@86YD(")D969A=6QT
M(BX@($EF(&YO(&QA>65R(&ES('-P96-I9FEE9"P@82!V86QU90IW:6QL(&)E
M('!I8VME9"!F<F]M('1H92!F:7)S="!L87EE<B!T:&%T(&1E9FEN97,@=&AE
M('!A<F%M971E<BP@:6X@=&AE(&]R9&5R"FIU<W0@<W!E8VEF:65D+@HG+`H@
M("`@("`@("`@("`I+`H@("`@("`@("=C;VYF:6<M<V5T)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=#:&%N9V4@4V5T=&EN9R<L"B`@
M("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0V]N9FEG4V5T)RP*("`@("`@
M("`@("`@)W-H;W)T8W5T)R`]/B`G8W,G+`H@("`@("`@("`@("`G;W!T:6]N
M<R<@/3X@87)R87DH*2P*("`@("`@("`@("`@)V1O8R<@/3X@)SQP87)A;65T
M97(^(#QV86QU93X@6VQA>65R70I3971S('1H92!V86QU92!O9B!O;F4@8V]N
M9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4@9FER<W0@87)G=6UE;G0@:7,*
M=&AE(&YA;64@;V8@=&AE('!A<F%M971E<BP@=&AE('-E8V]N9"!A<F=U;65N
M="!I<R!T:&4@;F5W('9A;'5E+B`@4V]M90IP87)A;65T97)S(&%R92!S=6)J
M96-T('1O('9A;&ED871I;VXL(&%N9"!T:&4@8V]M;6%N9"!W:6QL(&9A:6P@
M=VET:`IA;B!E<G)O<B!M97-S86=E(&EF('1H92!N97<@=F%L=64@9&]E<R!N
M;W0@;6%K92!S96YS92X@($%N(&]P=&EO;F%L"G1H:7)D(&%R9W5M96YT(&UA
M>2!B92!U<V5D('1O('-P96-I9GD@:6X@=VAI8V@@;&%Y97(@=&\@<V5T('1H
M90IC;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%1H92!D969A=6QT(&QA>65R
M(&ES(")U<V5R(BX*)RP*("`@("`@("`@("`@*2P*("`@("`@("`G8V]N9FEG
M+6AE;'`G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U-H
M;W<@26YF;W)M871I;VX@06)O=70@4V5T=&EN9R<L"B`@("`@("`@("`@("=F
M=6YC=&EO;B<@/3X@)V1O0V]N9FEG2&5L<"<L"B`@("`@("`@("`@("=S:&]R
M=&-U="<@/3X@)V-H)RP*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y
M*"DL"B`@("`@("`@("`@("=D;V,G(#T^("=;<&%R86UE=&5R70I$:7-P;&%Y
M<R!H96QP(&9O<B!A(&-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5VET:&]U
M="!A<F=U;65N=',@:70*9&ES<&QA>7,@:&5L<"!F;W(@86QL(&-O;F9I9W5R
M871I;VX@<&%R86UE=&5R<RX*)RP*("`@("`@("`@("`I+`H@("`@("`@("D[
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*
M("`@("`J(%!%05)?0V]M;6%N9%]#;VYF:6<@8V]N<W1R=6-T;W(N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M4$5!4E]#;VUM86YD7T-O;F9I9R@F)'5I+"`F)&-O;F9I9RD*("`@('L*("`@
M("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I+"`D8V]N9FEG
M*3L*("`@('T*"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9&]#;VYF:6=3:&]W
M*"D*"B`@("!F=6YC=&EO;B!D;T-O;F9I9U-H;W<H)&-O;6UA;F0L("1O<'1I
M;VYS+"`D<&%R86US*0H@("`@>PH@("`@("`@("\O("1P87)A;7-;,%T@+3X@
M=&AE(&QA>65R"B`@("`@("`@:68@*"1E<G)O<B`]("1T:&ES+3Y?8VAE8VM,
M87EE<BA`)'!A<F%M<ULP72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1E<G)O<BD["B`@("`@("`@?0H@("`@("`@("1K97ES
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T2V5Y<R@I.PH@("`@("`@('-O<G0H)&ME
M>7,I.PH@("`@("`@("1D871A(#T@87)R87DH)V-A<'1I;VXG(#T^("=#;VYF
M:6=U<F%T:6]N.B<I.PH@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI
M('L*("`@("`@("`@("`@)'1Y<&4@/2`D=&AI<RT^8V]N9FEG+3YG9714>7!E
M*"1K97DI.PH@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)&ME>2P@0"1P87)A;7-;,%TI.PH@("`@("`@("`@("!I9B`H)'1Y<&4@
M/3T@)W!A<W-W;W)D)R`F)B`D=F%L=64I('L*("`@("`@("`@("`@("`@("1V
M86QU92`]("<J*BHJ*BHJ*B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1V86QU92`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1V86QU
M92`]("=F86QS92<["B`@("`@("`@("`@('T@96QS96EF("@D=F%L=64@/3T]
M('1R=64I('L*("`@("`@("`@("`@("`@("1V86QU92`]("=T<G5E)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R1T:&ES+3YC
M;VYF:6<M/F=E=$=R;W5P*"1K97DI75M=(#T@87)R87DH)'1H:7,M/F-O;F9I
M9RT^9V5T4')O;7!T*"1K97DI("P@)&ME>2P@)'9A;'5E*3L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N
M9"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9&]#;VYF:6='970H*0H*("`@(&9U;F-T:6]N(&1O0V]N9FEG
M1V5T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD*("`@('L*("`@("`@
M("`O+R`D<&%R86US6S!=("T^('1H92!P87)A;65T97(*("`@("`@("`O+R`D
M<&%R86US6S%=("T^('1H92!L87EE<@H@("`@("`@(&EF("@D97)R;W(@/2`D
M=&AI<RT^7V-H96-K3&%Y97(H0"1P87)A;7-;,5TI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;W(I.PH@("`@("`@('T*
M("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I(#P@,2!\?"!S:7IE;V8H)'!A
M<F%M<RD@/B`R*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B8V]N9FEG+6=E="!E>'!E8W1S(#$@;W(@,B!P87)A;65T97)S(BD[
M"B`@("`@("`@?2!E;'-E:68@*'-I>F5O9B@D<&%R86US*2`]/2`Q*2!["B`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B)'!A<F%M<ULP73TB
M("X@)'1H:7,M/F-O;F9I9RT^9V5T*"1P87)A;7-;,%TI+"`D8V]M;6%N9"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&$@/2`B)'!A<F%M
M<ULQ72XD<&%R86US6S!=/2(@+B1T:&ES+3YC;VYF:6<M/F=E="@D<&%R86US
M6S!=+"`D<&%R86US6S%=*3L*("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"1D871A+"`D8V]M;6%N9"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1O0V]N
M9FEG4V5T*"D*"B`@("!F=6YC=&EO;B!D;T-O;F9I9U-E="@D8V]M;6%N9"P@
M)&]P=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@+R\@)'!A<F%M6S!=
M("T^(&$@<&%R86UE=&5R('1O('-E=`H@("`@("`@("\O("1P87)A;5LQ72`M
M/B!T:&4@=F%L=64@9F]R('1H92!P87)A;65T97(*("`@("`@("`O+R`D<&%R
M86U;,ET@+3X@=&AE(&QA>65R"B`@("`@("`@)&9A:6QM<V<@/2`G)SL*("`@
M("`@("!I9B`H<VEZ96]F*"1P87)A;7,I(#P@,B!\?"!S:7IE;V8H)'!A<F%M
M<RD@/B`S*2!["B`@("`@("`@("`@("1F86EL;7-G("X](")C;VYF:6<M<V5T
M(&5X<&5C=',@,B!O<B`S('!A<F%M971E<G,B.PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@D9F%I;&US9RD["B`@("`@("`@?0H@("`@
M("`@(&EF("@D97)R;W(@/2`D=&AI<RT^7V-H96-K3&%Y97(H0"1P87)A;7-;
M,ETI*2!["B`@("`@("`@("`@("1F86EL;7-G("X]("1E<G)O<CL*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&9A:6QM<V<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H(6-A;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y
M*"8D=&AI<RT^8V]N9FEG+"`G<V5T)RDL("1P87)A;7,I*0H@("`@("`@('L*
M("`@("`@("`@("`@)&9A:6QM<V<@/2`B8V]N9FEG+7-E="`H(B`N(&EM<&QO
M9&4H(BP@(BP@)'!A<F%M<RD@+B`B*2!F86EL960B.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-T;W)E*"D["B`@("`@
M("`@?0H@("`@("`@(&EF("@D9F%I;&US9RD@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)&9A:6QM<V<I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!D;T-O;F9I9TAE;'`H*0H*("`@(&9U;F-T:6]N(&1O0V]N9FEG2&5L<"@D
M8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@/2`D=&AI
M<RT^8V]N9FEG+3YG971+97ES*"D["B`@("`@("`@?0H@("`@("`@("1D871A
M6R=C87!T:6]N)UT@(#T@(D-O;F9I9R!H96QP(B`N("@H8V]U;G0H)'!A<F%M
M<RD@/3T@,2D@/R`B(&9O<B`D<&%R86US6S!=(B`Z("<G*3L*("`@("`@("`D
M9&%T85LG:&5A9&QI;F4G72`](&%R<F%Y*"=.86UE)RP@)U1Y<&4G+"`G1&5S
M8W)I<'1I;VXG*3L*("`@("`@("`D9&%T85LG8F]R9&5R)UT@("`]('1R=64[
M"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D;F%M92D@>PH@("`@("`@
M("`@("`D='EP92`]("1T:&ES+3YC;VYF:6<M/F=E=%1Y<&4H)&YA;64I.PH@
M("`@("`@("`@("`D9&]C<R`]("1T:&ES+3YC;VYF:6<M/F=E=$1O8W,H)&YA
M;64I.PH@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)W-E="<I('L*("`@("`@
M("`@("`@("`@("1D;V-S(#T@<G1R:6TH)&1O8W,I("X@(EQN5F%L:60@<V5T
M.B`B("X*("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<@)RP@)'1H:7,M
M/F-O;F9I9RT^9V5T4V5T5F%L=65S*"1N86UE*2D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&YA;64L("1T
M>7!E+"`D9&]C<RD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(%]C:&5C:TQA>65R*"D*"B`@("`O*BH*("`@("`J($-H96-K
M<R!I9B!A(&QA>65R(&ES(&1E9FEN960@;W(@;F]T"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;&%Y97(@5&AE(&QA>65R('1O('-E87)C:"!F;W(*
M("`@("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@;F\@97)R;W(@;W(@=&AE
M(&5R<F]R(&UE<W-A9V4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K3&%Y
M97(H)&QA>65R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1L
M87EE<BD@)B8@)&QA>65R("$]("=D969A=6QT)RD@>PH@("`@("`@("`@("`D
M;&%Y97)S(#T@)'1H:7,M/F-O;F9I9RT^9V5T3&%Y97)S*"D["B`@("`@("`@
M("`@(&EF("@A:6Y?87)R87DH)&QA>65R+"`D;&%Y97)S*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("(@;VYL>2!T:&4@;&%Y97)S.B!<(B(@+B!I;7!L
M;V1E*"<B(&]R("(G+"`D;&%Y97)S*2`N(")<(B!A<F4@<W5P<&]R=&5D(CL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+R\@?7U]"GT*"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T)U:6QD+G!H
M<```````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4T-S``,3`T,3<S
M-C,P,#8`,#(Q,C(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW
M+3(P,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D
M('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I
M<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P*+R\@
M?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*
M+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@4W1I9R!"86MK96X@/'-S
M8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"`@("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O
M;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!"=6EL9"YP:'`L=B`Q+CD@,C`P-"\P,2\P."`Q
M-SHS,SHQ,R!S;FEP97(@17AP("0*"G)E<75I<F5?;VYC92`B4$5!4B]#;VUM
M86YD+T-O;6UO;BYP:'`B.PIR97%U:7)E7V]N8V4@(E!%05(O0G5I;&1E<BYP
M:'`B.PH*+RHJ"B`J(%!%05(@8V]M;6%N9',@9F]R(&)U:6QD:6YG(&5X=&5N
M<VEO;G,N"B`J"B`J+PIC;&%S<R!014%27T-O;6UA;F1?0G5I;&0@97AT96YD
M<R!014%27T-O;6UA;F1?0V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S
M"@H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`H@("`@("`@("=B=6EL9"<@
M/3X@87)R87DH"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0G5I;&0@86X@
M17AT96YS:6]N($9R;VT@0R!3;W5R8V4G+`H@("`@("`@("`@("`G9G5N8W1I
M;VXG(#T^("=D;T)U:6QD)RP*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M8B<L"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`H@("`@("`@
M("`@("`G9&]C)R`]/B`G6W!A8VMA9V4N>&UL70I"=6EL9',@;VYE(&]R(&UO
M<F4@97AT96YS:6]N<R!C;VYT86EN960@:6X@82!P86-K86=E+B<*("`@("`@
M("`@("`@*2P*("`@("`@("`I.PH*("`@("\O('U]?0H*("`@("\O('M[>R!C
M;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@4$5!4E]#;VUM86YD7T)U:6QD
M(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]"=6EL9"@F)'5I+"`F
M)&-O;F9I9RD*("`@('L*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#
M;VUM;VXH)'5I+"`D8V]N9FEG*3L*("`@('T*"B`@("`O+R!]?7T*"B`@("`O
M+R![>WL@9&]"=6EL9"@I"@H@("`@9G5N8W1I;VX@9&]"=6EL9"@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@:68@*'-I>F5O
M9B@D<&%R86US*2`\(#$I('L*("`@("`@("`@("`@)'!A<F%M<ULP72`]("=P
M86-K86=E+GAM;"<["B`@("`@("`@?0H@("`@("`@("1B=6EL9&5R(#T@)FYE
M=R!014%27T)U:6QD97(H)'1H:7,M/G5I*3L*("`@("`@("`D=&AI<RT^9&5B
M=6<@/2`D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*3L*("`@("`@("`D
M97)R(#T@)&)U:6QD97(M/F)U:6QD*"1P87)A;7-;,%TL(&%R<F%Y*"8D=&AI
M<RP@)V)U:6QD0V%L;&)A8VLG*2D["B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<BDI('L*("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&)U:6QD0V%L;&)A8VLH*0H*("`@(&9U;F-T:6]N(&)U:6QD0V%L
M;&)A8VLH)'=H870L("1D871A*0H@("`@>PH@("`@("`@(&EF("@H)'=H870@
M/3T@)V-M9&]U='!U="<@)B8@)'1H:7,M/F1E8G5G(#X@,2D@?'P*("`@("`@
M("`@("`@*"1W:&%T(#T]("=O=71P=70G("8F("1T:&ES+3YD96)U9R`^(#`I
M*2!["B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AR=')I;2@D
M9&%T82DL("=B=6EL9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+T-O;6UA;F0O4F5G:7-T<GDN<&AP````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`S,C,T-0`Q,#0Q-S,V,S`P-@`P,C$W-S4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+R\@+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(
M4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(
M4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO
M+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T
M:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@
M<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<CH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+PHO+R`D260Z(%)E9VES=')Y+G!H<"QV(#$N,S8@,C`P-"\P
M,2\P."`Q-SHS,SHQ,R!S;FEP97(@17AP("0*"G)E<75I<F5?;VYC92`G4$5!
M4B]#;VUM86YD+T-O;6UO;BYP:'`G.PIR97%U:7)E7V]N8V4@)U!%05(O4F5G
M:7-T<GDN<&AP)SL*<F5Q=6ER95]O;F-E("=014%2+T-O;F9I9RYP:'`G.PH*
M8VQA<W,@4$5!4E]#;VUM86YD7U)E9VES=')Y(&5X=&5N9',@4$5!4E]#;VUM
M86YD7T-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@('9A<B`D
M8V]M;6%N9',@/2!A<G)A>2@*("`@("`@("`G;&ES="<@/3X@87)R87DH"B`@
M("`@("`@("`@("=S=6UM87)Y)R`]/B`G3&ES="!);G-T86QL960@4&%C:V%G
M97,G+`H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TQI<W0G+`H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=L)RP*("`@("`@("`@("`@)V]P=&EO
M;G,G(#T^(&%R<F%Y*"DL"B`@("`@("`@("`@("=D;V,G(#T^("=;<&%C:V%G
M95T*268@:6YV;VME9"!W:71H;W5T('!A<F%M971E<G,L('1H:7,@8V]M;6%N
M9"!L:7-T<R!T:&4@4$5!4B!P86-K86=E<PII;G-T86QL960@:6X@>6]U<B!P
M:'!?9&ER("A[8V]N9FEG('!H<%]D:7(I*2X@(%=I=&@@82!P87)A;65T97(L
M(&ET"FQI<W1S('1H92!F:6QE<R!I;B!T:&%T('!A8VMA9V4N"B<L"B`@("`@
M("`@("`@("DL"B`@("`@("`@)W-H96QL+71E<W0G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G<W5M;6%R>2<@/3X@)U-H96QL(%-C<FEP="!497-T)RP*("`@
M("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]3:&5L;%1E<W0G+`H@("`@("`@
M("`@("`G<VAO<G1C=70G(#T^("=S="<L"B`@("`@("`@("`@("=O<'1I;VYS
M)R`]/B!A<G)A>2@I+`H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^
M(%M;<F5L871I;VY=('9E<G-I;VY="E1E<W1S(&EF(&$@<&%C:V%G92!I<R!I
M;G-T86QL960@:6X@=&AE('-Y<W1E;2X@5VEL;"!E>&ET*#$I(&EF(&ET(&ES
M(&YO="X*("`@/')E;&%T:6]N/B`@(%1H92!V97)S:6]N(&-O;7!A<FES;VX@
M;W!E<F%T;W(N($]N92!O9CH*("`@("`@("`@("`@("`@(#PL(&QT+"`\/2P@
M;&4L(#XL(&=T+"`^/2P@9V4L(#T]+"`]+"!E<2P@(3TL(#P^+"!N90H@("`\
M=F5R<VEO;CX@("`@5&AE('9E<G-I;VX@=&\@8V]M<&%R92!W:71H"B<I+`H@
M("`@("`@("=I;F9O)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W-U;6UA<GDG
M("`]/B`G1&ES<&QA>2!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4G+`H@
M("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TEN9F\G+`H@("`@("`@("`@
M("`G<VAO<G1C=70G(#T^("=I;B<L"B`@("`@("`@("`@("=O<'1I;VYS)R`@
M/3X@87)R87DH*2P*("`@("`@("`@("`@)V1O8R<@("`@("`]/B`G/'!A8VMA
M9V4^"D1I<W!L87ES(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92X@5&AE
M('!A8VMA9V4@87)G=6UE;G0@;6%Y(&)E(&$*;&]C86P@<&%C:V%G92!F:6QE
M+"!A;B!54DP@=&\@82!P86-K86=E(&9I;&4L(&]R('1H92!N86UE(&]F(&%N
M"FEN<W1A;&QE9"!P86-K86=E+B<*("`@("`@("`@("`@*0H@("`@("`@("D[
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*
M("`@("`J(%!%05)?0V]M;6%N9%]296=I<W1R>2!C;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!014%27T-O;6UA;F1?4F5G:7-T<GDH)B1U:2P@)B1C;VYF:6<I"B`@("![
M"B`@("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M;6]N*"1U:2P@)&-O
M;F9I9RD["B`@("!]"@H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&1O3&ES="@I
M"@H@("`@9G5N8W1I;VX@7W-O<G1I;F9O*"1A+"`D8BD*("`@('L*("`@("`@
M("!R971U<FX@<W1R8VUP*"1A6R=P86-K86=E)UTL("1B6R=P86-K86=E)UTI
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&1O3&ES="@D8V]M;6%N9"P@)&]P=&EO
M;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@)')E9R`](&YE=R!014%27U)E
M9VES=')Y*"1T:&ES+3YC;VYF:6<M/F=E="@G<&AP7V1I<B<I*3L*("`@("`@
M("!I9B`H<VEZ96]F*"1P87)A;7,I(#T](#`I('L*("`@("`@("`@("`@)&EN
M<W1A;&QE9"`]("1R96<M/G!A8VMA9V5);F9O*"D["B`@("`@("`@("`@('5S
M;W)T*"1I;G-T86QL960L(&%R<F%Y*"8D=&AI<RP@)U]S;W)T:6YF;R<I*3L*
M("`@("`@("`@("`@)&D@/2`D:B`](#`["B`@("`@("`@("`@("1D871A(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)TEN<W1A;&QE
M9"!P86-K86=E<SHG+`H@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U
M92P*("`@("`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH)U!A8VMA
M9V4G+"`G5F5R<VEO;B<L("=3=&%T92<I"B`@("`@("`@("`@("`@("`I.PH@
M("`@("`@("`@("!F;W)E86-H("@D:6YS=&%L;&5D(&%S("1P86-K86=E*2![
M"B`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D<&%C
M:V%G95LG<&%C:V%G92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G95LG=F5R<VEO;B==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`)'!A8VMA9V5;)W)E
M;&5A<V5?<W1A=&4G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*&-O=6YT*"1I;G-T86QL960I/3TP*2!["B`@("`@("`@("`@("`@("`D9&%T
M82`]("<H;F\@<&%C:V%G97,@:6YS=&%L;&5D*2<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M
M;6%N9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&9I;&5?
M97AI<W1S*"1P87)A;7-;,%TI("8F("%I<U]D:7(H)'!A<F%M<ULP72DI('L*
M("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`B4$5!4B]#;VUM;VXN<&AP
M(CL*("`@("`@("`@("`@("`@("1O8FH@/2`F;F5W(%!%05)?0V]M;6]N.PH@
M("`@("`@("`@("`@("`@)&EN9F\@/2`D;V)J+3YI;F9O1G)O;4%N>2@D<&%R
M86US6S!=*3L*("`@("`@("`@("`@("`@("1H96%D:6YG<R`](&%R<F%Y*"=0
M86-K86=E($9I;&4G+"`G26YS=&%L;"!0871H)RD["B`@("`@("`@("`@("`@
M("`D:6YS=&%L;&5D(#T@9F%L<V4["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D:6YF;R`]("1R96<M/G!A8VMA9V5);F9O*"1P87)A
M;7-;,%TI.PH@("`@("`@("`@("`@("`@)&AE861I;F=S(#T@87)R87DH)U1Y
M<&4G+"`G26YS=&%L;"!0871H)RD["B`@("`@("`@("`@("`@("`D:6YS=&%L
M;&5D(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D:6YF;RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1I;F9O(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F`D<&%R86US6S!=)R!N;W0@:6YS
M=&%L;&5D(BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QI<W0@/2`D
M:6YF;ULG9FEL96QI<W0G73L*("`@("`@("`@("`@:68@*"1I;G-T86QL960I
M('L*("`@("`@("`@("`@("`@("1C87!T:6]N(#T@)TEN<W1A;&QE9"!&:6QE
M<R!&;W(@)R`N("1P87)A;7-;,%T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D8V%P=&EO;B`]("=#;VYT96YT<R!O9B`G("X@8F%S
M96YA;64H)'!A<F%M<ULP72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&1A=&$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=C87!T:6]N)R`]/B`D
M8V%P=&EO;BP*("`@("`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L"B`@
M("`@("`@("`@("`@("`G:&5A9&QI;F4G(#T^("1H96%D:6YG<RD["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1F:6QE(#T^("1A='0I('L*("`@
M("`@("`@("`@("`@(&EF("@D:6YS=&%L;&5D*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&5M<'1Y*"1A='1;)VEN<W1A;&QE9%]A<R==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@
M87)R87DH)&%T=%LG<F]L92==+"`D871T6R=I;G-T86QL961?87,G72D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D871T6R=B87-E:6YS=&%L;&1I<B==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5S="`]("1A='1;)V)A<V5I;G-T86QL9&ER)UT@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F:6QE.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1D97-T(#T@)&9I;&4["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)&%T
M=%LG<F]L92==*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W1E
M<W0G.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=D871A)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:6YS=&%L;&5D*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L@,CL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D97-T(#T@)RTM('=I;&P@;F]T(&)E(&EN<W1A;&QE9"`M+2<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`G9&]C)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D97-T(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D;V-?9&ER
M)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5S=#L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=P:'`G
M.@H@("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<W0@/2`D=&AI<RT^8V]N9FEG+3YG970H
M)W!H<%]D:7(G*2`N($1)4D5#5$]265]315!!4D%43U(@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D97-T.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D9&5S="`]('!R96=?<F5P;&%C
M92@G(2\K(2<L("<O)RP@)&1E<W0I.PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@<')E9U]R97!L86-E*"<A+RLA)RP@)R\G+"`D9FEL92D["B`@("`@
M("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&9I;&4L
M("1D97-T*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD
M*3L*"@H@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!D;U-H96QL5&5S="@I"@H@("`@9G5N8W1I
M;VX@9&]3:&5L;%1E<W0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0H@
M("`@>PH@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD["B`@("`@("`@)')E9R`]("9N97<@4$5!4E]296=I<W1R
M>2@D=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G*2D["B`@("`@("`@+R\@
M(G!E87(@<VAE;&PM=&5S="!&;V\B"B`@("`@("`@:68@*'-I>F5O9B@D<&%R
M86US*2`]/2`Q*2!["B`@("`@("`@("`@(&EF("@A)')E9RT^<&%C:V%G945X
M:7-T<R@D<&%R86US6S!=*2D@>PH@("`@("`@("`@("`@("`@97AI="@Q*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`O+R`B<&5A<B!S:&5L;"UT97-T
M($9O;R`Q+C`B"B`@("`@("`@?2!E;'-E:68@*'-I>F5O9B@D<&%R86US*2`]
M/2`R*2!["B`@("`@("`@("`@("1V(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A
M<F%M<ULP72P@)W9E<G-I;VXG*3L*("`@("`@("`@("`@:68@*"$D=B!\?"`A
M=F5R<VEO;E]C;VUP87)E*"(D=B(L(")[)'!A<F%M<ULQ77TB+"`B9V4B*2D@
M>PH@("`@("`@("`@("`@("`@97AI="@Q*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`O+R`B<&5A<B!S:&5L;"UT97-T($9O;R!G92`Q+C`B"B`@("`@
M("`@?2!E;'-E:68@*'-I>F5O9B@D<&%R86US*2`]/2`S*2!["B`@("`@("`@
M("`@("1V(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A<F%M<ULP72P@)W9E<G-I
M;VXG*3L*("`@("`@("`@("`@:68@*"$D=B!\?"`A=F5R<VEO;E]C;VUP87)E
M*"(D=B(L(")[)'!A<F%M<ULR77TB+"`D<&%R86US6S%=*2D@>PH@("`@("`@
M("`@("`@("`@97AI="@Q*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@
M("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9#H@97AP96-T
M<R`Q('1O(#,@<&%R86UE=&5R<R(I.PH@("`@("`@("`@("!E>&ET*#$I.PH@
M("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D;TEN9F\*
M"B`@("!F=6YC=&EO;B!D;TEN9F\H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R
M86US*0H@("`@>PH@("`@("`@("\O("1P87)A;7-;,%T@5&AE('!A8VMA9V4@
M9F]R('-H;W=I;F<@:6YF;PH@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@
M(3T@,2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(E1H:7,@8V]M;6%N9"!O;FQY(&%C8V5P=',@;VYE('!A<F%M.B`B+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(G1H92!P86-K86=E
M('EO=2!W86YT(&EN9F]R;6%T:6]N(BD["B`@("`@("`@?0H@("`@("`@(&EF
M("A`:7-?9FEL92@D<&%R86US6S!=*2D@>PH@("`@("`@("`@("`D;V)J("`]
M("9N97<@4$5!4E]#;VUM;VXH*3L*("`@("`@("`@("`@)&EN9F\@/2`D;V)J
M+3YI;F9O1G)O;4%N>2@D<&%R86US6S!=*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<F5G(#T@)FYE=R!014%27U)E9VES=')Y*"1T:&ES+3YC
M;VYF:6<M/F=E="@G<&AP7V1I<B<I*3L*("`@("`@("`@("`@)&EN9F\@/2`D
M<F5G+3YP86-K86=E26YF;R@D<&%R86US6S!=*3L*("`@("`@("!]"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6YF;SL*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@B3F]T:&EN9R!F
M;W5N9"!F;W(@8"1P87)A;7-;,%TG(BD["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"B`@("`@("`@=6YS970H)&EN9F];)V9I;&5L:7-T)UTI.PH@
M("`@("`@('5N<V5T*"1I;F9O6R=C:&%N9V5L;V<G72D["B`@("`@("`@)&ME
M>7,@/2!A<G)A>5]K97ES*"1I;F9O*3L*("`@("`@("`D;&]N9W1E>'0@/2!A
M<G)A>2@G9&5S8W)I<'1I;VXG+"`G<W5M;6%R>2<I.PH@("`@("`@(&9O<F5A
M8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1I;F9O6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@<W=I=&-H("@D:V5Y
M*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G;6%I;G1A:6YE<G,G.B![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&US='(@/2`G)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&EN9F];)&ME>5T@87,@)&TI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D:2LK(#X@,"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1M<W1R("X](")<;B(["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;7-T<B`N/2`D;5LG;F%M92==("X@(B`\(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D;5LG96UA:6PG72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;7-T<B`N/2`D;5LG96UA:6PG
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&US='(@+CT@)&U;)VAA;F1L
M92==("X@)T!P:'`N;F5T)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M<W1R("X]("(^("@D
M;5MR;VQE72DB.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O6R1K97E=(#T@)&US='(["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!C87-E("=R96QE87-E7V1E<',G.B!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&1S='(@/2`G)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&EN9F];)&ME>5T@87,@)&0I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?<F5L7W1R86YS
M6R1D6R=R96PG75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E;"`]("1T:&ES+3Y?9&5P<U]R96Q?=')A;G-;)&1;)W)E;"==73L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E;"`]("1D6R=R96PG73L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD
M9%LG='EP92==72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D='EP92`]('5C9FER<W0H)'1H:7,M/E]D97!S7W1Y<&5?=')A;G-;)&1;
M)W1Y<&4G75TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("1D
M6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)VYA;64G72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1D
M6R=N86UE)UT@+B`G("<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)W9E<G-I;VXG72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]
M("1D6R=V97)S:6]N)UT@+B`G("<["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1V97)S:6]N(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'-T<B`N/2`B)'1Y<&4@
M)&YA;64D<F5L("1V97)S:6]N7&XB.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1K97E=(#T@)&1S
M='(["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!C87-E("=P<F]V:61E
M<R<@.B!["B`@("`@("`@("`@("`@("`@("`@("`@("1D96)U9R`]("1T:&ES
M+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&1E8G5G(#P@,BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!S='(@/2`G0VQA<W-E<SH@)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M<W1R(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D:6YF;ULD:V5Y72!A<R`D<"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1D96)U9R`\(#(@)B8@)'!;)W1Y<&4G72`A
M/2`B8VQA<W,B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!/;FQY('!R:6YT(&-L87-S97,@
M=VAE;B!V97)B;W-I='D@;6]D92!I<R`\(#(*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D9&5B=6<@/"`R*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1I*RL@/B`P*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P<W1R("X]("(L("(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P<W1R("X]("1P6R=N86UE)UT["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D:2LK(#X@,"D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<'-T<B`N/2`B7&XB.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<'-T<B`N/2!U8V9I<G-T*"1P6R=T>7!E)UTI("X@(B`B
M("X@)'!;)VYA;64G73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'!;)V5X<&QI8VET)UTI("8F("1P6R=E>'!L:6-I="==
M(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!S='(@+CT@(B`H97AP;&EC:70I(CL*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)&ME>5T@/2`D<'-T<CL*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&1E9F%U;'0Z('L*("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F];)&ME>5T@/2!I;7!L;V1E*"(L("(L("1I;F9O6R1K97E=*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D:V5Y(#T]("=?;&%S=&UO9&EF:65D)RD@>PH@("`@("`@("`@("`@
M("`@)&AD871E(#T@9&%T92@G62UM+60G+"`D:6YF;ULD:V5Y72D["B`@("`@
M("`@("`@("`@("!U;G-E="@D:6YF;ULD:V5Y72D["B`@("`@("`@("`@("`@
M("`D:6YF;ULG3&%S="!-;V1I9FEE9"==(#T@)&AD871E.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@/2!T<FEM
M*"1I;F9O6R1K97E=*3L*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D
M:V5Y+"`D;&]N9W1E>'0I*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)&ME>5T@/2!P<F5G7W)E<&QA8V4H)R\@("LO)RP@)R`G+"`D:6YF;ULD:V5Y
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@)&-A<'1I;VX@/2`G06)O=70@)R`N("1I;F9O6R=P86-K86=E
M)UT@+B`G+2<@+B`D:6YF;ULG=F5R<VEO;B==.PH@("`@("`@("1D871A(#T@
M87)R87DH"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`D8V%P=&EO;BP*("`@
M("`@("`@("`@)V)O<F1E<B<@/3X@=')U92D["B`@("`@("`@9F]R96%C:"`H
M)&EN9F\@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&ME>2`]
M('5C=V]R9',H=')I;2AS=')?<F5P;&%C92@G7R<L("<@)RP@)&ME>2DI*3L*
M("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&ME>2P@)'9A
M;'5E*3L*("`@("`@("!]"B`@("`@("`@)&1A=&%;)W)A=R==(#T@)&EN9F\[
M"@H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)W!A8VMA
M9V4M:6YF;R<I.PH@("`@?0H*("`@("\O('U]?0I]"@H_/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N
M9"]-:7)R;W(N<&AP````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V
M-#`Q`#$P-#$W,S8S,#`V`#`R,30S,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`U("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H
M="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@
M("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS
M92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@
M("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z($%L97AA
M;F1E<B!-97)Z(#QA;&5X;65R>D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!-:7)R
M;W(N<&AP+'8@,2XS(#(P,#0O,#$O,#@@,3<Z,S,Z,3,@<VYI<&5R($5X<"`D
M"@IR97%U:7)E7V]N8V4@(E!%05(O0V]M;6%N9"]#;VUM;VXN<&AP(CL*<F5Q
M=6ER95]O;F-E(")014%2+T-O;6UA;F0N<&AP(CL*<F5Q=6ER95]O;F-E(")0
M14%2+U)E;6]T92YP:'`B.PIR97%U:7)E7V]N8V4@(E!%05(N<&AP(CL*"B\J
M*@H@*B!014%2(&-O;6UA;F1S(&9O<B!P<F]V:61I;F<@9FEL92!M:7)R;W)S
M"B`J"B`J+PIC;&%S<R!014%27T-O;6UA;F1?36ER<F]R(&5X=&5N9',@4$5!
M4E]#;VUM86YD7T-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@
M('9A<B`D8V]M;6%N9',@/2!A<G)A>2@*("`@("`@("`G9&]W;FQO860M86QL
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=$;W=N;&]A
M9',@96%C:"!A=F%I8FQE(%!A8VMA9V4@9G)O;2!M87-T97)?<V5R=F5R)RP*
M("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]$;W=N;&]A9$%L;"<L"B`@
M("`@("`@("`@("=S:&]R=&-U="<@/3X@)V1A)RP*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*"DL"B`@("`@("`@("`@("=D;V,G(#T^("<*"2`@
M("!297%U97-T(&$@;&ES="!O9B!A=F%I8FQE(%!A8VMA9V5S(&9R;VT@=&AE
M(%!A8VMA9V4M4V5R=F5R"@D@("`@*&UA<W1E<E]S97)V97(I(&%N9"!D;W=N
M;&]A9',@=&AE;2!T;R!C=7)R96YT('=O<FMI;F<@9&ER)PH@("`@("`@("`@
M("`I+`H@("`@("`@("D["@H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G-T
M<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!014%27T-O;6UA;F1?36ER<F]R(&-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<&%R86T@;V)J96-T(%!%05)?1G)O;G1E;F0@82!R969E<F5N8V4@=&\@
M86X@9G)O;G1E;F0*("`@("`J($!P87)A;2!O8FIE8W0@4$5!4E]#;VYF:6<@
M82!R969E<F5N8V4@=&\@=&AE(&-O;F9I9W5R871I;VX@9&%T80H@("`@("HO
M"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?36ER<F]R*"8D=6DL("8D8V]N
M9FEG*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO
M;B@D=6DL("1C;VYF:6<I.PH@("`@?0H*("`@("\O('U]?0H*("`@("\O('M[
M>R!D;T1O=VYL;V%D06QL*"D*("`@("\J*@H@("`@*B!R971R:65V97,@82!L
M:7-T(&]F(&%V86EB;&4@4&%C:V%G97,@9G)O;2!M87-T97(@<V5R=F5R"B`@
M("`J(&%N9"!D;W=N;&]A9',@=&AE;0H@("`@*@H@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@*B!`<&%R86T@<W1R:6YG("1C;VUM86YD('1H92!C;VUM86YD
M"B`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R!T:&4@8V]M;6%N9"!O<'1I
M;VYS(&)E9F]R92!T:&4@8V]M;6%N9`H@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R!T:&4@<W1U9F8@869T97(@=&AE(&-O;6UA;F0@;F%M90H@("`@*B!`
M<F5T=7)N(&)O;VP@=')U92!I9B!S=6-C97-F=6P*("`@("H@0'1H<F]W(%!%
M05)?17)R;W(@"B`@("`J+PH@("`@9G5N8W1I;VX@9&]$;W=N;&]A9$%L;"@D
M8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("!["@DD=&AI<RT^8V]N
M9FEG+3YS970H(G!H<%]D:7(B+"`B+B(I.R`*"21R96UO=&4@/2`F;F5W(%!%
M05)?4F5M;W1E*"1T:&ES+3YC;VYF:6<I.PH))')E;6]T94EN9F\@/2`D<F5M
M;W1E+3YC86QL*")P86-K86=E+FQI<W1!;&PB*3L*"6EF*%!%05(Z.FES17)R
M;W(H)')E;6]T94EN9F\I*2!["@D)<F5T=7)N("1R96UO=&5);F9O.PH)?0H)
M)&-M9"`]("9014%27T-O;6UA;F0Z.F9A8W1O<GDH(F1O=VYL;V%D(BP@)'1H
M:7,M/F-O;F9I9RD["@EI9BA014%2.CII<T5R<F]R*"1C;60I*2!["@D)<F5T
M=7)N("1C;60["@E]"0H)9F]R96%C:"@D<F5M;W1E26YF;R!A<R`D<&MG;CT^
M)'!K9RD@>R`@(`H)"2\O(&5R<F]R(&AA;F1L:6YG(&YO="!N96-C97-A<GDL
M(&)E8V%U<V4*"0DO+R!A;')E861Y(&1O;F4@8GD@=&AE(&1O=VYL;V%D(&-O
M;6UA;F0*"0DD8VUD+3YR=6XH(F1O=VYL;V%D(BP@87)R87DH*2P@87)R87DH
M)'!K9VXI*3L@("`@("`@"B`@"7T@"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\O('U]?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA
M;F0O0V]M;6]N+G!H<```````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-S0V,P`Q,#0Q-S,V,S`P-@`P,C$T,C$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-2`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!3=&EG
M(%/F=&AE<B!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\*+R\@)$ED.B!#;VUM;VXN<&AP+'8@,2XR-"`R,#`T+S`Q+S`X(#$W.C,S
M.C$S('-N:7!E<B!%>'`@)`H*<F5Q=6ER95]O;F-E(")014%2+G!H<"(["@IC
M;&%S<R!014%27T-O;6UA;F1?0V]M;6]N(&5X=&5N9',@4$5!4@I["B`@("`O
M+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@4$5!4E]#;VYF:6<@
M;V)J96-T('5S960@=&\@<&%S<R!U<V5R('-Y<W1E;2!A;F0@8V]N9FEG=7)A
M=&EO;@H@("`@("H@;VX@=VAE;B!E>&5C=71I;F<@8V]M;6%N9',*("`@("`J
M"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)&-O;F9I9SL*
M"B`@("`O*BH*("`@("`J(%5S97(@26YT97)F86-E(&]B:F5C="P@9F]R(&%L
M;"!I;G1E<F%C=&EO;B!W:71H('1H92!U<V5R+@H@("`@("H@0'9A<B!O8FIE
M8W0*("`@("`J+PH@("`@=F%R("1U:3L*"B`@("!V87(@)%]D97!S7W)E;%]T
M<F%N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;'0G(#T^("<\)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VQE)R`]/B`G/#TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G97$G(#T^("<])RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VYE)R`]/B`G(3TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G9W0G(#T^("<^)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V=E)R`]/B`G/CTG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:&%S)R`]/B`G/3TG"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D["@H@("`@=F%R("1?9&5P<U]T>7!E7W1R86YS(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&MG
M)R`]/B`G<&%C:V%G92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G97AT96YS:6]N)R`]/B`G97AT96YS:6]N)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=P:'`G(#T^("=02%`G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!R;V<G(#T^("=E>'1E<FYA
M;"!P<F]G<F%M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=L9&QI8B<@/3X@)V5X=&5R;F%L(&QI8G)A<GD@9F]R(&QI;FMI;F<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)T;&EB)R`]/B`G
M97AT97)N86P@<G5N=&EM92!L:6)R87)Y)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=O<R<@/3X@)V]P97)A=&EN9R!S>7-T96TG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=E8G-R=B<@/3X@
M)W=E8B!S97)V97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W-A<&DG(#T^("=305!)(&)A8VME;F0G"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I.PH*("`@("\O('U]?0H@("`@+R\@>WM[(&-O
M;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!014%27T-O;6UA;F1?0V]M;6]N
M(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]#;VUM;VXH)B1U:2P@
M)B1C;VYF:6<I"B`@("!["B`@("`@("`@<&%R96YT.CI014%2*"D["B`@("`@
M("`@)'1H:7,M/F-O;F9I9R`]("8D8V]N9FEG.PH@("`@("`@("1T:&ES+3YU
M:2`]("8D=6D["B`@("!]"@H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$-O
M;6UA;F1S*"D*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@86QL
M('1H92!C;VUM86YD<R!D969I;F5D(&)Y('1H:7,@8VQA<W,N"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y(&QI<W0@;V8@8V]M;6%N9',*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;6UA;F1S*"D*("`@
M('L*("`@("`@("`D<F5T(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("AA
M<G)A>5]K97ES*"1T:&ES+3YC;VUM86YD<RD@87,@)&-O;6UA;F0I('L*("`@
M("`@("`@("`@)')E=%LD8V]M;6%N9%T@/2`D=&AI<RT^8V]M;6%N9'-;)&-O
M;6UA;F1=6R=S=6UM87)Y)UT["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-H;W)T8W5T
M<R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!L:7-T(&]F(&%L;"!T:&4@
M8V]M;6%N9"!S:&]R=&-U=',@9&5F:6YE9"!B>2!T:&ES(&-L87-S+@H@("`@
M("H@0')E='5R;B!A<G)A>2!S:&]R=&-U="`]/B!C;VUM86YD"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&]R=&-U
M=',H*0H@("`@>PH@("`@("`@("1R970@/2!A<G)A>2@I.PH@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/F-O;6UA;F1S*2!A<R`D8V]M;6%N
M9"D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;6UA;F1S6R1C
M;VUM86YD75LG<VAO<G1C=70G72DI('L*("`@("`@("`@("`@("`@("1R971;
M)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG<VAO<G1C=70G75T@/2`D8V]M
M;6%N9#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G971/<'1I;VYS
M*"D*"B`@("!F=6YC=&EO;B!G971/<'1I;VYS*"1C;VUM86YD*0H@("`@>PH@
M("`@("`@(')E='5R;B!`)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T
M:6]N<R==.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$=E=&]P
M=$%R9W,H*0H*("`@(&9U;F-T:6]N(&=E=$=E=&]P=$%R9W,H)&-O;6UA;F0L
M("8D<VAO<G1?87)G<RP@)B1L;VYG7V%R9W,I"B`@("!["B`@("`@("`@)'-H
M;W)T7V%R9W,@/2`B(CL*("`@("`@("`D;&]N9U]A<F=S(#T@87)R87DH*3L*
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD72DI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@("`@("!R97-E
M="@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=*3L*("`@("`@("!W:&EL92`H
M;&ES="@D;W!T:6]N+"`D:6YF;RD@/2!E86-H*"1T:&ES+3YC;VUM86YD<ULD
M8V]M;6%N9%U;)V]P=&EO;G,G72DI('L*("`@("`@("`@("`@)&QA<F<@/2`D
M<V%R9R`]("<G.PH@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)V%R9R==
M*2D@>PH@("`@("`@("`@("`@("`@:68@*"1I;F9O6R=A<F<G77LP?2`]/2`G
M*"<I('L*("`@("`@("`@("`@("`@("`@("`D;&%R9R`]("<]/2<["B`@("`@
M("`@("`@("`@("`@("`@)'-A<F<@/2`G.CHG.PH@("`@("`@("`@("`@("`@
M("`@("1A<F<@/2!S=6)S='(H)&EN9F];)V%R9R==+"`Q+"`M,2D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1L87)G
M(#T@)STG.PH@("`@("`@("`@("`@("`@("`@("1S87)G(#T@)SHG.PH@("`@
M("`@("`@("`@("`@("`@("1A<F<@/2`D:6YF;ULG87)G)UT["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1I;F9O6R=S:&]R=&]P="==*2D@>PH@("`@("`@("`@("`@("`@)'-H;W)T
M7V%R9W,@+CT@)&EN9F];)W-H;W)T;W!T)UT@+B`D<V%R9SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D;&]N9U]A<F=S6UT@/2`D;W!T:6]N("X@)&QA
M<F<["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E
M=$AE;'`H*0H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(&AE;'`@;65S<V%G
M92!F;W(@=&AE(&=I=F5N(&-O;6UA;F0*("`@("H*("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]M;6%N9"!4:&4@8V]M;6%N9`H@("`@*B!`<F5T=7)N(&UI>&5D
M($$@9F%I;"!S=')I;F<@:68@=&AE(&-O;6UA;F0@9&]E<R!N;W0@:&%V92!H
M96QP(&]R"B`@("`J("`@("`@("`@("`@("`@82!T=V\@96QE;65N=',@87)R
M87D@8V]N=&%I;FEN9R!;,%T]/FAE;'`@<W1R:6YG+`H@("`@*B`@("`@("`@
M("`@("`@(%LQ73T^(&AE;'`@<W1R:6YG(&9O<B!T:&4@86-C97!T960@8VUD
M(&%R9W,*("`@("HO"B`@("!F=6YC=&EO;B!G971(96QP*"1C;VUM86YD*0H@
M("`@>PH@("`@("`@("1C;VYF:6<@/2`F4$5!4E]#;VYF:6<Z.G-I;F=L971O
M;B@I.PH@("`@("`@("1H96QP(#T@0"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N
M9%U;)V1O8R==.PH@("`@("`@(&EF("AE;7!T>2@D:&5L<"DI('L*("`@("`@
M("`@("`@+R\@6%A8("AC;W@I($9A;&QB86-K('1O('-U;6UA<GD@:68@=&AE
M<F4@:7,@;F\@9&]C("AS:&]W(&)O=&@_*0H@("`@("`@("`@("!I9B`H(21H
M96QP(#T@0"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)W-U;6UA<GDG72D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(").;R!H96QP(&9O<B!C;VUM86YD
M(%PB)&-O;6UA;F1<(B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*'!R96=?;6%T8VA?86QL*"<O>V-O;F9I9UQS*RA;7EQ]72LI?2]E
M)RP@)&AE;'`L("1M871C:&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H*"1M
M871C:&5S6S!=(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("`D:&5L
M<"`]('!R96=?<F5P;&%C92@B+R1V+R(L("1C;VYF:6<M/F=E="@D;6%T8VAE
M<ULQ75LD:UTI+"`D:&5L<"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"1H96QP+"`D=&AI<RT^9V5T2&5L<$%R9W,H
M)&-O;6UA;F0I*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G971(
M96QP07)G<R@I"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@:&5L<"!F;W(@
M=&AE(&%C8V5P=&5D(&%R9W5M96YT<R!O9B!A(&-O;6UA;F0*("`@("H*("`@
M("H@0'!A<F%M("!S=')I;F<@)&-O;6UA;F0*("`@("H@0')E='5R;B!S=')I
M;F<@5&AE(&AE;'`@<W1R:6YG"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T2&5L
M<$%R9W,H)&-O;6UA;F0I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VUM86YD<ULD8V]M;6%N9%U;)V]P=&EO;G,G72D@)B8*("`@("`@("`@
M("`@8V]U;G0H)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T:6]N<R==
M*2D*("`@("`@("!["B`@("`@("`@("`@("1H96QP(#T@(D]P=&EO;G,Z7&XB
M.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA
M;F1=6R=O<'1I;VYS)UT@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D=ELG87)G)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1V6R=A<F<G77LP?2`]/2`G*"<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R9R`]('-U8G-T<B@D=ELG87)G)UTL(#$L("TQ*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-A<'`@/2`B(%LD87)G72(["B`@("`@("`@
M("`@("`@("`@("`@("`@("1L87!P(#T@(EL])&%R9UTB.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1S
M87!P(#T@(B`D=EMA<F==(CL*("`@("`@("`@("`@("`@("`@("`@("`@)&QA
M<'`@/2`B/21V6V%R9UTB.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'-A<'`@
M/2`D;&%P<"`]("(B.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1V6R=S:&]R=&]P="==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1S(#T@)'9;)W-H;W)T;W!T)UT["B`@("`@("`@("`@("`@("`@
M("`@0"1H96QP("X]("(@("TD<R1S87!P+"`M+21K)&QA<'!<;B(["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@($`D:&5L
M<"`N/2`B("`M+21K)&QA<'!<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<"`]("(@("`@("`@("(["B`@("`@("`@("`@("`@("`D
M9&]C(#T@<G1R:6TH<W1R7W)E<&QA8V4H(EQN(BP@(EQN)'`B+"`D=ELG9&]C
M)UTI*3L*("`@("`@("`@("`@("`@("1H96QP("X]("(@("`@("`@("1D;V-<
M;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1H96QP.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!R=6XH*0H*("`@(&9U;F-T:6]N(')U;B@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@)&9U;F,@/2!`
M)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG9G5N8W1I;VXG73L*("`@("`@
M("!I9B`H96UP='DH)&9U;F,I*2!["B`@("`@("`@("`@("\O(&QO;VL@9F]R
M('-H;W)T8W5T<PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T
M:&ES+3YC;VUM86YD<RD@87,@)&-M9"D@>PH@("`@("`@("`@("`@("`@:68@
M*$`D=&AI<RT^8V]M;6%N9'-;)&-M9%U;)W-H;W)T8W5T)UT@/3T@)&-O;6UA
M;F0I('L*("`@("`@("`@("`@("`@("`@("`D8V]M;6%N9"`]("1C;60["B`@
M("`@("`@("`@("`@("`@("`@)&9U;F,@/2!`)'1H:7,M/F-O;6UA;F1S6R1C
M;VUM86YD75LG9G5N8W1I;VXG73L*("`@("`@("`@("`@("`@("`@("!I9B`H
M96UP='DH)&9U;F,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N
M9"<B*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3XD9G5N8R@D8V]M;6%N9"P@
M)&]P=&EO;G,L("1P87)A;7,I.PH@("`@?0H*("`@("\O('U]?0I]"@H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]#;VUM86YD+TEN<W1A;&PN<&AP````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-#,P-S$`,3`T,3<S-C,P,#8`,#(Q-3<Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!6
M97)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($%U=&AO<CH@4W1I9R!3YG1H97(@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@26YS=&%L;"YP:'`L=B`Q
M+C4R(#(P,#0O,#$O,#@@,3<Z,S,Z,3,@<VYI<&5R($5X<"`D"@IR97%U:7)E
M7V]N8V4@(E!%05(O0V]M;6%N9"]#;VUM;VXN<&AP(CL*<F5Q=6ER95]O;F-E
M(")014%2+TEN<W1A;&QE<BYP:'`B.PH*+RHJ"B`J(%!%05(@8V]M;6%N9',@
M9F]R(&EN<W1A;&QA=&EO;B!O<B!D96EN<W1A;&QA=&EO;B]U<&=R861I;F<@
M;V8*("H@<&%C:V%G97,N"B`J"B`J+PIC;&%S<R!014%27T-O;6UA;F1?26YS
M=&%L;"!E>'1E;F1S(%!%05)?0V]M;6%N9%]#;VUM;VX*>PH@("`@+R\@>WM[
M('!R;W!E<G1I97,*"B`@("!V87(@)&-O;6UA;F1S(#T@87)R87DH"B`@("`@
M("`@)VEN<W1A;&PG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G<W5M;6%R>2<@
M/3X@)TEN<W1A;&P@4&%C:V%G92<L"B`@("`@("`@("`@("=F=6YC=&EO;B<@
M/3X@)V1O26YS=&%L;"<L"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)VDG
M+`H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`G9F]R8V4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)V8G+`H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=W:6QL(&]V97)W<FET92!N97=E<B!I;G-T86QL960@<&%C:V%G97,G+`H@
M("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G;F]D97!S
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=N)RP*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G:6=N;W)E(&1E
M<&5N9&5N8VEE<RP@:6YS=&%L;"!A;GEW87DG+`H@("`@("`@("`@("`@("`@
M("`@("DL"B`@("`@("`@("`@("`@("`G<F5G:7-T97(M;VYL>2<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<B<L"B`@
M("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!I;G-T86QL(&9I
M;&5S+"!O;FQY(')E9VES=&5R('1H92!P86-K86=E(&%S(&EN<W1A;&QE9"<L
M"B`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=S;V9T
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=S)RP*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<V]F="!I;G-T
M86QL+"!F86EL('-I;&5N=&QY+"!O<B!U<&=R861E(&EF(&%L<F5A9'D@:6YS
M=&%L;&5D)RP*("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@
M("`@)VYO8G5I;&0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)T(G+`H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=D;VY<)W0@8G5I;&0@0R!E>'1E;G-I;VYS)RP*("`@("`@("`@("`@("`@
M("`@("`I+`H@("`@("`@("`@("`@("`@)VYO8V]M<')E<W,G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)UHG+`H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=R97%U97-T('5N8V]M<')E<W-E
M9"!F:6QE<R!W:&5N(&1O=VYL;V%D:6YG)RP*("`@("`@("`@("`@("`@("`@
M("`I+`H@("`@("`@("`@("`@("`@)VEN<W1A;&QR;V]T)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=2)RP*("`@("`@
M("`@("`@("`@("`@("`G87)G)R`]/B`G1$E2)RP*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G<F]O="!D:7)E8W1O<GD@=7-E9"!W:&5N(&EN<W1A
M;&QI;F<@9FEL97,@*&%L82!02%!<)W,@24Y35$%,3%]23T]4*2<L"B`@("`@
M("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=I9VYO<F4M97)R
M;W)S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M9F]R8V4@:6YS=&%L;"!E=F5N(&EF('1H97)E('=E<F4@97)R;W)S)RP*("`@
M("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@)V%L;&1E<',G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@
M)V$G+`H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=I;G-T86QL(&%L
M;"!R97%U:7)E9"!A;F0@;W!T:6]N86P@9&5P96YD96YC:65S)RP*("`@("`@
M("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@)V]N;'ER97%D97!S
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=O)RP*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G:6YS=&%L;"!A
M;&P@<F5Q=6ER960@9&5P96YD96YC:65S)RP*("`@("`@("`@("`@("`@("`@
M("`I+`H@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@)V1O8R<@/3X@
M)SQP86-K86=E/B`N+BX*26YS=&%L;',@;VYE(&]R(&UO<F4@4$5!4B!P86-K
M86=E<RX@(%EO=2!C86X@<W!E8VEF>2!A('!A8VMA9V4@=&\*:6YS=&%L;"!I
M;B!F;W5R('=A>7,Z"@HB4&%C:V%G92TQ+C`N=&=Z(B`Z(&EN<W1A;&QS(&9R
M;VT@82!L;V-A;"!F:6QE"@HB:'1T<#HO+V5X86UP;&4N8V]M+U!A8VMA9V4M
M,2XP+G1G>B(@.B!I;G-T86QL<R!F<F]M"F%N>7=H97)E(&]N('1H92!N970N
M"@HB<&%C:V%G92YX;6PB(#H@:6YS=&%L;',@=&AE('!A8VMA9V4@9&5S8W)I
M8F5D(&EN"G!A8VMA9V4N>&UL+B`@57-E9G5L(&9O<B!T97-T:6YG+"!O<B!F
M;W(@=W)A<'!I;F<@82!014%2('!A8VMA9V4@:6X*86YO=&AE<B!P86-K86=E
M(&UA;F%G97(@<W5C:"!A<R!24$TN"@HB4&%C:V%G92(@.B!Q=65R:65S('EO
M=7(@8V]N9FEG=7)E9"!S97)V97(**'MC;VYF:6<@;6%S=&5R7W-E<G9E<GTI
M(&%N9"!D;W=N;&]A9',@=&AE(&YE=V5S="!P86-K86=E('=I=&@*=&AE('!R
M969E<G)E9"!Q=6%L:71Y+W-T871E("A[8V]N9FEG('!R969E<G)E9%]S=&%T
M97TI+@H*36]R92!T:&%N(&]N92!P86-K86=E(&UA>2!B92!S<&5C:69I960@
M870@;VYC92X@($ET(&ES(&]K('1O(&UI>"!T:&5S90IF;W5R('=A>7,@;V8@
M<W!E8VEF>6EN9R!P86-K86=E<RX*)RDL"B`@("`@("`@)W5P9W)A9&4G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U5P9W)A9&4@4&%C
M:V%G92<L"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O26YS=&%L;"<L
M"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W5P)RP*("`@("`@("`@("`@
M)V]P=&EO;G,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)V9O<F-E)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=F
M)RP*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G;W9E<G=R:71E(&YE
M=V5R(&EN<W1A;&QE9"!P86-K86=E<R<L"B`@("`@("`@("`@("`@("`@("`@
M*2P*("`@("`@("`@("`@("`@("=N;V1E<',G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=I9VYO<F4@9&5P96YD96YC:65S+"!U<&=R861E
M(&%N>7=A>2<L"B`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@
M("`@("=R96=I<W1E<BUO;FQY)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=R)RP*("`@("`@("`@("`@("`@("`@("`G
M9&]C)R`]/B`G9&\@;F]T(&EN<W1A;&P@9FEL97,L(&]N;'D@<F5G:7-T97(@
M=&AE('!A8VMA9V4@87,@=7!G<F%D960G+`H@("`@("`@("`@("`@("`@("`@
M("DL"B`@("`@("`@("`@("`@("`G;F]B=6EL9"<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G0B<L"B`@("`@("`@("`@
M("`@("`@("`@)V1O8R<@/3X@)V1O;EPG="!B=6EL9"!#(&5X=&5N<VEO;G,G
M+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G;F]C
M;VUP<F5S<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G6B<L"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)E
M<75E<W0@=6YC;VUP<F5S<V5D(&9I;&5S('=H96X@9&]W;FQO861I;F<G+`H@
M("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G:6YS=&%L
M;')O;W0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)U(G+`H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$25(G
M+`H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=R;V]T(&1I<F5C=&]R
M>2!U<V5D('=H96X@:6YS=&%L;&EN9R!F:6QE<R`H86QA(%!(4%PG<R!)3E-4
M04Q,7U)/3U0I)RP*("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@
M("`@("`@)VEG;F]R92UE<G)O<G,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=F;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@
M=V5R92!E<G)O<G,G+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@
M("`@("`@("`G86QL9&5P<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G82<L"B`@("`@("`@("`@("`@("`@("`@)V1O
M8R<@/3X@)VEN<W1A;&P@86QL(')E<75I<F5D(&%N9"!O<'1I;VYA;"!D97!E
M;F1E;F-I97,G+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@
M("`@("`G;VYL>7)E<61E<',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=S:&]R=&]P="<@/3X@)V\G+`H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("=I;G-T86QL(&%L;"!R97%U:7)E9"!D97!E;F1E;F-I97,G+`H@
M("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`I+`H@("`@
M("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^("XN+@I5<&=R861E<R!O;F4@
M;W(@;6]R92!014%2('!A8VMA9V5S+B`@4V5E(&1O8W5M96YT871I;VX@9F]R
M('1H90HB:6YS=&%L;"(@8V]M;6%N9"!F;W(@=V%Y<R!T;R!S<&5C:69Y(&$@
M<&%C:V%G92X*"E=H96X@=7!G<F%D:6YG+"!Y;W5R('!A8VMA9V4@=VEL;"!B
M92!U<&1A=&5D(&EF('1H92!P<F]V:61E9"!N97<*<&%C:V%G92!H87,@82!H
M:6=H97(@=F5R<VEO;B!N=6UB97(@*'5S92!T:&4@+68@;W!T:6]N(&EF('EO
M=2!N965D('1O"G5P9W)A9&4@86YY=V%Y*2X*"DUO<F4@=&AA;B!O;F4@<&%C
M:V%G92!M87D@8F4@<W!E8VEF:65D(&%T(&]N8V4N"B<I+`H@("`@("`@("=U
M<&=R861E+6%L;"<@/3X@87)R87DH"B`@("`@("`@("`@("=S=6UM87)Y)R`]
M/B`G57!G<F%D92!!;&P@4&%C:V%G97,G+`H@("`@("`@("`@("`G9G5N8W1I
M;VXG(#T^("=D;TEN<W1A;&PG+`H@("`@("`@("`@("`G<VAO<G1C=70G(#T^
M("=U82<L"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("=N;V1E<',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=S:&]R=&]P="<@/3X@)VXG+`H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("=I9VYO<F4@9&5P96YD96YC:65S+"!U<&=R861E(&%N>7=A>2<L
M"B`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=R96=I
M<W1E<BUO;FQY)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G<VAO
M<G1O<'0G(#T^("=R)RP*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M9&\@;F]T(&EN<W1A;&P@9FEL97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA
M9V4@87,@=7!G<F%D960G+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@
M("`@("`@("`@("`G;F]B=6EL9"<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G0B<L"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)V1O;EPG="!B=6EL9"!#(&5X=&5N<VEO;G,G+`H@("`@("`@
M("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M6B<L"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)E<75E<W0@=6YC
M;VUP<F5S<V5D(&9I;&5S('=H96X@9&]W;FQO861I;F<G+`H@("`@("`@("`@
M("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G:6YS=&%L;')O;W0G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)U(G
M+`H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$25(G+`H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=R;V]T(&1I<F5C=&]R>2!U<V5D('=H
M96X@:6YS=&%L;&EN9R!F:6QE<R`H86QA(%!(4%PG<R!)3E-404Q,7U)/3U0I
M)RP*("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@)VEG
M;F]R92UE<G)O<G,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("=F;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@=V5R92!E<G)O
M<G,G+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`I
M+`H@("`@("`@("`@("`G9&]C)R`]/B`G"E5P9W)A9&5S(&%L;"!P86-K86=E
M<R!T:&%T(&AA=F4@82!N97=E<B!R96QE87-E(&%V86EL86)L92X@(%5P9W)A
M9&5S(&%R90ID;VYE(&]N;'D@:68@=&AE<F4@:7,@82!R96QE87-E(&%V86EL
M86)L92!O9B!T:&4@<W1A=&4@<W!E8VEF:65D(&EN"B)P<F5F97)R961?<W1A
M=&4B("AC=7)R96YT;'D@>V-O;F9I9R!P<F5F97)R961?<W1A=&5]*2P@;W(@
M82!S=&%T92!C;VYS:61E<F5D"FUO<F4@<W1A8FQE+@HG*2P*("`@("`@("`G
M=6YI;G-T86QL)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^
M("=5;BUI;G-T86QL(%!A8VMA9V4G+`H@("`@("`@("`@("`G9G5N8W1I;VXG
M(#T^("=D;U5N:6YS=&%L;"<L"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@
M)W5N)RP*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)VYO9&5P<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G;B<L"B`@("`@("`@("`@("`@("`@("`@)V1O
M8R<@/3X@)VEG;F]R92!D97!E;F1E;F-I97,L('5N:6YS=&%L;"!A;GEW87DG
M+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G<F5G
M:7-T97(M;VYL>2<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G<B<L"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)V1O(&YO="!R96UO=F4@9FEL97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA
M9V5S(&%S(&YO="!I;G-T86QL960G+`H@("`@("`@("`@("`@("`@("`@("DL
M"B`@("`@("`@("`@("`@("`G:6YS=&%L;')O;W0G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)U(G+`H@("`@("`@("`@
M("`@("`@("`@("=A<F<G(#T^("=$25(G+`H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=R;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@:6YS=&%L;&EN
M9R!F:6QE<R`H86QA(%!(4%PG<R!)3E-404Q,7U)/3U0I)RP*("`@("`@("`@
M("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@)VEG;F]R92UE<G)O<G,G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=F;W)C
M92!I;G-T86QL(&5V96X@:68@=&AE<F4@=V5R92!E<G)O<G,G+`H@("`@("`@
M("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@
M("`G9&]C)R`]/B`G/'!A8VMA9V4^("XN+@I5;FEN<W1A;&QS(&]N92!O<B!M
M;W)E(%!%05(@<&%C:V%G97,N("!-;W)E('1H86X@;VYE('!A8VMA9V4@;6%Y
M(&)E"G-P96-I9FEE9"!A="!O;F-E+@HG*2P*("`@("`@("`G8G5N9&QE)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=5;G!A8VMS(&$@
M4&5C;"!086-K86=E)RP*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]"
M=6YD;&4G+`H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=B=6XG+`H@("`@
M("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G
M9&5S=&EN871I;VXG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G9"<L"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@
M)T1)4B<L"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T]P=&EO;F%L
M(&1E<W1I;F%T:6]N(&1I<F5C=&]R>2!F;W(@=6YP86-K:6YG("AD969A=6QT
M<R!T;R!C=7)R96YT('!A=&@@;W(@(F5X="(@:68@97AI<W1S*2<L"B`@("`@
M("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=F;W)C92<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G9B<L
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T9O<F-E('1H92!U;G!A
M8VMI;F<@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<R!I;B!T:&4@<&%C:V%G
M92<L"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`I+`H@("`@("`@
M("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^"E5N<&%C:W,@82!096-L(%!A8VMA
M9V4@:6YT;R!T:&4@<V5L96-T960@;&]C871I;VXN($ET('=I;&P@9&]W;FQO
M860@=&AE"G!A8VMA9V4@:68@;F5E9&5D+@HG*2P*("`@("D["@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%!%
M05)?0V]M;6%N9%]);G-T86QL(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%!%05)?0V]M
M;6%N9%]);G-T86QL*"8D=6DL("8D8V]N9FEG*0H@("`@>PH@("`@("`@('!A
M<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL("1C;VYF:6<I.PH@("`@
M?0H*("`@("\O('U]?0H*("`@("\O('M[>R!D;TEN<W1A;&PH*0H*("`@(&9U
M;F-T:6]N(&1O26YS=&%L;"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I
M"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1O=VYL;V%D97(N
M<&AP)SL*("`@("`@("!I9B`H96UP='DH)'1H:7,M/FEN<W1A;&QE<BDI('L*
M("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<B`]("9N97<@4$5!4E]);G-T
M86QL97(H)'1H:7,M/G5I*3L*("`@("`@("!]"B`@("`@("`@:68@*"1C;VUM
M86YD(#T]("=U<&=R861E)RD@>PH@("`@("`@("`@("`D;W!T:6]N<ULG=7!G
M<F%D92==(#T@=')U93L*("`@("`@("!]"B`@("`@("`@:68@*"1C;VUM86YD
M(#T]("=U<&=R861E+6%L;"<I('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E
M(")014%2+U)E;6]T92YP:'`B.PH@("`@("`@("`@("`D;W!T:6]N<ULG=7!G
M<F%D92==(#T@=')U93L*("`@("`@("`@("`@)')E;6]T92`]("9N97<@4$5!
M4E]296UO=&4H)'1H:7,M/F-O;F9I9RD["B`@("`@("`@("`@("1S=&%T92`]
M("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RD["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D<W1A=&4I('Q\("1S=&%T92`]/2`G86YY)RD@
M>PH@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R96UO=&4M/F-A;&PH(G!A
M8VMA9V4N;&ES=$QA=&5S=%)E;&5A<V5S(BD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;&%T97-T(#T@)')E;6]T92T^8V%L;"@B
M<&%C:V%G92YL:7-T3&%T97-T4F5L96%S97,B+"`D<W1A=&4I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1L871E<W0I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&QA=&5S=#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<F5G(#T@;F5W(%!%05)?4F5G:7-T<GDH)'1H
M:7,M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RDI.PH@("`@("`@("`@("`D:6YS
M=&%L;&5D(#T@87)R87E?9FQI<"@D<F5G+3YL:7-T4&%C:V%G97,H*2D["B`@
M("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E
M86-H("@D;&%T97-T(&%S("1P86-K86=E(#T^("1I;F9O*2!["B`@("`@("`@
M("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!A8VMA9V4I.PH@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D:6YS=&%L;&5D6R1P86-K86=E72DI
M('L*("`@("`@("`@("`@("`@("`@("`O+R!S:VEP('!A8VMA9V5S('=E(&1O
M;B=T(&AA=F4@:6YS=&%L;&5D"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:6YS=%]V
M97)S:6]N(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=V97)S:6]N
M)RD["B`@("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"(D:6YF
M;UMV97)S:6]N72(L("(D:6YS=%]V97)S:6]N(BP@(FQE(BDI('L*("`@("`@
M("`@("`@("`@("`@("`O+R!I;G-T86QL960@=F5R<VEO;B!I<R!U<"UT;RUD
M871E"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D<&%R86US6UT@/2`D<&%C:V%G93L*
M("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AA<G)A>2@G
M9&%T82<@/3X@(E=I;&P@=7!G<F%D92`D<&%C:V%G92(I+"`D8V]M;6%N9"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F1O=VYL
M;V%D97(@/2`F;F5W(%!%05)?1&]W;FQO861E<B@D=&AI<RT^=6DL("1O<'1I
M;VYS+"`D=&AI<RT^8V]N9FEG*3L*("`@("`@("`D97)R;W)S(#T@87)R87DH
M*3L*("`@("`@("`D9&]W;FQO861E9"`](&%R<F%Y*"D["B`@("`@("`@)'1H
M:7,M/F1O=VYL;V%D97(M/F1O=VYL;V%D*"1P87)A;7,I.PH@("`@("`@("1E
M<G)O<G,@/2`D=&AI<RT^9&]W;FQO861E<BT^9V5T17)R;W)-<V=S*"D["B`@
M("`@("`@:68@*&-O=6YT*"1E<G)O<G,I*2!["B`@("`@("`@("`@("1E<G);
M)V1A=&$G72`](&%R<F%Y*"1E<G)O<G,I.PH@("`@("`@("`@("`D97)R6R=H
M96%D;&EN92==(#T@)TEN<W1A;&P@17)R;W)S)SL*("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"1E<G(I.PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(B1C;VUM86YD(&9A:6QE9"(I.PH@("`@("`@
M('T*("`@("`@("`D9&]W;FQO861E9"`]("1T:&ES+3YD;W=N;&]A9&5R+3YG
M971$;W=N;&]A9&5D4&%C:V%G97,H*3L*("`@("`@("`D=&AI<RT^:6YS=&%L
M;&5R+3YS;W)T4&MG1&5P<R@D9&]W;FQO861E9"D["B`@("`@("`@9F]R96%C
M:"`H)&1O=VYL;V%D960@87,@)'!K9RD@>PH@("`@("`@("`@("`D8FX@/2!B
M87-E;F%M92@D<&MG6R=F:6QE)UTI.PH@("`@("`@("`@("`D:6YF;R`]("1T
M:&ES+3YI;G-T86QL97(M/FEN<W1A;&PH)'!K9ULG9FEL92==+"`D;W!T:6]N
M<RP@)'1H:7,M/F-O;F9I9RD["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M:6YF;RDI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG
M970H)W9E<F)O<V4G*2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D;&%B
M96P@/2`B)&EN9F];<&%C:V%G95T@)&EN9F];=F5R<VEO;ETB.PH@("`@("`@
M("`@("`@("`@("`@("1O=70@/2!A<G)A>2@G9&%T82<@/3X@(B1C;VUM86YD
M(&]K.B`D;&%B96PB*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&EN9F];)W)E;&5A<V5?=V%R;FEN9W,G72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]U=%LG<F5L96%S95]W87)N:6YG<R==(#T@)&EN9F];)W)E
M;&5A<V5?=V%R;FEN9W,G73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1O=70L("1C
M;VUM86YD*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M)&-O;6UA;F0@9F%I;&5D(BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9&]5;FEN<W1A;&PH*0H*("`@(&9U;F-T:6]N(&1O56YI;G-T86QL*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/FEN<W1A;&QE<BDI('L*("`@("`@("`@("`@)'1H:7,M
M/FEN<W1A;&QE<B`]("9N97<@4$5!4E]);G-T86QL97(H)'1H:7,M/G5I*3L*
M("`@("`@("!]"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")0;&5A<V4@
M<W5P<&QY('1H92!P86-K86=E*',I('EO=2!W86YT('1O('5N:6YS=&%L;"(I
M.PH@("`@("`@('T*("`@("`@("!I;F-L=61E7V]N8V4@)U!%05(O4F5G:7-T
M<GDN<&AP)SL*("`@("`@("`D<F5G(#T@;F5W(%!%05)?4F5G:7-T<GDH)'1H
M:7,M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RDI.PH@("`@("`@("1N97=P87)A
M;7,@/2!A<G)A>2@I.PH@("`@("`@("1B861P87)A;7,@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!K9RD@>PH@("`@("`@("`@
M("`D:6YF;R`]("1R96<M/G!A8VMA9V5);F9O*"1P:V<I.PH@("`@("`@("`@
M("!I9B`H)&EN9F\@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@("1B861P
M87)A;7-;72`]("1P:V<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D;F5W<&%R86US6UT@/2`D:6YF;SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("`D=&AI<RT^:6YS=&%L;&5R+3YS;W)T4&MG1&5P
M<R@D;F5W<&%R86US+"!T<G5E*3L*("`@("`@("`D<&%R86US(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H*"1N97=P87)A;7,@87,@)&EN9F\I('L*("`@
M("`@("`@("`@)'!A<F%M<UM=(#T@)&EN9F];)VEN9F\G75LG<&%C:V%G92==
M.PH@("`@("`@('T*("`@("`@("`D<&%R86US(#T@87)R87E?;65R9V4H)'!A
M<F%M<RP@)&)A9'!A<F%M<RD["B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A
M<R`D<&MG*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:6YS=&%L;&5R+3YU
M;FEN<W1A;&PH)'!K9RP@)&]P=&EO;G,I*2!["B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`P*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")U;FEN<W1A
M;&P@;VLZ("1P:V<B+"`D8V]M;6%N9"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(G5N:6YS=&%L;"!F86EL960Z("1P:V<B*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O+R!]?7T*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&]"=6YD
M;&4H*0H@("`@+RH*("`@("AC;W@I($ET(&IU<W0@9&]W;FQO861S(&%N9"!U
M;G1A<G,@=&AE('!A8VMA9V4L(&1O97,@;F]T(&1O"B`@("`@("`@("`@(&%N
M>2!C:&5C:R!T:&%T('1H92!014%27TEN<W1A;&QE<CHZ7VEN<W1A;&Q&:6QE
M*"D@9&]E<RX*("`@("HO"@H@("`@9G5N8W1I;VX@9&]"=6YD;&4H)&-O;6UA
M;F0L("1O<'1I;VYS+"`D<&%R86US*0H@("`@>PH@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^:6YS=&%L;&5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^:6YS
M=&%L;&5R(#T@)FYE=R!014%27T1O=VYL;V%D97(H)'1H:7,M/G5I*3L*("`@
M("`@("!]"B`@("`@("`@)&EN<W1A;&QE<B`]("8D=&AI<RT^:6YS=&%L;&5R
M.PH@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4&QE87-E('-U<'!L>2!T
M:&4@<&%C:V%G92!Y;W4@=V%N="!T;R!B=6YD;&4B*3L*("`@("`@("!]"B`@
M("`@("`@)'!K9V9I;&4@/2`D<&%R86US6S!=.PH@("`@("`@("1N965D7V1O
M=VYL;V%D(#T@9F%L<V4["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R->*&AT
M='!\9G1P*3HO+R,G+"`D<&MG9FEL92DI('L*("`@("`@("`@("`@)&YE961?
M9&]W;FQO860@/2!T<G5E.PH@("`@("`@('T@96QS96EF("@A0&ES7V9I;&4H
M)'!K9V9I;&4I*2!["B`@("`@("`@("`@(&EF("@D:6YS=&%L;&5R+3YV86QI
M9%!A8VMA9V5.86UE*"1P:V=F:6QE*2D@>PH@("`@("`@("`@("`@("`@)'!K
M9V9I;&4@/2`D:6YS=&%L;&5R+3YG971086-K86=E1&]W;FQO8615<FPH)'!K
M9V9I;&4I.PH@("`@("`@("`@("`@("`@)&YE961?9&]W;FQO860@/2!T<G5E
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*'-T
M<FQE;B@D<&MG9FEL92DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(D-O=6QD(&YO="!O<&5N('1H92!P86-K86=E
M(&9I;&4Z("1P:V=F:6QE(BD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M3F\@<&%C:V%G92!F:6QE(&=I=F5N(BD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($1O=VYL;V%D('!A
M8VMA9V4@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*("`@("`@("!I9B`H)&YE961?9&]W;FQO860I('L*("`@("`@
M("`@("`@)&1O=VYL;V%D9&ER(#T@)&EN<W1A;&QE<BT^8V]N9FEG+3YG970H
M)V1O=VYL;V%D7V1I<B<I.PH@("`@("`@("`@("!I9B`H96UP='DH)&1O=VYL
M;V%D9&ER*2D@>PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&1O=VYL;V%D9&ER(#T@4WES=&5M.CIM:W1E;7`H)RUD)RDI*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1D;W=N;&]A9&1I<CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1I;G-T86QL97(M/FQO9R@R+"`G
M*R!T;7`@9&ER(&-R96%T960@870@)R`N("1D;W=N;&]A9&1I<BD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&-A;&QB86-K(#T@)'1H:7,M/G5I(#\@
M87)R87DH)B1I;G-T86QL97(L("=?9&]W;FQO861#86QL8F%C:R<I(#H@;G5L
M;#L*("`@("`@("`@("`@)&9I;&4@/2`D:6YS=&%L;&5R+3YD;W=N;&]A9$AT
M='`H)'!K9V9I;&4L("1T:&ES+3YU:2P@)&1O=VYL;V%D9&ER+"`D8V%L;&)A
M8VLI.PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL92DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D9FEL
M92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!K9V9I;&4@/2`D9FEL
M93L*("`@("`@("!]"@H@("`@("`@+R\@4&%R<V4@>&UL(&9I;&4@+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*("`@
M("`@("`D<&MG:6YF;R`]("1I;G-T86QL97(M/FEN9F]&<F]M5&=Z1FEL92@D
M<&MG9FEL92D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!K9VEN9F\I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<&MG
M:6YF;RD["B`@("`@("`@?0H@("`@("`@("1I;G-T86QL97(M/G9A;&ED871E
M4&%C:V%G94EN9F\H)'!K9VEN9F\L("1E<G)O<G,L("1W87)N:6YG<RD["B`@
M("`@("`@+R\@6%A8(%=E(&%L;&]W('=A<FYI;F=S+"!D;R!W92!H879E('1O
M(&1O(&ET/PH@("`@("`@(&EF("AC;W5N="@D97)R;W)S*2D@>PH@("`@("`@
M("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=F;W)C92==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")4:&4@9F]L;&]W
M:6YG(&5R<F]R<R!W:&5R92!F;W5N9#I<;B(N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*")<;B(L
M("1E<G)O<G,I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V<H,"P@(G=A<FYI;F<@.B!T:&4@9F]L;&]W:6YG(&5R
M<F]R<R!W97)E(&9O=6YD.EQN(BX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:6UP;&]D92@B7&XB+"`D97)R;W)S*2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@)'!K9VYA;64@/2`D<&MG:6YF;ULG<&%C:V%G92==
M.PH*("`@("`@("`O+R!5;G!A8VMI;F<@+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)V1E<W1I;F%T:6]N)UTI*2!["B`@("`@("`@("`@(&EF
M("@A:7-?9&ER*"1O<'1I;VYS6R=D97-T:6YA=&EO;B==*2D@>PH@("`@("`@
M("`@("`@("`@4WES=&5M.CIM:V1I<B@G+7`@)R`N("1O<'1I;VYS6R=D97-T
M:6YA=&EO;B==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&5S="`]
M(')E86QP871H*"1O<'1I;VYS6R=D97-T:6YA=&EO;B==*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<'=D(#T@9V5T8W=D*"D["B`@("`@("`@
M("`@(&EF("AI<U]D:7(H)'!W9"`N($1)4D5#5$]265]315!!4D%43U(@+B`G
M97AT)RDI('L*("`@("`@("`@("`@("`@("1D97-T(#T@)'!W9"`N($1)4D5#
M5$]265]315!!4D%43U(@+B`G97AT)SL*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1D97-T(#T@)'!W9#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("`D9&5S="`N/2!$25)%0U1/4EE?4T5005)!5$]2
M("X@)'!K9VYA;64["B`@("`@("`@)&]R:6<@/2`D<&MG;F%M92`N("<M)R`N
M("1P:V=I;F9O6R=V97)S:6]N)UT["@H@("`@("`@("1T87(@/2!N97<@07)C
M:&EV95]487(H)'!K9V9I;&4I.PH@("`@("`@(&EF("@A0"1T87(M/F5X=')A
M8W1-;V1I9GDH)&1E<W0L("1O<FEG*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(G5N86)L92!T;R!U;G!A8VL@)'!K9V9I;&4B
M*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")0
M86-K86=E(')E861Y(&%T("<D9&5S="<B*3L*("`@("\O('U]?0H@("`@?0H*
M("`@("\O('U]?0H*?0H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+T-O;6UA;F0O4&%C:V%G92YP:'``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`V,#<Q-@`Q,#0Q-S,V,S`P-@`P,C$U,C,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E
M<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@
M($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN970^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O"B\O("1)9#H@4&%C:V%G92YP:'`L=B`Q+C8P(#(P,#0O,#$O,S$@
M,C(Z,SDZ,C4@8V5L;&]G($5X<"`D"@IR97%U:7)E7V]N8V4@)U!%05(O0V]M
M;6]N+G!H<"<["G)E<75I<F5?;VYC92`G4$5!4B]#;VUM86YD+T-O;6UO;BYP
M:'`G.PH*8VQA<W,@4$5!4E]#;VUM86YD7U!A8VMA9V4@97AT96YD<R!014%2
M7T-O;6UA;F1?0V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@
M=F%R("1C;VUM86YD<R`](&%R<F%Y*`H@("`@("`@("=P86-K86=E)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("="=6EL9"!086-K86=E
M)RP*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]086-K86=E)RP*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<"<L"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=N;V-O;7!R97-S)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=:
M)RP*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&\@;F]T(&=Z:7`@
M=&AE('!A8VMA9V4@9FEL92<*("`@("`@("`@("`@("`@("`@("`I+`H@("`@
M("`@("`@("`@("`@)W-H;W=N86UE)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=N)RP*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G4')I;G0@=&AE(&YA;64@;V8@=&AE('!A8VMA9V5D(&9I
M;&4N)RP*("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@
M*2P*("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C9FEL95T*0W)E871E<R!A
M(%!%05(@<&%C:V%G92!F<F]M(&ET<R!D97-C<FEP=&EO;B!F:6QE("AU<W5A
M;&QY(&-A;&QE9`IP86-K86=E+GAM;"DN"B<*("`@("`@("`@("`@*2P*("`@
M("`@("`G<&%C:V%G92UV86QI9&%T92<@/3X@87)R87DH"B`@("`@("`@("`@
M("=S=6UM87)Y)R`]/B`G5F%L:61A=&4@4&%C:V%G92!#;VYS:7-T96YC>2<L
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G959A;&ED871E
M)RP*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<'8G+`H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH*2P*("`@("`@("`@("`@)V1O8R<@/3X@
M)PHG+`H@("`@("`@("`@("`I+`H@("`@("`@("=C=G-D:69F)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=2=6X@82`B8W9S(&1I9F8B
M(&9O<B!A;&P@9FEL97,@:6X@82!P86-K86=E)RP*("`@("`@("`@("`@)V9U
M;F-T:6]N)R`]/B`G9&]#=G-$:69F)RP*("`@("`@("`@("`@)W-H;W)T8W5T
M)R`]/B`G8V0G+`H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`G<75I970G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)W$G+`H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("="92!Q=6EE="<L"B`@("`@("`@("`@("`@("`@("`@*2P*
M("`@("`@("`@("`@("`@("=R96%L;'EQ=6EE="<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G42<L"B`@("`@("`@("`@
M("`@("`@("`@)V1O8R<@/3X@)T)E(')E86QL>2!Q=6EE="<L"B`@("`@("`@
M("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=D871E)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=$)RP*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T(')E=FES
M:6]N(&]F($1!5$4G+`H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$
M051%)RP*("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@
M)W)E;&5A<V4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=S:&]R
M=&]P="<@/3X@)U(G+`H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$
M:69F(&%G86EN<W0@=&%G(&9O<B!P86-K86=E(')E;&5A<V4@4D5,)RP*("`@
M("`@("`@("`@("`@("`@("`G87)G)R`]/B`G4D5,)RP*("`@("`@("`@("`@
M("`@("`@("`I+`H@("`@("`@("`@("`@("`@)W)E=FES:6]N)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=R)RP*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T(')E=FES
M:6]N(%)%5B<L"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)U)%5B<L
M"B`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=C;VYT
M97AT)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=C)RP*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1V5N97)A
M=&4@8V]N=&5X="!D:69F)RP*("`@("`@("`@("`@("`@("`@("`I+`H@("`@
M("`@("`@("`@("`@)W5N:69I960G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)W4G+`H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("='96YE<F%T92!U;FEF:65D(&1I9F8G+`H@("`@("`@("`@
M("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G:6=N;W)E+6-A<V4G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VDG
M+`H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=)9VYO<F4@8V%S92P@
M8V]N<VED97(@=7!P97(M(&%N9"!L;W=E<BUC87-E(&QE='1E<G,@97%U:79A
M;&5N="<L"B`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@
M("=I9VYO<F4M=VAI=&5S<&%C92<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G8B<L"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)TEG;F]R92!C:&%N9V5S(&EN(&%M;W5N="!O9B!W:&ET92!S
M<&%C92<L"B`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@
M("=I9VYO<F4M8FQA;FLM;&EN97,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)T(G+`H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=)9VYO<F4@8VAA;F=E<R!T:&%T(&EN<V5R="!O<B!D96QE
M=&4@8FQA;FL@;&EN97,G+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@
M("`@("`@("`@("`G8G)I968G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("=297!O<G0@;VYL>2!W:&5T:&5R('1H92!F:6QE<R!D
M:69F97(L(&YO(&1E=&%I;',G+`H@("`@("`@("`@("`@("`@("`@("DL"B`@
M("`@("`@("`@("`@("`G9')Y+7)U;B<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;B<L"B`@("`@("`@("`@("`@("`@
M("`@)V1O8R<@/3X@)T1O;EPG="!D;R!A;GET:&EN9RP@:G5S="!P<F5T96YD
M)RP*("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@*2P*
M("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E+GAM;#X*0V]M<&%R97,@
M86QL('1H92!F:6QE<R!I;B!A('!A8VMA9V4N("!7:71H;W5T(&%N>2!O<'1I
M;VYS+"!T:&ES"F-O;6UA;F0@=VEL;"!C;VUP87)E('1H92!C=7)R96YT(&-O
M9&4@=VET:"!T:&4@;&%S="!C:&5C:V5D+6EN(&-O9&4N"E5S:6YG('1H92`M
M<B!O<B`M4B!O<'1I;VX@>6]U(&UA>2!C;VUP87)E('1H92!C=7)R96YT(&-O
M9&4@=VET:"!T:&%T"F]F(&$@<W!E8VEF:6,@<F5L96%S92X*)RP*("`@("`@
M("`@("`@*2P*("`@("`@("`G8W9S=&%G)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W-U;6UA<GDG(#T^("=3970@0U93(%)E;&5A<V4@5&%G)RP*("`@("`@
M("`@("`@)V9U;F-T:6]N)R`]/B`G9&]#=G-486<G+`H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=C="<L"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("=Q=6EE="<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<2<L"B`@("`@("`@("`@
M("`@("`@("`@)V1O8R<@/3X@)T)E('%U:65T)RP*("`@("`@("`@("`@("`@
M("`@("`I+`H@("`@("`@("`@("`@("`@)W)E86QL>7%U:65T)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=1)RP*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G0F4@<F5A;&QY('%U:65T)RP*
M("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@)W-L:61E
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=&)RP*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G36]V92`H<VQI
M9&4I('1A9R!I9B!I="!E>&ES=',G+`H@("`@("`@("`@("`@("`@("`@("DL
M"B`@("`@("`@("`@("`@("`G9&5L971E)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=D)RP*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G4F5M;W9E('1A9R<L"B`@("`@("`@("`@("`@("`@
M("`@*2P*("`@("`@("`@("`@("`@("=D<GDM<G5N)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=N)RP*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G1&]N7"=T(&1O(&%N>71H:6YG+"!J=7-T
M('!R971E;F0G+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@
M("`@("`I+`H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4N>&UL/@I3
M971S(&$@0U93('1A9R!O;B!A;&P@9FEL97,@:6X@82!P86-K86=E+B`@57-E
M('1H:7,@8V]M;6%N9"!A9G1E<B!Y;W4@:&%V90IP86-K86=E9"!A(&1I<W1R
M:6)U=&EO;B!T87)B86QL('=I=&@@=&AE(")P86-K86=E(B!C;VUM86YD('1O
M('1A9R!W:&%T"G)E=FES:6]N<R!O9B!W:&%T(&9I;&5S('=E<F4@:6X@=&AA
M="!R96QE87-E+B`@268@;F5E9"!T;R!F:7@@<V]M971H:6YG"F%F=&5R(')U
M;FYI;F<@8W9S=&%G(&]N8V4L(&)U="!B969O<F4@=&AE('1A<F)A;&P@:7,@
M<F5L96%S960@=&\@=&AE('!U8FQI8RP*=7-E('1H92`B<VQI9&4B(&]P=&EO
M;B!T;R!M;W9E('1H92!R96QE87-E('1A9RX*)RP*("`@("`@("`@("`@*2P*
M("`@("`@("`G<G5N+71E<W1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W-U
M;6UA<GDG(#T^("=2=6X@4F5G<F5S<VEO;B!497-T<R<L"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O4G5N5&5S=',G+`H@("`@("`@("`@("`G<VAO
M<G1C=70G(#T^("=R="<L"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A
M>2@I+`H@("`@("`@("`@("`G9&]C)R`]/B`G6W1E<W1F:6QE?&1I<B`N+BY=
M"E)U;B!R96=R97-S:6]N('1E<W1S('=I=&@@4$A07"=S(')E9W)E<W-I;VX@
M=&5S=&EN9R!S8W)I<'0@*')U;BUT97-T<RYP:'`I+B<L"B`@("`@("`@("`@
M("DL"B`@("`@("`@)W!A8VMA9V4M9&5P96YD96YC:65S)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=3:&]W('!A8VMA9V4@9&5P96YD
M96YC:65S)RP*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]086-K86=E
M1&5P96YD96YC:65S)RP*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<&0G
M+`H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P*("`@("`@("`@
M("`@)V1O8R<@/3X@)PI,:7-T(&%L;"!D97!E;F-I97,@=&AE('!A8VMA9V4@
M:&%S+B<*("`@("`@("`@("`@*2P*("`@("`@("`G<VEG;B<@/3X@87)R87DH
M"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4VEG;B!A('!A8VMA9V4@9&ES
M=')I8G5T:6]N(&9I;&4G+`H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;U-I9VXG+`H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=S:2<L"B`@("`@
M("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`H@("`@("`@("`@("`G9&]C
M)R`]/B`G/'!A8VMA9V4M9FEL93X*4VEG;G,@82!P86-K86=E(&1I<W1R:6)U
M=&EO;B`H+G1A<B!O<B`N=&=Z*2!F:6QE('=I=&@@1VYU4$<N)RP*("`@("`@
M("`@("`@*2P*("`@("`@("`G;6%K97)P;2<@/3X@87)R87DH"B`@("`@("`@
M("`@("=S=6UM87)Y)R`]/B`G0G5I;&1S(&%N(%)032!S<&5C(&9I;&4@9G)O
M;2!A(%!%05(@<&%C:V%G92<L"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@
M)V1O36%K95)032<L"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)P;2<L
M"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("=S<&5C+71E;7!L871E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=T)RP*("`@("`@("`@("`@("`@("`@("`G
M87)G)R`]/B`G1DE,12<L"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)U5S92!&24Q%(&%S(%)032!S<&5C(&9I;&4@=&5M<&QA=&4G"B`@("`@("`@
M("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=R<&TM<&MG;F%M92<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M<"<L"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T9/4DU!5"<L"B`@
M("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)U5S92!&3U)-050@87,@9F]R
M;6%T('-T<FEN9R!F;W(@4E!-('!A8VMA9V4@;F%M92P@)7,@:7,@<F5P;&%C
M960*8GD@=&AE(%!%05(@<&%C:V%G92!N86UE+"!D969A=6QT<R!T;R`B4$5!
M4CHZ)7,B+B<L"B`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@
M("`@("DL"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G92UF:6QE/@H*
M0W)E871E<R!A;B!24$T@+G-P96,@9FEL92!F;W(@=W)A<'!I;F<@82!014%2
M('!A8VMA9V4@:6YS:61E(&%N(%)030IP86-K86=E+B`@26YT96YD960@=&\@
M8F4@=7-E9"!F<F]M('1H92!34$5#4R!D:7)E8W1O<GDL('=I=&@@=&AE(%!%
M05(*<&%C:V%G92!T87)B86QL(&EN('1H92!33U520T53(&1I<F5C=&]R>3H*
M"B0@<&5A<B!M86ME<G!M("XN+U-/55)#15,O3F5T7U-O8VME="TQ+C`N=&=Z
M"E=R;W1E(%)032!S<&5C(&9I;&4@4$5!4CHZ3F5T7T=E;RTQ+C`N<W!E8PHD
M(')P;2`M8F(@4$5!4CHZ3F5T7U-O8VME="TQ+C`N<W!E8PHN+BX*5W)O=&4Z
M("]U<W(O<W)C+W)E9&AA="]24$U3+VDS.#8O4$5!4CHZ3F5T7U-O8VME="TQ
M+C`M,2YI,S@V+G)P;0HG+`H@("`@("`@("`@("`I+`H@("`@("`@("D["@H@
M("`@=F%R("1O=71P=70["@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R
M=6-T;W(*"B`@("`O*BH*("`@("`J(%!%05)?0V]M;6%N9%]086-K86=E(&-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]086-K86=E*"8D=6DL("8D
M8V]N9FEG*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O
M;6UO;B@D=6DL("1C;VYF:6<I.PH@("`@?0H*("`@("\O('U]?0H*("`@("\O
M('M[>R!?9&ES<&QA>59A;&ED871I;VY297-U;'1S*"D*"B`@("!F=6YC=&EO
M;B!?9&ES<&QA>59A;&ED871I;VY297-U;'1S*"1E<G(L("1W87)N+"`D<W1R
M:6-T(#T@9F%L<V4I"B`@("!["B`@("`@("`@9F]R96%C:"`H)&5R<B!A<R`D
M92D@>PH@("`@("`@("`@("`D=&AI<RT^;W5T<'5T("X](")%<G)O<CH@)&5<
M;B(["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1W87)N(&%S("1W*2![
M"B`@("`@("`@("`@("1T:&ES+3YO=71P=70@+CT@(E=A<FYI;F<Z("1W7&XB
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;W5T<'5T("X]('-P<FEN=&8H
M)U9A;&ED871I;VXZ("5D(&5R<F]R*',I+"`E9"!W87)N:6YG*',I)RXB7&XB
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S:7IE
M;V8H)&5R<BDL('-I>F5O9B@D=V%R;BDI.PH@("`@("`@(&EF("@D<W1R:6-T
M("8F('-I>F5O9B@D97)R*2`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/F]U
M='!U="`N/2`B1FEX('1H97-E(&5R<F]R<R!A;F0@=')Y(&%G86EN+B(["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&]086-K
M86=E*"D*"B`@("!F=6YC=&EO;B!D;U!A8VMA9V4H)&-O;6UA;F0L("1O<'1I
M;VYS+"`D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3YO=71P=70@/2`G
M)SL*("`@("`@("!I;F-L=61E7V]N8V4@)U!%05(O4&%C:V%G97(N<&AP)SL*
M("`@("`@("`D<&MG:6YF;V9I;&4@/2!I<W-E="@D<&%R86US6S!=*2`_("1P
M87)A;7-;,%T@.B`G<&%C:V%G92YX;6PG.PH@("`@("`@("1P86-K86=E<B`]
M)B!N97<@4$5!4E]086-K86=E<B@I.PH@("`@("`@("1E<G(@/2`D=V%R;B`]
M(&%R<F%Y*"D["B`@("`@("`@)&1I<B`](&1I<FYA;64H)'!K9VEN9F]F:6QE
M*3L*("`@("`@("`D8V]M<')E<W,@/2!E;7!T>2@D;W!T:6]N<ULG;F]C;VUP
M<F5S<R==*2`_('1R=64@.B!F86QS93L*("`@("`@("`D<F5S=6QT(#T@)'!A
M8VMA9V5R+3YP86-K86=E*"1P:V=I;F9O9FEL92P@)&-O;7!R97-S*3L*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA
M;F0I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E
M<W5L="D["B`@("`@("`@?0H@("`@("`@("\O($1O;B=T('=A;G0@;W5T<'5T
M+"!O;FQY('1H92!P86-K86=E(&9I;&4@;F%M92!J=7-T(&-R96%T960*("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-H;W=N86UE)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3YO=71P=70@/2`D<F5S=6QT.PH@("`@("`@('T*("`@
M("`@("`O*B`H8V]X*2!7:&%T(&ES('-U<'!O<V5D('1O(&1O('1H870@8V]D
M93\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<;B(L("1T:&ES+3YO=71P
M=70I.PH@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@
M("`@("`@("`D=&AI<RT^;W5T<'5T("X]("1L:6YE+B)N(CL*("`@("`@("!]
M"B`@("`@("`@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^;W5T<'5T("X](")086-K86=E(&9A
M:6QE9#H@(BXD<F5S=6QT+3YG971-97-S86=E*"D["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M
M;6%N9"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9&]086-K86=E5F%L:61A=&4H*0H*("`@(&9U;F-T:6]N
M(&1O4&%C:V%G959A;&ED871E*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M
M<RD*("`@('L*("`@("`@("`D=&AI<RT^;W5T<'5T(#T@)R<["B`@("`@("`@
M:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L*("`@("`@("`@("`@)'!A<F%M
M<ULP72`](")P86-K86=E+GAM;"(["B`@("`@("`@?0H@("`@("`@("1O8FH@
M/2!N97<@4$5!4E]#;VUM;VX["B`@("`@("`@)&EN9F\@/2!N=6QL.PH@("`@
M("`@(&EF("@D9G`@/2!`9F]P96XH)'!A<F%M<ULP72P@(G(B*2D@>PH@("`@
M("`@("`@("`D=&5S="`](&9R96%D*"1F<"P@-2D["B`@("`@("`@("`@(&9C
M;&]S92@D9G`I.PH@("`@("`@("`@("!I9B`H)'1E<W0@/3T@(CP_>&UL(BD@
M>PH@("`@("`@("`@("`@("`@)&EN9F\@/2`D;V)J+3YI;F9O1G)O;41E<V-R
M:7!T:6]N1FEL92@D<&%R86US6S!=*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&EN9F\I*2!["B`@("`@("`@("`@("1I
M;F9O(#T@)&]B:BT^:6YF;T9R;VU49WI&:6QE*"1P87)A;7-;,%TI.PH@("`@
M("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1I;F9O*3L*("`@
M("`@("!]"B`@("`@("`@)&]B:BT^=F%L:61A=&5086-K86=E26YF;R@D:6YF
M;RP@)&5R<BP@)'=A<FXI.PH@("`@("`@("1T:&ES+3Y?9&ES<&QA>59A;&ED
M871I;VY297-U;'1S*"1E<G(L("1W87)N*3L*("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1O
M0W9S5&%G*"D*"B`@("!F=6YC=&EO;B!D;T-V<U1A9R@D8V]M;6%N9"P@)&]P
M=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/F]U='!U="`]
M("<G.PH@("`@("`@("1?8VUD(#T@)&-O;6UA;F0["B`@("`@("`@:68@*'-I
M>F5O9B@D<&%R86US*2`\(#$I('L*("`@("`@("`@("`@)&AE;'`@/2`D=&AI
M<RT^9V5T2&5L<"@D8V]M;6%N9"D["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0Z(&UI<W-I;F<@<&%R86UE=&5R.B`D
M:&5L<%LP72(I.PH@("`@("`@('T*("`@("`@("`D;V)J(#T@;F5W(%!%05)?
M0V]M;6]N.PH@("`@("`@("1I;F9O(#T@)&]B:BT^:6YF;T9R;VU$97-C<FEP
M=&EO;D9I;&4H)'!A<F%M<ULP72D["B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&EN9F\I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D:6YF;RD["B`@("`@("`@?0H@("`@("`@("1E<G(@/2`D=V%R;B`]
M(&%R<F%Y*"D["B`@("`@("`@)&]B:BT^=F%L:61A=&5086-K86=E26YF;R@D
M:6YF;RP@)&5R<BP@)'=A<FXI.PH@("`@("`@(&EF("@A)'1H:7,M/E]D:7-P
M;&%Y5F%L:61A=&EO;E)E<W5L=',H)&5R<BP@)'=A<FXL('1R=64I*2!["B`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T
M+"`D8V]M;6%N9"D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@
M("`@("`D=F5R<VEO;B`]("1I;F9O6R=V97)S:6]N)UT["B`@("`@("`@)&-V
M<W9E<G-I;VX@/2!P<F5G7W)E<&QA8V4H)R];7F$M>C`M.5TO:2<L("=?)RP@
M)'9E<G-I;VXI.PH@("`@("`@("1C=G-T86<@/2`B4D5,14%315\D8W9S=F5R
M<VEO;B(["B`@("`@("`@)&9I;&5S(#T@87)R87E?:V5Y<R@D:6YF;ULG9FEL
M96QI<W0G72D["B`@("`@("`@)&-O;6UA;F0@/2`B8W9S(CL*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)W%U:65T)UTI*2!["B`@("`@("`@("`@("1C
M;VUM86YD("X]("<@+7$G.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI*2!["B`@("`@("`@("`@("1C;VUM
M86YD("X]("<@+5$G.PH@("`@("`@('T*("`@("`@("`D8V]M;6%N9"`N/2`G
M('1A9R<["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=S;&ED92==*2D@
M>PH@("`@("`@("`@("`D8V]M;6%N9"`N/2`G("U&)SL*("`@("`@("!]"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=D96QE=&4G72DI('L*("`@("`@
M("`@("`@)&-O;6UA;F0@+CT@)R`M9"<["B`@("`@("`@?0H@("`@("`@("1C
M;VUM86YD("X]("<@)R`N("1C=G-T86<@+B`G("<@+B!E<V-A<&5S:&5L;&%R
M9R@D<&%R86US6S!=*3L*("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I
M;&4I('L*("`@("`@("`@("`@)&-O;6UA;F0@+CT@)R`G("X@97-C87!E<VAE
M;&QA<F<H)&9I;&4I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F-O
M;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`Q*2!["B`@("`@("`@("`@("1T:&ES
M+3YO=71P=70@+CT@(BL@)&-O;6UA;F1<;B(["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YO=71P=70@+CT@(BL@)&-O;6UA;F1<;B(["B`@("`@("`@:68@
M*&5M<'1Y*"1O<'1I;VYS6R=D<GDM<G5N)UTI*2!["B`@("`@("`@("`@("1F
M<"`]('!O<&5N*"1C;VUM86YD+"`B<B(I.PH@("`@("`@("`@("!W:&EL92`H
M)&QI;F4@/2!F9V5T<R@D9G`L(#$P,C0I*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^;W5T<'5T("X](')T<FEM*"1L:6YE*2XB7&XB.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@('!C;&]S92@D9G`I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)%]C;60I
M.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&1O0W9S1&EF9B@I"@H@("`@9G5N8W1I;VX@9&]#=G-$:69F*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI
M<RT^;W5T<'5T(#T@)R<["B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\
M(#$I('L*("`@("`@("`@("`@)&AE;'`@/2`D=&AI<RT^9V5T2&5L<"@D8V]M
M;6%N9"D["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M)&-O;6UA;F0Z(&UI<W-I;F<@<&%R86UE=&5R.B`D:&5L<%LP72(I.PH@("`@
M("`@('T*("`@("`@("`D;V)J(#T@;F5W(%!%05)?0V]M;6]N.PH@("`@("`@
M("1I;F9O(#T@)&]B:BT^:6YF;T9R;VU$97-C<FEP=&EO;D9I;&4H)'!A<F%M
M<ULP72D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD["B`@
M("`@("`@?0H@("`@("`@("1F:6QE<R`](&%R<F%Y7VME>7,H)&EN9F];)V9I
M;&5L:7-T)UTI.PH@("`@("`@("1C;60@/2`B8W9S(CL*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)W%U:65T)UTI*2!["B`@("`@("`@("`@("1C;60@
M+CT@)R`M<2<["B`@("`@("`@("`@('5N<V5T*"1O<'1I;VYS6R=Q=6EE="==
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R96%L
M;'EQ=6EE="==*2D@>PH@("`@("`@("`@("`D8VUD("X]("<@+5$G.PH@("`@
M("`@("`@("!U;G-E="@D;W!T:6]N<ULG<F5A;&QY<75I970G72D["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<F5L96%S92==*2D@
M>PH@("`@("`@("`@("`D8W9S=F5R<VEO;B`]('!R96=?<F5P;&%C92@G+UM>
M82UZ,"TY72]I)RP@)U\G+"`D;W!T:6]N<ULG<F5L96%S92==*3L*("`@("`@
M("`@("`@)&-V<W1A9R`](")214Q%05-%7R1C=G-V97)S:6]N(CL*("`@("`@
M("`@("`@)&]P=&EO;G-;)W)E=FES:6]N)UT@/2`D8W9S=&%G.PH@("`@("`@
M("`@("!U;G-E="@D;W!T:6]N<ULG<F5L96%S92==*3L*("`@("`@("!]"B`@
M("`@("`@)&5X96-U=&4@/2!T<G5E.PH@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULG9')Y+7)U;B==*2D@>PH@("`@("`@("`@("`D97AE8W5T92`](&9A
M;'-E.PH@("`@("`@("`@("!U;G-E="@D;W!T:6]N<ULG9')Y+7)U;B==*3L*
M("`@("`@("!]"B`@("`@("`@)&-M9"`N/2`G(&1I9F8G.PH@("`@("`@("\O
M('1H92!R97-T(&]F('1H92!O<'1I;VYS(&%R92!P87-S960@<FEG:'0@;VX@
M=&\@(F-V<R!D:69F(@H@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1O
M<'1I;VX@/3X@)&]P=&%R9RD@>PH@("`@("`@("`@("`D87)G(#T@0"1T:&ES
M+3YC;VUM86YD<ULD8V]M;6%N9%U;)V]P=&EO;G,G75LD;W!T:6]N75LG87)G
M)UT["B`@("`@("`@("`@("1S:&]R="`]($`D=&AI<RT^8V]M;6%N9'-;)&-O
M;6UA;F1=6R=O<'1I;VYS)UU;)&]P=&EO;EU;)W-H;W)T;W!T)UT["B`@("`@
M("`@("`@("1C;60@+CT@)'-H;W)T(#\@(B`M)'-H;W)T(B`Z("(@+2TD;W!T
M:6]N(CL*("`@("`@("`@("`@:68@*"1A<F<@)B8@)&]P=&%R9RD@>PH@("`@
M("`@("`@("`@("`@)&-M9"`N/2`H)'-H;W)T(#\@)R<@.B`G/2<I("X@97-C
M87!E<VAE;&QA<F<H)&]P=&%R9RD["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE*2!["B`@("`@("`@
M("`@("1C;60@+CT@)R`G("X@97-C87!E<VAE;&QA<F<H)&9I;&4I.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E
M)RD@/B`Q*2!["B`@("`@("`@("`@("1T:&ES+3YO=71P=70@+CT@(BL@)&-M
M9%QN(CL*("`@("`@("!]"B`@("`@("`@:68@*"1E>&5C=71E*2!["B`@("`@
M("`@("`@("1F<"`]('!O<&5N*"1C;60L(")R(BD["B`@("`@("`@("`@('=H
M:6QE("@D;&EN92`](&9G971S*"1F<"P@,3`R-"DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YO=71P=70@+CT@<G1R:6TH)&QI;F4I+B)<;B(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<&-L;W-E*"1F<"D["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D
M8V]M;6%N9"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9&]2=6Y497-T<R@I"@H@("`@9G5N8W1I;VX@9&]2
M=6Y497-T<R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("!["B`@
M("`@("`@)&-W9"`](&=E=&-W9"@I.PH@("`@("`@("1P:'`@/2`D=&AI<RT^
M8V]N9FEG+3YG970H)W!H<%]B:6XG*3L*("`@("`@("!P=71E;G8H(E1%4U1?
M4$A07T5814-55$%"3$4])'!H<"(I.PH@("`@("`@("\O(&%L;"!C;W)E(%!%
M05(@=&5S=',@=7-E('1H:7,@8V]N<W1A;G0@=&\@9&5T97)M:6YE('=H971H
M97(@=&AE>2!S:&]U;&0@8F4@<G5N(&]R(&YO=`H@("`@("`@('!U=&5N=B@B
M4$A07U!%05)?4E5.5$535%,],2(I.PH@("`@("`@("1I<"`](&EN:5]G970H
M(FEN8VQU9&5?<&%T:"(I.PH@("`@("`@("1P<R`]($]37U=)3D1/5U,@/R`G
M.R<@.B`G.B<["B`@("`@("`@)')U;E]T97-T<R`]("1R='-T<R`]("1T:&ES
M+3YC;VYF:6<M/F=E="@G<&AP7V1I<B<I("X@1$E214-43U)97U-%4$%2051/
M4B`N("=R=6XM=&5S=',N<&AP)SL*("`@("`@("!I9B`H(69I;&5?97AI<W1S
M*"1R=6Y?=&5S=',I*2!["B`@("`@("`@("`@("1R=6Y?=&5S=',@/2!014%2
M7TE.4U1!3$Q?1$E2("X@1$E214-43U)97U-%4$%2051/4B`N("=R=6XM=&5S
M=',N<&AP)SL*("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D<G5N7W1E
M<W1S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*").;R!R=6XM=&5S=',N<&AP(&9I;&4@9F]U;F0N(%!L96%S92!C;W!Y
M('1H:7,@(BX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(F9I;&4@9G)O;2!T:&4@<V]U<F-E<R!O9B!Y;W5R(%!(
M4"!D:7-T<FEB=71I;VX@=&\@)')T<W1S(BD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@:68@*$]37U=)3D1/5U,I('L*("`@("`@("`@("`@
M+R\@;F]T92P@=&AI<R!R97%U:7)E<R!A('-L:6=H=&QY(&UO9&EF:65D('9E
M<G-I;VX@;V8@<G5N+71E<W1S+G!H<`H@("`@("`@("`@("`O+R!F;W(@<V]M
M92!S971U<',*("`@("`@("`@("`@+R\@=6YO9F9I8VEA;"!D;W=N;&]A9"!L
M;V-A=&EO;B!I<R!I;B!T:&4@<&5A<BUD978@87)C:&EV97,*("`@("`@("`@
M("`@)&%R9W8@/2`D<&%R86US.PH@("`@("`@("`@("!A<G)A>5]U;G-H:69T
M*"1A<F=V+"`D<G5N7W1E<W1S*3L*("`@("`@("`@("`@)&%R9V,@/2!C;W5N
M="@D87)G=BD["B`@("`@("`@("`@(&EN8VQU9&4@)')U;E]T97-T<SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&QI<W0@/2!I;7!L;V1E*"<@
M)RP@)'!A<F%M<RD["B`@("`@("`@("`@("1C;60@/2`B)'!H<"`M9"!I;F-L
M=61E7W!A=&@])&-W9"1P<R1I<"`M9B`D<G5N7W1E<W1S("TM("1P;&ES="([
M"B`@("`@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&]0
M86-K86=E1&5P96YD96YC:65S*"D*"B`@("!F=6YC=&EO;B!D;U!A8VMA9V5$
M97!E;F1E;F-I97,H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0H@("`@
M>PH@("`@("`@("\O("1P87)A;7-;,%T@+3X@=&AE(%!%05(@<&%C:V%G92!T
M;R!L:7-T(&ET<R!I;F9O<FUA=&EO;@H@("`@("`@(&EF("AS:7IE;V8H)'!A
M<F%M<RD@(3T@,2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(F)A9"!P87)A;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<
M(B(I.PH@("`@("`@('T*"B`@("`@("`@)&]B:B`](&YE=R!014%27T-O;6UO
M;B@I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O(#T@)&]B:BT^
M:6YF;T9R;VU!;GDH)'!A<F%M<ULP72DI*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-?87)R87DH)&EN9F];)W)E;&5A<V5?9&5P<R==*2D@>PH@("`@
M("`@("`@("`D9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)V-A<'1I
M;VXG(#T^("=$97!E;F1E;F-I97,@9F]R("<@+B`D:6YF;ULG<&%C:V%G92==
M+`H@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P*("`@("`@("`@
M("`@("`@("=H96%D;&EN92<@/3X@87)R87DH(E1Y<&4B+"`B3F%M92(L(")2
M96QA=&EO;B(L(")697)S:6]N(BDL"B`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("`@("`@9F]R96%C:"`H)&EN9F];)W)E;&5A<V5?9&5P<R==(&%S("1D
M*2!["@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?9&5P<U]R
M96Q?=')A;G-;)&1;)W)E;"==72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<F5L(#T@)'1H:7,M/E]D97!S7W)E;%]T<F%N<ULD9%LG<F5L)UU=.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5L
M(#T@)&1;)W)E;"==.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP
M92==72DI('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]('5C9FER<W0H
M)'1H:7,M/E]D97!S7W1Y<&5?=')A;G-;)&1;)W1Y<&4G75TI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]
M("1D6R=T>7!E)UT["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2`D9%LG;F%M92==.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D;F%M92`]("<G.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9%LG=F5R<VEO
M;B==*2D@>PH@("`@("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)&1;)W9E
M<G-I;VXG73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)'9E<G-I;VX@/2`G)SL*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D='EP92P@
M)&YA;64L("1R96PL("1V97)S:6]N*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M+R\@1F%L;&)A8VL*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(E1H
M:7,@<&%C:V%G92!D;V5S(&YO="!H879E(&%N>2!D97!E;F1E;F-I97,N(BP@
M)&-O;6UA;F0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1O4VEG
M;B@I"@H@("`@9G5N8W1I;VX@9&]3:6=N*"1C;VUM86YD+"`D;W!T:6]N<RP@
M)'!A<F%M<RD*("`@('L*("`@("`@("`O+R!S:&]U;&0@;6]V92!M;W-T(&]F
M('1H:7,@8V]D92!I;G1O(%!%05)?4&%C:V%G97(*("`@("`@("`O+R!S;R!I
M="=L;"!B92!E87-Y('1O(&EM<&QE;65N="`B<&5A<B!P86-K86=E("TM<VEG
M;B(*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")B860@<&%R86UE=&5R
M*',I+"!T<GD@7")H96QP("1C;VUM86YD7"(B*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D<&%R86US6S!=*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@9&]E<R!N;W0@97AI
M<W0Z("1P87)A;7-;,%TB*3L*("`@("`@("!]"B`@("`@("`@)&]B:B`](&YE
M=R!014%27T-O;6UO;CL*("`@("`@("`D:6YF;R`]("1O8FHM/FEN9F]&<F]M
M5&=Z1FEL92@D<&%R86US6S!=*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D:6YF;RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"1I;F9O*3L*("`@("`@("!]"B`@("`@("`@:6YC;'5D95]O;F-E(")!
M<F-H:79E+U1A<BYP:'`B.PH@("`@("`@(&EN8VQU9&5?;VYC92`B4WES=&5M
M+G!H<"(["B`@("`@("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D<&%R86US
M6S!=*3L*("`@("`@("`D=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H)RUD('!E
M87)S:6=N)RD["B`@("`@("`@:68@*"$D=&%R+3YE>'1R86-T3&ES="@G<&%C
M:V%G92YX;6P@<&%C:V%G92YS:6<G+"`D=&UP9&ER*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!E>'1R86-T
M('1A<B!F:6QE(BD["B`@("`@("`@?0H@("`@("`@(&EF("AF:6QE7V5X:7-T
M<R@B)'1M<&1I<B]P86-K86=E+G-I9R(I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B<&%C:V%G92!A;')E861Y('-I9VYE9"(I
M.PH@("`@("`@('T*("`@("`@("!`=6YL:6YK*"(D=&UP9&ER+W!A8VMA9V4N
M<VEG(BD["B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/G5I+3YU<V5R1&EA;&]G
M*"1C;VUM86YD+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G1VYU4$<@4&%S<W!H<F%S92<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%S<W=O<F0G*2D[
M"B`@("`@("`@)&=P9R`]('!O<&5N*")G<&<@+2UB871C:"`M+7!A<W-P:')A
M<V4M9F0@,"`M+6%R;6]R("TM9&5T86-H+7-I9VX@+2UO=71P=70@)'1M<&1I
M<B]P86-K86=E+G-I9R`D=&UP9&ER+W!A8VMA9V4N>&UL(#(^+V1E=B]N=6QL
M(BP@(G<B*3L*("`@("`@("!I9B`H(21G<&<I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")G<&<@8V]M;6%N9"!F86EL960B*3L*
M("`@("`@("!]"B`@("`@("`@9G=R:71E*"1G<&<L("(D:6YP=71;,%U<<B(I
M.PH@("`@("`@(&EF("AP8VQO<V4H)&=P9RD@?'P@(69I;&5?97AI<W1S*"(D
M=&UP9&ER+W!A8VMA9V4N<VEG(BDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")G<&<@<VEG;B!F86EL960B*3L*("`@("`@("!]
M"B`@("`@("`@)'1A<BT^861D36]D:69Y*"(D=&UP9&ER+W!A8VMA9V4N<VEG
M(BP@)R<L("1T;7!D:7(I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&1O36%K95)032@I"@H@("`@+RH*"B`@
M("`H8V]X*0H*("`@(%1/1$\Z"@H@("`@("`@("T@1FEL;"!T:&4@<G!M(&1E
M<&5N9&5N8VEE<R!I;B!T:&4@=&5M<&QA=&4@9FEL92X*"B`@("!)1$5!4SH*
M"B`@("`@("`@+2!);G-T96%D(&]F(&UA<'!I;F<@=&AE(')O;&4@=&\@<G!M
M('9A<G,L('!E<FAA<',@:70G<R!B971T97(*"B`@("`@("`@("!T;R!U<V4@
M9&ER96-T;'D@=&AE('!E87(@8VUD('1O(&EN<W1A;&P@=&AE(&9I;&5S(&)Y
M(&ET<V5L9@H*("`@("`@("`@(&EN("5P;W-T<G5N('-O.@H*("`@("`@("`@
M('!E87(@+60@<&AP7V1I<CTE>U]L:6)D:7)]+W!H<"]P96%R("UD('1E<W1?
M9&ER/2XN(#QP86-K86=E/@H*("`@("HO"@H@("`@9G5N8W1I;VX@9&]-86ME
M4E!-*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD*("`@('L*("`@("`@
M("!I9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")B860@<&%R86UE=&5R*',I+"!T<GD@
M7")H96QP("1C;VUM86YD7"(B*3L*("`@("`@("!]"B`@("`@("`@:68@*"%F
M:6QE7V5X:7-T<R@D<&%R86US6S!=*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@9&]E<R!N;W0@97AI<W0Z("1P87)A
M;7-;,%TB*3L*("`@("`@("!]"B`@("`@("`@:6YC;'5D95]O;F-E(")!<F-H
M:79E+U1A<BYP:'`B.PH@("`@("`@(&EN8VQU9&5?;VYC92`B4$5!4B]);G-T
M86QL97(N<&AP(CL*("`@("`@("!I;F-L=61E7V]N8V4@(E-Y<W1E;2YP:'`B
M.PH@("`@("`@("1T87(@/2!N97<@07)C:&EV95]487(H)'!A<F%M<ULP72D[
M"B`@("`@("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP*"<M9"!P96%R,G)P
M;2<I.PH@("`@("`@("1I;G-T<F]O="`](%-Y<W1E;3HZ;6MT96UP*"<M9"!P
M96%R,G)P;2<I.PH@("`@("`@("1T;7`@/2`D=&AI<RT^8V]N9FEG+3YG970H
M)W9E<F)O<V4G*3L*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)W9E<F)O
M<V4G+"`P*3L*("`@("`@("`D:6YS=&%L;&5R(#T@;F5W(%!%05)?26YS=&%L
M;&5R*"1T:&ES+3YU:2D["B`@("`@("`@)&EN9F\@/2`D:6YS=&%L;&5R+3YI
M;G-T86QL*"1P87)A;7-;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=I;G-T86QL<F]O="<@/3X@)&EN<W1R;V]T+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]D
M97!S)R`]/B!T<G5E*2D["B`@("`@("`@)'!K9V1I<B`]("(D:6YF;UMP86-K
M86=E72TD:6YF;UMV97)S:6]N72(["B`@("`@("`@)&EN9F];)W)P;5]X;6Q?
M9&ER)UT@/2`G+W9A<B]L:6(O<&5A<B<["B`@("`@("`@)'1H:7,M/F-O;F9I
M9RT^<V5T*"=V97)B;W-E)RP@)'1M<"D["B`@("`@("`@:68@*"$D=&%R+3YE
M>'1R86-T3&ES="@B<&%C:V%G92YX;6PB+"`D=&UP9&ER+"`D<&MG9&ER*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE
M9"!T;R!E>'1R86-T("1P87)A;7-;,%TB*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@B)'1M<&1I<B]P86-K86=E+GAM;"(I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B;F\@<&%C:V%G
M92YX;6P@9F]U;F0@:6X@)'!A<F%M<ULP72(I.PH@("`@("`@('T*("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;G-;)W-P96,M=&5M<&QA=&4G72DI('L*("`@
M("`@("`@("`@)'-P96-?=&5M<&QA=&4@/2`D;W!T:6]N<ULG<W!E8RUT96UP
M;&%T92==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S<&5C7W1E
M;7!L871E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D871A7V1I<B<I("X*("`@
M("`@("`@("`@("`@("<O4$5!4B]T96UP;&%T92YS<&5C)SL*("`@("`@("!]
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R<&TM<&MG;F%M92==*2D@
M>PH@("`@("`@("`@("`D<G!M7W!K9VYA;65?9F]R;6%T(#T@)&]P=&EO;G-;
M)W)P;2UP:V=N86UE)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)')P;5]P:V=N86UE7V9O<FUA="`](")014%2.CHE<R(["B`@("`@("`@?0H*
M("`@("`@("`D:6YF;ULG97AT<F%?:&5A9&5R<R==(#T@)R<["B`@("`@("`@
M)&EN9F];)V1O8U]F:6QE<R==(#T@)R<["B`@("`@("`@)&EN9F];)V9I;&5S
M)UT@/2`G)SL*("`@("`@("`D:6YF;ULG<G!M7W!A8VMA9V4G72`]('-P<FEN
M=&8H)')P;5]P:V=N86UE7V9O<FUA="P@)&EN9F];)W!A8VMA9V4G72D["B`@
M("`@("`@)'-R8V9I;&5S(#T@,#L*("`@("`@("!F;W)E86-H("@D:6YF;ULG
M9FEL96QI<W0G72!A<R`D;F%M92`]/B`D871T<BD@>PH*("`@("`@("`@("`@
M:68@*"1A='1R6R=R;VQE)UT@/3T@)V1O8R<I('L*("`@("`@("`@("`@("`@
M("1I;F9O6R=D;V-?9FEL97,G72`N/2`B("1N86UE(CL*"B`@("`@("`@("`@
M("\O($UA<"!R;VQE('1O('1H92!R<&T@=F%R<PH@("`@("`@("`@("!](&5L
M<V4@>PH*("`@("`@("`@("`@("`@("1C7W!R969I>"`]("<E>U]L:6)D:7)]
M+W!H<"]P96%R)SL*"B`@("`@("`@("`@("`@("!S=VET8V@@*"1A='1R6R=R
M;VQE)UTI('L*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<&AP)SH*"B`@
M("`@("`@("`@("`@("`@("`@("`@("1P<F5F:7@@/2`D8U]P<F5F:7@[(&)R
M96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=E>'0G.@H*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!R969I>"`]("<E>U]L:6)D:7)]+W!H<"<[
M(&)R96%K.R`O+R!86%@@9V]O9"!P;&%C93\*"B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G<W)C)SH*"B`@("`@("`@("`@("`@("`@("`@("`@("1S<F-F
M:6QE<RLK.PH*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]("<E
M>U]I;F-L=61E9&ER?2]P:'`G.R!B<F5A:SL@+R\@6%A8(&=O;V0@<&QA8V4_
M"@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W1E<W0G.@H*("`@("`@("`@
M("`@("`@("`@("`@("`@)'!R969I>"`]("(D8U]P<F5F:7@O=&5S=',O(B`N
M("1I;F9O6R=P86-K86=E)UT[(&)R96%K.PH*("`@("`@("`@("`@("`@("`@
M("!C87-E("=D871A)SH*"B`@("`@("`@("`@("`@("`@("`@("`@("1P<F5F
M:7@@/2`B)&-?<')E9FEX+V1A=&$O(B`N("1I;F9O6R=P86-K86=E)UT[(&)R
M96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=S8W)I<'0G.@H*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]("<E>U]B:6YD:7)])SL@
M8G)E86L["@H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1I
M;F9O6R=F:6QE<R==("X]("(D<')E9FEX+R1N86UE7&XB.PH*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'-R8V9I;&5S(#X@,"D@>PH@
M("`@("`@("`@("!I;F-L=61E7V]N8V4@(D]3+T=U97-S+G!H<"(["B`@("`@
M("`@("`@("1O<R`](&YE=R!/4U]'=65S<SL*("`@("`@("`@("`@)&%R8V@@
M/2`D;W,M/F=E=$-P=2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1A<F-H(#T@)VYO87)C:"<["B`@("`@("`@?0H@("`@("`@("1C9F<@/2!A
M<G)A>2@G;6%S=&5R7W-E<G9E<B<L("=P:'!?9&ER)RP@)V5X=%]D:7(G+"`G
M9&]C7V1I<B<L"B`@("`@("`@("`@("`@("`@("`@("=B:6Y?9&ER)RP@)V1A
M=&%?9&ER)RP@)W1E<W1?9&ER)RD["B`@("`@("`@9F]R96%C:"`H)&-F9R!A
M<R`D:RD@>PH@("`@("`@("`@("`D:6YF;ULD:UT@/2`D=&AI<RT^8V]N9FEG
M+3YG970H)&LI.PH@("`@("`@('T*("`@("`@("`D:6YF;ULG87)C:"==(#T@
M)&%R8V@["B`@("`@("`@)&9P(#T@0&9O<&5N*"1S<&5C7W1E;7!L871E+"`B
M<B(I.PH@("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&]P96X@4E!-('-P96,@9FEL
M92!T96UP;&%T92`D<W!E8U]T96UP;&%T93H@)'!H<%]E<G)O<FUS9R(I.PH@
M("`@("`@('T*("`@("`@("`D<W!E8U]C;VYT96YT<R`]('!R96=?<F5P;&%C
M92@G+T`H6V$M>C`M.5\M72LI0"]E)RP@)R1I;F9O6R)<,2)=)RP@9G)E860H
M)&9P+"!F:6QE<VEZ92@D<W!E8U]T96UP;&%T92DI*3L*("`@("`@("!F8VQO
M<V4H)&9P*3L*("`@("`@("`D<W!E8U]F:6QE(#T@(B1I;F9O6W)P;5]P86-K
M86=E72TD:6YF;UMV97)S:6]N72YS<&5C(CL*("`@("`@("`D=W`@/2!F;W!E
M;B@D<W!E8U]F:6QE+"`B=V(B*3L*("`@("`@("!I9B`H(21W<"D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!W
M<FET92!24$T@<W!E8R!F:6QE("1S<&5C7V9I;&4Z("1P:'!?97)R;W)M<V<B
M*3L*("`@("`@("!]"B`@("`@("`@9G=R:71E*"1W<"P@)'-P96-?8V]N=&5N
M=',I.PH@("`@("`@(&9C;&]S92@D=W`I.PH@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@B5W)O=&4@4E!-('-P96,@9FEL92`D<W!E8U]F:6QE(BP@
M)&-O;6UA;F0I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M+R!]?7T*?0H*/SX*````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+T%U=&@N<&AP````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3$U,S$`,3`T,3<S-C,P,#8`,#(Q,#8P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\O"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N
M(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG('5R;#H@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<CH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@075T:"YP:'`L=B`Q+C$U(#(P,#0O
M,#$O,#@@,3<Z,S,Z,3,@<VYI<&5R($5X<"`D"@IR97%U:7)E7V]N8V4@(E!%
M05(O0V]M;6%N9"]#;VUM;VXN<&AP(CL*<F5Q=6ER95]O;F-E(")014%2+U)E
M;6]T92YP:'`B.PIR97%U:7)E7V]N8V4@(E!%05(O0V]N9FEG+G!H<"(["@HO
M*BH*("H@4$5!4B!C;VUM86YD<R!F;W(@;6%N86=I;F<@8V]N9FEG=7)A=&EO
M;B!D871A+@H@*@H@*B\*8VQA<W,@4$5!4E]#;VUM86YD7T%U=&@@97AT96YD
M<R!014%27T-O;6UA;F1?0V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S
M"@H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`H@("`@("`@("=L;V=I;B<@
M/3X@87)R87DH"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0V]N;F5C=',@
M86YD(&%U=&AE;G1I8V%T97,@=&\@<F5M;W1E('-E<G9E<B<L"B`@("`@("`@
M("`@("=S:&]R=&-U="<@/3X@)VQI)RP*("`@("`@("`@("`@)V9U;F-T:6]N
M)R`]/B`G9&],;V=I;B<L"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A
M>2@I+`H@("`@("`@("`@("`G9&]C)R`]/B`G"DQO9R!I;B!T;R!T:&4@<F5M
M;W1E('-E<G9E<BX@(%1O('5S92!R96UO=&4@9G5N8W1I;VYS(&EN('1H92!I
M;G-T86QL97(*=&AA="!R97%U:7)E(&%N>2!K:6YD(&]F('!R:79I;&5G97,L
M('EO=2!N965D('1O(&QO9R!I;B!F:7)S="X@(%1H90IU<V5R;F%M92!A;F0@
M<&%S<W=O<F0@>6]U(&5N=&5R(&AE<F4@=VEL;"!B92!S=&]R960@:6X@>6]U
M<B!P97(M=7-E<@I014%2(&-O;F9I9W5R871I;VX@*'XO+G!E87)R8R!O;B!5
M;FEX+6QI:V4@<WES=&5M<RDN("!!9G1E<B!L;V=G:6YG"FEN+"!Y;W5R('5S
M97)N86UE(&%N9"!P87-S=V]R9"!W:6QL(&)E('-E;G0@86QO;F<@:6X@<W5B
M<V5Q=65N=`IO<&5R871I;VYS(&]N('1H92!R96UO=&4@<V5R=F5R+B<L"B`@
M("`@("`@("`@("DL"B`@("`@("`@)VQO9V]U="<@/3X@87)R87DH"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`G3&]G<R!O=70@9G)O;2!T:&4@<F5M;W1E
M('-E<G9E<B<L"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)VQO)RP*("`@
M("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&],;V=O=70G+`H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH*2P*("`@("`@("`@("`@)V1O8R<@/3X@
M)PI,;V=S(&]U="!F<F]M('1H92!R96UO=&4@<V5R=F5R+B`@5&AI<R!C;VUM
M86YD(&1O97,@;F]T(&%C='5A;&QY"F-O;FYE8W0@=&\@=&AE(')E;6]T92!S
M97)V97(L(&ET(&]N;'D@9&5L971E<R!T:&4@<W1O<F5D('5S97)N86UE(&%N
M9`IP87-S=V]R9"!F<F]M('EO=7(@=7-E<B!C;VYF:6=U<F%T:6]N+B<L"B`@
M("`@("`@("`@("D*"B`@("`@("`@*3L*"B`@("`O+R!]?7T*"B`@("`O+R![
M>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%!%05)?0V]M;6%N9%]!
M=71H(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]!=71H*"8D=6DL
M("8D8V]N9FEG*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD
M7T-O;6UO;B@D=6DL("1C;VYF:6<I.PH@("`@?0H*("`@("\O('U]?0H*("`@
M("\O('M[>R!D;TQO9VEN*"D*"B`@("`O*BH*("`@("`J($5X96-U=&4@=&AE
M("=L;V=I;B<@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;VUM86YD(&-O;6UA;F0@;F%M90H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D;W!T:6]N<R!O<'1I;VY?;F%M92`]/B!V86QU90H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US(&QI<W0@;V8@861D:71I;VYA;"!P
M87)A;65T97)S"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@
M<W5C8V5S<RP@1D%,4T4@9F]R('5N:VYO=VX@8V]M;6%N9',L(&]R"B`@("`@
M*B!A(%!%05(@97)R;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O3&]G:6XH)&-O;6UA
M;F0L("1O<'1I;VYS+"`D<&%R86US*0H@("`@>PH@("`@("`@("1S97)V97(@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)VUA<W1E<E]S97)V97(G*3L*("`@("`@
M("`D<F5M;W1E(#T@;F5W(%!%05)?4F5M;W1E*"1T:&ES+3YC;VYF:6<I.PH@
M("`@("`@("1U<V5R;F%M92`]("1T:&ES+3YC;VYF:6<M/F=E="@G=7-E<FYA
M;64G*3L*("`@("`@("!I9B`H96UP='DH)'5S97)N86UE*2D@>PH@("`@("`@
M("`@("`D=7-E<FYA;64@/2!`)%]%3E9;)U5315(G73L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"),;V=G:6YG(&EN('1O("1S
M97)V97(N(BP@)&-O;6UA;F0I.PH@("`@("`@(`H@("`@("`@(&QI<W0H)'5S
M97)N86UE+"`D<&%S<W=O<F0I(#T@)'1H:7,M/G5I+3YU<V5R1&EA;&]G*`H@
M("`@("`@("`@("`D8V]M;6%N9"P*("`@("`@("`@("`@87)R87DH)U5S97)N
M86UE)RP@)U!A<W-W;W)D)RDL"B`@("`@("`@("`@(&%R<F%Y*"=T97AT)RP@
M("`@("=P87-S=V]R9"<I+`H@("`@("`@("`@("!A<G)A>2@D=7-E<FYA;64L
M("`G)RD*("`@("`@("`@("`@*3L*("`@("`@("`D=7-E<FYA;64@/2!T<FEM
M*"1U<V5R;F%M92D["B`@("`@("`@)'!A<W-W;W)D(#T@=')I;2@D<&%S<W=O
M<F0I.PH@("`@("`@(`H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G=7-E
M<FYA;64G+"`D=7-E<FYA;64I.PH@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E
M="@G<&%S<W=O<F0G+"`D<&%S<W=O<F0I.PH@("`@("`@(`H@("`@("`@("1R
M96UO=&4M/F5X<&5C=$5R<F]R*#0P,2D["B`@("`@("`@)&]K(#T@)')E;6]T
M92T^8V%L;"@G;&]G:6YT97-T)RD["B`@("`@("`@)')E;6]T92T^<&]P17AP
M96-T*"D["B`@("`@("`@:68@*"1O:R`]/3T@=')U92D@>PH@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(DQO9V=E9"!I;BXB+"`D8V]M;6%N
M9"D["B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-T;W)E*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"),;V=I;B!F86EL960A(BD["B`@("`@("`@?0H*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!D;TQO9V]U="@I"@H@("`@+RHJ"B`@("`@*B!%
M>&5C=71E('1H92`G;&]G;W5T)R!C;VUM86YD+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O;6UA;F0@8V]M;6%N9"!N86UE"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS(&]P=&EO;E]N86UE(#T^('9A;'5E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@;&ES="!O9B!A
M9&1I=&EO;F%L('!A<F%M971E<G,*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VP@5%)512!O;B!S=6-C97-S+"!&04Q312!F;W(@=6YK;F]W;B!C;VUM86YD
M<RP@;W(*("`@("`J(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&],
M;V=O=70H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0H@("`@>PH@("`@
M("`@("1S97)V97(@/2`D=&AI<RT^8V]N9FEG+3YG970H)VUA<W1E<E]S97)V
M97(G*3L*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(DQO9V=I;F<@
M;W5T(&9R;VT@)'-E<G9E<BXB+"`D8V]M;6%N9"D["B`@("`@("`@)'1H:7,M
M/F-O;F9I9RT^<F5M;W9E*"=U<V5R;F%M92<I.PH@("`@("`@("1T:&ES+3YC
M;VYF:6<M/G)E;6]V92@G<&%S<W=O<F0G*3L*("`@("`@("`D=&AI<RT^8V]N
M9FEG+3YS=&]R92@I.PH@("`@?0H*("`@("\O('U]?0I]"@H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O0V]M;6%N9"\C4F5M;W1E+G!H<",`````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#,S-C$V`#$P-#$W,S8S,#`V`#`R,34S,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO+R`O*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@4F5M;W1E+G!H<"QV(#$N,CD@,C`P,R\P
M,R\Q."`Q,CHP-CHP-R!S<V(@17AP("0*"G)E<75I<F5?;VYC92`G4$5!4B]#
M;VUM86YD+T-O;6UO;BYP:'`G.PIR97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N
M+G!H<"<["G)E<75I<F5?;VYC92`G4$5!4B]296UO=&4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=014%2+U)E9VES=')Y+G!H<"<["@IC;&%S<R!014%27T-O;6UA
M;F1?4F5M;W1E(&5X=&5N9',@4$5!4E]#;VUM86YD7T-O;6UO;@I["B`@("`O
M+R![>WL@8V]M;6%N9"!D969I;FET:6]N<PH*("`@('9A<B`D8V]M;6%N9',@
M/2!A<G)A>2@*("`@("`@("`G<F5M;W1E+6EN9F\G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G<W5M;6%R>2<@/3X@)TEN9F]R;6%T:6]N($%B;W5T(%)E;6]T
M92!086-K86=E<R<L"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4F5M
M;W1E26YF;R<L"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)I)RP*("`@
M("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL"B`@("`@("`@("`@("=D
M;V,G(#T^("<\<&%C:V%G93X*1V5T(&1E=&%I;',@;VX@82!P86-K86=E(&9R
M;VT@=&AE('-E<G9E<BXG+`H@("`@("`@("`@("`I+`H@("`@("`@("=L:7-T
M+75P9W)A9&5S)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^
M("=,:7-T($%V86EL86)L92!5<&=R861E<R<L"B`@("`@("`@("`@("=F=6YC
M=&EO;B<@/3X@)V1O3&ES=%5P9W)A9&5S)RP*("`@("`@("`@("`@)W-H;W)T
M8W5T)R`]/B`G;'4G+`H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH
M*2P*("`@("`@("`@("`@)V1O8R<@/3X@)PI,:7-T(')E;&5A<V5S(&]N('1H
M92!S97)V97(@;V8@<&%C:V%G97,@>6]U(&AA=F4@:6YS=&%L;&5D('=H97)E
M"F$@;F5W97(@=F5R<VEO;B!I<R!A=F%I;&%B;&4@=VET:"!T:&4@<V%M92!R
M96QE87-E('-T871E("AS=&%B;&4@971C+BDN)PH@("`@("`@("`@("`I+`H@
M("`@("`@("=R96UO=&4M;&ES="<@/3X@87)R87DH"B`@("`@("`@("`@("=S
M=6UM87)Y)R`]/B`G3&ES="!296UO=&4@4&%C:V%G97,G+`H@("`@("`@("`@
M("`G9G5N8W1I;VXG(#T^("=D;U)E;6]T94QI<W0G+`H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=R;"<L"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A
M<G)A>2@I+`H@("`@("`@("`@("`G9&]C)R`]/B`G"DQI<W1S('1H92!P86-K
M86=E<R!A=F%I;&%B;&4@;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L;VYG
M('=I=&@@=&AE"FQA=&5S="!S=&%B;&4@<F5L96%S92!O9B!E86-H('!A8VMA
M9V4N)RP*("`@("`@("`@("`@*2P*("`@("`@("`G<V5A<F-H)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=396%R8V@@<F5M;W1E('!A
M8VMA9V4@9&%T86)A<V4G+`H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;U-E87)C:"<L"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W-P)RP*("`@
M("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL"B`@("`@("`@("`@("=D
M;V,G(#T^("<*3&ES=',@86QL('!A8VMA9V5S('=H:6-H(&UA=&-H('1H92!S
M96%R8V@@<&%R86UE=&5R<R`H9FER<W0@<&%R86T*:7,@<&%C:V%G92!N86UE
M+"!S96-O;F0@<&%C:V%G92!I;F9O*2<L"B`@("`@("`@("`@("DL"B`@("`@
M("`@)VQI<W0M86QL)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W-U;6UA<GDG
M(#T^("=,:7-T($%L;"!086-K86=E<R<L"B`@("`@("`@("`@("=F=6YC=&EO
M;B<@/3X@)V1O3&ES=$%L;"<L"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@
M)VQA)RP*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL"B`@("`@
M("`@("`@("=D;V,G(#T^("<*3&ES=',@=&AE('!A8VMA9V5S(&%V86EL86)L
M92!O;B!T:&4@8V]N9FEG=7)E9"!S97)V97(@86QO;F<@=VET:"!T:&4*;&%T
M97-T('-T86)L92!R96QE87-E(&]F(&5A8V@@<&%C:V%G92XG+`H@("`@("`@
M("`@("`I+`H@("`@("`@("=D;W=N;&]A9"<@/3X@87)R87DH"B`@("`@("`@
M("`@("=S=6UM87)Y)R`]/B`G1&]W;FQO860@4&%C:V%G92<L"B`@("`@("`@
M("`@("=F=6YC=&EO;B<@/3X@)V1O1&]W;FQO860G+`H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=D)RP*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@)VYO8V]M<')E<W,G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)UHG+`H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=D;W=N;&]A9"!A;B!U;F-O;7!R97-S
M960@*"YT87(I(&9I;&4G+`H@("`@("`@("`@("`@("`@("`@("DL"B`@("`@
M("`@("`@("`@("`I+`H@("`@("`@("`@("`G9&]C)R`]/B`G>W!A8VMA9V5\
M<&%C:V%G92UV97)S:6]N?0I$;W=N;&]A9"!A('!A8VMA9V4@=&%R8F%L;"X@
M(%1H92!F:6QE('=I;&P@8F4@;F%M960@87,@<W5G9V5S=&5D(&)Y('1H90IS
M97)V97(L(&9O<B!E>&%M<&QE(&EF('EO=2!D;W=N;&]A9"!T:&4@1$(@<&%C
M:V%G92!A;F0@=&AE(&QA=&5S="!S=&%B;&4*=F5R<VEO;B!O9B!$0B!I<R`Q
M+C(L('1H92!D;W=N;&]A9&5D(&9I;&4@=VEL;"!B92!$0BTQ+C(N=&=Z+B<L
M"B`@("`@("`@("`@("DL"B`@("`@("`@)V-L96%R+6-A8VAE)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=#;&5A<B!834PM4E!#($-A
M8VAE)RP*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]#;&5A<D-A8VAE
M)RP*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8V,G+`H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH*2P*("`@("`@("`@("`@)V1O8R<@/3X@
M)PI#;&5A<B!T:&4@6$U,+5)00R!C86-H92X@(%-E92!A;'-O('1H92!C86-H
M95]T=&P@8V]N9FEG=7)A=&EO;@IP87)A;65T97(N"B<L"B`@("`@("`@("`@
M("DL"B`@("`@("`@*3L*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U
M8W1O<@H*("`@("\J*@H@("`@("H@4$5!4E]#;VUM86YD7U)E;6]T92!C;VYS
M=')U8W1O<BX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?4F5M;W1E*"8D=6DL("8D8V]N
M9FEG*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO
M;B@D=6DL("1C;VYF:6<I.PH@("`@?0H*("`@("\O('U]?0H*("`@("\O('M[
M>R!D;U)E;6]T94EN9F\H*0H*("`@(&9U;F-T:6]N(&1O4F5M;W1E26YF;R@D
M8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@:68@
M*'-I>F5O9B@D<&%R86US*2`A/2`Q*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0@97AP96-T<R!O;F4@<&%R86TZ
M('1H92!R96UO=&4@<&%C:V%G92!N86UE(BD["B`@("`@("`@?0H@("`@("`@
M("1R(#T@;F5W(%!%05)?4F5M;W1E*"1T:&ES+3YC;VYF:6<I.PH@("`@("`@
M("1I;F9O(#T@)'(M/F-A;&PH)W!A8VMA9V4N:6YF;R<L("1P87)A;7-;,%TI
M.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PH@("`@("`@
M('T*"B`@("`@("`@)')E9R`](&YE=R!014%27U)E9VES=')Y*"1T:&ES+3YC
M;VYF:6<M/F=E="@G<&AP7V1I<B<I*3L*("`@("`@("`D:6YS=&%L;&5D(#T@
M)')E9RT^<&%C:V%G94EN9F\H)&EN9F];)VYA;64G72D["B`@("`@("`@)&EN
M9F];)VEN<W1A;&QE9"==(#T@)&EN<W1A;&QE9%LG=F5R<VEO;B==(#\@)&EN
M<W1A;&QE9%LG=F5R<VEO;B==(#H@)RT@;F\@+2<["@H@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D:6YF;RP@)&-O;6UA;F0I.PH*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D;U)E
M;6]T94QI<W0H*0H*("`@(&9U;F-T:6]N(&1O4F5M;W1E3&ES="@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@)'(@/2!N97<@
M4$5!4E]296UO=&4H)'1H:7,M/F-O;F9I9RD["B`@("`@("`@)&QI<W1?;W!T
M:6]N<R`](&9A;'-E.PH@("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H
M)W!R969E<G)E9%]S=&%T92<I(#T]("=S=&%B;&4G*0H@("`@("`@("`@("`D
M;&ES=%]O<'1I;VYS(#T@=')U93L*("`@("`@("`D879A:6QA8FQE(#T@)'(M
M/F-A;&PH)W!A8VMA9V4N;&ES=$%L;"<L("1L:7-T7V]P=&EO;G,I.PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1A=F%I;&%B;&4I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D879A:6QA8FQE*3L*("`@
M("`@("!]"B`@("`@("`@)&D@/2`D:B`](#`["B`@("`@("`@)&1A=&$@/2!A
M<G)A>2@*("`@("`@("`@("`@)V-A<'1I;VXG(#T^("=!=F%I;&%B;&4@<&%C
M:V%G97,Z)RP*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P*("`@("`@
M("`@("`@)VAE861L:6YE)R`]/B!A<G)A>2@G4&%C:V%G92<L("=697)S:6]N
M)RDL"B`@("`@("`@("`@("D["B`@("`@("`@9F]R96%C:"`H)&%V86EL86)L
M92!A<R`D;F%M92`]/B`D:6YF;RD@>PH@("`@("`@("`@("`D9&%T85LG9&%T
M82==6UT@/2!A<G)A>2@D;F%M92P@:7-S970H)&EN9F];)W-T86)L92==*2`_
M("1I;F9O6R=S=&%B;&4G72`Z("<M;B]A+2<I.PH@("`@("`@('T*("`@("`@
M("!I9B`H8V]U;G0H)&%V86EL86)L92D]/3`I('L*("`@("`@("`@("`@)&1A
M=&$@/2`G*&YO('!A8VMA9V5S(&EN<W1A;&QE9"!Y970I)SL*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N
M9"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9&],:7-T06QL*"D*"B`@("!F=6YC=&EO;B!D;TQI<W1!;&PH
M)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0H@("`@>PH@("`@("`@("1R
M(#T@;F5W(%!%05)?4F5M;W1E*"1T:&ES+3YC;VYF:6<I.PH@("`@("`@("1R
M96<@/2!N97<@4$5!4E]296=I<W1R>2@D=&AI<RT^8V]N9FEG+3YG970H)W!H
M<%]D:7(G*2D["B`@("`@("`@)&QI<W1?;W!T:6]N<R`](&9A;'-E.PH@("`@
M("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I
M(#T]("=S=&%B;&4G*0H@("`@("`@("`@("`D;&ES=%]O<'1I;VYS(#T@=')U
M93L*("`@("`@("`D879A:6QA8FQE(#T@)'(M/F-A;&PH)W!A8VMA9V4N;&ES
M=$%L;"<L("1L:7-T7V]P=&EO;G,I.PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1A=F%I;&%B;&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D879A:6QA8FQE*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D879A:6QA8FQE*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)U1H92!P86-K86=E(&QI<W0@8V]U;&0@;F]T
M(&)E(&9E=&-H960@9G)O;2!T:&4@<F5M;W1E('-E<G9E<BX@4&QE87-E('1R
M>2!A9V%I;BX@*$1E8G5G(&EN9F\Z("(G+B1A=F%I;&%B;&4N)R(I)RD["B`@
M("`@("`@?0H@("`@("`@("1D871A(#T@87)R87DH"B`@("`@("`@("`@("=C
M87!T:6]N)R`]/B`G06QL('!A8VMA9V5S.B<L"B`@("`@("`@("`@("=B;W)D
M97(G(#T^('1R=64L"B`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH
M)U!A8VMA9V4G+"`G3&%T97-T)RP@)TQO8V%L)RDL"B`@("`@("`@("`@("D[
M"@H@("`@("`@(&9O<F5A8V@@*"1A=F%I;&%B;&4@87,@)&YA;64@/3X@)&EN
M9F\I('L*("`@("`@("`@("`@)&EN<W1A;&QE9"`]("1R96<M/G!A8VMA9V5)
M;F9O*"1N86UE*3L*("`@("`@("`@("`@)&1E<V,@/2`D:6YF;ULG<W5M;6%R
M>2==.PH@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULD;F%M95TI*0H@
M("`@("`@("`@("`@("`@)&1E<V,@+CT@(EQN7&XB+B1I;F9O6R=D97-C<FEP
M=&EO;B==.PH*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=M;V1E
M)UTI*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!I9B`H)&]P=&EO
M;G-;)VUO9&4G72`]/2`G:6YS=&%L;&5D)R`F)B`A:7-S970H)&EN<W1A;&QE
M9%LG=F5R<VEO;B==*2D*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@("`@(&EF("@D;W!T:6]N<ULG;6]D92==(#T]("=N;W1I
M;G-T86QL960G("8F(&ES<V5T*"1I;G-T86QL961;)W9E<G-I;VXG72DI"B`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!I
M9B`H)&]P=&EO;G-;)VUO9&4G72`]/2`G=7!G<F%D97,G"B`@("`@("`@("`@
M("`@("`@("`@)B8@*"%I<W-E="@D:6YS=&%L;&5D6R=V97)S:6]N)UTI('Q\
M("1I;G-T86QL961;)W9E<G-I;VXG72`]/2`D:6YF;ULG<W1A8FQE)UTI*0H@
M("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@?3L*("`@("`@("`@("`@?3L*"B`@("`@("`@
M("`@("1D871A6R=D871A)UU;)&EN9F];)V-A=&5G;W)Y)UU=6UT@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("1N86UE+`H@("`@("`@("`@("`@("`@0"1I
M;F9O6R=S=&%B;&4G72P*("`@("`@("`@("`@("`@($`D:6YS=&%L;&5D6R=V
M97)S:6]N)UTL"B`@("`@("`@("`@("`@("!`)&1E<V,L"B`@("`@("`@("`@
M("`@("!`)&EN9F];)V1E<',G72P*("`@("`@("`@("`@("`@("D["B`@("`@
M("`@?0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O
M;6UA;F0I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&1O4V5A<F-H*"D*"B`@("!F=6YC=&EO;B!D;U-E87)C
M:"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@
M:68@*"@A:7-S970H)'!A<F%M<ULP72D@?'P@96UP='DH)'!A<F%M<ULP72DI
M"B`@("`@("`@("`@("8F("@A:7-S970H)'!A<F%M<ULQ72D@?'P@96UP='DH
M)'!A<F%M<ULQ72DI*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=N;R!V86QI9"!S96%R8V@@<W1R:6YG('-U<'!L
M:65D)RD["B`@("`@("`@?3L*"B`@("`@("`@)'(@/2!N97<@4$5!4E]296UO
M=&4H)'1H:7,M/F-O;F9I9RD["B`@("`@("`@)')E9R`](&YE=R!014%27U)E
M9VES=')Y*"1T:&ES+3YC;VYF:6<M/F=E="@G<&AP7V1I<B<I*3L*("`@("`@
M("`D879A:6QA8FQE(#T@)'(M/F-A;&PH)W!A8VMA9V4N;&ES=$%L;"<L('1R
M=64I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1A=F%I;&%B;&4I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D879A:6QA
M8FQE*3L*("`@("`@("!]"B`@("`@("`@)&1A=&$@/2!A<G)A>2@*("`@("`@
M("`@("`@)V-A<'1I;VXG(#T^("=-871C:&5D('!A8VMA9V5S.B<L"B`@("`@
M("`@("`@("=B;W)D97(G(#T^('1R=64L"B`@("`@("`@("`@("=H96%D;&EN
M92<@/3X@87)R87DH)U!A8VMA9V4G+"`G3&%T97-T)RP@)TQO8V%L)RDL"B`@
M("`@("`@("`@("D["@H@("`@("`@(&9O<F5A8V@@*"1A=F%I;&%B;&4@87,@
M)&YA;64@/3X@)&EN9F\I('L*("`@("`@("`@("`@)&9O=6YD(#T@*"%E;7!T
M>2@D<&%R86US6S!=*2`F)B!S=')I<W1R*"1N86UE+"`D<&%R86US6S!=*2`A
M/3T@9F%L<V4I.PH@("`@("`@("`@("!I9B`H(21F;W5N9"`F)B`A*&ES<V5T
M*"1P87)A;7-;,5TI("8F("%E;7!T>2@D<&%R86US6S%=*0H@("`@("`@("`@
M("`@("`@)B8@*'-T<FES='(H)&EN9F];)W-U;6UA<GDG72P@)'!A<F%M<ULQ
M72D@(3T](&9A;'-E"B`@("`@("`@("`@("`@("`@("`@?'P@<W1R:7-T<B@D
M:6YF;ULG9&5S8W)I<'1I;VXG72P@)'!A<F%M<ULQ72D@(3T](&9A;'-E*2DI
M"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!].PH*("`@("`@("`@("`@)&EN<W1A;&QE9"`]("1R96<M/G!A
M8VMA9V5);F9O*"1N86UE*3L*("`@("`@("`@("`@)&1E<V,@/2`D:6YF;ULG
M<W5M;6%R>2==.PH@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULD;F%M
M95TI*0H@("`@("`@("`@("`@("`@)&1E<V,@+CT@(EQN7&XB+B1I;F9O6R=D
M97-C<FEP=&EO;B==.PH*("`@("`@("`@("`@)&1A=&%;)V1A=&$G75LD:6YF
M;ULG8V%T96=O<GDG75U;72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)&YA
M;64L"B`@("`@("`@("`@("`@("`D:6YF;ULG<W1A8FQE)UTL"B`@("`@("`@
M("`@("`@("`D:6YS=&%L;&5D6R=V97)S:6]N)UTL"B`@("`@("`@("`@("`@
M("`D9&5S8RP*("`@("`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@("`@
M(&EF("@A:7-S970H)&1A=&%;)V1A=&$G72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=N;R!P86-K86=E<R!F;W5N9"<I.PH@
M("`@("`@('T["B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A
M+"`D8V]M;6%N9"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9&]$;W=N;&]A9"@I"@H@("`@9G5N8W1I;VX@
M9&]$;W=N;&]A9"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I"B`@("![
M"B`@("`@("`@+R\D<&%R86US6S!=("T^(%1H92!P86-K86=E('1O(&1O=VYL
M;V%D"B`@("`@("`@:68@*&-O=6YT*"1P87)A;7,I("$](#$I('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(F1O=VYL;V%D(&5X<&5C
M=',@;VYE(&%R9W5M96YT.B!T:&4@<&%C:V%G92!T;R!D;W=N;&]A9"(I.PH@
M("`@("`@('T*("`@("`@("`D<V5R=F5R(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"=M87-T97)?<V5R=F5R)RD["B`@("`@("`@:68@*"%E<F5G*"=>:'1T<#HO
M+R<L("1P87)A;7-;,%TI*2!["B`@("`@("`@("`@("1P:V=F:6QE(#T@(FAT
M='`Z+R\D<V5R=F5R+V=E="\D<&%R86US6S!=(CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<&MG9FEL92`]("1P87)A;7-;,%T["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3YB>71E<U]D;W=N;&]A9&5D(#T@,#L*("`@("`@
M("`D<V%V960@/2!014%27T-O;6UO;CHZ9&]W;FQO861(='1P*"1P:V=F:6QE
M+"`D=&AI<RT^=6DL("<N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"8D=&AI<RP@)V1O=VYL;V%D0V%L;&)A
M8VLG*2D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'-A=F5D*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'-A=F5D*3L*
M("`@("`@("!]"B`@("`@("`@)&9N86UE(#T@8F%S96YA;64H)'-A=F5D*3L*
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(D9I;&4@)&9N86UE(&1O
M=VYL;V%D960@*"1T:&ES+3YB>71E<U]D;W=N;&]A9&5D(&)Y=&5S*2(L("1C
M;VUM86YD*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC
M=&EO;B!D;W=N;&]A9$-A;&QB86-K*"1M<V<L("1P87)A;7,@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@D;7-G(#T]("=D;VYE)RD@>PH@("`@("`@("`@
M("`D=&AI<RT^8GET97-?9&]W;FQO861E9"`]("1P87)A;7,["B`@("`@("`@
M?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1O3&ES=%5P9W)A9&5S
M*"D*"B`@("!F=6YC=&EO;B!D;TQI<W15<&=R861E<R@D8V]M;6%N9"P@)&]P
M=&EO;G,L("1P87)A;7,I"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E(")0
M14%2+U)E9VES=')Y+G!H<"(["B`@("`@("`@)')E;6]T92`](&YE=R!014%2
M7U)E;6]T92@D=&AI<RT^8V]N9FEG*3L*("`@("`@("!I9B`H96UP='DH)'!A
M<F%M<ULP72DI('L*("`@("`@("`@("`@)'-T871E(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<W1A=&4@/2`D<&%R86US6S!=.PH@("`@("`@('T*("`@
M("`@("`D8V%P=&EO;B`]("=!=F%I;&%B;&4@57!G<F%D97,G.PH@("`@("`@
M(&EF("AE;7!T>2@D<W1A=&4I('Q\("1S=&%T92`]/2`G86YY)RD@>PH@("`@
M("`@("`@("`D;&%T97-T(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T
M3&%T97-T4F5L96%S97,B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;&%T97-T(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T3&%T97-T
M4F5L96%S97,B+"`D<W1A=&4I.PH@("`@("`@("`@("`D8V%P=&EO;B`N/2`G
M("@G("X@)'-T871E("X@)RDG.PH@("`@("`@('T*("`@("`@("`D8V%P=&EO
M;B`N/2`G.B<["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QA=&5S="DI
M('L*("`@("`@("`@("`@<F5T=7)N("1L871E<W0["B`@("`@("`@?0H@("`@
M("`@("1R96<@/2!N97<@4$5!4E]296=I<W1R>2@D=&AI<RT^8V]N9FEG+3YG
M970H)W!H<%]D:7(G*2D["B`@("`@("`@)&EN<W0@/2!A<G)A>5]F;&EP*"1R
M96<M/FQI<W1086-K86=E<R@I*3L*("`@("`@("`D9&%T82`](&%R<F%Y*`H@
M("`@("`@("`@("`G8V%P=&EO;B<@/3X@)&-A<'1I;VXL"B`@("`@("`@("`@
M("=B;W)D97(G(#T^(#$L"B`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R
M87DH)U!A8VMA9V4G+"`G5F5R<VEO;B<L("=3:7IE)RDL"B`@("`@("`@("`@
M("D["B`@("`@("`@9F]R96%C:"`H)&QA=&5S="!A<R`D<&%C:V%G92`]/B`D
M:6YF;RD@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;G-T6R1P86-K86=E
M72DI('L*("`@("`@("`@("`@("`@("\O('-K:7`@<&%C:V%G97,@=V4@9&]N
M)W0@:&%V92!I;G-T86QL960*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5X=')A8W0H)&EN9F\I.PH@("`@
M("`@("`@("`D:6YS=%]V97)S:6]N(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A
M8VMA9V4L("=V97)S:6]N)RD["B`@("`@("`@("`@(&EF("AV97)S:6]N7V-O
M;7!A<F4H(B1V97)S:6]N(BP@(B1I;G-T7W9E<G-I;VXB+"`B;&4B*2D@>PH@
M("`@("`@("`@("`@("`@+R\@:6YS=&%L;&5D('9E<G-I;VX@:7,@=7`M=&\M
M9&%T90H@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1F:6QE<VEZ92`^/2`R,#0X,"D@>PH@("`@("`@
M("`@("`@("`@)&9I;&5S:7IE("L](#$P,C0@+2`H)&9I;&5S:7IE("4@,3`R
M-"D["B`@("`@("`@("`@("`@("`D9G,@/2!S<')I;G1F*"(E9&M"(BP@)&9I
M;&5S:7IE("\@,3`R-"D["B`@("`@("`@("`@('T@96QS96EF("@D9FEL97-I
M>F4@/B`P*2!["B`@("`@("`@("`@("`@("`D9FEL97-I>F4@*ST@,3`S("T@
M*"1F:6QE<VEZ92`E(#$P,RD["B`@("`@("`@("`@("`@("`D9G,@/2!S<')I
M;G1F*"(E+C%F:T(B+"`D9FEL97-I>F4@+R`Q,#(T+C`I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9S(#T@(B`@+2([("\O(%A8
M6"!C96YT97(@:6YS=&5A9`H@("`@("`@("`@("!]"B`@("`@("`@("`@("1D
M871A6R=D871A)UU;72`](&%R<F%Y*"1P86-K86=E+"`D=F5R<VEO;BP@)&9S
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D871A6R=D871A)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G3F\@=7!G
M<F%D97,@879A:6QA8FQE)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&1O0VQE87)#86-H92@I"@H@("`@9G5N8W1I;VX@9&]#
M;&5A<D-A8VAE*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD*("`@('L*
M("`@("`@("`D8V%C:&5?9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=C86-H
M95]D:7(G*3L*("`@("`@("`D=F5R8F]S92`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G=F5R8F]S92<I.PH@("`@("`@("1O=71P=70@/2`G)SL*("`@("`@("!I
M9B`H(2@D9'`@/2!`;W!E;F1I<B@D8V%C:&5?9&ER*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")O<&5N9&ER*"1C86-H95]D
M:7(I(&9A:6QE9#H@)'!H<%]E<G)O<FUS9R(I.PH@("`@("`@('T*("`@("`@
M("!I9B`H)'9E<F)O<V4@/CT@,2D@>PH@("`@("`@("`@("`D;W5T<'5T("X]
M(")R96%D:6YG(&1I<F5C=&]R>2`D8V%C:&5?9&ER7&XB.PH@("`@("`@('T*
M("`@("`@("`D;G5M(#T@,#L*("`@("`@("!W:&EL92`H)&5N="`](')E861D
M:7(H)&1P*2D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UYX;6QR
M<&-?8V%C:&5?6V$M>C`M.5U[,S)])"\G+"`D96YT*2D@>PH@("`@("`@("`@
M("`@("`@)'!A=&@@/2`D8V%C:&5?9&ER("X@1$E214-43U)97U-%4$%2051/
M4B`N("1E;G0["B`@("`@("`@("`@("`@("`D;VL@/2!`=6YL:6YK*"1P871H
M*3L*("`@("`@("`@("`@("`@(&EF("@D;VLI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'9E<F)O<V4@/CT@,BD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X](")D96QE=&5D("1P871H7&XB.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;G5M*RL["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)'9E<F)O<V4@/CT@,2D@>PH@("`@("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@(F9A:6QE9"!T;R!D96QE=&4@)'!A
M=&A<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@8VQO<V5D:7(H)&1P*3L*("`@("`@("!I9B`H)'9E<F)O
M<V4@/CT@,2D@>PH@("`@("`@("`@("`D;W5T<'5T("X]("(D;G5M(&-A8VAE
M(&5N=')I97,@8VQE87)E9%QN(CL*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*')T<FEM*"1O=71P=70I+"`D8V]M;6%N9"D["B`@
M("`@("`@<F5T=7)N("1N=6T["B`@("!]"@H@("`@+R\@?7U]"GT*"C\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+T9R;VYT96YD+P``````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-@`P,3<V-3$`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O1G)O;G1E;F0O0TQ)+G!H
M<```````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0P-#<R`#$P-#$W
M,S8S,#`V`#`R,#<W-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*@H@("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PH@('P@4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`H@("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PH@('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`H@("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH@('P@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS92P@("`@("`@?`H@('P@=&AA="!I<R!B=6YD;&5D('=I=&@@
M=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@
M("`@?`H@('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`H@('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`H@('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`H@('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`H@('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`H@("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PH@('P@075T:&]R.B!3=&EG(%/F=&AE<B!"86MK96X@/'-S8D!P:'`N
M;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`H@("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PH*("`D260Z($-,22YP:'`L=B`Q+C0Q(#(P
M,#0O,#(O,3<@,#4Z-#DZ,38@<W-B($5X<"`D"BHO"@IR97%U:7)E7V]N8V4@
M(E!%05(N<&AP(CL*"F-L87-S(%!%05)?1G)O;G1E;F1?0TQ)(&5X=&5N9',@
M4$5!4@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@
M5VAA="!T>7!E(&]F('5S97(@:6YT97)F86-E('1H:7,@9G)O;G1E;F0@:7,@
M9F]R+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@('9A<B`D='EP92`]("=#3$DG.PH@("`@=F%R("1L<"`]
M("<G.R`O+R!L:6YE('!R969I>`H*("`@('9A<B`D<&%R86US(#T@87)R87DH
M*3L*("`@('9A<B`D=&5R;2`](&%R<F%Y*`H@("`@("`@("=B;VQD)R`]/B`G
M)RP*("`@("`@("`G;F]R;6%L)R`]/B`G)RP*("`@("`@("`I.PH*("`@("\O
M('U]?0H*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@(&9U;F-T:6]N(%!%
M05)?1G)O;G1E;F1?0TQ)*"D*("`@('L*("`@("`@("!P87)E;G0Z.E!%05(H
M*3L*("`@("`@("`D=&5R;2`](&=E=&5N=B@G5$5232<I.R`O+RAC;W@I("1?
M14Y6(&ES(&5M<'1Y(&9O<B!M92!I;B`T+C$N,0H@("`@("`@(&EF("AF=6YC
M=&EO;E]E>&ES=',H)W!O<VEX7VES871T>2<I("8F("%P;W-I>%]I<V%T='DH
M,2DI('L*("`@("`@("`@("`@+R\@;W5T<'5T(&ES(&)E:6YG(')E9&ER96-T
M960@=&\@82!F:6QE(&]R('1H<F]U9V@@82!P:7!E"B`@("`@("`@?2!E;'-E
M:68@*"1T97)M*2!["B`@("`@("`@("`@("\O(%A86"!C86X@=7-E(&YC=7)S
M97,@97AT96YS:6]N(&AE<F4L(&EF(&%V86EL86)L90H@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@G+UXH>'1E<FU\=G0R,C!\;&EN=7@I+R<L("1T97)M
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G1E<FU;)V)O;&0G72`]('-P
M<FEN=&8H(B5C)6,E8R5C(BP@,C<L(#DQ+"`T.2P@,3`Y*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YT97)M6R=N;W)M86PG73US<')I;G1F*"(E8R5C)6,B
M+"`R-RP@.3$L(#$P.2D["B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA
M=&-H*"<O7G9T,3`P+R<L("1T97)M*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G1E<FU;)V)O;&0G72`]('-P<FEN=&8H(B5C)6,E8R5C)6,E8R(L(#(W
M+"`Y,2P@-#DL(#$P.2P@,"P@,"D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M=&5R;5LG;F]R;6%L)UT]<W!R:6YT9B@B)6,E8R5C)6,E8R(L(#(W+"`Y,2P@
M,3`Y+"`P+"`P*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("A/
M4U]724Y$3U=3*2!["B`@("`@("`@("`@("\O(%A86"!A9&0@04Y322!C;V1E
M<R!H97)E"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*("`@("\O('M[
M>R!D:7-P;&%Y3&EN92AT97AT*0H*("`@(&9U;F-T:6]N(&1I<W!L87E,:6YE
M*"1T97AT*0H@("`@>PH@("`@("`@('1R:6=G97)?97)R;W(H(E!%05)?1G)O
M;G1E;F1?0TQ).CID:7-P;&%Y3&EN92!D97!R96-A=&5D(BP@15]54T527T52
M4D]2*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9&ES<&QA>4QI;F4H)'1E>'0I
M"B`@("!["B`@("`@("`@<')I;G0@(B1T:&ES+3YL<"1T97AT7&XB.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<W!L87DH=&5X="D*"B`@("!F
M=6YC=&EO;B!D:7-P;&%Y*"1T97AT*0H@("`@>PH@("`@("`@('1R:6=G97)?
M97)R;W(H(E!%05)?1G)O;G1E;F1?0TQ).CID:7-P;&%Y(&1E<')E8V%T960B
M+"!%7U5315)?15)23U(I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]D:7-P;&%Y
M*"1T97AT*0H@("`@>PH@("`@("`@('!R:6YT("1T97AT.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&1I<W!L87E%<G)O<BAE;V)J*0H*("`@("\J
M*@H@("`@("H@0'!A<F%M(&]B:F5C="!014%27T5R<F]R(&]B:F5C=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!D:7-P;&%Y17)R;W(H)&5O8FHI"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&5O8FHM/F=E=$UE
M<W-A9V4H*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES<&QA
M>49A=&%L17)R;W(H96]B:BD*"B`@("`O*BH*("`@("`J($!P87)A;2!O8FIE
M8W0@4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES
M<&QA>49A=&%L17)R;W(H)&5O8FHI"B`@("!["B`@("`@("`@)'1H:7,M/F1I
M<W!L87E%<G)O<B@D96]B:BD["B`@("`@("`@97AI="@Q*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!D:7-P;&%Y2&5A9&EN9RAT:71L92D*"B`@
M("!F=6YC=&EO;B!D:7-P;&%Y2&5A9&EN9R@D=&ET;&4I"B`@("!["B`@("`@
M("`@=')I9V=E<E]E<G)O<B@B4$5!4E]&<F]N=&5N9%]#3$DZ.F1I<W!L87E(
M96%D:6YG(&1E<')E8V%T960B+"!%7U5315)?15)23U(I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]D:7-P;&%Y2&5A9&EN9R@D=&ET;&4I"B`@("!["B`@("`@
M("`@<')I;G0@)'1H:7,M/FQP+B1T:&ES+3YB;VQD*"1T:71L92DN(EQN(CL*
M("`@("`@("!P<FEN="`D=&AI<RT^;'`N<W1R7W)E<&5A="@B/2(L('-T<FQE
M;B@D=&ET;&4I*2XB7&XB.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('5S97)$:6%L;V<H<')O;7!T+"!;='EP95TL(%MD969A=6QT72D*"B`@("!F
M=6YC=&EO;B!U<V5R1&EA;&]G*"1C;VUM86YD+"`D<')O;7!T<RP@)'1Y<&5S
M(#T@87)R87DH*2P@)&1E9F%U;'1S(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D<F5S=6QT(#T@87)R87DH*3L*("`@("`@("!I9B`H:7-?87)R87DH)'!R
M;VUP=',I*2!["B`@("`@("`@("`@("1F<"`](&9O<&5N*")P:'`Z+R]S=&1I
M;B(L(")R(BD["B`@("`@("`@("`@(&9O<F5A8V@@*"1P<F]M<'1S(&%S("1K
M97D@/3X@)'!R;VUP="D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D='EP
M97-;)&ME>5T["B`@("`@("`@("`@("`@("`D9&5F875L="`]($`D9&5F875L
M='-;)&ME>5T["B`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)W!A<W-W
M;W)D)RD@>PH@("`@("`@("`@("`@("`@("`@('-Y<W1E;2@G<W1T>2`M96-H
M;R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<')I;G0@
M(B1T:&ES+3YL<"1P<F]M<'0@(CL*("`@("`@("`@("`@("`@(&EF("@D9&5F
M875L="D@>PH@("`@("`@("`@("`@("`@("`@('!R:6YT(");)&1E9F%U;'1=
M("(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!P<FEN="`B
M.B`B.PH@("`@("`@("`@("`@("`@)&QI;F4@/2!F9V5T<R@D9G`L(#(P-#@I
M.PH@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=P87-S=V]R9"<I('L*
M("`@("`@("`@("`@("`@("`@("!S>7-T96TH)W-T='D@96-H;R<I.PH@("`@
M("`@("`@("`@("`@("`@('!R:6YT(")<;B(["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H)&1E9F%U;'0@)B8@=')I;2@D;&EN92D@
M/3T@(B(I('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6R1K97E=(#T@
M)&1E9F%U;'0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1R97-U;'1;)&ME>5T@/2`D;&EN93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@=7-E<D-O;F9I<FTH<')O;7!T+"!;9&5F875L
M=%TI"@H@("`@9G5N8W1I;VX@=7-E<D-O;F9I<FTH)'!R;VUP="P@)&1E9F%U
M;'0@/2`G>65S)RD*("`@('L*("`@("`@("!T<FEG9V5R7V5R<F]R*")014%2
M7T9R;VYT96YD7T-,23HZ=7-E<D-O;F9I<FT@;F]T('EE="!C;VYV97)T960B
M+"!%7U5315)?15)23U(I.PH@("`@("`@('-T871I8R`D<&]S:71I=F5S(#T@
M87)R87DH)WDG+"`G>65S)RP@)V]N)RP@)S$G*3L*("`@("`@("!S=&%T:6,@
M)&YE9V%T:79E<R`](&%R<F%Y*"=N)RP@)VYO)RP@)V]F9B<L("<P)RD["B`@
M("`@("`@<')I;G0@(B1T:&ES+3YL<"1P<F]M<'0@6R1D969A=6QT72`Z("([
M"B`@("`@("`@)&9P(#T@9F]P96XH(G!H<#HO+W-T9&EN(BP@(G(B*3L*("`@
M("`@("`D;&EN92`](&9G971S*"1F<"P@,C`T."D["B`@("`@("`@9F-L;W-E
M*"1F<"D["B`@("`@("`@)&%N<W=E<B`]('-T<G1O;&]W97(H=')I;2@D;&EN
M92DI.PH@("`@("`@(&EF("AE;7!T>2@D86YS=V5R*2D@>PH@("`@("`@("`@
M("`D86YS=V5R(#T@)&1E9F%U;'0["B`@("`@("`@?0H@("`@("`@(&EF("AI
M;E]A<G)A>2@D86YS=V5R+"`D<&]S:71I=F5S*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@:68@*&EN7V%R<F%Y*"1A
M;G-W97(L("1N96=A=&EV97,I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("`@("`@:68@*&EN7V%R<F%Y*"1D969A=6QT+"`D
M<&]S:71I=F5S*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('-T87)T5&%B;&4H6W!A<F%M<UTI"@H@("`@9G5N8W1I;VX@
M<W1A<G1486)L92@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!T
M<FEG9V5R7V5R<F]R*")014%27T9R;VYT96YD7T-,23HZ<W1A<G1486)L92!D
M97!R96-A=&5D(BP@15]54T527T524D]2*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!?<W1A<G1486)L92@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D<&%R86US6R=T86)L95]D871A)UT@/2!A<G)A>2@I.PH@("`@("`@("1P
M87)A;7-;)W=I9&5S="==(#T@87)R87DH*3L@("\O(&EN9&5X960@8GD@8V]L
M=6UN"B`@("`@("`@)'!A<F%M<ULG:&EG:&5S="==(#T@87)R87DH*3L@+R\@
M:6YD97AE9"!B>2!R;W<*("`@("`@("`D<&%R86US6R=N8V]L<R==(#T@,#L*
M("`@("`@("`D=&AI<RT^<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!T86)L95)O=RAC;VQU;6YS+"!;<F]W<&%R86US
M72P@6V-O;'!A<F%M<UTI"@H@("`@9G5N8W1I;VX@=&%B;&52;W<H)&-O;'5M
M;G,L("1R;W=P87)A;7,@/2!A<G)A>2@I+"`D8V]L<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!T<FEG9V5R7V5R<F]R*")014%27T9R;VYT96YD
M7T-,23HZ=&%B;&52;W<@9&5P<F5C871E9"(L($5?55-%4E]%4E)/4BD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W1A8FQE4F]W*"1C;VQU;6YS+"`D<F]W<&%R
M86US(#T@87)R87DH*2P@)&-O;'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)&AI9VAE<W0@/2`Q.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M('-I>F5O9B@D8V]L=6UN<RD[("1I*RLI('L*("`@("`@("`@("`@)&-O;"`]
M("8D8V]L=6UN<ULD:5T["B`@("`@("`@("`@(&EF("AI<W-E="@D8V]L<&%R
M86US6R1I72D@)B8@(65M<'1Y*"1C;VQP87)A;7-;)&E=6R=W<F%P)UTI*2![
M"B`@("`@("`@("`@("`@("`D8V]L(#T@=V]R9'=R87`H)&-O;"P@)&-O;'!A
M<F%M<ULD:5U;)W=R87`G72P@(EQN(BP@,"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*'-T<G!O<R@D8V]L+"`B7&XB*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1M=6QT:6QI;F4@/2!E>'!L;V1E*")<;B(L("1C
M;VPI.PH@("`@("`@("`@("`@("`@)'<@/2`P.PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&UU;'1I;&EN92!A<R`D;B`]/B`D;&EN92D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("AS=')L96XH)&QI;F4I(#X@)'<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'<@/2!S=')L96XH)&QI;F4I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1L:6YE<R`]('-I>F5O9B@D;75L=&EL:6YE*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1W(#T@<W1R;&5N*"1C;VPI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=R`^($`D=&AI<RT^<&%R
M86US6R=W:61E<W0G75LD:5TI('L*("`@("`@("`@("`@("`@("1T:&ES+3YP
M87)A;7-;)W=I9&5S="==6R1I72`]("1W.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T;7`@/2!C;W5N=%]C:&%R<R@D8V]L=6UN<ULD:5TL(#$I.PH@
M("`@("`@("`@("`O+R!H86YD;&4@=6YI>"P@;6%C(&%N9"!W:6YD;W=S(&9O
M<FUA=',*("`@("`@("`@("`@)&QI;F5S(#T@*&ES<V5T*"1T;7!;,3!=*2`_
M("1T;7!;,3!=(#H@0"1T;7!;,3-=*2`K(#$["B`@("`@("`@("`@(&EF("@D
M;&EN97,@/B`D:&EG:&5S="D@>PH@("`@("`@("`@("`@("`@)&AI9VAE<W0@
M/2`D;&EN97,["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@
M*'-I>F5O9B@D8V]L=6UN<RD@/B`D=&AI<RT^<&%R86US6R=N8V]L<R==*2![
M"B`@("`@("`@("`@("1T:&ES+3YP87)A;7-;)VYC;VQS)UT@/2!S:7IE;V8H
M)&-O;'5M;G,I.PH@("`@("`@('T*("`@("`@("`D;F5W7W)O=R`](&%R<F%Y
M*`H@("`@("`@("`@("`G9&%T82<@/3X@)&-O;'5M;G,L"B`@("`@("`@("`@
M("=H96EG:'0G(#T^("1H:6=H97-T+`H@("`@("`@("`@("`G<F]W<&%R86US
M)R`]/B`D<F]W<&%R86US+`H@("`@("`@("`@("`G8V]L<&%R86US)R`]/B`D
M8V]L<&%R86US+`H@("`@("`@("`@("`I.PH@("`@("`@("1T:&ES+3YP87)A
M;7-;)W1A8FQE7V1A=&$G75M=(#T@)&YE=U]R;W<["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@96YD5&%B;&4H*0H*("`@(&9U;F-T:6]N(&5N9%1A
M8FQE*"D*("`@('L*("`@("`@("!T<FEG9V5R7V5R<F]R*")014%27T9R;VYT
M96YD7T-,23HZ96YD5&%B;&4@9&5P<F5C871E9"(L($5?55-%4E]%4E)/4BD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7V5N9%1A8FQE*"D*("`@('L*("`@("`@
M("!E>'1R86-T*"1T:&ES+3YP87)A;7,I.PH@("`@("`@(&EF("@A96UP='DH
M)&-A<'1I;VXI*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>4AE861I
M;F<H)&-A<'1I;VXI.PH@("`@("`@('T*("`@("`@("!I9B`H8V]U;G0H)'1A
M8FQE7V1A=&$I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*("`@("`@("!I9B`H(6ES<V5T*"1W:61T:"DI('L*("`@("`@("`@("`@
M)'=I9'1H(#T@)'=I9&5S=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D;F-O;',[("1I*RLI('L*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'=I9'1H6R1I72DI('L*("`@("`@("`@("`@
M("`@("`@("`D=VED=&A;)&E=(#T@)'=I9&5S=%LD:5T["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&)O<F1E
M<B`](&9A;'-E.PH@("`@("`@(&EF("AE;7!T>2@D8F]R9&5R*2D@>PH@("`@
M("`@("`@("`D8V5L;'-T87)T(#T@)R<["B`@("`@("`@("`@("1C96QL96YD
M(#T@)R`G.PH@("`@("`@("`@("`D<F]W96YD(#T@)R<["B`@("`@("`@("`@
M("1P861R;W=E;F0@/2!F86QS93L*("`@("`@("`@("`@)&)O<F1E<FQI;F4@
M/2`G)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V5L;'-T87)T
M(#T@)WP@)SL*("`@("`@("`@("`@)&-E;&QE;F0@/2`G("<["B`@("`@("`@
M("`@("1R;W=E;F0@/2`G?"<["B`@("`@("`@("`@("1P861R;W=E;F0@/2!T
M<G5E.PH@("`@("`@("`@("`D8F]R9&5R;&EN92`]("<K)SL*("`@("`@("`@
M("`@9F]R96%C:"`H)'=I9'1H(&%S("1W*2!["B`@("`@("`@("`@("`@("`D
M8F]R9&5R;&EN92`N/2!S=')?<F5P96%T*"<M)RP@)'<@*R!S=')L96XH)&-E
M;&QS=&%R="D@*R!S=')L96XH)&-E;&QE;F0I("T@,2D["B`@("`@("`@("`@
M("`@("`D8F]R9&5R;&EN92`N/2`G*R<["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*"1B;W)D97)L:6YE*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?9&ES<&QA>4QI;F4H)&)O<F1E<FQI;F4I.PH@("`@("`@('T*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1A8FQE7V1A=&$I.R`D
M:2LK*2!["B`@("`@("`@("`@(&5X=')A8W0H)'1A8FQE7V1A=&%;)&E=*3L*
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F]W<&%R86US*2D@>PH@("`@
M("`@("`@("`@("`@)')O=W!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D8V]L<&%R86US*2D@>PH@
M("`@("`@("`@("`@("`@)&-O;'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)')O=VQI;F5S(#T@87)R87DH*3L*("`@("`@
M("`@("`@:68@*"1H96EG:'0@/B`Q*2!["B`@("`@("`@("`@("`@("!F;W(@
M*"1C(#T@,#L@)&,@/"!S:7IE;V8H)&1A=&$I.R`D8RLK*2!["B`@("`@("`@
M("`@("`@("`@("`@)')O=VQI;F5S6R1C72`]('!R96=?<W!L:70H)R\H7'(_
M7&Y\7'(I+R<L("1D871A6R1C72D["B`@("`@("`@("`@("`@("`@("`@:68@
M*'-I>F5O9B@D<F]W;&EN97-;)&-=*2`\("1H96EG:'0I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)')O=VQI;F5S6R1C72`](&%R<F%Y7W!A9"@D<F]W
M;&EN97-;)&-=+"`D:&5I9VAT+"`G)RD["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@9F]R("@D8R`](#`[("1C(#P@<VEZ96]F*"1D871A*3L@
M)&,K*RD@>PH@("`@("`@("`@("`@("`@("`@("1R;W=L:6YE<ULD8UT@/2!A
M<G)A>2@D9&%T85LD8UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&9O<B`H)'(@/2`P.R`D<B`\("1H96EG:'0[("1R
M*RLI('L*("`@("`@("`@("`@("`@("1R;W=T97AT(#T@)R<["B`@("`@("`@
M("`@("`@("!F;W(@*"1C(#T@,#L@)&,@/"!S:7IE;V8H)&1A=&$I.R`D8RLK
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;VQP87)A;7-;
M)&-=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB<R`](&%R
M<F%Y7VUE<F=E*"1R;W=P87)A;7,L("1C;VQP87)A;7,I.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1A
M='1R:6)S(#T@)')O=W!A<F%M<SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)'<@/2!I<W-E="@D=VED=&A;)&-=*2`_("1W
M:61T:%LD8UT@.B`P.PH@("`@("`@("`@("`@("`@("`@("\O)&-E;&P@/2`D
M9&%T85LD8UT["B`@("`@("`@("`@("`@("`@("`@)&-E;&P@/2`D<F]W;&EN
M97-;)&-=6R1R73L*("`@("`@("`@("`@("`@("`@("`D;"`]('-T<FQE;B@D
M8V5L;"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1L(#X@)'<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-E;&P@/2!S=6)S='(H)&-E;&PL(#`L
M("1W*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1A='1R:6)S6R=B;VQD)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C96QL(#T@)'1H:7,M/F)O;&0H)&-E;&PI.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H)&P@
M/"`D=RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!N;W0@=7-I;F<@
M<W1R7W!A9"!H97)E(&)E8V%U<V4@=V4@;6%Y"B`@("`@("`@("`@("`@("`@
M("`@("`@("\O(&%D9"!B;VQD(&5S8V%P92!C:&%R86-T97)S('1O("1C96QL
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C96QL("X]('-T<E]R97!E870H
M)R`G+"`D=R`M("1L*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("1R;W=T97AT("X]("1C96QL<W1A<G0@+B`D8V5L;"`N
M("1C96QL96YD.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*"$D8F]R9&5R*2!["B`@("`@("`@("`@("`@("`@("`@)')O=W1E>'0@
M/2!R=')I;2@D<F]W=&5X="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D<F]W=&5X="`N/2`D<F]W96YD.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D:7-P;&%Y3&EN92@D<F]W=&5X="D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@:68@*"1B;W)D97)L:6YE*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&)O<F1E<FQI;F4I.PH@("`@("`@
M('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!O=71P=71$871A*"D*
M"B`@("!F=6YC=&EO;B!O=71P=71$871A*"1D871A+"`D8V]M;6%N9"`]("=?
M9&5F875L="<I"B`@("!["B`@("`@("`@<W=I=&-H("@D8V]M;6%N9"D@>PH@
M("`@("`@("`@("!C87-E("=I;G-T86QL)SH*("`@("`@("`@("`@8V%S92`G
M=7!G<F%D92<Z"B`@("`@("`@("`@(&-A<V4@)W5P9W)A9&4M86QL)SH*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG<F5L96%S95]W87)N:6YG
M<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>4QI
M;F4H)R<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A<G1486)L
M92AA<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C87!T:6]N)R`]/B`G
M4F5L96%S92!787)N:6YG<R<*("`@("`@("`@("`@("`@("`@("`@("`@*2D[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=RAA<G)A>2@D
M9&%T85LG<F5L96%S95]W87)N:6YG<R==*2P@;G5L;"P@87)R87DH,2`]/B!A
M<G)A>2@G=W)A<"<@/3X@-34I*2D["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]E;F1486)L92@I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&ES<&QA>4QI;F4H)R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]D:7-P;&%Y3&EN92@D9&%T85LG9&%T82==*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=S96%R8V@G
M.@H@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%R=%1A8FQE*"1D871A*3L*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG:&5A9&QI;F4G72D@
M)B8@:7-?87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]T86)L95)O=R@D9&%T85LG:&5A9&QI;F4G72P@
M87)R87DH)V)O;&0G(#T^('1R=64I+"!A<G)A>2@Q(#T^(&%R<F%Y*"=W<F%P
M)R`]/B`U-2DI*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("!F;W)E86-H*"1D871A6R=D871A)UT@87,@)&-A=&5G;W)Y*2!["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"@D8V%T96=O<GD@87,@)'!K9RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1A8FQE4F]W*"1P:V<L
M(&YU;&PL(&%R<F%Y*#$@/3X@87)R87DH)W=R87`G(#T^(#4U*2DI.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V5N9%1A8FQE*"D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@8V%S92`G;&ES="UA;&PG.@H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S=&%R=%1A8FQE*"1D871A*3L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9&%T85LG:&5A9&QI;F4G72D@)B8@:7-?87)R87DH
M)&1A=&%;)VAE861L:6YE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]T86)L95)O=R@D9&%T85LG:&5A9&QI;F4G72P@87)R87DH)V)O;&0G
M(#T^('1R=64I+"!A<G)A>2@Q(#T^(&%R<F%Y*"=W<F%P)R`]/B`U-2DI*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!F;W)E86-H*"1D
M871A6R=D871A)UT@87,@)&-A=&5G;W)Y*2!["B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"@D8V%T96=O<GD@87,@)'!K9RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D<&MG6S-=*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)'!K9ULT72D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=&%B;&52;W<H)'!K9RP@;G5L;"P@87)R87DH,2`]/B!A<G)A
M>2@G=W)A<"<@/3X@-34I*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?96YD5&%B
M;&4H*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M("=C;VYF:6<M<VAO=R<Z"B`@("`@("`@("`@("`@("`D9&%T85LG8F]R9&5R
M)UT@/2!F86QS93L*("`@("`@("`@("`@("`@("1O<'1S(#T@87)R87DH,"`]
M/B!A<G)A>2@G=W)A<"<@/3X@,S`I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Q(#T^(&%R<F%Y*"=W<F%P)R`]/B`R,"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#(@/3X@87)R87DH)W=R87`G(#T^(#,U*2D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T87)T5&%B;&4H)&1A=&$I.PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=H96%D;&EN92==*2`F
M)B!I<U]A<G)A>2@D9&%T85LG:&5A9&QI;F4G72DI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W1A8FQE4F]W*"1D871A6R=H96%D;&EN92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O
M;&0G(#T^('1R=64I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&]P=',I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@9F]R96%C:"@D9&%T85LG9&%T82==(&%S("1G<F]U<"D@>PH@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@H)&=R;W5P(&%S("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E6S)=(#T]("<G*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;,ET@/2`B/&YO="!S
M970^(CL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W1A8FQE4F]W*"1V86QU92P@;G5L;"P@)&]P
M=',I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?96YD5&%B;&4H*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=R96UO=&4M:6YF;R<Z
M"B`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=C87!T:6]N)R`]/B`G4&%C:V%G92!D971A:6QS.B<L"B`@("`@
M("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@)V1A=&$G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@B3&%T97-T(BP@("`@)&1A=&%;)W-T86)L92==*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH(DEN<W1A;&QE9"(L("1D871A
M6R=I;G-T86QL960G72DL"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*")086-K86=E(BP@("`D9&%T85LG;F%M92==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH(DQI8V5N<V4B+"`@("1D871A6R=L:6-E;G-E)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@B0V%T96=O<GDB+"`@
M)&1A=&%;)V-A=&5G;W)Y)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@B4W5M;6%R>2(L("`@)&1A=&%;)W-U;6UA<GDG72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*")$97-C<FEP=&EO;B(L("1D871A6R=D
M97-C<FEP=&EO;B==*2P*("`@("`@("`@("`@("`@("`@("`@("`@*2P*("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("!D969A=6QT.B!["B`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&1A=&$I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S=&%R=%1A8FQE*"1D871A*3L*("`@("`@
M("`@("`@("`@("`@("`D8V]U;G0@/2!C;W5N="@D9&%T85LG9&%T82==6S!=
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-O=6YT(#T](#(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]P=',@/2!A<G)A>2@P(#T^(&%R<F%Y
M*"=W<F%P)R`]/B`R-2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@,2`]/B!A<G)A>2@G=W)A<"<@/3X@-#@I"B`@("`@("`@("`@
M("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1C;W5N="`]/2`S*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1O<'1S
M(#T@87)R87DH,"`]/B!A<G)A>2@G=W)A<"<@/3X@,S`I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@/3X@87)R87DH)W=R87`G
M(#T^(#(P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`R(#T^(&%R<F%Y*"=W<F%P)R`]/B`S-2D*("`@("`@("`@("`@("`@("`@
M("`@("`@*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;W!T<R`](&YU;&P["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG
M:&5A9&QI;F4G72D@)B8@:7-?87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A
M=&%;)VAE861L:6YE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V)O;&0G(#T^('1R=64I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1S*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D
M9&%T85LG9&%T82==(&%S("1R;W<I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]T86)L95)O=R@D<F]W+"!N=6QL+"`D;W!T<RD["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M96YD5&%B;&4H*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D:7-P;&%Y3&EN92@D9&%T82D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@;&]G*'1E>'0I"@H*("`@(&9U;F-T:6]N
M(&QO9R@D=&5X="P@)&%P<&5N9%]C<FQF(#T@=')U92D*("`@('L*("`@("`@
M("!I9B`H)&%P<&5N9%]C<FQF*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1I<W!L87E,:6YE*"1T97AT*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&ES<&QA>2@D=&5X="D["B`@("!]"@H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&)O;&0H)'1E>'0I"@H@("`@9G5N8W1I;VX@8F]L9"@D
M=&5X="D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/G1E<FU;)V)O
M;&0G72DI('L*("`@("`@("`@("`@<F5T=7)N('-T<G1O=7!P97(H)'1E>'0I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G1E<FU;)V)O;&0G
M72`N("1T97AT("X@)'1H:7,M/G1E<FU;)VYO<FUA;"==.PH@("`@?0H*("`@
M("\O('U]?0I]"@H_/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]$97!E;F1E;F-Y+G!H<```````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#`U,C0`,3`T,3<S-C,P,#8`
M,#(P-C8S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@
M5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@
M=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@
M("`@?`HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P*+R\@?"!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%1O;6%S(%8N5BY#;W@@/&-O>$!I
M9&5C;F5T+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"`@("`@("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($1E<&5N9&5N8WDN<&AP+'8@,2XS
M-B`R,#`T+S`Q+S`X(#$W.C,S.C$R('-N:7!E<B!%>'`@)`H*<F5Q=6ER95]O
M;F-E(")014%2+G!H<"(["@ID969I;F4H)U!%05)?1$5014Y$14Y#65]-25-3
M24Y')RP@("`@("`@("TQ*3L*9&5F:6YE*"=014%27T1%4$5.1$5.0UE?0T].
M1DQ)0U0G+"`@("`@("`M,BD["F1E9FEN92@G4$5!4E]$15!%3D1%3D-97U50
M1U)!1$5?34E.3U(G+"`@+3,I.PID969I;F4H)U!%05)?1$5014Y$14Y#65]5
M4$=2041%7TU!2D]2)RP@("TT*3L*9&5F:6YE*"=014%27T1%4$5.1$5.0UE?
M0D%$7T1%4$5.1$5.0UDG+"`M-2D["F1E9FEN92@G4$5!4E]$15!%3D1%3D-9
M7TU)4U-)3D=?3U!424].04PG+"`M-BD["F1E9FEN92@G4$5!4E]$15!%3D1%
M3D-97T-/3D9,24-47T]05$E/3D%,)RP@("`@("`@+3<I.PID969I;F4H)U!%
M05)?1$5014Y$14Y#65]54$=2041%7TU)3D]27T]05$E/3D%,)RP@("TX*3L*
M9&5F:6YE*"=014%27T1%4$5.1$5.0UE?55!'4D%$15]-04I/4E]/4%1)3TY!
M3"<L("`M.2D["@HO*BH*("H@1&5P96YD96YC>2!C:&5C:R!F;W(@4$5!4B!P
M86-K86=E<PH@*@H@*B!4:&4@8VQA<W,@:7,@8F%S960@;VX@=&AE(&1E<&5N
M9&5N8WD@4D9#('1H870@8V%N(&)E(&9O=6YD(&%T"B`J(&AT='`Z+R]C=G,N
M<&AP+FYE="]C=G,N<&AP+W!E87)W96(O<F9C+B!)="!R97%U:7)E<R!02%`@
M/CT@-"XQ"B`J"B`J($!A=71H;W(@5&]M87,@5BY6+E9O>"`\8V]X0&ED96-N
M970N8V]M/@H@*B!`875T:&]R(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*
M("HO"F-L87-S(%!%05)?1&5P96YD96YC>0I["B`@("`O+R![>WL@8V]N<W1R
M=6-T;W(*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!O8FIE8W0@4F5G:7-T
M<GD@;V)J96-T"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N
M8W1I;VX@4$5!4E]$97!E;F1E;F-Y*"8D<F5G:7-T<GDI"B`@("!["B`@("`@
M("`@)'1H:7,M/G)E9VES=')Y(#T@)B1R96=I<W1R>3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!C86QL0VAE8VM-971H;V0H*0H*("`@("\J*@H@
M("`@*B!4:&ES(&UE=&AO9"!M87!S('1H92!834P@9&5P96YD96YC>2!D969I
M;FET:6]N('1O('1H90H@("`@*B!C;W)R97-P;VYD:6YG(&]N92!F<F]M(%!%
M05)?1&5P96YD96YC>0H@("`@*@H@("`@*B`\<')E/@H@("`@*B`D;W!T<R`]
M/B!!<G)A>0H@("`@*B`@("`H"B`@("`J("`@("`@("!;='EP95T@/3X@<&MG
M"B`@("`J("`@("`@("!;<F5L72`]/B!G90H@("`@*B`@("`@("`@6W9E<G-I
M;VY=(#T^(#,N-`H@("`@*B`@("`@("`@6VYA;65=(#T^($A434Q?0V]M;6]N
M"B`@("`J("`@("`@("!;;W!T:6]N86Q=(#T^(&9A;'-E"B`@("`J("`@("D*
M("`@("H@/"]P<F4^"B`@("`J"B`@("`J($!P87)A;2`@<W1R:6YG($5R<F]R
M(&UE<W-A9V4*("`@("H@0'!A<F%M("!A<G)A>2`@3W!T:6]N<PH@("`@*B!`
M<F5T=7)N(&)O;VQE86X*("`@("HO"B`@("!F=6YC=&EO;B!C86QL0VAE8VM-
M971H;V0H)B1E<G)M<V<L("1O<'1S*0H@("`@>PH@("`@("`@("1R96P@/2!I
M<W-E="@D;W!T<ULG<F5L)UTI(#\@)&]P='-;)W)E;"==(#H@)VAA<R<["B`@
M("`@("`@)')E<2`](&ES<V5T*"1O<'1S6R=V97)S:6]N)UTI(#\@)&]P='-;
M)W9E<G-I;VXG72`Z(&YU;&P["B`@("`@("`@)&YA;64@/2!I<W-E="@D;W!T
M<ULG;F%M92==*2`_("1O<'1S6R=N86UE)UT@.B!N=6QL.PH@("`@("`@("1O
M<'0@/2`H:7-S970H)&]P='-;)V]P=&EO;F%L)UTI("8F("1O<'1S6R=O<'1I
M;VYA;"==(#T]("=Y97,G*2`_"B`@("`@("`@("`@("1O<'1S6R=O<'1I;VYA
M;"==(#H@;G5L;#L*("`@("`@("`D97)R;7-G(#T@)R<["B`@("`@("`@<W=I
M=&-H("@D;W!T<ULG='EP92==*2!["B`@("`@("`@("`@(&-A<V4@)W!K9R<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-H96-K4&%C:V%G92@D
M97)R;7-G+"`D;F%M92P@)')E<2P@)')E;"P@)&]P="D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G97AT)SH*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^8VAE8VM%>'1E;G-I;VXH)&5R<FUS9RP@
M)&YA;64L("1R97$L("1R96PL("1O<'0I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)W!H<"<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F-H96-K4$A0*"1E<G)M<V<L("1R97$L("1R96PI.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)W!R;V<G
M.@H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC:&5C:U!R;V=R86TH
M)&5R<FUS9RP@)&YA;64I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@)V]S)SH*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^8VAE8VM/4R@D97)R;7-G+"`D;F%M92D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@8V%S92`G<V%P:2<Z"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F-H96-K4T%022@D97)R;7-G+"`D;F%M92D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G>F5N9"<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-H96-K6F5N9"@D97)R
M;7-G+"`D;F%M92D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B`B)WLD;W!T<ULG
M='EP92==?2<@9&5P96YD96YC>2!T>7!E(&YO="!S=7!P;W)T960B.PH@("`@
M("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C:&5C:U!A8VMA
M9V4H*0H*("`@("\J*@H@("`@("H@4&%C:V%G92!D97!E;F1E;F-I97,@8VAE
M8VL@;65T:&]D"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D97)R;7-G
M("`@($5M<'1Y('-T<FEN9RP@:70@=VEL;"!B92!P;W!U;&%T960@=VET:"!A
M;B!E<G)O<B!M97-S86=E+"!I9B!A;GD*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@("!.86UE(&]F('1H92!P86-K86=E('1O('1E<W0*("`@("`J
M($!P87)A;2!S=')I;F<@)')E<2`@("`@("!4:&4@<&%C:V%G92!V97)S:6]N
M(')E<75I<F5D"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96QA=&EO;B`@2&]W
M('1O(&-O;7!A<F4@=F5R<VEO;G,@=VET:"!E86-H(&]T:&5R"B`@("`@*B!`
M<&%R86T@8F]O;"`@("1O<'0@("`@("`@5VAE=&AE<B!T:&4@<F5L871I;VYS
M:&EP(&ES(&]P=&EO;F%L"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!B
M;V]L(&9A;'-E(&EF(&YO(&5R<F]R(&]R('1H92!E<G)O<B!S=')I;F<*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VAE8VM086-K86=E*"8D97)R;7-G+"`D;F%M
M92P@)')E<2`](&YU;&PL("1R96QA=&EO;B`]("=H87,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("1O<'0@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H:7-?<W1R:6YG*"1R97$I("8F('-U8G-T<B@D<F5Q+"`P+"`R*2`]/2`G
M=BXG*2!["B`@("`@("`@("`@("1R97$@/2!S=6)S='(H)')E<2P@,BD["B`@
M("`@("`@?0H@("`@("`@('-W:71C:"`H)')E;&%T:6]N*2!["B`@("`@("`@
M("`@(&-A<V4@)VAA<R<Z"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YR
M96=I<W1R>2T^<&%C:V%G945X:7-T<R@D;F%M92DI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&]P="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M97)R;7-G(#T@(G!A8VMA9V4@8"1N86UE)R!I<R!R96-O;6UE;F1E9"!T;R!U
M=&EL:7IE('-O;64@9F5A='5R97,N(CL*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]-25-324Y'7T]05$E/3D%,.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D97)R
M;7-G(#T@(G)E<75I<F5S('!A8VMA9V4@8"1N86UE)R(["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]-25-324Y'.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!C87-E("=N;W0G.@H@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D;F%M92DI('L*("`@("`@
M("`@("`@("`@("`@("`D97)R;7-G(#T@(F-O;F9L:6-T<R!W:71H('!A8VMA
M9V4@8"1N86UE)R(["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05)?
M1$5014Y$14Y#65]#3TY&3$E#5#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@8V%S92`G;'0G
M.@H@("`@("`@("`@("!C87-E("=L92<Z"B`@("`@("`@("`@(&-A<V4@)V5Q
M)SH*("`@("`@("`@("`@8V%S92`G;F4G.@H@("`@("`@("`@("!C87-E("=G
M92<Z"B`@("`@("`@("`@(&-A<V4@)V=T)SH*("`@("`@("`@("`@("`@("1V
M97)S:6]N(#T@)'1H:7,M/G)E9VES=')Y+3YP86-K86=E26YF;R@D;F%M92P@
M)W9E<G-I;VXG*3L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/G)E9VES
M=')Y+3YP86-K86=E17AI<W1S*"1N86UE*0H@("`@("`@("`@("`@("`@("`@
M('Q\("%V97)S:6]N7V-O;7!A<F4H(B1V97)S:6]N(BP@(B1R97$B+"`D<F5L
M871I;VXI*0H@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@
M("1C;V1E(#T@)'1H:7,M/F-O9&5&<F]M4F5L871I;VXH)')E;&%T:6]N+"`D
M=F5R<VEO;BP@)')E<2P@)&]P="D["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1O<'0I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<FUS9R`](")P
M86-K86=E(&`D;F%M92<@=F5R<VEO;B`B("X@)'1H:7,M/G-I9VY/<&5R871O
M<B@D<F5L871I;VXI("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("(@
M)')E<2!I<R!R96-O;6UE;F1E9"!T;R!U=&EL:7IE('-O;64@9F5A='5R97,N
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R;7-G("X]("(@($EN<W1A
M;&QE9"!V97)S:6]N(&ES("1V97)S:6]N(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-O9&4[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1E
M<G)M<V<@/2`B<F5Q=6ER97,@<&%C:V%G92!@)&YA;64G("(@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<VEG;D]P97)A=&]R*"1R96QA=&EO
M;BD@+B`B("1R97$B.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D8V]D
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@)&5R<FUS9R`](")R96QA=&EO;B`G
M)')E;&%T:6]N)R!W:71H(')E<75I<F5M96YT("<D<F5Q)R!I<R!N;W0@<W5P
M<&]R=&5D("AN86UE/21N86UE*2(["B`@("`@("`@<F5T=7)N(%!%05)?1$50
M14Y$14Y#65]"041?1$5014Y$14Y#63L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!C:&5C:U!A8VMA9V55;FEN<W1A;&PH*0H*("`@("\J*@H@("`@
M("H@0VAE8VL@<&%C:V%G92!D97!E;F1E;F-I97,@;VX@=6YI;G-T86QL"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D97)R;W(@("`@(%1H92!R97-U
M;'1A;G0@97)R;W(@<W1R:6YG"B`@("`@*B!`<&%R86T@<W1R:6YG("1W87)N
M:6YG("`@5&AE(')E<W5L=&%N="!W87)N:6YG('-T<FEN9PH@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@($YA;64@;V8@=&AE('!A8VMA9V4@=&\@
M=&5S=`H@("`@("H*("`@("`J($!R971U<FX@8F]O;"!T<G5E(&EF('1H97)E
M('=E<F4@97)R;W)S"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K4&%C:V%G
M955N:6YS=&%L;"@F)&5R<F]R+"`F)'=A<FYI;F<L("1P86-K86=E*0H@("`@
M>PH@("`@("`@("1E<G)O<B`](&YU;&P["B`@("`@("`@)'!A8VMA9V5S(#T@
M)'1H:7,M/G)E9VES=')Y+3YL:7-T4&%C:V%G97,H*3L*("`@("`@("!F;W)E
M86-H("@D<&%C:V%G97,@87,@)'!K9RD@>PH@("`@("`@("`@("!I9B`H)'!K
M9R`]/2`D<&%C:V%G92D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&1E<',@/2`D=&AI<RT^<F5G:7-T
M<GDM/G!A8VMA9V5);F9O*"1P:V<L("=R96QE87-E7V1E<',G*3L*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1D97!S*2D@>PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&1E
M<',@87,@)&1E<"D@>PH@("`@("`@("`@("`@("`@:68@*"1D97!;)W1Y<&4G
M72`]/2`G<&MG)R`F)B!S=')C87-E8VUP*"1D97!;)VYA;64G72P@)'!A8VMA
M9V4I(#T](#`I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<%LG<F5L
M)UT@/3T@)VYE)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D97!;)V]P=&EO;F%L
M)UT@/3T@)WEE<R<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'=A<FYI
M;F<@+CT@(EQN5V%R;FEN9SH@4&%C:V%G92`G)'!K9R<@;W!T:6]N86QL>2!D
M97!E;F1S(&]N("<D<&%C:V%G92<B.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<B`N/2`B4&%C
M:V%G92`G)'!K9R<@9&5P96YD<R!O;B`G)'!A8VMA9V4G7&XB.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@*"1E<G)O<BD@/R!T<G5E(#H@
M9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8VAE8VM%>'1E
M;G-I;VXH*0H*("`@("\J*@H@("`@("H@17AT96YS:6]N(&1E<&5N9&5N8VEE
M<R!C:&5C:R!M971H;V0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("`@("`@("!.86UE(&]F('1H92!E>'1E;G-I;VX@=&\@=&5S=`H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<F5Q7V5X=%]V97(@4F5Q=6ER960@97AT96YS
M:6]N('9E<G-I;VX@=&\@8V]M<&%R92!W:71H"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1R96QA=&EO;B`@("!(;W<@=&\@8V]M<&%R92!V97)S:6]N<R!W:71H
M(&5A8VAO=&AE<@H@("`@("H@0'!A<F%M(&)O;VP@("`D;W!T("`@("`@("`@
M5VAE=&AE<B!T:&4@<F5L871I;VYS:&EP(&ES(&]P=&EO;F%L"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"!B;V]L(&9A;'-E(&EF(&YO(&5R<F]R(&]R
M('1H92!E<G)O<B!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM%
M>'1E;G-I;VXH)B1E<G)M<V<L("1N86UE+"`D<F5Q(#T@;G5L;"P@)')E;&%T
M:6]N(#T@)VAA<R<L"B`@("`@("`@)&]P="`](&9A;'-E*0H@("`@>PH@("`@
M("`@(&EF("@D<F5L871I;VX@/3T@)VYO="<I('L*("`@("`@("`@("`@:68@
M*&5X=&5N<VEO;E]L;V%D960H)&YA;64I*2!["B`@("`@("`@("`@("`@("`D
M97)R;7-G(#T@(F-O;F9L:6-T<R!W:71H("!02%`@97AT96YS:6]N("<D;F%M
M92<B.PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]#
M3TY&3$E#5#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"1N86UE*2D@>PH@("`@("`@("`@
M("!I9B`H)')E;&%T:6]N(#T]("=N92<I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&]P
M="D@>PH@("`@("`@("`@("`@("`@)&5R<FUS9R`]("(G)&YA;64G(%!(4"!E
M>'1E;G-I;VX@:7,@<F5C;VUM96YD960@=&\@=71I;&EZ92!S;VUE(&9E871U
M<F5S(CL*("`@("`@("`@("`@("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?
M34E34TE.1U]/4%1)3TY!3#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M97)R;7-G(#T@(B<D;F%M92<@4$A0(&5X=&5N<VEO;B!I<R!N;W0@:6YS=&%L
M;&5D(CL*("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]-25-3
M24Y'.PH@("`@("`@('T*("`@("`@("!I9B`H)')E;&%T:6]N(#T]("=H87,G
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@
M("`@)&-O9&4@/2!F86QS93L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97$I
M("8F('-U8G-T<B@D<F5Q+"`P+"`R*2`]/2`G=BXG*2!["B`@("`@("`@("`@
M("1R97$@/2!S=6)S='(H)')E<2P@,BD["B`@("`@("`@?0H@("`@("`@("1E
M>'1?=F5R(#T@<&AP=F5R<VEO;B@D;F%M92D["B`@("`@("`@)&]P97)A=&]R
M(#T@)')E;&%T:6]N.PH@("`@("`@("\O($9O<F-E('!A<F%M<R!T;R!B92!S
M=')I;F=S+"!O=&AE<G=I<V4@=&AE(&-O;7!A<F%T:6]N('=I;&P@9F%I;"`H
M97@N(#`N.3T],"XY,"D*("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R92@B
M)&5X=%]V97(B+"`B)')E<2(L("1O<&5R871O<BDI('L*("`@("`@("`@("`@
M)&5R<FUS9R`]("(G)&YA;64G(%!(4"!E>'1E;G-I;VX@=F5R<VEO;B`B("X*
M("`@("`@("`@("`@("`@("1T:&ES+3YS:6=N3W!E<F%T;W(H)&]P97)A=&]R
M*2`N("(@)')E<2!I<R!R97%U:7)E9"(["B`@("`@("`@("`@("1C;V1E(#T@
M)'1H:7,M/F-O9&5&<F]M4F5L871I;VXH)')E;&%T:6]N+"`D97AT7W9E<BP@
M)')E<2P@)&]P="D["B`@("`@("`@("`@(&EF("@D;W!T*2!["B`@("`@("`@
M("`@("`@("`D97)R;7-G(#T@(B<D;F%M92<@4$A0(&5X=&5N<VEO;B!V97)S
M:6]N("(@+B`D=&AI<RT^<VEG;D]P97)A=&]R*"1O<&5R871O<BD@+@H@("`@
M("`@("`@("`@("`@("`@("(@)')E<2!I<R!R96-O;6UE;F1E9"!T;R!U=&EL
M:7IE('-O;64@9F5A='5R97,B.PH@("`@("`@("`@("`@("`@<F5T=7)N("1C
M;V1E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M8V]D93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C:&5C:T]3*"D*
M"B`@("`O*BH*("`@("`J($]P97)A=&EN9R!S>7-T96T@(&1E<&5N9&5N8VEE
M<R!C:&5C:R!M971H;V0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O
M<R`@3F%M92!O9B!T:&4@;W!E<F%T:6YG('-Y<W1E;0H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@8F]O;"!F86QS92!I9B!N;R!E<G)O<B!O<B!T:&4@
M97)R;W(@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K3U,H)B1E
M<G)M<V<L("1O<RD*("`@('L*("`@("`@("`O+R!86%@@1FEX;64Z($EM<&QE
M;65N="!A(&UO<F4@9FQE>&EB;&4@=V%Y+"!L:6ME"B`@("`@("`@+R\@8V]M
M;6$@<V5P87)A=&5D('9A;'5E<R!O<B!S;VUE=&AI;F<@<VEM:6QA<B!T;R!0
M14%27T]3"B`@("`@("`@<W1A=&EC("1M>6]S.PH@("`@("`@(&EF("AE;7!T
M>2@D;7EO<RDI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E(")/4R]'=65S
M<RYP:'`B.PH@("`@("`@("`@("`D;7EO<R`](&YE=R!/4U]'=65S<R@I.PH@
M("`@("`@('T*("`@("`@("`O+R!O;FQY("=H87,G(')E;&%T:6]N(&ES(&-U
M<G)E;G1L>2!S=7!P;W)T960*("`@("`@("!I9B`H)&UY;W,M/FUA=&-H4VEG
M;F%T=7)E*"1O<RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@("`@("`D97)R;7-G(#T@(B<D;W,G(&]P97)A=&EN9R!S>7-T
M96T@;F]T('-U<'!O<G1E9"(["B`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$
M14Y#65]#3TY&3$E#5#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C
M:&5C:U!(4"@I"@H@("`@+RHJ"B`@("`@*B!02%`@=F5R<VEO;B!C:&5C:R!M
M971H;V0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R97$@("!W:&EC
M:"!V97)S:6]N('1O(&-O;7!A<F4*("`@("`J($!P87)A;2!S=')I;F<@)')E
M;&%T:6]N("!H;W<@=&\@8V]M<&%R92!T:&4@=F5R<VEO;@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@8F]O;"!F86QS92!I9B!N;R!E<G)O<B!O<B!T
M:&4@97)R;W(@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K4$A0
M*"8D97)R;7-G+"`D<F5Q+"`D<F5L871I;VX@/2`G9V4G*0H@("`@>PH@("`@
M("`@("\O('1H:7,@=V]U;&0@8F4@82!B:70@<W1U<&ED+"!B=70@;V@@=V5L
M;"`Z*0H@("`@("`@(&EF("@D<F5L871I;VX@/3T@)VAA<R<I('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H)')E
M;&%T:6]N(#T]("=N;W0G*2!["B`@("`@("`@("`@("1E<G)M<V<@/2`B26YV
M86QI9"!D97!E;F1E;F-Y("T@)VYO="<@:7,@86QL;W=E9"!W:&5N('-P96-I
M9GEI;F<@4$A0+"!Y;W4@;75S="!R=6X@4$A0(&EN(%!(4"(["B`@("`@("`@
M("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?0D%$7T1%4$5.1$5.0UD["B`@
M("`@("`@?0H@("`@("`@(&EF("AS=6)S='(H)')E<2P@,"P@,BD@/3T@)W8N
M)RD@>PH@("`@("`@("`@("`D<F5Q(#T@<W5B<W1R*"1R97$L,BP@<W1R;&5N
M*"1R97$I("T@,BD["B`@("`@("`@?0H@("`@("`@("1P:'!?=F5R(#T@<&AP
M=F5R<VEO;B@I.PH@("`@("`@("1O<&5R871O<B`]("1R96QA=&EO;CL*("`@
M("`@("!I9B`H(79E<G-I;VY?8V]M<&%R92@B)'!H<%]V97(B+"`B)')E<2(L
M("1O<&5R871O<BDI('L*("`@("`@("`@("`@)&5R<FUS9R`](")02%`@=F5R
M<VEO;B`B("X@)'1H:7,M/G-I9VY/<&5R871O<B@D;W!E<F%T;W(I("X*("`@
M("`@("`@("`@("`@("(@)')E<2!I<R!R97%U:7)E9"(["B`@("`@("`@("`@
M(')E='5R;B!014%27T1%4$5.1$5.0UE?0T].1DQ)0U0["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!C:&5C:U!R;V=R86TH*0H*("`@("\J*@H@("`@("H@17AT97)N86P@
M<')O9W)A;2!C:&5C:R!M971H;V0N("!,;V]K<R!F;W(@97AE8W5T86)L92!F
M:6QE<R!I;@H@("`@("H@9&ER96-T;W)I97,@;&ES=&5D(&EN('1H92!0051(
M(&5N=FER;VYM96YT('9A<FEA8FQE+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!R;V=R86T@("!W:&EC:"!P<F]G<F%M('1O(&QO;VL@9F]R"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!B;V]L(&9A;'-E(&EF(&YO(&5R
M<F]R(&]R('1H92!E<G)O<B!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VAE8VM0<F]G<F%M*"8D97)R;7-G+"`D<')O9W)A;2D*("`@('L*("`@("`@
M("`O+R!86%@@1DE8344@:&]N;W(@<V%F92!M;V1E"B`@("`@("`@)&5X95]S
M=69F:7@@/2!/4U]724Y$3U=3(#\@)RYE>&4G(#H@)R<["B`@("`@("`@)'!A
M=&A?96QE;65N=',@/2!E>'!L;V1E*%!!5$A?4T5005)!5$]2+"!G971E;G8H
M)U!!5$@G*2D["B`@("`@("`@9F]R96%C:"`H)'!A=&A?96QE;65N=',@87,@
M)&1I<BD@>PH@("`@("`@("`@("`D9FEL92`]("1D:7(@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)'!R;V=R86T@+B`D97AE7W-U9F9I>#L*("`@("`@("`@
M("`@:68@*$!F:6QE7V5X:7-T<R@D9FEL92D@)B8@0&ES7V5X96-U=&%B;&4H
M)&9I;&4I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&5R<FUS9R`]("(G)'!R;V=R
M86TG('!R;V=R86T@:7,@;F]T('!R97-E;G0@:6X@=&AE(%!!5$@B.PH@("`@
M("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?34E34TE.1SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!C:&5C:U-!4$DH*0H*("`@("\J*@H@("`@
M("H@4T%022!B86-K96YD(&-H96-K(&UE=&AO9"X@(%9E<G-I;VX@8V]M<&%R
M:7-O;B!I<R!N;W0@>65T"B`@("`@*B!A=F%I;&%B;&4@:&5R92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@;F%M92!O9B!305!)
M(&)A8VME;F0*("`@("`J($!P87)A;2!S=')I;F<@)')E<2`@('=H:6-H('9E
M<G-I;VX@=&\@8V]M<&%R90H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5L871I
M;VX@(&AO=R!T;R!C;VUP87)E('9E<G-I;VYS("AC=7)R96YT;'D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!H87)D8V]D960@=&\@)VAA<R<I
M"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@9F%L<V4@:68@;F\@97)R;W(@
M;W(@=&AE(&5R<F]R('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!C:&5C
M:U-!4$DH)B1E<G)M<V<L("1N86UE+"`D<F5Q(#T@;G5L;"P@)')E;&%T:6]N
M(#T@)VAA<R<I"B`@("!["B`@("`@("`@+R\@6%A8($9I>&UE.B!4:&5R92!I
M<R!N;R!W87D@=&\@:VYO=R!I9B!T:&4@=7-E<B!H87,@;W(*("`@("`@("`O
M+R!N;W0@;W1H97(@4T%022!B86-K96YD<R!I;G-T86QL960@=&AA;B!T:&4@
M:6YS=&%L;&5R(&]N90H*("`@("`@("`D<V%P:5]B86-K96YD(#T@<&AP7W-A
M<&E?;F%M92@I.PH@("`@("`@("\O(%9E<G-I;VX@8V]M<&%R:7-O;G,@;F]T
M('-U<'!O<G1E9"P@<V%P:2!B86-K96YD<R!D;VXG="!H879E"B`@("`@("`@
M+R\@=F5R<VEO;B!I;F9O<FUA=&EO;B!Y970N"B`@("`@("`@:68@*"1S87!I
M7V)A8VME;F0@/3T@)&YA;64I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@("`@("`D97)R;7-G(#T@(B<D<V%P:5]B86-K96YD
M)R!305!)(&)A8VME;F0@;F]T('-U<'!O<G1E9"(["B`@("`@("`@<F5T=7)N
M(%!%05)?1$5014Y$14Y#65]#3TY&3$E#5#L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!C:&5C:UIE;F0H*0H*("`@("\J*@H@("`@("H@6F5N9"!V
M97)S:6]N(&-H96-K(&UE=&AO9`H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)')E<2`@('=H:6-H('9E<G-I;VX@=&\@8V]M<&%R90H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<F5L871I;VX@(&AO=R!T;R!C;VUP87)E('1H92!V97)S
M:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!B;V]L(&9A;'-E(&EF
M(&YO(&5R<F]R(&]R('1H92!E<G)O<B!S=')I;F<*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VAE8VM:96YD*"8D97)R;7-G+"`D<F5Q+"`D<F5L871I;VX@/2`G
M9V4G*0H@("`@>PH@("`@("`@(&EF("AS=6)S='(H)')E<2P@,"P@,BD@/3T@
M)W8N)RD@>PH@("`@("`@("`@("`D<F5Q(#T@<W5B<W1R*"1R97$L,BP@<W1R
M;&5N*"1R97$I("T@,BD["B`@("`@("`@?0H@("`@("`@("1Z96YD7W9E<B`]
M('IE;F1?=F5R<VEO;B@I.PH@("`@("`@("1O<&5R871O<B`]('-U8G-T<B@D
M<F5L871I;VXL,"PR*3L*("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R92@B
M)'IE;F1?=F5R(BP@(B1R97$B+"`D;W!E<F%T;W(I*2!["B`@("`@("`@("`@
M("1E<G)M<V<@/2`B6F5N9"!V97)S:6]N("(@+B`D=&AI<RT^<VEG;D]P97)A
M=&]R*"1O<&5R871O<BD@+@H@("`@("`@("`@("`@("`@(B`D<F5Q(&ES(')E
M<75I<F5D(CL*("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]#
M3TY&3$E#5#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-I9VY/<&5R871O<B@I"@H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T<R!T97AT(&-O;7!A<FEN9R!O<&5R871O<G,@
M=&\@=&AE;2!S:6=N(&5Q=6EV86QE;G1S"B`@("`@*@H@("`@("H@17AA;7!L
M93H@)V=E)R!T;R`G/CTG"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!P87)A;2`@<W1R:6YG($]P97)A=&]R"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R!3:6=N(&5Q=6EV86QE;G0*("`@("`J+PH@("`@9G5N8W1I;VX@
M<VEG;D]P97)A=&]R*"1O<&5R871O<BD*("`@('L*("`@("`@("!S=VET8V@H
M)&]P97)A=&]R*2!["B`@("`@("`@("`@(&-A<V4@)VQT)SH@<F5T=7)N("<\
M)SL*("`@("`@("`@("`@8V%S92`G;&4G.B!R971U<FX@)SP])SL*("`@("`@
M("`@("`@8V%S92`G9W0G.B!R971U<FX@)SXG.PH@("`@("`@("`@("!C87-E
M("=G92<Z(')E='5R;B`G/CTG.PH@("`@("`@("`@("!C87-E("=E<2<Z(')E
M='5R;B`G/3TG.PH@("`@("`@("`@("!C87-E("=N92<Z(')E='5R;B`G(3TG
M.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N
M("1O<&5R871O<CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@8V]D949R;VU296QA=&EO;B@I"@H@("`@+RHJ"B`@("`@*B!#;VYV
M97)T(')E;&%T:6]N(&EN=&\@8V]R<F5S<&]N9&EN9R!C;V1E"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@<W1R:6YG(%)E
M;&%T:6]N"B`@("`@*B!`<&%R86T@('-T<FEN9R!697)S:6]N"B`@("`@*B!`
M<&%R86T@('-T<FEN9R!297%U:7)E;65N=`H@("`@("H@0'!A<F%M("!B;V]L
M("`@3W!T:6]N86P@9&5P96YD96YC>2!I;F1I8V%T;W(*("`@("`J($!R971U
M<FX@:6YT96=E<@H@("`@("HO"B`@("!F=6YC=&EO;B!C;V1E1G)O;5)E;&%T
M:6]N*"1R96QA=&EO;BP@)'9E<G-I;VXL("1R97$L("1O<'0@/2!F86QS92D*
M("`@('L*("`@("`@("`D8V]D92`](%!%05)?1$5014Y$14Y#65]"041?1$50
M14Y$14Y#63L*("`@("`@("!S=VET8V@@*"1R96QA=&EO;BD@>PH@("`@("`@
M("`@("!C87-E("=G="<Z(&-A<V4@)V=E)SH@8V%S92`G97$G.@H@("`@("`@
M("`@("`@("`@+R\@=7!G<F%D90H@("`@("`@("`@("`@("`@)&AA=F5?;6%J
M;W(@/2!P<F5G7W)E<&QA8V4H)R]<1"XJ+R<L("<G+"`D=F5R<VEO;BD["B`@
M("`@("`@("`@("`@("`D;F5E9%]M86IO<B`]('!R96=?<F5P;&%C92@G+UQ$
M+BHO)RP@)R<L("1R97$I.PH@("`@("`@("`@("`@("`@:68@*"1N965D7VUA
M:F]R(#X@)&AA=F5?;6%J;W(I('L*("`@("`@("`@("`@("`@("`@("`D8V]D
M92`]("1O<'0@/R!014%27T1%4$5.1$5.0UE?55!'4D%$15]-04I/4E]/4%1)
M3TY!3"`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E]$15!%3D1%3D-97U501U)!1$5?34%*3U(["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1C;V1E(#T@)&]P="`_(%!%
M05)?1$5014Y$14Y#65]54$=2041%7TU)3D]27T]05$E/3D%,(#H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T1%4$5.1$5.0UE?
M55!'4D%$15]-24Y/4CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=L="<Z(&-A<V4@)VQE)SH@
M8V%S92`G;F4G.@H@("`@("`@("`@("`@("`@)&-O9&4@/2`D;W!T(#\@4$5!
M4E]$15!%3D1%3D-97T-/3D9,24-47T]05$E/3D%,(#H*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05)?1$5014Y$14Y#65]#3TY&3$E#5#L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&-O9&4["B`@("!]"@H@("`@+R\@?7U]"GT*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+U)E;6]T92YP:'``````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`S,S,W,``Q,#0Q-S,V,S`P-@`P,C`P-#$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0
M(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!296UO=&4N<&AP+'8@
M,2XT.2`R,#`T+S`Q+S`X(#$W.C,S.C$R('-N:7!E<B!%>'`@)`H*<F5Q=6ER
M95]O;F-E("=014%2+G!H<"<["G)E<75I<F5?;VYC92`G4$5!4B]#;VYF:6<N
M<&AP)SL*"B\J*@H@*B!4:&ES(&ES(&$@8VQA<W,@9F]R(&1O:6YG(')E;6]T
M92!O<&5R871I;VYS(&%G86EN<W0@=&AE(&-E;G1R86P*("H@4$5!4B!D871A
M8F%S92X*("H*("H@0&YO9&5P(%A-3%]24$-?5F%L=64*("H@0&YO9&5P(%A-
M3%]24$-?365S<V%G90H@*B!`;F]D97`@6$U,7U)00U]#;&EE;G0*("HO"F-L
M87-S(%!%05)?4F5M;W1E(&5X=&5N9',@4$5!4@I["B`@("`O+R![>WL@<')O
M<&5R=&EE<PH*("`@('9A<B`D8V]N9FEG(#T@;G5L;#L*("`@('9A<B`D8V%C
M:&4@(#T@;G5L;#L*"B`@("`O+R!]?7T*"B`@("`O+R![>WL@4$5!4E]296UO
M=&4H8V]N9FEG7V]B:F5C="D*"B`@("!F=6YC=&EO;B!014%27U)E;6]T92@F
M)&-O;F9I9RD*("`@('L*("`@("`@("`D=&AI<RT^4$5!4B@I.PH@("`@("`@
M("1T:&ES+3YC;VYF:6<@/2`F)&-O;F9I9SL*("`@('T*"B`@("`O+R!]?7T*
M"B`@("`O+R![>WL@9V5T0V%C:&4H*0H*"B`@("!F=6YC=&EO;B!G971#86-H
M92@D87)G<RD*("`@('L*("`@("`@("`D:60@("`@("`@/2!M9#4H<V5R:6%L
M:7IE*"1A<F=S*2D["B`@("`@("`@)&-A8VAE9&ER(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=C86-H95]D:7(G*3L*("`@("`@("`D9FEL96YA;64@/2`D8V%C
M:&5D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)WAM;')P8U]C86-H95\G
M("X@)&ED.PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&5N86UE*2D@
M>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!].PH*("`@("`@
M("`D9G`@/2!F;W!E;B@D9FEL96YA;64L("=R8B<I.PH@("`@("`@(&EF("@A
M)&9P*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@
M("`@("`D8V]N=&5N="`@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F:6QE;F%M
M92DI.PH@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("1R97-U;'0@("`]
M(&%R<F%Y*`H@("`@("`@("`@("`G86=E)R`@("`@("`@/3X@=&EM92@I("T@
M9FEL96UT:6UE*"1F:6QE;F%M92DL"B`@("`@("`@("`@("=L87-T0VAA;F=E
M)R`]/B!F:6QE;71I;64H)&9I;&5N86UE*2P*("`@("`@("`@("`@)V-O;G1E
M;G0G("`@(#T^('5N<V5R:6%L:7IE*"1C;VYT96YT*2P*("`@("`@("`@("`@
M*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*
M"B`@("`O+R![>WL@<V%V94-A8VAE*"D*"B`@("!F=6YC=&EO;B!S879E0V%C
M:&4H)&%R9W,L("1D871A*0H@("`@>PH@("`@("`@("1I9"`@("`@("`](&UD
M-2AS97)I86QI>F4H)&%R9W,I*3L*("`@("`@("`D8V%C:&5D:7(@/2`D=&AI
M<RT^8V]N9FEG+3YG970H)V-A8VAE7V1I<B<I.PH@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)&-A8VAE9&ER*2D@>PH@("`@("`@("`@("!3>7-T96TZ.FUK
M9&ER*&%R<F%Y*"<M<"<L("1C86-H961I<BDI.PH@("`@("`@('T*("`@("`@
M("`D9FEL96YA;64@/2`D8V%C:&5D:7(N)R]X;6QR<&-?8V%C:&5?)RXD:60[
M"@H@("`@("`@("1F<"`]($!F;W!E;B@D9FEL96YA;64L(")W8B(I.PH@("`@
M("`@(&EF("@D9G`I('L*("`@("`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L
M:7IE*"1D871A*2D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@
M('T["B`@("!]"@H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-A;&PH;65T:&]D
M+"!;87)G<RXN+ETI"@H@("`@9G5N8W1I;VX@8V%L;"@D;65T:&]D*0H@("`@
M>PH@("`@("`@("1?87)G<R`]("1A<F=S(#T@9G5N8U]G971?87)G<R@I.PH*
M("`@("`@("`D=&AI<RT^8V%C:&4@/2`D=&AI<RT^9V5T0V%C:&4H)&%R9W,I
M.PH@("`@("`@("1C86-H971T;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C
M:&5?='1L)RD["B`@("`@("`@+R\@268@8V%C:&4@:7,@;F5W97(@=&AA;B`D
M8V%C:&5T=&P@<V5C;VYD<RP@=V4@=7-E('1H92!C86-H92$*("`@("`@("!I
M9B`H)'1H:7,M/F-A8VAE("$]/2!N=6QL("8F("1T:&ES+3YC86-H95LG86=E
M)UT@/"`D8V%C:&5T=&PI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC
M86-H95LG8V]N=&5N="==.PH@("`@("`@('T["@H@("`@("`@(&EF("AE>'1E
M;G-I;VY?;&]A9&5D*")X;6QR<&,B*2D@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH)B1T:&ES+"`G8V%L;%]E
M<&DG*2P@)&%R9W,I.PH@("`@("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H
M)')E<W5L="DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS879E0V%C:&4H
M)%]A<F=S+"`D<F5S=6QT*3L*("`@("`@("`@("`@?3L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(&EF("@A0&EN8VQU
M9&5?;VYC92@B6$U,+U)00RYP:'`B*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(D9O<B!T:&ES(')E;6]T92!014%2(&]P97)A
M=&EO;B!Y;W4@;F5E9"!T;R!I;G-T86QL('1H92!834Q?4E!#('!A8VMA9V4B
M*3L*("`@("`@("!]"B`@("`@("`@87)R87E?<VAI9G0H)&%R9W,I.PH@("`@
M("`@("1S97)V97)?:&]S="`]("1T:&ES+3YC;VYF:6<M/F=E="@G;6%S=&5R
M7W-E<G9E<B<I.PH@("`@("`@("1U<V5R;F%M92`]("1T:&ES+3YC;VYF:6<M
M/F=E="@G=7-E<FYA;64G*3L*("`@("`@("`D<&%S<W=O<F0@/2`D=&AI<RT^
M8V]N9FEG+3YG970H)W!A<W-W;W)D)RD["B`@("`@("`@)&5A<F=S(#T@87)R
M87DH*3L*("`@("`@("!F;W)E86-H*"1A<F=S(&%S("1A<F<I("1E87)G<UM=
M(#T@)'1H:7,M/E]E;F-O9&4H)&%R9RD["B`@("`@("`@)&8@/2!N97<@6$U,
M7U)00U]-97-S86=E*"1M971H;V0L("1E87)G<RD["B`@("`@("`@:68@*"1T
M:&ES+3YC86-H92`A/3T@;G5L;"D@>PH@("`@("`@("`@("`D;6%X06=E(#T@
M)S]M87A!9V4])RXD=&AI<RT^8V%C:&5;)VQA<W1#:&%N9V4G73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;6%X06=E(#T@)R<["B`@("`@("`@
M?3L*("`@("`@("`D<')O>'E?:&]S="`]("1P<F]X>5]P;W)T(#T@)'!R;WAY
M7W5S97(@/2`D<')O>'E?<&%S<R`]("<G.PH@("`@("`@(&EF("@D<')O>'D@
M/2!P87)S95]U<FPH)'1H:7,M/F-O;F9I9RT^9V5T*"=H='1P7W!R;WAY)RDI
M*2!["B`@("`@("`@("`@("1P<F]X>5]H;W-T(#T@0"1P<F]X>5LG:&]S="==
M.PH@("`@("`@("`@("`D<')O>'E?<&]R="`]($`D<')O>'E;)W!O<G0G73L*
M("`@("`@("`@("`@)'!R;WAY7W5S97(@/2!`)'!R;WAY6R=U<V5R)UT["B`@
M("`@("`@("`@("1P<F]X>5]P87-S(#T@0"1P<F]X>5LG<&%S<R==.PH@("`@
M("`@('T*("`@("`@("`D8R`](&YE=R!834Q?4E!#7T-L:65N="@G+WAM;')P
M8RYP:'`G+B1M87A!9V4L("1S97)V97)?:&]S="P@.#`L("1P<F]X>5]H;W-T
M+"`D<')O>'E?<&]R="P@)'!R;WAY7W5S97(L("1P<F]X>5]P87-S*3L*("`@
M("`@("!I9B`H)'5S97)N86UE("8F("1P87-S=V]R9"D@>PH@("`@("`@("`@
M("`D8RT^<V5T0W)E9&5N=&EA;',H)'5S97)N86UE+"`D<&%S<W=O<F0I.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B
M;W-E)RD@/CT@,RD@>PH@("`@("`@("`@("`D8RT^<V5T1&5B=6<H,2D["B`@
M("`@("`@?0H@("`@("`@("1R(#T@)&,M/G-E;F0H)&8I.PH@("`@("`@(&EF
M("@A)'(I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")834Q?4E!#('-E;F0@9F%I;&5D(BD["B`@("`@("`@?0H@("`@("`@("1V
M(#T@)'(M/G9A;'5E*"D["B`@("`@("`@:68@*"1E(#T@)'(M/F9A=6QT0V]D
M92@I*2!["B`@("`@("`@("`@(&EF("@D92`]/2`D1TQ/0D%,4ULG6$U,7U)0
M0U]E<G(G75LG:'1T<%]E<G)O<B==("8F('-T<G-T<B@D<BT^9F%U;'13=')I
M;F<H*2P@)S,P-"!.;W0@36]D:69I960G*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^8V%C:&5;)V-O;G1E;G0G73L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)'(M/F9A=6QT4W1R:6YG*"DL("1E*3L*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'0@/2!834Q?4E!#7V1E8V]D92@D=BD["B`@("`@("`@)'1H:7,M
M/G-A=F5#86-H92@D7V%R9W,L("1R97-U;'0I.PH@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@?0H*("`@("\O('U]?0H*("`@("\O('M[>R!C86QL7V5P
M:2AM971H;V0L(%MA<F=S+BXN72D*"B`@("!F=6YC=&EO;B!C86QL7V5P:2@D
M;65T:&]D*0H@("`@>PH@("`@("`@(&1O('L*("`@("`@("`@("`@:68@*&5X
M=&5N<VEO;E]L;V%D960H(GAM;')P8R(I*2!["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H3U-?5TE.1$]7
M4RD@>PH@("`@("`@("`@("`@("`@)&5X="`]("=D;&PG.PH@("`@("`@("`@
M("!](&5L<V5I9B`H4$A07T]3(#T]("=(4"U56"<I('L*("`@("`@("`@("`@
M("`@("1E>'0@/2`G<VPG.PH@("`@("`@("`@("!](&5L<V5I9B`H4$A07T]3
M(#T]("=!25@G*2!["B`@("`@("`@("`@("`@("`D97AT(#T@)V$G.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&5X="`]("=S;R<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5X="`]($]37U=)3D1/5U,@
M/R`G9&QL)R`Z("=S;R<["B`@("`@("`@("`@($!D;"@B>&UL<G!C+65P:2XD
M97AT(BD["B`@("`@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*")X;6QR
M<&,B*2D@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@0&1L*")X;6QR<&,N)&5X="(I.PH@("`@("`@("`@("!I
M9B`H97AT96YS:6]N7VQO861E9"@B>&UL<G!C(BDI('L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B=6YA8FQE('1O(&QO860@>&UL<G!C(&5X=&5N
M<VEO;B(I.PH@("`@("`@('T@=VAI;&4@*&9A;'-E*3L*("`@("`@("`D<&%R
M86US(#T@9G5N8U]G971?87)G<R@I.PH@("`@("`@(&%R<F%Y7W-H:69T*"1P
M87)A;7,I.PH@("`@("`@("1M971H;V0@/2!S=')?<F5P;&%C92@B7R(L("(N
M(BP@)&UE=&AO9"D["B`@("`@("`@)')E<75E<W0@/2!X;6QR<&-?96YC;V1E
M7W)E<75E<W0H)&UE=&AO9"P@)'!A<F%M<RD["B`@("`@("`@)'-E<G9E<E]H
M;W-T(#T@)'1H:7,M/F-O;F9I9RT^9V5T*")M87-T97)?<V5R=F5R(BD["B`@
M("`@("`@:68@*&5M<'1Y*"1S97)V97)?:&]S="DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")014%27U)E;6]T93HZ8V%L;#H@
M;F\@;6%S=&5R7W-E<G9E<B!C;VYF:6=U<F5D(BD["B`@("`@("`@?0H@("`@
M("`@("1S97)V97)?<&]R="`](#@P.PH@("`@("`@(&EF("@D:'1T<%]P<F]X
M>2`]("1T:&ES+3YC;VYF:6<M/F=E="@G:'1T<%]P<F]X>2<I*2!["B`@("`@
M("`@("`@("1P<F]X>2`]('!A<G-E7W5R;"@D:'1T<%]P<F]X>2D["B`@("`@
M("`@("`@("1P<F]X>5]H;W-T(#T@)'!R;WAY7W!O<G0@/2`D<')O>'E?=7-E
M<B`]("1P<F]X>5]P87-S(#T@)R<["B`@("`@("`@("`@("1P<F]X>5]H;W-T
M(#T@0"1P<F]X>5LG:&]S="==.PH@("`@("`@("`@("`D<')O>'E?<&]R="`]
M($`D<')O>'E;)W!O<G0G73L*("`@("`@("`@("`@)'!R;WAY7W5S97(@/2!`
M)'!R;WAY6R=U<V5R)UT["B`@("`@("`@("`@("1P<F]X>5]P87-S(#T@0"1P
M<F]X>5LG<&%S<R==.PH@("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1P
M<F]X>5]H;W-T+"`D<')O>'E?<&]R="D["B`@("`@("`@("`@("1U<V5?<')O
M>'D@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1U<V5?
M<')O>'D@/2!F86QS93L*("`@("`@("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D
M<V5R=F5R7VAO<W0L("1S97)V97)?<&]R="D["B`@("`@("`@?0H@("`@("`@
M(&EF("@A)&9P("8F("1H='1P7W!R;WAY*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]296UO=&4Z.F-A;&PZ(&9S;V-K
M;W!E;BA@)'!R;WAY7VAO<W0G+"`D<')O>'E?<&]R="D@9F%I;&5D(BD["B`@
M("`@("`@?2!E;'-E:68@*"$D9G`I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")014%27U)E;6]T93HZ8V%L;#H@9G-O8VMO<&5N
M*&`D<V5R=F5R7VAO<W0G+"`D<V5R=F5R7W!O<G0I(&9A:6QE9"(I.PH@("`@
M("`@('T*("`@("`@("`D;&5N(#T@<W1R;&5N*"1R97%U97-T*3L*("`@("`@
M("`D<F5Q7VAE861E<G,@/2`B2&]S=#H@)'-E<G9E<E]H;W-T.B1S97)V97)?
M<&]R=%QR7&XB("X*("`@("`@("`@("`@(")#;VYT96YT+71Y<&4Z('1E>'0O
M>&UL7')<;B(@+@H@("`@("`@("`@("`@(D-O;G1E;G0M;&5N9W1H.B`D;&5N
M7')<;B(["B`@("`@("`@)'5S97)N86UE(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"=U<V5R;F%M92<I.PH@("`@("`@("1P87-S=V]R9"`]("1T:&ES+3YC;VYF
M:6<M/F=E="@G<&%S<W=O<F0G*3L*("`@("`@("!I9B`H)'5S97)N86UE("8F
M("1P87-S=V]R9"D@>PH@("`@("`@("`@("`D<F5Q7VAE861E<G,@+CT@(D-O
M;VMI93H@4$5!4E]54T52/21U<V5R;F%M93L@4$5!4E]05STD<&%S<W=O<F1<
M<EQN(CL*("`@("`@("`@("`@)'1M<"`](&)A<V4V-%]E;F-O9&4H(B1U<V5R
M;F%M93HD<&%S<W=O<F0B*3L*("`@("`@("`@("`@)')E<5]H96%D97)S("X]
M(")!=71H;W)I>F%T:6]N.B!"87-I8R`D=&UP7')<;B(["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^8V%C:&4@(3T](&YU;&PI('L*("`@("`@("`@
M("`@)&UA>$%G92`]("<_;6%X06=E/2<N)'1H:7,M/F-A8VAE6R=L87-T0VAA
M;F=E)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UA>$%G92`]
M("<G.PH@("`@("`@('T["@H@("`@("`@(&EF("@D=7-E7W!R;WAY("8F("1P
M<F]X>5]H;W-T("$]("<G("8F("1P<F]X>5]U<V5R("$]("<G*2!["B`@("`@
M("`@("`@("1R97%?:&5A9&5R<R`N/2`G4')O>'DM075T:&]R:7IA=&EO;CH@
M0F%S:6,@)PH@("`@("`@("`@("`@("`@+F)A<V4V-%]E;F-O9&4H)'!R;WAY
M7W5S97(N)SHG+B1P<F]X>5]P87-S*0H@("`@("`@("`@("`@("`@+B)<<EQN
M(CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H
M)W9E<F)O<V4G*2`^(#,I('L*("`@("`@("`@("`@<')I;G0@(EA-3%)00R!2
M15%515-4($A%041%4E,Z7&XB.PH@("`@("`@("`@("!V87)?9'5M<"@D<F5Q
M7VAE861E<G,I.PH@("`@("`@("`@("!P<FEN="`B6$U,4E!#(%)%455%4U0@
M0D]$63I<;B(["B`@("`@("`@("`@('9A<E]D=6UP*"1R97%U97-T*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D=7-E7W!R;WAY("8F("1P<F]X>5]H;W-T
M("$]("<G*2!["B`@("`@("`@("`@("1P;W-T7W-T<FEN9R`](")03U-4(&AT
M='`Z+R\B+B1S97)V97)?:&]S=#L*("`@("`@("`@("`@:68@*"1P<F]X>5]P
M;W)T(#X@)R<I('L*("`@("`@("`@("`@("`@("1P;W-T7W-T<FEN9R`N/2`G
M.B<N)'-E<G9E<E]P;W)T.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'!O<W1?<W1R:6YG(#T@(E!/4U0@(CL*("`@("`@
M("!]"@H@("`@("`@(&9W<FET92@D9G`L("@D<&]S=%]S=')I;F<N(B]X;6QR
M<&,N<&AP)&UA>$%G92!(5%10+S$N,%QR7&XD<F5Q7VAE861E<G-<<EQN)')E
M<75E<W0B*2D["B`@("`@("`@)')E<W!O;G-E(#T@)R<["B`@("`@("`@)&QI
M;F4Q(#T@9F=E=',H)&9P+"`R,#0X*3L*("`@("`@("!I9B`H(7!R96=?;6%T
M8V@H)R%>2%144"];,"TY7"Y=*R`H7&0K*2`H+BHI(2<L("1L:6YE,2P@)&UA
M=&-H97,I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B4$5!4E]296UO=&4Z(&EN=F%L:60@2%144"!R97-P;VYS92!F<F]M(%A-
M3"U24$,@<V5R=F5R(BD["B`@("`@("`@?0H@("`@("`@('-W:71C:"`H)&UA
M=&-H97-;,5TI('L*("`@("`@("`@("`@8V%S92`B,C`P(CH@+R\@3TL*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("(S,#0B.B`O
M+R!.;W0@36]D:69I960*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M8V%C:&5;)V-O;G1E;G0G73L*("`@("`@("`@("`@8V%S92`B-#`Q(CH@+R\@
M56YA=71H;W)I>F5D"B`@("`@("`@("`@("`@("!I9B`H)'5S97)N86UE("8F
M("1P87-S=V]R9"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B4$5!4E]296UO=&4Z(&%U=&AO<FEZ871I;VX@9F%I
M;&5D(BP@-#`Q*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")014%27U)E
M;6]T93H@875T:&]R:7IA=&EO;B!R97%U:7)E9"P@<&QE87-E(&QO9R!I;B!F
M:7)S="(L(#0P,2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(E!%05)?4F5M;W1E.B!U;F5X<&5C=&5D($A45%`@<F5S<&]N<V4B+"`H
M:6YT*21M871C:&5S6S%=+"!N=6QL+"!N=6QL+"`B)&UA=&-H97-;,5T@)&UA
M=&-H97-;,ETB*3L*("`@("`@("!]"B`@("`@("`@=VAI;&4@*'1R:6TH9F=E
M=',H)&9P+"`R,#0X*2D@(3T@)R<I.R`O+R!S:VEP(')E<W0@;V8@:&5A9&5R
M<PH@("`@("`@('=H:6QE("@D8VAU;FL@/2!F<F5A9"@D9G`L(#$P,C0P*2D@
M>PH@("`@("`@("`@("`D<F5S<&]N<V4@+CT@)&-H=6YK.PH@("`@("`@('T*
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!I9B`H)'1H:7,M/F-O;F9I
M9RT^9V5T*"=V97)B;W-E)RD@/B`S*2!["B`@("`@("`@("`@('!R:6YT(")8
M34Q24$,@4D534$].4T4Z7&XB.PH@("`@("`@("`@("!V87)?9'5M<"@D<F5S
M<&]N<V4I.PH@("`@("`@('T*("`@("`@("`D<F5T(#T@>&UL<G!C7V1E8V]D
M92@D<F5S<&]N<V4I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T*2`F)B!I
M<W-E="@D<F5T6R=?7U!%05)?5%E015]?)UTI*2!["B`@("`@("`@("`@(&EF
M("@D<F5T6R=?7U!%05)?5%E015]?)UT@/3T@)V5R<F]R)RD@>PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1R971;)U]?4$5!4E]#3$%34U]?)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&-L87-S(#T@)')E=%LG7U]014%27T-,
M05-37U\G73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&-L87-S(#T@(E!%05)?17)R;W(B.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*"1R971;)V-O9&4G72`@("`@/3T]
M("<G*2`D<F5T6R=C;V1E)UT@("`@(#T@;G5L;#L*("`@("`@("`@("`@("`@
M(&EF("@D<F5T6R=M97-S86=E)UT@(#T]/2`G)RD@)')E=%LG;65S<V%G92==
M("`](&YU;&P["B`@("`@("`@("`@("`@("!I9B`H)')E=%LG=7-E<FEN9F\G
M72`]/3T@)R<I("1R971;)W5S97)I;F9O)UT@/2!N=6QL.PH@("`@("`@("`@
M("`@("`@:68@*'-T<G1O;&]W97(H)&-L87-S*2`]/2`G9&)?97)R;W(G*2![
M"B`@("`@("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3YR86ES945R<F]R
M*%!%05(Z.F5R<F]R365S<V%G92@D<F5T6R=C;V1E)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T6R=C;V1E
M)UTL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R971;)W5S97)I;F9O)UTI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)'1H
M:7,M/G)A:7-E17)R;W(H)')E=%LG;65S<V%G92==+"`D<F5T6R=C;V1E)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&YU;&PL(&YU;&PL("1R971;)W5S97)I;F9O)UTI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y
M*"1R970I("8F('-I>F5O9B@D<F5T*2`]/2`Q("8F(&ES<V5T*"1R971;,%TI
M"B`@("`@("`@("`@("`@("`@("8F(&ES7V%R<F%Y*"1R971;,%TI("8F"B`@
M("`@("`@("`@("`@("`@("%E;7!T>2@D<F5T6S!=6R=F875L=%-T<FEN9R==
M*2`F)@H@("`@("`@("`@("`@("`@("`A96UP='DH)')E=%LP75LG9F%U;'1#
M;V1E)UTI*2!["B`@("`@("`@("`@(&5X=')A8W0H)')E=%LP72D["B`@("`@
M("`@("`@("1F875L=%-T<FEN9R`](")834PM4E!#(%-E<G9E<B!&875L=#H@
M(B`N"B`@("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H(EQN(BP@(B`B+"`D
M9F%U;'13=')I;F<I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)&9A=6QT4W1R:6YG+"`D9F%U;'1#;V1E*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"@H@("`@+R\@
M>WM[(%]E;F-O9&4*"B`@("`O+R!A('-L:6=H=&QY(&5X=&5N9&5D('9E<G-I
M;VX@;V8@6$U,7U)00U]E;F-O9&4*("`@(&9U;F-T:6]N(%]E;F-O9&4H)'!H
M<%]V86PI"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?4E!#7T)O;VQE86XL
M("1834Q?4E!#7TEN="P@)%A-3%]24$-?1&]U8FQE.PH@("`@("`@(&=L;V)A
M;"`D6$U,7U)00U]3=')I;F<L("1834Q?4E!#7T%R<F%Y+"`D6$U,7U)00U]3
M=')U8W0["@H@("`@("`@("1T>7!E(#T@9V5T='EP92@D<&AP7W9A;"D["B`@
M("`@("`@)'AM;')P8W9A;"`](&YE=R!834Q?4E!#7U9A;'5E.PH*("`@("`@
M("!S=VET8V@H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`B87)R87DB.@H@
M("`@("`@("`@("`@("`@<F5S970H)'!H<%]V86PI.PH@("`@("`@("`@("`@
M("`@)&9I<G-T:V5Y(#T@:V5Y*"1P:'!?=F%L*3L*("`@("`@("`@("`@("`@
M(&5N9"@D<&AP7W9A;"D["B`@("`@("`@("`@("`@("`D;&%S=&ME>2`](&ME
M>2@D<&AP7W9A;"D["B`@("`@("`@("`@("`@("!I9B`H)&9I<G-T:V5Y(#T]
M/2`P("8F(&ES7VEN="@D;&%S=&ME>2D@)B8*("`@("`@("`@("`@("`@("`@
M("`H)&QA<W1K97D@*R`Q*2`]/2!C;W5N="@D<&AP7W9A;"DI('L*("`@("`@
M("`@("`@("`@("`@("`D:7-?8V]N=&EN=6]U<R`]('1R=64["B`@("`@("`@
M("`@("`@("`@("`@<F5S970H)'!H<%]V86PI.PH@("`@("`@("`@("`@("`@
M("`@("1S:7IE(#T@8V]U;G0H)'!H<%]V86PI.PH@("`@("`@("`@("`@("`@
M("`@(&9O<B`H)&5X<&5C="`](#`[("1E>'!E8W0@/"`D<VEZ93L@)&5X<&5C
M="LK+"!N97AT*"1P:'!?=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:V5Y*"1P:'!?=F%L*2`A/3T@)&5X<&5C="D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&ES7V-O;G1I;G5O=7,@/2!F86QS93L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D:7-?8V]N=&EN=6]U<RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!R97-E="@D<&AP7W9A;"D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1A<G(@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!W:&EL92`H;&ES="@D:RP@)'8I(#T@96%C:"@D<&AP7W9A;"DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A<G);)&M=(#T@)'1H:7,M/E]E
M;F-O9&4H)'8I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("1X;6QR<&-V86PM/F%D9$%R<F%Y*"1A<G(I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`O+R!F
M86QL('1H;W5G:"!I9B!N;W0@;G5M97)I8V%L(&%N9"!C;VYT:6YU;W5S"B`@
M("`@("`@("`@(&-A<V4@(F]B:F5C="(Z"B`@("`@("`@("`@("`@("`D87)R
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('=H:6QE("AL:7-T*"1K+"`D
M=BD@/2!E86-H*"1P:'!?=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("1A
M<G);)&M=(#T@)'1H:7,M/E]E;F-O9&4H)'8I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'AM;')P8W9A;"T^861D4W1R=6-T*"1A<G(I
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(FEN
M=&5G97(B.@H@("`@("`@("`@("`@("`@)'AM;')P8W9A;"T^861D4V-A;&%R
M*"1P:'!?=F%L+"`D6$U,7U)00U]);G0I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@(F1O=6)L92(Z"B`@("`@("`@("`@("`@
M("`D>&UL<G!C=F%L+3YA9&138V%L87(H)'!H<%]V86PL("1834Q?4E!#7T1O
M=6)L92D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92`B<W1R:6YG(CH*("`@("`@("`@("`@8V%S92`B3E5,3"(Z"B`@("`@("`@
M("`@("`@("`D>&UL<G!C=F%L+3YA9&138V%L87(H)'!H<%]V86PL("1834Q?
M4E!#7U-T<FEN9RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`B8F]O;&5A;B(Z"B`@("`@("`@("`@("`@("`D>&UL<G!C=F%L
M+3YA9&138V%L87(H)'!H<%]V86PL("1834Q?4E!#7T)O;VQE86XI.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(G5N:VYO=VX@
M='EP92(Z"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1X;6QR<&-V
M86P["B`@("!]"@H@("`@+R\@?7U]"@I]"@H_/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]#;VYF:6<N<&AP````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`Q,#0P,C8`,3`T,3<S-C,P,#8`,#(P,#$P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!6
M97)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($%U=&AO<CH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@0V]N9FEG+G!H<"QV(#$N
M-3(@,C`P-"\P,2\P."`Q-SHS,SHQ,B!S;FEP97(@17AP("0*"G)E<75I<F5?
M;VYC92`G4$5!4BYP:'`G.PIR97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PH*
M+RHJ"B`J($QA<W0@8W)E871E9"!014%27T-O;F9I9R!I;G-T86YC92X*("H@
M0'9A<B!O8FIE8W0*("HO"B1'3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS=&%N
M8V4G72`](&YU;&P["FEF("@A9&5F:6YE9"@G4$5!4E])3E-404Q,7T1)4B<I
M('Q\("%014%27TE.4U1!3$Q?1$E2*2!["B`@("`D4$5!4E])3E-404Q,7T1)
M4B`](%!(4%],24)$25(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!E87(G
M.PI](&5L<V4@>PH@("`@)%!%05)?24Y35$%,3%]$25(@/2!014%27TE.4U1!
M3$Q?1$E2.PI]"@HO+R!"96QO=R!W92!D969I;F4@8V]N<W1A;G1S('=I=&@@
M9&5F875L="!V86QU97,@9F]R(&%L;"!C;VYF:6=U<F%T:6]N"B\O('!A<F%M
M971E<G,@97AC97!T('5S97)N86UE+W!A<W-W;W)D+B`@06QL(&]F('1H96T@
M8V%N(&AA=F4@=&AE:7(*+R\@9&5F875L=',@<V5T('1H<F]U9V@@96YV:7)O
M;FUE;G0@=F%R:6%B;&5S+B`@5&AE(')E87-O;B!W92!U<V4@=&AE"B\O(%!(
M4%\@<')E9FEX(&ES(&9O<B!S;VUE('-E8W5R:71Y+"!02%`@<')O=&5C=',@
M96YV:7)O;FUE;G0*+R\@=F%R:6%B;&5S('-T87)T:6YG('=I=&@@4$A07RHN
M"@II9B`H9V5T96YV*"=02%!?4$5!4E]365-#3TY&7T1)4B<I*2!["B`@("!D
M969I;F4H)U!%05)?0T].1DE'7U-94T-/3D9$25(G+"!G971E;G8H)U!(4%]0
M14%27U-94T-/3D9?1$E2)RDI.PI](&5L<V5I9B`H9V5T96YV*"=3>7-T96U2
M;V]T)RDI('L*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?4UE30T].1D1)4B<L
M(&=E=&5N=B@G4WES=&5M4F]O="<I*3L*?2!E;'-E('L*("`@(&1E9FEN92@G
M4$5!4E]#3TY&24=?4UE30T].1D1)4B<L(%!(4%]365-#3TY&1$E2*3L*?0H*
M+R\@1&5F875L="!F;W(@;6%S=&5R7W-E<G9E<@II9B`H9V5T96YV*"=02%!?
M4$5!4E]-05-415)?4T525D52)RDI('L*("`@(&1E9FEN92@G4$5!4E]#3TY&
M24=?1$5&055,5%]-05-415)?4T525D52)RP@9V5T96YV*"=02%!?4$5!4E]-
M05-415)?4T525D52)RDI.PI](&5L<V4@>PH@("`@9&5F:6YE*"=014%27T-/
M3D9)1U]$149!54Q47TU!4U1%4E]315)615(G+"`G<&5A<BYP:'`N;F5T)RD[
M"GT*"B\O($1E9F%U;'0@9F]R(&AT='!?<')O>'D*:68@*&=E=&5N=B@G4$A0
M7U!%05)?2%144%]04D]862<I*2!["B`@("!D969I;F4H)U!%05)?0T].1DE'
M7T1%1D%53%1?2%144%]04D]862<L(&=E=&5N=B@G4$A07U!%05)?2%144%]0
M4D]862<I*3L*?2!E;'-E:68@*&=E=&5N=B@G:'1T<%]P<F]X>2<I*2!["B`@
M("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?2%144%]04D]862<L(&=E
M=&5N=B@G:'1T<%]P<F]X>2<I*3L*?2!E;'-E('L*("`@(&1E9FEN92@G4$5!
M4E]#3TY&24=?1$5&055,5%](5%107U!23UA9)RP@)R<I.PI]"@HO+R!$969A
M=6QT(&9O<B!P:'!?9&ER"FEF("AG971E;G8H)U!(4%]014%27TE.4U1!3$Q?
M1$E2)RDI('L*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]02%!?
M1$E2)RP@9V5T96YV*"=02%!?4$5!4E])3E-404Q,7T1)4B<I*3L*?2!E;'-E
M('L*("`@(&EF("A`:7-?9&ER*"1014%27TE.4U1!3$Q?1$E2*2D@>PH@("`@
M("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]02%!?1$E2)RP*("`@
M("`@("`@("`@("`@)%!%05)?24Y35$%,3%]$25(I.PH@("`@?2!E;'-E('L*
M("`@("`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4$A07T1)4B<L
M("1014%27TE.4U1!3$Q?1$E2*3L*("`@('T*?0H*+R\@1&5F875L="!F;W(@
M97AT7V1I<@II9B`H9V5T96YV*"=02%!?4$5!4E]%6%1%3E-)3TY?1$E2)RDI
M('L*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@
M9V5T96YV*"=02%!?4$5!4E]%6%1%3E-)3TY?1$E2)RDI.PI](&5L<V4@>PH@
M("`@:68@*&EN:5]G970H)V5X=&5N<VEO;E]D:7(G*2D@>PH@("`@("`@(&1E
M9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@:6YI7V=E="@G
M97AT96YS:6]N7V1I<B<I*3L*("`@('T@96QS96EF("AD969I;F5D*"=014%2
M7T585$5.4TE/3E]$25(G*2`F)B!`:7-?9&ER*%!%05)?15A414Y324].7T1)
M4BDI('L*("`@("`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?15A4
M7T1)4B<L(%!%05)?15A414Y324].7T1)4BD["B`@("!](&5L<V5I9B`H9&5F
M:6YE9"@G4$A07T585$5.4TE/3E]$25(G*2D@>PH@("`@("`@(&1E9FEN92@G
M4$5!4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@4$A07T585$5.4TE/3E]$
M25(I.PH@("`@?2!E;'-E('L*("`@("`@("!D969I;F4H)U!%05)?0T].1DE'
M7T1%1D%53%1?15A47T1)4B<L("<N)RD["B`@("!]"GT*"B\O($1E9F%U;'0@
M9F]R(&1O8U]D:7(*:68@*&=E=&5N=B@G4$A07U!%05)?1$]#7T1)4B<I*2![
M"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?1$]#7T1)4B<L(&=E
M=&5N=B@G4$A07U!%05)?1$]#7T1)4B<I*3L*?2!E;'-E('L*("`@(&1E9FEN
M92@G4$5!4E]#3TY&24=?1$5&055,5%]$3T-?1$E2)RP*("`@("`@("`@("`D
M4$5!4E])3E-404Q,7T1)4BY$25)%0U1/4EE?4T5005)!5$]2+B=D;V-S)RD[
M"GT*"B\O($1E9F%U;'0@9F]R(&)I;E]D:7(*:68@*&=E=&5N=B@G4$A07U!%
M05)?0DE.7T1)4B<I*2!["B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%5
M3%1?0DE.7T1)4B<L(&=E=&5N=B@G4$A07U!%05)?0DE.7T1)4B<I*3L*?2!E
M;'-E('L*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]"24Y?1$E2
M)RP@4$A07T))3D1)4BD["GT*"B\O($1E9F%U;'0@9F]R(&1A=&%?9&ER"FEF
M("AG971E;G8H)U!(4%]014%27T1!5$%?1$E2)RDI('L*("`@(&1E9FEN92@G
M4$5!4E]#3TY&24=?1$5&055,5%]$051!7T1)4B<L(&=E=&5N=B@G4$A07U!%
M05)?1$%405]$25(G*2D["GT@96QS92!["B`@("!D969I;F4H)U!%05)?0T].
M1DE'7T1%1D%53%1?1$%405]$25(G+`H@("`@("`@("`@("1014%27TE.4U1!
M3$Q?1$E2+D1)4D5#5$]265]315!!4D%43U(N)V1A=&$G*3L*?0H*+R\@1&5F
M875L="!F;W(@=&5S=%]D:7(*:68@*&=E=&5N=B@G4$A07U!%05)?5$535%]$
M25(G*2D@>PH@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U1%4U1?
M1$E2)RP@9V5T96YV*"=02%!?4$5!4E]415-47T1)4B<I*3L*?2!E;'-E('L*
M("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]415-47T1)4B<L"B`@
M("`@("`@("`@)%!%05)?24Y35$%,3%]$25(N1$E214-43U)97U-%4$%2051/
M4BXG=&5S=',G*3L*?0H*+R\@1&5F875L="!F;W(@8V%C:&5?9&ER"FEF("AG
M971E;G8H)U!(4%]014%27T-!0TA%7T1)4B<I*2!["B`@("!D969I;F4H)U!%
M05)?0T].1DE'7T1%1D%53%1?0T%#2$5?1$E2)RP@9V5T96YV*"=02%!?4$5!
M4E]#04-(15]$25(G*2D["GT@96QS92!["B`@("!D969I;F4H)U!%05)?0T].
M1DE'7T1%1D%53%1?0T%#2$5?1$E2)RP*("`@("`@("`@("!3>7-T96TZ.G1M
M<&1I<B@I("X@1$E214-43U)97U-%4$%2051/4B`N("=P96%R)R`N"B`@("`@
M("`@("`@1$E214-43U)97U-%4$%2051/4B`N("=C86-H92<I.PI]"@HO+R!$
M969A=6QT(&9O<B!P:'!?8FEN"FEF("AG971E;G8H)U!(4%]014%27U!(4%]"
M24XG*2D@>PH@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U!(4%]"
M24XG+"!G971E;G8H)U!(4%]014%27U!(4%]"24XG*2D["GT@96QS92!["B`@
M("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4$A07T))3B<L(%!%05)?
M0T].1DE'7T1%1D%53%1?0DE.7T1)4BX*("`@("`@("`@("!$25)%0U1/4EE?
M4T5005)!5$]2+B=P:'`G+BA/4U]724Y$3U=3(#\@)RYE>&4G(#H@)R<I*3L*
M?0H*+R\@1&5F875L="!F;W(@=F5R8F]S90II9B`H9V5T96YV*"=02%!?4$5!
M4E]615)"3U-%)RDI('L*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,
M5%]615)"3U-%)RP@9V5T96YV*"=02%!?4$5!4E]615)"3U-%)RDI.PI](&5L
M<V4@>PH@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U9%4D)/4T4G
M+"`Q*3L*?0H*+R\@1&5F875L="!F;W(@<')E9F5R<F5D7W-T871E"FEF("AG
M971E;G8H)U!(4%]014%27U!2149%4E)%1%]35$%412<I*2!["B`@("!D969I
M;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4%)%1D524D5$7U-4051%)RP@9V5T
M96YV*"=02%!?4$5!4E]04D5&15)2141?4U1!5$4G*2D["GT@96QS92!["B`@
M("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4%)%1D524D5$7U-4051%
M)RP@)W-T86)L92<I.PI]"@HO+R!$969A=6QT(&9O<B!U;6%S:PII9B`H9V5T
M96YV*"=02%!?4$5!4E]534%32R<I*2!["B`@("!D969I;F4H)U!%05)?0T].
M1DE'7T1%1D%53%1?54U!4TLG+"!G971E;G8H)U!(4%]014%27U5-05-+)RDI
M.PI](&5L<V4@>PH@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U5-
M05-+)RP@9&5C;V-T*'5M87-K*"DI*3L*?0H*+R\@1&5F875L="!F;W(@8V%C
M:&5?='1L"FEF("AG971E;G8H)U!(4%]014%27T-!0TA%7U143"<I*2!["B`@
M("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?0T%#2$5?5%1,)RP@9V5T
M96YV*"=02%!?4$5!4E]#04-(15]45$PG*2D["GT@96QS92!["B`@("!D969I
M;F4H)U!%05)?0T].1DE'7T1%1D%53%1?0T%#2$5?5%1,)RP@,S8P,"D["GT*
M"B\O($1E9F%U;'0@9F]R('-I9U]T>7!E"FEF("AG971E;G8H)U!(4%]014%2
M7U-)1U]465!%)RDI('L*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,
M5%]324=?5%E012<L(&=E=&5N=B@G4$A07U!%05)?4TE'7U194$4G*2D["GT@
M96QS92!["B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'7U19
M4$4G+"`G9W!G)RD["GT*"B\O($1E9F%U;'0@9F]R('-I9U]B:6X*:68@*&=E
M=&5N=B@G4$A07U!%05)?4TE'7T))3B<I*2!["B`@("!D969I;F4H)U!%05)?
M0T].1DE'7T1%1D%53%1?4TE'7T))3B<L(&=E=&5N=B@G4$A07U!%05)?4TE'
M7T))3B<I*3L*?2!E;'-E('L*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&
M055,5%]324=?0DE.)RP*("`@("`@("`@("!3>7-T96TZ.G=H:6-H*`H@("`@
M("`@("`@("`@("`G9W!G)RP@3U-?5TE.1$]74R`_("=C.EQG;G5P9UQG<&<N
M97AE)R`Z("<O=7-R+VQO8V%L+V)I;B]G<&<G*2D["GT*"B\O($1E9F%U;'0@
M9F]R('-I9U]K97ED:7(*:68@*&=E=&5N=B@G4$A07U!%05)?4TE'7TM%641)
M4B<I*2!["B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'7TM%
M641)4B<L(&=E=&5N=B@G4$A07U!%05)?4TE'7TM%641)4B<I*3L*?2!E;'-E
M('L*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]324=?2T591$E2
M)RP*("`@("`@("`@("!014%27T-/3D9)1U]365-#3TY&1$E2("X@1$E214-4
M3U)97U-%4$%2051/4B`N("=P96%R:V5Y<R<I.PI]"@HO*BH*("H@5&AI<R!I
M<R!A(&-L87-S(&9O<B!S=&]R:6YG(&-O;F9I9W5R871I;VX@9&%T82P@:V5E
M<&EN9R!T<F%C:R!O9@H@*B!W:&EC:"!A<F4@<WES=&5M+61E9FEN960L('5S
M97(M9&5F:6YE9"!O<B!D969A=6QT960N"B`J+PIC;&%S<R!014%27T-O;F9I
M9R!E>'1E;F1S(%!%05(*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O
M*BH*("`@("`J($%R<F%Y(&]F(&-O;F9I9R!F:6QE<R!U<V5D+@H@("`@("H*
M("`@("`J($!V87(@87)R87D@;&%Y97(@/3X@8V]N9FEG(&9I;&4*("`@("`J
M+PH@("`@=F%R("1F:6QE<R`](&%R<F%Y*`H@("`@("`@("=S>7-T96TG(#T^
M("<G+`H@("`@("`@("=U<V5R)R`]/B`G)RP*("`@("`@("`I.PH*("`@('9A
M<B`D;&%Y97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;F9I9W5R
M871I;VX@9&%T82P@='=O+61I;65N<VEO;F%L(&%R<F%Y('=H97)E('1H92!F
M:7)S=`H@("`@("H@9&EM96YS:6]N(&ES('1H92!C;VYF:6<@;&%Y97(@*"=U
M<V5R)RP@)W-Y<W1E;2<@86YD("=D969A=6QT)RDL"B`@("`@*B!A;F0@=&AE
M('-E8V]N9"!D:6UE;G-I;VX@:7,@:V5Y;F%M92`]/B!V86QU92X*("`@("`J
M"B`@("`@*B!4:&4@;W)D97(@:6X@=&AE(&9I<G-T(&1I;65N<VEO;B!I<R!I
M;7!O<G1A;G0A("!%87)L:65R"B`@("`@*B!L87EE<G,@=VEL;"!S:&%D;W<@
M;&%T97(@;VYE<R!W:&5N(&$@8V]N9FEG('9A;'5E(&ES"B`@("`@*B!R97%U
M97-T960@*&EF(&$@)W5S97(G('9A;'5E(&5X:7-T<RP@:70@=VEL;"!B92!R
M971U<FYE9"!F:7)S="P*("`@("`J('1H96X@)W-Y<W1E;2<@86YD(&9I;F%L
M;'D@)V1E9F%U;'0G*2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y(&QA>65R
M(#T^(&%R<F%Y*&ME>6YA;64@/3X@=F%L=64L("XN+BD*("`@("`J+PH@("`@
M=F%R("1C;VYF:6=U<F%T:6]N(#T@87)R87DH"B`@("`@("`@)W5S97(G(#T^
M(&%R<F%Y*"DL"B`@("`@("`@)W-Y<W1E;2<@/3X@87)R87DH*2P*("`@("`@
M("`G9&5F875L="<@/3X@87)R87DH*2P*("`@("`@("`I.PH*("`@("\J*@H@
M("`@("H@26YF;W)M871I;VX@86)O=70@=&AE(&-O;F9I9W5R871I;VX@9&%T
M82X@(%-T;W)E<R!T:&4@='EP92P*("`@("`J(&1E9F%U;'0@=F%L=64@86YD
M(&$@9&]C=6UE;G1A=&EO;B!S=')I;F<@9F]R(&5A8V@@8V]N9FEG=7)A=&EO
M;@H@("`@("H@=F%L=64N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>2!L87EE
M<B`]/B!A<G)A>2AI;F9O='EP92`]/B!V86QU92P@+BXN*0H@("`@("HO"B`@
M("!V87(@)&-O;F9I9W5R871I;VY?:6YF;R`](&%R<F%Y*`H@("`@("`@("\O
M($EN=&5R;F5T($%C8V5S<PH@("`@("`@("=M87-T97)?<V5R=F5R)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=S=')I;F<G+`H@("`@("`@
M("`@("`G9&5F875L="<@/3X@)W!E87(N<&AP+FYE="<L"B`@("`@("`@("`@
M("=D;V,G(#T^("=N86UE(&]F('1H92!M86EN(%!%05(@<V5R=F5R)RP*("`@
M("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@<V5R=F5R)RP*("`@("`@("`@
M("`@)V=R;W5P)R`]/B`G26YT97)N970@06-C97-S)RP*("`@("`@("`@("`@
M*2P*("`@("`@("`G:'1T<%]P<F]X>2<@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M(%!%05)?0T].1DE'7T1%1D%53%1?2%144%]04D]862P*("`@("`@("`@("`@
M)V1O8R<@/3X@)TA45%`@<')O>'D@*&AO<W0Z<&]R="D@=&\@=7-E('=H96X@
M9&]W;FQO861I;F<@<&%C:V%G97,G+`H@("`@("`@("`@("`G<')O;7!T)R`]
M/B`G2%144"!0<F]X>2!397)V97(@061D<F5S<R<L"B`@("`@("`@("`@("=G
M<F]U<"<@/3X@)TEN=&5R;F5T($%C8V5S<R<L"B`@("`@("`@("`@("DL"B`@
M("`@("`@+R\@1FEL92!,;V-A=&EO;G,*("`@("`@("`G<&AP7V1I<B<@/3X@
M87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&ER96-T;W)Y)RP*("`@
M("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?4$A0
M7T1)4BP*("`@("`@("`@("`@)V1O8R<@/3X@)V1I<F5C=&]R>2!W:&5R92`N
M<&AP(&9I;&5S(&%R92!I;G-T86QL960G+`H@("`@("`@("`@("`G<')O;7!T
M)R`]/B`G4$5!4B!D:7)E8W1O<GDG+`H@("`@("`@("`@("`G9W)O=7`G(#T^
M("=&:6QE($QO8V%T:6]N<R<L"B`@("`@("`@("`@("DL"B`@("`@("`@)V5X
M=%]D:7(G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V1I<F5C
M=&]R>2<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$
M149!54Q47T585%]$25(L"B`@("`@("`@("`@("=D;V,G(#T^("=D:7)E8W1O
M<GD@=VAE<F4@;&]A9&%B;&4@97AT96YS:6]N<R!A<F4@:6YS=&%L;&5D)RP*
M("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!(4"!E>'1E;G-I;VX@9&ER96-T
M;W)Y)RP*("`@("`@("`@("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO;G,G
M+`H@("`@("`@("`@("`I+`H@("`@("`@("=D;V-?9&ER)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`H@("`@("`@("`@
M("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]$3T-?1$E2+`H@
M("`@("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E(&1O8W5M96YT
M871I;VX@:7,@:6YS=&%L;&5D)RP*("`@("`@("`@("`@)W!R;VUP="<@/3X@
M)U!%05(@9&]C=6UE;G1A=&EO;B!D:7)E8W1O<GDG+`H@("`@("`@("`@("`G
M9W)O=7`G(#T^("=&:6QE($QO8V%T:6]N<R<L"B`@("`@("`@("`@("DL"B`@
M("`@("`@)V)I;E]D:7(G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)V1I<F5C=&]R>2<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%2
M7T-/3D9)1U]$149!54Q47T))3E]$25(L"B`@("`@("`@("`@("=D;V,G(#T^
M("=D:7)E8W1O<GD@=VAE<F4@97AE8W5T86)L97,@87)E(&EN<W1A;&QE9"<L
M"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=014%2(&5X96-U=&%B;&5S(&1I
M<F5C=&]R>2<L"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T9I;&4@3&]C871I
M;VYS)RP*("`@("`@("`@("`@*2P*("`@("`@("`G9&%T85]D:7(G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V1I<F5C=&]R>2<L"B`@("`@
M("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T1!5$%?
M1$E2+`H@("`@("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E(&1A
M=&$@9FEL97,@87)E(&EN<W1A;&QE9"<L"B`@("`@("`@("`@("=P<F]M<'0G
M(#T^("=014%2(&1A=&$@9&ER96-T;W)Y)RP*("`@("`@("`@("`@)V=R;W5P
M)R`]/B`G1FEL92!,;V-A=&EO;G,@*$%D=F%N8V5D*2<L"B`@("`@("`@("`@
M("DL"B`@("`@("`@)W1E<W1?9&ER)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`H@("`@("`@("`@("`G9&5F875L="<@
M/3X@4$5!4E]#3TY&24=?1$5&055,5%]415-47T1)4BP*("`@("`@("`@("`@
M)V1O8R<@/3X@)V1I<F5C=&]R>2!W:&5R92!R96=R97-S:6]N('1E<W1S(&%R
M92!I;G-T86QL960G+`H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!4B!T
M97-T(&1I<F5C=&]R>2<L"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T9I;&4@
M3&]C871I;VYS("A!9'9A;F-E9"DG+`H@("`@("`@("`@("`I+`H@("`@("`@
M("=C86-H95]D:7(G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)V1I<F5C=&]R>2<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/
M3D9)1U]$149!54Q47T-!0TA%7T1)4BP*("`@("`@("`@("`@)V1O8R<@/3X@
M)V1I<F5C=&]R>2!W:&EC:"!I<R!U<V5D(&9O<B!834Q24$,@8V%C:&4G+`H@
M("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!4B!);G-T86QL97(@8V%C:&4@
M9&ER96-T;W)Y)RP*("`@("`@("`@("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A
M=&EO;G,@*$%D=F%N8V5D*2<L"B`@("`@("`@("`@("DL"B`@("`@("`@)W!H
M<%]B:6XG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V9I;&4G
M+`H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,
M5%]02%!?0DE.+`H@("`@("`@("`@("`G9&]C)R`]/B`G4$A0($-,22]#1TD@
M8FEN87)Y(&9O<B!E>&5C=71I;F<@<V-R:7!T<R<L"B`@("`@("`@("`@("=P
M<F]M<'0G(#T^("=02%`@0TQ)+T-'22!B:6YA<GDG+`H@("`@("`@("`@("`G
M9W)O=7`G(#T^("=&:6QE($QO8V%T:6]N<R`H061V86YC960I)RP*("`@("`@
M("`@("`@*2P*("`@("`@("`O+R!-86EN=&%I;F5R<PH@("`@("`@("=U<V5R
M;F%M92<@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<G+`H@("`@("`@("`@("`G
M9&]C)R`]/B`G*&UA:6YT86EN97)S*2!Y;W5R(%!%05(@86-C;W5N="!N86UE
M)RP*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@=7-E<FYA;64@*&9O
M<B!M86EN=&%I;F5R<RDG+`H@("`@("`@("`@("`G9W)O=7`G(#T^("=-86EN
M=&%I;F5R<R<L"B`@("`@("`@("`@("DL"B`@("`@("`@)W!A<W-W;W)D)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=P87-S=V]R9"<L"B`@
M("`@("`@("`@("=D969A=6QT)R`]/B`G)RP*("`@("`@("`@("`@)V1O8R<@
M/3X@)RAM86EN=&%I;F5R<RD@>6]U<B!014%2(&%C8V]U;G0@<&%S<W=O<F0G
M+`H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!4B!P87-S=V]R9"`H9F]R
M(&UA:6YT86EN97)S*2<L"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TUA:6YT
M86EN97)S)RP*("`@("`@("`@("`@*2P*("`@("`@("`O+R!!9'9A;F-E9`H@
M("`@("`@("=V97)B;W-E)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?
M0T].1DE'7T1%1D%53%1?5D520D]312P*("`@("`@("`@("`@)V1O8R<@/3X@
M)W9E<F)O<VET>2!L979E;`HP.B!R96%L;'D@<75I970*,3H@<V]M97=H870@
M<75I970*,CH@=F5R8F]S90HS.B!D96)U9R<L"B`@("`@("`@("`@("=P<F]M
M<'0G(#T^("=$96)U9R!,;V<@3&5V96PG+`H@("`@("`@("`@("`G9W)O=7`G
M(#T^("=!9'9A;F-E9"<L"B`@("`@("`@("`@("DL"B`@("`@("`@)W!R969E
M<G)E9%]S=&%T92<@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M<V5T)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%
M1D%53%1?4%)%1D524D5$7U-4051%+`H@("`@("`@("`@("`G9&]C)R`]/B`G
M=&AE(&EN<W1A;&QE<B!W:6QL('!R969E<B!R96QE87-E<R!W:71H('1H:7,@
M<W1A=&4@=VAE;B!I;G-T86QL:6YG('!A8VMA9V5S('=I=&AO=70@82!V97)S
M:6]N(&]R('-T871E('-P96-I9FEE9"<L"B`@("`@("`@("`@("=V86QI9%]S
M970G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)W-T86)L92<L("=B971A
M)RP@)V%L<&AA)RP@)V1E=F5L)RP@)W-N87!S:&]T)RDL"B`@("`@("`@("`@
M("=P<F]M<'0G(#T^("=0<F5F97)R960@4&%C:V%G92!3=&%T92<L"B`@("`@
M("`@("`@("=G<F]U<"<@/3X@)T%D=F%N8V5D)RP*("`@("`@("`@("`@*2P*
M("`@("`@("`G=6UA<VLG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)VUA<VLG+`H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&
M24=?1$5&055,5%]534%32RP*("`@("`@("`@("`@)V1O8R<@/3X@)W5M87-K
M('5S960@=VAE;B!C<F5A=&EN9R!F:6QE<R`H56YI>"UL:6ME('-Y<W1E;7,@
M;VYL>2DG+`H@("`@("`@("`@("`G<')O;7!T)R`]/B`G56YI>"!F:6QE(&UA
M<VLG+`H@("`@("`@("`@("`G9W)O=7`G(#T^("=!9'9A;F-E9"<L"B`@("`@
M("`@("`@("DL"B`@("`@("`@)V-A8VAE7W1T;"<@/3X@87)R87DH"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=D969A
M=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T-!0TA%7U143"P*("`@("`@
M("`@("`@)V1O8R<@/3X@)V%M;W5N="!O9B!S96-S('=H97)E('1H92!L;V-A
M;"!C86-H92!I<R!U<V5D(&%N9"!N;W0@=7!D871E9"<L"B`@("`@("`@("`@
M("=P<F]M<'0G(#T^("=#86-H92!4:6UE5&],:79E)RP*("`@("`@("`@("`@
M)V=R;W5P)R`]/B`G061V86YC960G+`H@("`@("`@("`@("`I+`H@("`@("`@
M("=S:6=?='EP92<@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M<V5T)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%
M1D%53%1?4TE'7U194$4L"B`@("`@("`@("`@("=D;V,G(#T^("=W:&EC:"!P
M86-K86=E('-I9VYA='5R92!M96-H86YI<VT@=&\@=7-E)RP*("`@("`@("`@
M("`@)W9A;&ED7W-E="<@/3X@87)R87DH)V=P9R<I+`H@("`@("`@("`@("`G
M<')O;7!T)R`]/B`G4&%C:V%G92!3:6=N871U<F4@5'EP92<L"B`@("`@("`@
M("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S)RP*("`@("`@("`@("`@*2P*
M("`@("`@("`G<VEG7V)I;B<@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?
M0T].1DE'7T1%1D%53%1?4TE'7T))3BP*("`@("`@("`@("`@)V1O8R<@/3X@
M)W=H:6-H('!A8VMA9V4@<VEG;F%T=7)E(&UE8VAA;FES;2!T;R!U<V4G+`H@
M("`@("`@("`@("`G<')O;7!T)R`]/B`G4VEG;F%T=7)E($AA;F1L:6YG(%!R
M;V=R86TG+`H@("`@("`@("`@("`G9W)O=7`G(#T^("=-86EN=&%I;F5R<R<L
M"B`@("`@("`@("`@("DL"B`@("`@("`@)W-I9U]K97EI9"<@/3X@87)R87DH
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^("<G+`H@("`@("`@("`@("`G9&]C)R`]/B`G=VAI8V@@
M:V5Y('1O('5S92!F;W(@<VEG;FEN9R!W:71H)RP*("`@("`@("`@("`@)W!R
M;VUP="<@/3X@)U-I9VYA='5R92!+97D@260G+`H@("`@("`@("`@("`G9W)O
M=7`G(#T^("=-86EN=&%I;F5R<R<L"B`@("`@("`@("`@("DL"B`@("`@("`@
M)W-I9U]K97ED:7(G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)W-T<FEN9R<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)
M1U]$149!54Q47U-)1U]+15E$25(L"B`@("`@("`@("`@("=D;V,G(#T^("=W
M:&EC:"!P86-K86=E('-I9VYA='5R92!M96-H86YI<VT@=&\@=7-E)RP*("`@
M("`@("`@("`@)W!R;VUP="<@/3X@)U-I9VYA='5R92!+97D@1&ER96-T;W)Y
M)RP*("`@("`@("`@("`@)V=R;W5P)R`]/B`G36%I;G1A:6YE<G,G+`H@("`@
M("`@("`@("`I+`H@("`@("`@("D["@H@("`@+R\@?7U]"@H@("`@+R\@>WM[
M(%!%05)?0V]N9FEG*%MF:6QE72P@6V1E9F%U;'1S7V9I;&5=*0H*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`H;W!T:6]N86PI(&9I;&4@=&\@<F5A9"!U<V5R+61E9FEN960@;W!T
M:6]N<R!F<F]M"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@9FEL
M92!T;R!R96%D('-Y<W1E;2UW:61E(&1E9F%U;'1S(&9R;VT*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!S964@4$5!4E]#
M;VYF:6<Z.G-I;F=L971O;@H@("`@("HO"B`@("!F=6YC=&EO;B!014%27T-O
M;F9I9R@D=7-E<E]F:6QE(#T@)R<L("1S>7-T96U?9FEL92`]("<G*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y014%2*"D["B`@("`@("`@)'-L(#T@1$E214-4
M3U)97U-%4$%2051/4CL*("`@("`@("!I9B`H96UP='DH)'5S97)?9FEL92DI
M('L*("`@("`@("`@("`@:68@*$]37U=)3D1/5U,I('L*("`@("`@("`@("`@
M("`@("1U<V5R7V9I;&4@/2!014%27T-/3D9)1U]365-#3TY&1$E2("X@)'-L
M("X@)W!E87(N:6YI)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1U<V5R7V9I;&4@/2!G971E;G8H)TA/344G*2`N("1S;"`N("<N
M<&5A<G)C)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)'-Y<W1E;5]F:6QE*2D@>PH@("`@("`@("`@("!I9B`H3U-?5TE.
M1$]74RD@>PH@("`@("`@("`@("`@("`@)'-Y<W1E;5]F:6QE(#T@4$5!4E]#
M3TY&24=?4UE30T].1D1)4B`N("1S;"`N("=P96%R<WES+FEN:2<["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<WES=&5M7V9I;&4@
M/2!014%27T-/3D9)1U]365-#3TY&1$E2("X@)'-L("X@)W!E87(N8V]N9B<[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'1H:7,M/FQA>65R
M<R`](&%R<F%Y7VME>7,H)'1H:7,M/F-O;F9I9W5R871I;VXI.PH@("`@("`@
M("1T:&ES+3YF:6QE<ULG=7-E<B==(#T@)'5S97)?9FEL93L*("`@("`@("`D
M=&AI<RT^9FEL97-;)W-Y<W1E;2==(#T@)'-Y<W1E;5]F:6QE.PH@("`@("`@
M(&EF("@D=7-E<E]F:6QE("8F(&9I;&5?97AI<W1S*"1U<V5R7V9I;&4I*2![
M"B`@("`@("`@("`@("1T:&ES+3YR96%D0V]N9FEG1FEL92@D=7-E<E]F:6QE
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"1S>7-T96U?9FEL92`F)B!F:6QE
M7V5X:7-T<R@D<WES=&5M7V9I;&4I*2!["B`@("`@("`@("`@("1T:&ES+3YM
M97)G94-O;F9I9T9I;&4H)'-Y<W1E;5]F:6QE+"!F86QS92P@)W-Y<W1E;2<I
M.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]N9FEG=7)A
M=&EO;E]I;F9O(&%S("1K97D@/3X@)&EN9F\I('L*("`@("`@("`@("`@)'1H
M:7,M/F-O;F9I9W5R871I;VY;)V1E9F%U;'0G75LD:V5Y72`]("1I;F9O6R=D
M969A=6QT)UT["B`@("`@("`@?0H@("`@("`@("\O)$=,3T)!3%-;)U]014%2
M7T-O;F9I9U]I;G-T86YC92==(#T@)B1T:&ES.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[('-I;F=L971O;BA;9FEL95TL(%MD969A=6QT<U]F:6QE
M72D*"B`@("`O*BH*("`@("`J(%-T871I8R!S:6YG;&5T;VX@;65T:&]D+B`@
M268@>6]U('=A;G0@=&\@:V5E<"!O;FQY(&]N92!I;G-T86YC90H@("`@("H@
M;V8@=&AI<R!C;&%S<R!I;B!U<V4L('1H:7,@;65T:&]D('=I;&P@9VEV92!Y
M;W4@82!R969E<F5N8V4@=&\*("`@("`J('1H92!L87-T(&-R96%T960@4$5!
M4E]#;VYF:6<@;V)J96-T(&EF(&]N92!E>&ES=',L(&]R(&-R96%T92!A"B`@
M("`@*B!N97<@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M*&]P=&EO;F%L*2!F:6QE('1O(')E860@=7-E<BUD969I;F5D(&]P=&EO;G,@
M9G)O;0H@("`@("H@0'!A<F%M('-T<FEN9R`H;W!T:6]N86PI(&9I;&4@=&\@
M<F5A9"!S>7-T96TM=VED92!D969A=6QT<R!F<F]M"B`@("`@*@H@("`@("H@
M0')E='5R;B!O8FIE8W0@86X@97AI<W1I;F<@;W(@;F5W(%!%05)?0V]N9FEG
M(&EN<W1A;F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M"B`@("`@*B!`<V5E(%!%05)?0V]N9FEG.CI014%27T-O;F9I9PH@("`@("HO
M"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1U<V5R7V9I;&4@/2`G)RP@)'-Y
M<W1E;5]F:6QE(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES7V]B:F5C="@D
M1TQ/0D%,4ULG7U!%05)?0V]N9FEG7VEN<W1A;F-E)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]N9FEG7VEN<W1A;F-E)UT[
M"B`@("`@("`@?0H@("`@("`@("1'3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS
M=&%N8V4G72`]"B`@("`@("`@("`@("`F;F5W(%!%05)?0V]N9FEG*"1U<V5R
M7V9I;&4L("1S>7-T96U?9FEL92D["B`@("`@("`@<F5T=7)N("1'3$]"04Q3
M6R=?4$5!4E]#;VYF:6=?:6YS=&%N8V4G73L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!R96%D0V]N9FEG1FEL92A;9FEL95TL(%ML87EE<ETI"@H@
M("`@+RHJ"B`@("`@*B!296%D<R!C;VYF:6=U<F%T:6]N(&1A=&$@9G)O;2!A
M(&9I;&4N("!!;&P@97AI<W1I;F<@=F%L=65S(&EN"B`@("`@*B!T:&4@8V]N
M9FEG(&QA>65R(&%R92!D:7-C87)D960@86YD(')E<&QA8V5D('=I=&@@9&%T
M82!F<F]M('1H90H@("`@("H@9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("AO<'1I;VYA;"D@9FEL92!T;R!R96%D(&9R;VTL(&EF($Y53$P@
M;W(@;F]T"B`@("`@*B!S<&5C:69I960L('1H92!L87-T+75S960@9FEL92!F
M;W(@=&AE('-A;64@;&%Y97(@*'-E8V]N9"!P87)A;2D*("`@("`J(&ES('5S
M960*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@8V]N
M9FEG(&QA>65R('1O(&EN<V5R="!D871A(&EN=&\*("`@("`J("@G=7-E<B<@
M;W(@)W-Y<W1E;2<I"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L(%12544@
M;VX@<W5C8V5S<R!O<B!A(%!%05(@97)R;W(@;VX@9F%I;'5R90H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M861#;VYF:6=&:6QE*"1F:6QE(#T@;G5L;"P@)&QA>65R(#T@)W5S97(G*0H@
M("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^9FEL97-;)&QA>65R72DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")U;FMN
M;W=N(&-O;F9I9R!F:6QE('1Y<&4@8"1L87EE<B<B*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"1F:6QE(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1F:6QE
M(#T@)'1H:7,M/F9I;&5S6R1L87EE<ET["B`@("`@("`@?0H@("`@("`@("1D
M871A(#T@)'1H:7,M/E]R96%D0V]N9FEG1&%T849R;VTH)&9I;&4I.PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1D871A*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&1A=&$["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?9&5C;V1E
M26YP=70H)&1A=&$I.PH@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L
M87EE<ET@/2`D9&%T83L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!M97)G94-O;F9I9T9I;&4H9FEL92P@6V]V
M97)R:61E72P@6VQA>65R72D*"B`@("`O*BH*("`@("`J($UE<F=E<R!D871A
M(&EN=&\@82!C;VYF:6<@;&%Y97(@9G)O;2!A(&9I;&4N("!$;V5S('1H92!S
M86UE"B`@("`@*B!T:&EN9R!A<R!R96%D0V]N9FEG1FEL92P@97AC97!T(&ET
M(&1O97,@;F]T(')E<&QA8V4@86QL"B`@("`@*B!E>&ES=&EN9R!V86QU97,@
M:6X@=&AE(&-O;F9I9R!L87EE<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&9I;&4@=&\@<F5A9"!F<F]M"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VP@*&]P=&EO;F%L*2!W:&5T:&5R('1O(&]V97)W<FET92!E>&ES=&EN9R!D
M871A"B`@("`@*B`H9&5F875L="!44E5%*0H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@8V]N9FEG(&QA>65R('1O(&EN<V5R="!D871A(&EN=&\@*"=U
M<V5R)R!O<@H@("`@("H@)W-Y<W1E;2<I"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L(%12544@;VX@<W5C8V5S<R!O<B!A(%!%05(@97)R;W(@;VX@9F%I
M;'5R90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!M97)G94-O;F9I9T9I;&4H)&9I;&4L("1O=F5R<FED92`]
M('1R=64L("1L87EE<B`]("=U<V5R)RD*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/F9I;&5S6R1L87EE<ETI*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VYF:6<@9FEL92!T>7!E
M(&`D;&%Y97(G(BD["B`@("`@("`@?0H@("`@("`@(&EF("@D9FEL92`]/3T@
M;G5L;"D@>PH@("`@("`@("`@("`D9FEL92`]("1T:&ES+3YF:6QE<ULD;&%Y
M97)=.PH@("`@("`@('T*("`@("`@("`D9&%T82`]("1T:&ES+3Y?<F5A9$-O
M;F9I9T1A=&%&<F]M*"1F:6QE*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7V1E8V]D94EN<'5T*"1D871A*3L*("`@("`@
M("!I9B`H)&]V97)R:61E*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U
M<F%T:6]N6R1L87EE<ET@/2!A<G)A>5]M97)G92@D=&AI<RT^8V]N9FEG=7)A
M=&EO;ELD;&%Y97)=+"`D9&%T82D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72`](&%R<F%Y7VUE
M<F=E*"1D871A+"`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@=W)I=&5#;VYF:6=&:6QE*%MF:6QE72P@6VQA>65R72D*
M"B`@("`O*BH*("`@("`J(%=R:71E<R!D871A(&EN=&\@82!C;VYF:6<@;&%Y
M97(@9G)O;2!A(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!F
M:6QE('1O(')E860@9G)O;0H@("`@("H*("`@("`J($!P87)A;2!B;V]L("AO
M<'1I;VYA;"D@=VAE=&AE<B!T;R!O=F5R=W)I=&4@97AI<W1I;F<@9&%T80H@
M("`@("H@*&1E9F%U;'0@5%)512D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&-O;F9I9R!L87EE<B!T;R!I;G-E<G0@9&%T82!I;G1O("@G=7-E<B<@
M;W(*("`@("`J("=S>7-T96TG*0H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;"!44E5%(&]N('-U8V-E<W,@;W(@82!014%2(&5R<F]R(&]N(&9A:6QU<F4*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@=W)I=&5#;VYF:6=&:6QE*"1F:6QE(#T@;G5L;"P@)&QA>65R(#T@
M)W5S97(G+"`D9&%T82`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1L87EE
M<B`]/2`G8F]T:"<@?'P@)&QA>65R(#T]("=A;&PG*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YF:6QE<R!A<R`D='EP92`]/B`D9FEL92D@>PH@
M("`@("`@("`@("`@("`@)&5R<B`]("1T:&ES+3YW<FET94-O;F9I9T9I;&4H
M)&9I;&4L("1T>7!E+"`D9&%T82D["B`@("`@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D97)R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/F9I;&5S6R1L87EE<ETI*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VYF:6<@9FEL92!T>7!E
M(&`D;&%Y97(G(BD["B`@("`@("`@?0H@("`@("`@(&EF("@D9FEL92`]/3T@
M;G5L;"D@>PH@("`@("`@("`@("`D9FEL92`]("1T:&ES+3YF:6QE<ULD;&%Y
M97)=.PH@("`@("`@('T*("`@("`@("`D9&%T82`]("@D9&%T82`]/3T@;G5L
M;"D@/R`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=(#H@)&1A=&$["B`@
M("`@("`@)'1H:7,M/E]E;F-O9&5/=71P=70H)&1A=&$I.PH@("`@("`@("1O
M<'0@/2!A<G)A>2@G+7`G+"!D:7)N86UE*"1F:6QE*2D["B`@("`@("`@:68@
M*"%`4WES=&5M.CIM:T1I<B@D;W!T*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A=&4@9&ER96-T;W)Y
M.B`B("X@9&ER;F%M92@D9FEL92DI.PH@("`@("`@('T*("`@("`@("!I9B`H
M0&ES7V9I;&4H)&9I;&4I("8F("%`:7-?=W)I=&5A8FQE*"1F:6QE*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO('=R:71E
M(&%C8V5S<R!T;R`D9FEL92$B*3L*("`@("`@("!]"B`@("`@("`@)&9P(#T@
M0&9O<&5N*"1F:6QE+"`B=R(I.PH@("`@("`@(&EF("@A)&9P*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]#;VYF:6<Z
M.G=R:71E0V]N9FEG1FEL92!F;W!E;B@G)&9I;&4G+"=W)RD@9F%I;&5D(BD[
M"B`@("`@("`@?0H@("`@("`@("1C;VYT96YT<R`]("(C4$5!4E]#;VYF:6<@
M,"XY7&XB("X@<V5R:6%L:7IE*"1D871A*3L*("`@("`@("!I9B`H(4!F=W)I
M=&4H)&9P+"`D8V]N=&5N=',I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B4$5!4E]#;VYF:6<Z.G=R:71E0V]N9FEG1FEL93H@
M9G=R:71E(&9A:6QE9"(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?<F5A9$-O;F9I9T1A
M=&%&<F]M*&9I;&4I"@H@("`@+RHJ"B`@("`@*B!296%D<R!C;VYF:6=U<F%T
M:6]N(&1A=&$@9G)O;2!A(&9I;&4@86YD(')E='5R;G,@=&AE('!A<G-E9"!D
M871A"B`@("`@*B!I;B!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&9I;&4@=&\@<F5A9"!F<F]M"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2!C;VYF:6=U<F%T:6]N(&1A=&$@;W(@82!014%2(&5R<F]R(&]N
M(&9A:6QU<F4*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W)E861#;VYF:6=$871A1G)O;2@D9FEL92D*("`@
M('L*("`@("`@("`D9G`@/2!`9F]P96XH)&9I;&4L(")R(BD["B`@("`@("`@
M:68@*"$D9G`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")014%27T-O;F9I9SHZ<F5A9$-O;F9I9T9I;&4@9F]P96XH)R1F:6QE
M)RPG<B<I(&9A:6QE9"(I.PH@("`@("`@('T*("`@("`@("`D<VEZ92`](&9I
M;&5S:7IE*"1F:6QE*3L*("`@("`@("`D<G0@/2!G971?;6%G:6-?<75O=&5S
M7W)U;G1I;64H*3L*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H
M,"D["B`@("`@("`@)&-O;G1E;G1S(#T@9G)E860H)&9P+"`D<VEZ92D["B`@
M("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"1R="D["B`@("`@("`@
M9F-L;W-E*"1F<"D["B`@("`@("`@)'9E<G-I;VX@/2`G,"XQ)SL*("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UXC4$5!4E]#;VYF:6=<<RLH7%,K*5QS*R]S
M:2<L("1C;VYT96YT<RP@)&UA=&-H97,I*2!["B`@("`@("`@("`@("1V97)S
M:6]N(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("1C;VYT96YT<R`]('-U
M8G-T<B@D8V]N=&5N=',L('-T<FQE;B@D;6%T8VAE<ULP72DI.PH@("`@("`@
M('T*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"(D=F5R<VEO;B(L("<Q
M)RP@)SPG*2D@>PH@("`@("`@("`@("`D9&%T82`]('5N<V5R:6%L:7IE*"1C
M;VYT96YT<RD["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&1A=&$I*2![
M"B`@("`@("`@("`@("`@("!I9B`H<W1R;&5N*'1R:6TH)&-O;G1E;G1S*2D@
M/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R(#T@(E!%05)?0V]N
M9FEG.B!B860@9&%T82!I;B`D9FEL92(["B\O("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)&5R<F]R*3L*+R\@("`@("`@("`@("`@("`@
M?2!E;'-E('L*+R\@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"1E<G)O<BD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("\O(&%D9"!P87)S:6YG
M(&]F(&YE=V5R(&9O<FUA=',@:&5R92XN+@H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&9I;&4Z('5N
M:VYO=VX@=F5R<VEO;B!@)'9E<G-I;VXG(BD["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M971#;VYF1FEL92AL87EE<BD*("`@("\J*@H@("`@*B!'971S('1H92!F:6QE
M('5S960@9F]R('-T;W)I;F<@=&AE(&-O;F9I9R!F;W(@82!L87EE<@H@("`@
M*@H@("`@*B!`<&%R86T@<W1R:6YG("1L87EE<B`G=7-E<B<@;W(@)W-Y<W1E
M;2<*("`@("HO"@H@("`@9G5N8W1I;VX@9V5T0V]N9D9I;&4H)&QA>65R*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9FEL97-;)&QA>65R73L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?96YC;V1E3W5T<'5T*"9D871A
M*0H*("`@("\J*@H@("`@("H@16YC;V1E<R]S8W)A;6)L97,@8V]N9FEG=7)A
M=&EO;B!D871A(&)E9F]R92!W<FET:6YG('1O(&9I;&5S+@H@("`@("H@0W5R
M<F5N=&QY+"`G<&%S<W=O<F0G('9A;'5E<R!W:6QL(&)E(&)A<V4V-"UE;F-O
M9&5D(&%S('1O(&%V;VED"B`@("`@*B!T:&%T('!E;W!L92!S<&]T(&-L96%R
M=&5X="!P87-S=V]R9',@8GD@86-C:61E;G0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("AR969E<F5N8V4I(&%R<F%Y('1O(&5N8V]D92!V86QU97,@
M:6X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]E;F-O9&5/=71P=70H)B1D871A*0H@("`@>PH@("`@("`@(&9O
M<F5A8V@@*"1D871A(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72DI
M('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T>7!E(#T@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD
M:V5Y75LG='EP92==.PH@("`@("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@
M("`@("`@("`@("`@("`O+R!W92!B87-E-C0M96YC;V1E('!A<W-W;W)D<R!S
M;R!T:&5Y(&%R92!A="!L96%S=`H@("`@("`@("`@("`@("`@+R\@;F]T('-H
M;W=N(&EN('!L86EN(&)Y(&%C8VED96YT"B`@("`@("`@("`@("`@("!C87-E
M("=P87-S=V]R9"<Z('L*("`@("`@("`@("`@("`@("`@("`D9&%T85LD:V5Y
M72`](&)A<V4V-%]E;F-O9&4H)&1A=&%;)&ME>5TI.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@8V%S92`G;6%S:R<Z('L*("`@("`@("`@("`@("`@("`@("`D9&%T85LD
M:V5Y72`](&]C=&1E8R@D9&%T85LD:V5Y72D["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@7V1E8V]D94EN<'5T*"9D871A*0H*("`@("\J*@H@("`@
M("H@1&5C;V1E<R]U;G-C<F%M8FQE<R!C;VYF:6=U<F%T:6]N(&1A=&$@869T
M97(@<F5A9&EN9R!F<F]M(&9I;&5S+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`H<F5F97)E;F-E*2!A<G)A>2!T;R!E;F-O9&4@=F%L=65S(&EN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<PH@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!S964@
M4$5!4E]#;VYF:6<Z.E]E;F-O9&5/=71P=70*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V1E8V]D94EN<'5T*"8D9&%T82D*("`@('L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1D871A*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)&ME>2`]/B`D=F%L
M=64I('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^8V]N9FEG=7)A
M=&EO;E]I;F9O6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1Y<&4@/2`D=&AI<RT^8V]N
M9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=T>7!E)UT["B`@("`@("`@("`@('-W
M:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@)W!A<W-W;W)D
M)SH@>PH@("`@("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@8F%S938T
M7V1E8V]D92@D9&%T85LD:V5Y72D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!C87-E("=M
M87-K)SH@>PH@("`@("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@9&5C
M;V-T*"1D871A6R1K97E=*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!G970H:V5Y+"!;;&%Y97)=*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(&-O;F9I9W5R871I;VX@=F%L=64L('!R:6]R:71I>FEN9R!L87EE<G,@87,@
M<&5R('1H90H@("`@("H@;&%Y97)S('!R;W!E<G1Y+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@=&AE(&-O;F9I9R!V86QU92P@;W(@3E5,3"!I9B!N;W0@9F]U
M;F0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G970H)&ME>2P@)&QA>65R(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H)&QA>65R(#T]/2!N=6QL*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YL87EE<G,@87,@)&QA>65R*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-O;F9I9W5R
M871I;VY;)&QA>65R75LD:V5Y73L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^8V]N9FEG
M=7)A=&EO;ELD;&%Y97)=6R1K97E=*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y73L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@<V5T*&ME>2P@=F%L=64L(%ML87EE<ETI"@H@("`@+RHJ"B`@("`@
M*B!3970@82!C;VYF:6<@=F%L=64@:6X@82!S<&5C:69I8R!L87EE<B`H9&5F
M875L=',@=&\@)W5S97(G*2X*("`@("`J($5N9F]R8V5S('1H92!T>7!E<R!D
M969I;F5D(&EN('1H92!C;VYF:6=U<F%T:6]N7VEN9F\@87)R87DN("!!;@H@
M("`@("H@:6YT96=E<B!C;VYF:6<@=F%R:6%B;&4@=VEL;"!B92!C87-T('1O
M(&EN="P@86YD(&$@<V5T(&-O;F9I9PH@("`@("H@=F%R:6%B;&4@=VEL;"!B
M92!V86QI9&%T960@86=A:6YS="!I=',@;&5G86P@=F%L=65S+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@8V]N9FEG('9A;'5E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`H;W!T:6]N86PI(&-O;F9I9R!L87EE<@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A
M:6QU<F4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S970H)&ME>2P@)'9A;'5E+"`D;&%Y97(@/2`G=7-E<B<I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YC;VYF:6=U<F%T:6]N
M7VEN9F];)&ME>5TI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"B`@("`@("`@97AT<F%C="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I
M;F9O6R1K97E=*3L*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@
M("`@(&-A<V4@)VEN=&5G97(G.@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M*&EN="DD=F%L=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`G<V5T)SH@>PH@("`@("`@("`@("`@("`@+R\@268@82!V86QI
M9%]S970@:7,@<W!E8VEF:65D+"!R97%U:7)E('1H92!V86QU92!T;PH@("`@
M("`@("`@("`@("`@+R\@8F4@:6X@=&AE('-E="X@($EF('1H97)E(&ES(&YO
M('9A;&ED7W-E="P@86-C97!T"B`@("`@("`@("`@("`@("`O+R!A;GD@=F%L
M=64N"B`@("`@("`@("`@("`@("!I9B`H)'9A;&ED7W-E="D@>PH@("`@("`@
M("`@("`@("`@("`@(')E<V5T*"1V86QI9%]S970I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@H:V5Y*"1V86QI9%]S970I(#T]/2`P("8F("%I;E]A<G)A
M>2@D=F%L=64L("1V86QI9%]S970I*2!\?`H@("`@("`@("`@("`@("`@("`@
M("`@("`H:V5Y*"1V86QI9%]S970I("$]/2`P("8F(&5M<'1Y*"1V86QI9%]S
M971;)'9A;'5E72DI*0H@("`@("`@("`@("`@("`@("`@('L*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YC;VYF
M:6=U<F%T:6]N6R1L87EE<EU;)&ME>5T@/2`D=F%L=64["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T5'EP
M92AK97DI"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('1Y<&4@;V8@82!C;VYF
M:6<@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@8V]N9FEG
M(&ME>0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG('1Y<&4L(&]N92!O
M9B`B<W1R:6YG(BP@(FEN=&5G97(B+"`B9FEL92(L"B`@("`@*B`B9&ER96-T
M;W)Y(BP@(G-E="(@;W(@(G!A<W-W;W)D(BX*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP
M92@D:V5Y*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG
M=7)A=&EO;E]I;F9O6R1K97E=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG='EP92==.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9V5T1&]C<RAK97DI"@H@("`@+RHJ"B`@("`@*B!'970@=&AE
M(&1O8W5M96YT871I;VX@9F]R(&$@8V]N9FEG('9A;'5E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@(&-O;F9I9R!K97D*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R!D;V-U;65N=&%T:6]N('-T<FEN9PH@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$;V-S*"1K97DI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=D;V,G73L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@("`@
M+R\@?7U]"B`@("`O+R![>WL@9V5T4')O;7!T*&ME>2D*"B`@("`O*BH*("`@
M("`J($=E="!T:&4@<VAO<G0@9&]C=6UE;G1A=&EO;B!F;W(@82!C;VYF:6<@
M=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@8V]N9FEG(&ME
M>0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG('-H;W)T(&1O8W5M96YT
M871I;VX@<W1R:6YG"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R;VUP="@D:V5Y*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O
M6R1K97E=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-O;F9I9W5R
M871I;VY?:6YF;ULD:V5Y75LG<')O;7!T)UT["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*("`@("\O('U]?0H@("`@+R\@>WM[(&=E
M=$=R;W5P*&ME>2D*"B`@("`O*BH*("`@("`J($=E="!T:&4@<&%R86UE=&5R
M(&=R;W5P(&9O<B!A(&-O;F9I9R!K97DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@8V]N9FEG(&ME>0H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG('!A<F%M971E<B!G<F]U<`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<"@D:V5Y
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO
M;E]I;F9O6R1K97E=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-O
M;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG9W)O=7`G73L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&=E=$=R;W5P<R@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&QI<W0@
M;V8@<&%R86UE=&5R(&=R;W5P<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y(&QI<W0@;V8@<&%R86UE=&5R(&=R;W5P<PH@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'
M<F]U<',H*0H@("`@>PH@("`@("`@("1T;7`@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F\@87,@)&ME>2`]
M/B`D:6YF;RD@>PH@("`@("`@("`@("`D=&UP6R1I;F9O6R=G<F]U<"==72`]
M(#$["B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>5]K97ES*"1T;7`I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$=R;W5P2V5Y<R@I
M"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&QI<W0@;V8@=&AE('!A<F%M971E
M<G,@:6X@82!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G
M<F]U<"!P87)A;65T97(@9W)O=7`*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y(&QI<W0@;V8@<&%R86UE=&5R<R!I;B`D9W)O=7`*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1W)O=7!+97ES*"1G<F]U<"D*("`@('L*("`@("`@("`D:V5Y<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F-O;F9I9W5R871I;VY?
M:6YF;R!A<R`D:V5Y(#T^("1I;F9O*2!["B`@("`@("`@("`@(&EF("@D:6YF
M;ULG9W)O=7`G72`]/2`D9W)O=7`I('L*("`@("`@("`@("`@("`@("1K97ES
M6UT@/2`D:V5Y.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D:V5Y<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713
M971686QU97,H:V5Y*0H*("`@("\J*@H@("`@("H@1V5T('1H92!L:7-T(&]F
M(&%L;&]W960@<V5T('9A;'5E<R!F;W(@82!C;VYF:6<@=F%L=64N("!2971U
M<FYS"B`@("`@*B!.54Q,(&9O<B!C;VYF:6<@=F%L=65S('1H870@87)E(&YO
M="!S971S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@(&-O;F9I9R!K
M97D*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&5N=6UE<F%T960@87)R
M87D@;V8@<V5T('9A;'5E<RP@;W(@3E5,3"!I9B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@8V]N9FEG(&ME>2!I<R!U;FMN;W=N(&]R(&YO="!A('-E=`H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9713971686QU97,H)&ME>2D*("`@('L*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72D@)B8*
M("`@("`@("`@("`@:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD
M:V5Y75LG='EP92==*2`F)@H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG=7)A
M=&EO;E]I;F9O6R1K97E=6R=T>7!E)UT@/3T@)W-E="<I"B`@("`@("`@>PH@
M("`@("`@("`@("`D=F%L:61?<V5T(#T@)'1H:7,M/F-O;F9I9W5R871I;VY?
M:6YF;ULD:V5Y75LG=F%L:61?<V5T)UT["B`@("`@("`@("`@(')E<V5T*"1V
M86QI9%]S970I.PH@("`@("`@("`@("!I9B`H:V5Y*"1V86QI9%]S970I(#T]
M/2`P*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'9A;&ED7W-E=#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D=F%L
M:61?<V5T*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$ME>7,H*0H*("`@("\J*@H@
M("`@("H@1V5T(&%L;"!T:&4@8W5R<F5N="!C;VYF:6<@:V5Y<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y('-I;7!L92!A<G)A>2!O9B!C;VYF:6<@
M:V5Y<PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$ME>7,H*0H@("`@>PH@("`@("`@("1K97ES(#T@87)R
M87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^;&%Y97)S(&%S("1L87EE
M<BD@>PH@("`@("`@("`@("`D:V5Y<R`](&%R<F%Y7VUE<F=E*"1K97ES+"`D
M=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N(&%R<F%Y7VME>7,H)&ME>7,I.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(')E;6]V92AK97DL(%ML87EE<ETI"@H@("`@+RHJ"B`@
M("`@*B!296UO=F4@=&AE(&$@8V]N9FEG(&ME>2!F<F]M(&$@<W!E8VEF:6,@
M8V]N9FEG(&QA>65R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@8V]N
M9FEG(&ME>0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@*&]P=&EO;F%L
M*2!C;VYF:6<@;&%Y97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)5
M12!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E*"1K
M97DL("1L87EE<B`]("=U<V5R)RD*("`@('L*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI('L*("`@("`@
M("`@("`@=6YS970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y
M72D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<F5M;W9E3&%Y97(H;&%Y97(I"@H@("`@+RHJ"B`@("`@*B!496UP;W)A<FEL
M>2!R96UO=F4@86X@96YT:7)E(&-O;F9I9R!L87EE<BX@(%5312!7251(($-!
M4D4A"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@:V5Y"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`H;W!T:6]N86PI(&-O;F9I9R!L
M87EE<@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E
M<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5,87EE<B@D;&%Y97(I
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N
M6R1L87EE<ETI*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N
M6R1L87EE<ET@/2!A<G)A>2@I.PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[('-T;W)E*%ML87EE<ETI"@H@("`@+RHJ"B`@("`@
M*B!3=&]R97,@8V]N9FEG=7)A=&EO;B!D871A(&EN(&$@;&%Y97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@;&%Y97(@=&\@<W1O<F4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!O
M<B!014%2(&5R<F]R(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@D;&%Y97(@/2`G
M=7-E<B<L("1D871A(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G=R:71E0V]N9FEG1FEL92AN=6QL+"`D;&%Y97(L("1D871A*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T;T1E9F%U;'0H:V5Y*0H*("`@
M("\J*@H@("`@("H@56YS970@=&AE('5S97(M9&5F:6YE9"!V86QU92!O9B!A
M(&-O;F9I9R!K97DL(')E=F5R=&EN9R!T:&4*("`@("`J('9A;'5E('1O('1H
M92!S>7-T96TM9&5F:6YE9"!O;F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R!C;VYF:6<@:V5Y"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L(%12
M544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1O1&5F875L
M="@D:V5Y*0H@("`@>PH@("`@("`@('1R:6=G97)?97)R;W(H(E!%05)?0V]N
M9FEG.CIT;T1E9F%U;'0H*2!D97!R96-A=&5D+"!U<V4@4$5!4E]#;VYF:6<Z
M.G)E;6]V92@I(&EN<W1E860B+"!%7U5315)?3D]424-%*3L*("`@("`@("!R
M971U<FX@)'1H:7,M/G)E;6]V92@D:V5Y+"`G=7-E<B<I.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&1E9FEN961">2AK97DI"@H@("`@+RHJ"B`@
M("`@*B!496QL<R!W:&%T(&-O;F9I9R!L87EE<B!T:&%T(&=E=',@=&\@9&5F
M:6YE(&$@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG
M(&ME>0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG('1H92!C;VYF:6<@
M;&%Y97(L(&]R(&%N(&5M<'1Y('-T<FEN9R!I9B!N;W0@9F]U;F0*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!D
M969I;F5D0GDH)&ME>2D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M;&%Y97)S(&%S("1L87EE<BD@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D;&%Y97(["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&ES1&5F875L=&5D*&ME>2D*"B`@("`O*BH*("`@("`J(%1E;&QS('=H
M971H97(@82!C;VYF:6<@=F%L=64@:&%S(&$@<WES=&5M+61E9FEN960@=F%L
M=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@(&-O;F9I9R!K97D*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H*("`@("`J($!D97!R96-A=&5D"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES1&5F875L=&5D*"1K97DI"B`@("!["B`@("`@("`@
M=')I9V=E<E]E<G)O<B@B4$5!4E]#;VYF:6<Z.FES1&5F875L=&5D*"D@9&5P
M<F5C871E9"P@=7-E(%!%05)?0V]N9FEG.CID969I;F5D0GDH*2!I;G-T96%D
M(BP@15]54T527TY/5$E#12D["B`@("`@("`@<F5T=7)N("1T:&ES+3YD969I
M;F5D0GDH)&ME>2D@/3T@)W-Y<W1E;2<["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@:7-$969I;F5D*&ME>2D*"B`@("`O*BH*("`@("`J(%1E;&QS
M('=H971H97(@82!G:79E;B!K97D@97AI<W1S(&%S(&$@8V]N9FEG('9A;'5E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;"!W:&5T:&5R(#QC;VYF:6<@:V5Y/B!E
M>&ES=',@:6X@=&AI<R!O8FIE8W0*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!I<T1E9FEN960H)&ME>2D*("`@
M('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^;&%Y97)S(&%S("1L87EE<BD@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;
M)&QA>65R75LD:V5Y72DI('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!I<T1E9FEN961,87EE
M<BAK97DI"@H@("`@+RHJ"B`@("`@*B!496QL<R!W:&5T:&5R(&$@9VEV96X@
M8V]N9FEG(&QA>65R(&5X:7-T<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&-O;F9I9R!L87EE<@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"!W
M:&5T:&5R(#QC;VYF:6<@;&%Y97(^(&5X:7-T<R!I;B!T:&ES(&]B:F5C=`H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES1&5F:6YE9$QA>65R*"1L87EE<BD*("`@('L*("`@("`@("!R971U
M<FX@:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T3&%Y97)S*"D*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&QA>65R<R!D969I;F5D("AE>&-E<'0@=&AE
M("=D969A=6QT)R!O;F4I"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!O
M9B!T:&4@9&5F:6YE9"!L87EE<G,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3&%Y97)S*"D*("`@('L*("`@("`@("`D8V8@/2`D=&AI<RT^8V]N9FEG=7)A
M=&EO;CL*("`@("`@("!U;G-E="@D8V9;)V1E9F%U;'0G72D["B`@("`@("`@
M<F5T=7)N(&%R<F%Y7VME>7,H)&-F*3L*("`@('T*"B`@("`O+R!]?7T*?0H*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U)E9VES=')Y+G!H
M<```````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-3,T,@`Q
M,#0Q-S,V,S`P-@`P,C`T,3<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@
M?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\("`@("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N
M970N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z(%)E9VES=')Y+G!H<"QV(#$N-3`@,C`P
M-"\P,2\P."`Q-SHS,SHQ,B!S;FEP97(@17AP("0*"B\J"E1/1$\Z"B`@("`M
M(%1R86YS9F]R;2!I;G1O('-I;F=L971O;B@I"B`@("`M($%D9"!A<'!L:6-A
M=&EO;B!L979E;"!L;V-K("AA=F]I9"!C:&%N9V4@=&AE(')E9VES=')Y(&9R
M;VT@=&AE(&-M9&QI;F4*("`@("`@=VAI;&4@=7-I;F<@=&AE($=42R!I;G1E
M<F9A8V4L(&9O<B!E>"XI"BHO"G)E<75I<F5?;VYC92`B4WES=&5M+G!H<"([
M"G)E<75I<F5?;VYC92`B4$5!4BYP:'`B.PH*9&5F:6YE*"=014%27U)%1TE3
M5%)97T524D]27TQ/0TLG+"`@("TR*3L*9&5F:6YE*"=014%27U)%1TE35%)9
M7T524D]27T9/4DU!5"<L("TS*3L*9&5F:6YE*"=014%27U)%1TE35%)97T52
M4D]27T9)3$4G+"`@("TT*3L*"B\J*@H@*B!!9&UI;FES=')A=&EO;B!C;&%S
M<R!U<V5D('1O(&UA:6YT86EN('1H92!I;G-T86QL960@<&%C:V%G92!D871A
M8F%S92X*("HO"F-L87-S(%!%05)?4F5G:7-T<GD@97AT96YD<R!014%2"GL*
M("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ($1I<F5C=&]R>2!W:&5R
M92!R96=I<W1R>2!F:6QE<R!A<F4@<W1O<F5D+@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1S=&%T961I<B`]("<G.PH*("`@("\J*B!&
M:6QE('=H97)E('1H92!F:6QE(&UA<"!I<R!S=&]R960*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9FEL96UA<"`]("<G.PH*("`@("\J
M*B!.86UE(&]F(&9I;&4@=7-E9"!F;W(@;&]C:VEN9R!T:&4@<F5G:7-T<GD*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D;&]C:V9I;&4@
M/2`G)SL*"B`@("`O*BH@1FEL92!D97-C<FEP=&]R('5S960@9'5R:6YG(&QO
M8VMI;F<*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1L
M;V-K7V9P(#T@;G5L;#L*"B`@("`O*BH@36]D92!U<V5D(&1U<FEN9R!L;V-K
M:6YG"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&QO8VM?;6]D
M92`](#`[("\O(%A86"!53E53140*"B`@("`O*BH@0V%C:&4@;V8@<&%C:V%G
M92!I;F9O<FUA=&EO;BX@(%-T<G5C='5R93H*("`@("`J(&%R<F%Y*`H@("`@
M("H@("`G<&%C:V%G92<@/3X@87)R87DH)VED)R`]/B`N+BX@*2P*("`@("`J
M("`@+BXN("D*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1P
M:V=I;F9O7V-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH@0V%C:&4@;V8@9FEL
M92!M87`N("!3=')U8W1U<F4Z"B`@("`@*B!A<G)A>2@@)R]P871H+W1O+V9I
M;&4G(#T^("=P86-K86=E)RP@+BXN("D*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1F:6QE;6%P7V-A8VAE(#T@87)R87DH*3L*"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J
M(%!%05)?4F5G:7-T<GD@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`H;W!T:6]N86PI(%!%05(@:6YS=&%L;"!D:7)E8W1O<GD@
M*&9O<B`N<&AP(&9I;&5S*0H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%!%05)?4F5G:7-T<GDH)'!E87)?:6YS
M=&%L;%]D:7(@/2!014%27TE.4U1!3$Q?1$E2*0H@("`@>PH@("`@("`@('!A
M<F5N=#HZ4$5!4B@I.PH@("`@("`@("1D<R`]($1)4D5#5$]265]315!!4D%4
M3U(["B`@("`@("`@)'1H:7,M/FEN<W1A;&Q?9&ER(#T@)'!E87)?:6YS=&%L
M;%]D:7(["B`@("`@("`@)'1H:7,M/G-T871E9&ER(#T@)'!E87)?:6YS=&%L
M;%]D:7(N)&1S+B<N<F5G:7-T<GDG.PH@("`@("`@("1T:&ES+3YF:6QE;6%P
M("`]("1P96%R7VEN<W1A;&Q?9&ER+B1D<RXG+F9I;&5M87`G.PH@("`@("`@
M("1T:&ES+3YL;V-K9FEL92`]("1P96%R7VEN<W1A;&Q?9&ER+B1D<RXG+FQO
M8VLG.PH*("`@("`@("`O+R!86%@@0V]M<&%T:6)I;&ET>2!C;V1E('-H;W5L
M9"!B92!R96UO=F5D(&EN('1H92!F=71U<F4*("`@("`@("`O+R!R96YA;64@
M86QL(')E9VES=')Y(&9I;&5S(&EF(&%N>2!T;R!L;W=E<F-A<V4*("`@("`@
M("!I9B`H(4]37U=)3D1/5U,@)B8@)&AA;F1L92`]($!O<&5N9&ER*"1T:&ES
M+3YS=&%T961I<BDI('L*("`@("`@("`@("`@)&1E<W0@/2`D=&AI<RT^<W1A
M=&5D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2.PH@("`@("`@("`@("!W:&EL
M92`H9F%L<V4@(3T]("@D9FEL92`](')E861D:7(H)&AA;F1L92DI*2!["B`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXN*EM!+5I=+BI<+G)E
M9R0O)RP@)&9I;&4I*2!["B`@("`@("`@("`@("`@("`@("`@<F5N86UE*"1D
M97-T("X@)&9I;&4L("1D97-T("X@<W1R=&]L;W=E<B@D9FEL92DI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E
M9&ER*"1H86YD;&4I.PH@("`@("`@('T*("`@("`@("!I9B`H(69I;&5?97AI
M<W1S*"1T:&ES+3YF:6QE;6%P*2D@>PH@("`@("`@("`@("`D=&AI<RT^<F5B
M=6EL9$9I;&5-87`H*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9&5S=')U8W1O<@H*("`@("\J*@H@("`@("H@4$5!4E]296=I
M<W1R>2!D97-T<G5C=&]R+B`@36%K97,@<W5R92!N;R!L;V-K<R!A<F4@9F]R
M9V]T=&5N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?4$5!4E]296=I<W1R>2@I"B`@("!["B`@("`@("`@
M<&%R96YT.CI?4$5!4B@I.PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI
M<RT^;&]C:U]F<"DI('L*("`@("`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@H@("`@+R\@>WM[(%]A<W-E
M<G13=&%T941I<B@I"@H@("`@+RHJ"B`@("`@*B!-86ME('-U<F4@=&AE(&1I
M<F5C=&]R>2!W:&5R92!W92!K965P(')E9VES=')Y(&9I;&5S(&5X:7-T<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!I9B!D:7)E8W1O<GD@
M97AI<W1S+"!&04Q312!I9B!I="!C;W5L9"!N;W0@8F4*("`@("`J(&-R96%T
M960*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V%S<V5R=%-T871E1&ER*"D*("`@('L*("`@("`@("!I9B`H
M(4!I<U]D:7(H)'1H:7,M/G-T871E9&ER*2D@>PH@("`@("`@("`@("!I9B`H
M(5-Y<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@)'1H:7,M/G-T871E9&ER*2DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M8V]U;&0@;F]T(&-R96%T92!D:7)E8W1O<GD@)WLD=&AI<RT^<W1A=&5D:7)]
M)R(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]P86-K86=E1FEL
M94YA;64H*0H*("`@("\J*@H@("`@("H@1V5T('1H92!N86UE(&]F('1H92!F
M:6QE('=H97)E(&1A=&$@9F]R(&$@9VEV96X@<&%C:V%G92!I<R!S=&]R960N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&YA;64*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!R96=I<W1R>2!F:6QE(&YA;64*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&%C:V%G949I;&5.86UE*"1P86-K86=E*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^<W1A=&5D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+B`G+G)E9R<["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@7V]P96Y086-K86=E1FEL92@I"@H@("`@9G5N
M8W1I;VX@7V]P96Y086-K86=E1FEL92@D<&%C:V%G92P@)&UO9&4I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]A<W-E<G13=&%T941I<B@I.PH@("`@("`@("1F
M:6QE(#T@)'1H:7,M/E]P86-K86=E1FEL94YA;64H)'!A8VMA9V4I.PH@("`@
M("`@("1F<"`]($!F;W!E;B@D9FEL92P@)&UO9&4I.PH@("`@("`@(&EF("@A
M)&9P*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&9P.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(%]C;&]S95!A8VMA9V5&:6QE*"D*"B`@("!F=6YC=&EO;B!?8VQO<V5086-K
M86=E1FEL92@D9G`I"B`@("!["B`@("`@("`@9F-L;W-E*"1F<"D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F5B=6EL9$9I;&5-87`H*0H*("`@
M(&9U;F-T:6]N(')E8G5I;&1&:6QE36%P*"D*("`@('L*("`@("`@("`D<&%C
M:V%G97,@/2`D=&AI<RT^;&ES=%!A8VMA9V5S*"D["B`@("`@("`@)&9I;&5S
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D<&%C:V%G97,@87,@)'!A
M8VMA9V4I('L*("`@("`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^<&%C:V%G
M94EN9F\H)'!A8VMA9V4L("=V97)S:6]N)RD["B`@("`@("`@("`@("1F:6QE
M;&ES="`]("1T:&ES+3YP86-K86=E26YF;R@D<&%C:V%G92P@)V9I;&5L:7-T
M)RD["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&9I;&5L:7-T*2D@>PH@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@9F]R96%C:"`H)&9I;&5L:7-T(&%S("1N86UE(#T^("1A='1R<RD@
M>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG<F]L92==*2`F
M)B`D871T<G-;)W)O;&4G72`A/2`G<&AP)RD@>PH@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1A='1R<ULG8F%S96EN<W1A;&QD:7(G72DI('L*("`@
M("`@("`@("`@("`@("`@("`D9FEL92`]("1A='1R<ULG8F%S96EN<W1A;&QD
M:7(G72Y$25)%0U1/4EE?4T5005)!5$]2+B1N86UE.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1N86UE
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9I;&4@/2!P
M<F5G7W)E<&QA8V4H)RQ>+RLL)RP@)R<L("1F:6QE*3L*("`@("`@("`@("`@
M("`@("1F:6QE<ULD9FEL95T@/2`D<&%C:V%G93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("`D=&AI<RT^7V%S<V5R=%-T871E1&ER*"D["B`@
M("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES+3YF:6QE;6%P+"`G=V(G*3L*("`@
M("`@("!I9B`H(21F<"D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3YF:6QE;6%P7V-A8VAE(#T@)&9I;&5S
M.PH@("`@("`@(&9W<FET92@D9G`L('-E<FEA;&EZ92@D9FEL97,I*3L*("`@
M("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!R96%D1FEL94UA<"@I"@H@("`@9G5N
M8W1I;VX@<F5A9$9I;&5-87`H*0H@("`@>PH@("`@("`@("1F<"`]($!F;W!E
M;B@D=&AI<RT^9FEL96UA<"P@)W(G*3L*("`@("`@("!I9B`H(21F<"D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U!%05)?4F5G
M:7-T<GDZ(&-O=6QD(&YO="!O<&5N(&9I;&5M87`G+"!014%27U)%1TE35%)9
M7T524D]27T9)3$4L(&YU;&PL(&YU;&PL("1P:'!?97)R;W)M<V<I.PH@("`@
M("`@('T*("`@("`@("`D9G-I>F4@/2!F:6QE<VEZ92@D=&AI<RT^9FEL96UA
M<"D["B`@("`@("`@)')T(#T@9V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"D[
M"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*#`I.PH@("`@("`@
M("1D871A(#T@9G)E860H)&9P+"`D9G-I>F4I.PH@("`@("`@('-E=%]M86=I
M8U]Q=6]T97-?<G5N=&EM92@D<G0I.PH@("`@("`@(&9C;&]S92@D9G`I.PH@
M("`@("`@("1T;7`@/2!U;G-E<FEA;&EZ92@D9&%T82D["B`@("`@("`@:68@
M*"$D=&UP("8F("1F<VEZ92`^(#<I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=014%27U)E9VES=')Y.B!I;G9A;&ED(&9I;&5M
M87`@9&%T82<L(%!%05)?4D5'25-44EE?15)23U)?1D]234%4+"!N=6QL+"!N
M=6QL+"`D9&%T82D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YF:6QE;6%P
M7V-A8VAE(#T@)'1M<#L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!?;&]C:R@I"@H@("`@+RHJ"B`@("`@*B!,
M;V-K('1H92!R96=I<W1R>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B!L;V-K(&UO9&4L(&]N92!O9B!,3T-+7T58+"!,3T-+7U-((&]R($Q/0TM?
M54XN"B`@("`@*B`@("`@("`@("`@("`@("!3964@9FQO8VL@;6%N=6%L(&9O
M<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;"!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF(&QO8VMI;F<@9F%I;&5D+"!O
M<B!A"B`@("`@*B`@("`@("`@("`@("`@4$5!4B!E<G)O<B!I9B!S;VUE(&]T
M:&5R(&5R<F]R(&]C8W5R<R`H<W5C:"!A<R!T:&4*("`@("`J("`@("`@("`@
M("`@("!L;V-K(&9I;&4@;F]T(&)E:6YG('=R:71A8FQE*2X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO
M8VLH)&UO9&4@/2!,3T-+7T58*0H@("`@>PH@("`@("`@(&EF("@A97)E9VDH
M)U=I;F1O=W,@.2<L('!H<%]U;F%M92@I*2D@>PH@("`@("`@("`@("!I9B`H
M)&UO9&4@(3T@3$]#2U]53B`F)B!I<U]R97-O=7)C92@D=&AI<RT^;&]C:U]F
M<"DI('L*("`@("`@("`@("`@("`@("\O(%A86"!D;V5S(&YO="!C:&5C:R!T
M>7!E(&]F(&QO8VL@*$Q/0TM?4T@O3$]#2U]%6"D*("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E<G(@/2`D=&AI<RT^7V%S<V5R=%-T871E1&ER*"DI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D;W!E;E]M;V1E(#T@)W<G.PH@("`@("`@("`@("`O
M+R!86%@@4&5O<&QE(')E<&]R=&5D('!R;V)L96US('=I=&@@3$]#2U]32"!A
M;F0@)W<G"B`@("`@("`@("`@(&EF("@D;6]D92`]/3T@3$]#2U]32"!\?"`D
M;6]D92`]/3T@3$]#2U]53BD@>PH@("`@("`@("`@("`@("`@:68@*$`A:7-?
M9FEL92@D=&AI<RT^;&]C:V9I;&4I*2!["B`@("`@("`@("`@("`@("`@("`@
M=&]U8V@H)'1H:7,M/FQO8VMF:6QE*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1O<&5N7VUO9&4@/2`G<B<["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1T:&ES+3YL;V-K7V9P(#T@0&9O<&5N*"1T:&ES+3YL
M;V-K9FEL92P@)&]P96Y?;6]D92D["@H@("`@("`@("`@("!I9B`H(6ES7W)E
M<V]U<F-E*"1T:&ES+3YL;V-K7V9P*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N;W0@8W)E871E(&QO8VL@
M9FEL92(@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AI<W-E="@D<&AP7V5R<F]R;7-G*2`_("(Z("(@+B`D<&AP7V5R<F]R
M;7-G(#H@(B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(2AI
M;G0I9FQO8VLH)'1H:7,M/FQO8VM?9G`L("1M;V1E*2D@>PH@("`@("`@("`@
M("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@("`@("`@("`@("`@(&-A
M<V4@3$]#2U]32#H@)'-T<B`]("=S:&%R960G.R`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("!C87-E($Q/0TM?15@Z("1S='(@/2`G97AC;'5S:79E
M)SL@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92!,3T-+7U5..B`D
M<W1R(#T@)W5N;&]C:R<[("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z("`@("`@)'-T<B`]("=U;FMN;W=N)SL@("!B<F5A:SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&%C<75I<F4@)'-T<B!L;V-K("@D=&AI
M<RT^;&]C:V9I;&4I(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!014%27U)%1TE35%)97T524D]27TQ/0TLI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(%]U;FQO8VLH*0H*("`@(&9U;F-T:6]N
M(%]U;FQO8VLH*0H@("`@>PH@("`@("`@("1R970@/2`D=&AI<RT^7VQO8VLH
M3$]#2U]53BD["B`@("`@("`@)'1H:7,M/FQO8VM?9G`@/2!N=6QL.PH@("`@
M("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(%]P86-K86=E17AI<W1S*"D*"B`@("!F=6YC=&EO;B!?<&%C:V%G945X:7-T
M<R@D<&%C:V%G92D*("`@('L*("`@("`@("!R971U<FX@9FEL95]E>&ES=',H
M)'1H:7,M/E]P86-K86=E1FEL94YA;64H)'!A8VMA9V4I*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!?<&%C:V%G94EN9F\H*0H*("`@(&9U;F-T
M:6]N(%]P86-K86=E26YF;R@D<&%C:V%G92`](&YU;&PL("1K97D@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@D<&%C:V%G92`]/3T@;G5L;"D@>PH@("`@
M("`@("`@("!R971U<FX@87)R87E?;6%P*&%R<F%Y*"1T:&ES+"`G7W!A8VMA
M9V5);F9O)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]L:7-T4&%C:V%G97,H*2D["B`@("`@("`@?0H@("`@("`@("1F<"`]("1T
M:&ES+3Y?;W!E;E!A8VMA9V5&:6QE*"1P86-K86=E+"`G<B<I.PH@("`@("`@
M(&EF("@D9G`@/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@("`@("1R="`](&=E=%]M86=I8U]Q=6]T97-?<G5N
M=&EM92@I.PH@("`@("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@P*3L*
M("`@("`@("`D9&%T82`](&9R96%D*"1F<"P@9FEL97-I>F4H)'1H:7,M/E]P
M86-K86=E1FEL94YA;64H)'!A8VMA9V4I*2D["B`@("`@("`@<V5T7VUA9VEC
M7W%U;W1E<U]R=6YT:6UE*"1R="D["B`@("`@("`@)'1H:7,M/E]C;&]S95!A
M8VMA9V5&:6QE*"1F<"D["B`@("`@("`@)&1A=&$@/2!U;G-E<FEA;&EZ92@D
M9&%T82D["B`@("`@("`@:68@*"1K97D@/3T](&YU;&PI('L*("`@("`@("`@
M("`@<F5T=7)N("1D871A.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)&1A=&%;)&ME>5TI*2!["B`@("`@("`@("`@(')E='5R;B`D9&%T85LD:V5Y
M73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@7VQI<W1086-K86=E<R@I"@H@("`@9G5N8W1I
M;VX@7VQI<W1086-K86=E<R@I"B`@("!["B`@("`@("`@)'!K9VQI<W0@/2!A
M<G)A>2@I.PH@("`@("`@("1D<"`]($!O<&5N9&ER*"1T:&ES+3YS=&%T961I
M<BD["B`@("`@("`@:68@*"$D9'`I('L*("`@("`@("`@("`@<F5T=7)N("1P
M:V=L:7-T.PH@("`@("`@('T*("`@("`@("!W:&EL92`H)&5N="`](')E861D
M:7(H)&1P*2D@>PH@("`@("`@("`@("!I9B`H)&5N='LP?2`]/2`G+B<@?'P@
M<W5B<W1R*"1E;G0L("TT*2`A/2`G+G)E9R<I('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P:V=L:7-T
M6UT@/2!S=6)S='(H)&5N="P@,"P@+30I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'!K9VQI<W0["B`@("!]"@H@("`@+R\@?7U]"@H@("`@+R\@>WM[
M('!A8VMA9V5%>&ES=',H*0H*("`@(&9U;F-T:6]N('!A8VMA9V5%>&ES=',H
M)'!A8VMA9V4I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@
M/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2!["B`@("`@("`@("`@(')E='5R
M;B`D93L*("`@("`@("!]"B`@("`@("`@)')E="`]("1T:&ES+3Y?<&%C:V%G
M945X:7-T<R@D<&%C:V%G92D["B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L*
M("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!P86-K86=E26YF;R@I"@H@("`@9G5N8W1I;VX@<&%C:V%G94EN9F\H
M)'!A8VMA9V4@/2!N=6QL+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1E.PH@("`@("`@('T*("`@("`@("`D
M<F5T(#T@)'1H:7,M/E]P86-K86=E26YF;R@D<&%C:V%G92P@)&ME>2D["B`@
M("`@("`@)'1H:7,M/E]U;FQO8VLH*3L*("`@("`@("!R971U<FX@)')E=#L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!L:7-T4&%C:V%G97,H*0H*
M("`@(&9U;F-T:6]N(&QI<W1086-K86=E<R@I"B`@("!["B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![
M"B`@("`@("`@("`@(')E='5R;B`D93L*("`@("`@("!]"B`@("`@("`@)')E
M="`]("1T:&ES+3Y?;&ES=%!A8VMA9V5S*"D["B`@("`@("`@)'1H:7,M/E]U
M;FQO8VLH*3L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!A9&1086-K86=E*"D*"B`@("!F=6YC=&EO;B!A9&10
M86-K86=E*"1P86-K86=E+"`D:6YF;RD*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/G!A8VMA9V5%>&ES=',H)'!A8VMA9V4I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]%6"DI*2!["B`@("`@("`@("`@
M(')E='5R;B`D93L*("`@("`@("!]"B`@("`@("`@)&9P(#T@)'1H:7,M/E]O
M<&5N4&%C:V%G949I;&4H)'!A8VMA9V4L("=W8B<I.PH@("`@("`@(&EF("@D
M9G`@/3T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D
M:6YF;ULG7VQA<W1M;V1I9FEE9"==(#T@=&EM92@I.PH@("`@("`@(&9W<FET
M92@D9G`L('-E<FEA;&EZ92@D:6YF;RDI.PH@("`@("`@("1T:&ES+3Y?8VQO
M<V5086-K86=E1FEL92@D9G`I.PH@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9&5L971E4&%C:V%G92@I"@H@("`@9G5N8W1I;VX@9&5L971E4&%C
M:V%G92@D<&%C:V%G92D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI('L*("`@("`@("`@("`@
M<F5T=7)N("1E.PH@("`@("`@('T*("`@("`@("`D9FEL92`]("1T:&ES+3Y?
M<&%C:V%G949I;&5.86UE*"1P86-K86=E*3L*("`@("`@("`D<F5T(#T@0'5N
M;&EN:R@D9FEL92D["B`@("`@("`@)'1H:7,M/G)E8G5I;&1&:6QE36%P*"D[
M"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L*("`@("`@("!R971U<FX@)')E
M=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!U<&1A=&5086-K86=E
M*"D*"B`@("!F=6YC=&EO;B!U<&1A=&5086-K86=E*"1P86-K86=E+"`D:6YF
M;RP@)&UE<F=E(#T@=')U92D*("`@('L*("`@("`@("`D;VQD:6YF;R`]("1T
M:&ES+3YP86-K86=E26YF;R@D<&%C:V%G92D["B`@("`@("`@:68@*&5M<'1Y
M*"1O;&1I;F9O*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L
M;V-K*$Q/0TM?15@I*2D@>PH@("`@("`@("`@("!R971U<FX@)&4["B`@("`@
M("`@?0H@("`@("`@("1F<"`]("1T:&ES+3Y?;W!E;E!A8VMA9V5&:6QE*"1P
M86-K86=E+"`G=R<I.PH@("`@("`@(&EF("@D9G`@/3T](&YU;&PI('L*("`@
M("`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D:6YF;ULG7VQA<W1M;V1I9FEE
M9"==(#T@=&EM92@I.PH@("`@("`@(&EF("@D;65R9V4I('L*("`@("`@("`@
M("`@9G=R:71E*"1F<"P@<V5R:6%L:7IE*&%R<F%Y7VUE<F=E*"1O;&1I;F9O
M+"`D:6YF;RDI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F=W)I
M=&4H)&9P+"!S97)I86QI>F4H)&EN9F\I*3L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/E]C;&]S95!A8VMA9V5&:6QE*"1F<"D["B`@("`@("`@:68@*&ES
M<V5T*"1I;F9O6R=F:6QE;&ES="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<F5B=6EL9$9I;&5-87`H*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]U
M;FQO8VLH*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!C:&5C:T9I;&5-87`H*0H*("`@("\J*@H@("`@("H@
M5&5S="!W:&5T:&5R(&$@9FEL92!B96QO;F=S('1O(&$@<&%C:V%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H(&9I;&4@<&%T:"P@86)S
M;VQU=&4@;W(@<F5L871I=F4@=&\@=&AE('!E87(*("`@("`J(&EN<W1A;&P@
M9&ER"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@=VAI8V@@<&%C:V%G
M92!T:&4@9FEL92!B96QO;F=S('1O+"!O<B!A;B!E;7!T>0H@("`@("H@<W1R
M:6YG(&EF('1H92!F:6QE(&1O97,@;F]T(&)E;&]N9R!T;R!A;B!I;G-T86QL
M960@<&%C:V%G90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-H96-K1FEL94UA<"@D<&%T:"D*("`@('L*("`@
M("`@("!I9B`H:7-?87)R87DH)'!A=&@I*2!["B`@("`@("`@("`@('-T871I
M8R`D;F]T96UP='D["B`@("`@("`@("`@(&EF("AE;7!T>2@D;F]T96UP='DI
M*2!["B`@("`@("`@("`@("`@("`D;F]T96UP='D@/2!C<F5A=&5?9G5N8W1I
M;VXH)R1A)RPG<F5T=7)N("%E;7!T>2@D82D[)RD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'!K9W,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E
M86-H("@D<&%T:"!A<R`D;F%M92`]/B`D871T<G,I('L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D871T<G,I("8F(&ES<V5T*"1A='1R<ULG8F%S
M96EN<W1A;&QD:7(G72DI('L*("`@("`@("`@("`@("`@("`@("`D;F%M92`]
M("1A='1R<ULG8F%S96EN<W1A;&QD:7(G72Y$25)%0U1/4EE?4T5005)!5$]2
M+B1N86UE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'!K
M9W-;)&YA;65=(#T@)'1H:7,M/F-H96-K1FEL94UA<"@D;F%M92D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7V9I;'1E<B@D<&MG
M<RP@)&YO=&5M<'1Y*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1T
M:&ES+3YF:6QE;6%P7V-A8VAE*2`F)B!014%2.CII<T5R<F]R*"1T:&ES+3YR
M96%D1FEL94UA<"@I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YF:6QE;6%P7V-A8VAE
M6R1P871H72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF:6QE;6%P
M7V-A8VAE6R1P871H73L*("`@("`@("!]"B`@("`@("`@)&P@/2!S=')L96XH
M)'1H:7,M/FEN<W1A;&Q?9&ER*3L*("`@("`@("!I9B`H<W5B<W1R*"1P871H
M+"`P+"`D;"D@/3T@)'1H:7,M/FEN<W1A;&Q?9&ER*2!["B`@("`@("`@("`@
M("1P871H(#T@<')E9U]R97!L86-E*"<A7B<N1$E214-43U)97U-%4$%2051/
M4BXG*R$G+"`G)RP@<W5B<W1R*"1P871H+"`D;"DI.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/F9I;&5M87!?8V%C:&5;)'!A=&A=*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9I;&5M87!?8V%C:&5;)'!A
M=&A=.PH@("`@("`@('T*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@
M+R\@?7U]"@I]"@H_/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G97(N<&AP````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,#8V`#$P-#$W,S8S,#`V`#`R
M,#,R,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`U("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M("`@("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!086-K86=E<BYP:'`L=B`Q+C4R(#(P
M,#0O,#$O,#@@,3<Z,S,Z,3(@<VYI<&5R($5X<"`D"@IR97%U:7)E7V]N8V4@
M)U!%05(O0V]M;6]N+G!H<"<["G)E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[
M"@HO*BH*("H@061M:6YI<W1R871I;VX@8VQA<W,@=7-E9"!T;R!M86ME(&$@
M4$5!4B!R96QE87-E('1A<F)A;&PN"B`J"B`J(%1/1$\Z"B`J("`M(&%D9"!A
M;B!E>'1R82!P87)A;2!T:&4@9&ER('=H97)E('1O('!L86-E('1H92!C<F5A
M=&5D('!A8VMA9V4*("H*("H@0'-I;F-E(%!(4"`T+C`N,@H@*B!`875T:&]R
M(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("HO"F-L87-S(%!%05)?4&%C
M:V%G97(@97AT96YD<R!014%27T-O;6UO;@I["B`@("`O+R![>WL@8V]N<W1R
M=6-T;W(*"B`@("!F=6YC=&EO;B!014%27U!A8VMA9V5R*"D*("`@('L*("`@
M("`@("!P87)E;G0Z.E!%05)?0V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9&5S=')U8W1O<@H*("`@(&9U;F-T:6]N(%]014%27U!A
M8VMA9V5R*"D*("`@('L*("`@("`@("!P87)E;G0Z.E]014%27T-O;6UO;B@I
M.PH@("`@?0H*("`@("\O('U]?0H*("`@("\O('M[>R!P86-K86=E*"D*"B`@
M("!F=6YC=&EO;B!P86-K86=E*"1P:V=F:6QE(#T@;G5L;"P@)&-O;7!R97-S
M(#T@=')U92D*("`@('L*("`@("`@("`O+R![>WL@=F%L:61A=&4@<W5P<&QI
M960@<&%C:V%G92YX;6P@9FEL90H@("`@("`@(&EF("AE;7!T>2@D<&MG9FEL
M92DI('L*("`@("`@("`@("`@)'!K9V9I;&4@/2`G<&%C:V%G92YX;6PG.PH@
M("`@("`@('T*("`@("`@("`O+R`D=&AI<RT^<&MG:6YF;R!G971S('!O<'5L
M871E9"!I;G-I9&4*("`@("`@("`D<&MG:6YF;R`]("1T:&ES+3YI;F9O1G)O
M;41E<V-R:7!T:6]N1FEL92@D<&MG9FEL92D["B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)'!K9VEN9F\I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D<&MG:6YF;RD["B`@("`@("`@?0H*("`@("`@("`D
M<&MG9&ER(#T@9&ER;F%M92AR96%L<&%T:"@D<&MG9FEL92DI.PH@("`@("`@
M("1P:V=F:6QE(#T@8F%S96YA;64H)'!K9V9I;&4I.PH*("`@("`@("`D97)R
M;W)S(#T@)'=A<FYI;F=S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^=F%L
M:61A=&5086-K86=E26YF;R@D<&MG:6YF;RP@)&5R<F]R<RP@)'=A<FYI;F=S
M+"`D<&MG9&ER*3L*("`@("`@("!F;W)E86-H("@D=V%R;FEN9W,@87,@)'<I
M('L*("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B5V%R;FEN9SH@)'<B*3L*
M("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&5R<F]R<R!A<R`D92D@>PH@
M("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")%<G)O<CH@)&4B*3L*("`@("`@
M("!]"B`@("`@("`@:68@*'-I>F5O9B@D97)R;W)S*2`^(#`I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=%<G)O<G,@:6X@<&%C
M:V%G92<I.PH@("`@("`@('T*("`@("`@("`O+R!]?7T*"B`@("`@("`@)'!K
M9W9E<B`]("1P:V=I;F9O6R=P86-K86=E)UT@+B`G+2<@+B`D<&MG:6YF;ULG
M=F5R<VEO;B==.PH*("`@("`@("`O+R![>WL@0W)E871E('1H92!P86-K86=E
M(&9I;&4@;&ES=`H@("`@("`@("1F:6QE;&ES="`](&%R<F%Y*"D["B`@("`@
M("`@)&D@/2`P.PH*("`@("`@("!F;W)E86-H("@D<&MG:6YF;ULG9FEL96QI
M<W0G72!A<R`D9FYA;64@/3X@)&%T=',I('L*("`@("`@("`@("`@)&9I;&4@
M/2`D<&MG9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1F;F%M93L*("`@
M("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL92DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1FEL92!D;V5S(&YO
M="!E>&ES=#H@)&9N86UE(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D9FEL96QI<W1;)&DK*UT@/2`D9FEL93L*("`@("`@("`@
M("`@("`@(&EF("AE;7!T>2@D<&MG:6YF;ULG9FEL96QI<W0G75LD9FYA;65=
M6R=M9#5S=6TG72DI('L*("`@("`@("`@("`@("`@("`@("`D;60U<W5M(#T@
M;60U7V9I;&4H)&9I;&4I.PH@("`@("`@("`@("`@("`@("`@("1T<&MG:6YF
M;ULG9FEL96QI<W0G75LD9FYA;65=6R=M9#5S=6TG72`]("1M9#5S=6T["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#(L
M(")!9&1I;F<@9FEL92`D9FYA;64B*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`O+R!]?7T*"B`@("`@("`@+R\@>WM[(')E9V5N97)A=&4@
M<&%C:V%G92YX;6P*("`@("`@("`D;F5W7WAM;"`]("1T:&ES+3YX;6Q&<F]M
M26YF;R@D<&MG:6YF;RD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&YE
M=U]X;6PI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@D;F5W7WAM;"D["B`@("`@("`@?0H@("`@("`@(&EF("@A*"1T;7!D:7(@
M/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G*2DI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]086-K86=E<CH@;6MT
M96UP(&9A:6QE9"(I.PH@("`@("`@('T*("`@("`@("`D;F5W<&MG9FEL92`]
M("1T;7!D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA9V4N>&UL
M)SL*("`@("`@("`D;G`@/2!`9F]P96XH)&YE=W!K9V9I;&4L("=W8B<I.PH@
M("`@("`@(&EF("@A)&YP*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B4$5!4E]086-K86=E<CH@=6YA8FQE('1O(')E=W)I=&4@
M)'!K9V9I;&4@87,@)&YE=W!K9V9I;&4B*3L*("`@("`@("!]"B`@("`@("`@
M9G=R:71E*"1N<"P@)&YE=U]X;6PI.PH@("`@("`@(&9C;&]S92@D;G`I.PH@
M("`@("`@("\O('U]?0H*("`@("`@("`O+R![>WL@5$%2('1H92!086-K86=E
M("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*
M("`@("`@("`D97AT(#T@)&-O;7!R97-S(#\@)RYT9WHG(#H@)RYT87(G.PH@
M("`@("`@("1D97-T7W!A8VMA9V4@/2!G971C=V0H*2`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`D<&MG=F5R("X@)&5X=#L*("`@("`@("`D=&%R(#TF(&YE
M=R!!<F-H:79E7U1A<B@D9&5S=%]P86-K86=E+"`D8V]M<')E<W,I.PH@("`@
M("`@("1T87(M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.R`O+R!86%@@1&]N)W0@<')I;G0@97)R;W)S"B`@("`@("`@+R\@+2TM+2T@
M0W)E871E<R!W:71H('1H92!P86-K86=E+GAM;"!F:6QE"B`@("`@("`@)&]K
M(#T@)'1A<BT^8W)E871E36]D:69Y*&%R<F%Y*"1N97=P:V=F:6QE*2P@)R<L
M("1T;7!D:7(I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1O:RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1O:RD["B`@
M("`@("`@?2!E;'-E:68@*"$D;VLI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=014%27U!A8VMA9V5R.B!T87)B86QL(&-R96%T
M:6]N(&9A:6QE9"<I.PH@("`@("`@('T*("`@("`@("`O+R`M+2TM+2!!9&0@
M=&AE(&-O;G1E;G0@;V8@=&AE('!A8VMA9V4*("`@("`@("!I9B`H(21T87(M
M/F%D9$UO9&EF>2@D9FEL96QI<W0L("1P:V=V97(L("1P:V=D:7(I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G4$5!4E]086-K
M86=E<CH@=&%R8F%L;"!C<F5A=&EO;B!F86EL960G*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/FQO9R@Q+"`B4&%C:V%G92`D9&5S=%]P86-K86=E(&1O
M;F4B*3L*("`@("`@("!I9B`H9FEL95]E>&ES=',H(B1P:V=D:7(O0U93+U)O
M;W0B*2D@>PH@("`@("`@("`@("`D8W9S=F5R<VEO;B`]('!R96=?<F5P;&%C
M92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D<&MG:6YF;ULG=F5R<VEO;B==*3L*
M("`@("`@("`@("`@)&-V<W1A9R`](")214Q%05-%7R1C=G-V97)S:6]N(CL*
M("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B5&%G('1H92!R96QE87-E9"!C
M;V1E('=I=&@@8'!E87(@8W9S=&%G("1P:V=F:6QE)R(I.PH@("`@("`@("`@
M("`D=&AI<RT^;&]G*#$L("(H;W(@<V5T('1H92!#5E,@=&%G("1C=G-T86<@
M8GD@:&%N9"DB*3L*("`@("`@("!]"B`@("`@("`@+R\@?7U]"@H@("`@("`@
M(')E='5R;B`D9&5S=%]P86-K86=E.PH@("`@?0H*("`@("\O('U]?0I]"@HO
M+R![>WL@;60U7V9I;&4H*2!U=&EL:71Y(&9U;F-T:6]N"FEF("@A9G5N8W1I
M;VY?97AI<W1S*"=M9#5?9FEL92<I*2!["B`@("!F=6YC=&EO;B!M9#5?9FEL
M92@D9FEL92D@>PH@("`@("`@(&EF("@A)&9D(#T@0&9O<&5N*"1F:6QE+"`G
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@)&UD-2`](&UD-2AF<F5A9"@D9F0L(&9I;&5S:7IE*"1F:6QE*2DI
M.PH@("`@("`@(&9C;&]S92@D9F0I.PH@("`@("`@(')E='5R;B`D;60U.PH@
M("`@?0I]"B\O('U]?0H*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]!=71O;&]A9&5R+G!H<```````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34T,S``,3`T,3<S-C,P,#8`,#(P-S`R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\O("\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W
M:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`U("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!!=71O;&]A9&5R+G!H<"QV(#$N,3`@
M,C`P-"\P,2\P."`Q-SHS,SHQ,B!S;FEP97(@17AP("0*"FEF("@A97AT96YS
M:6]N7VQO861E9"@B;W9E<FQO860B*2D@>PH@("`@+R\@9&EE(&AA<F0@=VET
M:&]U="!E>'0O;W9E<FQO860*("`@(&1I92@B4F5B=6EL9"!02%`@=VET:"!T
M:&4@8&]V97)L;V%D)R!E>'1E;G-I;VX@=&\@=7-E(%!%05)?075T;VQO861E
M<B(I.PI]"@IR97%U:7)E7V]N8V4@(E!%05(N<&AP(CL*"B\J*@H@*B!4:&ES
M(&-L87-S(&ES(&9O<B!O8FIE8W1S('=H97)E('EO=2!W86YT('1O('-E<&%R
M871E('1H92!C;V1E(&9O<@H@*B!S;VUE(&UE=&AO9',@:6YT;R!S97!A<F%T
M92!C;&%S<V5S+B`@5&AI<R!I<R!U<V5F=6P@:68@>6]U(&AA=F4@80H@*B!C
M;&%S<R!W:71H(&YO="UF<F5Q=65N=&QY+75S960@;65T:&]D<R!T:&%T(&-O
M;G1A:6X@;&]T<R!O9B!C;V1E"B`J('1H870@>6]U('=O=6QD(&QI:V4@=&\@
M879O:60@86QW87ES('!A<G-I;F<N"B`J"B`J(%1H92!014%27T%U=&]L;V%D
M97(@8VQA<W,@<')O=FED97,@875T;VQO861I;F<@86YD(&%G9W)E9V%T:6]N
M+@H@*B!4:&4@875T;VQO861I;F<@;&5T<R!Y;W4@<V5T('5P(&EN('=H:6-H
M(&-L87-S97,@=&AE('-E<&%R871E9`H@*B!M971H;V1S(&%R92!F;W5N9"X@
M($%G9W)E9V%T:6]N(&ES('1H92!T96-H;FEQ=64@=7-E9"!T;R!I;7!O<G0@
M;F5W"B`J(&UE=&AO9',L(&%N(&EN<W1A;F-E(&]F(&5A8V@@8VQA<W,@<')O
M=FED:6YG('-E<&%R871E9"!M971H;V1S(&ES"B`J('-T;W)E9"!A;F0@8V%L
M;&5D(&5V97)Y('1I;64@=&AE(&%G9W)E9V%T960@;65T:&]D(&ES(&-A;&QE
M9"X*("H*("H@0&%U=&AO<B!3=&EG(%/F=&AE<B!"86MK96X@/'-S8D!P:'`N
M;F5T/@H@*B\*8VQA<W,@4$5!4E]!=71O;&]A9&5R(&5X=&5N9',@4$5!4@I[
M"B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@36%P(&]F
M(&UE=&AO9',@86YD(&-L87-S97,@=VAE<F4@=&AE>2!A<F4@9&5F:6YE9`H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?875T;VQO861?;6%P(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($UA<"!O9B!M971H;V1S(&%N9"!A9V=R
M96=A=&4@;V)J96-T<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;65T
M:&]D7VUA<"`](&%R<F%Y*"D["@H@("`@+R\@?7U]"B`@("`O+R![>WL@861D
M075T;VQO860H*0H*("`@("\J*@H@("`@("H@061D(&]N92!O<B!M;W)E(&%U
M=&]L;V%D(&5N=')I97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;65T:&]D("`@("!W:&EC:"!M971H;V0@=&\@875T;VQO860*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<VYA;64@("AO<'1I;VYA;"D@=VAI
M8V@@8VQA<W,@=&\@9FEN9"!T:&4@;65T:&]D(&EN+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!)9B!T:&4@)&UE=&AO9"!P87)A;65T97(@
M:7,@86X@87)R87DL('1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<&%R86UE=&5R(&UA>2!B92!O;6ET=&5D("AA;F0@=VEL;"!B92!I
M9VYO<F5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF(&YO
M="DL(&%N9"!T:&4@)&UE=&AO9"!P87)A;65T97(@=VEL;"!B90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T<F5A=&5D(&%S(&%N(&%S<V]C
M:6%T:79E(&%R<F%Y('=I=&@@;65T:&]D"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YA;65S(&%S(&ME>7,@86YD(&-L87-S(&YA;65S(&%S
M('9A;'5E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1!
M=71O;&]A9"@D;65T:&]D+"`D8VQA<W-N86UE(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H:7-?87)R87DH)&UE=&AO9"DI('L*("`@("`@("`@("`@87)R
M87E?=V%L:R@D;65T:&]D+"!C<F5A=&5?9G5N8W1I;VXH)R1A+"8D8B<L("<D
M8B`]('-T<G1O;&]W97(H)&(I.R<I*3L*("`@("`@("`@("`@)'1H:7,M/E]A
M=71O;&]A9%]M87`@/2!A<G)A>5]M97)G92@D=&AI<RT^7V%U=&]L;V%D7VUA
M<"P@)&UE=&AO9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/E]A=71O;&]A9%]M87!;<W1R=&]L;W=E<B@D;65T:&]D*5T@/2`D8VQA
M<W-N86UE.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!R96UO=F5!=71O;&]A9"@I"@H@("`@+RHJ"B`@("`@*B!296UO=F4@86X@
M875T;VQO860@96YT<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;65T:&]D("!W:&EC:"!M971H;V0@=&\@<F5M;W9E('1H92!A=71O;&]A9"!E
M;G1R>2!F;W(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!I9B!A
M;B!E;G1R>2!W87,@<F5M;W9E9"P@1D%,4T4@:68@;F]T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E
M075T;VQO860H)&UE=&AO9"D*("`@('L*("`@("`@("`D;65T:&]D(#T@<W1R
M=&]L;W=E<B@D;65T:&]D*3L*("`@("`@("`D;VL@/2!I<W-E="@D=&AI<RT^
M7V%U=&]L;V%D7VUA<%LD;65T:&]D72D["B`@("`@("`@=6YS970H)'1H:7,M
M/E]A=71O;&]A9%]M87!;)&UE=&AO9%TI.PH@("`@("`@(')E='5R;B`D;VL[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@861D06=G<F5G871E3V)J
M96-T*"D*"B`@("`O*BH*("`@("`J($%D9"!A;B!A9V=R96=A=&4@;V)J96-T
M('1O('1H:7,@;V)J96-T+B`@268@=&AE('-P96-I9FEE9"!C;&%S<PH@("`@
M("H@:7,@;F]T(&1E9FEN960L(&QO861I;F<@:70@=VEL;"!B92!A='1E;7!T
M960@9F]L;&]W:6YG(%!%05(G<PH@("`@("H@9FEL92!N86UI;F<@<V-H96UE
M+B`@06QL('1H92!M971H;V1S(&EN('1H92!C;&%S<R!W:6QL(&)E"B`@("`@
M*B!A9V=R96=A=&5D+"!E>&-E<'0@<')I=F%T92!O;F5S("AN86UE('-T87)T
M:6YG('=I=&@@86X*("`@("`J('5N9&5R<V-O<F4I(&%N9"!C;VYS=')U8W1O
M<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W-N86UE("!W
M:&%T(&-L87-S('1O(&EN<W1A;G1I871E(&9O<B!T:&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$%G9W)E9V%T94]B:F5C
M="@D8VQA<W-N86UE*0H@("`@>PH@("`@("`@("1C;&%S<VYA;64@/2!S=')T
M;VQO=V5R*"1C;&%S<VYA;64I.PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"1C;&%S<VYA;64I*2!["B`@("`@("`@("`@("1I;F-L=61E7V9I;&4@/2!P
M<F5G7W)E<&QA8V4H)R];7F$M>C`M.5TO:2<L("=?)RP@)&-L87-S;F%M92D[
M"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D:6YC;'5D95]F:6QE.PH@("`@
M("`@('T*("`@("`@("`D;V)J(#TF(&YE=R`D8VQA<W-N86UE.PH@("`@("`@
M("1M971H;V1S(#T@9V5T7V-L87-S7VUE=&AO9',H)&-L87-S;F%M92D["B`@
M("`@("`@9F]R96%C:"`H)&UE=&AO9',@87,@)&UE=&AO9"D@>PH@("`@("`@
M("`@("`O+R!D;VXG="!I;7!O<G0@<')I=FEA=&4@;65T:&]D<R!A;F0@8V]N
M<W1R=6-T;W)S"B`@("`@("`@("`@(&EF("@D;65T:&]D>S!]("$]("=?)R`F
M)B`D;65T:&]D("$]("1C;&%S<VYA;64I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;65T:&]D7VUA<%LD;65T:&]D72`]("1O8FH["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F5M
M;W9E06=G<F5G871E3V)J96-T*"D*"B`@("`O*BH*("`@("`J(%)E;6]V92!A
M;B!A9V=R96=A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-L87-S;F%M92`@=&AE(&-L87-S(&]F('1H92!O8FIE8W0@=&\@<F5M
M;W9E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&EF(&%N(&]B
M:F5C="!W87,@<F5M;W9E9"P@1D%,4T4@:68@;F]T"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E06=G
M<F5G871E3V)J96-T*"1C;&%S<VYA;64I"B`@("!["B`@("`@("`@)&]K(#T@
M9F%L<V4["B`@("`@("`@)&-L87-S;F%M92`]('-T<G1O;&]W97(H)&-L87-S
M;F%M92D["B`@("`@("`@<F5S970H)'1H:7,M/E]M971H;V1?;6%P*3L*("`@
M("`@("!W:&EL92`H;&ES="@D;65T:&]D+"`D;V)J*2`](&5A8V@H)'1H:7,M
M/E]M971H;V1?;6%P*2D@>PH@("`@("`@("`@("!I9B`H9V5T7V-L87-S*"1O
M8FHI(#T]("1C;&%S<VYA;64I('L*("`@("`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3Y?;65T:&]D7VUA<%LD;65T:&]D72D["B`@("`@("`@("`@("`@("`D
M;VL@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D;VL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7U]C86QL
M*"D*"B`@("`O*BH*("`@("`J($]V97)L;V%D960@;V)J96-T(&-A;&P@:&%N
M9&QE<BP@8V%L;&5D(&5A8V@@=&EM92!A;@H@("`@("H@=6YD969I;F5D+V%G
M9W)E9V%T960@;65T:&]D(&ES(&EN=F]K960N("!4:&ES(&UE=&AO9"!R97!E
M871S"B`@("`@*B!T:&4@8V%L;"!I;B!T:&4@<FEG:'0@86=G<F5G871E(&]B
M:F5C="!A;F0@<&%S<V5S(&]N('1H92!R971U<FX*("`@("`J('9A;'5E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@=VAI8V@@;65T
M:&]D('1H870@=V%S(&-A;&QE9`H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&%R9W,@("`@06X@87)R87D@;V8@=&AE('!A<F%M971E<G,@<&%S<V5D
M(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!O<FEG:6YA
M;"!C86QL"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E='5R
M;B!V86QU92!F<F]M('1H92!A9V=R96=A=&5D(&UE=&AO9"P@;W(@82!014%2
M"B`@("`@*B`@("`@("`@("`@("`@("!E<G)O<B!I9B!T:&4@8V%L;&5D(&UE
M=&AO9"!W87,@=6YK;F]W;BX*("`@("`J+PH@("`@9G5N8W1I;VX@7U]C86QL
M*"1M971H;V0L("1A<F=S+"`F)')E='9A;"D*("`@('L*("`@("`@("`D;65T
M:&]D(#T@<W1R=&]L;W=E<B@D;65T:&]D*3L*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]M971H;V1?;6%P6R1M971H;V1=*2`F)B!I<W-E="@D=&AI<RT^
M7V%U=&]L;V%D7VUA<%LD;65T:&]D72DI('L*("`@("`@("`@("`@)'1H:7,M
M/F%D9$%G9W)E9V%T94]B:F5C="@D=&AI<RT^7V%U=&]L;V%D7VUA<%LD;65T
M:&]D72D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VUE
M=&AO9%]M87!;)&UE=&AO9%TI*2!["B`@("`@("`@("`@("1R971V86P@/2!C
M86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@D=&AI<RT^7VUE=&AO9%]M87!;
M)&UE=&AO9%TL("1M971H;V0I+"`D87)G<RD["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+R\@?7U]"GT*"F]V97)L;V%D*")014%27T%U=&]L;V%D97(B*3L*
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!
M4B]#;VUM;VXN<&AP````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`R,#8T,C(`,3`T,3<S-C,P,#8`,#(P,#,V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O
M('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F
M:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG('5R
M;#H@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(
M4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N
M;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO
M<G,Z(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!4;VUA<R!6+E8N
M0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D
M260Z($-O;6UO;BYP:'`L=B`Q+C$Q.2`R,#`T+S`Q+S(V(#`P.C4W.C,P('!A
M:F]Y92!%>'`@)`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["G)E<75I<F5?
M;VYC92`G07)C:&EV92]487(N<&AP)SL*<F5Q=6ER95]O;F-E("=3>7-T96TN
M<&AP)SL*<F5Q=6ER95]O;F-E("=014%2+T-O;F9I9RYP:'`G.PH*+R\@>WM[
M(&-O;G-T86YT<R!A;F0@9VQO8F%L<PH*+RHJ"B`J(%!%05)?0V]M;6]N(&5R
M<F]R('=H96X@86X@:6YV86QI9"!02%`@9FEL92!I<R!P87-S960@=&\@4$5!
M4E]#;VUM;VXZ.F%N86QY>F53;W5R8V5#;V1E*"D*("HO"F1E9FEN92@G4$5!
M4E]#3TU-3TY?15)23U)?24Y604Q)1%!(4"<L(#$I.PID969I;F4H)U]014%2
M7T-/34U/3E]004-+04=%7TY!345?4%)%1R<L("=;02U:82UZ75MA+7I!+5HP
M+3E?72LG*3L*9&5F:6YE*"=014%27T-/34U/3E]004-+04=%7TY!345?4%)%
M1R<L("<O7B<@+B!?4$5!4E]#3TU-3TY?4$%#2T%'15].04U%7U!214<@+B`G
M)"\G*3L*"B\O('1H:7,@<VAO=6QD(&%L;&]W.B`Q+"`Q+C`L(#$N,%)#,2P@
M,2XP9&5V+"`Q+C!D978Q,C,R,S0R,S0R,S0L(#$N,&$Q+"`Q+C!B,2P@,2XP
M<&PQ"F1E9FEN92@G7U!%05)?0T]-34].7U!!0TM!1T5?5D524TE/3E]04D5'
M)RP@)UQD*R@_.EPN7&0K*2HH/SI;82UZ72M<9"HI/R<I.PID969I;F4H)U!%
M05)?0T]-34].7U!!0TM!1T5?5D524TE/3E]04D5')RP@)R]>)R`N(%]014%2
M7T-/34U/3E]004-+04=%7U9%4E-)3TY?4%)%1R`N("<D+VDG*3L*"B\O(%A8
M6"!F87(@9G)O;2!P97)F96-T(#HM*0ID969I;F4H)U!%05)?0T]-34].7U!!
M0TM!1T5?1$]73DQ/041?4%)%1R<L("<O7B@G("X@7U!%05)?0T]-34].7U!!
M0TM!1T5?3D%-15]04D5'("X@)RDH+2A;+C`M.6$M>D$M6ETK*2D_)"\G*3L*
M"B\J*@H@*B!,:7-T(&]F('1E;7!O<F%R>2!F:6QE<R!A;F0@9&ER96-T;W)I
M97,@<F5G:7-T97)E9"!B>0H@*B!014%27T-O;6UO;CHZ861D5&5M<$9I;&4H
M*2X*("H@0'9A<B!A<G)A>0H@*B\*)$=,3T)!3%-;)U]014%27T-O;6UO;E]T
M96UP9FEL97,G72`](&%R<F%Y*"D["@HO*BH*("H@5F%L:60@;6%I;G1A:6YE
M<B!R;VQE<PH@*B!`=F%R(&%R<F%Y"B`J+PHD1TQ/0D%,4ULG7U!%05)?0V]M
M;6]N7VUA:6YT86EN97)?<F]L97,G72`](&%R<F%Y*"=L96%D)RPG9&5V96QO
M<&5R)RPG8V]N=')I8G5T;W(G+"=H96QP97(G*3L*"B\J*@H@*B!686QI9"!R
M96QE87-E('-T871E<PH@*B!`=F%R(&%R<F%Y"B`J+PHD1TQ/0D%,4ULG7U!%
M05)?0V]M;6]N7W)E;&5A<V5?<W1A=&5S)UT@/2!A<G)A>2@G86QP:&$G+"=B
M971A)RPG<W1A8FQE)RPG<VYA<'-H;W0G+"=D979E;"<I.PH*+RHJ"B`J(%9A
M;&ED(&1E<&5N9&5N8WD@='EP97,*("H@0'9A<B!A<G)A>0H@*B\*)$=,3T)!
M3%-;)U]014%27T-O;6UO;E]D97!E;F1E;F-Y7W1Y<&5S)UT@/2!A<G)A>2@G
M<&MG)RPG97AT)RPG<&AP)RPG<')O9R<L)VQD;&EB)RPG<G1L:6(G+"=O<R<L
M)W=E8G-R=B<L)W-A<&DG*3L*"B\J*@H@*B!686QI9"!D97!E;F1E;F-Y(')E
M;&%T:6]N<PH@*B!`=F%R(&%R<F%Y"B`J+PHD1TQ/0D%,4ULG7U!%05)?0V]M
M;6]N7V1E<&5N9&5N8WE?<F5L871I;VYS)UT@/2!A<G)A>2@G:&%S)RPG97$G
M+"=L="<L)VQE)RPG9W0G+"=G92<L)VYO="<I.PH*+RHJ"B`J(%9A;&ED(&9I
M;&4@<F]L97,*("H@0'9A<B!A<G)A>0H@*B\*)$=,3T)!3%-;)U]014%27T-O
M;6UO;E]F:6QE7W)O;&5S)UT@/2!A<G)A>2@G<&AP)RPG97AT)RPG=&5S="<L
M)V1O8R<L)V1A=&$G+"=S<F,G+"=S8W)I<'0G*3L*"B\J*@H@*B!686QI9"!R
M97!L86-E;65N="!T>7!E<PH@*B!`=F%R(&%R<F%Y"B`J+PHD1TQ/0D%,4ULG
M7U!%05)?0V]M;6]N7W)E<&QA8V5M96YT7W1Y<&5S)UT@/2!A<G)A>2@G<&AP
M+6-O;G-T)RP@)W!E87(M8V]N9FEG)RP@)W!A8VMA9V4M:6YF;R<I.PH*+RHJ
M"B`J(%9A;&ED(")P<F]V:61E(B!T>7!E<PH@*B!`=F%R(&%R<F%Y"B`J+PHD
M1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W!R;W9I9&5?='EP97,G72`](&%R<F%Y
M*"=E>'0G+"`G<')O9R<L("=C;&%S<R<L("=F=6YC=&EO;B<L("=F96%T=7)E
M)RP@)V%P:2<I.PH*+RHJ"B`J(%9A;&ED(")P<F]V:61E(B!T>7!E<PH@*B!`
M=F%R(&%R<F%Y"B`J+PHD1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W-C<FEP=%]P
M:&%S97,G72`](&%R<F%Y*"=P<F4M:6YS=&%L;"<L("=P;W-T+6EN<W1A;&PG
M+"`G<')E+75N:6YS=&%L;"<L("=P;W-T+75N:6YS=&%L;"<L("=P<F4M8G5I
M;&0G+"`G<&]S="UB=6EL9"<L("=P<F4M8V]N9FEG=7)E)RP@)W!O<W0M8V]N
M9FEG=7)E)RP@)W!R92US971U<"<L("=P;W-T+7-E='5P)RD["@HO+R!]?7T*
M"B\J*@H@*B!#;&%S<R!P<F]V:61I;F<@8V]M;6]N(&9U;F-T:6]N86QI='D@
M9F]R(%!%05(@861M:6YS:71R871I;VX@8VQA<W-E<RX*("HO"F-L87-S(%!%
M05)?0V]M;6]N(&5X=&5N9',@4$5!4@I["B`@("`O+R![>WL@<')O<&5R=&EE
M<PH*("`@("\J*B!S=&%C:R!O9B!E;&5M96YT<RP@9VEV97,@<V]M92!S;W)T
M(&]F(%A-3"!C;VYT97AT("HO"B`@("!V87(@)&5L96UE;G1?<W1A8VL@/2!A
M<G)A>2@I.PH*("`@("\J*B!N86UE(&]F(&-U<G)E;G1L>2!P87)S960@6$U,
M(&5L96UE;G0@*B\*("`@('9A<B`D8W5R<F5N=%]E;&5M96YT.PH*("`@("\J
M*B!A<G)A>2!O9B!A='1R:6)U=&5S(&]F('1H92!C=7)R96YT;'D@<&%R<V5D
M(%A-3"!E;&5M96YT("HO"B`@("!V87(@)&-U<G)E;G1?871T<FEB=71E<R`]
M(&%R<F%Y*"D["@H@("`@+RHJ(&%S<V]C('=I=&@@:6YF;W)M871I;VX@86)O
M=70@82!P86-K86=E("HO"B`@("!V87(@)'!K9VEN9F\@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@57-E<B!);G1E<F9A8V4@;V)J96-T("A014%27T9R
M;VYT96YD7RH@8VQA<W,I+B`@268@;G5L;"P*("`@("`J('1H92!L;V<H*2!M
M971H;V0@=7-E<R!P<FEN="X*("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*
M("`@('9A<B`D=6D@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N9FEG=7)A
M=&EO;B!O8FIE8W0@*%!%05)?0V]N9FEG*2X*("`@("`J($!V87(@;V)J96-T
M"B`@("`@*B\*("`@('9A<B`D8V]N9FEG(#T@;G5L;#L*"B`@("!V87(@)&-U
M<G)E;G1?<&%T:"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!014%27U-O=7)C
M94%N86QY>F5R(&EN<W1A;F-E"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO
M"B`@("!V87(@)'-O=7)C95]A;F%L>7IE<B`](&YU;&P["B`@("`O*BH*("`@
M("`J($9L86<@=F%R:6%B;&4@=7-E9"!T;R!M87)K(&$@=F%L:60@<&%C:V%G
M92!F:6QE"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]V86QI9%!A8VMA9V5&:6QE.PH@("`@
M+RHJ"B`@("`@*B!496UP;W)A<GD@=F%R:6%B;&4@=7-E9"!I;B!S;W)T:6YG
M('!A8VMA9V5S(&)Y(&1E<&5N9&5N8WD@:6X@>T!L:6YK('-O<G10:V=$97!S
M*"E]"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1?<&%C:V%G95-O<G14<F5E.PH*("`@("\O('U]
M?0H*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@4$5!
M4E]#;VUM;VX@8V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!014%27T-O;6UO;B@I"B`@("![
M"B`@("`@("`@<&%R96YT.CI014%2*"D["B`@("`@("`@)'1H:7,M/F-O;F9I
M9R`]("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"D["B`@("`@("`@)'1H:7,M
M/F1E8G5G(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&5S=')U8W1O<@H*("`@("\J*@H@
M("`@("H@4$5!4E]#;VUM;VX@9&5S=')U8W1O<@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?4$5!4E]#;VUM
M;VXH*0H@("`@>PH@("`@("`@("\O(&1O97-N)W0@=V]R:R!D=64@=&\@8G5G
M(",Q-#<T-`H@("`@("`@("\O)'1E;7!F:6QE<R`]("1T:&ES+3Y?=&5M<&9I
M;&5S.PH@("`@("`@("1T96UP9FEL97,@/28@)$=,3T)!3%-;)U]014%27T-O
M;6UO;E]T96UP9FEL97,G73L*("`@("`@("!W:&EL92`H)&9I;&4@/2!A<G)A
M>5]S:&EF="@D=&5M<&9I;&5S*2D@>PH@("`@("`@("`@("!I9B`H0&ES7V1I
M<B@D9FEL92DI('L*("`@("`@("`@("`@("`@(%-Y<W1E;3HZ<FTH87)R87DH
M)RUR9B<L("1F:6QE*2D["B`@("`@("`@("`@('T@96QS96EF("AF:6QE7V5X
M:7-T<R@D9FEL92DI('L*("`@("`@("`@("`@("`@('5N;&EN:R@D9FEL92D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@861D5&5M<$9I;&4H*0H*("`@("\J*@H@("`@("H@4F5G:7-T
M97(@82!T96UP;W)A<GD@9FEL92!O<B!D:7)E8W1O<GDN("!7:&5N('1H92!D
M97-T<G5C=&]R(&ES"B`@("`@*B!E>&5C=71E9"P@86QL(')E9VES=&5R960@
M=&5M<&]R87)Y(&9I;&5S(&%N9"!D:7)E8W1O<FEE<R!A<F4*("`@("`J(')E
M;6]V960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&4@(&YA
M;64@;V8@9FEL92!O<B!D:7)E8W1O<GD*("`@("`J"B`@("`@*B!`<F5T=7)N
M('9O:60*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1496UP1FEL92@D9FEL92D*("`@('L*("`@("`@("`D
M1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W1E;7!F:6QE<R==6UT@/2`D9FEL93L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M:T1I<DAI97(H*0H*("`@
M("\J*@H@("`@("H@5W)A<'!E<B!T;R!3>7-T96TZ.FUK1&ER*"DL(&-R96%T
M97,@82!D:7)E8W1O<GD@87,@=V5L;"!A<PH@("`@("H@86YY(&YE8V5S<V%R
M>2!P87)E;G0@9&ER96-T;W)I97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&1I<B`@9&ER96-T;W)Y(&YA;64*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!O<B!A(%!%05(@97)R;W(*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!M:T1I<DAI97(H)&1I<BD*("`@('L*("`@("`@("`D=&AI<RT^;&]G*#(L
M("(K(&-R96%T92!D:7(@)&1I<B(I.PH@("`@("`@(')E='5R;B!3>7-T96TZ
M.FUK1&ER*&%R<F%Y*"<M<"<L("1D:7(I*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!L;V<H*0H*("`@("\J*@H@("`@("H@3&]G9VEN9R!M971H
M;V0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@(&QO9R!L
M979E;"`H,"!I<R!Q=6EE="P@:&EG:&5R(&ES(&YO:7-I97(I"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1M<V<@("`@;65S<V%G92!T;R!W<FET92!T;R!T:&4@
M;&]G"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1L979E
M;"P@)&US9RP@)&%P<&5N9%]C<FQF(#T@=')U92D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/F1E8G5G(#X]("1L979E;"D@>PH@("`@("`@("`@("!I9B`H
M:7-?;V)J96-T*"1T:&ES+3YU:2DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YU:2T^;&]G*"1M<V<L("1A<'!E;F1?8W)L9BD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!P<FEN="`B)&US9UQN(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!M:U1E;7!$:7(H*0H*("`@("\J*@H@("`@("H@0W)E871E(&%N9"!R96=I
M<W1E<B!A('1E;7!O<F%R>2!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&UP9&ER("AO<'1I;VYA;"D@1&ER96-T;W)Y('1O('5S
M92!A<R!T;7!D:7(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@5VEL
M;"!U<V4@<WES=&5M(&1E9F%U;'1S("AF;W(@97AA;7!L90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("]T;7`@;W(@8SI<=VEN9&]W<UQT96UP*2!I
M9B!N;W0@<W!E8VEF:65D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M;F%M92!O9B!C<F5A=&5D(&1I<F5C=&]R>0H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&UK5&5M<$1I<B@D=&UP
M9&ER(#T@)R<I"B`@("!["B`@("`@("`@:68@*"1T;7!D:7(I('L*("`@("`@
M("`@("`@)'1O<'0@/2!A<G)A>2@G+70G+"`D=&UP9&ER*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&]P="`](&%R<F%Y*"D["B`@("`@("`@
M?0H@("`@("`@("1T;W!T(#T@87)R87E?;65R9V4H)'1O<'0L(&%R<F%Y*"<M
M9"<L("=P96%R)RDI.PH@("`@("`@(&EF("@A)'1M<&1I<B`](%-Y<W1E;3HZ
M;6MT96UP*"1T;W!T*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3YA9&1496UP1FEL92@D=&UP9&ER*3L*
M("`@("`@("!R971U<FX@)'1M<&1I<CL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!S971&<F]N=&5N9$]B:F5C="@I"@H@("`@+RHJ"B`@("`@*B!3
M970@;V)J96-T('1H870@<F5P<F5S96YT<R!T:&4@9G)O;G1E;F0@=&\@8F4@
M=7-E9"X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!2969E<F5N8V4@
M;V8@=&AE(&9R;VYT96YD(&]B:F5C=`H@("`@("H@0')E='5R;B!V;VED"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971&
M<F]N=&5N9$]B:F5C="@F)'5I*0H@("`@>PH@("`@("`@("1T:&ES+3YU:2`]
M("8D=6D["B`@("!]"@H@("`@+R\@?7U]"@H@("`@+R\@>WM[(%]U;DEN9&5N
M="@I"@H@("`@+RHJ"B`@("`@*B!5;FEN9&5N="!G:79E;B!S=')I;F<@*#\I
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R(%1H92!S=')I;F<@
M=&AA="!H87,@=&\@8F4@=6YI;F1E;G1E9"X*("`@("`J($!R971U<FX@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W5N26YD96YT*"1S='(I"B`@("!["B`@("`@("`@+R\@<F5M;W9E(&QE
M861I;F<@;F5W;&EN97,*("`@("`@("`D<W1R(#T@<')E9U]R97!L86-E*"<O
M7EM<<EQN72LO)RP@)R<L("1S='(I.PH@("`@("`@("\O(&9I;F0@=VAI=&5S
M<&%C92!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F:7)S="!L:6YE"B`@("`@
M("`@)&EN9&5N=%]L96X@/2!S=')S<&XH)'-T<BP@(B!<="(I.PH@("`@("`@
M("1I;F1E;G0@/2!S=6)S='(H)'-T<BP@,"P@)&EN9&5N=%]L96XI.PH@("`@
M("`@("1D871A(#T@)R<["B`@("`@("`@+R\@<F5M;W9E('1H92!S86UE(&%M
M;W5N="!O9B!W:&ET97-P86-E(&9R;VT@9F]L;&]W:6YG(&QI;F5S"B`@("`@
M("`@9F]R96%C:"`H97AP;&]D92@B7&XB+"`D<W1R*2!A<R`D;&EN92D@>PH@
M("`@("`@("`@("!I9B`H<W5B<W1R*"1L:6YE+"`P+"`D:6YD96YT7VQE;BD@
M/3T@)&EN9&5N="D@>PH@("`@("`@("`@("`@("`@)&1A=&$@+CT@<W5B<W1R
M*"1L:6YE+"`D:6YD96YT7VQE;BD@+B`B7&XB.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!?96QE;65N=%]S=&%R="@I"@H@("`@+RHJ"B`@("`@
M*B!834P@<&%R<V5R(&-A;&QB86-K(&9O<B!S=&%R=&EN9R!E;&5M96YT<RX@
M(%5S960@=VAI;&4@<&%C:V%G90H@("`@("H@9F]R;6%T('9E<G-I;VX@:7,@
M;F]T('EE="!K;F]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@
M("1X<"`@("`@("!834P@<&%R<V5R(')E<V]U<F-E"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`@("1N86UE("`@("!N86UE(&]F('-T87)T:6YG(&5L96UE;G0*
M("`@("`J($!P87)A;2!A<G)A>2`@("`@)&%T=')I8G,@(&5L96UE;G0@871T
M<FEB=71E<RP@;F%M92`]/B!V86QU90H@("`@("H*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?96QE;65N=%]S=&%R="@D>'`L("1N86UE+"`D871T<FEB
M<RD*("`@('L*("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3YE;&5M96YT7W-T
M86-K+"`D;F%M92D["B`@("`@("`@)'1H:7,M/F-U<G)E;G1?96QE;65N="`]
M("1N86UE.PH@("`@("`@("1S<&]S(#T@<VEZ96]F*"1T:&ES+3YE;&5M96YT
M7W-T86-K*2`M(#(["B`@("`@("`@)'1H:7,M/G!R979?96QE;65N="`]("@D
M<W!O<R`^/2`P*2`_("1T:&ES+3YE;&5M96YT7W-T86-K6R1S<&]S72`Z("<G
M.PH@("`@("`@("1T:&ES+3YC=7)R96YT7V%T=')I8G5T97,@/2`D871T<FEB
M<SL*("`@("`@("!S=VET8V@@*"1N86UE*2!["B`@("`@("`@("`@(&-A<V4@
M)W!A8VMA9V4G.B!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED4&%C
M:V%G949I;&4@/2!T<G5E.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A
M='1R:6)S6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'9S
M(#T@<')E9U]R97!L86-E*"<O6UXP+3EA+7I=+R<L("=?)RP@)&%T=')I8G-;
M)W9E<G-I;VXG72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1V<R`]("<Q7S`G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&5L96U?<W1A<G0@/2`G7V5L96UE;G1?<W1A<G1?
M)RX@)'9S.PH@("`@("`@("`@("`@("`@)&5L96U?96YD(#T@)U]E;&5M96YT
M7V5N9%\G+B`D=G,["B`@("`@("`@("`@("`@("`D8V1A=&$@/2`G7W!K9VEN
M9F]?8V1A=&%?)RX@)'9S.PH@("`@("`@("`@("`@("`@:68@*"%M971H;V1?
M97AI<W1S*"1T:&ES+"`D96QE;5]S=&%R="D@?'P*("`@("`@("`@("`@("`@
M("`@("`@("%M971H;V1?97AI<W1S*"1T:&ES+"`D96QE;5]E;F0I('Q\"B`@
M("`@("`@("`@("`@("`@("`@("`A;65T:&]D7V5X:7-T<R@D=&AI<RP@)&-D
M871A*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R
M*").;R!H86YD;&5R<R!F;W(@<&%C:V%G92YX;6P@=F5R<VEO;B`D871T<FEB
M<UMV97)S:6]N72(I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('AM;%]S971?96QE;65N
M=%]H86YD;&5R*"1X<"P@)&5L96U?<W1A<G0L("1E;&5M7V5N9"D["B`@("`@
M("`@("`@("`@("!X;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'AP
M+"`D8V1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7V5L
M96UE;G1?96YD*"D*"B`@("`O*BH*("`@("`J(%A-3"!P87)S97(@8V%L;&)A
M8VL@9F]R(&5N9&EN9R!E;&5M96YT<RX@(%5S960@=VAI;&4@<&%C:V%G90H@
M("`@("H@9F]R;6%T('9E<G-I;VX@:7,@;F]T('EE="!K;F]W;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@("1X<"`@("!834P@<&%R<V5R(')E
M<V]U<F-E"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE("!N86UE(&]F
M(&5N9&EN9R!E;&5M96YT"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]E;&5M96YT7V5N9"@D>'`L("1N86UE*0H@("`@>PH@("`@?0H*("`@
M("\O('U]?0H*("`@("\O(%-U<'!O<G0@9F]R('!A8VMA9V4@1%1$('8Q+C`Z
M"B`@("`O+R![>WL@7V5L96UE;G1?<W1A<G1?,5\P*"D*"B`@("`O*BH*("`@
M("`J(%A-3"!P87)S97(@8V%L;&)A8VL@9F]R(&5N9&EN9R!E;&5M96YT<RX@
M(%5S960@9F]R('9E<G-I;VX@,2XP"B`@("`@*B!P86-K86=E<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@("1X<"`@("!834P@<&%R<V5R(')E
M<V]U<F-E"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE("!N86UE(&]F
M(&5N9&EN9R!E;&5M96YT"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]E;&5M96YT7W-T87)T7S%?,"@D>'`L("1N86UE+"`D871T<FEB<RD*
M("`@('L*("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3YE;&5M96YT7W-T86-K
M+"`D;F%M92D["B`@("`@("`@)'1H:7,M/F-U<G)E;G1?96QE;65N="`]("1N
M86UE.PH@("`@("`@("1S<&]S(#T@<VEZ96]F*"1T:&ES+3YE;&5M96YT7W-T
M86-K*2`M(#(["B`@("`@("`@)'1H:7,M/G!R979?96QE;65N="`]("@D<W!O
M<R`^/2`P*2`_("1T:&ES+3YE;&5M96YT7W-T86-K6R1S<&]S72`Z("<G.PH@
M("`@("`@("1T:&ES+3YC=7)R96YT7V%T=')I8G5T97,@/2`D871T<FEB<SL*
M("`@("`@("`D=&AI<RT^8V1A=&$@/2`G)SL*("`@("`@("!S=VET8V@@*"1N
M86UE*2!["B`@("`@("`@("`@(&-A<V4@)V1I<B<Z"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*"1A='1R:6)S6R=N86UE)UT@(3T@)R\G*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F1I<E]N86UE<UM=(#T@)&%T=')I8G-;)VYA;64G73L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M871T<FEB<ULG8F%S96EN<W1A;&QD:7(G72DI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9&ER7VEN<W1A;&P@/2`D871T<FEB<ULG8F%S96EN<W1A
M;&QD:7(G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D871T<FEB<ULG<F]L92==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YD:7)?<F]L92`]("1A='1R:6)S6R=R;VQE)UT["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`G9FEL92<Z"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN
M7V-H86YG96QO9RD@>PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R
M:6)S6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'!A=&@@/2`G
M)SL*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/F1I<E]N
M86UE<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/F1I<E]N86UE<R!A<R`D9&ER*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%T:"`N/2`D9&ER("X@1$E214-43U)97U-%4$%2051/4CL*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`D<&%T:"`N/2`D871T<FEB<ULG;F%M
M92==.PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1A='1R:6)S6R=N86UE
M)UTI.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT7W!A=&@@
M/2`D<&%T:#L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9FEL96QI<W1;
M)'!A=&A=(#T@)&%T=')I8G,["B`@("`@("`@("`@("`@("`@("`@+R\@4V5T
M('1H92!B87-E:6YS=&%L;&1I<B!O;FQY(&EF('1H92!F:6QE(&1O;B=T(&AA
M=F4@=&AI<R!A='1R:6(*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3YF:6QE;&ES=%LD<&%T:%U;)V)A<V5I;G-T86QL9&ER)UTI("8F
M"B`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD:7)?:6YS
M=&%L;"DI"B`@("`@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=B87-E:6YS=&%L;&1I
M<B==(#T@)'1H:7,M/F1I<E]I;G-T86QL.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`O+R!3970@=&AE(%)O;&4*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YF:6QE;&ES=%LD<&%T
M:%U;)W)O;&4G72D@)B8@:7-S970H)'1H:7,M/F1I<E]R;VQE*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=R
M;VQE)UT@/2`D=&AI<RT^9&ER7W)O;&4["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@)W)E<&QA8V4G.@H@("`@("`@("`@("`@("`@:68@
M*"$D=&AI<RT^:6Y?8VAA;F=E;&]G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F9I;&5L:7-T6R1T:&ES+3YC=7)R96YT7W!A=&A=6R=R97!L86-E
M;65N=',G75M=(#T@)&%T=')I8G,["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;6%I;G1A:6YE
M<G,G.@H@("`@("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F];)VUA:6YT86EN
M97)S)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FU?:2`]
M(#`[("\O(&UA:6YT86EN97)S(&%R<F%Y(&EN9&5X"B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;6%I;G1A:6YE<B<Z"B`@("`@
M("`@("`@("`@("`O+R!C;VUP871I8FEL:71Y(&-H96-K"B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3YP:V=I;F9O6R=M86EN=&%I;F5R<R==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O6R=M86EN
M=&%I;F5R<R==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;5]I(#T@,#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1T:&ES+3YP:V=I;F9O6R=M86EN=&%I;F5R<R==6R1T:&ES+3YM7VE=(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT7VUA:6YT
M86EN97(@/28@)'1H:7,M/G!K9VEN9F];)VUA:6YT86EN97)S)UU;)'1H:7,M
M/FU?:5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92`G8VAA;F=E;&]G)SH*("`@("`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O
M6R=C:&%N9V5L;V<G72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^8U]I(#T@,#L@+R\@8VAA;F=E;&]G(&%R<F%Y(&EN9&5X"B`@("`@("`@
M("`@("`@("`D=&AI<RT^:6Y?8VAA;F=E;&]G(#T@=')U93L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=R96QE87-E)SH*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^:6Y?8VAA;F=E;&]G*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F];)V-H86YG96QO9R==6R1T
M:&ES+3YC7VE=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^8W5R<F5N=%]R96QE87-E(#T@)B1T:&ES+3YP:V=I;F9O6R=C:&%N9V5L
M;V<G75LD=&AI<RT^8U]I73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S92`]("8D
M=&AI<RT^<&MG:6YF;SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=D97!S)SH*("`@("`@("`@
M("`@("`@(&EF("@A)'1H:7,M/FEN7V-H86YG96QO9RD@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YP:V=I;F9O6R=R96QE87-E7V1E<',G72`](&%R
M<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`G9&5P)SH*("`@("`@("`@("`@("`@("\O
M(&1E<&5N9&5N8VEE<R!A<G)A>2!I;F1E>`H@("`@("`@("`@("`@("`@:68@
M*"$D=&AI<RT^:6Y?8VAA;F=E;&]G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F1?:2LK.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP:V=I
M;F9O6R=R96QE87-E7V1E<',G75LD=&AI<RT^9%]I72`]("1A='1R:6)S.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@)V-O;F9I9W5R96]P=&EO;G,G.@H@("`@("`@("`@("`@
M("`@:68@*"$D=&AI<RT^:6Y?8VAA;F=E;&]G*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G!K9VEN9F];)V-O;F9I9W5R95]O<'1I;VYS)UT@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W5R96]P=&EO;B<Z"B`@("`@
M("`@("`@("`@("!I9B`H(21T:&ES+3YI;E]C:&%N9V5L;V<I('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<&MG:6YF;ULG8V]N9FEG=7)E7V]P=&EO
M;G,G75M=(#T@)&%T=')I8G,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G<')O=FED97,G.@H@
M("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1A='1R:6)S6R=T>7!E)UTI('Q\
M(&5M<'1Y*"1A='1R:6)S6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M871T<FEB<ULG97AP;&EC:70G72`]('1R=64["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<&MG:6YF;ULG<')O=FED97,G75LB)&%T=')I8G-;='EP95T[)&%T
M=')I8G-;;F%M95TB72`]("1A='1R:6)S.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]E
M;&5M96YT7V5N9%\Q7S`H*0H*("`@("\J*@H@("`@("H@6$U,('!A<G-E<B!C
M86QL8F%C:R!F;W(@96YD:6YG(&5L96UE;G1S+B`@57-E9"!F;W(@=F5R<VEO
M;B`Q+C`*("`@("`J('!A8VMA9V5S+@H@("`@("H*("`@("`J($!P87)A;2!R
M97-O=7)C92`@)'AP("`@(%A-3"!P87)S97(@<F5S;W5R8V4*("`@("`J($!P
M87)A;2!S=')I;F<@("`@)&YA;64@(&YA;64@;V8@96YD:6YG(&5L96UE;G0*
M("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V5L96UE;G1?96YD
M7S%?,"@D>'`L("1N86UE*0H@("`@>PH@("`@("`@("1D871A(#T@=')I;2@D
M=&AI<RT^8V1A=&$I.PH@("`@("`@('-W:71C:"`H)&YA;64I('L*("`@("`@
M("`@("`@8V%S92`G;F%M92<Z"B`@("`@("`@("`@("`@("!S=VET8V@@*"1T
M:&ES+3YP<F5V7V5L96UE;G0I('L*("`@("`@("`@("`@("`@("`@("!C87-E
M("=P86-K86=E)SH*("`@("`@("`@("`@("`@("`@("`@("`@+R\@6%A8('-H
M;W5L9"!W92!C:&5C:R!T:&4@<&%C:V%G92!N86UE(&AE<F4_"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O6R=P86-K86=E)UT@/2!E
M<F5G7W)E<&QA8V4H)UM>82UZ02U:,"TY+E]=)RP@)U\G+"`D9&%T82D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)VUA:6YT86EN97(G.@H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^8W5R<F5N=%]M86EN=&%I;F5R6R=N86UE)UT@/2`D9&%T83L*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G
M<W5M;6%R>2<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^<&MG:6YF;ULG<W5M
M;6%R>2==(#T@)&1A=&$["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@8V%S92`G9&5S8W)I<'1I;VXG.@H@("`@("`@("`@("`@("`@)&1A
M=&$@/2`D=&AI<RT^7W5N26YD96YT*"1T:&ES+3YC9&%T82D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<&MG:6YF;ULG9&5S8W)I<'1I;VXG72`]("1D871A
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)W5S
M97(G.@H@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?;6%I;G1A:6YE
M<ELG:&%N9&QE)UT@/2`D9&%T83L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E("=E;6%I;"<Z"B`@("`@("`@("`@("`@("`D=&AI
M<RT^8W5R<F5N=%]M86EN=&%I;F5R6R=E;6%I;"==(#T@)&1A=&$["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G<F]L92<Z"B`@
M("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]M86EN=&%I;F5R6R=R;VQE
M)UT@/2`D9&%T83L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!C87-E("=V97)S:6]N)SH*("`@("`@("`@("`@("`@("1D871A(#T@97)E
M9U]R97!L86-E("@G6UYA+7I!+5HP+3DN7UPM72<L("=?)RP@)&1A=&$I.PH@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]R96QE87-E6R=V97)S
M:6]N)UT@/2`D9&%T83L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F];)W9E<G-I;VXG72`]("1D
M871A.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@)V1A=&4G.@H@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^8W5R<F5N=%]R96QE87-E6R=R96QE87-E7V1A=&4G72`]("1D871A
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<&MG:6YF;ULG<F5L96%S95]D871E)UT@/2`D9&%T83L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!C87-E("=N;W1E<R<Z"B`@("`@("`@("`@("`@("`O+R!T<GD@=&\@
M(F1E+6EN9&5N="(@<F5L96%S92!N;W1E<R!I;B!C87-E('-O;65O;F4*("`@
M("`@("`@("`@("`@("\O(&AA<R!B965N(&]V97(M:6YD96YT:6YG('1H96ER
M('AM;"`[+2D*("`@("`@("`@("`@("`@("1D871A(#T@)'1H:7,M/E]U;DEN
M9&5N="@D=&AI<RT^8V1A=&$I.PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YI;E]C:&%N9V5L;V<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M8W5R<F5N=%]R96QE87-E6R=R96QE87-E7VYO=&5S)UT@/2`D9&%T83L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G!K9VEN9F];)W)E;&5A<V5?;F]T97,G72`]("1D871A.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@)W=A<FYI;F=S)SH*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M:6Y?8VAA;F=E;&]G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U
M<G)E;G1?<F5L96%S95LG<F5L96%S95]W87)N:6YG<R==(#T@)&1A=&$["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YP:V=I;F9O6R=R96QE87-E7W=A<FYI;F=S)UT@/2`D9&%T83L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!C87-E("=S=&%T92<Z"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/FEN7V-H86YG96QO9RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC
M=7)R96YT7W)E;&5A<V5;)W)E;&5A<V5?<W1A=&4G72`]("1D871A.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<&MG:6YF;ULG<F5L96%S95]S=&%T92==(#T@)&1A=&$["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M8V%S92`G;&EC96YS92<Z"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN
M7V-H86YG96QO9RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R
M96YT7W)E;&5A<V5;)W)E;&5A<V5?;&EC96YS92==(#T@)&1A=&$["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YP:V=I;F9O6R=R96QE87-E7VQI8V5N<V4G72`]("1D871A.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@)V1E<"<Z"B`@("`@("`@("`@("`@("!I9B`H)&1A=&$@)B8@(21T
M:&ES+3YI;E]C:&%N9V5L;V<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<&MG:6YF;ULG<F5L96%S95]D97!S)UU;)'1H:7,M/F1?:5U;)VYA;64G
M72`]("1D871A.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@)V1I<B<Z"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M87)R87E?<&]P*"1T:&ES+3YD:7)?;F%M97,I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@)V9I;&4G.@H@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("@D9&%T82D@>PH@("`@("`@("`@("`@("`@("`@("1P871H(#T@)R<[
M"B`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YD:7)?;F%M
M97,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YD:7)?;F%M97,@87,@)&1I<BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A=&@@+CT@)&1I<B`N($1)4D5#5$]265]315!!4D%43U(["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)'!A=&@@+CT@)&1A=&$["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F9I;&5L:7-T6R1P871H72`]("1T:&ES+3YC
M=7)R96YT7V%T=')I8G5T97,["B`@("`@("`@("`@("`@("`@("`@+R\@4V5T
M('1H92!B87-E:6YS=&%L;&1I<B!O;FQY(&EF('1H92!F:6QE(&1O;B=T(&AA
M=F4@=&AI<R!A='1R:6(*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3YF:6QE;&ES=%LD<&%T:%U;)V)A<V5I;G-T86QL9&ER)UTI("8F
M"B`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD:7)?:6YS
M=&%L;"DI"B`@("`@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=B87-E:6YS=&%L;&1I
M<B==(#T@)'1H:7,M/F1I<E]I;G-T86QL.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`O+R!3970@=&AE(%)O;&4*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YF:6QE;&ES=%LD<&%T
M:%U;)W)O;&4G72D@)B8@:7-S970H)'1H:7,M/F1I<E]R;VQE*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=R
M;VQE)UT@/2`D=&AI<RT^9&ER7W)O;&4["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@)VUA:6YT86EN97(G.@H@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3YP:V=I;F9O6R=M86EN=&%I;F5R<R==6R1T:&ES
M+3YM7VE=6R=R;VQE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G!K9VEN9F];)VUA:6YT86EN97)S)UU;)'1H:7,M/FU?:5U;)W)O;&4G72`]
M("=L96%D)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T
M:&ES+3YM7VDK*SL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!C87-E("=R96QE87-E)SH*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M:6Y?8VAA;F=E;&]G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-?
M:2LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@)V-H86YG96QO9R<Z"B`@("`@("`@("`@("`@
M("`D=&AI<RT^:6Y?8VAA;F=E;&]G(#T@9F%L<V4["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"B`@("`@("`@87)R87E?<&]P*"1T:&ES+3YE
M;&5M96YT7W-T86-K*3L*("`@("`@("`D<W!O<R`]('-I>F5O9B@D=&AI<RT^
M96QE;65N=%]S=&%C:RD@+2`Q.PH@("`@("`@("1T:&ES+3YC=7)R96YT7V5L
M96UE;G0@/2`H)'-P;W,@/B`P*2`_("1T:&ES+3YE;&5M96YT7W-T86-K6R1S
M<&]S72`Z("<G.PH@("`@("`@("1T:&ES+3YC9&%T82`]("<G.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(%]P:V=I;F9O7V-D871A7S%?,"@I"@H@
M("`@+RHJ"B`@("`@*B!834P@<&%R<V5R(&-A;&QB86-K(&9O<B!C:&%R86-T
M97(@9&%T82X@(%5S960@9F]R('9E<G-I;VX@,2XP"B`@("`@*B!P86-K86=E
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@("1X<"`@("!834P@
M<&%R<V5R(')E<V]U<F-E"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE
M("!C:&%R86-T97(@9&%T80H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&MG:6YF;U]C9&%T85\Q7S`H)'AP+"`D9&%T82D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/F-D871A*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^8V1A=&$@+CT@)&1A=&$["B`@("`@("`@?0H@("`@?0H*("`@("\O
M('U]?0H*("`@("\O('M[>R!I;F9O1G)O;51G>D9I;&4H*0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4@9FEL
M92X@($5X<&5C=',@=&AE(&YA;64@;V8*("`@("`J(&$@9WII<'!E9"!T87(@
M9FEL92!A<R!I;G!U="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M9FEL92`@;F%M92!O9B`N=&=Z(&9I;&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!A<G)A>2!W:71H('!A8VMA9V4@:6YF;W)M871I;VX*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J+PH@("`@9G5N
M8W1I;VX@:6YF;T9R;VU49WI&:6QE*"1F:6QE*0H@("`@>PH@("`@("`@(&EF
M("@A0&ES7V9I;&4H)&9I;&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&]P96X@9FEL92!<(B1F:6QE7"(B
M*3L*("`@("`@("!]"B`@("`@("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D
M9FEL92D["B`@("`@("`@:68@*"1T:&ES+3YD96)U9R`\/2`Q*2!["B`@("`@
M("`@("`@("1T87(M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D54
M55).*3L*("`@("`@("!]"B`@("`@("`@)&-O;G1E;G0@/2`D=&%R+3YL:7-T
M0V]N=&5N="@I.PH@("`@("`@(&EF("@D=&AI<RT^9&5B=6<@/#T@,2D@>PH@
M("`@("`@("`@("`D=&%R+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@
M?0H@("`@("`@(&EF("@A:7-?87)R87DH)&-O;G1E;G0I*2!["B`@("`@("`@
M("`@("1F:6QE(#T@<F5A;'!A=&@H)&9I;&4I.PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O=6QD(&YO="!G970@8V]N=&5N=',@
M;V8@<&%C:V%G92!<(B1F:6QE7"(B+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)RX@26YV86QI9"!T9WH@9FEL92XG*3L*("`@("`@
M("!]"B`@("`@("`@)'AM;"`](&YU;&P["B`@("`@("`@9F]R96%C:"`H)&-O
M;G1E;G0@87,@)&9I;&4I('L*("`@("`@("`@("`@)&YA;64@/2`D9FEL95LG
M9FEL96YA;64G73L*("`@("`@("`@("`@:68@*"1N86UE(#T]("=P86-K86=E
M+GAM;"<I('L*("`@("`@("`@("`@("`@("1X;6P@/2`D;F%M93L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!](&5L<V5I9B`H97)E9R@G
M<&%C:V%G92YX;6PD)RP@)&YA;64L("1M871C:"DI('L*("`@("`@("`@("`@
M("`@("1X;6P@/2`D;6%T8VA;,%T["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&UP9&ER(#T@4WES
M=&5M.CIM:U1E;7`H87)R87DH)RUD)RP@)W!E87(G*2D["B`@("`@("`@)'1H
M:7,M/F%D9%1E;7!&:6QE*"1T;7!D:7(I.PH@("`@("`@(&EF("@A)'AM;"!\
M?"`A)'1A<BT^97AT<F%C=$QI<W0H87)R87DH)'AM;"DL("1T;7!D:7(I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8V]U;&0@
M;F]T(&5X=')A8W0@=&AE('!A8VMA9V4N>&UL(&9I;&4G*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YI;F9O1G)O;41E<V-R:7!T:6]N1FEL
M92@B)'1M<&1I<B\D>&UL(BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@:6YF;T9R;VU$97-C<FEP=&EO;D9I;&4H*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4@9FEL92X@($5X
M<&5C=',@=&AE(&YA;64@;V8*("`@("`J(&$@<&%C:V%G92!X;6P@9FEL92!A
M<R!I;G!U="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9&5S8V9I
M;&4@(&YA;64@;V8@<&%C:V%G92!X;6P@9FEL90H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(&%R<F%Y('=I=&@@<&%C:V%G92!I;F9O<FUA=&EO;@H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I;F9O1G)O;41E<V-R:7!T:6]N1FEL92@D9&5S8V9I;&4I
M"B`@("!["B`@("`@("`@:68@*"%`:7-?9FEL92@D9&5S8V9I;&4I('Q\("%I
M<U]R96%D86)L92@D9&5S8V9I;&4I('Q\"B`@("`@("`@("`@("`H(21F<"`]
M($!F;W!E;B@D9&5S8V9I;&4L("=R)RDI*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B56YA8FQE('1O(&]P96X@)&1E<V-F:6QE
M(BD["B`@("`@("`@?0H*("`@("`@("`O+R!R96%D('1H92!W:&]L92!T:&EN
M9R!S;R!W92!O;FQY(&=E="!O;F4@8V1A=&$@8V%L;&)A8VL*("`@("`@("`O
M+R!F;W(@96%C:"!B;&]C:R!O9B!C9&%T80H@("`@("`@("1D871A(#T@9G)E
M860H)&9P+"!F:6QE<VEZ92@D9&5S8V9I;&4I*3L*("`@("`@("!R971U<FX@
M)'1H:7,M/FEN9F]&<F]M4W1R:6YG*"1D871A*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!I;F9O1G)O;5-T<FEN9R@I"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92!F:6QE+B`@
M17AP96-T<R!T:&4@8V]N=&5N=',*("`@("`J(&]F(&$@<&%C:V%G92!X;6P@
M9FEL92!A<R!I;G!U="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M9&%T82`@;F%M92!O9B!P86-K86=E('AM;"!F:6QE"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@(&%R<F%Y('=I=&@@<&%C:V%G92!I;F9O<FUA=&EO
M;@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I;F9O1G)O;5-T<FEN9R@D9&%T82D*("`@('L*("`@
M("`@("!R97%U:7)E7V]N8V4H)U!%05(O1&5P96YD96YC>2YP:'`G*3L*("`@
M("`@("!I9B`H4$5!4E]$97!E;F1E;F-Y.CIC:&5C:T5X=&5N<VEO;B@D97)R
M;W(L("=X;6PG*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)&5R<F]R*3L*("`@("`@("!]"B`@("`@("`@)'AP(#T@0'AM;%]P
M87)S97)?8W)E871E*"D["B`@("`@("`@:68@*"$D>'`I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;F%B;&4@=&\@8W)E871E
M(%A-3"!P87)S97(G*3L*("`@("`@("!]"B`@("`@("`@>&UL7W-E=%]O8FIE
M8W0H)'AP+"`D=&AI<RD["B`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L
M97(H)'AP+"`G7V5L96UE;G1?<W1A<G0G+"`G7V5L96UE;G1?96YD)RD["B`@
M("`@("`@>&UL7W-E=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1X<"P@)U]P
M:V=I;F9O7V-D871A)RD["B`@("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N
M*"1X<"P@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L(&9A;'-E*3L*"B`@("`@
M("`@)'1H:7,M/F5L96UE;G1?<W1A8VL@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3YP:V=I;F9O(#T@87)R87DH)W!R;W9I9&5S)R`]/B!A<G)A>2@I*3L*
M("`@("`@("`D=&AI<RT^8W5R<F5N=%]E;&5M96YT(#T@9F%L<V4["B`@("`@
M("`@=6YS970H)'1H:7,M/F1I<E]I;G-T86QL*3L*("`@("`@("`D=&AI<RT^
M<&MG:6YF;ULG9FEL96QI<W0G72`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M
M/F9I;&5L:7-T(#TF("1T:&ES+3YP:V=I;F9O6R=F:6QE;&ES="==.PH@("`@
M("`@("1T:&ES+3YD:7)?;F%M97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES
M+3YI;E]C:&%N9V5L;V<@/2!F86QS93L*("`@("`@("`D=&AI<RT^9%]I(#T@
M,#L*("`@("`@("`D=&AI<RT^8V1A=&$@/2`G)SL*("`@("`@("`D=&AI<RT^
M7W9A;&ED4&%C:V%G949I;&4@/2!F86QS93L*"B`@("`@("`@:68@*"%X;6Q?
M<&%R<V4H)'AP+"`D9&%T82P@,2DI('L*("`@("`@("`@("`@)&-O9&4@/2!X
M;6Q?9V5T7V5R<F]R7V-O9&4H)'AP*3L*("`@("`@("`@("`@)&US9R`]('-P
M<FEN=&8H(EA-3"!E<G)O<CH@)7,@870@;&EN92`E9"(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@('AM;%]E<G)O<E]S=')I;F<H)&-O9&4I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?;&EN95]N
M=6UB97(H)'AP*2D["B`@("`@("`@("`@('AM;%]P87)S97)?9G)E92@D>'`I
M.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&US9RP@
M)&-O9&4I.PH@("`@("`@('T*"B`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1X
M<"D["@H@("`@("`@(&EF("@A)'1H:7,M/E]V86QI9%!A8VMA9V5&:6QE*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G26YV86QI
M9"!086-K86=E($9I;&4L(&YO(#QP86-K86=E/B!T86<G*3L*("`@("`@("!]
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G!K9VEN9F\@87,@)&L@/3X@)'8I
M('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=BDI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YP:V=I;F9O6R1K72`]('1R:6TH)'8I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<&MG:6YF
M;SL*("`@('T*("`@("\O('U]?0H@("`@+R\@>WM[(&EN9F]&<F]M06YY*"D*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@<&%C:V%G92!I;F9O<FUA=&EO;B!F
M<F]M(&1I9F9E<F5N="!S;W5R8V5S"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@:7,@86)L92!T;R!E>'1R86-T(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C
M:V%G90H@("`@("H@9G)O;2!A("YT9WH@87)C:&EV92!O<B!F<F]M(&$@6$U,
M('!A8VMA9V4@9&5F:6YI=&EO;B!F:6QE+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@('-T<FEN9R!&:6QE;F%M92!O9B!T
M:&4@<V]U<F-E("@G<&%C:V%G92YX;6PG+"`G/'!A8VMA9V4^+G1G>B<I"B`@
M("`@*B!`<F5T=7)N('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!I;F9O
M1G)O;4%N>2@D:6YF;RD*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1I
M;F9O*2`F)B!F:6QE7V5X:7-T<R@D:6YF;RDI('L*("`@("`@("`@("`@)'1M
M<"`]('-U8G-T<B@D:6YF;RP@+30I.PH@("`@("`@("`@("!I9B`H)'1M<"`]
M/2`G+GAM;"<I('L*("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/FEN
M9F]&<F]M1&5S8W)I<'1I;VY&:6QE*"1I;F9O*3L*("`@("`@("`@("`@?2!E
M;'-E:68@*"1T;7`@/3T@)RYT87(G('Q\("1T;7`@/3T@)RYT9WHG*2!["B`@
M("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3YI;F9O1G)O;51G>D9I;&4H
M)&EN9F\I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&9P(#T@9F]P96XH)&EN9F\L(")R(BD["B`@("`@("`@("`@("`@("`D=&5S
M="`](&9R96%D*"1F<"P@-2D["B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L*("`@("`@("`@("`@("`@(&EF("@D=&5S="`]/2`B/#]X;6PB*2!["B`@
M("`@("`@("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^:6YF;T9R;VU$97-C
M<FEP=&EO;D9I;&4H)&EN9F\I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3YI;F9O1G)O;51G
M>D9I;&4H)&EN9F\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1I;F9O*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&EN9F\[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@>&UL1G)O;4EN9F\H*0H*
M("`@("\J*@H@("`@("H@4F5T=7)N(&%N(%A-3"!D;V-U;65N="!B87-E9"!O
M;B!T:&4@<&%C:V%G92!I;F9O("AA<R!R971U<FYE9`H@("`@("H@8GD@=&AE
M(%!%05)?0V]M;6]N.CII;F9O1G)O;2H@;65T:&]D<RDN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("`D<&MG:6YF;R`@<&%C:V%G92!I;F9O"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@6$U,(&1A=&$*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!X;6Q&<F]M
M26YF;R@D<&MG:6YF;RD*("`@('L*("`@("`@("!S=&%T:6,@)&UA:6YT7VUA
M<"`](&%R<F%Y*`H@("`@("`@("`@("`B:&%N9&QE(B`]/B`B=7-E<B(L"B`@
M("`@("`@("`@(")N86UE(B`]/B`B;F%M92(L"B`@("`@("`@("`@(")E;6%I
M;"(@/3X@(F5M86EL(BP*("`@("`@("`@("`@(G)O;&4B(#T^(")R;VQE(BP*
M("`@("`@("`@("`@*3L*("`@("`@("`D<F5T(#T@(CP_>&UL('9E<G-I;VX]
M7"(Q+C!<(B!E;F-O9&EN9SU<(DE33RTX.#4Y+3%<(B`_/EQN(CL*("`@("`@
M("`D<F5T("X]("(\(41/0U194$4@<&%C:V%G92!365-414T@7")H='1P.B\O
M<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,%PB/EQN(CL*("`@("`@("`D
M<F5T("X]("(\<&%C:V%G92!V97)S:6]N/5PB,2XP7"(^"B`@/&YA;64^)'!K
M9VEN9F];<&%C:V%G95T\+VYA;64^"B`@/'-U;6UA<GD^(BYH=&UL<W!E8VEA
M;&-H87)S*"1P:V=I;F9O6R=S=6UM87)Y)UTI+B(\+W-U;6UA<GD^"B`@/&1E
M<V-R:7!T:6]N/B(N:'1M;'-P96-I86QC:&%R<R@D<&MG:6YF;ULG9&5S8W)I
M<'1I;VXG72DN(CPO9&5S8W)I<'1I;VX^"B`@/&UA:6YT86EN97)S/@HB.PH@
M("`@("`@(&9O<F5A8V@@*"1P:V=I;F9O6R=M86EN=&%I;F5R<R==(&%S("1M
M86EN="D@>PH@("`@("`@("`@("`D<F5T("X]("(@("`@/&UA:6YT86EN97(^
M7&XB.PH@("`@("`@("`@("!F;W)E86-H("@D;6%I;G1?;6%P(&%S("1I9'@@
M/3X@)&5L;2D@>PH@("`@("`@("`@("`@("`@)')E="`N/2`B("`@("`@/"1E
M;&T^(CL*("`@("`@("`@("`@("`@("1R970@+CT@:'1M;'-P96-I86QC:&%R
M<R@D;6%I;G1;)&ED>%TI.PH@("`@("`@("`@("`@("`@)')E="`N/2`B/"\D
M96QM/EQN(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5T("X]("(@
M("`@/"]M86EN=&%I;F5R/EQN(CL*("`@("`@("!]"B`@("`@("`@)')E="`N
M/2`B("`\+VUA:6YT86EN97)S/EQN(CL*("`@("`@("`D<F5T("X]("1T:&ES
M+3Y?;6%K95)E;&5A<V58;6PH)'!K9VEN9F\I.PH@("`@("`@(&EF("A`<VEZ
M96]F*"1P:V=I;F9O6R=C:&%N9V5L;V<G72D@/B`P*2!["B`@("`@("`@("`@
M("1R970@+CT@(B`@/&-H86YG96QO9SY<;B(["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1P:V=I;F9O6R=C:&%N9V5L;V<G72!A<R`D;VQD<F5L96%S92D@>PH@
M("`@("`@("`@("`@("`@)')E="`N/2`D=&AI<RT^7VUA:V5296QE87-E6&UL
M*"1O;&1R96QE87-E+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<F5T("X]("(@(#PO8VAA;F=E;&]G/EQN(CL*("`@("`@("!]"B`@("`@
M("`@)')E="`N/2`B/"]P86-K86=E/EQN(CL*("`@("`@("!R971U<FX@)')E
M=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?;6%K95)E;&5A<V58
M;6PH*0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@<&%R="!O9B!A;B!834P@
M9&5S8W)I<'1I;VX@=VET:"!R96QE87-E(&EN9F]R;6%T:6]N+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`@)'!K9VEN9F\@("`@87)R87D@=VET:"!R
M96QE87-E(&EN9F]R;6%T:6]N"B`@("`@*B!`<&%R86T@8F]O;"`@("1C:&%N
M9V5L;V<@('=H971H97(@=&AE(')E<W5L="!W:6QL(&)E(&EN(&$@8VAA;F=E
M;&]G(&5L96UE;G0*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!834P@
M9&%T80H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;6%K95)E;&5A<V58;6PH)'!K9VEN9F\L("1C:&%N9V5L
M;V<@/2!F86QS92D*("`@('L*("`@("`@("`O+R!86%@@455/5$4@14Y4251)
M15,@24X@4$-$051!+"!/4B!%34)%1"!)3B!#1$%402!"3$]#2U,A(0H@("`@
M("`@("1I;F1E;G0@/2`D8VAA;F=E;&]G(#\@(B`@(B`Z("(B.PH@("`@("`@
M("1R970@/2`B)&EN9&5N="`@/')E;&5A<V4^7&XB.PH@("`@("`@(&EF("@A
M96UP='DH)'!K9VEN9F];)W9E<G-I;VXG72DI('L*("`@("`@("`@("`@)')E
M="`N/2`B)&EN9&5N="`@("`\=F5R<VEO;CXD<&MG:6YF;UMV97)S:6]N73PO
M=F5R<VEO;CY<;B(["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'!K
M9VEN9F];)W)E;&5A<V5?9&%T92==*2D@>PH@("`@("`@("`@("`D<F5T("X]
M("(D:6YD96YT("`@(#QD871E/B1P:V=I;F9O6W)E;&5A<V5?9&%T95T\+V1A
M=&4^7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1P:V=I;F9O
M6R=R96QE87-E7VQI8V5N<V4G72DI('L*("`@("`@("`@("`@)')E="`N/2`B
M)&EN9&5N="`@("`\;&EC96YS93XD<&MG:6YF;UMR96QE87-E7VQI8V5N<V5=
M/"]L:6-E;G-E/EQN(CL*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D
M<&MG:6YF;ULG<F5L96%S95]S=&%T92==*2D@>PH@("`@("`@("`@("`D<F5T
M("X]("(D:6YD96YT("`@(#QS=&%T93XD<&MG:6YF;UMR96QE87-E7W-T871E
M73PO<W1A=&4^7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1P
M:V=I;F9O6R=R96QE87-E7VYO=&5S)UTI*2!["B`@("`@("`@("`@("1R970@
M+CT@(B1I;F1E;G0@("`@/&YO=&5S/B(N:'1M;'-P96-I86QC:&%R<R@D<&MG
M:6YF;ULG<F5L96%S95]N;W1E<R==*2XB/"]N;W1E<SY<;B(["B`@("`@("`@
M?0H@("`@("`@(&EF("@A96UP='DH)'!K9VEN9F];)W)E;&5A<V5?=V%R;FEN
M9W,G72DI('L*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@("`\=V%R
M;FEN9W,^(BYH=&UL<W!E8VEA;&-H87)S*"1P:V=I;F9O6R=R96QE87-E7W=A
M<FYI;F=S)UTI+B(\+W=A<FYI;F=S/EQN(CL*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1P:V=I;F9O6R=R96QE87-E7V1E<',G72D@)B8@<VEZ96]F
M*"1P:V=I;F9O6R=R96QE87-E7V1E<',G72D@/B`P*2!["B`@("`@("`@("`@
M("1R970@+CT@(B1I;F1E;G0@("`@/&1E<',^7&XB.PH@("`@("`@("`@("!F
M;W)E86-H("@D<&MG:6YF;ULG<F5L96%S95]D97!S)UT@87,@)&1E<"D@>PH@
M("`@("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@("`@(#QD97`@='EP
M93U<(B1D97!;='EP95U<(B!R96P]7"(D9&5P6W)E;%U<(B(["B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<%LG=F5R<VEO;B==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1R970@+CT@(B!V97)S:6]N/5PB)&1E<%MV97)S:6]N
M75PB(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=O<'1I;VYA;"==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1R970@+CT@(B!O<'1I;VYA;#U<(B1D97!;;W!T:6]N86Q=7"(B.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)VYA;64G72DI('L*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("(^)&1E
M<%MN86UE73PO9&5P/EQN(CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)')E="`N/2`B+SY<;B(["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E="`N/2`B)&EN
M9&5N="`@("`\+V1E<',^7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S
M970H)'!K9VEN9F];)V-O;F9I9W5R95]O<'1I;VYS)UTI*2!["B`@("`@("`@
M("`@("1R970@+CT@(B1I;F1E;G0@("`@/&-O;F9I9W5R96]P=&EO;G,^7&XB
M.PH@("`@("`@("`@("!F;W)E86-H("@D<&MG:6YF;ULG8V]N9FEG=7)E7V]P
M=&EO;G,G72!A<R`D8RD@>PH@("`@("`@("`@("`@("`@)')E="`N/2`B)&EN
M9&5N="`@("`@(#QC;VYF:6=U<F5O<'1I;VX@;F%M93U<(B(N"B`@("`@("`@
M("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D8ULG;F%M92==*2`N(")<
M(B(["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-;)V1E9F%U;'0G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("(@9&5F875L=#U<(B(@
M+B!H=&UL<W!E8VEA;&-H87)S*"1C6R=D969A=6QT)UTI("X@(EPB(CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R970@+CT@(B!P<F]M
M<'0]7"(B("X@:'1M;'-P96-I86QC:&%R<R@D8ULG<')O;7!T)UTI("X@(EPB
M(CL*("`@("`@("`@("`@("`@("1R970@+CT@(B\^7&XB.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@("`@/"]C;VYF:6=U
M<F5O<'1I;VYS/EQN(CL*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1P
M:V=I;F9O6R=P<F]V:61E<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M<&MG:6YF;ULG<')O=FED97,G72!A<R`D:V5Y(#T^("1W:&%T*2!["B`@("`@
M("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`@(#QP<F]V:61E<R!T>7!E
M/5PB)'=H871;='EP95U<(B`B.PH@("`@("`@("`@("`@("`@)')E="`N/2`B
M;F%M93U<(B1W:&%T6VYA;65=7"(@(CL*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=VAA=%LG97AT96YD<R==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1R970@+CT@(F5X=&5N9',]7"(D=VAA=%ME>'1E;F1S75PB("(["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T("X]("(O/EQN(CL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'!K
M9VEN9F];)V9I;&5L:7-T)UTI*2!["B`@("`@("`@("`@("1R970@+CT@(B1I
M;F1E;G0@("`@/&9I;&5L:7-T/EQN(CL*("`@("`@("`@("`@9F]R96%C:"`H
M)'!K9VEN9F];)V9I;&5L:7-T)UT@87,@)&9I;&4@/3X@)&9A*2!["B`@("`@
M("`@("`@("`@("!`)')E="`N/2`B)&EN9&5N="`@("`@(#QF:6QE(')O;&4]
M7"(D9F%;<F]L95U<(B(["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9A
M6R=B87-E:6YS=&%L;&1I<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("1R
M970@+CT@)R!B87-E:6YS=&%L;&1I<CTB)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H)&9A6R=B87-E:6YS=&%L;&1I<B==
M*2`N("<B)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9F%;)VUD-7-U;2==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1R970@+CT@(B!M9#5S=6T]7"(D9F%;;60U<W5M75PB(CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9F%;)W!L871F
M;W)M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)')E="`N/2`B('!L871F
M;W)M/5PB)&9A6W!L871F;W)M75PB(CL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&9A6R=I;G-T86QL+6%S)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@)')E="`N/2`G(&EN<W1A;&PM87,](B<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1F
M85LG:6YS=&%L;"UA<R==*2`N("<B)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1R970@+CT@)R!N86UE/2(G("X@:'1M;'-P96-I86QC
M:&%R<R@D9FEL92D@+B`G(B<["B`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)&9A6R=R97!L86-E;65N=',G72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<F5T("X]("(O/EQN(CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)')E="`N/2`B/EQN(CL*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9F%;)W)E<&QA8V5M96YT<R==(&%S("1R*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@("`@("`@
M(#QR97!L86-E(CL*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'(@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R970@+CT@(B`D:SU<(B(@+B!H=&UL<W!E8VEA;&-H87)S*"1V*2`N)R(G
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("1R970@+CT@(B\^7&XB.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!`)')E="`N/2`B)&EN9&5N="`@("`@(#PO
M9FEL93Y<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@("`\+V9I;&5L:7-T/EQN(CL*
M("`@("`@("!]"B`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/"]R96QE87-E
M/EQN(CL*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!V86QI9&%T95!A8VMA9V5);F9O*"D*"B`@("`O*BH*("`@
M("`J(%9A;&ED871E(%A-3"!P86-K86=E(&1E9FEN:71I;VX@9FEL92X*("`@
M("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D:6YF;R!&:6QE;F%M92!O9B!T
M:&4@<&%C:V%G92!A<F-H:79E(&]R(&]F('1H90H@("`@("H@("`@("`@("`@
M("`@("`@<&%C:V%G92!D969I;FET:6]N(&9I;&4*("`@("`J($!P87)A;2`@
M87)R87D@)&5R<F]R<R!!<G)A>2!T:&%T('=I;&P@8V]N=&%I;B!T:&4@97)R
M;W)S"B`@("`@*B!`<&%R86T@(&%R<F%Y("1W87)N:6YG<R!!<G)A>2!T:&%T
M('=I;&P@8V]N=&%I;B!T:&4@=V%R;FEN9W,*("`@("`J($!P87)A;2`@<W1R
M:6YG("1D:7)?<')E9FEX("AO<'1I;VYA;"D@9&ER96-T;W)Y('=H97)E('-O
M=7)C92!F:6QE<PH@("`@("H@("`@("`@("`@("`@("`@;6%Y(&)E(&9O=6YD
M+"!O<B!E;7!T>2!I9B!T:&5Y(&%R92!N;W0@879A:6QA8FQE"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('9A;&ED871E4&%C:V%G94EN9F\H)&EN9F\L("8D97)R
M;W)S+"`F)'=A<FYI;F=S+"`D9&ER7W!R969I>"`]("<G*0H@("`@>PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O(#T@)'1H:7,M/FEN9F]&<F]M
M06YY*"1I;F9O*2DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1I;F9O*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D:6YF;RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@)&5R<F]R<R`](&%R<F%Y*"D["B`@("`@("`@)'=A<FYI
M;F=S(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=P86-K
M86=E)UTI*2!["B`@("`@("`@("`@("1E<G)O<G-;72`]("=M:7-S:6YG('!A
M8VMA9V4@;F%M92<["B`@("`@("`@?2!E;'-E:68@*"$D=&AI<RT^=F%L:610
M86-K86=E3F%M92@D:6YF;ULG<&%C:V%G92==*2D@>PH@("`@("`@("`@("`D
M97)R;W)S6UT@/2`G:6YV86QI9"!P86-K86=E(&YA;64G.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5.86UE(#T@)'!N(#T@)&EN9F];)W!A
M8VMA9V4G73L*"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=S=6UM87)Y)UTI
M*2!["B`@("`@("`@("`@("1E<G)O<G-;72`]("=M:7-S:6YG('-U;6UA<GDG
M.PH@("`@("`@('T@96QS96EF("AS=')P;W,H=')I;2@D:6YF;ULG<W5M;6%R
M>2==*2P@(EQN(BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1W87)N:6YG
M<UM=(#T@)W-U;6UA<GD@<VAO=6QD(&)E(&]N(&$@<VEN9VQE(&QI;F4G.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&EN9F];)V1E<V-R:7!T:6]N
M)UTI*2!["B`@("`@("`@("`@("1E<G)O<G-;72`]("=M:7-S:6YG(&1E<V-R
M:7!T:6]N)SL*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=R
M96QE87-E7VQI8V5N<V4G72DI('L*("`@("`@("`@("`@)&5R<F]R<UM=(#T@
M)VUI<W-I;F<@;&EC96YS92<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S
M970H)&EN9F];)W9E<G-I;VXG72DI('L*("`@("`@("`@("`@)&5R<F]R<UM=
M(#T@)VUI<W-I;F<@=F5R<VEO;B<["B`@("`@("`@?2!E;'-E:68@*"$D=&AI
M<RT^=F%L:61086-K86=E5F5R<VEO;B@D:6YF;ULG=F5R<VEO;B==*2D@>PH@
M("`@("`@("`@("`D97)R;W)S6UT@/2`G:6YV86QI9"!P86-K86=E('9E<G-I
M;VXG.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&EN9F];)W)E;&5A
M<V5?<W1A=&4G72DI('L*("`@("`@("`@("`@)&5R<F]R<UM=(#T@)VUI<W-I
M;F<@<F5L96%S92!S=&%T92<["B`@("`@("`@?2!E;'-E:68@*"%I;E]A<G)A
M>2@D:6YF;ULG<F5L96%S95]S=&%T92==+"!014%27T-O;6UO;CHZ9V5T4F5L
M96%S95-T871E<R@I*2D@>PH@("`@("`@("`@("`D97)R;W)S6UT@/2`B:6YV
M86QI9"!R96QE87-E('-T871E(&`D:6YF;UMR96QE87-E7W-T871E72<L('-H
M;W5L9"!B92!O;F4@;V8Z("(*("`@("`@("`@("`@("`@("X@:6UP;&]D92@G
M("<L(%!%05)?0V]M;6]N.CIG971296QE87-E4W1A=&5S*"DI.PH@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&EN9F];)W)E;&5A<V5?9&%T92==*2D@
M>PH@("`@("`@("`@("`D97)R;W)S6UT@/2`G;6ES<VEN9R!R96QE87-E(&1A
M=&4G.PH@("`@("`@('T@96QS96EF("@A<')E9U]M871C:"@G+UY<9'LT?2U<
M9%QD+5QD7&0D+R<L("1I;F9O6R=R96QE87-E7V1A=&4G72DI('L*("`@("`@
M("`@("`@)&5R<F]R<UM=(#T@(FEN=F%L:60@<F5L96%S92!D871E(&`D:6YF
M;UMR96QE87-E7V1A=&5=)RP@9F]R;6%T(&ES(%E965DM34TM1$0B.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&EN9F];)W)E;&5A<V5?;F]T97,G
M72DI('L*("`@("`@("`@("`@)&5R<F]R<UM=(#T@(FUI<W-I;F<@<F5L96%S
M92!N;W1E<R(["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG
M;6%I;G1A:6YE<G,G72DI('L*("`@("`@("`@("`@)&5R<F]R<UM=(#T@)VYO
M(&UA:6YT86EN97(H<RDG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1I(#T@,3L*("`@("`@("`@("`@9F]R96%C:"`H)&EN9F];)VUA:6YT86EN
M97)S)UT@87,@)&TI('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;5LG
M:&%N9&QE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@
M(FUA:6YT86EN97(@)&DZ(&UI<W-I;F<@:&%N9&QE(CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;5LG<F]L92==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;72`](")M86EN=&%I;F5R
M("1I.B!M:7-S:6YG(')O;&4B.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"%I;E]A<G)A>2@D;5LG<F]L92==+"!014%27T-O;6UO;CHZ9V5T57-E<E)O
M;&5S*"DI*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@(FUA
M:6YT86EN97(@)&DZ(&EN=F%L:60@<F]L92!@)&U;<F]L95TG+"!S:&]U;&0@
M8F4@;VYE(&]F.B`B"B`@("`@("`@("`@("`@("`@("`@("`@("X@:6UP;&]D
M92@G("<L(%!%05)?0V]M;6]N.CIG9715<V5R4F]L97,H*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&U;)VYA;64G
M72DI('L*("`@("`@("`@("`@("`@("`@("`D97)R;W)S6UT@/2`B;6%I;G1A
M:6YE<B`D:3H@;6ES<VEN9R!N86UE(CL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D;5LG96UA:6PG72DI('L*("`@("`@
M("`@("`@("`@("`@("`D97)R;W)S6UT@/2`B;6%I;G1A:6YE<B`D:3H@;6ES
M<VEN9R!E;6%I;"(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D:2LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A
M96UP='DH)&EN9F];)V1E<',G72DI('L*("`@("`@("`@("`@)&D@/2`Q.PH@
M("`@("`@("`@("!F;W)E86-H("@D:6YF;ULG9&5P<R==(&%S("1D*2!["B`@
M("`@("`@("`@("`@("!I9B`H96UP='DH)&1;)W1Y<&4G72DI('L*("`@("`@
M("`@("`@("`@("`@("`D97)R;W)S6UT@/2`B9&5P96YD96YC>2`D:3H@;6ES
M<VEN9R!T>7!E(CL*("`@("`@("`@("`@("`@('T@96QS96EF("@A:6Y?87)R
M87DH)&1;)W1Y<&4G72P@4$5!4E]#;VUM;VXZ.F=E=$1E<&5N9&5N8WE4>7!E
M<R@I*2D@>PH@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;72`](")D97!E
M;F1E;F-Y("1I.B!I;G9A;&ED('1Y<&4L('-H;W5L9"!B92!O;F4@;V8Z("(@
M+@H@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<@)RP@4$5!4E]#
M;VUM;VXZ.F=E=$1E<&5N9&5N8WE4>7!E<R@I*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D9%LG<F5L)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@(F1E<&5N9&5N8WD@)&DZ
M(&UI<W-I;F<@<F5L871I;VXB.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"%I;E]A<G)A>2@D9%LG<F5L)UTL(%!%05)?0V]M;6]N.CIG971$97!E;F1E
M;F-Y4F5L871I;VYS*"DI*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R
M<UM=(#T@(F1E<&5N9&5N8WD@)&DZ(&EN=F%L:60@<F5L871I;VXL('-H;W5L
M9"!B92!O;F4@;V8Z("(*("`@("`@("`@("`@("`@("`@("`@("`@+B!I;7!L
M;V1E*"<@)RP@4$5!4E]#;VUM;VXZ.F=E=$1E<&5N9&5N8WE296QA=&EO;G,H
M*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1D6R=O<'1I;VYA;"==*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@A:6Y?87)R87DH)&1;)V]P=&EO;F%L)UTL(&%R<F%Y*"=Y97,G+"`G;F\G
M*2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@(F1E
M<&5N9&5N8WD@)&DZ(&EN=F%L:60@<F5L871I;VX@;W!T:6]N86P@871T<FEB
M=71E+"!S:&]U;&0@8F4@;VYE(&]F.B!Y97,@;F\B.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@D9%LG<F5L)UT@(3T@)VAA<R<@)B8@96UP='DH)&1;)W9E<G-I;VXG72DI
M('L*("`@("`@("`@("`@("`@("`@("`D=V%R;FEN9W-;72`](")D97!E;F1E
M;F-Y("1I.B!M:7-S:6YG('9E<G-I;VXB.PH@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1D6R=R96PG72`]/2`G:&%S)R`F)B`A96UP='DH)&1;)W9E<G-I
M;VXG72DI('L*("`@("`@("`@("`@("`@("`@("`D=V%R;FEN9W-;72`](")D
M97!E;F1E;F-Y("1I.B!V97)S:6]N(&EG;F]R960@9F]R(&!H87,G(&1E<&5N
M9&5N8VEE<R(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)&1;)W1Y<&4G72`]/2`G<&AP)R`F)B`A96UP='DH)&1;)VYA;64G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D=V%R;FEN9W-;72`](")D97!E;F1E
M;F-Y("1I.B!N86UE(&EG;F]R960@9F]R('!H<"!T>7!E(&1E<&5N9&5N8VEE
M<R(["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&1;)W1Y<&4G72`A/2`G
M<&AP)R`F)B!E;7!T>2@D9%LG;F%M92==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1E<G)O<G-;72`](")D97!E;F1E;F-Y("1I.B!M:7-S:6YG(&YA;64B
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&DK*SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1I;F9O
M6R=C;VYF:6=U<F5?;W!T:6]N<R==*2D@>PH@("`@("`@("`@("`D:2`](#$[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=C;VYF:6=U<F5?;W!T:6]N
M<R==(&%S("1C*2!["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&-;)VYA
M;64G72DI('L*("`@("`@("`@("`@("`@("`@("`D97)R;W)S6UT@/2`B8V]N
M9FEG=7)E(&]P=&EO;B`D:3H@;6ES<VEN9R!N86UE(CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D8ULG<')O;7!T)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@(F-O;F9I9W5R
M92!O<'1I;VX@)&DZ(&UI<W-I;F<@<')O;7!T(CL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=F:6QE;&ES="==*2D@>PH@
M("`@("`@("`@("`D97)R;W)S6UT@/2`G;F\@9FEL97,G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=F:6QE;&ES="==
M(&%S("1F:6QE(#T^("1F82D@>PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y
M*"1F85LG<F]L92==*2D@>PH@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;
M72`](")F:6QE("1F:6QE.B!M:7-S:6YG(')O;&4B.PH@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"%I
M;E]A<G)A>2@D9F%;)W)O;&4G72P@4$5!4E]#;VUM;VXZ.F=E=$9I;&52;VQE
M<R@I*2D@>PH@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;72`](")F:6QE
M("1F:6QE.B!I;G9A;&ED(')O;&4L('-H;W5L9"!B92!O;F4@;V8Z("(*("`@
M("`@("`@("`@("`@("`@("`@("`@+B!I;7!L;V1E*"<@)RP@4$5!4E]#;VUM
M;VXZ.F=E=$9I;&52;VQE<R@I*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("@D9F%;)W)O;&4G72`]/2`G<&AP)R`F)B`D9&ER7W!R
M969I>"D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@(D%N
M86QY>FEN9R`D9FEL92(I.PH@("`@("`@("`@("`@("`@("`@("1S<F-I;F9O
M(#T@)'1H:7,M/F%N86QY>F53;W5R8V5#;V1E*"1D:7)?<')E9FEX("X@1$E2
M14-43U)97U-%4$%2051/4B`N("1F:6QE*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'-R8VEN9F\I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F)U:6QD4')O=FED97-!<G)A>2@D<W)C:6YF;RD["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("\O("AS<V(I($%N>2!C:&5C:W,@=V4@8V%N(&1O(&9O<B!B87-E:6YS=&%L
M;&1I<C\*("`@("`@("`@("`@("`@("\O("AC;W@I(%!E<FAA<',@8VAE8VMS
M('1H870@96ET:&5R('1H92!T87)G970@9&ER(&%N9`H@("`@("`@("`@("`@
M("`@+R\@("`@("`@8F%S94EN<W1A;&P@9&]E<VXG="!C;VEN=&%I;B`B+BXO
M+BXO(@H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94YA;64@/2`D<&X@/2`D:6YF;ULG<&%C:V%G92==.PH@("`@("`@
M("1P;FP@/2!S=')L96XH)'!N*3L*("`@("`@("!F;W)E86-H("@H87)R87DI
M)'1H:7,M/G!K9VEN9F];)W!R;W9I9&5S)UT@87,@)&ME>2`]/B`D=VAA="D@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)'=H871;)V5X<&QI8VET)UTI*2![
M"B`@("`@("`@("`@("`@("`O+R!S:VEP(&-O;F9O<FUA;F-E(&-H96-K<R!I
M9B!T:&4@<')O=FED97,@96YT<GD@:7,*("`@("`@("`@("`@("`@("\O('-P
M96-I9FEE9"!I;B!T:&4@<&%C:V%G92YX;6P@9FEL90H@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@97AT<F%C
M="@D=VAA="D["B`@("`@("`@("`@(&EF("@D='EP92`]/2`G8VQA<W,G*2![
M"B`@("`@("`@("`@("`@("!I9B`H(7-T<FYC87-E8VUP*"1N86UE+"`D<&XL
M("1P;FPI*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=V%R;FEN9W-;72`](")I
M;B`D9FEL93H@8VQA<W,@7"(D;F%M95PB(&YO="!P<F5F:7AE9"!W:71H('!A
M8VMA9V4@;F%M92!<(B1P;EPB(CL*("`@("`@("`@("`@?2!E;'-E:68@*"1T
M>7!E(#T]("=F=6YC=&EO;B<I('L*("`@("`@("`@("`@("`@(&EF("AS=')S
M='(H)&YA;64L("<Z.B<I('Q\("%S=')N8V%S96-M<"@D;F%M92P@)'!N+"`D
M<&YL*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=A<FYI;F=S6UT@/2`B:6X@
M)&9I;&4Z(&9U;F-T:6]N(%PB)&YA;65<(B!N;W0@<')E9FEX960@=VET:"!P
M86-K86=E(&YA;64@7"(D<&Y<(B(["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!B=6EL9%!R;W9I9&5S07)R87DH*0H*("`@("\J*@H@("`@("H@
M0G5I;&0@82`B<')O=FED97,B(&%R<F%Y(&9R;VT@9&%T82!R971U<FYE9"!B
M>0H@("`@("H@86YA;'EZ95-O=7)C94-O9&4H*2X@(%1H92!F;W)M870@;V8@
M=&AE(&)U:6QT(&%R<F%Y(&ES(&QI:V4*("`@("`J('1H:7,Z"B`@("`@*@H@
M("`@("H@(&%R<F%Y*`H@("`@("H@("`@)V-L87-S.TUY0VQA<W,G(#T^("=A
M<G)A>2@G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^("=->4-L87-S)RDL
M"B`@("`@*B`@("`N+BX*("`@("`J("`I"B`@("`@*@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<W)C:6YF;R!A<G)A>2!W:71H(&EN9F]R;6%T:6]N
M(&%B;W5T(&$@<V]U<F-E(&9I;&4*("`@("`J(&%S(')E='5R;F5D(&)Y('1H
M92!A;F%L>7IE4V]U<F-E0V]D92@I(&UE=&AO9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I;&10<F]V:61E<T%R<F%Y*"1S
M<F-I;F9O*0H@("`@>PH@("`@("`@("1F:6QE(#T@8F%S96YA;64H)'-R8VEN
M9F];)W-O=7)C95]F:6QE)UTI.PH@("`@("`@("1P;B`@/2`D=&AI<RT^7W!A
M8VMA9V5.86UE.PH@("`@("`@("1P;FP@/2!S=')L96XH)'!N*3L*("`@("`@
M("!F;W)E86-H("@D<W)C:6YF;ULG9&5C;&%R961?8VQA<W-E<R==(&%S("1C
M;&%S<RD@>PH@("`@("`@("`@("`D:V5Y(#T@(F-L87-S.R1C;&%S<R(["B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<&MG:6YF;ULG<')O=FED97,G
M75LD:V5Y72DI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O6R=P<F]V:61E<R==
M6R1K97E=(#T*("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)ST^("1F:6QE
M+"`G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^("1C;&%S<RD["B`@("`@
M("`@("`@(&EF("AI<W-E="@D<W)C:6YF;ULG:6YH97)I=&%N8V4G75LD8VQA
M<W-=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F];)W!R;W9I
M9&5S)UU;)&ME>5U;)V5X=&5N9',G72`]"B`@("`@("`@("`@("`@("`@("`@
M)'-R8VEN9F];)VEN:&5R:71A;F-E)UU;)&-L87-S73L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!F;W)E86-H("@D<W)C:6YF;ULG9&5C;&%R
M961?;65T:&]D<R==(&%S("1C;&%S<R`]/B`D;65T:&]D<RD@>PH@("`@("`@
M("`@("!F;W)E86-H("@D;65T:&]D<R!A<R`D;65T:&]D*2!["B`@("`@("`@
M("`@("`@("`D9G5N8W1I;VX@/2`B)&-L87-S.CHD;65T:&]D(CL*("`@("`@
M("`@("`@("`@("1K97D@/2`B9G5N8W1I;VX[)&9U;F-T:6]N(CL*("`@("`@
M("`@("`@("`@(&EF("@D;65T:&]D>S!](#T]("=?)R!\?"`A<W1R8V%S96-M
M<"@D;65T:&]D+"`D8VQA<W,I('Q\"B`@("`@("`@("`@("`@("`@("`@:7-S
M970H)'1H:7,M/G!K9VEN9F];)W!R;W9I9&5S)UU;)&ME>5TI*2!["B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D=&AI<RT^<&MG:6YF;ULG<')O=FED97,G75LD:V5Y
M72`]"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I;&4L
M("=T>7!E)R`]/B`G9G5N8W1I;VXG+"`G;F%M92<@/3X@)&9U;F-T:6]N*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'-R
M8VEN9F];)V1E8VQA<F5D7V9U;F-T:6]N<R==(&%S("1F=6YC=&EO;BD@>PH@
M("`@("`@("`@("`D:V5Y(#T@(F9U;F-T:6]N.R1F=6YC=&EO;B(["B`@("`@
M("`@("`@(&EF("@D9G5N8W1I;VY[,'T@/3T@)U\G('Q\(&ES<V5T*"1T:&ES
M+3YP:V=I;F9O6R=P<F]V:61E<R==6R1K97E=*2D@>PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%S
M=')S='(H)&9U;F-T:6]N+"`G.CHG*2`F)B!S=')N8V%S96-M<"@D9G5N8W1I
M;VXL("1P;BP@)'!N;"DI('L*("`@("`@("`@("`@("`@("1W87)N:6YG<UM=
M(#T@(FEN,2`B("X@)&9I;&4@+B`B.B!F=6YC=&EO;B!<(B1F=6YC=&EO;EPB
M(&YO="!P<F5F:7AE9"!W:71H('!A8VMA9V4@;F%M92!<(B1P;EPB(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<&MG:6YF;ULG<')O=FED
M97,G75LD:V5Y72`]"B`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D
M9FEL92P@)W1Y<&4G(#T^("=F=6YC=&EO;B<L("=N86UE)R`]/B`D9G5N8W1I
M;VXI.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A
M;F%L>7IE4V]U<F-E0V]D92@I"@H@("`@+RHJ"B`@("`@*B!!;F%L>7IE('1H
M92!S;W5R8V4@8V]D92!O9B!T:&4@9VEV96X@4$A0(&9I;&4*("`@("`J"B`@
M("`@*B!`<&%R86T@('-T<FEN9R!&:6QE;F%M92!O9B!T:&4@4$A0(&9I;&4*
M("`@("`J($!R971U<FX@;6EX960*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%N86QY>F53;W5R8V5#;V1E*"1F:6QE*0H@
M("`@>PH@("`@("`@(&EF("@A9G5N8W1I;VY?97AI<W1S*")T;VME;E]G971?
M86QL(BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21F<"`]($!F;W!E;B@D9FEL92P@(G(B*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1C;VYT
M96YT<R`](&9R96%D*"1F<"P@9FEL97-I>F4H)&9I;&4I*3L*("`@("`@("`D
M=&]K96YS(#T@=&]K96Y?9V5T7V%L;"@D8V]N=&5N=',I.PHO*@H@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&]K96YS*3L@)&DK*RD@>PH@
M("`@("`@("`@("!`;&ES="@D=&]K96XL("1D871A*2`]("1T;VME;G-;)&E=
M.PH@("`@("`@("`@("!I9B`H:7-?<W1R:6YG*"1T;VME;BDI('L*("`@("`@
M("`@("`@("`@('9A<E]D=6UP*"1T;VME;BD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!P<FEN="!T;VME;E]N86UE*"1T;VME;BD@
M+B`G("<["B`@("`@("`@("`@("`@("!V87)?9'5M<"AR=')I;2@D9&%T82DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0HJ+PH@("`@("`@("1L;V]K7V9O
M<B`](#`["B`@("`@("`@)'!A<F5N7VQE=F5L(#T@,#L*("`@("`@("`D8G)A
M8VME=%]L979E;"`](#`["B`@("`@("`@)&)R86-E7VQE=F5L(#T@,#L*("`@
M("`@("`D;&%S='!H<&1O8R`]("<G.PH@("`@("`@("1C=7)R96YT7V-L87-S
M(#T@)R<["B`@("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V96P@/2`M,3L*("`@
M("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G.PH@("`@("`@("1C=7)R96YT
M7V9U;F-T:6]N7VQE=F5L(#T@+3$["B`@("`@("`@)&1E8VQA<F5D7V-L87-S
M97,@/2!A<G)A>2@I.PH@("`@("`@("1D96-L87)E9%]F=6YC=&EO;G,@/2!A
M<G)A>2@I.PH@("`@("`@("1D96-L87)E9%]M971H;V1S(#T@87)R87DH*3L*
M("`@("`@("`D=7-E9%]C;&%S<V5S(#T@87)R87DH*3L*("`@("`@("`D=7-E
M9%]F=6YC=&EO;G,@/2!A<G)A>2@I.PH@("`@("`@("1E>'1E;F1S(#T@87)R
M87DH*3L*("`@("`@("`D;F]D97!S(#T@87)R87DH*3L*("`@("`@("`D:6YQ
M=6]T92`](&9A;'-E.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O
M9B@D=&]K96YS*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)'1O:V5N<ULD:5TI*2!["B`@("`@("`@("`@("`@("!L:7-T*"1T;VME;BP@
M)&1A=&$I(#T@)'1O:V5N<ULD:5T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&]K96X@/2`D=&]K96YS6R1I73L*("`@("`@("`@
M("`@("`@("1D871A(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1I;G%U;W1E*2!["B`@("`@("`@("`@("`@("!I9B`H)'1O:V5N("$]
M("<B)RD@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:6YQ=6]T
M92`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@('-W:71C:"`H)'1O:V5N*2!["B`@("`@("`@("`@("`@("!C
M87-E("<B)SH*("`@("`@("`@("`@("`@("`@("`D:6YQ=6]T92`]('1R=64[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E(%1?0U523%E?3U!%3CH*("`@("`@("`@("`@("`@(&-A<V4@5%]$3TQ,
M05)?3U!%3E]#55),65]"4D%#15,Z"B`@("`@("`@("`@("`@("!C87-E("=[
M)SH@)&)R86-E7VQE=F5L*RL[(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@
M("!C87-E("=])SH*("`@("`@("`@("`@("`@("`@("`D8G)A8V5?;&5V96PM
M+3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-U<G)E;G1?8VQA<W-?;&5V
M96P@/3T@)&)R86-E7VQE=F5L*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1C=7)R96YT7V-L87-S(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@
M("1C=7)R96YT7V-L87-S7VQE=F5L(#T@+3$["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@D8W5R<F5N=%]F=6YC=&EO
M;E]L979E;"`]/2`D8G)A8V5?;&5V96PI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`G)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@
M,CL*("`@("`@("`@("`@("`@(&-A<V4@)ULG.B`D8G)A8VME=%]L979E;"LK
M.R!C;VYT:6YU92`R.PH@("`@("`@("`@("`@("`@8V%S92`G72<Z("1B<F%C
M:V5T7VQE=F5L+2T[(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@("!C87-E
M("<H)SH@)'!A<F5N7VQE=F5L*RL[("`@8V]N=&EN=64@,CL*("`@("`@("`@
M("`@("`@(&-A<V4@)RDG.B`D<&%R96Y?;&5V96PM+3L@("!C;VYT:6YU92`R
M.PH@("`@("`@("`@("`@("`@8V%S92!47T-,05-3.@H@("`@("`@("`@("`@
M("`@("`@(&EF("@H)&-U<G)E;G1?8VQA<W-?;&5V96P@(3T@+3$I('Q\("@D
M8W5R<F5N=%]F=6YC=&EO;E]L979E;"`A/2`M,2DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@B4&%R<V5R(&5R<F]R.B!)
M;G9A;&ED(%!(4"!F:6QE("1F:6QE(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%!%05)?0T]-34].7T524D]27TE.5D%,24102%`I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8V%S92!47T953D-424]..@H@("`@
M("`@("`@("`@("`@8V%S92!47TY%5SH*("`@("`@("`@("`@("`@(&-A<V4@
M5%]%6%1%3D13.@H@("`@("`@("`@("`@("`@("`@("1L;V]K7V9O<B`]("1T
M;VME;CL*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@
M("`@("`@("`@8V%S92!47U-44DE.1SH*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&QO;VM?9F]R(#T](%1?0TQ!4U,I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-U<G)E;G1?8VQA<W,@/2`D9&%T83L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V96P@/2`D8G)A8V5?;&5V96P[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]C;&%S<V5S6UT@
M/2`D8W5R<F5N=%]C;&%S<SL*("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)&QO;VM?9F]R(#T](%1?15A414Y$4RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D97AT96YD<ULD8W5R<F5N=%]C;&%S<UT@/2`D9&%T83L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?1E5.
M0U1)3TXI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R96YT
M7V-L87-S*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N
M=%]F=6YC=&EO;B`]("(D8W5R<F5N=%]C;&%S<SHZ)&1A=&$B.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7VUE=&AO9'-;)&-U<G)E
M;G1?8VQA<W-=6UT@/2`D9&%T83L*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT
M7V9U;F-T:6]N(#T@)&1A=&$["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5C;&%R961?9G5N8W1I;VYS6UT@/2`D8W5R<F5N=%]F=6YC=&EO;CL*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]("1B<F%C95]L979E;#L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&T@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%].15<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'5S961?8VQA<W-E<ULD9&%T85T@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D;&]O:U]F;W(@/2`P.PH@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E(#(["B`@("`@("`@("`@("`@("!C87-E(%1?5D%224%"3$4Z"B`@("`@
M("`@("`@("`@("`@("`@)&QO;VM?9F]R(#T@,#L*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("`@("`@8V%S92!47T-/34U%
M3E0Z"B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R%>+UPJ
M7"I<<R$G+"`D9&%T82DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QA
M<W1P:'!D;V,@/2`D9&%T83L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*'!R96=?;6%T8VA?86QL*"<O0&YO9&5P7',K*%Q3*RDO)RP@)&QA<W1P:'!D
M;V,L("1M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO9&5P
M<R`](&%R<F%Y7VUE<F=E*"1N;V1E<',L("1M6S%=*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("`@("`@8V%S92!4
M7T1/54),15]#3TQ/3CH*("`@("`@("`@("`@("`@("`@("!I9B`H)'1O:V5N
M<ULD:2`M(#%=6S!=("$](%1?4U1224Y'*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(%!%05(Z.G)A:7-E17)R;W(H(E!A<G-E<B!E<G)O<CH@26YV86QI
M9"!02%`@9FEL92`D9FEL92(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%27T-/34U/3E]%4E)/4E])3E9!3$E$4$A0*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2`D=&]K96YS6R1I("T@
M,5U;,5T["B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&-L
M87-S*2`A/2`G<&%R96YT)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=7-E9%]C;&%S<V5S6R1C;&%S<UT@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@
M("`@("`@(G-O=7)C95]F:6QE(B`]/B`D9FEL92P*("`@("`@("`@("`@(F1E
M8VQA<F5D7V-L87-S97,B(#T^("1D96-L87)E9%]C;&%S<V5S+`H@("`@("`@
M("`@("`B9&5C;&%R961?;65T:&]D<R(@/3X@)&1E8VQA<F5D7VUE=&AO9',L
M"B`@("`@("`@("`@(")D96-L87)E9%]F=6YC=&EO;G,B(#T^("1D96-L87)E
M9%]F=6YC=&EO;G,L"B`@("`@("`@("`@(")U<V5D7V-L87-S97,B(#T^(&%R
M<F%Y7V1I9F8H87)R87E?:V5Y<R@D=7-E9%]C;&%S<V5S*2P@)&YO9&5P<RDL
M"B`@("`@("`@("`@(")I;FAE<FET86YC92(@/3X@)&5X=&5N9',L"B`@("`@
M("`@("`@("D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@(&)E='1E
M<E-T871E<R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FX@86X@87)R87D@8V]N
M=&%I;FEN9R!A;&P@;V8@=&AE('-T871E<R!T:&%T(&%R92!M;W)E('-T86)L
M92!T:&%N"B`@("`@*B!O<B!E<75A;"!T;R!T:&4@<&%S<V5D(&EN('-T871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!296QE87-E('-T871E"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B!$971E<FUI;F5S('=H971H97(@=&\@:6YC
M;'5D92`D<W1A=&4@:6X@=&AE(&QI<W0*("`@("`J($!R971U<FX@9F%L<V5\
M87)R87D@1F%L<V4@:68@)'-T871E(&ES(&YO="!A('9A;&ED(')E;&5A<V4@
M<W1A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@8F5T=&5R4W1A=&5S*"1S=&%T
M92P@)&EN8VQU9&4@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)'-T
M871E<R`](&%R<F%Y*"=S;F%P<VAO="<L("=D979E;"<L("=A;'!H82<L("=B
M971A)RP@)W-T86)L92<I.PH@("`@("`@("1I(#T@87)R87E?<V5A<F-H*"1S
M=&%T92P@)'-T871E<RD["B`@("`@("`@:68@*"1I(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF
M("@D:6YC;'5D92D@>PH@("`@("`@("`@("`D:2TM.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@87)R87E?<VQI8V4H)'-T871E<RP@)&D@*R`Q*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D971E8W1$97!E;F1E;F-I97,H
M*0H*("`@(&9U;F-T:6]N(&1E=&5C=$1E<&5N9&5N8VEE<R@D86YY+"`D<W1A
M='5S7V-A;&QB86-K(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(69U;F-T
M:6]N7V5X:7-T<R@B=&]K96Y?9V5T7V%L;"(I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&EN9F\@/2`D=&AI<RT^:6YF;T9R;VU!;GDH)&%N>2DI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD["B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-?87)R87DH)&EN9F\I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)&1E<',@/2!A
M<G)A>2@I.PH@("`@("`@("1U<V5D7V,@/2`D9&5C;%]C(#T@)&1E8VQ?9B`]
M("1D96-L7VT@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=F
M:6QE;&ES="==(&%S("1F:6QE(#T^("1F82D@>PH@("`@("`@("`@("`D=&UP
M(#T@)'1H:7,M/F%N86QY>F53;W5R8V5#;V1E*"1F:6QE*3L*("`@("`@("`@
M("`@)'5S961?8R`]($!A<G)A>5]M97)G92@D=7-E9%]C+"`D=&UP6R=U<V5D
M7V-L87-S97,G72D["B`@("`@("`@("`@("1D96-L7V,@/2!`87)R87E?;65R
M9V4H)&1E8VQ?8RP@)'1M<%LG9&5C;&%R961?8VQA<W-E<R==*3L*("`@("`@
M("`@("`@)&1E8VQ?9B`]($!A<G)A>5]M97)G92@D9&5C;%]F+"`D=&UP6R=D
M96-L87)E9%]F=6YC=&EO;G,G72D["B`@("`@("`@("`@("1D96-L7VT@/2!`
M87)R87E?;65R9V4H)&1E8VQ?;2P@)'1M<%LG9&5C;&%R961?;65T:&]D<R==
M*3L*("`@("`@("`@("`@)&EN:&5R:2`]($!A<G)A>5]M97)G92@D:6YH97)I
M+"`D=&UP6R=I;FAE<FET86YC92==*3L*("`@("`@("!]"B`@("`@("`@)'5S
M961?8R`](&%R<F%Y7W5N:7%U92@D=7-E9%]C*3L*("`@("`@("`D9&5C;%]C
M(#T@87)R87E?=6YI<75E*"1D96-L7V,I.PH@("`@("`@("1U;F1E8VQ?8R`]
M(&%R<F%Y7V1I9F8H)'5S961?8RP@)&1E8VQ?8RD["B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"=U<V5D7V-L87-S97,G(#T^("1U<V5D7V,L"B`@("`@("`@("`@
M("`@("`@("`@("=D96-L87)E9%]C;&%S<V5S)R`]/B`D9&5C;%]C+`H@("`@
M("`@("`@("`@("`@("`@("`G9&5C;&%R961?;65T:&]D<R<@/3X@)&1E8VQ?
M;2P*("`@("`@("`@("`@("`@("`@("`@)V1E8VQA<F5D7V9U;F-T:6]N<R<@
M/3X@)&1E8VQ?9BP*("`@("`@("`@("`@("`@("`@("`@)W5N9&5C;&%R961?
M8VQA<W-E<R<@/3X@)'5N9&5C;%]C+`H@("`@("`@("`@("`@("`@("`@("`G
M:6YH97)I=&%N8V4G(#T^("1I;FAE<FDL"B`@("`@("`@("`@("`@("`@("`@
M("D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T57-E<E)O;&5S
M*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@=F%L:60@<F]L97,@9F]R(&$@
M4$5!4B!P86-K86=E(&UA:6YT86EN97(*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%5S97)2;VQE<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?
M4$5!4E]#;VUM;VY?;6%I;G1A:6YE<E]R;VQE<R==.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&=E=%)E;&5A<V53=&%T97,H*0H*("`@("\J*@H@
M("`@("H@1V5T('1H92!V86QI9"!P86-K86=E(')E;&5A<V4@<W1A=&5S(&]F
M('!A8VMA9V5S"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>0H@("`@("H@
M0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971296QE87-E4W1A=&5S
M*"D*("`@('L*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T-O;6UO
M;E]R96QE87-E7W-T871E<R==.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&=E=$1E<&5N9&5N8WE4>7!E<R@I"@H@("`@+RHJ"B`@("`@*B!'970@
M=&AE(&EM<&QE;65N=&5D(&1E<&5N9&5N8WD@='EP97,@*'!H<"P@97AT+"!P
M:V<@971C+BD*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B!`
M<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E<&5N9&5N8WE4>7!E
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VUM
M;VY?9&5P96YD96YC>5]T>7!E<R==.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&=E=$1E<&5N9&5N8WE296QA=&EO;G,H*0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!I;7!L96UE;G1E9"!D97!E;F1E;F-Y(')E;&%T:6]N<R`H
M:&%S+"!L="P@9V4@971C+BD*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E<&5N
M9&5N8WE296QA=&EO;G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D1TQ/0D%,
M4ULG7U!%05)?0V]M;6]N7V1E<&5N9&5N8WE?<F5L871I;VYS)UT["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T1FEL95)O;&5S*"D*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@:6UP;&5M96YT960@9FEL92!R;VQE<PH@("`@
M("H*("`@("`J($!R971U<FX@87)R87D*("`@("`J($!S=&%T:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T1FEL95)O;&5S*"D*("`@('L*("`@("`@("!R
M971U<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]F:6QE7W)O;&5S)UT["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4F5P;&%C96UE;G14>7!E
M<R@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&EM<&QE;65N=&5D(&9I;&4@
M<F5P;&%C96UE;G0@='EP97,@:6X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E
M<&QA8V5M96YT5'EP97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D1TQ/0D%,
M4ULG7U!%05)?0V]M;6]N7W)E<&QA8V5M96YT7W1Y<&5S)UT["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4')O=FED951Y<&5S*"D*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@:6UP;&5M96YT960@9FEL92!R97!L86-E;65N
M="!T>7!E<R!I;@H@("`@("H*("`@("`J($!R971U<FX@87)R87D*("`@("`J
M($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')O=FED951Y<&5S
M*"D*("`@('L*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T-O;6UO
M;E]P<F]V:61E7W1Y<&5S)UT["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9V5T4V-R:7!T4&AA<V5S*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M:6UP;&5M96YT960@9FEL92!R97!L86-E;65N="!T>7!E<R!I;@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4V-R:7!T4&AA<V5S*"D*("`@('L*("`@("`@("!R
M971U<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]S8W)I<'1?<&AA<V5S)UT[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=F%L:61086-K86=E3F%M
M92@I"@H@("`@+RHJ"B`@("`@*B!497-T('=H971H97(@82!S=')I;F<@8V]N
M=&%I;G,@82!V86QI9"!P86-K86=E(&YA;64N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92!T:&4@<&%C:V%G92!N86UE('1O('1E<W0*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VP*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!V86QI9%!A8VMA9V5.86UE
M*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`H8F]O;"EP<F5G7VUA=&-H
M*%!%05)?0T]-34].7U!!0TM!1T5?3D%-15]04D5'+"`D;F%M92D["B`@("!]
M"@H*("`@("\O('U]?0H@("`@+R\@>WM[('9A;&ED4&%C:V%G959E<G-I;VXH
M*0H*("`@("\J*@H@("`@("H@5&5S="!W:&5T:&5R(&$@<W1R:6YG(&-O;G1A
M:6YS(&$@=F%L:60@<&%C:V%G92!V97)S:6]N+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'9E<B!T:&4@<&%C:V%G92!V97)S:6]N('1O('1E<W0*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!V86QI9%!A8VMA9V56
M97)S:6]N*"1V97(I"B`@("!["B`@("`@("`@<F5T=7)N("AB;V]L*7!R96=?
M;6%T8V@H4$5!4E]#3TU-3TY?4$%#2T%'15]615)324].7U!214<L("1V97(I
M.PH@("`@?0H*"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9&]W;FQO861(='1P
M*"D*"B`@("`O*BH*("`@("`J($1O=VYL;V%D(&$@9FEL92!T:')O=6=H($A4
M5%`N("!#;VYS:61E<G,@<W5G9V5S=&5D(&9I;&4@;F%M92!I;@H@("`@("H@
M0V]N=&5N="UD:7-P;W-I=&EO;CH@:&5A9&5R(&%N9"!C86X@<G5N(&$@8V%L
M;&)A8VL@9G5N8W1I;VX@9F]R"B`@("`@*B!D:69F97)E;G0@979E;G1S+B`@
M5&AE(&-A;&QB86-K('=I;&P@8F4@8V%L;&5D('=I=&@@='=O"B`@("`@*B!P
M87)A;65T97)S.B!T:&4@8V%L;&)A8VL@='EP92P@86YD('!A<F%M971E<G,N
M("!4:&4@:6UP;&5M96YT960*("`@("`J(&-A;&QB86-K('1Y<&5S(&%R93H*
M("`@("`J"B`@("`@*B`@)W-E='5P)R`@("`@("!C86QL960@870@=&AE('9E
M<GD@8F5G:6YN:6YG+"!P87)A;65T97(@:7,@82!522!O8FIE8W0*("`@("`J
M("`@("`@("`@("`@("`@('1H870@<VAO=6QD(&)E('5S960@9F]R(&%L;"!O
M=71P=70*("`@("`J("`G;65S<V%G92<@("`@('1H92!P87)A;65T97(@:7,@
M82!S=')I;F<@=VET:"!A;B!I;F9O<FUA=&EO;F%L(&UE<W-A9V4*("`@("`J
M("`G<V%V96%S)R`@("`@(&UA>2!B92!U<V5D('1O('-A=F4@=VET:"!A(&1I
M9F9E<F5N="!F:6QE(&YA;64L('1H90H@("`@("H@("`@("`@("`@("`@("`@
M<&%R86UE=&5R(&ES('1H92!F:6QE;F%M92!T:&%T(&ES(&%B;W5T('1O(&)E
M('5S960N"B`@("`@*B`@("`@("`@("`@("`@("!)9B!A("=S879E87,G(&-A
M;&QB86-K(')E='5R;G,@82!N;VXM96UP='D@<W1R:6YG+`H@("`@("H@("`@
M("`@("`@("`@("`@=&AA="!F:6QE(&YA;64@=VEL;"!B92!U<V5D(&%S('1H
M92!F:6QE;F%M92!I;G-T96%D+@H@("`@("H@("`@("`@("`@("`@("`@3F]T
M92!T:&%T("1S879E7V1I<B!W:6QL(&YO="!B92!A9F9E8W1E9"!B>2!T:&ES
M+"!O;FQY"B`@("`@*B`@("`@("`@("`@("`@("!T:&4@8F%S96YA;64@;V8@
M=&AE(&9I;&4N"B`@("`@*B`@)W-T87)T)R`@("`@("!D;W=N;&]A9"!I<R!S
M=&%R=&EN9RP@<&%R86UE=&5R(&ES(&YU;6)E<B!O9B!B>71E<PH@("`@("H@
M("`@("`@("`@("`@("`@=&AA="!A<F4@97AP96-T960L(&]R("TQ(&EF('5N
M:VYO=VX*("`@("`J("`G8GET97-R96%D)R`@('!A<F%M971E<B!I<R!T:&4@
M;G5M8F5R(&]F(&)Y=&5S(')E860@<V\@9F%R"B`@("`@*B`@)V1O;F4G("`@
M("`@("!D;W=N;&]A9"!I<R!C;VUP;&5T92P@<&%R86UE=&5R(&ES('1H92!T
M;W1A;"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@(&]F(&)Y=&5S(')E
M860*("`@("`J("`G8V]N;F9A:6QE9"<@(&EF('1H92!40U`@8V]N;F5C=&EO
M;B!F86EL<RP@=&AI<R!C86QL8F%C:R!I<R!C86QL960*("`@("`J("`@("`@
M("`@("`@("`@('=I=&@@87)R87DH:&]S="QP;W)T+&5R<FYO+&5R<FUS9RD*
M("`@("`J("`G=W)I=&5F86EL960G(&EF('=R:71I;F<@=&\@9&ES:R!F86EL
M<RP@=&AI<R!C86QL8F%C:R!I<R!C86QL960*("`@("`J("`@("`@("`@("`@
M("`@('=I=&@@87)R87DH9&5S=&9I;&4L97)R;7-G*0H@("`@("H*("`@("`J
M($EF(&%N($A45%`@<')O>'D@:&%S(&)E96X@8V]N9FEG=7)E9"`H:'1T<%]P
M<F]X>2!014%27T-O;F9I9PH@("`@("H@<V5T=&EN9RDL('1H92!P<F]X>2!W
M:6QL(&)E('5S960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5R
M;"`@("`@("!T:&4@55),('1O(&1O=VYL;V%D"B`@("`@*B!`<&%R86T@;V)J
M96-T("`D=6D@("`@("`@(%!%05)?1G)O;G1E;F1?*B!I;G-T86YC90H@("`@
M("H@0'!A<F%M(&]B:F5C="`@)&-O;F9I9R`@("!014%27T-O;F9I9R!I;G-T
M86YC90H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-A=F5?9&ER("`H;W!T:6]N
M86PI(&1I<F5C=&]R>2!T;R!S879E(&9I;&4@:6X*("`@("`J($!P87)A;2!M
M:7AE9"`@("1C86QL8F%C:R`@*&]P=&EO;F%L*2!F=6YC=&EO;B]M971H;V0@
M=&\@8V%L;"!F;W(@<W1A='5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('5P9&%T97,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M4F5T=7)N<R!T:&4@9G5L;"!P871H(&]F('1H92!D;W=N;&]A9&5D(&9I;&4@
M;W(@82!014%2"B`@("`@*B`@("`@("`@("`@("`@("`@97)R;W(@;VX@9F%I
M;'5R92X@($EF('1H92!E<G)O<B!I<R!C875S960@8GD*("`@("`J("`@("`@
M("`@("`@("`@("!S;V-K970M<F5L871E9"!E<G)O<G,L('1H92!E<G)O<B!O
M8FIE8W0@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@(&AA=F4@=&AE(&9S
M;V-K;W!E;B!E<G)O<B!C;V1E(&%V86EL86)L92!T:')O=6=H"B`@("`@*B`@
M("`@("`@("`@("`@("`@9V5T0V]D92@I+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O=VYL;V%D2'1T<"@D
M=7)L+"`F)'5I+"`D<V%V95]D:7(@/2`G+B<L("1C86QL8F%C:R`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"1C86QL8F%C:RD@>PH@("`@("`@("`@("!C
M86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=S971U<"<L(&%R<F%Y*"8D=6DI
M*3L*("`@("`@("!]"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R%>:'1T<#HO
M+RA;7B\Z/R-=*BDH.BA<9"LI*3\H+RXJ*2$G+"`D=7)L+"`D;6%T8VAE<RDI
M('L*("`@("`@("`@("`@;&ES="@L)&AO<W0L+"1P;W)T+"1P871H*2`]("1M
M871C:&5S.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'1H:7,I*2![
M"B`@("`@("`@("`@("1C;VYF:6<@/2`F)'1H:7,M/F-O;F9I9SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG
M.CIS:6YG;&5T;VXH*3L*("`@("`@("!]"B`@("`@("`@)'!R;WAY7VAO<W0@
M/2`D<')O>'E?<&]R="`]("1P<F]X>5]U<V5R(#T@)'!R;WAY7W!A<W,@/2`G
M)SL*("`@("`@("!I9B`H)'!R;WAY(#T@<&%R<V5?=7)L*"1C;VYF:6<M/F=E
M="@G:'1T<%]P<F]X>2<I*2D@>PH@("`@("`@("`@("`D<')O>'E?:&]S="`]
M($`D<')O>'E;)VAO<W0G73L*("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2!`
M)'!R;WAY6R=P;W)T)UT["B`@("`@("`@("`@("1P<F]X>5]U<V5R(#T@0"1P
M<F]X>5LG=7-E<B==.PH@("`@("`@("`@("`D<')O>'E?<&%S<R`]($`D<')O
M>'E;)W!A<W,G73L*"B`@("`@("`@("`@(&EF("@D<')O>'E?<&]R="`]/2`G
M)RD@>PH@("`@("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2`X,#@P.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@D8V%L;&)A8VLI('L*("`@("`@
M("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)VUE<W-A9V4G
M+"`B57-I;F<@2%144"!P<F]X>2`D:&]S=#HD<&]R="(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<&]R="DI('L*("`@
M("`@("`@("`@)'!O<G0@/2`X,#L*("`@("`@("!]"B`@("`@("`@:68@*"1P
M<F]X>5]H;W-T("$]("<G*2!["B`@("`@("`@("`@("1F<"`]($!F<V]C:V]P
M96XH)'!R;WAY7VAO<W0L("1P<F]X>5]P;W)T+"`D97)R;F\L("1E<G)S='(I
M.PH@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@("`@("`@("`@:68@
M*"1C86QL8F%C:RD@>PH@("`@("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F
M=6YC*"1C86QL8F%C:RP@)V-O;FYF86EL960G+"!A<G)A>2@D<')O>'E?:&]S
M="P@)'!R;WAY7W!O<G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)N;RP@
M)&5R<G-T<BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O;FYE8W1I;VX@=&\@8"1P<F]X
M>5]H;W-T.B1P<F]X>5]P;W)T)R!F86EL960Z("1E<G)S='(B+"`D97)R;F\I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97%U97-T(#T@(D=%5"`D
M=7)L($A45%`O,2XP7')<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&9P(#T@0&9S;V-K;W!E;B@D:&]S="P@)'!O<G0L("1E<G)N;RP@)&5R
M<G-T<BD["B`@("`@("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&-A;&QB86-K*2!["B`@("`@("`@("`@("`@("`@("`@8V%L;%]U
M<V5R7V9U;F,H)&-A;&QB86-K+"`G8V]N;F9A:6QE9"<L(&%R<F%Y*"1H;W-T
M+"`D<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<FYO+"`D97)R<W1R
M*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@B0V]N;F5C=&EO;B!T;R!@)&AO<W0Z)'!O<G0G
M(&9A:6QE9#H@)&5R<G-T<B(L("1E<G)N;RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)')E<75E<W0@/2`B1T54("1P871H($A45%`O,2XP7')<;B([
M"B`@("`@("`@?0H@("`@("`@("1R97%U97-T("X](")(;W-T.B`D:&]S=#HD
M<&]R=%QR7&XB+@H@("`@("`@("`@("`B57-E<BU!9V5N=#H@4$A0+R(N4$A0
M7U9%4E-)3TXN(EQR7&XB.PH@("`@("`@(&EF("@D<')O>'E?:&]S="`A/2`G
M)R`F)B`D<')O>'E?=7-E<B`A/2`G)RD@>PH@("`@("`@("`@("`D<F5Q=65S
M="`N/2`G4')O>'DM075T:&]R:7IA=&EO;CH@0F%S:6,@)R`N"B`@("`@("`@
M("`@("`@("!B87-E-C1?96YC;V1E*"1P<F]X>5]U<V5R("X@)SHG("X@)'!R
M;WAY7W!A<W,I("X@(EQR7&XB.PH@("`@("`@('T*("`@("`@("`D<F5Q=65S
M="`N/2`B7')<;B(["B`@("`@("`@9G=R:71E*"1F<"P@)')E<75E<W0I.PH@
M("`@("`@("1H96%D97)S(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H=')I
M;2@D;&EN92`](&9G971S*"1F<"P@,3`R-"DI*2!["B`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O7BA;7CI=*RDZ7',K*"XJ*5QS*B0O)RP@)&QI;F4L
M("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)&AE861E<G-;<W1R=&]L
M;W=E<B@D;6%T8VAE<ULQ72E=(#T@=')I;2@D;6%T8VAE<ULR72D["B`@("`@
M("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"=\7DA45%`O,2Y;,#%=("A;
M,"TY77LS?2D@?"<L("1L:6YE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@
M("`@(&EF("@D;6%T8VAE<ULQ72`A/2`R,#`I('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92!H='1P.B\O)&AO
M<W0Z)'!O<G0D<&%T:"!N;W0@=F%L:60@*')E8V5I=F5D.B`D;&EN92DB*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H:7-S970H)&AE861E<G-;)V-O;G1E;G0M9&ES<&]S:71I;VXG
M72D@)B8*("`@("`@("`@("`@<')E9U]M871C:"@G+UQS9FEL96YA;64]7"(H
M6UX[72I<4RE<(EQS*B@[?"0I+R<L("1H96%D97)S6R=C;VYT96YT+61I<W!O
M<VET:6]N)UTL("1M871C:&5S*2D@>PH@("`@("`@("`@("`D<V%V95]A<R`]
M(&)A<V5N86UE*"1M871C:&5S6S%=*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<V%V95]A<R`](&)A<V5N86UE*"1U<FPI.PH@("`@("`@('T*
M("`@("`@("!I9B`H)&-A;&QB86-K*2!["B`@("`@("`@("`@("1T;7`@/2!C
M86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=S879E87,G+"`D<V%V95]A<RD[
M"B`@("`@("`@("`@(&EF("@D=&UP*2!["B`@("`@("`@("`@("`@("`D<V%V
M95]A<R`]("1T;7`["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M)&1E<W1?9FEL92`]("1S879E7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@
M+B`D<V%V95]A<SL*("`@("`@("!I9B`H(21W<"`]($!F;W!E;B@D9&5S=%]F
M:6QE+"`G=V(G*2D@>PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@
M("`@("`@:68@*"1C86QL8F%C:RD@>PH@("`@("`@("`@("`@("`@8V%L;%]U
M<V5R7V9U;F,H)&-A;&QB86-K+"`G=W)I=&5F86EL960G+"!A<G)A>2@D9&5S
M=%]F:6QE+"`D<&AP7V5R<F]R;7-G*2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(F-O=6QD(&YO="!O<&5N
M("1D97-T7V9I;&4@9F]R('=R:71I;F<B*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1H96%D97)S6R=C;VYT96YT+6QE;F=T:"==*2D@>PH@("`@
M("`@("`@("`D;&5N9W1H(#T@)&AE861E<G-;)V-O;G1E;G0M;&5N9W1H)UT[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&QE;F=T:"`]("TQ.PH@
M("`@("`@('T*("`@("`@("`D8GET97,@/2`P.PH@("`@("`@(&EF("@D8V%L
M;&)A8VLI('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K
M+"`G<W1A<G0G+"!A<G)A>2AB87-E;F%M92@D9&5S=%]F:6QE*2P@)&QE;F=T
M:"DI.PH@("`@("`@('T*("`@("`@("!W:&EL92`H)&1A=&$@/2!`9G)E860H
M)&9P+"`Q,#(T*2D@>PH@("`@("`@("`@("`D8GET97,@*ST@<W1R;&5N*"1D
M871A*3L*("`@("`@("`@("`@:68@*"1C86QL8F%C:RD@>PH@("`@("`@("`@
M("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`G8GET97-R96%D)RP@
M)&)Y=&5S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(4!F=W)I
M=&4H)'=P+"`D9&%T82DI('L*("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PH@("`@("`@("`@("`@("`@:68@*"1C86QL8F%C:RD@>PH@("`@("`@("`@
M("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)W=R:71E9F%I
M;&5D)RP@87)R87DH)&1E<W1?9FEL92P@)'!H<%]E<G)O<FUS9RDI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(B1D97-T7V9I;&4Z('=R:71E(&9A:6QE9"`H)'!H<%]E<G)O
M<FUS9RDB*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!F8VQO
M<V4H)&9P*3L*("`@("`@("!F8VQO<V4H)'=P*3L*("`@("`@("!I9B`H)&-A
M;&QB86-K*2!["B`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C
M:RP@)V1O;F4G+"`D8GET97,I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&1E<W1?9FEL93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S;W)T
M4&MG1&5P<R@I"@H@("`@+RHJ"B`@("`@*B!3;W)T(&$@;&ES="!O9B!A<G)A
M>7,@;V8@87)R87DH9&]W;FQO861E9"!P86-K86=E9FEL96YA;64I(&)Y(&1E
M<&5N9&5N8WDN"B`@("`@*@H@("`@("H@270@86QS;R!R96UO=F5S(&1U<&QI
M8V%T92!D97!E;F1E;F-I97,*("`@("`J($!P87)A;2!A<G)A>0H@("`@("H@
M0'!A<F%M(&)O;VQE86X@4V]R="!P86-K86=E<R!I;B!R979E<G-E(&]R9&5R
M(&EF('1R=64*("`@("`J($!R971U<FX@87)R87D@87)R87D@;V8@87)R87DH
M<&%C:V%G969I;&5N86UE+"!P86-K86=E+GAM;"!C;VYT96YT<RD*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V]R=%!K9T1E<',H)B1P86-K86=E<RP@)'5N:6YS
M=&%L;"`](&9A;'-E*0H@("`@>PH@("`@("`@("1R970@/2!A<G)A>2@I.PH@
M("`@("`@(&EF("@D=6YI;G-T86QL*2!["B`@("`@("`@("`@(&9O<F5A8V@H
M)'!A8VMA9V5S(&%S("1P86-K86=E:6YF;RD@>PH@("`@("`@("`@("`@("`@
M)')E=%M=(#T@87)R87DH)VEN9F\G(#T^("1P86-K86=E:6YF;RD["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F;W)E86-H
M*"1P86-K86=E<R!A<R`D<&%C:V%G969I;&4I('L*("`@("`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)'!A8VMA9V5F:6QE*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1R971;72`](&%R<F%Y*"=F:6QE)R`]/B`D<&%C:V%G969I;&4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEN9F\G(#T^
M("1A(#T@)'1H:7,M/FEN9F]&<F]M06YY*"1P86-K86=E9FEL92DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!K9R<@/3X@)&%;)W!A
M8VMA9V4G72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1R971;72`]("1P86-K86=E9FEL93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D8VAE8VMD
M=7!E<R`](&%R<F%Y*"D["B`@("`@("`@)&YE=W)E="`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"@D<F5T(&%S("1I(#T^("1P*2!["B`@("`@("`@("`@
M(&EF("@A:7-S970H)&-H96-K9'5P97-;)'!;)VEN9F\G75LG<&%C:V%G92==
M72DI('L*("`@("`@("`@("`@("`@("1C:&5C:V1U<&5S6R1P6R=I;F9O)UU;
M)W!A8VMA9V4G75U;72`]("1I.PH@("`@("`@("`@("`@("`@)&YE=W)E=%M=
M(#T@)'`["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E4V]R=%1R964@/2`D=&AI<RT^7V=E=%!K9T1E<%1R964H)&YE
M=W)E="D["@H@("`@("`@("1F=6YC(#T@)'5N:6YS=&%L;"`_("=?<V]R=%!K
M9T1E<'-2978G(#H@)U]S;W)T4&MG1&5P<R<["B`@("`@("`@=7-O<G0H)&YE
M=W)E="P@87)R87DH)B1T:&ES+"`D9G5N8RDI.PH@("`@("`@("1T:&ES+3Y?
M<&%C:V%G95-O<G14<F5E(#T@;G5L;#L*("`@("`@("`D<&%C:V%G97,@/2`D
M;F5W<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]S;W)T4&MG
M1&5P<R@I"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E('1W;R!P86-K86=E)W,@
M<&%C:V%G92YX;6PL(&%N9"!S;W)T"B`@("`@*B!S;R!T:&%T(&1E<&5N9&5N
M8VEE<R!A<F4@:6YS=&%L;&5D(&9I<G-T"B`@("`@*@H@("`@("H@5&AI<R!I
M<R!A(&-R=61E(&-O;7!A<F4L(')E86P@9&5P96YD96YC>2!C:&5C:VEN9R!I
M<R!D;VYE(&]N(&EN<W1A;&PN"B`@("`@*B!4:&4@;VYL>2!P=7)P;W-E('1H
M:7,@<V5R=F5S(&ES('1O(&UA:V4@=&AE(&-O;6UA;F0M;&EN90H@("`@("H@
M;W)D97(M:6YD97!E;F1E;G0@*'EO=2!C86X@;&ES="!A(&1E<&5N9&5N="!P
M86-K86=E(&9I<G-T+"!A;F0*("`@("`J(&EN<W1A;&QA=&EO;B!O8V-U<G,@
M:6X@=&AE(&]R9&5R(')E<75I<F5D*0H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S;W)T4&MG1&5P<R@D<#$L("1P,BD*
M("`@('L*("`@("`@("`D<#%N86UE(#T@)'`Q6R=I;F9O)UU;)W!A8VMA9V4G
M73L*("`@("`@("`D<#)N86UE(#T@)'`R6R=I;F9O)UU;)W!A8VMA9V4G73L*
M("`@("`@("`D<#%D97!S(#T@)'1H:7,M/E]G9710:V=$97!S*"1P,2D["B`@
M("`@("`@)'`R9&5P<R`]("1T:&ES+3Y?9V5T4&MG1&5P<R@D<#(I.PH@("`@
M("`@(&EF("@A8V]U;G0H)'`Q9&5P<RD@)B8@(6-O=6YT*"1P,F1E<',I*2![
M"B`@("`@("`@("`@(')E='5R;B`P.R`O+R!O<F1E<B!M86ME<R!N;R!D:69F
M97)E;F-E"B`@("`@("`@?0H@("`@("`@(&EF("@A8V]U;G0H)'`Q9&5P<RDI
M('L*("`@("`@("`@("`@<F5T=7)N("TQ.R`O+R!P86-K86=E(#(@:&%S(&1E
M<&5N9&5N8VEE<RP@<&%C:V%G92`Q(&1O97-N)W0*("`@("`@("!]"B`@("`@
M("`@:68@*"%C;W5N="@D<#)D97!S*2D@>PH@("`@("`@("`@("!R971U<FX@
M,3L@+R\@<&%C:V%G92`Q(&AA<R!D97!E;F1E;F-I97,L('!A8VMA9V4@,B!D
M;V5S;B=T"B`@("`@("`@?0H@("`@("`@("\O(&)O=&@@:&%V92!D97!E;F1E
M;F-I97,*("`@("`@("!I9B`H:6Y?87)R87DH)'`Q;F%M92P@)'`R9&5P<RDI
M('L*("`@("`@("`@("`@<F5T=7)N("TQ.R`O+R!P=70@<&%C:V%G92`Q(&9I
M<G-T.B!P86-K86=E(#(@9&5P96YD<R!O;B!P86-K86=E(#$*("`@("`@("!]
M"B`@("`@("`@:68@*&EN7V%R<F%Y*"1P,FYA;64L("1P,61E<',I*2!["B`@
M("`@("`@("`@(')E='5R;B`Q.R`O+R!P=70@<&%C:V%G92`R(&9I<G-T.B!P
M86-K86=E(#$@9&5P96YD<R!O;B!P86-K86=E(#(*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3Y?<F5M;W9E9$1E<&5N9&5N8WDH)'`Q;F%M92P@)'`R
M;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N("TQ.R`O+R!P=70@<&%C:V%G
M92`Q(&9I<G-T.B!P86-K86=E(#(@9&5P96YD<R!O;B!P86-K86=E<R!T:&%T
M(&1E<&5N9"!O;B!P86-K86=E(#$*("`@("`@("!]"B`@("`@("`@:68@*"1T
M:&ES+3Y?<F5M;W9E9$1E<&5N9&5N8WDH)'`R;F%M92P@)'`Q;F%M92DI('L*
M("`@("`@("`@("`@<F5T=7)N(#$[("\O('!U="!P86-K86=E(#(@9FER<W0Z
M('!A8VMA9V4@,2!D97!E;F1S(&]N('!A8VMA9V5S('1H870@9&5P96YD(&]N
M('!A8VMA9V4@,@H@("`@("`@('T*("`@("`@("`O+R!D;V5S;B=T(')E86QL
M>2!M871T97(@:68@;F5I=&AE<B!D97!E;F1S(&]N('1H92!O=&AE<@H@("`@
M("`@(')E='5R;B`P.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]S
M;W)T4&MG1&5P<U)E=B@I"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E('1W;R!P
M86-K86=E)W,@<&%C:V%G92YX;6PL(&%N9"!S;W)T"B`@("`@*B!S;R!T:&%T
M(&1E<&5N9&5N8VEE<R!A<F4@=6YI;G-T86QL960@;&%S=`H@("`@("H*("`@
M("`J(%1H:7,@:7,@82!C<G5D92!C;VUP87)E+"!R96%L(&1E<&5N9&5N8WD@
M8VAE8VMI;F<@:7,@9&]N92!O;B!U;FEN<W1A;&PN"B`@("`@*B!4:&4@;VYL
M>2!P=7)P;W-E('1H:7,@<V5R=F5S(&ES('1O(&UA:V4@=&AE(&-O;6UA;F0M
M;&EN90H@("`@("H@;W)D97(M:6YD97!E;F1E;G0@*'EO=2!C86X@;&ES="!A
M(&1E<&5N9&5N8WD@9FER<W0L(&%N9`H@("`@("H@=6YI;G-T86QL871I;VX@
M;V-C=7)S(&EN('1H92!O<F1E<B!R97%U:7)E9"D*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<V]R=%!K9T1E<'-2978H
M)'`Q+"`D<#(I"B`@("!["B`@("`@("`@)'`Q;F%M92`]("1P,5LG:6YF;R==
M6R=P86-K86=E)UT["B`@("`@("`@)'`R;F%M92`]("1P,ELG:6YF;R==6R=P
M86-K86=E)UT["B`@("`@("`@)'`Q9&5P<R`]("1T:&ES+3Y?9V5T4F5V4&MG
M1&5P<R@D<#$I.PH@("`@("`@("1P,F1E<',@/2`D=&AI<RT^7V=E=%)E=E!K
M9T1E<',H)'`R*3L*("`@("`@("!I9B`H(6-O=6YT*"1P,61E<',I("8F("%C
M;W5N="@D<#)D97!S*2D@>PH@("`@("`@("`@("!R971U<FX@,#L@+R\@;W)D
M97(@;6%K97,@;F\@9&EF9F5R96YC90H@("`@("`@('T*("`@("`@("!I9B`H
M(6-O=6YT*"1P,61E<',I*2!["B`@("`@("`@("`@(')E='5R;B`Q.R`O+R!P
M86-K86=E(#(@:&%S(&1E<&5N9&5N8VEE<RP@<&%C:V%G92`Q(&1O97-N)W0*
M("`@("`@("!]"B`@("`@("`@:68@*"%C;W5N="@D<#)D97!S*2D@>PH@("`@
M("`@("`@("!R971U<FX@+3$[("\O('!A8VMA9V4@,B!H87,@9&5P96YD96YC
M:65S+"!P86-K86=E(#$@9&]E<VXG=`H@("`@("`@('T*("`@("`@("`O+R!B
M;W1H(&AA=F4@9&5P96YD96YC:65S"B`@("`@("`@:68@*&EN7V%R<F%Y*"1P
M,6YA;64L("1P,F1E<',I*2!["B`@("`@("`@("`@(')E='5R;B`Q.R`O+R!P
M=70@<&%C:V%G92`Q(&QA<W0*("`@("`@("!]"B`@("`@("`@:68@*&EN7V%R
M<F%Y*"1P,FYA;64L("1P,61E<',I*2!["B`@("`@("`@("`@(')E='5R;B`M
M,3L@+R\@<'5T('!A8VMA9V4@,B!L87-T"B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^7W)E;6]V961$97!E;F1E;F-Y*"1P,6YA;64L("1P,FYA;64I
M*2!["B`@("`@("`@("`@(')E='5R;B`Q.R`O+R!P=70@<&%C:V%G92`Q(&QA
M<W0Z('!A8VMA9V4@,B!D97!E;F1S(&]N('!A8VMA9V5S('1H870@9&5P96YD
M(&]N('!A8VMA9V4@,0H@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]R
M96UO=F5D1&5P96YD96YC>2@D<#)N86UE+"`D<#%N86UE*2D@>PH@("`@("`@
M("`@("!R971U<FX@+3$[("\O('!U="!P86-K86=E(#(@;&%S=#H@<&%C:V%G
M92`Q(&1E<&5N9',@;VX@<&%C:V%G97,@=&AA="!D97!E;F0@;VX@<&%C:V%G
M92`R"B`@("`@("`@?0H@("`@("`@("\O(&1O97-N)W0@<F5A;&QY(&UA='1E
M<B!I9B!N96ET:&5R(&1E<&5N9',@;VX@=&AE(&]T:&5R"B`@("`@("`@<F5T
M=7)N(#`["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7V=E=%!K9T1E
M<',H*0H*("`@("\J*@H@("`@("H@9V5T(&%N(&%R<F%Y(&]F('!A8VMA9V4@
M9&5P96YD96YC>2!N86UE<PH@("`@("H@0'!A<F%M(&%R<F%Y"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V=E=%!K9T1E<',H)'`I"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D<%LG:6YF;R==6R=R96QE87-E<R==*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]G97129790:V=$97!S*"1P*3L*("`@("`@("!]
M"B`@("`@("`@)')E;"`](&%R<F%Y7W-H:69T*"1P6R=I;F9O)UU;)W)E;&5A
M<V5S)UTI.PH@("`@("`@(&EF("@A:7-S970H)')E;%LG9&5P<R==*2D@>PH@
M("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@
M)')E="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"@D<F5L6R=D97!S)UT@
M87,@)&1E<"D@>PH@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==(#T]("=P
M:V<G*2!["B`@("`@("`@("`@("`@("`D<F5T6UT@/2`D9&5P6R=N86UE)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R970[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7V=E=%!K9T1E<',H*0H*
M("`@("\J*@H@("`@("H@9V5T(&%N(&%R<F%Y(')E<')E<V5N=&%T:6]N(&]F
M('1H92!P86-K86=E(&1E<&5N9&5N8WD@=')E90H@("`@("H@0')E='5R;B!A
M<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G9710:V=$97!4<F5E*"1P86-K86=E<RD*("`@('L*("`@("`@("`D
M=')E92`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5S(&%S
M("1P*2!["B`@("`@("`@("`@("1P86-K86=E(#T@)'!;)VEN9F\G75LG<&%C
M:V%G92==.PH@("`@("`@("`@("`D9&5P<R`]("1T:&ES+3Y?9V5T4&MG1&5P
M<R@D<"D["B`@("`@("`@("`@("1T<F5E6R1P86-K86=E72`]("1D97!S.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)'1R964["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@7W)E;6]V961$97!E;F1E;F-Y*"1P,2P@)'`R*0H*
M("`@("\J*@H@("`@("H@9V5T(&%N(&%R<F%Y(&]F('!A8VMA9V4@9&5P96YD
M96YC>2!N86UE<R!F;W(@=6YI;G-T86QL"B`@("`@*B!`<&%R86T@<W1R:6YG
M('!A8VMA9V4@,2!N86UE"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@
M,B!N86UE"B`@("`@*B!`<F5T=7)N(&)O;VP*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5M;W9E9$1E<&5N9&5N8WDH
M)'`Q+"`D<#(I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%C
M:V%G95-O<G14<F5E6R1P,ETI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("`@("`@:68@*"%I;E]A<G)A>2@D<#$L("1T:&ES
M+3Y?<&%C:V%G95-O<G14<F5E6R1P,ETI*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?<&%C:V%G95-O<G14<F5E6R1P,ET@87,@)'!O=&5N=&EA
M;"D@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<F5M;W9E9$1E<&5N
M9&5N8WDH)'`Q+"`D<&]T96YT:6%L*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7V=E
M=%)E=E!K9T1E<',H*0H*("`@("\J*@H@("`@("H@9V5T(&%N(&%R<F%Y(&]F
M('!A8VMA9V4@9&5P96YD96YC>2!N86UE<R!F;W(@=6YI;G-T86QL"B`@("`@
M*B!`<&%R86T@87)R87D*("`@("`J($!R971U<FX@87)R87D*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T4F5V4&MG
M1&5P<R@D<"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1P6R=I;F9O)UU;
M)W)E;&5A<V5?9&5P<R==*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("!]"B`@("`@("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"@D<%LG:6YF;R==6R=R96QE87-E7V1E<',G72!A<R`D9&5P*2![
M"B`@("`@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@/3T@)W!K9R<I('L*("`@
M("`@("`@("`@("`@("1R971;72`]("1D97!;)VYA;64G73L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@
M("`O+R!]?7T*?0H*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]014%2+T1O=VYL;V%D97(N<&AP````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U-3$R,@`Q,#0Q-S,V,S`P-@`P,C`W
M,#,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R<SH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!-87)T:6X@
M2F%N<V5N(#QM:D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO
M+R`D260Z($1O=VYL;V%D97(N<&AP+'8@,2XQ,R`R,#`T+S`Q+S`X(#$W.C,S
M.C$R('-N:7!E<B!%>'`@)`H*<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP
M:'`G.PIR97%U:7)E7V]N8V4@)U!%05(O4F5G:7-T<GDN<&AP)SL*<F5Q=6ER
M95]O;F-E("=014%2+T1E<&5N9&5N8WDN<&AP)SL*<F5Q=6ER95]O;F-E("=0
M14%2+U)E;6]T92YP:'`G.PIR97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PH*
M+RHJ"B`J($%D;6EN:7-T<F%T:6]N(&-L87-S('5S960@=&\@9&]W;FQO860@
M4$5!4B!P86-K86=E<R!A;F0@;6%I;G1A:6X@=&AE"B`J(&EN<W1A;&QE9"!P
M86-K86=E(&1A=&%B87-E+@H@*@H@*B!`<VEN8V4@4$5!4B`Q+C0*("H@0&%U
M=&AO<B!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^"B`J+PIC;&%S<R!0
M14%27T1O=VYL;V%D97(@97AT96YD<R!014%27T-O;6UO;@I["B`@("`O*BH*
M("`@("`J($!V87(@4$5!4E]#;VYF:6<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]C;VYF:6<["@H@("`@+RHJ"B`@("`@*B!`
M=F%R(%!%05)?4F5G:7-T<GD*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)%]R96=I<W1R>3L*"B`@("`O*BH*("`@("`J($!V87(@
M4$5!4E]296UO=&4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]R96UO=&4["@H@("`@+RHJ"B`@("`@*B!0<F5F97)R960@26YS
M=&%L;&%T:6]N(%-T871E("AS;F%P<VAO="P@9&5V96PL(&%L<&AA+"!B971A
M+"!S=&%B;&4I"B`@("`@*B!`=F%R('-T<FEN9WQN=6QL"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<')E9F5R<F5D4W1A=&4[
M"@H@("`@+RHJ"B`@("`@*B!/<'1I;VYS(&9R;VT@8V]M;6%N9"UL:6YE('!A
M<W-E9"!T;R!);G-T86QL+@H@("`@("H@"B`@("`@*B!296-O9VYI>F5D(&]P
M=&EO;G,Z/&)R("\^"B`@("`@*B`@+2!O;FQY<F5Q9&5P<R`@(#H@:6YS=&%L
M;"!A;&P@<F5Q=6ER960@9&5P96YD96YC:65S(&%S('=E;&P*("`@("`J("`M
M(&%L;&1E<',@("`@("`@.B!I;G-T86QL(&%L;"!D97!E;F1E;F-I97,L(&EN
M8VQU9&EN9R!O<'1I;VYA;`H@("`@("H@("T@:6YS=&%L;')O;W0@("`Z(&)A
M<V4@<F5L871I=F4@<&%T:"!T;R!I;G-T86QL(&9I;&5S(&EN"B`@("`@*B`@
M+2!F;W)C92`@("`@("`@(#H@9F]R8V4@82!D;W=N;&]A9"!E=F5N(&EF('=A
M<FYI;F=S('=O=6QD('!R979E;G0@:70*("`@("`J($!S964@4$5!4E]#;VUM
M86YD7TEN<W1A;&P*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O<'1I;VYS.PH*("`@("\J*@H@
M("`@("H@1&]W;FQO861E9"!086-K86=E<R!A9G1E<B!A(&-A;&P@=&\@9&]W
M;FQO860H*2X*("`@("`J(`H@("`@("H@1F]R;6%T(&]F(&5A8V@@96YT<GDZ
M"B`@("`@*@H@("`@("H@/&-O9&4^"B`@("`@*B!A<G)A>2@G<&MG)R`]/B`G
M<&%C:V%G95]N86UE)RP@)V9I;&4G(#T^("<O<&%T:"]T;R]L;V-A;"]F:6QE
M)RP*("`@("`J("`@("=I;F9O)R`]/B!A<G)A>2@I("\O('!A<G-E9"!P86-K
M86=E+GAM;`H@("`@("H@*3L*("`@("`J(#PO8V]D93X*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]D;W=N;&]A9&5D4&%C:V%G97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@4&%C:V%G97,@<VQA=&5D(&9O<B!D;W=N;&]A9"X*("`@("`J(`H@("`@
M("H@5&AI<R!I<R!U<V5D('1O('!R979E;G0@9&]W;FQO861I;F<@82!P86-K
M86=E(&UO<F4@=&AA;B!O;F-E('-H;W5L9"!I="!B92!A(&1E<&5N9&5N8WD*
M("`@("`J(&9O<B!T=V\@<&%C:V%G97,@=&\@8F4@:6YS=&%L;&5D+@H@("`@
M("H@1F]R;6%T(&]F(&5A8V@@96YT<GDZ"B`@("`@*@H@("`@("H@/'!R93X*
M("`@("`J(&%R<F%Y*"=P86-K86=E7VYA;64Q)R`]/B!P87)S960@<&%C:V%G
M92YX;6PL("=P86-K86=E7VYA;64R)R`]/B!P87)S960@<&%C:V%G92YX;6PL
M"B`@("`@*B`I.PH@("`@("H@/"]P<F4^"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=&]$;W=N
M;&]A9"`](&%R<F%Y*"D["B`@("`*("`@("\J*@H@("`@("H@07)R87D@;V8@
M979E<GD@<&%C:V%G92!I;G-T86QL960L('=I=&@@;F%M97,@;&]W97(M8V%S
M960N"B`@("`@*B`*("`@("`J($9O<FUA=#H*("`@("`J(#QC;V1E/@H@("`@
M("H@87)R87DH)W!A8VMA9V4Q)R`]/B`P+"`G<&%C:V%G93(G(#T^(#$L("D[
M"B`@("`@*B`\+V-O9&4^"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7VEN<W1A;&QE9"`](&%R<F%Y*"D["B`@("`*("`@("\J*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V5R<F]R4W1A8VL@/2!A<G)A>2@I.PH*("`@("\O('M[>R!0
M14%27T1O=VYL;V%D97(H*0H@("`@"B`@("!F=6YC=&EO;B!014%27T1O=VYL
M;V%D97(H)B1U:2P@)&]P=&EO;G,L("8D8V]N9FEG*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?;W!T:6]N<R`]("1O<'1I;VYS.PH@("`@("`@("1T:&ES+3Y?
M8V]N9FEG(#T@)B1C;VYF:6<["B`@("`@("`@)'1H:7,M/E]P<F5F97)R9613
M=&%T92`]("1T:&ES+3Y?8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I
M.PH@("`@("`@("1T:&ES+3YU:2`]("8D=6D["B`@("`@("`@:68@*"$D=&AI
M<RT^7W!R969E<G)E9%-T871E*2!["B`@("`@("`@("`@("\O(&1O;B=T(&EN
M861V97)T86YT;'D@=7-E(&$@;F]N+7-E="!P<F5F97)R961?<W1A=&4*("`@
M("`@("`@("`@)'1H:7,M/E]P<F5F97)R9613=&%T92`](&YU;&P["B`@("`@
M("`@?0H*("`@("`@("`D<&AP7V1I<B`]("1T:&ES+3Y?8V]N9FEG+3YG970H
M)W!H<%]D:7(G*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=I;G-T86QL<F]O="==*2D@>PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1T
M:&ES+3Y?;W!T:6]N<ULG:6YS=&%L;')O;W0G72P@+3$I(#T]($1)4D5#5$]2
M65]315!!4D%43U(I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N
M<ULG:6YS=&%L;')O;W0G72`]('-U8G-T<B@D=&AI<RT^7V]P=&EO;G-;)VEN
M<W1A;&QR;V]T)UTL(#`L("TQ*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<&AP7V1I<B`]("1T:&ES+3Y?<')E<&5N9%!A=&@H)'!H<%]D:7(L("1T
M:&ES+3Y?;W!T:6]N<ULG:6YS=&%L;')O;W0G72D["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F;F5W(%!%05)?4F5G:7-T<GDH)'!H
M<%]D:7(I.PH@("`@("`@("1T:&ES+3Y?<F5M;W1E(#T@)FYE=R!014%27U)E
M;6]T92@D8V]N9FEG*3L*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG86QL9&5P<R==*2!\?"!I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V]N
M;'ER97%D97!S)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6YS=&%L;&5D
M(#T@)'1H:7,M/E]R96=I<W1R>2T^;&ES=%!A8VMA9V5S*"D["B`@("`@("`@
M("`@(&%R<F%Y7W=A;&LH)'1H:7,M/E]I;G-T86QL960L(&-R96%T95]F=6YC
M=&EO;B@G)B1V+"1K)RPG)'8@/2!S=')T;VQO=V5R*"1V*3LG*2D["B`@("`@
M("`@("`@("1T:&ES+3Y?:6YS=&%L;&5D(#T@87)R87E?9FQI<"@D=&AI<RT^
M7VEN<W1A;&QE9"D["B`@("`@("`@?0H@("`@("`@('!A<F5N=#HZ4$5!4E]#
M;VUM;VXH*3L*("`@('T*("`@(`H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N
M9FEG4V5T*"D*("`@(&9U;F-T:6]N(&-O;F9I9U-E="@D:V5Y+"`D=F%L=64L
M("1L87EE<B`]("=U<V5R)RD*("`@('L*("`@("`@("`D=&AI<RT^7V-O;F9I
M9RT^<V5T*"1K97DL("1V86QU92P@)&QA>65R*3L*("`@("`@("`D=&AI<RT^
M7W!R969E<G)E9%-T871E(#T@)'1H:7,M/E]C;VYF:6<M/F=E="@G<')E9F5R
M<F5D7W-T871E)RD["B`@("`@("`@:68@*"$D=&AI<RT^7W!R969E<G)E9%-T
M871E*2!["B`@("`@("`@("`@("\O(&1O;B=T(&EN861V97)T86YT;'D@=7-E
M(&$@;F]N+7-E="!P<F5F97)R961?<W1A=&4*("`@("`@("`@("`@)'1H:7,M
M/E]P<F5F97)R9613=&%T92`](&YU;&P["B`@("`@("`@?0H@("`@?0H@("`@
M"B`@("`O+R!]?7T*("`@("\O('M[>R!S971/<'1I;VYS*"D*("`@(&9U;F-T
M:6]N('-E=$]P=&EO;G,H)&]P=&EO;G,I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS(#T@)&]P=&EO;G,["B`@("!]"B`@("`*("`@("\O('U]?0H@
M("`@+R\@>WM[(%]D;W=N;&]A9$9I;&4H*0H@("`@+RHJ"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&9I;&5N86UE('1O(&1O=VYL;V%D"B`@("`@*B!`<&%R86T@
M<W1R:6YG('9E<G-I;VXO<W1A=&4*("`@("`J($!P87)A;2!S=')I;F<@;W)I
M9VEN86P@=F%L=64@<&%S<V5D('1O(&-O;6UA;F0M;&EN90H@("`@("H@0'!A
M<F%M('-T<FEN9WQN=6QL('!R969E<G)E9"!S=&%T92`H<VYA<'-H;W0O9&5V
M96PO86QP:&$O8F5T82]S=&%B;&4I"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@1&5F875L=',@=&\@8V]N9FEG=7)A=&EO;B!P<F5F97)R960@<W1A=&4*
M("`@("`J($!R971U<FX@;G5L;'Q014%27T5R<F]R?'-T<FEN9PH@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D;W=N;&]A
M9$9I;&4H)'!K9V9I;&4L("1V97)S:6]N+"`D;W)I9W!K9V9I;&4L("1S=&%T
M92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'-T871E*2D@
M>PH@("`@("`@("`@("`D<W1A=&4@/2`D=&AI<RT^7W!R969E<G)E9%-T871E
M.PH@("`@("`@('T*("`@("`@("`O+R![>WL@8VAE8VL@=&AE('!A8VMA9V4@
M9FEL96YA;64L(&%N9"!W:&5T:&5R(&ET)W,@86QR96%D>2!I;G-T86QL960*
M("`@("`@("`D;F5E9%]D;W=N;&]A9"`](&9A;'-E.PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<C7BAH='1P?&9T<"DZ+R\C)RP@)'!K9V9I;&4I*2!["B`@
M("`@("`@("`@("1N965D7V1O=VYL;V%D(#T@=')U93L*("`@("`@("!](&5L
M<V5I9B`H(4!I<U]F:6QE*"1P:V=F:6QE*2D@>PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/G9A;&ED4&%C:V%G94YA;64H)'!K9V9I;&4I*2!["B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G945X:7-T<R@D
M<&MG9FEL92DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]O<'1I;VYS6R=U<&=R861E)UTI("8F(&5M<'1Y*"1T:&ES+3Y?;W!T
M:6]N<ULG9F]R8V4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R
M<F]R<UM=(#T@(B1P:V=F:6QE(&%L<F5A9'D@:6YS=&%L;&5D(CL*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P:V=F:6QE
M(#T@)'1H:7,M/F=E=%!A8VMA9V5$;W=N;&]A9%5R;"@D<&MG9FEL92P@)'9E
M<G-I;VXI.PH@("`@("`@("`@("`@("`@)&YE961?9&]W;FQO860@/2!T<G5E
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*'-T
M<FQE;B@D<&MG9FEL92DI('L*("`@("`@("`@("`@("`@("`@("`D97)R;W)S
M6UT@/2`B0V]U;&0@;F]T(&]P96X@=&AE('!A8VMA9V4@9FEL93H@)'!K9V9I
M;&4B.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D97)R;W)S6UT@/2`B3F\@<&%C:V%G92!F:6QE(&=I=F5N(CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!]?7T*"B`@("`@("`@+R\@
M>WM[($1O=VYL;V%D('!A8VMA9V4@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*("`@("`@("!I9B`H)&YE961?9&]W
M;FQO860I('L*("`@("`@("`@("`@)&1O=VYL;V%D9&ER(#T@)'1H:7,M/E]C
M;VYF:6<M/F=E="@G9&]W;FQO861?9&ER)RD["B`@("`@("`@("`@(&EF("AE
M;7!T>2@D9&]W;FQO861D:7(I*2!["B`@("`@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D9&]W;FQO861D:7(@/2!3>7-T96TZ.FUK=&5M<"@G+60G
M*2DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&1O=VYL;V%D9&ER
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9R@S+"`G*R!T;7`@9&ER(&-R96%T960@870@)R`N("1D;W=N;&]A9&1I<BD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-A;&QB86-K(#T@)'1H:7,M
M/G5I(#\@87)R87DH)B1T:&ES+"`G7V1O=VYL;V%D0V%L;&)A8VLG*2`Z(&YU
M;&P["B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD["B`@("`@("`@("`@("1F:6QE(#T@)'1H:7,M/F1O
M=VYL;V%D2'1T<"@D<&MG9FEL92P@)'1H:7,M/G5I+"`D9&]W;FQO861D:7(L
M("1C86QL8F%C:RD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L
M:6YG*"D["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F:6QE*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YV86QI9%!A8VMA9V5.86UE
M*"1O<FEG<&MG9FEL92DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(5!%
M05(Z.FES17)R;W(H)&EN9F\@/2`D=&AI<RT^7W)E;6]T92T^8V%L;"@G<&%C
M:V%G92YI;F9O)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D;W)I9W!K
M9V9I;&4I*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6-O=6YT
M*"1I;F9O6R=R96QE87-E<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=086-K86=E("<@+B`D
M;W)I9W!K9V9I;&4@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!H
M87,@;F\@<F5L96%S97,G*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G3F\@<F5L96%S97,@;V8@<')E9F5R<F5D('-T871E
M("(G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1S=&%T92`N("<B
M(&5X:7-T(&9O<B!P86-K86=E("<@+B`D;W)I9W!K9V9I;&4@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)RX@(%5S92`G("X@)&]R:6=P:V=F:6QE
M("X@)RUS=&%T92!T;R!I;G-T86QL(&%N;W1H97(G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<@<W1A=&4@*&QI:V4@)R`N("1O<FEG<&MG9FEL
M92`N)RUB971A*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%2
M7TE.4U1!3$Q%4E]%4E)/4E].3U]04D5&7U-4051%*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<&MG9FEL93L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D9FEL
M92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'!K9V9I;&4@/2`D9FEL93L*("`@("`@("!]"B`@("`@("`@+R\@?7U]
M"B`@("`@("`@<F5T=7)N("1P:V=F:6QE.PH@("`@?0H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9V5T4&%C:V%G941O=VYL;V%D57)L*"D*"B`@("!F=6YC=&EO
M;B!G971086-K86=E1&]W;FQO8615<FPH)'!A8VMA9V4L("1V97)S:6]N(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H)'9E<G-I;VXI('L*("`@("`@("`@
M("`@)'!A8VMA9V4@+CT@(BTD=F5R<VEO;B(["B`@("`@("`@?0H@("`@("`@
M(&EF("@D=&AI<R`]/3T@;G5L;"!\?"`D=&AI<RT^7V-O;F9I9R`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D<&%C:V%G92`](")H='1P.B\O<&5A<BYP:'`N
M;F5T+V=E="\D<&%C:V%G92(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'!A8VMA9V4@/2`B:'1T<#HO+R(@+B`D=&AI<RT^7V-O;F9I9RT^9V5T
M*"=M87-T97)?<V5R=F5R)RD@+@H@("`@("`@("`@("`@("`@(B]G970O)'!A
M8VMA9V4B.PH@("`@("`@('T*("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D
M960H(GIL:6(B*2D@>PH@("`@("`@("`@("`D<&%C:V%G92`N/2`G/W5N8V]M
M<')E<W,]>65S)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1P86-K86=E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5X=')A8W1$;W=N;&]A
M9$9I;&5.86UE*"1P:V=F:6QE+"`F)'9E<G-I;VXI"@H@("`@9G5N8W1I;VX@
M97AT<F%C=$1O=VYL;V%D1FEL94YA;64H)'!K9V9I;&4L("8D=F5R<VEO;BD*
M("`@('L*("`@("`@("!I9B`H0&ES7V9I;&4H)'!K9V9I;&4I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<&MG9FEL93L*("`@("`@("!]"B`@("`@("`@+R\@
M<F5G97@@9&5F:6YE9"!I;B!#;VUM;VXN<&AP"B`@("`@("`@:68@*'!R96=?
M;6%T8V@H4$5!4E]#3TU-3TY?4$%#2T%'15]$3U=.3$]!1%]04D5'+"`D<&MG
M9FEL92P@)&TI*2!["B`@("`@("`@("`@("1V97)S:6]N(#T@*&ES<V5T*"1M
M6S-=*2D@/R`D;5LS72`Z(&YU;&P["B`@("`@("`@("`@(')E='5R;B`D;5LQ
M73L*("`@("`@("!]"B`@("`@("`@)'9E<G-I;VX@/2!N=6QL.PH@("`@("`@
M(')E='5R;B`D<&MG9FEL93L*("`@('T*"B`@("`O+R!]?7T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!G971$;W=N;&]A9&5D4&%C:V%G97,H*0H*("`@("\J
M*@H@("`@("H@4F5T<FEE=F4@82!L:7-T(&]F(&1O=VYL;V%D960@<&%C:V%G
M97,@869T97(@82!C86QL('1O('M`;&EN:R!D;W=N;&]A9"@I?2X*("`@("`J
M(`H@("`@("H@06QS;R!R97-E=',@=&AE(&QI<W0@;V8@9&]W;FQO861E9"!P
M86-K86=E<RX*("`@("`J($!R971U<FX@87)R87D*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1&]W;FQO861E9%!A8VMA9V5S*"D*("`@('L*("`@("`@("`D
M<F5T(#T@)'1H:7,M/E]D;W=N;&]A9&5D4&%C:V%G97,["B`@("`@("`@)'1H
M:7,M/E]D;W=N;&]A9&5D4&%C:V%G97,@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3Y?=&]$;W=N;&]A9"`](&%R<F%Y*"D["B`@("`@("`@<F5T=7)N("1R
M970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&]W;FQO860H*0H*
M("`@("\J*@H@("`@("H@1&]W;FQO860@86YY(&9I;&5S(&%N9"!T:&5I<B!D
M97!E;F1E;F-I97,L(&EF(&YE8V5S<V%R>0H@("`@("H*("`@("`J($)#+6-O
M;7!A=&EB;&4@;65T:&]D(&YA;64*("`@("`J($!P87)A;2!A<G)A>2!A(&UI
M>&5D(&QI<W0@;V8@<&%C:V%G92!N86UE<RP@;&]C86P@9FEL97,L(&]R('!A
M8VMA9V4N>&UL"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O=VYL;V%D*"1P86-K
M86=E<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1O1&]W;FQO860H
M)'!A8VMA9V5S*3L*("`@('T*("`@(`H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9&]$;W=N;&]A9"@I"@H@("`@+RHJ"B`@("`@*B!$;W=N;&]A9"!A;GD@9FEL
M97,@86YD('1H96ER(&1E<&5N9&5N8VEE<RP@:68@;F5C97-S87)Y"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y(&$@;6EX960@;&ES="!O9B!P86-K86=E
M(&YA;65S+"!L;V-A;"!F:6QE<RP@;W(@<&%C:V%G92YX;6P*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&]$;W=N;&]A9"@D<&%C:V%G97,I"B`@("!["B`@("`@
M("`@)&UY=VEL;&EN<W1A;&P@/2!A<G)A>2@I.PH@("`@("`@("1S=&%T92`]
M("1T:&ES+3Y?<')E9F5R<F5D4W1A=&4["@H@("`@("`@("\O('M[>R!D;W=N
M;&]A9"!F:6QE<R!I;B!T:&ES(&QI<W0@:68@;F5C97-S87)Y"B`@("`@("`@
M9F]R96%C:"@D<&%C:V%G97,@87,@)'!K9V9I;&4I('L*("`@("`@("`@("`@
M)&YE961?9&]W;FQO860@/2!F86QS93L*("`@("`@("`@("`@:68@*"%I<U]F
M:6QE*"1P:V=F:6QE*2D@>PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R->*&AT='!\9G1P*3HO+R,G+"`D<&MG9FEL92DI('L*("`@("`@("`@
M("`@("`@("`@("`D;F5E9%]D;W=N;&]A9"`]('1R=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D<&MG9FEL92`]("1T:&ES+3Y?9&]W
M;FQO861.;VY&:6QE*"1P:V=F:6QE*3L*("`@("`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1P:V=F:6QE*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<&MG9FEL93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("@D<&MG9FEL92`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2`O+R!E;F0@:7-?9FEL92@I"@H@("`@("`@("`@("`D=&5M<&EN9F\@
M/2`D=&AI<RT^:6YF;T9R;VU!;GDH)'!K9V9I;&4I.PH@("`@("`@("`@("!I
M9B`H)&YE961?9&]W;FQO860I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=&]$;W=N;&]A9%M=(#T@)'1E;7!I;F9O6R=P86-K86=E)UT["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M86QL9&5P<R==*2!\?"!I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V]N;'ER97%D
M97!S)UTI*2!["B`@("`@("`@("`@("`@("`O+R!I9VYO<F4@9&5P96YD96YC
M:65S(&EF('1H97)E(&%R92!A;GD@97)R;W)S"B`@("`@("`@("`@("`@("!I
M9B`H(5!%05(Z.FES17)R;W(H)'1E;7!I;F9O*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1M>7=I;&QI;G-T86QL6W-T<G1O;&]W97(H)'1E;7!I;F9O6R=P
M86-K86=E)UTI72`]($`D=&5M<&EN9F];)W)E;&5A<V5?9&5P<R==.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3Y?9&]W;FQO861E9%!A8VMA9V5S6UT@/2!A<G)A>2@G<&MG)R`]/B`D=&5M
M<&EN9F];)W!A8VMA9V4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9I;&4G(#T^("1P:V=F:6QE+"`G:6YF;R<@/3X@)'1E
M;7!I;F9O*3L*("`@("`@("!]("\O(&5N9"!F;W)E86-H*"1P86-K86=E<RD*
M("`@("`@("`O+R!]?7T*"B`@("`@("`@+R\@>WM[(&5X=')A8W0@9&5P96YD
M96YC:65S(&9R;VT@9&]W;FQO861E9"!F:6QE<R!A;F0@=&AE;B!D;W=N;&]A
M9`H@("`@("`@("\O('1H96T@:68@;F5C97-S87)Y"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG86QL9&5P<R==*2!\?"!I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)V]N;'ER97%D97!S)UTI*2!["B`@("`@("`@("`@("1D
M97!P86-K86=E<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1M
M>7=I;&QI;G-T86QL(&%S("1P86-K86=E(#T^("1A;&QD97!S*2!["B`@("`@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A;&QD97!S*2D@>PH@("`@("`@
M("`@("`@("`@("`@("\O('1H97)E(&%R92!N;R!D97!E;F1E;F-I97,*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&9O<F5A8V@H)&%L;&1E<',@87,@)&EN9F\I('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&EN9F];)W1Y<&4G72`A/2`G<&MG
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)')E="`]("1T
M:&ES+3Y?<')O8V5S<T1E<&5N9&5N8WDH)'!A8VMA9V4L("1I;F9O+"`D;7EW
M:6QL:6YS=&%L;"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1R970@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)')E=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)&1E<'!A8VMA9V5S6UT@/2`D<F5T.PH@("`@("`@("`@
M("`@("`@?2`O+R!F;W)E86-H*"1A;&QD97!S"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("AC;W5N="@D9&5P<&%C:V%G97,I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^9&]$;W=N;&]A9"@D9&5P<&%C:V%G97,I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2`O+R!]?7T@:68@+2UA;&QD97!S(&]R("TM
M;VYL>7)E<61E<',*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?9&]W
M;FQO861.;VY&:6QE*"1P:V=F:6QE*0H@("`@"B`@("`O*BH*("`@("`J($!R
M971U<FX@9F%L<V5\4$5!4E]%<G)O<GQS=')I;F<@9F%L<V4@:68@;&]O<"!S
M:&]U;&0@8F4@8G)O:V5N(&]U="!O9BP*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W1R:6YG(&EF('1H92!F:6QE('=A<R!D;W=N
M;&]A9&5D+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%27T5R<F]R(&]N(&5X8V5P=&EO;@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D;W=N;&]A9$YO;D9I;&4H)'!K
M9V9I;&4I"B`@("!["B`@("`@("`@)&]R:6=P:V=F:6QE(#T@)'!K9V9I;&4[
M"B`@("`@("`@)'-T871E(#T@;G5L;#L*("`@("`@("`D<&MG9FEL92`]("1T
M:&ES+3YE>'1R86-T1&]W;FQO861&:6QE3F%M92@D<&MG9FEL92P@)'9E<G-I
M;VXI.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<C7BAH='1P?&9T<"DZ+R\C
M)RP@)'!K9V9I;&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O
M=VYL;V%D1FEL92@D<&MG9FEL92P@)'9E<G-I;VXL("1O<FEG<&MG9FEL92D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M/G9A;&ED4&%C:V%G94YA
M;64H)'!K9V9I;&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B4&%C:V%G92!N86UE("<D<&MG9FEL92<@;F]T('9A;&ED(BD[
M"B`@("`@("`@?0H@("`@("`@("\O(&EG;F]R92!P86-K86=E<R!T:&%T(&%R
M92!I;G-T86QL960@=6YL97-S('=E(&%R92!U<&=R861I;F<*("`@("`@("`D
M8W5R:6YF;R`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P:V=F
M:6QE*3L*("`@("`@("!I9B`H)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G945X
M:7-T<R@D<&MG9FEL92D*("`@("`@("`@("`@("`F)B!E;7!T>2@D=&AI<RT^
M7V]P=&EO;G-;)W5P9W)A9&4G72D@)B8@96UP='DH)'1H:7,M/E]O<'1I;VYS
M6R=F;W)C92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")086-K
M86=E("=[)&-U<FEN9F];)W!A8VMA9V4G77TG(&%L<F5A9'D@:6YS=&%L;&5D
M+"!S:VEP<&EN9R(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@(&EF("AI;E]A<G)A>2@D<&MG9FEL92P@)'1H:7,M/E]T
M;T1O=VYL;V%D*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@("1R96QE87-E<R`]("1T:&ES+3Y?<F5M;W1E+3YC86QL
M*"=P86-K86=E+FEN9F\G+"`D<&MG9FEL92P@)W)E;&5A<V5S)RP@=')U92D[
M"B`@("`@("`@:68@*"%C;W5N="@D<F5L96%S97,I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B3F\@<F5L96%S97,@9F]U;F0@
M9F]R('!A8VMA9V4@)R1P:V=F:6QE)R(I.PH@("`@("`@('T*("`@("`@("`O
M+R!786YT(&$@<W!E8VEF:6,@=F5R<VEO;B]S=&%T90H@("`@("`@(&EF("@D
M=F5R<VEO;B`A/3T@;G5L;"D@>PH@("`@("`@("`@("`O+R!087-S960@1F]O
M+3$N,@H@("`@("`@("`@("!I9B`H)'1H:7,M/G9A;&ED4&%C:V%G959E<G-I
M;VXH)'9E<G-I;VXI*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R
M96QE87-E<ULD=F5R<VEO;ETI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*").;R!R96QE87-E('=I=&@@=F5R<VEO
M;B`G)'9E<G-I;VXG(&9O=6YD(&9O<B`G)'!K9V9I;&4G(BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("\O(%!A<W-E9"!&;V\M86QP:&$*("`@
M("`@("`@("`@?2!E;'-E:68@*&EN7V%R<F%Y*"1V97)S:6]N+"`D=&AI<RT^
M9V5T4F5L96%S95-T871E<R@I*2D@>PH@("`@("`@("`@("`@("`@)'-T871E
M(#T@)'9E<G-I;VX["B`@("`@("`@("`@("`@("`D=F5R<VEO;B`](#`["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<F5L96%S97,@87,@)'9E<B`]/B`D
M:6YF*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1I;F9;)W-T871E)UT@
M/3T@)'-T871E("8F('9E<G-I;VY?8V]M<&%R92@B)'9E<G-I;VXB+"`B)'9E
M<B(I(#P@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]
M("1V97(["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@D=F5R<VEO;B`]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*").;R!R96QE87-E('=I=&@@<W1A
M=&4@)R1S=&%T92<@9F]U;F0@9F]R("<D<&MG9FEL92<B*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@+R\@:6YV86QI9"!P;W-T9FEX('!A<W-E
M9`H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"));G9A;&ED('!O<W1F:7@@)RTD=F5R<VEO
M;B<L(&)E('-U<F4@=&\@<&%S<R!A('9A;&ED(%!%05(@(BX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B=F5R<VEO;B!N=6UB
M97(@;W(@<F5L96%S92!S=&%T92(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M+R\@1W5E<W,@=VAA="!T;R!D;W=N;&]A9`H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S=&%T97,@/2`D=&AI<RT^8F5T=&5R4W1A=&5S*"1T:&ES
M+3Y?<')E9F5R<F5D4W1A=&4L('1R=64I.PH@("`@("`@("`@("`D<&]S<VEB
M;&4@/2!F86QS93L*("`@("`@("`@("`@)'9E<G-I;VX@/2`P.PH@("`@("`@
M("`@("!F;W)E86-H("@D<F5L96%S97,@87,@)'9E<B`]/B`D:6YF*2!["B`@
M("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)&EN9ELG<W1A=&4G72P@)'-T
M871E<RD@)B8@=F5R<VEO;E]C;VUP87)E*"(D=F5R<VEO;B(L("(D=F5R(BD@
M/"`P*2!["B`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`D=F5R.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=F5R<VEO;B`]/3T@,"`F
M)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=.;R!R96QE87-E
M('=I=&@@<W1A=&4@97%U86P@=&\Z(%PG)R`N(&EM<&QO9&4H)RP@)RP@)'-T
M871E<RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("(G(&9O=6YD(&9O<B`G)'!K9V9I;&4G(BD["B`@("`@("`@("`@('T@
M96QS96EF("@D=F5R<VEO;B`]/3T@,"D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9R@P+"`B5V%R;FEN9SH@)'!K9V9I;&4@:7,@<W1A=&4@)R1I;F9;
M<W1A=&5=)R!W:&EC:"!I<R!L97-S('-T86)L92`B("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(G1H86X@<W1A=&4@)R1T:&ES+3Y?<')E9F5R
M<F5D4W1A=&4G(BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M+R\@0VAE8VL@:68@=V4@:&%V96XG="!A;')E861Y('1H92!V97)S:6]N"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72D@)B8@
M(6ES7VYU;&PH)&-U<FEN9F\I*2!["B`@("`@("`@("`@(&EF("@D8W5R:6YF
M;ULG=F5R<VEO;B==(#T]("1V97)S:6]N*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*#`L(")086-K86=E("=[)&-U<FEN9F];)W!A8VMA9V4G77TM
M>R1C=7)I;F9O6R=V97)S:6]N)UU])R!A;')E861Y(&EN<W1A;&QE9"P@<VMI
M<'!I;F<B*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?2!E;'-E:68@*'9E<G-I;VY?8V]M<&%R92@B)'9E<G-I;VXB+"`B
M>R1C=7)I;F9O6R=V97)S:6]N)UU](BD@/"`P*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G*#`L(")086-K86=E("=[)&-U<FEN9F];)W!A8VMA9V4G
M77TG('9E<G-I;VX@)WLD8W5R:6YF;ULG=F5R<VEO;B==?2<@(B`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("(@:7,@:6YS=&%L;&5D(&%N9"![
M)&-U<FEN9F];)W9E<G-I;VXG77T@:7,@/B!R97%U97-T960@)R1V97)S:6]N
M)RP@<VMI<'!I;F<B*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^7W1O1&]W
M;FQO861;72`]("1P:V=F:6QE.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1O
M=VYL;V%D1FEL92@D<&MG9FEL92P@)'9E<G-I;VXL("1O<FEG<&MG9FEL92P@
M)'-T871E*3L*("`@('T*("`@(`H@("`@+R\@?7U]"B`@("`O+R![>WL@7W!R
M;V-E<W-$97!E;F1E;F-Y*"1P86-K86=E+"`D:6YF;RP@)&UY=VEL;&EN<W1A
M;&PI"B`@("`*("`@("\J*@H@("`@("H@4')O8V5S<R!A(&1E<&5N9&5N8WDL
M(&1O=VYL;V%D(&EF(&YE8V5S<V%R>0H@("`@("H@0'!A<F%M(&%R<F%Y(&1E
M<&5N9&5N8WD@:6YF;W)M871I;VX@9G)O;2!014%27U)E;6]T92!C86QL"B`@
M("`@*B!`<&%R86T@87)R87D@<&%C:V%G97,@=&AA="!W:6QL(&)E(&EN<W1A
M;&QE9"!I;B!T:&ES(&ET97)A=&EO;@H@("`@("H@0')E='5R;B!F86QS97QS
M=')I;F=\4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B!`=&]D;R!!9&0@=&5S="!F;W(@<F5L871I;VX@)VQT)R\G;&4G("T^(&UA
M:V4@<W5R92!T:&%T('1H92!D97!E;F1E;F-Y(')E<75E<W1E9"!I<PH@("`@
M("H@("`@("`@:6X@9F%C="!L;W=E<B!T:&%N('1H92!R97%U:7)E9"!V86QU
M92X@(%1H:7,@=VEL;"!B92!V97)Y(&EM<&]R=&%N="!F;W(@0D,@9&5P96YD
M96YC:65S"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P<F]C97-S1&5P96YD96YC
M>2@D<&%C:V%G92P@)&EN9F\L("1M>7=I;&QI;G-T86QL*0H@("`@>PH@("`@
M("`@("1S=&%T92`]("1T:&ES+3Y?<')E9F5R<F5D4W1A=&4["B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V%L;&1E<',G72D@)B8@:7-S
M970H)&EN9F];)V]P=&EO;F%L)UTI("8F"B`@("`@("`@("`@("`@)&EN9F];
M)V]P=&EO;F%L)UT@/3T@)WEE<R<I('L*("`@("`@("`@("`@+R\@<VMI<"!O
M<'1I;VYA;"!D97!S"B`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@(G-K:7!P
M:6YG(%!A8VMA9V4@)R1P86-K86=E)R!O<'1I;VYA;"!D97!E;F1E;F-Y("<D
M:6YF;UMN86UE72<B*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@("`@("`O+R![>WL@9V5T(')E;&5A<V5S"B`@("`@("`@)')E
M;&5A<V5S(#T@)'1H:7,M/E]R96UO=&4M/F-A;&PH)W!A8VMA9V4N:6YF;R<L
M("1I;F9O6R=N86UE)UTL("=R96QE87-E<R<L('1R=64I.PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1R96QE87-E<RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R96QE87-E<SL*("`@("`@("!]"B`@("`@("`@:68@*"%C;W5N="@D
M<F5L96%S97,I*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]I
M;G-T86QL961;<W1R=&]L;W=E<B@D:6YF;ULG;F%M92==*5TI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R*")086-K86=E("<D<&%C:V%G
M92<@9&5P96YD96YC>2`G)&EN9F];;F%M95TG("(N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`B:&%S(&YO(')E;&5A<V5S(BD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("`D9F]U;F0@/2!F86QS93L*("`@("`@("`D<V%V92`]("1R96QE87-E<SL*
M("`@("`@("!W:&EL92AC;W5N="@D<F5L96%S97,I("8F("$D9F]U;F0I('L*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D<W1A=&4I("8F("1S=&%T92`A/2`G
M86YY)RD@>PH@("`@("`@("`@("`@("`@;&ES="@D<F5L96%S95]V97)S:6]N
M+"`D<F5L96%S92D@/2!E86-H*"1R96QE87-E<RD["B`@("`@("`@("`@("`@
M("!I9B`H)'-T871E("$]("1R96QE87-E6R=S=&%T92==("8F"B`@("`@("`@
M("`@("`@("`@("`@(6EN7V%R<F%Y*"1R96QE87-E6R=S=&%T92==+"`D=&AI
M<RT^8F5T=&5R4W1A=&5S*"1S=&%T92DI*0H@("`@("`@("`@("`@("`@>PH@
M("`@("`@("`@("`@("`@("`@("\O(&1R;W`@=&AI<R!R96QE87-E("T@:70@
M86EN)W0@<W1A8FQE(&5N;W5G:`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M7W-H:69T*"1R96QE87-E<RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M9F]U;F0@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&EF("@A8V]U;G0H)')E;&5A<V5S*2`F)B`A)&9O=6YD*2!["B`@("`@("`@
M("`@("1G970@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H*"1S879E
M(&%S("1R96QE87-E*2!["B`@("`@("`@("`@("`@("`D9V5T(#T@87)R87E?
M;65R9V4H)&=E="P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8F5T=&5R
M4W1A=&5S*"1R96QE87-E6R=S=&%T92==+"!T<G5E*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'-A=F5S=&%T92`](&%R<F%Y7W-H:69T*"1G970I
M.PH@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R*"`B4F5L96%S92!F;W(@
M)R1P86-K86=E)R!D97!E;F1E;F-Y("<D:6YF;UMN86UE72<@(B`N"B`@("`@
M("`@("`@("`@("`B:&%S('-T871E("<D<V%V97-T871E)RP@<F5Q=6ER97,@
M)R1S=&%T92<B*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@("`@("!I9B`H:6Y?87)R87DH<W1R=&]L;W=E<B@D:6YF;ULG;F%M
M92==*2P@)'1H:7,M/E]T;T1O=VYL;V%D*2!\?`H@("`@("`@("`@("`@(&ES
M<V5T*"1M>7=I;&QI;G-T86QL6W-T<G1O;&]W97(H)&EN9F];)VYA;64G72E=
M*2D@>PH@("`@("`@("`@("`O+R!S:VEP('5P9W)A9&4@8VAE8VL@9F]R('!A
M8VMA9V5S('=E('=I;&P@:6YS=&%L;`H@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]I;G-T
M86QL961;<W1R=&]L;W=E<B@D:6YF;ULG;F%M92==*5TI*2!["B`@("`@("`@
M("`@("\O(&-H96-K('1O('-E92!I9B!W92!C86X@:6YS=&%L;"!T:&4@<W!E
M8VEF:6,@=F5R<VEO;B!R97%U:7)E9`H@("`@("`@("`@("!I9B`H)&EN9F];
M)W)E;"==(#T]("=E<2<I('L*("`@("`@("`@("`@("`@(')E='5R;B`D:6YF
M;ULG;F%M92==("X@)RTG("X@)&EN9F];)W9E<G-I;VXG73L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`O+R!S:VEP('5P9W)A9&4@8VAE8VL@9F]R('!A
M8VMA9V5S('=E(&1O;B=T(&AA=F4@:6YS=&%L;&5D"B`@("`@("`@("`@(')E
M='5R;B`D:6YF;ULG;F%M92==.PH@("`@("`@('T*("`@("`@("`O+R!]?7T*
M"B`@("`@("`@+R\@>WM[('-E92!I9B!A(&1E<&5N9&5N8WD@;75S="!B92!U
M<&=R861E9`H@("`@("`@("1I;G-T7W9E<G-I;VX@/2`D=&AI<RT^7W)E9VES
M=')Y+3YP86-K86=E26YF;R@D:6YF;ULG;F%M92==+"`G=F5R<VEO;B<I.PH@
M("`@("`@(&EF("@A:7-S970H)&EN9F];)W9E<G-I;VXG72DI('L*("`@("`@
M("`@("`@+R\@=&AI<R!I<R!A(')E;#TG:&%S)R!D97!E;F1E;F-Y+"!C:&5C
M:R!A9V%I;G-T(&QA=&5S=`H@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP
M87)E*"1R96QE87-E7W9E<G-I;VXL("1I;G-T7W9E<G-I;VXL("=L92<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)&EN9F];)VYA;64G73L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H=F5R<VEO;E]C
M;VUP87)E*"1I;F9O6R=V97)S:6]N)UTL("1I;G-T7W9E<G-I;VXL("=L92<I
M*2!["B`@("`@("`@("`@("\O(&EN<W1A;&QE9"!V97)S:6]N(&ES('5P+71O
M+61A=&4*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&EN9F];)VYA;64G73L*("`@('T*("`@(`H@("`@+R\@
M?7U]"B`@("`O+R![>WL@7V1O=VYL;V%D0V%L;&)A8VLH*0H*("`@(&9U;F-T
M:6]N(%]D;W=N;&]A9$-A;&QB86-K*"1M<V<L("1P87)A;7,@/2!N=6QL*0H@
M("`@>PH@("`@("`@('-W:71C:"`H)&US9RD@>PH@("`@("`@("`@("!C87-E
M("=S879E87,G.@H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B9&]W
M;FQO861I;F<@)'!A<F%M<R`N+BXB*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E("=D;VYE)SH*("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,2P@)RXN+F1O;F4Z("<@+B!N=6UB97)?9F]R;6%T*"1P87)A
M;7,L(#`L("<G+"`G+"<I("X@)R!B>71E<R<I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@)V)Y=&5S<F5A9"<Z"B`@("`@("`@
M("`@("`@("!S=&%T:6,@)&)Y=&5S.PH@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1B>71E<RDI('L*("`@("`@("`@("`@("`@("`@("`D8GET97,@/2`P
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"$H)&)Y
M=&5S("4@,3`R-#`I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9R@Q+"`G+B<L(&9A;'-E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1B>71E<R`K/2`D<&%R86US.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)W-T87)T)SH*("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,2P@(E-T87)T:6YG('1O(&1O=VYL;V%D('LD<&%R86US
M6S!=?2`H(BYN=6UB97)?9F]R;6%T*"1P87)A;7-;,5TL(#`L("<G+"`G+"<I
M+B(@8GET97,I(BD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,M/G5I+"`G7V1O=VYL
M;V%D0V%L;&)A8VLG*2D*("`@("`@("`@("`@)'1H:7,M/G5I+3Y?9&]W;FQO
M861#86QL8F%C:R@D;7-G+"`D<&%R86US*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!P=7-H17)R;W(H)&5R<FUS9RP@)&-O9&4I"B`@("`*("`@
M("\J*@H@("`@("H@0'!A<F%M('-T<FEN9PH@("`@("H@0'!A<F%M(&EN=&5G
M97(*("`@("`J+PH@("`@9G5N8W1I;VX@<'5S:$5R<F]R*"1E<G)M<V<L("1C
M;V1E(#T@+3$I"B`@("!["B`@("`@("`@87)R87E?<'5S:"@D=&AI<RT^7V5R
M<F]R4W1A8VLL(&%R<F%Y*"1E<G)M<V<L("1C;V1E*2D["B`@("!]"B`@("`*
M("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$5R<F]R37-G<R@I"B`@("`*("`@
M(&9U;F-T:6]N(&=E=$5R<F]R37-G<R@I"B`@("!["B`@("`@("`@)&US9W,@
M/2!A<G)A>2@I.PH@("`@("`@("1E<G)S(#T@)'1H:7,M/E]E<G)O<E-T86-K
M.PH@("`@("`@(&9O<F5A8V@@*"1E<G)S(&%S("1E<G(I('L*("`@("`@("`@
M("`@)&US9W-;72`]("1E<G);,%T["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3Y?97)R;W)3=&%C:R`](&%R<F%Y*"D["B`@("`@("`@<F5T=7)N("1M<V=S
M.PH@("`@?0H@("`@"B`@("`O+R!]?7T*?0HO+R!]?7T*"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+G!H<```````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C<W-C0`,3`T,3<S-C,P,#8`,#(P,3<V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\O"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N
M(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG('5R;#H@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<CH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@0V]M;6%N9"YP:'`L=B`Q+C(R(#(P
M,#0O,#$O,#@@,3<Z,S,Z,3(@<VYI<&5R($5X<"`D"@H*<F5Q=6ER95]O;F-E
M(")014%2+G!H<"(["@HO*BH*("H@3&ES="!O9B!C;VUM86YD<R!A;F0@=VAA
M="!C;&%S<V5S('1H97D@87)E(&EM<&QE;65N=&5D(&EN+@H@*B!`=F%R(&%R
M<F%Y(&-O;6UA;F0@/3X@:6UP;&5M96YT:6YG(&-L87-S"B`J+PHD1TQ/0D%,
M4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==(#T@87)R87DH*3L*"B\J
M*@H@*B!,:7-T(&]F('-H;W)T8W5T<R!T;R!C;VUM;VX@8V]M;6%N9',N"B`J
M($!V87(@87)R87D@<VAO<G1C=70@/3X@8V]M;6%N9`H@*B\*)$=,3T)!3%-;
M)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UT@/2!A<G)A>2@I.PH*+RHJ"B`J
M($%R<F%Y(&]F(&-O;6UA;F0@;V)J96-T<PH@*B!`=F%R(&%R<F%Y(&-L87-S
M(#T^(&]B:F5C=`H@*B\*)$=,3T)!3%-;)U]014%27T-O;6UA;F1?;V)J96-T
M<R==(#T@87)R87DH*3L*"B\J*@H@*B!7:&EC:"!U<V5R(&EN=&5R9F%C92!C
M;&%S<R!I<R!B96EN9R!U<V5D+@H@*B!`=F%R('-T<FEN9R!C;&%S<R!N86UE
M"B`J+PHD1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]U:6-L87-S)UT@/2`G4$5!
M4E]&<F]N=&5N9%]#3$DG.PH*+RHJ"B`J($EN<W1A;F-E(&]F("1?4$5!4E]#
M;VUM86YD7W5I8VQA<W,N"B`J($!V87(@;V)J96-T"B`J+PHD1TQ/0D%,4ULG
M7U!%05)?0V]M;6%N9%]U:6]B:F5C="==(#T@;G5L;#L*"B\J*@H@*B!014%2
M(&-O;6UA;F0@8VQA<W,L(&$@<VEM<&QE(&9A8W1O<GD@8VQA<W,@9F]R(&%D
M;6EN:7-T<F%T:79E"B`J(&-O;6UA;F1S+@H@*@H@*B!(;W<@=&\@:6UP;&5M
M96YT(&-O;6UA;F0@8VQA<W-E<SH*("H*("H@+2!4:&4@8VQA<W,@;75S="!B
M92!C86QL960@4$5!4E]#;VUM86YD7TYN;BP@:6YS=&%L;&5D(&EN('1H90H@
M*B`@(")014%2+T-O;6UO;B(@<W5B9&ER+"!W:71H(&$@;65T:&]D(&-A;&QE
M9"!G971#;VUM86YD<R@I('1H870*("H@("!R971U<FYS(&%N(&%R<F%Y(&]F
M('1H92!C;VUM86YD<R!I;7!L96UE;G1E9"!B>2!T:&4@8VQA<W,@*'-E90H@
M*B`@(%!%05(O0V]M;6%N9"]);G-T86QL+G!H<"!F;W(@86X@97AA;7!L92DN
M"B`J"B`J("T@5&AE(&-L87-S(&UU<W0@:6UP;&5M96YT(&$@<G5N*"D@9G5N
M8W1I;VX@=&AA="!I<R!C86QL960@=VET:"!T:')E90H@*B`@('!A<F%M<SH*
M("H*("H@("`@*'-T<FEN9RD@8V]M;6%N9"!N86UE"B`J("`@("AA<G)A>2D@
M(&%S<V]C(&%R<F%Y('=I=&@@;W!T:6]N<RP@9G)E96QY(&1E9FEN960@8GD@
M96%C:`H@*B`@("`@("`@("`@("!C;VUM86YD+"!F;W(@97AA;7!L93H*("H@
M("`@("`@("`@("`@87)R87DH)V9O<F-E)R`]/B!T<G5E*0H@*B`@("`H87)R
M87DI("!L:7-T(&]F('1H92!O=&AE<B!P87)A;65T97)S"B`J"B`J("`@5&AE
M(')U;B@I(&9U;F-T:6]N(')E='5R;G,@82!014%27T-O;6UA;F1297-P;VYS
M92!O8FIE8W0N("!5<V4*("H@("!T:&5S92!M971H;V1S('1O(&=E="!I;F9O
M<FUA=&EO;CH*("H*("H@("`@:6YT(&=E=%-T871U<R@I("`@4F5T=7)N<R!0
M14%27T-/34U!3D1?*%-50T-%4U-\1D%)3%5217Q005)424%,*0H@*B`@("`@
M("`@("`@("`@("`@("`@("`J7U!!4E1)04P@;65A;G,@=&AA="!Y;W4@;F5E
M9"!T;R!I<W-U92!A="!L96%S=`H@*B`@("`@("`@("`@("`@("`@("`@("!O
M;F4@;6]R92!C;VUM86YD('1O(&-O;7!L971E('1H92!O<&5R871I;VX*("H@
M("`@("`@("`@("`@("`@("`@("`@*'5S960@9F]R(&5X86UP;&4@9F]R('9A
M;&ED871I;VX@<W1E<',I+@H@*@H@*B`@("!S=')I;F<@9V5T365S<V%G92@I
M("!2971U<FYS(&$@;65S<V%G92!F;W(@=&AE('5S97(N("!296UE;6)E<BP*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@;F\@2%1-3"!O<B!O=&AE<B!I
M;G1E<F9A8V4M<W!E8VEF:6,@;6%R:W5P+@H@*@H@*B`@($EF('-O;65T:&EN
M9R!U;F5X<&5C=&5D(&AA<'!E;G,L(')U;B@I(')E='5R;G,@82!014%2(&5R
M<F]R+@H@*@H@*B`M($1/3B=4($]55%!55"!!3EE42$E.1R$@4F5T=7)N('1E
M>'0@9F]R(&]U='!U="!I;G-T96%D+@H@*@H@*B`M($1/3B=4(%5312!(5$U,
M(2!4:&4@=&5X="!Y;W4@<F5T=7)N('=I;&P@8F4@=7-E9"!F<F]M(&)O=&@@
M1W1K+`H@*B`@('=E8B!A;F0@8V]M;6%N9"UL:6YE(&EN=&5R9F%C97,L('-O
M(&9O<B!N;W<L(&ME97`@979E<GET:&EN9R!T;PH@*B`@('!L86EN('1E>'0N
M"B`J"B`J("T@1$].)U0@55-%($58250@3U(@1$E%(2!!;'=A>7,@=7-E('!E
M87(@97)R;W)S+B`@1G)O;2!S=&%T:6,*("H@("!C;&%S<V5S(&1O(%!%05(Z
M.G)A:7-E17)R;W(H*2P@9G)O;2!O=&AE<B!C;&%S<V5S(&1O"B`J("`@)'1H
M:7,M/G)A:7-E17)R;W(H*2X*("HO"F-L87-S(%!%05)?0V]M;6%N9`I["B`@
M("`O+R![>WL@9F%C=&]R>2@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(')I
M9VAT(&]B:F5C="!F;W(@97AE8W5T:6YG(&$@8V]M;6%N9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;VUM86YD(%1H92!N86UE(&]F('1H92!C
M;VUM86YD"B`@("`@*B!`<&%R86T@;V)J96-T("1C;VYF:6<@($EN<W1A;F-E
M(&]F(%!%05)?0V]N9FEG(&]B:F5C=`H@("`@("H*("`@("`J($!R971U<FX@
M;V)J96-T('1H92!C;VUM86YD(&]B:F5C="!O<B!A(%!%05(@97)R;W(*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!F86-T;W)Y*"1C;VUM86YD+"`F)&-O;F9I9RD*
M("`@('L*("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;)U]014%27T-O;6UA
M;F1?8V]M;6%N9&QI<W0G72DI('L*("`@("`@("`@("`@4$5!4E]#;VUM86YD
M.CIR96=I<W1E<D-O;6UA;F1S*"D["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<W-E="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G75LD8V]M
M;6%N9%TI*2!["B`@("`@("`@("`@("1C;VUM86YD(#T@)$=,3T)!3%-;)U]0
M14%27T-O;6UA;F1?<VAO<G1C=71S)UU;)&-O;6UA;F1=.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O
M;6UA;F1L:7-T)UU;)&-O;6UA;F1=*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B
M*3L*("`@("`@("!]"B`@("`@("`@)&-L87-S(#T@)$=,3T)!3%-;)U]014%2
M7T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD8V]M;6%N9%T["B`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B
M*3L*("`@("`@("!]"B`@("`@("`@)'5I(#TF(%!%05)?0V]M;6%N9#HZ9V5T
M1G)O;G1E;F1/8FIE8W0H*3L*("`@("`@("`D;V)J(#T@)FYE=R`D8VQA<W,H
M)'5I+"`D8V]N9FEG*3L*("`@("`@("!R971U<FX@)&]B:CL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R`F(&=E=$9R;VYT96YD3V)J96-T*"D*"B`@
M("`O*BH*("`@("`J($=E="!I;G-T86YC92!O9B!F<F]N=&5N9"!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$9R;VYT96YD3V)J96-T*"D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;)U]014%27T-O;6UA;F1?
M=6EO8FIE8W0G72DI('L*("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T-O
M;6UA;F1?=6EO8FIE8W0G72`]("9N97<@)$=,3T)!3%-;)U]014%27T-O;6UA
M;F1?=6EC;&%S<R==.PH@("`@("`@('T*("`@("`@("!R971U<FX@)$=,3T)!
M3%-;)U]014%27T-O;6UA;F1?=6EO8FIE8W0G73L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R`F('-E=$9R;VYT96YD0VQA<W,H*0H*("`@("\J*@H@
M("`@("H@3&]A9"!C=7)R96YT(&9R;VYT96YD(&-L87-S+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5I8VQA<W,@3F%M92!O9B!C;&%S<R!I;7!L
M96UE;G1I;F<@=&AE(&9R;VYT96YD"B`@("`@*@H@("`@("H@0')E='5R;B!O
M8FIE8W0@=&AE(&9R;VYT96YD(&]B:F5C="P@;W(@82!014%2(&5R<F]R"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9S971&<F]N=&5N
M9$-L87-S*"1U:6-L87-S*0H@("`@>PH@("`@("`@(&EF("AI<U]O8FIE8W0H
M)$=,3T)!3%-;)U]014%27T-O;6UA;F1?=6EO8FIE8W0G72D@)B8*("`@("`@
M("`@("`@<W1R=&]L;W=E<B@D=6EC;&%S<RD@/3T@9V5T7V-L87-S*"1'3$]"
M04Q36R=?4$5!4E]#;VUM86YD7W5I;V)J96-T)UTI*2!["B`@("`@("`@("`@
M(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]U:6]B:F5C="==.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D=6EC;&%S<RDI
M('L*("`@("`@("`@("`@)&9I;&4@/2!S=')?<F5P;&%C92@G7R<L("<O)RP@
M)'5I8VQA<W,I("X@)RYP:'`G.PH@("`@("`@("`@("!I9B`H4$5!4E]#;VUM
M86YD.CII<TEN8VQU9&5A8FQE*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@
M:6YC;'5D95]O;F-E("1F:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)'5I8VQA<W,I*2!["B`@("`@("`@
M("`@("1O8FH@/2`F;F5W("1U:6-L87-S.PH@("`@("`@("`@("`O+R!Q=6EC
M:R!T97-T('1O('-E92!I9B!T:&ES(&-L87-S(&EM<&QE;65N=',@82!F97<@
M;V8@=&AE(&UO<W0*("`@("`@("`@("`@+R\@:6UP;W)T86YT(&9R;VYT96YD
M(&UE=&AO9',*("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&]B:BP@
M)W5S97)#;VYF:7)M)RDI('L*("`@("`@("`@("`@("`@("1'3$]"04Q36R=?
M4$5!4E]#;VUM86YD7W5I;V)J96-T)UT@/2`F)&]B:CL*("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7W5I8VQA<W,G72`]("1U:6-L
M87-S.PH@("`@("`@("`@("`@("`@<F5T=7)N("1O8FH["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@B;F]T(&$@9G)O;G1E;F0@8VQA<W,Z("1U:6-L87-S(BD["B`@("`@
M("`@("`@("`@("!R971U<FX@)&5R<CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@B;F\@<W5C:"!C
M;&%S<SH@)'5I8VQA<W,B*3L*("`@("`@("!R971U<FX@)&5R<CL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!S971&<F]N=&5N9%1Y<&4H*0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&ES26YC;'5D96%B;&4H*0H*("`@("\J*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"!R96QA=&EV92!O<B!A8G-O;'5T
M92!I;F-L=61E('!A=&@*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("H@
M0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!I<TEN8VQU9&5A8FQE*"1P
M871H*0H@("`@>PH@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D<&%T:"D@)B8@
M:7-?<F5A9&%B;&4H)'!A=&@I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*("`@("`@("`D:7!A=&@@/2!E>'!L;V1E*%!!5$A?4T50
M05)!5$]2+"!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D["B`@("`@("`@9F]R
M96%C:"`H)&EP871H(&%S("1I;F-L=61E*2!["B`@("`@("`@("`@("1T97-T
M(#T@<F5A;'!A=&@H)&EN8VQU9&4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@
M)'!A=&@I.PH@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)'1E<W0I("8F
M(&ES7W)E861A8FQE*"1T97-T*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&-U<G)E;G0@9G)O
M;G1E;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=6ET>7!E($YA
M;64@;V8@=&AE(&9R;VYT96YD('1Y<&4@*&9O<B!E>&%M<&QE(")#3$DB*0H@
M("`@("H*("`@("`J($!R971U<FX@;V)J96-T('1H92!F<F]N=&5N9"!O8FIE
M8W0L(&]R(&$@4$5!4B!E<G)O<@H@("`@("H@0'-T871I8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S971&<F]N=&5N9%1Y<&4H)'5I='EP92D*("`@('L*("`@
M("`@("`D=6EC;&%S<R`]("=014%27T9R;VYT96YD7R<@+B`D=6ET>7!E.PH@
M("`@("`@(')E='5R;B!014%27T-O;6UA;F0Z.G-E=$9R;VYT96YD0VQA<W,H
M)'5I8VQA<W,I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')E9VES
M=&5R0V]M;6%N9',H*0H*("`@("\J*@H@("`@("H@4V-A;B!T:')O=6=H('1H
M92!#;VUM86YD(&1I<F5C=&]R>2!L;V]K:6YG(&9O<B!C;&%S<V5S"B`@("`@
M*B!A;F0@<V5E('=H870@8V]M;6%N9',@=&AE>2!I;7!L96UE;G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VP@("`H;W!T:6]N86PI(&EF($9!3%-%("AD
M969A=6QT*2P@=&AE(&YE=R!L:7-T(&]F"B`@("`@*B`@("`@("`@("`@("`@
M(&-O;6UA;F1S('-H;W5L9"!R97!L86-E('1H92!C=7)R96YT(&]N92X@($EF
M(%12544L"B`@("`@*B`@("`@("`@("`@("`@(&YE=R!E;G1R:65S('=I;&P@
M8F4@;65R9V5D('=I=&@@;VQD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@*&]P=&EO;F%L*2!W:&5R92`H=VAA="!D:7)E8W1O<GDI('1O(&QO;VL@
M9F]R"B`@("`@*B`@("`@("`@("`@("`@(&-L87-S97,L(&1E9F%U;'1S('1O
M('1H92!#;VUM86YD('-U8F1I<F5C=&]R>2!O9@H@("`@("H@("`@("`@("`@
M("`@("!T:&4@9&ER96-T;W)Y(&9R;VT@=VAE<F4@=&AI<R!F:6QE("A?7T9)
M3$5?7RD@:7,*("`@("`J("`@("`@("`@("`@("`@:6YC;'5D960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@82!014%2
M(&5R<F]R(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!R96=I<W1E
M<D-O;6UA;F1S*"1M97)G92`](&9A;'-E+"`D9&ER(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H)&1I<B`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D9&ER
M(#T@9&ER;F%M92A?7T9)3$5?7RD@+B`G+T-O;6UA;F0G.PH@("`@("`@('T*
M("`@("`@("`D9'`@/2!`;W!E;F1I<B@D9&ER*3L*("`@("`@("!I9B`H96UP
M='DH)&1P*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B<F5G:7-T97)#;VUM86YD<SH@;W!E;F1I<B@D9&ER*2!F86EL960B*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"$D;65R9V4I('L*("`@("`@("`@("`@
M)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G72`](&%R<F%Y
M*"D["B`@("`@("`@?0H@("`@("`@('=H:6QE("@D96YT<GD@/2!R96%D9&ER
M*"1D<"DI('L*("`@("`@("`@("`@:68@*"1E;G1R>7LP?2`]/2`G+B<@?'P@
M<W5B<W1R*"1E;G1R>2P@+30I("$]("<N<&AP)R!\?"`D96YT<GD@/3T@)T-O
M;6UO;BYP:'`G*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D8VQA<W,@/2`B4$5!4E]#;VUM86YD7R(N
M<W5B<W1R*"1E;G1R>2P@,"P@+30I.PH@("`@("`@("`@("`D9FEL92`]("(D
M9&ER+R1E;G1R>2(["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D9FEL93L*
M("`@("`@("`@("`@+R\@3&ES="!O9B!C;VUM86YD<PH@("`@("`@("`@("!I
M9B`H96UP='DH)$=,3T)!3%-;)U]014%27T-O;6UA;F1?;V)J96-T<R==6R1C
M;&%S<UTI*2!["B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?0V]M
M;6%N9%]O8FIE8W1S)UU;)&-L87-S72`]("9N97<@)&-L87-S*"1U:2P@)&-O
M;F9I9RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&EM<&QE;65N=',@
M/2`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]O8FIE8W1S)UU;)&-L87-S72T^
M9V5T0V]M;6%N9',H*3L*("`@("`@("`@("`@9F]R96%C:"`H)&EM<&QE;65N
M=',@87,@)&-O;6UA;F0@/3X@)&1E<V,I('L*("`@("`@("`@("`@("`@("1'
M3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T)UU;)&-O;6UA;F1=
M(#T@)&-L87-S.PH@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T-O
M;6UA;F1?8V]M;6%N9&1E<V,G75LD8V]M;6%N9%T@/2`D9&5S8SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D<VAO<G1C=71S(#T@)$=,3T)!3%-;)U]0
M14%27T-O;6UA;F1?;V)J96-T<R==6R1C;&%S<UTM/F=E=%-H;W)T8W5T<R@I
M.PH@("`@("`@("`@("!F;W)E86-H("@D<VAO<G1C=71S(&%S("1S:&]R=&-U
M="`]/B`D8V]M;6%N9"D@>PH@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]0
M14%27T-O;6UA;F1?<VAO<G1C=71S)UU;)'-H;W)T8W5T72`]("1C;VUM86YD
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$-O;6UA;F1S*"D*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@;&ES="!O9B!C=7)R96YT;'D@<W5P
M<&]R=&5D(&-O;6UA;F1S+"!A;F0@=VAA=`H@("`@("H@8VQA<W-E<R!I;7!L
M96UE;G0@=&AE;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&-O;6UA
M;F0@/3X@:6UP;&5M96YT:6YG(&-L87-S"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T0V]M;6%N9',H*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,
M4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==*2D@>PH@("`@("`@("`@
M("!014%27T-O;6UA;F0Z.G)E9VES=&5R0V]M;6%N9',H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA
M;F1L:7-T)UT["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4VAO
M<G1C=71S*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@;&ES="!O9B!C;VUM
M86YD('-H;W)T8W5T<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y('-H
M;W)T8W5T(#T^(&-O;6UA;F0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&]R
M=&-U=',H*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG7U!%
M05)?0V]M;6%N9%]S:&]R=&-U=',G72DI('L*("`@("`@("`@("`@4$5!4E]#
M;VUM86YD.CIR96=I<W1E<D-O;6UA;F1S*"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G73L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G971'971O<'1!<F=S*"D*
M"B`@("`O*BH*("`@("`J($-O;7!I;&5S(&%R9W5M96YT<R!F;W(@9V5T;W!T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UA;F0@("`@(&-O
M;6UA;F0@=&\@9V5T(&]P='-T<FEN9R!F;W(*("`@("`J($!P87)A;2!S=')I
M;F<@)'-H;W)T7V%R9W,@("AR969E<F5N8V4I('-H;W)T(&=E=&]P="!F;W)M
M870*("`@("`J($!P87)A;2!A<G)A>2`@)&QO;F=?87)G<R`@("AR969E<F5N
M8V4I(&QO;F<@9V5T;W!T(&9O<FUA=`H@("`@("H*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=E=&]P=$%R9W,H)&-O;6UA
M;F0L("8D<VAO<G1?87)G<RP@)B1L;VYG7V%R9W,I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T
M)UTI*2!["B`@("`@("`@("`@(%!%05)?0V]M;6%N9#HZ<F5G:7-T97)#;VUM
M86YD<R@I.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q3
M6R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T)UU;)&-O;6UA;F1=*2D@>PH@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@)&-L
M87-S(#T@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD
M8V]M;6%N9%T["B`@("`@("`@)&]B:B`]("8D1TQ/0D%,4ULG7U!%05)?0V]M
M;6%N9%]O8FIE8W1S)UU;)&-L87-S73L*("`@("`@("!R971U<FX@)&]B:BT^
M9V5T1V5T;W!T07)G<R@D8V]M;6%N9"P@)'-H;W)T7V%R9W,L("1L;VYG7V%R
M9W,I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$1E<V-R:7!T
M:6]N*"D*"B`@("`O*BH*("`@("`J($=E="!D97-C<FEP=&EO;B!F;W(@82!C
M;VUM86YD+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("1C;VUM86YD
M($YA;64@;V8@=&AE(&-O;6UA;F0*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!C;VUM86YD(&1E<V-R:7!T:6]N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1&5S8W)I<'1I;VXH)&-O;6UA;F0I"B`@("!["B`@("`@("`@:68@*"%I
M<W-E="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD9&5S8R==6R1C
M;VUM86YD72DI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM
M86YD9&5S8R==6R1C;VUM86YD73L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!G971(96QP*"D*"B`@("`O*BH*("`@("`J($=E="!H96QP(&9O<B!C
M;VUM86YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UA;F0@
M3F%M92!O9B!T:&4@8V]M;6%N9"!T;R!R971U<FX@:&5L<"!F;W(*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!G971(96QP*"1C;VUM86YD*0H@("`@>PH@("`@("`@
M("1C;61S(#T@4$5!4E]#;VUM86YD.CIG971#;VUM86YD<R@I.PH@("`@("`@
M(&EF("AI<W-E="@D8VUD<ULD8V]M;6%N9%TI*2!["B`@("`@("`@("`@("1C
M;&%S<R`]("1C;61S6R1C;VUM86YD73L*("`@("`@("`@("`@<F5T=7)N("1'
M3$]"04Q36R=?4$5!4E]#;VUM86YD7V]B:F5C=',G75LD8VQA<W-=+3YG971(
M96QP*"1C;VUM86YD*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H@("`@+R\@?7U]"GT*"C\^"@```````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T)U:6QD97(N<&AP````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,3`P,``Q,#0Q-S,V
M,S`P-@`P,C`Q-C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4W1I9R!3YG1H97(@0F%K
M:V5N(#QS<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!"
M=6EL9&5R+G!H<"QV(#$N,30@,C`P-"\P,2\P."`Q-SHS,SHQ,B!S;FEP97(@
M17AP("0*"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL*"B\J*@H@
M*B!#;&%S<R!T;R!H86YD;&4@8G5I;&1I;F<@*&-O;7!I;&EN9RD@97AT96YS
M:6]N<RX*("H*("H@0&%U=&AO<B!3=&EG(%/F=&AE<B!"86MK96X@/'-S8D!P
M:'`N;F5T/@H@*B\*8VQA<W,@4$5!4E]"=6EL9&5R(&5X=&5N9',@4$5!4E]#
M;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("!V87(@)'!H<%]A
M<&E?=F5R<VEO;B`](#`["B`@("!V87(@)'IE;F1?;6]D=6QE7V%P:5]N;R`]
M(#`["B`@("!V87(@)'IE;F1?97AT96YS:6]N7V%P:5]N;R`](#`["@H@("`@
M=F%R("1E>'1E;G-I;VYS7V)U:6QT(#T@87)R87DH*3L*"B`@("!V87(@)&-U
M<G)E;G1?8V%L;&)A8VL@/2!N=6QL.PH*("`@("\O('5S960@9F]R(&US9&5V
M(&)U:6QD<PH@("`@=F%R("1?;&%S=&QI;F4@/2!N=6QL.PH@("`@=F%R("1?
M9FER<W1L:6YE(#T@;G5L;#L*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;G-T
M<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!014%27T)U:6QD97(@8V]N<W1R=6-T
M;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D=6D@=7-E<B!I;G1E
M<F9A8V4@;V)J96-T("AI;G-T86YC92!O9B!014%27T9R;VYT96YD7RHI"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@4$5!4E]"=6EL9&5R*"8D=6DI"B`@("!["B`@("`@("`@<&%R96YT.CI0
M14%27T-O;6UO;B@I.PH@("`@("`@("1T:&ES+3YS971&<F]N=&5N9$]B:F5C
M="@D=6DI.PH@("`@?0H*("`@("\O('U]?0H*("`@("\O('M[>R!?8G5I;&1?
M=VEN,S(H*0H*("`@("\J*@H@("`@("H@0G5I;&0@86X@97AT96YS:6]N(&9R
M;VT@<V]U<F-E(&]N('=I;F1O=W,N"B`@("`@*B!R97%U:7)E<R!M<V1E=@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&1?=VEN,S(H)&1E<V-F:6QE+"`D
M8V%L;&)A8VL@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1I;F9O(#T@)'1H:7,M/FEN9F]&<F]M1&5S8W)I<'1I;VY&:6QE*"1D
M97-C9FEL92DI*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;SL*("`@("`@
M("!]"B`@("`@("`@)&1I<B`](&1I<FYA;64H)&1E<V-F:6QE*3L*("`@("`@
M("`D;VQD7V-W9"`](&=E=&-W9"@I.PH*("`@("`@("!I9B`H(4!C:&1I<B@D
M9&ER*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(F-O=6QD(&YO="!C:&1I<B!T;R`D9&ER(BD["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YL;V<H,BP@(F)U:6QD:6YG(&EN("1D:7(B*3L*"B`@("`@("`@
M)&1S<"`]("1I;F9O6R=P86-K86=E)UTN)RYD<W`G.PH@("`@("`@(&EF("@A
M0&ES7V9I;&4H(B1D:7(O)&1S<"(I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B5&AE($134"`D9'-P(&1O97,@;F]T(&5X:7-T
M+B(I.PH@("`@("`@('T*("`@("`@("`O+R!86%@@5$]$3SH@;6%K92!R96QE
M87-E(&)U:6QD('1Y<&4@8V]N9FEG=7)A8FQE"B`@("`@("`@)&-O;6UA;F0@
M/2`G;7-D978@)RXD9'-P+B<@+TU!2T4@(B<N)&EN9F];)W!A8VMA9V4G72X@
M)R`M(%)E;&5A<V4B)SL*"B`@("`@("`@)'1H:7,M/F-U<G)E;G1?8V%L;&)A
M8VL@/2`D8V%L;&)A8VL["B`@("`@("`@)&5R<B`]("1T:&ES+3Y?<G5N0V]M
M;6%N9"@D8V]M;6%N9"P@87)R87DH)B1T:&ES+"`G;7-D979#86QL8F%C:R<I
M*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&5R<CL*("`@("`@("!]"@H@("`@("`@("\O(&9I9W5R
M92!O=70@=&AE(&)U:6QD('!L871F;W)M(&%N9"!T>7!E"B`@("`@("`@)'!L
M871F;W)M(#T@)U=I;C,R)SL*("`@("`@("`D8G5I;&1T>7!E(#T@)U)E;&5A
M<V4G.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O+BH_)RXD:6YF;ULG<&%C
M:V%G92==+B=<<RU<<RA<=RLI7',H+BH_*2TK+VDG+"1T:&ES+3Y?9FER<W1L
M:6YE+"1M871C:&5S*2D@>PH@("`@("`@("`@("`D<&QA=&9O<FT@/2`D;6%T
M8VAE<ULQ73L*("`@("`@("`@("`@)&)U:6QD='EP92`]("1M871C:&5S6S)=
M.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H+BHI/UQS
M+5QS*%QD*RDN*C\H7&0K*2\G+"1T:&ES+3Y?;&%S=&QI;F4L)&UA=&-H97,I
M*2!["B`@("`@("`@("`@(&EF("@D;6%T8VAE<ULR72D@>PH@("`@("`@("`@
M("`@("`@+R\@=&AE<F4@=V5R92!E<G)O<G,@:6X@=&AE(&)U:6QD"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E1H97)E('=E
M<F4@97)R;W)S(&1U<FEN9R!C;VUP:6QA=&EO;BXB*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D;W5T(#T@)&UA=&-H97-;,5T["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$
M:60@;F]T('5N9&5R<W1A;F0@=&AE(&-O;7!L971I;VX@<W1A='5S(')E='5R
M;F5D(&9R;VT@;7-D978N97AE+B(I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M;7-D978@9&]E<VXG="!T96QL('5S('1H92!O=71P=70@9&ER96-T;W)Y(#HO
M"B`@("`@("`@+R\@;W!E;B!T:&4@9'-P+"!F:6YD("]O=70@86YD('5S92!T
M:&%T(&1I<F5C=&]R>0H@("`@("`@("1D<W!T97AT(#T@:F]I;BAF:6QE*"1D
M<W`I+"<G*3L*"B`@("`@("`@+R\@=&AI<R!R96=E>"!D97!E;F1S(&]N('1H
M92!B=6EL9"!P;&%T9F]R;2!A;F0@='EP92!H879I;F<@8F5E;@H@("`@("`@
M("\O(&-O<G)E8W1L>2!I9&5N=&EF:65D(&%B;W9E+@H@("`@("`@("1R96=E
M>"`])R\N*C\A249<<RLB7"1<*$-&1UPI(EQS*ST]7',K*"(G+@H@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=P86-K86=E)UTN)UQS+5QS)RX*("`@("`@
M("`@("`@("`@("`@("`D<&QA=&9O<FTN)UQS)RX*("`@("`@("`@("`@("`@
M("`@("`D8G5I;&1T>7!E+B<B*2XJ/R<N"B`@("`@("`@("`@("`@("`@("`@
M)UPO;W5T.B(H+BH_*2(O:7,G.PH*("`@("`@("!I9B`H)&1S<'1E>'0@)B8@
M<')E9U]M871C:"@D<F5G97@L)&1S<'1E>'0L)&UA=&-H97,I*2!["B`@("`@
M("`@("`@("\O('=H870@=V4@9V5T(&)A8VL@:7,@82!R96QA=&EV92!P871H
M('1O('1H92!O=71P=70@9FEL92!I='-E;&8N"B`@("`@("`@("`@("1O=71F
M:6QE(#T@<F5A;'!A=&@H)&UA=&-H97-;,ETI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V]U;&0@
M;F]T(')E=')I979E(&]U='!U="!I;F9O<FUA=&EO;B!F<F]M("1D<W`N(BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("A`8V]P>2@D;W5T9FEL92P@(B1D:7(O
M)&]U="(I*2!["B`@("`@("`@("`@("1O=71F:6QE(#T@(B1D:7(O)&]U="([
M"B`@("`@("`@?0H*("`@("`@("`D8G5I;'1?9FEL97-;72`](&%R<F%Y*`H@
M("`@("`@("`@("`G9FEL92<@/3X@(B1O=71F:6QE(BP*("`@("`@("`@("`@
M)W!H<%]A<&DG(#T^("1T:&ES+3YP:'!?87!I7W9E<G-I;VXL"B`@("`@("`@
M("`@("=Z96YD7VUO9%]A<&DG(#T^("1T:&ES+3YZ96YD7VUO9'5L95]A<&E?
M;F\L"B`@("`@("`@("`@("=Z96YD7V5X=%]A<&DG(#T^("1T:&ES+3YZ96YD
M7V5X=&5N<VEO;E]A<&E?;F\L"B`@("`@("`@("`@("D["@H@("`@("`@(')E
M='5R;B`D8G5I;'1?9FEL97,["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![
M>WL@;7-D979#86QL8F%C:R@I"B`@("!F=6YC=&EO;B!M<V1E=D-A;&QB86-K
M*"1W:&%T+"`D9&%T82D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?9FER
M<W1L:6YE*0H@("`@("`@("`@("`D=&AI<RT^7V9I<G-T;&EN92`]("1D871A
M.PH@("`@("`@("1T:&ES+3Y?;&%S=&QI;F4@/2`D9&%T83L*("`@('T*("`@
M("\O('U]?0H*("`@("\O('M[>R!B=6EL9"@I"@H@("`@+RHJ"B`@("`@*B!"
M=6EL9"!A;B!E>'1E;G-I;VX@9G)O;2!S;W5R8V4N("!2=6YS(")P:'!I>F4B
M(&EN('1H92!S;W5R8V4*("`@("`J(&1I<F5C=&]R>2P@8G5T(&-O;7!I;&5S
M(&EN(&$@=&5M<&]R87)Y(&1I<F5C=&]R>0H@("`@("H@*"]V87(O=&UP+W!E
M87(M8G5I;&0M55-%4B]004-+04=%+59%4E-)3TXI+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1E<V-F:6QE('!A=&@@=&\@6$U,('!A8VMA9V4@
M9&5S8W)I<'1I;VX@9FEL90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M8V%L;&)A8VL@8V%L;&)A8VL@9G5N8W1I;VX@=7-E9"!T;R!R97!O<G0@;W5T
M<'5T+`H@("`@("H@<V5E(%!%05)?0G5I;&1E<CHZ7W)U;D-O;6UA;F0@9F]R
M(&1E=&%I;',*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&%N(&%R<F%Y
M(&]F(&%S<V]C:6%T:79E(&%R<F%Y<R!W:71H(&)U:6QT(&9I;&5S+`H@("`@
M("H@9F]R;6%T.@H@("`@("H@87)R87DH(&%R<F%Y*"`G9FEL92<@/3X@)R]P
M871H+W1O+V5X="YS;R<L"B`@("`@*B`@("`@("`@("`@("`@("=P:'!?87!I
M)R`]/B!965E934U$1"P*("`@("`J("`@("`@("`@("`@("`@)WIE;F1?;6]D
M7V%P:2<@/3X@65E964U-1$0L"B`@("`@*B`@("`@("`@("`@("`@("=Z96YD
M7V5X=%]A<&DG(#T^(%E965E-341$("DL"B`@("`@*B`@("`@("`@+BXN("D*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!S
M964@4$5!4E]"=6EL9&5R.CI?<G5N0V]M;6%N9`H@("`@("H@0'-E92!014%2
M7T-O;6UO;CHZ:6YF;T9R;VU$97-C<FEP=&EO;D9I;&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@8G5I;&0H)&1E<V-F:6QE+"`D8V%L;&)A8VL@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("A014%27T]3(#T](")7:6YD;W=S(BD@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]B=6EL9%]W:6XS,B@D9&5S8V9I;&4L
M)&-A;&QB86-K*3L*("`@("`@("!]"B`@("`@("`@:68@*%!%05)?3U,@(3T@
M)U5N:7@G*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B8G5I;&1I;F<@97AT96YS:6]N<R!N;W0@<W5P<&]R=&5D(&]N('1H:7,@
M<&QA=&9O<FTB*3L*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&EN9F\@/2`D=&AI<RT^:6YF;T9R;VU$97-C<FEP=&EO;D9I;&4H)&1E
M<V-F:6QE*2DI('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O.PH@("`@("`@
M('T*("`@("`@("`D9&ER(#T@9&ER;F%M92@D9&5S8V9I;&4I.PH@("`@("`@
M("1O;&1?8W=D(#T@9V5T8W=D*"D["B`@("`@("`@:68@*"%`8VAD:7(H)&1I
M<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C
M;W5L9"!N;W0@8VAD:7(@=&\@)&1I<B(I.PH@("`@("`@('T*("`@("`@("`D
M=F1I<B`]("(D:6YF;UMP86-K86=E72TD:6YF;UMV97)S:6]N72(["B`@("`@
M("`@:68@*&ES7V1I<B@D=F1I<BDI('L*("`@("`@("`@("`@8VAD:7(H)'9D
M:7(I.PH@("`@("`@('T*("`@("`@("`D9&ER(#T@9V5T8W=D*"D["B`@("`@
M("`@)'1H:7,M/FQO9R@R+"`B8G5I;&1I;F<@:6X@)&1I<B(I.PH@("`@("`@
M("1T:&ES+3YC=7)R96YT7V-A;&QB86-K(#T@)&-A;&QB86-K.PH@("`@("`@
M("1E<G(@/2`D=&AI<RT^7W)U;D-O;6UA;F0H(G!H<&EZ92(L(&%R<F%Y*"8D
M=&AI<RP@)W!H<&EZ94-A;&QB86-K)RDI.PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G(I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@
M("`@('T*("`@("`@("!I9B`H(21E<G(I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")@<&AP:7IE)R!F86EL960B*3L*("`@("`@
M("!]"@H@("`@("`@("\O('M[>R!S=&%R="!O9B!I;G1E<F%C=&EV92!P87)T
M"B`@("`@("`@)&-O;F9I9W5R95]C;VUM86YD(#T@(B1D:7(O8V]N9FEG=7)E
M(CL*("`@("`@("!I9B`H:7-S970H)&EN9F];)V-O;F9I9W5R95]O<'1I;VYS
M)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=C;VYF:6=U<F5?
M;W!T:6]N<R==(&%S("1O*2!["B`@("`@("`@("`@("`@("!L:7-T*"1R*2`]
M("1T:&ES+3YU:2T^=7-E<D1I86QO9R@G8G5I;&0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&];
M)W!R;VUP="==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=T97AT)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2A`)&];
M)V1E9F%U;'0G72DI.PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D;ULG
M;F%M92==+"`P+"`U*2`]/2`G=VET:"TG("8F"B`@("`@("`@("`@("`@("`@
M("`@*"1R(#T]("=Y97,G('Q\("1R(#T]("=A=71O9&5T96-T)RDI('L*("`@
M("`@("`@("`@("`@("`@("`D8V]N9FEG=7)E7V-O;6UA;F0@+CT@(B`M+21O
M6VYA;65=(CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&-O;F9I9W5R95]C;VUM86YD("X]("(@+2TD;UMN86UE73TD
M<B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@+R\@?7U](&5N9"!O9B!I;G1E<F%C=&EV92!P87)T"@H@("`@
M("`@("\O($9)6$U%(&UA:V4@8V]N9FEG=7)A8FQE"B`@("`@("`@:68H(21U
M<V5R/6=E=&5N=B@G55-%4B<I*7L*("`@("`@("`@("`@)'5S97(])V1E9F%U
M;'1U<V5R)SL*("`@("`@("!]"B`@("`@("`@)&)U:6QD7V)A<V5D:7(@/2`B
M+W9A<B]T;7`O<&5A<BUB=6EL9"TD=7-E<B(["B`@("`@("`@)&)U:6QD7V1I
M<B`]("(D8G5I;&1?8F%S961I<B\D:6YF;UMP86-K86=E72TD:6YF;UMV97)S
M:6]N72(["B`@("`@("`@)'1H:7,M/FQO9R@Q+"`B8G5I;&1I;F<@:6X@)&)U
M:6QD7V1I<B(I.PH@("`@("`@(&EF("AI<U]D:7(H)&)U:6QD7V1I<BDI('L*
M("`@("`@("`@("`@4WES=&5M.CIR;2@B+7)F("1B=6EL9%]D:7(B*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"%3>7-T96TZ.FUK1&ER*"(M<"`D8G5I;&1?
M9&ER(BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")C;W5L9"!N;W0@8W)E871E(&)U:6QD(&1I<CH@)&)U:6QD7V1I<B(I.PH@
M("`@("`@('T*("`@("`@("`D=&AI<RT^861D5&5M<$9I;&4H)&)U:6QD7V1I
M<BD["B`@("`@("`@:68@*&=E=&5N=B@G34%+12<I*2!["B`@("`@("`@("`@
M("1M86ME7V-O;6UA;F0@/2!G971E;G8H)TU!2T4G*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D;6%K95]C;VUM86YD(#T@)VUA:V4G.PH@("`@
M("`@('T*("`@("`@("`D=&]?<G5N(#T@87)R87DH"B`@("`@("`@("`@("1C
M;VYF:6=U<F5?8V]M;6%N9"P*("`@("`@("`@("`@)&UA:V5?8V]M;6%N9"P*
M("`@("`@("`@("`@*3L*("`@("`@("!I9B`H(4!C:&1I<B@D8G5I;&1?9&ER
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O
M=6QD(&YO="!C:&1I<B!T;R`D8G5I;&1?9&ER(BD["B`@("`@("`@?0H@("`@
M("`@(&9O<F5A8V@@*"1T;U]R=6X@87,@)&-M9"D@>PH@("`@("`@("`@("`D
M97)R(#T@)'1H:7,M/E]R=6Y#;VUM86YD*"1C;60L("1C86QL8F%C:RD["B`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2!["B`@("`@("`@
M("`@("`@("!C:&1I<B@D;VQD7V-W9"D["B`@("`@("`@("`@("`@("!R971U
M<FX@)&5R<CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21E<G(I
M('L*("`@("`@("`@("`@("`@(&-H9&ER*"1O;&1?8W=D*3L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8"1C;60G(&9A:6QE
M9"(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A*"1D
M<"`](&]P96YD:7(H(FUO9'5L97,B*2DI('L*("`@("`@("`@("`@8VAD:7(H
M)&]L9%]C=V0I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(FYO(&!M;V1U;&5S)R!D:7)E8W1O<GD@9F]U;F0B*3L*("`@("`@("!]
M"B`@("`@("`@)&)U:6QT7V9I;&5S(#T@87)R87DH*3L*("`@("`@("!W:&EL
M92`H)&5N="`](')E861D:7(H)&1P*2D@>PH@("`@("`@("`@("!I9B`H)&5N
M='LP?2`]/2`G+B<@?'P@<W5B<W1R*"1E;G0L("TS*2`]/2`G+FQA)RD@>PH@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@+R\@:&%R=F5S="$*("`@("`@("`@("`@:68@*$!C;W!Y*")M;V1U
M;&5S+R1E;G0B+"`B)&1I<B\D96YT(BDI('L*("`@("`@("`@("`@("`@("1B
M=6EL=%]F:6QE<UM=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V9I
M;&4G(#T^("(D9&ER+R1E;G0B+`H@("`@("`@("`@("`@("`@("`@("=P:'!?
M87!I)R`]/B`D=&AI<RT^<&AP7V%P:5]V97)S:6]N+`H@("`@("`@("`@("`@
M("`@("`@("=Z96YD7VUO9%]A<&DG(#T^("1T:&ES+3YZ96YD7VUO9'5L95]A
M<&E?;F\L"B`@("`@("`@("`@("`@("`@("`@)WIE;F1?97AT7V%P:2<@/3X@
M)'1H:7,M/GIE;F1?97AT96YS:6]N7V%P:5]N;RP*("`@("`@("`@("`@("`@
M("`@("`I.PH*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@(B1E;G0@
M8V]P:65D('1O("1D:7(O)&5N="(I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@8VAD:7(H)&]L9%]C=V0I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F86EL960@8V]P>6EN9R`D
M96YT('1O("1D:7(B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!C;&]S961I<B@D9'`I.PH@("`@("`@(&-H9&ER*"1O;&1?8W=D*3L*("`@
M("`@("!R971U<FX@)&)U:6QT7V9I;&5S.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('!H<&EZ94-A;&QB86-K*"D*"B`@("`O*BH*("`@("`J($UE
M<W-A9V4@8V%L;&)A8VL@9G5N8W1I;VX@=7-E9"!W:&5N(')U;FYI;F<@=&AE
M(")P:'!I>F4B"B`@("`@*B!P<F]G<F%M+B`@17AT<F%C=',@=&AE($%022!N
M=6UB97)S('5S960N("!)9VYO<F5S(&]T:&5R(&UE<W-A9V4*("`@("`J('1Y
M<&5S('1H86X@(F-M9&]U='!U="(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=VAA="!T:&4@='EP92!O9B!M97-S86=E"B`@("`@*B!`<&%R86T@
M;6EX960@)&1A=&$@=&AE(&UE<W-A9V4*("`@("`J"B`@("`@*B!`<F5T=7)N
M('9O:60*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!P:'!I>F5#86QL8F%C:R@D=VAA="P@)&1A=&$I"B`@("![
M"B`@("`@("`@:68@*"1W:&%T("$]("=C;61O=71P=70G*2!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/FQO9R@Q+"!R
M=')I;2@D9&%T82DI.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O66]U('-H
M;W5L9"!U<&1A=&4@>6]U<B`N86-L;V-A;"YM-"\G+"`D9&%T82DI('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@("`@("`D;6%T8VAE<R`]
M(&%R<F%Y*"D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',K*%Q36UXZ
M72LI.EQS*RA<9'LX?2DO)RP@)&1A=&$L("1M871C:&5S*2D@>PH@("`@("`@
M("`@("`D;65M8F5R(#T@<')E9U]R97!L86-E*"<O6UYA+7I=+R<L("=?)RP@
M<W1R=&]L;W=E<B@D;6%T8VAE<ULQ72DI.PH@("`@("`@("`@("`D87!I;F\@
M/2`H:6YT*21M871C:&5S6S)=.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/B1M96UB97(I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^)&UE;6)E
M<B`]("1A<&EN;SL*("`@("`@("`@("`@("`@("\O)&US9R`]('-P<FEN=&8H
M(B4M,C)S(#H@)60B+"`D;6%T8VAE<ULQ72P@)&%P:6YO*3L*("`@("`@("`@
M("`@("`@("\O)'1H:7,M/FQO9R@Q+"`D;7-G*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?<G5N0V]M
M;6%N9"@I"@H@("`@+RHJ"B`@("`@*B!2=6X@86X@97AT97)N86P@8V]M;6%N
M9"P@=7-I;F<@82!M97-S86=E(&-A;&QB86-K('1O(')E<&]R=`H@("`@("H@
M;W5T<'5T+B`@5&AE(&-O;6UA;F0@=VEL;"!B92!R=6X@=&AR;W5G:"!P;W!E
M;B!A;F0@;W5T<'5T(&ES"B`@("`@*B!R97!O<G1E9"!F;W(@979E<GD@;&EN
M92!W:71H(&$@(F-M9&]U='!U="(@;65S<V%G92!W:71H('1H90H@("`@("H@
M;&EN92!S=')I;F<L(&EN8VQU9&EN9R!N97=L:6YE<RP@87,@<&%Y;&]A9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VUM86YD('1H92!C;VUM
M86YD('1O(')U;@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D8V%L;&)A
M8VL@*&]P=&EO;F%L*2!F=6YC=&EO;B!T;R!U<V4@87,@;65S<V%G90H@("`@
M("H@8V%L;&)A8VL*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@=VAE=&AE
M<B!T:&4@8V]M;6%N9"!W87,@<W5C8V5S<V9U;"`H97AI="!C;V1E(#`*("`@
M("`J(&UE86YS('-U8V-E<W,L(&%N>2!O=&AE<B!M96%N<R!F86EL=7)E*0H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<G5N0V]M;6%N9"@D8V]M;6%N9"P@)&-A;&QB86-K(#T@;G5L;"D*
M("`@('L*("`@("`@("`D=&AI<RT^;&]G*#$L(")R=6YN:6YG.B`D8V]M;6%N
M9"(I.PH@("`@("`@("1P<"`]($!P;W!E;B@B)&-O;6UA;F0@,CXF,2(L(")R
M(BD["B`@("`@("`@:68@*"$D<'`I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")F86EL960@=&\@<G5N(&`D8V]M;6%N9"<B*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1C86QL8F%C:R`F)B`D8V%L;&)A8VM;
M,%TM/F1E8G5G(#T](#$I('L*("`@("`@("`@("`@)&]L9&1B9R`]("1C86QL
M8F%C:ULP72T^9&5B=6<["B`@("`@("`@("`@("1C86QL8F%C:ULP72T^9&5B
M=6<@/2`R.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*"1L:6YE(#T@9F=E
M=',H)'!P+"`Q,#(T*2D@>PH@("`@("`@("`@("!I9B`H)&-A;&QB86-K*2![
M"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=C
M;61O=71P=70G+"`D;&EN92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^;&]G*#(L(')T<FEM*"1L:6YE*2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1C86QL8F%C:R`F)B!I
M<W-E="@D;VQD9&)G*2D@>PH@("`@("`@("`@("`D8V%L;&)A8VM;,%TM/F1E
M8G5G(#T@)&]L9&1B9SL*("`@("`@("!]"B`@("`@("`@)&5X:71C;V1E(#T@
M0'!C;&]S92@D<'`I.PH@("`@("`@(')E='5R;B`H)&5X:71C;V1E(#T](#`I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&QO9R@I"@H@("`@9G5N
M8W1I;VX@;&]G*"1L979E;"P@)&US9RD*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/F-U<G)E;G1?8V%L;&)A8VLI('L*("`@("`@("`@("`@:68@*"1T:&ES
M+3YD96)U9R`^/2`D;&5V96PI('L*("`@("`@("`@("`@("`@(&-A;&Q?=7-E
M<E]F=6YC*"1T:&ES+3YC=7)R96YT7V-A;&QB86-K+"`G;W5T<'5T)RP@)&US
M9RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@4$5!4E]#;VUM;VXZ.FQO9R@D;&5V96PL("1M
M<V<I.PH@("`@?0H*("`@("\O('U]?0I]"@H_/@HN+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(N<&AP````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3<S,#4`,3`T,3<S-C,P,#8`,#(P
M-30T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@
M("`@("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@36%R=&EN
M($IA;G-E;B`\;6I`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!);G-T86QL97(N<&AP+'8@,2XQ-#<@,C`P-"\P,2\P."`Q-SHS
M,SHQ,B!S;FEP97(@17AP("0*"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN
M<&AP)SL*<F5Q=6ER95]O;F-E("=014%2+U)E9VES=')Y+G!H<"<["G)E<75I
M<F5?;VYC92`G4$5!4B]$97!E;F1E;F-Y+G!H<"<["G)E<75I<F5?;VYC92`G
M4$5!4B]$;W=N;&]A9&5R+G!H<"<["G)E<75I<F5?;VYC92`G4WES=&5M+G!H
M<"<["@ID969I;F4H)U!%05)?24Y35$%,3$527T]+)RP@("`@("`@,2D["F1E
M9FEN92@G4$5!4E])3E-404Q,15)?1D%)3$5$)RP@("`P*3L*9&5F:6YE*"=0
M14%27TE.4U1!3$Q%4E]32TE04$5$)RP@+3$I.PID969I;F4H)U!%05)?24Y3
M5$%,3$527T524D]27TY/7U!2149?4U1!5$4G+"`R*3L*"B\J*@H@*B!!9&UI
M;FES=')A=&EO;B!C;&%S<R!U<V5D('1O(&EN<W1A;&P@4$5!4B!P86-K86=E
M<R!A;F0@;6%I;G1A:6X@=&AE"B`J(&EN<W1A;&QE9"!P86-K86=E(&1A=&%B
M87-E+@H@*@H@*B!43T1/.@H@*B`@("T@0VAE8VL@9&5P96YD96YC:65S(&)R
M96%K(&]N('!A8VMA9V4@=6YI;G-T86QL("AW:&5N(&YO(&9O<F-E(&=I=F5N
M*0H@*B`@("T@861D(&$@9W5E<W-);G-T86QL1&5S="@I(&UE=&AO9"!W:71H
M('1H92!C;V1E(&9R;VT@7VEN<W1A;&Q&:6QE*"D@86YD"B`J("`@("!U<V4@
M=&AA="!M971H;V0@:6X@4F5G:7-T<GDZ.E]R96)U:6QD1FEL94UA<"@I("8@
M0V]M;6%N9%]296=I<W1R>3HZ9&],:7-T*"DL"B`J("`@("!O=&AE<G,N+@H@
M*@H@*B!`<VEN8V4@4$A0(#0N,"XR"B`J($!A=71H;W(@4W1I9R!"86MK96X@
M/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R($UA<G1I;B!*86YS96X@/&UJ0'!H
M<"YN970^"B`J($!A=71H;W(@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@H@*B\*8VQA<W,@4$5!4E]);G-T86QL97(@97AT96YD<R!014%27T1O=VYL
M;V%D97(*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH@;F%M92!O
M9B!T:&4@<&%C:V%G92!D:7)E8W1O<GDL(&9O<B!E>&%M<&QE($9O;RTQ+C`*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&MG9&ER.PH*
M("`@("\J*B!D:7)E8W1O<GD@=VAE<F4@4$A0(&-O9&4@9FEL97,@9V\*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP9&ER.PH*("`@
M("\J*B!D:7)E8W1O<GD@=VAE<F4@4$A0(&5X=&5N<VEO;B!F:6QE<R!G;PH@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1E>'1D:7(["@H@
M("`@+RHJ(&1I<F5C=&]R>2!W:&5R92!D;V-U;65N=&%T:6]N(&=O97,*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&]C9&ER.PH*("`@
M("\J*B!I;G-T86QL871I;VX@<F]O="!D:7)E8W1O<GD@*&%L82!02%`G<R!)
M3E-404Q,7U)/3U0@;W(*("`@("`J(&%U=&]M86ME)W,@1$535$1)4@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1I;G-T86QL<F]O="`]
M("<G.PH*("`@("\J*B!D96)U9R!L979E;`H@("`@("H@0'9A<B!I;G0*("`@
M("`J+PH@("`@=F%R("1D96)U9R`](#$["@H@("`@+RHJ('1E;7!O<F%R>2!D
M:7)E8W1O<GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M=&UP9&ER.PH*("`@("\J*B!014%27U)E9VES=')Y(&]B:F5C="!U<V5D(&)Y
M('1H92!I;G-T86QL97(*("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*("`@
M('9A<B`D<F5G:7-T<GD["@H@("`@+RHJ($QI<W0@;V8@9FEL92!T<F%N<V%C
M=&EO;G,@<75E=65D(&9O<B!A;B!I;G-T86QL+W5P9W)A9&4O=6YI;G-T86QL
M+@H@("`@("H*("`@("`J("!&;W)M870Z"B`@("`@*B`@("!A<G)A>2@*("`@
M("`J("`@("`@,"`]/B!A<G)A>2@B<F5N86UE(#T^(&%R<F%Y*")F<F]M+69I
M;&4B+"`B=&\M9FEL92(I*2P*("`@("`J("`@("`@,2`]/B!A<G)A>2@B9&5L
M971E(B`]/B!A<G)A>2@B9FEL92UT;RUD96QE=&4B*2DL"B`@("`@*B`@("`@
M("XN+@H@("`@("H@("`@*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1F:6QE7V]P97)A=&EO;G,@/2!A<G)A>2@I.PH*("`@
M("\O('U]?0H*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@
M("H@4$5!4E]);G-T86QL97(@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&]B:F5C="`D=6D@=7-E<B!I;G1E<F9A8V4@;V)J96-T("AI;G-T
M86YC92!O9B!014%27T9R;VYT96YD7RHI"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@4$5!4E]);G-T86QL97(H
M)B1U:2D*("`@('L*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6]N*"D["B`@
M("`@("`@)'1H:7,M/G-E=$9R;VYT96YD3V)J96-T*"1U:2D["B`@("`@("`@
M)'1H:7,M/F1E8G5G(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD[
M"B`@("`@("`@+R\D=&AI<RT^<F5G:7-T<GD@/2`F;F5W(%!%05)?4F5G:7-T
M<GDH)'1H:7,M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RDI.PH@("`@?0H*("`@
M("\O('U]?0H*("`@("\O('M[>R!?9&5L971E4&%C:V%G949I;&5S*"D*"B`@
M("`O*BH*("`@("`J($1E;&5T92!A('!A8VMA9V4G<R!I;G-T86QL960@9FEL
M97,L(&1O97,@;F]T(')E;6]V92!E;7!T>2!D:7)E8W1O<FEE<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P86-K86=E('!A8VMA9V4@;F%M90H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L(&]R
M(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96QE=&5086-K86=E
M1FEL97,H)'!A8VMA9V4I"B`@("!["B`@("`@("`@:68@*"%S=')L96XH)'!A
M8VMA9V4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B3F\@<&%C:V%G92!T;R!U;FEN<W1A;&P@9VEV96XB*3L*("`@("`@("!]
M"B`@("`@("`@)&9I;&5L:7-T(#T@)'1H:7,M/G)E9VES=')Y+3YP86-K86=E
M26YF;R@D<&%C:V%G92P@)V9I;&5L:7-T)RD["B`@("`@("`@:68@*"1F:6QE
M;&ES="`]/2!N=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B)'!A8VMA9V4@;F]T(&EN<W1A;&QE9"(I.PH@("`@("`@('T*
M("`@("`@("!F;W)E86-H("@D9FEL96QI<W0@87,@)&9I;&4@/3X@)'!R;W!S
M*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D<')O<'-;)VEN<W1A;&QE9%]A
M<R==*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'!A=&@@/2`D=&AI<RT^7W!R97!E;F10871H*"1P
M<F]P<ULG:6YS=&%L;&5D7V%S)UTL("1T:&ES+3YI;G-T86QL<F]O="D["B`@
M("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*"=D96QE=&4G+"!A
M<G)A>2@D<&%T:"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?:6YS=&%L;$9I;&4H*0H*
M("`@("\J*@H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE;F%M90H@("`@("H@
M0'!A<F%M(&%R<F%Y(&%T=')I8G5T97,@9G)O;2`\9FEL93X@=&%G(&EN('!A
M8VMA9V4N>&UL"B`@("`@*B!`<&%R86T@<W1R:6YG('!A=&@@=&\@:6YS=&%L
M;"!T:&4@9FEL92!I;@H@("`@("H@0'!A<F%M(&%R<F%Y(&]P=&EO;G,@9G)O
M;2!C;VUM86YD+6QI;F4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?:6YS=&%L;$9I;&4H)&9I;&4L("1A='1S+"`D=&UP
M7W!A=&@L("1O<'1I;VYS*0H@("`@>PH@("`@("`@("\O('M[>R!R971U<FX@
M:68@=&AI<R!F:6QE(&ES(&UE86YT(&9O<B!A;F]T:&5R('!L871F;W)M"B`@
M("`@("`@<W1A=&EC("1O<SL*("`@("`@("!I9B`H:7-S970H)&%T='-;)W!L
M871F;W)M)UTI*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D;W,I*2!["B`@
M("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@(D]3+T=U97-S+G!H<"(["B`@
M("`@("`@("`@("`@("`D;W,@/2!N97<@3U-?1W5E<W,H*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(21O<RT^;6%T8VA3:6=N871U<F4H)&%T
M='-;)W!L871F;W)M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M*#,L(")S:VEP<&5D("1F:6QE("AM96%N="!F;W(@)&%T='-;<&QA=&9O<FU=
M+"!W92!A<F4@(BXD;W,M/F=E=%-I9VYA='5R92@I+B(I(BD["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4E])3E-404Q,15)?4TM)4%!%1#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!]?7T*"B`@("`@("`@+R\@
M>WM[(&%S<V5M8FQE('1H92!D97-T:6YA=&EO;B!P871H<PH@("`@("`@('-W
M:71C:"`H)&%T='-;)W)O;&4G72D@>PH@("`@("`@("`@("!C87-E("=D;V,G
M.@H@("`@("`@("`@("!C87-E("=D871A)SH*("`@("`@("`@("`@8V%S92`G
M=&5S="<Z"B`@("`@("`@("`@("`@("`D9&5S=%]D:7(@/2`D=&AI<RT^8V]N
M9FEG+3YG970H)&%T='-;)W)O;&4G72`N("=?9&ER)RD@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4B`N("1T:&ES
M+3YP:V=I;F9O6R=P86-K86=E)UT["B`@("`@("`@("`@("`@("!U;G-E="@D
M871T<ULG8F%S96EN<W1A;&QD:7(G72D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`G97AT)SH*("`@("`@("`@("`@8V%S92`G
M<&AP)SH*("`@("`@("`@("`@("`@("1D97-T7V1I<B`]("1T:&ES+3YC;VYF
M:6<M/F=E="@D871T<ULG<F]L92==("X@)U]D:7(G*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=S8W)I<'0G.@H@("`@("`@
M("`@("`@("`@)&1E<W1?9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=B:6Y?
M9&ER)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92`G<W)C)SH*("`@("`@("`@("`@8V%S92`G97AT<W)C)SH*("`@("`@("`@
M("`@("`@("1T:&ES+3YS;W5R8V5?9FEL97,K*SL*("`@("`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B26YV86QI9"!R;VQE(&`D871T
M<UMR;VQE72<@9F]R(&9I;&4@)&9I;&4B*3L*("`@("`@("!]"B`@("`@("`@
M)'-A=F5?9&5S=&1I<B`]("1D97-T7V1I<CL*("`@("`@("!I9B`H(65M<'1Y
M*"1A='1S6R=B87-E:6YS=&%L;&1I<B==*2D@>PH@("`@("`@("`@("`D9&5S
M=%]D:7(@+CT@1$E214-43U)97U-%4$%2051/4B`N("1A='1S6R=B87-E:6YS
M=&%L;&1I<B==.PH@("`@("`@('T*("`@("`@("!I9B`H9&ER;F%M92@D9FEL
M92D@(3T@)RXG("8F(&5M<'1Y*"1A='1S6R=I;G-T86QL+6%S)UTI*2!["B`@
M("`@("`@("`@("1D97-T7V1I<B`N/2!$25)%0U1/4EE?4T5005)!5$]2("X@
M9&ER;F%M92@D9FEL92D["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D
M871T<ULG:6YS=&%L;"UA<R==*2D@>PH@("`@("`@("`@("`D9&5S=%]F:6QE
M(#T@)&1E<W1?9&ER("X@1$E214-43U)97U-%4$%2051/4B`N(&)A<V5N86UE
M*"1F:6QE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&5S=%]F
M:6QE(#T@)&1E<W1?9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1A='1S
M6R=I;G-T86QL+6%S)UT["B`@("`@("`@?0H@("`@("`@("1O<FEG7V9I;&4@
M/2`D=&UP7W!A=&@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4["@H@
M("`@("`@("\O($-L96%N('5P('1H92!$25)%0U1/4EE?4T5005)!5$]2(&UE
M<W,*("`@("`@("`D9',R(#T@1$E214-43U)97U-%4$%2051/4B`N($1)4D5#
M5$]265]315!!4D%43U(["B`@("`@("`@;&ES="@D9&5S=%]F:6QE+"`D;W)I
M9U]F:6QE*2`]('!R96=?<F5P;&%C92AA<G)A>2@G(5Q<7%PK(2<L("<A+R$G
M+"`B(21D<S(K(2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"1D97-T7V9I;&4L("1O<FEG7V9I;&4I*3L*("`@("`@("`D
M:6YS=&%L;&5D7V%S(#T@)&1E<W1?9FEL93L*("`@("`@("`D9FEN86Q?9&5S
M=%]F:6QE(#T@)'1H:7,M/E]P<F5P96YD4&%T:"@D9&5S=%]F:6QE+"`D=&AI
M<RT^:6YS=&%L;')O;W0I.PH@("`@("`@("1D97-T7V1I<B`](&1I<FYA;64H
M)&9I;F%L7V1E<W1?9FEL92D["B`@("`@("`@)&1E<W1?9FEL92`]("1D97-T
M7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`G+G1M<"<@+B!B87-E;F%M
M92@D9FEN86Q?9&5S=%]F:6QE*3L*("`@("`@("`O+R!]?7T*"B`@("`@("`@
M:68@*"%`:7-?9&ER*"1D97-T7V1I<BDI('L*("`@("`@("`@("`@:68@*"$D
M=&AI<RT^;6M$:7)(:65R*"1D97-T7V1I<BDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O(&UK9&ER("1D
M97-T7V1I<B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&UK9&ER("1D97-T7V1I<B(I
M.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&%T='-;)W)E<&QA8V5M
M96YT<R==*2D@>PH@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1O<FEG
M7V9I;&4I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(F9I;&4@9&]E<R!N;W0@97AI<W0B+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%
M1"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%`8V]P>2@D;W)I
M9U]F:6QE+"`D9&5S=%]F:6QE*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")F86EL960@=&\@=W)I=&4@)&1E<W1?9FEL
M92(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M4$5!4E])3E-404Q,15)?1D%)3$5$*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^;&]G*#,L("(K(&-P("1O<FEG7V9I;&4@)&1E<W1?9FEL
M92(I.PH@("`@("`@("`@("!I9B`H:7-S970H)&%T='-;)VUD-7-U;2==*2D@
M>PH@("`@("`@("`@("`@("`@)&UD-7-U;2`](&UD-5]F:6QE*"1D97-T7V9I
M;&4I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+R\@>WM[(&9I;&4@=VET:"!R97!L86-E;65N=',*("`@("`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D;W)I9U]F:6QE*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F:6QE(&1O97,@;F]T(&5X
M:7-T(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%27TE.4U1!3$Q%4E]&04E,140I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1F<"`](&9O<&5N*"1O<FEG7V9I;&4L(")R(BD["B`@("`@("`@
M("`@("1C;VYT96YT<R`](&9R96%D*"1F<"P@9FEL97-I>F4H)&]R:6=?9FEL
M92DI.PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1A='1S6R=M9#5S=6TG72DI('L*("`@("`@("`@("`@("`@("1M
M9#5S=6T@/2!M9#4H)&-O;G1E;G1S*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<W5B<W1?9G)O;2`]("1S=6)S=%]T;R`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1A='1S6R=R97!L86-E;65N=',G72!A<R`D82D@
M>PH@("`@("`@("`@("`@("`@)'1O(#T@)R<["B`@("`@("`@("`@("`@("!I
M9B`H)&%;)W1Y<&4G72`]/2`G<&AP+6-O;G-T)RD@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EMA+7HP+3E?72LD+VDG+"`D85LG
M=&\G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@979A;"@B7"1T;R`]
M("1A6W1O73LB*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")I;G9A;&ED('!H
M<"UC;VYS="!R97!L86-E;65N=#H@)&%;=&]=(BD["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS96EF("@D85LG='EP92==(#T]("=P96%R+6-O
M;F9I9R<I('L*("`@("`@("`@("`@("`@("`@("`D=&\@/2`D=&AI<RT^8V]N
M9FEG+3YG970H)&%;)W1O)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]N=6QL*"1T;RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9R@P+"`B:6YV86QI9"!P96%R+6-O;F9I9R!R97!L86-E;65N=#H@)&%;
M=&]=(BD["B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M85LG='EP92==(#T]("=P86-K86=E+6EN9F\G*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YP:V=I;F9O6R1A6R=T;R==72D@)B8@
M:7-?<W1R:6YG*"1T:&ES+3YP:V=I;F9O6R1A6R=T;R==72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1O(#T@)'1H:7,M/G!K9VEN9F];)&%;)W1O
M)UU=.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@(FEN=F%L:60@<&%C:V%G92UI
M;F9O(')E<&QA8V5M96YT.B`D85MT;UTB*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1T;RDI
M('L*("`@("`@("`@("`@("`@("`@("`D<W5B<W1?9G)O;5M=(#T@)&%;)V9R
M;VTG73L*("`@("`@("`@("`@("`@("`@("`D<W5B<W1?=&];72`]("1T;SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^;&]G*#,L(")D;VEN9R`B+G-I>F5O9B@D<W5B<W1?9G)O;2DN(B!S
M=6)S=&ET=71I;VXH<RD@9F]R("1F:6YA;%]D97-T7V9I;&4B*3L*("`@("`@
M("`@("`@:68@*'-I>F5O9B@D<W5B<W1?9G)O;2DI('L*("`@("`@("`@("`@
M("`@("1C;VYT96YT<R`]('-T<E]R97!L86-E*"1S=6)S=%]F<F]M+"`D<W5B
M<W1?=&\L("1C;VYT96YT<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'=P(#T@0&9O<&5N*"1D97-T7V9I;&4L(")W8B(I.PH@("`@("`@("`@("!I
M9B`H(6ES7W)E<V]U<F-E*"1W<"DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O(&-R96%T92`D9&5S=%]F
M:6QE.B`D<&AP7V5R<F]R;7-G(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A9G=R:71E*"1W<"P@)&-O;G1E
M;G1S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")F86EL960@=W)I=&EN9R!T;R`D9&5S=%]F:6QE.B`D<&AP7V5R<F]R
M;7-G(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%27TE.4U1!3$Q%4E]&04E,140I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&9C;&]S92@D=W`I.PH@("`@("`@("`@("`O+R!]?7T*("`@("`@
M("!]"B`@("`@("`@+R\@>WM[(&-H96-K('1H92!M9#4*("`@("`@("!I9B`H
M:7-S970H)&UD-7-U;2DI('L*("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)&UD-7-U;2D@/3T@<W1R=&]L;W=E<B@D871T<ULG;60U<W5M)UTI*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G*#(L(")M9#5S=6T@;VLZ("1F:6YA
M;%]D97-T7V9I;&4B*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9F]R8V4G72DI('L*("`@("`@
M("`@("`@("`@("`@("`O+R!D96QE=&4@=&AE(&9I;&4*("`@("`@("`@("`@
M("`@("`@("!`=6YL:6YK*"1D97-T7V9I;&4I.PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8F%D(&UD-7-U;2!F;W(@
M9FEL92`D9FEN86Q?9&5S=%]F:6QE(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@P+"`B=V%R;FEN9R`Z(&)A9"!M9#5S=6T@9F]R(&9I
M;&4@)&9I;F%L7V1E<W1?9FEL92(I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O('U]?0H@("`@("`@("\O
M('M[>R!S970@9FEL92!P97)M:7-S:6]N<PH@("`@("`@(&EF("@A3U-?5TE.
M1$]74RD@>PH@("`@("`@("`@("!I9B`H)&%T='-;)W)O;&4G72`]/2`G<V-R
M:7!T)RD@>PH@("`@("`@("`@("`@("`@)&UO9&4@/2`P-S<W("8@?BAI;G0I
M;V-T9&5C*"1T:&ES+3YC;VYF:6<M/F=E="@G=6UA<VLG*2D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&-H;6]D("MX("1D97-T7V9I;&4B
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M;V1E
M(#T@,#8V-B`F('XH:6YT*6]C=&1E8R@D=&AI<RT^8V]N9FEG+3YG970H)W5M
M87-K)RDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YA9&1&
M:6QE3W!E<F%T:6]N*")C:&UO9"(L(&%R<F%Y*"1M;V1E+"`D9&5S=%]F:6QE
M*2D["B`@("`@("`@("`@(&EF("@A0&-H;6]D*"1D97-T7V9I;&4L("1M;V1E
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B9F%I;&5D('1O
M(&-H86YG92!M;V1E(&]F("1D97-T7V9I;&4B*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("`O+R!]?7T*("`@("`@("`D=&AI<RT^861D1FEL
M94]P97)A=&EO;B@B<F5N86UE(BP@87)R87DH)&1E<W1?9FEL92P@)&9I;F%L
M7V1E<W1?9FEL92DI.PH@("`@("`@("\O(%-T;W)E('1H92!F=6QL('!A=&@@
M=VAE<F4@=&AE(&9I;&4@=V%S(&EN<W1A;&QE9"!F;W(@96%S>2!U;FES=&%L
M;`H@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*")I;G-T86QL961?
M87,B+"!A<G)A>2@D9FEL92P@)&EN<W1A;&QE9%]A<RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<V%V95]D97-T9&ER+"!D:7)N86UE*'-U
M8G-T<B@D9&5S=%]F:6QE+"!S=')L96XH)'-A=F5?9&5S=&1I<BDI*2DI.PH*
M("`@("`@("`O+R1T:&ES+3YL;V<H,BP@(FEN<W1A;&QE9#H@)&1E<W1?9FEL
M92(I.PH@("`@("`@(')E='5R;B!014%27TE.4U1!3$Q%4E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!A9&1&:6QE3W!E<F%T:6]N*"D*"B`@
M("`O*BH*("`@("`J($%D9"!A(&9I;&4@;W!E<F%T:6]N('1O('1H92!C=7)R
M96YT(&9I;&4@=')A;G-A8W1I;VXN"B`@("`@*@H@("`@("H@0'-E92!S=&%R
M=$9I;&54<F%N<V%C=&EO;B@I"B`@("`@*B!`=F%R('-T<FEN9R`D='EP92!4
M:&ES(&-A;B!B92!O;F4@;V8Z"B`@("`@*B`@("`M(')E;F%M93H@(')E;F%M
M92!A(&9I;&4@*"1D871A(&AA<R`R('9A;'5E<RD*("`@("`J("`@("T@8VAM
M;V0Z("`@8VAA;F=E('!E<FUI<W-I;VYS(&]N(&$@9FEL92`H)&1A=&$@:&%S
M(#(@=F%L=65S*0H@("`@("H@("`@+2!D96QE=&4Z("!D96QE=&4@82!F:6QE
M("@D9&%T82!H87,@,2!V86QU92D*("`@("`J("`@("T@<FUD:7(Z("`@9&5L
M971E(&$@9&ER96-T;W)Y(&EF(&5M<'1Y("@D9&%T82!H87,@,2!V86QU92D*
M("`@("`J("`@("T@:6YS=&%L;&5D7V%S.B!M87)K(&$@9FEL92!A<R!I;G-T
M86QL960@*"1D871A(&AA<R`T('9A;'5E<RDN"B`@("`@*B!`=F%R(&%R<F%Y
M("1D871A($9O<B!A;&P@9FEL92!O<&5R871I;VYS+"!T:&ES(&%R<F%Y(&UU
M<W0@8V]N=&%I;B!T:&4*("`@("`J("`@(&9U;&P@<&%T:"!T;R!T:&4@9FEL
M92!O<B!D:7)E8W1O<GD@=&AA="!I<R!B96EN9R!O<&5R871E9"!O;BX@($9O
M<@H@("`@("H@("`@=&AE(')E;F%M92!C;VUM86YD+"!T:&4@9FER<W0@<&%R
M86UE=&5R(&UU<W0@8F4@=&AE(&9I;&4@=&\@<F5N86UE+`H@("`@("H@("`@
M=&AE('-E8V]N9"!I=',@;F5W(&YA;64N"B`@("`@*@H@("`@("H@("`@5&AE
M(&EN<W1A;&QE9%]A<R!O<&5R871I;VX@8V]N=&%I;G,@-"!E;&5M96YT<R!I
M;B!T:&ES(&]R9&5R.@H@("`@("H@("`@,2X@1FEL96YA;64@87,@;&ES=&5D
M(&EN('1H92!F:6QE;&ES="!E;&5M96YT(&9R;VT@<&%C:V%G92YX;6P*("`@
M("`J("`@(#(N($9U;&P@<&%T:"!T;R!T:&4@:6YS=&%L;&5D(&9I;&4*("`@
M("`J("`@(#,N($9U;&P@<&%T:"!F<F]M('1H92!P:'!?9&ER(&-O;F9I9W5R
M871I;VX@=F%R:6%B;&4@=7-E9"!I;B!T:&ES"B`@("`@*B`@("`@("!I;G-T
M86QL871I;VX*("`@("`J("`@(#0N(%)E;&%T:79E('!A=&@@9G)O;2!T:&4@
M<&AP7V1I<B!T:&%T('1H:7,@9FEL92!I<R!I;G-T86QL960@:6X*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D1FEL94]P97)A=&EO;B@D='EP92P@)&1A=&$I
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D9&%T82DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=);G1E<FYA;"!%<G)O
M<CH@)&1A=&$@:6X@861D1FEL94]P97)A=&EO;B<*("`@("`@("`@("`@("`@
M("X@)R!M=7-T(&)E(&%N(&%R<F%Y+"!W87,@)R`N(&=E='1Y<&4H)&1A=&$I
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T>7!E(#T]("=C:&UO9"<I('L*
M("`@("`@("`@("`@)&]C=&UO9&4@/2!D96-O8W0H)&1A=&%;,%TI.PH@("`@
M("`@("`@("`D=&AI<RT^;&]G*#,L(")A9&1I;F<@=&\@=')A;G-A8W1I;VXZ
M("1T>7!E("1O8W1M;V1E("1D871A6S%=(BD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B861D:6YG('1O('1R86YS86-T
M:6]N.B`D='EP92`B("X@:6UP;&]D92@B("(L("1D871A*2D["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3YF:6QE7V]P97)A=&EO;G-;72`](&%R<F%Y*"1T
M>7!E+"`D9&%T82D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<W1A
M<G1&:6QE5')A;G-A8W1I;VXH*0H*("`@(&9U;F-T:6]N('-T87)T1FEL951R
M86YS86-T:6]N*"1R;VQL8F%C:U]I;E]C87-E(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@:68@*&-O=6YT*"1T:&ES+3YF:6QE7V]P97)A=&EO;G,I("8F("1R
M;VQL8F%C:U]I;E]C87-E*2!["B`@("`@("`@("`@("1T:&ES+3YR;VQL8F%C
M:T9I;&54<F%N<V%C=&EO;B@I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M9FEL95]O<&5R871I;VYS(#T@87)R87DH*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!C;VUM:71&:6QE5')A;G-A8W1I;VXH*0H*("`@(&9U;F-T
M:6]N(&-O;6UI=$9I;&54<F%N<V%C=&EO;B@I"B`@("!["B`@("`@("`@)&X@
M/2!C;W5N="@D=&AI<RT^9FEL95]O<&5R871I;VYS*3L*("`@("`@("`D=&AI
M<RT^;&]G*#(L(")A8F]U="!T;R!C;VUM:70@)&X@9FEL92!O<&5R871I;VYS
M(BD["B`@("`@("`@+R\@>WM[(&9I<G-T+"!C:&5C:R!P97)M:7-S:6]N<R!A
M;F0@<W5C:"!M86YU86QL>0H@("`@("`@("1E<G)O<G,@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YF:6QE7V]P97)A=&EO;G,@87,@)'1R
M*2!["B`@("`@("`@("`@(&QI<W0H)'1Y<&4L("1D871A*2`]("1T<CL*("`@
M("`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("`@("`@8V%S
M92`G<F5N86UE)SH*("`@("`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI
M<W1S*"1D871A6S!=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D97)R
M;W)S6UT@/2`B8V%N;F]T(')E;F%M92!F:6QE("1D871A6S!=+"!D;V5S;B=T
M(&5X:7-T(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@+R\@8VAE8VL@=&AA="!D97-T(&1I<BX@:7,@=W)I=&%B;&4*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES7W=R:71A8FQE*&1I<FYA;64H)&1A
M=&%;,5TI*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D97)R;W)S6UT@
M/2`B<&5R;6ES<VEO;B!D96YI960@*"1T>7!E*3H@)&1A=&%;,5TB.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@(&-A<V4@)V-H;6]D)SH*("`@("`@("`@("`@("`@
M("`@("`O+R!C:&5C:R!T:&%T(&9I;&4@:7,@=W)I=&%B;&4*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7W=R:71A8FQE*"1D871A6S%=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D97)R;W)S6UT@/2`B<&5R;6ES<VEO;B!D
M96YI960@*"1T>7!E*3H@)&1A=&%;,5T@(B`N(&1E8V]C="@D9&%T85LP72D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`G9&5L971E)SH*("`@("`@("`@
M("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D871A6S!=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#(L(")W87)N:6YG.B!F
M:6QE("1D871A6S!=(&1O97-N)W0@97AI<W0L(&-A;B=T(&)E(&1E;&5T960B
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M+R\@8VAE8VL@=&AA="!D:7)E8W1O<GD@:7,@=W)I=&%B;&4*("`@("`@("`@
M("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)&1A=&%;,%TI("8F("%I<U]W
M<FET86)L92AD:7)N86UE*"1D871A6S!=*2DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5R<F]R<UM=(#T@(G!E<FUI<W-I;VX@9&5N:65D("@D='EP
M92DZ("1D871A6S!=(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@?0H@
M("`@("`@("\O('U]?0H@("`@("`@("1M(#T@<VEZ96]F*"1E<G)O<G,I.PH@
M("`@("`@(&EF("@D;2`^(#`I('L*("`@("`@("`@("`@9F]R96%C:"`H)&5R
M<F]R<R!A<R`D97)R;W(I('L*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H
M,2P@)&5R<F]R*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@("\O('M[>R!R96%L;'D@8V]M;6ET
M('1H92!T<F%N<V%C=&EO;@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YF:6QE
M7V]P97)A=&EO;G,@87,@)'1R*2!["B`@("`@("`@("`@(&QI<W0H)'1Y<&4L
M("1D871A*2`]("1T<CL*("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PH@
M("`@("`@("`@("`@("`@8V%S92`G<F5N86UE)SH*("`@("`@("`@("`@("`@
M("`@("!`=6YL:6YK*"1D871A6S%=*3L*("`@("`@("`@("`@("`@("`@("!`
M<F5N86UE*"1D871A6S!=+"`D9&%T85LQ72D["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@S+"`B*R!M=B`D9&%T85LP72`D9&%T85LQ72(I.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S
M92`G8VAM;V0G.@H@("`@("`@("`@("`@("`@("`@($!C:&UO9"@D9&%T85LQ
M72P@)&1A=&%;,%TI.PH@("`@("`@("`@("`@("`@("`@("1O8W1M;V1E(#T@
M9&5C;V-T*"1D871A6S!=*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#,L("(K(&-H;6]D("1O8W1M;V1E("1D871A6S%=(BD["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("=D96QE
M=&4G.@H@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH)&1A=&%;,%TI.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@<FT@)&1A=&%;
M,%TB*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@(&-A<V4@)W)M9&ER)SH*("`@("`@("`@("`@("`@("`@("!`<FUD:7(H
M)&1A=&%;,%TI.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@
M(BL@<FUD:7(@)&1A=&%;,%TB*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@(&-A<V4@)VEN<W1A;&QE9%]A<R<Z"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F];)V9I;&5L:7-T)UU;)&1A
M=&%;,%U=6R=I;G-T86QL961?87,G72`]("1D871A6S%=.PH@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G!K9VEN9F];)V9I;&5L:7-T
M)UU;)V1I<G1R964G75MD:7)N86UE*"1D871A6S%=*5TI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O6R=F:6QE;&ES="==6R=D
M:7)T<F5E)UU;9&ER;F%M92@D9&%T85LQ72E=(#T@=')U93L*("`@("`@("`@
M("`@("`@("`@("`@("`@=VAI;&4H(65M<'1Y*"1D871A6S-=*2`F)B`D9&%T
M85LS72`A/2`G+R<@)B8@)&1A=&%;,UT@(3T@)UQ<)PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`F)B`D9&%T85LS72`A/2`G+B<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O6R=F:6QE;&ES
M="==6R=D:7)T<F5E)UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!;)'1H:7,M/E]P<F5P96YD4&%T:"@D9&%T85LS72P@)&1A=&%;,ETI72`]
M('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85LS72`]
M(&1I<FYA;64H)&1A=&%;,UTI.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O('U]?0H@
M("`@("`@("1T:&ES+3YL;V<H,BP@(G-U8V-E<W-F=6QL>2!C;VUM:71T960@
M)&X@9FEL92!O<&5R871I;VYS(BD["B`@("`@("`@)'1H:7,M/F9I;&5?;W!E
M<F%T:6]N<R`](&%R<F%Y*"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VM&:6QE5')A;G-A8W1I
M;VXH*0H*("`@(&9U;F-T:6]N(')O;&QB86-K1FEL951R86YS86-T:6]N*"D*
M("`@('L*("`@("`@("`D;B`](&-O=6YT*"1T:&ES+3YF:6QE7V]P97)A=&EO
M;G,I.PH@("`@("`@("1T:&ES+3YL;V<H,BP@(G)O;&QI;F<@8F%C:R`D;B!F
M:6QE(&]P97)A=&EO;G,B*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^9FEL
M95]O<&5R871I;VYS(&%S("1T<BD@>PH@("`@("`@("`@("!L:7-T*"1T>7!E
M+"`D9&%T82D@/2`D='(["B`@("`@("`@("`@('-W:71C:"`H)'1Y<&4I('L*
M("`@("`@("`@("`@("`@(&-A<V4@)W)E;F%M92<Z"B`@("`@("`@("`@("`@
M("`@("`@0'5N;&EN:R@D9&%T85LP72D["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FQO9R@S+"`B*R!R;2`D9&%T85LP72(I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G;6MD:7(G.@H@
M("`@("`@("`@("`@("`@("`@($!R;61I<B@D9&%T85LP72D["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!R;61I<B`D9&%T85LP72(I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M8V%S92`G8VAM;V0G.@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`G9&5L971E)SH*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)VEN<W1A;&QE9%]A<R<Z
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP:V=I;F9O
M6R=F:6QE;&ES="==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^<&MG:6YF;ULG9FEL96QI<W0G75LD9&%T85LP75U;)VEN<W1A
M;&QE9%]A<R==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP:V=I;F9O6R=F:6QE;&ES="==
M6R=D:7)T<F5E)UU;9&ER;F%M92@D9&%T85LQ72E=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^<&MG:6YF;ULG9FEL96QI<W0G
M75LG9&ER=')E92==6V1I<FYA;64H)&1A=&%;,5TI72D["B`@("`@("`@("`@
M("`@("`@("`@("`@('=H:6QE*"%E;7!T>2@D9&%T85LS72D@)B8@)&1A=&%;
M,UT@(3T@)R\G("8F("1D871A6S-=("$]("=<7"<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)B8@)&1A=&%;,UT@(3T@)RXG*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^<&MG:6YF;ULG9FEL
M96QI<W0G75LG9&ER=')E92=="B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6R1T:&ES+3Y?<')E<&5N9%!A=&@H)&1A=&%;,UTL("1D871A6S)=
M*5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;,UT@/2!D
M:7)N86UE*"1D871A6S-=*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/G!K9VEN9F];)V9I;&5L:7-T)UU;)V1I<G1R964G72D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`F)B`A8V]U;G0H)'1H:7,M/G!K
M9VEN9F];)V9I;&5L:7-T)UU;)V1I<G1R964G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@=6YS970H)'1H:7,M/G!K9VEN9F];)V9I;&5L:7-T)UU;
M)V1I<G1R964G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YF:6QE7V]P97)A=&EO;G,@/2!A<G)A>2@I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&UK1&ER2&EE<B@D9&ER*0H*("`@(&9U
M;F-T:6]N(&UK1&ER2&EE<B@D9&ER*0H@("`@>PH@("`@("`@("1T:&ES+3YA
M9&1&:6QE3W!E<F%T:6]N*"=M:V1I<B<L(&%R<F%Y*"1D:7(I*3L*("`@("`@
M("!R971U<FX@<&%R96YT.CIM:T1I<DAI97(H)&1I<BD["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@7W!R97!E;F10871H*"1P871H+"`D<')E<&5N
M9"D*"B`@("!F=6YC=&EO;B!?<')E<&5N9%!A=&@H)'!A=&@L("1P<F5P96YD
M*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)'!R97!E;F0I(#X@,"D@>PH@
M("`@("`@("`@("!I9B`H3U-?5TE.1$]74R`F)B!P<F5G7VUA=&-H*"<O7EMA
M+7I=.B]I)RP@)'!A=&@I*2!["B`@("`@("`@("`@("`@("`D<&%T:"`]("1P
M<F5P96YD("X@<W5B<W1R*"1P871H+"`R*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1P871H(#T@)'!R97!E;F0@+B`D<&%T:#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'!A=&@[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&]W;FQO860H*0H*("`@
M("\J*@H@("`@("H@1&]W;FQO860@86YY(&9I;&5S(&%N9"!T:&5I<B!D97!E
M;F1E;F-I97,L(&EF(&YE8V5S<V%R>0H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2!A(&UI>&5D(&QI<W0@;V8@<&%C:V%G92!N86UE<RP@;&]C86P@9FEL
M97,L(&]R('!A8VMA9V4N>&UL"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<*
M("`@("`J($!P87)A;2!A<G)A>2!O<'1I;VYS(&9R;VT@=&AE(&-O;6UA;F0@
M;&EN90H@("`@("H@0'!A<F%M(&%R<F%Y('1H:7,@:7,@=&AE(&%R<F%Y('1H
M870@=VEL;"!B92!P;W!U;&%T960@=VET:"!P86-K86=E<R!T;PH@("`@("H@
M("`@("`@("`@("`@(&EN<W1A;&PN("!&;W)M870@;V8@96%C:"!E;G1R>3H*
M("`@("`J"B`@("`@*B`\8V]D93X*("`@("`J(&%R<F%Y*"=P:V<G(#T^("=P
M86-K86=E7VYA;64G+"`G9FEL92<@/3X@)R]P871H+W1O+VQO8V%L+V9I;&4G
M+`H@("`@("H@("`@)VEN9F\G(#T^(&%R<F%Y*"D@+R\@<&%R<V5D('!A8VMA
M9V4N>&UL"B`@("`@*B`I.PH@("`@("H@/"]C;V1E/@H@("`@("H@0'!A<F%M
M(&%R<F%Y('1H:7,@=VEL;"!B92!P;W!U;&%T960@=VET:"!A;GD@97)R;W(@
M;65S<V%G97,*("`@("`J($!P87)A;2!F86QS92!P<FEV871E(')E8W5R<VEO
M;B!V87)I86)L90H@("`@("H@0'!A<F%M(&9A;'-E('!R:79A=&4@<F5C=7)S
M:6]N('9A<FEA8FQE"B`@("`@*B!`<&%R86T@9F%L<V4@<')I=F%T92!R96-U
M<G-I;VX@=F%R:6%B;&4*("`@("`J($!D97!R96-A=&5D(&EN(&9A=F]R(&]F
M(%!%05)?1&]W;FQO861E<@H@("`@("HO"B`@("!F=6YC=&EO;B!D;W=N;&]A
M9"@D<&%C:V%G97,L("1O<'1I;VYS+"`F)&-O;F9I9RP@)B1I;G-T86QL<&%C
M:V%G97,L"B`@("`@("`@("`@("`@("`@("`@("`F)&5R<F]R<RP@)&EN<W1A
M;&QE9"`](&9A;'-E+"`D=VEL;&EN<W1A;&P@/2!F86QS92P@)'-T871E(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@+R\@=')I8VMI;F5S<SH@:6YI=&EA;&EZ
M92!H97)E"B`@("`@("`@<&%R96YT.CI014%27T1O=VYL;V%D97(H)'1H:7,M
M/G5I+"`D;W!T:6]N<RP@)&-O;F9I9RD["B`@("`@("`@)')E="`]('!A<F5N
M=#HZ9&]W;FQO860H)'!A8VMA9V5S*3L*("`@("`@("`D97)R;W)S(#T@)'1H
M:7,M/F=E=$5R<F]R37-G<R@I.PH@("`@("`@("1I;G-T86QL<&%C:V%G97,@
M/2`D=&AI<RT^9V5T1&]W;FQO861E9%!A8VMA9V5S*"D["B`@("`@("`@=')I
M9V=E<E]E<G)O<B@B4$5!4B!787)N:6YG.B!014%27TEN<W1A;&QE<CHZ9&]W
M;FQO860H*2!I<R!D97!R96-A=&5D("(@+@H@("`@("`@("`@("`@("`@("`@
M("`@(FEN(&9A=F]R(&]F(%!%05)?1&]W;FQO861E<B!C;&%S<R(L($5?55-%
M4E]705).24Y'*3L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!I;G-T86QL*"D*"B`@("`O*BH*("`@("`J($EN
M<W1A;&QS('1H92!F:6QE<R!W:71H:6X@=&AE('!A8VMA9V4@9FEL92!S<&5C
M:69I960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&MG9FEL92!P
M871H('1O('1H92!P86-K86=E(&9I;&4*("`@("`J($!P87)A;2!A<G)A>2`D
M;W!T:6]N<PH@("`@("H@<F5C;V=N:7IE9"!O<'1I;VYS.@H@("`@("H@+2!I
M;G-T86QL<F]O="`@(#H@;W!T:6]N86P@<')E9FEX(&1I<F5C=&]R>2!F;W(@
M:6YS=&%L;&%T:6]N"B`@("`@*B`M(&9O<F-E("`@("`@("`@.B!F;W)C92!I
M;G-T86QL871I;VX*("`@("`J("T@<F5G:7-T97(M;VYL>2`Z('5P9&%T92!R
M96=I<W1R>2!B=70@9&]N)W0@:6YS=&%L;"!F:6QE<PH@("`@("H@+2!U<&=R
M861E("`@("`@(#H@=7!G<F%D92!E>&ES=&EN9R!I;G-T86QL"B`@("`@*B`M
M('-O9G0@("`@("`@("`@.B!F86EL('-I;&5N=&QY"B`@("`@*B`M(&YO9&5P
M<R`@("`@("`@.B!I9VYO<F4@9&5P96YD96YC>2!C;VYF;&EC=',O;6ES<VEN
M9R!D97!E;F1E;F-I97,*("`@("`J("T@86QL9&5P<R`@("`@("`Z(&EN<W1A
M;&P@86QL(&1E<&5N9&5N8VEE<PH@("`@("H@+2!O;FQY<F5Q9&5P<R`@(#H@
M:6YS=&%L;"!O;FQY(')E<75I<F5D(&1E<&5N9&5N8VEE<PH@("`@("H*("`@
M("`J($!R971U<FX@87)R87E\4$5!4E]%<G)O<B!P86-K86=E(&EN9F\@:68@
M<W5C8V5S<V9U;`H@("`@("HO"@H@("`@9G5N8W1I;VX@:6YS=&%L;"@D<&MG
M9FEL92P@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P:'!?
M9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RD["B`@("`@("`@
M:68@*&ES<V5T*"1O<'1I;VYS6R=I;G-T86QL<F]O="==*2D@>PH@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1O<'1I;VYS6R=I;G-T86QL<F]O="==+"`M,2D@
M/3T@1$E214-43U)97U-%4$%2051/4BD@>PH@("`@("`@("`@("`@("`@)&]P
M=&EO;G-;)VEN<W1A;&QR;V]T)UT@/2!S=6)S='(H)&]P=&EO;G-;)VEN<W1A
M;&QR;V]T)UTL(#`L("TQ*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<&AP7V1I<B`]("1T:&ES+3Y?<')E<&5N9%!A=&@H)'!H<%]D:7(L("1O<'1I
M;VYS6R=I;G-T86QL<F]O="==*3L*("`@("`@("`@("`@)'1H:7,M/FEN<W1A
M;&QR;V]T(#T@)&]P=&EO;G-;)VEN<W1A;&QR;V]T)UT["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QR;V]T(#T@)R<["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3YR96=I<W1R>2`]("9N97<@4$5!4E]2
M96=I<W1R>2@D<&AP7V1I<BD["B`@("`@("`@+R\@(#T]/B!86%@@<VAO=6QD
M(&)E(')E;6]V960@;&%T97(@;VX*("`@("`@("`D9FQA9U]O;&1?9F]R;6%T
M(#T@9F%L<V4["@H@("`@("`@(&EF("AS=6)S='(H)'!K9V9I;&4L("TT*2`]
M/2`G+GAM;"<I('L*("`@("`@("`@("`@)&1E<V-F:6QE(#T@)'!K9V9I;&4[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@>WM[($1E8V]M<')E
M<W,@<&%C:R!I;B!T;7`@9&ER("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*"B`@("`@("`@("`@("\O(%1O(&%L;&]W(')E;&%T:79E
M('!A8VMA9V4@9FEL92!N86UE<PH@("`@("`@("`@("`D<&MG9FEL92`](')E
M86QP871H*"1P:V=F:6QE*3L*"B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"@G+60G*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&UP9&ER.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3YL;V<H,RP@)RL@=&UP(&1I<B!C<F5A=&5D(&%T("<@
M+B`D=&UP9&ER*3L*"B`@("`@("`@("`@("1T87(@/2!N97<@07)C:&EV95]4
M87(H)'!K9V9I;&4I.PH@("`@("`@("`@("!I9B`H(4`D=&%R+3YE>'1R86-T
M*"1T;7!D:7(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(G5N86)L92!T;R!U;G!A8VL@)'!K9V9I;&4B*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R\@>WM[($QO;VL@9F]R(&5X:7-T:6YG
M('!A8VMA9V4@9FEL90H@("`@("`@("`@("`D9&5S8V9I;&4@/2`D=&UP9&ER
M("X@1$E214-43U)97U-%4$%2051/4B`N("=P86-K86=E+GAM;"<["@H@("`@
M("`@("`@("!I9B`H(6ES7V9I;&4H)&1E<V-F:6QE*2D@>PH@("`@("`@("`@
M("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@;VQD('!A8VMA9V4@87)C:&EV92!F
M;W)M870*("`@("`@("`@("`@("`@("\O($EN('1H:7,@9F]R;6%T('1H92!P
M86-K86=E+GAM;"!F:6QE('=A<R!I;G-I9&4@=&AE"B`@("`@("`@("`@("`@
M("`O+R!086-K86=E+6XN;B!D:7)E8W1O<GD*("`@("`@("`@("`@("`@("1D
M<"`](&]P96YD:7(H)'1M<&1I<BD["B`@("`@("`@("`@("`@("!D;R!["B`@
M("`@("`@("`@("`@("`@("`@)'!K9V1I<B`](')E861D:7(H)&1P*3L*("`@
M("`@("`@("`@("`@('T@=VAI;&4@*"1P:V=D:7)[,'T@/3T@)RXG*3L*"B`@
M("`@("`@("`@("`@("`D9&5S8V9I;&4@/2`D=&UP9&ER("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1P:V=D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@
M)W!A8VMA9V4N>&UL)SL*("`@("`@("`@("`@("`@("1F;&%G7V]L9%]F;W)M
M870@/2!T<G5E.PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B=V%R
M;FEN9R`Z('EO=2!A<F4@=7-I;F<@86X@87)C:&EV92!W:71H(&%N(&]L9"!F
M;W)M870B*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`O+R!]?7T*("`@
M("`@("`@("`@+R\@/#T](%A86"!4:&ES('!A<G0@<VAO=6QD(&)E(')E;6]V
M960@;&%T97(@;VX*("`@("`@("`@("`@+R\@?7U]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6ES7V9I;&4H)&1E<V-F:6QE*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO('!A8VMA9V4N>&UL(&9I;&4@
M869T97(@97AT<F%C=&EN9R!T:&4@87)C:&EV92(I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4&%R<V4@>&UL(&9I;&4@+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*("`@("`@("`D<&MG:6YF;R`]
M("1T:&ES+3YI;F9O1G)O;41E<V-R:7!T:6]N1FEL92@D9&5S8V9I;&4I.PH@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P:V=I;F9O*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'!K9VEN9F\["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3YV86QI9&%T95!A8VMA9V5);F9O*"1P:V=I;F9O+"`D97)R;W)S+"`D=V%R
M;FEN9W,I.PH@("`@("`@("\O(%A86"!792!A;&QO=R!W87)N:6YG<RP@9&\@
M=V4@:&%V92!T;R!D;R!I=#\*("`@("`@("!I9B`H8V]U;G0H)&5R<F]R<RDI
M('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=F;W)C92==*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")4
M:&4@9F]L;&]W:6YG(&5R<F]R<R!W:&5R92!F;W5N9"`H=7-E(&9O<F-E(&]P
M=&EO;B!T;R!I;G-T86QL(&%N>7=A>2DZ7&XB+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H(EQN(BP@)&5R<F]R
M<RDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9R@P+"`B=V%R;FEN9R`Z('1H92!F;VQL;W=I;F<@97)R;W)S('=E
M<F4@9F]U;F0Z7&XB+@H@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L
M;V1E*")<;B(L("1E<G)O<G,I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)'!K9VYA;64@/2`D<&MG:6YF;ULG<&%C:V%G92==.PH*("`@
M("`@("`O+R![>WL@0VAE8VL@9&5P96YD96YC:65S("TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*("`@("`@("!I9B`H:7-S
M970H)'!K9VEN9F];)W)E;&5A<V5?9&5P<R==*2`F)B!E;7!T>2@D;W!T:6]N
M<ULG;F]D97!S)UTI*2!["B`@("`@("`@("`@("1D97!?97)R;W)S(#T@)R<[
M"B`@("`@("`@("`@("1E<G)O<B`]("1T:&ES+3YC:&5C:T1E<',H)'!K9VEN
M9F\L("1D97!?97)R;W)S*3L*("`@("`@("`@("`@:68@*"1E<G)O<B`]/2!T
M<G5E*2!["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&]P=&EO;G-;)W-O
M9G0G72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L('-U
M8G-T<B@D9&5P7V5R<F]R<RP@,2DI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D<&MG;F%M
M93H@1&5P96YD96YC:65S(&9A:6QE9"(I.PH@("`@("`@("`@("!](&5L<V4@
M:68@*"%E;7!T>2@D9&5P7V5R<F]R<RDI('L*("`@("`@("`@("`@("`@("\O
M(%!R:6YT(&]P=&EO;F%L(&1E<&5N9&5N8VEE<PH@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1O<'1I;VYS6R=S;V9T)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@P+"`D9&5P7V5R<F]R<RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@?7U]
M"@H@("`@("`@("\O('M[>R!C:&5C:W,@=&\@9&\@=VAE;B!N;W0@:6X@(F9O
M<F-E(B!M;V1E"B`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=F;W)C92==
M*2D@>PH@("`@("`@("`@("`D=&5S="`]("1T:&ES+3YR96=I<W1R>2T^8VAE
M8VM&:6QE36%P*"1P:V=I;F9O*3L*("`@("`@("`@("`@:68@*'-I>F5O9B@D
M=&5S="DI('L*("`@("`@("`@("`@("`@("1T;7`@/2`D=&5S=#L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T;7`@87,@)&9I;&4@/3X@)'!K9RD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D<&MG(#T]("1P:V=N86UE*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T97-T6R1F:6QE72D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*'-I>F5O9B@D=&5S="DI('L*("`@("`@("`@("`@("`@
M("`@("`D;7-G(#T@(B1P:V=N86UE.B!C;VYF;&EC=&EN9R!F:6QE<R!F;W5N
M9#I<;B(["B`@("`@("`@("`@("`@("`@("`@)&QO;F=E<W0@/2!M87@H87)R
M87E?;6%P*")S=')L96XB+"!A<G)A>5]K97ES*"1T97-T*2DI.PH@("`@("`@
M("`@("`@("`@("`@("1F;70@/2`B)21[;&]N9V5S='US("@E<RE<;B(["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1E<W0@87,@)&9I;&4@/3X@
M)'!K9RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;7-G("X]('-P<FEN
M=&8H)&9M="P@)&9I;&4L("1P:V<I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)&US9RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@+R\@?7U]"@H@("`@("`@("1T:&ES+3YS=&%R=$9I;&54
M<F%N<V%C=&EO;B@I.PH*("`@("`@("!I9B`H96UP='DH)&]P=&EO;G-;)W5P
M9W)A9&4G72DI('L*("`@("`@("`@("`@+R\@8VAE8VMS('1O(&1O(&]N;'D@
M=VAE;B!I;G-T86QL:6YG(&YE=R!P86-K86=E<PH@("`@("`@("`@("!I9B`H
M96UP='DH)&]P=&EO;G-;)V9O<F-E)UTI("8F("1T:&ES+3YR96=I<W1R>2T^
M<&%C:V%G945X:7-T<R@D<&MG;F%M92DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)'!K9VYA;64@86QR96%D>2!I;G-T
M86QL960B*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K
M9VYA;64I*2!["B`@("`@("`@("`@("`@("`D=C$@/2`D=&AI<RT^<F5G:7-T
M<GDM/G!A8VMA9V5);F9O*"1P:V=N86UE+"`G=F5R<VEO;B<I.PH@("`@("`@
M("`@("`@("`@)'8R(#T@)'!K9VEN9F];)W9E<G-I;VXG73L*("`@("`@("`@
M("`@("`@("1C;7`@/2!V97)S:6]N7V-O;7!A<F4H(B1V,2(L("(D=C(B+"`G
M9W0G*3L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9F]R
M8V4G72D@)B8@(79E<G-I;VY?8V]M<&%R92@B)'8R(BP@(B1V,2(L("=G="<I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")U<&=R861E('1O(&$@;F5W97(@=F5R<VEO;B`H)'8R(&ES(&YO="!N
M97=E<B!T:&%N("1V,2DB*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("\O('=H96X@=7!G<F%D:6YG+"!R96UO
M=F4@;VQD(')E;&5A<V4G<R!F:6QE<R!F:7)S=#H*("`@("`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T@)'1H:7,M/E]D96QE=&50
M86-K86=E1FEL97,H)'!K9VYA;64I*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<BD["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R![>WL@0V]P>2!F:6QE<R!T;R!D97-T
M(&1I<B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*
M"B`@("`@("`@+R\@:6YF;R!F<F]M('1H92!P86-K86=E(&ET('-E;&8@=V4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!?:6YS=&%L;$9I;&4*("`@("`@("`D=&AI
M<RT^<&MG:6YF;R`]("8D<&MG:6YF;SL*("`@("`@("`O+R!U<V5D('1O(&1E
M=&5R;6EN92!W:&5T:&5R('=E('-H;W5L9"!B=6EL9"!A;GD@0R!C;V1E"B`@
M("`@("`@)'1H:7,M/G-O=7)C95]F:6QE<R`](#`["@H@("`@("`@(&EF("AE
M;7!T>2@D;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==*2D@>PH@("`@("`@("`@
M("!I9B`H(6ES7V1I<B@D<&AP7V1I<BDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B;F\@<V-R:7!T(&1E<W1I;F%T:6]N
M(&1I<F5C=&]R>5QN(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!N=6QL+"!014%27T524D]27T1)12D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T;7!?<&%T:"`](&1I<FYA;64H)&1E<V-F:6QE
M*3L*("`@("`@("`@("`@:68@*'-U8G-T<B@D<&MG9FEL92P@+30I("$]("<N
M>&UL)RD@>PH@("`@("`@("`@("`@("`@)'1M<%]P871H("X]($1)4D5#5$]2
M65]315!!4D%43U(@+B`D<&MG;F%M92`N("<M)R`N("1P:V=I;F9O6R=V97)S
M:6]N)UT["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O("`]/3X@6%A8
M(%1H:7,@<&%R="!S:&]U;&0@8F4@<F5M;W9E9"!L871E<B!O;@H@("`@("`@
M("`@("!I9B`H)&9L86=?;VQD7V9O<FUA="D@>PH@("`@("`@("`@("`@("`@
M)'1M<%]P871H(#T@9&ER;F%M92@D9&5S8V9I;&4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("\O(#P]/2!86%@@5&AI<R!P87)T('-H;W5L9"!B92!R
M96UO=F5D(&QA=&5R(&]N"@H@("`@("`@("`@("`O+R![>WL@:6YS=&%L;"!F
M:6QE<PH@("`@("`@("`@("!F;W)E86-H("@D<&MG:6YF;ULG9FEL96QI<W0G
M72!A<R`D9FEL92`]/B`D871T<RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F5X<&5C=$5R<F]R*%!%05)?24Y35$%,3$527T9!24Q%1"D["B`@("`@("`@
M("`@("`@("`D<F5S(#T@)'1H:7,M/E]I;G-T86QL1FEL92@D9FEL92P@)&%T
M=',L("1T;7!?<&%T:"P@)&]P=&EO;G,I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G!O<$5X<&5C="@I.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)&]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T:6]N*"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S+3YG971-97-S86=E*"D@
M/3T@(F9I;&4@9&]E<R!N;W0@97AI<W0B*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL92`D9FEL92!I;B!P
M86-K86=E+GAM;"!D;V5S(&YO="!E>&ES="(I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D<F5S*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")7
M87)N:6YG.B`B("X@)')E<RT^9V5T365S<V%G92@I*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)')E<R`A/2!014%27TE.4U1!3$Q%4E]/2RD@>PH@("`@("`@("`@("`@
M("`@("`@("\O($1O(&YO="!R96=I<W1E<B!F:6QE<R!T:&%T('=E<F4@;F]T
M(&EN<W1A;&QE9`H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P:V=I;F9O
M6R=F:6QE;&ES="==6R1F:6QE72D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@+R\@?7U]"@H@("`@("`@("`@("`O+R![
M>WL@8V]M<&EL92!A;F0@:6YS=&%L;"!S;W5R8V4@9FEL97,*("`@("`@("`@
M("`@:68@*"1T:&ES+3YS;W5R8V5?9FEL97,@/B`P("8F(&5M<'1Y*"1O<'1I
M;VYS6R=N;V)U:6QD)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M*#$L("(D=&AI<RT^<V]U<F-E7V9I;&5S('-O=7)C92!F:6QE<RP@8G5I;&1I
M;F<B*3L*("`@("`@("`@("`@("`@("1B;V(@/2`F;F5W(%!%05)?0G5I;&1E
M<B@D=&AI<RT^=6DI.PH@("`@("`@("`@("`@("`@)&)O8BT^9&5B=6<@/2`D
M=&AI<RT^9&5B=6<["B`@("`@("`@("`@("`@("`D8G5I;'0@/2`D8F]B+3YB
M=6EL9"@D9&5S8V9I;&4L(&%R<F%Y*"8D=&AI<RP@)U]B=6EL9$-A;&QB86-K
M)RDI.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&)U:6QT
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR;VQL8F%C:T9I;&54
M<F%N<V%C=&EO;B@I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D8G5I
M;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#$L(")<;D)U:6QD('!R;V-E<W,@8V]M<&QE=&5D('-U8V-E<W-F=6QL
M>2(I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&)U:6QT(&%S("1E>'0I
M('L*("`@("`@("`@("`@("`@("`@("`D8FX@/2!B87-E;F%M92@D97AT6R=F
M:6QE)UTI.PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)%]E>'1?;F%M92P@
M*2`](&5X<&QO9&4H)RXG+"`D8FXI.PH@("`@("`@("`@("`@("`@("`@(&EF
M("AE>'1E;G-I;VY?;&]A9&5D*"1?97AT7VYA;64I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*")%>'1E;G-I;VX@)R1?
M97AT7VYA;64G(&%L<F5A9'D@;&]A9&5D+B!0;&5A<V4@=6YL;V%D(&ET("(N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")I
M;B!Y;W5R('!H<"YI;FD@9FEL92!P<FEO<B!T;R!I;G-T86QL(&]R('5P9W)A
M9&4@:70N(BD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("1D97-T(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=E>'1?9&ER)RD@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&)N.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V<H,2P@(DEN<W1A;&QI;F<@)R1B;B<@870@97AT7V1I
M<B`H)&1E<W0I(BD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S
M+"`B*R!C<"`D97AT6V9I;&5=(&5X=%]D:7(@*"1D97-T*2(I.PH@("`@("`@
M("`@("`@("`@("`@("1C;W!Y=&\@/2`D=&AI<RT^7W!R97!E;F10871H*"1D
M97-T+"`D=&AI<RT^:6YS=&%L;')O;W0I.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A0&-O<'DH)&5X=%LG9FEL92==+"`D8V]P>71O*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<F]L;&)A8VM&:6QE5')A;G-A8W1I
M;VXH*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")F86EL960@=&\@8V]P>2`D8FX@=&\@)&-O<'ET;R(I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D<&MG
M:6YF;ULG9FEL96QI<W0G75LD8FY=(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("=R;VQE)R`]/B`G97AT)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)VEN<W1A;&QE9%]A<R<@/3X@)&1E<W0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=P:'!?87!I)R`]/B`D97AT6R=P:'!?87!I)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("=Z96YD7VUO9%]A<&DG(#T^("1E>'1;)WIE
M;F1?;6]D7V%P:2==+`H@("`@("`@("`@("`@("`@("`@("`@("`G>F5N9%]E
M>'1?87!I)R`]/B`D97AT6R=Z96YD7V5X=%]A<&DG72P*("`@("`@("`@("`@
M("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`O+R!]?7T*("`@("`@("!]"@H@("`@("`@(&EF("@A
M)'1H:7,M/F-O;6UI=$9I;&54<F%N<V%C=&EO;B@I*2!["B`@("`@("`@("`@
M("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I.PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O;6UI="!F86EL960B+"!0
M14%27TE.4U1!3$Q%4E]&04E,140I.PH@("`@("`@('T*("`@("`@("`O+R!]
M?7T*"B`@("`@("`@)')E="`](&9A;'-E.PH@("`@("`@("\O('M[>R!296=I
M<W1E<B!T:&%T('1H92!P86-K86=E(&ES(&EN<W1A;&QE9"`M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0H@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG=7!G
M<F%D92==*2D@>PH@("`@("`@("`@("`O+R!I9B`G9F]R8V4G(&ES('5S960L
M(')E<&QA8V4@=&AE(&EN9F\@:6X@<F5G:7-T<GD*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D;W!T:6]N<ULG9F]R8V4G72D@)B8@)'1H:7,M/G)E9VES=')Y
M+3YP86-K86=E17AI<W1S*"1P:V=N86UE*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G)E9VES=')Y+3YD96QE=&5086-K86=E*"1P:V=N86UE*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/G)E9VES=')Y
M+3YA9&1086-K86=E*"1P:V=N86UE+"`D<&MG:6YF;RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@;F5W.B!U<&=R861E(&EN<W1A;&QS(&$@
M<&%C:V%G92!I9B!I="!I<VXG="!I;G-T86QL960*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64I*2![
M"B`@("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/G)E9VES=')Y+3YA9&10
M86-K86=E*"1P:V=N86UE+"`D<&MG:6YF;RD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/G)E9VES=')Y+3YU
M<&1A=&5086-K86=E*"1P:V=N86UE+"`D<&MG:6YF;RP@9F%L<V4I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A)')E="D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D%D9&EN9R!P86-K
M86=E("1P:V=N86UE('1O(')E9VES=')Y(&9A:6QE9"(I.PH@("`@("`@('T*
M("`@("`@("`O+R!]?7T*("`@("`@("!R971U<FX@)'!K9VEN9F\["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=6YI;G-T86QL*"D*"B`@("`O*BH*
M("`@("`J(%5N:6YS=&%L;"!A('!A8VMA9V4*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!R96UO=F5S(&%L;"!F:6QE<R!I;G-T86QL960@8GD@=&AE(&%P
M<&QI8V%T:6]N+"!A;F0@=&AE;@H@("`@("H@<F5M;W9E<R!A;GD@96UP='D@
M9&ER96-T;W)I97,N"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M
M90H@("`@("H@0'!A<F%M(&%R<F%Y($-O;6UA;F0M;&EN92!O<'1I;VYS+B`@
M4&]S<VEB:6QI=&EE<R!I;F-L=61E.@H@("`@("H*("`@("`J("`@("`@("`@
M("`@("`M(&EN<W1A;&QR;V]T.B!B87-E(&EN<W1A;&QA=&EO;B!D:7(L(&EF
M(&YO="!T:&4@9&5F875L=`H@("`@("H@("`@("`@("`@("`@("T@;F]D97!S
M.B!D;R!N;W0@<')O8V5S<R!D97!E;F1E;F-I97,@;V8@;W1H97(@<&%C:V%G
M97,@=&\@96YS=7)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('5N
M:6YS=&%L;&%T:6]N(&1O97,@;F]T(&)R96%K('1H:6YG<PH@("`@("HO"B`@
M("!F=6YC=&EO;B!U;FEN<W1A;&PH)'!A8VMA9V4L("1O<'1I;VYS(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D<&AP7V1I<B`]("1T:&ES+3YC;VYF:6<M
M/F=E="@G<&AP7V1I<B<I.PH@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG
M:6YS=&%L;')O;W0G72DI('L*("`@("`@("`@("`@:68@*'-U8G-T<B@D;W!T
M:6]N<ULG:6YS=&%L;')O;W0G72P@+3$I(#T]($1)4D5#5$]265]315!!4D%4
M3U(I('L*("`@("`@("`@("`@("`@("1O<'1I;VYS6R=I;G-T86QL<F]O="==
M(#T@<W5B<W1R*"1O<'1I;VYS6R=I;G-T86QL<F]O="==+"`P+"`M,2D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QR;V]T(#T@
M)&]P=&EO;G-;)VEN<W1A;&QR;V]T)UT["B`@("`@("`@("`@("1P:'!?9&ER
M(#T@)'1H:7,M/E]P<F5P96YD4&%T:"@D<&AP7V1I<BP@)'1H:7,M/FEN<W1A
M;&QR;V]T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M:6YS=&%L;')O;W0@/2`G)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G)E
M9VES=')Y(#T@)FYE=R!014%27U)E9VES=')Y*"1P:'!?9&ER*3L*("`@("`@
M("`D9FEL96QI<W0@/2`D=&AI<RT^<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P
M86-K86=E+"`G9FEL96QI<W0G*3L*("`@("`@("!I9B`H)&9I;&5L:7-T(#T]
M(&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"(D<&%C:V%G92!N;W0@:6YS=&%L;&5D(BD["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D;W!T:6]N<ULG;F]D97!S)UTI*2!["B`@("`@("`@("`@
M("1D97!C:&5C:V5R(#T@)FYE=R!014%27T1E<&5N9&5N8WDH)'1H:7,M/G)E
M9VES=')Y*3L*("`@("`@("`@("`@)&5R<F]R(#T@)&1E<&-H96-K97(M/F-H
M96-K4&%C:V%G955N:6YS=&%L;"@D97)R;W)S+"`D=V%R;FEN9RP@)'!A8VMA
M9V4I.PH@("`@("`@("`@("!I9B`H)&5R<F]R*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<F]R<R`N("=U;FEN<W1A
M;&P@9F%I;&5D)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1W
M87)N:6YG*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1W87)N
M:6YG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R![>WL@
M1&5L971E('1H92!F:6QE<PH@("`@("`@("1T:&ES+3YS=&%R=$9I;&54<F%N
M<V%C=&EO;B@I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(@/2`D
M=&AI<RT^7V1E;&5T95!A8VMA9V5&:6QE<R@D<&%C:V%G92DI*2!["B`@("`@
M("`@("`@("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I.PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<BD["B`@("`@
M("`@?0H@("`@("`@(&EF("@A)'1H:7,M/F-O;6UI=$9I;&54<F%N<V%C=&EO
M;B@I*2!["B`@("`@("`@("`@("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C
M=&EO;B@I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(G5N:6YS=&%L;"!F86EL960B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^<W1A<G1&:6QE5')A;G-A8W1I;VXH*3L*("`@("`@("`@
M("`@:68@*"%I<W-E="@D9FEL96QI<W1;)V1I<G1R964G72D@?'P@(6-O=6YT
M*"1F:6QE;&ES=%LG9&ER=')E92==*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR96=I<W1R>2T^9&5L971E4&%C:V%G92@D<&%C:V%G92D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@871T96UP="!T;R!D96QE
M=&4@96UP='D@9&ER96-T;W)I97,*("`@("`@("`@("`@=6MS;W)T*"1F:6QE
M;&ES=%LG9&ER=')E92==+"!A<G)A>2@D=&AI<RP@)U]S;W)T1&ER<R<I*3L*
M("`@("`@("`@("`@9F]R96%C:"@D9FEL96QI<W1;)V1I<G1R964G72!A<R`D
M9&ER(#T^("1N;W1U<V5D*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^861D
M1FEL94]P97)A=&EO;B@G<FUD:7(G+"!A<G)A>2@D9&ER*2D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"$D=&AI<RT^8V]M;6ET1FEL951R86YS
M86-T:6]N*"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YR;VQL8F%C:T9I
M;&54<F%N<V%C=&EO;B@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("\O('U]?0H*("`@("`@("`O+R!296=I<W1E<B!T:&%T('1H92!P86-K
M86=E(&ES(&YO(&QO;F=E<B!I;G-T86QL960*("`@("`@("!R971U<FX@)'1H
M:7,M/G)E9VES=')Y+3YD96QE=&5086-K86=E*"1P86-K86=E*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!?<V]R=$1I<G,H*0H@("`@9G5N8W1I
M;VX@7W-O<G1$:7)S*"1A+"`D8BD*("`@('L*("`@("`@("!I9B`H<W1R;F%T
M8VUP*"1A+"`D8BD@/3T@+3$I(')E='5R;B`Q.PH@("`@("`@(&EF("AS=')N
M871C;7`H)&$L("1B*2`]/2`Q*2!R971U<FX@+3$["B`@("`@("`@<F5T=7)N
M(#`["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8VAE8VM$97!S*"D*
M"B`@("`O*BH*("`@("`J($-H96-K(&EF('1H92!P86-K86=E(&UE971S(&%L
M;"!D97!E;F1E;F-I97,*("`@("`J"B`@("`@*B!`<&%R86T@(&%R<F%Y("`@
M4&%C:V%G92!I;F9O<FUA=&EO;B`H<&%S<V5D(&)Y(')E9F5R96YC92D*("`@
M("`J($!P87)A;2`@<W1R:6YG("!%<G)O<B!M97-S86=E("AP87-S960@8GD@
M<F5F97)E;F-E*0H@("`@("H@0')E='5R;B!B;V]L96%N($9A;'-E('=H96X@
M;F\@97)R;W(@;V-C=7)E9"P@;W1H97)W:7-E('1R=64*("`@("`J+PH@("`@
M9G5N8W1I;VX@8VAE8VM$97!S*"8D<&MG:6YF;RP@)B1E<G)O<G,I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YR96=I<W1R>2DI('L*("`@("`@
M("`@("`@)'1H:7,M/G)E9VES=')Y(#T@)FYE=R!014%27U)E9VES=')Y*"1T
M:&ES+3YC;VYF:6<M/F=E="@G<&AP7V1I<B<I*3L*("`@("`@("!]"B`@("`@
M("`@)&1E<&-H96-K97(@/2`F;F5W(%!%05)?1&5P96YD96YC>2@D=&AI<RT^
M<F5G:7-T<GDI.PH@("`@("`@("1E<G)O<B`]("1E<G)O<G,@/2`G)SL*("`@
M("`@("`D9F%I;&5D7V1E<',@/2`D;W!T:6]N86Q?9&5P<R`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1P:V=I;F9O6R=R96QE87-E7V1E<',G
M72DI('L*("`@("`@("`@("`@9F]R96%C:"@D<&MG:6YF;ULG<F5L96%S95]D
M97!S)UT@87,@)&1E<"D@>PH@("`@("`@("`@("`@("`@)&-O9&4@/2`D9&5P
M8VAE8VME<BT^8V%L;$-H96-K365T:&]D*"1E<G)O<BP@)&1E<"D["B`@("`@
M("`@("`@("`@("!I9B`H)&-O9&4I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&1E<%LG;W!T:6]N86PG72D@)B8@)&1E<%LG;W!T:6]N86PG
M72`]/2`G>65S)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N
M86Q?9&5P<UM=(#T@87)R87DH)&1E<"P@)&-O9&4L("1E<G)O<BD["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&9A:6QE9%]D97!S6UT@/2!A<G)A>2@D9&5P+"`D8V]D92P@)&5R<F]R
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@+R\@>WM[(&9A:6QE9"!D97!E;F1E
M;F-I97,*("`@("`@("`@("`@)&X@/2!C;W5N="@D9F%I;&5D7V1E<',I.PH@
M("`@("`@("`@("!I9B`H)&X@/B`P*2!["B`@("`@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D;CL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9F%I;&5D7V1E<'-;)&E=6R=T>7!E)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)&9A:6QE9%]D97!S6R1I75LG
M='EP92==.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T>7!E(#T@)W!K9R<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)&9A:6QE9%]D
M97!S6R1I75LQ72D@>PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(%!%
M05)?1$5014Y$14Y#65]-25-324Y'.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1T>7!E(#T]("=P:V<G*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@:6YS=&%L;`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R
M<R`N/2`B7&XB("X@)&9A:6QE9%]D97!S6R1I75LR73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E(%!%05)?1$5014Y$14Y#65]54$=2041%7TU)3D]2.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=P:V<G*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=7!G<F%D90H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5R<F]R<R`N/2`B7&XB("X@)&9A:6QE9%]D97!S6R1I75LR
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5R<F]R<R`N/2`B7&XB("X@)&9A:6QE9%]D97!S6R1I75LR
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O
M('U]?0H*("`@("`@("`@("`@+R\@>WM[(&]P=&EO;F%L(&1E<&5N9&5N8VEE
M<PH@("`@("`@("`@("`D8V]U;G1?;W!T:6]N86P@/2!C;W5N="@D;W!T:6]N
M86Q?9&5P<RD["B`@("`@("`@("`@(&EF("@D8V]U;G1?;W!T:6]N86P@/B`P
M*2!["B`@("`@("`@("`@("`@("`D97)R;W)S(#T@(D]P=&EO;F%L(&1E<&5N
M9&5N8VEE<SHB.PH*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1C;W5N=%]O<'1I;VYA;#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N86Q?9&5P<ULD:5U;)W1Y<&4G72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`D;W!T:6]N86Q?9&5P<ULD
M:5U;)W1Y<&4G73L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D='EP92`]("=P:V<G.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*"1O<'1I
M;VYA;%]D97!S6R1I75LQ72D@>PH@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E(%!%05)?1$5014Y$14Y#65]-25-324Y'.@H@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E(%!%05)?1$5014Y$14Y#65]54$=2041%7TU)3D]2.@H@
M("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&5R<F]R<R`N/2`B7&XB("X@)&]P=&EO;F%L7V1E
M<'-;)&E=6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("\O('U]?0H@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7V)U:6QD0V%L;&)A8VLH
M*0H*("`@(&9U;F-T:6]N(%]B=6EL9$-A;&QB86-K*"1W:&%T+"`D9&%T82D*
M("`@('L*("`@("`@("!I9B`H*"1W:&%T(#T]("=C;61O=71P=70G("8F("1T
M:&ES+3YD96)U9R`^(#$I('Q\"B`@("`@("`@("`@("@D=VAA="`]/2`G;W5T
M<'5T)R`F)B`D=&AI<RT^9&5B=6<@/B`P*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H<G1R:6TH)&1A=&$I+"`G8G5I;&0G*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+R\@?7U]"GT*"B\O('M[>R!M9#5?9FEL92@I
M('5T:6QI='D@9G5N8W1I;VX*:68@*"%F=6YC=&EO;E]E>&ES=',H(FUD-5]F
M:6QE(BDI('L*("`@(&9U;F-T:6]N(&UD-5]F:6QE*"1F:6QE;F%M92D@>PH@
M("`@("`@("1F<"`](&9O<&5N*"1F:6QE;F%M92P@(G(B*3L*("`@("`@("!I
M9B`H(21F<"D@<F5T=7)N(&YU;&P["B`@("`@("`@)&-O;G1E;G1S(#T@9G)E
M860H)&9P+"!F:6QE<VEZ92@D9FEL96YA;64I*3L*("`@("`@("!F8VQO<V4H
M)&9P*3L*("`@("`@("!R971U<FX@;60U*"1C;VYT96YT<RD["B`@("!]"GT*
M+R\@?7U]"@H_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3U,O
M````````````````````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C,P,#8`,#$U-C8T`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]/4R]'=65S<RYP:'``````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#`S-0`Q,#0Q-S,V,S`P-@`P,3<T
M-C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R<SH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@1W5E<W,N<&AP+'8@,2XQ,R`R,#`T+S`Q
M+S`X(#$W.C,S.C$Q('-N:7!E<B!%>'`@)`H*+R\@>WM[('5N86UE(&5X86UP
M;&5S"@HO+R!P:'!?=6YA;64H*2!W:71H;W5T(&%R9W,@<F5T=7)N<R!T:&4@
M<V%M92!A<R`G=6YA;64@+6$G+"!O<B!A(%!(4"UC=7-T;VT*+R\@<W1R:6YG
M(&9O<B!7:6YD;W=S+@HO+R!02%`@=F5R<VEO;G,@<')I;W(@=&\@-"XS(')E
M='5R;B!T:&4@=6YA;64@;V8@=&AE(&AO<W0@=VAE<F4@4$A0('=A<R!B=6EL
M="P*+R\@87,@;V8@-"XS(&ET(')E='5R;G,@=&AE('5N86UE(&]F('1H92!H
M;W-T(')U;FYI;F<@=&AE(%!(4"!C;V1E+@HO+PHO+R!00R!2961(870@3&EN
M=7@@-RXQ.@HO+R!,:6YU>"!H;W-T+F5X86UP;&4N8V]M(#(N-"XR+3(@(S$@
M4W5N($%P<B`X(#(P.C0Q.C,P($5$5"`R,#`Q(&DV.#8@=6YK;F]W;@HO+PHO
M+R!00R!$96)I86X@4&]T871O.@HO+R!,:6YU>"!H;W-T(#(N-"XQ-R`C,B!3
M35`@5'5E($9E8B`Q,B`Q-3HQ,#HP-"!#150@,C`P,B!I-C@V('5N:VYO=VX*
M+R\*+R\@4$,@1G)E94)31"`S+C,Z"B\O($9R965"4T0@:&]S="YE>&%M<&QE
M+F-O;2`S+C,M4U1!0DQ%($9R965"4T0@,RXS+5-404),12`C,#H@36]N($9E
M8B`R,2`P,#HT,CHS,2!#150@,C`P,"`@("`@<F]O=$!E>&%M<&QE+F-O;3HO
M=7-R+W-R8R]S>7,O8V]M<&EL92]#3TY&24<@(&DS.#8*+R\*+R\@4$,@1G)E
M94)31"`T+C,Z"B\O($9R965"4T0@:&]S="YE>&%M<&QE+F-O;2`T+C,M4D5,
M14%312!&<F5E0E-$(#0N,RU214Q%05-%(",Q.B!-;VX@2G5N(#(U(#$Q.C$Y
M.C0S($5$5"`R,#`Q("`@("!R;V]T0&5X86UP;&4N8V]M.B]U<W(O<W)C+W-Y
M<R]C;VUP:6QE+T-/3D9)1R`@:3,X-@HO+PHO+R!00R!&<F5E0E-$(#0N-3H*
M+R\@1G)E94)31"!H;W-T+F5X86UP;&4N8V]M(#0N-2U35$%"3$4@1G)E94)3
M1"`T+C4M4U1!0DQ%(",P.B!7960@1F5B("`V(#(S.C4Y.C(S($-%5"`R,#`R
M("`@("!R;V]T0&5X86UP;&4N8V]M.B]U<W(O<W)C+W-Y<R]C;VUP:6QE+T-/
M3D9)1R`@:3,X-@HO+PHO+R!00R!&<F5E0E-$(#0N-2!W+W5N86UE(&9R;VT@
M1TY5('-H96QL=71I;',Z"B\O($9R965"4T0@:&]S="YE>&%M<&QE+F-O;2`T
M+C4M4U1!0DQ%($9R965"4T0@-"XU+5-404),12`C,#H@5V5D($9E8B`@:3,X
M-B!U;FMN;W=N"B\O"B\O($A0(#DP,#`O-S$R($A0+558(#$P.@HO+R!(4"U5
M6"!I<2!"+C$P+C$P($$@.3`P,"\W,3(@,C`P.#0R.3$Q,R!T=V\M=7-E<B!L
M:6-E;G-E"B\O"B\O($A0(#DP,#`O-S$R($A0+558(#$P('<O=6YA;64@9G)O
M;2!'3E4@<VAE;&QU=&EL<SH*+R\@2%`M55@@:&]S="!"+C$P+C$P($$@.3`P
M,"\W,3(@=6YK;F]W;@HO+PHO+R!)0DT@4E,V,#`P+S4U,"!!25@@-"XS.@HO
M+R!!25@@:&]S="`S(#0@,#`P,#`S-3,Q0S`P"B\O"B\O($%)6"`T+C,@=R]U
M;F%M92!F<F]M($=.52!S:&5L;'5T:6QS.@HO+R!!25@@:&]S="`S(#0@,#`P
M,#`S-3,Q0S`P('5N:VYO=VX*+R\*+R\@4T=)($]N>7@@25))6"`V+C4@=R]U
M;F%M92!F<F]M($=.52!S:&5L;'5T:6QS.@HO+R!)4DE8-C0@:&]S="`V+C4@
M,#$P.3$X,C`@25`Q.2!M:7!S"B\O"B\O(%-'22!/;GEX($E225@@-BXU.@HO
M+R!)4DE8-C0@:&]S="`V+C4@,#$P.3$X,C`@25`Q.0HO+PHO+R!3<&%R8U-T
M871I;VX@,C`@4V]L87)I<R`X('<O=6YA;64@9G)O;2!'3E4@<VAE;&QU=&EL
M<SH*+R\@4W5N3U,@:&]S="YE>&%M<&QE+F-O;2`U+C@@1V5N97)I8U\Q,#@U
M,C@M,3(@<W5N-&T@<W!A<F,*+R\*+R\@4W!A<F-3=&%T:6]N(#(P(%-O;&%R
M:7,@.#H*+R\@4W5N3U,@:&]S="YE>&%M<&QE+F-O;2`U+C@@1V5N97)I8U\Q
M,#@U,C@M,3(@<W5N-&T@<W!A<F,@4U5.5RQ34$%20W-T871I;VXM,C`*+R\*
M"B\O('U]?0H*+RH@5$]$3SH*("H@+2!D969I;F4@96YD:6%N;F5S<RP@=&\@
M86QL;W<@;6%T8VA3:6=N871U<F4H(F)I9V5N9"(I(&5T8RX*("HO"@IC;&%S
M<R!/4U]'=65S<PI["B`@("!V87(@)'-Y<VYA;64["B`@("!V87(@)&YO9&5N
M86UE.PH@("`@=F%R("1C<'4["B`@("!V87(@)')E;&5A<V4["B`@("!V87(@
M)&5X=')A.PH*("`@(&9U;F-T:6]N($]37T=U97-S*"1U;F%M92`](&YU;&PI
M"B`@("!["B`@("`@("`@;&ES="@D=&AI<RT^<WES;F%M92P*("`@("`@("`@
M("`@("1T:&ES+3YR96QE87-E+`H@("`@("`@("`@("`@)'1H:7,M/F-P=2P*
M("`@("`@("`@("`@("1T:&ES+3YE>'1R82P*("`@("`@("`@("`@("1T:&ES
M+3YN;V1E;F%M92D@/2`D=&AI<RT^<&%R<V53:6=N871U<F4H)'5N86UE*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!P87)S95-I9VYA='5R92@D=6YA;64@/2!N
M=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D<WES;6%P(#T@87)R87DH"B`@
M("`@("`@("`@("=(4"U56"<@/3X@)VAP=7@G+`H@("`@("`@("`@("`G25))
M6#8T)R`]/B`G:7)I>"<L"B`@("`@("`@("`@("\O($1A<G=I;C\*("`@("`@
M("`I.PH@("`@("`@('-T871I8R`D8W!U;6%P(#T@87)R87DH"B`@("`@("`@
M("`@("=I-3@V)R`]/B`G:3,X-B<L"B`@("`@("`@("`@("=I-C@V)R`]/B`G
M:3,X-B<L"B`@("`@("`@*3L*("`@("`@("!I9B`H)'5N86UE(#T]/2!N=6QL
M*2!["B`@("`@("`@("`@("1U;F%M92`]('!H<%]U;F%M92@I.PH@("`@("`@
M('T*("`@("`@("`D<&%R=',@/2!S<&QI="@G6ULZ<W!A8V4Z75TK)RP@=')I
M;2@D=6YA;64I*3L*("`@("`@("`D;B`](&-O=6YT*"1P87)T<RD["@H@("`@
M("`@("1R96QE87-E(#T@)&UA8VAI;F4@/2`D8W!U(#T@)R<["B`@("`@("`@
M)'-Y<VYA;64@/2`D<&%R='-;,%T["B`@("`@("`@)&YO9&5N86UE(#T@)'!A
M<G1S6S%=.PH@("`@("`@("1C<'4@/2`D<&%R='-;)&XM,5T["B`@("`@("`@
M)&5X=')A(#T@)R<["B`@("`@("`@:68@*"1C<'4@/3T@)W5N:VYO=VXG*2![
M"B`@("`@("`@("`@("1C<'4@/2`D<&%R='-;)&XM,ET["B`@("`@("`@?0H*
M("`@("`@("!S=VET8V@@*"1S>7-N86UE*2!["B`@("`@("`@("`@(&-A<V4@
M)T%)6"<Z"B`@("`@("`@("`@("`@("`D<F5L96%S92`]("(D<&%R='-;,UTN
M)'!A<G1S6S)=(CL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!C87-E("=7:6YD;W=S)SH*("`@("`@("`@("`@("`@('-W:71C:"`H)'!A
M<G1S6S%=*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G.34O.3@G.@H@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S92`]("<Y>"<["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E(#T@
M)'!A<G1S6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C<'4@/2`G:3,X-B<[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G3&EN
M=7@G.@H@("`@("`@("`@("`@("`@)&5X=')A(#T@)'1H:7,M/E]D971E8W1'
M;&EB8U9E<G-I;VXH*3L*("`@("`@("`@("`@("`@("\O('5S92!O;FQY('1H
M92!F:7)S="!T=V\@9&EG:71S(&9R;VT@=&AE(&ME<FYE;"!V97)S:6]N"B`@
M("`@("`@("`@("`@("`D<F5L96%S92`](&5R96=?<F5P;&%C92@G7BA;6SID
M:6=I=#I=72M<+EM;.F1I9VET.EU=*RDN*B<L("=<,2<L("1P87)T<ULR72D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@("`@("1R96QE87-E(#T@97)E9U]R97!L86-E*"<M+BHG
M+"`G)RP@)'!A<G1S6S)=*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"@H@("`@("`@(&EF("AI<W-E="@D<WES;6%P6R1S>7-N86UE72DI
M('L*("`@("`@("`@("`@)'-Y<VYA;64@/2`D<WES;6%P6R1S>7-N86UE73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<WES;F%M92`]('-T<G1O
M;&]W97(H)'-Y<VYA;64I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)&-P=6UA<%LD8W!U72DI('L*("`@("`@("`@("`@)&-P=2`]("1C<'5M87!;
M)&-P=5T["B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>2@D<WES;F%M
M92P@)')E;&5A<V4L("1C<'4L("1E>'1R82P@)&YO9&5N86UE*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?9&5T96-T1VQI8F-697)S:6]N*"D*("`@('L*("`@
M("`@("`O+R!5<V4@9VQI8F,G<R`\9F5A='5R97,N:#X@:&5A9&5R(&9I;&4@
M=&\*("`@("`@("`O+R!G970@;6%J;W(@86YD(&UI;F]R('9E<G-I;VX@;G5M
M8F5R.@H@("`@("`@(&EN8VQU9&5?;VYC92`B4WES=&5M+G!H<"(["B`@("`@
M("`@)'1M<&9I;&4@/2!3>7-T96TZ.FUK=&5M<"@B9VQI8F-T97-T(BD["B`@
M("`@("`@)&9P(#T@9F]P96XH)'1M<&9I;&4L(")W(BD["B`@("`@("`@9G=R
M:71E*"1F<"P@(B-I;F-L=61E(#QF96%T=7)E<RYH/EQN7U]'3$E"0U]?(%]?
M1TQ)0D-?34E.3U)?7UQN(BD["B`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@
M("`@)&-P<"`]('!O<&5N*"(O=7-R+V)I;B]C<'`@)'1M<&9I;&4B+"`B<B(I
M.PH@("`@("`@("1M86IO<B`]("1M:6YO<B`](#`["B`@("`@("`@=VAI;&4@
M*"1L:6YE(#T@9F=E=',H)&-P<"P@,3`R-"DI('L*("`@("`@("`@("`@:68@
M*"1L:6YE>S!](#T]("<C)R!\?"!T<FEM*"1L:6YE*2`]/2`G)RD@>PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&QI<W0H)&UA:F]R+"`D;6EN;W(I(#T@97AP;&]D92@G("<L('1R
M:6TH)&QI;F4I*2D@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1C<'`I.PH@("`@("`@
M('5N;&EN:R@D=&UP9FEL92D["B`@("`@("`@:68@*"$H)&UA:F]R("8F("1M
M:6YO<BD@)B8@:7-?;&EN:R@G+VQI8B]L:6)C+G-O+C8G*2D@>PH@("`@("`@
M("`@("`O+R!,970G<R!T<GD@<F5A9&EN9R!T:&4@;&EB8RYS;RXV('-Y;6QI
M;FL*("`@("`@("`@("`@:68@*&5R96<H)UYL:6)C+2A;+BI=*5PN<V\D)RP@
M8F%S96YA;64H<F5A9&QI;FLH)R]L:6(O;&EB8RYS;RXV)RDI+"`D;6%T8VAE
M<RDI('L*("`@("`@("`@("`@("`@(&QI<W0H)&UA:F]R+"`D;6EN;W(I(#T@
M97AP;&]D92@G+B<L("1M871C:&5S*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H(2@D;6%J;W(@)B8@)&UI;F]R*2D@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@("`@(')E='5R;B`B9VQI
M8F-[)&UA:F]R?2Y[)&UI;F]R?2(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M4VEG;F%T=7)E*"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/F5X
M=')A*2D@>PH@("`@("`@("`@("!R971U<FX@(GLD=&AI<RT^<WES;F%M97TM
M>R1T:&ES+3YR96QE87-E?2U[)'1H:7,M/F-P=7TB.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@(GLD=&AI<RT^<WES;F%M97TM>R1T:&ES+3YR96QE87-E
M?2U[)'1H:7,M/F-P=7TM>R1T:&ES+3YE>'1R87TB.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=%-Y<VYA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^<WES;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971.;V1E;F%M92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YN;V1E;F%M93L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971#<'4H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^8W!U.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%)E;&5A<V4H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5L96%S93L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971%>'1R82@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YE>'1R83L*("`@('T*"B`@("!F=6YC=&EO;B!M871C:%-I9VYA='5R
M92@D;6%T8V@I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1M871C:"DI
M('L*("`@("`@("`@("`@)&9R86=M96YT<R`]("1M871C:#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9G)A9VUE;G1S(#T@97AP;&]D92@G+2<L
M("1M871C:"D["B`@("`@("`@?0H@("`@("`@("1N(#T@8V]U;G0H)&9R86=M
M96YT<RD["B`@("`@("`@)&UA=&-H97,@/2`P.PH@("`@("`@(&EF("@D;B`^
M(#`I('L*("`@("`@("`@("`@)&UA=&-H97,@*ST@)'1H:7,M/E]M871C:$9R
M86=M96YT*"1F<F%G;65N='-;,%TL("1T:&ES+3YS>7-N86UE*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"1N(#X@,2D@>PH@("`@("`@("`@("`D;6%T8VAE
M<R`K/2`D=&AI<RT^7VUA=&-H1G)A9VUE;G0H)&9R86=M96YT<ULQ72P@)'1H
M:7,M/G)E;&5A<V4I.PH@("`@("`@('T*("`@("`@("!I9B`H)&X@/B`R*2![
M"B`@("`@("`@("`@("1M871C:&5S("L]("1T:&ES+3Y?;6%T8VA&<F%G;65N
M="@D9G)A9VUE;G1S6S)=+"`D=&AI<RT^8W!U*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1N(#X@,RD@>PH@("`@("`@("`@("`D;6%T8VAE<R`K/2`D=&AI
M<RT^7VUA=&-H1G)A9VUE;G0H)&9R86=M96YT<ULS72P@)'1H:7,M/F5X=')A
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("@D;6%T8VAE<R`]/2`D;BD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7VUA=&-H1G)A9VUE;G0H)&9R86=M96YT
M+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*'-T<F-S<&XH)&9R86=M96YT
M+"`G*C\G*2`\('-T<FQE;B@D9G)A9VUE;G0I*2!["B`@("`@("`@("`@("1R
M96<@/2`G7B<@+B!S=')?<F5P;&%C92AA<G)A>2@G*B<L("<_)RP@)R\G*2P@
M87)R87DH)RXJ)RP@)RXG+"`G7%PO)RDL("1F<F%G;65N="D@+B`G)"<["B`@
M("`@("`@("`@(')E='5R;B!E<F5G:2@D<F5G+"`D=F%L=64I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@*"1F<F%G;65N="`]/2`G*B<@?'P@(7-T<F-A
M<V5C;7`H)&9R86=M96YT+"`D=F%L=64I*3L*("`@('T*"GT*"B\J"B`J($QO
M8V%L(%9A<FEA8FQE<SH*("H@:6YD96YT+71A8G,M;6]D93H@;FEL"B`J(&,M
M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B].970O````````````````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-@`P,38P-S$`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+TYE="]$3E,O````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S
M,#`V`#`Q-C4Q-0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+T1.
M4R]24B\`````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,#8`,#$W,#0P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B].970O1$Y3+U)2+T-.04U%+G!H<```````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3`U-P`Q,#0Q-S,V,S`P-@`P,C`T,#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RH*("H@($QI8V5N<V4@26YF;W)M871I;VXZ"B`J"B`J("`@($YE=%]$
M3E,Z("!!(')E<V]L=F5R(&QI8G)A<GD@9F]R(%!(4`H@*B`@("!#;W!Y<FEG
M:'0@*&,I(#(P,#(M,C`P,R!%<FEC($MI;&9O:6P@97)I8T!Y<&%S<RYN970*
M("H*("H@("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C
M86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@*B`@("!M;V1I9GD@:70@=6YD
M97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC
M"B`J("`@($QI8V5N<V4@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W
M87)E($9O=6YD871I;VX[(&5I=&AE<@H@*B`@("!V97)S:6]N(#(N,2!O9B!T
M:&4@3&EC96YS92P@;W(@*&%T('EO=7(@;W!T:6]N*2!A;GD@;&%T97(@=F5R
M<VEO;BX*("H*("H@("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN
M('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`J("`@(&)U="!7
M251(3U54($%.62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D
M('=A<G)A;G1Y(&]F"B`J("`@($U%4D-(04Y404))3$E462!O<B!&251.15-3
M($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`J("`@
M($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I
M;',N"B`J"B`J("`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@
M;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("H@("`@3&EC96YS
M92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T
M:&4@1G)E92!3;V9T=V%R90H@*B`@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!4
M96UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+"!-02`@,#(Q,3$M,3,P
M-R`@55-!"B`J+PH*+RH@3F5T7T1.4U]24E]#3D%-12!D969I;FET:6]N('M[
M>R`J+PHO*BH*("H@02!R97!R97-E;G1A=&EO;B!O9B!A(')E<V]U<F-E(')E
M8V]R9"!O9B!T>7!E(#QB/D-.04U%/"]B/@H@*@H@*B!`<&%C:V%G92!.971?
M1$Y3"B`J+PIC;&%S<R!.971?1$Y37U)27T-.04U%(&5X=&5N9',@3F5T7T1.
M4U]24@I["B`@("`O*B!C;&%S<R!V87)I86)L92!D969I;FET:6]N<R![>WL@
M*B\*("`@('9A<B`D;F%M93L*("`@('9A<B`D='EP93L*("`@('9A<B`D8VQA
M<W,["B`@("!V87(@)'1T;#L*("`@('9A<B`D<F1L96YG=&@["B`@("!V87(@
M)')D871A.PH@("`@=F%R("1C;F%M93L*"B`@("`O*B!]?7T@*B\*("`@("\J
M(&-L87-S(&-O;G-T<G5C=&]R("T@4E(H)B1R<F\L("1D871A+"`D;V9F<V5T
M(#T@)R<I('M[>R`J+PH@("`@9G5N8W1I;VX@3F5T7T1.4U]24E]#3D%-12@F
M)')R;RP@)&1A=&$L("1O9F9S970@/2`G)RD*("`@('L*("`@("`@("`D=&AI
M<RT^;F%M92`]("1R<F\M/FYA;64["B`@("`@("`@)'1H:7,M/G1Y<&4@/2`D
M<G)O+3YT>7!E.PH@("`@("`@("1T:&ES+3YC;&%S<R`]("1R<F\M/F-L87-S
M.PH@("`@("`@("1T:&ES+3YT=&P@/2`D<G)O+3YT=&P["B`@("`@("`@)'1H
M:7,M/G)D;&5N9W1H(#T@)')R;RT^<F1L96YG=&@["B`@("`@("`@)'1H:7,M
M/G)D871A(#T@)')R;RT^<F1A=&$["@H@("`@("`@(&EF("@D;V9F<V5T*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^<F1L96YG=&@@/B`P*2!["B`@("`@
M("`@("`@("`@("!L:7-T*"1C;F%M92P@)&]F9G-E="D@/2!.971?1$Y37U!A
M8VME=#HZ9&Y?97AP86YD*"1D871A+"`D;V9F<V5T*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YC;F%M92`]("1C;F%M93L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YC;F%M92`](&5R96=?
M<F5P;&%C92@B6R!<=%TK*"XK*5M<+B!<=%TJ)"(L("=<7#$G+"`D9&%T82D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.
M4U]24E]#3D%-13HZ<F1A=&%S='(H*2![>WL@*B\*("`@(&9U;F-T:6]N(')D
M871A<W1R*"D*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1T:&ES+3YC;F%M
M92DI('L*("`@("`@("`@("`@<F5T=7)N*"1T:&ES+3YC;F%M92`N("<N)RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B@G.R!N;R!D871A)RD["B`@("!]
M"@H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)27T-.04U%.CIR<E]R
M9&%T82@D<&%C:V5T+"`D;V9F<V5T*2![>WL@*B\*("`@(&9U;F-T:6]N(')R
M7W)D871A*"1P86-K970L("1O9F9S970I"B`@("!["B`@("`@("`@:68@*'-T
M<FQE;B@D=&AI<RT^8VYA;64I*2!["B`@("`@("`@("`@(')E='5R;B@D<&%C
M:V5T+3YD;E]C;VUP*"1T:&ES+3YC;F%M92P@)&]F9G-E="DI.PH@("`@("`@
M('T*("`@("`@("!R971U<FXH3E5,3"D["B`@("!]"@H@("`@+RH@?7U]("HO
M"GT*+RH@?7U]("HO"B\J(%9)32!S971T:6YG<R![>WL*("H@3&]C86P@=F%R
M:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*
M("H@<V]F="US=&]P+7=I9'1H.B`T"B`J(&,@:6YD96YT(&]N"B`J($5N9#H*
M("H@=FEM-C`P.B!S=STT('1S/30@<W1S/30@8VEN9&5N="!F9&T];6%R:V5R
M(&5T"B`J('9I;3PV,#`Z('-W/30@=',]-`H@*B!]?7T@*B\*/SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TYE="]$
M3E,O4E(O02YP:'``````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`V,S,V`#$P-#$W,S8S,#`V`#`Q-S<S-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*@H@*B`@3&EC96YS
M92!);F9O<FUA=&EO;CH*("H*("H@("`@3F5T7T1.4SH@($$@<F5S;VQV97(@
M;&EB<F%R>2!F;W(@4$A0"B`J("`@($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S
M($5R:6,@2VEL9F]I;"!E<FEC0'EP87-S+FYE=`H@*@H@*B`@("!4:&ES(&QI
M8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@
M:70@86YD+V]R"B`J("`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@
M=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("H@("`@3&EC96YS92!A
M<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;CL@
M96ET:&5R"B`J("`@('9E<G-I;VX@,BXQ(&]F('1H92!,:6-E;G-E+"!O<B`H
M870@>6]U<B!O<'1I;VXI(&%N>2!L871E<B!V97)S:6]N+@H@*@H@*B`@("!4
M:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I
M="!W:6QL(&)E('5S969U;"P*("H@("`@8G5T(%=)5$A/550@04Y9(%=!4E)!
M3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("H@
M("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!
M4B!055)03U-%+B`@4V5E('1H92!'3E4*("H@("`@3&5S<V5R($=E;F5R86P@
M4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*("H*("H@("`@66]U
M('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E
M<B!'96YE<F%L(%!U8FQI8PH@*B`@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI
M<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E
M"B`J("`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I
M=&4@,S,P+"!";W-T;VXL($U!("`P,C$Q,2TQ,S`W("!54T$*("HO"@H*+RH@
M3F5T7T1.4U]24E]!(&]B:F5C="!D969I;FET:6]N('M[>R`J+PHO*BH*("H@
M02!R97!R97-E;G1A=&EO;B!O9B!A(')E<V]U<F-E(')E8V]R9"!O9B!T>7!E
M(#QB/D$\+V(^"B`J"B`J($!P86-K86=E($YE=%]$3E,*("HO"F-L87-S($YE
M=%]$3E-?4E)?02!E>'1E;F1S($YE=%]$3E-?4E(*>PH@("`@+RH@8VQA<W,@
M=F%R:6%B;&4@9&5F:6YI=&EO;G,@>WM[("HO"B`@("!V87(@)&YA;64["B`@
M("!V87(@)'1Y<&4["B`@("!V87(@)&-L87-S.PH@("`@=F%R("1T=&P["B`@
M("!V87(@)')D;&5N9W1H.PH@("`@=F%R("1R9&%T83L*("`@('9A<B`D861D
M<F5S<SL*("`@("\J('U]?2`J+PH@("`@+RH@8VQA<W,@8V]N<W1R=6-T;W(@
M+2!.971?1$Y37U)27T$H)B1R<F\L("1D871A+"`D;V9F<V5T(#T@)R<I('M[
M>R`J+PH@("`@9G5N8W1I;VX@3F5T7T1.4U]24E]!*"8D<G)O+"`D9&%T82P@
M)&]F9G-E="`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3YN86UE(#T@)')R
M;RT^;F%M93L*("`@("`@("`D=&AI<RT^='EP92`]("1R<F\M/G1Y<&4["B`@
M("`@("`@)'1H:7,M/F-L87-S(#T@)')R;RT^8VQA<W,["B`@("`@("`@)'1H
M:7,M/G1T;"`]("1R<F\M/G1T;#L*("`@("`@("`D=&AI<RT^<F1L96YG=&@@
M/2`D<G)O+3YR9&QE;F=T:#L*("`@("`@("`D=&AI<RT^<F1A=&$@/2`D<G)O
M+3YR9&%T83L*"B`@("`@("`@:68@*"1O9F9S970I('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YR9&QE;F=T:"`^(#`I('L*("`@("`@("`@("`@("`@("\J
M"B`@("`@("`@("`@("`@("`@*B`@5V4@9&]N)W0@:&%V92!I;F5T7VYT;V$@
M:6X@4$A0/PH@("`@("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`@("`D
M87!A<G1S(#T@=6YP86-K*"=#-&(G+"`D=&AI<RT^<F1A=&$I.PH@("`@("`@
M("`@("`@("`@)&%D9'(@/2`D87!A<G1S6R=B,2==("X@)RXG("X*("`@("`@
M("`@("`@("`@("`@("`D87!A<G1S6R=B,B==("X@)RXG("X*("`@("`@("`@
M("`@("`@("`@("`D87!A<G1S6R=B,R==("X@)RXG("X*("`@("`@("`@("`@
M("`@("`@("`D87!A<G1S6R=B-"==.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F%D9')E<W,@/2`D861D<CL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("AS=')L96XH)&1A=&$I("8F(&5R96<H(BA;
M,"TY72LI7"XH6S`M.5TK*5PN*%LP+3E=*RE<+BA;,"TY72LI6R!<=%TJ)"(L
M("1D871A+"`D<F5G<RDI('L*("`@("`@("`@("`@("`@(&EF("@H)')E9W-;
M,5T@/CT@,"`F)B`D<F5G<ULQ72`\/2`R-34I("8F"B`@("`@("`@("`@("`@
M("`@("`@("`@("@D<F5G<ULR72`^/2`P("8F("1R96=S6S)=(#P](#(U-2D@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@*"1R96=S6S-=(#X](#`@)B8@
M)')E9W-;,UT@/#T@,C4U*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`H
M)')E9W-;-%T@/CT@,"`F)B`D<F5G<ULT72`\/2`R-34I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9')E<W,@/2`D<F5G<ULQ72`N("<N)R`N
M("1R96=S6S)=("X@)RXG("X@)')E9W-;,UT@+B`G+B<@+B1R96=S6S1=.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2`*("`@
M('T*"B`@("`O*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4E)?03HZ<F1A=&%S
M='(H*2![>WL@*B\*("`@(&9U;F-T:6]N(')D871A<W1R*"D*("`@('L*("`@
M("`@("!I9B`H<W1R;&5N*"1T:&ES+3YA9&1R97-S*2D@>PH@("`@("`@("`@
M("!R971U<FXH)'1H:7,M/F%D9')E<W,I.PH@("`@("`@('T*("`@("`@("!R
M971U<FXH)SL@;F\@9&%T82<I.PH@("`@?0H@("`@+RH@?7U]("HO"B`@("`O
M*B!.971?1$Y37U)27T$Z.G)R7W)D871A*"1P86-K970L("1O9F9S970I('M[
M>R`J+PH@("`@9G5N8W1I;VX@<G)?<F1A=&$H)'!A8VME="P@)&]F9G-E="D*
M("`@('L*("`@("`@("`D87!A<G1S(#T@<W!L:70H)UPN)RP@)'1H:7,M/F%D
M9')E<W,I.PH@("`@("`@(&EF("AC;W5N="@D87!A<G1S*2`]/2`T*2!["B`@
M("`@("`@("`@(')E='5R;BAP86-K*"=C-"<L("1A<&%R='-;,%TL("1A<&%R
M='-;,5TL("1A<&%R='-;,ETL("1A<&%R='-;,UTI*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N*$Y53$PI.PH@("`@?0H*("`@("\J('U]?2`J+PH*?0HO
M*B!]?7T@*B\*+RH@5DE-('-E='1I;F=S('M[>PH@*B!,;V-A;"!V87)I86)L
M97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!S
M;V9T+7-T;W`M=VED=&@Z(#0*("H@8R!I;F1E;G0@;VX*("H@16YD.@H@*B!V
M:6TV,#`Z('-W/30@=',]-"!S=',]-"!C:6YD96YT(&9D;3UM87)K97(@970*
M("H@=FEM/#8P,#H@<W<]-"!T<STT"B`J('U]?2`J+PH_/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O
M1$Y3+U)2+TU8+G!H<```````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-38U,P`Q,#0Q-S,V,S`P-@`P,C`Q,#,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RH*("H@($QI8V5N
M<V4@26YF;W)M871I;VXZ"B`J"B`J("`@($YE=%]$3E,Z("!!(')E<V]L=F5R
M(&QI8G)A<GD@9F]R(%!(4`H@*B`@("!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P
M,R!%<FEC($MI;&9O:6P@97)I8T!Y<&%S<RYN970*("H*("H@("`@5&AI<R!L
M:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E
M(&ET(&%N9"]O<@H@*B`@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F
M('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`J("`@($QI8V5N<V4@
M87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VX[
M(&5I=&AE<@H@*B`@("!V97)S:6]N(#(N,2!O9B!T:&4@3&EC96YS92P@;W(@
M*&%T('EO=7(@;W!T:6]N*2!A;GD@;&%T97(@=F5R<VEO;BX*("H*("H@("`@
M5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@
M:70@=VEL;"!B92!U<V5F=6PL"B`J("`@(&)U="!7251(3U54($%.62!705)2
M04Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`J
M("`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,
M05(@4%524$]312X@(%-E92!T:&4@1TY5"B`J("`@($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"B`J"B`J("`@(%EO
M=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S
M97(@1V5N97)A;"!0=6)L:6,*("H@("`@3&EC96YS92!A;&]N9R!W:71H('1H
M:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R
M90H@*B`@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U
M:71E(#,S,"P@0F]S=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!"B`J+PH*+RH@
M3F5T7T1.4U]24E]-6"!D969I;FET:6]N('M[>R`J+PHO*BH*("H@02!R97!R
M97-E;G1A=&EO;B!O9B!A(')E<V]U<F-E(')E8V]R9"!O9B!T>7!E(#QB/DU8
M/"]B/@H@*@H@*B!`<&%C:V%G92!.971?1$Y3"B`J+PIC;&%S<R!.971?1$Y3
M7U)27TU8(&5X=&5N9',@3F5T7T1.4U]24@I["B`@("`O*B!C;&%S<R!V87)I
M86)L92!D969I;FET:6]N<R![>WL@*B\*("`@('9A<B`D;F%M93L*("`@('9A
M<B`D='EP93L*("`@('9A<B`D8VQA<W,["B`@("!V87(@)'1T;#L*("`@('9A
M<B`D<F1L96YG=&@["B`@("!V87(@)')D871A.PH@("`@=F%R("1P<F5F97)E
M;F-E.PH@("`@=F%R("1E>&-H86YG93L*"B`@("`O*B!]?7T@*B\*("`@("\J
M(&-L87-S(&-O;G-T<G5C=&]R("T@4E(H)B1R<F\L("1D871A+"`D;V9F<V5T
M(#T@)R<I('M[>R`J+PH@("`@9G5N8W1I;VX@3F5T7T1.4U]24E]-6"@F)')R
M;RP@)&1A=&$L("1O9F9S970@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^
M;F%M92`]("1R<F\M/FYA;64["B`@("`@("`@)'1H:7,M/G1Y<&4@/2`D<G)O
M+3YT>7!E.PH@("`@("`@("1T:&ES+3YC;&%S<R`]("1R<F\M/F-L87-S.PH@
M("`@("`@("1T:&ES+3YT=&P@/2`D<G)O+3YT=&P["B`@("`@("`@)'1H:7,M
M/G)D;&5N9W1H(#T@)')R;RT^<F1L96YG=&@["B`@("`@("`@)'1H:7,M/G)D
M871A(#T@)')R;RT^<F1A=&$["@H@("`@("`@(&EF("@D;V9F<V5T*2!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^<F1L96YG=&@@/B`P*2!["B`@("`@("`@
M("`@("`@("`D82`]('5N<&%C:R@B0"1O9F9S970O;G!R969E<F5N8V4B+"`D
M9&%T82D["B`@("`@("`@("`@("`@("`D;V9F<V5T("L](#(["B`@("`@("`@
M("`@("`@("!L:7-T*"1E>&-H86YG92P@)&]F9G-E="D@/2!.971?1$Y37U!A
M8VME=#HZ9&Y?97AP86YD*"1D871A+"`D;V9F<V5T*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YP<F5F97)E;F-E(#T@)&%;)W!R969E<F5N8V4G73L*("`@
M("`@("`@("`@("`@("1T:&ES+3YE>&-H86YG92`]("1E>&-H86YG93L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5R96<H
M(BA;,"TY72LI6R!<=%TK*"XK*5L@7'1=*B0B+"`D9&%T82P@)')E9W,I.PH@
M("`@("`@("`@("`D=&AI<RT^<')E9F5R96YC92`]("1R96=S6S%=.PH@("`@
M("`@("`@("`D=&AI<RT^97AC:&%N9V4@/2!E<F5G7W)E<&QA8V4H)R@N*BE<
M+B0G+"`G7%PQ)RP@)')E9W-;,ETI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4E)?35@Z.G)D871A<W1R*"D@>WM[
M("HO"B`@("!F=6YC=&EO;B!R9&%T87-T<B@I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3YP<F5F97)E;F-E*2!["B`@("`@("`@("`@(')E='5R;B@D=&AI
M<RT^<')E9F5R96YC92`N("<@)R`N("1T:&ES+3YE>&-H86YG92`N("<N)RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B@G.R!N;R!D871A)RD["B`@("!]
M"@H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)27TU8.CIR<E]R9&%T
M82@D<&%C:V5T+"`D;V9F<V5T*2![>WL@*B\*("`@(&9U;F-T:6]N(')R7W)D
M871A*"1P86-K970L("1O9F9S970I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YP<F5F97)E;F-E*2!["B`@("`@("`@("`@("1R9&%T82`]('!A8VLH)VXG
M+"`D=&AI<RT^<')E9F5R96YC92D["B`@("`@("`@("`@("1R9&%T82`N/2`D
M<&%C:V5T+3YD;E]C;VUP*"1T:&ES+3YE>&-H86YG92P@)&]F9G-E="`K('-T
M<FQE;B@D<F1A=&$I*3L*("`@("`@("`@("`@<F5T=7)N*"1R9&%T82D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;BA.54Q,*3L*("`@('T*"B`@("`O*B!]
M?7T@*B\*?0HO*B!]?7T@*B\*+RH@5DE-('-E='1I;F=S('M[>PH@*B!,;V-A
M;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E
M=#H@-`H@*B!S;V9T+7-T;W`M=VED=&@Z(#0*("H@8R!I;F1E;G0@;VX*("H@
M16YD.@H@*B!V:6TV,#`Z('-W/30@=',]-"!S=',]-"!C:6YD96YT(&9D;3UM
M87)K97(@970*("H@=FEM/#8P,#H@<W<]-"!T<STT"B`J('U]?2`J+PH_/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TYE="]$3E,O4E(O3E,N<&AP````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,#4V`#$P-#$W
M,S8S,#`V`#`R,#`W-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*@H@*B`@3&EC96YS92!);F9O<FUA=&EO;CH*
M("H*("H@("`@3F5T7T1.4SH@($$@<F5S;VQV97(@;&EB<F%R>2!F;W(@4$A0
M"B`J("`@($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S($5R:6,@2VEL9F]I;"!E
M<FEC0'EP87-S+FYE=`H@*@H@*B`@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S
M;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`J("`@
M(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@
M1V5N97)A;"!0=6)L:6,*("H@("`@3&EC96YS92!A<R!P=6)L:7-H960@8GD@
M=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R"B`J("`@('9E
M<G-I;VX@,BXQ(&]F('1H92!,:6-E;G-E+"!O<B`H870@>6]U<B!O<'1I;VXI
M(&%N>2!L871E<B!V97)S:6]N+@H@*@H@*B`@("!4:&ES(&QI8G)A<GD@:7,@
M9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U
M;"P*("H@("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V
M96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("H@("`@34520TA!3E1!0DE,
M2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E
M('1H92!'3E4*("H@("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@
M9F]R(&UO<F4@9&5T86EL<RX*("H*("H@("`@66]U('-H;W5L9"!H879E(')E
M8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI
M8PH@*B`@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N
M;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`J("`@($9O=6YD871I
M;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL
M($U!("`P,C$Q,2TQ,S`W("!54T$*("HO"@HO*B!.971?1$Y37U)27TY3(&1E
M9FEN:71I;VX@>WM[("HO"B\J*@H@*B!!(')E<')E<V5N=&%T:6]N(&]F(&$@
M<F5S;W5R8V4@<F5C;W)D(&]F('1Y<&4@/&(^3E,\+V(^"B`J"B`J($!P86-K
M86=E($YE=%]$3E,*("HO"F-L87-S($YE=%]$3E-?4E)?3E,@97AT96YD<R!.
M971?1$Y37U)2"GL*("`@("\J(&-L87-S('9A<FEA8FQE(&1E9FEN=&EI;VYS
M('M[>R`J+PH@("`@=F%R("1N86UE.PH@("`@=F%R("1T>7!E.PH@("`@=F%R
M("1C;&%S<SL*("`@('9A<B`D='1L.PH@("`@=F%R("1R9&QE;F=T:#L*("`@
M('9A<B`D<F1A=&$["B`@("!V87(@)&YS9&YA;64["@H@("`@+RH@?7U]("HO
M"B`@("`O*B!C;&%S<R!C;VYS=')U8W1O<B`M(%)2*"8D<G)O+"`D9&%T82P@
M)&]F9G-E="`]("<G*2![>WL@*B\*("`@(&9U;F-T:6]N($YE=%]$3E-?4E)?
M3E,H)B1R<F\L("1D871A+"`D;V9F<V5T(#T@)R<I"B`@("!["B`@("`@("`@
M)'1H:7,M/FYA;64@/2`D<G)O+3YN86UE.PH@("`@("`@("1T:&ES+3YT>7!E
M(#T@)')R;RT^='EP93L*("`@("`@("`D=&AI<RT^8VQA<W,@/2`D<G)O+3YC
M;&%S<SL*("`@("`@("`D=&AI<RT^='1L(#T@)')R;RT^='1L.PH@("`@("`@
M("1T:&ES+3YR9&QE;F=T:"`]("1R<F\M/G)D;&5N9W1H.PH@("`@("`@("1T
M:&ES+3YR9&%T82`]("1R<F\M/G)D871A.PH*"B`@("`@("`@:68@*"1O9F9S
M970I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YR9&QE;F=T:"`^(#`I('L*
M("`@("`@("`@("`@("`@(&QI<W0H)&YS9&YA;64L("1O9F9S970I(#T@3F5T
M7T1.4U]086-K970Z.F1N7V5X<&%N9"@D9&%T82P@)&]F9G-E="D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^;G-D;F%M92`]("1N<V1N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/FYS
M9&YA;64@/2!E<F5G7W)E<&QA8V4H(EL@7'1=*R@N*RE;(%QT72HD(BP@)UQ<
M,2<L("1D871A*3L*("`@("`@("!]"B`@("!]"@H@("`@+RH@?7U]("HO"B`@
M("`O*B!.971?1$Y37U)27TY3.CIR9&%T87-T<B@I('M[>R`J+PH@("`@9G5N
M8W1I;VX@<F1A=&%S='(H*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)'1H
M:7,M/FYS9&YA;64I*2!["B`@("`@("`@("`@(')E='5R;B@D=&AI<RT^;G-D
M;F%M92`N("<N)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B@G.R!N;R!D
M871A)RD["B`@("!]"@H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)2
M7TY3.CIR<E]R9&%T82@D<&%C:V5T+"`D;V9F<V5T*2![>WL@*B\*("`@(&9U
M;F-T:6]N(')R7W)D871A*"1P86-K970L("1O9F9S970I"B`@("!["B`@("`@
M("`@:68@*'-T<FQE;B@D=&AI<RT^;G-D;F%M92DI('L*("`@("`@("`@("`@
M<F5T=7)N*"1P86-K970M/F1N7V-O;7`H)'1H:7,M/FYS9&YA;64L("1O9F9S
M970I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N*$Y53$PI.PH@("`@?0H*
M("`@("\J('U]?2`J+PI]"B\J('U]?2`J+PHO*B!624T@<V5T=&EN9W,@>WM[
M"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S
M:6,M;V9F<V5T.B`T"B`J('-O9G0M<W1O<"UW:61T:#H@-`H@*B!C(&EN9&5N
M="!O;@H@*B!%;F0Z"B`J('9I;38P,#H@<W<]-"!T<STT('-T<STT(&-I;F1E
M;G0@9F1M/6UA<FME<B!E=`H@*B!V:6T\-C`P.B!S=STT('1S/30*("H@?7U]
M("HO"C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O3F5T+T1.4R]24B]33T$N<&AP````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3$P,#8`,3`T,3<S-C,P,#8`,#(P,38V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J"B`J("!,:6-E;G-E($EN9F]R;6%T:6]N.@H@*@H@*B`@("!.971?1$Y3
M.B`@02!R97-O;'9E<B!L:6)R87)Y(&9O<B!02%`*("H@("`@0V]P>7)I9VAT
M("AC*2`R,#`R+3(P,#,@17)I8R!+:6QF;VEL(&5R:6-`>7!A<W,N;F5T"B`J
M"B`J("`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N
M(')E9&ES=')I8G5T92!I="!A;F0O;W(*("H@("`@;6]D:69Y(&ET('5N9&5R
M('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@
M*B`@("!,:6-E;G-E(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R
M92!&;W5N9&%T:6]N.R!E:71H97(*("H@("`@=F5R<VEO;B`R+C$@;V8@=&AE
M($QI8V5N<V4L(&]R("AA="!Y;W5R(&]P=&EO;BD@86YY(&QA=&5R('9E<G-I
M;VXN"B`J"B`J("`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T
M:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@*B`@("!B=70@5TE4
M2$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W
M87)R86YT>2!O9@H@*B`@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&
M3U(@02!005)424-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@*B`@("!,
M97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS
M+@H@*@H@*B`@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F
M('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`J("`@($QI8V5N<V4@
M86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE
M($9R964@4V]F='=A<F4*("H@("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M
M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP@34$@(#`R,3$Q+3$S,#<@
M(%5300H@*B\*"B\J($YE=%]$3E-?4E)?4T]!(&1E9FEN:71I;VX@>WM[("HO
M"B\J*@H@*B!!(')E<')E<V5N=&%T:6]N(&]F(&$@<F5S;W5R8V4@<F5C;W)D
M(&]F('1Y<&4@/&(^4T]!/"]B/@H@*@H@*B!`<&%C:V%G92!.971?1$Y3"B`J
M+PIC;&%S<R!.971?1$Y37U)27U-/02!E>'1E;F1S($YE=%]$3E-?4E(*>PH@
M("`@+RH@8VQA<W,@=F%R:6%B;&4@9&5F:6YI=&EO;G,@>WM[("HO"B`@("!V
M87(@)&YA;64["B`@("!V87(@)'1Y<&4["B`@("!V87(@)&-L87-S.PH@("`@
M=F%R("1T=&P["B`@("!V87(@)')D;&5N9W1H.PH@("`@=F%R("1R9&%T83L*
M("`@('9A<B`D;6YA;64["B`@("!V87(@)')N86UE.PH@("`@=F%R("1S97)I
M86P["B`@("!V87(@)')E9G)E<V@["B`@("!V87(@)')E=')Y.PH@("`@=F%R
M("1E>'!I<F4["B`@("!V87(@)&UI;FEM=6T["@H@("`@+RH@?7U]("HO"B`@
M("`O*B!C;&%S<R!C;VYS=')U8W1O<B`M(%)2*"8D<G)O+"`D9&%T82P@)&]F
M9G-E="`]("<G*2![>WL@*B\*("`@(&9U;F-T:6]N($YE=%]$3E-?4E)?4T]!
M*"8D<G)O+"`D9&%T82P@)&]F9G-E="`]("<G*0H@("`@>PH@("`@("`@("1T
M:&ES+3YN86UE(#T@)')R;RT^;F%M93L*("`@("`@("`D=&AI<RT^='EP92`]
M("1R<F\M/G1Y<&4["B`@("`@("`@)'1H:7,M/F-L87-S(#T@)')R;RT^8VQA
M<W,["B`@("`@("`@)'1H:7,M/G1T;"`]("1R<F\M/G1T;#L*("`@("`@("`D
M=&AI<RT^<F1L96YG=&@@/2`D<G)O+3YR9&QE;F=T:#L*("`@("`@("`D=&AI
M<RT^<F1A=&$@/2`D<G)O+3YR9&%T83L*"B`@("`@("`@:68@*"1O9F9S970I
M('L*("`@("`@("`@("`@:68@*"1T:&ES+3YR9&QE;F=T:"`^(#`I('L*("`@
M("`@("`@("`@("`@(&QI<W0H)&UN86UE+"`D;V9F<V5T*2`]($YE=%]$3E-?
M4&%C:V5T.CID;E]E>'!A;F0H)&1A=&$L("1O9F9S970I.PH@("`@("`@("`@
M("`@("`@;&ES="@D<FYA;64L("1O9F9S970I(#T@3F5T7T1.4U]086-K970Z
M.F1N7V5X<&%N9"@D9&%T82P@)&]F9G-E="D["@H@("`@("`@("`@("`@("`@
M)&$@/2!U;G!A8VLH(D`D;V9F<V5T+TXU<V]A=F%L<R(L("1D871A*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YM;F%M92`]("1M;F%M93L*("`@("`@("`@
M("`@("`@("1T:&ES+3YR;F%M92`]("1R;F%M93L*("`@("`@("`@("`@("`@
M("1T:&ES+3YS97)I86P@/2`D85LG<V]A=F%L<S$G73L*("`@("`@("`@("`@
M("`@("1T:&ES+3YR969R97-H(#T@)&%;)W-O879A;',R)UT["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<F5T<GD@/2`D85LG<V]A=F%L<S,G73L*("`@("`@
M("`@("`@("`@("1T:&ES+3YE>'!I<F4@/2`D85LG<V]A=F%L<S0G73L*("`@
M("`@("`@("`@("`@("1T:&ES+3YM:6YI;75M(#T@)&%;)W-O879A;',U)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I
M9B`H97)E9R@B*%M>(%QT72LI6R!<=%TK*%M>(%QT72LI6R!<=%TK*%LP+3E=
M*RE;7B!<=%TK*%LP+3E=*RE;7B!<=%TK*%LP+3E=*RE;7B!<=%TK*%LP+3E=
M*RE;7B!<=%TJ)"(L("1S=')I;F<L("1R96=S*2D*("`@("`@("`@("`@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/FUN86UE(#T@97)E9U]R97!L86-E*"<H
M+BHI7"XD)RP@)UQ<,2<L("1R96=S6S%=*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YR;F%M92`](&5R96=?<F5P;&%C92@G*"XJ*5PN)"<L("=<7#$G+"`D
M<F5G<ULR72D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5R:6%L(#T@)')E
M9W-;,UT["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5F<F5S:"`]("1R96=S
M6S1=.PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E=')Y(#T@)')E9W-;-5T[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^97AP:7)E(#T@)')E9W-;-ET["B`@
M("`@("`@("`@("`@("`D=&AI<RT^;6EN:6UU;2`]("1R96=S6S==.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J('U]?2`J+PH@("`@
M+RH@3F5T7T1.4U]24E]33T$Z.G)D871A<W1R*"1P<F5T='D@/2`P*2![>WL@
M*B\*("`@(&9U;F-T:6]N(')D871A<W1R*"1P<F5T='D@/2`P*0H@("`@>PH@
M("`@("`@(&EF("AS=')L96XH)'1H:7,M/FUN86UE*2D@>PH@("`@("`@("`@
M("!I9B`H)'!R971T>2D@>PH@("`@("`@("`@("`@("`@)')D871A<W1R("`]
M("1T:&ES+3YM;F%M92`N("<N("<@+B`D=&AI<RT^<FYA;64@+B`B+B`H7&XB
M.PH@("`@("`@("`@("`@("`@)')D871A<W1R("X](")<=%QT7'1<=%QT(B`N
M("1T:&ES+3YS97)I86P@+B`B7'0[(%-E<FEA;%QN(CL*("`@("`@("`@("`@
M("`@("1R9&%T87-T<B`N/2`B7'1<=%QT7'1<="(@+B`D=&AI<RT^<F5F<F5S
M:"`N(")<=#L@4F5F<F5S:%QN(CL*("`@("`@("`@("`@("`@("1R9&%T87-T
M<B`N/2`B7'1<=%QT7'1<="(@+B`D=&AI<RT^<F5T<GD@+B`B7'0[(%)E=')Y
M7&XB.PH@("`@("`@("`@("`@("`@)')D871A<W1R("X](")<=%QT7'1<=%QT
M(B`N("1T:&ES+3YE>'!I<F4@+B`B7'0[($5X<&ER95QN(CL*("`@("`@("`@
M("`@("`@("1R9&%T87-T<B`N/2`B7'1<=%QT7'1<="(@+B`D=&AI<RT^;6EN
M:6UU;2`N("(@*5QT.R!-:6YI;75M(%143"(["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F1A=&%S='(@(#T@)'1H:7,M/FUN86UE
M("X@)RX@)R`N("1T:&ES+3YR;F%M92`N("<N("<@+@H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS97)I86P@+B`G("<@+B`@)'1H:7,M/G)E9G)E<V@@
M+B`G("<@+B`@)'1H:7,M/G)E=')Y("X@)R`G("X*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^97AP:7)E("X@)R`G("X@("1T:&ES+3YM:6YI;75M.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B@D<F1A=&%S='(I.PH@
M("`@("`@('T*("`@("`@("!R971U<FXH)SL@;F\@9&%T82<I.PH@("`@?0H*
M("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]24E]33T$Z.G)R7W)D871A
M*"1P86-K970L("1O9F9S970I('M[>R`J+PH@("`@9G5N8W1I;VX@<G)?<F1A
M=&$H)'!A8VME="P@)&]F9G-E="D*("`@('L*("`@("`@("!I9B`H<W1R;&5N
M*"1T:&ES+3YM;F%M92DI('L*("`@("`@("`@("`@)')D871A(#T@)'!A8VME
M="T^9&Y?8V]M<"@D=&AI<RT^;6YA;64L("1O9F9S970I.PH@("`@("`@("`@
M("`D<F1A=&$@+CT@)'!A8VME="T^9&Y?8V]M<"@D=&AI<RT^<FYA;64L("1O
M9F9S970@*R!S=')L96XH)')D871A*2D["B`@("`@("`@("`@("1R9&%T82`N
M/2!P86-K*"=.-2<L("1T:&ES+3YS97)I86PL"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G)E9G)E<V@L"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G)E=')Y+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE>'!I<F4L"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FUI;FEM=6TI.PH@("`@("`@("`@
M("!R971U<FXH)')D871A*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N*$Y5
M3$PI.PH@("`@?0H*("`@("\J('U]?2`J+PI]"B\J('U]?2`J+PHO*B!624T@
M<V5T=&EN9W,@>WM["B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H
M.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J('-O9G0M<W1O<"UW:61T:#H@
M-`H@*B!C(&EN9&5N="!O;@H@*B!%;F0Z"B`J('9I;38P,#H@<W<]-"!T<STT
M('-T<STT(&-I;F1E;G0@9F1M/6UA<FME<B!E=`H@*B!V:6T\-C`P.B!S=STT
M('1S/30*("H@?7U]("HO"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+TYE="]$3E,O4E(O4U)6+G!H<```````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,S0S`#$P-#$W,S8S,#`V`#`R
M,#(R-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*@H@*B`@3&EC96YS92!);F9O<FUA=&EO;CH*("H*("H@("`@
M3F5T7T1.4SH@($$@<F5S;VQV97(@;&EB<F%R>2!F;W(@4$A0"B`J("`@($-O
M<'ER:6=H="`H8RD@,C`P,BTR,#`S($5R:6,@2VEL9F]I;"!E<FEC0'EP87-S
M+FYE=`H@*@H@*B`@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@
M>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`J("`@(&UO9&EF>2!I
M="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,*("H@("`@3&EC96YS92!A<R!P=6)L:7-H960@8GD@=&AE($9R964@
M4V]F='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R"B`J("`@('9E<G-I;VX@,BXQ
M(&]F('1H92!,:6-E;G-E+"!O<B`H870@>6]U<B!O<'1I;VXI(&%N>2!L871E
M<B!V97)S:6]N+@H@*@H@*B`@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T
M960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("H@("`@
M8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM
M<&QI960@=V%R<F%N='D@;V8*("H@("`@34520TA!3E1!0DE,2519(&]R($9)
M5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*
M("H@("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@
M9&5T86EL<RX*("H*("H@("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@
M8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@*B`@("!,
M:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E
M('1O('1H92!&<F5E(%-O9G1W87)E"B`J("`@($9O=6YD871I;VXL($EN8RXL
M(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL($U!("`P,C$Q
M,2TQ,S`W("!54T$*("HO"@HO*B!.971?1$Y37U)27U-25B!D969I;FET:6]N
M('M[>R`J+PHO*BH*("H@02!R97!R97-E;G1A=&EO;B!O9B!A(')E<V]U<F-E
M(')E8V]R9"!O9B!T>7!E(#QB/E-25CPO8CX*("H*("H@0'!A8VMA9V4@3F5T
M7T1.4PH@*B\*8VQA<W,@3F5T7T1.4U]24E]34E8@97AT96YD<R!.971?1$Y3
M7U)2"GL*("`@("\J(&-L87-S('9A<FEA8FQE(&1E9FEN:71I;VYS('M[>R`J
M+PH@("`@=F%R("1N86UE.PH@("`@=F%R("1T>7!E.PH@("`@=F%R("1C;&%S
M<SL*("`@('9A<B`D='1L.PH@("`@=F%R("1R9&QE;F=T:#L*("`@('9A<B`D
M<F1A=&$["B`@("!V87(@)'!R969E<F5N8V4["@EV87(@)'=E:6=H=#L*"79A
M<B`D<&]R=#L*("`@('9A<B`D=&%R9V5T.PH*("`@("\J('U]?2`J+PH@("`@
M+RH@8VQA<W,@8V]N<W1R=6-T;W(@+2!24B@F)')R;RP@)&1A=&$L("1O9F9S
M970@/2`G)RD@>WM[("HO"B`@("!F=6YC=&EO;B!.971?1$Y37U)27U-25B@F
M)')R;RP@)&1A=&$L("1O9F9S970@/2`G)RD*("`@('L*("`@("`@("`D=&AI
M<RT^;F%M92`]("1R<F\M/FYA;64["B`@("`@("`@)'1H:7,M/G1Y<&4@/2`D
M<G)O+3YT>7!E.PH@("`@("`@("1T:&ES+3YC;&%S<R`]("1R<F\M/F-L87-S
M.PH@("`@("`@("1T:&ES+3YT=&P@/2`D<G)O+3YT=&P["B`@("`@("`@)'1H
M:7,M/G)D;&5N9W1H(#T@)')R;RT^<F1L96YG=&@["B`@("`@("`@)'1H:7,M
M/G)D871A(#T@)')R;RT^<F1A=&$["@H@("`@("`@(&EF("@D;V9F<V5T*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^<F1L96YG=&@@/B`P*2!["B`@("`@
M("`@("`@("`@("`D82`]('5N<&%C:R@B0"1O9F9S970O;G!R969E<F5N8V4O
M;G=E:6=H="]N<&]R="(L("1D871A*3L*("`@("`@("`@("`@("`@("1O9F9S
M970@*ST@-CL*("`@("`@("`@("`@("`@(&QI<W0H)'1A<F=E="P@)&]F9G-E
M="D@/2!.971?1$Y37U!A8VME=#HZ9&Y?97AP86YD*"1D871A+"`D;V9F<V5T
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5F97)E;F-E(#T@)&%;)W!R
M969E<F5N8V4G73L*("`@("`@("`@("`@("`@("1T:&ES+3YW96EG:'0@/2`D
M85LG=V5I9VAT)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^<&]R="`]("1A
M6R=P;W)T)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^=&%R9V5T(#T@)'1A
M<F=E=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&5R96<H(BA;,"TY72LI6R!<=%TK*%LP+3E=*RE;(%QT72LH6S`M.5TK
M*5L@7'1=*R@N*RE;(%QT72HD(BP@)&1A=&$L("1R96=S*3L*("`@("`@("`@
M("`@)'1H:7,M/G!R969E<F5N8V4@/2`D<F5G<ULQ73L*("`@("`@("`@("`@
M)'1H:7,M/G=E:6=H="`]("1R96=S6S)=.PH@("`@("`@("`@("`D=&AI<RT^
M<&]R="`]("1R96=S6S-=.PH@("`@("`@("`@("`D=&AI<RT^=&%R9V5T(#T@
M97)E9U]R97!L86-E*"<H+BHI7"XD)RP@)UQ<,2<L("1R96=S6S1=*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)2
M7U-25CHZ<F1A=&%S='(H*2![>WL@*B\*("`@(&9U;F-T:6]N(')D871A<W1R
M*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G!O<G0I('L*("`@("`@("`@
M("`@<F5T=7)N*&EN='9A;"@D=&AI<RT^<')E9F5R96YC92D@+B`G("<@+B!I
M;G1V86PH)'1H:7,M/G=E:6=H="D@+B`G("<@+B!I;G1V86PH)'1H:7,M/G!O
M<G0I("X@)R`G("X@)'1H:7,M/G1A<F=E="`N("<N)RD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B@G.R!N;R!D871A)RD["B`@("!]"@H@("`@+RH@?7U]
M("HO"B`@("`O*B!.971?1$Y37U)27U-25CHZ<G)?<F1A=&$H)'!A8VME="P@
M)&]F9G-E="D@>WM[("HO"B`@("!F=6YC=&EO;B!R<E]R9&%T82@D<&%C:V5T
M+"`D;V9F<V5T*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^<')E9F5R96YC
M92D@>PH@("`@("`@("`@("`D<F1A=&$@/2!P86-K*"=N;FXG+"`D=&AI<RT^
M<')E9F5R96YC92P@)'1H:7,M/G=E:6=H="P@)'1H:7,M/G!O<G0I.PH@("`@
M("`@("`@("`D<F1A=&$@+CT@)'!A8VME="T^9&Y?8V]M<"@D=&AI<RT^=&%R
M9V5T+"`D;V9F<V5T("L@<W1R;&5N*"1R9&%T82DI.PH@("`@("`@("`@("!R
M971U<FXH)')D871A*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N*$Y53$PI
M.PH@("`@?0H*("`@("\J('U]?2`J+PI]"B\J('U]?2`J+PHO*B!624T@<V5T
M=&EN9W,@>WM["B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T
M"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J('-O9G0M<W1O<"UW:61T:#H@-`H@
M*B!C(&EN9&5N="!O;@H@*B!%;F0Z"B`J('9I;38P,#H@<W<]-"!T<STT('-T
M<STT(&-I;F1E;G0@9F1M/6UA<FME<B!E=`H@*B!V:6T\-C`P.B!S=STT('1S
M/30*("H@?7U]("HO"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B].970O1$Y3+U)2+U185"YP:'``````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3<P-``Q,#0Q-S,V,S`P-@`P
M,C`R,S,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RH*("H@($QI8V5N<V4@26YF;W)M871I;VXZ"B`J"B`J("`@
M($YE=%]$3E,Z("!!(')E<V]L=F5R(&QI8G)A<GD@9F]R(%!(4`H@*B`@("!#
M;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!%<FEC($MI;&9O:6P@97)I8T!Y<&%S
M<RYN970*("H*("H@("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[
M('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@*B`@("!M;V1I9GD@
M:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC"B`J("`@($QI8V5N<V4@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E
M(%-O9G1W87)E($9O=6YD871I;VX[(&5I=&AE<@H@*B`@("!V97)S:6]N(#(N
M,2!O9B!T:&4@3&EC96YS92P@;W(@*&%T('EO=7(@;W!T:6]N*2!A;GD@;&%T
M97(@=F5R<VEO;BX*("H*("H@("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U
M=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`J("`@
M(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I
M;7!L:65D('=A<G)A;G1Y(&]F"B`J("`@($U%4D-(04Y404))3$E462!O<B!&
M251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5
M"B`J("`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E
M(&1E=&%I;',N"B`J"B`J("`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A
M(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("H@("`@
M3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET
M92!T;R!T:&4@1G)E92!3;V9T=V%R90H@*B`@("!&;W5N9&%T:6]N+"!);F,N
M+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+"!-02`@,#(Q
M,3$M,3,P-R`@55-!"B`J+PH*+RH@3F5T7T1.4U]24E]46%0@9&5F:6YI=&EO
M;B![>WL@*B\*+RHJ"B`J($$@<F5P<F5S96YT871I;VX@;V8@82!R97-O=7)C
M92!R96-O<F0@;V8@='EP92`\8CY46%0\+V(^"B`J"B`J($!P86-K86=E($YE
M=%]$3E,*("HO"F-L87-S($YE=%]$3E-?4E)?5%A4(&5X=&5N9',@3F5T7T1.
M4U]24@I["B`@("`O*B!C;&%S<R!V87)I86)L92!D969I;FET:6]N<R![>WL@
M*B\*("`@('9A<B`D;F%M93L*("`@('9A<B`D='EP93L*("`@('9A<B`D8VQA
M<W,["B`@("!V87(@)'1T;#L*("`@('9A<B`D<F1L96YG=&@["B`@("!V87(@
M)')D871A.PH)=F%R("1T97AT.PH*("`@("\J('U]?2`J+PH@("`@+RH@8VQA
M<W,@8V]N<W1R=6-T;W(@+2!24B@F)')R;RP@)&1A=&$L("1O9F9S970@/2`G
M)RD@>WM[("HO"B`@("!F=6YC=&EO;B!.971?1$Y37U)27U185"@F)')R;RP@
M)&1A=&$L("1O9F9S970@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^;F%M
M92`]("1R<F\M/FYA;64["B`@("`@("`@)'1H:7,M/G1Y<&4@/2`D<G)O+3YT
M>7!E.PH@("`@("`@("1T:&ES+3YC;&%S<R`]("1R<F\M/F-L87-S.PH@("`@
M("`@("1T:&ES+3YT=&P@/2`D<G)O+3YT=&P["B`@("`@("`@)'1H:7,M/G)D
M;&5N9W1H(#T@)')R;RT^<F1L96YG=&@["B`@("`@("`@)'1H:7,M/G)D871A
M(#T@)')R;RT^<F1A=&$["@H@("`@("`@(&EF("@D;V9F<V5T*2!["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^<F1L96YG=&@@/B`P*2!["B`@("`@("`@("`@
M("`@("!L:7-T*"1T97AT+"`D;V9F<V5T*2`]($YE=%]$3E-?4&%C:V5T.CIL
M86)E;%]E>'1R86-T*"1D871A+"`D;V9F<V5T*3L*"B`@("`@("`@("`@("`@
M("`D=&AI<RT^=&5X="`]("1T97AT.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&1A=&$@/2!S=')?<F5P;&%C92@G7%Q<
M7"<L(&-H<B@Q*2`N(&-H<B@Q*2P@)&1A=&$I.R`O*B!D:7-G=6ES92!E<V-A
M<&5D(&)A8VMS;&%S:"`J+PH@("`@("`@("`@("`D9&%T82`]('-T<E]R97!L
M86-E*"=<7"(G+"!C:'(H,BD@+B!C:'(H,BDL("1D871A*3L@+RH@9&ES9W5I
M<V4@7"(@*B\*"B`@("`@("`@("`@(&5R96<H)R@B6UXB72HB?%M>(%QT72HI
M6R!<=%TJ)"<L("1D871A+"`D<F5G<RD["B`@("`@("`@("`@("1R96=S6S%=
M(#T@<W1R7W)E<&QA8V4H8VAR*#(I("X@8VAR*#(I+"`G7%PB)RP@)')E9W-;
M,5TI.PH@("`@("`@("`@("`D<F5G<ULQ72`]('-T<E]R97!L86-E*&-H<B@Q
M*2`N(&-H<B@Q*2P@)UQ<7%PG+"`D<F5G<ULQ72D["B`@("`@("`@("`@("1R
M96=S6S%=(#T@<W1R:7!S;&%S:&5S*"1R96=S6S%=*3L*"B`@("`@("`@("`@
M("1T:&ES+3YT97AT(#T@)')E9W-;,5T["B`@("`@("`@?0H@("`@?0H*("`@
M("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]24E]46%0Z.G)D871A<W1R*"D@
M>WM[("HO"B`@("!F=6YC=&EO;B!R9&%T87-T<B@I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YT97AT*2!["B`@("`@("`@("`@(')E='5R;B@G(B<@+B!A
M9&1S;&%S:&5S*"1T:&ES+3YT97AT*2`N("<B)RD["B`@("`@("`@?2!E;'-E
M(')E='5R;B@G.R!N;R!D871A)RD["B`@("!]"@H@("`@+RH@?7U]("HO"B`@
M("`O*B!.971?1$Y37U)27U185#HZ<G)?<F1A=&$H)'!A8VME="P@)&]F9G-E
M="D@>WM[("HO"B`@("!F=6YC=&EO;B!R<E]R9&%T82@D<&%C:V5T+"`D;V9F
M<V5T*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=&5X="D@>PH@("`@("`@
M("`@("`D<F1A=&$@(#T@<&%C:R@G0R<L('-T<FQE;B@D=&AI<RT^=&5X="DI
M("X@)'1H:7,M/G1E>'0["B`@("`@("`@("`@(')E='5R;B@D<F1A=&$I.PH@
M("`@("`@('T*("`@("`@("!R971U<FXH3E5,3"D["B`@("!]"@H@("`@+RH@
M?7U]("HO"GT*+RH@?7U]("HO"B\J(%9)32!S971T:6YG<R![>WL*("H@3&]C
M86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S
M970Z(#0*("H@<V]F="US=&]P+7=I9'1H.B`T"B`J(&,@:6YD96YT(&]N"B`J
M($5N9#H*("H@=FEM-C`P.B!S=STT('1S/30@<W1S/30@8VEN9&5N="!F9&T]
M;6%R:V5R(&5T"B`J('9I;3PV,#`Z('-W/30@=',]-`H@*B!]?7T@*B\*/SX*
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+TYE="]$3E,O4E(O04%!02YP:'``````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$P-C`V`#$P-#$W,S8S,#`V`#`R,#(S-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*@H@*B`@
M3&EC96YS92!);F9O<FUA=&EO;CH*("H*("H@("`@3F5T7T1.4SH@($$@<F5S
M;VQV97(@;&EB<F%R>2!F;W(@4$A0"B`J("`@($-O<'ER:6=H="`H8RD@,C`P
M,BTR,#`S($5R:6,@2VEL9F]I;"!E<FEC0'EP87-S+FYE=`H@*@H@*B`@("!4
M:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R
M:6)U=&4@:70@86YD+V]R"B`J("`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R
M;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("H@("`@3&EC
M96YS92!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A
M=&EO;CL@96ET:&5R"B`J("`@('9E<G-I;VX@,BXQ(&]F('1H92!,:6-E;G-E
M+"!O<B`H870@>6]U<B!O<'1I;VXI(&%N>2!L871E<B!V97)S:6]N+@H@*@H@
M*B`@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@
M=&AA="!I="!W:6QL(&)E('5S969U;"P*("H@("`@8G5T(%=)5$A/550@04Y9
M(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@
M;V8*("H@("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%2
M5$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("H@("`@3&5S<V5R($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*("H*("H@
M("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5
M($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@*B`@("!,:6-E;G-E(&%L;VYG('=I
M=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O
M9G1W87)E"B`J("`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C
M92P@4W5I=&4@,S,P+"!";W-T;VXL($U!("`P,C$Q,2TQ,S`W("!54T$*("HO
M"@H*+RH@3F5T7T1.4U]24E]!04%!(&]B:F5C="!D969I;FET:6]N('M[>R`J
M+PHO*BH*("H@02!R97!R97-E;G1A=&EO;B!O9B!A(')E<V]U<F-E(')E8V]R
M9"!O9B!T>7!E(#QB/D%!04$\+V(^"B`J"B`J($!P86-K86=E($YE=%]$3E,*
M("HO"F-L87-S($YE=%]$3E-?4E)?04%!02!E>'1E;F1S($YE=%]$3E-?4E(*
M>PH@("`@+RH@8VQA<W,@=F%R:6%B;&4@9&5F:6YI=&EO;G,@>WM[("HO"B`@
M("!V87(@)&YA;64["B`@("!V87(@)'1Y<&4["B`@("!V87(@)&-L87-S.PH@
M("`@=F%R("1T=&P["B`@("!V87(@)')D;&5N9W1H.PH@("`@=F%R("1R9&%T
M83L*("`@('9A<B`D861D<F5S<SL*"B`@("`O*B!]?7T@*B\*("`@("\J(&-L
M87-S(&-O;G-T<G5C=&]R("T@3F5T7T1.4U]24E]!04%!*"8D<G)O+"`D9&%T
M82P@)&]F9G-E="`]("<G*2![>WL@*B\*("`@(&9U;F-T:6]N($YE=%]$3E-?
M4E)?04%!02@F)')R;RP@)&1A=&$L("1O9F9S970@/2`G)RD*("`@('L*("`@
M("`@("`D=&AI<RT^;F%M92`]("1R<F\M/FYA;64["B`@("`@("`@)'1H:7,M
M/G1Y<&4@/2`D<G)O+3YT>7!E.PH@("`@("`@("1T:&ES+3YC;&%S<R`]("1R
M<F\M/F-L87-S.PH@("`@("`@("1T:&ES+3YT=&P@/2`D<G)O+3YT=&P["B`@
M("`@("`@)'1H:7,M/G)D;&5N9W1H(#T@)')R;RT^<F1L96YG=&@["B`@("`@
M("`@)'1H:7,M/G)D871A(#T@)')R;RT^<F1A=&$["@H@("`@("`@(&EF("@D
M;V9F<V5T*2!["@D)"21T:&ES+3YA9&1R97-S(#T@3F5T7T1.4U]24E]!04%!
M.CII<'8V7V1E8V]M<')E<W,H<W5B<W1R*"1T:&ES+3YR9&%T82P@,"P@)'1H
M:7,M/G)D;&5N9W1H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*'-T<FQE;B@D9&%T82DI('L*("`@("`@("`@("`@("`@(&EF("AC;W5N
M="@D861A=&$@/2!E>'!L;V1E*"<Z)RP@)&1A=&$L(#@I*2`^/2`S*2!["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"@D861A=&$@87,@)&%D9'(I"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY;,"TY
M02U&77LP+#1])"]I)RP@)&%D9'(I*2!R971U<FX["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F%D9')E<W,@/2!T<FEM*"1D871A*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@"B`@("!]"@H@("`@
M+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)27T%!04$Z.G)D871A<W1R*"D@
M>WM[("HO"B`@("!F=6YC=&EO;B!R9&%T87-T<B@I"B`@("!["B`@("`@("`@
M:68@*'-T<FQE;B@D=&AI<RT^861D<F5S<RDI('L*("`@("`@("`@("`@<F5T
M=7)N*"1T:&ES+3YA9&1R97-S*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M*"<[(&YO(&1A=&$G*3L*("`@('T*("`@("\J('U]?2`J+PH@("`@+RH@3F5T
M7T1.4U]24E]!04%!.CIR<E]R9&%T82@D<&%C:V5T+"`D;V9F<V5T*2![>WL@
M*B\*("`@(&9U;F-T:6]N(')R7W)D871A*"1P86-K970L("1O9F9S970I"B`@
M("!["@D)<F5T=7)N($YE=%]$3E-?4E)?04%!03HZ:7!V-E]C;VUP<F5S<R@D
M=&AI<RT^861D<F5S<RD["B`@("!]"@H@("`@+RH@?7U]("HO"B`@("`O*B!.
M971?1$Y37U)27T%!04$Z.FEP=C9?8V]M<')E<W,H)&%D9'(I('M[>R`J+PH@
M("`@9G5N8W1I;VX@:7!V-E]C;VUP<F5S<R@D861D<BD*("`@('L*("`@("`@
M("`D;G5M<&%R=',@/2!C;W5N="AE>'!L;V1E*"<Z)RP@)&%D9'(I*3L*("`@
M("`@("!I9B`H)&YU;7!A<G1S(#P@,R!\?"`D;G5M<&%R=',@/B`X('Q\"B`@
M("`@("`@("`@("%P<F5G7VUA=&-H*"<O7BA;,"TY02U&77LP+#1].BE[,"PW
M?2@Z6S`M.4$M1EU[,"PT?2E[,"PW?20O:2<L("1A9&1R*2D@>PH@("`@("`@
M("`@("`O*B!.;VXM<V5N<VEC86P@25!V-B!A9&1R97-S("HO"B`@("`@("`@
M("`@(')E='5R;B!P86-K*"=N."<L(#`L(#`L(#`L(#`L(#`L(#`L(#`L(#`I
M.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R<&]S*"1A9&1R+"`G.CHG*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@+RH@1FER<W0@=V4@:&%V92!T;R!N
M;W)M86QI>F4@=&AE(&%D9')E<W,L('1U<FX@.CH@:6YT;R`Z,#HP.C`Z,#H@
M*B\*("`@("`@("`@("`@)&9I;&QE<B`]('-T<E]R97!E870H)SHP)RP@.2`M
M("1N=6UP87)T<RD@+B`G.B<["B`@("`@("`@("`@(&EF("AS=6)S='(H)&%D
M9'(L(#`L(#(I(#T]("<Z.B<I('L*("`@("`@("`@("`@("`@("1F:6QL97(@
M/2`B,"1F:6QL97(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS
M=6)S='(H)&%D9'(L("TR+"`R*2`]/2`G.CHG*2!["B`@("`@("`@("`@("`@
M("`D9FEL;&5R("X]("<P)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M861D<B`]('-T<E]R97!L86-E*"<Z.B<L("1F:6QL97(L("1A9&1R*3L*("`@
M("`@("!]"B`@("`@("`@)&%P87)T<R`](&5X<&QO9&4H)SHG+"`D861D<BD[
M"B`@("`@("`@<F5T=7)N('!A8VLH)VXX)RP@:&5X9&5C*"1A<&%R='-;,%TI
M+"!H97AD96,H)&%P87)T<ULQ72DL(&AE>&1E8R@D87!A<G1S6S)=*2P@:&5X
M9&5C*"1A<&%R='-;,UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(&AE
M>&1E8R@D87!A<G1S6S1=*2P@:&5X9&5C*"1A<&%R='-;-5TI+"!H97AD96,H
M)&%P87)T<ULV72DL(&AE>&1E8R@D87!A<G1S6S==*2D["B`@("!]"B`@("`O
M*B!]?7T@*B\*"B`@("`O*B!.971?1$Y37U)27T%!04$Z.FEP=C9?9&5C;VUP
M<F5S<R@D<&%C:RD@>WM[("HO"B`@("!F=6YC=&EO;B!I<'8V7V1E8V]M<')E
M<W,H)'!A8VLI"B`@("!["B`@("`@("`@:68@*'-T<FQE;B@D<&%C:RD@(3T@
M,38I('L*("`@("`@("`@("`@+RH@375S="!B92`X('-H;W)T<R!L;VYG("HO
M"B`@("`@("`@("`@(')E='5R;B`G.CHG.PH@("`@("`@('T*("`@("`@("`D
M82`]('5N<&%C:R@G;CAB)RP@)'!A8VLI.PH@("`@("`@(&9O<F5A8V@H)&$@
M87,@)&ED>"`]/B`D=F%L=64I"B`@("`@("`@("`@("1A6R1I9'A=(#T@9&5C
M:&5X*"1V86QU92D["B`@("`@("`@)&%D9'(@/2!I;7!L;V1E*"<Z)RP@)&$I
M.PH@("`@("`@("\J(%-H;W)T:&%N9"!T:&4@9FER<W0@.C`Z,#HP.B!S970@
M:6YT;R!A(#HZ("HO"B`@("`@("`@+RH@5$]$3SH@36%K92!T:&ES(&ES(&$@
M<VEN9VQE(')E<&QA8V5M96YT('!A='1E<FX@*B\*("`@("`@("!I9B`H<W5B
M<W1R*"1A9&1R+"`M-"P@-"D@/3T@)SHP.C`G*2!["B`@("`@("`@("`@(')E
M='5R;B!P<F5G7W)E<&QA8V4H)R\H*#HP*7LR+'TI)"\G+"`G.CHG+"`D861D
M<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('!R96=?
M<F5P;&%C92@G+R@Z/R@P.BE[,BQ]*2\G+"`G.CHG+"`D861D<BD["B`@("`@
M("`@?0H@("`@?0H@("`@+RH@?7U]("HO"GT*+RH@?7U]("HO"B\J(%9)32!S
M971T:6YG<R![>WL*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z
M(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@<V]F="US=&]P+7=I9'1H.B`T
M"B`J(&,@:6YD96YT(&]N"B`J($5N9#H*("H@=FEM-C`P.B!S=STT('1S/30@
M<W1S/30@8VEN9&5N="!F9&T];6%R:V5R(&5T"B`J('9I;3PV,#`Z('-W/30@
M=',]-`H@*B!]?7T@*B\*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+T1.4R]2
M4B](24Y&3RYP:'``````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#8T,S<`,3`T,3<S-C,P,#8`,#(P-#(S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J"B`J("!,:6-E;G-E($EN
M9F]R;6%T:6]N.@H@*@H@*B`@("!.971?1$Y3.B`@02!R97-O;'9E<B!L:6)R
M87)Y(&9O<B!02%`*("H@("`@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@17)I
M8R!+:6QF;VEL(&5R:6-`>7!A<W,N;F5T"B`J"B`J("`@(%1H:7,@;&EB<F%R
M>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A
M;F0O;W(*("H@("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@
M1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@*B`@("!,:6-E;G-E(&%S('!U
M8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N.R!E:71H
M97(*("H@("`@=F5R<VEO;B`R+C$@;V8@=&AE($QI8V5N<V4L(&]R("AA="!Y
M;W5R(&]P=&EO;BD@86YY(&QA=&5R('9E<G-I;VXN"B`J"B`J("`@(%1H:7,@
M;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I
M;&P@8F4@=7-E9G5L+`H@*B`@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[
M('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@*B`@("!-
M15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!5
M4E!/4T4N("!3964@=&AE($=.50H@*B`@("!,97-S97(@1V5N97)A;"!0=6)L
M:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H@*@H@*B`@("!9;W4@<VAO
M=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`J("`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI
M8G)A<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("H@
M("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S
M,S`L($)O<W1O;BP@34$@(#`R,3$Q+3$S,#<@(%5300H@*B\*"B\J($YE=%]$
M3E-?4E)?2$E.1D\@9&5F:6YI=&EO;B![>WL@*B\*+RHJ"B`J($$@<F5P<F5S
M96YT871I;VX@;V8@82!R97-O=7)C92!R96-O<F0@;V8@='EP92`\8CY(24Y&
M3SPO8CX*("H*("H@0'!A8VMA9V4@3F5T7T1.4PH@*B\*8VQA<W,@3F5T7T1.
M4U]24E](24Y&3R!E>'1E;F1S($YE=%]$3E-?4E(*>PH@("`@+RH@8VQA<W,@
M=F%R:6%B;&4@9&5F:6YI=&EO;G,@>WM[("HO"B`@("!V87(@)&YA;64["B`@
M("!V87(@)'1Y<&4["B`@("!V87(@)&-L87-S.PH@("`@=F%R("1T=&P["B`@
M("!V87(@)')D;&5N9W1H.PH@("`@=F%R("1R9&%T83L*"79A<B`D8W!U.PH@
M("`@=F%R("1O<SL*"B`@("`O*B!]?7T@*B\*("`@("\J(&-L87-S(&-O;G-T
M<G5C=&]R("T@4E(H)B1R<F\L("1D871A+"`D;V9F<V5T(#T@)R<I('M[>R`J
M+PH@("`@9G5N8W1I;VX@3F5T7T1.4U]24E](24Y&3R@F)')R;RP@)&1A=&$L
M("1O9F9S970@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^;F%M92`]("1R
M<F\M/FYA;64["B`@("`@("`@)'1H:7,M/G1Y<&4@/2`D<G)O+3YT>7!E.PH@
M("`@("`@("1T:&ES+3YC;&%S<R`]("1R<F\M/F-L87-S.PH@("`@("`@("1T
M:&ES+3YT=&P@/2`D<G)O+3YT=&P["B`@("`@("`@)'1H:7,M/G)D;&5N9W1H
M(#T@)')R;RT^<F1L96YG=&@["B`@("`@("`@)'1H:7,M/G)D871A(#T@)')R
M;RT^<F1A=&$["@H@("`@("`@(&EF("@D;V9F<V5T*2!["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^<F1L96YG=&@@/B`P*2!["B`@("`@("`@("`@("`@("!L
M:7-T*"1C<'4L("1O9F9S970I(#T@3F5T7T1.4U]086-K970Z.FQA8F5L7V5X
M=')A8W0H)&1A=&$L("1O9F9S970I.PH@("`@("`@("`@("`@("`@;&ES="@D
M;W,L("`D;V9F<V5T*2`]($YE=%]$3E-?4&%C:V5T.CIL86)E;%]E>'1R86-T
M*"1D871A+"`D;V9F<V5T*3L*"B`@("`@("`@("`@("`@("`D=&AI<RT^8W!U
M(#T@)&-P=3L*("`@("`@("`@("`@("`@("1T:&ES+3YO<R`@/2`D;W,["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%T
M82`]('-T<E]R97!L86-E*"=<7%Q<)RP@8VAR*#$I("X@8VAR*#$I+"`D9&%T
M82D[("\J(&1I<V=U:7-E(&5S8V%P960@8F%C:W-L87-H("HO"B`@("`@("`@
M("`@("1D871A(#T@<W1R7W)E<&QA8V4H)UQ<(B<L(&-H<B@R*2`N(&-H<B@R
M*2P@)&1A=&$I.R`O*B!D:7-G=6ES92!<(B`J+PH*("`@("`@("`@("`@97)E
M9R@G*");7B)=*B)\6UX@7'1=*BE;(%QT72LH(EM>(ETJ(GQ;7B!<=%TJ*5L@
M7'1=*B0G+"`D9&%T82P@)')E9W,I.PH@("`@("`@("`@("!F;W)E86-H*"1R
M96=S(&%S("1I9'@@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D=F%L
M=64@/2!S=')?<F5P;&%C92AC:'(H,BD@+B!C:'(H,BDL("=<7"(G+"`D=F%L
M=64I.PH@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA8V4H8VAR
M*#$I("X@8VAR*#$I+"`G7%Q<7"<L("1V86QU92D["B`@("`@("`@("`@("`@
M("`D<F5G<ULD:61X72`]('-T<FEP<VQA<VAE<R@D=F%L=64I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^8W!U(#T@)')E9W-;,5T["@D)
M"21T:&ES+3YO<R`]("1R96=S6S)=.PH@("`@("`@('T*("`@('T*"B`@("`O
M*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4E)?2$E.1D\Z.G)D871A<W1R*"D@
M>WM[("HO"B`@("!F=6YC=&EO;B!R9&%T87-T<B@I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YT97AT*2!["B`@("`@("`@("`@(')E='5R;B@G(B<@+B!A
M9&1S;&%S:&5S*"1T:&ES+3YC<'4I("X@)R(@(B<@+B!A9&1S;&%S:&5S*"1T
M:&ES+3YO<RD@+B`G(B<I.PH@("`@("`@('T@96QS92!R971U<FXH)SL@;F\@
M9&%T82<I.PH@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]2
M4E](24Y&3SHZ<G)?<F1A=&$H)'!A8VME="P@)&]F9G-E="D@>WM[("HO"B`@
M("!F=6YC=&EO;B!R<E]R9&%T82@D<&%C:V5T+"`D;V9F<V5T*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^=&5X="D@>PH@("`@("`@("`@("`D<F1A=&$@
M(#T@<&%C:R@G0R<L('-T<FQE;B@D=&AI<RT^8W!U*2D@+B`D=&AI<RT^8W!U
M.PH@("`@("`@("`@("`D<F1A=&$@+CT@<&%C:R@G0R<L('-T<FQE;B@D=&AI
M<RT^;W,I*2`@+B`D=&AI<RT^;W,["B`@("`@("`@("`@(')E='5R;B@D<F1A
M=&$I.PH@("`@("`@('T*("`@("`@("!R971U<FXH3E5,3"D["B`@("!]"@H@
M("`@+RH@?7U]("HO"GT*+RH@?7U]("HO"B\J(%9)32!S971T:6YG<R![>WL*
M("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I
M8RUO9F9S970Z(#0*("H@<V]F="US=&]P+7=I9'1H.B`T"B`J(&,@:6YD96YT
M(&]N"B`J($5N9#H*("H@=FEM-C`P.B!S=STT('1S/30@<W1S/30@8VEN9&5N
M="!F9&T];6%R:V5R(&5T"B`J('9I;3PV,#`Z('-W/30@=',]-`H@*B!]?7T@
M*B\*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TYE="]$3E,O
M4E(O3D%05%(N<&AP````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$P-S$W`#$P-#$W,S8S,#`V`#`R,#0T,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*@H@*B`@3&EC96YS92!)
M;F9O<FUA=&EO;CH*("H*("H@("`@3F5T7T1.4SH@($$@<F5S;VQV97(@;&EB
M<F%R>2!F;W(@4$A0"B`J("`@($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S($5R
M:6,@2VEL9F]I;"!E<FEC0'EP87-S+FYE=`H@*@H@*B`@("!4:&ES(&QI8G)A
M<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@
M86YD+V]R"B`J("`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("H@("`@3&EC96YS92!A<R!P
M=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;CL@96ET
M:&5R"B`J("`@('9E<G-I;VX@,BXQ(&]F('1H92!,:6-E;G-E+"!O<B`H870@
M>6]U<B!O<'1I;VXI(&%N>2!L871E<B!V97)S:6]N+@H@*@H@*B`@("!4:&ES
M(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W
M:6QL(&)E('5S969U;"P*("H@("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19
M.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("H@("`@
M34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!0
M55)03U-%+B`@4V5E('1H92!'3E4*("H@("`@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*("H*("H@("`@66]U('-H
M;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8PH@*B`@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L
M:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`J
M("`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@
M,S,P+"!";W-T;VXL($U!("`P,C$Q,2TQ,S`W("!54T$*("HO"@HO*B!.971?
M1$Y37U)27TY!4%12(&1E9FEN:71I;VX@>WM[("HO"B\J*@H@*B!!(')E<')E
M<V5N=&%T:6]N(&]F(&$@<F5S;W5R8V4@<F5C;W)D(&]F('1Y<&4@/&(^3D%0
M5%(\+V(^"B`J"B`J($!P86-K86=E($YE=%]$3E,*("HO"F-L87-S($YE=%]$
M3E-?4E)?3D%05%(@97AT96YD<R!.971?1$Y37U)2"GL*("`@("\J(&-L87-S
M('9A<FEA8FQE(&1E9FEN:71I;VYS('M[>R`J+PH@("`@=F%R("1N86UE.PH@
M("`@=F%R("1T>7!E.PH@("`@=F%R("1C;&%S<SL*("`@('9A<B`D='1L.PH@
M("`@=F%R("1R9&QE;F=T:#L*("`@('9A<B`D<F1A=&$["@EV87(@)&]R9&5R
M.PH)=F%R("1P<F5F97)E;F-E.PH)=F%R("1F;&%G<SL*"79A<B`D<V5R=FEC
M97,["@EV87(@)')E9V5X.PH)=F%R("1R97!L86-E;65N=#L*"B`@("`O*B!]
M?7T@*B\*("`@("\J(&-L87-S(&-O;G-T<G5C=&]R("T@4E(H)B1R<F\L("1D
M871A+"`D;V9F<V5T(#T@)R<I('M[>R`J+PH@("`@9G5N8W1I;VX@3F5T7T1.
M4U]24E].05!44B@F)')R;RP@)&1A=&$L("1O9F9S970@/2`G)RD*("`@('L*
M("`@("`@("`D=&AI<RT^;F%M92`]("1R<F\M/FYA;64["B`@("`@("`@)'1H
M:7,M/G1Y<&4@/2`D<G)O+3YT>7!E.PH@("`@("`@("1T:&ES+3YC;&%S<R`]
M("1R<F\M/F-L87-S.PH@("`@("`@("1T:&ES+3YT=&P@/2`D<G)O+3YT=&P[
M"B`@("`@("`@)'1H:7,M/G)D;&5N9W1H(#T@)')R;RT^<F1L96YG=&@["B`@
M("`@("`@)'1H:7,M/G)D871A(#T@)')R;RT^<F1A=&$["@H@("`@("`@(&EF
M("@D;V9F<V5T*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^<F1L96YG=&@@
M/B`P*2!["B`@("`@("`@("`@("`@("`D82`]('5N<&%C:R@B0"1O9F9S970O
M;F]R9&5R+VYP<F5F97)E;F-E(BP@)&1A=&$I.PH@("`@("`@("`@("`@("`@
M)&]F9G-E="`K/2`T.PH@("`@("`@("`@("`@("`@;&ES="@D9FQA9W,L("1O
M9F9S970I(#T@3F5T7T1.4U]086-K970Z.FQA8F5L7V5X=')A8W0H)&1A=&$L
M("1O9F9S970I.PH@("`@("`@("`@("`@("`@;&ES="@D<V5R=FEC97,L("1O
M9F9S970I(#T@3F5T7T1.4U]086-K970Z.FQA8F5L7V5X=')A8W0H)&1A=&$L
M("1O9F9S970I.PH@("`@("`@("`@("`@("`@;&ES="@D<F5G97@L("1O9F9S
M970I(#T@3F5T7T1.4U]086-K970Z.FQA8F5L7V5X=')A8W0H)&1A=&$L("1O
M9F9S970I.PH@("`@("`@("`@("`@("`@;&ES="@D<F5P;&%C96UE;G0L("1O
M9F9S970I(#T@3F5T7T1.4U]086-K970Z.F1N7V5X<&%N9"@D9&%T82P@)&]F
M9G-E="D["@H@("`@("`@("`@("`@("`@)'1H:7,M/F]R9&5R(#T@)&%;)V]R
M9&5R)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^<')E9F5R96YC92`]("1A
M6R=P<F5F97)E;F-E)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^9FQA9W,@
M/2`D9FQA9W,["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5R=FEC97,@/2`D
M<V5R=FEC97,["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5G97@@/2`D<F5G
M97@["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5P;&%C96UE;G0@/2`D<F5P
M;&%C96UE;G0["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D9&%T82`]('-T<E]R97!L86-E*"=<7%Q<)RP@8VAR*#$I("X@
M8VAR*#$I+"`D9&%T82D[("\J(&1I<V=U:7-E(&5S8V%P960@8F%C:W-L87-H
M("HO"B`@("`@("`@("`@("1D871A(#T@<W1R7W)E<&QA8V4H)UQ<(B<L(&-H
M<B@R*2`N(&-H<B@R*2P@)&1A=&$I.R`O*B!D:7-G=6ES92!<(B`J+PH@("`@
M("`@("`@("!E<F5G*"<H6S`M.5TK*5L@7'1=*RA;,"TY72LI6R!<=%TK*");
M7B)=*B)\6UX@7'1=*BE;(%QT72LH(EM>(ETJ(GQ;7B!<=%TJ*5L@7'1=*R@B
M6UXB72HB?%M>(%QT72HI6R!<=%TK*"XJ/RE;(%QT72HD)RP@)&1A=&$L("1R
M96=S*3L*("`@("`@("`@("`@)'1H:7,M/G!R969E<F5N8V4@/2`D<F5G<ULQ
M73L*("`@("`@("`@("`@)'1H:7,M/G=E:6=H="`]("1R96=S6S)=.PH@("`@
M("`@("`@("!F;W)E86-H*"1R96=S(&%S("1I9'@@/3X@)'9A;'5E*2!["B`@
M("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92AC:'(H,BD@+B!C
M:'(H,BDL("=<7"(G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@<W1R7W)E<&QA8V4H8VAR*#$I("X@8VAR*#$I+"`G7%Q<7"<L("1V86QU
M92D["B`@("`@("`@("`@("`@("`D<F5G<ULD:61X72`]('-T<FEP<VQA<VAE
M<R@D=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YF
M;&%G<R`]("1R96=S6S-=.PH@("`@("`@("`@("`D=&AI<RT^<V5R=FEC97,@
M/2`D<F5G<ULT73L*("`@("`@("`@("`@)'1H:7,M/G)E9V5X(#T@)')E9W-;
M-5T["B`@("`@("`@("`@("1T:&ES+3YR97!L86-E;65N="`]("1R96=S6S9=
M.PH@("`@("`@('T*("`@('T*"B`@("`O*B!]?7T@*B\*("`@("\J($YE=%]$
M3E-?4E)?3D%05%(Z.G)D871A<W1R*"D@>WM[("HO"B`@("!F=6YC=&EO;B!R
M9&%T87-T<B@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YP;W)T*2!["B`@
M("`@("`@("`@(')E='5R;BAI;G1V86PH)'1H:7,M/F]R9&5R*2`N("<@)R`N
M(&EN='9A;"@D=&AI<RT^<')E9F5R96YC92D@+B`G("(G("X@861D<VQA<VAE
M<R@D=&AI<RT^9FQA9W,I("X@)R(@(B<@+B`*("`@("`@("`@("`@("`@("`@
M(&%D9'-L87-H97,H)'1H:7,M/G-E<G9I8V5S*2`N("<B("(G("X@861D<VQA
M<VAE<R@D=&AI<RT^<F5G97@I("X@)R(@(B<@+B!A9&1S;&%S:&5S*"1T:&ES
M+3YR97!L86-E;65N="D@+B`G(B<I.PH@("`@("`@('T@96QS92!R971U<FXH
M)SL@;F\@9&%T82<I.PH@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T
M7T1.4U]24E].05!44CHZ<G)?<F1A=&$H)'!A8VME="P@)&]F9G-E="D@>WM[
M("HO"B`@("!F=6YC=&EO;B!R<E]R9&%T82@D<&%C:V5T+"`D;V9F<V5T*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^<')E9F5R96YC92D@>PH@("`@("`@
M("`@("`D<F1A=&$@(#T@<&%C:R@G;FXG+"`D=&AI<RT^;W)D97(L("1T:&ES
M+3YP<F5F97)E;F-E*3L*("`@("`@("`@("`@)')D871A("X]('!A8VLH)T,G
M+"!S=')L96XH)'1H:7,M/F9L86=S*2D@("`@+B`D=&AI<RT^9FQA9W,["B`@
M("`@("`@("`@("1R9&%T82`N/2!P86-K*"=#)RP@<W1R;&5N*"1T:&ES+3YS
M97)V:6-E<RDI("X@)'1H:7,M/G-E<G9I8V5S.PH@("`@("`@("`@("`D<F1A
M=&$@+CT@<&%C:R@G0R<L('-T<FQE;B@D=&AI<RT^<F5G97@I*2`@("`N("1T
M:&ES+3YR96=E>#L*("`@("`@("`@("`@)')D871A("X]("1P86-K970M/F1N
M7V-O;7`H)'1H:7,M/G)E<&QA8V5M96YT+"`D;V9F<V5T("L@<W1R;&5N*"1R
M9&%T82DI.PH@("`@("`@("`@("!R971U<FXH)')D871A*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N*$Y53$PI.PH@("`@?0H*("`@("\J('U]?2`J+PI]
M"B\J('U]?2`J+PHO*B!624T@<V5T=&EN9W,@>WM["B`J($QO8V%L('9A<FEA
M8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J
M('-O9G0M<W1O<"UW:61T:#H@-`H@*B!C(&EN9&5N="!O;@H@*B!%;F0Z"B`J
M('9I;38P,#H@<W<]-"!T<STT('-T<STT(&-I;F1E;G0@9F1M/6UA<FME<B!E
M=`H@*B!V:6T\-C`P.B!S=STT('1S/30*("H@?7U]("HO"C\^"@``````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+T1.4R]24B]44TE'+G!H
M<```````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38Q-C<`,3`T
M,3<S-C,P,#8`,#(P,S(W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J"B`J("!,:6-E;G-E($EN9F]R;6%T:6]N
M.@H@*@H@*B`@("!.971?1$Y3.B`@02!R97-O;'9E<B!L:6)R87)Y(&9O<B!0
M2%`*("H@("`@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@17)I8R!+:6QF;VEL
M(&5R:6-`>7!A<W,N;F5T"B`J"B`J("`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E
M('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(*("H@
M("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E
M<B!'96YE<F%L(%!U8FQI8PH@*B`@("!,:6-E;G-E(&%S('!U8FQI<VAE9"!B
M>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N.R!E:71H97(*("H@("`@
M=F5R<VEO;B`R+C$@;V8@=&AE($QI8V5N<V4L(&]R("AA="!Y;W5R(&]P=&EO
M;BD@86YY(&QA=&5R('9E<G-I;VXN"B`J"B`J("`@(%1H:7,@;&EB<F%R>2!I
M<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E
M9G5L+`H@*B`@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@
M979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@*B`@("!-15)#2$%.5$%"
M24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4N("!3
M964@=&AE($=.50H@*B`@("!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS
M92!F;W(@;6]R92!D971A:6QS+@H@*@H@*B`@("!9;W4@<VAO=6QD(&AA=F4@
M<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC"B`J("`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF
M(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("H@("`@1F]U;F1A
M=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O
M;BP@34$@(#`R,3$Q+3$S,#<@(%5300H@*B\*"F1E9FEN92@G3D547T1.4U]$
M149!54Q47T%,1T]2251(32<L("=H;6%C+6UD-2YS:6<M86QG+G)E9RYI;G0G
M*3L*9&5F:6YE*"=.151?1$Y37T1%1D%53%1?1E5$1T4G+"`S,#`I.PH*+RH@
M3F5T7T1.4U]24E]44TE'(&1E9FEN:71I;VX@>WM[("HO"B\J*@H@*B!!(')E
M<')E<V5N=&%T:6]N(&]F(&$@<F5S;W5R8V4@<F5C;W)D(&]F('1Y<&4@/&(^
M5%-)1SPO8CX*("H*("H@0'!A8VMA9V4@3F5T7T1.4PH@*B\*8VQA<W,@3F5T
M7T1.4U]24E]44TE'(&5X=&5N9',@3F5T7T1.4U]24@I["B`@("`O*B!C;&%S
M<R!V87)I86)L92!D969I;FET:6]N<R![>WL@*B\*("`@('9A<B`D;F%M93L*
M("`@('9A<B`D='EP93L*("`@('9A<B`D8VQA<W,["B`@("!V87(@)'1T;#L*
M("`@('9A<B`D<F1L96YG=&@["B`@("!V87(@)')D871A.PH@("`@=F%R("1T
M:6UE7W-I9VYE9#L*("`@('9A<B`D9G5D9V4["B`@("!V87(@)&UA8U]S:7IE
M.PH@("`@=F%R("1M86,["B`@("!V87(@)&]R:6=I;F%L7VED.PH@("`@=F%R
M("1E<G)O<CL*("`@('9A<B`D;W1H97)?;&5N.PH@("`@=F%R("1O=&AE<E]D
M871A.PH@("`@=F%R("1K97D["@H@("`@+RH@?7U]("HO"B`@("`O*B!C;&%S
M<R!C;VYS=')U8W1O<B`M(%)2*"8D<G)O+"`D9&%T82P@)&]F9G-E="`]("<G
M*2![>WL@*B\*("`@(&9U;F-T:6]N($YE=%]$3E-?4E)?5%-)1R@F)')R;RP@
M)&1A=&$L("1O9F9S970@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^;F%M
M92`]("1R<F\M/FYA;64["B`@("`@("`@)'1H:7,M/G1Y<&4@/2`D<G)O+3YT
M>7!E.PH@("`@("`@("1T:&ES+3YC;&%S<R`]("1R<F\M/F-L87-S.PH@("`@
M("`@("1T:&ES+3YT=&P@/2`D<G)O+3YT=&P["B`@("`@("`@)'1H:7,M/G)D
M;&5N9W1H(#T@)')R;RT^<F1L96YG=&@["B`@("`@("`@)'1H:7,M/G)D871A
M(#T@)')R;RT^<F1A=&$["@H@("`@("`@(&EF("@D;V9F<V5T*2!["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^<F1L96YG=&@@/B`P*2!["B`@("`@("`@("`@
M("`@("!L:7-T*"1A;&<L("1O9F9S970I(#T@3F5T7T1.4U]086-K970Z.F1N
M7V5X<&%N9"@D9&%T82P@)&]F9G-E="D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^86QG;W)I=&AM(#T@)&%L9SL*"B`@("`@("`@("`@("`@("`D9"`]('5N
M<&%C:R@B7$`D;V9F<V5T+VYT:"].=&PO;F9U9&=E+VYM86-?<VEZ92(L("1D
M871A*3L*("`@("`@("`@("`@("`@("1T:6UE7VAI9V@@/2`D9%LG=&@G73L*
M("`@("`@("`@("`@("`@("1T:6UE7VQO=R`]("1D6R=T;"==.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G1I;65?<VEG;F5D(#T@)'1I;65?;&]W.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F9U9&=E(#T@)&1;)V9U9&=E)UT["B`@("`@
M("`@("`@("`@("`D=&AI<RT^;6%C7W-I>F4@/2`D9%LG;6%C7W-I>F4G73L*
M("`@("`@("`@("`@("`@("1O9F9S970@*ST@,3`["@H@("`@("`@("`@("`@
M("`@)'1H:7,M/FUA8R`]('-U8G-T<B@D9&%T82P@)&]F9G-E="P@)'1H:7,M
M/FUA8U]S:7IE*3L*("`@("`@("`@("`@("`@("1O9F9S970@*ST@)'1H:7,M
M/FUA8U]S:7IE.PH*("`@("`@("`@("`@("`@("1D(#T@=6YP86-K*")`)&]F
M9G-E="]N;VED+VYE<G)O<B]N;VQE;B(L("1D871A*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YO<FEG:6YA;%]I9"`]("1D6R=O:60G73L*("`@("`@("`@
M("`@("`@("1T:&ES+3YE<G)O<B`]("1D6R=E<G)O<B==.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F]T:&5R7VQE;B`]("1D6R=O;&5N)UT["B`@("`@("`@
M("`@("`@("`D;V9F<V5T("L](#8["@H@("`@("`@("`@("`@("`@)&]D871A
M(#T@<W5B<W1R*"1D871A+"`D;V9F<V5T+"`D=&AI<RT^;W1H97)?;&5N*3L*
M("`@("`@("`@("`@("`@("1D(#T@=6YP86-K*"=N;V1A=&%?:&EG:"].;V1A
M=&%?;&]W)RP@)&]D871A*3L*("`@("`@("`@("`@("`@("1T:&ES+3YO=&AE
M<E]D871A(#T@)&1;)V]D871A7VQO=R==.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*'-T<FQE;B@D9&%T82D@)B8@
M<')E9U]M871C:"@G+UXH+BHI)"\G+"`D9&%T82P@)')E9W,I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^:V5Y(#T@)')E9W-;,5T["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T:&ES+3YA;&=O<FET:&T@("`]($Y%5%]$3E-?
M1$5&055,5%]!3$=/4DE42$T["B`@("`@("`@("`@("1T:&ES+3YT:6UE7W-I
M9VYE9"`]('1I;64H*3L*"B`@("`@("`@("`@("1T:&ES+3YF=61G92`@("`@
M("`]($Y%5%]$3E-?1$5&055,5%]&541'13L*("`@("`@("`@("`@)'1H:7,M
M/FUA8U]S:7IE("`@(#T@,#L*("`@("`@("`@("`@)'1H:7,M/FUA8R`@("`@
M("`@(#T@)R<["B`@("`@("`@("`@("1T:&ES+3YO<FEG:6YA;%]I9"`](#`[
M"B`@("`@("`@("`@("1T:&ES+3YE<G)O<B`@("`@("`](#`["B`@("`@("`@
M("`@("1T:&ES+3YO=&AE<E]L96X@("`](#`["B`@("`@("`@("`@("1T:&ES
M+3YO=&AE<E]D871A("`]("<G.PH*("`@("`@("`@("`@+R\@4D9#(#(X-#4@
M4V5C=&EO;B`R+C,*("`@("`@("`@("`@)'1H:7,M/F-L87-S(#T@)T%.62<[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.
M4U]24E]44TE'.CIR9&%T87-T<B@I('M[>R`J+PH@("`@9G5N8W1I;VX@<F1A
M=&%S='(H*0H@("`@>PH@("`@("`@("1E<G)O<B`]("1T:&ES+3YE<G)O<CL*
M("`@("`@("!I9B`H(2`D97)R;W(I('L*("`@("`@("`@("`@)&5R<F]R(#T@
M)U5.1$5&24Y%1"<["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R;&5N*"1T
M:&ES+3YA;&=O<FET:&TI*2!["B`@("`@("`@("`@("1R9&%T87-T<B`]("1T
M:&ES+3YA;&=O<FET:&T@+B`G+B`G("X@)'1H:7,M/G1I;65?<VEG;F5D("X@
M)R`G("X*("`@("`@("`@("`@("`@("1T:&ES+3YF=61G92`N("<@)SL*("`@
M("`@("`@("`@:68@*"1T:&ES+3YM86-?<VEZ92`F)B!S=')L96XH)'1H:7,M
M/FUA8RDI('L*("`@("`@("`@("`@("`@("1R9&%T87-T<B`N/2`G("<@+B`D
M=&AI<RT^;6%C7W-I>F4@+B`G("<@+B!B87-E-C1?96YC;V1E*"1T:&ES+3YM
M86,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')D
M871A<W1R("X]("<@,"`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R
M9&%T87-T<B`N/2`G("<@+B`D=&AI<RT^;W)I9VEN86Q?:60@+B`G("<@+B`D
M97)R;W(["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W1H97)?;&5N("8F('-T
M<FQE;B@D=&AI<RT^;W1H97)?9&%T82DI('L*("`@("`@("`@("`@("`@("1R
M9&%T87-T<B`N/2`G("<@+B`D=&AI<RT^;W1H97)?9&%T83L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R9&%T87-T<B`N/2`G(#`@
M)SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1R9&%T87-T<B`]("<[(&YO(&1A=&$G.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N*"1R9&%T87-T<BD["B`@("!]"@H@("`@+RH@?7U]("HO"B`@("`O
M*B!.971?1$Y37U)27U1324<Z.G)R7W)D871A*"1P86-K970L("1O9F9S970I
M('M[>R`J+PH@("`@9G5N8W1I;VX@<G)?<F1A=&$H)'!A8VME="P@)&]F9G-E
M="D*("`@('L*("`@("`@("`D<F1A=&$@/2`G)SL*("`@("`@("`D<VEG9&%T
M82`]("<G.PH*("`@("`@("!I9B`H<W1R;&5N*"1T:&ES+3YK97DI*2!["B`@
M("`@("`@("`@("1K97D@/2`D=&AI<RT^:V5Y.PH@("`@("`@("`@("`D:V5Y
M(#T@97)E9U]R97!L86-E*"<@)RP@)R<L("1K97DI.PH@("`@("`@("`@("`D
M:V5Y(#T@8F%S938T7V1E8V]D92@D:V5Y*3L*"B`@("`@("`@("`@("1N97=P
M86-K970@/2`D<&%C:V5T.PH@("`@("`@("`@("`D;F5W;V9F<V5T(#T@)&]F
M9G-E=#L*("`@("`@("`@("`@87)R87E?<&]P*"1N97=P86-K970M/F%D9&ET
M:6]N86PI.PH@("`@("`@("`@("`D;F5W<&%C:V5T+3YH96%D97(M/F%R8V]U
M;G0M+3L*("`@("`@("`@("`@)&YE=W!A8VME="T^8V]M<&YA;65S(#T@87)R
M87DH*3L*"B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J($%D9"!T:&4@
M<F5Q=65S="!-04,@:68@<')E<V5N="`H=7-E9"!T;R!V86QI9&%T92!R97-P
M;VYS97,I+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YR97%U97-T7VUA8RDI('L*("`@("`@("`@("`@("`@("1S:6=D
M871A("X]('!A8VLH)T@J)RP@)'1H:7,M/G)E<75E<W1?;6%C*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D<VEG9&%T82`N/2`D;F5W<&%C:V5T+3YD
M871A*"D["@H@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!$;VXG="!C
M;VUP<F5S<R!T:&4@<F5C;W)D("AK97DI(&YA;64N"B`@("`@("`@("`@("`J
M+PH@("`@("`@("`@("`D=&UP<&%C:V5T(#T@;F5W($YE=%]$3E-?4&%C:V5T
M.PH@("`@("`@("`@("`D<VEG9&%T82`N/2`D=&UP<&%C:V5T+3YD;E]C;VUP
M*'-T<G1O;&]W97(H)'1H:7,M/FYA;64I+"`P*3L*"B`@("`@("`@("`@("1S
M:6=D871A("X]('!A8VLH)VXG+"!.971?1$Y3.CIC;&%S<V5S8GEN86UE*'-T
M<G1O=7!P97(H)'1H:7,M/F-L87-S*2DI.PH@("`@("`@("`@("`D<VEG9&%T
M82`N/2!P86-K*"=.)RP@)'1H:7,M/G1T;"D["@H@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!$;VXG="!C;VUP<F5S<R!T:&4@86QG;W)I=&AM(&YA
M;64N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D=&UP<&%C:V5T+3YC
M;VUP;F%M97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D<VEG9&%T82`N/2`D
M=&UP<&%C:V5T+3YD;E]C;VUP*'-T<G1O;&]W97(H)'1H:7,M/F%L9V]R:71H
M;2DL(#`I.PH*("`@("`@("`@("`@)'-I9V1A=&$@+CT@<&%C:R@G;DXG+"`P
M+"`D=&AI<RT^=&EM95]S:6=N960I.PH@("`@("`@("`@("`D<VEG9&%T82`N
M/2!P86-K*"=N)RP@)'1H:7,M/F9U9&=E*3L*("`@("`@("`@("`@)'-I9V1A
M=&$@+CT@<&%C:R@G;FXG+"`D=&AI<RT^97)R;W(L("1T:&ES+3YO=&AE<E]L
M96XI.PH*("`@("`@("`@("`@:68@*'-T<FQE;B@D=&AI<RT^;W1H97)?9&%T
M82DI('L*("`@("`@("`@("`@("`@("1S:6=D871A("X]('!A8VLH)VY.)RP@
M,"P@)'1H:7,M/F]T:&5R7V1A=&$I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=&AI<RT^;6%C(#T@;6AA<V@H34A!4TA?340U+"`D<VEG9&%T82P@
M)&ME>2D["B`@("`@("`@("`@("1T:&ES+3YM86-?<VEZ92`]('-T<FQE;B@D
M=&AI<RT^;6%C*3L*"B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J($1O
M;B=T(&-O;7!R97-S('1H92!A;&=O<FET:&T@;F%M92X*("`@("`@("`@("`@
M("HO"B`@("`@("`@("`@('5N<V5T*"1T;7!P86-K970I.PH@("`@("`@("`@
M("`D=&UP<&%C:V5T(#T@;F5W($YE=%]$3E-?4&%C:V5T.PH@("`@("`@("`@
M("`D<F1A=&$@+CT@)'1M<'!A8VME="T^9&Y?8V]M<"AS=')T;VQO=V5R*"1T
M:&ES+3YA;&=O<FET:&TI+"`P*3L*"B`@("`@("`@("`@("1R9&%T82`N/2!P
M86-K*"=N3B<L(#`L("1T:&ES+3YT:6UE7W-I9VYE9"D["B`@("`@("`@("`@
M("1R9&%T82`N/2!P86-K*"=N;B<L("1T:&ES+3YF=61G92P@)'1H:7,M/FUA
M8U]S:7IE*3L*("`@("`@("`@("`@)')D871A("X]("1T:&ES+3YM86,["@H@
M("`@("`@("`@("`D<F1A=&$@+CT@<&%C:R@G;FYN)RPD<&%C:V5T+3YH96%D
M97(M/FED+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<BP*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;W1H97)?;&5N*3L*"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^;W1H97)?9&%T82D@>PH@("`@("`@("`@("`@("`@
M)')D871A("X]('!A8VLH)VY.)RP@,"P@)'1H:7,M/F]T:&5R7V1A=&$I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B@D<F1A=&$I
M.PH@("`@?0H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)27U1324<Z
M.F5R<F]R*"D@>WM[("HO"B`@("!F=6YC=&EO;B!E<G)O<B@I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3YE<G)O<B`A/2`P*2!["B`@("`@("`@("`@("1R
M8V]D92`]($YE=%]$3E,Z.G)C;V1E<V)Y=F%L*"1E<G)O<BD["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F-O9&4["B`@("!]"@H@("`@+RH@?7U]("HO
M"GT*+RH@?7U]("HO"B\J(%9)32!S971T:6YG<R![>WL*("H@3&]C86P@=F%R
M:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*
M("H@<V]F="US=&]P+7=I9'1H.B`T"B`J(&,@:6YD96YT(&]N"B`J(&5X<&%N
M9'1A8B!O;@H@*B!%;F0Z"B`J('9I;38P,#H@<W<]-"!T<STT('-T<STT(&-I
M;F1E;G0@9F1M/6UA<FME<B!E=`H@*B!V:6T\-C`P.B!S=STT('1S/30*("H@
M?7U]("HO"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O1$Y3+U)2+U!44BYP
M:'``````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3`W-0`Q
M,#0Q-S,V,S`P-@`P,C`R,C(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH*("H@($QI8V5N<V4@26YF;W)M871I
M;VXZ"B`J"B`J("`@($YE=%]$3E,Z("!!(')E<V]L=F5R(&QI8G)A<GD@9F]R
M(%!(4`H@*B`@("!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!%<FEC($MI;&9O
M:6P@97)I8T!Y<&%S<RYN970*("H*("H@("`@5&AI<R!L:6)R87)Y(&ES(&9R
M964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@
M*B`@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S
M<V5R($=E;F5R86P@4'5B;&EC"B`J("`@($QI8V5N<V4@87,@<'5B;&ES:&5D
M(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VX[(&5I=&AE<@H@*B`@
M("!V97)S:6]N(#(N,2!O9B!T:&4@3&EC96YS92P@;W(@*&%T('EO=7(@;W!T
M:6]N*2!A;GD@;&%T97(@=F5R<VEO;BX*("H*("H@("`@5&AI<R!L:6)R87)Y
M(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U
M<V5F=6PL"B`J("`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U
M="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`J("`@($U%4D-(04Y4
M04))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@
M(%-E92!T:&4@1TY5"B`J("`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E
M;G-E(&9O<B!M;W)E(&1E=&%I;',N"B`J"B`J("`@(%EO=2!S:&]U;&0@:&%V
M92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,*("H@("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@
M:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@*B`@("!&;W5N
M9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S
M=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!"B`J+PH*+RH@3F5T7T1.4U]24E]0
M5%(@9&5F:6YI=&EO;B![>WL@*B\*+RHJ"B`J($$@<F5P<F5S96YT871I;VX@
M;V8@82!R97-O=7)C92!R96-O<F0@;V8@='EP92`\8CY05%(\+V(^"B`J"B`J
M($!P86-K86=E($YE=%]$3E,*("HO"F-L87-S($YE=%]$3E-?4E)?4%12(&5X
M=&5N9',@3F5T7T1.4U]24@I["B`@("`O*B!C;&%S<R!V87)I86)L92!D969I
M;FET:6]N<R![>WL@*B\*("`@('9A<B`D;F%M93L*("`@('9A<B`D='EP93L*
M("`@('9A<B`D8VQA<W,["B`@("!V87(@)'1T;#L*("`@('9A<B`D<F1L96YG
M=&@["B`@("!V87(@)')D871A.PH@("`@=F%R("1P=')D;F%M93L*"B`@("`O
M*B!]?7T@*B\*("`@("\J(&-L87-S(&-O;G-T<G5C=&]R("T@4E(H)B1R<F\L
M("1D871A+"`D;V9F<V5T(#T@)R<I('M[>R`J+PH@("`@9G5N8W1I;VX@3F5T
M7T1.4U]24E]05%(H)B1R<F\L("1D871A+"`D;V9F<V5T(#T@)R<I"B`@("![
M"B`@("`@("`@)'1H:7,M/FYA;64@/2`D<G)O+3YN86UE.PH@("`@("`@("1T
M:&ES+3YT>7!E(#T@)')R;RT^='EP93L*("`@("`@("`D=&AI<RT^8VQA<W,@
M/2`D<G)O+3YC;&%S<SL*("`@("`@("`D=&AI<RT^='1L(#T@)')R;RT^='1L
M.PH@("`@("`@("1T:&ES+3YR9&QE;F=T:"`]("1R<F\M/G)D;&5N9W1H.PH@
M("`@("`@("1T:&ES+3YR9&%T82`]("1R<F\M/G)D871A.PH*"B`@("`@("`@
M:68@*"1O9F9S970I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YR9&QE;F=T
M:"`^(#`I('L*("`@("`@("`@("`@("`@(&QI<W0H)'!T<F1N86UE+"`D;V9F
M<V5T*2`]($YE=%]$3E-?4&%C:V5T.CID;E]E>'!A;F0H)&1A=&$L("1O9F9S
M970I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G!T<F1N86UE(#T@)'!T<F1N
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/G!T<F1N86UE(#T@97)E9U]R97!L86-E*");(%QT72LH+BLI
M6R!<=%TJ)"(L("=<7#$G+"`D9&%T82D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]24E]05%(Z.G)D871A<W1R*"D@
M>WM[("HO"B`@("!F=6YC=&EO;B!R9&%T87-T<B@I"B`@("!["B`@("`@("`@
M:68@*'-T<FQE;B@D=&AI<RT^<'1R9&YA;64I*2!["B`@("`@("`@("`@(')E
M='5R;B@D=&AI<RT^<'1R9&YA;64@+B`G+B<I.PH@("`@("`@('T*("`@("`@
M("!R971U<FXH)SL@;F\@9&%T82<I.PH@("`@?0H*("`@("\J('U]?2`J+PH@
M("`@+RH@3F5T7T1.4U]24E]05%(Z.G)R7W)D871A*"1P86-K970L("1O9F9S
M970I('M[>R`J+PH@("`@9G5N8W1I;VX@<G)?<F1A=&$H)'!A8VME="P@)&]F
M9G-E="D*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1T:&ES+3YP=')D;F%M
M92DI('L*("`@("`@("`@("`@<F5T=7)N*"1P86-K970M/F1N7V-O;7`H)'1H
M:7,M/G!T<F1N86UE+"`D;V9F<V5T*2D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;BA.54Q,*3L*("`@('T*"B`@("`O*B!]?7T@*B\*?0HO*B!]?7T@*B\*
M+RH@5DE-('-E='1I;F=S('M[>PH@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A
M8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!S;V9T+7-T;W`M
M=VED=&@Z(#0*("H@8R!I;F1E;G0@;VX*("H@16YD.@H@*B!V:6TV,#`Z('-W
M/30@=',]-"!S=',]-"!C:6YD96YT(&9D;3UM87)K97(@970*("H@=FEM/#8P
M,#H@<W<]-"!T<STT"B`J('U]?2`J+PH_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TYE="]$3E,O4E(N<&AP````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(Q,S4S`#$P-#$W,S8S,#`V`#`Q-S4U
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*@H@*B`@3&EC96YS92!);F9O<FUA=&EO;CH*("H*("H@("`@3F5T
M7T1.4SH@($$@<F5S;VQV97(@;&EB<F%R>2!F;W(@4$A0"B`J("`@($-O<'ER
M:6=H="`H8RD@,C`P,BTR,#`S($5R:6,@2VEL9F]I;"!E<FEC0'EP87-S+FYE
M=`H@*@H@*B`@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U
M(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`J("`@(&UO9&EF>2!I="!U
M;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L
M:6,*("H@("`@3&EC96YS92!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F
M='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R"B`J("`@('9E<G-I;VX@,BXQ(&]F
M('1H92!,:6-E;G-E+"!O<B`H870@>6]U<B!O<'1I;VXI(&%N>2!L871E<B!V
M97)S:6]N+@H@*@H@*B`@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@
M:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("H@("`@8G5T
M(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI
M960@=V%R<F%N='D@;V8*("H@("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%
M4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("H@
M("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T
M86EL<RX*("H*("H@("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P
M>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@*B`@("!,:6-E
M;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O
M('1H92!&<F5E(%-O9G1W87)E"B`J("`@($9O=6YD871I;VXL($EN8RXL(#4Y
M(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL($U!("`P,C$Q,2TQ
M,S`W("!54T$*("HO"@HO*B!);F-L=61E(&9I;&5S('M[>R`J+PIR97%U:7)E
M7V]N8V4H(B1P:'!D;G-?8F%S961I<B]$3E,O4E(O02YP:'`B*3L*<F5Q=6ER
M95]O;F-E*"(D<&AP9&YS7V)A<V5D:7(O1$Y3+U)2+T%!04$N<&AP(BD["G)E
M<75I<F5?;VYC92@B)'!H<&1N<U]B87-E9&ER+T1.4R]24B].4RYP:'`B*3L*
M<F5Q=6ER95]O;F-E*"(D<&AP9&YS7V)A<V5D:7(O1$Y3+U)2+T-.04U%+G!H
M<"(I.PIR97%U:7)E7V]N8V4H(B1P:'!D;G-?8F%S961I<B]$3E,O4E(O4%12
M+G!H<"(I.PIR97%U:7)E7V]N8V4H(B1P:'!D;G-?8F%S961I<B]$3E,O4E(O
M4T]!+G!H<"(I.PIR97%U:7)E7V]N8V4H(B1P:'!D;G-?8F%S961I<B]$3E,O
M4E(O35@N<&AP(BD["G)E<75I<F5?;VYC92@B)'!H<&1N<U]B87-E9&ER+T1.
M4R]24B]44TE'+G!H<"(I.PIR97%U:7)E7V]N8V4H(B1P:'!D;G-?8F%S961I
M<B]$3E,O4E(O5%A4+G!H<"(I.PIR97%U:7)E7V]N8V4H(B1P:'!D;G-?8F%S
M961I<B]$3E,O4E(O2$E.1D\N<&AP(BD["G)E<75I<F5?;VYC92@B)'!H<&1N
M<U]B87-E9&ER+T1.4R]24B]34E8N<&AP(BD["G)E<75I<F5?;VYC92@B)'!H
M<&1N<U]B87-E9&ER+T1.4R]24B].05!44BYP:'`B*3L*+RH@?7U]("HO"B\J
M($YE=%]$3E-?4E(@;V)J96-T(&1E9FEN:71I;VX@>WM[("HO"B\J*@H@*B!2
M97-O=7)C92!296-O<F0@;V)J96-T(&1E9FEN:71I;VX*("H*("H@0G5I;&1S
M(&]R('!A<G-E<R!R97-O=7)C92!R96-O<F0@<V5C=&EO;G,@;V8@=&AE($1.
M4R`@<&%C:V5T(&EN8VQU9&EN9PH@*B!T:&4@86YS=V5R+"!A=71H;W)I='DL
M(&%N9"!A9&1I=&EO;F%L("!S96-T:6]N<R!O9B!T:&4@<&%C:V5T+@H@*@H@
M*B!`<&%C:V%G92!.971?1$Y3"B`J+PIC;&%S<R!.971?1$Y37U)2"GL*("`@
M("\J(&-L87-S('9A<FEA8FQE(&1E9FEN:71I;VYS('M[>R`J+PH@("`@=F%R
M("1N86UE.PH@("`@=F%R("1T>7!E.PH@("`@=F%R("1C;&%S<SL*("`@('9A
M<B`D='1L.PH@("`@=F%R("1R9&QE;F=T:#L*("`@('9A<B`D<F1A=&$["B`@
M("`O*B!]?7T@*B\*"B`@("`O*@H@("`@("H@22!F:6YA;&QY(&1I9"!I="XN
M+B!I('!A<W,@86X@87)R87D@=&\@=&AE(&9U;F-T:6]N"B`@("`@*B!I;G-T
M96%D(&]F(&$@<&%R86UE=&5R(&QI<W0N+BX@54=(+BXN(&D@:&%T92!P97)L
M+BXN"B`@("`@*B\*("`@("\J(&-L87-S(&-O;G-T<G5C=&]R("T@3F5T7T1.
M4U]24B@D<G)D871A*2![>WL@*B\*("`@(&9U;F-T:6]N($YE=%]$3E-?4E(H
M)')R9&%T82D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R<F1A=&$I
M*2!["B`@("`@("`@("`@("1T:&ES(#T@)'1H:7,M/FYE=U]F<F]M7W-T<FEN
M9R@D<G)D871A*3L*("`@("`@("!](&5L<V4@:68@*&-O=6YT*"1R<F1A=&$I
M(#T](#<I('L*("`@("`@("`@("`@;&ES="`H)&YA;64L("1R<G1Y<&4L("1R
M<F-L87-S+"`D='1L+"`D<F1L96YG=&@L("1D871A+"`D;V9F<V5T*2`]("1R
M<F1A=&$["B`@("`@("`@("`@("1T:&ES(#T@)'1H:7,M/FYE=U]F<F]M7V1A
M=&$H)&YA;64L("1R<G1Y<&4L("1R<F-L87-S+"`D='1L+"`D<F1L96YG=&@L
M("1D871A+"`D;V9F<V5T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<R`]("1T:&ES+3YN97=?9G)O;5]A<G)A>2@D<G)D871A*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)2
M.CIN97=?9G)O;5]D871A*"1N86UE+"`D='1L+"`D<G)T>7!E+"`D<G)C;&%S
M<RP@)')D;&5N9W1H+"`D9&%T82P@)&]F9G-E="D@>WM[("HO"B`@("!F=6YC
M=&EO;B!N97=?9G)O;5]D871A*"1N86UE+"`D<G)T>7!E+"`D<G)C;&%S<RP@
M)'1T;"P@)')D;&5N9W1H+"`D9&%T82P@)&]F9G-E="D*("`@('L*("`@("`@
M("`D=&AI<RT^;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3YT>7!E(#T@
M)')R='EP93L*("`@("`@("`D=&AI<RT^8VQA<W,@/2`D<G)C;&%S<SL*("`@
M("`@("`D=&AI<RT^='1L(#T@)'1T;#L*("`@("`@("`D=&AI<RT^<F1L96YG
M=&@@/2`D<F1L96YG=&@["B`@("`@("`@)'1H:7,M/G)D871A(#T@<W5B<W1R
M*"1D871A+"`D;V9F<V5T+"`D<F1L96YG=&@I.PH@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)TYE=%]$3E-?4E)?)R`N("1R<G1Y<&4I*2!["B`@("`@("`@
M("`@("1S8VX@/2`G3F5T7T1.4U]24E\G("X@)')R='EP93L*("`@("`@("`@
M("`@)'-U8F-L87-S(#T@;F5W("1S8VXH)'1H:7,L("1D871A+"`D;V9F<V5T
M*3L*("`@("`@("`@("`@<F5T=7)N*"1S=6)C;&%S<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N*"1T:&ES*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)2.CIN97=?9G)O
M;5]S=')I;F<H)')R<W1R:6YG+"`D=7!D871E7W1Y<&4@/2`G)RD@>WM[("HO
M"B`@("!F=6YC=&EO;B!N97=?9G)O;5]S=')I;F<H)')R<W1R:6YG+"`D=7!D
M871E7W1Y<&4@/2`G)RD*("`@('L*("`@("`@("`D='1L(#T@,#L*("`@("`@
M("`D<&%R=',@/2!P<F5G7W-P;&ET*"<O6UQS72LO)RP@)')R<W1R:6YG*3L*
M("`@("`@("!W:&EL92`H)',@/2!A<G)A>5]S:&EF="@D<&%R=',I*2!["B`@
M("`@("`@("`@(&EF("@A:7-S970H)&YA;64I*2!["B`@("`@("`@("`@("`@
M("`D;F%M92`](&5R96=?<F5P;&%C92@G7"XK)"<L("<G+"`D<RD["B`@("`@
M("`@("`@('T@96QS92!I9B`H<')E9U]M871C:"@G+UY<9"LD+R<L("1S*2D@
M>PH@("`@("`@("`@("`@("`@)'1T;"`]("1S.PH@("`@("`@("`@("!](&5L
M<V4@:68@*"%I<W-E="@D<G)C;&%S<RD@)B8@(2!I<U]N=6QL*$YE=%]$3E,Z
M.F-L87-S97-B>6YA;64H<W1R=&]U<'!E<B@D<RDI*2D@>PH@("`@("`@("`@
M("`@("`@)')R8VQA<W,@/2!S=')T;W5P<&5R*"1S*3L*("`@("`@("`@("`@
M("`@("1R9&%T82`](&IO:6XH)R`G+"`D<&%R=',I.PH@("`@("`@("`@("!]
M(&5L<V4@:68@*"$@:7-?;G5L;"A.971?1$Y3.CIT>7!E<V)Y;F%M92AS=')T
M;W5P<&5R*"1S*2DI*2!["B`@("`@("`@("`@("`@("`D<G)T>7!E(#T@<W1R
M=&]U<'!E<B@D<RD["B`@("`@("`@("`@("`@("`D<F1A=&$@/2!J;VEN*"<@
M)RP@)'!A<G1S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@($1O('=E(&YE
M960@=&\@9&\@=&AI<S\*("`@("`@("`@*B\*("`@("`@("`D<F1A=&$@/2!T
M<FEM*&-H;W`H)')D871A*2D["@H@("`@("`@(&EF("@A('-T<FQE;B@D<G)T
M>7!E*2`F)B!S=')L96XH)')R8VQA<W,I("8F("1R<F-L87-S(#T]("=!3EDG
M*2!["B`@("`@("`@("`@("1R<G1Y<&4@/2`D<G)C;&%S<SL*("`@("`@("`@
M("`@)')R8VQA<W,@/2`G24XG.PH@("`@("`@('T@96QS92!I9B`H(2!I<W-E
M="@D<G)C;&%S<RDI('L*("`@("`@("`@("`@)')R8VQA<W,@/2`G24XG.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"$@<W1R;&5N*"1R<G1Y<&4I*2!["B`@
M("`@("`@("`@("1R<G1Y<&4@/2`G04Y9)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("AS=')L96XH)'5P9&%T95]T>7!E*2D@>PH@("`@("`@("`@("`D=7!D
M871E7W1Y<&4@/2!S=')T;VQO=V5R*"1U<&1A=&5?='EP92D["B`@("`@("`@
M("`@(&EF("@D=7!D871E7W1Y<&4@/3T@)WEX<G)S970G*2!["B`@("`@("`@
M("`@("`@("`D='1L(#T@,#L*("`@("`@("`@("`@("`@(&EF("@A('-T<FQE
M;B@D<F1A=&$I*2!["B`@("`@("`@("`@("`@("`@("`@)')R8VQA<W,@/2`G
M04Y9)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E(&EF
M("@D=7!D871E7W1Y<&4@/3T@)VYX<G)S970G*2!["B`@("`@("`@("`@("`@
M("`D='1L(#T@,#L*("`@("`@("`@("`@("`@("1R<F-L87-S(#T@)TY/3D4G
M.PH@("`@("`@("`@("`@("`@)')D871A(#T@)R<["B`@("`@("`@("`@('T@
M96QS92!I9B`H)'5P9&%T95]T>7!E(#T]("=Y>&1O;6%I;B<I('L*("`@("`@
M("`@("`@("`@("1T=&P@/2`P.PH@("`@("`@("`@("`@("`@)')R8VQA<W,@
M/2`G04Y9)SL*("`@("`@("`@("`@("`@("1R<G1Y<&4@/2`G04Y9)SL*("`@
M("`@("`@("`@("`@("1R9&%T82`]("<G.PH@("`@("`@("`@("!](&5L<V4@
M:68@*"1U<&1A=&5?='EP92`]/2`G;GAD;VUA:6XG*2!["B`@("`@("`@("`@
M("`@("`D='1L(#T@,#L*("`@("`@("`@("`@("`@("1R<F-L87-S(#T@)TY/
M3D4G.PH@("`@("`@("`@("`@("`@)')R='EP92`]("=!3EDG.PH@("`@("`@
M("`@("`@("`@)')D871A(#T@)R<["B`@("`@("`@("`@('T@96QS92!I9B`H
M<')E9U]M871C:"@G+UXH<G)?*3]A9&0D+R<L("1U<&1A=&5?='EP92DI('L*
M("`@("`@("`@("`@("`@("1U<&1A=&5?='EP92`]("=A9&0G.PH@("`@("`@
M("`@("`@("`@:68@*"$@)'1T;"D@>PH@("`@("`@("`@("`@("`@("`@("1T
M=&P@/2`X-C0P,#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E(&EF("AP<F5G7VUA=&-H*"<O7BAR<E\I/V1E;"AE=&4I/R0O)RP@)'5P
M9&%T95]T>7!E*2D@>PH@("`@("`@("`@("`@("`@)'5P9&%T95]T>7!E(#T@
M)V1E;"<["B`@("`@("`@("`@("`@("`D='1L(#T@,#L*("`@("`@("`@("`@
M("`@("1R<F-L87-S(#T@)')D871A(#\@)TY/3D4G(#H@)T%.62<["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AS=')L96XH)')R='EP
M92DI('L*("`@("`@("`@("`@)'1H:7,M/FYA;64@/2`D;F%M93L*("`@("`@
M("`@("`@)'1H:7,M/G1Y<&4@/2`D<G)T>7!E.PH@("`@("`@("`@("`D=&AI
M<RT^8VQA<W,@/2`D<G)C;&%S<SL*("`@("`@("`@("`@)'1H:7,M/G1T;"`]
M("1T=&P["B`@("`@("`@("`@("1T:&ES+3YR9&QE;F=T:"`](#`["B`@("`@
M("`@("`@("1T:&ES+3YR9&%T82`]("<G.PH*("`@("`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@G3F5T7T1.4U]24E\G("X@)')R='EP92DI('L*("`@("`@
M("`@("`@("`@("1S8VX@/2`G3F5T7T1.4U]24E\G("X@)')R='EP93L*("`@
M("`@("`@("`@("`@("1R8R`](&YE=R`D<V-N*"1T:&ES+"`D<F1A=&$I.PH@
M("`@("`@("`@("`@("`@<F5T=7)N*"1R8RD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FXH)'1H:7,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N*$Y53$PI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*B!]?7T@*B\*("`@("\J($YE=%]$
M3E-?4E(Z.FYE=U]F<F]M7V%R<F%Y*"1R<F%R<F%Y*2![>WL@*B\*("`@(&9U
M;F-T:6]N(&YE=U]F<F]M7V%R<F%Y*"1R<F%R<F%Y*0H@("`@>PH@("`@("`@
M(&9O<F5A8V@@*"1R<F%R<F%Y(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@
M("1T:&ES+3Y[<W1R=&]L;W=E<B@D:RE](#T@)'8["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(2!S=')L96XH)'1H:7,M/FYA;64I*2!["B`@("`@("`@("`@
M(')E='5R;BA.54Q,*3L*("`@("`@("!]"B`@("`@("`@:68@*"$@<W1R;&5N
M*"1T:&ES+3YT>7!E*2E["B`@("`@("`@("`@(')E='5R;BA.54Q,*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"$@)'1H:7,M/G1T;"D@>PH@("`@("`@("`@
M("`D=&AI<RT^='1L(#T@,#L*("`@("`@("!]"B`@("`@("`@:68@*"$@<W1R
M;&5N*"1T:&ES+3YC;&%S<RDI('L*("`@("`@("`@("`@)'1H:7,M/F-L87-S
M(#T@)TE.)SL*("`@("`@("!]"B`@("`@("`@:68@*'-T<FQE;B@D=&AI<RT^
M<F1A=&$I*2!["B`@("`@("`@("`@("1T:&ES+3YR9&QE;F=T:"`]('-T<FQE
M;B@D<F1A=&$I.PH@("`@("`@('T*("`@("`@("!I9B`H8VQA<W-?97AI<W1S
M*"=.971?1$Y37U)27R<@+B`D<G)T>7!E*2D@>PH@("`@("`@("`@("`D<V-N
M(#T@)TYE=%]$3E-?4E)?)R`N("1R<G1Y<&4["B`@("`@("`@("`@("1R8R`]
M(&YE=R`D<V-N*"1T:&ES+"`D<F1A=&$I.PH@("`@("`@("`@("!R971U<FXH
M)')C*3L*("`@("`@("!](&5L<V4*("`@("`@("`@("`@<F5T=7)N*"1T:&ES
M*3L*("`@('T*"B`@("`O*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4E(Z.F1I
M<W!L87DH*2![>WL@*B\*("`@(&9U;F-T:6]N(&1I<W!L87DH*0H@("`@>PH@
M("`@("`@(&5C:&\@)'1H:7,M/G-T<FEN9R@I("X@(EQN(CL*("`@('T*"B`@
M("`O*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4E(Z.G-T<FEN9R@I('M[>R`J
M+PH@("`@9G5N8W1I;VX@<W1R:6YG*"D*("`@('L*("`@("`@("!R971U<FXH
M)'1H:7,M/FYA;64@+B`B+EQT(B`N("AS=')L96XH)'1H:7,M/FYA;64I(#P@
M,38@/R`B7'0B(#H@)R<I("X*("`@("`@("`@("`@("`@("1T:&ES+3YT=&P@
M("X@(EQT(B`@+@H@("`@("`@("`@("`@("`@)'1H:7,M/F-L87-S+B`B7'0B
M("`N"B`@("`@("`@("`@("`@("`D=&AI<RT^='EP92`N(")<="(@("X*("`@
M("`@("`@("`@("`@("1T:&ES+3YR9&%T87-T<B@I*3L*"B`@("!]"@H@("`@
M+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)2.CIR9&%T87-T<B@I('M[>R`J
M+PH@("`@9G5N8W1I;VX@<F1A=&%S='(H*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^<F1L96YG=&@I('L*("`@("`@("`@("`@<F5T=7)N*"<[(')D;&5N
M9W1H(#T@)R`N("1T:&ES+3YR9&QE;F=T:"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B@G.R!N;R!D871A)RD["B`@("!]"@H@("`@+RH@?7U]("HO"B`@
M("`O*B!.971?1$Y37U)2.CIR9&%T82@I('M[>R`J+PH@("`@9G5N8W1I;VX@
M<F1A=&$H)B1P86-K971/4G)D871A+"`D;V9F<V5T(#T@)R<I"B`@("!["B`@
M("`@("`@:68@*"1O9F9S970I('L*("`@("`@("`@("`@<F5T=7)N*"1T:&ES
M+3YR<E]R9&%T82@D<&%C:V5T3U)R9&%T82P@)&]F9G-E="DI.PH@("`@("`@
M('T@96QS92!I9B`H<W1R;&5N*"1T:&ES+3YR9&%T82DI('L*("`@("`@("`@
M("`@<F5T=7)N*"1T:&ES+3YR9&%T82D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N*$Y53$PI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4E(Z.G)R7W)D871A*"1P86-K970L
M("1O9F9S970I('M[>R`J+PH@("`@9G5N8W1I;VX@<G)?<F1A=&$H)B1P86-K
M970L("1O9F9S970I"B`@("!["B`@("`@("`@<F5T=7)N*"AS=')L96XH)'1H
M:7,M/G)D871A*2`_("1T:&ES+3YR9&%T82`Z("<G*2D["B`@("!]"B`@("`O
M*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4E(Z.F1A=&$H*2![>WL@*B\*("`@
M(&9U;F-T:6]N(&1A=&$H)B1P86-K970L("1O9F9S970I"B`@("!["B`@("`@
M("`@)&1A=&$@/2`D<&%C:V5T+3YD;E]C;VUP*"1T:&ES+3YN86UE+"`D;V9F
M<V5T*3L*("`@("`@("`D9&%T82`N/2!P86-K*"=N)RP@3F5T7T1.4SHZ='EP
M97-B>6YA;64H<W1R=&]U<'!E<B@D=&AI<RT^='EP92DI*3L*("`@("`@("`D
M9&%T82`N/2!P86-K*"=N)RP@3F5T7T1.4SHZ8VQA<W-E<V)Y;F%M92AS=')T
M;W5P<&5R*"1T:&ES+3YC;&%S<RDI*3L*("`@("`@("`D9&%T82`N/2!P86-K
M*"=.)RP@)'1H:7,M/G1T;"D["@H@("`@("`@("1O9F9S970@*ST@<W1R;&5N
M*"1D871A*2`K(#([("`O+R!4:&4@,B!E>'1R82!B>71E<R!A<F4@9F]R(')D
M;&5N9W1H"@H@("`@("`@("1R9&%T82`]("1T:&ES+3YR9&%T82@D<&%C:V5T
M+"`D;V9F<V5T*3L*("`@("`@("`D9&%T82`N/2!P86-K*"=N)RP@<W1R;&5N
M*"1R9&%T82DI.PH@("`@("`@("1D871A("X]("1R9&%T83L*"B`@("`@("`@
M<F5T=7)N*"1D871A*3L*("`@('T*("`@("\J('U]?2`J+PI]"B\J('U]?2`J
M+PHO*B!624T@<V5T=&EN9W,@>WM["B`J($QO8V%L('9A<FEA8FQE<SH*("H@
M=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J('-O9G0M<W1O
M<"UW:61T:#H@-`H@*B!C(&EN9&5N="!O;@H@*B!%;F0Z"B`J('9I;38P,#H@
M<W<]-"!T<STT('-T<STT(&-I;F1E;G0@9F1M/6UA<FME<B!E=`H@*B!V:6T\
M-C`P.B!S=STT('1S/30*("H@?7U]("HO"C\^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+T1.4R]1=65S=&EO;BYP:'``````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4R,3$`,3`T,3<S-C,P
M,#8`,#(Q,#,Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J"B`J("!,:6-E;G-E($EN9F]R;6%T:6]N.@H@*@H@
M*B`@("!.971?1$Y3.B`@02!R97-O;'9E<B!L:6)R87)Y(&9O<B!02%`*("H@
M("`@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@17)I8R!+:6QF;VEL(&5R:6-`
M>7!A<W,N;F5T"B`J"B`J("`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W
M87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(*("H@("`@;6]D
M:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'96YE
M<F%L(%!U8FQI8PH@*B`@("!,:6-E;G-E(&%S('!U8FQI<VAE9"!B>2!T:&4@
M1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N.R!E:71H97(*("H@("`@=F5R<VEO
M;B`R+C$@;V8@=&AE($QI8V5N<V4L(&]R("AA="!Y;W5R(&]P=&EO;BD@86YY
M(&QA=&5R('9E<G-I;VXN"B`J"B`J("`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T
M<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@
M*B`@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T
M:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@*B`@("!-15)#2$%.5$%"24Q)5%D@
M;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4N("!3964@=&AE
M($=.50H@*B`@("!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@
M;6]R92!D971A:6QS+@H@*@H@*B`@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV
M960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`J
M("`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@
M=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("H@("`@1F]U;F1A=&EO;BP@
M26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP@34$@
M(#`R,3$Q+3$S,#<@(%5300H@*B\*"B\J($YE=%]$3E-?475E<W1I;VX@;V)J
M96-T(&1E9FEN:71I;VX@>WM[("HO"B\J*@H@*B!"=6EL9',@;W(@<&%R<V5S
M('1H92!154535$E/3B!S96-T:6]N(&]F(&$@1$Y3('!A8VME=`H@*@H@*B!"
M=6EL9',@;W(@<&%R<V5S('1H92!154535$E/3B!S96-T:6]N(&]F(&$@1$Y3
M('!A8VME=`H@*@H@*B!`<&%C:V%G92!.971?1$Y3"B`J+PIC;&%S<R!.971?
M1$Y37U%U97-T:6]N"GL*("`@("\J(&-L87-S('9A<FEA8FQE(&1E9FEN:71I
M;VYS('M[>R`J+PH@("`@=F%R("1Q;F%M92`]($Y53$P["B`@("!V87(@)'%T
M>7!E(#T@3E5,3#L*("`@('9A<B`D<6-L87-S(#T@3E5,3#L*"B`@("`O*B!]
M?7T@*B\*("`@("\J(&-L87-S(&-O;G-T<G5C=&]R($YE=%]$3E-?475E<W1I
M;VXH)'%N86UE+"`D<71Y<&4L("1Q8VQA<W,I('M[>R`J+PH@("`@9G5N8W1I
M;VX@3F5T7T1.4U]1=65S=&EO;B@D<6YA;64L("1Q='EP92P@)'%C;&%S<RD*
M("`@('L*("`@("`@("!I9B`H("`@:7-?;G5L;"A.971?1$Y3.CIT>7!E<V)Y
M;F%M92@D<71Y<&4I*0H@("`@("`@("`@("`@("`@)B8@("%I<U]N=6QL*$YE
M=%]$3E,Z.F-L87-S97-B>6YA;64H)'%T>7!E*2D*("`@("`@("`@("`@("`@
M("8F(&ES7VYU;&PH3F5T7T1.4SHZ8VQA<W-E<V)Y;F%M92@D<6-L87-S*2D*
M("`@("`@("`@("`@("`@("8F("`A:7-?;G5L;"A.971?1$Y3.CIT>7!E<V)Y
M;F%M92@D<6-L87-S*2DI('L*"B`@("`@("`@("`@("1T(#T@)'%T>7!E.PH@
M("`@("`@("`@("`D<71Y<&4@/2`D<6-L87-S.PH@("`@("`@("`@("`D<6-L
M87-S(#T@)'0["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^<6YA;64@/2`D
M<6YA;64["B`@("`@("`@)'1H:7,M/G%T>7!E(#T@)'%T>7!E.PH@("`@("`@
M("1T:&ES+3YQ8VQA<W,@/2`D<6-L87-S.PH@("`@?0H*("`@("\J('U]?2`J
M+PH@("`@+RH@3F5T7T1.4U]1=65S=&EO;CHZ9&ES<&QA>2@I('M[>RHO"B`@
M("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("!E8VAO("1T:&ES
M+3YS=')I;F<H*2`N(")<;B(["B`@("!]"@H@("`@+RI]?7TJ+PH@("`@+RH@
M3F5T7T1.4U]1=65S=&EO;CHZ<W1R:6YG*"D@>WM[*B\*("`@(&9U;F-T:6]N
M('-T<FEN9R@I"B`@("!["B`@("`@("`@<F5T=7)N*"1T:&ES+3YQ;F%M92`N
M("(N7'0B("X@)'1H:7,M/G%C;&%S<R`N(")<="(@+B`D=&AI<RT^<71Y<&4I
M.PH@("`@?0H*("`@("\J?7U]*B\*("`@("\J($YE=%]$3E-?475E<W1I;VXZ
M.F1A=&$H)B1P86-K970L("1O9F9S970I('M[>RHO"B`@("!F=6YC=&EO;B!D
M871A*"1P86-K970L("1O9F9S970I"B`@("!["B`@("`@("`@)&1A=&$@/2`D
M<&%C:V5T+3YD;E]C;VUP*"1T:&ES+3YQ;F%M92P@)&]F9G-E="D["B`@("`@
M("`@)&1A=&$@+CT@<&%C:R@G;B<L($YE=%]$3E,Z.G1Y<&5S8GEN86UE*'-T
M<G1O=7!P97(H)'1H:7,M/G%T>7!E*2DI.PH@("`@("`@("1D871A("X]('!A
M8VLH)VXG+"!.971?1$Y3.CIC;&%S<V5S8GEN86UE*'-T<G1O=7!P97(H)'1H
M:7,M/G%C;&%S<RDI*3L*("`@("`@("!R971U<FXH)&1A=&$I.PH@("`@?0H*
M("`@("\J?7U]*B\*?0HO*B!]?7T@*B\*+RH@5DE-('-E='1I;F=S>WM["B`J
M($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M
M;V9F<V5T.B`T"B`J('-O9G0M<W1O<"UW:61T:#H@-`H@*B!C(&EN9&5N="!O
M;@H@*B!%;F0Z"B`J('9I;38P,#H@<W<]-"!T<STT('-T<STT(&-I;F1E;G0@
M9F1M/6UA<FME<B!E=`H@*B!V:6T\-C`P.B!S=STT('1S/30*("H@?7U]("HO
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B].970O1$Y3+U)E<V]L=F5R+G!H<```````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#$R-3<Q-@`Q,#0Q-S,V,S`P-@`P,C$P-#``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH*
M("H@($QI8V5N<V4@26YF;W)M871I;VXZ"B`J"B`J("`@($YE=%]$3E,Z("!!
M(')E<V]L=F5R(&QI8G)A<GD@9F]R(%!(4`H@*B`@("!#;W!Y<FEG:'0@*&,I
M(#(P,#(M,C`P,R!%<FEC($MI;&9O:6P@97)I8T!Y<&%S<RYN970*("H*("H@
M("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D
M:7-T<FEB=71E(&ET(&%N9"]O<@H@*B`@("!M;V1I9GD@:70@=6YD97(@=&AE
M('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`J("`@
M($QI8V5N<V4@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O
M=6YD871I;VX[(&5I=&AE<@H@*B`@("!V97)S:6]N(#(N,2!O9B!T:&4@3&EC
M96YS92P@;W(@*&%T('EO=7(@;W!T:6]N*2!A;GD@;&%T97(@=F5R<VEO;BX*
M("H*("H@("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H
M;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`J("`@(&)U="!7251(3U54
M($%.62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A
M;G1Y(&]F"B`J("`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!
M(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`J("`@($QE<W-E
M<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"B`J
M"B`J("`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("H@("`@3&EC96YS92!A;&]N
M9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E
M92!3;V9T=V%R90H@*B`@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@
M4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!
M"B`J+PH*"B\J($YE=%]$3E-?4F5S;VQV97(@;V)J96-T(&1E9FEN:71I;VX@
M>WM[("HO"B\J*@H@*B!!($1.4R!297-O;'9E<B!L:6)R87)Y"B`J"B`J(%)E
M<V]L=F5R(&QI8G)A<GDN("!"=6EL9',@82!$3E,@<75E<GD@<&%C:V5T+"!S
M96YD<R`@=&AE('!A8VME="!T;R!T:&4*("H@<V5R=F5R(&%N9"!P87)S97,@
M=&AE(')E<&]N<V4N"B`J"B`J($!P86-K86=E($YE=%]$3E,*("HO"F-L87-S
M($YE=%]$3E-?4F5S;VQV97(*>PH@("`@+RH@8VQA<W,@=F%R:6%B;&4@9&5F
M:6YI=&EO;G,@>WM[("HO"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&%L
M;"!N86UE<V5R=F5R<R!T;R!Q=65R>0H@("`@("H*("`@("`J($%N(&%R<F%Y
M(&]F(&%L;"!N86UE<V5R=F5R<R!T;R!Q=65R>0H@("`@("H*("`@("`J($!V
M87(@87)R87D@("`D;F%M97-E<G9E<G,*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@('9A<B`D;F%M97-E<G9E<G,["B`@("`O*BH*("`@("`J
M(%1H92!51%`@<&]R="!T;R!U<V4@9F]R('1H92!Q=65R>2`H9&5F875L="`]
M(#4S*0H@("`@("H*("`@("`J(%1H92!51%`@<&]R="!T;R!U<V4@9F]R('1H
M92!Q=65R>2`H9&5F875L="`](#4S*0H@("`@("H*("`@("`J($!V87(@:6YT
M96=E<B`D<&]R=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M=F%R("1P;W)T.PH@("`@+RHJ"B`@("`@*B!4:&4@9&]M86EN(&EN('=H:6-H
M('1H92!R97-O;'9E<B!C;&EE;G0@:&]S="!R97-I9&5S+@H@("`@("H*("`@
M("`J(%1H92!D;VUA:6X@:6X@=VAI8V@@=&AE(')E<V]L=F5R(&-L:65N="!H
M;W-T(')E<VED97,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<@)&1O;6%I
M;@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@=F%R("1D;VUA
M:6X["B`@("`O*BH*("`@("`J(%1H92!S96%R8VAL:7-T('1O(&%P<&QY('1O
M('5N<75A;&EF:65D(&AO<W1S"B`@("`@*@H@("`@("H@06X@87)R87D@;V8@
M<W1R:6YG<R!C;VYT86EN9R!D;VUA:6YS('1O(&%P<&QY('1O('5N<75A;&EF
M:65D(&AO<W1S"B`@("`@*B!P87-S960@=&\@=&AE(')E<V]L=F5R+@H@("`@
M("H*("`@("`J($!V87(@87)R87D@)'-E87)C:&QI<W0*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D<V5A<F-H;&ES=#L*("`@("\J
M*@H@("`@("H@5&AE(&YU;6)E<B!O9B!S96-O;F1S(&)E='=E96X@<F5T<F%N
M<VUI<W-I;VX@;V8@=6YA<W=E<F5D('%U97)I97,*("`@("`J"B`@("`@*B!4
M:&4@;G5M8F5R(&]F('-E8V]N9',@8F5T=V5E;B!R971R86YS;6ES<VEO;B!O
M9B!U;F%S=V5R960@<75E<FEE<PH@("`@("H*("`@("`J($!V87(@:6YT96=E
M<B`D<F5T<F%N<PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M=F%R("1R971R86YS.PH@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F('1I
M;65S('5N86YS=V5R960@<F5Q=65S=',@<VAO=6QD(&)E(')E=')I960*("`@
M("`J"B`@("`@*B!4:&4@;G5M8F5R(&]F('1I;65S('5N86YS=V5R960@<F5Q
M=65S=',@<VAO=6QD(&)E(')E=')I960*("`@("`J"B`@("`@*B!`=F%R(&EN
M=&5G97(@)')E=')Y"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!V87(@)')E=')Y.PH@("`@+RHJ"B`@("`@*B!7:&5T:&5R(&]R(&YO="!T
M;R!U<V4@5$-0("A6:7)T=6%L($-I<F-U:71S*2!I;G-T96%D(&]F(%5$4`H@
M("`@("H*("`@("`J($EF('-E="!T;R`P+"!51%`@=VEL;"!B92!U<V5D('5N
M;&5S<R!40U`@:7,@<F5Q=6ER960N("!40U`@:7,*("`@("`J(')E<75I<F5D
M(&9O<B!Q=65S=&EO;G,@;W(@<F5S<&]N<V5S(&=R96%T97(@=&AA;B`U,3(@
M8GET97,N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N("1U<V5V8PH@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@=F%R("1U<V5V8SL*("`@
M("\J*@H@("`@("H@56YK;F]W;@H@("`@("HO"B`@("!V87(@)'-T87EO<&5N
M.PH@("`@+RHJ"B`@("`@*B!)9VYO<F4@5$,@*'1R=6YC871E9"D@8FET"B`@
M("`@*@H@("`@("H@268@=&AE('-E<G9E<B!R97-P;VYD<R!W:71H('1H92!4
M0R!B:70@<V5T(&]N(&$@<F5S<&]N<V4L(&%N9"`D:6=N=&,*("`@("`J(&ES
M('-E="!T;R`P+"!T:&4@<F5S;VQV97(@=VEL;"!A=71O;6%T:6-A;&QY(')E
M=')A;G-M:70@=&AE(')E<75E<W0*("`@("`J('5S:6YG('9I<G1U86P@8VER
M8W5I=',@*%1#4"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!V87(@8F]O;&5A;B`D:6=N=&,*("`@("`J+PH@("`@=F%R("1I9VYT
M8SL*("`@("\J*@H@("`@("H@4F5C=7)S:6]N($1E<VER960*("`@("`J"B`@
M("`@*B!3971S('1H92!V86QU92!O9B!T:&4@4D0@*')E8W5R<VEO;B!D97-I
M<F5D*2!B:70@:6X@=&AE(&AE861E<BX@268*("`@("`J('1H92!21"!B:70@
M:7,@<V5T('1O(#`L('1H92!S97)V97(@=VEL;"!N;W0@<&5R9F]R;2!R96-U
M<G-I;VX@;VX@=&AE"B`@("`@*B!R97%U97-T+@H@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;B`D<F5C=7)S90H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@=F%R("1R96-U<G-E.PH@("`@+RHJ"B`@("`@*B!5;FMN;W=N
M"B`@("`@*B\*("`@('9A<B`D9&5F;F%M97,["B`@("`O*BH*("`@("`J(%5N
M:VYO=VX*("`@("`J+PH@("`@=F%R("1D;G-R8V@["B`@("`O*BH*("`@("`J
M($-O;G1A:6YS('1H92!V86QU92!O9B!T:&4@;&%S="!E<G)O<B!R971U<FYE
M9"!B>2!T:&4@<F5S;VQV97(N"B`@("`@*@H@("`@("H@0V]N=&%I;G,@=&AE
M('9A;'5E(&]F('1H92!L87-T(&5R<F]R(')E='5R;F5D(&)Y('1H92!R97-O
M;'9E<BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9R`D97)R;W)S=')I;F<*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D97)R;W)S
M=')I;F<["B`@("`O*BH*("`@("`J(%1H92!O<FEG:6X@;V8@=&AE('!A8VME
M="X*("`@("`J"B`@("`@*B!4:&ES(&-O;G1A:6YS(&$@<W1R:6YG(&-O;G1A
M:6YI;F<@=&AE($E0(&%D9')E<W,@;V8@=&AE(&YA;64@<V5R=F5R"B`@("`@
M*B!F<F]M('=H:6-H('1H92!A;G-W97(@=V%S(&=I=F5N+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG("1A;G-W97)F<F]M"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!V87(@)&%N<W=E<F9R;VT["B`@("`O*BH*("`@
M("`J(%1H92!S:7IE(&]F('1H92!A;G-W97(@<&%C:V5T+@H@("`@("H*("`@
M("`J(%1H:7,@8V]N=&%I;G,@82!I;G1E9V5R(&-O;G1A:6YI;F<@=&AE('-I
M>F4@;V8@=&AE($1.4R!P86-K970@=&AE"B`@("`@*B!S97)V97(@<F5S<&]N
M9&5D('=I=&@N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<@)&%N<W=E<G-I
M>F4*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D86YS
M=V5R<VEZ93L*("`@("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!S96-O;F1S
M(&%F=&5R('=H:6-H(&$@5$-0(&-O;FYE=&EO;B!S:&]U;&0@=&EM96]U=`H@
M("`@("H*("`@("`J($!V87(@:6YT96=E<B`D=&-P7W1I;65O=70*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D=&-P7W1I;65O=70[
M"B`@("`O*BH*("`@("`J(%1H92!L;V-A=&EO;B!O9B!T:&4@<WES=&5M(')E
M<V]L=BYC;VYF(&9I;&4N"B`@("`@*@H@("`@("H@5&AE(&QO8V%T:6]N(&]F
M('1H92!S>7-T96T@<F5S;VQV+F-O;F8@9FEL92X*("`@("`J(`H@("`@("H@
M0'9A<B!S=')I;F<@)')E<V]L=E]C;VYF"B`@("`@*B\*("`@('9A<B`D<F5S
M;VQV7V-O;F8@/2`G+V5T8R]R97-O;'8N8V]N9B<["B`@("`O*BH*("`@("`J
M(%1H92!N86UE(&]F('1H92!U<V5R(&1E9FEN960@<F5S;VQV+F-O;F8*("`@
M("`J"B`@("`@*B!4:&4@<F5S;VQV97(@=VEL;"!A='1E;7!T('1O(&QO;VL@
M:6X@8F]T:"!T:&4@8W5R<F5N="!D:7)E8W1O<GD@87,*("`@("`J('=E;&P@
M87,@=&AE('5S97(G<R!H;VUE(&1I<F5C=&]R>2!F;W(@82!U<V5R(&1E9FEN
M960@<F5S;VQV97(*("`@("`J(&-O;F9I9W5R871I;VX@9FEL90H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG("1D;W1F:6QE"B`@("`@*B!`<V5E($YE=%]$
M3E-?4F5S;VQV97(Z.B1C;VYF<&%T:`H@("`@("HO"B`@("!V87(@)&1O=&9I
M;&4@/2`G+G)E<V]L=BYC;VYF)SL*("`@("\J*@H@("`@("H@02!A<G)A>2!O
M9B!D:7)E8W1O<FEE<R!T;R!S96%R8V@@9F]R('1H92!U<V5R)W,@<F5S;VQV
M97(@8V]N9FEG"B`@("`@*@H@("`@("H@02!A<G)A>2!O9B!D:7)E8W1O<FEE
M<R!T;R!S96%R8V@@9F]R('1H92!U<V5R)W,@<F5S;VQV97(@8V]N9FEG"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<@)&-O;F9P871H"B`@("`@*B!`<V5E
M($YE=%]$3E-?4F5S;VQV97(Z.B1D;W1F:6QE"B`@("`@*B\*("`@('9A<B`D
M8V]N9G!A=&@["B`@("`O*BH*("`@("`J(&1E8G5G9VEN9R!F;&%G"B`@("`@
M*@H@("`@("H@268@<V5T('1O(%12544@*&YO;BUZ97)O*2P@9&5B=6=G:6YG
M(&-O9&4@=VEL;"!B92!D:7-P;&%Y960@87,@=&AE"B`@("`@*B!R97-O;'9E
M<B!M86ME<R!T:&4@<F5Q=65S="X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X@)&1E8G5G.PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M=F%R("1D96)U9SL*("`@("\J*@H@("`@("H@=7-E('1H92`H8W5R<F5N=&QY
M*2!E>'!E<FEM96YT86P@4$A0('-O8VME="!L:6)R87)Y"B`@("`@*@H@("`@
M("H@268@<V5T('1O(%12544@*&YO;BUZ97)O*2P@=&AE(%)E<V]L=F5R('=I
M;&P@871T96UP="!T;R!U<V4@=&AE"B`@("`@*B!M=6-H(&UO<F4@969F96-I
M96YT(%!(4"!S;V-K971S(&5X=&5N<VEO;B`H:68@879A:6QA8FQE*2X*("`@
M("`J"B`@("`@*B!`=F%R(&)O;VQE86X@)'5S945N:&%N8V5D4V]C:V5T<SL*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D=7-E16YH
M86YC9613;V-K971S(#T@,3L*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@
M<V]C:V5T<R!C;VYN96-T960@=&\@82!N86UE('-E<G9E<G,*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y("1S;V-K971S"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1S;V-K971S.PH@("`@+RHJ"B`@("`@*B!A
M>&9R('1C<"!S;V-K970*("`@("`J"B`@("`@*B!5<V5D('1O('-T;W)E(&$@
M4$A0('-O8VME="!R97-O=7)C92!F;W(@82!C;VYN96-T:6]N('1O(&$@<V5R
M=F5R"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C92`D7V%X9G)?<V]C:SL*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]A>&9R
M7W-O8VL["B`@("`O*BH*("`@("`J(&%X9G(@<F5S;W5R8V4@<F5C;W)D(&QS
M:70*("`@("`J"B`@("`@*B!5<V5D('1O('-T;W)E(&$@<F5S;W5R8V4@<F5C
M;W)D(&QI<W0@9G)O;2!A('IO;F4@=')A;G-F97(*("`@("`J"B`@("`@*B!`
M=F%R(')E<V]U<F-E("1?87AF<E]R<CL*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]A>&9R7W)R.PH@("`@+RHJ"B`@("`@*B!A
M>&9R('-O82!C;W5N=`H@("`@("H*("`@("`J(%5S960@=&\@<W1O<F4@=&AE
M(&YU;6)E<B!O9B!S;V$@<F5C;W)D<R!R96-E:79E9"!F<F]M(&$@>F]N92!T
M<F%N<V9E<@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4@)%]A>&9R7W-O
M85]C;W5N=#L*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]A>&9R7W-O85]C;W5N=#L*"@H@("`@+RH@?7U]("HO"B`@("`O*B!C
M;&%S<R!C;VYS=')U8W1O<B`M($YE=%]$3E-?4F5S;VQV97(H*2![>WL@*B\*
M("`@("\J*@H@("`@("H@26YI=&EA;&EZ97,@=&AE(%)E<V]L=F5R($]B:F5C
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!.971?1$Y37U)E<V]L=F5R*"D*("`@
M('L*("`@("`@("`D9&5F875L="`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M)VYA;65S97)V97)S)R`]/B!A<G)A>2@I+`H@("`@("`@("`@("`@("`@)W!O
M<G0G("`@(#T^("<U,R<L"B`@("`@("`@("`@("`@("`G9&]M86EN)R`@/3X@
M)R<L"B`@("`@("`@("`@("`@("`G<V5A<F-H;&ES="<@(#T^(&%R<F%Y*"DL
M"B`@("`@("`@("`@("`@("`G<F5T<F%N<R<@/3X@-2P*("`@("`@("`@("`@
M("`@("=R971R>2<@("`]/B`T+`H@("`@("`@("`@("`@("`@)W5S979C)R`@
M(#T^(#`L"B`@("`@("`@("`@("`@("`G<W1A>6]P96XG("`]/B`P+`H@("`@
M("`@("`@("`@("`@)VEG;G1C)R`@(#T^(#`L"B`@("`@("`@("`@("`@("`G
M<F5C=7)S92<@/3X@,2P*("`@("`@("`@("`@("`@("=D969N86UE<R<@(#T^
M(#$L"B`@("`@("`@("`@("`@("`G9&YS<F-H)R`@/3X@,2P*("`@("`@("`@
M("`@("`@("=D96)U9R<@("`]/B`P+`H@("`@("`@("`@("`@("`@)V5R<F]R
M<W1R:6YG)R`]/B`G=6YK;F]W;B!E<G)O<B!O<B!N;R!E<G)O<B<L"B`@("`@
M("`@("`@("`@("`G86YS=V5R9G)O;2<@("`@/3X@)R<L"B`@("`@("`@("`@
M("`@("`G86YS=V5R<VEZ92<@("`@/3X@,"P*("`@("`@("`@("`@("`@("=T
M8W!?=&EM96]U="<@("`]/B`Q,C`*("`@("`@("`@("`@("`@("D["B`@("`@
M("`@9F]R96%C:"`H)&1E9F%U;'0@87,@)&L@/3X@)'8I('L*("`@("`@("`@
M("`@)'1H:7,M/GLD:WT@/2`D=CL*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/F-O;F9P871H6S!=(#T@9V5T96YV*"=(3TU%)RD["B`@("`@("`@)'1H:7,M
M/F-O;F9P871H6S%=(#T@)RXG.PH@("`@("`@("1T:&ES+3YR97-?:6YI="@I
M.PH@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]297-O;'9E
M<CHZ<F5S7VEN:70H*2![>WL@*B\*("`@("\J*@H@("`@("H@26YI=&%L:7IE
M<R!T:&4@<F5S;VQV97(@;&EB<F%R>0H@("`@("H*("`@("`J(')E<U]I;FET
M*"D@<V5A<F-H97,@9F]R(')E<V]L=F5R(&QI8G)A<GD@8V]N9FEG=7)A=&EO
M;B!F:6QE<R`@86X*("`@("`J(&EN:71I86QI>F5S('1H92!V87)I;W5S('!R
M;W!E<G1I97,@;V8@=&AE(')E<V]L=F5R(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<V5E($YE=%]$3E-?4F5S;VQV97(Z.B1R97-O;'9?8V]N9BP@3F5T7T1.
M4U]297-O;'9E<CHZ)&1O=&9I;&4L"B`@("`@*B`@("`@($YE=%]$3E-?4F5S
M;VQV97(Z.B1C;VYF<&%T:"P@3F5T7T1.4U]297-O;'9E<CHZ)'-E87)C:&QI
M<W0L"B`@("`@*B`@("`@($YE=%]$3E-?4F5S;VQV97(Z.B1D;VUA:6XL($YE
M=%]$3E-?4F5S;VQV97(Z.B1N86UE<V5R=F5R<PH@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S7VEN:70H*0H@("`@>PH@
M("`@("`@("1E<G(@/2!E<G)O<E]R97!O<G1I;F<H,"D["B`@("`@("`@:68@
M*&9I;&5?97AI<W1S*"1T:&ES+3YR97-O;'9?8V]N9BD@)B8@:7-?<F5A9&%B
M;&4H)'1H:7,M/G)E<V]L=E]C;VYF*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<F5A9%]C;VYF:6<H)'1H:7,M/G)E<V]L=E]C;VYF*3L*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VYF<&%T:"!A<R`D9&ER*2!["B`@
M("`@("`@("`@("1F:6QE(#T@(B1D:7(O(B`N("1T:&ES+3YD;W1F:6QE.PH@
M("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)&9I;&4I("8F(&ES7W)E861A
M8FQE*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E861?8V]N
M9FEG*"1F:6QE*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/G)E861?96YV*"D["@H@("`@("`@(&EF("@A<W1R;&5N*"1T:&ES
M+3YD;VUA:6XI("8F('-T<FQE;B@D=&AI<RT^<V5A<F-H;&ES="DI('L*("`@
M("`@("`@("`@)'1H:7,M/F1E9F%U;'1[)V1O;6%I;B=](#T@)'1H:7,M/F1E
M9F%U;'1[)W-E87)C:&QI<W0G?5LP73L*("`@("`@("!](&5L<V4@:68@*"$@
M<W1R;&5N*"1T:&ES+3YS96%R8VAL:7-T*2`F)B!S=')L96XH)'1H:7,M/F1O
M;6%I;BDI('L*("`@("`@("`@("`@)'1H:7,M/G-E87)C:&QI<W0@/2!A<G)A
M>2@D=&AI<RT^9&]M86EN*3L*("`@("`@("!]"B`@("`@("`@97)R;W)?<F5P
M;W)T:6YG*"1E<G(I.PH@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T
M7T1.4U]297-O;'9E<CHZ<F5A9%]C;VYF:6<@>WM[("HO"B`@("`O*BH*("`@
M("`J(%)E861S(&%N9"!P87)S97,@82!R97-O;'9E<B!C;VYF:6=U<F%T:6]N
M(&9I;&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE(%1H92!N
M86UE(&]F('1H92!F:6QE('1O(&]P96X@86YD('!A<G-E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E861?8V]N9FEG*"1F:6QE*0H@("`@>PH@("`@("`@(&EF
M("@A("@D9B`](&9O<&5N*"1F:6QE+"`G<B<I*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^97)R;W(@/2`B8V%N)W0@;W!E;B`D9FEL92(["B`@("`@("`@?0H*
M("`@("`@("!W:&EL92`H(2!F96]F*"1F*2D@>PH@("`@("`@("`@("`D;&EN
M92`](&-H;W`H9F=E=',H)&8L(#$P,C0P*2D["B`@("`@("`@("`@("1L:6YE
M(#T@97)E9U]R97!L86-E*"<H+BHI6SLC72XJ)RP@)UQ<,2<L("1L:6YE*3L*
M("`@("`@("`@("`@:68@*&5R96<H(EY;(%QT72HD(BP@)&QI;F4L("1R96=S
M*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@97)E9R@B7EL@7'1=*BA;7B!<=%TK*5L@7'1=*RA;7B!<
M=%TK*2(L("1L:6YE+"`D<F5G<RD["B`@("`@("`@("`@("1O<'1I;VX@/2`D
M<F5G<ULQ73L*("`@("`@("`@("`@)'9A;'5E(#T@)')E9W-;,ET["@H@("`@
M("`@("`@("!S=VET8V@@*"1O<'1I;VXI('L*("`@("`@("`@("`@("`@(&-A
M<V4@)V1O;6%I;B<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1O;6%I
M;B`]("1R96=S6S)=.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`G<V5A<F-H)SH*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5A<F-H;&ES=%MC;W5N="@D=&AI<RT^<V5A<F-H;&ES="E=
M(#T@)')E9W-;,ET["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E("=N86UE<V5R=F5R)SH*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("AS<&QI="@G("<L("1R96=S6S)=*2!A<R`D;G,I"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YN86UE<V5R=F5R<UMC;W5N
M="@D=&AI<RT^;F%M97-E<G9E<G,I72`]("1N<SL*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!F
M8VQO<V4H)&8I.PH@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.
M4U]297-O;'9E<CHZ<F5A9%]E;G8H*2![>WL@*B\*("`@("\J*@H@("`@("H@
M17AA;6EN97,@=&AE(&5N=FER;VYM96YT(&9O<B!R97-O;'9E<B!C;VYF:6<@
M:6YF;W)M871I;VX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9%]E;G8H*0H@
M("`@>PH@("`@("`@(&EF("AG971E;G8H)U)%4U].04U%4T525D524R<I*2![
M"B`@("`@("`@("`@("1T:&ES+3YN86UE<V5R=F5R<R`]('-P;&ET*"<@)RP@
M9V5T96YV*"=215-?3D%-15-%4E9%4E,G*2D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H9V5T96YV*"=215-?4T5!4D-(3$E35"<I*2!["B`@("`@("`@("`@
M("1T:&ES+3YS96%R8VAL:7-T(#T@<W!L:70H)R`G+"!G971E;G8H)U)%4U]3
M14%20TA,25-4)RDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&=E=&5N=B@G
M3$]#04Q$3TU!24XG*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&]M86EN(#T@
M9V5T96YV*"=,3T-!3$1/34%)3B<I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&=E=&5N=B@G4D537T]05$E/3E,G*2D@>PH@("`@("`@("`@("`D96YV(#T@
M<W!L:70H)R`G+"!G971E;G8H)U)%4U]/4%1)3TY3)RDI.PH@("`@("`@("`@
M("!F;W)E86-H("@D96YV(&%S("1O<'0I('L*("`@("`@("`@("`@("`@(&QI
M<W0H)&YA;64L("1V86PI(#T@<W!L:70H)SHG+"`D;W!T*3L*("`@("`@("`@
M("`@("`@(&EF("@D=F%L(#T]("<G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A;"`](#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=&AI<RT^>R1N86UE?2`]("1V86P["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)E<V]L=F5R
M.CIS=')I;F<H*2![>WL@*B\*("`@("\J*@H@("`@("H@0G5I;&1S(&$@<W1R
M:6YG(&-O;G1A:6YI;F<@=&AE(&-U<G)E;G0@<W1A=&4@;V8@=&AE(')E<V]L
M=F5R"B`@("`@*@H@("`@("H@0G5I;&1S(&9O<FUA='1E9"!S=')I;F<@8V]N
M=&%I;FEN9R!T:&4@<W1A=&4@;V8@=&AE(')E<V]L=F5R(&QI8G)A<GD@<W5I
M=&5D"B`@("`@*B!F;W(@9&ES<&QA>2X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S=')I;F<H*0H@("`@>PH@
M("`@("`@("1S=&%T92`]("([.R!.971?1$Y37U)E<V]L=F5R('-T871E.EQN
M(CL*("`@("`@("`D<W1A=&4@+CT@)SL[("!D;VUA:6X@("`@("`@/2`G("X@
M)'1H:7,M/F1O;6%I;B`N(")<;B(["B`@("`@("`@)'-T871E("X]("<[.R`@
M<V5A<F-H;&ES="`@(#T@)R`N(&EM<&QO9&4H)R`G+"`D=&AI<RT^<V5A<F-H
M;&ES="D@+B`B7&XB.PH@("`@("`@("1S=&%T92`N/2`G.SL@(&YA;65S97)V
M97)S("`]("<@+B!I;7!L;V1E*"<@)RP@)'1H:7,M/FYA;65S97)V97)S*2`N
M(")<;B(["B`@("`@("`@)'-T871E("X]("<[.R`@<&]R="`@("`@("`@(#T@
M)R`N("1T:&ES+3YP;W)T("X@(EQN(CL*("`@("`@("`D<W1A=&4@+CT@)SL[
M("!T8W!?=&EM96]U="`@/2`G.PH@("`@("`@("1S=&%T92`N/2`H)'1H:7,M
M/G1C<%]T:6UE;W5T(#\@)'1H:7,M/G1C<%]T:6UE;W5T(#H@)VEN9&5F:6YI
M=&4G*2`N(")<;B(["B`@("`@("`@)'-T871E("X]("<[.R`@<F5T<F%N<R`@
M/2`G("X@)'1H:7,M/G)E=')A;G,@+B`G("`G.PH@("`@("`@("1S=&%T92`N
M/2`G<F5T<GD@("`@/2`G("X@)'1H:7,M/G)E=')Y("X@(EQN(CL*("`@("`@
M("`D<W1A=&4@+CT@)SL[("!U<V5V8R`@("`]("<@+B`D=&AI<RT^=7-E=F,@
M+B`G("`G.PH@("`@("`@("1S=&%T92`N/2`G<W1A>6]P96X@/2`G("X@)'1H
M:7,M/G-T87EO<&5N("X@)R`@("`G.PH@("`@("`@("1S=&%T92`N/2`G:6=N
M=&,@/2`G("X@)'1H:7,M/FEG;G1C("X@(EQN(CL*("`@("`@("`D<W1A=&4@
M+CT@)SL[("!D969N86UE<R`]("<@+B`D=&AI<RT^9&5F;F%M97,@+B`G("`G
M.PH@("`@("`@("1S=&%T92`N/2`G9&YS<F-H("`@/2`G("X@)'1H:7,M/F1N
M<W)C:"`N(")<;B(["B`@("`@("`@)'-T871E("X]("<[.R`@<F5C=7)S92`@
M/2`G("X@)'1H:7,M/G)E8W5R<V4@+B`G("`G.PH@("`@("`@("1S=&%T92`N
M/2`G9&5B=6<@("`@/2`G("X@)'1H:7,M/F1E8G5G("X@(EQN(CL*("`@("`@
M("!R971U<FXH)'-T871E*3L*("`@('T*"B`@("`O*B!]?7T@*B\*("`@("\J
M($YE=%]$3E-?4F5S;VQV97(Z.FYE>'1I9"@I('M[>R`J+PH@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!N97AT(')E<75E<W0@260@=&\@8F4@=7-E9"!F
M;W(@=&AE($1.4R!P86-K970@:&5A9&5R"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YE>'1I9"@I"B`@("!["B`@("`@("`@9VQO8F%L("1?3F5T7T1.4U]P86-K
M971?:60["@H@("`@("`@(')E='5R;B@D7TYE=%]$3E-?<&%C:V5T7VED*RLI
M.PH@("`@?0H@("`@+RH@?7U]("HO"B`@("`O*B!N;W0@8V]M<&QE=&5D("T@
M3F5T7T1.4U]297-O;'9E<CHZ;F%M97-E<G9E<G,H*2![>WL@*B\*("`@("\J
M*@H@("`@("H@56YK;F]W;B`M(&YO="!P;W)T960@>65T"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&YA;65S97)V97)S*"1N<V$I"B`@("!["B`@("`@("`@)&1E
M9G)E<R`](&YE=R!.971?1$Y37U)E<V]L=F5R*"D["@H@("`@("`@(&EF("AI
M<U]A<G)A>2@D;G,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1N<V$@87,@
M)&YS*2!["B`@("`@("`@("`@("`@("!I9B`H97)E9R@G7ELP+3E=*RA<+ELP
M+3E=*RE[,"PS?20G+"`D;G,L("1R96=S*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1N97=N<UMC;W5N="@D;F5W;G,I72`]("1N<SL*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+RH@"B`@("`@("`@
M("`@("`@("`@("`@("H@5&AI<R!S=&EL;"!N965D<R!T;R!B92!P;W)T960*
M("`@("`@("`@("`@("`@("`@("`@*@H@("`@("`@("`@("`@("`@("`@("!I
M9B`H)&YS("%^("]<+B\I('L*("`@("`@("`@("`@("`@("`@("`@:68@*&1E
M9FEN960@)&1E9G)E<RT^<V5A<F-H;&ES="D@>PH@("`@("`@("`@("`@("`@
M("`@("!`;F%M97,@/2!M87`@>R`D;G,@+B`B+B(@+B`D7R!]"B`@("`@("`@
M("`@("`@("`@("`@("1D969R97,M/G-E87)C:&QI<W0["B`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@96QS:68@*&1E9FEN
M960@)&1E9G)E<RT^9&]M86EN*2!["B`@("`@("`@("`@("`@("`@("`@($!N
M86UE<R`]("@D;G,@+B`B+B(@+B`D9&5F<F5S+3YD;VUA:6XI.PH@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@($!N
M86UE<R`]("@D;G,I.PH@("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("!M>2`D<&%C:V5T(#T@)&1E9G)E<RT^<V5A<F-H*"1N
M<RD["B`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<G-T<FEN9R@D
M9&5F<F5S+3YE<G)O<G-T<FEN9RD["B`@("`@("`@("`@("`@("`@("`@(&EF
M("AD969I;F5D*"1P86-K970I*2!["B`@("`@("`@("`@("`@("`@("`@('!U
M<V@@0&$L(&-N86UE7V%D9'(H6T!N86UE<UTL("1P86-K970I.PH@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@*B\*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^;F%M
M97-E<G9E<G,@/2`D;G-A.PH@("`@("`@('T*("`@("`@("!R971U<FXH)'1H
M:7,M/FYA;65S97)V97)S*3L*("`@('T*"B`@("`O*B!]?7T@*B\*("`@("\J
M(&YO="!C;VUP;&5T960@+2!.971?1$Y37U)E<V]L=F5R.CIC;F%M95]A9&1R
M*"D@>WM[("HO"B`@("`O*BH*("`@("`J(%5N:VYO=VX@+2!N;W0@<&]R=&5D
M('EE=`H@("`@("HO"B`@("!F=6YC=&EO;B!C;F%M95]A9&1R*"D*("`@('L*
M("`@('T*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]297-O;'9E<CHZ
M<V5A<F-H*"D@>WM[("HO"B`@("`O*BH*("`@("`J(%-E87)C:&5S(&YA;65S
M97)V97)S(&9O<B!A;B!A;G-W97(*("`@("`J"B`@("`@*B!';V5S('1H<F]U
M9V@@=&AE('-E87)C:"!L:7-T(&%N9"!A='1E;7!T<R!T;R!R97-O;'9E(&YA
M;64@8F%S960@;VX*("`@("`J('1H92!I;F9O<FUA=&EO;B!I;B!T:&4@<V5A
M<F-H(&QI<W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92!4
M:&4@;F%M92`H3$A3*2!O9B!A(')E<V]U<F-E(')E8V]R9"!T;R!Q=65R>2X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@5&AE('1Y<&4@;V8@<F5C;W)D
M('1O('%U97)Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@5&AE(&-L
M87-S(&]F(')E8V]R9"!T;R!Q=65R>2X*("`@("`J($!R971U<FX@;6EX960@
M("`@86X@;V)J96-T(&]F('1Y<&4@3F5T7T1.4U]086-K970@;VX@<W5C8V5S
M<RP*("`@("`J("`@("`@("`@("`@("`@("`@;W(@1D%,4T4@;VX@9F%I;'5R
M92X*("`@("`J($!S964@3F5T7T1.4SHZ='EP97-B>6YA;64H*2P@3F5T7T1.
M4SHZ8VQA<W-E<V)Y;F%M92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!S96%R8V@H)&YA;64L("1T>7!E(#T@)T$G+"`D
M8VQA<W,@/2`G24XG*0H@("`@>PH@("`@("`@("\J"B`@("`@("`@("H@268@
M=&AE(&YA;64@;&]O:W,@;&EK92!A;B!)4"!A9&1R97-S('1H96X@9&\@86X@
M87!P<F]P<FEA=&4*("`@("`@("`@*B!05%(@<75E<GDN"B`@("`@("`@("HO
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>*%QD*RE<+BA<9"LI7"XH7&0K
M*5PN*%QD*RDD+R<L("1N86UE+"`D<F5G<RDI('L*("`@("`@("`@("`@)&YA
M;64@/2`B)')E9W-;-%TN)')E9W-;,UTN)')E9W-;,ETN)')E9W-;,5TN:6XM
M861D<BYA<G!A(CL*("`@("`@("`@("`@)'1Y<&4@/2`G4%12)SL*("`@("`@
M("!]"@H@("`@("`@("\J"B`@("`@("`@("H@268@=&AE(&YA;64@8V]N=&%I
M;G,@870@;&5A<W0@;VYE(&1O="!T:&5N('1R>2!I="!A<R!I<R!F:7)S="X*
M("`@("`@("`@*B\*("`@("`@("!I9B`H<W1R8VAR*"1N86UE+"`G+B<I*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@
M("`@(&5C:&\@(CL[('-E87)C:"@D;F%M92P@)'1Y<&4L("1C;&%S<RE<;B([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&%N<R`]("1T:&ES+3YQ=65R
M>2@D;F%M92P@)'1Y<&4L("1C;&%S<RD["B`@("`@("`@("`@(&EF("@H:7-?
M;V)J96-T*"1A;G,I*2`F)B`D86YS+3YH96%D97(M/F%N8V]U;G0@/B`P*2![
M"B`@("`@("`@("`@("`@("!R971U<FXH)&%N<RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@268@=&AE(&YA;64@
M9&]E<VXG="!E;F0@:6X@82!D;W0@=&AE;B!A<'!L>2!T:&4@<V5A<F-H(&QI
M<W0N"B`@("`@("`@("HO"B`@("`@("`@)&1O;6%I;B`]("<G.PH@("`@("`@
M(&EF("@H(2!P<F5G7VUA=&-H*"<O7"XD+R<L("1N86UE*2D@)B8@)'1H:7,M
M/F1N<W)C:"D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^<V5A<F-H
M;&ES="!A<R`D9&]M86EN*2!["B`@("`@("`@("`@("`@("`D;F5W;F%M92`]
M("(D;F%M92XD9&]M86EN(CL*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M9&5B=6<I('L*("`@("`@("`@("`@("`@("`@("!E8VAO("([.R!S96%R8V@H
M)&YE=VYA;64L("1T>7!E+"`D8VQA<W,I7&XB.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&%N<R`]("1T:&ES+3YQ=65R>2@D;F5W;F%M
M92P@)'1Y<&4L("1C;&%S<RD["B`@("`@("`@("`@("`@("!I9B`H*&ES7V]B
M:F5C="@D86YS*2D@)B8@)&%N<RT^:&5A9&5R+3YA;F-O=6YT(#X@,"D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B@D86YS*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH*("`@
M("`@("`@*B!&:6YA;&QY+"!I9B!T:&4@;F%M92!H87,@;F\@9&]T<R!T:&5N
M('1R>2!I="!A<R!I<RX*("`@("`@("`@*B\*("`@("`@("!I9B`H(2!S=')L
M96XH<W1R8VAR*"1N86UE+"`G+B<I*2D@>PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/F1E8G5G*2!["B`@("`@("`@("`@("`@("!E8VAO("([.R!S96%R8V@H
M)&YA;64L("1T>7!E+"`D8VQA<W,I7&XB.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1A;G,@/2`D=&AI<RT^<75E<GDH(B1N86UE+B(L("1T>7!E+"`D
M8VQA<W,I.PH@("`@("`@("`@("!I9B`H*"1A;G,@/2`D=&AI<RT^<75E<GDH
M)&YA;64L("1T>7!E+"`D8VQA<W,I*2`F)@H@("`@("`@("`@("`@("`@("`@
M("1A;G,M/FAE861E<BT^86YC;W5N="`^(#`I('L*("`@("`@("`@("`@("`@
M(')E='5R;B@D86YS*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH*("`@("`@("`@*B!.;R!A;G-W97(@=V%S(&9O=6YD+@H@("`@("`@
M("`J+PH@("`@("`@(')E='5R;B@P*3L*("`@('T*"B`@("`O*B!]?7T@*B\*
M("`@("\J($YE=%]$3E-?4F5S;VQV97(Z.G%U97)Y*"D@>WM[("HO"B`@("`O
M*BH*("`@("`J(%%U97)I97,@;F%M97-E<G9E<G,@9F]R(&%N(&%N<W=E<@H@
M("`@("H*("`@("`J(%%U97)I97,@=&AE(&YA;65S97)V97)S(&QI<W1E9"!I
M;B!T:&4@<F5S;VQV97(@8V]N9FEG=7)A=&EO;B!F;W(@(&%N"B`@("`@*B!A
M;G-W97(@=&\@82!Q=65S=&EO;B!P86-K970N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92!4:&4@;F%M92`H3$A3*2!O9B!A(')E<V]U<F-E
M(')E8V]R9"!T;R!Q=65R>2X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M5&AE('1Y<&4@;V8@<F5C;W)D('1O('%U97)Y+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8VQA<W,@5&AE(&-L87-S(&]F(')E8V]R9"!T;R!Q=65R>2X*("`@
M("`J($!R971U<FX@;6EX960@("`@86X@;V)J96-T(&]F('1Y<&4@3F5T7T1.
M4U]086-K970@;VX@<W5C8V5S<RP*("`@("`J("`@("`@("`@("`@("`@("`@
M;W(@1D%,4T4@;VX@9F%I;'5R92X*("`@("`J($!S964@3F5T7T1.4SHZ='EP
M97-B>6YA;64H*2P@3F5T7T1.4SHZ8VQA<W-E<V)Y;F%M92@I"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>2@D;F%M
M92P@)'1Y<&4@/2`G02<L("1C;&%S<R`]("=)3B<I"B`@("!["B`@("`@("`@
M+RH*("`@("`@("`@*B!)9B!T:&4@;F%M92!D;V5S;B=T(&-O;G1A:6X@86YY
M(&1O=',@=&AE;B!A<'!E;F0@=&AE(&1E9F%U;'0@9&]M86EN+@H@("`@("`@
M("`J+PH@("`@("`@(&EF("@H<W1R8VAR*"1N86UE+"`G+B<I(#P@,"D@)B8@
M)'1H:7,M/F1E9FYA;65S*2!["B`@("`@("`@("`@("1N86UE("X]("<N)R`N
M("1T:&ES+3YD;VUA:6X["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@
M("`J($EF('1H92!N86UE(&QO;VMS(&QI:V4@86X@25`@861D<F5S<R!T:&5N
M(&1O(&%N(&%P<')O<')I871E"B`@("`@("`@("H@4%12('%U97)Y+@H@("`@
M("`@("`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BA<9"LI7"XH7&0K
M*5PN*%QD*RE<+BA<9"LI)"\G+"`D;F%M92P@)')E9W,I*2!["B`@("`@("`@
M("`@("1N86UE(#T@(B1R96=S6S1=+B1R96=S6S-=+B1R96=S6S)=+B1R96=S
M6S%=+FEN+6%D9'(N87)P82(["B`@("`@("`@("`@("1T>7!E(#T@)U!44B<[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@
M("`@("`@(&5C:&\@(CL[('%U97)Y*"1N86UE+"`D='EP92P@)&-L87-S*5QN
M(CL*("`@("`@("!]"B`@("`@("`@)'!A8VME="`](&YE=R!.971?1$Y37U!A
M8VME="@D=&AI<RT^9&5B=6<I.PH@("`@("`@("1P86-K970M/F)U:6QD475E
M<W1I;VXH)&YA;64L("1T>7!E+"`D8VQA<W,I.PH@("`@("`@("1P86-K970M
M/FAE861E<BT^<F0@/2`D=&AI<RT^<F5C=7)S93L*("`@("`@("`D86YS(#T@
M)'1H:7,M/G-E;F0H)'!A8VME="D["B`@("`@("`@:68@*&ES7V]B:F5C="@D
M86YS*2`F)B`D86YS+3YH96%D97(M/F%N8V]U;G0@/B`P*2!["B`@("`@("`@
M("`@(')E='5R;B@D86YS*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N*#`I
M.PH@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]297-O;'9E
M<CHZ<V5N9"@D<&%C:V5T3U)N86UE+"`D<71Y<&4@/2`G)RP@)'%C;&%S<R`]
M("<G*2![>WL@*B\*("`@("\J*@H@("`@("H@4V5N9',@82!P86-K970@=&\@
M82!N86UE<V5R=F5R"B`@("`@*@H@("`@("H@1&5T97)M:6YE<R!T:&4@87!P
M<F]P<FEA=&4@8V]M;75N:6-A=&EO;B!M971H;V0@*%5$4"!O<B!40U`I(&%N
M9`H@("`@("H@<V5N9"!A($1.4R!P86-K970@=&\@82!N86UE<V5R=F5R+B`@
M57-E(&]F('1H92!T:&ES(&9U;F-T:6]N"B`@("`@*B!D:7)E8W1L>2`@:7,@
M9&ES8V]U<F%G960N("1P86-K971/4FYA;64@<VAO=6QD(&%L=V%Y<R!B92!A
M('!R;W!E<FQY"B`@("`@*B!F;W)M871T960@8FEN87)Y($1.4R!P86-K970N
M("!(;W=E=F5R+"!I="!I<R!P;W-S:6)L92!T;R!S96YD("!A"B`@("`@*B!Q
M=65R>2!H97)E(&%N9"!B>7!A<W,@3F5T7T1.4U]297-O;'9E<CHZ<75E<GDH
M*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A8VME=$]2;F%M92`@
M("`@($$@8FEN87)Y($1.4R!P86-K970@<W1R96%M(&]R(&$*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AO<W1N86UE('1O('%U
M97)Y"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q='EP92`@("`@5&AI<R!S:&]U
M;&0@;F]T(&)E('5S960*("`@("`J($!P87)A;2!S=')I;F<@)'%C;&%S<R`@
M("!4:&ES('-H;W5L9"!N;W0@8F4@=7-E9`H@("`@("H@0')E='5R;B!O8FIE
M8W0@3F5T7T1.4U]086-K970@("`@06X@86YS=V5R('!A8VME="!O8FIE8W0*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5N9"@D<&%C:V5T3U)N86UE+"`D<71Y
M<&4@/2`G)RP@)'%C;&%S<R`]("<G*0H@("`@>PH@("`@("`@("1P86-K970@
M/2`D=&AI<RT^;6%K95]Q=65R>5]P86-K970H)'!A8VME=$]2;F%M92P@)'%T
M>7!E+"`D<6-L87-S*3L*("`@("`@("`D<&%C:V5T7V1A=&$@/2`D<&%C:V5T
M+3YD871A*"D["@H@("`@("`@(&EF("@D=&AI<RT^=7-E=F,@(3T@,"!\?"!S
M=')L96XH)'!A8VME=%]D871A(#X@-3$R*2D@>PH@("`@("`@("`@("`D86YS
M(#T@)'1H:7,M/G-E;F1?=&-P*"1P86-K970L("1P86-K971?9&%T82D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%N<R`]("1T:&ES+3YS96YD
M7W5D<"@D<&%C:V5T+"`D<&%C:V5T7V1A=&$I.PH*("`@("`@("`@("`@:68@
M*"1A;G,@)B8@)&%N<RT^:&5A9&5R+3YT8R`F)B`D=&AI<RT^:6=N=&,@(3T@
M,"D@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YD96)U9RD@>PH@("`@
M("`@("`@("`@("`@("`@(&5C:&\@(CL[7&X[.R!P86-K970@=')U;F-A=&5D
M.B!R971R>6EN9R!U<VEN9R!40U!<;B(["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D86YS(#T@)'1H:7,M/G-E;F1?=&-P*"1P86-K970L
M("1P86-K971?9&%T82D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N*"1A;G,I.PH@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@
M3F5T7T1.4U]297-O;'9E<CHZ<')I;G1H97@H)'!A8VME=%]D871A*2![>WL@
M*B\*("`@("\J*@H@("`@("H@4V5N9',@82!P86-K970@=FEA(%1#4"!T;R!T
M:&4@;&ES="!O9B!N86UE('-E<G9E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!R:6YT:&5X*"1D871A*0H@("`@>PH@("`@("`@("1D871A(#T@)R`@)R`N
M("1D871A.PH@("`@("`@("1S=&%R="`](#`["B`@("`@("`@=VAI;&4@*"1S
M=&%R="`\('-T<FQE;B@D9&%T82DI('L*("`@("`@("`@("`@<')I;G1F*"<[
M.R`E,#-D.B`G+"`D<W1A<G0I.PH@("`@("`@("`@("!F;W(@*"1C='(@/2`D
M<W1A<G0[("1C='(@/"`D<W1A<G0K,38[("1C='(K*RD@>PH@("`@("`@("`@
M("`@("`@:68@*"1C='(@/"!S=')L96XH)&1A=&$I*0H@("`@("`@("`@("`@
M("`@("`@('!R:6YT9B@G)3`R>"`G+"!O<F0H)&1A=&%;)&-T<ETI*3L*("`@
M("`@("`@("`@("`@(&5L<V4*("`@("`@("`@("`@("`@("`@("!E8VAO("<@
M("`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@)R`@("<["B`@
M("`@("`@("`@(&9O<B`H)&-T<B`]("1S=&%R=#L@)&-T<B`\("1S=&%R="LQ
M-CL@)&-T<BLK*2!["B`@("`@("`@("`@("`@("!I9B`H;W)D*"1D871A6R1C
M=')=*2`\(#,R('Q\(&]R9"@D9&%T85LD8W1R72D@/B`Q,C<I('L*("`@("`@
M("`@("`@("`@("`@("!E8VAO("<N)SL*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@96-H;R`D9&%T85LD8W1R73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO
M(")<;B(["B`@("`@("`@("`@("1S=&%R="`K/2`Q-CL*("`@("`@("!]"B`@
M("!]"B`@("`O*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4F5S;VQV97(Z.G-E
M;F1?=&-P*"1P86-K970L("1P86-K971?9&%T82D@>WM[("HO"B`@("`O*BH*
M("`@("`J(%-E;F1S(&$@<&%C:V5T('9I82!40U`@=&\@=&AE(&QI<W0@;V8@
M;F%M92!S97)V97)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M8VME="`@("!!('!A8VME="!O8FIE8W0@=&\@<V5N9"!T;R!T:&4@3E,@;&ES
M=`H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%C:V5T7V1A=&$@("!4:&4@9&%T
M82!I;B!T:&4@<&%C:V5T(&%S(')E='5R;F5D(&)Y"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!.971?1$Y37U!A8VME=#HZ9&%T
M82@I(&UE=&AO9`H@("`@("H@0')E='5R;B!O8FIE8W0@3F5T7T1.4U]086-K
M970@4F5T=7)N<R!A;B!A;G-W97(@<&%C:V5T(&]B:F5C=`H@("`@("H@0'-E
M92!.971?1$Y37U)E<V]L=F5R.CIS96YD7W5D<"@I+"!.971?1$Y37U)E<V]L
M=F5R.CIS96YD*"D*("`@("`J+PH@("`@9G5N8W1I;VX@<V5N9%]T8W`H)'!A
M8VME="P@)'!A8VME=%]D871A*0H@("`@>PH@("`@("`@(&EF("@A(&-O=6YT
M*"1T:&ES+3YN86UE<V5R=F5R<RDI('L*("`@("`@("`@("`@)'1H:7,M/F5R
M<F]R<W1R:6YG(#T@)VYO(&YA;65S97)V97)S)SL*("`@("`@("`@("`@:68@
M*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@96-H;R`B.SL@15)2
M3U(Z('-E;F1?=&-P.B!N;R!N86UE<V5R=F5R<UQN(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FXH3E5,3"D["B`@("`@("`@?0H@("`@("`@
M("1T:6UE;W5T(#T@)'1H:7,M/G1C<%]T:6UE;W5T.PH*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^;F%M97-E<G9E<G,@87,@)&YS*2!["B`@("`@("`@("`@
M("1D<W1P;W)T(#T@)'1H:7,M/G!O<G0["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@(&5C:&\@(CL[('-E;F1?=&-P
M*"1N<SHD9'-T<&]R="E<;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'-O8VM?:V5Y(#T@(B1N<SHD9'-T<&]R="(["B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^<V]C:V5T<ULD<V]C:U]K97E=*2`F)B!I<U]R97-O=7)C
M92@D=&AI<RT^<V]C:V5T<ULD<V]C:U]K97E=*2D@>PH@("`@("`@("`@("`@
M("`@)'-O8VL@/2`F)'1H:7,M/G-O8VME='-;)'-O8VM?:V5Y73L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@A("@D<V]C:R`]
M($!F<V]C:V]P96XH)&YS+"`D9'-T<&]R="P@)&5R<FYO+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E<G)S='(L("1T:6UE;W5T*2DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)S=')I;F<@/2`G8V]N
M;F5C=&EO;B!F86EL960G.PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`B.SL@
M15)23U(Z('-E;F1?=&-P.B!C;VYN96-T:6]N(&9A:6QE9#H@)&5R<G-T<EQN
M(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V]C:V5T<ULD<V]C:U]K97E=(#T@)'-O8VL["B`@("`@("`@("`@
M("`@("!U;G-E="@D<V]C:RD["B`@("`@("`@("`@("`@("`D<V]C:R`]("8D
M=&AI<RT^<V]C:V5T<ULD<V]C:U]K97E=.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1L96YM<V<@/2!P86-K*"=N)RP@<W1R;&5N*"1P86-K971?9&%T
M82DI.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@("`@
M("`@("`@("!E8VAO("<[.R!S96YD:6YG("<@+B!S=')L96XH)'!A8VME=%]D
M871A*2`N("(@8GET97-<;B(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@H)'-E;G0@/2!F=W)I=&4H)'-O8VLL("1L96YM<V<I*2`]/2`M,2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R<W1R:6YG(#T@)VQE;F=T
M:"!S96YD(&9A:6QE9"<["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F1E
M8G5G*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`B.SL@15)23U(Z('-E
M;F1?=&-P.B!L96YG=&@@<V5N9"!F86EL961<;B(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"@D<V5N="`](&9W<FET92@D<V]C:RP@)'!A8VME
M=%]D871A*2D@/3T@+3$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O
M<G-T<FEN9R`]("=P86-K970@<V5N9"!F86EL960G.PH@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@("`@(&5C
M:&\@(CL[($524D]2.B!S96YD7W1C<#H@<&%C:V5T(&1A=&$@<V5N9"!F86EL
M961<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@('-O8VME=%]S971?=&EM96]U="@D<V]C:RP@)'1I;65O=70I.PH@
M("`@("`@("`@("`D8G5F(#T@9G)E860H)'-O8VLL(#(I.PH@("`@("`@("`@
M("`D92`]('-O8VME=%]G971?<W1A='5S*"1S;V-K*3L*("`@("`@("`@("`@
M+RH@268@)&)U9B!I<R!E;7!T>2P@=V4@=V%N="!T;R!S=7!R97-S(&5R<F]R
M<PH@("`@("`@("`@("`@("!L;VYG(&5N;W5G:"!T;R!R96%C:"!T:&4@8V]N
M=&EN=64[(&1O=VX@=&AE(&QI;F4@*B\*("`@("`@("`@("`@)&QE;B`]($!U
M;G!A8VLH)VYI;G0G+"`D8G5F*3L*("`@("`@("`@("`@)&QE;B`]($`D;&5N
M6R=I;G0G73L*("`@("`@("`@("`@:68@*"$D;&5N*2!["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8G5F
M(#T@9G)E860H)'-O8VLL("1L96XI.PH@("`@("`@("`@("`D86-T=6%L(#T@
M<W1R;&5N*"1B=68I.PH@("`@("`@("`@("`D=&AI<RT^86YS=V5R9G)O;2`]
M("1N<SL*("`@("`@("`@("`@)'1H:7,M/F%N<W=E<G-I>F4@/2`D;&5N.PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@("`@("`@("`@
M("!E8VAO("([.R!R96-E:79E9"`D86-T=6%L(&)Y=&5S7&XB.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D86-T=6%L("$]("1L96XI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YE<G)O<G-T<FEN9R`](")E>'!E8W1E9"`D
M;&5N(&)Y=&5S+"!R96-E:79E9"`D8G5F(CL*("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@("`@("!E8VAO("<[
M.R!S96YD7W1C<#H@)R`N("1T:&ES+3YE<G)O<G-T<FEN9SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D86YS(#T@;F5W($YE=%]$3E-?4&%C:V5T*"1T
M:&ES+3YD96)U9RD["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1A;G,M/G!A
M<G-E*"1B=68I*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F5R<F]R<W1R:6YG(#T@)&%N
M<RT^:&5A9&5R+3YR8V]D93L*("`@("`@("`@("`@)&%N<RT^86YS=V5R9G)O
M;2`]("1T:&ES+3YA;G-W97)F<F]M.PH@("`@("`@("`@("`D86YS+3YA;G-W
M97)S:7IE(#T@)'1H:7,M/F%N<W=E<G-I>F4["B`@("`@("`@("`@(')E='5R
M;B@D86YS*3L*("`@("`@("!]"B`@("!]"@H@("`@+RH@?7U]("HO"B`@("`O
M*B!.971?1$Y37U)E<V]L=F5R.CIS96YD7W5D<%]N;U]S;V-K7VQI8B@D<&%C
M:V5T+"`D<&%C:V5T7V1A=&$I('M[>R`J+PH@("`@+RHJ"B`@("`@*B!396YD
M<R!A('!A8VME="!V:6$@5410('1O('1H92!L:7-T(&]F(&YA;64@<V5R=F5R
M<RX*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T:6]N('-E;F1S(&$@<&%C:V5T
M('1O(&$@;F%M97-E<G9E<BX@($ET(&ES(&-A;&QE9"!B>0H@("`@("H@<V5N
M9%]U9'`@:68@=&AE('-O8VME=',@4$A0(&5X=&5N<VEO;B!I<R!N;W0@8V]M
M<&EL960@:6YT;R!02%`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%C:V5T("`@($$@<&%C:V5T(&]B:F5C="!T;R!S96YD('1O('1H92!.4R!L
M:7-T"B`@("`@*B!`<&%R86T@<W1R:6YG("1P86-K971?9&%T82`@(%1H92!D
M871A(&EN('1H92!P86-K970@87,@<F5T=7)N960@8GD*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE($YE=%]$3E-?4&%C:V5T.CID
M871A*"D@;65T:&]D"B`@("`@*B!`<F5T=7)N(&]B:F5C="!.971?1$Y37U!A
M8VME="!2971U<FYS(&%N(&%N<W=E<B!P86-K970@;V)J96-T"B`@("`@*B!`
M<V5E($YE=%]$3E-?4F5S;VQV97(Z.G-E;F1?=&-P*"DL($YE=%]$3E-?4F5S
M;VQV97(Z.G-E;F0H*2P*("`@("`J("`@("`@3F5T7T1.4U]297-O;'9E<CHZ
M<V5N9%]U9'`H*2P@3F5T7T1.4U]297-O;'9E<CHZ<V5N9%]U9'!?=VET:%]S
M;V-K7VQI8B@I"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F1?=61P7VYO7W-O
M8VM?;&EB*"1P86-K970L("1P86-K971?9&%T82D*("`@('L*("`@("`@("`D
M<F5T<F%N<R`]("1T:&ES+3YR971R86YS.PH@("`@("`@("1T:6UE;W5T(#T@
M)')E=')A;G,["@H@("`@("`@("\J"B`@("`@("`@("H@4$A0(&1O97-N)W0@
M:&%V92!E>&-E;&QE;G0@<V]C:V5T('-U<'!O<G0@87,@;V8@=&AI<R!W<FET
M:6YG+@H@("`@("`@("`J(%1H:7,@;F5E9',@=&\@8F4@<F5W<FET=&5N('=H
M96X@4$A0(%!/4TE8('-O8VME="!S=7!P;W)T(&ES"B`@("`@("`@("H@8V]M
M<&QE=&4N"B`@("`@("`@("H@3V)V:6]U<VQY+"!T:&ES(&-O9&4@:7,@355#
M2"!D:69F97)E;G0@=&AA;B!T:&4@4$523"!I;7!L96UE;G1A=&EO;@H@("`@
M("`@("`J+PH*("`@("`@("`D=R`](&5R<F]R7W)E<&]R=&EN9R@P*3L*("`@
M("`@("`D8W1R(#T@,#L*("`@("`@("`O+R!#<F5A=&4@82!S;V-K970@:&%N
M9&QE(&9O<B!E86-H(&YA;65S97)V97(*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^;F%M97-E<G9E<G,@87,@)&YA;65S97)V97(I('L*("`@("`@("`@("`@
M:68@*"1S;V-K6R1C='(K*UT@/2!F<V]C:V]P96XH(G5D<#HO+R1N86UE<V5R
M=F5R(BP@)'1H:7,M/G!O<G0I*2!["B`@("`@("`@("`@("`@("`D<&5E<FAO
M<W1;)&-T<BTQ72`]("1N86UE<V5R=F5R.PH@("`@("`@("`@("`@("`@)'!E
M97)P;W)T6R1C='(M,5T@/2`D=&AI<RT^<&]R=#L*("`@("`@("`@("`@("`@
M('-O8VME=%]S971?8FQO8VMI;F<H)'-O8VLL($9!3%-%*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C='(M+3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!E<G)O<E]R97!O<G1I;F<H)'<I.PH*
M("`@("`@("!I9B`H)&-T<B`]/2`P*2!["B`@("`@("`@("`@("1T:&ES+3YE
M<G)O<G-T<FEN9R`]("=N;R!N86UE<V5R=F5R<R<["B`@("`@("`@("`@(')E
M='5R;BA.54Q,*3L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1T:&ES+3YR971R>3L@)&DK*RP@)')E=')A;G,@*CT@,BP*("`@("`@
M("`@("`@("`@("1T:6UE;W5T(#T@*&EN="D@*"1R971R86YS("\@*&-O=6YT
M*"1N<RDK,2DI*2!["B`@("`@("`@("`@(&EF("@D=&EM96]U="`\(#$I('L*
M("`@("`@("`@("`@("`@("1T:6UE;W5T(#T@,3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@9F]R96%C:"`H)'-O8VL@87,@)&L@/3X@)',I('L*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@
M("`@("`@("!E8VAO("<[.R!S96YD7W5D<"@G("X@)'!E97)H;W-T6R1K72`N
M("<Z)R`N("1P965R<&]R=%LD:UT@+B`G*3H@<V5N9&EN9R`G("X@<W1R;&5N
M*"1P86-K971?9&%T82D@+B`B(&)Y=&5S7&XB.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@(&EF("@A(&9W<FET92@D<RP@)'!A8VME=%]D
M871A*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`B.SL@<V5N9"!E<G)O
M<EQN(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@+RH*("`@("`@("`@("`@("`@("`J("!(97)E
M)W,@=VAE<F4@:70@9V5T)W,@<F5A;&QY(&YA<W1Y+B`@5V4@9&]N)W0@:&%V
M92!A('-E;&5C="@I"B`@("`@("`@("`@("`@("`@*B`@9G5N8W1I;VX@:&5R
M92P@<V\@=V4@:&%V92!T;R!P;VQL(&9O<B!A(')E<W!O;G-E+BXN(%5'2"$*
M("`@("`@("`@("`@("`@("`J+PH*("`@("`@("`@("`@("`@("1T:6UE=&]4
M3R`@/2!T:6UE*"D@*R`H9&]U8FQE*6UI8W)O=&EM92@I("L@)'1I;65O=70[
M"@H@("`@("`@("`@("`@("`@+RH*("`@("`@("`@("`@("`@("`J(&QE="=S
M('-L965P(&9O<B!A(&9E=R!H=6YD<F5D(&UI8W)O<V5C;VYD<R!T;R!L970@
M=&AE"B`@("`@("`@("`@("`@("`@*B!D871A(&-O;64@:6X@9G)O;2!T:&4@
M;F5T=V]R:RXN+@H@("`@("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`@
M("!U<VQE97`H-3`P*3L*("`@("`@("`@("`@("`@("1B=68@/2`G)SL*("`@
M("`@("`@("`@("`@('=H:6QE("@A('-T<FQE;B@D8G5F*2`F)B`D=&EM971O
M5$\@/B`H=&EM92@I("L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("AD
M;W5B;&4I;6EC<F]T:6UE*"DI*2!["B`@("`@("`@("`@("`@("`@("`@<V]C
M:V5T7W-E=%]B;&]C:VEN9R@D<RP@1D%,4T4I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D8G5F(#T@9G)E860H)',L(#4Q,BDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F%N<W=E<F9R;VT@/2`D<&5E<FAO<W1;)&M=
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^86YS=V5R<VEZ92`]
M('-T<FQE;B@D8G5F*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@96-H
M;R`G.SL@86YS=V5R(&9R;VT@)R`N("1P965R:&]S=%LD:UT@+B`G.B<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P965R<&]R=%LD:UT@
M+B`@)SH@)R`N('-T<FQE;B@D8G5F*2`N("(@8GET97-<;B(["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&%N
M<R`](&YE=R!.971?1$Y37U!A8VME="@D=&AI<RT^9&5B=6<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&%N<RT^<&%R<V4H)&)U9BDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D86YS+3YH96%D97(M/G%R
M("$]("<Q)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1A;G,M/FAE861E<BT^:60@(3T@
M)'!A8VME="T^:&5A9&5R+3YI9"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R
M<W1R:6YG(#T@)&%N<RT^:&5A9&5R+3YR8V]D93L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1A;G,M/F%N<W=E<F9R;VT@/2`D=&AI<RT^86YS=V5R
M9G)O;3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A;G,M/F%N<W=E
M<G-I>F4@/2`D=&AI<RT^86YS=V5R<VEZ93L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B@D86YS*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`O+R!3;&5E<"!A;F]T:&5R(#$O,3`P=&@@;V8@82!S96-O;F0N+BX@=&AI
M<R!S=6-K<RXN+@H@("`@("`@("`@("`@("`@("`@('5S;&5E<"@Q,#`P*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D=&AI<RT^97)R
M;W)S=')I;F<@/2`G<75E<GD@=&EM960@;W5T)SL*("`@("`@("`@("`@("`@
M(')E='5R;BA.54Q,*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O*B!]?7T@*B\*("`@("\J($YE=%]$3E-?4F5S;VQV97(Z.G-E;F1?
M=61P7W=I=&A?<V]C:U]L:6(H)'!A8VME="P@)'!A8VME=%]D871A*2![>WL@
M*B\*("`@("\J*@H@("`@("H@4V5N9',@82!P86-K970@=FEA(%5$4"!T;R!T
M:&4@;&ES="!O9B!N86UE('-E<G9E<G,N"B`@("`@*@H@("`@("H@5&AI<R!F
M=6YC=&EO;B!S96YD<R!A('!A8VME="!T;R!A(&YA;65S97)V97(N("!)="!I
M<R!C86QL960@8GD*("`@("`J('-E;F1?=61P(&EF('1H92!S;V-K971S(%!(
M4"!E>'1E;G-I;VX@:7,@8V]M<&EL960@:6YT;R!02%`N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%C:V5T("`@($$@<&%C:V5T(&]B:F5C="!T
M;R!S96YD('1O('1H92!.4R!L:7-T"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M86-K971?9&%T82`@(%1H92!D871A(&EN('1H92!P86-K970@87,@<F5T=7)N
M960@8GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M($YE=%]$3E-?4&%C:V5T.CID871A*"D@;65T:&]D"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="!.971?1$Y37U!A8VME="!2971U<FYS(&%N(&%N<W=E<B!P86-K
M970@;V)J96-T"B`@("`@*B!`<V5E($YE=%]$3E-?4F5S;VQV97(Z.G-E;F1?
M=&-P*"DL($YE=%]$3E-?4F5S;VQV97(Z.G-E;F0H*2P*("`@("`J("`@("`@
M3F5T7T1.4U]297-O;'9E<CHZ<V5N9%]U9'`H*2P@3F5T7T1.4U]297-O;'9E
M<CHZ<V5N9%]U9'!?;F]?<V]C:U]L:6(H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!S96YD7W5D<%]W:71H7W-O8VM?;&EB*"1P86-K970L("1P86-K971?9&%T
M82D*("`@('L*("`@("`@("`D<F5T<F%N<R`]("1T:&ES+3YR971R86YS.PH@
M("`@("`@("1T:6UE;W5T(#T@)')E=')A;G,["@H@("`@("`@("\O)'<@/2!E
M<G)O<E]R97!O<G1I;F<H,"D["B`@("`@("`@)&-T<B`](#`["B`@("`@("`@
M+R\@0W)E871E(&$@<V]C:V5T(&AA;F1L92!F;W(@96%C:"!N86UE<V5R=F5R
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FYA;65S97)V97)S(&%S("1N86UE
M<V5R=F5R*2!["B`@("`@("`@("`@(&EF("@H*"1S;V-K6R1C='(K*UT@/2!S
M;V-K971?8W)E871E*$%&7TE.150L(%-/0TM?1$=204TL(%-/3%]51%`I*2`^
M/2`P*2`F)@H@("`@("`@("`@("`@("`@("`@('-O8VME=%]C;VYN96-T*"1S
M;V-K6R1C='(M,5TL("1N86UE<V5R=F5R+"`D=&AI<RT^<&]R="D@/CT@,"D@
M>PH@("`@("`@("`@("`@("`@)'!E97)H;W-T6R1C='(M,5T@/2`D;F%M97-E
M<G9E<CL*("`@("`@("`@("`@("`@("1P965R<&]R=%LD8W1R+3%=(#T@)'1H
M:7,M/G!O<G0["B`@("`@("`@("`@("`@("!S;V-K971?<V5T7VYO;F)L;V-K
M*"1S;V-K6R1C='(M,5TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&-T<BTM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("\O97)R;W)?<F5P;W)T:6YG*"1W*3L*"B`@("`@("`@:68@*"1C='(@
M/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^97)R;W)S=')I;F<@/2`G;F\@
M;F%M97-E<G9E<G,G.PH@("`@("`@("`@("!R971U<FXH3E5,3"D["B`@("`@
M("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^<F5T<GD[
M("1I*RLL("1R971R86YS("H](#(L"B`@("`@("`@("`@("`@("`D=&EM96]U
M="`]("AI;G0I("@D<F5T<F%N<R`O("AC;W5N="@D;G,I*S$I*2D@>PH@("`@
M("`@("`@("!I9B`H)'1I;65O=70@/"`Q*2!["B`@("`@("`@("`@("`@("`D
M=&EM96]U="`](#$["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1S;V-K(&%S("1K(#T^("1S*2!["B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/F1E8G5G*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`G.SL@
M<V5N9%]U9'`H)R`N("1P965R:&]S=%LD:UT@+B`G.B<@+B`D<&5E<G!O<G1;
M)&M=("X@)RDZ('-E;F1I;F<@)R`N('-T<FQE;B@D<&%C:V5T7V1A=&$I("X@
M(B!B>71E<UQN(CL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("!I9B`H(2!S;V-K971?=W)I=&4H)',L("1P86-K971?9&%T82DI('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&5C:&\@(CL[('-E;F0@97)R;W)<;B(["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1S970@/2!A<G)A>2@D<RD["B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/F1E8G5G*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`B.SL@
M=&EM96]U="!S970@=&\@)'1I;65O=70@<V5C;VYD<UQN(CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1C:&%N9V5D(#T@<V]C:V5T7W-E
M;&5C="@D<V5T+"`D=R`](&YU;&PL("1E(#T@;G5L;"P@)'1I;65O=70I.PH@
M("`@("`@("`@("`@("`@:68@*"1C:&%N9V5D*2!["B`@("`@("`@("`@("`@
M("`@("`@)&)U9B`]('-O8VME=%]R96%D*"1S971;,%TL(#4Q,BD["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F%N<W=E<F9R;VT@/2`D<&5E<FAO<W1;
M)&M=.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA;G-W97)S:7IE(#T@
M<W1R;&5N*"1B=68I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M9&5B=6<I('L*("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`G.SL@86YS
M=V5R(&9R;VT@)R`N("1P965R:&]S=%LD:UT@+B`G.B<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!E97)P;W)T6R1K72`N("`G.B`G("X@<W1R
M;&5N*"1B=68I("X@(B!B>71E<UQN(CL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)&%N<R`](&YE=R!.971?1$Y37U!A8VME
M="@D=&AI<RT^9&5B=6<I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D86YS
M+3YP87)S92@D8G5F*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)&%N<RT^:&5A9&5R+3YQ<B`A/2`G,2<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D86YS+3YH96%D97(M/FED
M("$]("1P86-K970M/FAE861E<BT^:60I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<G-T<FEN9R`]
M("1A;G,M/FAE861E<BT^<F-O9&4["B`@("`@("`@("`@("`@("`@("`@("`@
M("1A;G,M/F%N<W=E<F9R;VT@/2`D=&AI<RT^86YS=V5R9G)O;3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&%N<RT^86YS=V5R<VEZ92`]("1T:&ES+3YA
M;G-W97)S:7IE.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FXH)&%N
M<RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<G-T<FEN9R`]("=Q=65R>2!T
M:6UE9"!O=70G.PH@("`@("`@("`@("`@("`@<F5T=7)N*$Y53$PI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J('U]?2`J+PH@("`@
M+RH@3F5T7T1.4U]297-O;'9E<CHZ<V5N9%]U9'`H)'!A8VME="P@)'!A8VME
M=%]D871A*2![>WL@*B\*("`@("\J*@H@("`@("H@4V5N9',@82!P86-K970@
M=FEA(%5$4"!T;R!T:&4@;&ES="!O9B!N86UE('-E<G9E<G,N"B`@("`@*@H@
M("`@("H@5&AI<R!F=6YC=&EO;B!S96YD<R!A('!A8VME="!T;R!A(&YA;65S
M97)V97(N("!S96YD7W5D<"!C86QL<PH@("`@("H@96ET:&5R($YE=%]$3E-?
M4F5S;VQV97(Z.G-E;F1?=61P7VYO7W-O8VM?;&EB*"D@;W(*("`@("`J($YE
M=%]$3E-?4F5S;VQV97(Z.G-E;F1?=61P7W=I=&A?<V]C:U]L:6(H*2!D97!E
M;F1I;F<@;VX@=VAE=&AE<B!O<@H@("`@("H@;F]T('1H92!S;V-K971S(&5X
M=&5N<VEO;B!I<R!C;VUP:6QE9"!I;G1O(%!(4"X@($YO=&4@=&AA="!U<VEN
M9R!T:&4*("`@("`J('-O8VME=',@97AT96YS:6]N(&ES($U50T@@;6]R92!E
M9F9E8VEE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="!.971?1$Y3
M7U!A8VME="`D<&%C:V5T($$@<&%C:V5T(&]B:F5C="!T;R!S96YD('1O('1H
M92!.4R!L:7-T"B`@("`@*B!`<&%R86T@<W1R:6YG("1P86-K971?9&%T82`@
M(%1H92!D871A(&EN('1H92!P86-K970@87,@<F5T=7)N960@8GD*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE($YE=%]$3E-?4&%C
M:V5T.CID871A*"D@;65T:&]D"B`@("`@*B!`<F5T=7)N(&]B:F5C="!.971?
M1$Y37U!A8VME="!2971U<FYS(&%N(&%N<W=E<B!P86-K970@;V)J96-T"B`@
M("`@*B!`<V5E($YE=%]$3E-?4F5S;VQV97(Z.G-E;F1?=&-P*"DL($YE=%]$
M3E-?4F5S;VQV97(Z.G-E;F0H*2P*("`@("`J("`@("`@3F5T7T1.4U]297-O
M;'9E<CHZ<V5N9%]U9'`H*2P@3F5T7T1.4U]297-O;'9E<CHZ<V5N9%]U9'!?
M;F]?<V]C:U]L:6(H*0H@("`@("HO"B`@("!F=6YC=&EO;B!S96YD7W5D<"@D
M<&%C:V5T+"`D<&%C:V5T7V1A=&$I"B`@("!["B`@("`@("`@:68@*&5X=&5N
M<VEO;E]L;V%D960H)W-O8VME=',G*2`F)B`D=&AI<RT^=7-E16YH86YC9613
M;V-K971S*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@
M("`@("`@("`@("`@(&5C:&\@(EQN.SL@=7-I;F<@97AT96YD960@4$A0('-O
M8VME='-<;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N*"1T
M:&ES+3YS96YD7W5D<%]W:71H7W-O8VM?;&EB*"1P86-K970L("1P86-K971?
M9&%T82DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@(&5C:&\@(EQN.SL@=7-I;F<@
M<VEM<&QE('-O8VME='-<;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N*"1T:&ES+3YS96YD7W5D<%]N;U]S;V-K7VQI8B@D<&%C:V5T+"`D
M<&%C:V5T7V1A=&$I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RH@?7U]("HO
M"B`@("`O*B!.971?1$Y37U)E<V]L=F5R.CIM86ME7W%U97)Y7W!A8VME="@D
M<&%C:V5T3U)N86UE+"`D='EP92`]("<G+"`D8VQA<W,@/2`G)RD@>WM[("HO
M"B`@("`O*BH*("`@("`J(%5N:VYO=VX*("`@("`J+PH@("`@9G5N8W1I;VX@
M;6%K95]Q=65R>5]P86-K970H)'!A8VME=$]2;F%M92P@)'1Y<&4@/2`G)RP@
M)&-L87-S(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES7V]B:F5C="@D<&%C
M:V5T3U)N86UE*2`F)B!G971?8VQA<W,H)'!A8VME=$]2;F%M92D@/3T@)VYE
M=%]D;G-?<&%C:V5T)RD@>PH@("`@("`@("`@("`D<&%C:V5T(#T@)'!A8VME
M=$]2;F%M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]
M("1P86-K971/4FYA;64["B`@("`@("`@("`@(&EF("@D='EP92`]/2`G)RD@
M>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`G02<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1C;&%S<R`]/2`G)RD@>PH@("`@("`@("`@("`@
M("`@)&-L87-S(#T@)TE.)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+RH*("`@("`@("`@("`@("H@268@=&AE(&YA;64@;&]O:W,@;&EK92!A;B!)
M4"!A9&1R97-S('1H96X@9&\@86X@87!P<F]P<FEA=&4*("`@("`@("`@("`@
M("H@4%12('%U97)Y+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]>*%QD*RE<+BA<9"LI7"XH7&0K*5PN*%QD*RDD+R<L
M("1N86UE+"`D<F5G<RDI('L*("`@("`@("`@("`@("`@("1N86UE(#T@(B1R
M96=S6S1=+B1R96=S6S-=+B1R96=S6S)=+B1R96=S6S%=+FEN+6%D9'(N87)P
M82(["B`@("`@("`@("`@("`@("`D='EP92`]("=05%(G.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@("`@
M("`@("`@("!E8VAO("([.R!Q=65R>2@D;F%M92P@)'1Y<&4L("1C;&%S<RE<
M;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!A8VME="`](&YE=R!.
M971?1$Y37U!A8VME="@D=&AI<RT^9&5B=6<I.PH@("`@("`@("`@("`D<&%C
M:V5T+3YB=6EL9%%U97-T:6]N*"1N86UE+"`D='EP92P@)&-L87-S*3L*("`@
M("`@("!]"@H@("`@("`@("1P86-K970M/FAE861E<BT^<F0@/2`D=&AI<RT^
M<F5C=7)S93L*"B`@("`@("`@<F5T=7)N*"1P86-K970I.PH@("`@?0H*("`@
M("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]297-O;'9E<CHZ87AF<E]O;&0H
M)&1N86UE+"`D8VQA<W,@/2`G24XG*2![>WL@*B\*("`@("\J*@H@("`@("H@
M4&5R9F]R;7,@86X@05A&4B!Q=65R>2`H>F]N92!T<F%N<V9E<BD@*$],1"!"
M54='62!35%E,12D*("`@("`J"B`@("`@*B!4:&ES(&ES(&1E<')E8V%T960@
M86YD('-H;W5L9"!N;W0@8F4@=7-E9"$*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D;F%M92!4:&4@9&]M86EN("AZ;VYE*2!T;R!T<F%N<V9E<@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@5&AE(&-L87-S(&EN('=H:6-H
M('1O(&QO;VL@9F]R('1H92!Z;VYE+@H@("`@("H@0')E='5R;B!O8FIE8W0@
M3F5T7T1.4U]086-K970*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%X9G)?;VQD*"1D;F%M92P@)&-L87-S(#T@)TE.)RD*
M("`@('L*("`@("`@("!R971U<FXH)'1H:7,M/F%X9G(H)&1N86UE+"`D8VQA
M<W,L(%12544I*3L*("`@('T*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.
M4U]297-O;'9E<CHZ87AF<B@D9&YA;64L("1C;&%S<R`]("=)3B<L("1O;&0@
M/2!&04Q312D@>WM[("HO"B`@("`O*BH*("`@("`J(%!E<F9O<FUS(&%N($%8
M1E(@<75E<GD@*'IO;F4@=')A;G-F97(I"B`@("`@*@H@("`@("H@4F5Q=65S
M=',@82!Z;VYE('1R86YS9F5R(&9R;VT@=&AE(&YA;65S97)V97)S+B!.;W1E
M('1H870@>F]N90H@("`@("H@=')A;G-F97)S('=I;&P@04Q705E3('5S92!4
M0U`@<F5G87)D;&5S<R!O9B!T:&4@<V5T=&EN9R!O9B!T:&4*("`@("`J($YE
M=%]$3E-?4F5S;VQV97(Z.B1U<V5V8R!F;&%G+B`@268@)&]L9"!I<R!S970@
M=&\@5%)512P@3F5T7T1.4R!R97%U:7)E<PH@("`@("H@82!N86UE<V5R=F5R
M('1H870@<W5P<&]R=',@=&AE(&UA;GDM86YS=V5R<R!S='EL92!T<F%N<V9E
M<B!F;W)M870N("!,87)G90H@("`@("H@>F]N92!T<F%N<V9E<G,@=VEL;"!N
M;W0@9G5N8W1I;VX@<')O<&5R;'DN("!3971T:6YG("1O;&0@=&\@5%)512!I
M<R!?3D]47PH@("`@("H@<F5C;VUM96YD960@86YD('-H;W5L9"!O;FQY(&)E
M('5S960@9F]R(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1N86UE(%1H92!D;VUA:6X@*'IO;F4I('1O
M('1R86YS9F5R"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R!4:&4@8VQA
M<W,@:6X@=VAI8V@@=&\@;&]O:R!F;W(@=&AE('IO;F4N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D;VQD(%)E<75I<F5S("=O;&0G('-T>6QE(&UA;GDM86YS
M=V5R(&9O<FUA="!T;R!F=6YC=&EO;BX@(%5S960@9F]R(&)A8VMW87)D<R!C
M;VUP871I8FEL:71Y(&]N;'DN"B`@("`@*B!`<F5T=7)N(&]B:F5C="!.971?
M1$Y37U!A8VME=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@87AF<B@D9&YA;64L("1C;&%S<R`]("=)3B<L("1O;&0@/2!&
M04Q312D*("`@('L*("`@("`@("!I9B`H)&]L9"D@>PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@("`@("`@("`@("!E8VAO("([.R!A
M>&9R7W-T87)T*"1D;F%M92P@)&-L87-S*5QN(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(2!C;W5N="@D=&AI<RT^;F%M97-E<G9E<G,I*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)S=')I;F<@/2`G;F\@;F%M
M97-E<G9E<G,G.PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YD96)U9RD@
M>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@(CL[($524D]2.B!N;R!N86UE
M<V5R=F5R<UQN(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(')E='5R;BA.54Q,*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&%C
M:V5T(#T@)'1H:7,M/FUA:V5?<75E<GE?<&%C:V5T*"1D;F%M92P@)T%81E(G
M+"`D8VQA<W,I.PH@("`@("`@("`@("`D<&%C:V5T7V1A=&$@/2`D<&%C:V5T
M+3YD871A*"D["B`@("`@("`@("`@("1A;G,@/2`D=&AI<RT^<V5N9%]T8W`H
M)'!A8VME="P@)'!A8VME=%]D871A*3L*("`@("`@("`@("`@<F5T=7)N*"1A
M;G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M87AF<E]S=&%R="@D9&YA;64L("1C;&%S<RD@/3T]($Y53$PI('L*("`@("`@
M("`@("`@("`@(')E='5R;BA.54Q,*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<F5T(#T@87)R87DH*3L*("`@("`@("`@("`@=VAI;&4@*"@D86YS
M(#T@)'1H:7,M/F%X9G)?;F5X="@I*2`A/3T@3E5,3"D@>PH@("`@("`@("`@
M("`@("`@:68@*"1A;G,@/3T]($Y53$PI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FXH3E5,3"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!A<G)A>5]P=7-H*"1R970L("1A;G,I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B@D<F5T*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U)E<V]L=F5R.CIA>&9R7W-T87)T
M*"1D;F%M92P@)&-L87-S(#T@)TE.)RD@>WM[("HO"B`@("`O*BH*("`@("`J
M(%-E;F1S(&$@<&%C:V5T('9I82!40U`@=&\@=&AE(&QI<W0@;V8@;F%M92!S
M97)V97)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A8VME="`@
M("!!('!A8VME="!O8FIE8W0@=&\@<V5N9"!T;R!T:&4@3E,@;&ES=`H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%C:V5T7V1A=&$@("!4:&4@9&%T82!I;B!T
M:&4@<&%C:V5T(&%S(')E='5R;F5D(&)Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!.971?1$Y37U!A8VME=#HZ9&%T82@I(&UE
M=&AO9`H@("`@("H@0')E='5R;B!O8FIE8W0@3F5T7T1.4U]086-K970@4F5T
M=7)N<R!A;B!A;G-W97(@<&%C:V5T(&]B:F5C=`H@("`@("H@0'-E92!.971?
M1$Y37U)E<V]L=F5R.CIS96YD7W1C<"@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%X9G)?<W1A<G0H)&1N86UE+"`D8VQA<W,@/2`G24XG*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@96-H;R`B.SL@
M87AF<E]S=&%R="@D9&YA;64L("1C;&%S<RE<;B(["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(2!C;W5N="@D=&AI<RT^;F%M97-E<G9E<G,I*2!["B`@("`@
M("`@("`@("1T:&ES+3YE<G)O<G-T<FEN9R`](")N;R!N86UE<V5R=F5R<R([
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@
M("`@(&5C:&\@(CL[($524D]2.B!A>&9R7W-T87)T.B!N;R!N86UE<V5R=F5R
M<UQN(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FXH3E5,3"D[
M"B`@("`@("`@?0H@("`@("`@("1P86-K970@/2`D=&AI<RT^;6%K95]Q=65R
M>5]P86-K970H)&1N86UE+"`B05A&4B(L("1C;&%S<RD["B`@("`@("`@)'!A
M8VME=%]D871A(#T@)'!A8VME="T^9&%T82@I.PH*("`@("`@("`D=&EM96]U
M="`]("1T:&ES+3YT8W!?=&EM96]U=#L*"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/FYA;65S97)V97)S(&%S("1N<RD@>PH@("`@("`@("`@("`D9'-T<&]R
M="`]("1T:&ES+3YP;W)T.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F1E8G5G
M*2!["B`@("`@("`@("`@("`@("!E8VAO("([.R!A>&9R7W-T87)T*"1N<SHD
M9'-T<&]R="E<;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-O8VM?
M:V5Y(#T@(B1N<SHD9'-T<&]R="(["B`@("`@("`@("`@(&EF("AI<U]R97-O
M=7)C92@D=&AI<RT^<V]C:V5T<ULD<V]C:U]K97E=*2D@>PH@("`@("`@("`@
M("`@("`@)'-O8VL@/2`F)'1H:7,M/G-O8VME='-;)'-O8VM?:V5Y73L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@A("@D<V]C
M:R`](&9S;V-K;W!E;B@D;G,L("1D<W1P;W)T+"`D97)R;F\L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&5R<G-T<BP@)'1I;65O=70I*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<G-T<FEN9R`](")C
M;VYN96-T:6]N(&9A:6QE9"(["B`@("`@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!E8VAO("([
M.R!%4E)/4CH@87AF<E]S=&%R=#H@8V]N;F5C=&EO;B!F86EL960Z("1E<G)S
M=')<;B(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'1H:7,M/G-O8VME='-;)'-O8VM?:V5Y72`]("1S;V-K.PH@("`@("`@
M("`@("`@("`@=6YS970H)'-O8VLI.PH@("`@("`@("`@("`@("`@)'-O8VL@
M/2`F)'1H:7,M/G-O8VME='-;)'-O8VM?:V5Y73L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D;&5N;7-G(#T@<&%C:R@B;B(L('-T<FQE;B@D<&%C:V5T
M7V1A=&$I*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YD96)U9RD@>PH@("`@
M("`@("`@("`@("`@96-H;R`B.SL@<V5N9&EN9R`B("X@<W1R;&5N*"1P86-K
M971?9&%T82D@+B`B(&)Y=&5S7&XB.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H*"1S96YT(#T@9G=R:71E*"1S;V-K+"`D;&5N;7-G*2D@/3T@
M+3$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<G-T<FEN9R`](")L
M96YG=&@@<V5N9"!F86EL960B.PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@(CL[($524D]2
M.B!A>&9R7W-T87)T.B!L96YG=&@@<V5N9"!F86EL961<;B(["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*"@D<V5N="`](&9W<FET92@D<V]C:RP@
M)'!A8VME=%]D871A*2D@/3T@+3$I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YE<G)O<G-T<FEN9R`](")P86-K970@<V5N9"!F86EL960B.PH@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@
M("`@(&5C:&\@(CL[($524D]2.B!A>&9R7W-T87)T.B!P86-K970@9&%T82!S
M96YD(&9A:6QE9%QN(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@<V]C:V5T7W-E=%]T:6UE;W5T*"1S;V-K+"`D=&EM
M96]U="D["@H@("`@("`@("`@("`D=&AI<RT^7V%X9G)?<V]C:R`]("1S;V-K
M.PH@("`@("`@("`@("`D=&AI<RT^7V%X9G)?<G(@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`D=&AI<RT^7V%X9G)?<V]A7V-O=6YT(#T@,#L*("`@("`@("`@
M("`@<F5T=7)N*"1S;V-K*3L*("`@("`@("!]"B`@("!]"@H@("`@+RH@?7U]
M("HO"B`@("`O*B!.971?1$Y37U)E<V]L=F5R.CIA>&9R7VYE>'0H*2![>WL@
M*B\*("`@("\J*@H@("`@("H@4F5Q=65S=',@=&AE(&YE>'0@4E(@9G)O;2!A
M(&5X:7-T:6YG('1R86YS9F5R('-T87)T960@=VET:"!A>&9R7W-T87)T"B`@
M("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@3F5T7T1.4U]24B!2971U<FYS
M(&$@3F5T7T1.4U]24B!O8FIE8W0@;V8@=&AE(&YE>'0@4E(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9G)O;2!A('IO;F4@=')A;G-F97(N
M"B`@("`@*B!`<V5E($YE=%]$3E-?4F5S;VQV97(Z.G-E;F1?=&-P*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@87AF<E]N97AT*"D*("`@('L*("`@("`@("!I
M9B`H(2!C;W5N="@D=&AI<RT^7V%X9G)?<G(I*2!["B`@("`@("`@("`@(&EF
M("@A(&ES<V5T*"1T:&ES+3Y?87AF<E]S;V-K*2!\?"`A(&ES7W)E<V]U<F-E
M*"1T:&ES+3Y?87AF<E]S;V-K*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F5R<F]R<W1R:6YG(#T@)VYO('IO;F4@=')A;G-F97(@:6X@<')O9W)E<W,G
M.PH@("`@("`@("`@("`@("`@<F5T=7)N*$Y53$PI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:6UE;W5T(#T@)'1H:7,M/G1C<%]T:6UE;W5T.PH@
M("`@("`@("`@("`D8G5F(#T@)'1H:7,M/G)E861?=&-P*"1T:&ES+3Y?87AF
M<E]S;V-K+"`R+"`D=&AI<RT^9&5B=6<I.PH@("`@("`@("`@("!I9B`H(2!S
M=')L96XH)&)U9BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<G-T
M<FEN9R`]("=T<G5N8V%T960@>F]N92!T<F%N<V9E<B<["B`@("`@("`@("`@
M("`@("!R971U<FXH3E5,3"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&QE;B`]('5N<&%C:R@G;C%L96XG+"`D8G5F*3L*("`@("`@("`@("`@)&QE
M;B`]("1L96Y;)VQE;B==.PH@("`@("`@("`@("!I9B`H(2`D;&5N*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^97)R;W)S=')I;F<@/2`G=')U;F-A=&5D
M('IO;F4@=')A;G-F97(G.PH@("`@("`@("`@("`@("`@<F5T=7)N*$Y53$PI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1B=68@/2`D=&AI<RT^<F5A
M9%]T8W`H)'1H:7,M/E]A>&9R7W-O8VLL("1L96XL("1T:&ES+3YD96)U9RD[
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@
M("`@(&5C:&\@)SL[(')E8V5I=F5D("<@+B!S=')L96XH)&)U9BD@+B`B8GET
M97-<;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*'-T<FQE;B@D
M8G5F*2`A/2`D;&5N*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)S
M=')I;F<@/2`G97AP96-T960@)R`N("1L96X@+B`G(&)Y=&5S+"!R96-E:79E
M9"`G("X@<W1R;&5N*"1B=68I.PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@)SL[("<@+B`D
M97)R("X@(EQN(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(')E='5R;BA.54Q,*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D86YS
M(#T@;F5W($YE=%]$3E-?4&%C:V5T*"1T:&ES+3YD96)U9RD["B`@("`@("`@
M("`@(&EF("@A("1A;G,M/G!A<G-E*"1B=68I*2!["B`@("`@("`@("`@("`@
M("!I9B`H(2`D=&AI<RT^97)R;W)S=')I;F<I('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^97)R;W)S=')I;F<@/2`G=6YK;F]W;B!E<G)O<B!D=7)I
M;F<@<&%C:V5T('!A<G-I;F<G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@<F5T=7)N*$Y53$PI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@D86YS+3YH96%D97(M/F%N8V]U;G0@/"`Q*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^97)R;W)S=')I;F<@/2`G=')U;F-A=&5D('IO;F4@
M=')A;G-F97(G.PH@("`@("`@("`@("`@("`@<F5T=7)N*$Y53$PI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@D86YS+3YH96%D97(M/G)C;V1E
M("$]("=.3T524D]2)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R
M<W1R:6YG(#T@)V5R<F]R8V]D92`G("X@)&%N<RT^:&5A9&5R+3YR8V]D92`N
M("<@<F5T=7)N960G.PH@("`@("`@("`@("`@("`@<F5T=7)N*$Y53$PI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1A;G,M/F%N<W=E
M<B!A<R`D<G(I('L*("`@("`@("`@("`@("`@(&EF("@D<G(M/G1Y<&4@/3T@
M)U-/02<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H*RLD=&AI<RT^7V%X
M9G)?<V]A7V-O=6YT(#P@,BD@>PH@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>5]P=7-H*"1T:&ES+3Y?87AF<E]R<BP@)')R*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]A>&9R7W)R+"`D<G(I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7V%X9G)?<V]A7V-O=6YT(#X](#(I('L*("`@("`@("`@("`@
M("`@('5N<V5T*"1T:&ES+3Y?87AF<E]S;V-K*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("`D<G(@/2!A<G)A>5]S:&EF="@D=&AI<RT^7V%X
M9G)?<G(I.PH@("`@("`@(')E='5R;B@D<G(I.PH@("`@?0H*("`@("\J('U]
M?2`J+PH@("`@+RH@3F5T7T1.4U]297-O;'9E<CHZ<F5A9%]T8W`H*2![>WL@
M*B\*("`@("\J*@H@("`@("H@56YK;F]W;B`M(&YO="!P;W)T960@>65T"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E861?=&-P*"1S;V-K+"`D;F)Y=&5S+"`D
M9&5B=6<@/2`P*0H@("`@>PH@("`@("`@("1B=68@/2`G)SL*("`@("`@("!W
M:&EL92`H<W1R;&5N*"1B=68I(#P@)&YB>71E<RD@>PH@("`@("`@("`@("`D
M;G)E860@/2`D;F)Y=&5S("T@<W1R;&5N*"1B=68I.PH@("`@("`@("`@("`D
M<F5A9%]B=68@/2`G)SL*("`@("`@("`@("`@:68@*"1D96)U9RD@>PH@("`@
M("`@("`@("`@("`@96-H;R`B.SL@<F5A9%]T8W`Z(&5X<&5C=&EN9R`D;G)E
M860@8GET97-<;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E861?
M8G5F(#T@9G)E860H)'-O8VLL("1N<F5A9"D["B`@("`@("`@("`@(&EF("@A
M('-T<FQE;B@D<F5A9%]B=68I*2!["B`@("`@("`@("`@("`@("!I9B`H)&1E
M8G5G*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`B.SL@15)23U(Z(')E
M861?=&-P.B!F<F5A9"!F86EL961<;B(["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)&1E8G5G*2!["B`@("`@("`@("`@("`@("!E8VAO("<[.R!R96%D
M7W1C<#H@<F5C96EV960@)R`N('-T<FQE;B@D<F5A9%]B=68I("X@(B!B>71E
M<UQN(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(7-T<FQE;B@D
M<F5A9%]B=68I*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&)U9B`N/2`D<F5A9%]B=68["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B@D8G5F*3L*("`@('T*("`@("\J('U]?2`J+PI]
M"B\J('U]?2`J+PHO*B!624T@<V5T=&EN9W,@>WM["B`J($QO8V%L('9A<FEA
M8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J
M('-O9G0M<W1O<"UW:61T:#H@-`H@*B!C(&EN9&5N="!O;@H@*B!E>'!A;F1T
M86(@;VX*("H@16YD.@H@*B!V:6TV,#`Z('-W/30@=',]-"!S=',]-"!C:6YD
M96YT(&9D;3UM87)K97(@970*("H@=FEM/#8P,#H@<W<]-"!T<STT"B`J('U]
M?2`J+PH_/@H`````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].
M970O1$Y3+TAE861E<BYP:'``````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R,30U,``Q,#0Q-S,V,S`P-@`P,C`T,34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RH*("H@($QI
M8V5N<V4@26YF;W)M871I;VXZ"B`J"B`J("`@($YE=%]$3E,Z("!!(')E<V]L
M=F5R(&QI8G)A<GD@9F]R(%!(4`H@*B`@("!#;W!Y<FEG:'0@*&,I(#(P,#(M
M,C`P,R!%<FEC($MI;&9O:6P@97)I8T!Y<&%S<RYN970*("H*("H@("`@5&AI
M<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB
M=71E(&ET(&%N9"]O<@H@*B`@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS
M(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`J("`@($QI8V5N
M<V4@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I
M;VX[(&5I=&AE<@H@*B`@("!V97)S:6]N(#(N,2!O9B!T:&4@3&EC96YS92P@
M;W(@*&%T('EO=7(@;W!T:6]N*2!A;GD@;&%T97(@=F5R<VEO;BX*("H*("H@
M("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H
M870@:70@=VEL;"!B92!U<V5F=6PL"B`J("`@(&)U="!7251(3U54($%.62!7
M05)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F
M"B`J("`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`J("`@($QE<W-E<B!'96YE
M<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"B`J"B`J("`@
M(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,
M97-S97(@1V5N97)A;"!0=6)L:6,*("H@("`@3&EC96YS92!A;&]N9R!W:71H
M('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T
M=V%R90H@*B`@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L
M(%-U:71E(#,S,"P@0F]S=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!"B`J+PH*
M+RH@($YE=%]$3E-?2&5A9&5R(&]B:F5C="!D969I;FET:6]N('M[>R`J+PHO
M*BH*("H@3V)J96-T(')E<')E<V5N=&%T:6]N(&]F('1H92!(14%$15(@<V5C
M=&EO;B!O9B!A($1.4R!P86-K970*("H*("H@5&AE($YE=%]$3E,Z.DAE861E
M<B!C;&%S<R!C;VYT86EN<R!T:&4@=F%L=65S(&]F(&$@1$Y3("!P86-K970N
M("!)="!P87)S97,*("H@=&AE(&AE861E<B!O9B!A($1.4R!P86-K970@;W(@
M8V%N("!G96YE<F%T92!T:&4@8FEN87)Y(&1A=&$*("H@<F5P<F5S96YT871I
M;VX@;V8@=&AE('!A8VME="X@(%1H92!F;W)M870@;V8@=&AE(&AE861E<B!I
M<R!D97-C<FEB960@:6X*("H@4D9#,3`S-2X*("H*("H@0'!A8VMA9V4@3F5T
M7T1.4PH@*B\*8VQA<W,@3F5T7T1.4U](96%D97(*>PH@("`@+RH@8VQA<W,@
M=F%R:6%B;&4@9&5F:6YI=&EO;G,@>WM[("HO"B`@("`O*BH*("`@("`J(%1H
M92!P86-K970G<R!R97%U97-T(&ED"B`@("`@*@H@("`@("H@5&AE(')E<75E
M<W0@:60@;V8@=&AE('!A8VME="!R97!R97-E;G1E9"!A<R`@82`Q-B!B:70@
M:6YT96=E<BX*("`@("`J+PH@("`@=F%R("1I9#L*("`@("\J*@H@("`@("H@
M5&AE(%%2(&)I="!I;B!A($1.4R!P86-K970@:&5A9&5R"B`@("`@*@H@("`@
M("H@5&AE(%%2(&)I="!A<R!D97-C<FEB960@:6X@4D9#,3`S-2X@(%%2(&ES
M('-E="!T;R`P(&9O<B!Q=65R:65S+"!A;F0*("`@("`J(#$@9F]R(')E<'-O
M;F5S+@H@("`@("HO"B`@("!V87(@)'%R.PH@("`@+RHJ"B`@("`@*B!4:&4@
M3U!#3T1%(&YA;64@;V8@=&AI<R!P86-K970N"B`@("`@*@H@("`@("H@5&AE
M('-T<FEN9R!V86QU92`H;F%M92D@;V8@=&AE(&]P8V]D92!F;W(@=&AE($1.
M4R!P86-K970N"B`@("`@*B\*("`@('9A<B`D;W!C;V1E.PH@("`@+RHJ"B`@
M("`@*B!4:&4@04$@*&%U=&AO<FET871I=F4@86YS=V5R*2!B:70@:6X@82!$
M3E,@<&%C:V5T(&AE861E<@H@("`@("H*("`@("`J(%1H92!!02!B:70@87,@
M9&5S8W)I8F5D(&EN(%)&0S$P,S4N("!!02!I<R!S970@=&\@(#$@:68@=&AE
M(&%N<W=E<@H@("`@("H@:7,@875T:&]R:71A=&EV92X@($ET(&AA<R!N;R!M
M96%N:6YG(&EF(%%2(&ES('-E="!T;R`P+@H@("`@("HO"B`@("!V87(@)&%A
M.PH@("`@+RHJ"B`@("`@*B!4:&4@5$,@*'1R=6YC871E9"D@8FET(&EN(&$@
M1$Y3('!A8VME="!H96%D97(*("`@("`J"B`@("`@*B!4:&ES(&9L86<@:7,@
M<V5T('1O(#$@:68@=&AE(')E<W!O;G-E('=A<R!T<G5N8V%T960N("!4:&ES
M(&9L86<@:&%S"B`@("`@*B!N;R!M96%N:6YG(&EN(&$@<75E<GD@<&%C:V5T
M+@H@("`@("HO"B`@("!V87(@)'1C.PH@("`@+RHJ"B`@("`@*B!4:&4@4D0@
M*')E8W5R<VEO;B!D97-I<F5D*2!B:70@:6X@82!$3E,@<&%C:V5T(&AE861E
M<@H@("`@("H*("`@("`J(%1H:7,@8FET('-H;W5L9"!B92!S970@=&\@,2!I
M;B!A('%U97)Y(&EF(')E8W5R<VEO;B`@:7,@9&5S:7)E9"!B>0H@("`@("H@
M=&AE($1.4R!S97)V97(N"B`@("`@*B\*("`@('9A<B`D<F0["B`@("`O*BH*
M("`@("`J(%1H92!202`H<F5C=7)S:6]N(&%V86EL86)L92D@8FET(&EN(&$@
M1$Y3('!A8VME="!H96%D97(*("`@("`J"B`@("`@*B!4:&ES(&)I="!I<R!S
M970@=&\@,2!B>2!T:&4@1$Y3('-E<G9E<B!I9B!T:&4@<V5R=F5R(&ES('=I
M;&QI;F<@=&\*("`@("`J('!E<F9O<FT@<F5C=7)S:6]N+@H@("`@("HO"B`@
M("!V87(@)')A.PH@("`@+RHJ"B`@("`@*B!4:&4@4D-/1$4@;F%M92!F;W(@
M=&AI<R!P86-K970N"B`@("`@*@H@("`@("H@5&AE('-T<FEN9R!V86QU92`H
M;F%M92D@;V8@=&AE(')C;V1E(&9O<B!T:&4@1$Y3('!A8VME="X*("`@("`J
M+PH@("`@=F%R("1R8V]D93L*("`@("\J*@H@("`@("H@3G5M8F5R(&]F('%U
M97-T:6]N<R!C;VYT86EN960@=VET:&EN('1H92!P86-K970*("`@("`J"B`@
M("`@*B`Q-F)I="!I;G1E9V5R(')E<')E<V5N=&EN9R!T:&4@;G5M8F5R(&]F
M('%U97-T:6]N<R!I;B!T:&4@<75E<W1I;VX*("`@("`J('-E8W1I;VX@;V8@
M=&AE($1.4R!P86-K970N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R("1Q
M9&-O=6YT"B`@("`@*B!`<V5E("`@("!.971?1$Y37U%U97-T:6]N(&-L87-S
M"B`@("`@*B\*("`@('9A<B`D<61C;W5N=#L*("`@("\J*@H@("`@("H@3G5M
M8F5R(&]F(&%N<W=E<B!24G,@8V]N=&%I;F5D('=I=&AI;B!T:&4@<&%C:V5T
M"B`@("`@*@H@("`@("H@,39B:70@:6YT96=E<B!R97!R97-E;G1I;F<@=&AE
M(&YU;6)E<B!O9B!A;G-W97(@<F5S;W5R8V4@<F5C;W)D<PH@("`@("H@8V]N
M=&%I;F5D(&EN('1H92!A;G-W97(@<V5C=&EO;B!O9B!T:&4@1$Y3('!A8VME
M="X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(@)&%N8V]U;G0*("`@("`J
M($!S964@("`@($YE=%]$3E-?4E(@8VQA<W,*("`@("`J+PH@("`@=F%R("1A
M;F-O=6YT.PH@("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@875T:&]R:71Y(%)2
M<R!W:71H:6X@=&AE('!A8VME=`H@("`@("H*("`@("`J(#$V8FET(&EN=&5G
M97(@<F5P<F5S96YT:6YG('1H92!N=6UB97(@;V8@875T:&]R:71Y("A.4RD@
M<F5S;W5R8V4*("`@("`J(')E8V]R9',@(&-O;G1A:6YE9"!I;B!T:&4@875T
M:&]R:71Y('-E8W1I;VX@;V8@=&AE($1.4R!P86-K970N"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R("1N<V-O=6YT"B`@("`@*B!`<V5E("`@("!.971?
M1$Y37U)2(&-L87-S"B`@("`@*B\*("`@('9A<B`D;G-C;W5N=#L*("`@("\J
M*@H@("`@("H@3G5M8F5R(&]F(&%D9&ET:6]N86P@4E)S('=I=&AI;B!T:&4@
M<&%C:V5T"B`@("`@*@H@("`@("H@,39B:70@:6YT96=E<B!R97!R97-E;G1I
M;F<@=&AE(&YU;6)E<B!O9B!A9&1I=&EO;F%L(')E<V]U<F-E(')E8V]R9',*
M("`@("`J(&-O;G1A:6YE9"!I;B!T:&4@861D:71I;VYA;"!S96-T:6]N(&]F
M('1H92!$3E,@<&%C:V5T+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<B`D
M87)C;W5N=`H@("`@("H@0'-E92`@("`@3F5T7T1.4U]24B!C;&%S<PH@("`@
M("HO"B`@("!V87(@)&%R8V]U;G0["@H@("`@+RH@?7U]("HO"B`@("`O*B!C
M;&%S<R!C;VYS=')U8W1O<B`M($YE=%]$3E-?2&5A9&5R*"1D871A(#T@(B(I
M('M[>R`J+PH@("`@+RHJ"B`@("`@*B!);FET:6%L:7IE<R!T:&4@9&5F875L
M="!V86QU97,@9F]R('1H92!(96%D97(@;V)J96-T+@H@("`@("H@"B`@("`@
M*B!"=6EL9',@82!H96%D97(@;V)J96-T(&9R;VT@96ET:&5R(&1E9F%U;'0@
M=F%L=65S+"!O<B!F<F]M(&$@1$Y3"B`@("`@*B!P86-K970@<&%S<V5D(&EN
M=&\@=&AE(&-O;G-T<G5C=&]R(&%S("1D871A"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&%T82`@02!$3E,@<&%C:V5T(&]F('=H:6-H('1H92!H
M96%D97(@=VEL;"!B92!P87)S960N"B`@("`@*B!`<F5T=7)N("!O8FIE8W0@
M($YE=%]$3E-?2&5A9&5R"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!.971?1$Y37TAE861E<B@D9&%T82`]("<G*0H@("`@
M>PH@("`@("`@(&EF("@D9&%T82`A/2`G)RD@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!4:&4@:&5A9&5R($U54U0@8F4@870@;&5A<W0@,3(@
M8GET97,N"B`@("`@("`@("`@("`J(%!A<W-I;F<@=&AE(&9U;&P@9&%T86=R
M86T@=&\@=&AI<R!C;VYS=')U8W1O<@H@("`@("`@("`@("`@*B!W:6QL(&5X
M86UI;F4@;VYL>2!T:&4@:&5A9&5R('-E8W1I;VX@;V8@=&AE($1.4R!P86-K
M970*("`@("`@("`@("`@("HO"B`@("`@("`@("`@(&EF("AS=')L96XH)&1A
M=&$I(#P@,3(I"B`@("`@("`@("`@("`@("!R971U<FXH,"D["@H@("`@("`@
M("`@("`D82`]('5N<&%C:R@G;FED+T,R9FQA9W,O;C1C;W5N=',G+"`D9&%T
M82D["B`@("`@("`@("`@("1T:&ES+3YI9"`@("`@(#T@)&%;)VED)UT["B`@
M("`@("`@("`@("1T:&ES+3YQ<B`@("`@(#T@*"1A6R=F;&%G<S$G72`^/B`W
M*2`F(#!X,3L*("`@("`@("`@("`@)'1H:7,M/F]P8V]D92`@/2`H)&%;)V9L
M86=S,2==(#X^(#,I("8@,'AF.PH@("`@("`@("`@("`D=&AI<RT^86$@("`@
M("`]("@D85LG9FQA9W,Q)UT@/CX@,BD@)B`P>#$["B`@("`@("`@("`@("1T
M:&ES+3YT8R`@("`@(#T@*"1A6R=F;&%G<S$G72`^/B`Q*2`F(#!X,3L*("`@
M("`@("`@("`@)'1H:7,M/G)D("`@("`@/2`D85LG9FQA9W,Q)UT@)B`P>#$[
M"B`@("`@("`@("`@("1T:&ES+3YR82`@("`@(#T@*"1A6R=F;&%G<S(G72`^
M/B`W*2`F(#!X,3L*("`@("`@("`@("`@)'1H:7,M/G)C;V1E("`@/2`D85LG
M9FQA9W,R)UT@)B`P>&8["B`@("`@("`@("`@("1T:&ES+3YQ9&-O=6YT(#T@
M)&%;)V-O=6YT<S$G73L*("`@("`@("`@("`@)'1H:7,M/F%N8V]U;G0@/2`D
M85LG8V]U;G1S,B==.PH@("`@("`@("`@("`D=&AI<RT^;G-C;W5N="`]("1A
M6R=C;W5N=',S)UT["B`@("`@("`@("`@("1T:&ES+3YA<F-O=6YT(#T@)&%;
M)V-O=6YT<S0G73L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YI9"`@("`@(#T@3F5T7T1.4U]297-O;'9E<CHZ;F5X=&ED
M*"D["B`@("`@("`@("`@("1T:&ES+3YQ<B`@("`@(#T@,#L*("`@("`@("`@
M("`@)'1H:7,M/F]P8V]D92`@/2`P.PH@("`@("`@("`@("`D=&AI<RT^86$@
M("`@("`](#`["B`@("`@("`@("`@("1T:&ES+3YT8R`@("`@(#T@,#L*("`@
M("`@("`@("`@)'1H:7,M/G)D("`@("`@/2`Q.PH@("`@("`@("`@("`D=&AI
M<RT^<F$@("`@("`](#`["B`@("`@("`@("`@("1T:&ES+3YR8V]D92`@(#T@
M,#L*("`@("`@("`@("`@)'1H:7,M/G%D8V]U;G0@/2`Q.PH@("`@("`@("`@
M("`D=&AI<RT^86YC;W5N="`](#`["B`@("`@("`@("`@("1T:&ES+3YN<V-O
M=6YT(#T@,#L*("`@("`@("`@("`@)'1H:7,M/F%R8V]U;G0@/2`P.PH@("`@
M("`@('T*"B`@("`@("`@:68@*$YE=%]$3E,Z.F]P8V]D97-B>79A;"@D=&AI
M<RT^;W!C;V1E*2D@>PH@("`@("`@("`@("`D=&AI<RT^;W!C;V1E(#T@3F5T
M7T1.4SHZ;W!C;V1E<V)Y=F%L*"1T:&ES+3YO<&-O9&4I.PH@("`@("`@('T*
M("`@("`@("!I9B`H3F5T7T1.4SHZ<F-O9&5S8GEV86PH)'1H:7,M/G)C;V1E
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<F-O9&4@/2!.971?1$Y3.CIR8V]D
M97-B>79A;"@D=&AI<RT^<F-O9&4I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*B!]?7T@*B\*("`@("\J($YE=%]$3E-?2&5A9&5R.CID:7-P;&%Y*"D@>WM[
M("HO"B`@("`O*BH*("`@("`J($1I<W!L87ES('1H92!P<F]P97)T:65S(&]F
M('1H92!H96%D97(N"B`@("`@*@H@("`@("H@1&ES<&QA>7,@=&AE('!R;W!E
M<G1I97,@;V8@=&AE(&AE861E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@
M("`@("!E8VAO("1T:&ES+3YS=')I;F<H*3L*("`@('T*"B`@("`O*B!]?7T@
M*B\*("`@("\J($YE=%]$3E-?2&5A9&5R.CIS=')I;F<H*2![>WL@*B\*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(&9O<FUA='1E9"!S=')I;F<@8V]N=&%I
M;FEN9R!T:&4@<')O<&5R=&EE<R!O9B!T:&4@:&5A9&5R+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("`@82!F;W)M871T960@<W1R:6YG(&-O;G1A
M:6YI;F<@=&AE('!R;W!E<G1I97,@;V8@=&AE(&AE861E<BX*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<FEN9R@I"B`@
M("!["B`@("`@("`@)')E='9A;"`]("<[.R!I9"`]("<@+B`D=&AI<RT^:60@
M+B`B7&XB.PH@("`@("`@(&EF("@D=&AI<RT^;W!C;V1E(#T]("=54$1!5$4G
M*2!["B`@("`@("`@("`@("1R971V86P@+CT@)SL[('%R(#T@)R`N("1T:&ES
M+3YQ<B`N("<@("`@)R`N"B`@("`@("`@("`@("`@("`G;W!C;V1E(#T@)R`N
M("1T:&ES+3YO<&-O9&4@+B`G("`@("<@("`N"B`@("`@("`@("`@("`@("`G
M<F-O9&4@/2`G("X@)'1H:7,M/G)C;V1E("X@(EQN(CL*("`@("`@("`@("`@
M)')E='9A;"`N/2`G.SL@>F]C;W5N="`]("<@+B`D=&AI<RT^<61C;W5N="`N
M("<@("<@+B`@"B`@("`@("`@("`@("`@("`G<')C;W5N="`]("<@+B`D=&AI
M<RT^86YC;W5N="`N("<@("<@("`@("`@("`@("X*("`@("`@("`@("`@("`@
M("=U<&-O=6YT(#T@)R`N("1T:&ES+3YN<V-O=6YT("X@)R`@)R`@("`@("`@
M("`@+@H@("`@("`@("`@("`@("`@)V%D8V]U;G0@/2`G("X@)'1H:7,M/F%R
M8V]U;G0@+B`B7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M971V86P@+CT@)SL[('%R(#T@)R`N("1T:&ES+3YQ<B`N("<@("`@)R`N"B`@
M("`@("`@("`@("`@("`G;W!C;V1E(#T@)R`N("1T:&ES+3YO<&-O9&4@+B`G
M("`@("<@("`N"B`@("`@("`@("`@("`@("`G86$@/2`G("X@)'1H:7,M/F%A
M("X@)R`@("`G("`@("`@("`@("`N"B`@("`@("`@("`@("`@("`G=&,@/2`G
M("X@)'1H:7,M/G1C("X@)R`@("`G("`@("`@("`@("`N"B`@("`@("`@("`@
M("`@("`G<F0@/2`G("X@)'1H:7,M/G)D("X@(EQN(CL*"B`@("`@("`@("`@
M("1R971V86P@+CT@)SL[(')A(#T@)R`N("1T:&ES+3YR82`N("<@("`@)R`N
M"B`@("`@("`@("`@("`@("`G<F-O9&4@(#T@)R`N("1T:&ES+3YR8V]D92`N
M(")<;B(["@H@("`@("`@("`@("`D<F5T=F%L("X]("<[.R!Q9&-O=6YT(#T@
M)R`N("1T:&ES+3YQ9&-O=6YT("X@)R`@)R`N"B`@("`@("`@("`@("`@("`G
M86YC;W5N="`]("<@+B`D=&AI<RT^86YC;W5N="`N("<@("<@("`@+@H@("`@
M("`@("`@("`@("`@)VYS8V]U;G0@/2`G("X@)'1H:7,M/FYS8V]U;G0@+B`G
M("`G("`@("X*("`@("`@("`@("`@("`@("=A<F-O=6YT(#T@)R`N("1T:&ES
M+3YA<F-O=6YT("X@(EQN(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N*"1R
M971V86PI.PH@("`@?0H*("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U](
M96%D97(Z.F1A=&$H*2![>WL@*B\*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@8FEN87)Y(&1A=&$@8V]N=&%I;FEN9R!T:&4@<')O<&5R=&EE<R!O9B!T
M:&4@:&5A9&5R"B`@("`@*@H@("`@("H@4&%C:W,@=&AE('!R;W!E<G1I97,@
M;V8@=&AE($AE861E<B!O8FIE8W0@:6YT;R!A(&)I;F%R>2!S=')I;F<*("`@
M("`J('-U:71A8FQE(&9O<B!U<VEN9R!A<R!T:&4@2&5A9&5R('-E8W1I;VX@
M;V8@82!$3E,@<&%C:V5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("`@8FEN87)Y(')E<')E<V5N=&%T:6]N(&]F('1H92!H96%D97(@;V)J96-T
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!D
M871A*"D*("`@('L*("`@("`@("`D;W!C;V1E(#T@3F5T7T1.4SHZ;W!C;V1E
M<V)Y;F%M92@D=&AI<RT^;W!C;V1E*3L*("`@("`@("`D<F-O9&4@(#T@3F5T
M7T1.4SHZ<F-O9&5S8GEN86UE*"1T:&ES+3YR8V]D92D["@H@("`@("`@("1B
M>71E,B`]("@D=&AI<RT^<7(@/#P@-RD*("`@("`@("`@("`@?"`H)&]P8V]D
M92`\/"`S*0H@("`@("`@("`@("!\("@D=&AI<RT^86$@/#P@,BD*("`@("`@
M("`@("`@?"`H)'1H:7,M/G1C(#P\(#$I"B`@("`@("`@("`@('P@*"1T:&ES
M+3YR9"D["@H@("`@("`@("1B>71E,R`]("@D=&AI<RT^<F$@/#P@-RD@?"`D
M<F-O9&4["@H@("`@("`@(')E='5R;B!P86-K*"=N0S)N-"<L("1T:&ES+3YI
M9"P*("`@("`@("`@("`@("`@("1B>71E,BP*("`@("`@("`@("`@("`@("1B
M>71E,RP*("`@("`@("`@("`@("`@("1T:&ES+3YQ9&-O=6YT+`H@("`@("`@
M("`@("`@("`@)'1H:7,M/F%N8V]U;G0L"B`@("`@("`@("`@("`@("`D=&AI
M<RT^;G-C;W5N="P*("`@("`@("`@("`@("`@("1T:&ES+3YA<F-O=6YT*3L*
M("`@('T*"B`@("`O*B!]?7T@*B\*?0HO*B!]?7T@*B\*+RH@5DE-('-E='1I
M;F=S('M[>PH@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@
M*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!S;V9T+7-T;W`M=VED=&@Z(#0*("H@
M8R!I;F1E;G0@;VX*("H@97AP86YD=&%B(&]N"B`J($5N9#H*("H@=FEM-C`P
M.B!S=STT('1S/30@<W1S/30@8VEN9&5N="!F9&T];6%R:V5R(&5T"B`J('9I
M;3PV,#`Z('-W/30@=',]-`H@*B!]?7T@*B\*/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+TYE="]$3E,O4&%C:V5T+G!H<```````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#4Q,S(S`#$P-#$W,S8S,#`V`#`R,#0S-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*@H@*B`@3&EC96YS92!);F9O<FUA=&EO;CH*("H*("H@("`@3F5T7T1.4SH@
M($$@<F5S;VQV97(@;&EB<F%R>2!F;W(@4$A0"B`J("`@($-O<'ER:6=H="`H
M8RD@,C`P,BTR,#`S($5R:6,@2VEL9F]I;"!E<FEC0'EP87-S+FYE=`H@*@H@
M*B`@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R
M961I<W1R:6)U=&4@:70@86YD+V]R"B`J("`@(&UO9&EF>2!I="!U;F1E<B!T
M:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("H@
M("`@3&EC96YS92!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@
M1F]U;F1A=&EO;CL@96ET:&5R"B`J("`@('9E<G-I;VX@,BXQ(&]F('1H92!,
M:6-E;G-E+"!O<B`H870@>6]U<B!O<'1I;VXI(&%N>2!L871E<B!V97)S:6]N
M+@H@*@H@*B`@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE
M(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("H@("`@8G5T(%=)5$A/
M550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R
M<F%N='D@;V8*("H@("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("H@("`@3&5S
M<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*
M("H*("H@("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T
M:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@*B`@("!,:6-E;G-E(&%L
M;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&
M<F5E(%-O9G1W87)E"B`J("`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L
M92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL($U!("`P,C$Q,2TQ,S`W("!5
M4T$*("HO"@HO*B!.971?1$Y37U!A8VME="!O8FIE8W0@9&5F:6YI=&EO;B![
M>WL@*B\*+RHJ"B`J($$@;V)J96-T(')E<')E<V%T:6]N(&]F(&$@1$Y3('!A
M8VME="`H4D9#,3`S-2D*("H*("H@5&AI<R!O8FIE8W0@:7,@=7-E9"!T;R!M
M86YA9V4@82!$3E,@<&%C:V5T+B`@270@8V]N=&%I;G,@;65T:&]D<R!F;W(*
M("H@1$Y3('!A8VME="!C;VUP<F5S<VEO;B!A<R!D969I;F5D(&EN(%)&0S$P
M,S4L(&%S('=E;&P@87,@<&%R<VEN9R`@82!$3E,*("H@<&%C:V5T(')E<W!O
M;G-E(&9R;VT@82!$3E,@<V5R=F5R+"!O<B!B=6EL9&EN9R!A($1.4R!P86-K
M970@9G)O;2`@=&AE"B`J(&EN<W1A;F-E('9A<FEA8FQE<R!C;VYT86EN960@
M:6X@=&AE(&-L87-S+@H@*@H@*B!`<&%C:V%G92!.971?1$Y3"B`J+PIC;&%S
M<R!.971?1$Y37U!A8VME=`I["B`@("`O*B!C;&%S<R!V87)I86)L92!D969I
M;FET:6]N<R![>WL@*B\*("`@("\J*@H@("`@("H@9&5B=6=G:6YG(&9L86<*
M("`@("`J"B`@("`@*B!)9B!S970@=&\@5%)512`H;F]N+7IE<F\I+"!D96)U
M9V=I;F<@8V]D92!W:6QL(&)E(&1I<W!L87EE9"!A<R!T:&4*("`@("`J('!A
M8VME="!I<R!P87)S960N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N("1D
M96)U9PH@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D
M9&5B=6<["B`@("`O*BH*("`@("`J($$@<&%C:V5T($AE861E<B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@06X@;V)J96-T(&]F('1Y<&4@3F5T7T1.4U](96%D
M97(@=VAI8V@@8V]N=&%I;G,@=&AE(&AE861E<@H@("`@("H@:6YF;W)M871I
M;VX@(&]F('1H92!P86-K970N"B`@("`@*@H@("`@("H@0'9A<B!O8FIE8W0@
M3F5T7T1.4U](96%D97(@)&AE861E<@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B\*("`@('9A<B`D:&5A9&5R.PH@("`@+RHJ"B`@("`@*B!!(&AA
M<V@@;V8@8V]M<')E<W-E9"!L86)E;',*("`@("`J"B`@("`@*B!!(&QI<W0@
M;V8@86QL(&QA8F5L<R!W:&EC:"!H879E(&)E96X@8V]M<')E<W-E9"!I;B!T
M:&4@1$Y3('!A8VME=`H@("`@("H@86YD("!T:&4@;&]C871I;VX@;V9F<V5T
M(&]F('1H92!L86)E;"!W:71H:6X@=&AE('!A8VME="X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y("`@)&-O;7!N86UE<PH@("`@("HO"B`@("!V87(@)&-O
M;7!N86UE<SL*("`@("\J*@H@("`@("H@5&AE(&]R:6=I;B!O9B!T:&4@<&%C
M:V5T+"!I9B!T:&4@<&%C:V5T(&ES(&$@<V5R=F5R(')E<W!O;G-E+@H@("`@
M("H*("`@("`J(%1H:7,@8V]N=&%I;G,@82!S=')I;F<@8V]N=&%I;FEN9R!T
M:&4@25`@861D<F5S<R!O9B!T:&4@;F%M92!S97)V97(*("`@("`J(&9R;VT@
M=VAI8V@@=&AE(&%N<W=E<B!W87,@9VEV96XN"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<@("1A;G-W97)F<F]M"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J+PH@("`@=F%R("1A;G-W97)F<F]M.PH@("`@+RHJ"B`@("`@*B!4
M:&4@<VEZ92!O9B!T:&4@86YS=V5R('!A8VME="P@:68@=&AE('!A8VME="!I
M<R!A('-E<G9E<B!R97-P;VYS92X*("`@("`J"B`@("`@*B!4:&ES(&-O;G1A
M:6YS(&$@:6YT96=E<B!C;VYT86EN:6YG('1H92!S:7IE(&]F('1H92!$3E,@
M<&%C:V5T('1H90H@("`@("H@<V5R=F5R(')E<W!O;F1E9"!W:71H(&EF('1H
M:7,@<&%C:V5T('=A<R!R96-E:79E9"!B>2!A($1.4R!S97)V97(*("`@("`J
M('5S:6YG('1H92!Q=65R>2@I(&UE=&AO9"X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9R`@)&%N<W=E<G-I>F4*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("HO"B`@("!V87(@)&%N<W=E<G-I>F4["B`@("`O*BH*("`@("`J($%N
M(&%R<F%Y(&]F($YE=%]$3E-?475E<W1I;VX@;V)J96-T<PH@("`@("H*("`@
M("`J($-O;G1A:6YS(&%L;"!O9B!T:&4@<75E<W1I;VYS('=I=&AI;B!T:&4@
M<&%C:V5T+B`@16%C:"!Q=65S=&EO;B!I<PH@("`@("H@<W1O<F5D(&%S(&%N
M(&]B:F5C="!O9B!T>7!E($YE=%]$3E-?475E<W1I;VXN"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>2`@("1Q=65S=&EO;@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B\*("`@('9A<B`D<75E<W1I;VX["B`@("`O*BH*("`@("`J
M($%N(&%R<F%Y(&]F($YE=%]$3E-?4E(@04Y35T52(&]B:F5C=',*("`@("`J
M"B`@("`@*B!#;VYT86EN<R!A;&P@;V8@=&AE(&%N<W=E<B!24G,@=VET:&EN
M('1H92!P86-K970N("!%86-H(&%N<W=E<B!I<PH@("`@("H@<W1O<F5D(&%S
M(&%N(&]B:F5C="!O9B!T>7!E($YE=%]$3E-?4E(N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>2`@("1A;G-W97(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("HO"B`@("!V87(@)&%N<W=E<CL*("`@("\J*@H@("`@("H@06X@87)R
M87D@;V8@3F5T7T1.4U]24B!!551(3U))5%D@;V)J96-T<PH@("`@("H*("`@
M("`J($-O;G1A:6YS(&%L;"!O9B!T:&4@875T:&]R:71Y(%)2<R!W:71H:6X@
M=&AE('!A8VME="X@($5A8V@@875T:&]R:71Y(&ES"B`@("`@*B!S=&]R960@
M87,@86X@;V)J96-T(&]F('1Y<&4@3F5T7T1.4U]24BX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y("`@)&%U=&AO<FET>0H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B\*("`@('9A<B`D875T:&]R:71Y.PH@("`@+RHJ"B`@("`@
M*B!!;B!A<G)A>2!O9B!.971?1$Y37U)2($%$1$E424].04P@;V)J96-T<PH@
M("`@("H*("`@("`J($-O;G1A:6YS(&%L;"!O9B!T:&4@861D:71I;VYA;"!2
M4G,@=VET:&EN('1H92!P86-K970N("!%86-H(&%D9&ET:6]N86P@:7,*("`@
M("`J('-T;W)E9"!A<R!A;B!O8FIE8W0@;V8@='EP92!.971?1$Y37U)2+@H@
M("`@("H*("`@("`J($!V87(@87)R87D@("`D861D:71I;VYA;`H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D861D:71I;VYA;#L*
M"B`@("`O*B!]?7T@*B\*("`@("\J(&-L87-S(&-O;G-T<G5C=&]R("T@3F5T
M7T1.4U]086-K970H)&1E8G5G(#T@1D%,4T4I('M[>R`J+PH@("`@+RH*("`@
M("`J('5N9F]R='5N871E;'D@*&]R(&9O<G1U;F%T96QY*2P@=V4@8V%N)W0@
M9F]L;&]W('1H92!S86UE"B`@("`@*B!S:6QL>2!M971H;V0@9F]R(&1E=&5R
M;6EN:6YG(&EF(&YA;64@:7,@82!H;W-T;F%M92!O<B!A('!A8VME=`H@("`@
M("H@<W1R96%M(&EN(%!(4"P@<VEN8V4@=&AE<F4@:7,@;F\@<F5F*"D@9G5N
M8W1I;VXN("!3;R!W92=R92!G;VEN9PH@("`@("H@=&\@9&5F:6YE(&$@;F5W
M(&UE=&AO9"!C86QL960@<&%R<V4@=&\@9&5A;"!W:71H('1H:7,*("`@("`J
M(&-I<F-U;7-T86YC92!A;F0@86YO=&AE<B!M971H;V0@8V%L;&5D(&)U:6QD
M475E<W1I;VX@=&\@8G5I;&0@82!Q=65S=&EO;BX*("`@("`J($D@;&EK92!I
M="!B971T97(@=&AA="!W87D@86YY=V%Y+@H@("`@("HO"B`@("`O*BH*("`@
M("`J($EN:71A;&EZ97,@82!.971?1$Y37U!A8VME="!O8FIE8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5B=6<@5'5R;G,@9&5B=6=G:6YG
M(&]N(&]R(&]F9@H@("`@("HO"B`@("!F=6YC=&EO;B!.971?1$Y37U!A8VME
M="@D9&5B=6<@/2!&04Q312D*("`@('L*("`@("`@("`D=&AI<RT^9&5B=6<@
M/2`D9&5B=6<["B`@("`@("`@)'1H:7,M/F-O;7!N86UE<R`](&%R<F%Y*"D[
M"B`@("!]"@H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y37U!A8VME=#HZ
M8G5I;&11=65S=&EO;B@D;F%M92P@)'1Y<&4@/2`B02(L("1C;&%S<R`]("))
M3B(I('M[>R`J+PH@("`@+RHJ"B`@("`@*B!!9&1S(&$@1$Y3('%U97-T:6]N
M('1O('1H92!$3E,@<&%C:V5T"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("1N86UE("`@(%1H92!N86UE(&]F('1H92!R96-O<F0@=&\@<75E<GD*
M("`@("`J($!P87)A;2`@('-T<FEN9R`D='EP92`@("!4:&4@='EP92!O9B!R
M96-O<F0@=&\@<75E<GD*("`@("`J($!P87)A;2`@('-T<FEN9R`D8VQA<W,@
M("!4:&4@8VQA<W,@;V8@<F5C;W)D('1O('%U97)Y"B`@("`@*B!`<V5E($YE
M=%]$3E,Z.G1Y<&5S8GEN86UE*"DL($YE=%]$3E,Z.F-L87-S97-B>6YA;64H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9%%U97-T:6]N*"1N86UE+"`D
M='EP92`]("=!)RP@)&-L87-S(#T@)TE.)RD*("`@('L*("`@("`@("`D=&AI
M<RT^:&5A9&5R(#T@;F5W($YE=%]$3E-?2&5A9&5R*"D["B`@("`@("`@)'1H
M:7,M/FAE861E<BT^<61C;W5N="`](#$["B`@("`@("`@)'1H:7,M/G%U97-T
M:6]N6S!=(#T@;F5W($YE=%]$3E-?475E<W1I;VXH)&YA;64L("1T>7!E+"`D
M8VQA<W,I.PH@("`@("`@("1T:&ES+3YA;G-W97(@/2!.54Q,.PH@("`@("`@
M("1T:&ES+3YA=71H;W)I='D@/2!.54Q,.PH@("`@("`@("1T:&ES+3YA9&1I
M=&EO;F%L(#T@3E5,3#L*("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@
M("`@("`@("`@("1T:&ES+3YD:7-P;&%Y*"D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J('U]?2`J+PH@("`@+RH@3F5T7T1.4U]086-K970Z.G!A<G-E*"1D
M871A*2![>WL@*B\*("`@("\J*@H@("`@("H@4&%R<V5S(&$@1$Y3('!A8VME
M="!R971U<FYE9"!B>2!A($1.4R!S97)V97(*("`@("`J"B`@("`@*B!087)S
M97,@82!C;VUP;&5T92!$3E,@<&%C:V5T(&%N9"!B=6EL9',@86X@;V)J96-T
M(&AI97)A<F-H>0H@("`@("H@8V]N=&%I;FEN9R!A;&P@;V8@=&AE('!A<G1S
M(&]F('1H92!P86-K970Z"B`@("`@*B`\=6P^"B`@("`@*B`@(#QL:3Y(14%$
M15(@("`*("`@("`J("`@/&QI/E%515-424].("`@"B`@("`@*B`@(#QL:3Y!
M3E-715(@?'P@4%)%4D5154E3251%("`@"B`@("`@*B`@(#QL:3Y!1$1)5$E/
M3D%,('Q\(%501$%412`@(`H@("`@("H@("`\;&D^05542$]22519"B`@("`@
M*B`\+W5L/@H@("`@("H@"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("!!
M(&)I;F%R>2!S=')I;F<@8V]N=&%I;FEN9R!A($1.4R!P86-K970*("`@("`J
M($!R971U<FX@8F]O;&5A;B!44E5%(&]N('-U8V-E<W,L($Y53$P@;VX@<&%R
M<V5R(&5R<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E*"1D871A*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@
M96-H;R`G.SL@2$5!1$52(%-%0U1)3TXG("X@(EQN(CL*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YH96%D97(@/2!N97<@3F5T7T1.4U](96%D97(H)&1A
M=&$I.PH*("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@("`@("`@
M("1T:&ES+3YH96%D97(M/F1I<W!L87DH*3L*("`@("`@("!]"@H@("`@("`@
M("\J"B`@("`@("`@("H@(%!R:6YT(&%N9"!P87)S92!T:&4@455%4U1)3TX@
M<V5C=&EO;B!O9B!T:&4@<&%C:V5T"B`@("`@("`@("HO"B`@("`@("`@:68@
M*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("!E8VAO(")<;B(["B`@("`@
M("`@("`@("1S96-T:6]N(#T@*"1T:&ES+3YH96%D97(M/F]P8V]D92`@/3T@
M)U501$%412<I(#\@)UI/3D4G(#H@)U%515-424].)SL*("`@("`@("`@("`@
M96-H;R`B.SL@)'-E8W1I;VX@4T5#5$E/3B`H(B`N("1T:&ES+3YH96%D97(M
M/G%D8V]U;G0@+B`G(')E8V]R9"<@+@H@("`@("`@("`@("`@("`@*"1T:&ES
M+3YH96%D97(M/G%D8V]U;G0@/3T@,2`_("<G(#H@)W,G*2`N("(I7&XB.PH@
M("`@("`@('T*"B`@("`@("`@)&]F9G-E="`](#$R.PH*("`@("`@("`D=&AI
M<RT^<75E<W1I;VX@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)&-T<B`](#`[
M("1C='(@/"`D=&AI<RT^:&5A9&5R+3YQ9&-O=6YT.R`D8W1R*RLI('L*("`@
M("`@("`@("`@;&ES="@D<6]B:BP@)&]F9G-E="D@/2`D=&AI<RT^<&%R<V5?
M<75E<W1I;VXH)&1A=&$L("1O9F9S970I.PH@("`@("`@("`@("!I9B`H:7-?
M;G5L;"@D<6]B:BDI('L*("`@("`@("`@("`@("`@(')E='5R;BA.54Q,*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/G%U97-T:6]N6V-O
M=6YT*"1T:&ES+3YQ=65S=&EO;BE=(#T@)'%O8FH["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@(&5C:&\@(CL[7&X[
M(CL*("`@("`@("`@("`@("`@("1Q;V)J+3YD:7-P;&%Y*"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@(%!R:6YT
M(&%N9"!P87)S92!T:&4@4%)%4D5154E3251%(&]R($%.4U=%4B`@<V5C=&EO
M;B!O9B!T:&4@<&%C:V5T"B`@("`@("`@("HO"B`@("`@("`@:68@*"1T:&ES
M+3YD96)U9RD@>PH@("`@("`@("`@("!E8VAO(")<;B(["B`@("`@("`@("`@
M("1S96-T:6]N(#T@*"1T:&ES+3YH96%D97(M/F]P8V]D92`]/2`G55!$051%
M)RD@/R`G4%)%4D5154E3251%)R`Z)T%.4U=%4B<["B`@("`@("`@("`@(&5C
M:&\@(CL[("1S96-T:6]N(%-%0U1)3TX@*"(@+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/FAE861E<BT^86YC;W5N="`N("<@<F5C;W)D)R`N"B`@("`@("`@
M("`@("`@("`H*"1T:&ES+3YH96%D97(M/F%N8V]U;G0@/3T@,2D@/R`G)R`Z
M("=S)RD@+@H@("`@("`@("`@("`@("`@(BE<;B(["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^86YS=V5R(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1C
M='(@/2`P.R`D8W1R(#P@)'1H:7,M/FAE861E<BT^86YC;W5N=#L@)&-T<BLK
M*2!["B`@("`@("`@("`@(&QI<W0H)')R;V)J+"`D;V9F<V5T*2`]("1T:&ES
M+3YP87)S95]R<B@D9&%T82P@)&]F9G-E="D["@H@("`@("`@("`@("!I9B`H
M:7-?;G5L;"@D<G)O8FHI*2!["B`@("`@("`@("`@("`@("!R971U<FXH3E5,
M3"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@87)R87E?<'5S:"@D=&AI
M<RT^86YS=V5R+"`D<G)O8FHI.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F1E
M8G5G*2!["B`@("`@("`@("`@("`@("`D<G)O8FHM/F1I<W!L87DH*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B`@
M4')I;G0@86YD('!A<G-E('1H92!54$1!5$4@;W(@05542$]22519('-E8W1I
M;VX@;V8@=&AE('!A8VME=`H@("`@("`@("`J+PH@("`@("`@(&EF("@D=&AI
M<RT^9&5B=6<I('L*("`@("`@("`@("`@96-H;R`B7&XB.PH@("`@("`@("`@
M("`D<V5C=&EO;B`]("@D=&AI<RT^:&5A9&5R+3YO<&-O9&4@/3T@)U501$%4
M12<I(#\@)U501$%412<@.B`G05542$]22519)SL*("`@("`@("`@("`@96-H
M;R`B.SL@)'-E8W1I;VX@4T5#5$E/3B`H(B`N"B`@("`@("`@("`@("`@("`D
M=&AI<RT^:&5A9&5R+3YN<V-O=6YT("X@)R!R96-O<F0G("X*("`@("`@("`@
M("`@("`@("@H)'1H:7,M/FAE861E<BT^;G-C;W5N="`]/2`Q*2`_("<G(#H@
M)W,G*2`N"B`@("`@("`@("`@("`@("`B*5QN(CL*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3YA=71H;W)I='D@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H
M)&-T<B`](#`[("1C='(@/"`D=&AI<RT^:&5A9&5R+3YN<V-O=6YT.R`D8W1R
M*RLI('L*("`@("`@("`@("`@;&ES="@D<G)O8FHL("1O9F9S970I(#T@)'1H
M:7,M/G!A<G-E7W)R*"1D871A+"`D;V9F<V5T*3L*"B`@("`@("`@("`@(&EF
M("AI<U]N=6QL*"1R<F]B:BDI('L*("`@("`@("`@("`@("`@(')E='5R;BA.
M54Q,*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G)A>5]P=7-H*"1T
M:&ES+3YA=71H;W)I='DL("1R<F]B:BD["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@("1R<F]B:BT^9&ES<&QA>2@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@
M("`J("!0<FEN="!A;F0@<&%R<V4@=&AE($%$1$E424].04P@<V5C=&EO;B!O
M9B!T:&4@<&%C:V5T"B`@("`@("`@("HO"B`@("`@("`@:68@*"1T:&ES+3YD
M96)U9RD@>PH@("`@("`@("`@("!E8VAO(")<;B(["B`@("`@("`@("`@(&5C
M:&\@)SL[($%$1$E424].04P@4T5#5$E/3B`H)R`N"B`@("`@("`@("`@("`@
M("`D=&AI<RT^:&5A9&5R+3YA<F-O=6YT("X@)R!R96-O<F0G("X*("`@("`@
M("`@("`@("`@("@H)'1H:7,M/FAE861E<BT^87)C;W5N="`]/2`Q*2`_("<G
M(#H@)W,G*2`N"B`@("`@("`@("`@("`@("`B*5QN(CL*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YA9&1I=&EO;F%L(#T@87)R87DH*3L*("`@("`@("!F
M;W(@*"1C='(@/2`P.R`D8W1R(#P@)'1H:7,M/FAE861E<BT^87)C;W5N=#L@
M)&-T<BLK*2!["B`@("`@("`@("`@(&QI<W0H)')R;V)J+"`D;V9F<V5T*2`]
M("1T:&ES+3YP87)S95]R<B@D9&%T82P@)&]F9G-E="D["@H@("`@("`@("`@
M("!I9B`H:7-?;G5L;"@D<G)O8FHI*2!["B`@("`@("`@("`@("`@("!R971U
M<FXH3E5,3"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@87)R87E?<'5S
M:"@D=&AI<RT^861D:71I;VYA;"P@)')R;V)J*3L*("`@("`@("`@("`@:68@
M*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@)')R;V)J+3YD:7-P
M;&%Y*"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;BA44E5%*3L*("`@('T*"B`@("`O*B!]?7T@*B\*("`@("\J($YE=%]$3E-?
M4&%C:V5T.CID871A*"D@>WM[*B\*("`@("\J*@H@("`@("H@0G5I;&0@82!P
M86-K970@9G)O;2!A(%!A8VME="!O8FIE8W0@:&EE<F%R8VAY"B`@("`@*@H@
M("`@("H@0G5I;&1S(&$@=F%L:60@1$Y3('!A8VME="!S=6ET86)L92!F;W(@
M<V5N9&EN9R!T;R!A($1.4R!S97)V97(@;W(*("`@("`J(')E<V]L=F5R(&-L
M:65N="!C;VYT86EN:6YG(&%L;"!O9B!T:&4@9&%T82!I;B!T:&4@<&%C:V5T
M(&AI97)A<F-H>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!!(&)I
M;F%R>2!S=')I;F<@8V]N=&%I;FEN9R!A($1.4R!086-K970*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&%T82@I"B`@("!["B`@("`@("`@)&1A=&$@/2`D=&AI
M<RT^:&5A9&5R+3YD871A*"D["@H@("`@("`@(&9O<B`H)&-T<B`](#`[("1C
M='(@/"`D=&AI<RT^:&5A9&5R+3YQ9&-O=6YT.R`D8W1R*RLI('L*("`@("`@
M("`@("`@)&1A=&$@+CT@)'1H:7,M/G%U97-T:6]N6R1C=')=+3YD871A*"1T
M:&ES+"!S=')L96XH)&1A=&$I*3L*("`@("`@("!]"@H@("`@("`@(&9O<B`H
M)&-T<B`](#`[("1C='(@/"`D=&AI<RT^:&5A9&5R+3YA;F-O=6YT.R`D8W1R
M*RLI('L*("`@("`@("`@("`@)&1A=&$@+CT@)'1H:7,M/F%N<W=E<ELD8W1R
M72T^9&%T82@D=&AI<RP@<W1R;&5N*"1D871A*2D["B`@("`@("`@?0H*("`@
M("`@("!F;W(@*"1C='(@/2`P.R`D8W1R(#P@)'1H:7,M/FAE861E<BT^;G-C
M;W5N=#L@)&-T<BLK*2!["B`@("`@("`@("`@("1D871A("X]("1T:&ES+3YA
M=71H;W)I='E;)&-T<ETM/F1A=&$H)'1H:7,L('-T<FQE;B@D9&%T82DI.PH@
M("`@("`@('T*"B`@("`@("`@9F]R("@D8W1R(#T@,#L@)&-T<B`\("1T:&ES
M+3YH96%D97(M/F%R8V]U;G0[("1C='(K*RD@>PH@("`@("`@("`@("`D9&%T
M82`N/2`D=&AI<RT^861D:71I;VYA;%LD8W1R72T^9&%T82@D=&AI<RP@<W1R
M;&5N*"1D871A*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FXH)&1A=&$I
M.PH@("`@?0H*("`@("\J?7U]*B\*("`@("\J($YE=%]$3E-?4&%C:V5T.CID
M;E]C;VUP*"1N86UE+"`D;V9F<V5T*2![>WLJ+PH@("`@+RHJ"B`@("`@*B!$
M3E,@<&%C:V5T(&-O;7!R97-S:6]N(&UE=&AO9`H@("`@("H*("`@("`J(%)E
M='5R;G,@82!D;VUA:6X@;F%M92!C;VUP<F5S<V5D(&9O<B!A('!A<G1I8W5L
M87(@<&%C:V5T(&]B:F5C="P@=&\*("`@("`J(&)E('-T;W)E9"!B96=I;FYI
M;F<@870@=&AE(&=I=F5N(&]F9G-E="!W:71H:6X@=&AE('!A8VME="!D871A
M+B`@5&AE"B`@("`@*B!N86UE('=I;&P@8F4@861D960@=&\@82!R=6YN:6YG
M(&QI<W0@;V8@8V]M<')E<W-E9"!D;VUA:6X@;F%M97,@9F]R"B`@("`@*B!F
M=71U<F4@=7-E+@H@("`@("H@"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N
M86UE("`@("`@(%1H92!N86UE(&]F('1H92!L86)E;"!T;R!C;VUP<F5S<PH@
M("`@("H@0'!A<F%M(&EN=&5G97(@("`D;V9F<V5T("`@("!4:&4@;&]C871I
M;VX@;V9F<V5T(&EN('1H92!P86-K970@=&\@=VAE<F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&QA8F5L('=I;&P@8F4@<W1O
M<F5D+@H@("`@("H@0')E='5R;B!S=')I;F<@("`D8V]M<&YA;64@("!!(&)I
M;F%R>2!S=')I;F<@8V]N=&%I;FEN9R!T:&4@8V]M<')E<W-E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L86)E;"X*("`@("`J($!S
M964@3F5T7T1.4U]086-K970Z.F1N7V5X<&%N9"@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1N7V-O;7`H)&YA;64L("1O9F9S970I"B`@("!["B`@("`@("`@
M)&YA;65S(#T@97AP;&]D92@G+B<L("1N86UE*3L*("`@("`@("`D8V]M<&YA
M;64@/2`G)SL*("`@("`@("!W:&EL92`H8V]U;G0H)&YA;65S*2D@>PH@("`@
M("`@("`@("`D9&YA;64@/2!J;VEN*"<N)RP@)&YA;65S*3L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YC;VUP;F%M97-;)&1N86UE72DI('L*("`@
M("`@("`@("`@("`@("1C;VUP;F%M92`N/2!P86-K*"=N)RP@,'AC,#`P('P@
M)'1H:7,M/F-O;7!N86UE<ULD9&YA;65=*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^8V]M<&YA
M;65S6R1D;F%M95T@/2`D;V9F<V5T.PH@("`@("`@("`@("`D9FER<W0@/2!A
M<G)A>5]S:&EF="@D;F%M97,I.PH@("`@("`@("`@("`D;&5N9W1H(#T@<W1R
M;&5N*"1F:7)S="D["B`@("`@("`@("`@("1C;VUP;F%M92`N/2!P86-K*"=#
M82HG+"`D;&5N9W1H+"`D9FER<W0I.PH@("`@("`@("`@("`D;V9F<V5T("L]
M("1L96YG=&@@*R`Q.PH@("`@("`@('T*("`@("`@("!I9B`H(2!C;W5N="@D
M;F%M97,I*2!["B`@("`@("`@("`@("1C;VUP;F%M92`N/2!P86-K*"=#)RP@
M,"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B@D8V]M<&YA;64I.PH@("`@
M?0H*("`@("\J?7U]*B\*("`@("\J($YE=%]$3E-?4&%C:V5T.CID;E]E>'!A
M;F0H)'!A8VME="P@)&]F9G-E="D@>WM[("HO"B`@("`O*BH*("`@("`J($1.
M4R!P86-K970@9&5C;VUP<F5S<VEO;B!M971H;V0*("`@("`J"B`@("`@*B!%
M>'!A;F1S('1H92!D;VUA:6X@;F%M92!S=&]R960@870@82!P87)T:6-U;&%R
M(&QO8V%T:6]N(&EN(&$@1$Y3"B`@("`@*B!P86-K970N("!4:&4@9FER<W0@
M87)G=6UE;G0@:7,@82!V87)I86)L92!C;VYT86EN:6YG("!T:&4@<&%C:V5T
M"B`@("`@*B!D871A+B`@5&AE('-E8V]N9"!A<F=U;65N="!I<R!T:&4@;V9F
M<V5T('=I=&AI;B!T:&4@('!A8VME="!W:&5R90H@("`@("H@=&AE("AP;W-S
M:6)L>2D@8V]M<')E<W-E9"!D;VUA:6X@;F%M92!I<R!S=&]R960N"B`@("`@
M*B`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)'!A8VME="!4:&4@<&%C:V5T
M(&1A=&$*("`@("`J($!P87)A;2`@(&EN=&5G97(@)&]F9G-E="!4:&4@;&]C
M871I;VX@;V9F<V5T(&EN('1H92!P86-K970@;V8@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@;&%B96P@=&\@9&5C;VUP<F5S<RX*("`@
M("`J($!R971U<FX@(&%R<F%Y("`@4F5T=7)N<R!A(&QI<W0@;V8@='EP92!A
M<G)A>2@D;F%M92P@)&]F9G-E="D@=VAE<F4*("`@("`J("`@("`@("`@("`@
M("`@("`@)&YA;64@:7,@=&AE(&YA;64@;V8@=&AE(&QA8F5L('=H:6-H('=A
M<R!D96-O;7!R97-S960*("`@("`J("`@("`@("`@("`@("`@("`@86YD("1O
M9F9S970@:7,@=&AE(&]F9G-E="!O9B!T:&4@;F5X="!F:65L9"!I;B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@<&%C:V5T+B`@4F5T=7)N<R!A<G)A
M>2A.54Q,+"!.54Q,*2!O;B!E<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M;E]E>'!A;F0H)'!A8VME="P@)&]F9G-E="D*("`@('L*("`@("`@("`D<&%C
M:V5T;&5N(#T@<W1R;&5N*"1P86-K970I.PH@("`@("`@("1I;G0Q-G-Z(#T@
M,CL*("`@("`@("`D;F%M92`]("<G.PH@("`@("`@('=H:6QE("@Q*2!["B`@
M("`@("`@("`@(&EF("@D<&%C:V5T;&5N(#P@*"1O9F9S970@*R`Q*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N*&%R<F%Y*$Y53$PL($Y53$PI*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&$@/2!U;G!A8VLH(D`D;V9F<V5T
M+T-C:&%R(BP@)'!A8VME="D["B`@("`@("`@("`@("1L96X@/2`D85LG8VAA
M<B==.PH*("`@("`@("`@("`@:68@*"1L96X@/3T@,"D@>PH@("`@("`@("`@
M("`@("`@)&]F9G-E="LK.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T@96QS92!I9B`H*"1L96X@)B`P>&,P*2`]/2`P>&,P*2!["B`@
M("`@("`@("`@("`@("!I9B`H)'!A8VME=&QE;B`\("@D;V9F<V5T("L@)&EN
M=#$V<WHI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N*&%R<F%Y*$Y5
M3$PL($Y53$PI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1P='(@/2!U;G!A8VLH(D`D;V9F<V5T+VYI(BP@)'!A8VME="D["B`@("`@
M("`@("`@("`@("`D<'1R(#T@)'!T<ELG:2==.PH@("`@("`@("`@("`@("`@
M)'!T<B`]("1P='(@)B`P>#-F9F8["B`@("`@("`@("`@("`@("`D;F%M93(@
M/2!.971?1$Y37U!A8VME=#HZ9&Y?97AP86YD*"1P86-K970L("1P='(I.PH*
M("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1N86UE,ELP72DI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FXH87)R87DH3E5,3"P@3E5,3"DI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&YA;64@+CT@)&YA
M;64R6S!=.PH@("`@("`@("`@("`@("`@)&]F9G-E="`K/2`D:6YT,39S>CL*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&]F9G-E="LK.PH*("`@("`@("`@("`@("`@(&EF
M("@D<&%C:V5T;&5N(#P@*"1O9F9S970@*R`D;&5N*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;BAA<G)A>2A.54Q,+"!.54Q,*2D["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&5L96T@/2!S=6)S='(H)'!A
M8VME="P@)&]F9G-E="P@)&QE;BD["B`@("`@("`@("`@("`@("`D;F%M92`N
M/2`D96QE;2`N("<N)SL*("`@("`@("`@("`@("`@("1O9F9S970@*ST@)&QE
M;CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D;F%M92`](&5R
M96=?<F5P;&%C92@G7"XD)RP@)R<L("1N86UE*3L*("`@("`@("!R971U<FXH
M87)R87DH)&YA;64L("1O9F9S970I*3L*("`@('T*"B`@("`O*GU]?2HO"B`@
M("`O*B!.971?1$Y37U!A8VME=#HZ;&%B96Q?97AT<F%C="@D<&%C:V5T+"`D
M;V9F<V5T*2![>WL@*B\*("`@("\J*@H@("`@("H@1$Y3('!A8VME="!D96-O
M;7!R97-S:6]N(&UE=&AO9`H@("`@("H*("`@("`J($5X=')A8W1S('1H92!L
M86)E;"!S=&]R960@870@82!P87)T:6-U;&%R(&QO8V%T:6]N(&EN(&$@1$Y3
M"B`@("`@*B!P86-K970N("!4:&4@9FER<W0@87)G=6UE;G0@:7,@82!V87)I
M86)L92!C;VYT86EN:6YG("!T:&4@<&%C:V5T"B`@("`@*B!D871A+B`@5&AE
M('-E8V]N9"!A<F=U;65N="!I<R!T:&4@;V9F<V5T('=I=&AI;B!T:&4@('!A
M8VME="!W:&5R90H@("`@("H@=&AE("AP;W-S:6)L>2D@8V]M<')E<W-E9"!D
M;VUA:6X@;F%M92!I<R!S=&]R960N"B`@("`@*B`*("`@("`J($!P87)A;2`@
M('-T<FEN9R`@)'!A8VME="!4:&4@<&%C:V5T(&1A=&$*("`@("`J($!P87)A
M;2`@(&EN=&5G97(@)&]F9G-E="!4:&4@;&]C871I;VX@;V9F<V5T(&EN('1H
M92!P86-K970@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@;&%B96P@=&\@97AT<F%C="X*("`@("`J($!R971U<FX@(&%R<F%Y("`@
M4F5T=7)N<R!A(&QI<W0@;V8@='EP92!A<G)A>2@D;F%M92P@)&]F9G-E="D@
M=VAE<F4*("`@("`J("`@("`@("`@("`@("`@("`@)&YA;64@:7,@=&AE(&YA
M;64@;V8@=&AE(&QA8F5L('=H:6-H('=A<R!D96-O;7!R97-S960*("`@("`J
M("`@("`@("`@("`@("`@("`@86YD("1O9F9S970@:7,@=&AE(&]F9G-E="!O
M9B!T:&4@;F5X="!F:65L9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@<&%C:V5T+B`@4F5T=7)N<R!A<G)A>2A.54Q,+"!.54Q,*2!O;B!E<G)O
M<@H@("`@("HO"B`@("!F=6YC=&EO;B!L86)E;%]E>'1R86-T*"1P86-K970L
M("1O9F9S970I"B`@("!["B`@("`@("`@)'!A8VME=&QE;B`]('-T<FQE;B@D
M<&%C:V5T*3L*("`@("`@("`D;F%M92`]("<G.PH@("`@("`@(&EF("@D<&%C
M:V5T;&5N(#P@*"1O9F9S970@*R`Q*2D@>PH@("`@("`@("`@("!R971U<FXH
M87)R87DH3E5,3"P@3E5,3"DI.PH@("`@("`@('T*"B`@("`@("`@)&$@/2!U
M;G!A8VLH(D`D;V9F<V5T+T-C:&%R(BP@)'!A8VME="D["B`@("`@("`@)&QE
M;B`]("1A6R=C:&%R)UT["@D))&]F9G-E="LK.PH*("`@("`@("!I9B`H)&QE
M;B`K("1O9F9S970@/B`D<&%C:V5T;&5N*2!["B`@("`@("`@("`@("1N86UE
M(#T@<W5B<W1R*"1P86-K970L("1O9F9S970I.PH@("`@("`@("`@("`D;V9F
M<V5T(#T@)'!A8VME=&QE;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;F%M92`]('-U8G-T<B@D<&%C:V5T+"`D;V9F<V5T+"`D;&5N*3L*("`@
M("`@("`@("`@)&]F9G-E="`K/2`D;&5N.PH@("`@("`@('T*("`@("`@("!R
M971U<FXH87)R87DH)&YA;64L("1O9F9S970I*3L*("`@('T*"B`@("`O*GU]
M?2HO"B`@("`O*B!.971?1$Y37U!A8VME=#HZ<&%R<V5?<75E<W1I;VXH)&1A
M=&$L("1O9F9S970I('M[>R`J+PH@("`@+RHJ"B`@("`@*B!087)S97,@=&AE
M('%U97-T:6]N('-E8W1I;VX@;V8@82!P86-K970*("`@("`J"B`@("`@*B!%
M>&%M:6YE<R!A($1.4R!P86-K970@870@=&AE('-P96-I9FEE9"!O9F9S970@
M86YD('!A<G-E<R!T:&4@9&%T80H@("`@("H@;V8@=&AE(%%515-424].('-E
M8W1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9&%T82`@
M(%1H92!P86-K970@9&%T82!R971U<FYE9"!F<F]M('1H92!S97)V97(*("`@
M("`J($!P87)A;2`@(&EN=&5G97(@)&]F9G-E="!4:&4@;&]C871I;VX@;V9F
M<V5T(&]F('1H92!S=&%R="!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!Q=65S=&EO;B!S96-T:6]N+@H@("`@("H@0')E='5R;B`@
M87)R87D@("!!;B!A<G)A>2!O9B!T>7!E(&%R<F%Y*"1Q+"`D;V9F<V5T*2!W
M:&5R92`D<0H@("`@("H@("`@("`@("`@("`@("`@("!I<R!A($YE=%]$3E-?
M475E<W1I;VX@;V)J96-T(&%N9"`D;V9F<V5T(&ES('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("!L;V-A=&EO;B!O9B!T:&4@;F5X="!S96-T:6]N(&]F
M('1H92!P86-K970@=VAI8V@*("`@("`J("`@("`@("`@("`@("`@("`@;F5E
M9',@=&\@8F4@<&%R<V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S95]Q
M=65S=&EO;B@D9&%T82P@)&]F9G-E="D*("`@('L*("`@("`@("!L:7-T*"1Q
M;F%M92P@)&]F9G-E="D@/2`D=&AI<RT^9&Y?97AP86YD*"1D871A+"`D;V9F
M<V5T*3L*("`@("`@("!I9B`H:7-?;G5L;"@D<6YA;64I*2!["B`@("`@("`@
M("`@(')E='5R;BAA<G)A>2A.54Q,+"!.54Q,*2D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H<W1R;&5N*"1D871A*2`\("@D;V9F<V5T("L@,B`J(#(I*2![
M"B`@("`@("`@("`@(')E='5R;BAA<G)A>2A.54Q,+"!.54Q,*2D["B`@("`@
M("`@?0H*("`@("`@("`D<2`]('5N<&%C:R@B0"1O9F9S970O;C)I;G0B+"`D
M9&%T82D["B`@("`@("`@)'%T>7!E(#T@)'%;)VEN=#$G73L*("`@("`@("`D
M<6-L87-S(#T@)'%;)VEN=#(G73L*("`@("`@("`D;V9F<V5T("L](#(@*B`R
M.PH*("`@("`@("`D<71Y<&4@/2!.971?1$Y3.CIT>7!E<V)Y=F%L*"1Q='EP
M92D["B`@("`@("`@)'%C;&%S<R`]($YE=%]$3E,Z.F-L87-S97-B>79A;"@D
M<6-L87-S*3L*"B`@("`@("`@)'$@/2!N97<@3F5T7T1.4U]1=65S=&EO;B@D
M<6YA;64L("1Q='EP92P@)'%C;&%S<RD["B`@("`@("`@<F5T=7)N*&%R<F%Y
M*"1Q+"`D;V9F<V5T*2D["B`@("!]"@H@("`@+RI]?7TJ+PH@("`@+RH@3F5T
M7T1.4U]086-K970Z.G!A<G-E7W)R*"1D871A+"`D;V9F<V5T*2![>WL@*B\*
M("`@("\J*@H@("`@("H@4&%R<V5S(&$@<F5S;W5R8V4@<F5C;W)D('-E8W1I
M;VX@;V8@82!P86-K970*("`@("`J"B`@("`@*B!%>&%M:6YE<R!A($1.4R!P
M86-K970@870@=&AE('-P96-I9FEE9"!O9F9S970@86YD('!A<G-E<R!T:&4@
M9&%T80H@("`@("H@;V8@82!S96-T:6]N('=H:6-H(&-O;G1A:6YS(%)2<R`H
M04Y35T52+"!!551(3U))5%DL($%$1$E424].04PI+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("`@)&1A=&$@("!4:&4@<&%C:V5T(&1A=&$@<F5T
M=7)N960@9G)O;2!T:&4@<V5R=F5R"B`@("`@*B!`<&%R86T@:6YT96=E<B`@
M("1O9F9S970@5&AE(&QO8V%T:6]N(&]F9G-E="!O9B!T:&4@<W1A<G0@;V8@
M=&AE(')E<V]U<F-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5C;W)D('-E8W1I;VXN"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@($%N(&%R
M<F%Y(&]F('1Y<&4@87)R87DH)')R+"`D;V9F<V5T*2!W:&5R92`D<G(*("`@
M("`J("`@("`@("`@("`@("`@("`@:7,@82!.971?1$Y37U)2(&]B:F5C="!A
M;F0@)&]F9G-E="!I<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@;&]C
M871I;VX@;V8@=&AE(&YE>'0@<V5C=&EO;B!O9B!T:&4@<&%C:V5T('=H:6-H
M"B`@("`@*B`@("`@("`@("`@("`@("`@(&YE961S('1O(&)E('!A<G-E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V5?<G(H)&1A=&$L("1O9F9S970I
M"B`@("!["B`@("`@("`@;&ES="@D;F%M92P@)&]F9G-E="D@/2`D=&AI<RT^
M9&Y?97AP86YD*"1D871A+"`D;V9F<V5T*3L*("`@("`@("!I9B`H(2!S=')L
M96XH)&YA;64I*2!["B`@("`@("`@("`@(')E='5R;BAA<G)A>2A.54Q,+"!.
M54Q,*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R;&5N*"1D871A*2`\
M("@D;V9F<V5T("L@,3`I*2!["B`@("`@("`@("`@(')E='5R;BAA<G)A>2A.
M54Q,+"!.54Q,*2D["B`@("`@("`@?0H*("`@("`@("`D82`]('5N<&%C:R@B
M0"1O9F9S970O;C)T8R].='1L+VYR9&QE;F=T:"(L("1D871A*3L*("`@("`@
M("`D='EP92`]("1A6R=T8S$G73L*("`@("`@("`D8VQA<W,@/2`D85LG=&,R
M)UT["B`@("`@("`@)'1T;"`]("1A6R=T=&PG73L*("`@("`@("`D<F1L96YG
M=&@@/2`D85LG<F1L96YG=&@G73L*"B`@("`@("`@)'1Y<&4@/2!.971?1$Y3
M.CIT>7!E<V)Y=F%L*"1T>7!E*3L*("`@("`@("`D8VQA<W,@/2!.971?1$Y3
M.CIC;&%S<V5S8GEV86PH)&-L87-S*3L*"B`@("`@("`@)&]F9G-E="`K/2`Q
M,#L*("`@("`@("!I9B`H<W1R;&5N*"1D871A*2`\("@D;V9F<V5T("L@)')D
M;&5N9W1H*2D@>PH@("`@("`@("`@("!R971U<FXH87)R87DH3E5,3"P@3E5,
M3"DI.PH@("`@("`@('T*"B`@("`@("`@)')R;V)J(#T@;F5W($YE=%]$3E-?
M4E(H87)R87DH)&YA;64L"B`@("`@("`@("`@("`@("`@("`@)'1Y<&4L"B`@
M("`@("`@("`@("`@("`@("`@)&-L87-S+`H@("`@("`@("`@("`@("`@("`@
M("1T=&PL"B`@("`@("`@("`@("`@("`@("`@)')D;&5N9W1H+`H@("`@("`@
M("`@("`@("`@("`@("1D871A+`H@("`@("`@("`@("`@("`@("`@("1O9F9S
M970I*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)')R;V)J*2D@>PH@("`@("`@
M("`@("!R971U<FXH87)R87DH3E5,3"P@3E5,3"DI.PH@("`@("`@('T*"B`@
M("`@("`@)&]F9G-E="`K/2`D<F1L96YG=&@["@H@("`@("`@(')E='5R;BAA
M<G)A>2@D<G)O8FHL("1O9F9S970I*3L*("`@('T*"B`@("`O*B!]?7T@*B\*
M("`@("\J($YE=%]$3E-?4&%C:V5T.CID:7-P;&%Y*"D@>WM[("HO"B`@("`O
M*BH*("`@("`J(%!R:6YT<R!O=70@=&AE('!A8VME="!I;B!A(&AU;6%N(')E
M861A8FQE(&9O<FUA='1E9"!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&ES<&QA>2@I"B`@("!["B`@("`@("`@96-H;R`D=&AI<RT^<W1R:6YG*"D[
M"B`@("!]"@H@("`@+RI]?7TJ+PH@("`@+RH@3F5T7T1.4U]086-K970Z.G-T
M<FEN9R@I('M[>R`J+PH@("`@+RHJ"B`@("`@*B!"=6EL9',@82!H=6UA;B!R
M96%D86)L92!F;W)M871T960@<W1R:6YG(')E<')E<V5N=&EN9R!A('!A8VME
M=`H@("`@("HO(`H@("`@9G5N8W1I;VX@<W1R:6YG*"D*("`@('L*("`@("`@
M("`D<F5T=F%L(#T@)R<["B`@("`@("`@:68@*"1T:&ES+3YA;G-W97)F<F]M
M*2!["B`@("`@("`@("`@("1R971V86P@+CT@)SL[($%N<W=E<B!R96-E:79E
M9"!F<F]M("<@+B`D=&AI<RT^86YS=V5R9G)O;2`N("<H)R`N"B`@("`@("`@
M("`@("`@("`D=&AI<RT^86YS=V5R<VEZ92`N("(@8GET97,I7&X[.UQN(CL*
M("`@("`@("!]"@H@("`@("`@("1R971V86P@+CT@(CL[($A%041%4B!314-4
M24].7&XB.PH@("`@("`@("1R971V86P@+CT@)'1H:7,M/FAE861E<BT^<W1R
M:6YG*"D["B`@("`@("`@)')E='9A;"`N/2`B7&XB.PH*("`@("`@("`D<V5C
M=&EO;B`]("@D=&AI<RT^:&5A9&5R+3YO<&-O9&4@/3T@)U501$%412<I(#\@
M)UI/3D4G(#H@)U%515-424].)SL*("`@("`@("`D<F5T=F%L("X]("([.R`D
M<V5C=&EO;B!314-424].("@B("X@)'1H:7,M/FAE861E<BT^<61C;W5N="`@
M("`@+@H@("`@("`@("`@("`G(')E8V]R9"<@+B`H)'1H:7,M/FAE861E<BT^
M<61C;W5N="`]/2`Q(#\@)R<@.B`G<R<I("X*("`@("`@("`@("`@(BE<;B([
M"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YQ=65S=&EO;B!A<R`D<7(I('L*
M("`@("`@("`@("`@)')E='9A;"`N/2`G.SL@)R`N("1Q<BT^<W1R:6YG*"D@
M+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@)'-E8W1I;VX@/2`H)'1H:7,M
M/FAE861E<BT^;W!C;V1E(#T]("=54$1!5$4G*2`_("=04D5215%525-)5$4G
M(#H@)T%.4U=%4B<["B`@("`@("`@)')E='9A;"`N/2`B7&X[.R`D<V5C=&EO
M;B!314-424].("@B("X@)'1H:7,M/FAE861E<BT^86YC;W5N="`@("`@+@H@
M("`@("`@("`@("`G(')E8V]R9"<@+B`H)'1H:7,M/FAE861E<BT^86YC;W5N
M="`]/2`Q(#\@)R<@.B`G<R<I("X*("`@("`@("`@("`@(BE<;B(["@H@("`@
M("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^86YS=V5R*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^86YS=V5R(&%S("1A;G,I('L*("`@("`@("`@
M("`@("`@("1R971V86P@+CT@)SL[("<@+B`D86YS+3YS=')I;F<H*2`N(")<
M;B(["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S96-T:6]N
M(#T@*"1T:&ES+3YH96%D97(M/F]P8V]D92`]/2`G55!$051%)RD@/R`G55!$
M051%)R`Z("=!551(3U))5%DG.PH@("`@("`@("1R971V86P@+CT@(EQN.SL@
M)'-E8W1I;VX@4T5#5$E/3B`H(B`N("1T:&ES+3YH96%D97(M/FYS8V]U;G0@
M("`@("X*("`@("`@("`@("`@)R!R96-O<F0G("X@*"1T:&ES+3YH96%D97(M
M/FYS8V]U;G0@/3T@,2`_("<G(#H@)W,G*2`N"B`@("`@("`@("`@("(I7&XB
M.PH*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/F%U=&AO<FET>2DI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F%U=&AO<FET>2!A<R`D875T
M:"D@>PH@("`@("`@("`@("`@("`@)')E='9A;"`N/2`G.SL@)R`N("1A=71H
M+3YS=')I;F<H*2`N(")<;B(["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1R971V86P@+CT@(EQN.SL@041$251)3TY!3"!314-424].("@B
M("X@)'1H:7,M/FAE861E<BT^87)C;W5N="`@("`@+@H@("`@("`@("`@("`G
M(')E8V]R9"<@+B`H)'1H:7,M/FAE861E<BT^87)C;W5N="`]/2`Q(#\@)R<@
M.B`G<R<I("X*("`@("`@("`@("`@(BE<;B(["@H@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&AI<RT^861D:71I;VYA;"DI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/F%D9&ET:6]N86P@87,@)&%D9&PI('L*("`@("`@("`@("`@
M("`@("1R971V86P@+CT@)SL[("<@+B`D861D;"T^<W1R:6YG*"D@+B`B7&XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5T=F%L("X]
M(")<;EQN(CL*("`@("`@("!R971U<FXH)')E='9A;"D["B`@("!]"@H@("`@
M+RI]?7TJ+PI]"B\J('U]?2`J+PHO*B!624T@<V5T=&EN9W,@>WM["B`J($QO
M8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F
M<V5T.B`T"B`J('-O9G0M<W1O<"UW:61T:#H@-`H@*B!C(&EN9&5N="!O;@H@
M*B!%;F0Z"B`J('9I;38P,#H@<W<]-"!T<STT('-T<STT(&-I;F1E;G0@9F1M
M/6UA<FME<B!E=`H@*B!V:6T\-C`P.B!S=STT('1S/30*("H@?7U]("HO"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O3F5T+TY.5%`O````````````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#8`
M,#$V-C4P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O3DY44"]2
M96%L=&EM92YP:'``````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U
M,C<R-@`Q,#0Q-S,V,S`P-@`P,C$Q,S0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P-"B\O('P@0V]P>7)I9VAT(*D@,C`P,R!(96EN;R!(+B!'96AL<V5N+B!!
M;&P@4FEG:'1S(%)E<V5R=F5D+B`@("`@("`@("`@("`@('P-"B\O('P@("`@
M("`@("`@("`@("`@("!H='1P.B\O=W=W+FAE:6YO+F=E:&QS96XN9&LO<V]F
M='=A<F4O;&EC96YS92`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@5&AI<R!W
M;W)K("AI;F-L=61I;F<@<V]F='=A<F4L(&1O8W5M96YT<RP@;W(@;W1H97(@
M<F5L871E9"!I=&5M<RD@:7,@('P-"B\O('P@8F5I;F<@<')O=FED960@8GD@
M=&AE(&-O<'ER:6=H="!H;VQD97)S('5N9&5R('1H92!F;VQL;W=I;F<@;&EC
M96YS92X@('P-"B\O('P@0GD@;V)T86EN:6YG+"!U<VEN9R!A;F0O;W(@8V]P
M>6EN9R!T:&ES('=O<FLL('EO=2`H=&AE(&QI8V5N<V5E*2`@("`@('P-"B\O
M('P@86=R964@=&AA="!Y;W4@:&%V92!R96%D+"!U;F1E<G-T;V]D+"!A;F0@
M=VEL;"!C;VUP;'D@=VET:"!T:&4@("`@("`@('P-"B\O('P@9F]L;&]W:6YG
M('1E<FUS(&%N9"!C;VYD:71I;VYS.B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@4&5R;6ES<VEO;B!T;R!U<V4L(&-O<'DL(&UO9&EF>2P@
M86YD(&1I<W1R:6)U=&4@=&AI<R!S;V9T=V%R92!A;F0@("`@('P-"B\O('P@
M:71S(&1O8W5M96YT871I;VXL('=I=&@@;W(@=VET:&]U="!M;V1I9FEC871I
M;VXL(&9O<B!A;GD@<'5R<&]S92!A;F0@('P-"B\O('P@=VET:&]U="!F964@
M;W(@<F]Y86QT>2!I<R!H97)E8GD@9W)A;G1E9"P@<')O=FED960@=&AA="!Y
M;W4@:6YC;'5D92`@('P-"B\O('P@=&AE(&9O;&QO=VEN9R!O;B!!3$P@8V]P
M:65S(&]F('1H92!S;V9T=V%R92!A;F0@9&]C=6UE;G1A=&EO;B!O<B`@("`@
M('P-"B\O('P@<&]R=&EO;G,@=&AE<F5O9BP@:6YC;'5D:6YG(&UO9&EF:6-A
M=&EO;G,L('1H870@>6]U(&UA:V4Z("`@("`@("`@("`@('P-"B\O('P@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@,2X@5&AE(&9U;&P@=&5X
M="!O9B!T:&ES($Y/5$E#12!I;B!A(&QO8V%T:6]N('9I97=A8FQE('1O('5S
M97)S(&]F("`@('P-"B\O('P@("`@=&AE(')E9&ES=')I8G5T960@;W(@9&5R
M:79A=&EV92!W;W)K+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@,BX@06YY
M('!R92UE>&ES=&EN9R!I;G1E;&QE8W1U86P@<')O<&5R='D@9&ES8VQA:6UE
M<G,L(&YO=&EC97,L(&]R("`@('P-"B\O('P@("`@=&5R;7,@86YD(&-O;F1I
M=&EO;G,N($EF(&YO;F4@97AI<W0L(&$@<VAO<G0@;F]T:6-E(&]F('1H92`@
M("`@("`@('P-"B\O('P@("`@9F]L;&]W:6YG(&9O<FT@*&AY<&5R=&5X="!I
M<R!P<F5F97)R960L('1E>'0@:7,@<&5R;6ET=&5D*2!S:&]U;&0@('P-"B\O
M('P@("`@8F4@=7-E9"!W:71H:6X@=&AE(&)O9'D@;V8@86YY(')E9&ES=')I
M8G5T960@;W(@9&5R:79A=&EV92!C;V1E.B`@('P-"B\O('P@("`@(D-O<'ER
M:6=H=""I(#(P,#,@2&5I;F\@2"X@1V5H;'-E;BX@06QL(%)I9VAT<R!297-E
M<G9E9"X@("`@("`@("`@('P-"B\O('P@("`@(&AT='`Z+R]W=W<N:&5I;F\N
M9V5H;'-E;BYD:R]S;V9T=V%R92]L:6-E;G-E(B`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@
M,RX@3F]T:6-E(&]F(&%N>2!C:&%N9V5S(&]R(&UO9&EF:6-A=&EO;G,@=&\@
M=&AE(&9I;&5S+"!I;F-L=61I;F<@("`@('P-"B\O('P@("`@=&AE(&1A=&4@
M8VAA;F=E<R!W97)E(&UA9&4N("A792!R96-O;6UE;F0@>6]U('!R;W9I9&4@
M55))<R!T;R`@("`@('P-"B\O('P@("`@=&AE(&QO8V%T:6]N(&9R;VT@=VAI
M8V@@=&AE(&-O9&4@:7,@9&5R:79E9"XI("`@("`@("`@("`@("`@("`@("`@
M('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@5$A)
M4R!33T945T%212!!3D0@1$]#54U%3E1!5$E/3B!)4R!04D]6241%1"`B05,@
M25,L(B!!3D0@0T]065))1TA4("`@('P-"B\O('P@2$],1$524R!-04M%($Y/
M(%)%4%)%4T5.5$%424].4R!/4B!705)204Y42453+"!%6%!215-3($]2($E-
M4$Q)140L("`@('P-"B\O('P@24Y#3%5$24Y'($)55"!.3U0@3$E-251%1"!4
M3RP@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@3U(@("`@("`@('P-
M"B\O('P@1DE43D534R!&3U(@04Y9(%!!4E1)0U5,05(@4%524$]312!/4B!4
M2$%4(%1(12!54T4@3T8@5$A%(%-/1E1705)%("`@('P-"B\O('P@3U(@1$]#
M54U%3E1!5$E/3B!724Q,($Y/5"!)3D9224Y'12!!3ED@5$A)4D0@4$%25%D@
M4$%414Y44RP@("`@("`@("`@('P-"B\O('P@0T]065))1TA44RP@5%)!1$5-
M05)+4R!/4B!/5$A%4B!224=(5%,N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M('P@0T]065))1TA4($A/3$1%4E,@5TE,3"!.3U0@0D4@3$E!0DQ%($9/4B!!
M3ED@1$E214-4+"!)3D1)4D5#5"P@("`@("`@('P-"B\O('P@4U!%0TE!3"!/
M4B!#3TY315%514Y424%,($1!34%'15,@05))4TE.1R!/550@3T8@04Y9(%53
M12!/1B!42$4@("`@("`@('P-"B\O('P@4T]&5%=!4D4@3U(@1$]#54U%3E1!
M5$E/3BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@
M5&AE(&YA;64@86YD('1R861E;6%R:W,@;V8@8V]P>7)I9VAT(&AO;&1E<G,@
M;6%Y($Y/5"!B92!U<V5D(&EN("`@("`@('P-"B\O('P@861V97)T:7-I;F<@
M;W(@<'5B;&EC:71Y('!E<G1A:6YI;F<@=&\@=&AE('-O9G1W87)E('=I=&AO
M=70@<W!E8VEF:6,L('P-"B\O('P@=W)I='1E;B!P<FEO<B!P97)M:7-S:6]N
M+B!4:71L92!T;R!C;W!Y<FEG:'0@:6X@=&AI<R!S;V9T=V%R92!A;F0@86YY
M('P-"B\O('P@87-S;V-I871E9"!D;V-U;65N=&%T:6]N('=I;&P@870@86QL
M('1I;65S(')E;6%I;B!W:71H(&-O<'ER:6=H="`@("`@('P-"B\O('P@:&]L
M9&5R<RX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@5&AI<R!L
M:6-E;G-E(&ES(&)A<V5D(&]N('1H92`B5S-#KB!33T945T%212!.3U1)0T4@
M04Y$($Q)0T5.4T4B+B`@("`@('P-"B\O('P@3F\@8VAA;F=E<R!H879E(&)E
M96X@;6%D92!T;R!T:&4@(E<S0ZX@4T]&5%=!4D4@3D]424-%($%.1"!,24-%
M3E-%(BP@('P-"B\O('P@97AC97!T(&9O<B!T:&4@<F5F97)E;F-E<R!T;R!T
M:&4@8V]P>7)I9VAT(&AO;&1E<BP@=VAI8V@@:&%S(&5I=&AE<B`@('P-"B\O
M('P@8F5E;B!C:&%N9V5S(&]R(')E;6]V960N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L-"B\O("1)9#H@4F5A;'1I;64N<&AP+'8@,2XQ(#(P,#,O,3`O,3`@
M,3,Z,3$Z,3D@:&5I;F\@17AP("0-"@T*<F5Q=6ER95]O;F-E("=.970O3DY4
M4"]0<F]T;V-O;"YP:'`G.PT*<F5Q=6ER95]O;F-E("=.970O3DY44"](96%D
M97(N<&AP)SL-"G)E<75I<F5?;VYC92`G3F5T+TY.5%`O365S<V%G92YP:'`G
M.PT*#0H-"B\J($Y.5%`@075T:&5N=&EC871I;VX@;6]D97,@*B\-"F1E9FEN
M92@G3D547TY.5%!?05542$]224=)3D%,)RP@)V]R:6=I;F%L)RD[#0ID969I
M;F4H)TY%5%].3E107T%55$A324U03$4G+"`@("=S:6UP;&4G*3L-"F1E9FEN
M92@G3D547TY.5%!?05542$=%3D5224,G+"`@)V=E;F5R:6,G*3L-"@T*+RHJ
M#0H@*B!4:&4@3F5T7TY.5%!?4F5A;'1I;64@8VQA<W,@:7,@82!F<F]N=&5N
M9"!C;&%S<R!T;R!T:&4@#0H@*B!.971?3DY44%]0<F]T;V-O;"!C;&%S<RX@
M270@9&]E<R!E=F5R>71H:6YG(&EN(')E86QT:6UE+BXN#0H@*@T*("H@0&%U
M=&AO<B!(96EN;R!(+B!'96AL<V5N(#QH96EN;T!G96AL<V5N+F1K/@T*("HO
M#0IC;&%S<R!.971?3DY44%]296%L=&EM92!E>'1E;F1S($YE=%].3E107U!R
M;W1O8V]L#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@("\J*@T*
M("`@("`J(%5S960@9F]R('-T;W)I;F<@:6YF;W)M871I;VX@86)O=70@=&AE
M(&-U<G)E;G1L>2!S96QE8W1E9"!G<F]U<`T*("`@("`J#0H@("`@("H@0'9A
M<B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!S:6YC
M92`P+C,-"B`@("`@*B\-"B`@("!V87(@)%]C=7)R96YT1W)O=7`@/2!N=6QL
M.PT*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@
M("`O*BH-"B`@("`@*B!#;VYS=')U8W1O<@T*("`@("`J+PT*("`@(&9U;F-T
M:6]N($YE=%].3E107U)E86QT:6UE*"D-"B`@("![#0H)<&%R96YT.CI.971?
M3DY44%]0<F]T;V-O;"@I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!C;VYN96-T*"D-"@T*("`@("\J*@T*("`@("`J($-O;FYE8W0@=&\@
M=&AE($Y.5%`M<V5R=F5R+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&]P=&EO
M;F%L('-T<FEN9R`D:&]S="!4:&4@861R97-S(&]F('1H92!.3E10+7-E<G9E
M<B!T;R!C;VYN96-T('1O+@T*("`@("`J($!P87)A;2!O<'1I;VYA;"!I;G0@
M)'!O<G0@5&AE('!O<G0@=&\@8V]N;F5C="!T;RX-"B`@("`@*@T*("`@("`J
M($!R971U<FX@;6EX960@*&)O;VPI('1R=64@;VX@<W5C8V5S<R!O<B`H;V)J
M96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J($!S964@3F5T7TY.5%`Z.G%U:70H*0T*("`@("`J($!S
M964@3F5T7TY.5%`Z.F%U=&AE;G1I8V%T92@I#0H@("`@("H@0'-E92!.971?
M3DY44#HZ8V]N;F5C=$%U=&AE;G1I8V%T960H*0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&-O;FYE8W0H)&AO<W0@/2!.151?3DY44%]04D]43T-/3%]$149!
M54Q47TA/4U0L#0H@("`@("`@("`@("`@("`@("`@("`D<&]R="`]($Y%5%].
M3E107U!23U1/0T],7T1%1D%53%1?4$]25"D-"B`@("![#0H)<F5T=7)N('!A
M<F5N=#HZ8V]N;F5C="@D:&]S="P@)'!O<G0I.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!C;VYN96-T075T:&5N=&EC871E9"@I#0H-"B`@
M("`O*BH-"B`@("`@*B!#;VYN96-T('1O('1H92!.3E10+7-E<G9E<BP@86YD
M(&%U=&AE;G1I8V%T92!U<VEN9R!G:79E;B!U<V5R;F%M92!A;F0@<&%S<W=O
M<F0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG("1U
M<V5R(%1H92!U<V5R;F%M92X-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@<W1R
M:6YG("1P87-S(%1H92!P87-S=V]R9"X-"B`@("`@*B!`<&%R86T@;W!T:6]N
M86P@<W1R:6YG("1H;W-T(%1H92!)4"UA9&1R97-S(&]F('1H92!.3E10+7-E
M<G9E<B!T;R!C;VYN96-T('1O+@T*("`@("`J($!P87)A;2!O<'1I;VYA;"!I
M;G0@)'!O<G0@5&AE('!O<G0@=&\@8V]N;F5C="!T;RX-"B`@("`@*B!`<&%R
M86T@;W!T:6]N86P@<W1R:6YG("1A=71H;6]D92!4:&4@875T:&5N=&EC871I
M;VX@;6]D92X-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&)O;VPI
M('1R=64@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A
M:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S:6YC92`P
M+C,-"B`@("`@*B!`<V5E($YE=%].3E10.CIC;VYN96-T*"D-"B`@("`@*B!`
M<V5E($YE=%].3E10.CIA=71H96YT:6-A=&4H*0T*("`@("`J($!S964@3F5T
M7TY.5%`Z.G%U:70H*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-O;FYE8W1!
M=71H96YT:6-A=&5D*"1U<V5R(#T@;G5L;"P-"B`@("`@("`@("`@(`D)"2`@
M)'!A<W,@/2!N=6QL+`T*"0D)"2`@)&AO<W0@/2!.151?3DY44%]04D]43T-/
M3%]$149!54Q47TA/4U0L#0H@("`@("`@("`@("`@("`@"0D@("1P;W)T(#T@
M3D547TY.5%!?4%)/5$]#3TQ?1$5&055,5%]03U)4+`T*("`@("`@("`@("`@
M("`@(`D)("`D875T:&UO9&4@/2!.151?3DY44%]!551(3U))1TE.04PI#0H@
M("`@>PT*"212(#T@)'1H:7,M/F-O;FYE8W0H)&AO<W0L("1P;W)T*3L-"@EI
M9B`H4$5!4CHZ:7-%<G)O<B@D4BDI('L-"@D@("`@<F5T=7)N("12.PT*"7T-
M"@T*"2\O($%U=&AE;G1I8V%T92!I9B!U<V5R;F%M92!I<R!G:79E;@T*"6EF
M("@D=7-E<B`A/2!N=6QL*2![#0H@("`@"2`@("`D4B`]("1T:&ES+3YA=71H
M96YT:6-A=&4H)'5S97(L("1P87-S+"`D875T:&UO9&4I.PT*("`@(`D@("`@
M:68@*%!%05(Z.FES17)R;W(H)%(I*2![#0H@("`@"0ER971U<FX@)%([#0H@
M("`@"2`@("!]#0H)?0T*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!Q=6ET*"D-"@T*("`@("\J*@T*
M("`@("`J($-L;W-E(&-O;FYE8W1I;VX@=&\@=&AE(&YE=W-S97)V97(-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-E92!.971?
M3DY44#HZ8V]N;F5C="@I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<75I="@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F-M9%%U:70H*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@875T:&5N=&EC871E*"D-
M"@T*("`@("\J*@T*("`@("`J($%U=&AE;G1I8V%T90T*("`@("`J(`T*("`@
M("`J($%U=&@@<')O8V5S<R`H;F]T('EE="!S=&%N9&%R:7IE9"!B=70@=7-E
M9"!A;GD@=V%Y*0T*("`@("`J(&AT='`Z+R]W=W<N;6EB<V]F='=A<F4N8V]M
M+W5S97)K="]N;G1P97AT+VEN9&5X+FAT;6P-"B`@("`@*@T*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97(@5&AE('5S97)N86UE#0H@("`@("H@0'!A<F%M
M(&]P=&EO;F%L('-T<FEN9R`D<&%S<R!4:&4@<&%S<W=O<F0-"B`@("`@*B!`
M<&%R86T@;W!T:6]N86P@<W1R:6YG("1M;V1E(%1H92!A=71H96YT:6-A=&EO
M;B!M;V1E("AO<FEG:6YA;"P@<VEM<&QE+"!G96YE<FEC*2X-"B`@("`@*@T*
M("`@("`J($!R971U<FX@;6EX960@*&)O;VPI('1R=64@;VX@<W5C8V5S<R!O
M<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J($!S964@3F5T7TY.5%`Z.F-O;FYE8W0H*0T*
M("`@("`J($!S964@3F5T7TY.5%`Z.F-O;FYE8W1!=71H96YT:6-A=&5D*"D-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A=71H96YT:6-A=&4H)'5S97(L("1P
M87-S+"`D;6]D92`]($Y%5%].3E107T%55$A/4DE'24Y!3"D-"B`@("![#0H@
M("`@("`@("\O(%5S97)N86UE(&ES(&$@;75S="XN+@T*("`@("`@("!I9B`H
M)'5S97(@/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YT
M:')O=T5R<F]R*"=.;R!U<V5R;F%M92!S=7!P;&EE9"<L(&YU;&PI.PT*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@57-E('-E;&5C=&5D(&%U=&AE;G1I8V%T
M:6]N(&UE=&AO9`T*("`@("`@("!S=VET8V@@*"1M;V1E*2![#0H@("`@("`@
M("`@("!C87-E($Y%5%].3E107T%55$A/4DE'24Y!3#H-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F-M9$%U=&AI;F9O*"1U<V5R+"`D<&%S<RD[
M#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E($Y%
M5%].3E107T%55$A324U03$4Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YC;61!=71H:6YF;U-I;7!L92@D=7-E<BP@)'!A<W,I.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!.151?3DY44%]!
M551(1T5.15))0SH-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-M
M9$%U=&AI;F9O1V5N97)I8R@D=7-E<BP@)'!A<W,I.PT*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G1H<F]W17)R;W(H(E1H92!A=71H(&UO9&4Z
M("<D;6]D92<@:7,@=6YK;F]W;B(L(&YU;&PI.PT*("`@("`@("!]#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&ES0V]N;F5C=&5D*"D-"@T*
M("`@("\J*@T*("`@("`J(%1E<W0@=VAE=&AE<B!A(&-O;FYE8W1I;VX@:7,@
M8W5R<F5N=&QY(&]P96XN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@
M=')U92!O<B!F86QS90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@
M0'-E92!.971?3DY44#HZ8V]N;F5C="@I#0H@("`@("H@0'-E92!.971?3DY4
M4#HZ<75I="@I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-#;VYN96-T960H
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ:7-#;VYN96-T960H
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<V5L96-T1W)O
M=7`H*0T*#0H@("`@+RHJ#0H@("`@("H@4V5L96-T<R!A(&YE=W-G<F]U<`T*
M("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<V=R;W5P($YE=W-G
M<F]U<"!N86UE#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A
M>2D@26YF;R!A8F]U="!T:&4@;F5W<V=R;W5P(&]N('-U8V-E<W,@;W(@*&]B
M:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`@*B!`<V5E($YE=%].3E10.CIG<F]U<"@I#0H@("`@("H@
M0'-E92!.971?3DY44#HZ9FER<W0H*0T*("`@("`J($!S964@3F5T7TY.5%`Z
M.FQA<W0H*0T*("`@("`J($!S964@3F5T7TY.5%`Z.F-O=6YT*"D-"B`@("`@
M*B!`<V5E($YE=%].3E10.CIG971'<F]U<',H*0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E;&5C=$=R;W5P*"1N97=S9W)O=7`I#0H@("`@>PT*("`@("`@
M("`D<F5S<&]N<V5?87)R(#T@)'1H:7,M/F-M9$=R;W5P*"1N97=S9W)O=7`I
M.PT*("`@(`EI9B`H4$5!4CHZ:7-%<G)O<B@D<F5S<&]N<V5?87)R*2D@>PT*
M"2`@("!R971U<FX@)')E<W!O;G-E7V%R<CL-"@E]#0H-"@DO+R!3=&]R92!G
M<F]U<"!I;F9O(&EN('1H92!O8FIE8W0-"@DD=&AI<RT^7V-U<G)E;G1'<F]U
M<"`]("1R97-P;VYS95]A<G([#0H-"@ER971U<FX@)')E<W!O;G-E7V%R<CL-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1W)O=7!S*"D-
M"@T*("`@("\J*@T*("`@("`J($9E=&-H97,@82!L:7-T(&]F(&%L;"!A=F%I
M8FQE(&YE=W-G<F]U<',-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@
M*&%R<F%Y*2!N97-T960@87)R87D@=VET:"!I;F9O<FUA=&EO;G,@86)O=70@
M97AI<W1I;F<@;F5W<V=R;W5P<R!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E
M87)?97)R;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("H@0'-E92!.971?3DY44#HZ<V5L96-T1W)O=7`H*0T*("`@("`J($!S
M964@3F5T7TY.5%`Z.F=E=$1E<V-R:7!T:6]N<R@I#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T1W)O=7!S*"D-"B`@("![#0H)+R\@1V5T(&=R;W5P<PT*
M"21G<F]U<',@/2`D=&AI<RT^8VUD3&ES="@I.PT*"6EF("A014%2.CII<T5R
M<F]R*"1G<F]U<',I*2![#0H)("`@(')E='5R;B`D9W)O=7!S.PT*"7T-"@T*
M"7)E='5R;B`D9W)O=7!S.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!G971$97-C<FEP=&EO;G,H*0T*#0H@("`@+RHJ#0H@("`@("H@1F5T
M8VAE<R!A(&QI<W0@;V8@86QL(&%V86EB;&4@;F5W<V=R;W5P(&1E<V-R:7!T
M:6]N<RX-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&%R<F%Y*2!N
M97-T960@87)R87D@=VET:"!D97-C<FEP=&EO;B!O9B!E>&ES=&EN9R!N97=S
M9W)O=7!S(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F
M86EL=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<V5E($YE
M=%].3E10.CIG971'<F]U<',H*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=$1E<V-R:7!T:6]N<R@I#0H@("`@>PT*#0H)+R\@1V5T(&=R;W5P(&1E<V-R
M:7!T:6]N<PT*"21D97-C<FEP=&EO;G,@/2`D=&AI<RT^8VUD3&ES=$YE=W-G
M<F]U<',H*3L-"@EI9B`H4$5!4CHZ:7-%<G)O<B@D9&5S8W)I<'1I;VYS*2D@
M>PT*"2`@("!R971U<FX@)&1E<V-R:7!T:6]N<SL-"@E]#0H)#0H)<F5T=7)N
M("1D97-C<FEP=&EO;G,[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$]V97)V:65W*"D-"@T*("`@("\J*@T*("`@("`J($9E=&-H(&UE
M<W-A9V4@:&5A9&5R(&9I96QD<R!F<F]M(&UE<W-A9V4@;G5M8F5R("1F:7)S
M="!T;R`D;&%S=`T*("`@("`J#0H@("`@("H@5&AE(&9O<FUA="!O9B!T:&4@
M<F5T=7)N960@87)R87D@:7,Z#0H@("`@("H@)&UE<W-A9V5S6VUE<W-A9V5?
M:61=6VAE861E<E]N86UE70T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&9I<G-T(&9I<G-T(&%R=&EC;&4@=&\@9F5T8V@-"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;&%S="`@;&%S="!A<G1I8VQE('1O(&9E=&-H#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A>2D@;F5S=&5D(&%R<F%Y
M(&]F(&UE<W-A9V4@86YD('1H96ER(&AE861E<G,@;VX@<W5C8V5S<R!O<B`H
M;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J($!S964@3F5T7TY.5%`Z.F=E=$]V97)V:65W1F]R
M;6%T*"D-"B`@("`@*B!`<V5E($YE=%].3E10.CIG9712969E<F5N8V5S3W9E
M<G9I97<H*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$]V97)V:65W*"1F
M:7)S="P@)&QA<W0I#0H@("`@>PT*"21O=F5R=FEE=R`]("1T:&ES+3YC;618
M3W9E<B@D9FER<W0L("1L87-T*3L-"@EI9B`H4$5!4CHZ:7-%<G)O<B@D;W9E
M<G9I97<I*2![#0H)("`@(')E='5R;B`D;W9E<G9I97<[#0H)?0T*"0T*"7)E
M='5R;B`D;W9E<G9I97<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$]V97)V:65W1FUT*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R
M;G,@82!L:7-T(&]F(&%V86EB;&4@:&5A9&5R<R!W:&EC:"!A<F4@<V5N9"!F
M<F]M($Y.5%`M<V5R=F5R('1O('1H92!C;&EE;G0@9F]R(&5V97)Y(&YE=W,@
M;65S<V%G90T*("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE9"`H87)R87DI
M(&AE861E<B!N86UE<R!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E87)?97)R
M;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@
M0'-E92!.971?3DY44#HZ9V5T3W9E<G9I97<H*0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=$]V97)V:65W1F]R;6%T*"D-"B`@("![#0H)<F5T=7)N("1T
M:&ES+3YC;61,:7-T3W9E<G9I97=&;70H*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@9V5T4F5F97)E;F-E<T]V97)V:65W*"D-"@T*("`@
M("\J*@T*("`@("`J($9E=&-H(&$@;&ES="!O9B!E86-H(&UE<W-A9V4G<R!R
M969E<F5N8V4@:&5A9&5R+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&9I<G-T(&9I<G-T(&%R=&EC;&4@=&\@9F5T8V@-"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;&%S="`@;&%S="!A<G1I8VQE('1O(&9E=&-H#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A>2D@;F5S=&5D(&%R<F%Y
M(&]F(')E9F5R96YC97,@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R
M<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M($!S964@3F5T7TY.5%`Z.F=E=$]V97)V:65W*"D-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G9712969E<F5N8V5S3W9E<G9I97<H)&9I<G-T+"`D;&%S="D-
M"B`@("![#0H))&]V97)V:65W(#T@)'1H:7,M/F-M9%A23W9E<B@D9FER<W0L
M("1L87-T*3L-"@EI9B`H4$5!4CHZ:7-%<G)O<B@D;W9E<G9I97<I*2![#0H)
M("`@(')E='5R;B`D;W9E<G9I97<[#0H)?0T*"0T*"7)E='5R;B`D;W9E<G9I
M97<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('!O<W0H*0T*
M#0H@("`@+RHJ#0H@("`@("H@4&]S="!A;B!A<G1I8VQE('1O(&$@;G5M8F5R
M(&]F(&YE=W-G<F]U<',N#0H@("`@("H-"B`@("`@*B`H06UO;F<@=&AE(&%D
M:71I;VYA;"!H96%D97)S('EO=2!M:6=H="!T:&EN:R!O9B!A9&1I;F<@8V]U
M;&0@8F4Z#0H@("`@("H@(DY.5%`M4&]S=&EN9RU(;W-T.B`\:7`M;V8M875T
M:&]R/B(L('=H:6-H('-H;W5L9"!C;VYT86EN('1H92!)4"UA9&1R97-S#0H@
M("`@("H@;V8@=&AE(&%U=&AO<B!O9B!T:&4@<&]S="P@<V\@=&AE(&UE<W-A
M9V4@8V%N(&)E('1R86-E9"!B86-K('1O(&AI;2X-"B`@("`@*B!/<B`B3W)G
M86YI>F%T:6]N.B`\;W)G/B(@=VAI8V@@8V]N=&%I;B!T:&4@;F%M92!O9B!T
M:&4@;W)G86YI>F%T:6]N#0H@("`@("H@=&AE('!O<W0@;W)I9VEN871E<R!F
M<F]M*0T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<V=R;W5P
M<R!4:&4@;F5W<V=R;W5P('1O('!O<W0@=&\N#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W5B:F5C="!4:&4@<W5B:F5C="!O9B!T:&4@<&]S="X-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1B;V1Y(%1H92!B;V1Y(&]F('1H92!P;W-T(&ET
M<V5L9BX-"B`@("`@*B!`<&%R86T@<W1R:6YG("1F<F]M($YA;64@*R!E;6%I
M;"UA9')E<W,@;V8@<V5N9&5R+@T*("`@("`J($!P87)A;2!O<'1I;VYA;"!S
M=')I;F<@)&%D:71I;VYA;"!!9&ET:6]N86P@:&5A9&5R<R!T;R!S96YD+@T*
M("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE9"`H<W1R:6YG*2!S97)V97(@
M<F5S<&]N<V4@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N
M(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N('!O<W0H)&YE=W-G<F]U<',L("1S=6)J96-T+"`D8F]D>2P@
M)&9R;VTL("1A9&ET:6]N86P@/2`G)RD-"B`@("![#0H)<F5T=7)N("1T:&ES
M+3YC;610;W-T*"1N97=S9W)O=7!S+"`D<W5B:F5C="P@)&)O9'DL("1F<F]M
M+"`D861I=&EO;F%L*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9V5T07)T:6-L92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@86X@87)T
M:6-L90T*("`@("`J#0H@("`@("H@5&AE('8P+C(@=F5R<VEO;B!O9B!T:&4@
M=&AI<R!F=6YC=&EO;B`H=VAI8V@@<F5T=7)N960@=&AE(&%R=&EC;&4@87,@
M82!S=')I;F<I(&AA<R!B965N(')E;F%M960@=&\@9V5T07)T:6-L95)A=R@I
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1A<G1I8VQE($5I=&AE
M<B!T:&4@;65S<V%G92UI9"!O<B!T:&4@;65S<V%G92UN=6UB97(@;VX@=&AE
M('-E<G9E<B!O9B!T:&4@87)T:6-L92!T;R!F971C:"X-"B`@("`@*@T*("`@
M("`J($!R971U<FX@;6EX960@*&]B:F5C="D@;65S<V%G92!O8FIE8W0@;VX@
M<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S964@3F5T7TY.5%`Z.F=E
M=$%R=&EC;&5287<H*0T*("`@("`J($!S964@3F5T7TY.5%`Z.F=E=$AE861E
M<B@I#0H@("`@("H@0'-E92!.971?3DY44#HZ9V5T0F]D>2@I#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T07)T:6-L92@D87)T:6-L92D-"B`@("![#0H@
M("`@("`@("1M97-S86=E(#T@)'1H:7,M/F=E=$%R=&EC;&5287<H)&%R=&EC
M;&4L(&9A;'-E*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&UE<W-A
M9V4I*2![#0H)("`@(')E='5R;B`D9&%T83L-"@E]#0H)#0H))$T@/2!.971?
M3DY44%]-97-S86=E.CIC<F5A=&4H)&UE<W-A9V4I.PT*"0T*"7)E='5R;B`D
M33L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T07)T:6-L
M95)A=R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@82!A<G1I8VQE("AR87<@
M9&%T82D-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE9"`D87)T:6-L92!%
M:71H97(@=&AE(&UE<W-A9V4M:60@;W(@=&AE(&UE<W-A9V4M;G5M8F5R(&]N
M('1H92!S97)V97(@;V8@=&AE(&%R=&EC;&4@=&\@9F5T8V@N#0H@("`@("H@
M0'!A<F%M(&]P=&EO;F%L(&)O;VP@("1I;7!L;V1E(%=H96X@=')U92!T:&4@
M<F5S=6QT(&%R<F%Y(&ES(&EM<&QO9&5D('1O(&$@<W1R:6YG+"!D969A=6QT
M<R!T;R!F86QS92X-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&%R
M<F%Y+W-T<FEN9RD@5&AE(&%R=&EC;&4@;VX@<W5C8V5S<R!O<B`H;V)J96-T
M*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J($!S964@3F5T7TY.5%`Z.F=E=$%R=&EC;&4H*0T*("`@("`J
M($!S964@3F5T7TY.5%`Z.F=E=$AE861E<E)A=R@I#0H@("`@("H@0'-E92!.
M971?3DY44#HZ9V5T0F]D>5)A=R@I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T07)T:6-L95)A=R@D87)T:6-L92P@)&EM<&QO9&4@/2!F86QS92D-"B`@
M("![#0H@("`@("`@("1D871A(#T@)'1H:7,M/F-M9$%R=&EC;&4H)&%R=&EC
M;&4I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9&%T82DI('L-"@D@
M("`@<F5T=7)N("1D871A.PT*"7T-"@T*"6EF("@D:6UP;&]D92`]/2!T<G5E
M*2![#0H)("`@("1D871A(#T@:6UP;&]D92@B7')<;B(L("1D871A*3L-"@E]
M#0H-"@ER971U<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&=E=$AE861E<B@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE
M(&AE861E<B!O9B!A;B!A<G1I8VQE#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M;6EX960@)&%R=&EC;&4@16ET:&5R('1H92`H<W1R:6YG*2!M97-S86=E+6ED
M(&]R('1H92`H:6YT*2!M97-S86=E+6YU;6)E<B!O;B!T:&4@<V5R=F5R(&]F
M('1H92!A<G1I8VQE('1O(&9E=&-H+@T*("`@("`J#0H@("`@("H@0')E='5R
M;B!M:7AE9"`H;V)J96-T*2!H96%D97(@;V)J96-T(&]N('-U8V-E<W,@;W(@
M*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B!`<V5E($YE=%].3E10.CIG971(96%D97)287<H
M*0T*("`@("`J($!S964@3F5T7TY.5%`Z.F=E=$%R=&EC;&4H*0T*("`@("`J
M($!S964@3F5T7TY.5%`Z.F=E=$)O9'DH*0T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$AE861E<B@D87)T:6-L92D-"B`@("![#0H@("`@("`@("1H96%D
M97(@/2`D=&AI<RT^9V5T2&5A9&5R4F%W*"1A<G1I8VQE+"!F86QS92D[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1H96%D97(I*2![#0H)("`@(')E
M='5R;B`D:&5A9&5R#3L-"@E]#0H-"@DD2"`]($YE=%].3E107TAE861E<CHZ
M8W)E871E*"1H96%D97(I.PT*#0H)<F5T=7)N("1(.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!G971(96%D97)287<H*0T*#0H@("`@+RHJ
M#0H@("`@("H@1V5T('1H92!H96%D97(@;V8@86X@87)T:6-L92`H<F%W(&1A
M=&$I#0H@("`@("H-"B`@("`@*B!`<&%R86T@;6EX960@)&%R=&EC;&4@16ET
M:&5R('1H92`H<W1R:6YG*2!M97-S86=E+6ED(&]R('1H92`H:6YT*2!M97-S
M86=E+6YU;6)E<B!O;B!T:&4@<V5R=F5R(&]F('1H92!A<G1I8VQE('1O(&9E
M=&-H+@T*("`@("`J($!P87)A;2!O<'1I;VYA;"!B;V]L("1I;7!L;V1E(%=H
M96X@=')U92!T:&4@<F5S=6QT(&%R<F%Y(&ES(&EM<&QO9&5D('1O(&$@<W1R
M:6YG+"!D969A=6QT<R!T;R!F86QS92X-"B`@("`@*@T*("`@("`J($!R971U
M<FX@;6EX960@*&%R<F%Y+W-T<FEN9RD@:&5A9&5R(&9I96QD<R!O;B!S=6-C
M97-S(&]R("AO8FIE8W0I('!E87)?97)R;W(@;VX@9F%I;'5R90T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-E92!.971?3DY44#HZ9V5T2&5A
M9&5R*"D-"B`@("`@*B!`<V5E($YE=%].3E10.CIG971!<G1I8VQE4F%W*"D-
M"B`@("`@*B!`<V5E($YE=%].3E10.CIG971";V1Y4F%W*"D-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971(96%D97)287<H)&%R=&EC;&4L("1I;7!L;V1E
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D9&%T82`]("1T:&ES+3YC;61(
M96%D*"1A<G1I8VQE*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&1A
M=&$I*2![#0H)("`@(')E='5R;B`D9&%T83L-"@E]#0H-"@EI9B`H)&EM<&QO
M9&4@/3T@=')U92D@>PT*"2`@("`D9&%T82`](&EM<&QO9&4H(EQR7&XB+"`D
M9&%T82D[#0H)?0T*#0H)<F5T=7)N("1D871A.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!G971";V1Y*"D-"@T*"2\O($YO="!W<FET=&5N
M('EE="XN+@T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$)O9'E287<H
M*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!B;V1Y(&]F(&%N(&%R=&EC
M;&4@*')A=R!D871A*0T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1A
M<G1I8VQE($5I=&AE<B!T:&4@;65S<V%G92UI9"!O<B!T:&4@;65S<V%G92UN
M=6UB97(@;VX@=&AE('-E<G9E<B!O9B!T:&4@87)T:6-L92!T;R!F971C:"X-
M"B`@("`@*B!`<&%R86T@;W!T:6]N86P@8F]O;"`D:6UP;&]D92!7:&5N('1R
M=64@=&AE(')E<W5L="!A<G)A>2!I<R!I;7!L;V1E9"!T;R!A('-T<FEN9RP@
M9&5F875L=',@=&\@9F%L<V4N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("AA<G)A>2]S=')I;F<I(&)O9'D@;VX@<W5C8V5S<R!O<B`H;V)J96-T
M*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J($!S964@3F5T7TY.5%`Z.F=E=$)O9'DH*0T*("`@("`J($!S
M964@3F5T7TY.5%`Z.F=E=$AE861E<E)A=R@I#0H@("`@("H@0'-E92!.971?
M3DY44#HZ9V5T07)T:6-L95)A=R@I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T0F]D>5)A=R@D87)T:6-L92P@)&EM<&QO9&4@/2!F86QS92D-"B`@("![
M#0H@("`@("`@("1D871A(#T@)'1H:7,M/F-M9$)O9'DH)&%R=&EC;&4I.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9&%T82DI('L-"@D@("`@<F5T
M=7)N("1D871A.PT*"7T-"@D-"@EI9B`H)&EM<&QO9&4@/3T@=')U92D@>PT*
M"2`@("`D9&%T82`](&EM<&QO9&4H(EQR7&XB+"`D9&%T82D[#0H)?0T*"0T*
M"7)E='5R;B`D9&%T83L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9V5T1W)O=7!!<G1I8VQE<R@I#0H-"B`@("`O*BH-"B`@("`@*B!%>'!E
M<FEM96YT86P-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("H@0'-I;F-E(#`N,PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$=R;W5P
M07)T:6-L97,H)&YE=W-G<F]U<"D-"B`@("![#0H@("`@("`@(')E='5R;B`D
M=&AI<RT^8VUD3&ES=&=R;W5P*"1N97=S9W)O=7`I.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!G971.97='<F]U<',H*0T*#0H@("`@+RHJ
M#0H@("`@("H@17AP97)I;65N=&%L#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J($!S:6YC92`P+C,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971.97='<F]U<',H)'1I;64I#0H@("`@>PT*"7-W:71C:"`H9V5T
M='EP92@D=&EM92DI('L-"@D@("`@8V%S92`G:6YT96=E<B<Z#0H)"6)R96%K
M.PT*"2`@("!C87-E("=S=')I;F<G.@T*"0DD=&EM92`]("AI;G0I('-T<G1O
M=&EM92@D=&EM92D[#0H)"6)R96%K.PT*"2`@("!D969A=6QT.@T*"2`@("`@
M("`@<F5T=7)N("1T:&ES+3YT:')O=T5R<F]R*"<G*3L-"@E]#0H-"@ER971U
M<FX@)'1H:7,M/F-M9$YE=V=R;W5P<R@D=&EM92D[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&=E=$YE=TYE=W,H*0T*#0H@("`@+RHJ#0H@
M("`@("H@17AP97)I;65N=&%L#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J($!S:6YC92`P+C,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!G971.97=.97=S*"1T:6UE+"`D;F5W<V=R;W5P<R`]("<J)RD-"B`@("![
M#0H)<W=I=&-H("AG971T>7!E*"1T:6UE*2D@>PT*"2`@("!C87-E("=I;G1E
M9V5R)SH-"@D)8G)E86L[#0H)("`@(&-A<V4@)W-T<FEN9R<Z#0H)"21T:6UE
M(#T@*&EN="D@<W1R=&]T:6UE*"1T:6UE*3L-"@D)8G)E86L[#0H)("`@(&1E
M9F%U;'0Z#0H)("`@("`@("!R971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G55!3
M+BXN)RD[#0H)?0T*#0H)<F5T=7)N("1T:&ES+3YC;61.97=N97=S*"1T:6UE
M+"`D;F5W<V=R;W5P<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$1A=&4H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!.3E10
M+7-E<G9E<B=S(&EN=&5R;F%L(&1A=&4-"B`@("`@*@T*("`@("`J($=E="!T
M:&4@9&%T92!F<F]M('1H92!N97=S<V5R=F5R(&9O<FUA="!O9B!R971U<FYE
M9"!D871E.@T*("`@("`J#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L(&EN="`D
M9F]R;6%T#0H@("`@("H@("T@,#H@)&1A=&4@+2!T:6UE<W1A;7`-"B`@("`@
M*B`@+2`Q.B`D9&%T95LG>2==("T@>65A<@T*("`@("`J("`@("`@("1D871E
M6R=M)UT@+2!M;VYT:`T*("`@("`J("`@("`@("1D871E6R=D)UT@+2!D87D-
M"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&UI>&5D*2!D871E(&]N
M('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<VEN8V4@,"XS#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T1&%T92@D9F]R;6%T(#T@,2D-"B`@("![
M#0H@("`@("`@("1D871E(#T@)'1H:7,M/F-M9$1A=&4H*3L-"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&1A=&4I*2![#0H)("`@(')E='5R;B`D9&%T
M93L-"@E]#0H-"@ES=VET8V@@*"1F;W)M870I('L-"@D@("`@8V%S92`Q.@T*
M"2`@("`@("`@<F5T=7)N(&%R<F%Y*"=Y)R`]/B!S=6)S='(H)&1A=&4L(#`L
M(#0I+"`G;2<@/3X@<W5B<W1R*"1D871E+"`T+"`R*2P@)V0G(#T^('-U8G-T
M<B@D9&%T92P@-BP@,BDI.PT*"2`@("`@("`@8G)E86L[#0H-"@D@("`@8V%S
M92`P.@T*"2`@("!D969A=6QT.@T*"2`@("`@("`@<F5T=7)N("1D871E.PT*
M"2`@("`@("`@8G)E86L[#0H)?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!C;W5N="@I#0H-"B`@("`O*BH-"B`@("`@*B!.=6UB97(@;V8@
M87)T:6-L97,@:6X@8W5R<F5N=&QY('-E;&5C=&5D(&=R;W5P#0H@("`@("H-
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@;G5M8F5R(&]F(&%R=&EC;&4@:6X@
M9W)O=7`-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S:6YC92`P
M+C,-"B`@("`@*B!`<V5E($YE=%].3E10.CIG<F]U<"@I#0H@("`@("H@0'-E
M92!.971?3DY44#HZ9FER<W0H*0T*("`@("`J($!S964@3F5T7TY.5%`Z.FQA
M<W0H*0T*("`@("`J($!S964@3F5T7TY.5%`Z.G-E;&5C=$=R;W5P*"D-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!C;W5N="@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)'1H:7,M/E]C=7)R96YT1W)O=7!;)V-O=6YT)UT[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&QA<W0H*0T*#0H@("`@+RHJ#0H@
M("`@("H@36%X:6UU;2!A<G1I8VQE(&YU;6)E<B!I;B!C=7)R96YT;'D@<V5L
M96-T960@9W)O=7`-"B`@("`@*@T*("`@("`J($!R971U<FX@:6YT96=E<B!N
M=6UB97(@;V8@;&%S="!A<G1I8VQE#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B!`<VEN8V4@,"XS#0H@("`@("H@0'-E92!.971?3DY44#HZ9FER
M<W0H*0T*("`@("`J($!S964@3F5T7TY.5%`Z.F=R;W5P*"D-"B`@("`@*B!`
M<V5E($YE=%].3E10.CIC;W5N="@I#0H@("`@("H@0'-E92!.971?3DY44#HZ
M<V5L96-T1W)O=7`H*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&QA<W0H*0T*
M("`@('L-"@ER971U<FX@)'1H:7,M/E]C=7)R96YT1W)O=7!;)VQA<W0G73L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9FER<W0H*0T*#0H@
M("`@+RHJ#0H@("`@("H@36EN:6UU;2!A<G1I8VQE(&YU;6)E<B!I;B!C=7)R
M96YT;'D@<V5L96-T960@9W)O=7`-"B`@("`@*@T*("`@("`J($!R971U<FX@
M:6YT96=E<B!N=6UB97(@;V8@9FER<W0@87)T:6-L90T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N,PT*("`@("`J($!S964@3F5T
M7TY.5%`Z.FQA<W0H*0T*("`@("`J($!S964@3F5T7TY.5%`Z.F=R;W5P*"D-
M"B`@("`@*B!`<V5E($YE=%].3E10.CIC;W5N="@I#0H@("`@("H@0'-E92!.
M971?3DY44#HZ<V5L96-T1W)O=7`H*0T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&9I<G-T*"D-"B`@("![#0H)<F5T=7)N("1T:&ES+3Y?8W5R<F5N=$=R;W5P
M6R=F:7)S="==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G
M<F]U<"@I#0H-"B`@("`O*BH-"B`@("`@*B!#=7)R96YT;'D@<V5L96-T960@
M9W)O=7`-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(&=R;W5P(&YA
M;64-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S:6YC92`P+C,-
M"B`@("`@*B!`<V5E($YE=%].3E10.CIF:7)S="@I#0H@("`@("H@0'-E92!.
M971?3DY44#HZ;&%S="@I#0H@("`@("H@0'-E92!.971?3DY44#HZ8V]U;G0H
M*0T*("`@("`J($!S964@3F5T7TY.5%`Z.G-E;&5C=$=R;W5P*"D-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G<F]U<"@I#0H@("`@>PT*"7)E='5R;B`D=&AI
M<RT^7V-U<G)E;G1'<F]U<%LG9W)O=7`G73L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@8V]M;6%N9"@I#0H-"B`@("`O*BH-"B`@("`@*B!)
M<W-U92!A(&-O;6UA;F0@=&\@=&AE($Y.5%`@<V5R=F5R#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;60@5&AE(&-O;6UA;F0@=&\@;&%U;F-H
M+"!I93H@(D%25$E#3$4@,3`P-#@U,R(-"B`@("`@*@T*("`@("`J($!R971U
M<FX@;6EX960@*&EN="D@<F5S<&]N<V4@8V]D92!O;B!S=6-C97-S(&]R("AO
M8FIE8W0I('!E87)?97)R;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8V]M;6%N9"@D8VUD*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5N9$-O;6UA;F0H)&-M
M9"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"GT-"C\^#0H`````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O3F5T+TY.5%`O2&5A9&5R+G!H<```````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C8R,#8`,3`T,3<S-C,P,#8`
M,#(P-38P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($-O<'ER:6=H
M=""I(#(P,#,@2&5I;F\@2"X@1V5H;'-E;BX@06QL(%)I9VAT<R!297-E<G9E
M9"X@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@:'1T
M<#HO+W=W=RYH96EN;RYG96AL<V5N+F1K+W-O9G1W87)E+VQI8V5N<V4@("`@
M("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R!\(%1H:7,@=V]R:R`H:6YC;'5D:6YG('-O
M9G1W87)E+"!D;V-U;65N=',L(&]R(&]T:&5R(')E;&%T960@:71E;7,I(&ES
M("!\#0HO+R!\(&)E:6YG('!R;W9I9&5D(&)Y('1H92!C;W!Y<FEG:'0@:&]L
M9&5R<R!U;F1E<B!T:&4@9F]L;&]W:6YG(&QI8V5N<V4N("!\#0HO+R!\($)Y
M(&]B=&%I;FEN9RP@=7-I;F<@86YD+V]R(&-O<'EI;F<@=&AI<R!W;W)K+"!Y
M;W4@*'1H92!L:6-E;G-E92D@("`@("!\#0HO+R!\(&%G<F5E('1H870@>6]U
M(&AA=F4@<F5A9"P@=6YD97)S=&]O9"P@86YD('=I;&P@8V]M<&QY('=I=&@@
M=&AE("`@("`@("!\#0HO+R!\(&9O;&QO=VEN9R!T97)M<R!A;F0@8V]N9&ET
M:6]N<SH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(%!E<FUI
M<W-I;VX@=&\@=7-E+"!C;W!Y+"!M;V1I9GDL(&%N9"!D:7-T<FEB=71E('1H
M:7,@<V]F='=A<F4@86YD("`@("!\#0HO+R!\(&ET<R!D;V-U;65N=&%T:6]N
M+"!W:71H(&]R('=I=&AO=70@;6]D:69I8V%T:6]N+"!F;W(@86YY('!U<G!O
M<V4@86YD("!\#0HO+R!\('=I=&AO=70@9F5E(&]R(')O>6%L='D@:7,@:&5R
M96)Y(&=R86YT960L('!R;W9I9&5D('1H870@>6]U(&EN8VQU9&4@("!\#0HO
M+R!\('1H92!F;VQL;W=I;F<@;VX@04Q,(&-O<&EE<R!O9B!T:&4@<V]F='=A
M<F4@86YD(&1O8W5M96YT871I;VX@;W(@("`@("!\#0HO+R!\('!O<G1I;VYS
M('1H97)E;V8L(&EN8VQU9&EN9R!M;V1I9FEC871I;VYS+"!T:&%T('EO=2!M
M86ME.B`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\#0HO+R!\(#$N(%1H92!F=6QL('1E>'0@;V8@=&AI<R!.3U1)0T4@
M:6X@82!L;V-A=&EO;B!V:65W86)L92!T;R!U<V5R<R!O9B`@("!\#0HO+R!\
M("`@('1H92!R961I<W1R:6)U=&5D(&]R(&1E<FEV871I=F4@=V]R:RX@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R!\(#(N($%N>2!P<F4M97AI<W1I;F<@:6YT
M96QL96-T=6%L('!R;W!E<G1Y(&1I<V-L86EM97)S+"!N;W1I8V5S+"!O<B`@
M("!\#0HO+R!\("`@('1E<FUS(&%N9"!C;VYD:71I;VYS+B!)9B!N;VYE(&5X
M:7-T+"!A('-H;W)T(&YO=&EC92!O9B!T:&4@("`@("`@("!\#0HO+R!\("`@
M(&9O;&QO=VEN9R!F;W)M("AH>7!E<G1E>'0@:7,@<')E9F5R<F5D+"!T97AT
M(&ES('!E<FUI='1E9"D@<VAO=6QD("!\#0HO+R!\("`@(&)E('5S960@=VET
M:&EN('1H92!B;V1Y(&]F(&%N>2!R961I<W1R:6)U=&5D(&]R(&1E<FEV871I
M=F4@8V]D93H@("!\#0HO+R!\("`@(")#;W!Y<FEG:'0@J2`R,#`S($AE:6YO
M($@N($=E:&QS96XN($%L;"!2:6=H=',@4F5S97)V960N("`@("`@("`@("!\
M#0HO+R!\("`@("!H='1P.B\O=W=W+FAE:6YO+F=E:&QS96XN9&LO<V]F='=A
M<F4O;&EC96YS92(@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(#,N($YO=&EC92!O9B!A;GD@
M8VAA;F=E<R!O<B!M;V1I9FEC871I;VYS('1O('1H92!F:6QE<RP@:6YC;'5D
M:6YG("`@("!\#0HO+R!\("`@('1H92!D871E(&-H86YG97,@=V5R92!M861E
M+B`H5V4@<F5C;VUM96YD('EO=2!P<F]V:61E(%5227,@=&\@("`@("!\#0HO
M+R!\("`@('1H92!L;V-A=&EO;B!F<F]M('=H:6-H('1H92!C;V1E(&ES(&1E
M<FEV960N*2`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\#0HO+R!\(%1(25,@4T]&5%=!4D4@04Y$($1/
M0U5-14Y4051)3TX@25,@4%)/5DE$140@(D%3($E3+"(@04Y$($-/4%E224=(
M5"`@("!\#0HO+R!\($A/3$1%4E,@34%+12!.3R!215!215-%3E1!5$E/3E,@
M3U(@5T%24D%.5$E%4RP@15A04D534R!/4B!)35!,245$+"`@("!\#0HO+R!\
M($E.0TQ51$E.1R!"550@3D]4($Q)34E4140@5$\L(%=!4E)!3E1)15,@3T8@
M34520TA!3E1!0DE,2519($]2("`@("`@("!\#0HO+R!\($9)5$Y%4U,@1D]2
M($%.62!005)424-53$%2(%!54E!/4T4@3U(@5$A!5"!42$4@55-%($]&(%1(
M12!33T945T%212`@("!\#0HO+R!\($]2($1/0U5-14Y4051)3TX@5TE,3"!.
M3U0@24Y&4DE.1T4@04Y9(%1(25)$(%!!4E19(%!!5$5.5%,L("`@("`@("`@
M("!\#0HO+R!\($-/4%E224=(5%,L(%12041%34%22U,@3U(@3U1(15(@4DE'
M2%13+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($-/4%E224=(5"!(3TQ$
M15)3(%=)3$P@3D]4($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%
M0U0L("`@("`@("!\#0HO+R!\(%-014-)04P@3U(@0T].4T51545.5$E!3"!$
M04U!1T53($%225-)3D<@3U54($]&($%.62!54T4@3T8@5$A%("`@("`@("!\
M#0HO+R!\(%-/1E1705)%($]2($1/0U5-14Y4051)3TXN("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(%1H92!N86UE(&%N9"!T<F%D
M96UA<FMS(&]F(&-O<'ER:6=H="!H;VQD97)S(&UA>2!.3U0@8F4@=7-E9"!I
M;B`@("`@("!\#0HO+R!\(&%D=F5R=&ES:6YG(&]R('!U8FQI8VET>2!P97)T
M86EN:6YG('1O('1H92!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC+"!\#0HO
M+R!\('=R:71T96X@<')I;W(@<&5R;6ES<VEO;BX@5&ET;&4@=&\@8V]P>7)I
M9VAT(&EN('1H:7,@<V]F='=A<F4@86YD(&%N>2!\#0HO+R!\(&%S<V]C:6%T
M960@9&]C=6UE;G1A=&EO;B!W:6QL(&%T(&%L;"!T:6UE<R!R96UA:6X@=VET
M:"!C;W!Y<FEG:'0@("`@("!\#0HO+R!\(&AO;&1E<G,N("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R!\(%1H:7,@;&EC96YS92!I<R!B87-E9"!O
M;B!T:&4@(E<S0ZX@4T]&5%=!4D4@3D]424-%($%.1"!,24-%3E-%(BX@("`@
M("!\#0HO+R!\($YO(&-H86YG97,@:&%V92!B965N(&UA9&4@=&\@=&AE(")7
M,T.N(%-/1E1705)%($Y/5$E#12!!3D0@3$E#14Y312(L("!\#0HO+R!\(&5X
M8V5P="!F;W(@=&AE(')E9F5R96YC97,@=&\@=&AE(&-O<'ER:6=H="!H;VQD
M97(L('=H:6-H(&AA<R!E:71H97(@("!\#0HO+R!\(&)E96X@8VAA;F=E<R!O
M<B!R96UO=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R`D260Z($AE
M861E<BYP:'`L=B`Q+C$P(#(P,#,O,3`O,3`@,34Z,S4Z,C(@:&5I;F\@17AP
M("0-"@T*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0H-"@T*9&5F:6YE*"=.
M151?3DY44%](14%$15)?4T547U5.1D],1"<L(#$I.PT*9&5F:6YE*"=.151?
M3DY44%](14%$15)?4T547T1%0T]$12<L(#(I.PT*9&5F:6YE*"=.151?3DY4
M4%](14%$15)?4T547T-,14%.)RP@-"D[#0ID969I;F4H)TY%5%].3E107TA%
M041%4E]3151?2T5%4$-!4T4G+"`X*3L-"F1E9FEN92@G3D547TY.5%!?2$5!
M1$527U-%5%]$149!54Q4)RP@3D547TY.5%!?2$5!1$527U-%5%]#3$5!3B!\
M($Y%5%].3E107TA%041%4E]3151?54Y&3TQ$('P@3D547TY.5%!?2$5!1$52
M7U-%5%]$14-/1$4I.PT*#0ID969I;F4H)TY%5%].3E107TA%041%4E]'151?
M1D],1"<L(#$I.PT*9&5F:6YE*"=.151?3DY44%](14%$15)?1T547T5.0T]$
M12<L(#(I.PT*9&5F:6YE*"=.151?3DY44%](14%$15)?1T547T1%1D%53%0G
M+"!.151?3DY44%](14%$15)?1T547T5.0T]$12!\($Y%5%].3E107TA%041%
M4E]'151?1D],1"D[#0H-"@T*+RHJ#0H@*B!4:&4@3F5T7TY.5%!?2&5A9&5R
M(&-L87-S#0H@*@T*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C$P("0-"B`J
M($!P86-K86=E($YE=%].3E10#0H@*@T*("H@0&%U=&AO<B!(96EN;R!(+B!'
M96AL<V5N(#QH96EN;T!G96AL<V5N+F1K/@T*("HO#0IC;&%S<R!.971?3DY4
M4%](96%D97(-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@+RHJ
M#0H@("`@("H@0V]N=&%I;F5R(&9O<B!T:&4@:&5A9&5R(&9I96QD<PT*("`@
M("`J#0H@("`@("H@0'9A<B`@("!A<G)A>0T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("HO#0H@("`@=F%R("1F:65L9',[#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J($-O
M;G-T<G5C=&]R#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J($!S:6YC92`P+C$-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!.971?3DY4
M4%](96%D97(H*0T*("`@('L-"@DO+R!297-E="!O8FIE8W0-"@DD=&AI<RT^
M<F5S970H*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<F5S
M970H*0T*("`@(`T*("`@("\J*@T*("`@("`J(%)E<V5T('1H92!F:65L9"!C
M;VYT86EN97(-"B`@("`@*B`-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J($!S:6YC92`P+C$-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R97-E="@I
M#0H@("`@>PT*"21T:&ES+3YF:65L9',@/2!A<G)A>2@I.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!C<F5A=&4H*0T*("`@(`T*("`@("\J
M*@T*("`@("`J($-R96%T92!A(&YE=R!I;G-T86YC92!O9B!.971?3DY44%](
M96%D97(-"B`@("`@*@T*("`@("`J($!P87)A;2!O<'1I;VYA;"!M:7AE9"`D
M:6YP=70@0V%N(&)E(&%N>2!O9B!T:&4@9F]L;&]W:6YG.@T*("`@("`J(`D@
M("`)("`@("`@("`@("`@("`@("`@("`H<W1R:6YG*2!21D,R.#(R('-T>6QE
M(&AE861E<B!L:6YE<R`H0U),1B!I;F-L=61E9"D-"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("AA<G)A>2D@(%)&0S(X,C(@<W1Y;&4@
M:&5A9&5R(&QI;F5S("A#4DQ&(&YO="!I;F-L=61E9"D-"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("AO8FIE8W0I($YE=%].3E107TAE
M861E<B!O8FIE8W0-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AO8FIE8W0I($YE=%].3E107TUE<W-A9V4@;V)J96-T#0H@("`@("H@
M#0H@("`@("H@0')E='5R;B!O8FIE8W0@3F5T7TY.5%!?2&5A9&5R(&]B:F5C
M=`T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N,0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N("8@8W)E871E*"1I;G!U="`](&YU;&PI
M#0H@("`@>PT*"7-W:71C:"`H=')U92D@>PT*#0H)("`@("\O($YU;&P-"@D@
M("`@8V%S92!I<U]N=6QL*"1I;G!U="D[#0H)"21/8FIE8W0@/2!N97<@3F5T
M7TY.5%!?2&5A9&5R*"D[#0H)("`@("`@("!R971U<FX@)$]B:F5C=#L-"@D)
M8G)E86L[#0H-"@T)("`@("\O($]B:F5C=`T*"2`@("!C87-E(&ES7V]B:F5C
M="@D:6YP=70I.PT*"0ES=VET8V@@*'1R=64I('L-"@D)("`@(`T*"0D@("`@
M+R\@2&5A9&5R#0H)"2`@("!C87-E(&ES7V$H)&EN<'5T+"`G;F5T7VYN='!?
M:&5A9&5R)RDZ#0H)"0ER971U<FX@)&EN<'5T.PT*"0D)8G)E86L[#0H)"0D-
M"@D)("`@("\O($UE<W-A9V4-"@D)("`@(&-A<V4@:7-?82@D:6YP=70L("=N
M971?;FYT<%]M97-S86=E)RDZ#0H)"0ER971U<FX@)&EN<'5T+3YG971(96%D
M97(H*3L-"@D)"6)R96%K.PT*"0D)#0H)"2`@("`O+R!5;FMN;W=N(&]B:F5C
M="]C;&%S<PT*"0D@("`@9&5F875L=#H-"@D)"7)E='5R;B!014%2.CIT:')O
M=T5R<F]R*"=5;G-U<'!O<G1E9"!O8FIE8W0O8VQA<W,Z("<N9V5T7V-L87-S
M*"1I;G!U="DL(&YU;&PI.PT*"0E]#0H)"6)R96%K.PT*#0H)("`@("\O(%-T
M<FEN9R`F($%R<F%Y#0H)("`@(&-A<V4@:7-?<W1R:6YG*"1I;G!U="D[#0H)
M("`@(&-A<V4@:7-?87)R87DH)&EN<'5T*3L-"@D@("`@("`@("1/8FIE8W0@
M/2!N97<@3F5T7TY.5%!?2&5A9&5R*"D[#0H)"212(#T@)$]B:F5C="T^<V5T
M1FEE;&1S*"1I;G!U="D-.PT*"0EI9B`H4$5!4CHZ:7-%<G)O<B@D4BDI('L-
M"@D)("`@(')E='5R;B`D4CL-"@D)?0T*"0ER971U<FX@)$]B:F5C=#L-"@D)
M8G)E86L[#0H-"@D@("`@+R\@56YK;F]W;B!T>7!E#0H)("`@(&1E9F%U;'0Z
M#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=5;G-U<'!O<G1E9"!O8FIE
M8W0O8VQA<W,Z("<N9V5T7V-L87-S*"1I;G!U="DL(&YU;&PI.PT*"7T-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@861D*"D-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!!9&0@82!N97<@9FEE;&0-"B`@("`@*B`-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T86<-"B`@("`@*B!`<&%R86T@<W1R:6YG("1V
M86QU90T*("`@("`J($!P87)A;2!O<'1I;VYA;"!I;G0@)&EN9&5X#0H@("`@
M("H@#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<VEN8V4@,"XQ
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D*"1T86<L("1V86QU92P@)&EN
M9&5X(#T@;G5L;"D-"B`@("![#0H)+R\@061D(&AE861E<B!T;R`D<F5T=7)N
M(&%R<F%Y#0H@("`@"6EF("AI<W-E="@D=&AI<RT^9FEE;&1S6R1T86==*2`F
M)B!I<U]A<G)A>2@D=&AI<RT^9FEE;&1S6R1T86==*2D@>PT*"2`@("`O+R!4
M:&4@:&5A9&5R(&YA;64@:&%S(&%L<F5A9'D@8F5E;B!U<V5D(&%T(&QE87-T
M('1W;R!T:6UE<RX-"B`@("`@("`@("`@("1T:&ES+3YF:65L9'-;)'1A9UU;
M72`]("1V86QU93L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YF
M:65L9'-;)'1A9UTI*2![#0H)("`@("\O(%1H92!H96%D97(@;F%M92!H87,@
M86QR96%D>2!B965N('5S960@;VYE('1I;64@+3X@8VAA;F=E('1O(&YE9'1E
M9"!V86QU97,N#0H@("`@("`@("`@("`D=&AI<RT^9FEE;&1S6R1T86==(#T@
M87)R87DH)'1H:7,M/F9I96QD<ULD=&%G72P@)'9A;'5E*3L-"B`@("`@("`@
M?2!E;'-E('L-"@D@("`@+R\@5&AE(&AE861E<B!N86UE(&AA<R!N;W0@=7-E
M9"!U;G1I;"!N;W<N#0H)("`@("1T:&ES+3YF:65L9'-;)'1A9UT@/2`D=F%L
M=64[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@<F5P;&%C92@I#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4F5P;&%C92!A
M(&9I96QD)W,@=F%L=64-"B`@("`@*B`-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T86<-"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU90T*("`@("`J($!P
M87)A;2!O<'1I;VYA;"!I;G0@)&EN9&5X#0H@("`@("H@#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B!`<VEN8V4@,"XQ#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<F5P;&%C92@D=&%G+"`D=F%L=64L("1I;F1E>"`](&YU;&PI
M#0H@("`@>PT*"6EF("AI<W-E="@D=&AI<RT^9FEE;&1S6R1T86==*2D@>PT*
M"2`@("!I9B`H)&EN9&5X(#T]/2!N=6QL*2![#0H)"21T:&ES+3YF:65L9'-;
M)'1A9UT@/2`D=F%L=64[#0H)("`@('T@96QS92![#0H)"6EF("AI<U]A<G)A
M>2@D=&AI<RT^9FEE;&1S6R1T86==*2D@>PT*"0D@("`@)'1H:7,M/F9I96QD
M<ULD=&%G75LD:6YD97A=(#T@)'9A;'5E.PT*"0E](&5L<V4@>PT*+R]43T1/
M.B!#=7)R96YT;'D@:6=N;W)E<R`D:6YD97@L(&%N9"!J=7-T(')E<&QA8V5S
M('1H92!V86QU90T*"0D@("`@)'1H:7,M/F9I96QD<ULD=&%G72`]("1V86QU
M93L-"@D)?0T*"2`@("!]#0H)?2!E;'-E('L-"@D@("`@)'1H:7,M/F9I96QD
M<ULD=&%G72`]("1V86QU93L-"@E]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&1E;&5T92@I#0H@("`@#0H@("`@+RHJ#0H@("`@("H@1&5L
M971E(&$@9FEE;&0-"B`@("`@*B`-"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M86<-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@:6YT("1I;F1E>`T*("`@("`J
M(`T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N,0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&1E;&5T92@D=&%G+"`D:6YD97@@/2!N
M=6QL*0T*("`@('L-"@EI9B`H:7-S970H)'1H:7,M/F9I96QD<ULD=&%G72DI
M('L-"@D@("`@:68@*"1I;F1E>"`]/2!N=6QL*2![#0H)"75N<V5T*"1T:&ES
M+3YF:65L9'-;)'1A9UTI.PT*"2`@("!](&5L<V4@>PT*"0EI9B`H:7-?87)R
M87DH)'1H:7,M/F9I96QD<ULD=&%G72DI('L-"@D)("`@('5N<V5T*"1T:&ES
M+3YF:65L9'-;)'1A9UU;)&EN9&5X72D[#0H)"7T@96QS92![#0H)"2`@("!U
M;G-E="@D=&AI<RT^9FEE;&1S6R1T86==*3L-"@D)?0T*"2`@("!]#0H)?2!E
M;'-E('L-"@D@("`@+R\@1&\@;F]T:&EN9RXN+@T*"7T-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@9V5T*"D-"B`@("`-"B`@("`O*BH-"B`@
M("`@*B!'971S('1H92!V86QU92!O9B!A(&AE861E<B!F:65L9`T*("`@("`J
M(`T*("`@("`J($!P87)A;2!S=')I;F<@)'1A9PT*("`@("`J($!P87)A;2!O
M<'1I;VYA;"!I;G0@)&EN9&5X("AD969A=6QT<R!T;R`P*0T*("`@("`J(`T*
M("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B!`<VEN8V4@,"XQ#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T
M*"1T86<L("1I;F1E>"`](#`I#0H@("`@>PT*"6EF("@A:7-S970H)'1H:7,M
M/F9I96QD<ULD=&%G72DI('L-"@D@("`@<F5T=7)N(&YU;&P[#0H)?0T*#0H)
M:68@*&ES7V%R<F%Y*"1T:&ES+3YF:65L9'-;)'1A9UTI*2![#0H)("`@(')E
M='5R;B`D=&AI<RT^9FEE;&1S6R1T86==6R1I;F1E>%T[#0H)?2!E;'-E('L-
M"@D@("`@:68@*"1I;F1E>"`]/2`P*2![#0H)"7)E='5R;B`D=&AI<RT^9FEE
M;&1S6R1T86==.PT*"2`@("!](&5L<V4@>PT*"2`@("`@("`@<F5T=7)N(&YU
M;&P[#0H)("`@('T-"@E]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$%L;"@I#0H@("`@#0H@("`@+RHJ#0H@("`@("H@1V5T<R!T:&4@
M=F%L=65S(&]F(&$@86QL(&]C8W5R96YC97,@;V8@82!F:65L9`T*("`@("`J
M(`T*("`@("`J($!P87)A;2!S=')I;F<@)'1A9PT*("`@("`J($!P87)A;2!O
M<'1I;VYA;"!I;G0@)&EN9&5X#0H@("`@("H@#0H@("`@("H@0')E='5R;B!A
M<G)A>0T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N
M,0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$%L;"@D=&%G*0T*("`@('L-
M"@EI9B`H(6ES<V5T*"1T:&ES+3YF:65L9'-;)'1A9UTI*2![#0H)("`@(&%R
M<F%Y*"D[#0H)?0T*#0H):68@*&ES7V%R<F%Y*"1T:&ES+3YF:65L9'-;)'1A
M9UTI*2![#0H)("`@(')E='5R;B`D=&AI<RT^9FEE;&1S6R1T86==.PT*"7T@
M96QS92![#0HO+R!43T1/.B!7:&%T('1O(&1O+"!W:&5N(&YO="!A<G)A>2!B
M=70@:6YD97@@:7,@<V5T+BXN#0H)("`@(')E='5R;B!A<G)A>2@D=&AI<RT^
M9FEE;&1S6R1T86==*3L-"@E]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&-O=6YT*"D-"B`@("`-"B`@("`O*BH-"B`@("`@*B!2971U<FYS
M('1H92!N=6UB97(@;V8@=&EM97,@=&AE(&=I=F5N(&9I96QD('1A9R!A<'!E
M87)S(&EN('1H92!H96%D97(N#0H@("`@("H@#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&%G#0H@("`@("H@#0H@("`@("H@0')E='5R;B!I;G0-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S:6YC92`P+C$-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!C;W5N="@D=&%G*0T*("`@('L-"@EI9B`H(6ES<V5T
M*"1T:&ES+3YF:65L9'-;)'1A9UTI*2![#0H)("`@(')E='5R;B`P.PT*"7T-
M"@T*"6EF("AI<U]A<G)A>2@D=&AI<RT^9FEE;&1S6R1T86==*2D@>PT*"2`@
M("!R971U<FX@8V]U;G0H)'1H:7,M/F9I96QD<ULD=&%G72D[#0H)?2!E;'-E
M('L-"@D@("`@<F5T=7)N(#$[#0H)?0T*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!T86=S*"D-"B`@("`-"B`@("`O*BH-"B`@("`@*B!2971U
M<FYS(&%N(&%R<F%Y(&]F(&%L;"!T:&4@=&%G<R!T:&%T(&5X:7-T(&EN('1H
M92!H96%D97(N#0H@("`@("H@16%C:"!T86<@=VEL;"!O;FQY(&%P<&5A<B!I
M;B!T:&4@;&ES="!O;F-E+@T*("`@("`J(`T*("`@("`J($!R971U<FX@87)R
M87D-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S:6YC92`P+C$-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!T86=S*"D-"B`@("![#0H)<F5T=7)N
M(&%R<F%Y7VME>7,H)'1H:7,M/F9I96QD<RD[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&-L96%N*"D-"B`@("`-"B`@("`O*BH-"B`@("`@
M*B!296UO=F4@86YY(&AE861E<B!F:65L9"!T:&%T(&]N;'D@8V]N=&%I;G,@
M=VAI=&5S<&%C92X-"B`@("`@*B`-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J($!S:6YC92`P+C$-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;&5A
M;B@I#0H@("`@>PT*"69O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/F9I96QD
M<RD@87,@)'1A9RD@>PT*"2`@("!I9B`H:7-?87)R87DH)'1H:7,M/F9I96QD
M<ULD=&%G72DI('L-"@D)9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^9FEE
M;&1S6R1T86==*2!A<R`D:2D@>PT*"0D@("`@:68@*'1R:6TH)'1H:7,M/F9I
M96QD<ULD=&%G75LD:5TI(#T]("<G*2![#0H)"0EU;G-E="@D=&AI<RT^9FEE
M;&1S6R1T86==6R1I72D[#0H)"2`@("!]#0H)"7T-"@D@("`@?2!E;'-E('L-
M"@D):68@*'1R:6TH)'1H:7,M/F9I96QD<ULD=&%G72D@/3T@)R<I('L-"@D)
M("`@('5N<V5T*"1T:&ES+3YF:65L9'-;)'1A9UTI.PT*"0E]#0H)("`@('T-
M"@E]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-E=$9I96QD
M<R@I#0H@("`@#0H@("`@+RHJ#0H@("`@("H@26UP;W)T(%)&0S(X,C(@<W1Y
M;&4@:&5A9&5R(&QI;F5S(&=I=F5N(&EN("1I;G!U="!I;G1O('1H92!O8FIE
M8W0-"B`@("`@*B`-"B`@("`@*B!`<&%R86T@;6EX960@)&EN<'5T($-A;B!B
M92!A;GD@;V8@=&AE(&9O;&QO=VEN9SH-"B`@("`@*B`)(`D@("`@("`@("`@
M("AS=')I;F<I(%)&0S(X,C(@<W1Y;&4@:&5A9&5R(&QI;F5S("A#4DQ&(&EN
M8VQU9&5D*0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@*&%R<F%Y*2`@
M4D9#,C@R,B!S='EL92!H96%D97(@;&EN97,@*$-23$8@;F]T(&EN8VQU9&5D
M*0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@*&]B:F5C="D@3F5T7TY.
M5%!?2&5A9&5R(&]B:F5C=`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M*&]B:F5C="D@3F5T7TY.5%!?365S<V%G92!O8FIE8W0-"B`@("`@*B!`<&%R
M86T@;W!T:6]N86P@)&9L86=S#0H@("`@("H@#0H@("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`@*B!`<VEN8V4@,"XQ#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T1FEE;&1S*"8D:6YP=70L("1F;&%G<R`]($Y%5%].3E107TA%041%
M4E]3151?1$5&055,5"D-"B`@("![#0H)<W=I=&-H("AT<G5E*2![#0H-"@D@
M("`@+R\@3V)J96-T#0H)("`@(&-A<V4@:7-?;V)J96-T*"1I;G!U="DZ#0H)
M"7-W:71C:"`H=')U92D@>PT*"0D@("`@8V%S92!I<U]A*"1I;G!U="P@)VYE
M=%]N;G1P7VAE861E<B<I.@T*"0D))'1H:7,@/28@)&EN<'5T.PT*"0D)8G)E
M86L[#0H)"2`@("`-"@D)("`@(&-A<V4@:7-?82@D:6YP=70L("=N971?;FYT
M<%]M97-S86=E)RDZ#0H)"0DD=&AI<R`])B`D:6YP=70M/F=E=$AE861E<B@I
M.PT*"0D)8G)E86L[#0H)"2`@("`-"@D)("`@("\O(%5N:VYO=VX@='EP90T*
M"0D@("`@9&5F875L=#H-"@D)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=5
M;G-U<'!O<G1E9"!O8FIE8W0O8VQA<W,Z("<N9V5T7V-L87-S*"1I;G!U="DL
M(&YU;&PI.PT*"0E]#0H)"6)R96%K.PT*#0H)("`@("\O(%-T<FEN9PT*"2`@
M("!C87-E(&ES7W-T<FEN9R@D:6YP=70I.@T*"0DD=&AI<RT^9FEE;&1S(#T@
M)'1H:7,M/E]P87)S95-T<FEN9R@D:6YP=70L("1F;&%G<RD[#0H)"6)R96%K
M.PT*#0H)("`@("\O($%R<F%Y#0H)("`@(&-A<V4@:7-?87)R87DH)&EN<'5T
M*3H-"@D))'1H:7,M/F9I96QD<R`]("1T:&ES+3Y?<&%R<V5!<G)A>2@D:6YP
M=70L("1F;&%G<RD[#0H)"6)R96%K.PT*#0H)("`@("\O(%5N:VYO=VX@='EP
M90T*"2`@("!D969A=6QT.@T*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G
M56YS=7!P;W)T960@='EP93H@)RYG971T>7!E*"1I;G!U="DL(&YU;&PI.PT*
M"7T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1FEE;&1S
M*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@87)R87D@;V8@:&5A9&5R
M(&9I96QD<RX-"B`@("`@*B`-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@)&9L
M86=S#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B!`<VEN8V4@,"XQ#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T1FEE;&1S*"D-"B`@("![#0H)<F5T=7)N("1T:&ES+3YF
M:65L9',[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$9I
M96QD<U-T<FEN9R@I#0H-"B`@("`O*BH-"B`@("`@*B!%>'!O<G0@82!S=')I
M;F<@;V8@4D9#,C@R,B!S='EL92!H96%D97(@<W1Y;&4@;&EN97,@9G)O;2!T
M:&4@;V)J96-T+@T*("`@("`J(`T*("`@("`J($!P87)A;2!O<'1I;VYA;"`D
M9FQA9W,-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(%)&0S(X,C(@
M<W1Y;&4@:&5A9&5R(&QI;F5S("A#4DQ&(&EN8VQU9&5D*0T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N,0T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$9I96QD<U-T<FEN9R@D9FQA9W,@/2!.151?3DY44%](
M14%$15)?1T547T1%1D%53%0I#0H@("`@>PT*"7)E='5R;B`D=&AI<RT^7W)E
M9V5N97)A=&53=')I;F<H)'1H:7,M/F9I96QD<RP@)&9L86=S*3L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1FEE;&1S07)R87DH*0T*
M#0H@("`@+RHJ#0H@("`@("H@17AP;W)T(&%N(&%R<F%Y(&]F(%)&0S(X,C(@
M<W1Y;&4@:&5A9&5R('-T>6QE(&QI;F5S(&9R;VT@=&AE(&]B:F5C="X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!O<'1I;VYA;"`D9FQA9W,-"B`@("`@*@T*
M("`@("`J($!R971U<FX@87)R87D@4D9#,C@R,B!S='EL92!H96%D97(@;&EN
M97,@*$-23$8@;F]T(&EN8VQU9&5D*0T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("H@0'-I;F-E(#`N,0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=$9I96QD<T%R<F%Y*"1F;&%G<R`]($Y%5%].3E107TA%041%4E]'151?1$5&
M055,5"D-"B`@("![#0H)<F5T=7)N("1T:&ES+3Y?<F5G96YE<F%T94%R<F%Y
M*"1T:&ES+3YF:65L9',L("1F;&%G<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(%]P87)S95-T<FEN9R@I#0H@("`@#0H@("`@+RHJ#0H@
M("`@("H@4&%R<V4@82!S=')I;F<@;V8@4D9#,C@R,B!S='EL92!H96%D97(@
M;&EN97,@:6YT;R!A("=H96%D97(@87)R87DG('=I=&@@=&AE(&AE861E<B!N
M86UE<R!A<R!K97ES+@T*("`@("`J(`T*("`@("`J($!P87)A;2!S=')I;F<@
M)'-T<FEN9R!21D,R.#(R('-T>6QE(&AE861E<B!L:6YE<R`H0U),1B!I;F-L
M=61E9"D-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@)&9L86=S#0H@("`@("H@
M#0H@("`@("H@0')E='5R;B!A<G)A>2`G:&5A9&5R(&%R<F%Y)R!W:71H('1H
M92!H96%D97(@;F%M97,@87,@:V5Y<RP@=F%L=65S(&UA>2!B92!N97-T960N
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'-I;F-E(#`N,0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]P87)S95-T<FEN9R@D<W1R:6YG+"`D
M9FQA9W,I#0H@("`@>PT*("`@(`DO+R!#;&5A;B!T:&4@:&5A9&5R(&QI;F5S
M#0H):68@*"@D9FQA9W,@)B!.151?3DY44%](14%$15)?4T547T-,14%.*2`]
M/2!.151?3DY44%](14%$15)?4T547T-,14%.*2![#0H)("`@("1S=')I;F<@
M/2`D=&AI<RT^8VQE86Y3=')I;F<H)'-T<FEN9RD[#0H)?0T*#0H@("`@"2\O
M(%5N9F]L9"!T:&4@:&5A9&5R(&QI;F5S#0H):68@*"@D9FQA9W,@)B!.151?
M3DY44%](14%$15)?4T547U5.1D],1"D@/3T@3D547TY.5%!?2$5!1$527U-%
M5%]53D9/3$0I('L-"@D@("`@)'-T<FEN9R`]("1T:&ES+3YU;F9O;&13=')I
M;F<H)'-T<FEN9RD[#0H)?0T*#0H)+R\@0V]N=F5R="!T;R!A<G)A>0T*"21A
M<G)A>2`](&5X<&QO9&4H(EQR7&XB+"`D<W1R:6YG*3L-"@T*"2\O(%)E;6]V
M92!B;V1Y(&EF('!R97-E;G0-"@DD:2`](&%R<F%Y7W-E87)C:"@G)RP@)&%R
M<F%Y*3L-"@EI9B`H)&D@(3T@;G5L;"D@>PT*"2`@("!A<G)A>5]S<&QI8V4H
M)&%R<F%Y+"`D:2P@*&-O=6YT*"1A<G)A>2DI+21I*3L-"@E]#0H-"@DO+R!&
M;W)W87)D('1O(%]P87)S92@I#0H)<F5T=7)N("1T:&ES+3Y?<&%R<V4H)&%R
M<F%Y+"`D9FQA9W,I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!?<&%R<V5!<G)A>2@I#0H-"B`@("`O*BH-"B`@("`@*B!087)S92!A;B!A
M<G)A>2!O9B!21D,R.#(R('-T>6QE(&AE861E<B!L:6YE<R!I;G1O(&$@)VAE
M861E<B!A<G)A>2<@=VET:"!T:&4@:&5A9&5R(&YA;65S(&%S(&ME>7,N#0H@
M("`@("H@#0H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A>2!21D,R.#(R('-T
M>6QE(&AE861E<B!L:6YE<R`H0U),1B!N;W0@:6YC;'5D960I#0H@("`@("H@
M0'!A<F%M(&]P=&EO;F%L("1F;&%G<PT*("`@("`J#0H@("`@("H@0')E='5R
M;B!A<G)A>2`G:&5A9&5R(&%R<F%Y)R!W:71H('1H92!H96%D97(@;F%M97,@
M87,@:V5Y<RP@=F%L=65S(&UA>2!B92!N97-T960N#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("H@0'-I;F-E(#`N,0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]P87)S94%R<F%Y*"1A<G)A>2P@)&9L86=S*0T*("`@('L-"B`@
M("`)+R\@0VQE86X@=&AE(&AE861E<B!L:6YE<PT*"6EF("@H)&9L86=S("8@
M3D547TY.5%!?2$5!1$527U-%5%]#3$5!3BD@/3T@3D547TY.5%!?2$5!1$52
M7U-%5%]#3$5!3BD@>PT*"2`@("`D87)R87D@/2`D=&AI<RT^8VQE86Y!<G)A
M>2@D87)R87DI.PT*"7T-"@T*("`@(`DO+R!5;F9O;&0@=&AE(&AE861E<B!L
M:6YE<PT*"6EF("@H)&9L86=S("8@3D547TY.5%!?2$5!1$527U-%5%]53D9/
M3$0I(#T]($Y%5%].3E107TA%041%4E]3151?54Y&3TQ$*2![#0H)("`@("1A
M<G)A>2`]("1T:&ES+3YU;F9O;&1!<G)A>2@D87)R87DI.PT*"7T-"@T*"2\O
M(%)E;6]V92!B;V1Y(&EF('!R97-E;G0-"@DD:2`](&%R<F%Y7W-E87)C:"@G
M)RP@)&%R<F%Y*3L-"@EI9B`H)&D@(3T@;G5L;"D@>PT*"2`@("!A<G)A>5]S
M<&QI8V4H)&%R<F%Y+"`D:2P@8V]U;G0H)&%R<F%Y*2TD:2D[#0H)?0T*#0H)
M+R\@1F]R=V%R9"!T;R!?<&%R<V4H*0T*"7)E='5R;B`D=&AI<RT^7W!A<G-E
M*"1A<G)A>2P@)&9L86=S*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@7W!A<G-E*"D-"@T*("`@("\J*@T*("`@("`J(%!A<G-E(&$@8VQE
M86YE9"!A;F0@=6YF;VQD960@87)R87D@;V8@4D9#,C@R,B!S='EL92!H96%D
M97(@;&EN97,@:6YT;R!A("=H96%D97(@87)R87DG('=I=&@@=&AE(&AE861E
M<B!N86UE<R!A<R!K97ES+@T*("`@("`J(%=H96X@:&5A9&5R(&YA;65S(&$G
M<&5A<B!M;W)E('1H92!O;F-E+"!T:&4@<F5S=6QT:6YG(&%R<F%Y('=I;&P@
M:&%V92!T:&4@=F%L=65S(&YE<W1E9"!I;B!T:&4@;W)D97(@;V8@82=P96%R
M)V5N8V4N#0H@("`@("H@#0H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A>2!2
M1D,R.#(R('-T>6QE(&AE861E<B!L:6YE<R`H0U),1B!N;W0@:6YC;'5D960I
M#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L("1F;&%G<PT*("`@("`J#0H@("`@
M("H@0')E='5R;B!A<G)A>2`G:&5A9&5R(&%R<F%Y)R!W:71H('1H92!H96%D
M97(@;F%M97,@87,@:V5Y<RP@=F%L=65S(&UA>2!B92!N97-T960N#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'-I;F-E(#`N,0T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]P87)S92@D87)R87DL("1F;&%G<RD-"B`@("![
M#0H)+R\@26YI="!R971U<FX@=F%R:6%B;&4-"@DD<F5T=7)N(#T@87)R87DH
M*3L-"@T*"2\O($QO;W`@=&AR;W5G:"!A;&P@:&5A9&5R<PT*("`@("`@("!F
M;W)E86-H("@D87)R87D@87,@)&9I96QD*2![#0H)("`@("\O(%-E<&%R871E
M(&AE861E<B!N86UE(&%N9"!V86QU90T*"2`@("!I9B`H(7!R96=?;6%T8V@H
M)R\H6UQ372LI7#I<<RHH+BHI7',J+R<L("1F:65L9"P@)&UA=&-H97,I*2![
M#0H)"2\O($9A:6PN+BX-"@D@("`@?0T*"2`@("`D;F%M92`]("1M871C:&5S
M6S%=.PT*"2`@("`D=F%L=64@/2`D;6%T8VAE<ULR73L-"@D@("`@=6YS970H
M)&UA=&-H97,I.PT*#0H)("`@("\O($-H86YG92!H96%D97(@;F%M92!T;R!L
M;W=E<B!C87-E#0H)("`@(&EF("@H)&9L86=S("8@3D547TY.5%!?2$5!1$52
M7U-%5%]+14500T%312D@(3T@3D547TY.5%!?2$5!1$527U-%5%]+14500T%3
M12D@>PT*(`D))&YA;64@/2!S=')T;VQO=V5R*"1N86UE*3L-"@D@("`@?0T*
M"2`@("`-"@D@("`@+R\@1&5C;V1E(&AE861E<B!V86QU92!A8V]R9&EN9R!T
M;R!21D,@,C`T-PT*"2`@("!I9B`H*"1F;&%G<R`F($Y%5%].3E107TA%041%
M4E]3151?1$5#3T1%*2`]/2!.151?3DY44%](14%$15)?4T547U5.1D],1"D@
M>PT*"0DD=F%L=64-(#T@)'1H:7,M/F1E8V]D95-T<FEN9R@D=F%L=64I.PT*
M"2`@("!]#0H)("`@(`T*"2`@("`O+R!!9&0@:&5A9&5R('1O("1R971U<FX@
M87)R87D-"B`@("`)("`@(&EF("AI<W-E="@D<F5T=7)N6R1N86UE72D@04Y$
M(&ES7V%R<F%Y*"1R971U<FY;)&YA;65=*2D@>PT*"0DO+R!4:&4@:&5A9&5R
M(&YA;64@:&%S(&%L<F5A9'D@8F5E;B!U<V5D(&%T(&QE87-T('1W;R!T:6UE
M<RX-"B`@("`@("`@("`@(`DD<F5T=7)N6R1N86UE75M=(#T@)'9A;'5E.PT*
M("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1R971U<FY;)&YA;65=*2D@
M>PT*"0DO+R!4:&4@:&5A9&5R(&YA;64@:&%S(&%L<F5A9'D@8F5E;B!U<V5D
M(&]N92!T:6UE("T^(&-H86YG92!T;R!N961T960@=F%L=65S+@T*("`@("`@
M("`@("`@"21R971U<FY;)&YA;65=(#T@87)R87DH)')E='5R;ELD;F%M95TL
M("1V86QU92D[#0H@("`@("`@("`@("!](&5L<V4@>PT*"0DO+R!4:&4@:&5A
M9&5R(&YA;64@:&%S(&YO="!U<V5D('5N=&EL(&YO=RX-"B`@("`@("`@"21R
M971U<FY;)&YA;65=(#T@)'9A;'5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H-"B`@("`@("`@<F5T=7)N("1R971U<FX[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(%]R96=E;F5R871E4W1R:6YG*"D-"B`@("`-
M"B`@("`O*BH-"B`@("`@*B!'96YE<F%T92!A('-T<FEN9R!O9B!21D,R.#(R
M('-T>6QE(&AE861E<B!L:6YE<R!F<F]M('1H92`G:&5A9&5R(&%R<F%Y)R!G
M:79E;B!I;B`D87)R87DN#0H@("`@("H@#0H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A<G)A>2!21D,R.#(R('-T>6QE(&AE861E<B!L:6YE<PT*("`@("`J($!P
M87)A;2!O<'1I;VYA;"`D9FQA9W,-"B`@("`@*@T*("`@("`J($!R971U<FX@
M<W1R:6YG(%)&0S@R,B!S='EL92!H96%D97(@;&EN97,@*$-23$8@:6YC;'5D
M960I+@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!S:6YC92`P
M+C$-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<F5G96YE<F%T95-T<FEN9R@D
M87)R87DL("1F;&%G<RD-"B`@("![#0H)+R\@*"!&;W)W87)D('1O(%]R96=E
M;F5R871E07)R87DH*2!A;F0@=&AE;B!C;VYV97)T('1O('-T<FEN9R`I#0H)
M<F5T=7)N(&EM<&QO9&4H(EQR7&XB+"`D=&AI<RT^7W)E9V5N97)A=&5!<G)A
M>2@D87)R87DL("1F;&%G<RDI.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!?<F5G96YE<F%T94%R<F%Y*"D-"@T*("`@("\J*@T*("`@("`J
M($=E;F5R871E(&%N(&%R<F%Y(&]F(%)&0S(X,C(@<W1Y;&4@:&5A9&5R(&QI
M;F5S(&9R;VT@=&AE(&%R<F%Y(&=I=F5N(&EN("1A<G)A>2X-"B`@("`@*@T*
M("`@("`J($!P87)A;2!A<G)A>2`D87)R87D@)VAE861E<B!F:65L9"!A<G)A
M>2<-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@)&9L86=S#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y(%)&0S@R,B!S='EL92!H96%D97(@;&EN97,@
M*$-23$8@;F]T(&EN8VQU9&5D*2X-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B!`<VEN8V4@,"XQ#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W)E
M9V5N97)A=&5!<G)A>2@D87)R87DL("1F;&%G<RD-"B`@("![#0H)+R\@26YI
M="!R971U<FX@=F%R:6%B;&4-"@DD<F5T=7)N(#T@87)R87DH*3L-"@T*"2\O
M($QO;W`@=&AR;W5G:"!H96%D97)S#0H@("`@("`@(&9O<F5A8V@@*"1A<G)A
M>2!A<R`D;F%M92`]/B`D=F%L=64I('L-"@D@("`@+R\@16YC;V1E(&AE861E
M<B!V86QU97,@86-O<F1I;F<@=&\@4D9#(#(P-#<-"@D@("`@:68@*"@D9FQA
M9W,@)B!.151?3DY44%](14%$15)?1T547T5.0T]$12D@/3T@3D547TY.5%!?
M2$5!1$527T=%5%]%3D-/1$4I('L-"@D):68@*&ES7V%R<F%Y*"1V86QU92DI
M('L-"@D)("`@(&9O<F5A8V@H87)R87E?:V5Y<R@D=F%L=64I(&%S("1K97DI
M('L-"@D)"21V86QU95LD:V5Y72`]("1T:&ES+3YE;F-O9&53=')I;F<H)'9A
M;'5E6R1K97E=*3L-"@D)("`@('T-"@D)?2!E;'-E('L-"@D)("`@("1V86QU
M92`]("1T:&ES+3YE;F-O9&53=')I;F<H)'9A;'5E*3L-"@D)?0T*"2`@("!]
M#0H-"@D@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L-"B`@("`)"69O<F5A
M8V@@*"1V86QU92!A<R`D<W5B7W9A;'5E*2![#0H@("`@("`@(`D@("`@)')E
M='5R;EM=(#T@)&YA;64N)SH@)RXD<W5B7W9A;'5E.PT*"0E]#0H)("`@('T@
M96QS92![#0H@("`@("`@(`DD<F5T=7)N6UT@/2`D;F%M92XG.B`G+B1V86QU
M93L-"@D@("`@?0T*("`@("`@("!]#0H-"@DO+R!&;VQD(&AE861E<G,-"@EI
M9B`H*"1F;&%G<R`F($Y%5%].3E107TA%041%4E]'151?1D],1"D@/3T@3D54
M7TY.5%!?2$5!1$527T=%5%]&3TQ$*2![#0H)("`@("1R971U<FX@/2`D=&AI
M<RT^9F]L9$%R<F%Y*"1R971U<FXI.PT*"7T-"@T*("`@("`@("!R971U<FX@
M)')E='5R;CL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=6YF
M;VQD4W1R:6YG*"D-"@T*("`@("\J*@T*("`@("`J($1O('1H92`H4D9#.#(R
M(#,N,2XQ*2!H96%D97(@=6YF;VQD:6YG('1O(&$@<W1R:6YG(&]F(%)&0S(X
M,C(@:&5A9&5R(&QI;F5S+@T*("`@("`J(`T*("`@("`J($!P87)A;2!S=')I
M;F<@)'-T<FEN9R!21D,R.#(R(&AE861E<B!L:6YE<R!T;R!U;F9O;&1E9"`H
M0U),1B!I;F-L=61E9"D-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG
M(%5N9F]L9&5D(%)&0S(X,C(@:&5A9&5R(&QI;F5S("A#4DQ&(&EN8VQU9&5D
M*0T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N,0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N('5N9F]L9%-T<FEN9R@D<W1R:6YG*0T*
M("`@('L-"@DO+R!#;W)R96-T(%QR('1O(%QR7&X-"B`@("`))'-T<FEN9R`]
M('!R96=?<F5P;&%C92@B+UQR/UQN+R(L(")<<EQN(BP@)'-T<FEN9RD[#0H-
M"@DO+R!5;F9O;&0@;75L=&EL:6YE(&AE861E<G,-"B`@("`))'-T<FEN9R`]
M('!R96=?<F5P;&%C92@B+UQR7&XH7'1\("DK+R(L("<@)RP@)'-T<FEN9RD[
M#0H-"@ER971U<FX@)'-T<FEN9SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@=6YF;VQD07)R87DH*0T*#0H@("`@+RHJ#0H@("`@("H@1&\@
M=&AE("A21D,X,C(@,RXQ+C$I(&AE861E<B!U;F9O;&1I;F<@=&\@86X@87)R
M87D@;V8@4D9#,C@R,B!H96%D97(@;&EN97,N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@87)R87D@)&%R<F%Y(%)&0S(X,C(@:&5A9&5R(&QI;F5S('1O('5N
M9F]L9&5D("A#4DQ&(&YO="!I;F-L=61E9"D-"B`@("`@*@T*("`@("`J($!R
M971U<FX@87)R87D@56YF;VQD960@4D9#,C@R,B!H96%D97(@;&EN97,@*$-2
M3$8@;F]T(&EN8VQU9&5D*0T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("H@0'-I;F-E(#`N,0T*("`@("`J+PT*("`@(&9U;F-T:6]N('5N9F]L9$%R
M<F%Y*"1A<G)A>2D-"B`@("![#0H)+R\@56YF;VQD(&UU;'1I;&EN92!H96%D
M97)S#0H)9F]R("@D:2`](&-O=6YT*"1A<G)A>2DM,3L@)&D^,#L@)&DM+2D@
M>PT*#0H)("`@("\O($-H96-K(&9O<B!L96%D:6YG('=H:71E<W!A8V4-"@D@
M("`@:68@*'!R96=?;6%T8V@H)R]>*%QX,#E\7'@R,"DO)RP@)&%R<F%Y6R1I
M72DI('L-"@D)("`@(`T*"2`@("`@("`@+R\@4F5M;W9E(&9O;&1I;F<@7')<
M;@T*("`@(`D@("`@("`@(&EF("AS=6)S='(H)&%R<F%Y6R1I+3%=+"`M,BD@
M/3T@(EQR7&XB*2![#0H)("`@("`@("`@("`@)&%R<F%Y6R1I+3%=(#T@<W5B
M<W1R*"1A<G)A>5LD:2TQ72P@,"P@+3(I.PT*("`@(`D@("`@("`@('T-"@D)
M"0T*"2`@("`@("`@+R\@07!P96YD(&9O;&1E9"!L:6YE('1O('!R978@;&EN
M90T*"2`@("`@("`@)&%R<F%Y6R1I+3%=(#T@)&%R<F%Y6R1I+3%=+B<@)RYL
M=')I;2@D87)R87E;)&E=+"`B(%QT(BD[#0H)"0D-"@D@("`@("`@("\O(%)E
M;6]V92!F;VQD960@;&EN90T*"0EA<G)A>5]S<&QI8V4H)&%R<F%Y+"`D:2P@
M,2D[#0H)("`@('T-"@E]#0H-"@ER971U<FX@)&%R<F%Y.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!F;VQD07)R87DH*0T*#0H@("`@+RHJ
M#0H@("`@("H@1F]L9',@86X@87)R87D@;V8@4D9#,C@R,B!S='EL92!H96%D
M97(@;&EN97,N#0H@("`@("H-"B`@("`@*B!`<&%R86T@87)R87D@)&%R<F%Y
M#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L(&EN="`D;6%X;&5N#0H@("`@("H-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y(`T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("H@0'-I;F-E(#`N,0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&9O
M;&1!<G)A>2@D87)R87DL("1M87AL96X@/2`W."D-"B`@("![#0H))')E='5R
M;B`](&%R<F%Y*"D[#0H-"@EF;W)E86-H("AA<G)A>5]K97ES*"1A<G)A>2D@
M87,@)&ME>2D@>PT*"2`@("`D=&UP(#T@)'1H:7,M/E]F;VQD17AP;&]D92@D
M87)R87E;)&ME>5TL("1M87AL96XI.PT*"2`@("`D<')E<&5N9"`]("<G.PT*
M"2`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T;7`I(&%S("1K97DR*2![#0H)
M"21R971U<FY;72`]("1P<F5P96YD+B1T;7!;)&ME>3)=.PT*"0DD<')E<&5N
M9"`](")<="([#0H)("`@('T-"@E]#0H-"@ER971U<FX@)')E='5R;CL)#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&9O;&13=')I;F<H*0T*
M#0H@("`@+RHJ#0H@("`@("H@1F]L9',@82!S=')I;F<@8GD@:6YS97)T:6YG
M($-23$8G<R!A;F0@5$%")W,@=VAE<F4@86QL;W=E9`T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG#0H@("`@("H@0'!A<F%M(&]P=&EO
M;F%L(&EN="`D;6%X;&5N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S:6YC92`P+C$-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!F;VQD4W1R:6YG*"1S=')I;F<L("1M
M87AL96X@/2`W."D-"B`@("![#0H))&%R<F%Y(#T@)'1H:7,M/E]F;VQD17AP
M;&]D92@D<W1R:6YG+"`D;6%X;&5N*3L-"@DD<F5T=7)N(#T@:6UP;&]D92@B
M7')<;EQT(BP@)&%R<F%Y*3L-"@ER971U<FX@)')E='5R;CL-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V9O;&1%>'!L;V1E*"D-"@T*("`@
M("\J*@T*("`@("`J(%5N9F]L9"`D<W1R:6YG+"!A;F0@<F5T=7)N(&$@)V9O
M;&1E9"<@87)R87D-"B`@("`@*@T*("`@("`J(%1H92!C=7)R96YT(&EM<&QE
M;65N=&%T:6]N(&ES('-T:6QL(&5X<&5R:6UE;G1A;"P@86YD(&ES($Y/5"!E
M>'!E8W1E9"!T;R!C;VUP;'D@=VET:"!21D,R.#(R("$A(0T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG#0H@("`@("H@0'!A<F%M(&]P
M=&EO;F%L(&EN="`D;6%X;&5N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'-I;F-E(#`N
M,0T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]F;VQD17AP;&]D92@D<W1R:6YG
M+"`D;6%X;&5N(#T@-S@-*0T*+R]43T1/.@T*("`@('L-"@EI9B`H)&UA>&QE
M;B`\(#(P*2![#0H)("`@("1M87AL96X@/2`R,#L-"@E]#0H-"@EI9B`H)&UA
M>&QE;B`^(#DY."D@>PT*"2`@("`D;6%X;&5N(#T@.3DX.PT*"7T-"@T*"6EF
M("AS=')L96XH)'-T<FEN9RD@/#T@)&UA>&QE;BD@>PT*"2`@("!R971U<FX@
M87)R87DH)'-T<FEN9RD[#0H@("`@"7T-"B`@("`@(`T*"21M:6X@/2`H:6YT
M*2`H)&UA>&QE;B`J("@R+S4I*2`M(#0[#0H@("`@("`@("1M87@@/2`D;6%X
M;&5N("T@-3L@("`@("`@("`@("`@("`@("`@+R\@-"!F;W(@;&5A9&EN9R!S
M<&-S("L@,2!F;W(@6UPL7#M=#0H-"@DO+R!T<GD@<W!L:71T:6YG(&%T("<L
M)R!O<B`G.R<@("`^,B\U(&%L;VYG('1H92!L:6YE#0H@("`@("`@("\O(%-P
M;&ET('1H92!L:6YE('5P#0H)+R\@;F5X="!S<&QI="!A('=H:71E<W!A8V4-
M"@DO+R!E;'-E('=E(&%R92!L;V]K:6YG(&%T(&$@<VEN9VQE('=O<F0@86YD
M('!R;V)A8FQY(&1O;B=T('=A;G0@=&\@<W!L:70-"@DD97AP(#T@87)R87DH
M*3L-"B`@("`@("`@)&5X<%M=(#T@(EM>7")=7'LD;6EN+"1M87A]/UM<+%P[
M75QS(CL-"B`@("`@("`@)&5X<%M=(#T@(EM>7")=7'LQ+"1M87A]7',B.PT*
M("`@("`@("`D97AP6UT@/2`B6UY<<UPB72HH/SI<(EM>7")=*EPB6UY<<UPB
M72HI*UQS(CL-"@DD97AP6UT@/2`B6UY<<UPB72M<<R([#0H-"@DD97AP(#TB
M+UY<<RHH(BYI;7!L;V1E*"=\)RP@)&5X<"DN(BDH+BHI7"0O>"([#0H))'1M
M<"`]("1S=')I;F<[#0H))')E='5R;B`](&%R<F%Y*"D[#0H-"@EW:&EL92`H
M*'-T<FQE;B@D=&UP*2`^("1M87@I("8F("AP<F5G7VUA=&-H*"1E>'`L("1T
M;7`L("1M871C:"DI*2![#0H)("`@("1R971U<FY;72`]("1M871C:%LQ73L-
M"@D@("`@)'1M<"`]("1M871C:%LR73L-"@E]#0H-"@DD<F5T=7)N6UT@/2`D
M=&UP.PT*"0T*"7)E='5R;B`D<F5T=7)N.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!D96-O9&53=')I;F<H*0T*#0H@("`@+RHJ#0H@("`@
M("H@1VEV96X@82!H96%D97(O<W1R:6YG+"!T:&ES(&9U;F-T:6]N('=I;&P@
M9&5C;V1E(&ET#2!A8V-O<F1I;F<@=&\@4D9#,C`T-RX-"B`@("`@*B!0<F]B
M86)L>2!N;W0@*F5X86-T;'DJ#2!C;VYF;W)M86YT+"!B=70@:70@9&]E<R!P
M87-S(&%L;"!T:&4@9VEV96X-"B`@("`@*B!E>&%M<&QE<R`H:6X@4D9#,C`T
M-RDN#0H@("`@("H@#0H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@26YP
M=70@:&5A9&5R('9A;'5E('1O(&1E8V]D90T*("`@("`J#0H@("`@("H@0')E
M='5R;B!S=')I;F<@1&5C;V1E9"!H96%D97(@=F%L=64-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J($!S:6YC92`P+C$-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!D96-O9&53=')I;F<H)&EN<'5T*0T*("`@('L-"B`@("`@("`@
M+R\@4F5M;W9E('=H:71E('-P86-E(&)E='=E96X@96YC;V1E9"UW;W)D<PT*
M("`@("`@("`D:6YP=70@/2!P<F5G7W)E<&QA8V4H)R\H/5P_6UX_72M</RAQ
M?&(I7#];7C]=*EP_/2DH7',I*SU</R]I)RP@)UPQ/3\G+"`D:6YP=70I.PT*
M#0H@("`@("`@("\O($9O<B!E86-H(&5N8V]D960M=V]R9"XN+@T*("`@("`@
M("!W:&EL92`H<')E9U]M871C:"@G+R@]7#\H6UX_72LI7#\H<7QB*5P_*%M>
M/UTJ*5P_/2DO:2<L("1I;G!U="P@)&UA=&-H97,I*2![#0H-"B`@("`@("`@
M("`@("1E;F-O9&5D("`]("1M871C:&5S6S%=.PT*("`@("`@("`@("`@)&-H
M87)S970@(#T@)&UA=&-H97-;,ET[#0H@("`@("`@("`@("`D96YC;V1I;F<@
M/2`D;6%T8VAE<ULS73L-"B`@("`@("`@("`@("1T97AT("`@("`]("1M871C
M:&5S6S1=.PT*#0H@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)&5N
M8V]D:6YG*2D@>PT*#0H@("`@("`@("`@("`@("`@8V%S92`G8B<Z#2`O+R!2
M1D,R,#0W(#0N,0T*("`@("`@("`@("`@("`@("`@("`D=&5X="`](&)A<V4V
M-%]D96-O9&4H)'1E>'0I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"@T*("`@("`@("`@("`@("`@(&-A<V4@)W$G.B`O+R!21D,R,#0W(#0N,@T*
M("`@("`@("`@("`@("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*"=?)RP@
M)R`G+"`D=&5X="D[#0H@("`@("`@("`@("`@("`@("`@('!R96=?;6%T8VA?
M86QL*"<O/2A;82UF,"TY77LR?2DO:2<L("1T97AT+"`D;6%T8VAE<RD[#0H@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&UA=&-H97-;,5T@87,@)'9A
M;'5E*0T*("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0@/2!S=')?<F5P
M;&%C92@G/2<N)'9A;'5E+"!C:'(H:&5X9&5C*"1V86QU92DI+"`D=&5X="D[
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*
M#0H@("`@("`@("`@("`D:6YP=70@/2!S=')?<F5P;&%C92@D96YC;V1E9"P@
M)'1E>'0L("1H96%D97(I.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N
M("1I;G!U=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@96YC
M;V1E4W1R:6YG*"D-"@T*("`@("\J*@T*("`@("`J($5N8V]D97,@=&AE('-T
M<FEN9R!G:79E;B!I;B`D<W1R:6YG(&%S('!E<B!21D,R,#0W#0H@("`@("H@
M#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG(%1H92!S=')I;F<@=&\@
M96YC;V1E#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!%;F-O9&5D
M('-T<FEN9PT*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E
M(#`N,0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&5N8V]D95-T<FEN9R@D<W1R
M:6YG*0T*("`@('L-"@DO+R!43T1/.B!C;W5L9"!B92!B971T97(A("A,;V]K
M(&EN=&\@0U!!3B=S($5N8V]D93HZ34E-13HZ2&5A9&5R*0T*"0T*"21C:&%R
M<V5T(#T@)VES;RTX.#4Y+3$G.PT*"0T*("`@("`@("!P<F5G7VUA=&-H7V%L
M;"@G+RA<=RI;7'@X,"U<>$9&72M<=RHI+R<L("1S=')I;F<L("1M871C:&5S
M*3L-"@EF;W)E86-H("@D;6%T8VAE<ULQ72!A<R`D=F%L=64I('L-"B`@("`@
M("`@("`@("1R97!L86-E;65N="`]('!R96=?<F5P;&%C92@G+RA;7'@X,"U<
M>$9&72DO92<L("<B/2(@+B!S=')T;W5P<&5R*&1E8VAE>"AO<F0H(EPQ(BDI
M*2<L("1V86QU92D[#0H@("`@("`@("`@("`D<W1R:6YG(#T@<W1R7W)E<&QA
M8V4H)'9A;'5E+"`G/3\G("X@)&-H87)S970@+B`G/U$_)R`N("1R97!L86-E
M;65N="`N("<_/2<L("1S=')I;F<I.PT*("`@("`@("!]#0H@("`@("`@("`@
M("`-"B`@("`@("`@<F5T=7)N("1S=')I;F<[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&-L96%N4W1R:6YG*"D-"@T*("`@("\J*@T*("`@
M("`J(%)E;6]V97,@0U),1B!A;F0@;6ES<&QA8V5D(&5M<'1Y(&QI;F5S(&)E
M9F]R92!A;F0@869T97(@86-T=6%L(&AE861E<FQI;F5S+@T*("`@("`J(`T*
M("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9RX-"B`@("`@*@T*("`@("`J
M($!R971U<FX@<W1R:6YG(`T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("H@0'-I;F-E(#`N,0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-L96%N4W1R
M:6YG*"1S=')I;F<I#0H@("`@>PT*"2\O($-O<G)E8W0@;6ES<VEN9R!#4B=S
M(&)E9F]R92!,1B=S#0H@("`@("`@("1S=')I;F<@/2!P<F5G7W)E<&QA8V4H
M(B%<<C]<;B$B+"`B7')<;B(L("1S=')I;F<I.PT*#0H)+R\@4F5M;W9E(&5M
M<'1Y(&QI;F5S(&9R;VT@<W1A<G0@86YD(&5N9"X-"@DO+R!43T1/.B!4:&ES
M('-H;W5L9"!B92!D;VYE(&)E='1E<BXN+@T*"21S=')I;F<@/2!T<FEM*"1S
M=')I;F<L(")<<EQN(BD[#0H-"B`@("`@("`@<F5T=7)N("1S=')I;F<-.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C;&5A;D%R<F%Y*"D-
M"@T*("`@("\J*@T*("`@("`J(%)E;6]V97,@0U),1B!A;F0@;6ES<&QA8V5D
M(&5M<'1Y(&QI;F5S(&)E9F]R92!A;F0@869T97(@86-T=6%L(&AE861E<FQI
M;F5S+@T*("`@("`J(`T*("`@("`J($!P87)A;2!A<G)A>2`D:6YP=70@#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`@*B!`<VEN8V4@,"XQ#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@8VQE86Y!<G)A>2@D:6YP=70I#0H@("`@>PT*"2\O(%)E;6]V92!E;7!T
M>2!L:6YE<R!F<F]M('1H92!S=&%R=`T*"7=H:6QE("AR97-E="@D:6YP=70I
M(#T](")<<EQN(BD@>PT*"2`@("!A<G)A>5]S:&EF="@D:6YP=70I.PT*"7T-
M"@DO+R!296UO=F4@96UP='D@;&EN97,@9G)O;2!T:&4@96YD#0H)=VAI;&4@
M*&5N9"@D:6YP=70I(#T](")<<EQN(BD@>PT*"2`@("!A<G)A>5]P;W`H)&EN
M<'5T*3L-"@E]#0H-"@DO+R!2=6X@8F%C:W=A<F1S('1H<F]U9V@@86QL(&QI
M;F5S#0H)9F]R("@D:2`](&-O=6YT*"1I;G!U="DM,3L@)&D@/B`P.R`D:2TM
M*2![#0H-"@D@("`@+R\@4F5M;W9E(%QR7&X@9G)O;2!T:&4@96YD#0H)("`@
M("1I;G!U="`]('!R96=?<F5P;&%C92@B+UQR/UQN)"\B+"`G)RP@)&EN<'5T
M*3L-"@E]#0H-"B`@("`@("`@<F5T=7)N("1I;G!U=#L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"@T*?0T*#0H_/@T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TYE="].3E10+TUE<W-A9V4N<&AP
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,P-3<S`#$P-#$W
M,S8S,#`V`#`R,#<U,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PT*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!#
M;W!Y<FEG:'0@J2`R,#`S($AE:6YO($@N($=E:&QS96XN($%L;"!2:6=H=',@
M4F5S97)V960N("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@
M("`@(&AT='`Z+R]W=W<N:&5I;F\N9V5H;'-E;BYD:R]S;V9T=V%R92]L:6-E
M;G-E("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!4:&ES('=O<FL@*&EN8VQU
M9&EN9R!S;V9T=V%R92P@9&]C=6UE;G1S+"!O<B!O=&AE<B!R96QA=&5D(&ET
M96US*2!I<R`@?`T*+R\@?"!B96EN9R!P<F]V:61E9"!B>2!T:&4@8V]P>7)I
M9VAT(&AO;&1E<G,@=6YD97(@=&AE(&9O;&QO=VEN9R!L:6-E;G-E+B`@?`T*
M+R\@?"!">2!O8G1A:6YI;F<L('5S:6YG(&%N9"]O<B!C;W!Y:6YG('1H:7,@
M=V]R:RP@>6]U("AT:&4@;&EC96YS964I("`@("`@?`T*+R\@?"!A9W)E92!T
M:&%T('EO=2!H879E(')E860L('5N9&5R<W1O;V0L(&%N9"!W:6QL(&-O;7!L
M>2!W:71H('1H92`@("`@("`@?`T*+R\@?"!F;VQL;W=I;F<@=&5R;7,@86YD
M(&-O;F1I=&EO;G,Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M?"!097)M:7-S:6]N('1O('5S92P@8V]P>2P@;6]D:69Y+"!A;F0@9&ES=')I
M8G5T92!T:&ES('-O9G1W87)E(&%N9"`@("`@?`T*+R\@?"!I=',@9&]C=6UE
M;G1A=&EO;BP@=VET:"!O<B!W:71H;W5T(&UO9&EF:6-A=&EO;BP@9F]R(&%N
M>2!P=7)P;W-E(&%N9"`@?`T*+R\@?"!W:71H;W5T(&9E92!O<B!R;WEA;'1Y
M(&ES(&AE<F5B>2!G<F%N=&5D+"!P<F]V:61E9"!T:&%T('EO=2!I;F-L=61E
M("`@?`T*+R\@?"!T:&4@9F]L;&]W:6YG(&]N($%,3"!C;W!I97,@;V8@=&AE
M('-O9G1W87)E(&%N9"!D;V-U;65N=&%T:6]N(&]R("`@("`@?`T*+R\@?"!P
M;W)T:6]N<R!T:&5R96]F+"!I;F-L=61I;F<@;6]D:69I8V%T:6]N<RP@=&AA
M="!Y;W4@;6%K93H@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@?"`Q+B!4:&4@9G5L;"!T97AT(&]F('1H:7,@
M3D]424-%(&EN(&$@;&]C871I;VX@=FEE=V%B;&4@=&\@=7-E<G,@;V8@("`@
M?`T*+R\@?"`@("!T:&4@<F5D:7-T<FEB=71E9"!O<B!D97)I=F%T:79E('=O
M<FLN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`R+B!!;GD@<')E+65X:7-T
M:6YG(&EN=&5L;&5C='5A;"!P<F]P97)T>2!D:7-C;&%I;65R<RP@;F]T:6-E
M<RP@;W(@("`@?`T*+R\@?"`@("!T97)M<R!A;F0@8V]N9&ET:6]N<RX@268@
M;F]N92!E>&ES="P@82!S:&]R="!N;W1I8V4@;V8@=&AE("`@("`@("`@?`T*
M+R\@?"`@("!F;VQL;W=I;F<@9F]R;2`H:'EP97)T97AT(&ES('!R969E<G)E
M9"P@=&5X="!I<R!P97)M:71T960I('-H;W5L9"`@?`T*+R\@?"`@("!B92!U
M<V5D('=I=&AI;B!T:&4@8F]D>2!O9B!A;GD@<F5D:7-T<FEB=71E9"!O<B!D
M97)I=F%T:79E(&-O9&4Z("`@?`T*+R\@?"`@("`B0V]P>7)I9VAT(*D@,C`P
M,R!(96EN;R!(+B!'96AL<V5N+B!!;&P@4FEG:'1S(%)E<V5R=F5D+B`@("`@
M("`@("`@?`T*+R\@?"`@("`@:'1T<#HO+W=W=RYH96EN;RYG96AL<V5N+F1K
M+W-O9G1W87)E+VQI8V5N<V4B("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`S+B!.;W1I8V4@
M;V8@86YY(&-H86YG97,@;W(@;6]D:69I8V%T:6]N<R!T;R!T:&4@9FEL97,L
M(&EN8VQU9&EN9R`@("`@?`T*+R\@?"`@("!T:&4@9&%T92!C:&%N9V5S('=E
M<F4@;6%D92X@*%=E(')E8V]M;65N9"!Y;W4@<')O=FED92!54DES('1O("`@
M("`@?`T*+R\@?"`@("!T:&4@;&]C871I;VX@9G)O;2!W:&EC:"!T:&4@8V]D
M92!I<R!D97)I=F5D+BD@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!42$E3(%-/1E1705)%
M($%.1"!$3T-5345.5$%424].($E3(%!23U9)1$5$(")!4R!)4RPB($%.1"!#
M3U!94DE'2%0@("`@?`T*+R\@?"!(3TQ$15)3($U!2T4@3D\@4D504D5314Y4
M051)3TY3($]2(%=!4E)!3E1)15,L($584%)%4U,@3U(@24U03$E%1"P@("`@
M?`T*+R\@?"!)3D-,541)3D<@0E54($Y/5"!,24U)5$5$(%1/+"!705)204Y4
M2453($]&($U%4D-(04Y404))3$E462!/4B`@("`@("`@?`T*+R\@?"!&251.
M15-3($9/4B!!3ED@4$%25$E#54Q!4B!055)03U-%($]2(%1(050@5$A%(%53
M12!/1B!42$4@4T]&5%=!4D4@("`@?`T*+R\@?"!/4B!$3T-5345.5$%424].
M(%=)3$P@3D]4($E.1E))3D=%($%.62!42$E21"!005)462!0051%3E13+"`@
M("`@("`@("`@?`T*+R\@?"!#3U!94DE'2%13+"!44D%$14U!4DM3($]2($]4
M2$52(%))1TA44RX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*
M+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!#3U!94DE'
M2%0@2$],1$524R!724Q,($Y/5"!"12!,24%"3$4@1D]2($%.62!$25)%0U0L
M($E.1$E214-4+"`@("`@("`@?`T*+R\@?"!34$5#24%,($]2($-/3E-%455%
M3E1)04P@1$%-04=%4R!!4DE324Y'($]55"!/1B!!3ED@55-%($]&(%1(12`@
M("`@("`@?`T*+R\@?"!33T945T%212!/4B!$3T-5345.5$%424].+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!4:&4@;F%M92!A
M;F0@=')A9&5M87)K<R!O9B!C;W!Y<FEG:'0@:&]L9&5R<R!M87D@3D]4(&)E
M('5S960@:6X@("`@("`@?`T*+R\@?"!A9'9E<G1I<VEN9R!O<B!P=6)L:6-I
M='D@<&5R=&%I;FEN9R!T;R!T:&4@<V]F='=A<F4@=VET:&]U="!S<&5C:69I
M8RP@?`T*+R\@?"!W<FET=&5N('!R:6]R('!E<FUI<W-I;VXN(%1I=&QE('1O
M(&-O<'ER:6=H="!I;B!T:&ES('-O9G1W87)E(&%N9"!A;GD@?`T*+R\@?"!A
M<W-O8VEA=&5D(&1O8W5M96YT871I;VX@=VEL;"!A="!A;&P@=&EM97,@<F5M
M86EN('=I=&@@8V]P>7)I9VAT("`@("`@?`T*+R\@?"!H;VQD97)S+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!4:&ES(&QI8V5N<V4@:7,@
M8F%S960@;VX@=&AE(")7,T.N(%-/1E1705)%($Y/5$E#12!!3D0@3$E#14Y3
M12(N("`@("`@?`T*+R\@?"!.;R!C:&%N9V5S(&AA=F4@8F5E;B!M861E('1O
M('1H92`B5S-#KB!33T945T%212!.3U1)0T4@04Y$($Q)0T5.4T4B+"`@?`T*
M+R\@?"!E>&-E<'0@9F]R('1H92!R969E<F5N8V5S('1O('1H92!C;W!Y<FEG
M:'0@:&]L9&5R+"!W:&EC:"!H87,@96ET:&5R("`@?`T*+R\@?"!B965N(&-H
M86YG97,@;W(@<F5M;W9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@
M)$ED.B!-97-S86=E+G!H<"QV(#$N-R`R,#`S+S`X+S$V(#$Y.C$U.C`T(&AE
M:6YO($5X<"`D#0H-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q=6ER
M95]O;F-E("=.970O3DY44"](96%D97(N<&AP)SL-"@T*+RHJ#0H@*@T@(%1H
M92!.971?3DY44%]-97-S86=E(&-L87-S#0H@*@T*("H@0'9E<G-I;VX@)%)E
M=FES:6]N.B`Q+C<@)`T*("H@0'!A8VMA9V4@3F5T7TY.5%`-"B`J#0H@*B!`
M875T:&]R("!(96EN;R!(+B!'96AL<V5N(#QH96EN;T!G96AL<V5N+F1K/@T*
M("HO#0IC;&%S<R!.971?3DY44%]-97-S86=E#0I[#0H@("`@+R\@>WM[('!R
M;W!E<G1I97,-"@T*("`@("\J#0H@("`@("H@0V]N=&%I;G,@=&AE(&UE<W-A
M9V4G<R!H96%D97(@;V)J96-T#0H@("`@("H-"B`@("`@*B!`=F%R("`@(&]B
M:F5C=`T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@=F%R
M("1H96%D97([#0H)"0D)(`T*("`@("\J*@T*("`@("`J($-O;G1A:6YS('1H
M92!B;V1Y('!A<G0@;V8@=&AE(&UE<W-A9V4-"B`@("`@*@T*("`@("`J($!V
M87(@("`@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-
M"B`@("!V87(@)&)O9'D[#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N
M<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J($-O;G-T<G5C=&]R+@T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!.971?3DY44%]-97-S86=E*"D-"B`@("![#0H))'1H:7,M/G)E<V5T
M*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(')E<V5T*"D-
M"@T*("`@("\J*@T*("`@("`J(%)E<V5T<R!T:&4@;65S<V%G92!O8FIE8W0-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<F5S970H*0T*("`@('L-"@DD=&AI<RT^:&5A9&5R(#T@;F5W
M($YE=%].3E107TAE861E<B@I.PT*"21T:&ES+3YB;V1Y(#T@;G5L;#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8W)E871E*"D-"B`@("`-
M"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@82!N97<@:6YS=&%N8V4@;V8@3F5T
M7TY.5%!?365S<V%G90T*("`@("`J#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L
M(&UI>&5D("1I;G!U="`@0V%N(&)E(&%N>2!O9B!T:&4@9F]L;&]W:6YG.@T*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AS=')I;F<I
M(%)&0S(X,C(@;65S<V%G92!L:6YE<R`H4D-,1B!I;F-L=61E9"D-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H87)R87DI("!21D,R
M.#(R(&UE<W-A9V4@;&EN97,@*%)#3$8@;F]T(&EN8VQU9&5D*0T*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AO8FIE8W0I($YE=%].
M3E107TAE861E<B!O8FIE8W0-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`H;V)J96-T*2!.971?3DY44%]-97-S86=E(&]B:F5C=`T*
M("`@("`J($!P87)A;2!O<'1I;VYA;"!M:7AE9"`D:6YP=70R($EF(&=I=F5N
M+"`D:6YP=70@=VEL;"!O;FQY(&)E('5S92!F;W(@=&AE(&UE<W-A9V4G<PT*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AE861E<BP@
M=VAI;&4@)&EN<'5T,B!W:6QL(&)E('5S960@9F]R('1H92!B;V1Y+@T*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("A$:7-A;&QO=V5D
M('=H96X@)&EN<'5T(&ES(&$@3F5T7TY.5%!?365S<V%G92D-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N,0T*("`@
M("`J+PT*("`@(&9U;F-T:6]N("8@8W)E871E*"1I;G!U="`](&YU;&PL("1I
M;G!U=#(@/2!N=6QL*0T*("`@('L-"@DD3V)J96-T(#T@;F5W($YE=%].3E10
M7TUE<W-A9V4H*3L-"@D-"@ES=VET8V@@*'1R=64I('L-"@T*"2`@("`O+R!.
M=6QL#0H)("`@(&-A<V4@*&ES7VYU;&PH)&EN<'5T*2`F)B!I<U]N=6QL*"1I
M;G!U=#(I*3H-"@D@("`@("`@(')E='5R;B`D3V)J96-T.PT*"0EB<F5A:SL-
M"@T*#0D@("`@+R\@3V)J96-T(`T*"2`@("!C87-E(&ES7V]B:F5C="@D:6YP
M=70I.@T*"0ES=VET8V@@*'1R=64I('L-"@D)("`@(`T*"0D@("`@+R\@2&5A
M9&5R#0H)"2`@("!C87-E(&ES7V$H)&EN<'5T+"`G;F5T7VYN='!?:&5A9&5R
M)RDZ#0H)"0DD3V)J96-T+3YS971(96%D97(H)&EN<'5T*3L-"@D)"21/8FIE
M8W0M/G-E=$)O9'DH)&EN<'5T,BD[#0H)"0ER971U<FX@)$]B:F5C=#L-"@D)
M"6)R96%K.PT*"0D)#0H)"2`@("`O+R!-97-S86=E#0H)"2`@("!C87-E(&ES
M7V$H)&EN<'5T+"`G;F5T7VYN='!?;65S<V%G92<I.@T*"0D):68@*"1I;G!U
M=#(@(3T@;G5L;"D@>PT*"0D)("`@(')E='5R;B!014%2.CIT:')O=T5R<F]R
M*"=396-O;F0@<&%R86UE=&5R(&YO="!A;&QO=V5D(2<L(&YU;&PI.PT*"0D)
M?0D)"0T*"0D)<F5T=7)N("1I;G!U=#L-"@D)"6)R96%K.PT*"0D)#0H)"2`@
M("`O+R!5;FMN;W=N(&]B:F5C="]C;&%S<PT*"0D@("`@9&5F875L=#H-"@D)
M"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=5;G-U<'!O<G1E9"!O8FIE8W0O
M8VQA<W,Z("<N9V5T7V-L87-S*"1I;G!U="DL(&YU;&PI.PT*"0E]#0H)"6)R
M96%K.PT*#0H)("`@("\O($%R<F%Y("8@4W1R:6YG("AO;FQY(#%S="!P87)A
M;65T97(I#0H)("`@(&-A<V4@*"AI<U]S=')I;F<H)&EN<'5T*2!\?"!I<U]A
M<G)A>2@D:6YP=70I*2`F)B`H:7-?;G5L;"@D:6YP=70R*2DI.@T*"0DD3V)J
M96-T+3YS971-97-S86=E*"1I;G!U="D-.PT*"0ER971U<FX@)$]B:F5C=#L-
M"@D)8G)E86L[#0H-"@D@("`@+R\@07)R87D@)B!3=')I;F<@*&%L<V\@,FYD
M('!A<F%M971E<BD-"@D@("`@8V%S92`H*&ES7W-T<FEN9R@D:6YP=70I('Q\
M(&ES7V%R<F%Y*"1I;G!U="DI("8F("AI<U]S=')I;F<H)&EN<'5T,BD@?'P@
M:7-?87)R87DH)&EN<'5T,BDI*3H-"@T*"0DD3V)J96-T+3YS971(96%D97(H
M)&EN<'5T*0T[#0H-"@D):68@*&ES7V%R<F%Y*"1I;G!U=#(I*2![#0H)"2`@
M("`D3V)J96-T+3YB;V1Y(#T@:6UP;&]D92@B7')<;B(L("1I;G!U=#(I#3L-
M"@D)?2!E;'-E('L-"@D)("`@("1/8FIE8W0M/F)O9'D@/2`D:6YP=70R.PT*
M"0E]#0H-"@D)<F5T=7)N("1/8FIE8W0[#0H)"6)R96%K.PT*#0H)("`@("\O
M(%5N:VYO=VX@='EP90T*"2`@("!D969A=6QT.@T*"0ER971U<FX@4$5!4CHZ
M=&AR;W=%<G)O<B@G56YS=7!P;W)T960@;V)J96-T+V-L87-S.B`G+F=E=%]C
M;&%S<R@D:6YP=70I+"!N=6QL*3L-"@E]#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[('-E=$UE<W-A9V4H*0T*#0H@("`@+RHJ#0H@("`@("H@
M4V5T<R!T:&4@:&5A9&5R(&%N9"!B;V1Y(&=R;VT@=&AE(&=I=F5N("1M97-S
M86=E#0H@("`@("H-"B`@("`@*B!`<&%R86T@;6EX960@)&UE<W-A9V4@0V%N
M(&)E(&%N>2!O9B!T:&4@9F]L;&]W:6YG.@T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`H<W1R:6YG*2!21D,R.#(R(&UE<W-A9V4@;&EN97,@*%)#
M3$8@:6YC;'5D960I#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("AA
M<G)A>2D@(%)&0S(X,C(@;65S<V%G92!L:6YE<R`H4D-,1B!N;W0@:6YC;'5D
M960I#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("AO8FIE8W0I($YE
M=%].3E107TUE<W-A9V4@;V)J96-T#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$UE<W-A9V4H)&UE
M<W-A9V4I#0H@("`@>PT*"7-W:71C:"`H=')U92D@>PT*#0H)("`@("\O($]B
M:F5C=`T*"2`@("!C87-E(&ES7V]B:F5C="@D;65S<V%G92D[#0H)("`@("`@
M("!S=VET8V@@*'1R=64I('L-"@T*"0D@("`@+R\@365S<V%G90T*"0D@("`@
M8V%S92!I<U]A*"1I;G!U="P@)VYE=%]N;G1P7VUE<W-A9V4G*3H-"@D)("`@
M("`@("`D=&AI<R`])B`D;65S<V%G93L-"@D)("`@("`@("!B<F5A:SL-"@T*
M"0D@("`@+R\@56YK;F]W;B!O8FIE8W0O8VQA<W,-"@D)("`@(&1E9F%U;'0Z
M#0H)"2`@("`@("`@<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)U5N<W5P<&]R
M=&5D(&]B:F5C="]C;&%S<SH@)RYG971?8VQA<W,H)&UE<W-A9V4I+"!N=6QL
M*3L-"@D)?0T*"0EB<F5A:SL-"@T*"2`@("`O+R!!<G)A>2`F(%-T<FEN9PT*
M"2`@("!C87-E(&ES7V%R<F%Y*"1M97-S86=E*3H-"@D@("`@8V%S92!I<U]S
M=')I;F<H)&UE<W-A9V4I.@T*"0DD87)R87D@/2`D=&AI<RT^<W!L:71-97-S
M86=E*"1M97-S86=E*3L-"@D))'1H:7,M/G-E=$AE861E<B@D87)R87E;)VAE
M861E<B==*3L-"@D))'1H:7,M/G-E=$)O9'DH)&%R<F%Y6R=B;V1Y)UTI.PT*
M"2`@("`@("`@8G)E86L[#0H)"0T*"2`@("`O+R!5;FMN;W=N('1Y<&4-"@D@
M("`@9&5F875L=#H-"@D@("`@("`@(')E='5R;B!014%2.CIT:')O=T5R<F]R
M*"=5;G-U<'!O<G1E9"!T>7!E.B`G+F=E='1Y<&4H)&UE<W-A9V4I+"!N=6QL
M*3L-"@E]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$UE
M<W-A9V53=')I;F<H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!C;VUP
M;&5T92!T<F%N<W!O<G0M<F5A9'D@;65S<V%G92!A<R!A('-T<FEN9PT*("`@
M("`J#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V53=')I;F<H
M*0T*("`@('L-"@ER971U<FX@)'1H:7,M/FAE861E<BT^9V5T1FEE;&1S4W1R
M:6YG*"DN(EQR7&Y<<EQN(BXD=&AI<RT^9V5T0F]D>2@I.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!G971-97-S86=E07)R87DH*0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5T('1H92!C;VUP;&5T92!T<F%N<W!O<G0M<F5A
M9'D@;65S<V%G92!A<R!A;B!A<G)A>0T*("`@("`J#0H@("`@("H@0')E='5R
M;B!S=')I;F<-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$UE<W-A9V5!<G)A>2@I#0H@("`@>PT*"2\O($=E="!T
M:&4@:&5A9&5R(&9I96QD<PT*"21H96%D97(@/2`D=&AI<RT^:&5A9&5R+3YG
M971&:65L9'-!<G)A>2@I.PT*"0T*"2\O($%P<&5N9"!N=6QL(&QI;F4-"@DD
M:&5A9&5R6UT@/2`G)SL-"@D-"@DO+R!-97)G92!W:71H(&)O9'DL(&%N9"!R
M971U<FX-"@ER971U<FX@87)R87E?;65R9V4H)&AE861E<BP@97AP;&]D92@B
M7')<;B(L("1T:&ES+3YG971";V1Y*"DI*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@<V5T2&5A9&5R*"D-"@T*("`@("\J*@T*("`@("`J
M(%-E=',@=&AE(&AE861E<B=S(&9I96QD<R!F<F]M('1H92!G:79E;B`D:6YP
M=70-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE9"`D:6YP=70@0V%N(&)E
M(&%N>2!O9B!T:&4@9F]L;&]W:6YG.@T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@*'-T<FEN9RD@4D9#,C@R,B!M97-S86=E(&QI;F5S("A20TQ&(&EN
M8VQU9&5D*0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@*&%R<F%Y*2`@
M4D9#,C@R,B!M97-S86=E(&QI;F5S("A20TQ&(&YO="!I;F-L=61E9"D-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("AO8FIE8W0I($YE=%].3E107TAE
M861E<B!O8FIE8W0-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<V5T2&5A9&5R*"1I;G!U="D-"B`@("![
M#0H)("`@('-W:71C:"`H=')U92D@>PT*#0H)"2\O($]B:F5C=`T*"0EC87-E
M(&ES7V]B:F5C="@D:6YP=70I.@T*"0D@("`@<W=I=&-H("AT<G5E*2![#0H)
M"2`@("`-"@D)"2\O($AE861E<@T*"0D)8V%S92!I<U]A*"1I;G!U="P@)VYE
M=%]N;G1P7VAE861E<B<I.@T*"0D@("`@"2`@("`D=&AI<RT^:&5A9&5R(#T@
M)&EN<'5T.PT*"0D)("`@(&)R96%K.PT*#0H)"0DO+R!5;FMN;W=N(&]B:F5C
M="]C;&%S<PT*"0D)9&5F875L=#H-"@D)"2`@("!R971U<FX@4$5!4CHZ=&AR
M;W=%<G)O<B@G56YS=7!P;W)T960@;V)J96-T+V-L87-S.B`G+B!G971?8VQA
M<W,H)&EN<'5T*2P@;G5L;"D[#0H)"2`@("!]#0H)"2`@("!B<F5A:SL-"@T*
M#0D)+R\@07)R87D@)B!3=')I;F<-"@D)8V%S92!I<U]A<G)A>2@D:6YP=70I
M.@T*"0EC87-E(&ES7W-T<FEN9R@D:6YP=70I.@T*"0D@("`@)'1H:7,M/FAE
M861E<BT^<V5T1FEE;&1S*"1I;G!U="D[#0H)"2`@("!B<F5A:SL-"@T*#0D)
M+R\@56YK;F]W;B!T>7!E#0H)"61E9F%U;'0Z#0H)"2`@("!R971U<FX@4$5!
M4CHZ=&AR;W=%<G)O<B@G56YS=7!P;W)T960@='EP93H@)RX@9V5T='EP92@D
M:6YP=70I+"!N=6QL*3L-"@D@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!G971(96%D97(H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T
M<R!T:&4@:&5A9&5R(&]B:F5C=`T*("`@("`J#0H@("`@("H@0')E='5R;B!O
M8FIE8W0-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=$AE861E<B@I#0H@("`@>PT*"7)E='5R;B`D=&AI<RT^:&5A
M9&5R.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!S971";V1Y
M*"D-"@T*("`@("\J*@T*("`@("`J(%-E=',@=&AE(&)O9'D-"B`@("`@*@T*
M("`@("`J($!P87)A;2!M:7AE9"`D8F]D>0T@07)R87D@;W(@<W1R:6YG#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E=$)O9'DH)&)O9'DI#0H@("`@>PT*"6EF("AI<U]A<G)A>2@D
M8F]D>2DI('L-"@D@("`@)'1H:7,M/F)O9'D@/2!I;7!L;V1E*")<<EQN(BP@
M)&)O9'DI.PT*"7T@96QS92![#0H)("`@("1T:&ES+3YB;V1Y(#T@)&)O9'D[
M#0H)?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971";V1Y
M*"D-"@T*("`@("\J*@T*("`@("`J($=E=',@=&AE(&)O9'D-"B`@("`@*@T*
M("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971";V1Y*"D-"B`@("![#0H)<F5T
M=7)N("1T:&ES+3YB;V1Y.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!S<&QI=$UE<W-A9V4H*0T*#0H@("`@+RHJ#0H@("`@("H@4W!L:71S
M('1H92!H96%D97(@86YD(&)O9'D@9VEV96X@:6X@)&EN<'5T(&%P87)T("AA
M="!T:&4@9FER<W0-"B`@("`@*B!B;&%N:R!L:6YE*2!A;F0@<F5T=7)N('1H
M96T@*&EN(&%N(&%R<F%Y*2!W:71H('1H92!S86UE('1Y<&4@87,@)&EN<'5T
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1I;G!U="!-97-S86=E
M(&EN(&9O<FT@;V8@96ET97(@<W1R:6YG(&]R(&%R<F%Y#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y($-O;G1A:6YS('-E<&%R871E9"!H96%D97(@
M86YD(&)O9'D@<V5C=&EO;@US(&EN('-A;64@='EP92!A<R`D:6YP=70-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-P
M;&ET365S<V%G92@D:6YP=70I#0H@("`@>PT*"7-W:71C:"`H=')U92D@>PT*
M#0H)("`@("\O(%-T<FEN9PT*"2`@("!C87-E(&ES7W-T<FEN9R@D:6YP=70I
M.PT*("`@(`D):68@*'!R96=?;6%T8V@H(B]>*"XJ/RE<<C]<;EQR/UQN*"XJ
M*2]S(BP@)&EN<'5T+"`D;6%T8VAE<RDI('L-"B`@("`)"2`@("!R971U<FX@
M87)R87DH)VAE861E<B<@/3X@)&UA=&-H97-;,5TL("=B;V1Y)R`]/B`D;6%T
M8VAE<ULR72D[#0H@("`@"0E]#2!E;'-E('L-"@D@("`@"2`@("!R971U<FX@
M4$5!4CHZ=&AR;W=%<G)O<B@G0V]U;&0@;F]T('-P;&ET(&AE861E<B!A;F0@
M8F]D>2<I.PT*"0E]#0H)"6)R96%K.PT*"0D-"@D@("`@+R\@07)R87D-"@D@
M("`@8V%S92!I<U]A<G)A>2@D:6YP=70I.PT*"0DD:&5A9&5R(#T@87)R87DH
M*3L-"@D)=VAI;&4@*"@D;&EN92`](&%R<F%Y7W-H:69T*"1I;G!U="DI("$]
M("<G*2![#0H)"2`@("`D:&5A9&5R6UT@/2`D;&EN93L-"@D)?0T*("`@(`D)
M<F5T=7)N(&%R<F%Y*"=H96%D97(G(#T^("8D:&5A9&5R+"`G8F]D>2<@/3X@
M)&EN<'5T*3L-"@D)8G)E86L[#0H-"@D@("`@+R\@56YK;F]W;B!T>7!E#0H)
M("`@(&1E9F%U;'0Z#0H)("`@("`@("!R971U<FX@4$5!4CHZ=&AR;W=%<G)O
M<B@G56YS=7!P;W)T960@='EP93H@)RYG971T>7!E*"1I;G!U="DI.PT*"7T-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*?0T*#0H_/@T*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B].970O3DY44"]0<F]T;V-O;"YP:'``````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$Q,S<U,P`Q,#0Q-S,V,S`P-@`P
M,C$Q-S$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@0V]P>7)I9VAT
M(*D@,C`P,R!(96EN;R!(+B!'96AL<V5N+B!!;&P@4FEG:'1S(%)E<V5R=F5D
M+B`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@("!H='1P
M.B\O=W=W+FAE:6YO+F=E:&QS96XN9&LO<V]F='=A<F4O;&EC96YS92`@("`@
M("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O('P@5&AI<R!W;W)K("AI;F-L=61I;F<@<V]F
M='=A<F4L(&1O8W5M96YT<RP@;W(@;W1H97(@<F5L871E9"!I=&5M<RD@:7,@
M('P-"B\O('P@8F5I;F<@<')O=FED960@8GD@=&AE(&-O<'ER:6=H="!H;VQD
M97)S('5N9&5R('1H92!F;VQL;W=I;F<@;&EC96YS92X@('P-"B\O('P@0GD@
M;V)T86EN:6YG+"!U<VEN9R!A;F0O;W(@8V]P>6EN9R!T:&ES('=O<FLL('EO
M=2`H=&AE(&QI8V5N<V5E*2`@("`@('P-"B\O('P@86=R964@=&AA="!Y;W4@
M:&%V92!R96%D+"!U;F1E<G-T;V]D+"!A;F0@=VEL;"!C;VUP;'D@=VET:"!T
M:&4@("`@("`@('P-"B\O('P@9F]L;&]W:6YG('1E<FUS(&%N9"!C;VYD:71I
M;VYS.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@4&5R;6ES
M<VEO;B!T;R!U<V4L(&-O<'DL(&UO9&EF>2P@86YD(&1I<W1R:6)U=&4@=&AI
M<R!S;V9T=V%R92!A;F0@("`@('P-"B\O('P@:71S(&1O8W5M96YT871I;VXL
M('=I=&@@;W(@=VET:&]U="!M;V1I9FEC871I;VXL(&9O<B!A;GD@<'5R<&]S
M92!A;F0@('P-"B\O('P@=VET:&]U="!F964@;W(@<F]Y86QT>2!I<R!H97)E
M8GD@9W)A;G1E9"P@<')O=FED960@=&AA="!Y;W4@:6YC;'5D92`@('P-"B\O
M('P@=&AE(&9O;&QO=VEN9R!O;B!!3$P@8V]P:65S(&]F('1H92!S;V9T=V%R
M92!A;F0@9&]C=6UE;G1A=&EO;B!O<B`@("`@('P-"B\O('P@<&]R=&EO;G,@
M=&AE<F5O9BP@:6YC;'5D:6YG(&UO9&EF:6-A=&EO;G,L('1H870@>6]U(&UA
M:V4Z("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@,2X@5&AE(&9U;&P@=&5X="!O9B!T:&ES($Y/5$E#12!I
M;B!A(&QO8V%T:6]N('9I97=A8FQE('1O('5S97)S(&]F("`@('P-"B\O('P@
M("`@=&AE(')E9&ES=')I8G5T960@;W(@9&5R:79A=&EV92!W;W)K+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O('P@,BX@06YY('!R92UE>&ES=&EN9R!I;G1E
M;&QE8W1U86P@<')O<&5R='D@9&ES8VQA:6UE<G,L(&YO=&EC97,L(&]R("`@
M('P-"B\O('P@("`@=&5R;7,@86YD(&-O;F1I=&EO;G,N($EF(&YO;F4@97AI
M<W0L(&$@<VAO<G0@;F]T:6-E(&]F('1H92`@("`@("`@('P-"B\O('P@("`@
M9F]L;&]W:6YG(&9O<FT@*&AY<&5R=&5X="!I<R!P<F5F97)R960L('1E>'0@
M:7,@<&5R;6ET=&5D*2!S:&]U;&0@('P-"B\O('P@("`@8F4@=7-E9"!W:71H
M:6X@=&AE(&)O9'D@;V8@86YY(')E9&ES=')I8G5T960@;W(@9&5R:79A=&EV
M92!C;V1E.B`@('P-"B\O('P@("`@(D-O<'ER:6=H=""I(#(P,#,@2&5I;F\@
M2"X@1V5H;'-E;BX@06QL(%)I9VAT<R!297-E<G9E9"X@("`@("`@("`@('P-
M"B\O('P@("`@(&AT='`Z+R]W=W<N:&5I;F\N9V5H;'-E;BYD:R]S;V9T=V%R
M92]L:6-E;G-E(B`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O('P@,RX@3F]T:6-E(&]F(&%N>2!C
M:&%N9V5S(&]R(&UO9&EF:6-A=&EO;G,@=&\@=&AE(&9I;&5S+"!I;F-L=61I
M;F<@("`@('P-"B\O('P@("`@=&AE(&1A=&4@8VAA;F=E<R!W97)E(&UA9&4N
M("A792!R96-O;6UE;F0@>6]U('!R;W9I9&4@55))<R!T;R`@("`@('P-"B\O
M('P@("`@=&AE(&QO8V%T:6]N(&9R;VT@=VAI8V@@=&AE(&-O9&4@:7,@9&5R
M:79E9"XI("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P-"B\O('P@5$A)4R!33T945T%212!!3D0@1$]#
M54U%3E1!5$E/3B!)4R!04D]6241%1"`B05,@25,L(B!!3D0@0T]065))1TA4
M("`@('P-"B\O('P@2$],1$524R!-04M%($Y/(%)%4%)%4T5.5$%424].4R!/
M4B!705)204Y42453+"!%6%!215-3($]2($E-4$Q)140L("`@('P-"B\O('P@
M24Y#3%5$24Y'($)55"!.3U0@3$E-251%1"!43RP@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@3U(@("`@("`@('P-"B\O('P@1DE43D534R!&3U(@
M04Y9(%!!4E1)0U5,05(@4%524$]312!/4B!42$%4(%1(12!54T4@3T8@5$A%
M(%-/1E1705)%("`@('P-"B\O('P@3U(@1$]#54U%3E1!5$E/3B!724Q,($Y/
M5"!)3D9224Y'12!!3ED@5$A)4D0@4$%25%D@4$%414Y44RP@("`@("`@("`@
M('P-"B\O('P@0T]065))1TA44RP@5%)!1$5-05)+4R!/4B!/5$A%4B!224=(
M5%,N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@0T]065))1TA4($A/3$1%
M4E,@5TE,3"!.3U0@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#
M5"P@("`@("`@('P-"B\O('P@4U!%0TE!3"!/4B!#3TY315%514Y424%,($1!
M34%'15,@05))4TE.1R!/550@3T8@04Y9(%5312!/1B!42$4@("`@("`@('P-
M"B\O('P@4T]&5%=!4D4@3U(@1$]#54U%3E1!5$E/3BX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O('P@5&AE(&YA;64@86YD('1R861E
M;6%R:W,@;V8@8V]P>7)I9VAT(&AO;&1E<G,@;6%Y($Y/5"!B92!U<V5D(&EN
M("`@("`@('P-"B\O('P@861V97)T:7-I;F<@;W(@<'5B;&EC:71Y('!E<G1A
M:6YI;F<@=&\@=&AE('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,L('P-"B\O
M('P@=W)I='1E;B!P<FEO<B!P97)M:7-S:6]N+B!4:71L92!T;R!C;W!Y<FEG
M:'0@:6X@=&AI<R!S;V9T=V%R92!A;F0@86YY('P-"B\O('P@87-S;V-I871E
M9"!D;V-U;65N=&%T:6]N('=I;&P@870@86QL('1I;65S(')E;6%I;B!W:71H
M(&-O<'ER:6=H="`@("`@('P-"B\O('P@:&]L9&5R<RX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O('P@5&AI<R!L:6-E;G-E(&ES(&)A<V5D(&]N
M('1H92`B5S-#KB!33T945T%212!.3U1)0T4@04Y$($Q)0T5.4T4B+B`@("`@
M('P-"B\O('P@3F\@8VAA;F=E<R!H879E(&)E96X@;6%D92!T;R!T:&4@(E<S
M0ZX@4T]&5%=!4D4@3D]424-%($%.1"!,24-%3E-%(BP@('P-"B\O('P@97AC
M97!T(&9O<B!T:&4@<F5F97)E;F-E<R!T;R!T:&4@8V]P>7)I9VAT(&AO;&1E
M<BP@=VAI8V@@:&%S(&5I=&AE<B`@('P-"B\O('P@8F5E;B!C:&%N9V5S(&]R
M(')E;6]V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O("1)9#H@4')O
M=&]C;VPN<&AP+'8@,2XV+C(N,2`R,#`S+S$Q+S$T(#`X.C0T.C$Y(&AE:6YO
M($5X<"`D#0H-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q=6ER95]O
M;F-E("=.970O4V]C:V5T+G!H<"<[#0H-"@T*9&5F:6YE*"=.151?3DY44%]0
M4D]43T-/3%]$149!54Q47TA/4U0G+"`G;&]C86QH;W-T)RD[#0ID969I;F4H
M)TY%5%].3E107U!23U1/0T],7T1%1D%53%1?4$]25"<L("<Q,3DG*3L-"@T*
M+RHJ#0H@*B!4:&4@3F5T7TY.5%!?4')O=&]C;VP@8VQA<W,@:6UP;&5M96YT
M<R!T:&4@3DY44"!S=&%N9&%R9"!A8V]R9&EN9R!T;PT*("H@4D98(#DW-RP@
M4D9#(#(Y.#`L(%)&0R`X-3`O,3`S-@TL(&%N9"!21D,@.#(R+S(X,C(-"B`J
M#0H@*B!`=F5R<VEO;B`P+C`N,0T*("H@0&%U=&AO<B!(96EN;R!(+B!'96AL
M<V5N(#QH96EN;T!G96AL<V5N+F1K/@T*("HO#0IC;&%S<R!.971?3DY44%]0
M<F]T;V-O;"!E>'1E;F1S(%!%05(-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE
M<PT*#0H@("`@+RHJ#0H@("`@("H@5&AE('-O8VME="!R97-O=7)C92!B96EN
M9R!U<V5D('1O(&-O;FYE8W0@=&\@=&AE($E-05`@<V5R=F5R+@T*("`@("`J
M#0H@("`@("H@0'9A<B!R97-O=7)C90T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@('9A<B`D7W-O8VME="`](&YU;&P[#0H-"B`@("`O
M*BH-"B`@("`@*@T*("`@("`J#0H@("`@("H@0'9A<B!R97-O=7)C90T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7V-U<G)E
M;G13=&%T=7-297-P;VYS92`](&YU;&P[#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@8V]N<W1R=6-T;W(-"@D@("`@#0H@("`@+RHJ#0H@("`@("H-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!.971?3DY44%]0<F]T;V-O;"@I('L-"@EP
M87)E;G0Z.E!%05(H*3L-"@D-"@DD=&AI<RT^7W-O8VME="`](&YE=R!.971?
M4V]C:V5T*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[($-O
M;FYE8W0H*0T*#0H@("`@+RHJ#0H@("`@("H@0V]N;F5C="!T;R!T:&4@<V5R
M=F5R#0H@("`@("H-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG("1H
M;W-T(%1H92!A9')E<W,@;V8@=&AE($Y.5%`M<V5R=F5R('1O(&-O;FYE8W0@
M=&\L(&1E9F%U;'1S('1O("=L;V-A;&AO<W0G+@T*("`@("`J($!P87)A;2!O
M<'1I;VYA;"!I;G0@)'!O<G0@5&AE('!O<G0@;G5M8F5R('1O(&-O;FYE8W0@
M=&\L(&1E9F%U;'1S('1O(#$Q.2X-"B`@("`@*@T*("`@("`J($!R971U<FX@
M;6EX960@*&)O;VPI('1R=64@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R
M7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&AO<W0@/2!.151?3DY44%]0
M4D]43T-/3%]$149!54Q47TA/4U0L("1P;W)T(#T@3D547TY.5%!?4%)/5$]#
M3TQ?1$5&055,5%]03U)4*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YI
M<T-O;FYE8W1E9"@I("D@>PT*"2`@("!R971U<FX@4$5!4CHZ=&AR;W=%<G)O
M<B@G06QR96%D>2!C;VYN96-T960L(&1I<V-O;FYE8W0@9FER<W0A)RP@;G5L
M;"D[#0H)?0T*#0H)+R\@3W!E;B!#;VYN96-T:6]N#0H))%(@/2!`)'1H:7,M
M/E]S;V-K970M/F-O;FYE8W0H)&AO<W0L("1P;W)T+"!F86QS92P@,34I.PT*
M"6EF("@D=&AI<RT^:7-%<G)O<B@D4BDI('L-"@D@("`@<F5T=7)N(%!%05(Z
M.G1H<F]W17)R;W(H)T-O=6QD(&YO="!C;VYN96-T('1O('1H92!S97)V97(G
M+"!N=6QL+"`D4BT^9V5T365S<V%G92@I*3L-"@E]#0H-"@DO+R!2971R:79E
M('1H92!S97)V97(G<R!I;FET:6%L(')E<W!O;G-E+@T*"21R97-P;VYS92`]
M("1T:&ES+3Y?9V5T4W1A='5S4F5S<&]N<V4H*3L-"@EI9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S<&]N<V4I*2![#0H)("`@(')E='5R;B`D<F5S<&]N<V4[#0H@
M("`@("`@('T-"@T*("`@("`@("!S=VET8V@@*"1R97-P;VYS92D@>PT*"2`@
M("!C87-E(#(P,#H@+R\@4&]S=&EN9R!A;&QO=V5D#0H)"2\O(%1/1$\Z(%-E
M="!S;VUE('9A<FEA8FQE#0H)("`@("`@("!R971U<FX@=')U93L-"@D@("`@
M("`@(&)R96%K.PT*"2`@("!C87-E(#(P,3H@+R\@4&]S=&EN9R!.3U0@86QL
M;W=E9`T*"0DO+R!43T1/.B!3970@<V]M92!V87)I86)L90T*"2`@("`@("`@
M<F5T=7)N('1R=64[#0H)("`@("`@("!B<F5A:SL-"@D@("`@8V%S92`U,#(Z
M("\O("=A8V-E<W,@<F5S=')I8W1I;VX@;W(@<&5R;6ES<VEO;B!D96YI960G
M#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=397)V97(@<F5F=7-E9"!C
M;VYN96-T:6]N)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E
M<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@9&5F875L=#H-"@D)<F5T=7)N
M(%!%05(Z.G1H<F]W17)R;W(H)U5N:61E;G1I9FEE9"!R97-P;VYS92!C;V1E
M)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E<W!O;G-E*"DI
M.PT*"7T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&ES8V]N
M;F5C="@I#0H-"B`@("`O*BH-"B`@("`@*B!A;&EA<R!F;W(@8VUD475I="@I
M#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0T*("`@('L-"@ER971U<FX@)'1H:7,M
M/F-M9%%U:70H*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M8VUD475I="@I#0H-"B`@("`O*BH-"B`@("`@*B!#;&]S92!C;VYN96-T:6]N
M('1O('1H92!S97)V97(-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VUD475I="@I#0H@("`@>PT*"2\O
M(%1E;&P@=&AE('-E<G9E<B!T;R!C;&]S92!T:&4@8V]N;F5C=&EO;@T*"21R
M97-P;VYS92`]("1T:&ES+3Y?<V5N9$-O;6UA;F0H)U%5250G*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E<W!O;G-E*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1R97-P;VYS93L-"@E]#0H)#0H@("`@("`@('-W:71C:"`H
M)')E<W!O;G-E*2![#0H)("`@(&-A<V4@,C`U.B`O+R!21D,Y-S<Z("=C;&]S
M:6YG(&-O;FYE8W1I;VX@+2!G;V]D8GEE(2<-"@D)+R\@268@<V]C:V5T(&ES
M('-T:6QL(&]P96XL(&-L;W-E(&ET+@T*"0EI9B`H)'1H:7,M/FES0V]N;F5C
M=&5D*"DI('L-"B`@("`)("`@(`D@("`@)'1H:7,M/E]S;V-K970M/F1I<V-O
M;FYE8W0H*3L-"@D)?0T*"0ER971U<FX@=')U93L-"@D)8G)E86L[#0H)("`@
M(&1E9F%U;'0Z#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=5;FED96YT
M:69I960@<F5S<&]N<V4@8V]D92<L("1R97-P;VYS92P@)'1H:7,M/F-U<G)E
M;G13=&%T=7-297-P;VYS92@I*3L-"@E]#0H-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"@T*("`@("\J*@T*("`@("`J(%1H92!A=71H96YT:6-A=&EO;B!P<F]C
M97-S(&D@;F]T('EE="!S=&%N9&%R:7IE9"!B=70@=7-E9"!A;GD@=V%Y#0H@
M("`@("H@*&AT='`Z+R]W=W<N;6EB<V]F='=A<F4N8V]M+W5S97)K="]N;G1P
M97AT+VEN9&5X+FAT;6PI+@T*("`@("`J+PT*("`@("`-"B`@("`O+R![>WL@
M8VUD075T:&EN9F\H*0T*#0H@("`@+RHJ#0H@("`@("H@075T:&5N=&EC871E
M<R!T:&4@=7-E<B!U<VEN9R!T:&4@;W)I9VEN86P@;65T:&]D#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R(%1H92!U<V5R;F%M92!T;R!A
M=71H96YT:6-A=&4@87,N#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<R!4
M:&4@<&%S<W=O<F0@=&\@875T:&5N=&EC871E('=I=&@N#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("AB;V]L*2!T<G5E(&]N('-U8V-E<W,@;W(@
M*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E(`T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-M9$%U=&AI;F9O
M*"1U<V5R+"`D<&%S<RD-"B`@("![#0H)+R\@4V5N9"!T:&4@=7-E<FYA;64-
M"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD0V]M;6%N9"@G0554
M2$E.1D\@=7-E<B`G+B1U<V5R*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)')E<W!O;G-E*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1R97-P;VYS
M93L-"@E]#0H-"@DO+R!396YD('1H92!P87-S=V]R9"P@:68@=&AE('-E<G9E
M<B!A<VMS#0H):68@*"@D<F5S<&]N<V4@/3T@,S@Q*2`F)B`H)'!A<W,@(3T]
M(&YU;&PI*2![#0H)("`@("\O(%-E;F0@=&AE('!A<W-W;W)D#0H@("`@("`@
M("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7W-E;F1#;VUM86YD*"=!551(24Y&
M3R!P87-S("<N)'!A<W,I.PT*"2`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S
M<&]N<V4I*2![#0H@("`@("`@(`ER971U<FX@)')E<W!O;G-E.PT*"2`@("!]
M#0H)?0T*#0H@("`@("`@('-W:71C:"`H)')E<W!O;G-E*2![#0H)("`@(&-A
M<V4@,C@Q.B`O+R!21D,R.3@P.B`G075T:&5N=&EC871I;VX@86-C97!T960G
M#0H)("`@("`@("!R971U<FX@=')U93L-"@D@("`@("`@(&)R96%K.PT*"2`@
M("!C87-E(#,X,3H@+R\@4D9#,CDX,#H@)TUO<F4@875T:&5N=&EC871I;VX@
M:6YF;W)M871I;VX@<F5Q=6ER960G#0H)("`@("`@("!R971U<FX@4$5!4CHZ
M=&AR;W=%<G)O<B@G075T:&5N=&EC871I;VX@=6YC;VUP;&5T960G+"`D<F5S
M<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)("`@
M("`@("!B<F5A:SL-"@D@("`@8V%S92`T.#(Z("\O(%)&0S(Y.#`Z("=!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"<-"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R
M;W(H)T%U=&AE;G1I8V%T:6]N(')E:F5C=&5D)RP@)')E<W!O;G-E+"`D=&AI
M<RT^8W5R<F5N=%-T871U<U)E<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@
M8V%S92`U,#(Z("\O(%)&0S(Y.#`Z("=.;R!P97)M:7-S:6]N)PT*"0ER971U
M<FX@4$5!4CHZ=&AR;W=%<G)O<B@G075T:&5N=&EC871I;VX@<F5J96-T960G
M+"`D<F5S<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[
M#0H)"6)R96%K.PT*+R\)("`@(&-A<V4@-3`P.@T*+R\)("`@(&-A<V4@-3`Q
M.@T*+R\)("`@(`ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G075T:&5N=&EC
M871I;VX@9F%I;&5D)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U
M<U)E<W!O;G-E*"DI.PT*+R\)("`@(`EB<F5A:SL-"@D@("`@9&5F875L=#H-
M"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)U5N97AP96-T960@875T:&5N
M=&EC871I;VX@97)R;W(A)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T
M871U<U)E<W!O;G-E*"DI.PT*"7T-"B`@("!]#0H)#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&-M9$%U=&AI;F9O4VEM<&QE*"D-"@T*("`@("\J*@T*("`@
M("`J($%U=&AE;G1I8V%T97,@=&AE('5S97(@=7-I;F<@=&AE('-I;7!L92!M
M971H;V0-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@5&AE
M('5S97)N86UE('1O(&%U=&AE;G1I8V%T92!A<RX-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87-S(%1H92!P87-S=V]R9"!T;R!A=71H96YT:6-A=&4@=VET
M:"X-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&)O;VPI('1R=64@
M;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4@
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@8VUD075T:&EN9F]3:6UP;&4H)'5S97(L("1P87-S*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H(E1H92!A=71H(&UO9&4Z
M("=S:6UP;&4G(&ES(&AA<R!N;W0@8F5E;B!I;7!L96UE;G1E9"!Y970B+"!N
M=6QL*3L-"B`@("!]#0H)#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-M9$%U
M=&AI;F9O1V5N97)I8R@I#0H-"B`@("`O*BH-"B`@("`@*B!!=71H96YT:6-A
M=&5S('1H92!U<V5R('5S:6YG('1H92!S:6UP;&4@;65T:&]D#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R(%1H92!U<V5R;F%M92!T;R!A
M=71H96YT:6-A=&4@87,N#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<R!4
M:&4@<&%S<W=O<F0@=&\@875T:&5N=&EC871E('=I=&@N#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("AB;V]L*2!T<G5E(&]N('-U8V-E<W,@;W(@
M*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E(`T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-M9$%U=&AI;F9O
M1V5N97)I8R@D=7-E<BP@)'!A<W,I#0H@("`@>PT*("`@("`@("!R971U<FX@
M4$5!4CHZ=&AR;W=%<G)O<B@B5&AE(&%U=&@@;6]D93H@)V=E;F5R:6,G(&ES
M(&AA<R!N;W0@8F5E;B!I;7!L96UE;G1E9"!Y970B+"!N=6QL*3L-"B`@("!]
M#0H)#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-M9$UO9&5296%D97(H*0T*
M#0H@("`@+RHJ#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AB;V]L
M*2!T<G5E('=H96X@;VYE(&-A;B!P;W-T(&]N('-U8V-E<W,@;W(@*&]B:F5C
M="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E(`T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VUD36]D95)E861E<B@I#0H@
M("`@>PT*("`@("`@("`O+R!T96QL('1H92!N97=S<V5R=F5R('=E('=A;G0@
M86X@87)T:6-L90T*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7W-E;F1#
M;VUM86YD*"=-3T1%(%)%041%4B<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S<&]N<V4I*2![#0H@("`@("`@("`@("!R971U<FX@)')E<W!O
M;G-E.PT*("`@("`@("!]#0H)#0H)<W=I=&-H("@D<F5S<&]N<V4I('L-"B`@
M("`@("`@("`@(&-A<V4@,C`P.B`O+R!21D,R.3@P.B`G2&5L;&\L('EO=2!C
M86X@<&]S="<-"@D@("`@("`@(&)R96%K.PT*"2`@("!C87-E(#(P,3H@+R\@
M4D9#,CDX,#H@)TAE;&QO+"!Y;W4@8V%N)W0@<&]S="<-"@D)8G)E86L[#0H)
M("`@(&1E9F%U;'0Z#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=5;FED
M96YT:69I960@<F5S<&]N<V4@8V]D92<L("1R97-P;VYS92P@)'1H:7,M/F-U
M<G)E;G13=&%T=7-297-P;VYS92@I*3L-"@E]#0H-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@8VUD07)T:6-L92@I#0H-"B`@("`O*BH-"B`@
M("`@*B!'970@86X@87)T:6-L92!F<F]M('1H92!C=7)R96YT;'D@;W!E;B!C
M;VYN96-T:6]N+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1A<G1I
M8VQE($5I=&AE<B!A(&UE<W-A9V4M:60@;W(@82!M97-S86=E+6YU;6)E<B!O
M9B!T:&4@87)T:6-L92!T;R!F971C:"X@268@;G5L;"!O<B`G)RP@=&AE;B!U
M<V4@8W5R<F5N="!A<G1I8VQE+@T*("`@("`J#0H@("`@("H@0')E='5R;B!M
M:7AE9"`H87)R87DI(&%R=&EC;&4@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P
M96%R7V5R<F]R(&]N(&9A:6QU<F4@#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;61!<G1I8VQE*"1A<G1I8VQE*0T*
M("`@('L-"B`@("`@("`@+R\@=&5L;"!T:&4@;F5W<W-E<G9E<B!W92!W86YT
M(&%N(&%R=&EC;&4-"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD
M0V]M;6%N9"@G05)424-,12`G+B1A<G1I8VQE*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)')E<W!O;G-E*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1R97-P;VYS93L-"B`@("`@("`@?0T*"0T*"7-W:71C:"`H)')E<W!O;G-E
M*2![#0H)("`@(&-A<V4@,C(P.B`O+R!21D,Y-S<Z("=N(#QA/B!A<G1I8VQE
M(')E=')I979E9"`M(&AE860@86YD(&)O9'D@9F]L;&]W("AN(#T@87)T:6-L
M92!N=6UB97(L(#QA/B`](&UE<W-A9V4M:60I)PT*"2`@("!C87-E(#(R,3H@
M+R\@4D9#.3<W.B`G;B`\83X@87)T:6-L92!R971R:65V960@+2!H96%D(&9O
M;&QO=W,G#0H)("`@(&-A<V4@,C(R.B`O+R!21D,Y-S<Z("=N(#QA/B!A<G1I
M8VQE(')E=')I979E9"`M(&)O9'D@9F]L;&]W<R<-"@D@("`@8V%S92`R,C,Z
M("\O(%)&0SDW-SH@)VX@/&$^(&%R=&EC;&4@<F5T<FEE=F5D("T@<F5Q=65S
M="!T97AT('-E<&%R871E;'DG#0H)"21D871A(#T@)'1H:7,M/E]G971497AT
M4F5S<&]N<V4H*3L-"B`@("`)"6EF("A014%2.CII<T5R<F]R*"1D871A*2D@
M>PT*("`@(`D@("`@"2`@("!R971U<FX@)&1A=&$[#0H@("`@"0E]#0H)"7)E
M='5R;B`D9&%T83L-"@D)8G)E86L[#0H)("`@(&-A<V4@-#$R.B`O+R!21D,Y
M-S<Z("=N;R!N97=S9W)O=7`@:&%S(&)E96X@<V5L96-T960G#0H)"7)E='5R
M;B!014%2.CIT:')O=T5R<F]R*"=.;R!N97=S9W)O=7`@:&%S(&)E96X@<V5L
M96-T960G+"`D<F5S<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N
M<V4H*2D[#0H)"6)R96%K.PT*"2`@("!C87-E(#0R,#H@+R\@4D9#.3<W.B`G
M;F\@8W5R<F5N="!A<G1I8VQE(&AA<R!B965N('-E;&5C=&5D)PT*"0ER971U
M<FX@4$5!4CHZ=&AR;W=%<G)O<B@G3F\@8W5R<F5N="!A<G1I8VQE(&AA<R!B
M965N('-E;&5C=&5D)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U
M<U)E<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@8V%S92`T,C,Z("\O(%)&
M0SDW-SH@)VYO('-U8V@@87)T:6-L92!N=6UB97(@:6X@=&AI<R!G<F]U<"<-
M"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)TYO('-U8V@@87)T:6-L92!N
M=6UB97(@:6X@=&AI<R!G<F]U<"<L("1R97-P;VYS92P@)'1H:7,M/F-U<G)E
M;G13=&%T=7-297-P;VYS92@I*3L-"@D)8G)E86L[#0H)("`@(&-A<V4@-#,P
M.B`O+R!21D,Y-S<Z("=N;R!S=6-H(&%R=&EC;&4@9F]U;F0G#0H)"7)E='5R
M;B!014%2.CIT:')O=T5R<F]R*"=.;R!S=6-H(&%R=&EC;&4@9F]U;F0G+"`D
M<F5S<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)
M"6)R96%K.PT*"2`@("!D969A=6QT.@T*"0ER971U<FX@4$5!4CHZ=&AR;W=%
M<G)O<B@G56YI9&5N=&EF:65D(')E<W!O;G-E(&-O9&4G+"`D<F5S<&]N<V4L
M("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)?0T*#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-M9$AE860H*0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5T('1H92!H96%D97)S(&]F(&%N(&%R=&EC;&4@9G)O
M;2!T:&4@8W5R<F5N=&QY(&]P96X@8V]N;F5C=&EO;BX-"B`@("`@*@T*("`@
M("`J($!P87)A;2!M:7AE9"`D87)T:6-L92!%:71H97(@82!M97-S86=E+6ED
M(&]R(&$@;65S<V%G92UN=6UB97(@;V8@=&AE(&%R=&EC;&4@=&\@9F5T8V@@
M=&AE(&AE861E<G,@9G)O;2X@268@;G5L;"!O<B`G)RP@=&AE;B!U<V4@8W5R
M<F5N="!A<G1I8VQE+@T*("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE9"`H
M87)R87DI(&AE861E<G,@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R
M<F]R(&]N(&9A:6QU<F4@#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!C;61(96%D*"1A<G1I8VQE*0T*("`@('L-"B`@
M("`@("`@+R\@=&5L;"!T:&4@;F5W<W-E<G9E<B!W92!W86YT('1H92!H96%D
M97(@;V8@86X@87)T:6-L90T*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^
M7W-E;F1#;VUM86YD*"=(14%$("<N)&%R=&EC;&4I.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5S<&]N<V4I*2![#0H@("`@("`@("`@("!R971U
M<FX@)')E<W!O;G-E.PT*("`@("`@("!]#0H-"@ES=VET8V@@*"1R97-P;VYS
M92D@>PT*"2`@("!C87-E(#(R,#H@+R\@4D9#.3<W.B`G;B`\83X@87)T:6-L
M92!R971R:65V960@+2!H96%D(&%N9"!B;V1Y(&9O;&QO=R`H;B`](&%R=&EC
M;&4@;G5M8F5R+"`\83X@/2!M97-S86=E+6ED*2<-"@D@("`@8V%S92`R,C$Z
M("\O(%)&0SDW-SH@)VX@/&$^(&%R=&EC;&4@<F5T<FEE=F5D("T@:&5A9"!F
M;VQL;W=S)PT*"2`@("!C87-E(#(R,CH@+R\@4D9#.3<W.B`G;B`\83X@87)T
M:6-L92!R971R:65V960@+2!B;V1Y(&9O;&QO=W,G#0H)("`@(&-A<V4@,C(S
M.B`O+R!21D,Y-S<Z("=N(#QA/B!A<G1I8VQE(')E=')I979E9"`M(')E<75E
M<W0@=&5X="!S97!A<F%T96QY)PT*"0DD9&%T82`]("1T:&ES+3Y?9V5T5&5X
M=%)E<W!O;G-E*"D[#0H@("`@("`@(`EI9B`H4$5!4CHZ:7-%<G)O<B@D9&%T
M82DI('L-"B`@("`@("`@"2`@("!R971U<FX@)&1A=&$[#0H@("`@("`@(`E]
M#0H)("`@("`@("!R971U<FX@)&1A=&$[#0H)"6)R96%K.PT*"2`@("!C87-E
M(#0Q,CH@+R\@4D9#.3<W.B`G;F\@;F5W<V=R;W5P(&AA<R!B965N('-E;&5C
M=&5D)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G3F\@;F5W<V=R;W5P
M(&AA<R!B965N('-E;&5C=&5D)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N
M=%-T871U<U)E<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@8V%S92`T,C`Z
M("\O(%)&0SDW-SH@)VYO(&-U<G)E;G0@87)T:6-L92!H87,@8F5E;B!S96QE
M8W1E9"<-"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)TYO(&-U<G)E;G0@
M87)T:6-L92!H87,@8F5E;B!S96QE8W1E9"<L("1R97-P;VYS92P@)'1H:7,M
M/F-U<G)E;G13=&%T=7-297-P;VYS92@I*3L-"@D)8G)E86L[#0H)("`@(&-A
M<V4@-#(S.B`O+R!21D,Y-S<Z("=N;R!S=6-H(&%R=&EC;&4@;G5M8F5R(&EN
M('1H:7,@9W)O=7`G#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=.;R!S
M=6-H(&%R=&EC;&4@;G5M8F5R(&EN('1H:7,@9W)O=7`G+"`D<F5S<&]N<V4L
M("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)"6)R96%K.PT*
M"2`@("!C87-E(#0S,#H@+R\@4D9#.3<W.B`G;F\@<W5C:"!A<G1I8VQE(&9O
M=6YD)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G3F\@<W5C:"!A<G1I
M8VQE(&9O=6YD)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E
M<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@9&5F875L=#H-"@D)<F5T=7)N
M(%!%05(Z.G1H<F]W17)R;W(H)U5N:61E;G1I9FEE9"!R97-P;VYS92!C;V1E
M)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E<W!O;G-E*"DI
M.PT*"7T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VUD0F]D
M>2@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&)O9'D@;V8@86X@87)T
M:6-L92!F<F]M('1H92!C=7)R96YT;'D@;W!E;B!C;VYN96-T:6]N+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1A<G1I8VQE($5I=&AE<B!A(&UE
M<W-A9V4M:60@;W(@82!M97-S86=E+6YU;6)E<B!O9B!T:&4@87)T:6-L92!T
M;R!F971C:"!T:&4@8F]D>2!F<F]M+B!)9B!N=6QL(&]R("<G+"!T:&5N('5S
M92!C=7)R96YT(&%R=&EC;&4N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("AA<G)A>2D@8F]D>2!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E87)?
M97)R;W(@;VX@9F%I;'5R92`-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&-M9$)O9'DH)&%R=&EC;&4I#0H@("`@>PT*
M("`@("`@("`O+R!T96QL('1H92!N97=S<V5R=F5R('=E('=A;G0@=&AE(&)O
M9'D@;V8@86X@87)T:6-L90T*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^
M7W-E;F1#;VUM86YD*"="3T19("<N)&%R=&EC;&4I.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5S<&]N<V4I*2![#0H@("`@("`@("`@("!R971U
M<FX@)')E<W!O;G-E.PT*("`@("`@("!]#0H-"@ES=VET8V@@*"1R97-P;VYS
M92D@>PT*"2`@("!C87-E(#(R,#H@+R\@4D9#.3<W.B`G;B`\83X@87)T:6-L
M92!R971R:65V960@+2!H96%D(&%N9"!B;V1Y(&9O;&QO=R`H;B`](&%R=&EC
M;&4@;G5M8F5R+"`\83X@/2!M97-S86=E+6ED*2<-"@D@("`@8V%S92`R,C$Z
M("\O(%)&0SDW-SH@)VX@/&$^(&%R=&EC;&4@<F5T<FEE=F5D("T@:&5A9"!F
M;VQL;W=S)PT*"2`@("!C87-E(#(R,CH@+R\@4D9#.3<W.B`G;B`\83X@87)T
M:6-L92!R971R:65V960@+2!B;V1Y(&9O;&QO=W,G#0H)("`@(&-A<V4@,C(S
M.B`O+R!21D,Y-S<Z("=N(#QA/B!A<G1I8VQE(')E=')I979E9"`M(')E<75E
M<W0@=&5X="!S97!A<F%T96QY)PT*"0DD9&%T82`]("1T:&ES+3Y?9V5T5&5X
M=%)E<W!O;G-E*"D[#0H@("`@("`@(`EI9B`H4$5!4CHZ:7-%<G)O<B@D9&%T
M82DI('L-"B`@("`@("`@"2`@("!R971U<FX@)&1A=&$[#0H@("`@("`@(`E]
M#0H)("`@("`@("!R971U<FX@)&1A=&$[#0H)"6)R96%K.PT*"2`@("!C87-E
M(#0Q,CH@+R\@4D9#.3<W.B`G;F\@;F5W<V=R;W5P(&AA<R!B965N('-E;&5C
M=&5D)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G3F\@;F5W<V=R;W5P
M(&AA<R!B965N('-E;&5C=&5D)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N
M=%-T871U<U)E<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@8V%S92`T,C`Z
M("\O(%)&0SDW-SH@)VYO(&-U<G)E;G0@87)T:6-L92!H87,@8F5E;B!S96QE
M8W1E9"<-"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)TYO(&-U<G)E;G0@
M87)T:6-L92!H87,@8F5E;B!S96QE8W1E9"<L("1R97-P;VYS92P@)'1H:7,M
M/F-U<G)E;G13=&%T=7-297-P;VYS92@I*3L-"@D)8G)E86L[#0H)("`@(&-A
M<V4@-#(S.B`O+R!21D,Y-S<Z("=N;R!S=6-H(&%R=&EC;&4@;G5M8F5R(&EN
M('1H:7,@9W)O=7`G#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=.;R!S
M=6-H(&%R=&EC;&4@;G5M8F5R(&EN('1H:7,@9W)O=7`G+"`D<F5S<&]N<V4L
M("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)"6)R96%K.PT*
M"2`@("!C87-E(#0S,#H@+R\@4D9#.3<W.B`G;F\@<W5C:"!A<G1I8VQE(&9O
M=6YD)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G3F\@<W5C:"!A<G1I
M8VQE(&9O=6YD)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E
M<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@9&5F875L=#H-"@D)<F5T=7)N
M(%!%05(Z.G1H<F]W17)R;W(H)U5N:61E;G1I9FEE9"!R97-P;VYS92!C;V1E
M)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E<W!O;G-E*"DI
M.PT*"7T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VUD4&]S
M="@I#0H-"B`@("`O*BH-"B`@("`@*B!0;W-T(&%N(&%R=&EC;&4@=&\@82!N
M97=S9W)O=7`N#0H@("`@("H-"B`@("`@*B!!;6]N9R!T:&4@861I=&EO;F%L
M(&AE861E<G,@>6]U(&UI9VAT('1H:6YK(&]F(&%D9&EN9R!C;W5L9"!B93H-
M"B`@("`@*B`B3DY44"U0;W-T:6YG+4AO<W0Z(#QI<"UO9BUA=71H;W(^(BP@
M=VAI8V@@<VAO=6QD(&-O;G1A:6X@=&AE($E0+6%D<F5S<PT*("`@("`J(&]F
M('1H92!A=71H;W(@;V8@=&AE('!O<W0L('-O('1H92!M97-S86=E(&-A;B!B
M92!T<F%C960@8F%C:R!T;R!H:6TN#0H@("`@("H@(D]R9V%N:7IA=&EO;CH@
M/&]R9SXB('=H:6-H(&-O;G1A:6X@=&AE(&YA;64@;V8@=&AE(&]R9V%N:7IA
M=&EO;@T*("`@("`J('1H92!P;W-T(&]R:6=I;F%T97,@9G)O;2X-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@)&YE=W-G<F]U<"!4:&4@;F5W<V=R
M;W5P('1O('!O<W0@=&\N#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<W5B:F5C
M="!4:&4@<W5B:F5C="!O9B!T:&4@<&]S="X-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1B;V1Y(%1H92!B;V1Y(&]F('1H92!P;W-T(&ET<V5L9BX-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F<F]M($YA;64@*R!E;6%I;"UA9')E<W,@;V8@
M<V5N9&5R+@T*("`@("`J($!P87)A;2!O<'1I;VYA;"!S=')I;F<@)&%D:71I
M;VYA;"!!9&ET:6]N86P@:&5A9&5R<R!T;R!S96YD+@T*("`@("`J#0H@("`@
M("H@0')E='5R;B!M:7AE9"`H8F]O;"D@=')U92!O;B!S=6-C97-S(&]R("AO
M8FIE8W0I('!E87)?97)R;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VUD4&]S="@D;F5W<V=R
M;W5P+"`D<W5B:F5C="P@)&)O9'DL("1F<F]M+"`D861I=&EO;F%L(#T@)R<I
M#0H@("`@>PT*("`@("`@("`O+R!T96QL('1H92!N97=S<V5R=F5R('=E('=A
M;G0@=&\@<&]S="!A;B!A<G1I8VQE#0H))')E<W!O;G-E(#T@)'1H:7,M/E]S
M96YD0V]M;6%N9"@G4$]35"<I.PT*"6EF("A014%2.CII<T5R<F]R*"1R97-P
M;VYS92DI('L-"@D@("`@<F5T=7)N("1R97-P;VYS93L-"B`@("`@("`@?0T*
M#0H):68@*"1R97-P;VYS92`]/2`S-#`I('L@+R\@4D9#.3<W.B`G<V5N9"!A
M<G1I8VQE('1O(&)E('!O<W1E9"X@16YD('=I=&@@/$-2+4Q&/BX\0U(M3$8^
M)PT*#0H)("`@("\O('-H;W5L9"!B92!P<F5S96YT960@:6X@=&AE(&9O<FUA
M="!S<&5C:69I960@8GD@4D9#.#4P#0H)("`@(`T*("`@("`@("`@("`@)'1H
M:7,M/E]S;V-K970M/G=R:71E*").97=S9W)O=7!S.B`D;F5W<V=R;W5P7')<
M;B(I.PT*("`@("`@("`@("`@)'1H:7,M/E]S;V-K970M/G=R:71E*")3=6)J
M96-T.B`D<W5B:F5C=%QR7&XB*3L-"B`@("`)("`@("1T:&ES+3Y?<V]C:V5T
M+3YW<FET92@B1G)O;3H@)&9R;VU<<EQN(BD[#0H@("`@("`@("`@("`D=&AI
M<RT^7W-O8VME="T^=W)I=&4H(E@M<&]S=&5R.B!014%2.CI.971?3DY44%QR
M7&XB*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<V]C:V5T+3YW<FET92@B)&%D
M:71I;VYA;%QR7&XB*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<V]C:V5T+3YW
M<FET92@B7')<;B(I.PT*("`@("`@("`@("`@)'1H:7,M/E]S;V-K970M/G=R
M:71E*"(D8F]D>5QR7&XB*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<V]C:V5T
M+3YW<FET92@B+EQR7&XB*3L-"@T*"2`@("`O+R!2971R:79E('-E<G9E<B=S
M(')E<W!O;G-E+@T*"2`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V=E=%-T871U
M<U)E<W!O;G-E*"D[#0H)("`@(&EF("A014%2.CII<T5R<F]R*"1R97-P;VYS
M92DI('L-"@D)<F5T=7)N("1R97-P;VYS93L-"B`@("`)("`@('T-"@E]#0H-
M"@ES=VET8V@@*"1R97-P;VYS92D@>PT*("`@(`D@("`@8V%S92`R-#`Z("\O
M(%)&0SDW-SH@)V%R=&EC;&4@<&]S=&5D(&]K)PT*"0ER971U<FX@=')U93L-
M"@D)8G)E86L[#0H@("`@"2`@("!C87-E(#,T,#H@+R\@4D9#.3<W.B`G<V5N
M9"!A<G1I8VQE('1O(&)E('!O<W1E9"X@16YD('=I=&@@/$-2+4Q&/BX\0U(M
M3$8^)PT*"0DO+R!4:&ES('-H;W5L9"!N;W0@:&%P<&5N(&AE<F4A#0H)"7)E
M='5R;B!014%2.CIT:')O=T5R<F]R*"=5;FMN;W=N(&5R<F]R(&1U<FEN9R!P
M;W-T)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E<W!O;G-E
M*"DI.PT*"0EB<F5A:SL-"B`@("`)("`@(&-A<V4@-#0P.B`O+R!21D,Y-S<Z
M("=P;W-T:6YG(&YO="!A;&QO=V5D)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%
M<G)O<B@G4&]S=&EN9R!N;W0@86QL;W=E9"<L("1R97-P;VYS92P@)'1H:7,M
M/F-U<G)E;G13=&%T=7-297-P;VYS92@I*3L-"@D)8G)E86L[#0H@("`@"2`@
M("!C87-E(#0T,3H@+R\@4D9#.3<W.B`G<&]S=&EN9R!F86EL960G#0H)"7)E
M='5R;B!014%2.CIT:')O=T5R<F]R*"=0;W-T:6YG(&9A:6QE9"<L("1R97-P
M;VYS92P@)'1H:7,M/F-U<G)E;G13=&%T=7-297-P;VYS92@I*3L-"@D)8G)E
M86L[#0H)("`@(&1E9F%U;'0Z#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R
M*"=5;FED96YT:69I960@<F5S<&]N<V4@8V]D92<L("1R97-P;VYS92P@)'1H
M:7,M/F-U<G)E;G13=&%T=7-297-P;VYS92@I*3L-"@E]#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&-M9$=R;W5P*"D-"@T*("`@("\J*@T*
M("`@("`J(%-E;&5C=',@82!N97=S(&=R;W5P("AI<W-U92!A($=23U50(&-O
M;6UA;F0@=&\@=&AE('-E<G9E<BD-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)&YE=W-G<F]U<"!4:&4@;F5W<V=R;W5P(&YA;64-"B`@("`@*@T*
M("`@("`J($!R971U<FX@;6EX960@*&%R<F%Y*2!G<F]U<&EN9F\@;VX@<W5C
M8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-M9$=R
M;W5P*"1N97=S9W)O=7`I#0H@("`@>PT*("`@("`@("`D<F5S<&]N<V4@/2`D
M=&AI<RT^7W-E;F1#;VUM86YD*"='4D]54"`G+B1N97=S9W)O=7`I.PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S<&]N<V4I*2![#0H@("`@("`@
M("`@("!R971U<FX@)')E<W!O;G-E.PT*("`@("`@("!]#0H-"@ES=VET8V@@
M*"1R97-P;VYS92D@>PT*("`@(`D@("`@8V%S92`R,3$Z("\O(%)&0SDW-SH@
M)VX@9B!L(',@9W)O=7`@<V5L96-T960G#0H@("`@"0DD<F5S<&]N<V5?87)R
M(#T@<W!L:70H)R`G+"!T<FEM*"1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N
M<V4H*2DI.PT*("`@(`D))')E<W!O;G-E7V%R<ELG8V]U;G0G72`])B`D<F5S
M<&]N<V5?87)R6S!=.PT*"2`@("`@("`@)')E<W!O;G-E7V%R<ELG9FER<W0G
M72`])B`D<F5S<&]N<V5?87)R6S%=.PT*"0DD<F5S<&]N<V5?87)R6R=L87-T
M)UT@(#TF("1R97-P;VYS95]A<G);,ET[#0H)"21R97-P;VYS95]A<G);)V=R
M;W5P)UT@/28@)')E<W!O;G-E7V%R<ELS73L-"@D)<F5T=7)N("1R97-P;VYS
M95]A<G([#0H)"6)R96%K.PT*"2`@("!C87-E(#0Q,3H@+R\@4D9#.3<W.B`G
M;F\@<W5C:"!N97=S(&=R;W5P)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O
M<B@G3F\@<W5C:"!N97=S(&=R;W5P)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R
M<F5N=%-T871U<U)E<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@9&5F875L
M=#H-"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)U5N:61E;G1I9FEE9"!R
M97-P;VYS92!C;V1E)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U
M<U)E<W!O;G-E*"DI.PT*"7T-"@D-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@8VUD3&ES="@I#0H-"B`@("`O*BH-"B`@("`@*B!&971C:&5S
M(&$@;&ES="!O9B!A;&P@879A:6)L92!N97=S9W)O=7!S#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A>2D@;F5S=&5D(&%R<F%Y('=I=&@@
M:6YF;W)M871I;VYS(&%B;W5T(&5X:7-T:6YG(&YE=W-G<F]U<',@;VX@<W5C
M8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-M9$QI
M<W0H*0T*("`@('L-"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD
M0V]M;6%N9"@G3$E35"<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5S<&]N<V4I*7L-"B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4[#0H@
M("`@("`@('T-"@T*"7-W:71C:"`H)')E<W!O;G-E*2![#0H@("`@"2`@("!C
M87-E(#(Q-3H@+R\@4D9#.3<W.B`G;&ES="!O9B!N97=S9W)O=7!S(&9O;&QO
M=W,G#0H)"21D871A(#T@)'1H:7,M/E]G971497AT4F5S<&]N<V4H*3L-"B`@
M("`)"6EF("A014%2.CII<T5R<F]R*"1D871A*2D@>PT*("`@(`D)("`@(')E
M='5R;B`D9&%T83L-"B`@("`)"7T-"B`@("`)"69O<F5A8V@H)&1A=&$@87,@
M)&QI;F4I('L-"B`@("`)"2`@("`D87)R(#T@97AP;&]D92@G("<L('1R:6TH
M)&QI;F4I*3L-"B`@("`)"2`@("`D87)R6R=G<F]U<"==("`@(#TF("1A<G);
M,%T[#0H@("`@"0D@("`@)&%R<ELG;&%S="==("`@("`])B`D87)R6S%=.PT*
M("`@(`D)("`@("1A<G);)V9I<G-T)UT@("`@/28@)&%R<ELR73L-"B`@("`)
M"2`@("`D87)R6R=P;W-T:6YG)R!=(#T@*&)O;VPI("@D87)R6S-=(#T]("=Y
M)RD[#0H@("`@"0D@("`@)&=R;W5P<ULD87)R6S!=72`]("1A<G([#0H@("`@
M"0E]#0H)("`@("`@("!R971U<FX@)&=R;W5P<SL-"@D)8G)E86L[#0H)("`@
M(&1E9F%U;'0Z#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=5;FED96YT
M:69I960@<F5S<&]N<V4@8V]D92<L("1R97-P;VYS92P@)'1H:7,M/F-U<G)E
M;G13=&%T=7-297-P;VYS92@I*3L-"@E]#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&-M9$QI<W1.97=S9W)O=7!S*"D-"@T*("`@("\J*@T*
M("`@("`J($9E=&-H97,@82!L:7-T(&]F("AA;&PI(&%V86EB;&4@;F5W<V=R
M;W5P(&1E<V-R:7!T:6]N<RX-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F<@)'=I;&1M870@5VEL9&UA="!O9B!T:&4@9W)O=7!S+"!T:&%T(&ES('1O
M(&)E(&QI<W1E9"P@9&5F875L=',@=&\@)R<[#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("AA<G)A>2D@;F5S=&5D(&%R<F%Y('=I=&@@9&5S8W)I
M<'1I;VX@;V8@97AI<W1I;F<@;F5W<V=R;W5P<R!O;B!S=6-C97-S(&]R("AO
M8FIE8W0I('!E87)?97)R;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VUD3&ES=$YE=W-G<F]U
M<',H)'=I;&1M870@/2`G)RD-"B`@("![#0H@("`@("`@("1R97-P;VYS92`]
M("1T:&ES+3Y?<V5N9$-O;6UA;F0H)TQ)4U0@3D574T=23U504R`G+B1W:6QD
M;6%T*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W!O;G-E*2E[
M#0H@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PT*("`@("`@("!]#0H-
M"@ES=VET8V@@*"1R97-P;VYS92D@>PT*"2`@("!C87-E(#(Q-3H@+R\@4D9#
M,CDX,#H@)VEN9F]R;6%T:6]N(&9O;&QO=W,G#0H)"21D871A(#T@)'1H:7,M
M/E]G971497AT4F5S<&]N<V4H*3L-"@D@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1D871A*2D@>PT*"2`@("`@("`@("`@(')E='5R;B`D9&%T83L-"@D@
M("`@("`@('T-"@T*"2`@("`@("`@9F]R96%C:"@D9&%T82!A<R`D;&EN92D@
M>PT*"2`@("`@("`@("`@('!R96=?;6%T8V@H(B]>*"XJ/RE<<R@N*C\D*2\B
M+"!T<FEM*"1L:6YE*2P@)&UA=&-H97,I.PT*"2`@("`@("`@("`@("1G<F]U
M<'-;)&UA=&-H97-;,5U=(#T@*'-T<FEN9RD@)&UA=&-H97-;,ET[#0H)("`@
M("`@("!]#0H-"@D@("`@("`@(')E='5R;B`D9W)O=7!S.PT*"0EB<F5A:SL-
M"@D@("`@8V%S92`U,#,Z("\O(%)&0S(Y.#`Z("=P<F]G<F%M(&5R<F]R+"!F
M=6YC=&EO;B!N;W0@<&5R9F]R;65D)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%
M<G)O<B@G26YT97)N86P@<V5R=F5R(&5R<F]R+"!F=6YC=&EO;B!N;W0@<&5R
M9F]R;65D)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E<W!O
M;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@9&5F875L=#H-"@D)<F5T=7)N(%!%
M05(Z.G1H<F]W17)R;W(H)U5N:61E;G1I9FEE9"!R97-P;VYS92!C;V1E)RP@
M)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E<W!O;G-E*"DI.PT*
M"7T-"@T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\J*@T*("`@("`J($9E
M=&-H97,@82!L:7-T(&]F("AA;&PI(&%V86EB;&4@;F5W<V=R;W5P(&1E<V-R
M:7!T:6]N<RX-"B`@("`@*B!$97!R97-A=&5D(&%S(&]F(%)&0S(Y.#`N#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:6QD;6%T(%=I;&1M870@
M;V8@=&AE(&=R;W5P<RP@=&AA="!I<R!T;R!B92!L:7-T960L(&1E9F%U;'1S
M('1O("<J)SL-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&%R<F%Y
M*2!N97-T960@87)R87D@=VET:"!D97-C<FEP=&EO;B!O9B!E>&ES=&EN9R!N
M97=S9W)O=7!S(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O
M;B!F86EL=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!C;6181U1I=&QE*"1W:6QD;6%T(#T@)RHG*0T*("`@('L-
M"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD0V]M;6%N9"@G6$=4
M251,12`G+B1W:6QD;6%T*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E<W!O;G-E*2E[#0H@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PT*
M("`@("`@("!]#0H-"@ES=VET8V@@*"1R97-P;VYS92D@>PT*"2`@("!C87-E
M(#(X,CH@+R\@4D9#,CDX,#H@)VQI<W0@;V8@9W)O=7!S(&%N9"!D97-C<FEP
M=&EO;G,@9F]L;&]W<R<-"@D))&1A=&$@/2`D=&AI<RT^7V=E=%1E>'1297-P
M;VYS92@I.PT*"2`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&1A=&$I*2![
M#0H)("`@("`@("`@("`@<F5T=7)N("1D871A.PT*"2`@("`@("`@?0T*#0H)
M("`@("`@("!F;W)E86-H*"1D871A(&%S("1L:6YE*2![#0H)("`@("`@("`@
M("`@<')E9U]M871C:"@B+UXH+BH_*5QS*"XJ/R0I+R(L('1R:6TH)&QI;F4I
M+"`D;6%T8VAE<RD[#0H)("`@("`@("`@("`@)&=R;W5P<ULD;6%T8VAE<ULQ
M75T@/2`H<W1R:6YG*2`D;6%T8VAE<ULR73L-"@D@("`@("`@('T-"@T*"2`@
M("`@("`@<F5T=7)N("1G<F]U<',[#0H)"6)R96%K.PT*"0D@(`T*"2`@("!C
M87-E(#0X,3H@+R\@4D9#,CDX,#H@)T=R;W5P<R!A;F0@9&5S8W)I<'1I;VYS
M('5N879A:6QA8FQE)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G1W)O
M=7!S(&%N9"!D97-C<FEP=&EO;G,@=6YA=F%I;&%B;&4G+"`D<F5S<&]N<V4L
M("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)"6)R96%K.PT*
M"2`@("!D969A=6QT.@T*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G56YI
M9&5N=&EF:65D(')E<W!O;G-E(&-O9&4G+"`D<F5S<&]N<V4L("1T:&ES+3YC
M=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)?0T*#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&-M9$YE=V=R;W5P<R@I#0H-"B`@("`O*BH-
M"B`@("`@*B!&971C:&5S(&$@;&ES="!O9B!A;&P@;F5W<V=R;W5P<R!C<F5A
M=&5D('-I;F-E(&$@<W!E8VEF:65D(&1A=&4N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@:6YT("1T:6UE($QA<W0@=&EM92!Y;W4@8VAE8VME9"!F;W(@9W)O
M=7!S("AT:6UE<W1A;7`I+@T*("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE
M9"`H87)R87DI(&YE<W1E9"!A<G)A>2!W:71H(&EN9F]R;6%T:6]N<R!A8F]U
M="!E>&ES=&EN9R!N97=S9W)O=7!S(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@
M<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;61.97=G<F]U<',H)'1I;64I#0H@
M("`@>PT*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7W-E;F1#;VUM86YD
M*"=.15='4D]54%,@)RYD871E*"=Y;60@2&ES)RP@)'1I;64I*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E<W!O;G-E*2E[#0H@("`@("`@("`@
M("!R971U<FX@)')E<W!O;G-E.PT*("`@("`@("!]#0H-"@ES=VET8V@@*"1R
M97-P;VYS92D@>PT*"2`@("!C87-E(#(S,3H@+R\@4D5&.3<W.B`G;&ES="!O
M9B!N97<@;F5W<V=R;W5P<R!F;VQL;W=S)PT*"0DD9W)O=7!S(#T@87)R87DH
M*3L-"@D@("`@("`@(&9O<F5A8V@H)'1H:7,M/E]G971497AT4F5S<&]N<V4H
M*2!A<R`D;&EN92D@>PT*"0D@("`@)&%R<B`](&5X<&QO9&4H)R`G+"`D;&EN
M92D[#0H)"2`@("`D9W)O=7!S6R1A<G);,%U=6R=G<F]U<"==(#T@)&%R<ELP
M73L-"@D)("`@("1G<F]U<'-;)&%R<ELP75U;)VQA<W0G72`]("1A<G);,5T[
M#0H)"2`@("`D9W)O=7!S6R1A<G);,%U=6R=F:7)S="==(#T@)&%R<ELR73L-
M"@D)("`@("1G<F]U<'-;)&%R<ELP75U;)W!O<W1I;F<G72`]("1A<G);,UT[
M#0H)"7T-"@D)<F5T=7)N("1G<F]U<',[#0H)"6)R96%K.PT*"2`@("!D969A
M=6QT.@T*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G56YI9&5N=&EF:65D
M(')E<W!O;G-E(&-O9&4G+"`D<F5S<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A
M='5S4F5S<&]N<V4H*2D[#0H)?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!C;61,:7-T3W9E<G9I97=&;70H*0T*#0H@("`@+RHJ#0H@("`@
M("H@4F5T=7)N<R!A(&QI<W0@;V8@879A:6)L92!H96%D97)S('=H:6-H(&%R
M92!S96YD(&9R;VT@;F5W<W-E<G9E<B!T;R!C;&EE;G0@9F]R(&5V97)Y(&YE
M=W,@;65S<V%G90T*("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE9"`H87)R
M87DI(&]F(&AE861E<B!N86UE<R!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E
M87)?97)R;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@8VUD3&ES=$]V97)V:65W1FUT*"D-"B`@
M("![#0H))')E<W!O;G-E(#T@)'1H:7,M/E]S96YD0V]M;6%N9"@G3$E35"!/
M5D525DE%5RY&350G*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E
M<W!O;G-E*2E[#0H@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PT*("`@
M("`@("!]#0H-"@ES=VET8V@@*"1R97-P;VYS92D@>PT*"2`@("!C87-E(#(Q
M-3H@+R\@4D9#,CDX,#H@)VEN9F]R;6%T:6]N(&9O;&QO=W,G#0H)"21D871A
M(#T@)'1H:7,M/E]G971497AT4F5S<&]N<V4H*3L-"@D@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1D871A*2D@>PT*"2`@("`@("`@("`@(')E='5R;B`D
M9&%T83L-"@D@("`@("`@('T-"@T*"2`@("`@("`@)&9O<FUA="`](&%R<F%Y
M*"=N=6UB97(G*3L-"@D@("`@("`@("\O(%A86"!5<V4@=&AE('-P;&ET2&5A
M9&5R<R@I(&%L9V]R:71H;2!F;W(@<W5P<&]R=&EN9PT*"2`@("`@("`@+R\@
M("`@(&UU;'1I;&EN92!H96%D97)S/PT*"2`@("`@("`@9F]R96%C:"`H)&1A
M=&$@87,@)&QI;F4I('L-"@D@("`@("`@("`@("`D;&EN92`](&-U<G)E;G0H
M97AP;&]D92@G.B<L('1R:6TH)&QI;F4I*2D[#0H)("`@("`@("`@("`@)&9O
M<FUA=%M=(#T@)&QI;F4[#0H)("`@("`@("!]#0H)("`@("`@("!R971U<FX@
M)&9O<FUA=#L-"@D)8G)E86L[#0H)("`@(&-A<V4@-3`S.B`O+R!21D,R.3@P
M.B`G<')O9W)A;2!E<G)O<BP@9G5N8W1I;VX@;F]T('!E<F9O<FUE9"<-"@D)
M<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)TEN=&5R;F%L('-E<G9E<B!E<G)O
M<BP@9G5N8W1I;VX@;F]T('!E<F9O<FUE9"<L("1R97-P;VYS92P@)'1H:7,M
M/F-U<G)E;G13=&%T=7-297-P;VYS92@I*3L-"@D)8G)E86L[#0H)("`@(&1E
M9F%U;'0Z#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=5;FED96YT:69I
M960@<F5S<&]N<V4@8V]D92<L("1R97-P;VYS92P@)'1H:7,M/F-U<G)E;G13
M=&%T=7-297-P;VYS92@I*3L-"@E]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&-M9%A/=F5R*"D-"@T*("`@("\J*@T*("`@("`J($9E=&-H
M(&UE<W-A9V4@:&5A9&5R(&9R;VT@;65S<V%G92!N=6UB97(@)&9I<G-T('5N
M=&EL("1L87-T#0H@("`@("H-"B`@("`@*B!4:&4@9F]R;6%T(&]F('1H92!R
M971U<FYE9"!A<G)A>2!I<SH-"B`@("`@*B`D;65S<V%G97-;;65S<V%G95]I
M9%U;:&5A9&5R7VYA;65=#0H@("`@("H-"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9FER<W0@9FER<W0@87)T:6-L92!T;R!F971C:`T*("`@("`J($!P87)A
M;2!I;G1E9V5R("1L87-T("!L87-T(&%R=&EC;&4@=&\@9F5T8V@-"B`@("`@
M*@T*("`@("`J($!R971U<FX@;6EX960@*&%R<F%Y*2!N97-T960@87)R87D@
M;V8@;65S<V%G92!A;F0@=&AE<F4@:&5A9&5R<R!O;B!S=6-C97-S(&]R("AO
M8FIE8W0I('!E87)?97)R;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VUD6$]V97(H)&9I<G-T
M+"`D;&%S="D-"B`@("![#0H@("`@("`@("1F;W)M870@/2`D=&AI<RT^8VUD
M3&ES=$]V97)V:65W1FUT*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1F;W)M870I*7L-"B`@("`@("`@("`@(')E='5R;B`D9F]R;70[#0H@("`@
M("`@('T-"@T*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7W-E;F1#;VUM
M86YD*"=83U9%4B`G+B1F:7)S="XG+2<N)&QA<W0I.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5S<&]N<V4I*7L-"B`@("`@("`@("`@(')E='5R
M;B`D<F5S<&]N<V4[#0H@("`@("`@('T-"@T*"7-W:71C:"`H)')E<W!O;G-E
M*2![#0H)("`@(&-A<V4@,C(T.B`O+R!21D,R.3@P.B`G3W9E<G9I97<@:6YF
M;W)M871I;VX@9F]L;&]W<R<-"@D))&1A=&$@/2`D=&AI<RT^7V=E=%1E>'12
M97-P;VYS92@I.PT*"2`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&1A=&$I
M*2![#0H)("`@("`@("`@("`@<F5T=7)N("1D871A.PT*"2`@("`@("`@?0T*
M"0DD;65S<V%G97,@/2!A<G)A>2@I.PT*"2`@("`@("`@9F]R96%C:"@D9&%T
M82!A<R`D;&EN92D@>PT*"2`@("`@("`@("`@("1I/3`[#0H)("`@("`@("`@
M("`@9F]R96%C:"AE>'!L;V1E*")<="(L('1R:6TH)&QI;F4I*2!A<R`D;&EN
M92D@>PT*"2`@("`@("`@("`@("`@("`D;65S<V%G95LD9F]R;6%T6R1I*RM=
M72`]("1L:6YE.PT*"2`@("`@("`@("`@('T-"@D@("`@("`@("`@("`D;65S
M<V%G97-;)&UE<W-A9V5;)TUE<W-A9V4M240G75T@/2`D;65S<V%G93L-"@D@
M("`@("`@('T-"B`@("`@("`@"7)E='5R;B`D;65S<V%G97,[#0H)"6)R96%K
M.PT*"2`@("!C87-E(#0Q,CH@+R\@4D9#,CDX,#H@)TYO(&YE=W,@9W)O=7`@
M8W5R<F5N="!S96QE8W1E9"<-"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H
M)TYO(&YE=W,@9W)O=7`@8W5R<F5N="!S96QE8W1E9"<L("1R97-P;VYS92P@
M)'1H:7,M/F-U<G)E;G13=&%T=7-297-P;VYS92@I*3L-"@D)8G)E86L[#0H)
M("`@(&-A<V4@-#(P.B`O+R!21D,R.3@P.B`G3F\@87)T:6-L92AS*2!S96QE
M8W1E9"<-"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)TYO(&%R=&EC;&4H
M<RD@<V5L96-T960G+"`D<F5S<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A='5S
M4F5S<&]N<V4H*2D[#0H)"6)R96%K.PT*"2`@("!C87-E(#4P,CH@+R\@4D9#
M,CDX,#H@)VYO('!E<FUI<W-I;VXG#0H)"7)E='5R;B!014%2.CIT:')O=T5R
M<F]R*"=.;R!P97)M:7-S:6]N)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N
M=%-T871U<U)E<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@9&5F875L=#H-
M"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)U5N:61E;G1I9FEE9"!R97-P
M;VYS92!C;V1E)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R<F5N=%-T871U<U)E
M<W!O;G-E*"DI.PT*"7T-"B`@("!]#0H@("`@#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&-M9%A23W9E<B@I#0H-"B`@("`O*BH-"B`@("`@*B!&971C:"!M
M97-S86=E(')E9F5R96YC97,@9G)O;2!M97-S86=E(&YU;6)E<B`D9FER<W0@
M=&\@)&QA<W0-"B`@("`@*@T*("`@("`J($!P87)A;2!I;G1E9V5R("1F:7)S
M="!F:7)S="!A<G1I8VQE('1O(&9E=&-H#0H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&QA<W0@(&QA<W0@87)T:6-L92!T;R!F971C:`T*("`@("`J#0H@("`@
M("H@0')E='5R;B!M:7AE9"`H87)R87DI(&%S<V]C+B!A<G)A>2!O9B!M97-S
M86=E(')E9F5R96YC97,@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R
M<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&-M9%A23W9E<B@D9FER<W0L("1L87-T*0T*("`@
M('L-"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD0V]M;6%N9"@G
M6%)/5D52("<N)&9I<G-T+B<M)RXD;&%S="D[#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R97-P;VYS92DI>PT*("`@("`@("`@("`@<F5T=7)N("1R
M97-P;VYS93L-"B`@("`@("`@?0T*#0H)<W=I=&-H("@D<F5S<&]N<V4I('L-
M"@D@("`@8V%S92`R,C0Z("\O(%)&0S(Y.#`Z("=/=F5R=FEE=R!I;F9O<FUA
M=&EO;B!F;VQL;W=S)PT*"0DD9&%T82`]("1T:&ES+3Y?9V5T5&5X=%)E<W!O
M;G-E*"D[#0H)("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9&%T82DI('L-
M"@D@("`@("`@("`@("!R971U<FX@)&1A=&$[#0H)("`@("`@("!]#0H-"@D@
M("`@("`@(&9O<F5A8V@H)&1A=&$@87,@)&QI;F4I('L-"@T*"2`@("`@("`@
M("`@("1R969E<F5N8V5S(#T@<')E9U]S<&QI="@B+R`K+R(L('1R:6TH)&QI
M;F4I+"`M,2P@4%)%1U]34$Q)5%].3U]%35!462D[#0H-"@D@("`@("`@("`@
M("`D:60@/2!A<G)A>5]S:&EF="@D<F5F97)E;F-E<RD[#0H-"@D@("`@("`@
M("`@("`D;65S<V%G97-;)&ED72`]("1R969E<F5N8V5S.PT*"2`@("`@("`@
M?0T*("`@("`@("`)<F5T=7)N("1M97-S86=E<SL-"@D)8G)E86L[#0H)("`@
M(&-A<V4@-#$R.B`O+R!21D,R.3@P.B`G3F\@;F5W<R!G<F]U<"!C=7)R96YT
M('-E;&5C=&5D)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G3F\@;F5W
M<R!G<F]U<"!C=7)R96YT('-E;&5C=&5D)RP@)')E<W!O;G-E+"`D=&AI<RT^
M8W5R<F5N=%-T871U<U)E<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@("`@8V%S
M92`T,C`Z("\O(%)&0S(Y.#`Z("=.;R!A<G1I8VQE*',I('-E;&5C=&5D)PT*
M"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G3F\@87)T:6-L92AS*2!S96QE
M8W1E9"<L("1R97-P;VYS92P@)'1H:7,M/F-U<G)E;G13=&%T=7-297-P;VYS
M92@I*3L-"@D)8G)E86L[#0H)("`@(&-A<V4@-3`R.B`O+R!21D,R.3@P.B`G
M;F\@<&5R;6ES<VEO;B<-"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)TYO
M('!E<FUI<W-I;VXG+"`D<F5S<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A='5S
M4F5S<&]N<V4H*2D[#0H)"6)R96%K.PT*"2`@("!D969A=6QT.@T*"0ER971U
M<FX@4$5!4CHZ=&AR;W=%<G)O<B@G56YI9&5N=&EF:65D(')E<W!O;G-E(&-O
M9&4G+"`D<F5S<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H
M*2D[#0H)?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C;61,
M:7-T9W)O=7`H*0T*#0H@("`@+RHJ#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N97=S9W)O=7`@#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("AA<G)A>2D@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R
M(&]N(&9A:6QU<F4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;61,:7-T9W)O
M=7`H)&YE=W-G<F]U<"D-"B`@("![#0H@("`@("`@("1R97-P;VYS92`]("1T
M:&ES+3Y?<V5N9$-O;6UA;F0H)TQ)4U1'4D]54"`G+B1N97=S9W)O=7`I.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S<&]N<V4I*7L-"B`@("`@
M("`@("`@(')E='5R;B`D<F5S<&]N<V4[#0H@("`@("`@('T-"@T*"7-W:71C
M:"`H)')E<W!O;G-E*2![#0H)("`@(&-A<V4@,C$Q.B`O+R!21D,R.3@P.B`G
M;&ES="!O9B!A<G1I8VQE(&YU;6)E<G,@9F]L;&]W)PT*"0DD9&%T82`]("1T
M:&ES+3Y?9V5T5&5X=%)E<W!O;G-E*"D[#0H)("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D9&%T82DI('L-"@D@("`@("`@("`@("!R971U<FX@)&1A=&$[
M#0H)("`@("`@("!]#0H)("`@("`@("!R971U<FX@)&1A=&$[#0H)"6)R96%K
M.PT*"2`@("!C87-E(#0Q,CH@+R\@4D9#,CDX,#H@)TYO="!C=7)R96YT;'D@
M:6X@;F5W<V=R;W5P)PT*"0ER971U<FX@4$5!4CHZ=&AR;W=%<G)O<B@G3F]T
M(&-U<G)E;G1L>2!I;B!N97=S9W)O=7`G+"`D<F5S<&]N<V4L("1T:&ES+3YC
M=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)"6)R96%K.PT*"2`@("!C87-E
M(#4P,CH@+R\@4D9#,CDX,#H@)VYO('!E<FUI<W-I;VXG#0H)"7)E='5R;B!0
M14%2.CIT:')O=T5R<F]R*"=.;R!P97)M:7-S:6]N)RP@)')E<W!O;G-E+"`D
M=&AI<RT^8W5R<F5N=%-T871U<U)E<W!O;G-E*"DI.PT*"0EB<F5A:SL-"@D@
M("`@9&5F875L=#H-"@D)<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)U5N:61E
M;G1I9FEE9"!R97-P;VYS92!C;V1E)RP@)')E<W!O;G-E+"`D=&AI<RT^8W5R
M<F5N=%-T871U<U)E<W!O;G-E*"DI.PT*"7T-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@8VUD3F5W;F5W<R@I#0H-"B`@("`O*BH-"B`@("`@
M*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-M9$YE=VYE=W,H)'1I;64L("1N
M97=S9W)O=7!S(#T@)RHG*0T*("`@('L-"@DO+R!43T1/.B!T:&4@;&5N9VAT
M(&]F('1H92!R97%U97-T('-T<FEN9R!M87D@;F]T(&5X8V5E9"`U,3`@8VAA
M<G,-"@D-"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD0V]M;6%N
M9"@G3D573D574R`G+B1N97=S9W)O=7!S+B<@)RYD871E*"=Y;60@2&ES)RP@
M)'1I;64I*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W!O;G-E
M*2E[#0H@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PT*("`@("`@("!]
M#0H-"@ES=VET8V@@*"1R97-P;VYS92D@>PT*"2`@("!C87-E(#(S,#H@+R\@
M4D9#.3<W.B`G;&ES="!O9B!N97<@87)T:6-L97,@8GD@;65S<V%G92UI9"!F
M;VQL;W=S)PT*"0DD;65S<V%G97,@/2!A<G)A>2@I.PT*("`@("`@("`)9F]R
M96%C:"@D=&AI<RT^7V=E=%1E>'1297-P;VYS92@I(&%S("1L:6YE*2![#0H)
M"2`@("`D;65S<V%G97-;72`]("1L:6YE.PT*"0E]#0H)"7)E='5R;B`D;65S
M<V%G97,[#0H)"6)R96%K.PT*"2`@("!D969A=6QT.@T*"0ER971U<FX@4$5!
M4CHZ=&AR;W=%<G)O<B@G56YI9&5N=&EF:65D(')E<W!O;G-E(&-O9&4G+"`D
M<F5S<&]N<V4L("1T:&ES+3YC=7)R96YT4W1A='5S4F5S<&]N<V4H*2D[#0H)
M?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C;61$871E*"D-
M"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@9&%T92!F<F]M('1H92!N97=S
M<V5R=F5R(&9O<FUA="!O9B!R971U<FYE9"!D871E#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@8F]O;"`D=&EM97-T87`@=VAE;B!F86QS92!F=6YC=&EO;B!R
M971U<FYS('-T<FEN9RP@86YD('=H96X@=')U92!F=6YC=&EO;B!R971U<FYS
M(&EN="]T:6UE<W1A;7`N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("AS=')I;F<I("=965E934U$1&AH;6US<R<@+R`H:6YT*2!T:6UE<W1A;7`@
M;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-
M"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&-M9$1A=&4H)'1I;65S=&%M<"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD0V]M;6%N9"@G1$%412<I.PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S<&]N<V4I*7L-"B`@("`@("`@
M("`@(')E='5R;B`D<F5S<&]N<V4[#0H@("`@("`@('T-"@T*"7-W:71C:"`H
M)')E<W!O;G-E*2![#0H)("`@(&-A<V4@,3$Q.B`O+R!21D,R.3@P.B`G65E9
M64U-1$1H:&UM<W,G#0H@("`@("`@("`@("`@("`@)&0@/2`D=&AI<RT^8W5R
M<F5N=%-T871U<U)E<W!O;G-E*"D[#0H)"6EF("@D=&EM97-T86UP(#T]/2!F
M86QS92D@>PT*"0D@("`@<F5T=7)N("AS=')I;F<I("1D.PD@("`@#0H)"7T@
M96QS92![#0H)("`@(`D@("`@<F5T=7)N("AI;G0I('-T<G1O=&EM92AS=6)S
M='(H)&0L(#`L(#@I+B<@)RXD9%LX72XD9%LY72XG.B<N)&1;,3!=+B1D6S$Q
M72XG.B<N)&1;,3)=+B1D6S$S72D[#0H)"7T-"@D)8G)E86L[#0H)("`@(&1E
M9F%U;'0Z#0H)"7)E='5R;B!014%2.CIT:')O=T5R<F]R*"=5;FED96YT:69I
M960@<F5S<&]N<V4@8V]D92<L("1R97-P;VYS92P@)'1H:7,M/F-U<G)E;G13
M=&%T=7-297-P;VYS92@I*3L-"@E]#0H@("`@?0T*("`@("\O('U]?0T*("`@
M("\O('M[>R!I<T-O;FYE8W1E9"@I#0H-"B`@("`O*BH-"B`@("`@*B!497-T
M('=H971H97(@=V4@87)E(&-O;FYE8W1E9"!O<B!N;W0N#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&)O;VP@=')U92!O<B!F86QS90T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T-O
M;FYE8W1E9"@I#0H@("`@>PT*"7)E='5R;B`H:7-?<F5S;W5R8V4H)'1H:7,M
M/E]S;V-K970M/F9P*2`F)B`A9F5O9B@D=&AI<RT^7W-O8VME="T^9G`I*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<V5T1&5B=6<H*0T*
M#0H@("`@+RHJ#0H@("`@("H@4V5T<R!T:&4@9&5B=6=I;F<@:6YF;W)M871I
M;VX@;VX@;W(@;V9F#0H@("`@("H-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!4
M<G5E(&]R(&9A;'-E(`T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L('!R
M979I;W,@<W1A=&4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-E=$1E8G5G*"1D96)U9R`]('1R=64I#0H@("`@>PT*
M("`@("`@("`D=&UP(#T@)'1H:7,M/E]D96)U9SL-"B`@("`@("`@)'1H:7,M
M/E]D96)U9R`]("1D96)U9SL-"B`@("`@("`@<F5T=7)N("1T;7`[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]G9713=&%T=7-297-P;VYS
M92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@<V5R=F5R<R!S=&%T=7-R97-P
M;VYS92!A9G1E<B!A(&-O;6UA;F0N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("AI;G0I('-T871U<V-O9&4@;VX@<W5C8V5S<R!O<B`H;V)J96-T
M*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T4W1A='5S4F5S<&]N<V4H
M*0T*("`@('L-"@DO+R!2971R:65V92!A(&QI;F4@*'1E<FUI;F%T960@8GD@
M(EQR7&XB*2!F<F]M('1H92!S97)V97(N#0H))')E<W!O;G-E(#T@)'1H:7,M
M/E]S;V-K970M/F=E=',H,C4V*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)')E<W!O;G-E*2`I('L-"B`@("`)("`@(')E='5R;B!014%2.CIT:')O
M=T5R<F]R*"=&86EL960@=&\@<F5A9"!F<F]M('-O8VME="$G+"!N=6QL+"`D
M<F5S<&]N<V4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@('T-"@T*("`@("`@
M("!I9B`H)'1H:7,M/E]D96)U9RD@>PT*("`@("`@("`@("`@96-H;R`B4SH@
M)')E<W!O;G-E7')<;B([#0H@("`@("`@('T-"@T*"2\O(%1R:6T@=&AE('-T
M87)T(&]F('1H92!R97-P;VYS92!I;B!C87-E(&]F(&UI<W!L87-E9"!W:&ET
M97-P86-E("AS:&]U;&0@;F]T(&)E(&YE961E;B$A(2D-"@DD<F5S<&]N<V4@
M/2!L=')I;2@D<F5S<&]N<V4I.PT*#0H@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=%-T871U<U)E<W!O;G-E(#T@87)R87DH#0H)"0D)"2`@("`@("AI;G0I('-U
M8G-T<B@D<F5S<&]N<V4L(#`L(#,I+`T*"2`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*'-T<FEN9RD@<G1R:6TH<W5B<W1R*"1R97-P
M;VYS92P@-"DI#0H)"0D)"2`@("`@*3L-"@T*"7)E='5R;B`D=&AI<RT^7V-U
M<G)E;G13=&%T=7-297-P;VYS95LP73L-"B`@("!]#0H@("`@#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&-U<G)E;G13=&%T=7-297-P;VYS92@I#0H-"B`@
M("`O*BH-"B`@("`@*@T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@
M<W1A='5S('1E>'0-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!C=7)R96YT4W1A='5S4F5S<&]N<V4H*0T*("`@('L-
M"@ER971U<FX@)'1H:7,M/E]C=7)R96YT4W1A='5S4F5S<&]N<V5;,5T[#0H@
M("`@?0T*("`@(`T*("`@("\O('U]?0T*("`@("\O('M[>R!?9V5T5&5X=%)E
M<W!O;G-E*"D-"@T*("`@("\J*@T*("`@("`J($=E="!D871A('5N=&EL(&$@
M;&EN92!W:71H(&]N;'D@82`G+B<@:6X@:70@:7,@<F5A9"!A;F0@<F5T=7)N
M(&1A=&$N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A>2D@
M=&5X="!R97-P;VYS92!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E87)?97)R
M;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]G971497AT4F5S<&]N<V4H*0T*("`@('L-"B`@
M("`@("`@)&1A=&$@/2!A<G)A>2@I.PT*("`@("`@("`D;&EN92`]("<G.PT*
M"0T*("`@("`@("`O+R!#;VYT:6YU92!U;G1I;"!C;VYN96-T:6]N(&ES(&QO
M<W0-"B`@("`@("`@=VAI;&4H(21T:&ES+3Y?<V]C:V5T+3YE;V8H*2D@>PT*
M#0H@("`@("`@("`@("`O+R!2971R:65V92!A;F0@87!P96YD('5P('1O(#$P
M,C0@8VAA<F%C=&5R<R!F<F]M('1H92!S97)V97(N#0H@("`@("`@("`@("`D
M;&EN92`N/2`D=&AI<RT^7W-O8VME="T^9V5T<R@Q,#(T*3L@#0H@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;&EN92D@*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H("=&86EL960@=&\@<F5A
M9"!F<F]M('-O8VME="$G+"!N=6QL+"`D;&EN92T^9V5T365S<V%G92@I*3L-
M"B`@("`)("`@('T-"@D@("`@#0H@("`@("`@("`@("`O+R!#;VYT:6YU92!I
M9B!T:&4@;&EN92!I<R!N;W0@=&5R;6EN871E9"!B>2!#4DQ&#0H@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1L:6YE+"`M,BD@(3T@(EQR7&XB('Q\('-T<FQE
M;B@D;&EN92D@/"`R*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("\O(%9A;&ED871E(')E8VEE
M=F5D(&QI;F4-"B`@("`@("`@("`@(&EF("AF86QS92D@>PT*("`@("`@("`@
M("`@("`@("\O($QI;F5S('-H;W5L9"]M87D@;F]T(&)E(&QO;F=E<B!T:&%N
M(#DY."LR(&-H87)S("A21D,R.#(R(#(N,RD-"B`@("`@("`@("`@("`@("!I
M9B`H<W1R;&5N*"1L:6YE*2`^(#$P,#`I('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G1H<F]W17)R;W(H)TEN=F%L:60@;&EN92!R96-I
M979E9"$G+"!N=6QL*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@("\O(%)E;6]V92!#4DQ&(&9R;VT@=&AE(&5N
M9"!O9B!T:&4@;&EN90T*("`@("`@("`@("`@)&QI;F4@/2!S=6)S='(H)&QI
M;F4L(#`L("TR*3L-"@T*("`@("`@("`@("`@+R\@0VAE8VL@:68@=&AE(&QI
M;F4@=&5R;6EN871E<R!T:&4@=&5X=')E<W!O;G-E#0H@("`@("`@("`@("!I
M9B`H)&QI;F4@/3T@)RXG*2![#0H@("`@("`@("`@("`@("`@+R\@<F5T=7)N
M(&%L;"!P<F5V:6]U<R!L:6YE<PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M9&%T83L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@+R\@268@,7-T(&-H87(@:7,@)RXG(&ET)W,@9&]U
M8FQE9"`H3DY44"]21D,Y-S<@,BXT+C$I#0H@("`@("`@("`@("!I9B`H<W5B
M<W1R*"1L:6YE+"`P+"`R*2`]/2`G+BXG*2![#0H@("`@("`@("`@("`@("`@
M)&QI;F4@/2!S=6)S='(H)&QI;F4L(#$I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@#0H@("`@("`@("`@("`O+R!!9&0@=&AE(&QI;F4@=&\@=&AE
M(&%R<F%Y(&]F(&QI;F5S#0H@("`@("`@("`@("`D9&%T85M=(#T@)&QI;F4[
M#0H-"B`@("`@("`@("`@("\O(%)E<V5T+V5M<'1Y("1L:6YE#0H@("`@("`@
M("`@("`D;&EN92`]("<G.PT*("`@("`@("!]#0H-"B`@("`)<F5T=7)N(%!%
M05(Z.G1H<F]W17)R;W(H)T1A=&$@<W1R96%M(&YO="!T97)M:6YA=&5D('=I
M=&@@<&5R:6]D)RP@;G5L;"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(%]S96YD0V]M;6%N9"@I#0H-"B`@("`O*BH-"B`@("`@*B!396YD
M(&$@8V]M;6%N9"!T;R!T:&4@<V5R=F5R+B!!(&-A<G)I86=E(')E='5R;B`O
M(&QI;F5F965D("A#4DQ&*2!S97%U96YC90T*("`@("`J('=I;&P@8F4@87!P
M96YD960@=&\@96%C:"!C;VUM86YD('-T<FEN9R!B969O<F4@:70@:7,@<V5N
M="!T;R!T:&4@24U!4"!S97)V97(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;60@5&AE(&-O;6UA;F0@=&\@;&%U;F-H+"!I93H@(D%25$E#
M3$4@,3`P-#@U,R(-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&EN
M="D@<F5S<&]N<V4@8V]D92!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E87)?
M97)R;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]S96YD0V]M;6%N9"@D8VUD*0T*("`@('L-
M"B`@("`@("`@+R\@3DY44"]21D,Y-S<@;VYL>2!A;&QO=W,@8V]M;6%N9"!U
M<"!T;R`U,3(@*"TR*2!C:&%R<RX-"B`@("`@("`@:68@*"%S=')L96XH)&-M
M9"D@/B`U,3`I('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIT:')O=T5R
M<F]R*"=&86EL960@=&\@=W)I=&4@=&\@<V]C:V5T(2`H0V]M;6%N9"!T;R!L
M;VYG("T@;6%X(#4Q,"!C:&%R<RDG*3L-"B`@("`@("`@?0T*#0H@("`@("`@
M("\O($-H96-K(&EF(&-O;FYE8W1E9`T*"6EF("@A)'1H:7,M/FES0V]N;F5C
M=&5D*"DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIT:')O=T5R<F]R
M*"=&86EL960@=&\@=W)I=&4@=&\@<V]C:V5T(2`H8V]N;F5C=&EO;B!L;W-T
M(2DG*3L-"B`@("`@("`@?0T*#0H)+R\@4V5N9"!T:&4@8V]M;6%N9`T*"212
M(#T@)'1H:7,M/E]S;V-K970M/G=R:71E3&EN92@D8VUD*3L-"B`@("`@("`@
M:68@*"!014%2.CII<T5R<F]R*"12*2`I('L-"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIT:')O=T5R<F]R*"=&86EL960@=&\@=W)I=&4@=&\@<V]C:V5T
M(2<L(&YU;&PL("12+3YG971-97-S86=E*"DI.PT*("`@("`@("!]#0H)#0H@
M("`@("`@(&EF("@D=&AI<RT^7V1E8G5G*2![#0H@("`@("`@("`@("!E8VAO
M(")#.B`D8VUD7')<;B([#0H@("`@("`@('T-"@T*"7)E='5R;B`D=&AI<RT^
M7V=E=%-T871U<U)E<W!O;G-E*"D[#0H@("`@?0T*("`@(`T*("`@("\O('U]
M?0T*#0I]#0H-"C\^#0H````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+U-O8VME="YP:'``````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`V,3,`,3`T,3<S-C,P
M,#8`,#(P,#,R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#(@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-T:6<@0F%K:V5N(#QS<V)`
M9F%S="YN;SX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"`@("`@("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(%-O8VME="YP:'`L=B`Q+C(@
M,C`P,B\P-"\P,R`R,3HT.3HQ-B!S<V(@17AP("0*+R\*"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PH*+RHJ"B`J($=E;F5R86QI>F5D(%-O8VME="!C;&%S
M<RX@36]R92!D;V-S('1O(&)E('=R:71T96XN"B`J"B`J($!V97)S:6]N(#$N
M,`H@*B!`875T:&]R(%-T:6<@0F%K:V5N(#QS<V)`9F%S="YN;SX*("H@0&%U
M=&AO<B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("HO"F-L
M87-S($YE=%]3;V-K970@97AT96YD<R!014%2('L*("`@(`H@("`@+R\@>WM[
M('!R;W!E<G1I97,*("`@(`H@("`@+RHJ(%-O8VME="!F:6QE('!O:6YT97(N
M("HO"B`@("!V87(@)&9P(#T@;G5L;#L*("`@(`H@("`@+RHJ(%=H971H97(@
M=&AE('-O8VME="!I<R!B;&]C:VEN9RX@*B\*("`@('9A<B`D8FQO8VMI;F<@
M/2!T<G5E.PH@("`@"B`@("`O*BH@5VAE=&AE<B!T:&4@<V]C:V5T(&ES('!E
M<G-I<W1E;G0N("HO"B`@("!V87(@)'!E<G-I<W1E;G0@/2!F86QS93L*("`@
M(`H@("`@+RHJ(%1H92!)4"!A9&1R97-S('1O(&-O;FYE8W0@=&\N("HO"B`@
M("!V87(@)&%D9'(@/2`G)SL*("`@(`H@("`@+RHJ(%1H92!P;W)T(&YU;6)E
M<B!T;R!C;VYN96-T('1O+B`J+PH@("`@=F%R("1P;W)T(#T@,#L*("`@(`H@
M("`@+RHJ($YU;6)E<B!O9B!S96-O;F1S('1O('=A:70@;VX@<V]C:V5T(&-O
M;FYE8W1I;VYS(&)E9F]R90H@("`@("`@(&%S<W5M:6YG('1H97)E)W,@;F\@
M;6]R92!D871A+B`J+PH@("`@=F%R("1T:6UE;W5T(#T@9F%L<V4["B`@("`*
M("`@("\J*B!.=6UB97(@;V8@8GET97,@=&\@<F5A9"!A="!A('1I;64@:6X@
M<F5A9$QI;F4H*2!A;F0*("`@("`@("!R96%D06QL*"DN("HO"B`@("!V87(@
M)&QI;F5,96YG=&@@/2`R,#0X.PH@("`@+R\@?7U]"B`@("`*("`@("\O('M[
M>R!C;VYS=')U8W1O<@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M($YE=%]3;V-K970@;V)J96-T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($YE=%]3;V-K970H*2!["B`@("`@
M("`@)'1H:7,M/E!%05(H*3L*("`@('T*("`@("\O('U]?0H@("`@"B`@("`O
M+R![>WL@8V]N;F5C="@I"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE
M('-P96-I9FEE9"!P;W)T+B!)9B!C86QL960@=VAE;B!T:&4@<V]C:V5T(&ES
M"B`@("`@*B!A;')E861Y(&-O;FYE8W1E9"P@:70@9&ES8V]N;F5C=',@86YD
M(&-O;FYE8W1S(&%G86EN+@H@("`@("H*("`@("`J($!P87)A;2`D861D<B!S
M=')I;F<@25`@861D<F5S<R!O<B!H;W-T(&YA;64*("`@("`J($!P87)A;2`D
M<&]R="!I;G0@5$-0('!O<G0@;G5M8F5R"B`@("`@*B!`<&%R86T@)'!E<G-I
M<W1E;G0@8F]O;"`H;W!T:6]N86PI('=H971H97(@=&AE(&-O;FYE8W1I;VX@
M:7,*("`@("`J("`@("`@("!P97)S:7-T96YT("AK97!T(&]P96X@8F5T=V5E
M;B!R97%U97-T<R!B>2!T:&4@=V5B('-E<G9E<BD*("`@("`J($!P87)A;2`D
M=&EM96]U="!I;G0@*&]P=&EO;F%L*2!H;W<@;&]N9R!T;R!W86ET(&9O<B!D
M871A"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!M:7AE
M9"!T<G5E(&]N('-U8V-E<W,@;W(@97)R;W(@;V)J96-T"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;FYE8W0H)&%D9'(L("1P;W)T+"`D<&5R<VES=&5N="`]
M(&YU;&PL("1T:6UE;W5T(#T@;G5L;"D@>PH@("`@("`@(&EF("AI<U]R97-O
M=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@($!F8VQO<V4H)'1H:7,M
M/F9P*3L*("`@("`@("`@("`@)'1H:7,M/F9P(#T@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@"B`@("`@("`@:68@*'-T<G-P;B@D861D<BP@)RXP,3(S-#4V
M-S@Y)RD@/3T@<W1R;&5N*"1A9&1R*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M861D<B`]("1A9&1R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3YA9&1R(#T@9V5T:&]S=&)Y;F%M92@D861D<BD["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3YP;W)T(#T@)'!O<G0@)2`V-34S-CL*("`@("`@("!I
M9B`H)'!E<G-I<W1E;G0@(3T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M
M/G!E<G-I<W1E;G0@/2`D<&5R<VES=&5N=#L*("`@("`@("!]"B`@("`@("`@
M:68@*"1T:6UE;W5T("$]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3YT
M:6UE;W5T(#T@)'1I;65O=70["B`@("`@("`@?0H@("`@("`@("1O<&5N9G5N
M8R`]("1T:&ES+3YP97)S:7-T96YT(#\@)W!F<V]C:V]P96XG(#H@)V9S;V-K
M;W!E;B<["B`@("`@("`@)&5R<FYO(#T@,#L*("`@("`@("`D97)R<W1R(#T@
M)R<["B`@("`@("`@:68@*"1T:&ES+3YT:6UE;W5T*2!["B`@("`@("`@("`@
M("1F<"`]("1O<&5N9G5N8R@D=&AI<RT^861D<BP@)'1H:7,M/G!O<G0L("1E
M<G)N;RP@)&5R<G-T<BP@)'1H:7,M/G1I;65O=70I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F<"`]("1O<&5N9G5N8R@D=&AI<RT^861D<BP@
M)'1H:7,M/G!O<G0L("1E<G)N;RP@)&5R<G-T<BD["B`@("`@("`@?0H@("`@
M("`@(`H@("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D97)R<W1R+"`D97)R;F\I.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/F9P(#T@)&9P.PH@("`@("`@(`H@("`@("`@(')E
M='5R;B`D=&AI<RT^<V5T0FQO8VMI;F<H)'1H:7,M/F)L;V-K:6YG*3L*("`@
M('T*("`@("\O('U]?0H@("`@"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"B`@
M("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE('!E97(L(&-L;W-E
M<R!T:&4@<V]C:V5T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S<R!O<B!A;B!E<G)O
M<B!O8FIE8W0@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O
M;FYE8W0H*2!["B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI
M('L*("`@("`@("`@("`@9F-L;W-E*"1T:&ES+3YF<"D["B`@("`@("`@("`@
M("1T:&ES+3YF<"`](&YU;&P["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO
M="!C;VYN96-T960B*3L*("`@('T*("`@("\O('U]?0H@("`@"B`@("`O+R![
M>WL@:7-";&]C:VEN9R@I"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF('1H
M92!S;V-K970@:7,@:6X@8FQO8VMI;F<@;6]D92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L('1H92!C=7)R96YT
M(&)L;V-K:6YG(&UO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES0FQO8VMI
M;F<H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3YB;&]C:VEN9SL*("`@('T*
M("`@("\O('U]?0H@("`@"B`@("`O+R![>WL@<V5T0FQO8VMI;F<H*0H@("`@
M+RHJ"B`@("`@*B!3971S('=H971H97(@=&AE('-O8VME="!C;VYN96-T:6]N
M('-H;W5L9"!B92!B;&]C:VEN9R!O<@H@("`@("H@;F]T+B!!(')E860@8V%L
M;"!T;R!A(&YO;BUB;&]C:VEN9R!S;V-K970@=VEL;"!R971U<FX@:6UM961I
M871E;'D*("`@("`J(&EF('1H97)E(&ES(&YO(&1A=&$@879A:6QA8FQE+"!W
M:&5R96%S(&ET('=I;&P@8FQO8VL@=6YT:6P@=&AE<F4*("`@("`J(&ES(&1A
M=&$@9F]R(&)L;V-K:6YG('-O8VME=',N"B`@("`@*@H@("`@("H@0'!A<F%M
M("1M;V1E(&)O;VP@=')U92!F;W(@8FQO8VMI;F<@<V]C:V5T<RP@9F%L<V4@
M9F]R(&YO;F)L;V-K:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0')E='5R;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@;W(@86X@97)R;W(@;V)J
M96-T(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO;B!S971";&]C:VEN
M9R@D;6]D92D@>PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^9G`I
M*2!["B`@("`@("`@("`@("1T:&ES+3YB;&]C:VEN9R`]("1M;V1E.PH@("`@
M("`@("`@("!S;V-K971?<V5T7V)L;V-K:6YG*"1T:&ES+3YF<"P@)'1H:7,M
M/F)L;V-K:6YG*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B;F]T(&-O;FYE
M8W1E9"(I.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E=%1I;65O
M=70H*0H@("`@+RHJ"B`@("`@*B!3971S('1H92!T:6UE;W5T('9A;'5E(&]N
M('-O8VME="!D97-C<FEP=&]R+"`*("`@("`J(&5X<')E<W-E9"!I;B!T:&4@
M<W5M(&]F('-E8V]N9',@86YD(&UI8W)O<V5C;VYD<PH@("`@("H*("`@("`J
M($!P87)A;2`D<V5C;VYD<R!I;G0@<V5C;VYD<PH@("`@("H@0'!A<F%M("1M
M:6-R;W-E8V]N9',@:6YT(&UI8W)O<V5C;VYD<PH@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!R971U<FX@;6EX960@=')U92!O;B!S=6-C97-S(&]R
M(&%N(&5R<F]R(&]B:F5C="!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T5&EM96]U="@D<V5C;VYD<RP@)&UI8W)O<V5C;VYD<RD@>PH@("`@
M("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@
M('-O8VME=%]S971?=&EM96]U="@D=&AI<RT^9G`L("1S96-O;F1S+"`D;6EC
M<F]S96-O;F1S*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B;F]T(&-O;FYE
M8W1E9"(I.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%-T871U
M<R@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@
M86X@97AI<W1I;F<@<V]C:V5T(')E<V]U<F-E+B`*("`@("`J($-U<G)E;G1L
M>2!R971U<FYS(&9O=7(@96YT<FEE<R!I;B!T:&4@<F5S=6QT(&%R<F%Y.B`*
M("`@("`J"B`@("`@*B`\<#X*("`@("`J('1I;65D7V]U="`H8F]O;"D@+2!4
M:&4@<V]C:V5T('1I;65D(&]U="!W86ET:6YG(&9O<B!D871A/&)R/@H@("`@
M("H@8FQO8VME9"`H8F]O;"D@+2!4:&4@<V]C:V5T('=A<R!B;&]C:V5D/&)R
M/@H@("`@("H@96]F("AB;V]L*2`M($EN9&EC871E<R!%3T8@979E;G0\8G(^
M"B`@("`@*B!U;G)E861?8GET97,@*&EN="D@+2!.=6UB97(@;V8@8GET97,@
M;&5F="!I;B!T:&4@<V]C:V5T(&)U9F9E<CQB<CX*("`@("`J(#PO<#X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!M:7AE
M9"!!<G)A>2!C;VYT86EN:6YG(&EN9F]R;6%T:6]N(&%B;W5T(&5X:7-T:6YG
M('-O8VME="!R97-O=7)C92!O<B!A;B!E<G)O<B!O8FIE8W0@;W1H97)W:7-E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-T871U<R@I('L*("`@("`@("!I
M9B`H:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U
M<FX@<V]C:V5T7V=E=%]S=&%T=7,H)'1H:7,M/F9P*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")N;W0@8V]N;F5C=&5D
M(BD["B`@("!]"B`@("`O+R!]?7T*("`@(`H@("`@+R\@>WM[(&=E=',H*0H@
M("`@+RHJ"B`@("`@*B!'970@82!S<&5C:69I960@;&EN92!O9B!D871A"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@)'-I
M>F4@8GET97,@;V8@9&%T82!F<F]M('1H92!S;V-K970L(&]R(&$@4$5!4E]%
M<G)O<B!I9@H@("`@("H@("`@("`@("!N;W0@8V]N;F5C=&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971S*"1S:7IE*2!["B`@("`@("`@:68@*&ES7W)E
M<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N(&9G971S
M*"1T:&ES+3YF<"P@)'-I>F4I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(FYO="!C;VYN96-T960B*3L*("`@('T*("`@
M("\O('U]?0H@("`@"B`@("`O+R![>WL@<F5A9"@I"B`@("`O*BH*("`@("`J
M(%)E860@82!S<&5C:69I960@86UO=6YT(&]F(&1A=&$N(%1H:7,@:7,@9W5A
M<F%N=&5E9"!T;R!R971U<FXL"B`@("`@*B!A;F0@:&%S('1H92!A9&1E9"!B
M96YE9FET(&]F(&=E='1I;F<@979E<GET:&EN9R!I;B!O;F4@9G)E860H*0H@
M("`@("H@8VAU;FL[(&EF('EO=2!K;F]W('1H92!S:7IE(&]F('1H92!D871A
M('EO=2=R92!G971T:6YG"B`@("`@*B!B969O<F5H86YD+"!T:&ES(&ES(&1E
M9FEN:71E;'D@=&AE('=A>2!T;R!G;RX*("`@("`J"B`@("`@*B!`<&%R86T@
M)'-I>F4@5&AE(&YU;6)E<B!O9B!B>71E<R!T;R!R96%D(&9R;VT@=&AE('-O
M8VME="X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N("1S
M:7IE(&)Y=&5S(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T+"!O<B!A(%!%05)?
M17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5A9"@D<VEZ92D@>PH@("`@("`@(&EF("AI<U]R
M97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B!F<F5A
M9"@D=&AI<RT^9G`L("1S:7IE*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")N;W0@8V]N;F5C=&5D(BD["B`@("!]"B`@
M("`O+R!]?7T*("`@(`H@("`@+R\@>WM[('=R:71E*"D*("`@("\J*@H@("`@
M("H@5W)I=&4@82!S<&5C:69I960@86UO=6YT(&]F(&1A=&$N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;6EX960@=')U
M92!O;B!S=6-C97-S(&]R(&%N(&5R<F]R(&]B:F5C="!O=&AE<G=I<V4*("`@
M("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&1A=&$I('L*("`@("`@("!I9B`H
M:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@
M9G=R:71E*"1T:&ES+3YF<"P@)&1A=&$I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO="!C;VYN96-T960B*3L*("`@
M('T*("`@("\O('U]?0H@("`@"B`@("`O+R![>WL@=W)I=&5,:6YE*"D*("`@
M("\J*@H@("`@("H@5W)I=&4@82!L:6YE(&]F(&1A=&$@=&\@=&AE('-O8VME
M="P@9F]L;&]W960@8GD@82!T<F%I;&EN9R`B7')<;B(N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;6EX960@9G!U=',@
M<F5S=6QT+"!O<B!A;B!E<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M94QI;F4@*"1D871A*2!["B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES
M+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW<FET92@D9&%T
M82`N(")<<EQN(BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B;F]T(&-O;FYE8W1E9"(I.PH@("`@?0H@("`@+R\@?7U]
M"B`@("`*("`@("\O('M[>R!E;V8H*0H@("`@+RHJ"B`@("`@*B!497-T<R!F
M;W(@96YD+6]F+69I;&4@;VX@82!S;V-K970@9&5S8W)I<'1O<@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&)O;VP*("`@
M("`J+PH@("`@9G5N8W1I;VX@96]F*"D@>PH@("`@("`@(')E='5R;B`H:7-?
M<F5S;W5R8V4H)'1H:7,M/F9P*2`F)B!F96]F*"1T:&ES+3YF<"DI.PH@("`@
M?0H@("`@+R\@?7U]"B`@("`*("`@("\O('M[>R!R96%D0GET92@I"B`@("`O
M*BH*("`@("`J(%)E861S(&$@8GET92!O9B!D871A"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@,2!B>71E(&]F(&1A=&$@
M9G)O;2!T:&4@<V]C:V5T+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@
M("`@("`@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9$)Y=&4H*2!["B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&]R9"@D=&AI<RT^<F5A9"@Q*2D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B;F]T
M(&-O;FYE8W1E9"(I.PH@("`@?0H@("`@+R\@?7U]"B`@("`*("`@("\O('M[
M>R!R96%D5V]R9"@I"B`@("`O*BH*("`@("`J(%)E861S(&$@=V]R9"!O9B!D
M871A"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U
M<FX@,2!W;W)D(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T+"!O<B!A(%!%05)?
M17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5A9%=O<F0H*2!["B`@("`@("`@:68@*&ES7W)E
M<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@)&)U9B`]("1T:&ES
M+3YR96%D*#(I.PH@("`@("`@("`@("!R971U<FX@*&]R9"@D8G5F6S!=*2`K
M("AO<F0H)&)U9ELQ72D@/#P@."DI.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO="!C;VYN96-T960B*3L*("`@('T*
M("`@("\O('U]?0H@("`@"B`@("`O+R![>WL@<F5A9$EN="@I"B`@("`O*BH*
M("`@("`J(%)E861S(&%N(&EN="!O9B!D871A"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@,2!I;G0@;V8@9&%T82!F<F]M
M('1H92!S;V-K970L(&]R(&$@4$5!4E]%<G)O<B!I9@H@("`@("H@("`@("`@
M("!N;W0@8V]N;F5C=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D26YT
M*"D@>PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@
M("`@("`@("`@("1B=68@/2`D=&AI<RT^<F5A9"@T*3L*("`@("`@("`@("`@
M<F5T=7)N("AO<F0H)&)U9ELP72D@*R`H;W)D*"1B=69;,5TI(#P\(#@I("L*
M("`@("`@("`@("`@("`@("`@("`H;W)D*"1B=69;,ETI(#P\(#$V*2`K("AO
M<F0H)&)U9ELS72D@/#P@,C0I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")N;W0@8V]N;F5C=&5D(BD["B`@("!]"B`@
M("`O+R!]?7T*("`@(`H@("`@+R\@>WM[(')E8613=')I;F<H*0H@("`@+RHJ
M"B`@("`@*B!296%D<R!A('IE<F]T97)M:6YA=&5D('-T<FEN9R!O9B!D871A
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@
M<W1R:6YG+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T
M(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9%-T<FEN9R@I
M('L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@
M("`@("`@("`D<W1R:6YG(#T@)R<["B`@("`@("`@("`@('=H:6QE("@H)&-H
M87(@/2`D=&AI<RT^<F5A9"@Q*2D@(3T@(EQX,#`B*2`@>PH@("`@("`@("`@
M("`@("`@)'-T<FEN9R`N/2`D8VAA<CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@)'-T<FEN9SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")N;W0@8V]N;F5C=&5D(BD["B`@("!]"B`@
M("`O+R!]?7T*("`@(`H@("`@+R\@>WM[(')E861)4$%D9')E<W,H*0H@("`@
M+RHJ"B`@("`@*B!296%D<R!A;B!)4"!!9&1R97-S(&%N9"!R971U<FYS(&ET
M(&EN(&$@9&]T(&9O<FUA=&5D('-T<FEN9PH@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N($1O="!F;W)M871E9"!S=')I;F<L
M(&]R(&$@4$5!4E]%<G)O<B!I9@H@("`@("H@("`@("`@("!N;W0@8V]N;F5C
M=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D25!!9&1R97-S*"D@>PH@
M("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@
M("`@("1B=68@/2`D=&AI<RT^<F5A9"@T*3L*("`@("`@("`@("`@<F5T=7)N
M('-P<FEN=&8H(B5S+B5S+B5S+B5S(BP@;W)D*"1B=69;,%TI+"!O<F0H)&)U
M9ELQ72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&]R9"@D8G5F6S)=
M*2P@;W)D*"1B=69;,UTI*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")N;W0@8V]N;F5C=&5D(BD["B`@("!]"B`@("`O
M+R!]?7T*("`@(`H@("`@+R\@>WM[(')E861,:6YE*"D*("`@("\J*@H@("`@
M("H@4F5A9"!U;G1I;"!E:71H97(@=&AE(&5N9"!O9B!T:&4@<V]C:V5T(&]R
M(&$@;F5W;&EN92P@=VAI8VAE=F5R"B`@("`@*B!C;VUE<R!F:7)S="X@4W1R
M:7!S('1H92!T<F%I;&EN9R!N97=L:6YE(&9R;VT@=&AE(')E='5R;F5D(&1A
M=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U
M<FX@06QL(&%V86EL86)L92!D871A('5P('1O(&$@;F5W;&EN92P@=VET:&]U
M="!T:&%T"B`@("`@*B`@("`@("`@(&YE=VQI;F4L(&]R('5N=&EL('1H92!E
M;F0@;V8@=&AE('-O8VME="P@;W(@82!014%27T5R<F]R(&EF"B`@("`@*B`@
M("`@("`@(&YO="!C;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M861,:6YE*"D@>PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^9G`I
M*2!["B`@("`@("`@("`@("1L:6YE(#T@)R<["B`@("`@("`@("`@("1T:6UE
M;W5T(#T@=&EM92@I("L@)'1H:7,M/G1I;65O=70["B`@("`@("`@("`@('=H
M:6QE("@A)'1H:7,M/F5O9B@I("8F("@A)'1H:7,M/G1I;65O=70@?'P@=&EM
M92@I(#P@)'1I;65O=70I*2!["B`@("`@("`@("`@("`@("`D;&EN92`N/2`D
M=&AI<RT^9V5T<R@D=&AI<RT^;&EN94QE;F=T:"D["B`@("`@("`@("`@("`@
M("!I9B`H<W1R;&5N*"1L:6YE*2`^/2`R("8F"B`@("`@("`@("`@("`@("`@
M("`@*'-U8G-T<B@D;&EN92P@+3(I(#T](")<<EQN(B!\?`H@("`@("`@("`@
M("`@("`@("`@("!S=6)S='(H)&QI;F4L("TQ*2`]/2`B7&XB*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!R=')I;2@D;&EN92D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1L
M:6YE.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(FYO="!C;VYN96-T960B*3L*("`@('T*("`@("\O('U]?0H@("`@"B`@
M("`O+R![>WL@<F5A9$%L;"@I"B`@("`O*BH*("`@("`J(%)E860@=6YT:6P@
M=&AE('-O8VME="!C;&]S97,N(%1(25,@1E5.0U1)3TX@5TE,3"!.3U0@15A)
M5"!I9B!T:&4*("`@("`J('-O8VME="!I<R!I;B!B;&]C:VEN9R!M;V1E('5N
M=&EL('1H92!S;V-K970@8VQO<V5S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N($%L;"!D871A('5N=&EL('1H92!S;V-K
M970@8VQO<V5S+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@
M;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9$%L;"@I
M('L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@
M("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("`@("!W:&EL92`H(21T:&ES
M+3YE;V8H*2D*("`@("`@("`@("`@("`@("1D871A("X]("1T:&ES+3YR96%D
M*"1T:&ES+3YL:6YE3&5N9W1H*3L*("`@("`@("`@("`@<F5T=7)N("1D871A
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(FYO="!C;VYN96-T960B*3L*("`@('T*("`@("\O('U]?0H@("`@"GT*/SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TYE="]33510+G!H<```````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8U-S$W`#$P-#$W,S8S,#`V`#`Q-S0P
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@<V]F='1A8G-T;W`]-"!T86)S
M=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@($1A;6EA;B!!;&5J86YD<F\@1F5R;F%N9&5Z(%-O<V$@/&1A;6QI
M<W1S0&-N8F$N=6)A+F%R/B`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*<F5Q=6ER95]O
M;F-E("=.970O4V]C:V5T+G!H<"<["@HO*BH*("H@4')O=FED97,@86X@:6UP
M;&5M96YT871I;VX@;V8@=&AE(%--5%`@<')O=&]C;VP@=7-I;F<@4$5!4B=S
M"B`J($YE=%]3;V-K970Z.B!C;&%S<RX*("H*("H@0'!A8VMA9V4@3F5T7U--
M5%`*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`
M875T:&]R("!$86UI86X@06QE:F%N9')O($9E<FYA;F1E>B!3;W-A(#QD86UL
M:7-T<T!C;F)A+G5B82YA<CX*("HO"F-L87-S($YE=%]33510"GL*("`@("\J
M*@H@("`@("H@5&AE('-E<G9E<B!T;R!C;VYN96-T('1O+@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@('9A
M<B`D:&]S="`]("=L;V-A;&AO<W0G.PH*("`@("\J*@H@("`@("H@5&AE('!O
M<G0@=&\@8V]N;F5C="!T;RX*("`@("`J($!V87(@:6YT"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!V87(@)'!O<G0@/2`R-3L*"B`@("`O
M*BH*("`@("`J(%1H92!V86QU92!T;R!G:79E('=H96X@<V5N9&EN9R!%2$Q/
M(&]R($A%3$\N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@=F%R("1L;V-A;&AO<W0@/2`G;&]C86QH;W-T
M)SL*"B`@("`O*BH*("`@("`J($QI<W0@;V8@<W5P<&]R=&5D(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9',L(&EN('!R969E<F5N=&EA;"!O<F1E<BX*("`@("`J
M($!V87(@87)R87D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M('9A<B`D875T:%]M971H;V1S(#T@87)R87DH)T1)1T535"U-1#4G+"`G0U)!
M32U-1#4G+"`G3$]'24XG+"`G4$Q!24XG*3L*"B`@("`O*BH*("`@("`J(%-H
M;W5L9"!D96)U9V=I;F<@;W5T<'5T(&)E(&5N86)L960_"B`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]D96)U9R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE('-O8VME
M="!R97-O=7)C92!B96EN9R!U<V5D('1O(&-O;FYE8W0@=&\@=&AE(%--5%`@
M<V5R=F5R+@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7W-O8VME="`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!4:&4@;6]S="!R96-E;G0@<V5R=F5R(')E<W!O;G-E(&-O
M9&4N"B`@("`@*B!`=F%R(&EN=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V-O9&4@/2`M,3L*"B`@("`O*BH*("`@("`J(%1H
M92!M;W-T(')E8V5N="!S97)V97(@<F5S<&]N<V4@87)G=6UE;G1S+@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V%R9W5M96YT<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!3=&]R97,@9&5T96-T960@9F5A='5R97,@;V8@=&AE(%--5%`@<V5R=F5R
M+@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V5S;71P(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($EN<W1A;G1I871E<R!A(&YE=R!.971?4TU44"!O8FIE8W0L(&]V97)R
M:61I;F<@86YY(&1E9F%U;'1S"B`@("`@*B!W:71H('!A<F%M971E<G,@=&AA
M="!A<F4@<&%S<V5D(&EN+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M5&AE('-E<G9E<B!T;R!C;VYN96-T('1O+@H@("`@("H@0'!A<F%M(&EN="!4
M:&4@<&]R="!T;R!C;VYN96-T('1O+@H@("`@("H@0'!A<F%M('-T<FEN9R!4
M:&4@=F%L=64@=&\@9VEV92!W:&5N('-E;F1I;F<@14A,3R!O<B!(14Q/+@H@
M("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@
M,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N($YE=%]33510*"1H;W-T(#T@;G5L
M;"P@)'!O<G0@/2!N=6QL+"`D;&]C86QH;W-T(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)&AO<W0I*2`D=&AI<RT^:&]S="`]("1H;W-T.PH@
M("`@("`@(&EF("AI<W-E="@D<&]R="DI("1T:&ES+3YP;W)T(#T@)'!O<G0[
M"B`@("`@("`@:68@*&ES<V5T*"1L;V-A;&AO<W0I*2`D=&AI<RT^;&]C86QH
M;W-T(#T@)&QO8V%L:&]S=#L*"B`@("`@("`@)'1H:7,M/E]S;V-K970@/2!N
M97<@3F5T7U-O8VME="@I.PH*("`@("`@("`O*@H@("`@("`@("`J($EN8VQU
M9&4@=&AE($%U=&A?4T%33"!P86-K86=E+B`@268@=&AE('!A8VMA9V4@:7,@
M;F]T(&%V86EL86)L92P*("`@("`@("`@*B!W92!D:7-A8FQE('1H92!A=71H
M96YT:6-A=&EO;B!M971H;V1S('1H870@9&5P96YD('5P;VX@:70N"B`@("`@
M("`@("HO"B`@("`@("`@:68@*"A`:6YC;'5D95]O;F-E("=!=71H+U-!4TPN
M<&AP)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1P;W,@/2!A<G)A>5]S
M96%R8V@H)T1)1T535"U-1#4G+"`D=&AI<RT^875T:%]M971H;V1S*3L*("`@
M("`@("`@("`@=6YS970H)'1H:7,M/F%U=&A?;65T:&]D<ULD<&]S72D["B`@
M("`@("`@("`@("1P;W,@/2!A<G)A>5]S96%R8V@H)T-204TM340U)RP@)'1H
M:7,M/F%U=&A?;65T:&]D<RD["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YA
M=71H7VUE=&AO9'-;)'!O<UTI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!T:&4@=F%L=64@;V8@=&AE(&1E8G5G9VEN9R!F;&%G+@H@
M("`@("H*("`@("`J($!P87)A;2`@(&)O;VQE86X@)&1E8G5G("`@("`@3F5W
M('9A;'5E(&9O<B!T:&4@9&5B=6=G:6YG(&9L86<N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("`Q+C$N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971$96)U9R@D9&5B=6<I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]D96)U9R`]("1D96)U9SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E;F0@=&AE(&=I=F5N('-T<FEN9R!O9B!D871A('1O('1H92!S97)V97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9&%T82`@("`@("!4
M:&4@<W1R:6YG(&]F(&1A=&$@=&\@<V5N9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N("!M:7AE9"`@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("H@0'-I;F-E("`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-E;F0H)&1A=&$I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?9&5B
M=6<I('L*("`@("`@("`@("`@96-H;R`B1$5"54<Z(%-E;F0Z("1D871A7&XB
M.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R
M(#T@)'1H:7,M/E]S;V-K970M/G=R:71E*"1D871A*2DI('L*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!014%27T5R<F]R*"=&86EL960@=&\@=W)I=&4@=&\@
M<V]C:V5T.B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E<G)O<BT^9V5T365S<V%G92@I*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!A(&-O;6UA
M;F0@=&\@=&AE('-E<G9E<B!W:71H(&%N(&]P=&EO;F%L('-T<FEN9R!O9B!A
M<F=U;65N=',N"B`@("`@*B!!(&-A<G)I86=E(')E='5R;B`O(&QI;F5F965D
M("A#4DQ&*2!S97%U96YC92!W:6QL(&)E(&%P<&5N9&5D('1O(&5A8V@*("`@
M("`J(&-O;6UA;F0@<W1R:6YG(&)E9F]R92!I="!I<R!S96YT('1O('1H92!3
M3510('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1C
M;VUM86YD("`@(%1H92!33510(&-O;6UA;F0@=&\@<V5N9"!T;R!T:&4@<V5R
M=F5R+@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D87)G<R`@("`@("!!('-T
M<FEN9R!O9B!O<'1I;VYA;"!A<F=U;65N=',@=&\@87!P96YD"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O('1H92!C;VUM86YD+@H@
M("`@("H*("`@("`J($!R971U<FX@(&UI>&5D("`@5&AE(')E<W5L="!O9B!T
M:&4@7W-E;F0H*2!C86QL+@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A
M=&4*("`@("`J($!S:6YC92`@(#$N,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]P=70H)&-O;6UA;F0L("1A<F=S(#T@)R<I"B`@("!["B`@("`@("`@:68@
M*"%E;7!T>2@D87)G<RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<V5N9"@D8V]M;6%N9"`N("<@)R`N("1A<F=S("X@(EQR7&XB*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E;F0H)&-O;6UA;F0@+B`B
M7')<;B(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9"!A(')E<&QY(&9R
M;VT@=&AE(%--5%`@<V5R=F5R+B`@5&AE(')E<&QY(&-O;G-I<W1S(&]F(&$@
M<F5S<&]N<V4*("`@("`J(&-O9&4@86YD(&$@<F5S<&]N<V4@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1V86QI9"`@("`@(%1H
M92!S970@;V8@=F%L:60@<F5S<&]N<V4@8V]D97,N("!4:&5S90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!M87D@8F4@<W!E8VEF:65D
M(&%S(&%N(&%R<F%Y(&]F(&EN=&5G97(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=F%L=65S(&]R(&%S(&$@<VEN9VQE(&EN=&5G97(@
M=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B`@;6EX960@("!4<G5E(&EF
M('1H92!S97)V97(@<F5T=7)N960@82!V86QI9"!R97-P;VYS92!C;V1E(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M:7,@86X@97)R;W(@8V]N9&ET:6]N(&ES(')E86-H960N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'-I;F-E("`@,2XQ+C`*("`@
M("`J"B`@("`@*B!`<V5E("`@("!G971297-P;VYS90H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<&%R<V5297-P;VYS92@D=F%L:60I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]C;V1E(#T@+3$["B`@("`@("`@)'1H:7,M/E]A<F=U;65N=',@
M/2!A<G)A>2@I.PH*("`@("`@("!W:&EL92`H)&QI;F4@/2`D=&AI<RT^7W-O
M8VME="T^<F5A9$QI;F4H*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]D
M96)U9RD@>PH@("`@("`@("`@("`@("`@96-H;R`B1$5"54<Z(%)E8W8Z("1L
M:6YE7&XB.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)9B!W92!R
M96-E:79E(&%N(&5M<'1Y(&QI;F4L('1H92!C;VYN96-T:6]N(&AA<R!B965N
M(&-L;W-E9"X@*B\*("`@("`@("`@("`@:68@*&5M<'1Y*"1L:6YE*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@
M("`@("`@(')E='5R;B!N97<@4$5!4E]%<G)O<B@B0V]N;F5C=&EO;B!W87,@
M=6YE>'!E8W1E9&QY(&-L;W-E9"(I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!296%D('1H92!C;V1E(&%N9"!S=&]R92!T:&4@<F5S="!I;B!T
M:&4@87)G=6UE;G1S(&%R<F%Y+B`J+PH@("`@("`@("`@("`D8V]D92`]('-U
M8G-T<B@D;&EN92P@,"P@,RD["B`@("`@("`@("`@("1T:&ES+3Y?87)G=6UE
M;G1S6UT@/2!T<FEM*'-U8G-T<B@D;&EN92P@-"DI.PH*("`@("`@("`@("`@
M+RH@0VAE8VL@=&AE('-Y;G1A>"!O9B!T:&4@<F5S<&]N<V4@8V]D92X@*B\*
M("`@("`@("`@("`@:68@*&ES7VYU;65R:6,H)&-O9&4I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-O9&4@/2`H:6YT*21C;V1E.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;V1E(#T@+3$[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@268@=&AI<R!I<R!N;W0@82!M=6QT:6QI;F4@<F5S<&]N<V4L
M('=E)W)E(&1O;F4N("HO"B`@("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L
M(#,L(#$I("$]("<M)RD@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-O;7!A<F4@=&AE('-E
M<G9E<B=S(')E<W!O;G-E(&-O9&4@=VET:"!T:&4@=F%L:60@8V]D92X@*B\*
M("`@("`@("!I9B`H:7-?:6YT*"1V86QI9"D@)B8@*"1T:&ES+3Y?8V]D92`]
M/3T@)'9A;&ED*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\J($EF('=E('=E<F4@9VEV96X@86X@87)R87D@;V8@
M=F%L:60@<F5S<&]N<V4@8V]D97,L(&-H96-K(&5A8V@@;VYE+B`J+PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D=F%L:60I*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1V86QI9"!A<R`D=F%L:61?8V]D92D@>PH@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?8V]D92`]/3T@)'9A;&ED7V-O9&4I('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YE=R!014%2
M7T5R<F]R*"));G9A;&ED(')E<W!O;G-E(&-O9&4@<F5C96EV960@9G)O;2!S
M97)V97(B*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(#(M='5P
M;&4@8V]N=&%I;FEN9R!T:&4@;&%S="!R97-P;VYS92!F<F]M('1H92!33510
M('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@($$@='=O
M+65L96UE;G0@87)R87DZ('1H92!F:7)S="!E;&5M96YT(&-O;G1A:6YS('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("!R97-P;VYS92!C;V1E(&%S(&%N
M(&EN=&5G97(@86YD('1H92!S96-O;F0@96QE;65N=`H@("`@("H@("`@("`@
M("`@("`@("`@("!C;VYT86EN<R!T:&4@<F5S<&]N<V4G<R!A<F=U;65N=',@
M87,@82!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<VEN8V4@("`Q+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!G9712
M97-P;VYS92@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"1T:&ES+3Y?
M8V]D92P@:F]I;B@B7&XB+"`D=&AI<RT^7V%R9W5M96YT<RDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP="!T;R!C;VYN96-T('1O('1H92!33510
M('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@("!I;G0@("`@("1T:6UE
M;W5T("`@(%1H92!T:6UE;W5T('9A;'5E("AI;B!S96-O;F1S*2!F;W(@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-O8VME="!C
M;VYN96-T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N
M<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@
M("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@
M;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN
M8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1T:6UE;W5T
M(#T@;G5L;"D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]S;V-K
M970M/F-O;FYE8W0H)'1H:7,M/FAO<W0L("1T:&ES+3YP;W)T+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92P@)'1I
M;65O=70I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@("`@(')E='5R;B!N97<@4$5!4E]%<G)O<B@G1F%I;&5D('1O
M(&-O;FYE8W0@<V]C:V5T.B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R97-U;'0M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A
M<G-E4F5S<&]N<V4H,C(P*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R
M(#T@)'1H:7,M/E]N96=O=&EA=&4H*2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP="!T;R!D:7-C;VYN96-T(&9R;VT@
M=&AE(%--5%`@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N
M(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R
M('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T
M*"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!U="@G455)5"<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C(Q*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]S;V-K970M/F1I<V-O;FYE8W0H
M*2DI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!014%27T5R<F]R*"=&86EL
M960@=&\@9&ES8V]N;F5C="!S;V-K970Z("<@+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&5R<F]R+3YG971-97-S86=E*"DI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T('1O('-E;F0@=&AE($5(3$\@8V]M;6%N9"!A;F0@;V)T
M86EN(&$@;&ES="!O9B!%4TU44`H@("`@("H@97AT96YS:6]N<R!A=F%I;&%B
M;&4L(&%N9"!F86EL:6YG('1H870@:G5S="!S96YD($A%3$\N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H
M(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@
M(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-I;F-E("`Q+C$N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!?;F5G;W1I871E*"D*("`@('L*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G14A,
M3R<L("1T:&ES+3YL;V-A;&AO<W0I*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@("\J
M($EF('=E(')E8V5I=F4@82`U,#,@<F5S<&]N<V4L('=E)W)E(&%L<F5A9'D@
M875T:&5N=&EC871E9"X@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]D
M92`]/3T@-3`S*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@268@=&AE($5(3$\@9F%I;&5D
M+"!T<GD@=&AE('-I;7!L97(@2$5,3R!C;VUM86YD+B`J+PH@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G2$5,
M3R<L("1T:&ES+3YL;V-A;&AO<W0I*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!N97<@4$5!4E]%<G)O<B@G2$5,3R!W87,@
M;F]T(&%C8V5P=&5D.B`G+"`D=&AI<RT^7V-O9&4I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?87)G=6UE;G1S(&%S("1A<F=U;65N="D@>PH@
M("`@("`@("`@("`D=F5R8B`]('-T<G1O:R@D87)G=6UE;G0L("<@)RD["B`@
M("`@("`@("`@("1A<F=U;65N=',@/2!S=6)S='(H)&%R9W5M96YT+"!S=')L
M96XH)'9E<F(I("L@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')L96XH)&%R9W5M96YT*2`M('-T<FQE;B@D=F5R8BD@+2`Q*3L*("`@
M("`@("`@("`@)'1H:7,M/E]E<VUT<%LD=F5R8ET@/2`D87)G=6UE;G1S.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!N86UE(&]F('1H92!B97-T(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"!T:&%T('1H92!S97)V97(*("`@("`J(&AA<R!A9'9E
M<G1I<V5D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@4F5T=7)N
M<R!A('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F('1H92!B97-T"B`@
M("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G1E9"!A=71H96YT:6-A=&EO
M;B!M971H;V0@;W(@82!014%27T5R<F]R(&]B:F5C=`H@("`@("H@("`@("`@
M("`@("`@("`@("!I9B!A(&9A:6QU<F4@8V]N9&ET:6]N(&ES(&5N8V]U;G1E
M<F5D+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<VEN8V4@(#$N
M,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971"97-T075T:$UE=&AO9"@I
M"B`@("!["B`@("`@("`@)&%V86EL86)L95]M971H;V1S(#T@97AP;&]D92@G
M("<L("1T:&ES+3Y?97-M='!;)T%55$@G72D["@H@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YA=71H7VUE=&AO9',@87,@)&UE=&AO9"D@>PH@("`@("`@("`@
M("!I9B`H:6Y?87)R87DH)&UE=&AO9"P@)&%V86EL86)L95]M971H;V1S*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1M971H;V0["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!N97<@4$5!4E]%<G)O<B@G
M3F\@<W5P<&]R=&5D(&%U=&AE;G1I8V%T:6]N(&UE=&AO9',G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'0@=&\@9&\@4TU44"!A=71H96YT:6-A
M=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!U<V5R:60@
M=&\@875T:&5N=&EC871E(&%S+@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@
M<&%S<W=O<F0@=&\@875T:&5N=&EC871E('=I=&@N"B`@("`@*B!`<&%R86T@
M<W1R:6YG(%1H92!R97%U97-T960@875T:&5N=&EC871I;VX@;65T:&]D+B`@
M268@;F]N92!I<PH@("`@("H@("`@("`@("`@("`@("!S<&5C:69I960L('1H
M92!B97-T('-U<'!O<G1E9"!M971H;V0@=VEL;"!B92!U<V5D+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET
M:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@
M("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!A=71H*"1U:60L("1P=V0@+"`D;65T:&]D(#T@)R<I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?97-M='!;)T%55$@G72DI
M('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!014%27T5R<F]R*"=33510('-E
M<G9E<B!D;V5S(&YO('-U<'!O<G0@875T:&5N=&EC871I;VXG*3L*("`@("`@
M("!]"@H@("`@("`@("\J"B`@("`@("`@("H@268@;F\@;65T:&]D(&AA<R!B
M965N('-P96-I9FEE9"P@9V5T('1H92!N86UE(&]F('1H92!B97-T('-U<'!O
M<G1E9`H@("`@("`@("`J(&UE=&AO9"!A9'9E<G1I<V5D(&)Y('1H92!33510
M('-E<G9E<BX*("`@("`@("`@*B\*("`@("`@("!I9B`H96UP='DH)&UE=&AO
M9"DI('L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&UE=&AO9"`]
M("1T:&ES+3Y?9V5T0F5S=$%U=&A-971H;V0H*2DI('L*("`@("`@("`@("`@
M("`@("\J(%)E='5R;B!T:&4@4$5!4E]%<G)O<B!O8FIE8W0@9G)O;2!?9V5T
M0F5S=$%U=&A-971H;V0H*2X@*B\*("`@("`@("`@("`@("`@(')E='5R;B`D
M;65T:&]D.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&UE=&AO9"`]('-T<G1O=7!P97(H)&UE=&AO9"D["B`@("`@("`@
M("`@(&EF("@A:6Y?87)R87DH)&UE=&AO9"P@)'1H:7,M/F%U=&A?;65T:&]D
M<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!N97<@4$5!4E]%<G)O<B@B
M)&UE=&AO9"!I<R!N;W0@82!S=7!P;W)T960@875T:&5N=&EC871I;VX@;65T
M:&]D(BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('-W:71C
M:"`H)&UE=&AO9"D@>PH@("`@("`@("`@("!C87-E("=$24=%4U0M340U)SH*
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V%U=&A$:6=E<W1?
M340U*"1U:60L("1P=V0I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@)T-204TM340U)SH*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7V%U=&A#4D%-7TU$-2@D=6ED+"`D<'=D*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=,3T=)3B<Z"B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]A=71H3&]G:6XH)'5I
M9"P@)'!W9"D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M8V%S92`G4$Q!24XG.@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?875T:%!L86EN*"1U:60L("1P=V0I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@;F5W(%!%05)?17)R;W(H(B1M971H;V0@:7,@;F]T(&$@<W5P<&]R
M=&5D(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"(I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A;B!E<G)O<B!W87,@
M96YC;W5N=&5R960L(')E='5R;B!T:&4@4$5!4E]%<G)O<B!O8FIE8W0N("HO
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!2
M1D,M,C4U-"!R97%U:7)E<R!U<R!T;R!R92UN96=O=&EA=&4@15--5%`@869T
M97(@86X@05542"X@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(@/2`D=&AI<RT^7VYE9V]T:6%T92@I*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RH@075T:&5N=&EC871E<R!T:&4@=7-E<B!U<VEN9R!T:&4@
M1$E'15-4+4U$-2!M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R!4:&4@=7-E<FED('1O(&%U=&AE;G1I8V%T92!A<RX*("`@("`J($!P87)A
M;2!S=')I;F<@5&AE('!A<W-W;W)D('1O(&%U=&AE;G1I8V%T92!W:71H+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R
M;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@
M("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-I;F-E("`Q+C$N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!?875T:$1I9V5S=%]-1#4H)'5I9"P@)'!W
M9"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!U="@G05542"<L("=$24=%4U0M340U)RDI*2!["B`@("`@("`@
M("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@("\J(#,S-#H@
M0V]N=&EN=64@875T:&5N=&EC871I;VX@<F5Q=65S="`J+PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS
M92@S,S0I*2D@>PH@("`@("`@("`@("`O*B`U,#,Z($5R<F]R.B!A;')E861Y
M(&%U=&AE;G1I8V%T960@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]D
M92`]/3T@-3`S*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@
M('T*"B`@("`@("`@)&-H86QL96YG92`](&)A<V4V-%]D96-O9&4H)'1H:7,M
M/E]A<F=U;65N='-;,%TI.PH@("`@("`@("1D:6=E<W0@/2`F075T:%]305-,
M.CIF86-T;W)Y*"=D:6=E<W1M9#4G*3L*("`@("`@("`D875T:%]S='(@/2!B
M87-E-C1?96YC;V1E*"1D:6=E<W0M/F=E=%)E<W!O;G-E*"1U:60L("1P=V0L
M("1C:&%L;&5N9V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]S="P@(G-M='`B*2D[
M"@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?
M<'5T*"1A=71H7W-T<BDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W([
M"B`@("`@("`@?0H@("`@("`@("\J(#,S-#H@0V]N=&EN=64@875T:&5N=&EC
M871I;VX@<F5Q=65S="`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@
M("`@("`@*B!792!D;VXG="!U<V4@=&AE('!R;W1O8V]L)W,@=&AI<F0@<W1E
M<"!B96-A=7-E(%--5%`@9&]E<VXG="!A;&QO=PH@("`@("`@("`J('-U8G-E
M<75E;G0@875T:&5N=&EC871I;VXL('-O('=E(&IU<W0@<VEL96YT;'D@:6=N
M;W)E(&ET+@H@("`@("`@("`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"<@)RDI*2!["B`@("`@("`@("`@(')E
M='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@("\J(#(S-3H@075T:&5N
M=&EC871I;VX@<W5C8V5S<V9U;"`J+PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@R,S4I*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@('T*"B`@
M("`O*B!!=71H96YT:6-A=&5S('1H92!U<V5R('5S:6YG('1H92!#4D%-+4U$
M-2!M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@=7-E
M<FED('1O(&%U=&AE;G1I8V%T92!A<RX*("`@("`J($!P87)A;2!S=')I;F<@
M5&AE('!A<W-W;W)D('1O(&%U=&AE;G1I8V%T92!W:71H+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A
M;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K
M:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H@0'-I;F-E("`Q+C$N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!?875T:$-204U?340U*"1U:60L("1P=V0I"B`@("!["B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H
M)T%55$@G+"`G0U)!32U-1#4G*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E
M<G)O<CL*("`@("`@("!]"B`@("`@("`@+RH@,S,T.B!#;VYT:6YU92!A=71H
M96YT:6-A=&EO;B!R97%U97-T("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#,S-"DI*2!["B`@
M("`@("`@("`@("\J(#4P,SH@17)R;W(Z(&%L<F5A9'D@875T:&5N=&EC871E
M9"`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;V1E(#T]/2`U,#,I('L*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("`D
M8VAA;&QE;F=E(#T@8F%S938T7V1E8V]D92@D=&AI<RT^7V%R9W5M96YT<ULP
M72D["B`@("`@("`@)&-R86T@/2`F075T:%]305-,.CIF86-T;W)Y*"=C<F%M
M;60U)RD["B`@("`@("`@)&%U=&A?<W1R(#T@8F%S938T7V5N8V]D92@D8W)A
M;2T^9V5T4F5S<&]N<V4H)'5I9"P@)'!W9"P@)&-H86QL96YG92DI.PH*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@D
M875T:%]S='(I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@
M("`@('T*"B`@("`@("`@+RH@,C,U.B!!=71H96YT:6-A=&EO;B!S=6-C97-S
M9G5L("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H
M:7,M/E]P87)S95)E<W!O;G-E*#(S-2DI*2!["B`@("`@("`@("`@(')E='5R
M;B`D97)R;W(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@075T
M:&5N=&EC871E<R!T:&4@=7-E<B!U<VEN9R!T:&4@3$]'24X@;65T:&]D+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE('5S97)I9"!T;R!A=71H
M96YT:6-A=&4@87,N"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!P87-S=V]R
M9"!T;R!A=71H96YT:6-A=&4@=VET:"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S
M<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL
M=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!S:6YC92`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V%U=&A,;V=I;B@D=6ED+"`D<'=D*0H@("`@>PH@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=!551()RP@)TQ/1TE.
M)RDI*2![(`H@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*
M("`@("`@("`O*B`S,S0Z($-O;G1I;G5E(&%U=&AE;G1I8V%T:6]N(')E<75E
M<W0@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI
M<RT^7W!A<G-E4F5S<&]N<V4H,S,T*2DI('L*("`@("`@("`@("`@+RH@-3`S
M.B!%<G)O<CH@86QR96%D>2!A=71H96YT:6-A=&5D("HO"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7V-O9&4@/3T](#4P,RD@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E<G)O<B`]("1T:&ES+3Y?<'5T*&)A<V4V-%]E;F-O9&4H)'5I9"DI*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@
M("`O*B`S,S0Z($-O;G1I;G5E(&%U=&AE;G1I8V%T:6]N(')E<75E<W0@*B\*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A
M<G-E4F5S<&]N<V4H,S,T*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O
M<B`]("1T:&ES+3Y?<'5T*&)A<V4V-%]E;F-O9&4H)'!W9"DI*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@+RH@
M,C,U.B!!=71H96YT:6-A=&EO;B!S=6-C97-S9G5L("HO"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E
M*#(S-2DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($%U=&AE;G1I8V%T97,@=&AE('5S97(@=7-I;F<@=&AE(%!,04E.(&UE=&AO
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!U<V5R:60@=&\@
M875T:&5N=&EC871E(&%S+@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@<&%S
M<W=O<F0@=&\@875T:&5N=&EC871E('=I=&@N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R
M(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@
M9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`<VEN8V4@(#$N,2XP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]A=71H4&QA:6XH)'5I9"P@)'!W9"D*("`@('L*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G05542"<L("=0
M3$%)3B<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@
M('T*("`@("`@("`O*B`S,S0Z($-O;G1I;G5E(&%U=&AE;G1I8V%T:6]N(')E
M<75E<W0@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!A<G-E4F5S<&]N<V4H,S,T*2DI('L*("`@("`@("`@("`@+RH@
M-3`S.B!%<G)O<CH@86QR96%D>2!A=71H96YT:6-A=&5D("HO"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V-O9&4@/3T](#4P,RD@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@("1A=71H7W-T<B`](&)A
M<V4V-%]E;F-O9&4H8VAR*#`I("X@)'5I9"`N(&-H<B@P*2`N("1P=V0I.PH*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U
M="@D875T:%]S='(I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*"B`@("`@("`@+RH@,C,U.B!!=71H96YT:6-A=&EO;B!S=6-C
M97-S9G5L("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@
M)'1H:7,M/E]P87)S95)E<W!O;G-E*#(S-2DI*2!["B`@("`@("`@("`@(')E
M='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE($A%3$\@8V]M;6%N9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!D;VUA:6X@;F%M92!T
M;R!S87D@=V4@87)E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T
M=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N
M>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R
M=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!H96QO*"1D;VUA:6XI
M"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H
M:7,M/E]P=70H)TA%3$\G+"`D9&]M86EN*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@
M("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE($U!
M24P@1E)/33H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M(%1H92!S96YD97(@*')E=F5R<V4@<&%T:"D@=&\@<V5T+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A
M;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K
M:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F
M=6YC=&EO;B!M86EL1G)O;2@D<V5N9&5R*0H@("`@>PH@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=-04E,)RP@(D92
M3TTZ/"1S96YD97(^(BDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W([
M"B`@("`@("`@?0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]
M("1T:&ES+3Y?<&%R<V5297-P;VYS92@R-3`I*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD('1H92!20U!4(%1/.B!C;VUM
M86YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE(')E8VEP:65N
M="`H9F]R=V%R9"!P871H*2!T;R!A9&0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE
M<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I
M;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(')C
M<'14;R@D<F5C:7!I96YT*0H@("`@>PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=20U!4)RP@(E1/.CPD<F5C:7!I
M96YT/B(I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@
M('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!A<G-E4F5S<&]N<V4H87)R87DH,C4P+"`R-3$I*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@475O=&4@=&AE(&1A=&$@<V\@
M=&AA="!I="!M965T<R!33510('-T86YD87)D<RX*("`@("`J"B`@("`@*B!4
M:&ES(&ES('!R;W9I9&5D(&%S(&$@<V5P87)A=&4@<'5B;&EC(&9U;F-T:6]N
M('1O(&9A8VEL:71A=&4@96%S:65R"B`@("`@*B!O=F5R;&]A9&EN9R!F;W(@
M=&AE(&-A<V5S('=H97)E(&ET(&ES(&1E<VER86)L92!T;R!C=7-T;VUI>F4@
M=&AE"B`@("`@*B!Q=6]T:6YG(&)E:&%V:6]R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@5&AE(&UE<W-A9V4@=&5X="!T;R!Q=6]T92X@(%1H92!S
M=')I;F<@;75S="!B92!P87-S960*("`@("`J("`@("`@("`@("`@("`@8GD@
M<F5F97)E;F-E+"!A;F0@=&AE('1E>'0@=VEL;"!B92!M;V1I9FEE9"!I;B!P
M;&%C92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I
M;F-E("`Q+C(*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&5D871A*"8D9&%T
M82D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($-H86YG92!5;FEX("A<
M;BD@86YD($UA8R`H7'(I(&QI;F5F965D<R!I;G1O($EN=&5R;F5T+7-T86YD
M87)D($-23$8*("`@("`@("`@*B`H7')<;BD@;&EN969E961S+@H@("`@("`@
M("`J+PH@("`@("`@("1D871A(#T@<')E9U]R97!L86-E*"(O*%M>7')=>S%]
M*5QN+R(L(")<7#%<<EQN(BP@)&1A=&$I.PH@("`@("`@("1D871A(#T@<')E
M9U]R97!L86-E*"(O7&Y<;B\B+"`B7&Y<<EQN(BP@)&1A=&$I.PH*("`@("`@
M("`O*@H@("`@("`@("`J($)E8V%U<V4@82!S:6YG;&4@;&5A9&EN9R!P97)I
M;V0@*"XI('-I9VYI9FEE<R!A;B!E;F0@=&\@=&AE(&1A=&$L"B`@("`@("`@
M("H@;&5G:71I;6%T92!L96%D:6YG('!E<FEO9',@;F5E9"!T;R!B92`B9&]U
M8FQE9"(@*&4N9RX@)RXN)RDN"B`@("`@("`@("HO"B`@("`@("`@)&1A=&$@
M/2!P<F5G7W)E<&QA8V4H(B]<;EPN+R(L(")<;BXN(BP@)&1A=&$I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@1$%402!C;VUM86YD+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE(&UE<W-A9V4@8F]D>2!T;R!S
M96YD+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%
M05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@
M("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C
M8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!D871A*"1D871A*0H@("`@>PH@("`@
M("`@("\J"B`@("`@("`@("H@4D9#(#$X-S`L('-E8W1I;VX@,RP@<W5B<V5C
M=&EO;B`S('-T871E<R`B82!V86QU92!O9B!Z97)O(&EN9&EC871E<PH@("`@
M("`@("`J('1H870@;F\@9FEX960@;6%X:6UU;2!M97-S86=E('-I>F4@:7,@
M:6X@9F]R8V4B+B`@1G5R=&AE<FUO<F4L(&ET"B`@("`@("`@("H@<V%Y<R!T
M:&%T(&EF(")T:&4@<&%R86UE=&5R(&ES(&]M:71T960@;F\@:6YF;W)M871I
M;VX@:7,@8V]N=F5Y960*("`@("`@("`@*B!A8F]U="!T:&4@<V5R=F5R)W,@
M9FEX960@;6%X:6UU;2!M97-S86=E('-I>F4B+@H@("`@("`@("`J+PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V5S;71P6R=325I%)UTI("8F("@D=&AI
M<RT^7V5S;71P6R=325I%)UT@/B`P*2D@>PH@("`@("`@("`@("!I9B`H<W1R
M;&5N*"1D871A*2`^/2`D=&AI<RT^7V5S;71P6R=325I%)UTI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@("`@
M("!R971U<FX@;F5W(%!%05)?17)R;W(H)TUE<W-A9V4@<VEZ92!E>&-E9&5S
M('1H92!S97)V97(@;&EM:70G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@475O=&4@=&AE(&1A=&$@8F%S960@;VX@=&AE(%--5%`@
M<W1A;F1A<F1S+B`J+PH@("`@("`@("1T:&ES+3YQ=6]T961A=&$H)&1A=&$I
M.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!U="@G1$%402<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!A<G-E4F5S<&]N<V4H,S4T*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1T:&ES+3Y?<V5N9"@D9&%T82`N(")<<EQN+EQR7&XB*2DI('L*("`@
M("`@("`@("`@<F5T=7)N(&YE=R!014%27T5R<F]R*"=W<FET92!T;R!S;V-K
M970@9F%I;&5D)RD["B`@("`@("`@?0H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@R-3`I*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD('1H92!3
M14Y$($923TTZ(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R!4:&4@<F5V97)S92!P871H('1O('-E;F0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R
M(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@
M9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E;F1?9G)O;2@D<&%T:"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G4T5.1"<L(")&4D]-.CPD<&%T
M:#XB*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P
M87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E;F0@=&AE(%-/34P@1E)/33H@8V]M;6%N9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!R979E<G-E('!A=&@@=&\@
M<V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!0
M14%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J
M("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U
M8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q
M+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<V]M;%]F<F]M*"1P871H*0H@("`@
M>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?
M<'5T*"=33TU,)RP@(D923TTZ/"1P871H/B(I*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@
M4T%-3"!&4D]-.B!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@5&AE(')E=F5R<V4@<&%T:"!T;R!S96YD+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O
M<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F
M(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S86UL7V9R;VTH)'!A=&@I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)U-!34PG+"`B1E)/33H\)'!A
M=&@^(BDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@
M?0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?
M<&%R<V5297-P;VYS92@R-3`I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!396YD('1H92!24T54(&-O;6UA;F0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H
M(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@
M(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')S970H*0H@("`@>PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=24T54)RDI*2!["B`@("`@("`@
M("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@R-3`I
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD
M('1H92!64D99(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R!4:&4@<W1R:6YG('1O('9E<FEF>0H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S
M86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU
M<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!V<F9Y
M*"1S=')I;F<I"B`@("!["B`@("`@("`@+RH@3F]T93H@,C4Q(&ES(&%L<V\@
M82!V86QI9"!R97-P;VYS92!C;V1E("HO"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)U921EDG+"`D<W1R:6YG*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E
M<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E;F0@=&AE($Y/3U`@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R
M;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O
M9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F]O<"@I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R
M<F]R(#T@)'1H:7,M/E]P=70H)TY/3U`G*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@
M("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($)A8VMW87)D<RUC
M;VUP871I8FEL:71Y(&UE=&AO9"X@(&ED96YT:69Y4V5N9&5R*"DG<R!F=6YC
M=&EO;F%L:71Y(&ES"B`@("`@*B!N;W<@:&%N9&QE9"!I;G1E<FYA;&QY+@H@
M("`@("H*("`@("`J($!R971U<FX@(&)O;VQE86X@("`@(%1H:7,@;65T:&]D
M(&%L=V%Y<R!R971U<FX@=')U92X*("`@("`J"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J($!S:6YC92`@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!I9&5N=&EF>5-E;F1E<B@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"GT*"C\^"@``````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O3F5T+TY.5%`N<&AP````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-C$S,C0`,3`T,3<S-C,P,#8`,#$W,S8T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP#0HO+PT*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%!(4"!697)S
M:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS
M92P@("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\#0HO
M+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK#0HO+R!\($%U=&AO<G,Z($UA<G1I;B!+86QT;V9T("`@/&UA
M<G1I;D!N:71R;RYD:SX@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M('P@("`@("`@("`@5&]M87,@5BY6+D-O>"`@("`\8V]X0&ED96-N970N8V]M
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("!(
M96EN;R!(+B!'96AL<V5N(#QH96EN;T!G96AL<V5N+F1K/B`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O#0HO+R`D260Z($Y.5%`N<&AP+'8@,2XR."`R,#`S+S$P+S$P(#(P
M.C,W.C(W(&AE:6YO($5X<"`D#0H-"G)E<75I<F5?;VYC92`G3F5T+TY.5%`O
M4')O=&]C;VPN<&AP)SL-"@T*#0HO*B!.3E10($%U=&AE;G1I8V%T:6]N(&UO
M9&5S("HO#0ID969I;F4H)TY%5%].3E107T%55$A/4DE'24Y!3"<L("=O<FEG
M:6YA;"<I.PT*9&5F:6YE*"=.151?3DY44%]!551(4TE-4$Q%)RP@("`G<VEM
M<&QE)RD[#0ID969I;F4H)TY%5%].3E107T%55$A'14Y%4DE#)RP@("=G96YE
M<FEC)RD[#0H@#0HO+R!$97!R96-A=&5D(&1U92!T;R!N86UI;F<-"F1E9FEN
M92@G4$5!4E].3E107T%55$A/4DE'24Y!3"<L($Y%5%].3E107T%55$A/4DE'
M24Y!3"D[#0ID969I;F4H)U!%05)?3DY44%]!551(4TE-4$Q%)RP@("!.151?
M3DY44%]!551(4TE-4$Q%*3L-"F1E9FEN92@G4$5!4E].3E107T%55$A'14Y%
M4DE#)RP@($Y%5%].3E107T%55$A'14Y%4DE#*3L-"@T*#0HO*BH-"B`J(%1H
M92!.971?3DY44"!C;&%S<R!I<R!A;B!A;&UO<W0@,3`P("4@8F%C:W=A<F0@
M8V]M<&%T:6)L92`-"B`J(&9R;VYT96YD(&-L87-S('1O('1H92!.971?3DY4
M4%]0<F]T;V-O;"!C;&%S<RX-"B`J(`T*("H@051414Y424].(2$A#0H@*B!4
M:&ES(&-L87-S('-H;W5L9"!.3U0@8F4@=7-E9"!I;B!N97<@<')O:F5C=',N
M($ET(&ES(&UE86YT#0H@*B!A<R!A(&1R;W`@:6X@<F5P;&%C96UE;G0@=&\@
M=&AE(&]U=&1A=&5D('8P+C(L(&%N9"!U<V5S(`T*("H@97AC871L>2!T:&4@
M<V%M92!P<F]T;V-O;"!I;7!L96UE;G1A=&EO;B!A<R!T:&4@;F5W(`T*("H@
M3F5T7TY.5%!?4F5A;'1I;64@8VQA<W,L(&)U="!H87,@82!L;W0@;V8@9&5P
M<F5C871E9"`-"B`J(&UE=&AO9',@971C+B!7:&EL92!T:&ES(&-L87-S(&ES
M('-T:6QL(&UA:6YT86EN960L(&ET(&ES#0H@*B!O9F9I8VEA;&QY(&1E860N
M+BX-"B`J#0H@*B!`875T:&]R($UA<G1I;B!+86QT;V9T("`@/&UA<G1I;D!N
M:71R;RYD:SX-"B`J($!A=71H;W(@5&]M87,@5BY6+D-O>"`@("`\8V]X0&ED
M96-N970N8V]M/@T*("H@0&%U=&AO<B!(96EN;R!(+B!'96AL<V5N(#QH96EN
M;T!G96AL<V5N+F1K/@T*("HO#0H-"F-L87-S($YE=%].3E10(&5X=&5N9',@
M3F5T7TY.5%!?4')O=&]C;VP-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*
M#0H@("`@+RHJ#0H@("`@("H@0'9A<B!I;G0-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J($!D97!R96-A=&5D('5S92!L87-T*"D@:6YS=&5A9`T*
M("`@("`J+PT*("`@('9A<B`D;6%X.PT*#0H@("`@+RHJ#0H@("`@("H@0'9A
M<B!I;G0-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!D97!R96-A
M=&5D('5S92!F:7)S="@I(&EN<W1E860-"B`@("`@*B\-"B`@("!V87(@)&UI
M;CL-"@T*("`@("\J*@T*("`@("`J(%5S960@9F]R('-T;W)I;F<@:6YF;W)M
M871I;VX@86)O=70@=&AE(&-U<G)E;G1L>2!S96QE8W1E9"!G<F]U<`T*("`@
M("`J#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J($!S:6YC92`P+C,-"B`@("`@*B\-"B`@("!V87(@)%]C=7)R
M96YT1W)O=7`@/2!N=6QL.PT*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O
M;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!#;VYS=')U8W1O<@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N($YE=%].3E10*"D-"B`@("![#0H)<&%R96YT
M.CI.971?3DY44%]0<F]T;V-O;"@I.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!C;VYN96-T*"D-"@T*("`@("\J*@T*("`@("`J($-O;FYE
M8W0@=&\@=&AE(&YE=W-S97)V97(N#0H@("`@("H-"B`@("`@*B!4:&4@9G5N
M8W1I;VX@8W5R<F5N=&QY(&%L;&]W<R!A=71O;6%T:6,@875T:&5N=&EC871I
M;VX@=FEA('1H92!T:')E92!L87-T('!A<F%M971E<G,L(`T*("`@("`J(&)U
M="!T:&ES(&9E871U<F4@:7,@=&\@8F4@8V]N<VED97)E9"!D97!R97-A=&5D
M("AU<V4@8V]N;F5C=$%U=&AE;G1I8V%T960@:6YS=&5A9"D-"B`@("`@*@T*
M("`@("`J($EN('1H92!F=71U<F4L('1H:7,@9G5N8W1I;VX@=VEL;"!J=7-T
M(&)E(&EN:&5R<FET960@9G)O;2!T:&4@<&%R96YT+`T*("`@("`J(&%N9"!T
M:'5S('1H92!L87-T('1H<F5E('!A<F%M971E<G,@=VEL;"!N;R!L;VYG97(@
M8F4@=7-E9"!T;R!A=71H96YT:6-A=&4N#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@;W!T:6]N86P@<W1R:6YG("1H;W-T(%1H92!A9')E<W,@;V8@=&AE($Y.
M5%`M<V5R=F5R('1O(&-O;FYE8W0@=&\N#0H@("`@("H@0'!A<F%M(&]P=&EO
M;F%L(&EN="`D<&]R="!4:&4@<&]R="!T;R!C;VYN96-T('1O+@T*("`@("`J
M($!P87)A;2!O<'1I;VYA;"!S=')I;F<@)'5S97(@1&5P<F5C871E9"$-"B`@
M("`@*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG("1P87-S($1E<')E8V%T960A
M#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L('-T<FEN9R`D875T:&UO9&4@1&5P
M<F5C871E9"$-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&)O;VPI
M('1R=64@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A
M:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S964@3F5T
M7TY.5%`Z.G%U:70H*0T*("`@("`J($!S964@3F5T7TY.5%`Z.F-O;FYE8W1!
M=71H96YT:6-A=&5D*"D-"B`@("`@*B!`<V5E($YE=%].3E10.CIA=71H96YT
M:6-A=&4H*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&AO<W0@
M/2!.151?3DY44%]04D]43T-/3%]$149!54Q47TA/4U0L#0H@("`@("`@("`@
M("`@("`@("`@("`D<&]R="`]($Y%5%].3E107U!23U1/0T],7T1%1D%53%1?
M4$]25"P-"B`@("`@("`@("`@("`@("`@("`@("1U<V5R(#T@;G5L;"P-"B`@
M("`@("`@("`@("`@("`@("`@("1P87-S(#T@;G5L;"P-"B`@("`@("`@("`@
M("`@("`@("`@("1A=71H;6]D92`]($Y%5%].3E107T%55$A/4DE'24Y!3"D-
M"B`@("![#0H)+R\@0W5R<F5N=&QY('1H:7,@9G5N8W1I;VX@:G5S="`G9F]R
M=V%R9',G('1O(&-O;FYE8W1!=71H96YT:6-A=&5D*"DN#0H)<F5T=7)N("1T
M:&ES+3YC;VYN96-T075T:&5N=&EC871E9"@D=7-E<BP@)'!A<W,L("1H;W-T
M+"`D<&]R="P@)&%U=&AM;V1E*3L-"B`@("!]#0H-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!C;VYN96-T075T:&5N=&EC871E9"@I#0H-"B`@("`O*BH-
M"B`@("`@*B!#;VYN96-T('1O('1H92!N97=S<V5R=F5R+"!A;F0@875T:&5N
M=&EC871E+B!)9B!N;R!U<V5R+W!A<W,@:7,@<W!E8VEF:65D+"!J=7-T(&-O
M;FYE8W0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG
M("1U<V5R(%1H92!U<V5R(&YA;64@=&\@875T:&5N=&EC871E('=I=&@-"B`@
M("`@*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG("1P87-S(%1H92!P87-S=V]R
M9`T*("`@("`J($!P87)A;2!O<'1I;VYA;"!S=')I;F<@)&AO<W0@5&AE(&%D
M<F5S<R!O9B!T:&4@3DY44"US97)V97(@=&\@8V]N;F5C="!T;RX-"B`@("`@
M*B!`<&%R86T@;W!T:6]N86P@:6YT("1P;W)T(%1H92!P;W)T('1O(&-O;FYE
M8W0@=&\N#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L('-T<FEN9R`D875T:&UO
M9&4@5&AE(&%U=&AE;G1I8V%T:6]N(&UO9&4-"B`@("`@*@T*("`@("`J($!R
M971U<FX@;6EX960@*&)O;VPI('1R=64@;VX@<W5C8V5S<R!O<B`H;V)J96-T
M*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J($!S:6YC92`P+C,-"B`@("`@*B!`<V5E($YE=%].3E10.CIC
M;VYN96-T*"D-"B`@("`@*B!`<V5E($YE=%].3E10.CIA=71H96YT:6-A=&4H
M*0T*("`@("`J($!S964@3F5T7TY.5%`Z.G%U:70H*0T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&-O;FYE8W1!=71H96YT:6-A=&5D*"1U<V5R(#T@;G5L;"P-
M"B`@("`@("`@("`@(`D)"2`@)'!A<W,@/2!N=6QL+`T*("`@("`@("`@("`@
M"0D)("`D:&]S="`]($Y%5%].3E107U!23U1/0T],7T1%1D%53%1?2$]35"P-
M"B`@("`@("`@("`@("`@("`)"2`@)'!O<G0@/2!.151?3DY44%]04D]43T-/
M3%]$149!54Q47U!/4E0L#0H@("`@("`@("`@("`@("`@"0D@("1A=71H;6]D
M92`]($Y%5%].3E107T%55$A/4DE'24Y!3"D-"B`@("![#0H)+R\@56YT:6P@
M8V]N;F5C="@I(&ES(&-H86YG960L(&-O;FYE8W0H*2!I<R!C86QL960@9&ER
M96-T;'D@9G)O;2!T:&4@<&%R96YT+BXN#0H))%(@/2!P87)E;G0Z.F-O;FYE
M8W0H)&AO<W0L("1P;W)T*3L-"@EI9B`H4$5!4CHZ:7-%<G)O<B@D4BDI('L-
M"@D@("`@<F5T=7)N("12.PT*"7T-"@T*"2\O($%U=&AE;G1I8V%T92!I9B!U
M<V5R;F%M92!I<R!G:79E;@T*"6EF("@D=7-E<B`A/2!N=6QL*2![#0H@("`@
M"2`@("`D4B`]("1T:&ES+3YA=71H96YT:6-A=&4H)'5S97(L("1P87-S+"`D
M875T:&UO9&4I.PT*("`@(`D@("`@:68@*%!%05(Z.FES17)R;W(H)%(I*2![
M#0H@("`@"0ER971U<FX@)%([#0H@("`@"2`@("!]#0H)?0T*#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!Q=6ET*"D-"@T*("`@("\J*@T*("`@("`J($-L;W-E(&-O;FYE8W1I;VX@
M=&\@=&AE(&YE=W-S97)V97(-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("H@0'-E92!.971?3DY44#HZ8V]N;F5C="@I#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<75I="@I#0H@("`@>PT*("`@("`@("!R971U<FX@
M)'1H:7,M/F-M9%%U:70H*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@<')E<&%R94-O;FYE8W1I;VXH*0T*#0H@("`@+RHJ#0H@("`@("H@
M0V]N;F5C="!T;R!T:&4@;F5W<W-E<G9E<BP@86YD(&ES<W5E(&$@1U)/55`@
M8V]M;6%N9`T*("`@("`J($]N8V4@8V]N;F5C=&EO;B!I<R!P<F5P87)E9"P@
M=V4@8V%N(&]N;'D@9F5T8V@@87)T:6-L97,@9G)O;2!O;F4@9W)O=7`-"B`@
M("`@*B!A="!A('1I;64L('1O(&9E=&-H(&9R;VT@86YO=&AE<B!G<F]U<"P@
M82!N97<@8V]N;F5C=&EO;B!H87,@=&\@8F4@;6%D92X-"B`@("`@*@T*("`@
M("`J(%1H:7,@:7,@=&\@879O:60@=&AE($=23U50(&-O;6UA;F0@9F]R(&5V
M97)Y(&%R=&EC;&4L(&%S(&ET(&ES('9E<GD-"B`@("`@*B!R97-S;W5R8V4@
M:6YT96YS:79E(&]N('1H92!N97=S<V5R=F5R(&5S<&5C:6%L;'D@=VAE;B!U
M<V5D(&9O<@T*("`@("`J(&=R;W5P<R!W:71H(&UA;GD@87)T:6-L97,N#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1H;W-T(%1H92!A9')E<W,@
M;V8@=&AE($Y.5%`M<V5R=F5R('1O(&-O;FYE8W0@=&\N#0H@("`@("H@0'!A
M<F%M(&]P=&EO;F%L(&EN="`D<&]R="!T:&4@<&]R="UN=6UB97(@=&\@8V]N
M;F5C="!T;RP@9&5F875L=',@=&\@,3$Y+@T*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=W-G<F]U<"!4:&4@;F%M92!O9B!T:&4@;F5W<V=R;W5P('1O('5S
M92X-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG("1U<V5R(%1H92!U
M<V5R(&YA;64@=&\@875T:&5N=&EC871E('=I=&@-"B`@("`@*B!`<&%R86T@
M;W!T:6]N86P@<W1R:6YG("1P87-S(%1H92!P87-S=V]R9`T*("`@("`J($!P
M87)A;2!O<'1I;VYA;"!S=')I;F<@)&%U=&AM;V1E(%1H92!A=71H96YT:6-A
M=&EO;B!M;V1E#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AB;V]L
M*2!T<G5E(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F
M86EL=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J
M($!D97!R96-A=&5D(%5S92!C;VYN96-T*"D@;W(@8V]N;F5C=$%U=&AE;G1I
M8V%T960H*2!I;G-T96%D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<')E<&%R
M94-O;FYE8W1I;VXH)&AO<W0L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;W)T(#T@,3$Y+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F5W<V=R;W5P+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=7-E<B`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P87-S(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%U=&AM;V1E(#T@3D547TY.5%!?05542$]224=)3D%,
M*0T*("`@('L-"B`@("`@("`@+RH@8V]N;F5C="!T;R!T:&4@<V5R=F5R("HO
M#0H@("`@("`@("12(#T@)'1H:7,M/F-O;FYE8W0H)&AO<W0L("1P;W)T+"`D
M=7-E<BP@)'!A<W,L("1A=71H;6]D92D[#0H@("`@("`@(&EF("@D=&AI<RT^
M:7-%<G)O<B@D4BDI('L-"B`@("`@("`@("`@(')E='5R;B`D4CL-"B`@("`@
M("`@?0T*#0H@("`@("`@("\J(&ES<W5E(&$@1U)/55`@8V]M;6%N9"`J+PT*
M("`@("`@("`D4B`]("1T:&ES+3YS96QE8W1'<F]U<"@D;F5W<V=R;W5P*3L-
M"B`@("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"12*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("12.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%U=&AE;G1I
M8V%T92@I#0H-"B`@("`O*BH-"B`@("`@*B!!=71H('!R;V-E<W,@*&YO="!Y
M970@<W1A;F1A<FEZ960@8G5T('5S960@86YY('=A>2D-"B`@("`@*B!H='1P
M.B\O=W=W+FUI8G-O9G1W87)E+F-O;2]U<V5R:W0O;FYT<&5X="]I;F1E>"YH
M=&UL#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R(%1H92!U
M<V5R(&YA;64-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG("1P87-S
M(%1H92!P87-S=V]R9"!I9B!N965D960-"B`@("`@*B!`<&%R86T@;W!T:6]N
M86P@<W1R:6YG("1M;V1E($%U=&AI;F9O('1Y<&4Z(&]R:6=I;F%L+"!S:6UP
M;&4L(&=E;F5R:6,-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&)O
M;VPI('1R=64@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N
M(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S:6YC
M92`P+C,-"B`@("`@*B!`<V5E($YE=%].3E10.CIC;VYN96-T*"D-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A=71H96YT:6-A=&4H)'5S97(L("1P87-S+"`D
M;6]D92`]($Y%5%].3E107T%55$A/4DE'24Y!3"D-"B`@("![#0H@("`@("`@
M("\O(%5S97)N86UE(&ES(&$@;75S="XN+@T*("`@("`@("!I9B`H)'5S97(@
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YT:')O=T5R
M<F]R*"=.;R!U<V5R;F%M92!S=7!P;&EE9"<L(&YU;&PI.PT*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@57-E('-E;&5C=&5D(&%U=&AE;G1I8V%T:6]N(&UE
M=&AO9`T*("`@("`@("!S=VET8V@@*"1M;V1E*2![#0H@("`@("`@("`@("!C
M87-E($Y%5%].3E107T%55$A/4DE'24Y!3#H-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F-M9$%U=&AI;F9O*"1U<V5R+"`D<&%S<RD[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E($Y%5%].3E10
M7T%55$A324U03$4Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC
M;61!=71H:6YF;U-I;7!L92@D=7-E<BP@)'!A<W,I.PT*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!.151?3DY44%]!551(1T5.
M15))0SH-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-M9$%U=&AI
M;F9O1V5N97)I8R@D=7-E<BP@)'!A<W,I.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G1H<F]W17)R;W(H(E1H92!A=71H(&UO9&4Z("<D;6]D
M92<@:7,@=6YK;F]W;B(L(&YU;&PI.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&ES0V]N;F5C=&5D*"D-"@T*("`@("\J
M*@T*("`@("`J(%1E<W0@=VAE=&AE<B!W92!A<F4@8V]N;F5C=&5D(&]R(&YO
M="X-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!T<G5E(&]R(&9A;'-E
M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<V5E($YE=%].3E10
M.CIC;VYN96-T*"D-"B`@("`@*B!`<V5E($YE=%].3E10.CIQ=6ET*"D-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!I<T-O;FYE8W1E9"@I#0H@("`@>PT*("`@
M("`@("!R971U<FX@<&%R96YT.CII<T-O;FYE8W1E9"@I.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!S96QE8W1'<F]U<"@I#0H-"B`@("`O
M*BH-"B`@("`@*B!396QE8W1S(&$@;F5W<R!G<F]U<"`H:7-S=64@82!'4D]5
M4"!C;VUM86YD('1O('1H92!S97)V97(I#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N97=S9W)O=7`@5&AE(&YE=W-G<F]U<"!N86UE#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A>2D@1W)O=7!S(&EN9F\@
M;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-
M"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S964@9W)O=7`H*0T*
M("`@("`J($!S964@8V]U;G0H*0T*("`@("`J($!S964@9FER<W0H*0T*("`@
M("`J($!S964@;&%S="@I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5L96-T
M1W)O=7`H)&YE=W-G<F]U<"D-"B`@("![#0H@("`@("`@("1R97-P;VYS95]A
M<G(@/2`D=&AI<RT^8VUD1W)O=7`H)&YE=W-G<F]U<"D[#0H@("`@"6EF("A0
M14%2.CII<T5R<F]R*"1R97-P;VYS95]A<G(I*2![#0H)("`@(')E='5R;B`D
M<F5S<&]N<V5?87)R.PT*"7T-"@T*"21T:&ES+3Y?8W5R<F5N=$=R;W5P(#T@
M)')E<W!O;G-E7V%R<CL-"@T*"2\O($1E<')E8V%T960@+R!H:7-T;W)I8V%L
M"0D)"2`@"0T*"21R97-P;VYS95]A<G);)VUI;B==(#TF("1R97-P;VYS95]A
M<G);)V9I<G-T)UT[#0H))')E<W!O;G-E7V%R<ELG;6%X)UT@/28@)')E<W!O
M;G-E7V%R<ELG;&%S="==.PT*"21T:&ES+3YM:6X@/28@)')E<W!O;G-E7V%R
M<ELG;6EN)UT[#0H))'1H:7,M/FUA>"`])B`D<F5S<&]N<V5?87)R6R=M87@G
M73L-"@T*"7)E='5R;B`D<F5S<&]N<V5?87)R.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!G971'<F]U<',H*0T*#0H@("`@+RHJ#0H@("`@
M("H@1F5T8VAE<R!A(&QI<W0@;V8@86QL(&%V86EB;&4@;F5W<V=R;W5P<PT*
M("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE9"`H87)R87DI(&YE<W1E9"!A
M<G)A>2!W:71H(&EN9F]R;6%T:6]N<R!A8F]U="!E>&ES=&EN9R!N97=S9W)O
M=7!S(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL
M=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971'<F]U<',H*0T*("`@('L-"@DO+R!'970@9W)O=7!S#0H))&=R
M;W5P<R`]("1T:&ES+3YC;61,:7-T*"D[#0H):68@*%!%05(Z.FES17)R;W(H
M)&=R;W5P<RDI('L-"@D@("`@<F5T=7)N("1G<F]U<',[#0H)?0T*#0H)+R\@
M1&5P<F5C871E9"`O(&AI<W1O<FEC86P-"@EF;W)E86-H("AA<G)A>5]K97ES
M*"1G<F]U<',I(&%S("1K*2![#0H@("`@"2`@("`D9W)O=7!S6R1K75LG<&]S
M=&EN9U]A;&QO=V5D)UT@/28@)&=R;W5P<ULD:UU;,UT[#0H)?0T*#0H)+R\@
M1V5T(&=R;W5P(&1E<V-R:7!T:6]N<PT*"21D97-C<FEP=&EO;G,@/2`D=&AI
M<RT^8VUD3&ES=$YE=W-G<F]U<',H*3L-"@EI9B`H4$5!4CHZ:7-%<G)O<B@D
M9&5S8W)I<'1I;VYS*2D@>PT*"2`@("!R971U<FX@)&1E<V-R:7!T:6]N<SL-
M"@E]#0H)#0H)+R\@4V5T(&MN;W=N(&1E<V-R:7!T:6]N<R!F;W(@9W)O=7!S
M#0H):68@*&-O=6YT*"1D97-C<FEP=&EO;G,I(#X@,"D@>PT*("`@(`D@("`@
M9F]R96%C:"`H)&1E<V-R:7!T:6]N<R!A<R`D:ST^)'8I('L-"@D))&=R;W5P
M<ULD:UU;)V1E<V,G72`]("1V.PT*"2`@("!]#0H)?0T*#0H)<F5T=7)N("1G
M<F]U<',[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$]V
M97)V:65W*"D-"@T*("`@("\J*@T*("`@("`J($9E=&-H(&UE<W-A9V4@:&5A
M9&5R(&9R;VT@;65S<V%G92!N=6UB97(@)&9I<G-T('1O("1L87-T#0H@("`@
M("H-"B`@("`@*B!4:&4@9F]R;6%T(&]F('1H92!R971U<FYE9"!A<G)A>2!I
M<SH-"B`@("`@*B`D;65S<V%G97-;;65S<V%G95]I9%U;:&5A9&5R7VYA;65=
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9FER<W0@9FER<W0@
M87)T:6-L92!T;R!F971C:`T*("`@("`J($!P87)A;2!I;G1E9V5R("1L87-T
M("!L87-T(&%R=&EC;&4@=&\@9F5T8V@-"B`@("`@*@T*("`@("`J($!R971U
M<FX@;6EX960@*&%R<F%Y*2!N97-T960@87)R87D@;V8@;65S<V%G92!A;F0@
M=&AE<F4@:&5A9&5R<R!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E87)?97)R
M;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@
M0'-E92!.971?3DY44#HZ9V5T3W9E<G9I97=&;W)M870H*0T*("`@("`J($!S
M964@3F5T7TY.5%`Z.F=E=%)E9F5R96YC97-/=F5R=FEE=R@I#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T3W9E<G9I97<H)&9I<G-T+"`D;&%S="D-"B`@
M("![#0H))&]V97)V:65W(#T@)'1H:7,M/F-M9%A/=F5R*"1F:7)S="P@)&QA
M<W0I.PT*"6EF("A014%2.CII<T5R<F]R*"1O=F5R=FEE=RDI('L-"@D@("`@
M<F5T=7)N("1O=F5R=FEE=SL-"@E]#0H-"@ER971U<FX@)&]V97)V:65W.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971/=F5R=FEE=T9O
M<FUA="@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!A
M=F%I8FQE(&AE861E<G,@=VAI8V@@87)E('-E;F0@9G)O;2!N97=S<V5R=F5R
M('1O(&-L:65N="!F;W(@979E<GD@;F5W<R!M97-S86=E#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A>2D@:&5A9&5R(&YA;65S(&]N('-U
M8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<V5E($YE=%].3E10.CIG971/
M=F5R=FEE=R@I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T3W9E<G9I97=&
M;W)M870H*0T*("`@('L-"@ER971U<FX@)'1H:7,M/F-M9$QI<W1/=F5R=FEE
M=T9-5"@I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971/
M=F5R=FEE=T9M="@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FYS(&$@;&ES
M="!O9B!A=F%I8FQE(&AE861E<G,@=VAI8V@@87)E('-E;F0@9G)O;2!N97=S
M<V5R=F5R('1O(&-L:65N="!F;W(@979E<GD@;F5W<R!M97-S86=E#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A>2D@:&5A9&5R(&YA;65S
M(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E
M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E9"!U
M<V4@9V5T3W9E<G9I97=&;W)M870H*2!I;G-T96%D#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T3W9E<G9I97=&;70H*0T*("`@('L-"@ER971U<FX@)'1H
M:7,M/F=E=$]V97)V:65W1F]R;6%T*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&=E=%)E9F5R96YC97-/=F5R=FEE=R@I#0H-"B`@("`O
M*BH-"B`@("`@*B!&971C:"!A(&QI<W0@;V8@96%C:"!M97-S86=E)W,@<F5F
M97)E;F-E(&AE861E<BX-"B`@("`@*@T*("`@("`J($!P87)A;2!I;G1E9V5R
M("1F:7)S="!F:7)S="!A<G1I8VQE('1O(&9E=&-H#0H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&QA<W0@(&QA<W0@87)T:6-L92!T;R!F971C:`T*("`@("`J
M#0H@("`@("H@0')E='5R;B!M:7AE9"`H87)R87DI(&YE<W1E9"!A<G)A>2!O
M9B!R969E<F5N8V5S(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O
M<B!O;B!F86EL=7)E#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AA
M<G)A>2D@;F5S=&5D(&%R<F%Y(&]F(&UE<W-A9V4@86YD('1H97)E(&AE861E
M<G,@;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU
M<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S964@3F5T7TY.
M5%`Z.F=E=$]V97)V:65W*"D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9712
M969E<F5N8V5S3W9E<G9I97<H)&9I<G-T+"`D;&%S="D-"B`@("![#0H))&]V
M97)V:65W(#T@)'1H:7,M/F-M9%A23W9E<B@D9FER<W0L("1L87-T*3L-"@EI
M9B`H4$5!4CHZ:7-%<G)O<B@D;W9E<G9I97<I*2![#0H)("`@(')E='5R;B`D
M;W9E<G9I97<[#0H)?0T*"0T*"7)E='5R;B`D;W9E<G9I97<[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('!O<W0H*0T*#0H@("`@+RHJ#0H@
M("`@("H@4&]S="!A;B!A<G1I8VQE('1O(&$@;G5M8F5R(&]F(&YE=W-G<F]U
M<',N#0H@("`@("H-"B`@("`@*B`H06UO;F<@=&AE(&%D:71I;VYA;"!H96%D
M97)S('EO=2!M:6=H="!T:&EN:R!O9B!A9&1I;F<@8V]U;&0@8F4Z#0H@("`@
M("H@(DY.5%`M4&]S=&EN9RU(;W-T.B`\:7`M;V8M875T:&]R/B(L('=H:6-H
M('-H;W5L9"!C;VYT86EN('1H92!)4"UA9')E<W,-"B`@("`@*B!O9B!T:&4@
M875T:&]R(&]F('1H92!P;W-T+"!S;R!T:&4@;65S<V%G92!C86X@8F4@=')A
M8V5D(&)A8VL@=&\@:&EM+@T*("`@("`J($]R(")/<F=A;FEZ871I;VXZ(#QO
M<F<^(B!W:&EC:"!C;VYT86EN('1H92!N86UE(&]F('1H92!O<F=A;FEZ871I
M;VX-"B`@("`@*B!T:&4@<&]S="!O<FEG:6YA=&5S(&9R;VTI#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=6)J96-T(%1H92!S=6)J96-T(&]F
M('1H92!P;W-T+@T*("`@("`J($!P87)A;2!S=')I;F<@)&YE=W-G<F]U<"!4
M:&4@;F5W<V=R;W5P('1O('!O<W0@=&\N#0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9G)O;2!.86UE("L@96UA:6PM861R97-S(&]F('-E;F1E<BX-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1B;V1Y(%1H92!B;V1Y(&]F('1H92!P;W-T(&ET
M<V5L9BX-"B`@("`@*B!`<&%R86T@;W!T:6]N86P@<W1R:6YG("1A9&ET:6]N
M86P@061I=&EO;F%L(&AE861E<G,@=&\@<V5N9"X-"B`@("`@*@T*("`@("`J
M($!R971U<FX@;6EX960@*'-T<FEN9RD@<V5R=F5R(')E<W!O;G-E(&]N('-U
M8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P;W-T
M*"1S=6)J96-T+"`D;F5W<V=R;W5P+"`D9G)O;2P@)&)O9'DL("1A9&ET:6]N
M86P@/2`G)RD-"B`@("![#0H)<F5T=7)N("1T:&ES+3YC;610;W-T*"1N97=S
M9W)O=7`L("1S=6)J96-T+"`D8F]D>2P@)&9R;VTL("1A9&ET:6]N86PI.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971!<G1I8VQE4F%W
M*"D-"@T*("`@("\J*@T*("`@("`J($=E="!A;B!A<G1I8VQE("AR87<@9&%T
M82D-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE9"`D87)T:6-L92!%:71H
M97(@=&AE(&UE<W-A9V4M:60@;W(@=&AE(&UE<W-A9V4M;G5M8F5R(&]N('1H
M92!S97)V97(@;V8@=&AE(&%R=&EC;&4@=&\@9F5T8V@N#0H@("`@("H@0'!A
M<F%M(&)O;VP@("1I;7!L;V1E(%=H96X@=')U92!T:&4@<F5S=6QT(&%R<F%Y
M(&ES(&EM<&QO9&5D('1O(&$@<W1R:6YG+"!D969A=6QT<R!T;R!T<G5E+@T*
M("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE9"`H87)R87DO<W1R:6YG*2!4
M:&4@:&5A9&5R<R!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E87)?97)R;W(@
M;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I
M;F-E(#`N,PT*("`@("`J($!S964@9V5T2&5A9&5R4F%W*"D-"B`@("`@*B!`
M<V5E(&=E=$)O9'E287<H*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$%R
M=&EC;&5287<H)&%R=&EC;&4L("1I;7!L;V1E(#T@=')U92D-"B`@("![#0H@
M("`@("`@("1D871A(#T@)'1H:7,M/F-M9$%R=&EC;&4H)&%R=&EC;&4I.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9&%T82DI('L-"@D@("`@<F5T
M=7)N("1D871A.PT*"7T-"@EI9B`H)&EM<&QO9&4@/3T@=')U92D@>PT*"2`@
M("`D9&%T82`](&EM<&QO9&4H(EQR7&XB+"`D9&%T82D[#0H)?0T*"7)E='5R
M;B`D9&%T83L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T
M07)T:6-L92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@86X@87)T:6-L92`H
M9&5P<F5C871E9"D-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE9"`D87)T
M:6-L92!%:71H97(@=&AE(&UE<W-A9V4M:60@;W(@=&AE(&UE<W-A9V4M;G5M
M8F5R(&]N('1H92!S97)V97(@;V8@=&AE(&%R=&EC;&4@=&\@9F5T8V@N#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("AS=')I;F<I(%1H92!H96%D
M97)S(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL
M=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E
M9"!5<V4@9V5T07)T:6-L95)A=R@I(&EN<W1E860-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971!<G1I8VQE*"1A<G1I8VQE*0T*("`@('L-"@ER971U<FX@
M)'1H:7,M/F=E=$%R=&EC;&5287<H)&%R=&EC;&4I.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!G971(96%D97)287<H*0T*#0H@("`@+RHJ
M#0H@("`@("H@1V5T('1H92!H96%D97)S(&]F(&%N(&%R=&EC;&4@*')A=R!D
M871A*0T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1A<G1I8VQE($5I
M=&AE<B!T:&4@*'-T<FEN9RD@;65S<V%G92UI9"!O<B!T:&4@*&EN="D@;65S
M<V%G92UN=6UB97(@;VX@=&AE('-E<G9E<B!O9B!T:&4@87)T:6-L92!T;R!F
M971C:"X-"B`@("`@*B!`<&%R86T@8F]O;"`@)&EM<&QO9&4@5VAE;B!T<G5E
M('1H92!R97-U;'0@87)R87D@:7,@:6UP;&]D960@=&\@82!S=')I;F<L(&1E
M9F%U;'1S('1O('1R=64N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("AA<G)A>2]S=')I;F<I(&AE861E<G,@;VX@<W5C8V5S<R!O<B`H;V)J96-T
M*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J($!S:6YC92`P+C,-"B`@("`@*B!`<V5E(&=E=$%R=&EC;&52
M87<H*0T*("`@("`J($!S964@9V5T0F]D>5)A=R@I#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T2&5A9&5R4F%W*"1A<G1I8VQE+"`D:6UP;&]D92`]('1R
M=64I#0H@("`@>PT*("`@("`@("`D9&%T82`]("1T:&ES+3YC;61(96%D*"1A
M<G1I8VQE*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&1A=&$I*2![
M#0H)("`@(')E='5R;B`D9&%T83L-"@E]#0H):68@*"1I;7!L;V1E(#T]('1R
M=64I('L-"@D@("`@)&1A=&$@/2!I;7!L;V1E*")<<EQN(BP@)&1A=&$I.PT*
M"7T-"@ER971U<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&=E=$AE861E<G,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H
M92!H96%D97)S(&]F(&%N(&%R=&EC;&4@*&1E<')E8V%T960I#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@;6EX960@)&%R=&EC;&4@16ET:&5R('1H92`H<W1R
M:6YG*2!M97-S86=E+6ED(&]R('1H92`H:6YT*2!M97-S86=E+6YU;6)E<B!O
M;B!T:&4@<V5R=F5R(&]F('1H92!A<G1I8VQE('1O(&9E=&-H+@T*("`@("`J
M#0H@("`@("H@0')E='5R;B!M:7AE9"`H<W1R:6YG*2!H96%D97)S(&]N('-U
M8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E9"!5<V4@9V5T
M2&5A9&5R4F%W*"D@:6YS=&5A9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=$AE861E<G,H)&%R=&EC;&4I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H
M:7,M/F=E=$AE861E<E)A=R@D87)T:6-L92D[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=$)O9'E287<H*0T*#0H@("`@+RHJ#0H@("`@
M("H@1V5T('1H92!B;V1Y(&]F(&%N(&%R=&EC;&4@*')A=R!D871A*0T*("`@
M("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1A<G1I8VQE($5I=&AE<B!T:&4@
M;65S<V%G92UI9"!O<B!T:&4@;65S<V%G92UN=6UB97(@;VX@=&AE('-E<G9E
M<B!O9B!T:&4@87)T:6-L92!T;R!F971C:"X-"B`@("`@*B!`<&%R86T@8F]O
M;"`@)&EM<&QO9&4@5VAE;B!T<G5E('1H92!R97-U;'0@87)R87D@:7,@:6UP
M;&]D960@=&\@82!S=')I;F<L(&1E9F%U;'1S('1O('1R=64N#0H@("`@("H-
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("AA<G)A>2]S=')I;F<I(&AE861E<G,@
M;VX@<W5C8V5S<R!O<B`H;V)J96-T*2!P96%R7V5R<F]R(&]N(&9A:6QU<F4-
M"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S:6YC92`P+C,-"B`@
M("`@*B!`<V5E(&=E=$AE861E<E)A=R@I#0H@("`@("H@0'-E92!G971!<G1I
M8VQE4F%W*"D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971";V1Y4F%W*"1A
M<G1I8VQE+"`D:6UP;&]D92`]('1R=64I#0H@("`@>PT*("`@("`@("`D9&%T
M82`]("1T:&ES+3YC;61";V1Y*"1A<G1I8VQE*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&1A=&$I*2![#0H)("`@(')E='5R;B`D9&%T83L-"@E]
M#0H):68@*"1I;7!L;V1E(#T]('1R=64I('L-"@D@("`@)&1A=&$@/2!I;7!L
M;V1E*")<<EQN(BP@)&1A=&$I.PT*"7T-"@ER971U<FX@)&1A=&$[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$)O9'DH*0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5T('1H92!B;V1Y(&]F(&%N(&%R=&EC;&4@*&1E<')E
M8V%T960I#0H@("`@("H-"B`@("`@*B!`<&%R86T@;6EX960@)&%R=&EC;&4@
M16ET:&5R('1H92!M97-S86=E+6ED(&]R('1H92!M97-S86=E+6YU;6)E<B!O
M;B!T:&4@<V5R=F5R(&]F('1H92!A<G1I8VQE('1O(&9E=&-H+@T*("`@("`J
M#0H@("`@("H@0')E='5R;B!M:7AE9"`H<W1R:6YG*2!H96%D97)S(&]N('-U
M8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E9"!5<V4@9V5T
M0F]D>5)A=R@I(&EN<W1E860-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971"
M;V1Y*"1A<G1I8VQE*0T*("`@('L-"@ER971U<FX@)'1H:7,M/F=E=$)O9'E2
M87<H)&%R=&EC;&4I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!G971'<F]U<$%R=&EC;&5S*"D-"@T*("`@("\J*@T*("`@("`J($5X<&5R
M:6UE;G1A;`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B!`<VEN8V4@,"XS#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1W)O=7!!
M<G1I8VQE<R@D;F5W<V=R;W5P*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YC;61,:7-T9W)O=7`H)&YE=W-G<F]U<"D[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&=E=$YE=T=R;W5P<R@I#0H-"B`@("`O*BH-
M"B`@("`@*B!%>'!E<FEM96YT86P-"B`@("`@*@T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N,PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$YE=T=R;W5P<R@D=&EM92D-"B`@("![#0H)<W=I=&-H("AG971T
M>7!E*"1T:6UE*2D@>PT*"2`@("!C87-E("=I;G1E9V5R)SH-"@D)8G)E86L[
M#0H)("`@(&-A<V4@)W-T<FEN9R<Z#0H)"21T:6UE(#T@*&EN="D@<W1R=&]T
M:6UE*"1T:6UE*3L-"@D)8G)E86L[#0H)("`@(&1E9F%U;'0Z#0H)("`@("`@
M("!R971U<FX@)'1H:7,M/G1H<F]W17)R;W(H)R<I.PT*"7T-"@T*"7)E='5R
M;B`D=&AI<RT^8VUD3F5W9W)O=7!S*"1T:6UE*3L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@9V5T3F5W3F5W<R@I#0H-"B`@("`O*BH-"B`@
M("`@*B!%>'!E<FEM96YT86P-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("H@0'-I;F-E(#`N,PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=$YE=TYE=W,H)'1I;64L("1N97=S9W)O=7!S(#T@)RHG*0T*("`@('L-
M"@ES=VET8V@@*&=E='1Y<&4H)'1I;64I*2![#0H)("`@(&-A<V4@)VEN=&5G
M97(G.@T*"0EB<F5A:SL-"@D@("`@8V%S92`G<W1R:6YG)SH-"@D))'1I;64@
M/2`H:6YT*2!S=')T;W1I;64H)'1I;64I.PT*"0EB<F5A:SL-"@D@("`@9&5F
M875L=#H-"@D@("`@("`@(')E='5R;B`D=&AI<RT^=&AR;W=%<G)O<B@G55!3
M+BXN)RD[#0H)?0T*#0H)<F5T=7)N("1T:&ES+3YC;61.97=N97=S*"1T:6UE
M+"`D;F5W<V=R;W5P<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$1A=&4H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!.3E10
M+7-E<G9E<B=S(&EN=&5R;F%L(&1A=&4-"B`@("`@*@T*("`@("`J($=E="!T
M:&4@9&%T92!F<F]M('1H92!N97=S<V5R=F5R(&9O<FUA="!O9B!R971U<FYE
M9"!D871E.@T*("`@("`J#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L(&EN="`D
M9F]R;6%T#0H@("`@("H@("T@,#H@)&1A=&4@+2!T:6UE<W1A;7`-"B`@("`@
M*B`@+2`Q.B`D9&%T95LG>2==("T@>65A<@T*("`@("`J("`@("`@("1D871E
M6R=M)UT@+2!M;VYT:`T*("`@("`J("`@("`@("1D871E6R=D)UT@+2!D87D-
M"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*&UI>&5D*2!D871E(&]N
M('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O;B!F86EL=7)E#0H@
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<VEN8V4@,"XS#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T1&%T92@D9F]R;6%T(#T@,2D-"B`@("![
M#0H@("`@("`@("1D871E(#T@)'1H:7,M/F-M9$1A=&4H*3L-"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&1A=&4I*2![#0H)("`@(')E='5R;B`D9&%T
M93L-"@E]#0H-"@ES=VET8V@@*"1F;W)M870I('L-"@D@("`@8V%S92`Q.@T*
M"2`@("`@("`@<F5T=7)N(&%R<F%Y*"=Y)R`]/B!S=6)S='(H)&1A=&4L(#`L
M(#0I+"`G;2<@/3X@<W5B<W1R*"1D871E+"`T+"`R*2P@)V0G(#T^('-U8G-T
M<B@D9&%T92P@-BP@,BDI.PT*"2`@("`@("`@8G)E86L[#0H-"@D@("`@8V%S
M92`P.@T*"2`@("!D969A=6QT.@T*"2`@("`@("`@<F5T=7)N("1D871E.PT*
M"2`@("`@("`@8G)E86L[#0H)?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!D871E*"D-"@T*("`@("\J*@T*("`@("`J($!R971U<FX@;6EX
M960@*&%R<F%Y*2!D871E(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E
M<G)O<B!O;B!F86EL=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*@T*("`@("`J($!D97!R96-A=&5D(%5S92!G971$871E*"D@:6YS=&5A9`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&1A=&4H*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YG971$871E*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&-O=6YT*"D-"@T*("`@("\J*@T*("`@("`J($YU;6)E
M<B!O9B!A<G1I8VQE<R!I;B!C=7)R96YT;'D@<V5L96-T960@9W)O=7`-"B`@
M("`@*@T*("`@("`J($!R971U<FX@:6YT96=E<B!C;W5N=`T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(#`N,PT*("`@("`J($!S964@
M3F5T7TY.5%`Z.G-E;&5C=$=R;W5P*"D-"B`@("`@*B!`<V5E($YE=%].3E10
M.CIG<F]U<"@I#0H@("`@("H@0'-E92!.971?3DY44#HZ9FER<W0H*0T*("`@
M("`J($!S964@3F5T7TY.5%`Z.FQA<W0H*0T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&-O=6YT*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V-U
M<G)E;G1'<F]U<%LG8V]U;G0G73L-"@T*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!L87-T*"D-"@T*("`@("\J*@T*("`@("`J($UA>&EM=6T@
M87)T:6-L92!N=6UB97(@:6X@8W5R<F5N="!G<F]U<`T*("`@("`J#0H@("`@
M("H@0')E='5R;B!I;G1E9V5R(&UA>&EM=6T-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J($!S:6YC92`P+C,-"B`@("`@*B!`<V5E($YE=%].3E10
M.CIS96QE8W1'<F]U<"@I#0H@("`@("H@0'-E92!.971?3DY44#HZ9W)O=7`H
M*0T*("`@("`J($!S964@3F5T7TY.5%`Z.F9I<G-T*"D-"B`@("`@*B!`<V5E
M($YE=%].3E10.CIC;W5N="@I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@;&%S
M="@I#0H@("`@>PT*"7)E='5R;B`D=&AI<RT^7V-U<G)E;G1'<F]U<%LG;&%S
M="==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!M87@H*0T*
M#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!I;G1E9V5R(&UA>&EM=6T-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J#0H@("`@("H@0&1E<')E8V%T
M960@57-E(&QA<W0H*2!I;G-T96%D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M;6%X*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^;&%S="@I.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!F:7)S="@I#0H-"B`@
M("`O*BH-"B`@("`@*B!-:6YI;75M(&%R=&EC;&4@;G5M8F5R(&EN(&-U<G)E
M;G0@9W)O=7`-"B`@("`@*@T*("`@("`J($!R971U<FX@:6YT96=E<B!M:6YI
M;75M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<VEN8V4@,"XS
M#0H@("`@("H@0'-E92!.971?3DY44#HZ<V5L96-T1W)O=7`H*0T*("`@("`J
M($!S964@3F5T7TY.5%`Z.F=R;W5P*"D-"B`@("`@*B!`<V5E($YE=%].3E10
M.CIL87-T*"D-"B`@("`@*B!`<V5E($YE=%].3E10.CIC;W5N="@I#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9FER<W0H*0T*("`@('L-"@ER971U<FX@)'1H
M:7,M/E]C=7)R96YT1W)O=7!;)V9I<G-T)UT[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&UI;B@I#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@;6EN:6UU;0T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("H-"B`@("`@*B!`9&5P<F5C871E9"!5<V4@9FER<W0H*2!I;G-T96%D
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@;6EN*"D-"B`@("![#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^9FER<W0H*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9W)O=7`H*0T*#0H@("`@+RHJ#0H@("`@("H@0W5R<F5N
M=&QY('-E;&5C=&5D(&=R;W5P#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!G<F]U<`T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I
M;F-E(#`N,PT*("`@("`J($!S964@3F5T7TY.5%`Z.G-E;&5C=$=R;W5P*"D-
M"B`@("`@*B!`<V5E($YE=%].3E10.CIF:7)S="@I#0H@("`@("H@0'-E92!.
M971?3DY44#HZ;&%S="@I#0H@("`@("H@0'-E92!.971?3DY44#HZ8V]U;G0H
M*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=R;W5P*"D-"B`@("![#0H)<F5T
M=7)N("1T:&ES+3Y?8W5R<F5N=$=R;W5P6R=G<F]U<"==.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!S<&QI=$AE861E<G,H*0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5T('1H92!H96%D97)S(&]F(&%N(&%R=&EC;&4@9G)O
M;2!T:&4@8W5R<F5N=&QY(&]P96X@8V]N;F5C=&EO;BP@86YD('!A<G-E('1H
M96T@:6YT;R!A(&ME>65D(&%R<F%Y+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M(&UI>&5D("1A<G1I8VQE($5I=&AE<B!T:&4@*'-T<FEN9RD@;65S<V%G92UI
M9"!O<B!T:&4@*&EN="D@;65S<V%G92UN=6UB97(@;VX@=&AE('-E<G9E<B!O
M9B!T:&4@87)T:6-L92!T;R!F971C:"X-"B`@("`@*@T*("`@("`J($!R971U
M<FX@;6EX960@*&%R<F%Y*2!!<W-O8R!A<G)A>2!W:71H(&AE861E<G,@;F%M
M97,@87,@:V5Y(&]N('-U8V-E<W,@;W(@*&]B:F5C="D@<&5A<E]E<G)O<B!O
M;B!F86EL=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!S<&QI=$AE861E<G,H)&%R=&EC;&4I#0H@("`@>PT*"2\O
M(%)E=')I979E(&AE861E<G,-"B`@("`@("`@)&AE861E<G,@/2`D=&AI<RT^
M9V5T2&5A9&5R4F%W*"1A<G1I8VQE+"!F86QS92D[#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1H96%D97)S*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YT:')O=T5R<F]R*"1H96%D97)S*3L-"B`@("`@("`@?0T*"0T*
M"21R971U<FX@/2!A<G)A>2@I.PT*#0H)+R\@3&]O<"!T:')O=6=H(&%L;"!H
M96%D97(@9FEE;&0@;&EN97,-"B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@
M87,@)&9I96QD*2![#0H)("`@("\O(%-E<&%R871E(&AE861E<B!N86UE(&%N
M9"!V86QU90T*"2`@("!I9B`H(7!R96=?;6%T8V@H)R\H6UQ372LI7#I<<RHH
M+BHI7',J+R<L("1F:65L9"P@)&UA=&-H97,I*2![#0H)"2\O($9A:6PN+BX-
M"@D@("`@?0T*"2`@("`D;F%M92`]("1M871C:&5S6S%=.PT*"2`@("`D=F%L
M=64@/2`D;6%T8VAE<ULR73L-"@D@("`@=6YS970H)&UA=&-H97,I.PT*#0H)
M("`@("\O($%D9"!H96%D97(@=&\@)')E='5R;B!A<G)A>0T*("`@(`D@("`@
M:68@*&ES<V5T*"1R971U<FY;)&YA;65=*2!!3D0@:7-?87)R87DH)')E='5R
M;ELD;F%M95TI*2![#0H)"2\O(%1H92!H96%D97(@;F%M92!H87,@86QR96%D
M>2!B965N('5S960@870@;&5A<W0@='=O('1I;65S+@T*("`@("`@("`@("`@
M"21R971U<FY;)&YA;65=6UT@/2`D=F%L=64[#0H@("`@("`@("`@("!](&5L
M<V5I9B`H:7-S970H)')E='5R;ELD;F%M95TI*2![#0H)"2\O(%1H92!H96%D
M97(@;F%M92!H87,@86QR96%D>2!B965N('5S960@;VYE('1I;64@+3X@8VAA
M;F=E('1O(&YE9'1E9"!V86QU97,N#0H@("`@("`@("`@("`))')E='5R;ELD
M;F%M95T@/2!A<G)A>2@D<F5T=7)N6R1N86UE72P@)'9A;'5E*3L-"B`@("`@
M("`@("`@('T@96QS92![#0H)"2\O(%1H92!H96%D97(@;F%M92!H87,@;F]T
M('5S960@=6YT:6P@;F]W+@T*("`@("`@("`))')E='5R;ELD;F%M95T@/2`D
M=F%L=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*"7)E='5R;B`D
M<F5T=7)N.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!R97-P
M;VYS94-O9&4H*0T*#0H@("`@+RHJ#0H@("`@("H@<F5T=7)N<R!T:&4@<F5S
M<&]N<V4@8V]D92!O9B!A(&YE=W-S97)V97(@8V]M;6%N9`T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<F5S<&]N<V4@;F5W<W-E<G9E<B!A;G-W
M97(-"B`@("`@*@T*("`@("`J($!R971U<FX@:6YT96=E<B!R97-P;VYS92!C
M;V1E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J($!D
M97!R96-A=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5S<&]N<V5#;V1E
M*"1R97-P;VYS92D-"B`@("![#0H@("`@("`@("1P87)T<R`](&5X<&QO9&4H
M)R`G+"!L=')I;2@D<F5S<&]N<V4I+"`R*3L-"B`@("`@("`@<F5T=7)N("AI
M;G0I("1P87)T<ULP73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@7V=E=$1A=&$H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(&1A=&$@=6YT
M:6P@82!L:6YE('=I=&@@;VYL>2!A("<N)R!I;B!I="!I<R!R96%D(&%N9"!R
M971U<FX@9&%T82X-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@*'-T
M<FEN9RD@9&%T82!O;B!S=6-C97-S(&]R("AO8FIE8W0I('!E87)?97)R;W(@
M;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J#0H@
M("`@("H@0&1E<')E8V%T960@57-E(%]G971497AT4F5S<&]N<V4H*2!I;G-T
M96%D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V=E=$1A=&$H*0T*("`@('L-
M"@ER971U<FX@)'1H:7,M/E]G971497AT4F5S<&]N<V4H*3L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]M;6%N9"@I#0H-"B`@("`O*BH-
M"B`@("`@*B!)<W-U92!A(&-O;6UA;F0@=&\@=&AE($Y.5%`@<V5R=F5R#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;60@5&AE(&-O;6UA;F0@
M=&\@;&%U;F-H+"!I93H@(D%25$E#3$4@,3`P-#@U,R(-"B`@("`@*@T*("`@
M("`J($!R971U<FX@;6EX960@*&EN="D@<F5S<&]N<V4@8V]D92!O;B!S=6-C
M97-S(&]R("AO8FIE8W0I('!E87)?97)R;W(@;VX@9F%I;'5R90T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8V]M;6%N
M9"@D8VUD*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5N9$-O
M;6UA;F0H)&-M9"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"GT-"C\^#0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O3F5T+U523"YP:'``````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8V-S8`,3`T,3<S-C,P,#8`,#$W
M,C8R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-"P@4FEC:&%R9"!(97EE<R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@<F5S
M97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF:6-A
M=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I
M;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&\@
M4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H
M92!A8F]V92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(N("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@
M9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`HO
M+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U;65N
M=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T
M:&4@9&ES=')I8G5T:6]N+GP@"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U
M=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@
M("`@('P*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W
M87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?`HO+R!\("`@
M<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9
M(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?`HO
M+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.
M5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\"B\O('P@3$E-251%1"!4
M3RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@
M04Y$($9)5$Y%4U,@1D]2('P*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!
M4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(
M5"`@?`HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2
M($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\"B\O('P@4U!%
M0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.
M0TQ51$E.1RP@0E54($Y/5"`@("`@('P*+R\@?"!,24U)5$5$(%1/+"!04D]#
M55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3
M($]&(%5312P@?`HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3
M($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\"B\O
M('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@
M4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P*+R\@?"`H24Y#3%5$24Y'
M($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@
M3U54($]&(%1(12!54T4@?`HO+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@
M248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N
M("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@4FEC:&%R9"!(
M97EE<R`\<FEC:&%R9$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M)$ED.B!54DPN<&AP+'8@,2XS,2`R,#`T+S`Q+S$W(#$U.C4R.C4P('!A:F]Y
M92!%>'`@)`HO+R`*+R\@3F5T7U523"!#;&%S<PH*8VQA<W,@3F5T7U523`I[
M"B`@("`O*BH*("`@("H@1G5L;"!U<FP*("`@("H@0'9A<B!S=')I;F<*("`@
M("HO"B`@("!V87(@)'5R;#L*("`@(`H@("`@+RHJ"B`@("`J(%!R;W1O8V]L
M"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1P<F]T;V-O;#L*
M"B`@("`O*BH*("`@("H@57-E<FYA;64*("`@("H@0'9A<B!S=')I;F<*("`@
M("HO"B`@("!V87(@)'5S97)N86UE.PH*("`@("\J*@H@("`@*B!087-S=V]R
M9`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D<&%S<W=O<F0[
M"@H@("`@+RHJ"B`@("`J($AO<W0*("`@("H@0'9A<B!S=')I;F<*("`@("HO
M"B`@("!V87(@)&AO<W0["B`@("`*("`@("\J*@H@("`@*B!0;W)T"B`@("`J
M($!V87(@:6YT96=E<@H@("`@*B\*("`@('9A<B`D<&]R=#L*("`@(`H@("`@
M+RHJ"B`@("`J(%!A=&@*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V
M87(@)'!A=&@["B`@("`*("`@("\J*@H@("`@*B!1=65R>2!S=')I;F<*("`@
M("H@0'9A<B!A<G)A>0H@("`@*B\*("`@('9A<B`D<75E<GES=')I;F<["@H@
M("`@+RHJ"B`@("`J($%N8VAO<@H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*
M("`@('9A<B`D86YC:&]R.PH*("`@("\J*@H@("`@*B!7:&5T:&5R('1O('5S
M92!;70H@("`@*B!`=F%R(&)O;VP*("`@("HO"B`@("!V87(@)'5S94)R86-K
M971S.PH*("`@("\J*@H@("`@*B!#;VYS=')U8W1O<@H@("`@*@H@("`@*B!0
M87)S97,@=&AE(&=I=F5N('5R;"!A;F0@<W1O<F5S('1H92!V87)I;W5S('!A
M<G1S"B`@("`J($1E9F%U;'1S(&%R92!U<V5D(&EN(&-E<G1A:6X@8V%S97,*
M("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("`@("`@3W!T:6]N
M86P@55),"@DJ($!P87)A;2!B;V]L("`@)'5S94)R86-K971S(%=H971H97(@
M=&\@=7-E('-Q=6%R92!B<F%C:V5T<R!W:&5N"@DJ("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&UU;'1I<&QE('%U97)Y<W1R:6YG<R!W:71H('1H92!S
M86UE(&YA;64*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@97AI<W0*
M("`@("HO"B`@("!F=6YC=&EO;B!.971?55),*"1U<FP@/2!N=6QL+"`D=7-E
M0G)A8VME=',@/2!T<G5E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D2%144%]3
M15)615)?5D%24SL*"B`@("`@("`@)'1H:7,M/G5S94)R86-K971S(#T@)'5S
M94)R86-K971S.PH@("`@("`@("1T:&ES+3YU<FP@("`@("`@("`]("1U<FP[
M"B`@("`@("`@)'1H:7,M/G5S97(@("`@("`@(#T@)R<["B`@("`@("`@)'1H
M:7,M/G!A<W,@("`@("`@(#T@)R<["@D))'1H:7,M/FAO<W0@("`@("`@(#T@
M)R<["@D))'1H:7,M/G!O<G0@("`@("`@(#T@.#`["@D))'1H:7,M/G!A=&@@
M("`@("`@(#T@)R<["@D))'1H:7,M/G%U97)Y<W1R:6YG(#T@87)R87DH*3L*
M"0DD=&AI<RT^86YC:&]R("`@("`@/2`G)SL*"@D)+R\@3VYL>2!U<V4@9&5F
M875L=',@:68@;F]T(&%N(&%B<V]L=71E(%523"!G:79E;@H)"6EF("@A<')E
M9U]M871C:"@G+UY;82UZ,"TY72LZ7"]<+R]I)RP@)'5R;"DI('L*"2`@("`@
M("`@+RHJ"@D@("`@("`@("H@1FEG=7)E(&]U="!H;W-T+W!O<G0*"2`@("`@
M("`@*B\*"2`@("`@("`@:68@*"%E;7!T>2@D2%144%]315)615)?5D%24ULG
M2%144%](3U-4)UTI($%.1"!P<F5G7VUA=&-H*"<O7B@N*BDH.BA;,"TY72LI
M*3\D+U4G+"`D2%144%]315)615)?5D%24ULG2%144%](3U-4)UTL("1M871C
M:&5S*2D@>PH)("`@("`@("`@("`@)&AO<W0@/2`D;6%T8VAE<ULQ73L*"2`@
M("`@("`@("`@(&EF("@A96UP='DH)&UA=&-H97-;,UTI*2!["@D@("`@("`@
M("`@("`@("`@)'!O<G0@/2`D;6%T8VAE<ULS73L*"2`@("`@("`@("`@('T@
M96QS92!["@D@("`@("`@("`@("`@("`@)'!O<G0@/2`G.#`G.PH)("`@("`@
M("`@("`@?0H)("`@("`@("!]"@D*"2`@("`@("`@)'1H:7,M/G!R;W1O8V]L
M("`@(#T@)VAT='`G("X@*$`D2%144%]315)615)?5D%24ULG2%144%,G72`]
M/2`G;VXG(#\@)W,G(#H@)R<I.PH)("`@("`@("`D=&AI<RT^=7-E<B`@("`@
M("`@/2`G)SL*"2`@("`@("`@)'1H:7,M/G!A<W,@("`@("`@(#T@)R<["@D@
M("`@("`@("1T:&ES+3YH;W-T("`@("`@("`]("%E;7!T>2@D:&]S="D@/R`D
M:&]S="`Z("AI<W-E="@D2%144%]315)615)?5D%24ULG4T525D527TY!344G
M72D@/R`D2%144%]315)615)?5D%24ULG4T525D527TY!344G72`Z("=L;V-A
M;&AO<W0G*3L*"2`@("`@("`@)'1H:7,M/G!O<G0@("`@("`@(#T@(65M<'1Y
M*"1P;W)T*2`_("1P;W)T(#H@*&ES<V5T*"1(5%107U-%4E9%4E]605)36R=3
M15)615)?4$]25"==*2`_("1(5%107U-%4E9%4E]605)36R=315)615)?4$]2
M5"==(#H@.#`I.PH)("`@("`@("`D=&AI<RT^<&%T:"`@("`@("`@/2`A96UP
M='DH)$A45%!?4T525D527U9!4E-;)U!(4%]314Q&)UTI(#\@)$A45%!?4T52
M5D527U9!4E-;)U!(4%]314Q&)UT@.B`G+R<["@D@("`@("`@("1T:&ES+3YQ
M=65R>7-T<FEN9R`](&ES<V5T*"1(5%107U-%4E9%4E]605)36R=1545265]3
M5%))3D<G72D@/R`D=&AI<RT^7W!A<G-E4F%W475E<GES=')I;F<H)$A45%!?
M4T525D527U9!4E-;)U%515)97U-44DE.1R==*2`Z(&YU;&P["@D@("`@("`@
M("1T:&ES+3YA;F-H;W(@("`@("`]("<G.PH)"7T*"B`@("`@("`@+R\@4&%R
M<V4@=&AE('5R;"!A;F0@<W1O<F4@=&AE('9A<FEO=7,@<&%R=',*("`@("`@
M("!I9B`H(65M<'1Y*"1U<FPI*2!["B`@("`@("`@("`@("1U<FQI;F9O(#T@
M<&%R<V5?=7)L*"1U<FPI.PH*("`@("`@("`@("`@+R\@1&5F875L="!Q=65R
M>7-T<FEN9PH@("`@("`@("`@("`D=&AI<RT^<75E<GES=')I;F<@/2!A<G)A
M>2@I.PH@("`@"B`@("`@("`@("`@(&9O<F5A8V@@*"1U<FQI;F9O(&%S("1K
M97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!S=VET8V@@*"1K97DI
M('L*("`@("`@("`@("`@("`@("`@("!C87-E("=S8VAE;64G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<')O=&]C;VP@/2`D=F%L=64["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@(`H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W5S97(G.@H@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)W!A<W,G.@H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)VAO<W0G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W!O<G0G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^)&ME>2`]("1V86QU
M93L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)W!A=&@G.@H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'9A;'5E>S!](#T]("<O)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G!A=&@@/2`D=F%L=64["B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%T:"`](&1I<FYA;64H)'1H:7,M/G!A=&@I(#T]($1)4D5#5$]265]3
M15!!4D%43U(@/R`G)R`Z(&1I<FYA;64H)'1H:7,M/G!A=&@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!A=&@@/2!S<')I;G1F*"<E
M<R\E<R<L("1P871H+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W%U97)Y)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G%U97)Y<W1R:6YG(#T@
M)'1H:7,M/E]P87)S95)A=U%U97)Y4W1R:6YG*"1V86QU92D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C
M87-E("=F<F%G;65N="<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YA;F-H;W(@/2`D=F%L=64["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@*B!2971U<FYS(&9U;&P@=7)L"B`@("`J
M"B`@("`J($!R971U<FX@<W1R:6YG($9U;&P@=7)L"B`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T55),*"D*("`@('L*("`@
M("`@("`D<75E<GES=')I;F<@/2`D=&AI<RT^9V5T475E<GE3=')I;F<H*3L*
M"B`@("`@("`@)'1H:7,M/G5R;"`]("1T:&ES+3YP<F]T;V-O;"`N("<Z+R\G
M"B`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YU<V5R("X@*"%E;7!T>2@D
M=&AI<RT^<&%S<RD@/R`G.B<@.B`G)RD*("`@("`@("`@("`@("`@("`@("X@
M)'1H:7,M/G!A<W,@+B`H(65M<'1Y*"1T:&ES+3YU<V5R*2`_("=`)R`Z("<G
M*0H@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^:&]S="`N("@D=&AI<RT^
M<&]R="`]/2`G.#`G(#\@)R<@.B`G.B<@+B`D=&AI<RT^<&]R="D*("`@("`@
M("`@("`@("`@("`@("X@)'1H:7,M/G!A=&@*("`@("`@("`@("`@("`@("`@
M("X@*"%E;7!T>2@D<75E<GES=')I;F<I(#\@)S\G("X@)'%U97)Y<W1R:6YG
M(#H@)R<I"B`@("`@("`@("`@("`@("`@("`N("@A96UP='DH)'1H:7,M/F%N
M8VAO<BD@/R`G(R<@+B`D=&AI<RT^86YC:&]R(#H@)R<I.PH*("`@("`@("!R
M971U<FX@)'1H:7,M/G5R;#L*("`@('T*"B`@("`O*BH*("`@("H@061D<R!A
M('%U97)Y<W1R:6YG(&ET96T*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@
M)&YA;64@("`@("`@3F%M92!O9B!I=&5M"B`@("`J($!P87)A;2`@<W1R:6YG
M("1V86QU92`@("`@(%9A;'5E(&]F(&ET96T*("`@("H@0'!A<F%M("!B;V]L
M("`@)'!R965N8V]D960@5VAE=&AE<B!V86QU92!I<R!U<FQE;F-O9&5D(&]R
M(&YO="P@9&5F875L="`](&YO=`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9%%U97)Y4W1R:6YG*"1N86UE+"`D=F%L=64L
M("1P<F5E;F-O9&5D(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1P<F5E
M;F-O9&5D*2!["B`@("`@("`@("`@("1T:&ES+3YQ=65R>7-T<FEN9ULD;F%M
M95T@/2`D=F%L=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/G%U97)Y<W1R:6YG6R1N86UE72`](&ES7V%R<F%Y*"1V86QU92D_(&%R
M<F%Y7VUA<"@G<F%W=7)L96YC;V1E)RP@)'9A;'5E*3H@<F%W=7)L96YC;V1E
M*"1V86QU92D["B`@("`@("`@?0H@("`@?2`@("`*"B`@("`O*BH*("`@("H@
M4F5M;W9E<R!A('%U97)Y<W1R:6YG(&ET96T*("`@("H*("`@("H@0'!A<F%M
M("!S=')I;F<@)&YA;64@3F%M92!O9B!I=&5M"B`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E475E<GE3=')I;F<H)&YA
M;64I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YQ=65R>7-T<FEN
M9ULD;F%M95TI*2!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YQ=65R>7-T
M<FEN9ULD;F%M95TI.PH@("`@("`@('T*("`@('T@("`@"B`@("`*("`@("\J
M*@H@("`@*B!3971S('1H92!Q=65R>7-T<FEN9R!T;R!L:71E<F%L;'D@=VAA
M="!Y;W4@<W5P<&QY"B`@("`J"B`@("`J($!P87)A;2`@<W1R:6YG("1Q=65R
M>7-T<FEN9R!4:&4@<75E<GES=')I;F<@9&%T82X@4VAO=6QD(&)E(&]F('1H
M92!F;W)M870@9F]O/6)A<B9X/7D@971C"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J+PH@("`@9G5N8W1I;VX@861D4F%W475E<GE3=')I;F<H)'%U97)Y
M<W1R:6YG*0H@("`@>PH@("`@("`@("1T:&ES+3YQ=65R>7-T<FEN9R`]("1T
M:&ES+3Y?<&%R<V5287=1=65R>5-T<FEN9R@D<75E<GES=')I;F<I.PH@("`@
M?0H@("`@"B`@("`O*BH*("`@("H@4F5T=7)N<R!F;&%T('%U97)Y<W1R:6YG
M"B`@("`J"B`@("`J($!R971U<FX@<W1R:6YG(%%U97)Y<W1R:6YG"B`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T475E<GE3
M=')I;F<H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/G%U97)Y
M<W1R:6YG*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^<75E<GES
M=')I;F<@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1V86QU92!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<75E<GES=')I;F=;72`]("1T:&ES+3YU<V5"<F%C:V5T<R`_
M('-P<FEN=&8H)R5S6R5S73TE<R<L("1N86UE+"`D:RP@)'8I(#H@*"1N86UE
M("X@)STG("X@)'8I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T@96QS96EF("@A:7-?;G5L;"@D=F%L=64I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'%U97)Y<W1R:6YG6UT@/2`D;F%M92`N("<])R`N("1V
M86QU93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'%U97)Y<W1R:6YG6UT@/2`D;F%M93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<75E<GES=')I;F<@/2!I
M;7!L;V1E*"<F)RP@)'%U97)Y<W1R:6YG*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<75E<GES=')I;F<@/2`G)SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<75E<GES=')I;F<["B`@("!]"@H@("`@+RHJ"B`@("`J
M(%!A<G-E<R!R87<@<75E<GES=')I;F<@86YD(')E='5R;G,@86X@87)R87D@
M;V8@:70*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@("1Q=65R>7-T<FEN
M9R!4:&4@<75E<GES=')I;F<@=&\@<&%R<V4*("`@("H@0')E='5R;B!A<G)A
M>2`@("`@("`@("`@("`@("!!;B!A<G)A>2!O9B!T:&4@<75E<GES=')I;F<@
M9&%T80H@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO"B`@("!F=6YC=&EO
M;B!?<&%R<V5287=1=65R>7-T<FEN9R@D<75E<GES=')I;F<I"B`@("!["B`@
M("`@("`@)'!A<G1S("`]('!R96=?<W!L:70H)R\F+R<L("1Q=65R>7-T<FEN
M9RP@+3$L(%!214=?4U!,251?3D]?14U05%DI.PH@("`@("`@("1R971U<FX@
M/2!A<G)A>2@I.PH@("`@("`@(`H@("`@("`@(&9O<F5A8V@@*"1P87)T<R!A
M<R`D<&%R="D@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1P87)T+"`G/2<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W5B<W1R
M*"1P87)T+"!S=')P;W,H)'!A<G0L("<])RD@*R`Q*3L*("`@("`@("`@("`@
M("`@("1K97D@("`]('-U8G-T<B@D<&%R="P@,"P@<W1R<&]S*"1P87)T+"`G
M/2<I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1V
M86QU92`](&YU;&P["B`@("`@("`@("`@("`@("`D:V5Y("`@/2`D<&%R=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1K97DL("TR
M*2`]/2`G6UTG*2!["B`@("`@("`@("`@("`@("`D:V5Y(#T@<W5B<W1R*"1K
M97DL(#`L("TR*3L*("`@("`@("`@("`@("`@(&EF("A`(6ES7V%R<F%Y*"1R
M971U<FY;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)')E='5R;ELD
M:V5Y72`@(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N
M6R1K97E=6UT@/2`D=F%L=64["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1R971U<FY;)&ME>5U;72`]("1V86QU93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"$D=&AI
M<RT^=7-E0G)A8VME=',@04Y$("%E;7!T>2@D<F5T=7)N6R1K97E=*2D@>PH@
M("`@("`@("`@("`@("`@)')E='5R;ELD:V5Y72`@(#T@*&%R<F%Y*21R971U
M<FY;)&ME>5T["B`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=6UT@/2`D
M=F%L=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<F5T=7)N6R1K97E=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E='5R;CL*("`@('T*("`@(`H@("`@+RHJ
M"B`@("`J(%)E<V]L=F5S("\O+"`N+B\@86YD("XO(&9R;VT@82!P871H(&%N
M9"!R971U<FYS"B`@("`J('1H92!R97-U;'0N($5G.@H@("`@*@H@("`@*B`O
M9F]O+V)A<B\N+B]B;V\N<&AP("`@(#T^("]F;V\O8F]O+G!H<`H@("`@*B`O
M9F]O+V)A<B\N+B\N+B]B;V\N<&AP(#T^("]B;V\N<&AP"B`@("`J("]F;V\O
M8F%R+RXN+RXO+V)O;RYP:'`@/3X@+V9O;R]B;V\N<&AP"B`@("`J"B`@("`J
M(%1H:7,@;65T:&]D(&-A;B!A;'-O(&)E(&-A;&QE9"!S=&%T:6-A;&QY+@H@
M("`@*@H@("`@*B!`<&%R86T@('-T<FEN9R`D=7)L(%523"!P871H('1O(')E
M<V]L=F4*("`@("H@0')E='5R;B!S=')I;F<@("`@("!4:&4@<F5S=6QT"B`@
M("`J+PH@("`@9G5N8W1I;VX@<F5S;VQV95!A=&@H)'!A=&@I"B`@("!["B`@
M("`@("`@)'!A=&@@/2!E>'!L;V1E*"<O)RP@<W1R7W)E<&QA8V4H)R\O)RP@
M)R\G+"`D<&%T:"DI.PH@("`@("`@(`H@("`@("`@(&9O<B`H)&D],#L@)&D\
M8V]U;G0H)'!A=&@I.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@D<&%T:%LD
M:5T@/3T@)RXG*2!["B`@("`@("`@("`@("`@("!U;G-E="@D<&%T:%LD:5TI
M.PH@("`@("`@("`@("`@("`@)'!A=&@@/2!A<G)A>5]V86QU97,H)'!A=&@I
M.PH@("`@("`@("`@("`@("`@)&DM+3L*"B`@("`@("`@("`@('T@96QS96EF
M("@D<&%T:%LD:5T@/3T@)RXN)R!!3D0@*"1I(#X@,2!/4B`H)&D@/3T@,2!!
M3D0@)'!A=&A;,%T@(3T@)R<I("D@*2!["B`@("`@("`@("`@("`@("!U;G-E
M="@D<&%T:%LD:5TI.PH@("`@("`@("`@("`@("`@=6YS970H)'!A=&A;)&DM
M,5TI.PH@("`@("`@("`@("`@("`@)'!A=&@@/2!A<G)A>5]V86QU97,H)'!A
M=&@I.PH@("`@("`@("`@("`@("`@)&D@+3T@,CL*"B`@("`@("`@("`@('T@
M96QS96EF("@D<&%T:%LD:5T@/3T@)RXN)R!!3D0@)&D@/3T@,2!!3D0@)'!A
M=&A;,%T@/3T@)R<I('L*("`@("`@("`@("`@("`@('5N<V5T*"1P871H6R1I
M72D["B`@("`@("`@("`@("`@("`D<&%T:"`](&%R<F%Y7W9A;'5E<R@D<&%T
M:"D["B`@("`@("`@("`@("`@("`D:2TM.PH*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@:6UP;&]D92@G+R<L("1P871H*3L*
M("`@('T*?0H_/@H`````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O3F5T+T1)344N<&AP````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3,U,3(`,3`T,3<S-C,P,#8`
M,#$W,S(S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M#0HO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P,B!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L
M960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD
M(&ES("`@("`@("!\#0HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P-"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<G,Z(%-H86YE
M($-A<F%V96\@/'-H86YE0&-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O('P@"0D@(%)A;&8@2&]F;6%N;B`\<F%L9BYH;V9M
M86YN0'9E<F1I<V]F="YC;VT^"0D)"0D@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\-"B\O("1)9#H@1$E-12YP:'`L=B`Q+C4@,C`P
M,B\P.2\R.2`P,3HU-3HQ-B!S:&%N92!%>'`@)`T*+R\-"@T*<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<[#0HO*BH-"B`J#0H@*B`@1$E-12!%;F-O9&EN9R]$
M96-O9&EN9PT*("H-"B`J(%=H870@:7,@:70_#0H@*B`@(%1H:7,@8VQA<W,@
M96YA8FQE<R!Y;W4@=&\@;6%N:7!U;&%T92!A;F0@8G5I;&0-"B`J("`@82!$
M24U%(&5N8V%P<W5L871E9"!M97-S86=E+@T*("H-"B`J(&AT='`Z+R]W=W<N
M:65T9BYO<F<O:6YT97)N970M9')A9G1S+V1R869T+6YI96QS96XM9&EM92TP
M,BYT>'0-"B`J#0H@*B`P.2\Q."\P,B!286QF("T@($$@:'5G92!N=6UB97(@
M;V8@8VAA;F=E<R!T;R!B92!C;VUP;&EA;G0@#0H@*B`)"0D)"7=I=&@@=&AE
M($1)344@4W!E8VEF:6-A=&EO;B!296QE87-E(#$W($IU;F4@,C`P,@T*("H@
M#0H@*B!43T1/.B!L;W1S(&]F('-T=69F(&YE961S('1O(&)E('1E<W1E9"X-
M"B`J("`@("`@("`@("!$969I;FET:6QY(&AA=F4@=&\@9V\@=&AR;W5G:"!$
M24U%('-P96,@86YD#0H@*B`@("`@("`@("`@;6%K92!T:&EN9W,@=V]R:R!R
M:6=H="P@;6]S="!I;7!O<G1A;G1L>2P@<V5C(#,N,PT*("H@("`@("`@("`@
M(&UA:V4@97AA;7!L97,L(&1O8W5M96YT#0H@*@T*("H@<V5E('1E<W0O9&EM
M95]M97-A9V5?=&5S="YP:'`@9F]R(&5X86UP;&4@;V8@=7-A9V4-"B`J(`T*
M("H@0&%U=&AO<B`@4VAA;F4@0V%R879E;R`\<VAA;F5`8V%R879E;RYC;VT^
M+"`-"B`J("`@("`@("`@(%)A;&8@2&]F;6%N;B`\<F%L9BYH;V9M86YN0'9E
M<F1I<V]F="YC;VT^"2`-"B`J($!V97)S:6]N("12979I<VEO;CH@,2XU("0-
M"B`J($!P86-K86=E($YE=%]$24U%#0H@*B\-"F1E9FEN92@G3D547T1)345?
M5%E015]53D-(04Y'140G+#!X,#`I.PT*9&5F:6YE*"=.151?1$E-15]465!%
M7TU%1$E!)RPP>#`Q*3L-"F1E9FEN92@G3D547T1)345?5%E015]54DDG+#!X
M,#(I.PT*9&5F:6YE*"=.151?1$E-15]465!%7U5.2TY/5TXG+#!X,#,I.PT*
M9&5F:6YE*"=.151?1$E-15]465!%7TY/3D4G+#!X,#0I.PT*#0ID969I;F4H
M)TY%5%]$24U%7U9%4E-)3TXG+#!X,#`P,2D[#0H-"F1E9FEN92@G3D547T1)
M345?4D5#3U)$7TA%041%4B<L,3(I.PT*#0ID969I;F4H)TY%5%]$24U%7T9,
M04=3)RP@,"D[#0ID969I;F4H)TY%5%]$24U%7T]05%-?3$5.)RP@,2D[#0ID
M969I;F4H)TY%5%]$24U%7TE$7TQ%3B<L(#(I.PT*9&5F:6YE*"=.151?1$E-
M15]465!%7TQ%3B<L(#,I.PT*9&5F:6YE*"=.151?1$E-15]$051!7TQ%3B<L
M(#0I.PT*9&5F:6YE*"=.151?1$E-15]/4%13)RP@-2D[#0ID969I;F4H)TY%
M5%]$24U%7TE$)RP@-BD[#0ID969I;F4H)TY%5%]$24U%7U194$4G+"`W*3L-
M"F1E9FEN92@G3D547T1)345?1$%402<L(#@I.PT*#0IC;&%S<R!.971?1$E-
M15]296-O<F0@97AT96YD<R!014%2#0I[#0H@("`@+R\@=&AE<V4@87)E('5S
M960@=&\@:&]L9"!T:&4@<&%D9&5D(&QE;F=T:`T*("`@('9A<B`D3U!44U],
M14Y'5$@@/2`P.PT*("`@('9A<B`D241?3$5.1U1((#T@,#L-"B`@("!V87(@
M)%194$5?3$5.1U1((#T@,#L@#0H@("`@=F%R("1$051!7TQ%3D=42"`](#`[
M#0H@("`@=F%R("1?:&%V94]P=',@/2!&04Q313L-"B`@("!V87(@)%]H879E
M240@/2!&04Q313L-"B`@("!V87(@)%]H879E5'EP92`]($9!3%-%.PT*("`@
M('9A<B`D7VAA=F5$871A(#T@1D%,4T4[#0H@("`@=F%R("1D96)U9R`]($9!
M3%-%.PT*("`@('9A<B`D<&%D<W1R(#T@(EPP(CL-"B`@("`O*BH-"B`@("`@
M*B!%;&5M96YT<PT*("`@("`J(%M.151?1$E-15]&3$%'4UTL("`@(#$V(&)I
M=',Z(%9%4E-)3TXZ34(Z344Z0T8Z5%E015]4#0H@("`@("H@6TY%5%]$24U%
M7T]05%-?3$5.72P@,38@8FET<SH@3U!424].4U],14Y'5$@-"B`@("`@*B!;
M3D547T1)345?241?3$5.72P@("`Q-B!B:71S.B!)1%],14Y'5$@-"B`@("`@
M*B!;3D547T1)345?5%E015],14Y=+"`Q-B!B:71S.B!465!%7TQ%3D=42`T*
M("`@("`J(%M.151?1$E-15]$051!7TQ%3ETL(#,R(&)I=',Z($1!5$%?3$5.
M1U1(#0H)("H@6TY%5%]$24U%7T]05%-=("`@("`@("`@("`@(#H@3U!424].
M4PT*"2`J(%M.151?1$E-15])1%T@("`@(`D)("`@.B!)1`T*"2`J(%M.151?
M1$E-15]465!%72`@("`@("`@("`@("`Z(%194$4-"@D@*B!;3D547T1)345?
M1$%405T@("`@("`@("`@("`@.B!$051!#0H@("`@("HO#0H@("`@=F%R("1%
M;&5M96YT<R`](&%R<F%Y*$Y%5%]$24U%7T9,04=3(#T^(#`L("!.151?1$E-
M15]/4%137TQ%3B`]/B`P+"`-"@D@("`@("`@("`@("`@("`@("`@("`@3D54
M7T1)345?241?3$5.(#T^(#`L($Y%5%]$24U%7U194$5?3$5.(#T^(#`L(`T*
M("`@("`)"0D)"2`@3D547T1)345?1$%405],14X@/3X@,"P-"@D@"0D)"0D@
M($Y%5%]$24U%7T]05%,@/3X@)R<L#0H)"0D)"0D@($Y%5%]$24U%7TE$(#T^
M("<G+`T*"0D)"0D)("!.151?1$E-15]465!%(#T^("<G+`T*"0D)"0D)("!.
M151?1$E-15]$051!(#T^("<G*3L-"B`@("`-"B`@("!F=6YC=&EO;B!.971?
M1$E-15]296-O<F0H)&1E8G5G(#T@1D%,4T4I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^9&5B=6<@/2`D9&5B=6<[#0H@("`@("`@(&EF("@D9&5B=6<I("1T
M:&ES+3YP861S='(@/2`G*B<[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M34(H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%
M7T9,04=372!\/2`P>#`T,#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M344H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%
M7T9,04=372!\/2`P>#`R,#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M0T8H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%
M7T9,04=372!\/2`P>#`Q,#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-#
M:'5N:R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/D5L96UE;G1S
M6TY%5%]$24U%7T9,04=372`F(#!X,#$P,#L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!I<T5N9"@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/D5L
M96UE;G1S6TY%5%]$24U%7T9,04=372`F(#!X,#(P,#L-"B`@("!]#0H@("`@
M#0H@("`@9G5N8W1I;VX@:7-3=&%R="@I#0H@("`@>PT*("`@("`@("!R971U
M<FX@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T9,04=372`F(#!X,#0P,#L-
M"B`@("!]#0H@("`@#0H@("`@9G5N8W1I;VX@9V5T240H*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y%;&5M96YT<UM.151?1$E-15])1%T[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T5'EP92@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7U194$5=.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=$1A=&$H*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y%;&5M96YT<UM.151?1$E-15]$051!73L-"B`@("!]
M#0H@("`@#0H@("`@9G5N8W1I;VX@9V5T1&%T84QE;F=T:"@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T1!5$%?
M3$5.73L-"B`@("!]#0H@("`@#0H@("`@9G5N8W1I;VX@<V5T5'EP92@D='EP
M97-T<FEN9RP@)'1Y<&4]3D547T1)345?5%E015]53DM.3U=.*0T*("`@('L-
M"B`@("`@("`@)'1Y<&5L96X@/2!S=')L96XH)'1Y<&5S=')I;F<I("8@,'A&
M1D9&.PT*("`@("`@("`D='EP92`]("1T>7!E(#P\(#0[#0H@("`@("`@("1T
M:&ES+3Y%;&5M96YT<UM.151?1$E-15]&3$%'4UT@/2`H)'1H:7,M/D5L96UE
M;G1S6TY%5%]$24U%7T9,04=372`F(#!X1D8P1BD@?"`D='EP93L-"B`@("`@
M("`@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7U194$5?3$5.72`]("1T>7!E
M;&5N.PT*("`@("`@("`D=&AI<RT^5%E015],14Y'5$@@/2`D=&AI<RT^7V=E
M=%!A9$QE;F=T:"@D='EP96QE;BD[#0H@("`@("`@("1T:&ES+3Y%;&5M96YT
M<UM.151?1$E-15]465!%72`]("1T>7!E<W1R:6YG.PT*("`@('T-"B`@("`-
M"B`@("!F=6YC=&EO;B!G96YE<F%T94E$*"D-"B`@("![#0H@("`@("`@("1I
M9"`](&UD-2AT:6UE*"DI.PT*("`@("`@("`D=&AI<RT^<V5T240H)&ED*3L-
M"B`@("`@("`@<F5T=7)N("1I9#L-"B`@("!]#0H@("`@#0H@("`@9G5N8W1I
M;VX@<V5T240H)&ED*0T*("`@('L-"B`@("`@("`@)&ED;&5N(#T@<W1R;&5N
M*"1I9"D@)B`P>$9&1D8[#0H@("`@("`@("1T:&ES+3Y%;&5M96YT<UM.151?
M1$E-15])1%],14Y=(#T@)&ED;&5N.PT*("`@("`@("`D=&AI<RT^241?3$5.
M1U1((#T@)'1H:7,M/E]G9710861,96YG=&@H)&ED;&5N*3L-"B`@("`@("`@
M)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7TE$72`]("1I9#L-"B`@("!]#0H@
M("`@#0H@("`@9G5N8W1I;VX@<V5T1&%T82@D9&%T82P@)'-I>F4],"D-"B`@
M("![#0H@("`@("`@("1D871A;&5N(#T@)'-I>F4_)'-I>F4Z<W1R;&5N*"1D
M871A*3L-"B`@("`@("`@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T1!5$%?
M3$5.72`]("1D871A;&5N.PT*("`@("`@("`D=&AI<RT^1$%405],14Y'5$@@
M/2`D=&AI<RT^7V=E=%!A9$QE;F=T:"@D9&%T86QE;BD[#0H@("`@("`@("1T
M:&ES+3Y%;&5M96YT<UM.151?1$E-15]$051!72`]("1D871A.PT*("`@('T-
M"B`@("`-"B`@("!F=6YC=&EO;B!E;F-O9&4H*0T*("`@('L-"@D)+R\@:6YS
M97)T('9E<G-I;VX@#0H)("`@("1T:&ES+3Y%;&5M96YT<UM.151?1$E-15]&
M3$%'4UT@/2`H)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T9,04=372`F(#!X
M,#=&1BD@?"`H3D547T1)345?5D524TE/3B`\/"`Q,2D[#0H-"B`@("`@("`@
M+R\@=&AE(')E86P@9&EM92!E;F-O9&EN9PT*("`@("`@("`D9F]R;6%T(#T@
M("`G)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)RX-"B`@("`@("`@("`@("`@
M("`@("`@)R4G+B1T:&ES+3Y/4%137TQ%3D=42"XG<R<N#0H@("`@("`@("`@
M("`@("`@("`@("<E)RXD=&AI<RT^241?3$5.1U1(+B=S)RX-"B`@("`@("`@
M("`@("`@("`@("`@)R4G+B1T:&ES+3Y465!%7TQ%3D=42"XG<R<N#0H@("`@
M("`@("`@("`@("`@("`@("<E)RXD=&AI<RT^1$%405],14Y'5$@N)W,G.PT*
M("`@("`@("!R971U<FX@<W!R:6YT9B@D9F]R;6%T+`T*"2`@("`@("`@("`@
M("`@("`@("`H)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T9,04=3728P>#`P
M,#!&1C`P*3X^."P-"B`@("`)("`@("`@("`@("`@("`@*"1T:&ES+3Y%;&5M
M96YT<UM.151?1$E-15]&3$%'4UTF,'@P,#`P,#!&1BDL#0H@("`@("`@(`D@
M("`@("`@("`@("@D=&AI<RT^16QE;65N='-;3D547T1)345?3U!44U],14Y=
M)C!X,#`P,$9&,#`I/CXX+`T*("`@("`@("`@("`@"2`@("`@("`H)'1H:7,M
M/D5L96UE;G1S6TY%5%]$24U%7T]05%-?3$5.728P>#`P,#`P,$9&*2P-"B`@
M("`@("`@"2`@("`@("`@("`@*"1T:&ES+3Y%;&5M96YT<UM.151?1$E-15])
M1%],14Y=)C!X,#`P,$9&,#`I/CXX+`T*("`@("`@("`@("`@"2`@("`@("`H
M)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7TE$7TQ%3ETF,'@P,#`P,#!&1BDL
M#0H@("`@("`@(`D@("`@("`@("`@("@D=&AI<RT^16QE;65N='-;3D547T1)
M345?5%E015],14Y=)C!X,#`P,$9&,#`I/CXX+`T*("`@("`@("`@("`@"2`@
M("`@("`H)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7U194$5?3$5.728P>#`P
M,#`P,$9&*2P-"B`@("`@("`@("`@("`@("`)("`@*"1T:&ES+3Y%;&5M96YT
M<UM.151?1$E-15]$051!7TQ%3ETF,'A&1C`P,#`P,"D^/C(T+`T*"2`@("`@
M("`@("`@("`@("`@("`H)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T1!5$%?
M3$5.728P>#`P1D8P,#`P*3X^,38L#0H@("`@"2`@("`@("`@("`@("`@("@D
M=&AI<RT^16QE;65N='-;3D547T1)345?1$%405],14Y=)C!X,#`P,$9&,#`I
M/CXX+`T*("`@("`@("`)("`@("`@("`@("`H)'1H:7,M/D5L96UE;G1S6TY%
M5%]$24U%7T1!5$%?3$5.728P>#`P,#`P,$9&*2P-"B`@("`@("`@("`@(`D@
M("`@("`@<W1R7W!A9"@D=&AI<RT^16QE;65N='-;3D547T1)345?3U!44UTL
M("1T:&ES+3Y/4%137TQ%3D=42"P@)'1H:7,M/G!A9'-T<BDL#0H@("`@("`@
M("`@("`)("`@("`@('-T<E]P860H)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%
M7TE$72P@)'1H:7,M/DE$7TQ%3D=42"P@)'1H:7,M/G!A9'-T<BDL#0H@("`@
M("`@("`@("`@("`@"2`@('-T<E]P860H)'1H:7,M/D5L96UE;G1S6TY%5%]$
M24U%7U194$5=+"`D=&AI<RT^5%E015],14Y'5$@L("1T:&ES+3YP861S='(I
M+`T*"2`@("`@("`@("`@("`@("`@("!S=')?<&%D*"1T:&ES+3Y%;&5M96YT
M<UM.151?1$E-15]$051!72P@)'1H:7,M/D1!5$%?3$5.1U1(+"`D=&AI<RT^
M<&%D<W1R*2D[#0H@("`@?0T*("`@(`T*("`@(&9U;F-T:6]N(%]G9710861,
M96YG=&@H)&QE;BD-"B`@("![#0H@("`@("`@("1P860@/2`P.PT*("`@("`@
M("!I9B`H)&QE;BD@>PT*("`@("`@("`@("`@)'!A9"`]("1L96X@)2`T.PT*
M("`@("`@("`@("`@:68@*"1P860I("1P860@/2`T("T@)'!A9#L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)&QE;B`K("1P860[#0H@("`@?0T*("`@
M(`T*("`@(&9U;F-T:6]N(&1E8V]D92@F)&1A=&$I#0H@("`@>PT*("`@("`@
M("`O+R!214%,($1)344@9&5C;V1I;F<-"B`@("`@("`@)'1H:7,M/D5L96UE
M;G1S6TY%5%]$24U%7T9,04=372`@("`]("AH97AD96,H8FEN,FAE>"@D9&%T
M85LP72DI/#PX*2`K(&AE>&1E8RAB:6XR:&5X*"1D871A6S%=*2D[#0H@("`@
M("`@("1T:&ES+3Y%;&5M96YT<UM.151?1$E-15]/4%137TQ%3ET@/2`H:&5X
M9&5C*&)I;C)H97@H)&1A=&%;,ETI*3P\."D@*R!H97AD96,H8FEN,FAE>"@D
M9&%T85LS72DI.PT*("`@("`@("`D=&AI<RT^16QE;65N='-;3D547T1)345?
M241?3$5.72`@(#T@*&AE>&1E8RAB:6XR:&5X*"1D871A6S1=*2D\/#@I("L@
M:&5X9&5C*&)I;C)H97@H)&1A=&%;-5TI*3L-"B`@("`@("`@)'1H:7,M/D5L
M96UE;G1S6TY%5%]$24U%7U194$5?3$5.72`]("AH97AD96,H8FEN,FAE>"@D
M9&%T85LV72DI/#PX*2`K(&AE>&1E8RAB:6XR:&5X*"1D871A6S==*2D[#0H@
M("`@("`@("1T:&ES+3Y%;&5M96YT<UM.151?1$E-15]$051!7TQ%3ET@/2`H
M:&5X9&5C*&)I;C)H97@H)&1A=&%;.%TI*3P\,C0I("L-"@D)("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H:&5X9&5C*&)I;C)H97@H)&1A=&%;.5TI
M*3P\,38I("L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H:&5X9&5C*&)I;C)H97@H)&1A=&%;,3!=*2D\/#@I("L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:&5X9&5C*&)I;C)H97@H
M)&1A=&%;,3%=*2D[#0H@("`@("`@("1P(#T@,3([#0H)"0T*"0DD=F5R<VEO
M;B`]("@H)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T9,04=373X^,3$I("8@
M,'@P,#%&*3L-"@D)#0H)"6EF("@D=F5R<VEO;B`]/2!.151?1$E-15]615)3
M24].*2`-"@D)>PT*"2`@("`@("`@)'1H:7,M/D]05%-?3$5.1U1((#T@)'1H
M:7,M/E]G9710861,96YG=&@H)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T]0
M5%-?3$5.72D[("`@("`@("`-"@D@("`@("`@("1T:&ES+3Y)1%],14Y'5$@@
M/2`D=&AI<RT^7V=E=%!A9$QE;F=T:"@D=&AI<RT^16QE;65N='-;3D547T1)
M345?241?3$5.72D[#0H)("`@("`@("`D=&AI<RT^5%E015],14Y'5$@@/2`D
M=&AI<RT^7V=E=%!A9$QE;F=T:"@D=&AI<RT^16QE;65N='-;3D547T1)345?
M5%E015],14Y=*3L-"@D@("`@("`@("1T:&ES+3Y$051!7TQ%3D=42"`]("1T
M:&ES+3Y?9V5T4&%D3&5N9W1H*"1T:&ES+3Y%;&5M96YT<UM.151?1$E-15]$
M051!7TQ%3ETI.PT*"2`@("`@("`@("`@("`@("`-"@D@("`@("`@("1D871A
M;&5N(#T@<W1R;&5N*"1D871A*3L-"@D@("`@("`@("1T:&ES+3Y%;&5M96YT
M<UM.151?1$E-15]/4%1372`]('-U8G-T<B@D9&%T82PD<"PD=&AI<RT^16QE
M;65N='-;3D547T1)345?3U!44U],14Y=*3L-"@D@("`@("`@("1T:&ES+3Y?
M:&%V94]P=',@/2`H<W1R;&5N*"1T:&ES+3Y%;&5M96YT<UM.151?1$E-15]/
M4%1372D@/3T@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7T]05%-?3$5.72D[
M#0H)("`@("`@("!I9B`H)'1H:7,M/E]H879E3W!T<RD@>PT*"2`@("`@("`@
M("`@("1P("L]("1T:&ES+3Y/4%137TQ%3D=42#L)"0T*"0D@("`@("`@("1T
M:&ES+3Y%;&5M96YT<UM.151?1$E-15])1%T@/2!S=6)S='(H)&1A=&$L)'`L
M)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7TE$7TQ%3ETI.PT*"0D@("`@("`@
M("1T:&ES+3Y?:&%V94E$(#T@*'-T<FQE;B@D=&AI<RT^16QE;65N='-;3D54
M7T1)345?241=*2`]/2`D=&AI<RT^16QE;65N='-;3D547T1)345?241?3$5.
M72D[#0H)"2`@("`@("`@:68@*"1T:&ES+3Y?:&%V94E$*2![#0H)"2`@("`@
M("`@("`@("1P("L]("1T:&ES+3Y)1%],14Y'5$@[#0H)"2`@("`@("`@("`@
M("1T:&ES+3Y%;&5M96YT<UM.151?1$E-15]465!%72`]('-U8G-T<B@D9&%T
M82PD<"PD=&AI<RT^16QE;65N='-;3D547T1)345?5%E015],14Y=*3L-"@D)
M("`@("`@("`@("`@)'1H:7,M/E]H879E5'EP92`]("AS=')L96XH)'1H:7,M
M/D5L96UE;G1S6TY%5%]$24U%7U194$5=*2`]/2`D=&AI<RT^16QE;65N='-;
M3D547T1)345?5%E015],14Y=*3L-"@D)("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?:&%V951Y<&4I('L-"@D)("`@("`@("`@("`@("`@("1P("L]("1T:&ES
M+3Y465!%7TQ%3D=42#L-"@D)("`@("`@("`@("`@("`@("1T:&ES+3Y%;&5M
M96YT<UM.151?1$E-15]$051!72`]('-U8G-T<B@D9&%T82PD<"PD=&AI<RT^
M16QE;65N='-;3D547T1)345?1$%405],14Y=*3L-"@D)("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:&%V941A=&$@/2`H<W1R;&5N*"1T:&ES+3Y%;&5M96YT
M<UM.151?1$E-15]$051!72D@/3T@)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%
M7T1!5$%?3$5.72D[#0H)"2`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]H
M879E1&%T82D@>PT*"0D@("`@("`@("`@("`@("`@("`@("1P("L]("1T:&ES
M+3Y$051!7TQ%3D=42#L-"@D)("`@("`@("`@("`@("`@('T@96QS92![#0H)
M"2`@("`@("`@("`@("`@("`@("`@)'`@*ST@<W1R;&5N*"1T:&ES+3Y%;&5M
M96YT<UM.151?1$E-15]$051!72D[#0H)"2`@("`@("`@("`@("`@("!]#0H)
M"2`@("`@("`@("`@('T@96QS92![#0H)"2`@("`@("`@("`@("`@("`D<"`K
M/2!S=')L96XH)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%7U194$5=*3L-"@D)
M"0D)?0T*"0D@("`@("`@('T@96QS92![#0H)"2`@("`@("`@("`@("1P("L]
M('-T<FQE;B@D=&AI<RT^16QE;65N='-;3D547T1)345?241=*3L-"@D)"0E]
M#0H)"2`@("!](&5L<V4@>PT*"0D@("`@"21P("L]('-T<FQE;B@D=&AI<RT^
M16QE;65N='-;3D547T1)345?3U!44UTI.PD)"0D)#0H)("`@("`@("!]#0H)
M"7T-"B`@("`@("`@<F5T=7)N('-U8G-T<B@D9&%T82P@)'`I.PT*("`@('T-
M"B`@("`-"B`@("!F=6YC=&EO;B!A9&1$871A*"8D9&%T82D-"B`@("![#0H@
M("`@("`@("1D871A;&5N(#T@<W1R;&5N*"1D871A*3L-"B`@("`@("`@)'`@
M/2`P.PT*("`@("`@("!I9B`H(21T:&ES+3Y?:&%V94]P=',I('L-"B`@("`@
M("`@("`@("1H879E(#T@<W1R;&5N*"1T:&ES+3Y%;&5M96YT<UM.151?1$E-
M15]/4%1372D[#0H@("`@("`@("`@("`D=&AI<RT^16QE;65N='-;3D547T1)
M345?3U!44UT@+CT@<W5B<W1R*"1D871A+"1P+"1T:&ES+3Y%;&5M96YT<UM.
M151?1$E-15]/4%137TQ%3ETM)&AA=F4I.PT*("`@("`@("`@("`@)'1H:7,M
M/E]H879E3W!T<R`]("AS=')L96XH)'1H:7,M/D5L96UE;G1S6TY%5%]$24U%
M7T]05%-=*2`]/2`D=&AI<RT^16QE;65N='-;1$E-15]/5%!37TQ%3ETI.PT*
M("`@("`@("`@("`@:68@*"$D=&AI<RT^7VAA=F5/<'1S*2!R971U<FX@3E5,
M3#L-"B`@("`@("`@("`@("1P("L]("1T:&ES+3Y/4%137TQ%3D=42"TD:&%V
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3Y?:&%V94E$*2![
M#0H@("`@("`@("`@("`D:&%V92`]('-T<FQE;B@D=&AI<RT^16QE;65N='-;
M3D547T1)345?241=*3L-"B`@("`@("`@("`@("1T:&ES+3Y%;&5M96YT<UM.
M151?1$E-15])1%T@+CT@<W5B<W1R*"1D871A+"1P+"1T:&ES+3Y%;&5M96YT
M<UM.151?1$E-15])1%],14Y=+21H879E*3L-"B`@("`@("`@("`@("1T:&ES
M+3Y?:&%V94E$(#T@*'-T<FQE;B@D=&AI<RT^16QE;65N='-;3D547T1)345?
M241=*2`]/2`D=&AI<RT^16QE;65N='-;3D547T1)345?241?3$5.72D[#0H@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?:&%V94E$*2!R971U<FX@3E5,3#L-
M"B`@("`@("`@("`@("1P("L]("1T:&ES+3Y)1%],14Y'5$@M)&AA=F4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"$D=&AI<RT^7VAA=F54>7!E("8F("1P
M(#P@)&1A=&%L96XI('L-"B`@("`@("`@("`@("1H879E(#T@<W1R;&5N*"1T
M:&ES+3Y%;&5M96YT<UM.151?1$E-15]465!%72D[#0H@("`@("`@("`@("`D
M=&AI<RT^16QE;65N='-;3D547T1)345?5%E015T@+CT@<W5B<W1R*"1D871A
M+"1P+"1T:&ES+3Y%;&5M96YT<UM.151?1$E-15]465!%7TQ%3ETM)&AA=F4I
M.PT*("`@("`@("`@("`@)'1H:7,M/E]H879E5'EP92`]("AS=')L96XH)'1H
M:7,M/D5L96UE;G1S6TY%5%]$24U%7U194$5=*2`]/2`D=&AI<RT^16QE;65N
M='-;3D547T1)345?5%E015],14Y=*3L-"B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/E]H879E5'EP92D@<F5T=7)N($Y53$P[#0H@("`@("`@("`@("`D<"`K
M/2`D=&AI<RT^5%E015],14Y'5$@M)&AA=F4[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"$D=&AI<RT^7VAA=F5$871A("8F("1P(#P@)&1A=&%L96XI('L-
M"B`@("`@("`@("`@("1H879E(#T@<W1R;&5N*"1T:&ES+3Y%;&5M96YT<UM.
M151?1$E-15]$051!72D[#0H@("`@("`@("`@("`D=&AI<RT^16QE;65N='-;
M3D547T1)345?1$%405T@+CT@<W5B<W1R*"1D871A+"1P+"1T:&ES+3Y%;&5M
M96YT<UM.151?1$E-15]$051!7TQ%3ETM)&AA=F4I.PT*("`@("`@("`@("`@
M)'1H:7,M/E]H879E1&%T82`]("AS=')L96XH)'1H:7,M/D5L96UE;G1S6TY%
M5%]$24U%7T1!5$%=*2`]/2`D=&AI<RT^16QE;65N='-;3D547T1)345?1$%4
M05],14Y=*3L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]H879E1&%T82D@
M<F5T=7)N($Y53$P[#0H@("`@("`@("`@("`D<"`K/2`D=&AI<RT^1$%405],
M14Y'5$@M)&AA=F4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('-U8G-T
M<B@D9&%T82PD<"D[#0H@("`@?2`@(`T*?0T*#0H-"F-L87-S($YE=%]$24U%
M7TUE<W-A9V4@97AT96YD<R!014%2#0I[#0H-"B`@("!V87(@)')E8V]R9%]S
M:7IE(#T@-#`Y-CL-"B`@("`C=F%R("1R96-O<F1S(#UA<G)A>2@I.PT*("`@
M('9A<B`D<&%R=',@/2!A<G)A>2@I.PT*("`@('9A<B`D8W5R<F5N=%!A<G0@
M/2`M,3L-"B`@("!V87(@)'-T<F5A;2`]($Y53$P[#0H@("`@=F%R("1?8W5R
M<F5N=%)E8V]R9#L-"B`@("!V87(@)%]P<F]C(#T@87)R87DH*3L-"B`@("!V
M87(@)'1Y<&4[#0H@("`@=F%R("1T>7!E<W1R.PT*("`@('9A<B`D;6(@/2`Q
M.PT*("`@('9A<B`D;64@/2`P.PT*("`@('9A<B`D8V8@/2`P.PT*("`@('9A
M<B`D:60@/2!.54Q,.PT*("`@('9A<B`D9&5B=6<@/2!&04Q313L-"B`@("`O
M*BH-"B`@("`@*B!C;VYS=')U8W1O<@T*("`@("`J#0H@("`@("H@=&AI<R!C
M=7)R96YT;'D@=&%K97,@82!F:6QE('!O:6YT97(@87,@<')O=FED960-"B`@
M("`@*B!B>2!F;W!E;@T*("`@("`J#0H@("`@("H@5$]$3SH@:6YT96=R871E
M('=I=&@@=&AE('!H<"!S=')E86US('-T=69F#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@3F5T7T1)345?365S<V%G92@D<W1R96%M/4Y53$PL("1R96-O<F1?
M<VEZ92`](#0P.38L("1D96)U9R`]($9!3%-%*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/G-T<F5A;2`]("1S=')E86T[#0H@("`@("`@("1T:&ES+3YR96-O
M<F1?<VEZ92`]("1R96-O<F1?<VEZ93L-"B`@("`@("`@)'1H:7,M/F1E8G5G
M(#T@)&1E8G5G.PT*("`@('T-"B`@("`-"B`@("!F=6YC=&EO;B!?;6%K95)E
M8V]R9"@F)&1A=&$L("1T>7!E<W1R/2<G+"`D:60]3E5,3"P@)'1Y<&4]3D54
M7T1)345?5%E015]53DM.3U=.*0T*("`@('L-"B`@("`@("`@)')E8V]R9"`]
M(&YE=R!.971?1$E-15]296-O<F0H)'1H:7,M/F1E8G5G*3L-"B`@("`@("`@
M:68@*"1T:&ES+3YM8BD@>PT*("`@("`@("`@("`@)')E8V]R9"T^<V5T34(H
M*3L-"B`@("`@("`@("`@("\O(&%L;"!S=6)S97%U96YT(')E8V]R9',@87)E
M(&YO="!M97-S86=E(&)E9VEN(0T*("`@("`@("`@("`@)'1H:7,M/FUB(#T@
M,#L@#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YM92D@)')E8V]R
M9"T^<V5T344H*3L-"B`@("`@("`@:68@*"1T:&ES+3YC9BD@)')E8V]R9"T^
M<V5T0T8H*3L-"B`@("`@("`@)')E8V]R9"T^<V5T1&%T82@D9&%T82D[#0H@
M("`@("`@("1R96-O<F0M/G-E=%1Y<&4H)'1Y<&5S='(L)'1Y<&4I.PT*("`@
M("`@("!I9B`H)&ED*2`D<F5C;W)D+3YS971)1"@D:60I.PT*("`@("`@("`C
M:68@*"1T:&ES+3YD96)U9RD@>PT*("`@("`@("`C("`@('!R:6YT('-T<E]R
M97!L86-E*"=<,"<L)RHG+"1R96-O<F0M/F5N8V]D92@I*3L-"B`@("`@("`@
M(WT-"B`@("`@("`@<F5T=7)N("1R96-O<F0M/F5N8V]D92@I.PT*("`@('T-
M"B`@("`-"B`@("!F=6YC=&EO;B!S=&%R=$-H=6YK*"8D9&%T82P@)'1Y<&5S
M='(])R<L("1I9#U.54Q,+"`D='EP93U.151?1$E-15]465!%7U5.2TY/5TXI
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^;64@/2`P.PT*("`@("`@("`D=&AI
M<RT^8V8@/2`Q.PT*("`@("`@("`D=&AI<RT^='EP92`]("1T>7!E.PT*("`@
M("`@("`D=&AI<RT^='EP97-T<B`]("1T>7!E<W1R.PT*("`@("`@("!I9B`H
M)&ED*2![#0H@("`@("`@("`@("`D=&AI<RT^:60@/2`D:60[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^:60@/2!M9#4H=&EM92@I
M*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]M86ME4F5C
M;W)D*"1D871A+"`D=&AI<RT^='EP97-T<BP@)'1H:7,M/FED+"`D=&AI<RT^
M='EP92D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&]#:'5N:R@F)&1A=&$I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^;64@/2`P.PT*("`@("`@("`D=&AI
M<RT^8V8@/2`Q.PT*("`@("`@("!R971U<FX@)'1H:7,M/E]M86ME4F5C;W)D
M*"1D871A+"!.54Q,+"!.54Q,+"!.151?1$E-15]465!%7U5.0TA!3D=%1"D[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@96YD0VAU;FLH*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/F-F(#T@,#L-"B`@("`@("`@)&1A=&$@/2!.54Q,.PT*
M("`@("`@("`D<F5C(#T@)'1H:7,M/E]M86ME4F5C;W)D*"1D871A+"!.54Q,
M+"!.54Q,+"!.151?1$E-15]465!%7U5.0TA!3D=%1"D[#0H@("`@("`@("1T
M:&ES+3YI9"`](#`[#0H@("`@("`@("1T:&ES+3YC9B`](#`[#0H@("`@("`@
M("1T:&ES+3YI9"`](#`[#0H@("`@("`@("1T:&ES+3YT>7!E(#T@3D547T1)
M345?5%E015]53DM.3U=..PT*("`@("`@("`D=&AI<RT^='EP97-T<B`]($Y5
M3$P[#0H@("`@("`@(')E='5R;B`D<F5C.PT*("`@('T-"B`@("`-"B`@("!F
M=6YC=&EO;B!E;F1-97-S86=E*"D-"B`@("![#0H@("`@("`@("1T:&ES+3YM
M92`](#$[#0H@("`@("`@("1D871A(#T@3E5,3#L-"B`@("`@("`@)')E8R`]
M("1T:&ES+3Y?;6%K95)E8V]R9"@D9&%T82P@3E5,3"P@3E5,3"P@3D547T1)
M345?5%E015].3TY%*3L-"B`@("`@("`@)'1H:7,M/FUE(#T@,#L-"B`@("`@
M("`@)'1H:7,M/FUB(#T@,3L-"B`@("`@("`@)'1H:7,M/FED(#T@,#L-"B`@
M("`@("`@<F5T=7)N("1R96,[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@
M("`J('-E;F1296-O<F0-"B`@("`@*@T*("`@("`J(&=I=F5N(&$@8VAU;FL@
M;V8@9&%T82P@:70@8W)E871E<R!$24U%(')E8V]R9',-"B`@("`@*B!A;F0@
M=W)I=&5S('1H96T@=&\@=&AE('-T<F5A;0T*("`@("`J#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@<V5N9$1A=&$H)B1D871A+"`D='EP97-T<CTG)RP@)&ED
M/4Y53$PL("1T>7!E/4Y%5%]$24U%7U194$5?54Y+3D]73BD-"B`@("![#0H@
M("`@("`@("1L96X@/2!S=')L96XH)&1A=&$I.PT*("`@("`@("!I9B`H)&QE
M;B`^("1T:&ES+3YR96-O<F1?<VEZ92D@>PT*("`@("`@("`@("`@)&-H=6YK
M(#T@<W5B<W1R*"1D871A+"`P+"`D=&AI<RT^<F5C;W)D7W-I>F4I.PT*("`@
M("`@("`@("`@)'`@/2`D=&AI<RT^<F5C;W)D7W-I>F4[#0H@("`@("`@("`@
M("`D<F5C(#T@)'1H:7,M/G-T87)T0VAU;FLH)&-H=6YK+"1T>7!E<W1R+"1I
M9"PD='EP92D[#0H@("`@("`@("`@("!F=W)I=&4H)'1H:7,M/G-T<F5A;2P@
M)')E8RD[#0H@("`@("`@("`@("!W:&EL92`H)'`@/"`D;&5N*2![#0H@("`@
M("`@("`@("`@("`@)&-H=6YK(#T@<W5B<W1R*"1D871A+"`D<"P@)'1H:7,M
M/G)E8V]R9%]S:7IE*3L-"B`@("`@("`@("`@("`@("`D<"`K/2`D=&AI<RT^
M<F5C;W)D7W-I>F4[#0H@("`@("`@("`@("`@("`@)')E8R`]("1T:&ES+3YD
M;T-H=6YK*"1C:'5N:RD[#0H@("`@("`@("`@("`@("`@9G=R:71E*"1T:&ES
M+3YS=')E86TL("1R96,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)')E8R`]("1T:&ES+3YE;F1#:'5N:R@I.PT*("`@("`@("`@("`@9G=R:71E
M*"1T:&ES+3YS=')E86TL("1R96,I.PT*("`@("`@("`@("`@<F5T=7)N.PT*
M("`@("`@("!]#0H@("`@("`@("1R96,@/2`D=&AI<RT^7VUA:V5296-O<F0H
M)&1A=&$L("1T>7!E<W1R+"1I9"PD='EP92D[#0H@("`@("`@(&9W<FET92@D
M=&AI<RT^<W1R96%M+"`D<F5C*3L-"B`@("!]#0H@("`@#0H@("`@9G5N8W1I
M;VX@<V5N9$5N9$UE<W-A9V4H*0T*("`@('L-"B`@("`@("`@)')E8R`]("1T
M:&ES+3YE;F1-97-S86=E*"D[#0H@("`@("`@(&9W<FET92@D=&AI<RT^<W1R
M96%M+"`D<F5C*3L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@<V5N
M9$9I;&4-"B`@("`@*@T*("`@("`J(&=I=F5N(&$@9FEL96YA;64L(&ET(')E
M861S('1H92!F:6QE+`T*("`@("`J(&-R96%T97,@<F5C;W)D<R!A;F0@=W)I
M=&5S('1H96T@=&\@=&AE('-T<F5A;0T*("`@("`J#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<V5N9$9I;&4H)&9I;&5N86UE+"`D='EP97-T<CTG)RP@)&ED
M/4Y53$PL("1T>7!E/4Y%5%]$24U%7U194$5?54Y+3D]73BD-"B`@("![#0H@
M("`@("`@("1F(#T@9F]P96XH)&9I;&5N86UE+"`B<F(B*3L-"B`@("`@("`@
M:68@*"1F*2![#0H@("`@("`@("`@("!I9B`H)&1A=&$@/2!F<F5A9"@D9BP@
M)'1H:7,M/G)E8V]R9%]S:7IE*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3YS=&%R=$-H=6YK*"1D871A+"1T>7!E<W1R+"1I9"PD='EP92D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!W:&EL92`H)&1A=&$@/2!F<F5A9"@D
M9BP@)'1H:7,M/G)E8V]R9%]S:7IE*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3YD;T-H=6YK*"1D871A+"1T>7!E<W1R+"1I9"PD='EP92D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^96YD0VAU;FLH*3L-"B`@
M("`@("`@("`@(&9C;&]S92@D9BD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!E;F-O9&5$871A#0H@("`@("H-"B`@("`@*B!G:79E
M;B!D871A+"!E;F-O9&4@:70@:6X@1$E-10T*("`@("`J#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@96YC;V1E1&%T82@D9&%T82P@)'1Y<&5S='(])R<L("1I
M9#U.54Q,+"`D='EP93U.151?1$E-15]465!%7U5.2TY/5TXI#0H@("`@>PT*
M("`@("`@("`D;&5N(#T@<W1R;&5N*"1D871A*3L-"B`@("`@("`@)')E<W`@
M/2`G)SL-"B`@("`@("`@:68@*"1L96X@/B`D=&AI<RT^<F5C;W)D7W-I>F4I
M('L-"B`@("`@("`@("`@("1C:'5N:R`]('-U8G-T<B@D9&%T82P@,"P@)'1H
M:7,M/G)E8V]R9%]S:7IE*3L-"B`@("`@("`@("`@("1P(#T@)'1H:7,M/G)E
M8V]R9%]S:7IE.PT*("`@("`@("`@("`@)')E<W`@+CT@)'1H:7,M/G-T87)T
M0VAU;FLH)&-H=6YK+"1T>7!E<W1R+"1I9"PD='EP92D[#0H@("`@("`@("`@
M("!W:&EL92`H)'`@/"`D;&5N*2![#0H@("`@("`@("`@("`@("`@)&-H=6YK
M(#T@<W5B<W1R*"1D871A+"`D<"P@)'1H:7,M/G)E8V]R9%]S:7IE*3L-"B`@
M("`@("`@("`@("`@("`D<"`K/2`D=&AI<RT^<F5C;W)D7W-I>F4[#0H@("`@
M("`@("`@("`@("`@)')E<W`@+CT@)'1H:7,M/F1O0VAU;FLH)&-H=6YK*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R97-P("X]("1T:&ES+3YE
M;F1#:'5N:R@I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)')E
M<W`@+CT@)'1H:7,M/E]M86ME4F5C;W)D*"1D871A+"`D='EP97-T<BPD:60L
M)'1Y<&4I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5S<#L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!S96YD1FEL90T*("`@("`J#0H@("`@
M("H@9VEV96X@82!F:6QE;F%M92P@:70@<F5A9',@=&AE(&9I;&4L#0H@("`@
M("H@8W)E871E<R!R96-O<F1S(&%N9"!W<FET97,@=&AE;2!T;R!T:&4@<W1R
M96%M#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!E;F-O9&5&:6QE
M*"1F:6QE;F%M92P@)'1Y<&5S='(])R<L("1I9#U.54Q,+"`D='EP93U.151?
M1$E-15]465!%7U5.2TY/5TXI#0H@("`@>PT*("`@("`@("`D9B`](&9O<&5N
M*"1F:6QE;F%M92P@(G)B(BD[#0H@("`@("`@(&EF("@D9BD@>PT*("`@("`@
M("`@("`@:68@*"1D871A(#T@9G)E860H)&8L("1T:&ES+3YR96-O<F1?<VEZ
M92DI('L-"B`@("`@("`@("`@("`@("`D<F5S<"`]("1T:&ES+3YS=&%R=$-H
M=6YK*"1D871A+"1T>7!E<W1R+"1I9"PD='EP92D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!W:&EL92`H)&1A=&$@/2!F<F5A9"@D9BP@)'1H:7,M
M/G)E8V]R9%]S:7IE*2D@>PT*("`@("`@("`@("`@("`@("1R97-P(#T@)'1H
M:7,M/F1O0VAU;FLH)&1A=&$L)'1Y<&5S='(L)&ED+"1T>7!E*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1R97-P(#T@)'1H:7,M/F5N9$-H=6YK
M*"D[#0H@("`@("`@("`@("!F8VQO<V4H)&8I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D<F5S<#L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@
M("H@7W!R;V-E<W-$871A#0H@("`@("H-"B`@("`@*B!C<F5A=&5S($YE=%]$
M24U%7U)E8V]R9',@9G)O;2!P<F]V:61E9"!D871A#0H@("`@("H-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?<')O8V5S<T1A=&$H)B1D871A*0T*("`@('L-
M"B`@("`@("`@)&QE9G1O=F5R(#T@3E5,3#L-"B`@("`@("`@:68@*"$D=&AI
M<RT^7V-U<G)E;G1296-O<F0I('L-"B`@("`@("`@("`@("1T:&ES+3Y?8W5R
M<F5N=%)E8V]R9"`](&YE=R!.971?1$E-15]296-O<F0H)'1H:7,M/F1E8G5G
M*3L-"B`@("`@("`@("`@("1D871A(#T@)'1H:7,M/E]C=7)R96YT4F5C;W)D
M+3YD96-O9&4H)&1A=&$I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)&1A=&$@/2`D=&AI<RT^7V-U<G)E;G1296-O<F0M/F%D9$1A=&$H)&1A
M=&$I.PT*("`@("`@("!]#0H)"0D)#0H@("`@("`@(&EF("@D=&AI<RT^7V-U
M<G)E;G1296-O<F0M/E]H879E1&%T82D@>PT*("`@("`@("`@("`@:68@*&-O
M=6YT*"1T:&ES+3YP87)T<RD]/3`@)B8@(21T:&ES+3Y?8W5R<F5N=%)E8V]R
M9"T^:7-3=&%R="@I*2![#0H@("`@("`@("`@("`@("`@+R\@<F%I<V4@86X@
M97)R;W(A#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T9I<G-T($UE<W-A9V4@:7,@;F]T(&$@1$E-12!B96=I;B!R96-O<F0A
M)RD[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V-U<G)E;G1296-O<F0M/FES16YD*"D@)B8@)'1H:7,M/E]C=7)R96YT4F5C
M;W)D+3YG971$871A3&5N9W1H*"D]/3`I('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@3E5,3#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(`T*("`@
M("`@("`@("`@:68@*"1T:&ES+3YC=7)R96YT4&%R="`\(#`@)B8@(21T:&ES
M+3Y?8W5R<F5N=%)E8V]R9"T^:7-#:'5N:R@I*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/G!A<G1S6UT@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YC=7)R96YT4&%R="`](&-O=6YT*"1T:&ES+3YP87)T<RDM,3L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<&%R='-;)'1H:7,M/F-U<G)E;G10
M87)T75LG:60G72`@(#T@)'1H:7,M/E]C=7)R96YT4F5C;W)D+3YG971)1"@I
M.PT*("`@("`@("`@("`@("`@("1T:&ES+3YP87)T<ULD=&AI<RT^8W5R<F5N
M=%!A<G1=6R=T>7!E)UT@/2`D=&AI<RT^7V-U<G)E;G1296-O<F0M/F=E=%1Y
M<&4H*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<&%R='-;)'1H:7,M/F-U
M<G)E;G1087)T75LG9&%T82==(#T@)'1H:7,M/E]C=7)R96YT4F5C;W)D+3YG
M971$871A*"D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1087)T
M(#T@+3$[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M(&EF("@D=&AI<RT^8W5R<F5N=%!A<G0@/"`P*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YP87)T<UM=(#T@87)R87DH*3L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F-U<G)E;G1087)T(#T@8V]U;G0H)'1H:7,M/G!A
M<G1S*2TQ.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&%R='-;)'1H
M:7,M/F-U<G)E;G1087)T75LG:60G72`@(#T@)'1H:7,M/E]C=7)R96YT4F5C
M;W)D+3YG971)1"@I.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&%R
M='-;)'1H:7,M/F-U<G)E;G1087)T75LG='EP92==(#T@)'1H:7,M/E]C=7)R
M96YT4F5C;W)D+3YG9714>7!E*"D[#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YP87)T<ULD=&AI<RT^8W5R<F5N=%!A<G1=6R=D871A)UT@/2`D=&AI
M<RT^7V-U<G)E;G1296-O<F0M/F=E=$1A=&$H*3L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&%R='-;
M)'1H:7,M/F-U<G)E;G1087)T75LG9&%T82==("X]("1T:&ES+3Y?8W5R<F5N
M=%)E8V]R9"T^9V5T1&%T82@I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?8W5R<F5N=%)E8V]R9"T^:7-#:'5N:R@I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!W92!R96%C:&5D('1H92!E;F0@;V8@=&AE
M(&-H=6YK#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N
M=%!A<G0@/2`M,3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(",D=&AI<RT^
M<F5C;W)D<UM=(#T@)'1H:7,M/E]C=7)R96YT4F5C;W)D.PT*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^7V-U<G)E;G1296-O<F0M/FES16YD*"DI("1T:&ES
M+3Y?8W5R<F5N=%)E8V]R9"`]($Y53$P[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N($Y53$P[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(&1E
M8V]D941A=&$-"B`@("`@*@T*("`@("`J(&1E8V]D97,@82!$24U%(&5N8W)Y
M<'1E9"!S=')I;F<@;V8@9&%T80T*("`@("`J#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9&5C;V1E1&%T82@F)&1A=&$I('L-"B`@("`@("`@=VAI;&4@*'-T
M<FQE;B@D9&%T82D@/CT@3D547T1)345?4D5#3U)$7TA%041%4BD@>PT*("`@
M("`@("`@("`@)&5R<B`]("1T:&ES+3Y?<')O8V5S<T1A=&$H)&1A=&$I.PT*
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!R96%D#0H@("`@
M("H-"B`@("`@*B!R96%D<R!T:&4@<W1R96%M(&%N9"!C<F5A=&5S#0H@("`@
M("H@86X@87)R87D@;V8@<F5C;W)D<PT*("`@("`J#0H@("`@("H@:70@8V%N
M(&%C8V5P="!T:&4@<W1A<G0@;V8@82!P<F5V:6]U<VQY(')E860@8G5F9F5R
M#0H@("`@("H@=&AI<R!I<R!U<V5F=6QL(&EN('-I='5A=&EO;G,@=VAE<F4@
M>6]U(&YE960@=&\@<F5A9`T*("`@("`J(&AE861E<G,@8F5F;W)E(&1I<V-O
M=F5R:6YG('1H870@=&AE(&1A=&$@:7,@1$E-12!E;F-O9&5D#0H@("`@("H@
M<W5C:"!A<R!I;B!T:&4@8V%S92!O9B!R96%D:6YG(&%N($A45%`@<F5S<&]N
M<V4N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5A9"@D8G5F/4Y53$PI#0H@
M("`@>PT*("`@("`@("!W:&EL92`H)&1A=&$@/2!F<F5A9"@D=&AI<RT^<W1R
M96%M+"`X,3DR*2D@>PT*("`@("`@("`@("`@:68@*"1B=68I('L-"B`@("`@
M("`@("`@("`@("`D9&%T82`]("1B=68N)&1A=&$[#0H@("`@("`@("`@("`@
M("`@)&)U9B`]($Y53$P[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/F1E8G5G*0T*("`@("`@("`@("`@("`@(&5C:&\@(G)E860Z
M("(N<W1R;&5N*"1D871A*2XB(&)Y=&5S7&XB.PT*("`@("`@("`@("`@)&5R
M<B`]("1T:&ES+3YD96-O9&5$871A*"1D871A*3L-"B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1E<G([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`-"B`@("`@
M("`@("`@("\O('-T;W)E(&%N>2!L969T;W9E<B!D871A('1O(&)E('5S960@
M86=A:6X-"B`@("`@("`@("`@("\O('-H;W5L9"!B92`\($Y%5%]$24U%7U)%
M0T]21%](14%$15(@8GET97,-"B`@("`@("`@("`@("1B=68@/2`D9&%T83L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3Y?8W5R<F5N=%)E8V]R
M9"!\?"`A)'1H:7,M/E]C=7)R96YT4F5C;W)D+3YI<T5N9"@I*2![#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<F5A8VAE9"!S=')E
M86T@96YD('=I=&AO=70@96YD(')E8V]R9"<I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!.54Q,.PT*("`@('T-"GT-"C\^````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O3F5T+T1.4RYP:'``````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S0V-#4`,3`T,3<S-C,P,#8`
M,#$W,C,W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J"B`J("!-;V1U;&4@=W)I='1E;B]P;W)T960@8GD@17)I
M8R!+:6QF;VEL(#QE<FEC0'EP87-S+FYE=#X*("H@"B`J("!4:&ES(&ES('1H
M92!C;W!Y<FEG:'0@;F]T:6-E(&9R;VT@=&AE(%!%4DP@3F5T.CI$3E,@;6]D
M=6QE.@H@*@H@*B`@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#`@36EC:&%E;"!&
M=6AR+B`@06QL(')I9VAT<R!R97-E<G9E9"X@(%1H:7,*("H@('!R;V=R86T@
M:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD
M+V]R(&UO9&EF>2!I=`H@*B`@=6YD97(@=&AE('-A;64@=&5R;7,@87,@4&5R
M;"!I='-E;&8N"B`J"B`J("!4:&4@;6%J;W)I='D@;V8@=&AI<R!I<R!?3D]4
M7R!M>2!C;V1E+B`@22!S:6UP;'D@<&]R=&5D(&ET(&9R;VT@=&AE"B`J("!0
M15),($YE=#HZ1$Y3(&UO9'5L92X@(`H@*@H@*B`@5&AE(&%U=&AO<B!O9B!T
M:&4@3F5T.CI$3E,@;6]D=6QE(&ES($UI8VAA96P@1G5H<B`\;6EK94!F=6AR
M+F]R9SX*("H@(&AT='`Z+R]W=W<N9G5H<BYO<F<O?FUF=6AR+W!E<FQD;G,O
M"B`J"B`J("!)(%]$3U\@;6%I;G1A:6X@=&AI<R!C;V1E+"!A;F0@36EA8VAA
M96P@1G5H<B!H87,@;F]T:&EN9R!T;R!W:71H('1H90H@*B`@<&]R=&EN9R!O
M9B!T:&ES(&-O9&4@=&\@4$A0+B`@06YY('%U97-T:6]N<R!D:7)E8W1L>2!R
M96QA=&5D('1O('1H:7,*("H@(&-L87-S(&QI8G)A<GD@<VAO=6QD(&)E(&1I
M<F5C=&5D('1O(&UE+@H@*@H@*B`@22=L;"!B92!S971T:6YG('5P(&$@0U93
M(')E<&]S:71O<GD@9F]R('1H:7,@8VQA<W,@<V]O;BX@(%1H92!M;W)E"B`J
M("!E;6%I;',@:2!G970@8V]N8V5R;FEN9R!T:&ES+"!T:&4@;6]R92!A<'0@
M:2!A;2!T;R!D;R!I="X*("H*("H@($QI8V5N<V4@26YF;W)M871I;VXZ"B`J
M"B`J("`@($YE=%]$3E,Z("!!(')E<V]L=F5R(&QI8G)A<GD@9F]R(%!(4`H@
M*B`@("!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!%<FEC($MI;&9O:6P@97)I
M8T!Y<&%S<RYN970*("H*("H@("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F
M='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@*B`@("!M
M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`J("`@($QI8V5N<V4@87,@<'5B;&ES:&5D(&)Y('1H
M92!&<F5E(%-O9G1W87)E($9O=6YD871I;VX[(&5I=&AE<@H@*B`@("!V97)S
M:6]N(#(N,2!O9B!T:&4@3&EC96YS92P@;W(@*&%T('EO=7(@;W!T:6]N*2!A
M;GD@;&%T97(@=F5R<VEO;BX*("H*("H@("`@5&AI<R!L:6)R87)Y(&ES(&1I
M<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL
M"B`J("`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U="!E=F5N
M('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`J("`@($U%4D-(04Y404))3$E4
M62!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T
M:&4@1TY5"B`J("`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O
M<B!M;W)E(&1E=&%I;',N"B`J"B`J("`@(%EO=2!S:&]U;&0@:&%V92!R96-E
M:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*
M("H@("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T
M+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@*B`@("!&;W5N9&%T:6]N
M+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+"!-
M02`@,#(Q,3$M,3,P-R`@55-!"B`J+PH*+RH@26YC;'5D92!I;F9O<FUA=&EO
M;B![>WL@*B\*"B`@("`D<&AP9&YS7V)A<V5D:7(@/2`G3F5T)SL*("`@(')E
M<75I<F5?;VYC92@B)'!H<&1N<U]B87-E9&ER+T1.4R](96%D97(N<&AP(BD[
M"B`@("!R97%U:7)E7V]N8V4H(B1P:'!D;G-?8F%S961I<B]$3E,O475E<W1I
M;VXN<&AP(BD["B`@("!R97%U:7)E7V]N8V4H(B1P:'!D;G-?8F%S961I<B]$
M3E,O4&%C:V5T+G!H<"(I.PH@("`@<F5Q=6ER95]O;F-E*"(D<&AP9&YS7V)A
M<V5D:7(O1$Y3+U)E<V]L=F5R+G!H<"(I.PH@("`@<F5Q=6ER95]O;F-E*"(D
M<&AP9&YS7V)A<V5D:7(O1$Y3+U)2+G!H<"(I.PH*+RH@?7U]("HO"B\J($=,
M3T)!3"!605))04),12!D969I;FET:6]N<R![>WL@*B\*"B\O(%5S960@8GD@
M=&AE($YE=%]$3E-?4F5S;VQV97(@;V)J96-T('1O(&=E;F5R871E(&%N($E$
M"FUT7W-R86YD*"AD;W5B;&4I(&UI8W)O=&EM92@I("H@,3`P,#`I.PHD7TYE
M=%]$3E-?<&%C:V5T7VED(#T@*&EN="EM=%]R86YD*#`L(#8U-3,U*3L*"B\J
M('U]?2`J+PHO*B!.971?1$Y3(&]B:F5C="!D969I;FET:6]N("AI;F-O;7!L
M971E*2![>WL@*B\*+RHJ"B`J($EN:71I86QI>F5S(&$@<F5S;VQV97(@;V)J
M96-T"B`J"B`J($YE=%]$3E,@86QL;W=S('EO=2!T;R!Q=65R>2!A(&YA;65S
M97)V97(@9F]R($1.4R`@;&]O:W5P<RX@($ET(&)Y<&%S<V5S('1H90H@*B!S
M>7-T96T@<F5S;VQV97(@;&EB<F%R>2`@96YT:7)E;'DL('=H:6-H(&%L;&]W
M<R!Y;W4@=&\@<75E<GD@86YY(&YA;65S97)V97(L"B`J('-E="!Y;W5R(&]W
M;B!V86QU97,@9F]R(')E=')I97,L('1I;65O=71S+"!R96-U<G-I;VXL("!E
M=&,N"B`J"B`J($!A=71H;W(@17)I8R!+:6QF;VEL(#QE<FEC0'EP87-S+FYE
M=#X*("H@0'!A8VMA9V4@3F5T7T1.4PH@*B!`=F5R<VEO;B`P+C`Q86QP:&$*
M("HO"F-L87-S($YE=%]$3E,*>PH@("`@+RH@8VQA<W,@=F%R:6%B;&4@9&5F
M:6YI=&EO;G,@>WM[("HO"B`@("`O*BH*("`@("`J($$@9&5F875L="!R97-O
M;'9E<B!O8FIE8W0@8W)E871E9"!O;B!I;G-T86YT:6%T:6]N"B`@("`@*@H@
M("`@("H@0'9A<B!O8FIE8W0@3F5T7T1.4U]297-O;'9E<@H@("`@("HO"B`@
M("!V87(@)')E<V]L=F5R.PH@("`@=F%R("1615)324].(#T@)S$N,#!B,B<[
M("\O(%1H:7,@<VAO=6QD('!R;V)A8FQY(&)E(&$@9&5F:6YE(#HH"B`@("!V
M87(@)%!!0TM%5%-:(#T@-3$R.PH@("`@=F%R("1(1DE814136B`](#$R.PH@
M("`@=F%R("111DE814136B`](#0["B`@("!V87(@)%)21DE814136B`](#$P
M.PH@("`@=F%R("1)3E0S,E-:(#T@-#L*("`@('9A<B`D24Y4,3936B`](#([
M"B`@("`O*B!]?7T@*B\*("`@("\J(&-L87-S(&-O;G-T<G5C=&]R("T@3F5T
M7T1.4R@I('M[>R`J+PH@("`@+RHJ"B`@("`@*B!);FET:6%L:7IE<R!A(')E
M<V]L=F5R(&]B:F5C=`H@("`@("H*("`@("`J($!S964@3F5T7T1.4U]297-O
M;'9E<@H@("`@("HO"B`@("!F=6YC=&EO;B!.971?1$Y3*"D*("`@('L*("`@
M("`@("`D=&AI<RT^<F5S;VQV97(@/2!N97<@3F5T7T1.4U]297-O;'9E<B@I
M.PH@("`@?0H@("`@+RH@?7U]("HO"B`@("`O*B!.971?1$Y3.CIO<&-O9&5S
M8GEN86UE*"D@>WM[("HO"B`@("`O*BH*("`@("`J(%1R86YS;&%T97,@;W!C
M;V1E(&YA;65S('1O(&EN=&5G97)S"B`@("`@*@H@("`@("H@5')A;G-L871E
M<R!T:&4@;F%M92!O9B!A($1.4R!/4$-/1$4@:6YT;R!I="=S(&%S<VEG;F5D
M("!N=6UB97(*("`@("`J(&QI<W1E9"!I;B!21D,Q,#,U+"!21D,Q.3DV+"!O
M<B!21D,R,3,V+B!686QI9"`@3U!#3T1%4R!A<F4Z"B`@("`@*B`\=6P^"B`@
M("`@*B`@(#QL:3Y1545262`@(`H@("`@("H@("`\;&D^25%515)9("`@"B`@
M("`@*B`@(#QL:3Y35$%455,@("`*("`@("`J("`@/&QI/DY37TY/5$E&65]/
M4"`@(`H@("`@("H@("`\;&D^55!$051%"B`@("`@*B`\=6P^"B`@("`@*B`*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@)&]P8V]D92!!($1.4R!086-K970@
M3U!#3T1%(&YA;64*("`@("`J($!R971U<FX@(&EN=&5G97(@5&AE(&EN=&5G
M97(@=F%L=64@;V8@86X@3U!#3T1%"B`@("`@*B!`<V5E("`@("!.971?1$Y3
M.CIO<&-O9&5S8GEV86PH*0H@("`@("HO"B`@("!F=6YC=&EO;B!O<&-O9&5S
M8GEN86UE*"1O<&-O9&4I"B`@("!["B`@("`@("`@)&]P(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`G455%4EDG("`@("`@("`]/B`P+"`@("\O(%)&0R`Q
M,#,U"B`@("`@("`@("`@("`@("`G25%515)9)R`@("`@("`]/B`Q+"`@("\O
M(%)&0R`Q,#,U"B`@("`@("`@("`@("`@("`G4U1!5%53)R`@("`@("`]/B`R
M+"`@("\O(%)&0R`Q,#,U"B`@("`@("`@("`@("`@("`G3E-?3D]424997T]0
M)R`]/B`T+"`@("\O(%)&0R`Q.3DV"B`@("`@("`@("`@("`@("`G55!$051%
M)R`@("`@("`]/B`U+"`@("\O(%)&0R`R,3,V"B`@("`@("`@("`@("`@("`I
M.PH@("`@("`@(&EF("@A('-T<FQE;B@D;W!;)&]P8V]D95TI*2!["B`@("`@
M("`@("`@("1O<%LD;W!C;V1E72`]($Y53$P["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B@D;W!;)&]P8V]D95TI.PH@("`@?0H*("`@("\J('U]?2`J+PH@
M("`@+RH@3F5T7T1.4SHZ;W!C;V1E<V)Y=F%L*"D@>WM[*B\*("`@("\J*@H@
M("`@("H@5')A;G-L871E<R!O<&-O9&4@:6YT96=E<G,@:6YT;R!N86UE<PH@
M("`@("H*("`@("`J(%1R86YS;&%T97,@=&AE(&EN=&5G97(@=F%L=64@;V8@
M86X@;W!C;V1E(&EN=&\@:70G<R!N86UE"B`@("`@*B`*("`@("`J($!P87)A
M;2`@(&EN=&5G97(@)&]P8V]D979A;"`@02!$3E,@<&%C:V5T(&]P8V]D92!I
M;G1E9V5R"B`@("`@*B!`<F5T=7)N("!S=')I;F<@(%1H92!N86UE(&]F('1H
M92!/4$-/1$4*("`@("`J($!S964@("`@($YE=%]$3E,Z.F]P8V]D97-B>6YA
M;64H*0H@("`@("HO"B`@("!F=6YC=&EO;B!O<&-O9&5S8GEV86PH)&]P8V]D
M979A;"D*("`@('L*("`@("`@("`D;W!V86P@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@(#`@/3X@)U%515)9)RP*("`@("`@("`@("`@("`@(#$@/3X@)TE1
M545262<L"B`@("`@("`@("`@("`@("`R(#T^("=35$%455,G+`H@("`@("`@
M("`@("`@("`@-"`]/B`G3E-?3D]424997T]0)RP*("`@("`@("`@("`@("`@
M(#4@/3X@)U501$%412<L"B`@("`@("`@("`@("`@("`I.PH@("`@("`@(&EF
M("@A('-T<FQE;B@D;W!V86Q;)&]P8V]D979A;%TI*2!["B`@("`@("`@("`@
M("1O<'9A;%LD;W!C;V1E=F%L72`]($Y53$P["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B@D;W!V86Q;)&]P8V]D979A;%TI.PH@("`@?0H*("`@("\J?7U]
M*B\*("`@("\J($YE=%]$3E,Z.G)C;V1E<V)Y;F%M92@I('M[>RHO"B`@("`O
M*BH*("`@("`J(%1R86YS;&%T97,@<F-O9&4@;F%M97,@=&\@:6YT96=E<G,*
M("`@("`J"B`@("`@*B!4<F%N<VQA=&5S('1H92!N86UE(&]F(&$@1$Y3(%)#
M3T1%("AR97-U;'0@8V]D92D@:6YT;R!I="=S(&%S<VEG;F5D(&YU;6)E<BX*
M("`@("`J(#QU;#X*("`@("`J("`@/&QI/DY/15)23U(@("`*("`@("`J("`@
M/&QI/D9/4DU%4E(@("`*("`@("`J("`@/&QI/E-%4E9&04E,("`@"B`@("`@
M*B`@(#QL:3Y.6$1/34%)3B`@(`H@("`@("H@("`\;&D^3D]424U0("`@"B`@
M("`@*B`@(#QL:3Y214954T5$("`@"B`@("`@*B`@(#QL:3Y96$1/34%)3B`@
M(`H@("`@("H@("`\;&D^65A24E-%5"`@(`H@("`@("H@("`\;&D^3EA24E-%
M5"`@(`H@("`@("H@("`\;&D^3D]405542"`@(`H@("`@("H@("`\;&D^3D]4
M6D].10H@("`@("H@/'5L/@H@("`@("H@"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@("1R8V]D92`@02!$3E,@4&%C:V5T(%)#3T1%(&YA;64*("`@("`J($!R
M971U<FX@(&EN=&5G97(@5&AE(&EN=&5G97(@=F%L=64@;V8@86X@4D-/1$4*
M("`@("`J($!S964@("`@($YE=%]$3E,Z.G)C;V1E<V)Y=F%L*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F-O9&5S8GEN86UE*"1R8V]D92D*("`@('L*("`@
M("`@("`D<F,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=.3T524D]2)R`@
M(#T^(#`L("`@+R\@4D9#(#$P,S4*("`@("`@("`@("`@("`@("=&3U)-15)2
M)R`@(#T^(#$L("`@+R\@4D9#(#$P,S4*("`@("`@("`@("`@("`@("=315)6
M1D%)3"<@(#T^(#(L("`@+R\@4D9#(#$P,S4*("`@("`@("`@("`@("`@("=.
M6$1/34%)3B<@(#T^(#,L("`@+R\@4D9#(#$P,S4*("`@("`@("`@("`@("`@
M("=.3U1)35`G("`@(#T^(#0L("`@+R\@4D9#(#$P,S4*("`@("`@("`@("`@
M("`@("=214954T5$)R`@(#T^(#4L("`@+R\@4D9#(#$P,S4*("`@("`@("`@
M("`@("`@("=96$1/34%)3B<@(#T^(#8L("`@+R\@4D9#(#(Q,S8*("`@("`@
M("`@("`@("`@("=96%)24T54)R`@(#T^(#<L("`@+R\@4D9#(#(Q,S8*("`@
M("`@("`@("`@("`@("=.6%)24T54)R`@(#T^(#@L("`@+R\@4D9#(#(Q,S8*
M("`@("`@("`@("`@("`@("=.3U1!551()R`@(#T^(#DL("`@+R\@4D9#(#(Q
M,S8*("`@("`@("`@("`@("`@("=.3U1:3TY%)R`@(#T^(#$P+"`@("`O+R!2
M1D,@,C$S-@H@("`@("`@("`@("`@("`@*3L*("`@("`@("!I9B`H(2!S=')L
M96XH)')C6R1R8V]D95TI*2!["B`@("`@("`@("`@("1R8ULD<F-O9&5=(#T@
M3E5,3#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N*"1R8ULD<F-O9&5=*3L*
M("`@('T*"B`@("`O*GU]?2HO"B`@("`O*B!.971?1$Y3.CIR8V]D97-B>79A
M;"@I('M[>RHO"B`@("`O*BH*("`@("`J(%1R86YS;&%T97,@<F-O9&4@:6YT
M96=E<G,@:6YT;R!N86UE<PH@("`@("H*("`@("`J(%1R86YS;&%T97,@=&AE
M(&EN=&5G97(@=F%L=64@;V8@86X@<F-O9&4@:6YT;R!I="=S(&YA;64*("`@
M("`J(`H@("`@("H@0'!A<F%M("`@:6YT96=E<B`D<F-O9&5V86P@("!!($1.
M4R!P86-K970@<F-O9&4@:6YT96=E<@H@("`@("H@0')E='5R;B`@<W1R:6YG
M("!4:&4@;F%M92!O9B!T:&4@4D-/1$4*("`@("`J($!S964@("`@($YE=%]$
M3E,Z.G)C;V1E<V)Y;F%M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(')C;V1E
M<V)Y=F%L*"1R8V]D979A;"D*("`@('L*("`@("`@("`D<F,@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@(#`@/3X@)TY/15)23U(G+`H@("`@("`@("`@("`@
M("`@,2`]/B`G1D]234524B<L"B`@("`@("`@("`@("`@("`R(#T^("=315)6
M1D%)3"<L"B`@("`@("`@("`@("`@("`S(#T^("=.6$1/34%)3B<L"B`@("`@
M("`@("`@("`@("`T(#T^("=.3U1)35`G+`H@("`@("`@("`@("`@("`@-2`]
M/B`G4D5&55-%1"<L"B`@("`@("`@("`@("`@("`V(#T^("=96$1/34%)3B<L
M"B`@("`@("`@("`@("`@("`W(#T^("=96%)24T54)RP*("`@("`@("`@("`@
M("`@(#@@/3X@)TY84E)3150G+`H@("`@("`@("`@("`@("`@.2`]/B`G3D]4
M05542"<L"B`@("`@("`@("`@("`@("`Q,"`]/B`G3D]46D].12<L"B`@("`@
M("`@("`@("`@("`I.PH@("`@("`@(&EF("@A('-T<FQE;B@D<F-;)')C;V1E
M=F%L72DI('L*("`@("`@("`@("`@)')C6R1R8V]D979A;%T@/2!.54Q,.PH@
M("`@("`@('T*("`@("`@("!R971U<FXH)')C6R1R8V]D979A;%TI.PH@("`@
M?0H*("`@("\J?7U]*B\*("`@("\J($YE=%]$3E,Z.G1Y<&5S8GEN86UE*"D@
M>WM[*B\*("`@("\J*@H@("`@("H@5')A;G-L871E<R!24B!T>7!E(&YA;65S
M(&EN=&\@:6YT96=E<G,*("`@("`J"B`@("`@*B!4<F%N<VQA=&5S(&$@4F5S
M;W5R8V4@4F5C;W)D(&9R;VT@:70G<R!N86UE('1O(&ET)W,@(&EN=&5G97(@
M=F%L=64N"B`@("`@*B!686QI9"!R97-O=7)C92!R96-O<F0@='EP97,@87)E
M.@H@("`@("H*("`@("`J(#QU;#X*("`@("`J("`@/&QI/D$@("`*("`@("`J
M("`@/&QI/DY3("`@"B`@("`@*B`@(#QL:3Y-1"`@(`H@("`@("H@("`\;&D^
M348@("`*("`@("`J("`@/&QI/D-.04U%("`@"B`@("`@*B`@(#QL:3Y33T$@
M("`*("`@("`J("`@/&QI/DU"("`@"B`@("`@*B`@(#QL:3Y-1R`@(`H@("`@
M("H@("`\;&D^35(@("`*("`@("`J("`@/&QI/DY53$P@("`*("`@("`J("`@
M/&QI/E=+4R`@(`H@("`@("H@("`\;&D^4%12("`@"B`@("`@*B`@(#QL:3Y(
M24Y&3R`@(`H@("`@("H@("`\;&D^34E.1D\@("`*("`@("`J("`@/&QI/DU8
M("`@"B`@("`@*B`@(#QL:3Y46%0@("`*("`@("`J("`@/&QI/E)0("`@"B`@
M("`@*B`@(#QL:3Y!1E-$0B`@(`H@("`@("H@("`\;&D^6#(U("`@"B`@("`@
M*B`@(#QL:3Y)4T1.("`@"B`@("`@*B`@(#QL:3Y25"`@(`H@("`@("H@("`\
M;&D^3E-!4"`@(`H@("`@("H@("`\;&D^3E-!4%]05%(@("`*("`@("`J("`@
M/&QI/E-)1R`@(`H@("`@("H@("`\;&D^2T59("`@"B`@("`@*B`@(#QL:3Y0
M6"`@(`H@("`@("H@("`\;&D^1U!/4R`@(`H@("`@("H@("`\;&D^04%!02`@
M(`H@("`@("H@("`\;&D^3$]#("`@"B`@("`@*B`@(#QL:3Y.6%0@("`*("`@
M("`J("`@/&QI/D5)1"`@(`H@("`@("H@("`\;&D^3DE-3$]#("`@"B`@("`@
M*B`@(#QL:3Y34E8@("`*("`@("`J("`@/&QI/D%434$@("`*("`@("`J("`@
M/&QI/DY!4%12("`@"B`@("`@*B`@(#QL:3Y44TE'("`@"B`@("`@*B`@(#QL
M:3Y524Y&3R`@(`H@("`@("H@("`\;&D^54E$("`@"B`@("`@*B`@(#QL:3Y'
M240@("`*("`@("`J("`@/&QI/E5.4U!%0R`@(`H@("`@("H@("`\;&D^25A&
M4B`@(`H@("`@("H@("`\;&D^05A&4B`@(`H@("`@("H@("`\;&D^34%)3$(@
M("`*("`@("`J("`@/&QI/DU!24Q!("`@"B`@("`@*B`@(#QL:3Y!3ED*("`@
M("`J(#QU;#X*("`@("`J(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D<G)T
M>7!E($$@1$Y3('!A8VME="!24B!T>7!E(&YA;64@("`*("`@("`J($!R971U
M<FX@(&EN=&5G97(@5&AE(&EN=&5G97(@=F%L=64@;V8@86X@4E(@='EP90H@
M("`@("H@0'-E92`@("`@3F5T7T1.4SHZ='EP97-B>79A;"@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1Y<&5S8GEN86UE*"1R<G1Y<&4I"B`@("!["B`@("`@
M("`@)')C(#T@87)R87DH"B`@("`@("`@("`@("`@("`G02<@("`@("`@("`@
M("`@/3X@,2P*("`@("`@("`@("`@("`@("=.4R<@("`@("`@("`@("`]/B`R
M+`H@("`@("`@("`@("`@("`@)TU$)R`@("`@("`@("`@(#T^(#,L"B`@("`@
M("`@("`@("`@("`G348G("`@("`@("`@("`@/3X@-"P*("`@("`@("`@("`@
M("`@("=#3D%-12<@("`@("`@("`]/B`U+`H@("`@("`@("`@("`@("`@)U-/
M02<@("`@("`@("`@(#T^(#8L"B`@("`@("`@("`@("`@("`G34(G("`@("`@
M("`@("`@/3X@-RP*("`@("`@("`@("`@("`@("=-1R<@("`@("`@("`@("`]
M/B`X+`H@("`@("`@("`@("`@("`@)TU2)R`@("`@("`@("`@(#T^(#DL"B`@
M("`@("`@("`@("`@("`G3E5,3"<@("`@("`@("`@/3X@,3`L"B`@("`@("`@
M("`@("`@("`G5TM3)R`@("`@("`@("`@/3X@,3$L"B`@("`@("`@("`@("`@
M("`G4%12)R`@("`@("`@("`@/3X@,3(L"B`@("`@("`@("`@("`@("`G2$E.
M1D\G("`@("`@("`@/3X@,3,L"B`@("`@("`@("`@("`@("`G34E.1D\G("`@
M("`@("`@/3X@,30L"B`@("`@("`@("`@("`@("`G35@G("`@("`@("`@("`@
M/3X@,34L"B`@("`@("`@("`@("`@("`G5%A4)R`@("`@("`@("`@/3X@,38L
M"B`@("`@("`@("`@("`@("`G4E`G("`@("`@("`@("`@/3X@,3<L"B`@("`@
M("`@("`@("`@("`G04931$(G("`@("`@("`@/3X@,3@L"B`@("`@("`@("`@
M("`@("`G6#(U)R`@("`@("`@("`@/3X@,3DL"B`@("`@("`@("`@("`@("`G
M25-$3B<@("`@("`@("`@/3X@,C`L"B`@("`@("`@("`@("`@("`G4E0G("`@
M("`@("`@("`@/3X@,C$L"B`@("`@("`@("`@("`@("`G3E-!4"<@("`@("`@
M("`@/3X@,C(L"B`@("`@("`@("`@("`@("`G3E-!4%]05%(G("`@("`@/3X@
M,C,L"B`@("`@("`@("`@("`@("`G4TE')R`@("`@("`@("`@/3X@,C0L"B`@
M("`@("`@("`@("`@("`G2T59)R`@("`@("`@("`@/3X@,C4L"B`@("`@("`@
M("`@("`@("`G4%@G("`@("`@("`@("`@/3X@,C8L"B`@("`@("`@("`@("`@
M("`G1U!/4R<@("`@("`@("`@/3X@,C<L"B`@("`@("`@("`@("`@("`G04%!
M02<@("`@("`@("`@/3X@,C@L"B`@("`@("`@("`@("`@("`G3$]#)R`@("`@
M("`@("`@/3X@,CDL"B`@("`@("`@("`@("`@("`G3EA4)R`@("`@("`@("`@
M/3X@,S`L"B`@("`@("`@("`@("`@("`G14E$)R`@("`@("`@("`@/3X@,S$L
M"B`@("`@("`@("`@("`@("`G3DE-3$]#)R`@("`@("`@/3X@,S(L"B`@("`@
M("`@("`@("`@("`G4U)6)R`@("`@("`@("`@/3X@,S,L"B`@("`@("`@("`@
M("`@("`G051-02<@("`@("`@("`@/3X@,S0L"B`@("`@("`@("`@("`@("`G
M3D%05%(G("`@("`@("`@/3X@,S4L"B`@("`@("`@("`@("`@("`G54E.1D\G
M("`@("`@("`@/3X@,3`P+`H@("`@("`@("`@("`@("`@)U5)1"<@("`@("`@
M("`@(#T^(#$P,2P*("`@("`@("`@("`@("`@("='240G("`@("`@("`@("`]
M/B`Q,#(L"B`@("`@("`@("`@("`@("`G54Y34$5#)R`@("`@("`@/3X@,3`S
M+`H@("`@("`@("`@("`@("`@)U1324<G("`@("`@("`@(#T^(#(U,"P*("`@
M("`@("`@("`@("`@("=)6$92)R`@("`@("`@("`]/B`R-3$L"B`@("`@("`@
M("`@("`@("`G05A&4B<@("`@("`@("`@/3X@,C4R+`H@("`@("`@("`@("`@
M("`@)TU!24Q")R`@("`@("`@(#T^(#(U,RP*("`@("`@("`@("`@("`@("=-
M04E,02<@("`@("`@("`]/B`R-30L"B`@("`@("`@("`@("`@("`G04Y9)R`@
M("`@("`@("`@/3X@,C4U+`H@("`@("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@("`@(&EF("@A('-T<FQE;B@D<F-;)')R='EP95TI*2!["B`@("`@("`@
M("`@("`@("`@("`@)')C6R1R<G1Y<&5=(#T@3E5,3#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(')E='5R;B@D<F-;)')R='EP95TI.PH@
M("`@?0H*("`@("\J?7U]*B\*("`@("\J($YE=%]$3E,Z.G1Y<&5S8GEV86PH
M*2![>WLJ+PH@("`@+RHJ"B`@("`@*B!4<F%N<VQA=&5S(%)2('1Y<&4@:6YT
M96=E<G,@:6YT;R!N86UE<PH@("`@("H*("`@("`J(%1R86YS;&%T97,@=&AE
M(&EN=&5G97(@=F%L=64@;V8@86X@4E(@='EP92!I;G1O(&ET)W,@;F%M90H@
M("`@("H@"B`@("`@*B!`<&%R86T@("!I;G1E9V5R("1R<G1Y<&5V86P@($$@
M1$Y3('!A8VME="!24B!T>7!E(&EN=&5G97(*("`@("`J($!R971U<FX@('-T
M<FEN9R`@5&AE(&YA;64@;V8@=&AE(%)2('1Y<&4*("`@("`J($!S964@("`@
M($YE=%]$3E,Z.G1Y<&5S8GEN86UE*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M='EP97-B>79A;"@D<G)T>7!E=F%L*0H@("`@>PH@("`@("`@("1R8R`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@,2`]/B`G02<L"B`@("`@("`@("`@("`@
M("`R(#T^("=.4R<L"B`@("`@("`@("`@("`@("`S(#T^("=-1"<L"B`@("`@
M("`@("`@("`@("`T(#T^("=-1B<L"B`@("`@("`@("`@("`@("`U(#T^("=#
M3D%-12<L"B`@("`@("`@("`@("`@("`V(#T^("=33T$G+`H@("`@("`@("`@
M("`@("`@-R`]/B`G34(G+`H@("`@("`@("`@("`@("`@."`]/B`G34<G+`H@
M("`@("`@("`@("`@("`@.2`]/B`G35(G+`H@("`@("`@("`@("`@("`@,3`@
M/3X@)TY53$PG+`H@("`@("`@("`@("`@("`@,3$@/3X@)U=+4R<L"B`@("`@
M("`@("`@("`@("`Q,B`]/B`G4%12)RP*("`@("`@("`@("`@("`@(#$S(#T^
M("=(24Y&3R<L"B`@("`@("`@("`@("`@("`Q-"`]/B`G34E.1D\G+`H@("`@
M("`@("`@("`@("`@,34@/3X@)TU8)RP*("`@("`@("`@("`@("`@(#$V(#T^
M("=46%0G+`H@("`@("`@("`@("`@("`@,3<@/3X@)U)0)RP*("`@("`@("`@
M("`@("`@(#$X(#T^("=!1E-$0B<L"B`@("`@("`@("`@("`@("`Q.2`]/B`G
M6#(U)RP*("`@("`@("`@("`@("`@(#(P(#T^("=)4T1.)RP*("`@("`@("`@
M("`@("`@(#(Q(#T^("=25"<L"B`@("`@("`@("`@("`@("`R,B`]/B`G3E-!
M4"<L"B`@("`@("`@("`@("`@("`R,R`]/B`G3E-!4%]05%(G+`H@("`@("`@
M("`@("`@("`@,C0@/3X@)U-)1R<L"B`@("`@("`@("`@("`@("`R-2`]/B`G
M2T59)RP*("`@("`@("`@("`@("`@(#(V(#T^("=06"<L"B`@("`@("`@("`@
M("`@("`R-R`]/B`G1U!/4R<L"B`@("`@("`@("`@("`@("`R."`]/B`G04%!
M02<L"B`@("`@("`@("`@("`@("`R.2`]/B`G3$]#)RP*("`@("`@("`@("`@
M("`@(#,P(#T^("=.6%0G+`H@("`@("`@("`@("`@("`@,S$@/3X@)T5)1"<L
M"B`@("`@("`@("`@("`@("`S,B`]/B`G3DE-3$]#)RP*("`@("`@("`@("`@
M("`@(#,S(#T^("=34E8G+`H@("`@("`@("`@("`@("`@,S0@/3X@)T%434$G
M+`H@("`@("`@("`@("`@("`@,S4@/3X@)TY!4%12)RP*("`@("`@("`@("`@
M("`@(#$P,"`]/B`G54E.1D\G+`H@("`@("`@("`@("`@("`@,3`Q(#T^("=5
M240G+`H@("`@("`@("`@("`@("`@,3`R(#T^("='240G+`H@("`@("`@("`@
M("`@("`@,3`S(#T^("=53E-014,G+`H@("`@("`@("`@("`@("`@,C4P(#T^
M("=44TE')RP*("`@("`@("`@("`@("`@(#(U,2`]/B`G25A&4B<L"B`@("`@
M("`@("`@("`@("`R-3(@/3X@)T%81E(G+`H@("`@("`@("`@("`@("`@,C4S
M(#T^("=-04E,0B<L"B`@("`@("`@("`@("`@("`R-30@/3X@)TU!24Q!)RP*
M("`@("`@("`@("`@("`@(#(U-2`]/B`G04Y9)RP*("`@("`@("`@("`@("`@
M("D["B`@("`@("`@("`@("`@("!I9B`H(2!S=')L96XH)')C6R1R<G1Y<&5V
M86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@("1R8ULD<G)T>7!E=F%L72`]
M($Y53$P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U
M<FXH)')C6R1R<G1Y<&5V86Q=*3L*("`@('T*"B`@("`O*GU]?2HO"B`@("`O
M*B!.971?1$Y3.CIC;&%S<V5S8GEN86UE*"D@>WM[*B\*("`@("\J*@H@("`@
M("H@=')A;G-L871E<R!A($1.4R!C;&%S<R!F<F]M(&ET)W,@;F%M92!T;R!I
M="=S("!I;G1E9V5R('9A;'5E+B!686QI9`H@("`@("H@8VQA<W,@;F%M97,@
M87)E.@H@("`@("H@/'5L/@H@("`@("H@("`\;&D^24X@("`*("`@("`J("`@
M/&QI/D-(("`@"B`@("`@*B`@(#QL:3Y(4R`@(`H@("`@("H@("`\;&D^3D].
M12`@(`H@("`@("H@("`\;&D^04Y9"B`@("`@*B`\+W5L/@H@("`@("H@"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("1C;&%S<R`@02!$3E,@<&%C:V5T(&-L
M87-S('1Y<&4*("`@("`J($!R971U<FX@(&EN=&5G97(@5&AE(&EN=&5G97(@
M=F%L=64@;V8@86X@8VQA<W,@='EP90H@("`@("H@0'-E92`@("`@3F5T7T1.
M4SHZ8VQA<W-E<V)Y=F%L*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8VQA<W-E
M<V)Y;F%M92@D8VQA<W,I"B`@("!["B`@("`@("`@)')C(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`G24XG("`@("`@("`@("`@/3X@,2P*("`@("`@("`@
M("`@("`@("=#2"<@("`@("`@("`@("`]/B`S+`H@("`@("`@("`@("`@("`@
M)TA3)R`@("`@("`@("`@(#T^(#0L"B`@("`@("`@("`@("`@("`G3D].12<@
M("`@("`@("`@/3X@,C4T+`H@("`@("`@("`@("`@("`@)T%.62<@("`@("`@
M("`@(#T^(#(U-0H@("`@("`@("`@("`@("`@*3L*("`@("`@("!I9B`H(2!I
M<W-E="@D<F-;)&-L87-S72DI('L*("`@("`@("`@("`@)')C6R1C;&%S<UT@
M/2!.54Q,.PH@("`@("`@('T*("`@("`@("!R971U<FXH)')C6R1C;&%S<UTI
M.PH@("`@?0H*("`@("\J?7U]*B\*("`@("\J($YE=%]$3E,Z.F-L87-S97-B
M>79A;"@I('M[>RHO"B`@("`O*BH*("`@("`J(%1R86YS;&%T97,@4E(@8VQA
M<W,@:6YT96=E<G,@:6YT;R!N86UE<PH@("`@("H*("`@("`J(%1R86YS;&%T
M97,@=&AE(&EN=&5G97(@=F%L=64@;V8@86X@4E(@8VQA<W,@:6YT;R!I="=S
M(&YA;64*("`@("`J(`H@("`@("H@0'!A<F%M("`@:6YT96=E<B`D8VQA<W-V
M86P@("!!($1.4R!P86-K970@4E(@8VQA<W,@:6YT96=E<@H@("`@("H@0')E
M='5R;B`@<W1R:6YG("!4:&4@;F%M92!O9B!T:&4@4E(@8VQA<W,*("`@("`J
M($!S964@("`@($YE=%]$3E,Z.F-L87-S97-B>6YA;64H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;&%S<V5S8GEV86PH)&-L87-S=F%L*0H@("`@>PH@("`@
M("`@("1R8R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@,2`]/B`G24XG+`H@
M("`@("`@("`@("`@("`@,R`]/B`G0T@G+`H@("`@("`@("`@("`@("`@-"`]
M/B`G2%,G+`H@("`@("`@("`@("`@("`@,C4T(#T^("=.3TY%)RP*("`@("`@
M("`@("`@("`@(#(U-2`]/B`G04Y9)PH@("`@("`@("`@("`@("`@*3L*("`@
M("`@("!I9B`H(2!S=')L96XH)')C6R1C;&%S<W9A;%TI*2!["B`@("`@("`@
M("`@("1R8ULD8VQA<W-V86Q=(#T@3E5,3#L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N*"1R8ULD8VQA<W-V86Q=*3L*("`@('T*"B`@("`O*GU]?2HO"B`@
M("`O*B!N;W0@8V]M<&QE=&5D("T@3F5T7T1.4SHZ;7@H*2![>WLJ+PH@("`@
M+RI]?7TJ+PH@("`@+RH@;F]T(&-O;7!L971E9"`M($YE=%]$3E,Z.GEX<G)S
M970H*2![>WLJ+PH@("`@+RI]?7TJ+PH@("`@+RH@;F]T(&-O;7!L971E9"`M
M($YE=%]$3E,Z.FYX<G)S970H*2![>WLJ+PH@("`@+RI]?7TJ+PH@("`@+RH@
M;F]T(&-O;7!L971E9"`M($YE=%]$3E,Z.GEX9&]M86EN*"D@>WM[*B\*("`@
M("\J?7U]*B\*("`@("\J(&YO="!C;VUP;&5T960@+2!.971?1$Y3.CIN>&1O
M;6%I;B@I('M[>RHO"B`@("`O*GU]?2HO"B`@("`O*B!N;W0@8V]M<&QE=&5D
M("T@3F5T7T1.4SHZ<G)?861D*"D@>WM[*B\*("`@("\J?7U]*B\*("`@("\J
M(&YO="!C;VUP;&5T960@+2!.971?1$Y3.CIR<E]D96PH*2![>WLJ+PH@("`@
M+RI]?7TJ+PI]"B\J('U]?2`J+PHO*B!624T@4V5T=&EN9W,@>WM["B`J($QO
M8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F
M<V5T.B`T"B`J('-O9G0M<W1O<"UW:61T:#H@-`H@*B!C(&EN9&5N="!O;@H@
M*B!%;F0Z"B`J('9I;38P,#H@<W<]-"!T<STT('-T<STT(&-I;F1E;G0@9F1M
M/6UA<FME<B!E=`H@*B!V:6T\-C`P.B!S=STT('1S/30*("H@?7U]("HO"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+U-I979E+G!H
M<```````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#,S
M-30`,3`T,3<S-C,P,#8`,#$W-C8S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,RP@4FEC
M:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E
M(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@
M("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E
M9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@87)E
M(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C
M;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\"B\O
M('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P*+R\@?"!O(%)E9&ES=')I
M8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O
M=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H
M92!\"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA
M;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP*+R\@?"!O(%1H
M92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD
M;W)S92!O<B!P<F]M;W1E("`@("`@?`HO+R!\("`@<')O9'5C=',@9&5R:79E
M9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W
M<FET=&5N("!\"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(%1(25,@4T]&5%=!
M4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#
M3TY44DE"551/4E,@("!\"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@
M3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@
M('P*+R\@?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&
M($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@?`HO+R!\($$@4$%2
M5$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!3
M2$%,3"!42$4@0T]065))1TA4("!\"B\O('P@3U=.15(@3U(@0T].5%))0E54
M3U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$
M14Y404PL('P*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%
M3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@("`@?`HO+R!\
M($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@
M3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!\"B\O('P@1$%402P@3U(@4%)/
M1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%
M1"!!3D0@3TX@04Y9('P*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$54
M2$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@
M?`HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%2
M25-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\"B\O('P@3T8@5$A)
M4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E4
M62!/1B!354-(($1!34%'12X@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/B`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PH*<F5Q=6ER95]O;F-E*"=.970O4V]C:V5T+G!H<"<I
M.PIR97%U:7)E7V]N8V4H)T%U=&@O4T%33"YP:'`G*3L*"B\J*@HJ(%1/1$\*
M*@HJ(&\@:&%S17AT96YS:6]N*"D**B!O(&=E=$5X=&5N<VEO;G,H*0HJ(&\@
M<W5P<&]R='-!=71H365C:"@I"BHO"@HO*BH**B!$:7-C;VYN96-T960@<W1A
M=&4**B!`8V]N<W0@3D547U-)159%7U-4051%7T1)4T-/3DY%0U1%1`HJ+PID
M969I;F4H)TY%5%]3245615]35$%415]$25-#3TY.14-4140G+"`@,2P@=')U
M92D["@HO*BH**B!!=71H;W)I<V%T:6]N('-T871E"BH@0&-O;G-T($Y%5%]3
M245615]35$%415]!551(3U))4T%424]."BHO"F1E9FEN92@G3D547U-)159%
M7U-4051%7T%55$A/4DE3051)3TXG+"`R+"!T<G5E*3L*"B\J*@HJ(%1R86YS
M86-T:6]N('-T871E"BH@0&-O;G-T($Y%5%]3245615]35$%415]44D%.4T%#
M5$E/3@HJ+PID969I;F4H)TY%5%]3245615]35$%415]44D%.4T%#5$E/3B<L
M("`@,RP@=')U92D["@HO*BH**B!!(&-L87-S(&9O<B!T86QK:6YG('1O('1H
M92!T:6US:65V960@<V5R=F5R('=H:6-H"BH@8V]M97,@=VET:"!#>7)U<R!)
M34%0+B!$;V5S(&YO="!S=7!P;W)T('1H92!(059%4U!!0T4**B!C;VUM86YD
M('=H:6-H(&%P<&5A<G,@=&\@8F4@8G)O:V5N("A#>7)U<R`R+C`N,38I+@HJ
M"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@HJ
M($!A8V-E<W,@('!U8FQI8PHJ($!V97)S:6]N(#`N.`HJ($!P86-K86=E($YE
M=%]3:65V90HJ+PH*8VQA<W,@3F5T7U-I979E"GL*("`@("\J*@H@("`@*B!4
M:&4@<V]C:V5T(&]B:F5C=`H@("`@*B!`=F%R(&]B:F5C=`H@("`@*B\*("`@
M('9A<B`D7W-O8VL["@H@("`@+RHJ"B`@("`J($EN9F\@86)O=70@=&AE(&-O
M;FYE8W0*("`@("H@0'9A<B!A<G)A>0H@("`@*B\*("`@('9A<B`D7V1A=&$[
M"@H@("`@+RHJ"B`@("`J($-U<G)E;G0@<W1A=&4@;V8@=&AE(&-O;FYE8W1I
M;VX*("`@("H@0'9A<B!I;G1E9V5R"B`@("`J+PH@("`@=F%R("1?<W1A=&4[
M"@H@("`@+RHJ"B`@("`J($-O;G-T<G5C=&]R(&5R<F]R(&ES(&%N>0H@("`@
M*B!`=F%R(&]B:F5C=`H@("`@*B\*("`@('9A<B`D7V5R<F]R.PH*("`@("\J
M*@H@("`@*B!#;VYS=')U8W1O<@H@("`@*B!3971S('5P('1H92!O8FIE8W0L
M(&-O;FYE8W1S('1O('1H92!S97)V97(@86YD(&QO9W,@:6XN('-T;W)E<PH@
M("`@*B!A;GD@9V5N97)A=&5D(&5R<F]R(&EN("1T:&ES+3Y?97)R;W(L('=H
M:6-H(&-A;B!B92!R971R:65V960*("`@("H@=7-I;F<@=&AE(&=E=$5R<F]R
M*"D@;65T:&]D+@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`
M<&%R86T@('-T<FEN9R`D=7-E<B`@("`@($QO9VEN('5S97)N86UE"B`@("`J
M($!P87)A;2`@<W1R:6YG("1P87-S("`@("`@3&]G:6X@<&%S<W=O<F0*("`@
M("H@0'!A<F%M("!S=')I;F<@)&AO<W0@("`@("!(;W-T;F%M92!O9B!S97)V
M97(*("`@("H@0'!A<F%M("!S=')I;F<@)'!O<G0@("`@("!0;W)T(&]F('-E
M<G9E<@H@("`@*B!`<&%R86T@('-T<FEN9R`D;&]G:6YT>7!E(%1Y<&4@;V8@
M;&]G:6X@=&\@<&5R9F]R;0H@("`@*B!`<&%R86T@('-T<FEN9R`D975S97(@
M("`@($5F9F5C=&EV92!5<V5R("AI9B`D=7-E<CUA9&UI;BP@;&]G:6X@87,@
M)&5U<V5R*0H@("`@*B\*("`@(&9U;F-T:6]N($YE=%]3:65V92@D=7-E<BP@
M)'!A<W,L("1H;W-T(#T@)VQO8V%L:&]S="<L("1P;W)T(#T@,C`P,"P@)&QO
M9VEN='EP92`]("=03$%)3B<L("1E=7-E<B`]("<G*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<W1A=&4@/2!.151?4TE%5D5?4U1!5$5?1$E30T].3D5#5$5$
M.PH*("`@("`@("`D=&AI<RT^7V1A=&%;)W5S97(G72`]("1U<V5R.PH@("`@
M("`@("1T:&ES+3Y?9&%T85LG<&%S<R==(#T@)'!A<W,["B`@("`@("`@)'1H
M:7,M/E]D871A6R=H;W-T)UT@/2`D:&]S=#L*("`@("`@("`D=&AI<RT^7V1A
M=&%;)W!O<G0G72`]("1P;W)T.PH@("`@("`@("1T:&ES+3Y?9&%T85LG975S
M97(G72`]("1E=7-E<CL*("`@("`@("`D=&AI<RT^7W-O8VL@/2`F;F5W($YE
M=%]3;V-K970H*3L*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]
M("1T:&ES+3Y?8V]N;F5C="@D:&]S="P@)'!O<G0I*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V5R<F]R(#T@)')E<SL*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1T
M:&ES+3Y?;&]G:6XH)'5S97(L("1P87-S+"`D;&]G:6YT>7!E+"`D975S97(I
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R(#T@)')E<SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@86X@:6YD97AE9"!A
M<G)A>2!O9B!S8W)I<'1S(&-U<G)E;G1L>0H@("`@*B!O;B!T:&4@<V5R=F5R
M"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@;6EX
M960@26YD97AE9"!A<G)A>2!O9B!S8W)I<'1N86UE<R!O<B!014%27T5R<F]R
M(&]N(&9A:6QU<F4*("`@("HO"B`@("!F=6YC=&EO;B!L:7-T4V-R:7!T<R@I
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1S8W)I<'1S(#T@)'1H:7,M
M/E]C;61,:7-T4V-R:7!T<R@I*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%C
M=&EV92`]("1S8W)I<'1S6S%=.PH@("`@("`@("`@("!R971U<FX@)'-C<FEP
M='-;,%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1S
M8W)I<'1S.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("H@4F5T=7)N
M<R!T:&4@86-T:79E('-C<FEP=`H@("`@*@H@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@*B!`<F5T=7)N(&UI>&5D(%1H92!A8W1I=F4@<V-R:7!T;F%M92!O
M<B!014%27T5R<F]R(&]N(&9A:6QU<F4*("`@("HO"B`@("!F=6YC=&EO;B!G
M971!8W1I=F4H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]A
M8W1I=F4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%C=&EV93L*
M"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1S8W)I<'1S(#T@)'1H:7,M
M/E]C;61,:7-T4V-R:7!T<R@I*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%C
M=&EV92`]("1S8W)I<'1S6S%=.PH@("`@("`@("`@("!R971U<FX@)'-C<FEP
M='-;,5T["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!3971S('1H
M92!A8W1I=F4@<V-R:7!T"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J($!P87)A;2`@<W1R:6YG("1S8W)I<'1N86UE(%1H92!N86UE(&]F('1H
M92!S8W)I<'0@=&\@8F4@<V5T(&%S(&%C=&EV90H@("`@*B!`<F5T=7)N(&UI
M>&5D("`@("`@("`@("`@("!T<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@
M;VX@9F%I;'5R90H@("`@*B\*("`@(&9U;F-T:6]N('-E=$%C=&EV92@D<V-R
M:7!T;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;613971!
M8W1I=F4H)'-C<FEP=&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@*B!2971R
M:65V97,@82!S8W)I<'0*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("H@0'!A<F%M("!S=')I;F<@)'-C<FEP=&YA;64@5&AE(&YA;64@;V8@=&AE
M('-C<FEP="!T;R!B92!R971R:65V960*("`@("H@0')E='5R;B!M:7AE9"`@
M("`@("`@("`@("`@5&AE('-C<FEP="!O;B!S=6-C97-S+"!014%27T5R<F]R
M(&]N(&9A:6QU<F4*("`@("HO"B`@("!F=6YC=&EO;B!G97138W)I<'0H)'-C
M<FEP=&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VUD1V5T
M4V-R:7!T*"1S8W)I<'1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("H@061D
M<R!A('-C<FEP="!T;R!T:&4@<V5R=F5R"B`@("`J"B`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`J($!P87)A;2`@<W1R:6YG("1S8W)I<'1N86UE($YA;64@
M;V8@=&AE('-C<FEP=`H@("`@*B!`<&%R86T@('-T<FEN9R`D<V-R:7!T("`@
M("!4:&4@<V-R:7!T"B`@("`J($!P87)A;2`@8F]O;"`@("1M86ME86-T:79E
M(%=H971H97(@=&\@;6%K92!T:&ES('1H92!A8W1I=F4@<V-R:7!T"B`@("`J
M($!R971U<FX@;6EX960@("`@("`@("`@("`@('1R=64@;VX@<W5C8V5S<RP@
M4$5!4E]%<G)O<B!O;B!F86EL=7)E"B`@("`J+PH@("`@9G5N8W1I;VX@:6YS
M=&%L;%-C<FEP="@D<V-R:7!T;F%M92P@)'-C<FEP="P@)&UA:V5A8W1I=F4@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S
M(#T@)'1H:7,M/E]C;610=7138W)I<'0H)'-C<FEP=&YA;64L("1S8W)I<'0I
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*"B`@("`@("`@?2!E;'-E
M:68@*"1M86ME86-T:79E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-M9%-E=$%C=&EV92@D<V-R:7!T;F%M92D["@H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("H@4F5M;W9E<R!A('-C<FEP="!F<F]M('1H92!S97)V97(*
M("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M("!S=')I
M;F<@)'-C<FEP=&YA;64@3F%M92!O9B!T:&4@<V-R:7!T"B`@("`J($!R971U
M<FX@;6EX960@("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E"B`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E4V-R
M:7!T*"1S8W)I<'1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-M9$1E;&5T95-C<FEP="@D<V-R:7!T;F%M92D["B`@("!]"@H@("`@+RHJ
M"B`@("`J(%)E='5R;G,@86YY(&5R<F]R('1H870@;6%Y(&AA=F4@8F5E;B!G
M96YE<F%T960@:6X@=&AE"B`@("`J(&-O;G-T<G5C=&]R"B`@("`J"B`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@;6EX960@1F%L<V4@:68@
M;F\@97)R;W(L(%!%05)?17)R;W(@;W1H97)W:7-E"B`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T17)R;W(H*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CII
M<T5R<F]R*"1T:&ES+3Y?97)R;W(I(#\@)'1H:7,M/E]E<G)O<B`Z(&9A;'-E
M.PH@("`@?0H*("`@("\J*@H@("`@*B!(86YD;&5S(&-O;FYE8W1I;F<@=&\@
M=&AE('-E<G9E<B!A;F0@8VAE8VMI;F<@=&AE"B`@("`J(')E<W!O;G-E(&ES
M('9A;&ED+@H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'!A
M<F%M("!S=')I;F<@)&AO<W0@2&]S=&YA;64@;V8@<V5R=F5R"B`@("`J($!P
M87)A;2`@<W1R:6YG("1P;W)T(%!O<G0@;V8@<V5R=F5R"B`@("`J($!R971U
M<FX@;6EX960@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O
M=&AE<G=I<V4*("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@D:&]S="P@
M)'!O<G0I"B`@("!["B`@("`@("`@:68@*$Y%5%]3245615]35$%415]$25-#
M3TY.14-4140@/3T@)'1H:7,M/E]S=&%T92D@>PH@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'1H:7,M/E]S;V-K+3YC;VYN96-T*"1H
M;W-T+"`D<&]R="P@;G5L;"P@-2DI*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`O+R!'970@;&]G
M;VX@9W)E971I;F<O8V%P86)I;&ET>2!A;F0@<&%R<V4*("`@("`@("`@("`@
M:68H(5!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES+3Y?9V5T4F5S<&]N<V4H
M*2DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5#87!A8FEL:71Y
M*"1R97,I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T92`]($Y%5%]3
M245615]35$%415]!551(3U))4T%424]..PH@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V-A<&%B:6QI='E;)W-A<VPG72DI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@875T
M:&5N=&EC871I;VX@;65C:&%N:7-M<R!A=F%I;&%B;&4N)RD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=&86EL960@=&\@8V]N;F5C="P@<V5R=F5R('-A:60Z("<@
M+B`D<F5S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)TYO="!C=7)R96YT;'D@:6X@1$E30T].3D5#5$5$('-T871E)RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!,;V=S(&EN=&\@<V5R=F5R+@H@
M("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'!A<F%M("!S=')I
M;F<@)'5S97(@("`@("!,;V=I;B!U<V5R;F%M90H@("`@*B!`<&%R86T@('-T
M<FEN9R`D<&%S<R`@("`@($QO9VEN('!A<W-W;W)D"B`@("`J($!P87)A;2`@
M<W1R:6YG("1L;V=I;G1Y<&4@5'EP92!O9B!L;V=I;B!M971H;V0@=&\@=7-E
M"B`@("`J($!P87)A;2`@<W1R:6YG("1E=7-E<B`@("`@169F96-T:79E(%5)
M1"`H<&5R9F]R;2!O;B!B96AA;&8@;V8@)&5U<V5R*0H@("`@*B!`<F5T=7)N
M(&UI>&5D("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O
M<B!O=&AE<G=I<V4*("`@("HO"B`@("!F=6YC=&EO;B!?;&]G:6XH)'5S97(L
M("1P87-S+"`D;&]G:6YT>7!E(#T@)U!,04E.)RP@)&5U<V5R(#T@)R<I"B`@
M("!["B`@("`@("`@:68@*$Y%5%]3245615]35$%415]!551(3U))4T%424].
M("$]("1T:&ES+3Y?<W1A=&4I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)TYO="!C=7)R96YT;'D@:6X@05542$]225-!5$E/3B!S
M=&%T92<I.PH@("`@("`@('T@("`@("`@("`@("`*("`@("`@("`@("`@"B`@
M("`@("`@:68@*"%I;E]A<G)A>2@D;&]G:6YT>7!E+"`D=&AI<RT^7V-A<&%B
M:6QI='E;)W-A<VPG72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9B@G075T:&5N=&EC871I;VX@;65C:&%N:7-M("5S
M(&YO="!S=7!P;W)T960@8GD@=&AI<R!S97)V97(N)RP@)&QO9VEN='EP92DI
M.PH@("`@("`@('T*"B`@("`@("`@)'-A<VP@/2`F075T:%]305-,.CIF86-T
M;W)Y*"1L;V=I;G1Y<&4I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1S
M87-L*2D@>PH@("`@("`@("`@("!R971U<FX@)'-A<VP["B`@("`@("`@?0H*
M("`@("`@("!S=VET8V@@*"1L;V=I;G1Y<&4I('L*("`@("`@("!C87-E("=0
M3$%)3B<Z"B`@("`@("`@("`@("1T:&ES+3Y?<V5N9$-M9"AS<')I;G1F*"=!
M551(14Y424-!5$4@(E!,04E.(B`B)7,B)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8F%S938T7V5N8V]D92@D<V%S;"T^9V5T4F5S
M<&]N<V4H)'5S97(L("1P87-S+"`D975S97(I*2DI.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!C87-E("=,3T=)3B<Z"B`@("`@("`@("`@("1T:&ES
M+3Y?<V5N9$-M9"@G05542$5.5$E#051%("),3T=)3B(G*3L*("`@("`@("`@
M("`@)'1H:7,M/E]S96YD0VUD*"<B)R`N(&)A<V4V-%]E;F-O9&4H)'5S97(I
M("X@)R(G*3L*("`@("`@("`@("`@)'1H:7,M/E]S96YD0VUD*"<B)R`N(&)A
M<V4V-%]E;F-O9&4H)'!A<W,I("X@)R(G*3L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9B@G075T:&5N=&EC871I;VX@;65C:&%N:7-M("5S
M(&YO="!S=7!P;W)T960@8GD@=&AI<R!C;&EE;G0N)RP@)&QO9VEN='EP92DI
M.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H(5!%05(Z.FES17)R
M;W(H)')E<R`]("1T:&ES+3Y?9V5T4F5S<&]N<V4H*2DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]S=&%T92`]($Y%5%]3245615]35$%415]44D%.4T%#5$E/
M3CL*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@*B!296UO=F5S(&$@<V-R:7!T(&9R;VT@=&AE('-E<G9E<@H@
M("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'!A<F%M("!S=')I
M;F<@)'-C<FEP=&YA;64@3F%M92!O9B!T:&4@<V-R:7!T('1O(&1E;&5T90H@
M("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@("`@("!4<G5E(&]N('-U8V-E
M<W,L(%!%05)?17)R;W(@;W1H97)W:7-E"B`@("`J+PH@("`@9G5N8W1I;VX@
M7V-M9$1E;&5T95-C<FEP="@D<V-R:7!T;F%M92D*("`@('L*("`@("`@("!I
M9B`H3D547U-)159%7U-4051%7U1204Y304-424].(#T]/2`D=&AI<RT^7W-T
M871E*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5N9$-M9"AS<')I;G1F*"=$
M14Q%5$530U))4%0@(B5S(B<L("1S8W)I<'1N86UE*2D["@H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'1H:7,M/E]G971297-P;VYS
M92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=.;W0@8W5R<F5N=&QY(&EN(%1204Y304-4
M24].('-T871E)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!2
M971R:65V97,@=&AE(&-O;G1E;G1S(&]F('1H92!N86UE9"!S8W)I<'0*("`@
M("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!P87)A;2`@<W1R:6YG
M("1S8W)I<'1N86UE($YA;64@;V8@=&AE('-C<FEP="!T;R!R971R:65V90H@
M("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@("`@("!4:&4@<V-R:7!T(&EF
M('-U8V-E<W-F=6PL(%!%05)?17)R;W(@;W1H97)W:7-E"B`@("`J+PH@("`@
M9G5N8W1I;VX@7V-M9$=E=%-C<FEP="@D<V-R:7!T;F%M92D*("`@('L*("`@
M("`@("!I9B`H3D547U-)159%7U-4051%7U1204Y304-424].(#T]/2`D=&AI
M<RT^7W-T871E*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5N9$-M9"AS<')I
M;G1F*"='15130U))4%0@(B5S(B<L("1S8W)I<'1N86UE*2D["B`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7V=E=%)E<W!O
M;G-E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!P<F5G7W)E
M<&QA8V4H)R][6S`M.5TK?5QR7&XO)RP@)R<L("1R97,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)TYO="!C=7)R96YT;'D@:6X@5%)!3E-!0U1)3TX@<W1A
M=&4G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(%-E=',@=&AE
M($%#5$E612!S8W)I<'0L(&EE('1H92!O;F4@=&AA="!G971S(')U;B!O;B!N
M97<@;6%I;`H@("`@*B!B>2!T:&4@<V5R=F5R"B`@("`J"B`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@*B!`<&%R86T@('-T<FEN9R`D<V-R:7!T;F%M92!4
M:&4@;F%M92!O9B!T:&4@<V-R:7!T('1O(&UA<FL@87,@86-T:79E"B`@("`J
M($!R971U<FX@;6EX960@("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@
M4$5!4E]%<G)O<B!O=&AE<G=I<V4*("`@("HO"B`@("!F=6YC=&EO;B!?8VUD
M4V5T06-T:79E*"1S8W)I<'1N86UE*0H@("`@>PH@("`@("`@(&EF("A.151?
M4TE%5D5?4U1!5$5?5%)!3E-!0U1)3TX@/3T]("1T:&ES+3Y?<W1A=&4I('L*
M("`@("`@("`@("`@)'1H:7,M/E]S96YD0VUD*'-P<FEN=&8H)U-%5$%#5$E6
M12`B)7,B)RP@)'-C<FEP=&YA;64I*3L*"B`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7V=E=%)E<W!O;G-E*"DI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?86-T:79E4V-R:7!T(#T@)'-C
M<FEP=&YA;64["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=.;W0@8W5R<F5N=&QY(&EN(%1204Y304-424].
M('-T871E)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!396YD
M<R!T:&4@3$E35%-#4DE05%,@8V]M;6%N9`H@("`@*@H@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("H@0')E='5R;B!M:7AE9"!4=V\@:71E;2!A<G)A>2!O
M9B!S8W)I<'1S+"!A;F0@86-T:79E('-C<FEP="!O;B!S=6-C97-S+`H@("`@
M*B`@("`@("`@("`@("`@(%!%05)?17)R;W(@;W1H97)W:7-E+@H@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;61,:7-T4V-R:7!T<R@I"B`@("!["B`@("`@("`@
M:68@*$Y%5%]3245615]35$%415]44D%.4T%#5$E/3B`]/3T@)'1H:7,M/E]S
M=&%T92D@>PH@("`@("`@("`@("`D<V-R:7!T<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@("1A8W1I=F5S8W)I<'0@/2!N=6QL.PH@("`@("`@("`@("`D=&AI
M<RT^7W-E;F1#;60H)TQ)4U130U))4%13)RD["B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7V=E=%)E<W!O;G-E*"DI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R97,@/2!E>'!L;V1E*")<<EQN(BP@
M)')E<RD["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5S(&%S("1V86QU
M92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7B(H
M+BHI(B@@04-4259%*3\D+VDG+"`D=F%L=64L("1M871C:&5S*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<V-R:7!T<UM=(#T@)&UA=&-H97-;,5T[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&UA=&-H97-;
M,ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D86-T:79E<V-R
M:7!T(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH)'-C<FEP=',L("1A8W1I=F5S8W)I
M<'0I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO="!C=7)R96YT;'D@:6X@
M5%)!3E-!0U1)3TX@<W1A=&4G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`J(%-E;F1S('1H92!055130U))4%0@8V]M;6%N9"!T;R!A9&0@82!S
M8W)I<'0@=&\*("`@("H@=&AE('-E<G9E<BX*("`@("H*("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`J($!P87)A;2`@<W1R:6YG("1S8W)I<'1N86UE($YA
M;64@;V8@=&AE(&YE=R!S8W)I<'0*("`@("H@0'!A<F%M("!S=')I;F<@)'-C
M<FEP=&1A=&$@5&AE(&YE=R!S8W)I<'0*("`@("H@0')E='5R;B!M:7AE9"`@
M("`@("`@("`@("`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]T:&5R
M=VES90H@("`@*B\*("`@(&9U;F-T:6]N(%]C;610=7138W)I<'0H)'-C<FEP
M=&YA;64L("1S8W)I<'1D871A*0H@("`@>PH@("`@("`@(&EF("A.151?4TE%
M5D5?4U1!5$5?5%)!3E-!0U1)3TX@/3T]("1T:&ES+3Y?<W1A=&4I('L*("`@
M("`@("`@("`@)'1H:7,M/E]S96YD0VUD*'-P<FEN=&8H)U!55%-#4DE05"`B
M)7,B('LE9"M])RP@)'-C<FEP=&YA;64L('-T<FQE;B@D<V-R:7!T9&%T82DI
M*3L*("`@("`@("`@("`@)'1H:7,M/E]S96YD0VUD*"1S8W)I<'1D871A*3L*
M("`@("`@("`@("`@:68@*"%014%2.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^
M7V=E=%)E<W!O;G-E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO="!C=7)R96YT;'D@
M:6X@5%)!3E-!0U1)3TX@<W1A=&4G*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`J(%-E;F1S('1H92!,3T=/550@8V]M;6%N9"!A;F0@=&5R;6EN
M871E<R!T:&4@8V]N;F5C=&EO;@H@("`@*@H@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("H@0')E='5R;B!M:7AE9"!4<G5E(&]N('-U8V-E<W,L(%!%05)?
M17)R;W(@;W1H97)W:7-E"B`@("`J+PH@("`@9G5N8W1I;VX@7V-M9$QO9V]U
M="@I"B`@("!["B`@("`@("`@:68@*$Y%5%]3245615]35$%415]$25-#3TY.
M14-4140@(3T]("1T:&ES+3Y?<W1A=&4I('L*("`@("`@("`@("`@)'1H:7,M
M/E]S96YD0VUD*"=,3T=/550G*3L*("`@("`@("`@("`@:68@*"%014%2.CII
M<T5R<F]R*"1R97,@/2`D=&AI<RT^7V=E=%)E<W!O;G-E*"DI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-O8VLM/F1I<V-O;FYE8W0H*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<W1A=&4@/2!.151?4TE%5D5?4U1!5$5?1$E3
M0T].3D5#5$5$.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=.;W0@8W5R<F5N=&QY(&-O;FYE8W1E
M9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("H@4V5N9',@=&AE
M($-!4$%"24Q)5%D@8V]M;6%N9`H@("`@*@H@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("H@0')E='5R;B!M:7AE9"!4<G5E(&]N('-U8V-E<W,L(%!%05)?
M17)R;W(@;W1H97)W:7-E"B`@("`J+PH@("`@9G5N8W1I;VX@7V-M9$-A<&%B
M:6QI='DH*0H@("`@>PH@("`@("`@(&EF("A.151?4TE%5D5?4U1!5$5?5%)!
M3E-!0U1)3TX@/3T]("1T:&ES+3Y?<W1A=&4I('L*("`@("`@("`@("`@)'1H
M:7,M/E]S96YD0VUD*"=#05!!0DE,2519)RD["B`@("`@("`@("`@(&EF("@A
M4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'1H:7,M/E]G971297-P;VYS92@I*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S94-A<&%B:6QI='DH)')E
M<RD["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)TYO="!C=7)R96YT;'D@:6X@5%)!3E-!0U1)3TX@
M<W1A=&4G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(%!A<G-E
M<R!T:&4@<F5S<&]N<V4@9G)O;2!T:&4@8V%P86)I;&ET>2!C;VUM86YD+B!3
M=&]R97,*("`@("H@=&AE(')E<W5L="!I;B`D=&AI<RT^7V-A<&%B:6QI='D*
M("`@("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I
M;VX@7W!A<G-E0V%P86)I;&ET>2@D9&%T82D*("`@('L*("`@("`@("`D9&%T
M82`]('!R96=?<W!L:70H)R]<<C]<;B\G+"`D9&%T82P@+3$L(%!214=?4U!,
M251?3D]?14U05%DI.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N
M="@D9&%T82D[("1I*RLI('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R]>(BA;82UZ72LI(B`H(B@N*BDB*3\D+VDG+"`D9&%T85LD:5TL("1M871C
M:&5S*2D@>PH@("`@("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*"1M
M871C:&5S6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VEM<&QE
M;65N=&%T:6]N)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M87!A8FEL:71Y6R=I;7!L96UE;G1A=&EO;B==(#T@)&UA=&-H97-;,UT["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M("`@("!C87-E("=S87-L)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C87!A8FEL:71Y6R=S87-L)UT@/2!P<F5G7W-P;&ET*"<O7',K+R<L
M("1M871C:&5S6S-=*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W-I979E)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C87!A8FEL:71Y6R=E>'1E;G-I;VYS
M)UT@/2!P<F5G7W-P;&ET*"<O7',K+R<L("1M871C:&5S6S-=*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)W-T87)T=&QS)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C87!A8FEL:71Y6R=S=&%R='1L<R==(#T@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("H@4V5N9',@82!C;VUM86YD('1O('1H92!S97)V97(*("`@("H*
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!P87)A;2!S=')I;F<@)&-M
M9"!4:&4@8V]M;6%N9"!T;R!S96YD"B`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M;F1#;60H)&-M9"D*("`@('L*("`@("`@("`D=&AI<RT^7W-O8VLM/G=R:71E
M3&EN92@D8VUD*3L*("`@('T*"B`@("`O*BH*("`@("H@4F5T<FEE=F5S(&$@
M<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R(&%N9"P@=&\@82!C97)T86EN(&1E
M9W)E92P*("`@("H@<&%R<V5S(&ET+@H@("`@*@H@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("H@0')E='5R;B!M:7AE9"!297!O;G-E('-T<FEN9R!I9B!A
M;B!/2R!R97-P;VYS92P@4$5!4E]%<G)O<B!I9B!A($Y/(')E<W!O;G-E"B`@
M("`J+PH@("`@9G5N8W1I;VX@7V=E=%)E<W!O;G-E*"D*("`@('L*("`@("`@
M("`D<F5S<&]N<V4@/2`G)SL*"B`@("`@("`@=VAI;&4@*'1R=64I('L*("`@
M("`@("`@("`@)&QI;F4@/2`D=&AI<RT^7W-O8VLM/G)E861,:6YE*"D["B`@
M("`@("`@("`@(&EF("@G;VLG(#T]('-T<G1O;&]W97(H<W5B<W1R*"1L:6YE
M+"`P+"`R*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!R=')I;2@D<F5S
M<&]N<V4I.PH*("`@("`@("`@("`@?2!E;'-E:68@*"=N;R<@/3T@<W1R=&]L
M;W=E<BAS=6)S='(H)&QI;F4L(#`L(#(I*2D@>PH@("`@("`@("`@("`@("`@
M+R\@0VAE8VL@9F]R('-T<FEN9R!L:71E<F%L(&5R<F]R(&UE<W-A9V4*("`@
M("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7FYO('LH6S`M.5TK*5PK
M/WTO:2<L("1L:6YE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@
M("`D;&EN92`N/2!S=')?<F5P;&%C92@B7')<;B(L("<@)RP@)'1H:7,M/E]S
M;V-K+3YR96%D*"1M871C:&5S6S%=*2D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAT<FEM*"1R
M97-P;VYS92`N('-U8G-T<B@D;&EN92P@,BDI*3L*("`@("`@("`@("`@?2!E
M;'-E:68@*"=B>64G(#T]('-T<G1O;&]W97(H<W5B<W1R*"1L:6YE+"`P+"`S
M*2DI('L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7F)Y92!<
M*"AR969E<G)A;"D@(BA;7B)=*RDO:2<L("1L:6YE+"`D;6%T8VAE<RDI('L*
M("`@("`@("`@("`@("`@("`@("`D;&EN92`]("1M871C:&5S6S%=("X@(B`B
M("X@)&UA=&-H97-;,ET["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAT<FEM*"1R97-P;VYS92`N
M("1L:6YE*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-P;VYS
M92`N/2`D;&EN92`N(")<<EQN(CL*("`@("`@("!]"B`@("!]"GT*"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B\`````````````
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,S`P-@`P,34V,S``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+T1"+V9B<W%L+G!H<```````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#0U,S4W`#$P-#$W,S8S,#`V`#`Q-S0V,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!F;VQD
M;65T:&]D/6UA<FME<CH@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@
M=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!&<F%N:R!-+B!+<F]M86YN
M(#QF<F%N:T!F<F]N=&)A<V4N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($UA:6YT86EN97(Z($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@9F)S<6PN<&AP+'8@,2XS
M,2`R,#`T+S`R+S$X(#`U.C,W.C,Q(&1A;FEE;&,@17AP("0*"@HO+R!86%@@
M;&5G96YD.@HO+PHO+R!86%@@15)23U)-4T<Z(%1H92!E<G)O<B!M97-S86=E
M(&9R;VT@=&AE(&9B<W%L(&9U;F-T:6]N('-H;W5L9`HO+R`@("`@("`@("`@
M("`@(&)E(')E9VES=&5R960@:&5R92X*+R\*+R\@5$]$3R]W:7-H;&ES=#H*
M+R\@;&]N9U)E861L96X*+R\@8FEN;6]D90H*"G)E<75I<F5?;VYC92`G1$(O
M8V]M;6]N+G!H<"<["@HO*BH*("H@1&%T86)A<V4@:6YD97!E;F1E;G0@<75E
M<GD@:6YT97)F86-E(&1E9FEN:71I;VX@9F]R(%!(4"=S($9R;VYT0F%S90H@
M*B!E>'1E;G-I;VXN"B`J"B`J($!P86-K86=E("!$0@H@*B!`=F5R<VEO;B`@
M)$ED.B!F8G-Q;"YP:'`L=B`Q+C,Q(#(P,#0O,#(O,3@@,#4Z,S<Z,S$@9&%N
M:65L8R!%>'`@)`H@*B!`8V%T96=O<GD@1&%T86)A<V4*("H@0&%U=&AO<B`@
M($9R86YK($TN($MR;VUA;FX@/&9R86YK0&9R;VYT8F%S92YC;VT^"B`J+PIC
M;&%S<R!$0E]F8G-Q;"!E>'1E;F1S($1"7V-O;6UO;@I["B`@("`O+R![>WL@
M<')O<&5R=&EE<PH*("`@('9A<B`D8V]N;F5C=&EO;CL*("`@('9A<B`D<&AP
M='EP92P@)&1B<WEN=&%X.PH@("`@=F%R("1P<F5P87)E7W1O:V5N<R`](&%R
M<F%Y*"D["B`@("!V87(@)'!R97!A<F5?='EP97,@/2!A<G)A>2@I.PH@("`@
M=F%R("1N=6U?<F]W<R`](&%R<F%Y*"D["B`@("!V87(@)&9E=&-H;6]D92`]
M($1"7T9%5$-(34]$15]/4D1%4D5$.R`O*B!$969A=6QT(&9E=&-H(&UO9&4@
M*B\*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J
M*@H@("`@("H@1$)?9F)S<6P@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?9F)S<6PH
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@("`@("`D
M=&AI<RT^<&AP='EP92`]("=F8G-Q;"<["B`@("`@("`@)'1H:7,M/F1B<WEN
M=&%X(#T@)V9B<W%L)SL*("`@("`@("`D=&AI<RT^9F5A='5R97,@/2!A<G)A
M>2@*("`@("`@("`@("`@)W!R97!A<F4G(#T^(&9A;'-E+`H@("`@("`@("`@
M("`G<&-O;FYE8W0G(#T^('1R=64L"B`@("`@("`@("`@("=T<F%N<V%C=&EO
M;G,G(#T^('1R=64L"B`@("`@("`@("`@("=L:6UI="<@/3X@)V5M=6QA=&4G
M"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<"`](&%R
M<F%Y*`H@("`@("`@("`@("`Q,#`T(#T^($1"7T524D]27T-!3DY/5%]#4D5!
M5$4L"B`@("`@("`@("`@(#$P,#4@/3X@1$)?15)23U)?0T%.3D]47T-214%4
M12P*("`@("`@("`@("`@,3`P-B`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%
M+`H@("`@("`@("`@("`Q,#`W(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13
M+`H@("`@("`@("`@("`Q,#`X(#T^($1"7T524D]27T-!3DY/5%]$4D]0+`H@
M("`@("`@("`@("`Q,#0V(#T^($1"7T524D]27TY/1$)314Q%0U1%1"P*("`@
M("`@("`@("`@,3`U,"`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@
M("`@("`@("`@,3`U,2`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@
M("`@("`@,3`U-"`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@
M("`@,3`V,B`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@
M("`@,3`V-"`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@(#$Q,#`@
M/3X@1$)?15)23U)?3D]47TQ/0TM%1"P*("`@("`@("`@("`@,3$S-B`]/B!$
M0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@("`@(#$Q-#8@
M/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J
M($-O;FYE8W0@=&\@82!D871A8F%S92!A;F0@;&]G(&EN(&%S('1H92!S<&5C
M:69I960@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@)&1S;B!T:&4@9&%T
M82!S;W5R8V4@;F%M92`H<V5E($1".CIP87)S94133B!F;W(@<WEN=&%X*0H@
M("`@("H@0'!A<F%M("1P97)S:7-T96YT("AO<'1I;VYA;"D@=VAE=&AE<B!T
M:&4@8V]N;F5C=&EO;B!S:&]U;&0*("`@("`J("`@("`@("!B92!P97)S:7-T
M96YT"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@
M1$)?3TL@;VX@<W5C8V5S<RP@82!$0B!E<G)O<B!O;B!F86EL=7)E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;FEN9F\L("1P97)S:7-T96YT
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%$0CHZ87-S97)T17AT96YS
M:6]N*"=F8G-Q;"<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YD<VX@/2`D9'-N:6YF;SL*("`@("`@("`D
M9&)H;W-T(#T@)&1S;FEN9F];)VAO<W1S<&5C)UT@/R`D9'-N:6YF;ULG:&]S
M='-P96,G72`Z("=L;V-A;&AO<W0G.PH*("`@("`@("`D<&AP7V5R<F]R;7-G
M(#T@)R<["B`@("`@("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N
M="`_("=F8G-Q;%]P8V]N;F5C="<@.B`G9F)S<6Q?8V]N;F5C="<["@H@("`@
M("`@(&EF("@D9&)H;W-T("8F("1D<VYI;F9O6R=U<V5R;F%M92==("8F("1D
M<VYI;F9O6R=P87-S=V]R9"==*2!["B`@("`@("`@("`@("1C;VYN(#T@0"1C
M;VYN96-T7V9U;F-T:6]N*"1D8FAO<W0L("1D<VYI;F9O6R=U<V5R;F%M92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'-N
M:6YF;ULG<&%S<W=O<F0G72D["B`@("`@("`@?2!E;'-E:68@*"1D8FAO<W0@
M)B8@)&1S;FEN9F];)W5S97)N86UE)UTI('L*("`@("`@("`@("`@)&-O;FX@
M/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1B:&]S="P@)&1S;FEN9F];)W5S97)N
M86UE)UTI.PH@("`@("`@('T@96QS96EF("@D9&)H;W-T*2!["B`@("`@("`@
M("`@("1C;VYN(#T@0"1C;VYN96-T7V9U;F-T:6]N*"1D8FAO<W0I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1C;VYN(#T@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@(&EF("@A)&-O;FXI('L*("`@("`@("`@("`@:68@*&5M
M<'1Y*"1P:'!?97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&YU;&PL("1P:'!?97)R;W)M<V<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&1S;FEN9F];)V1A=&%B87-E)UTI('L*("`@
M("`@("`@("`@:68@*"%F8G-Q;%]S96QE8W1?9&(H)&1S;FEN9F];)V1A=&%B
M87-E)UTL("1C;VYN*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YF8G-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2`D8V]N;CL*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES
M8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!,;V<@;W5T(&%N9"!D:7-C;VYN
M96-T(&9R;VT@=&AE(&1A=&%B87-E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C
M8V5S<RP@1D%,4T4@:68@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`](&9B<W%L
M7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N
M;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@
M("`@("H@4V5N9"!A('%U97)Y('1O(&9B<W%L(&%N9"!R971U<FX@=&AE(')E
M<W5L=',@87,@82!F8G-Q;"!R97-O=7)C90H@("`@("H@:61E;G1I9FEE<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@=&AE(%-13"!Q=65R>0H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!R971U<FYS(&$@=F%L:60@9F)S<6P@<F5S=6QT(&9O<B!S=6-C97-S9G5L
M(%-%3$5#5`H@("`@("H@<75E<FEE<RP@1$)?3TL@9F]R(&]T:&5R('-U8V-E
M<W-F=6P@<75E<FEE<RX@($$@1$(@97)R;W(@:7,*("`@("`J(')E='5R;F5D
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y
M*"1Q=65R>2D*("`@('L*("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q
M=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)'%U
M97)Y*3L*("`@("`@("`D<F5S=6QT(#T@0&9B<W%L7W%U97)Y*"(D<75E<GD[
M(BP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O<B@I
M.PH@("`@("`@('T*("`@("`@("`O+R!$971E<FUI;F4@=VAI8V@@<75E<FEE
M<R!T:&%T('-H;W5L9"!R971U<FX@9&%T82P@86YD('=H:6-H"B`@("`@("`@
M+R\@<VAO=6QD(')E='5R;B!A;B!E<G)O<B!C;V1E(&]N;'DN"B`@("`@("`@
M:68@*$1".CII<TUA;FEP*"1Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N
M($1"7T]+.PH@("`@("`@('T*("`@("`@("`D;G5M<F]W<R`]("1T:&ES+3YN
M=6UR;W=S*"1R97-U;'0I.PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&YU;7)O
M=W,I*2!["B`@("`@("`@("`@(')E='5R;B`D;G5M<F]W<SL*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/FYU;5]R;W=S6R1R97-U;'1=(#T@)&YU;7)O=W,[
M"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H
M92!I;G1E<FYA;"!F8G-Q;"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A
M=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@
M9F)S<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('1R=64@:68@82!R97-U;'0@
M:7,@879A:6QA8FQE(&]T:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@
M("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@
M(')E='5R;B!`9F)S<6Q?;F5X=%]R97-U;'0H)')E<W5L="D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@
M("`J($9E=&-H(&$@<F]W(&%N9"!I;G-E<G0@=&AE(&1A=&$@:6YT;R!A;B!E
M>&ES=&EN9R!A<G)A>2X*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE
M(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N
M"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I
M;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E
M<W5L="`@("!Q=65R>2!R97-U;'0@:61E;G1I9FEE<@H@("`@("H@0'!A<F%M
M(&%R<F%Y("`@("1A<G(@("`@("`@*')E9F5R96YC92D@87)R87D@=VAE<F4@
M9&%T82!F<F]M('1H92!R;W<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-H;W5L9"!B92!P;&%C960*("`@("`J($!P87)A;2!I;G0@("`@
M("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B
M92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT("`@("`@)')O=VYU;2`@("!T
M:&4@<F]W(&YU;6)E<B!T;R!F971C:`H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N(&5N9"!O9B!R97-U
M;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@("`@(')E86-H960@;W(@;VX@
M9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN
M=&\H*0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O
M=VYU;3UN=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL
M*2!["B`@("`@("`@("`@(&EF("@A0&9B<W%L7V1A=&%?<V5E:R@D<F5S=6QT
M+"`D<F]W;G5M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@
M)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@("`@("`@)&%R<B`]($!F
M8G-Q;%]F971C:%]A<G)A>2@D<F5S=6QT+"!&0E-13%]!4U-/0RD["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"
M7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D87)R*2!["B`@("`@("`@("`@
M("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?
M3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&%R<B`]($!F8G-Q;%]F971C:%]R;W<H)')E<W5L="D["B`@("`@
M("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@("`@("`@("`@("`D97)R;F\@
M/2!`9F)S<6Q?97)R;F\H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@
M("!I9B`H(21E<G)N;RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N($Y53$P[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF8G-Q
M;%)A:7-E17)R;W(H)&5R<FYO*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?
M4E1224TI('L*("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L=65S
M*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-4%19
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A;'5E
M<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4F5S=6QT*"D*
M"B`@("`O*BH*("`@("`J($9R964@=&AE(&EN=&5R;F%L(')E<V]U<F-E<R!A
M<W-O8VEA=&5D('=I=&@@)')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@
M)')E<W5L="!F8G-Q;"!R97-U;'0@:61E;G1I9FEE<@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L(%12
M544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I;G9A;&ED"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9R965297-U;'0H)')E<W5L="D*("`@('L*
M("`@("`@("!R971U<FX@0&9B<W%L7V9R965?<F5S=6QT*"1R97-U;'0I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@
M(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N;V9F/69A;'-E*0H@("`@>PH@("`@
M("`@(&EF("@D;VYO9F8I('L*("`@("`@("`@("`@)'1H:7,M/G%U97)Y*")3
M150@0T]-34E4(%12544B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^<75E<GDH(E-%5"!#3TU-250@1D%,4T4B*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@("!F
M=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@(&9B<W%L7V-O;6UI="@I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@
M("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@("`@("`@9F)S<6Q?<F]L
M;&)A8VLH*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS
M*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@
M:6X@82!R97-U;'0@<V5T+@H@("`@("H*("`@("`J($!P87)A;2`D<F5S=6QT
M(&9B<W%L(')E<W5L="!I9&5N=&EF:65R"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@;G5M8F5R
M(&]F(&-O;'5M;G,@<&5R(')O=R!I;B`D<F5S=6QT"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@("`@("`D8V]L<R`]
M($!F8G-Q;%]N=6U?9FEE;&1S*"1R97-U;'0I.PH*("`@("`@("!I9B`H(21C
M;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F)S<6Q286ES945R
M<F]R*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;',["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@
M("`@*B!'970@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S=6QT('-E="X*
M("`@("`J"B`@("`@*B!`<&%R86T@)')E<W5L="!F8G-Q;"!R97-U;'0@:61E
M;G1I9FEE<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@=&AE(&YU;6)E<B!O9B!R;W=S(&EN("1R97-U
M;'0*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@
M>PH@("`@("`@("1R;W=S(#T@0&9B<W%L7VYU;5]R;W=S*"1R97-U;'0I.PH@
M("`@("`@(&EF("@D<F]W<R`]/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E
M<B!O9B!R;W=S(&%F9F5C=&5D(&)Y('1H92!D871A(&UA;FEP=6QA=&EO;@H@
M("`@("H@<75E<GDN("!&;W(@;W1H97(@<75E<FEE<RP@=&AI<R!F=6YC=&EO
M;B!R971U<FYS(#`N"B`@("`@*@H@("`@("H@0')E='5R;B!N=6UB97(@;V8@
M<F]W<R!A9F9E8W1E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("A$0CHZ
M:7--86YI<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*("`@("`@("`@("`@)')E
M<W5L="`]($!F8G-Q;%]A9F9E8W1E9%]R;W=S*"1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@,#L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@
M("`J($=E="!T:&4@;F%T:79E(&5R<F]R(&-O9&4@;V8@=&AE(&QA<W0@97)R
M;W(@*&EF(&%N>2D@=&AA=`H@("`@("H@;V-C=7)E9"!O;B!T:&4@8W5R<F5N
M="!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@;F%T:79E(&9B<W%L(&5R<F]R(&-O
M9&4*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!F8G-Q;%]E<G)N;R@D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E
M;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N
M86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N
M9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L
M;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I
M9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+B`@1$)?17)R
M;W(@:68@<')O8FQE;2X*("`@("`J"B`@("`@*B!`:6YT97)N86P*("`@("`J
M($!S964@1$)?8V]M;6]N.CIN97AT240H*0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N
M9&5M86YD(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES
M+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("`D<F5P96%T
M(#T@,#L*("`@("`@("!D;R!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^<75E<GDH(DE.4T525"!)3E1/("1[<V5Q;F%M97T@5D%,5453*$Y53$PI
M(BD["B`@("`@("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H
M)')E<W5L="D@)B8*("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H
M*2`]/2!$0E]%4E)/4E].3U-50TA404),12D@>PH@("`@("`@("`@("`@("`@
M)')E<&5A="`](#$["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97!E870@/2`P.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["B`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F)S<6Q?:6YS
M97)T7VED*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E<75E;F-E
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N
M("!!($1"7T5R<F]R(&]B:F5C="!I<R!R971U<FYE9"!I9@H@("`@("H@("`@
M("`@("`@("`@('!R;V)L96US(&%R:7-E+@H@("`@("H*("`@("`J($!I;G1E
M<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"D*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R
M96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("`D<V5Q;F%M
M92`]("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@
M("!R971U<FX@)'1H:7,M/G%U97)Y*")#4D5!5$4@5$%"3$4@)'MS97%N86UE
M?2`B+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RAI9"!)3E1%1T52
M(%5.4TE'3D5$($%55$]?24Y#4D5-14Y4($Y/5"!.54Q,+"<N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G(%!224U!4ED@2T59*&ED*2DG*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E
M('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?
M3TL@;VX@<W5C8V5S<RX@($1"7T5R<F]R(&EF('!R;V)L96US+@H@("`@("H*
M("`@("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!3
M97%U96YC92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@
M("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I
M.PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH(D123U`@5$%"3$4@)'MS
M97%N86UE?2!215-44DE#5"(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&UO9&EF>5%U97)Y*"D*"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R>2@D
M<75E<GDI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T
M86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4*2!["B`@
M("`@("`@("`@("\O(")$14Q%5$4@1E)/32!T86)L92(@9VEV97,@,"!A9F9E
M8W1E9"!R;W=S(&EN(&9B<W%L+@H@("`@("`@("`@("`O+R!4:&ES(&QI='1L
M92!H86-K(&QE=',@>6]U(&MN;W<@:&]W(&UA;GD@<F]W<R!W97)E(&1E;&5T
M960N"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EQS*D1%3$5415QS
M*T923TU<<RLH7%,K*5QS*B0O:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@
M("`@("1Q=65R>2`]('!R96=?<F5P;&%C92@G+UY<<RI$14Q%5$5<<RM&4D]-
M7',K*%Q3*RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)T1%3$5412!&4D]-(%PQ(%=(15)%(#$],2<L("1Q=65R>2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1Q=65R
M>3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T95-M87)T*"D*
M"B`@("`O*BH*("`@("`J($9O<FUA="!I;G!U="!S;R!I="!C86X@8F4@<V%F
M96QY('5S960@:6X@82!Q=65R>0H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`D:6X@(&1A=&$@=&\@8F4@<75O=&5D"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!3=6)M:71T960@=F%R:6%B;&4G<R!T>7!E(#T@<F5T=7)N960@
M=F%L=64Z"B`@("`@*B`@("`@("`@("`@("`@("L@;G5L;"`]('1H92!S=')I
M;F<@/'-A;7`^3E5,3#PO<V%M<#X*("`@("`J("`@("`@("`@("`@("`@*R!B
M;V]L96%N(#T@<W1R:6YG(#QS86UP/E12544\+W-A;7`^(&]R(#QS86UP/D9!
M3%-%/"]S86UP/@H@("`@("H@("`@("`@("`@("`@("`K(&EN=&5G97(@;W(@
M9&]U8FQE(#T@=&AE('5N<75O=&5D(&YU;6)E<@H@("`@("H@("`@("`@("`@
M("`@("`K(&]T:&5R("AI;F-L=61I;F<@<W1R:6YG<R!A;F0@;G5M97)I8R!S
M=')I;F=S*2`]"B`@("`@*B`@("`@("`@("`@("`@("`@=&AE(&1A=&$@97-C
M87!E9"!A8V-O<F1I;F<@=&\@37E344PG<R!S971T:6YG<PH@("`@("H@("`@
M("`@("`@("`@("`@('1H96X@96YC87!S=6QA=&5D(&)E='=E96X@<VEN9VQE
M('%U;W1E<PH@("`@("H*("`@("`J($!I;G1E<FYA;`H@("`@("HO"B`@("!F
M=6YC=&EO;B!Q=6]T95-M87)T*"1I;BD*("`@('L*("`@("`@("!I9B`H:7-?
M:6YT*"1I;BD@?'P@:7-?9&]U8FQE*"1I;BDI('L*("`@("`@("`@("`@<F5T
M=7)N("1I;CL*("`@("`@("!](&5L<V5I9B`H:7-?8F]O;"@D:6XI*2!["B`@
M("`@("`@("`@(')E='5R;B`D:6X@/R`G5%)512<@.B`G1D%,4T4G.PH@("`@
M("`@('T@96QS96EF("AI<U]N=6QL*"1I;BDI('L*("`@("`@("`@("`@<F5T
M=7)N("=.54Q,)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@(B<B("X@)'1H:7,M/F5S8V%P95-I;7!L92@D:6XI("X@(B<B.PH@("`@
M("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F8G-Q;%)A:7-E
M17)R;W(H*0H*("`@("\J*@H@("`@("H@1V%T:&5R(&EN9F]R;6%T:6]N(&%B
M;W5T(&%N(&5R<F]R+"!T:&5N('5S92!T:&%T(&EN9F\@=&\@8W)E871E(&$*
M("`@("`J($1"(&5R<F]R(&]B:F5C="!A;F0@9FEN86QL>2!R971U<FX@=&AA
M="!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M("!I;G1E9V5R("`D97)R
M;F\@(%!%05(@97)R;W(@;G5M8F5R("AU<W5A;&QY(&$@1$(@8V]N<W1A;G0I
M(&EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@;6%N=6%L;'D@
M<F%I<VEN9R!A;B!E<G)O<@H@("`@("H@0')E='5R;B!O8FIE8W0@($1"(&5R
M<F]R(&]B:F5C=`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F5R<F]R0V]D92@I
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9B<W%L4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@
M("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92AF8G-Q;%]E<G)N;R@D=&AI
M<RT^8V]N;F5C=&EO;BDI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+`H@("`@
M("`@("`@("`@("`@("`@("`@("!F8G-Q;%]E<G)O<B@D=&AI<RT^8V]N;F5C
M=&EO;BDI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF
M;R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T
M(&$@=&%B;&4@;W(@82!R97-U;'0@<V5T+@H@("`@("H*("`@("`J($!P87)A
M;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R
M;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T86)L
M90H@("`@("H@0'!A<F%M(&EN="`@("`@("`@("`@("1M;V1E("`@(&$@=F%L
M:60@=&%B;&5);F9O(&UO9&4*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S
M<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E
M9`H@("`@("H@("`@("`@("`@("`@("`@;W(@86X@97)R;W(@;V)J96-T(&EF
M('-O;65T:&EN9R!I<R!W<F]N9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF
M;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D
M;6]D92`](&YU;&PI('L*("`@("`@("!I9B`H:7-S970H)')E<W5L="T^<F5S
M=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L
M>2!R96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X
M=')A8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@
M("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@
M("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS
M96EF("AI<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@
M("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@
M("`@("`@("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I
M9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]($!F8G-Q
M;%]L:7-T7V9I96QD<R@D=&AI<RT^9'-N6R=D871A8F%S92==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="P@)'1H:7,M
M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@
M("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I
M9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I="X*("`@("`@("`@("`@("H@
M1&5P<FEC871E9"X@($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*("`@
M("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0["B`@("`@
M("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(6ES7W)E<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YF8G-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!
M5$$I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P
M;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@
M("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@
M("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@0&9B<W%L7VYU;5]F:65L9',H
M)&ED*3L*"B`@("`@("`@+R\@;6%D92!T:&ES($E&(&1U92!T;R!P97)F;W)M
M86YC92`H;VYE(&EF(&ES(&9A<W1E<B!T:&%N("1C;W5N="!I9B=S*0H@("`@
M("`@(&EF("@A)&UO9&4I('L*("`@("`@("`@("`@9F]R("@D:3TP.R`D:3PD
M8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@("`@("1R97-;)&E=6R=T86)L
M92==(#T@)&-A<V5?9G5N8RA`9F)S<6Q?9FEE;&1?=&%B;&4H)&ED+"`D:2DI
M.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)VYA;64G72`@/2`D8V%S95]F
M=6YC*$!F8G-Q;%]F:65L9%]N86UE*"1I9"P@)&DI*3L*("`@("`@("`@("`@
M("`@("1R97-;)&E=6R=T>7!E)UT@(#T@0&9B<W%L7V9I96QD7W1Y<&4H)&ED
M+"`D:2D["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG;&5N)UT@("`]($!F
M8G-Q;%]F:65L9%]L96XH)&ED+"`D:2D["B`@("`@("`@("`@("`@("`D<F5S
M6R1I75LG9FQA9W,G72`]($!F8G-Q;%]F:65L9%]F;&%G<R@D:60L("1I*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![("\O(&9U;&P*("`@("`@
M("`@("`@)')E<ULB;G5M7V9I96QD<R)=/2`D8V]U;G0["@H@("`@("`@("`@
M("!F;W(@*"1I/3`[("1I/"1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)')E<ULD:5U;)W1A8FQE)UT@/2`D8V%S95]F=6YC*$!F8G-Q;%]F:65L
M9%]T86)L92@D:60L("1I*2D["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG
M;F%M92==("`]("1C87-E7V9U;F,H0&9B<W%L7V9I96QD7VYA;64H)&ED+"`D
M:2DI.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)W1Y<&4G72`@/2!`9F)S
M<6Q?9FEE;&1?='EP92@D:60L("1I*3L*("`@("`@("`@("`@("`@("1R97-;
M)&E=6R=L96XG72`@(#T@0&9B<W%L7V9I96QD7VQE;B@D:60L("1I*3L*("`@
M("`@("`@("`@("`@("1R97-;)&E=6R=F;&%G<R==(#T@0&9B<W%L7V9I96QD
M7V9L86=S*"1I9"P@)&DI.PH*("`@("`@("`@("`@("`@(&EF("@D;6]D92`F
M($1"7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@("`@("1R
M97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%
M24Y&3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@("`@("`@("`@("`@)')E<ULG
M;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG;F%M
M92==72`]("1I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W
M92!W97)E(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R
M:6YG*2!["B`@("`@("`@("`@($!F8G-Q;%]F<F5E7W)E<W5L="@D:60I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!G9713<&5C:6%L475E<GDH*0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<75E<GD@;F5E9&5D('1O(&=E="!S;VUE(&)A8VME
M;F0@:6YF;PH@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92!7:&%T(&MI;F0@
M;V8@:6YF;R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@("H@0')E='5R;B!S
M=')I;F<@5&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@>PH@("`@("`@('-W:71C
M:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G=&%B;&5S)SH*("`@("`@
M("`@("`@("`@(')E='5R;B`G<V5L96-T(")T86)L95]N86UE(B!F<F]M(&EN
M9F]R;6%T:6]N7W-C:&5M82YT86)L97,G.PH@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@
M?0H*("`@("\O('U]?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A
M8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+VUS<6PN
M<&AP````````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$U-#`S`#$P-#$W,S8S,#`V`#`Q-S,Q-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A
M;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!F;VQD;65T:&]D/6UA<FME
M<CH@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0
M(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E
M;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R.B!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG0'!H
M<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($UA:6YT
M86EN97(Z($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("1)9#H@;7-Q;"YP:'`L=B`Q+C(R(#(P,#0O,#(O,3@@
M,#4Z,S<Z,S$@9&%N:65L8R!%>'`@)`H*<F5Q=6ER95]O;F-E("=$0B]C;VUM
M;VXN<&AP)SL*"B\J*@H@*B!$871A8F%S92!I;F1E<&5N9&5N="!Q=65R>2!I
M;G1E<F9A8V4@9&5F:6YI=&EO;B!F;W(@4$A0)W,@36EN:2U344P*("H@97AT
M96YS:6]N+@H@*@H@*B!`<&%C:V%G92`@1$(*("H@0'9E<G-I;VX@("1)9#H@
M;7-Q;"YP:'`L=B`Q+C(R(#(P,#0O,#(O,3@@,#4Z,S<Z,S$@9&%N:65L8R!%
M>'`@)`H@*B!`8V%T96=O<GD@1&%T86)A<V4*("H@0&%U=&AO<B`@(%-T97)L
M:6YG($AU9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X*("HO"F-L87-S($1"7VUS
M<6P@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*
M"B`@("!V87(@)&-O;FYE8W1I;VX["B`@("!V87(@)'!H<'1Y<&4L("1D8G-Y
M;G1A>#L*("`@('9A<B`D<')E<&%R95]T;VME;G,@/2!A<G)A>2@I.PH@("`@
M=F%R("1P<F5P87)E7W1Y<&5S(#T@87)R87DH*3L*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!C;VYS=')U8W1O<@H*("`@(&9U;F-T:6]N($1"7VUS<6PH*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@("`@("`D=&AI
M<RT^<&AP='EP92`]("=M<W%L)SL*("`@("`@("`D=&AI<RT^9&)S>6YT87@@
M/2`G;7-Q;"<["B`@("`@("`@)'1H:7,M/F9E871U<F5S(#T@87)R87DH"B`@
M("`@("`@("`@("=P<F5P87)E)R`]/B!F86QS92P*("`@("`@("`@("`@)W!C
M;VYN96-T)R`]/B!T<G5E+`H@("`@("`@("`@("`G=')A;G-A8W1I;VYS)R`]
M/B!F86QS92P*("`@("`@("`@("`@)VQI;6ET)R`]/B`G96UU;&%T92<*("`@
M("`@("`I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H
M*0H*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;FEN9F\L("1P97)S:7-T96YT
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%$0CHZ87-S97)T17AT96YS
M:6]N*"=M<W%L)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VYI;F9O.PH@("`@("`@("1D
M8FAO<W0@/2`D9'-N:6YF;ULG:&]S='-P96,G72`_("1D<VYI;F9O6R=H;W-T
M<W!E8R==(#H@)VQO8V%L:&]S="<["@H@("`@("`@("1C;VYN96-T7V9U;F-T
M:6]N(#T@)'!E<G-I<W1E;G0@/R`G;7-Q;%]P8V]N;F5C="<@.B`G;7-Q;%]C
M;VYN96-T)SL*"B`@("`@("`@:68@*"1D8FAO<W0@)B8@)&1S;FEN9F];)W5S
M97)N86UE)UT@)B8@)&1S;FEN9F];)W!A<W-W;W)D)UTI('L*("`@("`@("`@
M("`@)&-O;FX@/2`D8V]N;F5C=%]F=6YC=&EO;B@D9&)H;W-T+"`D9'-N:6YF
M;ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9'-N:6YF;ULG<&%S<W=O<F0G72D["B`@("`@("`@?2!E;'-E
M:68@*"1D8FAO<W0@)B8@)&1S;FEN9F];)W5S97)N86UE)UTI('L*("`@("`@
M("`@("`@)&-O;FX@/2`D8V]N;F5C=%]F=6YC=&EO;B@D9&)H;W-T+"`D9'-N
M:6YF;ULG=7-E<FYA;64G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&-O;FX@/2`D8V]N;F5C=%]F=6YC=&EO;B@D9&)H;W-T*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"$D8V]N;BD@>PH@("`@("`@("`@("`D=&AI<RT^
M<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"D["B`@("`@("`@
M?0H@("`@("`@(&EF("@A0&US<6Q?<V5L96-T7V1B*"1D<VYI;F9O6R=D871A
M8F%S92==+"`D8V]N;BDI>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2`D8V]N;CL*("`@("`@("!R971U
M<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N
M;F5C="@I"@H@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@
M("`@)')E="`]($!M<W%L7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@
M("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N
M("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E
M<GDH*0H*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*("`@('L*
M("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D
M<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)'%U97)Y*3L*("`@("`@("`D
M<F5S=6QT(#T@0&US<6Q?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO
M;BD["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("`O+R!$
M971E<FUI;F4@=VAI8V@@<75E<FEE<R!T:&%T('-H;W5L9"!R971U<FX@9&%T
M82P@86YD('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E='5R;B!A;B!E<G)O
M<B!C;V1E(&]N;'DN"B`@("`@("`@<F5T=7)N($1".CII<TUA;FEP*"1Q=65R
M>2D@/R!$0E]/2R`Z("1R97-U;'0["B`@("!]"@H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@
M:6YT97)N86P@;7-Q;"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I
M;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@9F)S
M<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('1R=64@:68@82!R97-U;'0@:7,@
M879A:6QA8FQE(&]T:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@("`@
M9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C
M:$EN=&\H*0H*("`@("\J*@H@("`@("H@1F5T8V@@82!R;W<@86YD(&EN<V5R
M="!T:&4@9&%T82!I;G1O(&%N(&5X:7-T:6YG(&%R<F%Y+@H@("`@("H*("`@
M("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E
M:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E
M=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('%U97)Y(')E<W5L="!I9&5N
M=&EF:65R"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@("`@("`H<F5F
M97)E;F-E*2!A<G)A>2!W:&5R92!D871A(&9R;VT@=&AE(')O=PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<VAO=6QD(&)E('!L86-E9`H@
M("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H92!R97-U
M;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P87)A;2!I
M;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!$0E]/2R!O;B!S=6-C97-S+"!.
M54Q,('=H96X@96YD(&]F(')E<W5L="!S970@:7,*("`@("`J("`@("`@("`@
M("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L("8D
M87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M/6YU;&PI"B`@("!["B`@("`@("`@
M:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"%`;7-Q
M;%]D871A7W-E96LH)')E<W5L="P@)')O=VYU;2DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@
M("`@("`@("`@("1A<G(@/2!`;7-Q;%]F971C:%]A<G)A>2@D<F5S=6QT+"!-
M4U%,7T%34T]#*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P
M;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F("1A
M<G(I('L*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y
M7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D87)R(#T@0&US<6Q?9F5T8VA?<F]W
M*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@
M("`@("`@("`@:68@*"1E<G)O<B`](&US<6Q?97)R;W(H*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G)O<BD["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@;G5L
M;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))
M32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R
M<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R
M=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%
M;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@
M(&9U;F-T:6]N(&9R965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R
M971U<FX@0&US<6Q?9G)E95]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@9G5N8W1I;VX@;G5M
M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&US<6Q?;G5M
M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)&-O;',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;G5M4F]W<R@I"@H@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT
M*0H@("`@>PH@("`@("`@("1R;W=S(#T@0&US<6Q?;G5M7W)O=W,H)')E<W5L
M="D["B`@("`@("`@:68@*"$D<F]W<RD@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1R;W=S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D
M*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&%F
M9F5C=&5D(&)Y(&$@<75E<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!N=6UB
M97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("HO
M"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(')E
M='5R;B!`;7-Q;%]A9F9E8W1E9%]R;W=S*"1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@('T*"B`@("`O+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*
M("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*
M("HO"@H_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+T1"+W-Q;&ET92YP:'``````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4T,S(U`#$P-#$W,S8S
M,#`V`#`Q-S8U,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT
M('-H:69T=VED=&@]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@
M?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0
M(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M<SH@57)S($=E:')I9R`\=7)S0&-I<F-L92YC:#X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@($UI:V$@5'5U<&]L
M82`\='5U<&]L84!A<'!E;'-I:6YI+FYE=#X@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!-86EN=&%I;F5R.B!$86YI96P@0V]N=FES<V]R(#QD86YI
M96QC0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('-Q;&ET92YP:'`L
M=B`Q+C4X(#(P,#0O,#(O,3D@,3@Z,34Z,S@@9&%N:65L8R!%>'`@)`H*"B\O
M(%-13&ET92!F=6YC=&EO;B!S970Z"B\O("`@<W%L:71E7V]P96XL('-Q;&ET
M95]P;W!E;BP@<W%L:71E7V-L;W-E+"!S<6QI=&5?<75E<GD*+R\@("!S<6QI
M=&5?;&EB=F5R<VEO;BP@<W%L:71E7VQI8F5N8V]D:6YG+"!S<6QI=&5?8VAA
M;F=E<PHO+R`@('-Q;&ET95]N=6U?<F]W<RP@<W%L:71E7VYU;5]F:65L9',L
M('-Q;&ET95]F:65L9%]N86UE+"!S<6QI=&5?<V5E:PHO+R`@('-Q;&ET95]E
M<V-A<&5?<W1R:6YG+"!S<6QI=&5?8G5S>5]T:6UE;W5T+"!S<6QI=&5?;&%S
M=%]E<G)O<@HO+R`@('-Q;&ET95]E<G)O<E]S=')I;F<L('-Q;&ET95]U;F)U
M9F9E<F5D7W%U97)Y+"!S<6QI=&5?8W)E871E7V%G9W)E9V%T90HO+R`@('-Q
M;&ET95]C<F5A=&5?9G5N8W1I;VXL('-Q;&ET95]L87-T7VEN<V5R=%]R;W=I
M9"P@<W%L:71E7V9E=&-H7V%R<F%Y"B\O"B\O($9O<FUA='1I;F<Z"B\O("`@
M(R!A<W1Y;&4@+2US='EL93UK<B`\('-Q;&ET92YP:'`@/B!O=70N<&AP"B\O
M"B\O(%-T871U<SH*+R\@("!%6%!%4DE-14Y404P*"@HO*@H@*B!%>&%M<&QE
M.@H@*@H\/W!H<`H*("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*"B`@("`O
M+R!$969I;F4@82!$4TX*("`@("1D<VX@/2`G<W%L:71E.B\O9'5M;7DZ0&QO
M8V%L:&]S="\G("X@9V5T8W=D*"D@+B`G+W1E<W0N9&(_;6]D93TP-C0T)SL*
M"B`@("`D9&(@/2!$0CHZ8V]N;F5C="@D9'-N+"!F86QS92D["@H@("`@+R\@
M1VEV92!A(&YE=R!T86)L92!N86UE"B`@("`D=&%B;&4@/2`G=&)L7R<@+B`@
M;60U*'5N:7%I9"AR86YD*"DI*3L*("`@("1T86)L92`]('-U8G-T<B@D=&%B
M;&4L(#`L(#$P*3L*"B`@("`O+R!#<F5A=&4@82!N97<@=&%B;&4*("`@("1R
M97-U;'0@/2`D9&(M/G%U97)Y*")#4D5!5$4@5$%"3$4@)'1A8FQE("AC;VUM
M96YT('9A<F-H87(H-3`I+`H@("`@("!D871E=&EM92!V87)C:&%R*#4P*2D[
M(BD["B`@("`D<F5S=6QT(#T@)&1B+3YQ=65R>2@B24Y315)4($E.5$\@)'1A
M8FQE(%9!3%5%4R`H)T1A=&4@86YD(%1I;64G+"`G(B`N"B`@("`@(&1A=&4H
M)UDM;2UJ($@Z:3IS)RD@+B`B)RD[(BD["@H@("`@+R\@1V5T(')E<W5L=',*
M("`@('!R:6YT9B@B869F96-T9612;W=S.EQT7'0E<UQN(BP@)&1B+3YA9F9E
M8W1E9%)O=W,H*2D["B`@("`D<F5S=6QT(#T@)&1B+3YQ=65R>2@B4T5,14-4
M($923TT@)'1A8FQE.R(I.PH@("`@)&%R<B`]("1D8BT^9F5T8VA2;W<H)')E
M<W5L="D["B`@("!P<FEN=%]R*"1A<G(I.PH@("`@)&1B+3YD:7-C;VYN96-T
M*"D["C\^"B`J"B`J+PH*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*
M"B\J*@H@*B!$871A8F%S92!I;F1E<&5N9&5N="!Q=65R>2!I;G1E<F9A8V4@
M9&5F:6YI=&EO;B!F;W(@=&AE(%-13&ET90H@*B!014-,(&5X=&5N<VEO;BX*
M("H*("H@0'!A8VMA9V4@($1""B`J($!V97)S:6]N("`D260Z('-Q;&ET92YP
M:'`L=B`Q+C4X(#(P,#0O,#(O,3D@,3@Z,34Z,S@@9&%N:65L8R!%>'`@)`H@
M*B!`8V%T96=O<GD@1&%T86)A<V4*("H@0&%U=&AO<B`@(%5R<R!'96AR:6<@
M/'5R<T!C:7)C;&4N8V@^"B`J($!A=71H;W(@("!-:6MA(%1U=7!O;&$@/'1U
M=7!O;&%`87!P96QS:6EN:2YN970^"B`J+PIC;&%S<R!$0E]S<6QI=&4@97AT
M96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("!V
M87(@)&-O;FYE8W1I;VX["B`@("!V87(@)'!H<'1Y<&4L("1D8G-Y;G1A>#L*
M("`@('9A<B`D<')E<&%R95]T;VME;G,@/2!A<G)A>2@I.PH@("`@=F%R("1P
M<F5P87)E7W1Y<&5S(#T@87)R87DH*3L*("`@('9A<B`D7VQA<W1E<G)O<B`]
M("<G.PH*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<B!F;W(@=&AI<R!C;&%S<RX*("`@("`J
M"B`@("`@*B!%<G)O<B!C;V1E<R!A8V-O<F1I;F<@=&\@<W%L:71E7V5X96,N
M("!%<G)O<B!#;V1E<R!S<&5C:69I8V%T:6]N(&ES"B`@("`@*B!I;B!T:&4@
M>T!L:6YK(&AT='`Z+R]S<6QI=&4N;W)G+V-?:6YT97)F86-E+FAT;6P@;VYL
M:6YE(&UA;G5A;'TN"B`@("`@*@H@("`@("H@5&AI<R!E<G)O<FAA;F1L:6YG
M(&)A<V5D(&]N('-Q;&ET95]E>&5C(&ES(&YO="!Y970@:6UP;&5M96YT960N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@1$)?<W%L:71E*"D*("`@('L*"B`@("`@("`@)'1H:7,M/D1"7V-O
M;6UO;B@I.PH@("`@("`@("1T:&ES+3YP:'!T>7!E(#T@)W-Q;&ET92<["B`@
M("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@)W-Q;&ET92<["B`@("`@("`@)'1H
M:7,M/F9E871U<F5S(#T@87)R87D@*`H@("`@("`@("`@("`G<')E<&%R92<@
M/3X@9F%L<V4L"B`@("`@("`@("`@("=P8V]N;F5C="<@/3X@=')U92P*("`@
M("`@("`@("`@)W1R86YS86-T:6]N<R<@/3X@9F%L<V4L"B`@("`@("`@("`@
M("=L:6UI="<@/3X@)V%L=&5R)PH@("`@("`@("D["@H@("`@("`@("\O(%-1
M3&ET92!D871A('1Y<&5S+"!H='1P.B\O=W=W+G-Q;&ET92YO<F<O9&%T871Y
M<&5S+FAT;6P*("`@("`@("`D=&AI<RT^:V5Y=V]R9',@/2!A<G)A>2`H"B`@
M("`@("`@("`@("="3$]")R`@("`@(#T^("<G+`H@("`@("`@("`@("`G0D]/
M3$5!3B<@("`]/B`G)RP*("`@("`@("`@("`@)T-(05)!0U1%4B<@/3X@)R<L
M"B`@("`@("`@("`@("=#3$]")R`@("`@(#T^("<G+`H@("`@("`@("`@("`G
M1DQ/050G("`@("`]/B`G)RP*("`@("`@("`@("`@)TE.5$5'15(G("`@/3X@
M)R<L"B`@("`@("`@("`@("=+15DG("`@("`@(#T^("<G+`H@("`@("`@("`@
M("`G3D%424].04PG("`]/B`G)RP*("`@("`@("`@("`@)TY5345224,G("`@
M/3X@)R<L"B`@("`@("`@("`@("=.5D%20TA!4B<@(#T^("<G+`H@("`@("`@
M("`@("`G4%))34%262<@("`]/B`G)RP*("`@("`@("`@("`@)U1%6%0G("`@
M("`@/3X@)R<L"B`@("`@("`@("`@("=424U%4U1!35`G(#T^("<G+`H@("`@
M("`@("`@("`G54Y)455%)R`@("`]/B`G)RP*("`@("`@("`@("`@)U9!4D-(
M05(G("`@/3X@)R<L"B`@("`@("`@("`@("=605)924Y')R`@(#T^("<G"B`@
M("`@("`@*3L*("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<"`](&%R<F%Y
M*`H@("`@("`@("D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N
M;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O(&$@9&%T86)A<V4@
M<F5P<F5S96YT960@8GD@82!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2`D
M9'-N('1H92!D871A('-O=7)C92!N86UE.R!T:&4@9FEL92!I<R!T86ME;B!A
M<PH@("`@("H@("`@("`@(&1A=&%B87-E.R`B<W%L:71E.B\O<F]O=#I`:&]S
M="]T97-T+F1B/VUO9&4],#8T-"(*("`@("`J($!P87)A;2`D<&5R<VES=&5N
M="`H;W!T:6]N86PI('=H971H97(@=&AE(&-O;FYE8W1I;VX@<VAO=6QD"B`@
M("`@*B`@("`@("`@8F4@<&5R<VES=&5N=`H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!R971U<FX@:6YT($1"7T]+(&]N('-U8V-E<W,L(&$@1$(@
M97)R;W(@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T
M*"1D<VYI;F9O+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A1$(Z.F%S<V5R=$5X=&5N<VEO;B@G<W%L:71E)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.
M4TE/3E].3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S
M;B`]("1D<VYI;F9O.PH*("`@("`@("!I9B`H)&1S;FEN9F];)V1A=&%B87-E
M)UTI('L*("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9'-N:6YF;ULG
M9&%T86)A<V4G72DI('L*("`@("`@("`@("`@("`@(&EF("@A=&]U8V@H)&1S
M;FEN9F];)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YS<6QI=&5286ES945R<F]R*$1"7T524D]27TY/5%]&3U5.
M1"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1D<VYI;F9O6R=M;V1E)UTI('Q\"B`@("`@("`@("`@("`@("`@("`@
M(6ES7VYU;65R:6,H)&1S;FEN9F];)VUO9&4G72DI"B`@("`@("`@("`@("`@
M("!["B`@("`@("`@("`@("`@("`@("`@)&UO9&4@/2`P-C0T.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;6]D92`]
M(&]C=&1E8R@D9'-N:6YF;ULG;6]D92==*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@A8VAM;V0H)&1S;FEN9F];)V1A=&%B87-E
M)UTL("1M;V1E*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<W%L:71E4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?1D]53D0I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T
M<R@D9'-N:6YF;ULG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R;W(H1$)?15)23U)?3D]4
M7T9/54Y$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H(6ES7V9I;&4H)&1S;FEN9F];)V1A=&%B87-E)UTI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R
M;W(H1$)?15)23U)?24Y604Q)1"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"%I<U]R96%D86)L92@D9'-N:6YF;ULG9&%T86)A<V4G72DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I<V5%<G)O
M<BA$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L
M:71E4F%I<V5%<G)O<BA$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].*3L*("`@
M("`@("!]"@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E
M;G0@/R`G<W%L:71E7W!O<&5N)R`Z("=S<6QI=&5?;W!E;B<["B`@("`@("`@
M:68@*"$H)&-O;FX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1S;FEN9F];)V1A
M=&%B87-E)UTI*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q;&ET
M95)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2`D8V]N;CL*"B`@("`@("`@
M<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I
M<V-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@3&]G(&]U="!A;F0@9&ES8V]N
M;F5C="!F<F]M('1H92!D871A8F%S92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@
M1D%,4T4@:68@;F]T(&-O;FYE8W1E9"X*("`@("`J($!T;V1O(&9I>"!R971U
M<FX@=F%L=65S"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@("1R970@/2!`<W%L:71E7V-L;W-E*"1T:&ES+3YC;VYN
M96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@
M("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9"!A('%U97)Y
M('1O(%-13&ET92!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT<R!A<R!A(%-13&ET
M92!R97-O=7)C90H@("`@("H@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@=&AE(%-13"!Q=65R>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!R971U<FX@;6EX960@<F5T=7)N<R!A('9A;&ED(%-13&ET92!R97-U
M;'0@9F]R('-U8V-E<W-F=6P@4T5,14-4"B`@("`@*B!Q=65R:65S+"!$0E]/
M2R!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S+B!!($1"(&5R<F]R(&ES
M"B`@("`@*B!R971U<FYE9"!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)&ES;6%N
M:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES+3YL87-T
M7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T:&ES+3Y?;6]D
M:69Y475E<GDH)'%U97)Y*3L*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O
M<G,G+"!T<G5E*3L*("`@("`@("`D<F5S=6QT(#T@0'-Q;&ET95]Q=65R>2@D
M<75E<GDL("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!I;FE?<F5S=&]R
M92@G=')A8VM?97)R;W)S)RD["B`@("`@("`@)'1H:7,M/E]L87-T97)R;W(@
M/2!I<W-E="@D<&AP7V5R<F]R;7-G*2`_("1P:'!?97)R;W)M<V<@.B`G)SL*
M("`@("`@("`D=&AI<RT^<F5S=6QT(#T@)')E<W5L=#L*("`@("`@("!I9B`H
M(21T:&ES+3YR97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS
M<6QI=&5286ES945R<F]R*&YU;&PI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M<W%L:71E7W%U97)Y*"D@<V5E;7,@=&\@86QL=V%Y<R!R971U<FX@82!R97-O
M=7)C92`J+PH@("`@("`@("\J('-O(&-A;G0@=7-E('1H870N(%5S:6YG("1I
M<VUA;FEP(&EN<W1E860@("`@("`@("`@*B\*("`@("`@("!I9B`H(21I<VUA
M;FEP*2!["B`@("`@("`@("`@("1N=6U2;W=S(#T@)'1H:7,M/FYU;5)O=W,H
M)')E<W5L="D["@H@("`@("`@("`@("`O*B!I9B!N=6U2;W=S*"D@<F5T=7)N
M960@4$5!4E]%<G)O<B`J+PH@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1N
M=6U2;W=S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1N=6U2;W=S.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E
M('1H92!I;G1E<FYA;"!S<6QI=&4@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE
M>'0@879A:6QA8FQE(')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@82!V
M86QI9"!S<6QI=&4@<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES(&%V86EL
M86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O
M*"D*"B`@("`O*BH*("`@("`J($9E=&-H(&$@<F]W(&%N9"!I;G-E<G0@=&AE
M(&1A=&$@:6YT;R!A;B!E>&ES=&EN9R!A<G)A>2X*("`@("`J"B`@("`@*B!&
M;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R
M92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN
M=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<F5S;W5R8V4@)')E<W5L="`@("!Q=65R>2!R97-U;'0@:61E;G1I9FEE
M<@H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@*')E9F5R96YC
M92D@87)R87D@=VAE<F4@9&%T82!F<F]M('1H92!R;W<*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-H;W5L9"!B92!P;&%C960*("`@("`J
M($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT:6YG
M(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT("`@
M("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:`H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W
M:&5N(&5N9"!O9B!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@("`@
M(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@
M)&9E=&-H;6]D92P@)')O=VYU;3UN=6QL*0H@("`@>PH@("`@("`@(&EF("@D
M<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@A0'-Q;&ET95]S
M965K*"1T:&ES+3YR97-U;'0L("1R;W=N=6TI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]!4U-/0RD@>PH@("`@
M("`@("`@("`D87)R(#T@<W%L:71E7V9E=&-H7V%R<F%Y*"1R97-U;'0L(%-1
M3$E415]!4U-/0RD["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D
M87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME
M>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]('-Q;&ET95]F971C:%]A
M<G)A>2@D<F5S=6QT+"!344Q)5$5?3E5-*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"$D87)R*2!["B`@("`@("`@("`@("\J(%-E93H@:'1T<#HO+V)U9W,N
M<&AP+FYE="]B=6<N<&AP/VED/3(R,S(X("HO"B`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@
M("`@("`@("`O*@H@("`@("`@("`@("`@*B!%=F5N('1H;W5G:"!T:&ES($1"
M35,@86QR96%D>2!T<FEM<R!O=71P=70L('=E(&1O('1H:7,@8F5C875S90H@
M("`@("`@("`@("`@*B!A(&9I96QD(&UI9VAT(&AA=F4@:6YT96YT:6]N86P@
M=VAI=&5S<&%C92!A="!T:&4@96YD('1H870*("`@("`@("`@("`@("H@9V5T
M<R!R96UO=F5D(&)Y($1"7U!/4E1!0DE,25197U)44DE-('5N9&5R(&%N;W1H
M97(@9')I=F5R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!F<F5E4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($9R964@=&AE(&EN
M=&5R;F%L(')E<V]U<F-E<R!A<W-O8VEA=&5D('=I=&@@)')E<W5L="X*("`@
M("`J"B`@("`@*B!`<&%R86T@)')E<W5L="!344QI=&4@<F5S=6QT(&ED96YT
M:69I97(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&)O
M;VP@5%)512!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@F)')E<W5L="D*
M("`@('L*("`@("`@("`O+R!86%@@3F\@;F%T:79E(&9R964_"B`@("`@("`@
M:68@*"%I<U]R97-O=7)C92@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2!N=6QL.PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R
M(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T+@H@("`@("H*("`@("`J($!R
M971U<FX@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@("`@
M("`D8V]L<R`]($!S<6QI=&5?;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@
M("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L
M:71E4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O
M;',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@
M("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E
M9"!B>2!A('%U97)Y+@H@("`@("H*("`@("`J($!R971U<FX@;G5M8F5R(&]F
M(')O=W,@869F96-T960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J+PH@("`@
M9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1R;W=S
M(#T@0'-Q;&ET95]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(6ES
M7VEN=&5G97(H)')O=W,I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')O=W,[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T960H*0H*("`@
M("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@
M8GD@82!Q=65R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&YU;6)E<B!O9B!R
M;W=S(&%F9F5C=&5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@("`@<F5T=7)N('-Q
M;&ET95]C:&%N9V5S*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@
M*B!'970@=&AE(&YA=&EV92!E<G)O<B!S=')I;F<@;V8@=&AE(&QA<W0@97)R
M;W(@*&EF(&%N>2D@=&AA=`H@("`@("H@;V-C=7)E9"!O;B!T:&4@8W5R<F5N
M="!C;VYN96-T:6]N+@H@("`@("H*("`@("`J(%1H:7,@:7,@=7-E9"!T;R!R
M971R:65V92!M;W)E(&UE86YI;F=F=6QL(&5R<F]R(&UE<W-A9V5S($1"7W!G
M<W%L"B`@("`@*B!W87D@<VEN8V4@<W%L:71E7VQA<W1?97)R;W(H*2!D;V5S
M(&YO="!P<F]V:61E(&%D97%U871E(&EN9F\N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@;F%T:79E(%-13&ET92!E<G)O<B!M97-S86=E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!R
M971U<FXH)'1H:7,M/E]L87-T97)R;W(I.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI
M;F4@4$5!4CHZ1$(@97)R;W(@8V]D92!F<F]M('1H92!D871A8F%S92=S('1E
M>'0@97)R;W(@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN
M9R`@)&5R<F]R;7-G("!E<G)O<B!M97-S86=E(')E='5R;F5D(&9R;VT@=&AE
M(&1A=&%B87-E"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(&%N(&5R<F]R(&YU
M;6)E<B!F<F]M(&$@1$(@97)R;W(@8V]N<W1A;G0*("`@("`J+PH@("`@9G5N
M8W1I;VX@97)R;W)#;V1E*"1E<G)O<FUS9RD*("`@('L*("`@("`@("!S=&%T
M:6,@)&5R<F]R7W)E9V5X<',["B`@("`@("`@:68@*"%I<W-E="@D97)R;W)?
M<F5G97AP<RDI('L*("`@("`@("`@("`@)&5R<F]R7W)E9V5X<',@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("<O7FYO('-U8V@@=&%B;&4Z+R<@/3X@1$)?
M15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@("`@("`G+UYT86)L92`N
M*B!A;')E861Y(&5X:7-T<R0O)R`]/B!$0E]%4E)/4E]!3%)%04197T5825-4
M4RP*("`@("`@("`@("`@("`@("<O4%))34%262!+15D@;75S="!B92!U;FEQ
M=64O:2<@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@
M("<O:7,@;F]T('5N:7%U92\G(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@
M("`@("`@("`@("`@("`G+W5N:7%U96YE<W,@8V]N<W1R86EN="!F86EL960O
M)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`@("`@)R]M
M87D@;F]T(&)E($Y53$PO)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].
M54Q,+`H@("`@("`@("`@("`@("`@)R]>;F\@<W5C:"!C;VQU;6XZ+R<@/3X@
M1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@("`@("`@("`G+UYN96%R
M("(N*B(Z('-Y;G1A>"!E<G)O<B0O)R`]/B!$0E]%4E)/4E]364Y405@*("`@
M("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&5R<F]R
M7W)E9V5X<',@87,@)')E9V5X<"`]/B`D8V]D92D@>PH@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@D<F5G97AP+"`D97)R;W)M<V<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)&-O9&4["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@+R\@1F%L;"!B86-K('1O($1"7T524D]2(&EF('1H97)E('=A
M<R!N;R!M87!P:6YG+@H@("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J
M*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O
M(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@($1"7T5R<F]R(&EF('!R;V)L96US+@H@("`@("H*("`@
M("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U
M96YC92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S
M97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH(D123U`@5$%"3$4@)'-E<6YA
M;64B*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q
M=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@
M;F%M92!O9B!T:&4@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!I
M<R!R971U<FYE9"!I9@H@("`@("H@("`@("`@("`@("`@('!R;V)L96US(&%R
M:7-E+@H@("`@("H*("`@("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.F-R96%T95-E<75E;F-E*"D*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M
M92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC
M94YA;64H)'-E<5]N86UE*3L*("`@("`@("`D<75E<GD@("`]("=#4D5!5$4@
M5$%"3$4@)R`N("1S97%N86UE("X*("`@("`@("`@("`@("`@("`@("<@*&ED
M($E.5$5'15(@54Y324=.140@4%))34%262!+15DI("<["B`@("`@("`@)')E
M<W5L="`@/2`D=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N*"1R97-U
M;'0I.PH@("`@("`@('T*("`@("`@("`D<75E<GD@("`](")#4D5!5$4@5%))
M1T=%4B`D>W-E<6YA;65]7V-L96%N=7`@049415(@24Y315)4($].("1S97%N
M86UE"B`@("`@("`@("`@("`@("`@("`@0D5'24X*("`@("`@("`@("`@("`@
M("`@("`@("`@1$5,151%($923TT@)'-E<6YA;64@5TA%4D4@:60\3$%35%])
M3E-%4E1?4D]7240H*3L*("`@("`@("`@("`@("`@("`@("!%3D0@(CL*("`@
M("`@("`D<F5S=6QT("`]("1T:&ES+3YQ=65R>2@D<75E<GDI.PH@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U
M<FXH)')E<W5L="D["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N
M97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4*("`@
M("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E+"!T:&4@
M<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN
M('1H92!S97%U96YC92X@($1"7T5R<F]R(&EF('!R;V)L96TN"B`@("`@*@H@
M("`@("H@0&EN=&5R;F%L"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$
M*"D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@
M("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?
M;F%M92D["@H@("`@("`@(&1O('L*("`@("`@("`@("`@)')E<&5A="`](#`[
M"B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E
M<GDH(DE.4T525"!)3E1/("1S97%N86UE(%9!3%5%4R`H3E5,3"DB*3L*("`@
M("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@
M("`@:68@*"1R97-U;'0@/3T@1$)?3TLI('L*("`@("`@("`@("`@("`@("1I
M9"`]('-Q;&ET95]L87-T7VEN<V5R=%]R;W=I9"@D=&AI<RT^8V]N;F5C=&EO
M;BD["B`@("`@("`@("`@("`@("!I9B`H)&ED("$](#`I('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V5I9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R
M97-U;'0I("8F"B`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT+3YG971#
M;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"3$4I"B`@("`@("`@("`@('L*
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q=65N
M8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)')E<&5A="`](#$["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P
M96%T*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U
M;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P96-I86Q1
M=65R>2@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!Q=65R>2!N965D
M960@=&\@9V5T('-O;64@8F%C:V5N9"!I;F9O+@H@("`@("H*("`@("`J(%)E
M9F5R('1O('1H92!O;FQI;F4@;6%N=6%L(&%T(&AT='`Z+R]S<6QI=&4N;W)G
M+W-Q;&ET92YH=&UL+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y
M<&4@5VAA="!K:6YD(&]F(&EN9F\@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@
M("`J($!R971U<FX@<W1R:6YG(%1H92!344P@<75E<GD@<W1R:6YG"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92P@)&%R9W,]
M87)R87DH*2D*("`@('L*("`@("`@("!I9B@A:7-?87)R87DH)&%R9W,I*0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO(&ME>2!S
M<&5C:69I960G+"!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)T%R9W5M96YT(&AA<R!T;R!B92!A;B!A
M<G)A>2XG*3L*("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)'1Y<&4I*2![
M"B`@("`@("`@("`@(&-A<V4@)VUA<W1E<B<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)U-%3$5#5"`J($923TT@<W%L:71E7VUA<W1E<CLG.PH@("`@("`@
M("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N(")3
M14Q%0U0@;F%M92!&4D]-('-Q;&ET95]M87-T97(@5TA%4D4@='EP93TG=&%B
M;&4G("(*("`@("`@("`@("`@("`@("`@("`@("`N("=53DE/3B!!3$P@4T5,
M14-4(&YA;64@1E)/32!S<6QI=&5?=&5M<%]M87-T97(@)PH@("`@("`@("`@
M("`@("`@("`@("`@("X@(E=(15)%('1Y<&4])W1A8FQE)R!/4D1%4B!"62!N
M86UE.R(["B`@("`@("`@("`@(&-A<V4@)W-C:&5M82<Z"B`@("`@("`@("`@
M("`@("!R971U<FX@)U-%3$5#5"!S<6P@1E)/32`H4T5,14-4("H@1E)/32!S
M<6QI=&5?;6%S=&5R(%5.24].($%,3"`G"B`@("`@("`@("`@("`@("`@("`@
M("`@+B`G4T5,14-4("H@1E)/32!S<6QI=&5?=&5M<%]M87-T97(I("<*("`@
M("`@("`@("`@("`@("`@("`@("`N(")72$5212!T>7!E(3TG;65T82<@3U)$
M15(@0ED@=&)L7VYA;64L('1Y<&4@1$530RP@;F%M93LB.PH@("`@("`@("`@
M("!C87-E("=S8VAE;6%X)SH*("`@("`@("`@("`@8V%S92`G<V-H96UA7W@G
M.@H@("`@("`@("`@("`@("`@+RH*("`@("`@("`@("`@("`@("`J(%5S92!L
M:6ME.@H@("`@("`@("`@("`@("`@("H@)')E<R`]("1D8BT^<75E<GDH)&1B
M+3YG9713<&5C:6%L475E<GDH)W-C:&5M85]X)RP@87)R87DH)W1A8FQE)R`]
M/B`G=&%B;&4S)RDI*3L*("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@
M("`@("`@<F5T=7)N("=314Q%0U0@<W%L($923TT@*%-%3$5#5"`J($923TT@
M<W%L:71E7VUA<W1E<B!53DE/3B!!3$P@)PH@("`@("`@("`@("`@("`@("`@
M("`@("X@)U-%3$5#5"`J($923TT@<W%L:71E7W1E;7!?;6%S=&5R*2`G"B`@
M("`@("`@("`@("`@("`@("`@("`@+B`B5TA%4D4@=&)L7VYA;64@3$E+12`G
M>R1A<F=S6R=T86)L92==?2<@04Y$('1Y<&4A/2=M971A)R`B"B`@("`@("`@
M("`@("`@("`@("`@("`@+B`G3U)$15(@0ED@='EP92!$15-#+"!N86UE.R<[
M"B`@("`@("`@("`@(&-A<V4@)V%L=&5R)SH*("`@("`@("`@("`@("`@("\J
M"B`@("`@("`@("`@("`@("`@*B!344QI=&4@9&]E<R!N;W0@<W5P<&]R="!!
M3%1%4B!404),13L@=&AI<R!I<R!A(&AE;'!E<B!Q=65R>0H@("`@("`@("`@
M("`@("`@("H@=&\@:&%N9&QE('1H:7,N("=T86)L92<@<F5P<F5S96YT<R!T
M:&4@=&%B;&4@;F%M92P@)W)O=W,G"B`@("`@("`@("`@("`@("`@*B!T:&4@
M;F5W<R!R;W=S('1O(&-R96%T92P@)W-A=F4G('1H92!R;W<H<RD@=&\@:V5E
M<"!?=VET:%\*("`@("`@("`@("`@("`@("`J('1H92!D871A+@H@("`@("`@
M("`@("`@("`@("H*("`@("`@("`@("`@("`@("`J(%5S92!L:6ME.@H@("`@
M("`@("`@("`@("`@("H@)&%R9W,@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("`J("`@("`G=&%B;&4G(#T^("1T86)L92P*("`@("`@("`@("`@("`@("`J
M("`@("`G<F]W<R<@(#T^(")I9"!)3E1%1T52(%!224U!4ED@2T59+"!F:7)S
M=&YA;64@5$585"P@<W5R;F%M92!415A4+"!D871E=&EM92!415A4(BP*("`@
M("`@("`@("`@("`@("`J("`@("`G<V%V92<@(#T^(").54Q,+"!T:71E;"P@
M8V]N=&5N="P@9&%T971I;64B"B`@("`@("`@("`@("`@("`@*B`I.PH@("`@
M("`@("`@("`@("`@("H@)')E<R`]("1D8BT^<75E<GDH("1D8BT^9V5T4W!E
M8VEA;%%U97)Y*"=A;'1E<B<L("1A<F=S*2D["B`@("`@("`@("`@("`@("`@
M*B\*("`@("`@("`@("`@("`@("1R;W=S(#T@<W1R='(H)&%R9W-;)W)O=W,G
M72P@)'1H:7,M/FME>7=O<F1S*3L*"B`@("`@("`@("`@("`@("`D<2`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("="14=)3B!44D%.4T%#5$E/3B<L
M"B`@("`@("`@("`@("`@("`@("`@(D-214%412!414U03U)!4ED@5$%"3$4@
M>R1A<F=S6R=T86)L92==?5]B86-K=7`@*'LD87)G<ULG<F]W<R==?2DB+`H@
M("`@("`@("`@("`@("`@("`@("))3E-%4E0@24Y43R![)&%R9W-;)W1A8FQE
M)UU]7V)A8VMU<"!314Q%0U0@>R1A<F=S6R=S879E)UU]($923TT@>R1A<F=S
M6R=T86)L92==?2(L"B`@("`@("`@("`@("`@("`@("`@(D123U`@5$%"3$4@
M>R1A<F=S6R=T86)L92==?2(L"B`@("`@("`@("`@("`@("`@("`@(D-214%4
M12!404),12![)&%R9W-;)W1A8FQE)UU]("A[)&%R9W-;)W)O=W,G77TI(BP*
M("`@("`@("`@("`@("`@("`@("`B24Y315)4($E.5$\@>R1A<F=S6R=T86)L
M92==?2!314Q%0U0@>R1R;W=S?2!&4D]-('LD87)G<ULG=&%B;&4G77U?8F%C
M:W5P(BP*("`@("`@("`@("`@("`@("`@("`B1%)/4"!404),12![)&%R9W-;
M)W1A8FQE)UU]7V)A8VMU<"(L"B`@("`@("`@("`@("`@("`@("`@)T-/34U)
M5"<L"B`@("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@("`@("\O(%1H
M:7,@:7,@82!D:7)T>2!H86-K+"!S:6YC92!T:&4@86)O=F4@<75E<GD@=VEL
M;"!N;R!G970@97AE8W5T960@=VET:"!A('-I;F=L90H@("`@("`@("`@("`@
M("`@+R\@<75E<GD@8V%L;#L@<V\@:&5R92!T:&4@<75E<GD@;65T:&]D('=I
M;&P@8F4@8V%L;&5D(&1I<F5C=&QY(&%N9"!R971U<FX@82!S96QE8W0@:6YS
M=&5A9"X*("`@("`@("`@("`@("`@(&9O<F5A8V@H)'$@87,@)'%U97)Y*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G%U97)Y*"1Q=65R>2D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@(E-%3$5#
M5"`J($923TT@>R1A<F=S6R=T86)L92==?3LB.PH@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$1B1FEL95-T871S*"D*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@9FEL92!S=&%T<R!F;W(@=&AE(&-U
M<G)E;G0@9&%T86)A<V4N"B`@("`@*@H@("`@("H@4&]S<VEB;&4@87)G=6UE
M;G1S(&%R92!D978L(&EN;RP@;6]D92P@;FQI;FLL('5I9"P@9VED+"!R9&5V
M+"!S:7IE+`H@("`@("H@871I;64L(&UT:6UE+"!C=&EM92P@8FQK<VEZ92P@
M8FQO8VMS(&]R(&$@;G5M97)I8R!K97D@8F5T=V5E;@H@("`@("H@,"!A;F0@
M,3(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87)G($%R<F%Y(&ME
M>2!F;W(@<W1A=',H*0H@("`@("H@0')E='5R;B!M:7AE9"!A<G)A>2!O;B!A
M;B!U;G-P96-I9FEE9"!K97DL(&EN=&5G97(@;VX@82!P87-S960@87)G(&%N
M9`H@("`@("H@1D%,4T4@870@82!S=&%T<R!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1&)&:6QE4W1A=',H)&%R9R`]("<G*0H@("`@>PH@("`@
M("`@("1S=&%T<R`]('-T870H)'1H:7,M/F1S;ELG9&%T86)A<V4G72D["B`@
M("`@("`@:68@*"1S=&%T<R`]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A<G)A>2@D<W1A
M=',I*2!["B`@("`@("`@("`@(&EF*&ES7VYU;65R:6,H)&%R9RDI('L*("`@
M("`@("`@("`@("`@(&EF("@H*&EN="DD87)G(#P](#$R*2`F("@H:6YT*21A
M<F<@/CT@,"DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@)'-T
M871S6R1A<F<@73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H87)R
M87E?:V5Y7V5X:7-T<RAT<FEM*"1A<F<I+"`D<W1A=',I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'-T871S6R1A<F<@73L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)'-T871S.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI;6ET475E<GDH*0H*("`@(&9U;F-T
M:6]N(&UO9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT*0H@
M("`@>PH@("`@("`@("1Q=65R>2`]("1Q=65R>2`N("(@3$E-250@)&-O=6YT
M($]&1E-%5"`D9G)O;2(["B`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE1=65R>2@I"@H@("`@+RHJ
M"B`@("`@*B`B1$5,151%($923TT@=&%B;&4B(&=I=F5S(#`@869F96-T960@
M<F]W<R!I;B!344QI=&4N"B`@("`@*@H@("`@("H@5&AI<R!L:71T;&4@:&%C
M:R!L971S('EO=2!K;F]W(&AO=R!M86YY(')O=W,@=V5R92!D96QE=&5D+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y(%1H92!344P@<75E
M<GD@<W1R:6YG"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@4U%,('%U97)Y
M('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!?;6]D:69Y475E<GDH)'%U
M97)Y*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197T1%3$5415]#3U5.5"D@>PH@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<<RI$14Q%5$5<<RM&4D]-7',K
M*%Q3*RE<<RHD+VDG+"`D<75E<GDI*2!["B`@("`@("`@("`@("`@("`D<75E
M<GD@/2!P<F5G7W)E<&QA8V4H)R]>7',J1$5,151%7',K1E)/35QS*RA<4RLI
M7',J)"\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=$14Q%5$4@1E)/32!<,2!72$5212`Q/3$G+"`D<75E<GDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<75E<GD["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<W%L:71E4F%I<V5%<G)O<B@I"@H@
M("`@+RHJ"B`@("`@*B!'871H97(@:6YF;W)M871I;VX@86)O=70@86X@97)R
M;W(L('1H96X@=7-E('1H870@:6YF;R!T;R!C<F5A=&4@80H@("`@("H@1$(@
M97)R;W(@;V)J96-T(&%N9"!F:6YA;&QY(')E='5R;B!T:&%T(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@(&EN=&5G97(@("1E<G)N;R`@4$5!4B!E
M<G)O<B!N=6UB97(@*'5S=6%L;'D@82!$0B!C;VYS=&%N="D@:68*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!M86YU86QL>2!R86ES:6YG(&%N
M(&5R<F]R"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@1$(@97)R;W(@;V)J96-T
M"B`@("`@*B!`<V5E(&5R<F]R3F%T:79E*"D*("`@("`J($!S964@97)R;W)#
M;V1E*"D*("`@("`J($!S964@1$)?8V]M;6]N.CIR86ES945R<F]R*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@<W%L:71E4F%I<V5%<G)O<B@D97)R;F\@/2!N
M=6QL*0H@("`@>PH*("`@("`@("`D;F%T:79E(#T@)'1H:7,M/F5R<F]R3F%T
M:79E*"D["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@
M("`@("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*"1N871I=F4I.PH@("`@
M("`@('T*"B`@("`@("`@)&5R<F]R8V]D92`]($!S<6QI=&5?;&%S=%]E<G)O
M<B@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'5S97)I;F9O(#T@(B1E
M<G)O<F-O9&4@*BH@)'1H:7,M/FQA<W1?<75E<GDB.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"`D=7-E
M<FEN9F\L("1N871I=F4I.PH@("`@?0H*("`@("\O('U]?0I]"@HO*@H@*B!,
M;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F
M9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O:6)A
M<V4N<&AP````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-C,P-38`,3`T,3<S-C,P,#8`,#$W-#,S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X
M<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT(&9O;&1M971H;V0];6%R
M:V5R.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!0
M2%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!!=71H;W(Z(%-T97)L:6YG($AU9VAE<R`\<W1E<FQI;F=`
M<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@36%I
M;G1A:6YE<CH@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/B`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!I8F%S92YP:'`L=B`Q+C8S(#(P,#0O,#(O
M,3D@,3DZ,C0Z,30@9&%N:65L8R!%>'`@)`H*"B\O($)U9W,Z"B\O("`M($EF
M(&1B<WEN=&%X(&ES(&YO="!F:7)E8FER9"P@=&AE(&QI;6ET475E<GD@;6%Y
M(&9A:6P*"@IR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J
M($1A=&%B87-E(&EN9&5P96YD96YT('%U97)Y(&EN=&5R9F%C92!D969I;FET
M:6]N(&9O<B!02%`G<R!);G1E<F)A<V4*("H@97AT96YS:6]N+@H@*@H@*B!`
M<&%C:V%G92`@1$(*("H@0'9E<G-I;VX@("1)9#H@:6)A<V4N<&AP+'8@,2XV
M,R`R,#`T+S`R+S$Y(#$Y.C(T.C$T(&1A;FEE;&,@17AP("0*("H@0&-A=&5G
M;W)Y($1A=&%B87-E"B`J($!A=71H;W(@("!3=&5R;&EN9R!(=6=H97,@/'-T
M97)L:6YG0'!H<"YN970^"B`J+PIC;&%S<R!$0E]I8F%S92!E>'1E;F1S($1"
M7V-O;6UO;@I["@H@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("!V87(@)&-O
M;FYE8W1I;VX["B`@("!V87(@)'!H<'1Y<&4L("1D8G-Y;G1A>#L*("`@('9A
M<B`D875T;V-O;6UI="`](#$["B`@("!V87(@)&UA;FEP7W%U97)Y(#T@87)R
M87DH*3L*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@
M(&9U;F-T:6]N($1"7VEB87-E*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?
M8V]M;6]N*"D["B`@("`@("`@)'1H:7,M/G!H<'1Y<&4@/2`G:6)A<V4G.PH@
M("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("=I8F%S92<["B`@("`@("`@)'1H
M:7,M/F9E871U<F5S(#T@87)R87DH"B`@("`@("`@("`@("=P<F5P87)E)R`]
M/B!T<G5E+`H@("`@("`@("`@("`G<&-O;FYE8W0G(#T^('1R=64L"B`@("`@
M("`@("`@("=T<F%N<V%C=&EO;G,G(#T^('1R=64L"B`@("`@("`@("`@("=L
M:6UI="<@/3X@9F%L<V4*("`@("`@("`I.PH@("`@("`@("\O(&IU<W0@82!F
M97<@;V8@=&AE('1O;G,@;V8@26YT97)B87-E(&5R<F]R(&-O9&5S(&QI<W1E
M9"!I;B!T:&4*("`@("`@("`O+R!,86YG=6%G92!2969E<F5N8V4@<V5C=&EO
M;B!O9B!T:&4@26YT97)B87-E(&UA;G5A;`H@("`@("`@("1T:&ES+3YE<G)O
M<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@("`@("TQ,#0@/3X@1$)?15)2
M3U)?4UE.5$%8+`H@("`@("`@("`@("`M,34P(#T^($1"7T524D]27T%#0T53
M4U]624],051)3TXL"B`@("`@("`@("`@("TQ-3$@/3X@1$)?15)23U)?04-#
M15-37U9)3TQ!5$E/3BP*("`@("`@("`@("`@+3$U-2`]/B!$0E]%4E)/4E].
M3U-50TA404),12P*("`@("`@("`@("`@.#@@("`]/B!$0E]%4E)/4E].3U-5
M0TA404),12P*("`@("`@("`@("`@+3$U-R`]/B!$0E]%4E)/4E].3U-50TA&
M245,1"P*("`@("`@("`@("`@+3$U."`]/B!$0E]%4E)/4E]604Q515]#3U5.
M5%]/3E]23U<L"B`@("`@("`@("`@("TQ-S`@/3X@1$)?15)23U)?34E334%4
M0T@L"B`@("`@("`@("`@("TQ-S$@/3X@1$)?15)23U)?34E334%40T@L"B`@
M("`@("`@("`@("TQ-S(@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@("`@
M("`@+3(P-"`]/B!$0E]%4E)/4E])3E9!3$E$+`H@("`@("`@("`@("`M,C`U
M(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("`@("`M,C`V(#T^
M($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("`@("`M,C`X(#T^($1"
M7T524D]27TE.5D%,240L"B`@("`@("`@("`@("TR,3D@/3X@1$)?15)23U)?
M3D]354-(5$%"3$4L"B`@("`@("`@("`@("TR.3<@/3X@1$)?15)23U)?0T].
M4U1204E.5"P*("`@("`@("`@("`@+34S,"`]/B!$0E]%4E)/4E]#3TY35%)!
M24Y4+`H@("`@("`@("`@("`M-C`W(#T^($1"7T524D]27TY/4U5#2%1!0DQ%
M+`H@("`@("`@("`@("`M.#`S(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@
M("`@("`@("`@("TU-3$@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*
M("`@("`@("`@("`@+34U,B`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].
M+`H@("`@("`@("`@("`M.3(R(#T^($1"7T524D]27TY/4U5#2$1"+`H@("`@
M("`@("`@("`M.3(S(#T^($1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@
M("`@("`@("`M.3(T(#T^($1"7T524D]27T-/3DY%0U1?1D%)3$5$"B`@("`@
M("`@*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*
M"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VYI;F9O+"`D<&5R<VES=&5N="`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A1$(Z.F%S<V5R=$5X=&5N<VEO
M;B@G:6YT97)B87-E)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;FEN9F\["B`@("`@("`@
M)&1B:&]S="`]("1D<VYI;F9O6R=H;W-T<W!E8R==(#\*("`@("`@("`@("`@
M("`@("`@*"1D<VYI;F9O6R=H;W-T<W!E8R==("X@)SHG("X@)&1S;FEN9F];
M)V1A=&%B87-E)UTI(#H*("`@("`@("`@("`@("`@("`@)&1S;FEN9F];)V1A
M=&%B87-E)UT["@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I
M<W1E;G0@/R`G:6)A<V5?<&-O;FYE8W0G(#H@)VEB87-E7V-O;FYE8W0G.PH*
M("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`D<&%R86US6UT@
M/2`D9&)H;W-T.PH@("`@("`@("1P87)A;7-;72`]("1D<VYI;F9O6R=U<V5R
M;F%M92==(#\@)&1S;FEN9F];)W5S97)N86UE)UT@.B!N=6QL.PH@("`@("`@
M("1P87)A;7-;72`]("1D<VYI;F9O6R=P87-S=V]R9"==(#\@)&1S;FEN9F];
M)W!A<W-W;W)D)UT@.B!N=6QL.PH@("`@("`@("1P87)A;7-;72`](&ES<V5T
M*"1D<VYI;F9O6R=C:&%R<V5T)UTI(#\@)&1S;FEN9F];)V-H87)S970G72`Z
M(&YU;&P["B`@("`@("`@)'!A<F%M<UM=(#T@:7-S970H)&1S;FEN9F];)V)U
M9F9E<G,G72D@/R`D9'-N:6YF;ULG8G5F9F5R<R==(#H@;G5L;#L*("`@("`@
M("`D<&%R86US6UT@/2!I<W-E="@D9'-N:6YF;ULG9&EA;&5C="==*2`_("1D
M<VYI;F9O6R=D:6%L96-T)UT@.B!N=6QL.PH@("`@("`@("1P87)A;7-;72`]
M(&ES<V5T*"1D<VYI;F9O6R=R;VQE)UTI("`@(#\@)&1S;FEN9F];)W)O;&4G
M72`Z(&YU;&P["@H@("`@("`@("1C;VYN(#T@0&-A;&Q?=7-E<E]F=6YC7V%R
M<F%Y*"1C;VYN96-T7V9U;F-T:6]N+"`D<&%R86US*3L*("`@("`@("!I9B`H
M(21C;VYN*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES
M945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2`D8V]N;CL*("`@("`@("!I9B`H
M)'1H:7,M/F1S;ELG9&)S>6YT87@G72`]/2`G9FER96)I<F0G*2!["B`@("`@
M("`@("`@("1T:&ES+3YF96%T=7)E<ULG;&EM:70G72`]("=A;'1E<B<["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("!F=6YC=&EO;B!D:7-C
M;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0&EB87-E7V-L;W-E*"1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]
M(&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@(&9U;F-T:6]N('-I;7!L
M95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII
M<TUA;FEP*"1Q=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D
M<75E<GD["B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q
M=65R>2D["B`@("`@("`@)')E<W5L="`]($!I8F%S95]Q=65R>2@D=&AI<RT^
M8V]N;F5C=&EO;BP@)'%U97)Y*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI8F%S95)A:7-E17)R;W(H*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YA=71O8V]M;6ET("8F("1I
M<VUA;FEP*2!["B`@("`@("`@("`@(&EB87-E7V-O;6UI="@D=&AI<RT^8V]N
M;F5C=&EO;BD["B`@("`@("`@?0H@("`@("`@("\O($1E=&5R;6EN92!W:&EC
M:"!Q=65R:65S('1H870@<VAO=6QD(')E='5R;B!D871A+"!A;F0@=VAI8V@*
M("`@("`@("`O+R!S:&]U;&0@<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*
M("`@("`@("!R971U<FX@)&ES;6%N:7`@/R!$0E]/2R`Z("1R97-U;'0["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I
M"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!U<V5D(&)Y(&)A8VME
M;F1S('1O(&%L=&5R(&QI;6ET960@<75E<FEE<PH@("`@("H@57-E<R!T:&4@
M;F5W($9)4E-4(&X@4TM)4"!N($9I<F5B:7)D(#$N,"!S>6YT87@L('-O(&ET
M(&ES"B`@("`@*B!O;FQY(&-O;7!A=&EB;&4@=VET:"!&:7)E8FER9"`Q+G@*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<75E<GD@<75E<GD@=&\@
M;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;2`@=&AE(')O=R!T
M;R!S=&%R="!T;R!F971C:&EN9PH@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O
M=6YT('1H92!N=6UB97)S(&]F(')O=W,@=&\@9F5T8V@*("`@("`J"B`@("`@
M*B!`<F5T=7)N('1H92!N97<@*&UO9&EF:65D*2!Q=65R>0H@("`@("H@0&%U
M=&AO<B!,=61O=FEC;R!-86=N;V-A=F%L;&\@/&QU9&]`<W5M871R87-O;'5T
M:6]N<RYC;VT^"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U
M;G0I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YD<VY;)V1B<WEN=&%X)UT@
M/3T@)V9I<F5B:7)D)RD@>PH@("`@("`@("`@("`O+R1F<F]M*RL[("\O(%-+
M25`@<W1A<G1S(&9R;VT@,2P@:64@4TM)4"`Q('-T87)T<R!F<F]M('1H92!F
M:7)S="!R96-O<F0*("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@*&-O
M>"D@4V5E;7,@=&AA="!32TE0('-T87)T<R!I;B`P"B`@("`@("`@("`@("1Q
M=65R>2`]('!R96=?<F5P;&%C92@G+UY<<RIS96QE8W1<<R@N*BDD+VES)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")314Q%0U0@1DE2
M4U0@)&-O=6YT(%-+25`@)&9R;VT@)#$B+"`D<75E<GDI.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@
M:6YT97)N86P@:6)A<V4@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A
M:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A('9A;&ED(&9B
M<W%L(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES
M(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T
M8VA);G1O*"D*"B`@("`O*BH*("`@("`J($9E=&-H(&$@<F]W(&%N9"!I;G-E
M<G0@=&AE(&1A=&$@:6YT;R!A;B!E>&ES=&EN9R!A<G)A>2X*("`@("`J"B`@
M("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R
M96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF
M971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!Q=65R>2!R97-U;'0@:61E
M;G1I9FEE<@H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@*')E
M9F5R96YC92D@87)R87D@=VAE<F4@9&%T82!F<F]M('1H92!R;W<*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-H;W5L9"!B92!P;&%C960*
M("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S
M=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@
M:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:`H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@1$)?3TL@;VX@<W5C8V5S<RP@
M3E5,3"!W:&5N(&5N9"!O9B!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@
M("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F
M)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;3UN=6QL*0H@("`@>PH@("`@("`@
M(&EF("@D<F]W;G5M("$]/2!.54Q,*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^:6)A<V5286ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/
M1$5?05-33T,I('L*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G
M:6)A<V5?9F5T8VA?87-S;V,G*2D@>PH@("`@("`@("`@("`@("`@)&%R<B`]
M($!I8F%S95]F971C:%]A<W-O8R@D<F5S=6QT*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1A<G(@/2!G971?;V)J96-T7W9A<G,H
M:6)A<V5?9F5T8VA?;V)J96-T*"1R97-U;'0I*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@
M("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#
M05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1A<G(@/2!`:6)A<V5?9F5T8VA?<F]W*"1R97-U;'0I.PH@
M("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@("`@("`@:68@
M*"1E<G)M<V<@/2!I8F%S95]E<G)M<V<H*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YI8F%S95)A:7-E17)R;W(H;G5L;"P@)&5R<FUS9RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]2
M5%))32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H
M)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S
M5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*
M("`@(&9U;F-T:6]N(&9R965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@
M("!R971U<FX@0&EB87-E7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&9R9651=65R>2@I"@H@("`@9G5N8W1I
M;VX@9G)E95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("!I8F%S95]F<F5E
M7W%U97)Y*"1Q=65R>2D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@9G5N8W1I;VX@
M;G5M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@:6)A<V5?
M;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES945R<F]R*"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!P<F5P87)E*"D*"B`@("`O*BH*("`@("`J(%!R97!A
M<F5S(&$@<75E<GD@9F]R(&UU;'1I<&QE(&5X96-U=&EO;B!W:71H(&5X96-U
M=&4H*2X*("`@("`J"B`@("`@*B!P<F5P87)E*"D@<F5Q=6ER97,@82!G96YE
M<FEC('%U97)Y(&%S('-T<FEN9R!L:6ME(#QC;V1E/@H@("`@("H@("`@24Y3
M15)4($E.5$\@;G5M8F5R<R!604Q515,@*#\L(#\L(#\I"B`@("`@*B`\+V-O
M9&4^+B`@5&AE(#QK8F0^/SPO:V)D/B!C:&%R86-T97)S(&%R92!P;&%C96AO
M;&1E<G,N"B`@("`@*@H@("`@("H@5&AR964@='EP97,@;V8@<&QA8V5H;VQD
M97)S(&-A;B!B92!U<V5D.@H@("`@("H@("`K(#QK8F0^/SPO:V)D/B`@82!Q
M=6]T960@<V-A;&%R('9A;'5E+"!I+F4N('-T<FEN9W,L(&EN=&5G97)S"B`@
M("`@*B`@("L@/&MB9#XA/"]K8F0^("!V86QU92!I<R!I;G-E<G1E9"`G87,@
M:7,G"B`@("`@*B`@("L@/&MB9#XF/"]K8F0^("!R97%U:7)E<R!A(&9I;&4@
M;F%M92X@(%1H92!F:6QE)W,@8V]N=&5N=',@9V5T"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@(&EN<V5R=&5D(&EN=&\@=&AE('%U97)Y("AI+F4N('-A
M=FEN9R!B:6YA<GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@9&%T82!I
M;B!A(&1B*0H@("`@("H*("`@("`J(%5S92!B86-K<VQA<VAE<R!T;R!E<V-A
M<&4@<&QA8V5H;VQD97(@8VAA<F%C=&5R<R!I9B!Y;W4@9&]N)W0@=V%N=`H@
M("`@("H@=&AE;2!T;R!B92!I;G1E<G!R971E9"!A<R!P;&%C96AO;&1E<G,N
M("!%>&%M<&QE.B`\8V]D93X*("`@("`J("`@(")54$1!5$4@9F]O(%-%5"!C
M;VP]/R!72$5212!C;VP])V]V97(@7"8@=6YD97(G(@H@("`@("H@/"]C;V1E
M/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y('%U97)Y('1O
M(&)E('!R97!A<F5D"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"('-T871E;65N
M="!R97-O=7)C92!O;B!S=6-C97-S+B!$0E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P<F5P87)E*"1Q=65R>2D*("`@('L*("`@
M("`@("`D=&]K96YS("`@/2!P<F5G7W-P;&ET*"<O*"@_/"%<7%PI6R8_(5TI
M+R<L("1Q=65R>2P@+3$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!04D5'7U-03$E47T1%3$E-7T-!4%154D4I.PH@("`@("`@("1T;VME;B`@
M("`](#`["B`@("`@("`@)'1Y<&5S("`@(#T@87)R87DH*3L*("`@("`@("`D
M;F5W<75E<GD@/2`G)SL*"B`@("`@("`@9F]R96%C:"`H)'1O:V5N<R!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@<W=I=&-H("@D=F%L*2!["B`@
M("`@("`@("`@("`@("!C87-E("<_)SH*("`@("`@("`@("`@("`@("`@("`D
M='EP97-;)'1O:V5N*RM=(#T@1$)?4$%204U?4T-!3$%2.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G)B<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-
M7T]005%513L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@)R$G.@H@("`@("`@("`@("`@("`@("`@("1T>7!E<ULD
M=&]K96XK*UT@/2!$0E]005)!35]-25-#.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@("`@("`D=&]K96YS6R1K97E=(#T@<')E9U]R97!L86-E*"<O7%Q<*%LF
M/R%=*2\G+"`B7%PQ(BP@)'9A;"D["B`@("`@("`@("`@("`@("`@("`@)&YE
M=W%U97)Y("X]("1T;VME;G-;)&ME>5T@+B`G/R<["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1N97=Q=65R>2`]('-U8G-T<B@D;F5W<75E
M<GDL(#`L("TQ*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R
M>3L*("`@("`@("`D;F5W<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)&YE
M=W%U97)Y*3L*("`@("`@("`D<W1M="`](&EB87-E7W!R97!A<F4H)'1H:7,M
M/F-O;FYE8W1I;VXL("1N97=Q=65R>2D["B`@("`@("`@)'1H:7,M/G!R97!A
M<F5?='EP97-;*&EN="DD<W1M=%T@/2`D='EP97,["B`@("`@("`@)'1H:7,M
M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=("`@/2!$0CHZ:7--86YI<"@D<75E
M<GDI.PH@("`@("`@(')E='5R;B`D<W1M=#L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!E>&5C=71E*"D*"B`@("`O*BH*("`@("`J($5X96-U=&5S
M(&$@1$(@<W1A=&5M96YT('!R97!A<F5D('=I=&@@<')E<&%R92@I+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`@)'-T;70@(&$@1$(@<W1A=&5M
M96YT(')E<V]U<F-E(')E='5R;F5D(&9R;VT@<')E<&%R92@I"B`@("`@*B!`
M<&%R86T@;6EX960@("1D871A("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@
M9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET
M96US"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M
M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q(&9O<B!N;VXM87)R
M87D@:71E;7,@;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!Q
M=6%N=&ET>2!O9B!E;&5M96YT<R!I;B!T:&4@87)R87DN"B`@("`@*B!`<F5T
M=7)N(&]B:F5C="`@82!N97<@1$)?4F5S=6QT(&]R(&$@1$)?17)R;W(@=VAE
M;B!F86EL"B`@("`@*B!`<V5E($1"7VEB87-E.CIP<F5P87)E*"D*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9E>&5C=71E
M*"1S=&UT+"`D9&%T82`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D9&%T82DI('L*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@D
M9&%T82D["B`@("`@("`@?0H*("`@("`@("`D='EP97,@/28@)'1H:7,M/G!R
M97!A<F5?='EP97-;)'-T;71=.PH@("`@("`@(&EF("AC;W5N="@D='EP97,I
M("$](&-O=6YT*"1D871A*2D@>PH@("`@("`@("`@("`D=&UP(#TF("1T:&ES
M+3YR86ES945R<F]R*$1"7T524D]27TU)4TU!5$-(*3L*("`@("`@("`@("`@
M<F5T=7)N("1T;7`["B`@("`@("`@?0H*("`@("`@("`D:2`](#`["B`@("`@
M("`@9F]R96%C:"`H)&1A=&$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@:68@*"1T>7!E<ULD:5T@/3T@1$)?4$%204U?34E30RD@>PH@("`@
M("`@("`@("`@("`@+RH*("`@("`@("`@("`@("`@("`J(&EB87-E(&1O97-N
M)W0@<V5E;2!T;R!H879E('1H92!A8FEL:71Y('1O('!A<W,@80H@("`@("`@
M("`@("`@("`@("H@<&%R86UE=&5R(&%L;VYG('5N8VAA;F=E9"P@<V\@<W1R
M:7`@;V9F('%U;W1E<R!F<F]M('-T87)T"B`@("`@("`@("`@("`@("`@*B!A
M;F0@96YD+"!P;'5S('1U<FX@='=O('-I;F=L92!Q=6]T97,@=&\@;VYE('-I
M;F=L92!Q=6]T92P*("`@("`@("`@("`@("`@("`J(&EN(&]R9&5R('1O(&%V
M;VED('1H92!Q=6]T97,@9V5T=&EN9R!E<V-A<&5D(&)Y"B`@("`@("`@("`@
M("`@("`@*B!I8F%S92!A;F0@96YD:6YG('5P(&EN('1H92!D871A8F%S92X*
M("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@("`@)&1A=&%;)&ME
M>5T@/2!P<F5G7W)E<&QA8V4H(B]>)R@N*BDG)"\B+"`B7%PQ(BP@)&1A=&%;
M)&ME>5TI.PH@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!S=')?<F5P
M;&%C92@B)R<B+"`B)R(L("1D871A6R1K97E=*3L*("`@("`@("`@("`@?2!E
M;'-E:68@*"1T>7!E<ULD:5T@/3T@1$)?4$%204U?3U!!455%*2!["B`@("`@
M("`@("`@("`@("`D9G`@/2!`9F]P96XH)&1A=&%;)&ME>5TL("=R8B<I.PH@
M("`@("`@("`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@("`@("`@
M("`D=&UP(#TF("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T%#0T534U]6
M24],051)3TXI.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&UP.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@
M/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1D871A6R1K97E=*2D["B`@("`@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D:2LK.PH@("`@("`@('T*"B`@("`@("`@87)R87E?=6YS:&EF="@D9&%T
M82P@)'-T;70I.PH*("`@("`@("`D<F5S(#T@8V%L;%]U<V5R7V9U;F-?87)R
M87DH)VEB87-E7V5X96-U=&4G+"`D9&%T82D["B`@("`@("`@:68@*"$D<F5S
M*2!["B`@("`@("`@("`@("1T;7`@/28@)'1H:7,M/FEB87-E4F%I<V5%<G)O
M<B@I.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("!]"B`@("`@
M("`@+RH@6%A8(&YE960@=&AI<S\*("`@("`@("!I9B`H)'1H:7,M/F%U=&]C
M;VUM:70@)B8@)'1H:7,M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=*2!["B`@
M("`@("`@("`@(&EB87-E7V-O;6UI="@D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@?2HO"B`@("`@("`@:68@*"1T:&ES+3YM86YI<%]Q=65R>5LH:6YT
M*21S=&UT72D@>PH@("`@("`@("`@("`D=&UP(#T@1$)?3TL["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1M<"`])B!N97<@1$)?<F5S=6QT*"1T
M:&ES+"`D<F5S*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T;7`["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&<F5E('1H92!I;G1E<FYA;"!R97-O=7)C
M97,@87-S;V-I871E9"!W:71H(&$@<')E<&%R960@<75E<GDN"B`@("`@*@H@
M("`@("H@0'!A<F%M("1S=&UT(%1H92!I;G1E<F)A<V5?<75E<GD@<F5S;W5R
M8V4@='EP90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U
M8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("HO"B`@
M("!F=6YC=&EO;B!F<F5E4')E<&%R960H)'-T;70I"B`@("!["B`@("`@("`@
M:68@*"%I<U]R97-O=7)C92@D<W1M="DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I8F%S95]F<F5E7W%U97)Y*"1S
M=&UT*3L*("`@("`@("!U;G-E="@D=&AI<RT^<')E<&%R95]T;VME;G-;*&EN
M="DD<W1M=%TI.PH@("`@("`@('5N<V5T*"1T:&ES+3YP<F5P87)E7W1Y<&5S
M6RAI;G0I)'-T;71=*3L*("`@("`@("!U;G-E="@D=&AI<RT^;6%N:7!?<75E
M<GE;*&EN="DD<W1M=%TI.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@(&9U;F-T
M:6]N(&%U=&]#;VUM:70H)&]N;V9F(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)'1H:7,M/F%U=&]C;VUM:70@/2`D;VYO9F8@/R`Q(#H@,#L*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M
M;6ET*"D*"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@(')E
M='5R;B!I8F%S95]C;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("!F=6YC=&EO
M;B!R;VQL8F%C:R@I"B`@("!["B`@("`@("`@<F5T=7)N(&EB87-E7W)O;&QB
M86-K*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!T<F%N<V%C=&EO;DEN:70H*0H*("`@(&9U;F-T:6]N('1R86YS
M86-T:6]N26YI="@D=')A;G-?87)G<R`](#`I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T<F%N<U]A<F=S(#\@:6)A<V5?=')A;G,H)'1R86YS7V%R9W,L("1T
M:&ES+3YC;VYN96-T:6]N*2`Z(&EB87-E7W1R86YS*"D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S
M97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N
M('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO
M="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I
M9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+B`@1$)?17)R;W(@:68@<')O8FQE
M;2X*("`@("`J"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S964@1$)?8V]M
M;6]N.CIN97AT240H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD(#T@=')U
M92D*("`@('L*("`@("`@("`D<W%N(#T@<W1R=&]U<'!E<B@D=&AI<RT^9V5T
M4V5Q=65N8V5.86UE*"1S97%?;F%M92DI.PH@("`@("`@("1R97!E870@/2`P
M.PH@("`@("`@(&1O('L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L
M="`])B`D=&AI<RT^<75E<GDH(E-%3$5#5"!'14Y?240H)'MS<6Y]+"`Q*2`B
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G1E)/32!2
M1$(D1T5.15)!5$]24R`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`B5TA%4D4@4D1"7"1'14Y%4D%43U)?3D%-13TG)'MS<6Y])R(I
M.PH@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@
M("`@("`@("!I9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I
M*2!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@,3L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N86UE
M*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)')E<&5A="`](#`["B`@("`@("`@("`@('T*("`@("`@("!]('=H:6QE
M("@D<F5P96%T*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U
M;'0I.PH@("`@("`@('T*("`@("`@("`D87)R(#T@)')E<W5L="T^9F5T8VA2
M;W<H1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@("1R97-U;'0M/F9R
M964H*3L*("`@("`@("!R971U<FX@)&%R<ELP73L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!C<F5A=&5397%U96YC92@I"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&4@=&AE('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<V5Q7VYA;64@=&AE(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@
M*B!`<F5T=7)N(&UI>&5D($1"7T]+(&]N('-U8V-E<W,@;W(@1$(@97)R;W(@
M;VX@97)R;W(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@
M("`D<W%N(#T@<W1R=&]U<'!E<B@D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S
M97%?;F%M92DI.PH@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ
M=65R>2@B0U)%051%($=%3D52051/4B`D>W-Q;GTB*3L*("`@("`@("`D=&AI
M<RT^<&]P17)R;W)(86YD;&EN9R@I.PH*("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H
M*0H*("`@("\J*@H@("`@("H@1')O<"!A('-E<75E;F-E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@=&AE(&YA;64@;V8@=&AE('-E
M<75E;F-E"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"7T]+(&]N('-U8V-E<W,@
M;W(@1$(@97)R;W(@;VX@97)R;W(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I"B`@
M("!["B`@("`@("`@)'-Q;B`]('-T<G1O=7!P97(H)'1H:7,M/F=E=%-E<75E
M;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@("`@("!R971U<FX@)'1H:7,M/G%U
M97)Y*"=$14Q%5$4@1E)/32!21$(D1T5.15)!5$]24R`G"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N(")72$5212!21$)<)$=%3D52051/4E].04U%
M/2<D>W-Q;GTG(BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7VEB
M87-E1FEE;&1&;&%G<R@I"@H@("`@+RHJ"B`@("`@*B!G970@=&AE($9L86=S
M(&]F(&$@1FEE;&0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:65L
M9%]N86UE('1H92!N86UE(&]F('1H92!F:65L9`H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&%B;&5?;F%M92!T:&4@;F%M92!O9B!T:&4@=&%B;&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@9FQA9W,@;V8@=&AE(&9I96QD
M("@B<')I;6%R>5]K97DB+"`B=6YI<75E7VME>2(L(")N;W1?;G5L;"(*("`@
M("`J("`@("`@("`@("`@("`@(")D969A=6QT(BP@(F-O;7!U=&5D(B!A;F0@
M(F)L;V(B(&%R92!S=7!P;W)T960I"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7VEB87-E1FEE;&1&;&%G<R@D9FEE;&1?
M;F%M92P@)'1A8FQE7VYA;64I"B`@("!["B`@("`@("`@)'-Q;"`]("=314Q%
M0U0@4BY21$(D0T].4U1204E.5%]465!%($-465!%)PH@("`@("`@("`@("`@
M("`N)R!&4D]-(%)$0B1)3D1%6%]314=-14Y44R!))PH@("`@("`@("`@("`@
M("`N)R`@2D])3B!21$(D4D5,051)3TY?0T].4U1204E.5%,@4B!/3B!)+E)$
M0B1)3D1%6%].04U%/5(N4D1")$E.1$587TY!344G"B`@("`@("`@("`@("`@
M("XG(%=(15)%($DN4D1")$9)14Q$7TY!344]7"<G("X@)&9I96QD7VYA;64@
M+B`G7"<G"B`@("`@("`@("`@("`@("XG("!!3D0@55!015(H4BY21$(D4D5,
M051)3TY?3D%-12D]7"<G("X@<W1R=&]U<'!E<B@D=&%B;&5?;F%M92D@+B`G
M7"<G.PH*("`@("`@("`D<F5S=6QT(#T@:6)A<V5?<75E<GDH)'1H:7,M/F-O
M;FYE8W1I;VXL("1S<6PI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FEB87-E4F%I<V5%<G)O<B@I.PH@("`@
M("`@('T*"B`@("`@("`@)&9L86=S(#T@)R<["B`@("`@("`@:68@*"1O8FH@
M/2!`:6)A<V5?9F5T8VA?;V)J96-T*"1R97-U;'0I*2!["B`@("`@("`@("`@
M(&EB87-E7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@("`@("`@("!I9B`H
M:7-S970H)&]B:BT^0U194$4I("`F)B!T<FEM*"1O8FHM/D-465!%*2`]/2`G
M4%))34%262!+15DG*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)W!R
M:6UA<GE?:V5Y("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1O8FHM/D-465!%*2`@)B8@=')I;2@D;V)J+3Y#5%E012D@/3T@)U5.
M25%512<I('L*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G=6YI<75E7VME
M>2`G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W%L(#T@
M)U-%3$5#5"!2+E)$0B1.54Q,7T9,04<@05,@3D9,04<L)PH@("`@("`@("`@
M("`@("`N)R`@4BY21$(D1$5&055,5%]33U520T4@05,@1%-/55)#12PG"B`@
M("`@("`@("`@("`@("XG("!&+E)$0B1&245,1%]465!%($%3($9465!%+"<*
M("`@("`@("`@("`@("`@+B<@($8N4D1")$-/35!55$5$7U-/55)#12!!4R!#
M4T]54D-%)PH@("`@("`@("`@("`@("`N)R!&4D]-(%)$0B1214Q!5$E/3E]&
M245,1%,@4B`G"B`@("`@("`@("`@("`@("XG("!*3TE.(%)$0B1&245,1%,@
M1B!/3B!2+E)$0B1&245,1%]33U520T4]1BY21$(D1DE%3$1?3D%-12<*("`@
M("`@("`@("`@("`@+B<@5TA%4D4@55!015(H4BY21$(D4D5,051)3TY?3D%-
M12D]7"<G("X@<W1R=&]U<'!E<B@D=&%B;&5?;F%M92D@+B`G7"<G"B`@("`@
M("`@("`@("`@("XG("!!3D0@4BY21$(D1DE%3$1?3D%-13U<)R<@+B`D9FEE
M;&1?;F%M92`N("=<)R<["@H@("`@("`@("1R97-U;'0@/2!I8F%S95]Q=65R
M>2@D=&AI<RT^8V]N;F5C=&EO;BP@)'-Q;"D["B`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@(&EF("@D;V)J(#T@0&EB87-E7V9E
M=&-H7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!I8F%S95]F<F5E
M7W)E<W5L="@D<F5S=6QT*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FHM
M/DY&3$%'*2D@>PH@("`@("`@("`@("`@("`@)&9L86=S("X]("=N;W1?;G5L
M;"`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D;V)J
M+3Y$4T]54D-%*2D@>PH@("`@("`@("`@("`@("`@)&9L86=S("X]("=D969A
M=6QT("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1O
M8FHM/D-33U520T4I*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)V-O
M;7!U=&5D("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1O8FHM/D9465!%*2`@)B8@)&]B:BT^1E194$4@/3T@,C8Q*2!["B`@("`@
M("`@("`@("`@("`D9FQA9W,@+CT@)V)L;V(@)SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R:6TH)&9L86=S*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@
M<F5S=6QT('-E="X*("`@("`J"B`@("`@*B!.3U1%.B!O;FQY('-U<'!O<G1S
M("=T86)L92<@86YD("=F;&%G<R<@:68@/'9A<CXD<F5S=6QT/"]V87(^"B`@
M("`@*B!I<R!A('1A8FQE(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B
M:F5C='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A
M('%U97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE"B`@
M("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T
M86)L94EN9F\@;6]D90H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I
M871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D"B`@
M("`@*B`@("`@("`@("`@("`@("!O<B!A;B!E<G)O<B!O8FIE8W0@:68@<V]M
M971H:6YG(&ES('=R;VYG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0&EN=&5R;F%L"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)')E<W5L="T^<F5S
M=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L
M>2!R96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X
M=')A8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@
M("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@
M("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS
M96EF("AI<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@
M("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@
M("`@("`@("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I
M9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`D:60@/2!`:6)A
M<V5?<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(E-%3$5#5"`J($923TT@)')E<W5L="!72$5212`Q
M/3`B*3L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A
M8FQY(')E8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@
M("`@("`@("`@("`J($-O<'D@:70N"B`@("`@("`@("`@("`J($1E<')I8V%T
M960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@("`@
M("`J+PH@("`@("`@("`@("`@)&ED(#T@)')E<W5L=#L*("`@("`@("`@("`@
M)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL
M:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*("`@("`@("`@
M("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@
M?0H*("`@("`@("`D8V]U;G0@/2!`:6)A<V5?;G5M7V9I96QD<R@D:60I.PH*
M("`@("`@("`O+R!M861E('1H:7,@248@9'5E('1O('!E<F9O<FUA;F-E("AO
M;F4@:68@:7,@9F%S=&5R('1H86X@)&-O=6YT(&EF)W,I"B`@("`@("`@:68@
M*"$D;6]D92D@>PH@("`@("`@("`@("!F;W(@*"1I/3`[("1I/"1C;W5N=#L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@)&EN9F\@/2!`:6)A<V5?9FEE;&1?
M:6YF;R@D:60L("1I*3L*("`@("`@("`@("`@("`@("1R97-;)&E=6R=T86)L
M92==(#T@)&=O=%]S=')I;F<@/R`D8V%S95]F=6YC*"1R97-U;'0I(#H@)R<[
M"B`@("`@("`@("`@("`@("`D<F5S6R1I75LG;F%M92==("`]("1C87-E7V9U
M;F,H)&EN9F];)VYA;64G72D["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG
M='EP92==("`]("1I;F9O6R=T>7!E)UT["B`@("`@("`@("`@("`@("`D<F5S
M6R1I75LG;&5N)UT@("`]("1I;F9O6R=L96YG=&@G73L*("`@("`@("`@("`@
M("`@("1R97-;)&E=6R=F;&%G<R==(#T@*"1G;W1?<W1R:6YG*2`_("1T:&ES
M+3Y?:6)A<V5&:65L9$9L86=S*"1I;F9O6R=N86UE)UTL("1R97-U;'0I(#H@
M)R<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>R`O+R!F=6QL"B`@
M("`@("`@("`@("1R97-;)VYU;5]F:65L9',G73T@)&-O=6YT.PH*("`@("`@
M("`@("`@9F]R("@D:3TP.R`D:3PD8V]U;G0[("1I*RLI('L*("`@("`@("`@
M("`@("`@("1I;F9O(#T@0&EB87-E7V9I96QD7VEN9F\H)&ED+"`D:2D["B`@
M("`@("`@("`@("`@("`D<F5S6R1I75LG=&%B;&4G72`]("1G;W1?<W1R:6YG
M(#\@)&-A<V5?9G5N8R@D<F5S=6QT*2`Z("<G.PH@("`@("`@("`@("`@("`@
M)')E<ULD:5U;)VYA;64G72`@/2`D8V%S95]F=6YC*"1I;F9O6R=N86UE)UTI
M.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)W1Y<&4G72`@/2`D:6YF;ULG
M='EP92==.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)VQE;B==("`@/2`D
M:6YF;ULG;&5N9W1H)UT["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG9FQA
M9W,G72`]("@D9V]T7W-T<FEN9RD@/R`D=&AI<RT^7VEB87-E1FEE;&1&;&%G
M<R@D:6YF;ULG;F%M92==+"`D<F5S=6QT*2`Z("<G.PH*("`@("`@("`@("`@
M("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@
M("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D
M;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@("`@
M("`@("`@("`@)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==
M75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!F<F5E('1H92!R
M97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@
M("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@("`@(&EB87-E7V9R965?
M<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&EB87-E4F%I<V5%<G)O<B@I
M"@H@("`@+RHJ"B`@("`@*B!'871H97(@:6YF;W)M871I;VX@86)O=70@86X@
M97)R;W(L('1H96X@=7-E('1H870@:6YF;R!T;R!C<F5A=&4@80H@("`@("H@
M1$(@97)R;W(@;V)J96-T(&%N9"!F:6YA;&QY(')E='5R;B!T:&%T(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@(&EN=&5G97(@("1D8E]E<G)N;R`@
M4$5!4B!E<G)O<B!N=6UB97(@*'5S=6%L;'D@82!$0B!C;VYS=&%N="D@:68*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!M86YU86QL>2!R
M86ES:6YG(&%N(&5R<F]R"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&YA=&EV
M95]E<G)M<V<@('1E>'0@;V8@97)R;W(@;65S<V%G92!I9B!K;F]W;@H@("`@
M("H@0')E='5R;B!O8FIE8W0@($1"(&5R<F]R(&]B:F5C=`H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.F5R<F]R0V]D92@I"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ<F%I<V5%<G)O<B@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9I8F%S95)A
M:7-E17)R;W(H)&1B7V5R<FYO(#T@;G5L;"P@)&YA=&EV95]E<G)M<V<@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@D;F%T:79E7V5R<FUS9R`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D;F%T:79E7V5R<FUS9R`](&EB87-E7V5R<FUS
M9R@I.PH@("`@("`@('T*("`@("`@("`O+R!M96UO(&9O<B!T:&4@:6YT97)B
M87-E('!H<"!M;V1U;&4@:&%C:V5R<SH@=V4@;F5E9"!S;VUE=&AI;F<@<VEM
M:6QA<@H@("`@("`@("\O('1O(&UY<W%L7V5R<FYO*"D@=&\@<F5T<FEE=F4@
M97)R;W(@8V]D97,@:6YS=&5A9"!O9B!T:&ES('5G;'D@:&%C:PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7BA;7C`M.5PM72LI*%LP+3E<+5TK*5QS*R@N
M*BDD+R<L("1N871I=F5?97)R;7-G+"`D;2DI('L*("`@("`@("`@("`@)&YA
M=&EV95]E<G)N;R`]("AI;G0I)&U;,ET["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&YA=&EV95]E<G)N;R`](&YU;&P["B`@("`@("`@?0H@("`@
M("`@("\O('1R>2!T;R!M87`@=&AE(&YA=&EV92!E<G)O<B!T;R!T:&4@1$(@
M;VYE"B`@("`@("`@:68@*"1D8E]E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@
M("`@("!I9B`H)&YA=&EV95]E<G)N;RD@>PH@("`@("`@("`@("`@("`@+R\@
M=')Y('1O(&EN=&5R<')E="!);G1E<F)A<V4@97)R;W(@8V]D92`H=&AA="=S
M('=H>2!W92!N965D(&EB87-E7V5R<FYO*"D*("`@("`@("`@("`@("`@("\O
M(&EN('1H92!I;G1E<F)A<V4@;6]D=6QE('1O(')E='5R;B!T:&4@<F5A;"!E
M<G)O<B!C;V1E*0H@("`@("`@("`@("`@("`@<W=I=&-H("@D;F%T:79E7V5R
M<FYO*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`M,C`T.@H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-?:6YT*'-T<G!O<R@D;5LS72P@)U1A
M8FQE('5N:VYO=VXG*2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D8E]E<G)N;R`]($1"7T524D]27TY/4U5#2%1!0DQ%.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1D8E]E<G)N;R`]("1T:&ES+3YE<G)O<D-O9&4H)&YA=&EV
M95]E<G)N;RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D97)R;W)?<F5G97AP<R`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("<O6W1476%B;&4@;F]T(&9O=6YD+R<@/3X@
M1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@("`@("`@("`@)R];
M=%1=86)L92`N*B!A;')E861Y(&5X:7-T<R\G(#T^($1"7T524D]27T%,4D5!
M1%E?15A)4U13+`H@("`@("`@("`@("`@("`@("`@("<O=F%L:61A=&EO;B!E
M<G)O<B!F;W(@8V]L=6UN("XJ('9A;'5E(")<*EPJ7"H@;G5L;"\G(#T^($1"
M7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@("`@
M("`@)R]V:6]L871I;VX@;V8@6UQW(%TK(&-O;G-T<F%I;G0O)R`]/B!$0E]%
M4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`@("`@("`@("<O8V]N=F5R
M<VEO;B!E<G)O<B!F<F]M('-T<FEN9R\G(#T^($1"7T524D]27TE.5D%,241?
M3E5-0D52+`H@("`@("`@("`@("`@("`@("`@("<O;F\@<&5R;6ES<VEO;B!F
M;W(O)R`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@("`@("`@
M("`@("`@("`@("<O87)I=&AM971I8R!E>&-E<'1I;VXL(&YU;65R:6,@;W9E
M<F9L;W<L(&]R('-T<FEN9R!T<G5N8V%T:6]N+R<@/3X@1$)?15)23U)?1$E6
M6D523PH@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1E<G)O<E]R96=E>'!S(&%S("1R96=E>'`@/3X@)&-O9&4I('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<F5G97AP+"`D;F%T
M:79E7V5R<FUS9RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1B7V5R
M<FYO(#T@)&-O9&4["B`@("`@("`@("`@("`@("`@("`@("`@("1N871I=F5?
M97)R;F\@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'1M<"`])B`D=&AI<RT^<F%I
M<V5%<G)O<B@D9&)?97)R;F\L(&YU;&PL(&YU;&PL(&YU;&PL("1N871I=F5?
M97)R;7-G*3L*("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O+R!]
M?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T
M"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+VUS
M<W%L+G!H<```````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#4U,38S`#$P-#$W,S8S,#`V`#`Q-S4P-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E
M>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!F;VQD;65T:&]D/6UA
M<FME<CH@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R.B!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG
M0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($UA
M:6YT86EN97(Z($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@;7-S<6PN<&AP+'8@,2XU,2`R,#`T+S`R
M+S$X(#(S.C`W.C$P(&1A;FEE;&,@17AP("0*"G)E<75I<F5?;VYC92`G1$(O
M8V]M;6]N+G!H<"<["@HO*BH*("H@1&%T86)A<V4@:6YD97!E;F1E;G0@<75E
M<GD@:6YT97)F86-E(&1E9FEN:71I;VX@9F]R(%!(4"=S($UI8W)O<V]F="!3
M44P@4V5R=F5R"B`J(&5X=&5N<VEO;BX*("H*("H@0'!A8VMA9V4@($1""B`J
M($!V97)S:6]N("`D260Z(&US<W%L+G!H<"QV(#$N-3$@,C`P-"\P,B\Q."`R
M,SHP-SHQ,"!D86YI96QC($5X<"`D"B`J($!C871E9V]R>2!$871A8F%S90H@
M*B!`875T:&]R("`@4W1E<FQI;F<@2'5G:&5S(#QS=&5R;&EN9T!P:'`N;F5T
M/@H@*B\*8VQA<W,@1$)?;7-S<6P@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@
M+R\@>WM[('!R;W!E<G1I97,*"B`@("!V87(@)&-O;FYE8W1I;VX["B`@("!V
M87(@)'!H<'1Y<&4L("1D8G-Y;G1A>#L*("`@('9A<B`D<')E<&%R95]T;VME
M;G,@/2!A<G)A>2@I.PH@("`@=F%R("1P<F5P87)E7W1Y<&5S(#T@87)R87DH
M*3L*("`@('9A<B`D=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("!V87(@
M)&%U=&]C;VUM:70@/2!T<G5E.PH@("`@=F%R("1?9&(@/2!N=6QL.PH*("`@
M("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@9G5N8W1I;VX@
M1$)?;7-S<6PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*
M("`@("`@("`D=&AI<RT^<&AP='EP92`]("=M<W-Q;"<["B`@("`@("`@)'1H
M:7,M/F1B<WEN=&%X(#T@)VUS<W%L)SL*("`@("`@("`D=&AI<RT^9F5A='5R
M97,@/2!A<G)A>2@*("`@("`@("`@("`@)W!R97!A<F4G(#T^(&9A;'-E+`H@
M("`@("`@("`@("`G<&-O;FYE8W0G(#T^('1R=64L"B`@("`@("`@("`@("=T
M<F%N<V%C=&EO;G,G(#T^('1R=64L"B`@("`@("`@("`@("=L:6UI="<@/3X@
M)V5M=6QA=&4G"B`@("`@("`@*3L*("`@("`@("`O+R!86%@@061D(&AE<F4@
M97)R;W(@8V]D97,@:64Z("=3,3`P12<@/3X@1$)?15)23U)?4UE.5$%8"B`@
M("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@("`@("`@
M("`@,3<P("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`R,#<@
M("`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@,C`X("`@
M/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@(#(T-2`@(#T^
M($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@("`@("`U,34@("`]
M/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@("`@("`U
M-#<@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`R-C(W
M("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`R-S$T("`]
M/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@("`@,S<P,2`@
M/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@(#@Q,S0@(#T^
M($1"7T524D]27T1)5EI%4D\L"B`@("`@("`@*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("!F=6YC=&EO;B!C;VYN96-T
M*"1D<VYI;F9O+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A1$(Z.F%S<V5R=$5X=&5N<VEO;B@G;7-S<6PG*2`F)B`A1$(Z.F%S
M<V5R=$5X=&5N<VEO;B@G<WEB87-E)RD*("`@("`@("`@("`@)B8@(41".CIA
M<W-E<G1%>'1E;G-I;VXH)W-Y8F%S95]C="<I*0H@("`@("`@('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.
M4TE/3E].3U1?1D]53D0I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^9'-N
M(#T@)&1S;FEN9F\["B`@("`@("`@)&1B:&]S="`]("1D<VYI;F9O6R=H;W-T
M<W!E8R==(#\@)&1S;FEN9F];)VAO<W1S<&5C)UT@.B`G;&]C86QH;W-T)SL*
M("`@("`@("`D9&)H;W-T("X]("1D<VYI;F9O6R=P;W)T)UT@/R`G.B<@+B`D
M9'-N:6YF;ULG<&]R="==(#H@)R<["@H@("`@("`@("1C;VYN96-T7V9U;F-T
M:6]N(#T@)'!E<G-I<W1E;G0@/R`G;7-S<6Q?<&-O;FYE8W0G(#H@)VUS<W%L
M7V-O;FYE8W0G.PH*("`@("`@("!I9B`H)&1B:&]S="`F)B`D9'-N:6YF;ULG
M=7-E<FYA;64G72`F)B`D9'-N:6YF;ULG<&%S<W=O<F0G72D@>PH@("`@("`@
M("`@("`D8V]N;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D9&)H;W-T+"`D9'-N
M:6YF;ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1S;FEN9F];)W!A<W-W;W)D)UTI.PH@("`@("`@('T@
M96QS96EF("@D9&)H;W-T("8F("1D<VYI;F9O6R=U<V5R;F%M92==*2!["B`@
M("`@("`@("`@("1C;VYN(#T@0"1C;VYN96-T7V9U;F-T:6]N*"1D8FAO<W0L
M("1D<VYI;F9O6R=U<V5R;F%M92==*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8V]N;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D9&)H;W-T*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"$D8V]N;BD@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,
M140L(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;G5L;"P@;7-S<6Q?9V5T7VQA<W1?;65S<V%G92@I*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1D<VYI;F9O6R=D871A8F%S92==*2![
M"B`@("`@("`@("`@(&EF("@A0&US<W%L7W-E;&5C=%]D8B@D9'-N:6YF;ULG
M9&%T86)A<V4G72P@)&-O;FXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&YU;&PL(&US<W%L7V=E=%]L87-T7VUE<W-A9V4H*2D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("1D<VYI;F9O6R=D871A
M8F%S92==.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]
M("1C;VYN.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("!F=6YC=&EO;B!D:7-C
M;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0&US<W%L7V-L;W-E*"1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]
M(&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@(&9U;F-T:6]N('-I;7!L
M95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII
M<TUA;FEP*"1Q=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D
M<75E<GD["B`@("`@("`@:68@*"%`;7-S<6Q?<V5L96-T7V1B*"1T:&ES+3Y?
M9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I
M.PH@("`@("`@('T*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y475E
M<GDH)'%U97)Y*3L*("`@("`@("!I9B`H(21T:&ES+3YA=71O8V]M;6ET("8F
M("1I<VUA;FEP*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I
M;VY?;W!C;W5N="`]/2`P*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M0&US<W%L7W%U97)Y*"="14=)3B!44D%.)RP@)'1H:7,M/F-O;FYE8W1I;VXI
M.PH@("`@("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^=')A;G-A8W1I;VY?;W!C;W5N="LK.PH@("`@("`@('T*("`@("`@("`D
M<F5S=6QT(#T@0&US<W%L7W%U97)Y*"1Q=65R>2P@)'1H:7,M/F-O;FYE8W1I
M;VXI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@
M("`O+R!$971E<FUI;F4@=VAI8V@@<75E<FEE<R!T:&%T('-H;W5L9"!R971U
M<FX@9&%T82P@86YD('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E='5R;B!A
M;B!E<G)O<B!C;V1E(&]N;'DN"B`@("`@("`@<F5T=7)N("1I<VUA;FEP(#\@
M1$)?3TL@.B`D<F5S=6QT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N
M86P@;7-S<6P@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA8FQE
M(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A('9A;&ED(&9B<W%L(')E
M<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES(&%V86EL
M86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@
M;7-S<6Q?;F5X=%]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J($9E=&-H
M(&$@<F]W(&%N9"!I;G-E<G0@=&AE(&1A=&$@:6YT;R!A;B!E>&ES=&EN9R!A
M<G)A>2X*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N
M9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3
M964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!Q
M=65R>2!R97-U;'0@:61E;G1I9FEE<@H@("`@("H@0'!A<F%M(&%R<F%Y("`@
M("1A<G(@("`@("`@*')E9F5R96YC92D@87)R87D@=VAE<F4@9&%T82!F<F]M
M('1H92!R;W<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('-H
M;W5L9"!B92!P;&%C960*("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM
M;V1E(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D
M"B`@("`@*B!`<&%R86T@:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU
M;6)E<B!T;R!F971C:`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@1$)?
M3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N(&5N9"!O9B!R97-U;'0@<V5T(&ES
M"B`@("`@*B`@("`@("`@("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@
M("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H
M26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;3UN=6QL
M*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@
M("`@("`@(&EF("@A0&US<W%L7V1A=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#
M2$U/1$5?05-33T,I('L*("`@("`@("`@("`@)&%R<B`]($!M<W-Q;%]F971C
M:%]A<G)A>2@D<F5S=6QT+"!-4U-13%]!4U-/0RD["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197TQ/5T520T%312`F)B`D87)R*2!["B`@("`@("`@("`@("`@("`D87)R
M(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R
M<B`]($!M<W-Q;%]F971C:%]R;W<H)')E<W5L="D["B`@("`@("`@?0H@("`@
M("`@(&EF("@A)&%R<BD@>PH@("`@("`@("`@("`O*B!4:&ES('1H<F]W<R!I
M;F9O<FUA=&EV92!E<G)O<B!M97-S86=E<RP*("`@("`@("`@("`@("`@9&]N
M)W0@=7-E(&ET(&9O<B!N;W<*("`@("`@("`@("`@:68@*"1M<V<@/2!M<W-Q
M;%]G971?;&%S=%]M97-S86=E*"DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D;7-G*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`J+PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M/E]R
M=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E4
M65].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R
M=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!F<F5E4F5S=6QT*"D*"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U
M;'0I"B`@("!["B`@("`@("`@<F5T=7)N($!M<W-Q;%]F<F5E7W)E<W5L="@D
M<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS
M*"D*"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@
M("`@)&-O;',@/2!`;7-S<6Q?;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@
M("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S
M<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V]L
M<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U2;W=S*"D*"B`@
M("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@)')O
M=W,@/2!`;7-S<6Q?;G5M7W)O=W,H)')E<W5L="D["B`@("`@("`@:68@*"1R
M;W=S(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS
M<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')O
M=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI="@I
M"@H@("`@+RHJ"B`@("`@*B!%;F%B;&4O9&ES86)L92!A=71O;6%T:6,@8V]M
M;6ET<PH@("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A
M8W1I;VY?;W!C;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@
M("\O(&ES<W5E(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O
M8V]M;6ET(#T@)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R
M;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H
M*0H*("`@("\J*@H@("`@("H@0V]M;6ET('1H92!C=7)R96YT('1R86YS86-T
M:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@
M("`@("`@("`@:68@*"%`;7-S<6Q?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T
M:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YM<W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT(#T@0&US<W%L7W%U
M97)Y*"=#3TU-250@5%)!3B<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@
M("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;7-S<6Q286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*("`@("`J(%)O;&P@8F%C
M:R`H=6YD;RD@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@A
M0&US<W%L7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO
M;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES
M945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)')E<W5L="`]($!M<W-Q;%]Q=65R>2@G4D],3$)!0TL@
M5%)!3B<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H:7,M
M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H(21R
M97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q2
M86ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F
M9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@
M;V8@<F]W<R!A9F9E8W1E9"!B>2!T:&4@;&%S="!Q=65R>2X*("`@("`J(&EF
M('1H92!L87-T('%U97)Y('=A<R!A('-E;&5C="P@<F5T=7)N<R`P+@H@("`@
M("H*("`@("`J($!R971U<FX@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@
M=&AE(&QA<W0@<75E<GD@;W(@1$)?15)23U(*("`@("`J+PH@("`@9G5N8W1I
M;VX@869F96-T9612;W=S*"D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N
M:7`H)'1H:7,M/FQA<W1?<75E<GDI*2!["B`@("`@("`@("`@("1R97,@/2!`
M;7-S<6Q?<75E<GDH)W-E;&5C="!`0')O=V-O=6YT)RP@)'1H:7,M/F-O;FYE
M8W1I;VXI.PH@("`@("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R*"D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&%R(#T@0&US<W%L7V9E=&-H7W)O=R@D<F5S
M*3L*("`@("`@("`@("`@:68@*"$D87(I('L*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`P.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@0&US<W%L7V9R965?<F5S=6QT*"1R97,I.PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1A<ELP73L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1R97-U;'0@/2`P.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X="!F
M<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E<65N
M8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU;6)E<B!I;B!T:&4@
M<V5Q=65N8V4N("!$0E]%<G)O<B!I9B!P<F]B;&5M+@H@("`@("H*("`@("`J
M($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.FYE>'1)1"@I"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!N97AT
M260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@
M("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I
M.PH@("`@("`@(&EF("@A0&US<W%L7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D
M=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YM<W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@
M("`@("!]"B`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@9&\@>PH@("`@
M("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"))
M3E-%4E0@24Y43R`D<V5Q;F%M92`H=F%P;W(I(%9!3%5%4R`H,"DB*3L*("`@
M("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@
M("`@:68@*"1O;F1E;6%N9"`F)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@
M("`@("`@("`@("`@("`@*"1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%4E)/
M4B!\?"`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"
M3$4I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@
M,3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q
M=65N8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E:68@*"%$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("`@("`@)')E<W5L="`])B`D=&AI<RT^<75E<GDH(E-%
M3$5#5"!`0$E$14Y42519($923TT@)'-E<6YA;64B*3L*("`@("`@("`@("`@
M("`@("1R97!E870@/2`P.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)')E<&5A="`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!W:&EL92`H)')E<&5A="D["B`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]("1R
M97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*("`@("`@
M("!R971U<FX@)')E<W5L=%LP73L*("`@('T*"B`@("`O*BH*("`@("`J($-R
M96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E<75E;F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"
M7T5R<F]R(&]B:F5C="!I<R!R971U<FYE9"!I9@H@("`@("H@("`@("`@("`@
M("`@('!R;V)L96US(&%R:7-E+@H@("`@("H*("`@("`J($!I;G1E<FYA;`H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"D*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E
M<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T
M:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("!R971U
M<FX@)'1H:7,M/G%U97)Y*")#4D5!5$4@5$%"3$4@)'-E<6YA;64@(BX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<H6VED72!;:6YT72!)1$5.5$E4
M62`H,2P@,2D@3D]4($Y53$P@+"<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)UMV87!O<ET@6VEN=%T@3E5,3"DG*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@
M1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T
M960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S
M<RX@($1"7T5R<F]R(&EF('!R;V)L96US+@H@("`@("H*("`@("`J($!I;G1E
M<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P
M4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@
M)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@(')E
M='5R;B`D=&AI<RT^<75E<GDH(D123U`@5$%"3$4@)'-E<6YA;64B*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@
M+RHJ"B`@("`@*B!$971E<FUI;F4@35,@4U%,(%-E<G9E<B!E<G)O<B!C;V1E
M(&)Y('%U97)Y:6YG($!`15)23U(N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@;7-S<6PG<R!N871I=F4@97)R;W(@8V]D92!O<B!$0E]%4E)/4B!I
M9B!U;FMN;W=N+@H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I
M"B`@("!["B`@("`@("`@)')E<R`](&US<W%L7W%U97)Y*"=S96QE8W0@0$!%
M4E)/4B!A<R!%<G)O<D-O9&4G+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@
M("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B!$0E]%4E)/4CL*
M("`@("`@("!]"B`@("`@("`@)')O=R`](&US<W%L7V9E=&-H7W)O=R@D<F5S
M*3L*("`@("`@("!R971U<FX@)')O=ULP73L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!E<G)O<D-O9&4H*0H*("`@("\J*@H@("`@("H@1&5T97)M
M:6YE(%!%05(Z.D1"(&5R<F]R(&-O9&4@9G)O;2!M<W-Q;"=S(&YA=&EV92!C
M;V1E<RX*("`@("`J"B`@("`@*B!)9B`\=F%R/B1N871I=F5C;V1E/"]V87(^
M(&ES;B=T(&MN;W=N('EE="P@:70@=VEL;"!B92!L;V]K960@=7`N"B`@("`@
M*@H@("`@("H@0'!A<F%M("!M:7AE9"`@)&YA=&EV96-O9&4@(&US<W%L(&5R
M<F]R(&-O9&4L(&EF(&MN;W=N"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(&%N
M(&5R<F]R(&YU;6)E<B!F<F]M(&$@1$(@97)R;W(@8V]N<W1A;G0*("`@("`J
M($!S964@97)R;W).871I=F4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O
M<D-O9&4H)&YA=&EV96-O9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M)&YA=&EV96-O9&4I('L*("`@("`@("`@("`@)&YA=&EV96-O9&4@/2`D=&AI
M<RT^97)R;W).871I=F4H*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YE<G)O<F-O9&5?;6%P6R1N871I=F5C;V1E72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YE<G)O<F-O9&5?;6%P6R1N871I=F5C;V1E
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@1$)?15)2
M3U(["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&US
M<W%L4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!'871H97(@:6YF;W)M
M871I;VX@86)O=70@86X@97)R;W(L('1H96X@=7-E('1H870@:6YF;R!T;R!C
M<F5A=&4@80H@("`@("H@1$(@97)R;W(@;V)J96-T(&%N9"!F:6YA;&QY(')E
M='5R;B!T:&%T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@(&EN=&5G
M97(@("1C;V1E("!014%2(&5R<F]R(&YU;6)E<B`H=7-U86QL>2!A($1"(&-O
M;G-T86YT*2!I9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@;6%N
M=6%L;'D@<F%I<VEN9R!A;B!E<G)O<@H@("`@("H@0')E='5R;B!O8FIE8W0@
M($1"(&5R<F]R(&]B:F5C=`H@("`@("H@0'-E92!E<G)O<D-O9&4H*0H@("`@
M("H@0'-E92!E<G)O<DYA=&EV92@I"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M<F%I<V5%<G)O<B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&US<W%L4F%I<V5%
M<G)O<B@D8V]D92`](&YU;&PI"B`@("!["B`@("`@("`@)&UE<W-A9V4@/2!M
M<W-Q;%]G971?;&%S=%]M97-S86=E*"D["B`@("`@("`@:68@*"$D8V]D92D@
M>PH@("`@("`@("`@("`D8V]D92`]("1T:&ES+3YE<G)O<DYA=&EV92@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'1H
M:7,M/F5R<F]R0V]D92@D8V]D92DL(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("(D8V]D92`M("1M97-S86=E
M(BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T
M86)L92!O<B!A(')E<W5L="!S970N"B`@("`@*@H@("`@("H@3D]413H@;VYL
M>2!S=7!P;W)T<R`G=&%B;&4G(&%N9"`G9FQA9W,G(&EF(#QV87(^)')E<W5L
M=#PO=F%R/@H@("`@("H@:7,@82!T86)L92!N86UE+@H@("`@("H*("`@("`J
M($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J
M96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@
M82!T86)L90H@("`@("H@0'!A<F%M(&EN="`@("`@("`@("`@("1M;V1E("`@
M(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*("`@("`J($!R971U<FX@87)R87D@
M(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E
M<75E<W1E9`H@("`@("H@("`@("`@("`@("`@("`@;W(@86X@97)R;W(@;V)J
M96-T(&EF('-O;65T:&EN9R!I<R!W<F]N9PH@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A
M8FQE26YF;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S
M=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1R
M97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@
M("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@;V)J96-T+@H@("`@("`@
M("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE
M<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0M
M/G)E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@
M("`@("!](&5L<V5I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@=&%B
M;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S=6QT(')E<V]U
M<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("!I
M9B`H(4!M<W-Q;%]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE
M8W1I;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L
M4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1I9"`]($!M<W-Q;%]Q=65R>2@B4T5,14-4("H@
M1E)/32`D<F5S=6QT(%=(15)%(#$],"(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1G
M;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L
M="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y(&ET
M+@H@("`@("`@("`@("`@*B!$97!R:6-A=&5D+B`@2&5R92!F;W(@8V]M<&%T
M:6)I;&ET>2!O;FQY+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED
M(#T@)')E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%
M4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E4
M65],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T
M;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F
M=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@/2!`
M;7-S<6Q?;G5M7V9I96QD<R@D:60I.PH*("`@("`@("`O+R!M861E('1H:7,@
M248@9'5E('1O('!E<F9O<FUA;F-E("AO;F4@:68@:7,@9F%S=&5R('1H86X@
M)&-O=6YT(&EF)W,I"B`@("`@("`@:68@*"$D;6]D92D@>PH@("`@("`@("`@
M("!F;W(@*"1I/3`[("1I/"1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)')E<ULD:5U;)W1A8FQE)UT@/2`D9V]T7W-T<FEN9R`_("1C87-E7V9U
M;F,H)')E<W5L="D@.B`G)SL*("`@("`@("`@("`@("`@("1R97-;)&E=6R=N
M86UE)UT@(#T@)&-A<V5?9G5N8RA`;7-S<6Q?9FEE;&1?;F%M92@D:60L("1I
M*2D["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG='EP92==("`]($!M<W-Q
M;%]F:65L9%]T>7!E*"1I9"P@)&DI.PH@("`@("`@("`@("`@("`@)')E<ULD
M:5U;)VQE;B==("`@/2!`;7-S<6Q?9FEE;&1?;&5N9W1H*"1I9"P@)&DI.PH@
M("`@("`@("`@("`@("`@+R\@5V4@;VYL>2!S=7!P;W)T(&9L86=S(&9O<B!T
M86)L97,*("`@("`@("`@("`@("`@("1R97-;)&E=6R=F;&%G<R==(#T@)&=O
M=%]S=')I;F<@/R`D=&AI<RT^7VUS<W%L7V9I96QD7V9L86=S*"1R97-U;'0L
M("1R97-;)&E=6R=N86UE)UTI(#H@)R<["B`@("`@("`@("`@('T*"B`@("`@
M("`@?2!E;'-E('L@+R\@9G5L;`H@("`@("`@("`@("`D<F5S6R=N=6U?9FEE
M;&1S)UT]("1C;W5N=#L*"B`@("`@("`@("`@(&9O<B`H)&D],#L@)&D\)&-O
M=6YT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG=&%B;&4G
M72`]("1G;W1?<W1R:6YG(#\@)&-A<V5?9G5N8R@D<F5S=6QT*2`Z("<G.PH@
M("`@("`@("`@("`@("`@)')E<ULD:5U;)VYA;64G72`@/2`D8V%S95]F=6YC
M*$!M<W-Q;%]F:65L9%]N86UE*"1I9"P@)&DI*3L*("`@("`@("`@("`@("`@
M("1R97-;)&E=6R=T>7!E)UT@(#T@0&US<W%L7V9I96QD7W1Y<&4H)&ED+"`D
M:2D["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG;&5N)UT@("`]($!M<W-Q
M;%]F:65L9%]L96YG=&@H)&ED+"`D:2D["B`@("`@("`@("`@("`@("`O+R!7
M92!O;FQY('-U<'!O<G0@9FQA9W,@9F]R('1A8FQE<PH@("`@("`@("`@("`@
M("`@)')E<ULD:5U;)V9L86=S)UT@/2`D9V]T7W-T<FEN9R`_("1T:&ES+3Y?
M;7-S<6Q?9FEE;&1?9FQA9W,H)')E<W5L="P@)')E<ULD:5U;)VYA;64G72D@
M.B`G)SL*"B`@("`@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.
M1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==
M6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)4
M04),12D@>PH@("`@("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G
M75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL
M960@;VX@82!T86)L90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@
M("`@("`@("!`;7-S<6Q?9G)E95]R97-U;'0H)&ED*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE('%U97)Y(&YE961E9"!T;R!G970@<V]M92!B86-K96YD(&EN9F\*("`@
M("`J($!P87)A;2!S=')I;F<@)'1Y<&4@5VAA="!K:6YD(&]F(&EN9F\@>6]U
M('=A;G0@=&\@<F5T<FEE=F4*("`@("`J($!R971U<FX@<W1R:6YG(%1H92!3
M44P@<75E<GD@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I
M86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E*2![
M"B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@(G-E;&5C="!N86UE(&9R;VT@<WES;V)J96-T<R!W:&5R92!T>7!E
M(#T@)U4G(&]R9&5R(&)Y(&YA;64B.PH@("`@("`@("`@("!C87-E("=V:65W
M<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@(G-E;&5C="!N86UE(&9R;VT@
M<WES;V)J96-T<R!W:&5R92!T>7!E(#T@)U8G(CL*("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?;7-S<6Q?9FEE;&1?9FQA
M9W,H*0H*("`@("\J*@H@("`@("H@1V5T('1H92!F;&%G<R!F;W(@82!F:65L
M9"P@8W5R<F5N=&QY('-U<'!O<G1S(")N;W1?;G5L;"(L(")P<FEM87)Y7VME
M>2(L"B`@("`@*B`B875T;U]I;F-R96UE;G0B("AM<W-Q;"!I9&5N=&ET>2DL
M(")T:6UE<W1A;7`B("AM<W-Q;"!T:6UE<W1A;7`I+`H@("`@("H@(G5N:7%U
M95]K97DB("AM<W-Q;"!U;FEQ=64@:6YD97@L('5N:7%U92!C:&5C:R!O<B!P
M<FEM87)Y7VME>2D@86YD"B`@("`@*B`B;75L=&EP;&5?:V5Y(B`H;75L=&EK
M97D@:6YD97@I"B`@("`@*@H@("`@("H@;7-S<6P@=&EM97-T86UP(&ES($Y/
M5"!S:6UI;&%R('1O('1H92!M>7-Q;"!T:6UE<W1A;7`@<V\@=&AI<R!I<R!M
M87EB90H@("`@("H@;F]T('5S969U;"!A="!A;&P@+2!I<R!T:&4@8F5H879I
M;W5R(&]F(&UY<W%L7V9I96QD7V9L86=S('1H870@<')I;6%R>0H@("`@("H@
M:V5Y<R!A<F4@86QW87D@=6YI<75E/R!I<R!T:&4@:6YT97)P<F5T871I;VX@
M;V8@;75L=&EP;&5?:V5Y(&-O<G)E8W0_"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R!4:&4@=&%B;&4@;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R!4
M:&4@9FEE;&0*("`@("`J($!A=71H;W(@2F]E<FX@0F%R=&AE;"`\:E]B87)T
M:&5L0'=E8BYD93X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;7-S<6Q?9FEE;&1?9FQA9W,H)'1A8FQE+"`D8V]L=6UN
M*0H@("`@>PH@("`@("`@('-T871I8R`D=&%B;&5.86UE(#T@;G5L;#L*("`@
M("`@("!S=&%T:6,@)&9L86=S(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T
M86)L92`A/2`D=&%B;&5.86UE*2!["@H@("`@("`@("`@("`D9FQA9W,@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`D=&%B;&5.86UE(#T@)'1A8FQE.PH*("`@
M("`@("`@("`@+R\@9V5T('5N:7%U92!A;F0@<')I;6%R>2!K97ES"B`@("`@
M("`@("`@("1R97,@/2`D=&AI<RT^9V5T06QL*")%6$5#(%-07TA%3%!)3D1%
M6%LD=&%B;&5=(BP@1$)?1D540TA-3T1%7T%34T]#*3L*"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1R97,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)&ME
M>7,@/2!E>'!L;V1E*"<L("<L("1V86Q;)VEN9&5X7VME>7,G72D["@H@("`@
M("`@("`@("`@("`@:68@*'-I>F5O9B@D:V5Y<RD@/B`Q*2!["B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G<ULD:V5Y
M72P@)VUU;'1I<&QE7VME>2<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1V
M86Q;)VEN9&5X7V1E<V-R:7!T:6]N)UTL("=P<FEM87)Y(&ME>2<I*2!["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G
M<ULD:V5Y72P@)W!R:6UA<GE?:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=F%L6R=I;F1E
M>%]D97-C<FEP=&EO;B==+"`G=6YI<75E)RDI('L*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S6R1K97E=+"`G=6YI
M<75E7VME>2<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@9V5T(&%U=&]?
M:6YC<F5M96YT+"!N;W1?;G5L;"!A;F0@=&EM97-T86UP"B`@("`@("`@("`@
M("1R97,@/2`D=&AI<RT^9V5T06QL*")%6$5#(%-07T-/3%5-3E-;)'1A8FQE
M72(L($1"7T9%5$-(34]$15]!4U-/0RD["@H@("`@("`@("`@("!F;W)E86-H
M("@D<F5S(&%S("1V86PI('L*("`@("`@("`@("`@("`@("1V86P@/2!A<G)A
M>5]C:&%N9V5?:V5Y7V-A<V4H)'9A;"P@0T%315],3U=%4BD["B`@("`@("`@
M("`@("`@("!I9B`H)'9A;%LG;G5L;&%B;&4G72`]/2`G,"<I('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G<ULD=F%L6R=C
M;VQU;6Y?;F%M92==72P@)VYO=%]N=6QL)RD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1V86Q;)W1Y<&5?;F%M92==
M+"`G:61E;G1I='DG*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M861D7V9L86<H)&9L86=S6R1V86Q;)V-O;'5M;E]N86UE)UU=+"`G875T;U]I
M;F-R96UE;G0G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AS=')P;W,H)'9A;%LG='EP95]N86UE)UTL("=T:6UE<W1A;7`G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S
M6R1V86Q;)V-O;'5M;E]N86UE)UU=+"`G=&EM97-T86UP)RD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("AA<G)A>5]K97E?97AI<W1S*"1C;VQU;6XL("1F;&%G<RDI('L*("`@("`@
M("`@("`@<F5T=7)N*&EM<&QO9&4H)R`G+"`D9FQA9W-;)&-O;'5M;ETI*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(%]A9&1?9FQA9R@I"@H@("`@+RHJ"B`@("`@*B!!9&1S
M(&$@<W1R:6YG('1O('1H92!F;&%G<R!A<G)A>2!I9B!T:&4@9FQA9R!I<R!N
M;W0@>65T(&EN('1H97)E"B`@("`@*B`M(&EF('1H97)E(&ES(&YO(&9L86<@
M<')E<V5N="!T:&4@87)R87D@:7,@8W)E871E9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5F97)E;F-E("!2969E<F5N8V4@=&\@=&AE(&9L86<M87)R87D*
M("`@("`J($!P87)A;2!V86QU92`@("`@(%1H92!F;&%G('9A;'5E"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!A=71H;W(@2F]E<FX@0F%R=&AE
M;"`\:E]B87)T:&5L0'=E8BYD93X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D
M9%]F;&%G("@F)&%R<F%Y+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D87)R87DI*2!["B`@("`@("`@("`@("1A<G)A>2`](&%R<F%Y
M*"1V86QU92D["B`@("`@("`@?2!E;'-E:68@*"%I;E]A<G)A>2@D=F%L=64L
M("1A<G)A>2DI('L*("`@("`@("`@("`@87)R87E?<'5S:"@D87)R87DL("1V
M86QU92D["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('%U;W1E261E;G1I9FEE<B@I"@H@("`@+RHJ"B`@("`@*B!1=6]T92!A('-T
M<FEN9R!S;R!I="!C86X@8F4@<V%F96QY('5S960@87,@82!T86)L92`O(&-O
M;'5M;B!N86UE"B`@("`@*@H@("`@("H@475O=&EN9R!S='EL92!D97!E;F1S
M(&]N('=H:6-H(&1A=&%B87-E(&1R:79E<B!I<R!B96EN9R!U<V5D+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@:61E;G1I9FEE<B!N86UE
M('1O(&)E('%U;W1E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!Q
M=6]T960@:61E;G1I9FEE<B!S=')I;F<*("`@("`J"B`@("`@*B!`<VEN8V4@
M,2XV+C`*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N('%U;W1E261E;G1I9FEE<B@D<W1R*0H@("`@>PH@("`@("`@(')E='5R
M;B`G6R<@+B!S=')?<F5P;&%C92@G72<L("==72<L("1S='(I("X@)UTG.PH@
M("`@?0H*("`@("\O('U]?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J
M('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J
M+PH*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]S=&]R86=E+G!H<```
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-34S-0`Q
M,#0Q-S,V,S`P-@`P,C`P,34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S:&EF='=I9'1H/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N
M(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<CH@4W1I9R!"86MK96X@/'-T:6=`<&AP+FYE=#X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!-86EN=&%I;F5R.B!$
M86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+PHO+R`D260Z('-T;W)A9V4N<&AP+'8@,2XQ-R`R,#`T+S`R+S`T(#`Q.C0R
M.C`U(&1A;FEE;&,@17AP("0*"G)E<75I<F5?;VYC92`G1$(N<&AP)SL*"B\J
M*@H@*B!0<F]V:61E<R!A;B!O8FIE8W0@:6YT97)F86-E('1O(&$@=&%B;&4@
M<F]W+@H@*@H@*B!)="!L971S('EO=2!A9&0L(&1E;&5T92!A;F0@8VAA;F=E
M(')O=W,@=7-I;F<@;V)J96-T<R!R871H97(@=&AA;B!344P*("H@<W1A=&5M
M96YT<RX*("H*("H@0'!A8VMA9V4@($1""B`J($!V97)S:6]N("`D260Z('-T
M;W)A9V4N<&AP+'8@,2XQ-R`R,#`T+S`R+S`T(#`Q.C0R.C`U(&1A;FEE;&,@
M17AP("0*("H@0&-A=&5G;W)Y($1A=&%B87-E"B`J($!A=71H;W(@("!3=&EG
M($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B\*8VQA<W,@1$)?<W1O<F%G92!E
M>'1E;F1S(%!%05(*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH@
M=&AE(&YA;64@;V8@=&AE('1A8FQE("AO<B!V:65W+"!I9B!T:&4@8F%C:V5N
M9"!D871A8F%S92!S=7!P;W)T<PH@("`@("`@('5P9&%T97,@:6X@=FEE=W,I
M('=E(&AO;&0@9&%T82!F<F]M("HO"B`@("!V87(@)%]T86)L92`](&YU;&P[
M"@H@("`@+RHJ('=H:6-H(&-O;'5M;BAS*2!I;B!T:&4@=&%B;&4@8V]N=&%I
M;G,@<')I;6%R>2!K97ES+"!C86X@8F4@80H@("`@("`@('-T<FEN9R!F;W(@
M<VEN9VQE+6-O;'5M;B!P<FEM87)Y(&ME>7,L(&]R(&%N(&%R<F%Y(&]F('-T
M<FEN9W,*("`@("`@("!F;W(@;75L=&EP;&4M8V]L=6UN('!R:6UA<GD@:V5Y
M<R`J+PH@("`@=F%R("1?:V5Y8V]L=6UN(#T@;G5L;#L*"B`@("`O*BH@1$(@
M8V]N;F5C=&EO;B!H86YD;&4@=7-E9"!F;W(@86QL('1R86YS86-T:6]N<R`J
M+PH@("`@=F%R("1?9&)H(#T@;G5L;#L*"B`@("`O*BH@86X@87-S;V,@=VET
M:"!T:&4@;F%M97,@;V8@9&%T86)A<V4@9FEE;&1S('-T;W)E9"!A<R!P<F]P
M97)T:65S"B`@("`@("`@:6X@=&AI<R!O8FIE8W0@*B\*("`@('9A<B`D7W!R
M;W!E<G1I97,@/2!A<G)A>2@I.PH*("`@("\J*B!A;B!A<W-O8R!W:71H('1H
M92!N86UE<R!O9B!T:&4@<')O<&5R=&EE<R!I;B!T:&ES(&]B:F5C="!T:&%T
M"B`@("`@("`@:&%V92!B965N(&-H86YG960@<VEN8V4@=&AE>2!W97)E(&9E
M=&-H960@9G)O;2!T:&4@9&%T86)A<V4@*B\*("`@('9A<B`D7V-H86YG97,@
M/2!A<G)A>2@I.PH*("`@("\J*B!F;&%G('1H870@9&5C:61E<R!I9B!D871A
M(&EN('1H:7,@;V)J96-T(&-A;B!B92!C:&%N9V5D+@H@("`@("`@(&]B:F5C
M=',@=&AA="!D;VXG="!H879E('1H96ER('1A8FQE)W,@:V5Y(&-O;'5M;B!I
M;B!T:&5I<@H@("`@("`@('!R;W!E<G1Y(&QI<W1S('=I;&P@8F4@9FQA9V=E
M9"!A<R!R96%D+6]N;'DN("HO"B`@("!V87(@)%]R96%D;VYL>2`](&9A;'-E
M.PH*("`@("\J*B!F=6YC=&EO;B!O<B!M971H;V0@=&AA="!I;7!L96UE;G1S
M(&$@=F%L:61A=&]R(&9O<B!F:65L9',@=&AA=`H@("`@("`@(&%R92!S970L
M('1H:7,@=F%L:61A=&]R(&9U;F-T:6]N(')E='5R;G,@=')U92!I9B!T:&4@
M9FEE;&0@:7,*("`@("`@("!V86QI9"P@9F%L<V4@:68@;F]T("HO"B`@("!V
M87(@)%]V86QI9&%T;W(@/2!N=6QL.PH*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@
M("H*("`@("`J($!P87)A;2`D=&%B;&4@<W1R:6YG('1H92!N86UE(&]F('1H
M92!D871A8F%S92!T86)L90H@("`@("H*("`@("`J($!P87)A;2`D:V5Y8V]L
M=6UN(&UI>&5D('-T<FEN9R!W:71H(&YA;64@;V8@:V5Y(&-O;'5M;BP@;W(@
M87)R87D@;V8*("`@("`J('-T<FEN9W,@:68@=&AE('1A8FQE(&AA<R!A('!R
M:6UA<GD@:V5Y(&]F(&UO<F4@=&AA;B!O;F4@8V]L=6UN"B`@("`@*@H@("`@
M("H@0'!A<F%M("1D8F@@;V)J96-T(&1A=&%B87-E(&-O;FYE8W1I;VX@;V)J
M96-T"B`@("`@*@H@("`@("H@0'!A<F%M("1V86QI9&%T;W(@;6EX960@9G5N
M8W1I;VX@;W(@;65T:&]D('5S960@=&\@=F%L:61A=&4*("`@("`J(&5A8V@@
M;F5W('9A;'5E+"!C86QL960@=VET:"!T:')E92!P87)A;65T97)S.B!T:&4@
M;F%M92!O9B!T:&4*("`@("`J(&9I96QD+V-O;'5M;B!T:&%T(&ES(&-H86YG
M:6YG+"!A(')E9F5R96YC92!T;R!T:&4@;F5W('9A;'5E(&%N9`H@("`@("H@
M82!R969E<F5N8V4@=&\@=&AI<R!O8FIE8W0*("`@("`J"B`@("`@*B\*("`@
M(&9U;F-T:6]N($1"7W-T;W)A9V4H)'1A8FQE+"`D:V5Y8V]L=6UN+"`F)&1B
M:"P@)'9A;&ED871O<B`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E!%
M05(H)T1"7T5R<F]R)RD["B`@("`@("`@)'1H:7,M/E]T86)L92`]("1T86)L
M93L*("`@("`@("`D=&AI<RT^7VME>6-O;'5M;B`]("1K97EC;VQU;6X["B`@
M("`@("`@)'1H:7,M/E]D8F@@/2`D9&)H.PH@("`@("`@("1T:&ES+3Y?<F5A
M9&]N;'D@/2!F86QS93L*("`@("`@("`D=&AI<RT^7W9A;&ED871O<B`]("1V
M86QI9&%T;W(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7VUA:V57
M:&5R92@I"@H@("`@+RHJ"B`@("`@*B!5=&EL:71Y(&UE=&AO9"!T;R!B=6EL
M9"!A(")72$5212(@8VQA=7-E('1O(&QO8V%T92!O=7)S96QV97,@:6X*("`@
M("`J('1H92!T86)L92X*("`@("`J"B`@("`@*B!86%@@9G5T=7)E(&EM<')O
M=F5M96YT.B!U<V4@<F]W:61S/PH@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?;6%K95=H97)E*"1K97EV86P@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7VME
M>6-O;'5M;BDI('L*("`@("`@("`@("`@:68@*"1K97EV86P@/3T](&YU;&PI
M('L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D
M=&AI<RT^7VME>6-O;'5M;BD[("1I*RLI('L*("`@("`@("`@("`@("`@("`@
M("`D:V5Y=F%L6UT@/2`D=&AI<RT^>R1T:&ES+3Y?:V5Y8V]L=6UN6R1I77T[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'=H97)E8VQA=7-E(#T@)R<["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\('-I>F5O9B@D=&AI<RT^7VME>6-O;'5M;BD[("1I*RLI('L*("`@("`@
M("`@("`@("`@(&EF("@D:2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D
M=VAE<F5C;&%U<V4@+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1W:&5R96-L875S92`N/2`D=&AI<RT^7VME>6-O;'5M
M;ELD:5T["B`@("`@("`@("`@("`@("!I9B`H:7-?;G5L;"@D:V5Y=F%L6R1I
M72DI('L*("`@("`@("`@("`@("`@("`@("`O+R!T:&5R92=S(&YO="!M=6-H
M('!O:6YT(&EN(&AA=FEN9R!A($Y53$P@:V5Y+`H@("`@("`@("`@("`@("`@
M("`@("\O(&)U="!W92!S=7!P;W)T(&ET(&%N>7=A>0H@("`@("`@("`@("`@
M("`@("`@("1W:&5R96-L875S92`N/2`G($E3($Y53$PG.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=VAE<F5C;&%U
M<V4@+CT@)R`]("<@+B`D=&AI<RT^7V1B:"T^<75O=&4H)&ME>79A;%LD:5TI
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@:68@*"1K97EV86P@/3T](&YU;&PI('L*("`@
M("`@("`@("`@("`@("1K97EV86P@/2!`)'1H:7,M/GLD=&AI<RT^7VME>6-O
M;'5M;GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'=H97)E8VQA=7-E
M(#T@)'1H:7,M/E]K97EC;VQU;6X["B`@("`@("`@("`@(&EF("AI<U]N=6QL
M*"1K97EV86PI*2!["B`@("`@("`@("`@("`@("`O+R!T:&5R92=S(&YO="!M
M=6-H('!O:6YT(&EN(&AA=FEN9R!A($Y53$P@:V5Y+`H@("`@("`@("`@("`@
M("`@+R\@8G5T('=E('-U<'!O<G0@:70@86YY=V%Y"B`@("`@("`@("`@("`@
M("`D=VAE<F5C;&%U<V4@+CT@)R!)4R!.54Q,)SL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1W:&5R96-L875S92`N/2`G(#T@)R`N
M("1T:&ES+3Y?9&)H+3YQ=6]T92@D:V5Y=F%L*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)'=H97)E8VQA=7-E.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[('-E='5P*"D*"B`@("`O*BH*("`@("`J
M($UE=&AO9"!U<V5D('1O(&EN:71I86QI>F4@82!$0E]S=&]R86=E(&]B:F5C
M="!F<F]M('1H90H@("`@("H@8V]N9FEG=7)E9"!T86)L92X*("`@("`J"B`@
M("`@*B!`<&%R86T@)&ME>79A;"!M:7AE9"!T:&4@:V5Y6W-=(&]F('1H92!R
M;W<@=&\@9F5T8V@@*'-T<FEN9R!O<B!A<G)A>2D*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="!$0E]/2R!O;B!S=6-C97-S+"!A($1"(&5R<F]R(&EF(&YO
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!S971U<"@D:V5Y=F%L*0H@("`@>PH@
M("`@("`@("1W:&5R96-L875S92`]("1T:&ES+3Y?;6%K95=H97)E*"1K97EV
M86PI.PH@("`@("`@("1Q=65R>2`]("=314Q%0U0@*B!&4D]-("<@+B`D=&AI
M<RT^7W1A8FQE("X@)R!72$5212`G("X@)'=H97)E8VQA=7-E.PH@("`@("`@
M("1S=&@@/2`D=&AI<RT^7V1B:"T^<75E<GDH)'%U97)Y*3L*("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@("`@("`@<F5T=7)N("1S
M=&@["B`@("`@("`@?0H@("`@("`@("1R;W<@/2`D<W1H+3YF971C:%)O=RA$
M0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F]W*2D@>PH@("`@("`@("`@("!R971U<FX@)')O=SL*("`@("`@("!]"B`@
M("`@("`@:68@*"$D<F]W*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<BAN=6QL+"!$0E]%4E)/4E].3U1?1D]53D0L(&YU;&PL(&YU
M;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<75E
M<GDL(&YU;&PL('1R=64I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D
M<F]W(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<')O<&5R=&EE<ULD:V5Y72`]('1R=64["B`@("`@("`@("`@("1T:&ES+3XD
M:V5Y(#T@)'9A;'5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@:6YS97)T*"D*"B`@("`O
M*BH*("`@("`J($-R96%T92!A(&YE=R`H96UP='DI(')O=R!I;B!T:&4@8V]N
M9FEG=7)E9"!T86)L92!F;W(@=&AI<PH@("`@("H@;V)J96-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I;G-E<G0H)&YE=W!K*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D=&AI<RT^7VME>6-O;'5M;BDI('L*("`@("`@("`@("`@
M)'!R:6UA<GEK97D@/2`D=&AI<RT^7VME>6-O;'5M;CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<')I;6%R>6ME>2`](&%R<F%Y*"1T:&ES+3Y?
M:V5Y8V]L=6UN*3L*("`@("`@("!]"B`@("`@("`@<V5T='EP92@D;F5W<&LL
M(")A<G)A>2(I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D
M<')I;6%R>6ME>2D[("1I*RLI('L*("`@("`@("`@("`@)'!K=F%L<UM=(#T@
M)'1H:7,M/E]D8F@M/G%U;W1E*"1N97=P:ULD:5TI.PH@("`@("`@('T*"B`@
M("`@("`@)'-T:"`]("1T:&ES+3Y?9&)H+3YQ=65R>2@B24Y315)4($E.5$\@
M)'1H:7,M/E]T86)L92`H(B`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L;V1E*"(L(BP@)'!R:6UA<GEK97DI("X@(BD@5D%,5453
M*"(@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D
M92@B+"(L("1P:W9A;',I("X@(BDB*3L*("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)'-T:"DI('L*("`@("`@("`@("`@<F5T=7)N("1S=&@["B`@("`@("`@
M?0H@("`@("`@(&EF("AS:7IE;V8H)&YE=W!K*2`]/2`Q*2!["B`@("`@("`@
M("`@("1N97=P:R`]("1N97=P:ULP73L*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/G-E='5P*"1N97=P:RD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@=&]3=')I;F<H*0H*("`@("\J*@H@("`@("H@3W5T<'5T(&$@<VEM<&QE
M(&1E<V-R:7!T:6]N(&]F('1H:7,@1$)?<W1O<F%G92!O8FIE8W0N"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R!O8FIE8W0@9&5S8W)I<'1I;VX*("`@("`J+PH@
M("`@9G5N8W1I;VX@=&]3=')I;F<H*0H@("`@>PH@("`@("`@("1I;F9O(#T@
M<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*3L*("`@("`@("`D:6YF;R`N
M/2`B("AT86)L93TB.PH@("`@("`@("1I;F9O("X]("1T:&ES+3Y?=&%B;&4[
M"B`@("`@("`@)&EN9F\@+CT@(BP@:V5Y8V]L=6UN/2(["B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1T:&ES+3Y?:V5Y8V]L=6UN*2D@>PH@("`@("`@("`@("`D
M:6YF;R`N/2`B*"(@+B!I;7!L;V1E*"(L(BP@)'1H:7,M/E]K97EC;VQU;6XI
M("X@(BDB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I;F9O("X]
M("1T:&ES+3Y?:V5Y8V]L=6UN.PH@("`@("`@('T*("`@("`@("`D:6YF;R`N
M/2`B+"!D8F@](CL*("`@("`@("!I9B`H:7-?;V)J96-T*"1T:&ES+3Y?9&)H
M*2D@>PH@("`@("`@("`@("`D:6YF;R`N/2`D=&AI<RT^7V1B:"T^=&]3=')I
M;F<H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:6YF;R`N/2`B
M;G5L;"(["B`@("`@("`@?0H@("`@("`@("1I;F9O("X]("(I(CL*("`@("`@
M("!I9B`H<VEZ96]F*"1T:&ES+3Y?<')O<&5R=&EE<RDI('L*("`@("`@("`@
M("`@)&EN9F\@+CT@(B!;;&]A9&5D+"!K97D](CL*("`@("`@("`@("`@)&ME
M>6YA;64@/2`D=&AI<RT^7VME>6-O;'5M;CL*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1K97EN86UE*2D@>PH@("`@("`@("`@("`@("`@)&EN9F\@+CT@
M(B@B.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F
M*"1K97EN86UE*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M:2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F\@+CT@(BPB
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D
M:6YF;R`N/2`D=&AI<RT^)&ME>6YA;65;)&E=.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&EN9F\@+CT@(BDB.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&EN9F\@+CT@)'1H:7,M/B1K97EN
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I;F9O("X](")=(CL*
M("`@("`@("!]"B`@("`@("`@:68@*'-I>F5O9B@D=&AI<RT^7V-H86YG97,I
M*2!["B`@("`@("`@("`@("1I;F9O("X]("(@6VUO9&EF:65D72(["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!D=6UP*"D*"B`@("`O*BH*("`@("`J($1U;7`@=&AE(&-O
M;G1E;G1S(&]F('1H:7,@;V)J96-T('1O(")S=&%N9&%R9"!O=71P=70B+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D=6UP*"D*("`@('L*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W!R;W!E<G1I97,@87,@)'!R;W`@/3X@)&9O;RD@>PH@
M("`@("`@("`@("!P<FEN="`B)'!R;W`@/2`B.PH@("`@("`@("`@("!P<FEN
M="!H=&UL96YT:71I97,H)'1H:7,M/B1P<F]P*3L*("`@("`@("`@("`@<')I
M;G0@(CQB<B`O/EQN(CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@)F-R96%T92@I"@H@("`@+RHJ"B`@("`@*B!3=&%T:6,@;65T
M:&]D('5S960@=&\@8W)E871E(&YE=R!$0B!S=&]R86=E(&]B:F5C=',N"B`@
M("`@*B!`<&%R86T@)&1A=&$@87-S;V,N(&%R<F%Y('=H97)E('1H92!K97ES
M(&%R92!T:&4@;F%M97,*("`@("`J("`@("`@("`@("`@("!O9B!P<F]P97)T
M:65S+V-O;'5M;G,*("`@("`J($!R971U<FX@;V)J96-T(&$@;F5W(&EN<W1A
M;F-E(&]F($1"7W-T;W)A9V4@;W(@82!S=6)C;&%S<R!O9B!I=`H@("`@("HO
M"B`@("!F=6YC=&EO;B`F8W)E871E*"1T86)L92P@)B1D871A*0H@("`@>PH@
M("`@("`@("1C;&%S<VYA;64@/2!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI
M<RDI.PH@("`@("`@("1O8FH@/28@;F5W("1C;&%S<VYA;64H)'1A8FQE*3L*
M("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D;F%M92`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@)&]B:BT^7W!R;W!E<G1I97-;)&YA;65=(#T@=')U93L*
M("`@("`@("`@("`@)&]B:BT^)&YA;64@/2`F)'9A;'5E.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)&]B:CL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!L;V%D1G)O;5%U97)Y*"D*"B`@("`O*BH*("`@("`J($QO861S(&1A
M=&$@:6YT;R!T:&ES(&]B:F5C="!F<F]M('1H92!G:79E;B!Q=65R>2X@($EF
M('1H:7,*("`@("`J(&]B:F5C="!A;')E861Y(&-O;G1A:6YS('1A8FQE(&1A
M=&$L(&-H86YG97,@=VEL;"!B92!S879E9"!A;F0*("`@("`J('1H92!O8FIE
M8W0@<F4M:6YI=&EA;&EZ960@9FER<W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M("1Q=65R>2!344P@<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@)'!A<F%M
M<R!P87)A;65T97(@;&ES="!I;B!C87-E('EO=2!W86YT('1O('5S90H@("`@
M("H@<')E<&%R92]E>&5C=71E(&UO9&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="!$0E]/2R!O;B!S=6-C97-S+"!$0E]705).24Y'7U)%041?3TY,62!I
M9B!T:&4*("`@("`J(')E='5R;F5D(&]B:F5C="!I<R!R96%D+6]N;'D@*&)E
M8V%U<V4@=&AE(&]B:F5C="=S('-P96-I9FEE9`H@("`@("H@:V5Y(&-O;'5M
M;B!W87,@;F]T(&9O=6YD(&%M;VYG('1H92!C;VQU;6YS(')E='5R;F5D(&)Y
M("1Q=65R>2DL"B`@("`@*B!O<B!A;F]T:&5R($1"(&5R<F]R(&-O9&4@:6X@
M8V%S92!O9B!E<G)O<G,N"B`@("`@*B\*+R\@6%A8(&-O;6UE;G1E9"!O=70@
M9F]R(&YO=PHO*@H@("`@9G5N8W1I;VX@;&]A9$9R;VU1=65R>2@D<75E<GDL
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AS:7IE;V8H)'1H
M:7,M/E]P<F]P97)T:65S*2D@>PH@("`@("`@("`@("!I9B`H<VEZ96]F*"1T
M:&ES+3Y?8VAA;F=E<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=&]R
M92@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5S(#T@87)R87DH
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W!R;W!E<G1I
M97,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D<F]W9&%T82`]("1T
M:&ES+3Y?9&)H+3YG9712;W<H)'%U97)Y+"!$0E]&151#2$U/1$5?05-33T,L
M("1P87)A;7,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F]W9&%T82DI
M('L*("`@("`@("`@("`@<F5T=7)N("1R;W=D871A.PH@("`@("`@('T*("`@
M("`@("!R97-E="@D<F]W9&%T82D["B`@("`@("`@)&9O=6YD7VME>6-O;'5M
M;B`](&9A;'-E.PH@("`@("`@('=H:6QE("AL:7-T*"1K97DL("1V86QU92D@
M/2!E86-H*"1R;W=D871A*2D@>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`D
M=&AI<RT^7VME>6-O;'5M;BD@>PH@("`@("`@("`@("`@("`@)&9O=6YD7VME
M>6-O;'5M;B`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/E]P<F]P97)T:65S6R1K97E=(#T@=')U93L*("`@("`@("`@("`@)'1H
M:7,M/B1K97D@/2`F)'9A;'5E.PH@("`@("`@("`@("!U;G-E="@D=F%L=64I
M.R`O+R!H879E('1O('5N<V5T+"!O<B!A;&P@<')O<&5R=&EE<R!W:6QL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(')E9F5R('1O('1H92!S86UE
M('9A;'5E"B`@("`@("`@?0H@("`@("`@(&EF("@A)&9O=6YD7VME>6-O;'5M
M;BD@>PH@("`@("`@("`@("`D=&AI<RT^7W)E861O;FQY(#T@=')U93L*("`@
M("`@("`@("`@<F5T=7)N($1"7U=!4DY)3D=?4D5!1%]/3DQ9.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"B`J+PH*("`@("\O('U]
M?0H@("`@+R\@>WM[('-E="@I"@H@("`@+RHJ"B`@("`@*B!-;V1I9GD@86X@
M871T<FEU=&4@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D<')O
M<&5R='DL("1N97=V86QU92D*("`@('L*("`@("`@("`O+R!O;FQY(&-H86YG
M92!I9B`D<')O<&5R='D@:7,@:VYO=VX@86YD(&]B:F5C="!I<R!N;W0*("`@
M("`@("`O+R!R96%D+6]N;'D*("`@("`@("!I9B`H)'1H:7,M/E]R96%D;VYL
M>2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H;G5L
M;"P@1$)?5T%23DE.1U]214%$7T].3%DL(&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+"!T<G5E
M*3L*("`@("`@("!]"B`@("`@("`@:68@*$!I<W-E="@D=&AI<RT^7W!R;W!E
M<G1I97-;)'!R;W!E<G1Y72DI('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T
M:&ES+3Y?=F%L:61A=&]R*2D@>PH@("`@("`@("`@("`@("`@)'9A;&ED(#T@
M=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1V
M86QI9"`]($!C86QL7W5S97)?9G5N8R@D=&AI<RT^7W9A;&ED871O<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P<F]P97)T>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;F5W=F%L=64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/B1P<F]P97)T>2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"1V86QI9"D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/B1P<F]P97)T>2`]("1N97=V86QU93L*("`@("`@("`@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V-H86YG97-;)'!R;W!E<G1Y72DI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG97-;)'!R;W!E
M<G1Y72`](#`["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;F=E<ULD<')O<&5R='E=*RL["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H;G5L;"P@1$)?15)23U)?
M24Y604Q)1"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!N=6QL+"`B:6YV86QI9"!F:65L9#H@)'!R;W!E<G1Y(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL
M+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*&YU;&PL($1"7T524D]27TY/4U5#2$9)14Q$+"!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"`B=6YK;F]W;B!F:65L9#H@
M)'!R;W!E<G1Y(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"P@=')U92D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@)F=E
M="@I"@H@("`@+RHJ"B`@("`@*B!&971C:"!A;B!A='1R:6)U=&4@=F%L=64N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!A='1R:6)U=&4@;F%M90H@
M("`@("H*("`@("`J($!R971U<FX@871T<FEB=71E(&-O;G1E;G1S+"!O<B!N
M=6QL(&EF('1H92!A='1R:6)U=&4@;F%M92!I<PH@("`@("H@=6YK;F]W;@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F9V5T*"1P<F]P97)T>2D*("`@('L*("`@
M("`@("`O+R!O;FQY(')E='5R;B!I9B`D<')O<&5R='D@:7,@:VYO=VX*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F]P97)T:65S6R1P<F]P97)T>5TI
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^)'!R;W!E<G1Y.PH@("`@
M("`@('T*("`@("`@("`D=&UP(#T@;G5L;#L*("`@("`@("!R971U<FX@)'1M
M<#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?1$)?<W1O<F%G92@I
M"@H@("`@+RHJ"B`@("`@*B!$97-T<G5C=&]R+"!C86QL<R!$0E]S=&]R86=E
M.CIS=&]R92@I(&EF('1H97)E(&%R92!C:&%N9V5S"B`@("`@*B!T:&%T(&%R
M92!T;R!B92!K97!T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?1$)?<W1O<F%G
M92@I"B`@("!["B`@("`@("`@:68@*'-I>F5O9B@D=&AI<RT^7V-H86YG97,I
M*2!["B`@("`@("`@("`@("1T:&ES+3YS=&]R92@I.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^7W!R;W!E<G1I97,@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3Y?8VAA;F=E<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]T86)L
M92`](&YU;&P["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<W1O<F4H
M*0H*("`@("\J*@H@("`@("H@4W1O<F5S(&-H86YG97,@=&\@=&AI<R!O8FIE
M8W0@:6X@=&AE(&1A=&%B87-E+@H@("`@("H*("`@("`J($!R971U<FX@1$)?
M3TL@;W(@82!$0B!E<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@I
M"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C:&%N9V5S(&%S("1N
M86UE(#T^("1F;V\I('L*("`@("`@("`@("`@)'!A<F%M<UM=(#T@)B1T:&ES
M+3XD;F%M93L*("`@("`@("`@("`@)'9A<G-;72`]("1N86UE("X@)R`](#\G
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'9A<G,I('L*("`@("`@("`@("`@
M)'%U97)Y(#T@)U501$%412`G("X@)'1H:7,M/E]T86)L92`N("<@4T54("<@
M+@H@("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D=F%R<RD@+B`G(%=(
M15)%("<@+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]M86ME5VAE<F4H*3L*
M("`@("`@("`@("`@)'-T;70@/2`D=&AI<RT^7V1B:"T^<')E<&%R92@D<75E
M<GDI.PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/E]D8F@M/F5X96-U=&4H
M)'-T;70L("1P87)A;7,I.PH@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E<R`](&%R<F%Y*"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!R96UO=F4H*0H*("`@("\J*@H@("`@("H@4F5M
M;W9E('1H92!R;W<@<F5P<F5S96YT960@8GD@=&AI<R!O8FIE8W0@9G)O;2!T
M:&4@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!$0E]/
M2R!O<B!A($1"(&5R<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<F5A9&]N;'DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*&YU;&PL($1"7U=!4DY)
M3D=?4D5!1%]/3DQ9+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@=')U92D["B`@("`@("`@
M?0H@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/E]T
M86)L92`N)R!72$5212`G+@H@("`@("`@("`@("`D=&AI<RT^7VUA:V57:&5R
M92@I.PH@("`@("`@("1R97,@/2`D=&AI<RT^7V1B:"T^<75E<GDH)'%U97)Y
M*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?<')O<&5R=&EE<R!A<R`D<')O<"`]/B`D9F]O*2!["B`@("`@("`@
M("`@('5N<V5T*"1T:&ES+3XD<')O<"D["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?<')O<&5R=&EE<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]C
M:&%N9V5S(#T@87)R87DH*3L*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B
M+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T1"+V1B87-E+G!H<```````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-C,T`#$P-#$W,S8S,#`V`#`Q
M-S0R-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!4;VUA
M<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\($UA:6YT86EN97(Z($1A;FEE;"!#;VYV:7-S
M;W(@/&1A;FEE;&-`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@9&)A
M<V4N<&AP+'8@,2XQ-R`R,#`T+S`R+S$Y(#$X.C(V.C$P(&1A;FEE;&,@17AP
M("0*"@HO+R!86%@@;&5G96YD.@HO+R`@66]U(&AA=F4@=&\@8V]M<&EL92!Y
M;W5R(%!(4"!W:71H('1H92`M+65N86)L92UD8F%S92!O<'1I;VX*"@IR97%U
M:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J($1A=&%B87-E(&EN
M9&5P96YD96YT('%U97)Y(&EN=&5R9F%C92!D969I;FET:6]N(&9O<B!02%`G
M<R!D8F%S90H@*B!E>'1E;G-I;VXN"B`J"B`J($!P86-K86=E("!$0@H@*B!`
M=F5R<VEO;B`@)$ED.B!D8F%S92YP:'`L=B`Q+C$W(#(P,#0O,#(O,3D@,3@Z
M,C8Z,3`@9&%N:65L8R!%>'`@)`H@*B!`8V%T96=O<GD@1&%T86)A<V4*("H@
M0&%U=&AO<B`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("HO"F-L87-S
M($1"7V1B87-E(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P
M97)T:65S"@H@("`@=F%R("1C;VYN96-T:6]N.PH@("`@=F%R("1P:'!T>7!E
M+"`D9&)S>6YT87@["B`@("!V87(@)'!R97!A<F5?=&]K96YS(#T@87)R87DH
M*3L*("`@('9A<B`D<')E<&%R95]T>7!E<R`](&%R<F%Y*"D["B`@("!V87(@
M)')E<U]R;W<@/2!A<G)A>2@I.PH@("`@=F%R("1R97-U;'0@/2`P.PH*("`@
M("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@
M*B!$0E]M>7-Q;"!C;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!$0E]D8F%S92@I"B`@("![
M"B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@("`@("`@("1T:&ES+3YP
M:'!T>7!E(#T@)V1B87-E)SL*("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`G
M9&)A<V4G.PH@("`@("`@("1T:&ES+3YF96%T=7)E<R`](&%R<F%Y*`H@("`@
M("`@("`@("`G<')E<&%R92<@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("=P8V]N;F5C="<@("`@("`]/B!F86QS92P*("`@("`@("`@("`@)W1R86YS
M86-T:6]N<R<@(#T^(&9A;'-E+`H@("`@("`@("`@("`G;&EM:70G("`@("`@
M("`@/3X@9F%L<V4*("`@("`@("`I.PH@("`@("`@("1T:&ES+3YE<G)O<F-O
M9&5?;6%P(#T@87)R87DH*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!C;VYN96-T*"D*"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VYI;F9O+"`D
M<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A1$(Z.F%S
M<V5R=$5X=&5N<VEO;B@G9&)A<V4G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/5%]&3U5.
M1"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YD<VX@/2`D9'-N:6YF;SL*
M("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("1C;VYN("`](&1B87-E7V]P
M96XH)&1S;FEN9F];)V1A=&%B87-E)UTL(#`I.PH@("`@("`@("1E<G)O<B`]
M(&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH@
M("`@("`@(&EF("@A)&-O;FXI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+"!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L
M;"P@<W1R:7!?=&%G<R@D97)R;W(I*3L*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/F-O;FYE8W1I;VX@/2`D8V]N;CL*("`@("`@("!R971U<FX@1$)?3TL[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@
M("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]
M(&1B87-E7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI
M<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@)G%U97)Y*"D*"B`@("!F=6YC
M=&EO;B`F<75E<GDH)'%U97)Y(#T@;G5L;"D*("`@('L*("`@("`@("`O+R!E
M;75L871E(')E<W5L="!R97-O=7)C97,*("`@("`@("`D=&AI<RT^<F5S7W)O
M=ULD=&AI<RT^<F5S=6QT72`](#`["B`@("`@("`@)'1M<"`])B!N97<@1$)?
M<F5S=6QT*"1T:&ES+"`D=&AI<RT^<F5S=6QT*RLI.PH@("`@("`@(')E='5R
M;B`D=&UP.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H26YT
M;R@I"@H@("`@+RHJ"B`@("`@*B!&971C:"!A(')O=R!A;F0@:6YS97)T('1H
M92!D871A(&EN=&\@86X@97AI<W1I;F<@87)R87DN"B`@("`@*@H@("`@("H@
M1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A
M<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA)
M;G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M(')E<V]U<F-E("1R97-U;'0@("`@<75E<GD@<F5S=6QT(&ED96YT:69I
M97(*("`@("`J($!P87)A;2!A<G)A>2`@("`D87)R("`@("`@("AR969E<F5N
M8V4I(&%R<F%Y('=H97)E(&1A=&$@9G)O;2!T:&4@<F]W"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S:&]U;&0@8F4@<&QA8V5D"B`@("`@
M*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN
M9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@
M("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"7T]+(&]N('-U8V-E<W,L($Y53$P@
M=VAE;B!E;F0@;V8@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@
M("!R96%C:&5D(&]R(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"
M7W)E<W5L=#HZ9F5T8VA);G1O*"D*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L
M("1F971C:&UO9&4L("1R;W=N=6T];G5L;"D*("`@('L*("`@("`@("!I9B`H
M)')O=VYU;2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<F]W;G5M(#T@)'1H
M:7,M/G)E<U]R;W=;)')E<W5L=%TK*SL*("`@("`@("!]"B`@("`@("`@:68@
M*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@("`@
M("`@)&%R<B`]($!D8F%S95]G971?<F5C;W)D7W=I=&A?;F%M97,H)'1H:7,M
M/F-O;FYE8W1I;VXL("1R;W=N=6TI.PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%
M4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y
M7V-H86YG95]K97E?8V%S92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A<G(@/2!`9&)A
M<V5?9V5T7W)E8V]R9"@D=&AI<RT^8V]N;F5C=&EO;BP@)')O=VYU;2D["B`@
M("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@("`@("`@("`@("!R971U
M<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@
M("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y
M)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R
M<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("!F=6YC=&EO;B!N
M=6U#;VQS*"1F;V\I"B`@("!["B`@("`@("`@<F5T=7)N(&1B87-E7VYU;69I
M96QD<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@;G5M4F]W<R@I"@H@("`@9G5N8W1I;VX@;G5M4F]W<R@D9F]O
M*0H@("`@>PH@("`@("`@(')E='5R;B!D8F%S95]N=6UR96-O<F1S*"1T:&ES
M+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q
M=6]T95-M87)T*"D*"B`@("`O*BH*("`@("`J($9O<FUA="!I;G!U="!S;R!I
M="!C86X@8F4@<V%F96QY('5S960@:6X@82!Q=65R>0H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D:6X@(&1A=&$@=&\@8F4@<75O=&5D"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"!3=6)M:71T960@=F%R:6%B;&4G<R!T>7!E
M(#T@<F5T=7)N960@=F%L=64Z"B`@("`@*B`@("`@("`@("`@("`@("L@;G5L
M;"`]('1H92!S=')I;F<@/'-A;7`^3E5,3#PO<V%M<#X*("`@("`J("`@("`@
M("`@("`@("`@*R!B;V]L96%N(#T@/'-A;7`^5#PO<V%M<#X@:68@=')U92!O
M<@H@("`@("H@("`@("`@("`@("`@("`@(#QS86UP/D8\+W-A;7`^(&EF(&9A
M;'-E+B`@57-E('1H92`\:V)D/DQO9VEC86P\+VMB9#X*("`@("`J("`@("`@
M("`@("`@("`@("!D871A('1Y<&4N"B`@("`@*B`@("`@("`@("`@("`@("L@
M:6YT96=E<B!O<B!D;W5B;&4@/2!T:&4@=6YQ=6]T960@;G5M8F5R"B`@("`@
M*B`@("`@("`@("`@("`@("L@;W1H97(@*&EN8VQU9&EN9R!S=')I;F=S(&%N
M9"!N=6UE<FEC('-T<FEN9W,I(#T*("`@("`J("`@("`@("`@("`@("`@("!T
M:&4@9&%T82!W:71H('-I;F=L92!Q=6]T97,@97-C87!E9"!B>2!P<F5C965D
M:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@<VEN9VQE('%U;W1E<R!T:&5N
M('1H92!W:&]L92!S=')I;F<@:7,@96YC87!S=6QA=&5D"B`@("`@*B`@("`@
M("`@("`@("`@("`@8F5T=V5E;B!S:6YG;&4@<75O=&5S"B`@("`@*@H@("`@
M("H@0&EN=&5R;F%L"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E4VUA<G0H
M)&EN*0H@("`@>PH@("`@("`@(&EF("AI<U]I;G0H)&EN*2!\?"!I<U]D;W5B
M;&4H)&EN*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN.PH@("`@("`@('T@
M96QS96EF("AI<U]B;V]L*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M;B`_("=4)R`Z("=&)SL*("`@("`@("!](&5L<V5I9B`H:7-?;G5L;"@D:6XI
M*2!["B`@("`@("`@("`@(')E='5R;B`G3E5,3"<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("(G(B`N("1T:&ES+3YE<V-A<&53:6UP
M;&4H)&EN*2`N("(G(CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@I]
M"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C
M+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]M>7-Q;&DN<&AP````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V-S8V,P`Q
M,#0Q-S,V,S`P-@`P,3<V-S8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S:&EF='=I9'1H/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N
M(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<CH@0VAA:6QL86X@3FEC;VQA<R`\;FEC;W-`<&AP+FYE=#X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!"87-E9"!O;B!M>7-Q
M;"YP:'`@8GD@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@36%I;G1A:6YE<CH@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!M>7-Q
M;&DN<&AP+'8@,2XS(#(P,#0O,#(O,3D@,34Z-#@Z-3(@9&%N:65L8R!%>'`@
M)`H*"B\O($Y/5$4Z("!4:&4@=&%B;&5);F9O*"D@;65T:&]D(&UU<W0@8F4@
M<F5D;VYE(&)E8V%U<V4@=&AE(&9U;F-T:6]N<R!I=`HO+R!R96QI97,@;VX@
M;F\@;&]N9V5R(&5X:7-T(&EN('1H92!N97<@97AT96YS:6]N+@HO+PHO+R!%
M6%!%4DE-14Y404P*"@IR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*
M+RHJ"B`J($1A=&%B87-E(&EN9&5P96YD96YT('%U97)Y(&EN=&5R9F%C92!D
M969I;FET:6]N(&9O<B!02%`G<R!M>7-Q;&D*("H@97AT96YS:6]N+@H@*@H@
M*B!4:&ES(&ES(&9O<B!->5-13"!V97)S:6]N<R`T+C$@86YD(&%B;W9E+B`@
M4F5Q=6ER97,@4$A0(#4N"B`J"B`J($YO=&4@=&AA="!P97)S:7-T96YT(&-O
M;FYE8W1I;VYS(&YO(&QO;F=E<B!E>&ES="X*("H*("H@0'!A8VMA9V4@($1"
M"B`J($!V97)S:6]N("`D260Z(&UY<W%L:2YP:'`L=B`Q+C,@,C`P-"\P,B\Q
M.2`Q-3HT.#HU,B!D86YI96QC($5X<"`D"B`J($!C871E9V]R>2!$871A8F%S
M90H@*B!`875T:&]R("`@0VAA:6QL86X@3FEC;VQA<R`\;FEC;W-`<&AP+FYE
M=#X*("HO"F-L87-S($1"7VUY<W%L:2!E>'1E;F1S($1"7V-O;6UO;@I["B`@
M("`O+R![>WL@<')O<&5R=&EE<PH*("`@('9A<B`D8V]N;F5C=&EO;CL*("`@
M('9A<B`D<&AP='EP92P@)&1B<WEN=&%X.PH@("`@=F%R("1P<F5P87)E7W1O
M:V5N<R`](&%R<F%Y*"D["B`@("!V87(@)'!R97!A<F5?='EP97,@/2!A<G)A
M>2@I.PH@("`@=F%R("1N=6U?<F]W<R`](&%R<F%Y*"D["B`@("!V87(@)'1R
M86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@=F%R("1A=71O8V]M;6ET(#T@
M=')U93L*("`@('9A<B`D9F5T8VAM;V1E(#T@1$)?1D540TA-3T1%7T]21$52
M140[("\J($1E9F%U;'0@9F5T8V@@;6]D92`J+PH@("`@=F%R("1?9&(@/2!F
M86QS93L*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@
M("\J*@H@("`@("H@1$)?;7ES<6P@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?;7ES
M<6QI*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("`@
M("`@)'1H:7,M/G!H<'1Y<&4@/2`G;7ES<6QI)SL*("`@("`@("`D=&AI<RT^
M9&)S>6YT87@@/2`G;7ES<6QI)SL*("`@("`@("`D=&AI<RT^9F5A='5R97,@
M/2!A<G)A>2@*("`@("`@("`@("`@)W!R97!A<F4G(#T^(&9A;'-E+`H@("`@
M("`@("`@("`G<W-L)R`]/B!T<G5E+`H@("`@("`@("`@("`G=')A;G-A8W1I
M;VYS)R`]/B!T<G5E+`H@("`@("`@("`@("`G;&EM:70G(#T^("=A;'1E<B<*
M("`@("`@("`I.PH@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P(#T@87)R
M87DH"B`@("`@("`@("`@(#$P,#0@/3X@1$)?15)23U)?0T%.3D]47T-214%4
M12P*("`@("`@("`@("`@,3`P-2`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%
M+`H@("`@("`@("`@("`Q,#`V(#T^($1"7T524D]27T-!3DY/5%]#4D5!5$4L
M"B`@("`@("`@("`@(#$P,#<@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L
M"B`@("`@("`@("`@(#$P,#@@/3X@1$)?15)23U)?0T%.3D]47T123U`L"B`@
M("`@("`@("`@(#$P,C(@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@
M("`@("`@("`@(#$P-#8@/3X@1$)?15)23U)?3D]$0E-%3$5#5$5$+`H@("`@
M("`@("`@("`Q,#4P(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@
M("`@("`@("`Q,#4Q(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@
M("`@("`Q,#4T(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("`@
M("`Q,#8R(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@("`@
M("`Q,#8T(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`@("`@,3$P,"`]
M/B!$0E]%4E)/4E].3U1?3$]#2T5$+`H@("`@("`@("`@("`Q,3,V(#T^($1"
M7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP*("`@("`@("`@("`@,3$T-B`]
M/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`@("`@,3`T."`]/B!$
M0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`Q,C$V(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`@("`@*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@
M=&\@82!D871A8F%S92!A;F0@;&]G(&EN(&%S('1H92!S<&5C:69I960@=7-E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<VX@=&AE(&1A=&$@
M<V]U<F-E(&YA;64@*'-E92!$0CHZ<&%R<V5$4TX@9F]R('-Y;G1A>"D*("`@
M("`J($!P87)A;2!B;V]L96%N("1P97)S:7-T96YT("AO<'1I;VYA;"D@=VAE
M=&AE<B!T:&4@8V]N;F5C=&EO;B!S:&]U;&0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)E('!E<G-I<W1E;G0*("`@("`J($!R971U<FX@
M;6EX960@1$)?3TL@;VX@<W5C8V5S<RP@82!$0B!E<G)O<B!O;B!F86EL=7)E
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C
M;VYN96-T*"1D<VYI;F9O+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("@A1$(Z.F%S<V5R=$5X=&5N<VEO;B@G;7ES<6QI)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/F1S;B`]("1D<VYI;F9O.PH@("`@("`@(&EF("@D9'-N:6YF;ULG<')O
M=&]C;VPG72`F)B`D9'-N:6YF;ULG<')O=&]C;VPG72`]/2`G=6YI>"<I('L*
M("`@("`@("`@("`@)&1B:&]S="`]("<Z)R`N("1D<VYI;F9O6R=S;V-K970G
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&)H;W-T(#T@)&1S
M;FEN9F];)VAO<W1S<&5C)UT@/R`D9'-N:6YF;ULG:&]S='-P96,G72`Z("=L
M;V-A;&AO<W0G.PH@("`@("`@("`@("!I9B`H)&1S;FEN9F];)W!O<G0G72D@
M>PH@("`@("`@("`@("`@("`@)&1B:&]S="`N/2`G.B<@+B`D9'-N:6YF;ULG
M<&]R="==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W-L
M7VUO9&4@/2`D=&AI<RT^9V5T3W!T:6]N*"=S<VPG*2`]/3T@=')U92`_("=#
M3$E%3E1?4U-,)R`Z($Y53$P["@H@("`@("`@($!I;FE?<V5T*"=T<F%C:U]E
M<G)O<G,G+"!T<G5E*3L*"B`@("`@("`@:68@*"1D8FAO<W0@)B8@)&1S;FEN
M9F];)W5S97)N86UE)UT@)B8@)&1S;FEN9F];)W!A<W-W;W)D)UTI('L*("`@
M("`@("`@("`@+R\@3F5E9"!T;R!V97)I9GD@:68@87)G=6UE;G1S(&%R92!O
M:V%Y"B`@("`@("`@("`@("1C;VYN(#T@0&UY<W%L:5]C;VYN96-T*"1D8FAO
M<W0L("1D<VYI;F9O6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9'-N:6YF;ULG<&%S<W=O<F0G72P@)'-S;%]M
M;V1E*3L*("`@("`@("!](&5L<V5I9B`H)&1B:&]S="`F)B!I<W-E="@D9'-N
M:6YF;ULG=7-E<FYA;64G72DI('L*("`@("`@("`@("`@)&-O;FX@/2!`;7ES
M<6QI7V-O;FYE8W0H)&1B:&]S="P@)&1S;FEN9F];)W5S97)N86UE)UTL($Y5
M3$PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S<VQ?
M;6]D92D["B`@("`@("`@?2!E;'-E:68@*"1D8FAO<W0I('L*("`@("`@("`@
M("`@)&-O;FX@/2!`;7ES<6QI7V-O;FYE8W0H)&1B:&]S="P@3E5,3"P@3E5,
M3"P@)'-S;%]M;V1E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M8V]N;B`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@0&EN:5]R97-T;W)E
M*"=T<F%C:U]E<G)O<G,G*3L*"B`@("`@("`@:68@*"$D8V]N;BD@>PH@("`@
M("`@("`@("!I9B`H*"1E<G(@/2!`;7ES<6QI7V5R<F]R*"DI("$]("<G*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?
M15)23U)?0T].3D5#5%]&04E,140L(&YU;&PL(&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@)&5R<BD["B`@
M("`@("`@("`@('T@96QS96EF("AE;7!T>2@D<&AP7V5R<F]R;7-G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T52
M4D]27T-/3DY%0U1?1D%)3$5$*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/
M4E]#3TY.14-47T9!24Q%1"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"`D<&AP7V5R<F]R;7-G
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1D<VYI
M;F9O6R=D871A8F%S92==*2!["B`@("`@("`@("`@(&EF("@A0&UY<W%L:5]S
M96QE8W1?9&(H)&1S;FEN9F];)V1A=&%B87-E)UTL("1C;VYN*2D@>PH@("`@
M("`@("`@("`@("`@<W=I=&-H*&UY<W%L:5]E<G)N;R@D8V]N;BDI('L*("`@
M("`@("`@("`@("`@("`@("!C87-E(#$P-#DZ"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U-5
M0TA$0BP@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&UY<W%L:5]E<G)O<B@D8V]N
M;BDI.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@,3`T-#H*("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%
M4E)/4E]!0T-%4U-?5DE/3$%424].+"!N=6QL+"!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL
M(&UY<W%L:5]E<G)O<B@D8V]N;BDI.PH@("`@("`@("`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<BA$0E]%4E)/4BP@;G5L;"P@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&UY
M<W%L:5]E<G)O<B@D8V]N;BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("\O(&9I>"!T;R!A;&QO=R!C86QL<R!T;R!D
M:69F97)E;G0@9&%T86)A<V5S(&EN('1H92!S86UE('-C<FEP=`H@("`@("`@
M("`@("`D=&AI<RT^7V1B(#T@)&1S;FEN9F];)V1A=&%B87-E)UT["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y
M)UT@)B!$0E]03U)404))3$E465]%4E)/4E,I('L*("`@("`@("`@("`@)'1H
M:7,M/F5R<F]R8V]D95]M87!;,3`R,ET@/2!$0E]%4E)/4E]#3TY35%)!24Y4
M.PH@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#0X72`]($1"
M7T524D]27T-/3E-44D%)3E1?3D]47TY53$P["B`@("`@("`@("`@("1T:&ES
M+3YE<G)O<F-O9&5?;6%P6S$P-C)=(#T@1$)?15)23U)?0T].4U1204E.5#L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@)&-O;FX[
M"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@3&]G(&]U="!A
M;F0@9&ES8V]N;F5C="!F<F]M('1H92!D871A8F%S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@5%)512!O;B!S=6-C97-S+"!&04Q312!I9B!N
M;W0@8V]N;F5C=&5D"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@
M;7ES<6QI7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI
M<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@
M("\J*@H@("`@("H@4V5N9"!A('%U97)Y('1O($UY4U%,(&%N9"!R971U<FX@
M=&AE(')E<W5L=',@87,@82!->5-13"!R97-O=7)C90H@("`@("H@:61E;G1I
M9FEE<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2!T:&4@
M4U%,('%U97)Y"B`@("`@*B!`<F5T=7)N(&UI>&5D(&$@=F%L:60@37E344P@
M<F5S=6QT(&9O<B!S=6-C97-S9G5L(%-%3$5#5`H@("`@("H@("`@("`@("`@
M("`@("!Q=65R:65S+"!$0E]/2R!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R
M:65S+@H@("`@("H@("`@("`@("`@("`@("!!($1"(&5R<F]R(&ES(')E='5R
M;F5D(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@
M("`@)&ES;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T
M:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T
M:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@(&EF("@D=&AI<RT^
M7V1B*2!["B`@("`@("`@("`@(&EF("@A0&UY<W%L:5]S96QE8W1?9&(H)'1H
M:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"
M4T5,14-4140I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF
M("@A)'1H:7,M/F%U=&]C;VUM:70@)B8@)&ES;6%N:7`I('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T](#`I('L*("`@
M("`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6QI7W%U97)Y*"=3150@0554
M3T-/34U)5#TP)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@
M("`@)')E<W5L="`]($!M>7-Q;&E?<75E<GDH)T)%1TE.)RP@)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R
M;W(H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="LK.PH@("`@("`@('T*
M("`@("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q=65R>2@D<75E<GDL("1T:&ES
M+3YC;VYN96-T:6]N*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1R97-U;'0I*2!["B`@("`@
M("`@("`@("1N=6UR;W=S(#T@)'1H:7,M/FYU;7)O=W,H)')E<W5L="D["B`@
M("`@("`@("`@(&EF("AI<U]O8FIE8W0H)&YU;7)O=W,I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)&YU;7)O=W,["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/FYU;5]R;W=S6RAI;G0I)')E<W5L=%T@/2`D;G5M<F]W
M<SL*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@=&AE(&EN=&5R
M;F%L(&UY<W%L(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L
M92!R97-U;'0N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:&%S(&YO="!B
M965N(&EM<&QE;65N=&5D('EE="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S
M;W5R8V4@)')E<W5L="!A('9A;&ED('-Q;"!R97-U;'0@<F5S;W5R8V4*("`@
M("`J($!R971U<FX@9F%L<V4*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J($9E=&-H(&$@<F]W(&%N
M9"!I;G-E<G0@=&AE(&1A=&$@:6YT;R!A;B!E>&ES=&EN9R!A<G)A>2X*("`@
M("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T
M82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S
M=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!Q=65R>2!R97-U
M;'0@:61E;G1I9FEE<@H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@
M("`@*')E9F5R96YC92D@87)R87D@=VAE<F4@9&%T82!F<F]M('1H92!R;W<*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('-H;W5L9"!B92!P
M;&%C960*("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T
M:&4@<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`
M<&%R86T@:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F
M971C:`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@1$)?3TL@;VX@<W5C
M8V5S<RP@3E5,3"!W:&5N(&5N9"!O9B!R97-U;'0@<V5T(&ES"B`@("`@*B`@
M("`@("`@("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@
M("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S
M=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;3UN=6QL*0H@("`@>PH@
M("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF
M("@A0&UY<W%L:5]D871A7W-E96LH)')E<W5L="P@)')O=VYU;2DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%7T%3
M4T]#*2!["B`@("`@("`@("`@("1A<G(@/2!`;7ES<6QI7V9E=&-H7V%R<F%Y
M*"1R97-U;'0L($U94U%,25]!4U-/0RD["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/
M5T520T%312`F)B`D87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R
M87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]($!M
M>7-Q;&E?9F5T8VA?<F]W*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("!I
M9B`H(21A<G(I('L*("`@("`@("`@("`@)&5R<FYO(#T@0&UY<W%L:5]E<G)N
M;R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@(&EF("@A)&5R<FYO
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@3E5,3#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<B@D
M97)R;F\I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@
M("`@("`@("`O*@H@("`@("`@("`@("`@*B!%=F5N('1H;W5G:"!T:&ES($1"
M35,@86QR96%D>2!T<FEM<R!O=71P=70L('=E(&1O('1H:7,@8F5C875S90H@
M("`@("`@("`@("`@*B!A(&9I96QD(&UI9VAT(&AA=F4@:6YT96YT:6]N86P@
M=VAI=&5S<&%C92!A="!T:&4@96YD('1H870*("`@("`@("`@("`@("H@9V5T
M<R!R96UO=F5D(&)Y($1"7U!/4E1!0DE,25197U)44DE-('5N9&5R(&%N;W1H
M97(@9')I=F5R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!F<F5E4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($9R964@=&AE(&EN
M=&5R;F%L(')E<V]U<F-E<R!A<W-O8VEA=&5D('=I=&@@)')E<W5L="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="!->5-13"!R97-U
M;'0@:61E;G1I9FEE<@H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C
M8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R
M97-U;'0I"B`@("!["B`@("`@("`@=6YS970H)'1H:7,M/FYU;5]R;W=S6RAI
M;G0I)')E<W5L=%TI.PH@("`@("`@(')E='5R;B!`;7ES<6QI7V9R965?<F5S
M=6QT*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU
M;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T('1H92!N=6UB97(@;V8@8V]L
M=6UN<R!I;B!A(')E<W5L="!S970N"B`@("`@*@H@("`@("H@0'!A<F%M("1R
M97-U;'0@37E344P@<F5S=6QT(&ED96YT:69I97(*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U<FX@:6YT('1H92!N
M=6UB97(@;V8@8V]L=6UN<R!P97(@<F]W(&EN("1R97-U;'0*("`@("`J+PH@
M("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C
M;VQS(#T@0&UY<W%L:5]N=6U?9FEE;&1S*"1R97-U;'0I.PH*("`@("`@("!I
M9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q2
M86ES945R<F]R*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;',[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S=6QT
M('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="!-
M>5-13"!R97-U;'0@:61E;G1I9FEE<@H@("`@("H@0')E='5R;B!I;G0@=&AE
M(&YU;6)E<B!O9B!R;W=S(&EN("1R97-U;'0*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@
M('L*("`@("`@("`D<F]W<R`]($!M>7-Q;&E?;G5M7W)O=W,H)')E<W5L="D[
M"B`@("`@("`@:68@*"1R;W=S(#T]/2!N=6QL*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F]W<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L92]D:7-A8FQE
M(&%U=&]M871I8R!C;VUM:71S+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71O
M0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@("`@>PH@("`@("`@("\O(%A86"!I
M9B`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`L('=E('-H;W5L9"!P
M<F]B86)L>0H@("`@("`@("\O(&ES<W5E(&$@=V%R;FEN9R!H97)E+@H@("`@
M("`@("1T:&ES+3YA=71O8V]M;6ET(#T@)&]N;V9F(#\@=')U92`Z(&9A;'-E
M.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!C;VUM:70H*0H*("`@("\J*@H@("`@("H@0V]M;6ET('1H92!C
M=7)R96YT('1R86YS86-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM
M:70H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C
M;W5N="`^(#`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&(I('L*("`@
M("`@("`@("`@("`@(&EF("@A0&UY<W%L:5]S96QE8W1?9&(H)'1H:7,M/E]D
M8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%
M3$5#5$5$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q=65R>2@G0T]-34E4)RP@)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L
M:5]Q=65R>2@G4T54($%55$]#3TU-250],2<L("1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P
M.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*("`@("`J
M(%)O;&P@8F%C:R`H=6YD;RD@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VXN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V1B*2!["B`@("`@("`@("`@("`@("!I9B`H(4!M
M>7-Q;&E?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q2
M86ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L="`]($!M
M>7-Q;&E?<75E<GDH)U)/3$Q"04-+)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@
M("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q=65R>2@G4T54($%55$]#
M3TU-250],2<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES
M<6Q286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB
M97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!T:&4@9&%T82!M86YI<'5L871I;VX*
M("`@("`J('%U97)Y+B`@1F]R(&]T:&5R('%U97)I97,L('1H:7,@9G5N8W1I
M;VX@<F5T=7)N<R`P+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B!N
M=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@
M(&EF("A$0CHZ:7--86YI<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*("`@("`@
M("`@("`@<F5T=7)N($!M>7-Q;&E?869F96-T961?<F]W<R@D=&AI<RT^8V]N
M;F5C=&EO;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(#`["B`@("`@("`@?0H@("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E
M<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&YA=&EV92!E
M<G)O<B!C;V1E(&]F('1H92!L87-T(&5R<F]R("AI9B!A;GDI('1H870*("`@
M("`J(&]C8W5R960@;VX@=&AE(&-U<G)E;G0@8V]N;F5C=&EO;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="!N871I=F4@37E344P@97)R;W(@8V]D90H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@97)R
M;W).871I=F4H*0H@("`@>PH@("`@("`@(')E='5R;B!M>7-Q;&E?97)R;F\H
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N97AT
M(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J
M($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q
M96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H
M92!S97%U96YC92X@($1"7T5R<F]R(&EF('!R;V)L96TN"B`@("`@*@H@("`@
M("H@0&EN=&5R;F%L"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"D*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE
M>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@
M("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M
M92D["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@
M("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@B
M55!$051%("1[<V5Q;F%M97T@(BX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G4T54(&ED/4Q!4U1?24Y315)47TE$*&ED*S$I)RD["B`@
M("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@
M("`@(&EF("@D<F5S=6QT(#T]($1"7T]+*2!["B`@("`@("`@("`@("`@("`O
M*BH@0T]-34].($-!4T4@*BHO"B`@("`@("`@("`@("`@("`D:60@/2!`;7ES
M<6QI7VEN<V5R=%]I9"@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@
M("`@("!I9B`H)&ED("$](#`I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&ED.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+RHJ
M($5-4%19(%-%42!404),12`J*B\*("`@("`@("`@("`@("`@("\O(%-E<75E
M;F-E('1A8FQE(&UU<W0@8F4@96UP='D@9F]R('-O;64@<F5A<V]N+"!S;R!F
M:6QL(&ET(&%N9"!R971U<FX@,0H@("`@("`@("`@("`@("`@+R\@3V)T86EN
M(&$@=7-E<BUL979E;"!L;V-K"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/F=E=$]N92@B4T5,14-4($=%5%],3T-+*"<D>W-E<6YA;65]7VQO
M8VLG+#$P*2(I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R
M97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*"1R97-U;'0@/3T@,"D@>PH@("`@("`@("`@("`@("`@
M("`@("\O($9A:6QE9"!T;R!G970@=&AE(&QO8VLL(&)A:6P@=VET:"!A($1"
M7T524D]27TY/5%],3T-+140@97)R;W(*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?3$]#
M2T5$*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!A
M9&0@=&AE(&1E9F%U;'0@=F%L=64*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^<75E<GDH(E)%4$Q!0T4@24Y43R`D>W-E<6YA;65](%9!3%5%
M4R`H,"DB*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`O+R!296QE87-E('1H92!L;V-K"B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,14-4(%)%3$5!4T5?3$]#2R@G
M)'MS97%N86UE?5]L;V-K)RDB*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("\O(%=E(&MN;W<@=VAA="!T:&4@<F5S=6QT
M('=I;&P@8F4L('-O(&YO(&YE960@=&\@=')Y(&%G86EN"B`@("`@("`@("`@
M("`@("!R971U<FX@,3L*"B`@("`@("`@("`@("\J*B!/3D1%34%.1"!404),
M12!#4D5!5$E/3B`J*B\*("`@("`@("`@("`@?2!E;'-E:68@*"1O;F1E;6%N
M9"`F)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@
M)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*0H@
M("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("`O
M+R!3:6YC92!C<F5A=&5397%U96YC92!I;FET:6%L:7IE<R!T:&4@240@=&\@
M8F4@,2P*("`@("`@("`@("`@("`@("\O('=E(&1O(&YO="!N965D('1O(')E
M=')I979E('1H92!)1"!A9V%I;B`H;W(@=V4@=VEL;"!G970@,BD*("`@("`@
M("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@+R\@1FER<W0@240@;V8@82!N97=L>2!C<F5A=&5D('-E<75E;F-E(&ES
M(#$*("`@("`@("`@("`@("`@("`@("!R971U<FX@,3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J*B!"04-+5T%21%,@0T]-4$%4("HJ+PH@
M("`@("`@("`@("!](&5L<V5I9B`H1$(Z.FES17)R;W(H)')E<W5L="D@)B8*
M("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$
M0E]%4E)/4E]!3%)%04197T5825-44RD*("`@("`@("`@("`@>PH@("`@("`@
M("`@("`@("`@+R\@<V5E(%]"0W-E<75E;F-E*"D@8V]M;65N=`H@("`@("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?0D-S97%U96YC92@D<V5Q;F%M
M92D["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D<F5P96%T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@
M*"1R97!E870I.PH*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)')E<W5L="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA
M;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE
M8W0@:7,@<F5T=7)N960@:68*("`@("`J("`@("`@("`@("`@("!P<F]B;&5M
M<R!A<FES92X*("`@("`J"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S964@
M1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q
M7VYA;64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q
M=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@)')E<R`]("1T:&ES+3YQ
M=65R>2@B0U)%051%(%1!0DQ%("1[<V5Q;F%M97T@(BX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<H:60@24Y414=%4B!53E-)1TY%1"!!551/7TE.
M0U)%345.5"!.3U0@3E5,3"PG+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R!04DE-05)9($M%62AI9"DI)RD["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M('T*("`@("`@("`O+R!I;G-E<G0@>6EE;&1S('9A;'5E(#$L(&YE>'1)9"!C
M86QL('=I;&P@9V5N97)A=&4@240@,@H@("`@("`@(')E='5R;B`D=&AI<RT^
M<75E<GDH(DE.4T525"!)3E1/("1[<V5Q;F%M97T@5D%,5453*#`I(BD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@
M("`O*BH*("`@("`J($1E;&5T97,@82!S97%U96YC90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC
M92!T;R!B92!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"
M7T]+(&]N('-U8V-E<W,N("!$0E]%<G)O<B!I9B!P<F]B;&5M<RX*("`@("`J
M"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P
M4V5Q=65N8V4H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9')O<%-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G%U97)Y*"=$4D]0(%1!0DQ%("<@+B`D=&AI<RT^
M9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(%]"0W-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($)A
M8VMW87)D<R!C;VUP871I8FEL:71Y('=I=&@@;VQD('-E<75E;F-E(&5M=6QA
M=&EO;B!I;7!L96UE;G1A=&EO;@H@("`@("H@*&-L96%N('5P('1H92!D=7!E
M<RDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q;F%M92!4:&4@
M<V5Q=65N8V4@;F%M92!T;R!C;&5A;B!U<`H@("`@("H@0')E='5R;B!M:7AE
M9"!$0E]%<G)O<B!O<B!T<G5E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]"0W-E
M<75E;F-E*"1S97%N86UE*0H@("`@>PH@("`@("`@("\O($]B=&%I;B!A('5S
M97(M;&5V96P@;&]C:RXN+B!T:&ES('=I;&P@<F5L96%S92!A;GD@<')E=FEO
M=7,*("`@("`@("`O+R!A<'!L:6-A=&EO;B!L;V-K<RP@8G5T('5N;&EK92!,
M3T-+(%1!0DQ%4RP@:70@9&]E<R!N;W0@86)O<G0*("`@("`@("`O+R!T:&4@
M8W5R<F5N="!T<F%N<V%C=&EO;B!A;F0@:7,@;75C:"!L97-S(&9R97%U96YT
M;'D@=7-E9"X*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,
M14-4($=%5%],3T-+*"<D>W-E<6YA;65]7VQO8VLG+#$P*2(I.PH@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@:68@*"1R97-U;'0@/3T@
M,"D@>PH@("`@("`@("`@("`O+R!&86EL960@=&\@9V5T('1H92!L;V-K+"!C
M86XG="!D;R!T:&4@8V]N=F5R<VEO;BP@8F%I;`H@("`@("`@("`@("`O+R!W
M:71H(&$@1$)?15)23U)?3D]47TQ/0TM%1"!E<G)O<@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?3$]#
M2T5$*3L*("`@("`@("!]"@H@("`@("`@("1H:6=H97-T7VED(#T@)'1H:7,M
M/F=E=$]N92@B4T5,14-4($U!6"AI9"D@1E)/32`D>W-E<6YA;65](BD["B`@
M("`@("`@:68@*$1".CII<T5R<F]R*"1H:6=H97-T7VED*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&AI9VAE<W1?:60["B`@("`@("`@?0H@("`@("`@("\O
M(%1H:7,@<VAO=6QD(&MI;&P@86QL(')O=W,@97AC97!T('1H92!H:6=H97-T
M"B`@("`@("`@+R\@5V4@<VAO=6QD('!R;V)A8FQY(&1O('-O;65T:&EN9R!I
M9B`D:&EG:&5S=%]I9"!I<VXG=`H@("`@("`@("\O(&YU;65R:6,L(&)U="!)
M)VT@870@82!L;W-S(&%S(&AO=R!T;R!H86YD;&4@=&AA="XN+@H@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^<75E<GDH(D1%3$5412!&4D]-("1[<V5Q;F%M
M97T@5TA%4D4@:60@/#X@)&AI9VAE<W1?:60B*3L*("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!A;F]T:&5R('1H<F5A9"!H
M87,@8F5E;B!W86ET:6YG(&9O<B!T:&ES(&QO8VLL"B`@("`@("`@+R\@:70@
M=VEL;"!G;R!T:')U('1H92!A8F]V92!P<F]C961U<F4L(&)U="!W:6QL(&AA
M=F4@;F\*("`@("`@("`O+R!R96%L(&5F9F5C=`H@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^9V5T3VYE*")314Q%0U0@4D5,14%315],3T-+*"<D>W-E<6YA
M;65]7VQO8VLG*2(I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@<75O=&5)9&5N=&EF:65R*"D*"B`@("`O*BH*("`@("`J(%%U;W1E(&$@
M<W1R:6YG('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!A<R!A('1A8FQE(&]R
M(&-O;'5M;B!N86UE"B`@("`@*@H@("`@("H@475O=&EN9R!S='EL92!D97!E
M;F1S(&]N('=H:6-H(&1A=&%B87-E(&1R:79E<B!I<R!B96EN9R!U<V5D+@H@
M("`@("H*("`@("`J($UY4U%,(&-A;B=T(&AA;F1L92!T:&4@8F%C:W1I8VL@
M8VAA<F%C=&5R("@\:V)D/F`\+VMB9#XI(&EN"B`@("`@*B!T86)L92!O<B!C
M;VQU;6X@;F%M97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R
M("!I9&5N=&EF:65R(&YA;64@=&\@8F4@<75O=&5D"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('%U;W1E9"!I9&5N=&EF:65R('-T<FEN9PH@("`@
M("H*("`@("`J($!S:6YC92`Q+C8N,`H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!I;G1E<FYA;`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T94ED
M96YT:69I97(H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@)V`G("X@)'-T
M<B`N("=@)SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<V-A<&53
M:6UP;&4H*0H*("`@("\J*@H@("`@("H@17-C87!E(&$@<W1R:6YG(&%C8V]R
M9&EN9R!T;R!T:&4@8W5R<F5N="!$0DU3)W,@<W1A;F1A<F1S"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<W1R("!T:&4@<W1R:6YG('1O(&)E(&5S
M8V%P960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5S8V%P
M960@<W1R:6YG"B`@("`@*@H@("`@("H@0&EN=&5R;F%L"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5S8V%P95-I;7!L92@D<W1R*2!["B`@("`@("`@<F5T=7)N
M(&UY<W%L:5]R96%L7V5S8V%P95]S=')I;F<H)'-T<BP@)'1H:7,M/F-O;FYE
M8W1I;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>5%U
M97)Y*"D*"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R>2@D<75E<GDI"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4*2!["B`@("`@("`@("`@("\O
M(")$14Q%5$4@1E)/32!T86)L92(@9VEV97,@,"!A9F9E8W1E9"!R;W=S(&EN
M($UY4U%,+@H@("`@("`@("`@("`O+R!4:&ES(&QI='1L92!H86-K(&QE=',@
M>6]U(&MN;W<@:&]W(&UA;GD@<F]W<R!W97)E(&1E;&5T960N"B`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O7EQS*D1%3$5415QS*T923TU<<RLH7%,K
M*5QS*B0O:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@("`@("1Q=65R>2`]
M('!R96=?<F5P;&%C92@G+UY<<RI$14Q%5$5<<RM&4D]-7',K*%Q3*RE<<RHD
M+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T1%
M3$5412!&4D]-(%PQ(%=(15)%(#$],2<L("1Q=65R>2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,:6UI=%%U97)Y*"D*"B`@("!F
M=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y*"1Q=65R>2P@)&9R;VTL("1C;W5N
M="D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'%U97)Y*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'%U97)Y("X@(B!,24U)5"`D8V]U;G0B.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D<75E<GD@+B`B
M($Q)34E4("1F<F]M+"`D8V]U;G0B.PH@("`@("`@('T*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!M>7-Q;%)A:7-E17)R;W(H*0H*("`@("\J*@H@
M("`@("H@1V%T:&5R(&EN9F]R;6%T:6]N(&%B;W5T(&%N(&5R<F]R+"!T:&5N
M('5S92!T:&%T(&EN9F\@=&\@8W)E871E(&$*("`@("`J($1"(&5R<F]R(&]B
M:F5C="!A;F0@9FEN86QL>2!R971U<FX@=&AA="!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!I;G1E9V5R("`D97)R;F\@(%!%05(@97)R;W(@;G5M
M8F5R("AU<W5A;&QY(&$@1$(@8V]N<W1A;G0I(&EF"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@;6%N=6%L;'D@<F%I<VEN9R!A;B!E<G)O<@H@
M("`@("H@0')E='5R;B!O8FIE8W0@($1"(&5R<F]R(&]B:F5C=`H@("`@("H@
M0'-E92!$0E]C;VUM;VXZ.F5R<F]R0V]D92@I"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ<F%I<V5%<G)O<B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&UY<W%L
M4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D
M97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R<FYO(#T@)'1H:7,M
M/F5R<F]R0V]D92AM>7-Q;&E?97)R;F\H)'1H:7,M/F-O;FYE8W1I;VXI*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E
M<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@0&UY<W%L:5]E<G)N;R@D=&AI<RT^8V]N;F5C=&EO;BD@
M+B`G("HJ("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`
M;7ES<6QI7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N*2D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L
M="!S970N"B`@("`@*@H@("`@("H@5T%23DE.1SH@=&AI<R!M971H;V0@=VEL
M;"!P<F]B86)L>2!N;W0@=V]R:R!B96-A=7-E('1H92!M>7-Q;&E?*B@I"B`@
M("`@*B!F=6YC=&EO;G,@:70@<F5L:65S('5P;VX@;6%Y(&YO="!E>&ES="X*
M("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@
M1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG
M('1H92!N86UE(&]F(&$@=&%B;&4*("`@("`J($!P87)A;2!I;G0@("`@("`@
M("`@("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I
M;F9O<FUA=&EO;B!R97%U97-T960*("`@("`J("`@("`@("`@("`@("`@(&]R
M(&%N(&5R<F]R(&]B:F5C="!I9B!S;VUE=&AI;F<@:7,@=W)O;F<*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S964@
M1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!T
M86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*2!["B`@("`@("`@:68@
M*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@
M("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@;V)J96-T
M+@H@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S;W5R8V4@
M:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]
M("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F
M86QS93L*("`@("`@("!](&5L<V5I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2![
M"B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I
M=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S
M=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D:60@/2!`;7ES<6QI7VQI<W1?9FEE;&1S*"1T:&ES+3YD<VY;
M)V1A=&%B87-E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5S=6QT+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@
M("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E
M<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y
M(&ET+@H@("`@("`@("`@("`@*B!$97!R:6-A=&5D+B`@2&5R92!F;W(@8V]M
M<&%T:6)I;&ET>2!O;FQY+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@
M)&ED(#T@)')E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$
M0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S
M=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S
M95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@
M/2!`;7ES<6QI7VYU;5]F:65L9',H)&ED*3L*"B`@("`@("`@+R\@;6%D92!T
M:&ES($E&(&1U92!T;R!P97)F;W)M86YC92`H;VYE(&EF(&ES(&9A<W1E<B!T
M:&%N("1C;W5N="!I9B=S*0H@("`@("`@(&EF("@A)&UO9&4I('L*("`@("`@
M("`@("`@9F]R("@D:3TP.R`D:3PD8V]U;G0[("1I*RLI('L*("`@("`@("`@
M("`@("`@("1R97-;)&E=6R=T86)L92==(#T@)&-A<V5?9G5N8RA`;7ES<6QI
M7V9I96QD7W1A8FQE*"1I9"P@)&DI*3L*("`@("`@("`@("`@("`@("1R97-;
M)&E=6R=N86UE)UT@(#T@)&-A<V5?9G5N8RA`;7ES<6QI7V9I96QD7VYA;64H
M)&ED+"`D:2DI.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)W1Y<&4G72`@
M/2!`;7ES<6QI7V9I96QD7W1Y<&4H)&ED+"`D:2D["B`@("`@("`@("`@("`@
M("`D<F5S6R1I75LG;&5N)UT@("`]($!M>7-Q;&E?9FEE;&1?;&5N*"1I9"P@
M)&DI.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)V9L86=S)UT@/2!`;7ES
M<6QI7V9I96QD7V9L86=S*"1I9"P@)&DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L@+R\@9G5L;`H@("`@("`@("`@("`D<F5S6R=N=6U?9FEE
M;&1S)UT]("1C;W5N=#L*"B`@("`@("`@("`@(&9O<B`H)&D],#L@)&D\)&-O
M=6YT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG=&%B;&4G
M72`]("1C87-E7V9U;F,H0&UY<W%L:5]F:65L9%]T86)L92@D:60L("1I*2D[
M"B`@("`@("`@("`@("`@("`D<F5S6R1I75LG;F%M92==("`]("1C87-E7V9U
M;F,H0&UY<W%L:5]F:65L9%]N86UE*"1I9"P@)&DI*3L*("`@("`@("`@("`@
M("`@("1R97-;)&E=6R=T>7!E)UT@(#T@0&UY<W%L:5]F:65L9%]T>7!E*"1I
M9"P@)&DI.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)VQE;B==("`@/2!`
M;7ES<6QI7V9I96QD7VQE;B@D:60L("1I*3L*("`@("`@("`@("`@("`@("1R
M97-;)&E=6R=F;&%G<R==(#T@0&UY<W%L:5]F:65L9%]F;&%G<R@D:60L("1I
M*3L*"B`@("`@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?
M3U)$15(I('L*("`@("`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==6R1R
M97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),
M12D@>PH@("`@("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD
M<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+R\@9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@
M;VX@82!T86)L90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@
M("`@("!`;7ES<6QI7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!Q=65R>2!N965D960@=&\@9V5T('-O;64@8F%C:V5N9"!I;F9O+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@5VAA="!K:6YD(&]F(&EN
M9F\@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J($!R971U<FX@<W1R:6YG
M(%1H92!344P@<75E<GD@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T
M>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@
M("`@("!R971U<FX@)U-(3U<@5$%"3$53)SL*("`@("`@("`@("`@8V%S92`G
M=FEE=W,G.@H@("`@("`@("`@("`@("`@<F5T=7)N($1"7T524D]27TY/5%]#
M05!!0DQ%.PH@("`@("`@("`@("!C87-E("=U<V5R<R<Z"B`@("`@("`@("`@
M("`@("`D<W%L(#T@)W-E;&5C="!D:7-T:6YC="!5<V5R(&9R;VT@=7-E<B<[
M"B`@("`@("`@("`@("`@("!I9B@D=&AI<RT^9'-N6R=D871A8F%S92==("$]
M("=M>7-Q;"<I('L*("`@("`@("`@("`@("`@("`@("`D9'-N(#T@)'1H:7,M
M/F1S;CL*("`@("`@("`@("`@("`@("`@("`D9'-N6R=D871A8F%S92==(#T@
M)VUY<W%L)SL*("`@("`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)&1B(#T@1$(Z.F-O;FYE8W0H)&1S;BDI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D9&(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1S<6P@/2`D9&(M/F=E=$-O;"@D<W%L*3L*("`@
M("`@("`@("`@("`@("`@("`D9&(M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@
M("`@("`@("`@("`O+R!86%@@1FEX;64@=&AE(&UY<W%L(&1R:79E<B!S:&]U
M;&0@=&%K92!C87)E(&]F('1H:7,*("`@("`@("`@("`@("`@("`@("!I9B`H
M(4!M>7-Q;&E?<V5L96-T7V1B*"1T:&ES+3YD<VY;)V1A=&%B87-E)UTL("1T
M:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,
M14-4140I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(')E='5R;B`D<W%L.PH@("`@("`@("`@("!C
M87-E("=D871A8F%S97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=32$]7
M($1!5$%"05-%4R<["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`O+R!]?7T*
M"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J
M(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]$0B]S>6)A<V4N<&AP````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`V,38T-0`Q,#0Q-S,V,S`P-@`P,3<V-#``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@
M9F]L9&UE=&AO9#UM87)K97(Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-T97)L:6YG($AU
M9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("!!;G3T;FEO($-A<FQO<R!696[B;F-I;R!*
M^FYI;W(@/&9L;W)I<&%`<&AP+FYE=#X@("`@("`@("`@("!\"B\O('P@36%I
M;G1A:6YE<CH@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/B`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!S>6)A<V4N<&AP+'8@,2XT."`R,#`T+S`R
M+S$X(#(S.C`W.C$P(&1A;FEE;&,@17AP("0*"@HO+R!43T1/"B\O("`@("T@
M5&AI<R!D<FEV97(@;6%Y(&9A:6P@=VET:"!M=6QT:7!L92!C;VYN96-T:6]N
M<R!U;F1E<B!T:&4@<V%M90HO+R`@("`@('5S97(O<&%S<R]H;W-T(&%N9"!D
M:69F97)E;G0@9&%T86)A<V5S"@H*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN
M<&AP)SL*"B\J*@H@*B!$871A8F%S92!I;F1E<&5N9&5N="!Q=65R>2!I;G1E
M<F9A8V4@9&5F:6YI=&EO;B!F;W(@4$A0)W,@4WEB87-E"B`J(&5X=&5N<VEO
M;BX*("H*("H@0'!A8VMA9V4@($1""B`J($!V97)S:6]N("`D260Z('-Y8F%S
M92YP:'`L=B`Q+C0X(#(P,#0O,#(O,3@@,C,Z,#<Z,3`@9&%N:65L8R!%>'`@
M)`H@*B!`8V%T96=O<GD@1&%T86)A<V4*("H@0&%U=&AO<B`@(%-T97)L:6YG
M($AU9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X*("H@0&%U=&AO<B`@($%N=/1N
M:6\@0V%R;&]S(%9E;N)N8VEO($KZ;FEO<B`\9FQO<FEP84!P:'`N;F5T/@H@
M*B\*8VQA<W,@1$)?<WEB87-E(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O
M('M[>R!P<F]P97)T:65S"@H@("`@=F%R("1C;VYN96-T:6]N.PH@("`@=F%R
M("1P:'!T>7!E+"`D9&)S>6YT87@["B`@("!V87(@)'!R97!A<F5?=&]K96YS
M(#T@87)R87DH*3L*("`@('9A<B`D<')E<&%R95]T>7!E<R`](&%R<F%Y*"D[
M"B`@("!V87(@)'1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@=F%R("1A
M=71O8V]M;6ET(#T@=')U93L*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS
M=')U8W1O<@H*("`@("\J*@H@("`@("H@1$)?<WEB87-E(&-O;G-T<G5C=&]R
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N($1"7W-Y8F%S92@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O
M;6UO;B@I.PH@("`@("`@("1T:&ES+3YP:'!T>7!E(#T@)W-Y8F%S92<["B`@
M("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@)W-Y8F%S92<["B`@("`@("`@)'1H
M:7,M/F9E871U<F5S(#T@87)R87DH"B`@("`@("`@("`@("=P<F5P87)E)R`]
M/B!F86QS92P*("`@("`@("`@("`@)W!C;VYN96-T)R`]/B!T<G5E+`H@("`@
M("`@("`@("`G=')A;G-A8W1I;VYS)R`]/B!F86QS92P*("`@("`@("`@("`@
M)VQI;6ET)R`]/B`G96UU;&%T92<*("`@("`@("`I.PH@("`@("`@("1T:&ES
M+3YE<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J
M($-O;FYE8W0@=&\@82!D871A8F%S92!A;F0@;&]G(&EN(&%S('1H92!S<&5C
M:69I960@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@)&1S;B!T:&4@9&%T
M82!S;W5R8V4@;F%M92`H<V5E($1".CIP87)S94133B!F;W(@<WEN=&%X*0H@
M("`@("H@0'!A<F%M("1P97)S:7-T96YT("AO<'1I;VYA;"D@=VAE=&AE<B!T
M:&4@8V]N;F5C=&EO;B!S:&]U;&0*("`@("`J("`@("`@("!B92!P97)S:7-T
M96YT"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@
M1$)?3TL@;VX@<W5C8V5S<RP@82!$0B!E<G)O<B!O;B!F86EL=7)E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;FEN9F\L("1P97)S:7-T96YT
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%$0CHZ87-S97)T17AT96YS
M:6]N*"=S>6)A<V4G*2`F)@H@("`@("`@("`@("`A1$(Z.F%S<V5R=$5X=&5N
M<VEO;B@G<WEB87-E7V-T)RDI"B`@("`@("`@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/5%]&
M3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;FEN
M9F\["@H@("`@("`@("1I;G1E<F9A8V4@/2`D9'-N:6YF;ULG:&]S='-P96,G
M72`_("1D<VYI;F9O6R=H;W-T<W!E8R==(#H@)VQO8V%L:&]S="<["B`@("`@
M("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=S>6)A<V5?
M<&-O;FYE8W0G(#H@)W-Y8F%S95]C;VYN96-T)SL*"B`@("`@("`@:68@*"1I
M;G1E<F9A8V4@)B8@)&1S;FEN9F];)W5S97)N86UE)UT@)B8@)&1S;FEN9F];
M)W!A<W-W;W)D)UTI('L*("`@("`@("`@("`@)&-O;FX@/2!`)&-O;FYE8W1?
M9G5N8W1I;VXH)&EN=&5R9F%C92P@)&1S;FEN9F];)W5S97)N86UE)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D<VYI;F9O
M6R=P87-S=V]R9"==*3L*("`@("`@("!](&5L<V5I9B`H)&EN=&5R9F%C92`F
M)B`D9'-N:6YF;ULG=7-E<FYA;64G72D@>PH@("`@("`@("`@("`O*@H@("`@
M("`@("`@("`@*B!5<VEN9R!F86QS92!F;W(@<'<@87,@82!W;W)K87)O=6YD
M('1O(&%V;VED('-E9V9A=6QT+@H@("`@("`@("`@("`@*B!3964@4$5!4B!B
M=6<@-C,Q"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D8V]N;B`]($`D
M8V]N;F5C=%]F=6YC=&EO;B@D:6YT97)F86-E+"`D9'-N:6YF;ULG=7-E<FYA
M;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C;VYN(#T@
M1D%,4T4["B`@("`@("`@?0H*("`@("`@("!I9B`H(21C;VYN*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.
M14-47T9!24Q%1"D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1S;FEN9F];
M)V1A=&%B87-E)UTI('L*("`@("`@("`@("`@:68@*"%`<WEB87-E7W-E;&5C
M=%]D8B@D9'-N:6YF;ULG9&%T86)A<V4G72P@)&-O;FXI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]$
M0E-%3$5#5$5$+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YU;&PL(&YU;&PL('-Y8F%S95]G971?;&%S=%]M97-S
M86=E*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9&(@
M/2`D9'-N:6YF;ULG9&%T86)A<V4G73L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3YC;VYN96-T:6]N(#T@)&-O;FX["B`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*
M("`@("\J*@H@("`@("H@3&]G(&]U="!A;F0@9&ES8V]N;F5C="!F<F]M('1H
M92!D871A8F%S92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L($9!3%-%
M(&EF(&YO="!C;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O
M;FYE8W0H*0H@("`@>PH@("`@("`@("1R970@/2!`<WEB87-E7V-L;W-E*"1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]
M(&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T
M('1H92!L87-T('-E<G9E<B!E<G)O<B!M97-S9V4@*&EF(&%N>2D*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R!S>6)A<V4@;&%S="!E<G)O<B!M97-S
M86=E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*
M("`@("`@("!R971U<FX@<WEB87-E7V=E=%]L87-T7VUE<W-A9V4H*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<D-O9&4H*0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE(%!%05(Z.D1"(&5R<F]R(&-O9&4@9G)O;2!T
M:&4@9&%T86)A<V4G<R!T97AT(&5R<F]R(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!S=')I;F<@("1E<G)O<FUS9R`@97)R;W(@;65S<V%G92!R
M971U<FYE9"!F<F]M('1H92!D871A8F%S90H@("`@("H@0')E='5R;B!I;G1E
M9V5R("!A;B!E<G)O<B!N=6UB97(@9G)O;2!A($1"(&5R<F]R(&-O;G-T86YT
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D92@D97)R;W)M<V<I"B`@
M("!["B`@("`@("`@<W1A=&EC("1E<G)O<E]R96=E>'!S.PH@("`@("`@(&EF
M("@A:7-S970H)&5R<F]R7W)E9V5X<',I*2!["B`@("`@("`@("`@("1E<G)O
M<E]R96=E>'!S(#T@87)R87DH"B`@("`@("`@("`@("`@("`G+TEN8V]R<F5C
M="!S>6YT87@@;F5A<B\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)2
M3U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R]>56YC;&]S960@<75O=&4@
M8F5F;W)E('1H92!C:&%R86-T97(@<W1R:6YG(%M<(EPG72XJ6UPB7"==7"XO
M)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27U-93E1!6"P*("`@
M("`@("`@("`@("`@("<O26UP;&EC:70@8V]N=F5R<VEO;B!F<F]M(&1A=&%T
M>7!E(%M<(EPG72XK6UPB7"==('1O(%M<(EPG72XK6UPB7"==(&ES(&YO="!A
M;&QO=V5D7"XO)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.
M5D%,241?3E5-0D52+`H@("`@("`@("`@("`@("`@)R]#86YN;W0@9')O<"!T
M:&4@=&%B;&4@6UPB7"==+BM;7")<)UTL(&)E8V%U<V4@:70@9&]E<VY<)W0@
M97AI<W0@:6X@=&AE('-Y<W1E;2!C871A;&]G<UPN+R<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`@("`@
M("`@("<O3VYL>2!T:&4@;W=N97(@;V8@;V)J96-T(%M<(EPG72XK6UPB7"==
M(&]R(&$@=7-E<B!W:71H(%-Y<W1E;2!!9&UI;FES=')A=&]R(%PH4T%<*2!R
M;VQE(&-A;B!R=6X@=&AI<R!C;VUM86YD7"XO)PH@("`@("`@("`@("`@("`@
M("`@(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@("`@("`@
M("`@("`G+UXN*R!P97)M:7-S:6]N(&1E;FEE9"!O;B!O8FIE8W0@+BLL(&1A
M=&%B87-E("XK+"!O=VYE<B`N*R\G"B`@("`@("`@("`@("`@("`@("`@/3X@
M1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`@("`@("`@("<O
M7BXJ('!E<FUI<W-I;VX@9&5N:65D+"!D871A8F%S92`N*RP@;W=N97(@+BLO
M)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%#0T534U]624],
M051)3TXL"B`@("`@("`@("`@("`@("`G+UM>+BI=(&YO="!F;W5N9%PN+R<*
M("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA404),12P*
M("`@("`@("`@("`@("`@("<O5&AE<F4@:7,@86QR96%D>2!A;B!O8FIE8W0@
M;F%M960O)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%,4D5!
M1%E?15A)4U13+`H@("`@("`@("`@("`@("`@)R]);G9A;&ED(&-O;'5M;B!N
M86UE+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA&
M245,1"P*("`@("`@("`@("`@("`@("<O9&]E<R!N;W0@86QL;W<@;G5L;"!V
M86QU97,O)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-/3E-4
M4D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@("`G+T-O;6UA;F0@:&%S
M(&)E96X@86)O<G1E9"\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)2
M3U)?0T].4U1204E.5"P*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@
M("`@(&9O<F5A8V@@*"1E<G)O<E]R96=E>'!S(&%S("1R96=E>'`@/3X@)&-O
M9&4I('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)')E9V5X<"P@)&5R
M<F]R;7-G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C;V1E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]%4E)/4CL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S>6)A<V5286ES945R<F]R
M*"D*"B`@("`O*BH*("`@("`J($=A=&AE<B!I;F9O<FUA=&EO;B!A8F]U="!A
M;B!E<G)O<BP@=&AE;B!U<V4@=&AA="!I;F9O('1O(&-R96%T92!A"B`@("`@
M*B!$0B!E<G)O<B!O8FIE8W0@86YD(&9I;F%L;'D@<F5T=7)N('1H870@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2`@:6YT96=E<B`@)&5R<FYO("!0
M14%2(&5R<F]R(&YU;6)E<B`H=7-U86QL>2!A($1"(&-O;G-T86YT*2!I9@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&UA;G5A;&QY(')A:7-I
M;F<@86X@97)R;W(*("`@("`J($!R971U<FX@;V)J96-T("!$0B!E<G)O<B!O
M8FIE8W0*("`@("`J($!S964@97)R;W).871I=F4H*0H@("`@("H@0'-E92!E
M<G)O<D-O9&4H*0H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!S>6)A<V5286ES945R<F]R*"1E<G)N
M;R`](&YU;&PI"B`@("!["B`@("`@("`@)&YA=&EV92`]("1T:&ES+3YE<G)O
M<DYA=&EV92@I.PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@
M("`@("`@("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92@D;F%T:79E*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E
M<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P@)&YA=&EV92D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@
M("H@4V5N9"!A('%U97)Y('1O(%-Y8F%S92!A;F0@<F5T=7)N('1H92!R97-U
M;'1S(&%S(&$@4WEB87-E(')E<V]U<F-E"B`@("`@*B!I9&5N=&EF:65R+@H@
M("`@("H*("`@("`J($!P87)A;2!T:&4@4U%,('%U97)Y"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M(')E='5R;G,@82!V86QI9"!3>6)A<V4@<F5S=6QT(&9O<B!S=6-C97-S9G5L
M(%-%3$5#5`H@("`@("H@<75E<FEE<RP@1$)?3TL@9F]R(&]T:&5R('-U8V-E
M<W-F=6P@<75E<FEE<RX@($$@1$(@97)R;W(@:7,*("`@("`J(')E='5R;F5D
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y
M*"1Q=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII<TUA;FEP
M*"1Q=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD[
M"B`@("`@("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D
M=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YS>6)A<V5286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@
M("`@("`@?0H@("`@("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D
M<75E<GDI.PH@("`@("`@(&EF("@A)'1H:7,M/F%U=&]C;VUM:70@)B8@)&ES
M;6%N:7`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O
M<&-O=6YT(#T](#`I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!`<WEB
M87-E7W%U97)Y*"="14=)3B!44D%.4T%#5$E/3B<L("1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<B@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT*RL["B`@("`@("`@?0H@("`@
M("`@("1R97-U;'0@/2!`<WEB87-E7W%U97)Y*"1Q=65R>2P@)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("1N=6UR;W=S(#T@)'1H:7,M/FYU;5)O=W,H)')E<W5L="D["B`@("`@
M("`@("`@(&EF("AI<U]O8FIE8W0H)&YU;7)O=W,I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)&YU;7)O=W,["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/FYU;5]R;W=S6RAI;G0I)')E<W5L=%T@/2`D;G5M<F]W<SL*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@
M("\O($1E=&5R;6EN92!W:&EC:"!Q=65R:65S('1H870@<VAO=6QD(')E='5R
M;B!D871A+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U;&0@<F5T=7)N(&%N
M(&5R<F]R(&-O9&4@;VYL>2X*("`@("`@("!R971U<FX@)&ES;6%N:7`@/R!$
M0E]/2R`Z("1R97-U;'0["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA
M;"!S>6)A<V4@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA8FQE
M(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A('9A;&ED('-Y8F%S92!R
M97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I<R!A=F%I
M;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F=6YC
M=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H26YT
M;R@I"@H@("`@+RHJ"B`@("`@*B!&971C:"!A(')O=R!A;F0@:6YS97)T('1H
M92!D871A(&EN=&\@86X@97AI<W1I;F<@87)R87DN"B`@("`@*@H@("`@("H@
M1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A
M<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA)
M;G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M(')E<V]U<F-E("1R97-U;'0@("`@<75E<GD@<F5S=6QT(&ED96YT:69I
M97(*("`@("`J($!P87)A;2!A<G)A>2`@("`D87)R("`@("`@("AR969E<F5N
M8V4I(&%R<F%Y('=H97)E(&1A=&$@9G)O;2!T:&4@<F]W"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S:&]U;&0@8F4@<&QA8V5D"B`@("`@
M*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN
M9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@
M("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"7T]+(&]N('-U8V-E<W,L($Y53$P@
M=VAE;B!E;F0@;V8@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@
M("!R96%C:&5D(&]R(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"
M7W)E<W5L=#HZ9F5T8VA);G1O*"D*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L
M("1F971C:&UO9&4L("1R;W=N=6T];G5L;"D*("`@('L*("`@("`@("!I9B`H
M)')O=VYU;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H(4!S>6)A<V5?
M9&%T85]S965K*"1R97-U;'0L("1R;W=N=6TI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]!4U-/0RD@>PH@("`@
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=S>6)A<V5?9F5T8VA?87-S
M;V,G*2D@>PH@("`@("`@("`@("`@("`@)&%R<B`]($!S>6)A<V5?9F5T8VA?
M87-S;V,H)')E<W5L="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H)&%R<B`]($!S>6)A<V5?9F5T8VA?87)R87DH)')E<W5L
M="DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D87)R(&%S("1K
M97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]I;G0H)&ME>2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N
M<V5T*"1A<G);)&ME>5TI.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D87)R*2![
M"B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E
M*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&%R<B`]($!S>6)A<V5?9F5T8VA?<F]W*"1R
M97-U;'0I.PH@("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@
M("`@("`@+R\@<F5P;W)T960@;F]T('=O<FL@87,@<V5E;7,@=&AA="!S>6)A
M<V5?9V5T7VQA<W1?;65S<V%G92@I"B`@("`@("`@("`@("\O(&%L=V%Y<R!R
M971U<FX@82!M97-S86=E(&AE<F4*("`@("`@("`@("`@+R]I9B`H)&5R<FUS
M9R`]('-Y8F%S95]G971?;&%S=%]M97-S86=E*"DI('L*("`@("`@("`@("`@
M+R\@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R*"1E<G)M<V<I
M.PH@("`@("`@("`@("`O+WT@96QS92!["B`@("`@("`@("`@("`@("!R971U
M<FX@;G5L;#L*("`@("`@("`@("`@+R]]"B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197U)44DE-*2!["B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A
M;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%
M35!462D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E6
M86QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L
M="@I"@H@("`@+RHJ"B`@("`@*B!&<F5E('1H92!I;G1E<FYA;"!R97-O=7)C
M97,@87-S;V-I871E9"!W:71H("1R97-U;'0N"B`@("`@*@H@("`@("H@0'!A
M<F%M("1R97-U;'0@4WEB87-E(')E<W5L="!I9&5N=&EF:65R"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VP@5%)512!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@
M("`@>PH@("`@("`@('5N<V5T*"1T:&ES+3YN=6U?<F]W<ULH:6YT*21R97-U
M;'1=*3L*("`@("`@("!R971U<FX@0'-Y8F%S95]F<F5E7W)E<W5L="@D<F5S
M=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@
M82!R97-U;'0@<V5T+@H@("`@("H*("`@("`J($!P87)A;2`D<F5S=6QT(%-Y
M8F%S92!R97-U;'0@:61E;G1I9FEE<@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@=&AE(&YU;6)E<B!O
M9B!C;VQU;6YS('!E<B!R;W<@:6X@)')E<W5L=`H@("`@("HO"B`@("!F=6YC
M=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@/2!`
M<WEB87-E7VYU;5]F:65L9',H)')E<W5L="D["B`@("`@("`@:68@*"$D8V]L
M<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R
M;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970N"B`@
M("`@*@H@("`@("H@0'!A<F%M("1R97-U;'0@4WEB87-E(')E<W5L="!I9&5N
M=&EF:65R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="!T:&4@;G5M8F5R(&]F(')O=W,@:6X@)')E<W5L
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("![
M"B`@("`@("`@)')O=W,@/2!`<WEB87-E7VYU;5]R;W=S*"1R97-U;'0I.PH@
M("`@("`@(&EF("@D<F]W<R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R*"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F]W<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M
M8F5R(&]F(')O=W,@869F96-T960@8GD@=&AE(&1A=&$@;6%N:7!U;&%T:6]N
M"B`@("`@*B!Q=65R>2X@($9O<B!O=&AE<B!Q=65R:65S+"!T:&ES(&9U;F-T
M:6]N(')E='5R;G,@,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&YU;6)E<B!O
M9B!R;W=S(&%F9F5C=&5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@("`@:68@*$1"
M.CII<TUA;FEP*"1T:&ES+3YL87-T7W%U97)Y*2D@>PH@("`@("`@("`@("`D
M<F5S=6QT(#T@0'-Y8F%S95]A9F9E8W1E9%]R;W=S*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@
M,#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T
M:&4@<V5Q=65N8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@
M=VAE;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E
M<R!N;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE
M>'0@:60@;G5M8F5R(&EN('1H92!S97%U96YC92X@($1"7T5R<F]R(&EF('!R
M;V)L96TN"B`@("`@*@H@("`@("H@0&EN=&5R;F%L"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ;F5X=$E$*"D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]
M('1R=64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q
M=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@:68@*"%`<WEB87-E7W-E
M;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R*$1"7T52
M4D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@?0H@("`@("`@("1R97!E870@
M/2`P.PH@("`@("`@(&1O('L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YQ=65R>2@B24Y315)4($E.5$\@)'-E<6YA;64@*'9A
M<&]R*2!604Q515,@*#`I(BD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O
M<DAA;F1L:6YG*"D["B`@("`@("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z
M.FES17)R;W(H)')E<W5L="D@)B8*("`@("`@("`@("`@("`@("@D<F5S=6QT
M+3YG971#;V1E*"D@/3T@1$)?15)23U(@?'P@)')E<W5L="T^9V5T0V]D92@I
M(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*2D*("`@("`@("`@("`@>PH@("`@
M("`@("`@("`@("`@)')E<&5A="`](#$["B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@
M("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L
M="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@A
M1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/28@)'1H:7,M/G%U97)Y*")314Q%0U0@0$!)1$5.5$E462!&4D]-("1S
M97%N86UE(BD["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97!E870@/2!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R97!E870I.PH@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@
M?0H@("`@("`@("1R97-U;'0@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#
M2$U/1$5?3U)$15)%1"D["B`@("`@("`@<F5T=7)N("1R97-U;'1;,%T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@
M=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:7,@<F5T=7)N
M960@:68*("`@("`J("`@("`@("`@("`@("!P<F]B;&5M<R!A<FES92X*("`@
M("`J"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S964@1$)?8V]M;6]N.CIC
M<F5A=&5397%U96YC92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("![
M"B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S
M97%?;F%M92D["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@B0U)%051%
M(%1!0DQ%("1S97%N86UE("(N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G*&ED(&YU;65R:6,H,3`L,"D@241%3E1)5%D@3D]4($Y53$P@+"<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A<&]R(&EN="!.54Q,*2<I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q
M=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B`@1$)?17)R;W(@:68@<')O8FQE;7,N"B`@
M("`@*@H@("`@("H@0&EN=&5R;F%L"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M9')O<%-E<75E;F-E*"D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@
M("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?
M;F%M92D["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@B1%)/4"!404),
M12`D<V5Q;F%M92(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E
M=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!Q
M=65R>2!N965D960@=&\@9V5T('-O;64@8F%C:V5N9"!I;F9O"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T>7!E(%=H870@:VEN9"!O9B!I;F9O('EO=2!W86YT
M('1O(')E=')I979E"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@4U%,('%U
M97)Y('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L475E
M<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@
M("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N
M(")S96QE8W0@;F%M92!F<F]M('-Y<V]B:F5C=',@=VAE<F4@='EP92`]("=5
M)R!O<F1E<B!B>2!N86UE(CL*("`@("`@("`@("`@8V%S92`G=FEE=W,G.@H@
M("`@("`@("`@("`@("`@<F5T=7)N(")S96QE8W0@;F%M92!F<F]M('-Y<V]B
M:F5C=',@=VAE<F4@='EP92`]("=6)R(["B`@("`@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ
M"B`@("`@*B!%;F%B;&4O9&ES86)L92!A=71O;6%T:6,@8V]M;6ET<PH@("`@
M("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@
M("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A8W1I;VY?;W!C
M;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@("\O(&ES<W5E
M(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O8V]M;6ET(#T@
M)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@("\J
M*@H@("`@("H@0V]M;6ET('1H92!C=7)R96YT('1R86YS86-T:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@("`@("`@
M:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N
M;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB
M87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2!`<WEB87-E7W%U97)Y*"=#
M3TU-250G+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1T:&ES
M+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S
M95)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F]L;"!B86-K("AU;F1O*2!T
M:&4@8W5R<F5N="!T<F%N<V%C=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F]L;&)A8VLH*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I
M;VY?;W!C;W5N="`^(#`I('L*("`@("`@("`@("`@:68@*"%`<WEB87-E7W-E
M;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<BA$
M0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1R97-U;'0@/2!`<WEB87-E7W%U97)Y*"=23TQ,0D%#2R<L("1T:&ES
M+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N
M7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<B@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A
M8FQE(&]R(&$@<F5S=6QT('-E="X*("`@("`J"B`@("`@*B!.3U1%.B!O;FQY
M('-U<'!O<G1S("=T86)L92<@86YD("=F;&%G<R<@:68@/'9A<CXD<F5S=6QT
M/"]V87(^"B`@("`@*B!I<R!A('1A8FQE(&YA;64N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&]B:F5C='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE
M8W0@9G)O;2!A('%U97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A
M('1A8FQE"B`@("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@
M82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@("H@0')E='5R;B!A<G)A>2`@
M86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q
M=65S=&5D"B`@("`@*B`@("`@("`@("`@("`@("!O<B!A;B!E<G)O<B!O8FIE
M8W0@:68@<V]M971H:6YG(&ES('=R;VYG"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0&EN=&5R;F%L"B`@("`@*B!`<VEN8V4@,2XV+C`*("`@("`J
M($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@("`@
M("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S
M=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT
M(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@
M("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G;W1?
M<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B
M86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R
M96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI
M<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"
M4T5,14-4140I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I9"`]($!S
M>6)A<V5?<75E<GDH(E-%3$5#5"`J($923TT@)')E<W5L="!72$5212`Q/3`B
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;VYN
M96-T:6]N*3L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R
M;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N
M"B`@("`@("`@("`@("`J($-O<'D@:70N"B`@("`@("`@("`@("`J($1E<')I
M8V%T960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@
M("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@
M("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<U]R97-O=7)C92@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<WEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A
M8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*("`@("`@
M("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@
M("`@?0H*("`@("`@("`D8V]U;G0@/2!`<WEB87-E7VYU;5]F:65L9',H)&ED
M*3L*"B`@("`@("`@+R\@;6%D92!T:&ES($E&(&1U92!T;R!P97)F;W)M86YC
M92`H;VYE(&EF(&ES(&9A<W1E<B!T:&%N("1C;W5N="!I9B=S*0H@("`@("`@
M(&EF("@A)&UO9&4I('L*"B`@("`@("`@("`@(&9O<B`H)&D],#L@)&D\)&-O
M=6YT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D9B`]($!S>6)A<V5?9F5T
M8VA?9FEE;&0H)&ED+"`D:2D["@H@("`@("`@("`@("`@("`@+R\@8V]L=6UN
M7W-O=7)C92!I<R!O9G1E;B!B;&%N:PH@("`@("`@("`@("`@("`@:68@*"1G
M;W1?<W1R:6YG*2!["B`@("`@("`@("`@("`@("`@("`@)')E<ULD:5U;)W1A
M8FQE)UT@/2`D8V%S95]F=6YC*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S6R1I75LG=&%B;&4G
M72`]("1C87-E7V9U;F,H)&8M/F-O;'5M;E]S;W5R8V4I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)')E<ULD:5U;)VYA;64G72`@/2`D
M8V%S95]F=6YC*"1F+3YN86UE*3L*("`@("`@("`@("`@("`@("1R97-;)&E=
M6R=T>7!E)UT@(#T@)&8M/G1Y<&4["B`@("`@("`@("`@("`@("`D<F5S6R1I
M75LG;&5N)UT@("`]("1F+3YM87A?;&5N9W1H.PH@("`@("`@("`@("`@("`@
M:68@*"1R97-;)&E=6R=T86)L92==*2!["B`@("`@("`@("`@("`@("`@("`@
M)')E<ULD:5U;)V9L86=S)UT@/2`D=&AI<RT^7W-Y8F%S95]F:65L9%]F;&%G
M<R@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-;)&E=6R=T86)L
M92==+"`D<F5S6R1I75LG;F%M92==*3L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)')E<ULD:5U;)V9L86=S)UT@/2`G
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!G970@9G5L;"!I;F9O"@H@("`@("`@
M("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0["@H@("`@("`@("`@
M("!F;W(@*"1I/3`[("1I/"1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)&8@/2!`<WEB87-E7V9E=&-H7V9I96QD*"1I9"P@)&DI.PH*("`@("`@
M("`@("`@("`@("\O(&-O;'5M;E]S;W5R8V4@:7,@;V9T96X@8FQA;FL*("`@
M("`@("`@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("`@
M("`@("`@("1R97-;)&E=6R=T86)L92==(#T@)&-A<V5?9G5N8R@D<F5S=6QT
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)')E<ULD:5U;)W1A8FQE)UT@/2`D8V%S95]F=6YC*"1F+3YC;VQU;6Y?
M<V]U<F-E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R
M97-;)&E=6R=N86UE)UT@(#T@)&-A<V5?9G5N8R@D9BT^;F%M92D["B`@("`@
M("`@("`@("`@("`D<F5S6R1I75LG='EP92==("`]("1F+3YT>7!E.PH@("`@
M("`@("`@("`@("`@)')E<ULD:5U;)VQE;B==("`@/2`D9BT^;6%X7VQE;F=T
M:#L*("`@("`@("`@("`@("`@(&EF("@D<F5S6R1I75LG=&%B;&4G72D@>PH@
M("`@("`@("`@("`@("`@("`@("1R97-;)&E=6R=F;&%G<R==(#T@)'1H:7,M
M/E]S>6)A<V5?9FEE;&1?9FQA9W,H"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5S6R1I75LG=&%B;&4G72P@)')E<ULD:5U;)VYA;64G72D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R
M97-;)&E=6R=F;&%G<R==(#T@)R<["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2![
M"B`@("`@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G75LD<F5S6R1I75LG
M;F%M92==72`]("1I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$525$%"3$4I('L*("`@
M("`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;
M)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&9R
M964@=&AE(')E<W5L="!O;FQY(&EF('=E('=E<F4@8V%L;&5D(&]N(&$@=&%B
M;&4*("`@("`@("!I9B`H)&=O=%]S=')I;F<I('L*("`@("`@("`@("`@0'-Y
M8F%S95]F<F5E7W)E<W5L="@D:60I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?<WEB87-E
M7V9I96QD7V9L86=S*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@9FQA9W,@
M9F]R(&$@9FEE;&0N"B`@("`@*@H@("`@("H@0W5R<F5N=&QY('-U<'!O<G1S
M.@H@("`@("H@("L@/'-A;7`^=6YI<75E7VME>3PO<V%M<#X@("`@*'5N:7%U
M92!I;F1E>"P@=6YI<75E(&-H96-K(&]R('!R:6UA<GE?:V5Y*0H@("`@("H@
M("L@/'-A;7`^;75L=&EP;&5?:V5Y/"]S86UP/B`@*&UU;'1I+6ME>2!I;F1E
M>"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&%B;&4@("!T86)L
M92!N86UE"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L=6UN("!F:65L9"!N
M86UE"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@<W!A8V4@9&5L:6UI=&5D('-T
M<FEN9R!O9B!F;&%G<RX@($5M<'1Y('-T<FEN9R!I9B!N;VYE+@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S>6)A<V5?
M9FEE;&1?9FQA9W,H)'1A8FQE+"`D8V]L=6UN*0H@("`@>PH@("`@("`@('-T
M871I8R`D=&%B;&5.86UE(#T@;G5L;#L*("`@("`@("!S=&%T:6,@)&9L86=S
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T86)L92`A/2`D=&%B;&5.86UE
M*2!["B`@("`@("`@("`@("1F;&%G<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("1T86)L94YA;64@/2`D=&%B;&4["@H@("`@("`@("`@("`O+R!G970@=6YI
M<75E+W!R:6UA<GD@:V5Y<PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F=E
M=$%L;"@B<W!?:&5L<&EN9&5X("1T86)L92(L($1"7T9%5$-(34]$15]!4U-/
M0RD["@H@("`@("`@("`@("!I9B`H(6ES<V5T*"1R97-;,%U;)VEN9&5X7V1E
M<V-R:7!T:6]N)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)R<["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@*"1R97,@87,@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@)&ME>7,@/2!E>'!L;V1E*"<L("<L('1R
M:6TH)'9A;%LG:6YD97A?:V5Y<R==*2D["@H@("`@("`@("`@("`@("`@:68@
M*'-I>F5O9B@D:V5Y<RD@/B`Q*2!["B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G<ULD:V5Y72P@)VUU;'1I<&QE7VME
M>2<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1V86Q;)VEN9&5X7V1E<V-R
M:7!T:6]N)UTL("=U;FEQ=64G*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A9&1?9FQA9R@D9FQA9W-;)&ME>5TL("=U;FEQ=65?:V5Y
M)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@:68@*&%R<F%Y7VME
M>5]E>&ES=',H)&-O;'5M;BP@)&9L86=S*2D@>PH@("`@("`@("`@("!R971U
M<FXH:6UP;&]D92@G("<L("1F;&%G<ULD8V]L=6UN72DI.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(%]A9&1?9FQA9R@I"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<W1R:6YG
M('1O('1H92!F;&%G<R!A<G)A>2!I9B!T:&4@9FQA9R!I<R!N;W0@>65T(&EN
M('1H97)E"B`@("`@*B`M(&EF('1H97)E(&ES(&YO(&9L86<@<')E<V5N="!T
M:&4@87)R87D@:7,@8W)E871E9"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@("1A<G)A>2`@<F5F97)E;F-E(&]F(&9L86=S(&%R<F%Y('1O(&%D9"!A
M('9A;'5E('1O"B`@("`@*B!`<&%R86T@;6EX960@("1V86QU92`@=F%L=64@
M=&\@861D('1O('1H92!F;&%G(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9%]F;&%G*"8D87)R87DL("1V
M86QU92D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<G)A>2DI('L*
M("`@("`@("`@("`@)&%R<F%Y(#T@87)R87DH)'9A;'5E*3L*("`@("`@("!]
M(&5L<V5I9B`H(6EN7V%R<F%Y*"1V86QU92P@)&%R<F%Y*2D@>PH@("`@("`@
M("`@("!A<G)A>5]P=7-H*"1A<G)A>2P@)'9A;'5E*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&5)9&5N=&EF:65R*"D*
M"B`@("`O*BH*("`@("`J(%%U;W1E(&$@<W1R:6YG('-O(&ET(&-A;B!B92!S
M869E;'D@=7-E9"!A<R!A('1A8FQE("\@8V]L=6UN(&YA;64*("`@("`J"B`@
M("`@*B!1=6]T:6YG('-T>6QE(&1E<&5N9',@;VX@=VAI8V@@9&%T86)A<V4@
M9')I=F5R(&ES(&)E:6YG('5S960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W1R("!I9&5N=&EF:65R(&YA;64@=&\@8F4@<75O=&5D"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@('%U;W1E9"!I9&5N=&EF:65R('-T
M<FEN9PH@("`@("H*("`@("`J($!S:6YC92`Q+C8N,`H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&5)9&5N=&EF:65R
M*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N("=;)R`N('-T<E]R97!L86-E
M*"==)RP@)UU=)RP@)'-T<BD@+B`G72<["B`@("!]"@H@("`@+R\@?7U]"@I]
M"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C
M+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]O8VDX+G!H<```````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V-34V,0`Q,#0Q-S,V,S`P
M-@`P,3<R,34`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S
M:&EF='=I9'1H/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@
M2F%M97,@3"X@4&EN92`\:FQP0'9A;&EN=7@N8V]M/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!-86EN=&%I;F5R.B!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M(&]C:3@N<&AP+'8@,2XV,"`R,#`T+S`R+S$Y(#`W.C(X.C,T(&1A;FEE;&,@
M17AP("0*"@HO+R!B92!A=V%R92XN+B`@3T-)17)R;W(H*2!O;FQY(&%P<&5A
M<G,@=&\@<F5T=7)N(&%N>71H:6YG('=H96X@9VEV96X@80HO+R!S=&%T96UE
M;G0L('-O(&9U;F-T:6]N<R!R971U<FX@=&AE(&=E;F5R:6,@1$)?15)23U(@
M:6YS=&5A9"!O9B!M;W)E"B\O('5S969U;"!E<G)O<G,@=&AA="!H879E('1O
M(&1O('=I=&@@9F5E9&)A8VL@9G)O;2!T:&4@9&%T86)A<V4N"@H*<F5Q=6ER
M95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!$871A8F%S92!I;F1E
M<&5N9&5N="!Q=65R>2!I;G1E<F9A8V4@9&5F:6YI=&EO;B!F;W(@4$A0)W,@
M3W)A8VQE(#@*("H@8V%L;"UI;G1E<F9A8V4@97AT96YS:6]N+@H@*@H@*B!$
M969I;FET96QY('=O<FMS('=I=&@@=F5R<VEO;G,@."!A;F0@.2!O9B!/<F%C
M;&4N"B`J"B`J($!P86-K86=E("!$0@H@*B!`=F5R<VEO;B`@)$ED.B!O8VDX
M+G!H<"QV(#$N-C`@,C`P-"\P,B\Q.2`P-SHR.#HS-"!D86YI96QC($5X<"`D
M"B`J($!C871E9V]R>2!$871A8F%S90H@*B!`875T:&]R("`@2F%M97,@3"X@
M4&EN92`\:FQP0'9A;&EN=7@N8V]M/@H@*B\*8VQA<W,@1$)?;V-I."!E>'1E
M;F1S($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@('9A
M<B`D8V]N;F5C=&EO;CL*("`@('9A<B`D<&AP='EP92P@)&1B<WEN=&%X.PH@
M("`@=F%R("1M86YI<%]Q=65R>2`](&%R<F%Y*"D["B`@("!V87(@)'!R97!A
M<F5?='EP97,@/2!A<G)A>2@I.PH@("`@=F%R("1A=71O0V]M;6ET(#T@,3L*
M("`@('9A<B`D;&%S=%]S=&UT(#T@9F%L<V4["@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@8V]N<W1R=6-T;W(*"B`@("!F=6YC=&EO;B!$0E]O8VDX*"D*("`@
M('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("`@("`@)'1H:7,M
M/G!H<'1Y<&4@/2`G;V-I."<["B`@("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@
M)V]C:3@G.PH@("`@("`@("1T:&ES+3YF96%T=7)E<R`](&%R<F%Y*`H@("`@
M("`@("`@("`G<')E<&%R92<@/3X@9F%L<V4L"B`@("`@("`@("`@("=P8V]N
M;F5C="<@/3X@=')U92P*("`@("`@("`@("`@)W1R86YS86-T:6]N<R<@/3X@
M=')U92P*("`@("`@("`@("`@)VQI;6ET)R`]/B`G86QT97(G"B`@("`@("`@
M*3L*("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@
M("`@("`@("`Q(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@("`@
M(#DP,"`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@(#DP-"`]/B!$
M0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@.3(Q(#T^($1"7T52
M4D]27U-93E1!6"P*("`@("`@("`@("`@.3(S(#T^($1"7T524D]27U-93E1!
M6"P*("`@("`@("`@("`@.30R(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@
M("`@("`@("`@("`Y-34@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@
M("`@("`@("`@(#$T,#`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,
M3"P*("`@("`@("`@("`@,30P-R`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/
M5%].54Q,+`H@("`@("`@("`@("`Q-#<V(#T^($1"7T524D]27T1)5EI%4D\L
M"B`@("`@("`@("`@(#$W,C(@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L
M"B`@("`@("`@("`@(#(R.#D@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@
M("`@("`@("`@(#(R.3$@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@
M("`@("`@,C0T.2`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("D[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@
M+RHJ"B`@("`@*B!#;VYN96-T('1O(&$@9&%T86)A<V4@86YD(&QO9R!I;B!A
M<R!T:&4@<W!E8VEF:65D('5S97(N"B`@("`@*@H@("`@("H@0'!A<F%M("1D
M<VX@=&AE(&1A=&$@<V]U<F-E(&YA;64@*'-E92!$0CHZ<&%R<V5$4TX@9F]R
M('-Y;G1A>"D*("`@("`J($!P87)A;2`D<&5R<VES=&5N="`H;W!T:6]N86PI
M('=H971H97(@=&AE(&-O;FYE8W1I;VX@<VAO=6QD"B`@("`@*B`@("`@("`@
M8F4@<&5R<VES=&5N=`H@("`@("H*("`@("`J($!R971U<FX@:6YT($1"7T]+
M(&]N('-U8V-E<W,L(&$@1$(@97)R;W(@8V]D92!O;B!F86EL=7)E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;FEN9F\L("1P97)S:7-T96YT
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%$0CHZ87-S97)T17AT96YS
M:6]N*"=O8VDX)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;FEN9F\["@H@("`@("`@("1C
M;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E;G0@/R`G3T-)4$QO9V]N)R`Z
M("=/0TE,;V=O;B<["@H@("`@("`@(&EF("@D9'-N:6YF;ULG:&]S='-P96,G
M72D@>PH@("`@("`@("`@("`D8V]N;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D
M9'-N:6YF;ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1S;FEN9F];)W!A<W-W;W)D)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D<VYI;F9O6R=H;W-T
M<W!E8R==*3L*("`@("`@("!](&5L<V5I9B`H)&1S;FEN9F];)W5S97)N86UE
M)UT@?'P@)&1S;FEN9F];)W!A<W-W;W)D)UTI('L*("`@("`@("`@("`@)&-O
M;FX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1S;FEN9F];)W5S97)N86UE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D<VYI
M;F9O6R=P87-S=V]R9"==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D8V]N;B`](&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H)&-O;FX@
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&5R<F]R(#T@3T-)17)R;W(H*3L*
M("`@("`@("`@("`@)&5R<F]R(#T@*&ES7V%R<F%Y*"1E<G)O<BDI(#\@)&5R
M<F]R6R=M97-S86=E)UT@.B!N=6QL.PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L(&YU;&PL
M(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N
M=6QL+"`D97)R;W(I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^8V]N;F5C
M=&EO;B`]("1C;VYN.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@
M("`J($QO9R!O=70@86YD(&1I<V-O;FYE8W0@9G)O;2!T:&4@9&%T86)A<V4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@
M1D%,4T4@:68@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]($!/0TE,;V=/9F8H
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T:6]N
M(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@*B!3
M96YD(&$@<75E<GD@=&\@;W)A8VQE(&%N9"!R971U<FX@=&AE(')E<W5L=',@
M87,@86X@;V-I."!R97-O=7)C90H@("`@("H@:61E;G1I9FEE<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@)'%U97)Y('1H92!344P@<75E<GD*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="!R971U<FYS(&$@=F%L:60@;V-I."!R97-U;'0@
M9F]R('-U8V-E<W-F=6P@4T5,14-4"B`@("`@*B!Q=65R:65S+"!$0E]/2R!F
M;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S+B`@02!$0B!E<G)O<B!C;V1E
M"B`@("`@*B!I<R!R971U<FYE9"!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)'1H
M:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@("`@)'%U97)Y(#T@)'1H
M:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D["B`@("`@("`@)')E<W5L="`]($!/
M0TE087)S92@D=&AI<RT^8V]N;F5C=&EO;BP@)'%U97)Y*3L*("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX
M4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F%U
M=&]#;VUM:70I('L*("`@("`@("`@("`@)'-U8V-E<W,@/2!`3T-)17AE8W5T
M92@D<F5S=6QT+$]#25]#3TU-251?3TY?4U5#0T534RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'-U8V-E<W,@/2!`3T-)17AE8W5T92@D<F5S
M=6QT+$]#25]$149!54Q4*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D<W5C
M8V5S<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R
M<F]R*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;&%S=%]S
M=&UT/21R97-U;'0["B`@("`@("`@+R\@1&5T97)M:6YE('=H:6-H('%U97)I
M97,@=&AA="!S:&]U;&0@<F5T=7)N(&1A=&$L(&%N9"!W:&EC:`H@("`@("`@
M("\O('-H;W5L9"!R971U<FX@86X@97)R;W(@8V]D92!O;FQY+@H@("`@("`@
M(')E='5R;B!$0CHZ:7--86YI<"@D<75E<GDI(#\@1$)?3TL@.B`D<F5S=6QT
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*
M("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@;W)A8VQE(')E<W5L
M="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R97-U;'0*("`@("`J
M"B`@("`@*B!`<&%R86T@82!V86QI9"!O8VDX(')E<W5L="!R97-O=7)C90H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E
M='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@
M<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H
M)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@
M("`J($9E=&-H(&$@<F]W(&%N9"!I;G-E<G0@=&AE(&1A=&$@:6YT;R!A;B!E
M>&ES=&EN9R!A<G)A>2X*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE
M(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N
M"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I
M;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E
M<W5L="`@("!Q=65R>2!R97-U;'0@:61E;G1I9FEE<@H@("`@("H@0'!A<F%M
M(&%R<F%Y("`@("1A<G(@("`@("`@*')E9F5R96YC92D@87)R87D@=VAE<F4@
M9&%T82!F<F]M('1H92!R;W<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-H;W5L9"!B92!P;&%C960*("`@("`J($!P87)A;2!I;G0@("`@
M("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B
M92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT("`@("`@)')O=VYU;2`@("!T
M:&4@<F]W(&YU;6)E<B!T;R!F971C:`H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N(&5N9"!O9B!R97-U
M;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@("`@(')E86-H960@;W(@;VX@
M9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN
M=&\H*0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O
M=VYU;3UN=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!.54Q,
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%
M4E)/4E].3U1?0T%004),12D["B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T
M8VAM;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1M
M;W)E9&%T82`]($!/0TE&971C:$EN=&\H)')E<W5L="PD87)R+$]#25]!4U-/
M0RM/0TE?4D5455).7TY53$Q3*T]#25]215154DY?3$]"4RD["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/
M4E1!0DE,25197TQ/5T520T%312`F)@H@("`@("`@("`@("`@("`@)&UO<F5D
M871A*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R
M87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO<F5D871A
M(#T@3T-)1F5T8VA);G1O*"1R97-U;'0L)&%R<BQ/0TE?4D5455).7TY53$Q3
M*T]#25]215154DY?3$]"4RD["B`@("`@("`@?0H@("`@("`@(&EF("@A)&UO
M<F5D871A*2!["B`@("`@("`@("`@(')E='5R;B!.54Q,.PH@("`@("`@('T*
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$
M0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T
M<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,2519
M7TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T
M3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1G)E92!T:&4@:6YT97)N
M86P@<F5S;W5R8V5S(&%S<V]C:6%T960@=VET:"`D<F5S=6QT+@H@("`@("H*
M("`@("`J($!P87)A;2`D<F5S=6QT(&]C:3@@<F5S=6QT(&ED96YT:69I97(*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!&
M04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J+PH@("`@9G5N8W1I
M;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`
M3T-)1G)E95-T871E;65N="@D<F5S=6QT*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($9R964@=&AE(&EN=&5R;F%L(')E<V]U<F-E<R!A<W-O8VEA=&5D('=I
M=&@@82!P<F5P87)E9"!Q=65R>2X*("`@("`J"B`@("`@*B!`<&%R86T@)'-T
M;70@;V-I."!S=&%T96UE;G0@:61E;G1I9FEE<@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@
M:7,@:6YV86QI9`H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4')E<&%R960H
M)'-T;70I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP<F5P87)E
M7W1Y<&5S6RAI;G0I)'-T;71=*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^<')E<&%R95]T>7!E<ULH:6YT*21S=&UT72D["B`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3YM86YI<%]Q=65R>5LH:6YT*21S=&UT72D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!N=6U2;W=S*"D*"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I
M"B`@("!["B`@("`@("`@+R\@96UU;&%T92!N=6U2;W=S(&9O<B!/<F%C;&4N
M("!Y=6-K+@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI
M='DG72`F($1"7U!/4E1!0DE,25197TY535)/5U,@)B8*("`@("`@("`@("`@
M)')E<W5L="`]/3T@)'1H:7,M/FQA<W1?<W1M="D*("`@("`@("!["B`@("`@
M("`@("`@("1C;W5N='%U97)Y(#T@)U-%3$5#5"!#3U5.5"@J*2!&4D]-("@G
M+B1T:&ES+3YL87-T7W%U97)Y+B<I)SL*("`@("`@("`@("`@)'-A=F5?<75E
M<GD@/2`D=&AI<RT^;&%S=%]Q=65R>3L*("`@("`@("`@("`@)'-A=F5?<W1M
M="`]("1T:&ES+3YL87-T7W-T;70["B`@("`@("`@("`@("1C;W5N="`])B`D
M=&AI<RT^<75E<GDH)&-O=6YT<75E<GDI.PH@("`@("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)&-O=6YT*2!\?`H@("`@("`@("`@("`@("`@1$(Z.FES17)R
M;W(H)')O=R`]("1C;W5N="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52
M140I*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQA
M<W1?<75E<GD@/2`D<V%V95]Q=65R>3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YL87-T7W-T;70@/2`D<V%V95]S=&UT.PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')O=ULP73L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T52
M4D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@;G5M8F5R(&]F
M(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T+@H@("`@("H*("`@("`J($!P87)A
M;2`D<F5S=6QT(&]C:3@@<F5S=6QT(&ED96YT:69I97(*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@<&5R(')O=R!I
M;B`D<F5S=6QT"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L
M="D*("`@('L*("`@("`@("`D8V]L<R`]($!/0TE.=6U#;VQS*"1R97-U;'0I
M.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YO8VDX4F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@;F%T:79E
M(&5R<F]R(&-O9&4@;V8@=&AE(&QA<W0@97)R;W(@*&EF(&%N>2D@=&AA="!O
M8V-U<F5D"B`@("`@*B!O;B!T:&4@8W5R<F5N="!C;VYN96-T:6]N+B`@5&AI
M<R!D;V5S(&YO="!W;W)K+"!A<R!/0TE%<G)O<B!D;V5S"B`@("`@*B!N;W0@
M=V]R:R!U;FQE<W,@9VEV96X@82!S=&%T96UE;G0N("!)9B!/0TE%<G)O<B!D
M;V5S(')E='5R;@H@("`@("H@<V]M971H:6YG+"!S;R!W:6QL('1H:7,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@;F%T:79E(&]C:3@@97)R;W(@8V]D
M90H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@
M("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3YL87-T7W-T;70I*2!["B`@
M("`@("`@("`@("1E<G)O<B`]($!/0TE%<G)O<B@D=&AI<RT^;&%S=%]S=&UT
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97)R;W(@/2!`3T-)
M17)R;W(H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@('T*("`@("`@("!I
M9B`H:7-?87)R87DH)&5R<F]R*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R6R=C;V1E)UT["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P<F5P87)E*"D*"B`@("`O
M*BH*("`@("`J(%!R97!A<F5S(&$@<75E<GD@9F]R(&UU;'1I<&QE(&5X96-U
M=&EO;B!W:71H(&5X96-U=&4H*2X*("`@("`J"B`@("`@*B!7:71H(&]C:3@L
M('1H:7,@:7,@96UU;&%T960N"B`@("`@*@H@("`@("H@<')E<&%R92@I(')E
M<75I<F5S(&$@9V5N97)I8R!Q=65R>2!A<R!S=')I;F<@;&EK92`\8V]D93X*
M("`@("`J("`@($E.4T525"!)3E1/(&YU;6)E<G,@5D%,5453("@_+"`_+"`_
M*0H@("`@("H@/"]C;V1E/BX@(%1H92`\:V)D/C\\+VMB9#X@8VAA<F%C=&5R
M<R!A<F4@<&QA8V5H;VQD97)S+@H@("`@("H*("`@("`J(%1H<F5E('1Y<&5S
M(&]F('!L86-E:&]L9&5R<R!C86X@8F4@=7-E9#H*("`@("`J("`@*R`\:V)D
M/C\\+VMB9#X@(&$@<75O=&5D('-C86QA<B!V86QU92P@:2YE+B!S=')I;F=S
M+"!I;G1E9V5R<PH@("`@("H@("`K(#QK8F0^(3PO:V)D/B`@=F%L=64@:7,@
M:6YS97)T960@)V%S(&ES)PH@("`@("H@("`K(#QK8F0^)CPO:V)D/B`@<F5Q
M=6ER97,@82!F:6QE(&YA;64N("!4:&4@9FEL92=S(&-O;G1E;G1S(&=E=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("!I;G-E<G1E9"!I;G1O('1H92!Q
M=65R>2`H:2YE+B!S879I;F<@8FEN87)Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@(&1A=&$@:6X@82!D8BD*("`@("`J"B`@("`@*B!5<V4@8F%C:W-L
M87-H97,@=&\@97-C87!E('!L86-E:&]L9&5R(&-H87)A8W1E<G,@:68@>6]U
M(&1O;B=T('=A;G0*("`@("`J('1H96T@=&\@8F4@:6YT97)P<F5T960@87,@
M<&QA8V5H;VQD97)S+B`@17AA;7!L93H@/&-O9&4^"B`@("`@*B`@("`B55!$
M051%(&9O;R!3150@8V]L/3\@5TA%4D4@8V]L/2=O=F5R(%PF('5N9&5R)R(*
M("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q
M=65R>2!Q=65R>2!T;R!B92!P<F5P87)E9`H@("`@("H@0')E='5R;B!M:7AE
M9"!$0B!S=&%T96UE;G0@<F5S;W5R8V4@;VX@<W5C8V5S<RX@1$)?17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E<&%R92@D<75E
M<GDI"B`@("!["B`@("`@("`@)'1O:V5N<R`@(#T@<')E9U]S<&QI="@G+R@H
M/SPA7%Q<*5LF/R%=*2\G+"`D<75E<GDL("TQ+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4%)%1U]34$Q)5%]$14Q)35]#05!455)%*3L*("`@
M("`@("`D8FEN9',@("`@/2!C;W5N="@D=&]K96YS*2`M(#$["B`@("`@("`@
M)'1O:V5N("`@(#T@,#L*("`@("`@("`D='EP97,@("`@/2!A<G)A>2@I.PH@
M("`@("`@("1N97=Q=65R>2`]("<G.PH*("`@("`@("!F;W)E86-H("@D=&]K
M96YS(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!S=VET8V@@*"1V
M86PI('L*("`@("`@("`@("`@("`@(&-A<V4@)S\G.@H@("`@("`@("`@("`@
M("`@("`@("1T>7!E<ULD=&]K96XK*UT@/2!$0E]005)!35]30T%,05(["B`@
M("`@("`@("`@("`@("`@("`@=6YS970H)'1O:V5N<ULD:V5Y72D["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("<F
M)SH*("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N*RM=(#T@1$)?
M4$%204U?3U!!455%.PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T;VME
M;G-;)&ME>5TI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@8V%S92`G(2<Z"B`@("`@("`@("`@("`@("`@("`@)'1Y<&5S
M6R1T;VME;BLK72`]($1"7U!!4D%-7TU)4T,["B`@("`@("`@("`@("`@("`@
M("`@=6YS970H)'1O:V5N<ULD:V5Y72D["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@("`@("1T;VME;G-;)&ME>5T@/2!P<F5G7W)E<&QA8V4H)R]<7%PH6R8_
M(5TI+R<L(")<7#$B+"`D=F%L*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&ME>2`A/2`D8FEN9',I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE
M=W%U97)Y("X]("1T;VME;G-;)&ME>5T@+B`G.F)I;F0G("X@)'1O:V5N.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1N97=Q=65R>2`N/2`D=&]K96YS6R1K97E=.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@("`@)&YE=W%U97)Y
M(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1N97=Q=65R>2D["B`@("`@("`@:68@
M*"$D<W1M="`]($!/0TE087)S92@D=&AI<RT^8V]N;F5C=&EO;BP@)&YE=W%U
M97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YP<F5P87)E7W1Y<&5S
M6R1S=&UT72`]("1T>7!E<SL*("`@("`@("`D=&AI<RT^;6%N:7!?<75E<GE;
M*&EN="DD<W1M=%T@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@("`@("`@(')E
M='5R;B`D<W1M=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E>&5C
M=71E*"D*"B`@("`O*BH*("`@("`J($5X96-U=&5S(&$@1$(@<W1A=&5M96YT
M('!R97!A<F5D('=I=&@@<')E<&%R92@I+@H@("`@("H*("`@("`J($!P87)A
M;2!R97-O=7)C92`@)'-T;70@(&$@1$(@<W1A=&5M96YT(')E<V]U<F-E(')E
M='5R;F5D(&9R;VT@<')E<&%R92@I"B`@("`@*B!`<&%R86T@;6EX960@("1D
M871A("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@
M=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O
M9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M('%U97)Y.B`@;65A;FEN9R`Q(&9O<B!N;VXM87)R87D@:71E;7,@;W(@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!Q=6%N=&ET>2!O9B!E;&5M
M96YT<R!I;B!T:&4@87)R87DN"B`@("`@*B!`<F5T=7)N(&EN="!R971U<FYS
M(&%N(&]C:3@@<F5S=6QT(')E<V]U<F-E(&9O<B!S=6-C97-S9G5L"B`@("`@
M*B!314Q%0U0@<75E<FEE<RP@1$)?3TL@9F]R(&]T:&5R('-U8V-E<W-F=6P@
M<75E<FEE<RX@($$@1$(@97)R;W(*("`@("`J(&-O9&4@:7,@<F5T=7)N960@
M;VX@9F%I;'5R92X*("`@("`J($!S964@1$)?;V-I.CIP<F5P87)E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F5X96-U=&4H)'-T;70L("1D871A(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871A*2D@>PH@
M("`@("`@("`@("`D9&%T82`](&%R<F%Y*"1D871A*3L*("`@("`@("!]"@H@
M("`@("`@("1T>7!E<R`])B`D=&AI<RT^<')E<&%R95]T>7!E<ULD<W1M=%T[
M"B`@("`@("`@:68@*&-O=6YT*"1T>7!E<RD@(3T@8V]U;G0H)&1A=&$I*2![
M"B`@("`@("`@("`@("1T;7`@/28@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?34E334%40T@I.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@
M("!]"@H@("`@("`@("1I(#T@,#L*("`@("`@("!F;W)E86-H("@D9&%T82!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("!I9B`H)'1Y<&5S6R1I
M72`]/2!$0E]005)!35]-25-#*2!["B`@("`@("`@("`@("`@("`O*@H@("`@
M("`@("`@("`@("`@("H@3W)A8VQE(&1O97-N)W0@<V5E;2!T;R!H879E('1H
M92!A8FEL:71Y('1O('!A<W,@80H@("`@("`@("`@("`@("`@("H@<&%R86UE
M=&5R(&%L;VYG('5N8VAA;F=E9"P@<V\@<W1R:7`@;V9F('%U;W1E<R!F<F]M
M('-T87)T"B`@("`@("`@("`@("`@("`@*B!A;F0@96YD+"!P;'5S('1U<FX@
M='=O('-I;F=L92!Q=6]T97,@=&\@;VYE('-I;F=L92!Q=6]T92P*("`@("`@
M("`@("`@("`@("`J(&EN(&]R9&5R('1O(&%V;VED('1H92!Q=6]T97,@9V5T
M=&EN9R!E<V-A<&5D(&)Y"B`@("`@("`@("`@("`@("`@*B!/<F%C;&4@86YD
M(&5N9&EN9R!U<"!I;B!T:&4@9&%T86)A<V4N"B`@("`@("`@("`@("`@("`@
M*B\*("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@<')E9U]R97!L86-E
M*"(O7B<H+BHI)R0O(BP@(EQ<,2(L("1D871A6R1K97E=*3L*("`@("`@("`@
M("`@("`@("1D871A6R1K97E=(#T@<W1R7W)E<&QA8V4H(B<G(BP@(B<B+"`D
M9&%T85LD:V5Y72D["B`@("`@("`@("`@('T@96QS96EF("@D='EP97-;)&E=
M(#T]($1"7U!!4D%-7T]005%512D@>PH@("`@("`@("`@("`@("`@)&9P(#T@
M0&9O<&5N*"1D871A6R1K97E=+"`G<F(G*3L*("`@("`@("`@("`@("`@(&EF
M("@A)&9P*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^
M<F%I<V5%<G)O<BA$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].*3L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@9G)E860H)&9P+"!F:6QE
M<VEZ92@D9&%T85LD:V5Y72DI.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F
M<"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%`3T-)0FEN9$)Y
M3F%M92@D<W1M="P@)SIB:6YD)R`N("1I+"`D9&%T85LD:V5Y72P@+3$I*2![
M"B`@("`@("`@("`@("`@("`D=&UP(#T@)'1H:7,M/F]C:3A286ES945R<F]R
M*"1S=&UT*3L*("`@("`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1I*RL["B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^875T;T-O;6UI="D@>PH@("`@("`@("`@("`D<W5C8V5S<R`]
M($!/0TE%>&5C=71E*"1S=&UT+"!/0TE?0T]-34E47T].7U-50T-%4U,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=6-C97-S(#T@0$]#245X
M96-U=&4H)'-T;70L($]#25]$149!54Q4*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"$D<W5C8V5S<RD@>PH@("`@("`@("`@("`D=&UP(#T@)'1H:7,M/F]C
M:3A286ES945R<F]R*"1S=&UT*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YL87-T7W-T;70@/2`D<W1M=#L*
M("`@("`@("!I9B`H)'1H:7,M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=*2![
M"B`@("`@("`@("`@("1T;7`@/2!$0E]/2SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&UP(#TF(&YE=R!$0E]R97-U;'0H)'1H:7,L("1S=&UT
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T;7`["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ"B`@("`@
M*B!%;F%B;&4O9&ES86)L92!A=71O;6%T:6,@8V]M;6ET<PH@("`@("H*("`@
M("`J($!P87)A;2`D;VYO9F8@=')U92]F86QS92!W:&5T:&5R('1O(&%U=&]C
M;VUM:70*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T-O;6UI="@D;VYO9F8@
M/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^875T;T-O;6UI="`]("AB
M;V]L*21O;F]F9CL["B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#
M;VUM:70@=')A;G-A8W1I;VYS(&]N('1H92!C=7)R96YT(&-O;FYE8W1I;VX*
M("`@("`J"B`@("`@*B!`<F5T=7)N($1"7T524D]2(&]R($1"7T]+"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@("`@("`@)')E<W5L
M="`]($!/0TE#;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF
M("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A2
M86ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!R;VQL8F%C:R@I"@H@("`@
M+RHJ"B`@("`@*B!2;VQL(&)A8VL@86QL('5N8V]M;6ET=&5D('1R86YS86-T
M:6]N<R!O;B!T:&4@8W5R<F5N="!C;VYN96-T:6]N+@H@("`@("H*("`@("`J
M($!R971U<FX@1$)?15)23U(@;W(@1$)?3TL*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@("1R97-U;'0@/2!`3T-)4F]L
M;&)A8VLH)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<W5L
M="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R<F]R
M*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@
M("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@=&AE
M(&QA<W0@<75E<GDN"B`@("`@*B!I9B!T:&4@;&%S="!Q=65R>2!W87,@82!S
M96QE8W0L(')E='5R;G,@,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&YU;6)E
M<B!O9B!R;W=S(&%F9F5C=&5D(&)Y('1H92!L87-T('%U97)Y(&]R($1"7T52
M4D]2"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3YL87-T7W-T;70@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H*3L*("`@
M("`@("!]"B`@("`@("`@)')E<W5L="`]($!/0TE2;W=#;W5N="@D=&AI<RT^
M;&%S=%]S=&UT*3L*("`@("`@("!I9B`H)')E<W5L="`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@D=&AI
M<RT^;&%S=%]S=&UT*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y475E<GDH
M*0H*("`@(&9U;F-T:6]N(&UO9&EF>5%U97)Y*"1Q=65R>2D*("`@('L*("`@
M("`@("`O+R`B4T5,14-4(#(K,B(@;75S="!B92`B4T5,14-4(#(K,B!&4D]-
M(&1U86PB(&EN($]R86-L90H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EQS
M*E-%3$5#5"]I)RP@)'%U97)Y*2`F)@H@("`@("`@("`@("`A<')E9U]M871C
M:"@G+UQS1E)/35QS+VDG+"`D<75E<GDI*2!["B`@("`@("`@("`@("1Q=65R
M>2`N/2`G($923TT@9'5A;"<["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y3&EM
M:711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!%;75L871E('1H92!R;W<@;&EM
M:70@<W5P<&]R="!A;'1E<FEN9R!T:&4@<75E<GD*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1Q=65R>2!4:&4@<75E<GD@=&\@=')E870*("`@("`J
M($!P87)A;2!I;G0@("`@)&9R;VT@(%1H92!R;W<@=&\@<W1A<G0@=&\@9F5T
M8V@@9G)O;0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@5&AE(&]F9G-E
M=`H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(&UO9&EF:65D('%U97)Y"B`@
M("`@*@H@("`@("H@0&%U=&AO<B!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE
M="YC;VT^"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>4QI;6ET475E<GDH
M)'%U97)Y+"`D9G)O;2P@)&-O=6YT*0H@("`@>PH@("`@("`@("\O($QE="!/
M<F%C;&4@<F5T=7)N('1H92!N86UE(&]F('1H92!C;VQU;6YS(&EN<W1E860@
M;V8*("`@("`@("`O+R!C;V1I;F<@82`B:&]M92(@4U%,('!A<G-E<@H@("`@
M("`@("1Q7V9I96QD<R`](")314Q%0U0@*B!&4D]-("@D<75E<GDI(%=(15)%
M($Y53$P@/2!.54Q,(CL*("`@("`@("!I9B`H(21R97-U;'0@/2!`3T-)4&%R
M<V4H)'1H:7,M/F-O;FYE8W1I;VXL("1Q7V9I96QD<RDI('L*("`@("`@("`@
M("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<5]F:65L9',["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"%`3T-)17AE8W5T92@D<F5S=6QT+"!/0TE?1$5&055,5"DI
M('L*("`@("`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<5]F:65L9',[
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H)')E
M<W5L="D["B`@("`@("`@?0H@("`@("`@("1N8V]L<R`]($]#24YU;4-O;',H
M)')E<W5L="D["B`@("`@("`@)&-O;',@(#T@87)R87DH*3L*("`@("`@("!F
M;W(@*"`D:2`](#$[("1I(#P]("1N8V]L<SL@)&DK*R`I('L*("`@("`@("`@
M("`@)&-O;'-;72`]("<B)R`N($]#24-O;'5M;DYA;64H)')E<W5L="P@)&DI
M("X@)R(G.PH@("`@("`@('T*("`@("`@("`D9FEE;&1S(#T@:6UP;&]D92@G
M+"`G+"`D8V]L<RD["B`@("`@("`@+R\@6%A8(%1E<W0@=&AA="`H=&EP(&)Y
M($IO:&X@3&EM*0H@("`@("`@("\O:68H<')E9U]M871C:"@G+UY<<RI314Q%
M0U1<<RLO:7,G+"`D<75E<GDL("1M871C:"DI('L*("`@("`@("`O+R`@("`O
M+R!);G1R;V1U8V4@=&AE($9)4E-47U)/5U,@3W)A8VQE('%U97)Y(&]P=&EM
M:7IE<@H@("`@("`@("\O("`@("1Q=65R>2`]('-U8G-T<B@D<75E<GDL('-T
M<FQE;B@D;6%T8VA;,%TI+"!S=')L96XH)'%U97)Y*2D["B`@("`@("`@+R\@
M("`@)'%U97)Y(#T@(E-%3$5#5"`O*B`K1DE24U1?4D]74R`J+R`B("X@)'%U
M97)Y.PH@("`@("`@("\O?0H*("`@("`@("`O+R!#;VYS=')U8W0@=&AE('%U
M97)Y"B`@("`@("`@+R\@;6]R92!A=#H@:'1T<#HO+VUA<F,N=&AE86EM<V=R
M;W5P+F-O;2\_;#UP:'`M9&(F;3TY.3@S,3DU.#$P,3(Q,B9W/3(*("`@("`@
M("`O+R!097)H87!S('1H:7,@8V]U;&0@8F4@;W!T:6UI>F5D('=I=&@@=&AE
M('5S92!O9B!5;FEO;G,*("`@("`@("`D<75E<GD@/2`B4T5,14-4("1F:65L
M9',@1E)/32(N"B`@("`@("`@("`@("`@("`@(B`@*%-%3$5#5"!R;W=N=6T@
M87,@;&EN96YU;2P@)&9I96QD<R!&4D]-(BX*("`@("`@("`@("`@("`@("`B
M("`@("`@*"1Q=65R>2DB+@H@("`@("`@("`@("`@("`@("<@(%=(15)%(')O
M=VYU;2`\/2`G+B`H)&9R;VT@*R`D8V]U;G0I("X*("`@("`@("`@("`@("`@
M("`G*2!72$5212!L:6YE;G5M(#X]("<@+B`K*R1F<F]M.PH@("`@("`@(')E
M='5R;B`D<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X
M=$ED*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I
M9"!I;B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E(&ES
M(&%U=&]M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E
M;F-E+B`@1$)?17)R;W(@:68@<')O8FQE;2X*("`@("`J"B`@("`@*B!`:6YT
M97)N86P*("`@("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S
M97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q
M;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@
M("`@("`D<F5P96%T(#T@,#L*("`@("`@("!D;R!["B`@("`@("`@("`@("1T
M:&ES+3YE>'!E8W1%<G)O<BA$0E]%4E)/4E].3U-50TA404),12D["B`@("`@
M("`@("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y*")314Q%0U0@)'MS97%N
M86UE?2YN97AT=F%L($923TT@9'5A;"(I.PH@("`@("`@("`@("`D=&AI<RT^
M<&]P17AP96-T*"D["B`@("`@("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z
M.FES17)R;W(H)')E<W5L="D@)B8*("`@("`@("`@("`@("`@("1R97-U;'0M
M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U-50TA404),12D@>PH@("`@("`@
M("`@("`@("`@)')E<&5A="`](#$["B`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@
M("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@
M('T@=VAI;&4@*"1R97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1A<G(@/2`D<F5S=6QT
M+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@<F5T
M=7)N("1A<G);,%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@
M;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q
M7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@:7,@<F5T=7)N960@:68*("`@("`J("`@("`@("`@("`@("!P<F]B
M;&5M<R!A<FES92X*("`@("`J"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S
M964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D
M<V5Q7VYA;64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T
M4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YQ=65R>2@B0U)%051%(%-%455%3D-%("1[<V5Q;F%M97TB*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J
M*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O
M(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@($1"7T5R<F]R(&EF('!R;V)L96US+@H@("`@("H*("`@
M("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U
M96YC92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S
M97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH(D123U`@4T51545.0T4@)'MS
M97%N86UE?2(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&]C:3A2
M86ES945R<F]R*"D*"B`@("`O*BH*("`@("`J($=A=&AE<B!I;F9O<FUA=&EO
M;B!A8F]U="!A;B!E<G)O<BP@=&AE;B!U<V4@=&AA="!I;F9O('1O(&-R96%T
M92!A"B`@("`@*B!$0B!E<G)O<B!O8FIE8W0@86YD(&9I;F%L;'D@<F5T=7)N
M('1H870@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2`@:6YT96=E<B`@
M)&5R<FYO("!014%2(&5R<F]R(&YU;6)E<B`H=7-U86QL>2!A($1"(&-O;G-T
M86YT*2!I9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&UA;G5A
M;&QY(')A:7-I;F<@86X@97)R;W(*("`@("`J($!R971U<FX@;V)J96-T("!$
M0B!E<G)O<B!O8FIE8W0*("`@("`J($!S964@1$)?8V]M;6]N.CIE<G)O<D-O
M9&4H*0H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!O8VDX4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@
M("`@("`@)&5R<F]R(#T@0$]#245R<F]R*"1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1T:&ES+3YE
M<G)O<D-O9&4H)&5R<F]R6R=C;V1E)UTI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@)&5R<F]R6R=M
M97-S86=E)UTI.PH@("`@("`@('T@96QS96EF("AI<U]R97-O=7)C92@D97)R
M;F\I*2!["B`@("`@("`@("`@("1E<G)O<B`]($!/0TE%<G)O<B@D97)R;F\I
M.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'1H:7,M
M/F5R<F]R0V]D92@D97)R;W);)V-O9&4G72DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+"`D97)R;W);
M)VUE<W-A9V4G72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D=&AI<RT^97)R;W)#;V1E*"1E<G)N;RDI.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!Q=65R>2!N965D960@=&\@9V5T('-O
M;64@8F%C:V5N9"!I;F9O"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E(%=H
M870@:VEN9"!O9B!I;F9O('EO=2!W86YT('1O(')E=')I979E"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R!4:&4@4U%,('%U97)Y('-T<FEN9PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G9713<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@
M("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C87-E("=T86)L97,G
M.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@=&%B;&5?;F%M92!&
M4D]-('5S97)?=&%B;&5S)SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT
M('-E="X*("`@("`J"B`@("`@*B!.3U1%.B!O;FQY('-U<'!O<G1S("=T86)L
M92<@86YD("=F;&%G<R<@:68@/'9A<CXD<F5S=6QT/"]V87(^"B`@("`@*B!I
M<R!A('1A8FQE(&YA;64N"B`@("`@*@H@("`@("H@3D]413H@9FQA9W,@=V]N
M)W0@8V]N=&%I;B!I;F1E>"!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C
M="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@
M=&%B;&4*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A
M('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A
M;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R97%U
M97-T960*("`@("`J("`@("`@("`@("`@("`@(&]R(&%N(&5R<F]R(&]B:F5C
M="!I9B!S;VUE=&AI;F<@:7,@=W)O;F<*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L
M94EN9F\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L
M="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R
M=F%L)SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]S=')I;F<H)')E<W5L
M="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#<F5A=&4@
M82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@("1R97-U;'0@/2!S=')T;W5P<&5R*"1R97-U;'0I.PH@
M("`@("`@("`@("`D<5]F:65L9',@/2`G4T5,14-4(&-O;'5M;E]N86UE+"!D
M871A7W1Y<&4L(&1A=&%?;&5N9W1H+"`G"B`@("`@("`@("`@("`@("`@("`@
M("`@("X@)VYU;&QA8FQE("<*("`@("`@("`@("`@("`@("`@("`@("`@+B`G
M1E)/32!U<V5R7W1A8E]C;VQU;6YS("<*("`@("`@("`@("`@("`@("`@("`@
M("`@+B`B5TA%4D4@=&%B;&5?;F%M93TG)')E<W5L="<@3U)$15(@0ED@8V]L
M=6UN7VED(CL*"B`@("`@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%?
M9FEE;&1S.PH*("`@("`@("`@("`@:68@*"$D<W1M="`]($!/0TE087)S92@D
M=&AI<RT^8V]N;F5C=&EO;BP@)'%?9FEE;&1S*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<BA$0E]%4E)/4E].145$
M7TU/4D5?1$%402D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%`
M3T-)17AE8W5T92@D<W1M="P@3T-)7T1%1D%53%0I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R<F]R*"1S=&UT*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("!W
M:&EL92`H0$]#249E=&-H*"1S=&UT*2D@>PH@("`@("`@("`@("`@("`@)')E
M<ULD:5U;)W1A8FQE)UT@/2`D8V%S95]F=6YC*"1R97-U;'0I.PH@("`@("`@
M("`@("`@("`@)')E<ULD:5U;)VYA;64G72`@/2`D8V%S95]F=6YC*$!/0TE2
M97-U;'0H)'-T;70L(#$I*3L*("`@("`@("`@("`@("`@("1R97-;)&E=6R=T
M>7!E)UT@(#T@0$]#25)E<W5L="@D<W1M="P@,BD["B`@("`@("`@("`@("`@
M("`D<F5S6R1I75LG;&5N)UT@("`]($!/0TE297-U;'0H)'-T;70L(#,I.PH@
M("`@("`@("`@("`@("`@)')E<ULD:5U;)V9L86=S)UT@/2`H0$]#25)E<W5L
M="@D<W1M="P@-"D@/3T@)TXG*2`_("=N;W1?;G5L;"<@.B`G)SL*"B`@("`@
M("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*
M("`@("`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N
M86UE)UU=(#T@)&D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@
M("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD<F5S6R1I75LG
M=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1R97-;)VYU;5]F:65L9',G72`]("1I.PH@("`@("`@("`@
M("!`3T-)1G)E95-T871E;65N="@D<W1M="D["@H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@
M("`@("`@("`@("`@("`O*@H@("`@("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!R97-U;'0@;V)J96-T+@H@("`@("`@("`@("`@("`@("H@
M17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@
M("`@("`@("`@("`@*B\*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D<F5S
M=6QT+3YR97-U;'0["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`O*@H@("`@("`@("`@("`@("`@("H@14Q312P@<')O8F%B;'D@<F5C
M96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@
M("`@("`@("`J($1E<')I8V%T960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y
M(&]N;'DN"B`@("`@("`@("`@("`@("`@*B\*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*"1R97-U;'0@/3T]("1T:&ES+3YL87-T7W-T;70I('L*
M("`@("`@("`@("`@("`@("1C;W5N="`]($!/0TE.=6U#;VQS*"1R97-U;'0I
M.PH*("`@("`@("`@("`@("`@(&9O<B`H)&D],#L@)&D\)&-O=6YT.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@)')E<ULD:5U;)W1A8FQE)UT@/2`G
M)SL*("`@("`@("`@("`@("`@("`@("`D<F5S6R1I75LG;F%M92==("`]("1C
M87-E7V9U;F,H0$]#24-O;'5M;DYA;64H)')E<W5L="P@)&DK,2DI.PH@("`@
M("`@("`@("`@("`@("`@("1R97-;)&E=6R=T>7!E)UT@(#T@0$]#24-O;'5M
M;E1Y<&4H)')E<W5L="P@)&DK,2D["B`@("`@("`@("`@("`@("`@("`@)')E
M<ULD:5U;)VQE;B==("`@/2!`3T-)0V]L=6UN4VEZ92@D<F5S=6QT+"`D:2LQ
M*3L*("`@("`@("`@("`@("`@("`@("`D<F5S6R1I75LG9FQA9W,G72`]("<G
M.PH*("`@("`@("`@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.
M1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("`@("`@("`@)')E<ULG;W)D
M97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),
M14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=
M6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G
M72`]("1C;W5N=#L*"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!
M4$%"3$4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@=F%R
M:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*
M("H@16YD.@H@*B\*"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+T1"+VEF>"YP:'``````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#0R,38T`#$P-#$W,S8S,#`V`#`Q-S$S,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!4;VUA<R!6+E8N
M0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($UA:6YT86EN97(Z($1A;FEE;"!#;VYV:7-S;W(@/&1A
M;FEE;&-`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@:69X+G!H<"QV
M(#$N-#4@,C`P-"\P,B\Q.2`Q-3HS-#HP,2!D86YI96QC($5X<"`D"@H*+R\@
M3&5G96YD.@HO+R!&;W(@;6]R92!I;F9O(&]N($EN9F]R;6EX(&5R<F]R<R!S
M964Z"B\O(&AT='`Z+R]W=W<N:6YF;W)M:7@N8V]M+V%N<W=E<G,O96YG;&ES
M:"]I97)R;W)S+FAT;0HO+PHO+R!43T1/.@HO+R`@+2!S970@;F5E9&5D(&5N
M=B!);F9O<FUI>"!V87)S(&]N(&-O;FYE8W0*+R\@("T@:6UP;&5M96YT(&YA
M=&EV92!P<F5P87)E+V5X96-U=&4*"@IR97%U:7)E7V]N8V4@)T1"+V-O;6UO
M;BYP:'`G.PH*+RHJ"B`J($1A=&%B87-E(&EN9&5P96YD96YT('%U97)Y(&EN
M=&5R9F%C92!D969I;FET:6]N(&9O<B!02%`G<R!);F9O<FUI>`H@*B!E>'1E
M;G-I;VXN"B`J"B`J($!P86-K86=E("!$0@H@*B!`=F5R<VEO;B`@)$ED.B!I
M9G@N<&AP+'8@,2XT-2`R,#`T+S`R+S$Y(#$U.C,T.C`Q(&1A;FEE;&,@17AP
M("0*("H@0&-A=&5G;W)Y($1A=&%B87-E"B`J($!A=71H;W(@("!4;VUA<R!6
M+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J+PIC;&%S<R!$0E]I9G@@97AT
M96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("!V
M87(@)&-O;FYE8W1I;VX["B`@("!V87(@)&%F9F5C=&5D(#T@,#L*("`@('9A
M<B`D9'-N(#T@87)R87DH*3L*("`@('9A<B`D=')A;G-A8W1I;VY?;W!C;W5N
M="`](#`["B`@("!V87(@)&%U=&]C;VUM:70@/2!T<G5E.PH@("`@=F%R("1F
M971C:&UO9&4@/2!$0E]&151#2$U/1$5?3U)$15)%1#L@+RH@1&5F875L="!F
M971C:"!M;V1E("HO"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T
M;W(*"B`@("!F=6YC=&EO;B!$0E]I9G@H*0H@("`@>PH@("`@("`@("1T:&ES
M+3YP:'!T>7!E(#T@)VEF>"<["B`@("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@
M)VEF>"<["B`@("`@("`@)'1H:7,M/F9E871U<F5S(#T@87)R87DH"B`@("`@
M("`@("`@("=P<F5P87)E)R`]/B!F86QS92P*("`@("`@("`@("`@)W!C;VYN
M96-T)R`]/B!T<G5E+`H@("`@("`@("`@("`G=')A;G-A8W1I;VYS)R`]/B!T
M<G5E+`H@("`@("`@("`@("`G;&EM:70G(#T^("=E;75L871E)PH@("`@("`@
M("D["B`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@
M("`@("`@("`@)RTR,#$G("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@
M("`@("`@)RTR,#8G("`@(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@
M("`@("`@("`G+3(Q-R<@("`@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@
M("`@("`@("`@("<M,C,Y)R`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@
M("`@("`@("`@("`G+3(U,R<@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@
M("`@("`@("`G+3(Y,B<@("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?
M3E5,3"P*("`@("`@("`@("`@)RTS,3`G("`@(#T^($1"7T524D]27T%,4D5!
M1%E?15A)4U13+`H@("`@("`@("`@("`G+3,R.2<@("`@/3X@1$)?15)23U)?
M3D]$0E-%3$5#5$5$+`H@("`@("`@("`@("`G+3,T-B<@("`@/3X@1$)?15)2
M3U)?0T].4U1204E.5"P*("`@("`@("`@("`@)RTS.#8G("`@(#T^($1"7T52
M4D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("<M,SDQ)R`@
M("`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@("`@
M("`G+34U-"<@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`G
M+38Y,2<@("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`@("`@
M)RTW,#,G("`@(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@
M("`@("`@("`@("<M,3(P-"<@("`]/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L
M"B`@("`@("`@("`@("<M,3(P-2<@("`]/B!$0E]%4E)/4E])3E9!3$E$7T1!
M5$4L"B`@("`@("`@("`@("<M,3(P-B<@("`]/B!$0E]%4E)/4E])3E9!3$E$
M7T1!5$4L"B`@("`@("`@("`@("<M,3(P.2<@("`]/B!$0E]%4E)/4E])3E9!
M3$E$7T1!5$4L"B`@("`@("`@("`@("<M,3(Q,"<@("`]/B!$0E]%4E)/4E])
M3E9!3$E$7T1!5$4L"B`@("`@("`@("`@("<M,3(Q,B<@("`]/B!$0E]%4E)/
M4E])3E9!3$E$7T1!5$4L"B`@("`@("`@("`@("<M,3(Q,R<@("`]/B!$0E]%
M4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@0V]N
M;F5C="!T;R!A(&1A=&%B87-E(&%N9"!L;V<@:6X@87,@=&AE('-P96-I9FEE
M9"!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2`D9'-N('1H92!D871A('-O
M=7)C92!N86UE("AS964@1$(Z.G!A<G-E1%-.(&9O<B!S>6YT87@I"B`@("`@
M*B!`<&%R86T@)'!E<G-I<W1E;G0@*&]P=&EO;F%L*2!W:&5T:&5R('1H92!C
M;VYN96-T:6]N('-H;W5L9`H@("`@("H@("`@("`@(&)E('!E<G-I<W1E;G0*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!$0E]/2R!O;B!S=6-C97-S+"!A
M($1"(&5R<F]R(&-O9&4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VYN96-T*"1D<VYI;F9O+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@
M>PH@("`@("`@(&EF("@A1$(Z.F%S<V5R=$5X=&5N<VEO;B@G:6YF;W)M:7@G
M*2`F)@H@("`@("`@("`@("`A1$(Z.F%S<V5R=$5X=&5N<VEO;B@G26YF;W)M
M:7@G*2D*("`@("`@("!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VYI;F9O.PH@("`@("`@("1D
M8FAO<W0@/2`D9'-N:6YF;ULG:&]S='-P96,G72`_("=`)R`N("1D<VYI;F9O
M6R=H;W-T<W!E8R==(#H@)R<["B`@("`@("`@)&1B;F%M92`]("1D<VYI;F9O
M6R=D871A8F%S92==(#\@)&1S;FEN9F];)V1A=&%B87-E)UT@+B`D9&)H;W-T
M(#H@)R<["B`@("`@("`@)'5S97(@/2`D9'-N:6YF;ULG=7-E<FYA;64G72`_
M("1D<VYI;F9O6R=U<V5R;F%M92==(#H@)R<["B`@("`@("`@)'!W(#T@)&1S
M;FEN9F];)W!A<W-W;W)D)UT@/R`D9'-N:6YF;ULG<&%S<W=O<F0G72`Z("<G
M.PH*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@
M)VEF>%]P8V]N;F5C="<@.B`G:69X7V-O;FYE8W0G.PH*("`@("`@("`D=&AI
M<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D9&)N86UE+"`D
M=7-E<BP@)'!W*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YC
M;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEF>')A
M:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!,;V<@;W5T(&%N
M9"!D:7-C;VYN96-T(&9R;VT@=&AE(&1A=&%B87-E+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF(&YO="!C
M;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@("1R970@/2!`:69X7V-L;W-E*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@
M("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9"!A('%U97)Y('1O
M($EN9F]R;6EX(&%N9"!R971U<FX@=&AE(')E<W5L=',@87,@80H@("`@("H@
M26YF;W)M:7@@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@)'%U97)Y('1H92!344P@<75E<GD*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="!R971U<FYS(&$@=F%L:60@26YF;W)M:7@@<F5S=6QT(&9O<B!S
M=6-C97-S9G5L(%-%3$5#5`H@("`@("H@<75E<FEE<RP@1$)?3TL@9F]R(&]T
M:&5R('-U8V-E<W-F=6P@<75E<FEE<RX@($$@1$(@97)R;W(@8V]D90H@("`@
M("H@:7,@<F5T=7)N960@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1I<VUA;FEP
M(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q
M=65R>2`]("1Q=65R>3L*("`@("`@("`D=&AI<RT^869F96-T960@("`](&YU
M;&P["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H4T5,14-4*2]I)RP@)'%U
M97)Y*2D@>R`@("`O+U1%4U1-13H@57-E("%$0CHZ:7--86YI<"@I/PH@("`@
M("`@("`@("`O+R!T:&4@<V-R;VQL(&ES(&YE961E9"!F;W(@9F5T8VAI;F<@
M86)S;VQU=&4@<F]W(&YU;6)E<G,*("`@("`@("`@("`@+R\@:6X@82!S96QE
M8W0@<75E<GD@<F5S=6QT"B`@("`@("`@("`@("1R97-U;'0@/2!`:69X7W%U
M97)Y*"1Q=65R>2P@)'1H:7,M/F-O;FYE8W1I;VXL($E&6%]30U)/3$PI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/F%U=&]C
M;VUM:70@)B8@)&ES;6%N:7`I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@)')E<W5L="`]($!I9GA?<75E<GDH)T)%1TE.(%=/4DLG+"`D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M:69X<F%I<V5%<G)O<B@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT*RL["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L
M="`]($!I9GA?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@?0H@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FEF>')A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/F%F9F5C=&5D(#T@:69X7V%F9F5C=&5D7W)O=W,H)')E<W5L
M="D["B`@("`@("`@+R\@1&5T97)M:6YE('=H:6-H('%U97)I97,@<VAO=6QD
M(')E='5R;B!D871A+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U;&0@<F5T
M=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*("`@("`@("!I9B`H<')E9U]M871C
M:"@G+RA314Q%0U0I+VDG+"`D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("`O+R!86%@@5&5S=&UE.B!F
M<F5E(')E<W5L=',@:6YS:61E(&$@=')A;G-A8W1I;VX*("`@("`@("`O+R!M
M87D@8V%U<V4@=&\@<W1O<"!I="!A;F0@8V]M;6ET('1H92!W;W)K/PH*("`@
M("`@("`O+R!297-U;'0@:&%S('1O(&)E(&9R965D(&5V96X@=VET:"!A(&EN
M<V5R="!O<B!U<&1A=&4*("`@("`@("!I9GA?9G)E95]R97-U;'0H)')E<W5L
M="D["@H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@
M=&AE(&EN=&5R;F%L(&EF>"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A
M=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@
M9F)S<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('1R=64@:68@82!R97-U;'0@
M:7,@879A:6QA8FQE(&]T:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@
M("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A
M9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R
M(&]F(')O=W,@869F96-T960@8GD@=&AE(&QA<W0@<75E<GDN"B`@("`@*B!I
M9B!T:&4@;&%S="!Q=65R>2!W87,@82!S96QE8W0L(')E='5R;G,@,"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y
M('1H92!L87-T('%U97)Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D
M4F]W<R@I"B`@("!["B`@("`@("`@:68@*$1".CII<TUA;FEP*"1T:&ES+3YL
M87-T7W%U97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F%F9F5C
M=&5D.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`P.PH@
M("`@("`@('T*("`@("`@("`*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@1F5T8V@@82!R;W<@86YD
M(&EN<V5R="!T:&4@9&%T82!I;G1O(&%N(&5X:7-T:6YG(&%R<F%Y+@H@("`@
M("H*("`@("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A
M('1H97)E:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U
M;'0Z.F9E=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*
M("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('%U97)Y(')E<W5L
M="!I9&5N=&EF:65R"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@("`@
M("`H<F5F97)E;F-E*2!A<G)A>2!W:&5R92!D871A(&9R;VT@=&AE(')O=PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<VAO=6QD(&)E('!L
M86-E9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H
M92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P
M87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E
M=&-H"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!$0E]/2R!O;B!S=6-C
M97-S+"!.54Q,('=H96X@96YD(&]F(')E<W5L="!S970@:7,*("`@("`J("`@
M("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@
M("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U
M;'0L("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M/6YU;&PI"B`@("!["B`@
M("`@("`@:68@*"@D<F]W;G5M("$]/2!N=6QL*2`F)B`H)')O=VYU;2`\(#`I
M*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@
M("!I9B`H)')O=VYU;2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`O*@H@("`@
M("`@("`@("`@*B!%=F5N('1H;W5G:"!F971C:%]R;W<H*2!S:&]U;&0@<F5T
M=7)N('1H92!N97AT(')O=R`@:68*("`@("`@("`@("`@("H@)')O=VYU;2!I
M<R!N=6QL+"!I="!D;V5S;B=T(&EN(&%L;"!C87-E<RX@($)U9R`U.3@N"B`@
M("`@("`@("`@("`J+PH@("`@("`@("`@("`D<F]W;G5M(#T@)TY%6%0G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($EN9&5X('-T87)T<R!A
M="!R;W<@,2P@=6YL:6ME(&UO<W0@1$)-4R=S('-T87)T:6YG(&%T(#`N"B`@
M("`@("`@("`@("1R;W=N=6TK*SL*("`@("`@("!]"B`@("`@("`@:68@*"$D
M87)R(#T@0&EF>%]F971C:%]R;W<H)')E<W5L="P@)')O=VYU;2DI('L*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D
M9F5T8VAM;V1E("$]/2!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@("`@
M("`@)&D],#L*("`@("`@("`@("`@)&]R9&5R(#T@87)R87DH*3L*("`@("`@
M("`@("`@9F]R96%C:"`H)&%R<B!A<R`D=F%L*2!["B`@("`@("`@("`@("`@
M("`D;W)D97);)&DK*UT@/2`D=F%L.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1A<G(@/2`D;W)D97(["B`@("`@("`@?2!E;'-E:68@*"1F971C:&UO
M9&4@/3T@1$)?1D540TA-3T1%7T%34T]#("8F"B`@("`@("`@("`@("`@("`@
M("1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)
M5%E?3$]715)#05-%*0H@("`@("`@('L*("`@("`@("`@("`@)&%R<B`](&%R
M<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==
M("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M
M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!N=6U2;W=S*"D*"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T52
M4D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@;G5M8F5R(&]F
M(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T+@H@("`@("H*("`@("`J($!P87)A
M;2`D<F5S=6QT($EN9F]R;6EX(')E<W5L="!I9&5N=&EF:65R"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@=&AE(&YU;6)E<B!O9B!C;VQU;6YS('!E<B!R
M;W<@:6X@)')E<W5L=`H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R
M97-U;'0I"B`@("!["B`@("`@("`@:68@*"$D8V]L<R`]($!I9GA?;G5M7V9I
M96QD<R@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEF
M>')A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*
M("`@("\J*@H@("`@("H@1G)E92!T:&4@:6YT97)N86P@<F5S;W5R8V5S(&%S
M<V]C:6%T960@=VET:"`D<F5S=6QT+@H@("`@("H*("`@("`J($!P87)A;2`D
M<F5S=6QT($EN9F]R;6EX(')E<W5L="!I9&5N=&EF:65R"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E
M<W5L="!I<R!I;G9A;&ED"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R965297-U
M;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&EF>%]F<F5E7W)E
M<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A
M=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L92]D:7-A8FQE(&%U
M=&]M871I8R!C;VUM:71S"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#;VUM
M:70H)&]N;V9F(#T@=')U92D*("`@('L*("`@("`@("`O+R!86%@@:68@)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P+"!W92!S:&]U;&0@<')O8F%B
M;'D*("`@("`@("`O+R!I<W-U92!A('=A<FYI;F<@:&5R92X*("`@("`@("`D
M=&AI<RT^875T;V-O;6UI="`]("1O;F]F9B`_('1R=64@.B!F86QS93L*("`@
M("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@("`J($-O;6UI="!T:&4@8W5R<F5N
M="!T<F%N<V%C=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M;6ET*"D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@
M/B`P*2!["B`@("`@("`@("`@("1R97-U;'0@/2!`:69X7W%U97)Y*"=#3TU-
M250@5T]22R<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:69X
M4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!R
M;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2;VQL(&)A8VL@*'5N9&\I('1H
M92!C=7)R96YT('1R86YS86-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M;VQL8F%C:R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@0&EF>%]Q
M=65R>2@G4D],3$)!0TL@5T]22R<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@
M("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@
M("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^:69X4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!I9GAR86ES945R<F]R*"D*"B`@("`O*BH*("`@("`J($=A
M=&AE<B!I;F9O<FUA=&EO;B!A8F]U="!A;B!E<G)O<BP@=&AE;B!U<V4@=&AA
M="!I;F9O('1O(&-R96%T92!A"B`@("`@*B!$0B!E<G)O<B!O8FIE8W0@86YD
M(&9I;F%L;'D@<F5T=7)N('1H870@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2`@:6YT96=E<B`@)&5R<FYO("!014%2(&5R<F]R(&YU;6)E<B`H=7-U
M86QL>2!A($1"(&-O;G-T86YT*2!I9@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&UA;G5A;&QY(')A:7-I;F<@86X@97)R;W(*("`@("`J($!R
M971U<FX@;V)J96-T("!$0B!E<G)O<B!O8FIE8W0*("`@("`J($!S964@97)R
M;W).871I=F4H*0H@("`@("H@0'-E92!E<G)O<D-O9&4H*0H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!I9GAR86ES945R<F]R*"1E<G)N;R`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D97)R;F\@/2`D
M=&AI<RT^97)R;W)#;V1E*&EF>%]E<G)O<B@I*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU
M;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M97)R;W).871I=F4H*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M97)R;W)#;V1E*"D*"B`@("`O*BH*("`@("`J($UA<"!N871I=F4@97)R;W(@
M8V]D97,@=&\@1$(G<R!P;W)T86)L92!O;F5S+@H@("`@("H*("`@("`J(%)E
M<75I<F5S('1H870@=&AE($1"(&EM<&QE;65N=&%T:6]N)W,@8V]N<W1R=6-T
M;W(@9FEL;',*("`@("`J(&EN('1H92`\=F%R/B1E<G)O<F-O9&5?;6%P/"]V
M87(^('!R;W!E<G1Y+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D
M;F%T:79E8V]D92`@97)R;W(@8V]D92!R971U<FYE9"!B>2!T:&4@9&%T86)A
M<V4*("`@("`J($!R971U<FX@:6YT(&$@<&]R=&%B;&4@1$(@97)R;W(@8V]D
M92P@;W(@1$)?15)23U(@:68@=&AI<R!$0@H@("`@("H@:6UP;&5M96YT871I
M;VX@:&%S(&YO(&UA<'!I;F<@9F]R('1H92!G:79E;B!E<G)O<B!C;V1E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<D-O9&4H)&YA=&EV96-O9&4I"B`@
M("!["B`@("`@("`@:68@*&5R96<H)U-13$-/1$4]*"XJ*5TG+"`D;F%T:79E
M8V]D92P@)&UA=&-H*2D@>PH@("`@("`@("`@("`D8V]D92`]("1M871C:%LQ
M73L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YE<G)O<F-O9&5?;6%P
M6R1C;V1E72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^97)R
M;W)C;V1E7VUA<%LD8V]D95T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N($1"7T524D]2.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M;F%T:79E(&5R<F]R(&UE<W-A9V4@;V8@=&AE(&QA<W0@97)R;W(@*&EF(&%N
M>2D@=&AA=`H@("`@("H@;V-C=7)E9"!O;B!T:&4@8W5R<F5N="!C;VYN96-T
M:6]N+@H@("`@("H*("`@("`J($!R971U<FX@:6YT(&YA=&EV92!);F9O<FUI
M>"!E<G)O<B!C;V1E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E
M*"D*("`@('L*("`@("`@("!R971U<FX@:69X7V5R<F]R*"D@+B`G("<@+B!I
M9GA?97)R;W)M<V<H*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M9713<&5C:6%L475E<GDH*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<75E<GD@;F5E9&5D('1O(&=E="!S;VUE(&)A8VME;F0@:6YF;PH@("`@("H@
M0'!A<F%M('-T<FEN9R`D='EP92!7:&%T(&MI;F0@;V8@:6YF;R!Y;W4@=V%N
M="!T;R!R971R:65V90H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(%-13"!Q
M=65R>2!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U
M97)Y*"1T>7!E*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@
M("`@("`@("`@8V%S92`G=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E='5R
M;B`G<V5L96-T('1A8FYA;64@9G)O;2!S>7-T86)L97,@=VAE<F4@=&%B:60@
M/CT@,3`P)SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I
M;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT('-E="X*("`@
M("`J"B`@("`@*B!.3U1%.B!O;FQY('-U<'!O<G1S("=T86)L92<@:68@/'9A
M<CXD<F5S=6QT/"]V87(^(&ES(&$@=&%B;&4@;F%M92X*("`@("`J"B`@("`@
M*B!)9B!A;F%L>7II;F<@82!Q=65R>2!R97-U;'0@86YD('1H92!R97-U;'0@
M:&%S(&1U<&QI8V%T92!F:65L9"!N86UE<RP*("`@("`J(&%N(&5R<F]R('=I
M;&P@8F4@<F%I<V5D('-A>6EN9PH@("`@("H@/'-A;7`^8V%N)W0@9&ES=&EN
M9W5I<V@@9'5P;&EC871E(&9I96QD(&YA;65S/"]S86UP/BX*("`@("`J"B`@
M("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT
M(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE
M(&]F(&$@=&%B;&4*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D
M92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO
M;B!R97%U97-T960*("`@("`J("`@("`@("`@("`@("`@(&]R(&%N(&5R<F]R
M(&]B:F5C="!I9B!S;VUE=&AI;F<@:7,@=W)O;F<*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S:6YC92`Q+C8N,`H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@
M("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@
M82!R97-U;'0@;V)J96-T+@H@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R
M97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@
M("`@("`@("`@("1I9"`]("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@
M)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!](&5L<V5I9B`H:7-?<W1R
M:6YG*"1R97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J
M(%!R;V)A8FQY(')E8V5I=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@
M("H@0W)E871E(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@
M("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2!`:69X7W%U97)Y*")314Q%
M0U0@*B!&4D]-("1R97-U;'0@5TA%4D4@,3TP(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@
M("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E
M<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y
M(&ET+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L
M=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FEF>%)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-
M3U)%7T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@)&9L9',@/2!`:69X7V9I
M96QD<')O<&5R=&EE<R@D:60I.PH@("`@("`@("1C;W5N="`]($!I9GA?;G5M
M7V9I96QD<R@D:60I.PH*("`@("`@("!I9B`H8V]U;G0H)&9L9',I("$]("1C
M;W5N="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(F-A;B=T(&1I<W1I;F=U:7-H(&1U<&QI8V%T92!F:65L9"!N86UE<R(I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@
M("`@("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@
M('T*"B`@("`@("`@)&D@/2`P.PH@("`@("`@("\O(&UA9&4@=&AI<R!)1B!D
M=64@=&\@<&5R9F]R;6%N8V4@*&]N92!I9B!I<R!F87-T97(@=&AA;B`D8V]U
M;G0@:68G<RD*("`@("`@("!I9B`H(21M;V1E*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1F;&1S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("`D<')O<',@/2!E>'!L;V1E*"<[)RP@)'9A;'5E*3L*"B`@("`@("`@
M("`@("`@("`D<F5S6R1I75LG=&%B;&4G72`]("1G;W1?<W1R:6YG(#\@)&-A
M<V5?9G5N8R@D<F5S=6QT*2`Z("<G.PH@("`@("`@("`@("`@("`@)')E<ULD
M:5U;)VYA;64G72`@/2`D8V%S95]F=6YC*"1K97DI.PH@("`@("`@("`@("`@
M("`@)')E<ULD:5U;)W1Y<&4G72`@/2`D<')O<'-;,%T["B`@("`@("`@("`@
M("`@("`D<F5S6R1I75LG;&5N)UT@("`]("1P<F]P<ULQ73L*("`@("`@("`@
M("`@("`@("1R97-;)&E=6R=F;&%G<R==(#T@)'!R;W!S6S1=(#T]("=.)R`_
M("=N;W1?;G5L;"<@.B`G)SL*("`@("`@("`@("`@("`@("1I*RL["B`@("`@
M("`@("`@('T*"B`@("`@("`@?2!E;'-E('L@+R\@9G5L;`H@("`@("`@("`@
M("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0["@H@("`@("`@("`@("!F
M;W)E86-H("@D9FQD<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@
M("`@("`@)'!R;W!S(#T@97AP;&]D92@G.R<L("1V86QU92D["@H@("`@("`@
M("`@("`@("`@)')E<ULD:5U;)W1A8FQE)UT@/2`D9V]T7W-T<FEN9R`_("1C
M87-E7V9U;F,H)')E<W5L="D@.B`G)SL*("`@("`@("`@("`@("`@("1R97-;
M)&E=6R=N86UE)UT@(#T@)&-A<V5?9G5N8R@D:V5Y*3L*("`@("`@("`@("`@
M("`@("1R97-;)&E=6R=T>7!E)UT@(#T@)'!R;W!S6S!=.PH@("`@("`@("`@
M("`@("`@)')E<ULD:5U;)VQE;B==("`@/2`D<')O<'-;,5T["B`@("`@("`@
M("`@("`@("`D<F5S6R1I75LG9FQA9W,G72`]("1P<F]P<ULT72`]/2`G3B<@
M/R`G;F]T7VYU;&PG(#H@)R<["@H@("`@("`@("`@("`@("`@:68@*"1M;V1E
M("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`@("`@
M)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"
M3$5)3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("`@("`D<F5S
M6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N
M86UE)UU=(#T@)&D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D:2LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!F
M<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O;B!A('1A
M8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@("`@($!I
M9GA?9G)E95]R97-U;'0H)&ED*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1R97,["B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@*B!,;V-A;"!V87)I
M86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@
M*B!%;F0Z"B`J+PH*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+W!G<W%L
M+G!H<```````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#8U,C4Q`#$P-#$W,S8S,#`V`#`Q-S0W-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A
M;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!F;VQD;65T:&]D/6UA<FME
M<CH@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0
M(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E
M;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R<SH@4G5I($AI<F]K87=A(#QH:7)O:V%W84!P:'`N
M;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@
M("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!-86EN=&%I;F5R.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D
M260Z('!G<W%L+G!H<"QV(#$N-S$@,C`P-"\P,B\Q."`R,SHP-SHQ,"!D86YI
M96QC($5X<"`D"@IR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ
M"B`J($1A=&%B87-E(&EN9&5P96YD96YT('%U97)Y(&EN=&5R9F%C92!D969I
M;FET:6]N(&9O<B!02%`G<R!0;W-T9W)E4U%,"B`J(&5X=&5N<VEO;BX*("H*
M("H@0'!A8VMA9V4@($1""B`J($!V97)S:6]N("`D260Z('!G<W%L+G!H<"QV
M(#$N-S$@,C`P-"\P,B\Q."`R,SHP-SHQ,"!D86YI96QC($5X<"`D"B`J($!C
M871E9V]R>2!$871A8F%S90H@*B!`875T:&]R("`@4G5I($AI<F]K87=A(#QH
M:7)O:V%W84!P:'`N;F5T/@H@*B!`875T:&]R("`@4W1I9R!"86MK96X@/'-S
M8D!P:'`N;F5T/@H@*B\*8VQA<W,@1$)?<&=S<6P@97AT96YD<R!$0E]C;VUM
M;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("!V87(@)&-O;FYE8W1I
M;VX["B`@("!V87(@)'!H<'1Y<&4L("1D8G-Y;G1A>#L*("`@('9A<B`D<')E
M<&%R95]T;VME;G,@/2!A<G)A>2@I.PH@("`@=F%R("1P<F5P87)E7W1Y<&5S
M(#T@87)R87DH*3L*("`@('9A<B`D=')A;G-A8W1I;VY?;W!C;W5N="`](#`[
M"B`@("!V87(@)&1S;B`](&%R<F%Y*"D["B`@("!V87(@)')O=R`](&%R<F%Y
M*"D["B`@("!V87(@)&YU;5]R;W=S(#T@87)R87DH*3L*("`@('9A<B`D869F
M96-T960@/2`P.PH@("`@=F%R("1A=71O8V]M;6ET(#T@=')U93L*("`@('9A
M<B`D9F5T8VAM;V1E(#T@1$)?1D540TA-3T1%7T]21$52140["@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("!F=6YC=&EO;B!$0E]P
M9W-Q;"@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@("`@
M("`@("1T:&ES+3YP:'!T>7!E(#T@)W!G<W%L)SL*("`@("`@("`D=&AI<RT^
M9&)S>6YT87@@/2`G<&=S<6PG.PH@("`@("`@("1T:&ES+3YF96%T=7)E<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`G<')E<&%R92<@/3X@9F%L<V4L"B`@("`@
M("`@("`@("=P8V]N;F5C="<@/3X@=')U92P*("`@("`@("`@("`@)W1R86YS
M86-T:6]N<R<@/3X@=')U92P*("`@("`@("`@("`@)VQI;6ET)R`]/B`G86QT
M97(G"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<"`]
M(&%R<F%Y*`H@("`@("`@("D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O(&$@9&%T
M86)A<V4@86YD(&QO9R!I;B!A<R!T:&4@<W!E8VEF:65D('5S97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M("1D<VX@=&AE(&1A=&$@<V]U<F-E(&YA;64@*'-E
M92!$0CHZ<&%R<V5$4TX@9F]R('-Y;G1A>"D*("`@("`J($!P87)A;2`D<&5R
M<VES=&5N="`H;W!T:6]N86PI('=H971H97(@=&AE(&-O;FYE8W1I;VX@<VAO
M=6QD"B`@("`@*B`@("`@("`@8F4@<&5R<VES=&5N=`H@("`@("H*("`@("`J
M($!R971U<FX@:6YT($1"7T]+(&]N('-U8V-E<W,L(&$@1$(@97)R;W(@8V]D
M92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D
M<VYI;F9O+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("@A1$(Z.F%S<V5R=$5X=&5N<VEO;B@G<&=S<6PG*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].
M7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@
M)&1S;FEN9F\["B`@("`@("`@)'!R;W1O8V]L(#T@)&1S;FEN9F];)W!R;W1O
M8V]L)UT@/R`D9'-N:6YF;ULG<')O=&]C;VPG72`Z("=T8W`G.PH@("`@("`@
M("1C;VYN<W1R(#T@)R<["@H@("`@("`@(&EF("@D<')O=&]C;VP@/3T@)W1C
M<"<I('L*("`@("`@("`@("`@:68@*"1D<VYI;F9O6R=H;W-T<W!E8R==*2![
M"B`@("`@("`@("`@("`@("`D8V]N;G-T<B`N/2`G:&]S=#TG("X@)&1S;FEN
M9F];)VAO<W1S<&5C)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1D<VYI;F9O6R=P;W)T)UTI('L*("`@("`@("`@("`@("`@("1C;VYN<W1R
M("X]("<@<&]R=#TG("X@)&1S;FEN9F];)W!O<G0G73L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS96EF("@D<')O=&]C;VP@/3T@)W5N:7@G*2!["B`@
M("`@("`@("`@("\O($%L;&]W(&9O<B!P9R!S;V-K970@:6X@;F]N+7-T86YD
M87)D(&QO8V%T:6]N<RX*("`@("`@("`@("`@:68@*"1D<VYI;F9O6R=S;V-K
M970G72D@>PH@("`@("`@("`@("`@("`@)&-O;FYS='(@+CT@)VAO<W0])R`N
M("1D<VYI;F9O6R=S;V-K970G73L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*"1D<VYI;F9O6R=D871A8F%S92==*2!["B`@("`@("`@
M("`@("1C;VYN<W1R("X]("<@9&)N86UE/5PG)R`N(&%D9'-L87-H97,H)&1S
M;FEN9F];)V1A=&%B87-E)UTI("X@)UPG)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"1D<VYI;F9O6R=U<V5R;F%M92==*2!["B`@("`@("`@("`@("1C;VYN
M<W1R("X]("<@=7-E<CU<)R<@+B!A9&1S;&%S:&5S*"1D<VYI;F9O6R=U<V5R
M;F%M92==*2`N("=<)R<["B`@("`@("`@?0H@("`@("`@(&EF("@D9'-N:6YF
M;ULG<&%S<W=O<F0G72D@>PH@("`@("`@("`@("`D8V]N;G-T<B`N/2`G('!A
M<W-W;W)D/5PG)R`N(&%D9'-L87-H97,H)&1S;FEN9F];)W!A<W-W;W)D)UTI
M("X@)UPG)SL*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1D<VYI;F9O
M6R=O<'1I;VYS)UTI*2!["B`@("`@("`@("`@("1C;VYN<W1R("X]("<@;W!T
M:6]N<STG("X@)&1S;FEN9F];)V]P=&EO;G,G73L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES<V5T*"1D<VYI;F9O6R=T='DG72DI('L*("`@("`@("`@("`@
M)&-O;FYS='(@+CT@)R!T='D])R`N("1D<VYI;F9O6R=T='DG73L*("`@("`@
M("!]"@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E;G0@
M/R`G<&=?<&-O;FYE8W0G(#H@)W!G7V-O;FYE8W0G.PH@("`@("`@("\O(&-A
M=&-H(&5R<F]R"B`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@("`D8V]N;B`]
M("1C;VYN96-T7V9U;F-T:6]N*"1C;VYN<W1R*3L*("`@("`@("`D97)R;W(@
M/2!O8E]G971?8V]N=&5N=',H*3L*("`@("`@("!O8E]E;F1?8VQE86XH*3L*
M("`@("`@("!I9B`H)&-O;FX@/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"P@;G5L;"P@<W1R:7!?=&%G<R@D97)R;W(I*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2`D8V]N;CL*("`@("`@("!R971U
M<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N
M;F5C="@I"@H@("`@+RHJ"B`@("`@*B!,;V<@;W5T(&%N9"!D:7-C;VYN96-T
M(&9R;VT@=&AE(&1A=&%B87-E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;"!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF(&YO="!C;VYN96-T960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@
M("1R970@/2!`<&=?8VQO<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E
M=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I
M"@H@("`@+RHJ"B`@("`@*B!396YD(&$@<75E<GD@=&\@4&]S=&=R95-13"!A
M;F0@<F5T=7)N('1H92!R97-U;'1S(&%S(&$*("`@("`J(%!O<W1G<F5344P@
M<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<&%R86T@)'%U
M97)Y('1H92!344P@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!R
M971U<FYS(&$@=F%L:60@4&]S=&=R95-13"!R97-U;'0@9F]R('-U8V-E<W-F
M=6P@4T5,14-4"B`@("`@*B!Q=65R:65S+"!$0E]/2R!F;W(@;W1H97(@<W5C
M8V5S<V9U;"!Q=65R:65S+B`@02!$0B!E<G)O<B!C;V1E"B`@("`@*B!I<R!R
M971U<FYE9"!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP
M;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)&ES;6%N:7`@/2!$0CHZ
M:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@
M)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D
M<75E<GDI.PH@("`@("`@(&EF("@A)'1H:7,M/F%U=&]C;VUM:70@)B8@)&ES
M;6%N:7`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O
M<&-O=6YT(#T](#`I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!`<&=?
M97AE8R@D=&AI<RT^8V]N;F5C=&EO;BP@)V)E9VEN.R<I.PH@("`@("`@("`@
M("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I
M;VY?;W!C;W5N="LK.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@0'!G
M7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL("1Q=65R>2D["B`@("`@("`@:68@
M*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<&=S<6Q2
M86ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("\O($1E=&5R;6EN92!W
M:&EC:"!Q=65R:65S('1H870@<VAO=6QD(')E='5R;B!D871A+"!A;F0@=VAI
M8V@*("`@("`@("`O+R!S:&]U;&0@<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL
M>2X*("`@("`@("!I9B`H)&ES;6%N:7`I('L*("`@("`@("`@("`@)'1H:7,M
M/F%F9F5C=&5D(#T@0'!G7V-M9'1U<&QE<R@D<F5S=6QT*3L*("`@("`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H
M*"<O7EQS*EPH/UQS*BA314Q%0U0H/R%<<RM)3E1/*7Q%6%!,04E.?%-(3U<I
M7',O<VDG+"`D<75E<GDI*2!["B`@("`@("`@("`@("\J(%!O<W1G<F5344P@
M8V]M;6%N9',Z"B`@("`@("`@("`@("`@($%"3U)4+"!!3%1%4BP@0D5'24XL
M($-,3U-%+"!#3%535$52+"!#3TU-250L($-/4%DL"B`@("`@("`@("`@("`@
M($-214%412P@1$5#3$%212P@1$5,151%+"!$4D]0(%1!0DQ%+"!%6%!,04E.
M+"!&151#2"P*("`@("`@("`@("`@("`@1U)!3E0L($E.4T525"P@3$E35$5.
M+"!,3T%$+"!,3T-++"!-3U9%+"!.3U1)1EDL(%)%4T54+`H@("`@("`@("`@
M("`@("!2159/2T4L(%)/3$Q"04-++"!314Q%0U0L(%-%3$5#5"!)3E1/+"!3
M150L(%-(3U<L"B`@("`@("`@("`@("`@(%5.3$E35$5.+"!54$1!5$4L(%9!
M0U5530H@("`@("`@("`@("`J+PH@("`@("`@("`@("`D=&AI<RT^<F]W6RAI
M;G0I)')E<W5L=%T@/2`P.R`O+R!R97-E="!T:&4@<F]W(&-O=6YT97(N"B`@
M("`@("`@("`@("1N=6UR;W=S(#T@)'1H:7,M/FYU;7)O=W,H)')E<W5L="D[
M"B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)&YU;7)O=W,I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&YU;7)O=W,["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/FYU;5]R;W=S6RAI;G0I)')E<W5L=%T@/2`D;G5M
M<F]W<SL*("`@("`@("`@("`@)'1H:7,M/F%F9F5C=&5D(#T@,#L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/F%F9F5C=&5D(#T@,#L*("`@("`@("`@("`@<F5T=7)N
M($1"7T]+.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@=&AE(&EN=&5R
M;F%L('!G<W%L(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L
M92!R97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!F8G-Q;"!R
M97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I<R!A=F%I
M;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F=6YC
M=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D
M92@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@4$5!4CHZ1$(@97)R;W(@
M8V]D92!F<F]M('1H92!D871A8F%S92=S('1E>'0@97)R;W(@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&5R<F]R;7-G("!E<G)O
M<B!M97-S86=E(')E='5R;F5D(&9R;VT@=&AE(&1A=&%B87-E"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@(&%N(&5R<F]R(&YU;6)E<B!F<F]M(&$@1$(@97)R
M;W(@8V]N<W1A;G0*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)#;V1E*"1E
M<G)O<FUS9RD*("`@('L*("`@("`@("!S=&%T:6,@)&5R<F]R7W)E9V5X<',[
M"B`@("`@("`@:68@*"%I<W-E="@D97)R;W)?<F5G97AP<RDI('L*("`@("`@
M("`@("`@)&5R<F]R7W)E9V5X<',@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("<O*"A;4G)=96QA=&EO;GQ;4W-=97%U96YC97Q;5'1=86)L92DH(%M<(EPG
M72XJ6UPB7"==*3\@9&]E<R!N;W0@97AI<W1\6T-C76QA<W,@(BXK(B!N;W0@
M9F]U;F0I)"\G(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@("`@
M("`@("`@)R];0V-=;VQU;6X@6UPB7"==+BI;7")<)UT@9&]E<R!N;W0@97AI
M<W0O)R`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@("`@
M("<O6U)R765L871I;VX@6UPB7"==+BI;7")<)UT@86QR96%D>2!E>&ES='-\
M6T-C76%N;F]T(&EN<V5R="!A(&1U<&QI8V%T92!K97D@:6YT;R`H82`I/W5N
M:7%U92!I;F1E>"XJ+R<@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@
M("`@("`@("`@("`@("`G+RAD:79I9&5\9&EV:7-I;VXI(&)Y('IE<F\D+R<@
M("`@("`@("`@/3X@1$)?15)23U)?1$E66D523RP*("`@("`@("`@("`@("`@
M("<O<&=?871O:3H@97)R;W(@:6X@+BHZ(&-A;EPG="!P87)S92`O)R`]/B!$
M0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`@("`@("`@("<O:6YV
M86QI9"!I;G!U="!S>6YT87@@9F]R(&EN=&5G97(O)R`@("`]/B!$0E]%4E)/
M4E])3E9!3$E$7TY534)%4BP*("`@("`@("`@("`@("`@("<O='1R:6)U=&4@
M6UPB7"==+BI;7")<)UT@;F]T(&9O=6YD)'Q;4G)=96QA=&EO;B!;7")<)UTN
M*EM<(EPG72!D;V5S(&YO="!H879E(&%T=')I8G5T92!;7")<)UTN*EM<(EPG
M72\G(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("`@("`@("`@
M)R]P87)S97(Z('!A<G-E(&5R<F]R(&%T(&]R(&YE87(@7"(O)R`@(#T^($1"
M7T524D]27U-93E1!6"P*("`@("`@("`@("`@("`@("<O<WEN=&%X(&5R<F]R
M(&%T+R<@("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L
M"B`@("`@("`@("`@("`@("`G+W9I;VQA=&5S(&YO="UN=6QL(&-O;G-T<F%I
M;G0O)R`@("`@("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*
M("`@("`@("`@("`@("`@("<O=FEO;&%T97,@6UQW(%TK(&-O;G-T<F%I;G0O
M)R`@("`@("`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@
M("`@("`@)R]R969E<F5N=&EA;"!I;G1E9W)I='D@=FEO;&%T:6]N+R<@("`@
M(#T^($1"7T524D]27T-/3E-44D%)3E0*("`@("`@("`@("`@*3L*("`@("`@
M("!]"B`@("`@("`@9F]R96%C:"`H)&5R<F]R7W)E9V5X<',@87,@)')E9V5X
M<"`]/B`D8V]D92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<F5G
M97AP+"`D97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&-O
M9&4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@1F%L;"!B
M86-K('1O($1"7T524D]2(&EF('1H97)E('=A<R!N;R!M87!P:6YG+@H@("`@
M("`@(')E='5R;B!$0E]%4E)/4CL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@1F5T8V@@82!R;W<@
M86YD(&EN<V5R="!T:&4@9&%T82!I;G1O(&%N(&5X:7-T:6YG(&%R<F%Y+@H@
M("`@("H*("`@("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D
M871A('1H97)E:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R
M97-U;'0Z.F9E=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('%U97)Y(')E
M<W5L="!I9&5N=&EF:65R"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@
M("`@("`H<F5F97)E;F-E*2!A<G)A>2!W:&5R92!D871A(&9R;VT@=&AE(')O
M=PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<VAO=6QD(&)E
M('!L86-E9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W
M('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J
M($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O
M(&9E=&-H"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!$0E]/2R!O;B!S
M=6-C97-S+"!.54Q,('=H96X@96YD(&]F(')E<W5L="!S970@:7,*("`@("`J
M("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@
M("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R
M97-U;'0L("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M/6YU;&PI"B`@("![
M"B`@("`@("`@)')O=VYU;2`]("@D<F]W;G5M("$]/2!N=6QL*2`_("1R;W=N
M=6T@.B`D=&AI<RT^<F]W6R1R97-U;'1=.PH@("`@("`@(&EF("@D<F]W;G5M
M(#X]("1T:&ES+3YN=6U?<F]W<ULD<F5S=6QT72D@>PH@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@
M)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@("`@("`@)&%R<B`]($!P
M9U]F971C:%]A<G)A>2@D<F5S=6QT+"`D<F]W;G5M+"!01U-13%]!4U-/0RD[
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG
M72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D87)R*2!["B`@("`@
M("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L
M($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&%R<B`]($!P9U]F971C:%]R;W<H)')E<W5L="P@)')O
M=VYU;2D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@("`@("`@
M("`@("`D97)R(#T@<&=?97)R;W)M97-S86=E*"1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("`@("`@:68@*"$D97)R*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G!G<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465]25%))32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E6
M86QU97,H)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?
M14U05%DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y
M5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/G)O=ULD<F5S=6QT72`]("LK)')O=VYU;3L*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I
M"@H@("`@+RHJ"B`@("`@*B!&<F5E('1H92!I;G1E<FYA;"!R97-O=7)C97,@
M87-S;V-I871E9"!W:71H("1R97-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M
M("1R97-U;'0@:6YT(%!O<W1G<F5344P@<F5S=6QT(&ED96YT:69I97(*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!&04Q3
M12!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(&EF("AI<U]R97-O
M=7)C92@D<F5S=6QT*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^<F]W
M6RAI;G0I)')E<W5L=%TI.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^;G5M
M7W)O=W-;*&EN="DD<F5S=6QT72D["B`@("`@("`@("`@("1T:&ES+3YA9F9E
M8W1E9"`](#`["B`@("`@("`@("`@(')E='5R;B!`<&=?9G)E97)E<W5L="@D
M<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E*"D*"B`@("`O*BH*("`@
M("`J($!D97!R96-A=&5D("!$97!R96-A=&5D(&EN(')E;&5A<V4@,2XV+C`*
M("`@("`J($!I;G1E<FYA;`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T92@D
M<W1R*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=6]T95-M87)T*"1S='(I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E4VUA<G0H*0H*
M("`@("\J*@H@("`@("H@1F]R;6%T(&EN<'5T('-O(&ET(&-A;B!B92!S869E
M;'D@=7-E9"!I;B!A('%U97)Y"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1I;B`@9&%T82!T;R!B92!Q=6]T960*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(%-U8FUI='1E9"!V87)I86)L92=S('1Y<&4@/2!R971U<FYE9"!V
M86QU93H*("`@("`J("`@("`@("`@("`@("`@*R!N=6QL(#T@=&AE('-T<FEN
M9R`\<V%M<#Y.54Q,/"]S86UP/@H@("`@("H@("`@("`@("`@("`@("`K(&)O
M;VQE86X@/2!S=')I;F<@/'-A;7`^5%)513PO<V%M<#X@;W(@/'-A;7`^1D%,
M4T4\+W-A;7`^"B`@("`@*B`@("`@("`@("`@("`@("L@:6YT96=E<B!O<B!D
M;W5B;&4@/2!T:&4@=6YQ=6]T960@;G5M8F5R"B`@("`@*B`@("`@("`@("`@
M("`@("L@;W1H97(@*&EN8VQU9&EN9R!S=')I;F=S(&%N9"!N=6UE<FEC('-T
M<FEN9W,I(#T*("`@("`J("`@("`@("`@("`@("`@("!T:&4@9&%T82!E<V-A
M<&5D(&%C8V]R9&EN9R!T;R!->5-13"=S('-E='1I;F=S"B`@("`@*B`@("`@
M("`@("`@("`@("`@=&AE;B!E;F-A<'-U;&%T960@8F5T=V5E;B!S:6YG;&4@
M<75O=&5S"B`@("`@*@H@("`@("H@0&EN=&5R;F%L"B`@("`@*B\*("`@(&9U
M;F-T:6]N('%U;W1E4VUA<G0H)&EN*0H@("`@>PH@("`@("`@(&EF("AI<U]I
M;G0H)&EN*2!\?"!I<U]D;W5B;&4H)&EN*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&EN.PH@("`@("`@('T@96QS96EF("AI<U]B;V]L*"1I;BDI('L*("`@
M("`@("`@("`@<F5T=7)N("1I;B`_("=44E5%)R`Z("=&04Q312<["B`@("`@
M("`@?2!E;'-E:68@*&ES7VYU;&PH)&EN*2D@>PH@("`@("`@("`@("!R971U
M<FX@)TY53$PG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`B)R(@+B`D=&AI<RT^97-C87!E4VEM<&QE*"1I;BD@+B`B)R(["B`@("`@
M("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5S8V%P95-I;7!L
M92@I"@H@("`@+RHJ"B`@("`@*B!%<V-A<&4@82!S=')I;F<@86-C;W)D:6YG
M('1O('1H92!C=7)R96YT($1"35,G<R!S=&%N9&%R9',*("`@("`J"B`@("`@
M*B!0;W-T9W)E4U%,('1R96%T<R!A(&)A8VMS;&%S:"!A<R!A;B!E<V-A<&4@
M8VAA<F%C=&5R+"!S;R!T:&5Y(&%R90H@("`@("H@<F5M;W9E9"X*("`@("`J
M"B`@("`@*B!.;W0@=7-I;F<@<&=?97-C87!E7W-T<FEN9R@I('EE="!B96-A
M=7-E(&ET(')E<75I<F5S(%!O<W1G<F5344P*("`@("`J('1O(&)E(&%T('9E
M<G-I;VX@-RXR(&]R(&=R96%T97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W1R("!T:&4@<W1R:6YG('1O(&)E(&5S8V%P960*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5S8V%P960@<W1R:6YG"B`@("`@
M*@H@("`@("H@0&EN=&5R;F%L"B`@("`@*B\*("`@(&9U;F-T:6]N(&5S8V%P
M95-I;7!L92@D<W1R*2!["B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"(G
M(BP@(B<G(BP@<W1R7W)E<&QA8V4H)UQ<)RP@)UQ<7%PG+"`D<W1R*2D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ
M"B`@("`@*B!'970@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT
M('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@)')E<W5L="!R97-O=7)C92!0
M;W-T9W)E4U%,(')E<W5L="!I9&5N=&EF:65R"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@=&AE(&YU;6)E<B!O9B!C;VQU;6YS('!E<B!R;W<@:6X@)')E
M<W5L=`H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@
M("!["B`@("`@("`@)&-O;',@/2!`<&=?;G5M9FEE;&1S*"1R97-U;'0I.PH@
M("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YP9W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H
M*0H*("`@("\J*@H@("`@("H@1V5T('1H92!N=6UB97(@;V8@<F]W<R!I;B!A
M(')E<W5L="!S970N"B`@("`@*@H@("`@("H@0'!A<F%M("1R97-U;'0@<F5S
M;W5R8V4@4&]S=&=R95-13"!R97-U;'0@:61E;G1I9FEE<@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT('1H92!N=6UB97(@;V8@<F]W<R!I;B`D<F5S=6QT
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*
M("`@("`@("`D<F]W<R`]($!P9U]N=6UR;W=S*"1R97-U;'0I.PH@("`@("`@
M(&EF("@D<F]W<R`]/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G!G<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).
M871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T('1H92!N871I=F4@97)R;W(@
M8V]D92!O9B!T:&4@;&%S="!E<G)O<B`H:68@86YY*2!T:&%T"B`@("`@*B!O
M8V-U<F5D(&]N('1H92!C=7)R96YT(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@;F%T:79E(%!O<W1G<F5344P@97)R;W(@8V]D90H@
M("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@
M("`@<F5T=7)N('!G7V5R<F]R;65S<V%G92@D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI="@I"@H@
M("`@+RHJ"B`@("`@*B!%;F%B;&4O9&ES86)L92!A=71O;6%T:6,@8V]M;6ET
M<PH@("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A
M;'-E*0H@("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A8W1I
M;VY?;W!C;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@("\O
M(&ES<W5E(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O8V]M
M;6ET(#T@)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R;B!$
M0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*
M("`@("\J*@H@("`@("H@0V]M;6ET('1H92!C=7)R96YT('1R86YS86-T:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@
M("`@("`@+R\@*&1I<V%B;&5D*2!H86-K('1O('-H=70@=7`@97)R;W(@;65S
M<V%G97,@9G)O;2!L:6)P<2YA"B`@("`@("`@("`@("\O0&9C;&]S92A`9F]P
M96XH(G!H<#HO+W-T9&5R<B(L(")W(BDI.PH@("`@("`@("`@("`D<F5S=6QT
M(#T@0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL("=E;F0[)RD["B`@("`@
M("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@
M("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G!G<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2;VQL(&)A
M8VL@*'5N9&\I('1H92!C=7)R96YT('1R86YS86-T:6]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL("=A8F]R=#LG*3L*
M("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@
M("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<&=S<6Q286ES945R<F]R*"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@
M*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!T:&4@;&%S
M="!Q=65R>2X*("`@("`J(&EF('1H92!L87-T('%U97)Y('=A<R!A('-E;&5C
M="P@<F5T=7)N<R`P+@H@("`@("H*("`@("`J($!R971U<FX@:6YT(&YU;6)E
M<B!O9B!R;W=S(&%F9F5C=&5D(&)Y('1H92!L87-T('%U97)Y(&]R($1"7T52
M4D]2"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YA9F9E8W1E9#L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E
M<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@
M=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T
M(&5X:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED
M(&YU;6)E<B!I;B!T:&4@<V5Q=65N8V4N("!$0E]%<G)O<B!I9B!P<F]B;&5M
M+@H@("`@("H*("`@("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.FYE>'1)1"@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E
M*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E
M3F%M92@D<V5Q7VYA;64I.PH@("`@("`@("1R97!E870@/2!F86QS93L*("`@
M("`@("!D;R!["B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@/28@
M)'1H:7,M/G%U97)Y*")314Q%0U0@3D585%9!3"@G)'MS97%N86UE?2<I(BD[
M"B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@
M("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="D@
M)B8*("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%
M4E)/4E].3U-50TA404),12D@>PH@("`@("`@("`@("`@("`@)')E<&5A="`]
M('1R=64["B`@("`@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1R97!E870@/2!F86QS93L*("`@("`@("`@("`@?0H@("`@
M("`@('T@=VAI;&4@*"1R97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1A<G(@/2`D<F5S
M=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@
M)')E<W5L="T^9G)E92@I.PH@("`@("`@(')E='5R;B`D87)R6S!=.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-R96%T95-E<75E;F-E*"D*"B`@
M("`O*BH*("`@("`J($-R96%T92!T:&4@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92!T:&4@;F%M92!O9B!T:&4@<V5Q
M=65N8V4*("`@("`J($!R971U<FX@;6EX960@1$)?3TL@;VX@<W5C8V5S<R!O
M<B!$0B!E<G)O<B!O;B!E<G)O<@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*0H@
M("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M
M92@D<V5Q7VYA;64I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH
M(D-214%412!315%514Y#12`D>W-E<6YA;65](BD["B`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9')O<%-E
M<75E;F-E*"D*"B`@("`O*BH*("`@("`J($1R;W`@82!S97%U96YC90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE('1H92!N86UE(&]F
M('1H92!S97%U96YC90H@("`@("H@0')E='5R;B!M:7AE9"!$0E]/2R!O;B!S
M=6-C97-S(&]R($1"(&5R<F]R(&]N(&5R<F]R"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N
M86UE*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E
M;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E
M<GDH(D123U`@4T51545.0T4@)'MS97%N86UE?2(I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI;6ET475E<GDH*0H*("`@(&9U;F-T
M:6]N(&UO9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT*0H@
M("`@>PH@("`@("`@("1Q=65R>2`]("1Q=65R>2`N("(@3$E-250@)&-O=6YT
M($]&1E-%5"`D9G)O;2(["B`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!P9W-Q;%)A:7-E17)R;W(H*0H*("`@
M("\J*@H@("`@("H@1V%T:&5R(&EN9F]R;6%T:6]N(&%B;W5T(&%N(&5R<F]R
M+"!T:&5N('5S92!T:&%T(&EN9F\@=&\@8W)E871E(&$*("`@("`J($1"(&5R
M<F]R(&]B:F5C="!A;F0@9FEN86QL>2!R971U<FX@=&AA="!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M("!I;G1E9V5R("`D97)R;F\@(%!%05(@97)R
M;W(@;G5M8F5R("AU<W5A;&QY(&$@1$(@8V]N<W1A;G0I(&EF"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@;6%N=6%L;'D@<F%I<VEN9R!A;B!E
M<G)O<@H@("`@("H@0')E='5R;B!O8FIE8W0@($1"(&5R<F]R(&]B:F5C=`H@
M("`@("H@0'-E92!E<G)O<DYA=&EV92@I"B`@("`@*B!`<V5E(&5R<F]R0V]D
M92@I"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!G<W%L4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1N871I=F4@/2`D=&AI<RT^97)R;W).871I=F4H
M*3L*("`@("`@("!I9B`H)&5R<FYO(#T]/2!N=6QL*2!["B`@("`@("`@("`@
M("1E<G(@/2`D=&AI<RT^97)R;W)#;V1E*"1N871I=F4I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1E<G(@/2`D97)R;F\["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R+"!N=6QL+"!N
M=6QL+"!N=6QL+"`D;F%T:79E*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!?<&=&:65L9$9L86=S*"D*"B`@("`O*BH*("`@("`J($9L86=S(&]F
M(&$@1FEE;&0*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1R97-O=7)C92!0
M;W-T9W)E4U%,(')E<W5L="!I9&5N=&EF:65R"B`@("`@*B!`<&%R86T@:6YT
M("1N=6U?9FEE;&0@=&AE(&9I96QD(&YU;6)E<@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG(%1H92!F;&%G<R!O9B!T:&4@9FEE;&0@*")N;W1?;G5L
M;"(L(")D969A=6QT7W9A;'5E(BP*("`@("`J("`@("`@("`@("`@("`@(")P
M<FEM87)Y7VME>2(L(")U;FEQ=65?:V5Y(B!A;F0@(FUU;'1I<&QE7VME>2(*
M("`@("`J("`@("`@("`@("`@("`@(&%R92!S=7!P;W)T960I+B`@5&AE(&1E
M9F%U;'0@=F%L=64@:7,@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("!T
M:')O=6=H(')A=W5R;&5N8V]D92@I(&EN(&-A<V4@=&AE<F4@87)E('-P86-E
M<R!I;B!I="X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<&=&:65L9$9L86=S*"1R97-O=7)C92P@)&YU;5]F:65L9"P@
M)'1A8FQE7VYA;64I"B`@("!["B`@("`@("`@)&9I96QD7VYA;64@/2!`<&=?
M9FEE;&1N86UE*"1R97-O=7)C92P@)&YU;5]F:65L9"D["@H@("`@("`@("1R
M97-U;'0@/2!`<&=?97AE8R@D=&AI<RT^8V]N;F5C=&EO;BP@(E-%3$5#5"!F
M+F%T=&YO=&YU;&PL(&8N871T:&%S9&5F"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@1E)/32!P9U]A='1R:6)U=&4@9BP@<&=?8VQA<W,@=&%B
M+"!P9U]T>7!E('1Y<`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%=(15)%('1A8BYR96QN86UE(#T@='EP+G1Y<&YA;64*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!!3D0@='EP+G1Y<')E;&ED(#T@9BYA='1R
M96QI9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.1"!F+F%T
M=&YA;64@/2`G)&9I96QD7VYA;64G"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@04Y$('1A8BYR96QN86UE(#T@)R1T86)L95]N86UE)R(I.PH@
M("`@("`@(&EF("A`<&=?;G5M<F]W<R@D<F5S=6QT*2`^(#`I('L*("`@("`@
M("`@("`@)')O=R`]($!P9U]F971C:%]R;W<H)')E<W5L="P@,"D["B`@("`@
M("`@("`@("1F;&%G<R`@/2`H)')O=ULP72`]/2`G="<I(#\@)VYO=%]N=6QL
M("<@.B`G)SL*"B`@("`@("`@("`@(&EF("@D<F]W6S%=(#T]("=T)RD@>PH@
M("`@("`@("`@("`@("`@)')E<W5L="`]($!P9U]E>&5C*"1T:&ES+3YC;VYN
M96-T:6]N+"`B4T5,14-4(&$N861S<F,*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1E)/32!P9U]A='1R:6)U=&4@9BP@<&=?8VQA<W,@
M=&%B+"!P9U]T>7!E('1Y<"P@<&=?871T<F1E9B!A"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%=(15)%('1A8BYR96QN86UE(#T@='EP
M+G1Y<&YA;64@04Y$('1Y<"YT>7!R96QI9"`](&8N871T<F5L:60*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$(&8N871T<F5L:60@
M/2!A+F%D<F5L:60@04Y$(&8N871T;F%M92`]("<D9FEE;&1?;F%M92<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$('1A8BYR96QN
M86UE(#T@)R1T86)L95]N86UE)R!!3D0@9BYA='1N=6T@/2!A+F%D;G5M(BD[
M"B`@("`@("`@("`@("`@("`D<F]W(#T@0'!G7V9E=&-H7W)O=R@D<F5S=6QT
M+"`P*3L*("`@("`@("`@("`@("`@("1N=6T@/2!P<F5G7W)E<&QA8V4H(B\G
M*"XJ*2<Z.EQW*R\B+"`B7%PQ(BP@)')O=ULP72D["B`@("`@("`@("`@("`@
M("`D9FQA9W,@+CT@)V1E9F%U;'1?)R`N(')A=W5R;&5N8V]D92@D;G5M*2`N
M("<@)SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1F;&%G<R`]("<G.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@
M0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL(")314Q%0U0@:2YI;F1I<W5N
M:7%U92P@:2YI;F1I<W!R:6UA<GDL(&DN:6YD:V5Y"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1E)/32!P9U]A='1R:6)U=&4@9BP@<&=?8VQA
M<W,@=&%B+"!P9U]T>7!E('1Y<"P@<&=?:6YD97@@:0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%=(15)%('1A8BYR96QN86UE(#T@='EP+G1Y
M<&YA;64*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!!3D0@='EP
M+G1Y<')E;&ED(#T@9BYA='1R96QI9`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($%.1"!F+F%T=')E;&ED(#T@:2YI;F1R96QI9`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($%.1"!F+F%T=&YA;64@/2`G)&9I
M96QD7VYA;64G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$
M('1A8BYR96QN86UE(#T@)R1T86)L95]N86UE)R(I.PH@("`@("`@("1C;W5N
M="`]($!P9U]N=6UR;W=S*"1R97-U;'0I.PH*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D8V]U;G0@.R`D:2LK*2!["B`@("`@("`@("`@("1R;W<@/2!`
M<&=?9F5T8VA?<F]W*"1R97-U;'0L("1I*3L*("`@("`@("`@("`@)&ME>7,@
M/2!E>'!L;V1E*"<@)RP@)')O=ULR72D["@H@("`@("`@("`@("!I9B`H:6Y?
M87)R87DH)&YU;5]F:65L9"`K(#$L("1K97ES*2D@>PH@("`@("`@("`@("`@
M("`@)&9L86=S("X]("@D<F]W6S!=(#T]("=T)R`F)B`D<F]W6S%=(#T]("=F
M)RD@/R`G=6YI<75E7VME>2`G(#H@)R<["B`@("`@("`@("`@("`@("`D9FQA
M9W,@+CT@*"1R;W=;,5T@/3T@)W0G*2`_("=P<FEM87)Y7VME>2`G(#H@)R<[
M"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&ME>7,I(#X@,2D*("`@("`@
M("`@("`@("`@("`@("`D9FQA9W,@+CT@)VUU;'1I<&QE7VME>2`G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')I;2@D9FQA
M9W,I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@
M=&%B;&4@;W(@82!R97-U;'0@<V5T+@H@("`@("H*("`@("`J($Y/5$4Z(&]N
M;'D@<W5P<&]R=',@)W1A8FQE)R!A;F0@)V9L86=S)R!I9B`\=F%R/B1R97-U
M;'0\+W9A<CX*("`@("`J(&ES(&$@=&%B;&4@;F%M92X*("`@("`J"B`@("`@
M*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B
M:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F
M(&$@=&%B;&4*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@
M("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R
M97%U97-T960*("`@("`J("`@("`@("`@("`@("`@(&]R(&%N(&5R<F]R(&]B
M:F5C="!I9B!S;VUE=&AI;F<@:7,@=W)O;F<*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S964@1$)?8V]M;6]N.CIT
M86)L94EN9F\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E
M<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M<F5S=6QT+3YR97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@
M("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@
M("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I
M97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT
M+3YR97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@
M("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A
M8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O
M=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@
M)&ED(#T@0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL(")314Q%0U0@*B!&
M4D]-("1R97-U;'0@3$E-250@,"(I.PH@("`@("`@("`@("`D9V]T7W-T<FEN
M9R`]('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@
M("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R
M8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I="X*("`@("`@
M("`@("`@("H@1&5P<F5C871E9"X@($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@
M;VYL>2X*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U
M;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1I9"DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D5%
M1%]-3U)%7T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#
M05-%*2!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S
M=')V86PG.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@0'!G7VYU;69I
M96QD<R@D:60I.PH*("`@("`@("`O+R!M861E('1H:7,@248@9'5E('1O('!E
M<F9O<FUA;F-E("AO;F4@:68@:7,@9F%S=&5R('1H86X@)&-O=6YT(&EF)W,I
M"B`@("`@("`@:68@*"$D;6]D92D@>PH*("`@("`@("`@("`@9F]R("@D:3TP
M.R`D:3PD8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@("`@("1R97-;)&E=
M6R=T86)L92==(#T@)&=O=%]S=')I;F<@/R`D8V%S95]F=6YC*"1R97-U;'0I
M(#H@)R<["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG;F%M92==("`]("1C
M87-E7V9U;F,H0'!G7V9I96QD;F%M92@D:60L("1I*2D["B`@("`@("`@("`@
M("`@("`D<F5S6R1I75LG='EP92==("`]($!P9U]F:65L9'1Y<&4H)&ED+"`D
M:2D["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG;&5N)UT@("`]($!P9U]F
M:65L9'-I>F4H)&ED+"`D:2D["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG
M9FQA9W,G72`]("1G;W1?<W1R:6YG(#\@)'1H:7,M/E]P9T9I96QD9FQA9W,H
M)&ED+"`D:2P@)')E<W5L="D@.B`G)SL*("`@("`@("`@("`@?0H*("`@("`@
M("!](&5L<V4@>R`O+R!F=6QL"B`@("`@("`@("`@("1R97-;)VYU;5]F:65L
M9',G73T@)&-O=6YT.PH*("`@("`@("`@("`@9F]R("@D:3TP.R`D:3PD8V]U
M;G0[("1I*RLI('L*("`@("`@("`@("`@("`@("1R97-;)&E=6R=T86)L92==
M(#T@)&=O=%]S=')I;F<@/R`D8V%S95]F=6YC*"1R97-U;'0I(#H@)R<["B`@
M("`@("`@("`@("`@("`D<F5S6R1I75LG;F%M92==("`]("1C87-E7V9U;F,H
M0'!G7V9I96QD;F%M92@D:60L("1I*2D["B`@("`@("`@("`@("`@("`D<F5S
M6R1I75LG='EP92==("`]($!P9U]F:65L9'1Y<&4H)&ED+"`D:2D["B`@("`@
M("`@("`@("`@("`D<F5S6R1I75LG;&5N)UT@("`]($!P9U]F:65L9'-I>F4H
M)&ED+"`D:2D["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG9FQA9W,G72`]
M("1G;W1?<W1R:6YG(#\@)'1H:7,M/E]P9T9I96QD1FQA9W,H)&ED+"`D:2P@
M)')E<W5L="D@.B`G)SL*"B`@("`@("`@("`@("`@("!I9B`H)&UO9&4@)B!$
M0E]404),14E.1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("`@("`D<F5S
M6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.
M1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@("`@("1R97-;)V]R
M9&5R=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G
M75T@/2`D:3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+R\@9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@
M=V5R92!C86QL960@;VX@82!T86)L90H@("`@("`@(&EF("@D9V]T7W-T<FEN
M9RD@>PH@("`@("`@("`@("!`<&=?9G)E97)E<W5L="@D:60I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!G971486)L97-1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!Q=65R>2!N965D960@=&\@9V5T('-O;64@8F%C:V5N9"!I;F9O
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E(%=H870@:VEN9"!O9B!I;F9O
M('EO=2!W86YT('1O(')E=')I979E"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4
M:&4@4U%,('%U97)Y('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713
M<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP
M92D@>PH@("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@
M("`@<F5T=7)N(")314Q%0U0@8RYR96QN86UE(&%S(%PB3F%M95PB"B`@("`@
M("`@("`@("`@("`@("`@("`@($923TT@<&=?8VQA<W,@8RP@<&=?=7-E<B!U
M"B`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%(&,N<F5L;W=N97(@/2!U
M+G5S97-Y<VED($%.1"!C+G)E;&MI;F0@/2`G<B<*("`@("`@("`@("`@("`@
M("`@("`@("`@04Y$(&YO="!E>&ES=',@*'-E;&5C="`Q(&9R;VT@<&=?=FEE
M=W,@=VAE<F4@=FEE=VYA;64@/2!C+G)E;&YA;64I"B`@("`@("`@("`@("`@
M("`@("`@("`@($%.1"!C+G)E;&YA;64@(7X@)UYP9U\G"B`@("`@("`@("`@
M("`@("`@("`@("`@(%5.24]."B`@("`@("`@("`@("`@("`@("`@("`@(%-%
M3$5#5"!C+G)E;&YA;64@87,@7").86UE7"(*("`@("`@("`@("`@("`@("`@
M("`@("`@1E)/32!P9U]C;&%S<R!C"B`@("`@("`@("`@("`@("`@("`@("`@
M(%=(15)%(&,N<F5L:VEN9"`]("=R)PH@("`@("`@("`@("`@("`@("`@("`@
M("!!3D0@;F]T(&5X:7-T<R`H<V5L96-T(#$@9G)O;2!P9U]V:65W<R!W:&5R
M92!V:65W;F%M92`](&,N<F5L;F%M92D*("`@("`@("`@("`@("`@("`@("`@
M("`@04Y$(&YO="!E>&ES=',@*'-E;&5C="`Q(&9R;VT@<&=?=7-E<B!W:&5R
M92!U<V5S>7-I9"`](&,N<F5L;W=N97(I"B`@("`@("`@("`@("`@("`@("`@
M("`@($%.1"!C+G)E;&YA;64@(7X@)UYP9U\G(CL*("`@("`@("`@("`@8V%S
M92`G=FEE=W,G.@H@("`@("`@("`@("`@("`@+R\@5&%B;&4@8V]L<SH@=FEE
M=VYA;64@?"!V:65W;W=N97(@?"!D969I;FET:6]N"B`@("`@("`@("`@("`@
M("!R971U<FX@)U-%3$5#5"!V:65W;F%M92!&4D]-('!G7W9I97=S)SL*("`@
M("`@("`@("`@8V%S92`G=7-E<G,G.@H@("`@("`@("`@("`@("`@+R\@8V]L
M<SH@=7-E;F%M92!\=7-E<WES:61\=7-E8W)E871E9&)\=7-E=')A8V5\=7-E
M<W5P97)\=7-E8V%T=7!D?'!A<W-W9"`@?'9A;'5N=&EL"B`@("`@("`@("`@
M("`@("!R971U<FX@)U-%3$5#5"!U<V5N86UE($923TT@<&=?=7-E<B<["B`@
M("`@("`@("`@(&-A<V4@)V1A=&%B87-E<R<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)U-%3$5#5"!D871N86UE($923TT@<&=?9&%T86)A<V4G.PH@("`@
M("`@("`@("!C87-E("=F=6YC=&EO;G,G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("=314Q%0U0@<')O;F%M92!&4D]-('!G7W!R;V,G.PH@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H@("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@=F%R:6%B
M;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@
M16YD.@H@*B\*"C\^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O;7ES<6PN<&AP````````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C<V,#``,3`T
M,3<S-C,P,#8`,#$W-3$T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W(Z(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@36%I;G1A:6YE<CH@1&%N
M:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!M>7-Q;"YP:'`L=B`Q+C8T(#(P,#0O,#(O,3D@,34Z-#DZ,S0@
M9&%N:65L8R!%>'`@)`H*"B\O(%A86"!L96=E;F0Z"B\O"B\O(%A86"!%4E)/
M4DU31SH@5&AE(&5R<F]R(&UE<W-A9V4@9G)O;2!T:&4@;7ES<6P@9G5N8W1I
M;VX@<VAO=6QD"B\O("`@("`@("`@("`@("`@8F4@<F5G:7-T97)E9"!H97)E
M+@HO+PHO+R!43T1/+W=I<VAL:7-T.@HO+R!L;VYG4F5A9&QE;@HO+R!B:6YM
M;V1E"@H*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!$
M871A8F%S92!I;F1E<&5N9&5N="!Q=65R>2!I;G1E<F9A8V4@9&5F:6YI=&EO
M;B!F;W(@4$A0)W,@37E344P*("H@97AT96YS:6]N+@H@*@H@*B!4:&ES(&ES
M(&9O<B!->5-13"!V97)S:6]N<R`T+C`@86YD(&)E;&]W+@H@*@H@*B!`<&%C
M:V%G92`@1$(*("H@0'9E<G-I;VX@("1)9#H@;7ES<6PN<&AP+'8@,2XV-"`R
M,#`T+S`R+S$Y(#$U.C0Y.C,T(&1A;FEE;&,@17AP("0*("H@0&-A=&5G;W)Y
M($1A=&%B87-E"B`J($!A=71H;W(@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^"B`J+PIC;&%S<R!$0E]M>7-Q;"!E>'1E;F1S($1"7V-O;6UO;@I["B`@
M("`O+R![>WL@<')O<&5R=&EE<PH*("`@('9A<B`D8V]N;F5C=&EO;CL*("`@
M('9A<B`D<&AP='EP92P@)&1B<WEN=&%X.PH@("`@=F%R("1P<F5P87)E7W1O
M:V5N<R`](&%R<F%Y*"D["B`@("!V87(@)'!R97!A<F5?='EP97,@/2!A<G)A
M>2@I.PH@("`@=F%R("1N=6U?<F]W<R`](&%R<F%Y*"D["B`@("!V87(@)'1R
M86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@=F%R("1A=71O8V]M;6ET(#T@
M=')U93L*("`@('9A<B`D9F5T8VAM;V1E(#T@1$)?1D540TA-3T1%7T]21$52
M140[("\J($1E9F%U;'0@9F5T8V@@;6]D92`J+PH@("`@=F%R("1?9&(@/2!F
M86QS93L*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@
M("\J*@H@("`@("H@1$)?;7ES<6P@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?;7ES
M<6PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@("`@
M("`D=&AI<RT^<&AP='EP92`]("=M>7-Q;"<["B`@("`@("`@)'1H:7,M/F1B
M<WEN=&%X(#T@)VUY<W%L)SL*("`@("`@("`D=&AI<RT^9F5A='5R97,@/2!A
M<G)A>2@*("`@("`@("`@("`@)W!R97!A<F4G(#T^(&9A;'-E+`H@("`@("`@
M("`@("`G<&-O;FYE8W0G(#T^('1R=64L"B`@("`@("`@("`@("=T<F%N<V%C
M=&EO;G,G(#T^('1R=64L"B`@("`@("`@("`@("=L:6UI="<@/3X@)V%L=&5R
M)PH@("`@("`@("D["B`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87`@/2!A
M<G)A>2@*("`@("`@("`@("`@,3`P-"`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%
M051%+`H@("`@("`@("`@("`Q,#`U(#T^($1"7T524D]27T-!3DY/5%]#4D5!
M5$4L"B`@("`@("`@("`@(#$P,#8@/3X@1$)?15)23U)?0T%.3D]47T-214%4
M12P*("`@("`@("`@("`@,3`P-R`]/B!$0E]%4E)/4E]!3%)%04197T5825-4
M4RP*("`@("`@("`@("`@,3`P."`]/B!$0E]%4E)/4E]#04Y.3U1?1%)/4"P*
M("`@("`@("`@("`@,3`R,B`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*
M("`@("`@("`@("`@,3`T-B`]/B!$0E]%4E)/4E].3T1"4T5,14-4140L"B`@
M("`@("`@("`@(#$P-3`@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@
M("`@("`@("`@(#$P-3$@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@
M("`@("`@(#$P-30@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@
M("`@(#$P-C(@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@
M("`@(#$P-C0@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`Q,3`P
M(#T^($1"7T524D]27TY/5%],3T-+140L"B`@("`@("`@("`@(#$Q,S8@/3X@
M1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("`@("`Q,30V
M(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@("`@("`Q,#0X(#T^
M($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@("`@(#$R,38@/3X@1$)?
M15)23U)?0T].4U1204E.5`H@("`@("`@("D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T
M('1O(&$@9&%T86)A<V4@86YD(&QO9R!I;B!A<R!T:&4@<W!E8VEF:65D('5S
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M("1D<VX@=&AE(&1A=&$@<V]U<F-E
M(&YA;64@*'-E92!$0CHZ<&%R<V5$4TX@9F]R('-Y;G1A>"D*("`@("`J($!P
M87)A;2`D<&5R<VES=&5N="`H;W!T:6]N86PI('=H971H97(@=&AE(&-O;FYE
M8W1I;VX@<VAO=6QD"B`@("`@*B`@("`@("`@8F4@<&5R<VES=&5N=`H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT($1"7T]+(&]N
M('-U8V-E<W,L(&$@1$(@97)R;W(@;VX@9F%I;'5R90H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;VYN96-T*"1D<VYI;F9O+"`D<&5R<VES=&5N="`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("@A1$(Z.F%S<V5R=$5X=&5N<VEO;B@G;7ES
M<6PG*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YD<VX@/2`D9'-N:6YF;SL*("`@("`@("!I9B`H)&1S;FEN
M9F];)W!R;W1O8V]L)UT@)B8@)&1S;FEN9F];)W!R;W1O8V]L)UT@/3T@)W5N
M:7@G*2!["B`@("`@("`@("`@("1D8FAO<W0@/2`G.B<@+B`D9'-N:6YF;ULG
M<V]C:V5T)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1B:&]S
M="`]("1D<VYI;F9O6R=H;W-T<W!E8R==(#\@)&1S;FEN9F];)VAO<W1S<&5C
M)UT@.B`G;&]C86QH;W-T)SL*("`@("`@("`@("`@:68@*"1D<VYI;F9O6R=P
M;W)T)UTI('L*("`@("`@("`@("`@("`@("1D8FAO<W0@+CT@)SHG("X@)&1S
M;FEN9F];)W!O<G0G73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=M>7-Q;%]P
M8V]N;F5C="<@.B`G;7ES<6Q?8V]N;F5C="<["@H@("`@("`@(&EF("@D9&)H
M;W-T("8F("1D<VYI;F9O6R=U<V5R;F%M92==("8F(&ES<V5T*"1D<VYI;F9O
M6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("`D8V]N;B`]($`D8V]N;F5C
M=%]F=6YC=&EO;B@D9&)H;W-T+"`D9'-N:6YF;ULG=7-E<FYA;64G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;FEN9F];
M)W!A<W-W;W)D)UTI.PH@("`@("`@('T@96QS96EF("@D9&)H;W-T("8F("1D
M<VYI;F9O6R=U<V5R;F%M92==*2!["B`@("`@("`@("`@("1C;VYN(#T@0"1C
M;VYN96-T7V9U;F-T:6]N*"1D8FAO<W0L("1D<VYI;F9O6R=U<V5R;F%M92==
M*3L*("`@("`@("!](&5L<V5I9B`H)&1B:&]S="D@>PH@("`@("`@("`@("`D
M8V]N;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D9&)H;W-T*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D8V]N;B`](&9A;'-E.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21C;VYN*2!["B`@("`@("`@("`@(&EF("@H)&5R<B`]
M($!M>7-Q;%]E<G)O<B@I*2`A/2`G)RD@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$
M+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&YU;&PL("1E<G(I.PH@("`@("`@("`@("!](&5L<V5I9B`H
M96UP='DH)'!H<%]E<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L(&YU
M;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;G5L;"P@)'!H<%]E<G)O<FUS9RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D9'-N:6YF;ULG9&%T86)A<V4G72D@>PH@
M("`@("`@("`@("!I9B`H(4!M>7-Q;%]S96QE8W1?9&(H)&1S;FEN9F];)V1A
M=&%B87-E)UTL("1C;VYN*2D@>PH@("`@("`@("`@("`@("!S=VET8V@H;7ES
M<6Q?97)R;F\H)&-O;FXI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@,3`T.3H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U-50TA$0BP@;G5L;"P@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!N=6QL+"!M>7-Q;%]E<G)O<B@D8V]N;BDI.PH@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E(#$P-#0Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7T%#0T534U]624],051)3TXL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL
M(&UY<W%L7V5R<F]R*"1C;VYN*2D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U(L(&YU;&PL(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;G5L;"P@;7ES<6Q?97)R;W(H)&-O;FXI*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@9FEX('1O(&%L
M;&]W(&-A;&QS('1O(&1I9F9E<F5N="!D871A8F%S97,@:6X@=&AE('-A;64@
M<V-R:7!T"B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`D9'-N:6YF;ULG9&%T
M86)A<V4G73L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N
M<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197T524D]24RD@>PH@
M("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#(R72`]($1"7T52
M4D]27T-/3E-44D%)3E0["B`@("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?
M;6%P6S$P-#A=(#T@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3#L*("`@
M("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`V,ET@/2!$0E]%4E)/
M4E]#3TY35%)!24Y4.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F-O;FYE
M8W1I;VX@/2`D8V]N;CL*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@
M("`@*B!,;V<@;W5T(&%N9"!D:7-C;VYN96-T(&9R;VT@=&AE(&1A=&%B87-E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@;F]T(&-O
M;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@
M("!["B`@("`@("`@)')E="`](&UY<W%L7V-L;W-E*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@
M("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9"!A('%U97)Y('1O
M($UY4U%,(&%N9"!R971U<FX@=&AE(')E<W5L=',@87,@82!->5-13"!R97-O
M=7)C90H@("`@("H@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M=&AE(%-13"!Q=65R>0H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!R971U<FYS(&$@=F%L:60@37E3
M44P@<F5S=6QT(&9O<B!S=6-C97-S9G5L(%-%3$5#5`H@("`@("H@<75E<FEE
M<RP@1$)?3TL@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE<RX@($$@1$(@
M97)R;W(@:7,*("`@("`J(')E='5R;F5D(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@
M("`D:7-M86YI<"`]($1".CII<TUA;FEP*"1Q=65R>2D["B`@("`@("`@)'1H
M:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@("`@)'%U97)Y(#T@)'1H
M:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*"1T:&ES+3Y?
M9&(I('L*("`@("`@("`@("`@:68@*"%`;7ES<6Q?<V5L96-T7V1B*"1T:&ES
M+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%
M3$5#5$5$*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M(21T:&ES+3YA=71O8V]M;6ET("8F("1I<VUA;FEP*2!["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]/2`P*2!["B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L7W%U97)Y*"=3150@05543T-/
M34U)5#TP)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G0D5'24XG+"`D=&AI<RT^8V]N;F5C
M=&EO;BD["B`@("`@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<B@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT*RL["B`@("`@("`@?0H@("`@
M("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N
M;F5C=&EO;BD["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<U]R97-O=7)C92@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("`D;G5M<F]W<R`]("1T:&ES+3YN=6UR;W=S*"1R97-U;'0I.PH@("`@("`@
M("`@("!I9B`H:7-?;V)J96-T*"1N=6UR;W=S*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1N=6UR;W=S.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YN=6U?<F]W<ULH:6YT*21R97-U;'1=(#T@)&YU;7)O=W,["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X
M=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!M
M>7-Q;"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S
M=6QT"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:&%S(&YO="!B965N(&EM
M<&QE;65N=&5D('EE="X*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!S
M<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA)
M;G1O*"D*"B`@("`O*BH*("`@("`J($9E=&-H(&$@<F]W(&%N9"!I;G-E<G0@
M=&AE(&1A=&$@:6YT;R!A;B!E>&ES=&EN9R!A<G)A>2X*("`@("`J"B`@("`@
M*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN
M(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C
M:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!Q=65R>2!R97-U;'0@:61E;G1I
M9FEE<@H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@*')E9F5R
M96YC92D@87)R87D@=VAE<F4@9&%T82!F<F]M('1H92!R;W<*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-H;W5L9"!B92!P;&%C960*("`@
M("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT
M:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:`H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@1$)?3TL@;VX@<W5C8V5S<RP@3E5,
M3"!W:&5N(&5N9"!O9B!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@
M("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@
M1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R
M<BP@)&9E=&-H;6]D92P@)')O=VYU;3UN=6QL*0H@("`@>PH@("`@("`@(&EF
M("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@A0&UY<W%L
M7V1A=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@
M("`@("`@("`@)&%R<B`]($!M>7-Q;%]F971C:%]A<G)A>2@D<F5S=6QT+"!-
M65-13%]!4U-/0RD["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D
M87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME
M>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]($!M>7-Q;%]F971C:%]R
M;W<H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@
M("`@("`@("`@("`O+R!3964Z(&AT='`Z+R]B=6=S+G!H<"YN970O8G5G+G!H
M<#]I9#TR,C,R.`H@("`@("`@("`@("`O+R!F;W(@=VAY('=E(&-A;B=T(&-H
M96-K(&5R<F]R<R!O;B!F971C:&EN9PH@("`@("`@("`@("!R971U<FX@;G5L
M;#L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@)&5R<FYO(#T@0&UY<W%L
M7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@:68@*"$D
M97)R;F\I('L*("`@("`@("`@("`@("`@(')E='5R;B!.54Q,.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R
M<F]R*"1E<G)N;RD["B`@("`@("`@("`@("HO"B`@("`@("`@?0H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197U)44DE-*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J
M($5V96X@=&AO=6=H('1H:7,@1$)-4R!A;')E861Y('1R:6US(&]U='!U="P@
M=V4@9&\@=&AI<R!B96-A=7-E"B`@("`@("`@("`@("`J(&$@9FEE;&0@;6EG
M:'0@:&%V92!I;G1E;G1I;VYA;"!W:&ET97-P86-E(&%T('1H92!E;F0@=&AA
M=`H@("`@("`@("`@("`@*B!G971S(')E;6]V960@8GD@1$)?4$]25$%"24Q)
M5%E?4E1224T@=6YD97(@86YO=&AE<B!D<FEV97(N"B`@("`@("`@("`@("`J
M+PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T
M>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J
M*@H@("`@("H@1G)E92!T:&4@:6YT97)N86P@<F5S;W5R8V5S(&%S<V]C:6%T
M960@=VET:"`D<F5S=6QT+@H@("`@("H*("`@("`J($!P87)A;2`D<F5S=6QT
M($UY4U%,(')E<W5L="!I9&5N=&EF:65R"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S
M=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@
M('5N<V5T*"1T:&ES+3YN=6U?<F]W<ULH:6YT*21R97-U;'1=*3L*("`@("`@
M("!R971U<FX@0&UY<W%L7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!N=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970N
M"B`@("`@*@H@("`@("H@0'!A<F%M("1R97-U;'0@37E344P@<F5S=6QT(&ED
M96YT:69I97(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*
M("`@("`J($!R971U<FX@:6YT('1H92!N=6UB97(@;V8@8V]L=6UN<R!P97(@
M<F]W(&EN("1R97-U;'0*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D
M<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&UY<W%L7VYU;5]F:65L
M9',H)')E<W5L="D["@H@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!N=6U2;W=S*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@;G5M
M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T+@H@("`@("H*("`@("`J($!P
M87)A;2`D<F5S=6QT($UY4U%,(')E<W5L="!I9&5N=&EF:65R"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="!T:&4@;G5M8F5R(&]F(')O=W,@:6X@)')E<W5L=`H@("`@("HO"B`@("!F
M=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@)')O=W,@
M/2!`;7ES<6Q?;G5M7W)O=W,H)')E<W5L="D["B`@("`@("`@:68@*"1R;W=S
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q2
M86ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F]W<SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@
M("`O*BH*("`@("`J($5N86)L92]D:7-A8FQE(&%U=&]M871I8R!C;VUM:71S
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N;V9F(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@+R\@6%A8(&EF("1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT(#X@,"P@=V4@<VAO=6QD('!R;V)A8FQY"B`@("`@("`@+R\@
M:7-S=64@82!W87)N:6YG(&AE<F4N"B`@("`@("`@)'1H:7,M/F%U=&]C;VUM
M:70@/2`D;VYO9F8@/R!T<G5E(#H@9F%L<V4["B`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;6UI="@I"@H@
M("`@+RHJ"B`@("`@*B!#;VUM:70@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]D8BD@>PH@("`@("`@("`@("`@("`@:68@*"%`
M;7ES<6Q?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q2
M86ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L="`]($!M
M>7-Q;%]Q=65R>2@G0T]-34E4)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@
M("`@("`@("`D<F5S=6QT(#T@0&UY<W%L7W%U97)Y*"=3150@05543T-/34U)
M5#TQ)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D=&AI<RT^
M=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A
M:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L
M;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F]L;"!B86-K("AU;F1O*2!T:&4@
M8W5R<F5N="!T<F%N<V%C=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F]L
M;&)A8VLH*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?
M;W!C;W5N="`^(#`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&(I('L*
M("`@("`@("`@("`@("`@(&EF("@A0&UY<W%L7W-E;&5C=%]D8B@D=&AI<RT^
M7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"
M4T5,14-4140I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)U)/3$Q"04-+)RP@
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D<F5S=6QT(#T@0&UY
M<W%L7W%U97)Y*"=3150@05543T-/34U)5#TQ)RP@)'1H:7,M/F-O;FYE8W1I
M;VXI.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]
M(#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*
M("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y('1H
M92!D871A(&UA;FEP=6QA=&EO;@H@("`@("H@<75E<GDN("!&;W(@;W1H97(@
M<75E<FEE<RP@=&AI<R!F=6YC=&EO;B!R971U<FYS(#`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!T:&4@;&%S
M="!Q=65R>0H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@
M("`@>PH@("`@("`@(&EF("A$0CHZ:7--86YI<"@D=&AI<RT^;&%S=%]Q=65R
M>2DI('L*("`@("`@("`@("`@<F5T=7)N($!M>7-Q;%]A9F9E8W1E9%]R;W=S
M*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@;F%T:79E(&5R<F]R(&-O9&4@;V8@=&AE(&QA<W0@97)R;W(@*&EF(&%N
M>2D@=&AA=`H@("`@("H@;V-C=7)E9"!O;B!T:&4@8W5R<F5N="!C;VYN96-T
M:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@;F%T:79E($UY4U%,(&5R<F]R(&-O9&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@("`@>PH@("`@("`@(')E
M='5R;B!M>7-Q;%]E<G)N;R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E;F-E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N86UE(&]F('1H
M92!S97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M86YD("!W
M:&5N('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L;'D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S
M(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X
M="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+B`@1$)?17)R;W(@:68@<')O
M8FQE;2X*("`@("`J"B`@("`@*B!`:6YT97)N86P*("`@("`J($!S964@1$)?
M8V]M;6]N.CIN97AT240H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD(#T@
M=')U92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U
M96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("!D;R!["B`@("`@("`@("`@
M("1R97!E870@/2`P.PH@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/G%U97)Y*")54$1!5$4@)'MS97%N86UE?2`B+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=3150@:60]3$%35%])3E-%
M4E1?240H:60K,2DG*3L*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N
M9&QI;F<H*3L*("`@("`@("`@("`@:68@*"1R97-U;'0@/3T@1$)?3TLI('L*
M("`@("`@("`@("`@("`@("\J*B!#3TU-3TX@0T%312`J*B\*("`@("`@("`@
M("`@("`@("1I9"`](&UY<W%L7VEN<V5R=%]I9"@D=&AI<RT^8V]N;F5C=&EO
M;BD["B`@("`@("`@("`@("`@("!I9B`H)&ED("$](#`I('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@+RHJ($5-4%19(%-%42!404),12`J*B\*("`@("`@("`@
M("`@("`@("\O(%-E<75E;F-E('1A8FQE(&UU<W0@8F4@96UP='D@9F]R('-O
M;64@<F5A<V]N+"!S;R!F:6QL(&ET(&%N9"!R971U<FX@,0H@("`@("`@("`@
M("`@("`@+R\@3V)T86EN(&$@=7-E<BUL979E;"!L;V-K"B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,14-4($=%5%],3T-+
M*"<D>W-E<6YA;65]7VQO8VLG+#$P*2(I.PH@("`@("`@("`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1R97-U;'0@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@("`@("\O($9A:6QE9"!T;R!G970@=&AE(&QO8VLL
M(&)A:6P@=VET:"!A($1"7T524D]27TY/5%],3T-+140@97)R;W(*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$
M0E]%4E)/4E].3U1?3$]#2T5$*3L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O+R!A9&0@=&AE(&1E9F%U;'0@=F%L=64*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH(E)%4$Q!0T4@24Y43R`D
M>W-E<6YA;65](%9!3%5%4R`H,"DB*3L*("`@("`@("`@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`O+R!296QE87-E('1H92!L;V-K"B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,14-4
M(%)%3$5!4T5?3$]#2R@G)'MS97%N86UE?5]L;V-K)RDB*3L*("`@("`@("`@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\O(%=E(&MN;W<@
M=VAA="!T:&4@<F5S=6QT('=I;&P@8F4L('-O(&YO(&YE960@=&\@=')Y(&%G
M86EN"B`@("`@("`@("`@("`@("!R971U<FX@,3L*"B`@("`@("`@("`@("\J
M*B!/3D1%34%.1"!404),12!#4D5!5$E/3B`J*B\*("`@("`@("`@("`@?2!E
M;'-E:68@*"1O;F1E;6%N9"`F)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@
M("`@("`@("`@("`@("`@)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]2
M7TY/4U5#2%1!0DQ%*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@
M("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E
M<W5L="D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RHJ($)!0TM705)$4R!#3TU0050@*BHO"B`@("`@("`@("`@('T@
M96QS96EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27T%,4D5!
M1%E?15A)4U13*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`O+R!S
M964@7T)#<V5Q=65N8V4H*2!C;VUM96YT"B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]"0W-E<75E;F-E*"1S97%N86UE*3L*("`@("`@("`@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R97!E870@/2`Q
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["@H@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C<F5A=&5397%U96YC92@I"@H@
M("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE
M=R!S97%U96YC90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O
M;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:7,@<F5T=7)N960@:68*
M("`@("`J("`@("`@("`@("`@("!P<F]B;&5M<R!A<FES92X*("`@("`J"B`@
M("`@*B!`:6YT97)N86P*("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&53
M97%U96YC92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@
M("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M
M92D["B`@("`@("`@)')E<R`]("1T:&ES+3YQ=65R>2@B0U)%051%(%1!0DQ%
M("1[<V5Q;F%M97T@(BX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<H
M:60@24Y414=%4B!53E-)1TY%1"!!551/7TE.0U)%345.5"!.3U0@3E5,3"PG
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!04DE-05)9($M%62AI
M9"DI)RD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@("`@("`O+R!I;G-E
M<G0@>6EE;&1S('9A;'5E(#$L(&YE>'1)9"!C86QL('=I;&P@9V5N97)A=&4@
M240@,@H@("`@("`@("1R97,@/2`D=&AI<RT^<75E<GDH(DE.4T525"!)3E1/
M("1[<V5Q;F%M97T@5D%,5453*#`I(BD["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M('T*("`@("`@("`O+R!S;R!R97-E="!T;R!Z97)O"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YQ=65R>2@B55!$051%("1[<V5Q;F%M97T@4T54(&ED(#T@,#LB
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H
M*0H*("`@("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E
M<75E;F-E('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@1$)?3TL@;VX@<W5C8V5S<RX@($1"7T5R<F]R(&EF('!R;V)L96US+@H@
M("`@("H*("`@("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.F1R;W!397%U96YC92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T123U`@5$%"3$4@)R`N("1T
M:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@7T)#<V5Q=65N8V4H*0H*("`@("\J*@H@("`@
M("H@0F%C:W=A<F1S(&-O;7!A=&EB:6QI='D@=VET:"!O;&0@<V5Q=65N8V4@
M96UU;&%T:6]N(&EM<&QE;65N=&%T:6]N"B`@("`@*B`H8VQE86X@=7`@=&AE
M(&1U<&5S*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<6YA;64@
M5&AE('-E<75E;F-E(&YA;64@=&\@8VQE86X@=7`*("`@("`J($!R971U<FX@
M;6EX960@1$)?17)R;W(@;W(@=')U90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M0D-S97%U96YC92@D<V5Q;F%M92D*("`@('L*("`@("`@("`O+R!/8G1A:6X@
M82!U<V5R+6QE=F5L(&QO8VLN+BX@=&AI<R!W:6QL(')E;&5A<V4@86YY('!R
M979I;W5S"B`@("`@("`@+R\@87!P;&EC871I;VX@;&]C:W,L(&)U="!U;FQI
M:V4@3$]#2R!404),15,L(&ET(&1O97,@;F]T(&%B;W)T"B`@("`@("`@+R\@
M=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX@86YD(&ES(&UU8V@@;&5S<R!F<F5Q
M=65N=&QY('5S960N"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YG971/;F4H
M(E-%3$5#5"!'151?3$]#2R@G)'MS97%N86UE?5]L;V-K)RPQ,"DB*3L*("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(&EF("@D<F5S=6QT
M(#T](#`I('L*("`@("`@("`@("`@+R\@1F%I;&5D('1O(&=E="!T:&4@;&]C
M:RP@8V%N)W0@9&\@=&AE(&-O;G9E<G-I;VXL(&)A:6P*("`@("`@("`@("`@
M+R\@=VET:"!A($1"7T524D]27TY/5%],3T-+140@97)R;W(*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]4
M7TQ/0TM%1"D["B`@("`@("`@?0H*("`@("`@("`D:&EG:&5S=%]I9"`]("1T
M:&ES+3YG971/;F4H(E-%3$5#5"!-05@H:60I($923TT@)'MS97%N86UE?2(I
M.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D:&EG:&5S=%]I9"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1H:6=H97-T7VED.PH@("`@("`@('T*("`@("`@
M("`O+R!4:&ES('-H;W5L9"!K:6QL(&%L;"!R;W=S(&5X8V5P="!T:&4@:&EG
M:&5S=`H@("`@("`@("\O(%=E('-H;W5L9"!P<F]B86)L>2!D;R!S;VUE=&AI
M;F<@:68@)&AI9VAE<W1?:60@:7-N)W0*("`@("`@("`O+R!N=6UE<FEC+"!B
M=70@22=M(&%T(&$@;&]S<R!A<R!H;W<@=&\@:&%N9&QE('1H870N+BX*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*")$14Q%5$4@1E)/32`D>W-E
M<6YA;65](%=(15)%(&ED(#P^("1H:6=H97-T7VED(BD["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@268@86YO=&AE<B!T:')E
M860@:&%S(&)E96X@=V%I=&EN9R!F;W(@=&AI<R!L;V-K+`H@("`@("`@("\O
M(&ET('=I;&P@9V\@=&AR=2!T:&4@86)O=F4@<')O8V5D=7)E+"!B=70@=VEL
M;"!H879E(&YO"B`@("`@("`@+R\@<F5A;"!E9F9E8W0*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,14-4(%)%3$5!4T5?3$]#2R@G)'MS
M97%N86UE?5]L;V-K)RDB*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[('%U;W1E261E;G1I9FEE<B@I"@H@("`@+RHJ"B`@("`@*B!1=6]T
M92!A('-T<FEN9R!S;R!I="!C86X@8F4@<V%F96QY('5S960@87,@82!T86)L
M92!O<B!C;VQU;6X@;F%M90H@("`@("H*("`@("`J(%%U;W1I;F<@<W1Y;&4@
M9&5P96YD<R!O;B!W:&EC:"!D871A8F%S92!D<FEV97(@:7,@8F5I;F<@=7-E
M9"X*("`@("`J"B`@("`@*B!->5-13"!C86XG="!H86YD;&4@=&AE(&)A8VMT
M:6-K(&-H87)A8W1E<B`H/&MB9#Y@/"]K8F0^*2!I;@H@("`@("H@=&%B;&4@
M;W(@8V]L=6UN(&YA;65S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'-T<B`@:61E;G1I9FEE<B!N86UE('1O(&)E('%U;W1E9`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!Q=6]T960@:61E;G1I9FEE<B!S=')I;F<*
M("`@("`J"B`@("`@*B!`<VEN8V4@,2XV+C`*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`:6YT97)N86P*("`@("`J+PH@("`@9G5N8W1I;VX@<75O
M=&5)9&5N=&EF:65R*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N("=@)R`N
M("1S='(@+B`G8"<["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O
M=&4H*0H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960@($1E<')E8V%T960@
M:6X@<F5L96%S92`Q+C8N,`H@("`@("H@0&EN=&5R;F%L"B`@("`@*B\*("`@
M(&9U;F-T:6]N('%U;W1E*"1S='(I('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G%U;W1E4VUA<G0H)'-T<BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@97-C87!E4VEM<&QE*"D*"B`@("`O*BH*("`@("`J($5S8V%P92!A('-T
M<FEN9R!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@1$)-4R=S('-T86YD87)D
M<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@=&AE('-T<FEN
M9R!T;R!B92!E<V-A<&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!E<V-A<&5D('-T<FEN9PH@("`@("H*("`@("`J($!I;G1E<FYA;`H@
M("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&53:6UP;&4H)'-T<BD@>PH@("`@
M("`@(&EF*&9U;F-T:6]N7V5X:7-T<R@G;7ES<6Q?<F5A;%]E<V-A<&5?<W1R
M:6YG)RDI('L*("`@("`@("`@("`@<F5T=7)N(&UY<W%L7W)E86Q?97-C87!E
M7W-T<FEN9R@D<W1R+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(&UY<W%L7V5S8V%P95]S=')I;F<H
M)'-T<BD["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&UO9&EF>5%U97)Y*"D*"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R>2@D<75E
M<GDI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4*2!["B`@("`@
M("`@("`@("\O(")$14Q%5$4@1E)/32!T86)L92(@9VEV97,@,"!A9F9E8W1E
M9"!R;W=S(&EN($UY4U%,+@H@("`@("`@("`@("`O+R!4:&ES(&QI='1L92!H
M86-K(&QE=',@>6]U(&MN;W<@:&]W(&UA;GD@<F]W<R!W97)E(&1E;&5T960N
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EQS*D1%3$5415QS*T92
M3TU<<RLH7%,K*5QS*B0O:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@("`@
M("1Q=65R>2`]('!R96=?<F5P;&%C92@G+UY<<RI$14Q%5$5<<RM&4D]-7',K
M*%Q3*RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)T1%3$5412!&4D]-(%PQ(%=(15)%(#$],2<L("1Q=65R>2D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1Q=65R>3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,:6UI=%%U97)Y
M*"D*"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y*"1Q=65R>2P@)&9R
M;VTL("1C;W5N="D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'%U
M97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@)'%U97)Y("X@(B!,24U)5"`D
M8V]U;G0B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D
M<75E<GD@+B`B($Q)34E4("1F<F]M+"`D8V]U;G0B.PH@("`@("`@('T*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M>7-Q;%)A:7-E17)R;W(H*0H*
M("`@("\J*@H@("`@("H@1V%T:&5R(&EN9F]R;6%T:6]N(&%B;W5T(&%N(&5R
M<F]R+"!T:&5N('5S92!T:&%T(&EN9F\@=&\@8W)E871E(&$*("`@("`J($1"
M(&5R<F]R(&]B:F5C="!A;F0@9FEN86QL>2!R971U<FX@=&AA="!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!I;G1E9V5R("`D97)R;F\@(%!%05(@
M97)R;W(@;G5M8F5R("AU<W5A;&QY(&$@1$(@8V]N<W1A;G0I(&EF"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@;6%N=6%L;'D@<F%I<VEN9R!A
M;B!E<G)O<@H@("`@("H@0')E='5R;B!O8FIE8W0@($1"(&5R<F]R(&]B:F5C
M=`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F5R<F]R0V]D92@I"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UY<W%L4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R<FYO
M(#T@)'1H:7,M/F5R<F]R0V]D92AM>7-Q;%]E<G)N;R@D=&AI<RT^8V]N;F5C
M=&EO;BDI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!`;7ES<6Q?97)R;F\H)'1H:7,M/F-O;FYE
M8W1I;VXI("X@)R`J*B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@0&UY<W%L7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N*2D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L92!O<B!A
M(')E<W5L="!S970N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C='QS=')I
M;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U97)Y(&]R
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I
M;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE"B`@("`@*B!`<&%R
M86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@
M;6]D90H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R
M87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D"B`@("`@*B`@("`@
M("`@("`@("`@("!O<B!A;B!E<G)O<B!O8FIE8W0@:68@<V]M971H:6YG(&ES
M('=R;VYG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&EN=&5R;F%L
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E(#T@;G5L;"D@
M>PH@("`@("`@(&EF("AI<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@
M("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@
M<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S
M=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G
M;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*&ES7W-T<FEN
M9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0
M<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@("`J
M($-R96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@
M("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@0&UY<W%L7VQI<W1?9FEE;&1S
M*"1T:&ES+3YD<VY;)V1A=&%B87-E)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT+"`D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R
M96-E:79E9"!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@
M("`@("`@*B!#;W!Y(&ET+@H@("`@("`@("`@("`@*B!$97!R96-A=&5D+B`@
M2&5R92!F;W(@8V]M<&%T:6)I;&ET>2!O;FQY+@H@("`@("`@("`@("`@*B\*
M("`@("`@("`@("`@)&ED(#T@)')E<W5L=#L*("`@("`@("`@("`@)&=O=%]S
M=')I;F<@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<F5S
M;W5R8V4H)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L
M4F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A
M<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@
M("`@("`D8V]U;G0@/2!`;7ES<6Q?;G5M7V9I96QD<R@D:60I.PH*("`@("`@
M("`O+R!M861E('1H:7,@248@9'5E('1O('!E<F9O<FUA;F-E("AO;F4@:68@
M:7,@9F%S=&5R('1H86X@)&-O=6YT(&EF)W,I"B`@("`@("`@:68@*"$D;6]D
M92D@>PH@("`@("`@("`@("!F;W(@*"1I/3`[("1I/"1C;W5N=#L@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)W1A8FQE)UT@/2`D8V%S95]F
M=6YC*$!M>7-Q;%]F:65L9%]T86)L92@D:60L("1I*2D["B`@("`@("`@("`@
M("`@("`D<F5S6R1I75LG;F%M92==("`]("1C87-E7V9U;F,H0&UY<W%L7V9I
M96QD7VYA;64H)&ED+"`D:2DI.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;
M)W1Y<&4G72`@/2!`;7ES<6Q?9FEE;&1?='EP92@D:60L("1I*3L*("`@("`@
M("`@("`@("`@("1R97-;)&E=6R=L96XG72`@(#T@0&UY<W%L7V9I96QD7VQE
M;B@D:60L("1I*3L*("`@("`@("`@("`@("`@("1R97-;)&E=6R=F;&%G<R==
M(#T@0&UY<W%L7V9I96QD7V9L86=S*"1I9"P@)&DI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L@+R\@9G5L;`H@("`@("`@("`@("`D<F5S6R=N
M=6U?9FEE;&1S)UT]("1C;W5N=#L*"B`@("`@("`@("`@(&9O<B`H)&D],#L@
M)&D\)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG
M=&%B;&4G72`]("1C87-E7V9U;F,H0&UY<W%L7V9I96QD7W1A8FQE*"1I9"P@
M)&DI*3L*("`@("`@("`@("`@("`@("1R97-;)&E=6R=N86UE)UT@(#T@)&-A
M<V5?9G5N8RA`;7ES<6Q?9FEE;&1?;F%M92@D:60L("1I*2D["B`@("`@("`@
M("`@("`@("`D<F5S6R1I75LG='EP92==("`]($!M>7-Q;%]F:65L9%]T>7!E
M*"1I9"P@)&DI.PH@("`@("`@("`@("`@("`@)')E<ULD:5U;)VQE;B==("`@
M/2!`;7ES<6Q?9FEE;&1?;&5N*"1I9"P@)&DI.PH@("`@("`@("`@("`@("`@
M)')E<ULD:5U;)V9L86=S)UT@/2!`;7ES<6Q?9FEE;&1?9FQA9W,H)&ED+"`D
M:2D["@H@("`@("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/
M7T]21$52*2!["B`@("`@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G75LD
M<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$525$%"
M3$4I('L*("`@("`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;
M)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O(&9R964@=&AE(')E<W5L="!O;FQY(&EF('=E('=E<F4@8V%L;&5D
M(&]N(&$@=&%B;&4*("`@("`@("!I9B`H)&=O=%]S=')I;F<I('L*("`@("`@
M("`@("`@0&UY<W%L7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!Q=65R>2!N965D960@=&\@9V5T('-O;64@8F%C:V5N9"!I;F9O"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T>7!E(%=H870@:VEN9"!O9B!I;F9O('EO=2!W
M86YT('1O(')E=')I979E"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@4U%,
M('%U97)Y('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L
M475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@
M("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("=32$]7(%1!0DQ%4R<["B`@("`@("`@("`@(&-A<V4@)W9I97=S)SH*
M("`@("`@("`@("`@("`@(')E='5R;B!$0E]%4E)/4E].3U1?0T%004),13L*
M("`@("`@("`@("`@8V%S92`G=7-E<G,G.@H@("`@("`@("`@("`@("`@)'-Q
M;"`]("=S96QE8W0@9&ES=&EN8W0@57-E<B!F<F]M('5S97(G.PH@("`@("`@
M("`@("`@("`@:68H)'1H:7,M/F1S;ELG9&%T86)A<V4G72`A/2`G;7ES<6PG
M*2!["B`@("`@("`@("`@("`@("`@("`@)&1S;B`]("1T:&ES+3YD<VX["B`@
M("`@("`@("`@("`@("`@("`@)&1S;ELG9&%T86)A<V4G72`]("=M>7-Q;"<[
M"B`@("`@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1D8B`]($1"
M.CIC;VYN96-T*"1D<VXI*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)&1B.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D<W%L(#T@)&1B+3YG971#;VPH)'-Q;"D["B`@("`@("`@("`@
M("`@("`@("`@)&1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@("`@("`@
M("`@+R\@6%A8($9I>&UE('1H92!M>7-Q;"!D<FEV97(@<VAO=6QD('1A:V4@
M8V%R92!O9B!T:&ES"B`@("`@("`@("`@("`@("`@("`@:68@*"%`;7ES<6Q?
M<V5L96-T7V1B*"1T:&ES+3YD<VY;)V1A=&%B87-E)UTL("1T:&ES+3YC;VYN
M96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(')E='5R;B`D<W%L.PH@("`@("`@("`@("!C87-E("=D871A
M8F%S97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=32$]7($1!5$%"05-%
M4R<["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U
M<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@
M*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC
M+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O1$(O;V1B8RYP:'``````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-#$S,C,`,3`T,3<S-C,P,#8`,#$W,C4P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT(&9O
M;&1M971H;V0];6%R:V5R.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%-T:6<@0F%K:V5N(#QS
M<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@36%I;G1A:6YE<CH@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!O9&)C+G!H<"QV(#$N
M-#(@,C`P-"\P,B\Q."`R,SHP-SHQ,"!D86YI96QC($5X<"`D"@H*+R\@6%A8
M(&QE9V5N9#H*+R\@($UO<F4@:6YF;R!O;B!/1$)#(&5R<F]R<R!C;W5L9"!B
M92!F;W5N9"!H97)E.@HO+R`@:'1T<#HO+VUS9&XN;6EC<F]S;V9T+F-O;2]L
M:6)R87)Y+V1E9F%U;'0N87-P/W5R;#TO;&EB<F%R>2]E;BUU<R]T<F)L<W%L
M+W1R7V5R<E]O9&)C7S5S='HN87-P"B\O"B\O(%A86"!%4E)/4DU31SH@5&AE
M(&5R<F]R(&UE<W-A9V4@9G)O;2!T:&4@;V1B8R!F=6YC=&EO;B!S:&]U;&0*
M+R\@("`@("`@("`@("`@("`@(&)E(')E9VES=&5R960@:&5R92X*"@IR97%U
M:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J($1A=&%B87-E(&EN
M9&5P96YD96YT('%U97)Y(&EN=&5R9F%C92!D969I;FET:6]N(&9O<B!02%`G
M<R!/1$)#"B`J(&5X=&5N<VEO;BX*("H*("H@0'!A8VMA9V4@($1""B`J($!V
M97)S:6]N("`D260Z(&]D8F,N<&AP+'8@,2XT,B`R,#`T+S`R+S$X(#(S.C`W
M.C$P(&1A;FEE;&,@17AP("0*("H@0&-A=&5G;W)Y($1A=&%B87-E"B`J($!A
M=71H;W(@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J+PIC;&%S<R!$
M0E]O9&)C(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T
M:65S"@H@("`@=F%R("1C;VYN96-T:6]N.PH@("`@=F%R("1P:'!T>7!E+"`D
M9&)S>6YT87@["B`@("!V87(@)')O=R`](&%R<F%Y*"D["@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("!F=6YC=&EO;B!$0E]O9&)C
M*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("`@("`@
M)'1H:7,M/G!H<'1Y<&4@/2`G;V1B8R<["B`@("`@("`@)'1H:7,M/F1B<WEN
M=&%X(#T@)W-Q;#DR)SL*("`@("`@("`D=&AI<RT^9F5A='5R97,@/2!A<G)A
M>2@*("`@("`@("`@("`@)W!R97!A<F4G(#T^('1R=64L"B`@("`@("`@("`@
M("=P8V]N;F5C="<@/3X@=')U92P*("`@("`@("`@("`@)W1R86YS86-T:6]N
M<R<@/3X@9F%L<V4L"B`@("`@("`@("`@("=L:6UI="<@/3X@)V5M=6QA=&4G
M"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<"`](&%R
M<F%Y*`H@("`@("`@("`@("`G,#$P,#0G(#T^($1"7T524D]27U1254Y#051%
M1"P*("`@("`@("`@("`@)S`W,#`Q)R`]/B!$0E]%4E)/4E]-25--051#2"P*
M("`@("`@("`@("`@)S(Q4S`Q)R`]/B!$0E]%4E)/4E]-25--051#2"P*("`@
M("`@("`@("`@)S(Q4S`R)R`]/B!$0E]%4E)/4E]-25--051#2"P*("`@("`@
M("`@("`@)S(R,#`S)R`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@
M("`@("`@("`@)S(R,#`U)R`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*
M("`@("`@("`@("`@)S(R,#`X)R`]/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L
M"B`@("`@("`@("`@("<R,C`Q,B<@/3X@1$)?15)23U)?1$E66D523RP*("`@
M("`@("`@("`@)S(S,#`P)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@
M("`@("`@("`G,C,U,#(G(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY5
M3$PL"B`@("`@("`@("`@("<R,S4P,R<@/3X@1$)?15)23U)?0T].4U1204E.
M5"P*("`@("`@("`@("`@)S(S-3`U)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4
M+`H@("`@("`@("`@("`G,C0P,#`G(#T^($1"7T524D]27TE.5D%,240L"B`@
M("`@("`@("`@("<S-#`P,"<@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@
M("`@("`@)S,W,#`P)R`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@
M("<T,C`P,"<@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`G-#(V
M,#$G(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`@("`@)TE-,#`Q)R`]
M/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`@("`@)U,P,#`P)R`]
M/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`@("`@)U,P,#`Q)R`]
M/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@("`@)U,P,#`R
M)R`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`@("`@)U,P,#$Q
M)R`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@("`@)U,P
M,#$R)R`]/B!$0E]%4E)/4E].3U1?1D]53D0L"B`@("`@("`@("`@("=3,#`R
M,2<@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@("=3
M,#`R,B<@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@("`@("=3
M,3`P,"<@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@
M("`@("`@)U,Q,#`Y)R`]/B!$0E]%4E)/4E])3E9!3$E$+`H@("`@("`@("`@
M("`G4S$P.3`G(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@("`@("=3
M,4,P,"<@/3X@1$)?15)23U)?3D]47T-!4$%"3$4*("`@("`@("`I.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J*@H@
M("`@("H@0V]N;F5C="!T;R!A(&1A=&%B87-E(&%N9"!L;V<@:6X@87,@=&AE
M('-P96-I9FEE9"!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2`D9'-N('1H
M92!D871A('-O=7)C92!N86UE("AS964@1$(Z.G!A<G-E1%-.(&9O<B!S>6YT
M87@I"B`@("`@*B!`<&%R86T@)'!E<G-I<W1E;G0@*&]P=&EO;F%L*2!W:&5T
M:&5R('1H92!C;VYN96-T:6]N('-H;W5L9`H@("`@("H@("`@("`@(&)E('!E
M<G-I<W1E;G0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!$0E]/2R!O;B!S
M=6-C97-S+"!A($1"(&5R<F]R(&-O9&4@;VX@9F%I;'5R90H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VYN96-T*"1D<VYI;F9O+"`D<&5R<VES=&5N="`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@A1$(Z.F%S<V5R=$5X=&5N<VEO;B@G
M;V1B8R<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YD<VX@/2`D9'-N:6YF;SL*("`@("`@("!I9B`H)&1S
M;FEN9F];)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M/F1B<WEN
M=&%X(#T@)&1S;FEN9F];)V1B<WEN=&%X)UT["B`@("`@("`@?0H@("`@("`@
M('-W:71C:"`H)'1H:7,M/F1B<WEN=&%X*2!["B`@("`@("`@("`@(&-A<V4@
M)W-O;&ED)SH*("`@("`@("`@("`@("`@("1T:&ES+3YF96%T=7)E<R`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("=P<F5P87)E)R`]/B!T<G5E+`H@
M("`@("`@("`@("`@("`@("`@("=P8V]N;F5C="<@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`G=')A;G-A8W1I;VYS)R`]/B!T<G5E"B`@("`@("`@
M("`@("`@("`I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@)VYA=FES:6]N)SH*("`@("`@("`@("`@("`@("\O('1H92!.879I
M<VEO;B!D<FEV97(@9&]E<VXG="!S=7!P;W)T(&9E=&-H(')O=R!B>2!N=6UB
M97(*("`@("`@("`@("`@("`@("1T:&ES+3YF96%T=7)E<ULG;&EM:70G72`]
M(&9A;'-E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@)V%C8V5S<R<Z"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]%4E)/4E,I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LG,#<P
M,#$G72`]($1"7T524D]27TY/4U5#2$9)14Q$.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\J
M"B`@("`@("`@("H@5&AI<R!I<R!H96%R(&9O<B!B86-K=V%R9',@8V]M<&%T
M:6)I;&ET>2X*("`@("`@("`@*B!3:&]U;&0@:&%V92!B965N('5S:6YG("=D
M871A8F%S92<@86QL(&%L;VYG+"!B=70@=7-E9"!H;W-T<W!E8RX*("`@("`@
M("`@*B\*("`@("`@("!I9B`H)&1S;FEN9F];)V1A=&%B87-E)UTI('L*("`@
M("`@("`@("`@)&]D8F-D<VX@/2`D9'-N:6YF;ULG9&%T86)A<V4G73L*("`@
M("`@("!](&5L<V5I9B`H)&1S;FEN9F];)VAO<W1S<&5C)UTI('L*("`@("`@
M("`@("`@)&]D8F-D<VX@/2`D9'-N:6YF;ULG:&]S='-P96,G73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;V1B8V1S;B`]("=L;V-A;&AO<W0G
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YP<F]V:61E<R@G<&-O
M;FYE8W0G*2D@>PH@("`@("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P
M97)S:7-T96YT(#\@)V]D8F-?<&-O;FYE8W0G(#H@)V]D8F-?8V]N;F5C="<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;FYE8W1?9G5N8W1I
M;VX@/2`G;V1B8U]C;VYN96-T)SL*("`@("`@("!]"B`@("`@("`@)&-O;FX@
M/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&]D8F-D<VXL("1D<VYI;F9O6R=U<V5R
M;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M<VYI;F9O6R=P87-S=V]R9"==*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E
M*"1C;VYN*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L(&YU;&PL(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@)'1H
M:7,M/F5R<F]R3F%T:79E*"DI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M8V]N;F5C=&EO;B`]("1C;VYN.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("!F
M=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D97)R(#T@0&]D
M8F-?8VQO<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC
M;VYN96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)&5R<CL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ
M"B`@("`@*B!396YD(&$@<75E<GD@=&\@3T1"0R!A;F0@<F5T=7)N('1H92!R
M97-U;'1S(&%S(&$@3T1"0R!R97-O=7)C90H@("`@("H@:61E;G1I9FEE<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@)'%U97)Y('1H92!344P@<75E<GD*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="!R971U<FYS(&$@=F%L:60@3T1"0R!R
M97-U;'0@9F]R('-U8V-E<W-F=6P@4T5,14-4"B`@("`@*B!Q=65R:65S+"!$
M0E]/2R!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S+B`@02!$0B!E<G)O
M<B!C;V1E"B`@("`@*B!I<R!R971U<FYE9"!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@
M("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@("`@)'%U97)Y
M(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D["B`@("`@("`@)')E<W5L
M="`]($!O9&)C7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL("1Q=65R>2D["B`@
M("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;V1B8U)A:7-E17)R;W(H*3L@+R\@6%A8($524D]235-'"B`@("`@("`@
M?0H@("`@("`@("\O($1E=&5R;6EN92!W:&EC:"!Q=65R:65S('1H870@<VAO
M=6QD(')E='5R;B!D871A+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U;&0@
M<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*("`@("`@("!I9B`H1$(Z.FES
M36%N:7`H)'%U97)Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^;6%N:7!?<F5S
M=6QT(#T@)')E<W5L=#L@+R\@1F]R(&%F9F5C=&5D4F]W<R@I"B`@("`@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G)O
M=ULH:6YT*21R97-U;'1=(#T@,#L*("`@("`@("`D=&AI<RT^;6%N:7!?<F5S
M=6QT(#T@,#L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J
M($UO=F4@=&AE(&EN=&5R;F%L(&]D8F,@<F5S=6QT('!O:6YT97(@=&\@=&AE
M(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A
M('9A;&ED(&9B<W%L(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@
M<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*
M("`@("`@("!R971U<FX@;V1B8U]N97AT7W)E<W5L="@D<F5S=6QT*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J
M*@H@("`@("H@1F5T8V@@82!R;W<@86YD(&EN<V5R="!T:&4@9&%T82!I;G1O
M(&%N(&5X:7-T:6YG(&%R<F%Y+@H@("`@("H*("`@("`J($9O<FUA=&EN9R!O
M9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@87)E(&-O;F9I9W5R
M86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&9O<B!M
M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C
M92`D<F5S=6QT("`@('%U97)Y(')E<W5L="!I9&5N=&EF:65R"B`@("`@*B!`
M<&%R86T@87)R87D@("`@)&%R<B`@("`@("`H<F5F97)E;F-E*2!A<G)A>2!W
M:&5R92!D871A(&9R;VT@=&AE(')O=PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<VAO=6QD(&)E('!L86-E9`H@("`@("H@0'!A<F%M(&EN
M="`@("`@("1F971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO
M=6QD(&)E(&EN9&5X960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M
M("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!$0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@96YD(&]F
M(')E<W5L="!S970@:7,*("`@("`J("`@("`@("`@("`@("`@<F5A8VAE9"!O
M<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E
M=&-H26YT;R@I"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L("8D87)R+"`D9F5T8VAM;V1E
M+"`D<F]W;G5M/6YU;&PI"B`@("!["B`@("`@("`@)&%R<B`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@("`@("`@
M)')O=VYU;2LK.R`O+R!/1$)#(&9I<G-T(')O=R!I<R`Q"B`@("`@("`@("`@
M(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-"XR+C`G+"`G
M9V4G*2D@>PH@("`@("`@("`@("`@("`@)&-O;',@/2!O9&)C7V9E=&-H7VEN
M=&\H)')E<W5L="P@)&%R<BP@)')O=VYU;2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D8V]L<R`](&]D8F-?9F5T8VA?:6YT;R@D
M<F5S=6QT+"`D<F]W;G5M+"`D87)R*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1C;VQS(#T@;V1B8U]F971C:%]I;G1O
M*"1R97-U;'0L("1A<G(I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D8V]L
M<RD@>PH@("`@("`@("`@("`O*B!86%@@1DE8344Z(&1O97-N)W0@=V]R:R!W
M:71H('5N:7A/1$)#(&%N9"!E87-Y<V]F=`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("AG970@8V]R<G5P=&5D("1E<G)N;R!V86QU97,I"B`@("`@("`@
M("`@(&EF("@D97)R;F\@/2!O9&)C7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y286ES945R<F]R
M*"1E<G)N;RD["B`@("`@("`@("`@('TJ+PH@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@(3T]($1"
M7T9%5$-(34]$15]/4D1%4D5$*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(&-O=6YT*"1A<G(I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D
M8V]L3F%M92`](&]D8F-?9FEE;&1?;F%M92@D<F5S=6QT+"`D:2LQ*3L*("`@
M("`@("`@("`@("`@("1A6R1C;VQ.86UE72`]("1A<G);)&E=.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@
M("`@("`@("`@)&$@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&$L($-!4T5?
M3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A<G(@/2`D83L*
M("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@
M)'1H:7,M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]0
M3U)404))3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!F<F5E4F5S=6QT*"D*"B`@("!F=6YC=&EO;B!F<F5E4F5S
M=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@=6YS970H)'1H:7,M/G)O=ULH
M:6YT*21R97-U;'1=*3L*("`@("`@("!R971U<FX@0&]D8F-?9G)E95]R97-U
M;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M
M0V]L<R@I"@H@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT*0H@("`@>PH@
M("`@("`@("1C;VQS(#T@0&]D8F-?;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@
M("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C
M;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D4F]W
M<R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N=6UB97(@;V8@<F]W
M<R!A9F9E8W1E9"!B>2!A(&UA;FEP=6QA=&EV92!Q=65R>0H@("`@("H@*$E.
M4T525"P@1$5,151%+"!54$1!5$4I"B`@("`@*B!`<F5T=7)N(&UI>&5D(&EN
M="!A9F9E8W1E9"!R;W=S+"`P('=H96X@;F]N(&UA;FEP('%U97)I97,@;W(*
M("`@("`J("`@("`@("`@("`@("`@1$(@97)R;W(@;VX@97)R;W(*("`@("`J
M+PH@("`@9G5N8W1I;VX@869F96-T9612;W=S*"D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/FUA;FEP7W)E<W5L="DI('L@("\O($EN(&-A<V4@
M;V8@4T5,14-4('-T;7,*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?0H@("`@("`@("1N<F]W<R`](&]D8F-?;G5M7W)O=W,H)'1H:7,M/FUA;FEP
M7W)E<W5L="D["B`@("`@("`@:68@*"1N<F]W<R`]/2`M,2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F]D8F-286ES945R<F]R*"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D;G)O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!/1$)#(&UA>2!O
M<B!M87D@;F]T('-U<'!O<G0@8V]U;G1I;F<@<F]W<R!I;B!T:&4@<F5S=6QT
M('-E="!O9@H@("`@("H@4T5,14-4<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M)')E<W5L="!T:&4@;V1B8R!R97-U;'0@<F5S;W5R8V4*("`@("`J($!R971U
M<FX@=&AE(&YU;6)E<B!O9B!R;W=S+"!O<B`P"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*("`@("`@("`D;G)O=W,@/2!O
M9&)C7VYU;5]R;W=S*"1R97-U;'0I.PH@("`@("`@(&EF("@D;G)O=W,@/3T@
M+3$I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O
M<BA$0E]%4E)/4E]53E-54%!/4E1%1"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D;G)O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O
M=&5)9&5N=&EF:65R*"D*"B`@("`O*BH*("`@("`J(%%U;W1E(&$@<W1R:6YG
M('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!A<R!A('1A8FQE("\@8V]L=6UN
M(&YA;64*("`@("`J"B`@("`@*B!1=6]T:6YG('-T>6QE(&1E<&5N9',@;VX@
M=VAI8V@@9&)S>6YT87@@=V%S('!A<W-E9"!I;B!T:&4@1%-.+@H@("`@("H*
M("`@("`J(%5S92`G;7-S<6PG(&%S('1H92!D8G-Y;G1A>"!I;B!T:&4@1$(@
M1%-.(&]N;'D@:68@>6]U)W9E('5N8VAE8VME9`H@("`@("H@(E5S92!!3E-)
M('%U;W1E9"!I9&5N=&EF:65R<R(@=VAE;B!S971T:6YG('5P('1H92!/1$)#
M(&1A=&$@<V]U<F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T
M<B`@:61E;G1I9FEE<B!N86UE('1O(&)E('%U;W1E9`H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!Q=6]T960@:61E;G1I9FEE<B!S=')I;F<*("`@
M("`J"B`@("`@*B!`<VEN8V4@,2XV+C`*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E261E;G1I9FEE<B@D<W1R*0H@
M("`@>PH@("`@("`@('-W:71C:"`H)'1H:7,M/F1S;ELG9&)S>6YT87@G72D@
M>PH@("`@("`@("`@("!C87-E("=A8V-E<W,G.@H@("`@("`@("`@("`@("`@
M<F5T=7)N("=;)R`N("1S='(@+B`G72<["B`@("`@("`@("`@(&-A<V4@)VUS
M<W%L)SH*("`@("`@("`@("`@8V%S92`G<WEB87-E)SH*("`@("`@("`@("`@
M("`@(')E='5R;B`G6R<@+B!S=')?<F5P;&%C92@G72<L("==72<L("1S='(I
M("X@)UTG.PH@("`@("`@("`@("!C87-E("=M>7-Q;"<Z"B`@("`@("`@("`@
M(&-A<V4@)VUY<W%L:2<Z"B`@("`@("`@("`@("`@("!R971U<FX@)V`G("X@
M)'-T<B`N("=@)SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@(')E='5R;B`G(B<@+B!S=')?<F5P;&%C92@G(B<L("<B(B<L("1S='(I
M("X@)R(G.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!Q=6]T92@I"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@1&5P<F5C
M871E9"!I;B!R96QE87-E(#$N-BXP"B`@("`@*B!`:6YT97)N86P*("`@("`J
M+PH@("`@9G5N8W1I;VX@<75O=&4H)'-T<BD@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^<75O=&53;6%R="@D<W1R*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE
M(&YA=&EV92!E<G)O<B!C;V1E(&]F('1H92!L87-T(&5R<F]R("AI9B!A;GDI
M('1H870*("`@("`J(&]C8W5R960@;VX@=&AE(&-U<G)E;G0@8V]N;F5C=&EO
M;BX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J
M($!R971U<FX@:6YT($]$0D,@97)R;W(@8V]D90H@("`@("HO"B`@("!F=6YC
M=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^8V]N;F5C=&EO;BD@?'P@(6ES7W)E<V]U<F-E*"1T:&ES+3YC;VYN
M96-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@;V1B8U]E<G)O<B@I("X@
M)R`G("X@;V1B8U]E<G)O<FUS9R@I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@;V1B8U]E<G)O<B@D=&AI<RT^8V]N;F5C=&EO;BD@+B`G("<@+B!O9&)C
M7V5R<F]R;7-G*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E
M;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U
M92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X
M:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU
M;6)E<B!I;B!T:&4@<V5Q=65N8V4N("!$0E]%<G)O<B!I9B!P<F]B;&5M+@H@
M("`@("H*("`@("`J($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.FYE>'1)1"@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@
M("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M
M92@D<V5Q7VYA;64I.PH@("`@("`@("1R97!E870@/2`P.PH@("`@("`@(&1O
M('L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ
M=65R>2@B=7!D871E("1[<V5Q;F%M97T@<V5T(&ED(#T@:60@*R`Q(BD["B`@
M("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@
M("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="D@)B8*
M("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%4E)/
M4E].3U-50TA404),12D@>PH@("`@("`@("`@("`@("`@)')E<&5A="`](#$[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T
M:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M<75E<GDH(FEN<V5R="!I;G1O("1[<V5Q;F%M97T@*&ED*2!V86QU97,H,"DB
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97!E
M870@/2`P.PH@("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A
M="D["@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@
M("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*")S96QE
M8W0@:60@9G)O;2`D>W-E<6YA;65](BD["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"
M7T9%5$-(34]$15]/4D1%4D5$*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')O=R!\?"`A)')O=RDI('L*("`@("`@("`@("`@<F5T=7)N("1R;W<["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')O=ULP73L*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E
M<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U
M8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!I<R!R971U<FYE9"!I9@H@("`@
M("H@("`@("`@("`@("`@('!R;V)L96US(&%R:7-E+@H@("`@("H*("`@("`J
M($!I;G1E<FYA;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E
M;F-E*"D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("`D
M<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*
M("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*")#4D5!5$4@5$%"3$4@)'MS
M97%N86UE?2`B+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RAI9"!I
M;G1E9V5R($Y/5"!.54Q,+"<N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G(%!224U!4ED@2T59*&ED*2DG*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E
M<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q
M7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($1"
M7T5R<F]R(&EF('!R;V)L96US+@H@("`@("H*("`@("`J($!I;G1E<FYA;`H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N
M8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M
M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@(')E='5R;B`D
M=&AI<RT^<75E<GDH(D123U`@5$%"3$4@)'MS97%N86UE?2(I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@(&9U;F-T
M:6]N(&%U=&]#;VUM:70H)&]N;V9F(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M:68@*"%`;V1B8U]A=71O8V]M;6ET*"1T:&ES+3YC;VYN96-T:6]N+"`D;VYO
M9F8I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R
M;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&-O;6UI="@I"@H@("`@9G5N8W1I;VX@
M8V]M;6ET*"D*("`@('L*("`@("`@("!I9B`H(4!O9&)C7V-O;6UI="@D=&AI
M<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO
M9&)C4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH*0H*
M("`@(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H(4!O
M9&)C7W)O;&QB86-K*"1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F]D8F-286ES945R<F]R*"D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!O9&)C4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!'871H97(@
M:6YF;W)M871I;VX@86)O=70@86X@97)R;W(L('1H96X@=7-E('1H870@:6YF
M;R!T;R!C<F5A=&4@80H@("`@("H@1$(@97)R;W(@;V)J96-T(&%N9"!F:6YA
M;&QY(')E='5R;B!T:&%T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&EN=&5G97(@("1E<G)N;R`@4$5!4B!E<G)O<B!N=6UB97(@*'5S=6%L;'D@
M82!$0B!C;VYS=&%N="D@:68*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!M86YU86QL>2!R86ES:6YG(&%N(&5R<F]R"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="`@1$(@97)R;W(@;V)J96-T"B`@("`@*B!`<V5E(&5R<F]R3F%T
M:79E*"D*("`@("`J($!S964@1$)?8V]M;6]N.CIE<G)O<D-O9&4H*0H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!O9&)C4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R
M<FYO(#T@)'1H:7,M/F5R<F]R0V]D92AO9&)C7V5R<F]R*"1T:&ES+3YC;VYN
M96-T:6]N*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YE<G)O<DYA=&EV92@I*3L*("`@('T*"B`@
M("`O+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I
M9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T1"+V-O;6UO;BYP:'``````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3<Q-C0W`#$P-#$W,S8S,#`V`#`Q
M-S8T-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\("`@("`@("`@5&]M87,@5BY6+D-O>"`\8V]X
M0&ED96-N970N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!-86EN=&%I;F5R.B!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H
M<"YN970^("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&-O;6UO;BYP:'`L=B`Q+CDQ
M(#(P,#0O,#(O,3D@,#@Z,#@Z,#8@9&%N:65L8R!%>'`@)`H*<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<["@HO*BH*("H@1$)?8V]M;6]N(&ES(&$@8F%S92!C
M;&%S<R!F;W(@1$(@:6UP;&5M96YT871I;VYS+"!A;F0@;75S="!B90H@*B!I
M;FAE<FET960@8GD@86QL('-U8V@*("H*("H@0'!A8VMA9V4@($1""B`J($!V
M97)S:6]N("`D260Z(&-O;6UO;BYP:'`L=B`Q+CDQ(#(P,#0O,#(O,3D@,#@Z
M,#@Z,#8@9&%N:65L8R!%>'`@)`H@*B!`8V%T96=O<GD@1&%T86)A<V4*("H@
M0&%U=&AO<B`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO
M<B`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("HO"F-L87-S
M($1"7V-O;6UO;B!E>'1E;F1S(%!%05(*>PH@("`@+R\@>WM[('!R;W!E<G1I
M97,*"B`@("`O*BH*("`@("`J(&%S<V]C(&]F(&-A<&%B:6QI=&EE<R!F;W(@
M=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@("H@)&9E871U<F5S6R=L:6UI
M="==(#T^("`G96UU;&%T92<@/3X@96UU;&%T92!W:71H(&9E=&-H(')O=R!B
M>2!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)V%L=&5R
M)R`@(#T^(&%L=&5R('1H92!Q=65R>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!F86QS92`@("`@/3X@<VMI<"!R;W=S"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A='5R97,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@87-S;V,@;6%P<&EN9R!N871I=F4@97)R;W(@8V]D97,@
M=&\@1$(@;VYE<PH@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)&5R<F]R8V]D95]M87`@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@1$(@
M='EP92`H;7ES<6PL(&]C:3@L(&]D8F,@971C+BD*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP93L*"B`@("`O*BH*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<')E<&%R95]T;VME;G,[
M"@H@("`@+RHJ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)'!R97!A<F5?='EP97,["@H@("`@+RHJ"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)'!R97!A<F5D7W%U97)I97,["@H@("`@+RHJ"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1P<F5P87)E7VUA
M>'-T;70@/2`P.PH*("`@("\J*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1L87-T7W%U97)Y(#T@)R<["@H@("`@+RHJ"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1F971C:&UO9&4@/2!$0E]&
M151#2$U/1$5?3U)$15)%1#L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D9F5T8VAM;V1E7V]B:F5C=%]C;&%S<R`]("=S
M=&1#;&%S<R<["@H@("`@+RHJ"B`@("`@*B!2=6XM=&EM92!C;VYF:6=U<F%T
M:6]N(&]P=&EO;G,N"B`@("`@*@H@("`@("H@5&AE("=O<'1I;6EZ92<@;W!T
M:6]N(&AA<R!B965N(&1E<')E8V%T960N("!5<V4@=&AE("=P;W)T86)I;&ET
M>2<*("`@("`J(&]P=&EO;B!I;G-T96%D+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`G<&5R<VES
M=&5N="<@/3X@9F%L<V4L"B`@("`@("`@)W-S;"<@/3X@9F%L<V4L"B`@("`@
M("`@)V1E8G5G)R`]/B`P+`H@("`@("`@("=S97%N86UE7V9O<FUA="<@/3X@
M)R5S7W-E<2<L"B`@("`@("`@)V%U=&]F<F5E)R`]/B!F86QS92P*("`@("`@
M("`G<&]R=&%B:6QI='DG(#T^($1"7U!/4E1!0DE,25197TY/3D4L"B`@("`@
M("`@)V]P=&EM:7IE)R`]/B`G<&5R9F]R;6%N8V4G+"`@+R\@1&5P<F5C871E
M9"X@(%5S92`G<&]R=&%B:6QI='DG+@H@("`@*3L*"B`@("`O*BH*("`@("`J
M($1"(&AA;F1L90H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V
M87(@)&1B:#L*"B`@("`O+R!]?7T*("`@("\O('M[>R!T;U-T<FEN9R@I"@H@
M("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=F5R<V%T:6]N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I"B`@("!["B`@("`@("`@)&EN
M9F\@/2!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI.PH@("`@("`@("1I
M;F9O("X]("`G.B`H<&AP='EP93TG("X@)'1H:7,M/G!H<'1Y<&4@+@H@("`@
M("`@("`@("`@("`@("`G+"!D8G-Y;G1A>#TG("X@)'1H:7,M/F1B<WEN=&%X
M("X*("`@("`@("`@("`@("`@("`@)RDG.PH*("`@("`@("!I9B`H)'1H:7,M
M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@)&EN9F\@+CT@)R!;8V]N;F5C
M=&5D72<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN9F\["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7V-O
M;6UO;B@I"B`@("!["B`@("`@("`@)'1H:7,M/E!%05(H)T1"7T5R<F]R)RD[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&53=')I;F<H*0H*
M("`@("\J*@H@("`@("H@1$504D5#051%1#H@475O=&5S(&$@<W1R:6YG('-O
M(&ET(&-A;B!B92!S869E;'D@=7-E9"!W:71H:6X@<W1R:6YG"B`@("`@*B!D
M96QI;6ET97)S(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!Q=6]T960@<W1R:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G%U;W1E4VUA<G0H*2P@1$)?8V]M;6]N.CIE<V-A<&53:6UP;&4H*0H@
M("`@("H@0&1E<')E8V%T960@($1E<')E8V%T960@:6X@<F5L96%S92`Q+C(@
M;W(@;&]W97(*("`@("`J($!I;G1E<FYA;`H@("`@("HO"B`@("!F=6YC=&EO
M;B!Q=6]T95-T<FEN9R@D<W1R:6YG*0H@("`@>PH@("`@("`@("1S=')I;F<@
M/2`D=&AI<RT^<75O=&4H)'-T<FEN9RD["B`@("`@("`@:68@*"1S=')I;F=[
M,'T@/3T@(B<B*2!["B`@("`@("`@("`@(')E='5R;B!S=6)S='(H)'-T<FEN
M9RP@,2P@+3$I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-T<FEN9SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T92@I"@H@("`@+RHJ
M"B`@("`@*B!$15!214-!5$5$.B!1=6]T97,@82!S=')I;F<@<V\@:70@8V%N
M(&)E('-A9F5L>2!U<V5D(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S=')I;F<@=&AE(&EN<'5T('-T<FEN9R!T;R!Q=6]T90H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%1H92!.54Q,('-T<FEN9R!O
M<B!T:&4@<W1R:6YG('%U;W1E<PH@("`@("H@("`@("`@("`@("`@("`@:6X@
M;6%G:6-?<75O=&5?<WEB87-E('-T>6QE"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.G%U;W1E4VUA<G0H*2P@1$)?8V]M;6]N.CIE<V-A<&53:6UP
M;&4H*0H@("`@("H@0&1E<')E8V%T960@($1E<')E8V%T960@:6X@<F5L96%S
M92`Q+C8N,`H@("`@("H@0&EN=&5R;F%L"B`@("`@*B\*("`@(&9U;F-T:6]N
M('%U;W1E*"1S=')I;F<@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B`H
M)'-T<FEN9R`]/3T@;G5L;"D@/R`G3E5,3"<@.B`B)R(N<W1R7W)E<&QA8V4H
M(B<B+"`B)R<B+"`D<W1R:6YG*2XB)R(["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@<75O=&5)9&5N=&EF:65R*"D*"B`@("`O*BH*("`@("`J(%%U
M;W1E(&$@<W1R:6YG('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!A<R!A('1A
M8FQE(&]R(&-O;'5M;B!N86UE"B`@("`@*@H@("`@("H@1&5L:6UI=&EN9R!S
M='EL92!D97!E;F1S(&]N('=H:6-H(&1A=&%B87-E(&1R:79E<B!I<R!B96EN
M9R!U<V5D+@H@("`@("H*("`@("`J($Y/5$4Z(&IU<W0@8F5C875S92!Y;W4@
M0T%.('5S92!D96QI;6ET960@:61E;G1I9FEE<G,@9&]E<VXG="!M96%N"B`@
M("`@*B!Y;W4@4TA/54Q$('5S92!T:&5M+B`@26X@9V5N97)A;"P@=&AE>2!E
M;F0@=7`@8V%U<VEN9R!W87D@;6]R90H@("`@("H@<')O8FQE;7,@=&AA;B!T
M:&5Y('-O;'9E+@H@("`@("H*("`@("`J(%!O<G1A8FEL:71Y(&ES(&)R;VME
M;B!B>2!U<VEN9R!T:&4@9F]L;&]W:6YG(&-H87)A8W1E<G,@:6YS:61E"B`@
M("`@*B!D96QI;6ET960@:61E;G1I9FEE<G,Z"B`@("`@*B`@("L@8F%C:W1I
M8VL@*#QK8F0^8#PO:V)D/BD@+2T@9'5E('1O($UY4U%,"B`@("`@*B`@("L@
M9&]U8FQE('%U;W1E("@\:V)D/B(\+VMB9#XI("TM(&1U92!T;R!/<F%C;&4*
M("`@("`J("`@*R!B<F%C:V5T<R`H/&MB9#Y;/"]K8F0^(&]R(#QK8F0^73PO
M:V)D/BD@+2T@9'5E('1O($%C8V5S<PH@("`@("H*("`@("`J($1E;&EM:71E
M9"!I9&5N=&EF:65R<R!A<F4@:VYO=VX@=&\@9V5N97)A;&QY('=O<FL@8V]R
M<F5C=&QY('5N9&5R"B`@("`@*B!T:&4@9F]L;&]W:6YG(&1R:79E<G,Z"B`@
M("`@*B`@("L@;7-S<6P*("`@("`J("`@*R!M>7-Q;`H@("`@("H@("`K(&UY
M<W%L:0H@("`@("H@("`K(&]C:3@*("`@("`J("`@*R!O9&)C*&%C8V5S<RD*
M("`@("`J("`@*R!O9&)C*&1B,BD*("`@("`J("`@*R!P9W-Q;`H@("`@("H@
M("`K('-Q;&ET90H@("`@("H@("`K('-Y8F%S90H@("`@("H*("`@("`J($EN
M=&5R0F%S92!D;V5S;B=T('-E96T@=&\@8F4@86)L92!T;R!U<V4@9&5L:6UI
M=&5D(&ED96YT:69I97)S"B`@("`@*B!V:6$@4$A0(#0N("!4:&5Y('=O<FL@
M9FEN92!U;F1E<B!02%`@-2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S='(@(&ED96YT:69I97(@;F%M92!T;R!B92!Q=6]T960*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@<75O=&5D(&ED96YT:69I97(@<W1R:6YG
M"B`@("`@*@H@("`@("H@0'-I;F-E(#$N-BXP"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T94ED96YT:69I97(H)'-T
M<BD*("`@('L*("`@("`@("!R971U<FX@)R(G("X@<W1R7W)E<&QA8V4H)R(G
M+"`G(B(G+"`D<W1R*2`N("<B)SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!Q=6]T95-M87)T*"D*"B`@("`O*BH*("`@("`J($9O<FUA="!I;G!U
M="!S;R!I="!C86X@8F4@<V%F96QY('5S960@:6X@82!Q=65R>0H@("`@("H*
M("`@("`J(%1H92!O=71P=70@9&5P96YD<R!O;B!T:&4@4$A0(&1A=&$@='EP
M92!O9B!I;G!U="!A;F0@=&AE(&1A=&%B87-E"B`@("`@*B!T>7!E(&)E:6YG
M('5S960N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I;B`@9&%T82!T
M;R!B92!Q=6]T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!T:&4@
M9F]R;6%T(&]F('1H92!R97-U;'1S(&1E<&5N9',@;VX@=&AE(&EN<'5T)W,*
M("`@("`J("`@("`@("`@("`@("`@(%!(4"!T>7!E.@H@("`@("H*("`@("`J
M(#QU;#X*("`@("`J("`\;&D^"B`@("`@*B`@("`\:V)D/FEN<'5T/"]K8F0^
M("T^(#QS86UP/G)E='5R;G,\+W-A;7`^"B`@("`@*B`@/"]L:3X*("`@("`J
M("`\;&D^"B`@("`@*B`@("`\:V)D/FYU;&P\+VMB9#X@+3X@=&AE('-T<FEN
M9R`\<V%M<#Y.54Q,/"]S86UP/@H@("`@("H@(#PO;&D^"B`@("`@*B`@/&QI
M/@H@("`@("H@("`@/&MB9#YI;G1E9V5R/"]K8F0^(&]R(#QK8F0^9&]U8FQE
M/"]K8F0^("T^('1H92!U;G%U;W1E9"!N=6UB97(*("`@("`J("`\+VQI/@H@
M("`@("H@(#QL:3X*("`@("`J("`@("9T>7!E+F)O;VP[("T^(&]U='!U="!D
M97!E;F1S(&]N('1H92!D<FEV97(@:6X@=7-E"B`@("`@*B`@("!-;W-T(&1R
M:79E<G,@<F5T=7)N(&EN=&5G97)S.B`\<V%M<#XQ/"]S86UP/B!I9@H@("`@
M("H@("`@/&MB9#YT<G5E/"]K8F0^(&]R(#QS86UP/C`\+W-A;7`^(&EF"B`@
M("`@*B`@("`\:V)D/F9A;'-E/"]K8F0^+@H@("`@("H@("`@4V]M92!R971U
M<FX@<W1R:6YG<SH@/'-A;7`^5%)513PO<V%M<#X@:68*("`@("`J("`@(#QK
M8F0^=')U93PO:V)D/B!O<B`\<V%M<#Y&04Q313PO<V%M<#X@:68*("`@("`J
M("`@(#QK8F0^9F%L<V4\+VMB9#XN"B`@("`@*B`@("!&:6YA;&QY(&]N92!R
M971U<FYS('-T<FEN9W,Z(#QS86UP/E0\+W-A;7`^(&EF"B`@("`@*B`@("`\
M:V)D/G1R=64\+VMB9#X@;W(@/'-A;7`^1CPO<V%M<#X@:68*("`@("`J("`@
M(#QK8F0^9F%L<V4\+VMB9#XN($AE<F4@:7,@82!L:7-T(&]F(&5A8V@@1$)-
M4RP*("`@("`J("`@('1H92!V86QU97,@<F5T=7)N960@86YD('1H92!S=6=G
M97-T960@8V]L=6UN('1Y<&4Z"B`@("`@*B`@("`\=6P^"B`@("`@*B`@("`@
M(#QL:3X*("`@("`J("`@("`@("`\:V)D/F1B87-E/"]K8F0^("T^(#QS86UP
M/E0O1CPO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y,;V=I8V%L/"]K8F0^
M*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@
M("`@("`@/&MB9#YF8F%S93PO:V)D/B`M/B`\<V%M<#Y44E5%+T9!3%-%/"]S
M86UP/@H@("`@("H@("`@("`@("@\:V)D/D)/3TQ%04X\+VMB9#XI"B`@("`@
M*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\
M:V)D/FEB87-E/"]K8F0^("T^(#QS86UP/C$O,#PO<V%M<#X*("`@("`J("`@
M("`@("`H/&MB9#Y334%,3$E.5#PO:V)D/BD@6S%="B`@("`@*B`@("`@(#PO
M;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D/FEF>#PO
M:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^
M4TU!3$Q)3E0\+VMB9#XI(%LQ70H@("`@("H@("`@("`\+VQI/@H@("`@("H@
M("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YM<W%L/"]K8F0^("T^(#QS
M86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y)3E1%1T52/"]K
M8F0^*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@
M*B`@("`@("`@/&MB9#YM<W-Q;#PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^
M"B`@("`@*B`@("`@("`@*#QK8F0^0DE4/"]K8F0^*0H@("`@("H@("`@("`\
M+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YM>7-Q
M;#PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK
M8F0^5$E.64E.5"@Q*3PO:V)D/BD*("`@("`J("`@("`@/"]L:3X*("`@("`J
M("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^;7ES<6QI/"]K8F0^("T^
M(#QS86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y424Y924Y4
M*#$I/"]K8F0^*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^
M"B`@("`@*B`@("`@("`@/&MB9#YO8VDX/"]K8F0^("T^(#QS86UP/C$O,#PO
M<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y.54U"15(H,2D\+VMB9#XI"B`@
M("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@
M("`\:V)D/F]D8F,\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@("H@
M("`@("`@("@\:V)D/E--04Q,24Y4/"]K8F0^*2!;,5T*("`@("`J("`@("`@
M/"]L:3X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^<&=S
M<6P\+VMB9#X@+3X@/'-A;7`^5%)512]&04Q313PO<V%M<#X*("`@("`J("`@
M("`@("`H/&MB9#Y"3T],14%./"]K8F0^*0H@("`@("H@("`@("`\+VQI/@H@
M("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YS<6QI=&4\+VMB
M9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@("H@("`@("`@("@\:V)D/DE.
M5$5'15(\+VMB9#XI"B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL
M:3X*("`@("`J("`@("`@("`\:V)D/G-Y8F%S93PO:V)D/B`M/B`\<V%M<#XQ
M+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^5$E.64E.5"@Q*3PO:V)D
M/BD*("`@("`J("`@("`@/"]L:3X*("`@("`J("`@(#PO=6P^"B`@("`@*B`@
M("!;,5T@06-C;VUM;V1A=&4@=&AE(&QO=V5S="!C;VUM;VX@9&5N;VUI;F%T
M;W(@8F5C875S92!N;W0@86QL"B`@("`@*B`@("!V97)S:6]N<R!O9B!H879E
M(#QK8F0^0D]/3$5!3CPO:V)D/BX*("`@("`J("`\+VQI/@H@("`@("H@(#QL
M:3X*("`@("`J("`@(&]T:&5R("AI;F-L=61I;F<@<W1R:6YG<R!A;F0@;G5M
M97)I8R!S=')I;F=S*2`M/@H@("`@("H@("`@=&AE(&1A=&$@=VET:"!S:6YG
M;&4@<75O=&5S(&5S8V%P960@8GD@<')E8V5E9&EN9PH@("`@("H@("`@<VEN
M9VQE('%U;W1E<RP@8F%C:W-L87-H97,@87)E(&5S8V%P960@8GD@<')E8V5E
M9&EN9PH@("`@("H@("`@8F%C:W-L87-H97,L('1H96X@=&AE('=H;VQE('-T
M<FEN9R!I<R!E;F-A<'-U;&%T960*("`@("`J("`@(&)E='=E96X@<VEN9VQE
M('%U;W1E<PH@("`@("H@(#PO;&D^"B`@("`@*B`\+W5L/@H@("`@("H*("`@
M("`J($!S:6YC92`Q+C8N,`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F5S8V%P
M95-I;7!L92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!Q=6]T95-M87)T*"1I;BD*("`@('L*("`@("`@("!I9B`H:7-?
M:6YT*"1I;BD@?'P@:7-?9&]U8FQE*"1I;BDI('L*("`@("`@("`@("`@<F5T
M=7)N("1I;CL*("`@("`@("!](&5L<V5I9B`H:7-?8F]O;"@D:6XI*2!["B`@
M("`@("`@("`@(')E='5R;B`D:6X@/R`Q(#H@,#L*("`@("`@("!](&5L<V5I
M9B`H:7-?;G5L;"@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`G3E5,3"<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("(G(B`N("1T
M:&ES+3YE<V-A<&53:6UP;&4H)&EN*2`N("(G(CL*("`@("`@("!]"B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97-C87!E4VEM<&QE*"D*"B`@("`O
M*BH*("`@("`J($5S8V%P92!A('-T<FEN9R!A8V-O<F1I;F<@=&\@=&AE(&-U
M<G)E;G0@1$)-4R=S('-T86YD87)D<PH@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'-T<B`@=&AE('-T<FEN9R!T;R!B92!E<V-A<&5D"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@('1H92!E<V-A<&5D('-T<FEN9PH@("`@
M("H*("`@("`J($!S:6YC92`Q+C8N,`H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.G%U;W1E4VUA<G0H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@97-C87!E4VEM<&QE*"1S='(I('L*("`@("`@("!R971U
M<FX@<W1R7W)E<&QA8V4H(B<B+"`B)R<B+"`D<W1R*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!P<F]V:61E<R@I"@H@("`@+RHJ"B`@("`@*B!4
M96QL('=H971H97(@82!$0B!I;7!L96UE;G1A=&EO;B!O<B!I=',@8F%C:V5N
M9"!E>'1E;G-I;VX*("`@("`J('-U<'!O<G1S(&$@9VEV96X@9F5A='5R90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9F5A='5R92!N86UE(&]F('1H
M92!F96%T=7)E("AS964@=&AE($1"(&-L87-S(&1O8RD*("`@("`J($!R971U
M<FX@8F]O;"!W:&5T:&5R('1H:7,@1$(@:6UP;&5M96YT871I;VX@<W5P<&]R
M=',@)&9E871U<F4*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!R;W9I9&5S*"1F96%T=7)E*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^9F5A='5R97-;)&9E871U<F5=.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@*B!-
M87`@;F%T:79E(&5R<F]R(&-O9&5S('1O($1")W,@<&]R=&%B;&4@;VYE<PH@
M("`@("H*("`@("`J(%)E<75I<F5S('1H870@=&AE($1"(&EM<&QE;65N=&%T
M:6]N)W,@8V]N<W1R=6-T;W(@9FEL;',*("`@("`J(&EN('1H92`\=F%R/B1E
M<G)O<F-O9&5?;6%P/"]V87(^('!R;W!E<G1Y+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`@)&YA=&EV96-O9&4@('1H92!N871I=F4@97)R;W(@8V]D
M92P@87,@<F5T=7)N960@8GD@=&AE"B`@("`@*B!B86-K96YD(&1A=&%B87-E
M(&5X=&5N<VEO;B`H<W1R:6YG(&]R(&EN=&5G97(I"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@82!P;W)T86)L92!$0B!E<G)O<B!C;V1E+"!O<B!$0E]%
M4E)/4B!I9B!T:&ES($1""B`@("`@*B!I;7!L96UE;G1A=&EO;B!H87,@;F\@
M;6%P<&EN9R!F;W(@=&AE(&=I=F5N(&5R<F]R(&-O9&4N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)#
M;V1E*"1N871I=F5C;V1E*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^97)R;W)C;V1E7VUA<%LD;F%T:79E8V]D95TI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^97)R;W)C;V1E7VUA<%LD;F%T:79E8V]D95T["B`@
M("`@("`@?0H@("`@("`@("\O($9A;&P@8F%C:R!T;R!$0E]%4E)/4B!I9B!T
M:&5R92!W87,@;F\@;6%P<&EN9RX*("`@("`@("!R971U<FX@1$)?15)23U([
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W)-97-S86=E*"D*
M"B`@("`O*BH*("`@("`J($UA<"!A($1"(&5R<F]R(&-O9&4@=&\@82!T97AT
M=6%L(&UE<W-A9V4N("!4:&ES(&ES(&%C='5A;&QY"B`@("`@*B!J=7-T(&$@
M=W)A<'!E<B!F;W(@1$(Z.F5R<F]R365S<V%G92@I"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&1B8V]D92!T:&4@1$(@97)R;W(@8V]D90H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG('1H92!C;W)R97-P;VYD:6YG(&5R
M<F]R(&UE<W-A9V4L(&]F($9!3%-%"B`@("`@*B!I9B!T:&4@97)R;W(@8V]D
M92!W87,@=6YK;F]W;@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R365S<V%G92@D9&)C;V1E*0H@("`@
M>PH@("`@("`@(')E='5R;B!$0CHZ97)R;W)-97-S86=E*"1T:&ES+3YE<G)O
M<F-O9&5?;6%P6R1D8F-O9&5=*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!R86ES945R<F]R*"D*"B`@("`O*BH*("`@("`J($-O;6UU;FEC871E
M(&%N(&5R<F]R(&%N9"!I;G9O:V4@97)R;W(@8V%L;&)A8VMS+"!E=&,*("`@
M("`J"B`@("`@*B!"87-I8V%L;'D@82!W<F%P<&5R(&9O<B!014%2.CIR86ES
M945R<F]R('=I=&AO=70@=&AE(&UE<W-A9V4@<W1R:6YG+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`@("!I;G1E9V5R(&5R<F]R(&-O9&4L(&]R(&$@
M4$5!4B!E<G)O<B!O8FIE8W0@*&%L;`H@("`@("H@("`@("`@("`@("`@("`@
M(&]T:&5R('!A<F%M971E<G,@87)E(&EG;F]R960@:68@=&AI<R!P87)A;65T
M97(@:7,*("`@("`J("`@("`@("`@("`@("`@("!A;B!O8FIE8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT("`@("`@97)R;W(@;6]D92P@<V5E(%!%05)?
M17)R;W(@9&]C<PH@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@("!)9B!E
M<G)O<B!M;V1E(&ES(%!%05)?15)23U)?5%))1T=%4BP@=&AI<R!I<R!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("!E<G)O<B!L979E;"`H15]54T527TY/
M5$E#12!E=&,I+B`@268@97)R;W(@;6]D92!I<PH@("`@("H@("`@("`@("`@
M("`@("`@(%!%05)?15)23U)?0T%,3$)!0TLL('1H:7,@:7,@=&AE(&-A;&QB
M86-K(&9U;F-T:6]N+`H@("`@("H@("`@("`@("`@("`@("`@(&5I=&AE<B!A
M<R!A(&9U;F-T:6]N(&YA;64L(&]R(&%S(&%N(&%R<F%Y(&]F(&%N"B`@("`@
M*B`@("`@("`@("`@("`@("`@;V)J96-T(&%N9"!M971H;V0@;F%M92X@($9O
M<B!O=&AE<B!E<G)O<B!M;V1E<R!T:&ES"B`@("`@*B`@("`@("`@("`@("`@
M("`@<&%R86UE=&5R(&ES(&EG;F]R960N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@($5X=')A(&1E8G5G(&EN9F]R;6%T:6]N+B`@1&5F875L=',@
M=&\@=&AE(&QA<W0*("`@("`J("`@("`@("`@("`@("`@("!Q=65R>2!A;F0@
M;F%T:79E(&5R<F]R(&-O9&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("`@($YA=&EV92!E<G)O<B!C;V1E+"!I;G1E9V5R(&]R('-T<FEN9R!D97!E
M;F1I;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@82!014%2(&5R<F]R(&]B:F5C
M=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<V5E(%!%
M05)?17)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@)G)A:7-E17)R;W(H)&-O
M9&4@/2!$0E]%4E)/4BP@)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<FEN9F\@/2!N=6QL+"`D
M;F%T:79E8V]D92`](&YU;&PI"B`@("!["B`@("`@("`@+R\@5&AE(&5R<F]R
M(&ES('EE="!A($1"(&5R<F]R(&]B:F5C=`H@("`@("`@(&EF("AI<U]O8FIE
M8W0H)&-O9&4I*2!["B`@("`@("`@("`@("\O(&)E8V%U<V4@=V4@=&AE('-T
M871I8R!014%2.CIR86ES945R<F]R+"!O=7(@9VQO8F%L"B`@("`@("`@("`@
M("\O(&AA;F1L97(@<VAO=6QD(&)E('5S960@:68@:70@:7,@<V5T"B`@("`@
M("`@("`@(&EF("@D;6]D92`]/3T@;G5L;"`F)B`A96UP='DH)'1H:7,M/E]D
M969A=6QT7V5R<F]R7VUO9&4I*2!["B`@("`@("`@("`@("`@("`D;6]D92`@
M("`]("1T:&ES+3Y?9&5F875L=%]E<G)O<E]M;V1E.PH@("`@("`@("`@("`@
M("`@)&]P=&EO;G,@/2`D=&AI<RT^7V1E9F%U;'1?97)R;W)?;W!T:6]N<SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&UP(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@D8V]D92P@;G5L;"P@)&UO9&4L("1O<'1I;VYS+"!N=6QL+"!N=6QL
M+"!T<G5E*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'5S97)I;F9O(#T]/2!N=6QL*2!["B`@("`@("`@("`@
M("1U<V5R:6YF;R`]("1T:&ES+3YL87-T7W%U97)Y.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1N871I=F5C;V1E*2!["B`@("`@("`@("`@("1U<V5R:6YF
M;R`N/2`G(%MN871I=F5C;V1E/2<@+B!T<FEM*"1N871I=F5C;V1E*2`N("==
M)SL*("`@("`@("!]"@H@("`@("`@("1T;7`@/2!014%2.CIR86ES945R<F]R
M*&YU;&PL("1C;V1E+"`D;6]D92P@)&]P=&EO;G,L("1U<V5R:6YF;RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1$)?17)R;W(G+"!T<G5E
M*3L*("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!S971&971C:$UO9&4H*0H*("`@("\J*@H@("`@("H@4V5T<R!W
M:&EC:"!F971C:"!M;V1E('-H;W5L9"!B92!U<V5D(&)Y(&1E9F%U;'0@;VX@
M<75E<FEE<PH@("`@("H@;VX@=&AI<R!C;VYN96-T:6]N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&9E=&-H;6]D92!$0E]&151#2$U/1$5?3U)$
M15)%1"!O<@H@("`@("H@("`@("`@($1"7T9%5$-(34]$15]!4U-/0RP@<&]S
M<VEB;'D@8FET+7=I<V4@3U(G960@=VET:`H@("`@("H@("`@("`@($1"7T9%
M5$-(34]$15]&3$E04$5$+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&]B:F5C=%]C;&%S<R!4:&4@8VQA<W,@;V8@=&AE(&]B:F5C=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@=&\@8F4@<F5T=7)N960@8GD@=&AE(&9E
M=&-H(&UE=&AO9',@=VAE;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M=&AE($1"7T9%5$-(34]$15]/0DI%0U0@;6]D92!I<R!S96QE8W1E9"X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@($EF(&YO(&-L87-S(&ES('-P96-I
M9FEE9"!B>2!D969A=6QT(&$@8V%S=`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@=&\@;V)J96-T(&9R;VT@=&AE(&%S<V]C(&%R<F%Y(')O=R!W:6QL
M(&)E(&1O;F4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!4:&5R92!I
M<R!A;'-O('1H92!P;W-I8FEL:71Y('1O('5S92!A;F0@97AT96YD('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@)T1"7U)O=R<@8VQA<W,N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]&151#2$U/1$5?3U)$15)%1`H@("`@("H@
M0'-E92!$0E]&151#2$U/1$5?05-33T,*("`@("`J($!S964@1$)?1D540TA-
M3T1%7T9,25!0140*("`@("`J($!S964@1$)?1D540TA-3T1%7T]"2D5#5`H@
M("`@("H@0'-E92!$0E]2;W<Z.D1"7U)O=R@I"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971&971C:$UO9&4H)&9E=&-H
M;6]D92P@)&]B:F5C=%]C;&%S<R`](&YU;&PI"B`@("!["B`@("`@("`@<W=I
M=&-H("@D9F5T8VAM;V1E*2!["B`@("`@("`@("`@(&-A<V4@1$)?1D540TA-
M3T1%7T]"2D5#5#H*("`@("`@("`@("`@("`@(&EF("@D;V)J96-T7V-L87-S
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9E=&-H;6]D95]O8FIE
M8W1?8VQA<W,@/2`D;V)J96-T7V-L87-S.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!C87-E($1"7T9%5$-(34]$15]/4D1%4D5$.@H@("`@("`@
M("`@("!C87-E($1"7T9%5$-(34]$15]!4U-/0SH*("`@("`@("`@("`@("`@
M("1T:&ES+3YF971C:&UO9&4@/2`D9F5T8VAM;V1E.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VEN=F%L:60@9F5T8VAM;V1E
M(&UO9&4G*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@<V5T3W!T:6]N*"D*"B`@("`O*BH*("`@("`J(%-E="!R=6XM=&EM92!C
M;VYF:6=U<F%T:6]N(&]P=&EO;G,@9F]R(%!%05(@1$(*("`@("`J"B`@("`@
M*B!/<'1I;VYS+"!T:&5I<B!D871A('1Y<&5S+"!D969A=6QT('9A;'5E<R!A
M;F0@9&5S8W)I<'1I;VXZ"B`@("`@*B`\=6P^"B`@("`@*B`\;&D^"B`@("`@
M*B`\=F%R/F%U=&]F<F5E/"]V87(^(#QK8F0^8F]O;&5A;CPO:V)D/B`](#QS
M86UP/F9A;'-E/"]S86UP/@H@("`@("H@("`@("`\8G(@+SYS:&]U;&0@<F5S
M=6QT<R!B92!F<F5E9"!A=71O;6%T:6-A;&QY('=H96X@=&AE<F4@87)E(&YO
M"B`@("`@*B`@("`@("`@("`@(&UO<F4@<F]W<S\*("`@("`J(#PO;&D^/&QI
M/@H@("`@("H@/'9A<CYD96)U9SPO=F%R/B`\:V)D/FEN=&5G97(\+VMB9#X@
M/2`\<V%M<#XP/"]S86UP/@H@("`@("H@("`@("`\8G(@+SYD96)U9R!L979E
M;`H@("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R/G!E<G-I<W1E;G0\+W9A
M<CX@/&MB9#YB;V]L96%N/"]K8F0^(#T@/'-A;7`^9F%L<V4\+W-A;7`^"B`@
M("`@*B`@("`@(#QB<B`O/G-H;W5L9"!T:&4@8V]N;F5C=&EO;B!B92!P97)S
M:7-T96YT/PH@("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R/G!O<G1A8FEL
M:71Y/"]V87(^(#QK8F0^:6YT96=E<CPO:V)D/B`](#QS86UP/D1"7U!/4E1!
M0DE,25197TY/3D4\+W-A;7`^"B`@("`@*B`@("`@(#QB<B`O/G!O<G1A8FEL
M:71Y(&UO9&4@8V]N<W1A;G0@*'-E92!B96QO=RD*("`@("`J(#PO;&D^/&QI
M/@H@("`@("H@/'9A<CYS97%N86UE7V9O<FUA=#PO=F%R/B`\:V)D/G-T<FEN
M9SPO:V)D/B`](#QS86UP/B5S7W-E<3PO<V%M<#X*("`@("`J("`@("`@/&)R
M("\^=&AE('-P<FEN=&8H*2!F;W)M870@<W1R:6YG('5S960@;VX@<V5Q=65N
M8V4@;F%M97,N("!4:&ES"B`@("`@*B`@("`@("`@("`@(&9O<FUA="!I<R!A
M<'!L:65D('1O('-E<75E;F-E(&YA;65S('!A<W-E9"!T;PH@("`@("H@("`@
M("`@("`@("!C<F5A=&5397%U96YC92@I+"!N97AT240H*2!A;F0@9')O<%-E
M<75E;F-E*"DN"B`@("`@*B`\+VQI/CQL:3X*("`@("`J(#QV87(^<W-L/"]V
M87(^(#QK8F0^8F]O;&5A;CPO:V)D/B`](#QS86UP/F9A;'-E/"]S86UP/@H@
M("`@("H@("`@("`\8G(@+SYU<V4@<W-L('1O(&-O;FYE8W0_"B`@("`@*B`\
M+VQI/@H@("`@("H@/"]U;#X*("`@("`J"B`@("`@*B`M+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@("`@("H*("`@("`J(%!/
M4E1!0DE,2519($U/1$53"B`@("`@*@H@("`@("H@5&AE<V4@;6]D97,@87)E
M(&)I='=I<V5D+"!S;R!T:&5Y(&-A;B!B92!C;VUB:6YE9"!U<VEN9R`\:V)D
M/GP\+VMB9#X*("`@("`J(&%N9"!R96UO=F5D('5S:6YG(#QK8F0^7CPO:V)D
M/BX@(%-E92!T:&4@97AA;7!L97,@<V5C=&EO;B!B96QO=R!O;B!H;W<*("`@
M("`J('1O(&1O('1H:7,N"B`@("`@*@H@("`@("H@/'-A;7`^1$)?4$]25$%"
M24Q)5%E?3D].13PO<V%M<#X*("`@("`J('1U<FX@;V9F(&%L;"!P;W)T86)I
M;&ET>2!F96%T=7)E<PH@("`@("H*("`@("`J(%1H:7,@;6]D92!G971S(&%U
M=&]M871I8V%L;'D@='5R;F5D(&]N(&EF('1H92!D97!R96-A=&5D"B`@("`@
M*B`\=F%R/F]P=&EM:7IE/"]V87(^(&]P=&EO;B!G971S('-E="!T;R`\<V%M
M<#YP97)F;W)M86YC93PO<V%M<#XN"B`@("`@*@H@("`@("H*("`@("`J(#QS
M86UP/D1"7U!/4E1!0DE,25197TQ/5T520T%313PO<V%M<#X*("`@("`J(&-O
M;G9E<G0@;F%M97,@;V8@=&%B;&5S(&%N9"!F:65L9',@=&\@;&]W97(@8V%S
M92!W:&5N('5S:6YG"B`@("`@*B`\:V)D/F=E="HH*3PO:V)D/BP@/&MB9#YF
M971C:"HH*3PO:V)D/B!A;F0@/&MB9#YT86)L94EN9F\H*3PO:V)D/@H@("`@
M("H*("`@("`J(%1H:7,@;6]D92!G971S(&%U=&]M871I8V%L;'D@='5R;F5D
M(&]N(&EN('1H92!F;VQL;W=I;F<@9&%T86)A<V5S"B`@("`@*B!I9B!T:&4@
M9&5P<F5C871E9"!O<'1I;VX@/'9A<CYO<'1I;6EZ93PO=F%R/B!G971S('-E
M="!T;PH@("`@("H@/'-A;7`^<&]R=&%B:6QI='D\+W-A;7`^.@H@("`@("H@
M*R!O8VDX"B`@("`@*@H@("`@("H*("`@("`J(#QS86UP/D1"7U!/4E1!0DE,
M25197U)44DE-/"]S86UP/@H@("`@("H@<FEG:'0@=')I;2!T:&4@9&%T82!O
M=71P=70@8GD@/&MB9#YG970J*"D\+VMB9#X@/&MB9#YF971C:"HH*3PO:V)D
M/@H@("`@("H*("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))3$E465]$
M14Q%5$5?0T]53E0\+W-A;7`^"B`@("`@*B!F;W)C92!R97!O<G1I;F<@=&AE
M(&YU;6)E<B!O9B!R;W=S(&1E;&5T960*("`@("`J"B`@("`@*B!3;VUE($1"
M35,G<R!D;VXG="!C;W5N="!T:&4@;G5M8F5R(&]F(')O=W,@9&5L971E9"!W
M:&5N('!E<F9O<FUI;F<*("`@("`J('-I;7!L92`\:V)D/D1%3$5412!&4D]-
M('1A8FQE;F%M93PO:V)D/B!Q=65R:65S+B`@5&AI<R!P;W)T86)I;&ET>0H@
M("`@("H@;6]D92!T<FEC:W,@<W5C:"!$0DU3)W,@:6YT;R!T96QL:6YG('1H
M92!C;W5N="!B>2!A9&1I;F<*("`@("`J(#QS86UP/E=(15)%(#$],3PO<V%M
M<#X@=&\@=&AE(&5N9"!O9B`\:V)D/D1%3$5413PO:V)D/B!Q=65R:65S+@H@
M("`@("H*("`@("`J(%1H:7,@;6]D92!G971S(&%U=&]M871I8V%L;'D@='5R
M;F5D(&]N(&EN('1H92!F;VQL;W=I;F<@9&%T86)A<V5S"B`@("`@*B!I9B!T
M:&4@9&5P<F5C871E9"!O<'1I;VX@/'9A<CYO<'1I;6EZ93PO=F%R/B!G971S
M('-E="!T;PH@("`@("H@/'-A;7`^<&]R=&%B:6QI='D\+W-A;7`^.@H@("`@
M("H@*R!F8G-Q;`H@("`@("H@*R!M>7-Q;`H@("`@("H@*R!M>7-Q;&D*("`@
M("`J("L@<W%L:71E"B`@("`@*@H@("`@("H*("`@("`J(#QS86UP/D1"7U!/
M4E1!0DE,25197TY535)/5U,\+W-A;7`^"B`@("`@*B!E;F%B;&4@:&%C:R!T
M:&%T(&UA:V5S(#QK8F0^;G5M4F]W<R@I/"]K8F0^('=O<FL@:6X@3W)A8VQE
M"B`@("`@*@H@("`@("H@5&AI<R!M;V1E(&=E=',@875T;VUA=&EC86QL>2!T
M=7)N960@;VX@:6X@=&AE(&9O;&QO=VEN9R!D871A8F%S97,*("`@("`J(&EF
M('1H92!D97!R96-A=&5D(&]P=&EO;B`\=F%R/F]P=&EM:7IE/"]V87(^(&=E
M=',@<V5T('1O"B`@("`@*B`\<V%M<#YP;W)T86)I;&ET>3PO<V%M<#XZ"B`@
M("`@*B`K(&]C:3@*("`@("`J"B`@("`@*@H@("`@("H@/'-A;7`^1$)?4$]2
M5$%"24Q)5%E?15)23U)3/"]S86UP/@H@("`@("H@;6%K97,@8V5R=&%I;B!E
M<G)O<B!M97-S86=E<R!I;B!C97)T86EN(&1R:79E<G,@8V]M<&%T:6)L90H@
M("`@("H@=VET:"!T:&]S92!F<F]M(&]T:&5R($1"35,G<PH@("`@("H*("`@
M("`J("L@;7ES<6PL(&UY<W%L:3H@(&-H86YG92!U;FEQ=64O<')I;6%R>2!K
M97D@8V]N<W1R86EN=',*("`@("`J("`@1$)?15)23U)?04Q214%$65]%6$E3
M5%,@+3X@1$)?15)23U)?0T].4U1204E.5`H@("`@("H*("`@("`J("L@;V1B
M8RAA8V-E<W,I.B`@35,G<R!/1$)#(&1R:79E<B!R97!O<G1S("=N;R!S=6-H
M(&9I96QD)R!A<R!C;V1E"B`@("`@*B`@(#`W,#`Q+"!W:&EC:"!M96%N<R`G
M=&]O(&9E=R!P87)A;65T97)S+B<@(%=H96X@=&AI<R!O<'1I;VX@:7,@;VX*
M("`@("`J("`@=&AA="!C;V1E(&=E=',@;6%P<&5D('1O($1"7T524D]27TY/
M4U5#2$9)14Q$+@H@("`@("H@("!$0E]%4E)/4E]-25--051#2"`M/B!$0E]%
M4E)/4E].3U-50TA&245,1`H@("`@("H*("`@("`J"B`@("`@*B`\<V%M<#Y$
M0E]03U)404))3$E465].54Q,7U1/7T5-4%19/"]S86UP/@H@("`@("H@8V]N
M=F5R="!N=6QL('9A;'5E<R!T;R!E;7!T>2!S=')I;F=S(&EN(&1A=&$@;W5T
M<'5T(&)Y(&=E="HH*2!A;F0*("`@("`J(&9E=&-H*B@I+B`@3F5E9&5D(&)E
M8V%U<V4@3W)A8VQE(&-O;G-I9&5R<R!E;7!T>2!S=')I;F=S('1O(&)E(&YU
M;&PL"B`@("`@*B!W:&EL92!M;W-T(&]T:&5R($1"35,G<R!K;F]W('1H92!D
M:69F97)E;F-E(&)E='=E96X@96UP='D@86YD(&YU;&PN"B`@("`@*@H@("`@
M("H*("`@("`J(#QS86UP/D1"7U!/4E1!0DE,25197T%,3#PO<V%M<#X*("`@
M("`J('1U<FX@;VX@86QL('!O<G1A8FEL:71Y(&9E871U<F5S"B`@("`@*@H@
M("`@("H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*("`@("`J"B`@("`@*B!%>&%M<&QE(#$N(%-I;7!L92!S971/<'1I;VXH
M*2!E>&%M<&QE"B`@("`@*B`\8V]D93X@/#]P:'`*("`@("`J("1D8F@M/G-E
M=$]P=&EO;B@G875T;V9R964G+"!T<G5E*3L*("`@("`J(#\^/"]C;V1E/@H@
M("`@("H*("`@("`J($5X86UP;&4@,BX@4&]R=&%B:6QI='D@9F]R(&QO=V5R
M8V%S:6YG(&%N9"!T<FEM;6EN9PH@("`@("H@/&-O9&4^(#P_<&AP"B`@("`@
M*B`D9&)H+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP*("`@("`J("`@("`@
M("`@("`@("`@("`@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]2
M5$%"24Q)5%E?4E1224TI.PH@("`@("H@/SX\+V-O9&4^"B`@("`@*@H@("`@
M("H@17AA;7!L92`S+B!!;&P@<&]R=&%B:6QI='D@;W!T:6]N<R!E>&-E<'0@
M=')I;6UI;F<*("`@("`J(#QC;V1E/B`\/W!H<`H@("`@("H@)&1B:"T^<V5T
M3W!T:6]N*"=P;W)T86)I;&ET>2<L"B`@("`@*B`@("`@("`@("`@("`@("`@
M($1"7U!/4E1!0DE,25197T%,3"!>($1"7U!/4E1!0DE,25197U)44DE-*3L*
M("`@("`J(#\^/"]C;V1E/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&]P=&EO;B!O<'1I;VX@;F%M90H@("`@("H@0'!A<F%M(&UI>&5D("`D=F%L
M=64@=F%L=64@9F]R('1H92!O<'1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CHD;W!T:6]N
M<PH@("`@("HO"B`@("!F=6YC=&EO;B!S971/<'1I;VXH)&]P=&EO;BP@)'9A
M;'5E*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<ULD
M;W!T:6]N72DI('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G-;)&]P=&EO
M;ET@/2`D=F%L=64["@H@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!"
M86-K=V%R9',@8V]M<&%T:6)I;&ET>2!C:&5C:R!F;W(@=&AE(&1E<')E8V%T
M960@)V]P=&EM:7IE)PH@("`@("`@("`@("`@*B!O<'1I;VXN("!$;VYE(&AE
M<F4@:6X@8V%S92!S971T:6YG<R!C:&%N9V4@869T97(@8V]N;F5C=&EN9RX*
M("`@("`@("`@("`@("HO"B`@("`@("`@("`@(&EF("@D;W!T:6]N(#T]("=O
M<'1I;6EZ92<I('L*("`@("`@("`@("`@("`@(&EF("@D=F%L=64@/3T@)W!O
M<G1A8FEL:71Y)RD@>PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)'1H
M:7,M/G!H<'1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G
M;V-I."<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1"7U!/4E1!0DE,25197TQ/5T520T%312!\"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1"7U!/4E1!0DE,2519
M7TY535)/5U,["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G9F)S<6PG.@H@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E("=M>7-Q;"<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)VUY<W%L:2<Z"B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)W-Q;&ET92<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($1"7U!/4E1!0DE,25197T1%3$54
M15]#3U5.5#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL
M:71Y)UT@/2!$0E]03U)404))3$E465].3TY%.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK
M;F]W;B!O<'1I;VX@)&]P=&EO;B(I.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&=E=$]P=&EO;B@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!V86QU92!O9B!A;B!O<'1I;VX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1O<'1I;VX@;W!T:6]N(&YA;64*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D('1H92!O<'1I;VX@=F%L=64*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T3W!T:6]N*"1O<'1I;VXI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3YO<'1I;VYS6R1O<'1I;VY=*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F]P=&EO;G-;)&]P=&EO;ET["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK;F]W;B!O<'1I;VX@)&]P=&EO
M;B(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('!R97!A<F4H*0H*
M("`@("\J*@H@("`@("H@4')E<&%R97,@82!Q=65R>2!F;W(@;75L=&EP;&4@
M97AE8W5T:6]N('=I=&@@97AE8W5T92@I"B`@("`@*@H@("`@("H@0W)E871E
M<R!A('%U97)Y('1H870@8V%N(&)E(')U;B!M=6QT:7!L92!T:6UE<RX@($5A
M8V@@=&EM92!I="!I<R!R=6XL"B`@("`@*B!T:&4@<&QA8V5H;VQD97)S+"!I
M9B!A;GDL('=I;&P@8F4@<F5P;&%C960@8GD@=&AE(&-O;G1E;G1S(&]F"B`@
M("`@*B!E>&5C=71E*"DG<R`D9&%T82!A<F=U;65N="X*("`@("`J"B`@("`@
M*B!4:')E92!T>7!E<R!O9B!P;&%C96AO;&1E<G,@8V%N(&)E('5S960Z"B`@
M("`@*B`@("L@/&MB9#X_/"]K8F0^("!S8V%L87(@=F%L=64@*&DN92X@<W1R
M:6YG<RP@:6YT96=E<G,I+B`@5&AE('-Y<W1E;0H@("`@("H@("`@("`@("`@
M("`@("`@("`@=VEL;"!A=71O;6%T:6-A;&QY('%U;W1E(&%N9"!E<V-A<&4@
M=&AE(&1A=&$N"B`@("`@*B`@("L@/&MB9#XA/"]K8F0^("!V86QU92!I<R!I
M;G-E<G1E9"`G87,@:7,G"B`@("`@*B`@("L@/&MB9#XF/"]K8F0^("!R97%U
M:7)E<R!A(&9I;&4@;F%M92X@(%1H92!F:6QE)W,@8V]N=&5N=',@9V5T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("!I;G-E<G1E9"!I;G1O('1H92!Q=65R
M>2`H:2YE+B!S879I;F<@8FEN87)Y"B`@("`@*B`@("`@("`@("`@("`@("`@
M("!D871A(&EN(&$@9&(I"B`@("`@*@H@("`@("H@17AA;7!L92`Q+@H@("`@
M("H@/&-O9&4^(#P_<&AP"B`@("`@*B`D<W1H(#T@)&1B:"T^<')E<&%R92@G
M24Y315)4($E.5$\@=&)L("AA+"!B+"!C*2!604Q515,@*#\L("$L("8I)RD[
M"B`@("`@*B`D9&%T82`](&%R<F%Y*`H@("`@("H@("`@(")*;VAN)W,@=&5X
M="(L"B`@("`@*B`@("`@(B=I="<G<R!G;V]D)R(L"B`@("`@*B`@("`@)V9I
M;&5N86UE+G1X="<*("`@("`J("D["B`@("`@*B`D<F5S(#T@)&1B:"T^97AE
M8W5T92@D<W1H+"`D9&%T82D["B`@("`@*B`_/CPO8V]D93X*("`@("`J"B`@
M("`@*B!5<V4@8F%C:W-L87-H97,@=&\@97-C87!E('!L86-E:&]L9&5R(&-H
M87)A8W1E<G,@:68@>6]U(&1O;B=T('=A;G0*("`@("`J('1H96T@=&\@8F4@
M:6YT97)P<F5T960@87,@<&QA8V5H;VQD97)S.@H@("`@("H@/'!R93X*("`@
M("`J("`@(")54$1!5$4@9F]O(%-%5"!C;VP]/R!72$5212!C;VP])V]V97(@
M7"8@=6YD97(G(@H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@5VET:"!S
M;VUE(&1A=&%B87-E(&)A8VME;F1S+"!T:&ES(&ES(&5M=6QA=&5D+@H@("`@
M("H*("`@("`J('M`:6YT97)N86P@:6)A<V4@86YD(&]C:3@@:&%V92!T:&5I
M<B!O=VX@<')E<&%R92@I(&UE=&AO9',N?7T*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1Q=65R>2!Q=65R>2!T;R!B92!P<F5P87)E9`H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@1$(@<W1A=&5M96YT(')E<V]U<F-E(&]N
M('-U8V-E<W,N($1"7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@
M0'-E92!$0E]C;VUM;VXZ.F5X96-U=&4H*0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<')E<&%R92@D<75E<GDI"B`@("![
M"B`@("`@("`@)'1O:V5N<R`@(#T@<')E9U]S<&QI="@G+R@H/SPA7%Q<*5LF
M/R%=*2\G+"`D<75E<GDL("TQ+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@4%)%1U]34$Q)5%]$14Q)35]#05!455)%*3L*("`@("`@("`D=&]K
M96X@("`@(#T@,#L*("`@("`@("`D='EP97,@("`@(#T@87)R87DH*3L*("`@
M("`@("`D;F5W=&]K96YS(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H
M)'1O:V5N<R!A<R`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H)'9A;"D@
M>PH@("`@("`@("`@("`@("`@8V%S92`G/R<Z"B`@("`@("`@("`@("`@("`@
M("`@)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-7U-#04Q!4CL*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)R8G
M.@H@("`@("`@("`@("`@("`@("`@("1T>7!E<ULD=&]K96XK*UT@/2!$0E]0
M05)!35]/4$%1544["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E("<A)SH*("`@("`@("`@("`@("`@("`@("`D='EP
M97-;)'1O:V5N*RM=(#T@1$)?4$%204U?34E30SL*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("`@("`@)&YE=W1O:V5N<UM=(#T@<')E9U]R97!L86-E*"<O7%Q<
M*%LF/R%=*2\G+"`B7%PQ(BP@)'9A;"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YP<F5P87)E7W1O:V5N<UM=(#T@)B1N97=T
M;VME;G,["B`@("`@("`@96YD*"1T:&ES+3YP<F5P87)E7W1O:V5N<RD["@H@
M("`@("`@("1K(#T@:V5Y*"1T:&ES+3YP<F5P87)E7W1O:V5N<RD["B`@("`@
M("`@)'1H:7,M/G!R97!A<F5?='EP97-;)&M=(#T@)'1Y<&5S.PH@("`@("`@
M("1T:&ES+3YP<F5P87)E9%]Q=65R:65S6R1K72`](&EM<&QO9&4H)R`G+"`D
M;F5W=&]K96YS*3L*"B`@("`@("`@<F5T=7)N("1K.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&%U=&]0<F5P87)E*"D*"B`@("`O*BH*("`@("`J
M($%U=&]M871I8V%L>2!G96YE<F%T92!A;B!I;G-E<G0@;W(@=7!D871E('%U
M97)Y(&%N9"!P87-S(&ET('1O('!R97!A<F4H*0H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1A8FQE(&YA;64@;V8@=&AE('1A8FQE"B`@("`@*B!`
M<&%R86T@87)R87D@)'1A8FQE7V9I96QD<R!O<F1E<F5D(&%R<F%Y(&-O;G1A
M:6YI;F<@=&AE(&9I96QD<R!N86UE<PH@("`@("H@0'!A<F%M(&EN="`D;6]D
M92!T>7!E(&]F('%U97)Y('1O(&UA:V4@*$1"7T%55$]1545265])3E-%4E0@
M;W(@1$)?05543U%515)97U501$%412D*("`@("`J($!P87)A;2!S=')I;F<@
M)'=H97)E(&EN(&-A<V4@;V8@=7!D871E('%U97)I97,L('1H:7,@<W1R:6YG
M('=I;&P@8F4@<'5T(&%F=&5R('1H92!S<6P@5TA%4D4@<W1A=&5M96YT"B`@
M("`@*B!`<F5T=7)N(')E<V]U<F-E(&AA;F1L92!F;W(@=&AE('%U97)Y"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ<')E<&%R92@I+"!$0E]C;VUM;VXZ.F)U
M:6QD36%N:7!344PH*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@875T;U!R97!A<F4H)'1A8FQE+"`D=&%B;&5?9FEE;&1S
M+"`D;6]D92`]($1"7T%55$]1545265])3E-%4E0L("1W:&5R92`](&9A;'-E
M*0H@("`@>PH@("`@("`@("1Q=65R>2`]("1T:&ES+3YB=6EL9$UA;FEP4U%,
M*"1T86)L92P@)'1A8FQE7V9I96QD<RP@)&UO9&4L("1W:&5R92D["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YP<F5P87)E*"1Q=65R>2D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@875T;T5X96-U=&4H*0H*("`@("\J*@H@("`@
M("H@075T;VUA=&EC86QY(&=E;F5R871E(&%N(&EN<V5R="!O<B!U<&1A=&4@
M<75E<GD@86YD(&-A;&P@<')E<&%R92@I"B`@("`@*B!A;F0@97AE8W5T92@I
M('=I=&@@:70*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L92!N
M86UE(&]F('1H92!T86)L90H@("`@("H@0'!A<F%M(&%R<F%Y("1F:65L9'-?
M=F%L=65S(&%S<V]C("@D:V5Y/3XD=F%L=64I('=H97)E("1K97D@:7,@82!F
M:65L9"!N86UE(&%N9"`D=F%L=64@:71S('9A;'5E"B`@("`@*B!`<&%R86T@
M:6YT("1M;V1E('1Y<&4@;V8@<75E<GD@=&\@;6%K92`H1$)?05543U%515)9
M7TE.4T525"!O<B!$0E]!551/455%4EE?55!$051%*0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=VAE<F4@:6X@8V%S92!O9B!U<&1A=&4@<75E<FEE<RP@=&AI
M<R!S=')I;F<@=VEL;"!B92!P=70@869T97(@=&AE('-Q;"!72$5212!S=&%T
M96UE;G0*("`@("`J($!R971U<FX@;6EX960@(&$@;F5W($1"7U)E<W5L="!O
M<B!A($1"7T5R<F]R('=H96X@9F%I;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.F%U=&]0<F5P87)E*"DL($1"7V-O;6UO;CHZ8G5I;&1-86YI<%-13"@I"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A=71O
M17AE8W5T92@D=&%B;&4L("1F:65L9'-?=F%L=65S+"`D;6]D92`]($1"7T%5
M5$]1545265])3E-%4E0L("1W:&5R92`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1S=&@@/2`D=&AI<RT^875T;U!R97!A<F4H)'1A8FQE+"!A<G)A>5]K97ES
M*"1F:65L9'-?=F%L=65S*2P@)&UO9&4L("1W:&5R92D["B`@("`@("`@)')E
M="`])B`D=&AI<RT^97AE8W5T92@D<W1H+"!A<G)A>5]V86QU97,H)&9I96QD
M<U]V86QU97,I*3L*("`@("`@("`D=&AI<RT^9G)E95!R97!A<F5D*"1S=&@I
M.PH@("`@("`@(')E='5R;B`D<F5T.PH*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!B=6EL9$UA;FEP4U%,*"D*"B`@("`O*BH*("`@("`J($UA:V4@
M875T;VUA=&EC86QY(&%N('-Q;"!Q=65R>2!F;W(@<')E<&%R92@I"B`@("`@
M*@H@("`@("H@17AA;7!L92`Z(&)U:6QD36%N:7!344PH)W1A8FQE7W-Q;"<L
M(&%R<F%Y*"=F:65L9#$G+"`G9FEE;&0R)RP@)V9I96QD,R<I+"!$0E]!551/
M455%4EE?24Y315)4*0H@("`@("H@("`@("`@("`@('=I;&P@<F5T=7)N('1H
M92!S=')I;F<@.B!)3E-%4E0@24Y43R!T86)L95]S<6P@*&9I96QD,2QF:65L
M9#(L9FEE;&0S*2!604Q515,@*#\L/RP_*0H@("`@("H@3D(@.B`M(%1H:7,@
M8F5L;VYG<R!M;W)E('1O(&$@4U%,($)U:6QD97(@8VQA<W,L(&)U="!T:&ES
M(&ES(&$@<VEM<&QE(&9A8VEL:71Y"B`@("`@*B`@("`@("T@0F4@8V%R969U
M;&P@(2!)9B!Y;W4@9&]N)W0@9VEV92!A("1W:&5R92!P87)A;2!W:71H(&%N
M(%501$%412!Q=65R>2P@86QL"B`@("`@*B`@("`@("`@=&AE(')E8V]R9',@
M;V8@=&AE('1A8FQE('=I;&P@8F4@=7!D871E9"`A"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&%B;&4@;F%M92!O9B!T:&4@=&%B;&4*("`@("`J
M($!P87)A;2!A<G)A>2`D=&%B;&5?9FEE;&1S(&]R9&5R960@87)R87D@8V]N
M=&%I;FEN9R!T:&4@9FEE;&1S(&YA;65S"B`@("`@*B!`<&%R86T@:6YT("1M
M;V1E('1Y<&4@;V8@<75E<GD@=&\@;6%K92`H1$)?05543U%515)97TE.4T52
M5"!O<B!$0E]!551/455%4EE?55!$051%*0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=VAE<F4@:6X@8V%S92!O9B!U<&1A=&4@<75E<FEE<RP@=&AI<R!S=')I
M;F<@=VEL;"!B92!P=70@869T97(@=&AE('-Q;"!72$5212!S=&%T96UE;G0*
M("`@("`J($!R971U<FX@<W1R:6YG('-Q;"!Q=65R>2!F;W(@<')E<&%R92@I
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!B
M=6EL9$UA;FEP4U%,*"1T86)L92P@)'1A8FQE7V9I96QD<RP@)&UO9&4L("1W
M:&5R92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&%B;&5?
M9FEE;&1S*2`]/2`P*2!["B`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R
M*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"B`@("`@("`@
M)&9I<G-T(#T@=')U93L*("`@("`@("!S=VET8V@@*"1M;V1E*2!["B`@("`@
M("`@("`@(&-A<V4@1$)?05543U%515)97TE.4T525#H*("`@("`@("`@("`@
M("`@("1V86QU97,@/2`G)SL*("`@("`@("`@("`@("`@("1N86UE<R`]("<G
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1A8FQE7V9I96QD<R!A<R`D
M=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&9I<G-T*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1N86UE<R`N/2`G+"<["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU
M97,@+CT@)RPG.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D;F%M97,@+CT@)'9A;'5E.PH@("`@("`@("`@("`@("`@("`@
M("1V86QU97,@+CT@)S\G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@<F5T=7)N("))3E-%4E0@24Y43R`D=&%B;&4@*"1N86UE<RD@5D%,
M5453("@D=F%L=65S*2(["B`@("`@("`@("`@(&-A<V4@1$)?05543U%515)9
M7U501$%413H*("`@("`@("`@("`@("`@("1S970@/2`G)SL*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1T86)L95]F:65L9',@87,@)'9A;'5E*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1F:7)S="D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D9FER<W0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<V5T("X]("<L
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'-E="`N/2`B)'9A;'5E(#T@/R(["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<W%L(#T@(E501$%412`D=&%B;&4@4T54("1S970B.PH@
M("`@("`@("`@("`@("`@:68@*"1W:&5R92D@>PH@("`@("`@("`@("`@("`@
M("`@("1S<6P@+CT@(B!72$5212`D=VAE<F4B.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@<F5T=7)N("1S<6P["B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%
M4E)/4E]364Y405@I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!E>&5C=71E*"D*"B`@("`O*BH*("`@("`J($5X96-U=&5S(&$@
M1$(@<W1A=&5M96YT('!R97!A<F5D('=I=&@@<')E<&%R92@I"B`@("`@*@H@
M("`@("H@17AA;7!L92`Q+@H@("`@("H@/&-O9&4^(#P_<&AP"B`@("`@*B`D
M<W1H(#T@)&1B:"T^<')E<&%R92@G24Y315)4($E.5$\@=&)L("AA+"!B+"!C
M*2!604Q515,@*#\L("$L("8I)RD["B`@("`@*B`D9&%T82`](&%R<F%Y*`H@
M("`@("H@("`@(")*;VAN)W,@=&5X="(L"B`@("`@*B`@("`@(B=I="<G<R!G
M;V]D)R(L"B`@("`@*B`@("`@)V9I;&5N86UE+G1X="<*("`@("`J("D["B`@
M("`@*B`D<F5S(#TF("1D8F@M/F5X96-U=&4H)'-T:"P@)&1A=&$I.PH@("`@
M("H@/SX\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("`D
M<W1M="`@82!$0B!S=&%T96UE;G0@<F5S;W5R8V4@<F5T=7)N960@9G)O;2!P
M<F5P87)E*"D*("`@("`J($!P87)A;2!M:7AE9"`@)&1A=&$@(&%R<F%Y+"!S
M=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT
M+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R
M<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N
M:6YG(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E
M<B!A<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T
M("!A(&YE=R!$0E]297-U;'0@;W(@82!$0E]%<G)O<B!W:&5N(&9A:6P*("`@
M("`J"B`@("`@*B![0&EN=&5R;F%L(&EB87-E(&%N9"!O8VDX(&AA=F4@=&AE
M:7(@;W=N(&5X96-U=&4H*2!M971H;V1S+GU]"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.G!R97!A<F4H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F5X96-U=&4H)'-T;70L("1D871A(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D<F5A;'%U97)Y(#T@)'1H:7,M/F5X
M96-U=&5%;75L871E475E<GDH)'-T;70L("1D871A*3L*("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')E86QQ=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1R96%L<75E<GD["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^<VEM<&QE475E<GDH)')E86QQ=65R>2D["@H@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2!\?"`D<F5S=6QT(#T]/2!$0E]/2RD@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&UP(#TF(&YE=R!$0E]R97-U;'0H)'1H:7,L("1R97-U;'0I
M.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("!]"B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@97AE8W5T945M=6QA=&51=65R>2@I"@H@
M("`@+RHJ"B`@("`@*B!%;75L871E<R!T:&4@97AE8W5T92!S=&%T96UE;G0L
M('=H96X@;F]T('-U<'!O<G1E9`H@("`@("H*("`@("`J($!P87)A;2!R97-O
M=7)C92`@)'-T;70@(&$@1$(@<W1A=&5M96YT(')E<V]U<F-E(')E='5R;F5D
M(&9R;VT@97AE8W5T92@I"B`@("`@*B!`<&%R86T@;6EX960@("1D871A("!A
M<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T
M871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C
M96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@('%U97)Y
M.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@,2!P;&%C96AO
M;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(')E86P@<75E<GD@<G5N
M('=H96X@96UU;&%T:6YG"B`@("`@*B`@("`@("`@("`@("`@('!R97!A<F4O
M97AE8W5T92X@($$@1$(@97)R;W(@8V]D92!I<R!R971U<FYE9"!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIE>&5C=71E*"D*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!E
M>&5C=71E16UU;&%T95%U97)Y*"1S=&UT+"`D9&%T82`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D9&%T82DI('L*("`@("`@("`@
M("`@)&1A=&$@/2!A<G)A>2@D9&%T82D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H8V]U;G0H)'1H:7,M/G!R97!A<F5?='EP97-;)'-T;71=*2`A/2!C;W5N
M="@D9&%T82DI('L*("`@("`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D
M=&AI<RT^<')E<&%R961?<75E<FEE<ULD<W1M=%T["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]-25--051#2"D["B`@
M("`@("`@?0H*("`@("`@("`D<F5A;'%U97)Y(#T@)'1H:7,M/G!R97!A<F5?
M=&]K96YS6R1S=&UT75LP73L*"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O
M<F5A8V@@*"1D871A(&%S("1V86QU92D@>PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/G!R97!A<F5?='EP97-;)'-T;71=6R1I72`]/2!$0E]005)!35]30T%,
M05(I('L*("`@("`@("`@("`@("`@("1R96%L<75E<GD@+CT@)'1H:7,M/G%U
M;W1E4VUA<G0H)'9A;'5E*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES
M+3YP<F5P87)E7W1Y<&5S6R1S=&UT75LD:5T@/3T@1$)?4$%204U?3U!!455%
M*2!["B`@("`@("`@("`@("`@("`D9G`@/2!`9F]P96XH)'9A;'5E+"`G<F(G
M*3L*("`@("`@("`@("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T%#0T53
M4U]624],051)3TXI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)')E86QQ=65R>2`N/2`D=&AI<RT^<75O=&53;6%R="AF<F5A9"@D9G`L
M(&9I;&5S:7IE*"1V86QU92DI*3L*("`@("`@("`@("`@("`@(&9C;&]S92@D
M9G`I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E
M86QQ=65R>2`N/2`D=F%L=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1R96%L<75E<GD@+CT@)'1H:7,M/G!R97!A<F5?=&]K96YS6R1S=&UT75LK
M*R1I73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5A;'%U97)Y.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5X96-U=&5-=6QT:7!L92@I
M"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N(&1O97,@<V5V97)A;"!E
M>&5C=71E*"D@8V%L;',@;VX@=&AE('-A;64*("`@("`J('-T871E;65N="!H
M86YD;&4*("`@("`J"B`@("`@*B`D9&%T82!M=7-T(&)E(&%N(&%R<F%Y(&EN
M9&5X960@;G5M97)I8V%L;'D*("`@("`J(&9R;VT@,"P@;VYE(&5X96-U=&4@
M8V%L;"!I<R!D;VYE(&9O<B!E=F5R>2`B<F]W(B!I;B!T:&4@87)R87DN"B`@
M("`@*@H@("`@("H@268@86X@97)R;W(@;V-C=7)S(&1U<FEN9R!E>&5C=71E
M*"DL(&5X96-U=&5-=6QT:7!L92@I(&1O97,@;F]T"B`@("`@*B!E>&5C=71E
M('1H92!U;F9I;FES:&5D(')O=W,L(&)U="!R871H97(@<F5T=7)N<R!T:&%T
M(&5R<F]R+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<W1M="!Q
M=65R>2!H86YD;&4@9G)O;2!P<F5P87)E*"D*("`@("`J($!P87)A;2!A<G)A
M>2`@("`D9&%T82!N=6UE<FEC(&%R<F%Y(&-O;G1A:6YI;F<@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@9&%T82!T;R!I;G-E<G0@:6YT;R!T
M:&4@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"7T]+(&]R
M($1"7T5R<F]R"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G!R97!A
M<F4H*2P@1$)?8V]M;6]N.CIE>&5C=71E*"D*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X96-U=&5-=6QT:7!L92@D<W1M
M="P@)&1A=&$I"B`@("!["B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)'9A
M;'5E*2!["B`@("`@("`@("`@("1R97,@/28@)'1H:7,M/F5X96-U=&4H)'-T
M;70L("1V86QU92D["B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&9R9650<F5P87)E9"@I"@H@("`@+RHJ"B`@
M("`@*B!&<F5E('1H92!R97-O=7)C92!U<V5D(&EN(&$@<')E<&%R960@<75E
M<GD*("`@("`J"B`@("`@*B!`<&%R86T@)'-T;70@5&AE(')E<W5R8V4@<F5T
M=7)N960@8GD@=&AE('!R97!A<F4H*2!F=6YC=&EO;@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.G!R97!A<F4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E
M4')E<&%R960H)'-T;70I"B`@("!["B`@("`@("`@+R\@1G)E92!T:&4@:6YT
M97)N86P@<')E<&%R960@=F%R<PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M<')E<&%R95]T;VME;G-;)'-T;71=*2D@>PH@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^<')E<&%R95]T;VME;G-;)'-T;71=*3L*("`@("`@("`@("`@=6YS
M970H)'1H:7,M/G!R97!A<F5?='EP97-;)'-T;71=*3L*("`@("`@("`@("`@
M=6YS970H)'1H:7,M/G!R97!A<F5D7W%U97)I97-;)'-T;71=*3L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE1=65R
M>2@I"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!U<V5D(&)Y(&)A
M8VME;F1S('1O(&%L=&5R('%U97)I97,@9F]R('9A<FEO=7,*("`@("`J(')E
M87-O;G,*("`@("`J"B`@("`@*B!)="!I<R!D969I;F5D(&AE<F4@=&\@87-S
M=7)E('1H870@86QL(&EM<&QE;65N=&%T:6]N<PH@("`@("H@:&%V92!T:&ES
M(&UE=&AO9"!D969I;F5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'%U97)Y("!Q=65R>2!T;R!M;V1I9GD*("`@("`J"B`@("`@*B!`<F5T=7)N
M('1H92!N97<@*&UO9&EF:65D*2!Q=65R>0H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R>2@D
M<75E<GDI('L*("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI;6ET475E<GDH*0H*("`@("\J*@H@
M("`@("H@5&AI<R!M971H;V0@:7,@=7-E9"!B>2!B86-K96YD<R!T;R!A;'1E
M<B!L:6UI=&5D('%U97)I97,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D<75E<GD@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9G)O;2`@=&AE(')O=R!T;R!S=&%R="!T;R!F971C:&EN9PH@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-O=6YT('1H92!N=6UB97)S(&]F(')O=W,@=&\@
M9F5T8V@*("`@("`J"B`@("`@*B!`<F5T=7)N('1H92!N97<@*&UO9&EF:65D
M*2!Q=65R>0H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y*"1Q=65R>2P@)&9R;VTL
M("1C;W5N="D*("`@('L*("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[('%U97)Y*"D*"B`@("`O*BH*("`@("`J
M(%-E;F0@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@86YD(')E='5R;B!A;GD@
M<F5S=6QT<R!W:71H(&$*("`@("`J($1"7W)E<W5L="!O8FIE8W0*("`@("`J
M"B`@("`@*B!4:&4@<75E<GD@<W1R:6YG(&-A;B!B92!E:71H97(@82!N;W)M
M86P@<W1A=&5M96YT('1O(&)E('-E;G0@9&ER96-T;'D*("`@("`J('1O('1H
M92!S97)V97(@3U(@:68@/'9A<CXD<&%R86US/"]V87(^(&%R92!P87-S960@
M=&AE('%U97)Y(&-A;B!H879E"B`@("`@*B!P;&%C96AO;&1E<G,@86YD(&ET
M('=I;&P@8F4@<&%S<V5D('1H<F]U9V@@<')E<&%R92@I(&%N9"!E>&5C=71E
M*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@('1H92!3
M44P@<75E<GD@;W(@=&AE('-T871E;65N="!T;R!P<F5P87)E"B`@("`@*B!`
M<&%R86T@;6EX960@("1P87)A;7,@87)R87DL('-T<FEN9R!O<B!N=6UE<FEC
M(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@
M:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S
M="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI;F<@,2!P;&%C96AO
M;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M
M96YT+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(&$@1$)?<F5S=6QT
M(&]B:F5C="!O<B!$0E]/2R!O;B!S=6-C97-S+"!A($1""B`@("`@*B`@("`@
M("`@("`@("`@("!E<G)O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0L($1"7V-O;6UO;CHZ<')E<&%R92@I+"!$0E]C;VUM;VXZ
M.F5X96-U=&4H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@)G%U97)Y*"1Q=65R>2P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`^(#`I('L*("`@("`@
M("`@("`@)'-T:"`]("1T:&ES+3YP<F5P87)E*"1Q=65R>2D["B`@("`@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D<W1H*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S=&@["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E="`]
M)B`D=&AI<RT^97AE8W5T92@D<W1H+"`D<&%R86US*3L*("`@("`@("`@("`@
M)'1H:7,M/F9R9650<F5P87)E9"@D<W1H*3L*("`@("`@("`@("`@<F5T=7)N
M("1R970["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YS:6UP;&51=65R>2@D<75E<GDI.PH@("`@("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')E<W5L="D@?'P@)')E<W5L="`]/3T@1$)?3TLI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1M<"`])B!N97<@1$)?<F5S=6QT
M*"1T:&ES+"`D<F5S=6QT*3L*("`@("`@("`@("`@("`@(')E='5R;B`D=&UP
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&QI;6ET475E<GDH*0H*("`@("\J*@H@("`@("H@1V5N97)A
M=&5S(&$@;&EM:71E9"!Q=65R>0H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("1Q=65R>2!Q=65R>0H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9R;VT@
M('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C;W5N="!T:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@
M("`@*B!`<&%R86T@87)R87D@("`D<&%R86US(')E<75I<F5D(&9O<B!A('-T
M871E;65N=`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@82!$0E]297-U
M;'0@;V)J96-T+"!$0E]/2R!O<B!A($1"7T5R<F]R"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)FQI;6ET475E
M<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y3&EM:711=65R
M>2@D<75E<GDL("1F<F]M+"`D8V]U;G0I.PH@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D<75E<GDI*7L*("`@("`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@
M("`@("!]"B`@("`@("`@)')E<W5L="`])B`D=&AI<RT^<75E<GDH)'%U97)Y
M+"`D<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G1$)?<F5S
M=6QT)RDI('L*("`@("`@("`@("`@)')E<W5L="T^<V5T3W!T:6]N*"=L:6UI
M=%]F<F]M)RP@)&9R;VTI.PH@("`@("`@("`@("`D<F5S=6QT+3YS971/<'1I
M;VXH)VQI;6ET7V-O=6YT)RP@)&-O=6YT*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9V5T3VYE*"D*"B`@("`O*BH*("`@("`J($9E=&-H('1H92!F:7)S="!C;VQU
M;6X@;V8@=&AE(&9I<G-T(')O=R!O9B!D871A(')E='5R;F5D(&9R;VT*("`@
M("`J(&$@<75E<GD*("`@("`J"B`@("`@*B!486ME<R!C87)E(&]F(&1O:6YG
M('1H92!Q=65R>2!A;F0@9G)E96EN9R!T:&4@<F5S=6QT<R!W:&5N(&9I;FES
M:&5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@
M4U%,('%U97)Y"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@87)R87DL
M('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M
M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO
M;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@
M(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L
M9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@('1H92!R971U<FYE9"!V86QU92!O9B!T:&4@<75E<GDN("!$0E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971/;F4H)'%U97)Y+"`D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S971T>7!E*"1P87)A;7,L("=A
M<G)A>2<I.PH@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/B`P*2!["B`@
M("`@("`@("`@("1S=&@@/2`D=&AI<RT^<')E<&%R92@D<75E<GDI.PH@("`@
M("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<W1H.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R
M97,@/28@)'1H:7,M/F5X96-U=&4H)'-T:"P@)'!A<F%M<RD["B`@("`@("`@
M("`@("1T:&ES+3YF<F5E4')E<&%R960H)'-T:"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)')E<R`])B`D=&AI<RT^<75E<GDH)'%U97)Y*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1E
M<G(@/2`D<F5S+3YF971C:$EN=&\H)')O=RP@1$)?1D540TA-3T1%7T]21$52
M140I.PH@("`@("`@("1R97,M/F9R964H*3L*"B`@("`@("`@:68@*"1E<G(@
M(3T]($1"7T]+*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R;W=;,%T["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9V5T4F]W*"D*"B`@("`O*BH*("`@("`J($9E=&-H('1H
M92!F:7)S="!R;W<@;V8@9&%T82!R971U<FYE9"!F<F]M(&$@<75E<GD*("`@
M("`J"B`@("`@*B!486ME<R!C87)E(&]F(&1O:6YG('1H92!Q=65R>2!A;F0@
M9G)E96EN9R!T:&4@<F5S=6QT<R!W:&5N(&9I;FES:&5D+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@4U%,('%U97)Y"B`@("`@
M*B!`<&%R86T@87)R87D@("1P87)A;7,@87)R87D@=&\@8F4@=7-E9"!I;B!E
M>&5C=71I;VX@;V8@=&AE('-T871E;65N="X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!1=6%N=&ET>2!O9B!A<G)A>2!E;&5M96YT<R!M=7-T(&UA
M=&-H('%U86YT:71Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;V8@
M<&QA8V5H;VQD97)S(&EN('%U97)Y+B`@5&AI<R!F=6YC=&EO;B!D;V5S"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@3D]4('-U<'!O<G0@<V-A;&%R
M<RX*("`@("`J($!P87)A;2!I;G0@("`@)&9E=&-H;6]D92`@=&AE(&9E=&-H
M(&UO9&4@=&\@=7-E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!T:&4@
M9FER<W0@<F]W(&]F(')E<W5L=',@87,@86X@87)R87D@:6YD97AE9"!F<F]M
M"B`@("`@*B`@("`@("`@("`@("`@(#`L(&]R(&$@1$(@97)R;W(@8V]D92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B`F9V5T4F]W*"1Q=65R>2P*("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<R`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("1F971C:&UO
M9&4@/2!$0E]&151#2$U/1$5?1$5&055,5"D*("`@('L*("`@("`@("`O+R!C
M;VUP870@8VAE8VLL('1H92!P87)A;7,@86YD(&9E=&-H;6]D92!P87)A;65T
M97)S('5S960@=&\*("`@("`@("`O+R!H879E('1H92!O<'!O<VET92!O<F1E
M<@H@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1F971C:&UO9&4I*2!["B`@("`@("`@("`@("`@
M("!I9B`H)'!A<F%M<R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@
M("1T;7`@/2!$0E]&151#2$U/1$5?1$5&055,5#L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]("1P87)A;7,[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<&%R86US(#T@
M)&9E=&-H;6]D93L*("`@("`@("`@("`@("`@("1F971C:&UO9&4@/2`D=&UP
M.PH@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M<R`A/3T@;G5L;"D@>PH@
M("`@("`@("`@("`@("`@)&9E=&-H;6]D92`]("1P87)A;7,["B`@("`@("`@
M("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`^(#`I('L*("`@
M("`@("`@("`@)'-T:"`]("1T:&ES+3YP<F5P87)E*"1Q=65R>2D["B`@("`@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<W1H*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1S=&@["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E
M<R`])B`D=&AI<RT^97AE8W5T92@D<W1H+"`D<&%R86US*3L*("`@("`@("`@
M("`@)'1H:7,M/F9R9650<F5P87)E9"@D<W1H*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YQ=65R>2@D<75E<GDI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&5R
M<B`]("1R97,M/F9E=&-H26YT;R@D<F]W+"`D9F5T8VAM;V1E*3L*"B`@("`@
M("`@)')E<RT^9G)E92@I.PH*("`@("`@("!I9B`H)&5R<B`A/3T@1$)?3TLI
M('L*("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)')O=SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M971#;VPH*0H*("`@("\J*@H@("`@("H@1F5T8V@@82!S:6YG;&4@8V]L=6UN
M(&9R;VT@82!R97-U;'0@<V5T(&%N9"!R971U<FX@:70@87,@86X*("`@("`J
M(&EN9&5X960@87)R87D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q
M=65R>2`@=&AE(%-13"!Q=65R>0H@("`@("H@0'!A<F%M(&UI>&5D("`D8V]L
M("`@('=H:6-H(&-O;'5M;B!T;R!R971U<FX@*&EN=&5G97(@6V-O;'5M;B!N
M=6UB97(L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W1A<G1I;F<@
M870@,%T@;W(@<W1R:6YG(%MC;VQU;6X@;F%M95TI"B`@("`@*B!`<&%R86T@
M;6EX960@("1P87)A;7,@87)R87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@
M=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&5X
M96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C
M:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F
M;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%R
M86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&EN9&5X960@87)R87D@
M=VET:"!T:&4@9&%T82!F<F]M('1H92!F:7)S=`H@("`@("H@("`@("`@("`@
M("`@("`@<F]W(&%T(&EN9&5X(#`L(&]R(&$@1$(@97)R;W(@8V]D90H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ=65R>2@I"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T0V]L*"1Q=65R
M>2P@)&-O;"`](#`L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M('-E='1Y<&4H)'!A<F%M<RP@)V%R<F%Y)RD["B`@("`@("`@:68@*'-I>F5O
M9B@D<&%R86US*2`^(#`I('L*("`@("`@("`@("`@)'-T:"`]("1T:&ES+3YP
M<F5P87)E*"1Q=65R>2D["@H@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)'-T:"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W1H.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YE>&5C=71E*"1S
M=&@L("1P87)A;7,I.PH@("`@("`@("`@("`D=&AI<RT^9G)E95!R97!A<F5D
M*"1S=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97,@/28@
M)'1H:7,M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,[
M"B`@("`@("`@?0H*("`@("`@("`D9F5T8VAM;V1E(#T@:7-?:6YT*"1C;VPI
M(#\@1$)?1D540TA-3T1%7T]21$52140@.B!$0E]&151#2$U/1$5?05-33T,[
M"B`@("`@("`@)')E="`](&%R<F%Y*"D["@H@("`@("`@('=H:6QE("AI<U]A
M<G)A>2@D<F]W(#T@)')E<RT^9F5T8VA2;W<H)&9E=&-H;6]D92DI*2!["B`@
M("`@("`@("`@("1R971;72`]("1R;W=;)&-O;%T["B`@("`@("`@?0H*("`@
M("`@("`D<F5S+3YF<F5E*"D["@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F]W*2D@>PH@("`@("`@("`@("`D<F5T(#T@)')O=SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&=E=$%S<V]C*"D*"B`@("`O*BH*("`@("`J($9E=&-H('1H92!E;G1I
M<F4@<F5S=6QT('-E="!O9B!A('%U97)Y(&%N9"!R971U<FX@:70@87,@86X*
M("`@("`J(&%S<V]C:6%T:79E(&%R<F%Y('5S:6YG('1H92!F:7)S="!C;VQU
M;6X@87,@=&AE(&ME>0H@("`@("H*("`@("`J($EF('1H92!R97-U;'0@<V5T
M(&-O;G1A:6YS(&UO<F4@=&AA;B!T=V\@8V]L=6UN<RP@=&AE('9A;'5E"B`@
M("`@*B!W:6QL(&)E(&%N(&%R<F%Y(&]F('1H92!V86QU97,@9G)O;2!C;VQU
M;6X@,BUN+B`@268@=&AE(')E<W5L=`H@("`@("H@<V5T(&-O;G1A:6YS(&]N
M;'D@='=O(&-O;'5M;G,L('1H92!R971U<FYE9"!V86QU92!W:6QL(&)E(&$*
M("`@("`J('-C86QA<B!W:71H('1H92!V86QU92!O9B!T:&4@<V5C;VYD(&-O
M;'5M;B`H=6YL97-S(&9O<F-E9"!T;R!A;@H@("`@("H@87)R87D@=VET:"!T
M:&4@)&9O<F-E7V%R<F%Y('!A<F%M971E<BDN("!!($1"(&5R<F]R(&-O9&4@
M:7,*("`@("`J(')E='5R;F5D(&]N(&5R<F]R<RX@($EF('1H92!R97-U;'0@
M<V5T(&-O;G1A:6YS(&9E=V5R('1H86X@='=O"B`@("`@*B!C;VQU;6YS+"!A
M($1"7T524D]27U1254Y#051%1"!E<G)O<B!I<R!R971U<FYE9"X*("`@("`J
M"B`@("`@*B!&;W(@97AA;7!L92P@:68@=&AE('1A8FQE(")M>71A8FQE(B!C
M;VYT86EN<SH*("`@("`J"B`@("`@*B`\<')E/@H@("`@("H@($E$("`@("`@
M5$585"`@("`@("!$051%"B`@("`@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0H@("`@("H@(#$@("`@("`@)V]N92<@("`@("`Y-#0V-SDT
M,#@*("`@("`J("`R("`@("`@("=T=V\G("`@("`@.30T-C<Y-#`X"B`@("`@
M*B`@,R`@("`@("`G=&AR964G("`@(#DT-#8W.30P.`H@("`@("H@/"]P<F4^
M"B`@("`@*@H@("`@("H@5&AE;B!T:&4@8V%L;"!G971!<W-O8R@G4T5,14-4
M(&ED+'1E>'0@1E)/32!M>71A8FQE)RD@<F5T=7)N<SH*("`@("`J(#QP<F4^
M"B`@("`@*B`@(&%R<F%Y*`H@("`@("H@("`@("<Q)R`]/B`G;VYE)RP*("`@
M("`J("`@("`G,B<@/3X@)W1W;R<L"B`@("`@*B`@("`@)S,G(#T^("=T:')E
M92<L"B`@("`@*B`@("D*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J("XN
M+G=H:6QE('1H92!C86QL(&=E=$%S<V]C*"=314Q%0U0@:60L=&5X="QD871E
M($923TT@;7ET86)L92<I(')E='5R;G,Z"B`@("`@*B`\<')E/@H@("`@("H@
M("!A<G)A>2@*("`@("`J("`@("`G,2<@/3X@87)R87DH)V]N92<L("<Y-#0V
M-SDT,#@G*2P*("`@("`J("`@("`G,B<@/3X@87)R87DH)W1W;R<L("<Y-#0V
M-SDT,#@G*2P*("`@("`J("`@("`G,R<@/3X@87)R87DH)W1H<F5E)RP@)SDT
M-#8W.30P."<I"B`@("`@*B`@("D*("`@("`J(#PO<')E/@H@("`@("H*("`@
M("`J($EF('1H92!M;W)E('1H86X@;VYE(')O=R!O8V-U<G,@=VET:"!T:&4@
M<V%M92!V86QU92!I;B!T:&4*("`@("`J(&9I<G-T(&-O;'5M;BP@=&AE(&QA
M<W0@<F]W(&]V97)W<FET97,@86QL('!R979I;W5S(&]N97,@8GD*("`@("`J
M(&1E9F%U;'0N("!5<V4@=&AE("1G<F]U<"!P87)A;65T97(@:68@>6]U(&1O
M;B=T('=A;G0@=&\*("`@("`J(&]V97)W<FET92!L:6ME('1H:7,N("!%>&%M
M<&QE.@H@("`@("H*("`@("`J(#QP<F4^"B`@("`@*B!G971!<W-O8R@G4T5,
M14-4(&-A=&5G;W)Y+&ED+&YA;64@1E)/32!M>71A8FQE)RP@9F%L<V4L(&YU
M;&PL"B`@("`@*B`@("`@("`@("!$0E]&151#2$U/1$5?05-33T,L('1R=64I
M(')E='5R;G,Z"B`@("`@*@H@("`@("H@("!A<G)A>2@*("`@("`J("`@("`G
M,2<@/3X@87)R87DH87)R87DH)VED)R`]/B`G-"<L("=N86UE)R`]/B`G;G5M
M8F5R(&9O=7(G*2P*("`@("`J("`@("`@("`@("`@("`@("`@87)R87DH)VED
M)R`]/B`G-B<L("=N86UE)R`]/B`G;G5M8F5R('-I>"<I"B`@("`@*B`@("`@
M("`@("`@("DL"B`@("`@*B`@("`@)SDG(#T^(&%R<F%Y*&%R<F%Y*"=I9"<@
M/3X@)S0G+"`G;F%M92<@/3X@)VYU;6)E<B!F;W5R)RDL"B`@("`@*B`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=I9"<@/3X@)S8G+"`G;F%M92<@/3X@)VYU
M;6)E<B!S:7@G*0H@("`@("H@("`@("`@("`@("`I"B`@("`@*B`@("D*("`@
M("`J(#PO<')E/@H@("`@("H*("`@("`J($ME97`@:6X@;6EN9"!T:&%T(&1A
M=&%B87-E(&9U;F-T:6]N<R!I;B!02%`@=7-U86QL>2!R971U<FX@<W1R:6YG
M"B`@("`@*B!V86QU97,@9F]R(')E<W5L=',@<F5G87)D;&5S<R!O9B!T:&4@
M9&%T86)A<V4G<R!I;G1E<FYA;"!T>7!E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("1Q=65R>2`@=&AE(%-13"!Q=65R>0H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&9O<F-E7V%R<F%Y("!U<V5D(&]N;'D@=VAE;B!T:&4@<75E
M<GD@<F5T=7)N<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!E>&%C=&QY('1W;R!C;VQU;6YS+B`@268@=')U92P@=&AE('9A;'5E<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O9B!T:&4@<F5T
M=7)N960@87)R87D@=VEL;"!B92!O;F4M96QE;65N=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>7,@:6YS=&5A9"!O9B!S8V%L
M87)S+@H@("`@("H@0'!A<F%M(&UI>&5D("`@)'!A<F%M<R!A<G)A>2P@<W1R
M:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT
M+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD
M97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('%U97)Y.B`@
M;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L
M9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&=R;W5P("!I9B!T<G5E+"!T:&4@=F%L=65S(&]F('1H92!R971U<FYE9"!A
M<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I<R!W<F%P<&5D
M(&EN(&%N;W1H97(@87)R87DN("!)9B!T:&4@<V%M90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!K97D@=F%L=64@*&EN('1H92!F:7)S="!C;VQU
M;6XI(')E<&5A=',*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@:71S
M96QF+"!T:&4@=F%L=65S('=I;&P@8F4@87!P96YD960@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@=&AI<R!A<G)A>2!I;G-T96%D(&]F(&]V
M97)W<FET:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!E
M>&ES=&EN9R!V86QU97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M87-S;V-I871I=F4@87)R87D@=VET:"!R97-U;'1S(&9R;VT@=&AE('%U97)Y
M+@H@("`@("H@("`@("`@("`@("`@("`@1$(@17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B`F9V5T07-S;V,H)'%U97)Y+"`D9F]R8V5?87)R87D@/2!F86QS92P@
M)'!A<F%M<R`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@)&9E
M=&-H;6]D92`]($1"7T9%5$-(34]$15]$149!54Q4+"`D9W)O=7`@/2!F86QS
M92D*("`@('L*("`@("`@("!S971T>7!E*"1P87)A;7,L("=A<G)A>2<I.PH@
M("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/B`P*2!["B`@("`@("`@("`@
M("1S=&@@/2`D=&AI<RT^<')E<&%R92@D<75E<GDI.PH*("`@("`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1S=&@I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'-T:#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<R`])B`D
M=&AI<RT^97AE8W5T92@D<W1H+"`D<&%R86US*3L*("`@("`@("`@("`@)'1H
M:7,M/F9R9650<F5P87)E9"@D<W1H*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<F5S(#TF("1T:&ES+3YQ=65R>2@D<75E<GDI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H
M;6]D92`]/2!$0E]&151#2$U/1$5?1$5&055,5"D@>PH@("`@("`@("`@("`D
M9F5T8VAM;V1E(#T@)'1H:7,M/F9E=&-H;6]D93L*("`@("`@("!]"B`@("`@
M("`@)&-O;',@/2`D<F5S+3YN=6U#;VQS*"D["@H@("`@("`@(&EF("@D8V]L
M<R`\(#(I('L*("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^<F%I<V5%<G)O
M<BA$0E]%4E)/4E]44E5.0T%4140I.PH@("`@("`@("`@("!R971U<FX@)'1M
M<#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'1S(#T@87)R87DH*3L*"B`@
M("`@("`@:68@*"1C;VQS(#X@,B!\?"`D9F]R8V5?87)R87DI('L*("`@("`@
M("`@("`@+R\@<F5T=7)N(&%R<F%Y('9A;'5E<PH@("`@("`@("`@("`O+R!8
M6%@@=&AI<R!P87)T(&-A;B!B92!O<'1I;6EZ960*("`@("`@("`@("`@:68@
M*"1F971C:&UO9&4@/3T@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@
M("`@("`@("!W:&EL92`H:7-?87)R87DH)')O=R`]("1R97,M/F9E=&-H4F]W
M*$1"7T9%5$-(34]$15]!4U-/0RDI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5S970H)')O=RD["B`@("`@("`@("`@("`@("`@("`@)&ME>2`](&-U<G)E
M;G0H)')O=RD["B`@("`@("`@("`@("`@("`@("`@=6YS970H)')O=UMK97DH
M)')O=RE=*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&=R;W5P*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K97E=6UT@/2`D<F]W
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1R97-U;'1S6R1K97E=(#T@)')O=SL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M96EF("@D9F5T8VAM;V1E(#T]($1"7T9%5$-(34]$15]/0DI%0U0I('L*("`@
M("`@("`@("`@("`@('=H:6QE("@D<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?
M1D540TA-3T1%7T]"2D5#5"DI('L*("`@("`@("`@("`@("`@("`@("`D87)R
M(#T@9V5T7V]B:F5C=%]V87)S*"1R;W<I.PH@("`@("`@("`@("`@("`@("`@
M("1K97D@/2!C=7)R96YT*"1A<G(I.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D9W)O=7`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;
M)&ME>5U;72`]("1R;W<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5T@/2`D<F]W
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@('=H:6QE("AI<U]A
M<G)A>2@D<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52
M140I*2D@>PH@("`@("`@("`@("`@("`@("`@("\O('=E('-H:69T(&%W87D@
M=&AE(&9I<G-T(&5L96UE;G0@=&\@9V5T"B`@("`@("`@("`@("`@("`@("`@
M+R\@:6YD:6-E<R!R=6YN:6YG(&9R;VT@,"!A9V%I;@H@("`@("`@("`@("`@
M("`@("`@("1K97D@/2!A<G)A>5]S:&EF="@D<F]W*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&=R;W5P*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R97-U;'1S6R1K97E=6UT@/2`D<F]W.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K
M97E=(#T@)')O=SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R;W<I*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT<R`]("1R;W<[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!R971U<FX@<V-A;&%R('9A;'5E<PH@("`@("`@("`@("!W:&EL92`H:7-?
M87)R87DH)')O=R`]("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%
M4D5$*2DI('L*("`@("`@("`@("`@("`@(&EF("@D9W)O=7`I('L*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT<ULD<F]W6S!=75M=(#T@)')O=ULQ73L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)')E<W5L='-;)')O=ULP75T@/2`D<F]W6S%=.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F]W*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L=',@/2`D<F]W.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S+3YF<F5E*"D["@H@
M("`@("`@(')E='5R;B`D<F5S=6QT<SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!G971!;&PH*0H*("`@("\J*@H@("`@("H@1F5T8V@@86QL('1H
M92!R;W=S(')E='5R;F5D(&9R;VT@82!Q=65R>0H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'%U97)Y("!T:&4@4U%,('%U97)Y"B`@("`@*B!`<&%R
M86T@87)R87D@("1P87)A;7,@87)R87D@=&\@8F4@=7-E9"!I;B!E>&5C=71I
M;VX@;V8@=&AE('-T871E;65N="X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!1=6%N=&ET>2!O9B!A<G)A>2!E;&5M96YT<R!M=7-T(&UA=&-H('%U
M86YT:71Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;V8@<&QA8V5H
M;VQD97)S(&EN('%U97)Y+B`@5&AI<R!F=6YC=&EO;B!D;V5S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@3D]4('-U<'!O<G0@<V-A;&%R<RX*("`@
M("`J($!P87)A;2!I;G0@("`@)&9E=&-H;6]D92`@=&AE(&9E=&-H(&UO9&4@
M=&\@=7-E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@;F5S=&5D
M(&%R<F%Y+B`@1$(@97)R;W(@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T06QL*"1Q
M=65R>2P*("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"DL
M"B`@("`@("`@("`@("`@("`@("`@("1F971C:&UO9&4@/2!$0E]&151#2$U/
M1$5?1$5&055,5"D*("`@('L*("`@("`@("`O+R!C;VUP870@8VAE8VLL('1H
M92!P87)A;7,@86YD(&9E=&-H;6]D92!P87)A;65T97)S('5S960@=&\*("`@
M("`@("`O+R!H879E('1H92!O<'!O<VET92!O<F1E<@H@("`@("`@(&EF("@A
M:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1F971C:&UO9&4I*2!["B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<R`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!$0E]&151#
M2$U/1$5?1$5&055,5#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1M<"`]("1P87)A;7,["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D<&%R86US(#T@)&9E=&-H;6]D93L*("`@
M("`@("`@("`@("`@("1F971C:&UO9&4@/2`D=&UP.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)'!A<F%M<R`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@
M)&9E=&-H;6]D92`]("1P87)A;7,["B`@("`@("`@("`@("`@("`D<&%R86US
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*'-I>F5O9B@D<&%R86US*2`^(#`I('L*("`@("`@("`@("`@)'-T:"`]
M("1T:&ES+3YP<F5P87)E*"1Q=65R>2D["@H@("`@("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)'-T:"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W1H
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YE
M>&5C=71E*"1S=&@L("1P87)A;7,I.PH@("`@("`@("`@("`D=&AI<RT^9G)E
M95!R97!A<F5D*"1S=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1R97,@/28@)'1H:7,M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RD@?'P@)')E<R`]/2!$0E]/2RD@
M>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'1S(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H1$)?3TL@/3T]
M("1R97,M/F9E=&-H26YT;R@D<F]W+"`D9F5T8VAM;V1E*2D@>PH@("`@("`@
M("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]&3$E04$5$*2![
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F]W(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K97E=6UT@/2`D
M=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)')E<W5L='-;72`]("1R;W<["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1R97,M/F9R964H*3L*"B`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1R;W<I*2!["B`@("`@("`@("`@("1T;7`@/28@
M)'1H:7,M/G)A:7-E17)R;W(H)')O=RD["B`@("`@("`@("`@(')E='5R;B`D
M=&UP.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=',["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ
M"B`@("`@*B!E;F%B;&4@875T;VUA=&EC($-O;6UI=`H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1O;F]F9@H@("`@("H@0')E='5R;B!M:7AE9"!$
M0E]%<G)O<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N;V9F/69A;'-E*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?
M0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET
M*"D*"B`@("`O*BH*("`@("`J('-T87)T<R!A($-O;6UI=`H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@1$)?17)R;W(*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].
M3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L
M;&)A8VLH*0H*("`@("\J*@H@("`@("H@<W1A<G1S(&$@<F]L;&)A8VL*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"7T5R<F]R"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A
M8VLH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N
M=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!O8FIE8W0*("`@("`J"B`@("`@
M*B!`<&%R86T@;V)J96-T($1"7U)E<W5L="!T:&4@<F5S=6QT(&]B:F5C="!T
M;R!C:&5C:PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@1$)?17)R;W(@
M;W(@=&AE(&YU;6)E<B!O9B!R;W=S"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/
M4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%F
M9F5C=&5D(')O=W,@;V8@82!Q=65R>0H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@1$)?17)R;W(@;W(@;G5M8F5R(&]F(')O=W,*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E
M9%)O=W,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A;B!E<G)O<FUE<W-A9V4L('!R;W9I9&5S(&)Y('1H92!D871A8F%S90H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@1$)?17)R;W(@;W(@;65S<V%G
M90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-E<75E;F-E3F%M92@I"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@;F%M92!U<V5D(&EN<VED92!T:&4@
M9&%T86)A<V4@9F]R(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!4:&4@8W)E
M871E4V5Q=65N8V4H*2!D;V-B;&]C:R!C;VYT86EN<R!N;W1E<R!A8F]U="!S
M=&]R:6YG('-E<75E;F-E"B`@("`@*B!N86UE<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S<6X@('1H92!S97%U96YC92=S('!U8FQI8R!N86UE
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!S97%U96YC92=S
M(&YA;64@:6X@=&AE(&)A8VME;F0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CID<F]P4V5Q=65N
M8V4H*2P*("`@("`J("`@("`@1$)?8V]M;6]N.CIN97AT240H*2P@1$)?8V]M
M;6]N.CIS971/<'1I;VXH*0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%-E<75E;F-E3F%M92@D<W%N*0H@("`@>PH@
M("`@("`@(')E='5R;B!S<')I;G1F*"1T:&ES+3YG971/<'1I;VXH)W-E<6YA
M;65?9F]R;6%T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@<')E9U]R97!L
M86-E*"<O6UYA+7HP+3E?+ETO:2<L("=?)RP@)'-Q;BDI.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@
M<V5Q=65N8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE
M;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E<R!N
M;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@
M:60@;G5M8F5R(&EN('1H92!S97%U96YC92X@($1"7T5R<F]R(&EF('!R;V)L
M96TN"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E
M;F-E*"DL($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL"B`@("`@*B`@("`@
M($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"D*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L
M("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!C<F5A=&5397%U96YC92@I"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@
M5&AE(&YA;64@;V8@82!G:79E;B!S97%U96YC92!I<R!D971E<FUI;F5D(&)Y
M('!A<W-I;F<@=&AE('-T<FEN9PH@("`@("H@<')O=FED960@:6X@=&AE(#QV
M87(^)'-E<5]N86UE/"]V87(^(&%R9W5M96YT('1H<F]U9V@@4$A0)W,@<W!R
M:6YT9B@I"B`@("`@*B!F=6YC=&EO;B!U<VEN9R!T:&4@=F%L=64@9G)O;2!T
M:&4@/'9A<CYS97%N86UE7V9O<FUA=#PO=F%R/B!O<'1I;VX@87,*("`@("`J
M('1H92!S<')I;G1F*"DG<R!F;W)M870@87)G=6UE;G0N"B`@("`@*@H@("`@
M("H@/'9A<CYS97%N86UE7V9O<FUA=#PO=F%R/B!I<R!S970@=FEA('-E=$]P
M=&EO;B@I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE
M("!N86UE(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T
M(&ES(')E='5R;F5D(&EF"B`@("`@*B`@("`@("`@("`@("`@<')O8FQE;7,@
M87)I<V4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U
M96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@
M("`@("!$0E]C;VUM;VXZ.FYE>'1)1"@I"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA
M;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"
M7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!A
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA
M;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($1"7T5R
M<F]R(&EF('!R;V)L96US+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CIC<F5A=&5397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M
M92@I+`H@("`@("H@("`@("!$0E]C;VUM;VXZ.FYE>'1)1"@I"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N
M8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S
M970*("`@("`J"B`@("`@*B!4:&4@9F]R;6%T(&]F('1H92!R97-U;'1I;F<@
M87)R87D@9&5P96YD<R!O;B!W:&EC:"`\=F%R/B1M;V1E/"]V87(^"B`@("`@
M*B!Y;W4@<V5L96-T+B`@5&AE('-A;7!L92!O=71P=70@8F5L;W<@:7,@8F%S
M960@;VX@=&AI<R!Q=65R>3H*("`@("`J(#QP<F4^"B`@("`@*B`@("!314Q%
M0U0@=&)L1F]O+F9L9$E$+"!T8FQ&;V\N9FQD4&AO;F4L('1B;$)A<BYF;&1)
M9`H@("`@("H@("`@1E)/32!T8FQ&;V\*("`@("`J("`@($I/24X@=&)L0F%R
M($].('1B;$9O;RYF;&1)9"`]('1B;$)A<BYF;&1)9`H@("`@("H@/"]P<F4^
M"B`@("`@*@H@("`@("H@/'5L/@H@("`@("H@/&QI/@H@("`@("H*("`@("`J
M(#QK8F0^;G5L;#PO:V)D/B`H9&5F875L="D*("`@("`J("`@/'!R93X*("`@
M("`J("`@6S!=(#T^($%R<F%Y("@*("`@("`J("`@("`@(%MT86)L95T@/3X@
M=&)L1F]O"B`@("`@*B`@("`@("!;;F%M95T@/3X@9FQD260*("`@("`J("`@
M("`@(%MT>7!E72`]/B!I;G0*("`@("`J("`@("`@(%ML96Y=(#T^(#$Q"B`@
M("`@*B`@("`@("!;9FQA9W-=(#T^('!R:6UA<GE?:V5Y(&YO=%]N=6QL"B`@
M("`@*B`@("D*("`@("`J("`@6S%=(#T^($%R<F%Y("@*("`@("`J("`@("`@
M(%MT86)L95T@/3X@=&)L1F]O"B`@("`@*B`@("`@("!;;F%M95T@/3X@9FQD
M4&AO;F4*("`@("`J("`@("`@(%MT>7!E72`]/B!S=')I;F<*("`@("`J("`@
M("`@(%ML96Y=(#T^(#(P"B`@("`@*B`@("`@("!;9FQA9W-=(#T^"B`@("`@
M*B`@("D*("`@("`J("`@6S)=(#T^($%R<F%Y("@*("`@("`J("`@("`@(%MT
M86)L95T@/3X@=&)L0F%R"B`@("`@*B`@("`@("!;;F%M95T@/3X@9FQD260*
M("`@("`J("`@("`@(%MT>7!E72`]/B!I;G0*("`@("`J("`@("`@(%ML96Y=
M(#T^(#$Q"B`@("`@*B`@("`@("!;9FQA9W-=(#T^('!R:6UA<GE?:V5Y(&YO
M=%]N=6QL"B`@("`@*B`@("D*("`@("`J("`@/"]P<F4^"B`@("`@*@H@("`@
M("H@/"]L:3X\;&D^"B`@("`@*@H@("`@("H@/&MB9#Y$0E]404),14E.1D]?
M3U)$15(\+VMB9#X*("`@("`J"B`@("`@*B`@(#QP/DEN(&%D9&ET:6]N('1O
M('1H92!I;F9O<FUA=&EO;B!F;W5N9"!I;B!T:&4@9&5F875L="!O=71P=70L
M"B`@("`@*B`@(&$@;F]T871I;VX@;V8@=&AE(&YU;6)E<B!O9B!C;VQU;6YS
M(&ES('!R;W9I9&5D(&)Y('1H90H@("`@("H@("`\<V%M<#YN=6U?9FEE;&1S
M/"]S86UP/B!E;&5M96YT('=H:6QE('1H92`\<V%M<#YO<F1E<CPO<V%M<#X*
M("`@("`J("`@96QE;65N="!P<F]V:61E<R!A;B!A<G)A>2!W:71H('1H92!C
M;VQU;6X@;F%M97,@87,@=&AE(&ME>7,@86YD"B`@("`@*B`@('1H96ER(&QO
M8V%T:6]N(&EN9&5X(&YU;6)E<B`H8V]R<F5S<&]N9&EN9R!T;R!T:&4@:V5Y
M<R!I;B!T:&4*("`@("`J("`@=&AE(&1E9F%U;'0@;W5T<'5T*2!A<R!T:&4@
M=F%L=65S+CPO<#X*("`@("`J"B`@("`@*B`@(#QP/DEF(&$@<F5S=6QT('-E
M="!H87,@:61E;G1I8V%L(&9I96QD(&YA;65S+"!T:&4@;&%S="!O;F4@:7,*
M("`@("`J("`@=7-E9"X\+W`^"B`@("`@*@H@("`@("H@("`\<')E/@H@("`@
M("H@("!;;G5M7V9I96QD<UT@/3X@,PH@("`@("H@("!;;W)D97)=(#T^($%R
M<F%Y("@*("`@("`J("`@("`@(%MF;&1)9%T@/3X@,@H@("`@("H@("`@("`@
M6V9L9%1R86YS72`]/B`Q"B`@("`@*B`@("D*("`@("`J("`@/"]P<F4^"B`@
M("`@*@H@("`@("H@/"]L:3X\;&D^"B`@("`@*@H@("`@("H@/&MB9#Y$0E]4
M04),14E.1D]?3U)$15)404),13PO:V)D/@H@("`@("H*("`@("`J("`@/'`^
M4VEM:6QA<B!T;R`\:V)D/D1"7U1!0DQ%24Y&3U]/4D1%4CPO:V)D/B!B=70@
M861D<R!M;W)E"B`@("`@*B`@(&1I;65N<VEO;G,@=&\@=&AE(&%R<F%Y(&EN
M('=H:6-H('1H92!T86)L92!N86UE<R!A<F4@:V5Y<R!A;F0*("`@("`J("`@
M=&AE(&9I96QD(&YA;65S(&%R92!S=6(M:V5Y<RX@(%1H:7,@:7,@:&5L<&9U
M;"!F;W(@<75E<FEE<R!T:&%T"B`@("`@*B`@(&IO:6X@=&%B;&5S('=H:6-H
M(&AA=F4@:61E;G1I8V%L(&9I96QD(&YA;65S+CPO<#X*("`@("`J"B`@("`@
M*B`@(#QP<F4^"B`@("`@*B`@(%MN=6U?9FEE;&1S72`]/B`S"B`@("`@*B`@
M(%MO<F1E<G1A8FQE72`]/B!!<G)A>2`H"B`@("`@*B`@("`@("!;=&)L1F]O
M72`]/B!!<G)A>2`H"B`@("`@*B`@("`@("`@("`@6V9L9$ED72`]/B`P"B`@
M("`@*B`@("`@("`@("`@6V9L9%!H;VYE72`]/B`Q"B`@("`@*B`@("`@("`I
M"B`@("`@*B`@("`@("!;=&)L0F%R72`]/B!!<G)A>2`H"B`@("`@*B`@("`@
M("`@("`@6V9L9$ED72`]/B`R"B`@("`@*B`@("`@("`I"B`@("`@*B`@("D*
M("`@("`J("`@/"]P<F4^"B`@("`@*@H@("`@("H@/"]L:3X*("`@("`J(#PO
M=6P^"B`@("`@*@H@("`@("H@5&AE(#QS86UP/F9L86=S/"]S86UP/B!E;&5M
M96YT(&-O;G1A:6YS(&$@<W!A8V4@<V5P87)A=&5D(&QI<W0*("`@("`J(&]F
M(&5X=')A(&EN9F]R;6%T:6]N(&%B;W5T('1H92!F:65L9"X@(%1H:7,@9&%T
M82!I<R!I;F-O;G-I<W1E;G0*("`@("`J(&)E='=E96X@1$)-4R=S(&1U92!T
M;R!T:&4@=V%Y(&5A8V@@1$)-4R!W;W)K<RX*("`@("`J("`@*R`\<V%M<#YP
M<FEM87)Y7VME>3PO<V%M<#X*("`@("`J("`@*R`\<V%M<#YU;FEQ=65?:V5Y
M/"]S86UP/@H@("`@("H@("`K(#QS86UP/FUU;'1I<&QE7VME>3PO<V%M<#X*
M("`@("`J("`@*R`\<V%M<#YN;W1?;G5L;#PO<V%M<#X*("`@("`J"B`@("`@
M*B!-;W-T($1"35,G<R!O;FQY('!R;W9I9&4@=&AE(#QS86UP/G1A8FQE/"]S
M86UP/B!A;F0@/'-A;7`^9FQA9W,\+W-A;7`^"B`@("`@*B!E;&5M96YT<R!I
M9B`\=F%R/B1R97-U;'0\+W9A<CX@:7,@82!T86)L92!N86UE+B`@5&AE(&9O
M;&QO=VEN9R!$0DU3)W,*("`@("`J('!R;W9I9&4@9G5L;"!I;F9O<FUA=&EO
M;B!F<F]M('%U97)I97,Z"B`@("`@*B`@("L@9F)S<6P*("`@("`J("`@*R!M
M>7-Q;`H@("`@("H*("`@("`J($EF('1H92`G<&]R=&%B:6QI='DG(&]P=&EO
M;B!H87,@/'-A;7`^1$)?4$]25$%"24Q)5%E?3$]715)#05-%/"]S86UP/@H@
M("`@("H@='5R;F5D(&]N+"!T:&4@;F%M97,@;V8@=&%B;&5S(&%N9"!F:65L
M9',@=VEL;"!B92!L;W=E<F-A<V5D+@H@("`@("H*("`@("`J($!P87)A;2!O
M8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R;VT@
M82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T86)L92X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!7:&EL92!T
M:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(')E<V]U<F-E(&ED96YT:69I97(L
M('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A<F%M(&EN="`@)&UO
M9&4@("!E:71H97(@=6YU<V5D(&]R(&]N92!O9B!T:&4@=&%B;&5);F9O(&UO
M9&5S.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`\:V)D/D1"7U1!0DQ%
M24Y&3U]/4D1%4E1!0DQ%/"]K8F0^+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`\:V)D/D1"7U1!0DQ%24Y&3U]/4D1%4CPO:V)D/B!O<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`\:V)D/D1"7U1!0DQ%24Y&3U]&54Q,/"]K
M8F0^("AW:&EC:"!D;V5S(&)O=&@I+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("!4:&5S92!A<F4@8FET=VES92P@<V\@=&AE(&9I<G-T('1W;R!C86X@
M8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@8V]M8FEN960@=7-I;F<@
M/&MB9#Y\/"]K8F0^+@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I
M871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@
M("`@("H@("`@("`@("`@("`@("`@268@<V]M971H:6YG(&=O97,@=W)O;F<@
M86X@97)R;W(@;V)J96-T(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($!S
M964@1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M
M;V1E(#T@;G5L;"D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($EF('1H
M92!$0E\\9')I=F5R/B!C;&%S<R!H87,@82!T86)L94EN9F\H*2!M971H;V0L
M('1H870@;VYE"B`@("`@("`@("H@;W9E<G)I9&5S('1H:7,@;VYE+B`@0G5T
M+"!I9B!T:&4@9')I=F5R(&1O97-N)W0@:&%V92!O;F4L"B`@("`@("`@("H@
M=&AI<R!M971H;V0@<G5N<R!A;F0@=&5L;',@=7-E<G,@86)O=70@=&AA="!F
M86-T+@H@("`@("`@("`J+PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9V5T5&%B;&5S*"D*"B`@("`O*BH*("`@("`J($!D97!R
M96-A=&5D("!$97!R96-A=&5D(&EN(')E;&5A<V4@,2XR(&]R(&QO=V5R"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%1A8FQE<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YG971,:7-T3V8H)W1A8FQE<R<I.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&=E=$QI<W1/9B@I"@H@("`@+RHJ"B`@("`@
M*B!L:7-T(&EN=&5R;F%L($1"(&EN9F\*("`@("`J('9A;&ED('9A;'5E<R!F
M;W(@)'1Y<&4@87)E(&1B(&1E<&5N9&5N="P*("`@("`J(&]F=&5N.B!D871A
M8F%S97,L('5S97)S+"!V:65W+"!F=6YC=&EO;G,*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T>7!E('1Y<&4@;V8@<F5Q=65S=&5D(&EN9F\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"7T5R<F]R(&]R('1H92!R97%U
M97-T960@9&%T80H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$QI<W1/9B@D='EP92D*("`@('L*("`@("`@
M("`D<W%L(#T@)'1H:7,M/F=E=%-P96-I86Q1=65R>2@D='EP92D["B`@("`@
M("`@:68@*"1S<6P@/3T](&YU;&PI('L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O($YO('-U<'!O<G0*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*$1"7T524D]27U5.4U504$]25$5$*3L*("`@("`@
M("!](&5L<V5I9B`H:7-?:6YT*"1S<6PI('Q\($1".CII<T5R<F]R*"1S<6PI
M*2![("`@("`@+R\@4')E=FEO=7,@97)R;W(*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1S<6PI.PH@("`@("`@('T@96QS96EF("AI
M<U]A<G)A>2@D<W%L*2D@>R`@("`@("`@("`@("`@("`@("`@("`@("`O+R!!
M;')E861Y('1H92!R97-U;'0*("`@("`@("`@("`@<F5T=7)N("1S<6P["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^9V5T0V]L*"1S<6PI.R`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!,875N8V@@=&AI<R!Q=65R>0H@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!Q=65R>2!N965D960@=&\@
M9V5T('-O;64@8F%C:V5N9"!I;F9O"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92!7:&%T(&MI;F0@;V8@:6YF;R!Y;W4@=V%N="!T;R!R971R
M:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%1H92!344P@<75E
M<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]53E-5
M4%!/4E1%1"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7W)T<FEM
M07)R87E686QU97,H*0H*("`@("\J*@H@("`@("H@4FEG:'0@=')I;2!A;&P@
M<W1R:6YG<R!I;B!A;B!A<G)A>0H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`@)&%R<F%Y("!T:&4@87)R87D@=&\@8F4@=')I;6UE9"`H<&%S<V5D(&)Y
M(')E9F5R96YC92D*("`@("`J($!R971U<FX@=F]I9`H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R=')I;4%R<F%Y5F%L
M=65S*"8D87)R87DI('L*("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME
M>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*&ES7W-T<FEN9R@D=F%L
M=64I*2!["B`@("`@("`@("`@("`@("`D87)R87E;)&ME>5T@/2!R=')I;2@D
M=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(%]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T
M>2@I"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T(&%L;"!N=6QL('9A;'5E<R!I
M;B!A;B!A<G)A>2!T;R!E;7!T>2!S=')I;F=S"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("`D87)R87D@('1H92!A<G)A>2!T;R!B92!D92UN=6QL:69I
M960@*'!A<W-E9"!B>2!R969E<F5N8V4I"B`@("`@*B!`<F5T=7)N('9O:60*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)B1A<G)A>2D@>PH@("`@
M("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@("`@("!I9B`H:7-?;G5L;"@D=F%L=64I*2!["B`@("`@("`@("`@("`@
M("`D87)R87E;)&ME>5T@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O+R!]?7T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@
M*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@
M*B\*"C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-O;G-O;&4O
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#`V`#`Q-C<T-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O0V]N<V]L92]'971O<'0N<&AP````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C(U,#``,3`T,3<S-C,P,#8`,#(P-S$T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT
M.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@
M5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@
M1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@
M?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*
M+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!!=71H;W(Z($%N9')E:2!:;6EE=G-K:2`\86YD<F5I0'!H<"YN
M970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($=E=&]P="YP:'`L=B`Q
M+C(Q+C0N-R`R,#`S+S$R+S`U(#(Q.C4W.C`Q(&%N9')E:2!%>'`@)`H*<F5Q
M=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@0V]M;6%N9"UL:6YE(&]P
M=&EO;G,@<&%R<VEN9R!C;&%S<RX*("H*("H@0&%U=&AO<B!!;F1R96D@6FUI
M979S:VD@/&%N9')E:4!P:'`N;F5T/@H@*@H@*B\*8VQA<W,@0V]N<V]L95]'
M971O<'0@>PH@("`@+RHJ"B`@("`@*B!087)S97,@=&AE(&-O;6UA;F0M;&EN
M92!O<'1I;VYS+@H@("`@("H*("`@("`J(%1H92!F:7)S="!P87)A;65T97(@
M=&\@=&AI<R!F=6YC=&EO;B!S:&]U;&0@8F4@=&AE(&QI<W0@;V8@8V]M;6%N
M9"UL:6YE"B`@("`@*B!A<F=U;65N=',@=VET:&]U="!T:&4@;&5A9&EN9R!R
M969E<F5N8V4@=&\@=&AE(')U;FYI;F<@<')O9W)A;2X*("`@("`J"B`@("`@
M*B!4:&4@<V5C;VYD('!A<F%M971E<B!I<R!A('-T<FEN9R!O9B!A;&QO=V5D
M('-H;W)T(&]P=&EO;G,N($5A8V@@;V8@=&AE"B`@("`@*B!O<'1I;VX@;&5T
M=&5R<R!C86X@8F4@9F]L;&]W960@8GD@82!C;VQO;B`G.B<@=&\@<W!E8VEF
M>2!T:&%T('1H92!O<'1I;VX*("`@("`J(')E<75I<F5S(&%N(&%R9W5M96YT
M+"!O<B!A(&1O=6)L92!C;VQO;B`G.CHG('1O('-P96-I9GD@=&AA="!T:&4@
M;W!T:6]N"B`@("`@*B!T86ME<R!A;B!O<'1I;VYA;"!A<F=U;65N="X*("`@
M("`J"B`@("`@*B!4:&4@=&AI<F0@87)G=6UE;G0@:7,@86X@;W!T:6]N86P@
M87)R87D@;V8@86QL;W=E9"!L;VYG(&]P=&EO;G,N(%1H90H@("`@("H@;&5A
M9&EN9R`G+2TG('-H;W5L9"!N;W0@8F4@:6YC;'5D960@:6X@=&AE(&]P=&EO
M;B!N86UE+B!/<'1I;VYS('1H870*("`@("`J(')E<75I<F4@86X@87)G=6UE
M;G0@<VAO=6QD(&)E(&9O;&QO=V5D(&)Y("<])RP@86YD(&]P=&EO;G,@=&AA
M="!T86ME(&%N"B`@("`@*B!O<'1I;VX@87)G=6UE;G0@<VAO=6QD(&)E(&9O
M;&QO=V5D(&)Y("<]/2<N"B`@("`@*@H@("`@("H@5&AE(')E='5R;B!V86QU
M92!I<R!A;B!A<G)A>2!O9B!T=V\@96QE;65N=',Z('1H92!L:7-T(&]F('!A
M<G-E9`H@("`@("H@;W!T:6]N<R!A;F0@=&AE(&QI<W0@;V8@;F]N+6]P=&EO
M;B!C;VUM86YD+6QI;F4@87)G=6UE;G1S+B!%86-H(&5N=')Y(&EN"B`@("`@
M*B!T:&4@;&ES="!O9B!P87)S960@;W!T:6]N<R!I<R!A('!A:7(@;V8@96QE
M;65N=',@+2!T:&4@9FER<W0@;VYE"B`@("`@*B!S<&5C:69I97,@=&AE(&]P
M=&EO;BP@86YD('1H92!S96-O;F0@;VYE('-P96-I9FEE<R!T:&4@;W!T:6]N
M(&%R9W5M96YT+`H@("`@("H@:68@=&AE<F4@=V%S(&]N92X*("`@("`J"B`@
M("`@*B!,;VYG(&%N9"!S:&]R="!O<'1I;VYS(&-A;B!B92!M:7AE9"X*("`@
M("`J"B`@("`@*B!-;W-T(&]F('1H92!S96UA;G1I8W,@;V8@=&AI<R!F=6YC
M=&EO;B!A<F4@8F%S960@;VX@1TY5(&=E=&]P=%]L;VYG*"DN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("`D87)G<R`@("`@("`@("`@86X@87)R87D@
M;V8@8V]M;6%N9"UL:6YE(&%R9W5M96YT<PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D<VAO<G1?;W!T:6]N<R`@<W!E8VEF:65S('1H92!L:7-T(&]F(&%L;&]W
M960@<VAO<G0@;W!T:6]N<PH@("`@("H@0'!A<F%M(&%R<F%Y("`D;&]N9U]O
M<'1I;VYS("`@<W!E8VEF:65S('1H92!L:7-T(&]F(&%L;&]W960@;&]N9R!O
M<'1I;VYS"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!T=V\M96QE;65N
M="!A<G)A>2!C;VYT86EN:6YG('1H92!L:7-T(&]F('!A<G-E9"!O<'1I;VYS
M(&%N9`H@("`@("H@=&AE(&YO;BUO<'1I;VX@87)G=6UE;G1S"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=&]P=#(H)&%R9W,L("1S:&]R=%]O<'1I;VYS+"`D;&]N9U]O<'1I
M;VYS(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@0V]N<V]L95]'971O
M<'0Z.F1O1V5T;W!T*#(L("1A<F=S+"`D<VAO<G1?;W!T:6]N<RP@)&QO;F=?
M;W!T:6]N<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N
M(&5X<&5C=',@)&%R9W,@=&\@<W1A<G0@=VET:"!T:&4@<V-R:7!T(&YA;64@
M*%!/4TE8+7-T>6QE*2X*("`@("`J(%!R97-E<G9E9"!F;W(@8F%C:W=A<F1S
M(&-O;7!A=&EB:6QI='DN"B`@("`@*B!`<V5E(&=E=&]P=#(H*0H@("`@("HO
M("`@(`H@("`@9G5N8W1I;VX@9V5T;W!T*"1A<F=S+"`D<VAO<G1?;W!T:6]N
M<RP@)&QO;F=?;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N
M($-O;G-O;&5?1V5T;W!T.CID;T=E=&]P="@Q+"`D87)G<RP@)'-H;W)T7V]P
M=&EO;G,L("1L;VYG7V]P=&EO;G,I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5&AE(&%C='5A;"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@87)G=6UE;G0@<&%R
M<VEN9R!C;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D;T=E=&]P="@D=F5R
M<VEO;BP@)&%R9W,L("1S:&]R=%]O<'1I;VYS+"`D;&]N9U]O<'1I;VYS(#T@
M;G5L;"D*("`@('L*("`@("`@("`O+R!I;B!C87-E('EO=2!P87-S(&1I<F5C
M=&QY(')E86102%!!<F=V*"D@87,@=&AE(&9I<G-T(&%R9PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1A<F=S*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&%R9W,["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D87)G<RDI('L*
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*&%R<F%Y*"DL(&%R<F%Y*"DI.PH@
M("`@("`@('T*("`@("`@("`D;W!T<R`@("`@/2!A<G)A>2@I.PH@("`@("`@
M("1N;VY?;W!T<R`](&%R<F%Y*"D["@H@("`@("`@('-E='1Y<&4H)&%R9W,L
M("=A<G)A>2<I.PH*("`@("`@("!I9B`H)&QO;F=?;W!T:6]N<RD@>PH@("`@
M("`@("`@("!S;W)T*"1L;VYG7V]P=&EO;G,I.PH@("`@("`@('T*"B`@("`@
M("`@+RH*("`@("`@("`@*B!0<F5S97)V92!B86-K=V%R9',@8V]M<&%T:6)I
M;&ET>2!W:71H(&-A;&QE<G,@=&AA="!R96QI960@;VX*("`@("`@("`@*B!E
M<G)O;F5O=7,@4$]325@@9FEX+@H@("`@("`@("`J+PH@("`@("`@(&EF("@D
M=F5R<VEO;B`\(#(I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1A<F=S6S!=
M>S!]*2`F)B`D87)G<ULP77LP?2`A/2`G+2<I('L*("`@("`@("`@("`@("`@
M(&%R<F%Y7W-H:69T*"1A<F=S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5S970H)&%R9W,I.PH@("`@("`@('=H:6QE("AL:7-T*"1I
M+"`D87)G*2`](&5A8V@H)&%R9W,I*2!["@H@("`@("`@("`@("`O*B!4:&4@
M<W!E8VEA;"!E;&5M96YT("<M+2<@;65A;G,@97AP;&EC:70@96YD(&]F"B`@
M("`@("`@("`@("`@(&]P=&EO;G,N(%1R96%T('1H92!R97-T(&]F('1H92!A
M<F=U;65N=',@87,@;F]N+6]P=&EO;G,*("`@("`@("`@("`@("`@86YD(&5N
M9"!T:&4@;&]O<"X@*B\*("`@("`@("`@("`@:68@*"1A<F<@/3T@)RTM)RD@
M>PH@("`@("`@("`@("`@("`@)&YO;E]O<'1S(#T@87)R87E?;65R9V4H)&YO
M;E]O<'1S+"!A<G)A>5]S;&EC92@D87)G<RP@)&D@*R`Q*2D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"1A<F=[,'T@(3T@)RTG('Q\("AS=')L96XH)&%R9RD@/B`Q("8F("1A<F=[
M,7T@/3T@)RTG("8F("$D;&]N9U]O<'1I;VYS*2D@>PH@("`@("`@("`@("`@
M("`@)&YO;E]O<'1S(#T@87)R87E?;65R9V4H)&YO;E]O<'1S+"!A<G)A>5]S
M;&EC92@D87)G<RP@)&DI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!](&5L<V5I9B`H<W1R;&5N*"1A<F<I(#X@,2`F)B`D87)G>S%]
M(#T]("<M)RD@>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@0V]N<V]L95]'
M971O<'0Z.E]P87)S94QO;F=/<'1I;VXH<W5B<W1R*"1A<F<L(#(I+"`D;&]N
M9U]O<'1I;VYS+"`D;W!T<RP@)&%R9W,I.PH@("`@("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<F]R*2D*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&5R<F]R(#T@0V]N<V]L95]'971O<'0Z.E]P87)S95-H;W)T3W!T
M:6]N*'-U8G-T<B@D87)G+"`Q*2P@)'-H;W)T7V]P=&EO;G,L("1O<'1S+"`D
M87)G<RD["B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(I*0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D;W!T
M<RP@)&YO;E]O<'1S*3L*("`@('T*"B`@("`O*BH*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E4VAO
M<G1/<'1I;VXH)&%R9RP@)'-H;W)T7V]P=&EO;G,L("8D;W!T<RP@)B1A<F=S
M*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE;B@D87)G
M*3L@)&DK*RD@>PH@("`@("`@("`@("`D;W!T(#T@)&%R9WLD:7T["B`@("`@
M("`@("`@("1O<'1?87)G(#T@;G5L;#L*"B`@("`@("`@("`@("\J(%1R>2!T
M;R!F:6YD('1H92!S:&]R="!O<'1I;VX@:6X@=&AE('-P96-I9FEE<B!S=')I
M;F<N("HO"B`@("`@("`@("`@(&EF("@H)'-P96,@/2!S=')S='(H)'-H;W)T
M7V]P=&EO;G,L("1O<'0I*2`]/3T@9F%L<V4@?'P@)&%R9WLD:7T@/3T@)SHG
M*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z('5N<F5C;V=N:7IE9"!O<'1I
M;VX@+2T@)&]P="(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M<W1R;&5N*"1S<&5C*2`^(#$@)B8@)'-P96-[,7T@/3T@)SHG*2!["B`@("`@
M("`@("`@("`@("!I9B`H<W1R;&5N*"1S<&5C*2`^(#(@)B8@)'-P96-[,GT@
M/3T@)SHG*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1I("L@,2`\('-T
M<FQE;B@D87)G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!/<'1I
M;VX@=&%K97,@86X@;W!T:6]N86P@87)G=6UE;G0N(%5S92!T:&4@<F5M86EN
M9&5R(&]F"B`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!A<F<@<W1R
M:6YG(&EF('1H97)E(&ES(&%N>71H:6YG(&QE9G0N("HO"B`@("`@("`@("`@
M("`@("`@("`@("`@("1O<'1S6UT@/2!A<G)A>2@D;W!T+"!S=6)S='(H)&%R
M9RP@)&D@*R`Q*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@+RH@3W!T:6]N(')E<75I<F5S(&%N(&%R
M9W5M96YT+B!5<V4@=&AE(')E;6%I;F1E<B!O9B!T:&4@87)G"B`@("`@("`@
M("`@("`@("`@("`@("`@<W1R:6YG(&EF('1H97)E(&ES(&%N>71H:6YG(&QE
M9G0N("HO"B`@("`@("`@("`@("`@("`@("`@:68@*"1I("L@,2`\('-T<FQE
M;B@D87)G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T<UM=(#T@
M87)R87DH)&]P="P@('-U8G-T<B@D87)G+"`D:2`K(#$I*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E(&EF("AL:7-T*"P@)&]P=%]A<F<I(#T@96%C:"@D87)G<RDI"B`@("`@
M("`@("`@("`@("`@("`@("`@("\J($5L<V4@=7-E('1H92!N97AT(&%R9W5M
M96YT+B`J+SL*("`@("`@("`@("`@("`@("`@("!E;'-E"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYS;VQE
M7T=E=&]P=#H@;W!T:6]N(')E<75I<F5S(&%N(&%R9W5M96YT("TM("1O<'0B
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&]P='-;72`](&%R<F%Y*"1O<'0L("1O<'1?87)G*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94QO;F=/<'1I;VXH)&%R9RP@
M)&QO;F=?;W!T:6]N<RP@)B1O<'1S+"`F)&%R9W,I"B`@("!["B`@("`@("`@
M0&QI<W0H)&]P="P@)&]P=%]A<F<I(#T@97AP;&]D92@G/2<L("1A<F<I.PH@
M("`@("`@("1O<'1?;&5N(#T@<W1R;&5N*"1O<'0I.PH*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!C;W5N="@D;&]N9U]O<'1I;VYS*3L@)&DK*RD@>PH@
M("`@("`@("`@("`D;&]N9U]O<'0@(#T@)&QO;F=?;W!T:6]N<ULD:5T["B`@
M("`@("`@("`@("1O<'1?<W1A<G0@/2!S=6)S='(H)&QO;F=?;W!T+"`P+"`D
M;W!T7VQE;BD["@H@("`@("`@("`@("`O*B!/<'1I;VX@9&]E<VXG="!M871C
M:"X@1V\@;VX@=&\@=&AE(&YE>'0@;VYE+B`J+PH@("`@("`@("`@("!I9B`H
M)&]P=%]S=&%R="`A/2`D;W!T*0H@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"@H@("`@("`@("`@("`D;W!T7W)E<W0@(#T@<W5B<W1R*"1L;VYG7V]P="P@
M)&]P=%]L96XI.PH*("`@("`@("`@("`@+RH@0VAE8VL@=&AA="!T:&4@;W!T
M:6]N<R!U;FEQ=65L>2!M871C:&5S(&]N92!O9B!T:&4@86QL;W=E9`H@("`@
M("`@("`@("`@("!O<'1I;VYS+B`J+PH@("`@("`@("`@("!I9B`H)&]P=%]R
M97-T("$]("<G("8F("1O<'1[,'T@(3T@)STG("8F"B`@("`@("`@("`@("`@
M("`D:2`K(#$@/"!C;W5N="@D;&]N9U]O<'1I;VYS*2`F)@H@("`@("`@("`@
M("`@("`@)&]P="`]/2!S=6)S='(H)&QO;F=?;W!T:6]N<ULD:2LQ72P@,"P@
M)&]P=%]L96XI*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z(&]P=&EO;B`M+21O<'0@:7,@86UB
M:6=U;W5S(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AS=6)S
M='(H)&QO;F=?;W!T+"`M,2D@/3T@)STG*2!["B`@("`@("`@("`@("`@("!I
M9B`H<W5B<W1R*"1L;VYG7V]P="P@+3(I("$]("<]/2<I('L*("`@("`@("`@
M("`@("`@("`@("`O*B!,;VYG(&]P=&EO;B!R97%U:7)E<R!A;B!A<F=U;65N
M="X*("`@("`@("`@("`@("`@("`@("`@("!486ME('1H92!N97AT(&%R9W5M
M96YT(&EF(&]N92!W87-N)W0@<W!E8VEF:65D+B`J+SL*("`@("`@("`@("`@
M("`@("`@("!I9B`H(7-T<FQE;B@D;W!T7V%R9RD@)B8@(2AL:7-T*"P@)&]P
M=%]A<F<I(#T@96%C:"@D87)G<RDI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYS;VQE7T=E=&]P=#H@
M;W!T:6]N("TM)&]P="!R97%U:7)E<R!A;B!A<F=U;65N="(I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E(&EF("@D;W!T7V%R9RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(D-O;G-O;&5?1V5T;W!T.B!O<'1I;VX@+2TD
M;W!T(&1O97-N)W0@86QL;W<@86X@87)G=6UE;G0B*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&]P='-;72`](&%R<F%Y*"<M+2<@+B`D;W!T+"`D
M;W!T7V%R9RD["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYS;VQE7T=E=&]P=#H@
M=6YR96-O9VYI>F5D(&]P=&EO;B`M+21O<'0B*3L*("`@('T*"B`@("`O*BH*
M("`@("H@4V%F96QY(')E860@=&AE("1A<F=V(%!(4"!A<G)A>2!A8W)O<W,@
M9&EF9F5R96YT(%!(4"!C;VYF:6=U<F%T:6]N<RX*("`@("H@5VEL;"!T86ME
M(&-A<F4@;VX@<F5G:7-T97)?9VQO8F%L<R!A;F0@<F5G:7-T97)?87)G8U]A
M<F=V(&EN:2!D:7)E8W1I=F5S"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J($!R971U<FX@;6EX960@=&AE("1A<F=V(%!(4"!A<G)A>2!O<B!0
M14%2(&5R<F]R(&EF(&YO="!R96=I<W1E<F5D"B`@("`J+PH@("`@9G5N8W1I
M;VX@<F5A9%!(4$%R9W8H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D87)G=CL*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<F=V*2D@>PH@("`@("`@("`@("!I
M9B`H(4!I<U]A<G)A>2@D7U-%4E9%4ELG87)G=B==*2D@>PH@("`@("`@("`@
M("`@("`@:68@*"%`:7-?87)R87DH)$=,3T)!3%-;)TA45%!?4T525D527U9!
M4E,G75LG87)G=B==*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*")#;VYS;VQE7T=E=&]P=#H@0V]U;&0@;F]T(')E
M860@8VUD(&%R9W,@*')E9VES=&5R7V%R9V-?87)G=CU/9F8_*2(I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q3
M6R=(5%107U-%4E9%4E]605)3)UU;)V%R9W8G73L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@)%]315)615);)V%R9W8G73L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1A<F=V.PH@("`@?0H*?0H*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1A=&4O````````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8S,#`W`#`Q-C(R,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O1&%T92]#86QC+G!H<```````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`Q-#<V,#8`,3`T,3<S-C,P,#<`,#$W-C`W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M+R!4:&4@8V]N<W1A;G0@=&5L;&EN9R!U<R!W:&%T(&1A>2!S=&%R=',@=&AE
M('=E96LN($UO;F1A>2`H,2D@:7,@=&AE"B\O(&EN=&5R;F%T:6]N86P@<W1A
M;F1A<F0N(%)E9&5F:6YE('1H:7,@=&\@,"!I9B!Y;W4@=V%N="!W965K<R!T
M;PHO+R!B96=I;B!O;B!3=6YD87DN"FEF("@A9&5F:6YE9"@G1$%415]#04Q#
M7T)%1TE.7U=%14M$05DG*2D@>PH@("`@9&5F:6YE*"=$051%7T-!3$-?0D5'
M24Y?5T5%2T1!62<L(#$I.PI]"@HO*BH*("H@1&%T95]#86QC(&ES(&$@8V%L
M96YD87(@8VQA<W,@=7-E9"!T;R!C86QC=6QA=&4@86YD"B`J(&UA;FEP=6QA
M=&4@8V%L96YD87(@9&%T97,@86YD(')E=')I979E(&1A=&5S(&EN(&$@8V%L
M96YD87(*("H@9F]R;6%T+B!)="!D;V5S(&YO="!R96QY(&]N(#,R+6)I="!S
M>7-T96T@9&%T92!S=&%M<',L('-O"B`J('EO=2!C86X@9&ES<&QA>2!C86QE
M;F1A<G,@86YD(&-O;7!A<F4@9&%T97,@=&AA="!D871E"B`J('!R92`Q.3<P
M(&%N9"!P;W-T(#(P,S@N"B`J"B`J(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES"B`J(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A=`H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="X*("H@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O"B`J(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@
M82!N;W1E('1O"B`J(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!#;W!Y<FEG:'0@*&,I(#$Y
M.3DL(#(P,#(L(#(P,#,@:7-P:0H@*@H@*B!`86-C97-S('!U8FQI8PH@*@H@
M*B!`=F5R<VEO;B`Q+C(N-@H@*B!`875T:&]R($UO;G1E($]H<G0@/&UO;G1E
M0&ES<&DN;F5T/@H@*B\*"F-L87-S($1A=&5?0V%L8PI["B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@;&]C86P@9&%T92X@3D]413H@5&AI
M<R!F=6YC=&EO;@H@("`@("H@<F5T<FEE=F5S('1H92!L;V-A;"!D871E('5S
M:6YG('-T<F9T:6UE*"DL('=H:6-H(&UA>0H@("`@("H@;W(@;6%Y(&YO="!B
M92`S,BUB:70@<V%F92!O;B!Y;W5R('-Y<W1E;2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG('1H92!S=')F=&EM92@I(&9O<FUA="!T;R!R971U<FX@
M=&AE(&1A=&4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG('1H92!C=7)R96YT(&1A=&4@:6X@<W!E
M8VEF:65D(&9O<FUA=`H@("`@("HO"@H@("`@9G5N8W1I;VX@9&%T94YO=R@D
M9F]R;6%T/2<E625M)60G*0H@("`@>PH@("`@("`@(')E='5R;BAS=')F=&EM
M92@D9F]R;6%T+'1I;64H*2DI.PH*("`@('T@+R\@96YD(&9U;F,@9&%T94YO
M=PH*("`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!F;W(@=F%L:60@9&%T
M92P@9F%L<V4@9F]R(&EN=F%L:60@9&%T92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG('EE87(@:6X@9F]R;6%T($-#65D*("`@("`J($!P87)A;2!S
M=')I;F<@;6]N=&@@:6X@9F]R;6%T($U-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&1A>2!I;B!F;W)M870@1$0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E+V9A;'-E"B`@
M("`@*B\*"B`@("!F=6YC=&EO;B!I<U9A;&ED1&%T92@D9&%Y+"`D;6]N=&@L
M("1Y96%R*0H@("`@>PH@("`@("`@(&EF("@D>65A<B`\(#`@?'P@)'EE87(@
M/B`Y.3DY*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@:68@*"%C:&5C:V1A=&4H)&UO;G1H+"1D87DL)'EE87(I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!I<U9A;&ED1&%T90H*
M("`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!F;W(@82!L96%P('EE87(L
M(&5L<V4@9F%L<V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG('EE87(@
M:6X@9F]R;6%T($-#65D*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E+V9A;'-E"B`@("`@
M*B\*"B`@("!F=6YC=&EO;B!I<TQE87!996%R*"1Y96%R/2<G*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UQ$+R<L)'EE87(I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D>65A<B`\
M(#$P,#`I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1Y96%R(#P@,34X,BD@>PH@("`@("`@("`@("`O+R!P
M<F4@1W)E9V]R:6\@6$E)22`M(#$U.#(*("`@("`@("`@("`@<F5T=7)N("@D
M>65A<B`E(#0@/3T@,"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+R\@<&]S="!'<F5G;W)I;R!824E)("T@,34X,@H@("`@("`@("`@("!R971U
M<FX@*"`H*"1Y96%R("4@-"`]/2`P*2!A;F0@*"1Y96%R("4@,3`P("$](#`I
M*2!O<B`H)'EE87(@)2`T,#`@/3T@,"D@*3L*("`@("`@("!]"B`@("!]("\O
M(&5N9"!F=6YC(&ES3&5A<%EE87(*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@:68@9VEV96X@9&%T92!I<R!A(&9U='5R92!D871E(&9R;VT@;F]W+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@9&%Y(&EN(&9O<FUA="!$1`H@
M("`@("H@0'!A<F%M('-T<FEN9R!M;VYT:"!I;B!F;W)M870@34T*("`@("`J
M($!P87)A;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-960H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N('1R=64O9F%L<V4*("`@("`J+PH*("`@(&9U;F-T:6]N(&ES1G5T=7)E
M1&%T92@D9&%Y+"1M;VYT:"PD>65A<BD*("`@('L*("`@("`@("`D=&AI<U]Y
M96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@("1T:&ES
M7VUO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@("1T
M:&ES7V1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*"B`@("`@("`@
M:68@*"1Y96%R(#X@)'1H:7-?>65A<BD@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!](&5L<V5I9B`H)'EE87(@/3T@)'1H:7-?>65A<BD@
M>PH@("`@("`@("`@("!I9B`H)&UO;G1H(#X@)'1H:7-?;6]N=&@I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&UO;G1H(#T]("1T:&ES7VUO;G1H*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&1A>2`^("1T:&ES7V1A>2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]("\O(&5N9"!F
M=6YC(&ES1G5T=7)E1&%T90H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I
M9B!G:79E;B!D871E(&ES(&$@<&%S="!D871E(&9R;VT@;F]W+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@9&%Y(&EN(&9O<FUA="!$1`H@("`@("H@
M0'!A<F%M('-T<FEN9R!M;VYT:"!I;B!F;W)M870@34T*("`@("`J($!P87)A
M;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-960H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N('1R
M=64O9F%L<V4*("`@("`J+PH*("`@(&9U;F-T:6]N(&ES4&%S=$1A=&4H)&1A
M>2PD;6]N=&@L)'EE87(I"B`@("!["B`@("`@("`@)'1H:7-?>65A<B`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("`D=&AI<U]M;VYT:"`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("`D=&AI<U]D87D@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["@H@("`@("`@(&EF("@D>65A
M<B`\("1T:&ES7WEE87(I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?2!E;'-E:68@*"1Y96%R(#T]("1T:&ES7WEE87(I('L*("`@("`@
M("`@("`@:68@*"1M;VYT:"`\("1T:&ES7VUO;G1H*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"1M;VYT
M:"`]/2`D=&AI<U]M;VYT:"D@>PH@("`@("`@("`@("`@("`@:68@*"1D87D@
M/"`D=&AI<U]D87DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2`O+R!E;F0@9G5N8R!I<U!A
M<W1$871E"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1A>2!O9B!W965K(&9O
M<B!G:79E;B!D871E+"`P/5-U;F1A>0H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@9&%Y(&EN(&9O<FUA="!$1"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&1A>0H@("`@("H@0'!A<F%M('-T<FEN9R!M;VYT:"!I;B!F;W)M870@
M34TL(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A
M<F%M('-T<FEN9R!Y96%R(&EN(&9O<FUA="!#0UE9+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@)'=E96MD87E?;G5M8F5R"B`@
M("`@*B\*"B`@("!F=6YC=&EO;B!D87E/9E=E96LH)&1A>3TG)RPD;6]N=&@]
M)R<L)'EE87(])R<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@
M>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@
M("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@
M("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D;6]N=&@@/B`R*2!["B`@("`@("`@("`@("1M;VYT
M:"`M/2`R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M;VYT:"`K
M/2`Q,#L*("`@("`@("`@("`@)'EE87(M+3L*("`@("`@("!]"@H@("`@("`@
M("1D87D@/2`H(&9L;V]R*"@Q,R`J("1M;VYT:"`M(#$I("\@-2D@*PH@("`@
M("`@("`@("`D9&%Y("L@*"1Y96%R("4@,3`P*2`K"B`@("`@("`@("`@(&9L
M;V]R*"@D>65A<B`E(#$P,"D@+R`T*2`K"B`@("`@("`@("`@(&9L;V]R*"@D
M>65A<B`O(#$P,"D@+R`T*2`M(#(@*@H@("`@("`@("`@("!F;&]O<B@D>65A
M<B`O(#$P,"D@*R`W-RD["@H@("`@("`@("1W965K9&%Y7VYU;6)E<B`]("@H
M)&1A>2`M(#<@*B!F;&]O<B@D9&%Y("\@-RDI*3L*"B`@("`@("`@<F5T=7)N
M("1W965K9&%Y7VYU;6)E<CL*("`@('T@+R\@96YD(&9U;F,@9&%Y3V97965K
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=E96L@;V8@=&AE('EE87(L(&9I
M<G-T(%-U;F1A>2!I<R!F:7)S="!D87D@;V8@9FER<W0@=V5E:PH@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@9&%Y(&EN(&9O<FUA="!$1"P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M('-T<FEN9R!M
M;VYT:"!I;B!F;W)M870@34TL(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M
M;VYT:`H@("`@("H@0'!A<F%M('-T<FEN9R!Y96%R(&EN(&9O<FUA="!#0UE9
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R
M("1W965K7VYU;6)E<@H@("`@("HO"@H@("`@9G5N8W1I;VX@=V5E:T]F665A
M<B@D9&%Y/2<G+"1M;VYT:#TG)RPD>65A<CTG)RD*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#
M86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D
M9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W
M*"<E9"<I.PH@("`@("`@('T*("`@("`@("`D:7-O("`@(#T@1&%T95]#86QC
M.CIG<F5G;W)I86Y4;TE33R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@
M("`D<&%R=',@(#T@97AP;&]D92@G+2<L)&ES;RD["B`@("`@("`@)'=E96M?
M;G5M8F5R(#T@:6YT=F%L*"1P87)T<ULQ72D["B`@("`@("`@<F5T=7)N("1W
M965K7VYU;6)E<CL*("`@('T@+R\@96YD(&9U;F,@=V5E:T]F665A<@H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!N=6UB97(@;V8@9&%Y<R!S:6YC92`S,2!$
M96-E;6)E<B!O9B!Y96%R(&)E9F]R92!G:79E;B!D871E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@9&%Y(&EN(&9O<FUA="!$1"P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M('-T<FEN9R!M;VYT
M:"!I;B!F;W)M870@34TL(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT
M:`H@("`@("H@0'!A<F%M('-T<FEN9R!Y96%R(&EN(&9O<FUA="!#0UE9+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@)&IU;&EA
M;@H@("`@("HO"@H@("`@9G5N8W1I;VX@:G5L:6%N1&%T92@D9&%Y/2<G+"1M
M;VYT:#TG)RPD>65A<CTG)RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE
M87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W
M*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@
M>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@
M("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@
M("`@('T*"B`@("`@("`@)&1A>7,@/2!A<G)A>2@P+#,Q+#4Y+#DP+#$R,"PQ
M-3$L,3@Q+#(Q,BPR-#,L,C<S+#,P-"PS,S0I.PH*("`@("`@("`D:G5L:6%N
M(#T@*"1D87ES6R1M;VYT:"`M(#%=("L@)&1A>2D["@H@("`@("`@(&EF("@D
M;6]N=&@@/B`R("8F($1A=&5?0V%L8SHZ:7-,96%P665A<B@D>65A<BDI('L*
M("`@("`@("`@("`@)&IU;&EA;BLK.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N*"1J=6QI86XI.PH@("`@?2`O+R!E;F0@9G5N8R!J=6QI86Y$871E"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('%U87)T97(@;V8@=&AE('EE87(@9F]R
M(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(&1A>2!I
M;B!F;W)M870@1$0L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@
M("`J($!P87)A;2!S=')I;F<@;6]N=&@@:6X@9F]R;6%T($U-+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!S=')I;F<@
M>65A<B!I;B!F;W)M870@0T-962P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M('EE87(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@
M("`J($!R971U<FX@:6YT("1Y96%R7W%U87)T97(*("`@("`J+PH*("`@(&9U
M;F-T:6]N('%U87)T97)/9EEE87(H)&1A>3TG)RPD;6]N=&@])R<L)'EE87(]
M)R<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@
M("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@
M)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*
M("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"@H@("`@("`@
M("1Y96%R7W%U87)T97(@/2`H:6YT=F%L*"@D;6]N=&@@+2`Q*2`O(#,@*R`Q
M*2D["@H@("`@("`@(')E='5R;B`D>65A<E]Q=6%R=&5R.PH@("`@?2`O+R!E
M;F0@9G5N8R!Q=6%R=&5R3V9996%R"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&1A=&4@;V8@8F5G:6X@;V8@;F5X="!M;VYT:"!O9B!G:79E;B!D871E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@9&%Y(&EN(&9O<FUA="!$1"P@
M9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M('-T
M<FEN9R!M;VYT:"!I;B!F;W)M870@34TL(&1E9F%U;'0@:7,@8W5R<F5N="!L
M;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M('-T<FEN9R!Y96%R(&EN(&9O<FUA
M="!#0UE9+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@
M0'!A<F%M('-T<FEN9R!F;W)M870@9F]R(')E='5R;F5D(&1A=&4*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG(&1A=&4@:6X@9VEV96X@9F]R;6%T"B`@("`@*B\*"B`@("!F=6YC
M=&EO;B!B96=I;D]F3F5X=$UO;G1H*"1D87D])R<L)&UO;G1H/2<G+"1Y96%R
M/2<G+"1F;W)M870])R59)6TE9"<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT
M:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W
M*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*
M("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D;6]N=&@@/"`Q,BD@>PH@("`@("`@
M("`@("`D;6]N=&@K*SL*("`@("`@("`@("`@)&1A>3TQ.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1Y96%R*RL["B`@("`@("`@("`@("1M;VYT
M:#TQ.PH@("`@("`@("`@("`D9&%Y/3$["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*"1D87DL)&UO;G1H+"1Y96%R
M+"1F;W)M870I.PH@("`@?2`O+R!E;F0@9G5N8R!B96=I;D]F3F5X=$UO;G1H
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1A=&4@;V8@=&AE(&QA<W0@9&%Y
M(&]F(&YE>'0@;6]N=&@@;V8@9VEV96X@9&%T92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&1A>2!I;B!F;W)M870@1$0L(&1E9F%U;'0@:7,@8W5R
M<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A;2!S=')I;F<@;6]N=&@@:6X@
M9F]R;6%T($U-+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@
M("`J($!P87)A;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-962P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@
M9F]R;6%T(&9O<B!R971U<FYE9"!D871E"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D871E(&EN
M(&=I=F5N(&9O<FUA=`H@("`@("HO"@H@("`@9G5N8W1I;VX@96YD3V9.97AT
M36]N=&@H)&1A>3TG)RPD;6]N=&@])R<L)'EE87(])R<L)&9O<FUA=#TG)5DE
M;25D)RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@
M("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@
M("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y
M(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1M;VYT:"`\(#$R*2!["B`@("`@("`@("`@("1M;VYT:"LK.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Y96%R*RL["B`@("`@("`@
M("`@("1M;VYT:#TQ.PH@("`@("`@('T*"B`@("`@("`@)&1A>2`]($1A=&5?
M0V%L8SHZ9&%Y<TEN36]N=&@H)&UO;G1H+"1Y96%R*3L*"B`@("`@("`@<F5T
M=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA="@D9&%Y+"1M;VYT:"PD>65A<BPD
M9F]R;6%T*3L*("`@('T@+R\@96YD(&9U;F,@96YD3V9.97AT36]N=&@*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@9FER<W0@9&%Y(&]F
M('!R979I;W5S(&UO;G1H(&]F(&=I=F5N(&1A=&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R!D87D@:6X@9F]R;6%T($1$+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@<W1R:6YG(&UO;G1H(&EN
M(&9O<FUA="!-32P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@
M("`@*B!`<&%R86T@<W1R:6YG('EE87(@:6X@9F]R;6%T($-#65DL(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&9O<FUA="!F;W(@<F5T=7)N960@9&%T90H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92!I
M;B!G:79E;B!F;W)M870*("`@("`J+PH*("`@(&9U;F-T:6]N(&)E9VEN3V90
M<F5V36]N=&@H)&1A>3TG)RPD;6]N=&@])R<L)'EE87(])R<L)&9O<FUA=#TG
M)5DE;25D)RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@
M("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@
M("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@
M("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D
M9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1M;VYT:"`^(#$I('L*("`@("`@("`@("`@)&UO;G1H+2T[
M"B`@("`@("`@("`@("1D87D],3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D>65A<BTM.PH@("`@("`@("`@("`D;6]N=&@],3(["B`@("`@("`@
M("`@("1D87D],3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!$871E7T-A
M;&,Z.F1A=&5&;W)M870H)&1A>2PD;6]N=&@L)'EE87(L)&9O<FUA="D["B`@
M("!]("\O(&5N9"!F=6YC(&)E9VEN3V90<F5V36]N=&@*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@9&%T92!O9B!T:&4@;&%S="!D87D@;V8@<')E=FEO=7,@
M;6]N=&@@9F]R(&=I=F5N(&1A=&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R!D87D@:6X@9F]R;6%T($1$+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C
M86P@9&%Y"B`@("`@*B!`<&%R86T@<W1R:6YG(&UO;G1H(&EN(&9O<FUA="!-
M32P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R
M86T@<W1R:6YG('EE87(@:6X@9F]R;6%T($-#65DL(&1E9F%U;'0@:7,@8W5R
M<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG(&9O<FUA="!F
M;W(@<F5T=7)N960@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92!I;B!G:79E;B!F
M;W)M870*("`@("`J+PH*("`@(&9U;F-T:6]N(&5N9$]F4')E=DUO;G1H*"1D
M87D])R<L)&UO;G1H/2<G+"1Y96%R/2<G+"1F;W)M870])R59)6TE9"<I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D
M>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H
M(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M;6]N=&@@/B`Q*2!["B`@("`@("`@("`@("1M;VYT:"TM.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1Y96%R+2T["B`@("`@("`@("`@("1M;VYT
M:#TQ,CL*("`@("`@("!]"@H@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A
M>7-);DUO;G1H*"1M;VYT:"PD>65A<BD["@H@("`@("`@(')E='5R;B!$871E
M7T-A;&,Z.F1A=&5&;W)M870H)&1A>2PD;6]N=&@L)'EE87(L)&9O<FUA="D[
M"B`@("!]("\O(&5N9"!F=6YC(&5N9$]F4')E=DUO;G1H"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&1A=&4@;V8@=&AE(&YE>'0@=V5E:V1A>2!O9B!G:79E
M;B!D871E+`H@("`@("H@<VMI<'!I;F<@9G)O;2!&<FED87D@=&\@36]N9&%Y
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@9&%Y(&EN(&9O<FUA="!$
M1"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M
M('-T<FEN9R!M;VYT:"!I;B!F;W)M870@34TL(&1E9F%U;'0@:7,@8W5R<F5N
M="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M('-T<FEN9R!Y96%R(&EN(&9O
M<FUA="!#0UE9+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@
M("H@0'!A<F%M('-T<FEN9R!F;W)M870@9F]R(')E='5R;F5D(&1A=&4*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG(&1A=&4@:6X@9VEV96X@9F]R;6%T"B`@("`@*B\*"B`@("!F
M=6YC=&EO;B!N97AT5V5E:V1A>2@D9&%Y/2<G+"1M;VYT:#TG)RPD>65A<CTG
M)RPD9F]R;6%T/2<E625M)60G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I
M*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G
M)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@
M("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@
M("`@("`@?0H*("`@("`@("`D9&%Y<R`]($1A=&5?0V%L8SHZ9&%T951O1&%Y
M<R@D9&%Y+"1M;VYT:"PD>65A<BD["@H@("`@("`@(&EF("A$871E7T-A;&,Z
M.F1A>4]F5V5E:R@D9&%Y+"1M;VYT:"PD>65A<BD@/3T@-2D@>PH@("`@("`@
M("`@("`D9&%Y<R`K/2`S.PH@("`@("`@('T@96QS96EF("A$871E7T-A;&,Z
M.F1A>4]F5V5E:R@D9&%Y+"1M;VYT:"PD>65A<BD@/3T@-BD@>PH@("`@("`@
M("`@("`D9&%Y<R`K/2`R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1D87ES("L](#$["B`@("`@("`@?0H*("`@("`@("!R971U<FXH1&%T95]#
M86QC.CID87ES5&]$871E*"1D87ES+"1F;W)M870I*3L*("`@('T@+R\@96YD
M(&9U;F,@;F5X=%=E96MD87D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T
M92!O9B!T:&4@<')E=FEO=7,@=V5E:V1A>2P*("`@("`J('-K:7!P:6YG(&9R
M;VT@36]N9&%Y('1O($9R:61A>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&1A>2!I;B!F;W)M870@1$0L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A
M;"!D87D*("`@("`J($!P87)A;2!S=')I;F<@;6]N=&@@:6X@9F]R;6%T($U-
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A
M;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-962P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@9F]R;6%T(&9O
M<B!R971U<FYE9"!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D871E(&EN(&=I=F5N(&9O
M<FUA=`H@("`@("HO"@H@("`@9G5N8W1I;VX@<')E=E=E96MD87DH)&1A>3TG
M)RPD;6]N=&@])R<L)'EE87(])R<L)&9O<FUA=#TG)5DE;25D)RD*("`@('L*
M("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R
M(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC
M.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@("`@)&1A>7,@/2!$
M871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2PD;6]N=&@L)'EE87(I.PH*("`@
M("`@("!I9B`H1&%T95]#86QC.CID87E/9E=E96LH)&1A>2PD;6]N=&@L)'EE
M87(I(#T](#$I('L*("`@("`@("`@("`@)&1A>7,@+3T@,SL*("`@("`@("!]
M(&5L<V5I9B`H1&%T95]#86QC.CID87E/9E=E96LH)&1A>2PD;6]N=&@L)'EE
M87(I(#T](#`I('L*("`@("`@("`@("`@)&1A>7,@+3T@,CL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9&%Y<R`M/2`Q.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N*$1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9&%Y<RPD9F]R
M;6%T*2D["B`@("!]("\O(&5N9"!F=6YC('!R9797965K9&%Y"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&1A=&4@;V8@=&AE(&YE>'0@<W!E8VEF:6,@9&%Y
M(&]F('1H92!W965K"B`@("`@*B!F<F]M('1H92!G:79E;B!D871E+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G0@9&%Y(&]F('=E96LL(#`]4W5N9&%Y"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&1A>2!I;B!F;W)M870@1$0L(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A;2!S=')I;F<@;6]N
M=&@@:6X@9F]R;6%T($U-+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N
M=&@*("`@("`J($!P87)A;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-962P@
M9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!B
M;V]L96%N(&]N3W)!9G1E<B!I9B!T<G5E(&%N9"!D87ES(&%R92!S86UE+"!R
M971U<FYS(&-U<G)E;G0@9&%Y"B`@("`@*B!`<&%R86T@<W1R:6YG(&9O<FUA
M="!F;W(@<F5T=7)N960@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92!I;B!G:79E
M;B!F;W)M870*("`@("`J+PH*("`@(&9U;F-T:6]N(&YE>'1$87E/9E=E96LH
M)&1O=RPD9&%Y/2<G+"1M;VYT:#TG)RPD>65A<CTG)RPD9F]R;6%T/2<E625M
M)60G+"1O;D]R069T97(]9F%L<V4I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT
M:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W
M*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*
M("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*
M("`@("`@("!]"@H@("`@("`@("1D87ES(#T@1&%T95]#86QC.CID871E5&]$
M87ES*"1D87DL)&UO;G1H+"1Y96%R*3L*("`@("`@("`D8W5R<E]W965K9&%Y
M(#T@1&%T95]#86QC.CID87E/9E=E96LH)&1A>2PD;6]N=&@L)'EE87(I.PH*
M("`@("`@("!I9B`H)&-U<G)?=V5E:V1A>2`]/2`D9&]W*2!["B`@("`@("`@
M("`@(&EF("@A)&]N3W)!9G1E<BD@>PH@("`@("`@("`@("`@("`@)&1A>7,@
M*ST@-SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!E;'-E:68@
M*"1C=7)R7W=E96MD87D@/B`D9&]W*2!["B`@("`@("`@("`@("1D87ES("L]
M(#<@+2`H("1C=7)R7W=E96MD87D@+2`D9&]W("D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&1A>7,@*ST@)&1O=R`M("1C=7)R7W=E96MD87D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FXH1&%T95]#86QC.CID87ES5&]$
M871E*"1D87ES+"1F;W)M870I*3L*("`@('T@+R\@96YD(&9U;F,@;F5X=$1A
M>4]F5V5E:PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F('1H92!P
M<F5V:6]U<R!S<&5C:69I8R!D87D@;V8@=&AE('=E96L*("`@("`J(&9R;VT@
M=&AE(&=I=F5N(&1A=&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="!D87D@
M;V8@=V5E:RP@,#U3=6YD87D*("`@("`J($!P87)A;2!S=')I;F<@9&%Y(&EN
M(&9O<FUA="!$1"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@
M("H@0'!A<F%M('-T<FEN9R!M;VYT:"!I;B!F;W)M870@34TL(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M('-T<FEN9R!Y
M96%R(&EN(&9O<FUA="!#0UE9+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@
M>65A<@H@("`@("H@0'!A<F%M(&)O;VQE86X@;VY/<D)E9F]R92!I9B!T<G5E
M(&%N9"!D87ES(&%R92!S86UE+"!R971U<FYS(&-U<G)E;G0@9&%Y"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&9O<FUA="!F;W(@<F5T=7)N960@9&%T90H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@9&%T92!I;B!G:79E;B!F;W)M870*("`@("`J+PH*("`@(&9U
M;F-T:6]N('!R979$87E/9E=E96LH)&1O=RPD9&%Y/2<G+"1M;VYT:#TG)RPD
M>65A<CTG)RPD9F]R;6%T/2<E625M)60G+"1O;D]R0F5F;W)E/69A;'-E*0H@
M("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@
M)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@
M("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT
M:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H*("`@("`@("`D9&%Y
M<R`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+"1M;VYT:"PD>65A<BD[
M"B`@("`@("`@)&-U<G)?=V5E:V1A>2`]($1A=&5?0V%L8SHZ9&%Y3V97965K
M*"1D87DL)&UO;G1H+"1Y96%R*3L*"B`@("`@("`@:68@*"1C=7)R7W=E96MD
M87D@/3T@)&1O=RD@>PH@("`@("`@("`@("!I9B`H(21O;D]R0F5F;W)E*2![
M"B`@("`@("`@("`@("`@("`D9&%Y<R`M/2`W.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&5L<V5I9B`H)&-U<G)?=V5E:V1A>2`\("1D;W<I
M('L*("`@("`@("`@("`@)&1A>7,@+3T@-R`M("@@)&1O=R`M("1C=7)R7W=E
M96MD87D@*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%Y<R`M
M/2`D8W5R<E]W965K9&%Y("T@)&1O=SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;BA$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&1A>7,L)&9O<FUA="DI.PH@
M("`@?2`O+R!E;F0@9G5N8R!P<F5V1&%Y3V97965K"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&1A=&4@;V8@=&AE(&YE>'0@<W!E8VEF:6,@9&%Y(&]F('1H
M92!W965K"B`@("`@*B!O;B!O<B!A9G1E<B!T:&4@9VEV96X@9&%T92X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT(&1A>2!O9B!W965K+"`P/5-U;F1A>0H@
M("`@("H@0'!A<F%M('-T<FEN9R!D87D@:6X@9F]R;6%T($1$+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@<W1R:6YG(&UO
M;G1H(&EN(&9O<FUA="!-32P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO
M;G1H"B`@("`@*B!`<&%R86T@<W1R:6YG('EE87(@:6X@9F]R;6%T($-#65DL
M(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&9O<FUA="!F;W(@<F5T=7)N960@9&%T90H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M9&%T92!I;B!G:79E;B!F;W)M870*("`@("`J+PH*("`@(&9U;F-T:6]N(&YE
M>'1$87E/9E=E96M/;D]R069T97(H)&1O=RPD9&%Y/2<G+"1M;VYT:#TG)RPD
M>65A<CTG)RPD9F]R;6%T/2<E625M)60G*0H@("`@>PH@("`@("`@(')E='5R
M;BA$871E7T-A;&,Z.FYE>'1$87E/9E=E96LH)&1O=RPD9&%Y+"1M;VYT:"PD
M>65A<BPD9F]R;6%T+'1R=64I*3L*("`@('T@+R\@96YD(&9U;F,@;F5X=$1A
M>4]F5V5E:T]N3W)!9G1E<@H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E
M(&]F('1H92!P<F5V:6]U<R!S<&5C:69I8R!D87D@;V8@=&AE('=E96L*("`@
M("`J(&]N(&]R(&)E9F]R92!T:&4@9VEV96X@9&%T92X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT(&1A>2!O9B!W965K+"`P/5-U;F1A>0H@("`@("H@0'!A
M<F%M('-T<FEN9R!D87D@:6X@9F]R;6%T($1$+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@<W1R:6YG(&UO;G1H(&EN(&9O
M<FUA="!-32P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@
M*B!`<&%R86T@<W1R:6YG('EE87(@:6X@9F]R;6%T($-#65DL(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG(&9O
M<FUA="!F;W(@<F5T=7)N960@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92!I;B!G
M:79E;B!F;W)M870*("`@("`J+PH*("`@(&9U;F-T:6]N('!R979$87E/9E=E
M96M/;D]R0F5F;W)E*"1D;W<L)&1A>3TG)RPD;6]N=&@])R<L)'EE87(])R<L
M)&9O<FUA=#TG)5DE;25D)RD*("`@('L*("`@("`@("!R971U<FXH1&%T95]#
M86QC.CIP<F5V1&%Y3V97965K*"1D;W<L)&1A>2PD;6]N=&@L)'EE87(L)&9O
M<FUA="QT<G5E*2D["B`@("!]("\O(&5N9"!F=6YC('!R979$87E/9E=E96M/
M;D]R069T97(*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!D87D@
M869T97(@9VEV96X@9&%T92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&1A>2!I;B!F;W)M870@1$0L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D
M87D*("`@("`J($!P87)A;2!S=')I;F<@;6]N=&@@:6X@9F]R;6%T($U-+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!S
M=')I;F<@>65A<B!I;B!F;W)M870@0T-962P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@9F]R;6%T(&9O<B!R
M971U<FYE9"!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D871E(&EN(&=I=F5N(&9O<FUA
M=`H@("`@("HO"@H@("`@9G5N8W1I;VX@;F5X=$1A>2@D9&%Y/2<G+"1M;VYT
M:#TG)RPD>65A<CTG)RPD9F]R;6%T/2<E625M)60G*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5D)RD["B`@("`@("`@?0H*("`@("`@("`D9&%Y<R`]($1A=&5?0V%L
M8SHZ9&%T951O1&%Y<R@D9&%Y+"1M;VYT:"PD>65A<BD["@H@("`@("`@(')E
M='5R;BA$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&1A>7,@*R`Q+"1F;W)M870I
M*3L*("`@('T@+R\@96YD(&9U;F,@;F5X=$1A>0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!D871E(&]F(&1A>2!B969O<F4@9VEV96X@9&%T92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&1A>2!I;B!F;W)M870@1$0L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A;2!S=')I;F<@
M;6]N=&@@:6X@9F]R;6%T($U-+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@
M;6]N=&@*("`@("`J($!P87)A;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-9
M62P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A
M;2!S=')I;F<@9F]R;6%T(&9O<B!R971U<FYE9"!D871E"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R!D871E(&EN(&=I=F5N(&9O<FUA=`H@("`@("HO"@H@("`@9G5N8W1I;VX@
M<')E=D1A>2@D9&%Y/2<G+"1M;VYT:#TG)RPD>65A<CTG)RPD9F]R;6%T/2<E
M625M)60G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@
M("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@
M("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@
M("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D
M87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H*("`@
M("`@("`D9&%Y<R`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+"1M;VYT
M:"PD>65A<BD["@H@("`@("`@(')E='5R;BA$871E7T-A;&,Z.F1A>7-4;T1A
M=&4H)&1A>7,@+2`Q+"1F;W)M870I*3L*("`@('T@+R\@96YD(&9U;F,@<')E
M=D1A>0H*("`@("\J*@H@("`@("H@4V5T<R!C96YT=7)Y(&9O<B`R(&1I9VET
M('EE87(N"B`@("`@*B`U,2TY.2!I<R`Q.2P@96QS92`R,`H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@,B!D:6=I="!Y96%R"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`T
M(&1I9VET('EE87(*("`@("`J+PH*("`@(&9U;F-T:6]N(&1E9F%U;'1#96YT
M=7)Y*"1Y96%R*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)'EE87(I(#T]
M(#$I('L*("`@("`@("`@("`@)'EE87(@/2`B,"1Y96%R(CL*("`@("`@("!]
M"B`@("`@("`@:68@*"1Y96%R(#X@-3`I('L*("`@("`@("`@("`@<F5T=7)N
M*"`B,3DD>65A<B(@*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FXH("(R,"1Y96%R(B`I.PH@("`@("`@('T*("`@('T@+R\@96YD(&9U
M;F,@9&5F875L=$-E;G1U<GD*"B`@("`O*BH*("`@("`J(%)E='5R;G,@;G5M
M8F5R(&]F(&1A>7,@8F5T=V5E;B!T=V\@9VEV96X@9&%T97,N"B`@("`@*@H@
M("`@*B!`<&%R86T@<W1R:6YG("1D87DQ("`@9&%Y(&EN(&9O<FUA="!$1`H@
M("`@*B!`<&%R86T@<W1R:6YG("1M;VYT:#$@;6]N=&@@:6X@9F]R;6%T($U-
M"B`@("`J($!P87)A;2!S=')I;F<@)'EE87(Q("!Y96%R(&EN(&9O<FUA="!#
M0UE9"B`@("`J($!P87)A;2!S=')I;F<@)&1A>3(@("!D87D@:6X@9F]R;6%T
M($1$"B`@("`J($!P87)A;2!S=')I;F<@)&UO;G1H,B!M;VYT:"!I;B!F;W)M
M870@34T*("`@("H@0'!A<F%M('-T<FEN9R`D>65A<C(@('EE87(@:6X@9F]R
M;6%T($-#65D*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*
M("`@("`J($!R971U<FX@:6YT(&%B<V]L=71E(&YU;6)E<B!O9B!D87ES(&)E
M='=E96X@9&%T97,L"B`@("`@*B`@("`@("TQ(&EF('1H97)E(&ES(&%N(&5R
M<F]R+@H@("`@("HO"@H@("`@9G5N8W1I;VX@9&%T941I9F8H)&1A>3$L)&UO
M;G1H,2PD>65A<C$L)&1A>3(L)&UO;G1H,BPD>65A<C(I"B`@("!["B`@("`@
M("`@:68@*"%$871E7T-A;&,Z.FES5F%L:61$871E*"1D87DQ+"1M;VYT:#$L
M)'EE87(Q*2D@>PH@("`@("`@("`@("!R971U<FX@+3$["B`@("`@("`@?0H@
M("`@("`@(&EF("@A1&%T95]#86QC.CII<U9A;&ED1&%T92@D9&%Y,BPD;6]N
M=&@R+"1Y96%R,BDI('L*("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N*&%B<R@H1&%T95]#86QC.CID871E5&]$87ES
M*"1D87DQ+"1M;VYT:#$L)'EE87(Q*2D*("`@("`@("`@("`@("`@("`@("`M
M("A$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>3(L)&UO;G1H,BPD>65A<C(I
M*2DI.PH@("`@?2`O+R!E;F0@9G5N8R!D871E1&EF9@H*("`@("\J*@H@("`@
M*B!#;VUP87)E<R!T=V\@9&%T97,*("`@("H*("`@("H@0'!A<F%M('-T<FEN
M9R`D9&%Y,2`@(&1A>2!I;B!F;W)M870@1$0*("`@("H@0'!A<F%M('-T<FEN
M9R`D;6]N=&@Q(&UO;G1H(&EN(&9O<FUA="!-30H@("`@*B!`<&%R86T@<W1R
M:6YG("1Y96%R,2`@>65A<B!I;B!F;W)M870@0T-960H@("`@*B!`<&%R86T@
M<W1R:6YG("1D87DR("`@9&%Y(&EN(&9O<FUA="!$1`H@("`@*B!`<&%R86T@
M<W1R:6YG("1M;VYT:#(@;6]N=&@@:6X@9F]R;6%T($U-"B`@("`J($!P87)A
M;2!S=')I;F<@)'EE87(R("!Y96%R(&EN(&9O<FUA="!#0UE9"B`@("`J"B`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@:6YT(#`@;VX@97%U
M86QI='DL(#$@:68@9&%T92`Q(&ES(&=R96%T97(L("TQ(&EF('-M86QL97(*
M("`@("HO"B`@("!F=6YC=&EO;B!C;VUP87)E1&%T97,H)&1A>3$L)&UO;G1H
M,2PD>65A<C$L)&1A>3(L)&UO;G1H,BPD>65A<C(I"B`@("!["B`@("`@("`@
M)&YD87ES,2`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y,2P@)&UO;G1H
M,2P@)'EE87(Q*3L*("`@("`@("`D;F1A>7,R(#T@1&%T95]#86QC.CID871E
M5&]$87ES*"1D87DR+"`D;6]N=&@R+"`D>65A<C(I.PH@("`@("`@(&EF("@D
M;F1A>7,Q(#T]("1N9&%Y<S(I('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`H)&YD87ES,2`^("1N9&%Y<S(I(#\@
M,2`Z("TQ.PH@("`@?2`O+R!E;F0@9G5N8R!C;VUP87)E1&%T97,*"B`@("`O
M*BH*("`@("`J($9I;F0@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!G:79E
M;B!M;VYT:"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(&UO;G1H(&EN
M(&9O<FUA="!-32P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@
M("`@*B!`<&%R86T@<W1R:6YG('EE87(@:6X@9F]R;6%T($-#65DL(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!N=6UB97(@;V8@
M9&%Y<PH@("`@("HO"@H@("`@9G5N8W1I;VX@9&%Y<TEN36]N=&@H)&UO;G1H
M/2<G+"1Y96%R/2<G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI
M('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@
M("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D>65A<B`]/2`Q-3@R("8F("1M;VYT
M:"`]/2`Q,"D@>PH@("`@("`@("`@("!R971U<FX@,C$[("`O+R!/8W1O8F5R
M(#$U.#(@;VYL>2!H860@,7-T+31T:"!A;F0@,35T:"TS,7-T"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&UO;G1H(#T](#(I('L*("`@("`@("`@("`@:68@
M*$1A=&5?0V%L8SHZ:7-,96%P665A<B@D>65A<BDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`R.3L*("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!R971U<FX@,C@["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V5I9B`H)&UO;G1H(#T](#0@;W(@)&UO;G1H(#T](#8@;W(@)&UO;G1H(#T]
M(#D@;W(@)&UO;G1H(#T](#$Q*2!["B`@("`@("`@("`@(')E='5R;B`S,#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,S$["B`@("`@
M("`@?0H@("`@?2`O+R!E;F0@9G5N8R!D87ES26Y-;VYT:`H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(')O=W,@;VX@82!C86QE;F1A
M<B!M;VYT:"X@57-E9G5L(&9O<@H@("`@("H@9&5T97)M:6YI;F<@=&AE(&YU
M;6)E<B!O9B!R;W=S('=H96X@9&ES<&QA>6EN9R!A('1Y<&EC86P*("`@("`J
M(&UO;G1H(&-A;&5N9&%R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M;6]N=&@@:6X@9F]R;6%T($U-+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@
M;6]N=&@*("`@("`J($!P87)A;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-9
M62P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U<FX@:6YT(&YU
M;6)E<B!O9B!W965K<PH@("`@("HO"@H@("`@9G5N8W1I;VX@=V5E:W-);DUO
M;G1H*"1M;VYT:#TG)RPD>65A<CTG)RD*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID
M871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO
M;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@("1&1$]-(#T@1&%T95]#86QC
M.CIF:7)S=$]F36]N=&A7965K9&%Y*"1M;VYT:"P@)'EE87(I.PH@("`@("`@
M(&EF("@D1D1/32`^($1!5$5?0T%,0U]"14=)3E]7145+1$%9*2!["B`@("`@
M("`@("`@("1F:7)S=%]W965K7V1A>7,@/2`W("T@)$9$3TT@*R!$051%7T-!
M3$-?0D5'24Y?5T5%2T1!63L*("`@("`@("`@("`@)'=E96MS(#T@,3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FER<W1?=V5E:U]D87ES(#T@
M1$%415]#04Q#7T)%1TE.7U=%14M$05D@+2`D1D1/33L*("`@("`@("`@("`@
M)'=E96MS(#T@,#L*("`@("`@("!]"B`@("`@("`@)&9I<G-T7W=E96M?9&%Y
M<R`E/2`W.PH@("`@("`@(')E='5R;B`H8V5I;"@H1&%T95]#86QC.CID87ES
M26Y-;VYT:"@D;6]N=&@L("1Y96%R*2`M("1F:7)S=%]W965K7V1A>7,I("\@
M-RD@*R`D=V5E:W,I.PH@("`@?2`O+R!E;F0@9G5N8R!W965K<TEN36]N=&@*
M"B`@("`O*BH*("`@("`J($9I;F0@=&AE(&1A>2!O9B!T:&4@=V5E:R!F;W(@
M=&AE(&9I<G-T(&]F('1H92!M;VYT:"!O9B!G:79E;B!D871E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@;6]N=&@@:6X@9F]R;6%T($U-+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!S=')I
M;F<@>65A<B!I;B!F;W)M870@0T-962P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L('EE87(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*
M("`@("`J($!R971U<FX@:6YT(&YU;6)E<B!O9B!W965K9&%Y(&9O<B!T:&4@
M9FER<W0@9&%Y+"`P/5-U;F1A>0H@("`@("HO"@H@("`@9G5N8W1I;VX@9FER
M<W1/9DUO;G1H5V5E:V1A>2@D;6]N=&@])R<L)'EE87(])R<I"B`@("!["B`@
M("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T
M95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N*$1A=&5?0V%L8SHZ9&%Y3V97965K*"<P,2<L)&UO;G1H+"1Y96%R*2D[
M"B`@("!]("\O(&5N9"!F=6YC(&9I<G-T3V9-;VYT:%=E96MD87D*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!D871E(&]F(&9I<G-T(&1A>2!O9B!M;VYT:"!O
M9B!G:79E;B!D871E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@;6]N
M=&@@:6X@9F]R;6%T($U-+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N
M=&@*("`@("`J($!P87)A;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-962P@
M9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S
M=')I;F<@9F]R;6%T(&9O<B!R971U<FYE9"!D871E"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D
M871E(&EN(&=I=F5N(&9O<FUA=`H@("`@("HO"@H@("`@9G5N8W1I;VX@8F5G
M:6Y/9DUO;G1H*"1M;VYT:#TG)RPD>65A<CTG)RPD9F]R;6%T/2<E625M)60G
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@
M("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M
M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;BA$871E7T-A;&,Z.F1A=&5&;W)M870H)S`Q)RPD;6]N
M=&@L)'EE87(L)&9O<FUA="DI.PH@("`@?2`O+R!E;F0@;V8@9G5N8R!B96=I
M;D]F36]N=&@*"B`@("`O*BH*("`@("`J($9I;F0@=&AE(&UO;G1H(&1A>2!O
M9B!T:&4@8F5G:6YN:6YG(&]F('=E96L@9F]R(&=I=F5N(&1A=&4L"B`@("`@
M*B!U<VEN9R!$051%7T-!3$-?0D5'24Y?5T5%2T1!62X@*&-A;B!R971U<FX@
M=V5E:V1A>2!O9B!P<F5V(&UO;G1H+BD*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&1A>2!I;B!F;W)M870@1$0L(&1E9F%U;'0@:7,@8W5R<F5N="!L
M;V-A;"!D87D*("`@("`J($!P87)A;2!S=')I;F<@;6]N=&@@:6X@9F]R;6%T
M($U-+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P
M87)A;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-962P@9&5F875L="!I<R!C
M=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@9F]R;6%T
M(&9O<B!R971U<FYE9"!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D871E(&EN(&=I=F5N
M(&9O<FUA=`H@("`@("HO"@H@("`@9G5N8W1I;VX@8F5G:6Y/9E=E96LH)&1A
M>3TG)RPD;6]N=&@])R<L)'EE87(])R<L)&9O<FUA=#TG)5DE;25D)RD*("`@
M('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y
M96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#
M86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7-?
M=V5E:V1A>2`]($1A=&5?0V%L8SHZ9&%Y3V97965K*"1D87DL)&UO;G1H+"1Y
M96%R*3L*"B`@("`@("`@:68@*$1!5$5?0T%,0U]"14=)3E]7145+1$%9(#T]
M(#$I('L*("`@("`@("`@("`@:68@*"1T:&ES7W=E96MD87D@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@)&)E9VEN3V97965K(#T@1&%T95]#86QC.CID871E
M5&]$87ES*"1D87DL)&UO;G1H+"1Y96%R*2`M(#8["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D8F5G:6Y/9E=E96L@/2!$871E7T-A
M;&,Z.F1A=&54;T1A>7,H)&1A>2PD;6]N=&@L)'EE87(I"B`@("`@("`@("`@
M("`@("`@("`@+2`D=&AI<U]W965K9&%Y("L@,3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8F5G:6Y/9E=E96L@
M/2`H1&%T95]#86QC.CID871E5&]$87ES*"1D87DL)&UO;G1H+"1Y96%R*0H@
M("`@("`@("`@("`@("`@("`@("T@)'1H:7-?=V5E:V1A>2D["B`@("`@("`@
M?0H*("`@("`@("\J("`D8F5G:6Y/9E=E96L@/2`H1&%T95]#86QC.CID871E
M5&]$87ES*"1D87DL)&UO;G1H+"1Y96%R*0H@("`@("`@("`@("`M("@D=&AI
M<U]W965K9&%Y("T@1$%415]#04Q#7T)%1TE.7U=%14M$05DI*3L@*B\*"B`@
M("`@("`@<F5T=7)N*$1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D8F5G:6Y/9E=E
M96LL)&9O<FUA="DI.PH@("`@?2`O+R!E;F0@;V8@9G5N8R!B96=I;D]F5V5E
M:PH*("`@("\J*@H@("`@("H@1FEN9"!T:&4@;6]N=&@@9&%Y(&]F('1H92!E
M;F0@;V8@=V5E:R!F;W(@9VEV96X@9&%T92P*("`@("`J('5S:6YG($1!5$5?
M0T%,0U]"14=)3E]7145+1$%9+B`H8V%N(')E='5R;B!W965K9&%Y"B`@("`@
M*B!O9B!F;VQL;W=I;F<@;6]N=&@N*0H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@9&%Y(&EN(&9O<FUA="!$1"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&1A>0H@("`@("H@0'!A<F%M('-T<FEN9R!M;VYT:"!I;B!F;W)M870@
M34TL(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A
M<F%M('-T<FEN9R!Y96%R(&EN(&9O<FUA="!#0UE9+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R!F;W)M870@
M9F]R(')E='5R;F5D(&1A=&4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(&1A=&4@:6X@9VEV96X@
M9F]R;6%T"B`@("`@*B\*"B`@("!F=6YC=&EO;B!E;F1/9E=E96LH)&1A>3TG
M)RPD;6]N=&@])R<L)'EE87(])R<L)&9O<FUA=#TG)5DE;25D)RD*("`@('L*
M("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R
M(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC
M.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7-?=V5E
M:V1A>2`]($1A=&5?0V%L8SHZ9&%Y3V97965K*"1D87DL)&UO;G1H+"1Y96%R
M*3L*"B`@("`@("`@)&QA<W1?9&%Y3V97965K(#T@*$1A=&5?0V%L8SHZ9&%T
M951O1&%Y<R@D9&%Y+"1M;VYT:"PD>65A<BD*("`@("`@("`@("`@*R`H-B`M
M("1T:&ES7W=E96MD87D@*R!$051%7T-!3$-?0D5'24Y?5T5%2T1!62DI.PH*
M("`@("`@("!R971U<FXH1&%T95]#86QC.CID87ES5&]$871E*"1L87-T7V1A
M>4]F5V5E:RPD9F]R;6%T*2D["B`@("!]("\O(&5N9"!F=6YC(&5N9$]F5V5E
M:PH*("`@("\J*@H@("`@("H@1FEN9"!T:&4@;6]N=&@@9&%Y(&]F('1H92!B
M96=I;FYI;F<@;V8@=V5E:R!A9G1E<B!G:79E;B!D871E+`H@("`@("H@=7-I
M;F<@1$%415]#04Q#7T)%1TE.7U=%14M$05DN("AC86X@<F5T=7)N('=E96MD
M87D@;V8@<')E=B!M;VYT:"XI"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R!D87D@:6X@9F]R;6%T($1$+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@
M9&%Y"B`@("`@*B!`<&%R86T@<W1R:6YG(&UO;G1H(&EN(&9O<FUA="!-32P@
M9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@
M<W1R:6YG('EE87(@:6X@9F]R;6%T($-#65DL(&1E9F%U;'0@:7,@8W5R<F5N
M="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG(&9O<FUA="!F;W(@
M<F5T=7)N960@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92!I;B!G:79E;B!F;W)M
M870*("`@("`J+PH*("`@(&9U;F-T:6]N(&)E9VEN3V9.97AT5V5E:R@D9&%Y
M/2<G+"1M;VYT:#TG)RPD>65A<CTG)RPD9F]R;6%T/2<E625M)60G*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE
M87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H(B59(BD["B`@("`@("`@?0H@("`@
M("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@B)6TB*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H(B5D(BD["B`@("`@("`@?0H*("`@("`@("`D9&%T92`]
M($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@*("`@("`@("`@("`@("`@("`@("!$
M871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2LW+"1M;VYT:"PD>65A<BDL(B59
M)6TE9"(*("`@("`@("`@("`@("`@("D["@H@("`@("`@("1N97AT7W=E96M?
M>65A<B`]('-U8G-T<B@D9&%T92PP+#0I.PH@("`@("`@("1N97AT7W=E96M?
M;6]N=&@@/2!S=6)S='(H)&1A=&4L-"PR*3L*("`@("`@("`D;F5X=%]W965K
M7V1A>2`]('-U8G-T<B@D9&%T92PV+#(I.PH*("`@("`@("!R971U<FX@1&%T
M95]#86QC.CIB96=I;D]F5V5E:R@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N97AT7W=E96M?9&%Y+"1N97AT7W=E96M?;6]N=&@L)&YE>'1?=V5E
M:U]Y96%R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA=`H@
M("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@?2`O+R!E;F0@9G5N8R!B
M96=I;D]F3F5X=%=E96L*"B`@("`O*BH*("`@("`J($9I;F0@=&AE(&UO;G1H
M(&1A>2!O9B!T:&4@8F5G:6YN:6YG(&]F('=E96L@8F5F;W)E(&=I=F5N(&1A
M=&4L"B`@("`@*B!U<VEN9R!$051%7T-!3$-?0D5'24Y?5T5%2T1!62X@*&-A
M;B!R971U<FX@=V5E:V1A>2!O9B!P<F5V(&UO;G1H+BD*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&1A>2!I;B!F;W)M870@1$0L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A;2!S=')I;F<@;6]N=&@@
M:6X@9F]R;6%T($U-+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*
M("`@("`J($!P87)A;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-962P@9&5F
M875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I
M;F<@9F]R;6%T(&9O<B!R971U<FYE9"!D871E"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D871E
M(&EN(&=I=F5N(&9O<FUA=`H@("`@("HO"@H@("`@9G5N8W1I;VX@8F5G:6Y/
M9E!R9797965K*"1D87D])R<L)&UO;G1H/2<G+"1Y96%R/2<G+"1F;W)M870]
M)R59)6TE9"<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@
M("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@B)5DB*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@
M("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"(E;2(I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@
M)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@B)60B*3L*("`@("`@("!]"@H@
M("`@("`@("1D871E(#T@1&%T95]#86QC.CID87ES5&]$871E*`H@("`@("`@
M("`@("`@("`@("`@("`@("!$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2TW
M+"1M;VYT:"PD>65A<BDL(B59)6TE9"(*("`@("`@("`@("`@("`@("`@("`I
M.PH*("`@("`@("`D<')E=E]W965K7WEE87(@/2!S=6)S='(H)&1A=&4L,"PT
M*3L*("`@("`@("`D<')E=E]W965K7VUO;G1H(#T@<W5B<W1R*"1D871E+#0L
M,BD["B`@("`@("`@)'!R979?=V5E:U]D87D@/2!S=6)S='(H)&1A=&4L-BPR
M*3L*"B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH)'!R
M979?=V5E:U]D87DL)'!R979?=V5E:U]M;VYT:"PD<')E=E]W965K7WEE87(L
M)&9O<FUA="D["B`@("!]("\O(&5N9"!F=6YC(&)E9VEN3V90<F5V5V5E:PH*
M("`@("\J*@H@("`@("H@4F5T=7)N(&%N(&%R<F%Y('=I=&@@9&%Y<R!I;B!W
M965K"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!D87D@:6X@9F]R;6%T
M($1$+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&UO;G1H(&EN(&9O<FUA="!-32P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@<W1R:6YG('EE87(@:6X@
M9F]R;6%T($-#65DL(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&9O<FUA="!F;W(@<F5T=7)N960@9&%T90H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`D=V5E:ULD=V5E:V1A>5T*("`@("`J+PH*("`@(&9U;F-T
M:6]N(&=E=$-A;&5N9&%R5V5E:R@D9&%Y/2<G+"1M;VYT:#TG)RPD>65A<CTG
M)RPD9F]R;6%T/2<E625M)60G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I
M*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G
M)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@
M("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@
M("`@("`@?0H*("`@("`@("`D=V5E:U]A<G)A>2`](&%R<F%Y*"D["@H@("`@
M("`@("\O(&1A=&4@9F]R('1H92!C;VQU;6X@;V8@=V5E:PH*("`@("`@("`D
M8W5R<E]D87D@/2!$871E7T-A;&,Z.F)E9VEN3V97965K*"1D87DL)&UO;G1H
M+"1Y96%R+"<E12<I.PH*("`@("`@("!F;W(H)&-O=6YT97(],#L@)&-O=6YT
M97(@/#T@-CL@)&-O=6YT97(K*RD@>PH@("`@("`@("`@("`D=V5E:U]A<G)A
M>5LD8V]U;G1E<ET@/2!$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&-U<G)?9&%Y
M+"1F;W)M870I.PH@("`@("`@("`@("`D8W5R<E]D87DK*SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=V5E:U]A<G)A>3L*("`@('T@+R\@96YD(&9U
M;F,@9V5T0V%L96YD87)7965K"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!S
M970@;V8@87)R87ES('1O(&-O;G-T<G5C="!A(&-A;&5N9&%R(&UO;G1H(&9O
M<@H@("`@("H@=&AE(&=I=F5N(&1A=&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R!M;VYT:"!I;B!F;W)M870@34TL(&1E9F%U;'0@:7,@8W5R<F5N
M="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M('-T<FEN9R!Y96%R(&EN(&9O
M<FUA="!#0UE9+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@
M("H@0'!A<F%M('-T<FEN9R!F;W)M870@9F]R(')E='5R;F5D(&1A=&4*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@)&UO;G1H6R1R;W==6R1C;VQ="B`@("`@*B\*"B`@("!F=6YC
M=&EO;B!G971#86QE;F1A<DUO;G1H*"1M;VYT:#TG)RPD>65A<CTG)RPD9F]R
M;6%T/2<E625M)60G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI
M('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@
M("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*
M("`@("`@("!]"@H@("`@("`@("1M;VYT:%]A<G)A>2`](&%R<F%Y*"D["@H@
M("`@("`@("\O(&1A=&4@9F]R('1H92!F:7)S="!R;W<L(&9I<G-T(&-O;'5M
M;B!O9B!C86QE;F1A<B!M;VYT:`H@("`@("`@(&EF("A$051%7T-!3$-?0D5'
M24Y?5T5%2T1!62`]/2`Q*2!["B`@("`@("`@("`@(&EF("A$871E7T-A;&,Z
M.F9I<G-T3V9-;VYT:%=E96MD87DH)&UO;G1H+"1Y96%R*2`]/2`P*2!["B`@
M("`@("`@("`@("`@("`D8W5R<E]D87D@/2!$871E7T-A;&,Z.F1A=&54;T1A
M>7,H)S`Q)RPD;6]N=&@L)'EE87(I("T@-CL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1C=7)R7V1A>2`]($1A=&5?0V%L8SHZ9&%T
M951O1&%Y<R@G,#$G+"1M;VYT:"PD>65A<BD*("`@("`@("`@("`@("`@("`@
M("`M($1A=&5?0V%L8SHZ9FER<W1/9DUO;G1H5V5E:V1A>2@D;6]N=&@L)'EE
M87(I("L@,3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1C=7)R7V1A>2`]("A$871E7T-A;&,Z.F1A=&54;T1A>7,H)S`Q
M)RPD;6]N=&@L)'EE87(I"B`@("`@("`@("`@("`@("`M($1A=&5?0V%L8SHZ
M9FER<W1/9DUO;G1H5V5E:V1A>2@D;6]N=&@L)'EE87(I*3L*("`@("`@("!]
M"@H@("`@("`@("\O(&YU;6)E<B!O9B!D87ES(&EN('1H:7,@;6]N=&@*("`@
M("`@("`D9&%Y<TEN36]N=&@@/2!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"1M
M;VYT:"PD>65A<BD["@H@("`@("`@("1W965K<TEN36]N=&@@/2!$871E7T-A
M;&,Z.G=E96MS26Y-;VYT:"@D;6]N=&@L)'EE87(I.PH@("`@("`@(&9O<B@D
M<F]W7V-O=6YT97(],#L@)')O=U]C;W5N=&5R(#P@)'=E96MS26Y-;VYT:#L@
M)')O=U]C;W5N=&5R*RLI('L*("`@("`@("`@("`@9F]R*"1C;VQU;6Y?8V]U
M;G1E<CTP.R`D8V]L=6UN7V-O=6YT97(@/#T@-CL@)&-O;'5M;E]C;W5N=&5R
M*RLI('L*("`@("`@("`@("`@("`@("1M;VYT:%]A<G)A>5LD<F]W7V-O=6YT
M97)=6R1C;VQU;6Y?8V]U;G1E<ET@/0H@("`@("`@("`@("`@("`@("`@($1A
M=&5?0V%L8SHZ9&%Y<U1O1&%T92@D8W5R<E]D87DL)&9O<FUA="D["B`@("`@
M("`@("`@("`@("`D8W5R<E]D87DK*SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1M;VYT:%]A<G)A>3L*("`@('T@+R\@96YD
M(&9U;F,@9V5T0V%L96YD87)-;VYT:`H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&$@<V5T(&]F(&%R<F%Y<R!T;R!C;VYS=')U8W0@82!C86QE;F1A<B!Y96%R
M(&9O<@H@("`@("H@=&AE(&=I=F5N(&1A=&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R!Y96%R(&EN(&9O<FUA="!#0UE9+"!D969A=6QT(&-U<G)E
M;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R!F;W)M870@9F]R
M(')E='5R;F5D(&1A=&4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@)'EE87);)&UO;G1H75LD<F]W
M75LD8V]L70H@("`@("HO"@H@("`@9G5N8W1I;VX@9V5T0V%L96YD87)996%R
M*"1Y96%R/2<G+"1F;W)M870])R59)6TE9"<I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"@H@("`@("`@("1Y96%R7V%R
M<F%Y(#T@87)R87DH*3L*"B`@("`@("`@9F]R*"1C=7)R7VUO;G1H/3`[("1C
M=7)R7VUO;G1H(#P],3$[("1C=7)R7VUO;G1H*RLI('L*("`@("`@("`@("`@
M)'EE87)?87)R87E;)&-U<G)?;6]N=&A=(#T*("`@("`@("`@("`@("`@($1A
M=&5?0V%L8SHZ9V5T0V%L96YD87)-;VYT:"AS<')I;G1F*"<E,#)D)RPD8W5R
M<E]M;VYT:"LQ*2PD>65A<BPD9F]R;6%T*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D>65A<E]A<G)A>3L*("`@('T@+R\@96YD(&9U;F,@9V5T0V%L
M96YD87)996%R"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A(&1A=&4@=&\@
M;G5M8F5R(&]F(&1A>7,@<VEN8V4@80H@("`@("H@9&ES=&%N="!U;G-P96-I
M9FEE9"!E<&]C:"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(&1A>2!I
M;B!F;W)M870@1$0*("`@("`J($!P87)A;2!S=')I;F<@;6]N=&@@:6X@9F]R
M;6%T($U-"B`@("`@*B!`<&%R86T@<W1R:6YG('EE87(@:6X@9F]R;6%T($-#
M65D*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B!N=6UB97(@;V8@9&%Y<PH@("`@("HO"@H@("`@
M9G5N8W1I;VX@9&%T951O1&%Y<R@D9&%Y+"1M;VYT:"PD>65A<BD*("`@('L*
M"B`@("`@("`@)&-E;G1U<GD@/2`H:6YT*2!S=6)S='(H)'EE87(L,"PR*3L*
M("`@("`@("`D>65A<B`]("AI;G0I('-U8G-T<B@D>65A<BPR+#(I.PH*("`@
M("`@("!I9B`H)&UO;G1H(#X@,BD@>PH@("`@("`@("`@("`D;6]N=&@@+3T@
M,SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6]N=&@@*ST@.3L*
M("`@("`@("`@("`@:68@*"1Y96%R*2!["B`@("`@("`@("`@("`@("`D>65A
M<BTM.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'EE
M87(@/2`Y.3L*("`@("`@("`@("`@("`@("1C96YT=7)Y("TM.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*&9L;V]R*"@@,30V
M,#DW("H@)&-E;G1U<GDI("\@-"`I("L*("`@("`@("`@("`@9FQO;W(H*"`Q
M-#8Q("H@)'EE87(I("\@-"`I("L*("`@("`@("`@("`@9FQO;W(H*"`Q-3,@
M*B`D;6]N=&@@*R`R*2`O(#4@*2`K"B`@("`@("`@("`@("1D87D@*R`Q-S(Q
M,3$Y*3L*("`@('T@+R\@96YD(&9U;F,@9&%T951O1&%Y<PH*("`@("\J*@H@
M("`@("H@0V]N=F5R=',@;G5M8F5R(&]F(&1A>7,@=&\@82!D:7-T86YT('5N
M<W!E8VEF:65D(&5P;V-H+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@;G5M
M8F5R(&]F(&1A>7,*("`@("`J($!P87)A;2!S=')I;F<@9F]R;6%T(&9O<B!R
M971U<FYE9"!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D871E(&EN('-P96-I9FEE9"!F
M;W)M870*("`@("`J+PH*("`@(&9U;F-T:6]N(&1A>7-4;T1A=&4H)&1A>7,L
M)&9O<FUA=#TG)5DE;25D)RD*("`@('L*"B`@("`@("`@)&1A>7,@("`@("`@
M+3T@(#$W,C$Q,3D["B`@("`@("`@)&-E;G1U<GD@("`@/2`@(&9L;V]R*"@@
M-"`J("1D87ES("T@,2D@+R`Q-#8P.3<I.PH@("`@("`@("1D87ES("`@("`@
M(#T@("!F;&]O<B@T("H@)&1A>7,@+2`Q("T@,30V,#DW("H@)&-E;G1U<GDI
M.PH@("`@("`@("1D87D@("`@("`@(#T@("!F;&]O<B@D9&%Y<R`O(#0I.PH*
M("`@("`@("`D>65A<B`@("`@("`]("`@9FQO;W(H*"`T("H@)&1A>2`K("`S
M*2`O(#$T-C$I.PH@("`@("`@("1D87D@("`@("`@(#T@("!F;&]O<B@T("H@
M)&1A>2`K("`S("T@,30V,2`J("1Y96%R*3L*("`@("`@("`D9&%Y("`@("`@
M("`]("`@9FQO;W(H*"1D87D@*R`@-"D@+R`T*3L*"B`@("`@("`@)&UO;G1H
M("`@("`@/2`@(&9L;V]R*"@@-2`J("1D87D@+2`S*2`O(#$U,RD["B`@("`@
M("`@)&1A>2`@("`@("`@/2`@(&9L;V]R*#4@*B`D9&%Y("T@,R`M(#$U,R`J
M("1M;VYT:"D["B`@("`@("`@)&1A>2`@("`@("`@/2`@(&9L;V]R*"@D9&%Y
M("L@(#4I("\@(#4I.PH*("`@("`@("!I9B`H)&UO;G1H(#P@,3`I('L*("`@
M("`@("`@("`@)&UO;G1H("L],SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;6]N=&@@+3TY.PH@("`@("`@("`@("!I9B`H)'EE87(K*R`]/2`Y
M.2D@>PH@("`@("`@("`@("`@("`@)'EE87(@/2`P.PH@("`@("`@("`@("`@
M("`@)&-E;G1U<GDK*SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&-E;G1U<GD@/2!S<')I;G1F*"<E,#)D)RPD8V5N='5R>2D["B`@("`@
M("`@)'EE87(@/2!S<')I;G1F*"<E,#)D)RPD>65A<BD["B`@("`@("`@<F5T
M=7)N*$1A=&5?0V%L8SHZ9&%T949O<FUA="@D9&%Y+"1M;VYT:"PD8V5N='5R
M>2XD>65A<BPD9F]R;6%T*2D["B`@("!]("\O(&5N9"!F=6YC(&1A>7-4;T1A
M=&4*"B`@("`O*BH*("`@("`J($-A;&-U;&%T97,@=&AE(&1A=&4@;V8@=&AE
M($YT:"!W965K9&%Y(&]F('1H92!M;VYT:"P*("`@("`J('-U8V@@87,@=&AE
M('-E8V]N9"!3871U<F1A>2!O9B!*86YU87)Y(#(P,#`N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R!O8V-U<F%N8V4Z(#$]9FER<W0L(#(]<V5C;VYD
M+"`S/71H:7)D+"!E=&,N"B`@("`@*B!`<&%R86T@<W1R:6YG(&1A>4]F5V5E
M:SH@,#U3=6YD87DL(#$]36]N9&%Y+"!E=&,N"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&UO;G1H(&EN(&9O<FUA="!-30H@("`@("H@0'!A<F%M('-T<FEN9R!Y
M96%R(&EN(&9O<FUA="!#0UE9"B`@("`@*B!`<&%R86T@<W1R:6YG(&9O<FUA
M="!F;W(@<F5T=7)N960@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92!I;B!G:79E
M;B!F;W)M870*("`@("`J+PH*("`@(&9U;F-T:6]N($Y7965K9&%Y3V9-;VYT
M:"@D;V-C=7)A;F-E+"1D87E/9E=E96LL)&UO;G1H+"1Y96%R+"1F;W)M870]
M)R59)6TE9"<I"B`@("!["B`@("`@("`@)'EE87(@/2!S<')I;G1F*"<E,#1D
M)RPD>65A<BD["B`@("`@("`@)&UO;G1H(#T@<W!R:6YT9B@G)3`R9"<L)&UO
M;G1H*3L*"B`@("`@("`@)$1/5S%D87D@/2!S<')I;G1F*"<E,#)D)RPH*"1O
M8V-U<F%N8V4@+2`Q*2`J(#<@*R`Q*2D["B`@("`@("`@)$1/5S$@/2!$871E
M7T-A;&,Z.F1A>4]F5V5E:R@D1$]7,61A>2PD;6]N=&@L)'EE87(I.PH*("`@
M("`@("`D=V1A=&4@/2`H)&]C8W5R86YC92`M(#$I("H@-R`K(#$@*PH@("`@
M("`@("`@("`@("`@*#<@*R`D9&%Y3V97965K("T@)$1/5S$I("4@-SL*"B`@
M("`@("`@:68@*"`D=V1A=&4@/B!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"1M
M;VYT:"PD>65A<BDI('L*("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;BA$871E7T-A;&,Z.F1A=&5&
M;W)M870H)'=D871E+"1M;VYT:"PD>65A<BPD9F]R;6%T*2D["B`@("`@("`@
M?0H@("`@?2`O+R!E;F0@9G5N8R!.5V5E:V1A>4]F36]N=&@*"B`@("`O*BH*
M("`@("`J("!&;W)M871S('1H92!D871E(&EN('1H92!G:79E;B!F;W)M870L
M(&UU8V@@;&EK90H@("`@("H@('-T<F9M="@I+B!4:&ES(&9U;F-T:6]N(&ES
M('5S960@=&\@86QL979I871E('1H90H@("`@("H@('!R;V)L96T@=VET:"`S
M,BUB:70@;G5M8F5R<R!F;W(@9&%T97,@<')E(#$Y-S`*("`@("`J("!O<B!P
M;W-T(#(P,S@L(&%S('-T<F9M="@I(&AA<R!O;B!M;W-T('-Y<W1E;7,N"B`@
M("`@*B`@36]S="!O9B!T:&4@9F]R;6%T=&EN9R!O<'1I;VYS(&%R92!C;VUP
M871I8FQE+@H@("`@("H*("`@("`J("!F;W)M871T:6YG(&]P=&EO;G,Z"B`@
M("`@*@H@("`@("H@("5A("`@("`@("!A8F)R979I871E9"!W965K9&%Y(&YA
M;64@*%-U;BP@36]N+"!4=64I"B`@("`@*B`@)4$@("`@("`@(&9U;&P@=V5E
M:V1A>2!N86UE("A3=6YD87DL($UO;F1A>2P@5'5E<V1A>2D*("`@("`J("`E
M8B`@("`@("`@86)B<F5V:6%T960@;6]N=&@@;F%M92`H2F%N+"!&96(L($UA
M<BD*("`@("`J("`E0B`@("`@("`@9G5L;"!M;VYT:"!N86UE("A*86YU87)Y
M+"!&96)R=6%R>2P@36%R8V@I"B`@("`@*B`@)60@("`@("`@(&1A>2!O9B!M
M;VYT:"`H<F%N9V4@,#`@=&\@,S$I"B`@("`@*B`@)64@("`@("`@(&1A>2!O
M9B!M;VYT:"P@<VEN9VQE(&1I9VET("AR86YG92`P('1O(#,Q*0H@("`@("H@
M("5%("`@("`@("!N=6UB97(@;V8@9&%Y<R!S:6YC92!U;G-P96-I9FEE9"!E
M<&]C:"`H:6YT96=E<BD*("`@("`J("`@("`@("`@("`@("@E12!I<R!U<V5F
M=6P@9F]R('!A<W-I;F<@82!D871E(&EN(&$@55),(&%S"B`@("`@*B`@("`@
M("`@("`@("!A;B!I;G1E9V5R('9A;'5E+B!4:&5N('-I;7!L>2!U<V4*("`@
M("`J("`@("`@("`@("`@(&1A>7-4;T1A=&4H*2!T;R!C;VYV97)T(&)A8VL@
M=&\@82!D871E+BD*("`@("`J("`E:B`@("`@("`@9&%Y(&]F('EE87(@*')A
M;F=E(#`P,2!T;R`S-C8I"B`@("`@*B`@)6T@("`@("`@(&UO;G1H(&%S(&1E
M8VEM86P@;G5M8F5R("AR86YG92`Q('1O(#$R*0H@("`@("H@("5N("`@("`@
M("!N97=L:6YE(&-H87)A8W1E<B`H7&XI"B`@("`@*B`@)70@("`@("`@('1A
M8B!C:&%R86-T97(@*%QT*0H@("`@("H@("5W("`@("`@("!W965K9&%Y(&%S
M(&1E8VEM86P@*#`@/2!3=6YD87DI"B`@("`@*B`@)54@("`@("`@('=E96L@
M;G5M8F5R(&]F(&-U<G)E;G0@>65A<BP@9FER<W0@<W5N9&%Y(&%S(&9I<G-T
M('=E96L*("`@("`J("`E>2`@("`@("`@>65A<B!A<R!D96-I;6%L("AR86YG
M92`P,"!T;R`Y.2D*("`@("`J("`E62`@("`@("`@>65A<B!A<R!D96-I;6%L
M(&EN8VQU9&EN9R!C96YT=7)Y("AR86YG92`P,#`P('1O(#DY.3DI"B`@("`@
M*B`@)24@("`@("`@(&QI=&5R86P@)R4G"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R!D87D@:6X@9F]R;6%T($1$"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&UO;G1H(&EN(&9O<FUA="!-30H@("`@("H@0'!A<F%M('-T<FEN9R!Y96%R
M(&EN(&9O<FUA="!#0UE9"B`@("`@*B!`<&%R86T@<W1R:6YG(&9O<FUA="!F
M;W(@<F5T=7)N960@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92!I;B!G:79E;B!F
M;W)M870*("`@("`J+PH*("`@(&9U;F-T:6]N(&1A=&5&;W)M870H)&1A>2PD
M;6]N=&@L)'EE87(L)&9O<FUA="D*("`@('L*("`@("`@("!I9B`H(41A=&5?
M0V%L8SHZ:7-686QI9$1A=&4H)&1A>2PD;6]N=&@L)'EE87(I*2!["B`@("`@
M("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@
M("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@
M("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@
M("`@("`@?0H*("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@(&9O<B@D
M<W1R<&]S(#T@,#L@)'-T<G!O<R`\('-T<FQE;B@D9F]R;6%T*3L@)'-T<G!O
M<RLK*2!["B`@("`@("`@("`@("1C:&%R(#T@<W5B<W1R*"1F;W)M870L)'-T
M<G!O<RPQ*3L*("`@("`@("`@("`@:68@*"1C:&%R(#T]("<E)RD@>PH@("`@
M("`@("`@("`@("`@)&YE>'1C:&%R(#T@<W5B<W1R*"1F;W)M870L)'-T<G!O
M<R`K(#$L,2D["B`@("`@("`@("`@("`@("!S=VET8V@H)&YE>'1C:&%R*2![
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G82<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CIG9717965K9&%Y06)B
M<FYA;64H)&1A>2PD;6]N=&@L)'EE87(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=!)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z.F=E
M=%=E96MD87E&=6QL;F%M92@D9&%Y+"1M;VYT:"PD>65A<BD["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)V(G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A
M=&5?0V%L8SHZ9V5T36]N=&A!8F)R;F%M92@D;6]N=&@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=")SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E
M7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H)&UO;G1H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G
M9"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT
M9B@G)3`R9"<L)&1A>2D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)V4G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]("1D87D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)T4G.@H@
M("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ
M9&%T951O1&%Y<R@D9&%Y+"1M;VYT:"PD>65A<BD["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VHG
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L
M8SHZ:G5L:6%N1&%T92@D9&%Y+"1M;VYT:"PD>65A<BD["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)VTG.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN
M=&8H)R4P,F0G+"1M;VYT:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VXG.@H@("`@("`@("`@
M("`@("`@("`@("`@("`D;W5T<'5T("X](")<;B(["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@(G0B
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X](")<="(["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)W<G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T
M("X]($1A=&5?0V%L8SHZ9&%Y3V97965K*"1D87DL)&UO;G1H+"1Y96%R*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G52<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@1&%T95]#86QC.CIW965K3V9996%R*"1D87DL)&UO;G1H+"1Y96%R
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@8V%S92`G>2<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@<W5B<W1R*"1Y96%R+#(L,BD["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)UDG.@H@
M("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1Y96%R.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!C87-E("<E)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`G)2<["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@)&-H87(N)&YE>'1C:&%R.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'-T<G!O<RLK.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D8VAA<CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@
M('T@+R\@96YD(&9U;F,@9&%T949O<FUA=`H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@8W5R<F5N="!L;V-A;"!Y96%R(&EN(&9O<FUA="!#0UE9"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!Y96%R(&EN(&9O<FUA="!#0UE9"B`@("`@*B\*"B`@("!F
M=6YC=&EO;B!G971996%R*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#
M86QC.CID871E3F]W*"<E62<I.PH@("`@?2`O+R!E;F0@9G5N8R!G971996%R
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT(&QO8V%L(&UO
M;G1H(&EN(&9O<FUA="!-30H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@;6]N=&@@:6X@9F]R;6%T
M($U-"B`@("`@*B\*"B`@("!F=6YC=&EO;B!G971-;VYT:"@I"B`@("!["B`@
M("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@('T@
M+R\@96YD(&9U;F,@9V5T36]N=&@*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&-U<G)E;G0@;&]C86P@9&%Y(&EN(&9O<FUA="!$1`H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@9&%Y(&EN(&9O<FUA="!$1`H@("`@("HO"@H@("`@9G5N8W1I;VX@9V5T
M1&%Y*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E3F]W
M*"<E9"<I.PH@("`@?2`O+R!E;F0@9G5N8R!G971$87D*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&9U;&P@;6]N=&@@;F%M92!F;W(@=&AE(&=I=F5N
M(&UO;G1H"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!M;VYT:"!I;B!F
M;W)M870@34T*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG(&9U;&P@;6]N=&@@;F%M90H@("`@("HO
M"@H@("`@9G5N8W1I;VX@9V5T36]N=&A&=6QL;F%M92@D;6]N=&@I"B`@("![
M"B`@("`@("`@)&UO;G1H(#T@*&EN="DD;6]N=&@["@H@("`@("`@(&EF("AE
M;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]("AI;G0I($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"@H@("`@("`@("1M
M;VYT:%]N86UE<R`]($1A=&5?0V%L8SHZ9V5T36]N=&A.86UE<R@I.PH*("`@
M("`@("!R971U<FX@)&UO;G1H7VYA;65S6R1M;VYT:%T["B`@("`@("`@+R\@
M9V5T36]N=&A.86UE<R!R971U<FYS(&UO;G1H<R!W:71H(&-O<G)E8W0@:6YD
M97AE<PH@("`@("`@("\O<F5T=7)N("1M;VYT:%]N86UE<ULH)&UO;G1H("T@
M,2E=.PH@("`@?2`O+R!E;F0@9G5N8R!G971-;VYT:$9U;&QN86UE"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!A8F)R979I871E9"!M;VYT:"!N86UE
M(&9O<B!T:&4@9VEV96X@;6]N=&@*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&UO;G1H(&EN(&9O<FUA="!-30H@("`@("H@0'!A<F%M(&EN="!O<'1I
M;VYA;"!L96YG=&@@;V8@86)B<F5V:6%T:6]N+"!D969A=6QT(&ES(#,*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG(&%B8G)E=FEA=&5D(&UO;G1H(&YA;64*("`@("`J($!S964@
M1&%T95]#86QC.CIG971-;VYT:$9U;&QN86UE"B`@("`@*B\*"B`@("!F=6YC
M=&EO;B!G971-;VYT:$%B8G)N86UE*"1M;VYT:"PD;&5N9W1H/3,I"B`@("![
M"B`@("`@("`@)&UO;G1H(#T@*&EN="DD;6]N=&@["@H@("`@("`@(&EF("AE
M;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!S
M=6)S='(H1&%T95]#86QC.CIG971-;VYT:$9U;&QN86UE*"1M;VYT:"DL(#`L
M("1L96YG=&@I.PH@("`@?2`O+R!E;F0@9G5N8R!G971-;VYT:$%B8G)N86UE
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!F=6QL('=E96MD87D@;F%M
M92!F;W(@=&AE(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&1A>2!I;B!F;W)M870@1$0L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A
M;"!D87D*("`@("`J($!P87)A;2!S=')I;F<@;6]N=&@@:6X@9F]R;6%T($U-
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A
M;2!S=')I;F<@>65A<B!I;B!F;W)M870@0T-962P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L('EE87(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(&9U;&P@;6]N=&@@;F%M90H@
M("`@("HO"@H@("`@9G5N8W1I;VX@9V5T5V5E:V1A>49U;&QN86UE*"1D87D]
M)R<L)&UO;G1H/2<G+"1Y96%R/2<G*0H@("`@>PH@("`@("`@(&EF("AE;7!T
M>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N
M=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2![
M"B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD[
M"B`@("`@("`@?0H*("`@("`@("`D=V5E:V1A>5]N86UE<R`]($1A=&5?0V%L
M8SHZ9V5T5V5E:T1A>7,H*3L*("`@("`@("`D=V5E:V1A>2`]($1A=&5?0V%L
M8SHZ9&%Y3V97965K*"1D87DL)&UO;G1H+"1Y96%R*3L*"B`@("`@("`@<F5T
M=7)N("1W965K9&%Y7VYA;65S6R1W965K9&%Y73L*("`@('T@+R\@96YD(&9U
M;F,@9V5T5V5E:V1A>49U;&QN86UE"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!A8F)R979I871E9"!W965K9&%Y(&YA;64@9F]R('1H92!G:79E;B!D
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!D87D@:6X@9F]R;6%T
M($1$+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&UO;G1H(&EN(&9O<FUA="!-32P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@<W1R:6YG('EE87(@:6X@
M9F]R;6%T($-#65DL(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@
M("`@*B!`<&%R86T@:6YT(&]P=&EO;F%L(&QE;F=T:"!O9B!A8F)R979I871I
M;VXL(&1E9F%U;'0@:7,@,PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@9G5L;"!M;VYT:"!N86UE
M"B`@("`@*B!`<V5E($1A=&5?0V%L8SHZ9V5T5V5E:V1A>49U;&QN86UE"B`@
M("`@*B\*"B`@("!F=6YC=&EO;B!G9717965K9&%Y06)B<FYA;64H)&1A>3TG
M)RPD;6]N=&@])R<L)'EE87(])R<L)&QE;F=T:#TS*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5D)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<W5B<W1R*$1A
M=&5?0V%L8SHZ9V5T5V5E:V1A>49U;&QN86UE*"1D87DL)&UO;G1H+"1Y96%R
M*2PP+"1L96YG=&@I.PH@("`@?2`O+R!E;F0@9G5N8R!G9717965K9&%Y1G5L
M;&YA;64*"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@;G5M97)I8R!M;VYT
M:"!F<F]M('1H92!M;VYT:"!N86UE(&]R(&%N(&%B<F5V:6%T:6]N"B`@("`J
M"B`@("`J($)O=&@@075G=7-T(&%N9"!!=6<@=V]U;&0@<F5T=7)N(#@N"B`@
M("`J($UO;G1H(&YA;64@:7,@8V%S92!I;G-E;G-I=&EV92X*("`@("H*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@;6]N=&@@;F%M90H@("`@*B!`<F5T=7)N
M("`@:6YT96=E<B!M;VYT:"!N=6UB97(*("`@("HO"B`@("!F=6YC=&EO;B!G
M971-;VYT:$9R;VU&=6QL3F%M92@D;6]N=&@I"B`@("!["B`@("`@("`@)&UO
M;G1H(#T@<W1R=&]L;W=E<B@D;6]N=&@I.PH@("`@("`@("1M;VYT:',@/2!$
M871E7T-A;&,Z.F=E=$UO;G1H3F%M97,H*3L*("`@("`@("!W:&EL92AL:7-T
M*"1I9"P@)&YA;64I(#T@96%C:"@D;6]N=&AS*2D@>PH@("`@("`@("`@("!I
M9B`H97)E9R@D;6]N=&@L('-T<G1O;&]W97(H)&YA;64I*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N*"1I9"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B@P*3L*("`@('T@+R\@96YD(&9U;F,@9V5T36]N
M=&A&<F]M1G5L;$YA;64*"B`@("`O*BH*("`@("H@4F5T=7)N<R!A;B!A<G)A
M>2!O9B!M;VYT:"!N86UE<PH@("`@*@H@("`@*B!5<V5D('1O('1A:V4@861V
M86YT86=E(&]F('1H92!S971L;V-A;&4@9G5N8W1I;VX@=&\@<F5T=7)N"B`@
M("`J(&QA;F=U86=E('-P96-I9FEC(&UO;G1H(&YA;65S+@H@("`@*B!86%@@
M8V%C:&4@=F%L=65S('1O('-O;64@9VQO8F%L(&%R<F%Y('1O(&%V;VED('!R
M969O<FUA8V4*("`@("H@:&ET<R!W:&5N(&-A;&QE9"!M;W)E('1H86X@;VYC
M92X*("`@("H*("`@("H@0')E='5R;G,@87)R87D@06X@87)R87D@;V8@;6]N
M=&@@;F%M97,*("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT:$YA;65S*"D*
M("`@('L*("`@("`@("!F;W(H)&D],3LD:3PQ,SLD:2LK*2!["B`@("`@("`@
M("`@("1M;VYT:'-;)&E=(#T@<W1R9G1I;64H)R5")RP@;6MT:6UE*#`L(#`L
M(#`L("1I+"`Q+"`R,#`Q*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B@D
M;6]N=&AS*3L*("`@('T@+R\@96YD(&9U;F,@9V5T36]N=&A.86UE<PH*("`@
M("\J*@H@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F('=E96L@9&%Y<PH@("`@
M*@H@("`@*B!5<V5D('1O('1A:V4@861V86YT86=E(&]F('1H92!S971L;V-A
M;&4@9G5N8W1I;VX@=&\*("`@("H@<F5T=7)N(&QA;F=U86=E('-P96-I9FEC
M('=E96L@9&%Y<PH@("`@*B!86%@@8V%C:&4@=F%L=65S('1O('-O;64@9VQO
M8F%L(&%R<F%Y('1O(&%V;VED('!R969O<FUA8V4*("`@("H@:&ET<R!W:&5N
M(&-A;&QE9"!M;W)E('1H86X@;VYC92X*("`@("H*("`@("H@0')E='5R;G,@
M87)R87D@06X@87)R87D@;V8@=V5E:R!D87D@;F%M97,*("`@("HO"B`@("!F
M=6YC=&EO;B!G9717965K1&%Y<R@I"B`@("!["B`@("`@("`@9F]R*"1I/3`[
M)&D\-SLD:2LK*2!["B`@("`@("`@("`@("1W965K9&%Y<ULD:5T@/2!S=')F
M=&EM92@G)4$G+"!M:W1I;64H,"P@,"P@,"P@,2P@)&DL(#(P,#$I*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N*"1W965K9&%Y<RD["B`@("!]("\O(&5N
M9"!F=6YC(&=E=%=E96M$87ES"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!F
M<F]M($=R96=O<FEA;B!996%R+4UO;G1H+41A>2!T;PH@("`@("H@25-/(%EE
M87).=6UB97(M5V5E:TYU;6)E<BU7965K1&%Y"B`@("`@*@H@("`@("H@57-E
M<R!)4T\@.#8P,2!D969I;FET:6]N<RX*("`@("`J($%L9V]R:71H;2!F<F]M
M(%)I8VL@36-#87)T>2P@,3DY.2!A=`H@("`@("H@:'1T<#HO+W!E<G-O;F%L
M+F5C=2YE9'4O;6-C87)T>7(O25-/=V1!3$<N='AT"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R!D87D@:6X@9F]R;6%T($1$"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&UO;G1H(&EN(&9O<FUA="!-30H@("`@("H@0'!A<F%M('-T<FEN
M9R!Y96%R(&EN(&9O<FUA="!#0UE9"B`@("`@*B!`<F5T=7)N('-T<FEN9PH@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@+R\@5')A;G-C<FEB
M960@=&\@4$A0(&)Y($IE<W5S($TN($-A<W1A9VYE='1O("AB;&%M92!H:6T@
M:68@:70@:7,@9G5B87)E9"`[+2D*("`@(&9U;F-T:6]N(&=R96=O<FEA;E1O
M25-/*"1D87DL)&UO;G1H+"1Y96%R*2!["B`@("`@("`@)&UN=&@@/2!A<G)A
M>2`H,"PS,2PU.2PY,"PQ,C`L,34Q+#$X,2PR,3(L,C0S+#(W,RPS,#0L,S,T
M*3L*("`@("`@("`D>5]I<VQE87`@/2!$871E7T-A;&,Z.FES3&5A<%EE87(H
M)'EE87(I.PH@("`@("`@("1Y7S%?:7-L96%P(#T@1&%T95]#86QC.CII<TQE
M87!996%R*"1Y96%R("T@,2D["B`@("`@("`@)&1A>5]O9E]Y96%R7VYU;6)E
M<B`]("1D87D@*R`D;6YT:%LD;6]N=&@@+2`Q73L*("`@("`@("!I9B`H)'E?
M:7-L96%P("8F("1M;VYT:"`^(#(I('L*("`@("`@("`@("`@)&1A>5]O9E]Y
M96%R7VYU;6)E<BLK.PH@("`@("`@('T*("`@("`@("`O+R!F:6YD($IA;B`Q
M('=E96MD87D@*&UO;F1A>2`](#$L('-U;F1A>2`](#<I"B`@("`@("`@)'EY
M(#T@*"1Y96%R("T@,2D@)2`Q,#`["B`@("`@("`@)&,@/2`H)'EE87(@+2`Q
M*2`M("1Y>3L*("`@("`@("`D9R`]("1Y>2`K(&EN='9A;"@D>7DO-"D["B`@
M("`@("`@)&IA;C%?=V5E:V1A>2`](#$@*R!I;G1V86PH*"@H*"1C("\@,3`P
M*2`E(#0I("H@-2D@*R`D9RD@)2`W*3L*("`@("`@("`O+R!W965K9&%Y(&9O
M<B!Y96%R+6UO;G1H+61A>0H@("`@("`@("1H(#T@)&1A>5]O9E]Y96%R7VYU
M;6)E<B`K("@D:F%N,5]W965K9&%Y("T@,2D["B`@("`@("`@)'=E96MD87D@
M/2`Q("L@:6YT=F%L*"@D:"`M(#$I("4@-RD["B`@("`@("`@+R\@9FEN9"!I
M9B!9($T@1"!F86QL<R!I;B!996%R3G5M8F5R(%DM,2P@5V5E:TYU;6)E<B`U
M,B!O<@H@("`@("`@(&EF("@D9&%Y7V]F7WEE87)?;G5M8F5R(#P]("@X("T@
M)&IA;C%?=V5E:V1A>2D@)B8@)&IA;C%?=V5E:V1A>2`^(#0I>PH@("`@("`@
M("`@("`D>65A<FYU;6)E<B`]("1Y96%R("T@,3L*("`@("`@("`@("`@:68@
M*"1J86XQ7W=E96MD87D@/3T@-2!\?"`H)&IA;C%?=V5E:V1A>2`]/2`V("8F
M("1Y7S%?:7-L96%P*2D@>PH@("`@("`@("`@("`@("`@)'=E96MN=6UB97(@
M/2`U,SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1W
M965K;G5M8F5R(#T@-3(["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D>65A<FYU;6)E<B`]("1Y96%R.PH@("`@("`@('T*
M("`@("`@("`O+R!F:6YD(&EF(%D@32!$(&9A;&QS(&EN(%EE87).=6UB97(@
M62LQ+"!7965K3G5M8F5R(#$*("`@("`@("!I9B`H)'EE87)N=6UB97(@/3T@
M)'EE87(I('L*("`@("`@("`@("`@:68@*"1Y7VES;&5A<"D@>PH@("`@("`@
M("`@("`@("`@)&D@/2`S-C8["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D:2`](#,V-3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H*"1I("T@)&1A>5]O9E]Y96%R7VYU;6)E<BD@/"`H-"`M("1W965K
M9&%Y*2D@>PH@("`@("`@("`@("`@("`@)'EE87)N=6UB97(K*SL*("`@("`@
M("`@("`@("`@("1W965K;G5M8F5R(#T@,3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`O+R!F:6YD(&EF(%D@32!$(&9A;&QS(&EN(%EE87).
M=6UB97(@62P@5V5E:TYU;6)E<B`Q('1H<F]U9V@@-3,*("`@("`@("!I9B`H
M)'EE87)N=6UB97(@/3T@)'EE87(I('L*("`@("`@("`@("`@)&H@/2`D9&%Y
M7V]F7WEE87)?;G5M8F5R("L@*#<@+2`D=V5E:V1A>2D@*R`H)&IA;C%?=V5E
M:V1A>2`M(#$I.PH@("`@("`@("`@("`D=V5E:VYU;6)E<B`](&EN='9A;"@D
M:B`O(#<I.PH@("`@("`@("`@("!I9B`H)&IA;C%?=V5E:V1A>2`^(#0I('L*
M("`@("`@("`@("`@("`@("1W965K;G5M8F5R+2T["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@+R\@<'5T(&ET(&%L;"!T;V=E=&AE<@H@("`@
M("`@(&EF("@D=V5E:VYU;6)E<B`\(#$P*0H@("`@("`@("`@("`D=V5E:VYU
M;6)E<B`]("<P)RXD=V5E:VYU;6)E<CL*("`@("`@("!R971U<FX@(GLD>65A
M<FYU;6)E<GTM>R1W965K;G5M8F5R?2U[)'=E96MD87E](CL*("`@('T*"B`@
M("`O*BH*("`@("H@1&5T97)M:6YE<R!J=6QI86X@9&%T92!O9B!T:&4@9VEV
M96X@<V5A<V]N"B`@("`J($%D87!T960@9G)O;2!P<F5V:6]U<R!W;W)K(&EN
M($IA=F$@8GD@2F%M97,@36%R:R!(86UI;'1O;BP@;6AA;6EL=&]N0'%W97-T
M+FYE=`H@("`@*@H@("`@*B!`875T:&]R(%)O8F5R="!"=71L97(@/')O8D!M
M87AW96QL8W)E96LN;W)G/@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG(&ES
M(%9%4DY!3$5154E.3U@L(%-534U%4E-/3%-424-%+"!!551534Y!3$5154E.
M3U@L(&]R(%=)3E1%4E-/3%-424-%+@H@("`@*B!`<&%R86T@<W1R:6YG('EE
M87(@:6X@9F]R;6%T($-#65DL(&UU<W0@8F4@82!C86QE;F1A<B!Y96%R(&)E
M='=E96X@+3$P,#!"0R!A;F0@,S`P,$%$+@H@("`@*@H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*@H@("`@*B!`<F5T=7)N(&9L;V%T("1J=6QI86YD871E
M"B`@("`J+PH*("`@(&9U;F-T:6]N(&1A=&5396%S;VX@*"1S96%S;VXL("1Y
M96%R(#T@)R<I('L*("`@("`@("`@("`@:68@*"1Y96%R(#T]("<G*2!["B`@
M("`@("`@("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R59)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@H)'EE87(@
M/CT@+3$P,#`I("8F("@D>65A<B`\/2`Q,#`P*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1Y(#T@)'EE87(@+R`Q,#`P+C`["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1S96%S;VX@/3T@)U9%4DY!3$5154E.3U@G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:G5L:6%N9&%T92`]("@H*"@H*"@M,"XP
M,#`W,2`J("1Y*2`M(#`N,#`Q,3$I("H@)'DI("L@,"XP-C$S-"D@*B`D>2D@
M*R`S-C4R-#(N,3,W-"D@*B`D>2D@*R`Q-S(Q,3,Y+C(Y,3@Y.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!I9B`H)'-E87-O;B`]/2`G4U5-34524T],
M4U1)0T4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:G5L:6%N
M9&%T92`]("@H*"@H*"@@,"XP,#`R-2`J("1Y*2`K(#`N,#`Y,#<I("H@)'DI
M("T@,"XP-3,R,RD@*B`D>2D@*R`S-C4R-#$N-S(U-C(I("H@)'DI("L@,3<R
M,3(S,RXR-30P,3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@:68@*"1S
M96%S;VX@/3T@)T%55%5-3D%,15%524Y/6"<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1J=6QI86YD871E(#T@*"@H*"@H*"`P+C`P,#<T("H@
M)'DI("T@,"XP,#(Y-RD@*B`D>2D@+2`P+C$Q-C<W*2`J("1Y*2`K(#,V-3(T
M,BXT.34U."D@*B`D>2D@*R`Q-S(Q,S(U+C<P-#4U.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!I9B`H)'-E87-O;B`]/2`G5TE.5$524T],4U1)0T4G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:G5L:6%N9&%T92`]
M("@H*"@H*"@M,"XP,#`P-B`J("1Y*2`M(#`N,#`Y,S,I("H@)'DI("T@,"XP
M,#<V.2D@*B`D>2D@*R`S-C4R-#(N.#@R-3<I("H@)'DI("L@,3<R,30Q-"XS
M.3DX-SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M96EF("@H)'EE87(@/B`Q,#`P*2`F)B`H)'EE87(@/#T@,S`P,"DI('L*("`@
M("`@("`@("`@("`@("`@("`D>2`]("@D>65A<B`M(#(P,#`I("\@,3`P,#L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'-E87-O;B`]/2`G5D523D%,15%5
M24Y/6"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1J=6QI86YD
M871E(#T@*"@H*"@H*"TP+C`P,#4W("H@)'DI("T@,"XP,#0Q,2D@*B`D>2D@
M*R`P+C`U,38Y*2`J("1Y*2`K(#,V-3(T,BXS-S0P-"D@*B`D>2D@*R`R-#4Q
M-C(S+C@P.3@T.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!I9B`H)'-E
M87-O;B`]/2`G4U5-34524T],4U1)0T4G*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:G5L:6%N9&%T92`]("@H*"@H*"@M,"XP,#`S("H@)'DI
M("L@,"XP,#@X."D@*B`D>2D@*R`P+C`P,S(U*2`J("1Y*2`K(#,V-3(T,2XV
M,C8P,RD@*B`D>2D@*R`R-#4Q-S$V+C4V-S8W.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!I9B`H)'-E87-O;B`]/2`G055454U.04Q%455)3D]8)RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&IU;&EA;F1A=&4@/2`H
M*"@H*"@H(#`N,#`P-S@@*B`D>2D@*R`P+C`P,S,W*2`J("1Y*2`M(#`N,3$U
M-S4I("H@)'DI("L@,S8U,C0R+C`Q-S8W*2`J("1Y*2`K(#(T-3$X,3`N,C$W
M,34["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E(&EF("@D<V5A<V]N(#T]
M("=724Y415)33TQ35$E#12<I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1J=6QI86YD871E(#T@*"@H*"@H*"`P+C`P,#,R("H@)'DI("T@,"XP
M,#@R,RD@*B`D>2D@+2`P+C`V,C(S*2`J("1Y*2`K(#,V-3(T,BXW-#`T.2D@
M*B`D>2D@*R`R-#4Q.3`P+C`U.34R.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("@D:G5L:6%N9&%T
M92D["B`@("!]("\O(&5N9"!F=6YC(&1A=&5396%S;VX*"GT@+R\@96YD(&-L
M87-S($1A=&5?0V%L8PH*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1&%T92](=6UA
M;BYP:'``````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,34V,3,`,3`T,3<S-C,P,#<`,#(P,#`U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@06QL
M86X@2V5N="`\86QL86Y`;&]D97-T;VYE+F-O+GIA/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O"B\O("1)9#H@2'5M86XN<&AP+'8@,2XS(#(P,#,O,#$O,#0@,3$Z-30Z
M-30@;6H@17AP("0*+R\*"B\J*@H@*B!#;&%S<R!T;R!C;VYV97)T(&1A=&4@
M<W1R:6YG<R!B971W965N($=R96=O<FEA;B!A;F0@2'5M86X@8V%L96YD87(@
M9F]R;6%T<RX*("H@5&AE($AU;6%N($-A;&5N9&%R(&9O<FUA="!H87,@8F5E
M;B!P<F]P;W-E9"!B>2!38V]T="!&;&%N<V)U<F<@86YD(&-A;B!B90H@*B!E
M>'!L86EN960@87,@9F]L;&]W<SH*("H@(%1H92!Y96%R(&ES(&UA9&4@=7`@
M;V8@,3,@;6]N=&AS"B`J("!%86-H(&UO;G1H(&AA<R`R."!D87ES"B`J("!#
M;W5N=&EN9R!O9B!M;VYT:',@<W1A<G1S(&9R;VT@,"`H>F5R;RD@<V\@=&AE
M(&UO;G1H<R!W:6QL(')U;B!F<F]M(#`@=&\@,3(*("H@($YE=R!996%R<R!D
M87D@*#`P*2!I<R!A(&UO;G1H;&5S<R!D87D*("H@($YO=&4Z($QE87`@665A
M<G,@87)E(&YO="!Y970@86-C;W5N=&5D(&9O<B!I;B!T:&4@2'5M86X@0V%L
M96YD87(@<WES=&5M"B`J"B`J($!S:6YC92!02%`@-"XP+C0*("H@0&%U=&AO
M<B!!;&QA;B!+96YT(#QA;&QA;D!L;V1E<W1O;F4N8V\N>F$^"B`J+PIC;&%S
M<R!$871E7TAU;6%N"GL*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87-S
M;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!T:&4@8V]N=F5R=&5D(&1A=&4@
M:6YF;W)M871I;VX*("`@("`J(&EN("=(=6UA;B!#86QE;F1A<B<@9F]R;6%T
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@9&%Y(&EN($1$(&9O<FUA="P@
M9&5F875L="!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="!M
M;VYT:"!I;B!-32!F;W)M870L(&1E9F%U;'0@8W5R<F5N="!L;V-A;"!M;VYT
M:`H@("`@("H@0'!A<F%M(&EN="!Y96%R(&EN($-#65D@9F]R;6%T+"!D969A
M=6QT('1O(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!A<W-O8VEA=&EV92!A
M<G)A>2@*("`@("`J("`@("`@("`@("`@("`@:&1O;2P@("`@("`@+R\@2'5M
M86X@1&%Y($]F($UO;G1H+"!S=&%R=&EN9R!A="`Q"B`@("`@*B`@("`@("`@
M("`@("`@(&AD;W<L("`@("`@("\O($AU;6%N($1A>2!/9B!7965K+"!S=&%R
M=&EN9R!A="`Q"B`@("`@*B`@("`@("`@("`@("`@(&AW;VTL("`@("`@("\O
M($AU;6%N(%=E96L@;V8@36]N=&@L('-T87)T:6YG(&%T(#$*("`@("`J("`@
M("`@("`@("`@("`@:'=O>2P@("`@("`@+R\@2'5M86X@5V5E:R!O9B!996%R
M+"!S=&%R=&EN9R!A="`Q"B`@("`@*B`@("`@("`@("`@("`@(&AM;WDL("`@
M("`@("\O($AU;6%N($UO;G1H(&]F(%EE87(L('-T87)T:6YG(&%T(#`*("`@
M("`J("`@("`@("`@("`@("`@*0H@("`@("H*("`@("`J($EF('1H92!D87D@
M:7,@3F5W(%EE87)S($1A>2P@=&AE(&9U;F-T:6]N('=I;&P@<F5T=7)N"B`@
M("`@*B`B:&1O;2(@/3X@(#`*("`@("`J(")H9&]W(B`]/B`@,`H@("`@("H@
M(FAW;VTB(#T^("`P"B`@("`@*B`B:'=O>2(@/3X@(#`*("`@("`J(")H;6]Y
M(B`]/B`M,0H@("`@("H@(%-I;F-E(#`@:7,@82!V86QI9"!M;VYT:"!N=6UB
M97(@=6YD97(@=&AE($AU;6%N($-A;&5N9&%R+"!)(&AA=F4@;&5F=`H@("`@
M("H@('1H92!M;VYT:"!A<R`M,2!F;W(@3F5W(%EE87)S($1A>2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9W)E9V]R:6%N5&](=6UA;B@D9&%Y/3`L("1M;VYT
M:#TP+"`D>65A<CTP*0H@("`@>PH@("`@("`@("\J*@H@("`@("`@("`J($-H
M96-K('1O('-E92!I9B!A;GD@;V8@=&AE(&%R9W5M96YT<R!A<F4@96UP='D*
M("`@("`@("`@*B!)9B!T:&5Y(&%R92!T:&5N('!O<'5L871E('1H92`D9&%T
M96EN9F\@87)R87D*("`@("`@("`@*B!4:&5N(&-H96-K('1O('-E92!W:&EC
M:"!A<F=U;65N=',@87)E(&5M<'1Y(&%N9"!F:6QL"B`@("`@("`@("H@=&AO
M<V4@=VET:"!T:&4@8W5R<F5N="!D871E(&EN9F\*("`@("`@("`@*B\*("`@
M("`@("!I9B`H*&5M<'1Y*"1D87DI('Q\("AE;7!T>2@D;6]N=&@I*2!\?"!E
M;7!T>2@D>65A<BDI*2!["B`@("`@("`@("`@("1D871E:6YF;R`](&=E=&1A
M=&4H=&EM92@I*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI
M*2!["B`@("`@("`@("`@("1D87D@/2`D9&%T96EN9F];(FUD87DB73L*("`@
M("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@
M("`@)&UO;G1H(#T@)&1A=&5I;F9O6R)M;VXB73L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]("1D
M871E:6YF;ULB>65A<B)=.PH@("`@("`@('T*("`@("`@("`O*BH*("`@("`@
M("`@*B!792!N965D('1O(&MN;W<@:&]W(&UA;GD@9&%Y<R!I;G1O('1H92!Y
M96%R('=E(&%R90H@("`@("`@("`J+PH@("`@("`@("1D871E:6YF;R`](&=E
M=&1A=&4H;6MT:6UE*#`L(#`L(#`L("1M;VYT:"P@)&1A>2P@)'EE87(I*3L*
M("`@("`@("`D9&%Y;V9Y96%R(#T@)&1A=&5I;F9O6R)Y9&%Y(ET["B`@("`@
M("`@+RHJ"B`@("`@("`@("H@2'5M86X@0V%L96YD87(@<W1A<G1S(&%T(#`@
M9F]R(&UO;G1H<R!A;F0@=&AE(&9I<G-T(&1A>2!O9B!T:&4@>65A<@H@("`@
M("`@("`J(&ES(&1E<VEG;F%T960@,#`L('-O('=E(&YE960@=&\@<W1A<G0@
M;W5R(&1A>2!O9B!T:&4@>65A<B!A="`P(&9O<@H@("`@("`@("`J('1H97-E
M(&-A;&-U;&%T:6]N<RX*("`@("`@("`@*B!!;'-O+"!T:&4@9&%Y(&]F('1H
M92!M;VYT:"!I<R!C86QC=6QA=&5D('=I=&@@82!M;V1U;'5S(&]F(#(X+@H@
M("`@("`@("`J($)E8V%U<V4@82!D87D@:7,@,C@@9&%Y<RP@=&AE(&QA<W0@
M9&%Y(&]F('1H92!M;VYT:"!W;W5L9"!H879E(&$*("`@("`@("`@*B!R96UA
M:6YD97(@;V8@,"!A;F0@;F]T(#(X(&%S(&ET('-H;W5L9"!B92X@($1E8W)E
M;65N=&EN9R`D9&%Y;V9Y96%R"B`@("`@("`@("H@9V5T<R!A<F]U;F0@=&AI
M<RX*("`@("`@("`@*B\*("`@("`@("`D9&%Y;V9Y96%R+2T["B`@("`@("`@
M+RHJ"B`@("`@("`@("H@,C@@9&%Y<R!I;B!A(&UO;G1H+BXN"B`@("`@("`@
M("HO"B`@("`@("`@)&AU;6%N36]N=&A/9EEE87(@/2!F;&]O<B@D9&%Y;V9Y
M96%R("\@,C@I.PH@("`@("`@("\J*@H@("`@("`@("`J($EF('=E(&%R92!I
M;B!T:&4@9FER<W0@;6]N=&@@=&AE;B!T:&4@9&%Y(&]F('1H92!M;VYT:"!I
M<R`D9&%Y;V9Y96%R"B`@("`@("`@("H@96QS92!W92!N965D('1O(&9I;F0@
M=&AE(&UO9'5L=7,@;V8@,C@N"B`@("`@("`@("HO"B`@("`@("`@:68@*"1H
M=6UA;DUO;G1H3V9996%R(#T](#`I('L*("`@("`@("`@("`@)&AU;6%N1&%Y
M3V9-;VYT:"`]("1D87EO9GEE87(["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&AU;6%N1&%Y3V9-;VYT:"`]("@D9&%Y;V9Y96%R*2`E(#(X.PH@
M("`@("`@('T*("`@("`@("`O*BH*("`@("`@("`@*B!$87D@;V8@=&AE('=E
M96L@:7,@;6]D=6QU<R`W"B`@("`@("`@("HO"B`@("`@("`@)&AU;6%N1&%Y
M3V97965K(#T@)&1A>6]F>65A<B`E(#<["B`@("`@("`@+RHJ"B`@("`@("`@
M("H@5V4@8V%N(&YO=R!I;F-R96UE;G0@)&1A>6]F>65A<B!B86-K('1O(&ET
M)W,@8V]R<F5C="!V86QU92!F;W(*("`@("`@("`@*B!T:&4@<F5M86EN9&5R
M(&]F('1H92!C86QC=6QA=&EO;G,*("`@("`@("`@*B\*("`@("`@("`D9&%Y
M;V9Y96%R*RL["B`@("`@("`@+RHJ"B`@("`@("`@("H@)&AU;6%N1&%Y3V9-
M;VYT:"!N965D<R!T;R!B92!I;F-R96UE;G1E9"!N;W<@+2!R96-A;&P@=&AA
M="!W92!F=61G960*("`@("`@("`@*B!I="!A(&)I="!B>2!D96-R96UE;G1I
M;F<@)&1A>6]F>65A<B!E87)L:65R"B`@("`@("`@("H@4V%M92!G;V5S(&9O
M<B`D:'5M86Y$87E/9E=E96L*("`@("`@("`@*B\*("`@("`@("`D:'5M86Y$
M87E/9DUO;G1H*RL["B`@("`@("`@)&AU;6%N1&%Y3V97965K*RL["B`@("`@
M("`@+RHJ"B`@("`@("`@("H@5V5E:R!O9B!T:&4@;6]N=&@@:7,@9&%Y(&]F
M('1H92!M;VYT:"!D:79I9&5D(&)Y(#<L(')O=6YD960@=7`*("`@("`@("`@
M*B!386UE(&9O<B!W965K(&]F('1H92!Y96%R+"!B=70@=7-E("1D87EO9GEE
M87(@:6YS=&5A9"`D:'5M86Y$87E/9DUO;G1H"B`@("`@("`@("HO"B`@("`@
M("`@)&AU;6%N5V5E:T]F36]N=&@@/2!C96EL*"1H=6UA;D1A>4]F36]N=&@@
M+R`W*3L*("`@("`@("`D:'5M86Y7965K3V9996%R(#T@8V5I;"@D9&%Y;V9Y
M96%R("\@-RD["B`@("`@("`@+RHJ"B`@("`@("`@("H@4F5T=7)N(&%N(&%S
M<V]C:6%T:79E(&%R<F%Y(&]F('1H92!V86QU97,*("`@("`@("`@*B\*("`@
M("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(")H9&]M
M(B`]/B`D:'5M86Y$87E/9DUO;G1H+`H@("`@("`@("`@("`@("`@("`@("`B
M:&1O=R(@/3X@)&AU;6%N1&%Y3V97965K+`H@("`@("`@("`@("`@("`@("`@
M("`B:'=O;2(@/3X@)&AU;6%N5V5E:T]F36]N=&@L"B`@("`@("`@("`@("`@
M("`@("`@(")H=V]Y(B`]/B`D:'5M86Y7965K3V9996%R+`H@("`@("`@("`@
M("`@("`@("`@("`B:&UO>2(@/3X@)&AU;6%N36]N=&A/9EEE87(@*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=6YI>"!T:6UE<W1A;7`@9F]R
M(&$@9VEV96X@2'5M86X@0V%L96YD87(@9&%T90H@("`@("H*("`@("`J($!P
M87)A;2!I;G0@9&%Y(&EN($1$(&9O<FUA=`H@("`@("H@0'!A<F%M(&EN="!M
M;VYT:"!I;B!-32!F;W)M870*("`@("`J($!P87)A;2!I;G0@>65A<B!I;B!#
M0UE9(&9O<FUA="P@9&5F875L="!T;R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U
M<FX@:6YT('5N:7@@=&EM97-T86UP(&]F(&1A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@2'5M86Y4;T=R96=O<FEA;B@D9&%Y+"`D;6]N=&@L("1Y96%R/3`I
M"B`@("!["B`@("`@("`@+RHJ"B`@("`@("`@("H@0VAE8VL@=&\@<V5E(&EF
M('1H92!Y96%R(&AA<R!B965N('!A<W-E9"!T:')O=6=H+@H@("`@("`@("`J
M($EF(&YO="!G970@8W5R<F5N="!Y96%R"B`@("`@("`@("HO"B`@("`@("`@
M:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D9&%T96EN9F\@/2!G
M971D871E*'1I;64H*2D["B`@("`@("`@("`@("1Y96%R(#T@)&1A=&5I;F9O
M6R)Y96%R(ET["B`@("`@("`@?0H@("`@("`@("\J*@H@("`@("`@("`J(%=E
M(&YE960@=&\@9V5T('1H92!D87D@;V8@=&AE('EE87(@=&AA="!W92!A<F4@
M8W5R<F5N=&QY(&%T('-O('1H870*("`@("`@("`@*B!W92!C86X@=V]R:R!O
M=70@=&AE($=R96=O<FEA;B!-;VYT:"!A;F0@9&%Y"B`@("`@("`@("HO"B`@
M("`@("`@)$1A>4]F665A<B`]("1M;VYT:"`J(#(X.PH@("`@("`@("1$87E/
M9EEE87(@*ST@)&1A>3L*("`@("`@("`O*BH*("`@("`@("`@*B!(=6UA;B!#
M86QE;F1A<B!S=&%R=',@870@,"P@<V\@=V4@;F5E9"!T;R!I;F-R96UE;G0@
M)$1A>4]F665A<@H@("`@("`@("`J('1O('1A:V4@:6YT;R!A8V-O=6YT('1H
M92!D87D@,#`*("`@("`@("`@*B\*("`@("`@("`D1&%Y3V9996%R*RL["B`@
M("`@("`@+RHJ"B`@("`@("`@("H@=&AE(&UK=&EM92@I(&9U;F-T:6]N('=I
M;&P@8V]R<F5C=&QY(&-A;&-U;&%T92!T:&4@9&%T92!F;W(@;W5T(&]F"B`@
M("`@("`@("H@<F%N9V4@=F%L=65S+"!S;R!P=71T:6YG("1$87E/9EEE87(@
M:6YS=&5A9"!O9B!T:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@("`@("`J('=I
M;&P@=V]R:R!F:6YE+@H@("`@("`@("`J+PH@("`@("`@("1'<F5G;W)I86Y4
M:6UE4W1A;7`@/2!M:W1I;64H,"P@,"P@,"P@,2P@)$1A>4]F665A<BP@)'EE
M87(I.PH@("`@("`@(')E='5R;B`D1W)E9V]R:6%N5&EM95-T86UP.PH@("`@
M?0H*?0H_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O1&%T92]3<&%N+G!H<```````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S0R-S<`,3`T,3<S-C,P
M,#<`,#$W-C4Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<V]F='1A8G-T;W`]-"!S:&EF='=I9'1H/30Z"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@3&5A;F1R
M;R!,=6-A<F5L;&$@/&QL=6-A>$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M"B\O("1)9#H@4W!A;BYP:'`L=B`Q+C0@,C`P,R\P-"\S,"`P,SHU-CHR-B!L
M;'5C87@@17AP("0*+R\*"G)E<75I<F5?;VYC92`G1&%T92YP:'`G.PIR97%U
M:7)E7V]N8V4@)T1A=&4O0V%L8RYP:'`G.PH*+RHJ"B`J($YO;B!.=6UE<FEC
M(%-E<&%R871E9"!686QU97,@*$Y.4U8I($EN<'5T($9O<FUA="X*("H*("H@
M26YP=70@9F]R;6%T(&=U97-S960@9G)O;2!S;VUE=&AI;F<@;&EK92!T:&ES
M.@H@*B!D87ES/'-E<#YH;W5R<SQS97`^;6EN=71E<SQS97`^<V5C;VYD<PH@
M*B!7:&5R92`\<V5P/B!I<R!A;GD@<75A;G1I='D@;V8@;F]N(&YU;65R:6,@
M8VAA<G,N($EF(&YO('9A;'5E<R!A<F4*("H@9VEV96XL('1I;64@<W!A;B!I
M<R!S970@=&\@>F5R;RP@:68@;VYE('9A;'5E(&ES(&=I=F5N+"!I="=S('5S
M960@9F]R"B`J(&AO=7)S+"!I9B!T=V\@=F%L=65S(&%R92!G:79E;B!I="=S
M('5S960@9F]R(&AO=7)S(&%N9"!M:6YU=&5S(&%N9"!I9@H@*B!T:')E92!V
M86QU97,@87)E(&=I=F5N+"!I="=S('5S960@9F]R(&AO=7)S+"!M:6YU=&5S
M(&%N9"!S96-O;F1S+CQB<CX*("H@17AA;7!L97,Z/&)R/@H@*B`G)R`@("`@
M("`@("`@("`@("`@("`M/B`P+"`P+"`P+"`P("AD87ES+"!H;W5R<RP@;6EN
M=71E<RP@<V5C;VYD<RD\8G(^"B`J("<Q,B<@("`@("`@("`@("`@("`@("T^
M(#`L(#$R+"`P+"`P"B`J("<Q,BXS,"<@("`@("`@("`@("`@("T^(#`L(#$R
M+"`S,"P@,#QB<CX*("H@)S$R.C,P.C$X)R`@("`@("`@("`@+3X@,"P@,3(L
M(#,P+"`Q.#QB<CX*("H@)S,M,3(M,S`M,3@G("`@("`@("`@+3X@,RP@,3(L
M(#,P+"`Q.#QB<CX*("H@)S,@9&%Y<RP@,3(M,S`M,3@G("`@+3X@,RP@,3(L
M(#,P+"`Q.#QB<CX*("H@)S$R.C,P('=I=&@@,3@@<V5C<R<@+3X@,"P@,3(L
M(#,P+"`Q.#QB<CX*("H*("H@0&-O;G-T(&EN=`H@*B\*9&5F:6YE*"=$051%
M7U-004Y?24Y0551?1D]234%47TY.4U8G+"`Q*3L*"B\J*@H@*B!$969A=6QT
M('1I;64@9F]R;6%T('=H96X@8V]N=F5R=&EN9R!T;R!A('-T<FEN9RX*("H*
M("H@0&=L;V)A;"!S=')I;F<*("HO"B1?1$%415]34$%.7T9/4DU!5"`@/2`G
M)4,G.PH*+RHJ"B`J($1E9F%U;'0@=&EM92!F;W)M870@=VAE;B!C;VYV97)T
M:6YG(&9R;VT@82!S=')I;F<N"B`J"B`J($!G;&]B86P@;6EX960*("HO"B1?
M1$%415]34$%.7TE.4%547T9/4DU!5"`]($1!5$5?4U!!3E])3E!55%]&3U)-
M051?3DY35CL*"B\J*@H@*B!'96YE<FEC('1I;64@<W!A;B!H86YD;&EN9R!C
M;&%S<R!F;W(@4$5!4BX*("H*("H@0'!A8VMA9V4@1&%T90H@*B!`875T:&]R
M("!,96%N9')O($QU8V%R96QL82`\;&QU8V%X0'!H<"YN970^"B`J($!V97)S
M:6]N("12979I<VEO;CH@,2XT("0*("H@0'-I;F-E("`@,2XT"B`J($!T;V1O
M("`@($=E="!A;F0@<V5T(&1E9F%U;'0@;&]C86P@:6YP=70@86YD(&]U='!U
M="!F;W)M871S/PH@*B!`86-C97-S("!P=6)L:6,*("HO"F-L87-S($1A=&5?
M4W!A;B!["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V
M87(@)&1A>3L*"B`@("`O*BH*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@
M('9A<B`D:&]U<CL*"B`@("`O*BH*("`@("`J($!V87(@:6YT"B`@("`@*B\*
M("`@('9A<B`D;6EN=71E.PH*("`@("\J*@H@("`@("H@0'9A<B!I;G0*("`@
M("`J+PH@("`@=F%R("1S96-O;F0["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J"B`@("`@*B!#<F5A=&5S('1H92!T:6UE('-P86X@;V)J
M96-T(&-A;&QI;F<@=&AE('-E="@I(&UE=&AO9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@(&UI>&5D("1T:6UE("`@5&EM92!S<&%N(&5X<')E<W-I;VXN"B`@
M("`@*B!`<&%R86T@(&UI>&5D("1F;W)M870@1F]R;6%T('-T<FEN9R!T;R!S
M970@:70@9G)O;2!A('-T<FEN9R!O<B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!S96-O;F0@9&%T92!S970@:70@9G)O;2!A(&1A=&4@9&EF
M9BX*("`@("`J"B`@("`@*B!`<V5E("`@('-E="@I"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!$871E7U-P86XH)'1I;64@
M/2`P+"`D9F]R;6%T(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^<V5T
M*"1T:6UE+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@=&EM92!S<&%N('1O(&$@;F5W('9A;'5E(&EN(&$@)W-M87)T)R!W87DN
M"B`@("`@*@H@("`@("H@4V5T<R!T:&4@=&EM92!S<&%N(&1E<&5N9&EN9R!O
M;B!T:&4@87)G=6UE;G0@='EP97,L(&-A;&QI;F<*("`@("`J('1O('1H92!A
M<'!R;W!R:6%T92!S971&<F]M6'AX*"D@;65T:&]D+@H@("`@("H*("`@("`J
M($!P87)A;2`@;6EX960@)'1I;64@("!4:6UE('-P86X@97AP<F5S<VEO;BX*
M("`@("`J($!P87)A;2`@;6EX960@)&9O<FUA="!&;W)M870@<W1R:6YG('1O
M('-E="!I="!F<F]M(&$@<W1R:6YG(&]R('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('-E8V]N9"!D871E('-E="!I="!F<F]M(&$@9&%T92!D
M:69F+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=')U92!O;B!S=6-C
M97-S+@H@("`@("H*("`@("`J($!S964@("`@<V5T1G)O;4]B:F5C="@I"B`@
M("`@*B!`<V5E("`@('-E=$9R;VU!<G)A>2@I"B`@("`@*B!`<V5E("`@('-E
M=$9R;VU3=')I;F<H*0H@("`@("H@0'-E92`@("!S971&<F]M4V5C;VYD<R@I
M"B`@("`@*B!`<V5E("`@('-E=$9R;VU$871E1&EF9B@I"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S970H)'1I;64@/2`P
M+"`D9F]R;6%T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?82@D=&EM
M92P@)V1A=&5?<W!A;B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M8V]P>2@D=&EM92D["B`@("`@("`@?2!E;'-E:68@*&ES7V$H)'1I;64L("=D
M871E)RD@86YD(&ES7V$H)&9O<FUA="P@)V1A=&4G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G-E=$9R;VU$871E1&EF9B@D=&EM92P@)&9O<FUA
M="D["B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T:6UE*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU!<G)A>2@D=&EM92D["B`@
M("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D=&EM92DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YS971&<F]M4W1R:6YG*"1T:6UE+"`D9F]R;6%T
M*3L*("`@("`@("!](&5L<V5I9B`H:7-?:6YT*"1T:6UE*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU396-O;F1S*"1T:6UE*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R
M;VU396-O;F1S*#`I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@86X@87)R87DN"B`@("`@*@H@("`@
M("H@4V5T('1H92!T:6UE('-P86X@9G)O;2!A;B!A<G)A>2X@06YY('9A;'5E
M(&-A;B!B92!A(&9L;V%T("AB=70@:70*("`@("`J(&AA<R!N;R!S96YS92!I
M;B!S96-O;F1S*2P@9F]R(&5X86UP;&4@87)R87DH,C,N-2P@,C`L(#`I(&ES
M"B`@("`@*B!I;G1E<G!R971E9"!A<R`R,R!H;W5R<RP@+C4J-C`@*R`R,"`]
M(#4P(&UI;G5T97,@86YD(#`@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@(&%R<F%Y("1T:6UE($ET96US(&%R92!C;W5N=&5D(&9R;VT@<FEG:'0@
M=&\@;&5F="X@1FER<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@:71E
M;2!I<R!F;W(@<V5C;VYD<RP@<V5C;VYD(&9O<B!M:6YU=&5S+"!T:&ER9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("!F;W(@:&]U<G,@86YD(&9O=7)T
M:"!F;W(@9&%Y<RX@268@=&AE<F4@87)E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@(&QE<W,@:71E;7,@=&AA;B`T+"!Z97)O("@P*2!I<R!A<W-U;65D
M(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@86)S96YT('9A
M;'5E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%1R=64@;VX@<W5C
M8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S971&<F]M07)R87DH)'1I;64I"B`@("!["B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D=&EM92DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@("`@("`D=&UP,2`](&YE=R!$871E7U-P86X[
M"B`@("`@("`@:68@*"$D=&UP,2T^<V5T1G)O;5-E8V]N9',H0&%R<F%Y7W!O
M<"@D=&EM92DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("`@("`@)'1M<#(@/2!N97<@1&%T95]3<&%N.PH@("`@("`@(&EF
M("@A)'1M<#(M/G-E=$9R;VU-:6YU=&5S*$!A<G)A>5]P;W`H)'1I;64I*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M("1T;7`Q+3YA9&0H)'1M<#(I.PH@("`@("`@(&EF("@A)'1M<#(M/G-E=$9R
M;VU(;W5R<RA`87)R87E?<&]P*"1T:6UE*2DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D=&UP,2T^861D*"1T;7`R
M*3L*("`@("`@("!I9B`H(21T;7`R+3YS971&<F]M1&%Y<RA`87)R87E?<&]P
M*"1T:6UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@("`@("`D=&UP,2T^861D*"1T;7`R*3L*("`@("`@("!R971U<FX@
M)'1H:7,M/F-O<'DH)'1M<#$I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('1H92!T:6UE('-P86X@9G)O;2!A('-T<FEN9R!B87-E9"!O;B!A;B!I;G!U
M="!F;W)M870N"B`@("`@*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@9G)O
M;2!A('-T<FEN9R!B87-E9"!O;B!A;B!I;G!U="!F;W)M870N(%1H:7,@:7,*
M("`@("`J('-O;64@;&EK92!A(&UI>"!O9B!F;W)M870H*2!M971H;V0@86YD
M('-S8V%N9B@I(%!(4"!F=6YC=&EO;BX@5&AE"B`@("`@*B!E<G)O<B!C:&5C
M:VEN9R!A;F0@=F%L:61A=&EO;B!O9B!T:&ES(&9U;F-T:6]N(&ES('9E<GD@
M<')I;6ET:79E+`H@("`@("H@<V\@>6]U('-H;W5L9"!B92!C87)E9G5L;"!W
M:&5N('5S:6YG(&ET('=I=&@@=6YK;F]W;B`D=&EM92!S=')I;F=S+@H@("`@
M("H@5VET:"!T:&ES(&UE=&AO9"!Y;W4@87)E(&%S<VEG;FEN9R!D87DL(&AO
M=7(L(&UI;G5T92!A;F0@<V5C;VYD"B`@("`@*B!V86QU97,L(&%N9"!T:&4@
M;&%S="!V86QU97,@87)E('5S960N(%1H:7,@;65A;G,@=&AA="!I9B!Y;W4@
M=7-E"B`@("`@*B!S;VUE=&AI;F<@;&EK92!S971&<F]M4W1R:6YG*"<Q,"P@
M,C`G+"`G)4@L("5H)RD@>6]U<B!T:6UE('-P86X*("`@("`J('=O=6QD(&)E
M(#(P(&AO=7)S(&QO;F<N($%L;'=A>7,@<F5M96UB97(@=&AA="!T:&ES(&UE
M=&AO9"!S970*("`@("`J(#QB/F%L;#PO8CX@=&AE('9A;'5E<RP@<V\@:68@
M>6]U(&AA9"!A("1T:6UE('-P86X@,S`@;6EN=71E<R!L;VYG"B`@("`@*B!A
M;F0@>6]U(&UA:V4@)'1I;64M/G-E=$9R;VU3=')I;F<H)S(P(&AO=7)S)RP@
M)R5((&AO=7)S)RDL("1T:6UE"B`@("`@*B!S<&%N('=O=6QD(&)E(#(P(&AO
M=7)S(&QO;F<@*&%N9"!N;W0@,C`@:&]U<G,@86YD(#,P(&UI;G5T97,I+@H@
M("`@("H@26YP=70@9F]R;6%T(&]P=&EO;G,Z/&)R/@H@("`@("H@(#QC;V1E
M/B5#/"]C;V1E/B!$87ES('=I=&@@=&EM92P@<V%M92!A<R`B)40L("5(.B5-
M.B53(BX\8G(^"B`@("`@*B`@/&-O9&4^)60\+V-O9&4^(%1O=&%L(&1A>7,@
M87,@82!F;&]A="!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#(@
M9&%Y<RP@,3(@:&]U<G,@/2`R+C4@9&%Y<RDN/&)R/@H@("`@("H@(#QC;V1E
M/B5$/"]C;V1E/B!$87ES(&%S(&$@9&5C:6UA;"!N=6UB97(N/&)R/@H@("`@
M("H@(#QC;V1E/B5E/"]C;V1E/B!4;W1A;"!H;W5R<R!A<R!A(&9L;V%T(&YU
M;6)E<@H@("`@("H@("`@("`@("`@("`@("`@("`H,2!D87DL(#(@:&]U<G,L
M(#,P(&UI;G5T97,@/2`R-BXU(&AO=7)S*2X\8G(^"B`@("`@*B`@/&-O9&4^
M)68\+V-O9&4^(%1O=&%L(&UI;G5T97,@87,@82!F;&]A="!N=6UB97(*("`@
M("`J("`@("`@("`@("`@("`@("`@*#(@;6EN=71E<RP@,S`@<V5C;VYD<R`]
M(#(N-2!M:6YU=&5S*2X\8G(^"B`@("`@*B`@/&-O9&4^)6<\+V-O9&4^(%1O
M=&%L('-E8V]N9',@87,@82!D96-I;6%L(&YU;6)E<@H@("`@("H@("`@("`@
M("`@("`@("`@("`H,B!M:6YU=&5S+"`S,"!S96-O;F1S(#T@.3`@<V5C;VYD
M<RDN/&)R/@H@("`@("H@(#QC;V1E/B5H/"]C;V1E/B!(;W5R<R!A<R!D96-I
M;6%L(&YU;6)E<BX\8G(^"B`@("`@*B`@/&-O9&4^)4@\+V-O9&4^($AO=7)S
M(&%S(&1E8VEM86P@;G5M8F5R(&QI;6ET960@=&\@,B!D:6=I=',N/&)R/@H@
M("`@("H@(#QC;V1E/B5M/"]C;V1E/B!-:6YU=&5S(&%S(&$@9&5C:6UA;"!N
M=6UB97(N/&)R/@H@("`@("H@(#QC;V1E/B5-/"]C;V1E/B!-:6YU=&5S(&%S
M(&$@9&5C:6UA;"!N=6UB97(@;&EM:71E9"!T;R`R(&1I9VET<RX\8G(^"B`@
M("`@*B`@/&-O9&4^)6X\+V-O9&4^($YE=VQI;F4@8VAA<F%C=&5R("A<;BDN
M/&)R/@H@("`@("H@(#QC;V1E/B5P/"]C;V1E/B!%:71H97(@)V%M)R!O<B`G
M<&TG(&1E<&5N9&EN9R!O;B!T:&4@=&EM92X@268@)W!M)PH@("`@("H@("`@
M("`@("`@("`@("`@("!I<R!D971E8W1E9"!I="!A9&1S(#$R(&AO=7)S('1O
M('1H92!R97-U;'1I;F<@=&EM90H@("`@("H@("`@("`@("`@("`@("`@("!S
M<&%N("AW:71H;W5T(&%N>2!C:&5C:W,I+B!4:&ES(&ES(&-A<V4*("`@("`J
M("`@("`@("`@("`@("`@("`@:6YS96YS:71I=F4N/&)R/@H@("`@("H@(#QC
M;V1E/B5R/"]C;V1E/B!4:6UE(&EN(&%M+W!M(&YO=&%T:6]N+"!S86UE(&%S
M("(E2#HE33HE4R`E<"(N/&)R/@H@("`@("H@(#QC;V1E/B52/"]C;V1E/B!4
M:6UE(&EN(#(T+6AO=7(@;F]T871I;VXL('-A;64@87,@(B5(.B5-(BX\8G(^
M"B`@("`@*B`@/&-O9&4^)7,\+V-O9&4^(%-E8V]N9',@87,@82!D96-I;6%L
M(&YU;6)E<BX\8G(^"B`@("`@*B`@/&-O9&4^)5,\+V-O9&4^(%-E8V]N9',@
M87,@82!D96-I;6%L(&YU;6)E<B!L:6UI=&5D('1O(#(@9&EG:71S+CQB<CX*
M("`@("`J("`\8V]D93XE=#PO8V]D93X@5&%B(&-H87)A8W1E<B`H7'0I+CQB
M<CX*("`@("`J("`\8V]D93XE5#PO8V]D93X@0W5R<F5N="!T:6UE(&5Q=6EV
M86QE;G0L('-A;64@87,@(B5(.B5-.B53(BX\8G(^"B`@("`@*B`@/&-O9&4^
M)24\+V-O9&4^($QI=&5R86P@)R4G+CQB<CX*("`@("`J"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`D=&EM92`@(%-T<FEN9R!F<F]M('=H97)E('1O(&=E="!T
M:&4@=&EM92!S<&%N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&EN
M9F]R;6%T:6]N+@H@("`@("H@0'!A<F%M("!S=')I;F<@)&9O<FUA="!&;W)M
M870@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@(%1R=64@
M;VX@<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!S971&<F]M4W1R:6YG*"1T:6UE+"`D9F]R;6%T
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D9F]R;6%T*2D@
M>PH@("`@("`@("`@("`D9F]R;6%T(#T@)$=,3T)!3%-;)U]$051%7U-004Y?
M24Y0551?1D]234%4)UT["B`@("`@("`@?0H@("`@("`@("\O($EF(&9O<FUA
M="!I<R!A('-T<FEN9RP@:70@<&%R<V5S('1H92!S=')I;F<@9F]R;6%T+@H@
M("`@("`@(&EF("AI<U]S=')I;F<H)&9O<FUA="DI('L*("`@("`@("`@("`@
M)'-T<B`]("<G.PH@("`@("`@("`@("`D=F%R<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@("1P;2`]("=A;2<["B`@("`@("`@("`@("1D87D@/2`D:&]U<B`]
M("1M:6YU=&4@/2`D<V5C;VYD(#T@,#L*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@<W1R;&5N*"1F;W)M870I.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`D8VAA<B`]("1F;W)M871[)&E].PH@("`@("`@("`@("`@("`@:68@
M*"1C:&%R(#T]("<E)RD@>PH@("`@("`@("`@("`@("`@("`@("1N97AT8VAA
M<B`]("1F;W)M871[*RLD:7T["B`@("`@("`@("`@("`@("`@("`@<W=I=&-H
M("@D;F5X=&-H87(I('L*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G
M8R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9"P@
M)60Z)60Z)60G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M<'5S:"@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R<RP@
M)V1A>2<L("=H;W5R)RP@)VUI;G5T92<L("=S96-O;F0G*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E("=#)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M='(@+CT@)R5D+"`E,F0Z)3)D.B4R9"<["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>5]P=7-H*`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V87)S+"`G9&%Y)RP@)VAO=7(G+"`G;6EN=71E)RP@)W-E8V]N
M9"<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)V0G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-T<B`N/2`G)68G.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)V1A>2<I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)T0G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T
M<B`N/2`G)60G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M<'5S:"@D=F%R<RP@)V1A>2<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)V4G.@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)68G.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)VAO
M=7(G*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E("=F)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S='(@+CT@)R5F)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=M:6YU=&4G*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("=G)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S='(@+CT@)R5F)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y7W!U<V@H)'9A<G,L("=S96-O;F0G*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("=H)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R5D
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A
M<G,L("=H;W5R)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G2"<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E,F0G.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)VAO=7(G*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S='(@+CT@)R5D)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=M:6YU=&4G*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E("=-)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@
M+CT@)R4R9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P
M=7-H*"1V87)S+"`G;6EN=71E)RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G;B<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X](")<;B(["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`G<"<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<W1R("X]("<E,G,G.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87E?<'5S:"@D=F%R<RP@)W!M)RD["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`G<B<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E
M,F0Z)3)D.B4R9"`E,G,G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87E?<'5S:"@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R<RP@)VAO=7(G+"`G;6EN=71E)RP@)W-E8V]N9"<L("=P;2<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)U(G.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T<B`N/2`G)3)D.B4R9"<["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>5]P=7-H*"1V87)S+"`G:&]U<B<L("=M:6YU=&4G*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=S)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S='(@+CT@)R5D)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y7W!U<V@H)'9A<G,L("=S96-O;F0G*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E("=3)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@
M)R4R9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H
M*"1V87)S+"`G<V5C;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G="<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X](")<="(["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`G5"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<W1R("X]("<E,F0Z)3)D.B4R9"<["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G:&]U<B<L("=M:6YU=&4G+"`G
M<V5C;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G)2<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<W1R("X]("(E(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`D
M8VAA<B`N("1N97AT8VAA<CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1S='(@
M+CT@)&-H87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'9A;',@/2!S<V-A;F8H)'1I;64L("1S='(I.PH@("`@("`@
M("`@("!F;W)E86-H("@D=F%L<R!A<R`D:2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("`@("!I9B`H:7-?;G5L;"@D=F%L*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("0D=F%R<ULD:5T@/2`D=F%L.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AS=')C87-E8VUP*"1P;2P@)W!M)RD@/3T@,"D@>PH@("`@
M("`@("`@("`@("`@)&AO=7(@*ST@,3(["B`@("`@("`@("`@('T@96QS96EF
M("AS=')C87-E8VUP*"1P;2P@)V%M)RD@(3T@,"D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T
M:&ES+3YS971&<F]M07)R87DH87)R87DH)&1A>2P@)&AO=7(L("1M:6YU=&4L
M("1S96-O;F0I*3L*("`@("`@("`O+R!)9B!F;W)M870@:7,@82!I;G1E9V5R
M+"!I="!U<V5S(&$@<')E9&5F:6YE9"!F;W)M870*("`@("`@("`O+R!D971E
M8W1I;VX@;65T:&]D+@H@("`@("`@('T@96QS96EF("AI<U]I;G1E9V5R*"1F
M;W)M870I*2!["B`@("`@("`@("`@('-W:71C:"`H)&9O<FUA="D@>PH@("`@
M("`@("`@("`@("`@8V%S92!$051%7U-004Y?24Y0551?1D]234%47TY.4U8Z
M"B`@("`@("`@("`@("`@("`@("`@)'1I;64@/2!P<F5G7W-P;&ET*"<O7$0K
M+R<L("1T:6UE*3L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*&-O=6YT
M*"1T:6UE*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(#`Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R
M;VU!<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@P+"`P+"`P+"`P*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M,3H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<V5T1G)O;4%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*#`L("1T:6UE6S!=+"`P+"`P*2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<V5T1G)O;4%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*#`L("1T:6UE6S!=+"`D=&EM95LQ72P@,"DI
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU!<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@P+"`D=&EM
M95LP72P@)'1I;65;,5TL("1T:6UE6S)=*2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G-E=$9R;VU!<G)A>2@D=&EM92D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!T;W1A
M;"!N=6UB97(@;V8@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&EN
M="`@)'-E8V]N9',@5&]T86P@;G5M8F5R(&]F('-E8V]N9',N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L(%1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971&
M<F]M4V5C;VYD<R@D<V5C;VYD<RD*("`@('L*("`@("`@("!I9B`H)'-E8V]N
M9',@/"`P*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@)'-E8R`@/2!I;G1V86PH)'-E8V]N9',I.PH@("`@("`@("1M
M:6X@(#T@9FQO;W(H)'-E8R`O(#8P*3L*("`@("`@("`D:&]U<B`](&9L;V]R
M*"1M:6X@+R`V,"D["B`@("`@("`@)&1A>2`@/2!I;G1V86PH9FQO;W(H)&AO
M=7(@+R`R-"DI.PH@("`@("`@("1T:&ES+3YS96-O;F0@/2`D<V5C("4@-C`[
M"B`@("`@("`@)'1H:7,M/FUI;G5T92`]("1M:6X@)2`V,#L*("`@("`@("`D
M=&AI<RT^:&]U<B`@(#T@)&AO=7(@)2`R-#L*("`@("`@("`D=&AI<RT^9&%Y
M("`@(#T@)&1A>3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!T;W1A;"!N=6UB
M97(@;V8@;6EN=71E<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&9L;V%T("1M
M:6YU=&5S(%1O=&%L(&YU;6)E<B!O9B!M:6YU=&5S+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;"`@5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9R;VU-
M:6YU=&5S*"1M:6YU=&5S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M<V5T1G)O;5-E8V]N9',H<F]U;F0H)&UI;G5T97,@*B`V,"DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@9G)O;2!A('1O=&%L
M(&YU;6)E<B!O9B!H;W5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&9L;V%T
M("1H;W5R<R!4;W1A;"!N=6UB97(@;V8@:&]U<G,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L("!4<G5E(&]N('-U8V-E<W,N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1G)O;4AO
M=7)S*"1H;W5R<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R
M;VU396-O;F1S*')O=6YD*"1H;W5R<R`J(#,V,#`I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!T;W1A;"!N=6UB
M97(@;V8@9&%Y<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&9L;V%T("1D87ES
M(%1O=&%L(&YU;6)E<B!O9B!D87ES+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;"`@5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9R;VU$87ES*"1D87ES
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5T1G)O;5-E8V]N9',H
M<F]U;F0H)&1A>7,@*B`X-C0P,"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!S<&%N(&9R;VT@=&AE(&5L87!S960@=&EM92!B971W965N('1W
M;R!D871E<RX*("`@("`J"B`@("`@*B!3970@=&AE('-P86X@9G)O;2!T:&4@
M96QA<'-E9"!T:6UE(&)E='=E96X@='=O(&1A=&5S+B!4:&4@=&EM92!S<&%N
M"B`@("`@*B!I<R!A;&QW87ES('!O<VET:79E+"!S;R!T:&4@9&%T92=S(&]R
M9&5R(&ES(&YO="!I;7!O<G1A;G0N"B`@("`@*B`*("`@("`J($!P87)A;2`@
M;V)J96-T($1A=&4@)&1A=&4Q($9I<G-T($1A=&4N"B`@("`@*B!`<&%R86T@
M(&]B:F5C="!$871E("1D871E,B!396-O;F0@1&%T92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VP@(%1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971&<F]M
M1&%T941I9F8H)&1A=&4Q+"`D9&%T93(I"B`@("!["B`@("`@("`@:68@*"%I
M<U]A*"1D871E,2P@)V1A=&4G*2!O<B`A:7-?82@D9&%T93(L("=D871E)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("`D9&%T93$M/G1O551#*"D["B`@("`@("`@)&1A=&4R+3YT;U540R@I.PH@
M("`@("`@(&EF("@D9&%T93$M/F%F=&5R*"1D871E,BDI('L*("`@("`@("`@
M("`@;&ES="@D9&%T93$L("1D871E,BD@/2!A<G)A>2@D9&%T93(L("1D871E
M,2D["B`@("`@("`@?0H@("`@("`@("1D87ES(#T@1&%T95]#86QC.CID871E
M1&EF9B@*("`@("`@("`@("`@)&1A=&4Q+3YG971$87DH*2P@)&1A=&4Q+3YG
M971-;VYT:"@I+"`D9&%T93$M/F=E=%EE87(H*2P*("`@("`@("`@("`@)&1A
M=&4R+3YG971$87DH*2P@)&1A=&4R+3YG971-;VYT:"@I+"`D9&%T93(M/F=E
M=%EE87(H*0H@("`@("`@("D["B`@("`@("`@)&AO=7)S(#T@)&1A=&4R+3YG
M971(;W5R*"D@+2`D9&%T93$M/F=E=$AO=7(H*3L*("`@("`@("`D;6EN<R`@
M/2`D9&%T93(M/F=E=$UI;G5T92@I("T@)&1A=&4Q+3YG971-:6YU=&4H*3L*
M("`@("`@("`D<V5C<R`@/2`D9&%T93(M/F=E=%-E8V]N9"@I("T@)&1A=&4Q
M+3YG971396-O;F0H*3L*("`@("`@("`D=&AI<RT^<V5T1G)O;5-E8V]N9',H
M"B`@("`@("`@("`@("1D87ES("H@.#8T,#`@*R`D:&]U<G,@*B`S-C`P("L@
M)&UI;G,@*B`V,"`K("1S96-S"B`@("`@("`@*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@=&EM92!S<&%N
M(&9R;VT@86YO=&AE<B!T:6UE(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@(&]B:F5C="!$871E7U-P86X@)'1I;64@4V]U<F-E('1I;64@<W!A;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("`@5')U92!O;B!S
M=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-O<'DH)'1I;64I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)'1I;64L("=D871E7W-P86XG*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5C;VYD(#T@)'1I;64M/G-E8V]N9#L*("`@("`@("`@("`@)'1H:7,M/FUI
M;G5T92`]("1T:6UE+3YM:6YU=&4["B`@("`@("`@("`@("1T:&ES+3YH;W5R
M("`@/2`D=&EM92T^:&]U<CL*("`@("`@("`@("`@)'1H:7,M/F1A>2`@("`]
M("1T:6UE+3YD87D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:6UE('-P86X@<')E='1Y('!R:6YT
M:6YG("AS:6UI;&%R('1O($1A=&4Z.F9O<FUA="@I*2X*("`@("`J"B`@("`@
M*B!&;W)M871S('1H92!T:6UE('-P86X@:6X@=&AE(&=I=F5N(&9O<FUA="P@
M<VEM:6QA<B!T;PH@("`@("H@<W1R9G1I;64H*2!A;F0@1&%T93HZ9F]R;6%T
M*"DN/&)R/@H@("`@("H@/&)R/@H@("`@("H@1F]R;6%T=&EN9R!O<'1I;VYS
M.CQB<CX*("`@("`J("`\8V]D93XE0SPO8V]D93X@1&%Y<R!W:71H('1I;64L
M('-A;64@87,@(B5$+"`E2#HE33HE4R(N/&)R/@H@("`@("H@(#QC;V1E/B5D
M/"]C;V1E/B!4;W1A;"!D87ES(&%S(&$@9FQO870@;G5M8F5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("@R(&1A>7,L(#$R(&AO=7)S(#T@,BXU(&1A>7,I
M+CQB<CX*("`@("`J("`\8V]D93XE1#PO8V]D93X@1&%Y<R!A<R!A(&1E8VEM
M86P@;G5M8F5R+CQB<CX*("`@("`J("`\8V]D93XE93PO8V]D93X@5&]T86P@
M:&]U<G,@87,@82!F;&]A="!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@
M("`@*#$@9&%Y+"`R(&AO=7)S+"`S,"!M:6YU=&5S(#T@,C8N-2!H;W5R<RDN
M/&)R/@H@("`@("H@(#QC;V1E/B5%/"]C;V1E/B!4;W1A;"!H;W5R<R!A<R!A
M(&1E8VEM86P@;G5M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("@Q(&1A
M>2P@,B!H;W5R<RP@-#`@;6EN=71E<R`](#(V(&AO=7)S*2X\8G(^"B`@("`@
M*B`@/&-O9&4^)68\+V-O9&4^(%1O=&%L(&UI;G5T97,@87,@82!F;&]A="!N
M=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#(@;6EN=71E<RP@,S`@
M<V5C;VYD<R`](#(N-2!M:6YU=&5S*2X\8G(^"B`@("`@*B`@/&-O9&4^)48\
M+V-O9&4^(%1O=&%L(&UI;G5T97,@87,@82!D96-I;6%L(&YU;6)E<@H@("`@
M("H@("`@("`@("`@("`@("`@("`H,2!H;W5R+"`R(&UI;G5T97,L(#0P('-E
M8V]N9',@/2`V,B!M:6YU=&5S*2X\8G(^"B`@("`@*B`@/&-O9&4^)6<\+V-O
M9&4^(%1O=&%L('-E8V]N9',@87,@82!D96-I;6%L(&YU;6)E<@H@("`@("H@
M("`@("`@("`@("`@("`@("`H,B!M:6YU=&5S+"`S,"!S96-O;F1S(#T@.3`@
M<V5C;VYD<RDN/&)R/@H@("`@("H@(#QC;V1E/B5H/"]C;V1E/B!(;W5R<R!A
M<R!D96-I;6%L(&YU;6)E<B`H,"!T;R`R,RDN/&)R/@H@("`@("H@(#QC;V1E
M/B5(/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L(&YU;6)E<B`H,#`@=&\@,C,I
M+CQB<CX*("`@("`J("`\8V]D93XE:3PO8V]D93X@2&]U<G,@87,@9&5C:6UA
M;"!N=6UB97(@;VX@,3(M:&]U<B!C;&]C:PH@("`@("H@("`@("`@("`@("`@
M("`@("`H,2!T;R`Q,BDN/&)R/@H@("`@("H@(#QC;V1E/B5)/"]C;V1E/B!(
M;W5R<R!A<R!D96-I;6%L(&YU;6)E<B!O;B`Q,BUH;W5R(&-L;V-K"B`@("`@
M*B`@("`@("`@("`@("`@("`@("@P,2!T;R`Q,BDN/&)R/@H@("`@("H@(#QC
M;V1E/B5M/"]C;V1E/B!-:6YU=&5S(&%S(&$@9&5C:6UA;"!N=6UB97(@*#`@
M=&\@-3DI+CQB<CX*("`@("`J("`\8V]D93XE33PO8V]D93X@36EN=71E<R!A
M<R!A(&1E8VEM86P@;G5M8F5R("@P,"!T;R`U.2DN/&)R/@H@("`@("H@(#QC
M;V1E/B5N/"]C;V1E/B!.97=L:6YE(&-H87)A8W1E<B`H7&XI+CQB<CX*("`@
M("`J("`\8V]D93XE<#PO8V]D93X@16ET:&5R("=A;2<@;W(@)W!M)R!D97!E
M;F1I;F<@;VX@=&AE('1I;64N/&)R/@H@("`@("H@(#QC;V1E/B50/"]C;V1E
M/B!%:71H97(@)T%-)R!O<B`G4$TG(&1E<&5N9&EN9R!O;B!T:&4@=&EM92X\
M8G(^"B`@("`@*B`@/&-O9&4^)7(\+V-O9&4^(%1I;64@:6X@86TO<&T@;F]T
M871I;VXL('-A;64@87,@(B5).B5-.B53("5P(BX\8G(^"B`@("`@*B`@/&-O
M9&4^)5(\+V-O9&4^(%1I;64@:6X@,C0M:&]U<B!N;W1A=&EO;BP@<V%M92!A
M<R`B)4@Z)4TB+CQB<CX*("`@("`J("`\8V]D93XE<SPO8V]D93X@4V5C;VYD
M<R!A<R!A(&1E8VEM86P@;G5M8F5R("@P('1O(#4Y*2X\8G(^"B`@("`@*B`@
M/&-O9&4^)5,\+V-O9&4^(%-E8V]N9',@87,@82!D96-I;6%L(&YU;6)E<B`H
M,#`@=&\@-3DI+CQB<CX*("`@("`J("`\8V]D93XE=#PO8V]D93X@5&%B(&-H
M87)A8W1E<B`H7'0I+CQB<CX*("`@("`J("`\8V]D93XE5#PO8V]D93X@0W5R
M<F5N="!T:6UE(&5Q=6EV86QE;G0L('-A;64@87,@(B5(.B5-.B53(BX\8G(^
M"B`@("`@*B`@/&-O9&4^)24\+V-O9&4^($QI=&5R86P@)R4G+CQB<CX*("`@
M("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D9F]R;6%T(%1H92!F;W)M870@
M<W1R:6YG(&9O<B!R971U<FYE9"!T:6UE('-P86XN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@5&AE('1I;64@<W!A;B!I;B!S<&5C:69I960@9F]R
M;6%T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9O<FUA="@D9F]R;6%T(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H:7-?;G5L;"@D9F]R;6%T*2D@>PH@("`@("`@("`@("`D9F]R;6%T
M(#T@)$=,3T)!3%-;)U]$051%7U-004Y?1D]234%4)UT["B`@("`@("`@?0H@
M("`@("`@("1O=71P=70@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!S=')L96XH)&9O<FUA="D[("1I*RLI('L*("`@("`@("`@("`@)&-H87(@
M/2`D9F]R;6%T>R1I?3L*("`@("`@("`@("`@:68@*"1C:&%R(#T]("<E)RD@
M>PH@("`@("`@("`@("`@("`@)&YE>'1C:&%R(#T@)&9O<FUA='LK*R1I?3L*
M("`@("`@("`@("`@("`@('-W:71C:"`H)&YE>'1C:&%R*2!["B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G0R<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@<W!R:6YT9B@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<E9"P@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F1A>2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YH;W5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FUI;G5T92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS96-O;F0*("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M8V%S92`G9"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M)'1H:7,M/G1O1&%Y<R@I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=$)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^9&%Y.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=E)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI
M<RT^=&](;W5R<R@I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!C87-E("=%)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2!F;&]O<B@D=&AI<RT^=&](;W5R<R@I*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G9B<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@)'1H:7,M/G1O36EN=71E<R@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=&)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!F;&]O<B@D=&AI<RT^
M=&]-:6YU=&5S*"DI.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!C87-E("=G)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^=&]396-O;F1S*"D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)V@G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M("1T:&ES+3YH;W5R.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!C87-E("=()SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"<E,#)D)RP@)'1H:7,M/FAO
M=7(I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!C87-E("=I)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M)&AO=7(@/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3YH
M;W5R("L@,2D@/B`Q,B`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^:&]U<B`M(#$R(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YH;W5R.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T
M("X]("@D:&]U<B`]/2`P*2`_(#$R(#H@)&AO=7(["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)TDG
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D:&]U<B`]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`H)'1H:7,M/FAO=7(@*R`Q*2`^(#$R(#\*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R("T@,3(@.@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(["B`@("`@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@G)3`R9"<L
M("1H;W5R/3TP(#\@,3(@.B`D:&]U<BD["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YM:6YU=&4[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)TTG.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]('-P<FEN=&8H)R4P,F0G+"1T:&ES+3YM:6YU=&4I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C
M87-E("=N)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B
M7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!C87-E("=P)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2`D=&AI<RT^:&]U<B`^/2`Q,B`_("=P;2<@.B`G86TG.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!C87-E("=0)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2`D=&AI<RT^:&]U<B`^/2`Q,B`_("=032<@.B`G04TG.PH@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C
M87-E("=R)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&AO=7(@/0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3YH;W5R("L@,2D@/B`Q
M,B`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`M
M(#$R(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)3`R9#HE,#)D.B4P,F0@
M)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AO=7(]/3`@/R`@
M,3(@.B`D:&]U<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YM:6YU=&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5C;VYD+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO
M=7(@/CT@,3(@/R`G<&TG(#H@)V%M)PH@("`@("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!C87-E("=2)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2!S<')I;G1F*`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R4P,F0Z)3`R9"<L("1T:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E"B`@
M("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)W,G.@H@("`@
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YS96-O;F0[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)U,G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]('-P<FEN=&8H)R4P,F0G+"`D=&AI<RT^<V5C;VYD*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M8V%S92`G="<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M(EQT(CL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G5"<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@<W!R:6YT9B@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^:&]U<BP@)'1H:7,M/FUI;G5T92P@)'1H:7,M/G-E8V]N
M9`H@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("<E)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B)2(["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M)&-H87(@+B`D;F5X=&-H87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1C:&%R
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;W5T
M<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T:6UE('-P86X@
M=&\@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!4:6UE('-P
M86X@87,@86X@:6YT96=E<B!N=6UB97(@;V8@<V5C;VYD<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T;U-E
M8V]N9',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&%Y("H@.#8T
M,#`@*R`D=&AI<RT^:&]U<B`J(#,V,#`@*PH@("`@("`@("`@("`D=&AI<RT^
M;6EN=71E("H@-C`@*R`D=&AI<RT^<V5C;VYD.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0V]N=F5R="!T:6UE('-P86X@=&\@;6EN=71E<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&9L;V%T(%1I;64@<W!A;B!A<R!A(&1E8VEM86P@;G5M
M8F5R(&]F(&UI;G5T97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&]-:6YU=&5S*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/F1A>2`J(#$T-#`@*R`D=&AI<RT^:&]U<B`J(#8P
M("L@)'1H:7,M/FUI;G5T92`K"B`@("`@("`@("`@("1T:&ES+3YS96-O;F0@
M+R`V,#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&EM92!S<&%N
M('1O(&AO=7)S+@H@("`@("H*("`@("`J($!R971U<FX@9FQO870@5&EM92!S
M<&%N(&%S(&$@9&5C:6UA;"!N=6UB97(@;V8@:&]U<G,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&](;W5R
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD87D@*B`R-"`K("1T
M:&ES+3YH;W5R("L@)'1H:7,M/FUI;G5T92`O(#8P("L*("`@("`@("`@("`@
M)'1H:7,M/G-E8V]N9"`O(#,V,#`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYV97)T('1I;64@<W!A;B!T;R!D87ES+@H@("`@("H*("`@("`J($!R971U
M<FX@9FQO870@5&EM92!S<&%N(&%S(&$@9&5C:6UA;"!N=6UB97(@;V8@9&%Y
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!T;T1A>7,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M9&%Y("L@)'1H:7,M/FAO=7(@+R`R-"`K("1T:&ES+3YM:6YU=&4@+R`Q-#0P
M("L*("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`O(#@V-#`P.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A('1I;64@<W!A;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@(&]B:F5C="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O
M(&%D9"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&0H)'1I;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YS971&<F]M4V5C;VYD<R@*("`@("`@("`@("`@)'1H:7,M/G1O4V5C
M;VYD<R@I("L@)'1I;64M/G1O4V5C;VYD<R@I"B`@("`@("`@*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-U8G1R86-T<R!A('1I;64@<W!A;BX*("`@("`J
M"B`@("`@*B!3=6)T<F%C=',@82!T:6UE('-P86XN($EF('1H92!T:6UE('-P
M86X@=&\@<W5B=')A8W0@:7,@;&%R9V5R"B`@("`@*B!T:&%N('1H92!O<FEG
M:6YA;"P@=&AE(')E<W5L="!I<R!Z97)O("AT:&5R92=S(&YO('-E;G-E(&EN
M"B`@("`@*B!N96=A=&EV92!T:6UE('-P86YS*2X*("`@("`J"B`@("`@*B!`
M<&%R86T@(&]B:F5C="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O('-U
M8G1R86-T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-U8G1R86-T*"1T:6UE*0H@("`@>PH@("`@("`@("1S
M=6(@/2`D=&AI<RT^=&]396-O;F1S*"D@+2`D=&EM92T^=&]396-O;F1S*"D[
M"B`@("`@("`@:68@*"1S=6(@/"`P*2!["B`@("`@("`@("`@("1T:&ES+3YS
M971&<F]M4V5C;VYD<R@P*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^<V5T1G)O;5-E8V]N9',H)'-U8BD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@5&5L;',@:68@=&EM92!S<&%N(&ES(&5Q=6%L
M('1O("1T:6UE+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T($1A=&5?
M4W!A;B`D=&EM92!4:6UE('-P86X@=&\@8V]M<&%R92!T;RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VP@("!4<G5E(&EF('1H92!T:6UE('-P86YS(&%R
M92!E<75A;"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!E<75A;"@D=&EM92D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/G1O4V5C;VYD<R@I(#T]("1T:6UE+3YT;U-E8V]N9',H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%1E;&QS(&EF('1H:7,@=&EM92!S<&%N
M(&ES(&=R96%T97(@;W(@97%U86P@=&AA;B`D=&EM92X*("`@("`J"B`@("`@
M*B!`<&%R86T@(&]B:F5C="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O
M(&-O;7!A<F4@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("`@5')U
M92!I9B!T:&ES('1I;64@<W!A;B!I<R!G<F5A=&5R(&]R(&5Q=6%L('1H86X@
M)'1I;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9W)E871E<D5Q=6%L*"1T:6UE*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^=&]396-O;F1S*"D@/CT@)'1I;64M/G1O4V5C;VYD
M<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&5L;',@:68@=&AI<R!T:6UE
M('-P86X@:7,@;&]W97(@;W(@97%U86P@=&AA;B`D=&EM92X*("`@("`J"B`@
M("`@*B!`<&%R86T@(&]B:F5C="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N
M('1O(&-O;7!A<F4@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("`@
M5')U92!I9B!T:&ES('1I;64@<W!A;B!I<R!L;W=E<B!O<B!E<75A;"!T:&%N
M("1T:6UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QO=V5R17%U86PH)'1I;64I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YT;U-E8V]N9',H*2`\/2`D=&EM92T^=&]396-O;F1S
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!496QL<R!I9B!T:&ES('1I;64@
M<W!A;B!I<R!G<F5A=&5R('1H86X@)'1I;64N"B`@("`@*@H@("`@("H@0'!A
M<F%M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE(%1I;64@<W!A;B!T;R!C;VUP
M87)E('1O+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@(%1R=64@:68@
M=&AI<R!T:6UE('-P86X@:7,@9W)E871E<B!T:&%N("1T:6UE+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=R
M96%T97(H)'1I;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT;U-E
M8V]N9',H*2`^("1T:6UE+3YT;U-E8V]N9',H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1E;&QS(&EF('1H:7,@=&EM92!S<&%N(&ES(&QO=V5R('1H86X@
M)'1I;64N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N
M("1T:6UE(%1I;64@<W!A;B!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;"`@(%1R=64@:68@=&AI<R!T:6UE('-P86X@:7,@;&]W
M97(@=&AA;B`D=&EM92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!L;W=E<B@D=&EM92D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G1O4V5C;VYD<R@I(#P@)'1I;64M/G1O4V5C;VYD
M<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]M<&%R97,@='=O('1I;64@
M<W!A;G,N"B`@("`@*@H@("`@("H@0V]M<&%R97,@='=O('1I;64@<W!A;G,N
M(%-U:71A8FQE(&9O<B!U<V4@:6X@<V]R=&EN9R!F=6YC=&EO;G,N"B`@("`@
M*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE,2!4:&4@
M9FER<W0@=&EM92!S<&%N+@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3
M<&%N("1T:6UE,B!4:&4@<V5C;VYD('1I;64@<W!A;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@("`P(&EF('1H92!T:6UE('-P86YS(&%R92!E<75A
M;"P@+3$@:68@=&EM93$@:7,@;&]W97(*("`@("`J("`@("`@("`@("`@("`@
M('1H86X@=&EM93(L(#$@:68@=&EM93$@:7,@9W)E871E<B!T:&%N('1I;64R
M+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;7!A<F4H)'1I;64Q+"`D=&EM93(I
M"B`@("!["B`@("`@("`@:68@*"1T:6UE,2T^97%U86PH)'1I;64R*2D@>PH@
M("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!](&5L<V5I9B`H)'1I;64Q
M+3YL;W=E<B@D=&EM93(I*2!["B`@("`@("`@("`@(')E='5R;B`M,3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!496QL<R!I9B!T:&4@=&EM92!S<&%N
M(&ES(&5M<'1Y("AZ97)O(&QE;F=T:"DN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L(%1R=64@:7,@:70G<R!E;7!T>2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-%;7!T>2@I"B`@("!["B`@("`@("`@<F5T=7)N("$D=&AI<RT^9&%Y
M("8F("$D=&AI<RT^:&]U<B`F)B`A)'1H:7,M/FUI;G5T92`F)B`A)'1H:7,M
M/G-E8V]N9#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@9&5F875L
M="!I;G!U="!F;W)M870N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9"`D
M9F]R;6%T($YE=R!D969A=6QT(&EN<'5T(&9O<FUA="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%!R979I;W5S(&1E9F%U;'0@:6YP=70@9F]R;6%T
M+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T1&5F875L=$EN<'5T1F]R;6%T*"1F;W)M870I"B`@("!["B`@("`@("`@
M)&]L9"`]("1'3$]"04Q36R=?1$%415]34$%.7TE.4%547T9/4DU!5"==.PH@
M("`@("`@("1'3$]"04Q36R=?1$%415]34$%.7TE.4%547T9/4DU!5"==(#T@
M)&9O<FUA=#L*("`@("`@("!R971U<FX@)&]L9#L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!T:&4@9&5F875L="!I;G!U="!F;W)M870N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"!$969A=6QT(&EN<'5T(&9O<FUA="X*("`@
M("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E
M9F%U;'1);G!U=$9O<FUA="@I"B`@("!["B`@("`@("`@<F5T=7)N("1'3$]"
M04Q36R=?1$%415]34$%.7TE.4%547T9/4DU!5"==.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T('1H92!D969A=6QT(&9O<FUA="X*("`@("`J"B`@("`@
M*B!`<&%R86T@(&UI>&5D("1F;W)M870@3F5W(&1E9F%U;'0@9F]R;6%T+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@4')E=FEO=7,@9&5F875L="!F
M;W)M870N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!S971$969A=6QT1F]R;6%T*"1F;W)M870I"B`@("!["B`@("`@("`@
M)&]L9"`]("1'3$]"04Q36R=?1$%415]34$%.7T9/4DU!5"==.PH@("`@("`@
M("1'3$]"04Q36R=?1$%415]34$%.7T9/4DU!5"==(#T@)&9O<FUA=#L*("`@
M("`@("!R971U<FX@)&]L9#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@9&5F875L="!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!$969A=6QT(&9O<FUA="X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1&;W)M870H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D1TQ/0D%,4ULG7T1!5$5?4U!!3E]&3U)-050G73L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!C;W!Y(&]F('1H92!O8FIE
M8W0@*'=O<FMA<G)O=6YD(&9O<B!02%`U(&9O<G=A<F0@8V]M<&%T:6)I;&ET
M>2DN"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@1&%T95]3<&%N($-O
M<'D@;V8@=&AE(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@7U]C;&]N
M92@I('L*("`@("`@("`D8R`](&=E=%]C;&%S<R@D=&AI<RD["B`@("`@("`@
M)',@/2!N97<@)&,["B`@("`@("`@)',M/F1A>2`@("`]("1T:&ES+3YD87D[
M"B`@("`@("`@)',M/FAO=7(@("`]("1T:&ES+3YH;W5R.PH@("`@("`@("1S
M+3YM:6YU=&4@/2`D=&AI<RT^;6EN=71E.PH@("`@("`@("1S+3YS96-O;F0@
M/2`D=&AI<RT^<V5C;VYD.PH@("`@("`@(')E='5R;B`D<SL*("`@('T*?0H*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1A=&4O
M5&EM95IO;F4N<&AP````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,S8P,C8Q`#$P-#$W,S8S,#`W`#`R,#0W,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S
M.B!"86)A($)U96AL97(@/&)A8F%`8F%B87HN8V]M/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED
M.B!4:6UE6F]N92YP:'`L=B`Q+C,@,C`P,R\P,2\P-"`Q,3HU-#HU-"!M:B!%
M>'`@)`HO+PHO+R!$871E7U1I;65:;VYE($-L87-S"B\O"@HO*BH*("H@5&EM
M95IO;F4@<F5P<F5S96YT871I;VX@8VQA<W,L(&%L;VYG('=I=&@@=&EM92!Z
M;VYE(&EN9F]R;6%T:6]N(&1A=&$N"B`J"B`J(%1I;65:;VYE(')E<')E<V5N
M=&%T:6]N(&-L87-S+"!A;&]N9R!W:71H('1I;64@>F]N92!I;F9O<FUA=&EO
M;B!D871A+@H@*B!4:&4@9&5F875L="!T:6UE>F]N92!I<R!S970@9G)O;2!T
M:&4@9FER<W0@=F%L:60@=&EM97IO;F4@:60@9F]U;F0*("H@:6X@;VYE(&]F
M('1H92!F;VQL;W=I;F<@<&QA8V5S+"!I;B!T:&ES(&]R9&5R.B`\8G(^"B`J
M(#$I(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$5&055,5#QB<CX*("H@,BD@
M<WES=&5M(&5N=FER;VYM96YT('9A<FEA8FQE(%!(4%]46CQB<CX*("H@,RD@
M<WES=&5M(&5N=FER;VYM96YT('9A<FEA8FQE(%1:/&)R/@H@*B`T*2!T:&4@
M<F5S=6QT(&]F(&1A=&4H)U0G*3QB<CX*("H@268@;F\@=F%L:60@=&EM97IO
M;F4@:60@:7,@9F]U;F0L('1H92!D969A=6QT('1I;65Z;VYE(&ES('-E="!T
M;R`G551#)RX*("H@66]U(&UA>2!A;'-O(&UA;G5A;&QY('-E="!T:&4@9&5F
M875L="!T:6UE>F]N92!B>2!P87-S:6YG(&$@=F%L:60@:60@=&\*("H@1&%T
M95]4:6UE6F]N93HZ<V5T1&5F875L="@I+CQB<CX*("H*("H@5&AI<R!C;&%S
M<R!I;F-L=61E<R!T:6UE('IO;F4@9&%T82`H9G)O;2!Z;VYE:6YF;RD@:6X@
M=&AE(&9O<FT@;V8@82!G;&]B86P@87)R87DL("1?1$%415]424U%6D].15]$
M051!+@H@*@H@*@H@*B!`875T:&]R($)A8F$@0G5E:&QE<B`\8F%B84!B86)A
M>BYC;VT^"B`J($!P86-K86=E($1A=&4*("H@0&%C8V5S<R!P=6)L:6,*("H@
M0'9E<G-I;VX@,2XP"B`J+PIC;&%S<R!$871E7U1I;65:;VYE"GL*("`@("\J
M*@H@("`@("H@5&EM92!:;VYE($E$(&]F('1H:7,@=&EM92!Z;VYE"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&ED.PH@("`@+RHJ"B`@
M("`@*B!,;VYG($YA;64@;V8@=&AI<R!T:6UE('IO;F4@*&EE($-E;G1R86P@
M4W1A;F1A<F0@5&EM92D*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D;&]N9VYA;64["B`@("`O*BH*("`@("`J(%-H;W)T($YA;64@;V8@
M=&AI<R!T:6UE('IO;F4@*&EE($-35"D*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D<VAO<G1N86UE.PH@("`@+RHJ"B`@("`@*B!T<G5E
M(&EF('1H:7,@=&EM92!Z;VYE(&]B<V5R=F5S(&1A>6QI9VAT('-A=FEN9W,@
M=&EM90H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D:&%S
M9'-T.PH@("`@+RHJ"B`@("`@*B!$4U0@3&]N9R!.86UE(&]F('1H:7,@=&EM
M92!Z;VYE"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1S
M=&QO;F=N86UE.PH@("`@+RHJ"B`@("`@*B!$4U0@4VAO<G0@3F%M92!O9B!T
M:&ES('1I;65Z;VYE"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)&1S='-H;W)T;F%M93L*("`@("\J*@H@("`@("H@;V9F<V5T+"!I;B!M
M:6QL:7-E8V]N9',L(&]F('1H:7,@=&EM97IO;F4*("`@("`J($!V87(@:6YT
M"B`@("`@*B\*("`@('9A<B`D;V9F<V5T.PH*("`@("\J*@H@("`@("H@4WES
M=&5M($1E9F%U;'0@5&EM92!:;VYE"B`@("`@*B!`=F%R(&]B:F5C="!$871E
M7U1I;65:;VYE"B`@("`@*B\*("`@('9A<B`D9&5F875L=#L*"@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($-R96%T97,@82!N
M97<@1&%T93HZ5&EM95IO;F4@;V)J96-T+"!R97!R97-E;G1I;F<@=&AE('1I
M;64@>F]N90H@("`@("H@<W!E8VEF:65D(&EN("1I9"X@($EF('1H92!S=7!P
M;&EE9"!)1"!I<R!I;G9A;&ED+"!T:&4@8W)E871E9`H@("`@("H@=&EM92!Z
M;VYE(&ES(%540RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@=&AE('1I;64@>F]N92!I9`H@("`@("H@
M0')E='5R;B!O8FIE8W0@1&%T95]4:6UE6F]N92!T:&4@;F5W($1A=&5?5&EM
M95IO;F4@;V)J96-T"B`@("`@*B\*("`@(&9U;F-T:6]N($1A=&5?5&EM95IO
M;F4H)&ED*0H@("`@>PH@("`@("`@(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?
M1$%403L*("`@("`@("!I9BA$871E7U1I;65:;VYE.CII<U9A;&ED240H)&ED
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^:60@/2`D:60["B`@("`@("`@("`@
M("1T:&ES+3YL;VYG;F%M92`]("1?1$%415]424U%6D].15]$051!6R1I9%U;
M)VQO;F=N86UE)UT["B`@("`@("`@("`@("1T:&ES+3YS:&]R=&YA;64@/2`D
M7T1!5$5?5$E-15I/3D5?1$%405LD:61=6R=S:&]R=&YA;64G73L*("`@("`@
M("`@("`@)'1H:7,M/F]F9G-E="`]("1?1$%415]424U%6D].15]$051!6R1I
M9%U;)V]F9G-E="==.PH@("`@("`@("`@("!I9B@D7T1!5$5?5$E-15I/3D5?
M1$%405LD:61=6R=H87-D<W0G72D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FAA<V1S="`]('1R=64["B`@("`@("`@("`@("`@("`D=&AI<RT^9'-T;&]N
M9VYA;64@/2`D7T1!5$5?5$E-15I/3D5?1$%405LD:61=6R=D<W1L;VYG;F%M
M92==.PH@("`@("`@("`@("`@("`@)'1H:7,M/F1S='-H;W)T;F%M92`]("1?
M1$%415]424U%6D].15]$051!6R1I9%U;)V1S='-H;W)T;F%M92==.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FAA<V1S
M="`](&9A;'-E.PH@("`@("`@("`@("`@("`@)'1H:7,M/F1S=&QO;F=N86UE
M(#T@)'1H:7,M/FQO;F=N86UE.PH@("`@("`@("`@("`@("`@)'1H:7,M/F1S
M='-H;W)T;F%M92`]("1T:&ES+3YS:&]R=&YA;64["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^:60@/2`G551#
M)SL*("`@("`@("`@("`@)'1H:7,M/FQO;F=N86UE(#T@)%]$051%7U1)345:
M3TY%7T1!5$%;)'1H:7,M/FED75LG;&]N9VYA;64G73L*("`@("`@("`@("`@
M)'1H:7,M/G-H;W)T;F%M92`]("1?1$%415]424U%6D].15]$051!6R1T:&ES
M+3YI9%U;)W-H;W)T;F%M92==.PH@("`@("`@("`@("`D=&AI<RT^:&%S9'-T
M(#T@)%]$051%7U1)345:3TY%7T1!5$%;)'1H:7,M/FED75LG:&%S9'-T)UT[
M"B`@("`@("`@("`@("1T:&ES+3YO9F9S970@/2`D7T1!5$5?5$E-15I/3D5?
M1$%405LD=&AI<RT^:61=6R=O9F9S970G73L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@82!4:6UE6F]N92!O8FIE8W0@<F5P<F5S
M96YT:6YG('1H92!S>7-T96T@9&5F875L="!T:6UE('IO;F4*("`@("`J"B`@
M("`@*B!2971U<FX@82!4:6UE6F]N92!O8FIE8W0@<F5P<F5S96YT:6YG('1H
M92!S>7-T96T@9&5F875L="!T:6UE('IO;F4L"B`@("`@*B!W:&EC:"!I<R!I
M;FET:6%L:7IE9"!D=7)I;F<@=&AE(&QO861I;F<@;V8@5&EM95IO;F4N<&AP
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="!$871E7U1I;65:;VYE('1H92!D969A=6QT('1I;64@>F]N90H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT*"D*("`@('L*("`@("`@
M("!G;&]B86P@)&1E9F%U;'0["B`@("`@("`@<F5T=7)N(&YE=R!$871E7U1I
M;65:;VYE*"1D969A=6QT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE('-Y<W1E;2!D969A=6QT('1I;64@>F]N92!T;R!T:&4@=&EM92!Z;VYE
M(&EN("1I9`H@("`@("H*("`@("`J(%-E=',@=&AE('-Y<W1E;2!D969A=6QT
M('1I;64@>F]N92!T;R!T:&4@=&EM92!Z;VYE(&EN("1I9`H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"!T
M:&4@=&EM92!Z;VYE(&ED('1O('5S90H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971$969A=6QT*"1I9"D*("`@('L*("`@("`@("!G;&]B86P@)&1E9F%U;'0[
M"B`@("`@("`@:68H1&%T95]4:6UE6F]N93HZ:7-686QI9$E$*"1I9"DI('L*
M("`@("`@("`@("`@)&1E9F%U;'0@/2`D:60["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@5&5S=',@:68@9VEV96X@:60@:7,@<F5P<F5S96YT
M960@:6X@=&AE("1?1$%415]424U%6D].15]$051!('1I;64@>F]N92!D871A
M"B`@("`@*@H@("`@("H@5&5S=',@:68@9VEV96X@:60@:7,@<F5P<F5S96YT
M960@:6X@=&AE("1?1$%415]424U%6D].15]$051!('1I;64@>F]N92!D871A
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED('1H92!I9"!T;R!T97-T"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@=')U92!I9B!T:&4@<W5P<&QI960@240@:7,@=F%L:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-686QI9$E$*"1I9"D*("`@('L*("`@("`@("!G;&]B
M86P@)%]$051%7U1)345:3TY%7T1!5$$["B`@("`@("`@:68H:7-S970H)%]$
M051%7U1)345:3TY%7T1!5$%;)&ED72DI('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H:7,@
M=&EM92!Z;VYE(&5Q=6%L('1O(&%N;W1H97(*("`@("`J"B`@("`@*B!497-T
M<R!T;R!S964@:68@=&AI<R!T:6UE('IO;F4@:7,@97%U86P@*&ED<R!M871C
M:"D*("`@("`J('1O(&$@9VEV96X@1&%T95]4:6UE6F]N92!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE
M8W0@1&%T95]4:6UE6F]N92`D='H@=&AE('1I;65Z;VYE('1O('1E<W0*("`@
M("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@=&EM92!Z;VYE(&ES
M(&5Q=6%L('1O('1H92!S=7!P;&EE9"!T:6UE('IO;F4*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-%<75A;"@D='HI"B`@("!["B`@("`@("`@:68H<W1R8V%S
M96-M<"@D=&AI<RT^:60L("1T>BT^:60I(#T](#`I('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($ES
M('1H:7,@=&EM92!Z;VYE(&5Q=6EV86QE;G0@=&\@86YO=&AE<@H@("`@("H*
M("`@("`J(%1E<W1S('1O('-E92!I9B!T:&ES('1I;64@>F]N92!I<R!E<75I
M=F%L96YT('1O"B`@("`@*B!A(&=I=F5N('1I;64@>F]N92!O8FIE8W0N("!%
M<75I=F%L96YC92!I;B!T:&ES(&-O;G1E>'0*("`@("`J(&ES(&1E9FEN960@
M8GD@=&AE('1W;R!T:6UE('IO;F5S(&AA=FEN9R!A;B!E<75A;"!R87<*("`@
M("`J(&]F9G-E="!A;F0@86X@97%U86P@<V5T=&EN9R!O9B`B:&%S9'-T(BX@
M(%1H:7,@:7,@;F]T('1R=64*("`@("`J(&5Q=6EV86QE;F-E+"!A<R!T:&4@
M='=O('1I;64@>F]N97,@;6%Y(&AA=F4@9&EF9F5R96YT(')U;&5S"B`@("`@
M*B!F;W(@=&AE(&]B<V5R=F%N8V4@;V8@1%-4+"!B=70@=&AI<R!I;7!L96UE
M;G1A=&EO;B!D;V5S(&YO=`H@("`@("H@:VYO=R!$4U0@<G5L97,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@
M1&%T95]4:6UE6F]N92`D='H@=&AE('1I;65Z;VYE(&]B:F5C="!T;R!T97-T
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@=')U92!I9B!T:&ES('1I;64@>F]N
M92!I<R!E<75I=F%L96YT('1O('1H92!S=7!P;&EE9"!T:6UE('IO;F4*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-%<75I=F%L96YT*"1T>BD*("`@('L*("`@
M("`@("!I9B@D=&AI<RT^;V9F<V5T(#T]("1T>BT^;V9F<V5T("8F("1T:&ES
M+3YH87-D<W0@/3T@)'1Z+3YH87-D<W0I('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=')U92!I9B!T:&ES('IO;F4@;V)S97)V97,@9&%Y;&EG:'0@<V%V:6YG<R!T
M:6UE"B`@("`@*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF('1H:7,@>F]N92!O
M8G-E<G9E<R!D87EL:6=H="!S879I;F=S('1I;64*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@
M=&AI<R!T:6UE('IO;F4@:&%S($135`H@("`@("HO"B`@("!F=6YC=&EO;B!H
M87-$87EL:6=H=%1I;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M:&%S9'-T.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&=I=F5N(&1A
M=&4O=&EM92!I;B!$4U0@9F]R('1H:7,@=&EM92!Z;VYE"B`@("`@*@H@("`@
M("H@071T96UP=',@=&\@9&5T97)M:6YE(&EF(&$@9VEV96X@1&%T92!O8FIE
M8W0@<F5P<F5S96YT<R!A(&1A=&4O=&EM90H@("`@("H@=&AA="!I<R!I;B!$
M4U0@9F]R('1H:7,@=&EM92!Z;VYE+B`@5T%23DE.1U,Z('1H:7,@8F%S:6-A
M;&QY(&%T=&5M<'1S('1O"B`@("`@*B`B=')I8VLB('1H92!S>7-T96T@:6YT
M;R!T96QL:6YG('5S(&EF('=E)W)E(&EN($135"!F;W(@82!G:79E;B!T:6UE
M('IO;F4N"B`@("`@*B!4:&ES('5S97,@<'5T96YV*"D@=VAI8V@@;6%Y(&YO
M="!W;W)K(&EN('-A9F4@;6]D92P@86YD(')E;&EE<R!O;B!U;FEX('1I;64*
M("`@("`J('=H:6-H(&ES(&]N;'D@=F%L:60@9F]R(&1A=&5S(&9R;VT@,3DW
M,"!T;R!^,C`S."X@(%1H:7,@<F5L:65S(&]N('1H90H@("`@("H@=6YD97)L
M>6EN9R!/4R!C86QL<RP@<V\@:70@;6%Y(&YO="!W;W)K(&]N(%=I;F1O=W,@
M;W(@;VX@82!S>7-T96T@=VAE<F4*("`@("`J('IO;F5I;F9O(&ES(&YO="!I
M;G-T86QL960@;W(@8V]N9FEG=7)E9"!P<F]P97)L>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E("1D
M871E('1H92!D871E+W1I;64@=&\@=&5S=`H@("`@("H@0')E='5R;B!B;V]L
M96%N('1R=64@:68@=&AI<R!D871E(&ES(&EN($135"!F;W(@=&AI<R!T:6UE
M('IO;F4*("`@("`J+PH@("`@9G5N8W1I;VX@:6Y$87EL:6=H=%1I;64H)&1A
M=&4I"B`@("!["B`@("`@("`@)&5N=E]T>B`]("(B.PH@("`@("`@(&EF*&=E
M=&5N=B@B5%HB*2D@>PH@("`@("`@("`@("`D96YV7W1Z(#T@9V5T96YV*")4
M6B(I.PH@("`@("`@('T*("`@("`@("!P=71E;G8H(E1:/2(N)'1H:7,M/FED
M*3L*("`@("`@("`D;'1I;64@/2!L;V-A;'1I;64H)&1A=&4M/F=E=%1I;64H
M*2P@=')U92D["B`@("`@("`@<'5T96YV*")46CTB+B1E;G9?='HI.PH@("`@
M("`@(')E='5R;B`D;'1I;65;)W1M7VES9'-T)UT["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@=&AE($135"!O9F9S970@9F]R('1H:7,@=&EM92!Z;VYE
M"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@1%-4(&]F9G-E="!O9B!T:&ES
M('1I;64@>F]N92P@:6X@;6EL;&ES96-O;F1S+`H@("`@("H@:68@=&AE('IO
M;F4@;V)S97)V97,@1%-4+"!Z97)O(&]T:&5R=VES92X@($-U<G)E;G1L>2!T
M:&4*("`@("`J($135"!O9F9S970@:7,@:&%R9"UC;V1E9"!T;R!O;F4@:&]U
M<BX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R
M;B!I;G0@=&AE($135"!O9F9S970L(&EN(&UI;&QI<V5C;VYD<R!O<B!Z97)O
M(&EF('1H92!Z;VYE(&1O97,@;F]T(&]B<V5R=F4@1%-4"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$135%-A=FEN9W,H*0H@("`@>PH@("`@("`@(&EF*"1T
M:&ES+3YH87-D<W0I('L*("`@("`@("`@("`@<F5T=7)N(#,V,#`P,#`["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!$4U0M8V]R<F5C=&5D
M(&]F9G-E="!T;R!55$,@9F]R('1H92!G:79E;B!D871E"B`@("`@*@H@("`@
M("H@071T96UP=',@=&\@9V5T('1H92!O9F9S970@=&\@551#(&9O<B!A(&=I
M=F5N(&1A=&4O=&EM92P@=&%K:6YG(&EN=&\*("`@("`J(&%C8V]U;G0@9&%Y
M;&EG:'0@<V%V:6YG<R!T:6UE+"!I9B!T:&4@=&EM92!Z;VYE(&]B<V5R=F5S
M(&ET(&%N9"!I9@H@("`@("H@:70@:7,@:6X@969F96-T+B`@4&QE87-E('-E
M92!T:&4@5T%23DE.1U,@;VX@1&%T93HZ5&EM95IO;F4Z.FEN1&%Y;&EG:'14
M:6UE*"DN"B`@("`@*@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<&%R86T@;V)J96-T($1A=&4@)&1A=&4@=&AE($1A=&4@=&\@=&5S
M=`H@("`@("H@0')E='5R;B!I;G0@=&AE(&-O<G)E8W1E9"!O9F9S970@=&\@
M551#(&EN(&UI;&QI<V5C;VYD<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971/
M9F9S970H)&1A=&4I"B`@("!["B`@("`@("`@:68H)'1H:7,M/FEN1&%Y;&EG
M:'14:6UE*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]F
M9G-E="`K("1T:&ES+3YG971$4U13879I;F=S*"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9F9S970["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&ES="!O9B!V
M86QI9"!T:6UE('IO;F4@:60@<W1R:6YG<PH@("`@("H*("`@("`J(%)E='5R
M;G,@=&AE(&QI<W0@;V8@=F%L:60@=&EM92!Z;VYE(&ED('-T<FEN9W,*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!M:7AE
M9"!A;B!A<G)A>2!O9B!S=')I;F=S('=I=&@@=&AE('9A;&ED('1I;64@>F]N
M92!)1',*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T079A:6QA8FQE241S*"D*
M("`@('L*("`@("`@("!G;&]B86P@)%]$051%7U1)345:3TY%7T1!5$$["B`@
M("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)%]$051%7U1)345:3TY%7T1!5$$I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:60@9F]R('1H
M:7,@=&EM92!Z;VYE"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@=&EM92!Z
M;VYE(&ED("!F;W(@=&AI<R!T:6UE('IO;F4L(&DN92X@(D%M97)I8V$O0VAI
M8V%G;R(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E
M='5R;B!S=')I;F<@=&AE(&ED"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$E$
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FED.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&]N9R!N86UE(&9O<B!T:&ES('1I
M;64@>F]N90H@("`@("H*("`@("`J(%)E='5R;G,@=&AE(&QO;F<@;F%M92!F
M;W(@=&AI<R!T:6UE('IO;F4L"B`@("`@*B!I+F4N(")#96YT<F%L(%-T86YD
M87)D(%1I;64B"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@<W1R:6YG('1H92!L;VYG(&YA;64*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T3&]N9TYA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^;&]N9VYA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!S:&]R="!N86UE(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*("`@("`J
M(%)E='5R;G,@=&AE('-H;W)T(&YA;64@9F]R('1H:7,@=&EM92!Z;VYE+"!I
M+F4N(")#4U0B"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@<W1R:6YG('1H92!S:&]R="!N86UE"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-H;W)T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YS:&]R=&YA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!$4U0@;&]N9R!N86UE(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*
M("`@("`J(%)E='5R;G,@=&AE($135"!L;VYG(&YA;64@9F]R('1H:7,@=&EM
M92!Z;VYE+"!I+F4N(")#96YT<F%L($1A>6QI9VAT(%1I;64B"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@<W1R:6YG('1H
M92!D87EL:6=H="!S879I;F=S('1I;64@;&]N9R!N86UE"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$135$QO;F=.86UE*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/F1S=&QO;F=N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@1%-4('-H;W)T(&YA;64@9F]R('1H:7,@=&EM92!Z;VYE
M"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@1%-4('-H;W)T(&YA;64@9F]R
M('1H:7,@=&EM92!Z;VYE+"!I+F4N(")#1%0B"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@<W1R:6YG('1H92!D87EL:6=H
M="!S879I;F=S('1I;64@<VAO<G0@;F%M90H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$4U13:&]R=$YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^9'-T<VAO<G1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@<F%W("AN;VXM1%-4+6-O<G)E8W1E9"D@;V9F<V5T(&9R;VT@551#
M+T=-5"!F;W(@=&AI<R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS
M('1H92!R87<@*&YO;BU$4U0M8V]R<F5C=&5D*2!O9F9S970@9G)O;2!55$,O
M1TU4(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@;V9F<V5T+"!I;B!M:6QL
M:7-E8V]N9',*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F%W3V9F<V5T*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F]F9G-E=#L*("`@('T*"GT@
M+R\@1&%T95]4:6UE6F]N90H*"B\O"B\O(%1I;64@6F]N92!$871A"B\O("!O
M9F9S970@:7,@:6X@;6EL:7-E8V]N9',*+R\*)$=,3T)!3%-;)U]$051%7U1)
M345:3TY%7T1!5$$G72`](&%R<F%Y*`H@("`@)T5T8R]'350K,3(G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TT,S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")'350M,3(Z,#`B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350M,3(Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G171C+T=-5"LQ,2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=-5"TQ,3HP
M,"(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TQ,3HP,"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-250G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")797-T(%-A;6]A(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=74U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M4&%C:69I8R]!<&EA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B5V5S="!386UO82!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O36ED=V%Y)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B4V%M;V$@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=086-I9FEC+TYI=64G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(").
M:75E(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.550G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]086=O7U!A
M9V\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^(")386UO82!3=&%N9&%R9"!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O4V%M;V$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")386UO82!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G4U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U53+U-A;6]A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4V%M;V$@4W1A;F1A
M<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T%D86LG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")(87=A:6DM06QE=71I86X@4W1A;F1A<F0@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA!4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B2&%W
M86EI+4%L975T:6%N($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=(0414)R`I+`H@("`@)T%M97)I8V$O071K82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(DAA=V%I:2U!;&5U=&EA;B!3=&%N9&%R9"!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G2$%35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")(87=A:6DM
M06QE=71I86X@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)TA!1%0G("DL"B`@("`G171C+T=-5"LQ,"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D=-5"TQ,#HP,"(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"TQ,#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=(
M4U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^(")(87=A:6D@4W1A;F1A<F0@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T9A:V%O9F\G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")4;VME;&%U(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=42U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M4&%C:69I8R](;VYO;'5L=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(DAA=V%I:2!3
M=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2%-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O2F]H
M;G-T;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")(87=A:6D@4W1A;F1A<F0@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U)A<F]T;VYG82<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(D-O;VL@27,N(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#2U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4&%C:69I8R]486AI=&DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")486AI
M=&D@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1!2%0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B](4U0Q,"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@(DAA=V%I:2!3=&%N9&%R9"!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G2%-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U53+T%L975T:6%N)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`B2&%W86EI+4%L975T:6%N(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=(05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DAA=V%I:2U!;&5U=&EA;B!$
M87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G2$%$
M5"<@*2P*("`@("=54R](87=A:6DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")(87=A
M:6D@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC
M+TUA<G%U97-A<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,T
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(DUA<G%U97-A<R!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34%25"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!4U0G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")!;&%S:V$@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%+4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`B06QA<VMA($1A>6QI9VAT(%1I;64B+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=!2T14)R`I+`H@("`@)T%M97)I8V$O
M06YC:&]R86=E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B06QA<VMA(%-T86YD87)D
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!2U-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(D%L87-K82!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G04M$5"<@*2P*("`@("=!;65R:6-A+TIU;F5A=2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D%L87-K82!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G04M35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")!;&%S:V$@1&%Y;&EG:'0@5&EM
M92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G
M06UE<FEC82].;VUE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B06QA<VMA(%-T86YD
M87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!2U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@(D%L87-K82!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G04M$5"<@*2P*("`@("=!;65R:6-A+UEA:W5T870G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")!;&%S:V$@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B06QA<VMA($1A>6QI9VAT
M(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!2T14)R`I+`H@
M("`@)T5T8R]'350K.2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=-5"TP.3HP,"(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP.3HP,"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T=A;6)I97(G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")'86UB:65R(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='04U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U-Y<W1E;58O65-4.2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=A;6)I
M97(@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=!350G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]94U0Y6414
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B06QA<VMA(%-T86YD87)D(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=!2U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D%L87-K82!$
M87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04M$
M5"<@*2P*("`@("=54R]!;&%S:V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!;&%S
M:V$@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%+
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`B06QA<VMA($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=!2T14)R`I+`H@("`@)T%M97)I8V$O1&%W<V]N
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B4&%C:69I8R!3=&%N9&%R9"!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(E!A8VEF:6,@
M1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$
M5"<@*2P*("`@("=!;65R:6-A+T5N<V5N861A)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`B4&%C:69I8R!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@(E!A8VEF:6,@1&%Y;&EG:'0@5&EM92(L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("=!;65R:6-A
M+TQO<U]!;F=E;&5S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4&%C:69I8R!3=&%N
M9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@(E!A8VEF:6,@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)U!$5"<@*2P*("`@("=!;65R:6-A+U1I:G5A;F$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")086-I9FEC(%-T86YD87)D(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B4&%C:69I8R!$87EL:6=H
M="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@
M("`@)T%M97)I8V$O5F%N8V]U=F5R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4&%C
M:69I8R!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(E!A8VEF:6,@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("=!;65R:6-A+U=H:71E
M:&]R<V4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")086-I9FEC(%-T86YD87)D(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B4&%C
M:69I8R!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G4$14)R`I+`H@("`@)T-A;F%D82]086-I9FEC)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B4&%C:69I8R!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@(E!A8VEF:6,@1&%Y;&EG:'0@5&EM92(L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("=#86YA
M9&$O675K;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")086-I9FEC(%-T86YD87)D
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B
M4&%C:69I8R!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G4$14)R`I+`H@("`@)T5T8R]'350K."<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(D=-5"TP.#HP,"(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP
M.#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-97AI
M8V\O0F%J84YO<G1E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4&%C:69I8R!3=&%N
M9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@(E!A8VEF:6,@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)U!$5"<@*2P*("`@("=04U0G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")086-I9FEC(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`B4&%C:69I8R!$87EL:6=H="!4:6UE(BP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)U!35#A01%0G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")086-I9FEC(%-T86YD87)D(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B4&%C:69I8R!$
M87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14
M)R`I+`H@("`@)U!A8VEF:6,O4&ET8V%I<FXG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")0:71C86ER;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U-Y<W1E;58O4%-4."<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E!I=&-A:7)N(%-T
M86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]04U0X
M4$14)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4&%C:69I8R!3=&%N9&%R9"!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(E!A8VEF
M:6,@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)U!$5"<@*2P*("`@("=54R]086-I9FEC)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M4&%C:69I8R!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@(E!A8VEF:6,@1&%Y;&EG:'0@5&EM92(L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("=54R]086-I9FEC
M+4YE=R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E!A8VEF:6,@4W1A;F1A<F0@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")086-I
M9FEC($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=01%0G("DL"B`@("`G06UE<FEC82]";VES92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(DUO=6YT86EN(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`B36]U;G1A:6X@1&%Y;&EG:'0@5&EM92(L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=!;65R
M:6-A+T-A;6)R:61G95]"87DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")-;W5N=&%I
M;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@(DUO=6YT86EN($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@("`G06UE<FEC82]#:&EH=6%H
M=6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^(")-;W5N=&%I;B!3=&%N9&%R9"!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DUO=6YT
M86EN($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=-1%0G("DL"B`@("`G06UE<FEC82]$87=S;VY?0W)E96LG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")-;W5N=&%I;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%M97)I8V$O1&5N=F5R)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M36]U;G1A:6X@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^(")-;W5N=&%I;B!$87EL:6=H="!4:6UE(BP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O
M161M;VYT;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")-;W5N=&%I;B!3=&%N9&%R
M9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(DUO=6YT86EN($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=-1%0G("DL"B`@("`G06UE<FEC82](97)M;W-I;&QO)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B36]U;G1A:6X@4W1A;F1A<F0@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!;65R:6-A+TEN=79I:R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(DUO=6YT86EN(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`B36]U;G1A:6X@1&%Y;&EG:'0@5&EM92(L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=!;65R
M:6-A+TUA>F%T;&%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B36]U;G1A:6X@4W1A
M;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")-;W5N=&%I;B!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O4&AO96YI>"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(DUO=6YT86EN(%-T86YD87)D(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G06UE<FEC82]3:&EP<F]C:R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(DUO=6YT86EN(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`B36]U;G1A:6X@1&%Y;&EG:'0@5&EM
M92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=!
M;65R:6-A+UEE;&QO=VMN:69E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B36]U;G1A
M:6X@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^(")-;W5N=&%I;B!$87EL:6=H="!4:6UE(BP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T-A;F%D82]-;W5N=&%I
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(DUO=6YT86EN(%-T86YD87)D(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B36]U;G1A
M:6X@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)TU$5"<@*2P*("`@("=%=&,O1TU4*S<G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'
M350M,#<Z,#`B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#<Z,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G35-4)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B36]U;G1A:6X@4W1A;F1A<F0@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")-;W5N=&%I;B!$87EL
M:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I
M+`H@("`@)TU35#=-1%0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")-;W5N=&%I;B!3
M=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@(DUO=6YT86EN($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=-1%0G("DL"B`@("`G365X:6-O+T)A:F%3=7(G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")-;W5N=&%I;B!3=&%N9&%R9"!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DUO=6YT86EN($1A
M>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G
M("DL"B`@("`G3F%V86IO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B36]U;G1A:6X@
M4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(")-;W5N=&%I;B!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)U!.5"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(DUO=6YT86EN(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4WES=&5M5B]-4U0W)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B36]U;G1A
M:6X@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6
M+TU35#=-1%0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")-;W5N=&%I;B!3=&%N9&%R
M9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(DUO=6YT86EN($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=-1%0G("DL"B`@("`G55,O07)I>F]N82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(DUO=6YT86EN(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G55,O36]U;G1A:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")-;W5N=&%I
M;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@(DUO=6YT86EN($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@("`G06UE<FEC82]"96QI>F4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")#96YT<F%L(%-T86YD87)D(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]#86YC=6XG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")#96YT<F%L(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`B0V5N=')A;"!$87EL:6=H="!4:6UE
M(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M
M97)I8V$O0VAI8V%G;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@4W1A
M;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")#96YT<F%L($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#1%0G("DL"B`@("`G06UE<FEC82]#;W-T85]2:6-A)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O16Q?4V%L=F%D;W(G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")#96YT<F%L(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82]'=6%T96UA;&$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")#96YT<F%L(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06UE<FEC82]-86YA9W5A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!3
M=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O365N
M;VUI;F5E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E
M;G1R86P@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-$5"<@*2P*("`@("=!;65R:6-A+TUE<FED82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D-E;G1R86P@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L($1A>6QI9VAT(%1I;64B
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G06UE
M<FEC82]-97AI8V]?0VET>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@
M4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TUO
M;G1E<G)E>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@4W1A;F1A<F0@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#
M96YT<F%L($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=#1%0G("DL"B`@("`G06UE<FEC82].;W)T:%]$86MO=&$O0V5N=&5R
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@
M1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$
M5"<@*2P*("`@("=!;65R:6-A+U)A:6YY7U)I=F5R)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@1&%Y;&EG:'0@5&EM92(L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=!;65R
M:6-A+U)A;FMI;E]);FQE="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@
M4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(")%87-T97)N($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82]296=I;F$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")#96YT<F%L(%-T86YD87)D(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G06UE<FEC82]3=VEF=%]#=7)R96YT)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%M97)I8V$O5&5G=6-I9V%L<&$G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")#96YT<F%L(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82]7:6YN:7!E9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R
M86P@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^(")#96YT<F%L($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G0U-4)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@1&%Y;&EG:'0@5&EM
M92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=#
M4U0V0T14)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E
M;G1R86P@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-$5"<@*2P*("`@("=#86YA9&$O0V5N=')A;"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D-E;G1R86P@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L($1A>6QI9VAT(%1I;64B
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G0V%N
M861A+T5A<W0M4V%S:V%T8VAE=V%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N
M=')A;"!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-A;F%D
M82]387-K871C:&5W86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#96YT<F%L(%-T
M86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0VAI;&4O16%S=&5R
M27-L86YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R($ES+B!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97(@
M27,N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M14%34U0G("DL"B`@("`G171C+T=-5"LV)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M1TU4+3`V.C`P(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`V.C`P
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUE>&EC;R]'
M96YE<F%L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O16%S=&5R)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B16%S=&5R($ES+B!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G14%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97(@27,N(%-U;6UE<B!4
M:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14%34U0G("DL"B`@
M("`G4&%C:69I8R]'86QA<&%G;W,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'86QA
M<&%G;W,@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=!3%0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]#4U0V
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O0U-4-D-$5"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D-E;G1R86P@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L($1A>6QI9VAT(%1I
M;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G
M55,O0V5N=')A;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@4W1A;F1A
M<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M(")#96YT<F%L($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=#1%0G("DL"B`@("`G06UE<FEC82]";V=O=&$G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")#;VQO;6)I82!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%M97)I8V$O0V%Y;6%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3
M=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1&5T
M<F]I="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T
M97)N($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=%1%0G("DL"B`@("`G06UE<FEC82]%:7)U;F5P92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D%C<F4@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%#
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+T9O<G1?5V%Y;F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")%87-T97)N(%-T86YD
M87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]'<F%N9%]4
M=7)K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3=&%N9&%R9"!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E
M<FX@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T5$5"<@*2P*("`@("=!;65R:6-A+T=U87EA<75I;"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D5C=6%D;W(@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T5#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+TAA=F%N82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X
M,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@4W1A;F1A
M<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M(")#96YT<F%L($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=#1%0G("DL"B`@("`G06UE<FEC82]);F1I86YA+TEN9&EA;F%P
M;VQI<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TEN9&EA;F$O2VYO>"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TEN9&EA;F$O36%R96YG;R<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!;65R:6-A+TEN9&EA;F$O5F5V87DG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")%87-T97)N(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82]);F1I86YA<&]L:7,G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")%87-T97)N(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82])<6%L=6ET)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R
M;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@(D5A<W1E<FX@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+TIA;6%I8V$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")%87-T97)N(%-T86YD87)D(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]+96YT=6-K>2],;W5I<W9I;&QE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3=&%N9&%R9"!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("=!;65R:6-A+TME;G1U8VMY+TUO;G1I8V5L;&\G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")%87-T97)N(%-T86YD87)D(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R;B!$87EL:6=H
M="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@
M("`@)T%M97)I8V$O2VYO>%])3B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E
M<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T53
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+TQI;6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")097)U(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=0150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82],;W5I<W9I;&QE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B16%S=&5R;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E<FX@1&%Y;&EG:'0@5&EM92(L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R
M:6-A+TUO;G1R96%L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3=&%N
M9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@(D5A<W1E<FX@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+TYA<W-A=2<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97)N($1A>6QI9VAT
M(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@
M("`G06UE<FEC82].97=?66]R:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E
M<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T53
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^(")%87-T97)N($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82].:7!I9V]N
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3=&%N9&%R9"!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("=!;65R:6-A+U!A;F%M82<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M(D5A<W1E<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+U!A;F=N:7)T=6YG)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R
M;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@(D5A<W1E<FX@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+U!O<G0M874M
M4')I;F-E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3=&%N9&%R9"!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4&]R=&]?06-R92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@(D%C<F4@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+U)I;U]"<F%N8V\G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!
M8W)E(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!0U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]4:'5N9&5R
M7T)A>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T
M97)N($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=%1%0G("DL"B`@("`G0G)A>FEL+T%C<F4G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")!8W)E(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!0U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V%N861A+T5A<W1E
M<FXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^(")%87-T97)N(%-T86YD87)D(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R
M;B!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M1414)R`I+`H@("`@)T-U8F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#96YT<F%L
M(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`B0V5N=')A;"!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T535"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97)N($1A>6QI9VAT(%1I;64B
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G15-4
M-45$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T
M97)N($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=%1%0G("DL"B`@("`G171C+T=-5"LU)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M1TU4+3`U.C`P(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`U.C`P
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TE%5"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=*86UA:6-A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S
M=&5R;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E
M;58O15-4-2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+T535#5%1%0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")%87-T97)N(%-T86YD87)D(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R;B!$87EL
M:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I
M+`H@("`@)U53+T5A<W0M26YD:6%N82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A
M<W1E<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=54R]%
M87-T97)N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3=&%N9&%R9"!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A
M<W1E<FX@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T5$5"<@*2P*("`@("=54R]);F1I86YA+5-T87)K92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=54R]-:6-H:6=A;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E
M<FX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T53
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^(")%87-T97)N($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82]!;F=U:6QL
M82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]!;G1I9W5A)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B071L86YT:6,@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+T%R=6)A)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M071L86YT:6,@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+T%S=6YC:6]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4&%R86=U87D@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!95"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")0
M87)A9W5A>2!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)U!94U0G("DL"B`@("`G06UE<FEC82]"87)B861O<R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82]";V%?5FES=&$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")!;6%Z;VX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+T-A<F%C87,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")696YE>G5E;&$@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U9%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T-U:6%B82<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(D%M87IO;B!3=&%N9&%R9"!4:6UE(BP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G04U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D%M87IO;B!3=6UM97(@
M5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%-4U0G("DL"B`@
M("`G06UE<FEC82]#=7)A8V%O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B071L86YT
M:6,@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+T1O;6EN:6-A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B071L86YT:6,@4W1A;F1A
M<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T=L86-E7T)A
M>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B071L86YT
M:6,@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T%$5"<@*2P*("`@("=!;65R:6-A+T=O;W-E7T)A>2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`B071L86YT:6,@1&%Y;&EG:'0@5&EM
M92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%$5"<@*2P*("`@("=!
M;65R:6-A+T=R96YA9&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!=&QA;G1I8R!3
M=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1W5A
M9&5L;W5P92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]'=7EA;F$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")'=7EA;F$@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=95"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+TAA;&EF87@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!=&QA
M;G1I8R!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(D%T;&%N=&EC($1A>6QI9VAT(%1I;64B+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=!1%0G("DL"B`@("`G06UE<FEC82],85]0
M87HG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^(")";VQI=FEA(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("="3U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]-86YA=7,G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")!;6%Z;VX@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+TUA<G1I;FEQ=64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!=&QA;G1I
M8R!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M36]N='-E<G)A="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD
M87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]0;W)T7V]F
M7U-P86EN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B071L86YT:6,@4W1A;F1A<F0@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U!O<G1O7U9E;&AO
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B06UA>F]N(%-T86YD87)D(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=!350G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]0=65R=&]?4FEC;R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]386YT:6%G;R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(D-H:6QE(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#3%0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`B0VAI;&4@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#3%-4)R`I+`H@("`@)T%M97)I8V$O4V%N=&]?1&]M:6YG
M;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]3=%]+:71T<R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]3=%],=6-I82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82]3=%]4:&]M87,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!=&QA
M;G1I8R!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I
M8V$O4W1?5FEN8V5N="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T
M86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]4:'5L
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]4;W)T;VQA)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B071L86YT:6,@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+U9I<F=I;B<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M(D%T;&%N=&EC(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06YT87)C=&EC82]086QM97(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#:&EL92!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TQ4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-H
M:6QE(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M0TQ35"<@*2P*("`@("=!=&QA;G1I8R]"97)M=61A)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B071L86YT:6,@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")!=&QA;G1I8R!$87EL:6=H="!4:6UE
M(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@)T%T
M;&%N=&EC+U-T86YL97DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")&86QK;&%N9"!)
M<RX@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T9+5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M(")&86QK;&%N9"!)<RX@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=&2U-4)R`I+`H@("`@)T)R87II;"]797-T)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B06UA>F]N(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G0V%N861A+T%T;&%N=&EC)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M071L86YT:6,@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^(")!=&QA;G1I8R!$87EL:6=H="!4:6UE(BP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@)T-H:6QE+T-O
M;G1I;F5N=&%L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0VAI;&4@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T-,5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#:&EL92!3=6UM
M97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-,4U0G("DL
M"B`@("`G171C+T=-5"LT)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1TU4+3`T.C`P
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`T.C`P)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!25"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D%T;&%N=&EC(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4WES=&5M5B]!4U0T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B071L86YT
M:6,@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6
M+T%35#1!1%0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!=&QA;G1I8R!3=&%N9&%R
M9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(D%T;&%N=&EC($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=!1%0G("DL"B`@("`G06UE<FEC82]3=%]*;VAN<R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$R-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(DYE=V9O=6YD;&%N9"!3=&%N9&%R9"!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G3E-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DYE=V9O=6YD;&%N
M9"!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M3D14)R`I+`H@("`@)T-.5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$R-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(DYE=V9O=6YD
M;&%N9"!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M3E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(DYE=V9O=6YD;&%N9"!$87EL:6=H="!4:6UE(BP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3D14)R`I+`H@("`@)T-A;F%D82].
M97=F;W5N9&QA;F0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M,C8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(").97=F;W5N9&QA;F0@
M4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(").97=F;W5N9&QA;F0@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)TY$5"<@*2P*("`@("=!1U0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")!<F=E;G1I;F4@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!;65R:6-A+T%R86=U86EN82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D)R87II
M;"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0E)4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(D)R87II;"!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T)24U0G("DL"B`@("`G06UE<FEC82]"96QE;2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D)R87II;"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I
M8V$O0G5E;F]S7T%I<F5S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B07)G96YT:6YE
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4E0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]#871A;6%R8V$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")!<F=E;G1I;F4@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+T-A>65N;F4G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")&<F5N8V@@1W5I86YA(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("='1E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE
M<FEC82]#;W)D;V)A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B07)G96YT:6YE(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]&;W)T86QE>F$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")"<F%Z:6P@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T)25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")"<F%Z:6P@4W5M;65R(%1I;64B+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("="4E-4)R`I+`H@("`@)T%M97)I
M8V$O1V]D=&AA8B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P
M.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E=E<W1E<FX@1W)E96YL
M86YD(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=71U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`B5V5S=&5R;B!'<F5E;FQA;F0@4W5M;65R(%1I;64B+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=71U-4)R`I+`H@("`@)T%M97)I8V$O2G5J=7DG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")!<F=E;G1I;F4@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+TUA8V5I;R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M(D)R87II;"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0E)4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@(D)R87II;"!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T)24U0G("DL"B`@("`G06UE<FEC82]-96YD;WIA)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B07)G96YT:6YE(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G06UE<FEC82]-:7%U96QO;B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E!I
M97)R92`F($UI<75E;&]N(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=035-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@(E!I97)R92`F($UI<75E;&]N($1A
M>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=03414
M)R`I+`H@("`@)T%M97)I8V$O36]N=&5V:61E;R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(E5R=6=U87D@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U59
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+U!A<F%M87)I8F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")3=7)I;F%M92!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4U)4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4F5C:69E)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B0G)A>FEL(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("="4E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`B0G)A>FEL(%-U;6UE<B!4:6UE(BP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0E)35"<@*2P*("`@("=!;65R:6-A+U)O
M<V%R:6\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!<F=E;G1I;F4@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%25"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U-A;U]0875L;R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D)R87II;"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@(D)R87II;"!3=6UM97(@5&EM92(L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T)24U0G("DL"B`@("`G0D54)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B0G)A>FEL(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("="4E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`B0G)A>FEL(%-U;6UE<B!4:6UE(BP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0E)35"<@*2P*("`@("="<F%Z:6PO16%S
M="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D)R87II;"!4:6UE(BP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D)R87II;"!3=6UM97(@5&EM
M92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)24U0G("DL"B`@("`G
M171C+T=-5"LS)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1TU4+3`S.C`P(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`S.C`P)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O3F]R;VYH82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B1F5R;F%N9&\@9&4@3F]R;VYH82!4:6UE(BP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1DY4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%T;&%N=&EC+U-O=71H7T=E;W)G:6$G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TW,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(E-O=71H($=E;W)G:6$@4W1A;F1A<F0@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("="<F%Z:6PO1&5.;W)O;FAA)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")&97)N86YD;R!D92!.;W)O;FAA(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=&3E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G171C+T=-5"LR)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'350M,#(Z,#`B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#(Z,#`G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]38V]R97-B>7-U
M;F0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@1W)E96YL86YD(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%1U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R
M;B!'<F5E;FQA;F0@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%1U-4)R`I+`H@("`@)T%T;&%N=&EC+T%Z;W)E<R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B07IO<F5S(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!6D]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@(D%Z;W)E<R!3=6UM97(@5&EM92(L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T%:3U-4)R`I+`H@("`@)T%T;&%N=&EC
M+T-A<&5?5F5R9&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-A<&4@5F5R9&4@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-65"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4*S$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D=-5"TP,3HP,"(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"TP,3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M9G)I8V$O06)I9&IA;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@365A;B!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]!8V-R82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")'<F5E;G=I8V@@365A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F
M<FEC82]"86UA:V\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1W)E96YW:6-H($UE86X@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O0F%N:G5L)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M(D=R965N=VEC:"!-96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R
M:6-A+T)I<W-A=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@365A;B!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]#87-A8FQA;F-A)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(E=E<W1E<FX@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!9G)I8V$O0V]N86MR>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@365A;B!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]$86MA<B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")'<F5E;G=I8V@@365A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%F<FEC82]%;%]!86EU;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")797-T97)N($5U<F]P96%N
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7150G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T9R965T;W=N)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D=R965N=VEC:"!-96%N(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+TQO;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1W)E96YW:6-H($UE86X@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O36]N<F]V:6$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B1W)E96YW:6-H($UE86X@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!9G)I8V$O3F]U86MC:&]T="<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@
M365A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]/=6%G861O
M=6=O=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@365A;B!4:6UE(BP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%F<FEC82]386]?5&]M92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'<F5E
M;G=I8V@@365A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]4
M:6UB=6MT=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@365A;B!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O1&%N;6%R:W-H879N)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(D=R965N=VEC:"!-96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M071L86YT:6,O0V%N87)Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E=E<W1E<FX@175R;W!E86X@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")7
M97-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G5T535"<@*2P*("`@("=!=&QA;G1I8R]&865R;V4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B5V5S=&5R;B!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@(E=E<W1E<FX@175R;W!E86X@4W5M
M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=715-4)R`I
M+`H@("`@)T%T;&%N=&EC+TUA9&5I<F$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B5V5S=&5R;B!%
M=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@(E=E<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=715-4)R`I+`H@("`@)T%T;&%N=&EC+U)E
M>6MJ879I:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@365A;B!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%T;&%N=&EC+U-T7TAE;&5N82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")'<F5E;G=I8V@@365A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5I
M<F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B1W)E96YW:6-H($UE86X@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("))<FES:"!3=6UM97(@5&EM
M92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE35"<@*2P*("`@("=%
M=&,O1TU4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@(D=-5"LP,#HP,"(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=%=&,O1TU4*S`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1TU4*S`P.C`P(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]'350M,"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")'350K,#`Z,#`B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#`Z
M,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=-
M5#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B1TU4*S`P.C`P(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T5T8R]'<F5E;G=I8V@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1W)E96YW:6-H($UE
M86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O54-4)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(D-O;W)D:6YA=&5D(%5N:79E<G-A;"!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T5T8R]55$,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V]O<F1I;F%T960@56YI=F5R
M<V%L(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=55$,G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+U5N:79E<G-A;"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")#;V]R9&EN871E9"!5;FEV97)S86P@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=%=&,O6G5L=2<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#;V]R9&EN871E
M9"!5;FEV97)S86P@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U54
M0R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O
M0F5L9F%S="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@365A;B!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D)R:71I<V@@4W5M
M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("="4U0G("DL
M"B`@("`G175R;W!E+T1U8FQI;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'<F5E;G=I8V@@365A
M;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(DER:7-H(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G25-4)R`I+`H@("`@)T5U<F]P92],:7-B;VXG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B5V5S
M=&5R;B!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M5T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(E=E<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=715-4)R`I+`H@("`@)T5U<F]P
M92],;VYD;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B1W)E96YW:6-H($UE86X@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")"<FET:7-H(%-U
M;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E-4)R`I
M+`H@("`@)T=")R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D=R965N=VEC:"!-96%N(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B0G)I=&ES:"!3
M=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)35"<@
M*2P*("`@("='0BU%:7)E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=R965N=VEC:"!-96%N(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B0G)I
M=&ES:"!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T)35"<@*2P*("`@("='350G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1W)E96YW:6-H($UE86X@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='350P)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=-
M5"LP,#HP,"(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,#HP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='<F5E;G=I8V@G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B1W)E96YW:6-H($UE86X@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=)8V5L86YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=R965N=VEC:"!-96%N(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&]R='5G86PG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M5V5S=&5R;B!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@(E=E<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=715-4)R`I+`H@("`@)U5#
M5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")#;V]R9&EN871E9"!5;FEV97)S86P@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=55$,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V]O<F1I;F%T960@
M56YI=F5R<V%L(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=55$,G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G56YI=F5R<V%L
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D-O;W)D:6YA=&5D(%5N:79E<G-A;"!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U=%5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")797-T97)N($5U<F]P
M96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`B5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G6G5L=2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")#;V]R9&EN871E9"!5;FEV97)S86P@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!9G)I8V$O06QG:65R<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#96YT<F%L
M($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T)A
M;F=U:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^(")797-T97)N($%F<FEC86X@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O0G)A>GIA=FEL;&4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B5V5S=&5R;B!!9G)I8V%N(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+T-E=71A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R
M86P@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=!9G)I8V$O
M1&]U86QA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E=E<W1E<FX@069R:6-A;B!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]+:6YS:&%S82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")797-T97)N($%F<FEC86X@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!9G)I8V$O3&%G;W,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B5V5S=&5R
M;B!!9G)I8V%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TQI
M8G)E=FEL;&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B5V5S=&5R;B!!9G)I8V%N(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TQU86YD82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")797-T97)N($%F<FEC86X@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!9G)I8V$O36%L86)O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E=E<W1E
M<FX@069R:6-A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82].
M9&IA;65N82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")797-T97)N($%F<FEC86X@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3FEA;65Y)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(E=E<W1E<FX@069R:6-A;B!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%F<FEC82]0;W)T;RU.;W9O)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E=E
M<W1E<FX@069R:6-A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC
M82]4=6YI<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+U=I;F1H;V5K)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(E=E<W1E<FX@069R:6-A;B!4:6UE(BP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(E=E<W1E<FX@069R:6-A;B!3
M=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U=!4U0G
M("DL"B`@("`G07)C=&EC+TQO;F=Y96%R8GEE;B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")#96YT<F%L($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM
M92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G
M071L86YT:6,O2F%N7TUA>65N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@
M1W)E96YL86YD(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%1U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`B16%S=&5R;B!'<F5E;FQA;F0@4W5M;65R(%1I;64B+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=%1U-4)R`I+`H@("`@)T-%5"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A
M;B!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%
M4U0G("DL"B`@("`G14-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R
M;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=&,O1TU4+3$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B1TU4*S`Q.C`P(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S`Q.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T5U<F]P92]!;7-T97)D86TG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N
M=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64B+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P
M92]!;F1O<G)A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#
M96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O0F5L9W)A9&4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E
M86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#
M15-4)R`I+`H@("`@)T5U<F]P92]"97)L:6XG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M0V5N=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64B
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U
M<F]P92]"<F%T:7-L879A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R
M;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O0G)U<W-E
M;',G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@
M175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]"=61A<&5S="<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")#96YT<F%L($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!3=6UM
M97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL
M"B`@("`G175R;W!E+T-O<&5N:&%G96XG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N
M=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64B+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P
M92]':6)R86QT87(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A
M;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(D-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92],:G5B;&IA;F$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@175R
M;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=#15-4)R`I+`H@("`@)T5U<F]P92],=7AE;6)O=7)G)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE
M<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*
M("`@("=%=7)O<&4O36%D<FED)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@
M175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O36%L
M=&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@
M175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]-;VYA8V\G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@4W5M;65R
M(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@
M("`@)T5U<F]P92]/<VQO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R
M;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O4&%R:7,G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@175R
M;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=#15-4)R`I+`H@("`@)T5U<F]P92]0<F%G=64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`B0V5N=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@4W5M;65R(%1I
M;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@
M)T5U<F]P92]2;VUE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E
M86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O4V%N7TUA<FEN
M;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B0V5N=')A;"!%
M=7)O<&5A;B!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U-A<F%J979O)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE
M<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*
M("`@("=%=7)O<&4O4VMO<&IE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@
M175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O4W1O
M8VMH;VQM)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT
M<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O5&ER86YE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U
M;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@
M*2P*("`@("=%=7)O<&4O5F%D=7HG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A
M;"!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]6
M871I8V%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT
M<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O5FEE;FYA)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U
M;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@
M*2P*("`@("=%=7)O<&4O5V%R<V%W)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R
M86P@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O
M6F%G<F5B)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT
M<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O6G5R:6-H)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%-U
M;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@
M*2P*("`@("=-150G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B36ED9&QE($5U<F]P92!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3454)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DUI
M9&1L92!%=7)O<&4@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=-15-4)R`I+`H@("`@)U!O;&%N9"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")#96YT<F%L($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM
M92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G
M05)4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@175R;W!E86X@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97)N
M($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G14535"<@*2P*("`@("=!9G)I8V$O0FQA;G1Y<F4G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B0V5N=')A;"!!9G)I8V%N(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+T)U:G5M8G5R82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#96YT
M<F%L($%F<FEC86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O
M0V%I<F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%15-4)R`I+`H@("`@)T%F<FEC82]'86)O<F]N92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")#96YT<F%L($%F<FEC86X@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!9G)I8V$O2&%R87)E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R
M86P@069R:6-A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T%4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]*
M;VAA;FYE<V)U<F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4V]U=&@@069R:6-A(%-T
M86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=305-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]+:6=A
M;&DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!!9G)I8V%N(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TQU8G5M8F%S:&DG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B0V5N=')A;"!!9G)I8V%N(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+TQU<V%K82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#96YT<F%L
M($%F<FEC86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O36%P
M=71O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@069R:6-A;B!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]-87-E<G4G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B4V]U=&@@069R:6-A(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=305-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%F<FEC82]-8F%B86YE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E-O
M=71H($%F<FEC82!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G4T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!9G)I8V$O5')I<&]L:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")%87-T97)N($5U
M<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]!;6UA;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O
M<&5A;B!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T5%4U0G("DL"B`@("`G07-I82]"96ER=70G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M16%S=&5R;B!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@(D5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T%S
M:6$O1&%M87-C=7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A
M;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(D5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T%S:6$O1V%Z82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!3
M=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G
M("DL"B`@("`G07-I82])<W1A;F)U;"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")%87-T
M97)N($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92(L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G07-I82]*
M97)U<V%L96TG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B27-R865L(%-T86YD87)D(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B27-R
M865L($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=)1%0G("DL"B`@("`G07-I82].:6-O<VEA)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M(D5A<W1E<FX@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE
M(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=!
M<VEA+U1E;%]!=FEV)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(DES<F%E;"!3=&%N9&%R
M9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(DES<F%E;"!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G2414)R`I+`H@("`@)T-!5"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#96YT
M<F%L($%F<FEC86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%150G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!4:6UE(BP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E<FX@175R;W!E
M86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%
M15-4)R`I+`H@("`@)T5G>7!T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@
M175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(")%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%=&,O1TU4+3(G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`B1TU4*S`R.C`P(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4*S`R.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T5U<F]P92]!=&AE;G,G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S
M=&5R;B!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(D5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P
M92]"=6-H87)E<W0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A
M;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(D5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]#:&ES:6YA=2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O
M<&5A;B!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T5%4U0G("DL"B`@("`G175R;W!E+TAE;'-I;FMI)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(D5A<W1E<FX@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%-U;6UE<B!4
M:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@
M("=%=7)O<&4O27-T86YB=6PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!%
M=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@(D5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]+86QI
M;FEN9W)A9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S
M=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+TMI978G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E<FX@175R;W!E86X@4W5M
M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I
M+`H@("`@)T5U<F]P92]-:6YS:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")%87-T97)N
M($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92(L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+TYI
M8V]S:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]2:6=A)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(D5A<W1E<FX@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%-U;6UE
M<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*
M("`@("=%=7)O<&4O4VEM9F5R;W!O;"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")%87-T
M97)N($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92(L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E
M+U-O9FEA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@175R;W!E86X@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T
M97)N($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O<&4O5&%L;&EN;B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G175R;W!E+U1I<F%S<&]L)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A
M<W1E<FX@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^(")%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O
M<&4O57IH9V]R;V0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A
M;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M(D5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]6:6QN:75S)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@175R;W!E86X@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=%=7)O<&4O6F%P;W)O>FAY92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")%87-T97)N($5U<F]P96%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@
M5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@
M("`G27-R865L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(DES<F%E;"!3=&%N9&%R9"!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DES
M<F%E;"!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G2414)R`I+`H@("`@)TQI8GEA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E
M<FX@175R;W!E86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=4=7)K97DG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!%=7)O<&5A;B!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D5A<W1E<FX@175R
M;W!E86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=%15-4)R`I+`H@("`@)T%F<FEC82]!9&1I<U]!8F%B82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B16%S=&5R;B!!9G)I8V%N(%1I;64B+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+T%S;65R82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R
M;B!!9G)I8V%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T1A
M<E]E<U]386QA86TG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P
M.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@069R:6-A
M;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]$:FEB;W5T:2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!!9G)I8V%N(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G069R:6-A+TMA;7!A;&$G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(D5A<W1E<FX@069R:6-A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%F<FEC82]+:&%R=&]U;2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!!
M9G)I8V%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TUO9V%D
M:7-H=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!!9G)I8V%N(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TYA:7)O8FDG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D5A<W1E<FX@069R:6-A;B!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%N=&%R8W1I8V$O4WEO=V$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E-Y
M;W=A(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=364]4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O061E;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B07)A8FEA(%-T86YD87)D(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G07-I82]"86=H9&%D)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!
M<F%B:6$@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^(")!<F%B:6$@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T%$5"<@*2P*("`@("=!<VEA+T)A:')A:6XG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@(D%R86)I82!3=&%N9&%R9"!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%S:6$O2W5W86ET)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")!<F%B:6$@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M<VEA+U%A=&%R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!<F%B:6$@4W1A;F1A<F0@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U)I>6%D:"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B07)A8FEA(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G14%4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")%87-T97)N($%F<FEC
M86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4+3,G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D=-5"LP,SHP,"(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"LP,SHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=%=7)O<&4O36]S8V]W)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")-;W-C;W<@
M4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU32R<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(")-;W-C;W<@1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TU31"<@*2P*("`@("=);F1I86XO06YT86YA;F%R:79O
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")%87-T97)N($%F<FEC86X@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=);F1I86XO0V]M;W)O)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")%87-T97)N($%F<FEC86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=);F1I86XO36%Y;W1T92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!!
M9G)I8V%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5RU352<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B36]S8V]W(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=-4TLG+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B36]S8V]W($1A>6QI9VAT(%1I
M;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-4T0G("DL"B`@("`G
M07-I82]2:7EA9&@X-R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,3$R,C0P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1TU4*S`S.C`W(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4FEY861H.#@G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D=-5"LP,SHP-R(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!<VEA+U)I>6%D:#@Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'350K,#,Z
M,#<B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36ED96%S="]2:7EA9&@X
M-R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3$R,C0P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B1TU4*S`S.C`W(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)TUI9&5A<W0O4FEY861H.#@G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(D=-5"LP,SHP-R(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP
M,SHP-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-:61E
M87-T+U)I>6%D:#@Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'350K,#,Z,#<B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]496AR86XG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$R-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(DER86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TE25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("))<F%N(%-U;65R(%1I;64B+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=)4E-4)R`I+`H@("`@)TER86XG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$R-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(DER86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE2
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("))<F%N(%-U;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=)4E-4)R`I+`H@("`@)T%S:6$O07%T874G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D%Q=&%U(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=!4514)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@(D%Q=&%U(%-U;6UE<B!4:6UE(BP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G05%44U0G("DL"B`@("`G07-I82]"86MU)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")!>F5R8F%I:F%N(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!6E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B07IE<F)A:6IA;B!3=6UM97(@
M5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%:4U0G("DL"B`@
M("`G07-I82]$=6)A:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1W5L9B!3=&%N9&%R
M9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1U-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O375S8V%T)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")'=6QF(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G07-I82]48FEL:7-I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")'96]R
M9VEA(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`B1V5O<F=I82!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T=%4U0G("DL"B`@("`G07-I82]997)E=F%N)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")!<FUE;FEA(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=!350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`B07)M96YI82!3=6UM97(@5&EM92(L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T%-4U0G("DL"B`@("`G171C+T=-5"TT)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")'350K,#0Z,#`B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350K,#0Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G175R;W!E+U-A;6%R82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4V%M
M87)A(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=304U4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@(E-A;6%R82!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)U-!35-4)R`I+`H@("`@)TEN9&EA;B]-86AE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")397EC:&5L;&5S(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=30U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M26YD:6%N+TUA=7)I=&EU<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B36%U<FET:75S
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-550G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G26YD:6%N+U)E=6YI;VXG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(E)E=6YI;VX@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U)%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=.150G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D%R;65N:6$@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")!<FUE;FEA(%-U
M;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04U35"<@
M*2P*("`@("=!<VEA+TMA8G5L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q-C(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")!9F=H86YI
M<W1A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0494)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O07%T;V)E)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")!<71O8F4@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%15%0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`B07%T;V)E(%-U;6UE<B!4:6UE(BP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G05%44U0G("DL"B`@("`G07-I
M82]!<VAG86)A="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B5'5R:VUE;FES=&%N(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=4350G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]!<VAK:&%B860G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(E1U<FMM96YI<W1A;B!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O0FES:&ME:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B2VER9VEZ
M<W1A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2T=4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@(DMI<F=I>G-T86X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=+1U-4)R`I+`H@("`@)T%S:6$O1'5S:&%N8F4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(E1A:FEK:7-T86X@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U1*5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!<VEA+TMA<F%C:&DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E!A:VES=&%N
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=02U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]386UA<FMA;F0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(E1U<FMM96YI<W1A;B!4:6UE(BP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G5$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O5&%S:&ME;G0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E5Z
M8F5K:7-T86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U5:5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+UEE:V%T
M97)I;F)U<F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(EEE:V%T97)I;F)U<F<@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)UE%2U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B665K
M871E<FEN8G5R9R!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)UE%2U-4)R`I+`H@("`@)T5T8R]'350M-2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B1TU4*S`U.C`P(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M*S`U.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEN
M9&EA;B]+97)G=65L96XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D9R96YC:"!3;W5T
M:&5R;B`F($%N=&%R8W1I8R!,86YD<R!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G5$94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)TEN9&EA;B]-86QD:79E<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B36%L9&EV
M97,@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU65"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=03%0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@(E!A:VES=&%N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=02U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I
M82]#86QC=71T82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3DX
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B26YD:6$@4W1A;F1A<F0@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=)4U0G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#$Y.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(DEN9&EA(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=)4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M07-I82]+871M86YD=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C`W,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B3F5P86P@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY05"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T:6-A+TUA=W-O;B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B36%W<V]N(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=-05=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%N=&%R8W1I8V$O5F]S=&]K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")6;W-T;VL@
M=&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U9/4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]!;&UA='DG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D%L;6$M071A(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!3$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@(D%L;6$M071A(%-U;6UE<B!4:6UE(BP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04Q-4U0G("DL"B`@("`G07-I
M82]#;VQO;6)O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")3<FD@3&%N:V$@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TQ+5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T1A8V-A)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")"86YG;&%D97-H(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("="1%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I
M82]$:&%K82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0F%N9VQA9&5S:"!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0D14)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%S:6$O3F]V;W-I8FER<VLG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(DYO=F]S:6)I<G-K(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=.3U94)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@(DYO=F]S:6)I<G-K(%-U;6UE<B!4:6UE
M(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3D]64U0G("DL"B`@("`G
M07-I82]/;7-K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")/;7-K(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=/35-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D]M<VL@4W5M;65R
M(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=/35-35"<@*2P*
M("`@("=!<VEA+U1H:6UB=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0FAU=&%N(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="5%0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]4:&EM<&AU)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^(")":'5T86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T)45"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("="
M4U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D)A;F=L861E<V@@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T)$5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=%=&,O1TU4+38G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=-
M5"LP-CHP,"(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP-CHP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=);F1I86XO0VAA
M9V]S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("));F1I86X@3V-E86X@5&5R<FET;W)Y
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)3U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]286YG;V]N)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,S0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")->6%N;6%R(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=-350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G26YD:6%N+T-O8V]S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R,S0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#;V-O<R!)<VQA
M;F1S(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#0U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06YT87)C=&EC82]$879I
M<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B1&%V:7,@5&EM92(L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T1!5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G07-I82]"86YG:V]K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("));F1O
M8VAI;F$@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE#5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+TAO=F0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(DAO=F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TA/5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G07-I82]*86MA<G1A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")797-T($EN9&]N
M97-I82!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5TE4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2W)A<VYO>6%R
M<VLG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(DMR87-N;WEA<G-K(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=+4D%4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DMR87-N;WEA<G-K
M(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G2U)!
M4U0G("DL"B`@("`G07-I82]0:&YO;5]096YH)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("));F1O8VAI;F$@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE#
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U!O
M;G1I86YA:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B5V5S="!);F1O;F5S:6$@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=)5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U-A:6=O;B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B26YD;V-H:6YA(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=)0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M07-I82]6:65N=&EA;F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(DEN9&]C:&EN82!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G24-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]'350M-R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`B1TU4*S`W.C`P(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1TU4*S`W.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)TEN9&EA;B]#:')I<W1M87,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-H<FES=&UA
M<R!)<VQA;F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-85"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=64U0G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(DEN9&]C:&EN82!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G24-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%N=&%R8W1I8V$O0V%S97DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E=E<W1E
M<FX@4W1A;F1A<F0@5&EM92`H075S=')A;&EA*2(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!<VEA+T)R=6YE:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0G)U;F5I(%1I
M;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="3E0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]#:&]N9W%I;F<G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D-H:6YA(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G07-I82]#:'5N9VMI;F<G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-H
M:6YA(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82](
M87)B:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-H:6YA(%-T86YD87)D(%1I;64B
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82](;VYG7TMO;F<G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(DAO;F<@2V]N9R!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G2$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%S:6$O27)K=71S:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B27)K=71S:R!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25)+5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("))<FMU
M='-K(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M25)+4U0G("DL"B`@("`G07-I82]+87-H9V%R)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")#:&EN82!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S
M:6$O2W5A;&%?3'5M<'5R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")-86QA>7-I82!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35E4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2W5C:&EN9R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B36%L87ES:6$@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TU95"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!<VEA+TUA8V%O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R
M.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#:&EN82!3=&%N9&%R
M9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O36%N:6QA)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")0:&EL:7!P:6YE<R!4:6UE(BP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4$A4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O4VAA;F=H86DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-H:6YA
M(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]3:6YG
M87!O<F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@(E-I;F=A<&]R92!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G4T=4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%S:6$O5&%I<&5I)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")#:&EN82!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S
M:6$O56IU;F=?4&%N9&%N9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N=')A;"!)
M;F1O;F5S:6$@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-)5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U5L86%N
M8F%A=&%R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")5;&%A;F)A871A<B!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G54Q!5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U5L86Y?0F%T;W(G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(E5L86%N8F%A=&%R(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=53$%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%S:6$O57)U;7%I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#:&EN82!3=&%N
M9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI82]097)T
M:"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`B5V5S=&5R;B!3=&%N9&%R9"!4:6UE("A!
M=7-T<F%L:6$I(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI82]797-T
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")797-T97)N(%-T86YD87)D(%1I;64@*$%U
M<W1R86QI82DB+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=74U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0U14)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")#:&EN82!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T5T8R]'350M."<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1TU4*S`X.C`P(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`X.C`P)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TAO;F=K;VYG)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")(;VYG($MO;F<@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TA+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=0
M4D,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D-H:6YA(%-T86YD87)D(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G4VEN9V%P;W)E)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M(")3:6YG87!O<F4@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-'
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T-H
M;VEB86QS86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-H;VEB86QS86X@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-(3U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]$:6QI)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")%87-T(%1I;6]R(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=44%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I
M82]*87EA<'5R82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S="!);F1O;F5S:6$@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5)5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U!Y;VYG>6%N9R<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B2V]R96$@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)TM35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!<VEA+U-E;W5L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")+;W)E
M82!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2U-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O5&]K
M>6\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(DIA<&%N(%-T86YD87)D(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=*4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G07-I82]986MU='-K)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")986MU='-K(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=9
M04M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(EEA:W1S:R!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)UE!2U-4)R`I+`H@("`@)T5T8R]'350M.2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B1TU4*S`Y.C`P(BP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S`Y.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)TI35"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B2F%P86X@4W1A;F1A<F0@
M5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TI35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=*87!A;B<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B2F%P86X@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TI35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=086-I9FEC+U!A;&%U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")086QA=2!4:6UE
M(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%=4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U)/2R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M2V]R96$@4W1A;F1A<F0@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TM35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!0U0G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,T,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@4W1A;F1A<F0@5&EM92`H3F]R
M=&AE<FX@5&5R<FET;W)Y*2(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=7-T<F%L
M:6$O061E;&%I9&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,T
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@4W1A;F1A
M<F0@5&EM92`H4V]U=&@@075S=')A;&EA*2(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L(%-U;6UE<B!4:6UE("A3;W5T
M:"!!=7-T<F%L:6$I(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0U-4
M)R`I+`H@("`@)T%U<W1R86QI82]"<F]K96Y?2&EL;"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T<F%L:6$O
M3F5W(%-O=71H(%=A;&5S*2(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^(")#96YT<F%L(%-U;6UE<B!4:6UE("A3;W5T:"!!=7-T<F%L
M:6$O3F5W(%-O=71H(%=A;&5S*2(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-35"<@*2P*("`@("=!=7-T<F%L:6$O1&%R=VEN)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")#96YT<F%L(%-T86YD87)D(%1I;64@*$YO<G1H97)N(%1E<G)I
M=&]R>2DB+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A;&EA+TYO<G1H)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")#96YT<F%L(%-T86YD87)D(%1I;64@*$YO<G1H
M97)N(%1E<G)I=&]R>2DB+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A;&EA
M+U-O=71H)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#96YT<F%L(%-T86YD87)D(%1I
M;64@*%-O=71H($%U<W1R86QI82DB+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`B0V5N=')A;"!3=6UM97(@5&EM92`H4V]U=&@@075S
M=')A;&EA*2(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-35"<@*2P*
M("`@("=!=7-T<F%L:6$O66%N8V]W:6YN82<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T<F%L:6$O3F5W(%-O
M=71H(%=A;&5S*2(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")#96YT<F%L(%-U;6UE<B!4:6UE("A3;W5T:"!!=7-T<F%L:6$O3F5W
M(%-O=71H(%=A;&5S*2(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-3
M5"<@*2P*("`@("=!150G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A
M;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97)N(%-U;6UE<B!4:6UE("A.
M97<@4V]U=&@@5V%L97,I(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M15-4)R`I+`H@("`@)T%N=&%R8W1I8V$O1'5M;VYT1%5R=FEL;&4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D1U;6]N="UD)U5R=FEL;&4@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T1$550G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G07-I82]386MH86QI;B<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B
M4V%K:&%L:6X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-!2U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`B4V%K:&%L:6X@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=304M35"<@*2P*("`@("=!<VEA+U9L861I=F]S=&]K
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^(")6;&%D:79O<W1O:R!4:6UE(BP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G5DQ!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")6;&%D:79O<W1O:R!3
M=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U9,05-4
M)R`I+`H@("`@)T%U<W1R86QI82]!0U0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A
M<W1E<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97)N(%-U;6UE
M<B!4:6UE("A.97<@4V]U=&@@5V%L97,I(BP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82]"<FES8F%N92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3=&%N9&%R9"!4:6UE("A1=65E;G-L
M86YD*2(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=7-T<F%L:6$O0V%N8F5R<F$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM92`H3F5W
M(%-O=71H(%=A;&5S*2(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(")%87-T97)N(%-U;6UE<B!4:6UE("A.97<@4V]U=&@@5V%L97,I
M(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U
M<W1R86QI82](;V)A<G0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A
M;F1A<F0@5&EM92`H5&%S;6%N:6$I(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W5M;65R(%1I;64@*%1A<VUA;FEA
M*2(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@*2P*("`@("=!
M=7-T<F%L:6$O3&EN9&5M86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@
M4W1A;F1A<F0@5&EM92`H475E96YS;&%N9"DB+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G075S=')A;&EA+TUE;&)O=7)N92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S
M=&5R;B!3=&%N9&%R9"!4:6UE("A6:6-T;W)I82DB+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R;B!3=6UM97(@5&EM92`H
M5FEC=&]R:6$I(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I
M+`H@("`@)T%U<W1R86QI82].4U<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D5A<W1E
M<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")%87-T97)N(%-U;6UE<B!4
M:6UE("A.97<@4V]U=&@@5V%L97,I(BP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82]1=65E;G-L86YD)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^(")%87-T97)N(%-T86YD87)D(%1I;64@*%%U965N<VQA
M;F0I(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI82]3>61N97DG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(D5A<W1E<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O
M=71H(%=A;&5S*2(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")%87-T97)N(%-U;6UE<B!4:6UE("A.97<@4V]U=&@@5V%L97,I(BP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R
M86QI82]487-M86YI82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3=&%N
M9&%R9"!4:6UE("A487-M86YI82DB+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`B16%S=&5R;B!3=6UM97(@5&EM92`H5&%S;6%N:6$I
M(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U
M<W1R86QI82]6:6-T;W)I82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B16%S=&5R;B!3
M=&%N9&%R9"!4:6UE("A6:6-T;W)I82DB+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`B16%S=&5R;B!3=6UM97(@5&EM92`H5FEC=&]R
M:6$I(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@
M)T5T8R]'350M,3`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V
M,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=-5"LQ,#HP,"(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ,#HP,"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T=U86TG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D-H86UO<G)O(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#:%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U!A8VEF:6,O4&]R=%]-;W)E<V)Y)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")087!U82!.97<@1W5I;F5A(%1I;64B+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=01U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G4&%C:69I8R]386EP86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-H86UO<G)O
M(%-T86YD87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#:%-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O
M5')U:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`B5')U:R!4:6UE(BP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G5%)55"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=086-I9FEC+UEA<"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B66%P
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=905!4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI82],2$DG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,W.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(DQO860@2&]W92!3=&%N9&%R9"!4:6UE(BP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G3$A35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("),;V%D($AO=V4@
M4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=,2%-4
M)R`I+`H@("`@)T%U<W1R86QI82],;W)D7TAO=V4G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,W.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@(DQO860@2&]W92!3=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G3$A35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("),;V%D($AO=V4@4W5M;65R(%1I;64B
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=,2%-4)R`I+`H@("`@)T%S
M:6$O36%G861A;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B36%G861A;B!4:6UE(BP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G34%'5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")-86=A9&%N
M(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G34%'
M4U0G("DL"B`@("`G171C+T=-5"TQ,2<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1TU4
M*S$Q.C`P(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S$Q.C`P)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O169A
M=&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(E9A;G5A='4@5&EM92(L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U955"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=086-I9FEC+T=U861A;&-A;F%L)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^(")3;VQO;6]N($ES+B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G4T)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A
M8VEF:6,O2V]S<F%E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")+;W-R864@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TM/4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R].;W5M96$G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(DYE=R!#86QE9&]N:6$@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TY#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=086-I9FEC+U!O;F%P92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4&]N87!E
M(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=03TY4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-35"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B4V]L;VUO;B!)<RX@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U-"5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=0
M86-I9FEC+TYO<F9O;&LG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#0Q-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(DYO<F9O;&L@5&EM
M92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY&5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T:6-A+TUC375R9&\G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(DYE=R!:96%L86YD(%-T86YD87)D(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=.6E-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DYE=R!:96%L
M86YD($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=.6D14)R`I+`H@("`@)T%N=&%R8W1I8V$O4V]U=&A?4&]L92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B3F5W(%IE86QA;F0@4W1A;F1A<F0@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)TY:4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B3F5W(%IE86QA;F0@
M1&%Y;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TY:
M1%0G("DL"B`@("`G07-I82]!;F%D>7(G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D%N
M861Y<B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04Y!5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")!;F%D>7(@4W5M;65R(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=!3D%35"<@*2P*("`@("=!<VEA+TMA;6-H871K82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B4&5T<F]P879L;W9S:RU+86UC:&%T<VMI(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=01514)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(E!E=')O<&%V
M;&]V<VLM2V%M8VAA='-K:2!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)U!%5%-4)R`I+`H@("`@)T5T8R]'350M,3(G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@(D=-5"LQ,CHP,"(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"LQ,CHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=+=V%J86QE:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(DUA<G-H86QL($ES
M;&%N9',@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU(5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=.4U0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(DYE=R!:96%L86YD(%-T86YD87)D(%1I;64B+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=.6E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(DYE=R!:96%L86YD($1A
M>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=.6D14
M)R`I+`H@("`@)TY:)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T
M,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(").97<@6F5A;&%N9"!3
M=&%N9&%R9"!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3EI35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^(").97<@6F5A;&%N9"!$87EL:6=H="!4:6UE(BP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G3EI$5"<@*2P*("`@("=086-I9FEC+T%U8VML
M86YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^(").97<@6F5A;&%N9"!3=&%N9&%R9"!4
M:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3EI35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(").
M97<@6F5A;&%N9"!$87EL:6=H="!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G3EI$5"<@*2P*("`@("=086-I9FEC+T9I:FDG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(D9I:FD@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T9*5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I
M9FEC+T9U;F%F=71I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T
M,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")4=79A;'4@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U165"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+TMW86IA;&5I;B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B36%R<VAA;&P@27-L86YD<R!4:6UE(BP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G34A4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U!A8VEF:6,O36%J=7)O)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")-
M87)S:&%L;"!)<VQA;F1S(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=-2%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C
M:69I8R].875R=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B3F%U<G4@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TY25"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U1A<F%W82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`B1VEL8F5R="!)<RX@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=)3%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M4&%C:69I8R]786ME)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T
M,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")786ME(%1I;64B+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=704M4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O5V%L;&ES)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^(")786QL:7,@)B!&=71U;F$@5&EM92(L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U=&5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=.6BU#2$%4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T
M-3DP,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^(")#:&%T:&%M(%-T86YD
M87)D(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#2$%35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^(")#:&%T:&%M($1A>6QI9VAT(%1I;64B+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#2$%$5"<@*2P*("`@("=086-I9FEC+T-H871H86TG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0U.3`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@(D-H871H86T@4W1A;F1A<F0@5&EM92(L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-(05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@(D-H871H86T@1&%Y
M;&EG:'0@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-(0414
M)R`I+`H@("`@)T5T8R]'350M,3,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#0V.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D=-5"LQ
M,SHP,"(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ,SHP,"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T5N9&5R
M8G5R>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#8X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`B4&AO96YI>"!)<RX@5&EM92(L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U!(3U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]4;VYG871A<'4G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#0V.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@(E1O;F=A(%1I;64B+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=43U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C
M+T=-5"TQ-"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-3`T,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B1TU4*S$T.C`P(BP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4*S$T.C`P)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O2VER:71I;6%T:2<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-3`T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`B3&EN92!)<RX@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TQ)3E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("D**3L*
M"B\O"B\O($EN:71I86QI>F4@9&5F875L="!T:6UE>F]N90HO+R`@1FER<W0@
M=')Y(%]$051%7U1)345:3TY%7T1%1D%53%0@9VQO8F%L+`HO+R`@=&AE;B!0
M2%!?5%H@96YV:7)O;FUE;G0@=F%R+"!T:&5N(%1:(&5N=FER;VYM96YT('9A
M<@HO+PII9BAI<W-E="@D7T1!5$5?5$E-15I/3D5?1$5&055,5"D@"B`@("`F
M)B!$871E7U1I;65:;VYE.CII<U9A;&ED240H)%]$051%7U1)345:3TY%7T1%
M1D%53%0I"BD@>PH@("`@1&%T95]4:6UE6F]N93HZ<V5T1&5F875L="@D7T1!
M5$5?5$E-15I/3D5?1$5&055,5"D["GT@96QS96EF("AG971E;G8H)U!(4%]4
M6B<I("8F($1A=&5?5&EM95IO;F4Z.FES5F%L:61)1"AG971E;G8H)U!(4%]4
M6B<I*2D@>PH@("`@1&%T95]4:6UE6F]N93HZ<V5T1&5F875L="AG971E;G8H
M)U!(4%]46B<I*3L*?2!E;'-E:68@*&=E=&5N=B@G5%HG*2`F)B!$871E7U1I
M;65:;VYE.CII<U9A;&ED240H9V5T96YV*"=46B<I*2D@>PH@("`@1&%T95]4
M:6UE6F]N93HZ<V5T1&5F875L="AG971E;G8H)U1:)RDI.PI](&5L<V5I9B`H
M1&%T95]4:6UE6F]N93HZ:7-686QI9$E$*&1A=&4H)U0G*2DI('L*("`@($1A
M=&5?5&EM95IO;F4Z.G-E=$1E9F%U;'0H9&%T92@G5"<I*3L*?2!E;'-E('L*
M("`@($1A=&5?5&EM95IO;F4Z.G-E=$1E9F%U;'0H)U540R<I.PI]"B\O"B\O
M($5.1`H_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B],;V<O````````````````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P,38P
M-C4`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]S<6QI=&4N<&AP
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W-S,T
M`#$P-#$W,S8S,#`W`#`R,#$Q,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I;VX@-"XP("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@0F5R=')A
M;F0@36%N<VEO;B`\8FUA;G-I;VY`;6%M87-A;2YC;VT^("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!S<6QI=&4N<&AP+'8@,2XS(#(P,#0O,#$O,3D@,#@Z,#(Z-#`@
M:F]N($5X<"`D"@HO*BH*("H@5&AE($QO9U]S<6QI=&4@8VQA<W,@:7,@82!C
M;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S=')A
M8W0@8VQA<W,@=VAI8V@@<V5N9',@;65S<V%G97,@=&\@86X@4W%L:71E(&1A
M=&%B87-E+@H@*B!%86-H(&5N=')Y(&]C8W5P:65S(&$@<V5P87)A=&4@<F]W
M(&EN('1H92!D871A8F%S92X*("H*("H@5&AI<R!I;7!L96UE;G1A=&EO;B!U
M<V5S(%!(4"!N871I=F4@4W%L:71E(&9U;F-T:6]N<RX*("H*("H@0U)%051%
M(%1!0DQ%(&QO9U]T86)L92`H"B`J("!I9"`@("`@("`@("!)3E1%1T52(%!2
M24U!4ED@2T59($Y/5"!.54Q,+`H@*B`@;&]G=&EM92`@("`@3D]4($Y53$PL
M"B`J("!I9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("H@('!R:6]R
M:71Y("`@($E.5"!.3U0@3E5,3"P*("H@(&UE<W-A9V4*("H@*3L*("H*("H@
M0&%U=&AO<B`@0F5R=')A;F0@36%N<VEO;B`\8FUA;G-I;VY`;6%M87-A;2YC
M;VT^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`
M<VEN8V4@("!,;V<@,2XX+C,*("H@0'!A8VMA9V4@3&]G"B`J"B`J($!E>&%M
M<&QE('-Q;&ET92YP:'`@("`@("!5<VEN9R!T:&4@4W%L:71E(&AA;F1L97(N
M"B`J+PIC;&%S<R!,;V=?<W%L:71E(&5X=&5N9',@3&]G"GL*("`@("\J*@H@
M("`@("H@07)R87D@8V]N=&%I;FEN9R!T:&4@8V]N;F5C=&EO;B!D969A=6QT
M<PH@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A>2@G;6]D92<@("`@("`@
M/3X@,#8V-BP*("`@("`@("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N
M="<@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@3V)J96-T(&AO;&1I;F<@
M=&AE(&1A=&%B87-E(&AA;F1L92X*("`@("`J($!V87(@;V)J96-T"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&(@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@1FQA9R!I;F1I8V%T:6YG('1H870@=V4G<F4@
M=7-I;F<@86X@97AI<W1I;F<@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V5X:7-T:6YG0V]N;F5C=&EO;B`](&9A;'-E.PH*("`@("\J
M*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&1A=&%B87-E('1A8FQE('1O
M('5S92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?=&%B;&4@/2`G;&]G7W1A8FQE)SL*"@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W('-Q;"!L;V=G:6YG(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@
M("`@5&AE('1A<F=E="!344P@=&%B;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9&5N="`@("`@("`@5&AE(&ED96YT:69I8V%T:6]N(&9I96QD+@H@("`@
M("H@0'!A<F%M(&UI>&5D("`D8V]N9B`@("`@("`@($-A;B!B92!A;B!A<G)A
M>2!O9B!C;VYF:6=U<F%T:6]N(&]P=&EO;G,@=7-E9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1O(&]P96X@82!N97<@9&%T86)A<V4@
M8V]N;F5C=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&]R(&%N(&%L<F5A9'D@;W!E;F5D('-Q;&ET92!C;VYN96-T:6]N+@H@("`@
M("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@("`@($QO9R!M97-S86=E<R!U
M<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S
M('!U8FQI8R`@("`@"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]S<6QI=&4H
M)&YA;64L("1I9&5N="`]("<G+"`F)&-O;F8L("1L979E;"`](%!%05)?3$]'
M7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T
M:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?=&%B;&4@/2`D;F%M93L*("`@("`@
M("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S
M:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H:7-?87)R87DH
M)&-O;F8I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYF(&%S("1K(#T^
M("1O<'0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N<ULD:UT@
M/2`D;W!T.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@268@86X@97AI<W1I;F<@9&%T86)A<V4@8V]N;F5C=&EO;B!W
M87,@<')O=FED960L('5S92!I="X*("`@("`@("`@("`@)'1H:7,M/E]D8B`]
M)B`D8V]N9CL*("`@("`@("`@("`@)'1H:7,M/E]E>&ES=&EN9T-O;FYE8W1I
M;VX@/2!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($]P
M96YS(&$@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4L(&EF(&ET(&AA<R!N
M;W0@86QR96%D>0H@("`@("H@8F5E;B!O<&5N960N(%1H:7,@:7,@:6UP;&EC
M:71L>2!C86QL960@8GD@;&]G*"DL(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8R`@("`@"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("AI<U]R
M97-O=7)C92@D=&AI<RT^7V1B*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V]P
M96YE9"`]('1R=64["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-R96%T
M951A8FQE*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@4V5T
M('1H92!C;VYN96-T:6]N(&9U;F-T:6]N(&)A<V5D(&]N('1H92`G<&5R<VES
M=&5N="<@;W!T:6]N+B`J+PH@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]O<'1I;VYS6R=P97)S:7-T96YT)UTI*2!["B`@("`@("`@("`@("`@("`D
M8V]N;F5C=$9U;F-T:6]N(#T@)W-Q;&ET95]O<&5N)SL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;VYN96-T1G5N8W1I;VX@/2`G
M<W%L:71E7W!O<&5N)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M071T96UP="!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X@*B\*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?9&(@/2`D8V]N;F5C=$9U;F-T:6]N*"1T:&ES
M+3Y?;W!T:6]N<ULG9FEL96YA;64G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("AI;G0I)'1H:7,M/E]O<'1I;VYS
M6R=M;V1E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97)R;W(I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V]P96YE9"`]('1R=64["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]C<F5A=&5486)L92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]O<&5N960["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;&]S97,@=&AE(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E(&EF
M(&ET(&ES('-T:6QL(&]P96X@86YD('=E('=E<F4*("`@("`J('1H92!O;F5S
M('1H870@;W!E;F5D(&ET+B`@270@:7,@=&AE(&-A;&QE<B=S(')E<W!O;G-I
M8FQE('1O(&-L;W-E(&%N"B`@("`@*B!E>&ES=&EN9R!C;VYN96-T:6]N('1H
M870@=V%S('!A<W-E9"!T;R!U<R!V:6$@)&-O;F9;)V1B)UTN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS
M92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,@("`@(`H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@5V4@
M;F5V97(@8VQO<V4@97AI<W1I;F<@8V]N;F5C=&EO;G,N("HO"B`@("`@("`@
M:68@*"1T:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^
M7V]P96YE9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E
M.PH@("`@("`@("`@("!S<6QI=&5?8VQO<V4H)'1H:7,M/E]D8BD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G-E<G1S("1M97-S86=E('1O
M('1H92!C=7)R96YT;'D@;W!E;B!D871A8F%S92X@($-A;&QS(&]P96XH*2P*
M("`@("`J(&EF(&YE8V5S<V%R>2X@($%L<V\@<&%S<V5S('1H92!M97-S86=E
M(&%L;VYG('1O(&%N>2!,;V=?;V)S97)V97(*("`@("`J(&EN<W1A;F-E<R!T
M:&%T(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN
M:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@
M)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED
M"B`@("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'
M7T5-15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@("`@
M("`@4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).
M24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)0T4L
M(%!%05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A
M:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8R`@("`@"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@
M('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I
M9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D
M<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@
M)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T
M(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L
M;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME
M9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("\J($EF('1H92!C;VYN96-T:6]N(&ES;B=T(&]P
M96X@86YD(&-A;B=T(&)E(&]P96YE9"P@<F5T=7)N(&9A:6QU<F4N("HO"B`@
M("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`A)'1H:7,M/F]P96XH*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`O+R!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE
M(&UE<W-A9V4N"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-
M97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@+R\@0G5I;&0@=&AE(%-13"!Q
M=65R>2!F;W(@=&AI<R!L;V<@96YT<GD@:6YS97)T:6]N+@H@("`@("`@("1Q
M(#T@<W!R:6YT9B@G24Y315)4($E.5$\@6R5S72`H;&]G=&EM92P@:61E;G0L
M('!R:6]R:71Y+"!M97-S86=E*2`G("X*("`@("`@("`@("`@("`@("`@("`@
M(E9!3%5%4R`H)R5S)RP@)R5S)RP@)60L("<E<R<I(BP*("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]T86)L92P*("`@("`@("`@("`@("`@("`@("`@
M<W1R9G1I;64H)R59+25M+25D("5(.B5-.B53)RP@=&EM92@I*2P*("`@("`@
M("`@("`@("`@("`@("`@<W%L:71E7V5S8V%P95]S=')I;F<H)'1H:7,M/E]I
M9&5N="DL"B`@("`@("`@("`@("`@("`@("`@("1P<FEO<FET>2P*("`@("`@
M("`@("`@("`@("`@("`@<W%L:71E7V5S8V%P95]S=')I;F<H)&UE<W-A9V4I
M*3L*("`@("`@("!I9B`H(2@D<F5S(#T@0'-Q;&ET95]U;F)U9F9E<F5D7W%U
M97)Y*"1T:&ES+3Y?9&(L("1Q*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y
M*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A
M9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@=VAE=&AE<B!T:&4@;&]G('1A8FQE(&5X:7-T<R!A;F0@
M8W)E871E<R!I="!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R
M92X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8W)E871E5&%B;&4H*0H@("`@>PH@("`@("`@("1Q(#T@(E-%3$5#5"!N
M86UE($923TT@<W%L:71E7VUA<W1E<B!72$5212!N86UE/2<B("X@)'1H:7,M
M/E]T86)L92`N"B`@("`@("`@("`@("`B)R!!3D0@='EP93TG=&%B;&4G(CL*
M"B`@("`@("`@)')E<R`]('-Q;&ET95]Q=65R>2@D=&AI<RT^7V1B+"`D<2D[
M"@H@("`@("`@(&EF("AS<6QI=&5?;G5M7W)O=W,H)')E<RD@/3T@,"D@>PH@
M("`@("`@("`@("`D<2`]("=#4D5!5$4@5$%"3$4@6R<@+B`D=&AI<RT^7W1A
M8FQE("X@)UT@*"<@+@H@("`@("`@("`@("`@("`@("=I9"!)3E1%1T52(%!2
M24U!4ED@2T59($Y/5"!.54Q,+"`G("X*("`@("`@("`@("`@("`@("`G;&]G
M=&EM92!.3U0@3E5,3"P@)R`N"B`@("`@("`@("`@("`@("`@)VED96YT($-(
M05(H,38I($Y/5"!.54Q,+"`G("X*("`@("`@("`@("`@("`@("`G<')I;W)I
M='D@24Y4($Y/5"!.54Q,+"`G("X*("`@("`@("`@("`@("`@("`G;65S<V%G
M92DG.PH*("`@("`@("`@("`@:68@*"$H)')E<R`]('-Q;&ET95]U;F)U9F9E
M<F5D7W%U97)Y*"1T:&ES+3Y?9&(L("1Q*2DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"GT*"C\^"@``````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B],;V<O8V]M<&]S:71E+G!H<```````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,3,W-P`Q,#0Q-S,V,S`P-P`P,C`V,#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]C;VUP;W-I
M=&4N<&AP+'8@,2XR,B`R,#`T+S`Q+S$Y(#`X.C`R.C0P(&IO;B!%>'`@)`H@
M*B`D2&]R9&4Z(&AO<F1E+VQI8B],;V<O8V]M<&]S:71E+G!H<"QV(#$N,B`R
M,#`P+S`V+S(X(#(Q.C,V.C$S(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D
M4F5V:7-I;VXZ(#$N,C(@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO*BH*("H@
M5&AE($QO9U]C;VUP;W-I=&4Z.B!C;&%S<R!I;7!L96UE;G1S(&$@0V]M<&]S
M:71E('!A='1E<FX@=VAI8V@*("H@86QL;W=S(&UU;'1I<&QE($QO9R!I;7!L
M96UE;G1A=&EO;G,@=&\@<F5C96EV92!T:&4@<V%M92!E=F5N=',N"B`J"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X*("H*("H@0'-I
M;F-E($AO<F1E(#$N,PH@*B!`<VEN8V4@3&]G(#$N,`H@*B!`<&%C:V%G92!,
M;V<*("H*("H@0&5X86UP;&4@8V]M<&]S:71E+G!H<"`@(%5S:6YG('1H92!C
M;VUP;W-I=&4@:&%N9&QE<BX*("HO"F-L87-S($QO9U]C;VUP;W-I=&4@97AT
M96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!!<G)A>2!H;VQD:6YG(&%L;"!O
M9B!T:&4@3&]G(&EN<W1A;F-E<R!T;R!W:&EC:"!L;V<@979E;G1S('-H;W5L
M9"!B90H@("`@("H@<V5N="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?8VAI;&1R
M96X@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N
M97<@8V]M<&]S:71E($QO9R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@("`D;F%M92`@("`@("!4:&ES('!A<F%M971E<B!I<R!I9VYO
M<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@("`D:61E;G0@("`@("!4:&ES
M('!A<F%M971E<B!I<R!I9VYO<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M("`D8V]N9B`@("`@("!4:&ES('!A<F%M971E<B!I<R!I9VYO<F5D+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@("`D;&5V96P@("`@("!4:&ES('!A<F%M971E
M<B!I<R!I9VYO<F5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N($QO9U]C;VUP;W-I=&4H)&YA;64@/2!F86QS
M92P@)&ED96YT(#T@9F%L<V4L("1C;VYF(#T@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@
M>PH@("`@?0H*("`@("\J*@H@("`@("H@3W!E;G,@=&AE(&-H:6QD(&-O;FYE
M8W1I;VYS+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M
M/E]O<&5N960I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C:&EL
M9')E;B!A<R`D:60@/3X@)&-H:6QD*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-H:6QD<F5N6R1I9%TM/F]P96XH*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E<R!A;GD@8VAI;&0@
M:6YS=&%N8V5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/E]O<&5N960I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C
M:&EL9')E;B!A<R`D:60@/3X@)&-H:6QD*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-H:6QD<F5N6R1I9%TM/F-L;W-E*"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;'5S:&5S(&%L;"!O
M<&5N(&-H:6QD(&EN<W1A;F-E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-I;F-E($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC
M=&EO;B!F;'5S:"@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAI;&1R96X@87,@
M)&ED(#T^("1C:&EL9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&EL
M9')E;ELD:61=+3YF;'5S:"@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@)&UE<W-A9V4@86YD("1P<FEO
M<FET>2!T;R!E86-H(&-H:6QD(&]F('1H:7,@8V]M<&]S:71E+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`@("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R
M(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1O(&QO9RX*("`@("`J($!P87)A;2!S
M=')I;F<@("`@)'!R:6]R:71Y("`@*&]P=&EO;F%L*2!4:&4@<')I;W)I='D@
M;V8@=&AE(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%9A;&ED('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U]!3$52
M5"P@4$5!4E],3T=?0U))5"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)
M0T4L(%!%05)?3$]'7TE.1D\L(&%N9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!014%27TQ/1U]$14)51RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&5N=')Y(&ES('-U8V-E<W-F
M=6QL>2!L;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N
M=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E
M96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@
M("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I
M;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]C:&EL9')E;B!A<R`D:60@/3X@)&-H:6QD*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?8VAI;&1R96Y;)&ED72T^;&]G*"1M97-S
M86=E+"`D<')I;W)I='DI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]A
M;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A
M9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF('1H:7,@:7,@82!C
M;VUP;W-I=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF('1H:7,@:7,@82!C;VUP;W-I=&4@8VQA<W,N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;VUP;W-I
M=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!T:&ES(&ED96YT:69I8V%T:6]N('-T<FEN9R!F;W(@
M86QL(&]F('1H:7,@8V]M<&]S:71E)W,@8VAI;&1R96XN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@("`D:61E;G0@("`@("!4:&4@;F5W(&ED96YT
M:69I8V%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-I;F-E("!,;V<@,2XV+C<*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T261E;G0H)&ED96YT*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?8VAI;&1R96X@87,@)&ED(#T^("1C:&EL9"D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V-H:6QD<F5N6R1I9%TM/G-E=$ED96YT*"1I9&5N="D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A($QO9R!I;G-T
M86YC92!T;R!T:&4@;&ES="!O9B!C:&EL9')E;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@;V)J96-T("`@("1C:&EL9"`@("`@(%1H92!,;V<@:6YS=&%N8V4@
M=&\@861D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T:&4@3&]G(&EN<W1A;F-E('=A<R!S=6-C97-S9G5L;'D@861D960N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D0VAI;&0H)B1C:&EL9"D*("`@('L*("`@("`@("`O*B!-86ME('-U
M<F4@=&AI<R!I<R!A($QO9R!I;G-T86YC92X@*B\*("`@("`@("!I9B`H(6ES
M7V$H)&-H:6QD+"`G3&]G)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&EL9')E;ELD8VAI;&0M
M/E]I9%T@/2`F)&-H:6QD.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!,;V<@:6YS=&%N8V4@9G)O;2!T
M:&4@;&ES="!O9B!C:&EL9')E;BX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T("`@("1C:&EL9"`@("`@(%1H92!,;V<@:6YS=&%N8V4@=&\@<F5M;W9E
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@
M3&]G(&EN<W1A;F-E('=A<R!S=6-C97-S9G5L;'D@<F5M;W9E9"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!R
M96UO=F5#:&EL9"@D8VAI;&0I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1C
M:&EL9"P@)TQO9R<I('Q\("%I<W-E="@D=&AI<RT^7V-H:6QD<F5N6R1C:&EL
M9"T^7VED72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@=6YS970H)'1H:7,M/E]C:&EL9')E;ELD8VAI;&0M/E]I
M9%TI.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*?0H*/SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O3&]G+V1I<W!L87DN<&AP````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8T-S``,3`T,3<S-C,P,#<`,#(P,C0W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O
M9&ES<&QA>2YP:'`L=B`Q+C4@,C`P-"\P,2\Q.2`P.#HP,CHT,"!J;VX@17AP
M("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C4@)`H@*B!`<&%C:V%G
M92!,;V<*("HO"@HO*BH*("H@5&AE($QO9U]D:7-P;&%Y(&-L87-S(&ES(&$@
M8V]N8W)E=&4@:6UP;&5M96YT871I;VX@;V8@=&AE($QO9SHZ"B`J(&%B<W1R
M86-T(&-L87-S('=H:6-H('=R:71E<R!M97-S86=E(&EN=&\@8G)O=W-E<B!I
M;B!U<W5A;"!02%`@;6%N97(N"B`J(%1H:7,@;6%Y(&)E('5S969U;"!B96-A
M=7-E('=H96X@>6]U('5S92!014%2.CIS971%<G)O<DAA;F1L:6YG(&EN"B`J
M(%!%05)?15)23U)?0T%,3$)!0TL@;6]D92!E<G)O<B!M97-S86=E<R!A<F4@
M;F]T(&1I<W!L87EE9"!B>0H@*B!02%`@97)R;W(@:&%N9&QE<BX*("H*("H@
M0&%U=&AO<B`@4&%U;"!986YC:&5N:V\@/'!U<VAE<D!I;F%C;RYR=3X*("H@
M0'-I;F-E("`@3&]G(#$N."XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA
M;7!L92!D:7-P;&%Y+G!H<"`@("`@57-I;F<@=&AE(&1I<W!L87D@:&%N9&QE
M<BX*("HO"F-L87-S($QO9U]D:7-P;&%Y(&5X=&5N9',@3&]G"GL*("`@("\J
M*@H@("`@("H@4W1R:6YG('1O(&]U='!U="!B969O<F4@86X@97)R;W(@;65S
M<V%G90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]E<G)O<E]P<F5P96YD(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!3=')I;F<@=&\@;W5T<'5T(&%F=&5R(&%N(&5R<F]R(&UE
M<W-A9V4*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?97)R;W)?87!P96YD(#T@)R<["@H*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,;V=?9&ES<&QA>2!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@26=N
M;W)E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&ED96YT("`@(%1H92!I9&5N
M=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@("1C;VYF("`@("!4
M:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*("`@("`J($!P87)A;2!I;G0@("`@
M)&QE=F5L("`@($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H
M:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!,;V=?9&ES<&QA>2@D;F%M92`]("<G+"`D:61E;G0@/2`G)RP@
M)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&QE
M=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I
M9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]I9&5N="`]
M("1I9&5N=#L*("`@("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z.E505$\H)&QE
M=F5L*3L*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG97)R;W)?<')E<&5N
M9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R7W!R97!E;F0@/2`D
M8V]N9ELG97)R;W)?<')E<&5N9"==.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W)?<')E<&5N9"`](&EN:5]G970H)V5R<F]R
M7W!R97!E;F1?<W1R:6YG)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M
M<'1Y*"1C;VYF6R=E<G)O<E]A<'!E;F0G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]E<G)O<E]A<'!E;F0@/2`D8V]N9ELG97)R;W)?87!P96YD)UT["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<E]A<'!E
M;F0@/2!I;FE?9V5T*"=E<G)O<E]A<'!E;F1?<W1R:6YG)RD["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&5S("1M97-S86=E('1O('1H
M92!T97AT(&)R;W=S97(N($%L<V\L('!A<W-E<R!T:&4@;65S<V%G90H@("`@
M("H@86QO;F<@=&\@86YY($QO9U]O8G-E<G9E<B!I;G-T86YC97,@=&AA="!A
M<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG
M('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R
M:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@
M("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-
M15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@("`@("`@
M4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'
M+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%
M05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU
M<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@
M("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S
M92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?
M<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I
M9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L
M979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R
M:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@
M;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^
M7V5X=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@+RH@0G5I;&0@
M86YD(&]U='!U="!T:&4@8V]M<&QE=&4@;&]G(&QI;F4N("HO"B`@("`@("`@
M96-H;R`D=&AI<RT^7V5R<F]R7W!R97!E;F0@+@H@("`@("`@("`@("`@)SQB
M/B<@+B!U8V9I<G-T*"1T:&ES+3YP<FEO<FET>51O4W1R:6YG*"1P<FEO<FET
M>2DI("X@)SPO8CXZ("<N"B`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S
M*"1M97-S86=E*2`N"B`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R7V%P<&5N
M9"`N("(\8G(@+SY<;B(["@H@("`@("`@("\J($YO=&EF>2!O8G-E<G9E<G,@
M86)O=70@=&AI<R!L;V<@;65S<V%G92X@*B\*("`@("`@("`D=&AI<RT^7V%N
M;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G
M92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"GT*"C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TQO9R]O8G-E<G9E<BYP:'``````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-S$Q`#$P-#$W,S8S,#`W`#`R,#0S
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G
M+V]B<V5R=F5R+G!H<"QV(#$N,3(@,C`P-"\P,2\Q,2`R,#HT.3HT.2!J;VX@
M17AP("0*("H@)$AO<F1E.B!H;W)D92]L:6(O3&]G+V]B<V5R=F5R+G!H<"QV
M(#$N-2`R,#`P+S`V+S(X(#(Q.C,V.C$S(&IO;B!%>'`@)`H@*@H@*B!`=F5R
M<VEO;B`D4F5V:7-I;VXZ(#$N,3(@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO
M*BH*("H@5&AE($QO9U]O8G-E<G9E<CHZ(&-L87-S(&EM<&QE;65N=',@=&AE
M($]B<V5R=F5R(&5N9"!O9B!A(%-U8FIE8W0M3V)S97)V97(*("H@<&%T=&5R
M;B!F;W(@=V%T8VAI;F<@;&]G(&%C=&EV:71Y(&%N9"!T86MI;F<@86-T:6]N
M<R!O;B!E>&-E<'1I;VYA;"!E=F5N=',N"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`Q+C,*("H@0'-I;F-E("`@3&]G(#$N,`H@*B!`<&%C:V%G92!,;V<*("H*
M("H@0&5X86UP;&4@;V)S97)V97)?;6%I;"YP:'`@("!!;B!E>&%M<&QE($QO
M9U]O8G-E<G9E<B!I;7!L96UE;G1A=&EO;BX*("HO"F-L87-S($QO9U]O8G-E
M<G9E<@I["B`@("`O*BH*("`@("`J($EN<W1A;F-E+7-P96-I9FEC('5N:7%U
M92!I9&5N=&EF:6-A=&EO;B!N=6UB97(N"B`@("`@*@H@("`@("H@0'9A<B!I
M;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?:60@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&UI;FEM=6T@<')I;W)I
M='D@;&5V96P@;V8@;65S<V%G92!T:&%T('=E('=A;G0@=&\@:&5A<B!A8F]U
M="X*("`@("`J(%!%05)?3$]'7T5-15)'(&ES('1H92!H:6=H97-T('!R:6]R
M:71Y+"!S;R!W92!W:6QL(&]N;'D@:&5A<B!M97-S86=E<PH@("`@("H@=VET
M:"!A;B!I;G1E9V5R('!R:6]R:71Y('9A;'5E(&QE<W,@=&AA;B!O<B!E<75A
M;"!T;R!O=7)S+B`@270@9&5F875L=',*("`@("`J('1O(%!%05)?3$]'7TE.
M1D\L('=H:6-H(&QI<W1E;G,@=&\@979E<GET:&EN9R!E>&-E<'0@4$5!4E],
M3T=?1$5"54<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]P<FEO<FET>2`](%!%
M05)?3$]'7TE.1D\["@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W(&)A
M<VEC($QO9U]O8G-E<G9E<B!I;G-T86YC92X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`@("1P<FEO<FET>2`@(%1H92!H:6=H97-T('!R:6]R:71Y
M(&%T('=H:6-H('1O(')E8V5I=F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;&]G(&5V96YT(&YO=&EF:6-A=&EO;G,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@3&]G
M7V]B<V5R=F5R*"1P<FEO<FET>2`](%!%05)?3$]'7TE.1D\I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@
M)'1H:7,M/E]P<FEO<FET>2`]("1P<FEO<FET>3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&YE=R!C;VYC<F5T92!,;V=?
M;V)S97)V97(@:6YS=&%N8V4@;V8@=&AE(')E<75E<W1E9`H@("`@("H@='EP
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1T>7!E("`@("`@
M(%1H92!T>7!E(&]F(&-O;F-R96%T92!,;V=?;V)S97)V97(@<W5B8VQA<W,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@<F5T=7)N
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@("`D<')I;W)I='D@("!4:&4@:&EG
M:&5S="!P<FEO<FET>2!A="!W:&EC:"!T;R!R96-E:79E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&QO9R!E=F5N="!N;W1I9FEC871I
M;VYS+@H@("`@("H@0'!A<F%M(&%R<F%Y("`@("`D8V]N9B`@("`@("!/<'1I
M;VYA;"!A<W-O8VEA=&EV92!A<G)A>2!O9B!A9&1I=&EO;F%L"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;F9I9W5R871I;VX@=F%L
M=65S+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("`@("`@("`@("`@
M("`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@3&]G7V]B<V5R=F5R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;F-E+"!O
M<B!A;B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F9A8W1O<GDH)'1Y<&4L("1P<FEO<FET>2`](%!%05)?3$]'7TE.1D\L("1C
M;VYF(#T@87)R87DH*2D*("`@('L*("`@("`@("`D='EP92`]('-T<G1O;&]W
M97(H)'1Y<&4I.PH@("`@("`@("1C;&%S<R`]("=,;V=?;V)S97)V97)?)R`N
M("1T>7!E.PH*("`@("`@("`O*B!3=7!P;W)T(&)O=&@@=&AE(&YE=RUS='EL
M92!A;F0@;VQD+7-T>6QE(&9I;&4@;F%M:6YG(&-O;G9E;G1I;VYS+B`J+PH@
M("`@("`@(&EF("AF:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O
M;V)S97)V97)?)R`N("1T>7!E("X@)RYP:'`G*2D@>PH@("`@("`@("`@("`D
M8VQA<W-F:6QE(#T@)TQO9R]O8G-E<G9E<E\G("X@)'1Y<&4@+B`G+G!H<"<[
M"B`@("`@("`@("`@("1N97=S='EL92`]('1R=64["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&-L87-S9FEL92`]("=,;V<O)R`N("1T>7!E("X@
M)RYP:'`G.PH@("`@("`@("`@("`D;F5W<W1Y;&4@/2!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\J($ES<W5E(&$@=V%R;FEN9R!I9B!T:&4@;VQD+7-T
M>6QE(&-O;G9E;G1I;VYS(&%R92!B96EN9R!U<V5D+B`J+PH@("`@("`@(&EF
M("@A)&YE=W-T>6QE*0H@("`@("`@('L*("`@("`@("`@("`@=')I9V=E<E]E
M<G)O<B@G57-I;F<@;VQD+7-T>6QE($QO9U]O8G-E<G9E<B!C;VYV96YT:6]N
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@15]54T527U=!4DY)3D<I
M.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B!!='1E;7!T('1O
M(&EN8VQU9&4@;W5R('9E<G-I;VX@;V8@=&AE(&YA;65D(&-L87-S+"!B=70@
M9&]N)W0@=')E870*("`@("`@("`@*B!A(&9A:6QU<F4@87,@9F%T86PN("!4
M:&4@8V%L;&5R(&UA>2!H879E(&%L<F5A9'D@:6YC;'5D960@=&AE:7(@;W=N
M"B`@("`@("`@("H@=F5R<VEO;B!O9B!T:&4@;F%M960@8VQA<W,N"B`@("`@
M("`@("HO"B`@("`@("`@0&EN8VQU9&5?;VYC92`D8VQA<W-F:6QE.PH*("`@
M("`@("`O*B!)9B!T:&4@8VQA<W,@97AI<W1S+"!R971U<FX@82!N97<@:6YS
M=&%N8V4@;V8@:70N("HO"B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA
M<W,I*2!["B`@("`@("`@("`@("\J(%-U<'!O<G0@8F]T:"!N97<M<W1Y;&4@
M86YD(&]L9"US='EL92!C;VYS=')U8W1I;VXN("HO"B`@("`@("`@("`@(&EF
M("@D;F5W<W1Y;&4I('L*("`@("`@("`@("`@("`@(')E='5R;B!N97<@)&-L
M87-S*"1P<FEO<FET>2P@)&-O;F8I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&YE=R`D8VQA<W,H)'!R:6]R:71Y*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!I<R!A('-T=6(@;65T:&]D
M('1O(&UA:V4@<W5R92!T:&%T($QO9U]/8G-E<G9E<B!C;&%S<V5S(&1O"B`@
M("`@*B!S;VUE=&AI;F<@=VAE;B!T:&5Y(&%R92!N;W1I9FEE9"!O9B!A(&UE
M<W-A9V4N("!4:&4@9&5F875L="!B96AA=FEO<@H@("`@("H@:7,@=&\@:G5S
M="!P<FEN="!T:&4@;65S<V%G92P@=VAI8V@@:7,@;V)V:6]U<VQY(&YO="!D
M97-I<F5A8FQE(&EN"B`@("`@*B!P<F%C=&EC86QL>2!A;GD@<VET=6%T:6]N
M("T@=VAI8V@@:7,@=VAY('EO=2!N965D('1O(&]V97)R:61E('1H:7,*("`@
M("`J(&UE=&AO9"X@.BD*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`@
M("1E=F5N="`@("`@($$@:&%S:"!D97-C<FEB:6YG('1H92!L;V<@979E;G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO=&EF>2@D979E;G0I"B`@("!["B`@
M("`@("`@<')I;G1?<B@D979E;G0I.PH@("`@?0I]"@H_/@H`````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]S>7-L;V<N<&AP
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-#$S
M`#$P-#$W,S8S,#`W`#`R,#$Q,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S
M:71O<GDO<&5A<B],;V<O3&]G+W-Y<VQO9RYP:'`L=B`Q+C(R(#(P,#0O,#$O
M,3D@,#@Z,#(Z-#`@:F]N($5X<"`D"B`J("1(;W)D93H@:&]R9&4O;&EB+TQO
M9R]S>7-L;V<N<&AP+'8@,2XV(#(P,#`O,#8O,C@@,C$Z,S8Z,3,@:F]N($5X
M<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@,2XR,B`D"B`J($!P86-K
M86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7W-Y<VQO9R!C;&%S<R!I<R!A
M(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.@H@*B!A8G-T
M<F%C="!C;&%S<R!W:&EC:"!S96YD<R!M97-S86=E<R!T;R!S>7-L;V<@;VX@
M54Y)6"UL:6ME(&UA8VAI;F5S"B`J("A02%`@96UU;&%T97,@=&AI<R!W:71H
M('1H92!%=F5N="!,;V<@;VX@5VEN9&]W<R!M86-H:6YE<RDN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`Q+C,*("H@0'-I;F-E("`@3&]G(#$N,`H@*B!`<&%C
M:V%G92!,;V<*("H*("H@0&5X86UP;&4@<WES;&]G+G!H<"`@("`@(%5S:6YG
M('1H92!S>7-L;V<@:&%N9&QE<BX*("HO"F-L87-S($QO9U]S>7-L;V<@97AT
M96YD<R!,;V<*>PH@("`@+RHJ"B`@("`J($EN=&5G97(@:&]L9&EN9R!T:&4@
M;&]G(&9A8VEL:71Y('1O('5S92X@"B`@("`J($!V87(@<W1R:6YG"B`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@*B\*("`@('9A<B`D7VYA;64@/2!,3T=?
M4UE33$]'.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!S>7-L
M;V<@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M("`@(%1H92!S>7-L;V<@9F%C:6QI='DN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9&5N="`@("!4:&4@:61E;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("`D8V]N9B`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@
M("`@*B!`<&%R86T@:6YT("`@("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@
M=&\@86YD(&EN8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@3&]G7W-Y<VQO9R@D;F%M92P@
M)&ED96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@
M("`@+RH@16YS=7)E('=E(&AA=F4@82!V86QI9"!I;G1E9V5R('9A;'5E(&9O
M<B`D;F%M92X@*B\*("`@("`@("!I9B`H96UP='DH)&YA;64I('Q\("%I<U]I
M;G0H)&YA;64I*2!["B`@("`@("`@("`@("1N86UE(#T@3$]'7U-94TQ/1SL*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE
M*"DI.PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@("`@("1T
M:&ES+3Y?:61E;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M/E]M87-K(#T@
M3&]G.CI54%1/*"1L979E;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N
M<R!A(&-O;FYE8W1I;VX@=&\@=&AE('-Y<W1E;2!L;V=G97(L(&EF(&ET(&AA
M<R!N;W0@86QR96%D>0H@("`@("H@8F5E;B!O<&5N960N("!4:&ES(&ES(&EM
M<&QI8VET;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*
M("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@
M("`@(&]P96YL;V<H)'1H:7,M/E]I9&5N="P@3$]'7U!)1"P@)'1H:7,M/E]N
M86UE*3L*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VQO<V5S('1H92!C;VYN96-T:6]N('1O('1H92!S
M>7-T96T@;&]G9V5R+"!I9B!I="!I<R!O<&5N+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("!C;&]S96QO
M9R@I.PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L
M<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@)&UE<W-A9V4@=&\@
M=&AE(&-U<G)E;G1L>2!O<&5N('-Y<VQO9R!C;VYN96-T:6]N+B`@0V%L;',*
M("`@("`J(&]P96XH*2!I9B!N96-E<W-A<GDN($%L<V\@<&%S<V5S('1H92!M
M97-S86=E(&%L;VYG('1O(&%N>2!,;V=?;V)S97)V97(*("`@("`J(&EN<W1A
M;F-E<R!T:&%T(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1M97-S86=E(%-T<FEN9R!O<B!O8FIE8W0@8V]N
M=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R86T@:6YT
M("1P<FEO<FET>2`H;W!T:6]N86PI(%1H92!P<FEO<FET>2!O9B!T:&4@;65S
M<V%G92X@(%9A;&ED"B`@("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A
M<F4Z(%!%05)?3$]'7T5-15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@
M("`@("`@("`@("`@("`@4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!0
M14%27TQ/1U]705).24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("!014%2
M7TQ/1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)5
M1RX*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R
M(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU
M;&PI"B`@("!["B`@("`@("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E
M;B!S<&5C:69I960L('5S92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@
M("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO
M<FET>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O
M*B!!8F]R="!E87)L>2!I9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA
M>&EM=6T@;&]G9VEN9R!L979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?
M:7--87-K960H)'!R:6]R:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&4@8V]N;F5C=&EO;B!I
M<VXG="!O<&5N(&%N9"!C86XG="!B92!O<&5N960L(')E='5R;B!F86EL=7)E
M+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960@)B8@(21T:&ES+3YO
M<&5N*"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@+RH@17AT<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N
M(&]F('1H92!M97-S86=E+B`J+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M
M/E]E>'1R86-T365S<V%G92@D;65S<V%G92D["@H@("`@("`@(&EF("@A<WES
M;&]G*"1T:&ES+3Y?=&]3>7-L;V<H)'!R:6]R:71Y*2P@)&UE<W-A9V4I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I
M='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@4$5!4E],
M3T=?*B!C;VYS=&%N="!I;G1O(&$@<WES;&]G($Q/1U\J(&-O;G-T86YT+@H@
M("`@("H*("`@("`J(%1H:7,@9G5N8W1I;VX@97AI<W1S(&)E8V%U<V4L('5N
M9&5R(%=I;F1O=W,L(&YO="!A;&P@;V8@=&AE($Q/1U\J"B`@("`@*B!C;VYS
M=&%N=',@:&%V92!U;FEQ=64@=F%L=65S+B`@26YS=&5A9"P@=&AE(%!%05)?
M3$]'7RH@=V5R92!I;G1R;V1U8V5D"B`@("`@*B!F;W(@9VQO8F%L('5S92P@
M=VET:"!T:&4@8V]N=F5R<VEO;B!T;R!T:&4@3$]'7RH@8V]N<W1A;G1S(&ME
M<'0@;&]C86P@=&\*("`@("`J('1O('1H92!S>7-L;V<@9')I=F5R+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G0@)'!R:6]R:71Y("`@("!014%27TQ/1U\J
M('9A;'5E('1O(&-O;G9E<G0@=&\@3$]'7RH@=F%L=64N"B`@("`@*@H@("`@
M("H@0')E='5R;B`@5&AE($Q/1U\J(')E<')E<V5N=&%T:6]N(&]F("1P<FEO
M<FET>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W1O4WES;&]G*"1P<FEO<FET>2D*("`@('L*("`@("`@
M("!S=&%T:6,@)'!R:6]R:71I97,@/2!A<G)A>2@*("`@("`@("`@("`@4$5!
M4E],3T=?14U%4D<@("`]/B!,3T=?14U%4D<L"B`@("`@("`@("`@(%!%05)?
M3$]'7T%,15)4("`@/3X@3$]'7T%,15)4+`H@("`@("`@("`@("!014%27TQ/
M1U]#4DE4("`@(#T^($Q/1U]#4DE4+`H@("`@("`@("`@("!014%27TQ/1U]%
M4E(@("`@(#T^($Q/1U]%4E(L"B`@("`@("`@("`@(%!%05)?3$]'7U=!4DY)
M3D<@/3X@3$]'7U=!4DY)3D<L"B`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#
M12`@/3X@3$]'7TY/5$E#12P*("`@("`@("`@("`@4$5!4E],3T=?24Y&3R`@
M("`]/B!,3T=?24Y&3RP*("`@("`@("`@("`@4$5!4E],3T=?1$5"54<@("`]
M/B!,3T=?1$5"54<*("`@("`@("`I.PH*("`@("`@("`O*B!)9B!W92=R92!P
M87-S960@86X@=6YK;F]W;B!P<FEO<FET>2P@9&5F875L="!T;R!,3T=?24Y&
M3RX@*B\*("`@("`@("!I9B`H(6ES7VEN="@D<')I;W)I='DI('Q\("%I;E]A
M<G)A>2@D<')I;W)I='DL("1P<FEO<FET:65S*2D@>PH@("`@("`@("`@("!R
M971U<FX@3$]'7TE.1D\["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!R
M:6]R:71I97-;)'!R:6]R:71Y73L*("`@('T*?0H_/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O;6%I
M;"YP:'``````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q-#(P,0`Q,#0Q-S,V,S`P-P`P,3<U,3,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z
M("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]M86EL+G!H<"QV(#$N,C$@,C`P
M-"\P,2\Q.2`P.#HP,CHT,"!J;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E
M=FES:6]N.B`Q+C(Q("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H
M92!,;V=?;6%I;"!C;&%S<R!I<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N
M(&]F('1H92!,;V<Z.B!A8G-T<F%C="!C;&%S<PH@*B!W:&EC:"!S96YD<R!L
M;V<@;65S<V%G97,@=&\@82!M86EL8F]X+@H@*B!4:&4@;6%I;"!I<R!A8W1U
M86QL>2!S96YT('=H96X@>6]U(&-L;W-E*"D@=&AE(&QO9V=E<BP@;W(@=VAE
M;B!T:&4@9&5S=')U8W1O<@H@*B!I<R!C86QL960@*'=H96X@=&AE('-C<FEP
M="!I<R!T97)M:6YA=&5D*2X*("H@"B`J(%!,14%312!.3U1%('1H870@>6]U
M(&UU<W0@8W)E871E(&$@3&]G7VUA:6P@;V)J96-T('5S:6YG(#TF+"!L:6ME
M('1H:7,@.@H@*B`@)&QO9V=E<B`])B!,;V<Z.F9A8W1O<GDH(FUA:6PB+"`B
M<F5C:7!I96YT0&5X86UP;&4N8V]M(BP@+BXN*0H@*B`*("H@5&AI<R!I<R!A
M(%!%05(@<F5Q=6ER96UE;G0@9F]R(&1E<W1R=6-T;W)S('1O('=O<FL@<')O
M<&5R;'DN"B`J(%-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]C
M;&%S<RYP96%R+G!H<`H@*B`*("H@0&%U=&AO<B`@4F]N;FEE($=A<F-I82`\
M<F]N;FEE0&UK,BYN970^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P
M:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XS"B`J($!P86-K86=E($QO9PH@
M*@H@*B!`97AA;7!L92!M86EL+G!H<"`@("!5<VEN9R!T:&4@;6%I;"!H86YD
M;&5R+@H@*B\*8VQA<W,@3&]G7VUA:6P@97AT96YD<R!,;V<*>PH@("`@+RHJ
M(`H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(')E8VEP:65N="=S(&5M86EL
M(&%D9')E<W,N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7W)E8VEP:65N="`]("<G.PH*("`@
M("\J*B`*("`@("`J(%-T<FEN9R!H;VQD:6YG('1H92!S96YD97(G<R!E;6%I
M;"!A9&1R97-S+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]F<F]M(#T@)R<["@H@("`@+RHJ
M(`H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&5M86EL)W,@<W5B:F5C="X*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?<W5B:F5C="`]("=;3&]G7VUA:6Q=($QO9R!M97-S
M86=E)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!H;VQD:6YG(&%N(&]P=&EO
M;F%L('!R96%M8FQE(&9O<B!T:&4@;&]G(&UE<W-A9V5S+@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]P<F5A;6)L92`]("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO
M;&1I;F<@=&AE(&UA:6P@;65S<V%G92!B;V1Y+@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]M
M97-S86=E(#T@)R<["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!,;V=?;6%I;"!O8FIE8W0N"B`@("`@*B`*("`@("`J($AE<F4@:7,@:&]W
M('EO=2!C86X@8W5S=&]M:7IE('1H92!M86EL(&1R:79E<B!W:71H('1H92!C
M;VYF6UT@:&%S:"`Z"B`@("`@*B`@("1C;VYF6R=F<F]M)UT@("`@.B!T:&4@
M;6%I;"=S(")&<F]M(B!H96%D97(@;&EN92P*("`@("`J("`@)&-O;F9;)W-U
M8FIE8W0G72`Z('1H92!M86EL)W,@(E-U8FIE8W0B(&QI;F4N"B`@("`@*B`*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("!4:&4@9FEL96YA;64@
M;V8@=&AE(&QO9V9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@
M("`@5&AE(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@
M)&-O;F8@("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*("`@("`J($!P
M87)A;2!I;G0@("`@)&QE=F5L("`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD
M(&EN8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@3&]G7VUA:6PH)&YA;64L("1I9&5N="`]
M("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`D
M;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^
M7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7W)E8VEP
M:65N="`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E;G0[
M"B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D["@H@
M("`@("`@(&EF("@A96UP='DH)&-O;F9;)V9R;VTG72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]F<F]M(#T@)&-O;F9;)V9R;VTG73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V9R;VT@/2!I;FE?9V5T*"=S96YD
M;6%I;%]F<F]M)RD["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@A
M96UP='DH)&-O;F9;)W-U8FIE8W0G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]S=6)J96-T(#T@)&-O;F9;)W-U8FIE8W0G73L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A96UP='DH)&-O;F9;)W!R96%M8FQE)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<')E86UB;&4@/2`D8V]N9ELG<')E86UB;&4G73L*("`@
M("`@("!]"B`@("`@("`@"B`@("`@("`@+RH@<F5G:7-T97(@=&AE(&1E<W1R
M=6-T;W(@*B\*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA
M<G)A>2@F)'1H:7,L("=?3&]G7VUA:6PG*2D["B`@("!]"B`@("`*("`@("\J
M*@H@("`@("H@1&5S=')U8W1O<BX@0V%L;',@8VQO<V4H*2X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7TQO
M9U]M86EL*"D*("`@('L*("`@("`@("`D=&AI<RT^8VQO<V4H*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-T87)T<R!A(&YE=R!M86EL(&UE<W-A9V4N"B`@
M("`@*B!4:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N
M96-E<W-A<GDN"B`@("`@*B`*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("@A)'1H
M:7,M/E]O<&5N960I('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7W!R96%M8FQE*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M97-S86=E
M(#T@)'1H:7,M/E]P<F5A;6)L92`N(")<;EQN(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]('1R=64["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]O<&5N960["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;&]S97,@=&AE(&UE<W-A9V4L(&EF(&ET(&ES(&]P96XL(&%N
M9"!S96YD<R!T:&4@;6%I;"X*("`@("`J(%1H:7,@:7,@:6UP;&EC:71L>2!C
M86QL960@8GD@=&AE(&1E<W1R=6-T;W(L(&EF(&YE8V5S<V%R>2X*("`@("`J
M(`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VQO<V4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@>PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;65S<V%G92DI('L*("`@
M("`@("`@("`@("`@("1H96%D97)S(#T@(D9R;VTZ("1T:&ES+3Y?9G)O;5QN
M(CL*("`@("`@("`@("`@("`@("1H96%D97)S("X](")5<V5R+4%G96YT.B!,
M;V=?;6%I;"(["@H@("`@("`@("`@("`@("`@:68@*&UA:6PH)'1H:7,M/E]R
M96-I<&EE;G0L("1T:&ES+3Y?<W5B:F5C="P@)'1H:7,M/E]M97-S86=E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)&AE861E<G,I(#T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`@("`@97)R;W)?;&]G*"),;V=?;6%I;#H@1F%I
M;'5R92!E>&5C=71I;F<@;6%I;"@I(BP@,"D["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("\J($-L96%R('1H92!M97-S86=E('-T<FEN9R!N;W<@=&AA="!T
M:&4@96UA:6P@:&%S(&)E96X@<V5N="X@*B\*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;65S<V%G92`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&;'5S:&5S('1H92!L;V<@;W5T<'5T(&)Y(&9O<F-I;F<@
M=&AE(&5M86EL(&UE<W-A9V4@=&\@8F4@<V5N="!N;W<N"B`@("`@*B!%=F5N
M=',@=&AA="!A<F4@;&]G9V5D(&%F=&5R(&9L=7-H*"D@:7,@8V%L;&5D('=I
M;&P@8F4@87!P96YD960@=&\@80H@("`@("H@;F5W(&5M86EL(&UE<W-A9V4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92!,
M;V<@,2XX+C(*("`@("`J+PH@("`@9G5N8W1I;VX@9FQU<V@H*0H@("`@>PH@
M("`@("`@("\J"B`@("`@("`@("H@270G<R!S=69F:6-I96YT('1O('-I;7!L
M>2!C86QL(&-L;W-E*"D@=&\@9FQU<V@@=&AE(&]U='!U="X*("`@("`@("`@
M*B!4:&4@;F5X="!C86QL('1O(&QO9R@I('=I;&P@8V%U<V4@=&AE(&AA;F1L
M97(@=&\@8F4@<F5O<&5N960N"B`@("`@("`@("HO"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YC;&]S92@I.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&5S
M("1M97-S86=E('1O('1H92!C=7)R96YT;'D@;W!E;B!M86EL(&UE<W-A9V4N
M"B`@("`@*B!#86QL<R!O<&5N*"DL(&EF(&YE8V5S<V%R>2X*("`@("`J(`H@
M("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C
M="!C;VYT86EN:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A
M;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G
M92X@(%9A;&ED"B`@("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z
M(%!%05)?3$]'7T5-15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@("`@
M("`@("`@("`@("`@4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%2
M7TQ/1U]705).24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/
M1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A
M;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI
M"B`@("!["B`@("`@("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S
M<&5C:69I960L('5S92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@("!I
M9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET
M>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O*B!!
M8F]R="!E87)L>2!I9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM
M=6T@;&]G9VEN9R!L979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--
M87-K960H)'!R:6]R:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&4@;65S<V%G92!I<VXG="!O
M<&5N(&%N9"!C86XG="!B92!O<&5N960L(')E='5R;B!F86EL=7)E+B`J+PH@
M("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960@)B8@(21T:&ES+3YO<&5N*"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@17AT<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H
M92!M97-S86=E+B`J+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M/E]E>'1R
M86-T365S<V%G92@D;65S<V%G92D["@H@("`@("`@("1E;G1R>2`]('-P<FEN
M=&8H(B5S("5S(%LE<UT@)7-<;B(L('-T<F9T:6UE*"<E8B`E9"`E2#HE33HE
M4R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I9&5N="P@
M3&]G.CIP<FEO<FET>51O4W1R:6YG*"1P<FEO<FET>2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D;65S<V%G92D["@H@("`@("`@("1T:&ES+3Y?;65S
M<V%G92`N/2`D96YT<GD["@H@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H87)R
M87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S86=E)R`]/B`D;65S
M<V%G92DI.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*?0H*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O3&]G+V9I;&4N<&AP````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,3<W,C,`,3`T,3<S-C,P,#<`,#$W-3(T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O9FEL92YP
M:'`L=B`Q+C,W(#(P,#0O,#$O,3D@,#@Z,#(Z-#`@:F]N($5X<"`D"B`J"B`J
M($!V97)S:6]N("12979I<VEO;CH@,2XS-R`D"B`J($!P86-K86=E($QO9PH@
M*B\*"B\J*@H@*B!4:&4@3&]G7V9I;&4@8VQA<W,@:7,@82!C;VYC<F5T92!I
M;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T"B`J(&-L87-S('1H
M870@;&]G<R!M97-S86=E<R!T;R!A('1E>'0@9FEL92X*("H@"B`J($!A=71H
M;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`875T:&]R("!2;VUA
M;B!.975H875S97(@/&YE=6AA=7-E<D!B96QL879I<W1A+F-Z/@H@*B!`<VEN
M8V4@("!,;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!F
M:6QE+G!H<"`@("!5<VEN9R!T:&4@9FEL92!H86YD;&5R+@H@*B\*8VQA<W,@
M3&]G7V9I;&4@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@
M8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!T:&4@;&]G(&9I;&4N"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7V9I;&5N86UE(#T@)W!H<"YL;V<G.PH*("`@("\J*@H@("`@("H@
M2&%N9&QE('1O('1H92!L;V<@9FEL92X*("`@("`J($!V87(@<F5S;W5R8V4*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]F<"`]
M(&9A;'-E.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&YE=R!L;V<@96YT<FEE
M<R!B92!A<'!E;F0@=&\@86X@97AI<W1I;F<@;&]G(&9I;&4L(&]R('-H;W5L
M9"!T:&4*("`@("`J(&$@;F5W(&QO9R!F:6QE(&]V97)W<FET92!A;B!E>&ES
M=&EN9R!O;F4_"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]A<'!E;F0@/2!T<G5E.PH*("`@
M("\J*@H@("`@("H@26YT96=E<B`H:6X@;V-T86PI(&-O;G1A:6YI;F<@=&AE
M(&QO9R!F:6QE)W,@<&5R;6ES<VEO;G,@;6]D92X*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7VUO9&4@/2`P-C0T.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI
M;F<@=&AE(&9O<FUA="!O9B!A(&QO9R!L:6YE+@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L
M:6YE1F]R;6%T(#T@)R4Q)',@)3(D<R!;)3,D<UT@)30D<R<["@H@("`@+RHJ
M"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@=&EM97-T86UP(&9O<FUA
M="X@($ET('=I;&P@8F4@<&%S<V5D(&1I<F5C=&QY('1O"B`@("`@*B!S=')F
M=&EM92@I+B`@3F]T92!T:&%T('1H92!T:6UE<W1A;7`@<W1R:6YG('=I;&P@
M9V5N97)A=&5D('5S:6YG('1H90H@("`@("H@8W5R<F5N="!L;V-A;&4N"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7W1I;65&;W)M870@/2`G)6(@)60@)4@Z)4TZ)5,G.PH*
M("`@("\J*@H@("`@("H@2&%S:"!T:&%T(&UA<',@8V%N;VYI8V%L(&9O<FUA
M="!K97ES('1O('!O<VET:6]N(&%R9W5M96YT<R!F;W(@=&AE"B`@("`@*B`B
M;&EN92!F;W)M870B('-T<FEN9RX*("`@("`J($!V87(@87)R87D*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]F;W)M871-87`@
M/2!A<G)A>2@G)7MT:6UE<W1A;7!])R`@/3X@)R4Q)',G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R5[:61E;G1])R`@("`@(#T^("<E,B1S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E>W!R:6]R:71Y?2<@("`]
M/B`G)3,D<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)7MM97-S
M86=E?2<@("`@/3X@)R4T)',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R5<>R<@("`@("`@("`@(#T^("<E)7LG*3L*"B`@("`O*BH*("`@("`J
M(%-T<FEN9R!C;VYT86EN:6YG('1H92!E;F0M;VXM;&EN92!C:&%R86-T97(@
M<V5Q=65N8V4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5O;"`](")<;B(["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($QO9U]F:6QE(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T
M<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF
M:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@
M("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E
M;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M($QO9U]F:6QE*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I
M+`H@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"
M54<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H
M*2D["B`@("`@("`@)'1H:7,M/E]F:6QE;F%M92`]("1N86UE.PH@("`@("`@
M("1T:&ES+3Y?:61E;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M/E]M87-K
M(#T@3&]G.CI54%1/*"1L979E;"D["@H@("`@("`@(&EF("AI<W-E="@D8V]N
M9ELG87!P96YD)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?87!P96YD(#T@
M)&-O;F9;)V%P<&5N9"==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T
M>2@D8V]N9ELG;6]D92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VUO9&4@
M/2`D8V]N9ELG;6]D92==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T
M>2@D8V]N9ELG;&EN949O<FUA="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7VQI;F5&;W)M870@/2!S=')?<F5P;&%C92AA<G)A>5]K97ES*"1T:&ES+3Y?
M9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87E?=F%L=65S*"1T:&ES+3Y?9F]R;6%T36%P*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;F9;)VQI;F5&;W)M870G72D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(65M<'1Y*"1C;VYF6R=T:6UE1F]R;6%T)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?=&EM949O<FUA="`]("1C;VYF6R=T:6UE1F]R;6%T)UT["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=E;VPG72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]E;VP@/2`D8V]N9ELG96]L)UT["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]E;VP@/2`H<W1R<W1R*%!(
M4%]/4RP@)U=)3B<I*2`_(")<<EQN(B`Z(")<;B(["B`@("`@("`@?0H*("`@
M("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F)'1H:7,L
M("=?3&]G7V9I;&4G*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<G5C
M=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N(%],;V=?9FEL92@I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@("1T:&ES
M+3YC;&]S92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R
M96%T97,@=&AE(&=I=F5N(&1I<F5C=&]R>2!P871H+B`@268@=&AE('!A<F5N
M="!D:7)E8W1O<FEE<R!D;VXG=`H@("`@("H@86QR96%D>2!E>&ES="P@=&AE
M>2!W:6QL(&)E(&-R96%T960L('1O;RX*("`@("`J"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("1P871H("`@("`@(%1H92!F=6QL(&1I<F5C=&]R>2!P871H
M('1O(&-R96%T92X*("`@("`J($!P87)A;2`@(&EN=&5G97(@)&UO9&4@("`@
M("`@5&AE('!E<FUI<W-I;VYS(&UO9&4@=VET:"!W:&EC:"!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&ER96-T;W)I97,@=VEL
M;"!B92!C<F5A=&5D+@H@("`@("H*("`@("`J($!R971U<FX@(%1R=64@:68@
M=&AE(&9U;&P@<&%T:"!I<R!S=6-C97-S9G5L;'D@8W)E871E9"!O<B!A;')E
M861Y"B`@("`@*B`@("`@("`@("!E>&ES=',N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?;6MP871H*"1P
M871H+"`D;6]D92`](#`W,#`I"B`@("!["B`@("`@("`@<W1A=&EC("1D97!T
M:"`](#`["@H@("`@("`@("\J($=U87)D(&%G86EN<W0@<&]T96YT:6%L;'D@
M:6YF:6YI=&4@<F5C=7)S:6]N+B`J+PH@("`@("`@(&EF("@D9&5P=&@K*R`^
M(#(U*2!["B`@("`@("`@("`@('1R:6=G97)?97)R;W(H(E]M:W!A=&@H*3H@
M36%X:6UU;2!R96-U<G-I;VX@9&5P=&@@*#(U*2!E>&-E961E9"(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@15]54T527U=!4DY)3D<I.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!792=R
M92!O;FQY(&EN=&5R97-T960@:6X@=&AE(&1I<F5C=&]R>2!C;VUP;VYE;G0@
M;V8@=&AE('!A=&@N("HO"B`@("`@("`@)'!A=&@@/2!D:7)N86UE*"1P871H
M*3L*"B`@("`@("`@+RH@268@=&AE(&1I<F5C=&]R>2!A;')E861Y(&5X:7-T
M<RP@<F5T=7)N('-U8V-E<W,@:6UM961I871E;'DN("HO"B`@("`@("`@:68@
M*&ES7V1I<B@D<&%T:"DI('L*("`@("`@("`@("`@)&1E<'1H(#T@,#L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*@H@
M("`@("`@("`J($EN(&]R9&5R('1O('5N9&5R<W1A;F0@<F5C=7)S:6]N+"!Y
M;W4@;75S="!F:7)S="!U;F1E<G-T86YD"B`@("`@("`@("H@<F5C=7)S:6]N
M("XN+@H@("`@("`@("`J+PH@("`@("`@(&EF("@D=&AI<RT^7VUK<&%T:"@D
M<&%T:"P@)&UO9&4I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@0&UK9&ER*"1P871H
M+"`D;6]D92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!T:&4@;&]G
M(&9I;&4@9F]R(&]U='!U="X@($EF('1H92!S<&5C:69I960@;&]G(&9I;&4@
M9&]E<R!N;W0*("`@("`J(&%L<F5A9'D@97AI<W0L(&ET('=I;&P@8F4@8W)E
M871E9"X@($)Y(&1E9F%U;'0L(&YE=R!L;V<@96YT<FEE<R!A<F4*("`@("`J
M(&%P<&5N9&5D('1O('1H92!E;F0@;V8@=&AE(&QO9R!F:6QE+@H@("`@("H*
M("`@("`J(%1H:7,@:7,@:6UP;&EC:71L>2!C86QL960@8GD@;&]G*"DL(&EF
M(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@("!I9B`H(21T
M:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@("\J($EF('1H92!L;V<@9FEL
M92=S(&1I<F5C=&]R>2!D;V5S;B=T(&5X:7-T+"!C<F5A=&4@:70N("HO"B`@
M("`@("`@("`@(&EF("@A:7-?9&ER*&1I<FYA;64H)'1H:7,M/E]F:6QE;F%M
M92DI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUK<&%T:"@D=&AI<RT^
M7V9I;&5N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@3V)T
M86EN(&$@:&%N9&QE('1O('1H92!L;V<@9FEL92X@*B\*("`@("`@("`@("`@
M)'1H:7,M/E]F<"`](&9O<&5N*"1T:&ES+3Y?9FEL96YA;64L("@D=&AI<RT^
M7V%P<&5N9"D@/R`G82<@.B`G=R<I.PH*("`@("`@("`@("`@)'1H:7,M/E]O
M<&5N960@/2`H)'1H:7,M/E]F<"`A/3T@9F%L<V4I.PH*("`@("`@("`@("`@
M+RH@071T96UP="!T;R!S970@=&AE(&QO9R!F:6QE)W,@;6]D92X@*B\*("`@
M("`@("`@("`@0&-H;6]D*"1T:&ES+3Y?9FEL96YA;64L("1T:&ES+3Y?;6]D
M92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]O<&5N960[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE(&QO9R!F:6QE(&EF
M(&ET(&ES(&]P96XN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@("\J($EF
M('1H92!L;V<@9FEL92!I<R!O<&5N+"!C;&]S92!I="X@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]O<&5N960@)B8@9F-L;W-E*"1T:&ES+3Y?9G`I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&;'5S:&5S(&%L;"!P96YD:6YG(&1A=&$@
M=&\@=&AE(&9I;&4@:&%N9&QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<VEN8V4@3&]G(#$N."XR"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9L=7-H*"D*("`@('L*("`@("`@("!R971U<FX@9F9L=7-H*"1T:&ES
M+3Y?9G`I.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]G<R`D;65S<V%G92!T
M;R!T:&4@;W5T<'5T('=I;F1O=RX@(%1H92!M97-S86=E(&ES(&%L<V\@<&%S
M<V5D(&%L;VYG"B`@("`@*B!T;R!A;GD@3&]G7V]B<V5R=F5R(&EN<W1A;F-E
M<R!T:&%T(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C="!C;VYT
M86EN:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I
M;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A
M;&ED"B`@("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?
M3$]'7T5-15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@
M("`@("`@4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]7
M05).24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)
M0T4L(%!%05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N
M(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("![
M"B`@("`@("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I
M960L('5S92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R
M:6]R:71Y(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T
M:&ES+3Y?<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E
M87)L>2!I9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G
M9VEN9R!L979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H
M)'!R:6]R:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!T:&4@;&]G(&9I;&4@:7-N)W0@86QR96%D
M>2!O<&5N+"!O<&5N(&ET(&YO=RX@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?
M;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T
M<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@
M("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I
M.PH*("`@("`@("`O*B!"=6EL9"!T:&4@<W1R:6YG(&-O;G1A:6YI;F<@=&AE
M(&-O;7!L971E(&QO9R!L:6YE+B`J+PH@("`@("`@("1L:6YE(#T@<W!R:6YT
M9B@D=&AI<RT^7VQI;F5&;W)M870L('-T<F9T:6UE*"1T:&ES+3Y?=&EM949O
M<FUA="DL"B`@("`@("`@("`@("`@("`D=&AI<RT^7VED96YT+"`D=&AI<RT^
M<')I;W)I='E4;U-T<FEN9R@D<')I;W)I='DI+`H@("`@("`@("`@("`@("`@
M)&UE<W-A9V4I("X@)'1H:7,M/E]E;VP["@H@("`@("`@("\J(%=R:71E('1H
M92!L;V<@;&EN92!T;R!T:&4@;&]G(&9I;&4N("HO"B`@("`@("`@)'-U8V-E
M<W,@/2`H9G=R:71E*"1T:&ES+3Y?9G`L("1L:6YE*2`A/3T@9F%L<V4I.PH*
M("`@("`@("`O*B!.;W1I9GD@;V)S97)V97)S(&%B;W5T('1H:7,@;&]G(&UE
M<W-A9V4N("HO"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I
M;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D[
M"@H@("`@("`@(')E='5R;B`D<W5C8V5S<SL*("`@('T*?0H*/SX*````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]S<6PN<&AP````````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R-#8S`#$P-#$W
M,S8S,#`W`#`Q-S0P,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO
M<&5A<B],;V<O3&]G+W-Q;"YP:'`L=B`Q+C(Y(#(P,#0O,#$O,3D@,#@Z,#(Z
M-#`@:F]N($5X<"`D"B`J("1(;W)D93H@:&]R9&4O;&EB+TQO9R]S<6PN<&AP
M+'8@,2XQ,B`R,#`P+S`X+S$V(#(P.C(W.C,T(&-H=6-K($5X<"`D"B`J"B`J
M($!V97)S:6]N("12979I<VEO;CH@,2XR.2`D"B`J($!P86-K86=E($QO9PH@
M*B\*"B\J*B!014%2)W,@1$(@<&%C:V%G92`J+PIR97%U:7)E7V]N8V4@)T1"
M+G!H<"<["@HO*BH*("H@5&AE($QO9U]S<6P@8VQA<W,@:7,@82!C;VYC<F5T
M92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S=')A8W0@8VQA
M<W,@=VAI8V@@<V5N9',@;65S<V%G97,@=&\@86X@4U%,('-E<G9E<BX@($5A
M8V@@96YT<GD*("H@;V-C=7!I97,@82!S97!A<F%T92!R;W<@:6X@=&AE(&1A
M=&%B87-E+@H@*@H@*B!4:&ES(&EM<&QE;65N=&%T:6]N('5S97,@4$A0)W,@
M4$5!4B!D871A8F%S92!A8G-T<F%C=&EO;B!L87EE<BX*("H*("H@0U)%051%
M(%1!0DQ%(&QO9U]T86)L92`H"B`J("!I9"`@("`@("`@("!)3E0@3D]4($Y5
M3$PL"B`J("!L;V=T:6UE("`@("!424U%4U1!35`@3D]4($Y53$PL"B`J("!I
M9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("H@('!R:6]R:71Y("`@
M($E.5"!.3U0@3E5,3"P*("H@(&UE<W-A9V4@("`@(%9!4D-(05(H,C`P*2P*
M("H@(%!224U!4ED@2T59("AI9"D*("H@*3L*("H*("H@0&%U=&AO<B`@2F]N
M(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<VEN8V4@("!,;V<@,2XP"B`J($!P86-K86=E($QO9R`*("H*("H@0&5X
M86UP;&4@<W%L+G!H<"`@("`@57-I;F<@=&AE(%-13"!H86YD;&5R+@H@*B\*
M8VQA<W,@3&]G7W-Q;"!E>'1E;F1S($QO9R!["@H@("`@+RHJ(`H@("`@("H@
M07)R87D@8V]N=&%I;FEN9R!T:&4@9'-N(&EN9F]R;6%T:6]N+B`*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?9'-N(#T@)R<["@H@("`@+RHJ(`H@("`@("H@3V)J96-T(&AO
M;&1I;F<@=&AE(&1A=&%B87-E(&AA;F1L92X@"B`@("`@*B!`=F%R(&]B:F5C
M=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1B
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($9L86<@:6YD:6-A=&EN9R!T:&%T
M('=E)W)E('5S:6YG(&%N(&5X:7-T:6YG(&1A=&%B87-E(&-O;FYE8W1I;VXN
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]E>&ES=&EN9T-O;FYE8W1I;VX@/2!F86QS93L*
M"B`@("`O*BH@"B`@("`@*B!3=')I;F<@:&]L9&EN9R!T:&4@9&%T86)A<V4@
M=&%B;&4@=&\@=7-E+B`*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&%B;&4@/2`G;&]G7W1A
M8FQE)SL*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W('-Q;"!L
M;V=G:6YG(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("`@("`@("`@5&AE('1A<F=E="!344P@=&%B;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I9&5N="`@("`@("`@5&AE(&ED96YT:69I8V%T:6]N(&9I
M96QD+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VYF("`@("`@("`@(%1H92!C
M;VYN96-T:6]N(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R86T@
M:6YT("1L979E;"`@("`@("`@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I
M;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC("`@
M("`*("`@("`J+PH@("`@9G5N8W1I;VX@3&]G7W-Q;"@D;F%M92P@)&ED96YT
M(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@
M)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]T86)L
M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E;G0["B`@
M("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D["@H@("`@
M("`@("\J($EF(&%N(&5X:7-T:6YG(&1A=&%B87-E(&-O;FYE8W1I;VX@=V%S
M('!R;W9I9&5D+"!U<V4@:70N("HO"B`@("`@("`@:68@*&ES<V5T*"1C;VYF
M6R=D8B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1B(#T@)B1C;VYF6R=D
M8B==.PH@("`@("`@("`@("`D=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;B`]
M('1R=64["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V1S;B`]("1C;VYF
M6R=D<VXG73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N
M<R!A(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E+"!I9B!I="!H87,@;F]T
M(&%L<F5A9'D*("`@("`J(&)E96X@;W!E;F5D+B!4:&ES(&ES(&EM<&QI8VET
M;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,@("`@(`H@("`@("HO
M"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES
M+3Y?;W!E;F5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O
M;FYE8W0H)'1H:7,M/E]D<VXL('1R=64I.PH@("`@("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)'1H:7,M/E]D8BDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]P
M96YE9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]O<&5N960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE(&-O
M;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E(&EF(&ET(&ES('-T:6QL(&]P96X@
M86YD('=E('=E<F4*("`@("`J('1H92!O;F5S('1H870@;W!E;F5D(&ET+B`@
M270@:7,@=&AE(&-A;&QE<B=S(')E<W!O;G-I8FQE('1O(&-L;W-E(&%N"B`@
M("`@*B!E>&ES=&EN9R!C;VYN96-T:6]N('1H870@=V%S('!A<W-E9"!T;R!U
M<R!V:6$@)&-O;F9;)V1B)UTN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,@("`@(`H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D("8F("$D
M=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;BD@>PH@("`@("`@("`@("`D=&AI
M<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@26YS97)T<R`D;65S<V%G92!T;R!T:&4@8W5R<F5N=&QY(&]P96X@
M9&%T86)A<V4N("!#86QL<R!O<&5N*"DL"B`@("`@*B!I9B!N96-E<W-A<GDN
M("!!;'-O('!A<W-E<R!T:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@3&]G7V]B
M<V5R=F5R"B`@("`@*B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H
M:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@
M(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L
M;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I
M='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@
M("`@("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%
M4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%
M05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@
M("`@("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@
M4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,@("`@(`H@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A
M9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@82!P
M<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@9&5F875L
M="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2![
M"B`@("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I='D["B`@
M("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@<')I;W)I
M='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@*B\*("`@
M("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!)
M9B!T:&4@8V]N;F5C=&EO;B!I<VXG="!O<&5N(&%N9"!C86XG="!B92!O<&5N
M960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]O
M<&5N960@)B8@(21T:&ES+3YO<&5N*"DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@17AT<F%C="!T:&4@<W1R
M:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E+B`J+PH@("`@("`@
M("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G92@D;65S<V%G92D[
M"@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GD@9F]R('1H:7,@;&]G
M(&5N=')Y(&EN<V5R=&EO;BX@*B\*("`@("`@("`D:60@/2`D=&AI<RT^7V1B
M+3YN97AT260H)VQO9U]I9"<I.PH@("`@("`@("1Q(#T@<W!R:6YT9B@G:6YS
M97)T(&EN=&\@)7,@*&ED+"!L;V=T:6UE+"!I9&5N="P@<')I;W)I='DL(&UE
M<W-A9V4I)R`N"B`@("`@("`@("`@("`@("`@("`@("=V86QU97,H)60L($-5
M4E)%3E1?5$E-15-404U0+"`E<RP@)60L("5S*2<L"B`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=&%B;&4L("1I9"P@)'1H:7,M/E]D8BT^<75O=&4H
M)'1H:7,M/E]I9&5N="DL"B`@("`@("`@("`@("`@("`@("`@("1P<FEO<FET
M>2P@)'1H:7,M/E]D8BT^<75O=&4H)&UE<W-A9V4I*3L*"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q*3L*("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G
M<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E
M*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0I]"@H_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+TQO9R]C;VYS;VQE+G!H<```````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$R-S`T`#$P-#$W,S8S,#`W`#`R,#(T,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G+V-O;G-O;&4N
M<&AP+'8@,2XQ.2`R,#`T+S`Q+S$Y(#`X.C`R.C0P(&IO;B!%>'`@)`H@*@H@
M*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,3D@)`H@*B!`<&%C:V%G92!,;V<*
M("HO"@HO*BH*("H@5&AE($QO9U]C;VYS;VQE(&-L87-S(&ES(&$@8V]N8W)E
M=&4@:6UP;&5M96YT871I;VX@;V8@=&AE($QO9SHZ"B`J(&%B<W1R86-T(&-L
M87-S('=H:6-H('=R:71E<R!M97-S86=E('1O('1H92!T97AT(&-O;G-O;&4N
M"B`J(`H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X*("H@
M0'-I;F-E("`@3&]G(#$N,0H@*B!`<&%C:V%G92!,;V<*("H*("H@0&5X86UP
M;&4@8V]N<V]L92YP:'`@("`@(%5S:6YG('1H92!C;VYS;VQE(&AA;F1L97(N
M"B`J+PIC;&%S<R!,;V=?8V]N<V]L92!E>'1E;F1S($QO9PI["B`@("`O*BH*
M("`@("`J($AA;F1L92!T;R!T:&4@8W5R<F5N="!O=71P=70@<W1R96%M+@H@
M("`@("H@0'9A<B!R97-O=7)C90H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7W-T<F5A;2`](%-41$]55#L*"B`@("`O*BH*("`@
M("`J(%-H;W5L9"!T:&4@;W5T<'5T(&)E(&)U9F9E<F5D(&]R(&1I<W!L87EE
M9"!I;6UE9&EA=&5L>3\*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?8G5F9F5R:6YG(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L9&EN9R!T:&4@8G5F9F5R
M960@;W5T<'5T+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]B=69F97(@/2`G)SL*"B`@("`O
M*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!F;W)M870@;V8@82!L
M;V<@;&EN92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?;&EN949O<FUA="`]("<E,21S("4R
M)',@6R4S)'-=("4T)',G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A
M:6YI;F<@=&AE('1I;65S=&%M<"!F;W)M870N("!)="!W:6QL(&)E('!A<W-E
M9"!D:7)E8W1L>2!T;PH@("`@("H@<W1R9G1I;64H*2X@($YO=&4@=&AA="!T
M:&4@=&EM97-T86UP('-T<FEN9R!W:6QL(&=E;F5R871E9"!U<VEN9R!T:&4*
M("`@("`J(&-U<G)E;G0@;&]C86QE+@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T:6UE1F]R
M;6%T(#T@)R5B("5D("5(.B5-.B53)SL*"B`@("`O*BH*("`@("`J($AA<V@@
M=&AA="!M87!S(&-A;F]N:6-A;"!F;W)M870@:V5Y<R!T;R!P;W-I=&EO;B!A
M<F=U;65N=',@9F]R('1H90H@("`@("H@(FQI;F4@9F]R;6%T(B!S=')I;F<N
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?9F]R;6%T36%P(#T@87)R87DH)R5[=&EM97-T86UP
M?2<@(#T^("<E,21S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E
M>VED96YT?2<@("`@("`]/B`G)3(D<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G)7MP<FEO<FET>7TG("`@/3X@)R4S)',G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R5[;65S<V%G97TG("`@(#T^("<E-"1S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E7'LG("`@("`@("`@("`]
M/B`G)25[)RD["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($QO
M9U]C;VYS;VQE(&]B:F5C="X*("`@("`J(`H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R
M87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*("`@("`J
M($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S86=E<R!U<"!T;R!A
M;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?8V]N<V]L92@D;F%M92P@)&ED
M96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES
M+3Y?:61E;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G
M.CI54%1/*"1L979E;"D["@H@("`@("`@(&EF("@A96UP='DH)&-O;F9;)W-T
M<F5A;2==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-T<F5A;2`]("1C;VYF
M6R=S=')E86TG73L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D8V]N
M9ELG8G5F9F5R:6YG)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8G5F9F5R
M:6YG(#T@)&-O;F9;)V)U9F9E<FEN9R==.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D8V]N9ELG;&EN949O<FUA="==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7VQI;F5&;W)M870@/2!S=')?<F5P;&%C92AA<G)A>5]K97ES
M*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87E?=F%L=65S*"1T:&ES+3Y?9F]R
M;6%T36%P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;F9;)VQI;F5&;W)M870G72D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(65M<'1Y*"1C;VYF6R=T:6UE1F]R;6%T)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?=&EM949O<FUA="`]("1C;VYF6R=T:6UE1F]R;6%T
M)UT["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@("`J($EF(&]U='!U
M="!B=69F97)I;F<@:&%S(&)E96X@<F5Q=65S=&5D+"!W92!N965D('1O(')E
M9VES=&5R(&$*("`@("`@("`@*B!S:'5T9&]W;B!F=6YC=&EO;B!T:&%T('=I
M;&P@9'5M<"!T:&4@8G5F9F5R('5P;VX@=&5R;6EN871I;VXN"B`@("`@("`@
M("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8G5F9F5R:6YG*2!["B`@("`@("`@
M("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@
M)U],;V=?8V]N<V]L92<I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$97-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N(%],;V=?8V]N
M<V]L92@I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&;'5S:&5S(&%L;"!P96YD:6YG("@B8G5F9F5R960B
M*2!D871A('1O('1H92!O=71P=70@<W1R96%M+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@3&]G(#$N."XR"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9L=7-H*"D*("`@('L*("`@("`@("`O*@H@("`@("`@
M("`J($EF(&]U='!U="!B=69F97)I;F<@:7,@96YA8FQE9"P@9'5M<"!T:&4@
M8V]N=&5N=',@;V8@=&AE(&)U9F9E<B!T;PH@("`@("`@("`J('1H92!O=71P
M=70@<W1R96%M+@H@("`@("`@("`J+PH@("`@("`@(&EF("@D=&AI<RT^7V)U
M9F9E<FEN9R`F)B`H<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*2`^(#`I*2!["B`@
M("`@("`@("`@(&9W<FET92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]B=69F
M97(I.PH@("`@("`@("`@("`D=&AI<RT^7V)U9F9E<B`]("<G.PH@("`@("`@
M('T*(`H@("`@("`@(')E='5R;B!F9FQU<V@H)'1H:7,M/E]S=')E86TI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5W)I=&5S("1M97-S86=E('1O('1H92!T
M97AT(&-O;G-O;&4N($%L<V\L('!A<W-E<R!T:&4@;65S<V%G90H@("`@("H@
M86QO;F<@=&\@86YY($QO9U]O8G-E<G9E<B!I;G-T86YC97,@=&AA="!A<F4@
M;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H@"B`@("`@*B!`<&%R86T@;6EX
M960@("1M97-S86=E("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T
M:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEO
M<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@
M("H@("`@("`@("`@("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%3452
M1RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%
M05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*
M("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!014%2
M7TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E
M+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@
M("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@
M=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R
M:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@
M=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V
M96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET
M>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@17AT<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F
M('1H92!M97-S86=E+B`J+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M/E]E
M>'1R86-T365S<V%G92@D;65S<V%G92D["@H@("`@("`@("\J($)U:6QD('1H
M92!S=')I;F<@8V]N=&%I;FEN9R!T:&4@8V]M<&QE=&4@;&]G(&QI;F4N("HO
M"B`@("`@("`@)&QI;F4@/2!S<')I;G1F*"1T:&ES+3Y?;&EN949O<FUA="P@
M<W1R9G1I;64H)'1H:7,M/E]T:6UE1F]R;6%T*2P*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:61E;G0L("1T:&ES+3YP<FEO<FET>51O4W1R:6YG*"1P<FEO
M<FET>2DL"B`@("`@("`@("`@("`@("`D;65S<V%G92D@+B`B7&XB.PH*("`@
M("`@("`O*@H@("`@("`@("`J($EF(&)U9F9E<FEN9R!I<R!E;F%B;&5D+"!A
M<'!E;F0@=&AI<R!L:6YE('1O('1H92!O=71P=70@8G5F9F5R+@H@("`@("`@
M("`J($]T:&5R=VES92P@<')I;G0@=&AE(&QI;F4@=&\@=&AE(&]U='!U="!S
M=')E86T@:6UM961I871E;'DN"B`@("`@("`@("HO"B`@("`@("`@:68@*"1T
M:&ES+3Y?8G5F9F5R:6YG*2!["B`@("`@("`@("`@("1T:&ES+3Y?8G5F9F5R
M("X]("1L:6YE.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9W<FET
M92@D=&AI<RT^7W-T<F5A;2P@)&QI;F4I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@3F]T:69Y(&]B<V5R=F5R<R!A8F]U="!T:&ES(&QO9R!M97-S86=E+B`J
M+PH@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]
M/B`D<')I;W)I='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*?0H*/SX*````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]M8V%L+G!H<```````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-3$T`#$P
M-#$W,S8S,#`W`#`Q-S4Q,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O
M<GDO<&5A<B],;V<O3&]G+VUC86PN<&AP+'8@,2XQ-R`R,#`T+S`Q+S$Y(#`X
M.C`R.C0P(&IO;B!%>'`@)`H@*B`D2&]R9&4Z(&AO<F1E+VQI8B],;V<O;6-A
M;"YP:'`L=B`Q+C(@,C`P,"\P-B\R."`R,3HS-CHQ,R!J;VX@17AP("0*("H*
M("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C$W("0*("H@0'!A8VMA9V4@3&]G
M(`H@*B\*"B\J*@H@*B!4:&4@3&]G7VUC86P@8VQA<W,@:7,@82!C;VYC<F5T
M92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S=')A8W0@8VQA
M<W,@=VAI8V@@<V5N9',@;65S<V%G97,@=&\@82!L;V-A;"!O<B!R96UO=&4@
M8V%L96YD87(*("H@<W1O<F4@86-C97-S960@=&AR;W5G:"!-0T%,+@H@*B`*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!S:6YC92!(;W)D92`Q+C,*("H@0'-I;F-E($QO9R`Q+C`*("H@0'!A
M8VMA9V4@3&]G(`H@*B\*8VQA<W,@3&]G7VUC86P@97AT96YD<R!,;V<@>PH*
M("`@("\J*@H@("`@*B!H;VQD:6YG('1H92!C86QE;F1A<B!S<&5C:69I8V%T
M:6]N('1O(&-O;FYE8W0@=&\N(`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("HO"B`@("!V87(@)%]C86QE;F1A<B`]("=[
M;&]C86QH;W-T+VUS=&]R97TG.PH*("`@("\J*B`*("`@("H@:&]L9&EN9R!T
M:&4@=7-E<FYA;64@=&\@=7-E+B`*("`@("H@0'9A<B!S=')I;F<*("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@=F%R("1?=7-E<FYA;64@/2`G
M)SL*"B`@("`O*BH@"B`@("`J(&AO;&1I;F<@=&AE('!A<W-W;W)D('1O('5S
M92X@"B`@("`J($!V87(@<W1R:6YG"B`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@*B\*("`@('9A<B`D7W!A<W-W;W)D(#T@)R<["@H@("`@+RHJ(`H@("`@
M*B!H;VQD:6YG('1H92!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&-A;&5N9&%R
M('-T<F5A;2X@"B`@("`J($!V87(@:6YT96=E<@H@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("HO"B`@("!V87(@)%]O<'1I;VYS(#T@,#L*"B`@("`O*BH@
M"B`@("`J(%)E<V]U<F-E240@;V8@=&AE($U#04P@<W1R96%M+B`*("`@("H@
M0'9A<B!S=')I;F<*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@
M=F%R("1?<W1R96%M(#T@)R<["@H@("`@+RHJ(`H@("`@*B!);G1E9V5R(&AO
M;&1I;F<@=&AE(&QO9R!F86-I;&ET>2!T;R!U<V4N(`H@("`@*B!`=F%R('-T
M<FEN9PH@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO"B`@("!V87(@)%]N
M86UE(#T@3$]'7U-94TQ/1SL*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@;F5W($QO9U]M8V%L(&]B:F5C="X*("`@("`J(`H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@("`@5&AE(&-A=&5G;W)Y('1O('5S92!F;W(@;W5R
M(&5V96YT<RX*("`@("`J($!P87)A;2!S=')I;F<@)&ED96YT("`@(%1H92!I
M9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@("1C;VYF("`@
M("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*("`@("`J($!P87)A;2!I;G0@
M("`@)&QE=F5L("`@($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG
M('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!,;V=?;6-A;"@D;F%M92P@)&ED96YT(#T@)R<L("1C;VYF
M(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@("1L979E;"`](%!%
M05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H
M;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@
M("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M
M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D["B`@("`@("`@)'1H:7,M/E]C
M86QE;F1A<B`]("1C;VYF6R=C86QE;F1A<B==.PH@("`@("`@("1T:&ES+3Y?
M=7-E<FYA;64@/2`D8V]N9ELG=7-E<FYA;64G73L*("`@("`@("`D=&AI<RT^
M7W!A<W-W;W)D(#T@)&-O;F9;)W!A<W-W;W)D)UT["B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS(#T@)&-O;F9;)V]P=&EO;G,G73L*("`@('T*"B`@("`O*BH*
M("`@("`J($]P96YS(&$@8V%L96YD87(@<W1R96%M+"!I9B!I="!H87,@;F]T
M(&%L<F5A9'D@8F5E;@H@("`@("H@;W!E;F5D+B!4:&ES(&ES(&EM<&QI8VET
M;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*
M("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<W1R96%M(#T@;6-A;%]O<&5N*"1T:&ES+3Y?8V%L96YD87(L("1T
M:&ES+3Y?=7-E<FYA;64L"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<W-W
M;W)D+"`D=&AI<RT^7V]P=&EO;G,I.PH@("`@("`@("`@("`D=&AI<RT^7V]P
M96YE9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]O<&5N960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE(&-A
M;&5N9&%R('-T<F5A;2P@:68@:70@:7,@;W!E;BX*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@("`@;6-A;%]C
M;&]S92@D=&AI<RT^7W-T<F5A;2D["B`@("`@("`@("`@("1T:&ES+3Y?;W!E
M;F5D(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"1T:&ES
M+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,
M;V=S("1M97-S86=E(&%N9"!A<W-O8VEA=&5D(&EN9F]R;6%T:6]N('1O('1H
M92!C=7)R96YT;'D@;W!E;@H@("`@("H@8V%L96YD87(@<W1R96%M+B!#86QL
M<R!O<&5N*"D@:68@;F5C97-S87)Y+B!!;'-O('!A<W-E<R!T:&4*("`@("`J
M(&UE<W-A9V4@86QO;F<@=&\@86YY($QO9U]O8G-E<G9E<B!I;G-T86YC97,@
M=&AA="!A<F4@;V)S97)V:6YG"B`@("`@*B!T:&ES($QO9RX*("`@("`J(`H@
M("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C
M="!C;VYT86EN:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A
M;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G
M92X@5F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@
M4$5!4E],3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@
M("`@("`@("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?
M3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'
M7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L
M<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*
M("`@('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P
M96-I9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF
M("@D<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y
M(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B
M;W)T(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU
M;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA
M<VME9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("\J($EF('1H92!C;VYN96-T:6]N(&ES;B=T
M(&]P96X@86YD(&-A;B=T(&)E(&]P96YE9"P@<F5T=7)N(&9A:6QU<F4N("HO
M"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`A)'1H:7,M/F]P96XH
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@
M=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X
M=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)&1A=&5?<W1R(#T@
M9&%T92@G63IN.FHZ1SII.G,G*3L*("`@("`@("`D9&%T97,@/2!E>'!L;V1E
M*"<Z)RP@)&1A=&5?<W1R*3L*"B`@("`@("`@;6-A;%]E=F5N=%]I;FET*"1T
M:&ES+3Y?<W1R96%M*3L*("`@("`@("!M8V%L7V5V96YT7W-E=%]T:71L92@D
M=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]I9&5N="D["B`@("`@("`@;6-A;%]E
M=F5N=%]S971?8V%T96=O<GDH)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?;F%M
M92D["B`@("`@("`@;6-A;%]E=F5N=%]S971?9&5S8W)I<'1I;VXH)'1H:7,M
M/E]S=')E86TL("1M97-S86=E*3L*("`@("`@("!M8V%L7V5V96YT7V%D9%]A
M='1R:6)U=&4H)'1H:7,M/E]S=')E86TL("=P<FEO<FET>2<L("1P<FEO<FET
M>2D["B`@("`@("`@;6-A;%]E=F5N=%]S971?<W1A<G0H)'1H:7,M/E]S=')E
M86TL("1D871E<ULP72P@)&1A=&5S6S%=+"`D9&%T97-;,ETL"B`@("`@("`@
M("`@("1D871E<ULS72P@)&1A=&5S6S1=+"`D9&%T97-;-5TI.PH@("`@("`@
M(&UC86Q?979E;G1?<V5T7V5N9"@D=&AI<RT^7W-T<F5A;2P@)&1A=&5S6S!=
M+"`D9&%T97-;,5TL("1D871E<ULR72P*("`@("`@("`@("`@)&1A=&5S6S-=
M+"`D9&%T97-;-%TL("1D871E<ULU72D["B`@("`@("`@;6-A;%]A<'!E;F1?
M979E;G0H)'1H:7,M/E]S=')E86TI.PH*("`@("`@("`D=&AI<RT^7V%N;F]U
M;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@
M/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"GT*
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O97)R;W)?
M;&]G+G!H<```````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-C`V-@`Q,#0Q-S,V,S`P-P`P,C`U-S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R
M97!O<VET;W)Y+W!E87(O3&]G+TQO9R]E<G)O<E]L;V<N<&AP+'8@,2XV(#(P
M,#0O,#$O,3D@,#@Z,#(Z-#`@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N("12
M979I<VEO;CH@,2XV("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H
M92!,;V=?97)R;W)?;&]G(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT
M871I;VX@;V8@=&AE($QO9R!A8G-T<F%C=`H@*B!C;&%S<R!T:&%T(&QO9W,@
M;65S<V%G97,@=7-I;F<@4$A0)W,@97)R;W)?;&]G*"D@9G5N8W1I;VXN"B`J
M(`H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X*("H@0'-I
M;F-E("`@3&]G(#$N-RXP"B`J($!P86-K86=E($QO9PH@*B`*("H@0&5X86UP
M;&4@97)R;W)?;&]G+G!H<"`@(%5S:6YG('1H92!E<G)O<E]L;V<@:&%N9&QE
M<BX*("HO"F-L87-S($QO9U]E<G)O<E]L;V<@97AT96YD<R!,;V<*>PH@("`@
M+RHJ"B`@("`@*B!4:&4@97)R;W)?;&]G*"D@;&]G('1Y<&4N"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]T>7!E(#T@4$5!4E],3T=?5%E015]365-414T["@H@("`@+RHJ
M"B`@("`@*B!4:&4@='EP92US<&5C:69I8R!D97-T:6YA=&EO;B!V86QU92X*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?9&5S=&EN871I;VX@/2`G)SL*"B`@("`O*BH*("`@
M("`J($%D9&ET:6]N86P@:&5A9&5R<R!T;R!P87-S('1O('1H92!M86EL*"D@
M9G5N8W1I;VX@=VAE;B!T:&4*("`@("`J(%!%05)?3$]'7U194$5?34%)3"!T
M>7!E(&ES('5S960N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5X=')A7VAE861E<G,@/2`G
M)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@3&]G7V5R<F]R
M7VQO9R!O8FIE8W0N"B`@("`@*B`*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@("`@($EG;F]R960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@
M("!4:&4@:61E;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D
M8V]N9B`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R
M86T@:6YT("`@("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN
M8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@3&]G7V5R<F]R7VQO9R@D;F%M92P@)&ED96YT
M(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M
M/E]T>7!E(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N
M=#L*("`@("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z.E505$\H)&QE=F5L*3L*
M"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG9&5S=&EN871I;VXG72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]D97-T:6YA=&EO;B`]("1C;VYF6R=D97-T
M:6YA=&EO;B==.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF
M6R=E>'1R85]H96%D97)S)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?97AT
M<F%?:&5A9&5R<R`]("1C;VYF6R=E>'1R85]H96%D97)S)UT["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]G<R`D;65S<V%G92!U<VEN9R!0
M2%`G<R!E<G)O<E]L;V<H*2!F=6YC=&EO;BX@(%1H92!M97-S86=E(&ES(&%L
M<V\*("`@("`J('!A<W-E9"!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R(&EN
M<W1A;F-E<R!T:&%T(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*B`*
M("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@("!3=')I;F<@;W(@;V)J
M96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<')I;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S
M86=E+B`@5F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R
M93H@4$5!4E],3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@
M("`@("`@("`@("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%
M05)?3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?
M3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'
M+@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@
M9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L
M;"D*("`@('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N
M('-P96-I9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@
M(&EF("@D<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R
M:71Y(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J
M($%B;W)T(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X
M:6UU;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I
M<TUA<VME9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R
M97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S
M<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@
M("`@("`D<W5C8V5S<R`](&5R<F]R7VQO9R@D=&AI<RT^7VED96YT("X@)SH@
M)R`N("1M97-S86=E+"`D=&AI<RT^7W1Y<&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D97-T:6YA=&EO;BP@)'1H:7,M/E]E>'1R
M85]H96%D97)S*3L*"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G
M<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E
M*2D["@H@("`@("`@(')E='5R;B`D<W5C8V5S<SL*("`@('T*?0H*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+W=I;BYP
M:'``````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,38W,#,`,3`T,3<S-C,P,#<`,#$W,S<W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O
M<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O=VEN+G!H<"QV(#$N,34@,C`P-"\P
M,2\Q.2`P.#HP,CHT,"!J;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES
M:6]N.B`Q+C$U("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H92!,
M;V=?=VEN(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I;VX@;V8@
M=&AE($QO9R!A8G-T<F%C=`H@*B!C;&%S<R!T:&%T(&QO9W,@;65S<V%G97,@
M=&\@82!S97!A<F%T92!B<F]W<V5R('=I;F1O=RX*("H*("H@5&AE(&-O;F-E
M<'0@9F]R('1H:7,@;&]G(&AA;F1L97(@:7,@8F%S960@;VX@<&%R="!B>2!#
M<F%I9R!$879I<R<@87)T:6-L90H@*B!E;G1I=&QE9"`B2F%V85-C<FEP="!0
M;W=E<B!02%`@1&5B=6=G:6YG.@H@*@H@*B`@:'1T<#HO+W=W=RYZ96YD+F-O
M;2]Z96YD+W1U="]T=71O<FEA;"U$96)U9TQI8BYP:'`*("H@"B`J($!A=71H
M;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@
M,2XW+C`*("H@0'!A8VMA9V4@3&]G"B`J"B`J($!E>&%M<&QE('=I;BYP:'`@
M("`@(%5S:6YG('1H92!W:6YD;W<@:&%N9&QE<BX*("HO"F-L87-S($QO9U]W
M:6X@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T
M:&4@;W5T<'5T('=I;F1O=RX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;F%M92`]("=,;V=7
M:6YD;W<G.PH*("`@("\J*@H@("`@("H@5&AE('1I=&QE(&]F('1H92!O=71P
M=70@=VEN9&]W+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T:71L92`]("=,;V<@3W5T<'5T
M(%=I;F1O=R<["@H@("`@+RHJ"B`@("`@*B!-87!P:6YG(&]F(&QO9R!P<FEO
M<FET:65S('1O(&-O;&]R<RX*("`@("`J($!V87(@87)R87D*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C;VQO<G,@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?14U%4D<@("`]
M/B`G<F5D)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?04Q%
M4E0@("`]/B`G;W)A;F=E)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E],3T=?0U))5"`@("`]/B`G>65L;&]W)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4E],3T=?15)2("`@("`]/B`G9W)E96XG+`H@("`@("`@("`@
M("`@("`@("`@("`@("!014%27TQ/1U]705).24Y'(#T^("=B;'5E)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%("`]/B`G:6YD
M:6=O)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?24Y&3R`@
M("`]/B`G=FEO;&5T)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],
M3T=?1$5"54<@("`]/B`G8FQA8VLG"B`@("`@("`@("`@("`@("`@("`@*3L*
M"B`@("`O*BH*("`@("`J(%-T<FEN9R!B=69F97(@=&AA="!H;VQD<R!L:6YE
M('1H870@87)E('!E;F1I;F<@;W5T<'5T+@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V)U9F9E
M<B`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M($QO9U]W:6X@;V)J96-T+@H@("`@("H@"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@("!)9VYO<F5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E
M;G0@("`@5&AE(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A
M>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@
M0'!A<F%M(&EN="`@("`D;&5V96P@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N
M9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]W:6XH)&YA;64L("1I9&5N="`]
M("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]N
M86UE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*
M("`@("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z.E505$\H)&QE=F5L*3L*"B`@
M("`@("`@:68@*&ES<V5T*"1C;VYF6R=T:71L92==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W1I=&QE(#T@)&-O;F9;)W1I=&QE)UT["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<W-E="@D8V]N9ELG8V]L;W)S)UTI("8F(&ES7V%R<F%Y
M*"1C;VYF6R=C;VQO<G,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VQO
M<G,@/2`D8V]N9ELG8V]L;W)S)UT["B`@("`@("`@?0H*("`@("`@("!R96=I
M<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=?3&]G7W=I
M;B<I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R=6-T;W(*("`@("`J
M+PH@("`@9G5N8W1I;VX@7TQO9U]W:6XH*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7V]P96YE9"!\?"`H8V]U;G0H)'1H:7,M/E]B=69F97(I(#X@,"DI
M('L*("`@("`@("`@("`@)'1H:7,M/F-L;W-E*"D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@5&AE(&9I<G-T('1I;64@;W!E;B@I(&ES(&-A
M;&QE9"P@:70@=VEL;"!O<&5N(&$@;F5W(&)R;W=S97(@=VEN9&]W(&%N9`H@
M("`@("H@<')E<&%R92!I="!F;W(@;W5T<'5T+@H@("`@("H*("`@("`J(%1H
M:7,@:7,@:6UP;&EC:71L>2!C86QL960@8GD@;&]G*"DL(&EF(&YE8V5S<V%R
M>2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E
M;F5D*2!["C\^"CQS8W)I<'0@;&%N9W5A9V4](DIA=F%38W)I<'0B/@IW:6X@
M/2!W:6YD;W<N;W!E;B@G)RP@)SP_<&AP(&5C:&\@)'1H:7,M/E]N86UE.R`_
M/B<L("=T;V]L8F%R/6YO+'-C<F]L;&)A<G,L=VED=&@]-C`P+&AE:6=H=#TT
M,#`G*3L*=VEN+F1O8W5M96YT+G=R:71E;&XH)SQH=&UL/B<I.PIW:6XN9&]C
M=6UE;G0N=W)I=&5L;B@G/&AE860^)RD["G=I;BYD;V-U;65N="YW<FET96QN
M*"<\=&ET;&4^/#]P:'`@96-H;R`D=&AI<RT^7W1I=&QE.R`_/CPO=&ET;&4^
M)RD["G=I;BYD;V-U;65N="YW<FET96QN*"<\<W1Y;&4@='EP93TB=&5X="]C
M<W,B/B<I.PIW:6XN9&]C=6UE;G0N=W)I=&5L;B@G8F]D>2![(&9O;G0M9F%M
M:6QY.B!M;VYO<W!A8V4[(&9O;G0M<VEZ93H@.'!T.R!])RD["G=I;BYD;V-U
M;65N="YW<FET96QN*"=T9"QT:"![(&9O;G0M<VEZ93H@.'!T.R!])RD["G=I
M;BYD;V-U;65N="YW<FET96QN*"=T9"QT:"![(&)O<F1E<BUB;W1T;VTZ(",Y
M.3DY.3D@<V]L:60@,7!X.R!])RD["G=I;BYD;V-U;65N="YW<FET96QN*"=T
M9"QT:"![(&)O<F1E<BUR:6=H=#H@(SDY.3DY.2!S;VQI9"`Q<'@[('TG*3L*
M=VEN+F1O8W5M96YT+G=R:71E;&XH)SPO<W1Y;&4^)RD["G=I;BYD;V-U;65N
M="YW<FET96QN*"<\+VAE860^)RD["G=I;BYD;V-U;65N="YW<FET96QN*"<\
M8F]D>3XG*3L*=VEN+F1O8W5M96YT+G=R:71E;&XH)SQT86)L92!B;W)D97(]
M(C`B(&-E;&QP861D:6YG/2(R(B!C96QL<W!A8VEN9STB,"(^)RD["G=I;BYD
M;V-U;65N="YW<FET96QN*"<\='(^/'1H/E1I;64\+W1H/B<I.PH\/W!H<"!I
M9B`H(65M<'1Y*"1T:&ES+3Y?:61E;G0I*3H@/SX*=VEN+F1O8W5M96YT+G=R
M:71E;&XH)SQT:#Y)9&5N=#PO=&@^)RD["CP_<&AP(&5N9&EF.R`_/@IW:6XN
M9&]C=6UE;G0N=W)I=&5L;B@G/'1H/E!R:6]R:71Y/"]T:#X\=&@@=VED=&@]
M(C$P,"4B/DUE<W-A9V4\+W1H/CPO='(^)RD["CPO<V-R:7!T/@H\/W!H<`H@
M("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]('1R=64["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]O<&5N960["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;&]S97,@=&AE(&]U='!U="!S=')E86T@:68@:70@:7,@;W!E
M;BX@($EF('1H97)E(&%R92!S=&EL;"!P96YD:6YG"B`@("`@*B!L:6YE<R!I
M;B!T:&4@;W5T<'5T(&)U9F9E<BP@=&AE(&]U='!U="!W:6YD;W<@=VEL;"!B
M92!O<&5N960@<V\@=&AA=`H@("`@("H@=&AE(&)U9F9E<B!C86X@8F4@9')A
M:6YE9"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH*("`@("`@("`@
M*B!)9B!T:&5R92!A<F4@<W1I;&P@;&EN97,@=V%I=&EN9R!T;R!B92!W<FET
M=&5N+"!O<&5N('1H92!O=71P=70*("`@("`@("`@*B!W:6YD;W<@<V\@=&AA
M="!W92!C86X@9')A:6X@=&AE(&)U9F9E<BX*("`@("`@("`@*B\*("`@("`@
M("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F("AC;W5N="@D=&AI<RT^7V)U9F9E
M<BD@/B`P*2D@>PH@("`@("`@("`@("`D=&AI<RT^;W!E;B@I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?=W)I=&5L;B@G/"]T86)L93XG*3L*("`@("`@("`@("`@)'1H
M:7,M/E]W<FET96QN*"<\+V)O9'D^/"]H=&UL/B<I.PH@("`@("`@("`@("`D
M=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5W)I=&5S(&$@<VEN9VQE(&QI;F4@;V8@=&5X="!T;R!T:&4@
M;W5T<'5T('=I;F1O=RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`@
M("1L:6YE("`@5&AE(&QI;F4@;V8@=&5X="!T;R!W<FET92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W=R
M:71E;&XH)&QI;F4I"B`@("!["B`@("`@("`@+RH@061D('1H:7,@;&EN92!T
M;R!O=7(@;W5T<'5T(&)U9F9E<BX@*B\*("`@("`@("`D=&AI<RT^7V)U9F9E
M<EM=(#T@)&QI;F4["@H@("`@("`@("\J($)U9F9E<B!T:&4@;W5T<'5T('5N
M=&EL('1H:7,@<&%G92=S(&AE861E<G,@:&%V92!B965N('-E;G0N("HO"B`@
M("`@("`@:68@*"%H96%D97)S7W-E;G0H*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!H879E;B=T(&%L<F5A
M9'D@;W!E;F5D('1H92!O=71P=70@=VEN9&]W+"!D;R!S;R!N;W<N("HO"B`@
M("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`A)'1H:7,M/F]P96XH*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`O*B!$<F%I;B!T:&4@8G5F9F5R('1O('1H92!O=71P=70@=VEN9&]W+B`J
M+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8G5F9F5R(&%S("1L:6YE*2![
M"B`@("`@("`@("`@(&5C:&\@(CQS8W)I<'0@;&%N9W5A9V4])TIA=F%38W)I
M<'0G/EQN(CL*("`@("`@("`@("`@96-H;R`B=VEN+F1O8W5M96YT+G=R:71E
M;&XH)R(@+B!A9&1S;&%S:&5S*"1L:6YE*2`N("(G*3M<;B(["B`@("`@("`@
M("`@(&5C:&\@(G-E;&8N9F]C=7,H*3M<;B(["B`@("`@("`@("`@(&5C:&\@
M(CPO<V-R:7!T/EQN(CL*("`@("`@("!]"@H@("`@("`@("\J($YO=R!T:&%T
M('1H92!B=69F97(@:&%S(&)E96X@9')A:6YE9"P@8VQE87(@:70N("HO"B`@
M("`@("`@)'1H:7,M/E]B=69F97(@/2!A<G)A>2@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3&]G<R`D;65S<V%G92!T;R!T:&4@;W5T<'5T('=I;F1O=RX@
M(%1H92!M97-S86=E(&ES(&%L<V\@<&%S<V5D(&%L;VYG"B`@("`@*B!T;R!A
M;GD@3&]G7V]B<V5R=F5R(&EN<W1A;F-E<R!T:&%T(&%R92!O8G-E<G9I;F<@
M=&AI<R!,;V<N"B`@("`@*B`*("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A
M9V4@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T
M;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I
M;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@
M("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?
M04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L
M(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@
M("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A
M;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E
M+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I
M;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@
M=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@
M("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@
M("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y
M(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@
M("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@17AT
M<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E
M+B`J+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G
M92@D;65S<V%G92D["@H@("`@("`@(&QI<W0H)'5S96,L("1S96,I(#T@97AP
M;&]D92@G("<L(&UI8W)O=&EM92@I*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE
M(&]U='!U="!L:6YE('1H870@8V]N=&%I;G,@=&AE(&QO9R!E;G1R>2!R;W<N
M("HO"B`@("`@("`@)&QI;F4@(#T@)SQT<B!A;&EG;CTB;&5F="(@=F%L:6=N
M/2)T;W`B/B<["B`@("`@("`@)&QI;F4@+CT@<W!R:6YT9B@G/'1D/B5S+B5S
M/"]T9#XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@<W1R9G1I;64H)R54
M)RP@)'-E8RDL('-U8G-T<B@D=7-E8RP@,BP@,BDI.PH@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]I9&5N="DI('L*("`@("`@("`@("`@)&QI;F4@+CT@
M)SQT9#XG("X@)'1H:7,M/E]I9&5N="`N("<\+W1D/B<["B`@("`@("`@?0H@
M("`@("`@("1L:6YE("X]("<\=&0^)R`N('5C9FER<W0H)'1H:7,M/G!R:6]R
M:71Y5&]3=')I;F<H)'!R:6]R:71Y*2D@+B`G/"]T9#XG.PH@("`@("`@("1L
M:6YE("X]('-P<FEN=&8H)SQT9"!S='EL93TB8V]L;W(Z("5S(CXE<SPO=&0^
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]L;W)S6R1P
M<FEO<FET>5TL"B`@("`@("`@("`@("`@("`@("`@("`@("!P<F5G7W)E<&QA
M8V4H)R]<<EQN?%QN?%QR+R<L("<\8G(@+SXG+"`D;65S<V%G92DI.PH@("`@
M("`@("1L:6YE("X]("<\+W1R/B<["@H@("`@("`@("1T:&ES+3Y?=W)I=&5L
M;B@D;&EN92D["@H@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R
M:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*?0H*/SX*````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O;G5L
M;"YP:'``````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-#`P-P`Q,#0Q-S,V,S`P-P`P,3<U-#8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z
M("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]N=6QL+G!H<"QV(#$N,R`R,#`T
M+S`Q+S$Y(#`X.C`R.C0P(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V
M:7-I;VXZ(#$N,R`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@
M3&]G7VYU;&P@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4@3&]G.CH@86)S=')A8W0*("H@8VQA<W,N("!)="!S:6UP;'D@8V]N
M<W5M97,@;&]G(&5V96YT<RX*("H@"B`J($!A=71H;W(@($IO;B!087)I<V4@
M/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XX+C(*("H@0'!A8VMA
M9V4@3&]G"B`J"B`J($!E>&%M<&QE(&YU;&PN<&AP("`@(%5S:6YG('1H92!N
M=6QL(&AA;F1L97(N"B`J+PIC;&%S<R!,;V=?;G5L;"!E>'1E;F1S($QO9PI[
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@3&]G7VYU;&P@;V)J
M96-T+@H@("`@("H@"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)
M9VYO<F5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED
M96YT:71Y('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@
M(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@
M("`D;&5V96P@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@
M=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N($QO9U]N=6QL*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@
M/2!A<G)A>2@I+`H)"0D)"2`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@
M("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@("`@("`D=&AI<RT^
M7VUA<VL@/2!,;V<Z.E505$\H)&QE=F5L*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-I;7!L>2!C;VYS=6UE<R!T:&4@;&]G(&5V96YT+B`@5&AE(&UE<W-A
M9V4@=VEL;"!S=&EL;"!B92!P87-S960*("`@("`J(&%L;VYG('1O(&%N>2!,
M;V=?;V)S97)V97(@:6YS=&%N8V5S('1H870@87)E(&]B<V5R=FEN9R!T:&ES
M($QO9RX*("`@("`J(`H@("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G92`@
M("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@
M;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I;W)I='D@5&AE('!R:6]R
M:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@("`J("`@("`@("`@("`@
M("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%4D<L(%!%05)?3$]'7T%,
M15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U]#4DE4+"!0
M14%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@("`@
M("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD
M(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@
M)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!)9B!A('!R:6]R
M:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E('1H92!D969A=6QT('9A
M;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@/3T](&YU;&PI('L*("`@
M("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@("`@
M("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF('1H92!P<FEO<FET>2!I
M<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@
M(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I='DI*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S
M86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*?0H*/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]&:6QE+P``````````````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P,38R,C,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+T9I;&4O1FEN9"YP:'``````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R,S,R`#$P-#$W,S8S
M,#`W`#`Q-S8Q,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`R(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%-T97)L:6YG($AU9VAE<R`\
M<W1E<FQI;F=`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($9I
M;F0N<&AP+'8@,2XQ(#(P,#(O,3`O,C0@,C$Z,S$Z-3<@='5U<&]L82!%>'`@
M)`HO+PH*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH**B`@0V]M;6]N
M;'D@;F5E9&5D(&9U;F-T:6]N<R!S96%R8VAI;F<@9&ER96-T;W)Y('1R965S
M"BH**B!`86-C97-S('!U8FQI8PHJ($!V97)S:6]N("1)9#H@1FEN9"YP:'`L
M=B`Q+C$@,C`P,B\Q,"\R-"`R,3HS,3HU-R!T=75P;VQA($5X<"`D"BH@0'!A
M8VMA9V4@1FEL90HJ($!A=71H;W(@4W1E<FQI;F<@2'5G:&5S(#QS=&5R;&EN
M9T!P:'`N;F5T/@HJ+PIC;&%S<R!&:6QE7T9I;F0*>PH@("`@+RHJ"B`@("`J
M(&EN=&5R;F%L(&1I<BUL:7-T"B`@("`J($!V87(@87)R87D*("`@("HO"B`@
M("!V87(@)%]D:7)S("`@("`@(#T@87)R87D@*"D["B`@("`O*BH*("`@("H@
M9F]U;F1E9"!F:6QE<PH@("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R
M("1F:6QE<R`@("`@("`](&%R<F%Y("@I.PH@("`@+RHJ"B`@("`J(&9O=6YD
M960@9&ER<PH@("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1D:7)E
M8W1O<FEE<R`](&%R<F%Y("@I.PH*("`@("\J*@H@("`@("H@4V5A<F-H('1H
M92!C=7)R96YT(&1I<F5C=&]R>2!T;R!F:6YD(&UA=&-H97,@9F]R('1H90H@
M("`@("H@=&AE('-P96-I9FEE9"!P871T97)N+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A='1E<FX@82!S=')I;F<@8V]N=&%I;FEN9R!T:&4@
M<&%T=&5R;B!T;R!S96%R8V@*("`@("`J('1H92!D:7)E8W1O<GD@9F]R+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1I<G!A=&@@82!S=')I;F<@
M8V]N=&%I;FEN9R!T:&4@9&ER96-T;W)Y('!A=&@*("`@("`J('1O('-E87)C
M:"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871T97)N7W1Y<&4@
M82!S=')I;F<@8V]N=&%I;FEN9R!T:&4@='EP92!O9@H@("`@("H@<&%T=&5R
M;B!M871C:&EN9R!F=6YC=&EO;G,@=&\@=7-E("AC86X@96ET:&5R(&)E("=P
M:'`G(&]R"B`@("`@*B`G<&5R;"<I+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@8V]N=&%I;FEN9R!A;&P@;V8@=&AE(&9I;&5S(&%N9"!D:7)E8W1O
M<FEE<PH@("`@("H@;6%T8VAI;F<@=&AE('!A='1E<FX@;W(@;G5L;"!I9B!N
M;R!M871C:&5S"B`@("`@*@H@("`@("H@0&%U=&AO<B!3=&5R;&EN9R!(=6=H
M97,@/'-T97)L:6YG0'!H<"YN970^"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B`F9VQO8B`H)'!A='1E<FXL("1D:7)P871H
M+"`D<&%T=&5R;E]T>7!E/2=P:'`G*0H@("`@>PH@("`@("`@("1D:"`]($!O
M<&5N9&ER("@D9&ER<&%T:"D["@H@("`@("`@(&EF("@A)&1H*2!["B`@("`@
M("`@("`@("1P92`](&YE=R!&:6QE1FEN9$5X8V5P=&EO;B@B0V%N;F]T(&]P
M96X@9&ER96-T;W)Y(BD["B`@("`@("`@("`@(')E='5R;B`H)'!E*3L*("`@
M("`@("!]"@H@("`@("`@("1M871C:%]F=6YC=&EO;B`]($9I;&5?1FEN9#HZ
M7V1E=&5R;6EN95)E9V5X*"1P871T97)N+"`D<&%T=&5R;E]T>7!E*3L*("`@
M("`@("`D;6%T8VAE<R`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*"1E;G1R
M>2`]($!R96%D9&ER("@D9&@I*2!["B`@("`@("`@("`@(&EF("@D;6%T8VA?
M9G5N8W1I;VXH)'!A='1E<FXL("1E;G1R>2D@)B8*("`@("`@("`@("`@("`@
M("1E;G1R>2`A/2`G+B<@("`@("`@("`@("`@("`@("`@("`F)@H@("`@("`@
M("`@("`@("`@)&5N=')Y("$]("<N+B<I('L*("`@("`@("`@("`@("`@("1M
M871C:&5S6UT@/2`D96YT<GD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@($!C;&]S961I<B`H)&1H*3L*("`@("`@("!R971U<FX@8V]U;G0H
M)&UA=&-H97,I(#X@,"`_("1M871C:&5S(#H@;G5L;#L*("`@('T*"B`@("`O
M*BH*("`@("`J($UA<"!T:&4@9&ER96-T;W)Y('1R964@9VEV96X@8GD@=&AE
M(&1I<F5C=&]R>5]P871H('!A<F%M971E<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D:7)E8W1O<GD@8V]N=&%I;G,@=&AE(&1I<F5C=&]R>2!P
M871H('1H870@>6]U"B`@("`@*B!W86YT('1O(&UA<"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y(&$@='=O(&5L96UE;G0@87)R87DL('1H92!F:7)S
M="!E;&5M96YT(&-O;G1A:6YI;F<@82!L:7-T"B`@("`@*B!O9B!A;&P@=&AE
M(&1I<F5C=&]R:65S+"!T:&4@<V5C;VYD(&5L96UE;G0@8V]N=&%I;FEN9R!A
M(&QI<W0@;V8@86QL('1H90H@("`@("H@9FEL97,N"B`@("`@*@H@("`@("H@
M0&%U=&AO<B!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG0'!H<"YN970^"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F;6%P
M=')E92`H)&1I<F5C=&]R>2D*("`@('L*("`@("`@("`D=&AI<RT^7V1I<G,@
M/2!A<G)A>2@D9&ER96-T;W)Y*3L*"B`@("`@("`@=VAI;&4@*&-O=6YT*"1T
M:&ES+3Y?9&ER<RDI('L*("`@("`@("`@("`@)&1I<B`](&%R<F%Y7W!O<"@D
M=&AI<RT^7V1I<G,I.PH@("`@("`@("`@("!&:6QE7T9I;F0Z.E]B=6EL9"@D
M9&ER*3L*("`@("`@("`@("`@87)R87E?<'5S:"@D=&AI<RT^9&ER96-T;W)I
M97,L("1D:7(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1T
M:&ES+3YD:7)E8W1O<FEE<RP@)'1H:7,M/F9I;&5S*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($UA<"!T:&4@9&ER96-T;W)Y('1R964@9VEV96X@8GD@=&AE
M(&1I<F5C=&]R>2!P87)A;65T97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&ER96-T;W)Y(&-O;G1A:6YS('1H92!D:7)E8W1O<GD@<&%T:"!T
M:&%T('EO=0H@("`@("H@=V%N="!T;R!M87`N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D;6%X<F5C=7)S:6]N(&UA>&EM=6X@;G5M8F5R(&]F(&9O;&1E<G,@
M=&\@<F5C=7)S:79E(`H@("`@("H@;6%P"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2!A(&UU;'1I9&EM96YS:6]N86P@87)R87D@8V]N=&%I;FEN9R!A
M;&P@<W5B9&ER96-T;W)I97,*("`@("`J(&%N9"!T:&5I<B!F:6QE<RX@1F]R
M(&5X86UP;&4Z"B`@("`@*@H@("`@("H@07)R87D*("`@("`J("@*("`@("`J
M("`@(%LP72`]/B!F:6QE7S$N<&AP"B`@("`@*B`@("!;,5T@/3X@9FEL95\R
M+G!H<`H@("`@("H@("`@6W-U8F1I<FYA;65=(#T^($%R<F%Y"B`@("`@*B`@
M("`@("`H"B`@("`@*B`@("`@("`@("!;,%T@/3X@9FEL95\Q+G!H<`H@("`@
M("H@("`@("`@*0H@("`@("H@*0H@("`@("H*("`@("`J($!A=71H;W(@36EK
M82!4=75P;VQA(#QT=75P;VQA0&%P<&5L<VEI;FDN;F5T/@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH*("`@(&9U;F-T:6]N("9M87!4<F5E375L
M=&EP;&4H)&1I<F5C=&]R>2P@)&UA>')E8W5R<VEO;CTP+"`D8V]U;G0],"D*
M("`@('L@("`*"B`@("`@("`@)')E='9A;"`](&%R<F%Y*"D["@H@("`@("`@
M("1C;W5N="LK.PH*("`@("`@("`D9&ER96-T;W)Y("X]($1)4D5#5$]265]3
M15!!4D%43U(["B`@("`@("`@)&1H/6]P96YD:7(H)&1I<F5C=&]R>2D["B`@
M("`@("`@=VAI;&4@*"1E;G1R>2`](')E861D:7(H)&1H*2D@>PH@("`@("`@
M("`@("!I9B`H)&5N=')Y("$]("(N(B`F)B`D96YT<GD@(3T@(BXN(BD@>PH@
M("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)')E='9A;"P@)&5N=')Y*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@8VQO<V5D:7(H)&1H
M*3L*("`@("`*("`@("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L*2`](&5A
M8V@H)')E='9A;"DI('L*("`@("`@("`@("`@)'!A=&@@/2`D9&ER96-T;W)Y
M("X@)'9A;#L*("`@("`@("`@("`@)'!A=&@@/2!S=')?<F5P;&%C92A$25)%
M0U1/4EE?4T5005)!5$]2+D1)4D5#5$]265]315!!4D%43U(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4BP@
M)'!A=&@I.PH@("`@("`*("`@("`@("`@("`@:68@*"$H:7-?87)R87DH)'9A
M;"DI*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?9&ER*"1P871H*2D@>PH@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1R971V86Q;)&ME>5TI.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D;6%X<F5C=7)S:6]N(#T](#`@?'P@)&-O
M=6YT(#P@)&UA>')E8W5R<VEO;BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5T=F%L6R1V86Q=(#T@1FEL95]&:6YD.CIM87!4<F5E375L=&EP;&4H
M)'!A=&@L(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&UA>')E8W5R<VEO;BP@)&-O=6YT*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N*"1R971V86PI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5A<F-H('1H92!S<&5C:69I960@9&ER96-T;W)Y('1R964@=VET:"!T
M:&4@<W!E8VEF:65D('!A='1E<FXN("!2971U<FX@86X*("`@("`J(&%R<F%Y
M(&-O;G1A:6YI;F<@86QL(&UA=&-H:6YG(&9I;&5S("AN;R!D:7)E8W1O<FEE
M<R!I;F-L=61E9"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M=&5R;B!T:&4@<&%T=&5R;B!T;R!M871C:"!E=F5R>2!F:6QE('=I=&@N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER96-T;W)Y('1H92!D:7)E
M8W1O<GD@=')E92!T;R!S96%R8V@@:6XN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D='EP92!T:&4@='EP92!O9B!R96=U;&%R(&5X<')E<W-I;VX@
M<W5P<&]R="!T;R!U<V4L(&5I=&AE<@H@("`@("H@)W!H<"<@;W(@)W!E<FPG
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@82!L:7-T(&]F(&9I;&5S
M(&UA=&-H:6YG('1H92!P871T97)N('!A<F%M971E<B!I;B!T:&4@=&AE(&1I
M<F5C=&]R>0H@("`@("H@<&%T:"!S<&5C:69I960@8GD@=&AE(&1I<F5C=&]R
M>2!P87)A;65T97(*("`@("`J"B`@("`@*B!`875T:&]R(%-T97)L:6YG($AU
M9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9S96%R8V@@*"1P871T97)N+"`D9&ER
M96-T;W)Y+"`D='EP93TG<&AP)RD@>PH@("`@("`@("1M871C:&5S(#T@87)R
M87DH*3L*("`@("`@("!L:7-T("@L)&9I;&5S*2`@/2!&:6QE7T9I;F0Z.FUA
M<'1R964H)&1I<F5C=&]R>2D["B`@("`@("`@)&UA=&-H7V9U;F-T:6]N(#T@
M1FEL95]&:6YD.CI?9&5T97)M:6YE4F5G97@H)'!A='1E<FXL("1T>7!E*3L*
M"B`@("`@("`@<F5S970H)&9I;&5S*3L*("`@("`@("!W:&EL92`H;&ES="@L
M)&5N=')Y*2`](&5A8V@H)&9I;&5S*2D@>PH@("`@("`@("`@("!I9B`H)&UA
M=&-H7V9U;F-T:6]N*"1P871T97)N+"`D96YT<GDI*0H@("`@("`@("`@("`@
M("`@)&UA=&-H97-;72`]("1E;G1R>3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`H)&UA=&-H97,I.PH@("`@?0H@("`@+RHJ"B`@("`@*B!$971E<FUI
M;F4@=VAE=&AE<B!O<B!N;W0@82!V87)I86)L92!I<R!A(%!%05(@97AC97!T
M:6]N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="!014%27T5R<F]R("1V
M87(@=&AE('9A<FEA8FQE('1O('1E<W0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N(')E='5R;G,@=')U92!I9B!T:&4@=F%R:6%B;&4@:7,@82!0
M14%2(&5R<F]R+"!O=&AE<G=I<V4*("`@("`J(&ET(')E='5R;G,@9F%L<V4N
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!I
M<T5R<F]R("@F)'9A<BD*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ:7-%
M<G)O<B@D=F%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H('1H92!C
M=7)R96YT($9I;&5?1FEN9"!V97)S:6]N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@=&AE(&-U<G)E;G0@1FEL95]&:6YD('9E<G-I;VXN"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!&:6QE7T9I
M;F1?=F5R<VEO;B@I"B`@("!["B`@("`@("`@(')E='5R;B`Q+C$["B`@("!]
M"B`@("`O*BH*("`@("`J(&EN=&5R;F%L(&9U;F-T:6]N('1O(&)U:6QD('-I
M;F=U;&%R(&1I<F5C=&]R>2!T<F5E<RP@=7-E9"!B>0H@("`@("H@1FEL95]&
M:6YD.CIM87!T<F5E*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M:7)E8W1O<GD@;F%M92!O9B!T:&4@9&ER96-T;W)Y('1O(')E860*("`@("`J
M($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&0@*"1D
M:7)E8W1O<GDI"B`@("!["B`@("`@("`@)&1H(#T@0&]P96YD:7(@*"1D:7)E
M8W1O<GDI.PH*("`@("`@("!I9B`H(21D:"D@>PH@("`@("`@("`@("`D<&4@
M/2!N97<@1FEL949I;F1%>&-E<'1I;VXH(D-A;FYO="!O<&5N(&1I<F5C=&]R
M>2(I.PH@("`@("`@("`@("!R971U<FX@)'!E.PH@("`@("`@('T*"B`@("`@
M("`@=VAI;&4@*"1E;G1R>2`]($!R96%D9&ER*"1D:"DI('L*("`@("`@("`@
M("`@:68@*"1E;G1R>2`A/2`G+B<@)B8*("`@("`@("`@("`@("`@("1E;G1R
M>2`A/2`G+BXG*2!["@H@("`@("`@("`@("`@("`@)&5N=')Y(#T@)&1I<F5C
M=&]R>2Y$25)%0U1/4EE?4T5005)!5$]2+B1E;G1R>3L*"B`@("`@("`@("`@
M("`@("!I9B`H:7-?9&ER*"1E;G1R>2DI"B`@("`@("`@("`@("`@("`@("`@
M87)R87E?<'5S:"@D=&AI<RT^7V1I<G,L("1E;G1R>2D["B`@("`@("`@("`@
M("`@("!E;'-E"B`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=&AI
M<RT^9FEL97,L("1E;G1R>2D["@H@("`@("`@("`@("!]"@H@("`@("`@('T*
M"B`@("`@("`@0&-L;W-E9&ER*"1D:"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!I;G1E<FYA;"!F=6YC=&EO;B!T;R!D971E<FUI;F4@=&AE('1Y<&4@;V8@
M<F5G=6QA<B!E>'!R97-S:6]N('1O"B`@("`@*B!U<V4L(&EM<&QE;65N=&5D
M(&)Y($9I;&5?1FEN9#HZ9VQO8B@I(&%N9"!&:6QE7T9I;F0Z.G-E87)C:"@I
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92!G:79E;B!296=%
M>'`@='EP90H@("`@("H@0')E='5R;B!S=')I;F<@:VEN9"!O9B!F=6YC=&EO
M;B`H(")E<F5G:2(L(")E<F5G(B!O<B`B<')E9U]M871C:"(I(#L*("`@("`J
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D971E<FUI;F5296=E>"`H)'!A='1E
M<FXL("1T>7!E*0H@("`@>PH@("`@("`@(&EF("@A('-T<F-A<V5C;7`H)'1Y
M<&4L("=P97)L)RDI('L*("`@("`@("`@("`@)&UA=&-H7V9U;F-T:6]N(#T@
M)W!R96=?;6%T8V@G.PH@("`@("`@('T@96QS92!I9B`H(2!S=')C87-E8VUP
M*'-U8G-T<B@D<&%T=&5R;BP@+3(I+"`G+VDG*2D@>PH@("`@("`@("`@("`D
M;6%T8VA?9G5N8W1I;VX@/2`G97)E9VDG.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1M871C:%]F=6YC=&EO;B`]("=E<F5G)SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D;6%T8VA?9G5N8W1I;VX["B`@("!]"@HO+T5N
M9"!#;&%S<PI]"B\J*@HJ($5X8V5P=&EO;B!#;&%S<R!F;W(@17)R;W)H86YD
M;&EN9R!O9B!&:6QE7T9I;F0**B!`86-C97-S('!U8FQI8PHJ+PIC;&%S<R!&
M:6QE1FEN9$5X8V5P=&EO;B!E>'1E;F1S(%!%05)?17)R;W(*>PH@("`@+RHJ
M"B`@("`J(&-L87-S;F%M90H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@
M('9A<B`D8VQA<W-N86UE("`@("`@("`@("`@(#T@)T9I;&5&:6YD17AC97!T
M:6]N)SL*("`@("\J*@H@("`@*B!-97-S86=E(&EN(&9R;VYT(&]F('1H92!E
M<G)O<B!M97-S86=E"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R
M("1E<G)O<E]M97-S86=E7W!R97!E;F0@/2`G17)R;W(@:6X@1FEL95]&:6YD
M)SL*("`@("\J*@H@("`@*B!#<F5A=&5S(&$@4$5!4E]%<G)O<B!O8FIE8W0*
M("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@("!%<G)O<B!M
M97-S86=E"B`@("`J($!P87)A;2!I;G0@("`@)&UO9&4@("`@("`@17)R;W(@
M;6]D90H@("`@*B!`<&%R86T@:6YT("`@("1L979E;"`@("`@($5R<F]R(&QE
M=F5L"B`@("`J"B`@("`J($!R971U<FX@;V)J96-T(%!%05)?17)R;W(*("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!&:6QE1FEN
M9$5X8V5P=&EO;B`H)&UE<W-A9V4L("1M;V1E(#T@4$5!4E]%4E)/4E]21515
M4DXL("1L979E;"`]($5?55-%4E].3U1)0T4I"B`@("!["B`@("`@("`@)'1H
M:7,M/E!%05)?17)R;W(H)&UE<W-A9V4L("1M;V1E+"`D;&5V96PI.PH@("`@
M?0I]"@H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*
M("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]&:6QE+T-35BYP:'``````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`S-#8Q,P`Q,#0Q-S,V,S`P-P`P,3<S-S,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!4;VUA<R!6;VX@5F5S8VAL97(@
M0V]X("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I
M;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W)S.B!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\*+R\@)$ED.B!#4U8N<&AP+'8@,2XQ,R`R,#`S+S`Q+S`T(#$Q.C4T.C4U
M(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*<F5Q=6ER95]O
M;F-E("=&:6QE+G!H<"<["@HO*BH**B!&:6QE(&-L87-S(&9O<B!H86YD;&EN
M9R!#4U8@9FEL97,@*$-O;6UA(%-E<&%R871E9"!686QU97,I+"!A(&-O;6UO
M;B!F;W)M870**B!F;W(@97AC:&%N9VEN9R!D871A+@HJ"BH@5$]$3SH**B`@
M+2!5<V%G92!E>&%M<&QE(&%N9"!$;V,**B`@+2!5<V4@9V5T4&]I;G1E<B@I
M(&EN(&1I<V-O=F5R1F]R;6%T"BH@("T@061D(&$@;&EN92!C;W5N=&5R(&9O
M<B!B96EN9R!A8FQE('1O(&]U='!U="!B971T97(@97)R;W(@<F5P;W)T<PHJ
M("`M(%-T;W)E('1H92!L87-T(&5R<F]R(&EN($=,3T)!3%,@86YD(&%D9"!&
M:6QE7T-35CHZ9V5T3&%S=$5R<F]R*"D**@HJ(%=I<V@Z"BH@("T@4W5P<&]R
M="!-86,@14],(&9O<FUA=`HJ("`M($]T:&5R(&UE=&AO9',@;&EK92!R96%D
M06QL*"DL('=R:71E06QL*"DL(&YU;49I96QD<R@I+"!N=6U2;W=S*"D**B`@
M+2!4<GD@=&\@9&5T96-T(&EF(&$@0U-6(&AA<R!H96%D97(@;W(@;F]T(&EN
M(&1I<V-O=F5R1F]R;6%T*"D**@HJ($MN;W=N($)U9W,Z"BH@*'1H97D@:&%S
M(&)E96X@86YA;'EZ960@8G5T(&9O<B!T:&4@;6]M96YT('1H92!I;7!A8W0@
M:6X@=&AE('-P965D(&9O<@HJ("!P<F]P97)L>2!H86YD;&4@=&AI<R!U;F-O
M;6UO;B!C87-E<R!I<R!T;V\@:&EG:"!A;F0@=V]N)W0@8F4@<W5P<&]R=&5D
M*0HJ("`M($$@9FEE;&0@=VAI8V@@:7,@8V]M<&]S960@;VYL>2!B>2!A('-I
M;F=L92!Q=6]T960@<V5P87)A=&]R("AI92`M/B`[(CLB.RD**B`@("!I<R!N
M;W0@:&%N9&QE9"!P<F]P97)L>0HJ("`M(%=H96X@=&AE<F4@:7,@97AA8W1L
M>2!O;F4@9FEE;&0@;6EN=7,@=&AA;B!T:&4@97AP96-T960@;G5M8F5R(&%N
M9"!T:&5R90HJ("`@(&ES(&$@9FEE;&0@=VET:"!A('-E<&%R871O<B!I;G-I
M9&4L('1H92!P87)S97(@=VEL;"!T:')O=R!T:&4@(G=R;VYG(&-O=6YT(B!E
M<G)O<@HJ"BH@0&%U=&AO<B!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC
M;VT^"BH@0'!A8VMA9V4@1FEL90HJ+PIC;&%S<R!&:6QE7T-35@I["B`@("`O
M*BH*("`@("H@5&AI<R!R86ES945R<F]R(&UE=&AO9"!W;W)K<R!I;B!A(&1I
M9F9E<F5N="!W87DN($ET('=I;&P@86QW87ES(')E='5R;@H@("`@*B!F86QS
M92`H86X@97)R;W(@;V-C=7)R960I(&)U="!I="!W:6QL(&-A;&P@4$5!4CHZ
M<F%I<V5%<G)O<B@I(&)E9F]R90H@("`@*B!I="X@268@;F\@9&5F875L="!0
M14%2(&=L;V)A;"!H86YD;&5R(&ES('-E="P@=VEL;"!T<FEG9V5R(&%N(&5R
M<F]R+@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O<B!4:&4@97)R
M;W(@;65S<V%G90H@("`@*B!`<F5T=7)N(&)O;VP@86QW87ES(&9A;'-E"B`@
M("`J+PH@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D97)R;W(I"B`@("!["B`@
M("`@("`@+R\@268@82!D969A=6QT(%!%05(@17)R;W(@:&%N9&QE<B!I<R!N
M;W0@<V5T('1R:6=G97(@=&AE(&5R<F]R"B`@("`@("`@+R\@6%A8($%D9"!A
M(%!%05(Z.FES4V5T2&%N9&QE<B@I(&UE=&AO9#\*("`@("`@("!I9B`H)$=,
M3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==(#T](%!%05)?15)2
M3U)?4D5455).*2!["B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H)&5R
M<F]R+"!N=6QL+"!014%27T524D]27U1224='15(L($5?55-%4E]705).24Y'
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!014%2.CIR86ES945R
M<F]R*"1E<G)O<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("H@0VAE8VMS('1H92!C;VYF:6=U<F%T:6]N
M(&=I=F5N(&)Y('1H92!U<V5R"B`@("`J"B`@("`J($!P87)A;2!A<G)A>2`@
M)B1C;VYF("!4:&4@8V]N9FEG=7)A=&EO;B!A<W-O8R!A<G)A>0H@("`@*B!`
M<&%R86T@<W1R:6YG("8D97)R;W(@5&AE(&5R<F]R('=I;&P@8F4@=W)I='1E
M;B!H97)E(&EF(&%N>0H@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYF*"8D8V]N
M9BP@)B1E<G)O<BD*("`@('L*("`@("`@("`O+R!C:&5C:R!C;VYF"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D8V]N9BDI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<B`]("));G9A;&ED(&-O;F9I9W5R871I;VXB.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-S970H)&-O;F9;)W-E<"==*2D@>PH@("`@("`@("`@
M("!I9B`H<W1R;&5N*"1C;VYF6R=S97`G72D@(3T@,2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1E<G)O<B`]("=397!A<F%T;W(@8V%N(&]N;'D@8F4@
M;VYE(&-H87(G.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<B`]("=-:7-S:6YG('-E<&%R871O<B`H
M=&AE(")S97`B(&ME>2DG.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T
M*"1C;VYF6R=F:65L9',G72D@?'P@(6ES7VYU;65R:6,H)&-O;F9;)V9I96QD
M<R==*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R(#T@)U1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8R`H=&AE(")F:65L9',B(&ME
M>2DG.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)&-O;F9;)W%U;W1E
M)UTI*2!["B`@("`@("`@("`@(&EF("AS=')L96XH)&-O;F9;)W%U;W1E)UTI
M("$](#$I('L*("`@("`@("`@("`@("`@(')E='5R;B`D97)R;W(@/2`G5&AE
M('%U;W1E(&-H87(@;75S="!B92!O;F4@8VAA<B`H=&AE(")Q=6]T92(@:V5Y
M*2<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D8V]N9ELG<75O=&4G72`](&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF
M("@A:7-S970H)&-O;F9;)V-R;&8G72DI('L*("`@("`@("`@("`@)&-O;F9;
M)V-R;&8G72`](")<;B(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M*B!2971U<FX@;W(@8W)E871E('1H92!F:6QE(&1E<V-R:7!T;W(@87-S;V-I
M871E9"!W:71H(&$@9FEL90H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE(%1H92!N86UE(&]F('1H92!F:6QE"B`@("`J($!P87)A;2!A<G)A>2`@
M)B1C;VYF(%1H92!C;VYF:6=U<F%T:6]N"B`@("`J($!P87)A;2!S=')I;F<@
M)&UO9&4@5&AE(&]P96X@;F]D92`H97@Z($9)3$5?34]$15]214%$(&]R($9)
M3$5?34]$15]74DE412D*("`@("H*("`@("H@0')E='5R;B!M:7AE9"!!(&9I
M;&4@<F5S;W5R8V4@;W(@9F%L<V4*("`@("HO"B`@("!F=6YC=&EO;B!G9710
M;VEN=&5R*"1F:6QE+"`F)&-O;F8L("1M;V1E(#T@1DE,15]-3T1%7U)%040I
M"B`@("!["B`@("`@("`@<W1A=&EC("1R97-O=7)C97,@(#T@87)R87DH*3L*
M("`@("`@("!S=&%T:6,@)&-O;F9I9SL*("`@("`@("!I9B`H:7-S970H)')E
M<V]U<F-E<ULD9FEL95TI*2!["B`@("`@("`@("`@("1C;VYF(#T@)&-O;F9I
M9SL*("`@("`@("`@("`@<F5T=7)N("1R97-O=7)C97-;)&9I;&5=.PH@("`@
M("`@('T*("`@("`@("!&:6QE7T-35CHZ7V-O;F8H)&-O;F8L("1E<G)O<BD[
M"B`@("`@("`@:68@*"1E<G)O<BD@>PH@("`@("`@("`@("!R971U<FX@1FEL
M95]#4U8Z.G)A:7-E17)R;W(H)&5R<F]R*3L*("`@("`@("!]"B`@("`@("`@
M)&-O;F9I9R`]("1C;VYF.PH@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("`@("`D9G`@/2`F1FEL93HZ
M7V=E=$9I;&50;VEN=&5R*"1F:6QE+"`D;6]D92D["B`@("`@("`@4$5!4CHZ
M<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1F<"DI('L*("`@("`@("`@("`@<F5T=7)N($9I;&5?0U-6.CIR86ES945R
M<F]R*"1F<"D["B`@("`@("`@?0H@("`@("`@("1R97-O=7)C97-;)&9I;&5=
M(#T@)&9P.PH*("`@("`@("!I9B`H)&UO9&4@/3T@1DE,15]-3T1%7U)%040@
M)B8@(65M<'1Y*"1C;VYF6R=H96%D97(G72DI('L*("`@("`@("`@("`@:68@
M*"%&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1F<#L*("`@('T*"B`@("`O*BH*("`@("H@56YQ=6]T
M92!D871A"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@)&9I96QD(%1H92!D
M871A('1O('5N<75O=&4*("`@("H@0'!A<F%M('-T<FEN9R`D<75O=&4@5&AE
M('%U;W1E(&-H87(*("`@("H@0')E='5R;B!S=')I;F<@=&AE('5N<75O=&5D
M(&1A=&$*("`@("HO"B`@("!F=6YC=&EO;B!U;G%U;W1E*"1F:65L9"P@)'%U
M;W1E*0H@("`@>PH@("`@("`@("\O($EN8V%S92!N=6QL(&9I96QD<R`H9F]R
M;3H@.SLI"B`@("`@("`@:68@*"%S=')L96XH)&9I96QD*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&9I96QD.PH@("`@("`@('T*("`@("`@("!I9B`H)'%U
M;W1E("8F("1F:65L9'LP?2`]/2`D<75O=&4@)B8@)&9I96QD>W-T<FQE;B@D
M9FEE;&0I+3%](#T]("1Q=6]T92D@>PH@("`@("`@("`@("!R971U<FX@<W5B
M<W1R*"1F:65L9"P@,2P@+3$I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&9I96QD.PH@("`@?0H*("`@("\J*@H@("`@*B!296%D<R!A(')O=R!O9B!D
M871A(&%S(&%N(&%R<F%Y(&9R;VT@82!#4U8@9FEL92X@270G<R!A8FQE('1O
M"B`@("`J(')E860@;65M;R!F:65L9',@=VET:"!M=6QT:6QI;F4@9&%T82X*
M("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@(%1H92!F:6QE;F%M
M92!W:&5R92!T;R!W<FET92!T:&4@9&%T80H@("`@*B!`<&%R86T@87)R87D@
M("8D8V]N9B`@(%1H92!C;VYF:6=U<F%T:6]N(&]F('1H92!D97-T($-35@H@
M("`@*@H@("`@*B!`<F5T=7)N(&UI>&5D($%R<F%Y('=I=&@@=&AE(&1A=&$@
M<F5A9"!O<B!F86QS92!O;B!E<G)O<B]N;R!M;W)E(&1A=&$*("`@("HO"B`@
M("!F=6YC=&EO;B!R96%D475O=&5D*"1F:6QE+"`F)&-O;F8I"B`@("!["B`@
M("`@("`@:68@*"$D9G`@/2!&:6QE7T-35CHZ9V5T4&]I;G1E<B@D9FEL92P@
M)&-O;F8L($9)3$5?34]$15]214%$*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@("1B=69F(#T@)&,@/2!N=6QL.PH@
M("`@("`@("1R970@(#T@87)R87DH*3L*("`@("`@("`D:2`](#$["B`@("`@
M("`@)&EN7W%U;W1E(#T@9F%L<V4["B`@("`@("`@)'%U;W1E(#T@)&-O;F9;
M)W%U;W1E)UT["B`@("`@("`@)&8@/2`D8V]N9ELG9FEE;&1S)UT["B`@("`@
M("`@=VAI;&4@*"@D8V@@/2!F9V5T8R@D9G`I*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@)'!R978@/2`D8SL*("`@("`@("`@("`@)&,@/2`D8V@["B`@
M("`@("`@("`@("\O($-O;6UO;B!C87-E"B`@("`@("`@("`@(&EF("@D8R`A
M/2`D<75O=&4@)B8@)&,@(3T@)&-O;F9;)W-E<"==("8F("1C("$](")<;B(I
M('L*("`@("`@("`@("`@("`@("1B=69F("X]("1C.PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1C
M(#T]("1Q=6]T92`F)B`D<75O=&4@)B8*("`@("`@("`@("`@("`@("@D<')E
M=B`]/2`D8V]N9ELG<V5P)UT@?'P@)'!R978@/3T@(EQN(B!\?"`D<')E=B`]
M/3T@;G5L;"DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1I;E]Q
M=6]T92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("@D:6Y?<75O=&4I
M('L*("`@("`@("`@("`@("`@("\O(%=H96X@96YD<R!Q=6]T90H@("`@("`@
M("`@("`@("`@:68@*"1C(#T]("1C;VYF6R=S97`G72`F)B`D<')E=B`]/2`D
M8V]N9ELG<75O=&4G72D@>PH@("`@("`@("`@("`@("`@("`@("1I;E]Q=6]T
M92`](&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1C(#T](")<
M;B(I('L*("`@("`@("`@("`@("`@("`@("`D<W5B(#T@*"1P<F5V(#T](")<
M<B(I(#\@,B`Z(#$["B`@("`@("`@("`@("`@("`@("`@:68@*"AS=')L96XH
M)&)U9F8I(#X]("1S=6(I("8F"B`@("`@("`@("`@("`@("`@("`@("`@("@D
M8G5F9GMS=')L96XH)&)U9F8I("T@)'-U8GT@/3T@)'%U;W1E*2D*("`@("`@
M("`@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;E]Q
M=6]T92`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21I;E]Q
M=6]T92`F)B`H)&,@/3T@)&-O;F9;)W-E<"==('Q\("1C(#T](")<;B(I*2![
M"B`@("`@("`@("`@("`@("`O+R!-;W)E(&9I96QD<R!T:&%N(&5X<&5C=&5D
M"B`@("`@("`@("`@("`@("!I9B`H*"1C(#T]("1C;VYF6R=S97`G72D@)B8@
M*"AC;W5N="@D<F5T*2`K(#$I(#T]("1F*2D@>PH@("`@("`@("`@("`@("`@
M("`@('=H:6QE("@D8R`A/2`B7&XB*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C(#T@9F=E=&,H)&9P*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@1FEL95]#4U8Z.G)A:7-E17)R;W(H(E)E860@
M;6]R92!F:65L9',@=&AA;B!T:&4@(BX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`B97AP96-T960@(BXD8V]N9ELG9FEE;&1S
M)UTI.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@3&5S<R!F:65L9',@=&AA
M;B!E>'!E8W1E9`H@("`@("`@("`@("`@("`@:68@*"@D8R`]/2`B7&XB*2`F
M)B`H)&D@(3T@)&8I*2!["B`@("`@("`@("`@("`@("`@("`@1FEL95]#4U8Z
M.G)A:7-E17)R;W(H(E)E860@=W)O;F<@9FEE;&1S(&YU;6)E<B!C;W5N=#H@
M)R(N("1I("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`B)R!E>'!E8W1E9"`B+B1C;VYF6R=F:65L9',G72D["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H)'!R978@/3T@(EQR(BD@>PH@("`@("`@("`@
M("`@("`@("`@("1B=69F(#T@<W5B<W1R*"1B=69F+"`P+"`M,2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T6UT@/2!&:6QE7T-3
M5CHZ=6YQ=6]T92@D8G5F9BP@)'%U;W1E*3L*("`@("`@("`@("`@("`@(&EF
M("AC;W5N="@D<F5T*2`]/2`D9BD@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&)U9F8@/2`G)SL*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8G5F
M9B`N/2`D8SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("%F96]F*"1F<"D@
M/R`D<F5T(#H@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E861S(&$@
M(G)O=R(@9G)O;2!A($-35B!F:6QE(&%N9"!R971U<FX@:70@87,@86X@87)R
M87D*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92!4:&4@0U-6(&9I
M;&4*("`@("H@0'!A<F%M(&%R<F%Y("`F)&-O;F8@5&AE(&-O;F9I9W5R871I
M;VX@;V8@=&AE(&1E<W0@0U-6"B`@("`J"B`@("`J($!R971U<FX@;6EX960@
M07)R87D@;W(@9F%L<V4*("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1F:6QE
M+"`F)&-O;F8I"B`@("!["B`@("`@("`@:68@*"$D9G`@/2!&:6QE7T-35CHZ
M9V5T4&]I;G1E<B@D9FEL92P@)&-O;F8L($9)3$5?34]$15]214%$*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("\O
M(%1H92!S:7IE(&ES(&QI;6ET960@=&\@-$L*("`@("`@("!I9B`H(21L:6YE
M("`@/2!F9V5T<R@D9G`L(#0P.38I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@)&9I96QD<R`](&5X<&QO9&4H)&-O
M;F9;)W-E<"==+"`D;&EN92D["B`@("`@("`@:68@*"1C;VYF6R=Q=6]T92==
M*2!["B`@("`@("`@("`@("1L87-T(#TF("1F:65L9'-;8V]U;G0H)&9I96QD
M<RD@+2`Q73L*("`@("`@("`@("`@+R\@1F%L;&)A8VL@=&\@<F5A9"!T:&4@
M;&EN92!W:71H(')E8611=6]T960@=VAE;B!G=65S<PH@("`@("`@("`@("`O
M+R!T:&%T('1H92!S:6UP;&4@97AP;&]D92!W;VXG="!W;W)K(')I9VAT"B`@
M("`@("`@("`@(&EF("@H)&QA<W1[<W1R;&5N*"1L87-T*2`M(#%](#T](")<
M;B(*("`@("`@("`@("`@("`@("8F("1L87-T>S!](#T]("1C;VYF6R=Q=6]T
M92=="B`@("`@("`@("`@("`@("`F)B`D;&%S='MS=')L96XH<G1R:6TH)&QA
M<W0I*2`M(#%]("$]("1C;VYF6R=Q=6]T92==*0H@("`@("`@("`@("`@("`@
M?'P*("`@("`@("`@("`@("`@("AC;W5N="@D9FEE;&1S*2`A/2`D8V]N9ELG
M9FEE;&1S)UTI"B`@("`@("`@("`@("`@("`O+R!86%@@<&5R:&%P<R!T:&5R
M92!I<R!A('-E<&%R871O<B!I;G-I9&4@82!Q=6]T960@9FEE;&0*("`@("`@
M("`@("`@("`@("\O<')E9U]M871C:"@B?'LD8V]N9ELG<75O=&4G77TN*GLD
M8V]N9ELG<V5P)UU]+BI[)&-O;F9;)W%U;W1E)UU]?%4B+"`D;&EN92D*("`@
M("`@("`@("`@("`@("D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M)&QE;B`]('-T<FQE;B@D;&EN92D["B`@("`@("`@("`@("`@("!F<V5E:R@D
M9G`L("TQ("H@<W1R;&5N*"1L:6YE*2P@4T5%2U]#55(I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N($9I;&5?0U-6.CIR96%D475O=&5D*"1F:6QE+"`D8V]N
M9BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;&%S
M="`](')T<FEM*"1L87-T*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F
M:65L9',@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`D9FEE
M;&1S6R1K72`]($9I;&5?0U-6.CIU;G%U;W1E*"1V+"`D8V]N9ELG<75O=&4G
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*&-O=6YT*"1F:65L9',I("$]("1C;VYF6R=F:65L9',G
M72D@>PH@("`@("`@("`@("!&:6QE7T-35CHZ<F%I<V5%<G)O<B@B4F5A9"!W
M<F]N9R!F:65L9',@;G5M8F5R(&-O=6YT.B`G(BX@8V]U;G0H)&9I96QD<RD@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B<@97AP96-T
M960@(BXD8V]N9ELG9FEE;&1S)UTI.PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1F:65L9',["B`@("!]"@H@
M("`@+RHJ"B`@("`J($EN=&5R;F%L('5S92!O;FQY+"!W:6QL(&)E(')E;6]V
M960@:6X@=&AE(&9U='5R90H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1S
M='(@5&AE('-T<FEN9R!T;R!D96)U9PH@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("HO"B`@("!F=6YC=&EO;B!?9&)G0G5F9B@D<W1R*0H@("`@>PH@("`@
M("`@(&EF("AS=')P;W,H)'-T<BP@(EQR(BD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1S='(@/2!S=')?<F5P;&%C92@B7'(B+"`B7W)?(BP@)'-T<BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AS=')P;W,H)'-T<BP@(EQN(BD@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("1S='(@/2!S=')?<F5P;&%C92@B7&XB
M+"`B7VY?(BP@)'-T<BD["B`@("`@("`@?0H@("`@("`@(&EF("AS=')P;W,H
M)'-T<BP@(EQT(BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1S='(@/2!S
M=')?<F5P;&%C92@B7'0B+"`B7W1?(BP@)'-T<BD["B`@("`@("`@?0H@("`@
M("`@(&5C:&\@(F)U9F8Z("@D<W1R*5QN(CL*("`@('T*"B`@("`O*BH*("`@
M("H@5W)I=&5S(&$@<W1R=6,@*&%R<F%Y*2!I;B!A(&9I;&4@87,@0U-6"B`@
M("`J"B`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("!4:&4@9FEL96YA;64@
M=VAE<F4@=&\@=W)I=&4@=&AE(&1A=&$*("`@("H@0'!A<F%M(&%R<F%Y("`D
M9FEE;&1S($]R9&5R960@87)R87D@=VET:"!T:&4@9&%T80H@("`@*B!`<&%R
M86T@87)R87D@("8D8V]N9B`@(%1H92!C;VYF:6=U<F%T:6]N(&]F('1H92!D
M97-T($-35@H@("`@*@H@("`@*B!`<F5T=7)N(&)O;VP@5')U92!O;B!S=6-C
M97-S(&9A;'-E(&]T:&5R=VES90H@("`@*B\*("`@(&9U;F-T:6]N('=R:71E
M*"1F:6QE+"`D9FEE;&1S+"`F)&-O;F8I"B`@("!["B`@("`@("`@:68@*"$D
M9G`@/2!&:6QE7T-35CHZ9V5T4&]I;G1E<B@D9FEL92P@)&-O;F8L($9)3$5?
M34]$15]74DE412DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@("`@("!I9B`H8V]U;G0H)&9I96QD<RD@(3T@)&-O;F9;)V9I
M96QD<R==*2!["B`@("`@("`@("`@($9I;&5?0U-6.CIR86ES945R<F]R*")7
M<F]N9R!F:65L9',@;G5M8F5R(&-O=6YT.B`G(BX@8V]U;G0H)&9I96QD<RD@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B<@97AP96-T
M960@(BXD8V]N9ELG9FEE;&1S)UTI.PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"B`@("`@("`@)'=R:71E(#T@)R<["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@8V]U;G0H)&9I96QD<RD[("1I*RLI('L*("`@("`@
M("`@("`@:68@*"%I<U]N=6UE<FEC*"1F:65L9'-;)&E=*2`F)B`D8V]N9ELG
M<75O=&4G72D@>PH@("`@("`@("`@("`@("`@)'=R:71E("X]("1C;VYF6R=Q
M=6]T92==("X@)&9I96QD<ULD:5T@+B`D8V]N9ELG<75O=&4G73L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1W<FET92`N/2`D9FEE
M;&1S6R1I73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&D@/"`H
M8V]U;G0H)&9I96QD<RD@+2`Q*2D@>PH@("`@("`@("`@("`@("`@)'=R:71E
M("X]("1C;VYF6R=S97`G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1W<FET92`N/2`D8V]N9ELG8W)L9B==.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A9G=R:71E*"1F<"P@)'=R:71E
M*2D@>PH@("`@("`@("`@("!R971U<FX@1FEL95]#4U8Z.G)A:7-E17)R;W(H
M)T-A;B!N;W0@=W)I=&4@=&\@9FEL92<I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("H@1&ES8V]V97(@=&AE
M(&9O<FUA="!O9B!A($-35B!F:6QE("AT:&4@;G5M8F5R(&]F(&9I96QD<RP@
M=&AE('-E<&%R871O<@H@("`@*B!A;F0@:68@:70@<75O=&4@<W1R:6YG(&9I
M96QD<RD*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R!T:&4@0U-6(&9I;&4@
M;F%M90H@("`@*B!`<F5T=7)N(&UI>&5D($%S<V]C(&%R<F%Y(&]R(&9A;'-E
M"B`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]V97)&;W)M870H)&9I;&4I"B`@
M("!["B`@("`@("`@:68@*"$D9G`@/2!`9F]P96XH)&9I;&4L("=R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N($9I;&5?0U-6.CIR86ES945R<F]R*")#;W5L
M9"!N;W0@;W!E;B!F:6QE.B`D9FEL92(I.PH@("`@("`@('T*("`@("`@("`D
M<V5P<R`](&%R<F%Y*")<="(L("<[)RP@)SHG+"`G+"<I.PH@("`@("`@("1M
M871C:&5S(#T@87)R87DH*3L*("`@("`@("`O+R!486ME('1H92!F:7)S="`Q
M,"!L:6YE<R!A;F0@<W1O<F4@=&AE(&YU;6)E<B!O9B!O8W5R<F5N8V5S"B`@
M("`@("`@+R\@9F]R(&5A8V@@<V5P87)A=&]R(&EN(&5A8V@@;&EN90H@("`@
M("`@(&9O<B`H)&D@/2`P.R`H)&D@/"`Q,"D@)B8@*"1L:6YE(#T@9F=E=',H
M)&9P+"`T,#DV*2D[("1I*RLI('L*("`@("`@("`@("`@9F]R96%C:"`H)'-E
M<',@87,@)'-E<"D@>PH@("`@("`@("`@("`@("`@)&UA=&-H97-;)'-E<%U;
M)&E=(#T@<W5B<W1R7V-O=6YT*"1L:6YE+"`D<V5P*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`D9FEN86P@/2!A<G)A>2@I.PH@("`@("`@
M("\O($=R;W5P('1H92!R97-U;'1S(&)Y(&%M;W5N="!O9B!E<75A;"!O8W5R
M<F5N8V5S"B`@("`@("`@9F]R96%C:"`H)&UA=&-H97,@87,@)'-E<"`]/B`D
M<F5S*2!["B`@("`@("`@("`@("1T:6UE<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@("1T:6UE<ULP72`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1R97,@
M87,@)&L@/3X@)&YU;2D@>PH@("`@("`@("`@("`@("`@:68@*"1N=6T@/B`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1I;65S6R1N=6U=(#T@*&ES<V5T
M*"1T:6UE<ULD;G5M72DI(#\@)'1I;65S6R1N=6U=("L@,2`Z(#$["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@87)S;W)T
M*"1T:6UE<RD["B`@("`@("`@("`@("1F:65L9'-;)'-E<%T@/2!K97DH)'1I
M;65S*3L*("`@("`@("`@("`@)&%M;W5N=%LD<V5P72`]("1T:6UE<UMK97DH
M)'1I;65S*5T["B`@("`@("`@?0H@("`@("`@(&%R<V]R="@D86UO=6YT*3L*
M("`@("`@("`D<V5P("`@(#T@:V5Y*"1A;6]U;G0I.PH@("`@("`@("1F:65L
M9',@/2`D9FEE;&1S6R1S97!=.PH@("`@("`@(&EF("AE;7!T>2@D9FEE;&1S
M*2D@>PH@("`@("`@("`@("!R971U<FX@1FEL95]#4U8Z.G)A:7-E17)R;W(H
M)T-O=6QD(&YO="!D:7-C;W9E<B!T:&4@<V5P87)A=&]R)RD["B`@("`@("`@
M?0H@("`@("`@("1C;VYF6R=F:65L9',G72`]("1F:65L9',@*R`Q.PH@("`@
M("`@("1C;VYF6R=S97`G72`@("`]("1S97`["B`@("`@("`@+R\@5&5S="!I
M9B!T:&5R92!A<F4@9FEE;&1S('=I=&@@<75O=&5S(&%R<F]U;F0@:6X@=&AE
M(&9I<G-T(#4@;&EN97,*("`@("`@("`D<75O=&5S(#T@)R)<)R<["B`@("`@
M("`@)'%U;W1E("`](&YU;&P["B`@("`@("`@<F5W:6YD*"1F<"D["B`@("`@
M("`@9F]R("@D:2`](#`[("@D:2`\(#4I("8F("@D;&EN92`](&9G971S*"1F
M<"P@-#`Y-BDI.R`D:2LK*2!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*")\)'-E<"A;)'%U;W1E<UTI+BHH6R1Q=6]T97-=*21S97!\52(L("1L:6YE
M+"`D;6%T8V@I*2!["B`@("`@("`@("`@("`@("!I9B`H)&UA=&-H6S%=(#T]
M("1M871C:%LR72D@>PH@("`@("`@("`@("`@("`@("`@("1Q=6]T92`]("1M
M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@B?%XH6R1Q=6]T97-=*2XJ*%LD<75O=&5S72DD<V5P?"(L("1L:6YE
M+"`D;6%T8V@I"B`@("`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H*")\*%LD
M<75O=&5S72DN*BA;)'%U;W1E<UTI)'-E<%QS)'Q5<R(L("1L:6YE+"`D;6%T
M8V@I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!I9B`H)&UA=&-H
M6S%=(#T]("1M871C:%LR72D@>PH@("`@("`@("`@("`@("`@("`@("1Q=6]T
M92`]("1M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`D8V]N9ELG<75O=&4G72`]("1Q=6]T93L*("`@("`@("!F8VQO<V4H)&9P
M*3L*("`@("`@("`O+R!86%@@5VAA="!A8F]U="!T<GEI;F<@=&\@9&ES8V]V
M97(@=&AE(")H96%D97(B/PH@("`@("`@(')E='5R;B`D8V]N9CL*("`@('T*
M?0H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B](5%10+P``````````````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P
M,38Q,C,`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TA45%`O5V5B1$%6
M+P``````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8S,#`W`#`Q-S$W,P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O2%144"]796)$058O5&]O;',O````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#<`,#(P,C<S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B](5%10+U=E8D1!5B]4;V]L<R]?<&%R
M<V5?<')O<&9I;F0N<&AP````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$Q,P`Q,#0Q-S,V
M,S`P-P`P,C0Q-3$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"2\O(&AE;'!E<B!C;&%S<R!F;W(@<&%R<VEN9R!0
M4D]01DE.1"!R97%U97-T(&)O9&EE<PH)8VQA<W,@7W!A<G-E7W!R;W!F:6YD
M(`H@('L*"0DO+R!G970@<F5Q=65S=&5D('!R;W!E<G1I97,@87,@87)R87D@
M8V]N=&%I;FEN9R!N86UE+VYA;65S<&%C92!P86ER<PH)"69U;F-T:6]N(%]P
M87)S95]P<F]P9FEN9"@D<&%T:"D@"@D)>PH)"0DD=&AI<RT^<W5C8V5S<R`]
M('1R=64["@H)"0DD=&AI<RT^9&5P=&@@/2`P.PH)"0DD=&AI<RT^<')O<',@
M/2!A<G)A>2@I.PH)"0DD:&%D7VEN<'5T(#T@9F%L<V4["@D)"21X;6Q?<&%R
M<V5R(#T@>&UL7W!A<G-E<E]C<F5A=&5?;G,H(E541BTX(BP@(B`B*3L*"0D)
M>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'AM;%]P87)S97(L"@D)"0D)"0D)
M"6%R<F%Y*"8D=&AI<RP@(E]S=&%R=$5L96UE;G0B*2P*"0D)"0D)"0D)87)R
M87DH)B1T:&ES+"`B7V5N9$5L96UE;G0B*2D["@D)"7AM;%]P87)S97)?<V5T
M7V]P=&EO;B@D>&UL7W!A<G-E<BP@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L
M"@D)"0D)"0D)"0D)"0D)9F%L<V4I.PH)"0DD9E]I;B`](&9O<&5N*"1P871H
M+"`B<B(I.PH)"0EW:&EL92@D=&AI<RT^<W5C8V5S<R`F)B`A9F5O9B@D9E]I
M;BDI('L*"0D)"21L:6YE(#T@9F=E=',H)&9?:6XI.PH)"0D):68@*&ES7W-T
M<FEN9R@D;&EN92DI('L*"0D)"0DD;&EN92`]('1R:6TH)&QI;F4I.PH)"0D)
M"6EF*"1L:6YE(#T]("(B*2!C;VYT:6YU93L*"0D)"0DD:&%D7VEN<'5T(#T@
M=')U93L*"0D)"0DD=&AI<RT^<W5C8V5S<R`F/2!X;6Q?<&%R<V4H)'AM;%]P
M87)S97(L("1L:6YE+"!F86QS92D["@D)"0E]"@D)"7T@"@D)"6EF*"1H861?
M:6YP=70I('L*"0D)"21T:&ES+3YS=6-C97-S("8]('AM;%]P87)S92@D>&UL
M7W!A<G-E<BP@(B(L('1R=64I.PH)"0E]"@D)"69C;&]S92@D9E]I;BD["@D)
M"7AM;%]P87)S97)?9G)E92@D>&UL7W!A<G-E<BD["@H)"0EI9B@A8V]U;G0H
M)'1H:7,M/G!R;W!S*2D@)'1H:7,M/G!R;W!S(#T@(F%L;"([("\O(&1E9F%U
M;'0*"0E]"@D*"0H)9G5N8W1I;VX@7W-T87)T16QE;65N="@D<&%R<V5R+"`D
M;F%M92P@)&%T=')S*2`*("!["@D):68@*'-T<G-T<B@D;F%M92P@(B`B*2D@
M>PH)"0EL:7-T*"1N<RP@)'1A9RD@/2!E>'!L;V1E*"(@(BP@)&YA;64I.PH)
M"0EI9B`H)&YS(#T]("(B*0H)"0D))'1H:7,M/G-U8V-E<W,@/2!F86QS93L*
M"0E](&5L<V4@>PH)"0DD;G,@/2`B(CL*"0D))'1A9R`]("1N86UE.PH)"7T*
M"0EI9B`H)'1H:7,M/F1E<'1H(#T](#$I('L*"0D):68@*"1T86<@/3T@(F%L
M;'!R;W`B*0H)"0D))'1H:7,M/G!R;W!S(#T@(F%L;"(["@D)"6EF("@D=&%G
M(#T](")P<F]P;F%M92(I"@D)"0DD=&AI<RT^<')O<',@/2`B;F%M97,B.PH)
M"7T*"0EI9B`H)'1H:7,M/F1E<'1H(#T](#(I('L*"0D))'!R;W`@/2!A<G)A
M>2@B;F%M92(@/3X@)'1A9RD["@D)"6EF("@D;G,I"@D)"0DD<')O<%LB>&UL
M;G,B72`]("1N<SL*"0D))'1H:7,M/G!R;W!S6UT@/2`D<')O<#L*"0E]"@D)
M)'1H:7,M/F1E<'1H*RL["@E]"@H)9G5N8W1I;VX@7V5N9$5L96UE;G0H)'!A
M<G-E<BP@)&YA;64I(`H@('L*"0DD=&AI<RT^9&5P=&@M+3L*"7T*?0H*"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O2%144"]796)$058O5&]O;',O7W!A<G-E7W!R
M;W!P871C:"YP:'``````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0U-S0`,3`T,3<S-C,P,#<`
M,#(T,S0T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@H@("`@("`@("\O(&AE;'!E<B!C;&%S<R!F;W(@<&%R<VEN
M9R!04D]04$%40T@@<F5Q=65S="!B;V1I97,*8VQA<W,@7W!A<G-E7W!R;W!P
M871C:"!["B`@("!F=6YC=&EO;B!?<&%R<V5?<')O<'!A=&-H*"1P871H*2![
M"B`@("`@("`@)'1H:7,M/G-U8V-E<W,@/2!T<G5E.PH*("`@("`@("`D=&AI
M<RT^9&5P=&@@/2`P.PH@("`@("`@("1T:&ES+3YP<F]P<R`](&%R<F%Y*"D[
M"@D)"0DD:&%D7VEN<'5T(#T@9F%L<V4["B`@("`@("`@)'AM;%]P87)S97(@
M/2!X;6Q?<&%R<V5R7V-R96%T95]N<R@B551&+3@B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B`B*3L*("`@("`@("!X
M;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D>&UL7W!A<G-E<BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@F)'1H:7,L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(E]S=&%R=$5L96UE;G0B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@F)'1H
M:7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(E]E
M;F1%;&5M96YT(BDI.PH@("`@("`@('AM;%]S971?8VAA<F%C=&5R7V1A=&%?
M:&%N9&QE<B@D>&UL7W!A<G-E<BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)B1T:&ES+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B7V1A=&$B*2D["B`@("`@
M("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1X;6Q?<&%R<V5R+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?3U!424].7T-!4T5?1D],1$E.
M1RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4I.PH*"0D)
M"21F7VEN(#T@9F]P96XH)'!A=&@L(")R(BD["@D)"0EW:&EL92@D=&AI<RT^
M<W5C8V5S<R`F)B`A9F5O9B@D9E]I;BDI('L*"0D)"0DD;&EN92`](&9G971S
M*"1F7VEN*3L*"0D)"0EI9B`H:7-?<W1R:6YG*"1L:6YE*2D@>PH)"0D)"0DD
M;&EN92`]('1R:6TH)&QI;F4I.PH)"0D)"0EI9B@D;&EN92`]/2`B(BD@8V]N
M=&EN=64["@D)"0D)"21H861?:6YP=70@/2!T<G5E.PH)"0D)"0DD=&AI<RT^
M<W5C8V5S<R`F/2!X;6Q?<&%R<V4H)'AM;%]P87)S97(L("1L:6YE+"!F86QS
M92D["@D)"0D)?0H)"0D)?2`*"0D)"6EF*"1H861?:6YP=70I('L*"0D)"0DD
M=&AI<RT^<W5C8V5S<R`F/2!X;6Q?<&%R<V4H)'AM;%]P87)S97(L("(B+"!T
M<G5E*3L*"0D)"7T*"0D)"69C;&]S92@D9E]I;BD["@H@("`@("`@('AM;%]P
M87)S97)?9G)E92@D>&UL7W!A<G-E<BD["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W-T87)T16QE;65N="@D<&%R<V5R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')S
M*2!["B`@("`@("`@:68@*'-T<G-T<B@D;F%M92P@(B`B*2D@>PH@("`@("`@
M("`@("!L:7-T*"1N<RP@)'1A9RD@/2!E>'!L;V1E*"(@(BP@)&YA;64I.PH@
M("`@("`@("`@("!I9B`H)&YS(#T]("(B*0H@("`@("`@("`@("`@("`@)'1H
M:7,M/G-U8V-E<W,@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;G,@/2`B(CL*("`@("`@("`@("`@)'1A9R`]("1N86UE.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'1H:7,M/F1E<'1H(#T](#$I('L*("`@("`@
M("`@("`@)'1H:7,M/FUO9&4@/2`D=&%G.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F1E<'1H(#T](#,I('L*("`@("`@("`@("`@)'!R;W`@/2!A
M<G)A>2@B;F%M92(@/3X@)'1A9RD["B`@("`@("`@("`@("1T:&ES+3YC=7)R
M96YT(#T@87)R87DH(FYA;64B(#T^("1T86<L(")N<R(@/3X@)&YS+"`B<W1A
M='5S(CT^(#(P,"D["B`@("`@("`@("`@(&EF("@D=&AI<RT^;6]D92`]/2`B
M<V5T(BD*("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT6R)V86PB72`]
M("(B.R`@("`@+R\@9&5F875L="!S970@=F%L"B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YD97!T:"LK.PH@("`@?0H*("`@(&9U;F-T:6]N(%]E;F1%;&5M
M96YT*"1P87)S97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92D@
M>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8W5R<F5N="DI('L*("`@("`@
M("`@("`@)'1H:7,M/G!R;W!S6UT@/2`D=&AI<RT^8W5R<F5N=#L*("`@("`@
M("`@("`@=6YS970H)'1H:7,M/F-U<G)E;G0I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^9&5P=&@M+3L*("`@('T*"B`@("!F=6YC=&EO;B!?9&%T82@D
M<&%R<V5R+`H@("`@("`@("`@("`@("`@("`@)&1A=&$I('L*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-U<G)E;G0I*2!["B`@("`@("`@("`@("1T:&ES
M+3YC=7)R96YT6R)V86PB72`]("1D871A.PH@("`@("`@('T*("`@('T*?0H*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O2%144"]796)$058O5&]O
M;',O7W!A<G-E7VQO8VMI;F9O+G!H<```````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4S,3``
M,3`T,3<S-C,P,#<`,#(T,3,U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@H)+R\@:&5L<&5R(&-L87-S(&9O<B!P
M87)S:6YG($Q/0TL@<F5Q=65S="!B;V1I97,*"6-L87-S(%]P87)S95]L;V-K
M:6YF;R`*("!["@D)=F%R("1O=VYE<B`]("(B.PH)"79A<B`D8V]L;&5C=%]O
M=VYE<B`](&9A;'-E.PH)"B`@("!F=6YC=&EO;B!?<&%R<V5?;&]C:VEN9F\H
M)'!A=&@I(`H)"7L*"0D)"21T:&ES+3YS=6-C97-S(#T@=')U93L*"0D)"21H
M861?:6YP=70@/2!F86QS93L*"@D)"0DD>&UL7W!A<G-E<B`]('AM;%]P87)S
M97)?8W)E871E7VYS*")55$8M."(L("(@(BD["@D)"0EX;6Q?<V5T7V5L96UE
M;G1?:&%N9&QE<B@D>&UL7W!A<G-E<BP*"0D)"0D)"0D)"0D)"0D)"6%R<F%Y
M*"8D=&AI<RP@(E]S=&%R=$5L96UE;G0B*2P*"0D)"0D)"0D)"0D)"0D)"6%R
M<F%Y*"8D=&AI<RP@(E]E;F1%;&5M96YT(BDI.PH)"0D)>&UL7W-E=%]C:&%R
M86-T97)?9&%T85]H86YD;&5R*"1X;6Q?<&%R<V5R+`H)"0D)"0D)"0D)"0D)
M"0D)"0D)(&%R<F%Y*"8D=&AI<RP@(E]D871A(BDI.PH)"0D)>&UL7W!A<G-E
M<E]S971?;W!T:6]N*"1X;6Q?<&%R<V5R+`H)"0D)"0D)"0D)"0D)"0E834Q?
M3U!424].7T-!4T5?1D],1$E.1RP@9F%L<V4I.PH*"0D)"21F7VEN(#T@9F]P
M96XH)'!A=&@L(")R(BD["@D)"0EW:&EL92@D=&AI<RT^<W5C8V5S<R`F)B`A
M9F5O9B@D9E]I;BDI('L*"0D)"0DD;&EN92`](&9G971S*"1F7VEN*3L*"0D)
M"0EI9B`H:7-?<W1R:6YG*"1L:6YE*2D@>PH)"0D)"0DD;&EN92`]('1R:6TH
M)&QI;F4I.PH)"0D)"0EI9B@D;&EN92`]/2`B(BD@8V]N=&EN=64["@D)"0D)
M"21H861?:6YP=70@/2!T<G5E.PH)"0D)"0DD=&AI<RT^<W5C8V5S<R`F/2!X
M;6Q?<&%R<V4H)'AM;%]P87)S97(L("1L:6YE+"!F86QS92D["@D)"0D)?0H)
M"0D)?2`*"0D)"6EF*"1H861?:6YP=70I('L*"0D)"0DD=&AI<RT^<W5C8V5S
M<R`F/2!X;6Q?<&%R<V4H)'AM;%]P87)S97(L("(B+"!T<G5E*3L*"0D)"7T*
M"0D)"69C;&]S92@D9E]I;BD["@H)"0D)>&UL7W!A<G-E<E]F<F5E*"1X;6Q?
M<&%R<V5R*3L*"0E]"B`@("`*"B`@("!F=6YC=&EO;B!?<W1A<G1%;&5M96YT
M*"1P87)S97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D871T<G,I('L*("`@("`@("!I
M9B`H<W1R<W1R*"1N86UE+"`B("(I*2!["B`@("`@("`@("`@(&QI<W0H)&YS
M+"`D=&%G*2`](&5X<&QO9&4H(B`B+"`D;F%M92D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&YS(#T@(B(["B`@("`@("`@("`@("1T86<@/2`D
M;F%M93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^8V]L;&5C=%]O
M=VYE<BD@>PH@("`@("`@("`@("`D;G-?<VAO<G0@/2`B(CL*("`@("`@("`@
M("`@)&YS7V%T='(@/2`B(CL*("`@("`@("`@("`@:68@*"1N<RD@>PH@("`@
M("`@("`@("`@("`@:68@*"1N<R`]/2`B1$%6.B(I('L*("`@("`@("`@("`@
M("`@("`@("`D;G-?<VAO<G0@/2`B1#HB.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D;G-?871T<B`]("(@>&UL;G,]
M)R1N<R<B.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3YO=VYE<B`N/2`B/"1N<U]S:&]R="1T86<D;G-?871T
M<CXB.PH@("`@("`@('T@96QS92!I9B`H)&YS(#T](")$058Z(BD@>PH@("`@
M("`@("`@("!S=VET8V@@*"1T86<I('L*("`@("`@("`@("`@("`@(&-A<V4@
M(G=R:71E(CH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]C:W1Y<&4@
M/2`D=&%G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@8V%S92`B97AC;'5S:79E(CH*("`@("`@("`@("`@("`@(&-A<V4@
M(G-H87)E9"(Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO8VMS8V]P
M92`]("1T86<["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!C87-E(")O=VYE<B(Z"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F-O;&QE8W1?;W=N97(@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(%]D871A*"1P87)S97(L"B`@("`@("`@("`@("`@("`@("`D9&%T
M82D@>PH@("`@("`@(&EF("@D=&AI<RT^8V]L;&5C=%]O=VYE<BD@>PH@("`@
M("`@("`@("`D=&AI<RT^;W=N97(@+CT@)&1A=&$["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(%]E;F1%;&5M96YT*"1P87)S97(L("1N86UE*2![
M"@D)"6EF("AS=')S='(H)&YA;64L("(@(BDI('L*"0D)"6QI<W0H)&YS+"`D
M=&%G*2`](&5X<&QO9&4H(B`B+"`D;F%M92D["@D)"7T@96QS92!["@D)"0DD
M;G,@/2`B(CL*"0D)"21T86<@/2`D;F%M93L*"0D)?0H)"0EI9B`H*"1N<R`]
M/2`B1$%6.B(I("8F("@D=&%G(#T](")O=VYE<B(I*2!["@D)"0DD=&AI<RT^
M8V]L;&5C=%]O=VYE<B`](&9A;'-E.PH)"0E]"@D)"6EF("@D=&AI<RT^8V]L
M;&5C=%]O=VYE<BD@>PH)"0D))&YS7W-H;W)T(#T@(B(["@D)"0DD;G-?871T
M<B`]("(B.PH)"0D):68@*"1N<RD@>PH)"0D)"6EF("@D;G,@/3T@(D1!5CHB
M*2!["B`@("`@("`@("`@("`@("`@("`@)&YS7W-H;W)T(#T@(D0Z(CL*"0D)
M"0E](&5L<V4@>PH)"0D)"0DD;G-?871T<B`]("(@>&UL;G,])R1N<R<B.PH)
M"0D)"7T*"0D)"7T*"0D)"21T:&ES+3YO=VYE<B`N/2`B/"\D;G-?<VAO<G0D
M=&%G)&YS7V%T='(^(CL*"0D)?0H@("`@?0I]"@H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B](5%10+U=E8D1!5B]397)V97(O````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P,C`T
M-#$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TA45%`O5V5B1$%6+U-E
M<G9E<B]&:6QE<WES=&5M+G!H<```````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0R-C`W
M`#$P-#$W,S8S,#`W`#`R,S,P-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*("`@(')E<75I<F5?;VYC92`B2%14
M4"]796)$058O4V5R=F5R+G!H<"(["B`@("`*("`@("\J*@H@("`@("H@1FEL
M97-Y<W1E;2!A8V-E<W,@=7-I;F<@5V5B1$%6"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@8VQA<W,@2%144%]796)$059?4V5R
M=F5R7T9I;&5S>7-T96T@97AT96YD<R!(5%107U=E8D1!5E]397)V97(@"B`@
M("!["B`@("`@("`@+RHJ"B`@("`@("`@("H@4F]O="!D:7)E8W1O<GD@9F]R
M(%=E8D1!5B!A8V-E<W,*("`@("`@("`@*@H@("`@("`@("`J($1E9F%U;'1S
M('1O('=E8G-E<G9E<B!D;V-U;65N="!R;V]T("AS970@8GD@4V5R=F5297%U
M97-T*0H@("`@("`@("`J"B`@("`@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@("`@("H@0'9A<B`@("!S=')I;F<*("`@("`@("`@*B\*("`@("`@("!V
M87(@)&)A<V4@/2`B(CL*"B`@("`@("`@+RHJ(`H@("`@("`@("`J($UY4U%,
M($AO<W0@=VAE<F4@<')O<&5R='D@86YD(&QO8VMI;F<@:6YF;W)M871I;VX@
M:7,@<W1O<F5D"B`@("`@("`@("H*("`@("`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`@("`@*B!`=F%R("`@('-T<FEN9PH@("`@("`@("`J+PH@("`@
M("`@('9A<B`D9&)?:&]S="`](")L;V-A;&AO<W0B.PH*("`@("`@("`O*BH*
M("`@("`@("`@*B!->5-13"!D871A8F%S92!F;W(@<')O<&5R='DO;&]C:VEN
M9R!I;F9O<FUA=&EO;B!S=&]R86=E"B`@("`@("`@("H*("`@("`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`@("`@*B!`=F%R("`@('-T<FEN9PH@("`@
M("`@("`J+PH@("`@("`@('9A<B`D9&)?;F%M92`](")W96)D878B.PH*("`@
M("`@("`O*BH*("`@("`@("`@*B!->5-13"!U<V5R(&9O<B!P<F]P97)T>2]L
M;V-K:6YG(&1B(&%C8V5S<PH@("`@("`@("`J"B`@("`@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@("`@("H@0'9A<B`@("!S=')I;F<*("`@("`@("`@
M*B\*("`@("`@("!V87(@)&1B7W5S97(@/2`B<F]O="(["@H@("`@("`@("\J
M*@H@("`@("`@("`J($UY4U%,('!A<W-W;W)D(&9O<B!P<F]P97)T>2]L;V-K
M:6YG(&1B(&%C8V5S<PH@("`@("`@("`J"B`@("`@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@("`@("H@0'9A<B`@("!S=')I;F<*("`@("`@("`@*B\*
M("`@("`@("!V87(@)&1B7W!A<W-W9"`]("(B.PH*("`@("`@("`O*BH*("`@
M("`@("`@*B!397)V92!A('=E8F1A=B!R97%U97-T"B`@("`@("`@("H*("`@
M("`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("`@("`J($!P87)A;2`@<W1R
M:6YG("`*("`@("`@("`@*B\*("`@("`@("!F=6YC=&EO;B!397)V95)E<75E
M<W0H)&)A<V4@/2!F86QS92D@"B`@("`@("`@>PH@("`@("`@("`@("`O+R!S
M<&5C:6%L('1R96%T;65N="!F;W(@;&ET;75S(&-O;7!L:6%N8V4@=&5S=`H@
M("`@("`@("`@("`O+R!R97!L>2!O;B!I=',@:61E;G1I9FEE<B!H96%D97(*
M("`@("`@("`@("`@+R\@;F]T(&YE961E9"!F;W(@=&AE('1E<W0@:71S96QF
M(&)U="!E87-E<R!D96)U9V=I;F<*("`@("`@("`@("`@9F]R96%C:"AA<&%C
M:&5?<F5Q=65S=%]H96%D97)S*"D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@("`@(&EF*'-T<FES='(H)&ME>2PB;&ET;75S(BDI('L*("`@
M("`@("`@("`@("`@("`@("!E<G)O<E]L;V<H(DQI=&UU<R!T97-T("1V86QU
M92(I.PH@("`@("`@("`@("`@("`@("`@(&AE861E<B@B6"U,:71M=7,M<F5P
M;'DZ("(N)'9A;'5E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+R\@<V5T(')O;W0@9&ER96-T;W)Y+"!D969A=6QT
M<R!T;R!W96)S97)V97(@9&]C=6UE;G0@<F]O="!I9B!N;W0@<V5T"B`@("`@
M("`@("`@(&EF("@D8F%S92D@>R`*("`@("`@("`@("`@("`@("1T:&ES+3YB
M87-E(#T@<F5A;'!A=&@H)&)A<V4I.R`O+R!43T1/('1H<F]W(&EF(&YO="!A
M(&1I<F5C=&]R>0H@("`@("`@("`@("!](&5L<V4@:68H(21T:&ES+3YB87-E
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^8F%S92`]("1?4T525D526R=$
M3T-5345.5%]23T]4)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(`H@("`@("`@("`@("`O+R!E<W1A8FQI<V@@8V]N;F5C=&EO;B!T;R!P<F]P
M97)T>2]L;V-K:6YG(&1B"B`@("`@("`@("`@(&UY<W%L7V-O;FYE8W0H)'1H
M:7,M/F1B7VAO<W0L("1T:&ES+3YD8E]U<V5R+"`D=&AI<RT^9&)?<&%S<W=D
M*2!O<B!D:64H;7ES<6Q?97)R;W(H*2D["B`@("`@("`@("`@(&UY<W%L7W-E
M;&5C=%]D8B@D=&AI<RT^9&)?;F%M92D@;W(@9&EE*&UY<W%L7V5R<F]R*"DI
M.PH@("`@("`@("`@("`O+R!43T1/('1H<F]W(&]N(&-O;FYE8W1I;VX@<')O
M8FQE;7,*"B`@("`@("`@("`@("\O(&QE="!T:&4@8F%S92!C;&%S<R!D;R!A
M;&P@=&AE('=O<FL*("`@("`@("`@("`@<&%R96YT.CI397)V95)E<75E<W0H
M*3L*("`@("`@("!]"@H@("`@("`@("\J*@H@("`@("`@("`J($YO(&%U=&AE
M;G1I8V%T:6]N(&ES(&YE961E9"!H97)E"B`@("`@("`@("H*("`@("`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`@("`@*B!`<&%R86T@('-T<FEN9R`@
M2%144"!!=71H96YT:6-A=&EO;B!T>7!E("A"87-I8RP@1&EG97-T+"`N+BXI
M"B`@("`@("`@("H@0'!A<F%M("!S=')I;F<@(%5S97)N86UE"B`@("`@("`@
M("H@0'!A<F%M("!S=')I;F<@(%!A<W-W;W)D"B`@("`@("`@("HO"B`@("`@
M("`@9G5N8W1I;VX@8VAE8VM?875T:"@D='EP92P@)'5S97(L("1P87-S*2`*
M("`@("`@("!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@"B`@("`@("`@9G5N8W1I;VX@4%)/4$9)3D0H)&]P=&EO;G,L
M("8D9FEL97,I(`H@("`@("`@('L*("`@("`@("`@("`@+R\@9V5T(&%B<V]L
M=71E(&9S('!A=&@@=&\@<F5Q=65S=&5D(')E<V]U<F-E"B`@("`@("`@("`@
M("1F<W!A=&@@/2!R96%L<&%T:"@D=&AI<RT^8F%S92`N("1O<'1I;VYS6R)P
M871H(ETI.PH@("`@("`@("`@("`*("`@("`@("`@("`@+R\@<V%N:71Y(&-H
M96-K"B`@("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9S<&%T:"DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@<')E<&%R92!P<F]P97)T>2!A<G)A>0H@("`@("`@
M("`@("`D9FEL97-;(F9I;&5S(ET@/2!A<G)A>2@I.PH*("`@("`@("`@("`@
M+R\@<W1O<F4@:6YF;W)M871I;VX@9F]R('1H92!R97%U97-T960@<&%T:"!I
M='-E;&8*("`@("`@("`@("`@)&9I;&5S6R)F:6QE<R)=6UT@/2`D=&AI<RT^
M9FEL96EN9F\H)&]P=&EO;G-;(G!A=&@B72P@)&]P=&EO;G,I.PH*("`@("`@
M("`@("`@+R\@:6YF;W)M871I;VX@9F]R(&-O;G1A:6YE9"!R97-O=7)C97,@
M<F5Q=65S=&5D/PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1O<'1I;VYS6R)D
M97!T:")=*2D@('L@+R\@5$]$3R!C:&5C:R!F;W(@:7-?9&ER*"D@9FER<W0_
M"B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("\O(&UA:V4@<W5R
M92!P871H(&5N9',@=VET:"`G+R<*("`@("`@("`@("`@("`@(&EF("AS=6)S
M='(H)&]P=&EO;G-;(G!A=&@B72PM,2D@(3T@(B\B*2![(`H@("`@("`@("`@
M("`@("`@("`@("1O<'1I;VYS6R)P871H(ET@+CT@(B\B.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("\O('1R>2!T;R!O<&5N(&1I<F5C
M=&]R>0H@("`@("`@("`@("`@("`@)&AA;F1L92`]($!O<&5N9&ER*"1F<W!A
M=&@I.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("!I9B`H)&AA
M;F1L92D@>PH@("`@("`@("`@("`@("`@("`@("\O(&]K+"!N;W<@9V5T(&%L
M;"!I=',@8V]N=&5N=',*("`@("`@("`@("`@("`@("`@("!W:&EL92`H)&9I
M;&5N86UE(#T@<F5A9&1I<B@D:&%N9&QE*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&9I;&5N86UE("$]("(N(B`F)B`D9FEL96YA;64@(3T@
M(BXN(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5S6R)F
M:6QE<R)=6UT@/2`D=&AI<RT^9FEL96EN9F\@*"1O<'1I;VYS6R)P871H(ETN
M)&9I;&5N86UE+"`D;W!T:6]N<RD["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M+R\@5$]$3R!R96-U<G-I;VX@;F5E9&5D(&EF(")$97!T:#H@:6YF:6YI=&4B
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O(&]K+"!A;&P@9&]N90H@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!](`H*("`@("`@("!F=6YC=&EO;B!F:6QE:6YF;R@D=7)I+"`D;W!T
M:6]N<RD@"B`@("`@("`@>PH@("`@("`@("`@("`*("`@("`@("`@("`@)&9S
M<&%T:"`]("1T:&ES+3YB87-E("X@)'5R:3L*"B`@("`@("`@("`@("1F:6QE
M(#T@87)R87DH*3L*("`@("`@("`@("`@)&9I;&5;(G!A=&@B73T@)'5R:3L@
M("`@"@H@("`@("`@("`@("`D9FEL95LB<')O<',B75M=(#T@)'1H:7,M/FUK
M<')O<"@B9&ES<&QA>6YA;64B+"!S=')T;W5P<&5R*"1U<FDI*3L*"B`@("`@
M("`@("`@("1F:6QE6R)P<F]P<R)=6UT@/2`D=&AI<RT^;6MP<F]P*")C<F5A
M=&EO;F1A=&4B+"!F:6QE8W1I;64H)&9S<&%T:"DI.PH@("`@("`@("`@("`D
M9FEL95LB<')O<',B75M=(#T@)'1H:7,M/FUK<')O<"@B9V5T;&%S=&UO9&EF
M:65D(BP@9FEL96UT:6UE*"1F<W!A=&@I*3L*"B`@("`@("`@("`@(&EF("AI
M<U]D:7(H)&9S<&%T:"DI('L*("`@("`@("`@("`@("`@("1F:6QE6R)P<F]P
M<R)=6UT@/2`D=&AI<RT^;6MP<F]P*")G971C;VYT96YT;&5N9W1H(BP@,"D[
M"B`@("`@("`@("`@("`@("`D9FEL95LB<')O<',B75M=(#T@)'1H:7,M/FUK
M<')O<"@B<F5S;W5R8V5T>7!E(BP@(F-O;&QE8W1I;VXB*3L*("`@("`@("`@
M("`@("`@("1F:6QE6R)P<F]P<R)=6UT@/2`D=&AI<RT^;6MP<F]P*")G971C
M;VYT96YT='EP92(L(")H='1P9"]U;FEX+61I<F5C=&]R>2(I.R`@("`@("`@
M("`@("`*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F
M:6QE6R)P<F]P<R)=6UT@/2`D=&AI<RT^;6MP<F]P*")R97-O=7)C971Y<&4B
M+"`B(BD["B`@("`@("`@("`@("`@("`D9FEL95LB<')O<',B75M=(#T@)'1H
M:7,M/FUK<')O<"@B9V5T8V]N=&5N=&QE;F=T:"(L(&9I;&5S:7IE*"1F<W!A
M=&@I*3L*("`@("`@("`@("`@("`@(&EF("AI<U]R96%D86)L92@D9G-P871H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R)P<F]P<R)=6UT@/2`D
M=&AI<RT^;6MP<F]P*")G971C;VYT96YT='EP92(L("1T:&ES+3Y?;6EM971Y
M<&4H)&9S<&%T:"DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D9FEL95LB<')O<',B75M=(#T@)'1H:7,M/FUK<')O
M<"@B9V5T8V]N=&5N='1Y<&4B+"`B87!P;&EC871I;VXO>"UN;VXM<F5A9&%B
M;&4B*3L*("`@("`@("`@("`@("`@('T@("`@("`@("`@("`@("`*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`*("`@("`@("`@("`@)'%U97)Y(#T@(E-%
M3$5#5"!N<RP@;F%M92P@=F%L=64@1E)/32!P<F]P97)T:65S(%=(15)%('!A
M=&@@/2`G)'5R:2<B.PH@("`@("`@("`@("`D<F5S(#T@;7ES<6Q?<75E<GDH
M)'%U97)Y*3L*("`@("`@("`@("`@=VAI;&4H)')O=R`](&UY<W%L7V9E=&-H
M7V%S<V]C*"1R97,I*2!["B`@("`@("`@("`@("`@("`D9FEL95LB<')O<',B
M75M=(#T@)'1H:7,M/FUK<')O<"@D<F]W6R)N<R)=+"`D<F]W6R)N86UE(ETL
M("1R;W=;(G9A;'5E(ETI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&UY
M<W%L7V9R965?<F5S=6QT*"1R97,I.PH@("`@("`@("`@("!R971U<FX@)&9I
M;&4["B`@("`@("`@?0H*("`@("`@("`O*B!`0$`@*B\*("`@("`@("!F=6YC
M=&EO;B!?8V%N7V5X96-U=&4H)&YA;64L("1P871H/69A;'-E*2`*("`@("`@
M("!["B`@("`@("`@("`@(&EF("@A<W1R;F-M<"A02%!?3U,L(")724XB+"`S
M*2D@>PH@("`@("`@("`@("`@("`@)&5X=',@/2!A<G)A>2@B+F5X92(L("(N
M8V]M(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M97AT<R`](&%R<F%Y*"(B*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1P871H/3T]9F%L<V4I('L*("`@("`@("`@("`@("`@("1P871H(#T@
M9V5T96YV*")0051((BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O
M<F5A8V@@*&5X<&QO9&4H4$%42%]315!!4D%43U(L("1P871H*2!A<R`D9&ER
M*2!["B`@("`@("`@("`@("`@("!I9B`H(4!I<U]D:7(H)&1I<BDI(&-O;G1I
M;G5E.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5X=',@87,@)&5X="D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("A`:7-?97AE8W5T86)L92@B)&1I
M<B\D;F%M92(N)&5X="DI(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*"B`@("`@("`@9G5N8W1I;VX@
M7VUI;65T>7!E*"1F<W!A=&@I(`H@("`@("`@('L*("`@("`@("`@("`@:68@
M*$!I<U]D:7(H)&9S<&%T:"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`B
M:'1T<&0O=6YI>"UD:7)E8W1O<GDB.R`O+R!43T1/('=H870@;VX@5VEN9&]W
M<S\@.SX*("`@("`@("`@("`@?2!E;'-E(&EF("AF=6YC=&EO;E]E>&ES=',H
M(FUI;65?8V]N=&5N=%]T>7!E(BDI('L*("`@("`@("`@("`@("`@("\O('5S
M92!M:6UE(&UA9VEC(&5X=&5N<VEO;B!I9B!A=F%I;&%B;&4*("`@("`@("`@
M("`@("`@("1M:6UE7W1Y<&4@/2!M:6UE7V-O;G1E;G1?='EP92@D9G-P871H
M*3L*("`@("`@("`@("`@?2!E;'-E(&EF("@D=&AI<RT^7V-A;E]E>&5C=71E
M*")F:6QE(BDI('L*("`@("`@("`@("`@("`@("\O(&ET(&QO;VMS(&QI:V4@
M=V4@:&%V92!A("=F:6QE)R!C;VUM86YD+"`*("`@("`@("`@("`@("`@("\O
M(&QE=',@<V5E(&ET(&ET(&1O97,@:&%V92!M:6UE('-U<'!O<G0*("`@("`@
M("`@("`@("`@("1F<"`]('!O<&5N*")F:6QE("UI("<D9G-P871H)R`R/B]D
M978O;G5L;"(L(")R(BD["B`@("`@("`@("`@("`@("`D<F5P;'D@/2!F9V5T
M<R@D9G`I.PH@("`@("`@("`@("`@("`@<&-L;W-E*"1F<"D["B`@("`@("`@
M("`@("`@("`*("`@("`@("`@("`@("`@("\O('!O<&5N('=I;&P@;F]T(')E
M='5R;B!A;B!E<G)O<B!I9B!T:&4@8FEN87)Y('=A<R!N;W0@9F]U;F0*("`@
M("`@("`@("`@("`@("\O(&%N9"!F:6YD(&UA>2!N;W0@:&%V92!M:6UE('-U
M<'!O<G0@=7-I;F<@(BUI(@H@("`@("`@("`@("`@("`@+R\@<V\@=V4@=&5S
M="!T:&4@9F]R;6%T(&]F('1H92!R971U<FYE9"!S=')I;F<@"B`@("`@("`@
M("`@("`@("`*("`@("`@("`@("`@("`@("\O('1H92!R97!L>2!B96=I;G,@
M=VET:"!T:&4@<F5Q=65S=&5D(&9I;&5N86UE"B`@("`@("`@("`@("`@("!I
M9B`H(7-T<FYC;7`H)')E<&QY+"`B)&9S<&%T:#H@(BP@<W1R;&5N*"1F<W!A
M=&@I*S(I*2![("`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@
M("`@("`@)')E<&QY(#T@<W5B<W1R*"1R97!L>2P@<W1R;&5N*"1F<W!A=&@I
M*S(I.PH@("`@("`@("`@("`@("`@("`@("\O(&9O;&QO=V5D(&)Y('1H92!M
M:6UE('1Y<&4@*&UA>6)E(&EN8VQU9&EN9R!O<'1I;VYS*0H@("`@("`@("`@
M("`@("`@("`@(&EF("AE<F5G*")>6ULZ86QN=6TZ75\M72LO6ULZ86QN=6TZ
M75\M72L[/RXJ(BP@)')E<&QY+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&UI;65?='EP92`]("1M871C:&5S6S!=.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2`*("`@("`@("`@("`@"B`@("`@("`@("`@(&EF("AE;7!T>2@D;6EM95]T
M>7!E*2D@>PH@("`@("`@("`@("`@("`@+R\@1F%L;&)A8VL@<V]L=71I;VXZ
M('1R>2!T;R!G=65S<R!T:&4@='EP92!B>2!T:&4@9FEL92!E>'1E;G-I;VX*
M("`@("`@("`@("`@("`@("\O(%1/1$\Z(&%D9"!M;W)E("XN+@H@("`@("`@
M("`@("`@("`@+R\@5$]$3SH@8V%N('=E('5S92!T:&4@<F5G:7-T<GD@9F]R
M('1H:7,@;VX@5VEN9&]W<S\*("`@("`@("`@("`@("`@("\O("`@("`@($]4
M3T@@:68@=&AE('-E<G9E<B!I<R!7:6YD;W,@=&AE(&-L:65N=',@87)E(&QI
M:V5L>2!T;R`*("`@("`@("`@("`@("`@("\O("`@("`@(&)E(%=I;F1O=W,L
M('1O;RP@86YD('1E;F0@9&\@:6=N;W)E('1H92!#;VYT96YT+51Y<&4*("`@
M("`@("`@("`@("`@("\O("`@("`@(&%N>7=A>2`H;W9E<G)I9&EN9R!I="!W
M:71H(&EN9F]R;6%T:6]N('1A:V5N(&9R;VT*("`@("`@("`@("`@("`@("\O
M("`@("`@('1H92!R96=I<W1R>2D*("`@("`@("`@("`@("`@("\O(%1/1$\Z
M(&AA=F4@82!S97!E<F%T92!014%2(&-L87-S(&9O<B!M:6UE='EP92!D971E
M8W1I;VX_"B`@("`@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H<W1R
M<F-H<BAB87-E;F%M92@D9G-P871H*2P@(BXB*2DI('L*("`@("`@("`@("`@
M("`@(&-A<V4@(BYH=&UL(CH*("`@("`@("`@("`@("`@("`@("`D;6EM95]T
M>7!E(#T@(G1E>'0O:'1M;"(["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!C87-E("(N9VEF(CH*("`@("`@("`@("`@("`@
M("`@("`D;6EM95]T>7!E(#T@(FEM86=E+V=I9B(["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("(N:G!G(CH*("`@
M("`@("`@("`@("`@("`@("`D;6EM95]T>7!E(#T@(FEM86=E+VIP96<B.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@9&5F
M875L=#H@"B`@("`@("`@("`@("`@("`@("`@)&UI;65?='EP92`](")A<'!L
M:6-A=&EO;B]O8W1E="US=')E86TB.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(`H@("`@("`@("`@("!R971U<FX@)&UI;65?='EP93L*("`@("`@("!]
M"@H@("`@("`@(&9U;F-T:6]N($=%5"@F)&]P=&EO;G,I(`H@("`@("`@('L*
M("`@("`@("`@("`@)&9S<&%T:"`]("1T:&ES+3YB87-E("X@)&]P=&EO;G-;
M(G!A=&@B73L*"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9G-P871H
M*2D@>R`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("1O<'1I;VYS6R=M
M:6UE='EP92==(#T@)'1H:7,M/E]M:6UE='EP92@D9G-P871H*3L@"B`@("`@
M("`@("`@("`@("`*("`@("`@("`@("`@("`@("\O('-E92!R9F,R-3$X+"!S
M96-T:6]N(#$S+C<*("`@("`@("`@("`@("`@("\O('-O;64@8VQI96YT<R!S
M965M('1O('1R96%T('1H:7,@87,@82!R979E<G-E(')U;&4*("`@("`@("`@
M("`@("`@("\O(')E<75I97)I;F<@82!,87-T+4UO9&EF:65D(&AE861E<B!I
M9B!T:&4@9V5T;&%S=&UO9&EF:65D(&AE861E<B!W87,@<V5T"B`@("`@("`@
M("`@("`@("`D;W!T:6]N<ULG;71I;64G72`](&9I;&5M=&EM92@D9G-P871H
M*3L*("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@)&]P=&EO;G-;
M)W-I>F4G72`](&9I;&5S:7IE*"1F<W!A=&@I.PH@("`@("`@("`@("`*("`@
M("`@("`@("`@("`@("\O(%1/1$\@8VAE8VL@<&5R;6ES<VEO;G,O<F5S=6QT
M"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULG<W1R96%M)UT@/2!F;W!E;B@D
M9G-P871H+"`B<B(I.PH*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]("`@("`@("`@("`@("`@"B`@("`@("`@?0H*
M("`@("`@("!F=6YC=&EO;B!0550H)B1O<'1I;VYS*2`*("`@("`@("!["B`@
M("`@("`@("`@("1F<W!A=&@@/2`D=&AI<RT^8F%S92`N("1O<'1I;VYS6R)P
M871H(ET["@H@("`@("`@("`@("!I9B@A0&ES7V1I<BAD:7)N86UE*"1F<W!A
M=&@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("(T,#D@0V]N9FQI8W0B
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;W!T:6]N<ULB;F5W(ET@
M/2`A(&9I;&5?97AI<W1S*"1F<W!A=&@I.PH*("`@("`@("`@("`@)&9P(#T@
M9F]P96XH)&9S<&%T:"P@(G<B*3L*"B`@("`@("`@("`@(')E='5R;B`D9G`[
M"B`@("`@("`@?0H*"B`@("`@("`@9G5N8W1I;VX@34M#3TPH)&]P=&EO;G,I
M(`H@("`@("`@('L@("`@("`@("`@(`H@("`@("`@("`@("`D<&%T:"`]("1T
M:&ES+3YB87-E("XD;W!T:6]N<ULB<&%T:")=.PH@("`@("`@("`@("`D<&%R
M96YT(#T@9&ER;F%M92@D<&%T:"D["B`@("`@("`@("`@("1N86UE(#T@8F%S
M96YA;64H)'!A=&@I.PH*("`@("`@("`@("`@:68H(69I;&5?97AI<W1S*"1P
M87)E;G0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@(C0P.2!#;VYF;&EC
M="(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF*"%I<U]D:7(H)'!A
M<F5N="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`B-#`S($9O<F)I9&1E
M;B(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF*"!F:6QE7V5X:7-T
M<R@D<&%R96YT+B(O(BXD;F%M92D@*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@(C0P-2!-971H;V0@;F]T(&%L;&]W960B.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B@A96UP='DH)%]315)615);(D-/3E1%3E1?3$5.1U1(
M(ETI*2![("\O(&YO(&)O9'D@<&%R<VEN9R!Y970*("`@("`@("`@("`@("`@
M(')E='5R;B`B-#$U(%5N<W5P<&]R=&5D(&UE9&EA('1Y<&4B.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(`H@("`@("`@("`@("`D<W1A="`](&UK9&ER
M("@D<&%R96YT+B(O(BXD;F%M92PP-S<W*3L*("`@("`@("`@("`@:68H(21S
M=&%T*2!["B`@("`@("`@("`@("`@("!R971U<FX@(C0P,R!&;W)B:61D96XB
M.R`@("`@("`@("`@("`@("`@"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(')E='5R;B`H(C(P,2!#<F5A=&5D(BD["B`@("`@("`@?0H@("`@("`@(`H@
M("`@("`@(`H@("`@("`@(&9U;F-T:6]N(&1E;&5T92@D;W!T:6]N<RD@"B`@
M("`@("`@>PH@("`@("`@("`@("`D<&%T:"`]("1T:&ES+3YB87-E("X@(B\B
M("XD;W!T:6]N<ULB<&%T:")=.PH*("`@("`@("`@("`@:68H(69I;&5?97AI
M<W1S*"1P871H*2D@<F5T=7)N("(T,#0@3F]T(&9O=6YD(CL*"B`@("`@("`@
M("`@(&EF("AI<U]D:7(H)'!A=&@I*2!["B`@("`@("`@("`@("`@("`D<75E
M<GD@/2`B1$5,151%($923TT@<')O<&5R=&EE<R!72$5212!P871H($Q)2T4@
M)R1O<'1I;VYS6W!A=&A=)2<B.PH@("`@("`@("`@("`@("`@;7ES<6Q?<75E
M<GDH)'%U97)Y*3L*("`@("`@("`@("`@("`@('-Y<W1E;2@B<FT@+7)F("1P
M871H(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!U
M;FQI;FL@*"1P871H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<75E
M<GD@/2`B1$5,151%($923TT@<')O<&5R=&EE<R!72$5212!P871H(#T@)R1O
M<'1I;VYS6W!A=&A=)R(["B`@("`@("`@("`@(&UY<W%L7W%U97)Y*"1Q=65R
M>2D["@H@("`@("`@("`@("!R971U<FX@(C(P-"!.;R!#;VYT96YT(CL*("`@
M("`@("!]"@H*("`@("`@("!F=6YC=&EO;B!M;W9E*"1O<'1I;VYS*2`*("`@
M("`@("!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8V]P>2@D;W!T:6]N
M<RP@=')U92D["B`@("`@("`@?0H*("`@("`@("!F=6YC=&EO;B!C;W!Y*"1O
M<'1I;VYS+"`D9&5L/69A;'-E*2`*("`@("`@("!["B`@("`@("`@("`@("\O
M(%1/1$\@4')O<&5R='D@=7!D871E<R!S=&EL;"!B<F]K96X@*$QI=&UU<R!S
M:&]U;&0@9&5T96-T('1H:7,_*0H*("`@("`@("`@("`@:68H(65M<'1Y*"1?
M4T525D526R)#3TY414Y47TQ%3D=42")=*2D@>R`O+R!N;R!B;V1Y('!A<G-I
M;F<@>65T"B`@("`@("`@("`@("`@("!R971U<FX@(C0Q-2!5;G-U<'!O<G1E
M9"!M961I82!T>7!E(CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@
M;F\@8V]P>6EN9R!T;R!D:69F97)E;G0@5V5B1$%6(%-E<G9E<G,@>65T"B`@
M("`@("`@("`@(&EF*&ES<V5T*"1O<'1I;VYS6R)D97-T7W5R;")=*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("(U,#(@8F%D(&=A=&5W87DB.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<V]U<F-E(#T@)'1H:7,M/F)A<V4@
M+B1O<'1I;VYS6R)P871H(ET["B`@("`@("`@("`@(&EF*"%F:6QE7V5X:7-T
M<R@D<V]U<F-E*2D@<F5T=7)N("(T,#0@3F]T(&9O=6YD(CL*"B`@("`@("`@
M("`@("1D97-T(#T@)'1H:7,M/F)A<V4@+B`D;W!T:6]N<ULB9&5S=")=.PH*
M("`@("`@("`@("`@)&YE=R`]("%F:6QE7V5X:7-T<R@D9&5S="D["B`@("`@
M("`@("`@("1E>&ES=&EN9U]C;VP@/2!F86QS93L*"B`@("`@("`@("`@(&EF
M*"$D;F5W*2!["B`@("`@("`@("`@("`@("!I9B@D9&5L("8F(&ES7V1I<B@D
M9&5S="DI('L*("`@("`@("`@("`@("`@("`@("!I9B@A)&]P=&EO;G-;(F]V
M97)W<FET92)=*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`B
M-#$R('!R96-O;F1I=&EO;B!F86EL960B.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`D9&5S="`N/2!B87-E;F%M92@D<V]U
M<F-E*3L*("`@("`@("`@("`@("`@("`@("!I9BAF:6QE7V5X:7-T<R@D9&5S
M="YB87-E;F%M92@D<V]U<F-E*2DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;G-;(F1E<W0B72`N/2!B87-E;F%M92@D<V]U<F-E*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;F5W(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M:7-T:6YG7V-O;"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B@A
M)&YE=RD@>PH@("`@("`@("`@("`@("`@:68H)&]P=&EO;G-;(F]V97)W<FET
M92)=*2!["B`@("`@("`@("`@("`@("`@("`@)'-T870@/2`D=&AI<RT^9&5L
M971E*&%R<F%Y*")P871H(B`]/B`D;W!T:6]N<ULB9&5S=")=*2D["B`@("`@
M("`@("`@("`@("`@("`@:68H)'-T871[,'T@(3T@(C(B*2!R971U<FX@)'-T
M870[(`H@("`@("`@("`@("`@("`@?2!E;'-E('L@("`@("`@("`@("`@("`@
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("(T,3(@<')E8V]N9&ET:6]N
M(&9A:6QE9"(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("AI<U]D:7(H)'-O=7)C92DI('L*("`@("`@("`@("`@
M("`@("\O(%)&0R`R-3$X(%-E8W1I;VX@.2XR+"!L87-T('!A<F%G<F%P:`H@
M("`@("`@("`@("`@("`@:68@*"1O<'1I;VYS6R)D97!T:")=("$](")I;F9I
M;FET>2(I('L*("`@("`@("`@("`@("`@("`@("!E<G)O<E]L;V<H(BTM+2T@
M(BXD;W!T:6]N<ULB9&5P=&@B72D["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("(T,#`@0F%D(')E<75E<W0B.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@('-Y<W1E;2@B8W`@+5(@)'-O=7)C92`D9&5S="(I.PH*
M("`@("`@("`@("`@("`@(&EF*"1D96PI('L*("`@("`@("`@("`@("`@("`@
M("!S>7-T96TH(G)M("UR9B`D<V]U<F-E(BD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92![("`@("`@("`@("`@("`@(`H@("`@("`@
M("`@("`@("`@:68H)&1E;"D@>PH@("`@("`@("`@("`@("`@("`@($!U;FQI
M;FLH)&1E<W0I.PH@("`@("`@("`@("`@("`@("`@("1Q=65R>2`](")$14Q%
M5$4@1E)/32!P<F]P97)T:65S(%=(15)%('!A=&@@/2`G)&]P=&EO;G-;9&5S
M=%TG(CL*("`@("`@("`@("`@("`@("`@("!M>7-Q;%]Q=65R>2@D<75E<GDI
M.PH@("`@("`@("`@("`@("`@("`@(')E;F%M92@D<V]U<F-E+"`D9&5S="D[
M"B`@("`@("`@("`@("`@("`@("`@)'%U97)Y(#T@(E501$%412!P<F]P97)T
M:65S(%-%5"!P871H(#T@)R1O<'1I;VYS6V1E<W1=)R!72$5212!P871H(#T@
M)R1O<'1I;VYS6W!A=&A=)R(["B`@("`@("`@("`@("`@("`@("`@;7ES<6Q?
M<75E<GDH)'%U97)Y*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@:68H<W5B<W1R*"1D97-T+"TQ*3T](B\B*2`D9&5S
M="`]('-U8G-T<B@D9&5S="PP+"TQ*3L*("`@("`@("`@("`@("`@("`@("!C
M;W!Y*"1S;W5R8V4L("1D97-T*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("@D;F5W("8F("$D97AI<W1I
M;F=?8V]L*2`_("(R,#$@0W)E871E9"(@.B`B,C`T($YO($-O;G1E;G0B.R`@
M("`@("`@(`H@("`@("`@('T*"B`@("`@("`@9G5N8W1I;VX@<')O<'!A=&-H
M*"8D;W!T:6]N<RD@"B`@("`@("`@>PH@("`@("`@("`@("!G;&]B86P@)'!R
M969S+"`D=&%B.PH*("`@("`@("`@("`@)&US9R`]("(B.PH@("`@("`@("`@
M("`*("`@("`@("`@("`@)'!A=&@@/2`D;W!T:6]N<ULB<&%T:")=.PH@("`@
M("`@("`@("`*("`@("`@("`@("`@)&1I<B`](&1I<FYA;64H)'!A=&@I+B(O
M(CL*("`@("`@("`@("`@)&)A<V4@/2!B87-E;F%M92@D<&%T:"D["B`@("`@
M("`@("`@(`H@("`@("`@("`@("!F;W)E86-H*"1O<'1I;VYS6R)P<F]P<R)=
M(&%S("1K97D@/3X@)'!R;W`I('L*("`@("`@("`@("`@("`@(&EF*"1N<R`]
M/2`B1$%6.B(I('L*("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<ULB<')O
M<',B75LD:V5Y75LD<W1A='5S72`]("(T,#,@1F]R8FED9&5N(CL*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68H:7-S
M970H)'!R;W!;(G9A;")=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<75E<GD@/2`B4D503$%#12!)3E1/('!R;W!E<G1I97,@4T54('!A=&@@/2`G
M)&]P=&EO;G-;<&%T:%TG+"!N86UE(#T@)R1P<F]P6VYA;65=)RP@;G,]("<D
M<')O<%MN<UTG+"!V86QU92`]("<D<')O<%MV86Q=)R(["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'%U
M97)Y(#T@(D1%3$5412!&4D]-('!R;W!E<G1I97,@5TA%4D4@<&%T:"`]("<D
M;W!T:6]N<UMP871H72<@04Y$(&YA;64@/2`G)'!R;W!;;F%M95TG($%.1"!N
M<R`]("<D<')O<%MN<UTG(CL*("`@("`@("`@("`@("`@("`@("!]("`@("`@
M(`H@("`@("`@("`@("`@("`@("`@(&UY<W%L7W%U97)Y*"1Q=65R>2D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@"B`@("`@("`@("`@(')E='5R;B`B(CL*("`@("`@("!]"@H*
M("`@("`@("!F=6YC=&EO;B!L;V-K*"8D;W!T:6]N<RD@"B`@("`@("`@>PH@
M("`@("`@("`@("!I9BAI<W-E="@D;W!T:6]N<ULB=7!D871E(ETI*2![("\O
M($QO8VL@57!D871E"B`@("`@("`@("`@("`@("`D<75E<GD@/2`B55!$051%
M(&QO8VMS(%-%5"!E>'!I<F5S(#T@(BXH=&EM92@I*S,P,"D["B`@("`@("`@
M("`@("`@("!M>7-Q;%]Q=65R>2@D<75E<GDI.PH@("`@("`@("`@("`@("`@
M"B`@("`@("`@("`@("`@("!I9BAM>7-Q;%]A9F9E8W1E9%]R;W=S*"DI('L*
M("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<ULB=&EM96]U=")=(#T@,S`P
M.R`O+R`U;6EN(&AA<F1C;V1E9`H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@"B`@("`@("`@("`@("1O<'1I;VYS6R)T
M:6UE;W5T(ET@/2!T:6UE*"DK,S`P.R`O+R`U;6EN+B!H87)D8V]D960*"B`@
M("`@("`@("`@("1Q=65R>2`]("))3E-%4E0@24Y43R!L;V-K<PH@("`@("`@
M("`@("`@("`@("`@("`@("!3150@=&]K96X@("`]("<D;W!T:6]N<UML;V-K
M=&]K96Y=)PH@("`@("`@("`@("`@("`@("`@("`@("`@("P@<&%T:"`@("`]
M("<D;W!T:6]N<UMP871H72<*("`@("`@("`@("`@("`@("`@("`@("`@("`L
M(&]W;F5R("`@/2`G)&]P=&EO;G-;;W=N97)=)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("P@97AP:7)E<R`]("<D;W!T:6]N<UMT:6UE;W5T72<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`L(&5X8VQU<VEV96QO8VL@(#T@(B`N
M*"1O<'1I;VYS6R=S8V]P92==(#T]/2`B97AC;'5S:79E(B`_("(Q(B`Z("(P
M(BD*("`@("`@("`@("`@("`@(#L*("`@("`@("`@("`@;7ES<6Q?<75E<GDH
M)'%U97)Y*3L*("`@("`@("`@("`@<F5T=7)N(&UY<W%L7V%F9F5C=&5D7W)O
M=W,H*2`^(#`["@H@("`@("`@("`@("!R971U<FX@(C(P,"!/2R(["B`@("`@
M("`@?0H*("`@("`@("!F=6YC=&EO;B!U;FQO8VLH)B1O<'1I;VYS*2`*("`@
M("`@("!["B`@("`@("`@("`@("1Q=65R>2`](")$14Q%5$4@1E)/32!L;V-K
M<PH@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@<&%T:"`]("<D;W!T:6]N
M<UMP871H72<*("`@("`@("`@("`@("`@("`@("`@("`@04Y$('1O:V5N(#T@
M)R1O<'1I;VYS6W1O:V5N72<B.PH@("`@("`@("`@("!M>7-Q;%]Q=65R>2@D
M<75E<GDI.PH*("`@("`@("`@("`@<F5T=7)N(&UY<W%L7V%F9F5C=&5D7W)O
M=W,H*2`_("(R,#`@3TLB(#H@(C0P.2!#;VYF;&EC="(["B`@("`@("`@?0H*
M("`@("`@("!F=6YC=&EO;B!C:&5C:VQO8VLH)'!A=&@I(`H@("`@("`@('L*
M("`@("`@("`@("`@)')E<W5L="`](&9A;'-E.PH@("`@("`@("`@("`*("`@
M("`@("`@("`@)'%U97)Y(#T@(E-%3$5#5"!O=VYE<BP@=&]K96XL(&5X<&ER
M97,L(&5X8VQU<VEV96QO8VL*("`@("`@("`@("`@("`@("`@1E)/32!L;V-K
M<PH@("`@("`@("`@("`@("`@(%=(15)%('!A=&@@/2`G)'!A=&@G"B`@("`@
M("`@("`@("`@("(["B`@("`@("`@("`@("1R97,@/2!M>7-Q;%]Q=65R>2@D
M<75E<GDI.PH*("`@("`@("`@("`@:68H)')E<RD@>PH@("`@("`@("`@("`@
M("`@)')O=R`](&UY<W%L7V9E=&-H7V%R<F%Y*"1R97,I.PH@("`@("`@("`@
M("`@("`@;7ES<6Q?9G)E95]R97-U;'0H)')E<RD["@H@("`@("`@("`@("`@
M("`@:68H)')O=RD@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2!A
M<G)A>2@@(G1Y<&4B("`@(#T^(")W<FET92(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(G-C;W!E(B`@
M(#T^("1R;W=;(F5X8VQU<VEV96QO8VLB72`_(")E>&-L=7-I=F4B(#H@(G-H
M87)E9"(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(F1E<'1H(B`@(#T^(#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(F]W;F5R
M(B`@(#T^("1R;W=;)V]W;F5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(G1O:V5N(B`@(#T^("1R
M;W=;)W1O:V5N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(F5X<&ER97,B(#T^("1R;W=;)V5X<&ER
M97,G70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"@H@
M("`@("`@(&9U;F-T:6]N(&-R96%T95]D871A8F%S92@I(`H@("`@("`@('L*
M("`@("`@("`@("`@+R\@5$]$3PH@("`@("`@('T*("`@('T*"@H_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TA45%`O5V5B1$%6+U-E<G9E<BYP:'``````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,30T-3`R`#$P-#$W,S8S,#`W`#`R,3$U
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!0
M2%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!!=71H;W)S.B!(87)T;75T($AO;'IG<F%E9F4@/&AH;VQZ
M9W)A0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@
M("`@("`@0VAR:7-T:6%N(%-T;V-K97(@/&-H<F5G=4!B:71F;'5X+F-H/B`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!397)V97(N<&AP+'8@,2XQ,R`R,#`S+S$Q
M+S$X(#(Q.C`Y.C,U(&AH;VQZ9W)A($5X<"`D"B\O"B\O(%=E8D1!5B!S97)V
M97(@8F%S92!C;&%S<RP@;F5E9',@=&\@8F4@97AT96YD960@=&\@9&\@=7-E
M9G5L('=O<FL*+R\*+R\@<F5Q=6ER95]O;F-E(")(5%10+TA45%`N<&AP(CL*
M<F5Q=6ER95]O;F-E(")(5%10+U=E8D1!5B]4;V]L<R]?<&%R<V5?<')O<&9I
M;F0N<&AP(CL*<F5Q=6ER95]O;F-E(")(5%10+U=E8D1!5B]4;V]L<R]?<&%R
M<V5?<')O<'!A=&-H+G!H<"(["G)E<75I<F5?;VYC92`B2%144"]796)$058O
M5&]O;',O7W!A<G-E7VQO8VMI;F9O+G!H<"(["@H*"B`@+RHJ"B`@("H@5FER
M='5A;"!B87-E(&-L87-S(&9O<B!I;7!L96UE;G1I;F<@5V5B1$%6('-E<G9E
M<G,@"B`@("H*("`@*B!T:&ES(&ES(&ET"B`@("H@8FQA(&)L80H@("`J(`H@
M("`J($!P86-K86=E($A45%!?5V5B1$%67U-E<G9E<@H@("`J($!A=71H;W(@
M2&%R=&UU="!(;VQZ9W)A969E(#QH:&]L>F=R84!P:'`N;F5T/@H@("`J($!V
M97)S:6]N(#`N.35D978*("`@*B\*8VQA<W,@2%144%]796)$059?4V5R=F5R
M('L*("`@("\O('M[>R!-96UB97(@5F%R:6%B;&5S(`H@("`@"B`@("`@("`@
M("`@("`@("`O*BH*("`@("`@("`@*B!54DD@<&%T:"!F;W(@=&AI<R!R97%U
M97-T"B`@("`@("`@("H*("`@("`@("`@*B!`=F%R('-T<FEN9R`*("`@("`@
M("`@*B\*("`@('9A<B`D<&%T:#L*"B`@("`@("`@("`@("`@("`O*BH*("`@
M("`@("`@*B!296%L;2!S=')I;F<@=&\@8F4@=7-E9"!I;B!A=71H96YT:69I
M8V%T:6]N('!O<'5P<PH@("`@("`@("`J"B`@("`@("`@("H@0'9A<B!S=')I
M;F<@"B`@("`@("`@("HO"B`@("!V87(@)&AT='!?875T:%]R96%L;2`](")0
M2%`@5V5B1$%6(CL*"B`@("`@("`@("`@("`@("`O*BH*("`@("`@("`@*B!2
M96UE;6)E<B!P87)S960@268Z("A21D,R-3$X+SDN-"D@:&5A9&5R(&-O;F1I
M=&EO;G,@(`H@("`@("`@("`J"B`@("`@("`@("H@0'9A<B!A<G)A>0H@("`@
M("`@("`J+PH@("`@=F%R("1?:69?:&5A9&5R7W5R:7,@/2!A<G)A>2@I.PH*
M"B`@("!V87(@)%]H='1P7W-T871U<R`]("(R,#`@3TLB.PH*("`@('9A<B`D
M7W!R;W!?96YC;V1I;F<@/2`B=71F+3@B.PH@("`@+R\@?7U]"@H@("`@+R\@
M>WM[($-O;G-T<G5C=&]R(`H*("`@("`@("`@("`@("`@("\J*B`*("`@("`@
M("`@*B!#;VYS=')U8W1O<@H@("`@("`@("`J"B`@("`@("`@("H@0'!A<F%M
M('9O:60*("`@("`@("`@*B\*("`@(&9U;F-T:6]N($A45%!?5V5B1$%67U-E
M<G9E<B@I('L*("`@("`@("`O+R!02%`@;65S<V%G97,@9&5S=')O>2!834P@
M;W5T<'5T("T^('-W:71C:"!T:&5M(&]F9@H@("`@("`@(&EN:5]S970H(F1I
M<W!L87E?97)R;W)S(BP@,"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@4V5R=F5297%U97-T*"D@"B\J*B`*("`@("`@("`@*B!397)V92!796)$
M058@2%144"!R97%U97-T"B`@("`@("`@("H*("`@("`@("`@*B!D:7-P871C
M:"!796)$058@2%144"!R97%U97-T('1O('1H92!A<')O<')I871E(&UE=&AO
M9"!H86YD;&5R"B`@("`@("`@("H@"B`@("`@("`@("H@0'!A<F%M('9O:60*
M("`@("`@("`@*B!`<F5T=7)N('9O:60*("`@("`@("`@*B\*("`@(&9U;F-T
M:6]N(%-E<G9E4F5Q=65S="@I('L*("`@("`@("`@("`@+R\@:61E;G1I9GD@
M;W5R<V5L=F5S"B`@("`@("`@("`@(&AE861E<B@B6"U$878M4&]W97)E9"U"
M>3H@4$A0(&-L87-S.B`B+F=E=%]C;&%S<R@D=&AI<RDI.PH*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^7V-H96-K7V%U=&@H*2D@>PH@("`@("`@("`@("`@
M("`@+R\@4D9#,C4Q."!S87ES('=E(&UU<W0@=7-E($1I9V5S="!I;G-T96%D
M(&]F($)A<VEC"B`@("`@("`@("`@("`@("`O+R!B=70@36EC<F]S;V9T($-L
M:65N=',@9&\@;F]T('-U<'!O<G0@1&EG97-T"B`@("`@("`@("`@("`@("`O
M+R!A;F0@=V4@9&]N)W0@<W5P<&]R="!.5$Q-(&%N9"!-)"U+97)B97)O<PH@
M("`@("`@("`@("`@("`@+R\@<V\@=V4@87)E('-T=6-K('=I=&@@0F%S:6,@
M:&5R90H@("`@("`@("`@("`@("`@:&5A9&5R*"=75U<M075T:&5N=&EC871E
M.B!"87-I8R!R96%L;3TB)RXH)'1H:7,M/FAT='!?875T:%]R96%L;2DN)R(G
M*3L*("`@("`@("`@("`@("`@(&AE861E<B@G2%144"\Q+C`@-#`Q(%5N875T
M:&]R:7IE9"<I.PH*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF*"$@)'1H:7,M/E]C:&5C:U]I9E]H96%D97)?
M8V]N9&ET:6]N<R@I*2!["B`@("`@("`@("`@("`@("!H96%D97(H(DA45%`O
M,2XP(#0Q,B!0<F5C;VYD:71I;VX@9F%I;&5D(BD["B`@("`@("`@("`@("`@
M("!E>&ET.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!S970@<&%T
M:`H@("`@("`@("`@("`D=&AI<RT^<&%T:"`]"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W5R;&1E8V]D92@A96UP='DH)%]315)615);(E!!5$A?24Y&3R)=
M*2`_("1?4T525D526R)0051(7TE.1D\B72`Z("(O(BD["B`@("`@("`@("`@
M(&EF*&EN:5]G970H(FUA9VEC7W%U;W1E<U]G<&,B*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G!A=&@@/2!S=')I<'-L87-H97,H)'1H:7,M/G!A=&@I
M.PH@("`@("`@("`@("!]"@H*("`@("`@("`@("`@+R\@9&5T96-T(')E<75E
M<W1E9"!M971H;V0@;F%M97,*("`@("`@("`@("`@)&UE=&AO9"`]('-T<G1O
M;&]W97(H)%]315)615);(E)%455%4U1?34542$]$(ETI.PH@("`@("`@("`@
M("`D=W)A<'!E<B`](")H='1P7R(N)&UE=&AO9#L*"B`@("`@("`@("`@("\O
M(&%C=&EV871E($A%040@96UU;&%T:6]N(&)Y($=%5"!I9B!N;R!(14%$(&UE
M=&AO9"!F;W5N9`H@("`@("`@("`@("!I9B`H)&UE=&AO9"`]/2`B:&5A9"(@
M)B8@(6UE=&AO9%]E>&ES=',H)'1H:7,L(")H96%D(BDI('L*("`@("`@("`@
M("`@("`@("1M971H;V0@/2`B9V5T(CL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,L("1W<F%P<&5R*2`F)@H@
M("`@("`@("`@("`@("`@("`@("@D;65T:&]D(#T](")O<'1I;VYS(B!\?"!M
M971H;V1?97AI<W1S*"1T:&ES+"`D;65T:&]D*2DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3XD=W)A<'!E<B@I.R`@+R\@8V%L;"!M971H;V0@8GD@;F%M
M90H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"1?
M4T525D526R)215%515-47TU%5$A/1")=(#T]("),3T-+(BD@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YH='1P7W-T871U<R@B-#$R(%!R96-O;F1I
M=&EO;B!F86EL960B*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FAT='!?<W1A='5S*"(T,#4@365T:&]D
M(&YO="!A;&QO=V5D(BD["B`@("`@("`@("`@("`@("`@("`@:&5A9&5R*")!
M;&QO=SH@(BYJ;VEN*"(L("(L("1T:&ES+3Y?86QL;W<H*2DI.R`@+R\@=&5L
M;"!C;&EE;G0@=VAA="=S(&%L;&]W960*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@('T*"B`@("`O+R!]?7T*"B`@("`O+R![>WL@86)S
M=')A8W0@5V5B1$%6(&UE=&AO9',@"@H@("`@+R\@>WM[($=%5"@I(`H@("`@
M("`@("`@("`@("`@("\J*@H@("`@("`@("`J($=%5"!I;7!L96UE;G1A=&EO
M;@H@("`@("`@("`J"B`@("`@("`@("H@;W9E<FQO860@=&AI<R!M971H;V0@
M=&\@<F5T<FEE=F4@<F5S;W5R8V5S(&9R;VT@>6]U<B!S97)V97(*("`@("`@
M("`@*B`\8G(^"B`@("`@("`@("H@"B`@("`@("`@("H*("`@("`@("`@*B!`
M86)S=')A8W0@"B`@("`@("`@("H@0'!A<F%M(&%R<F%Y("8D<&%R86US($%R
M<F%Y(&]F(&EN<'5T(&%N9"!O=71P=70@<&%R86UE=&5R<PH@("`@("`@("`J
M(#QB<CX\8CYI;G!U=#PO8CX\=6P^"B`@("`@("`@("H@/&QI/B!P871H("T@
M"B`@("`@("`@("H@/"]U;#X*("`@("`@("`@*B`\8G(^/&(^;W5T<'5T/"]B
M/CQU;#X*("`@("`@("`@*B`\;&D^('-I>F4@+2`*("`@("`@("`@*B`\+W5L
M/@H@("`@("`@("`J($!R971U<FYS(&EN="!(5%10+5-T871U<V-O9&4*("`@
M("`@("`@*B\*"B`@("`O*B!A8G-T<F%C=`H@("`@("`@9G5N8W1I;VX@1T54
M*"8D<&%R86US*2!["B`@("`@("`O+R!D=6UM>2!E;G1R>2!F;W(@4$A01&]C
M"B`@("`@("!](`H@("`@("HO"@H@("`@+R\@?7U]"@H@("`@+R\@>WM[(%!5
M5"@I(`H@("`@("`@("`@("`@("`@+RHJ"B`@("`@("`@("H@4%54(&EM<&QE
M;65N=&%T:6]N"B`@("`@("`@("H*("`@("`@("`@*B!0550@:6UP;&5M96YT
M871I;VX*("`@("`@("`@*@H@("`@("`@("`J($!A8G-T<F%C="`*("`@("`@
M("`@*B!`<&%R86T@87)R87D@)B1P87)A;7,*("`@("`@("`@*B!`<F5T=7)N
M<R!I;G0@2%144"U3=&%T=7-C;V1E"B`@("`@("`@("HO"@H@("`@+RH@86)S
M=')A8W0*("`@("`@(&9U;F-T:6]N(%!55"@I('L*("`@("`@("\O(&1U;6UY
M(&5N=')Y(&9O<B!02%!$;V,*("`@("`@('T@"B`@("`@*B\*"B`@("`O+R!]
M?7T*"B`@("`O+R![>WL@0T]062@I(`H*("`@("`@("`@("`@("`@("\J*@H@
M("`@("`@("`J($-/4%D@:6UP;&5M96YT871I;VX*("`@("`@("`@*@H@("`@
M("`@("`J($-/4%D@:6UP;&5M96YT871I;VX*("`@("`@("`@*@H@("`@("`@
M("`J($!A8G-T<F%C="`*("`@("`@("`@*B!`<&%R86T@87)R87D@)B1P87)A
M;7,*("`@("`@("`@*B!`<F5T=7)N<R!I;G0@2%144"U3=&%T=7-C;V1E"B`@
M("`@("`@("HO"@H@("`@+RH@86)S=')A8W0*("`@("`@(&9U;F-T:6]N($-/
M4%DH*2!["B`@("`@("`O+R!D=6UM>2!E;G1R>2!F;W(@4$A01&]C"B`@("`@
M("!](`H@("`@("HO"@H@("`@+R\@?7U]"@H@("`@+R\@>WM[($U/5D4H*2`*
M"B`@("`@("`@("`@("`@("`O*BH*("`@("`@("`@*B!-3U9%(&EM<&QE;65N
M=&%T:6]N"B`@("`@("`@("H*("`@("`@("`@*B!-3U9%(&EM<&QE;65N=&%T
M:6]N"B`@("`@("`@("H*("`@("`@("`@*B!`86)S=')A8W0@"B`@("`@("`@
M("H@0'!A<F%M(&%R<F%Y("8D<&%R86US"B`@("`@("`@("H@0')E='5R;G,@
M:6YT($A45%`M4W1A='5S8V]D90H@("`@("`@("`J+PH*("`@("\J(&%B<W1R
M86-T"B`@("`@("!F=6YC=&EO;B!-3U9%*"D@>PH@("`@("`@+R\@9'5M;7D@
M96YT<GD@9F]R(%!(4$1O8PH@("`@("`@?2`*("`@("`J+PH*("`@("\O('U]
M?0H*("`@("\O('M[>R!$14Q%5$4H*2`*"B`@("`@("`@("`@("`@("`O*BH*
M("`@("`@("`@*B!$14Q%5$4@:6UP;&5M96YT871I;VX*("`@("`@("`@*@H@
M("`@("`@("`J($1%3$5412!I;7!L96UE;G1A=&EO;@H@("`@("`@("`J"B`@
M("`@("`@("H@0&%B<W1R86-T(`H@("`@("`@("`J($!P87)A;2!A<G)A>2`F
M)'!A<F%M<PH@("`@("`@("`J($!R971U<FYS(&EN="!(5%10+5-T871U<V-O
M9&4*("`@("`@("`@*B\*"B`@("`O*B!A8G-T<F%C=`H@("`@("`@9G5N8W1I
M;VX@1$5,151%*"D@>PH@("`@("`@+R\@9'5M;7D@96YT<GD@9F]R(%!(4$1O
M8PH@("`@("`@?2`*("`@("`J+PH@("`@+R\@?7U]"@H@("`@+R\@>WM[(%!2
M3U!&24Y$*"D@"@H@("`@("`@("`@("`@("`@+RHJ"B`@("`@("`@("H@4%)/
M4$9)3D0@:6UP;&5M96YT871I;VX*("`@("`@("`@*@H@("`@("`@("`J(%!2
M3U!&24Y$(&EM<&QE;65N=&%T:6]N"B`@("`@("`@("H*("`@("`@("`@*B!`
M86)S=')A8W0@"B`@("`@("`@("H@0'!A<F%M(&%R<F%Y("8D<&%R86US"B`@
M("`@("`@("H@0')E='5R;G,@:6YT($A45%`M4W1A='5S8V]D90H@("`@("`@
M("`J+PH*("`@("\J(&%B<W1R86-T"B`@("`@("!F=6YC=&EO;B!04D]01DE.
M1"@I('L*("`@("`@("\O(&1U;6UY(&5N=')Y(&9O<B!02%!$;V,*("`@("`@
M('T@"B`@("`@*B\*"B`@("`O+R!]?7T*"B`@("`O+R![>WL@4%)/4%!!5$-(
M*"D@"@H@("`@("`@("`@("`@("`@+RHJ"B`@("`@("`@("H@4%)/4%!!5$-(
M(&EM<&QE;65N=&%T:6]N"B`@("`@("`@("H*("`@("`@("`@*B!04D]04$%4
M0T@@:6UP;&5M96YT871I;VX*("`@("`@("`@*@H@("`@("`@("`J($!A8G-T
M<F%C="`*("`@("`@("`@*B!`<&%R86T@87)R87D@)B1P87)A;7,*("`@("`@
M("`@*B!`<F5T=7)N<R!I;G0@2%144"U3=&%T=7-C;V1E"B`@("`@("`@("HO
M"@H@("`@+RH@86)S=')A8W0*("`@("`@(&9U;F-T:6]N(%!23U!0051#2"@I
M('L*("`@("`@("\O(&1U;6UY(&5N=')Y(&9O<B!02%!$;V,*("`@("`@('T@
M"B`@("`@*B\*("`@("\O('U]?0H*("`@("\O('M[>R!,3T-+*"D@"@H@("`@
M("`@("`@("`@("`@+RHJ"B`@("`@("`@("H@3$]#2R!I;7!L96UE;G1A=&EO
M;@H@("`@("`@("`J"B`@("`@("`@("H@3$]#2R!I;7!L96UE;G1A=&EO;@H@
M("`@("`@("`J"B`@("`@("`@("H@0&%B<W1R86-T(`H@("`@("`@("`J($!P
M87)A;2!A<G)A>2`F)'!A<F%M<PH@("`@("`@("`J($!R971U<FYS(&EN="!(
M5%10+5-T871U<V-O9&4*("`@("`@("`@*B\*"B`@("`O*B!A8G-T<F%C=`H@
M("`@("`@9G5N8W1I;VX@3$]#2R@I('L*("`@("`@("\O(&1U;6UY(&5N=')Y
M(&9O<B!02%!$;V,*("`@("`@('T@"B`@("`@*B\*("`@("\O('U]?0H*("`@
M("\O('M[>R!53DQ/0TLH*2`*"B`@("`@("`@("`@("`@("`O*BH*("`@("`@
M("`@*B!53DQ/0TL@:6UP;&5M96YT871I;VX*("`@("`@("`@*@H@("`@("`@
M("`J(%5.3$]#2R!I;7!L96UE;G1A=&EO;@H@("`@("`@("`J"B`@("`@("`@
M("H@0&%B<W1R86-T(`H@("`@("`@("`J($!P87)A;2!A<G)A>2`F)'!A<F%M
M<PH@("`@("`@("`J($!R971U<FYS(&EN="!(5%10+5-T871U<V-O9&4*("`@
M("`@("`@*B\*"B`@("`O*B!A8G-T<F%C=`H@("`@("`@9G5N8W1I;VX@54Y,
M3T-+*"D@>PH@("`@("`@+R\@9'5M;7D@96YT<GD@9F]R(%!(4$1O8PH@("`@
M("`@?2`*("`@("`J+PH@("`@+R\@?7U]"@H@("`@+R\@?7U]"@H@("`@+R\@
M>WM[(&]T:&5R(&%B<W1R86-T(&UE=&AO9',@"@H@("`@+R\@>WM[(&-H96-K
M7V%U=&@H*2`*"B`@("`@("`@("`@("`@("`@+RHJ"B`@("`@("`@("H@8VAE
M8VL@875T:&5N=&EC871I;VX*("`@("`@("`@*@H@("`@("`@("`J(&]V97)L
M;V%D('1H:7,@;65T:&]D('1O(')E=')I979E(&%N9"!C;VYF:7)M(&%U=&AE
M;G1I8V%T:6]N(&EN9F]R;6%T:6]N"B`@("`@("`@("H*("`@("`@("`@*B!`
M86)S=')A8W0@"B`@("`@("`@("H@0'!A<F%M('-T<FEN9R!T>7!E($%U=&AE
M;G1I8V%T:6]N('1Y<&4L(&4N9RX@(F)A<VEC(B!O<B`B9&EG97-T(@H@("`@
M("`@("`J($!P87)A;2!S=')I;F<@=7-E<FYA;64@5')A;G-M:71T960@=7-E
M<FYA;64*("`@("`@("`@*B!`<&%R86T@<W1R:6YG('!A<W-W;W)T(%1R86YS
M;6ET=&5D('!A<W-W;W)D"B`@("`@("`@("H@0')E='5R;G,@8F]O;"!!=71H
M96YT:6-A=&EO;B!S=&%T=7,*("`@("`@("`@*B\*"B`@("`O*B!A8G-T<F%C
M=`H@("`@("`@9G5N8W1I;VX@8VAE8VM?875T:"@D='EP92P@)'5S97)N86UE
M+"`D<&%S<W=O<F0I('L*("`@("`@("\O(&1U;6UY(&5N=')Y(&9O<B!02%!$
M;V,*("`@("`@('T@"B`@("`@*B\*"B`@("`O+R!]?7T*"B`@("`O+R![>WL@
M8VAE8VML;V-K*"D@"@H@("`@("`@("`@("`@("`@("\J*@H@("`@("`@("`J
M(&-H96-K(&QO8VL@<W1A='5S(&9O<B!A(')E<V]U<F-E"B`@("`@("`@("H*
M("`@("`@("`@*B!O=F5R;&]A9"!T:&ES(&UE=&AO9"!T;R!R971U<FX@<VAA
M<F5D(&%N9"!E>&-L=7-I=F4@;&]C:W,@"B`@("`@("`@("H@86-T:79E(&9O
M<B!T:&ES(')E<V]U<F-E"B`@("`@("`@("H*("`@("`@("`@*B!`86)S=')A
M8W0@"B`@("`@("`@("H@0'!A<F%M('-T<FEN9R!R97-O=7)C92!297-O=7)C
M92!P871H('1O(&-H96-K"B`@("`@("`@("H@0')E='5R;G,@87)R87D@06X@
M87)R87D@;V8@;&]C:R!E;G1R:65S(&5A8V@@8V]N<VES=&EN9PH@("`@("`@
M("`J("`@("`@("`@("`@("`@(&]F("=T>7!E)R`H)W-H87)E9"<O)V5X8VQU
M<VEV92<I+"`G=&]K96XG(&%N9"`G=&EM96]U="<*("`@("`@("`@*B\*"B`@
M("`O*B!A8G-T<F%C=`H@("`@("`@9G5N8W1I;VX@8VAE8VML;V-K*"1R97-O
M=7)C92D@>PH@("`@("`@+R\@9'5M;7D@96YT<GD@9F]R(%!(4$1O8PH@("`@
M("`@?2`*("`@("`J+PH*("`@("\O('U]?0H*("`@("\O('U]?0H*("`@("\O
M('M[>R!796)$058@2%144"!M971H;V0@=W)A<'!E<G,@"@H@("`@+R\@>WM[
M(&AT='!?3U!424].4R@I(`H*("`@("`@("`@("`@("`@("\J*@H@("`@("`@
M("`J($]05$E/3E,@;65T:&]D(&AA;F1L97(*("`@("`@("`@*@H@("`@("`@
M("`J(%1H92!/4%1)3TY3(&UE=&AO9"!H86YD;&5R(&-R96%T97,@82!V86QI
M9"!/4%1)3TY3(')E<&QY"B`@("`@("`@("H@:6YC;'5D:6YG($1A=CH@86YD
M($%L;&]W960Z(&AE865R<PH@("`@("`@("`J(&)A<V5D(&]N('1H92!I;7!L
M96UE;G1E9"!M971H;V1S(&9O=6YD(&EN('1H92!A8W1U86P@:6YS=&%N8V4*
M("`@("`@("`@*@H@("`@("`@("`J($!P87)A;2!V;VED"B`@("`@("`@("H@
M0')E='5R;G,@=F]I9`H@("`@("`@("`J+PH*("`@(&9U;F-T:6]N(&AT='!?
M3U!424].4R@I('L*("`@("`@("`D=&AI<RT^:'1T<%]S=&%T=7,H(C(P,"!/
M2R(I.PH*("`@("`@("`O+R!B92!N:6-E('1O($TD(&-L:65N=',*("`@("`@
M("!H96%D97(H(DU3+4%U=&AO<BU6:6$Z($1!5B(I.PH*("`@("`@("`O+R!G
M970@86QL;W=E9"!M971H;V1S"B`@("`@("`@)&%L;&]W(#T@)'1H:7,M/E]A
M;&QO=R@I.PH*("`@("`@("`O+R!D878@:&5A9&5R"B`@("`@("`@)&1A=B`]
M(&%R<F%Y*#$I.R`@("`@("`@+R\@87-S=6UE('=E(&%R92!A;'=A>7,@9&%V
M(&-L87-S(#$@8V]M<&QI86YT"B`@("`@("`@:68@*&ES<V5T*"1A;&QO=ULG
M;&]C:R==*2D*("`@("`@("`@("`@)&1A=EM=(#T@,CL@("`@("`@("`O+R!D
M878@8VQA<W,@,B!R97%U:7)E<R!L;V-K:6YG(`H*("`@("`@("!H96%D97(H
M(D1!5CH@(BYJ;VEN*"(L(BP@)&1A=BDI.PH@("`@("`@(&AE861E<B@B06QL
M;W<Z("(N:F]I;B@B+"`B+"`D86QL;W<I*3L*("`@('T*"B`@("`O+R!]?7T*
M"@H@("`@+R\@>WM[(&AT='!?4%)/4$9)3D0H*2`*"B`@("!F=6YC=&EO;B!H
M='1P7U!23U!&24Y$*"D@>PH@("`@("`@("1O<'1I;VYS(#T@07)R87DH*3L*
M("`@("`@("`D;W!T:6]N<ULB<&%T:")=(#T@)'1H:7,M/G!A=&@["@H@("`@
M("`@("`@("!I9B`H:7-S970H)%]315)615);)TA45%!?1$505$@G72DI('L*
M("`@("`@("`@("`@("`@("1O<'1I;VYS6R)D97!T:")=(#T@)%]315)615);
M(DA45%!?1$505$@B73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1O<'1I;VYS6R)D97!T:")=(#T@(FEN9FEN:71Y(CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`*("`@("`@("`@("`@)'!R;W!I;F9O(#T@
M;F5W(%]P87)S95]P<F]P9FEN9"@B<&AP.B\O:6YP=70B*3L*"B`@("`@("`@
M("`@(&EF("@A)'!R;W!I;F9O+3YS=6-C97-S*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^:'1T<%]S=&%T=7,H(C0P,"!%<G)O<B(I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(`H@("`@
M("`@("`@("`D;W!T:6]N<ULG<')O<',G72`]("1P<F]P:6YF;RT^<')O<',[
M"B`@("`@("`@("`@(`H@("`@("`@("`@("!I9B`H)'1H:7,M/G!R;W!F:6YD
M*"1O<'1I;VYS+"`D9FEL97,I*2!["B`@("`@("`@("`@("`@("`O+R!C;VQL
M96-T(&YA;65S<&%C97,*("`@("`@("`@("`@("`@("1N<U]H87-H(#T@87)R
M87DH*3L*("`@("`@("`@("`@("`@("1N<U]D969S(#T@(GAM;&YS.FYS,#U<
M(G5R;CIU=6ED.F,R9C0Q,#$P+38U8C,M,3%D,2UA,CEF+3`P86$P,&,Q-#@X
M,B]<(B([("`@("\O($TD(&YE961S('1H:7,@9F]R('1I;64@=F%L=65S"B`@
M("`@("`@("`@("`@("!F;W)E86-H*"1F:6QE<ULB9FEL97,B72!A<R`D9FEL
M96ME>2`]/B`D9FEL92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("A`:7-?
M87)R87DH)&9I;&5;(G!R;W!S(ETI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@H)&9I;&5;(G!R;W!S(ET@87,@)&ME>2`]/B`D<')O<"D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@8VQE86X@=7`@<F5T
M=7)N960@<')O<&5R=&EE<RP@;&5A=F4@;VYL>2!R97%U97-T960@96YT<FEE
M<PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-W:71C:"@D;W!T:6]N
M<ULG<')O<',G72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`B86QL(CH@("`*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FYA;65S
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D9FEL
M97-;(F9I;&5S(EU;)&9I;&5K97E=6R)P<F]P<R)=6R1K97E=6R)V86PB72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<ULB<')O<',B72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D
M;W!T:6]N<ULB<')O<',B72!A<R`D<F5Q<')O<"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97%P<F]P6R)N86UE
M(ET@/3T@)'!R;W!;(FYA;64B72D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O('1O9&\@3F%M95-P86-E<PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N
M9"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"$D9F]U;F0I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I;&5S6R)F:6QE<R)=6R1F:6QE:V5Y
M75LB<')O<',B75LD:V5Y73TB(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64H,BD["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<')O<%LB;G,B72DI
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;G,@/2`D<')O<%LB;G,B73L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;G,@/3T@(D1!5CHB
M*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N<U]H87-H
M6R1N<UTI*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YS7VYA;64@/2`B
M;G,B+BAC;W5N="@D;G-?:&%S:"D@*R`Q*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N<U]H87-H6R1N<UT@/2`D;G-?;F%M93L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N<U]D969S("X]("(@>&UL;G,Z)&YS7VYA
M;64]7"(D;G-<(B(["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@861D(&5N
M=')I97,@<F5Q=65S=&5D(&)U="!N;W0@9F]U;F0*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G-;)W!R;W!S)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&]P=&EO;G-;(G!R;W!S(ET@
M87,@)')E<7!R;W`I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M*"1R97%P<F]P6R=N86UE)UT]/2(B*2!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"@D9FEL95LB<')O<',B72!A<R`D<')O
M<"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5Q
M<')O<%LB;F%M92)=(#T]("1P<F]P6R)N86UE(ETI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&]D;R!.86UE4W!A8V5S"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R
M=64["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68H)')E<7!R;W!;(GAM;&YS(ET]/3TB1$%6.B(@)B8@)')E<7!R
M;W!;(FYA;64B73T]/2)L;V-K9&ES8V]V97)Y(BD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9FEL97-;(F9I;&5S(EU;)&9I;&5K
M97E=6R)P<F]P<R)=6UT@"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`]("1T:&ES+3YM:W!R;W`H(D1!5CHB+"`B;&]C:V1I<V-O
M=F5R>2(@+"`D=&AI<RT^;&]C:V1I<V-O=F5R>2@D9FEL97-;(F9I;&5S(EU;
M)&9I;&5K97E=6R=P871H)UTI*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9FEL97-;(F9I;&5S(EU;)&9I;&5K97E=6R)N;W!R;W!S(EU;
M72`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;6MP<F]P*"1R97%P<F]P6R)X;6QN<R)=+"`D<F5Q<')O<%LB;F%M
M92)=+"`B(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D<F5Q<')O<%LB>&UL;G,B72`A/2`B1$%6.B(@)B8*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I<W-E="@D;G-?:&%S
M:%LD<F5Q<')O<%LB>&UL;G,B75TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;G-?;F%M92`](")N<R(N*&-O=6YT*"1N
M<U]H87-H*2`K(#$I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&YS7VAA<VA;)')E<7!R;W!;(GAM;&YS(EU=(#T@)&YS7VYA
M;64["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;G-?9&5F<R`N/2`B('AM;&YS.B1N<U]N86UE/5PB)')E<7!R;W!;>&UL;G-=
M7"(B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@"B`@("`@("`@("`@("`@("`D=&AI<RT^:'1T<%]S=&%T=7,H
M(C(P-R!-=6QT:2U3=&%T=7,B*3L*("`@("`@("`@("`@("`@(&AE861E<B@G
M0V]N=&5N="U4>7!E.B!T97AT+WAM;#L@8VAA<G-E=#TB=71F+3@B)RD["@H@
M("`@("`@("`@("`@("`@96-H;R`B/#]X;6P@=F5R<VEO;CU<(C$N,%PB(&5N
M8V]D:6YG/5PB=71F+3A<(C\^7&XB.PH@("`@("`@("`@("`@("`@96-H;R`B
M/$0Z;75L=&ES=&%T=7,@>&UL;G,Z1#U<(D1!5CI<(CY<;B(["@H@("`@("`@
M("`@("`@("`@9F]R96%C:"@D9FEL97-;(F9I;&5S(ET@87,@)&9I;&4I('L*
M("`@("`@("`@("`@("`@("`@("!I9B@A:7-?87)R87DH)&9I;&4I('Q\(&5M
M<'1Y*"1F:6QE*2!\?"`A:7-S970H)&9I;&5;(G!A=&@B72DI(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@("`@(&5C:&\@(B`\1#IR97-P;VYS92`D;G-?
M9&5F<SY<;B(["B`@("`@("`@("`@("`@("`@("`@)'!A=&@@/2`D9FEL95LG
M<&%T:"==.R`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@
M(&EF*"%I<U]S=')I;F<H)'!A=&@I('Q\("1P871H/3T](B(I(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@("`@("\O('1O9&\Z(&UA:V4@<W5R92!C;VQL
M96-T:6]N(&AR969S(&5N9"!I;B`G+R<*("`@("`@("`@("`@("`@("`@("`O
M+R!H='1P.B\O)%]315)615);2%144%](3U-470H@("`@("`@("`@("`@("`@
M("`@(&5C:&\@(B`@/$0Z:')E9CXB+B1T:&ES+3Y?=7)L96YC;V1E*"1?4T52
M5D526R)30U))4%1?3D%-12)=+B1P871H*2XB/"]$.FAR968^7&XB.PH@("`@
M("`@("`@("`@("`@("`@(&5C:&\@(B`@(#Q$.G!R;W!S=&%T/EQN(CL*("`@
M("`@("`@("`@("`@("`@("!E8VAO("(@("`@/$0Z<')O<#Y<;B(["B`@("`@
M("`@("`@("`@("`@("`@:68@*$!I<U]A<G)A>2@D9FEL95LB<')O<',B72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D9FEL95LB<')O
M<',B72!A<R`D:V5Y(#T^("1P<F]P*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P<F]P*2D@8V]N=&EN=64["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P<F]P6R)N86UE
M(ETI*2!C;VYT:6YU93L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1P<F]P6R)V86PB72D@?'P@)'!R;W!;(G9A;")=(#T]/2`B
M(B!\?"`D<')O<%LB=F%L(ET@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68H)'!R;W!;(FYS(ET]/2)$058Z(BD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E8VAO("(@("`@
M(#Q$.B1P<F]P6VYA;65=+SY<;B(["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E(&EF*"1P<F]P6R)N<R)=*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@(B`@("`@/"(N)&YS7VAA
M<VA;)'!R;W!;(FYS(EU=+B(Z)'!R;W!;;F%M95TO/EQN(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!E8VAO("(@("`@(#PD<')O<%MN86UE
M72!X;6QN<SU<(EPB+SXB.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!I9B`H
M)'!R;W!;(FYS(ET@/3T@(D1!5CHB*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W=I=&-H("@D<')O<%LB;F%M92)=*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B8W)E871I;VYD871E(CH*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`B("`@
M("`\1#IC<F5A=&EO;F1A=&4@;G,P.F1T/5PB9&%T951I;64N='I<(CXB+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&%T92@B
M62UM+61<7%1(.FDZ<UQ<6B(L)'!R;W!;)W9A;"==*2X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\+T0Z8W)E871I;VYD871E
M/EQN(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B9V5T
M;&%S=&UO9&EF:65D(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@96-H;R`B("`@("`\1#IG971L87-T;6]D:69I960@;G,P.F1T/5PB
M9&%T951I;64N<F9C,3$R,UPB/B(N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!D871E*")$+"!J($T@62!(.FTZ<R`B+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!R;W!;)W9A;"==*2X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(")'350\+T0Z9V5T;&%S=&UO9&EF:65D/EQN(CL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<F5S;W5R8V5T>7!E(CH*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`B("`@
M("`\1#IR97-O=7)C971Y<&4^/$0Z)'!R;W!;=F%L72\^/"]$.G)E<V]U<F-E
M='EP93Y<;B(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G-U<'!O<G1E9&QO8VLB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!E8VAO("(@("`@(#Q$.G-U<'!O<G1E9&QO8VL^)'!R;W!;=F%L
M73PO1#IS=7!P;W)T961L;V-K/EQN(CL*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B;&]C:V1I<V-O=F5R>2(Z("`*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`B("`@("`\1#IL;V-K9&ES
M8V]V97)Y/EQN(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@96-H;R`D<')O<%LB=F%L(ET["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5C:&\@(B`@("`@/"]$.FQO8VMD:7-C;W9E<GD^7&XB
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!E8VAO("(@("`@(#Q$.B1P<F]P6VYA
M;65=/B(N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<')O<%]E;F-O9&4H:'1M;'-P96-I86QC:&%R<PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*"1P<F]P6R=V86PG72DI+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(CPO1#HD<')O<%MN86UE73Y<;B([
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D<')O<%LB;G,B72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!E8VAO("(@("`@(#PB+B1N<U]H87-H6R1P<F]P6R)N<R)=72X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(Z)'!R
M;W!;;F%M95T^(BX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YP<F]P7V5N8V]D92AH=&UL<W!E8VEA;&-H87)S"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`H)'!R;W!;)W9A;"==*2DN(CPO(BX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N<U]H87-H6R1P
M<F]P6R)N<R)=72X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("(Z)'!R;W!;;F%M95T^7&XB.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5C:&\@(B`@("`@/"1P<F]P6VYA;65=('AM;&YS/5PB
M7"(^(BX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YP<F]P7V5N8V]D92AH=&UL<W!E8VEA;&-H87)S"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`H)'!R;W!;)W9A;"==*2DN"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B/"\D<')O<%MN86UE73Y<;B(["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!E8VAO("(@("`\+T0Z<')O<#Y<
M;B(["B`@("`@("`@("`@("`@("`@("`@96-H;R`B("`@/$0Z<W1A='5S/DA4
M5%`O,2XQ(#(P,"!/2SPO1#IS=&%T=7,^7&XB.PH@("`@("`@("`@("`@("`@
M("`@(&5C:&\@(B`@/"]$.G!R;W!S=&%T/EQN(CL*"B`@("`@("`@("`@("`@
M("`@("`@:68@*$!I<U]A<G)A>2@D9FEL95LB;F]P<F]P<R)=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!E8VAO("(@("`\1#IP<F]P<W1A=#Y<;B([
M"B`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@(B`@("`\1#IP<F]P/EQN
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D9FEL95LB;F]P
M<F]P<R)=(&%S("1K97D@/3X@)'!R;W`I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-?87)R87DH)'!R;W`I*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P<F]P(#T@87)R87DH(G9A;"(@/3X@)'!R
M;W`I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1P<F]P6R)N
M<R)=(#T](")$058Z(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5C:&\@(B`@("`@/$0Z)'!R;W!;;F%M95TO/EQN(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92!I9B`H)'!R;W!;(FYS(ET@/3T@
M(B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E8VAO("(@
M("`@(#PD<')O<%MN86UE72!X;6QN<SU<(EPB+SY<;B(["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5C:&\@(B`@("`@/"(N)&YS7VAA<VA;)'!R;W!;(FYS
M(EU=+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B.B1P
M<F]P6VYA;65=+SY<;B(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@96-H;R`B("`@/"]$.G!R;W`^7&XB.PH@("`@("`@("`@("`@("`@
M("`@("`@("!E8VAO("(@("`\1#IS=&%T=7,^2%144"\Q+C$@-#`T($YO="!&
M;W5N9#PO1#IS=&%T=7,^7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("!E
M8VAO("(@(#PO1#IP<F]P<W1A=#Y<;B(["B`@("`@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("`@("!E8VAO("(@/"]$.G)E<W!O;G-E/EQN
M(CL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!E8VAO("(\
M+T0Z;75L=&ES=&%T=7,^7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/FAT='!?<W1A='5S*"(T,#0@3F]T($9O=6YD
M(BD["B`@("`@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*"B`@("`O+R![
M>WL@:'1T<%]04D]04$%40T@H*2`*"B`@("!F=6YC=&EO;B!H='1P7U!23U!0
M051#2"@I('L*("`@("`@("!I9B@D=&AI<RT^7V-H96-K7VQO8VM?<W1A='5S
M*"1T:&ES+3YP871H*2D@>PH@("`@("`@("`@("`D;W!T:6]N<R`]($%R<F%Y
M*"D["B`@("`@("`@("`@("1O<'1I;VYS6R)P871H(ET@/2`D=&AI<RT^<&%T
M:#L*"B`@("`@("`@("`@("1P<F]P:6YF;R`](&YE=R!?<&%R<V5?<')O<'!A
M=&-H*")P:'`Z+R]I;G!U="(I.PH*("`@("`@("`@("`@:68@*"$D<')O<&EN
M9F\M/G-U8V-E<W,I('L*("`@("`@("`@("`@("`@("1T:&ES+3YH='1P7W-T
M871U<R@B-#`P($5R<F]R(BD["B`@("`@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1O<'1I;VYS6R=P<F]P<R==(#T@
M)'!R;W!I;F9O+3YP<F]P<SL*"B`@("`@("`@("`@("1R97-P;VYS961E<V-R
M(#T@)'1H:7,M/G!R;W!P871C:"@D;W!T:6]N<RD["@H@("`@("`@("`@("`D
M=&AI<RT^:'1T<%]S=&%T=7,H(C(P-R!-=6QT:2U3=&%T=7,B*3L*("`@("`@
M("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z('1E>'0O>&UL.R!C:&%R<V5T
M/2)U=&8M."(G*3L*"B`@("`@("`@("`@(&5C:&\@(CP_>&UL('9E<G-I;VX]
M7"(Q+C!<(B!E;F-O9&EN9SU<(G5T9BTX7"(_/EQN(CL*"B`@("`@("`@("`@
M(&5C:&\@(CQ$.FUU;'1I<W1A='5S('AM;&YS.D0]7")$058Z7"(^7&XB.PH@
M("`@("`@("`@("!E8VAO("(@/$0Z<F5S<&]N<V4^7&XB.PH@("`@("`@("`@
M("!E8VAO("(@(#Q$.FAR968^(BXD=&AI<RT^7W5R;&5N8V]D92@D7U-%4E9%
M4ELB4T-225!47TY!344B72XD=&AI<RT^<&%T:"DN(CPO1#IH<F5F/EQN(CL*
M"B`@("`@("`@("`@(&9O<F5A8V@H)&]P=&EO;G-;(G!R;W!S(ET@87,@)'!R
M;W`I('L*("`@("`@("`@("`@("`@(&5C:&\@(B`@(#Q$.G!R;W!S=&%T/EQN
M(CL*("`@("`@("`@("`@("`@(&5C:&\@(B`@("`\1#IP<F]P/CPD<')O<%MN
M86UE72!X;6QN<SU<(B1P<F]P6VYS75PB+SX\+T0Z<')O<#Y<;B(["B`@("`@
M("`@("`@("`@("!E8VAO("(@("`@/$0Z<W1A='5S/DA45%`O,2XQ("1P<F]P
M6W-T871U<UT\+T0Z<W1A='5S/EQN(CL*("`@("`@("`@("`@("`@(&5C:&\@
M(B`@(#PO1#IP<F]P<W1A=#Y<;B(["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@D<F5S<&]N<V5D97-C<BD@>PH@("`@("`@("`@("`@("`@96-H
M;R`B("`\1#IR97-P;VYS961E<V-R:7!T:6]N/B(N"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G!R;W!?96YC;V1E*&AT;6QS<&5C:6%L8VAA<G,H)')E
M<W!O;G-E9&5S8W(I*2X*("`@("`@("`@("`@("`@("`@("`B/"]$.G)E<W!O
M;G-E9&5S8W)I<'1I;VX^7&XB.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!E8VAO("(@/"]$.G)E<W!O;G-E/EQN(CL*("`@("`@("`@("`@96-H;R`B
M/"]$.FUU;'1I<W1A='5S/EQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^:'1T<%]S=&%T=7,H(C0R,R!,;V-K960B*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+R\@?7U]"@H*("`@("\O('M[>R!H='1P7TU+0T],
M*"D@"@H@("`@9G5N8W1I;VX@:'1T<%]-2T-/3"@I('L*("`@("`@("`D;W!T
M:6]N<R`]($%R<F%Y*"D["B`@("`@("`@)&]P=&EO;G-;(G!A=&@B72`]("1T
M:&ES+3YP871H.PH*("`@("`@("`D<W1A="`]("1T:&ES+3YM:V-O;"@D;W!T
M:6]N<RD["@H@("`@("`@("1T:&ES+3YH='1P7W-T871U<R@D<W1A="D["B`@
M("!]"@H@("`@+R\@?7U]"@H*("`@("\O('M[>R!H='1P7T=%5"@I(`H*("`@
M("`@("`@("`@("`@("\J*@H@("`@("`@("`J($=%5"!W<F%P<&5R"B`@("`@
M("`@("H*("`@("`@("`@*B!'150@=W)A<'!E<@H@("`@("`@("`J"B`@("`@
M("`@("H@0'!A<F%M('9O:60*("`@("`@("`@*B!`<F5T=7)N<R!V;VED"B`@
M("`@("`@("HO"@H@("`@9G5N8W1I;VX@:'1T<%]'150H*2!["B`@("`@("`@
M)&]P=&EO;G,@/2!!<G)A>2@I.PH@("`@("`@("1O<'1I;VYS6R)P871H(ET@
M/2`D=&AI<RT^<&%T:#L*"B`@("`@("`@)'1H:7,M/E]G971?<F%N9V5S*"1O
M<'1I;VYS*3L*"B`@("`@("`@:68@*'1R=64@/3T@*"1S=&%T=7,@/2`D=&AI
M<RT^9V5T*"1O<'1I;VYS*2DI('L*("`@("`@("`@("`@:68@*"%H96%D97)S
M7W-E;G0H*2D@>PH@("`@("`@("`@("`@("`@)'-T871U<R`]("(R,#`@3TLB
M.PH*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)VUI;65T
M>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G-;)VUI;65T
M>7!E)UT@/2`B87!P;&EC871I;VXO;V-T970M<W1R96%M(CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&AE861E<B@B0V]N=&5N="UT>7!E
M.B`D;W!T:6]N<UMM:6UE='EP95TB*3L*("`@("`@("`@("`@("`@("`@("`*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG;71I;64G72DI
M('L*("`@("`@("`@("`@("`@("`@("!H96%D97(H(DQA<W0M;6]D:69I960Z
M(BYD871E*")$+"!J($T@62!(.FTZ<R`B+"`D;W!T:6]N<ULG;71I;64G72DN
M(D=-5"(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-T<F5A;2==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("\O($=%5"!H86YD;&5R(')E='5R;F5D
M(&$@<W1R96%M"B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D;W!T
M:6]N<ULG<F%N9V5S)UTI("8F("@P/3T]9G-E96LH)&]P=&EO;G-;)W-T<F5A
M;2==+"`P+"!3145+7U-%5"DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("\O('!A<G1I86P@<F5Q=65S="!A;F0@<W1R96%M(&ES('-E96MA8FQE(`H@
M("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H8V]U;G0H)&]P=&EO;G-;)W)A;F=E<R==*2`]/3T@,2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')A;F=E(#T@)&]P=&EO;G-;)W)A;F=E
M<R==6S!=.PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<F%N9V5;)W-T87)T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9G-E96LH)&]P=&EO;G-;)W-T<F5A;2==+"`D<F%N9V5;)W-T
M87)T)UTL(%-%14M?4T54*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H9F5O9B@D;W!T:6]N<ULG<W1R96%M)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AT='!?<W1A='5S*"(T,38@
M4F5Q=65S=&5D(')A;F=E(&YO="!S871I<V9I86)L92(I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1R86YG95LG96YD)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S:7IE(#T@)')A;F=E6R=E
M;F0G72TD<F%N9V5;)W-T87)T)UTK,3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:'1T<%]S=&%T=7,H(C(P-B!P87)T:6%L(BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AE861E<B@B0V]N
M=&5N="UL96YG=&@Z("1S:7IE(BD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&AE861E<B@B0V]N=&5N="UR86YG93H@)')A;F=E6W-T
M87)T72TD<F%N9V5;96YD72\B+B`H:7-S970H)&]P=&EO;G-;)W-I>F4G72D@
M/R`D;W!T:6]N<ULG<VEZ92==(#H@(BHB*2D["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('=H:6QE("@D<VEZ92`F)B`A9F5O9B@D;W!T
M:6]N<ULG<W1R96%M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8G5F9F5R(#T@9G)E860H)&]P=&EO;G-;)W-T<F5A
M;2==+"`T,#DV*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S:7IE("T]('-T<FQE;B@D8G5F9F5R*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)&)U9F9E<CL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&AT='!?<W1A='5S*"(R,#8@<&%R=&EA
M;"(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)W-I>F4G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&AE861E<B@B0V]N=&5N="UL96YG=&@Z
M("(N*"1O<'1I;VYS6R=S:7IE)UT@+2`D<F%N9V5;)W-T87)T)UTI*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AE861E<B@B
M0V]N=&5N="UR86YG93H@)'-T87)T+21E;F0O(BX@*&ES<V5T*"1O<'1I;VYS
M6R=S:7IE)UTI(#\@)&]P=&EO;G-;)W-I>F4G72`Z("(J(BDI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9P87-S=&AR=2@D;W!T:6]N<ULG<W1R
M96%M)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:&5A9&5R*")#;VYT96YT+6QE;F=T:#H@
M(BXD<F%N9V5;)VQA<W0G72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9G-E96LH)&]P=&EO;G-;)W-T<F5A;2==+"`M)')A;F=E6R=L87-T
M)UTL(%-%14M?14Y$*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F<&%S<W1H<G4H)&]P=&EO;G-;)W-T<F5A;2==*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;75L
M=&EP87)T7V)Y=&5R86YG95]H96%D97(H*3L@+R\@:6YI="!M=6QT:7!A<G0*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS
M6R=R86YG97,G72!A<R`D<F%N9V4I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!43T1/('=H870@:68@<VEZ92!U;FMN;W=N/R`U,#`_
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R
M86YG95LG<W1A<G0G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9R;VT@(#T@)')A;F=E6R=S=&%R="==.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&\@("`@/2`A96UP='DH)')A
M;F=E6R=E;F0G72D@/R`D<F%N9V5;)V5N9"==(#H@)&]P=&EO;G-;)W-I>F4G
M72TQ.R`*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9G)O;2`]
M("1O<'1I;VYS6R=S:7IE)UT@+2`D<F%N9V5;)VQA<W0G72TQ.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&\@/2`D;W!T:6]N<ULG
M<VEZ92==("TQ.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&]T86P@/2!I<W-E
M="@D;W!T:6]N<ULG<VEZ92==*2`_("1O<'1I;VYS6R=S:7IE)UT@.B`B*B([
M(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S:7IE(#T@)'1O
M("T@)&9R;VT@*R`Q.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;75L=&EP87)T7V)Y=&5R86YG95]H96%D97(H)&]P=&EO;G-;
M)VUI;65T>7!E)UTL("1F<F]M+"`D=&\L("1T;W1A;"D["@H*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F<V5E:R@D;W!T:6]N<ULG<W1R96%M
M)UTL("1S=&%R="P@4T5%2U]3150I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('=H:6QE("@D<VEZ92`F)B`A9F5O9B@D;W!T:6]N<ULG<W1R
M96%M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1B=69F97(@/2!F<F5A9"@D;W!T:6]N<ULG<W1R96%M)UTL(#0P.38I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<VEZ92`M/2!S
M=')L96XH)&)U9F9E<BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5C:&\@)&)U9F9E<CL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUU;'1I<&%R=%]B>71E
M<F%N9V5?:&5A9&5R*"D[("\O(&5N9"!M=6QT:7!A<G0*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(&YO<FUA;"!R97%U97-T(&]R('-T
M<F5A;2!I<VXG="!S965K86)L92P@<F5T=7)N(&9U;&P@8V]N=&5N=`H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-I>F4G
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AE861E<B@B0V]N
M=&5N="UL96YG=&@Z("(N)&]P=&EO;G-;)W-I>F4G72D["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9G!A<W-T
M:')U*"1O<'1I;VYS6R=S=')E86TG72D["B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;CL@+R\@;F\@;6]R92!H96%D97)S"B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1O<'1I
M;VYS6R=D871A)UTI*2`@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D;W!T:6]N<ULG9&%T82==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!R97!L>2!T;R!P87)T:6%L(')E<75E<W0*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("!H96%D
M97(H(D-O;G1E;G0M;&5N9W1H.B`B+G-T<FQE;B@D;W!T:6]N<ULG9&%T82==
M*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)&1A=&$["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](`H@("`@("`@('T@"@H@("`@("`@(&EF("AF86QS92`]/3T@)'-T871U
M<RD@>PH@("`@("`@("`@("`D=&AI<RT^:'1T<%]S=&%T=7,H(C0P-"!N;W0@
M9F]U;F0B*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YH='1P7W-T871U
M<R@B)'-T871U<R(I.PH@("`@?0H*"B`@("!F=6YC=&EO;B!?9V5T7W)A;F=E
M<R@F)&]P=&EO;G,I('L*("`@("`@("!I9B`H:7-S970H)%]315)615);)TA4
M5%!?4D%.1T4G72DI('L*("`@("`@("`@("`@:68@*&5R96<H(F)Y=&5S6ULZ
M<W!A8V4Z75TJ/5M;.G-P86-E.EU=*B@N*BDB+"`D7U-%4E9%4ELG2%144%]2
M04Y'12==+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1O<'1I;VYS
M6R)R86YG97,B72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!F;W)E86-H
M("AE>'!L;V1E*"(L(BP@)&UA=&-H97-;,5TI(&%S("1R86YG92D@>PH@("`@
M("`@("`@("`@("`@("`@(&QI<W0H)'-T87)T+"`D96YD*2`](&5X<&QO9&4H
M(BTB+"`D<F%N9V4I.PH@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS6R)R
M86YG97,B75M=(#T@*"1S=&%R=#T]/2(B*2`_(&%R<F%Y*")L87-T(CT^)&5N
M9"D@.B!A<G)A>2@B<W1A<G0B/3XD<W1A<G0L(")E;F0B/3XD96YD*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!?;75L=&EP87)T7V)Y=&5R86YG95]H96%D97(H)&UI
M;65T>7!E(#T@9F%L<V4L("1F<F]M(#T@9F%L<V4L("1T;SUF86QS92P@)'1O
M=&%L/69A;'-E*2!["B`@("`@("`@:68@*"1M:6UE='EP92`]/2!F86QS92D@
M>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YM=6QT:7!A<G1?<V5P
M87)A=&]R*2D@>PH@("`@("`@("`@("`@("`@+R\@:6YI=&EA;`H@("`@("`@
M("`@("`@("`@)'1H:7,M/FUU;'1I<&%R=%]S97!A<F%T;W(@/2`B4T504$%2
M051/4E\B+FUD-2AM:6-R;W1I;64H*2D["B`@("`@("`@("`@("`@("!H96%D
M97(H(D-O;G1E;G0M='EP93H@;75L=&EP87)T+V)Y=&5R86YG97,[(&)O=6YD
M87)Y/2(N)'1H:7,M/FUU;'1I<&%R=%]S97!A<F%T;W(I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@9FEN86P*("`@("`@("`@
M("`@("`@(&5C:&\@(EQN+2U[)'1H:7,M/FUU;'1I<&%R=%]S97!A<F%T;W)]
M+2TB.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@96-H;R`B7&XM+7LD=&AI<RT^;75L=&EP87)T7W-E<&%R871O<GU<;B([
M"B`@("`@("`@("`@(&5C:&\@(D-O;G1E;G0M='EP93H@)&UI;65T>7!E7&XB
M.PH@("`@("`@("`@("!E8VAO(")#;VYT96YT+7)A;F=E.B`D9G)O;2TD=&\O
M(BX@*"1T;W1A;"`]/3T@9F%L<V4@/R`B*B(@.B`D=&]T86PI.PH@("`@("`@
M("`@("!E8VAO(")<;EQN(CL*("`@("`@("!]"B`@("!]"@H@("`@("`@("`@
M("`*"B`@("`O+R!]?7T*"B`@("`O+R![>WL@:'1T<%](14%$*"D@"@H@("`@
M9G5N8W1I;VX@:'1T<%](14%$*"D@>PH@("`@("`@("1S=&%T=7,@/2!F86QS
M93L*("`@("`@("`D;W!T:6]N<R`]($%R<F%Y*"D["B`@("`@("`@)&]P=&EO
M;G-;(G!A=&@B72`]("1T:&ES+3YP871H.PH@("`@("`@(`H@("`@("`@(&EF
M("AM971H;V1?97AI<W1S*"1T:&ES+"`B2$5!1"(I*2!["B`@("`@("`@("`@
M("1S=&%T=7,@/2`D=&AI<RT^:&5A9"@D;W!T:6]N<RD["B`@("`@("`@?2!E
M;'-E(&EF("AM971H;V1?97AI<W1S*"1T:&ES+"`B1T54(BDI('L*("`@("`@
M("`@("`@;V)?<W1A<G0H*3L*("`@("`@("`@("`@)'-T871U<R`]("1T:&ES
M+3Y'150H)&]P=&EO;G,I.PH@("`@("`@("`@("!O8E]E;F1?8VQE86XH*3L*
M("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68H)'-T871U<ST]/71R=64I
M("`D<W1A='5S(#T@(C(P,"!/2R(["B`@("`@("`@:68H)'-T871U<ST]/69A
M;'-E*2`D<W1A='5S(#T@(C0P-"!.;W0@9F]U;F0B.PH@("`@("`@(`H@("`@
M("`@("1T:&ES+3YH='1P7W-T871U<R@D<W1A='5S*3L*("`@('T*"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@:'1T<%]0550H*2`*"B`@("!F=6YC=&EO;B!H
M='1P7U!55"@I('L*("`@("`@("!I9B`H)'1H:7,M/E]C:&5C:U]L;V-K7W-T
M871U<R@D=&AI<RT^<&%T:"DI('L*("`@("`@("`@("`@)&]P=&EO;G,@/2!!
M<G)A>2@I.PH@("`@("`@("`@("`D;W!T:6]N<ULB<&%T:")=(#T@)'1H:7,M
M/G!A=&@["B`@("`@("`@("`@("1O<'1I;VYS6R)C;VYT96YT7VQE;F=T:")=
M(#T@)%]315)615);(D-/3E1%3E1?3$5.1U1((ET["@H@("`@("`@("`@("`O
M+R!G970@=&AE($-O;G1E;G0M='EP92`*("`@("`@("`@("`@:68@*&ES<V5T
M*"1?4T525D526R)#3TY414Y47U194$4B72DI('L*("`@("`@("`@("`@("`@
M("\O(&9O<B!N;W<@=V4@9&\@;F]T('-U<'!O<G0@86YY('-O<G0@;V8@;75L
M=&EP87)T(')E<75E<W1S"B`@("`@("`@("`@("`@("!I9B`H(7-T<FYC;7`H
M)%]315)615);(D-/3E1%3E1?5%E012)=+"`B;75L=&EP87)T+R(L(#$P*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH='1P7W-T871U<R@U,#$I
M.R`*("`@("`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULB8V]N=&5N=%]T>7!E(ET@
M/2`D7U-%4E9%4ELB0T].5$5.5%]465!%(ET["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`O+R!D969A=6QT(&-O;G1E;G0@='EP92!I
M9B!N;VYE(&=I=F5N"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULB8V]N=&5N
M=%]T>7!E(ET@/2`B87!P;&EC871I;VXO;V-T970M<W1R96%M(CL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+RH@4D9#(#(V,38@,BXV('-A>7,@(E1H
M92!R96-I<&EE;G0@;V8@=&AE(&5N=&ET>2!-55-4($Y/5"`*("`@("`@("`@
M("`@("`@:6=N;W)E(&%N>2!#;VYT96YT+2H@*&4N9RX@0V]N=&5N="U286YG
M92D@:&5A9&5R<R!T:&%T(&ET(`H@("`@("`@("`@("`@("!D;V5S(&YO="!U
M;F1E<G-T86YD(&]R(&EM<&QE;65N="!A;F0@35535"!R971U<FX@82`U,#$@
M"B`@("`@("`@("`@("`@("A.;W0@26UP;&5M96YT960I(')E<W!O;G-E(&EN
M('-U8V@@8V%S97,N"B`@("`@("`@("`@("HO"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1?4T525D52(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@:68@*'-T<FYC;7`H)&ME>2P@(DA45%!?0T].5$5.5"(L(#$Q*2D@8V]N
M=&EN=64["B`@("`@("`@("`@("`@("!S=VET8V@@*"1K97DI('L*("`@("`@
M("`@("`@("`@(&-A<V4@)TA45%!?0T].5$5.5%]%3D-/1$E.1R<Z("\O(%)&
M0R`R-C$V(#$T+C$Q"B`@("`@("`@("`@("`@("`@("`@+R\@5$]$3R!S=7!P
M;W)T('1H:7,@:68@97AT+WIL:6(@9FEL=&5R<R!A<F4@879A:6QA8FQE"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FAT='!?<W1A='5S*#4P,2D[(`H@
M("`@("`@("`@("`@("`@("`@(')E='5R;CL*"B`@("`@("`@("`@("`@("!C
M87-E("=(5%107T-/3E1%3E1?3$%.1U5!1T4G.B`O+R!21D,@,C8Q-B`Q-"XQ
M,@H@("`@("`@("`@("`@("`@("`@("\O('=E(&%S<W5M92!I="!I<R!N;W0@
M8W)I=&EC86P@:68@=&AI<R!O;F4@:7,@:6=N;W)E9`H@("`@("`@("`@("`@
M("`@("`@("\O(&EN('1H92!A8W1U86P@4%54(&EM<&QE;65N=&%T:6]N("XN
M+@H@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS6R)C;VYT96YT7VQA;F=U
M86=E(ET@/2`D=F%L=64["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`G2%144%]#3TY414Y47TQ/0T%424].)SH@
M+R\@4D9#(#(V,38@,30N,30*("`@("`@("`@("`@("`@("`@("`O*B!4:&4@
M;65A;FEN9R!O9B!T:&4@0V]N=&5N="U,;V-A=&EO;B!H96%D97(@:6X@4%54
M(`H@("`@("`@("`@("`@("`@("`@("`@(&]R(%!/4U0@<F5Q=65S=',@:7,@
M=6YD969I;F5D.R!S97)V97)S(&%R92!F<F5E(`H@("`@("`@("`@("`@("`@
M("`@("`@('1O(&EG;F]R92!I="!I;B!T:&]S92!C87-E<RX@*B\*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=(
M5%107T-/3E1%3E1?4D%.1T4G.B`@("`O+R!21D,@,C8Q-B`Q-"XQ-@H@("`@
M("`@("`@("`@("`@("`@("\O('-I;F=L92!B>71E(')A;F=E(')E<75E<W1S
M(&%R92!S=7!P;W)T960*("`@("`@("`@("`@("`@("`@("`O+R!T:&4@:&5A
M9&5R(&9O<FUA="!I<R!A;'-O('-P96-I9FEE9"!I;B!21D,@,C8Q-B`Q-"XQ
M-@H@("`@("`@("`@("`@("`@("`@("\O(%1/1$\@=V4@:&%V92!T;R!E;G-U
M<F4@=&AA="!I;7!L96UE;G1A=&EO;G,@<W5P<&]R="!T:&ES(&]R('-E;F0@
M-3`Q(&EN<W1E860*("`@("`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T
M8V@H)T!B>71E<UQS*RA<9"LI+2A<9"LI+R@H7&0K*7Q<*BE`)RP@)'9A;'5E
M+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FAT='!?<W1A='5S*#0P,"D[(`H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(`H@("`@("`@("`@("`@("`@("`@("1R86YG92`](&%R<F%Y*")S=&%R
M="(]/B1M871C:&5S6S%=+"`B96YD(CT^)&UA=&-H97-;,ETI.PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1M871C:&5S6S-=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<F%N9V5;(G1O=&%L7VQE;F=T:")=
M(#T@)&UA=&-H97-;,UT["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1O<'1I;VY;(G)A;F=E<R)=6UT@/2`D<F%N9V4["@H@
M("`@("`@("`@("`@("`@("`@("\O(%1/1$\@;6%K92!S=7)E('1H92!I;7!L
M96UE;G1A=&EO;B!S=7!P;W)T<R!P87)T:6%L(%!55`H@("`@("`@("`@("`@
M("`@("`@("\O('1H:7,@:&%S('1O(&)E(&1O;F4@:6X@861V86YC92!T;R!A
M=F]I9"!D871A(&)E:6YG(&]V97)W<FET=&5N"B`@("`@("`@("`@("`@("`@
M("`@+R\@;VX@:6UP;&5M96YT871I;VYS('1H870@9&\@;F]T('-U<'!O<G0@
M=&AI<R`N+BX*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=(5%107T-/3E1%3E1?340U)SH@("`@("`O+R!21D,@
M,C8Q-B`Q-"XQ-0H@("`@("`@("`@("`@("`@("`@("\O(%1/1$\Z(&UA>6)E
M('=E(&-A;B!J=7-T('!R971E;F0@:&5R93\*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^:'1T<%]S=&%T=7,H-3`Q*3L@"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z(`H@("`@("`@
M("`@("`@("`@("`@("\O(&%N>2!O=&AE<B!U;FMN;W=N($-O;G1E;G0M*B!H
M96%D97)S"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAT='!?<W1A='5S
M*#4P,2D[(`H@("`@("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]P=&EO;G-;
M(G-T<F5A;2)=(#T@9F]P96XH(G!H<#HO+VEN<'5T(BP@(G(B*3L*"B`@("`@
M("`@("`@("1S=&%T(#T@)'1H:7,M/E!55"@D;W!T:6]N<RD["@H@("`@("`@
M("`@("!I9B`H:7-?<F5S;W5R8V4H)'-T870I("8F(&=E=%]R97-O=7)C95]T
M>7!E*"1S=&%T*2`]/2`B<W1R96%M(BD@>PH@("`@("`@("`@("`@("`@)'-T
M<F5A;2`]("1S=&%T.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D;W!T
M:6]N<ULB<F%N9V5S(ETI*2!["B`@("`@("`@("`@("`@("`@("`@+R\@5$]$
M3R!M=6QT:7!A<G0@<W5P<&]R="!I<R!M:7-S:6YG("AS964@86QS;R!A8F]V
M92D*("`@("`@("`@("`@("`@("`@("`O+R!43T1/(&5R<F]R(&-H96-K:6YG
M"B`@("`@("`@("`@("`@("`@("`@)'-T870@/2!F<V5E:R@D<W1R96%M+"`D
M<F%N9V5;,%U;(G-T87)T(ETL(%-%14M?4T54*3L*("`@("`@("`@("`@("`@
M("`@("!F=W)I=&4H)'-T<F5A;2P@9G)E860H)&]P=&EO;G-;(G-T<F5A;2)=
M+"`D<F%N9V5;,%U;(F5N9")=+21R86YG95LP75LB<W1A<G0B72LQ*2D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@('=H
M:6QE("@A9F5O9B@D;W!T:6]N<ULB<W1R96%M(ETI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&9W<FET92@D<W1R96%M+"!F<F5A9"@D;W!T:6]N<ULB
M<W1R96%M(ETL(#0P.38I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!F8VQO<V4H)'-T<F5A;2D[
M"B`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@)'-T870@/2`D;W!T:6]N
M<ULB;F5W(ET@/R`B,C`Q($-R96%T960B(#H@(C(P-"!.;R!#;VYT96YT(CL*
M("`@("`@("`@("`@?2`*"B`@("`@("`@("`@("1T:&ES+3YH='1P7W-T871U
M<R@D<W1A="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/FAT='!?<W1A='5S*"(T,C,@3&]C:V5D(BD["B`@("`@("`@?0H@("`@?0H*
M("`@("\O('U]?0H*"B`@("`O+R![>WL@:'1T<%]$14Q%5$4H*2`*"B`@("!F
M=6YC=&EO;B!H='1P7T1%3$5412@I('L*("`@("`@("`O+R!21D,@,C4Q."!3
M96-T:6]N(#DN,BP@;&%S="!P87)A9W)A<&@*("`@("`@("!I9B`H:7-S970H
M)%]315)615);(DA45%!?1$505$@B72DI('L*("`@("`@("`@("`@:68@*"1?
M4T525D526R)(5%107T1%4%1((ET@(3T@(FEN9FEN:71Y(BD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FAT='!?<W1A='5S*"(T,#`@0F%D(%)E<75E<W0B
M*3L*("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?8VAE8VM?;&]C:U]S=&%T=7,H
M)'1H:7,M/G!A=&@I*2!["B`@("`@("`@("`@("1O<'1I;VYS(#T@07)R87DH
M*3L*("`@("`@("`@("`@)&]P=&EO;G-;(G!A=&@B72`]("1T:&ES+3YP871H
M.PH*("`@("`@("`@("`@)'-T870@/2`D=&AI<RT^9&5L971E*"1O<'1I;VYS
M*3L*"B`@("`@("`@("`@("1T:&ES+3YH='1P7W-T871U<R@D<W1A="D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/FAT='!?<W1A='5S
M*"(T,C,@3&]C:V5D(BD["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*
M("`@("\O('M[>R!H='1P7T-/4%DH*2`*"B`@("!F=6YC=&EO;B!H='1P7T-/
M4%DH*2!["B`@("`@("`@)'1H:7,M/E]C;W!Y;6]V92@B8V]P>2(I.PH@("`@
M?0H*("`@("\O('U]?0H*("`@("\O('M[>R!H='1P7TU/5D4H*2`*"B`@("!F
M=6YC=&EO;B!H='1P7TU/5D4H*2!["B`@("`@("`@:68@*"1T:&ES+3Y?8VAE
M8VM?;&]C:U]S=&%T=7,H)'1H:7,M/G!A=&@I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?8V]P>6UO=F4H(FUO=F4B*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^:'1T<%]S=&%T=7,H(C0R,R!,;V-K960B*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@H*("`@("\O('M[>R!H='1P7TQ/
M0TLH*2`*"B`@("!F=6YC=&EO;B!H='1P7TQ/0TLH*2!["B`@("`@("`@)&QO
M8VMI;F9O(#T@;F5W(%]P87)S95]L;V-K:6YF;R@B<&AP.B\O:6YP=70B*3L*
M"B`@("`@("`@:68H)'1H:7,M/E]C:&5C:U]L;V-K7W-T871U<R@D=&AI<RT^
M<&%T:"P@)&QO8VMI;F9O+3YL;V-K<V-O<&4@/3T](")S:&%R960B*2D@>PH@
M("`@("`@("`@("`D;W!T:6]N<R`]($%R<F%Y*"D["B`@("`@("`@("`@("1O
M<'1I;VYS6R)P871H(ET@/2`D=&AI<RT^<&%T:#L*"B`@("`@("`@("`@(&EF
M("AI<W-E="@D7U-%4E9%4ELG2%144%]$15!42"==*2D@>PH@("`@("`@("`@
M("`@("`@)&]P=&EO;G-;(F1E<'1H(ET@/2`D7U-%4E9%4ELB2%144%]$15!4
M2")=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]P
M=&EO;G-;(F1E<'1H(ET@/2`B:6YF:6YI='DB.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H:7-S970H)%]315)615);(DA45%!?5$E-14]55")=
M*2D@>PH@("`@("`@("`@("`@("`@)&]P=&EO;G-;(G1I;65O=70B72`](&5X
M<&QO9&4H(BPB+"`D7U-%4E9%4ELB2%144%]424U%3U54(ETI.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9BAE;7!T>2@D7U-%4E9%4ELG0T].5$5.
M5%],14Y'5$@G72D@)B8@(65M<'1Y*"1?4T525D526R=(5%107TE&)UTI*2![
M"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULB=7!D871E(ET@/2!S=6)S='(H
M)%]315)615);)TA45%!?248G72PR+"TR*3L*("`@("`@("`@("`@("`@("1S
M=&%T(#T@)'1H:7,M/FQO8VLH)&]P=&EO;G,I.PH@("`@("`@("`@("!](&5L
M<V4@>R`*("`@("`@("`@("`@("`@("\O(&YE=R!L;V-K(`H@("`@("`@("`@
M("`@("`@"B`@("`@("`@("`@("`@("!I9B`H)&QO8VMI;F9O+3YS=6-C97-S
M*2!["B`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G-;(G-C;W!E(ET@/2`D
M;&]C:VEN9F\M/FQO8VMS8V]P93L*("`@("`@("`@("`@("`@("`@("`D;W!T
M:6]N<ULB='EP92)=("`]("1L;V-K:6YF;RT^;&]C:W1Y<&4["B`@("`@("`@
M("`@("`@("`@("`@)&]P=&EO;G-;(F]W;F5R(ET@/2`D;&]C:VEN9F\M/F]W
M;F5R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@"@H@("`@
M("`@("`@("`@("`@)&]P=&EO;G-;(FQO8VMT;VME;B)=(#T@)'1H:7,M/E]N
M97=?;&]C:W1O:V5N*"D["B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@
M("`@("1S=&%T(#T@)'1H:7,M/FQO8VLH)&]P=&EO;G,I.R`@("`@("`@("`@
M("`@"B`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@("`@("`@("`@(&EF
M*&ES7V)O;VPH)'-T870I*2!["B`@("`@("`@("`@("`@("`D:'1T<%]S=&%T
M(#T@)'-T870@/R`B,C`P($]+(B`Z("(T,C,@3&]C:V5D(CL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H='1P7W-T870@/2`D<W1A
M=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/FAT='!?<W1A
M='5S*"1H='1P7W-T870I.PH*("`@("`@("`@("`@:68H)&]P=&EO;G-;(G1I
M;65O=70B72D@>PH@("`@("`@("`@("`@("`@+R\@;6]R92!T:&%N(&$@;6EL
M;&EO;B!I<R!C;VYS:61E<F5D(&%N(&%B<V]L=71E('1I;65S=&%M<`H@("`@
M("`@("`@("`@("`@+R\@;&5S<R!I<R!M;W)E(&QI:V5L>2!A(')E;&%T:79E
M('9A;'5E"B`@("`@("`@("`@("`@("!I9B@D;W!T:6]N<ULB=&EM96]U=")=
M/C$P,#`P,#`I('L*("`@("`@("`@("`@("`@("`@("`D=&EM96]U="`](")3
M96-O;F0M(BXH)&]P=&EO;G-;)W1I;65O=70G72UT:6UE*"DI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&EM96]U
M="`](")396-O;F0M)&]P=&EO;G-;=&EM96]U=%TB.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1I
M;65O=70@/2`B26YF:6YI=&4B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(`H@("`@("`@("`@("!I9B`H)'-T870@/3T@=')U92D@>R`@("`@("`@+R\@
M;VL@"B`@("`@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@=&5X
M="]X;6P[(&-H87)S970](G5T9BTX(B<I.PH@("`@("`@("`@("`@("`@:&5A
M9&5R*"),;V-K+51O:V5N.B`\)&]P=&EO;G-;;&]C:W1O:V5N73XB*3L*("`@
M("`@("`@("`@("`@(&5C:&\@(CP_>&UL('9E<G-I;VX]7"(Q+C!<(B!E;F-O
M9&EN9SU<(G5T9BTX7"(_/EQN(CL*("`@("`@("`@("`@("`@(&5C:&\@(CQ$
M.G!R;W`@>&UL;G,Z1#U<(D1!5CI<(CY<;B(["B`@("`@("`@("`@("`@("!E
M8VAO("(@/$0Z;&]C:V1I<V-O=F5R>3Y<;B(["B`@("`@("`@("`@("`@("!E
M8VAO("(@(#Q$.F%C=&EV96QO8VL^7&XB.PH@("`@("`@("`@("`@("`@96-H
M;R`B("`@/$0Z;&]C:W-C;W!E/CQ$.B1O<'1I;VYS6W-C;W!E72\^/"]$.FQO
M8VMS8V]P93Y<;B(["B`@("`@("`@("`@("`@("!E8VAO("(@("`\1#IL;V-K
M='EP93X\1#HD;W!T:6]N<UMT>7!E72\^/"]$.FQO8VMT>7!E/EQN(CL*("`@
M("`@("`@("`@("`@(&5C:&\@(B`@(#Q$.F1E<'1H/B1O<'1I;VYS6V1E<'1H
M73PO1#ID97!T:#Y<;B(["B`@("`@("`@("`@("`@("!E8VAO("(@("`\1#IO
M=VYE<CXD;W!T:6]N<UMO=VYE<ET\+T0Z;W=N97(^7&XB.PH@("`@("`@("`@
M("`@("`@96-H;R`B("`@/$0Z=&EM96]U=#XD=&EM96]U=#PO1#IT:6UE;W5T
M/EQN(CL*("`@("`@("`@("`@("`@(&5C:&\@(B`@(#Q$.FQO8VMT;VME;CX\
M1#IH<F5F/B1O<'1I;VYS6VQO8VMT;VME;ET\+T0Z:')E9CX\+T0Z;&]C:W1O
M:V5N/EQN(CL*("`@("`@("`@("`@("`@(&5C:&\@(B`@/"]$.F%C=&EV96QO
M8VL^7&XB.PH@("`@("`@("`@("`@("`@96-H;R`B(#PO1#IL;V-K9&ES8V]V
M97)Y/EQN(CL*("`@("`@("`@("`@("`@(&5C:&\@(CPO1#IP<F]P/EQN7&XB
M.PH@("`@("`@("`@("!](&5L<V4@>R`@("`@("`@("`@("`@("`O+R!F86EL
M(`H@("`@("`@("`@("`@("`@+R\@5$]$3R$A(0H@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/FAT='!?<W1A='5S
M*"(T,C,@3&]C:V5D(BD["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*
M("`@("\O('M[>R!H='1P7U5.3$]#2R@I(`H*("`@(&9U;F-T:6]N(&AT='!?
M54Y,3T-+*"D@>PH@("`@("`@("1O<'1I;VYS(#T@07)R87DH*3L*("`@("`@
M("`D;W!T:6]N<ULB<&%T:")=(#T@)'1H:7,M/G!A=&@["@H@("`@("`@(&EF
M("AI<W-E="@D7U-%4E9%4ELG2%144%]$15!42"==*2D@>PH@("`@("`@("`@
M("`D;W!T:6]N<ULB9&5P=&@B72`]("1?4T525D526R)(5%107T1%4%1((ET[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]P=&EO;G-;(F1E<'1H
M(ET@/2`B:6YF:6YI='DB.PH@("`@("`@('T*"B`@("`@("`@)&]P=&EO;G-;
M(G1O:V5N(ET@/2!S=6)S='(H)%]315)615);(DA45%!?3$]#2U]43TM%3B)=
M+"`Q+"`M,2D[("\O('-T<FEP(#P^(`H*("`@("`@("`D<W1A="`]("1T:&ES
M+3YU;FQO8VLH)&]P=&EO;G,I.PH*("`@("`@("`D=&AI<RT^:'1T<%]S=&%T
M=7,H)'-T870I.PH@("`@?0H*("`@("\O('U]?0H*("`@("\O('U]?0H*("`@
M("\O('M[>R!?8V]P>6UO=F4H*2`*"B`@("!F=6YC=&EO;B!?8V]P>6UO=F4H
M)'=H870I('L*("`@("`@("`D;W!T:6]N<R`]($%R<F%Y*"D["B`@("`@("`@
M)&]P=&EO;G-;(G!A=&@B72`]("1T:&ES+3YP871H.PH*("`@("`@("!I9B`H
M:7-S970H)%]315)615);(DA45%!?1$505$@B72DI('L*("`@("`@("`@("`@
M)&]P=&EO;G-;(F1E<'1H(ET@/2`D7U-%4E9%4ELB2%144%]$15!42")=.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O<'1I;VYS6R)D97!T:")=
M(#T@(FEN9FEN:71Y(CL*("`@("`@("!]"@H@("`@("`@(&5X=')A8W0H<&%R
M<V5?=7)L*"1?4T525D526R)(5%107T1%4U1)3D%424].(ETI*3L*("`@("`@
M("`D:'1T<%]H;W-T(#T@)&AO<W0["B`@("`@("`@:68@*&ES<V5T*"1P;W)T
M*2D*("`@("`@("`@("`@)&AT='!?:&]S="X]("(Z)'!O<G0B.PH*("`@("`@
M("!I9B`H)&AT='!?:&]S="`]/2`D7U-%4E9%4ELB2%144%](3U-4(ET@)B8*
M("`@("`@("`@("`@(7-T<FYC;7`H)%]315)615);(E-#4DE05%].04U%(ETL
M("1P871H+`H@("`@("`@("`@("`@("`@("`@("!S=')L96XH)%]315)615);
M(E-#4DE05%].04U%(ETI*2D@>PH@("`@("`@("`@("`D;W!T:6]N<ULB9&5S
M=")=(#T@<W5B<W1R*"1P871H+"!S=')L96XH)%]315)615);(E-#4DE05%].
M04U%(ETI*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7V-H96-K7VQO8VM?
M<W1A='5S*"1O<'1I;VYS6R)D97-T(ETI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^:'1T<%]S=&%T=7,H(C0R,R!,;V-K960B*3L*("`@("`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("`@("`@?0H*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;W!T:6]N<ULB9&5S=%]U<FPB72`]("1?4T525D526R)(
M5%107T1%4U1)3D%424].(ET["B`@("`@("`@?0H*("`@("`@("`O+R!S964@
M4D9#(#(U,3@@4V5C=&EO;G,@.2XV+"`X+C@N-"!A;F0@."XY+C,*("`@("`@
M("!I9B`H:7-S970H)%]315)615);(DA45%!?3U9%4E=2251%(ETI*2!["B`@
M("`@("`@("`@("1O<'1I;VYS6R)O=F5R=W)I=&4B72`]("1?4T525D526R)(
M5%107T]615)74DE412)=(#T](")4(CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;W!T:6]N<ULB;W9E<G=R:71E(ET@/2!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@)'-T870@/2`D=&AI<RT^)'=H870H)&]P=&EO;G,I.PH@
M("`@("`@("1T:&ES+3YH='1P7W-T871U<R@D<W1A="D["B`@("!]"@H@("`@
M+R\@?7U]"@H@("`@+R\@>WM[(%]A;&QO=R@I(`H*("`@("\J*@H@("`@("`@
M("`J(&-H96-K(&9O<B!I;7!L96UE;G1E9"!(5%10(&UE=&AO9',*("`@("`@
M("`@*@H@("`@("`@("`J(&-H96-K(&9O<B!I;7!L96UE;G1E9"!(5%10(&UE
M=&AO9',*("`@("`@("`@*@H@("`@("`@("`J($!P87)A;2!V;VED"B`@("`@
M("`@("H@0')E='5R;G,@87)R87D@<V]M971H:6YG"B`@("`@("`@("HO"B`@
M("!F=6YC=&EO;B!?86QL;W<H*2!["B`@("`@("`@+R\@3U!424].4R!I<R!A
M;'=A>7,@=&AE<F4*("`@("`@("`D86QL;W<@/2!A<G)A>2@B;W!T:6]N<R(@
M/3XB3U!424].4R(I.PH*("`@("`@("`O+R!A;&P@;W1H97(@34542$]$4R!N
M965D(&)O=&@@82!H='1P7VUE=&AO9"@I('=R87!P97(*("`@("`@("`O+R!A
M;F0@82!M971H;V0H*2!I;7!L96UE;G1A=&EO;@H@("`@("`@("\O('1H92!B
M87-E(&-L87-S('-U<'!L:65S('=R87!P97)S(&]N;'D*("`@("`@("!F;W)E
M86-H*&=E=%]C;&%S<U]M971H;V1S*"1T:&ES*2!A<R`D;65T:&]D*2!["B`@
M("`@("`@("`@(&EF("@A<W1R;F-M<"@B:'1T<%\B+"`D;65T:&]D+"`U*2D@
M>PH@("`@("`@("`@("`@("`@)&UE=&AO9"`]('-U8G-T<B@D;65T:&]D+"`U
M*3L*("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES+"`D
M;65T:&]D*2D@>PH@("`@("`@("`@("`@("`@("`@("1A;&QO=ULD;65T:&]D
M72`]('-T<G1O=7!P97(H)&UE=&AO9"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O('=E(&-A;B!E;75L
M871E(&$@;6ES<VEN9R!(14%$(&EM<&QE;65T871I;VX@=7-I;F<@1T54"B`@
M("`@("`@:68@*&ES<V5T*"1A;&QO=ULB9V5T(ETI*0H@("`@("`@("`@("`D
M86QL;W=;(FAE860B72`](")(14%$(CL*"B`@("`@("`@+R\@;F\@3$]#2R!W
M:71H;W5T(&-H96-K;&]K*"D*("`@("`@("!I9B`H(6UE=&AO9%]E>&ES=',H
M)'1H:7,L(")C:&5C:VQO8VLB*2D@>PH@("`@("`@("`@("!U;G-E="@D86QL
M;W=;(FQO8VLB72D["B`@("`@("`@("`@('5N<V5T*"1A;&QO=ULB=6YL;V-K
M(ETI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A;&QO=SL*("`@('T*
M"B`@("`O+R!]?7T*"@H@("`@9G5N8W1I;VX@;6MP<F]P*"D@>PH@("`@("`@
M("1A<F=S(#T@9G5N8U]G971?87)G<R@I.PH@("`@("`@(&EF("AC;W5N="@D
M87)G<RD@/3T@,RD@>PH@("`@("`@("`@("!R971U<FX@87)R87DH(FYA;64B
M(#T^)&%R9W-;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@("`B;G,B(#T^
M)&%R9W-;,%TL(")V86PB(#T^)&%R9W-;,ETI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@B;F%M92(@/3XD87)G<ULP72P*
M("`@("`@("`@("`@("`@("`@("`@("`@(")N<R(@/3XB1$%6.B(L(")V86PB
M(#T^)&%R9W-;,5TI.PH@("`@("`@('T*("`@('T*"B`@("`O+R![>WL@7V-H
M96-K7V%U=&@@"@H@("`@9G5N8W1I;VX@7V-H96-K7V%U=&@H*2!["B`@("`@
M("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,L(")C:&5C:U]A=71H(BDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC:&5C:U]A=71H*$`D7U-%4E9%
M4ELB05542%]465!%(ETL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!`)%]315)615);(E!(4%]!551(7U5315(B72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($`D7U-%4E9%4ELB4$A07T%5
M5$A?4%<B72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*("`@("\O('M[
M>R!554E$('-T=69F(`H*("`@(&9U;F-T:6]N(%]N97=?=75I9"@I('L*("`@
M("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*")U=6ED7V-R96%T92(I*2!["B`@
M("`@("`@("`@(')E='5R;B!U=6ED7V-R96%T92@I.PH@("`@("`@('T*("`@
M("`@("`O+R!F86QL8F%C:PH@("`@("`@("1U=6ED(#T@;60U*&UI8W)O=&EM
M92@I+F=E=&UY<&ED*"DI.R`@("`O+R!T:&ES('-H;W5L9"!B92!R86YD;VT@
M96YO=6=H(&9O<B!N;W<*"B`@("`@("`@+R\@<V5T('9A<FEA;G0@86YD('9E
M<G-I;VX@9FEE;&1S(&9O<B`G=')U92<@<F%N9&]M('5U:60*("`@("`@("`D
M=75I9"!["B`@("`@("`@,3)]"B`@("`@("`@/2`B-"(["B`@("`@("`@)&X@
M/2`X("L@*&]R9"@D=75I9"!["B`@("`@("`@("`@("`@("`@("`@("`Q-GT*
M("`@("`@("`@("`@("`@("`@*2`F(#,I.PH@("`@("`@("1H97@@/2`B,#$R
M,S0U-C<X.6%B8V1E9B(["B`@("`@("`@)'5U:60@>PH@("`@("`@(#$V?0H@
M("`@("`@(#T@)&AE>"!["B`@("`@("`@)&Y].PH*("`@("`@("`O+R!R971U
M<FX@9F]R;6%T960@=75I9`H@("`@("`@(')E='5R;B!S=6)S='(H)'5U:60L
M(#`L(#@I+B(M(BYS=6)S='(H)'5U:60L(#@L(#0I+B(M(BYS=6)S='(H)'5U
M:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#0I+B(M(BX*("`@("`@("`@("`@<W5B<W1R*"1U=6ED
M+"`Q-BP@-"DN(BTB+G-U8G-T<B@D=75I9"P@,C`I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]N97=?;&]C:W1O:V5N*"D@>PH@("`@("`@(')E='5R;B`B;W!A
M<75E;&]C:W1O:V5N.B(N)'1H:7,M/E]N97=?=75I9"@I.PH@("`@?0H*("`@
M("\O('U]?0H*("`@("\O('M[>R!796)$058@268Z(&AE861E<B!P87)S:6YG
M(`H*("`@(&9U;F-T:6]N(%]I9E]H96%D97)?;&5X97(H)'-T<FEN9RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)B1P;W,I('L*"B`@("`@("`@
M=VAI;&4@*&-T>7!E7W-P86-E*"1S=')I;F=[)'!O<WTI*0H@("`@("`@("`@
M("`K*R1P;W,[("`@("`@("`@("`@("\O('-K:7`@=VAI=&5S<&%C90H*("`@
M("`@("!I9B`H<W1R;&5N*"1S=')I;F<I(#P]("1P;W,I"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*"B`@("`@("`@)&,@/2`D<W1R:6YG>R1P;W,K*WT[
M"B`@("`@("`@<W=I=&-H("@D8RD@>PH@("`@("`@("`@("!C87-E("(\(CH*
M("`@("`@("`@("`@("`@("1P;W,R(#T@<W1R<&]S*"1S=')I;F<L("(^(BP@
M)'!O<RD["B`@("`@("`@("`@("`@("`D=7)I(#T@<W5B<W1R*"1S=')I;F<L
M("1P;W,L("1P;W,R("T@)'!O<RD["B`@("`@("`@("`@("`@("`D<&]S(#T@
M)'!O<S(@*R`Q.PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*")54DDB
M+"`D=7)I*3L*"B`@("`@("`@("`@(&-A<V4@(ELB.@H@("`@("`@("`@("`@
M("`@:68@*"1S=')I;F<@>PH@("`@("`@("`@("`@("`@("`@("1P;W-]"B`@
M("`@("`@("`@("`@("`@("`@/3T@(E<B*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1Y<&4@/2`B151!1U]714%+(CL*("`@("`@("`@("`@("`@("`@("`D
M<&]S("L](#(["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1T>7!E(#T@(D5404=?4U123TY'(CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1P;W,R(#T@<W1R<&]S*"1S=')I;F<L
M(")=(BP@)'!O<RD["B`@("`@("`@("`@("`@("`D971A9R`]('-U8G-T<B@D
M<W1R:6YG+"`D<&]S("L@,2P@)'!O<S(@+2`D<&]S("T@,BD["B`@("`@("`@
M("`@("`@("`D<&]S(#T@)'!O<S(@*R`Q.PH@("`@("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1T>7!E+"`D971A9RD["@H@("`@("`@("`@("!C87-E(").
M(CH*("`@("`@("`@("`@("`@("1P;W,@*ST@,CL*("`@("`@("`@("`@("`@
M(')E='5R;B!A<G)A>2@B3D]4(BP@(DYO="(I.PH*("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@B0TA!4B(L("1C
M*3L*("`@("`@("!]"B`@("!]"@H@("`@("`@("\J*B`*("`@("`@("`@*B!P
M87)S92!)9CH@:&5A9&5R"B`@("`@("`@("H*("`@("`@("`@*B!D:7-P871C
M:"!796)$058@2%144"!R97%U97-T('1O('1H92!A<')O<')I871E(&UE=&AO
M9"!H86YD;&5R"B`@("`@("`@("H@"B`@("`@("`@("H@0'!A<F%M("1S='(*
M("`@("`@("`@*B!`<F5T=7)N('9O:60*("`@("`@("`@*B\*("`@(&9U;F-T
M:6]N(%]I9E]H96%D97)?<&%R<V5R*"1S='(I('L*("`@("`@("`D<&]S(#T@
M,#L*("`@("`@("`D;&5N(#T@<W1R;&5N*"1S='(I.PH*("`@("`@("`D=7)I
M<R`](&%R<F%Y*"D["@H@("`@("`@('=H:6QE("@D<&]S(#P@)&QE;BD@>PH@
M("`@("`@("`@("`D=&]K96X@/2`D=&AI<RT^7VEF7VAE861E<E]L97AE<B@D
M<W1R+"`D<&]S*3L*"B`@("`@("`@("`@(&EF("@D=&]K96Y;,%T@/3T@(E52
M22(I('L*("`@("`@("`@("`@("`@("1U<FD@/2`D=&]K96Y;,5T["B`@("`@
M("`@("`@("`@("`D=&]K96X@/2`D=&AI<RT^7VEF7VAE861E<E]L97AE<B@D
M<W1R+"`D<&]S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1U<FD@/2`B(CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"1T;VME;ELP72`A/2`B0TA!4B(@?'P@)'1O:V5N6S%=("$]("(H(BD*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*"B`@("`@("`@("`@("1L:7-T
M(#T@87)R87DH*3L*("`@("`@("`@("`@)&QE=F5L(#T@,3L*("`@("`@("`@
M("`@)&YO="`]("(B.PH@("`@("`@("`@("!W:&EL92`H)&QE=F5L*2!["B`@
M("`@("`@("`@("`@("`D=&]K96X@/2`D=&AI<RT^7VEF7VAE861E<E]L97AE
M<B@D<W1R+"`D<&]S*3L*("`@("`@("`@("`@("`@(&EF("@D=&]K96Y;,%T@
M/3T@(DY/5"(I('L*("`@("`@("`@("`@("`@("`@("`D;F]T(#T@(B$B.PH@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@<W=I=&-H("@D=&]K96Y;,%TI('L*("`@("`@
M("`@("`@("`@("`@("!C87-E(")#2$%2(CH*("`@("`@("`@("`@("`@("`@
M("`@("`@<W=I=&-H("@D=&]K96Y;,5TI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@(B@B.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1L979E;"LK.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M*2(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L+2T[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`B55))(CH*("`@("`@("`@("`@
M("`@("`@("`@("`@)&QI<W1;72`]("1N;W0N(CPD=&]K96Y;,5T^(CL*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M("`@(&-A<V4@(D5404=?5T5!2R(Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1L:7-T6UT@/2`D;F]T+B);5R\G)'1O:V5N6S%=)UT^(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A
M<V4@(D5404=?4U123TY'(CH*("`@("`@("`@("`@("`@("`@("`@("`@)&QI
M<W1;72`]("1N;W0N(ELG)'1O:V5N6S%=)UT^(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1N;W0@/2`B(CL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*$!I<U]A<G)A>2@D=7)I<ULD=7)I
M72DI"B`@("`@("`@("`@("`@("`D=7)I<ULD=7)I72`](&%R<F%Y7VUE<F=E
M*"1U<FES6R1U<FE=+"1L:7-T*3L*("`@("`@("`@("`@96QS90H@("`@("`@
M("`@("`@("`@)'5R:7-;)'5R:5T@/2`D;&ES=#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=7)I<SL*("`@('T*"B`@("!F=6YC=&EO;B!?8VAE8VM?
M:69?:&5A9&5R7V-O;F1I=&EO;G,H*2!["B`@("`@("`@+R\@<V5E(')F8R`R
M-3$X('-E8RX@.2XT"B`@("`@("`@:68@*&ES<V5T*"1?4T525D526R)(5%10
M7TE&(ETI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:69?:&5A9&5R7W5R:7,@
M/0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I9E]H96%D97)?<&%R<V5R*"1?
M4T525D526R)(5%107TE&(ETI.PH*("`@("`@("`@("`@9F]R96%C:"@D=&AI
M<RT^7VEF7VAE861E<E]U<FES(&%S("1U<FD@/3X@)&-O;F1I=&EO;G,I('L*
M("`@("`@("`@("`@("`@(&EF("@D=7)I(#T]("(B*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@9&5F875L="!U<FD@:7,@=&AE(&-O;7!L971E(')E<75E
M<W0@=7)I"B`@("`@("`@("`@("`@("`@("`@)'5R:2`]("A`)%]315)615);
M(DA45%!3(ET@/3T](")O;B(@/R`B:'1T<',Z(B`Z(")H='1P.B(I.PH@("`@
M("`@("`@("`@("`@("`@("1U<FDN/0H@("`@("`@("`@("`@("`@("`@("`@
M("`B+R\D7U-%4E9%4EM(5%107TA/4U1=)%]315)615);4T-225!47TY!345=
M)%]315)615);4$%42%])3D9/72(["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`O+R!A;&P@;75S="!M871C:`H@("`@("`@("`@("`@("`@
M)'-T871E(#T@=')U93L*("`@("`@("`@("`@("`@(&9O<F5A8V@H)&-O;F1I
M=&EO;G,@87,@)&-O;F1I=&EO;BD@>PH@("`@("`@("`@("`@("`@("`@("\O
M(&QO8VL@=&]K96YS(&UA>2!B92!F<F5E(&9O<FT@*%)&0S(U,3@@-BXS*0H@
M("`@("`@("`@("`@("`@("`@("\O(&)U="!I9B!O<&%T=65L;V-K=&]K96YS
M(&%R92!U<V5D("A21D,R-3$X(#8N-"D*("`@("`@("`@("`@("`@("`@("`O
M+R!W92!H879E('1O(&-H96-K('1H92!F;W)M870@*&QI=&UU<R!T97-T<R!T
M:&ES*0H@("`@("`@("`@("`@("`@("`@(&EF("@A<W1R;F-M<"@D8V]N9&ET
M:6]N+"`B/&]P87%U96QO8VMT;VME;CHB+"!S=')L96XH(CQO<&%Q=65L;V-K
M=&]K96XB*2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E<F5G
M*")>/&]P87%U96QO8VMT;VME;CI;6SIX9&EG:70Z75U[.'TM6ULZ>&1I9VET
M.EU=>S1]+5M;.GAD:6=I=#I=77LT?2U;6SIX9&EG:70Z75U[-'TM6ULZ>&1I
M9VET.EU=>S$R?3XD(BP@)&-O;F1I=&EO;BDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H(21T:&ES+3Y?8VAE8VM?=7)I7V-O;F1I=&EO;B@D=7)I+"`D
M8V]N9&ET:6]N*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4@
M/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("\O(&%N>2!M871C:"!I<R!O:PH@("`@("`@("`@("`@("`@:68@
M*"1S=&%T92`]/2!T<G5E*0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@("`@
M("\J*@H@("`@("H@0VAE8VL@82!S:6YG;&4@55))(&-O;F1I=&EO;B!P87)S
M960@9G)O;2!A;B!I9BUH96%D97(*("`@("`J"B`@("`@*B!#:&5C:R!A('-I
M;F=L92!54DD@8V]N9&ET:6]N('!A<G-E9"!F<F]M(&%N(&EF+6AE861E<@H@
M("`@("H*("`@("`J($!A8G-T<F%C="`*("`@("`J($!P87)A;2!S=')I;F<@
M)'5R:2!54DD@=&\@8VAE8VL*("`@("`J($!P87)A;2!S=')I;F<@)&-O;F1I
M=&EO;B!#;VYD:71I;VX@=&\@8VAE8VL@9F]R('1H:7,@55))"B`@("`@*B!`
M<F5T=7)N<R!B;V]L($-O;F1I=&EO;B!C:&5C:R!R97-U;'0*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-H96-K7W5R:5]C;VYD:71I;VXH)'5R:2P@)&-O;F1I
M=&EO;BD@>PH@("`@("`@("\O(&YO="!R96%L;'D@:6UP;&5M96YT960@:&5R
M92P@"B`@("`@("`@+R\@:6UP;&5M96YT871I;VYS(&UU<W0@;W9E<G)I9&4*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"@H@("`@9G5N8W1I;VX@7V-H
M96-K7VQO8VM?<W1A='5S*"1P871H+"`D97AC;'5S:79E7V]N;'D@/2!F86QS
M92D@>PH@("`@("`@("\O($9)6$U%(&1E<'1H("T^(&EG;F]R960@9F]R(&YO
M=PH@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES+"`B8VAE8VML;V-K
M(BDI('L*("`@("`@("`@("`@+R\@:7,@;&]C:V5D/PH@("`@("`@("`@("`D
M;&]C:R`]("1T:&ES+3YC:&5C:VQO8VLH)'!A=&@I.PH*("`@("`@("`@("`@
M+R\@+BXN(&%N9"!L;V-K(&ES(&YO="!O=VYE9#\*("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1L;V-K*2`F)B!C;W5N="@D;&]C:RDI('L*("`@("`@("`@
M("`@("`@("\O($9)6$U%(&1O97-N)W0@8VAE8VL@=7)I(')E<W1R:6-T:6]N
M<R!Y970*("`@("`@("`@("`@("`@(&EF("@A<W1R<W1R*"1?4T525D526R)(
M5%107TE&(ETL("1L;V-K6R)T;VME;B)=*2D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A)&5X8VQU<VEV95]O;FQY('Q\("@D;&]C:ULB<V-O<&4B72`A
M/3T@(G-H87)E9"(I*0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H*("`@("\O('U]?0H*
M"@H@("`@9G5N8W1I;VX@;&]C:V1I<V-O=F5R>2@D<&%T:"D@>PH@("`@("`@
M(&EF("@A;65T:&]D7V5X:7-T<R@D=&AI<RP@(F-H96-K;&]C:R(I*2!["B`@
M("`@("`@("`@(')E='5R;B`B(CL*("`@("`@("!]"@H@("`@("`@("1L;V-K
M(#T@)'1H:7,M/F-H96-K;&]C:R@D<&%T:"D["@H@("`@("`@("1A8W1I=F5L
M;V-K<R`]("(B.PH*("`@("`@("!I9B`H:7-?87)R87DH)&QO8VLI("8F(&-O
M=6YT*"1L;V-K*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1L;V-K6R)E
M>'!I<F5S(ETI*2!["B`@("`@("`@("`@("`@("`D=&EM96]U="`](")396-O
M;F0M(BXH)&QO8VM;(F5X<&ER97,B72`M('1I;64H*2D["B`@("`@("`@("`@
M('T@96QS92!I9B`H(65M<'1Y*"1L;V-K6R)T:6UE;W5T(ETI*2!["B`@("`@
M("`@("`@("`@("`D=&EM96]U="`](")396-O;F0M)&QO8VM;=&EM96]U=%TB
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1I;65O
M=70@/2`B26YF:6YI=&4B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A
M8W1I=F5L;V-K<RX]("(*("`@("`@("`@("`@("`\1#IA8W1I=F5L;V-K/@H@
M("`@("`@("`@("`@("`\1#IL;V-K<V-O<&4^/$0Z)&QO8VM;<V-O<&5=+SX\
M+T0Z;&]C:W-C;W!E/@H@("`@("`@("`@("`@("`\1#IL;V-K='EP93X\1#HD
M;&]C:UMT>7!E72\^/"]$.FQO8VMT>7!E/@H@("`@("`@("`@("`@("`\1#ID
M97!T:#XD;&]C:UMD97!T:%T\+T0Z9&5P=&@^"B`@("`@("`@("`@("`@(#Q$
M.F]W;F5R/B1L;V-K6V]W;F5R73PO1#IO=VYE<CX*("`@("`@("`@("`@("`@
M/$0Z=&EM96]U=#XD=&EM96]U=#PO1#IT:6UE;W5T/@H@("`@("`@("`@("`@
M("`\1#IL;V-K=&]K96X^/$0Z:')E9CXD;&]C:UMT;VME;ET\+T0Z:')E9CX\
M+T0Z;&]C:W1O:V5N/@H@("`@("`@("`@("`@(#PO1#IA8W1I=F5L;V-K/@H@
M("`@("`B.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A8W1I=F5L;V-K
M<SL*("`@('T*"B`@("!F=6YC=&EO;B!H='1P7W-T871U<R@D<W1A='5S*2![
M"B`@("`@("`@:68H)'-T871U<R`]/3T@=')U92D@)'-T871U<R`]("(R,#`@
M3TLB.PH@("`@("`@("1T:&ES+3Y?:'1T<%]S=&%T=7,@/2`D<W1A='5S.PH@
M("`@("`@(&AE861E<B@B2%144"\Q+C$@)'-T871U<R(I.PH@("`@("`@(&AE
M861E<B@B6"U796)$058M4W1A='5S.B`D<W1A='5S(BD["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W5R;&5N8V]D92@D<&%T:"P@)&9O<E]H=&UL/69A;'-E*2![
M"B`@("`@("`@)')E='5R;B`]('-T<G1R*"1P871H+&%R<F%Y*"(@(CT^(B4R
M,"(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(F(CT^
M(B4R-B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\
M(CT^(B4S0R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("(^(CT^(B4S12(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("DI.PH@("`@("`@(&EF("@D9F]R7VAT;6PI('L*("`@("`@("`@("`@
M)')E='5R;B`]('-T<E]R97!L86-E*"(G(BP@(B4R-R(L("1R971U<FXI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W5R;&1E8V]D92@D<&%T:"D@>PH@("`@("`@(')E='5R;B!U
M<FQD96-O9&4H)'!A=&@I.PH@("`@?0H*"B`@("!F=6YC=&EO;B!P<F]P7V5N
M8V]D92@D=&5X="D@>PH@("`@("`@('-W:71C:"`H)'1H:7,M/E]P<F]P7V5N
M8V]D:6YG*2!["B`@("`@("`@8V%S92`B=71F+3@B.@H@("`@("`@("`@("!R
M971U<FX@)'1E>'0["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T
M=7)N('5T9CA?96YC;V1E*"1T97AT*3L*("`@("`@("!]"B`@("!]"GT@"@H@
M("\J"B`@("H@3&]C86P@=F%R:6%B;&5S.@H@("`J('1A8BUW:61T:#H@-`H@
M("`J(&,M8F%S:6,M;V9F<V5T.B`T"B`@("H@16YD.@H@("`J+PH_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TA45%`O4F5Q
M=65S="\`````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#`W`#`Q-S4U,P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O2%144"]297%U97-T+TQI<W1E;F5R+G!H<```````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#<R-3``,3`T,3<S-C,P,#<`,#(R,#4R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#(P,#(M,C`P,RP@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!2
M961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O
M<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@
M87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N
M9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&\@4F5D:7-T
M<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V
M92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@
M("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M
M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@
M;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO
M=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U;65N=&%T:6]N
M(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES
M=')I8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M
M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`HO
M+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET
M:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O('P@("!P97)M:7-S
M:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/
M4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\"B\O('P@(D%3
M($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)5$5$(%1/+"!42$4@
M24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE4
M3D534R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#
M3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\"B\O
M('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@?"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4
M($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%
M+"!\"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)2
M55!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P*+R\@?"!42$5/
M4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@
M3$E!0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@
M5$A%(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)
M4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!!;&5X97D@0F]R>F]V(#QA
M=F)`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@
M3&ES=&5N97(N<&AP+'8@,2XR(#(P,#,O,3`O,C8@,3`Z,C@Z,CD@879B($5X
M<"`D"B\O"@HO*BH*("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H92!/8G-E
M<G9E<B!P87)T(&]F(&$@4W5B:F5C="U/8G-E<G9E<@H@*B!D97-I9VX@<&%T
M=&5R;BX@270@;&ES=&5N<R!T;R!T:&4@979E;G1S('-E;G0@8GD@82`*("H@
M2%144%]297%U97-T(&]R($A45%!?4F5S<&]N<V4@:6YS=&%N8V4N"B`J"B`J
M($!P86-K86=E($A45%!?4F5Q=65S=`H@*B!`875T:&]R("!!;&5X97D@0F]R
M>F]V(#QA=F)`<&AP+FYE=#X*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C(@
M)`H@*B\*8VQA<W,@2%144%]297%U97-T7TQI<W1E;F5R(`I["B`@("\J*@H@
M("`@*B!!(&QI<W1E;F5R)W,@:61E;G1I9FEE<@H@("`@*B!`=F%R('-T<FEN
M9PH@("`@*B\*("`@('9A<B`D7VED.PH*("`@+RHJ"B`@("`J($-O;G-T<G5C
M=&]R+"!S971S('1H92!O8FIE8W0G<R!I9&5N=&EF:65R"B`@("`J"B`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@2%144%]297%U
M97-T7TQI<W1E;F5R*"D*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U
M*'5N:7%I9"@G:'1T<%]R97%U97-T7R<L(#$I*3L*("`@('T*"@H@("`O*BH*
M("`@("H@4F5T=7)N<R!T:&4@;&ES=&5N97(G<R!I9&5N=&EF:65R"B`@("`J
M"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@<W1R:6YG"B`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T260H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VED.PH@("`@?0H*"B`@("\J*@H@("`@*B!4:&ES(&UE=&AO
M9"!I<R!C86QL960@=VAE;B!,:7-T96YE<B!I<R!N;W1I9FEE9"!O9B!A;B!E
M=F5N=`H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!P87)A
M;2`@("!O8FIE8W0@(&%N(&]B:F5C="!T:&4@;&ES=&5N97(@:7,@871T86-H
M960@=&\*("`@("H@0'!A<F%M("`@('-T<FEN9R`@179E;G0@;F%M90H@("`@
M*B!`<&%R86T@("`@;6EX960@("!!9&1I=&EO;F%L(&1A=&$*("`@("H@0&%B
M<W1R86-T"B`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E*"8D<W5B:F5C="P@
M)&5V96YT+"`D9&%T82`](&YU;&PI"B`@("!["B`@("`@("`@96-H;R`B3F]T
M:69I960@;V8@979E;G0Z("<D979E;G0G7&XB.PH@("`@("`@(&EF("AN=6QL
M("$]/2`D9&%T82D@>PH@("`@("`@("`@("!E8VAO(")!9&1I=&EO;F%L(&1A
M=&$Z("(["B`@("`@("`@("`@('9A<E]D=6UP*"1D871A*3L*("`@("`@("!]
M"B`@("!]"GT*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O2%144"]297%U97-T+G!H<```
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#$Q,C(`,3`T
M,3<S-C,P,#<`,#(P,C4V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,RP@4FEC:&%R9"!(
M97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($%L
M;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O
M=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO
M+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T
M('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU
M<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(N("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N
M<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P
M>7)I9VAT("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O
M('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O
M=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE
M<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O
M<B!P<F]M;W1E("`@("`@?`HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M
M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N
M("!\"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@
M4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"
M551/4E,@("!\"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U0
M3$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P*+R\@
M?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(
M04Y404))3$E462!!3D0@1DE43D534R!&3U(@?`HO+R!\($$@4$%25$E#54Q!
M4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!4
M2$4@0T]065))1TA4("!\"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%
M($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL
M('P*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@
M1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@("`@?`HO+R!\($Q)34E4
M140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T52
M5DE#15,[($Q/4U,@3T8@55-%+"!\"B\O('P@1$%402P@3U(@4%)/1DE44SL@
M3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@
M3TX@04Y9('P*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.
M($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`HO+R!\
M("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@
M24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\"B\O('P@3T8@5$A)4R!33T94
M5T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!3
M54-(($1!34%'12X@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+PHO+R`D260Z(%)E<75E<W0N<&AP+'8@,2XS,R`R,#`S+S$P
M+S(V(#$P.C(X.C(X(&%V8B!%>'`@)`HO+PHO+R!(5%107U)E<75E<W0@0VQA
M<W,*+R\*+R\@4VEM<&QE(&5X86UP;&4L("A&971C:&5S('EA:&]O+F-O;2!A
M;F0@9&ES<&QA>7,@:70I.@HO+PHO+R`D82`]("9N97<@2%144%]297%U97-T
M*"=H='1P.B\O=W=W+GEA:&]O+F-O;2\G*3L*+R\@)&$M/G-E;F1297%U97-T
M*"D["B\O(&5C:&\@)&$M/F=E=%)E<W!O;G-E0F]D>2@I.PHO+PH*<F5Q=6ER
M95]O;F-E*"=.970O4V]C:V5T+G!H<"<I.PIR97%U:7)E7V]N8V4H)TYE="]5
M4DPN<&AP)RD["@ID969I;F4H)TA45%!?4D5154535%]-151(3T1?1T54)RP@
M("`@("='150G+"`@("`@=')U92D["F1E9FEN92@G2%144%]215%515-47TU%
M5$A/1%](14%$)RP@("`@)TA%040G+"`@("!T<G5E*3L*9&5F:6YE*"=(5%10
M7U)%455%4U1?34542$]$7U!/4U0G+"`@("`G4$]35"<L("`@('1R=64I.PID
M969I;F4H)TA45%!?4D5154535%]-151(3T1?4%54)RP@("`@("=0550G+"`@
M("`@=')U92D["F1E9FEN92@G2%144%]215%515-47TU%5$A/1%]$14Q%5$4G
M+"`@)T1%3$5412<L("!T<G5E*3L*9&5F:6YE*"=(5%107U)%455%4U1?3454
M2$]$7T]05$E/3E,G+"`G3U!424].4R<L('1R=64I.PID969I;F4H)TA45%!?
M4D5154535%]-151(3T1?5%)!0T4G+"`@("=44D%#12<L("`@=')U92D["@ID
M969I;F4H)TA45%!?4D5154535%](5%107U9%4E\Q7S`G+"`G,2XP)RP@=')U
M92D["F1E9FEN92@G2%144%]215%515-47TA45%!?5D527S%?,2<L("<Q+C$G
M+"!T<G5E*3L*"F-L87-S($A45%!?4F5Q=65S="!["@H@("`@+RHJ"B`@("`J
M($9U;&P@=7)L"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?
M=7)L.PH*("`@("\J*@H@("`@*B!4>7!E(&]F(')E<75E<W0*("`@("H@0'9A
M<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]M971H;V0["@H@("`@+RHJ"B`@
M("`J($A45%`@5F5R<VEO;@H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@
M('9A<B`D7VAT='`["@H@("`@+RHJ"B`@("`J(%)E<75E<W0@:&5A9&5R<PH@
M("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?<F5Q=65S=$AE861E
M<G,["@H@("`@+RHJ"B`@("`J($)A<VEC($%U=&@@57-E<FYA;64*("`@("H@
M0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]U<V5R.PH@("`@"B`@("`O
M*BH*("`@("H@0F%S:6,@075T:"!087-S=V]R9`H@("`@*B!`=F%R('-T<FEN
M9PH@("`@*B\*("`@('9A<B`D7W!A<W,["@H@("`@+RHJ"B`@("`J(%-O8VME
M="!O8FIE8W0*("`@("H@0'9A<B!O8FIE8W0*("`@("HO"B`@("!V87(@)%]S
M;V-K.PH@("`@"B`@("`O*BH*("`@("H@4')O>'D@<V5R=F5R"B`@("`J($!V
M87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?<')O>'E?:&]S=#L*("`@(`H@
M("`@+RHJ"B`@("`J(%!R;WAY('!O<G0*("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`J+PH@("`@=F%R("1?<')O>'E?<&]R=#L*("`@(`H@("`@+RHJ"B`@("`J
M(%!R;WAY('5S97)N86UE"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@
M=F%R("1?<')O>'E?=7-E<CL*("`@(`H@("`@+RHJ"B`@("`J(%!R;WAY('!A
M<W-W;W)D"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?<')O
M>'E?<&%S<SL*"B`@("`O*BH*("`@("H@4&]S="!D871A"B`@("`J($!V87(@
M;6EX960*("`@("HO"B`@("!V87(@)%]P;W-T1&%T83L*"B`@("\J*@H@("`@
M*B!&:6QE<R!T;R!P;W-T(`H@("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@
M=F%R("1?<&]S=$9I;&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("H@0V]N
M;F5C=&EO;B!T:6UE;W5T+@H@("`@*B!`=F%R(&EN=&5G97(*("`@("HO"B`@
M("!V87(@)%]T:6UE;W5T.PH@("`@"B`@("`O*BH*("`@("H@2%144%]297-P
M;VYS92!O8FIE8W0*("`@("H@0'9A<B!O8FIE8W0*("`@("HO"B`@("!V87(@
M)%]R97-P;VYS93L*("`@(`H@("`@+RHJ"B`@("`J(%=H971H97(@=&\@86QL
M;W<@<F5D:7)E8W1S"B`@("`J($!V87(@8F]O;&5A;@H@("`@*B\*("`@('9A
M<B`D7V%L;&]W4F5D:7)E8W1S.PH@("`@"B`@("`O*BH*("`@("H@36%X:6UU
M;2!R961I<F5C=',@86QL;W=E9`H@("`@*B!`=F%R(&EN=&5G97(*("`@("HO
M"B`@("!V87(@)%]M87A2961I<F5C=',["B`@("`*("`@("\J*@H@("`@*B!#
M=7)R96YT(&YU;6)E<B!O9B!R961I<F5C=',*("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`J+PH@("`@=F%R("1?<F5D:7)E8W1S.PH*("`@+RHJ"B`@("`J(%=H
M971H97(@=&\@87!P96YD(&)R86-K971S(%M=('1O(&%R<F%Y('9A<FEA8FQE
M<PH@("`@*B!`=F%R(&)O;VP*("`@("HO"B`@("!V87(@)%]U<V5"<F%C:V5T
M<R`]('1R=64["@H@("`O*BH*("`@("H@071T86-H960@;&ES=&5N97)S"B`@
M("`J($!V87(@87)R87D*("`@("HO"B`@("!V87(@)%]L:7-T96YE<G,@/2!A
M<G)A>2@I.PH*("`@+RHJ"B`@("`J(%=H971H97(@=&\@<V%V92!R97-P;VYS
M92!B;V1Y(&EN(')E<W!O;G-E(&]B:F5C="!P<F]P97)T>2`@"B`@("`J($!V
M87(@8F]O;`H@("`@*B\*("`@('9A<B`D7W-A=F5";V1Y(#T@=')U93L*"B`@
M("`O*BH*("`@("H@0V]N<W1R=6-T;W(*("`@("H*("`@("H@4V5T<R!U<"!T
M:&4@;V)J96-T"B`@("`J($!P87)A;2`D=7)L(%1H92!U<FP@=&\@9F5T8V@O
M86-C97-S"B`@("`J($!P87)A;2`D<&%R86US($%S<V]C:6%T:79E(&%R<F%Y
M(&]F('!A<F%M971E<G,@=VAI8V@@8V%N(&)E.@H@("`@*B`@("`@("`@("`@
M("`@("`@(&UE=&AO9"`@("`@("`@("T@365T:&]D('1O('5S92P@1T54+"!0
M3U-4(&5T8PH@("`@*B`@("`@("`@("`@("`@("`@(&AT='`@("`@("`@("`@
M("T@2%144"!697)S:6]N('1O('5S92P@,2XP(&]R(#$N,0H@("`@*B`@("`@
M("`@("`@("`@("`@('5S97(@("`@("`@("`@("T@0F%S:6,@075T:"!U<V5R
M;F%M90H@("`@*B`@("`@("`@("`@("`@("`@('!A<W,@("`@("`@("`@("T@
M0F%S:6,@075T:"!P87-S=V]R9`H@("`@*B`@("`@("`@("`@("`@("`@('!R
M;WAY7VAO<W0@("`@("T@4')O>'D@<V5R=F5R(&AO<W0*("`@("H@("`@("`@
M("`@("`@("`@("!P<F]X>5]P;W)T("`@("`M(%!R;WAY('-E<G9E<B!P;W)T
M"B`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?=7-E<B`@("`@+2!0<F]X
M>2!A=71H('5S97)N86UE"B`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?
M<&%S<R`@("`@+2!0<F]X>2!A=71H('!A<W-W;W)D"B`@("`J("`@("`@("`@
M("`@("`@("`@=&EM96]U="`@("`@("`@+2!#;VYN96-T:6]N('1I;65O=70@
M:6X@<V5C;VYD<RX*("`@("H@("`@("`@("`@("`@("`@("!A;&QO=U)E9&ER
M96-T<R`M(%=H971H97(@=&\@9F]L;&]W(')E9&ER96-T<R!O<B!N;W0*("`@
M("H@("`@("`@("`@("`@("`@("!M87A2961I<F5C=',@("`M($UA>"!N=6UB
M97(@;V8@<F5D:7)E8W1S('1O(&9O;&QO=PH@("`@*B`@("`@("`@("`@("`@
M("`@('5S94)R86-K971S("`@("T@5VAE=&AE<B!T;R!A<'!E;F0@6UT@=&\@
M87)R87D@=F%R:6%B;&4@;F%M97,*("`@("H@("`@("`@("`@("`@("`@("!S
M879E0F]D>2`@("`@("`M(%=H971H97(@=&\@<V%V92!R97-P;VYS92!B;V1Y
M(&EN(')E<W!O;G-E(&]B:F5C="!P<F]P97)T>0H@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N($A45%!?4F5Q=65S="@D=7)L+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W-O8VL@
M("`@("`@("`@(#T@)FYE=R!.971?4V]C:V5T*"D["B`@("`@("`@)'1H:7,M
M/E]M971H;V0@("`@("`@("`]("!(5%107U)%455%4U1?34542$]$7T=%5#L*
M("`@("`@("`D=&AI<RT^7VAT='`@("`@("`@("`@(#T@($A45%!?4D515453
M5%](5%107U9%4E\Q7S$["B`@("`@("`@)'1H:7,M/E]R97%U97-T2&5A9&5R
M<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]P;W-T1&%T82`@("`@("`]
M(&YU;&P["@H@("`@("`@("1T:&ES+3Y?=7-E<B`](&YU;&P["B`@("`@("`@
M)'1H:7,M/E]P87-S(#T@;G5L;#L*"B`@("`@("`@)'1H:7,M/E]P<F]X>5]H
M;W-T(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7W!R;WAY7W!O<G0@/2!N=6QL
M.PH@("`@("`@("1T:&ES+3Y?<')O>'E?=7-E<B`](&YU;&P["B`@("`@("`@
M)'1H:7,M/E]P<F]X>5]P87-S(#T@;G5L;#L*"B`@("`@("`@)'1H:7,M/E]A
M;&QO=U)E9&ER96-T<R`](&9A;'-E.PH@("`@("`@("1T:&ES+3Y?;6%X4F5D
M:7)E8W1S("`@/2`S.PH@("`@("`@("1T:&ES+3Y?<F5D:7)E8W1S("`@("`@
M/2`P.PH*("`@("`@("`D=&AI<RT^7W1I;65O=70@(#T@;G5L;#L*("`@("`@
M("`D=&AI<RT^7W)E<W!O;G-E(#T@;G5L;#L*"B`@("`@("`@9F]R96%C:"`H
M)'!A<F%M<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=&AI
M<RT^>R=?)R`N("1K97E](#T@)'9A;'5E.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/G-E=%523"@D=7)L*3L*"B`@("`@("`@+R\@1&5F875L="!U<V5R
M86=E;G0*("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=5<V5R+4%G96YT)RP@
M)U!%05(@2%144%]297%U97-T(&-L87-S("@@:'1T<#HO+W!E87(N<&AP+FYE
M="\@*2<I.PH*("`@("`@("`O+R!$969A=6QT($-O;G1E;G0M5'EP90H@("`@
M("`@("1T:&ES+3YA9&1(96%D97(H)T-O;G1E;G0M5'EP92<L("=A<'!L:6-A
M=&EO;B]X+7=W=RUF;W)M+75R;&5N8V]D960G*3L*"B`@("`@("`@+R\@36%K
M92!S=7)E(&ME97!A;&EV97,@9&]N="!K;F]B8FQE('5S"B`@("`@("`@)'1H
M:7,M/F%D9$AE861E<B@G0V]N;F5C=&EO;B<L("=C;&]S92<I.PH*("`@("`@
M("`O+R!"87-I8R!A=71H96YT:6-A=&EO;@H@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]U<V5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)E<75E<W1(
M96%D97)S6R=!=71H;W)I>F%T:6]N)UT@/2`G0F%S:6,@)R`N(&)A<V4V-%]E
M;F-O9&4H)'1H:7,M/E]U<V5R("X@)SHG("X@)'1H:7,M/E]P87-S*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%5S92!G>FEP(&5N8V]D:6YG(&EF('!O<W-I
M8FQE"B`@("`@("`@:68@*$A45%!?4D5154535%](5%107U9%4E\Q7S$@/3T@
M)'1H:7,M/E]H='1P("8F(&5X=&5N<VEO;E]L;V%D960H)WIL:6(G*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=!8V-E<'0M16YC;V1I;F<G
M+"`G9WII<"<I.PH@("`@("`@('T*("`@('T*("`@(`H@("`@+RHJ"B`@("`J
M($=E;F5R871E<R!A($AO<W0@:&5A9&5R(&9O<B!(5%10+S$N,2!R97%U97-T
M<PH@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0')E='5R;B!S
M=')I;F<*("`@("HO"B`@("!F=6YC=&EO;B!?9V5N97)A=&5(;W-T2&5A9&5R
M*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]U<FPM/G!O<G0@(3T@.#`@
M04Y$('-T<F-A<V5C;7`H)'1H:7,M/E]U<FPM/G!R;W1O8V]L+"`G:'1T<"<I
M(#T](#`I('L*("`@("`@("`@("`@)&AO<W0@/2`D=&AI<RT^7W5R;"T^:&]S
M="`N("<Z)R`N("1T:&ES+3Y?=7)L+3YP;W)T.PH*("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]U<FPM/G!O<G0@(3T@-#0S($%.1"!S=')C87-E8VUP*"1T
M:&ES+3Y?=7)L+3YP<F]T;V-O;"P@)VAT='!S)RD@/3T@,"D@>PH@("`@("`@
M("`@("`D:&]S="`]("1T:&ES+3Y?=7)L+3YH;W-T("X@)SHG("X@)'1H:7,M
M/E]U<FPM/G!O<G0["@H@("`@("`@('T@96QS96EF("@D=&AI<RT^7W5R;"T^
M<&]R="`]/2`T-#,@04Y$('-T<F-A<V5C;7`H)'1H:7,M/E]U<FPM/G!R;W1O
M8V]L+"`G:'1T<',G*2`]/2`P($%.1"!S=')P;W,H)'1H:7,M/E]U<FPM/G5R
M;"P@)SHT-#,G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)&AO<W0@/2`D
M=&AI<RT^7W5R;"T^:&]S="`N("<Z)R`N("1T:&ES+3Y?=7)L+3YP;W)T.PH@
M("`@("`@(`H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H;W-T(#T@
M)'1H:7,M/E]U<FPM/FAO<W0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&AO<W0["B`@("!]"B`@("`*("`@("\J*@H@("`@*B!297-E=',@=&AE(&]B
M:F5C="!T;R!I=',@:6YI=&EA;"!S=&%T92`H1$504D5#051%1"DN"B`@("`J
M(%1A:V5S('1H92!S86UE('!A<F%M971E<G,@87,@=&AE(&-O;G-T<G5C=&]R
M+@H@("`@*@H@("`@*B!`<&%R86T@('-T<FEN9R`D=7)L("`@(%1H92!U<FP@
M=&\@8F4@<F5Q=65S=&5D"B`@("`J($!P87)A;2`@87)R87D@("1P87)A;7,@
M07-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R<PH@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("AS964@8V]N<W1R=6-T;W(@9F]R(&1E=&%I;',I
M"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!D97!R96-A=&5D(&1E<')E
M8V%T960@<VEN8V4@,2XR+"!C86QL('1H92!C;VYS=')U8W1O<B!I9B!T:&ES
M(&ES(&YE8V5S<V%R>0H@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T*"1U<FPL
M("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y(5%10
M7U)E<75E<W0H)'5R;"P@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`J
M(%-E=',@=&AE(%523"!T;R!B92!R97%U97-T960*("`@("H*("`@("H@0'!A
M<F%M("!S=')I;F<@5&AE('5R;"!T;R!B92!R97%U97-T960*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S97154DPH)'5R;"D*
M("`@('L*("`@("`@("`D=&AI<RT^7W5R;"`]("9N97<@3F5T7U523"@D=7)L
M+"`D=&AI<RT^7W5S94)R86-K971S*3L*"B`@("`@("`@+R\@268@<&]R="!I
M<R`X,"!A;F0@<')O=&]C;VP@:7,@:'1T<',L(&%S<W5M92!P;W)T(#0T,R!I
M<R!T;R!B92!U<V5D"B`@("`@("`@+R\@5&AI<R!D;V5S(&UE86X@>6]U(&-A
M;B=T('-E;F0@86X@:'1T<',@<F5Q=65S="!T;R!P;W)T(#@P('=I=&AO=70*
M("`@("`@("`O+R!S;VUE(&9U9&=E+B`H;6UM+BXN*0H@("`@("`@(&EF("AS
M=')C87-E8VUP*"1T:&ES+3Y?=7)L+3YP<F]T;V-O;"P@)VAT='!S)RD@/3T@
M,"!!3D0@)'1H:7,M/E]U<FPM/G!O<G0@/3T@.#`I('L*("`@("`@("`@("`@
M)'1H:7,M/E]U<FPM/G!O<G0@/2`T-#,["B`@("`@("`@?0H@("`@("`@(&EF
M("A(5%107U)%455%4U1?2%144%]615)?,5\Q(#T]("1T:&ES+3Y?:'1T<"D@
M>PH@("`@("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=(;W-T)RP@)'1H:7,M
M/E]G96YE<F%T94AO<W1(96%D97(H*2D["B`@("`@("`@?0H@("`@?0H@("`@
M"B`@("`O*BH*("`@("H@4V5T<R!A('!R;WAY('1O(&)E('5S960*("`@("H*
M("`@("H@0'!A<F%M('-T<FEN9R`@("`@4')O>'D@:&]S=`H@("`@*B!`<&%R
M86T@:6YT("`@("`@("!0<F]X>2!P;W)T"B`@("`J($!P87)A;2!S=')I;F<@
M("`@(%!R;WAY('5S97)N86UE"B`@("`J($!P87)A;2!S=')I;F<@("`@(%!R
M;WAY('!A<W-W;W)D"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T4')O>'DH)&AO<W0L("1P;W)T(#T@.#`X,"P@)'5S97(@
M/2!N=6QL+"`D<&%S<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]P
M<F]X>5]H;W-T(#T@)&AO<W0["B`@("`@("`@)'1H:7,M/E]P<F]X>5]P;W)T
M(#T@)'!O<G0["B`@("`@("`@)'1H:7,M/E]P<F]X>5]U<V5R(#T@)'5S97([
M"B`@("`@("`@)'1H:7,M/E]P<F]X>5]P87-S(#T@)'!A<W,["@H@("`@("`@
M(&EF("@A96UP='DH)'5S97(I*2!["B`@("`@("`@("`@("1T:&ES+3YA9&1(
M96%D97(H)U!R;WAY+4%U=&AO<FEZ871I;VXG+"`G0F%S:6,@)R`N(&)A<V4V
M-%]E;F-O9&4H)'5S97(@+B`G.B<@+B`D<&%S<RDI.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("H@4V5T<R!B87-I8R!A=71H96YT:6-A=&EO;B!P
M87)A;65T97)S"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@("`@(%5S97)N
M86UE"B`@("`J($!P87)A;2!S=')I;F<@("`@(%!A<W-W;W)D"B`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T0F%S:6-!=71H*"1U<V5R+"`D<&%S<RD*("`@('L*
M("`@("`@("`D=&AI<RT^7W5S97(@/2`D=7-E<CL*("`@("`@("`D=&AI<RT^
M7W!A<W,@/2`D<&%S<SL*"B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G075T
M:&]R:7IA=&EO;B<L("="87-I8R`G("X@8F%S938T7V5N8V]D92@D=7-E<B`N
M("<Z)R`N("1P87-S*2D["B`@("!]"@H@("`@+RHJ"B`@("`J(%-E=',@=&AE
M(&UE=&AO9"!T;R!B92!U<V5D+"!'150L(%!/4U0@971C+@H@("`@*@H@("`@
M*B!`<&%R86T@<W1R:6YG("`@("!-971H;V0@=&\@=7-E+B!5<V4@=&AE(&1E
M9FEN960@8V]N<W1A;G1S(&9O<B!T:&ES"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T365T:&]D*"1M971H;V0I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]M971H;V0@/2`D;65T:&]D.PH@("`@?0H*("`@
M("\J*@H@("`@*B!3971S('1H92!(5%10('9E<G-I;VX@=&\@=7-E+"`Q+C`@
M;W(@,2XQ"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@("`@(%9E<G-I;VX@
M=&\@=7-E+B!5<V4@=&AE(&1E9FEN960@8V]N<W1A;G1S(&9O<B!T:&ES"B`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T2'1T
M<%9E<B@D:'1T<"D*("`@('L*("`@("`@("`D=&AI<RT^7VAT='`@/2`D:'1T
M<#L*("`@('T*"B`@("`O*BH*("`@("H@061D<R!A(')E<75E<W0@:&5A9&5R
M"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@("`@($AE861E<B!N86UE"B`@
M("`J($!P87)A;2!S=')I;F<@("`@($AE861E<B!V86QU90H@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&%D9$AE861E<B@D;F%M
M92P@)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5Q=65S=$AE861E
M<G-;)&YA;65=(#T@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@*B!296UO
M=F5S(&$@<F5Q=65S="!H96%D97(*("`@("H*("`@("H@0'!A<F%M('-T<FEN
M9R`@("`@2&5A9&5R(&YA;64@=&\@<F5M;W9E"B`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E2&5A9&5R*"1N86UE*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W)E<75E<W1(96%D97)S
M6R1N86UE72DI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]R97%U97-T
M2&5A9&5R<ULD;F%M95TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("H@061D<R!A('%U97)Y<W1R:6YG('!A<F%M971E<@H@("`@*@H@("`@*B!`
M<&%R86T@<W1R:6YG("`@("!1=65R>7-T<FEN9R!P87)A;65T97(@;F%M90H@
M("`@*B!`<&%R86T@<W1R:6YG("`@("!1=65R>7-T<FEN9R!P87)A;65T97(@
M=F%L=64*("`@("H@0'!A<F%M(&)O;VP@("`@("`@5VAE=&AE<B!T:&4@=F%L
M=64@:7,@86QR96%D>2!U<FQE;F-O9&5D(&]R(&YO="P@9&5F875L="`](&YO
M=`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9%%U97)Y4W1R:6YG*"1N86UE+"`D=F%L=64L("1P<F5E;F-O9&5D(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]U<FPM/F%D9%%U97)Y4W1R:6YG
M*"1N86UE+"`D=F%L=64L("1P<F5E;F-O9&5D*3L*("`@('T@("`@"B`@("`*
M("`@("\J*@H@("`@*B!3971S('1H92!Q=65R>7-T<FEN9R!T;R!L:71E<F%L
M;'D@=VAA="!Y;W4@<W5P<&QY"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@
M("`@(%1H92!Q=65R>7-T<FEN9R!D871A+B!3:&]U;&0@8F4@;V8@=&AE(&9O
M<FUA="!F;V\]8F%R)G@]>2!E=&,*("`@("H@0'!A<F%M(&)O;VP@("`@("`@
M5VAE=&AE<B!D871A(&ES(&%L<F5A9'D@=7)L96YC;V1E9"!O<B!N;W0L(&1E
M9F%U;'0@/2!A;')E861Y(&5N8V]D960*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1287=1=65R>5-T<FEN9R@D<75E<GES
M=')I;F<L("1P<F5E;F-O9&5D(#T@=')U92D*("`@('L*("`@("`@("`D=&AI
M<RT^7W5R;"T^861D4F%W475E<GE3=')I;F<H)'%U97)Y<W1R:6YG+"`D<')E
M96YC;V1E9"D["B`@("!]"@H@("`@+RHJ"B`@("`J($%D9',@<&]S=&1A=&$@
M:71E;7,*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`@("`@4&]S="!D871A
M(&YA;64*("`@("H@0'!A<F%M('-T<FEN9R`@("`@4&]S="!D871A('9A;'5E
M"B`@("`J($!P87)A;2!B;V]L("`@("`@(%=H971H97(@9&%T82!I<R!A;')E
M861Y('5R;&5N8V]D960@;W(@;F]T+"!D969A=6QT(#T@;F]T"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@861D4&]S=$1A=&$H
M)&YA;64L("1V86QU92P@)'!R965N8V]D960@/2!F86QS92D*("`@('L*("`@
M("`@("!I9B`H)'!R965N8V]D960I('L*("`@("`@("`@("`@)'1H:7,M/E]P
M;W-T1&%T85LD;F%M95T@/2`D=F%L=64["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/E]P;W-T1&%T85LD;F%M95T@/2!I<U]A<G)A>2@D
M=F%L=64I/R!A<G)A>5]M87`H)W5R;&5N8V]D92<L("1V86QU92DZ('5R;&5N
M8V]D92@D=F%L=64I.PH@("`@("`@('T*("`@('T*"B`@("\J*@H@("`@*B!!
M9&1S(&$@9FEL92!T;R!U<&QO860*("`@("H@"B`@("`J(%1H:7,@86QS;R!C
M:&%N9V5S(&-O;G1E;G0M='EP92!T;R`G;75L=&EP87)T+V9O<FTM9&%T82<@
M9F]R('!R;W!E<B!U<&QO860*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J($!P87)A;2`@<W1R:6YG("`@('9A<FEA8FQE(&YA;64*("`@("H@
M0'!A<F%M("!M:7AE9"`@("`@9FEL92!N86UE*',I"B`@("`J($!P87)A;2`@
M;6EX960@("`@(&-O;G1E;G0M='EP92AS*2!O9B!F:6QE*',I(&)E:6YG('5P
M;&]A9&5D"B`@("`J($!R971U<FX@8F]O;"`@("`@('1R=64@;VX@<W5C8V5S
M<PH@("`@*B!`=&AR;W=S(%!%05)?17)R;W(*("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1&:6QE*"1N86UE+"`D9FEL96YA;64L("1C;VYT96YT5'EP92`]("=A
M<'!L:6-A=&EO;B]O8W1E="US=')E86TG*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?87)R87DH)&9I;&5N86UE*2`F)B`A:7-?<F5A9&%B;&4H)&9I;&5N86UE
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL
M92`G>R1F:6QE;F%M97TG(&ES(&YO="!R96%D86)L92(I.PH@("`@("`@('T@
M96QS96EF("AI<U]A<G)A>2@D9FEL96YA;64I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1F:6QE;F%M92!A<R`D;F%M92D@>PH@("`@("`@("`@("`@("`@
M:68@*"%I<U]R96%D86)L92@D;F%M92DI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92`G>R1N86UE?2<@:7,@
M;F]T(')E861A8FQE(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G0V]N=&5N
M="U4>7!E)RP@)VUU;'1I<&%R="]F;W)M+61A=&$G*3L*("`@("`@("`D=&AI
M<RT^7W!O<W1&:6QE<ULD;F%M95T@/2!A<G)A>2@*("`@("`@("`@("`@)VYA
M;64G(#T^("1F:6QE;F%M92P*("`@("`@("`@("`@)W1Y<&4G(#T^("1C;VYT
M96YT5'EP90H@("`@("`@("D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`J($%D9',@<F%W('!O<W1D871A"B`@("`J"B`@("`J
M($!P87)A;2!S=')I;F<@("`@(%1H92!D871A"B`@("`J($!P87)A;2!B;V]L
M("`@("`@(%=H971H97(@9&%T82!I<R!P<F5E;F-O9&5D(&]R(&YO="P@9&5F
M875L="`](&%L<F5A9'D@96YC;V1E9`H@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9%)A=U!O<W1$871A*"1P;W-T9&%T82P@
M)'!R965N8V]D960@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&]S
M=$1A=&$@/2`D<')E96YC;V1E9"`_("1P;W-T9&%T82`Z('5R;&5N8V]D92@D
M<&]S=&1A=&$I.PH@("`@?0H*("`@("\J*@H@("`@*B!#;&5A<G,@86YY('!O
M<W1D871A('1H870@:&%S(&)E96X@861D960@*$1%4%)%0T%4140I+B`*("`@
M("H@"B`@("`J(%5S969U;"!F;W(@;75L=&EP;&4@<F5Q=65S="!S8V5N87)I
M;W,N"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!D97!R96-A
M=&5D(&1E<')E8V%T960@<VEN8V4@,2XR"B`@("`J+PH@("`@9G5N8W1I;VX@
M8VQE87)0;W-T1&%T82@I"B`@("!["B`@("`@("`@)'1H:7,M/E]P;W-T1&%T
M82`](&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`J($%P<&5N9',@82!C;V]K
M:64@=&\@(D-O;VMI93HB(&AE861E<@H@("`@*B`*("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92!C;V]K:64@;F%M90H@("`@*B!`<&%R86T@<W1R:6YG("1V
M86QU92!C;V]K:64@=F%L=64*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO
M"B`@("!F=6YC=&EO;B!A9&1#;V]K:64H)&YA;64L("1V86QU92D*("`@('L*
M("`@("`@("`D8V]O:VEE<R`](&ES<V5T*"1T:&ES+3Y?<F5Q=65S=$AE861E
M<G-;)T-O;VMI92==*2`_("1T:&ES+3Y?<F5Q=65S=$AE861E<G-;)T-O;VMI
M92==+B`G.R`G(#H@)R<["B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G0V]O
M:VEE)RP@)&-O;VMI97,@+B!U<FQE;F-O9&4H)&YA;64I("X@)STG("X@=7)L
M96YC;V1E*"1V86QU92DI.PH@("`@?0H@("`@"B`@("`O*BH*("`@("H@0VQE
M87)S(&%N>2!C;V]K:65S('1H870@:&%V92!B965N(&%D9&5D("A$15!214-!
M5$5$*2X@"B`@("`J(`H@("`@*B!5<V5F=6P@9F]R(&UU;'1I<&QE(')E<75E
M<W0@<V-E;F%R:6]S"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J
M($!D97!R96-A=&5D(&1E<')E8V%T960@<VEN8V4@,2XR"B`@("`J+PH@("`@
M9G5N8W1I;VX@8VQE87)#;V]K:65S*"D*("`@('L*("`@("`@("`D=&AI<RT^
M<F5M;W9E2&5A9&5R*"=#;V]K:64G*3L*("`@('T*"B`@("`O*BH*("`@("H@
M4V5N9',@=&AE(')E<75E<W0*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("H@0'!A<F%M("!B;V]L("`@5VAE=&AE<B!T;R!S=&]R92!R97-P;VYS
M92!B;V1Y(&EN(%)E<W!O;G-E(&]B:F5C="!P<F]P97)T>2P*("`@("H@("`@
M("`@("`@("`@("`@<V5T('1H:7,@=&\@9F%L<V4@:68@9&]W;FQO861I;F<@
M82!,05)'12!F:6QE(&%N9"!U<VEN9R!A($QI<W1E;F5R"B`@("`J($!R971U
M<FX@;6EX960@(%!%05(@97)R;W(@;VX@97)R;W(L('1R=64@;W1H97)W:7-E
M"B`@("`J+PH@("`@9G5N8W1I;VX@<V5N9%)E<75E<W0H)'-A=F5";V1Y(#T@
M=')U92D*("`@('L*("`@("`@("`D:&]S="`](&ES<V5T*"1T:&ES+3Y?<')O
M>'E?:&]S="D@/R`D=&AI<RT^7W!R;WAY7VAO<W0@.B`D=&AI<RT^7W5R;"T^
M:&]S=#L*("`@("`@("`D<&]R="`](&ES<V5T*"1T:&ES+3Y?<')O>'E?<&]R
M="D@/R`D=&AI<RT^7W!R;WAY7W!O<G0@.B`D=&AI<RT^7W5R;"T^<&]R=#L*
M"B`@("`@("`@+R\@-"XS+C`@<W5P<&]R=',@4U-,(&-O;FYE8W1I;VYS('5S
M:6YG($]P96Y34TPN(%1H92!F=6YC=&EO;B!T97-T(&1E=&5R;6EN97,*("`@
M("`@("`O+R!W92!R=6YN:6YG(&]N(&%T(&QE87-T(#0N,RXP"B`@("`@("`@
M:68@*'-T<F-A<V5C;7`H)'1H:7,M/E]U<FPM/G!R;W1O8V]L+"`G:'1T<',G
M*2`]/2`P($%.1"!F=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S
M)RD@04Y$(&5X=&5N<VEO;E]L;V%D960H)V]P96YS<VPG*2D@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F]X>5]H;W-T*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TA45%!3('!R;WAI
M97,@87)E(&YO="!S=7!P;W)T960N)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&AO<W0@/2`G<W-L.B\O)R`N("1H;W-T.PH@("`@("`@('T*"B`@
M("`@("`@+R\@268@=&AI<R!I<R!A('-E8V]N9"!R97%U97-T+"!W92!M87D@
M9V5T(&%W87D@=VET:&]U=`H@("`@("`@("\O(')E+6-O;FYE8W1I;F<@:68@
M=&AE>2=R92!O;B!T:&4@<V%M92!S97)V97(*("`@("`@("!I9B`H("`@4$5!
M4CHZ:7-%<G)O<B@D97)R(#T@)'1H:7,M/E]S;V-K+3YC;VYN96-T*"1H;W-T
M+"`D<&]R="P@;G5L;"P@)'1H:7,M/E]T:6UE;W5T*2D*("`@("`@("`@("`@
M3U(@4$5!4CHZ:7-%<G)O<B@D97)R(#T@)'1H:7,M/E]S;V-K+3YW<FET92@D
M=&AI<RT^7V)U:6QD4F5Q=65S="@I*2D@*2!["@H@("`@("`@("`@(')E='5R
M;B`D97)R.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]N;W1I9GDH)W-E
M;G1297%U97-T)RD["@H@("`@("`@("\O(%)E860@=&AE(')E<W!O;G-E"B`@
M("`@("`@)'1H:7,M/E]R97-P;VYS92`]("9N97<@2%144%]297-P;VYS92@D
M=&AI<RT^7W-O8VLL("1T:&ES+3Y?;&ES=&5N97)S*3L*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R(#T@)'1H:7,M/E]R97-P;VYS92T^<')O8V5S
M<R@D=&AI<RT^7W-A=F5";V1Y("8F("1S879E0F]D>2DI("D@>PH@("`@("`@
M("`@("!R971U<FX@)&5R<CL*("`@("`@("!]"@H@("`@("`@("\O($-H96-K
M(&9O<B!R961I<F5C=&EO;@H@("`@("`@("\O($)U9V9I>"`H4$5!4BD@8G5G
M(",Q."P@-B!O8W0@,C`P,R!B>2!$879E($UE<G1E;G,@*&AE861E<G,@87)E
M(&%L<V\@<W1O<F5D(&QO=V5R8V%S92P@<V\@=V4G<F4@9V]N;F$@=7-E('1H
M96T@:&5R92D*("`@("`@("`O+R!S;VUE(&YO;B!21D,R-C$V(&-O;7!L:6%N
M="!S97)V97)S("AS8W)I<'1S*2!A<F4@<F5T=7)N:6YG(&QO=V5R8V%S92!H
M96%D97)S("@G;&]C871I;VXZ('AX>"<I"B`@("`@("`@:68@*"`@("`D=&AI
M<RT^7V%L;&]W4F5D:7)E8W1S"B`@("`@("`@("`@($%.1"`D=&AI<RT^7W)E
M9&ER96-T<R`\/2`D=&AI<RT^7VUA>%)E9&ER96-T<PH@("`@("`@("`@("!!
M3D0@)'1H:7,M/F=E=%)E<W!O;G-E0V]D92@I(#X@,S`P"B`@("`@("`@("`@
M($%.1"`D=&AI<RT^9V5T4F5S<&]N<V5#;V1E*"D@/"`S.3D*("`@("`@("`@
M("`@04Y$("%E;7!T>2@D=&AI<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<ULG;&]C
M871I;VXG72DI('L*"B`@("`@("`@("`@(`H@("`@("`@("`@("`D<F5D:7)E
M8W0@/2`D=&AI<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<ULG;&]C871I;VXG73L*
M"B`@("`@("`@("`@("\O($%B<V]L=71E(%523`H@("`@("`@("`@("!I9B`H
M<')E9U]M871C:"@G+UYH='1P<S\Z7"]<+R]I)RP@)')E9&ER96-T*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]U<FP@/2`F;F5W($YE=%]54DPH)')E
M9&ER96-T*3L*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1(96%D97(H)TAO
M<W0G+"`D=&AI<RT^7V=E;F5R871E2&]S=$AE861E<B@I*3L*("`@("`@("`@
M("`@+R\@06)S;VQU=&4@<&%T:`H@("`@("`@("`@("!](&5L<V5I9B`H)')E
M9&ER96-T>S!](#T]("<O)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]U
M<FPM/G!A=&@@/2`D<F5D:7)E8W0["B`@("`@("`@("`@(`H@("`@("`@("`@
M("`O+R!296QA=&EV92!P871H"B`@("`@("`@("`@('T@96QS96EF("AS=6)S
M='(H)')E9&ER96-T+"`P+"`S*2`]/2`G+BXO)R!/4B!S=6)S='(H)')E9&ER
M96-T+"`P+"`R*2`]/2`G+B\G*2!["B`@("`@("`@("`@("`@("!I9B`H<W5B
M<W1R*"1T:&ES+3Y?=7)L+3YP871H+"`M,2D@/3T@)R\G*2!["B`@("`@("`@
M("`@("`@("`@("`@)')E9&ER96-T(#T@)'1H:7,M/E]U<FPM/G!A=&@@+B`D
M<F5D:7)E8W0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1R961I<F5C="`](&1I<FYA;64H)'1H:7,M/E]U<FPM/G!A
M=&@I("X@)R\G("X@)')E9&ER96-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)')E9&ER96-T(#T@3F5T7U523#HZ<F5S;VQV95!A=&@H
M)')E9&ER96-T*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=7)L+3YP871H
M(#T@)')E9&ER96-T.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("\O
M($9I;&5N86UE+"!N;R!P871H"B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!I9B`H<W5B<W1R*"1T:&ES+3Y?=7)L+3YP871H+"`M,2D@
M/3T@)R\G*2!["B`@("`@("`@("`@("`@("`@("`@)')E9&ER96-T(#T@)'1H
M:7,M/E]U<FPM/G!A=&@@+B`D<F5D:7)E8W0["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R961I<F5C="`](&1I<FYA
M;64H)'1H:7,M/E]U<FPM/G!A=&@I("X@)R\G("X@)')E9&ER96-T.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]U<FPM/G!A
M=&@@/2`D<F5D:7)E8W0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M:&ES+3Y?<F5D:7)E8W1S*RL["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<V5N9%)E<75E<W0H)'-A=F5";V1Y*3L*"B`@("`@("`@+R\@5&]O(&UA;GD@
M<F5D:7)E8W1S"B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?86QL;W=2961I
M<F5C=',@04Y$("1T:&ES+3Y?<F5D:7)E8W1S(#X@)'1H:7,M/E]M87A2961I
M<F5C=',I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U1O;R!M86YY(')E9&ER96-T<R<I.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("H@4F5T=7)N
M<R!T:&4@<F5S<&]N<V4@8V]D90H@("`@*@H@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@*B!`<F5T=7)N(&EN=`H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E
M<W!O;G-E0V]D92@I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES
M+3Y?<F5S<&]N<V4M/E]C;V1E*2`_("1T:&ES+3Y?<F5S<&]N<V4M/E]C;V1E
M(#H@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@96ET:&5R
M('1H92!N86UE9"!H96%D97(@;W(@86QL(&EF(&YO(&YA;64@9VEV96X*("`@
M("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@5&AE(&AE861E<B!N86UE('1O(')E='5R;@H@("`@*B!`<F5T=7)N(&UI
M>&5D("`@("!E:71H97(@=&AE('9A;'5E(&]F("1H96%D97)N86UE(&]R(&%N
M(&%R<F%Y(&]F(&%L;"!H96%D97(@=F%L=65S"B`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4F5S<&]N<V5(96%D97(H)&AE861E<FYA;64@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A:7-S970H)&AE861E<FYA;64I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]R
M97-P;VYS92T^7VAE861E<G-;)&AE861E<FYA;65=*2`_("1T:&ES+3Y?<F5S
M<&]N<V4M/E]H96%D97)S6R1H96%D97)N86UE72`Z(&9A;'-E.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@8F]D>2!O9B!T
M:&4@<F5S<&]N<V4*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@
M0')E='5R;B!S=')I;F<*("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS
M94)O9'DH*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W)E
M<W!O;G-E+3Y?8F]D>2D@/R`D=&AI<RT^7W)E<W!O;G-E+3Y?8F]D>2`Z(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@*B!2971U<FYS(&-O;VMI97,@<V5T
M(&EN(')E<W!O;G-E"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B!`<F5T=7)N(&%R<F%Y"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N
M<V5#;V]K:65S*"D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M
M/E]R97-P;VYS92T^7V-O;VMI97,I(#\@)'1H:7,M/E]R97-P;VYS92T^7V-O
M;VMI97,@.B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("H@0G5I;&1S('1H
M92!R97%U97-T('-T<FEN9PH@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("H@0')E='5R;B!S=')I;F<@5&AE(')E<75E<W0@<W1R:6YG"B`@("`J
M+PH@("`@9G5N8W1I;VX@7V)U:6QD4F5Q=65S="@I"B`@("!["B`@("`@("`@
M)'%U97)Y<W1R:6YG(#T@*"1Q=65R>7-T<FEN9R`]("1T:&ES+3Y?=7)L+3YG
M9711=65R>5-T<FEN9R@I*2`_("<_)R`N("1Q=65R>7-T<FEN9R`Z("<G.PH*
M("`@("`@("`D:&]S="`](&ES<V5T*"1T:&ES+3Y?<')O>'E?:&]S="D@/R`D
M=&AI<RT^7W5R;"T^<')O=&]C;VP@+B`G.B\O)R`N("1T:&ES+3Y?=7)L+3YH
M;W-T(#H@)R<["B`@("`@("`@)'!O<G0@/2`H:7-S970H)'1H:7,M/E]P<F]X
M>5]H;W-T*2!!3D0@)'1H:7,M/E]U<FPM/G!O<G0@(3T@.#`I(#\@)SHG("X@
M)'1H:7,M/E]U<FPM/G!O<G0@.B`G)SL*("`@("`@("`D<&%T:"`]("AE;7!T
M>2@D=&AI<RT^7W5R;"T^<&%T:"D_("<O)SH@)'1H:7,M/E]U<FPM/G!A=&@I
M("X@)'%U97)Y<W1R:6YG.PH@("`@("`@("1U<FP@(#T@)&AO<W0@+B`D<&]R
M="`N("1P871H.PH*("`@("`@("`D<F5Q=65S="`]("1T:&ES+3Y?;65T:&]D
M("X@)R`G("X@)'5R;"`N("<@2%144"\G("X@)'1H:7,M/E]H='1P("X@(EQR
M7&XB.PH*("`@("`@("!I9B`H)VUU;'1I<&%R="]F;W)M+61A=&$G(#T]("1T
M:&ES+3Y?<F5Q=65S=$AE861E<G-;)T-O;G1E;G0M5'EP92==*2!["B`@("`@
M("`@("`@("1B;W5N9&%R>2`]("=(5%107U)E<75E<W1?)R`N(&UD-2AU;FEQ
M:60H)W)E<75E<W0G*2`N(&UI8W)O=&EM92@I*3L*("`@("`@("`@("`@)'1H
M:7,M/F%D9$AE861E<B@G0V]N=&5N="U4>7!E)RP@)VUU;'1I<&%R="]F;W)M
M+61A=&$[(&)O=6YD87)Y/2<@+B`D8F]U;F1A<GDI.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4F5Q=65S="!(96%D97)S"B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W)E<75E<W1(96%D97)S*2D@>PH@("`@("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W)E<75E<W1(96%D97)S(&%S("1N86UE(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`@("`@)')E<75E<W0@+CT@)&YA;64@+B`G.B`G("X@
M)'9A;'5E("X@(EQR7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!0;W-T(&1A=&$@:68@:70G<R!A;B!A<G)A>0H@("`@("`@(&EF
M("@H(65M<'1Y*"1T:&ES+3Y?<&]S=$1A=&$I("8F(&ES7V%R<F%Y*"1T:&ES
M+3Y?<&]S=$1A=&$I*2!\?"`A96UP='DH)'1H:7,M/E]P;W-T1FEL97,I*2![
M"B`@("`@("`@("`@("\O(&UU;'1I<&%R="!R97%U97-T+"!P<F]B86)L>2!W
M:71H(&9I;&4@=7!L;V%D<PH@("`@("`@("`@("!I9B`H:7-S970H)&)O=6YD
M87)Y*2D@>PH@("`@("`@("`@("`@("`@)'!O<W1D871A(#T@)R<["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!O<W1$871A(&%S("1N86UE
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1V86QU92!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!O<W1D871A("X]("<M+2<@+B`D8F]U;F1A<GD@+B`B7')<;B([
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]S=&1A=&$@+CT@)T-O
M;G1E;G0M1&ES<&]S:71I;VXZ(&9O<FTM9&%T83L@;F%M93TB)R`N("1N86UE
M("X@*"1T:&ES+3Y?=7-E0G)A8VME=',_("=;)R`N("1K("X@)UTG.B`G)RD@
M+B`G(B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]S=&1A=&$@
M+CT@(EQR7&Y<<EQN(B`N('5R;&1E8V]D92@D=BD@+B`B7')<;B(["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<&]S=&1A=&$@+CT@)RTM
M)R`N("1B;W5N9&%R>2`N(")<<EQN(CL*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!O<W1D871A("X]("=#;VYT96YT+41I<W!O<VET:6]N.B!F;W)M+61A
M=&$[(&YA;64](B<@+B`D;F%M92`N("<B)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!O<W1D871A("X](")<<EQN7')<;B(@+B!U<FQD96-O9&4H)'9A
M;'5E*2`N(")<<EQN(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!O
M<W1&:6QE<R!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'9A;'5E6R=N86UE)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1V87)N86UE("`@("`@(#T@)&YA;64@+B`H)'1H
M:7,M/E]U<V5"<F%C:V5T<S\@)UM=)SH@)R<I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE
M("`@("`@(#T@)&YA;64["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU
M95LG;F%M92==(#T@87)R87DH)'9A;'5E6R=N86UE)UTI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L
M=65;)VYA;64G72!A<R`D:V5Y(#T^("1F:6QE;F%M92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D9G`@("`](&9O<&5N*"1F:6QE;F%M92P@)W(G*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L(&9I
M;&5S:7IE*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&)A<V5N86UE
M(#T@8F%S96YA;64H)&9I;&5N86UE*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1Y<&4@("`@(#T@:7-?87)R87DH)'9A;'5E6R=T>7!E)UTI/R!`)'9A
M;'5E6R=T>7!E)UU;)&ME>5TZ("1V86QU95LG='EP92==.PH*("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O<W1D871A("X]("<M+2<@+B`D8F]U;F1A<GD@
M+B`B7')<;B(["B`@("`@("`@("`@("`@("`@("`@("`@("1P;W-T9&%T82`N
M/2`G0V]N=&5N="U$:7-P;W-I=&EO;CH@9F]R;2UD871A.R!N86UE/2(G("X@
M)'9A<FYA;64@+B`G(CL@9FEL96YA;64](B<@+B`D8F%S96YA;64@+B`G(B<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P;W-T9&%T82`N/2`B7')<;D-O
M;G1E;G0M5'EP93H@(B`N("1T>7!E.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]S=&1A=&$@+CT@(EQR7&Y<<EQN(B`N("1D871A("X@(EQR7&XB.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1P;W-T9&%T82`N/2`G+2TG("X@)&)O=6YD87)Y("X@(EQR
M7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9F]R
M96%C:"@D=&AI<RT^7W!O<W1$871A(&%S("1N86UE(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:R`]
M/B`D=BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O<W1D871A
M6UT@/2`D=&AI<RT^7W5S94)R86-K971S/R!S<')I;G1F*"<E<ULE<UT])7,G
M+"`D;F%M92P@)&LL("1V*3H@)&YA;64@+B`G/2<@+B`D=CL*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P;W-T9&%T85M=(#T@)&YA;64@
M+B`G/2<@+B`D=F%L=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@"B`@("`@("`@("`@("`@("`D<&]S=&1A=&$@/2!I
M;7!L;V1E*"<F)RP@)'!O<W1D871A*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<F5Q=65S="`N/2`G0V]N=&5N="U,96YG=&@Z("<@+B!S=')L96XH
M)'!O<W1D871A*2`N(")<<EQN7')<;B(["B`@("`@("`@("`@("1R97%U97-T
M("X]("1P;W-T9&%T83L*"B`@("`@("`@+R\@4&]S="!D871A(&EF(&ET)W,@
M<F%W"B`@("`@("`@?2!E;'-E:68H(65M<'1Y*"1T:&ES+3Y?<&]S=$1A=&$I
M*2!["B`@("`@("`@("`@("1R97%U97-T("X]("=#;VYT96YT+4QE;F=T:#H@
M)R`N('-T<FQE;B@D=&AI<RT^7W!O<W1$871A*2`N(")<<EQN7')<;B(["B`@
M("`@("`@("`@("1R97%U97-T("X]("1T:&ES+3Y?<&]S=$1A=&$["@H@("`@
M("`@("\O($YO('!O<W0@9&%T82P@<V\@<VEM<&QY(&%D9"!A(&9I;F%L($-2
M3$8*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5Q=65S="`N/2`B
M7')<;B(["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(')E='5R;B`D<F5Q
M=65S=#L*("`@('T*"@H@("`O*BH*("`@("H@061D<R!A($QI<W1E;F5R('1O
M('1H92!L:7-T(&]F(&QI<W1E;F5R<R!T:&%T(&%R92!N;W1I9FEE9"!O9@H@
M("`@*B!T:&4@;V)J96-T)W,@979E;G1S"B`@("`J(`H@("`@*B!`<&%R86T@
M("`@;V)J96-T("`@2%144%]297%U97-T7TQI<W1E;F5R(&EN<W1A;F-E('1O
M(&%T=&%C:`H@("`@*B!`<F5T=7)N("`@8F]O;&5A;B`@=VAE=&AE<B!T:&4@
M;&ES=&5N97(@=V%S('-U8V-E<W-F=6QL>2!A='1A8VAE9`H@("`@*B!`86-C
M97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@871T86-H*"8D;&ES
M=&5N97(I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1L:7-T96YE<BP@)TA4
M5%!?4F5Q=65S=%],:7-T96YE<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&QI
M<W1E;F5R+3YG971)9"@I72`])B`D;&ES=&5N97(["B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H*("`@+RHJ"B`@("`J(%)E;6]V97,@82!,:7-T96YE
M<B!F<F]M('1H92!L:7-T(&]F(&QI<W1E;F5R<R`*("`@("H@"B`@("`J($!P
M87)A;2`@("!O8FIE8W0@("!(5%107U)E<75E<W1?3&ES=&5N97(@:6YS=&%N
M8V4@=&\@9&5T86-H"B`@("`J($!R971U<FX@("!B;V]L96%N("!W:&5T:&5R
M('1H92!L:7-T96YE<B!W87,@<W5C8V5S<V9U;&QY(&1E=&%C:&5D"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!D971A8V@H
M)B1L:7-T96YE<BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&QI<W1E;F5R
M+"`G2%144%]297%U97-T7TQI<W1E;F5R)RD@?'P@"B`@("`@("`@("`@("%I
M<W-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97(M/F=E=$ED*"E=*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M('5N<V5T*"1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<BT^9V5T260H*5TI
M.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*"B`@("\J*@H@("`@*B!.
M;W1I9FEE<R!A;&P@<F5G:7-T97)E9"!L:7-T96YE<G,@;V8@86X@979E;G0N
M"B`@("`J(`H@("`@*B!%=F5N=',@<V5N="!B>2!(5%107U)E<75E<W0@;V)J
M96-T"B`@("`J("=S96YT4F5Q=65S="<Z(&%F=&5R('1H92!R97%U97-T('=A
M<R!S96YT"B`@("`J($5V96YT<R!S96YT(&)Y($A45%!?4F5S<&]N<V4@;V)J
M96-T"B`@("`J("=G;W1(96%D97)S)SH@869T97(@<F5C96EV:6YG(')E<W!O
M;G-E(&AE861E<G,@*&AE861E<G,@87)E('!A<W-E9"!I;B`D9&%T82D*("`@
M("H@)W1I8VLG.B!O;B!R96-E:79I;F<@82!P87)T(&]F(')E<W!O;G-E(&)O
M9'D@*'1H92!P87)T(&ES('!A<W-E9"!I;B`D9&%T82D*("`@("H@)V=Z5&EC
M:R<Z(&]N(')E8V5I=FEN9R!A(&=Z:7`M96YC;V1E9"!P87)T(&]F(')E<W!O
M;G-E(&)O9'D@*&1I='1O*0H@("`@*B`G9V]T0F]D>2<Z(&%F=&5R(')E8V5I
M=FEN9R!T:&4@<F5S<&]N<V4@8F]D>2`H<&%S<V5S('1H92!D96-O9&5D(&)O
M9'D@:6X@)&1A=&$@:68@:70@=V%S(&=Z:7!P960I"B`@("`J(`H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!%=F5N="!N86UE"B`@("`J($!P87)A;2`@("!M
M:7AE9"`@($%D9&ET:6]N86P@9&%T80H@("`@*B!`86-C97-S("`@<')I=F%T
M90H@("`@*B\*("`@(&9U;F-T:6]N(%]N;W1I9GDH)&5V96YT+"`D9&%T82`]
M(&YU;&PI"B`@("!["B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI
M<RT^7VQI<W1E;F5R<RD@87,@)&ED*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;&ES=&5N97)S6R1I9%TM/G5P9&%T92@D=&AI<RP@)&5V96YT+"`D9&%T82D[
M"B`@("`@("`@?0H@("`@?0I]"@H*+RHJ"BH@4F5S<&]N<V4@8VQA<W,@=&\@
M8V]M<&QE;65N="!T:&4@4F5Q=65S="!C;&%S<PHJ+PIC;&%S<R!(5%107U)E
M<W!O;G-E"GL*("`@("\J*@H@("`@*B!3;V-K970@;V)J96-T"B`@("`J($!V
M87(@;V)J96-T"B`@("`J+PH@("`@=F%R("1?<V]C:SL*"B`@("`O*BH*("`@
M("H@4')O=&]C;VP*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@
M)%]P<F]T;V-O;#L*("`@(`H@("`@+RHJ"B`@("`J(%)E='5R;B!C;V1E"B`@
M("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?8V]D93L*("`@(`H@
M("`@+RHJ"B`@("`J(%)E<W!O;G-E(&AE861E<G,*("`@("H@0'9A<B!A<G)A
M>0H@("`@*B\*("`@('9A<B`D7VAE861E<G,["@H@("`@+RHJ"B`@("`J($-O
M;VMI97,@<V5T(&EN(')E<W!O;G-E("`*("`@("H@0'9A<B!A<G)A>0H@("`@
M*B\*("`@('9A<B`D7V-O;VMI97,["@H@("`@+RHJ"B`@("`J(%)E<W!O;G-E
M(&)O9'D*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]B;V1Y
M(#T@)R<["@H@("`O*BH*("`@("H@57-E9"!B>2!?<F5A9$-H=6YK960H*3H@
M<F5M86EN:6YG(&QE;F=T:"!O9B!T:&4@8W5R<F5N="!C:'5N:PH@("`@*B!`
M=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7V-H=6YK3&5N9W1H(#T@,#L*
M"B`@("\J*@H@("`@*B!!='1A8VAE9"!L:7-T96YE<G,*("`@("H@0'9A<B!A
M<G)A>0H@("`@*B\*("`@('9A<B`D7VQI<W1E;F5R<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`J($-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A;2`@
M;V)J96-T($YE=%]3;V-K970@("`@('-O8VME="!T;R!R96%D('1H92!R97-P
M;VYS92!F<F]M"B`@("`J($!P87)A;2`@87)R87D@("`@("`@("`@("`@("`@
M(&QI<W1E;F5R<R!A='1A8VAE9"!T;R!R97%U97-T"B`@("`J($!R971U<FX@
M;6EX960@4$5!4B!%<G)O<B!O;B!E<G)O<BP@=')U92!O=&AE<G=I<V4*("`@
M("HO"B`@("!F=6YC=&EO;B!(5%107U)E<W!O;G-E*"8D<V]C:RP@)B1L:7-T
M96YE<G,I"B`@("!["B`@("`@("`@)'1H:7,M/E]S;V-K("`@("`@/28@)'-O
M8VL["B`@("`@("`@)'1H:7,M/E]L:7-T96YE<G,@/28@)&QI<W1E;F5R<SL*
M("`@('T*"@H@("`O*BH*("`@("H@4')O8V5S<V5S(&$@2%144"!R97-P;VYS
M90H@("`@*B`*("`@("H@5&AI<R!E>'1R86-T<R!R97-P;VYS92!C;V1E+"!H
M96%D97)S+"!C;V]K:65S(&%N9"!D96-O9&5S(&)O9'D@:68@:70@"B`@("`J
M('=A<R!E;F-O9&5D(&EN('-O;64@=V%Y"B`@("`J"B`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`J($!P87)A;2`@8F]O;"`@("`@(%=H971H97(@=&\@<W1O
M<F4@<F5S<&]N<V4@8F]D>2!I;B!O8FIE8W0@<')O<&5R='DL('-E=`H@("`@
M*B`@("`@("`@("`@("`@("`@("!T:&ES('1O(&9A;'-E(&EF(&1O=VYL;V%D
M:6YG(&$@3$%21T4@9FEL92!A;F0@=7-I;F<@82!,:7-T96YE<BX*("`@("H@
M("`@("`@("`@("`@("`@("`@5&AI<R!I<R!A<W-U;65D('1O(&)E('1R=64@
M:68@8F]D>2!I<R!G>FEP+65N8V]D960N"B`@("`J($!T:')O=W,@4$5!4E]%
M<G)O<@H@("`@*B!`<F5T=7)N(&UI>&5D("`@("!T<G5E(&]N('-U8V-E<W,L
M(%!%05)?17)R;W(@:6X@8V%S92!O9B!M86QF;W)M960@<F5S<&]N<V4*("`@
M("HO"B`@("!F=6YC=&EO;B!P<F]C97-S*"1S879E0F]D>2`]('1R=64I"B`@
M("!["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D;&EN92`]("1T:&ES+3Y?
M<V]C:RT^<F5A9$QI;F4H*3L*("`@("`@("`@("`@:68@*'-S8V%N9B@D;&EN
M92P@)TA45%`O)7,@)7,G+"`D:'1T<%]V97)S:6]N+"`D<F5T=7)N8V]D92D@
M(3T@,BD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)TUA;&9O<FUE9"!R97-P;VYS92XG*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<')O=&]C;VP@/2`G2%144"\G
M("X@)&AT='!?=F5R<VEO;CL*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]D
M92`@("`@/2!I;G1V86PH)')E='5R;F-O9&4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@('=H:6QE("@G)R`A/3T@*"1H96%D97(@/2`D=&AI<RT^7W-O
M8VLM/G)E861,:6YE*"DI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!R
M;V-E<W-(96%D97(H)&AE861E<BD["B`@("`@("`@("`@('T*("`@("`@("!]
M('=H:6QE("@Q,#`@/3T@)'1H:7,M/E]C;V1E*3L*"B`@("`@("`@)'1H:7,M
M/E]N;W1I9GDH)V=O=$AE861E<G,G+"`D=&AI<RT^7VAE861E<G,I.PH*("`@
M("`@("`O+R!)9B!R97-P;VYS92!B;V1Y(&ES('!R97-E;G0L(')E860@:70@
M86YD(&1E8V]D90H@("`@("`@("1C:'5N:V5D(#T@:7-S970H)'1H:7,M/E]H
M96%D97)S6R=T<F%N<V9E<BUE;F-O9&EN9R==*2`F)B`H)V-H=6YK960G(#T]
M("1T:&ES+3Y?:&5A9&5R<ULG=')A;G-F97(M96YC;V1I;F<G72D["B`@("`@
M("`@)&=Z:7!P960@/2!I<W-E="@D=&AI<RT^7VAE861E<G-;)V-O;G1E;G0M
M96YC;V1I;F<G72D@)B8@*"=G>FEP)R`]/2`D=&AI<RT^7VAE861E<G-;)V-O
M;G1E;G0M96YC;V1I;F<G72D["B`@("`@("`@)&AA<T)O9'D@/2!F86QS93L*
M("`@("`@("!W:&EL92`H(21T:&ES+3Y?<V]C:RT^96]F*"DI('L*("`@("`@
M("`@("`@:68@*"1C:'5N:V5D*2!["B`@("`@("`@("`@("`@("`D9&%T82`]
M("1T:&ES+3Y?<F5A9$-H=6YK960H*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1D871A(#T@)'1H:7,M/E]S;V-K+3YR96%D*#0P
M.38I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@G)R`A/2`D9&%T
M82D@>PH@("`@("`@("`@("`@("`@)&AA<T)O9'D@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@:68@*"1S879E0F]D>2!\?"`D9WII<'!E9"D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8F]D>2`N/2`D9&%T83L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]T:69Y*"1G>FEP
M<&5D/R`G9WI4:6-K)SH@)W1I8VLG+"`D9&%T82D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@:68@*"1H87-";V1Y*2!["B`@("`@("`@("`@
M("\O(%5N8V]M<')E<W,@=&AE(&)O9'D@:68@;F5E9&5D"B`@("`@("`@("`@
M(&EF("@D9WII<'!E9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B;V1Y
M(#T@9WII;F9L871E*'-U8G-T<B@D=&AI<RT^7V)O9'DL(#$P*2D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VYO=&EF>2@G9V]T0F]D>2<L("1T:&ES+3Y?
M8F]D>2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VYO=&EF>2@G9V]T0F]D>2<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*"B`@("\J*@H@("`@
M*B!0<F]C97-S97,@=&AE(')E<W!O;G-E(&AE861E<@H@("`@*@H@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("H@0'!A<F%M("!S=')I;F<@("`@2%144"!H
M96%D97(*("`@("HO"B`@("!F=6YC=&EO;B!?<')O8V5S<TAE861E<B@D:&5A
M9&5R*0H@("`@>PH@("`@("`@(&QI<W0H)&AE861E<FYA;64L("1H96%D97)V
M86QU92D@/2!E>'!L;V1E*"<Z)RP@)&AE861E<BP@,BD["B`@("`@("`@)&AE
M861E<FYA;65?:2`]('-T<G1O;&]W97(H)&AE861E<FYA;64I.PH@("`@("`@
M("1H96%D97)V86QU92`@/2!L=')I;2@D:&5A9&5R=F%L=64I.PH@("`@("`@
M(`H@("`@("`@(&EF("@G<V5T+6-O;VMI92<@(3T@)&AE861E<FYA;65?:2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;)&AE861E<FYA;65=("`@
M/2`D:&5A9&5R=F%L=64["B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD
M:&5A9&5R;F%M95]I72`]("1H96%D97)V86QU93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7W!A<G-E0V]O:VEE*"1H96%D97)V86QU
M92D["B`@("`@("`@?0H@("`@?0H*"B`@("\J*@H@("`@*B!087)S92!A(%-E
M="U#;V]K:64@:&5A9&5R('1O(&9I;&P@)%]C;V]K:65S(&%R<F%Y"B`@("`J
M"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`<&%R86T@('-T<FEN9R`@
M("!V86QU92!O9B!3970M0V]O:VEE(&AE861E<@H@("`@*B\*("`@(&9U;F-T
M:6]N(%]P87)S94-O;VMI92@D:&5A9&5R=F%L=64I"B`@("!["B`@("`@("`@
M)&-O;VMI92`](&%R<F%Y*`H@("`@("`@("`@("`G97AP:7)E<R<@/3X@;G5L
M;"P*("`@("`@("`@("`@)V1O;6%I;B<@(#T^(&YU;&PL"B`@("`@("`@("`@
M("=P871H)R`@("`]/B!N=6QL+`H@("`@("`@("`@("`G<V5C=7)E)R`@/3X@
M9F%L<V4*("`@("`@("`I.PH*("`@("`@("`O+R!/;FQY(&$@;F%M93UV86QU
M92!P86ER"B`@("`@("`@:68@*"%S=')P;W,H)&AE861E<G9A;'5E+"`G.R<I
M*2!["B`@("`@("`@("`@(&QI<W0H)&-O;VMI95LG;F%M92==+"`D8V]O:VEE
M6R=V86QU92==*2`](&%R<F%Y7VUA<"@G=')I;2<L(&5X<&QO9&4H)STG+"`D
M:&5A9&5R=F%L=64I*3L*("`@("`@("`@("`@)&-O;VMI95LG;F%M92==("`]
M('5R;&1E8V]D92@D8V]O:VEE6R=N86UE)UTI.PH@("`@("`@("`@("`D8V]O
M:VEE6R=V86QU92==(#T@=7)L9&5C;V1E*"1C;V]K:65;)W9A;'5E)UTI.PH*
M("`@("`@("`O+R!3;VUE(&]P=&EO;F%L('!A<F%M971E<G,@87)E('-U<'!L
M:65D"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5L96UE;G1S(#T@
M97AP;&]D92@G.R<L("1H96%D97)V86QU92D["B`@("`@("`@("`@(&QI<W0H
M)&-O;VMI95LG;F%M92==+"`D8V]O:VEE6R=V86QU92==*2`](&%R<F%Y7VUA
M<"@G=')I;2<L(&5X<&QO9&4H)STG+"`D96QE;65N='-;,%TI*3L*("`@("`@
M("`@("`@)&-O;VMI95LG;F%M92==("`]('5R;&1E8V]D92@D8V]O:VEE6R=N
M86UE)UTI.PH@("`@("`@("`@("`D8V]O:VEE6R=V86QU92==(#T@=7)L9&5C
M;V1E*"1C;V]K:65;)W9A;'5E)UTI.PH*("`@("`@("`@("`@9F]R("@D:2`]
M(#$[("1I(#P@8V]U;G0H)&5L96UE;G1S*3LD:2LK*2!["B`@("`@("`@("`@
M("`@("!L:7-T("@D96Q.86UE+"`D96Q686QU92D@/2!A<G)A>5]M87`H)W1R
M:6TG+"!E>'!L;V1E*"<])RP@)&5L96UE;G1S6R1I72DI.PH@("`@("`@("`@
M("`@("`@:68@*"=S96-U<F4G(#T]("1E;$YA;64I('L*("`@("`@("`@("`@
M("`@("`@("`D8V]O:VEE6R=S96-U<F4G72`]('1R=64["B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)V5X<&ER97,G(#T]("1E;$YA;64I('L*("`@("`@
M("`@("`@("`@("`@("`D8V]O:VEE6R=E>'!I<F5S)UT@/2!S=')?<F5P;&%C
M92@G(B<L("<G+"`D96Q686QU92D["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)W!A=&@G(#T]("1E;$YA;64@3U(@)V1O;6%I;B<@/3T@)&5L3F%M92D@
M>PH@("`@("`@("`@("`@("`@("`@("1C;V]K:65;)&5L3F%M95T@/2!U<FQD
M96-O9&4H)&5L5F%L=64I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D8V]O:VEE6R1E;$YA;65=(#T@)&5L5F%L=64[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/E]C;V]K:65S6UT@/2`D8V]O:VEE.PH@("`@?0H*"B`@
M("\J*@H@("`@*B!296%D(&$@<&%R="!O9B!R97-P;VYS92!B;V1Y(&5N8V]D
M960@=VET:"!C:'5N:V5D(%1R86YS9F5R+45N8V]D:6YG"B`@("`J(`H@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("H@0')E='5R;B!S=')I;F<*("`@("HO
M"B`@("!F=6YC=&EO;B!?<F5A9$-H=6YK960H*0H@("`@>PH@("`@("`@("\O
M(&%T('-T87)T(&]F('1H92!N97AT(&-H=6YK/PH@("`@("`@(&EF("@P(#T]
M("1T:&ES+3Y?8VAU;FM,96YG=&@I('L*("`@("`@("`@("`@)&QI;F4@/2`D
M=&AI<RT^7W-O8VLM/G)E861,:6YE*"D["B`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7BA;,"TY82UF72LI+VDG+"`D;&EN92P@)&UA=&-H97,I*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H=6YK3&5N9W1H(#T@:&5X9&5C
M*"1M871C:&5S6S%=*3L@"B`@("`@("`@("`@("`@("`O+R!#:'5N:R!W:71H
M('IE<F\@;&5N9W1H(&EN9&EC871E<R!T:&4@96YD"B`@("`@("`@("`@("`@
M("!I9B`H,"`]/2`D=&AI<RT^7V-H=6YK3&5N9W1H*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S;V-K+3YR96%D06QL*"D[("\O(&UA:V4@=&AI
M<R!A;B!E;V8H*0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`D9&%T82`]("1T:&ES+3Y?<V]C:RT^<F5A9"@D=&AI<RT^7V-H=6YK3&5N
M9W1H*3L*("`@("`@("`D=&AI<RT^7V-H=6YK3&5N9W1H("T]('-T<FQE;B@D
M9&%T82D["B`@("`@("`@:68@*#`@/3T@)'1H:7,M/E]C:'5N:TQE;F=T:"D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-O8VLM/G)E861,:6YE*"D[("\O(%1R
M86EL:6YG($-23$8*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1D871A.PH@
M("`@?0H*"B`@("\J*@H@("`@*B!.;W1I9FEE<R!A;&P@<F5G:7-T97)E9"!L
M:7-T96YE<G,@;V8@86X@979E;G0N"B`@("`J(`H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("!%=F5N="!N86UE"B`@("`J($!P87)A;2`@("!M:7AE9"`@($%D
M9&ET:6]N86P@9&%T80H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`
M<V5E($A45%!?4F5Q=65S=#HZ7VYO=&EF>2@I"B`@("`J+PH@("`@9G5N8W1I
M;VX@7VYO=&EF>2@D979E;G0L("1D871A(#T@;G5L;"D*("`@('L*("`@("`@
M("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?;&ES=&5N97)S*2!A<R`D
M:60I('L*("`@("`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&ED72T^=7!D
M871E*"1T:&ES+"`D979E;G0L("1D871A*3L*("`@("`@("!]"B`@("!]"GT@
M+R\@16YD(&-L87-S($A45%!?4F5S<&]N<V4*/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL
M+P``````````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P,38R,C8`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TUA:6PO4D9#.#(R+G!H<```````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<U,S$U`#$P-#$W,S8S,#`W`#`Q-S8Q
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`R,#`Q+3(P,#(L(%)I8VAA<F0@2&5Y97,@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!!;&P@<FEG:'1S(')E<V5R
M=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R
M>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P*+R\@?"!M;V1I9FEC871I
M;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG
M(&-O;F1I=&EO;G,@("`@?`HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!O(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT("`@("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M+B`@("`@("!\"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O
M<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P*+R\@
M?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@?`HO+R!\("`@9&]C=6UE;G1A
M=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE
M(&1I<W1R:6)U=&EO;BY\(`HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H
M;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@
M("!\"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R
M92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P*+R\@?"`@('!E
M<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!4
M2$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P*+R\@
M?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)
M15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?`HO+R!\($Q)34E4140@5$\L
M(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.
M1"!&251.15-3($9/4B!\"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@
M('P*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!
M3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?`HO+R!\(%-014-)
M04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@("`@("!\"B\O('P@3$E-251%1"!43RP@4%)/0U52
M14U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/
M1B!54T4L('P*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)
M3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`HO+R!\
M(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-4
M4DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\"B\O('P@*$E.0TQ51$E.1R!.
M14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]5
M5"!/1B!42$4@55-%('P*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&
M($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@
M?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!2:6-H87)D($AE
M>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\("`@("`@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"B\J*@HJ(%)&0R`X,C(@16UA
M:6P@861D<F5S<R!L:7-T('9A;&ED871I;VX@571I;&ET>0HJ"BH@5VAA="!I
M<R!I=#\**@HJ(%1H:7,@8VQA<W,@=VEL;"!T86ME(&%N(&%D9')E<W,@<W1R
M:6YG+"!A;F0@<&%R<V4@:70@:6YT;R!I="=S(&-O;G-I='5E;G0**B!P87)T
M<RP@8F4@=&AA="!E:71H97(@861D<F5S<V5S+"!G<F]U<',L(&]R(&-O;6)I
M;F%T:6]N<RX@3F5S=&5D(&=R;W5P<PHJ(&%R92!N;W0@<W5P<&]R=&5D+B!4
M:&4@<W1R=6-T=7)E(&ET(')E='5R;G,@:7,@<')E='1Y('-T<F%I9VAT(&9O
M<G=A<F0L"BH@86YD(&ES('-I;6EL87(@=&\@=&AA="!P<F]V:61E9"!B>2!T
M:&4@:6UA<%]R9F,X,C)?<&%R<V5?861R;&ES="@I+B!5<V4**B!P<FEN=%]R
M*"D@=&\@=FEE=R!T:&4@<W1R=6-T=7)E+@HJ"BH@2&]W(&1O($D@=7-E(&ET
M/PHJ"BH@)&%D9')E<W-?<W1R:6YG(#T@)TUY($=R;W5P.B`B4FEC:&%R9"(@
M/')I8VAA<F1`;&]C86QH;W-T/B`H02!C;VUM96YT*2P@=&5D0&5X86UP;&4N
M8V]M("A4960@0FQO9V=S*2P@0F%R;F5Y.R<["BH@)'-T<G5C='5R92`]($UA
M:6Q?4D9#.#(R.CIP87)S94%D9')E<W-,:7-T*"1A9&1R97-S7W-T<FEN9RP@
M)V5X86UP;&4N8V]M)RP@=')U92D**B!P<FEN=%]R*"1S=')U8W1U<F4I.PHJ
M"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U+F]R
M9SX**B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX**B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,3`@)`HJ($!L:6-E;G-E($)3
M1`HJ($!P86-K86=E($UA:6P**B\*"F-L87-S($UA:6Q?4D9#.#(R('L*"B`@
M("`O*BH*("`@("`J(%1H92!A9&1R97-S(&)E:6YG('!A<G-E9"!B>2!T:&4@
M4D9#.#(R(&]B:F5C="X*("`@("`J($!V87(@<W1R:6YG("1A9&1R97-S"B`@
M("`@*B\*("`@('9A<B`D861D<F5S<R`]("<G.PH*("`@("\J*@H@("`@("H@
M5&AE(&1E9F%U;'0@9&]M86EN('1O('5S92!F;W(@=6YQ=6%L:69I960@861D
M<F5S<V5S+@H@("`@("H@0'9A<B!S=')I;F<@)&1E9F%U;'1?9&]M86EN"B`@
M("`@*B\*("`@('9A<B`D9&5F875L=%]D;VUA:6X@/2`G;&]C86QH;W-T)SL*
M"B`@("`O*BH*("`@("`J(%-H;W5L9"!W92!R971U<FX@82!N97-T960@87)R
M87D@<VAO=VEN9R!G<F]U<',L(&]R(&9L871T96X@979E<GET:&EN9S\*("`@
M("`J($!V87(@8F]O;&5A;B`D;F5S=$=R;W5P<PH@("`@("HO"B`@("!V87(@
M)&YE<W1'<F]U<',@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!O
M<B!N;W0@=&\@=F%L:61A=&4@871O;7,@9F]R(&YO;BUA<V-I:2!C:&%R86-T
M97)S+@H@("`@("H@0'9A<B!B;V]L96%N("1V86QI9&%T90H@("`@("HO"B`@
M("!V87(@)'9A;&ED871E(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1H92!A
M<G)A>2!O9B!R87<@861D<F5S<V5S(&)U:6QT('5P(&%S('=E('!A<G-E+@H@
M("`@("H@0'9A<B!A<G)A>2`D861D<F5S<V5S"B`@("`@*B\*("`@('9A<B`D
M861D<F5S<V5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!F:6YA
M;"!A<G)A>2!O9B!P87)S960@861D<F5S<R!I;F9O<FUA=&EO;B!T:&%T('=E
M(&)U:6QD('5P+@H@("`@("H@0'9A<B!A<G)A>2`D<W1R=6-T=7)E"B`@("`@
M*B\*("`@('9A<B`D<W1R=6-T=7)E(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J(%1H92!C=7)R96YT(&5R<F]R(&UE<W-A9V4L(&EF(&%N>2X*("`@("`J
M($!V87(@<W1R:6YG("1E<G)O<@H@("`@("HO"B`@("!V87(@)&5R<F]R(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J($%N(&EN=&5R;F%L(&-O=6YT97(O<&]I
M;G1E<BX*("`@("`J($!V87(@:6YT96=E<B`D:6YD97@*("`@("`J+PH@("`@
M=F%R("1I;F1E>"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R
M(&]F(&=R;W5P<R!T:&%T(&AA=F4@8F5E;B!F;W5N9"!I;B!T:&4@861D<F5S
M<R!L:7-T+@H@("`@("H@0'9A<B!I;G1E9V5R("1N=6U?9W)O=7!S"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!V87(@)&YU;5]G<F]U<',@
M/2`P.PH*("`@("\J*@H@("`@("H@02!V87)I86)L92!S;R!T:&%T('=E(&-A
M;B!T96QL('=H971H97(@;W(@;F]T('=E)W)E(&EN<VED92!A"B`@("`@*B!-
M86EL7U)&0S@R,B!O8FIE8W0N"B`@("`@*B!`=F%R(&)O;VQE86X@)&UA:6Q2
M1D,X,C(*("`@("`J+PH@("`@=F%R("1M86EL4D9#.#(R(#T@=')U93L*("`@
M(`H@("`@+RHJ"B`@("`J($$@;&EM:70@869T97(@=VAI8V@@<')O8V5S<VEN
M9R!S=&]P<PH@("`@*B!`=F%R(&EN="`D;&EM:70*("`@("HO"B`@("!V87(@
M)&QI;6ET(#T@;G5L;#L*"@H@("`@+RHJ"B`@("`@*B!3971S('5P('1H92!O
M8FIE8W0N(%1H92!A9&1R97-S(&UU<W0@96ET:&5R(&)E('-E="!H97)E(&]R
M('=H96X*("`@("`J(&-A;&QI;F<@<&%R<V5!9&1R97-S3&ES="@I+B!/;F4@
M;W(@=&AE(&]T:&5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D861D<F5S<R`@("`@("`@(%1H92!A9&1R
M97-S*&5S*2!T;R!V86QI9&%T92X*("`@("`J($!P87)A;2!S=')I;F<@("1D
M969A=6QT7V1O;6%I;B`@1&5F875L="!D;VUA:6XO:&]S="!E=&,N($EF(&YO
M="!S=7!P;&EE9"P@=VEL;"!B92!S970@=&\@;&]C86QH;W-T+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&YE<W1?9W)O=7!S("`@("!7:&5T:&5R('1O(')E
M='5R;B!T:&4@<W1R=6-T=7)E('=I=&@@9W)O=7!S(&YE<W1E9"!F;W(@96%S
M:65R('9I97=I;F<N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=F%L:61A=&4@
M("`@("`@(%=H971H97(@=&\@=F%L:61A=&4@871O;7,N(%1U<FX@=&AI<R!O
M9F8@:68@>6]U(&YE960@=&\@<G5N(&%D9')E<W-E<R!T:')O=6=H(&)E9F]R
M92!E;F-O9&EN9R!T:&4@<&5R<V]N86P@;F%M97,L(&9O<B!I;G-T86YC92X*
M("`@("`J(`H@("`@("H@0')E='5R;B!O8FIE8W0@36%I;%]21D,X,C(@02!N
M97<@36%I;%]21D,X,C(@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!-
M86EL7U)&0S@R,B@D861D<F5S<R`](&YU;&PL("1D969A=6QT7V1O;6%I;B`]
M(&YU;&PL("1N97-T7V=R;W5P<R`](&YU;&PL("1V86QI9&%T92`](&YU;&PL
M("1L:6UI="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1A9&1R
M97-S*2D@("`@("`@("1T:&ES+3YA9&1R97-S("`@("`@("`]("1A9&1R97-S
M.PH@("`@("`@(&EF("AI<W-E="@D9&5F875L=%]D;VUA:6XI*2`D=&AI<RT^
M9&5F875L=%]D;VUA:6X@/2`D9&5F875L=%]D;VUA:6X["B`@("`@("`@:68@
M*&ES<V5T*"1N97-T7V=R;W5P<RDI("`@("1T:&ES+3YN97-T1W)O=7!S("`@
M("`]("1N97-T7V=R;W5P<SL*("`@("`@("!I9B`H:7-S970H)'9A;&ED871E
M*2D@("`@("`@)'1H:7,M/G9A;&ED871E("`@("`@(#T@)'9A;&ED871E.PH@
M("`@("`@(&EF("AI<W-E="@D;&EM:70I*2`@("`@("`@("`D=&AI<RT^;&EM
M:70@("`@("`@("`@/2`D;&EM:70["B`@("!]"@H*("`@("\J*@H@("`@("H@
M4W1A<G1S('1H92!W:&]L92!P<F]C97-S+B!4:&4@861D<F5S<R!M=7-T(&5I
M=&AE<B!B92!S970@:&5R90H@("`@("H@;W(@=VAE;B!C<F5A=&EN9R!T:&4@
M;V)J96-T+B!/;F4@;W(@=&AE(&]T:&5R+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("`D861D<F5S<R`@("`@
M("`@(%1H92!A9&1R97-S*&5S*2!T;R!V86QI9&%T92X*("`@("`J($!P87)A
M;2!S=')I;F<@("1D969A=6QT7V1O;6%I;B`@1&5F875L="!D;VUA:6XO:&]S
M="!E=&,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;F5S=%]G<F]U<',@("`@
M(%=H971H97(@=&\@<F5T=7)N('1H92!S=')U8W1U<F4@=VET:"!G<F]U<',@
M;F5S=&5D(&9O<B!E87-I97(@=FEE=VEN9RX*("`@("`J($!P87)A;2!B;V]L
M96%N("1V86QI9&%T92`@("`@("`@5VAE=&AE<B!T;R!V86QI9&%T92!A=&]M
M<RX@5'5R;B!T:&ES(&]F9B!I9B!Y;W4@;F5E9"!T;R!R=6X@861D<F5S<V5S
M('1H<F]U9V@@8F5F;W)E(&5N8V]D:6YG('1H92!P97)S;VYA;"!N86UE<RP@
M9F]R(&EN<W1A;F-E+@H@("`@("H@"B`@("`@*B!`<F5T=7)N(&%R<F%Y($$@
M<W1R=6-T=7)E9"!A<G)A>2!O9B!A9&1R97-S97,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!A<G-E061D<F5S<TQI<W0H)&%D9')E<W,@/2!N=6QL+"`D9&5F
M875L=%]D;VUA:6X@/2!N=6QL+"`D;F5S=%]G<F]U<',@/2!N=6QL+"`D=F%L
M:61A=&4@/2!N=6QL+"`D;&EM:70@/2!N=6QL*0H@("`@>PH*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3YM86EL4D9#.#(R*2D@>PH@("`@("`@("`@("`D
M;V)J(#T@;F5W($UA:6Q?4D9#.#(R*"1A9&1R97-S+"`D9&5F875L=%]D;VUA
M:6XL("1N97-T7V=R;W5P<RP@)'9A;&ED871E+"`D;&EM:70I.PH@("`@("`@
M("`@("!R971U<FX@)&]B:BT^<&%R<V5!9&1R97-S3&ES="@I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S*2D@("`@("`@("1T:&ES
M+3YA9&1R97-S("`@("`@("`]("1A9&1R97-S.PH@("`@("`@(&EF("AI<W-E
M="@D9&5F875L=%]D;VUA:6XI*2`D=&AI<RT^9&5F875L=%]D;VUA:6X@/2`D
M9&5F875L=%]D;VUA:6X["B`@("`@("`@:68@*&ES<V5T*"1N97-T7V=R;W5P
M<RDI("`@("1T:&ES+3YN97-T1W)O=7!S("`@("`]("1N97-T7V=R;W5P<SL*
M("`@("`@("!I9B`H:7-S970H)'9A;&ED871E*2D@("`@("`@)'1H:7,M/G9A
M;&ED871E("`@("`@(#T@)'9A;&ED871E.PH@("`@("`@(&EF("AI<W-E="@D
M;&EM:70I*2`@("`@("`@("`D=&AI<RT^;&EM:70@("`@("`@("`@/2`D;&EM
M:70["@H@("`@("`@("1T:&ES+3YS=')U8W1U<F4@(#T@87)R87DH*3L*("`@
M("`@("`D=&AI<RT^861D<F5S<V5S("`](&%R<F%Y*"D["B`@("`@("`@)'1H
M:7,M/F5R<F]R("`@("`@/2!N=6QL.PH@("`@("`@("1T:&ES+3YI;F1E>"`@
M("`@(#T@;G5L;#L*"B`@("`@("`@=VAI;&4@*"1T:&ES+3YA9&1R97-S(#T@
M)'1H:7,M/E]S<&QI=$%D9')E<W-E<R@D=&AI<RT^861D<F5S<RDI('L*("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@
M(&EF("@D=&AI<RT^861D<F5S<R`]/3T@9F%L<V4@?'P@:7-S970H)'1H:7,M
M/F5R<F]R*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP
M)SL*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'1H:7,M
M/F5R<F]R*3L*("`@("`@("!]"@H@("`@("`@("\O($QO;W`@=&AR;W5G:"!A
M;&P@=&AE(&%D9')E<W-E<PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O
M=6YT*"1T:&ES+3YA9&1R97-S97,I.R`D:2LK*7L*"B`@("`@("`@("`@(&EF
M("@H)')E='5R;B`]("1T:&ES+3Y?=F%L:61A=&5!9&1R97-S*"1T:&ES+3YA
M9&1R97-S97-;)&E=*2D@/3T](&9A;'-E"B`@("`@("`@("`@("`@("!\?"!I
M<W-E="@D=&AI<RT^97)R;W(I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"1T:&ES+3YE<G)O<BD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@"B`@("`@("`@("`@(&EF("@A)'1H:7,M/FYE<W1'<F]U<',I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=')U8W1U<F4@/2!A<G)A>5]M
M97)G92@D=&AI<RT^<W1R=6-T=7)E+"`D<F5T=7)N*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=')U8W1U<F5;72`]
M("1R971U<FX["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^<W1R=6-T=7)E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4W!L:71S(&%N(&%D9')E<W,@:6YT;R!S97!E<F%T92!A9&1R97-S97,N"B`@
M("`@*B`*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T
M<FEN9R`D861D<F5S<R!4:&4@861D<F5S<V5S('1O('-P;&ET+@H@("`@("H@
M0')E='5R;B!B;V]L96%N(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-P;&ET061D<F5S<V5S*"1A9&1R97-S*0H@("`@>PH*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3YL:6UI="D@04Y$(&-O=6YT*"1T
M:&ES+3YA9&1R97-S97,I(#T]("1T:&ES+3YL:6UI="D@>PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]I
M<T=R;W5P*"1A9&1R97-S*2`F)B`A:7-S970H)'1H:7,M/F5R<F]R*2D@>PH@
M("`@("`@("`@("`D<W!L:71?8VAA<B`]("<[)SL*("`@("`@("`@("`@)&ES
M7V=R;W5P("`@/2!T<G5E.PH@("`@("`@('T@96QS96EF("@A:7-S970H)'1H
M:7,M/F5R<F]R*2D@>PH@("`@("`@("`@("`D<W!L:71?8VAA<B`]("<L)SL*
M("`@("`@("`@("`@)&ES7V=R;W5P("`@/2!F86QS93L*("`@("`@("!](&5L
M<V5I9B`H:7-S970H)'1H:7,M/F5R<F]R*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!3<&QI="!T:&4@<W1R
M:6YG(&)A<V5D(&]N('1H92!A8F]V92!T96X@;W(@<V\@;&EN97,N"B`@("`@
M("`@)'!A<G1S("`](&5X<&QO9&4H)'-P;&ET7V-H87(L("1A9&1R97-S*3L*
M("`@("`@("`D<W1R:6YG(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@
M)'-P;&ET7V-H87(I.PH*("`@("`@("`O+R!)9B!A(&=R;W5P+BXN"B`@("`@
M("`@:68@*"1I<U]G<F]U<"D@>PH@("`@("`@("`@("`O+R!)9B`D<W1R:6YG
M(&1O97,@;F]T(&-O;G1A:6X@82!C;VQO;B!O=71S:61E(&]F"B`@("`@("`@
M("`@("\O(&)R86-K971S+W%U;W1E<R!E=&,@=&AE;B!S;VUE=&AI;F<G<R!F
M=6)A<BX*"B`@("`@("`@("`@("\O($9I<G-T(&-H96-K('1H97)E)W,@82!C
M;VQO;B!A="!A;&PZ"B`@("`@("`@("`@(&EF("AS=')P;W,H)'-T<FEN9RP@
M)SHG*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O
M<B`]("=);G9A;&ED(&%D9')E<W,Z("<@+B`D<W1R:6YG.PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!.;W<@8VAE8VL@:70G<R!O=71S:61E(&]F(&)R86-K971S+W%U;W1E
M<SH*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W-P;&ET0VAE8VLH97AP;&]D
M92@G.B<L("1S=')I;F<I+"`G.B<I*0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH*("`@("`@("`@("`@+R\@5V4@;75S="!H879E(&$@9W)O=7`@
M870@=&AI<R!P;VEN="P@<V\@:6YC<F5A<V4@=&AE(&-O=6YT97(Z"B`@("`@
M("`@("`@("1T:&ES+3YN=6U?9W)O=7!S*RL["B`@("`@("`@?0H*("`@("`@
M("`O+R`D<W1R:6YG(&YO=R!C;VYT86EN<R!T:&4@9FER<W0@9G5L;"!A9&1R
M97-S+V=R;W5P+@H@("`@("`@("\O($%D9"!T;R!T:&4@861D<F5S<V5S(&%R
M<F%Y+@H@("`@("`@("1T:&ES+3YA9&1R97-S97-;72`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A9&1R97-S)R`]/B!T
M<FEM*"1S=')I;F<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=G<F]U<"<@("`]/B`D:7-?9W)O=7`*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`O+R!296UO=F4@=&AE(&YO
M=R!S=&]R960@861D<F5S<R!F<F]M('1H92!I;FET:6%L(&QI;F4L('1H92`K
M,0H@("`@("`@("\O(&ES('1O(&%C8V]U;G0@9F]R('1H92!E>'!L;V1E(&-H
M87)A8W1E<BX*("`@("`@("`D861D<F5S<R`]('1R:6TH<W5B<W1R*"1A9&1R
M97-S+"!S=')L96XH)'-T<FEN9RD@*R`Q*2D["@H@("`@("`@("\O($EF('1H
M92!N97AT(&-H87(@:7,@82!C;VUM82!A;F0@=&AI<R!W87,@82!G<F]U<"P@
M=&AE;@H@("`@("`@("\O('1H97)E(&%R92!M;W)E(&%D9')E<W-E<RP@;W1H
M97)W:7-E+"!I9B!T:&5R92!A<F4@86YY(&UO<F4*("`@("`@("`O+R!C:&%R
M<RP@=&AE;B!T:&5R92!I<R!A;F]T:&5R(&%D9')E<W,N"B`@("`@("`@:68@
M*"1I<U]G<F]U<"`F)B!S=6)S='(H)&%D9')E<W,L(#`L(#$I(#T]("<L)RE[
M"B`@("`@("`@("`@("1A9&1R97-S(#T@=')I;2AS=6)S='(H)&%D9')E<W,L
M(#$I*3L*("`@("`@("`@("`@<F5T=7)N("1A9&1R97-S.PH*("`@("`@("!]
M(&5L<V5I9B`H<W1R;&5N*"1A9&1R97-S*2`^(#`I('L*("`@("`@("`@("`@
M<F5T=7)N("1A9&1R97-S.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!Y;W4@9V]T
M(&AE<F4@=&AE;B!S;VUE=&AI;F<G<R!O9F8*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@9F]R(&$@9W)O=7`@
M870@=&AE('-T87)T(&]F('1H92!S=')I;F<N"B`@("`@*B`*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<F5S<R!4
M:&4@861D<F5S<R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@8F]O;&5A;B!7
M:&5T:&5R(&]R(&YO="!T:&5R92!I<R!A(&=R;W5P(&%T('1H92!S=&%R="!O
M9B!T:&4@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:7-'<F]U<"@D
M861D<F5S<RD*("`@('L*("`@("`@("`O+R!&:7)S="!C;VUM82!N;W0@:6X@
M<75O=&5S+"!A;F=L97,@;W(@97-C87!E9#H*("`@("`@("`D<&%R=',@(#T@
M97AP;&]D92@G+"<L("1A9&1R97-S*3L*("`@("`@("`D<W1R:6YG(#T@)'1H
M:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)RPG*3L*"B`@("`@("`@+R\@3F]W
M('=E(&AA=F4@=&AE(&9I<G-T(&%D9')E<W,L('=E(&-A;B!R96QI86)L>2!C
M:&5C:R!F;W(@80H@("`@("`@("\O(&=R;W5P(&)Y('-E87)C:&EN9R!F;W(@
M82!C;VQO;B!T:&%T)W,@;F]T(&5S8V%P960@;W(@:6X*("`@("`@("`O+R!Q
M=6]T97,@;W(@86YG;&4@8G)A8VME=',N"B`@("`@("`@:68@*&-O=6YT*"1P
M87)T<R`](&5X<&QO9&4H)SHG+"`D<W1R:6YG*2D@/B`Q*2!["B`@("`@("`@
M("`@("1S=')I;F<R(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)SHG
M*3L*("`@("`@("`@("`@<F5T=7)N("@D<W1R:6YG,B`A/3T@)'-T<FEN9RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($$@8V]M;6]N(&9U;F-T
M:6]N('1H870@=VEL;"!C:&5C:R!A;B!E>'!L;V1E9"!S=')I;F<N"B`@("`@
M*B`*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)T<R!4:&4@97AL;V1E9"!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C:&%R("!4:&4@8VAA<B!T:&%T('=A<R!E>'!L;V1E9"!O;BX*("`@
M("`J($!R971U<FX@;6EX960@1F%L<V4@:68@=&AE('-T<FEN9R!C;VYT86EN
M<R!U;F-L;W-E9"!Q=6]T97,O8G)A8VME=',L(&]R('1H92!S=')I;F<@;VX@
M<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-P;&ET0VAE8VLH)'!A
M<G1S+"`D8VAA<BD*("`@('L*("`@("`@("`D<W1R:6YG(#T@)'!A<G1S6S!=
M.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<&%R=',I.R`D
M:2LK*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7VAA<U5N8VQO<V5D475O
M=&5S*"1S=')I;F<I"B`@("`@("`@("`@("`@("!\?"`D=&AI<RT^7VAA<U5N
M8VQO<V5D0G)A8VME=',H)'-T<FEN9RP@)SP^)RD*("`@("`@("`@("`@("`@
M('Q\("1T:&ES+3Y?:&%S56YC;&]S961"<F%C:V5T<R@D<W1R:6YG+"`G6UTG
M*0H@("`@("`@("`@("`@("`@?'P@)'1H:7,M/E]H87-5;F-L;W-E9$)R86-K
M971S*"1S=')I;F<L("<H*2<I"B`@("`@("`@("`@("`@("!\?"!S=6)S='(H
M)'-T<FEN9RP@+3$I(#T]("=<7"<I('L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<&%R='-;)&D@*R`Q72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<W1R:6YG(#T@)'-T<FEN9R`N("1C:&%R("X@)'!A<G1S6R1I("L@,5T["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YE<G)O<B`]("=);G9A;&ED(&%D9')E<W,@<W!E8RX@56YC;&]S960@
M8G)A8VME="!O<B!Q=6]T97,G.PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YI;F1E>"`]("1I.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<W1R:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VMS(&EF(&$@<W1R:6YG(&AA<R!A;B!U;F-L;W-E9"!Q=6]T97,@;W(@;F]T
M+@H@("`@("H@"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A
M;2!S=')I;F<@)'-T<FEN9R!4:&4@<W1R:6YG('1O(&-H96-K+@H@("`@("H@
M0')E='5R;B!B;V]L96%N(%1R=64@:68@=&AE<F4@87)E('5N8VQO<V5D('%U
M;W1E<R!I;G-I9&4@=&AE('-T<FEN9RP@9F%L<V4@;W1H97)W:7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?:&%S56YC;&]S9611=6]T97,H)'-T<FEN9RD*
M("`@('L*("`@("`@("`D<W1R:6YG("`@("`](&5X<&QO9&4H)R(G+"`D<W1R
M:6YG*3L*("`@("`@("`D<W1R:6YG7V-N="`](&-O=6YT*"1S=')I;F<I.PH*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`H8V]U;G0H)'-T<FEN9RD@+2`Q
M*3L@)&DK*RD*("`@("`@("`@("`@:68@*'-U8G-T<B@D<W1R:6YG6R1I72P@
M+3$I(#T]("=<7"<I"B`@("`@("`@("`@("`@("`D<W1R:6YG7V-N="TM.PH*
M("`@("`@("!R971U<FX@*"1S=')I;F=?8VYT("4@,B`]/3T@,"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!S=')I;F<@:&%S(&%N('5N
M8VQO<V5D(&)R86-K971S(&]R(&YO="X@24U03U)404Y4.@H@("`@("H@5&AI
M<R!F=6YC=&EO;B!H86YD;&5S(&)O=&@@86YG;&4@8G)A8VME=',@86YD('-Q
M=6%R92!B<F%C:V5T<SL*("`@("`J(`H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@5&AE('-T<FEN9R!T;R!C
M:&5C:RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S("!4:&4@8VAA<F%C
M=&5R<R!T;R!C:&5C:R!F;W(N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5')U
M92!I9B!T:&5R92!A<F4@=6YC;&]S960@8G)A8VME=',@:6YS:61E('1H92!S
M=')I;F<L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7VAA<U5N8VQO<V5D0G)A8VME=',H)'-T<FEN9RP@)&-H87)S*0H@("`@>PH@
M("`@("`@("1N=6U?86YG;&5?<W1A<G0@/2!S=6)S=')?8V]U;G0H)'-T<FEN
M9RP@)&-H87)S6S!=*3L*("`@("`@("`D;G5M7V%N9VQE7V5N9"`@(#T@<W5B
M<W1R7V-O=6YT*"1S=')I;F<L("1C:&%R<ULQ72D["@H@("`@("`@("1T:&ES
M+3Y?:&%S56YC;&]S961"<F%C:V5T<U-U8B@D<W1R:6YG+"`D;G5M7V%N9VQE
M7W-T87)T+"`D8VAA<G-;,%TI.PH@("`@("`@("1T:&ES+3Y?:&%S56YC;&]S
M961"<F%C:V5T<U-U8B@D<W1R:6YG+"`D;G5M7V%N9VQE7V5N9"P@)&-H87)S
M6S%=*3L*"B`@("`@("`@:68@*"1N=6U?86YG;&5?<W1A<G0@/"`D;G5M7V%N
M9VQE7V5N9"D@>PH@("`@("`@("`@("`D=&AI<RT^97)R;W(@/2`G26YV86QI
M9"!A9&1R97-S('-P96,N(%5N;6%T8VAE9"!Q=6]T92!O<B!B<F%C:V5T("@G
M("X@)&-H87)S("X@)RDG.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("@D;G5M7V%N9VQE
M7W-T87)T(#X@)&YU;5]A;F=L95]E;F0I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-U8B!F=6YC=&EO;B!T:&%T(&ES('5S960@;VYL>2!B
M>2!H87-5;F-L;W-E9$)R86-K971S*"DN"B`@("`@*B`*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG(%1H92!S
M=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@:6YT96=E<B`F)&YU;2`@
M("!4:&4@;G5M8F5R(&]F(&]C8W5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C:&%R("`@5&AE(&-H87)A8W1E<B!T;R!C;W5N="X*("`@("`J($!R
M971U<FX@:6YT96=E<B!4:&4@;G5M8F5R(&]F(&]C8W5R96YC97,@;V8@)&-H
M87(@:6X@)'-T<FEN9RP@861J=7-T960@9F]R(&)A8VMS;&%S:&5S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?:&%S56YC;&]S961"<F%C:V5T<U-U8B@D<W1R
M:6YG+"`F)&YU;2P@)&-H87(I"B`@("!["B`@("`@("`@)'!A<G1S(#T@97AP
M;&]D92@D8VAA<BP@)'-T<FEN9RD["B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)'!A<G1S*3L@)&DK*RE["B`@("`@("`@("`@(&EF("AS=6)S
M='(H)'!A<G1S6R1I72P@+3$I(#T]("=<7"<@?'P@)'1H:7,M/E]H87-5;F-L
M;W-E9%%U;W1E<R@D<&%R='-;)&E=*2D*("`@("`@("`@("`@("`@("1N=6TM
M+3L*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T<ULD:2`K(#%=*2D*("`@
M("`@("`@("`@("`@("1P87)T<ULD:2`K(#%=(#T@)'!A<G1S6R1I72`N("1C
M:&%R("X@)'!A<G1S6R1I("L@,5T["B`@("`@("`@?0H@("`@("`@(`H@("`@
M("`@(')E='5R;B`D;G5M.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I
M;VX@=&\@8F5G:6X@8VAE8VMI;F<@=&AE(&%D9')E<W,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R
M97-S(%1H92!A9&1R97-S('1O('9A;&ED871E+@H@("`@("H@0')E='5R;B!M
M:7AE9"!&86QS92!O;B!F86EL=7)E+"!O<B!A('-T<G5C='5R960@87)R87D@
M;V8@861D<F5S<R!I;F9O<FUA=&EO;B!O;B!S=6-C97-S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?=F%L:61A=&5!9&1R97-S*"1A9&1R97-S*0H@("`@>PH@
M("`@("`@("1I<U]G<F]U<"`](&9A;'-E.PH*("`@("`@("!I9B`H)&%D9')E
M<W-;)V=R;W5P)UTI('L*("`@("`@("`@("`@)&ES7V=R;W5P(#T@=')U93L*
M"B`@("`@("`@("`@("\O($=E="!T:&4@9W)O=7`@<&%R="!O9B!T:&4@;F%M
M90H@("`@("`@("`@("`D<&%R=',@("`@(#T@97AP;&]D92@G.B<L("1A9&1R
M97-S6R=A9&1R97-S)UTI.PH@("`@("`@("`@("`D9W)O=7!N86UE(#T@)'1H
M:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)SHG*3L*("`@("`@("`@("`@)'-T
M<G5C='5R92`](&%R<F%Y*"D["@H@("`@("`@("`@("`O+R!!;F0@=F%L:61A
M=&4@=&AE(&=R;W5P('!A<G0@;V8@=&AE(&YA;64N"B`@("`@("`@("`@(&EF
M("@A)'1H:7,M/E]V86QI9&%T95!H<F%S92@D9W)O=7!N86UE*2E["B`@("`@
M("`@("`@("`@("`D=&AI<RT^97)R;W(@/2`G1W)O=7`@;F%M92!D:60@;F]T
M('9A;&ED871E+B<["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!$;VXG="!I
M;F-L=61E(&=R;W5P<R!I9B!W92!A<F4@;F]T(&YE<W1I;F<*("`@("`@("`@
M("`@("`@("\O('1H96TN(%1H:7,@879O:61S(')E='5R;FEN9R!I;G9A;&ED
M(&%D9')E<W-E<RX*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;F5S=$=R
M;W5P<RD@>PH@("`@("`@("`@("`@("`@("`@("1S=')U8W1U<F4@/2!N97<@
M<W1D0VQA<W,["B`@("`@("`@("`@("`@("`@("`@)'-T<G5C='5R92T^9W)O
M=7!N86UE(#T@)&=R;W5P;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&%D9')E<W-;)V%D9')E<W,G72`](&QT
M<FEM*'-U8G-T<B@D861D<F5S<ULG861D<F5S<R==+"!S=')L96XH)&=R;W5P
M;F%M92`N("<Z)RDI*3L*("`@("`@("!]"@H@("`@("`@("\O($EF(&$@9W)O
M=7`@=&AE;B!S<&QI="!O;B!C;VUM82!A;F0@<'5T(&EN=&\@86X@87)R87DN
M"B`@("`@("`@+R\@3W1H97)W:7-E+"!*=7-T('!U="!T:&4@=VAO;&4@861D
M<F5S<R!I;B!A;B!A<G)A>2X*("`@("`@("!I9B`H)&ES7V=R;W5P*2!["B`@
M("`@("`@("`@('=H:6QE("AS=')L96XH)&%D9')E<W-;)V%D9')E<W,G72D@
M/B`P*2!["B`@("`@("`@("`@("`@("`D<&%R=',@("`@("`@/2!E>'!L;V1E
M*"<L)RP@)&%D9')E<W-;)V%D9')E<W,G72D["B`@("`@("`@("`@("`@("`D
M861D<F5S<V5S6UT@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G+"<I
M.PH@("`@("`@("`@("`@("`@)&%D9')E<W-;)V%D9')E<W,G72`]('1R:6TH
M<W5B<W1R*"1A9&1R97-S6R=A9&1R97-S)UTL('-T<FQE;BAE;F0H)&%D9')E
M<W-E<RD@+B`G+"<I*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D861D<F5S<V5S6UT@/2`D861D<F5S<ULG861D<F5S
M<R==.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@=&AA="`D861D<F5S
M<V5S(&ES('-E="P@:68@861D<F5S<R!L:6ME('1H:7,Z"B`@("`@("`@+R\@
M1W)O=7!N86UE.CL*("`@("`@("`O+R!4:&5N(&5R<F]R<R!W97)E(&%P<&5A
M<FEN9RX*("`@("`@("!I9B`H(6ES<V5T*"1A9&1R97-S97,I*7L*("`@("`@
M("`@("`@)'1H:7,M/F5R<F]R(#T@)T5M<'1Y(&=R;W5P+B<["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1A9&1R97-S97,I.R`D:2LK*2!["B`@("`@("`@
M("`@("1A9&1R97-S97-;)&E=(#T@=')I;2@D861D<F5S<V5S6R1I72D["B`@
M("`@("`@?0H*("`@("`@("`O+R!686QI9&%T92!E86-H(&UA:6QB;W@N"B`@
M("`@("`@+R\@1F]R;6%T(&-O=6QD(&)E(&]N92!O9CH@;F%M92`\9V5E>F5R
M0&1O;6%I;BYC;VT^"B`@("`@("`@+R\@("`@("`@("`@("`@("`@("`@("`@
M("`@9V5E>F5R0&1O;6%I;BYC;VT*("`@("`@("`O+R`@("`@("`@("`@("`@
M("`@("`@("`@("!G965Z97(*("`@("`@("`O+R`N+BX@;W(@86YY(&]T:&5R
M(&9O<FUA="!V86QI9"!B>2!21D,@.#(R+@H@("`@("`@(&%R<F%Y7W=A;&LH
M)&%D9')E<W-E<RP@87)R87DH)'1H:7,L("=V86QI9&%T94UA:6QB;W@G*2D[
M"@H@("`@("`@("\O($YE<W1E9"!F;W)M870*("`@("`@("!I9B`H)'1H:7,M
M/FYE<W1'<F]U<',I('L*("`@("`@("`@("`@:68@*"1I<U]G<F]U<"D@>PH@
M("`@("`@("`@("`@("`@)'-T<G5C='5R92T^861D<F5S<V5S(#T@)&%D9')E
M<W-E<SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S
M=')U8W1U<F4@/2`D861D<F5S<V5S6S!=.PH@("`@("`@("`@("!]"@H@("`@
M("`@("\O($9L870@9F]R;6%T"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"1I<U]G<F]U<"D@>PH@("`@("`@("`@("`@("`@)'-T<G5C='5R
M92`](&%R<F%Y7VUE<F=E*"1S=')U8W1U<F4L("1A9&1R97-S97,I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-T<G5C='5R92`]
M("1A9&1R97-S97,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<W1R=6-T=7)E.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N
M8W1I;VX@=&\@=F%L:61A=&4@82!P:')A<V4N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1P:')A<V4@5&AE
M('!H<F%S92!T;R!C:&5C:RX*("`@("`J($!R971U<FX@8F]O;&5A;B!3=6-C
M97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T
M95!H<F%S92@D<&AR87-E*0H@("`@>PH@("`@("`@("\O(%-P;&ET<R!O;B!O
M;F4@;W(@;6]R92!486(@;W(@<W!A8V4N"B`@("`@("`@)'!A<G1S(#T@<')E
M9U]S<&QI="@G+UL@7%QX,#E=*R\G+"`D<&AR87-E+"`M,2P@4%)%1U]34$Q)
M5%].3U]%35!462D["@H@("`@("`@("1P:')A<V5?<&%R=',@/2!A<G)A>2@I
M.PH@("`@("`@('=H:6QE("AC;W5N="@D<&%R=',I(#X@,"E["B`@("`@("`@
M("`@("1P:')A<V5?<&%R='-;72`]("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R
M=',L("<@)RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1T:&ES
M+3YI;F1E>"`K(#$[("1I*RLI"B`@("`@("`@("`@("`@("!A<G)A>5]S:&EF
M="@D<&%R=',I.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)'!H<F%S95]P87)T<RD[("1I*RLI('L*("`@("`@("`@("`@
M+R\@268@<75O=&5D('-T<FEN9SH*("`@("`@("`@("`@:68@*'-U8G-T<B@D
M<&AR87-E7W!A<G1S6R1I72P@,"P@,2D@/3T@)R(G*2!["B`@("`@("`@("`@
M("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&51=6]T9613=')I;F<H)'!H<F%S
M95]P87)T<ULD:5TI*0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O+R!/=&AE<G=I<V4@:70G<R!A;B!A=&]M.@H@("`@("`@
M("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&5!=&]M*"1P:')A<V5?<&%R='-;
M)&E=*2D@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI
M9&%T92!A;B!A=&]M('=H:6-H(&9R;VT@<F9C.#(R(&ES.@H@("`@("H@871O
M;2`](#$J/&%N>2!#2$%2(&5X8V5P="!S<&5C:6%L<RP@4U!!0T4@86YD($-4
M3',^"B`@("`@*B`*("`@("`J($EF('9A;&ED871I;VX@*"1T:&ES+3YV86QI
M9&%T92D@:&%S(&)E96X@='5R;F5D(&]F9BP@=&AE;@H@("`@("H@=F%L:61A
M=&5!=&]M*"D@9&]E<VXG="!A8W1U86QL>2!C:&5C:R!A;GET:&EN9RX@5&AI
M<R!I<R!S;R!T:&%T('EO=0H@("`@("H@8V%N('-P;&ET(&$@;&ES="!O9B!A
M9&1R97-S97,@=7`@8F5F;W)E(&5N8V]D:6YG('!E<G-O;F%L(&YA;65S"B`@
M("`@*B`H=6UL875T<RP@971C+BDL(&9O<B!E>&%M<&QE+@H@("`@("H@"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)&%T
M;VT@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@8F]O;&5A
M;B!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V
M86QI9&%T94%T;VTH)&%T;VTI"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^
M=F%L:61A=&4I('L*("`@("`@("`@("`@+R\@5F%L:61A=&EO;B!H87,@8F5E
M;B!T=7)N960@;V9F.R!A<W-U;64@=&AE(&%T;VT@:7,@;VMA>2X*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C
M:R!F;W(@86YY(&-H87(@9G)O;2!!4T-)22`P("T@05-#24D@,3(W"B`@("`@
M("`@:68@*"%P<F5G7VUA=&-H*"<O7EM<7'@P,"U<7'@W15TK)"]I)RP@)&%T
M;VTL("1M871C:&5S*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@<W!E8VEA;',Z"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R];75LH*3P^0"P[7%PZ(BX@72\G+"`D871O
M;2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+R\@0VAE8VL@9F]R(&-O;G1R;VP@8VAA<F%C=&5R<R`H05-#24D@
M,"TS,2DZ"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R];7%QX,#`M7%QX,49=
M*R\G+"`D871O;2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!Q=6]T960@<W1R:6YG+"!W:&EC
M:"!I<SH*("`@("`J('%U;W1E9"US=')I;F<@/2`\(CX@*BAQ=&5X="]Q=6]T
M960M<&%I<BD@/"(^"B`@("`@*B`*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<7-T<FEN9R!4:&4@<W1R:6YG('1O(&-H
M96-K"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&51=6]T9613=')I;F<H
M)'%S=')I;F<I"B`@("!["B`@("`@("`@+R\@3&5A9&EN9R!A;F0@=')A:6QI
M;F<@(@H@("`@("`@("1Q<W1R:6YG(#T@<W5B<W1R*"1Q<W1R:6YG+"`Q+"`M
M,2D["@H@("`@("`@("\O(%!E<F9O<FT@8VAE8VLN"B`@("`@("`@<F5T=7)N
M("$H<')E9U]M871C:"@G+R@N*5M<>#!$7%Q<7")=+R<L("1Q<W1R:6YG+"`D
M;6%T8VAE<RD@)B8@)&UA=&-H97-;,5T@(3T@)UQ<)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A(&UA:6QB;W@L('=H
M:6-H(&ES.@H@("`@("H@;6%I;&)O>"`]("`@861D<BUS<&5C("`@("`@("`@
M.R!S:6UP;&4@861D<F5S<PH@("`@("H@("`@("`@("`@("\@<&AR87-E(')O
M=71E+6%D9'(@.R!N86UE(&%N9"!R;W5T92UA9&1R"B`@("`@*B`*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("8D;6%I;&)O
M>"!4:&4@<W1R:6YG('1O(&-H96-K+@H@("`@("H@0')E='5R;B!B;V]L96%N
M(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L
M:61A=&5-86EL8F]X*"8D;6%I;&)O>"D*("`@('L*("`@("`@("`O+R!!(&-O
M=7!L92!O9B!D969A=6QT<RX*("`@("`@("`D<&AR87-E("`]("<G.PH@("`@
M("`@("1C;VUM96YT(#T@)R<["B`@("`@("`@)&-O;6UE;G1S(#T@87)R87DH
M*3L*"B`@("`@("`@+R\@0V%T8V@@86YY(%)&0S@R,B!C;VUM96YT<R!A;F0@
M<W1O<F4@=&AE;2!S97!A<F%T96QY"B`@("`@("`@)%]M86EL8F]X(#T@)&UA
M:6QB;W@["B`@("`@("`@=VAI;&4@*'-T<FQE;BAT<FEM*"1?;6%I;&)O>"DI
M(#X@,"D@>PH@("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<H)RP@)%]M
M86EL8F]X*3L*("`@("`@("`@("`@)&)E9F]R95]C;VUM96YT(#T@)'1H:7,M
M/E]S<&QI=$-H96-K*"1P87)T<RP@)R@G*3L*("`@("`@("`@("`@:68@*"1B
M969O<F5?8V]M;65N="`A/2`D7VUA:6QB;W@I('L*("`@("`@("`@("`@("`@
M("\O($9I<G-T(&-H87(@<VAO=6QD(&)E(&$@*`H@("`@("`@("`@("`@("`@
M)&-O;6UE;G0@("`@/2!S=6)S='(H<W1R7W)E<&QA8V4H)&)E9F]R95]C;VUM
M96YT+"`G)RP@)%]M86EL8F]X*2P@,2D["B`@("`@("`@("`@("`@("`D<&%R
M=',@("`@("`](&5X<&QO9&4H)RDG+"`D8V]M;65N="D["B`@("`@("`@("`@
M("`@("`D8V]M;65N="`@("`]("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R=',L
M("<I)RD["B`@("`@("`@("`@("`@("`D8V]M;65N='-;72`]("1C;VUM96YT
M.PH*("`@("`@("`@("`@("`@("\O("LQ(&ES(&9O<B!T:&4@=')A:6QI;F<@
M*0H@("`@("`@("`@("`@("`@)%]M86EL8F]X("`@/2!S=6)S='(H)%]M86EL
M8F]X+"!S=')P;W,H)%]M86EL8F]X+"`D8V]M;65N="DK<W1R;&5N*"1C;VUM
M96YT*2LQ*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D8V]M;65N=',@87,@)&-O;6UE;G0I('L*("`@("`@("`@("`@)&UA
M:6QB;W@@/2!S=')?<F5P;&%C92@B*"1C;VUM96YT*2(L("<G+"`D;6%I;&)O
M>"D["B`@("`@("`@?0H*("`@("`@("`D;6%I;&)O>"`]('1R:6TH)&UA:6QB
M;W@I.PH*("`@("`@("`O+R!#:&5C:R!F;W(@;F%M92`K(')O=71E+6%D9'(*
M("`@("`@("!I9B`H<W5B<W1R*"1M86EL8F]X+"`M,2D@/3T@)SXG("8F('-U
M8G-T<B@D;6%I;&)O>"P@,"P@,2D@(3T@)SPG*2!["B`@("`@("`@("`@("1P
M87)T<R`@/2!E>'!L;V1E*"<\)RP@)&UA:6QB;W@I.PH@("`@("`@("`@("`D
M;F%M92`@(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)SPG*3L*"B`@
M("`@("`@("`@("1P:')A<V4@("`@(#T@=')I;2@D;F%M92D["B`@("`@("`@
M("`@("1R;W5T95]A9&1R(#T@=')I;2AS=6)S='(H)&UA:6QB;W@L('-T<FQE
M;B@D;F%M92XG/"<I+"`M,2DI.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M=F%L:61A=&50:')A<V4H)'!H<F%S92D@/3T](&9A;'-E('Q\("@D<F]U=&5?
M861D<B`]("1T:&ES+3Y?=F%L:61A=&52;W5T94%D9'(H)')O=71E7V%D9'(I
M*2`]/3T@9F%L<V4I"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["@H@
M("`@("`@("\O($]N;'D@9V]T(&%D9'(M<W!E8PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O($9I<G-T('-N:7`@86YG;&4@8G)A8VME=',@:68@
M<')E<V5N="X*("`@("`@("`@("`@:68@*'-U8G-T<B@D;6%I;&)O>"PP+#$I
M(#T]("<\)R`F)B!S=6)S='(H)&UA:6QB;W@L+3$I(#T]("<^)RD*("`@("`@
M("`@("`@("`@("1A9&1R7W-P96,@/2!S=6)S='(H)&UA:6QB;W@L,2PM,2D[
M"B`@("`@("`@("`@(&5L<V4*("`@("`@("`@("`@("`@("1A9&1R7W-P96,@
M/2`D;6%I;&)O>#L*"B`@("`@("`@("`@(&EF("@H)&%D9')?<W!E8R`]("1T
M:&ES+3Y?=F%L:61A=&5!9&1R4W!E8R@D861D<E]S<&5C*2D@/3T](&9A;'-E
M*0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+R\@0V]N<W1R=6-T('1H92!O8FIE8W0@=&AA="!W:6QL(&)E(')E
M='5R;F5D+@H@("`@("`@("1M8F]X(#T@;F5W('-T9$-L87-S*"D["@H@("`@
M("`@("\O($%D9"!T:&4@<&AR87-E("AE=F5N(&EF(&5M<'1Y*2!A;F0@8V]M
M;65N=',*("`@("`@("`D;6)O>"T^<&5R<V]N86P@/2`D<&AR87-E.PH@("`@
M("`@("1M8F]X+3YC;VUM96YT("`](&ES<V5T*"1C;VUM96YT<RD@/R`D8V]M
M;65N=',@.B!A<G)A>2@I.PH*("`@("`@("!I9B`H:7-S970H)')O=71E7V%D
M9'(I*2!["B`@("`@("`@("`@("1M8F]X+3YM86EL8F]X(#T@)')O=71E7V%D
M9');)VQO8V%L7W!A<G0G73L*("`@("`@("`@("`@)&UB;W@M/FAO<W0@("`@
M/2`D<F]U=&5?861D<ELG9&]M86EN)UT["B`@("`@("`@("`@("1R;W5T95]A
M9&1R6R=A9&PG72`A/3T@)R<@/R`D;6)O>"T^861L(#T@)')O=71E7V%D9');
M)V%D;"==(#H@)R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UB
M;W@M/FUA:6QB;W@@/2`D861D<E]S<&5C6R=L;V-A;%]P87)T)UT["B`@("`@
M("`@("`@("1M8F]X+3YH;W-T("`@(#T@)&%D9')?<W!E8ULG9&]M86EN)UT[
M"B`@("`@("`@?0H*("`@("`@("`D;6%I;&)O>"`]("1M8F]X.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC
M=&EO;B!V86QI9&%T97,@82!R;W5T92UA9&1R('=H:6-H(&ES.@H@("`@("H@
M<F]U=&4M861D<B`]("(\(B!;<F]U=&5=(&%D9'(M<W!E8R`B/B(*("`@("`J
M"B`@("`@*B!!;F=L92!B<F%C:V5T<R!H879E(&%L<F5A9'D@8F5E;B!R96UO
M=F5D(&%T('1H92!P;VEN="!O9@H@("`@("H@9V5T=&EN9R!T;R!T:&ES(&9U
M;F-T:6]N+@H@("`@("H@"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M($!P87)A;2!S=')I;F<@)')O=71E7V%D9'(@5&AE('-T<FEN9R!T;R!C:&5C
M:RX*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@9F%I;'5R92P@;W(@
M86X@87)R87D@8V]N=&%I;FEN9R!V86QI9&%T960@861D<F5S<R]R;W5T92!I
M;F9O<FUA=&EO;B!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M=F%L:61A=&52;W5T94%D9'(H)')O=71E7V%D9'(I"B`@("!["B`@("`@("`@
M+R\@0VAE8VL@9F]R(&-O;&]N+@H@("`@("`@(&EF("AS=')P;W,H)')O=71E
M7V%D9'(L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)T<R`]
M(&5X<&QO9&4H)SHG+"`D<F]U=&5?861D<BD["B`@("`@("`@("`@("1R;W5T
M92`]("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R=',L("<Z)RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)')O=71E(#T@)')O=71E7V%D9'(["B`@
M("`@("`@?0H*("`@("`@("`O+R!)9B`D<F]U=&4@:7,@<V%M92!A<R`D<F]U
M=&5?861D<B!T:&5N('1H92!C;VQO;B!W87,@:6X*("`@("`@("`O+R!Q=6]T
M97,@;W(@8G)A8VME=',@;W(L(&]F(&-O=7)S92P@;F]N(&5X:7-T96YT+@H@
M("`@("`@(&EF("@D<F]U=&4@/3T]("1R;W5T95]A9&1R*7L*("`@("`@("`@
M("`@=6YS970H)')O=71E*3L*("`@("`@("`@("`@)&%D9')?<W!E8R`]("1R
M;W5T95]A9&1R.PH@("`@("`@("`@("!I9B`H*"1A9&1R7W-P96,@/2`D=&AI
M<RT^7W9A;&ED871E061D<E-P96,H)&%D9')?<W!E8RDI(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@5F%L:61A=&4@<F]U
M=&4@<&%R="X*("`@("`@("`@("`@:68@*"@D<F]U=&4@/2`D=&AI<RT^7W9A
M;&ED871E4F]U=&4H)')O=71E*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1A9&1R7W-P96,@/2!S=6)S='(H)')O=71E7V%D9'(L('-T<FQE;B@D<F]U
M=&4@+B`G.B<I*3L*"B`@("`@("`@("`@("\O(%9A;&ED871E(&%D9'(M<W!E
M8R!P87)T+@H@("`@("`@("`@("!I9B`H*"1A9&1R7W-P96,@/2`D=&AI<RT^
M7W9A;&ED871E061D<E-P96,H)&%D9')?<W!E8RDI(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)')O=71E*2D@>PH@("`@("`@
M("`@("`D<F5T=7)N6R=A9&PG72`]("1R;W5T93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<F5T=7)N6R=A9&PG72`]("<G.PH@("`@("`@('T*
M"B`@("`@("`@)')E='5R;B`](&%R<F%Y7VUE<F=E*"1R971U<FXL("1A9&1R
M7W-P96,I.PH@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@82!R;W5T92P@=VAI8V@@
M:7,Z"B`@("`@*B!R;W5T92`](#$C*")`(B!D;VUA:6XI("(Z(@H@("`@("H@
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@
M)')O=71E(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T=7)N(&UI
M>&5D($9A;'-E(&]N(&9A:6QU<F4L(&]R('1H92!V86QI9&%T960@)')O=71E
M(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T95)O
M=71E*"1R;W5T92D*("`@('L*("`@("`@("`O+R!3<&QI="!O;B!C;VUM82X*
M("`@("`@("`D9&]M86EN<R`](&5X<&QO9&4H)RPG+"!T<FEM*"1R;W5T92DI
M.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&]M86EN<RD[
M("1I*RLI('L*("`@("`@("`@("`@)&1O;6%I;G-;)&E=(#T@<W1R7W)E<&QA
M8V4H)T`G+"`G)RP@=')I;2@D9&]M86EN<ULD:5TI*3L*("`@("`@("`@("`@
M:68@*"$D=&AI<RT^7W9A;&ED871E1&]M86EN*"1D;VUA:6YS6R1I72DI(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F]U=&4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A
M(&1O;6%I;BP@=&AO=6=H('1H:7,@:7,@;F]T('%U:71E('=H870*("`@("`J
M('EO=2!E>'!E8W0@;V8@82!S=')I8W0@:6YT97)N970@9&]M86EN+@H@("`@
M("H*("`@("`J(&1O;6%I;B`]('-U8BUD;VUA:6X@*B@B+B(@<W5B+61O;6%I
M;BD*("`@("`J(`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D;VUA:6X@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J
M($!R971U<FX@;6EX960@1F%L<V4@;VX@9F%I;'5R92P@;W(@=&AE('9A;&ED
M871E9"!D;VUA:6X@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W9A;&ED871E1&]M86EN*"1D;VUA:6XI"B`@("!["B`@("`@("`@+R\@3F]T
M92!T:&4@9&EF9F5R96YT('5S92!O9B`D<W5B9&]M86EN<R!A;F0@)'-U8E]D
M;VUA:6YS("`@("`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@)'-U8F1O
M;6%I;G,@/2!E>'!L;V1E*"<N)RP@)&1O;6%I;BD["@H@("`@("`@('=H:6QE
M("AC;W5N="@D<W5B9&]M86EN<RD@/B`P*2!["B`@("`@("`@("`@("1S=6)?
M9&]M86EN<UM=(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1S=6)D;VUA:6YS+"`G
M+B<I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^:6YD
M97@@*R`Q.R`D:2LK*0H@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)'-U
M8F1O;6%I;G,I.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)'-U8E]D;VUA:6YS*3L@)&DK*RD@>PH@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?=F%L:61A=&53=6)D;VUA:6XH=')I;2@D<W5B7V1O;6%I
M;G-;)&E=*2DI"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`O+R!-86YA9V5D('1O(&=E="!H97)E+"!S;R!R971U
M<FX@:6YP=70N"B`@("`@("`@<F5T=7)N("1D;VUA:6X["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A('-U8F1O;6%I;CH*
M("`@("`J("`@<W5B9&]M86EN(#T@9&]M86EN+7)E9B`O(&1O;6%I;BUL:71E
M<F%L"B`@("`@*B`*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<W5B9&]M86EN(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&53=6)D;VUA:6XH)'-U8F1O;6%I
M;BD*("`@('L*("`@("`@("!I9B`H<')E9U]M871C:"@G?%Y<6R@N*BE=)'PG
M+"`D<W5B9&]M86EN+"`D87)R*2E["B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]V86QI9&%T941L:71E<F%L*"1A<G);,5TI*2!R971U<FX@9F%L<V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED
M871E071O;2@D<W5B9&]M86EN*2D@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1V]T(&AE<F4L('-O(')E='5R;B!S=6-C97-S9G5L+@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N
M8W1I;VX@=&\@=F%L:61A=&4@82!D;VUA:6X@;&ET97)A;#H*("`@("`J("`@
M9&]M86EN+6QI=&5R86P@/2`@(ELB("HH9'1E>'0@+R!Q=6]T960M<&%I<BD@
M(ETB"B`@("`@*B`*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&QI=&5R86P@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@
M("`J($!R971U<FX@8F]O;&5A;B!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T941L:71E<F%L*"1D;&ET97)A;"D*
M("`@('L*("`@("`@("!R971U<FX@(7!R96=?;6%T8V@H)R\H+BE;75M<>#!$
M7%Q<7%TO)RP@)&1L:71E<F%L+"`D;6%T8VAE<RD@)B8@)&UA=&-H97-;,5T@
M(3T@)UQ<)SL*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O('9A
M;&ED871E(&%N(&%D9'(M<W!E8RX*("`@("`J"B`@("`@*B!A9&1R+7-P96,@
M/2!L;V-A;"UP87)T(")`(B!D;VUA:6X*("`@("`J(`H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R7W-P96,@5&AE
M('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@
M;VX@9F%I;'5R92P@;W(@=&AE('9A;&ED871E9"!A9&1R+7-P96,@;VX@<W5C
M8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E061D<E-P96,H
M)&%D9')?<W!E8RD*("`@('L*("`@("`@("`D861D<E]S<&5C(#T@=')I;2@D
M861D<E]S<&5C*3L*"B`@("`@("`@+R\@4W!L:70@;VX@0"!S:6=N(&EF('1H
M97)E(&ES(&]N92X*("`@("`@("!I9B`H<W1R<&]S*"1A9&1R7W-P96,L("=`
M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)T<R`@("`@(#T@97AP
M;&]D92@G0"<L("1A9&1R7W-P96,I.PH@("`@("`@("`@("`D;&]C86Q?<&%R
M="`]("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R=',L("=`)RD["B`@("`@("`@
M("`@("1D;VUA:6X@("`@(#T@<W5B<W1R*"1A9&1R7W-P96,L('-T<FQE;B@D
M;&]C86Q?<&%R="`N("=`)RDI.PH*("`@("`@("`O+R!.;R!`('-I9VX@<V\@
M87-S=6UE('1H92!D969A=6QT(&1O;6%I;BX*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;&]C86Q?<&%R="`]("1A9&1R7W-P96,["B`@("`@("`@
M("`@("1D;VUA:6X@("`@(#T@)'1H:7,M/F1E9F%U;'1?9&]M86EN.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"@D;&]C86Q?<&%R="`]("1T:&ES+3Y?=F%L
M:61A=&5,;V-A;%!A<G0H)&QO8V%L7W!A<G0I*2`]/3T@9F%L<V4I(')E='5R
M;B!F86QS93L*("`@("`@("!I9B`H*"1D;VUA:6X@("`@(#T@)'1H:7,M/E]V
M86QI9&%T941O;6%I;B@D9&]M86EN*2D@/3T](&9A;'-E*2!R971U<FX@9F%L
M<V4["B`@("`@("`@"B`@("`@("`@+R\@1V]T(&AE<F4@<V\@<F5T=7)N('-U
M8V-E<W-F=6PN"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=L;V-A;%]P87)T)R`]
M/B`D;&]C86Q?<&%R="P@)V1O;6%I;B<@/3X@)&1O;6%I;BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!T:&4@;&]C86P@
M<&%R="!O9B!A;B!A9&1R97-S.@H@("`@("H@("!L;V-A;"UP87)T(#T@=V]R
M9"`J*"(N(B!W;W)D*0H@("`@("H@"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J($!P87)A;2!S=')I;F<@)&QO8V%L7W!A<G0*("`@("`J($!R971U
M<FX@;6EX960@1F%L<V4@;VX@9F%I;'5R92P@;W(@=&AE('9A;&ED871E9"!L
M;V-A;"!P87)T(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V
M86QI9&%T94QO8V%L4&%R="@D;&]C86Q?<&%R="D*("`@('L*("`@("`@("`D
M<&%R=',@/2!E>'!L;V1E*"<N)RP@)&QO8V%L7W!A<G0I.PH*("`@("`@("`O
M+R!3<&QI="!T:&4@;&]C86Q?<&%R="!I;G1O('=O<F1S+@H@("`@("`@('=H
M:6QE("AC;W5N="@D<&%R=',I(#X@,"E["B`@("`@("`@("`@("1W;W)D<UM=
M(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)RXG*3L*("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)'1H:7,M/FEN9&5X("L@,3L@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)'!A<G1S*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@5F%L:61A=&4@96%C:"!W
M;W)D+@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1W;W)D<RD[
M("1I*RLI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?=F%L:61A=&50:')A
M<V4H=')I;2@D=V]R9'-;)&E=*2D@/3T](&9A;'-E*2!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O+R!-86YA9V5D('1O(&=E="!H97)E+"!S
M;R!R971U<FX@=&AE(&EN<'5T+@H@("`@("`@(')E='5R;B`D;&]C86Q?<&%R
M=#L*("`@('T*"B`@("`O*BH*("`@("H@4F5T=7)N<R!A;B!A<'!R;WAI;6%T
M92!C;W5N="!O9B!H;W<@;6%N>2!A9&1R97-S97,@87)E"B`@("`J(&EN('1H
M92!G:79E;B!S=')I;F<N(%1H:7,@:7,@05!04D]824U!5$4@87,@:70@;VYL
M>2!S<&QI=',*("`@("H@8F%S960@;VX@82!C;VUM82!W:&EC:"!H87,@;F\@
M<')E8V5D:6YG(&)A8VMS;&%S:"X@0V]U;&0@8F4*("`@("H@=7-E9G5L(&%S
M(&QA<F=E(&%M;W5N=',@;V8@861D<F5S<V5S('=I;&P@96YD('5P('!R;V1U
M8VEN9PH@("`@*B`J;&%R9V4J('-T<G5C='5R97,@=VAE;B!U<V5D('=I=&@@
M<&%R<V5!9&1R97-S3&ES="@I+@H@("`@*@H@("`@*B!`<&%R86T@('-T<FEN
M9R`D9&%T82!!9&1R97-S97,@=&\@8V]U;G0*("`@("H@0')E='5R;B!I;G0@
M("`@("`@("`@07!P<F]X:6UA=&4@8V]U;G0*("`@("HO"B`@("!F=6YC=&EO
M;B!A<'!R;WAI;6%T94-O=6YT*"1D871A*0H@("`@>PH@("`@("`@(')E='5R
M;B!C;W5N="AP<F5G7W-P;&ET*"<O*#\\(5Q<7%PI+"\G+"`D9&%T82DI.PH@
M("`@?0H@("`@"B`@("`O*BH*("`@("H@5&AI<R!I<R!A(&5M86EL('9A;&ED
M871I;F<@9G5N8W1I;VX@<V5P97)A=&4@=&\@=&AE(')E<W0*("`@("H@;V8@
M=&AE(&-L87-S+B!)="!S:6UP;'D@=F%L:61A=&5S('=H971H97(@86X@96UA
M:6P@:7,@;V8*("`@("H@=&AE(&-O;6UO;B!I;G1E<FYE="!F;W)M.B`\=7-E
M<CY`/&1O;6%I;CXN(%1H:7,@8V%N(&)E"B`@("`J('-U9F9I8VEE;G0@9F]R
M(&UO<W0@<&5O<&QE+B!/<'1I;VYA;"!S=')I8W1E<B!M;V1E(&-A;@H@("`@
M*B!B92!U=&EL:7-E9"!W:&EC:"!R97-T<FEC=',@;6%I;&)O>"!C:&%R86-T
M97)S(&%L;&]W960*("`@("H@=&\@86QP:&%N=6UE<FEC+"!F=6QL('-T;W`L
M(&AY<&AE;B!A;F0@=6YD97)S8V]R92X*("`@("H*("`@("H@0'!A<F%M("!S
M=')I;F<@("1D871A("`@061D<F5S<R!T;R!C:&5C:PH@("`@*B!`<&%R86T@
M(&)O;VQE86X@)'-T<FEC="!/<'1I;VYA;"!S=')I8W1E<B!M;V1E"B`@("`J
M($!R971U<FX@;6EX960@("`@("`@("`@($9A;'-E(&EF(&ET(&9A:6QS+"!A
M;B!I;F1E>&5D(&%R<F%Y"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('5S97)N86UE+V1O;6%I;B!I9B!I="!M871C:&5S"B`@("`J+PH@("`@9G5N
M8W1I;VX@:7-686QI9$EN971!9&1R97-S*"1D871A+"`D<W1R:6-T(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)')E9V5X(#T@)'-T<FEC="`_("<O7BA;+C`M
M.6$M>E\M72LI0"@H6S`M.6$M>BU=*UPN*2M;,"TY82UZ77LR+#1]*20O:2<@
M.B`G+UXH6RHK(2XF(R1\7"=<7"5<+S`M.6$M>EY?8'M]/3]^.BU=*RE`*"A;
M,"TY82UZ+5TK7"XI*ULP+3EA+7I=>S(L-'TI)"]I)SL*("`@("`@("!I9B`H
M<')E9U]M871C:"@D<F5G97@L('1R:6TH)&1A=&$I+"`D;6%T8VAE<RDI('L*
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1M871C:&5S6S%=+"`D;6%T8VAE
M<ULR72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*?0H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+TUA:6PO;6EM95!A<G0N<&AP````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#,P-S$P`#$P-#$W,S8S,#`W`#`R,#4Q,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#(P,#(@(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!2
M961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O
M<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`T*+R\@?"!M;V1I9FEC871I;VXL
M(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O
M;F1I=&EO;G,@("`@?`T*+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!O(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT("`@("`@?`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<BX@("`@("`@?`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@
M9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`T*
M+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@?`T*+R\@?"`@(&1O8W5M
M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H
M('1H92!D:7-T<FEB=71I;VXN?`T*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@
M875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E
M("`@("`@?`T*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O
M9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?`T*+R\@
M?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)
M1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3
M("`@?`T*+R\@?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$
M(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?`T*+R\@?"!,
M24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y4
M04))3$E462!!3D0@1DE43D534R!&3U(@?`T*+R\@?"!!(%!!4E1)0U5,05(@
M4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%
M($-/4%E224=(5"`@?`T*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@
M3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@
M?`T*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@
M1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@("`@?`T*+R\@?"!,24U)
M5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%
M4E9)0T53.R!,3U-3($]&(%5312P@?`T*+R\@?"!$051!+"!/4B!04D]&2513
M.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.
M1"!/3B!!3ED@?`T*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52
M($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`T*
M+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE3
M24Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?`T*+R\@?"!/1B!42$E3
M(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519
M($]&(%-50T@@1$%-04=%+B`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@
M?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PT*#0HO*BH-"BH-"BH@(%)A=R!M:6UE(&5N8V]D
M:6YG(&-L87-S#0HJ#0HJ(%=H870@:7,@:70_#0HJ("`@5&AI<R!C;&%S<R!E
M;F%B;&5S('EO=2!T;R!M86YI<'5L871E(&%N9"!B=6EL9`T**B`@(&$@;6EM
M92!E;6%I;"!F<F]M('1H92!G<F]U;F0@=7`N#0HJ#0HJ(%=H>2!U<V4@=&AI
M<R!I;G-T96%D(&]F(&UI;64N<&AP/PT**B`@(&UI;64N<&AP(&ES(&$@=7-E
M<F9R:65N9&QY(&%P:2!T;R!T:&ES(&-L87-S(&9O<@T**B`@('!E;W!L92!W
M:&\@87)E;B=T(&EN=&5R97-T960@:6X@=&AE(&EN=&5R;F%L<R!O9@T**B`@
M(&UI;64@;6%I;"X@5&AI<R!C;&%S<R!H;W=E=F5R(&%L;&]W<R!F=6QL(&-O
M;G1R;VP-"BH@("!O=F5R('1H92!E;6%I;"X-"BH-"BH@16<N#0HJ#0HJ("\O
M(%-I;F-E(&UU;'1I<&%R="]M:7AE9"!H87,@;F\@<F5A;"!B;V1Y+"`H=&AE
M(&)O9'D@:7,-"BH@+R\@=&AE('-U8G!A<G0I+"!W92!S970@=&AE(&)O9'D@
M87)G=6UE;G0@=&\@8FQA;FLN#0HJ#0HJ("1P87)A;7-;)V-O;G1E;G1?='EP
M92==(#T@)VUU;'1I<&%R="]M:7AE9"<[#0HJ("1E;6%I;"`](&YE=R!-86EL
M7VUI;65087)T*"<G+"`D<&%R86US*3L-"BH-"BH@+R\@2&5R92!W92!A9&0@
M82!T97AT('!A<G0@=&\@=&AE(&UU;'1I<&%R="!W92!H879E#0HJ("\O(&%L
M<F5A9'DN($%S<W5M92`D8F]D>2!C;VYT86EN<R!P;&%I;B!T97AT+@T**@T*
M*B`D<&%R86US6R=C;VYT96YT7W1Y<&4G72`]("=T97AT+W!L86EN)SL-"BH@
M)'!A<F%M<ULG96YC;V1I;F<G72`@("`@/2`G-V)I="<[#0HJ("1T97AT(#T@
M)&5M86EL+3YA9&13=6)087)T*"1B;V1Y+"`D<&%R86US*3L-"BH-"BH@+R\@
M3F]W(&%D9"!A;B!A='1A8VAM96YT+B!!<W-U;64@)&%T=&%C:"!I<PT**B!T
M:&4@8V]N=&5N=',@;V8@=&AE(&%T=&%C:&UE;G0-"BH-"BH@)'!A<F%M<ULG
M8V]N=&5N=%]T>7!E)UT@/2`G87!P;&EC871I;VXO>FEP)SL-"BH@)'!A<F%M
M<ULG96YC;V1I;F<G72`@("`@/2`G8F%S938T)SL-"BH@)'!A<F%M<ULG9&ES
M<&]S:71I;VXG72`@/2`G871T86-H;65N="<[#0HJ("1P87)A;7-;)V1F:6QE
M;F%M92==("`@(#T@)V5X86UP;&4N>FEP)SL-"BH@)&%T=&%C:"`])B`D96UA
M:6PM/F%D9%-U8E!A<G0H)&)O9'DL("1P87)A;7,I.PT**@T**B`O+R!.;W<@
M8G5I;&0@=&AE(&5M86EL+B!.;W1E('1H870@=&AE(&5N8V]D90T**B`O+R!F
M=6YC=&EO;B!R971U<FYS(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI
M;F<@='=O#0HJ("\O(&5L96UE;G1S+"!B;V1Y(&%N9"!H96%D97)S+B!9;W4@
M=VEL;"!N965D('1O(&%D9"!E>'1R80T**B`O+R!H96%D97)S+"`H96<N($UI
M;64M5F5R<VEO;BD@8F5F;W)E('-E;F1I;F<N#0HJ#0HJ("1E;6%I;"`]("1M
M97-S86=E+3YE;F-O9&4H*3L-"BH@)&5M86EL6R=H96%D97)S)UU;72`]("=-
M:6UE+59E<G-I;VXZ(#$N,"<[#0HJ#0HJ#0HJ($9U<G1H97(@97AA;7!L97,@
M87)E(&%V86EL86)L92!A="!H='1P.B\O=W=W+G!H<&=U<G4N;W)G#0HJ#0HJ
M(%1/1$\Z#0HJ("`M(%-E="!E;F-O9&4H*2!T;R!R971U<FX@=&AE("1O8FHM
M/F5N8V]D960@:68@96YC;V1E*"D-"BH@("`@:&%S(&%L<F5A9'D@8F5E;B!R
M=6XN(%5N;&5S<R!A(&9L86<@:7,@<&%S<V5D('1O('-P96-I9FEC86QL>0T*
M*B`@("!R92UB=6EL9"!T:&4@;65S<V%G92X-"BH-"BH@0&%U=&AO<B`@4FEC
M:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U+F]R9SX-"BH@0'9E<G-I;VX@
M)%)E=FES:6]N.B`Q+C$P("0-"BH@0'!A8VMA9V4@36%I;`T**B\-"@T*8VQA
M<W,@36%I;%]M:6UE4&%R="![#0H-"B`@("\J*@T*("`@("H@5&AE(&5N8V]D
M:6YG('1Y<&4@;V8@=&AI<R!P87)T#0H@("`@*B!`=F%R('-T<FEN9PT*("`@
M("HO#0H@("`@=F%R("1?96YC;V1I;F<[#0H-"B`@("\J*@T*("`@("H@06X@
M87)R87D@;V8@<W5B<&%R=',-"B`@("`J($!V87(@87)R87D-"B`@("`J+PT*
M("`@('9A<B`D7W-U8G!A<G1S.PT*#0H@("`O*BH-"B`@("`J(%1H92!O=71P
M=70@;V8@=&AI<R!P87)T(&%F=&5R(&)E:6YG(&)U:6QT#0H@("`@*B!`=F%R
M('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1?96YC;V1E9#L-"@T*("`@+RHJ
M#0H@("`@*B!(96%D97)S(&9O<B!T:&ES('!A<G0-"B`@("`J($!V87(@87)R
M87D-"B`@("`J+PT*("`@('9A<B`D7VAE861E<G,[#0H-"B`@("\J*@T*("`@
M("H@5&AE(&)O9'D@;V8@=&AI<R!P87)T("AN;W0@96YC;V1E9"D-"B`@("`J
M($!V87(@<W1R:6YG#0H@("`@*B\-"B`@("!V87(@)%]B;V1Y.PT*#0H@("`@
M+RHJ#0H@("`@("H@0V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!3971S
M('5P('1H92!O8FIE8W0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@)&)O9'D@
M("`M(%1H92!B;V1Y(&]F('1H92!M:6UE('!A<G0@:68@86YY+@T*("`@("`J
M($!P87)A;2`D<&%R86US("T@06X@87-S;V-I871I=F4@87)R87D@;V8@<&%R
M86UE=&5R<SH-"B`@("`@*B`@("`@("`@("`@("`@("`@(&-O;G1E;G1?='EP
M92`M(%1H92!C;VYT96YT('1Y<&4@9F]R('1H:7,@<&%R="!E9R!M=6QT:7!A
M<G0O;6EX960-"B`@("`@*B`@("`@("`@("`@("`@("`@(&5N8V]D:6YG("`@
M("`M(%1H92!E;F-O9&EN9R!T;R!U<V4L(#=B:70L(#AB:70L(&)A<V4V-"P@
M;W(@<75O=&5D+7!R:6YT86)L90T*("`@("`J("`@("`@("`@("`@("`@("`@
M8VED("`@("`@("`@("T@0V]N=&5N="!)1"!T;R!A<'!L>0T*("`@("`J("`@
M("`@("`@("`@("`@("`@9&ES<&]S:71I;VX@("T@0V]N=&5N="!D:7-P;W-I
M=&EO;BP@:6YL:6YE(&]R(&%T=&%C:&UE;G0-"B`@("`@*B`@("`@("`@("`@
M("`@("`@(&1F:6QE;F%M92`@("`M($]P=&EO;F%L(&9I;&5N86UE('!A<F%M
M971E<B!F;W(@8V]N=&5N="!D:7-P;W-I=&EO;@T*("`@("`J("`@("`@("`@
M("`@("`@("`@9&5S8W)I<'1I;VX@("T@0V]N=&5N="!D97-C<FEP=&EO;@T*
M("`@("`J("`@("`@("`@("`@("`@("`@8VAA<G-E="`@("`@("T@0VAA<F%C
M=&5R('-E="!T;R!U<V4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N($UA:6Q?;6EM95!A<G0H)&)O9'D@/2`G)RP@)'!A
M<F%M<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("!I9B`H(61E9FEN960H
M)TU!24Q?34E-15!!4E1?0U),1B<I*2![#0H@("`@("`@("`@("!D969I;F4H
M)TU!24Q?34E-15!!4E1?0U),1B<L(&1E9FEN960H)TU!24Q?34E-15]#4DQ&
M)RD@/R!-04E,7TU)345?0U),1B`Z(")<<EQN(BP@5%)512D[#0H@("`@("`@
M('T-"@T*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1K97D@/3X@)'9A
M;'5E*2![#0H@("`@("`@("`@("!S=VET8V@@*"1K97DI('L-"B`@("`@("`@
M("`@("`@("!C87-E("=C;VYT96YT7W1Y<&4G.@T*("`@("`@("`@("`@("`@
M("`@("`D:&5A9&5R<ULG0V]N=&5N="U4>7!E)UT@/2`D=F%L=64@+B`H:7-S
M970H)&-H87)S970I(#\@)SL@8VAA<G-E=#TB)R`N("1C:&%R<V5T("X@)R(G
M(#H@)R<I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@
M("`@("`@("`@(&-A<V4@)V5N8V]D:6YG)SH-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]E;F-O9&EN9R`]("1V86QU93L-"B`@("`@("`@("`@("`@
M("`@("`@)&AE861E<G-;)T-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<G72`]
M("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@
M("`@("`@("`@("!C87-E("=C:60G.@T*("`@("`@("`@("`@("`@("`@("`D
M:&5A9&5R<ULG0V]N=&5N="U)1"==(#T@)SPG("X@)'9A;'5E("X@)SXG.PT*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@
M(&-A<V4@)V1I<W!O<VET:6]N)SH-"B`@("`@("`@("`@("`@("`@("`@)&AE
M861E<G-;)T-O;G1E;G0M1&ES<&]S:71I;VXG72`]("1V86QU92`N("AI<W-E
M="@D9&9I;&5N86UE*2`_("<[(&9I;&5N86UE/2(G("X@)&1F:6QE;F%M92`N
M("<B)R`Z("<G*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@
M("`@("`@("`@("`@("!C87-E("=D9FEL96YA;64G.@T*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)T-O;G1E;G0M1&ES<&]S:71I
M;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1H96%D97)S6R=#
M;VYT96YT+41I<W!O<VET:6]N)UT@+CT@)SL@9FEL96YA;64](B<@+B`D=F%L
M=64@+B`G(B<[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D9&9I;&5N86UE(#T@)'9A;'5E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*#0H@("`@("`@("`@("`@("`@8V%S92`G9&5S8W)I<'1I;VXG.@T*("`@
M("`@("`@("`@("`@("`@("`D:&5A9&5R<ULG0V]N=&5N="U$97-C<FEP=&EO
M;B==(#T@)'9A;'5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*
M("`@("`@("`@("`@("`@(&-A<V4@)V-H87)S970G.@T*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)T-O;G1E;G0M5'EP92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M
M5'EP92==("X]("<[(&-H87)S970](B<@+B`D=F%L=64@+B`G(B<[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D8VAA<G-E="`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*#0H@("`@("`@("\O($1E9F%U;'0@8V]N=&5N="UT>7!E
M#0H@("`@("`@(&EF("@A:7-S970H)&AE861E<G-;)T-O;G1E;G0M5'EP92==
M*2D@>PT*("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M5'EP92==(#T@
M)W1E>'0O<&QA:6XG.PT*("`@("`@("!]#0H-"B`@("`@("`@+R]$969A=6QT
M(&5N8V]D:6YG#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]E;F-O9&EN
M9RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?96YC;V1I;F<@/2`G-V)I="<[
M#0H@("`@("`@('T-"@T*("`@("`@("`O+R!!<W-I9VX@<W1U9F8@=&\@;65M
M8F5R('9A<FEA8FQE<PT*("`@("`@("`D=&AI<RT^7V5N8V]D960@(#T@87)R
M87DH*3L-"B`@("`@("`@)'1H:7,M/E]H96%D97)S("`]("1H96%D97)S.PT*
M("`@("`@("`D=&AI<RT^7V)O9'D@("`@(#T@)&)O9'D[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@96YC;V1E*"D-"B`@("`@*@T*("`@("`J($5N8V]D
M97,@86YD(')E='5R;G,@=&AE(&5M86EL+B!!;'-O('-T;W)E<PT*("`@("`J
M(&ET(&EN('1H92!E;F-O9&5D(&UE;6)E<B!V87)I86)L90T*("`@("`J#0H@
M("`@("H@0')E='5R;B!!;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG
M('1W;R!E;&5M96YT<RP-"B`@("`@*B`@("`@("`@(&)O9'D@86YD(&AE861E
M<G,N(%1H92!H96%D97)S(&5L96UE;G0@:7,@:71S96QF#0H@("`@("H@("`@
M("`@("!A;B!I;F1E>&5D(&%R<F%Y+@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@96YC;V1E*"D-"B`@("![#0H@("`@
M("`@("1E;F-O9&5D(#TF("1T:&ES+3Y?96YC;V1E9#L-"@T*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?<W5B<&%R=',I*2![#0H@("`@("`@("`@("!S
M<F%N9"@H9&]U8FQE*6UI8W)O=&EM92@I*C$P,#`P,#`I.PT*("`@("`@("`@
M("`@)&)O=6YD87)Y(#T@)SU?)R`N(&UD-2AU;FEQ:60H<F%N9"@I*2`N(&UI
M8W)O=&EM92@I*3L-"B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULG0V]N
M=&5N="U4>7!E)UT@+CT@)SLG("X@34%)3%]-24U%4$%25%]#4DQ&("X@(EQT
M(B`N("=B;W5N9&%R>3TB)R`N("1B;W5N9&%R>2`N("<B)SL-"@T*("`@("`@
M("`@("`@+R\@061D(&)O9'D@<&%R=',@=&\@)'-U8G!A<G1S#0H@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7W-U8G!A<G1S
M*3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@("1H96%D97)S(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("`D=&UP(#T@)'1H:7,M/E]S=6)P87)T<ULD
M:5TM/F5N8V]D92@I.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T;7!;
M)VAE861E<G,G72!A<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@
M("`@("`@("`D:&5A9&5R<UM=(#T@)&ME>2`N("<Z("<@+B`D=F%L=64[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1S=6)P87)T<UM=
M(#T@:6UP;&]D92A-04E,7TU)345005)47T-23$8L("1H96%D97)S*2`N($U!
M24Q?34E-15!!4E1?0U),1B`N($U!24Q?34E-15!!4E1?0U),1B`N("1T;7!;
M)V)O9'DG73L-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@)&5N8V]D
M961;)V)O9'DG72`]("<M+2<@+B`D8F]U;F1A<GD@+B!-04E,7TU)345005)4
M7T-23$8@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO
M9&4H)RTM)R`N("1B;W5N9&%R>2`N($U!24Q?34E-15!!4E1?0U),1BP@)'-U
M8G!A<G1S*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RTM
M)R`N("1B;W5N9&%R>2XG+2TG("X@34%)3%]-24U%4$%25%]#4DQ&.PT*#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D96YC;V1E9%LG8F]D>2==
M(#T@)'1H:7,M/E]G971%;F-O9&5D1&%T82@D=&AI<RT^7V)O9'DL("1T:&ES
M+3Y?96YC;V1I;F<I("X@34%)3%]-24U%4$%25%]#4DQ&.PT*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@061D(&AE861E<G,@=&\@)&5N8V]D960-"B`@("`@
M("`@)&5N8V]D961;)VAE861E<G,G72`])B`D=&AI<RT^7VAE861E<G,[#0H-
M"B`@("`@("`@<F5T=7)N("1E;F-O9&5D.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J("9A9&13=6)087)T*"D-"B`@("`@*@T*("`@("`J($%D9',@82!S
M=6)P87)T('1O(&-U<G)E;G0@;6EM92!P87)T(&%N9"!R971U<FYS#0H@("`@
M("H@82!R969E<F5N8V4@=&\@:70-"B`@("`@*@T*("`@("`J($!P87)A;2`D
M8F]D>2`@(%1H92!B;V1Y(&]F('1H92!S=6)P87)T+"!I9B!A;GDN#0H@("`@
M("H@0'!A<F%M("1P87)A;7,@5&AE('!A<F%M971E<G,@9F]R('1H92!S=6)P
M87)T+"!S86UE#0H@("`@("H@("`@("`@("`@("`@("`@87,@=&AE("1P87)A
M;7,@87)G=6UE;G0@9F]R(&-O;G-T<G5C=&]R+@T*("`@("`J($!R971U<FX@
M02!R969E<F5N8V4@=&\@=&AE('!A<G0@>6]U(&IU<W0@861D960N($ET(&ES
M#0H@("`@("H@("`@("`@("!C<G5C:6%L(&EF('5S:6YG(&UU;'1I<&%R="\J
M(&EN('EO=7(@<W5B<&%R=',@=&AA=`T*("`@("`J("`@("`@("`@>6]U('5S
M92`])B!I;B!Y;W5R('-C<FEP="!W:&5N(&-A;&QI;F<@=&AI<R!F=6YC=&EO
M;BP-"B`@("`@*B`@("`@("`@(&]T:&5R=VES92!Y;W4@=VEL;"!N;W0@8F4@
M86)L92!T;R!A9&0@9G5R=&AE<B!S=6)P87)T<RX-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N("9A9&13=6)087)T*"1B
M;V1Y+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=6)P87)T
M<UM=(#T@;F5W($UA:6Q?;6EM95!A<G0H)&)O9'DL("1P87)A;7,I.PT*("`@
M("`@("!R971U<FX@)'1H:7,M/E]S=6)P87)T<UMC;W5N="@D=&AI<RT^7W-U
M8G!A<G1S*2`M(#%=.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%]G971%
M;F-O9&5D1&%T82@I#0H@("`@("H-"B`@("`@*B!2971U<FYS(&5N8V]D960@
M9&%T82!B87-E9"!U<&]N(&5N8V]D:6YG('!A<W-E9"!T;R!I=`T*("`@("`J
M#0H@("`@("H@0'!A<F%M("1D871A("`@("!4:&4@9&%T82!T;R!E;F-O9&4N
M#0H@("`@("H@0'!A<F%M("1E;F-O9&EN9R!4:&4@96YC;V1I;F<@='EP92!T
M;R!U<V4L(#=B:70L(&)A<V4V-"P-"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&]R('%U;W1E9"UP<FEN=&%B;&4N#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V=E=$5N8V]D961$871A*"1D871A
M+"`D96YC;V1I;F<I#0H@("`@>PT*("`@("`@("!S=VET8V@@*"1E;F-O9&EN
M9RD@>PT*("`@("`@("`@("`@8V%S92`G.&)I="<Z#0H@("`@("`@("`@("!C
M87-E("<W8FET)SH-"B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&$[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@)W%U
M;W1E9"UP<FEN=&%B;&4G.@T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W%U;W1E9%!R:6YT86)L945N8V]D92@D9&%T82D[#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@)V)A<V4V-"<Z#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(')T<FEM*&-H=6YK7W-P;&ET*&)A<V4V
M-%]E;F-O9&4H)&1A=&$I+"`W-BP@34%)3%]-24U%4$%25%]#4DQ&*2D[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&1E9F%U;'0Z
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1D871A.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@<75O=&5A9%!R:6YT86)L945N8V]D
M92@I#0H@("`@("H-"B`@("`@*B!%;F-O9&5S(&1A=&$@=&\@<75O=&5D+7!R
M:6YT86)L92!S=&%N9&%R9"X-"B`@("`@*@T*("`@("`J($!P87)A;2`D:6YP
M=70@("`@5&AE(&1A=&$@=&\@96YC;V1E#0H@("`@("H@0'!A<F%M("1L:6YE
M7VUA>"!/<'1I;VYA;"!M87@@;&EN92!L96YG=&@N(%-H;W5L9`T*("`@("`J
M("`@("`@("`@("`@("`@("`@;F]T(&)E(&UO<F4@=&AA;B`W-B!C:&%R<PT*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@7W%U;W1E9%!R:6YT86)L945N8V]D92@D:6YP=70@+"`D;&EN
M95]M87@@/2`W-BD-"B`@("![#0H@("`@("`@("1L:6YE<R`@/2!P<F5G7W-P
M;&ET*"(O7'(_7&XO(BP@)&EN<'5T*3L-"B`@("`@("`@)&5O;"`@("`]($U!
M24Q?34E-15!!4E1?0U),1CL-"B`@("`@("`@)&5S8V%P92`]("<])SL-"B`@
M("`@("`@)&]U='!U="`]("<G.PT*#0H@("`@("`@('=H:6QE*&QI<W0H+"`D
M;&EN92D@/2!E86-H*"1L:6YE<RDI>PT*#0H@("`@("`@("`@("`D;&EN;&5N
M("`@("`]('-T<FQE;B@D;&EN92D[#0H@("`@("`@("`@("`D;F5W;&EN92`]
M("<G.PT*#0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;&EN;&5N
M.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@)&-H87(@/2!S=6)S='(H)&QI
M;F4L("1I+"`Q*3L-"B`@("`@("`@("`@("`@("`D9&5C("`](&]R9"@D8VAA
M<BD[#0H-"B`@("`@("`@("`@("`@("!I9B`H*"1D96,@/3T@,S(I($%.1"`H
M)&D@/3T@*"1L:6YL96X@+2`Q*2DI>R`@("`O+R!C;VYV97)T('-P86-E(&%T
M(&5O;"!O;FQY#0H@("`@("`@("`@("`@("`@("`@("1C:&%R(#T@)STR,"<[
M#0H-"B`@("`@("`@("`@("`@("!](&5L<V5I9B@D9&5C(#T](#DI('L-"B`@
M("`@("`@("`@("`@("`@("`@.R`O+R!$;R!N;W1H:6YG(&EF(&$@=&%B+@T*
M("`@("`@("`@("`@("`@('T@96QS96EF*"@D9&5C(#T](#8Q*2!/4B`H)&1E
M8R`\(#,R("D@3U(@*"1D96,@/B`Q,C8I*2![#0H@("`@("`@("`@("`@("`@
M("`@("1C:&%R(#T@)&5S8V%P92`N('-T<G1O=7!P97(H<W!R:6YT9B@G)3`R
M<R<L(&1E8VAE>"@D9&5C*2DI.PT*("`@("`@("`@("`@("`@('T-"@T*("`@
M("`@("`@("`@("`@(&EF("@H<W1R;&5N*"1N97=L:6YE*2`K('-T<FQE;B@D
M8VAA<BDI(#X]("1L:6YE7VUA>"D@>R`@("`@("`@+R\@34%)3%]-24U%4$%2
M5%]#4DQ&(&ES(&YO="!C;W5N=&5D#0H@("`@("`@("`@("`@("`@("`@("1O
M=71P=70@("X]("1N97=L:6YE("X@)&5S8V%P92`N("1E;VP[("`@("`@("`@
M("`@("`@("`@("`O+R!S;V9T(&QI;F4@8G)E86L[("(@/5QR7&XB(&ES(&]K
M87D-"B`@("`@("`@("`@("`@("`@("`@)&YE=VQI;F4@(#T@)R<[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1N97=L:6YE("X]("1C
M:&%R.PT*("`@("`@("`@("`@?2`O+R!E;F0@;V8@9F]R#0H@("`@("`@("`@
M("`D;W5T<'5T("X]("1N97=L:6YE("X@)&5O;#L-"B`@("`@("`@?0T*("`@
M("`@("`D;W5T<'5T(#T@<W5B<W1R*"1O=71P=70L(#`L("TQ("H@<W1R;&5N
M*"1E;VPI*3L@+R\@1&]N)W0@=V%N="!L87-T(&-R;&8-"B`@("`@("`@<F5T
M=7)N("1O=71P=70[#0H@("`@?0T*?2`O+R!%;F0@;V8@8VQA<W,-"C\^#0H`
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL
M+VUA:6PN<&AP````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,#(U,``Q,#0Q-S,V,S`P-P`P,3<V-30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@
M?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0
M(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!M86EL+G!H<"QV(#$N-2`R,#`S+S`W+S$P(#`W
M.C`T.C4T(&IO;B!%>'`@)`H*<F5Q=6ER95]O;F-E("=-86EL+G!H<"<["@HO
M*BH*("H@:6YT97)N86P@4$A0+6UA:6PH*2!I;7!L96UE;G1A=&EO;B!O9B!T
M:&4@4$5!4B!-86EL.CH@:6YT97)F86-E+@H@*B!`86-C97-S('!U8FQI8PH@
M*B!`<&%C:V%G92!-86EL"B`J($!V97)S:6]N("12979I<VEO;CH@,2XU("0*
M("HO"B`*8VQA<W,@36%I;%]M86EL(&5X=&5N9',@36%I;`I["B`@("`O*BH*
M("`@("`J($%N>2!A<F=U;65N=',@=&\@<&%S<R!T;R!T:&4@;6%I;"@I(&9U
M;F-T:6]N+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M<&%R86US(#T@)R<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!);G-T86YT:6%T97,@82!N97<@36%I;%]M86EL.CH@;V)J
M96-T(&)A<V5D(&]N('1H92!P87)A;65T97)S"B`@("`@*B!P87-S960@:6XN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86US($5X=')A(&%R
M9W5M96YT<R!F;W(@=&AE(&UA:6PH*2!F=6YC=&EO;BX*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!-86EL7VUA
M:6PH)'!A<F%M<R`]("<G*0H@("`@>PH@("`@("`@("\J"B`@("`@("`@("H@
M5&AE(&]T:&5R(&UA:6P@:6UP;&5M96YT871I;VYS(&%C8V5P="!P87)A;65T
M97)S(&%S(&%R<F%Y<RX@($EN('1H90H@("`@("`@("`J(&EN=&5R97-T(&]F
M(&)E:6YG(&-O;G-I<W1E;G0L(&5X<&QO9&4@86X@87)R87D@:6YT;R!A('-T
M<FEN9R!O9@H@("`@("`@("`J('!A<F%M971E<B!A<F=U;65N=',N"B`@("`@
M("`@("HO"B`@("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US(#T@:F]I;B@G("<L("1P87)A;7,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M)'!A<F%M<SL*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@0F5C
M875S92!T:&4@;6%I;"@I(&9U;F-T:6]N(&UA>2!P87-S(&AE861E<G,@87,@
M8V]M;6%N9"!L:6YE"B`@("`@("`@("H@87)G=6UE;G1S+"!W92!C86XG="!G
M=6%R86YT964@=&AE('5S92!O9B!T:&4@<W1A;F1A<F0@(EQR7&XB"B`@("`@
M("`@("H@<V5P87)A=&]R+B`@26YS=&5A9"P@=V4@=7-E('1H92!S>7-T96TG
M<R!N871I=F4@;&EN92!S97!A<F%T;W(N"B`@("`@("`@("HO"B`@("`@("`@
M)'1H:7,M/G-E<"`]("AS=')S='(H4$A07T]3+"`G5TE.)RDI(#\@(EQR7&XB
M(#H@(EQN(CL*("`@('T*"@DO*BH*("`@("`J($EM<&QE;65N=',@36%I;%]M
M86EL.CIS96YD*"D@9G5N8W1I;VX@=7-I;F<@<&AP)W,@8G5I;'0M:6X@;6%I
M;"@I"B`@("`@*B!C;VUM86YD+@H@("`@("H@"B`@("`@*B!`<&%R86T@;6EX
M960@)')E8VEP:65N=',@16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI<W0@
M;V8@<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@("`@("A21D,X,C(@8V]M
M<&QI86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J("`@
M("`@("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N=&%I
M;B!R96-I<&EE;G1S(&YO=`H@("`@("H@("`@("`@("`@("`@('-P96-I9FEE
M9"!I;B!T:&4@:&5A9&5R<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@("H@
M("`@("`@("`@("`@(&UE<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O('-E
M;F0@=VET:"!T:&4@;6%I;"P@:6X@86X*("`@("`J("`@("`@("`@("`@("!A
M<W-O8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T:&4*
M("`@("`J("`@("`@("`@("`@("!H96%D97(@;F%M92`H:64L("=3=6)J96-T
M)RDL(&%N9"!T:&4@87)R87D@=F%L=64*("`@("`J("`@("`@("`@("`@("!I
M<R!T:&4@:&5A9&5R('9A;'5E("AI92P@)W1E<W0G*2X@5&AE(&AE861E<@H@
M("`@("H@("`@("`@("`@("`@('!R;V1U8V5D(&9R;VT@=&AO<V4@=F%L=65S
M('=O=6QD(&)E("=3=6)J96-T.@H@("`@("H@("`@("`@("`@("`@('1E<W0G
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)O9'D@5&AE(&9U;&P@
M=&5X="!O9B!T:&4@;65S<V%G92!B;V1Y+"!I;F-L=61I;F<@86YY"B`@("`@
M*B`@("`@("`@("`@("`@($UI;64@<&%R=',L(&5T8RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!O<B!A
M(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@8V]N=&%I;FEN9R!A
M(&1E<V-R:7!T:79E(&5R<F]R(&UE<W-A9V4@;VX*("`@("`J("`@("`@("`@
M("`@("`@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\)
M"B`@("!F=6YC=&EO;B!S96YD*"1R96-I<&EE;G1S+"`D:&5A9&5R<RP@)&)O
M9'DI"B`@("!["B`@("`@("`@+R\@:68@=V4G<F4@<&%S<V5D(&%N(&%R<F%Y
M(&]F(')E8VEP:65N=',L(&EM<&QO9&4@:70N"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1R96-I<&EE;G1S*2D@>PH@("`@("`@("`@("`D<F5C:7!I96YT<R`]
M(&EM<&QO9&4H)RP@)RP@)')E8VEP:65N=',I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@9V5T('1H92!3=6)J96-T(&]U="!O9B!T:&4@:&5A9&5R<R!A<G)A
M>2!S;R!T:&%T('=E(&-A;@H@("`@("`@("\O('!A<W,@:70@87,@82!S97!E
M<F%T92!A<F=U;65N="!T;R!M86EL*"DN"B`@("`@("`@)'-U8FIE8W0@/2`G
M)SL*("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)U-U8FIE8W0G72DI('L*
M("`@("`@("`@("`@)'-U8FIE8W0@/2`D:&5A9&5R<ULG4W5B:F5C="==.PH@
M("`@("`@("`@("!U;G-E="@D:&5A9&5R<ULG4W5B:F5C="==*3L*("`@("`@
M("!]"@H@("`@("`@("\O(&9L871T96X@=&AE(&AE861E<G,@;W5T+@H@("`@
M("`@(&QI<W0H+"1T97AT7VAE861E<G,I(#T@36%I;#HZ<')E<&%R94AE861E
M<G,H)&AE861E<G,I.PH*("`@("`@("!R971U<FX@;6%I;"@D<F5C:7!I96YT
M<RP@)'-U8FIE8W0L("1B;V1Y+"`D=&5X=%]H96%D97)S+"`D=&AI<RT^7W!A
M<F%M<RD["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TUA:6PO;6EM941E8V]D
M92YP:'``````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<S,S<W
M`#$P-#$W,S8S,#`W`#`R,3`Q,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/U!H<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(@(%)I8VAA<F0@
M2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*
M+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70@("`@?`T*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O
M=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`T*+R\@
M?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S
M;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@
M("`@?`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?`T*+R\@?"!O
M(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C
M92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`T*+R\@?"`@(&YO=&EC92P@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;B!T:&4@?`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T
M:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN
M?`T*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E
M('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`T*+R\@?"`@('!R
M;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E
M8VEF:6,@<')I;W(@=W)I='1E;B`@?`T*+R\@?"`@('!E<FUI<W-I;VXN("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*
M+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'
M2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?`T*+R\@?"`B05,@25,B
M($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ5
M1$E.1RP@0E54($Y/5"`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!42$4@24U0
M3$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4R!&3U(@?`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!
M24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`T*+R\@
M?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?`T*+R\@?"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4("`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.
M5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%53
M12P@?`T*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%
M4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`T*+R\@?"!4
M2$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))
M0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`T*+R\@?"`H24Y#3%5$24Y'($Y%
M1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54
M($]&(%1(12!54T4@?`T*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&
M($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@
M?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W(Z(%)I8VAA<F0@
M2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"@T*+RHJ#0HJ("`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T@24U03U)404Y4("TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"BH@('P@57-A9V4@;V8@=&AI<R!C;&%S
M<R!C;VUP87)E9"!T;R!N871I=F4@<&AP(&5X=&5N<VEO;G,@<W5C:"!A<R`@
M("`@("`@?`T**B`@?"!M86EL<&%R<V4@;W(@:6UA<"P@:7,@<VQO=R!A;F0@
M;6%Y(&)E(&9E871U<F4@9&5F:6-I96YT+B!)9B!A=F%I;&%B;&5\#0HJ("!\
M('EO=2!A<F4@4U123TY'3%D@<F5C;VUM96YD960@=&\@=7-E('1H92!P:'`@
M97AT96YS:6]N<RX@("`@("`@("`@("`@('P-"BH@("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT**@T**B!-:6UE($1E8V]D:6YG(&-L87-S#0HJ#0HJ
M(%1H:7,@8VQA<W,@=VEL;"!P87)S92!A(')A=R!M:6UE(&5M86EL(&%N9"!R
M971U<FX-"BH@=&AE('-T<G5C='5R92X@4F5T=7)N960@<W1R=6-T=7)E(&ES
M('-I;6EL87(@=&\-"BH@=&AA="!R971U<FYE9"!B>2!I;6%P7V9E=&-H<W1R
M=6-T=7)E*"DN#0HJ#0HJ(%5304=%.B`H87-S=6UE("1I;G!U="!I<R!Y;W5R
M(')A=R!E;6%I;"D-"BH-"BH@)&1E8V]D92`](&YE=R!-86EL7VUI;65$96-O
M9&4H)&EN<'5T+"`B7')<;B(I.PT**B`D<W1R=6-T=7)E(#T@)&1E8V]D92T^
M9&5C;V1E*"D[#0HJ('!R:6YT7W(H)'-T<G5C='5R92D[#0HJ#0HJ($]R('-T
M871I8V%L;'DZ#0HJ#0HJ("1P87)A;7-;)VEN<'5T)UT@/2`D:6YP=70[#0HJ
M("1S=')U8W1U<F4@/2!-86EL7VUI;65$96-O9&4Z.F1E8V]D92@D<&%R86US
M*3L-"BH@<')I;G1?<B@D<W1R=6-T=7)E*3L-"BH-"BH@5$]$3SH-"BH@("T@
M26UP;&5M96YT(&9U<G1H97(@8V]N=&5N="!T>7!E<RP@96<N(&UU;'1I<&%R
M="]P87)A;&QE;"P-"BH@("`@<&5R:&%P<R!E=F5N(&UE<W-A9V4O<&%R=&EA
M;"X-"BH-"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G
M=7)U+F]R9SX-"BH@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C,T("0-"BH@0'!A
M8VMA9V4@36%I;`T**B\-"@T*8VQA<W,@36%I;%]M:6UE1&5C;V1E(&5X=&5N
M9',@4$5!4@T*>PT*#0H@("`@+RHJ#0H@("`@("H@5&AE(')A=R!E;6%I;"!T
M;R!D96-O9&4-"B`@("`@*B!`=F%R("`@('-T<FEN9PT*("`@("`J+PT*("`@
M('9A<B`D7VEN<'5T.PT*#0H@("`@+RHJ#0H@("`@("H@5&AE(&AE861E<B!P
M87)T(&]F('1H92!I;G!U=`T*("`@("`J($!V87(@("`@<W1R:6YG#0H@("`@
M("HO#0H@("`@=F%R("1?:&5A9&5R.PT*#0H@("`@+RHJ#0H@("`@("H@5&AE
M(&)O9'D@<&%R="!O9B!T:&4@:6YP=70-"B`@("`@*B!`=F%R("`@('-T<FEN
M9PT*("`@("`J+PT*("`@('9A<B`D7V)O9'D[#0H-"B`@("`O*BH-"B`@("`@
M*B!)9B!A;B!E<G)O<B!O8V-U<G,L('1H:7,@:7,@=7-E9"!T;R!S=&]R92!T
M:&4@;65S<V%G90T*("`@("`J($!V87(@("`@<W1R:6YG#0H@("`@("HO#0H@
M("`@=F%R("1?97)R;W([#0H-"B`@("`O*BH-"B`@("`@*B!&;&%G('1O(&1E
M=&5R;6EN92!W:&5T:&5R('1O(&EN8VQU9&4@8F]D:65S(&EN('1H90T*("`@
M("`J(')E='5R;F5D(&]B:F5C="X-"B`@("`@*B!`=F%R("`@(&)O;VQE86X-
M"B`@("`@*B\-"B`@("!V87(@)%]I;F-L=61E7V)O9&EE<SL-"@T*("`@("\J
M*@T*("`@("`J($9L86<@=&\@9&5T97)M:6YE('=H971H97(@=&\@9&5C;V1E
M(&)O9&EE<PT*("`@("`J($!V87(@("`@8F]O;&5A;@T*("`@("`J+PT*("`@
M('9A<B`D7V1E8V]D95]B;V1I97,[#0H-"B`@("`O*BH-"B`@("`@*B!&;&%G
M('1O(&1E=&5R;6EN92!W:&5T:&5R('1O(&1E8V]D92!H96%D97)S#0H@("`@
M("H@0'9A<B`@("!B;V]L96%N#0H@("`@("HO#0H@("`@=F%R("1?9&5C;V1E
M7VAE861E<G,[#0H-"B`@("`O*BH-"B`@("`J($EF(&EN=F]K960@9G)O;2!A
M(&-L87-S+"`D=&AI<R!W:6QL(&)E('-E="X@5&AI<R!H87,@<')O8FQE;6%T
M:6,-"B`@("`J(&-O;FYO=&%T:6]N<R!F;W(@8V%L;&EN9R!D96-O9&4H*2!S
M=&%T:6-A;&QY+B!(96YC92!T:&ES('9A<FEA8FQE#0H@("`@*B!I<R!U<V5D
M('1O(&1E=&5R;6EN92!I9B!W92!A<F4@:6YD965D(&)E:6YG(&-A;&QE9"!S
M=&%T:6-A;&QY(&]R#0H@("`@*B!V:6$@86X@;V)J96-T+@T*("`@("HO#0H@
M("`@=F%R("1M86EL36EM941E8V]D93L-"@T*("`@("\J*@T*("`@("`J($-O
M;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@4V5T<R!U<"!T:&4@;V)J96-T
M+"!I;FET:6%L:7-E('1H92!V87)I86)L97,L(&%N9"!S<&QI=',@86YD#0H@
M("`@("H@<W1O<F5S('1H92!H96%D97(@86YD(&)O9'D@;V8@=&AE(&EN<'5T
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@:6YP=70@=&\@
M9&5C;V1E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!-86EL7VUI;65$96-O9&4H)&EN<'5T*0T*("`@('L-"B`@("`@
M("`@;&ES="@D:&5A9&5R+"`D8F]D>2D@("`]("1T:&ES+3Y?<W!L:71";V1Y
M2&5A9&5R*"1I;G!U="D[#0H-"B`@("`@("`@)'1H:7,M/E]I;G!U="`@("`@
M("`@("`]("1I;G!U=#L-"B`@("`@("`@)'1H:7,M/E]H96%D97(@("`@("`@
M("`]("1H96%D97([#0H@("`@("`@("1T:&ES+3Y?8F]D>2`@("`@("`@("`@
M/2`D8F]D>3L-"B`@("`@("`@)'1H:7,M/E]D96-O9&5?8F]D:65S("`](&9A
M;'-E.PT*("`@("`@("`D=&AI<RT^7VEN8VQU9&5?8F]D:65S(#T@=')U93L-
M"B`@("`@("`@#0H@("`@("`@("1T:&ES+3YM86EL36EM941E8V]D92`@/2!T
M<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($)E9VEN<R!T:&4@9&5C
M;V1I;F<@<')O8V5S<RX@268@8V%L;&5D('-T871I8V%L;'D-"B`@("`@*B!I
M="!W:6QL(&-R96%T92!A;B!O8FIE8W0@86YD(&-A;&P@=&AE(&1E8V]D92@I
M(&UE=&AO9`T*("`@("`J(&]F(&ET+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M(&%R<F%Y($%N(&%R<F%Y(&]F('9A<FEO=7,@<&%R86UE=&5R<R!T:&%T(&1E
M=&5R;6EN90T*("`@("`J("`@("`@("`@("`@("!V87)I;W5S('1H:6YG<SH-
M"B`@("`@*B`@("`@("`@("`@("`@:6YC;'5D95]B;V1I97,@+2!7:&5T:&5R
M('1O(&EN8VQU9&4@=&AE(&)O9'D@:6X@=&AE(')E='5R;F5D#0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T+@T*("`@("`J
M("`@("`@("`@("`@("!D96-O9&5?8F]D:65S("`M(%=H971H97(@=&\@9&5C
M;V1E('1H92!B;V1I97,-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O9B!T:&4@<&%R=',N("A4<F%N<V9E<B!E;F-O9&EN9RD-"B`@
M("`@*B`@("`@("`@("`@("`@9&5C;V1E7VAE861E<G,@+2!7:&5T:&5R('1O
M(&1E8V]D92!H96%D97)S#0H@("`@("H@("`@("`@("`@("`@(&EN<'5T("`@
M("`@("`@("T@268@8V%L;&5D('-T871I8V%L;'DL('1H:7,@=VEL;"!B92!T
M<F5A=&5D#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87,@=&AE(&EN<'5T#0H@("`@("H@0')E='5R;B!O8FIE8W0@1&5C;V1E9"!R
M97-U;'1S#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!D96-O9&4H)'!A<F%M<R`](&YU;&PI#0H@("`@>PT*#0H@("`@
M("`@("\O($AA=F4@=V4@8F5E;B!C86QL960@<W1A=&EC86QL>3\@268@<V\L
M(&-R96%T92!A;B!O8FIE8W0@86YD('!A<W,@9&5T86EL<R!T;R!T:&%T+@T*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YM86EL36EM941E8V]D92D@04Y$
M(&ES<V5T*"1P87)A;7-;)VEN<'5T)UTI*2![#0H-"B`@("`@("`@("`@("1O
M8FH@/2!N97<@36%I;%]M:6UE1&5C;V1E*"1P87)A;7-;)VEN<'5T)UTI.PT*
M("`@("`@("`@("`@)'-T<G5C='5R92`]("1O8FHM/F1E8V]D92@D<&%R86US
M*3L-"@T*("`@("`@("`O+R!#86QL960@<W1A=&EC86QL>2!B=70@;F\@:6YP
M=70-"B`@("`@("`@?2!E;'-E:68@*"%I<W-E="@D=&AI<RT^;6%I;$UI;65$
M96-O9&4I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G0V%L;&5D('-T871I8V%L;'D@86YD(&YO(&EN<'5T(&=I=F5N)RD[#0H-
M"B`@("`@("`@+R\@0V%L;&5D('9I82!A;B!O8FIE8W0-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?:6YC;'5D95]B;V1I97,@/2!I
M<W-E="@D<&%R86US6R=I;F-L=61E7V)O9&EE<R==*2`@/R`D<&%R86US6R=I
M;F-L=61E7V)O9&EE<R==("`Z(&9A;'-E.PT*("`@("`@("`@("`@)'1H:7,M
M/E]D96-O9&5?8F]D:65S("`](&ES<V5T*"1P87)A;7-;)V1E8V]D95]B;V1I
M97,G72D@("`_("1P87)A;7-;)V1E8V]D95]B;V1I97,G72`@(#H@9F%L<V4[
M#0H@("`@("`@("`@("`D=&AI<RT^7V1E8V]D95]H96%D97)S(#T@:7-S970H
M)'!A<F%M<ULG9&5C;V1E7VAE861E<G,G72D@(#\@)'!A<F%M<ULG9&5C;V1E
M7VAE861E<G,G72`@.B!F86QS93L-"@T*("`@("`@("`@("`@)'-T<G5C='5R
M92`]("1T:&ES+3Y?9&5C;V1E*"1T:&ES+3Y?:&5A9&5R+"`D=&AI<RT^7V)O
M9'DI.PT*("`@("`@("`@("`@:68@*"1S=')U8W1U<F4@/3T](&9A;'-E*2![
M#0H@("`@("`@("`@("`@("`@)'-T<G5C='5R92`]("1T:&ES+3YR86ES945R
M<F]R*"1T:&ES+3Y?97)R;W(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H-"B`@("`@("`@<F5T=7)N("1S=')U8W1U<F4[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@4&5R9F]R;7,@=&AE(&1E8V]D:6YG+B!$96-O9&5S('1H
M92!B;V1Y('-T<FEN9R!P87-S960@=&\@:70-"B`@("`@*B!)9B!I="!F:6YD
M<R!C97)T86EN(&-O;G1E;G0M='EP97,@:70@=VEL;"!C86QL(&ET<V5L9B!I
M;B!A#0H@("`@("H@<F5C=7)S:79E(&9A<VAI;VX-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@2&5A9&5R('-E8W1I;VX-"B`@("`@*B!`<&%R86T@
M<W1R:6YG($)O9'D@<V5C=&EO;@T*("`@("`J($!R971U<FX@;V)J96-T(%)E
M<W5L=',@;V8@9&5C;V1I;F<@<')O8V5S<PT*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]D96-O9&4H)&AE861E<G,L
M("1B;V1Y+"`D9&5F875L=%]C='EP92`]("=T97AT+W!L86EN)RD-"B`@("![
M#0H@("`@("`@("1R971U<FX@/2!N97<@<W1D0VQA<W,[#0H@("`@("`@("1H
M96%D97)S(#T@)'1H:7,M/E]P87)S94AE861E<G,H)&AE861E<G,I.PT*#0H@
M("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1V86QU92D@>PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D
M=F%L=65;)VYA;64G72E=*2!!3D0@(6ES7V%R<F%Y*"1R971U<FXM/FAE861E
M<G-;<W1R=&]L;W=E<B@D=F%L=65;)VYA;64G72E=*2D@>PT*("`@("`@("`@
M("`@("`@("1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L=65;)VYA
M;64G72E=("`@/2!A<G)A>2@D<F5T=7)N+3YH96%D97)S6W-T<G1O;&]W97(H
M)'9A;'5E6R=N86UE)UTI72D[#0H@("`@("`@("`@("`@("`@)')E='5R;BT^
M:&5A9&5R<UMS=')T;VQO=V5R*"1V86QU95LG;F%M92==*5U;72`]("1V86QU
M95LG=F%L=64G73L-"@T*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1R
M971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L=65;)VYA;64G72E=*2D@
M>PT*("`@("`@("`@("`@("`@("1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E
M<B@D=F%L=65;)VYA;64G72E=6UT@/2`D=F%L=65;)W9A;'5E)UT[#0H-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)')E='5R;BT^
M:&5A9&5R<UMS=')T;VQO=V5R*"1V86QU95LG;F%M92==*5T@/2`D=F%L=65;
M)W9A;'5E)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@
M("!R97-E="@D:&5A9&5R<RD[#0H@("`@("`@('=H:6QE("AL:7-T*"1K97DL
M("1V86QU92D@/2!E86-H*"1H96%D97)S*2D@>PT*("`@("`@("`@("`@)&AE
M861E<G-;)&ME>5U;)VYA;64G72`]('-T<G1O;&]W97(H)&AE861E<G-;)&ME
M>5U;)VYA;64G72D[#0H@("`@("`@("`@("!S=VET8V@@*"1H96%D97)S6R1K
M97E=6R=N86UE)UTI('L-"@T*("`@("`@("`@("`@("`@(&-A<V4@)V-O;G1E
M;G0M='EP92<Z#0H@("`@("`@("`@("`@("`@("`@("1C;VYT96YT7W1Y<&4@
M/2`D=&AI<RT^7W!A<G-E2&5A9&5R5F%L=64H)&AE861E<G-;)&ME>5U;)W9A
M;'5E)UTI.PT*#0H@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O*%LP+3EA+7HK+BU=*RE<+RA;,"TY82UZ*RXM72LI+VDG+"`D8V]N=&5N
M=%]T>7!E6R=V86QU92==+"`D<F5G<RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1R971U<FXM/F-T>7!E7W!R:6UA<GD@("`]("1R96=S6S%=.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^8W1Y<&5?<V5C;VYD
M87)Y(#T@)')E9W-;,ET[#0H@("`@("`@("`@("`@("`@("`@('T-"@T*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-O;G1E;G1?='EP95LG;W1H
M97(G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@('=H:6QE("AL:7-T
M*"1P7VYA;64L("1P7W9A;'5E*2`](&5A8V@H)&-O;G1E;G1?='EP95LG;W1H
M97(G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N
M+3YC='EP95]P87)A;65T97)S6R1P7VYA;65=(#T@)'!?=F%L=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@
M("!C87-E("=C;VYT96YT+61I<W!O<VET:6]N)SL-"B`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E;G1?9&ES<&]S:71I;VX@/2`D=&AI<RT^7W!A<G-E2&5A
M9&5R5F%L=64H)&AE861E<G-;)&ME>5U;)W9A;'5E)UTI.PT*("`@("`@("`@
M("`@("`@("`@("`D<F5T=7)N+3YD:7-P;W-I=&EO;B`@(#T@)&-O;G1E;G1?
M9&ES<&]S:71I;VY;)W9A;'5E)UT[#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D8V]N=&5N=%]D:7-P;W-I=&EO;ELG;W1H97(G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('=H:6QE("AL:7-T*"1P7VYA;64L("1P
M7W9A;'5E*2`](&5A8V@H)&-O;G1E;G1?9&ES<&]S:71I;VY;)V]T:&5R)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^9%]P
M87)A;65T97)S6R1P7VYA;65=(#T@)'!?=F%L=64[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("!C87-E("=C
M;VYT96YT+71R86YS9F5R+65N8V]D:6YG)SH-"B`@("`@("`@("`@("`@("`@
M("`@)&-O;G1E;G1?=')A;G-F97)?96YC;V1I;F<@/2`D=&AI<RT^7W!A<G-E
M2&5A9&5R5F%L=64H)&AE861E<G-;)&ME>5U;)W9A;'5E)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*#0H@("`@("`@(&EF("AI<W-E="@D8V]N=&5N=%]T>7!E*2D@>PT*("`@
M("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*"1C;VYT96YT7W1Y<&5;)W9A
M;'5E)UTI*2![#0H@("`@("`@("`@("`@("`@8V%S92`G=&5X="]P;&%I;B<Z
M#0H@("`@("`@("`@("`@("`@("`@("1E;F-O9&EN9R`](&ES<V5T*"1C;VYT
M96YT7W1R86YS9F5R7V5N8V]D:6YG*2`_("1C;VYT96YT7W1R86YS9F5R7V5N
M8V]D:6YG6R=V86QU92==(#H@)S=B:70G.PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VEN8VQU9&5?8F]D:65S(#\@)')E='5R;BT^8F]D>2`]("@D
M=&AI<RT^7V1E8V]D95]B;V1I97,@/R`D=&AI<RT^7V1E8V]D94)O9'DH)&)O
M9'DL("1E;F-O9&EN9RD@.B`D8F]D>2D@.B!N=6QL.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@(&-A<V4@)W1E>'0O
M:'1M;"<Z#0H@("`@("`@("`@("`@("`@("`@("1E;F-O9&EN9R`](&ES<V5T
M*"1C;VYT96YT7W1R86YS9F5R7V5N8V]D:6YG*2`_("1C;VYT96YT7W1R86YS
M9F5R7V5N8V]D:6YG6R=V86QU92==(#H@)S=B:70G.PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEN8VQU9&5?8F]D:65S(#\@)')E='5R;BT^8F]D
M>2`]("@D=&AI<RT^7V1E8V]D95]B;V1I97,@/R`D=&AI<RT^7V1E8V]D94)O
M9'DH)&)O9'DL("1E;F-O9&EN9RD@.B`D8F]D>2D@.B!N=6QL.PT*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@(&-A<V4@
M)VUU;'1I<&%R="]P87)A;&QE;"<Z#0H@("`@("`@("`@("`@("`@8V%S92`G
M;75L=&EP87)T+W)E<&]R="<Z("\O(%)&0S$X.3(-"B`@("`@("`@("`@("`@
M("!C87-E("=M=6QT:7!A<G0O<VEG;F5D)SH@+R\@4$=0#0H@("`@("`@("`@
M("`@("`@8V%S92`G;75L=&EP87)T+V1I9V5S="<Z#0H@("`@("`@("`@("`@
M("`@8V%S92`G;75L=&EP87)T+V%L=&5R;F%T:79E)SH-"B`@("`@("`@("`@
M("`@("!C87-E("=M=6QT:7!A<G0O<F5L871E9"<Z#0H@("`@("`@("`@("`@
M("`@8V%S92`G;75L=&EP87)T+VUI>&5D)SH-"B`@("`@("`@("`@("`@("`@
M("`@:68H(6ES<V5T*"1C;VYT96YT7W1Y<&5;)V]T:&5R)UU;)V)O=6YD87)Y
M)UTI*7L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(@
M/2`G3F\@8F]U;F1A<GD@9F]U;F0@9F]R("<@+B`D8V]N=&5N=%]T>7!E6R=V
M86QU92==("X@)R!P87)T)SL-"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@
M("`@("`@("`@("`@("1D969A=6QT7V-T>7!E(#T@*'-T<G1O;&]W97(H)&-O
M;G1E;G1?='EP95LG=F%L=64G72D@/3T]("=M=6QT:7!A<G0O9&EG97-T)RD@
M/R`G;65S<V%G92]R9F,X,C(G(#H@)W1E>'0O<&QA:6XG.PT*#0H@("`@("`@
M("`@("`@("`@("`@("1P87)T<R`]("1T:&ES+3Y?8F]U;F1A<GE3<&QI="@D
M8F]D>2P@)&-O;G1E;G1?='EP95LG;W1H97(G75LG8F]U;F1A<GDG72D[#0H@
M("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1P
M87)T<RD[("1I*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H
M)'!A<G1?:&5A9&5R+"`D<&%R=%]B;V1Y*2`]("1T:&ES+3Y?<W!L:71";V1Y
M2&5A9&5R*"1P87)T<ULD:5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<G0@/2`D=&AI<RT^7V1E8V]D92@D<&%R=%]H96%D97(L("1P87)T7V)O
M9'DL("1D969A=6QT7V-T>7!E*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF*"1P87)T(#T]/2!F86QS92D-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R="`]("1T:&ES+3YR86ES945R<F]R*"1T:&ES+3Y?97)R;W(I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^<&%R='-;72`]
M("1P87)T.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("`@("`@8V%S92`G;65S<V%G
M92]R9F,X,C(G.@T*("`@("`@("`@("`@("`@("`@("`D;V)J(#T@)FYE=R!-
M86EL7VUI;65$96-O9&4H)&)O9'DI.PT*("`@("`@("`@("`@("`@("`@("`D
M<F5T=7)N+3YP87)T<UM=(#T@)&]B:BT^9&5C;V1E*&%R<F%Y*"=I;F-L=61E
M7V)O9&EE<R<@/3X@)'1H:7,M/E]I;F-L=61E7V)O9&EE<RDI.PT*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D;V)J*3L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("!D969A=6QT.@T*("`@("`@
M("`@("`@("`@("`@("!I9B@A:7-S970H)&-O;G1E;G1?=')A;G-F97)?96YC
M;V1I;F=;)W9A;'5E)UTI*0T*("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;G1E;G1?=')A;G-F97)?96YC;V1I;F=;)W9A;'5E)UT@/2`G-V)I="<[#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YC;'5D95]B;V1I97,@/R`D
M<F5T=7)N+3YB;V1Y(#T@*"1T:&ES+3Y?9&5C;V1E7V)O9&EE<R`_("1T:&ES
M+3Y?9&5C;V1E0F]D>2@D8F]D>2P@)&-O;G1E;G1?=')A;G-F97)?96YC;V1I
M;F=;)W9A;'5E)UTI(#H@)&)O9'DI(#H@;G5L;#L-"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1C='EP92`](&5X<&QO9&4H)R\G+"`D9&5F875L
M=%]C='EP92D[#0H@("`@("`@("`@("`D<F5T=7)N+3YC='EP95]P<FEM87)Y
M("`@/2`D8W1Y<&5;,%T[#0H@("`@("`@("`@("`D<F5T=7)N+3YC='EP95]S
M96-O;F1A<GD@/2`D8W1Y<&5;,5T[#0H@("`@("`@("`@("`D=&AI<RT^7VEN
M8VQU9&5?8F]D:65S(#\@)')E='5R;BT^8F]D>2`]("@D=&AI<RT^7V1E8V]D
M95]B;V1I97,@/R`D=&AI<RT^7V1E8V]D94)O9'DH)&)O9'DI(#H@)&)O9'DI
M(#H@;G5L;#L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B`D<F5T=7)N
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=I=F5N('1H92!O=71P=70@
M;V8@=&AE(&%B;W9E(&9U;F-T:6]N+"!T:&ES('=I;&P@<F5T=7)N(&%N#0H@
M("`@("H@87)R87D@;V8@<F5F97)E;F-E<R!T;R!T:&4@<&%R=',L(&EN9&5X
M960@8GD@;6EM92!N=6UB97(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@(&]B
M:F5C="`D<W1R=6-T=7)E("`@5&AE('-T<G5C='5R92!T;R!G;R!T:')O=6=H
M#0H@("`@("H@0'!A<F%M("!S=')I;F<@)&UI;65?;G5M8F5R($EN=&5R;F%L
M('5S92!O;FQY+@T*("`@("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@
M("!-:6UE(&YU;6)E<G,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T36EM
M94YU;6)E<G,H)B1S=')U8W1U<F4L("1N;U]R969S(#T@9F%L<V4L("1M:6UE
M7VYU;6)E<B`]("<G+"`D<')E<&5N9"`]("<G*0T*("`@('L-"B`@("`@("`@
M)')E='5R;B`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@A96UP='DH)'-T<G5C
M='5R92T^<&%R=',I*2![#0H@("`@("`@("`@("!I9B`H)&UI;65?;G5M8F5R
M("$]("<G*2![#0H@("`@("`@("`@("`@("`@)'-T<G5C='5R92T^;6EM95]I
M9"`]("1P<F5P96YD("X@)&UI;65?;G5M8F5R.PT*("`@("`@("`@("`@("`@
M("1R971U<FY;)'!R97!E;F0@+B`D;6EM95]N=6UB97)=(#T@)B1S=')U8W1U
M<F4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D<W1R=6-T=7)E+3YP87)T<RD[("1I*RLI('L-"@T*("`@
M("`@("`@("`@#0H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D<W1R=6-T
M=7)E+3YH96%D97)S6R=C;VYT96YT+71Y<&4G72D@04Y$('-U8G-T<BAS=')T
M;VQO=V5R*"1S=')U8W1U<F4M/FAE861E<G-;)V-O;G1E;G0M='EP92==*2P@
M,"P@."D@/3T@)VUE<W-A9V4O)RD@>PT*("`@("`@("`@("`@("`@("`@("`D
M<')E<&5N9"`@("`@(#T@)'!R97!E;F0@+B`D;6EM95]N=6UB97(@+B`G+B<[
M#0H@("`@("`@("`@("`@("`@("`@("1?;6EM95]N=6UB97(@/2`G)SL-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M7VUI;65?;G5M8F5R(#T@*"1M:6UE7VYU;6)E<B`]/2`G)R`_("1I("L@,2`Z
M('-P<FEN=&8H)R5S+B5S)RP@)&UI;65?;G5M8F5R+"`D:2`K(#$I*3L-"B`@
M("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("`D87)R(#T@)DUA
M:6Q?;6EM941E8V]D93HZ9V5T36EM94YU;6)E<G,H)'-T<G5C='5R92T^<&%R
M='-;)&E=+"`D;F]?<F5F<RP@)%]M:6UE7VYU;6)E<BP@)'!R97!E;F0I.PT*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A<G(@87,@)&ME>2`]/B`D=F%L
M*2![#0H@("`@("`@("`@("`@("`@("`@("1N;U]R969S(#\@)')E='5R;ELD
M:V5Y72`]("<G(#H@)')E='5R;ELD:V5Y72`]("8D87)R6R1K97E=.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@(&EF("@D;6EM95]N=6UB97(@/3T@)R<I('L-"B`@
M("`@("`@("`@("`@("`D;6EM95]N=6UB97(@/2`G,2<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D<W1R=6-T=7)E+3YM:6UE7VED(#T@)'!R97!E
M;F0@+B`D;6EM95]N=6UB97([#0H@("`@("`@("`@("`D;F]?<F5F<R`_("1R
M971U<FY;)'!R97!E;F0@+B`D;6EM95]N=6UB97)=(#T@)R<@.B`D<F5T=7)N
M6R1P<F5P96YD("X@)&UI;65?;G5M8F5R72`]("8D<W1R=6-T=7)E.PT*("`@
M("`@("!]#0H@("`@("`@(`T*("`@("`@("!R971U<FX@)')E='5R;CL-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!':79E;B!A('-T<FEN9R!C;VYT86EN
M:6YG(&$@:&5A9&5R(&%N9"!B;V1Y#0H@("`@("H@<V5C=&EO;BP@=&AI<R!F
M=6YC=&EO;B!W:6QL('-P;&ET('1H96T@*&%T('1H92!F:7)S=`T*("`@("`J
M(&)L86YK(&QI;F4I(&%N9"!R971U<FX@=&AE;2X-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@26YP=70@=&\@<W!L:70@87!A<G0-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y($-O;G1A:6YS(&AE861E<B!A;F0@8F]D>2!S96-T:6]N
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@7W-P;&ET0F]D>4AE861E<B@D:6YP=70I#0H@("`@>PT*("`@("`@("!I
M9B`H<')E9U]M871C:"@B+UXH+BH_*5QR/UQN7'(_7&XH+BHI+W,B+"`D:6YP
M=70L("1M871C:"DI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@D;6%T
M8VA;,5TL("1M871C:%LR72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]E<G)O<B`]("=#;W5L9"!N;W0@<W!L:70@:&5A9&5R(&%N9"!B;V1Y)SL-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%!A<G-E(&AE861E<G,@9VEV96X@:6X@)&EN<'5T(&%N9"!R971U<FX-
M"B`@("`@*B!A<R!A<W-O8R!A<G)A>2X-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@2&5A9&5R<R!T;R!P87)S90T*("`@("`J($!R971U<FX@87)R
M87D@0V]N=&%I;G,@<&%R<V5D(&AE861E<G,-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<&%R<V5(96%D97)S*"1I
M;G!U="D-"B`@("![#0H-"B`@("`@("`@:68@*"1I;G!U="`A/3T@)R<I('L-
M"B`@("`@("`@("`@("\O(%5N9F]L9"!T:&4@:6YP=70-"B`@("`@("`@("`@
M("1I;G!U="`@(#T@<')E9U]R97!L86-E*"(O7'(_7&XO(BP@(EQR7&XB+"`D
M:6YP=70I.PT*("`@("`@("`@("`@)&EN<'5T("`@/2!P<F5G7W)E<&QA8V4H
M(B]<<EQN*%QT?"`I*R\B+"`G("<L("1I;G!U="D[#0H@("`@("`@("`@("`D
M:&5A9&5R<R`](&5X<&QO9&4H(EQR7&XB+"!T<FEM*"1I;G!U="DI.PT*#0H@
M("`@("`@("`@("!F;W)E86-H("@D:&5A9&5R<R!A<R`D=F%L=64I('L-"B`@
M("`@("`@("`@("`@("`D:&1R7VYA;64@/2!S=6)S='(H)'9A;'5E+"`P+"`D
M<&]S(#T@<W1R<&]S*"1V86QU92P@)SHG*2D[#0H@("`@("`@("`@("`@("`@
M)&AD<E]V86QU92`]('-U8G-T<B@D=F%L=64L("1P;W,K,2D[#0H@("`@("`@
M("`@("`@("`@:68H)&AD<E]V86QU95LP72`]/2`G("<I#0H@("`@("`@("`@
M("`@("`@("`@("1H9')?=F%L=64@/2!S=6)S='(H)&AD<E]V86QU92P@,2D[
M#0H-"B`@("`@("`@("`@("`@("`D<F5T=7)N6UT@/2!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1H9')?
M;F%M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L
M=64G(#T^("1T:&ES+3Y?9&5C;V1E7VAE861E<G,@/R`D=&AI<RT^7V1E8V]D
M94AE861E<B@D:&1R7W9A;'5E*2`Z("1H9')?=F%L=64-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D<F5T=7)N(#T@87)R87DH*3L-
M"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B`D<F5T=7)N.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($9U;F-T:6]N('1O('!A<G-E(&$@:&5A9&5R
M('9A;'5E+`T*("`@("`J(&5X=')A8W0@9FER<W0@<&%R="P@86YD(&%N>2!S
M96-O;F1A<GD-"B`@("`@*B!P87)T<R`H869T97(@.RD@5&AI<R!F=6YC=&EO
M;B!I<R!N;W0@87,-"B`@("`@*B!R;V)U<W0@87,@:70@8V]U;&0@8F4N($5G
M+B!H96%D97(@8V]M;65N=',-"B`@("`@*B!I;B!T:&4@=W)O;F<@<&QA8V4@
M=VEL;"!P<F]B86)L>2!B<F5A:R!I="X-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@2&5A9&5R('9A;'5E('1O('!A<G-E#0H@("`@("H@0')E='5R
M;B!A<G)A>2!#;VYT86EN<R!P87)S960@<F5S=6QT#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W!A<G-E2&5A9&5R
M5F%L=64H)&EN<'5T*0T*("`@('L-"@T*("`@("`@("!I9B`H*"1P;W,@/2!S
M=')P;W,H)&EN<'5T+"`G.R<I*2`A/3T@9F%L<V4I('L-"@T*("`@("`@("`@
M("`@)')E='5R;ELG=F%L=64G72`]('1R:6TH<W5B<W1R*"1I;G!U="P@,"P@
M)'!O<RDI.PT*("`@("`@("`@("`@)&EN<'5T(#T@=')I;2AS=6)S='(H)&EN
M<'5T+"`D<&]S*S$I*3L-"@T*("`@("`@("`@("`@:68@*'-T<FQE;B@D:6YP
M=70I(#X@,"D@>PT*#0H@("`@("`@("`@("`@("`@+R\@5&AI<R!S<&QI=',@
M;VX@82!S96UI+6-O;&]N+"!I9B!T:&5R92=S(&YO('!R96-E961I;F<@8F%C
M:W-L87-H#0H@("`@("`@("`@("`@("`@+R\@0V%N)W0@:&%N9&QE(&EF(&ET
M)W,@:6X@9&]U8FQE('%U;W1E<R!H;W=E=F5R+B`H3V8@8V]U<G-E(&%N>6]N
M90T*("`@("`@("`@("`@("`@("\O('-E;F1I;F<@=&AA="!N965D<R!A(&=O
M;V0@<VQA<"DN#0H@("`@("`@("`@("`@("`@)'!A<F%M971E<G,@/2!P<F5G
M7W-P;&ET*"<O7',J*#\\(5Q<7%PI.UQS*B]I)RP@)&EN<'5T*3L-"@T*("`@
M("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1P87)A;65T
M97)S*3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@("`@("`D<&%R86U?;F%M
M92`@/2!S=6)S='(H)'!A<F%M971E<G-;)&E=+"`P+"`D<&]S(#T@<W1R<&]S
M*"1P87)A;65T97)S6R1I72P@)STG*2D[#0H@("`@("`@("`@("`@("`@("`@
M("1P87)A;5]V86QU92`]('-U8G-T<B@D<&%R86UE=&5R<ULD:5TL("1P;W,@
M*R`Q*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1P87)A;5]V86QU95LP
M72`]/2`G(B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;5]V
M86QU92`]('-U8G-T<B@D<&%R86U?=F%L=64L(#$L("TQ*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N6R=O
M=&AE<B==6R1P87)A;5]N86UE72`]("1P87)A;5]V86QU93L-"B`@("`@("`@
M("`@("`@("`@("`@)')E='5R;ELG;W1H97(G75MS=')T;VQO=V5R*"1P87)A
M;5]N86UE*5T@/2`D<&%R86U?=F%L=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)')E='5R;ELG=F%L=64G72`]('1R:6TH)&EN<'5T*3L-"B`@("`@("`@?0T*
M#0H@("`@("`@(')E='5R;B`D<F5T=7)N.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%1H:7,@9G5N8W1I;VX@<W!L:71S('1H92!I;G!U="!B87-E9`T*
M("`@("`J(&]N('1H92!G:79E;B!B;W5N9&%R>0T*("`@("`J#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!);G!U="!T;R!P87)S90T*("`@("`J($!R971U<FX@
M87)R87D@0V]N=&%I;G,@87)R87D@;V8@<F5S=6QT:6YG(&UI;64@<&%R=',-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?8F]U;F1A<GE3<&QI="@D:6YP=70L("1B;W5N9&%R>2D-"B`@("![#0H@
M("`@("`@("1T;7`@/2!E>'!L;V1E*"<M+2<N)&)O=6YD87)Y+"`D:6YP=70I
M.PT*#0H@("`@("`@(&9O<B`H)&D],3L@)&D\8V]U;G0H)'1M<"DM,3L@)&DK
M*RD@>PT*("`@("`@("`@("`@)'!A<G1S6UT@/2`D=&UP6R1I73L-"B`@("`@
M("`@?0T*#0H@("`@("`@(')E='5R;B`D<&%R=',[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@1VEV96X@82!H96%D97(L('1H:7,@9G5N8W1I;VX@=VEL
M;"!D96-O9&4@:70-"B`@("`@*B!A8V-O<F1I;F<@=&\@4D9#,C`T-RX@4')O
M8F%B;'D@;F]T("IE>&%C=&QY*@T*("`@("`J(&-O;F9O<FUA;G0L(&)U="!I
M="!D;V5S('!A<W,@86QL('1H92!G:79E;@T*("`@("`J(&5X86UP;&5S("AI
M;B!21D,R,#0W*2X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@26YP
M=70@:&5A9&5R('9A;'5E('1O(&1E8V]D90T*("`@("`J($!R971U<FX@<W1R
M:6YG($1E8V]D960@:&5A9&5R('9A;'5E#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V1E8V]D94AE861E<B@D:6YP
M=70I#0H@("`@>PT*("`@("`@("`O+R!296UO=F4@=VAI=&4@<W!A8V4@8F5T
M=V5E;B!E;F-O9&5D+7=O<F1S#0H@("`@("`@("1I;G!U="`]('!R96=?<F5P
M;&%C92@G+R@]7#];7C]=*UP_*'%\8BE</UM>/UTJ7#\]*2A<<RDK/5P_+VDG
M+"`G7#$]/R<L("1I;G!U="D[#0H-"B`@("`@("`@+R\@1F]R(&5A8V@@96YC
M;V1E9"UW;W)D+BXN#0H@("`@("`@('=H:6QE("AP<F5G7VUA=&-H*"<O*#U<
M/RA;7C]=*RE</RAQ?&(I7#\H6UX_72HI7#\]*2]I)RP@)&EN<'5T+"`D;6%T
M8VAE<RDI('L-"@T*("`@("`@("`@("`@)&5N8V]D960@(#T@)&UA=&-H97-;
M,5T[#0H@("`@("`@("`@("`D8VAA<G-E="`@/2`D;6%T8VAE<ULR73L-"B`@
M("`@("`@("`@("1E;F-O9&EN9R`]("1M871C:&5S6S-=.PT*("`@("`@("`@
M("`@)'1E>'0@("`@(#T@)&UA=&-H97-;-%T[#0H-"B`@("`@("`@("`@('-W
M:71C:"`H<W1R=&]L;W=E<B@D96YC;V1I;F<I*2![#0H@("`@("`@("`@("`@
M("`@8V%S92`G8B<Z#0H@("`@("`@("`@("`@("`@("`@("1T97AT(#T@8F%S
M938T7V1E8V]D92@D=&5X="D[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*#0H@("`@("`@("`@("`@("`@8V%S92`G<2<Z#0H@("`@("`@("`@("`@
M("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)U\G+"`G("<L("1T97AT*3L-
M"B`@("`@("`@("`@("`@("`@("`@<')E9U]M871C:%]A;&PH)R\]*%MA+68P
M+3E=>S)]*2]I)RP@)'1E>'0L("1M871C:&5S*3L-"B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"@D;6%T8VAE<ULQ72!A<R`D=F%L=64I#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*"<])RXD=F%L
M=64L(&-H<BAH97AD96,H)'9A;'5E*2DL("1T97AT*3L-"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@
M("1I;G!U="`]('-T<E]R97!L86-E*"1E;F-O9&5D+"`D=&5X="P@)&EN<'5T
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B`D:6YP=70[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@1VEV96X@82!B;V1Y('-T<FEN9R!A;F0@
M86X@96YC;V1I;F<@='EP92P-"B`@("`@*B!T:&ES(&9U;F-T:6]N('=I;&P@
M9&5C;V1E(&%N9"!R971U<FX@:70N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M('-T<FEN9R!);G!U="!B;V1Y('1O(&1E8V]D90T*("`@("`J($!P87)A;2`@
M<W1R:6YG($5N8V]D:6YG('1Y<&4@=&\@=7-E+@T*("`@("`J($!R971U<FX@
M<W1R:6YG($1E8V]D960@8F]D>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]D96-O9&5";V1Y*"1I;G!U="P@)&5N
M8V]D:6YG(#T@)S=B:70G*0T*("`@('L-"B`@("`@("`@<W=I=&-H("@D96YC
M;V1I;F<I('L-"B`@("`@("`@("`@(&-A<V4@)S=B:70G.@T*("`@("`@("`@
M("`@("`@(')E='5R;B`D:6YP=70[#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H-"B`@("`@("`@("`@(&-A<V4@)W%U;W1E9"UP<FEN=&%B;&4G.@T*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W%U;W1E9%!R:6YT86)L941E
M8V]D92@D:6YP=70I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@
M("`@("`@("!C87-E("=B87-E-C0G.@T*("`@("`@("`@("`@("`@(')E='5R
M;B!B87-E-C1?9&5C;V1E*"1I;G!U="D[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H-"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1I;G!U=#L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($=I=F5N(&$@<75O=&5D+7!R:6YT86)L92!S=')I;F<L('1H:7,-
M"B`@("`@*B!F=6YC=&EO;B!W:6QL(&1E8V]D92!A;F0@<F5T=7)N(&ET+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M("!S=')I;F<@26YP=70@8F]D>2!T;R!D
M96-O9&4-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!$96-O9&5D(&)O9'D-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?
M<75O=&5D4')I;G1A8FQE1&5C;V1E*"1I;G!U="D-"B`@("![#0H@("`@("`@
M("\O(%)E;6]V92!S;V9T(&QI;F4@8G)E86MS#0H@("`@("`@("1I;G!U="`]
M('!R96=?<F5P;&%C92@B+SU<<C]<;B\B+"`G)RP@)&EN<'5T*3L-"@T*("`@
M("`@("`O+R!297!L86-E(&5N8V]D960@8VAA<F%C=&5R<PT*"0DD:6YP=70@
M/2!P<F5G7W)E<&QA8V4H)R\]*%MA+68P+3E=>S)]*2]I92<L(")C:'(H:&5X
M9&5C*"=<7#$G*2DB+"`D:6YP=70I.PT*#0H@("`@("`@(')E='5R;B`D:6YP
M=70[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0VAE8VMS('1H92!I;G!U
M="!F;W(@=75E;F-O9&5D(&9I;&5S(&%N9"!R971U<FYS#0H@("`@("H@86X@
M87)R87D@;V8@=&AE;2X@0V%N(&)E(&-A;&QE9"!S=&%T:6-A;&QY+"!E9SH-
M"B`@("`@*@T*("`@("`J("1F:6QE<R`])B!-86EL7VUI;65$96-O9&4Z.G5U
M9&5C;V1E*"1S;VUE7W1E>'0I.PT*("`@("`J#0H@("`@("H@270@=VEL;"!C
M:&5C:R!F;W(@=&AE(&)E9VEN(#8V-B`N+BX@96YD('-Y;G1A>`T*("`@("`J
M(&AO=V5V97(@86YD('=O;B=T(&IU<W0@8FQI;F1L>2!D96-O9&4@=VAA=&5V
M97(@>6]U#0H@("`@("H@<&%S<R!I="X-"B`@("`@*@T*("`@("`J($!P87)A
M;2`@<W1R:6YG($EN<'5T(&)O9'D@=&\@;&]O:R!F;W(@871T86AC;65N=',@
M:6X-"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!$96-O9&5D(&)O9&EE<RP@9FEL
M96YA;65S(&%N9"!P97)M:7-S:6]N<PT*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("H@0&%U=&AO<B!5;FMN;W=N#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@)G5U9&5C;V1E*"1I;G!U="D-"B`@("![#0H@("`@("`@("\O($9I;F0@
M86QL('5U96YC;V1E9"!S96-T:6]N<PT*("`@("`@("!P<F5G7VUA=&-H7V%L
M;"@B+V)E9VEN("A;,"TW77LS?2D@*"XK*5QR/UQN*"XK*5QR/UQN96YD+U5S
M(BP@)&EN<'5T+"`D;6%T8VAE<RD[#0H-"B`@("`@("`@9F]R("@D:B`](#`[
M("1J(#P@8V]U;G0H)&UA=&-H97-;,UTI.R`D:BLK*2![#0H-"B`@("`@("`@
M("`@("1S='(@("`@("`]("1M871C:&5S6S-=6R1J73L-"B`@("`@("`@("`@
M("1F:6QE;F%M92`]("1M871C:&5S6S)=6R1J73L-"B`@("`@("`@("`@("1F
M:6QE<&5R;2`]("1M871C:&5S6S%=6R1J73L-"@T*("`@("`@("`@("`@)&9I
M;&4@/2`G)SL-"B`@("`@("`@("`@("1S='(@/2!P<F5G7W-P;&ET*"(O7'(_
M7&XO(BP@=')I;2@D<W1R*2D[#0H@("`@("`@("`@("`D<W1R;&5N(#T@8V]U
M;G0H)'-T<BD[#0H-"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1S
M=')L96X[("1I*RLI('L-"B`@("`@("`@("`@("`@("`D<&]S(#T@,3L-"B`@
M("`@("`@("`@("`@("`D9"`](#`[#0H@("`@("`@("`@("`@("`@)&QE;CTH
M:6YT*2@H*&]R9"AS=6)S='(H)'-T<ELD:5TL,"PQ*2D@+3,R*2`M("<@)RD@
M)B`P-S<I.PT*#0H@("`@("`@("`@("`@("`@=VAI;&4@*"@D9"`K(#,@/#T@
M)&QE;BD@04Y$("@D<&]S("L@-"`\/2!S=')L96XH)'-T<ELD:5TI*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D8S`@/2`H;W)D*'-U8G-T<B@D<W1R6R1I
M72PD<&]S+#$I*2!>(#!X,C`I.PT*("`@("`@("`@("`@("`@("`@("`D8S$@
M/2`H;W)D*'-U8G-T<B@D<W1R6R1I72PD<&]S*S$L,2DI(%X@,'@R,"D[#0H@
M("`@("`@("`@("`@("`@("`@("1C,B`]("AO<F0H<W5B<W1R*"1S=');)&E=
M+"1P;W,K,BPQ*2D@7B`P>#(P*3L-"B`@("`@("`@("`@("`@("`@("`@)&,S
M(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL)'!O<RLS+#$I*2!>(#!X,C`I.PT*
M("`@("`@("`@("`@("`@("`@("`D9FEL92`N/2!C:'(H*"@H)&,P("T@)R`G
M*2`F(#`W-RD@/#P@,BD@?"`H*"@D8S$@+2`G("<I("8@,#<W*2`^/B`T*2D[
M#0H-"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@+CT@8VAR*"@H*"1C,2`M
M("<@)RD@)B`P-S<I(#P\(#0I('P@*"@H)&,R("T@)R`G*2`F(#`W-RD@/CX@
M,BDI.PT*#0H@("`@("`@("`@("`@("`@("`@("1F:6QE("X](&-H<B@H*"@D
M8S(@+2`G("<I("8@,#<W*2`\/"`V*2!\("`H*"1C,R`M("<@)RD@)B`P-S<I
M*3L-"@T*("`@("`@("`@("`@("`@("`@("`D<&]S("L](#0[#0H@("`@("`@
M("`@("`@("`@("`@("1D("L](#,[#0H@("`@("`@("`@("`@("`@?0T*#0H@
M("`@("`@("`@("`@("`@:68@*"@D9"`K(#(@/#T@)&QE;BD@)B8@*"1P;W,@
M*R`S(#P]('-T<FQE;B@D<W1R6R1I72DI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1C,"`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P;W,L,2DI(%X@,'@R
M,"D[#0H@("`@("`@("`@("`@("`@("`@("1C,2`]("AO<F0H<W5B<W1R*"1S
M=');)&E=+"1P;W,K,2PQ*2D@7B`P>#(P*3L-"B`@("`@("`@("`@("`@("`@
M("`@)&,R(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL)'!O<RLR+#$I*2!>(#!X
M,C`I.PT*("`@("`@("`@("`@("`@("`@("`D9FEL92`N/2!C:'(H*"@H)&,P
M("T@)R`G*2`F(#`W-RD@/#P@,BD@?"`H*"@D8S$@+2`G("<I("8@,#<W*2`^
M/B`T*2D[#0H-"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@+CT@8VAR*"@H
M*"1C,2`M("<@)RD@)B`P-S<I(#P\(#0I('P@*"@H)&,R("T@)R`G*2`F(#`W
M-RD@/CX@,BDI.PT*#0H@("`@("`@("`@("`@("`@("`@("1P;W,@*ST@,SL-
M"B`@("`@("`@("`@("`@("`@("`@)&0@*ST@,CL-"B`@("`@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@("`@("!I9B`H*"1D("L@,2`\/2`D;&5N*2`F
M)B`H)'!O<R`K(#(@/#T@<W1R;&5N*"1S=');)&E=*2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&,P(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL)'!O<RPQ
M*2D@7B`P>#(P*3L-"B`@("`@("`@("`@("`@("`@("`@)&,Q(#T@*&]R9"AS
M=6)S='(H)'-T<ELD:5TL)'!O<RLQ+#$I*2!>(#!X,C`I.PT*("`@("`@("`@
M("`@("`@("`@("`D9FEL92`N/2!C:'(H*"@H)&,P("T@)R`G*2`F(#`W-RD@
M/#P@,BD@?"`H*"@D8S$@+2`G("<I("8@,#<W*2`^/B`T*2D[#0H-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9FEL
M97-;72`](&%R<F%Y*"=F:6QE;F%M92<@/3X@)&9I;&5N86UE+"`G9FEL97!E
M<FTG(#T^("1F:6QE<&5R;2P@)V9I;&5D871A)R`]/B`D9FEL92D[#0H@("`@
M("`@('T-"@T*("`@("`@("!R971U<FX@)&9I;&5S.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J(&=E=%-E;F1!<G)A>2@I(')E='5R;G,@=&AE(&%R9W5M
M96YT<R!R97%U:7)E9"!F;W(@36%I;#HZ<V5N9"@I#0H@("`@("H@=7-E9"!T
M;R!B=6EL9"!T:&4@87)G=6UE;G1S(&9O<B!A(&UA:6PZ.G-E;F0H*2!C86QL
M(`T*("`@("`J#0H@("`@("H@57-A9V4Z#0H@("`@("H@)&UA:6QT97AT(#T@
M1G5L;"!E;6%I;"`H9F]R(&5X86UP;&4@9V5N97)A=&5D(&)Y(&$@=&5M<&QA
M=&4I#0H@("`@("H@)&1E8V]D97(@/2!N97<@36%I;%]M:6UE1&5C;V1E*"1M
M86EL=&5X="D[#0H@("`@("H@)'!A<G1S(#T@("1D96-O9&5R+3YG971396YD
M07)R87DH*3L-"B`@("`@*B!I9B`H(5!%05(Z.FES17)R;W(H)'!A<G1S*2![
M#0H@("`@("H@("`@(&QI<W0H)')E8VEP96YT<RPD:&5A9&5R<RPD8F]D>2D@
M/2`D<&%R=',[#0H@("`@("H@("`@("1M86EL(#T@36%I;#HZ9F%C=&]R>2@G
M<VUT<"<I.PT*("`@("`J("`@("`D;6%I;"T^<V5N9"@D<F5C:7!E;G1S+"1H
M96%D97)S+"1B;V1Y*3L-"B`@("`@*B!](&5L<V4@>PT*("`@("`J("`@("!E
M8VAO("1P87)T<RT^;65S<V%G93L-"B`@("`@*B!]#0H@("`@("H@0')E='5R
M;B!M:7AE9"`@(&%R<F%Y(&]F(')E8VEP96EN="P@:&5A9&5R<RQB;V1Y(&]R
M(%!E87)?17)R;W(-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!A
M=71H;W(@06QA;B!+;F]W;&5S(#QA;&%N0&%K8FMH;VUE+F-O;3X-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G971396YD07)R87DH*0T*("`@('L-"B`@("`@
M("`@+R\@<')E=F5N="!W87)N:6YG(&EF('1H:7,@:7,@;F]T('-E=`T*("`@
M("`@("`D=&AI<RT^7V1E8V]D95]H96%D97)S(#T@1D%,4T4[#0H@("`@("`@
M("1H96%D97)L:7-T(#TD=&AI<RT^7W!A<G-E2&5A9&5R<R@D=&AI<RT^7VAE
M861E<BD[#0H@("`@("`@("1T;R`]("(B.PT*("`@("`@("!I9B`H(21H96%D
M97)L:7-T*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(DUE<W-A9V4@9&ED(&YO="!C;VYT86EN(&AE861E<G,B*3L-"B`@("`@
M("`@?0T*("`@("`@("!F;W)E86-H*"1H96%D97)L:7-T(&%S("1I=&5M*2![
M#0H@("`@("`@("`@("`D:&5A9&5R6R1I=&5M6R=N86UE)UU=(#T@)&ET96U;
M)W9A;'5E)UT[#0H@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)&ET
M96U;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("!C87-E(")T;R(Z#0H@
M("`@("`@("`@("`@("`@8V%S92`B8V,B.@T*("`@("`@("`@("`@("`@(&-A
M<V4@(F)C8R(Z#0H@("`@("`@("`@("`@("`@("`@("1T;R`]("(L(BXD:71E
M;5LG=F%L=64G73L-"B`@("`@("`@("`@("`@("!D969A=6QT.@T*("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("@D=&\@/3T@(B(I('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B365S<V%G92!D:60@;F]T(&-O;G1A:6X@
M86YY(')E8VEP96YT<R(I.PT*("`@("`@("!]#0H@("`@("`@("1T;R`]('-U
M8G-T<B@D=&\L,2D[#0H@("`@("`@(')E='5R;B!A<G)A>2@D=&\L)&AE861E
M<BPD=&AI<RT^7V)O9'DI.PT*("`@('T@#0H-"@T*#0H-"@T*#0H-"@T*#0H@
M("`@+RHJ#0H@("`@("H@4F5T=7)N<R!A('AM;"!C;W!Y(&]F('1H92!O=71P
M=70@;V8-"B`@("`@*B!-86EL7VUI;65$96-O9&4Z.F1E8V]D92X@4&%S<R!T
M:&4@;W5T<'5T(&EN(&%S('1H90T*("`@("`J(&%R9W5M96YT+B!4:&ES(&9U
M;F-T:6]N(&-A;B!B92!C86QL960@<W1A=&EC86QL>2X@16<Z#0H@("`@("H-
M"B`@("`@*B`D;W5T<'5T(#T@)&]B:BT^9&5C;V1E*"D[#0H@("`@("H@)'AM
M;"`@("`]($UA:6Q?;6EM941E8V]D93HZ9V5T6$U,*"1O=71P=70I.PT*("`@
M("`J#0H@("`@("H@5&AE($141"!U<V5D(&9O<B!T:&ES('-H;W5L9"!H879E
M(&)E96X@:6X@=&AE('!A8VMA9V4N($]R#0H@("`@("H@86QT97)N871I=F5L
M>2!Y;W4@8V%N(&=E="!I="!F<F]M(&-V<RP@;W(@:&5R93H-"B`@("`@*B!H
M='1P.B\O=W=W+G!H<&=U<G4N;W)G+WAM86EL+WAM86EL+F1T9"X-"B`@("`@
M*@T*("`@("`J($!P87)A;2`@;V)J96-T($EN<'5T('1O(&-O;G9E<G0@=&\@
M>&UL+B!4:&ES('-H;W5L9"!B92!T:&4-"B`@("`@*B`@("`@("`@("`@("`@
M("!O=71P=70@;V8@=&AE($UA:6Q?;6EM941E8V]D93HZ9&5C;V1E(&9U;F-T
M:6]N#0H@("`@("H@0')E='5R;B!S=')I;F<@6$U,('9E<G-I;VX@;V8@:6YP
M=70-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=%A-3"@D:6YP=70I#0H@("`@>PT*("`@("`@("`D8W)L9B`@("`]
M("`B7')<;B([#0H@("`@("`@("1O=71P=70@(#T@)SP_>&UL('9E<G-I;VX]
M7"<Q+C!<)S\^)R`N("1C<FQF("X-"B`@("`@("`@("`@("`@("`@("`G/"%$
M3T-465!%(&5M86EL(%-94U1%32`B:'1T<#HO+W=W=RYP:'!G=7)U+F]R9R]X
M;6%I;"]X;6%I;"YD=&0B/B<@+B`D8W)L9B`N#0H@("`@("`@("`@("`@("`@
M("`@)SQE;6%I;#XG("X@)&-R;&8@+@T*("`@("`@("`@("`@("`@("`@($UA
M:6Q?;6EM941E8V]D93HZ7V=E=%A-3"@D:6YP=70I("X-"B`@("`@("`@("`@
M("`@("`@("`G/"]E;6%I;#XG.PT*#0H@("`@("`@(')E='5R;B`D;W5T<'5T
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($9U;F-T:6]N('1H870@9&]E
M<R!T:&4@86-T=6%L(&-O;G9E<G-I;VX@=&\@>&UL+B!$;V5S(&$@<VEN9VQE
M#0H@("`@("H@;6EM97!A<G0@870@82!T:6UE+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M("!O8FIE8W0@($EN<'5T('1O(&-O;G9E<G0@=&\@>&UL+B!4:&ES
M(&ES(&$@;6EM97!A<G0@;V)J96-T+@T*("`@("`J("`@("`@("`@("`@("`@
M("!)="!M87D@;W(@;6%Y(&YO="!C;VYT86EN('-U8G!A<G1S+@T*("`@("`J
M($!P87)A;2`@:6YT96=E<B!.=6UB97(@;V8@=&%B<R!T;R!I;F1E;G0-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@6$U,('9E<G-I;VX@;V8@:6YP=70-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?
M9V5T6$U,*"1I;G!U="P@)&EN9&5N="`](#$I#0H@("`@>PT*("`@("`@("`D
M:'1A8B`@("`]("`B7'0B.PT*("`@("`@("`D8W)L9B`@("`]("`B7')<;B([
M#0H@("`@("`@("1O=71P=70@(#T@("<G.PT*("`@("`@("`D:&5A9&5R<R`]
M($`H87)R87DI)&EN<'5T+3YH96%D97)S.PT*#0H@("`@("`@(&9O<F5A8V@@
M*"1H96%D97)S(&%S("1H9')?;F%M92`]/B`D:&1R7W9A;'5E*2![#0H-"B`@
M("`@("`@("`@("\O($UU;'1I<&QE(&AE861E<G,@=VET:"!T:&ES(&YA;64-
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D:&5A9&5R<ULD:&1R7VYA;65=
M*2D@>PT*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1H9')?=F%L=64I.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@36%I;%]M:6UE1&5C;V1E.CI?9V5T6$U,7VAE;'!E<B@D:&1R
M7VYA;64L("1H9')?=F%L=65;)&E=+"`D:6YD96YT*3L-"B`@("`@("`@("`@
M("`@("!]#0H-"B`@("`@("`@("`@("\O($]N;'D@;VYE(&AE861E<B!O9B!T
M:&ES('-O<G0-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@)&]U='!U="`N/2!-86EL7VUI;65$96-O9&4Z.E]G971834Q?:&5L<&5R
M*"1H9')?;F%M92P@)&AD<E]V86QU92P@)&EN9&5N="D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H(65M<'1Y*"1I;G!U="T^
M<&%R=',I*2![#0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N
M="@D:6YP=70M/G!A<G1S*3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@)&-R;&8@+B!S=')?<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N
M("<\;6EM97!A<G0^)R`N("1C<FQF("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@($UA:6Q?;6EM941E8V]D93HZ7V=E=%A-3"@D:6YP=70M/G!A<G1S
M6R1I72P@)&EN9&5N="LQ*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')?<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N("<\+VUI;65P87)T/B<@
M+B`D8W)L9CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1I;G!U="T^8F]D>2DI('L-"B`@("`@("`@("`@("1O=71P=70@+CT@
M)&-R;&8@+B!S=')?<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N("<\8F]D>3X\
M(5M#1$%405LG("X-"B`@("`@("`@("`@("`@("`@("`@("`@)&EN<'5T+3YB
M;V1Y("X@)UU=/CPO8F]D>3XG("X@)&-R;&8[#0H@("`@("`@('T-"@T*("`@
M("`@("!R971U<FX@)&]U='!U=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!(96QP97(@9G5N8W1I;VX@=&\@7V=E=%A-3"@I+B!2971U<FYS('AM;"!O
M9B!A(&AE861E<BX-"B`@("`@*@T*("`@("`J($!P87)A;2`@<W1R:6YG("!.
M86UE(&]F(&AE861E<@T*("`@("`J($!P87)A;2`@<W1R:6YG("!686QU92!O
M9B!H96%D97(-"B`@("`@*B!`<&%R86T@(&EN=&5G97(@3G5M8F5R(&]F('1A
M8G,@=&\@:6YD96YT#0H@("`@("H@0')E='5R;B!S=')I;F<@(%A-3"!V97)S
M:6]N(&]F(&EN<'5T#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7V=E=%A-3%]H96QP97(H)&AD<E]N86UE+"`D:&1R
M7W9A;'5E+"`D:6YD96YT*0T*("`@('L-"B`@("`@("`@)&AT86(@("`](")<
M="([#0H@("`@("`@("1C<FQF("`@/2`B7')<;B([#0H@("`@("`@("1R971U
M<FX@/2`G)SL-"@T*("`@("`@("`D;F5W7VAD<E]V86QU92`]("@D:&1R7VYA
M;64@(3T@)W)E8V5I=F5D)RD@/R!-86EL7VUI;65$96-O9&4Z.E]P87)S94AE
M861E<E9A;'5E*"1H9')?=F%L=64I(#H@87)R87DH)W9A;'5E)R`]/B`D:&1R
M7W9A;'5E*3L-"B`@("`@("`@)&YE=U]H9')?;F%M92`@/2!S=')?<F5P;&%C
M92@G("<L("<M)RP@=6-W;W)D<RAS=')?<F5P;&%C92@G+2<L("<@)RP@)&AD
M<E]N86UE*2DI.PT*#0H@("`@("`@("\O(%-O<G0@;W5T(&%N>2!P87)A;65T
M97)S#0H@("`@("`@(&EF("@A96UP='DH)&YE=U]H9')?=F%L=65;)V]T:&5R
M)UTI*2![#0H@("`@("`@("`@("!F;W)E86-H("@D;F5W7VAD<E]V86QU95LG
M;W1H97(G72!A<R`D<&%R86UN86UE(#T^("1P87)A;79A;'5E*2![#0H@("`@
M("`@("`@("`@("`@)'!A<F%M<UM=(#T@<W1R7W)E<&5A="@D:'1A8BP@)&EN
M9&5N="D@+B`D:'1A8B`N("<\<&%R86UE=&5R/B<@+B`D8W)L9B`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D:'1A8BP@)&EN
M9&5N="D@+B`D:'1A8B`N("1H=&%B("X@)SQP87)A;6YA;64^)R`N(&AT;6QS
M<&5C:6%L8VAA<G,H)'!A<F%M;F%M92D@+B`G/"]P87)A;6YA;64^)R`N("1C
M<FQF("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')?<F5P96%T
M*"1H=&%B+"`D:6YD96YT*2`N("1H=&%B("X@)&AT86(@+B`G/'!A<F%M=F%L
M=64^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'!A<F%M=F%L=64I("X@)SPO<&%R
M86UV86QU93XG("X@)&-R;&8@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)&AT86(@+B`G/"]P
M87)A;65T97(^)R`N("1C<FQF.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@
M("`@("`D<&%R86US(#T@:6UP;&]D92@G)RP@)'!A<F%M<RD[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D<&%R86US(#T@)R<[#0H@("`@("`@
M('T-"@T*("`@("`@("`D<F5T=7)N(#T@<W1R7W)E<&5A="@D:'1A8BP@)&EN
M9&5N="D@+B`G/&AE861E<CXG("X@)&-R;&8@+@T*("`@("`@("`@("`@("`@
M("`@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@+B`D:'1A8B`N("<\:&5A
M9&5R;F%M93XG("X@:'1M;'-P96-I86QC:&%R<R@D;F5W7VAD<E]N86UE*2`N
M("<\+VAE861E<FYA;64^)R`N("1C<FQF("X-"B`@("`@("`@("`@("`@("`@
M('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)&AT86(@+B`G/&AE861E
M<G9A;'5E/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1N97=?:&1R7W9A;'5E6R=V
M86QU92==*2`N("<\+VAE861E<G9A;'5E/B<@+B`D8W)L9B`N#0H@("`@("`@
M("`@("`@("`@("`D<&%R86US("X-"B`@("`@("`@("`@("`@("`@('-T<E]R
M97!E870H)&AT86(L("1I;F1E;G0I("X@)SPO:&5A9&5R/B<@+B`D8W)L9CL-
M"@T*("`@("`@("!R971U<FX@)')E='5R;CL-"B`@("!]#0H-"GT@+R\@16YD
M(&]F(&-L87-S#0H_/@T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O36%I;"]S96YD;6%I
M;"YP:'``````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(T
M-C$`,3`T,3<S-C,P,#<`,#(P-3,T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@IR
M97%U:7)E7V]N8V4@)TUA:6PN<&AP)SL*"B\J*@H@*B!396YD;6%I;"!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4@4$5!4B!-86EL.CH@:6YT97)F86-E+@H@*B!`
M86-C97-S('!U8FQI8PH@*B!`<&%C:V%G92!-86EL"B`J($!V97)S:6]N("12
M979I<VEO;CH@,2XT("0*("HO"F-L87-S($UA:6Q?<V5N9&UA:6P@97AT96YD
M<R!-86EL('L*("`@(`H)+RHJ"B`@("`@*B!4:&4@;&]C871I;VX@;V8@=&AE
M('-E;F1M86EL(&]R('-E;F1M86EL('=R87!P97(@8FEN87)Y(&]N('1H90H@
M("`@("H@9FEL97-Y<W1E;2X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D<V5N9&UA:6Q?<&%T:"`]("<O=7-R+W-B:6XO<V5N9&UA:6PG
M.PH@("`@"@DO*BH*("`@("`J($%N>2!E>'1R82!C;VUM86YD+6QI;F4@<&%R
M86UE=&5R<R!T;R!P87-S('1O('1H92!S96YD;6%I;"!O<@H@("`@("H@<V5N
M9&UA:6P@=W)A<'!E<B!B:6YA<GDN"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)'-E;F1M86EL7V%R9W,@/2`G)SL*("`@(`H)+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J(`H@("`@("H@26YS=&%N=&EA=&5S
M(&$@;F5W($UA:6Q?<V5N9&UA:6PZ.B!O8FIE8W0@8F%S960@;VX@=&AE('!A
M<F%M971E<G,*("`@("`J('!A<W-E9"!I;BX@270@;&]O:W,@9F]R('1H92!F
M;VQL;W=I;F<@<&%R86UE=&5R<SH*("`@("`J("`@("!S96YD;6%I;%]P871H
M("`@(%1H92!L;V-A=&EO;B!O9B!T:&4@<V5N9&UA:6P@8FEN87)Y(&]N('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@9FEL97-Y<W1E;2X@1&5F
M875L=',@=&\@)R]U<W(O<V)I;B]S96YD;6%I;"<N"B`@("`@*@H@("`@("H@
M("`@('-E;F1M86EL7V%R9W,@("`@06YY(&5X=')A('!A<F%M971E<G,@=&\@
M<&%S<R!T;R!T:&4@<V5N9&UA:6P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@(&]R('-E;F1M86EL('=R87!P97(@8FEN87)Y+@H@("`@("H*("`@("`J
M($EF(&$@<&%R86UE=&5R(&ES('!R97-E;G0@:6X@=&AE("1P87)A;7,@87)R
M87DL(&ET(')E<&QA8V5S('1H90H@("`@("H@9&5F875L="X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R!(87-H(&-O;G1A:6YI;F<@86YY
M('!A<F%M971E<G,@9&EF9F5R96YT(&9R;VT@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@9&5F875L=',N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"0H@("`@9G5N8W1I;VX@36%I;%]S96YD;6%I;"@D<&%R86US*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R=S96YD;6%I;%]P871H)UTI*2`D
M=&AI<RT^<V5N9&UA:6Q?<&%T:"`]("1P87)A;7-;)W-E;F1M86EL7W!A=&@G
M73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG<V5N9&UA:6Q?87)G<R==
M*2D@)'1H:7,M/G-E;F1M86EL7V%R9W,@/2`D<&%R86US6R=S96YD;6%I;%]A
M<F=S)UT["@H@("`@("`@("\J"B`@("`@("`@("H@0F5C875S92!W92!N965D
M('1O('!A<W,@;65S<V%G92!H96%D97)S('1O('1H92!S96YD;6%I;"!P<F]G
M<F%M(&]N"B`@("`@("`@("H@=&AE(&-O;6UA;F1L:6YE+"!W92!C86XG="!G
M=6%R86YT964@=&AE('5S92!O9B!T:&4@<W1A;F1A<F0@(EQR7&XB"B`@("`@
M("`@("H@<V5P87)A=&]R+B`@26YS=&5A9"P@=V4@=7-E('1H92!S>7-T96TG
M<R!N871I=F4@;&EN92!S97!A<F%T;W(N"B`@("`@("`@("HO"B`@("`@("`@
M)'1H:7,M/G-E<"`]("AS=')S='(H4$A07T]3+"`G5TE.)RDI(#\@(EQR7&XB
M(#H@(EQN(CL*("`@('T*("`@(`H)+RHJ"B`@("`@*B!);7!L96UE;G1S($UA
M:6PZ.G-E;F0H*2!F=6YC=&EO;B!U<VEN9R!T:&4@<V5N9&UA:6P*("`@("`J
M(&-O;6UA;F0M;&EN92!B:6YA<GDN"B`@("`@*B`*("`@("`J($!P87)A;2!M
M:7AE9"`D<F5C:7!I96YT<R!%:71H97(@82!C;VUM82US97!E<F%T960@;&ES
M="!O9B!R96-I<&EE;G1S"B`@("`@*B`@("`@("`@("`@("`@*%)&0S@R,B!C
M;VUP;&EA;G0I+"!O<B!A;B!A<G)A>2!O9B!R96-I<&EE;G1S+`H@("`@("H@
M("`@("`@("`@("`@(&5A8V@@4D9#.#(R('9A;&ED+B!4:&ES(&UA>2!C;VYT
M86EN(')E8VEP:65N=',@;F]T"B`@("`@*B`@("`@("`@("`@("`@<W!E8VEF
M:65D(&EN('1H92!H96%D97)S+"!F;W(@0F-C.BP@<F5S96YD:6YG"B`@("`@
M*B`@("`@("`@("`@("`@;65S<V%G97,L(&5T8RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&AE861E<G,@5&AE(&%R<F%Y(&]F(&AE861E<G,@=&\@
M<V5N9"!W:71H('1H92!M86EL+"!I;B!A;@H@("`@("H@("`@("`@("`@("`@
M(&%S<V]C:6%T:79E(&%R<F%Y+"!W:&5R92!T:&4@87)R87D@:V5Y(&ES('1H
M90H@("`@("H@("`@("`@("`@("`@(&AE861E<B!N86UE("AI92P@)U-U8FIE
M8W0G*2P@86YD('1H92!A<G)A>2!V86QU90H@("`@("H@("`@("`@("`@("`@
M(&ES('1H92!H96%D97(@=F%L=64@*&EE+"`G=&5S="<I+B!4:&4@:&5A9&5R
M"B`@("`@*B`@("`@("`@("`@("`@<')O9'5C960@9G)O;2!T:&]S92!V86QU
M97,@=V]U;&0@8F4@)U-U8FIE8W0Z"B`@("`@*B`@("`@("`@("`@("`@=&5S
M="<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]D>2!4:&4@9G5L
M;"!T97AT(&]F('1H92!M97-S86=E(&)O9'DL(&EN8VQU9&EN9R!A;GD*("`@
M("`J("`@("`@("`@("`@("`@36EM92!P87)T<RP@971C+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L(&]R
M(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("!C;VYT86EN:6YG
M(&$@9&5S8W)I<'1I=F4@97)R;W(@;65S<V%G92!O;@H@("`@("H@("`@("`@
M("`@("`@("!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PD*("`@(&9U;F-T:6]N('-E;F0H)')E8VEP:65N=',L("1H96%D97)S+"`D
M8F]D>2D*("`@('L*("`@("`@("`D<F5C:7!I96YT<R`](&5S8V%P95-H96QL
M0VUD*&EM<&QO9&4H)R`G+"`D=&AI<RT^<&%R<V5296-I<&EE;G1S*"1R96-I
M<&EE;G1S*2DI.PH@("`@("`@(`H@("`@("`@(&QI<W0H)&9R;VTL("1T97AT
M7VAE861E<G,I(#T@)'1H:7,M/G!R97!A<F5(96%D97)S*"1H96%D97)S*3L*
M("`@("`@("!I9B`H(6ES<V5T*"1F<F]M*2D@>PH@("`@("`@("`@("!R971U
M<FX@;F5W(%!%05)?17)R;W(H)TYO(&9R;VT@861D<F5S<R!G:79E;BXG*3L*
M("`@("`@("!](&5L<V5I9B`H<W1R<W1R*"1F<F]M+"`G("<I('Q\"B`@("`@
M("`@("`@("`@("`@('-T<G-T<B@D9G)O;2P@)SLG*2!\?`H@("`@("`@("`@
M("`@("`@("!S=')S='(H)&9R;VTL("<F)RD@?'P*("`@("`@("`@("`@("`@
M("`@<W1R<W1R*"1F<F]M+"`G8"<I*2!["B`@("`@("`@("`@(')E='5R;B!N
M97<@4$5!4E]%<G)O<B@G1G)O;2!A9&1R97-S('-P96-I9FEE9"!W:71H(&1A
M;F=E<F]U<R!C:&%R86-T97)S+B<I.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("`D<F5S=6QT(#T@,#L*("`@("`@("!I9B`H0&ES7V5X96-U=&%B;&4H
M)'1H:7,M/G-E;F1M86EL7W!A=&@I*2!["B`@("`@("`@("`@("1F<F]M(#T@
M97-C87!E4VAE;&Q#;60H)&9R;VTI.PH@("`@("`@("`@("`D;6%I;"`]('!O
M<&5N*"1T:&ES+3YS96YD;6%I;%]P871H("X@*"%E;7!T>2@D=&AI<RT^<V5N
M9&UA:6Q?87)G<RD@/R`G("<@+B`D=&AI<RT^<V5N9&UA:6Q?87)G<R`Z("<G
M*2`N("(@+68D9G)O;2`M+2`D<F5C:7!I96YT<R(L("=W)RD["B`@("`@("`@
M("`@(&9P=71S*"1M86EL+"`D=&5X=%]H96%D97)S*3L*("`@("`@("`@("`@
M9G!U=',H)&UA:6PL("1T:&ES+3YS97`I.R`@+R\@;F5W;&EN92!T;R!E;F0@
M=&AE(&AE861E<G,@<V5C=&EO;@H@("`@("`@("`@("!F<'5T<R@D;6%I;"P@
M)&)O9'DI.PH@("`@("`@("`@("`D<F5S=6QT(#T@<&-L;W-E*"1M86EL*2`^
M/B`X("8@,'A&1CL@+R\@;F5E9"!T;R!S:&EF="!T:&4@<&-L;W-E(')E<W5L
M="!T;R!G970@=&AE(&5X:70@8V]D90H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!N97<@4$5!4E]%<G)O<B@G<V5N9&UA:6P@6R<@+B`D
M=&AI<RT^<V5N9&UA:6Q?<&%T:"`N("==(&YO="!E>&5C=71A8FQE)RD["B`@
M("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D<F5S=6QT("$](#`I('L*
M("`@("`@("`@("`@<F5T=7)N(&YE=R!014%27T5R<F]R*"=S96YD;6%I;"!R
M971U<FYE9"!E<G)O<B!C;V1E("<@+B`D<F5S=6QT*3L*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`*?0H_/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O36%I;"]M:6UE+G!H<```````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-38R-S<`,3`T,3<S-C,P,#<`,#$W-S`T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O
M<'ER:6=H="`H8RD@,C`P,B`@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($%L;"!R:6=H=',@<F5S
M97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B
M:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\#0HO+R!\(&UO9&EF
M:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL
M;W=I;F<@8V]N9&ET:6]N<R`@("!\#0HO+R!\(&%R92!M970Z("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO
M+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T
M86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\#0HO+R!\("`@;F]T:6-E
M+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D
M:7-C;&%I;65R+B`@("`@("!\#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN
M(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG
M:'0@("!\#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N
M<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\#0HO+R!\
M("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I
M9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\#0HO+R!\(&\@5&AE(&YA;65S
M(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R
M('!R;VUO=&4@("`@("!\#0HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M
M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N
M("!\#0HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(%1(25,@4T]&5%=!4D4@
M25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY4
M4DE"551/4E,@("!\#0HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2
M($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\
M#0HO+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@
M34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\#0HO+R!\($$@4$%2
M5$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!3
M2$%,3"!42$4@0T]065))1TA4("!\#0HO+R!\($]73D52($]2($-/3E1224)5
M5$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)
M1$5.5$%,+"!\#0HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].4T51
M545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\#0HO
M+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/
M1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!\#0HO+R!\($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!\#0HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL
M(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/
M4E0@("!\#0HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)
M4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\#0HO+R!\
M($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]3
M4TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\#0HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK#0HO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G
M=7)U+F]R9SX@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@
M("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/B`H<&]R="!T
M;R!014%2*2`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!M:6UE+G!H<"QV(#$N,C,@,C`P
M,B\P-R\R-R`Q-#HS-SHU,R!R:6-H87)D($5X<"`D#0H-"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PT*<F5Q=6ER95]O;F-E("=-86EL+VUI;65087)T+G!H
M<"<[#0H-"B\J*@T**B!-:6UE(&UA:6P@8V]M<&]S97(@8VQA<W,N($-A;B!H
M86YD;&4Z('1E>'0@86YD(&AT;6P@8F]D:65S+"!E;6)E9&1E9"!H=&UL#0HJ
M(&EM86=E<R!A;F0@871T86-H;65N=',N#0HJ($1O8W5M96YT871I;VX@86YD
M(&5X86UP;&5S(&]F('1H:7,@8VQA<W,@87)E(&%V86EB;&4@:&5R93H-"BH@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO#0HJ#0HJ($!N;W1E<R!4:&ES
M(&-L87-S(&ES(&)A<V5D(&]N($A434P@36EM92!-86EL(&-L87-S(&9R;VT-
M"BH@("!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/B!W:&EC
M:"!W87,@8F%S960@86QS;PT**B`@(&EN('1H92!M:6UE7VUA:6PN8VQA<W,@
M8GD@5&]B:6%S(%)A='-C:&EL;&5R(#QT;V)I87-`9&YE="YI=#X@86YD#0HJ
M("`@4V%S8VAA(%-C:'5M86YN(#QS87-C:&%`<V-H=6UA;FXN8W@^+@T**@T*
M*B!`875T:&]R(%)I8VAA<F0@2&5Y97,@/')I8VAA<F0N:&5Y97-`:&5Y97,M
M8V]M<'5T:6YG+FYE=#X-"BH@0&%U=&AO<B!4;VUA<R!6+E8N0V]X(#QC;WA`
M:61E8VYE="YC;VT^#0HJ($!P86-K86=E($UA:6P-"BH@0&%C8V5S<R!P=6)L
M:6,-"BHO#0IC;&%S<R!-86EL7VUI;64-"GL-"B`@("`O*BH-"B`@("`J($-O
M;G1A:6YS('1H92!P;&%I;B!T97AT('!A<G0@;V8@=&AE(&5M86EL#0H@("`@
M*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1?='AT8F]D>3L-"B`@
M("`O*BH-"B`@("`J($-O;G1A:6YS('1H92!H=&UL('!A<G0@;V8@=&AE(&5M
M86EL#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1?:'1M
M;&)O9'D[#0H@("`@+RHJ#0H@("`@*B!C;VYT86EN<R!T:&4@;6EM92!E;F-O
M9&5D('1E>'0-"B`@("`J($!V87(@<W1R:6YG#0H@("`@*B\-"B`@("!V87(@
M)%]M:6UE.PT*("`@("\J*@T*("`@("H@8V]N=&%I;G,@=&AE(&UU;'1I<&%R
M="!C;VYT96YT#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R
M("1?;75L=&EP87)T.PT*("`@("\J*@T*("`@("H@;&ES="!O9B!T:&4@871T
M86-H960@:6UA9V5S#0H@("`@*B!`=F%R(&%R<F%Y#0H@("`@*B\-"B`@("!V
M87(@)%]H=&UL7VEM86=E<R`](&%R<F%Y*"D[#0H@("`@+RHJ#0H@("`@*B!L
M:7-T(&]F('1H92!A='1A8VAE;65N=',-"B`@("`J($!V87(@87)R87D-"B`@
M("`J+PT*("`@('9A<B`D7W!A<G1S(#T@87)R87DH*3L-"B`@("`O*BH-"B`@
M("`J($)U:6QD('!A<F%M971E<G,-"B`@("`J($!V87(@87)R87D-"B`@("`J
M+PT*("`@('9A<B`D7V)U:6QD7W!A<F%M<R`](&%R<F%Y*"D[#0H@("`@+RHJ
M#0H@("`@*B!(96%D97)S(&9O<B!T:&4@;6%I;`T*("`@("H@0'9A<B!A<G)A
M>0T*("`@("HO#0H@("`@=F%R("1?:&5A9&5R<R`](&%R<F%Y*"D[#0H-"@T*
M("`@("\J#0H@("`@*B!#;VYS=')U8W1O<B!F=6YC=&EO;@T*("`@("H-"B`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!-86EL
M7VUI;64H)&-R;&8@/2`B7')<;B(I#0H@("`@>PT*("`@("`@("!I9B`H(61E
M9FEN960H)TU!24Q?34E-15]#4DQ&)RDI('L-"B`@("`@("`@("`@(&1E9FEN
M92@G34%)3%]-24U%7T-23$8G+"`D8W)L9BP@=')U92D[#0H@("`@("`@('T-
M"@T*("`@("`@("`D=&AI<RT^7V)O=6YD87)Y(#T@)SU?)R`N(&UD-2AU;FEQ
M:60H=&EM92@I*2D[#0H-"B`@("`@("`@)'1H:7,M/E]B=6EL9%]P87)A;7,@
M/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=&5X=%]E;F-O9&EN9R<@/3X@)S=B:70G+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H=&UL7V5N8V]D:6YG)R`]/B`G<75O
M=&5D+7!R:6YT86)L92<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)S=B:71?=W)A<"<@("`@(#T^(#DY."P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:'1M;%]C:&%R<V5T)R`@/3X@
M)TE33RTX.#4Y+3$G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T97AT7V-H87)S970G("`]/B`G25-/+3@X-3DM,2<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE861?8VAA<G-E
M="<@(#T^("=)4T\M.#@U.2TQ)PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*3L-"B`@("!]#0H-"B`@("`O*@T*("`@("H@06-C97-S
M;W(@9G5N8W1I;VX@=&\@<V5T('1H92!B;V1Y('1E>'0N($)O9'D@=&5X="!I
M<R!U<V5D(&EF#0H@("`@*B!I="=S(&YO="!A;B!H=&UL(&UA:6P@8F5I;F<@
M<V5N="!O<B!E;'-E(&ES('5S960@=&\@9FEL;"!T:&4-"B`@("`J('1E>'0O
M<&QA:6X@<&%R="!T:&%T(&5M86EL<R!C;&EE;G1S('=H;R!D;VXG="!S=7!P
M;W)T#0H@("`@*B!H=&UL('-H;W5L9"!S:&]W+@T*("`@("H-"B`@("`J($!P
M87)A;2!S=')I;F<@)&1A=&$@16ET:&5R(&$@<W1R:6YG(&]R('1H92!F:6QE
M(&YA;64@=VET:"!T:&4-"B`@("`J("`@("`@("!C;VYT96YT<PT*("`@("H@
M0'!A<F%M(&)O;VP@)&ES9FEL92!)9B!T<G5E('1H92!F:7)S="!P87)A;2!S
M:&]U;&0@8F4@=')A=&5D#0H@("`@*B`@("`@("`@87,@82!F:6QE(&YA;64L
M(&5L<V4@87,@82!S=')I;F<@*&1E9F%U;'0I#0H@("`@*B!`<&%R86T@8F]O
M;"!)9B!T<G5E('1H92!T97AT(&]R(&9I;&4@:7,@87!P96YD960@=&\@=&AE
M#0H@("`@*B`@("`@("`@97AI<W1I;F<@8F]D>2P@96QS92!T:&4@;VQD(&)O
M9'D@:7,@;W9E<G=R:71T96X-"B`@("`J($!R971U<FX@;6EX960@=')U92!O
M;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;V)J96-T#0H@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@<V5T5%A40F]D>2@D9&%T
M82P@)&ES9FEL92`](&9A;'-E+"`D87!P96YD(#T@9F%L<V4I#0H@("`@>PT*
M("`@("`@("!I9B`H(21I<V9I;&4I('L-"B`@("`@("`@("`@(&EF("@A)&%P
M<&5N9"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?='AT8F]D>2`]("1D
M871A.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W1X=&)O9'D@+CT@)&1A=&$[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D8V]N="`]("1T:&ES+3Y?9FEL
M93)S='(H)&1A=&$I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&-O;G0I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1C;VYT.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$D87!P96YD*2![#0H@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?='AT8F]D>2`]("1C;VYT.PT*("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("1T:&ES+3Y?='AT
M8F]D>2`N/2`D8V]N=#L-"B`@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RH-"B`@("`J($%D
M9',@82!H=&UL('!A<G0@=&\@=&AE(&UA:6P-"B`@("`J#0H@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A($5I=&AE<B!A('-T<FEN9R!O<B!T:&4@9FEL92!N
M86UE('=I=&@@=&AE#0H@("`@*B`@("`@("`@8V]N=&5N=',-"B`@("`J($!P
M87)A;2!B;V]L("1I<V9I;&4@268@=')U92!T:&4@9FER<W0@<&%R86T@<VAO
M=6QD(&)E('1R871E9`T*("`@("H@("`@("`@(&%S(&$@9FEL92!N86UE+"!E
M;'-E(&%S(&$@<W1R:6YG("AD969A=6QT*0T*("`@("H@0')E='5R;B!M:7AE
M9"!T<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O8FIE8W0-"B`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S971(5$U,
M0F]D>2@D9&%T82P@)&ES9FEL92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M:68@*"$D:7-F:6QE*2![#0H@("`@("`@("`@("`D=&AI<RT^7VAT;6QB;V1Y
M(#T@)&1A=&$[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8V]N
M="`]("1T:&ES+3Y?9FEL93)S='(H)&1A=&$I.PT*("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-O;G0I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1C;VYT.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M
M/E]H=&UL8F]D>2`]("1C;VYT.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RH-"B`@("`J($%D9',@86X@:6UA
M9V4@=&\@=&AE(&QI<W0@;V8@96UB961D960@:6UA9V5S+@T*("`@("H-"B`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&4@5&AE(&EM86=E(&9I;&4@;F%M92!/
M4B!I;6%G92!D871A(&ET<V5L9@T*("`@("H@0'!A<F%M('-T<FEN9R`D8U]T
M>7!E(%1H92!C;VYT96YT('1Y<&4-"B`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@5&AE(&9I;&5N86UE(&]F('1H92!I;6%G92X@3VYL>2!U<V4@:68@)&9I
M;&4@:7,@=&AE(&EM86=E(&1A=&$-"B`@("`J($!P87)A;2!B;V]L("1I<V9I
M;&5N86UE(%=H971H97(@)&9I;&4@:7,@82!F:6QE;F%M92!O<B!N;W0N($1E
M9F%U;'1S('1O('1R=64-"B`@("`J($!R971U<FX@;6EX960@=')U92!O;B!S
M=6-C97-S(&]R(%!%05)?17)R;W(@;V)J96-T#0H@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@861D2%1-3$EM86=E*"1F:6QE
M+"`D8U]T>7!E/2=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+"`D;F%M92`]
M("<G+"`D:7-F:6QE;F%M92`]('1R=64I#0H@("`@>PT*("`@("`@("`D9FEL
M961A=&$@/2`H)&ES9FEL96YA;64@/3T]('1R=64I(#\@)'1H:7,M/E]F:6QE
M,G-T<B@D9FEL92D@.B`D9FEL93L-"B`@("`@("`@)&9I;&5N86UE(#T@*"1I
M<V9I;&5N86UE(#T]/2!T<G5E*2`_(&)A<V5N86UE*"1F:6QE*2`Z(&)A<V5N
M86UE*"1N86UE*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9I;&5D
M871A*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1F:6QE9&%T83L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7VAT;6Q?:6UA9V5S6UT@/2!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)O9'DG
M("`@/3X@)&9I;&5D871A+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;F%M92<@("`]/B`D9FEL96YA;64L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C7W1Y<&4G(#T^("1C7W1Y
M<&4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C
M:60G("`@(#T^(&UD-2AU;FEQ:60H=&EM92@I*2D-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O*@T*("`@("H@061D<R!A(&9I;&4@=&\@=&AE
M(&QI<W0@;V8@871T86-H;65N=',N#0H@("`@*@T*("`@("H@0'!A<F%M('-T
M<FEN9R`D9FEL92!4:&4@9FEL92!N86UE(&]F('1H92!F:6QE('1O(&%T=&%C
M:"!/4B!T:&4@9FEL92!D871A(&ET<V5L9@T*("`@("H@0'!A<F%M('-T<FEN
M9R`D8U]T>7!E(%1H92!C;VYT96YT('1Y<&4-"B`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@5&AE(&9I;&5N86UE(&]F('1H92!A='1A8VAM96YT+B!/;FQY
M('5S92!I9B`D9FEL92!I<R!T:&4@9FEL92!D871A#0H@("`@*B!`<&%R86T@
M8F]O;"`D:7-&:6QE;F%M92!7:&5T:&5R("1F:6QE(&ES(&$@9FEL96YA;64@
M;W(@;F]T+B!$969A=6QT<R!T;R!T<G5E#0H@("`@*B!`<F5T=7)N(&UI>&5D
M('1R=64@;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]B:F5C=`T*("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$%T=&%C
M:&UE;G0H)&9I;&4L("1C7W1Y<&4])V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A
M;2<L("1N86UE(#T@)R<L("1I<V9I;&5N86UE(#T@=')U92P@)&5N8V]D:6YG
M(#T@)V)A<V4V-"<I#0H@("`@>PT*("`@("`@("`D9FEL961A=&$@/2`H)&ES
M9FEL96YA;64@/3T]('1R=64I(#\@)'1H:7,M/E]F:6QE,G-T<B@D9FEL92D@
M.B`D9FEL93L-"B`@("`@("`@:68@*"1I<V9I;&5N86UE(#T]/2!T<G5E*2![
M#0H@("`@("`@("`@("`O+R!&;W)C92!T:&4@;F%M92!T:&4@=7-E<B!S=7!P
M;&EE9"P@;W1H97)W:7-E('5S92`D9FEL90T*("`@("`@("`@("`@)&9I;&5N
M86UE(#T@*"%E;7!T>2@D;F%M92DI(#\@)&YA;64@.B`D9FEL93L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1F:6QE;F%M92`]("1N86UE.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D9FEL96YA;64I*2![#0H@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G5&AE('-U<'!L
M:65D(&9I;&5N86UE(&9O<B!T:&4@871T86-H;65N="!C86Y<)W0@8F4@96UP
M='DG*3L-"B`@("`@("`@?0T*("`@("`@("`D9FEL96YA;64@/2!B87-E;F%M
M92@D9FEL96YA;64I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL
M961A=&$I*2![#0H@("`@("`@("`@("!R971U<FX@)&9I;&5D871A.PT*("`@
M("`@("!]#0H-"B`@("`@("`@)'1H:7,M/E]P87)T<UM=(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=B;V1Y)R`@("`@/3X@
M)&9I;&5D871A+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;F%M92<@("`@(#T^("1F:6QE;F%M92P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-?='EP92<@("`]/B`D8U]T>7!E+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G96YC;V1I;F<G(#T^("1E;F-O9&EN
M9PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J#0H@("`@*B!2971U<FYS
M('1H92!C;VYT96YT<R!O9B!T:&4@9VEV96X@9FEL92!N86UE(&%S('-T<FEN
M9PT*("`@("H@0'!A<F%M('-T<FEN9R`D9FEL95]N86UE#0H@("`@*B!`<F5T
M=7)N('-T<FEN9PT*("`@("H@0&%C8V5S('!R:79A=&4-"B`@("`J+PT*("`@
M(&9U;F-T:6]N("8@7V9I;&4R<W1R*"1F:6QE7VYA;64I#0H@("`@>PT*("`@
M("`@("!I9B`H(6ES7W)E861A8FQE*"1F:6QE7VYA;64I*2![#0H@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1FEL92!I<R!N;W0@<F5A
M9&%B;&4@)R`N("1F:6QE7VYA;64I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@A)&9D(#T@9F]P96XH)&9I;&5?;F%M92P@)W)B)RDI('L-"B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#;W5L9"!N;W0@;W!E;B`G
M("X@)&9I;&5?;F%M92D[#0H@("`@("`@('T-"B`@("`@("`@)&-O;G0@/2!F
M<F5A9"@D9F0L(&9I;&5S:7IE*"1F:6QE7VYA;64I*3L-"B`@("`@("`@9F-L
M;W-E*"1F9"D[#0H@("`@("`@(')E='5R;B`D8V]N=#L-"B`@("!]#0H-"B`@
M("`O*@T*("`@("H@061D<R!A('1E>'0@<W5B<&%R="!T;R!T:&4@;6EM95!A
M<G0@;V)J96-T(&%N9`T*("`@("H@<F5T=7)N<R!I="!D=7)I;F<@=&AE(&)U
M:6QD('!R;V-E<W,N#0H@("`@*@T*("`@("H@0'!A<F%M(&UI>&5D("`@(%1H
M92!O8FIE8W0@=&\@861D('1H92!P87)T('1O+"!O<@T*("`@("H@("`@("`@
M("`@("`@("`@(&YU;&P@:68@82!N97<@;V)J96-T(&ES('1O(&)E(&-R96%T
M960N#0H@("`@*B!`<&%R86T@<W1R:6YG("`@5&AE('1E>'0@=&\@861D+@T*
M("`@("H@0')E='5R;B!O8FIE8W0@(%1H92!T97AT(&UI;65087)T(&]B:F5C
M=`T*("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B`F7V%D9%1E>'1087)T*"8D;V)J+"`D=&5X="E[#0H-"B`@("`@("`@)'!A
M<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G=&5X="]P;&%I;B<[#0H@("`@("`@
M("1P87)A;7-;)V5N8V]D:6YG)UT@("`@(#T@)'1H:7,M/E]B=6EL9%]P87)A
M;7-;)W1E>'1?96YC;V1I;F<G73L-"B`@("`@("`@)'!A<F%M<ULG8VAA<G-E
M="==("`@("`@/2`D=&AI<RT^7V)U:6QD7W!A<F%M<ULG=&5X=%]C:&%R<V5T
M)UT[#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&]B:BDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D;V)J+3YA9&13=6)P87)T*"1T97AT+"`D<&%R86US*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!N97<@36%I
M;%]M:6UE4&%R="@D=&5X="P@)'!A<F%M<RD[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("`O*@T*("`@("H@061D<R!A(&AT;6P@<W5B<&%R="!T;R!T:&4@
M;6EM95!A<G0@;V)J96-T(&%N9`T*("`@("H@<F5T=7)N<R!I="!D=7)I;F<@
M=&AE(&)U:6QD('!R;V-E<W,N#0H@("`@*@T*("`@("H@0'!A<F%M(&UI>&5D
M("`@(%1H92!O8FIE8W0@=&\@861D('1H92!P87)T('1O+"!O<@T*("`@("H@
M("`@("`@("`@("`@("`@(&YU;&P@:68@82!N97<@;V)J96-T(&ES('1O(&)E
M(&-R96%T960N#0H@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&AT;6P@;6EM
M95!A<G0@;V)J96-T#0H@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`J+PT*
M("`@(&9U;F-T:6]N("9?861D2'1M;%!A<G0H)B1O8FHI>PT*#0H@("`@("`@
M("1P87)A;7-;)V-O;G1E;G1?='EP92==(#T@)W1E>'0O:'1M;"<[#0H@("`@
M("`@("1P87)A;7-;)V5N8V]D:6YG)UT@("`@(#T@)'1H:7,M/E]B=6EL9%]P
M87)A;7-;)VAT;6Q?96YC;V1I;F<G73L-"B`@("`@("`@)'!A<F%M<ULG8VAA
M<G-E="==("`@("`@/2`D=&AI<RT^7V)U:6QD7W!A<F%M<ULG:'1M;%]C:&%R
M<V5T)UT[#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&]B:BDI('L-"B`@("`@
M("`@("`@(')E='5R;B`D;V)J+3YA9&13=6)P87)T*"1T:&ES+3Y?:'1M;&)O
M9'DL("1P87)A;7,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M<F5T=7)N(&YE=R!-86EL7VUI;65087)T*"1T:&ES+3Y?:'1M;&)O9'DL("1P
M87)A;7,I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RH-"B`@("`J($-R
M96%T97,@82!N97<@;6EM95!A<G0@;V)J96-T+"!U<VEN9R!M=6QT:7!A<G0O
M;6EX960@87,-"B`@("`J('1H92!I;FET:6%L(&-O;G1E;G0M='EP92!A;F0@
M<F5T=7)N<R!I="!D=7)I;F<@=&AE#0H@("`@*B!B=6EL9"!P<F]C97-S+@T*
M("`@("H-"B`@("`J($!R971U<FX@;V)J96-T("!4:&4@;75L=&EP87)T+VUI
M>&5D(&UI;65087)T(&]B:F5C=`T*("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B`F7V%D9$UI>&5D4&%R="@I>PT*#0H@("`@
M("`@("1P87)A;7-;)V-O;G1E;G1?='EP92==(#T@)VUU;'1I<&%R="]M:7AE
M9"<[#0H@("`@("`@(')E='5R;B!N97<@36%I;%]M:6UE4&%R="@G)RP@)'!A
M<F%M<RD[#0H@("`@?0T*#0H@("`@+RH-"B`@("`J($%D9',@82!M=6QT:7!A
M<G0O86QT97)N871I=F4@<&%R="!T;R!A(&UI;65087)T#0H@("`@*B!O8FIE
M8W0L("AO<B!C<F5A=&5S(&]N92DL(&%N9"!R971U<FYS(&ET("!D=7)I;F<-
M"B`@("`J('1H92!B=6EL9"!P<F]C97-S+@T*("`@("H-"B`@("`J($!P87)A
M;2!M:7AE9"`@("!4:&4@;V)J96-T('1O(&%D9"!T:&4@<&%R="!T;RP@;W(-
M"B`@("`J("`@("`@("`@("`@("`@("!N=6QL(&EF(&$@;F5W(&]B:F5C="!I
M<R!T;R!B92!C<F5A=&5D+@T*("`@("H@0')E='5R;B!O8FIE8W0@(%1H92!M
M=6QT:7!A<G0O;6EX960@;6EM95!A<G0@;V)J96-T#0H@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`J+PT*("`@(&9U;F-T:6]N("9?861D06QT97)N871I
M=F5087)T*"8D;V)J*7L-"@T*("`@("`@("`D<&%R86US6R=C;VYT96YT7W1Y
M<&4G72`]("=M=6QT:7!A<G0O86QT97)N871I=F4G.PT*("`@("`@("!I9B`H
M:7-?;V)J96-T*"1O8FHI*2![#0H@("`@("`@("`@("!R971U<FX@)&]B:BT^
M861D4W5B<&%R="@G)RP@)'!A<F%M<RD[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("!R971U<FX@;F5W($UA:6Q?;6EM95!A<G0H)R<L("1P87)A
M;7,I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RH-"B`@("`J($%D9',@
M82!M=6QT:7!A<G0O<F5L871E9"!P87)T('1O(&$@;6EM95!A<G0-"B`@("`J
M(&]B:F5C="P@*&]R(&-R96%T97,@;VYE*2P@86YD(')E='5R;G,@:70@(&1U
M<FEN9PT*("`@("H@=&AE(&)U:6QD('!R;V-E<W,N#0H@("`@*@T*("`@("H@
M0'!A<F%M(&UI>&5D("`@(%1H92!O8FIE8W0@=&\@861D('1H92!P87)T('1O
M+"!O<@T*("`@("H@("`@("`@("`@("`@("`@(&YU;&P@:68@82!N97<@;V)J
M96-T(&ES('1O(&)E(&-R96%T960N#0H@("`@*B!`<F5T=7)N(&]B:F5C="`@
M5&AE(&UU;'1I<&%R="]M:7AE9"!M:6UE4&%R="!O8FIE8W0-"B`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("HO#0H@("`@9G5N8W1I;VX@)E]A9&1296QA
M=&5D4&%R="@F)&]B:BE[#0H-"B`@("`@("`@)'!A<F%M<ULG8V]N=&5N=%]T
M>7!E)UT@/2`G;75L=&EP87)T+W)E;&%T960G.PT*("`@("`@("!I9B`H:7-?
M;V)J96-T*"1O8FHI*2![#0H@("`@("`@("`@("!R971U<FX@)&]B:BT^861D
M4W5B<&%R="@G)RP@)'!A<F%M<RD[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("!R971U<FX@;F5W($UA:6Q?;6EM95!A<G0H)R<L("1P87)A;7,I
M.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RH-"B`@("`J($%D9',@86X@
M:'1M;"!I;6%G92!S=6)P87)T('1O(&$@;6EM95!A<G0@;V)J96-T#0H@("`@
M*B!A;F0@<F5T=7)N<R!I="!D=7)I;F<@=&AE(&)U:6QD('!R;V-E<W,N#0H@
M("`@*@T*("`@("H@0'!A<F%M("!O8FIE8W0@(%1H92!M:6UE4&%R="!T;R!A
M9&0@=&AE(&EM86=E('1O#0H@("`@*B!`<&%R86T@(&%R<F%Y("`@5&AE(&EM
M86=E(&EN9F]R;6%T:6]N#0H@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&EM
M86=E(&UI;65087)T(&]B:F5C=`T*("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B`F7V%D9$AT;6Q);6%G95!A<G0H)B1O8FHL
M("1V86QU92E[#0H-"B`@("`@("`@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@
M/2`D=F%L=65;)V-?='EP92==.PT*("`@("`@("`D<&%R86US6R=E;F-O9&EN
M9R==("`@("`]("=B87-E-C0G.PT*("`@("`@("`D<&%R86US6R=D:7-P;W-I
M=&EO;B==("`]("=I;FQI;F4G.PT*("`@("`@("`D<&%R86US6R=D9FEL96YA
M;64G72`@("`]("1V86QU95LG;F%M92==.PT*("`@("`@("`D<&%R86US6R=C
M:60G72`@("`@("`@("`]("1V86QU95LG8VED)UT[#0H@("`@("`@("1O8FHM
M/F%D9%-U8G!A<G0H)'9A;'5E6R=B;V1Y)UTL("1P87)A;7,I.PT*("`@('T-
M"@T*("`@("\J#0H@("`@*B!!9&1S(&%N(&%T=&%C:&UE;G0@<W5B<&%R="!T
M;R!A(&UI;65087)T(&]B:F5C=`T*("`@("H@86YD(')E='5R;G,@:70@9'5R
M:6YG('1H92!B=6EL9"!P<F]C97-S+@T*("`@("H-"B`@("`J($!P87)A;2`@
M;V)J96-T("!4:&4@;6EM95!A<G0@=&\@861D('1H92!I;6%G92!T;PT*("`@
M("H@0'!A<F%M("!A<G)A>2`@(%1H92!A='1A8VAM96YT(&EN9F]R;6%T:6]N
M#0H@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&EM86=E(&UI;65087)T(&]B
M:F5C=`T*("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@*B\-"B`@("!F=6YC
M=&EO;B`F7V%D9$%T=&%C:&UE;G1087)T*"8D;V)J+"`D=F%L=64I>PT*#0H@
M("`@("`@("1P87)A;7-;)V-O;G1E;G1?='EP92==(#T@)'9A;'5E6R=C7W1Y
M<&4G73L-"B`@("`@("`@)'!A<F%M<ULG96YC;V1I;F<G72`@("`@/2`D=F%L
M=65;)V5N8V]D:6YG)UT[#0H@("`@("`@("1P87)A;7-;)V1I<W!O<VET:6]N
M)UT@(#T@)V%T=&%C:&UE;G0G.PT*("`@("`@("`D<&%R86US6R=D9FEL96YA
M;64G72`@("`]("1V86QU95LG;F%M92==.PT*("`@("`@("`D;V)J+3YA9&13
M=6)P87)T*"1V86QU95LG8F]D>2==+"`D<&%R86US*3L-"B`@("!]#0H-"B`@
M("`O*@T*("`@("H@0G5I;&1S('1H92!M=6QT:7!A<G0@;65S<V%G92!F<F]M
M('1H92!L:7-T("@D=&AI<RT^7W!A<G1S*2!A;F0-"B`@("`J(')E='5R;G,@
M=&AE(&UI;64@8V]N=&5N="X-"B`@("`J#0H@("`@*B!`<&%R86T@(&%R<F%Y
M("!"=6EL9"!P87)A;65T97)S('1H870@8VAA;F=E('1H92!W87D@=&AE(&5M
M86EL#0H@("`@*B`@("`@("`@("`@("`@("!I<R!B=6EL="X@4VAO=6QD(&)E
M(&%S<V]C:6%T:79E+B!#86X@8V]N=&%I;CH-"B`@("`J("`@("`@("`@("`@
M("`@('1E>'1?96YC;V1I;F<@("T@(%=H870@96YC;V1I;F<@=&\@=7-E(&9O
M<B!P;&%I;B!T97AT#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!$969A=6QT(&ES(#=B:70-"B`@("`J("`@("`@("`@("`@("`@
M(&AT;6Q?96YC;V1I;F<@("T@(%=H870@96YC;V1I;F<@=&\@=7-E(&9O<B!H
M=&UL#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$
M969A=6QT(&ES('%U;W1E9"UP<FEN=&%B;&4-"B`@("`J("`@("`@("`@("`@
M("`@(#=B:71?=W)A<"`@("`@("T@($YU;6)E<B!O9B!C:&%R86-T97)S(&)E
M9F]R92!T97AT(&ES#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!W<F%P<&5D(&EN(#=B:70@96YC;V1I;F<-"B`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'0@:7,@.3DX#0H@
M("`@*B`@("`@("`@("`@("`@("!H=&UL7V-H87)S970@("`M("!4:&4@8VAA
M<F%C=&5R('-E="!T;R!U<V4@9F]R(&AT;6PN#0H@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT(&ES(&ES;RTX.#4Y+3$-
M"B`@("`J("`@("`@("`@("`@("`@('1E>'1?8VAA<G-E="`@("T@(%1H92!C
M:&%R86-T97(@<V5T('1O('5S92!F;W(@=&5X="X-"B`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'0@:7,@:7-O+3@X-3DM
M,0T*("`@("H@("`@("`@("`@("`@("`@:&5A9%]C:&%R<V5T("`@+2`@5&AE
M(&-H87)A8W1E<B!S970@=&\@=7-E(&9O<B!H96%D97)S+@T*("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L="!I<R!I<V\M
M.#@U.2TQ#0H@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@;6EM92!C;VYT96YT
M#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@
M)F=E="@D8G5I;&1?<&%R86US(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D8G5I;&1?<&%R86US*2D@>PT*("`@("`@("`@("`@=VAI;&4@
M*&QI<W0H)&ME>2P@)'9A;'5E*2`](&5A8V@H)&)U:6QD7W!A<F%M<RDI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V)U:6QD7W!A<F%M<ULD:V5Y72`]
M("1V86QU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]H=&UL7VEM86=E<RD@04Y$(&ES<V5T*"1T
M:&ES+3Y?:'1M;&)O9'DI*2![#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7VAT;6Q?:6UA9V5S(&%S("1V86QU92D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:'1M;&)O9'D@/2!S=')?<F5P;&%C92@D=F%L=65;)VYA;64G
M72P@)V-I9#HG+B1V86QU95LG8VED)UTL("1T:&ES+3Y?:'1M;&)O9'DI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@)&YU;&P@("`@
M("`@(#T@;G5L;#L-"B`@("`@("`@)&%T=&%C:&UE;G1S(#T@(65M<'1Y*"1T
M:&ES+3Y?<&%R=',I("`@("`@("`@("`@("`@(#\@5%)512`Z($9!3%-%.PT*
M("`@("`@("`D:'1M;%]I;6%G97,@/2`A96UP='DH)'1H:7,M/E]H=&UL7VEM
M86=E<RD@("`@("`@("`@/R!44E5%(#H@1D%,4T4[#0H@("`@("`@("1H=&UL
M("`@("`@("`]("%E;7!T>2@D=&AI<RT^7VAT;6QB;V1Y*2`@("`@("`@("`@
M("`_(%12544@.B!&04Q313L-"B`@("`@("`@)'1E>'0@("`@("`@(#T@*"$D
M:'1M;"!!3D0@(65M<'1Y*"1T:&ES+3Y?='AT8F]D>2DI(#\@5%)512`Z($9!
M3%-%.PT*#0H@("`@("`@('-W:71C:"`H5%)512D@>PT*("`@("`@("`@("`@
M8V%S92`D=&5X="!!3D0@(21A='1A8VAM96YT<SH-"B`@("`@("`@("`@("`@
M("`D;65S<V%G92`])B`D=&AI<RT^7V%D9%1E>'1087)T*"1N=6QL+"`D=&AI
M<RT^7W1X=&)O9'DI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@
M("`@("`@("!C87-E("$D=&5X="!!3D0@(21H=&UL($%.1"`D871T86-H;65N
M=',Z#0H@("`@("`@("`@("`@("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&1-
M:7AE9%!A<G0H*3L-"@T*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\(&-O=6YT*"1T:&ES+3Y?<&%R=',I.R`D:2LK*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?861D071T86-H;65N=%!A<G0H)&UE<W-A9V4L
M("1T:&ES+3Y?<&%R='-;)&E=*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@)'1E>'0@
M04Y$("1A='1A8VAM96YT<SH-"B`@("`@("`@("`@("`@("`D;65S<V%G92`]
M)B`D=&AI<RT^7V%D9$UI>&5D4&%R="@I.PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?861D5&5X=%!A<G0H)&UE<W-A9V4L("1T:&ES+3Y?='AT8F]D>2D[
M#0H-"B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D
M=&AI<RT^7W!A<G1S*3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%D9$%T=&%C:&UE;G1087)T*"1M97-S86=E+"`D=&AI<RT^7W!A
M<G1S6R1I72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E("1H=&UL($%.1"`A)&%T=&%C
M:&UE;G1S($%.1"`A)&AT;6Q?:6UA9V5S.@T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W1X=&)O9'DI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1M97-S86=E(#TF("1T:&ES+3Y?861D06QT97)N871I=F5087)T*"1N
M=6QL*3L-"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1497AT
M4&%R="@D;65S<V%G92P@)'1H:7,M/E]T>'1B;V1Y*3L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A9&1(=&UL4&%R="@D;65S<V%G92D[#0H-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M;65S<V%G92`])B`D=&AI<RT^7V%D9$AT;6Q087)T*"1N=6QL*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@
M("`@("`@(&-A<V4@)&AT;6P@04Y$("$D871T86-H;65N=',@04Y$("1H=&UL
M7VEM86=E<SH-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T
M>'1B;V1Y*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`])B`D
M=&AI<RT^7V%D9$%L=&5R;F%T:79E4&%R="@D;G5L;"D[#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?861D5&5X=%!A<G0H)&UE<W-A9V4L("1T:&ES
M+3Y?='AT8F]D>2D[#0H@("`@("`@("`@("`@("`@("`@("1R96QA=&5D(#TF
M("1T:&ES+3Y?861D4F5L871E9%!A<G0H)&UE<W-A9V4I.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1M97-S86=E
M(#TF("1T:&ES+3Y?861D4F5L871E9%!A<G0H)&YU;&PI.PT*("`@("`@("`@
M("`@("`@("`@("`D<F5L871E9"`])B`D;65S<V%G93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1(=&UL4&%R="@D
M<F5L871E9"D[#0H@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)'1H:7,M/E]H=&UL7VEM86=E<RD[("1I*RLI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1(=&UL26UA9V5087)T*"1R96QA=&5D
M+"`D=&AI<RT^7VAT;6Q?:6UA9V5S6R1I72D[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E
M("1H=&UL($%.1"`D871T86-H;65N=',@04Y$("$D:'1M;%]I;6%G97,Z#0H@
M("`@("`@("`@("`@("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&1-:7AE9%!A
M<G0H*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T>'1B
M;V1Y*2D@>PT*("`@("`@("`@("`@("`@("`@("`D86QT(#TF("1T:&ES+3Y?
M861D06QT97)N871I=F5087)T*"1M97-S86=E*3L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9&1497AT4&%R="@D86QT+"`D=&AI<RT^7W1X=&)O
M9'DI.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$AT;6Q087)T
M*"1A;'0I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?861D2'1M;%!A<G0H)&UE<W-A9V4I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D=&AI<RT^7W!A<G1S*3L@)&DK*RD@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%D9$%T=&%C:&UE;G1087)T*"1M97-S86=E
M+"`D=&AI<RT^7W!A<G1S6R1I72D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E("1H=&UL
M($%.1"`D871T86-H;65N=',@04Y$("1H=&UL7VEM86=E<SH-"B`@("`@("`@
M("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^7V%D9$UI>&5D4&%R="@I.PT*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1X=&)O9'DI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1A;'0@/28@)'1H:7,M/E]A9&1!;'1E
M<FYA=&EV95!A<G0H)&UE<W-A9V4I.PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%D9%1E>'1087)T*"1A;'0L("1T:&ES+3Y?='AT8F]D>2D[#0H@
M("`@("`@("`@("`@("`@("`@("1R96P@/28@)'1H:7,M/E]A9&1296QA=&5D
M4&%R="@D86QT*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D<F5L(#TF("1T:&ES+3Y?861D4F5L871E9%!A<G0H
M)&UE<W-A9V4I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9$AT;6Q087)T*"1R96PI.PT*("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?:'1M;%]I;6%G97,I
M.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D2'1M
M;$EM86=E4&%R="@D<F5L+"`D=&AI<RT^7VAT;6Q?:6UA9V5S6R1I72D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(&-O=6YT*"1T:&ES+3Y?<&%R=',I.R`D:2LK*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?861D071T86-H;65N=%!A<G0H)&UE<W-A
M9V4L("1T:&ES+3Y?<&%R='-;)&E=*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@?0T*#0H@("`@("`@
M(&EF("AI<W-E="@D;65S<V%G92DI('L-"B`@("`@("`@("`@("1O=71P=70@
M/2`D;65S<V%G92T^96YC;V1E*"D[#0H@("`@("`@("`@("`D=&AI<RT^7VAE
M861E<G,@/2!A<G)A>5]M97)G92@D=&AI<RT^7VAE861E<G,L("1O=71P=71;
M)VAE861E<G,G72D[#0H-"B`@("`@("`@("`@(')E='5R;B`D;W5T<'5T6R=B
M;V1Y)UT[#0H-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R
M;B!&04Q313L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J#0H@("`@*B!2
M971U<FYS(&%N(&%R<F%Y('=I=&@@=&AE(&AE861E<G,@;F5E9&5D('1O('!R
M97!E;F0@=&\@=&AE(&5M86EL#0H@("`@*B`H34E-12U697)S:6]N(&%N9"!#
M;VYT96YT+51Y<&4I+B!&;W)M870@;V8@87)G=6UE;G0@:7,Z#0H@("`@*B`D
M87)R87E;)VAE861E<BUN86UE)UT@/2`G:&5A9&5R+79A;'5E)SL-"B`@("`J
M#0H@("`@*B!`<&%R86T@(&%R<F%Y("1X=')A7VAE861E<G,@07-S;V,@87)R
M87D@=VET:"!A;GD@97AT<F$@:&5A9&5R<RX@3W!T:6]N86PN#0H@("`@*B!`
M<F5T=7)N(&%R<F%Y($%S<V]C(&%R<F%Y('=I=&@@=&AE(&UI;64@:&5A9&5R
M<PT*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N
M("9H96%D97)S*"1X=')A7VAE861E<G,@/2!N=6QL*0T*("`@('L-"B`@("`@
M("`@+R\@0V]N=&5N="U4>7!E(&AE861E<B!S:&]U;&0@86QR96%D>2!B92!P
M<F5S96YT+`T*("`@("`@("`O+R!3;R!J=7-T(&%D9"!M:6UE('9E<G-I;VX@
M:&5A9&5R#0H@("`@("`@("1H96%D97)S6R=-24U%+59E<G-I;VXG72`]("<Q
M+C`G.PT*("`@("`@("!I9B`H:7-S970H)'AT<F%?:&5A9&5R<RDI('L-"B`@
M("`@("`@("`@("1H96%D97)S(#T@87)R87E?;65R9V4H)&AE861E<G,L("1X
M=')A7VAE861E<G,I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?:&5A
M9&5R<R`](&%R<F%Y7VUE<F=E*"1H96%D97)S+"`D=&AI<RT^7VAE861E<G,I
M.PT*#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V5N8V]D94AE861E<G,H)'1H
M:7,M/E]H96%D97)S*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J($=E="!T
M:&4@=&5X="!V97)S:6]N(&]F('1H92!H96%D97)S#0H@("`@*B`H=7-E9G5L
M;"!I9B!Y;W4@=V%N="!T;R!U<V4@=&AE(%!(4"!M86EL*"D@9G5N8W1I;VXI
M#0H@("`@*@T*("`@("H@0'!A<F%M("!A<G)A>2`D>'1R85]H96%D97)S($%S
M<V]C(&%R<F%Y('=I=&@@86YY(&5X=')A(&AE861E<G,N($]P=&EO;F%L+@T*
M("`@("H@0')E='5R;B!S=')I;F<@4&QA:6X@=&5X="!H96%D97)S#0H@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@='AT2&5A
M9&5R<R@D>'1R85]H96%D97)S(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1H
M96%D97)S(#T@)'1H:7,M/FAE861E<G,H)'AT<F%?:&5A9&5R<RD[#0H@("`@
M("`@("1R970@/2`G)SL-"B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@
M)&ME>2`]/B`D=F%L*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:V5Y.B`D
M=F%L(B`N($U!24Q?34E-15]#4DQ&.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@4V5T<R!T:&4@
M4W5B:F5C="!H96%D97(-"B`@("`J(`T*("`@("H@0'!A<F%M("!S=')I;F<@
M)'-U8FIE8W0@4W1R:6YG('1O('-E="!T:&4@<W5B:F5C="!T;PT*("`@("H@
M86-C97-S("!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=%-U8FIE
M8W0H)'-U8FIE8W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VAE861E<G-;
M)U-U8FIE8W0G72`]("1S=6)J96-T.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("H@4V5T(&%N(&5M86EL('1O('1H92!&<F]M("AT:&4@<V5N9&5R*2!H96%D
M97(-"B`@("`J#0H@("`@*B!`<&%R86T@<W1R:6YG("1E;6%I;"!4:&4@96UA
M:6P@9&ER96-T:6]N('1O(&%D9`T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`J+PT*("`@(&9U;F-T:6]N('-E=$9R;VTH)&5M86EL*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]H96%D97)S6R=&<F]M)UT@/2`D96UA:6P[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@*B!!9&0@86X@96UA:6P@=&\@=&AE($-C("AC
M87)B;VX@8V]P>2D@:&5A9&5R#0H@("`@*B`H;75L=&EP;&4@8V%L;',@=&\@
M=&AI<R!M971H;V0@:7,@86QL;W=E9"D-"B`@("`J#0H@("`@*B!`<&%R86T@
M<W1R:6YG("1E;6%I;"!4:&4@96UA:6P@9&ER96-T:6]N('1O(&%D9`T*("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$-C
M*"1E;6%I;"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE
M861E<G-;)T-C)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;
M)T-C)UT@+CT@(BP@)&5M86EL(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?:&5A9&5R<ULG0V,G72`]("1E;6%I;#L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("H@061D(&%N(&5M86EL('1O
M('1H92!"8V,@*&)L86YK(&-A<F)O;B!C;W!Y*2!H96%D97(-"B`@("`J("AM
M=6QT:7!L92!C86QL<R!T;R!T:&ES(&UE=&AO9"!I<R!A;&QO=V5D*0T*("`@
M("H-"B`@("`J($!P87)A;2!S=')I;F<@)&5M86EL(%1H92!E;6%I;"!D:7)E
M8W1I;VX@=&\@861D#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@861D0F-C*"1E;6%I;"D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7VAE861E<G-;)T)C8R==*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]H96%D97)S6R="8V,G72`N/2`B+"`D96UA:6PB.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R="
M8V,G72`]("1E;6%I;#L-"B`@("`@("`@?0T*("`@('T-"B`@("`-"B`@("`O
M*BH-"B`@("`J($5N8V]D97,@82!H96%D97(@87,@<&5R(%)&0S(P-#<-"B`@
M("`J#0H@("`@*B!`<&%R86T@('-T<FEN9R`@)&EN<'5T(%1H92!H96%D97(@
M9&%T82!T;R!E;F-O9&4-"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@("`@
M16YC;V1E9"!D871A#0H@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(%]E;F-O9&5(96%D97)S*"1I;G!U="D-"B`@("![#0H@
M("`@("`@(&9O<F5A8V@@*"1I;G!U="!A<R`D:&1R7VYA;64@/3X@)&AD<E]V
M86QU92D@>PT*("`@("`@("`@("`@<')E9U]M871C:%]A;&PH)R\H7'<J6UQX
M.#`M7'A&1ETK7'<J*2\G+"`D:&1R7W9A;'5E+"`D;6%T8VAE<RD[#0H@("`@
M("`@("`@("!F;W)E86-H("@D;6%T8VAE<ULQ72!A<R`D=F%L=64I('L-"B`@
M("`@("`@("`@("`@("`D<F5P;&%C96UE;G0@/2!P<F5G7W)E<&QA8V4H)R\H
M6UQX.#`M7'A&1ETI+V4G+"`G(CTB("X@<W1R=&]U<'!E<BAD96-H97@H;W)D
M*")<,2(I*2DG+"`D=F%L=64I.PT*("`@("`@("`@("`@("`@("1H9')?=F%L
M=64@/2!S=')?<F5P;&%C92@D=F%L=64L("<]/R<@+B`D=&AI<RT^7V)U:6QD
M7W!A<F%M<ULG:&5A9%]C:&%R<V5T)UT@+B`G/U$_)R`N("1R97!L86-E;65N
M="`N("<_/2<L("1H9')?=F%L=64I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)&EN<'5T6R1H9')?;F%M95T@/2`D:&1R7W9A;'5E.PT*("`@("`@
M("!]#0H@("`@("`@(`T*("`@("`@("!R971U<FX@)&EN<'5T.PT*("`@('T-
M"@T*?2`O+R!%;F0@;V8@8VQA<W,-"C\^#0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O36%I;"]S;71P+G!H<```````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34Q-S<`,3`T,3<S-C,P,#<`
M,#$W-S,R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@
M5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!0
M2%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@
M=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@
M("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"`@("`@("`@("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PH*<F5Q=6ER95]O;F-E("=-86EL+G!H<"<["@HO*BH*
M("H@4TU44"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@4$5!4B!-86EL.CH@:6YT
M97)F86-E+B!297%U:7)E<R!T:&4@4$5!4@H@*B!.971?4TU44#HZ(&-L87-S
M+@H@*B!`86-C97-S('!U8FQI8PH@*B!`<&%C:V%G92!-86EL"B`J($!V97)S
M:6]N("12979I<VEO;CH@,2XQ,B`D"B`J+PIC;&%S<R!-86EL7W-M='`@97AT
M96YD<R!-86EL('L*"B`@("`O*BH*("`@("`J(%1H92!33510(&AO<W0@=&\@
M8V]N;F5C="!T;RX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D:&]S="`]("=L;V-A;&AO<W0G.PH*("`@("\J*@H@("`@("H@5&AE('!O
M<G0@=&AE(%--5%`@<V5R=F5R(&ES(&]N+@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D<&]R="`](#(U.PH*("`@("\J*@H@("`@("H@
M4VAO=6QD(%--5%`@875T:&5N=&EC871I;VX@8F4@=7-E9#\*("`@("`J"B`@
M("`@*B!4:&ES('9A;'5E(&UA>2!B92!S970@=&\@=')U92P@9F%L<V4@;W(@
M=&AE(&YA;64@;V8@82!S<&5C:69I8PH@("`@("H@875T:&5N=&EC871I;VX@
M;65T:&]D+@H@("`@("H*("`@("`J($EF('1H92!V86QU92!I<R!S970@=&\@
M=')U92P@=&AE($YE=%]33510('!A8VMA9V4@=VEL;"!A='1E;7!T('1O('5S
M90H@("`@("H@=&AE(&)E<W0@875T:&5N=&EC871I;VX@;65T:&]D(&%D=F5R
M=&ES960@8GD@=&AE(')E;6]T92!33510('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`=F%R(&UI>&5D"B`@("`@*B\*("`@('9A<B`D875T:"`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@5&AE('5S97)N86UE('1O('5S92!I9B!T:&4@4TU4
M4"!S97)V97(@<F5Q=6ER97,@875T:&5N=&EC871I;VXN"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'5S97)N86UE(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<&%S<W=O<F0@=&\@=7-E(&EF('1H92!33510('-E
M<G9E<B!R97%U:7)E<R!A=71H96YT:6-A=&EO;BX*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D<&%S<W=O<F0@/2`G)SL*"B`@("`O*BH*
M("`@("`J($AO<W1N86UE(&]R(&1O;6%I;B!T:&%T('=I;&P@8F4@<V5N="!T
M;R!T:&4@<F5M;W1E(%--5%`@<V5R=F5R(&EN('1H90H@("`@("H@2$5,3R`O
M($5(3$\@;65S<V%G92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)&QO8V%L:&]S="`]("=L;V-A;&AO<W0G.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@26YS=&%N=&EA
M=&5S(&$@;F5W($UA:6Q?<VUT<#HZ(&]B:F5C="!B87-E9"!O;B!T:&4@<&%R
M86UE=&5R<PH@("`@("H@<&%S<V5D(&EN+B!)="!L;V]K<R!F;W(@=&AE(&9O
M;&QO=VEN9R!P87)A;65T97)S.@H@("`@("H@("`@(&AO<W0@("`@("`@(%1H
M92!S97)V97(@=&\@8V]N;F5C="!T;RX@1&5F875L=',@=&\@;&]C86QH;W-T
M+@H@("`@("H@("`@('!O<G0@("`@("`@(%1H92!P;W)T('1O(&-O;FYE8W0@
M=&\N($1E9F%U;'1S('1O(#(U+@H@("`@("H@("`@(&%U=&@@("`@("`@(%--
M5%`@875T:&5N=&EC871I;VXN("!$969A=6QT<R!T;R!N;VYE+@H@("`@("H@
M("`@('5S97)N86UE("`@(%1H92!U<V5R;F%M92!T;R!U<V4@9F]R(%--5%`@
M875T:"X@3F\@9&5F875L="X*("`@("`J("`@("!P87-S=V]R9"`@("!4:&4@
M<&%S<W=O<F0@=&\@=7-E(&9O<B!33510(&%U=&@N($YO(&1E9F%U;'0N"B`@
M("`@*B`@("`@;&]C86QH;W-T("`@5&AE(&QO8V%L(&AO<W1N86UE("\@9&]M
M86EN+B!$969A=6QT<R!T;R!L;V-A;&AO<W0N"B`@("`@*@H@("`@("H@268@
M82!P87)A;65T97(@:7,@<')E<V5N="!I;B!T:&4@)'!A<F%M<R!A<G)A>2P@
M:70@<F5P;&%C97,@=&AE"B`@("`@*B!D969A=6QT+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2!(87-H(&-O;G1A:6YI;F<@86YY('!A<F%M971E<G,@
M9&EF9F5R96YT(&9R;VT@=&AE"B`@("`@*B`@("`@("`@("`@("`@9&5F875L
M=',N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!-86EL7W-M='`H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H:7-S970H
M)'!A<F%M<ULG:&]S="==*2D@)'1H:7,M/FAO<W0@/2`D<&%R86US6R=H;W-T
M)UT["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W!O<G0G72DI("1T:&ES
M+3YP;W)T(#T@)'!A<F%M<ULG<&]R="==.PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R=A=71H)UTI*2`D=&AI<RT^875T:"`]("1P87)A;7-;)V%U=&@G
M73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG=7-E<FYA;64G72DI("1T
M:&ES+3YU<V5R;F%M92`]("1P87)A;7-;)W5S97)N86UE)UT["B`@("`@("`@
M:68@*&ES<V5T*"1P87)A;7-;)W!A<W-W;W)D)UTI*2`D=&AI<RT^<&%S<W=O
M<F0@/2`D<&%R86US6R=P87-S=V]R9"==.PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R=L;V-A;&AO<W0G72DI("1T:&ES+3YL;V-A;&AO<W0@/2`D<&%R
M86US6R=L;V-A;&AO<W0G73L*("`@('T*"B`@("`O*BH*("`@("`J($EM<&QE
M;65N=',@36%I;#HZ<V5N9"@I(&9U;F-T:6]N('5S:6YG(%--5%`N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1R96-I<&EE;G1S($5I=&AE<B!A(&-O
M;6UA+7-E<&5R871E9"!L:7-T(&]F(')E8VEP:65N=',*("`@("`J("`@("`@
M("`@("`@("`H4D9#.#(R(&-O;7!L:6%N="DL(&]R(&%N(&%R<F%Y(&]F(')E
M8VEP:65N=',L"B`@("`@*B`@("`@("`@("`@("`@96%C:"!21D,X,C(@=F%L
M:60N(%1H:7,@;6%Y(&-O;G1A:6X@<F5C:7!I96YT<R!N;W0*("`@("`J("`@
M("`@("`@("`@("!S<&5C:69I960@:6X@=&AE(&AE861E<G,L(&9O<B!"8V,Z
M+"!R97-E;F1I;F<*("`@("`J("`@("`@("`@("`@("!M97-S86=E<RP@971C
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D:&5A9&5R<R!4:&4@87)R
M87D@;V8@:&5A9&5R<R!T;R!S96YD('=I=&@@=&AE(&UA:6PL(&EN(&%N"B`@
M("`@*B`@("`@("`@("`@("`@87-S;V-I871I=F4@87)R87DL('=H97)E('1H
M92!A<G)A>2!K97D@:7,@=&AE"B`@("`@*B`@("`@("`@("`@("`@:&5A9&5R
M(&YA;64@*&4N9RXL("=3=6)J96-T)RDL(&%N9"!T:&4@87)R87D@=F%L=64*
M("`@("`J("`@("`@("`@("`@("!I<R!T:&4@:&5A9&5R('9A;'5E("AE+F<N
M+"`G=&5S="<I+B!4:&4@:&5A9&5R"B`@("`@*B`@("`@("`@("`@("`@<')O
M9'5C960@9G)O;2!T:&]S92!V86QU97,@=V]U;&0@8F4@)U-U8FIE8W0Z"B`@
M("`@*B`@("`@("`@("`@("`@=&5S="<N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8F]D>2!4:&4@9G5L;"!T97AT(&]F('1H92!M97-S86=E(&)O
M9'DL(&EN8VQU9&EN9R!A;GD*("`@("`J("`@("`@("`@("`@("`@36EM92!P
M87)T<RP@971C+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N
M<R!T<G5E(&]N('-U8V-E<W,L(&]R(&$@4$5!4E]%<G)O<@H@("`@("H@("`@
M("`@("`@("`@("!C;VYT86EN:6YG(&$@9&5S8W)I<'1I=F4@97)R;W(@;65S
M<V%G92!O;@H@("`@("H@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5N9"@D<F5C
M:7!I96YT<RP@)&AE861E<G,L("1B;V1Y*0H@("`@>PH@("`@("`@(&EN8VQU
M9&5?;VYC92`G3F5T+U--5%`N<&AP)SL*"B`@("`@("`@:68@*"$H)'-M='`@
M/2!N97<@3F5T7U--5%`H)'1H:7,M/FAO<W0L("1T:&ES+3YP;W)T+"`D=&AI
M<RT^;&]C86QH;W-T*2DI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!014%2
M7T5R<F]R*"=U;F%B;&4@=&\@:6YS=&%N=&EA=&4@3F5T7U--5%`@;V)J96-T
M)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<VUT
M<"T^8V]N;F5C="@I*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W(%!%05)?
M17)R;W(H)W5N86)L92!T;R!C;VYN96-T('1O('-M='`@<V5R=F5R("<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO<W0@
M+B`G.B<@+B`D=&AI<RT^<&]R="D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'1H:7,M/F%U=&@I('L*("`@("`@("`@("`@)&UE=&AO9"`](&ES7W-T<FEN
M9R@D=&AI<RT^875T:"D@/R`D=&AI<RT^875T:"`Z("<G.PH*("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)'-M='`M/F%U=&@H)'1H:7,M/G5S97)N
M86UE+"`D=&AI<RT^<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1M971H;V0I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YE
M=R!014%27T5R<F]R*"=U;F%B;&4@=&\@875T:&5N=&EC871E('1O('-M='`@
M<V5R=F5R)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&QI
M<W0H)&9R;VTL("1T97AT7VAE861E<G,I(#T@)'1H:7,M/G!R97!A<F5(96%D
M97)S*"1H96%D97)S*3L*"B`@("`@("`@+RH*("`@("`@("`@*B!3:6YC92!F
M97<@351!<R!A<F4@9V]I;F<@=&\@86QL;W<@=&AI<R!H96%D97(@=&\@8F4@
M9F]R9V5D('5N;&5S<PH@("`@("`@("`J(&ET)W,@:6X@=&AE($U!24P@1E)/
M33H@97AC:&%N9V4L('=E)VQL('5S92!2971U<FXM4&%T:"!I;G-T96%D(&]F
M"B`@("`@("`@("H@1G)O;3H@:68@:70G<R!S970N"B`@("`@("`@("HO"B`@
M("`@("`@:68@*"%E;7!T>2@D:&5A9&5R<ULG4F5T=7)N+5!A=&@G72DI('L*
M("`@("`@("`@("`@)&9R;VT@/2`D:&5A9&5R<ULG4F5T=7)N+5!A=&@G73L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&9R;VTI*2!["B`@("`@
M("`@("`@(')E='5R;B!N97<@4$5!4E]%<G)O<B@G3F\@9G)O;2!A9&1R97-S
M(&=I=F5N)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<VUT<"T^;6%I;$9R;VTH)&9R;VTI*2D@>PH@("`@("`@("`@("!R971U
M<FX@;F5W(%!%05)?17)R;W(H)W5N86)L92!T;R!S970@<V5N9&5R('1O(%LG
M("X@)&9R;VT@+B`G72<I.PH@("`@("`@('T*"B`@("`@("`@)')E8VEP:65N
M=',@/2`D=&AI<RT^<&%R<V5296-I<&EE;G1S*"1R96-I<&EE;G1S*3L*("`@
M("`@("!F;W)E86-H*"1R96-I<&EE;G1S(&%S("1R96-I<&EE;G0I('L*("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1S;71P+3YR8W!T
M5&\H)')E8VEP:65N="DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@;F5W
M(%!%05)?17)R;W(H)W5N86)L92!T;R!A9&0@<F5C:7!I96YT(%LG("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5C:7!I96YT
M("X@)UTZ("<@+B`D<F5S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<VUT<"T^
M9&%T82@D=&5X=%]H96%D97)S("X@(EQR7&XB("X@)&)O9'DI*2D@>PH@("`@
M("`@("`@("!R971U<FX@;F5W(%!%05)?17)R;W(H)W5N86)L92!T;R!S96YD
M(&1A=&$G*3L*("`@("`@("!]"@H@("`@("`@("1S;71P+3YD:7-C;VYN96-T
M*"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"GT*"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O<&5A<F-M9"YP:'`N;W)I9P``````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C(S,S$`,3`T,3<S-C,P,#<`,#(P-#(U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\O"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N
M(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG('5R;#H@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<G,Z(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!4;VUA
M<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!P96%R
M8VUD+G!H<"QV(#$N.2`R,#`T+S`Q+S(V(#`Q.C4Y.C$T('!A:F]Y92!%>'`@
M)`H*;V)?96YD7V-L96%N*"D["B\J*@H@*B!`;F]D97`@1W1K"B`J+PII9B`H
M)R]H;VUE+VIA;B]P96%R7W)O;W0O<VAA<F4O<&5A<B<@(3T@)T`G+B=I;F-L
M=61E7W!A=&@G+B=`)RD@>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@
M)R]H;VUE+VIA;B]P96%R7W)O;W0O<VAA<F4O<&5A<B<I.PI]"FEN:5]S970H
M)V%L;&]W7W5R;%]F;W!E;B<L('1R=64I.PIS971?=&EM95]L:6UI="@P*3L*
M;V)?:6UP;&EC:71?9FQU<V@H=')U92D["FEN:5]S970H)W1R86-K7V5R<F]R
M<R<L('1R=64I.PII;FE?<V5T*"=H=&UL7V5R<F]R<R<L(&9A;'-E*3L*:6YI
M7W-E="@G;6%G:6-?<75O=&5S7W)U;G1I;64G+"!F86QS92D["G-E=%]E<G)O
M<E]H86YD;&5R*"=E<G)O<E]H86YD;&5R)RD["@HD<&5A<E]P86-K86=E7W9E
M<G-I;VX@/2`B,2XS(CL*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PIR97%U
M:7)E7V]N8V4@)U!%05(O0V]N9FEG+G!H<"<["G)E<75I<F5?;VYC92`G4$5!
M4B]#;VUM86YD+G!H<"<["G)E<75I<F5?;VYC92`G0V]N<V]L92]'971O<'0N
M<&AP)SL*"E!%05)?0V]M;6%N9#HZ<V5T1G)O;G1E;F14>7!E*"=#3$DG*3L*
M)&%L;%]C;VUM86YD<R`](%!%05)?0V]M;6%N9#HZ9V5T0V]M;6%N9',H*3L*
M"B1A<F=V(#T@0V]N<V]L95]'971O<'0Z.G)E86102%!!<F=V*"D["B\J("1P
M<F]G;F%M92`](&)A<V5N86UE*"1A<F=V6S!=*3L@*B\*)'!R;V=N86UE(#T@
M)W!E87(G.PIA<G)A>5]S:&EF="@D87)G=BD["B1O<'1I;VYS(#T@0V]N<V]L
M95]'971O<'0Z.F=E=&]P=#(H)&%R9W8L(")C.D,Z9#I$.D=H/W-3<74Z=E8B
M*3L*:68@*%!%05(Z.FES17)R;W(H)&]P=&EO;G,I*2!["B`@("!U<V%G92@D
M;W!T:6]N<RD["GT*"B1O<'1S(#T@)&]P=&EO;G-;,%T["@HD9F5T>7!E(#T@
M)T-,22<["FEF("@D<')O9VYA;64@/3T@)V=P96%R)R!\?"`D<')O9VYA;64@
M/3T@)W!E87(M9W1K)RD@>PH@("`@)&9E='EP92`]("='=&LG.PI](&5L<V4@
M>PH@("`@9F]R96%C:"`H)&]P=',@87,@)&]P="D@>PH@("`@("`@(&EF("@D
M;W!T6S!=(#T]("=')RD@>PH@("`@("`@("`@("`D9F5T>7!E(#T@)T=T:R<[
M"B`@("`@("`@?0H@("`@?0I]"E!%05)?0V]M;6%N9#HZ<V5T1G)O;G1E;F14
M>7!E*"1F971Y<&4I.PHD=6D@/2`F4$5!4E]#;VUM86YD.CIG971&<F]N=&5N
M9$]B:F5C="@I.PI014%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M0T%,3$)!0TLL(&%R<F%Y*"1U:2P@(F1I<W!L87E&871A;$5R<F]R(BDI.PH*
M)'!E87)?=7-E<E]C;VYF:6<@/2`G)SL*)'!E87)?<WES=&5M7V-O;F9I9R`]
M("<G.PHD<W1O<F5?=7-E<E]C;VYF:6<@/2!F86QS93L*)'-T;W)E7W-Y<W1E
M;5]C;VYF:6<@/2!F86QS93L*)'9E<F)O<V4@/2`Q.PH*9F]R96%C:"`H)&]P
M=',@87,@)&]P="D@>PH@("`@<W=I=&-H("@D;W!T6S!=*2!["B`@("`@("`@
M8V%S92`G8R<Z"B`@("`@("`@("`@("1P96%R7W5S97)?8V]N9FEG(#T@)&]P
M=%LQ73L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G0R<Z"B`@
M("`@("`@("`@("1P96%R7W-Y<W1E;5]C;VYF:6<@/2`D;W!T6S%=.PH@("`@
M("`@("`@("!B<F5A:SL*("`@('T*?0H*)&-O;F9I9R`]("9014%27T-O;F9I
M9SHZ<VEN9VQE=&]N*"1P96%R7W5S97)?8V]N9FEG+"`D<&5A<E]S>7-T96U?
M8V]N9FEG*3L*)'9E<F)O<V4@/2`D8V]N9FEG+3YG970H(G9E<F)O<V4B*3L*
M)&-M9&]P=',@/2!A<G)A>2@I.PH*9F]R96%C:"`H)&]P=',@87,@)&]P="D@
M>PH@("`@)'!A<F%M(#T@(65M<'1Y*"1O<'1;,5TI(#\@)&]P=%LQ72`Z('1R
M=64["B`@("!S=VET8V@@*"1O<'1;,%TI('L*("`@("`@("!C87-E("=D)SH*
M("`@("`@("`@("`@;&ES="@D:V5Y+"`D=F%L=64I(#T@97AP;&]D92@G/2<L
M("1P87)A;2D["B`@("`@("`@("`@("1C;VYF:6<M/G-E="@D:V5Y+"`D=F%L
M=64L("=U<V5R)RD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@
M)T0G.@H@("`@("`@("`@("!L:7-T*"1K97DL("1V86QU92D@/2!E>'!L;V1E
M*"<])RP@)'!A<F%M*3L*("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"1K97DL
M("1V86QU92P@)W-Y<W1E;2<I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!C87-E("=S)SH*("`@("`@("`@("`@)'-T;W)E7W5S97)?8V]N9FEG(#T@
M=')U93L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G4R<Z"B`@
M("`@("`@("`@("1S=&]R95]S>7-T96U?8V]N9FEG(#T@=')U93L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@8V%S92`G=2<Z"B`@("`@("`@("`@("1C
M;VYF:6<M/G)E;6]V92@D<&%R86TL("=U<V5R)RD["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@(&-A<V4@)W8G.@H@("`@("`@("`@("`D8V]N9FEG+3YS
M970H)W9E<F)O<V4G+"`D8V]N9FEG+3YG970H)W9E<F)O<V4G*2`K(#$I.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=Q)SH*("`@("`@("`@
M("`@)&-O;F9I9RT^<V5T*"=V97)B;W-E)RP@)&-O;F9I9RT^9V5T*"=V97)B
M;W-E)RD@+2`Q*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G
M5B<Z"B`@("`@("`@("`@('5S86=E*&YU;&PL("=V97)S:6]N)RD["B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@+R\@86QL(&YO;B!P96%R('!A<F%M
M<R!G;V5S('1O('1H92!C;VUM86YD"B`@("`@("`@("`@("1C;61O<'1S6R1O
M<'1;,%U=(#T@)'!A<F%M.PH@("`@("`@("`@("!B<F5A:SL*("`@('T*?0H*
M:68@*"1S=&]R95]S>7-T96U?8V]N9FEG*2!["B`@("`D8V]N9FEG+3YS=&]R
M92@G<WES=&5M)RD["GT*"FEF("@D<W1O<F5?=7-E<E]C;VYF:6<I('L*("`@
M("1C;VYF:6<M/G-T;W)E*"=U<V5R)RD["GT*"B1C;VUM86YD(#T@*&ES<V5T
M*"1O<'1I;VYS6S%=6S!=*2D@/R`D;W!T:6]N<ULQ75LP72`Z(&YU;&P["@II
M9B`H96UP='DH)&-O;6UA;F0I("8F("@D<W1O<F5?=7-E<E]C;VYF:6<@?'P@
M)'-T;W)E7W-Y<W1E;5]C;VYF:6<I*2!["B`@("!E>&ET.PI]"@II9B`H)&9E
M='EP92`]/2`G1W1K)RD@>PH@("`@1W1K.CIM86EN*"D["GT@96QS92!D;R![
M"B`@("!I9B`H)&-O;6UA;F0@/3T@)VAE;'`G*2!["B`@("`@("`@=7-A9V4H
M;G5L;"P@0"1O<'1I;VYS6S%=6S%=*3L*("`@('T*"B`@("!014%2.CIP=7-H
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`D8VUD(#T@
M4$5!4E]#;VUM86YD.CIF86-T;W)Y*"1C;VUM86YD+"`D8V]N9FEG*3L*("`@
M(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@(&EF("A014%2.CII<T5R
M<F]R*"1C;60I*2!["B`@("`@("`@=7-A9V4H;G5L;"P@0"1O<'1I;VYS6S%=
M6S%=*3L*("`@('T*"B`@("`D<VAO<G1?87)G<R`]("1L;VYG7V%R9W,@/2!N
M=6QL.PH@("`@4$5!4E]#;VUM86YD.CIG971'971O<'1!<F=S*"1C;VUM86YD
M+"`D<VAO<G1?87)G<RP@)&QO;F=?87)G<RD["B`@("!A<G)A>5]S:&EF="@D
M;W!T:6]N<ULQ72D["B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&UP(#T@0V]N
M<V]L95]'971O<'0Z.F=E=&]P=#(H)&]P=&EO;G-;,5TL("1S:&]R=%]A<F=S
M+"`D;&]N9U]A<F=S*2DI('L*("`@("`@("!B<F5A:SL*("`@('T*("`@(&QI
M<W0H)'1M<&]P="P@)'!A<F%M<RD@/2`D=&UP.PH@("`@)&]P=',@/2!A<G)A
M>2@I.PH@("`@9F]R96%C:"`H)'1M<&]P="!A<R`D9F]O(#T^("1T;7`R*2![
M"B`@("`@("`@;&ES="@D;W!T+"`D=F%L=64I(#T@)'1M<#(["B`@("`@("`@
M:68@*"1V86QU92`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D=F%L=64@/2!T
M<G5E.R`O+R!O<'1I;VYS('=I=&AO=70@87)G<PH@("`@("`@('T*("`@("`@
M("!I9B`H<W1R;&5N*"1O<'0I(#T](#$I('L*("`@("`@("`@("`@)&-M9&]P
M=&EO;G,@/2`D8VUD+3YG971/<'1I;VYS*"1C;VUM86YD*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)&-M9&]P=&EO;G,@87,@)&\@/3X@)&0I('L*("`@("`@
M("`@("`@("`@(&EF("A`)&1;)W-H;W)T;W!T)UT@/3T@)&]P="D@>PH@("`@
M("`@("`@("`@("`@("`@("1O<'1S6R1O72`]("1V86QU93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&EF("AS=6)S='(H)&]P="P@,"P@,BD@/3T@)RTM)RD@>PH@("`@
M("`@("`@("`@("`@)&]P='-;<W5B<W1R*"1O<'0L(#(I72`]("1V86QU93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@("1O:R`]("1C;60M
M/G)U;B@D8V]M;6%N9"P@)&]P=',L("1P87)A;7,I.PH@("`@:68@*"1O:R`]
M/3T@9F%L<V4I('L*("`@("`@("!014%2.CIR86ES945R<F]R*")U;FMN;W=N
M(&-O;6UA;F0@8"1C;VUM86YD)R(I.PH@("`@?0I]('=H:6QE("AF86QS92D[
M"@HO+R![>WL@=7-A9V4H*0H*9G5N8W1I;VX@=7-A9V4H)&5R<F]R(#T@;G5L
M;"P@)&AE;'!S=6)J96-T(#T@;G5L;"D*>PH@("`@9VQO8F%L("1P<F]G;F%M
M92P@)&%L;%]C;VUM86YD<SL*("`@("1S=&1E<G(@/2!F;W!E;B@G<&AP.B\O
M<W1D97)R)RP@)W<G*3L*("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<BDI
M('L*("`@("`@("!F<'5T<R@D<W1D97)R+"`D97)R;W(M/F=E=$UE<W-A9V4H
M*2`N(")<;B(I.PH@("`@?2!E;'-E:68@*"1E<G)O<B`A/3T@;G5L;"D@>PH@
M("`@("`@(&9P=71S*"1S=&1E<G(L("(D97)R;W)<;B(I.PH@("`@?0H@("`@
M:68@*"1H96QP<W5B:F5C="`A/2!N=6QL*2!["B`@("`@("`@)'!U="`](&-M
M9$AE;'`H)&AE;'!S=6)J96-T*3L*("`@('T@96QS92!["B`@("`@("`@)'!U
M="`]"B`@("`@("`@("`@(")5<V%G93H@)'!R;V=N86UE(%MO<'1I;VYS72!C
M;VUM86YD(%MC;VUM86YD+6]P=&EO;G-=(#QP87)A;65T97)S/EQN(BX*("`@
M("`@("`@("`@(E1Y<&4@7"(D<')O9VYA;64@:&5L<"!O<'1I;VYS7"(@=&\@
M;&ES="!A;&P@;W!T:6]N<RY<;B(N"B`@("`@("`@("`@(")4>7!E(%PB)'!R
M;V=N86UE(&AE;'`@/&-O;6UA;F0^7"(@=&\@9V5T('1H92!H96QP(&9O<B!T
M:&4@<W!E8VEF:65D(&-O;6UA;F0N7&XB+@H@("`@("`@("`@("`B0V]M;6%N
M9',Z7&XB.PH@("`@("`@("1M87AL96X@/2!M87@H87)R87E?;6%P*")S=')L
M96XB+"`D86QL7V-O;6UA;F1S*2D["B`@("`@("`@)&9O<FUA='-T<B`]("(E
M+7LD;6%X;&5N?7,@("5S7&XB.PH@("`@("`@(&MS;W)T*"1A;&Q?8V]M;6%N
M9',I.PH@("`@("`@(&9O<F5A8V@@*"1A;&Q?8V]M;6%N9',@87,@)&-M9"`]
M/B`D8VQA<W,I('L*("`@("`@("`@("`@)'!U="`N/2!S<')I;G1F*"1F;W)M
M871S='(L("1C;60L(%!%05)?0V]M;6%N9#HZ9V5T1&5S8W)I<'1I;VXH)&-M
M9"DI.PH@("`@("`@('T*("`@('T*("`@(&9P=71S*"1S=&1E<G(L("(D<'5T
M7&XB*3L*("`@(&9C;&]S92@D<W1D97)R*3L*("`@(&5X:70["GT*"F9U;F-T
M:6]N(&-M9$AE;'`H)&-O;6UA;F0I"GL*("`@(&=L;V)A;"`D<')O9VYA;64L
M("1A;&Q?8V]M;6%N9',L("1C;VYF:6<["B`@("!I9B`H)&-O;6UA;F0@/3T@
M(F]P=&EO;G,B*2!["B`@("`@("`@<F5T=7)N"B`@("`@("`@(D]P=&EO;G,Z
M7&XB+@H@("`@("`@("(@("`@("UV("`@("`@("`@:6YC<F5A<V4@=F5R8F]S
M:71Y(&QE=F5L("AD969A=6QT(#$I7&XB+@H@("`@("`@("(@("`@("UQ("`@
M("`@("`@8F4@<75I970L(&1E8W)E87-E('9E<F)O<VET>2!L979E;%QN(BX*
M("`@("`@("`B("`@("`M8R!F:6QE("`@(&9I;F0@=7-E<B!C;VYF:6=U<F%T
M:6]N(&EN(&!F:6QE)UQN(BX*("`@("`@("`B("`@("`M0R!F:6QE("`@(&9I
M;F0@<WES=&5M(&-O;F9I9W5R871I;VX@:6X@8&9I;&4G7&XB+@H@("`@("`@
M("(@("`@("UD(&9O;SUB87(@<V5T('5S97(@8V]N9FEG('9A<FEA8FQE(&!F
M;V\G('1O(&!B87(G7&XB+@H@("`@("`@("(@("`@("U$(&9O;SUB87(@<V5T
M('-Y<W1E;2!C;VYF:6<@=F%R:6%B;&4@8&9O;R<@=&\@8&)A<B=<;B(N"B`@
M("`@("`@(B`@("`@+4<@("`@("`@("!S=&%R="!I;B!G<F%P:&EC86P@*$=T
M:RD@;6]D95QN(BX*("`@("`@("`B("`@("`M<R`@("`@("`@('-T;W)E('5S
M97(@8V]N9FEG=7)A=&EO;EQN(BX*("`@("`@("`B("`@("`M4R`@("`@("`@
M('-T;W)E('-Y<W1E;2!C;VYF:6=U<F%T:6]N7&XB+@H@("`@("`@("(@("`@
M("UU(&9O;R`@("`@=6YS970@8&9O;R<@:6X@=&AE('5S97(@8V]N9FEG=7)A
M=&EO;EQN(BX*("`@("`@("`B("`@("`M:"P@+3\@("`@(&1I<W!L87D@:&5L
M<"]U<V%G92`H=&AI<R!M97-S86=E*5QN(BX*("`@("`@("`B("`@("`M5B`@
M("`@("`@('9E<G-I;VX@:6YF;W)M871I;VY<;B(["B`@("!](&5L<V5I9B`H
M)&-O;6UA;F0@/3T@(G-H;W)T8W5T<R(I('L*("`@("`@("`D<V,@/2!014%2
M7T-O;6UA;F0Z.F=E=%-H;W)T8W5T<R@I.PH@("`@("`@("1R970@/2`B4VAO
M<G1C=71S.EQN(CL*("`@("`@("!F;W)E86-H("@D<V,@87,@)',@/3X@)&,I
M('L*("`@("`@("`@("`@)')E="`N/2!S<')I;G1F*"(@("`@("4M.',@)7-<
M;B(L("1S+"`D8RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T.PH*
M("`@('T@96QS96EF("@D8V]M;6%N9"`]/2`B=F5R<VEO;B(I('L*("`@("`@
M("!R971U<FX@(E!%05(@5F5R<VEO;CH@(BXD1TQ/0D%,4ULG<&5A<E]P86-K
M86=E7W9E<G-I;VXG72X*("`@("`@("`@("`@("`@(EQN4$A0(%9E<G-I;VXZ
M("(N<&AP=F5R<VEO;B@I+@H@("`@("`@("`@("`@("`B7&Y:96YD($5N9VEN
M92!697)S:6]N.B`B+GIE;F1?=F5R<VEO;B@I+@H@("`@("`@("`@("`@("`B
M7&Y2=6YN:6YG(&]N.B`B+G!H<%]U;F%M92@I.PH*("`@('T@96QS96EF("@D
M:&5L<"`](%!%05)?0V]M;6%N9#HZ9V5T2&5L<"@D8V]M;6%N9"DI('L*("`@
M("`@("!I9B`H:7-?<W1R:6YG*"1H96QP*2D@>PH@("`@("`@("`@("!R971U
M<FX@(B1P<F]G;F%M92`D8V]M;6%N9"!;;W!T:6]N<UT@)&AE;'!<;B(["B`@
M("`@("`@?0H@("`@("`@(&EF("@D:&5L<%LQ72`]/3T@;G5L;"D@>PH@("`@
M("`@("`@("!R971U<FX@(B1P<F]G;F%M92`D8V]M;6%N9"`D:&5L<%LP72([
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("(D<')O9VYA
M;64@)&-O;6UA;F0@6V]P=&EO;G-=("1H96QP6S!=7&XD:&5L<%LQ72(["B`@
M("`@("`@?0H@("`@?0H@("`@<F5T=7)N(").;R!S=6-H(&-O;6UA;F0B.PI]
M"@HO+R!]?7T*"F9U;F-T:6]N(&5R<F]R7VAA;F1L97(H)&5R<FYO+"`D97)R
M;7-G+"`D9FEL92P@)&QI;F4L("1V87)S*2!["B`@("!I9B`H*&1E9FEN960H
M)T5?4U1224-4)RD@)B8@)&5R<FYO("8@15]35%))0U0I('Q\("%E<G)O<E]R
M97!O<G1I;F<H*2D@>PH@("`@("`@(')E='5R;CL@+R\@0'-I;&5N8V5D(&5R
M<F]R"B`@("!]"B`@("`D97)R;W)T>7!E(#T@87)R87D@*`H@("`@("`@($5?
M15)23U(@("`]/B`@(D5R<F]R(BP*("`@("`@("!%7U=!4DY)3D<@("`]/B`@
M(E=A<FYI;F<B+`H@("`@("`@($5?4$%24T4@("`]/B`@(E!A<G-I;F<@17)R
M;W(B+`H@("`@("`@($5?3D]424-%("`@/3X@(").;W1I8V4B+`H@("`@("`@
M($5?0T]215]%4E)/4B`@/3X@(")#;W)E($5R<F]R(BP*("`@("`@("!%7T-/
M4D5?5T%23DE.1R`@/3X@(")#;W)E(%=A<FYI;F<B+`H@("`@("`@($5?0T]-
M4$E,15]%4E)/4B`@/3X@(")#;VUP:6QE($5R<F]R(BP*("`@("`@("!%7T-/
M35!)3$5?5T%23DE.1R`]/B`@(D-O;7!I;&4@5V%R;FEN9R(L"B`@("`@("`@
M15]54T527T524D]2(#T^("`B57-E<B!%<G)O<B(L"B`@("`@("`@15]54T52
M7U=!4DY)3D<@/3X@(")5<V5R(%=A<FYI;F<B+`H@("`@("`@($5?55-%4E].
M3U1)0T4@/3X@(")5<V5R($YO=&EC92(*("`@("D["B`@("`D<')E9FEX(#T@
M)&5R<F]R='EP95LD97)R;F]=.PH@("`@)&9I;&4@/2!B87-E;F%M92@D9FEL
M92D["B`@("!P<FEN="`B7&XD<')E9FEX.B`D97)R;7-G(&EN("1F:6QE(&]N
M(&QI;F4@)&QI;F5<;B(["GT*"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J
M('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!I;F1E;G0M
M=&%B<RUM;V1E.B!N:6P*("H@;6]D93H@<&AP"B`J($5N9#H*("HO"B\O('9I
M;38P,#IS>6X]<&AP"@H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TA45%`N<&AP````````````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W,C,W`#$P
M-#$W,S8S,#`W`#`Q-C8T,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3=&EG($)A:VME
M;B`\<W-B0&9A<W0N;F\^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!(5%10+G!H<"QV
M(#$N,C`@,C`P,R\Q,B\P.2`Q,CHR-SHT-R!P86IO>64@17AP("0*+R\*+R\@
M2%144"!U=&EL:71Y(&9U;F-T:6]N<RX*+R\*"F-L87-S($A45%`*>PH@("`@
M+RHJ"B`@("`@*B!&;W)M870@82!21D,@8V]M<&QI86YT($A45%`@:&5A9&5R
M+B`@5&AI<R!F=6YC=&EO;@H@("`@("H@:&]N;W)S('1H92`B>3)K7V-O;7!L
M:6%N8V4B('!H<"YI;FD@9&ER96-T:79E+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G0@)'1I;64@54Y)6"!T:6UE<W1A;7`*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D($A45%`@9&%T92!S=')I;F<L(&]R(&9A;'-E(&9O<B!A;B!I
M;G9A;&ED('1I;65S=&%M<"X*("`@("`J"B`@("`@*B!`875T:&]R(%-T:6<@
M0F%K:V5N(#QS<V)`9F%S="YN;SX*("`@("`J($!A=71H;W(@4W1E<FQI;F<@
M2'5G:&5S(#QS=&5R;&EN9T!P:'`N;F5T/@H@("`@("HO"B`@("!F=6YC=&EO
M;B!$871E*"1T:6UE*0H@("`@>PH@("`@("`@("\J($EF('=E)W)E('DR:R!C
M;VUP;&EA;G0L('5S92!T:&4@;F5W97(L(')E8V-O;65N9&5D(%)&0R`X,C(*
M("`@("`@("`@("!F;W)M870@*B\*("`@("`@("!I9B`H:6YI7V=E="@B>3)K
M7V-O;7!L:6%N8V4B*2`]/2!T<G5E*2!["B`@("`@("`@("`@(')E='5R;B!G
M;61A=&4H(D0L(&0@32!9($@Z:3IS(%Q'7$U<5"(L("1T:6UE*3L*("`@("`@
M("!]"B`@("`@("`@+RH@57-E(%)&0RTX-3`@=VAI8V@@<W5P<&]R=',@='=O
M(&-H87)A8W1E<B!Y96%R(&YU;6)E<G,@*B\*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(&=M9&%T92@B1BP@9"U$+7D@2#II.G,@7$=<35Q4
M(BP@)'1I;64I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($YE
M9V]T:6%T92!L86YG=6%G92!W:71H('1H92!U<V5R)W,@8G)O=W-E<B!T:')O
M=6=H('1H90H@("`@("H@06-C97!T+4QA;F=U86=E($A45%`@:&5A9&5R(&]R
M('1H92!U<V5R)W,@:&]S="!A9&1R97-S+@H@("`@("H@3&%N9W5A9V4@8V]D
M97,@87)E(&=E;F5R86QL>2!I;B!T:&4@9F]R;2`B;&PB(&9O<B!A(&QA;F=U
M86=E"B`@("`@*B!S<&]K96X@:6X@;VYL>2!O;F4@8V]U;G1R>2P@;W(@(FQL
M+4-#(B!F;W(@82!L86YG=6%G92!S<&]K96X@:6X*("`@("`J(&$@<&%R=&EC
M=6QA<B!C;W5N=')Y+B`@1F]R(&5X86UP;&4L(%4N4RX@16YG;&ES:"!I<R`B
M96XM55,B+`H@("`@("H@=VAI;&4@0G)I=&ES:"!%;F=L:7-H(&ES(")E;BU5
M2R(N("!0;W)T=6=E<V4@87,@<W!O:V5N(&EN"B`@("`@*B!0;W)T=6=A;"!I
M<R`B<'0M4%0B+"!W:&EL92!"<F%Z:6QI86X@4&]R='5G97-E(&ES(")P="U"
M4B(N"B`@("`@*B!4=V\M;&5T=&5R(&-O=6YT<GD@8V]D97,@8V%N(&)E(&9O
M=6YD(&EN('1H92!)4T\@,S$V-B!S=&%N9&%R9"X*("`@("`J"B`@("`@*B!1
M=6%N=&ET:65S(&EN('1H92!!8V-E<'0M3&%N9W5A9V4Z(&AE861E<B!A<F4@
M<W5P<&]R=&5D+"!F;W(*("`@("`J(&5X86UP;&4Z"B`@("`@*@H@("`@("H@
M($%C8V5P="U,86YG=6%G93H@96XM54L[<3TP+C<L(&5N+553.W$],"XV+"!N
M;SMQ/3$N,"P@9&L[<3TP+C@*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'-U<'!O<G1E9"!A;B!A<W-O8VEA=&EV92!A<G)A>2!I;F1E>&5D(&)Y(&QA
M;F=U86=E"B`@("`@*B!C;V1E<R`H8V]U;G1R>2!C;V1E<RD@<W5P<&]R=&5D
M(&)Y('1H92!A<'!L:6-A=&EO;BX@(%9A;'5E<PH@("`@("H@;75S="!E=F%L
M=6%T92!T;R!T<G5E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1E
M9F%U;'0@=&AE(&1E9F%U;'0@;&%N9W5A9V4@=&\@=7-E(&EF(&YO;F4@:7,@
M9F]U;F0*("`@("`J(&1U<FEN9R!N96=O=&EA=&EO;BP@9&5F875L=',@=&\@
M(F5N+553(B!F;W(@52Y3+B!%;F=L:7-H"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@=&AE(&YE9V]T:6%T960@;&%N9W5A9V4@<F5S=6QT"B`@("`@
M*@H@("`@("H@0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B0&9A<W0N;F\^"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&YE9V]T:6%T94QA;F=U86=E*"8D<W5P<&]R
M=&5D+"`D9&5F875L="`]("=E;BU54R<I"B`@("!["B`@("`@("`@9VQO8F%L
M("1(5%107U-%4E9%4E]605)3.PH*("`@("`@("`D<W5P<&]R=&5D(#T@87)R
M87E?8VAA;F=E7VME>5]C87-E*"1S=7!P;W)T960L($-!4T5?3$]715(I.PH*
M("`@("`@("`O*B!)9B!T:&4@8VQI96YT(&AA<R!S96YT(&%N($%C8V5P="U,
M86YG=6%G93H@:&5A9&5R+"!S964@:68*("`@("`@("`@*B!I="!C;VYT86EN
M<R!A(&QA;F=U86=E('=E('-U<'!O<G0N"B`@("`@("`@("HO"B`@("`@("`@
M:68@*&ES<V5T*"1(5%107U-%4E9%4E]605)36R=(5%107T%#0T505%],04Y'
M54%'12==*2D@>PH@("`@("`@("`@("`D86-C97!T960@/2!S<&QI="@G+%M;
M.G-P86-E.EU=*B<L("1(5%107U-%4E9%4E]605)36R=(5%107T%#0T505%],
M04Y'54%'12==*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U
M;G0H)&%C8V5P=&5D*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*&5R
M96=I*"=>*%MA+7I?+5TK*3M;6SIS<&%C93I=72IQ/2A;,"TY7"Y=*RDG+"`D
M86-C97!T961;)&E=+"`D87)R*2D@>PH@("`@("`@("`@("`@("`@("`@("1Q
M(#T@*&1O=6)L92DD87)R6S)=.PH@("`@("`@("`@("`@("`@("`@("1L(#T@
M)&%R<ELQ73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)'$@/2`T,CL*("`@("`@("`@("`@("`@("`@("`D;"`]('-T
M<G1O;&]W97(H)&%C8V5P=&5D6R1I72D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D<W5P<&]R=&5D6R1L72D@)B8@
M*"1Q(#X@,"XP*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D<2`]/2`T
M,BD@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)&P["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1C86YD:61A
M=&5S6R1L72`]("1Q.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<W-E="@D8V%N9&ED871E<RDI('L*("`@("`@
M("`@("`@("`@(&%R<V]R="@D8V%N9&ED871E<RD["B`@("`@("`@("`@("`@
M("!R97-E="@D8V%N9&ED871E<RD["B`@("`@("`@("`@("`@("!R971U<FX@
M:V5Y*"1C86YD:61A=&5S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@0VAE8VL@9F]R(&$@=F%L:60@;&%N9W5A9V4@8V]D92!I;B!T
M:&4@=&]P+6QE=F5L(&1O;6%I;B!O9@H@("`@("`@("`J('1H92!C;&EE;G0G
M<R!H;W-T(&%D9')E<W,N"B`@("`@("`@("HO"B`@("`@("`@:68@*&ES<V5T
M*"1(5%107U-%4E9%4E]605)36R=214U/5$5?2$]35"==*2`F)@H@("`@("`@
M("`@("!E<F5G*")<+EM>7"Y=*R0B+"`D2%144%]315)615)?5D%24ULG4D5-
M3U1%7TA/4U0G72P@)&%R<BDI('L*("`@("`@("`@("`@)&QA;F<@/2!S=')T
M;VQO=V5R*"1A<G);,5TI.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1S=7!P
M;W)T961;)&QA;F==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1L86YG
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1E
M9F%U;'0["B`@("!]"@H@("`@+RHJ"B`@("`J(%-E;F1S(&$@(DA%040B($A4
M5%`@8V]M;6%N9"!T;R!A('-E<G9E<B!A;F0@<F5T=7)N<R!T:&4@:&5A9&5R
M<PH@("`@*B!A<R!A;B!A<W-O8VEA=&EV92!A<G)A>2X@17AA;7!L92!O=71P
M=70@8V]U;&0@8F4Z"B`@("`J("`@($%R<F%Y"B`@("`J("`@("@*("`@("H@
M("`@("`@(%MR97-P;VYS95]C;V1E72`]/B`R,#`@("`@("`@("`@+R\@5&AE
M($A45%`@<F5S<&]N<V4@8V]D90H@("`@*B`@("`@("`@6W)E<W!O;G-E72`]
M/B!(5%10+S$N,2`R,#`@3TL@("`O+R!4:&4@9G5L;"!(5%10(')E<W!O;G-E
M('-T<FEN9PH@("`@*B`@("`@("`@6T1A=&5=(#T^($9R:2P@,3$@2F%N(#(P
M,#(@,#$Z-#$Z-#0@1TU4"B`@("`J("`@("`@("!;4V5R=F5R72`]/B!!<&%C
M:&4O,2XS+C(P("A5;FEX*2!02%`O-"XQ+C$*("`@("H@("`@("`@(%M8+5!O
M=V5R960M0GE=(#T^(%!(4"\T+C$N,0H@("`@*B`@("`@("`@6T-O;FYE8W1I
M;VY=(#T^(&-L;W-E"B`@("`J("`@("`@("!;0V]N=&5N="U4>7!E72`]/B!T
M97AT+VAT;6P*("`@("H@("`@*0H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG
M("1U<FP@02!V86QI9"!U<FPL(&9O<B!E>#H@:'1T<#HO+W!E87(N<&AP+FYE
M="]C<F5D:71S+G!H<`H@("`@*B!`<F5T=7)N(&UI>&5D($%S<V]C(&%R<F%Y
M(&]R(%!%05(@97)R;W(*("`@("H*("`@("H@0&%U=&AO<B!4;VUA<R!6+E8N
M0V]X(#QC;WA`:61E8VYE="YC;VT^"B`@("`J+PH@("`@9G5N8W1I;VX@:&5A
M9"@D=7)L*0H@("`@>PH@("`@("`@("1P=7)L(#T@<&%R<V5?=7)L*"1U<FPI
M.PH@("`@("`@("1P;W)T(#T@*&ES<V5T*"1P=7)L6R=P;W)T)UTI*2`_("1P
M=7)L6R=P;W)T)UT@.B`X,#L*("`@("`@("`D9G`@/2!F<V]C:V]P96XH)'!U
M<FQ;)VAO<W0G72P@)'!O<G0L("1E<G)N;RP@)&5R<G-T<BP@,3`I.PH@("`@
M("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`B4$5!
M4BYP:'`B.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B
M2%144#HZ:&5A9"!%<G)O<B`D97)R<W1R("@D97)N;RDB*3L*("`@("`@("!]
M"B`@("`@("`@)'!A=&@@/2`H(65M<'1Y*"1P=7)L6R=P871H)UTI*2`_("1P
M=7)L6R=P871H)UT@.B`G+R<["@H@("`@("`@(&9P=71S*"1F<"P@(DA%040@
M)'!A=&@@2%144"\Q+C!<<EQN(BD["B`@("`@("`@9G!U=',H)&9P+"`B2&]S
M=#H@(B`N("1P=7)L6R=H;W-T)UT@+B`B7')<;B(I.PH@("`@("`@(&9P=71S
M*"1F<"P@(D-O;FYE8W1I;VXZ(&-L;W-E7')<;EQR7&XB*3L*"B`@("`@("`@
M)')E<W!O;G-E(#T@<G1R:6TH9F=E=',H)&9P+"`T,#DV*2D["B`@("`@("`@
M:68H<')E9U]M871C:"@B?%Y(5%10+UM>7'-=*EQS*"XJ/RE<<WPB+"`D<F5S
M<&]N<V4L("1S=&%T=7,I*2!["B`@("`@("`@("`@("1H96%D97)S6R=R97-P
M;VYS95]C;V1E)UT@/2`D<W1A='5S6S%=.PH@("`@("`@('T*("`@("`@("`D
M:&5A9&5R<ULG<F5S<&]N<V4G72`]("1R97-P;VYS93L*"B`@("`@("`@=VAI
M;&4@*"1L:6YE(#T@9F=E=',H)&9P+"`T,#DV*2D@>PH@("`@("`@("`@("!I
M9B`H(71R:6TH)&QI;F4I*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')P;W,H)&QI
M;F4L("<Z)RDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)&AE861E
M<B`]('-U8G-T<B@D;&EN92P@,"P@)'!O<RD["B`@("`@("`@("`@("`@("`D
M=F%L=64@(#T@=')I;2AS=6)S='(H)&QI;F4L("1P;W,@*R`Q*2D["B`@("`@
M("`@("`@("`@("`D:&5A9&5R<ULD:&5A9&5R72`]("1V86QU93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@
M("!R971U<FX@)&AE861E<G,["B`@("!]"@H@("`@+RHJ"B`@("`J(%1H:7,@
M9G5N8W1I;VX@<F5D:7)E8W1S('1H92!C;&EE;G0N(%1H:7,@:7,@9&]N92!B
M>2!I<W-U:6YG"B`@("`J(&$@3&]C871I;VXZ(&AE861E<B!A;F0@97AI=&EN
M9RX*("`@("H*("`@("H@0&%U=&AO<B!2:6-H87)D($AE>65S(#QR:6-H87)D
M0'!H<"YN970^"B`@("`J($!P87)A;2`@<W1R:6YG("1U<FP@55),('=H97)E
M('1H92!R961I<F5C="!S:&]U;&0@9V\@=&\*("`@("HO"B`@("!F=6YC=&EO
M;B!R961I<F5C="@D=7)L*0H@("`@>PH@("`@("`@(&=L;V)A;"`D2%144%]3
M15)615)?5D%24SL*("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>*&AT='!S
M/WQF='`I.EPO7"\O)RP@)'5R;"DI('L*("`@("`@("`@("`@)'-E<G9E<B`]
M("=H='1P)R`N("A`)$A45%!?4T525D527U9!4E-;)TA45%!3)UT@/3T@)V]N
M)R`_("=S)R`Z("<G*2`N("<Z+R\G("X@)$A45%!?4T525D527U9!4E-;)U-%
M4E9%4E].04U%)UT["B`@("`@("`@("`@(&EF("@D2%144%]315)615)?5D%2
M4ULG4T525D527U!/4E0G72`A/2`X,"`F)@H@("`@("`@("`@("`@("`@)$A4
M5%!?4T525D527U9!4E-;)U-%4E9%4E]03U)4)UT@(3T@-#0S*2!["B`@("`@
M("`@("`@("`@("`D<V5R=F5R("X]("<Z)R`N("1(5%107U-%4E9%4E]605)3
M6R=315)615)?4$]25"==.PH@("`@("`@("`@("!]"@D)"0H)"0DD<&%T:"`]
M(&1I<FYA;64H)$A45%!?4T525D527U9!4E-;)U!(4%]314Q&)UTI.PH@("`@
M("`@("`@("!I9B`H)'5R;'LP?2`A/2`G+R<I('L*"0D)"21P871H("`@+CT@
M)'5R;#L*("`@("`@("`@("`@("`@("1S97)V97(@+CT@9&ER;F%M92@D2%14
M4%]315)615)?5D%24ULG4$A07U-%3$8G72D["B`@("`@("`@("`@("`@("`D
M=7)L(#T@)'-E<G9E<B`N("<O)R`N('!R96=?<F5P;&%C92@G(5Y<+B\A)RP@
M)R<L("1U<FPI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'5R;"`]("1S97)V97(@+B`D=7)L.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@
M("`@("`@97AI=#L*("`@('T*?0H_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]$871E+G!H<```````````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$P-C8S,@`Q,#0Q-S,V,S`P-P`P,38W,S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N
M(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<G,Z($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+PHO+R`D260Z($1A=&4N<&AP+'8@,2XR,B`R,#`S+S$R+S(Q(#$T.C(Q.C0V
M('!A:F]Y92!%>'`@)`H*+RHJ0",K"B`J($EN8VQU9&4@<W5P<&]R=&EN9R!C
M;&%S<V5S"B`J+PIR97%U:7)E7V]N8V4@)T1A=&4O5&EM95IO;F4N<&AP)SL*
M<F5Q=6ER95]O;F-E("=$871E+T-A;&,N<&AP)SL*<F5Q=6ER95]O;F-E("=$
M871E+U-P86XN<&AP)SL*+RHJ0",M*B\*"B\J*D`C*PH@*B!/=71P=70@9F]R
M;6%T<RX@(%!A<W,@=&AI<R!T;R!G971$871E*"DN"B`J+PHO*BH*("H@(EE9
M65DM34TM1$0@2$@Z34TZ4U,B"B`J+PID969I;F4H)T1!5$5?1D]234%47TE3
M3R<L(#$I.PHO*BH*("H@(EE965E-35-35$A(34U34RA:?"@K+RTI2$A-32D_
M(@H@*B\*9&5F:6YE*"=$051%7T9/4DU!5%])4T]?0D%324,G+"`R*3L*+RHJ
M"B`J(")965E9+4U-+5-35$A(.DU-.E-3*%I\*"LO+2E(2#I-32D_(@H@*B\*
M9&5F:6YE*"=$051%7T9/4DU!5%])4T]?15A414Y$140G+"`S*3L*+RHJ"B`J
M(")965E934U$1$A(34U34R(*("HO"F1E9FEN92@G1$%415]&3U)-051?5$E-
M15-404U0)RP@-"D["B\J*@H@*B!L;VYG(&EN="P@<V5C;VYD<R!S:6YC92!T
M:&4@=6YI>"!E<&]C:`H@*B\*9&5F:6YE*"=$051%7T9/4DU!5%]53DE85$E-
M12<L(#4I.PHO*BI`(RTJ+PH*+RHJ"B`J($=E;F5R:6,@9&%T92!H86YD;&EN
M9R!C;&%S<R!F;W(@4$5!4BX*("H*("H@1V5N97)I8R!D871E(&AA;F1L:6YG
M(&-L87-S(&9O<B!014%2+B`@071T96UP=',@=&\@8F4@=&EM92!Z;VYE(&%W
M87)E"B`J('1H<F]U9V@@=&AE($1A=&4Z.E1I;65:;VYE(&-L87-S+B`@4W5P
M<&]R=',@<V5V97)A;"!O<&5R871I;VYS(&9R;VT*("H@1&%T93HZ0V%L8R!O
M;B!$871E(&]B:F5C=',N"B`J"B`J($!A=71H;W(@0F%B82!"=65H;&5R(#QB
M86)A0&)A8F%Z+F-O;3X*("H@0'!A8VMA9V4@1&%T90H@*B!`86-C97-S('!U
M8FQI8PH@*B\*8VQA<W,@1&%T90I["B`@("`O*BH*("`@("`J('1H92!Y96%R
M"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)'EE87(["B`@("`O
M*BH*("`@("`J('1H92!M;VYT:`H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@
M("`@=F%R("1M;VYT:#L*("`@("\J*@H@("`@("H@=&AE(&1A>0H@("`@("H@
M0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1D87D["B`@("`O*BH*("`@("`J
M('1H92!H;W5R"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&AO
M=7(["B`@("`O*BH*("`@("`J('1H92!M:6YU=&4*("`@("`J($!V87(@:6YT
M"B`@("`@*B\*("`@('9A<B`D;6EN=71E.PH@("`@+RHJ"B`@("`@*B!T:&4@
M<V5C;VYD"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)'-E8V]N
M9#L*("`@("\J*@H@("`@("H@=&EM97IO;F4@9F]R('1H:7,@9&%T90H@("`@
M("H@0'9A<B!O8FIE8W0@1&%T95]4:6UE6F]N90H@("`@("HO"B`@("!V87(@
M)'1Z.PH*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@
M("H@0W)E871E<R!A(&YE=R!$871E($]B:F5C="!I;FET:6%L:7IE9"!T;R!T
M:&4@8W5R<F5N="!D871E+W1I;64@:6X@=&AE"B`@("`@*B!S>7-T96TM9&5F
M875L="!T:6UE>F]N92!B>2!D969A=6QT+B`@02!D871E(&]P=&EO;F%L;'D*
M("`@("`J('!A<W-E9"!I;B!M87D@8F4@:6X@=&AE($E33R`X-C`Q+"!424U%
M4U1!35`@;W(@54Y)6%1)344@9F]R;6%T+`H@("`@("H@;W(@86YO=&AE<B!$
M871E(&]B:F5C="X@($EF(&YO(&1A=&4@:7,@<&%S<V5D+"!T:&4@8W5R<F5N
M="!D871E+W1I;64*("`@("`J(&ES('5S960N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S964@<V5T1&%T92@I"B`@("`@*B!`<&%R
M86T@;6EX960@)&1A=&4@;W!T:6]N86P@+2!D871E+W1I;64@=&\@:6YI=&EA
M;&EZ90H@("`@("H@0')E='5R;B!O8FIE8W0@1&%T92!T:&4@;F5W($1A=&4@
M;V)J96-T"B`@("`@*B\*("`@(&9U;F-T:6]N($1A=&4H)&1A=&4@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1T:&ES+3YT>B`]($1A=&5?5&EM95IO;F4Z.F=E
M=$1E9F%U;'0H*3L*("`@("`@("!I9B`H:7-?;G5L;"@D9&%T92DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$1A=&4H9&%T92@B62UM+60@2#II.G,B*2D[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V]B:F5C="@D9&%T92D@)B8@"B`@("`@
M("`@("`@("@H9V5T7V-L87-S*"1D871E*2`]/2`G9&%T92<I('Q\"B`@("`@
M("`@("`@("AI<U]S=6)C;&%S<U]O9B@D9&%T92PG9&%T92<I*2D*("`@("`@
M("`I('L*("`@("`@("`@("`@)'1H:7,M/F-O<'DH)&1A=&4I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS971$871E*"1D871E*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&9I96QD
M<R!O9B!A($1A=&4@;V)J96-T(&)A<V5D(&]N('1H92!I;G!U="!D871E(&%N
M9"!F;W)M870*("`@("`J"B`@("`@*B!3970@=&AE(&9I96QD<R!O9B!A($1A
M=&4@;V)J96-T(&)A<V5D(&]N('1H92!I;G!U="!D871E(&%N9"!F;W)M870L
M"B`@("`@*B!W:&EC:"!I<R!S<&5C:69I960@8GD@=&AE($1!5$5?1D]234%4
M7RH@8V]N<W1A;G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D871E(&EN<'5T(&1A=&4*("`@("`J($!P
M87)A;2!I;G0@)&9O<FUA="!/<'1I;VYA;"!F;W)M870@8V]N<W1A;G0@*$1!
M5$5?1D]234%47RHI(&]F('1H92!I;G!U="!D871E+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@(%1H:7,@<&%R86UE=&5R(&ES;B=T(')E86QL>2!N965D
M960@86YY;6]R92P@8G5T('EO=2!C;W5L9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@('5S92!I="!T;R!F;W)C92!$051%7T9/4DU!5%]53DE85$E-12X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&%T92@D9&%T92P@)&9O<FUA="`]
M($1!5$5?1D]234%47TE33RD*("`@('L*"B`@("`@("`@:68@*`H@("`@("`@
M("`@("!P<F5G7VUA=&-H*"<O7BA<9'LT?2DM/RA<9'LR?2DM/RA<9'LR?2DH
M6U1<<UT_*%QD>S)]*3H_*%QD>S)]*3H_*%QD>S)]*2A:?%M<*UPM75QD>S)]
M.C]<9'LR?2D_*3\D+VDG+"`D9&%T92P@)')E9W,I"B`@("`@("`@("`@("8F
M("1F;W)M870@(3T@1$%415]&3U)-051?54Y)6%1)344I('L*("`@("`@("`@
M("`@+R\@1$%415]&3U)-051?25-/+"!)4T]?0D%324,L($E33U]%6%1%3D1%
M1"P@86YD(%1)34535$%-4`H@("`@("`@("`@("`O+R!4:&5S92!F;W)M871S
M(&%R92!E>'1R96UE;'D@8VQO<V4@=&\@96%C:"!O=&AE<BX@(%1H:7,@<F5G
M97@*("`@("`@("`@("`@+R\@:7,@=F5R>2!L;V]S92!A;F0@86-C97!T<R!A
M;&UO<W0@86YY(&)U=&-H97)E9"!F;W)M870@>6]U(&-O=6QD"B`@("`@("`@
M("`@("\O('1H<F]W(&%T(&ET+B`@92YG+B`R,#`S+3$P+3`W(#$Y.C0U.C$U
M(&%N9"`R,#`S+3$P,#<Q.30U.C$U"B`@("`@("`@("`@("\O(&%R92!T:&4@
M<V%M92!T:&EN9R!I;B!T:&4@97EE<R!O9B!T:&ES(')E9V5X+"!E=F5N('1H
M;W5G:"!T:&4*("`@("`@("`@("`@+R\@;&%T=&5R(&ES(&YO="!A('9A;&ED
M($E33R`X-C`Q(&1A=&4N"B`@("`@("`@("`@("1T:&ES+3YY96%R("`@/2`D
M<F5G<ULQ73L*("`@("`@("`@("`@)'1H:7,M/FUO;G1H("`]("1R96=S6S)=
M.PH@("`@("`@("`@("`D=&AI<RT^9&%Y("`@(#T@)')E9W-;,UT["B`@("`@
M("`@("`@("1T:&ES+3YH;W5R("`@/2!I<W-E="@D<F5G<ULU72D_)')E9W-;
M-5TZ,#L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T92`](&ES<V5T*"1R96=S
M6S9=*3\D<F5G<ULV73HP.PH@("`@("`@("`@("`D=&AI<RT^<V5C;VYD(#T@
M:7-S970H)')E9W-;-UTI/R1R96=S6S==.C`["@H@("`@("`@("`@("`O+R!I
M9B!A;B!O9F9S970@:7,@9&5F:6YE9"P@8V]N=F5R="!T:6UE('1O(%540PH@
M("`@("`@("`@("`O+R!$871E(&-U<G)E;G1L>2!C86XG="!S970@82!T:6UE
M>F]N92!O;FQY(&)Y(&]F9G-E="P*("`@("`@("`@("`@+R\@<V\@:70@:&%S
M('1O('-T;W)E(&ET(&%S(%540PH@("`@("`@("`@("!I9B`H:7-S970H)')E
M9W-;.%TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^=&]55$-B>4]F9G-E
M="@D<F5G<ULX72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H
M:7-?;G5M97)I8R@D9&%T92DI('L*("`@("`@("`@("`@+R\@54Y)6%1)344*
M("`@("`@("`@("`@)'1H:7,M/G-E=$1A=&4H9&%T92@B62UM+60@2#II.G,B
M+"`D9&%T92DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O('5N
M:VYO=VX@9F]R;6%T"B`@("`@("`@("`@("1T:&ES+3YY96%R("`@/2`P.PH@
M("`@("`@("`@("`D=&AI<RT^;6]N=&@@(#T@,3L*("`@("`@("`@("`@)'1H
M:7,M/F1A>2`@("`](#$["B`@("`@("`@("`@("1T:&ES+3YH;W5R("`@/2`P
M.PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E(#T@,#L*("`@("`@("`@("`@
M)'1H:7,M/G-E8V]N9"`](#`["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&$@<W1R:6YG("AO<B!O=&AE<BD@<F5P<F5S96YT871I;VX@
M;V8@=&AI<R!D871E"B`@("`@*@H@("`@("H@1V5T(&$@<W1R:6YG("AO<B!O
M=&AE<BD@<F5P<F5S96YT871I;VX@;V8@=&AI<R!D871E(&EN('1H90H@("`@
M("H@9F]R;6%T('-P96-I9FEE9"!B>2!T:&4@1$%415]&3U)-051?*B!C;VYS
M=&%N=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P
M87)A;2!I;G0@)&9O<FUA="!F;W)M870@8V]N<W1A;G0@*$1!5$5?1D]234%4
M7RHI(&]F('1H92!O=71P=70@9&%T90H@("`@("H@0')E='5R;B!S=')I;F<@
M=&AE(&1A=&4@:6X@=&AE(')E<75E<W1E9"!F;W)M870*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1&%T92@D9F]R;6%T(#T@1$%415]&3U)-051?25-/*0H@
M("`@>PH@("`@("`@('-W:71C:"`H)&9O<FUA="D@>PH@("`@("`@(&-A<V4@
M1$%415]&3U)-051?25-/.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9O
M<FUA="@B)5DM)6TM)60@)50B*3L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@8V%S92!$051%7T9/4DU!5%])4T]?0D%324,Z"B`@("`@("`@("`@("1F
M;W)M870@/2`B)5DE;25D5"5()4TE4R(["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^='HM/F=E=$E$*"D@/3T@)U540R<I('L*("`@("`@("`@("`@("`@("1F
M;W)M870@+CT@(EHB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^9F]R;6%T*"1F;W)M870I.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!C87-E($1!5$5?1D]234%47TE33U]%6%1%3D1%1#H*("`@("`@
M("`@("`@)&9O<FUA="`]("(E62TE;2TE9%0E2#HE33HE4R(["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^='HM/F=E=$E$*"D@/3T@)U540R<I('L*("`@("`@
M("`@("`@("`@("1F;W)M870@+CT@(EHB.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9F]R;6%T*"1F;W)M870I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!C87-E($1!5$5?1D]234%47U1)34535$%-
M4#H*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF;W)M870H(B59)6TE9"5(
M)4TE4R(I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E($1!5$5?
M1D]234%47U5.25A424U%.@H@("`@("`@("`@("!R971U<FX@;6MT:6UE*"1T
M:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E+"`D=&AI<RT^<V5C;VYD+"`D=&AI
M<RT^;6]N=&@L("1T:&ES+3YD87DL("1T:&ES+3YY96%R*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]P
M>2!V86QU97,@9G)O;2!A;F]T:&5R($1A=&4@;V)J96-T"B`@("`@*@H@("`@
M("H@36%K97,@=&AI<R!$871E(&$@8V]P>2!O9B!A;F]T:&5R($1A=&4@;V)J
M96-T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R
M86T@;V)J96-T($1A=&4@)&1A=&4@1&%T92!T;R!C;W!Y(&9R;VT*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]P>2@D9&%T92D*("`@('L*("`@("`@("`D=&AI
M<RT^>65A<B`]("1D871E+3YY96%R.PH@("`@("`@("1T:&ES+3YM;VYT:"`]
M("1D871E+3YM;VYT:#L*("`@("`@("`D=&AI<RT^9&%Y(#T@)&1A=&4M/F1A
M>3L*("`@("`@("`D=&AI<RT^:&]U<B`]("1D871E+3YH;W5R.PH@("`@("`@
M("1T:&ES+3YM:6YU=&4@/2`D9&%T92T^;6EN=71E.PH@("`@("`@("1T:&ES
M+3YS96-O;F0@/2`D9&%T92T^<V5C;VYD.PH@("`@("`@("1T:&ES+3YT>B`]
M("1D871E+3YT>CL*("`@('T*"B`@("`O*BH*("`@("`J("!$871E('!R971T
M>2!P<FEN=&EN9RP@<VEM:6QA<B!T;R!S=')F=&EM92@I"B`@("`@*@H@("`@
M("H@($9O<FUA=',@=&AE(&1A=&4@:6X@=&AE(&=I=F5N(&9O<FUA="P@;75C
M:"!L:6ME"B`@("`@*B`@<W1R9G1I;64H*2X@($UO<W0@<W1R9G1I;64H*2!O
M<'1I;VYS(&%R92!S=7!P;W)T960N/&)R/CQB<CX*("`@("`J"B`@("`@*B`@
M9F]R;6%T=&EN9R!O<'1I;VYS.CQB<CX\8G(^"B`@("`@*@H@("`@("H@(#QC
M;V1E/B5A("`\+V-O9&4^("!A8F)R979I871E9"!W965K9&%Y(&YA;64@*%-U
M;BP@36]N+"!4=64I(#QB<CX*("`@("`J("`\8V]D93XE02`@/"]C;V1E/B`@
M9G5L;"!W965K9&%Y(&YA;64@*%-U;F1A>2P@36]N9&%Y+"!4=65S9&%Y*2`\
M8G(^"B`@("`@*B`@/&-O9&4^)6(@(#PO8V]D93X@(&%B8G)E=FEA=&5D(&UO
M;G1H(&YA;64@*$IA;BP@1F5B+"!-87(I(#QB<CX*("`@("`J("`\8V]D93XE
M0B`@/"]C;V1E/B`@9G5L;"!M;VYT:"!N86UE("A*86YU87)Y+"!&96)R=6%R
M>2P@36%R8V@I(#QB<CX*("`@("`J("`\8V]D93XE0R`@/"]C;V1E/B`@8V5N
M='5R>2!N=6UB97(@*'1H92!Y96%R(&1I=FED960@8GD@,3`P(&%N9"!T<G5N
M8V%T960@=&\@86X@:6YT96=E<BP@<F%N9V4@,#`@=&\@.3DI(#QB<CX*("`@
M("`J("`\8V]D93XE9"`@/"]C;V1E/B`@9&%Y(&]F(&UO;G1H("AR86YG92`P
M,"!T;R`S,2D@/&)R/@H@("`@("H@(#QC;V1E/B5$("`\+V-O9&4^("!S86UE
M(&%S("(E;2\E9"\E>2(@/&)R/@H@("`@("H@(#QC;V1E/B5E("`\+V-O9&4^
M("!D87D@;V8@;6]N=&@L('-I;F=L92!D:6=I="`H<F%N9V4@,"!T;R`S,2D@
M/&)R/@H@("`@("H@(#QC;V1E/B5%("`\+V-O9&4^("!N=6UB97(@;V8@9&%Y
M<R!S:6YC92!U;G-P96-I9FEE9"!E<&]C:"`H:6YT96=E<BP@1&%T95]#86QC
M.CID871E5&]$87ES*"DI(#QB<CX*("`@("`J("`\8V]D93XE2"`@/"]C;V1E
M/B`@:&]U<B!A<R!D96-I;6%L(&YU;6)E<B`H,#`@=&\@,C,I(#QB<CX*("`@
M("`J("`\8V]D93XE22`@/"]C;V1E/B`@:&]U<B!A<R!D96-I;6%L(&YU;6)E
M<B!O;B`Q,BUH;W5R(&-L;V-K("@P,2!T;R`Q,BD@/&)R/@H@("`@("H@(#QC
M;V1E/B5J("`\+V-O9&4^("!D87D@;V8@>65A<B`H<F%N9V4@,#`Q('1O(#,V
M-BD@/&)R/@H@("`@("H@(#QC;V1E/B5M("`\+V-O9&4^("!M;VYT:"!A<R!D
M96-I;6%L(&YU;6)E<B`H<F%N9V4@,#$@=&\@,3(I(#QB<CX*("`@("`J("`\
M8V]D93XE32`@/"]C;V1E/B`@;6EN=71E(&%S(&$@9&5C:6UA;"!N=6UB97(@
M*#`P('1O(#4Y*2`\8G(^"B`@("`@*B`@/&-O9&4^)6X@(#PO8V]D93X@(&YE
M=VQI;F4@8VAA<F%C=&5R("A<;BD@/&)R/@H@("`@("H@(#QC;V1E/B5/("`\
M+V-O9&4^("!D<W0M8V]R<F5C=&5D('1I;65Z;VYE(&]F9G-E="!E>'!R97-S
M960@87,@(BLO+4A(.DU-(B`\8G(^"B`@("`@*B`@/&-O9&4^)6\@(#PO8V]D
M93X@(')A=R!T:6UE>F]N92!O9F9S970@97AP<F5S<V5D(&%S("(K+RU(2#I-
M32(@/&)R/@H@("`@("H@(#QC;V1E/B5P("`\+V-O9&4^("!E:71H97(@)V%M
M)R!O<B`G<&TG(&1E<&5N9&EN9R!O;B!T:&4@=&EM92`\8G(^"B`@("`@*B`@
M/&-O9&4^)5`@(#PO8V]D93X@(&5I=&AE<B`G04TG(&]R("=032<@9&5P96YD
M:6YG(&]N('1H92!T:6UE(#QB<CX*("`@("`J("`\8V]D93XE<B`@/"]C;V1E
M/B`@=&EM92!I;B!A;2]P;2!N;W1A=&EO;BP@<V%M92!A<R`B)4DZ)4TZ)5,@
M)7`B(#QB<CX*("`@("`J("`\8V]D93XE4B`@/"]C;V1E/B`@=&EM92!I;B`R
M-"UH;W5R(&YO=&%T:6]N+"!S86UE(&%S("(E2#HE32(@/&)R/@H@("`@("H@
M(#QC;V1E/B53("`\+V-O9&4^("!S96-O;F1S(&%S(&$@9&5C:6UA;"!N=6UB
M97(@*#`P('1O(#4Y*2`\8G(^"B`@("`@*B`@/&-O9&4^)70@(#PO8V]D93X@
M('1A8B!C:&%R86-T97(@*%QT*2`\8G(^"B`@("`@*B`@/&-O9&4^)50@(#PO
M8V]D93X@(&-U<G)E;G0@=&EM92P@<V%M92!A<R`B)4@Z)4TZ)5,B(#QB<CX*
M("`@("`J("`\8V]D93XE=R`@/"]C;V1E/B`@=V5E:V1A>2!A<R!D96-I;6%L
M("@P(#T@4W5N9&%Y*2`\8G(^"B`@("`@*B`@/&-O9&4^)54@(#PO8V]D93X@
M('=E96L@;G5M8F5R(&]F(&-U<G)E;G0@>65A<BP@9FER<W0@<W5N9&%Y(&%S
M(&9I<G-T('=E96L@/&)R/@H@("`@("H@(#QC;V1E/B5Y("`\+V-O9&4^("!Y
M96%R(&%S(&1E8VEM86P@*')A;F=E(#`P('1O(#DY*2`\8G(^"B`@("`@*B`@
M/&-O9&4^)5D@(#PO8V]D93X@('EE87(@87,@9&5C:6UA;"!I;F-L=61I;F<@
M8V5N='5R>2`H<F%N9V4@,#`P,"!T;R`Y.3DY*2`\8G(^"B`@("`@*B`@/&-O
M9&4^)24@(#PO8V]D93X@(&QI=&5R86P@)R4G(#QB<CX*("`@("`J(#QB<CX*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M('-T
M<FEN9R!F;W)M870@=&AE(&9O<FUA="!S=')I;F<@9F]R(')E='5R;F5D(&1A
M=&4O=&EM90H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92]T:6UE(&EN(&=I
M=F5N(&9O<FUA=`H@("`@("HO"B`@("!F=6YC=&EO;B!F;W)M870H)&9O<FUA
M="D*("`@('L*("`@("`@("`D;W5T<'5T(#T@(B(["@H@("`@("`@(&9O<B@D
M<W1R<&]S(#T@,#L@)'-T<G!O<R`\('-T<FQE;B@D9F]R;6%T*3L@)'-T<G!O
M<RLK*2!["B`@("`@("`@("`@("1C:&%R(#T@<W5B<W1R*"1F;W)M870L)'-T
M<G!O<RPQ*3L*("`@("`@("`@("`@:68@*"1C:&%R(#T]("(E(BD@>PH@("`@
M("`@("`@("`@("`@)&YE>'1C:&%R(#T@<W5B<W1R*"1F;W)M870L)'-T<G!O
M<R`K(#$L,2D["B`@("`@("`@("`@("`@("!S=VET8V@@*"1N97AT8VAA<BD@
M>PH@("`@("`@("`@("`@("`@8V%S92`B82(Z"B`@("`@("`@("`@("`@("`@
M("`@)&]U='!U="`N/2!$871E7T-A;&,Z.F=E=%=E96MD87E!8F)R;F%M92@D
M=&AI<RT^9&%Y+"1T:&ES+3YM;VYT:"PD=&AI<RT^>65A<BD["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")!(CH*
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9V5T
M5V5E:V1A>49U;&QN86UE*"1T:&ES+3YD87DL)'1H:7,M/FUO;G1H+"1T:&ES
M+3YY96%R*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(F(B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@1&%T95]#86QC.CIG971-;VYT:$%B8G)N86UE*"1T:&ES+3YM;VYT:"D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E(")"(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?
M0V%L8SHZ9V5T36]N=&A&=6QL;F%M92@D=&AI<RT^;6]N=&@I.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B0R(Z
M"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E,#)D
M(BQI;G1V86PH)'1H:7,M/GEE87(O,3`P*2D["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")D(CH*("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0B+"1T:&ES+3YD
M87DI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@8V%S92`B1"(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S
M<')I;G1F*"(E,#)D+R4P,F0O)3`R9"(L)'1H:7,M/FUO;G1H+"1T:&ES+3YD
M87DL)'1H:7,M/GEE87(I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@8V%S92`B92(Z"B`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2`D=&AI<RT^9&%Y("H@,3L@+R\@9V5T(')I9"!O9B!L96%D
M:6YG('IE<F\*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(D4B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@1&%T95]#86QC.CID871E5&]$87ES*"1T:&ES+3YD87DL)'1H:7,M/FUO
M;G1H+"1T:&ES+3YY96%R*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@(&-A<V4@(D@B.@H@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@<W!R:6YT9B@B)3`R9"(L("1T:&ES+3YH;W5R*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@
M(DDB.@H@("`@("`@("`@("`@("`@("`@("1H;W5R(#T@*"1T:&ES+3YH;W5R
M("L@,2D@/B`Q,B`_("1T:&ES+3YH;W5R("T@,3(@.B`D=&AI<RT^:&]U<CL*
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0B
M+"`D:&]U<CT],"`_(#$R(#H@)&AO=7(I.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B:B(Z"B`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z.FIU;&EA;D1A=&4H)'1H
M:7,M/F1A>2PD=&AI<RT^;6]N=&@L)'1H:7,M/GEE87(I.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B;2(Z"B`@
M("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E,#)D(BPD
M=&AI<RT^;6]N=&@I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B32(Z"B`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!S<')I;G1F*"(E,#)D(BPD=&AI<RT^;6EN=71E*3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(FXB
M.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@(EQN(CL*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(D\B
M.@H@("`@("`@("`@("`@("`@("`@("1O9F9M<R`]("1T:&ES+3YT>BT^9V5T
M3V9F<V5T*"1T:&ES*3L*("`@("`@("`@("`@("`@("`@("`D9&ER96-T:6]N
M(#T@)&]F9FUS(#X](#`@/R`B*R(@.B`B+2(["B`@("`@("`@("`@("`@("`@
M("`@)&]F9FUI;G,@/2!A8G,H)&]F9FUS*2`O(#$P,#`@+R`V,#L*("`@("`@
M("`@("`@("`@("`@("`D:&]U<G,@/2`D;V9F;6EN<R`O(#8P.PH@("`@("`@
M("`@("`@("`@("`@("1M:6YU=&5S(#T@)&]F9FUI;G,@)2`V,#L*("`@("`@
M("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B5S)3`R9#HE,#)D
M(BP@)&1I<F5C=&EO;BP@)&AO=7)S+"`D;6EN=71E<RD["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")O(CH*("`@
M("`@("`@("`@("`@("`@("`D;V9F;7,@/2`D=&AI<RT^='HM/F=E=%)A=T]F
M9G-E="@D=&AI<RD["B`@("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO;B`]
M("1O9F9M<R`^/2`P(#\@(BLB(#H@(BTB.PH@("`@("`@("`@("`@("`@("`@
M("1O9F9M:6YS(#T@86)S*"1O9F9M<RD@+R`Q,#`P("\@-C`["B`@("`@("`@
M("`@("`@("`@("`@)&AO=7)S(#T@)&]F9FUI;G,@+R`V,#L*("`@("`@("`@
M("`@("`@("`@("`D;6EN=71E<R`]("1O9F9M:6YS("4@-C`["B`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E<R4P,F0Z)3`R9"(L
M("1D:7)E8W1I;VXL("1H;W5R<RP@)&UI;G5T97,I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B<"(Z"B`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^:&]U<B`^/2`Q,B`_
M(")P;2(@.B`B86TB.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B4"(Z"B`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2`D=&AI<RT^:&]U<B`^/2`Q,B`_(")032(@.B`B04TB.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B
M<B(Z"B`@("`@("`@("`@("`@("`@("`@)&AO=7(@/2`H)'1H:7,M/FAO=7(@
M*R`Q*2`^(#$R(#\@)'1H:7,M/FAO=7(@+2`Q,B`Z("1T:&ES+3YH;W5R.PH@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)3`R9#HE
M,#)D.B4P,F0@)7,B+"`D:&]U<CT],"`_("`Q,B`Z("1H;W5R+"`D=&AI<RT^
M;6EN=71E+"`D=&AI<RT^<V5C;VYD+"`D=&AI<RT^:&]U<B`^/2`Q,B`_(")0
M32(@.B`B04TB*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@(&-A<V4@(E(B.@H@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@<W!R:6YT9B@B)3`R9#HE,#)D(BP@)'1H:7,M/FAO=7(L("1T:&ES
M+3YM:6YU=&4I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@8V%S92`B4R(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2!S<')I;G1F*"(E,#)D(BP@)'1H:7,M/G-E8V]N9"D["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")T(CH*
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X](")<="(["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")4(CH*
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0Z
M)3`R9#HE,#)D(BP@)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU=&4L("1T:&ES
M+3YS96-O;F0I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@8V%S92`B=R(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D=&AI<RT^9&%Y+"1T:&ES+3YM
M;VYT:"PD=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!C87-E(")5(CH*("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ=V5E:T]F665A<B@D=&AI<RT^9&%Y
M+"1T:&ES+3YM;VYT:"PD=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")Y(CH*("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]('-U8G-T<B@D=&AI<RT^>65A<BPR+#(I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M8V%S92`B62(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI
M<RT^>65A<CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(EHB.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@)'1H:7,M/G1Z+3YI;D1A>6QI9VAT5&EM92@D=&AI<RD@/R`D=&AI<RT^
M='HM/F=E=$135%-H;W)T3F%M92@I(#H@)'1H:7,M/G1Z+3YG9713:&]R=$YA
M;64H*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@(&-A<V4@(B4B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M(B4B.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1C
M:&%R+B1N97AT8VAA<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1S=')P;W,K*SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@)&-H87(["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1O=71P=70["@H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T('1H:7,@9&%T92]T:6UE(&EN(%5N:7@@=&EM92@I(&9O<FUA
M=`H@("`@("H*("`@("`J($=E="!A(')E<')E<V5N=&%T:6]N(&]F('1H:7,@
M9&%T92!I;B!5;FEX('1I;64H*2!F;W)M870N("!4:&ES(&UA>2!O;FQY(&)E
M"B`@("`@*B!V86QI9"!F;W(@9&%T97,@9G)O;2`Q.3<P('1O('XR,#,X+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN
M="!N=6UB97(@;V8@<V5C;VYD<R!S:6YC92!T:&4@=6YI>"!E<&]C:`H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9714:6UE*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/F=E=$1A=&4H1$%415]&3U)-051?54Y)6%1)344I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@=&EM92!Z;VYE(&]F('1H:7,@
M1&%T90H@("`@("H*("`@("`J(%-E=',@=&AE('1I;64@>F]N92!O9B!T:&ES
M(&1A=&4@=VET:"!T:&4@9VEV96X*("`@("`J($1A=&5?5&EM95IO;F4@;V)J
M96-T+B`@1&]E<R!N;W0@86QT97(@=&AE(&1A=&4O=&EM92P*("`@("`J(&]N
M;'D@87-S:6=N<R!A(&YE=R!T:6UE('IO;F4N("!&;W(@8V]N=F5R<VEO;BP@
M=7-E"B`@("`@*B!C;VYV97)T5%HH*2X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E7U1I;65:;VYE("1T
M>B!T:&4@1&%T95]4:6UE6F]N92!O8FIE8W0@=&\@=7-E+"!I9B!C86QL960@
M"B`@("`@*B!W:71H(&$@<&%R86UA=&5R('1H870@:7,@;F]T(&$@1&%T95]4
M:6UE6F]N92!O8FIE8W0L('=I;&P@9F%L;"!T:')O=6=H('1O"B`@("`@*B!S
M97146F)Y240H*2X@"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1:*"1T>BD*
M("`@('L*("`@(`EI9BAI<U]A*"1T>BP@)V1A=&5?=&EM97IO;F4G*2D@>PH@
M("`@("`@(`DD=&AI<RT^='H@/2`D='H["B`@("`)?2!E;'-E('L*("`@(`D)
M)'1H:7,M/G-E=%1:8GE)1"@D='HI.PH@("`@"7T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E=',@=&AE('1I;64@>F]N92!O9B!T:&ES(&1A=&4@=VET:"!T
M:&4@9VEV96X@=&EM92!Z;VYE(&ED"B`@("`@*@H@("`@("H@4V5T<R!T:&4@
M=&EM92!Z;VYE(&]F('1H:7,@9&%T92!W:71H('1H92!G:79E;@H@("`@("H@
M=&EM92!Z;VYE(&ED+"!O<B!T;R!T:&4@<WES=&5M(&1E9F%U;'0@:68@=&AE
M"B`@("`@*B!G:79E;B!I9"!I<R!I;G9A;&ED+B!$;V5S(&YO="!A;'1E<B!T
M:&4@9&%T92]T:6UE+`H@("`@("H@;VYL>2!A<W-I9VYS(&$@;F5W('1I;64@
M>F]N92X@($9O<B!C;VYV97)S:6]N+"!U<V4*("`@("`J(&-O;G9E<G146B@I
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&ED(&$@=&EM92!Z;VYE(&ED"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=%1:8GE)1"@D:60I"B`@("!["B`@("`@("`@:68@*$1A=&5?5&EM95IO
M;F4Z.FES5F%L:61)1"@D:60I*2!["B`@("`@("`@("`@("1T:&ES+3YT>B`]
M(&YE=R!$871E7U1I;65:;VYE*"1I9"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/G1Z(#T@1&%T95]4:6UE6F]N93HZ9V5T1&5F875L
M="@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1E<W1S(&EF
M('1H:7,@9&%T92]T:6UE(&ES(&EN($135`H@("`@("H*("`@("`J(%)E='5R
M;G,@=')U92!I9B!D87EL:6=H="!S879I;F=S('1I;64@:7,@:6X@969F96-T
M(&9O<@H@("`@("H@=&AI<R!D871E(&EN('1H:7,@9&%T92=S('1I;64@>F]N
M92X@(%-E92!$871E7U1I;65:;VYE.CII;D1A>6QI9VAT5&EM92@I"B`@("`@
M*B!F;W(@8V]M<&%T86)I;&ET>2!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@
M:68@1%-4(&ES(&EN(&5F9F5C="!F;W(@=&AI<R!D871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&EN1&%Y;&EG:'14:6UE*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/G1Z+3YI;D1A>6QI9VAT5&EM92@D=&AI<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T<R!T:&ES(&1A=&4@=&\@551#(&%N9"!S
M971S('1H:7,@9&%T92=S('1I;65Z;VYE('1O(%540PH@("`@("H*("`@("`J
M($-O;G9E<G1S('1H:7,@9&%T92!T;R!55$,@86YD('-E=',@=&AI<R!D871E
M)W,@=&EM97IO;F4@=&\@551#"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&]55$,H*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^='HM/F=E=$]F9G-E="@D=&AI<RD@/B`P*2!["B`@("`@
M("`@("`@("1T:&ES+3YS=6)T<F%C=%-E8V]N9',H:6YT=F%L*"1T:&ES+3YT
M>BT^9V5T3V9F<V5T*"1T:&ES*2`O(#$P,#`I*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^861D4V5C;VYD<RAI;G1V86PH86)S*"1T
M:&ES+3YT>BT^9V5T3V9F<V5T*"1T:&ES*2D@+R`Q,#`P*2D["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3YT>B`](&YE=R!$871E7U1I;65:;VYE*"=55$,G
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1H:7,@9&%T92!T
M;R!A(&YE=R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!#;VYV97)T<R!T:&ES
M(&1A=&4@=&\@82!N97<@=&EM92!Z;VYE+@H@("`@("H@5T%23DE.1SH@5&AI
M<R!M87D@;F]T('=O<FL@8V]R<F5C=&QY(&EF('EO=7(@<WES=&5M(&1O97,@
M;F]T(&%L;&]W"B`@("`@*B!P=71E;G8H*2!O<B!I9B!L;V-A;'1I;64H*2!D
M;V5S(&YO="!W;W)K(&EN('EO=7(@96YV:7)O;FUE;G0N("!3964*("`@("`J
M($1A=&4Z.E1I;65:;VYE.CII;D1A>6QI9VAT5&EM92@I(&9O<B!M;W)E(&EN
M9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<&%R86T@;V)J96-T($1A=&5?5&EM95IO;F4@)'1Z('1H92!$871E.CI4
M:6UE6F]N92!O8FIE8W0@9F]R('1H92!C;VYV97)S:6]N('1I;64@>F]N90H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T5%HH)'1Z*0H@("`@>PH@("`@
M("`@("\O(&-O;G9E<G0@=&\@551#"B`@("`@("`@:68@*"1T:&ES+3YT>BT^
M9V5T3V9F<V5T*"1T:&ES*2`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/G-U
M8G1R86-T4V5C;VYD<RAI;G1V86PH86)S*"1T:&ES+3YT>BT^9V5T3V9F<V5T
M*"1T:&ES*2D@+R`Q,#`P*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/F%D9%-E8V]N9',H:6YT=F%L*&%B<R@D=&AI<RT^='HM/F=E
M=$]F9G-E="@D=&AI<RDI("\@,3`P,"DI.PH@("`@("`@('T*("`@("`@("`O
M+R!C;VYV97)T(%540R!T;R!N97<@=&EM97IO;F4*("`@("`@("!I9B`H)'1Z
M+3YG971/9F9S970H)'1H:7,I(#X@,"D@>PH@("`@("`@("`@("`D=&AI<RT^
M861D4V5C;VYD<RAI;G1V86PH86)S*"1T>BT^9V5T3V9F<V5T*"1T:&ES*2D@
M+R`Q,#`P*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/G-U8G1R86-T4V5C;VYD<RAI;G1V86PH86)S*"1T>BT^9V5T3V9F<V5T*"1T
M:&ES*2D@+R`Q,#`P*2D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YT>B`]
M("1T>CL*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1H:7,@9&%T
M92!T;R!A(&YE=R!T:6UE('IO;F4L(&=I=F5N(&$@=F%L:60@=&EM92!Z;VYE
M($E$"B`@("`@*@H@("`@("H@0V]N=F5R=',@=&AI<R!D871E('1O(&$@;F5W
M('1I;64@>F]N92P@9VEV96X@82!V86QI9"!T:6UE('IO;F4@240*("`@("`J
M(%=!4DY)3D<Z(%1H:7,@;6%Y(&YO="!W;W)K(&-O<G)E8W1L>2!I9B!Y;W5R
M('-Y<W1E;2!D;V5S(&YO="!A;&QO=PH@("`@("H@<'5T96YV*"D@;W(@:68@
M;&]C86QT:6UE*"D@9&]E<R!N;W0@=V]R:R!I;B!Y;W5R(&5N=FER;VYM96YT
M+B`@4V5E"B`@("`@*B!$871E.CI4:6UE6F]N93HZ:6Y$87EL:6=H=%1I;64H
M*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'!A<F%M('-T<FEN9R!I9"!A('1I;64@>F]N92!I
M9`H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T5%IB>4E$*"1I9"D*("`@
M('L*("`@("`@(&EF("A$871E7U1I;65:;VYE.CII<U9A;&ED240H)&ED*2D@
M>PH@("`@("`@("`@)'1Z(#T@;F5W($1A=&5?5&EM95IO;F4H)&ED*3L*("`@
M("`@('T@96QS92!["B`@("`@("`@("`D='H@/2!$871E7U1I;65:;VYE.CIG
M971$969A=6QT*"D["B`@("`@("!]"B`@("`@("`D=&AI<RT^8V]N=F5R=%1:
M*"1T>BD["B`@("!]"@H@("`@9G5N8W1I;VX@=&]55$-B>4]F9G-E="@D;V9F
M<V5T*0H@("`@>PH@("`@("`@(&EF("@D;V9F<V5T(#T]("):(B!\?"`D;V9F
M<V5T(#T]("(K,#`Z,#`B('Q\("1O9F9S970@/3T@(BLP,#`P(BD@>PH@("`@
M("`@("`@("`D=&AI<RT^=&]55$,H*3L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H*("`@("`@("!I9B`H<')E9U]M871C:"@G+RA;7"M<
M+5TI*%QD>S)]*3H_*%QD>S)]*2\G+"`D;V9F<V5T+"`D<F5G<RDI('L*("`@
M("`@("`@("`@+R\@8V]N=F5R="!O9F9S970@=&\@<V5C;VYD<PH@("`@("`@
M("`@("`D:&]U<G,@(#T@*&EN="D@:7-S970H)')E9W-;,ETI/R1R96=S6S)=
M.C`["B`@("`@("`@("`@("1M:6YS("`@/2`H:6YT*2!I<W-E="@D<F5G<ULS
M72D_)')E9W-;,UTZ,#L*("`@("`@("`@("`@)&]F9G-E="`]("@D:&]U<G,@
M*B`S-C`P*2`K("@D;6EN<R`J(#8P*3L*"B`@("`@("`@("`@(&EF("AI<W-E
M="@D<F5G<ULQ72D@)B8@)')E9W-;,5T@/3T@(BTB*2!["B`@("`@("`@("`@
M("`@("`D;V9F<V5T("H]("TQ.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H)&]F9G-E="`^(#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M=6)T<F%C=%-E8V]N9',H:6YT=F%L*"1O9F9S970I*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1396-O;F1S*&EN
M='9A;"AA8G,H)&]F9G-E="DI*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'1H:7,M/G1Z(#T@;F5W($1A=&5?5&EM95IO;F4H)U540R<I.PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!G:79E;B!N
M=6UB97(@;V8@<V5C;VYD<R!T;R!T:&4@9&%T90H@("`@("H*("`@("`J($%D
M9',@82!G:79E;B!N=6UB97(@;V8@<V5C;VYD<R!T;R!T:&4@9&%T90H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@:6YT("1S
M96,@=&AE(&YU;6)E<B!O9B!S96-O;F1S('1O(&%D9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&1396-O;F1S*"1S96,I"B`@("!["B`@("`@("`@)'1H:7,M
M/F%D9%-P86XH;F5W($1A=&5?4W!A;B@H:6YT96=E<BDD<V5C*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@=&EM92!S<&%N('1O('1H92!D871E
M"B`@("`@*@H@("`@("H@061D<R!A('1I;64@<W!A;B!T;R!T:&4@9&%T90H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J
M96-T($1A=&5?4W!A;B`D<W!A;B!T:&4@=&EM92!S<&%N('1O(&%D9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&13<&%N*"1S<&%N*0H@("`@>PH@("`@("`@
M("1T:&ES+3YS96-O;F0@*ST@)'-P86XM/G-E8V]N9#L*("`@("`@("!I9B`H
M)'1H:7,M/G-E8V]N9"`^/2`V,"D@>PH@("`@("`@("`@("`D=&AI<RT^;6EN
M=71E*RL["B`@("`@("`@("`@("1T:&ES+3YS96-O;F0@+3T@-C`["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^;6EN=71E("L]("1S<&%N+3YM:6YU=&4[
M"B`@("`@("`@:68@*"1T:&ES+3YM:6YU=&4@/CT@-C`I('L*("`@("`@("`@
M("`@)'1H:7,M/FAO=7(K*SL*("`@("`@("`@("`@:68@*"1T:&ES+3YH;W5R
M(#X](#(T*2!["B`@("`@("`@("`@("`@("!L:7-T*"1T:&ES+3YY96%R+"`D
M=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*("`@("`@("`@("`@("`@("`@
M("!S<V-A;F8H1&%T95]#86QC.CIN97AT1&%Y*"1T:&ES+3YD87DL("1T:&ES
M+3YM;VYT:"P@)'1H:7,M/GEE87(I+"`B)3`T<R4P,G,E,#)S(BD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^:&]U<B`M/2`R-#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^;6EN=71E("T](#8P.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/FAO=7(@*ST@)'-P86XM/FAO=7(["B`@("`@("`@:68@
M*"1T:&ES+3YH;W5R(#X](#(T*2!["B`@("`@("`@("`@(&QI<W0H)'1H:7,M
M/GEE87(L("1T:&ES+3YM;VYT:"P@)'1H:7,M/F1A>2D@/0H@("`@("`@("`@
M("`@("`@<W-C86YF*$1A=&5?0V%L8SHZ;F5X=$1A>2@D=&AI<RT^9&%Y+"`D
M=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*2P@(B4P-',E,#)S)3`R<R(I.PH@
M("`@("`@("`@("`D=&AI<RT^:&]U<B`M/2`R-#L*("`@("`@("!]"@H@("`@
M("`@("1D(#T@1&%T95]#86QC.CID871E5&]$87ES*"1T:&ES+3YD87DL("1T
M:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@("`@("1D("L]("1S<&%N
M+3YD87D["@H@("`@("`@(&QI<W0H)'1H:7,M/GEE87(L("1T:&ES+3YM;VYT
M:"P@)'1H:7,M/F1A>2D@/0H@("`@("`@("`@("!S<V-A;F8H1&%T95]#86QC
M.CID87ES5&]$871E*"1D*2P@(B4P-',E,#)S)3`R<R(I.PH@("`@("`@("1T
M:&ES+3YY96%R("`](&EN='9A;"@D=&AI<RT^>65A<BD["B`@("`@("`@)'1H
M:7,M/FUO;G1H(#T@:6YT=F%L*"1T:&ES+3YM;VYT:"D["B`@("`@("`@)'1H
M:7,M/F1A>2`@(#T@:6YT=F%L*"1T:&ES+3YD87DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4W5B=')A8W1S(&$@9VEV96X@;G5M8F5R(&]F('-E8V]N9',@
M9G)O;2!T:&4@9&%T90H@("`@("H*("`@("`J(%-U8G1R86-T<R!A(&=I=F5N
M(&YU;6)E<B!O9B!S96-O;F1S(&9R;VT@=&AE(&1A=&4*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&EN="`D<V5C('1H92!N
M=6UB97(@;V8@<V5C;VYD<R!T;R!S=6)T<F%C=`H@("`@("HO"B`@("!F=6YC
M=&EO;B!S=6)T<F%C=%-E8V]N9',H)'-E8RD*("`@('L*("`@("`@("`D=&AI
M<RT^<W5B=')A8W13<&%N*&YE=R!$871E7U-P86XH)'-E8RDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4W5B=')A8W1S(&$@=&EM92!S<&%N('1O('1H92!D
M871E"B`@("`@*@H@("`@("H@4W5B=')A8W1S(&$@=&EM92!S<&%N('1O('1H
M92!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P
M87)A;2!O8FIE8W0@1&%T95]3<&%N("1S<&%N('1H92!T:6UE('-P86X@=&\@
M<W5B=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<W5B=')A8W13<&%N*"1S
M<&%N*0H@("`@>PH@("`@("`@("1T:&ES+3YS96-O;F0@+3T@)'-P86XM/G-E
M8V]N9#L*("`@("`@("!I9B`H)'1H:7,M/G-E8V]N9"`\(#`I('L*("`@("`@
M("`@("`@)'1H:7,M/FUI;G5T92TM.PH@("`@("`@("`@("`D=&AI<RT^<V5C
M;VYD("L](#8P.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FUI;G5T92`M
M/2`D<W!A;BT^;6EN=71E.PH@("`@("`@(&EF("@D=&AI<RT^;6EN=71E(#P@
M,"D@>PH@("`@("`@("`@("`D=&AI<RT^:&]U<BTM.PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/FAO=7(@/"`P*2!["B`@("`@("`@("`@("`@("!L:7-T*"1T
M:&ES+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*("`@("`@
M("`@("`@("`@("`@("!S<V-A;F8H1&%T95]#86QC.CIP<F5V1&%Y*"1T:&ES
M+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I+"`B)3`T<R4P,G,E
M,#)S(BD["B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`K/2`R-#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^;6EN=71E("L](#8P.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/FAO=7(@+3T@)'-P86XM/FAO=7([
M"B`@("`@("`@:68@*"1T:&ES+3YH;W5R(#P@,"D@>PH@("`@("`@("`@("!L
M:7-T*"1T:&ES+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*
M("`@("`@("`@("`@("`@('-S8V%N9BA$871E7T-A;&,Z.G!R979$87DH)'1H
M:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BDL("(E,#1S)3`R
M<R4P,G,B*3L*("`@("`@("`@("`@)'1H:7,M/FAO=7(@*ST@,C0["B`@("`@
M("`@?0H*("`@("`@("`D9"`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D=&AI
M<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*("`@("`@("`D
M9"`M/2`D<W!A;BT^9&%Y.PH*("`@("`@("!L:7-T*"1T:&ES+3YY96%R+"`D
M=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*("`@("`@("`@("`@<W-C86YF
M*$1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9"DL("(E,#1S)3`R<R4P,G,B*3L*
M("`@("`@("`D=&AI<RT^>65A<B`@/2!I;G1V86PH)'1H:7,M/GEE87(I.PH@
M("`@("`@("1T:&ES+3YM;VYT:"`](&EN='9A;"@D=&AI<RT^;6]N=&@I.PH@
M("`@("`@("1T:&ES+3YD87D@("`](&EN='9A;"@D=&AI<RT^9&%Y*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-O;7!A<F5S('1W;R!D871E<PH@("`@("H*
M("`@("`J($-O;7!A<F5S('1W;R!D871E<RX@(%-U:71A8FQE(&9O<B!U<V4*
M("`@("`J(&EN('-O<G1I;F<@9G5N8W1I;VYS+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&4@)&0Q('1H
M92!F:7)S="!D871E"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&4@)&0R('1H
M92!S96-O;F0@9&%T90H@("`@("H@0')E='5R;B!I;G0@,"!I9B!T:&4@9&%T
M97,@87)E(&5Q=6%L+"`M,2!I9B!D,2!I<R!B969O<F4@9#(L(#$@:68@9#$@
M:7,@869T97(@9#(*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<&%R92@D9#$L
M("1D,BD*("`@('L*("`@("`@("`D9#$M/F-O;G9E<G146BAN97<@1&%T95]4
M:6UE6F]N92@G551#)RDI.PH@("`@("`@("1D,BT^8V]N=F5R=%1:*&YE=R!$
M871E7U1I;65:;VYE*"=55$,G*2D["B`@("`@("`@)&1A>7,Q(#T@1&%T95]#
M86QC.CID871E5&]$87ES*"1D,2T^9&%Y+"`D9#$M/FUO;G1H+"`D9#$M/GEE
M87(I.PH@("`@("`@("1D87ES,B`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D
M9#(M/F1A>2P@)&0R+3YM;VYT:"P@)&0R+3YY96%R*3L*("`@("`@("!I9B`H
M)&1A>7,Q(#P@)&1A>7,R*2!R971U<FX@+3$["B`@("`@("`@:68@*"1D87ES
M,2`^("1D87ES,BD@<F5T=7)N(#$["B`@("`@("`@:68@*"1D,2T^:&]U<B`\
M("1D,BT^:&]U<BD@<F5T=7)N("TQ.PH@("`@("`@(&EF("@D9#$M/FAO=7(@
M/B`D9#(M/FAO=7(I(')E='5R;B`Q.PH@("`@("`@(&EF("@D9#$M/FUI;G5T
M92`\("1D,BT^;6EN=71E*2!R971U<FX@+3$["B`@("`@("`@:68@*"1D,2T^
M;6EN=71E(#X@)&0R+3YM:6YU=&4I(')E='5R;B`Q.PH@("`@("`@(&EF("@D
M9#$M/G-E8V]N9"`\("1D,BT^<V5C;VYD*2!R971U<FX@+3$["B`@("`@("`@
M:68@*"1D,2T^<V5C;VYD(#X@)&0R+3YS96-O;F0I(')E='5R;B`Q.PH@("`@
M("`@(')E='5R;B`P.PH@("`@?0H*("`@("\J*@H@("`@("H@5&5S="!I9B!T
M:&ES(&1A=&4O=&EM92!I<R!B969O<F4@82!C97)T86EN(&1A=&4O=&EM90H@
M("`@("H*("`@("`J(%1E<W0@:68@=&AI<R!D871E+W1I;64@:7,@8F5F;W)E
M(&$@8V5R=&%I;B!D871E+W1I;64*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E("1W:&5N('1H92!D871E
M('1O('1E<W0@86=A:6YS=`H@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@
M:68@=&AI<R!D871E(&ES(&)E9F]R92`D=VAE;@H@("`@("HO"B`@("!F=6YC
M=&EO;B!B969O<F4H)'=H96XI"B`@("!["B`@("`@("`@:68@*$1A=&4Z.F-O
M;7!A<F4H)'1H:7,L)'=H96XI(#T]("TQ*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!497-T(&EF
M('1H:7,@9&%T92]T:6UE(&ES(&%F=&5R(&$@8V5R=&EA;B!D871E+W1I;64*
M("`@("`J"B`@("`@*B!497-T(&EF('1H:7,@9&%T92]T:6UE(&ES(&%F=&5R
M(&$@8V5R=&EA;B!D871E+W1I;64*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E("1W:&5N('1H92!D871E
M('1O('1E<W0@86=A:6YS=`H@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@
M:68@=&AI<R!D871E(&ES(&%F=&5R("1W:&5N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%F=&5R*"1W:&5N*0H@("`@>PH@("`@("`@(&EF("A$871E.CIC;VUP
M87)E*"1T:&ES+"1W:&5N*2`]/2`Q*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!497-T(&EF('1H
M:7,@9&%T92]T:6UE(&ES(&5X86-T;'D@97%U86P@=&\@82!C97)T:6%N(&1A
M=&4O=&EM90H@("`@("H*("`@("`J(%1E<W0@:68@=&AI<R!D871E+W1I;64@
M:7,@97AA8W1L>2!E<75A;"!T;R!A(&-E<G1I86X@9&%T92]T:6UE"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@
M1&%T92`D=VAE;B!T:&4@9&%T92!T;R!T97-T(&%G86EN<W0*("`@("`J($!R
M971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@9&%T92!I<R!E>&%C=&QY(&5Q
M=6%L('1O("1W:&5N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5Q=6%L<R@D=VAE
M;BD*("`@('L*("`@("`@("!I9B`H1&%T93HZ8V]M<&%R92@D=&AI<RPD=VAE
M;BD@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF('1H:7,@9&%T92!I
M<R!I;B!T:&4@9G5T=7)E"B`@("`@*@H@("`@("H@1&5T97)M:6YE(&EF('1H
M:7,@9&%T92!I<R!I;B!T:&4@9G5T=7)E"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@
M9&%T92!I<R!I;B!T:&4@9G5T=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M1G5T=7)E*"D*("`@('L*("`@("`@("`D;F]W(#T@;F5W($1A=&4H*3L*("`@
M("`@("!I9B`H)'1H:7,M/F%F=&5R*"1N;W<I*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E
M<FUI;F4@:68@=&AI<R!D871E(&ES(&EN('1H92!P87-T"B`@("`@*@H@("`@
M("H@1&5T97)M:6YE(&EF('1H:7,@9&%T92!I<R!I;B!T:&4@<&%S=`H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@=')U92!I9B!T:&ES(&1A=&4@:7,@:6X@=&AE('!A<W0*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-087-T*"D*("`@('L*("`@("`@("`D;F]W(#T@;F5W
M($1A=&4H*3L*("`@("`@("!I9B`H)'1H:7,M/F)E9F]R92@D;F]W*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE(&EF('1H92!Y96%R(&EN('1H:7,@9&%T92!I
M<R!A(&QE87`@>65A<@H@("`@("H*("`@("`J($1E=&5R;6EN92!I9B!T:&4@
M>65A<B!I;B!T:&ES(&1A=&4@:7,@82!L96%P('EE87(*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@
M:68@=&AI<R!Y96%R(&ES(&$@;&5A<"!Y96%R"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES3&5A<%EE87(H*0H@("`@>PH@("`@("`@(')E='5R;B!$871E7T-A
M;&,Z.FES3&5A<%EE87(H)'1H:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T('1H92!*=6QI86X@9&%T92!F;W(@=&AI<R!D871E"B`@("`@
M*@H@("`@("H@1V5T('1H92!*=6QI86X@9&%T92!F;W(@=&AI<R!D871E"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT
M('1H92!*=6QI86X@9&%T90H@("`@("HO"B`@("!F=6YC=&EO;B!G971*=6QI
M86Y$871E*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#86QC.CIJ=6QI
M86Y$871E*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@9&%Y(&]F('1H92!W
M965K(&9O<B!T:&ES(&1A=&4*("`@("`J"B`@("`@*B!'971S('1H92!D87D@
M;V8@=&AE('=E96L@9F]R('1H:7,@9&%T92`H,#U3=6YD87DI"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!D
M87D@;V8@=&AE('=E96L@*#`]4W5N9&%Y*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$87E/9E=E96LH*0H@("`@>PH@("`@("`@(')E='5R;B!$871E7T-A
M;&,Z.F1A>4]F5V5E:R@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES
M+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE('=E96L@
M;V8@=&AE('EE87(@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J($=E=',@
M=&AE('=E96L@;V8@=&AE('EE87(@9F]R('1H:7,@9&%T90H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@=V5E
M:R!O9B!T:&4@>65A<@H@("`@("HO"B`@("!F=6YC=&EO;B!G9717965K3V99
M96%R*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#86QC.CIW965K3V99
M96%R*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@<75A<G1E<B!O9B!T:&4@
M>65A<B!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@1V5T<R!T:&4@<75A
M<G1E<B!O9B!T:&4@>65A<B!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!Q=6%R=&5R
M(&]F('1H92!Y96%R("@Q+30I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U
M87)T97)/9EEE87(H*0H@("`@>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z
M.G%U87)T97)/9EEE87(H)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI
M<RT^>65A<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@
M("H@1V5T<R!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@@9F]R('1H:7,@
M9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N(&EN="!N=6UB97(@;V8@9&%Y<R!I;B!T:&ES(&UO;G1H"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$1A>7-);DUO;G1H*"D*("`@('L*("`@("`@("!R
M971U<FX@1&%T95]#86QC.CID87ES26Y-;VYT:"@D=&AI<RT^;6]N=&@L("1T
M:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU
M;6)E<B!O9B!W965K<R!I;B!T:&4@;6]N=&@@9F]R('1H:7,@9&%T90H@("`@
M("H*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!W965K<R!I;B!T:&4@;6]N
M=&@@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N(&EN="!N=6UB97(@;V8@=V5E:W,@:6X@=&AI<R!M
M;VYT:`H@("`@("HO"B`@("!F=6YC=&EO;B!G9717965K<TEN36]N=&@H*0H@
M("`@>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@D
M=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE(&9U;&P@;F%M92!O<B!A8F)R:79I871E9"!N86UE(&]F
M('1H:7,@=V5E:V1A>0H@("`@("H*("`@("`J($=E=',@=&AE(&9U;&P@;F%M
M92!O<B!A8F)R:79I871E9"!N86UE(&]F('1H:7,@=V5E:V1A>0H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M86)B<B!A8F)R:79A=&4@=&AE(&YA;64*("`@("`J($!R971U<FX@<W1R:6YG
M(&YA;64@;V8@=&AI<R!D87D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%Y
M3F%M92@D86)B<B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D86)B<BD@
M>PH@("`@("`@("`@("!R971U<FX@1&%T95]#86QC.CIG9717965K9&%Y06)B
M<FYA;64H)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N($1A=&5?0V%L
M8SHZ9V5T5V5E:V1A>49U;&QN86UE*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT
M:"P@)'1H:7,M/GEE87(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE(&9U;&P@;F%M92!O<B!A8F)R:79I871E9"!N86UE(&]F
M('1H:7,@;6]N=&@*("`@("`J"B`@("`@*B!'971S('1H92!F=6QL(&YA;64@
M;W(@86)B<FEV:6%T960@;F%M92!O9B!T:&ES(&UO;G1H"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!B;V]L96%N("1A8F)R
M(&%B8G)I=F%T92!T:&4@;F%M90H@("`@("H@0')E='5R;B!S=')I;F<@;F%M
M92!O9B!T:&ES(&UO;G1H"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UO;G1H
M3F%M92@D86)B<B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D86)B<BD@
M>PH@("`@("`@("`@("!R971U<FX@1&%T95]#86QC.CIG971-;VYT:$%B8G)N
M86UE*"1T:&ES+3YM;VYT:"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N($1A=&5?0V%L8SHZ9V5T36]N=&A&=6QL;F%M92@D=&AI<RT^
M;6]N=&@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M($1A=&4@;V)J96-T(&9O<B!T:&4@9&%Y(&%F=&5R('1H:7,@;VYE"B`@("`@
M*@H@("`@("H@1V5T(&$@1&%T92!O8FIE8W0@9F]R('1H92!D87D@869T97(@
M=&AI<R!O;F4N"B`@("`@*B!4:&4@=&EM92!O9B!T:&4@<F5T=7)N960@1&%T
M92!O8FIE8W0@:7,@=&AE('-A;64@87,@=&AI<R!T:6UE+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&]B:F5C="!$871E
M($1A=&4@<F5P<F5S96YT:6YG('1H92!N97AT(&1A>0H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971.97AT1&%Y*"D*("`@('L*("`@("`@("`D9&%Y(#T@1&%T
M95]#86QC.CIN97AT1&%Y*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H
M:7,M/GEE87(L("(E62TE;2TE9"(I.PH@("`@("`@("1D871E(#T@<W!R:6YT
M9B@B)7,@)3`R9#HE,#)D.B4P,F0B+"`D9&%Y+"`D=&AI<RT^:&]U<BP@)'1H
M:7,M/FUI;G5T92P@)'1H:7,M/G-E8V]N9"D["B`@("`@("`@)&YE=T1A=&4@
M/2!N97<@1&%T92@I.PH@("`@("`@("1N97=$871E+3YS971$871E*"1D871E
M*3L*("`@("`@("!R971U<FX@)&YE=T1A=&4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@82!$871E(&]B:F5C="!F;W(@=&AE(&1A>2!B969O<F4@=&AI
M<R!O;F4*("`@("`J"B`@("`@*B!'970@82!$871E(&]B:F5C="!F;W(@=&AE
M(&1A>2!B969O<F4@=&AI<R!O;F4N"B`@("`@*B!4:&4@=&EM92!O9B!T:&4@
M<F5T=7)N960@1&%T92!O8FIE8W0@:7,@=&AE('-A;64@87,@=&AI<R!T:6UE
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="!$871E($1A=&4@<F5P<F5S96YT:6YG('1H92!P<F5V:6]U<R!D
M87D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')E=D1A>2@I"B`@("!["B`@
M("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ<')E=D1A>2@D=&AI<RT^9&%Y+"`D
M=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R+"`B)5DM)6TM)60B*3L*("`@("`@
M("`D9&%T92`]('-P<FEN=&8H(B5S("4P,F0Z)3`R9#HE,#)D(BP@)&1A>2P@
M)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU=&4L("1T:&ES+3YS96-O;F0I.PH@
M("`@("`@("1N97=$871E(#T@;F5W($1A=&4H*3L*("`@("`@("`D;F5W1&%T
M92T^<V5T1&%T92@D9&%T92D["B`@("`@("`@<F5T=7)N("1N97=$871E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@1&%T92!O8FIE8W0@9F]R('1H
M92!W965K9&%Y(&%F=&5R('1H:7,@;VYE"B`@("`@*@H@("`@("H@1V5T(&$@
M1&%T92!O8FIE8W0@9F]R('1H92!W965K9&%Y(&%F=&5R('1H:7,@;VYE+@H@
M("`@("H@5&AE('1I;64@;V8@=&AE(')E='5R;F5D($1A=&4@;V)J96-T(&ES
M('1H92!S86UE(&%S('1H:7,@=&EM92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0')E='5R;B!O8FIE8W0@1&%T92!$871E(')E<')E
M<V5N=&EN9R!T:&4@;F5X="!W965K9&%Y"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$YE>'17965K9&%Y*"D*("`@('L*("`@("`@("`D9&%Y(#T@1&%T95]#
M86QC.CIN97AT5V5E:V1A>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T
M:&ES+3YY96%R+"`B)5DM)6TM)60B*3L*("`@("`@("`D9&%T92`]('-P<FEN
M=&8H(B5S("4P,F0Z)3`R9#HE,#)D(BP@)&1A>2P@)'1H:7,M/FAO=7(L("1T
M:&ES+3YM:6YU=&4L("1T:&ES+3YS96-O;F0I.PH@("`@("`@("1N97=$871E
M(#T@;F5W($1A=&4H*3L*("`@("`@("`D;F5W1&%T92T^<V5T1&%T92@D9&%T
M92D["B`@("`@("`@<F5T=7)N("1N97=$871E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&$@1&%T92!O8FIE8W0@9F]R('1H92!W965K9&%Y(&)E9F]R
M92!T:&ES(&]N90H@("`@("H*("`@("`J($=E="!A($1A=&4@;V)J96-T(&9O
M<B!T:&4@=V5E:V1A>2!B969O<F4@=&AI<R!O;F4N"B`@("`@*B!4:&4@=&EM
M92!O9B!T:&4@<F5T=7)N960@1&%T92!O8FIE8W0@:7,@=&AE('-A;64@87,@
M=&AI<R!T:6UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<F5T=7)N(&]B:F5C="!$871E($1A=&4@<F5P<F5S96YT:6YG('1H92!P
M<F5V:6]U<R!W965K9&%Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R9797
M965K9&%Y*"D*("`@('L*("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CIP<F5V
M5V5E:V1A>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R
M+"`B)5DM)6TM)60B*3L*("`@("`@("`D9&%T92`]('-P<FEN=&8H(B5S("4P
M,F0Z)3`R9#HE,#)D(BP@)&1A>2P@)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU
M=&4L("1T:&ES+3YS96-O;F0I.PH@("`@("`@("1N97=$871E(#T@;F5W($1A
M=&4H*3L*("`@("`@("`D;F5W1&%T92T^<V5T1&%T92@D9&%T92D["B`@("`@
M("`@<F5T=7)N("1N97=$871E.PH@("`@?0H*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE('EE87(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@
M*@H@("`@("H@4F5T=7)N<R!T:&4@>65A<B!F:65L9"!O9B!T:&4@9&%T92!O
M8FIE8W0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E
M='5R;B!I;G0@=&AE('EE87(*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T665A
M<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YY96%R.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;6]N=&@@9FEE;&0@;V8@=&AE
M(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@;6]N=&@@
M9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!M;VYT:`H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971-;VYT:"@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YM;VYT:#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&1A>2!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@
M*B!2971U<FYS('1H92!D87D@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT
M('1H92!D87D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%Y*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/F1A>3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&AO=7(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T
M"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@:&]U<B!F:65L9"!O9B!T:&4@
M9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0')E='5R;B!I;G0@=&AE(&AO=7(*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T2&]U<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YH;W5R.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;6EN=71E(&9I96QD
M(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%)E='5R;G,@=&AE
M(&UI;G5T92!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@=&AE(&UI;G5T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!G971-:6YU=&4H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^;6EN=71E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<V5C;VYD(&9I96QD(&]F('1H92!D871E(&]B:F5C
M=`H@("`@("H*("`@("`J(%)E='5R;G,@=&AE('-E8V]N9"!F:65L9"!O9B!T
M:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0')E='5R;B!I;G0@=&AE('-E8V]N9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971396-O;F0H*0H@("`@>PH@("`@("`@("!R971U<FX@)'1H:7,M
M/G-E8V]N9#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@>65A<B!F
M:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!3970@=&AE
M('EE87(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T+"!I;G9A;&ED('EE87)S
M("AN;W0@,"TY.3DY*2!A<F4@<V5T('1O(#`N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!I;G0@)'D@=&AE('EE87(*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T665A<B@D>2D*("`@('L*("`@("`@("!I
M9B`H)'D@/"`P('Q\("1Y(#X@.3DY.2D@>PH@("`@("`@("`@("`D=&AI<RT^
M>65A<B`](#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/GEE87(@/2`D>3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M970@=&AE(&UO;G1H(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*
M("`@("`J(%-E="!T:&4@;6]N=&@@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T
M+"!I;G9A;&ED(&UO;G1H<R`H;F]T(#$M,3(I(&%R92!S970@=&\@,2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&EN="`D
M;2!T:&4@;6]N=&@*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T36]N=&@H)&TI
M"B`@("!["B`@("`@("`@:68@*"1M(#P@,2!\?"`D;2`^(#$R*2!["B`@("`@
M("`@("`@("1T:&ES+3YM;VYT:"`](#$["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/FUO;G1H(#T@)&T["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T('1H92!D87D@9FEE;&0@;V8@=&AE(&1A=&4@
M;V)J96-T"B`@("`@*@H@("`@("H@4V5T('1H92!D87D@9FEE;&0@;V8@=&AE
M(&1A=&4@;V)J96-T+"!I;G9A;&ED(&1A>7,@*&YO="`Q+3,Q*2!A<F4@<V5T
M('1O(#$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P
M87)A;2!I;G0@)&0@=&AE(&1A>0H@("`@("HO"B`@("!F=6YC=&EO;B!S971$
M87DH)&0I"B`@("!["B`@("`@("`@:68@*"1D(#X@,S$@?'P@)&0@/"`Q*2![
M"B`@("`@("`@("`@("1T:&ES+3YD87D@/2`Q.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YD87D@/2`D9#L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&AO=7(@9FEE;&0@;V8@=&AE(&1A
M=&4@;V)J96-T"B`@("`@*@H@("`@("H@4V5T('1H92!H;W5R(&9I96QD(&]F
M('1H92!D871E(&]B:F5C="!I;B`R-"UH;W5R(&9O<FUA="X*("`@("`J($EN
M=F%L:60@:&]U<G,@*&YO="`P+3(S*2!A<F4@<V5T('1O(#`N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!I;G0@)&@@=&AE
M(&AO=7(*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2&]U<B@D:"D*("`@('L*
M("`@("`@("!I9B`H)&@@/B`R,R!\?"`D:"`\(#`I('L*("`@("`@("`@("`@
M)'1H:7,M/FAO=7(@/2`P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3YH;W5R(#T@)&@["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T('1H92!M:6YU=&4@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T
M"B`@("`@*@H@("`@("H@4V5T('1H92!M:6YU=&4@9FEE;&0@;V8@=&AE(&1A
M=&4@;V)J96-T+"!I;G9A;&ED(&UI;G5T97,@*&YO="`P+34Y*2!A<F4@<V5T
M('1O(#`N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P
M87)A;2!I;G0@)&T@=&AE(&UI;G5T90H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971-:6YU=&4H)&TI"B`@("!["B`@("`@("`@:68@*"1M(#X@-3D@?'P@)&T@
M/"`P*2!["B`@("`@("`@("`@("1T:&ES+3YM:6YU=&4@/2`P.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YM:6YU=&4@/2`D;3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('-E8V]N9"!F
M:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!3970@=&AE
M('-E8V]N9"!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0L(&EN=F%L:60@<V5C
M;VYD<R`H;F]T(#`M-3DI(&%R92!S970@=&\@,"X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&EN="`D<R!T:&4@<V5C;VYD
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-E8V]N9"@D<RD@>PH@("`@("`@
M(&EF("@D<R`^(#4Y('Q\("1S(#P@,"D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5C;VYD(#T@,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^<V5C;VYD(#T@)',["B`@("`@("`@?0H@("`@?0H*?2`O+R!$871E"@H*
M+R\*+R\@14Y$"C\^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B],;V<N<&AP````````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`T,S<W-@`Q,#0Q-S,V,S`P-P`P,38V,30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9RYP
M:'`L=B`Q+C0U(#(P,#0O,#$O,3D@,#@Z,#(Z,S@@:F]N($5X<"`D"B`J("1(
M;W)D93H@:&]R9&4O;&EB+TQO9RYP:'`L=B`Q+C$U(#(P,#`O,#8O,CD@,C,Z
M,SDZ-#4@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@,2XT
M-2`D"B`J($!P86-K86=E($QO9PH@*B\*"F1E9FEN92@G4$5!4E],3T=?14U%
M4D<G+"`@("`P*3L@("`@("\J*B!3>7-T96T@:7,@=6YU<V%B;&4@*B\*9&5F
M:6YE*"=014%27TQ/1U]!3$525"<L("`@(#$I.R`@("`@+RHJ($EM;65D:6%T
M92!A8W1I;VX@<F5Q=6ER960@*B\*9&5F:6YE*"=014%27TQ/1U]#4DE4)RP@
M("`@(#(I.R`@("`@+RHJ($-R:71I8V%L(&-O;F1I=&EO;G,@*B\*9&5F:6YE
M*"=014%27TQ/1U]%4E(G+"`@("`@(#,I.R`@("`@+RHJ($5R<F]R(&-O;F1I
M=&EO;G,@*B\*9&5F:6YE*"=014%27TQ/1U]705).24Y')RP@(#0I.R`@("`@
M+RHJ(%=A<FYI;F<@8V]N9&ET:6]N<R`J+PID969I;F4H)U!%05)?3$]'7TY/
M5$E#12<L("`@-2D[("`@("`O*BH@3F]R;6%L(&)U="!S:6=N:69I8V%N="`J
M+PID969I;F4H)U!%05)?3$]'7TE.1D\G+"`@("`@-BD[("`@("`O*BH@26YF
M;W)M871I;VYA;"`J+PID969I;F4H)U!%05)?3$]'7T1%0E5')RP@("`@-RD[
M("`@("`O*BH@1&5B=6<M;&5V96P@;65S<V%G97,@*B\*"F1E9FEN92@G4$5!
M4E],3T=?04Q,)RP@("`@("!B:6YD96,H)S$Q,3$Q,3$Q)RDI.R`@+RHJ($%L
M;"!M97-S86=E<R`J+PID969I;F4H)U!%05)?3$]'7TY/3D4G+"`@("`@8FEN
M9&5C*"<P,#`P,#`P,"<I*3L@("\J*B!.;R!M97-S86=E("HO"@HO*B!,;V<@
M='EP97,@9F]R(%!(4"=S(&YA=&EV92!E<G)O<E]L;V<H*2!F=6YC=&EO;BX@
M*B\*9&5F:6YE*"=014%27TQ/1U]465!%7U-94U1%32<L("`P*3L@+RHJ(%5S
M92!02%`G<R!S>7-T96T@;&]G9V5R("HO"F1E9FEN92@G4$5!4E],3T=?5%E0
M15]-04E,)RP@("`@,2D[("\J*B!5<V4@4$A0)W,@;6%I;"@I(&9U;F-T:6]N
M("HO"F1E9FEN92@G4$5!4E],3T=?5%E015]$14)51R<L("`@,BD[("\J*B!5
M<V4@4$A0)W,@9&5B=6=G:6YG(&-O;FYE8W1I;VX@*B\*9&5F:6YE*"=014%2
M7TQ/1U]465!%7T9)3$4G+"`@("`S*3L@+RHJ($%P<&5N9"!T;R!A(&9I;&4@
M*B\*"B\J*@H@*B!4:&4@3&]G.CH@8VQA<W,@:6UP;&5M96YT<R!B;W1H(&%N
M(&%B<W1R86-T:6]N(&9O<B!V87)I;W5S(&QO9V=I;F<*("H@;65C:&%N:7-M
M<R!A;F0@=&AE(%-U8FIE8W0@96YD(&]F(&$@4W5B:F5C="U/8G-E<G9E<B!P
M871T97)N+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN
M970^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!,;V<*("HO
M"F-L87-S($QO9PI["B`@("`O*BH*("`@("`J($EN9&EC871E<R!W:&5T:&5R
M(&]R(&YO="!T:&4@;&]G(&-A;B!B965N(&]P96YE9"`O(&-O;FYE8W1E9"X*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]O<&5N960@/2!F86QS93L*"B`@("`O
M*BH*("`@("`J($EN<W1A;F-E+7-P96-I9FEC('5N:7%U92!I9&5N=&EF:6-A
M=&EO;B!N=6UB97(N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?:60@/2`P.PH*
M("`@("\J*@H@("`@("H@5&AE(&QA8F5L('1H870@=6YI<75E;'D@:61E;G1I
M9FEE<R!T:&ES('-E="!O9B!L;V<@;65S<V%G97,N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]I9&5N="`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&1E9F%U
M;'0@<')I;W)I='D@=&\@=7-E('=H96X@;&]G9VEN9R!A;B!E=F5N="X*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]P<FEO<FET>2`](%!%05)?3$]'7TE.1D\[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@8FET;6%S:R!O9B!A;&QO=V5D(&QO9R!L
M979E;',N"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]M87-K(#T@4$5!4E],3T=?04Q,.PH*
M("`@("\J*@H@("`@("H@2&]L9',@86QL($QO9U]O8G-E<G9E<B!O8FIE8W1S
M('1H870@=VES:"!T;R!B92!N;W1I9FEE9"!O9B!N97<@;65S<V%G97,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7VQI<W1E;F5R<R`](&%R<F%Y*"D["@H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@3&]G
M(&EN<W1A;F-E(&]F('1Y<&4@)&AA;F1L97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:&%N9&QE<B`@(%1H92!T>7!E(&]F(&-O;F-R971E($QO
M9R!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@071T96UP="!T;R!D>6YA;6EC86QL>2!I;F-L=61E('1H92!C
M;V1E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@
M<W5B8VQA<W,N($-U<G)E;G1L>2P@=F%L:60@=F%L=65S(&%R90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYS;VQE)RP@)W-Y<VQO9R<L
M("=S<6PG+"`G9FEL92<L(&%N9"`G;6-A;"<N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@(%1H92!N86UE(&]F('1H92!A8W1U86QL
M>2!L;V<@9FEL92P@=&%B;&4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@;W1H97(@<W!E8VEF:6,@<W1O<F4@=&\@=7-E+B!$969A=6QT
M<R!T;R!A;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&5M<'1Y
M('-T<FEN9RP@=VET:"!W:&EC:"!T:&4@<W5B8VQA<W,@=VEL;`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%T=&5M<'0@=&\@9&\@<V]M971H
M:6YG(&EN=&5L;&EG96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED96YT("`@("!4:&4@:61E;G1I='D@<F5P;W)T960@=&\@=&AE(&QO9R!S
M>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8V]N9B`@("`@
M($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO
M;B!T:&%T(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT("1L979E;"`@("`@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N
M9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="!,;V<@("`@("`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@
M3&]G(&EN<W1A;F-E+"!O<B!A;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!S:6YC92!,;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1H86YD;&5R+"`D;F%M92`]("<G+"`D:61E;G0@/2`G)RP@
M)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L
M(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)&AA;F1L97(@/2!S
M=')T;VQO=V5R*"1H86YD;&5R*3L*("`@("`@("`D8VQA<W,@/2`G3&]G7R<@
M+B`D:&%N9&QE<CL*("`@("`@("`D8VQA<W-F:6QE(#T@)TQO9R\G("X@)&AA
M;F1L97(@+B`G+G!H<"<["@H@("`@("`@("\J"B`@("`@("`@("H@071T96UP
M="!T;R!I;F-L=61E(&]U<B!V97)S:6]N(&]F('1H92!N86UE9"!C;&%S<RP@
M8G5T(&1O;B=T('1R96%T"B`@("`@("`@("H@82!F86EL=7)E(&%S(&9A=&%L
M+B`@5&AE(&-A;&QE<B!M87D@:&%V92!A;')E861Y(&EN8VQU9&5D('1H96ER
M(&]W;@H@("`@("`@("`J('9E<G-I;VX@;V8@=&AE(&YA;65D(&-L87-S+@H@
M("`@("`@("`J+PH@("`@("`@($!I;F-L=61E7V]N8V4@)&-L87-S9FEL93L*
M"B`@("`@("`@+RH@268@=&AE(&-L87-S(&5X:7-T<RP@<F5T=7)N(&$@;F5W
M(&EN<W1A;F-E(&]F(&ET+B`J+PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H
M)&-L87-S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W("1C;&%S<R@D;F%M
M92P@)&ED96YT+"`D8V]N9BP@)&QE=F5L*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($QO9R!I;G-T
M86YC92!O9B!T>7!E"B`@("`@*B`D:&%N9&QE<BP@;VYL>2!C<F5A=&EN9R!A
M(&YE=R!I;G-T86YC92!I9B!N;R!L;V<@:6YS=&%N8V4@=VET:"!T:&4@<V%M
M90H@("`@("H@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*
M("`@("`J(%EO=2!S:&]U;&0@=7-E('1H:7,@:68@=&AE<F4@87)E(&UU;'1I
M<&QE('!L86-E<R!Y;W4@;6EG:'0@8W)E871E(&$*("`@("`J(&QO9V=E<BP@
M>6]U(&1O;B=T('=A;G0@=&\@8W)E871E(&UU;'1I<&QE(&QO9V=E<G,L(&%N
M9"!Y;W4@9&]N)W0@=V%N="!T;PH@("`@("H@8VAE8VL@9F]R('1H92!E>&ES
M=&%N8V4@;V8@;VYE(&5A8V@@=&EM92X@5&AE('-I;F=L971O;B!P871T97)N
M(&1O97,@86QL"B`@("`@*B!T:&4@8VAE8VMI;F<@=V]R:R!F;W(@>6]U+@H@
M("`@("H*("`@("`J(#QB/EEO=2!-55-4(&-A;&P@=&AI<R!M971H;V0@=VET
M:"!T:&4@)'9A<B`]("9,;V<Z.G-I;F=L971O;B@I('-Y;G1A>"X*("`@("`J
M(%=I=&AO=70@=&AE(&%M<&5R<V%N9"`H)BD@:6X@9G)O;G0@;V8@=&AE(&UE
M=&AO9"!N86UE+"!Y;W4@=VEL;"!N;W0@9V5T"B`@("`@*B!A(')E9F5R96YC
M92P@>6]U('=I;&P@9V5T(&$@8V]P>2X\+V(^"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:&%N9&QE<B`@(%1H92!T>7!E(&]F(&-O;F-R971E($QO
M9R!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@071T96UP="!T;R!D>6YA;6EC86QL>2!I;F-L=61E('1H92!C
M;V1E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@
M<W5B8VQA<W,N($-U<G)E;G1L>2P@=F%L:60@=F%L=65S(&%R90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYS;VQE)RP@)W-Y<VQO9R<L
M("=S<6PG+"`G9FEL92<L(&%N9"`G;6-A;"<N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@(%1H92!N86UE(&]F('1H92!A8W1U86QL
M>2!L;V<@9FEL92P@=&%B;&4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@;W1H97(@<W!E8VEF:6,@<W1O<F4@=&\@=7-E+B`@1&5F875L
M=',@=&\@86X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!E;7!T
M>2!S=')I;F<L('=I=&@@=VAI8V@@=&AE('-U8F-L87-S('=I;&P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!A='1E;7!T('1O(&1O('-O;65T
M:&EN9R!I;G1E;&QI9V5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9&5N="`@("`@5&AE(&ED96YT:71Y(')E<&]R=&5D('1O('1H92!L;V<@
M<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("`@
M("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T
M:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:6YF;W)M871I
M;VX@=&AA="!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="`D;&5V96P@("`@("`@($QO9R!M97-S86=E<R!U<"!T;R!A
M;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*@H@("`@("H@0')E='5R
M;B!O8FIE8W0@3&]G("`@("`@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E
M($QO9R!I;G-T86YC92P@;W(@86X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<VEN8V4@3&]G(#$N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B`F<VEN9VQE=&]N*"1H86YD;&5R+"`D;F%M92`]("<G+"`D:61E;G0@/2`G
M)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`D
M;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("!S=&%T:6,@
M)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2`D
M:6YS=&%N8V5S(#T@87)R87DH*3L*"B`@("`@("`@)'-I9VYA='5R92`]('-E
M<FEA;&EZ92AA<G)A>2@D:&%N9&QE<BP@)&YA;64L("1I9&5N="P@)&-O;F8L
M("1L979E;"DI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72`]("9,;V<Z.F9A8W1O<GDH)&AA;F1L97(L("1N86UE+"`D:61E;G0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYF+"`D;&5V96PI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!8G-T<F%C="!I;7!L96UE;G1A=&EO;B!O9B!T:&4@;W!E;B@I(&UE=&AO
M9"X*("`@("`J($!S:6YC92!,;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&]P96XH*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J($%B<W1R86-T(&EM<&QE;65N=&%T:6]N(&]F('1H92!C
M;&]S92@I(&UE=&AO9"X*("`@("`J($!S:6YC92!,;V<@,2XP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8G-T<F%C="!I;7!L96UE;G1A
M=&EO;B!O9B!T:&4@9FQU<V@H*2!M971H;V0N"B`@("`@*B!`<VEN8V4@3&]G
M(#$N."XR"B`@("`@*B\*("`@(&9U;F-T:6]N(&9L=7-H*"D*("`@('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8G-T
M<F%C="!I;7!L96UE;G1A=&EO;B!O9B!T:&4@;&]G*"D@;65T:&]D+@H@("`@
M("H@0'-I;F-E($QO9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M
M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($$@8V]N=F5N:65N8V4@
M9G5N8W1I;VX@9F]R(&QO9V=I;F<@82!E;65R9V5N8WD@979E;G0N("!)="!W
M:6QL(&QO9R!A"B`@("`@*B!M97-S86=E(&%T('1H92!014%27TQ/1U]%3452
M1R!L;V<@;&5V96PN"B`@("`@*@H@("`@("H@0'!A<F%M("`@;6EX960@("`D
M;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE
M<W-A9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@
M;&]G+@H@("`@("H*("`@("`J($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T
M:&4@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@
M("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!E;65R9R@D;65S<V%G92D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?
M14U%4D<I.PH@("`@?0H*("`@("\J*@H@("`@("H@02!C;VYV96YI96YC92!F
M=6YC=&EO;B!F;W(@;&]G9VEN9R!A;B!A;&5R="!E=F5N="X@($ET('=I;&P@
M;&]G(&$*("`@("`J(&UE<W-A9V4@870@=&AE(%!%05)?3$]'7T%,15)4(&QO
M9R!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1M97-S
M86=E("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!L;V<N
M"B`@("`@*@H@("`@("H@0')E='5R;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M
M97-S86=E('=A<R!S=6-C97-S9G5L;'D@;&]G9V5D+@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%L97)T*"1M97-S86=E*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^;&]G*"1M97-S86=E+"!014%27TQ/1U]!3$52
M5"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!(&-O;G9E;FEE;F-E(&9U;F-T
M:6]N(&9O<B!L;V=G:6YG(&$@8W)I=&EC86P@979E;G0N("!)="!W:6QL(&QO
M9R!A"B`@("`@*B!M97-S86=E(&%T('1H92!014%27TQ/1U]#4DE4(&QO9R!L
M979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1M97-S86=E
M("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!L;V<N"B`@
M("`@*@H@("`@("H@0')E='5R;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M97-S
M86=E('=A<R!S=6-C97-S9G5L;'D@;&]G9V5D+@H@("`@("H*("`@("`J($!A
M8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-R:70H)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?3$]'7T-2250I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@02!C;VYV96YI96YC92!F=6YC=&EO;B!F
M;W(@;&]G9VEN9R!A(&5R<F]R(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@
M("H@;65S<V%G92!A="!T:&4@4$5!4E],3T=?15)2(&QO9R!L979E;"X*("`@
M("`J"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1M97-S86=E("`@(%-T<FEN
M9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!L;V<N"B`@("`@*@H@("`@
M("H@0')E='5R;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M97-S86=E('=A<R!S
M=6-C97-S9G5L;'D@;&]G9V5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5R<B@D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?15)2*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@
M82!W87)N:6YG(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@;65S<V%G
M92!A="!T:&4@4$5!4E],3T=?5T%23DE.1R!L;V<@;&5V96PN"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@;6EX960@("`D;65S<V%G92`@("!3=')I;F<@;W(@
M;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*("`@("`J($!R
M971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W87,@<W5C8V5S
M<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!W87)N:6YG*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^;&]G*"1M97-S86=E+"!014%27TQ/1U]705).24Y'*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I
M;F<@82!N;W1I8V4@979E;G0N("!)="!W:6QL(&QO9R!A"B`@("`@*B!M97-S
M86=E(&%T('1H92!014%27TQ/1U].3U1)0T4@;&]G(&QE=F5L+@H@("`@("H*
M("`@("`J($!P87)A;2`@(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R
M(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1O(&QO9RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N("!B;V]L96%N(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S('-U8V-E
M<W-F=6QL>2!L;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F]T:6-E*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^;&]G*"1M97-S86=E+"!014%27TQ/1U].3U1)0T4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@02!C;VYV96YI96YC92!F=6YC=&EO;B!F;W(@;&]G9VEN
M9R!A(&EN9F]R;6%T:6]N(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@
M;65S<V%G92!A="!T:&4@4$5!4E],3T=?24Y&3R!L;V<@;&5V96PN"B`@("`@
M*@H@("`@("H@0'!A<F%M("`@;6EX960@("`D;65S<V%G92`@("!3=')I;F<@
M;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*("`@("`J
M($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W87,@<W5C
M8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!I;F9O*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^;&]G*"1M97-S86=E+"!014%27TQ/1U])3D9/*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@
M82!D96)U9R!E=F5N="X@($ET('=I;&P@;&]G(&$*("`@("`J(&UE<W-A9V4@
M870@=&AE(%!%05)?3$]'7T1%0E5'(&QO9R!L979E;"X*("`@("`J"B`@("`@
M*B!`<&%R86T@("!M:7AE9"`@("1M97-S86=E("`@(%-T<FEN9R!O<B!O8FIE
M8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T;R!L;V<N"B`@("`@*@H@("`@("H@0')E='5R
M;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M97-S86=E('=A<R!S=6-C97-S9G5L
M;'D@;&]G9V5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E
M8G5G*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]G
M*"1M97-S86=E+"!014%27TQ/1U]$14)51RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE
M(&UE<W-A9V4@9&%T82X*("`@("`J"B`@("`@*B!)9B`D;65S<V%G92!I<R!A
M;B!O8FIE8W0L(%]E>'1R86-T365S<V%G92@I('=I;&P@871T96UP="!T;R!E
M>'1R86-T"B`@("`@*B!T:&4@;65S<V%G92!T97AT('5S:6YG(&$@:VYO=VX@
M;65T:&]D("AS=6-H(&%S(&$@4$5!4E]%<G)O<B!O8FIE8W0G<PH@("`@("H@
M9V5T365S<V%G92@I(&UE=&AO9"DN("!)9B!A(&MN;W=N(&UE=&AO9"P@8V%N
M;F]T(&)E(&9O=6YD+"!T:&4*("`@("`J('-E<FEA;&EZ960@<F5P<F5S96YT
M871I;VX@;V8@=&AE(&]B:F5C="!W:6QL(&)E(')E='5R;F5D+@H@("`@("H*
M("`@("`J($EF('1H92!M97-S86=E(&1A=&$@:7,@86QR96%D>2!A('-T<FEN
M9RP@:70@=VEL;"!B92!R971U<FYE9"!U;F-H86YG960N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!M:7AE9"`D;65S<V%G92`@(%1H92!O<FEG:6YA;"!M97-S
M86=E(&1A=&$N("!4:&ES(&UA>2!B92!A"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W1R:6YG(&]R(&%N>2!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@("`@("`@("`@(%1H92!S=')I;F<@<F5P<F5S
M96YT871I;VX@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E>'1R86-T365S<V%G
M92@D;65S<V%G92D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($EF('=E
M)W9E(&)E96X@9VEV96X@86X@;V)J96-T+"!A='1E;7!T('1O(&5X=')A8W0@
M=&AE(&UE<W-A9V4@=7-I;F<*("`@("`@("`@*B!A(&MN;W=N(&UE=&AO9"X@
M($EF('=E(&-A;B=T(&9I;F0@<W5C:"!A(&UE=&AO9"P@9&5F875L="!T;R!T
M:&4*("`@("`@("`@*B`B:'5M86XM<F5A9&%B;&4B('9E<G-I;VX@;V8@=&AE
M(&]B:F5C="X*("`@("`@("`@*@H@("`@("`@("`J(%=E(&%L<V\@=7-E('1H
M92!H=6UA;BUR96%D86)L92!F;W)M870@9F]R(&%R<F%Y<RX*("`@("`@("`@
M*B\*("`@("`@("!I9B`H:7-?;V)J96-T*"1M97-S86=E*2D@>PH@("`@("`@
M("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;65S<V%G92P@)V=E=&UE<W-A9V4G
M*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D;65S<V%G92T^9V5T
M365S<V%G92@I.PH@("`@("`@("`@("!](&5L<V4@:68@*&UE=&AO9%]E>&ES
M=',H)&UE<W-A9V4L("=T;W-T<FEN9R<I*2!["B`@("`@("`@("`@("`@("`D
M;65S<V%G92`]("1M97-S86=E+3YT;U-T<FEN9R@I.PH@("`@("`@("`@("!]
M(&5L<V4@:68@*&UE=&AO9%]E>&ES=',H)&UE<W-A9V4L("=?7W1O<W1R:6YG
M)RDI('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@*'-T<FEN9RDD;65S
M<V%G93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M
M97-S86=E(#T@<')I;G1?<B@D;65S<V%G92P@=')U92D["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@:68@*&ES7V%R<F%Y*"1M97-S86=E*2D@>PH@
M("`@("`@("`@("`D;65S<V%G92`]('!R:6YT7W(H)&UE<W-A9V4L('1R=64I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3W1H97)W:7-E+"!W92!A<W-U;64@
M=&AE(&UE<W-A9V4@:7,@82!S=')I;F<N("HO"B`@("`@("`@<F5T=7)N("1M
M97-S86=E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<W1R
M:6YG(')E<')E<V5N=&%T:6]N(&]F(&$@4$5!4E],3T=?*B!I;G1E9V5R(&-O
M;G-T86YT+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@)'!R:6]R:71Y("`@
M("!!(%!%05)?3$]'7RH@:6YT96=E<B!C;VYS=&%N="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@("`@("`@("`@5&AE('-T<FEN9R!R97!R97-E
M;G1A=&EO;B!O9B`D;&5V96PN"B`@("`@*@H@("`@("H@0'-I;F-E("`@3&]G
M(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!P<FEO<FET>51O4W1R:6YG*"1P
M<FEO<FET>2D*("`@('L*("`@("`@("`D;&5V96QS(#T@87)R87DH"B`@("`@
M("`@("`@(%!%05)?3$]'7T5-15)'("`@/3X@)V5M97)G96YC>2<L"B`@("`@
M("`@("`@(%!%05)?3$]'7T%,15)4("`@/3X@)V%L97)T)RP*("`@("`@("`@
M("`@4$5!4E],3T=?0U))5"`@("`]/B`G8W)I=&EC86PG+`H@("`@("`@("`@
M("!014%27TQ/1U]%4E(@("`@(#T^("=E<G)O<B<L"B`@("`@("`@("`@(%!%
M05)?3$]'7U=!4DY)3D<@/3X@)W=A<FYI;F<G+`H@("`@("`@("`@("!014%2
M7TQ/1U].3U1)0T4@(#T^("=N;W1I8V4G+`H@("`@("`@("`@("!014%27TQ/
M1U])3D9/("`@(#T^("=I;F9O)RP*("`@("`@("`@("`@4$5!4E],3T=?1$5"
M54<@("`]/B`G9&5B=6<G"B`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N("1L
M979E;'-;)'!R:6]R:71Y73L*("`@('T*"B`@("`O*BH*("`@("`J($-A;&-U
M;&%T92!T:&4@;&]G(&UA<VL@9F]R('1H92!G:79E;B!P<FEO<FET>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`@("1P<FEO<FET>2`@(%1H92!P
M<FEO<FET>2!W:&]S92!M87-K('=I;&P@8F4@8V%L8W5L871E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C86QC=6QA=&5D(&QO9R!M
M87-K+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I
M;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N($U!4TLH)'!R
M:6]R:71Y*0H@("`@>PH@("`@("`@(')E='5R;B`H,2`\/"`D<')I;W)I='DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L8W5L871E('1H92!L;V<@;6%S
M:R!F;W(@86QL('!R:6]R:71I97,@=7`@=&\@=&AE(&=I=F5N('!R:6]R:71Y
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("`@)'!R:6]R:71Y("`@
M5&AE(&UA>&EM=6T@<')I;W)I='D@8V]V97)E9"!B>2!T:&ES(&UA<VLN"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@8V%L8W5L871E9"!L
M;V<@;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!54%1/
M*"1P<FEO<FET>2D*("`@('L*("`@("`@("!R971U<FX@*"@Q(#P\("@D<')I
M;W)I='D@*R`Q*2D@+2`Q*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!A
M;F0@<F5T=7)N('1H92!L979E;"!M87-K(&9O<B!T:&4@8W5R<F5N="!,;V<@
M:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA<VL@
M("`@($$@8FET=VES92!M87-K(&]F(&QO9R!L979E;',N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("`@("`@("`@(%1H92!C=7)R96YT(&QE=F5L
M(&UA<VLN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`
M<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T36%S
M:R@D;6%S:RD*("`@('L*("`@("`@("`D=&AI<RT^7VUA<VL@/2`D;6%S:SL*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%S:SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@;&5V96P@;6%S:RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5R9V5R("`@("`@("`@5&AE(&-U<G)E;G0@
M;&5V96P@;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971-87-K*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M87-K.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@=&AE(&=I=F5N('!R:6]R
M:71Y(&ES(&EN8VQU9&5D(&EN('1H92!C=7)R96YT(&QE=F5L(&UA<VLN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@("`D<')I;W)I='D@("!4:&4@
M<')I;W)I='D@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&EF('1H92!G:79E;B!P<FEO<FET>2!I<R!I;F-L=61E9"!I
M;B!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@("!L;V<@;6%S
M:RX*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<VEN
M8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7VES36%S:V5D
M*"1P<FEO<FET>2D*("`@('L*("`@("`@("!R971U<FX@*$QO9SHZ34%32R@D
M<')I;W)I='DI("8@)'1H:7,M/E]M87-K*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@9&5F875L="!P<FEO<FET>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C=7)R96YT(&1E9F%U
M;'0@<')I;W)I='DN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<VEN8V4@("!,;V<@,2XX+C0*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4')I;W)I='DH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!R
M:6]R:71Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@9&5F875L
M="!P<FEO<FET>2!T;R!T:&4@<W!E8VEF:65D('9A;'5E+@H@("`@("H*("`@
M("`J($!P87)A;2`@(&EN=&5G97(@)'!R:6]R:71Y("`@5&AE(&YE=R!D969A
M=6QT('!R:6]R:71Y+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0'-I;F-E("`@3&]G(#$N."XT"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=%!R:6]R:71Y*"1P<FEO<FET>2D*("`@('L*("`@("`@("`D=&AI<RT^
M7W!R:6]R:71Y(#T@)'!R:6]R:71Y.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D<R!A($QO9U]O8G-E<G9E<B!I;G-T86YC92!T;R!T:&4@;&ES="!O9B!O
M8G-E<G9E<G,@=&AA="!A<F4@;&ES=&5N:6YG"B`@("`@*B!F;W(@;65S<V%G
M97,@96UI='1E9"!B>2!T:&ES($QO9R!I;G-T86YC92X*("`@("`J"B`@("`@
M*B!`<&%R86T@;V)J96-T("`@("1O8G-E<G9E<B`@(%1H92!,;V=?;V)S97)V
M97(@:6YS=&%N8V4@=&\@871T86-H(&%S(&$*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@("!4<G5E(&EF('1H92!O8G-E<G9E<B!I<R!S=6-C97-S
M9G5L;'D@871T86-H960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<VEN8V4@("!,;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%T=&%C:"@F)&]B<V5R=F5R*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M;V)S97)V97(L("=,;V=?;V)S97)V97(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VQI<W1E;F5R
M<ULD;V)S97)V97(M/E]I9%T@/2`F)&]B<V5R=F5R.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!,;V=?
M;V)S97)V97(@:6YS=&%N8V4@9G)O;2!T:&4@;&ES="!O9B!O8G-E<G9E<G,N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`@("`D;V)S97)V97(@("!4
M:&4@3&]G7V]B<V5R=F5R(&EN<W1A;F-E('1O(&1E=&%C:"!F<F]M"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!L:7-T(&]F(&QI
M<W1E;F5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@(%1R=64@
M:68@=&AE(&]B<V5R=F5R(&ES('-U8V-E<W-F=6QL>2!D971A8VAE9"X*("`@
M("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO
M9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@9&5T86-H*"1O8G-E<G9E<BD*
M("`@('L*("`@("`@("!I9B`H(6ES7V$H)&]B<V5R=F5R+"`G3&]G7V]B<V5R
M=F5R)RD@?'P*("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?;&ES=&5N97)S
M6R1O8G-E<G9E<BT^7VED72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@=6YS970H)'1H:7,M/E]L:7-T96YE<G-;
M)&]B<V5R=F5R+3Y?:61=*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!);F9O<FUS(&5A8V@@<F5G:7-T97)E9"!O8G-E
M<G9E<B!I;G-T86YC92!T:&%T(&$@;F5W(&UE<W-A9V4@:&%S(&)E96X*("`@
M("`J(&QO9V=E9"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`@("1E
M=F5N="`@("`@($$@:&%S:"!D97-C<FEB:6YG('1H92!L;V<@979E;G0N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]A;FYO=6YC92@D979E;G0I"B`@("!["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]L:7-T96YE<G,@87,@)&ED(#T^("1L:7-T96YE<BD@>PH@("`@
M("`@("`@("!I9B`H)&5V96YT6R=P<FEO<FET>2==(#P]("1T:&ES+3Y?;&ES
M=&5N97)S6R1I9%TM/E]P<FEO<FET>2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]L:7-T96YE<G-;)&ED72T^;F]T:69Y*"1E=F5N="D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F1I8V%T
M97,@=VAE=&AE<B!T:&ES(&ES(&$@8V]M<&]S:71E(&-L87-S+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@("`@("`@("!4<G5E(&EF('1H:7,@
M:7,@82!C;VUP;W-I=&4@8VQA<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XP"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&ES0V]M<&]S:71E*"D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H:7,@3&]G(&EN<W1A
M;F-E)W,@:61E;G1I9FEC871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@("`@)&ED96YT("`@("`@5&AE(&YE=R!I9&5N=&EF:6-A
M=&EO;B!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<VEN8V4@("!,;V<@,2XV+C,*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T261E;G0H)&ED96YT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:61E;G0@
M/2`D:61E;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C
M=7)R96YT(&ED96YT:69I8V%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@(%1H92!C=7)R96YT($QO9R!I;G-T86YC92=S(&ED
M96YT:69I8V%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C8N,PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971)9&5N="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:61E;G0["B`@("!]"GT*"C\^"@``+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+T1"+G!H<```````````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,3`R,#$Q`#$P-#$W,S8S,#`W`#`Q-C,S,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\("`@("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C
M;F5T+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!-
M86EN=&%I;F5R.B!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z($1"+G!H<"QV(#$N-34@,C`P-"\P,B\Q
M."`R,SHP-SHP.2!D86YI96QC($5X<"`D"B\O"B\O($1A=&%B87-E(&EN9&5P
M96YD96YT('%U97)Y(&EN=&5R9F%C92X*"@IR97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL*"B\O('M[>R!C;VYS=&%N=',*+R\@>WM[(&5R<F]R(&-O9&5S"@HO
M*@H@*B!4:&4@;65T:&]D(&UA<$5R<F]R0V]D92!I;B!E86-H($1"7V1B='EP
M92!I;7!L96UE;G1A=&EO;B!M87!S"B`J(&YA=&EV92!E<G)O<B!C;V1E<R!T
M;R!O;F4@;V8@=&AE<V4N"B`J"B`J($EF('EO=2!A9&0@86X@97)R;W(@8V]D
M92!H97)E+"!M86ME('-U<F4@>6]U(&%L<V\@861D(&$@=&5X='5A;`H@*B!V
M97)S:6]N(&]F(&ET(&EN($1".CIE<G)O<DUE<W-A9V4H*2X*("HO"F1E9FEN
M92@G1$)?3TLG+"`@("`@("`@("`@("`@("`@("`@("`@("`Q*3L*9&5F:6YE
M*"=$0E]%4E)/4B<L("`@("`@("`@("`@("`@("`@("`@+3$I.PID969I;F4H
M)T1"7T524D]27U-93E1!6"<L("`@("`@("`@("`@("`M,BD["F1E9FEN92@G
M1$)?15)23U)?0T].4U1204E.5"<L("`@("`@("`@("TS*3L*9&5F:6YE*"=$
M0E]%4E)/4E].3U1?1D]53D0G+"`@("`@("`@("`@+30I.PID969I;F4H)T1"
M7T524D]27T%,4D5!1%E?15A)4U13)RP@("`@("`M-2D["F1E9FEN92@G1$)?
M15)23U)?54Y355!03U)4140G+"`@("`@("`@("TV*3L*9&5F:6YE*"=$0E]%
M4E)/4E]-25--051#2"<L("`@("`@("`@("`@+3<I.PID969I;F4H)T1"7T52
M4D]27TE.5D%,240G+"`@("`@("`@("`@("`M."D["F1E9FEN92@G1$)?15)2
M3U)?3D]47T-!4$%"3$4G+"`@("`@("`@("TY*3L*9&5F:6YE*"=$0E]%4E)/
M4E]44E5.0T%4140G+"`@("`@("`@("`M,3`I.PID969I;F4H)T1"7T524D]2
M7TE.5D%,241?3E5-0D52)RP@("`@("TQ,2D["F1E9FEN92@G1$)?15)23U)?
M24Y604Q)1%]$051%)RP@("`@("`@+3$R*3L*9&5F:6YE*"=$0E]%4E)/4E]$
M259:15)/)RP@("`@("`@("`@("`M,3,I.PID969I;F4H)T1"7T524D]27TY/
M1$)314Q%0U1%1"<L("`@("`@("TQ-"D["F1E9FEN92@G1$)?15)23U)?0T%.
M3D]47T-214%412<L("`@("`@+3$U*3L*9&5F:6YE*"=$0E]%4E)/4E]#04Y.
M3U1?1$5,151%)RP@("`@("`M,38I.PID969I;F4H)T1"7T524D]27T-!3DY/
M5%]$4D]0)RP@("`@("`@("TQ-RD["F1E9FEN92@G1$)?15)23U)?3D]354-(
M5$%"3$4G+"`@("`@("`@+3$X*3L*9&5F:6YE*"=$0E]%4E)/4E].3U-50TA&
M245,1"<L("`@("`@("`M,3DI.PID969I;F4H)T1"7T524D]27TY%141?34]2
M15]$051!)RP@("`@("TR,"D["F1E9FEN92@G1$)?15)23U)?3D]47TQ/0TM%
M1"<L("`@("`@("`@+3(Q*3L*9&5F:6YE*"=$0E]%4E)/4E]604Q515]#3U5.
M5%]/3E]23U<G+"`M,C(I.PID969I;F4H)T1"7T524D]27TE.5D%,241?1%-.
M)RP@("`@("`@("TR,RD["F1E9FEN92@G1$)?15)23U)?0T].3D5#5%]&04E,
M140G+"`@("`@+3(T*3L*9&5F:6YE*"=$0E]%4E)/4E]%6%1%3E-)3TY?3D]4
M7T9/54Y$)RPM,C4I.PID969I;F4H)T1"7T524D]27T%#0T534U]624],051)
M3TXG+"`@("TR-BD["F1E9FEN92@G1$)?15)23U)?3D]354-(1$(G+"`@("`@
M("`@("`@+3(W*3L*9&5F:6YE*"=$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].
M54Q,)RPM,CDI.PH*"B\O('U]?0HO+R![>WL@<')E<&%R960@<W1A=&5M96YT
M+7)E;&%T960*"@HO*@H@*B!4:&5S92!C;VYS=&%N=',@87)E('5S960@=VAE
M;B!S=&]R:6YG(&EN9F]R;6%T:6]N(&%B;W5T('!R97!A<F5D"B`J('-T871E
M;65N=',@*'5S:6YG('1H92`B<')E<&%R92(@;65T:&]D(&EN($1"7V1B='EP
M92DN"B`J"B`J(%1H92!P<F5P87)E+V5X96-U=&4@;6]D96P@:6X@1$(@:7,@
M;6]S=&QY(&)O<G)O=V5D(&9R;VT@=&AE($]$0D,*("H@97AT96YS:6]N+"!I
M;B!A('%U97)Y('1H92`B/R(@8VAA<F%C=&5R(&UE86YS(&$@<V-A;&%R('!A
M<F%M971E<BX*("H@5&AE<F4@87)E('1W;R!E>'1E;G-I;VYS('1H;W5G:"P@
M82`B)B(@8VAA<F%C=&5R(&UE86YS(&%N(&]P87%U90H@*B!P87)A;65T97(N
M("!!;B!O<&%Q=64@<&%R86UE=&5R(&ES('-I;7!L>2!A(&9I;&4@;F%M92P@
M=&AE(')E86P*("H@9&%T82!A<F4@:6X@=&AA="!F:6QE("AU<V5F=6P@9F]R
M('!U='1I;F<@=7!L;V%D960@9FEL97,@:6YT;R!Y;W5R"B`J(&1A=&%B87-E
M(&%N9"!S=6-H*2X@5&AE("(A(B!C:&%R(&UE86YS(&$@<&%R86UE=&5R('1H
M870@;75S="!B90H@*B!L969T(&%S(&ET(&ES+@H@*B!4:&5Y(&UO9&EF>2!T
M:&4@<75O=&4@8F5H879O:7(Z"B`J($1"7U!!4D%-7U-#04Q!4B`H/RD@/3X@
M)V]R:6=I;F%L('-T<FEN9R!Q=6]T960G"B`J($1"7U!!4D%-7T]005%512`H
M)BD@/3X@)W-T<FEN9R!F<F]M(&9I;&4@<75O=&5D)PH@*B!$0E]005)!35]-
M25-#("`@*"$I(#T^(&]R:6=I;F%L('-T<FEN9PH@*B\*9&5F:6YE*"=$0E]0
M05)!35]30T%,05(G+"`Q*3L*9&5F:6YE*"=$0E]005)!35]/4$%1544G+"`R
M*3L*9&5F:6YE*"=$0E]005)!35]-25-#)RP@("`S*3L*"@HO+R!]?7T*+R\@
M>WM[(&)I;F%R>2!D871A+7)E;&%T960*"@HO*@H@*B!4:&5S92!C;VYS=&%N
M=',@9&5F:6YE(&1I9F9E<F5N="!W87ES(&]F(')E='5R;FEN9R!B:6YA<GD@
M9&%T80H@*B!F<F]M('%U97)I97,N("!!9V%I;BP@=&AI<R!M;V1E;"!H87,@
M8F5E;B!B;W)R;W=E9"!F<F]M('1H92!/1$)#"B`J(&5X=&5N<VEO;BX*("H*
M("H@1$)?0DE.34]$15]005-35$A252!S96YD<R!T:&4@9&%T82!D:7)E8W1L
M>2!T:')O=6=H('1O('1H92!B<F]W<V5R"B`J('=H96X@9&%T82!I<R!F971C
M:&5D(&9R;VT@=&AE(&1A=&%B87-E+@H@*B!$0E]"24Y-3T1%7U)%5%523B!L
M971S('EO=2!R971U<FX@9&%T82!A<R!U<W5A;"X*("H@1$)?0DE.34]$15]#
M3TY615)4(')E='5R;G,@9&%T82!A<R!W96QL+"!O;FQY(&ET(&ES(&-O;G9E
M<G1E9"!T;PH@*B!H97@@9F]R;6%T+"!F;W(@97AA;7!L92!T:&4@<W1R:6YG
M("(Q,C,B('=O=6QD(&)E8V]M92`B,S$S,C,S(BX*("HO"F1E9FEN92@G1$)?
M0DE.34]$15]005-35$A252<L(#$I.PID969I;F4H)T1"7T))3DU/1$5?4D54
M55).)RP@("`R*3L*9&5F:6YE*"=$0E]"24Y-3T1%7T-/3E9%4E0G+"`@,RD[
M"@H*+R\@?7U]"B\O('M[>R!F971C:"!M;V1E<PH*"B\J*@H@*B!4:&ES(&ES
M(&$@<W!E8VEA;"!C;VYS=&%N="!T:&%T('1E;&QS($1"('1H92!U<V5R(&AA
M<VXG="!S<&5C:69I960*("H@86YY('!A<G1I8W5L87(@9V5T(&UO9&4L('-O
M('1H92!D969A=6QT('-H;W5L9"!B92!U<V5D+@H@*B\*9&5F:6YE*"=$0E]&
M151#2$U/1$5?1$5&055,5"<L(#`I.PH*+RHJ"B`J($-O;'5M;B!D871A(&EN
M9&5X960@8GD@;G5M8F5R<RP@;W)D97)E9"!F<F]M(#`@86YD('5P"B`J+PID
M969I;F4H)T1"7T9%5$-(34]$15]/4D1%4D5$)RP@,2D["@HO*BH*("H@0V]L
M=6UN(&1A=&$@:6YD97AE9"!B>2!C;VQU;6X@;F%M97,*("HO"F1E9FEN92@G
M1$)?1D540TA-3T1%7T%34T]#)RP@,BD["@HO*BH*("H@0V]L=6UN(&1A=&$@
M87,@;V)J96-T('!R;W!E<G1I97,*("HO"F1E9FEN92@G1$)?1D540TA-3T1%
M7T]"2D5#5"<L(#,I.PH*+RHJ"B`J($9O<B!M=6QT:2UD:6UE;G-I;VYA;"!R
M97-U;'1S.B!N;W)M86QL>2!T:&4@9FER<W0@;&5V96P@;V8@87)R87ES"B`J
M(&ES('1H92!R;W<@;G5M8F5R+"!A;F0@=&AE('-E8V]N9"!L979E;"!I;F1E
M>&5D(&)Y(&-O;'5M;B!N=6UB97(@;W(@;F%M92X*("H@1$)?1D540TA-3T1%
M7T9,25!0140@<W=I=&-H97,@=&AI<R!O<F1E<BP@<V\@=&AE(&9I<G-T(&QE
M=F5L(&]F(&%R<F%Y<PH@*B!I<R!T:&4@8V]L=6UN(&YA;64L(&%N9"!T:&4@
M<V5C;VYD(&QE=F5L('1H92!R;W<@;G5M8F5R+@H@*B\*9&5F:6YE*"=$0E]&
M151#2$U/1$5?1DQ)4%!%1"<L(#0I.PH*+RH@9F]R(&-O;7!A=&EB:6QI='D@
M*B\*9&5F:6YE*"=$0E]'151-3T1%7T]21$52140G+"!$0E]&151#2$U/1$5?
M3U)$15)%1"D["F1E9FEN92@G1$)?1T5434]$15]!4U-/0R<L("`@1$)?1D54
M0TA-3T1%7T%34T]#*3L*9&5F:6YE*"=$0E]'151-3T1%7T9,25!0140G+"!$
M0E]&151#2$U/1$5?1DQ)4%!%1"D["@H*+R\@?7U]"B\O('M[>R!T86)L94EN
M9F\H*2`F)B!A=71O4')E<&%R92@I+7)E;&%T960*"@HO*BH*("H@=&AE<V4@
M87)E(&-O;G-T86YT<R!F;W(@=&AE('1A8FQE26YF;RUF=6YC=&EO;@H@*B!T
M:&5Y(&%R92!B:71W:7-E9"!O<B=E9"X@<V\@:68@=&AE<F4@87)E(&UO<F4@
M8V]N<W1A;G1S('1O(&)E(&1E9FEN960*("H@:6X@=&AE(&9U='5R92P@861J
M=7-T($1"7U1!0DQ%24Y&3U]&54Q,(&%C8V]R9&EN9VQY"B`J+PID969I;F4H
M)T1"7U1!0DQ%24Y&3U]/4D1%4B<L(#$I.PID969I;F4H)T1"7U1!0DQ%24Y&
M3U]/4D1%4E1!0DQ%)RP@,BD["F1E9FEN92@G1$)?5$%"3$5)3D9/7T953$PG
M+"`S*3L*"B\J"B`J(%5S960@8GD@875T;U!R97!A<F4H*0H@*B\*9&5F:6YE
M*"=$0E]!551/455%4EE?24Y315)4)RP@,2D["F1E9FEN92@G1$)?05543U%5
M15)97U501$%412<L(#(I.PH*"B\O('U]?0HO+R![>WL@<&]R=&%B:6QI='D@
M;6]D97,*"@HO*BH*("H@4&]R=&%B:6QI='DZ('1U<FX@;V9F(&%L;"!P;W)T
M86)I;&ET>2!F96%T=7)E<RX*("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO
M;B@I"B`J+PID969I;F4H)T1"7U!/4E1!0DE,25197TY/3D4G+"`P*3L*"B\J
M*@H@*B!0;W)T86)I;&ET>3H@8V]N=F5R="!N86UE<R!O9B!T86)L97,@86YD
M(&9I96QD<R!T;R!L;W=E<B!C87-E"B`J('=H96X@=7-I;F<@=&AE(&=E="HH
M*2P@9F5T8V@J*"D@86YD('1A8FQE26YF;R@I(&UE=&AO9',N"B`J($!S964@
M1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@*B\*9&5F:6YE*"=$0E]03U)404))
M3$E465],3U=%4D-!4T4G+"`Q*3L*"B\J*@H@*B!0;W)T86)I;&ET>3H@<FEG
M:'0@=')I;2!T:&4@9&%T82!O=71P=70@8GD@9V5T*B@I(&%N9"!F971C:"HH
M*2X*("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I"B`J+PID969I;F4H
M)T1"7U!/4E1!0DE,25197U)44DE-)RP@,BD["@HO*BH*("H@4&]R=&%B:6QI
M='DZ(&9O<F-E(')E<&]R=&EN9R!T:&4@;G5M8F5R(&]F(')O=W,@9&5L971E
M9"X*("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I"B`J+PID969I;F4H
M)T1"7U!/4E1!0DE,25197T1%3$5415]#3U5.5"<L(#0I.PH*+RHJ"B`J(%!O
M<G1A8FEL:71Y.B!E;F%B;&4@:&%C:R!T:&%T(&UA:V5S(&YU;5)O=W,H*2!W
M;W)K(&EN($]R86-L92X*("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I
M"B`J+PID969I;F4H)T1"7U!/4E1!0DE,25197TY535)/5U,G+"`X*3L*"B\J
M*@H@*B!0;W)T86)I;&ET>3H@;6%K97,@8V5R=&%I;B!E<G)O<B!M97-S86=E
M<R!I;B!C97)T86EN(&1R:79E<G,@8V]M<&%T:6)L90H@*B!W:71H('1H;W-E
M(&9R;VT@;W1H97(@1$)-4R=S+@H@*@H@*B`K(&UY<W%L+"!M>7-Q;&DZ("!C
M:&%N9V4@=6YI<75E+W!R:6UA<GD@:V5Y(&-O;G-T<F%I;G1S"B`J("`@1$)?
M15)23U)?04Q214%$65]%6$E35%,@+3X@1$)?15)23U)?0T].4U1204E.5`H@
M*@H@*B`K(&]D8F,H86-C97-S*3H@($U3)W,@3T1"0R!D<FEV97(@<F5P;W)T
M<R`G;F\@<W5C:"!F:65L9"<@87,@8V]D90H@*B`@(#`W,#`Q+"!W:&EC:"!M
M96%N<R`G=&]O(&9E=R!P87)A;65T97)S+B<@(%=H96X@=&AI<R!O<'1I;VX@
M:7,@;VX*("H@("!T:&%T(&-O9&4@9V5T<R!M87!P960@=&\@1$)?15)23U)?
M3D]354-(1DE%3$0N"B`J"B`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH
M*0H@*B\*9&5F:6YE*"=$0E]03U)404))3$E465]%4E)/4E,G+"`Q-BD["@HO
M*BH*("H@4&]R=&%B:6QI='DZ(&-O;G9E<G0@;G5L;"!V86QU97,@=&\@96UP
M='D@<W1R:6YG<R!I;B!D871A(&]U='!U="!B>0H@*B!G970J*"D@86YD(&9E
M=&-H*B@I+@H@*B!`<V5E($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("HO"F1E
M9FEN92@G1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462<L(#,R*3L*"B\J
M*@H@*B!0;W)T86)I;&ET>3H@='5R;B!O;B!A;&P@<&]R=&%B:6QI='D@9F5A
M='5R97,N"B`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@*B\*9&5F
M:6YE*"=$0E]03U)404))3$E465]!3$PG+"`V,RD["@HO+R!]?7T*"@HO+R!]
M?7T*+R\@>WM[(&-L87-S($1""@HO*BH*("H@5&AE(&UA:6X@(D1"(B!C;&%S
M<R!I<R!S:6UP;'D@82!C;VYT86EN97(@8VQA<W,@=VET:"!S;VUE('-T871I
M8PH@*B!M971H;V1S(&9O<B!C<F5A=&EN9R!$0B!O8FIE8W1S(&%S('=E;&P@
M87,@<V]M92!U=&EL:71Y(&9U;F-T:6]N<PH@*B!C;VUM;VX@=&\@86QL('!A
M<G1S(&]F($1"+@H@*@H@*B!4:&4@;V)J96-T(&UO9&5L(&]F($1"(&ES(&%S
M(&9O;&QO=W,@*&EN9&5N=&%T:6]N(&UE86YS(&EN:&5R:71A;F-E*3H*("H*
M("H@1$(@("`@("`@("`@(%1H92!M86EN($1"(&-L87-S+B`@5&AI<R!I<R!S
M:6UP;'D@82!U=&EL:71Y(&-L87-S"B`J("`@("`@("`@("`@("!W:71H('-O
M;64@(G-T871I8R(@;65T:&]D<R!F;W(@8W)E871I;F<@1$(@;V)J96-T<R!A
M<PH@*B`@("`@("`@("`@("`@=V5L;"!A<R!C;VUM;VX@=71I;&ET>2!F=6YC
M=&EO;G,@9F]R(&]T:&5R($1"(&-L87-S97,N"B`J"B`J($1"7V-O;6UO;B`@
M("!4:&4@8F%S92!F;W(@96%C:"!$0B!I;7!L96UE;G1A=&EO;BX@(%!R;W9I
M9&5S(&1E9F%U;'0*("H@?"`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N<R`H
M:6X@3T\@;&EN9V\@=FER='5A;"!M971H;V1S*2!F;W(*("H@?"`@("`@("`@
M("`@('1H92!A8W1U86P@1$(@:6UP;&5M96YT871I;VYS(&%S('=E;&P@87,@
M82!B=6YC:"!O9@H@*B!\("`@("`@("`@("`@<75E<GD@=71I;&ET>2!F=6YC
M=&EO;G,N"B`J('P*("H@*RU$0E]M>7-Q;"`@(%1H92!$0B!I;7!L96UE;G1A
M=&EO;B!F;W(@37E344PN("!);FAE<FET<R!$0E]C;VUM;VXN"B`J("`@("`@
M("`@("`@("!7:&5N(&-A;&QI;F<@1$(Z.F9A8W1O<GD@;W(@1$(Z.F-O;FYE
M8W0@9F]R($UY4U%,"B`J("`@("`@("`@("`@("!C;VYN96-T:6]N<RP@=&AE
M(&]B:F5C="!R971U<FYE9"!I<R!A;B!I;G-T86YC92!O9B!T:&ES"B`J("`@
M("`@("`@("`@("!C;&%S<RX*("H*("H@0'!A8VMA9V4@($1""B`J($!A=71H
M;W(@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J($!A=71H;W(@("!4
M;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!S:6YC92`@("!0
M2%`@-"XP"B`J($!V97)S:6]N("`D260Z($1"+G!H<"QV(#$N-34@,C`P-"\P
M,B\Q."`R,SHP-SHP.2!D86YI96QC($5X<"`D"B`J($!C871E9V]R>2!$871A
M8F%S90H@*B\*8VQA<W,@1$(*>PH@("`@+R\@>WM[("9F86-T;W)Y*"D*"B`@
M("`O*BH*("`@("`J($-R96%T92!A(&YE=R!$0B!O8FIE8W0@9F]R('1H92!S
M<&5C:69I960@9&%T86)A<V4@='EP92X*("`@("`J"B`@("`@*B!!;&QO=W,@
M8W)E871I;VX@;V8@82!$0E\\9')I=F5R/B!O8FIE8W0@9G)O;2!W:&EC:"!T
M:&4@;V)J96-T)W,*("`@("`J(&UE=&AO9',@8V%N(&)E('5T:6QI>F5D('=I
M=&AO=70@86-T=6%L;'D@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@9&%T86)A<V4@='EP
M92P@9F]R(&5X86UP;&4@(FUY<W%L(@H@("`@("H@0'!A<F%M(&%R<F%Y("`D
M;W!T:6]N<R!A<W-O8VEA=&EV92!A<G)A>2!O9B!O<'1I;VX@;F%M97,@86YD
M('9A;'5E<PH@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!A(&YE=R!$
M0B!O8FIE8W0N("!/;B!E<G)O<BP@86X@97)R;W(@;V)J96-T+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)'1Y
M<&4L("1O<'1I;VYS(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D;W!T:6]N<RDI('L*("`@("`@("`@("`@)&]P=&EO;G,@/2!A<G)A
M>2@G<&5R<VES=&5N="<@/3X@)&]P=&EO;G,I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES<V5T*"1O<'1I;VYS6R=D96)U9R==*2`F)B`D;W!T:6]N<ULG
M9&5B=6<G72`^/2`R*2!["B`@("`@("`@("`@("\O(&5X<&]S92!P:'`@97)R
M;W)S('=I=&@@<W5F9FEC:65N="!D96)U9R!L979E;`H@("`@("`@("`@("!I
M;F-L=61E7V]N8V4@(D1"+WLD='EP97TN<&AP(CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E(")$0B][)'1Y<&5]+G!H<"([
M"B`@("`@("`@?0H*("`@("`@("`D8VQA<W-N86UE(#T@(D1"7R1[='EP97TB
M.PH*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W-N86UE*2D@>PH@
M("`@("`@("`@("`D=&UP(#T@4$5!4CHZ<F%I<V5%<G)O<BAN=6QL+"!$0E]%
M4E)/4E].3U1?1D]53D0L(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(")5;F%B;&4@=&\@:6YC;'5D92!T:&4@1$(O
M>R1T>7!E?2YP:'`@9FEL92(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=$0E]%<G)O<B<L('1R=64I.PH@("`@("`@("`@("!R971U
M<FX@)'1M<#L*("`@("`@("!]"@H@("`@("`@($`D;V)J(#TF(&YE=R`D8VQA
M<W-N86UE.PH*("`@("`@("!F;W)E86-H("@D;W!T:6]N<R!A<R`D;W!T:6]N
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=&5S="`]("1O8FHM/G-E=$]P
M=&EO;B@D;W!T:6]N+"`D=F%L=64I.PH@("`@("`@("`@("!I9B`H1$(Z.FES
M17)R;W(H)'1E<W0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1E<W0[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V)J
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[("9C;VYN96-T*"D*"B`@
M("`O*BH*("`@("`J($-R96%T92!A(&YE=R!$0B!O8FIE8W0@86YD(&-O;FYE
M8W0@=&\@=&AE('-P96-I9FEE9"!D871A8F%S92X*("`@("`J"B`@("`@*B!%
M>&%M<&QE(#$N"B`@("`@*B`\8V]D93X@/#]P:'`*("`@("`J(')E<75I<F5?
M;VYC92`G1$(N<&AP)SL*("`@("`J"B`@("`@*B`D9'-N(#T@)VUY<W%L.B\O
M=7-E<CIP87-S=V]R9$!H;W-T+V1A=&%B87-E)PH@("`@("H@)&]P=&EO;G,@
M/2!A<G)A>2@*("`@("`J("`@("`G9&5B=6<G("`@("`@(#T^(#(L"B`@("`@
M*B`@("`@)W!O<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E465]!3$PL"B`@
M("`@*B`I.PH@("`@("H*("`@("`J("1D8F@@/28@1$(Z.F-O;FYE8W0H)&1S
M;BP@)&]P=&EO;G,I.PH@("`@("H@:68@*$1".CII<T5R<F]R*"1D8F@I*2![
M"B`@("`@*B`@("`@9&EE*"1D8F@M/F=E=$UE<W-A9V4H*2D["B`@("`@*B!]
M"B`@("`@*B`_/CPO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&1S;B`@("`@('-T<FEN9R`B9&%T82!S;W5R8V4@;F%M92(@;W(@86X@87)R
M87D@:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&9O<FUA
M="!R971U<FYE9"!B>2!$0CHZ<&%R<V5$4TXH*0H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D;W!T:6]N<R`@86X@87-S;V-I871I=F4@87)R87D@;V8@
M;W!T:6]N(&YA;65S(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!T:&5I<B!V86QU97,*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@
M82!N97=L>2!C<F5A=&5D($1"(&-O;FYE8W1I;VX@;V)J96-T+"!O<B!A($1"
M"B`@("`@*B`@("`@("`@("`@("`@("`@97)R;W(@;V)J96-T(&]N(&5R<F]R
M"B`@("`@*@H@("`@("H@0'-E92!$0CHZ<&%R<V5$4TXH*2P@1$)?8V]M;6]N
M.CIS971/<'1I;VXH*2P@1$(Z.FES17)R;W(H*0H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)F-O;FYE8W0H)&1S;BP@)&]P
M=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D<VYI;F9O(#T@1$(Z
M.G!A<G-E1%-.*"1D<VXI.PH@("`@("`@("1T>7!E(#T@)&1S;FEN9F];)W!H
M<'1Y<&4G73L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;W!T:6]N<RDI('L*
M("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@1F]R(&)A8VMW87)D<R!C
M;VUP871I8FEL:71Y+B`@)&]P=&EO;G,@=7-E9"!T;R!B92!B;V]L96%N+`H@
M("`@("`@("`@("`@*B!I;F1I8V%T:6YG('=H971H97(@=&AE(&-O;FYE8W1I
M;VX@<VAO=6QD(&)E('!E<G-I<W1E;G0N"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"=P97)S:7-T96YT)R`]/B`D;W!T
M:6]N<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)V1E8G5G)UTI("8F("1O<'1I;VYS6R=D96)U9R==(#X](#(I('L*("`@("`@
M("`@("`@+R\@97AP;W-E('!H<"!E<G)O<G,@=VET:"!S=69F:6-I96YT(&1E
M8G5G(&QE=F5L"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`B1$(O)'MT>7!E
M?2YP:'`B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E
M7V]N8V4@(D1"+R1[='EP97TN<&AP(CL*("`@("`@("!]"@H@("`@("`@("1C
M;&%S<VYA;64@/2`B1$)?)'MT>7!E?2(["B`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)&-L87-S;F%M92DI('L*("`@("`@("`@("`@)'1M<"`](%!%05(Z
M.G)A:7-E17)R;W(H;G5L;"P@1$)?15)23U)?3D]47T9/54Y$+"!N=6QL+"!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B56YA
M8FQE('1O(&EN8VQU9&4@=&AE($1"+WLD='EP97TN<&AP(&9I;&4@9F]R(&`D
M9'-N)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=$
M0E]%<G)O<B<L('1R=64I.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@
M("`@("!]"@H@("`@("`@($`D;V)J(#TF(&YE=R`D8VQA<W-N86UE.PH*("`@
M("`@("!F;W)E86-H("@D;W!T:6]N<R!A<R`D;W!T:6]N(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`D=&5S="`]("1O8FHM/G-E=$]P=&EO;B@D;W!T:6]N
M+"`D=F%L=64I.PH@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'1E<W0I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1E<W0["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1E<G(@/2`D;V)J+3YC;VYN96-T*"1D
M<VYI;F9O+"`D;V)J+3YG971/<'1I;VXH)W!E<G-I<W1E;G0G*2D["B`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1E<G(I*2!["B`@("`@("`@("`@("1E<G(M
M/F%D9%5S97));F9O*"1D<VXI.PH@("`@("`@("`@("!R971U<FX@)&5R<CL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V)J.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&%P:59E<G-I;VXH*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!$0B!!4$D@=F5R<VEO;@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT('1H92!$0B!!4$D@=F5R<VEO;B!N=6UB97(*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A<&E697)S
M:6]N*"D*("`@('L*("`@("`@("!R971U<FX@,CL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!I<T5R<F]R*"D*"B`@("`O*BH*("`@("`J(%1E;&P@
M=VAE=&AE<B!A(')E<W5L="!C;V1E(&9R;VT@82!$0B!M971H;V0@:7,@86X@
M97)R;W(*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1V86QU92!R97-U;'0@
M8V]D90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"!W:&5T:&5R("1V86QU
M92!I<R!A;B!E<G)O<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES17)R;W(H)'9A;'5E*0H@("`@>PH@("`@
M("`@(')E='5R;B!I<U]A*"1V86QU92P@)T1"7T5R<F]R)RD["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@:7-#;VYN96-T:6]N*"D*"B`@("`O*BH*
M("`@("`J(%1E;&P@=VAE=&AE<B!A('9A;'5E(&ES(&$@1$(@8V]N;F5C=&EO
M;@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@=F%L=64@=&\@
M=&5S=`H@("`@("H*("`@("`J($!R971U<FX@8F]O;"!W:&5T:&5R("1V86QU
M92!I<R!A($1"(&-O;FYE8W1I;VX*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!I<T-O;FYE8W1I;VXH)'9A;'5E
M*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-?;V)J96-T*"1V86QU92D@)B8*
M("`@("`@("`@("`@("`@(&ES7W-U8F-L87-S7V]F*"1V86QU92P@)V1B7V-O
M;6UO;B<I("8F"B`@("`@("`@("`@("`@("!M971H;V1?97AI<W1S*"1V86QU
M92P@)W-I;7!L95%U97)Y)RDI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&ES36%N:7`H*0H*("`@("\J*@H@("`@("H@5&5L;"!W:&5T:&5R(&$@
M<75E<GD@:7,@82!D871A(&UA;FEP=6QA=&EO;B!Q=65R>2`H:6YS97)T+`H@
M("`@("H@=7!D871E(&]R(&1E;&5T92D@;W(@82!D871A(&1E9FEN:71I;VX@
M<75E<GD@*&-R96%T92P@9')O<"P*("`@("`J(&%L=&5R+"!G<F%N="P@<F5V
M;VME*2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'%U97)Y('1H92!Q=65R>0H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B!W:&5T:&5R("1Q=65R>2!I<R!A(&1A=&$@
M;6%N:7!U;&%T:6]N('%U97)Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES36%N
M:7`H)'%U97)Y*0H@("`@>PH@("`@("`@("1M86YI<',@/2`G24Y315)4?%50
M1$%417Q$14Q%5$5\)RXG4D503$%#17Q#4D5!5$5\1%)/4'PG+@H@("`@("`@
M("`@("`@("`@("`G04Q415)\1U)!3E1\4D563TM%?"<N)TQ/0TM\54Y,3T-+
M)SL*("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<<RHB/R@G+B1M86YI<',N
M)RE<<RLO:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!E<G)O<DUE<W-A9V4H*0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@=&5X='5A;"!E<G)O<B!M97-S86=E(&9O<B!A($1"(&5R
M<F]R(&-O9&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=F%L=64@
M97)R;W(@8V]D90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(&5R<F]R
M(&UE<W-A9V4L(&]R(&9A;'-E(&EF('1H92!E<G)O<B!C;V1E('=A<PH@("`@
M("H@;F]T(')E8V]G;FEZ960*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)-
M97-S86=E*"1V86QU92D*("`@('L*("`@("`@("!S=&%T:6,@)&5R<F]R365S
M<V%G97,["B`@("`@("`@:68@*"%I<W-E="@D97)R;W)-97-S86=E<RDI('L*
M("`@("`@("`@("`@)&5R<F]R365S<V%G97,@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@($1"7T524D]2("`@("`@("`@("`@("`@("`@("`]/B`G=6YK;F]W
M;B!E<G)O<B<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]!3%)%04197T58
M25-44R`@("`@/3X@)V%L<F5A9'D@97AI<W1S)RP*("`@("`@("`@("`@("`@
M($1"7T524D]27T-!3DY/5%]#4D5!5$4@("`@("`]/B`G8V%N(&YO="!C<F5A
M=&4G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?0T%.3D]47T1%3$5412`@
M("`@(#T^("=C86X@;F]T(&1E;&5T92<L"B`@("`@("`@("`@("`@("!$0E]%
M4E)/4E]#04Y.3U1?1%)/4"`@("`@("`@/3X@)V-A;B!N;W0@9')O<"<L"B`@
M("`@("`@("`@("`@("!$0E]%4E)/4E]#3TY35%)!24Y4("`@("`@("`@/3X@
M)V-O;G-T<F%I;G0@=FEO;&%T:6]N)RP*("`@("`@("`@("`@("`@($1"7T52
M4D]27T-/3E-44D%)3E1?3D]47TY53$P]/B`G;G5L;"!V86QU92!V:6]L871E
M<R!N;W0M;G5L;"!C;VYS=')A:6YT)RP*("`@("`@("`@("`@("`@($1"7T52
M4D]27T1)5EI%4D\@("`@("`@("`@("`]/B`G9&EV:7-I;VX@8GD@>F5R;R<L
M"B`@("`@("`@("`@("`@("!$0E]%4E)/4E])3E9!3$E$("`@("`@("`@("`@
M/3X@)VEN=F%L:60G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?24Y604Q)
M1%]$051%("`@("`@(#T^("=I;G9A;&ED(&1A=&4@;W(@=&EM92<L"B`@("`@
M("`@("`@("`@("!$0E]%4E)/4E])3E9!3$E$7TY534)%4B`@("`@/3X@)VEN
M=F%L:60@;G5M8F5R)RP*("`@("`@("`@("`@("`@($1"7T524D]27TU)4TU!
M5$-(("`@("`@("`@("`]/B`G;6ES;6%T8V@G+`H@("`@("`@("`@("`@("`@
M1$)?15)23U)?3D]$0E-%3$5#5$5$("`@("`@(#T^("=N;R!D871A8F%S92!S
M96QE8W1E9"<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E].3U-50TA&245,
M1"`@("`@("`@/3X@)VYO('-U8V@@9FEE;&0G+`H@("`@("`@("`@("`@("`@
M1$)?15)23U)?3D]354-(5$%"3$4@("`@("`@(#T^("=N;R!S=6-H('1A8FQE
M)RP*("`@("`@("`@("`@("`@($1"7T524D]27TY/5%]#05!!0DQ%("`@("`@
M("`]/B`G1$(@8F%C:V5N9"!N;W0@8V%P86)L92<L"B`@("`@("`@("`@("`@
M("!$0E]%4E)/4E].3U1?1D]53D0@("`@("`@("`@/3X@)VYO="!F;W5N9"<L
M"B`@("`@("`@("`@("`@("!$0E]%4E)/4E].3U1?3$]#2T5$("`@("`@("`@
M/3X@)VYO="!L;V-K960G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?4UE.
M5$%8("`@("`@("`@("`@(#T^("=S>6YT87@@97)R;W(G+`H@("`@("`@("`@
M("`@("`@1$)?15)23U)?54Y355!03U)4140@("`@("`@(#T^("=N;W0@<W5P
M<&]R=&5D)RP*("`@("`@("`@("`@("`@($1"7T524D]27U9!3%5%7T-/54Y4
M7T].7U)/5R`]/B`G=F%L=64@8V]U;G0@;VX@<F]W)RP*("`@("`@("`@("`@
M("`@($1"7T524D]27TE.5D%,241?1%-.("`@("`@("`]/B`G:6YV86QI9"!$
M4TXG+`H@("`@("`@("`@("`@("`@1$)?15)23U)?0T].3D5#5%]&04E,140@
M("`@(#T^("=C;VYN96-T(&9A:6QE9"<L"B`@("`@("`@("`@("`@("!$0E]/
M2R`@("`@("`@("`@("`@("`@("`@("`@/3X@)VYO(&5R<F]R)RP*("`@("`@
M("`@("`@("`@($1"7T524D]27TY%141?34]215]$051!("`@("`]/B`G:6YS
M=69F:6-I96YT(&1A=&$@<W5P<&QI960G+`H@("`@("`@("`@("`@("`@1$)?
M15)23U)?15A414Y324].7TY/5%]&3U5.1#T^("=E>'1E;G-I;VX@;F]T(&9O
M=6YD)RP*("`@("`@("`@("`@("`@($1"7T524D]27TY/4U5#2$1"("`@("`@
M("`@("`]/B`G;F\@<W5C:"!D871A8F%S92<L"B`@("`@("`@("`@("`@("!$
M0E]%4E)/4E]!0T-%4U-?5DE/3$%424].("`@/3X@)VEN<W5F9FEC:65N="!P
M97)M:7-S:6]N<R<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]44E5.0T%4
M140@("`@("`@("`@/3X@)W1R=6YC871E9"<*("`@("`@("`@("`@*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D=F%L=64I*2!["B`@
M("`@("`@("`@("1V86QU92`]("1V86QU92T^9V5T0V]D92@I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1E<G)O<DUE<W-A9V5S6R1V86QU
M95TI(#\@)&5R<F]R365S<V%G97-;)'9A;'5E72`Z("1E<G)O<DUE<W-A9V5S
M6T1"7T524D]273L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P87)S
M94133B@I"@H@("`@+RHJ"B`@("`@*B!087)S92!A(&1A=&$@<V]U<F-E(&YA
M;64N"B`@("`@*@H@("`@("H@061D:71I;VYA;"!K97ES(&-A;B!B92!A9&1E
M9"!B>2!A<'!E;F1I;F<@82!54DD@<75E<GD@<W1R:6YG('1O('1H90H@("`@
M("H@96YD(&]F('1H92!$4TXN"B`@("`@*@H@("`@("H@5&AE(&9O<FUA="!O
M9B!T:&4@<W5P<&QI960@1%-.(&ES(&EN(&ET<R!F=6QL97-T(&9O<FTZ"B`@
M("`@*B`\8V]D93X*("`@("`J("!P:'!T>7!E*&1B<WEN=&%X*3HO+W5S97)N
M86UE.G!A<W-W;W)D0'!R;W1O8V]L*VAO<W1S<&5C+V1A=&%B87-E/V]P=&EO
M;CTX)F%N;W1H97(]=')U90H@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J
M($UO<W0@=F%R:6%T:6]N<R!A<F4@86QL;W=E9#H*("`@("`J(#QC;V1E/@H@
M("`@("H@('!H<'1Y<&4Z+R]U<V5R;F%M93IP87-S=V]R9$!P<F]T;V-O;"MH
M;W-T<W!E8SHQ,3`O+W5S<B]D8E]F:6QE+F1B/VUO9&4],#8T-`H@("`@("H@
M('!H<'1Y<&4Z+R]U<V5R;F%M93IP87-S=V]R9$!H;W-T<W!E8R]D871A8F%S
M95]N86UE"B`@("`@*B`@<&AP='EP93HO+W5S97)N86UE.G!A<W-W;W)D0&AO
M<W1S<&5C"B`@("`@*B`@<&AP='EP93HO+W5S97)N86UE0&AO<W1S<&5C"B`@
M("`@*B`@<&AP='EP93HO+VAO<W1S<&5C+V1A=&%B87-E"B`@("`@*B`@<&AP
M='EP93HO+VAO<W1S<&5C"B`@("`@*B`@<&AP='EP92AD8G-Y;G1A>"D*("`@
M("`J("!P:'!T>7!E"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9'-N($1A=&$@4V]U<F-E($YA;64@=&\@8F4@<&%R<V5D
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!A;B!A<W-O8VEA=&EV92!A
M<G)A>2!W:71H('1H92!F;VQL;W=I;F<@:V5Y<SH*("`@("`J("`K('!H<'1Y
M<&4Z("!$871A8F%S92!B86-K96YD('5S960@:6X@4$A0("AM>7-Q;"P@;V1B
M8R!E=&,N*0H@("`@("H@("L@9&)S>6YT87@Z($1A=&%B87-E('5S960@=VET
M:"!R96=A<F1S('1O(%-13"!S>6YT87@@971C+@H@("`@("H@("L@<')O=&]C
M;VPZ($-O;6UU;FEC871I;VX@<')O=&]C;VP@=&\@=7-E("AT8W`L('5N:7@@
M971C+BD*("`@("`J("`K(&AO<W1S<&5C.B!(;W-T('-P96-I9FEC871I;VX@
M*&AO<W1N86UE6SIP;W)T72D*("`@("`J("`K(&1A=&%B87-E.B!$871A8F%S
M92!T;R!U<V4@;VX@=&AE($1"35,@<V5R=F5R"B`@("`@*B`@*R!U<V5R;F%M
M93H@57-E<B!N86UE(&9O<B!L;V=I;@H@("`@("H@("L@<&%S<W=O<F0Z(%!A
M<W-W;W)D(&9O<B!L;V=I;@H@("`@("H*("`@("`J($!A=71H;W(@5&]M87,@
M5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@H@("`@("HO"B`@("!F=6YC=&EO
M;B!P87)S94133B@D9'-N*0H@("`@>PH@("`@("`@("1P87)S960@/2!A<G)A
M>2@*("`@("`@("`@("`@)W!H<'1Y<&4G("`]/B!F86QS92P*("`@("`@("`@
M("`@)V1B<WEN=&%X)R`]/B!F86QS92P*("`@("`@("`@("`@)W5S97)N86UE
M)R`]/B!F86QS92P*("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B!F86QS92P*
M("`@("`@("`@("`@)W!R;W1O8V]L)R`]/B!F86QS92P*("`@("`@("`@("`@
M)VAO<W1S<&5C)R`]/B!F86QS92P*("`@("`@("`@("`@)W!O<G0G("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@)W-O8VME="<@("`]/B!F86QS92P*("`@
M("`@("`@("`@)V1A=&%B87-E)R`]/B!F86QS92P*("`@("`@("`I.PH*("`@
M("`@("!I9B`H:7-?87)R87DH)&1S;BDI('L*("`@("`@("`@("`@)&1S;B`]
M(&%R<F%Y7VUE<F=E*"1P87)S960L("1D<VXI.PH@("`@("`@("`@("!I9B`H
M(21D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@("`@("1D<VY;)V1B
M<WEN=&%X)UT@/2`D9'-N6R=P:'!T>7!E)UT["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N("1D<VX["B`@("`@("`@?0H*("`@("`@("`O+R!&
M:6YD('!H<'1Y<&4@86YD(&1B<WEN=&%X"B`@("`@("`@:68@*"@D<&]S(#T@
M<W1R<&]S*"1D<VXL("<Z+R\G*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("1S='(@/2!S=6)S='(H)&1S;BP@,"P@)'!O<RD["B`@("`@("`@("`@("1D
M<VX@/2!S=6)S='(H)&1S;BP@)'!O<R`K(#,I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1S='(@/2`D9'-N.PH@("`@("`@("`@("`D9'-N(#T@
M3E5,3#L*("`@("`@("!]"@H@("`@("`@("\O($=E="!P:'!T>7!E(&%N9"!D
M8G-Y;G1A>`H@("`@("`@("\O("1S='(@/3X@<&AP='EP92AD8G-Y;G1A>"D*
M("`@("`@("!I9B`H<')E9U]M871C:"@G?%XH+BL_*5PH*"XJ/RE<*21\)RP@
M)'-T<BP@)&%R<BDI('L*("`@("`@("`@("`@)'!A<G-E9%LG<&AP='EP92==
M("`]("1A<G);,5T["B`@("`@("`@("`@("1P87)S961;)V1B<WEN=&%X)UT@
M/2`A)&%R<ELR72`_("1A<G);,5T@.B`D87)R6S)=.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1P87)S961;)W!H<'1Y<&4G72`@/2`D<W1R.PH@
M("`@("`@("`@("`D<&%R<V5D6R=D8G-Y;G1A>"==(#T@)'-T<CL*("`@("`@
M("!]"@H@("`@("`@(&EF("@A8V]U;G0H)&1S;BDI('L*("`@("`@("`@("`@
M<F5T=7)N("1P87)S960["B`@("`@("`@?0H*("`@("`@("`O+R!'970@*&EF
M(&9O=6YD*3H@=7-E<FYA;64@86YD('!A<W-W;W)D"B`@("`@("`@+R\@)&1S
M;B`]/B!U<V5R;F%M93IP87-S=V]R9$!P<F]T;V-O;"MH;W-T<W!E8R]D871A
M8F%S90H@("`@("`@(&EF("@H)&%T(#T@<W1R<G!O<R@D9'-N+"=`)RDI("$]
M/2!F86QS92D@>PH@("`@("`@("`@("`D<W1R(#T@<W5B<W1R*"1D<VXL(#`L
M("1A="D["B`@("`@("`@("`@("1D<VX@/2!S=6)S='(H)&1S;BP@)&%T("L@
M,2D["B`@("`@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D<W1R+"`G.B<I
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P87)S961;)W5S97)N
M86UE)UT@/2!R87=U<FQD96-O9&4H<W5B<W1R*"1S='(L(#`L("1P;W,I*3L*
M("`@("`@("`@("`@("`@("1P87)S961;)W!A<W-W;W)D)UT@/2!R87=U<FQD
M96-O9&4H<W5B<W1R*"1S='(L("1P;W,@*R`Q*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<&%R<V5D6R=U<V5R;F%M92==(#T@
M<F%W=7)L9&5C;V1E*"1S='(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!&:6YD('!R;W1O8V]L(&%N9"!H;W-T<W!E8PH*("`@("`@
M("`O+R`D9'-N(#T^('!R;W1O*'!R;W1O7V]P=',I+V1A=&%B87-E"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H)WQ>*%M>*%TK*5PH*"XJ/RE<*2\_*"XJ/RDD
M?"<L("1D<VXL("1M871C:"DI('L*("`@("`@("`@("`@)'!R;W1O("`@("`@
M(#T@)&UA=&-H6S%=.PH@("`@("`@("`@("`D<')O=&]?;W!T<R`@/2`D;6%T
M8VA;,ET@/R`D;6%T8VA;,ET@.B!F86QS93L*("`@("`@("`@("`@)&1S;B`@
M("`@("`@(#T@)&UA=&-H6S-=.PH*("`@("`@("`O+R`D9'-N(#T^('!R;W1O
M8V]L*VAO<W1S<&5C+V1A=&%B87-E("AO;&0@9F]R;6%T*0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&EF("AS=')P;W,H)&1S;BP@)RLG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@(&QI<W0H)'!R;W1O+"`D9'-N*2`]
M(&5X<&QO9&4H)RLG+"`D9'-N+"`R*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1D<VXL("<O)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("!L:7-T*"1P<F]T;U]O<'1S+"`D9'-N*2`](&5X<&QO9&4H
M)R\G+"`D9'-N+"`R*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1P<F]T;U]O<'1S(#T@)&1S;CL*("`@("`@("`@("`@("`@("1D
M<VX@/2!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!P<F]C97-S('1H92!D:69F97)E;G0@<')O=&]C;VP@;W!T:6]N<PH@("`@
M("`@("1P87)S961;)W!R;W1O8V]L)UT@/2`H(65M<'1Y*"1P<F]T;RDI(#\@
M)'!R;W1O(#H@)W1C<"<["B`@("`@("`@)'!R;W1O7V]P=',@/2!R87=U<FQD
M96-O9&4H)'!R;W1O7V]P=',I.PH@("`@("`@(&EF("@D<&%R<V5D6R=P<F]T
M;V-O;"==(#T]("=T8W`G*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H)'!R
M;W1O7V]P=',L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!L
M:7-T*"1P87)S961;)VAO<W1S<&5C)UTL("1P87)S961;)W!O<G0G72D@/2!E
M>'!L;V1E*"<Z)RP@)'!R;W1O7V]P=',I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'!A<G-E9%LG:&]S='-P96,G72`]("1P<F]T
M;U]O<'1S.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1P87)S
M961;)W!R;W1O8V]L)UT@/3T@)W5N:7@G*2!["B`@("`@("`@("`@("1P87)S
M961;)W-O8VME="==(#T@)'!R;W1O7V]P=',["B`@("`@("`@?0H*("`@("`@
M("`O+R!'970@9&%B87-E(&EF(&%N>0H@("`@("`@("\O("1D<VX@/3X@9&%T
M86)A<V4*("`@("`@("!I9B`H)&1S;BD@>PH@("`@("`@("`@("`O+R`O9&%T
M86)A<V4*("`@("`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1D<VXL("<_
M)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'!A<G-E9%LG9&%T
M86)A<V4G72`]("1D<VX["B`@("`@("`@("`@("\O("]D871A8F%S93]P87)A
M;3$]=F%L=64Q)G!A<F%M,CUV86QU93(*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1P87)S961;)V1A=&%B87-E)UT@/2!S=6)S='(H
M)&1S;BP@,"P@)'!O<RD["B`@("`@("`@("`@("`@("`D9'-N(#T@<W5B<W1R
M*"1D<VXL("1P;W,@*R`Q*3L*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H
M)&1S;BP@)R8G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D
M;W!T<R`](&5X<&QO9&4H)R8G+"`D9'-N*3L*("`@("`@("`@("`@("`@('T@
M96QS92![("\O(&1A=&%B87-E/W!A<F%M,3UV86QU93$*("`@("`@("`@("`@
M("`@("`@("`D;W!T<R`](&%R<F%Y*"1D<VXI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&]P=',@87,@)&]P="D@>PH@
M("`@("`@("`@("`@("`@("`@(&QI<W0H)&ME>2P@)'9A;'5E*2`](&5X<&QO
M9&4H)STG+"`D;W!T*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1P87)S961;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&1O;B=T(&%L;&]W('!A<F%M<R!O=F5R=W)I=&4*("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<G-E9%LD:V5Y72`](')A=W5R;&1E8V]D92@D=F%L=64I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)S960[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@87-S97)T17AT96YS:6]N
M*"D*"B`@("`O*BH*("`@("`J($QO860@82!02%`@9&%T86)A<V4@97AT96YS
M:6]N(&EF(&ET(&ES(&YO="!L;V%D960@86QR96%D>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@=&AE(&)A<V4@;F%M92!O9B!T:&4@97AT96YS:6]N("AW:71H;W5T
M('1H92`N<V\@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@+F1L;"!S
M=69F:7@I"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@
M=&AE(&5X=&5N<VEO;B!W87,@86QR96%D>2!O<B!S=6-C97-S9G5L;'D*("`@
M("`J("`@("`@("`@("`@("`@("!L;V%D960L(&9A;'-E(&EF(&ET(&-O=6QD
M(&YO="!B92!L;V%D960*("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T17AT
M96YS:6]N*"1N86UE*0H@("`@>PH@("`@("`@(&EF("@A97AT96YS:6]N7VQO
M861E9"@D;F%M92DI('L*("`@("`@("`@("`@)&1L97AT(#T@3U-?5TE.1$]7
M4R`_("<N9&QL)R`Z("<N<V\G.PH@("`@("`@("`@("`D9&QP<F5F:7@@/2!/
M4U]724Y$3U=3(#\@)W!H<%\G(#H@)R<["B`@("`@("`@("`@($!D;"@D9&QP
M<F5F:7@@+B`D;F%M92`N("1D;&5X="D["B`@("`@("`@("`@(')E='5R;B!E
M>'1E;G-I;VY?;&]A9&5D*"1N86UE*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"B`@("`O+R!]?7T*?0H*+R\@?7U]"B\O('M[>R!C
M;&%S<R!$0E]%<G)O<@H*+RHJ"B`J($1"7T5R<F]R(&EM<&QE;65N=',@82!C
M;&%S<R!F;W(@<F5P;W)T:6YG('!O<G1A8FQE(&1A=&%B87-E(&5R<F]R"B`J
M(&UE<W-A9V5S+@H@*@H@*B!`<&%C:V%G92`@1$(*("H@0&%U=&AO<B!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^"B`J+PIC;&%S<R!$0E]%<G)O<B!E>'1E
M;F1S(%!%05)?17)R;W(*>PH@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@
M+RHJ"B`@("`@*B!$0E]%<G)O<B!C;VYS=')U8W1O<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@("`D8V]D92`@($1"(&5R<F]R(&-O9&4L(&]R('-T
M<FEN9R!W:71H(&5R<F]R(&UE<W-A9V4N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;6]D92`@('=H870@(F5R<F]R(&UO9&4B('1O(&]P97)A=&4@:6X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1L979E;"`@=VAA="!E<G)O<B!L979E;"!T
M;R!U<V4@9F]R("1M;V1E("8@4$5!4E]%4E)/4E]44DE'1T52"B`@("`@*B!`
M<&%R86T@;6EX960@("`D9&5B=6=I;F9O("!A9&1I=&EO;F%L(&1E8G5G(&EN
M9F\L('-U8V@@87,@=&AE(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H*("`@("`J($!S964@4$5!4E]%<G)O<@H@("`@
M("HO"B`@("!F=6YC=&EO;B!$0E]%<G)O<B@D8V]D92`]($1"7T524D]2+"`D
M;6]D92`](%!%05)?15)23U)?4D5455).+`H@("`@("`@("`@("`@("1L979E
M;"`]($5?55-%4E].3U1)0T4L("1D96)U9VEN9F\@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AI<U]I;G0H)&-O9&4I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y014%27T5R<F]R*"=$0B!%<G)O<CH@)R`N($1".CIE<G)O<DUE<W-A9V4H
M)&-O9&4I+"`D8V]D92P@)&UO9&4L("1L979E;"P@)&1E8G5G:6YF;RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E!%05)?17)R;W(H
M(D1"($5R<F]R.B`D8V]D92(L($1"7T524D]2+"`D;6]D92P@)&QE=F5L+"`D
M9&5B=6=I;F9O*3L*("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*?0H*+R\@
M?7U]"B\O('M[>R!C;&%S<R!$0E]R97-U;'0*"B\J*@H@*B!4:&ES(&-L87-S
M(&EM<&QE;65N=',@82!W<F%P<&5R(&9O<B!A($1"(')E<W5L="!S970N"B`J
M($$@;F5W(&EN<W1A;F-E(&]F('1H:7,@8VQA<W,@=VEL;"!B92!R971U<FYE
M9"!B>2!T:&4@1$(@:6UP;&5M96YT871I;VX*("H@869T97(@<')O8V5S<VEN
M9R!A('%U97)Y('1H870@<F5T=7)N<R!D871A+@H@*@H@*B!`<&%C:V%G92`@
M1$(*("H@0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J+PIC
M;&%S<R!$0E]R97-U;'0*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("!V
M87(@)&1B:#L*("`@('9A<B`D<F5S=6QT.PH@("`@=F%R("1R;W=?8V]U;G1E
M<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!F;W(@;&EM:70@<75E<FEE<RP@
M=&AE(')O=R!T;R!S=&%R="!F971C:&EN9PH@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D;&EM:71?9G)O;2`@/2!N=6QL.PH*("`@("\J
M*@H@("`@("H@9F]R(&QI;6ET('%U97)I97,L('1H92!N=6UB97(@;V8@<F]W
M<R!T;R!F971C:`H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D;&EM:71?8V]U;G0@/2!N=6QL.PH*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!$0E]R97-U;'0@8V]N<W1R
M=6-T;W(N"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)B1D8F@@("!$0B!O8FIE
M8W0@<F5F97)E;F-E"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@
M<F5S=6QT(')E<V]U<F-E(&ED"B`@("`@*B!`<&%R86T@87)R87D@("`@)&]P
M=&EO;G,@87-S;V,@87)R87D@=VET:"!O<'1I;VYA;"!R97-U;'0@;W!T:6]N
M<PH@("`@("HO"B`@("!F=6YC=&EO;B!$0E]R97-U;'0H)B1D8F@L("1R97-U
M;'0L("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^
M9&)H(#T@)B1D8F@["B`@("`@("`@)'1H:7,M/G)E<W5L="`]("1R97-U;'0[
M"B`@("`@("`@9F]R96%C:"`H)&]P=&EO;G,@87,@)&ME>2`]/B`D=F%L=64I
M('L*("`@("`@("`@("`@)'1H:7,M/G-E=$]P=&EO;B@D:V5Y+"`D=F%L=64I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;&EM:71?='EP92`@/2`D9&)H
M+3YF96%T=7)E<ULG;&EM:70G73L*("`@("`@("`D=&AI<RT^875T;V9R964@
M("`@/2`D9&)H+3YO<'1I;VYS6R=A=71O9G)E92==.PH@("`@("`@("1T:&ES
M+3YF971C:&UO9&4@("`]("1D8F@M/F9E=&-H;6]D93L*("`@("`@("`D=&AI
M<RT^9F5T8VAM;V1E7V]B:F5C=%]C;&%S<R`]("1D8F@M/F9E=&-H;6]D95]O
M8FIE8W1?8VQA<W,["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T3W!T:6]N*"1K
M97DL("1V86QU92`](&YU;&PI"B`@("!["B`@("`@("`@<W=I=&-H("@D:V5Y
M*2!["B`@("`@("`@("`@(&-A<V4@)VQI;6ET7V9R;VTG.@H@("`@("`@("`@
M("`@("`@)'1H:7,M/FQI;6ET7V9R;VT@/2`D=F%L=64[(&)R96%K.PH@("`@
M("`@("`@("!C87-E("=L:6UI=%]C;W5N="<Z"B`@("`@("`@("`@("`@("`D
M=&AI<RT^;&EM:71?8V]U;G0@/2`D=F%L=64[(&)R96%K.PH@("`@("`@('T*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:%)O=R@I"@H@("`@
M+RHJ"B`@("`@*B!&971C:"!A(')O=R!O9B!D871A(&%N9"!R971U<FX@:70@
M8GD@<F5F97)E;F-E(&EN=&\@86X@87)R87DN"B`@("`@*@H@("`@("H@5&AE
M('1Y<&4@;V8@87)R87D@<F5T=7)N960@8V%N(&)E(&-O;G1R;VQL960@96ET
M:&5R(&)Y('-E='1I;F<@=&AI<PH@("`@("H@;65T:&]D)W,@/'9A<CXD9F5T
M8VAM;V1E/"]V87(^('!A<F%M971E<B!O<B!B>2!C:&%N9VEN9R!T:&4@9&5F
M875L=`H@("`@("H@9F5T8V@@;6]D92!S971&971C:$UO9&4H*2!B969O<F4@
M8V%L;&EN9R!T:&ES(&UE=&AO9"X*("`@("`J"B`@("`@*B!4:&5R92!A<F4@
M='=O(&]P=&EO;G,@9F]R('-T86YD87)D:7II;F<@=&AE(&EN9F]R;6%T:6]N
M(')E='5R;F5D"B`@("`@*B!F<F]M(&1A=&%B87-E<RP@96YS=7)I;F<@=&AE
M:7(@=F%L=65S(&%R92!C;VYS:7-T96YT('=H96X@8VAA;F=I;F<*("`@("`J
M($1"35,G<RX@(%1H97-E('!O<G1A8FEL:71Y(&]P=&EO;G,@8V%N(&)E('1U
M<FYE9"!O;B!W:&5N(&-R96%T:6YG(&$*("`@("`J(&YE=R!$0B!O8FIE8W0@
M;W(@8GD@=7-I;F<@<V5T3W!T:6]N*"DN"B`@("`@*@H@("`@("H@("`K(#QS
M86UP/D1"7U!/4E1!0DE,25197TQ/5T520T%313PO<V%M<#X*("`@("`J("`@
M("!C;VYV97)T(&YA;65S(&]F(&9I96QD<R!T;R!L;W=E<B!C87-E"B`@("`@
M*@H@("`@("H@("`K(#QS86UP/D1"7U!/4E1!0DE,25197U)44DE-/"]S86UP
M/@H@("`@("H@("`@(')I9VAT('1R:6T@=&AE(&1A=&$*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("1F971C:&UO9&4@(&AO=R!T:&4@<F5S=6QT:6YG(&%R
M<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT("1R;W=N
M=6T@("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@82!R;W<@;V8@9&%T82P@3E5,3"!O;B!N;R!M;W)E
M(')O=W,@;W(@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@;V)J
M96-T(&]N(&5R<F]R"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G-E
M=$]P=&EO;B@I+"!$0E]C;VUM;VXZ.G-E=$9E=&-H36]D92@I"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9F5T8VA2;W<H
M)&9E=&-H;6]D92`]($1"7T9%5$-(34]$15]$149!54Q4+"`D<F]W;G5M/6YU
M;&PI"B`@("!["B`@("`@("`@:68@*"1F971C:&UO9&4@/3T]($1"7T9%5$-(
M34]$15]$149!54Q4*2!["B`@("`@("`@("`@("1F971C:&UO9&4@/2`D=&AI
M<RT^9F5T8VAM;V1E.PH@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D
M92`]/3T@1$)?1D540TA-3T1%7T]"2D5#5"D@>PH@("`@("`@("`@("`D9F5T
M8VAM;V1E(#T@1$)?1D540TA-3T1%7T%34T]#.PH@("`@("`@("`@("`D;V)J
M96-T7V-L87-S(#T@)'1H:7,M/F9E=&-H;6]D95]O8FIE8W1?8VQA<W,["B`@
M("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;&EM:71?9G)O;2`A/3T@;G5L
M;"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G)O=U]C;W5N=&5R(#T]/2!N
M=6QL*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<F]W7V-O=6YT97(@/2`D
M=&AI<RT^;&EM:71?9G)O;3L*("`@("`@("`@("`@("`@("\O(%-K:7`@<F]W
M<PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YL:6UI=%]T>7!E(#T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@
M("`@("`@("`@('=H:6QE("@D:2LK(#P@)'1H:7,M/FQI;6ET7V9R;VTI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1B:"T^9F5T8VA);G1O
M*"1T:&ES+3YR97-U;'0L("1A<G(L("1F971C:&UO9&4I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)'1H:7,M/G)O=U]C;W5N=&5R(#X]("@*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;&EM:71?9G)O;2`K("1T:&ES+3YL:6UI
M=%]C;W5N="DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^875T;V9R964I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9G)E92@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1M
M<"`](&YU;&P["B`@("`@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/FQI;6ET7W1Y<&4@/3T@
M)V5M=6QA=&4G*2!["B`@("`@("`@("`@("`@("`D<F]W;G5M(#T@)'1H:7,M
M/G)O=U]C;W5N=&5R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3YR;W=?8V]U;G1E<BLK.PH@("`@("`@('T*("`@("`@("`D<F5S(#T@)'1H
M:7,M/F1B:"T^9F5T8VA);G1O*"1T:&ES+3YR97-U;'0L("1A<G(L("1F971C
M:&UO9&4L("1R;W=N=6TI.PH@("`@("`@(&EF("@D<F5S(#T]/2!$0E]/2RD@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)&]B:F5C=%]C;&%S<RDI('L*("`@
M("`@("`@("`@("`@("\O(&1E9F%U;'0@;6]D92!S<&5C:69I960@:6X@1$)?
M8V]M;6]N.CIF971C:&UO9&5?;V)J96-T7V-L87-S('!R;W!E<G1Y"B`@("`@
M("`@("`@("`@("!I9B`H)&]B:F5C=%]C;&%S<R`]/2`G<W1D0VQA<W,G*2![
M"B`@("`@("`@("`@("`@("`@("`@)&%R<B`]("AO8FIE8W0I("1A<G(["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1A
M<G(@/2`F;F5W("1O8FIE8W1?8VQA<W,H)&%R<BD["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1A<G(["B`@
M("`@("`@?0H@("`@("`@(&EF("@D<F5S(#T](&YU;&P@)B8@)'1H:7,M/F%U
M=&]F<F5E*2!["B`@("`@("`@("`@("1T:&ES+3YF<F5E*"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&9E=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!&971C:"!A(')O
M=R!O9B!D871A(&EN=&\@86X@87)R87D@=VAI8V@@:7,@<&%S<V5D(&)Y(')E
M9F5R96YC92X*("`@("`J"B`@("`@*B!4:&4@='EP92!O9B!A<G)A>2!R971U
M<FYE9"!C86X@8F4@8V]N=')O;&QE9"!E:71H97(@8GD@<V5T=&EN9R!T:&ES
M"B`@("`@*B!M971H;V0G<R`\=F%R/B1F971C:&UO9&4\+W9A<CX@<&%R86UE
M=&5R(&]R(&)Y(&-H86YG:6YG('1H92!D969A=6QT"B`@("`@*B!F971C:"!M
M;V1E('-E=$9E=&-H36]D92@I(&)E9F]R92!C86QL:6YG('1H:7,@;65T:&]D
M+@H@("`@("H*("`@("`J(%1H97)E(&%R92!T=V\@;W!T:6]N<R!F;W(@<W1A
M;F1A<F1I>FEN9R!T:&4@:6YF;W)M871I;VX@<F5T=7)N960*("`@("`J(&9R
M;VT@9&%T86)A<V5S+"!E;G-U<FEN9R!T:&5I<B!V86QU97,@87)E(&-O;G-I
M<W1E;G0@=VAE;B!C:&%N9VEN9PH@("`@("H@1$)-4R=S+B`@5&AE<V4@<&]R
M=&%B:6QI='D@;W!T:6]N<R!C86X@8F4@='5R;F5D(&]N('=H96X@8W)E871I
M;F<@80H@("`@("H@;F5W($1"(&]B:F5C="!O<B!B>2!U<VEN9R!S971/<'1I
M;VXH*2X*("`@("`J"B`@("`@*B`@("L@/'-A;7`^1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%/"]S86UP/@H@("`@("H@("`@(&-O;G9E<G0@;F%M97,@;V8@
M9FEE;&1S('1O(&QO=V5R(&-A<V4*("`@("`J"B`@("`@*B`@("L@/'-A;7`^
M1$)?4$]25$%"24Q)5%E?4E1224T\+W-A;7`^"B`@("`@*B`@("`@<FEG:'0@
M=')I;2!T:&4@9&%T80H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&%R
M<B`@("`@("`H<F5F97)E;F-E*2!A<G)A>2!W:&5R92!D871A(&9R;VT@=&AE
M(')O=PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('-H;W5L9"!B
M92!P;&%C960*("`@("`J($!P87)A;2!I;G0@("`D9F5T8VAM;V1E("!H;W<@
M=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@
M0'!A<F%M(&EN="`@("1R;W=N=6T@("`@('1H92!R;W<@;G5M8F5R('1O(&9E
M=&-H"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C
M8V5S<RP@3E5,3"!O;B!N;R!M;W)E(')O=W,@;W(*("`@("`J("`@("`@("`@
M("`@("`@(&$@1$)?17)R;W(@;V)J96-T(&]N(&5R<F]R"B`@("`@*@H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I+"!$0E]C;VUM;VXZ.G-E
M=$9E=&-H36]D92@I"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!F971C:$EN=&\H)B1A<G(L("1F971C:&UO9&4@/2!$0E]&
M151#2$U/1$5?1$5&055,5"P@)')O=VYU;3UN=6QL*0H@("`@>PH@("`@("`@
M(&EF("@D9F5T8VAM;V1E(#T]/2!$0E]&151#2$U/1$5?1$5&055,5"D@>PH@
M("`@("`@("`@("`D9F5T8VAM;V1E(#T@)'1H:7,M/F9E=&-H;6]D93L*("`@
M("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@/3T]($1"7T9%5$-(34]$
M15]/0DI%0U0I('L*("`@("`@("`@("`@)&9E=&-H;6]D92`]($1"7T9%5$-(
M34]$15]!4U-/0SL*("`@("`@("`@("`@)&]B:F5C=%]C;&%S<R`]("1T:&ES
M+3YF971C:&UO9&5?;V)J96-T7V-L87-S.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/FQI;6ET7V9R;VT@(3T](&YU;&PI('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YR;W=?8V]U;G1E<B`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G)O=U]C;W5N=&5R(#T@)'1H:7,M/FQI;6ET7V9R;VT[
M"B`@("`@("`@("`@("`@("`O+R!3:VEP(')O=W,*("`@("`@("`@("`@("`@
M(&EF("@D=&AI<RT^;&EM:71?='EP92`]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H
M)&DK*R`\("1T:&ES+3YL:6UI=%]F<F]M*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YD8F@M/F9E=&-H26YT;R@D=&AI<RT^<F5S=6QT+"`D
M87)R+"`D9F5T8VAM;V1E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T
M:&ES+3YR;W=?8V]U;G1E<B`^/2`H"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FQI;6ET7V9R;VT@*R`D=&AI<RT^;&EM:71?8V]U;G0I*0H@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F%U=&]F<F5E*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^;&EM:71?='EP92`]/2`G
M96UU;&%T92<I('L*("`@("`@("`@("`@("`@("1R;W=N=6T@/2`D=&AI<RT^
M<F]W7V-O=6YT97(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES
M+3YR;W=?8V]U;G1E<BLK.PH@("`@("`@('T*("`@("`@("`D<F5S(#T@)'1H
M:7,M/F1B:"T^9F5T8VA);G1O*"1T:&ES+3YR97-U;'0L("1A<G(L("1F971C
M:&UO9&4L("1R;W=N=6TI.PH@("`@("`@(&EF("@D<F5S(#T]/2!$0E]/2RD@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)&]B:F5C=%]C;&%S<RDI('L*("`@
M("`@("`@("`@("`@("\O(&1E9F%U;'0@;6]D92!S<&5C:69I960@:6X@1$)?
M8V]M;6]N.CIF971C:&UO9&5?;V)J96-T7V-L87-S('!R;W!E<G1Y"B`@("`@
M("`@("`@("`@("!I9B`H)&]B:F5C=%]C;&%S<R`]/2`G<W1D0VQA<W,G*2![
M"B`@("`@("`@("`@("`@("`@("`@)&%R<B`]("AO8FIE8W0I("1A<G(["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1A
M<G(@/2!N97<@)&]B:F5C=%]C;&%S<R@D87)R*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@
M("`@("`@?0H@("`@("`@(&EF("@D<F5S(#T](&YU;&P@)B8@)'1H:7,M/F%U
M=&]F<F5E*2!["B`@("`@("`@("`@("1T:&ES+3YF<F5E*"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T('1H92!T:&4@
M;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT('1H92!N=6UB97(@;V8@8V]L=6UN<RP@;W(@82!$
M0B!E<G)O<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&YU;4-O;',H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9&)H+3YN=6U#;VQS*"1T:&ES+3YR97-U;'0I.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@=&AE(&YU;6)E<B!O9B!R;W=S+"!O<B!A
M($1"(&5R<F]R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YD8F@M/FYU;5)O=W,H)'1H:7,M/G)E<W5L="D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@
M("`@*B!'970@=&AE(&YE>'0@<F5S=6QT(&EF(&$@8F%T8V@@;V8@<75E<FEE
M<R!W87,@97AE8W5T960N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L('1R
M=64@:68@82!N97<@<F5S=6QT(&ES(&%V86EL86)L92!O<B!F86QS92!I9B!N
M;W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@;F5X=%)E<W5L="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YD8F@M/FYE>'1297-U;'0H)'1H:7,M/G)E<W5L="D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9G)E92@I"@H@("`@+RHJ"B`@("`@*B!&
M<F5E<R!T:&4@<F5S;W5R8V5S(&%L;&]C871E9"!F;W(@=&AI<R!R97-U;'0@
M<V5T+@H@("`@("H@0')E='5R;B`@:6YT(&5R<F]R(&-O9&4*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E
M*"D*("`@('L*("`@("`@("`D97)R(#T@)'1H:7,M/F1B:"T^9G)E95)E<W5L
M="@D=&AI<RT^<F5S=6QT*3L*("`@("`@("!I9BA$0CHZ:7-%<G)O<B@D97)R
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/G)E<W5L="`](&9A;'-E.PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@
M("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9`H@("`@("H@0&EN=&5R;F%L"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@=&%B;&5);F9O*"1M;V1E(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H:7-?<W1R:6YG*"1M;V1E*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F1B:"T^<F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%4
M02D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^9&)H+3YT86)L
M94EN9F\H)'1H:7,L("1M;V1E*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!G9712;W=#;W5N=&5R*"D*"B`@("`O*BH*("`@("`J(')E='5R;G,@
M=&AE(&%C='5A;"!R;W<@;G5M8F5R"B`@("`@*B!`<F5T=7)N(&EN=&5G97(*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F]W0V]U;G1E<B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YR;W=?8V]U;G1E<CL*("`@('T*("`@("\O
M('U]?0I]"@HO+R!]?7T*+R\@>WM[(&-L87-S($1"7U)O=PH*+RHJ"B`J(%!E
M87(@1$(@4F]W($]B:F5C=`H@*B!`<V5E($1"7V-O;6UO;CHZ<V5T1F5T8VA-
M;V1E*"D*("HO"F-L87-S($1"7W)O=PI["B`@("`O+R![>WL@8V]N<W1R=6-T
M;W(*"B`@("`O*BH*("`@("`J(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E(')O=R!D871A(&%S(&%R<F%Y"B`@("`@*B\*("`@
M(&9U;F-T:6]N($1"7W)O=R@F)&%R<BD*("`@('L*("`@("`@("!F;W)E86-H
M("@D87)R(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T:&ES
M+3XD:V5Y(#T@)B1A<G);)&ME>5T["B`@("`@("`@?0H@("`@?0H*("`@("\O
M('U]?0I]"@HO+R!]?7T*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B
M+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL
M+G!H<```````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q-C(T,P`Q,#0Q-S,V,S`P-P`P,38W-#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@
M?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0
M(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!-86EL+G!H<"QV(#$N-B`R,#`S+S`V+S(V(#`W
M.C`U.C,V(&IO;B!%>'`@)`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO
M*BH*("H@4$5!4B=S($UA:6PZ.B!I;G1E<F9A8V4N($1E9FEN97,@=&AE(&EN
M=&5R9F%C92!F;W(@:6UP;&5M96YT:6YG"B`J(&UA:6QE<G,@=6YD97(@=&AE
M(%!%05(@:&EE<F%R8VAY+"!A;F0@<')O=FED97,@<W5P<&]R=&EN9R!F=6YC
M=&EO;G,*("H@=7-E9G5L(&EN(&UU;'1I<&QE(&UA:6QE<B!B86-K96YD<RX*
M("H*("H@0&%C8V5S<R!P=6)L:6,*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q
M+C8@)`H@*B!`<&%C:V%G92!-86EL"B`J+PIC;&%S<R!-86EL"GL*("`@("\J
M*@H@("`@("H@3&EN92!T97)M:6YA=&]R('5S960@9F]R('-E<&%R871I;F<@
M:&5A9&5R(&QI;F5S+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1S97`@/2`B7')<;B(["@H@("`@+RHJ"B`@("`@*B!0<F]V:61E<R!A
M;B!I;G1E<F9A8V4@9F]R(&=E;F5R871I;F<@36%I;#HZ(&]B:F5C=',@;V8@
M=F%R:6]U<PH@("`@("H@='EP97,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D<FEV97(@5&AE(&MI;F0@;V8@36%I;#HZ(&]B:F5C="!T;R!I;G-T
M86YT:6%T92X*("`@("`J($!P87)A;2!A<G)A>2`@)'!A<F%M<R!4:&4@<&%R
M86UE=&5R<R!T;R!P87-S('1O('1H92!-86EL.CH@;V)J96-T+@H@("`@("H@
M0')E='5R;B!O8FIE8W0@36%I;"!A(&EN<W1A;F-E(&]F('1H92!D<FEV97(@
M8VQA<W,@;W(@:68@9F%I;',@82!014%2($5R<F]R"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!F86-T;W)Y*"1D<FEV97(L
M("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!S
M=')T;VQO=V5R*"1D<FEV97(I.PH@("`@("`@($!I;F-L=61E7V]N8V4@)TUA
M:6PO)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)TUA
M:6Q?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA
M<W,I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@)&-L87-S*"1P87)A;7,I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=5;F%B;&4@=&\@9FEN9"!C;&%S<R!F;W(@9')I=F5R("<@
M+B`D9')I=F5R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)
M;7!L96UE;G1S($UA:6PZ.G-E;F0H*2!F=6YC=&EO;B!U<VEN9R!P:'`G<R!B
M=6EL="UI;B!M86EL*"D*("`@("`J(&-O;6UA;F0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1R96-I<&EE;G1S($5I=&AE<B!A(&-O;6UA+7-E<&5R
M871E9"!L:7-T(&]F(')E8VEP:65N=',*("`@("`J("`@("`@("`@("`@("`H
M4D9#.#(R(&-O;7!L:6%N="DL(&]R(&%N(&%R<F%Y(&]F(')E8VEP:65N=',L
M"B`@("`@*B`@("`@("`@("`@("`@96%C:"!21D,X,C(@=F%L:60N(%1H:7,@
M;6%Y(&-O;G1A:6X@<F5C:7!I96YT<R!N;W0*("`@("`J("`@("`@("`@("`@
M("!S<&5C:69I960@:6X@=&AE(&AE861E<G,L(&9O<B!"8V,Z+"!R97-E;F1I
M;F<*("`@("`J("`@("`@("`@("`@("!M97-S86=E<RP@971C+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D:&5A9&5R<R!4:&4@87)R87D@;V8@:&5A
M9&5R<R!T;R!S96YD('=I=&@@=&AE(&UA:6PL(&EN(&%N"B`@("`@*B`@("`@
M("`@("`@("`@87-S;V-I871I=F4@87)R87DL('=H97)E('1H92!A<G)A>2!K
M97D@:7,@=&AE"B`@("`@*B`@("`@("`@("`@("`@:&5A9&5R(&YA;64@*&EE
M+"`G4W5B:F5C="<I+"!A;F0@=&AE(&%R<F%Y('9A;'5E"B`@("`@*B`@("`@
M("`@("`@("`@:7,@=&AE(&AE861E<B!V86QU92`H:64L("=T97-T)RDN(%1H
M92!H96%D97(*("`@("`J("`@("`@("`@("`@("!P<F]D=6-E9"!F<F]M('1H
M;W-E('9A;'5E<R!W;W5L9"!B92`G4W5B:F5C=#H*("`@("`J("`@("`@("`@
M("`@("!T97-T)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V1Y
M(%1H92!F=6QL('1E>'0@;V8@=&AE(&UE<W-A9V4@8F]D>2P@:6YC;'5D:6YG
M(&%N>0H@("`@("H@("`@("`@("`@("`@("!-:6UE('!A<G1S+"!E=&,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS('1R=64@;VX@<W5C
M8V5S<RP@;W(@82!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@(&-O
M;G1A:6YI;F<@82!D97-C<FEP=&EV92!E<G)O<B!M97-S86=E(&]N"B`@("`@
M*B`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0&1E<')E8V%T960@=7-E($UA:6Q?;6%I;#HZ<V5N9"!I;G-T
M96%D"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F0H)')E8VEP:65N=',L("1H
M96%D97)S+"`D8F]D>2D*("`@('L*("`@("`@("`O+R!I9B!W92=R92!P87-S
M960@86X@87)R87D@;V8@<F5C:7!I96YT<RP@:6UP;&]D92!I="X*("`@("`@
M("!I9B`H:7-?87)R87DH)')E8VEP:65N=',I*2!["B`@("`@("`@("`@("1R
M96-I<&EE;G1S(#T@:6UP;&]D92@G+"`G+"`D<F5C:7!I96YT<RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!G970@=&AE(%-U8FIE8W0@;W5T(&]F('1H92!H
M96%D97)S(&%R<F%Y('-O('1H870@=V4@8V%N"B`@("`@("`@+R\@<&%S<R!I
M="!A<R!A('-E<&5R871E(&%R9W5M96YT('1O(&UA:6PH*2X*("`@("`@("`D
M<W5B:F5C="`]("<G.PH@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG4W5B
M:F5C="==*2D@>PH@("`@("`@("`@("`D<W5B:F5C="`]("1H96%D97)S6R=3
M=6)J96-T)UT["B`@("`@("`@("`@('5N<V5T*"1H96%D97)S6R=3=6)J96-T
M)UTI.PH@("`@("`@('T*"B`@("`@("`@+R\@9FQA='1E;B!T:&4@:&5A9&5R
M<R!O=70N"B`@("`@("`@;&ES="@L)'1E>'1?:&5A9&5R<RD@/2!-86EL.CIP
M<F5P87)E2&5A9&5R<R@D:&5A9&5R<RD["@H@("`@("`@(')E='5R;B!M86EL
M*"1R96-I<&EE;G1S+"`D<W5B:F5C="P@)&)O9'DL("1T97AT7VAE861E<G,I
M.PH*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@86X@87)R87D@;V8@;6%I
M;"!H96%D97)S(&%N9"!R971U<FX@82!S=')I;F<@8V]N=&%I;FEN9PH@("`@
M("H@=&5X="!U<V%B;&4@:6X@<V5N9&EN9R!A(&UE<W-A9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D
M97)S('1O('!R97!A<F4L(&EN(&%N(&%S<V]C:6%T:79E"B`@("`@*B`@("`@
M("`@("`@("`@87)R87DL('=H97)E('1H92!A<G)A>2!K97D@:7,@=&AE(&AE
M861E<B!N86UE("AI92P*("`@("`J("`@("`@("`@("`@("`G4W5B:F5C="<I
M+"!A;F0@=&AE(&%R<F%Y('9A;'5E(&ES('1H92!H96%D97(*("`@("`J("`@
M("`@("`@("`@("!V86QU92`H:64L("=T97-T)RDN(%1H92!H96%D97(@<')O
M9'5C960@9G)O;2!T:&]S90H@("`@("H@("`@("`@("`@("`@('9A;'5E<R!W
M;W5L9"!B92`G4W5B:F5C=#H@=&5S="<N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!2971U<FYS(&9A;'-E(&EF(&ET(&5N8V]U;G1E<G,@82!B860@
M861D<F5S<RP*("`@("`J("`@("`@("`@("`@("`@;W1H97)W:7-E(')E='5R
M;G,@86X@87)R87D@8V]N=&%I;FEN9R!T=V\*("`@("`J("`@("`@("`@("`@
M("`@96QE;65N=',Z($%N>2!&<F]M.B!A9&1R97-S(&9O=6YD(&EN('1H92!H
M96%D97)S+`H@("`@("H@("`@("`@("`@("`@("!A;F0@=&AE('!L86EN('1E
M>'0@=F5R<VEO;B!O9B!T:&4@:&5A9&5R<RX*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!P<F5P87)E2&5A9&5R<R@D:&5A
M9&5R<RD*("`@('L*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@
M("1F<F]M(#T@;G5L;#L*"B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@
M)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*"1K97D@/3T]("=&
M<F]M)RD@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("=-86EL+U)&
M0S@R,BYP:'`G.PH*("`@("`@("`@("`@("`@("1A9&1R97-S97,@/2!-86EL
M7U)&0S@R,CHZ<&%R<V5!9&1R97-S3&ES="@D=F%L=64L("=L;V-A;&AO<W0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9A;'-E*3L*("`@("`@("`@("`@("`@("1F<F]M
M(#T@)&%D9')E<W-E<ULP72T^;6%I;&)O>"`N("=`)R`N("1A9&1R97-S97-;
M,%TM/FAO<W0["@H@("`@("`@("`@("`@("`@+R\@4F5J96-T(&5N=F5L;W!E
M($9R;VTZ(&%D9')E<W-E<R!W:71H('-P86-E<RX*("`@("`@("`@("`@("`@
M(&EF("AS=')S='(H)&9R;VTL("<@)RDI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)&QI;F5S6UT@/2`D:V5Y("X@)SH@)R`N("1V86QU93L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1K97D@/3T]("=296-E:79E9"<I('L*("`@("`@
M("`@("`@("`@("\O(%!U="!296-E:79E9#H@:&5A9&5R<R!A="!T:&4@=&]P
M+B`@4W!A;2!D971E8W1O<G,@;V9T96X*("`@("`@("`@("`@("`@("\O(&9L
M86<@;65S<V%G97,@=VET:"!296-E:79E9#H@:&5A9&5R<R!A9G1E<B!T:&4@
M4W5B:F5C=#H*("`@("`@("`@("`@("`@("\O(&%S('-P86TN"B`@("`@("`@
M("`@("`@("!A<G)A>5]U;G-H:69T*"1L:6YE<RP@)&ME>2`N("<Z("<@+B`D
M=F%L=64I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&QI;F5S6UT@/2`D:V5Y("X@)SH@)R`N("1V86QU93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1F<F]M+"!J;VEN
M*"1T:&ES+3YS97`L("1L:6YE<RD@+B`D=&AI<RT^<V5P*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%1A:V4@82!S970@;V8@<F5C:7!I96YT<R!A;F0@<&%R
M<V4@=&AE;2P@<F5T=7)N:6YG(&%N(&%R<F%Y(&]F"B`@("`@*B!B87)E(&%D
M9')E<W-E<R`H9F]R=V%R9"!P871H<RD@=&AA="!C86X@8F4@<&%S<V5D('1O
M('-E;F1M86EL"B`@("`@*B!O<B!A;B!S;71P('-E<G9E<B!W:71H('1H92!R
M8W!T('1O.B!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"!%
M:71H97(@82!C;VUM82US97!E<F%T960@;&ES="!O9B!R96-I<&EE;G1S"B`@
M("`@*B`@("`@("`@("`@("`@*%)&0S@R,B!C;VUP;&EA;G0I+"!O<B!A;B!A
M<G)A>2!O9B!R96-I<&EE;G1S+`H@("`@("H@("`@("`@("`@("`@(&5A8V@@
M4D9#.#(R('9A;&ED+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@06X@
M87)R87D@;V8@9F]R=V%R9"!P871H<R`H8F%R92!A9&1R97-S97,I+@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E
M4F5C:7!I96YT<R@D<F5C:7!I96YT<RD*("`@('L*("`@("`@("!I;F-L=61E
M7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["@H@("`@("`@("\O(&EF('=E)W)E
M('!A<W-E9"!A;B!A<G)A>2P@87-S=6UE(&%D9')E<W-E<R!A<F4@=F%L:60@
M86YD"B`@("`@("`@+R\@:6UP;&]D92!T:&5M(&)E9F]R92!P87)S:6YG+@H@
M("`@("`@(&EF("AI<U]A<G)A>2@D<F5C:7!I96YT<RDI('L*("`@("`@("`@
M("`@)')E8VEP:65N=',@/2!I;7!L;V1E*"<L("<L("1R96-I<&EE;G1S*3L*
M("`@("`@("!]"@H@("`@("`@("\O(%!A<G-E(')E8VEP:65N=',L(&QE879I
M;F<@;W5T(&%L;"!P97)S;VYA;"!I;F9O+B!4:&ES(&ES"B`@("`@("`@+R\@
M9F]R('-M='`@<F5C:7!I96YT<RP@971C+B!!;&P@<F5L979A;G0@<&5R<V]N
M86P@:6YF;W)M871I;VX*("`@("`@("`O+R!S:&]U;&0@86QR96%D>2!B92!I
M;B!T:&4@:&5A9&5R<RX*("`@("`@("`D861D<F5S<V5S(#T@36%I;%]21D,X
M,C(Z.G!A<G-E061D<F5S<TQI<W0H)')E8VEP:65N=',L("=L;V-A;&AO<W0G
M+"!F86QS92D["B`@("`@("`@)')E8VEP:65N=',@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D861D<F5S<V5S*2D@>PH@("`@("`@("`@("!F
M;W)E86-H("@D861D<F5S<V5S(&%S("1O8BD@>PH@("`@("`@("`@("`@("`@
M)')E8VEP:65N='-;72`]("1O8BT^;6%I;&)O>"`N("=`)R`N("1O8BT^:&]S
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M96-I<&EE;G1S.PH@("`@?0H*?0H_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%
M05(N<&AP````````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#<R-S`Q`#$P-#$W,S8S,#`W`#`Q-C8Q,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO+PHO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2+"!T:&4@4$A0($5X
M=&5N<VEO;B!A;F0@07!P;&EC871I;VX@4F5P;W-I=&]R>2`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!U
M<FPZ("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W)S.B!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG0'!H<"YN970^("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\("`@("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C
M;F5T+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@4$5!4BYP:'`L
M=B`Q+C<W(#(P,#0O,#(O,#<@,#0Z-#(Z,#<@8V5L;&]G($5X<"`D"B\O"@ID
M969I;F4H)U!%05)?15)23U)?4D5455).)RP@("`@(#$I.PID969I;F4H)U!%
M05)?15)23U)?4%))3E0G+"`@("`@(#(I.PID969I;F4H)U!%05)?15)23U)?
M5%))1T=%4B<L("`@(#0I.PID969I;F4H)U!%05)?15)23U)?1$E%)RP@("`@
M("`@(#@I.PID969I;F4H)U!%05)?15)23U)?0T%,3$)!0TLG+"`@,38I.PID
M969I;F4H)U!%05)?15)23U)?15A#15!424].)RP@,S(I.PID969I;F4H)U!%
M05)?6D4R)RP@*&9U;F-T:6]N7V5X:7-T<R@G=F5R<VEO;E]C;VUP87)E)RD@
M)B8*("`@("`@("`@("`@("`@("`@("!V97)S:6]N7V-O;7!A<F4H>F5N9%]V
M97)S:6]N*"DL("(R+61E=B(L(")G92(I*2D["@II9B`H<W5B<W1R*%!(4%]/
M4RP@,"P@,RD@/3T@)U=)3B<I('L*("`@(&1E9FEN92@G3U-?5TE.1$]74R<L
M('1R=64I.PH@("`@9&5F:6YE*"=/4U]53DE8)RP@("`@9F%L<V4I.PH@("`@
M9&5F:6YE*"=014%27T]3)RP@("`@)U=I;F1O=W,G*3L*?2!E;'-E('L*("`@
M(&1E9FEN92@G3U-?5TE.1$]74R<L(&9A;'-E*3L*("`@(&1E9FEN92@G3U-?
M54Y)6"<L("`@('1R=64I.PH@("`@9&5F:6YE*"=014%27T]3)RP@("`@)U5N
M:7@G*3L@+R\@8FQA=&%N="!A<W-U;7!T:6]N"GT*"B\O(&EN<W1A;G0@8F%C
M:W=A<F1S(&-O;7!A=&EB:6QI='D*:68@*"%D969I;F5D*"=0051(7U-%4$%2
M051/4B<I*2!["B`@("!I9B`H3U-?5TE.1$]74RD@>PH@("`@("`@(&1E9FEN
M92@G4$%42%]315!!4D%43U(G+"`G.R<I.PH@("`@?2!E;'-E('L*("`@("`@
M("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@)SHG*3L*("`@('T*?0H*)$=,
M3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==("`@("`](%!%05)?
M15)23U)?4D5455)..PHD1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O
M<'1I;VYS)UT@(#T@15]54T527TY/5$E#13L*)$=,3T)!3%-;)U]014%27V1E
M<W1R=6-T;W)?;V)J96-T7VQI<W0G72`](&%R<F%Y*"D["B1'3$]"04Q36R=?
M4$5!4E]S:'5T9&]W;E]F=6YC<R==("`@("`@("`@/2!A<G)A>2@I.PHD1TQ/
M0D%,4ULG7U!%05)?97)R;W)?:&%N9&QE<E]S=&%C:R==("`@(#T@87)R87DH
M*3L*"FEN:5]S970H)W1R86-K7V5R<F]R<R<L('1R=64I.PH*+RHJ"B`J($)A
M<V4@8VQA<W,@9F]R(&]T:&5R(%!%05(@8VQA<W-E<RX@(%!R;W9I9&5S(')U
M9&EM96YT87)Y"B`J(&5M=6QA=&EO;B!O9B!D97-T<G5C=&]R<RX*("H*("H@
M268@>6]U('=A;G0@82!D97-T<G5C=&]R(&EN('EO=7(@8VQA<W,L(&EN:&5R
M:70@4$5!4B!A;F0@;6%K92!A"B`J(&1E<W1R=6-T;W(@;65T:&]D(&-A;&QE
M9"!?>6]U<F-L87-S;F%M92`H<V%M92!N86UE(&%S('1H90H@*B!C;VYS=')U
M8W1O<BP@8G5T('=I=&@@82`B7R(@<')E9FEX*2X@($%L<V\L(&EN('EO=7(@
M8V]N<W1R=6-T;W(@>6]U"B`J(&AA=F4@=&\@8V%L;"!T:&4@4$5!4B!C;VYS
M=')U8W1O<CH@)'1H:7,M/E!%05(H*3LN"B`J(%1H92!D97-T<G5C=&]R(&UE
M=&AO9"!W:6QL(&)E(&-A;&QE9"!W:71H;W5T('!A<F%M971E<G,N("!.;W1E
M('1H870*("H@870@:6X@<V]M92!305!)(&EM<&QE;65N=&%T:6]N<R`H<W5C
M:"!A<R!!<&%C:&4I+"!A;GD@;W5T<'5T(&1U<FEN9PH@*B!T:&4@<F5Q=65S
M="!S:'5T9&]W;B`H:6X@=VAI8V@@9&5S=')U8W1O<G,@87)E(&-A;&QE9"D@
M<V5E;7,@=&\@8F4*("H@9&ES8V%R9&5D+B`@268@>6]U(&YE960@=&\@9V5T
M(&%N>2!D96)U9R!I;F9O<FUA=&EO;B!F<F]M('EO=7(*("H@9&5S=')U8W1O
M<BP@=7-E(&5R<F]R7VQO9R@I+"!S>7-L;V<H*2!O<B!S;VUE=&AI;F<@<VEM
M:6QA<BX*("H*("H@24U03U)404Y4(2!4;R!U<V4@=&AE(&5M=6QA=&5D(&1E
M<W1R=6-T;W)S('EO=2!N965D('1O(&-R96%T92!T:&4*("H@;V)J96-T<R!B
M>2!R969E<F5N8V4Z("1O8FH@/28@;F5W(%!%05)?8VAI;&0["B`J"B`J($!S
M:6YC92!02%`@-"XP+C(*("H@0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B0'!H
M<"YN970^"B`J($!S964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO"B`J
M+PIC;&%S<R!014%2"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ
M"B`@("`@*B!7:&5T:&5R('1O(&5N86)L92!I;G1E<FYA;"!D96)U9R!M97-S
M86=E<RX*("`@("`J"B`@("`@*B!`=F%R("`@("!B;V]L"B`@("`@*B!`86-C
M97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1E8G5G(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!$969A=6QT(&5R<F]R(&UO9&4@9F]R('1H:7,@
M;V)J96-T+@H@("`@("H*("`@("`J($!V87(@("`@(&EN=`H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D969A=6QT7V5R<F]R
M7VUO9&4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1&5F875L="!E<G)O<B!O
M<'1I;VYS('5S960@9F]R('1H:7,@;V)J96-T('=H96X@97)R;W(@;6]D90H@
M("`@("H@:7,@4$5!4E]%4E)/4E]44DE'1T52+@H@("`@("H*("`@("`J($!V
M87(@("`@(&EN=`H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]D969A=6QT7V5R<F]R7V]P=&EO;G,@/2!N=6QL.PH*("`@("\J
M*@H@("`@("H@1&5F875L="!E<G)O<B!H86YD;&5R("AC86QL8F%C:RD@9F]R
M('1H:7,@;V)J96-T+"!I9B!E<G)O<B!M;V1E(&ES"B`@("`@*B!014%27T52
M4D]27T-!3$Q"04-++@H@("`@("H*("`@("`J($!V87(@("`@('-T<FEN9PH@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D969A
M=6QT7V5R<F]R7VAA;F1L97(@/2`G)SL*"B`@("`O*BH*("`@("`J(%=H:6-H
M(&-L87-S('1O('5S92!F;W(@97)R;W(@;V)J96-T<RX*("`@("`J"B`@("`@
M*B!`=F%R("`@("!S=')I;F<*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?97)R;W)?8VQA<W,@/2`G4$5!4E]%<G)O<B<["@H@
M("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!E>'!E8W1E9"!E<G)O<G,N"B`@
M("`@*@H@("`@("H@0'9A<B`@("`@87)R87D*("`@("`J($!A8V-E<W,@('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?97AP96-T961?97)R;W)S(#T@87)R
M87DH*3L*"B`@("`O+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C=&]R+B`@4F5G:7-T97)S('1H:7,@;V)J
M96-T(&EN"B`@("`@*B`D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="!F
M;W(@9&5S=')U8W1O<B!E;75L871I;VX@:68@80H@("`@("H@9&5S=')U8W1O
M<B!O8FIE8W0@97AI<W1S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&5R<F]R7V-L87-S("`H;W!T:6]N86PI('=H:6-H(&-L87-S('1O('5S92!F
M;W(*("`@("`J("`@("`@("!E<G)O<B!O8FIE8W1S+"!D969A=6QT<R!T;R!0
M14%27T5R<F]R+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U
M<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!014%2*"1E<G)O<E]C;&%S
M<R`](&YU;&PI"B`@("!["B`@("`@("`@)&-L87-S;F%M92`](&=E=%]C;&%S
M<R@D=&AI<RD["B`@("`@("`@:68@*"1T:&ES+3Y?9&5B=6<I('L*("`@("`@
M("`@("`@<')I;G0@(E!%05(@8V]N<W1R=6-T;W(@8V%L;&5D+"!C;&%S<STD
M8VQA<W-N86UE7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H)&5R<F]R7V-L
M87-S("$]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3Y?97)R;W)?8VQA
M<W,@/2`D97)R;W)?8VQA<W,["B`@("`@("`@?0H@("`@("`@('=H:6QE("@D
M8VQA<W-N86UE*2!["B`@("`@("`@("`@("1D97-T<G5C=&]R(#T@(E\D8VQA
M<W-N86UE(CL*("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,L
M("1D97-T<G5C=&]R*2D@>PH@("`@("`@("`@("`@("`@9VQO8F%L("1?4$5!
M4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T.PH@("`@("`@("`@("`@("`@)%]0
M14%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W1;72`]("8D=&AI<SL*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&-L87-S;F%M92`](&=E=%]P87)E;G1?8VQA<W,H)&-L87-S
M;F%M92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9&5S=')U8W1O<@H*("`@("\J*@H@("`@("H@1&5S
M=')U8W1O<B`H=&AE(&5M=6QA=&5D('1Y<&4@;V8N+BXI+B`@1&]E<R!N;W1H
M:6YG(')I9VAT(&YO=RP*("`@("`J(&)U="!I<R!I;F-L=61E9"!F;W(@9F]R
M=V%R9"!C;VUP871I8FEL:71Y+"!S;R!S=6)C;&%S<PH@("`@("H@9&5S=')U
M8W1O<G,@<VAO=6QD(&%L=V%Y<R!C86QL(&ET+@H@("`@("H*("`@("`J(%-E
M92!T:&4@;F]T92!I;B!T:&4@8VQA<W,@9&5S8VEP=&EO;B!A8F]U="!O=71P
M=70@9G)O;0H@("`@("H@9&5S=')U8W1O<G,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!?4$5!4B@I('L*("`@("`@("!I9B`H)'1H:7,M/E]D96)U9RD@
M>PH@("`@("`@("`@("!P<FEN=&8H(E!%05(@9&5S=')U8W1O<B!C86QL960L
M(&-L87-S/25S7&XB+"!G971?8VQA<W,H)'1H:7,I*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4W1A=&EC4')O<&5R='DH
M*0H*("`@("\J*@H@("`@*B!)9B!Y;W4@:&%V92!A(&-L87-S('1H870G<R!M
M;W-T;'DO96YT:7)E;'D@<W1A=&EC+"!A;F0@>6]U(&YE960@<W1A=&EC"B`@
M("`J('!R;W!E<G1I97,L('EO=2!C86X@=7-E('1H:7,@;65T:&]D('1O('-I
M;75L871E('1H96TN($5G+B!I;B!Y;W5R(&UE=&AO9"AS*0H@("`@*B!D;R!T
M:&ES.B`D;7E687(@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)VUY5F%R
M)RD["B`@("`J(%EO=2!-55-4('5S92!A(')E9F5R96YC92P@;W(@=&AE>2!W
M:6QL(&YO="!P97)S:7-T(0H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@*B!`<&%R86T@('-T<FEN9R`D8VQA<W,@(%1H92!C86QL:6YG(&-L87-S
M;F%M92P@=&\@<')E=F5N="!C;&%S:&5S"B`@("`J($!P87)A;2`@<W1R:6YG
M("1V87(@("`@5&AE('9A<FEA8FQE('1O(')E=')I979E+@H@("`@*B!`<F5T
M=7)N(&UI>&5D("`@02!R969E<F5N8V4@=&\@=&AE('9A<FEA8FQE+B!)9B!N
M;W0@<V5T(&ET('=I;&P@8F4*("`@("H@("`@("`@("`@("`@("`@(&%U=&\@
M:6YI=&EA;&ES960@=&\@3E5,3"X*("`@("HO"B`@("!F=6YC=&EO;B`F9V5T
M4W1A=&EC4')O<&5R='DH)&-L87-S+"`D=F%R*0H@("`@>PH@("`@("`@('-T
M871I8R`D<')O<&5R=&EE<SL*("`@("`@("!R971U<FX@)'!R;W!E<G1I97-;
M)&-L87-S75LD=F%R73L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!R
M96=I<W1E<E-H=71D;W=N1G5N8R@I"@H@("`@+RHJ"B`@("`J(%5S92!T:&ES
M(&9U;F-T:6]N('1O(')E9VES=&5R(&$@<VAU=&1O=VX@;65T:&]D(&9O<B!S
M=&%T:6,*("`@("H@8VQA<W-E<RX*("`@("H*("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("H@0'!A<F%M("!M:7AE9"`D9G5N8R`@5&AE(&9U;F-T:6]N(&YA
M;64@*&]R(&%R<F%Y(&]F(&-L87-S+VUE=&AO9"D@=&\@8V%L;`H@("`@*B!`
M<&%R86T@(&UI>&5D("1A<F=S("!4:&4@87)G=6UE;G1S('1O('!A<W,@=&\@
M=&AE(&9U;F-T:6]N"B`@("`J($!R971U<FX@=F]I9`H@("`@*B\*("`@(&9U
M;F-T:6]N(')E9VES=&5R4VAU=&1O=VY&=6YC*"1F=6YC+"`D87)G<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)$=,3T)!3%-;)U]014%27W-H=71D;W=N
M7V9U;F-S)UU;72`](&%R<F%Y*"1F=6YC+"`D87)G<RD["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@:7-%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!4
M96QL('=H971H97(@82!V86QU92!I<R!A(%!%05(@97)R;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@;6EX960@)&1A=&$@("!T:&4@=F%L=64@=&\@=&5S
M=`H@("`@("H@0'!A<F%M("`@:6YT("`@)&-O9&4@("!I9B`D9&%T82!I<R!A
M;B!E<G)O<B!O8FIE8W0L(')E='5R;B!T<G5E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@(&]N;'D@:68@)&-O9&4@:7,@82!S=')I;F<@86YD"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("1O8FHM/F=E=$UE<W-A9V4H
M*2`]/2`D8V]D92!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]D92!I<R!A;B!I;G1E9V5R(&%N9"`D;V)J+3YG971#;V1E*"D@/3T@)&-O
M9&4*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@8F]O
M;"`@("!T<G5E(&EF('!A<F%M971E<B!I<R!A;B!E<G)O<@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<T5R<F]R*"1D871A+"`D8V]D92`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@:68@*&ES7VYU;&PH)&-O9&4I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*&ES7W-T<FEN
M9R@D8V]D92DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T82T^9V5T
M365S<V%G92@I(#T]("1C;V1E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1D871A+3YG971#;V1E*"D@/3T@)&-O9&4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-E=$5R<F]R2&%N9&QI
M;F<H*0H*("`@("\J*@H@("`@("H@4V5T<R!H;W<@97)R;W)S(&=E;F5R871E
M9"!B>2!T:&ES(&]B:F5C="!S:&]U;&0@8F4@:&%N9&QE9"X*("`@("`J($-A
M;B!B92!I;G9O:V5D(&)O=&@@:6X@;V)J96-T<R!A;F0@<W1A=&EC86QL>2X@
M($EF(&-A;&QE9`H@("`@("H@<W1A=&EC86QL>2P@<V5T17)R;W)(86YD;&EN
M9R!S971S('1H92!D969A=6QT(&)E:&%V:6]U<B!F;W(@86QL"B`@("`@*B!0
M14%2(&]B:F5C=',N("!)9B!C86QL960@:6X@86X@;V)J96-T+"!S971%<G)O
M<DAA;F1L:6YG('-E=',*("`@("`J('1H92!D969A=6QT(&)E:&%V:6]U<B!F
M;W(@=&AA="!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D;6]D
M90H@("`@("H@("`@("`@($]N92!O9B!014%27T524D]27U)%5%523BP@4$5!
M4E]%4E)/4E]04DE.5"P*("`@("`J("`@("`@("!014%27T524D]27U1224='
M15(L(%!%05)?15)23U)?1$E%+`H@("`@("H@("`@("`@(%!%05)?15)23U)?
M0T%,3$)!0TL@;W(@4$5!4E]%4E)/4E]%6$-%4%1)3TXN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS"B`@("`@*B`@("`@("`@5VAE;B`D
M;6]D92!I<R!014%27T524D]27U1224='15(L('1H:7,@:7,@=&AE(&5R<F]R
M(&QE=F5L("AO;F4*("`@("`J("`@("`@("!O9B!%7U5315)?3D]424-%+"!%
M7U5315)?5T%23DE.1R!O<B!%7U5315)?15)23U(I+@H@("`@("H*("`@("`J
M("`@("`@("!7:&5N("1M;V1E(&ES(%!%05)?15)23U)?0T%,3$)!0TLL('1H
M:7,@<&%R86UE=&5R(&ES(&5X<&5C=&5D"B`@("`@*B`@("`@("`@=&\@8F4@
M=&AE(&-A;&QB86-K(&9U;F-T:6]N(&]R(&UE=&AO9"X@($$@8V%L;&)A8VL*
M("`@("`J("`@("`@("!F=6YC=&EO;B!I<R!A('-T<FEN9R!W:71H('1H92!N
M86UE(&]F('1H92!F=6YC=&EO;BP@80H@("`@("H@("`@("`@(&-A;&QB86-K
M(&UE=&AO9"!I<R!A;B!A<G)A>2!O9B!T=V\@96QE;65N=',Z('1H92!E;&5M
M96YT"B`@("`@*B`@("`@("`@870@:6YD97@@,"!I<R!T:&4@;V)J96-T+"!A
M;F0@=&AE(&5L96UE;G0@870@:6YD97@@,2!I<PH@("`@("H@("`@("`@('1H
M92!N86UE(&]F('1H92!M971H;V0@=&\@8V%L;"!I;B!T:&4@;V)J96-T+@H@
M("`@("H*("`@("`J("`@("`@("!7:&5N("1M;V1E(&ES(%!%05)?15)23U)?
M4%))3E0@;W(@4$5!4E]%4E)/4E]$244L('1H:7,@:7,*("`@("`J("`@("`@
M("!A('!R:6YT9B!F;W)M870@<W1R:6YG('5S960@=VAE;B!P<FEN=&EN9R!T
M:&4@97)R;W(*("`@("`J("`@("`@("!M97-S86=E+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J($!S
M964@4$5!4E]%4E)/4E]215154DX*("`@("`J($!S964@4$5!4E]%4E)/4E]0
M4DE.5`H@("`@("H@0'-E92!014%27T524D]27U1224='15(*("`@("`J($!S
M964@4$5!4E]%4E)/4E]$244*("`@("`J($!S964@4$5!4E]%4E)/4E]#04Q,
M0D%#2PH@("`@("H@0'-E92!014%27T524D]27T580T505$E/3@H@("`@("H*
M("`@("`J($!S:6YC92!02%`@-"XP+C4*("`@("`J+PH*("`@(&9U;F-T:6]N
M('-E=$5R<F]R2&%N9&QI;F<H)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES*2`F)B!I<U]A*"1T
M:&ES+"`G4$5!4B<I*2!["B`@("`@("`@("`@("1S971M;V1E("`@("`]("8D
M=&AI<RT^7V1E9F%U;'1?97)R;W)?;6]D93L*("`@("`@("`@("`@)'-E=&]P
M=&EO;G,@(#T@)B1T:&ES+3Y?9&5F875L=%]E<G)O<E]O<'1I;VYS.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1S971M;V1E("`@("`]("8D1TQ/
M0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]M;V1E)UT["B`@("`@("`@("`@
M("1S971O<'1I;VYS("`]("8D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O
M<E]O<'1I;VYS)UT["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1M;V1E
M*2!["B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]215154DXZ"B`@("`@
M("`@("`@(&-A<V4@4$5!4E]%4E)/4E]04DE.5#H*("`@("`@("`@("`@8V%S
M92!014%27T524D]27U1224='15(Z"B`@("`@("`@("`@(&-A<V4@4$5!4E]%
M4E)/4E]$244Z"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]%6$-%4%1)
M3TXZ"B`@("`@("`@("`@(&-A<V4@;G5L;#H*("`@("`@("`@("`@("`@("1S
M971M;V1E(#T@)&UO9&4["B`@("`@("`@("`@("`@("`D<V5T;W!T:6]N<R`]
M("1O<'1I;VYS.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E(%!%05)?15)23U)?0T%,3$)!0TLZ"B`@("`@("`@("`@("`@("`D
M<V5T;6]D92`]("1M;V1E.PH@("`@("`@("`@("`@("`@+R\@8VQA<W,O;V)J
M96-T(&UE=&AO9"!C86QL8F%C:PH@("`@("`@("`@("`@("`@:68@*&ES7V-A
M;&QA8FQE*"1O<'1I;VYS*2D@>PH@("`@("`@("`@("`@("`@("`@("1S971O
M<'1I;VYS(#T@)&]P=&EO;G,["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@('1R:6=G97)?97)R;W(H(FEN=F%L:60@97)R
M;W(@8V%L;&)A8VLB+"!%7U5315)?5T%23DE.1RD["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")I;G9A;&ED(&5R
M<F]R(&UO9&4B+"!%7U5315)?5T%23DE.1RD["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M97AP96-T17)R;W(H*0H*("`@("\J*@H@("`@("H@5&AI<R!M971H;V0@:7,@
M=7-E9"!T;R!T96QL('=H:6-H(&5R<F]R<R!Y;W4@97AP96-T('1O(&=E="X*
M("`@("`J($5X<&5C=&5D(&5R<F]R<R!A<F4@86QW87ES(')E='5R;F5D('=I
M=&@@97)R;W(@;6]D90H@("`@("H@4$5!4E]%4E)/4E]215154DXN("!%>'!E
M8W1E9"!E<G)O<B!C;V1E<R!A<F4@<W1O<F5D(&EN(&$@<W1A8VLL"B`@("`@
M*B!A;F0@=&AI<R!M971H;V0@<'5S:&5S(&$@;F5W(&5L96UE;G0@;VYT;R!I
M="X@(%1H92!L:7-T(&]F"B`@("`@*B!E>'!E8W1E9"!E<G)O<G,@87)E(&EN
M(&5F9F5C="!U;G1I;"!T:&5Y(&%R92!P;W!P960@;V9F('1H90H@("`@("H@
M<W1A8VL@=VET:"!T:&4@<&]P17AP96-T*"D@;65T:&]D+@H@("`@("H*("`@
M("`J($YO=&4@=&AA="!T:&ES(&UE=&AO9"!C86X@;F]T(&)E(&-A;&QE9"!S
M=&%T:6-A;&QY"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1C;V1E(&$@
M<VEN9VQE(&5R<F]R(&-O9&4@;W(@86X@87)R87D@;V8@97)R;W(@8V]D97,@
M=&\@97AP96-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@("`@('1H92!N
M97<@9&5P=&@@;V8@=&AE(")E>'!E8W1E9"!E<G)O<G,B('-T86-K"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!E>'!E8W1%
M<G)O<B@D8V]D92`]("<J)RD*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)&-O9&4I*2!["B`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]E>'!E
M8W1E9%]E<G)O<G,L("1C;V1E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!A<G)A>5]P=7-H*"1T:&ES+3Y?97AP96-T961?97)R;W)S+"!A<G)A
M>2@D8V]D92DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@<VEZ96]F*"1T
M:&ES+3Y?97AP96-T961?97)R;W)S*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!P;W!%>'!E8W0H*0H*("`@("\J*@H@("`@("H@5&AI<R!M971H
M;V0@<&]P<R!O;F4@96QE;65N="!O9F8@=&AE(&5X<&5C=&5D(&5R<F]R(&-O
M9&5S"B`@("`@*B!S=&%C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("`@=&AE(&QI<W0@;V8@97)R;W(@8V]D97,@=&AA="!W97)E('!O<'!E9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!P;W!%>'!E8W0H*0H@("`@>PH@("`@("`@
M(')E='5R;B!A<G)A>5]P;W`H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]C:&5C:T1E;$5X<&5C="@I
M"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO9"!C:&5C:W,@=6YS971S(&%N
M(&5R<F]R(&-O9&4@:68@879A:6QA8FQE"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D(&5R<F]R(&-O9&4*("`@("`J($!R971U<FX@8F]O;"!T<G5E(&EF
M('1H92!E<G)O<B!C;V1E('=A<R!U;G-E="P@9F%L<V4@;W1H97)W:7-E"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S:6YC92!02%`@-"XS+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K1&5L17AP96-T*"1E<G)O<E]C
M;V1E*0H@("`@>PH@("`@("`@("1D96QE=&5D(#T@9F%L<V4["@H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?97AP96-T961?97)R;W)S($%3("1K97D@/3X@
M)&5R<F]R7V%R<F%Y*2!["B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D97)R
M;W)?8V]D92P@)&5R<F]R7V%R<F%Y*2D@>PH@("`@("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G-;)&ME>5U;87)R87E?<V5A<F-H
M*"1E<G)O<E]C;V1E+"`D97)R;W)?87)R87DI72D["B`@("`@("`@("`@("`@
M("`D9&5L971E9"`]('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O(&-L96%N('5P(&5M<'1Y(&%R<F%Y<PH@("`@("`@("`@("!I9B`H,"`]
M/2!C;W5N="@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<ULD:V5Y72DI('L*("`@
M("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?97AP96-T961?97)R;W)S6R1K
M97E=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M)&1E;&5T960["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&5L17AP
M96-T*"D*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D(&1E;&5T97,@86QL
M(&]C8W5R96YC97,@;V8@=&AE('-P96-I9FEE9"!E;&5M96YT(&9R;VT*("`@
M("`J('1H92!E>'!E8W1E9"!E<G)O<B!C;V1E<R!S=&%C:RX*("`@("`J"B`@
M("`@*B!`<&%R86T@(&UI>&5D("1E<G)O<E]C;V1E(&5R<F]R(&-O9&4@=&AA
M="!S:&]U;&0@8F4@9&5L971E9`H@("`@("H@0')E='5R;B!M:7AE9"!L:7-T
M(&]F(&5R<F]R(&-O9&5S('1H870@=V5R92!D96QE=&5D(&]R(&5R<F]R"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E(%!(4"`T+C,N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96Q%>'!E8W0H)&5R<F]R7V-O9&4I"B`@
M("!["B`@("`@("`@)&1E;&5T960@/2!F86QS93L*"B`@("`@("`@:68@*"AI
M<U]A<G)A>2@D97)R;W)?8V]D92D@)B8@*#`@(3T@8V]U;G0H)&5R<F]R7V-O
M9&4I*2DI('L*("`@("`@("`@("`@+R\@)&5R<F]R7V-O9&4@:7,@82!N;VXM
M96UP='D@87)R87D@:&5R93L*("`@("`@("`@("`@+R\@=V4@=V%L:R!T:')O
M=6=H(&ET('1R>6EN9R!T;R!U;G-E="!A;&P*("`@("`@("`@("`@+R\@=F%L
M=65S"B`@("`@("`@("`@(&9O<F5A8V@H)&5R<F]R7V-O9&4@87,@)&ME>2`]
M/B`D97)R;W(I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-H96-K
M1&5L17AP96-T*"1E<G)O<BDI('L*("`@("`@("`@("`@("`@("`@("`D9&5L
M971E9"`]("!T<G5E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D9&5L971E9"`](&9A;'-E.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9&5L971E
M9"`_('1R=64@.B!014%2.CIR86ES945R<F]R*")4:&4@97AP96-T960@97)R
M;W(@>6]U('-U8FUI='1E9"!D;V5S(&YO="!E>&ES="(I.R`O+R!)35!23U9%
M($U%"B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D97)R;W)?8V]D92DI('L*
M("`@("`@("`@("`@+R\@)&5R<F]R7V-O9&4@8V]M97,@86QO;F4L('1R>6EN
M9R!T;R!U;G-E="!I=`H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C:&5C:T1E
M;$5X<&5C="@D97)R;W)?8V]D92DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(E1H92!E>'!E8W1E9"!E<G)O<B!Y
M;W4@<W5B;6ET=&5D(&1O97,@;F]T(&5X:7-T(BD[("\O($E-4%)/5D4@344*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M("1E<G)O<E]C;V1E(&ES(&5M<'1Y"B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*")4:&4@97AP96-T960@97)R;W(@>6]U('-U8FUI='1E
M9"!I<R!E;7!T>2(I.R`O+R!)35!23U9%($U%"B`@("`@("`@?0H@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(')A:7-E17)R;W(H*0H*("`@("\J*@H@
M("`@("H@5&AI<R!M971H;V0@:7,@82!W<F%P<&5R('1H870@<F5T=7)N<R!A
M;B!I;G-T86YC92!O9B!T:&4*("`@("`J(&-O;F9I9W5R960@97)R;W(@8VQA
M<W,@=VET:"!T:&ES(&]B:F5C="=S(&1E9F%U;'0@97)R;W(*("`@("`J(&AA
M;F1L:6YG(&%P<&QI960N("!)9B!T:&4@)&UO9&4@86YD("1O<'1I;VYS('!A
M<F%M971E<G,@87)E(&YO=`H@("`@("H@<W!E8VEF:65D+"!T:&4@;V)J96-T
M)W,@9&5F875L=',@87)E('5S960N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1M97-S86=E(&$@=&5X="!E<G)O<B!M97-S86=E(&]R(&$@4$5!4B!E
M<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1C;V1E("`@
M("`@82!N=6UE<FEC(&5R<F]R(&-O9&4@*&ET(&ES('5P('1O('EO=7(@8VQA
M<W,*("`@("`J("`@("`@("`@("`@("`@("`@=&\@9&5F:6YE('1H97-E(&EF
M('EO=2!W86YT('1O('5S92!C;V1E<RD*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT("1M;V1E("`@("`@3VYE(&]F(%!%05)?15)23U)?4D5455).+"!014%2
M7T524D]27U!224Y4+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27T52
M4D]27U1224='15(L(%!%05)?15)23U)?1$E%+`H@("`@("H@("`@("`@("`@
M("`@("`@("!014%27T524D]27T-!3$Q"04-++"!014%27T524D]27T580T50
M5$E/3BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&]P=&EO;G,@268@
M)&UO9&4@:7,@4$5!4E]%4E)/4E]44DE'1T52+"!T:&ES('!A<F%M971E<@H@
M("`@("H@("`@("`@("`@("`@("`@("!S<&5C:69I97,@=&AE(%!(4"UI;G1E
M<FYA;"!E<G)O<B!L979E;"`H;VYE(&]F"B`@("`@*B`@("`@("`@("`@("`@
M("`@($5?55-%4E].3U1)0T4L($5?55-%4E]705).24Y'(&]R($5?55-%4E]%
M4E)/4BDN"B`@("`@*B`@("`@("`@("`@("`@("`@($EF("1M;V1E(&ES(%!%
M05)?15)23U)?0T%,3$)!0TLL('1H:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@<&%R86UE=&5R('-P96-I9FEE<R!T:&4@8V%L;&)A8VL@9G5N8W1I;VX@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@;65T:&]D+B`@26X@;W1H97(@
M97)R;W(@;6]D97,@=&AI<R!P87)A;65T97(*("`@("`J("`@("`@("`@("`@
M("`@("`@:7,@:6=N;W)E9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R:6YF;R!)9B!Y;W4@;F5E9"!T;R!P87-S(&%L;VYG(&9O<B!E>&%M
M<&QE(&1E8G5G"B`@("`@*B`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N
M+"!T:&ES('!A<F%M971E<B!I<R!M96%N="!F;W(@=&AA="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1E<G)O<E]C;&%S<R!4:&4@<F5T=7)N960@
M97)R;W(@;V)J96-T('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M:6YS=&%N=&EA=&5D(&9R;VT@=&AI<R!C;&%S<RP@:68@<W!E8VEF:65D+@H@
M("`@("H*("`@("`J($!P87)A;2!B;V]L("1S:VEP;7-G($EF('1R=64L(')A
M:7-E17)R;W(@=VEL;"!O;FQY('!A<W,@97)R;W(@8V]D97,L"B`@("`@*B`@
M("`@("`@("`@("`@("`@('1H92!E<G)O<B!M97-S86=E('!A<F%M971E<B!W
M:6QL(&)E(&1R;W!P960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!R971U<FX@;V)J96-T("`@82!014%2(&5R<F]R(&]B:F5C=`H@
M("`@("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L:6YG"B`@("`@*B!`<VEN
M8V4@4$A0(#0N,"XU"B`@("`@*B\*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H
M)&UE<W-A9V4@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M9&4@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&UO9&4@/2!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G,@/2!N=6QL
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)I;F9O(#T@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<E]C;&%S<R`](&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D<VMI<&US9R`](&9A;'-E*0H@
M("`@>PH@("`@("`@("\O(%1H92!E<G)O<B!I<R!Y970@82!014%2(&5R<F]R
M(&]B:F5C=`H@("`@("`@(&EF("AI<U]O8FIE8W0H)&UE<W-A9V4I*2!["B`@
M("`@("`@("`@("1C;V1E("`@("`@("`]("1M97-S86=E+3YG971#;V1E*"D[
M"B`@("`@("`@("`@("1U<V5R:6YF;R`@("`]("1M97-S86=E+3YG9715<V5R
M26YF;R@I.PH@("`@("`@("`@("`D97)R;W)?8VQA<W,@/2`D;65S<V%G92T^
M9V5T5'EP92@I.PH@("`@("`@("`@("`D;65S<V%G92T^97)R;W)?;65S<V%G
M95]P<F5F:7@@/2`G)SL*("`@("`@("`@("`@)&UE<W-A9V4@("`@(#T@)&UE
M<W-A9V4M/F=E=$UE<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RD@)B8@:7-S970H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I
M("8F('-I>F5O9B@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<RD@/B`P("8F('-I
M>F5O9B@D97AP(#T@96YD*"1T:&ES+3Y?97AP96-T961?97)R;W)S*2DI('L*
M("`@("`@("`@("`@:68@*"1E>'!;,%T@/3T@(BHB('Q\"B`@("`@("`@("`@
M("`@("`H:7-?:6YT*')E<V5T*"1E>'`I*2`F)B!I;E]A<G)A>2@D8V]D92P@
M)&5X<"DI('Q\"B`@("`@("`@("`@("`@("`H:7-?<W1R:6YG*')E<V5T*"1E
M>'`I*2`F)B!I;E]A<G)A>2@D;65S<V%G92P@)&5X<"DI*2!["B`@("`@("`@
M("`@("`@("`D;6]D92`](%!%05)?15)23U)?4D5455)..PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@("\O($YO(&UO9&4@9VEV96XL('1R>2!G
M;&]B86P@;VYE<PH@("`@("`@(&EF("@D;6]D92`]/3T@;G5L;"D@>PH@("`@
M("`@("`@("`O+R!#;&%S<R!E<G)O<B!H86YD;&5R"B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RD@)B8@:7-S970H)'1H:7,M/E]D969A=6QT7V5R<F]R
M7VUO9&4I*2!["B`@("`@("`@("`@("`@("`D;6]D92`@("`]("1T:&ES+3Y?
M9&5F875L=%]E<G)O<E]M;V1E.PH@("`@("`@("`@("`@("`@)&]P=&EO;G,@
M/2`D=&AI<RT^7V1E9F%U;'1?97)R;W)?;W!T:6]N<SL*("`@("`@("`@("`@
M+R\@1VQO8F%L(&5R<F]R(&AA;F1L97(*("`@("`@("`@("`@?2!E;'-E:68@
M*&ES<V5T*"1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R7VUO9&4G72DI
M('L*("`@("`@("`@("`@("`@("1M;V1E("`@(#T@)$=,3T)!3%-;)U]014%2
M7V1E9F%U;'1?97)R;W)?;6]D92==.PH@("`@("`@("`@("`@("`@)&]P=&EO
M;G,@/2`D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D97)R;W)?
M8VQA<W,@(3T](&YU;&PI('L*("`@("`@("`@("`@)&5C(#T@)&5R<F]R7V-L
M87-S.PH@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RD@)B8@:7-S970H
M)'1H:7,M/E]E<G)O<E]C;&%S<RDI('L*("`@("`@("`@("`@)&5C(#T@)'1H
M:7,M/E]E<G)O<E]C;&%S<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D96,@/2`G4$5!4E]%<G)O<B<["B`@("`@("`@?0H@("`@("`@(&EF("@D
M<VMI<&US9RD@>PH@("`@("`@("`@("!R971U<FX@;F5W("1E8R@D8V]D92P@
M)&UO9&4L("1O<'1I;VYS+"`D=7-E<FEN9F\I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!N97<@)&5C*"1M97-S86=E+"`D8V]D92P@
M)&UO9&4L("1O<'1I;VYS+"`D=7-E<FEN9F\I.PH@("`@("`@('T*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!T:')O=T5R<F]R*"D*"B`@("`O*BH*
M("`@("`J(%-I;7!L97(@9F]R;2!O9B!R86ES945R<F]R('=I=&@@9F5W97(@
M;W!T:6]N<RX@($EN(&UO<W0@8V%S97,*("`@("`J(&UE<W-A9V4L(&-O9&4@
M86YD('5S97)I;F9O(&%R92!E;F]U9V@N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;65S<V%G90H@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@
M=&AR;W=%<G)O<B@D;65S<V%G92`](&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D8V]D92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=7-E<FEN9F\@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RD@)B8@:7-?<W5B8VQA<W-?;V8H)'1H:7,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1M97-S
M86=E+"`D8V]D92P@;G5L;"P@;G5L;"P@)'5S97)I;F9O*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D
M;65S<V%G92P@)&-O9&4L(&YU;&PL(&YU;&PL("1U<V5R:6YF;RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('!U<VA%<G)O<DAA
M;F1L:6YG*"D*"B`@("`O*BH*("`@("`J(%!U<V@@82!N97<@97)R;W(@:&%N
M9&QE<B!O;B!T;W`@;V8@=&AE(&5R<F]R(&AA;F1L97(@;W!T:6]N<R!S=&%C
M:RX@5VET:"!T:&ES"B`@("`@*B!Y;W4@8V%N(&5A<VEL>2!O=F5R<FED92!T
M:&4@86-T=6%L(&5R<F]R(&AA;F1L97(@9F]R('-O;64@8V]D92!A;F0@<F5S
M=&]R90H@("`@("H@:70@;&%T97(@=VET:"!P;W!%<G)O<DAA;F1L:6YG+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;6]D92`H<V%M92!A<R!S971%
M<G)O<DAA;F1L:6YG*0H@("`@("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS("AS
M86UE(&%S('-E=$5R<F]R2&%N9&QI;F<I"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L($%L=V%Y<R!T<G5E"B`@("`@*@H@("`@("H@0'-E92!014%2.CIS
M971%<G)O<DAA;F1L:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N('!U<VA%<G)O
M<DAA;F1L:6YG*"1M;V1E+"`D;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@
M("`@)'-T86-K(#T@)B1'3$]"04Q36R=?4$5!4E]E<G)O<E]H86YD;&5R7W-T
M86-K)UT["B`@("`@("`@:68@*&ES<V5T*"1T:&ES*2`F)B!I<U]A*"1T:&ES
M+"`G4$5!4B<I*2!["B`@("`@("`@("`@("1D969?;6]D92`@("`]("8D=&AI
M<RT^7V1E9F%U;'1?97)R;W)?;6]D93L*("`@("`@("`@("`@)&1E9E]O<'1I
M;VYS(#T@)B1T:&ES+3Y?9&5F875L=%]E<G)O<E]O<'1I;VYS.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1D969?;6]D92`@("`]("8D1TQ/0D%,
M4ULG7U!%05)?9&5F875L=%]E<G)O<E]M;V1E)UT["B`@("`@("`@("`@("1D
M969?;W!T:6]N<R`]("8D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O
M<'1I;VYS)UT["B`@("`@("`@?0H@("`@("`@("1S=&%C:UM=(#T@87)R87DH
M)&1E9E]M;V1E+"`D9&5F7V]P=&EO;G,I.PH*("`@("`@("!I9B`H:7-S970H
M)'1H:7,I("8F(&ES7V$H)'1H:7,L("=014%2)RDI('L*("`@("`@("`@("`@
M)'1H:7,M/G-E=$5R<F]R2&%N9&QI;F<H)&UO9&4L("1O<'1I;VYS*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!014%2.CIS971%<G)O<DAA;F1L
M:6YG*"1M;V1E+"`D;W!T:6]N<RD["B`@("`@("`@?0H@("`@("`@("1S=&%C
M:UM=(#T@87)R87DH)&UO9&4L("1O<'1I;VYS*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P;W!%<G)O<DAA
M;F1L:6YG*"D*"B`@("`O*BH*("`@("H@4&]P('1H92!L87-T(&5R<F]R(&AA
M;F1L97(@=7-E9`H@("`@*@H@("`@*B!`<F5T=7)N(&)O;VP@06QW87ES('1R
M=64*("`@("H*("`@("H@0'-E92!014%2.CIP=7-H17)R;W)(86YD;&EN9PH@
M("`@*B\*("`@(&9U;F-T:6]N('!O<$5R<F]R2&%N9&QI;F<H*0H@("`@>PH@
M("`@("`@("1S=&%C:R`]("8D1TQ/0D%,4ULG7U!%05)?97)R;W)?:&%N9&QE
M<E]S=&%C:R==.PH@("`@("`@(&%R<F%Y7W!O<"@D<W1A8VLI.PH@("`@("`@
M(&QI<W0H)&UO9&4L("1O<'1I;VYS*2`]("1S=&%C:UMS:7IE;V8H)'-T86-K
M*2`M(#%=.PH@("`@("`@(&%R<F%Y7W!O<"@D<W1A8VLI.PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RD@)B8@:7-?82@D=&AI<RP@)U!%05(G*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T17)R;W)(86YD;&EN9R@D;6]D92P@)&]P=&EO
M;G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(%!%05(Z.G-E=$5R
M<F]R2&%N9&QI;F<H)&UO9&4L("1O<'1I;VYS*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;&]A9$5X=&5N<VEO;B@I"@H@("`@+RHJ"B`@("`J($]3(&EN9&5P96YD86YT
M(%!(4"!E>'1E;G-I;VX@;&]A9"X@4F5M96UB97(@=&\@=&%K92!C87)E"B`@
M("`J(&]N('1H92!C;W)R96-T(&5X=&5N<VEO;B!N86UE(&9O<B!C87-E('-E
M;G-I=&EV92!/4V5S+@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1E>'0@
M5&AE(&5X=&5N<VEO;B!N86UE"B`@("`J($!R971U<FX@8F]O;"!3=6-C97-S
M(&]R(&YO="!O;B!T:&4@9&PH*2!C86QL"B`@("`J+PH@("`@9G5N8W1I;VX@
M;&]A9$5X=&5N<VEO;B@D97AT*0H@("`@>PH@("`@("`@(&EF("@A97AT96YS
M:6]N7VQO861E9"@D97AT*2D@>PH@("`@("`@("`@("`O+R!I9B!E:71H97(@
M<F5T=7)N<R!T<G5E(&1L*"D@=VEL;"!P<F]D=6-E(&$@1D%404P@97)R;W(L
M('-T;W`@=&AA=`H@("`@("`@("`@("!I9B`H*&EN:5]G970H)V5N86)L95]D
M;"<I("$](#$I('Q\("AI;FE?9V5T*"=S869E7VUO9&4G*2`]/2`Q*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("`@("`D
M<W5F9FEX(#T@)RYD;&PG.PH@("`@("`@("`@("!](&5L<V5I9B`H4$A07T]3
M(#T]("=(4"U56"<I('L*("`@("`@("`@("`@("`@("1S=69F:7@@/2`G+G-L
M)SL*("`@("`@("`@("`@?2!E;'-E:68@*%!(4%]/4R`]/2`G04E8)RD@>PH@
M("`@("`@("`@("`@("`@)'-U9F9I>"`]("<N82<["B`@("`@("`@("`@('T@
M96QS96EF("A02%!?3U,@/3T@)T]36"<I('L*("`@("`@("`@("`@("`@("1S
M=69F:7@@/2`G+F)U;F1L92<["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<W5F9FEX(#T@)RYS;R<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N($!D;"@G<&AP7R<N)&5X="XD<W5F9FEX*2!\?"!`
M9&PH)&5X="XD<W5F9FEX*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+R\@?7U]"GT*"B\O('M[>R!?4$5!4E]C86QL7V1E
M<W1R=6-T;W)S*"D*"F9U;F-T:6]N(%]014%27V-A;&Q?9&5S=')U8W1O<G,H
M*0I["B`@("!G;&]B86P@)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0[
M"B`@("!I9B`H:7-?87)R87DH)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI
M<W0I("8F"B`@("`@("`@<VEZ96]F*"1?4$5!4E]D97-T<G5C=&]R7V]B:F5C
M=%]L:7-T*2D*("`@('L*("`@("`@("!R97-E="@D7U!%05)?9&5S=')U8W1O
M<E]O8FIE8W1?;&ES="D["B`@("`@("`@=VAI;&4@*&QI<W0H)&LL("1O8FIR
M968I(#T@96%C:"@D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="DI('L*
M("`@("`@("`@("`@)&-L87-S;F%M92`](&=E=%]C;&%S<R@D;V)J<F5F*3L*
M("`@("`@("`@("`@=VAI;&4@*"1C;&%S<VYA;64I('L*("`@("`@("`@("`@
M("`@("1D97-T<G5C=&]R(#T@(E\D8VQA<W-N86UE(CL*("`@("`@("`@("`@
M("`@(&EF("AM971H;V1?97AI<W1S*"1O8FIR968L("1D97-T<G5C=&]R*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1O8FIR968M/B1D97-T<G5C=&]R*"D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2!G971?
M<&%R96YT7V-L87-S*"1C;&%S<VYA;64I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O($5M<'1Y('1H92!O
M8FIE8W0@;&ES="!T;R!E;G-U<F4@=&AA="!D97-T<G5C=&]R<R!A<F4*("`@
M("`@("`O+R!N;W0@8V%L;&5D(&UO<F4@=&AA;B!O;F-E+@H@("`@("`@("1?
M4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T(#T@87)R87DH*3L*("`@('T*
M"B`@("`O+R!.;W<@8V%L;"!T:&4@<VAU=&1O=VX@9G5N8W1I;VYS"B`@("!I
M9B`H:7-?87)R87DH)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UTI
M($%.1"`A96UP='DH)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UTI
M*2!["B`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)U]014%27W-H=71D;W=N
M7V9U;F-S)UT@87,@)'9A;'5E*2!["B`@("`@("`@("`@(&-A;&Q?=7-E<E]F
M=6YC7V%R<F%Y*"1V86QU95LP72P@)'9A;'5E6S%=*3L*("`@("`@("!]"B`@
M("!]"GT*"B\O('U]?0H*8VQA<W,@4$5!4E]%<G)O<@I["B`@("`O+R![>WL@
M<')O<&5R=&EE<PH*("`@('9A<B`D97)R;W)?;65S<V%G95]P<F5F:7@@/2`G
M)SL*("`@('9A<B`D;6]D92`@("`@("`@("`@("`@("`@/2!014%27T524D]2
M7U)%5%523CL*("`@('9A<B`D;&5V96P@("`@("`@("`@("`@("`@/2!%7U53
M15)?3D]424-%.PH@("`@=F%R("1C;V1E("`@("`@("`@("`@("`@("`]("TQ
M.PH@("`@=F%R("1M97-S86=E("`@("`@("`@("`@("`]("<G.PH@("`@=F%R
M("1U<V5R:6YF;R`@("`@("`@("`@("`]("<G.PH@("`@=F%R("1B86-K=')A
M8V4@("`@("`@("`@("`](&YU;&P["@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%!%05)?17)R;W(@8V]N<W1R
M=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!M
M97-S86=E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D8V]D92`@("`@*&]P
M=&EO;F%L*2!E<G)O<B!C;V1E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D
M;6]D92`@("`@*&]P=&EO;F%L*2!E<G)O<B!M;V1E+"!O;F4@;V8Z(%!%05)?
M15)23U)?4D5455).+`H@("`@("H@4$5!4E]%4E)/4E]04DE.5"P@4$5!4E]%
M4E)/4E]$244L(%!%05)?15)23U)?5%))1T=%4BP*("`@("`J(%!%05)?15)2
M3U)?0T%,3$)!0TL@;W(@4$5!4E]%4E)/4E]%6$-%4%1)3TX*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&]P=&EO;G,@("`H;W!T:6]N86PI(&5R<F]R
M(&QE=F5L+"!?3U)?(&EN('1H92!C87-E(&]F"B`@("`@*B!014%27T524D]2
M7T-!3$Q"04-++"!T:&4@8V%L;&)A8VL@9G5N8W1I;VX@;W(@;V)J96-T+VUE
M=&AO9`H@("`@("H@='5P;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<FEN9F\@*&]P=&EO;F%L*2!A9&1I=&EO;F%L('5S97(O9&5B=6<@
M:6YF;PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@
M("HO"B`@("!F=6YC=&EO;B!014%27T5R<F]R*"1M97-S86=E(#T@)W5N:VYO
M=VX@97)R;W(G+"`D8V]D92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@
M("`@("1M;V1E(#T@;G5L;"P@)&]P=&EO;G,@/2!N=6QL+"`D=7-E<FEN9F\@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D;6]D92`]/3T@;G5L;"D@>PH@
M("`@("`@("`@("`D;6]D92`](%!%05)?15)23U)?4D5455)..PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^;65S<V%G92`@(#T@)&UE<W-A9V4["B`@("`@
M("`@)'1H:7,M/F-O9&4@("`@("`]("1C;V1E.PH@("`@("`@("1T:&ES+3YM
M;V1E("`@("`@/2`D;6]D93L*("`@("`@("`D=&AI<RT^=7-E<FEN9F\@(#T@
M)'5S97)I;F9O.PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H(F1E8G5G
M7V)A8VMT<F%C92(I*2!["B`@("`@("`@("`@("1T:&ES+3YB86-K=')A8V4@
M/2!D96)U9U]B86-K=')A8V4H*3L*("`@("`@("!]"B`@("`@("`@:68@*"1M
M;V1E("8@4$5!4E]%4E)/4E]#04Q,0D%#2RD@>PH@("`@("`@("`@("`D=&AI
M<RT^;&5V96P@/2!%7U5315)?3D]424-%.PH@("`@("`@("`@("`D=&AI<RT^
M8V%L;&)A8VL@/2`D;W!T:6]N<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H)&]P=&EO;G,@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@
M("1O<'1I;VYS(#T@15]54T527TY/5$E#13L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^;&5V96P@/2`D;W!T:6]N<SL*("`@("`@("`@("`@
M)'1H:7,M/F-A;&QB86-K(#T@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]04DE.5"D@>PH@("`@("`@("`@
M("!I9B`H:7-?;G5L;"@D;W!T:6]N<RD@?'P@:7-?:6YT*"1O<'1I;VYS*2D@
M>PH@("`@("`@("`@("`@("`@)&9O<FUA="`]("(E<R(["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D9F]R;6%T(#T@)&]P=&EO;G,[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<')I;G1F*"1F;W)M870L("1T
M:&ES+3YG971-97-S86=E*"DI.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H
M:7,M/FUO9&4@)B!014%27T524D]27U1224='15(I('L*("`@("`@("`@("`@
M=')I9V=E<E]E<G)O<B@D=&AI<RT^9V5T365S<V%G92@I+"`D=&AI<RT^;&5V
M96PI.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%2
M7T524D]27T1)12D@>PH@("`@("`@("`@("`D;7-G(#T@)'1H:7,M/F=E=$UE
M<W-A9V4H*3L*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&]P=&EO;G,I('Q\
M(&ES7VEN="@D;W!T:6]N<RDI('L*("`@("`@("`@("`@("`@("1F;W)M870@
M/2`B)7,B.PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D;7-G+"`M,2D@
M(3T@(EQN(BD@>PH@("`@("`@("`@("`@("`@("`@("1M<V<@+CT@(EQN(CL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1F;W)M870@/2`D;W!T:6]N<SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!D:64H<W!R:6YT9B@D9F]R;6%T+"`D;7-G*2D["B`@("`@
M("`@?0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?0T%,
M3$)!0TLI('L*("`@("`@("`@("`@:68@*&ES7V-A;&QA8FQE*"1T:&ES+3YC
M86QL8F%C:RDI('L*("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1T
M:&ES+3YC86QL8F%C:RP@)'1H:7,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&EF("A014%27UI%,B`F)B`D=&AI<RT^;6]D92`F(%!%05)?
M15)23U)?15A#15!424].*2!["B`@("`@("`@("`@(&5V86PH)W1H<F]W("1T
M:&ES.R<I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!G971-;V1E*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@97)R;W(@;6]D
M92!F<F]M(&%N(&5R<F]R(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="!E<G)O<B!M;V1E"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!G971-;V1E*"D@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^;6]D93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G971#86QL
M8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&-A;&QB86-K(&9U;F-T
M:6]N+VUE=&AO9"!F<F]M(&%N(&5R<F]R(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(&-A;&QB86-K(&9U;F-T:6]N(&]R(&]B:F5C="]M
M971H;V0@87)R87D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$-A;&QB86-K*"D@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^8V%L;&)A8VL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T
M365S<V%G92@I"@H*("`@("\J*@H@("`@("H@1V5T('1H92!E<G)O<B!M97-S
M86=E(&9R;VT@86X@97)R;W(@;V)J96-T+@H@("`@("H*("`@("`J($!R971U
M<FX@('-T<FEN9R`@9G5L;"!E<G)O<B!M97-S86=E"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971-97-S86=E*"D*("`@
M('L*("`@("`@("!R971U<FX@*"1T:&ES+3YE<G)O<E]M97-S86=E7W!R969I
M>"`N("1T:&ES+3YM97-S86=E*3L*("`@('T*"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9V5T0V]D92@I"@H@("`@+RHJ"B`@("`@*B!'970@97)R;W(@8V]D
M92!F<F]M(&%N(&5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!R971U<FX@
M:6YT(&5R<F]R(&-O9&4*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@("!F=6YC=&EO;B!G971#;V1E*"D*("`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YC;V1E.PH@("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M9714>7!E*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@;F%M92!O9B!T:&ES
M(&5R<F]R+V5X8V5P=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R!E<G)O<B]E>&-E<'1I;VX@;F%M92`H='EP92D*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!G971?8VQA<W,H)'1H:7,I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&=E=%5S97));F9O*"D*"B`@("`O*BH*("`@("`J
M($=E="!A9&1I=&EO;F%L('5S97(M<W5P<&QI960@:6YF;W)M871I;VXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@=7-E<BUS=7!P;&EE9"!I;F9O
M<FUA=&EO;@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T57-E<DEN9F\H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^=7-E<FEN9F\["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T
M1&5B=6=);F9O*"D*"B`@("`O*BH*("`@("`J($=E="!A9&1I=&EO;F%L(&1E
M8G5G(&EN9F]R;6%T:6]N('-U<'!L:65D(&)Y('1H92!A<'!L:6-A=&EO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D96)U9R!I;F9O<FUA=&EO
M;@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1&5B=6=);F9O*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E
M=%5S97));F9O*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T
M0F%C:W1R86-E*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@8V%L;"!B86-K
M=')A8V4@9G)O;2!W:&5R92!T:&4@97)R;W(@=V%S(&=E;F5R871E9"X*("`@
M("`J(%-U<'!O<G1E9"!W:71H(%!(4"`T+C,N,"!O<B!N97=E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT("1F<F%M92`H;W!T:6]N86PI('=H870@9G)A
M;64@=&\@9F5T8V@*("`@("`J($!R971U<FX@87)R87D@0F%C:W1R86-E+"!O
M<B!.54Q,(&EF(&YO="!A=F%I;&%B;&4N"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971"86-K=')A8V4H)&9R86UE(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H)&9R86UE(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^8F%C:W1R86-E.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/F)A8VMT<F%C95LD9G)A;65=.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%D9%5S97));F9O*"D*"B`@("!F
M=6YC=&EO;B!A9&15<V5R26YF;R@D:6YF;RD*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/G5S97)I;F9O*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M=7-E<FEN9F\@/2`D:6YF;SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^=7-E<FEN9F\@+CT@(B`J*B`D:6YF;R(["B`@("`@("`@?0H@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1O4W1R:6YG*"D*"B`@("`O
M*BH*("`@("`J($UA:V4@82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AI
M<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@82!S=')I
M;F<@=VET:"!A;B!O8FIE8W0@<W5M;6%R>0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&]3=')I;F<H*2!["B`@("`@("`@
M)&UO9&5S(#T@87)R87DH*3L*("`@("`@("`D;&5V96QS(#T@87)R87DH15]5
M4T527TY/5$E#12`@/3X@)VYO=&EC92<L"B`@("`@("`@("`@("`@("`@("`@
M("`@($5?55-%4E]705).24Y'(#T^("=W87)N:6YG)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@15]54T527T524D]2("`@/3X@)V5R<F]R)RD["B`@("`@
M("`@:68@*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]#04Q,0D%#2RD@>PH@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/F-A;&QB86-K*2D@>PH@
M("`@("`@("`@("`@("`@)&-A;&QB86-K(#T@9V5T7V-L87-S*"1T:&ES+3YC
M86QL8F%C:ULP72D@+B`G.CHG("X*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^8V%L;&)A8VM;,5T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D8V%L;&)A8VL@/2`D=&AI<RT^8V%L;&)A8VL["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H)ULE<SH@;65S<V%G
M93TB)7,B(&-O9&4])60@;6]D93UC86QL8F%C:R`G+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8V%L;&)A8VL])7,@<')E9FEX/2(E<R(@:6YF;STB
M)7,B72<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&=E=%]C;&%S<R@D
M=&AI<RDL("1T:&ES+3YM97-S86=E+"`D=&AI<RT^8V]D92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-A;&QB86-K+"`D=&AI<RT^97)R;W)?;65S
M<V%G95]P<F5F:7@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YU<V5R:6YF;RD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;6]D
M92`F(%!%05)?15)23U)?4%))3E0I('L*("`@("`@("`@("`@)&UO9&5S6UT@
M/2`G<')I;G0G.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@
M)B!014%27T524D]27U1224='15(I('L*("`@("`@("`@("`@)&UO9&5S6UT@
M/2`G=')I9V=E<B<["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;6]D
M92`F(%!%05)?15)23U)?1$E%*2!["B`@("`@("`@("`@("1M;V1E<UM=(#T@
M)V1I92<["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%
M05)?15)23U)?4D5455).*2!["B`@("`@("`@("`@("1M;V1E<UM=(#T@)W)E
M='5R;B<["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S<')I;G1F*"=;)7,Z
M(&UE<W-A9V4](B5S(B!C;V1E/25D(&UO9&4])7,@;&5V96P])7,@)RX*("`@
M("`@("`@("`@("`@("`@("`@("`G<')E9FEX/2(E<R(@:6YF;STB)7,B72<L
M"B`@("`@("`@("`@("`@("`@("`@("`@9V5T7V-L87-S*"1T:&ES*2P@)'1H
M:7,M/FUE<W-A9V4L("1T:&ES+3YC;V1E+`H@("`@("`@("`@("`@("`@("`@
M("`@(&EM<&QO9&4H(GPB+"`D;6]D97,I+"`D;&5V96QS6R1T:&ES+3YL979E
M;%TL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R7VUE<W-A
M9V5?<')E9FEX+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU<V5R
M:6YF;RD["B`@("!]"@H@("`@+R\@?7U]"GT*"FEF("@A9G5N8W1I;VY?97AI
M<W1S*"=I<U]A)RDI"GL*("`@9G5N8W1I;VX@:7-?82@F)&]B:F5C="P@)&-L
M87-S7VYA;64I"B`@('L*("`@("`@(&EF("AS=')T;VQO=V5R*&=E=%]C;&%S
M<R@D;V)J96-T*2D@/3T@)&-L87-S7VYA;64I(')E='5R;B!44E5%.PH@("`@
M("`@96QS92!R971U<FX@:7-?<W5B8VQA<W-?;V8H)&]B:F5C="P@)&-L87-S
M7VYA;64I.PH@("!]"GT*"G)E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*")?
M4$5!4E]C86QL7V1E<W1R=6-T;W)S(BD["@HO*@H@*B!,;V-A;"!687)I86)L
M97,Z"B`J(&UO9&4Z('!H<`H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO
M9F9S970Z(#0*("H@16YD.@H@*B\*/SX*````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(N<&AP+F]R:6<`````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<R,S4T`#$P
M-#$W,S8S,#`W`#`Q-S4U,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!014%2+"!T:&4@4$A0($5X=&5N<VEO;B!A;F0@07!P
M;&EC871I;VX@4F5P;W-I=&]R>2`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3=&5R;&EN9R!(
M=6=H97,@/'-T97)L:6YG0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@4$5!4BYP:'`L=B`Q+C<W(#(P,#0O,#(O
M,#<@,#0Z-#(Z,#<@8V5L;&]G($5X<"`D"B\O"@ID969I;F4H)U!%05)?15)2
M3U)?4D5455).)RP@("`@(#$I.PID969I;F4H)U!%05)?15)23U)?4%))3E0G
M+"`@("`@(#(I.PID969I;F4H)U!%05)?15)23U)?5%))1T=%4B<L("`@(#0I
M.PID969I;F4H)U!%05)?15)23U)?1$E%)RP@("`@("`@(#@I.PID969I;F4H
M)U!%05)?15)23U)?0T%,3$)!0TLG+"`@,38I.PID969I;F4H)U!%05)?15)2
M3U)?15A#15!424].)RP@,S(I.PID969I;F4H)U!%05)?6D4R)RP@*&9U;F-T
M:6]N7V5X:7-T<R@G=F5R<VEO;E]C;VUP87)E)RD@)B8*("`@("`@("`@("`@
M("`@("`@("!V97)S:6]N7V-O;7!A<F4H>F5N9%]V97)S:6]N*"DL("(R+61E
M=B(L(")G92(I*2D["@II9B`H<W5B<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)
M3B<I('L*("`@(&1E9FEN92@G3U-?5TE.1$]74R<L('1R=64I.PH@("`@9&5F
M:6YE*"=/4U]53DE8)RP@("`@9F%L<V4I.PH@("`@9&5F:6YE*"=014%27T]3
M)RP@("`@)U=I;F1O=W,G*3L*?2!E;'-E('L*("`@(&1E9FEN92@G3U-?5TE.
M1$]74R<L(&9A;'-E*3L*("`@(&1E9FEN92@G3U-?54Y)6"<L("`@('1R=64I
M.PH@("`@9&5F:6YE*"=014%27T]3)RP@("`@)U5N:7@G*3L@+R\@8FQA=&%N
M="!A<W-U;7!T:6]N"GT*"B\O(&EN<W1A;G0@8F%C:W=A<F1S(&-O;7!A=&EB
M:6QI='D*:68@*"%D969I;F5D*"=0051(7U-%4$%2051/4B<I*2!["B`@("!I
M9B`H3U-?5TE.1$]74RD@>PH@("`@("`@(&1E9FEN92@G4$%42%]315!!4D%4
M3U(G+"`G.R<I.PH@("`@?2!E;'-E('L*("`@("`@("!D969I;F4H)U!!5$A?
M4T5005)!5$]2)RP@)SHG*3L*("`@('T*?0H*)$=,3T)!3%-;)U]014%27V1E
M9F%U;'1?97)R;W)?;6]D92==("`@("`](%!%05)?15)23U)?4D5455)..PHD
M1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT@(#T@15]5
M4T527TY/5$E#13L*)$=,3T)!3%-;)U]014%27V1E<W1R=6-T;W)?;V)J96-T
M7VQI<W0G72`](&%R<F%Y*"D["B1'3$]"04Q36R=?4$5!4E]S:'5T9&]W;E]F
M=6YC<R==("`@("`@("`@/2!A<G)A>2@I.PHD1TQ/0D%,4ULG7U!%05)?97)R
M;W)?:&%N9&QE<E]S=&%C:R==("`@(#T@87)R87DH*3L*"FEN:5]S970H)W1R
M86-K7V5R<F]R<R<L('1R=64I.PH*+RHJ"B`J($)A<V4@8VQA<W,@9F]R(&]T
M:&5R(%!%05(@8VQA<W-E<RX@(%!R;W9I9&5S(')U9&EM96YT87)Y"B`J(&5M
M=6QA=&EO;B!O9B!D97-T<G5C=&]R<RX*("H*("H@268@>6]U('=A;G0@82!D
M97-T<G5C=&]R(&EN('EO=7(@8VQA<W,L(&EN:&5R:70@4$5!4B!A;F0@;6%K
M92!A"B`J(&1E<W1R=6-T;W(@;65T:&]D(&-A;&QE9"!?>6]U<F-L87-S;F%M
M92`H<V%M92!N86UE(&%S('1H90H@*B!C;VYS=')U8W1O<BP@8G5T('=I=&@@
M82`B7R(@<')E9FEX*2X@($%L<V\L(&EN('EO=7(@8V]N<W1R=6-T;W(@>6]U
M"B`J(&AA=F4@=&\@8V%L;"!T:&4@4$5!4B!C;VYS=')U8W1O<CH@)'1H:7,M
M/E!%05(H*3LN"B`J(%1H92!D97-T<G5C=&]R(&UE=&AO9"!W:6QL(&)E(&-A
M;&QE9"!W:71H;W5T('!A<F%M971E<G,N("!.;W1E('1H870*("H@870@:6X@
M<V]M92!305!)(&EM<&QE;65N=&%T:6]N<R`H<W5C:"!A<R!!<&%C:&4I+"!A
M;GD@;W5T<'5T(&1U<FEN9PH@*B!T:&4@<F5Q=65S="!S:'5T9&]W;B`H:6X@
M=VAI8V@@9&5S=')U8W1O<G,@87)E(&-A;&QE9"D@<V5E;7,@=&\@8F4*("H@
M9&ES8V%R9&5D+B`@268@>6]U(&YE960@=&\@9V5T(&%N>2!D96)U9R!I;F9O
M<FUA=&EO;B!F<F]M('EO=7(*("H@9&5S=')U8W1O<BP@=7-E(&5R<F]R7VQO
M9R@I+"!S>7-L;V<H*2!O<B!S;VUE=&AI;F<@<VEM:6QA<BX*("H*("H@24U0
M3U)404Y4(2!4;R!U<V4@=&AE(&5M=6QA=&5D(&1E<W1R=6-T;W)S('EO=2!N
M965D('1O(&-R96%T92!T:&4*("H@;V)J96-T<R!B>2!R969E<F5N8V4Z("1O
M8FH@/28@;F5W(%!%05)?8VAI;&0["B`J"B`J($!S:6YC92!02%`@-"XP+C(*
M("H@0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J($!S964@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO"B`J+PIC;&%S<R!014%2"GL*
M("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R
M('1O(&5N86)L92!I;G1E<FYA;"!D96)U9R!M97-S86=E<RX*("`@("`J"B`@
M("`@*B!`=F%R("`@("!B;V]L"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V1E8G5G(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@
M*B!$969A=6QT(&5R<F]R(&UO9&4@9F]R('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!V87(@("`@(&EN=`H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]D969A=6QT7V5R<F]R7VUO9&4@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@1&5F875L="!E<G)O<B!O<'1I;VYS('5S960@9F]R
M('1H:7,@;V)J96-T('=H96X@97)R;W(@;6]D90H@("`@("H@:7,@4$5!4E]%
M4E)/4E]44DE'1T52+@H@("`@("H*("`@("`J($!V87(@("`@(&EN=`H@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D969A=6QT
M7V5R<F]R7V]P=&EO;G,@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1&5F875L
M="!E<G)O<B!H86YD;&5R("AC86QL8F%C:RD@9F]R('1H:7,@;V)J96-T+"!I
M9B!E<G)O<B!M;V1E(&ES"B`@("`@*B!014%27T524D]27T-!3$Q"04-++@H@
M("`@("H*("`@("`J($!V87(@("`@('-T<FEN9PH@("`@("H@0&%C8V5S<R`@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D969A=6QT7V5R<F]R7VAA;F1L
M97(@/2`G)SL*"B`@("`O*BH*("`@("`J(%=H:6-H(&-L87-S('1O('5S92!F
M;W(@97)R;W(@;V)J96-T<RX*("`@("`J"B`@("`@*B!`=F%R("`@("!S=')I
M;F<*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M97)R;W)?8VQA<W,@/2`G4$5!4E]%<G)O<B<["@H@("`@+RHJ"B`@("`@*B!!
M;B!A<G)A>2!O9B!E>'!E8W1E9"!E<G)O<G,N"B`@("`@*@H@("`@("H@0'9A
M<B`@("`@87)R87D*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?97AP96-T961?97)R;W)S(#T@87)R87DH*3L*"B`@("`O+R!]
M?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+B`@4F5G:7-T97)S('1H:7,@;V)J96-T(&EN"B`@("`@*B`D
M7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="!F;W(@9&5S=')U8W1O<B!E
M;75L871I;VX@:68@80H@("`@("H@9&5S=')U8W1O<B!O8FIE8W0@97AI<W1S
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5R<F]R7V-L87-S("`H
M;W!T:6]N86PI('=H:6-H(&-L87-S('1O('5S92!F;W(*("`@("`J("`@("`@
M("!E<G)O<B!O8FIE8W1S+"!D969A=6QT<R!T;R!014%27T5R<F]R+@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!014%2*"1E<G)O<E]C;&%S<R`](&YU;&PI"B`@("![
M"B`@("`@("`@)&-L87-S;F%M92`](&=E=%]C;&%S<R@D=&AI<RD["B`@("`@
M("`@:68@*"1T:&ES+3Y?9&5B=6<I('L*("`@("`@("`@("`@<')I;G0@(E!%
M05(@8V]N<W1R=6-T;W(@8V%L;&5D+"!C;&%S<STD8VQA<W-N86UE7&XB.PH@
M("`@("`@('T*("`@("`@("!I9B`H)&5R<F]R7V-L87-S("$]/2!N=6QL*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W)?8VQA<W,@/2`D97)R;W)?8VQA
M<W,["B`@("`@("`@?0H@("`@("`@('=H:6QE("@D8VQA<W-N86UE*2!["B`@
M("`@("`@("`@("1D97-T<G5C=&]R(#T@(E\D8VQA<W-N86UE(CL*("`@("`@
M("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,L("1D97-T<G5C=&]R*2D@
M>PH@("`@("`@("`@("`@("`@9VQO8F%L("1?4$5!4E]D97-T<G5C=&]R7V]B
M:F5C=%]L:7-T.PH@("`@("`@("`@("`@("`@)%]014%27V1E<W1R=6-T;W)?
M;V)J96-T7VQI<W1;72`]("8D=&AI<SL*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-L87-S
M;F%M92`](&=E=%]P87)E;G1?8VQA<W,H)&-L87-S;F%M92D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9&5S=')U8W1O<@H*("`@("\J*@H@("`@("H@1&5S=')U8W1O<B`H=&AE(&5M
M=6QA=&5D('1Y<&4@;V8N+BXI+B`@1&]E<R!N;W1H:6YG(')I9VAT(&YO=RP*
M("`@("`J(&)U="!I<R!I;F-L=61E9"!F;W(@9F]R=V%R9"!C;VUP871I8FEL
M:71Y+"!S;R!S=6)C;&%S<PH@("`@("H@9&5S=')U8W1O<G,@<VAO=6QD(&%L
M=V%Y<R!C86QL(&ET+@H@("`@("H*("`@("`J(%-E92!T:&4@;F]T92!I;B!T
M:&4@8VQA<W,@9&5S8VEP=&EO;B!A8F]U="!O=71P=70@9G)O;0H@("`@("H@
M9&5S=')U8W1O<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?4$5!4B@I
M('L*("`@("`@("!I9B`H)'1H:7,M/E]D96)U9RD@>PH@("`@("`@("`@("!P
M<FEN=&8H(E!%05(@9&5S=')U8W1O<B!C86QL960L(&-L87-S/25S7&XB+"!G
M971?8VQA<W,H)'1H:7,I*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9V5T4W1A=&EC4')O<&5R='DH*0H*("`@("\J*@H@("`@
M*B!)9B!Y;W4@:&%V92!A(&-L87-S('1H870G<R!M;W-T;'DO96YT:7)E;'D@
M<W1A=&EC+"!A;F0@>6]U(&YE960@<W1A=&EC"B`@("`J('!R;W!E<G1I97,L
M('EO=2!C86X@=7-E('1H:7,@;65T:&]D('1O('-I;75L871E('1H96TN($5G
M+B!I;B!Y;W5R(&UE=&AO9"AS*0H@("`@*B!D;R!T:&ES.B`D;7E687(@/2`F
M4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)VUY5F%R)RD["B`@("`J(%EO=2!-
M55-4('5S92!A(')E9F5R96YC92P@;W(@=&AE>2!W:6QL(&YO="!P97)S:7-T
M(0H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`<&%R86T@('-T
M<FEN9R`D8VQA<W,@(%1H92!C86QL:6YG(&-L87-S;F%M92P@=&\@<')E=F5N
M="!C;&%S:&5S"B`@("`J($!P87)A;2`@<W1R:6YG("1V87(@("`@5&AE('9A
M<FEA8FQE('1O(')E=')I979E+@H@("`@*B!`<F5T=7)N(&UI>&5D("`@02!R
M969E<F5N8V4@=&\@=&AE('9A<FEA8FQE+B!)9B!N;W0@<V5T(&ET('=I;&P@
M8F4*("`@("H@("`@("`@("`@("`@("`@(&%U=&\@:6YI=&EA;&ES960@=&\@
M3E5,3"X*("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4W1A=&EC4')O<&5R='DH
M)&-L87-S+"`D=F%R*0H@("`@>PH@("`@("`@('-T871I8R`D<')O<&5R=&EE
M<SL*("`@("`@("!R971U<FX@)'!R;W!E<G1I97-;)&-L87-S75LD=F%R73L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!R96=I<W1E<E-H=71D;W=N
M1G5N8R@I"@H@("`@+RHJ"B`@("`J(%5S92!T:&ES(&9U;F-T:6]N('1O(')E
M9VES=&5R(&$@<VAU=&1O=VX@;65T:&]D(&9O<B!S=&%T:6,*("`@("H@8VQA
M<W-E<RX*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M
M("!M:7AE9"`D9G5N8R`@5&AE(&9U;F-T:6]N(&YA;64@*&]R(&%R<F%Y(&]F
M(&-L87-S+VUE=&AO9"D@=&\@8V%L;`H@("`@*B!`<&%R86T@(&UI>&5D("1A
M<F=S("!4:&4@87)G=6UE;G1S('1O('!A<W,@=&\@=&AE(&9U;F-T:6]N"B`@
M("`J($!R971U<FX@=F]I9`H@("`@*B\*("`@(&9U;F-T:6]N(')E9VES=&5R
M4VAU=&1O=VY&=6YC*"1F=6YC+"`D87)G<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UU;72`](&%R
M<F%Y*"1F=6YC+"`D87)G<RD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@:7-%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!496QL('=H971H97(@82!V
M86QU92!I<R!A(%!%05(@97)R;W(N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M;6EX960@)&1A=&$@("!T:&4@=F%L=64@=&\@=&5S=`H@("`@("H@0'!A<F%M
M("`@:6YT("`@)&-O9&4@("!I9B`D9&%T82!I<R!A;B!E<G)O<B!O8FIE8W0L
M(')E='5R;B!T<G5E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&]N
M;'D@:68@)&-O9&4@:7,@82!S=')I;F<@86YD"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("1O8FHM/F=E=$UE<W-A9V4H*2`]/2`D8V]D92!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`D8V]D92!I<R!A;B!I;G1E
M9V5R(&%N9"`D;V)J+3YG971#;V1E*"D@/3T@)&-O9&4*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@8F]O;"`@("!T<G5E(&EF('!A
M<F%M971E<B!I<R!A;B!E<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5R
M<F]R*"1D871A+"`D8V]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@:68@*&ES
M7VYU;&PH)&-O9&4I*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D8V]D92DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D9&%T82T^9V5T365S<V%G92@I(#T]("1C
M;V1E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1D871A+3YG971#;V1E*"D@/3T@)&-O9&4["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[('-E=$5R<F]R2&%N9&QI;F<H*0H*("`@("\J*@H@
M("`@("H@4V5T<R!H;W<@97)R;W)S(&=E;F5R871E9"!B>2!T:&ES(&]B:F5C
M="!S:&]U;&0@8F4@:&%N9&QE9"X*("`@("`J($-A;B!B92!I;G9O:V5D(&)O
M=&@@:6X@;V)J96-T<R!A;F0@<W1A=&EC86QL>2X@($EF(&-A;&QE9`H@("`@
M("H@<W1A=&EC86QL>2P@<V5T17)R;W)(86YD;&EN9R!S971S('1H92!D969A
M=6QT(&)E:&%V:6]U<B!F;W(@86QL"B`@("`@*B!014%2(&]B:F5C=',N("!)
M9B!C86QL960@:6X@86X@;V)J96-T+"!S971%<G)O<DAA;F1L:6YG('-E=',*
M("`@("`J('1H92!D969A=6QT(&)E:&%V:6]U<B!F;W(@=&AA="!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D;6]D90H@("`@("H@("`@("`@
M($]N92!O9B!014%27T524D]27U)%5%523BP@4$5!4E]%4E)/4E]04DE.5"P*
M("`@("`J("`@("`@("!014%27T524D]27U1224='15(L(%!%05)?15)23U)?
M1$E%+`H@("`@("H@("`@("`@(%!%05)?15)23U)?0T%,3$)!0TL@;W(@4$5!
M4E]%4E)/4E]%6$-%4%1)3TXN"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1O<'1I;VYS"B`@("`@*B`@("`@("`@5VAE;B`D;6]D92!I<R!014%27T52
M4D]27U1224='15(L('1H:7,@:7,@=&AE(&5R<F]R(&QE=F5L("AO;F4*("`@
M("`J("`@("`@("!O9B!%7U5315)?3D]424-%+"!%7U5315)?5T%23DE.1R!O
M<B!%7U5315)?15)23U(I+@H@("`@("H*("`@("`J("`@("`@("!7:&5N("1M
M;V1E(&ES(%!%05)?15)23U)?0T%,3$)!0TLL('1H:7,@<&%R86UE=&5R(&ES
M(&5X<&5C=&5D"B`@("`@*B`@("`@("`@=&\@8F4@=&AE(&-A;&QB86-K(&9U
M;F-T:6]N(&]R(&UE=&AO9"X@($$@8V%L;&)A8VL*("`@("`J("`@("`@("!F
M=6YC=&EO;B!I<R!A('-T<FEN9R!W:71H('1H92!N86UE(&]F('1H92!F=6YC
M=&EO;BP@80H@("`@("H@("`@("`@(&-A;&QB86-K(&UE=&AO9"!I<R!A;B!A
M<G)A>2!O9B!T=V\@96QE;65N=',Z('1H92!E;&5M96YT"B`@("`@*B`@("`@
M("`@870@:6YD97@@,"!I<R!T:&4@;V)J96-T+"!A;F0@=&AE(&5L96UE;G0@
M870@:6YD97@@,2!I<PH@("`@("H@("`@("`@('1H92!N86UE(&]F('1H92!M
M971H;V0@=&\@8V%L;"!I;B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J("`@
M("`@("!7:&5N("1M;V1E(&ES(%!%05)?15)23U)?4%))3E0@;W(@4$5!4E]%
M4E)/4E]$244L('1H:7,@:7,*("`@("`J("`@("`@("!A('!R:6YT9B!F;W)M
M870@<W1R:6YG('5S960@=VAE;B!P<FEN=&EN9R!T:&4@97)R;W(*("`@("`J
M("`@("`@("!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J($!S964@4$5!4E]%4E)/4E]2
M15154DX*("`@("`J($!S964@4$5!4E]%4E)/4E]04DE.5`H@("`@("H@0'-E
M92!014%27T524D]27U1224='15(*("`@("`J($!S964@4$5!4E]%4E)/4E]$
M244*("`@("`J($!S964@4$5!4E]%4E)/4E]#04Q,0D%#2PH@("`@("H@0'-E
M92!014%27T524D]27T580T505$E/3@H@("`@("H*("`@("`J($!S:6YC92!0
M2%`@-"XP+C4*("`@("`J+PH*("`@(&9U;F-T:6]N('-E=$5R<F]R2&%N9&QI
M;F<H)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES*2`F)B!I<U]A*"1T:&ES+"`G4$5!4B<I*2![
M"B`@("`@("`@("`@("1S971M;V1E("`@("`]("8D=&AI<RT^7V1E9F%U;'1?
M97)R;W)?;6]D93L*("`@("`@("`@("`@)'-E=&]P=&EO;G,@(#T@)B1T:&ES
M+3Y?9&5F875L=%]E<G)O<E]O<'1I;VYS.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S971M;V1E("`@("`]("8D1TQ/0D%,4ULG7U!%05)?9&5F
M875L=%]E<G)O<E]M;V1E)UT["B`@("`@("`@("`@("1S971O<'1I;VYS("`]
M("8D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT["B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*"1M;V1E*2!["B`@("`@("`@("`@
M(&-A<V4@4$5!4E]%4E)/4E]215154DXZ"B`@("`@("`@("`@(&-A<V4@4$5!
M4E]%4E)/4E]04DE.5#H*("`@("`@("`@("`@8V%S92!014%27T524D]27U12
M24='15(Z"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]$244Z"B`@("`@
M("`@("`@(&-A<V4@4$5!4E]%4E)/4E]%6$-%4%1)3TXZ"B`@("`@("`@("`@
M(&-A<V4@;G5L;#H*("`@("`@("`@("`@("`@("1S971M;V1E(#T@)&UO9&4[
M"B`@("`@("`@("`@("`@("`D<V5T;W!T:6]N<R`]("1O<'1I;VYS.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(%!%05)?15)2
M3U)?0T%,3$)!0TLZ"B`@("`@("`@("`@("`@("`D<V5T;6]D92`]("1M;V1E
M.PH@("`@("`@("`@("`@("`@+R\@8VQA<W,O;V)J96-T(&UE=&AO9"!C86QL
M8F%C:PH@("`@("`@("`@("`@("`@:68@*&ES7V-A;&QA8FQE*"1O<'1I;VYS
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1S971O<'1I;VYS(#T@)&]P=&EO
M;G,["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@('1R:6=G97)?97)R;W(H(FEN=F%L:60@97)R;W(@8V%L;&)A8VLB+"!%
M7U5315)?5T%23DE.1RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("!T<FEG9V5R7V5R<F]R*")I;G9A;&ED(&5R<F]R(&UO9&4B+"!%7U53
M15)?5T%23DE.1RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97AP96-T17)R;W(H*0H*
M("`@("\J*@H@("`@("H@5&AI<R!M971H;V0@:7,@=7-E9"!T;R!T96QL('=H
M:6-H(&5R<F]R<R!Y;W4@97AP96-T('1O(&=E="X*("`@("`J($5X<&5C=&5D
M(&5R<F]R<R!A<F4@86QW87ES(')E='5R;F5D('=I=&@@97)R;W(@;6]D90H@
M("`@("H@4$5!4E]%4E)/4E]215154DXN("!%>'!E8W1E9"!E<G)O<B!C;V1E
M<R!A<F4@<W1O<F5D(&EN(&$@<W1A8VLL"B`@("`@*B!A;F0@=&AI<R!M971H
M;V0@<'5S:&5S(&$@;F5W(&5L96UE;G0@;VYT;R!I="X@(%1H92!L:7-T(&]F
M"B`@("`@*B!E>'!E8W1E9"!E<G)O<G,@87)E(&EN(&5F9F5C="!U;G1I;"!T
M:&5Y(&%R92!P;W!P960@;V9F('1H90H@("`@("H@<W1A8VL@=VET:"!T:&4@
M<&]P17AP96-T*"D@;65T:&]D+@H@("`@("H*("`@("`J($YO=&4@=&AA="!T
M:&ES(&UE=&AO9"!C86X@;F]T(&)E(&-A;&QE9"!S=&%T:6-A;&QY"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1C;V1E(&$@<VEN9VQE(&5R<F]R(&-O
M9&4@;W(@86X@87)R87D@;V8@97)R;W(@8V]D97,@=&\@97AP96-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@("`@('1H92!N97<@9&5P=&@@;V8@=&AE
M(")E>'!E8W1E9"!E<G)O<G,B('-T86-K"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!E>'!E8W1%<G)O<B@D8V]D92`]("<J
M)RD*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&-O9&4I*2!["B`@("`@
M("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,L("1C
M;V1E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!A<G)A>5]P=7-H
M*"1T:&ES+3Y?97AP96-T961?97)R;W)S+"!A<G)A>2@D8V]D92DI.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@<VEZ96]F*"1T:&ES+3Y?97AP96-T961?
M97)R;W)S*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P;W!%>'!E
M8W0H*0H*("`@("\J*@H@("`@("H@5&AI<R!M971H;V0@<&]P<R!O;F4@96QE
M;65N="!O9F8@=&AE(&5X<&5C=&5D(&5R<F]R(&-O9&5S"B`@("`@*B!S=&%C
M:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@=&AE(&QI<W0@;V8@
M97)R;W(@8V]D97,@=&AA="!W97)E('!O<'!E9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!P;W!%>'!E8W0H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>5]P
M;W`H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(%]C:&5C:T1E;$5X<&5C="@I"@H@("`@+RHJ"B`@("`@
M*B!4:&ES(&UE=&AO9"!C:&5C:W,@=6YS971S(&%N(&5R<F]R(&-O9&4@:68@
M879A:6QA8FQE"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D(&5R<F]R(&-O
M9&4*("`@("`J($!R971U<FX@8F]O;"!T<G5E(&EF('1H92!E<G)O<B!C;V1E
M('=A<R!U;G-E="P@9F%L<V4@;W1H97)W:7-E"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J($!S:6YC92!02%`@-"XS+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V-H96-K1&5L17AP96-T*"1E<G)O<E]C;V1E*0H@("`@>PH@("`@
M("`@("1D96QE=&5D(#T@9F%L<V4["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?97AP96-T961?97)R;W)S($%3("1K97D@/3X@)&5R<F]R7V%R<F%Y*2![
M"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D97)R;W)?8V]D92P@)&5R<F]R
M7V%R<F%Y*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]E>'!E
M8W1E9%]E<G)O<G-;)&ME>5U;87)R87E?<V5A<F-H*"1E<G)O<E]C;V1E+"`D
M97)R;W)?87)R87DI72D["B`@("`@("`@("`@("`@("`D9&5L971E9"`]('1R
M=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(&-L96%N('5P(&5M
M<'1Y(&%R<F%Y<PH@("`@("`@("`@("!I9B`H,"`]/2!C;W5N="@D=&AI<RT^
M7V5X<&5C=&5D7V5R<F]R<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?97AP96-T961?97)R;W)S6R1K97E=*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&1E;&5T960["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&5L17AP96-T*"D*"B`@("`O*BH*
M("`@("`J(%1H:7,@;65T:&]D(&1E;&5T97,@86QL(&]C8W5R96YC97,@;V8@
M=&AE('-P96-I9FEE9"!E;&5M96YT(&9R;VT*("`@("`J('1H92!E>'!E8W1E
M9"!E<G)O<B!C;V1E<R!S=&%C:RX*("`@("`J"B`@("`@*B!`<&%R86T@(&UI
M>&5D("1E<G)O<E]C;V1E(&5R<F]R(&-O9&4@=&AA="!S:&]U;&0@8F4@9&5L
M971E9`H@("`@("H@0')E='5R;B!M:7AE9"!L:7-T(&]F(&5R<F]R(&-O9&5S
M('1H870@=V5R92!D96QE=&5D(&]R(&5R<F]R"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-I;F-E(%!(4"`T+C,N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!D96Q%>'!E8W0H)&5R<F]R7V-O9&4I"B`@("!["B`@("`@("`@)&1E
M;&5T960@/2!F86QS93L*"B`@("`@("`@:68@*"AI<U]A<G)A>2@D97)R;W)?
M8V]D92D@)B8@*#`@(3T@8V]U;G0H)&5R<F]R7V-O9&4I*2DI('L*("`@("`@
M("`@("`@+R\@)&5R<F]R7V-O9&4@:7,@82!N;VXM96UP='D@87)R87D@:&5R
M93L*("`@("`@("`@("`@+R\@=V4@=V%L:R!T:')O=6=H(&ET('1R>6EN9R!T
M;R!U;G-E="!A;&P*("`@("`@("`@("`@+R\@=F%L=65S"B`@("`@("`@("`@
M(&9O<F5A8V@H)&5R<F]R7V-O9&4@87,@)&ME>2`]/B`D97)R;W(I('L*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-H96-K1&5L17AP96-T*"1E<G)O
M<BDI('L*("`@("`@("`@("`@("`@("`@("`D9&5L971E9"`]("!T<G5E.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M9&5L971E9"`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@(')E='5R;B`D9&5L971E9"`_('1R=64@.B!014%2
M.CIR86ES945R<F]R*")4:&4@97AP96-T960@97)R;W(@>6]U('-U8FUI='1E
M9"!D;V5S(&YO="!E>&ES="(I.R`O+R!)35!23U9%($U%"B`@("`@("`@?2!E
M;'-E:68@*"%E;7!T>2@D97)R;W)?8V]D92DI('L*("`@("`@("`@("`@+R\@
M)&5R<F]R7V-O9&4@8V]M97,@86QO;F4L('1R>6EN9R!T;R!U;G-E="!I=`H@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]C:&5C:T1E;$5X<&5C="@D97)R;W)?
M8V]D92DI('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(E1H92!E>'!E8W1E9"!E<G)O<B!Y;W4@<W5B;6ET=&5D(&1O
M97,@;F]T(&5X:7-T(BD[("\O($E-4%)/5D4@344*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O("1E<G)O<E]C;V1E(&ES
M(&5M<'1Y"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")4
M:&4@97AP96-T960@97)R;W(@>6]U('-U8FUI='1E9"!I<R!E;7!T>2(I.R`O
M+R!)35!23U9%($U%"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(')A:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@5&AI<R!M971H
M;V0@:7,@82!W<F%P<&5R('1H870@<F5T=7)N<R!A;B!I;G-T86YC92!O9B!T
M:&4*("`@("`J(&-O;F9I9W5R960@97)R;W(@8VQA<W,@=VET:"!T:&ES(&]B
M:F5C="=S(&1E9F%U;'0@97)R;W(*("`@("`J(&AA;F1L:6YG(&%P<&QI960N
M("!)9B!T:&4@)&UO9&4@86YD("1O<'1I;VYS('!A<F%M971E<G,@87)E(&YO
M=`H@("`@("H@<W!E8VEF:65D+"!T:&4@;V)J96-T)W,@9&5F875L=',@87)E
M('5S960N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1M97-S86=E(&$@
M=&5X="!E<G)O<B!M97-S86=E(&]R(&$@4$5!4B!E<G)O<B!O8FIE8W0*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT("1C;V1E("`@("`@82!N=6UE<FEC(&5R
M<F]R(&-O9&4@*&ET(&ES('5P('1O('EO=7(@8VQA<W,*("`@("`J("`@("`@
M("`@("`@("`@("`@=&\@9&5F:6YE('1H97-E(&EF('EO=2!W86YT('1O('5S
M92!C;V1E<RD*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1M;V1E("`@("`@
M3VYE(&]F(%!%05)?15)23U)?4D5455).+"!014%27T524D]27U!224Y4+`H@
M("`@("H@("`@("`@("`@("`@("`@("!014%27T524D]27U1224='15(L(%!%
M05)?15)23U)?1$E%+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27T52
M4D]27T-!3$Q"04-++"!014%27T524D]27T580T505$E/3BX*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&]P=&EO;G,@268@)&UO9&4@:7,@4$5!4E]%
M4E)/4E]44DE'1T52+"!T:&ES('!A<F%M971E<@H@("`@("H@("`@("`@("`@
M("`@("`@("!S<&5C:69I97,@=&AE(%!(4"UI;G1E<FYA;"!E<G)O<B!L979E
M;"`H;VYE(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@($5?55-%4E].3U1)
M0T4L($5?55-%4E]705).24Y'(&]R($5?55-%4E]%4E)/4BDN"B`@("`@*B`@
M("`@("`@("`@("`@("`@($EF("1M;V1E(&ES(%!%05)?15)23U)?0T%,3$)!
M0TLL('1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@<&%R86UE=&5R('-P
M96-I9FEE<R!T:&4@8V%L;&)A8VL@9G5N8W1I;VX@;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@;65T:&]D+B`@26X@;W1H97(@97)R;W(@;6]D97,@=&AI
M<R!P87)A;65T97(*("`@("`J("`@("`@("`@("`@("`@("`@:7,@:6=N;W)E
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R:6YF;R!)9B!Y
M;W4@;F5E9"!T;R!P87-S(&%L;VYG(&9O<B!E>&%M<&QE(&1E8G5G"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N+"!T:&ES('!A<F%M971E
M<B!I<R!M96%N="!F;W(@=&AA="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1E<G)O<E]C;&%S<R!4:&4@<F5T=7)N960@97)R;W(@;V)J96-T('=I
M;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@:6YS=&%N=&EA=&5D(&9R
M;VT@=&AI<R!C;&%S<RP@:68@<W!E8VEF:65D+@H@("`@("H*("`@("`J($!P
M87)A;2!B;V]L("1S:VEP;7-G($EF('1R=64L(')A:7-E17)R;W(@=VEL;"!O
M;FQY('!A<W,@97)R;W(@8V]D97,L"B`@("`@*B`@("`@("`@("`@("`@("`@
M('1H92!E<G)O<B!M97-S86=E('!A<F%M971E<B!W:6QL(&)E(&1R;W!P960N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@
M;V)J96-T("`@82!014%2(&5R<F]R(&]B:F5C=`H@("`@("H@0'-E92!014%2
M.CIS971%<G)O<DAA;F1L:6YG"B`@("`@*B!`<VEN8V4@4$A0(#0N,"XU"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&UE<W-A9V4@/2!N=6QL
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&-O9&4@/2!N=6QL+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&UO9&4@/2!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)&]P=&EO;G,@/2!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'5S97)I;F9O(#T@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("1E<G)O<E]C;&%S<R`](&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D<VMI<&US9R`](&9A;'-E*0H@("`@>PH@("`@("`@("\O
M(%1H92!E<G)O<B!I<R!Y970@82!014%2(&5R<F]R(&]B:F5C=`H@("`@("`@
M(&EF("AI<U]O8FIE8W0H)&UE<W-A9V4I*2!["B`@("`@("`@("`@("1C;V1E
M("`@("`@("`]("1M97-S86=E+3YG971#;V1E*"D["B`@("`@("`@("`@("1U
M<V5R:6YF;R`@("`]("1M97-S86=E+3YG9715<V5R26YF;R@I.PH@("`@("`@
M("`@("`D97)R;W)?8VQA<W,@/2`D;65S<V%G92T^9V5T5'EP92@I.PH@("`@
M("`@("`@("`D;65S<V%G92T^97)R;W)?;65S<V%G95]P<F5F:7@@/2`G)SL*
M("`@("`@("`@("`@)&UE<W-A9V4@("`@(#T@)&UE<W-A9V4M/F=E=$UE<W-A
M9V4H*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RD@)B8@
M:7-S970H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I("8F('-I>F5O9B@D=&AI
M<RT^7V5X<&5C=&5D7V5R<F]R<RD@/B`P("8F('-I>F5O9B@D97AP(#T@96YD
M*"1T:&ES+3Y?97AP96-T961?97)R;W)S*2DI('L*("`@("`@("`@("`@:68@
M*"1E>'!;,%T@/3T@(BHB('Q\"B`@("`@("`@("`@("`@("`H:7-?:6YT*')E
M<V5T*"1E>'`I*2`F)B!I;E]A<G)A>2@D8V]D92P@)&5X<"DI('Q\"B`@("`@
M("`@("`@("`@("`H:7-?<W1R:6YG*')E<V5T*"1E>'`I*2`F)B!I;E]A<G)A
M>2@D;65S<V%G92P@)&5X<"DI*2!["B`@("`@("`@("`@("`@("`D;6]D92`]
M(%!%05)?15)23U)?4D5455)..PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@("\O($YO(&UO9&4@9VEV96XL('1R>2!G;&]B86P@;VYE<PH@("`@
M("`@(&EF("@D;6]D92`]/3T@;G5L;"D@>PH@("`@("`@("`@("`O+R!#;&%S
M<R!E<G)O<B!H86YD;&5R"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RD@
M)B8@:7-S970H)'1H:7,M/E]D969A=6QT7V5R<F]R7VUO9&4I*2!["B`@("`@
M("`@("`@("`@("`D;6]D92`@("`]("1T:&ES+3Y?9&5F875L=%]E<G)O<E]M
M;V1E.PH@("`@("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^7V1E9F%U
M;'1?97)R;W)?;W!T:6]N<SL*("`@("`@("`@("`@+R\@1VQO8F%L(&5R<F]R
M(&AA;F1L97(*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1'3$]"04Q3
M6R=?4$5!4E]D969A=6QT7V5R<F]R7VUO9&4G72DI('L*("`@("`@("`@("`@
M("`@("1M;V1E("`@(#T@)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?
M;6]D92==.PH@("`@("`@("`@("`@("`@)&]P=&EO;G,@/2`D1TQ/0D%,4ULG
M7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("@D97)R;W)?8VQA<W,@(3T](&YU;&PI
M('L*("`@("`@("`@("`@)&5C(#T@)&5R<F]R7V-L87-S.PH@("`@("`@('T@
M96QS96EF("AI<W-E="@D=&AI<RD@)B8@:7-S970H)'1H:7,M/E]E<G)O<E]C
M;&%S<RDI('L*("`@("`@("`@("`@)&5C(#T@)'1H:7,M/E]E<G)O<E]C;&%S
M<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D96,@/2`G4$5!4E]%
M<G)O<B<["B`@("`@("`@?0H@("`@("`@(&EF("@D<VMI<&US9RD@>PH@("`@
M("`@("`@("!R971U<FX@;F5W("1E8R@D8V]D92P@)&UO9&4L("1O<'1I;VYS
M+"`D=7-E<FEN9F\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!N97<@)&5C*"1M97-S86=E+"`D8V]D92P@)&UO9&4L("1O<'1I;VYS
M+"`D=7-E<FEN9F\I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!T:')O=T5R<F]R*"D*"B`@("`O*BH*("`@("`J(%-I;7!L97(@
M9F]R;2!O9B!R86ES945R<F]R('=I=&@@9F5W97(@;W!T:6]N<RX@($EN(&UO
M<W0@8V%S97,*("`@("`J(&UE<W-A9V4L(&-O9&4@86YD('5S97)I;F9O(&%R
M92!E;F]U9V@N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G
M90H@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@=&AR;W=%<G)O<B@D;65S
M<V%G92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`D8V]D92`]
M(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<FEN9F\@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RD@)B8@:7-?<W5B
M8VQA<W-?;V8H)'1H:7,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1M97-S86=E+"`D8V]D92P@;G5L
M;"P@;G5L;"P@)'5S97)I;F9O*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D;65S<V%G92P@)&-O9&4L
M(&YU;&PL(&YU;&PL("1U<V5R:6YF;RD["B`@("`@("`@?0H@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[('!U<VA%<G)O<DAA;F1L:6YG*"D*"B`@("`O
M*BH*("`@("`J(%!U<V@@82!N97<@97)R;W(@:&%N9&QE<B!O;B!T;W`@;V8@
M=&AE(&5R<F]R(&AA;F1L97(@;W!T:6]N<R!S=&%C:RX@5VET:"!T:&ES"B`@
M("`@*B!Y;W4@8V%N(&5A<VEL>2!O=F5R<FED92!T:&4@86-T=6%L(&5R<F]R
M(&AA;F1L97(@9F]R('-O;64@8V]D92!A;F0@<F5S=&]R90H@("`@("H@:70@
M;&%T97(@=VET:"!P;W!%<G)O<DAA;F1L:6YG+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D;6]D92`H<V%M92!A<R!S971%<G)O<DAA;F1L:6YG*0H@
M("`@("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS("AS86UE(&%S('-E=$5R<F]R
M2&%N9&QI;F<I"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L($%L=V%Y<R!T
M<G5E"B`@("`@*@H@("`@("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L:6YG
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!U<VA%<G)O<DAA;F1L:6YG*"1M;V1E
M+"`D;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@)'-T86-K(#T@)B1'
M3$]"04Q36R=?4$5!4E]E<G)O<E]H86YD;&5R7W-T86-K)UT["B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES*2`F)B!I<U]A*"1T:&ES+"`G4$5!4B<I*2!["B`@
M("`@("`@("`@("1D969?;6]D92`@("`]("8D=&AI<RT^7V1E9F%U;'1?97)R
M;W)?;6]D93L*("`@("`@("`@("`@)&1E9E]O<'1I;VYS(#T@)B1T:&ES+3Y?
M9&5F875L=%]E<G)O<E]O<'1I;VYS.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1D969?;6]D92`@("`]("8D1TQ/0D%,4ULG7U!%05)?9&5F875L
M=%]E<G)O<E]M;V1E)UT["B`@("`@("`@("`@("1D969?;W!T:6]N<R`]("8D
M1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT["B`@("`@
M("`@?0H@("`@("`@("1S=&%C:UM=(#T@87)R87DH)&1E9E]M;V1E+"`D9&5F
M7V]P=&EO;G,I.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,I("8F(&ES7V$H
M)'1H:7,L("=014%2)RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$5R<F]R
M2&%N9&QI;F<H)&UO9&4L("1O<'1I;VYS*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!014%2.CIS971%<G)O<DAA;F1L:6YG*"1M;V1E+"`D;W!T
M:6]N<RD["B`@("`@("`@?0H@("`@("`@("1S=&%C:UM=(#T@87)R87DH)&UO
M9&4L("1O<'1I;VYS*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!P;W!%<G)O<DAA;F1L:6YG*"D*"B`@("`O
M*BH*("`@("H@4&]P('1H92!L87-T(&5R<F]R(&AA;F1L97(@=7-E9`H@("`@
M*@H@("`@*B!`<F5T=7)N(&)O;VP@06QW87ES('1R=64*("`@("H*("`@("H@
M0'-E92!014%2.CIP=7-H17)R;W)(86YD;&EN9PH@("`@*B\*("`@(&9U;F-T
M:6]N('!O<$5R<F]R2&%N9&QI;F<H*0H@("`@>PH@("`@("`@("1S=&%C:R`]
M("8D1TQ/0D%,4ULG7U!%05)?97)R;W)?:&%N9&QE<E]S=&%C:R==.PH@("`@
M("`@(&%R<F%Y7W!O<"@D<W1A8VLI.PH@("`@("`@(&QI<W0H)&UO9&4L("1O
M<'1I;VYS*2`]("1S=&%C:UMS:7IE;V8H)'-T86-K*2`M(#%=.PH@("`@("`@
M(&%R<F%Y7W!O<"@D<W1A8VLI.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RD@
M)B8@:7-?82@D=&AI<RP@)U!%05(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5T17)R;W)(86YD;&EN9R@D;6]D92P@)&]P=&EO;G,I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H)&UO
M9&4L("1O<'1I;VYS*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;&]A9$5X=&5N<VEO;B@I
M"@H@("`@+RHJ"B`@("`J($]3(&EN9&5P96YD86YT(%!(4"!E>'1E;G-I;VX@
M;&]A9"X@4F5M96UB97(@=&\@=&%K92!C87)E"B`@("`J(&]N('1H92!C;W)R
M96-T(&5X=&5N<VEO;B!N86UE(&9O<B!C87-E('-E;G-I=&EV92!/4V5S+@H@
M("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1E>'0@5&AE(&5X=&5N<VEO;B!N
M86UE"B`@("`J($!R971U<FX@8F]O;"!3=6-C97-S(&]R(&YO="!O;B!T:&4@
M9&PH*2!C86QL"B`@("`J+PH@("`@9G5N8W1I;VX@;&]A9$5X=&5N<VEO;B@D
M97AT*0H@("`@>PH@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@D97AT
M*2D@>PH@("`@("`@("`@("`O+R!I9B!E:71H97(@<F5T=7)N<R!T<G5E(&1L
M*"D@=VEL;"!P<F]D=6-E(&$@1D%404P@97)R;W(L('-T;W`@=&AA=`H@("`@
M("`@("`@("!I9B`H*&EN:5]G970H)V5N86)L95]D;"<I("$](#$I('Q\("AI
M;FE?9V5T*"=S869E7VUO9&4G*2`]/2`Q*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("A/
M4U]724Y$3U=3*2!["B`@("`@("`@("`@("`@("`D<W5F9FEX(#T@)RYD;&PG
M.PH@("`@("`@("`@("!](&5L<V5I9B`H4$A07T]3(#T]("=(4"U56"<I('L*
M("`@("`@("`@("`@("`@("1S=69F:7@@/2`G+G-L)SL*("`@("`@("`@("`@
M?2!E;'-E:68@*%!(4%]/4R`]/2`G04E8)RD@>PH@("`@("`@("`@("`@("`@
M)'-U9F9I>"`]("<N82<["B`@("`@("`@("`@('T@96QS96EF("A02%!?3U,@
M/3T@)T]36"<I('L*("`@("`@("`@("`@("`@("1S=69F:7@@/2`G+F)U;F1L
M92<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<W5F
M9FEX(#T@)RYS;R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M($!D;"@G<&AP7R<N)&5X="XD<W5F9FEX*2!\?"!`9&PH)&5X="XD<W5F9FEX
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+R\@?7U]"GT*"B\O('M[>R!?4$5!4E]C86QL7V1E<W1R=6-T;W)S*"D*"F9U
M;F-T:6]N(%]014%27V-A;&Q?9&5S=')U8W1O<G,H*0I["B`@("!G;&]B86P@
M)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0["B`@("!I9B`H:7-?87)R
M87DH)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0I("8F"B`@("`@("`@
M<VEZ96]F*"1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T*2D*("`@('L*
M("`@("`@("!R97-E="@D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="D[
M"B`@("`@("`@=VAI;&4@*&QI<W0H)&LL("1O8FIR968I(#T@96%C:"@D7U!%
M05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="DI('L*("`@("`@("`@("`@)&-L
M87-S;F%M92`](&=E=%]C;&%S<R@D;V)J<F5F*3L*("`@("`@("`@("`@=VAI
M;&4@*"1C;&%S<VYA;64I('L*("`@("`@("`@("`@("`@("1D97-T<G5C=&]R
M(#T@(E\D8VQA<W-N86UE(CL*("`@("`@("`@("`@("`@(&EF("AM971H;V1?
M97AI<W1S*"1O8FIR968L("1D97-T<G5C=&]R*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1O8FIR968M/B1D97-T<G5C=&]R*"D["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1C;&%S<VYA;64@/2!G971?<&%R96YT7V-L87-S*"1C
M;&%S<VYA;64I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("\O($5M<'1Y('1H92!O8FIE8W0@;&ES="!T;R!E
M;G-U<F4@=&AA="!D97-T<G5C=&]R<R!A<F4*("`@("`@("`O+R!N;W0@8V%L
M;&5D(&UO<F4@=&AA;B!O;F-E+@H@("`@("`@("1?4$5!4E]D97-T<G5C=&]R
M7V]B:F5C=%]L:7-T(#T@87)R87DH*3L*("`@('T*"B`@("`O+R!.;W<@8V%L
M;"!T:&4@<VAU=&1O=VX@9G5N8W1I;VYS"B`@("!I9B`H:7-?87)R87DH)$=,
M3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UTI($%.1"`A96UP='DH)$=,
M3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UTI*2!["B`@("`@("`@9F]R
M96%C:"`H)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UT@87,@)'9A
M;'5E*2!["B`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1V86QU
M95LP72P@)'9A;'5E6S%=*3L*("`@("`@("!]"B`@("!]"GT*"B\O('U]?0H*
M8VQA<W,@4$5!4E]%<G)O<@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@
M('9A<B`D97)R;W)?;65S<V%G95]P<F5F:7@@/2`G)SL*("`@('9A<B`D;6]D
M92`@("`@("`@("`@("`@("`@/2!014%27T524D]27U)%5%523CL*("`@('9A
M<B`D;&5V96P@("`@("`@("`@("`@("`@/2!%7U5315)?3D]424-%.PH@("`@
M=F%R("1C;V1E("`@("`@("`@("`@("`@("`]("TQ.PH@("`@=F%R("1M97-S
M86=E("`@("`@("`@("`@("`]("<G.PH@("`@=F%R("1U<V5R:6YF;R`@("`@
M("`@("`@("`]("<G.PH@("`@=F%R("1B86-K=')A8V4@("`@("`@("`@("`]
M(&YU;&P["@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@
M("`O*BH*("`@("`J(%!%05)?17)R;W(@8V]N<W1R=6-T;W(*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!M97-S86=E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN="`D8V]D92`@("`@*&]P=&EO;F%L*2!E<G)O<B!C
M;V1E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D;6]D92`@("`@*&]P=&EO
M;F%L*2!E<G)O<B!M;V1E+"!O;F4@;V8Z(%!%05)?15)23U)?4D5455).+`H@
M("`@("H@4$5!4E]%4E)/4E]04DE.5"P@4$5!4E]%4E)/4E]$244L(%!%05)?
M15)23U)?5%))1T=%4BP*("`@("`J(%!%05)?15)23U)?0T%,3$)!0TL@;W(@
M4$5!4E]%4E)/4E]%6$-%4%1)3TX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&]P=&EO;G,@("`H;W!T:6]N86PI(&5R<F]R(&QE=F5L+"!?3U)?(&EN
M('1H92!C87-E(&]F"B`@("`@*B!014%27T524D]27T-!3$Q"04-++"!T:&4@
M8V%L;&)A8VL@9G5N8W1I;VX@;W(@;V)J96-T+VUE=&AO9`H@("`@("H@='5P
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FEN9F\@*&]P
M=&EO;F%L*2!A9&1I=&EO;F%L('5S97(O9&5B=6<@:6YF;PH@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO
M;B!014%27T5R<F]R*"1M97-S86=E(#T@)W5N:VYO=VX@97)R;W(G+"`D8V]D
M92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("1M;V1E(#T@;G5L
M;"P@)&]P=&EO;G,@/2!N=6QL+"`D=7-E<FEN9F\@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@D;6]D92`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D;6]D
M92`](%!%05)?15)23U)?4D5455)..PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^;65S<V%G92`@(#T@)&UE<W-A9V4["B`@("`@("`@)'1H:7,M/F-O9&4@
M("`@("`]("1C;V1E.PH@("`@("`@("1T:&ES+3YM;V1E("`@("`@/2`D;6]D
M93L*("`@("`@("`D=&AI<RT^=7-E<FEN9F\@(#T@)'5S97)I;F9O.PH@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H(F1E8G5G7V)A8VMT<F%C92(I*2![
M"B`@("`@("`@("`@("1T:&ES+3YB86-K=')A8V4@/2!D96)U9U]B86-K=')A
M8V4H*3L*("`@("`@("!]"B`@("`@("`@:68@*"1M;V1E("8@4$5!4E]%4E)/
M4E]#04Q,0D%#2RD@>PH@("`@("`@("`@("`D=&AI<RT^;&5V96P@/2!%7U53
M15)?3D]424-%.PH@("`@("`@("`@("`D=&AI<RT^8V%L;&)A8VL@/2`D;W!T
M:6]N<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)&]P=&EO
M;G,@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@("1O<'1I;VYS(#T@15]5
M4T527TY/5$E#13L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M;&5V96P@/2`D;W!T:6]N<SL*("`@("`@("`@("`@)'1H:7,M/F-A;&QB86-K
M(#T@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YM;V1E("8@
M4$5!4E]%4E)/4E]04DE.5"D@>PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D
M;W!T:6]N<RD@?'P@:7-?:6YT*"1O<'1I;VYS*2D@>PH@("`@("`@("`@("`@
M("`@)&9O<FUA="`]("(E<R(["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D9F]R;6%T(#T@)&]P=&EO;G,["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<')I;G1F*"1F;W)M870L("1T:&ES+3YG971-97-S86=E
M*"DI.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%2
M7T524D]27U1224='15(I('L*("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@D
M=&AI<RT^9V5T365S<V%G92@I+"`D=&AI<RT^;&5V96PI.PH@("`@("`@('T*
M("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27T1)12D@>PH@
M("`@("`@("`@("`D;7-G(#T@)'1H:7,M/F=E=$UE<W-A9V4H*3L*("`@("`@
M("`@("`@:68@*&ES7VYU;&PH)&]P=&EO;G,I('Q\(&ES7VEN="@D;W!T:6]N
M<RDI('L*("`@("`@("`@("`@("`@("1F;W)M870@/2`B)7,B.PH@("`@("`@
M("`@("`@("`@:68@*'-U8G-T<B@D;7-G+"`M,2D@(3T@(EQN(BD@>PH@("`@
M("`@("`@("`@("`@("`@("1M<V<@+CT@(EQN(CL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F;W)M
M870@/2`D;W!T:6]N<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!D:64H
M<W!R:6YT9B@D9F]R;6%T+"`D;7-G*2D["B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?0T%,3$)!0TLI('L*("`@("`@
M("`@("`@:68@*&ES7V-A;&QA8FQE*"1T:&ES+3YC86QL8F%C:RDI('L*("`@
M("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3YC86QL8F%C:RP@
M)'1H:7,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("A0
M14%27UI%,B`F)B`D=&AI<RT^;6]D92`F(%!%05)?15)23U)?15A#15!424].
M*2!["B`@("`@("`@("`@(&5V86PH)W1H<F]W("1T:&ES.R<I.PH@("`@("`@
M('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G971-;V1E*"D*"B`@
M("`O*BH*("`@("`J($=E="!T:&4@97)R;W(@;6]D92!F<F]M(&%N(&5R<F]R
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!E<G)O<B!M;V1E
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G
M971-;V1E*"D@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;6]D93L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!G971#86QL8F%C:R@I"@H@("`@+RHJ
M"B`@("`@*B!'970@=&AE(&-A;&QB86-K(&9U;F-T:6]N+VUE=&AO9"!F<F]M
M(&%N(&5R<F]R(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M(&-A;&QB86-K(&9U;F-T:6]N(&]R(&]B:F5C="]M971H;V0@87)R87D*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-A
M;&QB86-K*"D@>PH@("`@("`@(')E='5R;B`D=&AI<RT^8V%L;&)A8VL["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T365S<V%G92@I"@H*("`@
M("\J*@H@("`@("H@1V5T('1H92!E<G)O<B!M97-S86=E(&9R;VT@86X@97)R
M;W(@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@('-T<FEN9R`@9G5L
M;"!E<G)O<B!M97-S86=E"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!G971-97-S86=E*"D*("`@('L*("`@("`@("!R971U
M<FX@*"1T:&ES+3YE<G)O<E]M97-S86=E7W!R969I>"`N("1T:&ES+3YM97-S
M86=E*3L*("`@('T*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T0V]D92@I
M"@H@("`@+RHJ"B`@("`@*B!'970@97)R;W(@8V]D92!F<F]M(&%N(&5R<F]R
M(&]B:F5C=`H@("`@("H*("`@("`J($!R971U<FX@:6YT(&5R<F]R(&-O9&4*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@("!F=6YC=&EO;B!G
M971#;V1E*"D*("`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YC;V1E.PH@
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9714>7!E*"D*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@;F%M92!O9B!T:&ES(&5R<F]R+V5X8V5P=&EO
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!E<G)O<B]E>&-E<'1I
M;VX@;F%M92`H='EP92D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B!G
M971?8VQA<W,H)'1H:7,I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&=E=%5S97));F9O*"D*"B`@("`O*BH*("`@("`J($=E="!A9&1I=&EO;F%L
M('5S97(M<W5P<&QI960@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@=7-E<BUS=7!P;&EE9"!I;F9O<FUA=&EO;@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T57-E<DEN
M9F\H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^=7-E<FEN9F\["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T1&5B=6=);F9O*"D*"B`@
M("`O*BH*("`@("`J($=E="!A9&1I=&EO;F%L(&1E8G5G(&EN9F]R;6%T:6]N
M('-U<'!L:65D(&)Y('1H92!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R!D96)U9R!I;F9O<FUA=&EO;@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5B=6=);F9O*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=%5S97));F9O*"D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T0F%C:W1R86-E*"D*"B`@
M("`O*BH*("`@("`J($=E="!T:&4@8V%L;"!B86-K=')A8V4@9G)O;2!W:&5R
M92!T:&4@97)R;W(@=V%S(&=E;F5R871E9"X*("`@("`J(%-U<'!O<G1E9"!W
M:71H(%!(4"`T+C,N,"!O<B!N97=E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT("1F<F%M92`H;W!T:6]N86PI('=H870@9G)A;64@=&\@9F5T8V@*("`@
M("`J($!R971U<FX@87)R87D@0F%C:W1R86-E+"!O<B!.54Q,(&EF(&YO="!A
M=F%I;&%B;&4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971"86-K=')A8V4H)&9R86UE(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H)&9R86UE(#T]/2!N=6QL*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^8F%C:W1R86-E.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/F)A8VMT<F%C95LD9G)A;65=.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&%D9%5S97));F9O*"D*"B`@("!F=6YC=&EO;B!A9&15<V5R
M26YF;R@D:6YF;RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/G5S
M97)I;F9O*2D@>PH@("`@("`@("`@("`D=&AI<RT^=7-E<FEN9F\@/2`D:6YF
M;SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^=7-E<FEN
M9F\@+CT@(B`J*B`D:6YF;R(["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[('1O4W1R:6YG*"D*"B`@("`O*BH*("`@("`J($UA:V4@
M82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AI<R!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@82!S=')I;F<@=VET:"!A;B!O8FIE
M8W0@<W5M;6%R>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@=&]3=')I;F<H*2!["B`@("`@("`@)&UO9&5S(#T@87)R87DH
M*3L*("`@("`@("`D;&5V96QS(#T@87)R87DH15]54T527TY/5$E#12`@/3X@
M)VYO=&EC92<L"B`@("`@("`@("`@("`@("`@("`@("`@($5?55-%4E]705).
M24Y'(#T^("=W87)N:6YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@15]5
M4T527T524D]2("`@/3X@)V5R<F]R)RD["B`@("`@("`@:68@*"1T:&ES+3YM
M;V1E("8@4$5!4E]%4E)/4E]#04Q,0D%#2RD@>PH@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'1H:7,M/F-A;&QB86-K*2D@>PH@("`@("`@("`@("`@("`@
M)&-A;&QB86-K(#T@9V5T7V-L87-S*"1T:&ES+3YC86QL8F%C:ULP72D@+B`G
M.CHG("X*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%L;&)A8VM;,5T[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8V%L;&)A
M8VL@/2`D=&AI<RT^8V%L;&)A8VL["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@<F5T=7)N('-P<FEN=&8H)ULE<SH@;65S<V%G93TB)7,B(&-O9&4])60@
M;6]D93UC86QL8F%C:R`G+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8V%L;&)A8VL])7,@<')E9FEX/2(E<R(@:6YF;STB)7,B72<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&=E=%]C;&%S<R@D=&AI<RDL("1T:&ES+3YM
M97-S86=E+"`D=&AI<RT^8V]D92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-A;&QB86-K+"`D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU<V5R:6YF;RD["B`@
M("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?
M4%))3E0I('L*("`@("`@("`@("`@)&UO9&5S6UT@/2`G<')I;G0G.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27U12
M24='15(I('L*("`@("`@("`@("`@)&UO9&5S6UT@/2`G=')I9V=E<B<["B`@
M("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?
M1$E%*2!["B`@("`@("`@("`@("1M;V1E<UM=(#T@)V1I92<["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?4D5455).
M*2!["B`@("`@("`@("`@("1M;V1E<UM=(#T@)W)E='5R;B<["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!S<')I;G1F*"=;)7,Z(&UE<W-A9V4](B5S(B!C
M;V1E/25D(&UO9&4])7,@;&5V96P])7,@)RX*("`@("`@("`@("`@("`@("`@
M("`@("`G<')E9FEX/2(E<R(@:6YF;STB)7,B72<L"B`@("`@("`@("`@("`@
M("`@("`@("`@9V5T7V-L87-S*"1T:&ES*2P@)'1H:7,M/FUE<W-A9V4L("1T
M:&ES+3YC;V1E+`H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H(GPB
M+"`D;6]D97,I+"`D;&5V96QS6R1T:&ES+3YL979E;%TL"B`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YU<V5R:6YF;RD["B`@("!]"@H@
M("`@+R\@?7U]"GT*"G)E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*")?4$5!
M4E]C86QL7V1E<W1R=6-T;W)S(BD["@HO*@H@*B!,;V-A;"!687)I86)L97,Z
M"B`J(&UO9&4Z('!H<`H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S
M970Z(#0*("H@16YD.@H@*B\*/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+T-A8VAE+G!H<```````````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U,C4V`#$P-#$W,S8S,#`W`#`Q-S`V
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2
M(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@
M1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS
M92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@
M?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*
M+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O
M8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@
M("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN
M9&4^("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!#86-H92YP:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q
M,3HU-#HT-2!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["G)E
M<75I<F5?;VYC92`G0V%C:&4O17)R;W(N<&AP)SL*"B\J*@HJ($-A8VAE(&ES
M(&$@8F%S92!C;&%S<R!F;W(@8V%C:&4@:6UP;&5M96YT871I;VYS+@HJ"BH@
M5&AE('!E87(@8V%C:&4@;6]D=6QE(&ES(&$@9V5N97)I8R!D871A(&-A8VAE
M('=H:6-H(&-A;B!B92!U<V5D('1O(`HJ(&-A8VAE('-C<FEP="!R=6YS+B!4
M:&4@:61E82!B96AI;F0@=&AE(&-A8VAE(&ES('%U:71E('-I;7!L92X@268@
M>6]U(&AA=F4**B!T:&4@<V%M92!I;G!U="!P87)A;65T97)S(&9O<B!W:&%T
M979E<B!T87-K<R]A;&=O<FET:&T@>6]U('5S92!Y;W4G;&P**B!U<W5A;&QY
M(&=E="!T:&4@<V%M92!O=71P=70N(%-O('=H>2!N;W0@8V%C:&EN9R!T96UP
M;&%T97,L(&9U;F-T:6]N<R!C86QL<RP**B!G<F%P:&EC(&=E;F5R871I;VX@
M971C+B!#86-H:6YG(&-E<G1A:6X@86-T:6]N<R!E+F<N(%A33%0@=')A;F9O
M<FUA=&EO;G,**B!S879E<R!Y;W4@;&]T<R!O9B!T:6UE+B`**@HJ(%1H92!D
M97-I9VX@;V8@=&AE(&-A8VAE(')E;6EN9',@;V8@4$A03&EB<R!S97-S:6]N
M(&EM<&QE;65N=&%T:6]N+B!!(`HJ("A02%!,:6(Z('-E<W-I;VXI(&-O;G1R
M;VQL97(@=7-E<R!S=&]R86=E(&-O;G1A:6YE<B`H4$A03&EB.B!C=%\J+FEN
M8RD@=&\@<V%V92`**B!C97)T86EN(&1A=&$@*%!(4$QI8CH@<V5S<VEO;B!D
M871A*2X@26X@8V]N=')A<W0@=&\@=&AE('-E<W-I;VX@<W1U9F8@:70G<R!U
M<"!T;R`**B!Y;W4@=&\@9V5N97)A=&4@86X@240@9F]R('1H92!D871A('1O
M(&-A8VAE+B!)9B!Y;W4G<F4@=7-I;F<@=&AE(&]U='!U="!C86-H90HJ('EO
M=2!M:6=H="!U<V4@=&AE('-C<FEP="!N86UE(&%S(&$@<V5E9"!F;W(@8V%C
M:&4Z.F=E;F5R871E240H*2P@:68@>6]U<B!U<VEN9R!T:&4**B!F=6YC=&EO
M;B!C86-H92!Y;W4G9"!U<V4@86X@87)R87D@=VET:"!A;&P@9G5N8W1I;VX@
M<&%R86UE=&5R<RX**@HJ(%5S86=E(&5X86UP;&4@;V8@=&AE(&=E;F5R:6,@
M9&%T82!C86-H93H**@HJ(')E<75I<F5?;VYC92@G0V%C:&4N<&AP)RD["BH*
M*B`D8V%C:&4@/2!N97<@0V%C:&4H)V9I;&4G+"!A<G)A>2@G8V%C:&5?9&ER
M)R`]/B`G8V%C:&4O)RD@*3L**B`D:60@/2`D8V%C:&4M/F=E;F5R871E240H
M)W1E<W1E;G1R>2<I.PHJ"BH@:68@*"1D871A(#T@)&-A8VAE+3YG970H)&ED
M*2D@>PHJ("`@('!R:6YT(")#86-H92!H:70N/&)R/D1A=&$Z("1D871A(CL*
M*@HJ('T@96QS92!["BH@("`D9&%T82`]("=D871A(&]F(&%N>2!K:6YD)SL*
M*B`@("1C86-H92T^<V%V92@D:60L("1D871A*3L**B`@('!R:6YT("=#86-H
M92!M:7-S+CQB<CXG.PHJ('T**@HJ(%=!4DY)3D<Z($YO($9I;&4O1$(M5&%B
M;&4M4F]W(&QO8VMI;F<@:7,@:6UP;&5M96YT960@>65T+`HJ("`@("`@("`@
M(&ET)W,@<&]S<VEB;&4L('1H870@>6]U(&=E="!C;W)R=7!T960@9&%T82UE
M;G1R:65S('5N9&5R"BH@("`@("`@("`@8F%D(&-I<F-U;7-T86YC97,@("AE
M<W!E8VEA;&QY('=I=&@@=&AE(&9I;&4@8V]N=&%I;F5R*0HJ"BH@0&%U=&AO
M<B`@(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V97)S
M:6]N("`D260Z($-A8VAE+G!H<"QV(#$N-2`R,#`S+S`Q+S`T(#$Q.C4T.C0U
M(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BH@0&%C8V5S<R`@('!U8FQI
M8PHJ+PIC;&%S<R!#86-H92!E>'1E;F1S(%!%05(@>PH*("`@("\J*@H@("`@
M*B!%;F%B;&5S("\@9&ES86)L97,@8V%C:&EN9RX*("`@("H*("`@("H@5$]$
M3SH@061D(&5X<&QA;F%T:6]N('=H870@=&AI<R!I<R!G;V]D(&9O<BX*("`@
M("H*("`@("H@0'9A<B`@("`@(&)O;VQE86X*("`@("H@0&%C8V5S<R`@('!R
M:79A=&4*("`@("HO"B`@("!V87(@)&-A8VAI;F<@/2!T<G5E.PH*("`@("\J
M*@H@("`@*B!'87)B86=E(&-O;&QE8W1I;VXZ('!R;V)A8FEL:71Y(&EN('-E
M8V]N9',*("`@("H*("`@("H@268@<V5T('1O(&$@=F%L=64@86)O=F4@,"!A
M(&=A<F)A9V4@8V]L;&5C=&EO;B!W:6QL"B`@("`J(&9L=7-H(&%L;"!C86-H
M92!E;G1R:65S(&]L9&5R('1H86X@=&AE('-P96-I9FEE9"!N=6UB97(*("`@
M("H@;V8@<V5C;VYD<RX*("`@("H*("`@("H@0'9A<B`@("`@(&EN=&5G97(*
M("`@("H@0'-E92`@("`@("1G8U]P<F]B86)I;&ET>2P@)&=C7VUA>&QI9F5T
M:6UE"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!V87(@)&=C
M7W1I;64@(#T@,3L*"B`@("`O*BH*("`@("H@1V%R8F%G92!C;VQL96-T:6]N
M.B!P<F]B86)I;&ET>2!I;B!P97)C96YT"B`@("`J"B`@("`J(%1/1$\Z($%D
M9"!A;B!E>'!L86YA=&EO;BX*("`@("H*("`@("H@0'9A<B`@("`@(&EN=&5G
M97(@("`@(#`@/3X@;F5V97(*("`@("H@0'-E92`@("`@("1G8U]T:6UE+"`D
M9V-?;6%X;&EF971I;64*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*
M("`@('9A<B`D9V-?<')O8F%B:6QI='D@/2`Q.PH@("`@"B`@("`O*BH*("`@
M("H@1V%R8F%G92!C;VQL96-T:6]N.B!D96QE=&4@86QL(&5N=')I97,@;F]T
M('5S92!F;W(@;B!S96-O;F1S+@H@("`@*@H@("`@*B!$969A=6QT(&ES(&]N
M92!D87DL(#8P("H@-C`@*B`R-"`](#@V-#`P('-E8V]N9',N"B`@("`J"B`@
M("`J($!V87(@(&EN=&5G97(*("`@("H@0'-E92`@)&=C7W!R;V)A8FEL:71Y
M+"`D9V-?=&EM90H@("`@*B\*("`@('9A<B`D9V-?;6%X;&EF971I;64@/2`X
M-C0P,#L*"B`@("`O*BH*("`@("H@4W1O<F%G92!C;VYT86EN97(@;V)J96-T
M+@H@("`@*@H@("`@*B!`=F%R("!O8FIE8W0@0V%C:&5?0V]N=&%I;F5R"B`@
M("`J+PH@("`@=F%R("1C;VYT86EN97(["@H@("`@+R\*("`@("\O('!U8FQI
M8R!M971H;V1S"B`@("`O+PH*("`@("\J*@H@("`@*@H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("!.86UE(&]F(&-O;G1A:6YE<B!C;&%S<PH@("`@*B!`<&%R
M86T@("`@87)R87D@("!!<G)A>2!W:71H(&-O;G1A:6YE<B!C;&%S<R!O<'1I
M;VYS"B`@("`J+PH@("`@9G5N8W1I;VX@0V%C:&4H)&-O;G1A:6YE<BP@)&-O
M;G1A:6YE<E]O<'1I;VYS(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/E!%
M05(H*3L*("`@("`@("`D8V]N=&%I;F5R(#T@<W1R=&]L;W=E<B@D8V]N=&%I
M;F5R*3L*("`@("`@("`D8V]N=&%I;F5R7V-L87-S(#T@)T-A8VAE7T-O;G1A
M:6YE<E\G("X@)&-O;G1A:6YE<CL*("`@("`@("`D8V]N=&%I;F5R7V-L87-S
M9FEL92`]("=#86-H92]#;VYT86EN97(O)R`N("1C;VYT86EN97(@+B`G+G!H
M<"<["@H@("`@("`@(&EN8VQU9&5?;VYC92`D8V]N=&%I;F5R7V-L87-S9FEL
M93L*("`@("`@("`D=&AI<RT^8V]N=&%I;F5R(#T@;F5W("1C;VYT86EN97)?
M8VQA<W,H)&-O;G1A:6YE<E]O<'1I;VYS*3L*("`@('T*"B`@("`O+V1E8V]N
M<W1R=6-T;W(*("`@(&9U;F-T:6]N(%]#86-H92@I"B`@("!["B`@("`@("`@
M)'1H:7,M/F=A<F)A9V5#;VQL96-T:6]N*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!C=7)R96YT(&-A8VAI;F<@<W1A=&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B`@8F]O;&5A;B`@("`@5&AE(&-U<G)E;G0@8V%C
M:&EN9R!S=&%T92X*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971#86-H:6YG*"D*("`@('L*("`@("`@("!R971U<FX@
M*"1T:&ES+3YC86-H:6YG*3L*("`@('T*"B`@("`O*BH*("`@("`J($5N86)L
M97,@;W(@9&ES86)L97,@8V%C:&EN9RX*("`@("`J"B`@("`@*B!`<&%R86T@
M("!B;V]L96%N("`@("!4:&4@;F5W(&-A8VAI;F<@<W1A=&4N"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V%C:&EN
M9R@D<W1A=&4I"B`@("!["B`@("`@("`@)'1H:7,M/F-A8VAI;F<@/2`D<W1A
M=&4["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(')E<75E<W1E
M9"!D871A<V5T(&ET(&EF(&5X:7-T<R!A;F0@:7,@;F]T(&5X<&ER960*("`@
M("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@
M;6EX960@("!C86-H960@9&%T82!O<B!.54Q,(&]N(&9A:6QU<F4*("`@("H@
M0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D:60L
M("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A
M8VAI;F<I"B`@("`@("`@("`@(')E='5R;B`G)SL*"B`@("`@("`@:68@*"1T
M:&ES+3YI<T-A8VAE9"@D:60L("1G<F]U<"D@)B8@(21T:&ES+3YI<T5X<&ER
M960H)&ED+"`D9W)O=7`I*0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FQO
M860H)&ED+"`D9W)O=7`I.PH*("`@("`@("!R971U<FX@3E5,3#L*("`@('T@
M+R\@96YD(&9U;F,@9V5T"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!T:&4@9VEV
M96X@9&%T82!I;B!T:&4@8V%C:&4N"B`@("`J"B`@("`J($!P87)A;2`@("!S
M=')I;F<@(&1A=&%S970@240@=7-E9"!A<R!C86-H92!I9&5N=&EF:65R"B`@
M("`J($!P87)A;2`@("!M:7AE9"`@(&1A=&$@=&\@8V%C:&4*("`@("H@0'!A
M<F%M("`@(&EN=&5G97(@;&EF971I;64@;V8@=&AE(&-A8VAE9"!D871A(&EN
M('-E8V]N9',@+2`P(&9O<B!E;F1L97-S"B`@("`J($!P87)A;2`@("!S=')I
M;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I
M9"P@)&1A=&$L("1E>'!I<F5S(#T@,"P@)&=R;W5P(#T@)V1E9F%U;'0G*2![
M"B`@("`@("`@:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T
M=7)N('1R=64["@H@("`@("`@(')E='5R;B`D=&AI<RT^97AT4V%V92@D:60L
M("1D871A+"`G)RPD97AP:7)E<RP@)&=R;W5P*3L*("`@('T@+R\@96YD(&9U
M;F,@<V%V90H*("`@("\J*@H@("`@*B!3=&]R97,@82!D871A<V5T('=I=&@@
M861D:71I;VYA;"!U<V5R9&5F:6YE9"!D871A+@H@("`@*@H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!M:7AE
M9"`@(&1A=&$@=&\@<W1O<F4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@861D
M:71I;VYA;"!U<V5R9&5F:6YE9"!D871A"B`@("`J($!P87)A;2`@("!M:7AE
M9"`@('5S97)D969I;F5D(&5X<&ER92!D871E"B`@("`J($!P87)A;2`@("!S
M=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@
M("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@("`@*B!`86-C97-S("`@<'5B
M;&EC"B`@("`J($!S964@("`@("!G9715<V5R9&%T82@I"B`@("`J+PH@("`@
M9G5N8W1I;VX@97AT4V%V92@D:60L("1C86-H961A=&$L("1U<V5R9&%T82P@
M)&5X<&ER97,@/2`P+"`D9W)O=7`@/2`G9&5F875L="<I('L*("`@("`@("!I
M9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R971U<FX@=')U93L*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YC;VYT86EN97(M/G-A=F4H)&ED+"`D
M8V%C:&5D871A+"`D97AP:7)E<RP@)&=R;W5P+"`D=7-E<F1A=&$I.PH@("`@
M?2`O+R!E;F0@9G5N8R!E>'13879E"@H@("`@+RHJ"B`@("`J($QO861S('1H
M92!G:79E;B!)1"!F<F]M('1H92!C86-H92X*("`@("H*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@;6EX960@("!C86-H960@
M9&%T82!O<B!.54Q,(&]N(&9A:6QU<F4*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PH@("`@*B\*("`@(&9U;F-T:6]N(&QO860H)&ED+"`D9W)O=7`@/2`G9&5F
M875L="<I('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@
M("`@("!R971U<FX@)R<["@H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&%I
M;F5R+3YL;V%D*"1I9"P@)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@;&]A
M9`H*("`@("\J*@H@("`@*B!2971U<FYS('1H92!U<V5R9&%T82!F:65L9"!O
M9B!A(&-A8VAE9"!D871A('-E="X*("`@("H*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H
M92!G<F]U<`H@("`@*B!`<F5T=7)N("`@<W1R:6YG("!U<V5R9&%T80H@("`@
M*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!E>'13879E*"D*
M("`@("HO"B`@("!F=6YC=&EO;B!G9715<V5R9&%T82@D:60L("1G<F]U<"`]
M("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@
M("`@("`@("`@(')E='5R;B`G)SL*"B`@("`@("`@<F5T=7)N("1T:&ES+3YC
M;VYT86EN97(M/F=E=%5S97)D871A*"1I9"P@)&=R;W5P*3L*("`@('T@+R\@
M96YD(&9U;F,@9V5T57-E<F1A=&$*"B`@("`O*BH*("`@("H@4F5M;W9E<R!T
M:&4@<W!E8VEF:65D(&1A=&%S970@9G)O;2!T:&4@8V%C:&4N"B`@("`J"B`@
M("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@(&)O;VQE
M86X*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V92@D:60L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF
M("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*
M("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1A:6YE<BT^<F5M;W9E*"1I9"P@
M)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@<F5M;W9E"@H@("`@+RHJ"B`@
M("`J($9L=7-H97,@=&AE(&-A8VAE("T@<F5M;W9E<R!A;&P@9&%T82!F<F]M
M(&ET"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P
M+"!I9B!E;7!T>2!A;&P@9W)O=7!S('=I;&P@8F4@9FQA<VAE9`H@("`@*B!`
M<F5T=7)N("`@:6YT96=E<B!N=6UB97(@;V8@<F5M;W9E9"!D871A<V5T<PH@
M("`@*B\*("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"`]("=D969A=6QT)RD@
M>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH*("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1A:6YE<BT^
M9FQU<V@H)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@9FQU<V@*"B`@("`O
M*BH*("`@("H@0VAE8VMS(&EF(&$@9&%T87-E="!E>&ES=',N"B`@("`J"B`@
M("`J($YO=&4Z('1H:7,@9&]E<R!N;W0@<V%Y('1H870@=&AE(&-A8VAE9"!D
M871A(&ES(&YO="!E>'!I<F5D(0H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE
M(&=R;W5P"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`J($!A8V-E<W,@
M("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!I<T-A8VAE9"@D:60L("1G
M<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI
M;F<I"B`@("`@("`@("`@(')E='5R;B!F86QS93L*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YC;VYT86EN97(M/FES0V%C:&5D*"1I9"P@)&=R;W5P*3L*("`@
M('T@+R\@96YD(&9U;F,@:7-#86-H960*"B`@("`O*BH*("`@("H@0VAE8VMS
M(&EF(&$@9&%T87-E="!I<R!E>'!I<F5D"B`@("`J"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M8V%C:&4@9W)O=7`*("`@("H@0'!A<F%M("`@(&EN=&5G97(@;6%X:6UU;2!A
M9V4@9F]R('1H92!C86-H960@9&%T82!I;B!S96-O;F1S("T@,"!F;W(@96YD
M;&5S<PH@("`@*B`@("`@("`@("`@("`@("`@("!)9B!T:&4@8V%C:&5D(&1A
M=&$@:7,@;VQD97(@8G5T('1H92!G:79E;B!L:69E=&EM92!I="!W:6QL"B`@
M("`J("`@("`@("`@("`@("`@("`@(&)E(')E;6]V960@9G)O;2!T:&4@8V%C
M:&4N(%EO=2!D;VXG="!H879E('1O('!R;W9I9&4@=&AI<PH@("`@*B`@("`@
M("`@("`@("`@("`@("!A<F=U;65N="!I9B!Y;W4@8V%L;"!I<T5X<&ER960H
M*2X@179E<GD@9&%T87-E="!K;F]W<PH@("`@*B`@("`@("`@("`@("`@("`@
M("!I="=S(&5X<&ER92!D871E(&%N9"!W:6QL(&)E(')E;6]V960@875T;VUA
M=&EC86QL>2X@57-E"B`@("`J("`@("`@("`@("`@("`@("`@('1H:7,@;VYL
M>2!I9B!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN9RXN+@H@("`@*B!`<F5T
M=7)N("`@8F]O;&5A;@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@
M("`@9G5N8W1I;VX@:7-%>'!I<F5D*"1I9"P@)&=R;W5P(#T@)V1E9F%U;'0G
M+"`D;6%X7V%G92`](#`I('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG
M*0H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YC;VYT86EN97(M/FES17AP:7)E9"@D:60L("1G<F]U<"P@)&UA>%]A
M9V4I.PH@("`@?2`O+R!E;F0@9G5N8R!I<T5X<&ER960*"B`@("`O*BH*("`@
M("H@1V5N97)A=&5S(&$@(G5N:7%U92(@240@9F]R('1H92!G:79E;B!V86QU
M90H@("`@*@H@("`@*B!4:&ES(&ES(&$@<75I8VL@8G5T(&1I<G1Y(&AA8VL@
M=&\@9V5T(&$@(G5N:7%U92(@240@9F]R(&$@86YY(&MI;F0@;V8@=F%R:6%B
M;&4N"B`@("`J($E$(&-L87-H97,@;6EG:'0@;V-C=7(@9G)O;2!T:6UE('1O
M('1I;64@86QT:&]U9V@@=&AE>2!A<F4@97AT<F5M92!U;FQI:V5L>2$*("`@
M("H*("`@("H@0'!A<F%M("`@(&UI>&5D("`@=F%R:6%B;&4@=&\@9V5N97)A
M=&4@82!)1"!F;W(*("`@("H@0')E='5R;B`@('-T<FEN9R`@(G5N:7%U92(@
M240*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N
M(&=E;F5R871E240H)'9A<FEA8FQE*2!["B`@("`@("`@+R\@5T%23DE.1SH@
M240@8VQA<VAE<R!A<F4@<&]S<VEB;&4@86QT:&]U9V@@=6YL:6ME;'D*("`@
M("`@("!R971U<FX@;60U*'-E<FEA;&EZ92@D=F%R:6%B;&4I*3L*("`@('T*
M"B`@("`O*BH*("`@("H@0V%L;',@=&AE(&=A<F)A9V4@8V]L;&5C=&]R(&]F
M('1H92!S=&]R86=E(&]B:F5C="!W:71H(&$@8V5R=&%I;B!P<F]B86)I;&ET
M>0H@("`@*@H@("`@*B!`<&%R86T@("`@8F]O;&5A;B!&;W)C92!A(&=A<F)A
M9V4@8V]L;&5C=&EO;B!R=6X_"B`@("`J($!S964@("1G8U]P<F]B86)I;&ET
M>2P@)&=C7W1I;64*("`@("HO"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C
M=&EO;B@D9F]R8V4@/2!F86QS92D@>PH@("`@("`@('-T871I8R`D;&%S=%]R
M=6X@/2`P.PH*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@
M("`@("!R971U<FX["@H@("`@("`@('-R86YD*"AD;W5B;&4I(&UI8W)O=&EM
M92@I("H@,3`P,#`P,"D["@H@("`@("`@("\O('1I;64@86YD('!R;V)A8FEL
M:71Y(&)A<V5D"B`@("`@("`@:68@*"@D9F]R8V4I('Q\("@D;&%S=%]R=6X@
M)B8@)&QA<W1?<G5N(#P@=&EM92@I("L@)'1H:7,M/F=C7W1I;64I('Q\("AR
M86YD*#$L(#$P,"D@/"`D=&AI<RT^9V-?<')O8F%B:6QI='DI*2!["B`@("`@
M("`@("`@("1T:&ES+3YC;VYT86EN97(M/F=A<F)A9V5#;VQL96-T:6]N*"1T
M:&ES+3YG8U]M87AL:69E=&EM92D["B`@("`@("`@("`@("1L87-T7W)U;B`]
M('1I;64H*3L*("`@("`@("!]"B`@("!]("\O(&5N9"!F=6YC(&=A<F)A9V5#
M;VQL96-T:6]N"@I]("\O(&5N9"!C;&%S<R!C86-H90H_/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]3
M>7-T96TN<&AP````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`T,S`U,@`Q,#0Q-S,V,S`P-P`P,3<S-#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+R\*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-2`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*
M+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M=7)L.B`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R<SH@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!3>7-T96TN<&AP+'8@,2XS-2`R,#`T+S`Q
M+S$Y(#`S.C,R.C$R(&-E;&QO9R!%>'`@)`HO+PH*<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["G)E<75I<F5?;VYC92`G0V]N<V]L92]'971O<'0N<&AP)SL*
M"B1'3$]"04Q36R=?4WES=&5M7W1E;7!?9FEL97,G72`](&%R<F%Y*"D["@HO
M*BH**B!3>7-T96T@;V9F97)S(&-R;W-S('!L871T9F]R;2!C;VUP871I8FQE
M('-Y<W1E;2!F=6YC=&EO;G,**@HJ(%-T871I8R!F=6YC=&EO;G,@9F]R(&1I
M9F9E<F5N="!O<&5R871I;VYS+B!3:&]U;&0@=V]R:R!U;F1E<@HJ(%5N:7@@
M86YD(%=I;F1O=W,N(%1H92!N86UE<R!A;F0@=7-A9V4@:&%S(&)E96X@=&%K
M96X@9G)O;2!I=',@<F5S<&5C=&EV96QY"BH@1TY5(&-O;6UA;F1S+B!4:&4@
M9G5N8W1I;VYS('=I;&P@<F5T=7)N("AB;V]L*2!F86QS92!O;B!E<G)O<B!A
M;F0@=VEL;`HJ('1R:6=G97(@=&AE(&5R<F]R('=I=&@@=&AE(%!(4"!T<FEG
M9V5R7V5R<F]R*"D@9G5N8W1I;VX@*'EO=2!C86X@<VEL96YC90HJ('1H92!E
M<G)O<B!B>2!P<F5F:7AI;F<@82`G0"<@<VEG;B!A9G1E<B!T:&4@9G5N8W1I
M;VX@8V%L;"DN"BH**B!$;V-U;65N=&%T:6]N(&]N('1H:7,@8VQA<W,@>6]U
M(&-A;B!F:6YD(&EN.@HJ(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+PHJ
M"BH@17AA;7!L92!U<V%G93H**B!I9B`H(4!3>7-T96TZ.G)M*"<M<B!F:6QE
M,2!D:7(Q)RDI('L**B`@("!P<FEN="`B8V]U;&0@;F]T(&1E;&5T92!F:6QE
M,2!O<B!D:7(Q(CL**B!]"BH**B!);B!C87-E('EO=2!N965D('1O('1O('!A
M<W,@9FEL92!N86UE<R!W:71H('-P86-E<RP**B!P87-S('1H92!P87)A;7,@
M87,@86X@87)R87DZ"BH**B!3>7-T96TZ.G)M*&%R<F%Y*"<M<B<L("1F:6QE
M,2P@)&1I<C$I*3L**@HJ($!P86-K86=E("!3>7-T96T**B!`875T:&]R("`@
M5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@HJ($!V97)S:6]N("`D
M4F5V:7-I;VXZ(#$N,S4@)`HJ($!A8V-E<W,@("!P=6)L:6,**B!`<V5E("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO"BHO"F-L87-S(%-Y<W1E
M;0I["B`@("`O*BH*("`@("H@<F5T=7)N<R!T:&4@8V]M;6%N9&QI;F4@87)G
M=6UE;G1S(&]F(&$@9G5N8W1I;VX*("`@("H*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@)&%R9W8@("`@("`@("`@('1H92!C;VUM86YD;&EN90H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`D<VAO<G1?;W!T:6]N<R`@=&AE(&%L;&]W960@
M;W!T:6]N('-H;W)T+71A9W,*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QO
M;F=?;W!T:6]N<R`@('1H92!A;&QO=V5D(&]P=&EO;B!L;VYG+71A9W,*("`@
M("H@0')E='5R;B`@(&%R<F%Y("`@=&AE(&=I=F5N(&]P=&EO;G,@86YD('1H
M97)E('9A;'5E<PH@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO"B`@("!F
M=6YC=&EO;B!?<&%R<V5!<F=S*"1A<F=V+"`D<VAO<G1?;W!T:6]N<RP@)&QO
M;F=?;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D87)G=BD@)B8@)&%R9W8@(3T](&YU;&PI('L*("`@("`@("`@("`@)&%R
M9W8@/2!P<F5G7W-P;&ET*"<O7',K+R<L("1A<F=V*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N($-O;G-O;&5?1V5T;W!T.CIG971O<'0R*"1A<F=V+"`D
M<VAO<G1?;W!T:6]N<RD["B`@("!]"@H@("`@+RHJ"B`@("`J($]U='!U="!E
M<G)O<G,@=VET:"!02%`@=')I9V=E<E]E<G)O<B@I+B!9;W4@8V%N('-I;&5N
M8V4@=&AE(&5R<F]R<PH@("`@*B!W:71H('!R969I>&EN9R!A(")`(B!S:6=N
M('1O('1H92!F=6YC=&EO;B!C86QL.B!`4WES=&5M.CIM:V1I<B@N+BD["B`@
M("`J"B`@("`J($!P87)A;2!M:7AE9"`D97)R;W(@82!014%2(&5R<F]R(&]R
M(&$@<W1R:6YG('=I=&@@=&AE(&5R<F]R(&UE<W-A9V4*("`@("H@0')E='5R
M;B!B;V]L(&9A;'-E"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B\*("`@
M(&9U;F-T:6]N(')A:7-E17)R;W(H)&5R<F]R*0H@("`@>PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G)O<BDI('L*("`@("`@("`@("`@)&5R<F]R
M(#T@)&5R<F]R+3YG971-97-S86=E*"D["B`@("`@("`@?0H@("`@("`@('1R
M:6=G97)?97)R;W(H)&5R<F]R+"!%7U5315)?5T%23DE.1RD["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@*B!#<F5A=&5S(&$@
M;F5S=&5D(&%R<F%Y(')E<')E<V5N=&EN9R!T:&4@<W1R=6-T=7)E(&]F(&$@
M9&ER96-T;W)Y"B`@("`J"B`@("`J(%-Y<W1E;3HZ7V1I<E1O4W1R=6-T*"=D
M:7(Q)RP@,"D@/3X*("`@("H@("!!<G)A>0H@("`@*B`@("`H"B`@("`J("`@
M(%MD:7)S72`]/B!!<G)A>0H@("`@*B`@("`@("`@*`H@("`@*B`@("`@("`@
M("`@(%LP72`]/B!D:7(Q"B`@("`J("`@("`@("`I"B`@("`J"B`@("`J("`@
M(%MF:6QE<UT@/3X@07)R87D*("`@("H@("`@("`@("@*("`@("H@("`@("`@
M("`@("!;,%T@/3X@9&ER,2]F:6QE,@H@("`@*B`@("`@("`@("`@(%LQ72`]
M/B!D:7(Q+V9I;&4S"B`@("`J("`@("`@("`I"B`@("`J("`@("D*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@)'-0871H("`@("`@3F%M92!O9B!T:&4@9&ER
M96-T;W)Y"B`@("`J($!P87)A;2`@("!I;G1E9V5R("1M87AI;G-T("`@(&UA
M>"X@9&5E<"!O9B!T:&4@;&]O:W5P"B`@("`J($!P87)A;2`@("!I;G1E9V5R
M("1A:W1I;G-T("`@('-T87)T:6YG(&1E97`@;V8@=&AE(&QO;VMU<`H@("`@
M*B!`<F5T=7)N("`@87)R87D@("!T:&4@<W1R=6-T=7)E(&]F('1H92!D:7(*
M("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("HO"@H@("`@9G5N8W1I;VX@
M7V1I<E1O4W1R=6-T*"1S4&%T:"P@)&UA>&EN<W0L("1A:W1I;G-T(#T@,"D*
M("`@('L*("`@("`@("`D<W1R=6-T(#T@87)R87DH)V1I<G,G(#T^(&%R<F%Y
M*"DL("=F:6QE<R<@/3X@87)R87DH*2D["B`@("`@("`@:68@*"@D9&ER(#T@
M0&]P96YD:7(H)'-0871H*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@(%-Y
M<W1E;3HZ<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&]P96X@9&ER("1S4&%T:"(I
M.PH@("`@("`@("`@("!R971U<FX@)'-T<G5C=#L@+R\@6%A8(&-O=6QD(&YO
M="!O<&5N(&5R<F]R"B`@("`@("`@?0H@("`@("`@("1S=')U8W1;)V1I<G,G
M75M=(#T@)'-0871H.R`O+R!86%@@9&]N)W0@861D(&EF("<N)R!O<B`G+BXG
M(#\*("`@("`@("`D;&ES="`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*"1F
M:6QE(#T@<F5A9&1I<B@D9&ER*2D@>PH@("`@("`@("`@("!I9B`H)&9I;&4@
M(3T@)RXG("8F("1F:6QE("$]("<N+B<I('L*("`@("`@("`@("`@("`@("1L
M:7-T6UT@/2`D9FEL93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!C;&]S961I<B@D9&ER*3L*("`@("`@("!S;W)T*"1L:7-T*3L*("`@("`@
M("!I9B`H)&%K=&EN<W0@/"`D;6%X:6YS="!\?"`D;6%X:6YS="`]/2`P*2![
M"B`@("`@("`@("`@(&9O<F5A8V@H)&QI<W0@87,@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@)'!A=&@@/2`D<U!A=&@@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)'9A;#L*("`@("`@("`@("`@("`@(&EF("AI<U]D:7(H)'!A=&@I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1M<"`](%-Y<W1E;3HZ7V1I<E1O4W1R
M=6-T*"1P871H+"`D;6%X:6YS="P@)&%K=&EN<W0K,2D["B`@("`@("`@("`@
M("`@("`@("`@)'-T<G5C="`](&%R<F%Y7VUE<F=E7W)E8W5R<VEV92@D=&UP
M+"`D<W1R=6-T*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'-T<G5C=%LG9FEL97,G75M=(#T@)'!A=&@["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1S=')U8W0["B`@("!]"@H@("`@+RHJ"B`@("`J($-R96%T97,@
M82!N97-T960@87)R87D@<F5P<F5S96YT:6YG('1H92!S=')U8W1U<F4@;V8@
M82!D:7)E8W1O<GD@86YD(&9I;&5S"B`@("`J"B`@("`J($!P87)A;2`@("!A
M<G)A>2`D9FEL97,@07)R87D@;&ES=&EN9R!F:6QE<R!A;F0@9&ER<PH@("`@
M*B!`<F5T=7)N("`@87)R87D*("`@("H@0'-E92!3>7-T96TZ.E]D:7)4;U-T
M<G5C="@I"B`@("`J+PH@("`@9G5N8W1I;VX@7VUU;'1I<&QE5&]3=')U8W0H
M)&9I;&5S*0H@("`@>PH@("`@("`@("1S=')U8W0@/2!A<G)A>2@G9&ER<R<@
M/3X@87)R87DH*2P@)V9I;&5S)R`]/B!A<G)A>2@I*3L*("`@("`@("!S971T
M>7!E*"1F:6QE<RP@)V%R<F%Y)RD["B`@("`@("`@9F]R96%C:"`H)&9I;&5S
M(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("AI<U]D:7(H)&9I;&4I*2![
M"B`@("`@("`@("`@("`@("`D=&UP(#T@4WES=&5M.CI?9&ER5&]3=')U8W0H
M)&9I;&4L(#`I.PH@("`@("`@("`@("`@("`@)'-T<G5C="`](&%R<F%Y7VUE
M<F=E7W)E8W5R<VEV92@D=&UP+"`D<W1R=6-T*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1S=')U8W1;)V9I;&5S)UU;72`]("1F
M:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<W1R=6-T.PH@("`@?0H*("`@("\J*@H@("`@*B!4:&4@<FT@8V]M;6%N9"!F
M;W(@<F5M;W9I;F<@9FEL97,N"B`@("`J(%-U<'!O<G1S(&UU;'1I<&QE(&9I
M;&5S(&%N9"!D:7)S(&%N9"!A;'-O(')E8W5R<VEV92!D96QE=&5S"B`@("`J
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("1A<F=S("`@=&AE(&%R9W5M96YT
M<R!F;W(@<FT*("`@("H@0')E='5R;B`@(&UI>&5D("`@4$5!4E]%<G)O<B!O
M<B!T<G5E(&9O<B!S=6-C97-S"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("HO"B`@("!F=6YC=&EO;B!R;2@D87)G<RD*("`@('L*("`@("`@("`D;W!T
M<R`](%-Y<W1E;3HZ7W!A<G-E07)G<R@D87)G<RP@)W)F)RD[("\O(")F(B!D
M;R!N;W1H:6YG(&)U="!L:6ME(&ET(#HM*0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1O<'1S*2D@>PH@("`@("`@("`@("!R971U<FX@4WES=&5M.CIR
M86ES945R<F]R*"1O<'1S*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"@D
M;W!T<ULP72!A<R`D;W!T*2!["B`@("`@("`@("`@(&EF("@D;W!T6S!=(#T]
M("=R)RD@>PH@("`@("`@("`@("`@("`@)&1O7W)E8W5R<VEV92`]('1R=64[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)')E="`]('1R=64[
M"B`@("`@("`@:68@*&ES<V5T*"1D;U]R96-U<G-I=F4I*2!["B`@("`@("`@
M("`@("1S=')U8W0@/2!3>7-T96TZ.E]M=6QT:7!L951O4W1R=6-T*"1O<'1S
M6S%=*3L*("`@("`@("`@("`@9F]R96%C:"@D<W1R=6-T6R=F:6QE<R==(&%S
M("1F:6QE*2!["B`@("`@("`@("`@("`@("!I9B`H(4!U;FQI;FLH)&9I;&4I
M*2!["B`@("`@("`@("`@("`@("`@("`@)')E="`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@H
M)'-T<G5C=%LG9&ER<R==(&%S("1D:7(I('L*("`@("`@("`@("`@("`@(&EF
M("@A0')M9&ER*"1D:7(I*2!["B`@("`@("`@("`@("`@("`@("`@)')E="`]
M(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R96%C:"`H)&]P='-;,5T@87,@
M)&9I;&4I('L*("`@("`@("`@("`@("`@("1D96QE=&4@/2`H:7-?9&ER*"1F
M:6QE*2D@/R`G<FUD:7(G(#H@)W5N;&EN:R<["B`@("`@("`@("`@("`@("!I
M9B`H(4`D9&5L971E*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@("`@("1R
M970@/2!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O*BH*
M("`@("H@36%K92!D:7)E8W1O<FEE<RX@3F]T92!T:&%T('=E('5S92!C86QL
M7W5S97)?9G5N8R@G;6MD:7(G*2!T;R!A=F]I9`H@("`@*B!A('!R;V)L96T@
M=VET:"!:13(@8V%L;&EN9R!3>7-T96TZ.FUK1&ER(&EN<W1E860@;V8@=&AE
M(&YA=&EV92!02%`@9G5N8RX*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@)&%R9W,@("`@=&AE(&YA;64@;V8@=&AE(&1I<F5C=&]R*'E\:65S*2!T
M;R!C<F5A=&4*("`@("H@0')E='5R;B`@(&)O;VP@("`@5')U92!F;W(@<W5C
M8V5S<PH@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I
M;VX@;6M$:7(H)&%R9W,I"B`@("!["B`@("`@("`@)&]P=',@/2!3>7-T96TZ
M.E]P87)S94%R9W,H)&%R9W,L("=P;3HG*3L*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D;W!T<RDI('L*("`@("`@("`@("`@<F5T=7)N(%-Y<W1E;3HZ
M<F%I<V5%<G)O<B@D;W!T<RD["B`@("`@("`@?0H@("`@("`@("1M;V1E(#T@
M,#<W-SL@+R\@9&5F875L="!M;V1E"B`@("`@("`@9F]R96%C:"@D;W!T<ULP
M72!A<R`D;W!T*2!["B`@("`@("`@("`@(&EF("@D;W!T6S!=(#T]("=P)RD@
M>PH@("`@("`@("`@("`@("`@)&-R96%T95]P87)E;G1S(#T@=')U93L*("`@
M("`@("`@("`@?2!E;'-E:68H)&]P=%LP72`]/2`G;2<I('L*("`@("`@("`@
M("`@("`@("\O(&EF('1H92!M;V1E(&ES(&-L96%R;'D@86X@;V-T86P@;G5M
M8F5R("AS=&%R=',@=VET:"`P*0H@("`@("`@("`@("`@("`@+R\@8V]N=F5R
M="!I="!T;R!D96-I;6%L"B`@("`@("`@("`@("`@("!I9B`H<W1R;&5N*"1O
M<'1;,5TI("8F("1O<'1;,5U[,'T@/3T@)S`G*2!["B`@("`@("`@("`@("`@
M("`@("`@)&]P=%LQ72`](&]C=&1E8R@D;W!T6S%=*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@8V]N=F5R="!T
M;R!I;G0*("`@("`@("`@("`@("`@("`@("`D;W!T6S%=("L](#`["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;6]D92`]("1O<'1;,5T[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)')E="`]('1R=64[
M"B`@("`@("`@:68@*&ES<V5T*"1C<F5A=&5?<&%R96YT<RDI('L*("`@("`@
M("`@("`@9F]R96%C:"@D;W!T<ULQ72!A<R`D9&ER*2!["B`@("`@("`@("`@
M("`@("`D9&ER<W1A8VL@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@=VAI
M;&4@*"%`:7-?9&ER*"1D:7(I("8F("1D:7(@(3T@1$E214-43U)97U-%4$%2
M051/4BD@>PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&1I
M<G-T86-K+"`D9&ER*3L*("`@("`@("`@("`@("`@("`@("`D9&ER(#T@9&ER
M;F%M92@D9&ER*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('=H:6QE("@D;F5W9&ER(#T@87)R87E?<VAI9G0H)&1I<G-T86-K*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A8V%L;%]U<V5R7V9U;F,H)VUK9&ER
M)RP@)&YE=V1I<BP@)&UO9&4I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R970@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!F;W)E86-H*"1O<'1S6S%=(&%S("1D:7(I('L*("`@("`@("`@
M("`@("`@(&EF("@A0&ES7V1I<B@D9&ER*2`F)B`A8V%L;%]U<V5R7V9U;F,H
M)VUK9&ER)RP@)&1I<BP@)&UO9&4I*2!["B`@("`@("`@("`@("`@("`@("`@
M)')E="`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\J
M*@H@("`@*B!#;VYC871E;F%T92!F:6QE<PH@("`@*@H@("`@*B!5<V%G93H*
M("`@("H@,2D@)'9A<B`](%-Y<W1E;3HZ8V%T*"=S86UP;&4N='AT('1E<W0N
M='AT)RD["B`@("`J(#(I(%-Y<W1E;3HZ8V%T*"=S86UP;&4N='AT('1E<W0N
M='AT(#X@9FEN86PN='AT)RD["B`@("`J(#,I(%-Y<W1E;3HZ8V%T*"=S86UP
M;&4N='AT('1E<W0N='AT(#X^(&9I;F%L+G1X="<I.PH@("`@*@H@("`@*B!.
M;W1E.B!A<R!T:&4@8VQA<W,@=7-E(&9O<&5N+"!U<FQS('-H;W5L9"!W;W)K
M(&%L<V\@*'1E<W0@=&AA="D*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@)&%R9W,@("!T:&4@87)G=6UE;G1S"B`@("`J($!R971U<FX@("!B;V]L
M96%N('1R=64@;VX@<W5C8V5S<PH@("`@*B!`86-C97-S("`@<'5B;&EC"B`@
M("`J+PH@("`@9G5N8W1I;VX@)F-A="@D87)G<RD*("`@('L*("`@("`@("`D
M<F5T(#T@;G5L;#L*("`@("`@("`D9FEL97,@/2!A<G)A>2@I.PH@("`@("`@
M(&EF("@A:7-?87)R87DH)&%R9W,I*2!["B`@("`@("`@("`@("1A<F=S(#T@
M<')E9U]S<&QI="@G+UQS*R\G+"`D87)G<RD["B`@("`@("`@?0H@("`@("`@
M(&9O<B@D:3TP.R`D:2`\(&-O=6YT*"1A<F=S*3L@)&DK*RD@>PH@("`@("`@
M("`@("!I9B`H)&%R9W-;)&E=(#T]("<^)RD@>PH@("`@("`@("`@("`@("`@
M)&UO9&4@/2`G=V(G.PH@("`@("`@("`@("`@("`@)&]U='!U=&9I;&4@/2`D
M87)G<ULD:2LQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!](&5L<V5I9B`H)&%R9W-;)&E=(#T]("<^/B<I('L*("`@("`@("`@("`@
M("`@("1M;V1E(#T@)V%B*R<["B`@("`@("`@("`@("`@("`D;W5T<'5T9FEL
M92`]("1A<F=S6R1I*S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9FEL97-;72`]("1A
M<F=S6R1I73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M:7-S970H)&UO9&4I*2!["B`@("`@("`@("`@(&EF("@A)&]U='!U=&9D(#T@
M9F]P96XH)&]U='!U=&9I;&4L("1M;V1E*2D@>PH@("`@("`@("`@("`@("`@
M)&5R<B`](%-Y<W1E;3HZ<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&]P96X@)&]U
M='!U=&9I;&4B*3L*("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1R970@/2!T<G5E.PH@("`@("`@('T*
M("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@("`@("`@
M("`@:68@*"$D9F0@/2!F;W!E;B@D9FEL92P@)W(G*2D@>PH@("`@("`@("`@
M("`@("`@4WES=&5M.CIR86ES945R<F]R*")#;W5L9"!N;W0@;W!E;B`D9FEL
M92(I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@=VAI;&4@*"1C;VYT(#T@9G)E860H)&9D+"`R,#0X*2D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O=71P=71F9"DI('L*("`@
M("`@("`@("`@("`@("`@("!F=W)I=&4H)&]U='!U=&9D+"`D8V]N="D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R
M970@+CT@)&-O;G0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@9F-L;W-E*"1F9"D["B`@("`@("`@?0H@("`@("`@(&EF
M("A`:7-?<F5S;W5R8V4H)&]U='!U=&9D*2D@>PH@("`@("`@("`@("!F8VQO
M<V4H)&]U='!U=&9D*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R970[
M"B`@("!]"@H@("`@+RHJ"B`@("`J($-R96%T97,@=&5M<&]R87)Y(&9I;&5S
M(&]R(&1I<F5C=&]R:65S+B!4:&ES(&9U;F-T:6]N('=I;&P@<F5M;W9E"B`@
M("`J('1H92!C<F5A=&5D(&9I;&5S('=H96X@=&AE('-C<FEP=',@9FEN:7-H
M(&ET<R!E>&5C=71I;VXN"B`@("`J"B`@("`J(%5S86=E.@H@("`@*B`@(#$I
M("1T96UP9FEL92`](%-Y<W1E;3HZ;6MT96UP*")P<F5F:7@B*3L*("`@("H@
M("`R*2`D=&5M<&1I<B`@/2!3>7-T96TZ.FUK=&5M<"@B+60@<')E9FEX(BD[
M"B`@("`J("`@,RD@)'1E;7!F:6QE(#T@4WES=&5M.CIM:W1E;7`H*3L*("`@
M("H@("`T*2`D=&5M<&9I;&4@/2!3>7-T96TZ.FUK=&5M<"@B+70@+W9A<B]T
M;7`@<')E9FEX(BD["B`@("`J"B`@("`J('!R969I>"`M/B!4:&4@<W1R:6YG
M('1H870@=VEL;"!B92!P<F5P96YD960@=&\@=&AE('1E;7`@;F%M90H@("`@
M*B`@("`@("`@("`@*&1E9F%U;'1S('1O(")T;7`B*2X*("`@("H@+60@("`@
M("T^($$@=&5M<&]R87)Y(&1I<B!W:6QL(&)E(&-R96%T960@:6YS=&5A9"!O
M9B!A(&9I;&4N"B`@("`J("UT("`@("`M/B!4:&4@=&%R9V5T(&1I<B!W:&5R
M92!T:&4@=&5M<&]R87)Y("AF:6QE?&1I<BD@=VEL;"!B92!C<F5A=&5D+B!)
M9@H@("`@*B`@("`@("`@("`@=&AI<R!P87)A;2!I<R!M:7-S:6YG(&)Y(&1E
M9F%U;'0@=&AE(&5N=B!V87)S(%1-4"!O;B!7:6YD;W=S(&]R"B`@("`J("`@
M("`@("`@("!435!$25(@:6X@56YI>"!W:6QL(&)E('5S960N($EF('1H97-E
M('9A<G,@87)E(&%L<V\@;6ES<VEN9PH@("`@*B`@("`@("`@("`@8SI<=VEN
M9&]W<UQT96UP(&]R("]T;7`@=VEL;"!B92!U<V5D+@H@("`@*@H@("`@*B!`
M<&%R86T@("!S=')I;F<@("1A<F=S("!4:&4@87)G=6UE;G1S"B`@("`J($!R
M971U<FX@(&UI>&5D("`@=&AE(&9U;&P@<&%T:"!O9B!T:&4@8W)E871E9"`H
M9FEL97QD:7(I(&]R(&9A;'-E"B`@("`J($!S964@4WES=&5M.CIT;7!D:7(H
M*0H@("`@*B!`86-C97-S("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!M
M:W1E;7`H)&%R9W,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D9FER
M<W1?=&EM92`]('1R=64["B`@("`@("`@)&]P=',@/2!3>7-T96TZ.E]P87)S
M94%R9W,H)&%R9W,L("=T.F0G*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D;W!T<RDI('L*("`@("`@("`@("`@<F5T=7)N(%-Y<W1E;3HZ<F%I<V5%
M<G)O<B@D;W!T<RD["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@H)&]P='-;
M,%T@87,@)&]P="D@>PH@("`@("`@("`@("!I9B@D;W!T6S!=(#T]("=D)RD@
M>PH@("`@("`@("`@("`@("`@)'1M<%]I<U]D:7(@/2!T<G5E.PH@("`@("`@
M("`@("!](&5L<V5I9B@D;W!T6S!=(#T]("=T)RD@>PH@("`@("`@("`@("`@
M("`@)'1M<&1I<B`]("1O<'1;,5T["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@)'!R969I>"`]("AI<W-E="@D;W!T<ULQ75LP72DI(#\@)&]P
M='-;,5U;,%T@.B`G=&UP)SL*("`@("`@("!I9B`H(6ES<V5T*"1T;7!D:7(I
M*2!["B`@("`@("`@("`@("1T;7!D:7(@/2!3>7-T96TZ.G1M<&1I<B@I.PH@
M("`@("`@('T*("`@("`@("!I9B`H(5-Y<W1E;3HZ;6M$:7(H(BUP("1T;7!D
M:7(B*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@("`@("1T;7`@/2!T96UP;F%M*"1T;7!D:7(L("1P<F5F:7@I.PH@("`@
M("`@(&EF("AI<W-E="@D=&UP7VES7V1I<BDI('L*("`@("`@("`@("`@=6YL
M:6YK*"1T;7`I.R`O+R!B92!C87)E9G5L('!O<W-I8FQE(')A8V4@8V]N9&ET
M:6]N(&AE<F4*("`@("`@("`@("`@:68@*"%C86QL7W5S97)?9G5N8R@G;6MD
M:7(G+"`D=&UP+"`P-S`P*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%-Y
M<W1E;3HZ<F%I<V5%<G)O<B@B56YA8FQE('1O(&-R96%T92!T96UP;W)A<GD@
M9&ER96-T;W)Y("1T;7!D:7(B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("`D1TQ/0D%,4ULG7U-Y<W1E;5]T96UP7V9I;&5S)UU;72`]("1T
M;7`["B`@("`@("`@:68@*"1F:7)S=%]T:6UE*2!["B`@("`@("`@("`@(%!%
M05(Z.G)E9VES=&5R4VAU=&1O=VY&=6YC*&%R<F%Y*"=3>7-T96TG+"`G7W)E
M;6]V951M<$9I;&5S)RDI.PH@("`@("`@("`@("`D9FER<W1?=&EM92`](&9A
M;'-E.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@
M("`O*BH*("`@("H@4F5M;W9E('1E;7!O<F%R>2!F:6QE<R!C<F5A=&5D(&UY
M(&UK5&5M<"X@5&AI<R!F=6YC=&EO;B!I<R!E>&5C=71E9`H@("`@*B!A="!S
M8W)I<'0@<VAU=&1O=VX@=&EM90H@("`@*@H@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("HO"B`@("!F=6YC=&EO;B!?<F5M;W9E5&UP1FEL97,H*0H@("`@
M>PH@("`@("`@(&EF("AC;W5N="@D1TQ/0D%,4ULG7U-Y<W1E;5]T96UP7V9I
M;&5S)UTI*2!["B`@("`@("`@("`@("1D96QE=&4@/2`D1TQ/0D%,4ULG7U-Y
M<W1E;5]T96UP7V9I;&5S)UT["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H
M)&1E;&5T92P@)RUR)RD["B`@("`@("`@("`@(%-Y<W1E;3HZ<FTH)&1E;&5T
M92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!'970@=&AE('!A
M=&@@;V8@=&AE('1E;7!O<F%L(&1I<F5C=&]R>2!S970@:6X@=&AE('-Y<W1E
M;0H@("`@*B!B>2!L;V]K:6YG(&EN(&ET<R!E;G9I<F]N;65N=',@=F%R:6%B
M;&5S+@H@("`@*B!.;W1E.B!P:'`N:6YI+7)E8V]M;65N9&5D(')E;6]V97,@
M=&AE(")%(B!F<F]M('1H92!V87)I86)L97-?;W)D97(@<V5T=&EN9RP*("`@
M("H@;6%K:6YG('5N879A:6)L92!T:&4@)%]%3E8@87)R87DL('1H870@<R!W
M:'D@=V4@9&\@=&5S=',@=VET:"!?14Y6"B`@("`J"B`@("`J($!R971U<FX@
M<W1R:6YG(%1H92!T96UP;W)A;"!D:7)E8W1O<GD@;VX@=&AE('-Y<W1E;0H@
M("`@*B\*("`@(&9U;F-T:6]N('1M<&1I<B@I"B`@("!["B`@("`@("`@:68@
M*$]37U=)3D1/5U,I('L*("`@("`@("`@("`@:68@*"1V87(@/2!I<W-E="@D
M7T5.5ELG5$5-4"==*2`_("1?14Y66R=414U0)UT@.B!G971E;G8H)U1%35`G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1V87(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1V87(@/2!I<W-E="@D7T5.5ELG5$U0)UTI
M(#\@)%]%3E9;)U1-4"==(#H@9V5T96YV*"=435`G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1V87(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1V87(@/2!I<W-E="@D7T5.5ELG=VEN9&ER)UTI(#\@)%]%3E9;)W=I
M;F1I<B==(#H@9V5T96YV*"=W:6YD:7(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1V87(["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M(&=E=&5N=B@G4WES=&5M4F]O="<I("X@)UQT96UP)SL*("`@("`@("!]"B`@
M("`@("`@:68@*"1V87(@/2!I<W-E="@D7T5.5ELG5$U01$E2)UTI(#\@)%]%
M3E9;)U1-4$1)4B==(#H@9V5T96YV*"=435!$25(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'9A<CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("<O=&UP
M)SL*("`@('T*"B`@("`O*BH*("`@("H@5&AE(")W:&EC:"(@8V]M;6%N9"`H
M<VAO=R!T:&4@9G5L;"!P871H(&]F(&$@8V]M;6%N9"D*("`@("H*("`@("H@
M0'!A<F%M('-T<FEN9R`D<')O9W)A;2!4:&4@8V]M;6%N9"!T;R!S96%R8V@@
M9F]R"B`@("`J($!R971U<FX@;6EX960@02!S=')I;F<@=VET:"!T:&4@9G5L
M;"!P871H(&]R(&9A;'-E(&EF(&YO="!F;W5N9`H@("`@*B!`875T:&]R(%-T
M:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("`@("HO"B`@("!F=6YC=&EO;B!W
M:&EC:"@D<')O9W)A;2P@)&9A;&QB86-K(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@+R\@:7-?97AE8W5T86)L92@I(&ES(&YO="!A=F%I;&%B;&4@;VX@=VEN
M9&]W<PH@("`@("`@(&EF("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1P
M96%R7VES7V5X96-U=&%B;&4@/2`G:7-?9FEL92<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'!E87)?:7-?97AE8W5T86)L92`]("=I<U]E>&5C
M=71A8FQE)SL*("`@("`@("!]"@H@("`@("`@("\O(&9U;&P@<&%T:"!G:79E
M;@H@("`@("`@(&EF("AB87-E;F%M92@D<')O9W)A;2D@(3T@)'!R;V=R86TI
M('L*("`@("`@("`@("`@<F5T=7)N("A`)'!E87)?:7-?97AE8W5T86)L92@D
M<')O9W)A;2DI(#\@)'!R;V=R86T@.B`D9F%L;&)A8VL["B`@("`@("`@?0H*
M("`@("`@("`O+R!86%@@1DE8344@:&]N;W(@<V%F92!M;V1E"B`@("`@("`@
M)'!A=&A?9&5L:6T@/2!/4U]724Y$3U=3(#\@)SLG(#H@)SHG.PH@("`@("`@
M("1E>&5?<W5F9FEX97,@/2!/4U]724Y$3U=3(#\@87)R87DH)RYE>&4G+"<N
M8F%T)RPG+F-M9"<L)RYC;VTG*2`Z(&%R<F%Y*"<G*3L*("`@("`@("`D<&%T
M:%]E;&5M96YT<R`](&5X<&QO9&4H)'!A=&A?9&5L:6TL(&=E=&5N=B@G4$%4
M2"<I*3L*("`@("`@("!F;W)E86-H("@D97AE7W-U9F9I>&5S(&%S("1S=69F
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1P871H7V5L96UE;G1S(&%S("1D
M:7(I('L*("`@("`@("`@("`@("`@("1F:6QE(#T@)&1I<B`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`D<')O9W)A;2`N("1S=69F.PH@("`@("`@("`@("`@
M("`@:68@*$!I<U]F:6QE*"1F:6QE*2`F)B!`)'!E87)?:7-?97AE8W5T86)L
M92@D9FEL92DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&9I;&4[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1F86QL8F%C:SL*("`@('T*"B`@("`O*BH*("`@("H@
M5&AE(")F:6YD(B!C;VUM86YD"B`@("`J"B`@("`J(%5S86=E.@H@("`@*@H@
M("`@*B!3>7-T96TZ.F9I;F0H)&1I<BD["B`@("`J(%-Y<W1E;3HZ9FEN9"@B
M)&1I<B`M='EP92!D(BD["B`@("`J(%-Y<W1E;3HZ9FEN9"@B)&1I<B`M='EP
M92!F(BD["B`@("`J(%-Y<W1E;3HZ9FEN9"@B)&1I<B`M;F%M92`J+G!H<"(I
M.PH@("`@*B!3>7-T96TZ.F9I;F0H(B1D:7(@+6YA;64@*BYP:'`@+6YA;64@
M*BYH=&TJ(BD["B`@("`J(%-Y<W1E;3HZ9FEN9"@B)&1I<B`M;6%X9&5P=&@@
M,2(I.PH@("`@*@H@("`@*B!087)A;7,@:6UP;&UE;G1E9#H*("`@("H@)&1I
M<B`@("`@("`@("`@("T^(%-T87)T('1H92!S96%R8V@@870@=&AI<R!D:7)E
M8W1O<GD*("`@("H@+71Y<&4@9"`@("`@("`@("T^(')E='5R;B!O;FQY(&1I
M<F5C=&]R:65S"B`@("`J("UT>7!E(&8@("`@("`@("`M/B!R971U<FX@;VYL
M>2!F:6QE<PH@("`@*B`M;6%X9&5P=&@@/&X^("`@+3X@;6%X(&1E<'1H(&]F
M(')E8W5R<VEO;@H@("`@*B`M;F%M92`\<&%T=&5R;CX@+3X@<V5A<F-H('!A
M='1E<FX@*&)A<V@@<W1Y;&4I+B!-=6QT:7!L92`M;F%M92!P87)A;2!A;&QO
M=V5D"B`@("`J"B`@("`J($!P87)A;2`@;6EX960@16ET:&5R(&%R<F%Y(&]R
M('-T<FEN9R!W:71H('1H92!C;VUM86YD(&QI;F4*("`@("H@0')E='5R;B!A
M<G)A>2!!<G)A>2!O9B!F;W5N9"!F:6QE<PH@("`@*@H@("`@*B\*("`@(&9U
M;F-T:6]N(&9I;F0H)&%R9W,I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D87)G<RDI('L*("`@("`@("`@("`@)&%R9W,@/2!P<F5G7W-P;&ET*"<O
M7',K+R<L("1A<F=S+"`M,2P@4%)%1U]34$Q)5%].3U]%35!462D["B`@("`@
M("`@?0H@("`@("`@("1D:7(@/2!A<G)A>5]S:&EF="@D87)G<RD["B`@("`@
M("`@)'!A='1E<FYS(#T@87)R87DH*3L*("`@("`@("`D9&5P=&@@/2`P.PH@
M("`@("`@("1D;U]F:6QE<R`]("1D;U]D:7)S(#T@=')U93L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D87)G<RD[("1I*RLI('L*("`@("`@
M("`@("`@<W=I=&-H("@D87)G<ULD:5TI('L*("`@("`@("`@("`@("`@(&-A
M<V4@)RUT>7!E)SH*("`@("`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH
M)&%R9W-;)&DK,5TL(&%R<F%Y*"=D)RP@)V8G*2DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1A<F=S6R1I*S%=(#T]("=D)RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D;U]F:6QE<R`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1O7V1I<G,@/2!F86QS93L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`G+6YA;64G.@H@("`@("`@("`@("`@("`@("`@
M("1P871T97)N<UM=(#T@(B@B("X@<')E9U]R97!L86-E*&%R<F%Y*"<O7"XO
M)RP@)R]<*B\G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G7"XG+"`G+BHG*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D87)G<ULD:2LQ72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("(I(CL*("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G
M+6UA>&1E<'1H)SH*("`@("`@("`@("`@("`@("`@("`D9&5P=&@@/2`D87)G
M<ULD:2LQ73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("`D<&%T:"`](%-Y<W1E;3HZ7V1I<E1O
M4W1R=6-T*"1D:7(L("1D97!T:"D["B`@("`@("`@:68@*"1D;U]F:6QE<R`F
M)B`D9&]?9&ER<RD@>PH@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G
M92@D<&%T:%LG9FEL97,G72P@)'!A=&A;)V1I<G,G72D["B`@("`@("`@?2!E
M;'-E:68@*"1D;U]D:7)S*2!["B`@("`@("`@("`@("1F:6QE<R`]("1P871H
M6R=D:7)S)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9I;&5S
M(#T@)'!A=&A;)V9I;&5S)UT["B`@("`@("`@?0H@("`@("`@(&EF("AC;W5N
M="@D<&%T=&5R;G,I*2!["B`@("`@("`@("`@("1P871T97)N<R`](&EM<&QO
M9&4H)WPG+"`D<&%T=&5R;G,I.PH@("`@("`@("`@("`D<F5T(#T@87)R87DH
M*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&9I;&5S
M*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(B->
M)'!A='1E<FYS7"0C(BP@)&9I;&5S6R1I72DI('L*("`@("`@("`@("`@("`@
M("`@("`D<F5T6UT@/2`D9FEL97-;)&E=.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@?0I]"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W!E
M87)C;60N<&AP````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#(R,S(W`#$P-#$W,S8S,#`W`#`Q-S0W,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO+PHO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`U("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!U
M<FPZ("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W)S.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@5&]M87,@5BY6
M+D-O>"`\8V]X0&ED96-N970N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@<&5A<F-M9"YP
M:'`L=B`Q+CD@,C`P-"\P,2\R-B`P,3HU.3HQ-"!P86IO>64@17AP("0*"F]B
M7V5N9%]C;&5A;B@I.PHO*BH*("H@0&YO9&5P($=T:PH@*B\*:68@*"<O=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B<@(3T@)T`G+B=I;F-L=61E7W!A
M=&@G+B=`)RD@>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@)R]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R)RD["GT*:6YI7W-E="@G86QL;W=?
M=7)L7V9O<&5N)RP@=')U92D["G-E=%]T:6UE7VQI;6ET*#`I.PIO8E]I;7!L
M:6-I=%]F;'5S:"AT<G5E*3L*:6YI7W-E="@G=')A8VM?97)R;W)S)RP@=')U
M92D["FEN:5]S970H)VAT;6Q?97)R;W)S)RP@9F%L<V4I.PII;FE?<V5T*"=M
M86=I8U]Q=6]T97-?<G5N=&EM92<L(&9A;'-E*3L*<V5T7V5R<F]R7VAA;F1L
M97(H)V5R<F]R7VAA;F1L97(G*3L*"B1P96%R7W!A8VMA9V5?=F5R<VEO;B`]
M("(Q+C,B.PH*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["G)E<75I<F5?;VYC
M92`G4$5!4B]#;VYF:6<N<&AP)SL*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA
M;F0N<&AP)SL*<F5Q=6ER95]O;F-E("=#;VYS;VQE+T=E=&]P="YP:'`G.PH*
M4$5!4E]#;VUM86YD.CIS971&<F]N=&5N9%1Y<&4H)T-,22<I.PHD86QL7V-O
M;6UA;F1S(#T@4$5!4E]#;VUM86YD.CIG971#;VUM86YD<R@I.PH*)&%R9W8@
M/2!#;VYS;VQE7T=E=&]P=#HZ<F5A9%!(4$%R9W8H*3L*+RH@)'!R;V=N86UE
M(#T@8F%S96YA;64H)&%R9W9;,%TI.R`J+PHD<')O9VYA;64@/2`G<&5A<B<[
M"F%R<F%Y7W-H:69T*"1A<F=V*3L*)&]P=&EO;G,@/2!#;VYS;VQE7T=E=&]P
M=#HZ9V5T;W!T,B@D87)G=BP@(F,Z0SID.D0Z1V@_<U-Q=3IV5B(I.PII9B`H
M4$5!4CHZ:7-%<G)O<B@D;W!T:6]N<RDI('L*("`@('5S86=E*"1O<'1I;VYS
M*3L*?0H*)&]P=',@/2`D;W!T:6]N<ULP73L*"B1F971Y<&4@/2`G0TQ))SL*
M:68@*"1P<F]G;F%M92`]/2`G9W!E87(G('Q\("1P<F]G;F%M92`]/2`G<&5A
M<BUG=&LG*2!["B`@("`D9F5T>7!E(#T@)T=T:R<["GT@96QS92!["B`@("!F
M;W)E86-H("@D;W!T<R!A<R`D;W!T*2!["B`@("`@("`@:68@*"1O<'1;,%T@
M/3T@)T<G*2!["B`@("`@("`@("`@("1F971Y<&4@/2`G1W1K)SL*("`@("`@
M("!]"B`@("!]"GT*4$5!4E]#;VUM86YD.CIS971&<F]N=&5N9%1Y<&4H)&9E
M='EP92D["B1U:2`]("9014%27T-O;6UA;F0Z.F=E=$9R;VYT96YD3V)J96-T
M*"D["E!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#
M2RP@87)R87DH)'5I+"`B9&ES<&QA>49A=&%L17)R;W(B*2D["@HD<&5A<E]U
M<V5R7V-O;F9I9R`]("<G.PHD<&5A<E]S>7-T96U?8V]N9FEG(#T@)R<["B1S
M=&]R95]U<V5R7V-O;F9I9R`](&9A;'-E.PHD<W1O<F5?<WES=&5M7V-O;F9I
M9R`](&9A;'-E.PHD=F5R8F]S92`](#$["@IF;W)E86-H("@D;W!T<R!A<R`D
M;W!T*2!["B`@("!S=VET8V@@*"1O<'1;,%TI('L*("`@("`@("!C87-E("=C
M)SH*("`@("`@("`@("`@)'!E87)?=7-E<E]C;VYF:6<@/2`D;W!T6S%=.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=#)SH*("`@("`@("`@
M("`@)'!E87)?<WES=&5M7V-O;F9I9R`]("1O<'1;,5T["B`@("`@("`@("`@
M(&)R96%K.PH@("`@?0I]"@HD8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG
M;&5T;VXH)'!E87)?=7-E<E]C;VYF:6<L("1P96%R7W-Y<W1E;5]C;VYF:6<I
M.PHD=F5R8F]S92`]("1C;VYF:6<M/F=E="@B=F5R8F]S92(I.PHD8VUD;W!T
M<R`](&%R<F%Y*"D["@IF;W)E86-H("@D;W!T<R!A<R`D;W!T*2!["B`@("`D
M<&%R86T@/2`A96UP='DH)&]P=%LQ72D@/R`D;W!T6S%=(#H@=')U93L*("`@
M('-W:71C:"`H)&]P=%LP72D@>PH@("`@("`@(&-A<V4@)V0G.@H@("`@("`@
M("`@("!L:7-T*"1K97DL("1V86QU92D@/2!E>'!L;V1E*"<])RP@)'!A<F%M
M*3L*("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"1K97DL("1V86QU92P@)W5S
M97(G*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G1"<Z"B`@
M("`@("`@("`@(&QI<W0H)&ME>2P@)'9A;'5E*2`](&5X<&QO9&4H)STG+"`D
M<&%R86TI.PH@("`@("`@("`@("`D8V]N9FEG+3YS970H)&ME>2P@)'9A;'5E
M+"`G<WES=&5M)RD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@
M)W,G.@H@("`@("`@("`@("`D<W1O<F5?=7-E<E]C;VYF:6<@/2!T<G5E.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=3)SH*("`@("`@("`@
M("`@)'-T;W)E7W-Y<W1E;5]C;VYF:6<@/2!T<G5E.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!C87-E("=U)SH*("`@("`@("`@("`@)&-O;F9I9RT^
M<F5M;W9E*"1P87)A;2P@)W5S97(G*3L*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@8V%S92`G=B<Z"B`@("`@("`@("`@("1C;VYF:6<M/G-E="@G=F5R
M8F]S92<L("1C;VYF:6<M/F=E="@G=F5R8F]S92<I("L@,2D["B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@(&-A<V4@)W$G.@H@("`@("`@("`@("`D8V]N
M9FEG+3YS970H)W9E<F)O<V4G+"`D8V]N9FEG+3YG970H)W9E<F)O<V4G*2`M
M(#$I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=6)SH*("`@
M("`@("`@("`@=7-A9V4H;G5L;"P@)W9E<G-I;VXG*3L*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`O+R!A;&P@;F]N('!E87(@<&%R86US(&=O97,@
M=&\@=&AE(&-O;6UA;F0*("`@("`@("`@("`@)&-M9&]P='-;)&]P=%LP75T@
M/2`D<&%R86T["B`@("`@("`@("`@(&)R96%K.PH@("`@?0I]"@II9B`H)'-T
M;W)E7W-Y<W1E;5]C;VYF:6<I('L*("`@("1C;VYF:6<M/G-T;W)E*"=S>7-T
M96TG*3L*?0H*:68@*"1S=&]R95]U<V5R7V-O;F9I9RD@>PH@("`@)&-O;F9I
M9RT^<W1O<F4H)W5S97(G*3L*?0H*)&-O;6UA;F0@/2`H:7-S970H)&]P=&EO
M;G-;,5U;,%TI*2`_("1O<'1I;VYS6S%=6S!=(#H@;G5L;#L*"FEF("AE;7!T
M>2@D8V]M;6%N9"D@)B8@*"1S=&]R95]U<V5R7V-O;F9I9R!\?"`D<W1O<F5?
M<WES=&5M7V-O;F9I9RDI('L*("`@(&5X:70["GT*"FEF("@D9F5T>7!E(#T]
M("='=&LG*2!["B`@("!'=&LZ.FUA:6XH*3L*?2!E;'-E(&1O('L*("`@(&EF
M("@D8V]M;6%N9"`]/2`G:&5L<"<I('L*("`@("`@("!U<V%G92AN=6QL+"!`
M)&]P=&EO;G-;,5U;,5TI.PH@("`@?0H*("`@(%!%05(Z.G!U<VA%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("1C;60@/2!014%27T-O
M;6UA;F0Z.F9A8W1O<GDH)&-O;6UA;F0L("1C;VYF:6<I.PH@("`@4$5!4CHZ
M<&]P17)R;W)(86YD;&EN9R@I.PH@("`@:68@*%!%05(Z.FES17)R;W(H)&-M
M9"DI('L*("`@("`@("!U<V%G92AN=6QL+"!`)&]P=&EO;G-;,5U;,5TI.PH@
M("`@?0H*("`@("1S:&]R=%]A<F=S(#T@)&QO;F=?87)G<R`](&YU;&P["B`@
M("!014%27T-O;6UA;F0Z.F=E=$=E=&]P=$%R9W,H)&-O;6UA;F0L("1S:&]R
M=%]A<F=S+"`D;&]N9U]A<F=S*3L*("`@(&%R<F%Y7W-H:69T*"1O<'1I;VYS
M6S%=*3L*("`@(&EF("A014%2.CII<T5R<F]R*"1T;7`@/2!#;VYS;VQE7T=E
M=&]P=#HZ9V5T;W!T,B@D;W!T:6]N<ULQ72P@)'-H;W)T7V%R9W,L("1L;VYG
M7V%R9W,I*2D@>PH@("`@("`@(&)R96%K.PH@("`@?0H@("`@;&ES="@D=&UP
M;W!T+"`D<&%R86US*2`]("1T;7`["B`@("`D;W!T<R`](&%R<F%Y*"D["B`@
M("!F;W)E86-H("@D=&UP;W!T(&%S("1F;V\@/3X@)'1M<#(I('L*("`@("`@
M("!L:7-T*"1O<'0L("1V86QU92D@/2`D=&UP,CL*("`@("`@("!I9B`H)'9A
M;'5E(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1V86QU92`]('1R=64[("\O
M(&]P=&EO;G,@=VET:&]U="!A<F=S"B`@("`@("`@?0H@("`@("`@(&EF("AS
M=')L96XH)&]P="D@/3T@,2D@>PH@("`@("`@("`@("`D8VUD;W!T:6]N<R`]
M("1C;60M/F=E=$]P=&EO;G,H)&-O;6UA;F0I.PH@("`@("`@("`@("!F;W)E
M86-H("@D8VUD;W!T:6]N<R!A<R`D;R`]/B`D9"D@>PH@("`@("`@("`@("`@
M("`@:68@*$`D9%LG<VAO<G1O<'0G72`]/2`D;W!T*2!["B`@("`@("`@("`@
M("`@("`@("`@)&]P='-;)&]=(#T@)'9A;'5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*'-U8G-T<B@D;W!T+"`P+"`R*2`]/2`G+2TG*2!["B`@("`@("`@("`@
M("`@("`D;W!T<UMS=6)S='(H)&]P="P@,BE=(#T@)'9A;'5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@)&]K(#T@)&-M9"T^<G5N*"1C
M;VUM86YD+"`D;W!T<RP@)'!A<F%M<RD["B`@("!I9B`H)&]K(#T]/2!F86QS
M92D@>PH@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H(G5N:VYO=VX@8V]M;6%N
M9"!@)&-O;6UA;F0G(BD["B`@("!]"GT@=VAI;&4@*&9A;'-E*3L*"B\O('M[
M>R!U<V%G92@I"@IF=6YC=&EO;B!U<V%G92@D97)R;W(@/2!N=6QL+"`D:&5L
M<'-U8FIE8W0@/2!N=6QL*0I["B`@("!G;&]B86P@)'!R;V=N86UE+"`D86QL
M7V-O;6UA;F1S.PH@("`@)'-T9&5R<B`](&9O<&5N*"=P:'`Z+R]S=&1E<G(G
M+"`G=R<I.PH@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R*2D@>PH@("`@
M("`@(&9P=71S*"1S=&1E<G(L("1E<G)O<BT^9V5T365S<V%G92@I("X@(EQN
M(BD["B`@("!](&5L<V5I9B`H)&5R<F]R("$]/2!N=6QL*2!["B`@("`@("`@
M9G!U=',H)'-T9&5R<BP@(B1E<G)O<EQN(BD["B`@("!]"B`@("!I9B`H)&AE
M;'!S=6)J96-T("$](&YU;&PI('L*("`@("`@("`D<'5T(#T@8VUD2&5L<"@D
M:&5L<'-U8FIE8W0I.PH@("`@?2!E;'-E('L*("`@("`@("`D<'5T(#T*("`@
M("`@("`@("`@(E5S86=E.B`D<')O9VYA;64@6V]P=&EO;G-=(&-O;6UA;F0@
M6V-O;6UA;F0M;W!T:6]N<UT@/'!A<F%M971E<G,^7&XB+@H@("`@("`@("`@
M("`B5'EP92!<(B1P<F]G;F%M92!H96QP(&]P=&EO;G-<(B!T;R!L:7-T(&%L
M;"!O<'1I;VYS+EQN(BX*("`@("`@("`@("`@(E1Y<&4@7"(D<')O9VYA;64@
M:&5L<"`\8V]M;6%N9#Y<(B!T;R!G970@=&AE(&AE;'`@9F]R('1H92!S<&5C
M:69I960@8V]M;6%N9"Y<;B(N"B`@("`@("`@("`@(")#;VUM86YD<SI<;B([
M"B`@("`@("`@)&UA>&QE;B`](&UA>"AA<G)A>5]M87`H(G-T<FQE;B(L("1A
M;&Q?8V]M;6%N9',I*3L*("`@("`@("`D9F]R;6%T<W1R(#T@(B4M>R1M87AL
M96Y]<R`@)7-<;B(["B`@("`@("`@:W-O<G0H)&%L;%]C;VUM86YD<RD["B`@
M("`@("`@9F]R96%C:"`H)&%L;%]C;VUM86YD<R!A<R`D8VUD(#T^("1C;&%S
M<RD@>PH@("`@("`@("`@("`D<'5T("X]('-P<FEN=&8H)&9O<FUA='-T<BP@
M)&-M9"P@4$5!4E]#;VUM86YD.CIG971$97-C<FEP=&EO;B@D8VUD*2D["B`@
M("`@("`@?0H@("`@?0H@("`@9G!U=',H)'-T9&5R<BP@(B1P=71<;B(I.PH@
M("`@9F-L;W-E*"1S=&1E<G(I.PH@("`@97AI=#L*?0H*9G5N8W1I;VX@8VUD
M2&5L<"@D8V]M;6%N9"D*>PH@("`@9VQO8F%L("1P<F]G;F%M92P@)&%L;%]C
M;VUM86YD<RP@)&-O;F9I9SL*("`@(&EF("@D8V]M;6%N9"`]/2`B;W!T:6]N
M<R(I('L*("`@("`@("!R971U<FX*("`@("`@("`B3W!T:6]N<SI<;B(N"B`@
M("`@("`@(B`@("`@+78@("`@("`@("!I;F-R96%S92!V97)B;W-I='D@;&5V
M96P@*&1E9F%U;'0@,2E<;B(N"B`@("`@("`@(B`@("`@+7$@("`@("`@("!B
M92!Q=6EE="P@9&5C<F5A<V4@=F5R8F]S:71Y(&QE=F5L7&XB+@H@("`@("`@
M("(@("`@("UC(&9I;&4@("`@9FEN9"!U<V5R(&-O;F9I9W5R871I;VX@:6X@
M8&9I;&4G7&XB+@H@("`@("`@("(@("`@("U#(&9I;&4@("`@9FEN9"!S>7-T
M96T@8V]N9FEG=7)A=&EO;B!I;B!@9FEL92=<;B(N"B`@("`@("`@(B`@("`@
M+60@9F]O/6)A<B!S970@=7-E<B!C;VYF:6<@=F%R:6%B;&4@8&9O;R<@=&\@
M8&)A<B=<;B(N"B`@("`@("`@(B`@("`@+40@9F]O/6)A<B!S970@<WES=&5M
M(&-O;F9I9R!V87)I86)L92!@9F]O)R!T;R!@8F%R)UQN(BX*("`@("`@("`B
M("`@("`M1R`@("`@("`@('-T87)T(&EN(&=R87!H:6-A;"`H1W1K*2!M;V1E
M7&XB+@H@("`@("`@("(@("`@("US("`@("`@("`@<W1O<F4@=7-E<B!C;VYF
M:6=U<F%T:6]N7&XB+@H@("`@("`@("(@("`@("U3("`@("`@("`@<W1O<F4@
M<WES=&5M(&-O;F9I9W5R871I;VY<;B(N"B`@("`@("`@(B`@("`@+74@9F]O
M("`@("!U;G-E="!@9F]O)R!I;B!T:&4@=7-E<B!C;VYF:6=U<F%T:6]N7&XB
M+@H@("`@("`@("(@("`@("UH+"`M/R`@("`@9&ES<&QA>2!H96QP+W5S86=E
M("AT:&ES(&UE<W-A9V4I7&XB+@H@("`@("`@("(@("`@("U6("`@("`@("`@
M=F5R<VEO;B!I;F9O<FUA=&EO;EQN(CL*("`@('T@96QS96EF("@D8V]M;6%N
M9"`]/2`B<VAO<G1C=71S(BD@>PH@("`@("`@("1S8R`](%!%05)?0V]M;6%N
M9#HZ9V5T4VAO<G1C=71S*"D["B`@("`@("`@)')E="`](")3:&]R=&-U=',Z
M7&XB.PH@("`@("`@(&9O<F5A8V@@*"1S8R!A<R`D<R`]/B`D8RD@>PH@("`@
M("`@("`@("`D<F5T("X]('-P<FEN=&8H(B`@("`@)2TX<R`E<UQN(BP@)',L
M("1C*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R970["@H@("`@?2!E
M;'-E:68@*"1C;VUM86YD(#T](")V97)S:6]N(BD@>PH@("`@("`@(')E='5R
M;B`B4$5!4B!697)S:6]N.B`B+B1'3$]"04Q36R=P96%R7W!A8VMA9V5?=F5R
M<VEO;B==+@H@("`@("`@("`@("`@("`B7&Y02%`@5F5R<VEO;CH@(BYP:'!V
M97)S:6]N*"DN"B`@("`@("`@("`@("`@(")<;EIE;F0@16YG:6YE(%9E<G-I
M;VXZ("(N>F5N9%]V97)S:6]N*"DN"B`@("`@("`@("`@("`@(")<;E)U;FYI
M;F<@;VXZ("(N<&AP7W5N86UE*"D["@H@("`@?2!E;'-E:68@*"1H96QP(#T@
M4$5!4E]#;VUM86YD.CIG971(96QP*"1C;VUM86YD*2D@>PH@("`@("`@(&EF
M("AI<U]S=')I;F<H)&AE;'`I*2!["B`@("`@("`@("`@(')E='5R;B`B)'!R
M;V=N86UE("1C;VUM86YD(%MO<'1I;VYS72`D:&5L<%QN(CL*("`@("`@("!]
M"B`@("`@("`@:68@*"1H96QP6S%=(#T]/2!N=6QL*2!["B`@("`@("`@("`@
M(')E='5R;B`B)'!R;V=N86UE("1C;VUM86YD("1H96QP6S!=(CL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@(B1P<F]G;F%M92`D8V]M
M;6%N9"!;;W!T:6]N<UT@)&AE;'!;,%U<;B1H96QP6S%=(CL*("`@("`@("!]
M"B`@("!]"B`@("!R971U<FX@(DYO('-U8V@@8V]M;6%N9"(["GT*"B\O('U]
M?0H*9G5N8W1I;VX@97)R;W)?:&%N9&QE<B@D97)R;F\L("1E<G)M<V<L("1F
M:6QE+"`D;&EN92P@)'9A<G,I('L*("`@(&EF("@H9&5F:6YE9"@G15]35%))
M0U0G*2`F)B`D97)R;F\@)B!%7U-44DE#5"D@?'P@(65R<F]R7W)E<&]R=&EN
M9R@I*2!["B`@("`@("`@<F5T=7)N.R`O+R!`<VEL96YC960@97)R;W(*("`@
M('T*("`@("1E<G)O<G1Y<&4@/2!A<G)A>2`H"B`@("`@("`@15]%4E)/4B`@
M(#T^("`B17)R;W(B+`H@("`@("`@($5?5T%23DE.1R`@(#T^("`B5V%R;FEN
M9R(L"B`@("`@("`@15]005)312`@(#T^("`B4&%R<VEN9R!%<G)O<B(L"B`@
M("`@("`@15].3U1)0T4@("`]/B`@(DYO=&EC92(L"B`@("`@("`@15]#3U)%
M7T524D]2("`]/B`@(D-O<F4@17)R;W(B+`H@("`@("`@($5?0T]215]705).
M24Y'("`]/B`@(D-O<F4@5V%R;FEN9R(L"B`@("`@("`@15]#3TU024Q%7T52
M4D]2("`]/B`@(D-O;7!I;&4@17)R;W(B+`H@("`@("`@($5?0T]-4$E,15]7
M05).24Y'(#T^("`B0V]M<&EL92!787)N:6YG(BP*("`@("`@("!%7U5315)?
M15)23U(@/3X@(")5<V5R($5R<F]R(BP*("`@("`@("!%7U5315)?5T%23DE.
M1R`]/B`@(E5S97(@5V%R;FEN9R(L"B`@("`@("`@15]54T527TY/5$E#12`]
M/B`@(E5S97(@3F]T:6-E(@H@("`@*3L*("`@("1P<F5F:7@@/2`D97)R;W)T
M>7!E6R1E<G)N;UT["B`@("`D9FEL92`](&)A<V5N86UE*"1F:6QE*3L*("`@
M('!R:6YT(")<;B1P<F5F:7@Z("1E<G)M<V<@:6X@)&9I;&4@;VX@;&EN92`D
M;&EN95QN(CL*?0H*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I
M9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&EN9&5N="UT86)S+6UO
M9&4Z(&YI;`H@*B!M;V1E.B!P:'`*("H@16YD.@H@*B\*+R\@=FEM-C`P.G-Y
M;CUP:'`*"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]&:6QE+G!H<```````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,34V-0`Q,#0Q-S,V
M,S`P-P`P,38W-#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]
M-"!S:&EF='=I9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW
M+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D
M('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I
M<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*
M+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%)I8VAA<F0@2&5Y97,@
M/')I8VAA<F1`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"`@("`@("`@("!486P@4&5E<B`\=&%L0'!H<"YN970^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PH*"B\J"BH@17AA;7!L92`Q.@HJ("1S=&1I
M;B`]($9I;&4Z.G)E861!;&PH)W!H<#HO+W-T9&EN)RD["BH**B!%>&%M<&QE
M(#(Z"BH@=VAI;&4@*"1D871A(#T@1FEL93HZ<F5A9"@G+V)L86%T+V)A<B<I
M*2!["BH@("`@("\O($-O9&4N+BX**B!]"BHO"@IR97%U:7)E7V]N8V4H)U!%
M05(N<&AP)RD["@HO*BH**B!4:&4@9&5F875L="!N=6UB97(@;V8@8GET97,@
M9F]R(')E861I;F<**B!`8V]N<W0@1DE,15]$149!54Q47U)%041325I%"BHO
M"F1E9FEN92@G1DE,15]$149!54Q47U)%041325I%)RP@,3`R-"P@=')U92D[
M"@HO*BH**B!-;V1E('1O('5S92!F;W(@<F5A9&EN9R!F<F]M(&9I;&5S"BH@
M0&-O;G-T($9)3$5?34]$15]214%$"BHO"F1E9FEN92@G1DE,15]-3T1%7U)%
M040G+"`@("=R8B<L('1R=64I.PH*+RHJ"BH@36]D92!T;R!U<V4@9F]R('1R
M=6YC871I;F<@9FEL97,L('1H96X@=W)I=&EN9PHJ($!C;VYS="!&24Q%7TU/
M1$5?5U))5$4**B\*9&5F:6YE*"=&24Q%7TU/1$5?5U))5$4G+"`@)W=B)RP@
M=')U92D["@HO*BH**B!-;V1E('1O('5S92!F;W(@87!P96YD:6YG('1O(&9I
M;&5S"BH@0&-O;G-T($9)3$5?34]$15]!4%!%3D0**B\*9&5F:6YE*"=&24Q%
M7TU/1$5?05!014Y$)RP@)V%B)RP@=')U92D["@HO*BH**B!5<V4@=&AI<R!W
M:&5N(&$@<VAA<F5D("AR96%D*2!L;V-K(&ES(')E<75I<F5D"BH@0&-O;G-T
M($9)3$5?3$]#2U]32$%2140**B\*9&5F:6YE*"=&24Q%7TQ/0TM?4TA!4D5$
M)RP@("`@3$]#2U]32"P@=')U92D["@HO*BH**B!5<V4@=&AI<R!W:&5N(&%N
M(&5X8VQU<VEV92`H=W)I=&4I(&QO8VL@:7,@<F5Q=6ER960**B!`8V]N<W0@
M1DE,15],3T-+7T580TQ54TE610HJ+PID969I;F4H)T9)3$5?3$]#2U]%6$-,
M55-)5D4G+"!,3T-+7T58+"!T<G5E*3L*"B\J*@HJ($-L87-S(&9O<B!H86YD
M;&EN9R!F:6QE<PHJ"BH@02!C;&%S<R!W:71H(&-O;6UO;B!F=6YC=&EO;G,@
M9F]R('=R:71I;F<L"BH@<F5A9&EN9R!A;F0@:&%N9&QI;F<@9FEL97,@86YD
M(&1I<F5C=&]R:65S"BH**@HJ($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I
M8VAA<F1`<&AP+FYE=#X**B!`875T:&]R("!486P@4&5E<B`\=&%L0'!H<"YN
M970^"BH@0&%C8V5S<R`@<'5B;&EC"BH@0'9E<G-I;VX@,"XY"BH@0'!A8VMA
M9V4@1FEL90HJ+PIC;&%S<R!&:6QE(&5X=&5N9',@4$5!4@I["B`@("`O*BH*
M("`@("H@1&5S=')U8W1O<@H@("`@*@H@("`@*B!5;FQO8VMS(&%N>2!L;V-K
M960@9FEL92!P;VEN=&5R<R!A;F0@8VQO<V5S(&%L;"!F:6QE<&]I;G1E<G,*
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I;VX@7T9I
M;&4H*0H@("`@>PH@("`@("`@("1L;V-K<R`]("9014%2.CIG9713=&%T:6-0
M<F]P97)T>2@G1FEL92<L("=L;V-K<R<I.PH@("`@("`@("1F:6QE4&]I;G1E
M<G,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)T9I;&4G+"`G9FEL95!O
M:6YT97)S)RD["@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1L
M;V-K<RD[("1I*RLI('L*("`@("`@("`@("`@9FQO8VLH)'1H:7,M/FQO8VMS
M6R1I72P@3$]#2U]53BD["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1F:6QE4&]I;G1E<G,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE
M4&]I;G1E<G,@87,@)&9N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'9A;'5E(&%S("1M;V1E(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@("`@($!F8VQO<V4H)&9I;&50;VEN=&5R<ULD9FYA;65=
M6R1M;V1E72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J($AA;F1L97,@9FEL92!P;VEN
M=&5R<RX@268@82!F:6QE('!O:6YT97(@;F5E9',@=&\@8F4@;W!E;F5D+`H@
M("`@*B!I="!W:6QL(&)E+B!)9B!I="!A;')E861Y(&5X:7-T<R`H8F%S960@
M;VX@9FEL96YA;64@86YD(&UO9&4I"B`@("`J('1H96X@=&AE(&5X:7-T:6YG
M(&]N92!W:6QL(&)E(')E='5R;F5D+@H@("`@*@H@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("H@0'!A<F%M("!S=')I;F<@("1F:6QE;F%M92!&:6QE;F%M
M92!T;R!B92!U<V5D"B`@("`J($!P87)A;2`@<W1R:6YG("`D;6]D92`@("`@
M36]D92!T;R!O<&5N('1H92!F:6QE(&EN"B`@("`J($!P87)A;2`@;6EX960@
M("`D;&]C:R`@("`@5'EP92!O9B!L;V-K('1O('5S90H@("`@*B!`<F5T=7)N
M(&UI>&5D("`@("`@("`@("`@(%!%05)?17)R;W(@;VX@97)R;W(@86YD(&9I
M;&4@<&]I;G1E<B!R97-O=7)C92!O;B!S=6-C97-S"B`@("`J+PH@("`@9G5N
M8W1I;VX@)E]G971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M;V1E+"`D;&]C
M:R`](&9A;'-E*0H@("`@>PH@("`@("`@("1F:6QE4&]I;G1E<G,@/2`F4$5!
M4CHZ9V5T4W1A=&EC4')O<&5R='DH)T9I;&4G+"`G9FEL95!O:6YT97)S)RD[
M"@H@("`@("`@("\O($YE960@=&\@;W!E;B!F:7)S="XN+@H@("`@("`@(&EF
M("@A:7-S970H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72D@3U(@
M(6ES7W)E<V]U<F-E*"1F:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95TI
M*2!["@H@("`@("`@("`@("`O+R!#:&5C:R!I="!E>&ES=',*("`@("`@("`@
M("`@:68@*$9)3$5?34]$15]214%$(#T]("1M;V1E($%.1"`A<')E9U]M871C
M:"@G+UXH:'1T<'QH='1P<WQF='!\<&AP*3I<+UPO+VDG+"`D9FEL96YA;64I
M($%.1"`A9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9I;&4@9&]E<R!N;W0@97AI
M<W0Z("<@+B`D9FEL96YA;64I.PH*("`@("`@("`@("`@+R\@5W)I=&5A8FQE
M/PH@("`@("`@("`@("!](&5L<V5I9B`H("A&24Q%7TU/1$5?5U))5$4@/3T@
M)&UO9&4@3U(@1DE,15]-3T1%7T%04$5.1"`]/2`D;6]D92D*("`@("`@("`@
M("`@("`@("`@("`@("`@04Y$("%F:6QE7V5X:7-T<R@D9FEL96YA;64I"B`@
M("`@("`@("`@("`@("`@("`@("`@($%.1"`A:7-?=W)I=&5A8FQE*&1I<FYA
M;64H)&9I;&5N86UE*2DI('L*"B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G0V]U;&0@;F]T(&-R96%T92!F:6QE.B`G("X@)&9I
M;&5N86UE*3L*"B`@("`@("`@("`@('T@96QS96EF("@@*$9)3$5?34]$15]7
M4DE412`]/2`D;6]D92!/4B!&24Q%7TU/1$5?05!014Y$(#T]("1M;V1E*0H@
M("`@("`@("`@("`@("`@("`@("`@("!!3D0@(6ES7W=R:71E86)L92AD:7)N
M86UE*"1F:6QE;F%M92DI*2!["@H@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T9I;&4@:7,@;F]T('=R:71E86)L93H@)R`N("1F
M:6QE;F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE4&]I
M;G1E<G-;)&9I;&5N86UE75LD;6]D95T@/2!`9F]P96XH)&9I;&5N86UE+"`D
M;6]D92D["B`@("`@("`@("`@(&EF("AF86QS92`]/3T@)&9I;&50;VEN=&5R
M<ULD9FEL96YA;65=6R1M;V1E72D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!O<&5N(&9I;&4Z("<@+B`D
M9FEL96YA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!,;V-K(&ET/PH@("`@("`@(&EF("@D;&]C:RD@>PH@("`@("`@("`@("`D
M;&]C:W,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)T9I;&4G+"`G;&]C
M:W,G*3L*("`@("`@("`@("`@:68@*&9L;V-K*"1F:6QE4&]I;G1E<G-;)&9I
M;&5N86UE75LD;6]D95TL("1L;V-K*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO8VMS6UT@/2`F)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&9I
M;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E73L*("`@('T*"B`@("`O*BH*
M("`@("H@4F5A9',@86X@96YT:7)E(&9I;&4@86YD(')E='5R;G,@:70N"B`@
M("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!P87)A;2`@<W1R:6YG
M("1F:6QE;F%M92!.86UE(&]F(&9I;&4@=&\@<F5A9"!F<F]M"B`@("`J($!P
M87)A;2`@;6EX960@("1L;V-K("`@("!4>7!E(&]F(&QO8VL@=&\@=7-E"B`@
M("`J($!R971U<FX@;6EX960@("`@("`@("`@("!014%27T5R<F]R(&EF(&%N
M(&5R<F]R(&AA<R!O8V-U<F5D(&]R(&$@<W1R:6YG('=I=&@@=&AE(&-O;G1E
M;G1S(&]F('1H92!T:&4@9FEL90H@("`@*B\*("`@(&9U;F-T:6]N(')E861!
M;&PH)&9I;&5N86UE+"`D;&]C:R`](&9A;'-E*0H@("`@>PH@("`@("`@("1F
M:6QE(#T@)R<["B`@("`@("`@=VAI;&4@*"@D=&UP(#T@1FEL93HZ<F5A9"@D
M9FEL96YA;64L($9)3$5?1$5&055,5%]214%$4TE:12P@)&QO8VLI*2`A/3T@
M1D%,4T4I('L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1M<"DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1F:6QE("X]("1T;7`["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&9I;&4["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@
M82!S<&5C:69I960@;G5M8F5R(&]F(&)Y=&5S(&]F(&$@9FEL92X@1&5F875L
M=',@=&\@,3`R-"X*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@
M0'!A<F%M("!S=')I;F<@("1F:6QE;F%M92!.86UE(&]F(&9I;&4@=&\@<F5A
M9"!F<F]M"B`@("`J($!P87)A;2`@:6YT96=E<B`D<VEZ92`@("`@0GET97,@
M=&\@<F5A9`H@("`@*B!`<&%R86T@(&UI>&5D("`@)&QO8VL@("`@(%1Y<&4@
M;V8@;&]C:R!T;R!U<V4*("`@("H@0')E='5R;B!M:7AE9"`@("`@("`@("`@
M("!014%27T5R<F]R(&]N(&5R<F]R(&]R(&$@<W1R:6YG('=H:6-H(&-O;G1A
M:6YS('1H92!D871A(')E860*("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!7:6QL(&%L<V\@<F5T=7)N(&9A;'-E('5P;VX@14]&"B`@("`J+PH@
M("`@9G5N8W1I;VX@<F5A9"@D9FEL96YA;64L("1S:7IE(#T@1DE,15]$149!
M54Q47U)%041325I%+"`D;&]C:R`](&9A;'-E*0H@("`@>PH@("`@("`@('-T
M871I8R`D9FEL95!O:6YT97)S.R`O+R!5<V5D('1O('!R979E;G0@=6YN96-E
M<W-A<GD@8V%L;',@=&\@7V=E=$9I;&50;VEN=&5R*"D*"B`@("`@("`@:68@
M*#`@/3T@)'-I>F4I('L*("`@("`@("`@("`@<F5T=7)N($9I;&4Z.G)E861!
M;&PH)&9I;&5N86UE*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H
M)&9I;&50;VEN=&5R<ULD9FEL96YA;65=*2!/4B`A:7-?<F5S;W5R8V4H)&9I
M;&50;VEN=&5R<ULD9FEL96YA;65=*2D@>PH@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE
M;F%M92P@1DE,15]-3T1%7U)%040L("1L;V-K*2DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D9G`["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F
M:6QE4&]I;G1E<G-;)&9I;&5N86UE72`]("8D9G`["@H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F<"`]("8D9FEL95!O:6YT97)S6R1F:6QE;F%M
M95T["B`@("`@("`@?0H*("`@("`@("!R971U<FX@(69E;V8H)&9P*2`_(&9R
M96%D*"1F<"P@)'-I>F4I(#H@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`J
M(%=R:71E<R!T:&4@9VEV96X@9&%T82!T;R!T:&4@9VEV96X@9FEL96YA;64N
M($1E9F%U;'1S('1O(&YO(&QO8VLL(&%P<&5N9"!M;V1E+@H@("`@*@H@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@*B!`<&%R86T@('-T<FEN9R`D9FEL96YA
M;64@3F%M92!O9B!F:6QE('1O('=R:71E('1O"B`@("`J($!P87)A;2`@<W1R
M:6YG("1D871A("`@("!$871A('1O('=R:71E('1O(&9I;&4*("`@("H@0'!A
M<F%M("!S=')I;F<@)&UO9&4@("`@($UO9&4@=&\@;W!E;B!F:6QE(&EN"B`@
M("`J($!P87)A;2`@;6EX960@("1L;V-K("`@("!4>7!E(&]F(&QO8VL@=&\@
M=7-E"B`@("`J($!R971U<FX@;6EX960@("`@("`@("`@("`@4$5!4E]%<G)O
M<B!O;B!E<G)O<B!O<B!N=6UB97(@;V8@8GET97,@=W)I='1E;B!T;R!F:6QE
M+@H@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1F:6QE;F%M92P@)&1A=&$L
M("1M;V1E(#T@1DE,15]-3T1%7T%04$5.1"P@)&QO8VL@/2!F86QS92D*("`@
M('L*("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)&9P(#T@)D9I;&4Z.E]G
M971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M;V1E+"`D;&]C:RDI*2!["B`@
M("`@("`@("`@(&EF("@H)&)Y=&5S(#T@9G=R:71E*"1F<"P@)&1A=&$L('-T
M<FQE;B@D9&%T82DI*2`]/2`M,2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G9G=R:71E*"D@8V%L;"!F86EL
M960@=&\@=W)I=&4@9&%T83H@(B5S(B!T;R!F:6QE.B`B)7,B)RP@)&1A=&$L
M("1F:6QE;F%M92DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1B>71E<SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1F<#L*("`@('T*"B`@("`O*BH*("`@("H@4F5A
M9',@86YD(')E='5R;G,@82!S:6YG;&4@8VAA<F%C=&5R(&9R;VT@9VEV96X@
M9FEL96YA;64*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0'!A
M<F%M("!S=')I;F<@)&9I;&5N86UE($YA;64@;V8@9FEL92!T;R!R96%D(&9R
M;VT*("`@("H@0'!A<F%M("!M:7AE9"`@)&QO8VL@("`@(%1Y<&4@;V8@;&]C
M:R!T;R!U<V4*("`@("H@0')E='5R;B!M:7AE9"`@("`@("`@("`@(%!%05)?
M17)R;W(@;VX@97)R;W(@;W(@;VYE(&-H87)A8W1E<B!O9B!T:&4@<W!E8VEF
M:65D(&9I;&4*("`@("HO"B`@("!F=6YC=&EO;B!R96%D0VAA<B@D9FEL96YA
M;64L("1L;V-K(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T=7)N($9I;&4Z
M.G)E860H)&9I;&5N86UE+"`Q+"`D;&]C:RD["B`@("!]"@H@("`@+RHJ"B`@
M("`J(%=R:71E<R!A('-I;F=L92!C:&%R86-T97(@=&\@82!F:6QE"B`@("`J
M"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!P87)A;2`@<W1R:6YG("1F
M:6QE;F%M92!.86UE(&]F(&9I;&4@=&\@=W)I=&4@=&\*("`@("H@0'!A<F%M
M("!S=')I;F<@)&-H87(@("`@($-H87)A8W1E<B!T;R!W<FET90H@("`@*B!`
M<&%R86T@('-T<FEN9R`D;6]D92`@("`@36]D92!T;R!U<V4@=VAE;B!W<FET
M:6YG"B`@("`J($!P87)A;2`@;6EX960@("1L;V-K("`@("!4>7!E(&]F(&QO
M8VL@=&\@=7-E"B`@("`J($!R971U<FX@;6EX960@("`@("`@("`@("!014%2
M7T5R<F]R(&]N(&5R<F]R+"!O<B`Q(&]N('-U8V-E<W,*("`@("HO"B`@("!F
M=6YC=&EO;B!W<FET94-H87(H)&9I;&5N86UE+"`D8VAA<BP@)&UO9&4@/2!&
M24Q%7TU/1$5?05!014Y$+"`D;&]C:R`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A4$5!4CHZ:7-%<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN
M=&5R*"1F:6QE;F%M92P@)&UO9&4L("1L;V-K*2DI('L*("`@("`@("`@("`@
M:68@*&9W<FET92@D9G`L("1C:&%R+"`Q*2`]/2`M,2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G9G=R:71E
M*"D@8V%L;"!F86EL960@=&\@=W)I=&4@9&%T83H@(B5S(B!T;R!F:6QE.B`B
M)7,B)RP@)&1A=&$L("1F:6QE;F%M92DI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D9G`["B`@("!]"@H@("`@+RHJ"B`@
M("`J(%)E='5R;G,@82!L:6YE(&]F('1H92!F:6QE"B`@("`J"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J($!P87)A;2`@<W1R:6YG("`D9FEL96YA;64@
M3F%M92!O9B!F:6QE('1O(')E860@9G)O;0H@("`@*B!`<&%R86T@(&)O;VQE
M86X@)&QO8VL@("`@(%1Y<&4@;V8@;&]C:R!T;R!U<V4*("`@("H@0')E='5R
M;B!M:7AE9"`@("`@("`@("`@("!014%27T5R<F]R(&]N(&5R<F]R(&]R(&$@
M<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&QI;F4@<F5A9"!F<F]M(&9I;&4*("`@
M("HO"B`@("!F=6YC=&EO;B!R96%D3&EN92@D9FEL96YA;64L("1L;V-K(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC("1F:6QE4&]I;G1E<G,[("\O
M(%5S960@=&\@<')E=F5N="!U;FYE8V5S<V%R>2!C86QL<R!T;R!?9V5T1FEL
M95!O:6YT97(H*0H*("`@("`@("!I9B`H(6ES<V5T*"1F:6QE4&]I;G1E<G-;
M)&9I;&5N86UE72D@3U(@(6ES7W)E<V]U<F-E*"1F:6QE4&]I;G1E<G-;)&9I
M;&5N86UE72DI('L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9P
M(#T@)D9I;&4Z.E]G971&:6QE4&]I;G1E<B@D9FEL96YA;64L($9)3$5?34]$
M15]214%$+"`D;&]C:RDI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&9P
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL95!O:6YT97)S6R1F
M:6QE;F%M95T@/2`F)&9P.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D9G`@/2`F)&9I;&50;VEN=&5R<ULD9FEL96YA;65=.PH@("`@("`@('T*
M"@D):68@*&9E;V8H)&9P*2D@>PH)"0ER971U<FX@9F%L<V4["@D)?0H*("`@
M("`@("`D9FEL95-T<FEN9R`]("<G.PH@("`@("`@('=H:6QE("@H)&9I;&5#
M:&%R(#T@9F=E=&,H)&9P*2D@(3T@(EQN(B!!3D0@(69E;V8H)&9P*2D@>PH@
M("`@("`@("`@("`D9FEL95-T<FEN9R`N/2`D9FEL94-H87(["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@<W5B<W1R*"1F:6QE4W1R:6YG+"`M,2D@/3T@
M(EQR(B`_('-U8G-T<B@D9FEL95-T<FEN9RP@,"P@+3$I(#H@)&9I;&53=')I
M;F<["B`@("!]"@H@("`@+RHJ"B`@("`J(%=R:71E<R!A('-I;F=L92!L:6YE
M+"!A<'!E;F1I;F<@82!,1B`H8GD@9&5F875L="D*("`@("H*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M("!S=')I;F<@)&9I;&5N86UE($YA
M;64@;V8@9FEL92!T;R!W<FET92!T;PH@("`@*B!`<&%R86T@('-T<FEN9R`D
M;&EN92`@("`@3&EN92!O9B!D871A('1O(&)E('=R:71T96X@=&\@9FEL90H@
M("`@*B!`<&%R86T@('-T<FEN9R`D;6]D92`@("`@5W)I=&4@;6]D92P@8V%N
M(&)E(&5I=&AE<B!&24Q%7TU/1$5?5U))5$4@;W(@1DE,15]-3T1%7T%04$5.
M1`H@("`@*B!`<&%R86T@('-T<FEN9R`D8W)L9B`@("`@5&AE($-23$8@>6]U
M<B!S>7-T96T@:7,@=7-I;F<N(%5.25@@/2!<;B!7:6YD;W=S(#T@7')<;B!-
M86,@/2!<<@H@("`@*B!`<&%R86T@(&UI>&5D("`D;&]C:R`@("`@5'EP92!O
M9B!L;V-K('1O('5S90H@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@("`@
M4$5!4E]%<G)O<B!O;B!E<G)O<B!O<B!N=6UB97(@;V8@8GET97,@=W)I='1E
M;B!T;R!F:6QE("AI;F-L=61I;F<@87!P96YD960@8W)L9BD*("`@("HO"B`@
M("!F=6YC=&EO;B!W<FET94QI;F4H)&9I;&5N86UE+"`D;&EN92P@)&UO9&4@
M/2!&24Q%7TU/1$5?05!014Y$+"`D8W)L9B`](")<;B(L("1L;V-K(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@:68H(5!%05(Z.FES17)R;W(H)&9P(#T@)D9I
M;&4Z.E]G971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M;V1E+"`D;&]C:RDI
M*7L*("`@("`@("`@("`@:68@*"@D8GET97,@/2!F=W)I=&4H)&9P+"`D;&EN
M92`N("1C<FQF*2D@/3T@+3$I('L*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H)V9W<FET92@I(&-A;&P@9F%I;&5D
M('1O('=R:71E(&1A=&$Z("(E<R(@=&\@9FEL93H@(B5S(B<L("1D871A+"`D
M9FEL96YA;64I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D8GET97,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D9G`["B`@("!]"@H@("`@+RHJ"B`@("`J(%1H:7,@
M<F5W:6YD<R!A(&9I;&5P;VEN=&5R('1O('1H92!S=&%R="!O9B!A(&9I;&4*
M("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M("!S=')I
M;F<@)&9I;&5N86UE(%1H92!F:6QE;F%M90H@("`@*B!`<&%R86T@('-T<FEN
M9R`D;6]D92`@("`@36]D92!T:&4@9FEL92!W87,@;W!E;F5D(&EN"B`@("`J
M($!R971U<FX@;6EX960@("`@("`@("`@("!014%2($5R<F]R(&]N(&5R<F]R
M+"!T<G5E(&]N('-U8V-E<W,*("`@("HO"B`@("!F=6YC=&EO;B!R97=I;F0H
M)&9I;&5N86UE+"`D;6]D92D*("`@('L*("`@("`@("!I9B`H(5!%05(Z.FES
M17)R;W(H)&9P(#T@)D9I;&4Z.E]G971&:6QE4&]I;G1E<B@D9FEL96YA;64L
M("1M;V1E*2DI('L*("`@("`@("`@("`@<F5T=7)N(')E=VEN9"@D9G`I(#\@
M=')U92`Z(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!R97=I;F0@9FEL
M93H@)R`N("1F:6QE;F%M92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&9P.PH@("`@?0H*("`@("\J*@H@("`@*B!4:&ES(&-L;W-E<R!A;B!O<&5N
M(&9I;&4@<&]I;G1E<@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B!`<&%R86T@('-T<FEN9R`D9FEL96YA;64@5&AE(&9I;&5N86UE('1H870@
M=V%S(&]P96YE9`H@("`@*B!`<&%R86T@('-T<FEN9R`D;6]D92`@("`@36]D
M92!T:&4@9FEL92!W87,@;W!E;F5D(&EN"B`@("`J($!R971U<FX@;6EX960@
M("`@("`@("`@("!014%2($5R<F]R(&]N(&5R<F]R+"!T<G5E(&]T:&5R=VES
M90H@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"1F:6QE;F%M92P@)&UO9&4I
M"B`@("!["B`@("`@("`@:68@*"%014%2.CII<T5R<F]R*"1F<"`]("9&:6QE
M.CI?9V5T1FEL95!O:6YT97(H)&9I;&5N86UE+"`D;6]D92DI*2!["B`@("`@
M("`@("`@("1F:6QE4&]I;G1E<G,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R
M='DH)T9I;&4G+"`G9FEL95!O:6YT97)S)RD["B`@("`@("`@("`@('5N<V5T
M*"1F:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95TI.PH@("`@("`@("`@
M("!R971U<FX@9F-L;W-E*"1F<"D@/R!T<G5E(#H@4$5!4CHZ<F%I<V5%<G)O
M<B@G1F%I;&5D('1O(&-L;W-E(&9I;&4Z("<@+B`D9FEL96YA;64I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1F<#L*("`@('T*"B`@("`O*BH*("`@
M("H@5&AI<R!U;FQO8VMS(&$@;&]C:V5D(&9I;&4@<&]I;G1E<BX*("`@("H*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M("!S=')I;F<@)&9I
M;&5N86UE(%1H92!F:6QE;F%M92!T:&%T('=A<R!O<&5N960*("`@("H@0'!A
M<F%M("!S=')I;F<@)&UO9&4@("`@($UO9&4@=&AE(&9I;&4@=V%S(&]P96YE
M9"!I;@H@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@("`@4$5!4B!%<G)O
M<B!O;B!E<G)O<BP@=')U92!O=&AE<G=I<V4*("`@("HO"B`@("!F=6YC=&EO
M;B!U;FQO8VLH)&9I;&5N86UE+"`D;6]D92D*("`@('L*("`@("`@("!I9B`H
M(5!%05(Z.FES17)R;W(H)&9P(#T@)D9)3$4Z.E]G971&:6QE4&]I;G1E<B@D
M9FEL96YA;64L("1M;V1E*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9L;V-K
M*"1F<"P@3$]#2U]53BD@/R!T<G5E(#H@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I
M;&5D('1O('5N;&]C:R!F:6QE.B`G("X@)&9I;&5N86UE*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9G`["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E
M='5R;G,@82!S=')I;F<@<&%T:"!B=6EL="!F<F]M('1H92!A<G)A>2`D<&%T
M:%!A<G1S+B!7:&5R92!A(&IO:6X@;V-C=7)S"B`@("`J(&UU;'1I<&QE('-E
M<&%R871O<G,@87)E(')E;6]V960N($IO:6YS('5S:6YG('1H92!O<'1I;VYA
M;"!S97!A<F%T;W(L(&1E9F%U;'1I;F<*("`@("H@=&\@=&AE(%!(4"!$25)%
M0U1/4EE?4T5005)!5$]2(&-O;G-T86YT+@H@("`@*@H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*B!`<&%R86T@(&%R<F%Y("`D<&%R=',@("`@($%R<F%Y
M(&-O;G1A:6YI;F<@=&AE('!A<G1S('1O(&)E(&IO:6YE9`H@("`@*B!`<&%R
M86T@('-T<FEN9R`D<V5P87)A=&]R(%1H92!S>7-T96T@9&ER96-T;W)Y('-E
M<&5R871O<@H@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD4&%T:"@D<&%R=',L
M("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1P87)T<RD[("1I*RLI('L*
M("`@("`@("`@("`@:68@*#`@/3T@)&DI('L*("`@("`@("`@("`@("`@("1P
M87)T<ULD:5T@/2!&:6QE.CIS=')I<%1R86EL:6YG4V5P87)A=&]R<R@D<&%R
M='-;)&E=+"`D<V5P87)A=&]R*3L*"B`@("`@("`@("`@('T@96QS96EF*&-O
M=6YT*"1P87)T<RD@+2`Q(#T]("1I*2!["B`@("`@("`@("`@("`@("`D<&%R
M='-;)&E=(#T@1FEL93HZ<W1R:7!,96%D:6YG4V5P87)A=&]R<R@D<&%R='-;
M)&E=+"`D<V5P87)A=&]R*3L*"B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<&%R='-;)&E=(#T@1FEL93HZ<W1R:7!4<F%I;&EN9U-E
M<&%R871O<G,H)'!A<G1S6R1I72P@)'-E<&%R871O<BD["B`@("`@("`@("`@
M("`@("`D<&%R='-;)&E=(#T@1FEL93HZ<W1R:7!,96%D:6YG4V5P87)A=&]R
M<R@D<&%R='-;)&E=+"`D<V5P87)A=&]R*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H)'-E<&%R871O<BP@)'!A
M<G1S*3L*("`@('T*"B`@("`O*BH*("`@("H@4W1R:7!S('1R86EL:6YG('-E
M<&%R871O<G,@9G)O;2!T:&4@9VEV96X@<&%T:`H@("`@*@H@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@*B!`<&%R86T@('-T<FEN9R`D<&%T:"`@("`@(%!A
M=&@@=&\@=7-E"B`@("`J($!P87)A;2`@<W1R:6YG("1S97!A<F%T;W(@4V5P
M87)A=&]R('1O(&QO;VL@9F]R"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@
M("`@("`@4F5S=6QT:6YG('!A=&@*("`@("HO"B`@("!F=6YC=&EO;B!S=')I
M<%1R86EL:6YG4V5P87)A=&]R<R@D<&%T:"P@)'-E<&%R871O<B`]($1)4D5#
M5$]265]315!!4D%43U(I"B`@("!["B`@("`@("`@=VAI;&4@*'-U8G-T<B@D
M<&%T:"P@+3$I(#T]("1S97!A<F%T;W(I('L*("`@("`@("`@("`@)'!A=&@@
M/2!S=6)S='(H)'!A=&@L(#`L("TQ*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<&%T:#L*("`@('T*"B`@("`O*BH*("`@("H@4W1R:7!S(&QE861I
M;F<@<V5P87)A=&]R<R!F<F]M('1H92!G:79E;B!P871H"B`@("`J"B`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`J($!P87)A;2`@<W1R:6YG("1P871H("`@
M("`@4&%T:"!T;R!U<V4*("`@("H@0'!A<F%M("!S=')I;F<@)'-E<&%R871O
M<B!397!A<F%T;W(@=&\@;&]O:R!F;W(*("`@("H@0')E='5R;B!S=')I;F<@
M("`@("`@("`@("!297-U;'1I;F<@<&%T:`H@("`@*B\*("`@(&9U;F-T:6]N
M('-T<FEP3&5A9&EN9U-E<&%R871O<G,H)'!A=&@L("1S97!A<F%T;W(@/2!$
M25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@("`@('=H:6QE("AS=6)S
M='(H)'!A=&@L(#`L(#$I(#T]("1S97!A<F%T;W(I('L*("`@("`@("`@("`@
M)'!A=&@@/2!S=6)S='(H)'!A=&@L(#$I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1P871H.PH@("`@?0H*("`@("\J*@H@("`@*B!2971U<FYS(&$@
M<&%T:"!W:71H;W5T(&QE861I;F<@+R!O<B!#.EPN($EF('1H:7,@:7,@;F]T
M"B`@("`J('!R97-E;G0@=&AE('!A=&@@:7,@<F5T=7)N960@87,@:7,N"B`@
M("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!P87)A;2`@<W1R:6YG
M("1P871H(%1H92!P871H('1O(&)E('!R;V-E<W-E9`H@("`@*B!`<F5T=7)N
M('-T<FEN9R`@("`@("!4:&4@<')O8V5S<V5D('!A=&@@;W(@=&AE('!A=&@@
M87,@:7,*("`@("HO"B`@("!F=6YC=&EO;B!S:VEP4F]O="@D<&%T:"D*("`@
M('L*("`@("`@("!I9B`H1FEL93HZ:7-!8G-O;'5T92@D<&%T:"DI('L*("`@
M("`@("`@("`@:68@*$1)4D5#5$]265]315!!4D%43U(@/3T@(B\B*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@<W5B<W1R*"1P871H+#$I.PH*("`@("`@
M("`@("`@?2!E;'-E:68H1$E214-43U)97U-%4$%2051/4B`]/2`B7%PB*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@<W5B<W1R*"1P871H+"`S*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`D<&%T:#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R
M;G,@=&AE('1E;7`@9&ER96-T;W)Y(&%C8V]R9&EN9R!T;R!E:71H97(@=&AE
M(%1-4"P@5$U01$E2+"!O<B!414U0(&5N=@H@("`@*B!V87)I86)L97,N($EF
M('1H97-E(&%R92!N;W0@<V5T(&ET('=I;&P@86QS;R!C:&5C:R!F;W(@=&AE
M(&5X:7-T96YC92!O9@H@("`@*B`O=&UP+"`E5TE.1$E2)5QT96UP"B`@("`J
M"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@<W1R:6YG(%1H
M92!S>7-T96T@=&UP(&1I<F5C=&]R>0H@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%1E;7!$:7(H*0H@("`@>PH@("`@("`@(&EF("A/4U]724Y$3U=3*7L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1?14Y66R=414U0)UTI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)%]%3E9;)U1%35`G73L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H:7-S970H)%]%3E9;)U1-4"==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1?14Y66R=435`G73L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H:7-S970H)%]%3E9;)W=I;F1I<B==*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1?14Y66R=W:6YD:7(G72`N("=<=&5M<"<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1?14Y66R=3>7-T
M96U2;V]T)UT@+B`G7'1E;7`G.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S
M970H)%]%3E9;)U1-4$1)4B==*2D@>PH@("`@("`@("`@("!R971U<FX@)%]%
M3E9;)U1-4$1)4B==.PH@("`@("`@('T*("`@("`@("!R971U<FX@)R]T;7`G
M.PH@("`@?0H*("`@("\J*@H@("`@*B!2971U<FYS(&$@=&5M<&]R87)Y(&9I
M;&5N86UE('5S:6YG('1E;7!N86TH*2!A;F0@=&AE(&%B;W9E(&=E=%1M<$1I
M<B@I(&9U;F-T:6]N+@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B!`<&%R86T@('-T<FEN9R`D9&ER;F%M92!/<'1I;VYA;"!D:7)E8W1O<GD@
M;F%M92!F;W(@=&AE('1M<"!F:6QE"B`@("`J($!R971U<FX@<W1R:6YG("`@
M("`@("`@($9I;&5N86UE(&%N9"!P871H(&]F('1H92!T;7`@9FEL90H@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%1E;7!&:6QE*"1D:7)N86UE(#T@3E5,3"D*
M("`@('L*"0EI9B`H:7-?;G5L;"@D9&ER;F%M92DI('L*"0D))&1I<FYA;64@
M/2!&:6QE.CIG971496UP1&ER*"D["@D)?0H@("`@("`@(')E='5R;B!T96UP
M;F%M*"1D:7)N86UE+"`G=&5M<"XG*3L*("`@('T*"B`@("`O*BH*("`@("H@
M4F5T=7)N<R!B;V]L96%N(&)A<V5D(&]N('=H971H97(@9VEV96X@<&%T:"!I
M<R!A8G-O;'5T92!O<B!N;W0N"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J($!P87)A;2`@<W1R:6YG("`D<&%T:"!':79E;B!P871H"B`@("`J
M($!R971U<FX@8F]O;&5A;B`@("`@("!4<G5E(&EF('1H92!P871H(&ES(&%B
M<V]L=71E+"!F86QS92!I9B!I="!I<R!N;W0*("`@("HO"B`@("!F=6YC=&EO
M;B!I<T%B<V]L=71E*"1P871H*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"(O7"Y<+B\B+"`D<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*$1)4D5#5$]265]315!!4D%4
M3U(@/3T@)R\G($%.1"`H<W5B<W1R*"1P871H+"`P+"`Q*2`]/2`G+R<@3U(@
M<W5B<W1R*"1P871H+"`P+"`Q*2`]/2`G?B<I*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH*("`@("`@("!](&5L<V5I9BA$25)%0U1/4EE?4T5005)!
M5$]2(#T]("=<7"<@04Y$('!R96=?;6%T8V@H)R]>6V$M>ETZ7%Q<+VDG+"`D
M<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["@H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0I]"@I014%2.CIR96=I<W1E
M<E-H=71D;W=N1G5N8RAA<G)A>2@G1FEL92<L("=?1FEL92<I*3L*"C\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+P``````````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C,P,#<`,#$V,C0P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O<&]R=&%L+P``````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P,3<U-#$`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO961I="YP:'``````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,3(W`#$P-#$W,S8S
M,#`W`#`R,3$W-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]P
M;W)T86PO961I="YP:'`L=B`Q+C0T+C@N-2`R,#`V+S`S+S`X(#$X.C`P.C4V
M(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC
M92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+TED96YT:71Y+G!H<"<["@II9B`H(4%U=&@Z.FES075T:&5N=&EC
M871E9"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D
M:7)E8W0H*3L*?0H*+R\@1V5T(&9U;&P@;F%M92!F;W(@=&ET;&4N"B1I9&5N
M=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B1F=6QL;F%M92`]("1I
M9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN86UE)RD["FEF("AE;7!T>2@D9G5L
M;&YA;64I*2!["B`@("`D9G5L;&YA;64@/2!!=71H.CIG971!=71H*"D["GT*
M"B\O($EN<W1A;G1I871E('1H92!B;&]C:W,@;V)J96-T<RX*)&)L;V-K<R`]
M("9(;W)D95]";&]C:U]#;VQL96-T:6]N.CIS:6YG;&5T;VXH)W!O<G1A;"<I
M.PHD;&%Y;W5T(#T@)DAO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R.CIS:6YG
M;&5T;VXH)W!O<G1A;"<L("1B;&]C:W,L("1P<F5F<RT^9V5T5F%L=64H)W!O
M<G1A;%]L87EO=70G*2D["@HO+R!(86YD;&4@<F5Q=65S=&5D(&%C=&EO;G,N
M"B1L87EO=70M/FAA;F1L92A5=&EL.CIG971&;W)M1&%T82@G86-T:6]N)RDL
M"B`@("`@("`@("`@("`@("`H:6YT*55T:6PZ.F=E=$9O<FU$871A*"=R;W<G
M*2P*("`@("`@("`@("`@("`@("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)V-O
M;"<I*3L*:68@*"1L87EO=70M/G5P9&%T960H*2D@>PH@("`@)'!R969S+3YS
M971686QU92@G<&]R=&%L7VQA>6]U="<L("1L87EO=70M/G-E<FEA;&EZ92@I
M*3L*?0H*)'1I=&QE(#T@7R@B37D@4&]R=&%L($QA>6]U="(I.PIR97%U:7)E
M($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U
M:7)E($A/4D1%7U1%35!,051%4R`N("<O<&]R=&%L+VUE;G4N:6YC)SL*)&YO
M=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T
M=7,G*2D["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]P;W)T86PO961I
M="YI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O
M;W1E<BYI;F,G.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<```````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`Q,``Q,#0Q-S,V,S`P-P`P
M,C$S-3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<"QV(#$N,SDN,3`N-R`R,#`V+S`S+S`X(#$X.C`P.C4V(&-H
M=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T:6]N
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH*:68@
M*"%!=71H.CII<T%U=&AE;G1I8V%T960H*2D@>PH@("`@2&]R9&4Z.F%U=&AE
M;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\O($=E="!F=6QL(&YA
M;64@9F]R('1I=&QE"B1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N
M*"D["B1F=6QL;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN86UE
M)RD["FEF("AE;7!T>2@D9G5L;&YA;64I*2!["B`@("`D9G5L;&YA;64@/2!!
M=71H.CIG971!=71H*"D["GT*"B\O($=E="!R969R97-H(&EN=&5R=F%L+@II
M9B`H)'!R969S+3YG971686QU92@G<W5M;6%R>5]R969R97-H7W1I;64G*2D@
M>PH@("`@)')E9G)E<VA?=&EM92`]("1P<F5F<RT^9V5T5F%L=64H)W-U;6UA
M<GE?<F5F<F5S:%]T:6UE)RD["B`@("`D<F5F<F5S:%]U<FP@/2!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A;"\G*3L*?0H*+R\@3&]A
M9"!L87EO=70@9G)O;2!P<F5F97)E;F-E<RX*)&QA>6]U=%]P<F5F(#T@)'!R
M969S+3YG971686QU92@G<&]R=&%L7VQA>6]U="<I.PII9B`H(21L87EO=71?
M<')E9BD@>PH@("`@)&QA>6]U=%]P<F5F(#T@2&]R9&5?0FQO8VM?0V]L;&5C
M=&EO;CHZ9V5T1FEX961";&]C:W,H*3L*?0HD=FEE=R`](&YE=R!(;W)D95]"
M;&]C:U],87EO=71?5FEE=R@D;&%Y;W5T7W!R968I.PHD;&%Y;W5T7VAT;6P@
M/2`D=FEE=RT^=&](=&UL*"D["B1C<W-!<'!S(#T@)'9I97<M/F=E=$%P<&QI
M8V%T:6]N<R@I.PHD;&EN:U1A9W,@/2`D=FEE=RT^9V5T3&EN:U1A9W,H*3L*
M"B1T:71L92`](%\H(DUY(%!O<G1A;"(I.PIR97%U:7)E($A/4D1%7U1%35!,
M051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O<&]R=&%L+VUE;G4N:6YC)SL*)&YO=&EF:6-A=&EO;BT^
M;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["F5C:&\@
M)&QA>6]U=%]H=&UL.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-S``,3`T,3<S-C,P,#<`,#(Q-3(R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP+'8@,BXQ-2XQ,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,30@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H
M)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*
M<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E
M<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]-;V)I;&4N<&AP)SL*"FEF("@A075T:#HZ9V5T075T:"@I*2![
M"B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@571I;#HZ861D4&%R86UE=&5R
M*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G;&]G:6XN<&AP)RP@=')U92DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U
M<FPG+"!(;W)D93HZ<V5L9E5R;"@I+"!F86QS92DI.PH@("`@97AI=#L*?0H*
M)&ED96YT:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*3L*)&9U;&QN86UE
M(#T@)&ED96YT:71Y+3YG971686QU92@G9G5L;&YA;64G*3L*:68@*&5M<'1Y
M*"1F=6QL;F%M92DI('L*("`@("1F=6QL;F%M92`]($%U=&@Z.F=E=$%U=&@H
M*3L*?0H*)&T@/2`F;F5W($AO<F1E7TUO8FEL92A?*")796QC;VUE(BDI.PHD
M;2T^861D*&YE=R!(;W)D95]-;V)I;&5?=&5X="AS<')I;G1F*%\H(E=E;&-O
M;64L("5S(BDL("1F=6QL;F%M92DI*3L*"B\O($UE<W-Y('=A>2!O9B!L:6YK
M:6YG('1O(&%C=&EV92!A<'!S('1H870@<W5P<&]R="!M;V)I;&4*+R\@9&5V
M:6-E<RX@4VAO=6QD(&)E(&UA9&4@;6]R92!E;&5G86YT(&%T('-O;64@<&]I
M;G0N"FEF("@A96UP='DH)')E9VES=')Y+3YA<'!L:6-A=&EO;G-;)VUI;7`G
M75LG<W1A='5S)UTI("8F"B`@("`D<F5G:7-T<GDM/F%P<&QI8V%T:6]N<ULG
M;6EM<"==6R=S=&%T=7,G72`A/2`G:6YA8W1I=F4G*2!["B`@("`D;2T^861D
M*&YE=R!(;W)D95]-;V)I;&5?;&EN:R@D<F5G:7-T<GDM/F=E="@G;F%M92<L
M("=M:6UP)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(
M;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VUI;7`G*2`N
M("<O)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5G
M:7-T<GDM/F=E="@G;F%M92<L("=M:6UP)RDI*3L*?0H*)&TM/F1I<W!L87DH
M*3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'``````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-C$T,@`Q,#0Q-S,V,S`P-P`P,C$U-C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`L=B`R+C(V+C8N,R`R,#`V
M+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U)00RYP:'`G
M.PH*:68@*"%!=71H.CII<T%U=&AE;G1I8V%T960H*2D@>PH@("`@2&]R9&4Z
M.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B1R<&-?<V5R
M=F5R<R`]($!U;G-E<FEA;&EZ92@D<')E9G,M/F=E=%9A;'5E*"=R96UO=&5?
M<W5M;6%R:65S)RDI.PII9B`H(6ES7V%R<F%Y*"1R<&-?<V5R=F5R<RDI('L*
M("`@("1R<&-?<V5R=F5R<R`](&%R<F%Y*"D["GT*"B1A8W1I;VY)1"`](%5T
M:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PH*+R\@2&%N9&QE(&-L:65N
M=',@=VET:&]U="!J879A<V-R:7!T+@II9B`H:7-?;G5L;"@D86-T:6]N240I
M*2!["B`@("!I9B`H571I;#HZ9V5T4&]S="@G961I="<I*2!["B`@("`@("`@
M)&%C=&EO;DE$(#T@)V5D:70G.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=%!O
M<W0H)W-A=F4G*2D@>PH@("`@("`@("1A8W1I;VY)1"`]("=S879E)SL*("`@
M('T@96QS96EF("A5=&EL.CIG9710;W-T*"=D96QE=&4G*2D@>PH@("`@("`@
M("1A8W1I;VY)1"`]("=D96QE=&4G.PH@("`@?0I]"@HO*B!2=6X@=&AR;W5G
M:"!T:&4@86-T:6]N(&AA;F1L97)S("HO"G-W:71C:"`H)&%C=&EO;DE$*2![
M"F-A<V4@)W-A=F4G.@H@("`@:68@*"@D=&]?961I="`](%5T:6PZ.F=E=$9O
M<FU$871A*"=E9&ET7W-E<G9E<B<I*2`]/2!N=6QL*2!["B`@("`@("`@)'1O
M7V5D:70@/2!C;W5N="@D<G!C7W-E<G9E<G,I.PH@("`@("`@("1R<&-?<V5R
M=F5R<UM=(#T@87)R87DH*3L*("`@('T*("`@("1R<&-?<V5R=F5R<ULD=&]?
M961I=%U;)W5R;"==("`@(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I.PH@
M("`@)')P8U]S97)V97)S6R1T;U]E9&ET75LG=7-E<B==("`@/2!5=&EL.CIG
M971&;W)M1&%T82@G=7-E<B<I.PH@("`@)')P8U]S97)V97)S6R1T;U]E9&ET
M75LG<&%S<W=D)UT@/2!5=&EL.CIG971&;W)M1&%T82@G<&%S<W=D)RD["B`@
M("`D<')E9G,M/G-E=%9A;'5E*"=R96UO=&5?<W5M;6%R:65S)RP@<V5R:6%L
M:7IE*"1R<&-?<V5R=F5R<RDI.PH@("`@)'!R969S+3YS=&]R92@I.PH@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N('-A=F5D+B(I+"`D<G!C7W-E<G9E<G-;)'1O7V5D:71=
M6R=U<FPG72DL("=H;W)D92YS=6-C97-S)RD["B`@("!B<F5A:SL*"F-A<V4@
M)V1E;&5T92<Z"B`@("`D=&]?9&5L971E(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W-E<G9E<B<I.PH@("`@:68@*"1T;U]D96QE=&4@(3T@+3$I('L*("`@("`@
M("`D9&5L971E9%]S97)V97(@/2`D<G!C7W-E<G9E<G-;)'1O7V1E;&5T95U;
M)W5R;"==.PH@("`@("`@("1S97)V97)?;&ES="`](&%R<F%Y*"D["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)')P8U]S97)V97)S*3L@)&DK
M*RD@>PH@("`@("`@("`@("!I9B`H)&D@/3T@)'1O7V1E;&5T92D@>PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'-E<G9E<E]L:7-T6UT@/2`D<G!C7W-E<G9E<G-;)&E=.PH@("`@("`@
M('T*("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=R96UO=&5?<W5M;6%R:65S
M)RP@<V5R:6%L:7IE*"1S97)V97)?;&ES="DI.PH@("`@("`@("1C:&]S96Y#
M;VQU;6YS(#T@97AP;&]D92@G.R<L("1P<F5F<RT^9V5T5F%L=64H)W-H;W=?
M<W5M;6%R:65S)RDI.PH@("`@("`@(&EF("@D8VAO<V5N0V]L=6UN<R`A/2!A
M<G)A>2@G)RDI('L*("`@("`@("`@("`@)&YE=T-O;'5M;G,@/2!A<G)A>2@I
M.PH@("`@("`@("`@("!F;W)E86-H("@D8VAO<V5N0V]L=6UN<R!A<R`D8VAO
M<V5N0V]L=6UN*2!["B`@("`@("`@("`@("`@("`D8VAO<V5N0V]L=6UN(#T@
M97AP;&]D92@G+"<L("1C:&]S96Y#;VQU;6XI.PH@("`@("`@("`@("`@("`@
M)')E;6]T92`](&5X<&QO9&4H)WPG+"`D8VAO<V5N0V]L=6UN6S!=*3L*("`@
M("`@("`@("`@("`@(&EF("AC;W5N="@D<F5M;W1E*2`A/2`S('Q\("1R96UO
M=&5;,ET@/3T@)&1E;&5T961?<V5R=F5R*2!["B`@("`@("`@("`@("`@("`@
M("`@)&YE=T-O;'5M;G-;72`](&EM<&QO9&4H)RPG+"`D8VAO<V5N0V]L=6UN
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<')E9G,M/G-E=%9A;'5E*"=S:&]W7W-U;6UA<FEE<R<L(&EM<&QO9&4H
M)SLG+"`D;F5W0V]L=6UN<RDI.PH@("`@("`@('T*("`@("`@("`D<')E9G,M
M/G-T;W)E*"D["B`@("`@("`@)')P8U]S97)V97)S(#T@)'-E<G9E<E]L:7-T
M.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(I+"`D9&5L971E9%]S
M97)V97(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@?2!E;'-E('L*("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"XB*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@
M('T*("`@(&)R96%K.PI]"@HO*B!3:&]W('1H92!H96%D97(N("HO"G)E<75I
M<F5?;VYC92`G2&]R9&4O4')E9G,O54DN<&AP)SL*<F5Q=6ER92!(3U)$15]"
M05-%("X@)R]C;VYF:6<O<')E9G,N<&AP)SL*)&%P<"`]("=H;W)D92<["E!R
M969S7U5).CIG96YE<F%T94AE861E<B@G<F5M;W1E)RD["@IR97%U:7)E($A/
M4D1%7U1%35!,051%4R`N("<O<G!C<W5M+W)P8W-U;2YI;F,G.PIR97%U:7)E
M($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<```````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,C4R,S0`,3`T,3<S-C,P,#<`,#(Q-C8V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<"QV(#$N-"XR+C$S(#(P
M,#8O,#,O,C`@,34Z,#`Z,#8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4&%W;&]W
M<VMY(#QM:G!A=VQO=W-K>4!Y86AO;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@HO*BH*("H@1&5T97)M:6YE(&EF('1H92!C=7)R96YT('5S97(@8V%N('-E
M92!A;B!A<'!L:6-A=&EO;BX*("H*("H@0'!A<F%M('-T<FEN9R`@)&%P<"`@
M("`@("`@("!4:&4@87!P;&EC871I;VX@;F%M92X*("H@0'!A<F%M(&%R<F%Y
M("`@)'!A<F%M<R`@("`@("!4:&4@87!P;&EC871I;VXG<R!P87)A;65T97)S
M+@H@*B!`<&%R86T@87)R87D@("8D:&%S0VAI;&1R96X@(%)E9F5R96YC92!T
M;R!A;B!A<G)A>2!T;R!S970@8VAI;&1R96X@9FQA9W,@:6XN"B`J+PIF=6YC
M=&EO;B!C86Y3964H)&%P<"P@)'!A<F%M<RP@)B1H87-#:&EL9')E;BD*>PH@
M("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("!S=&%T:6,@)&-A8VAE(#T@87)R
M87DH*3L*("`@('-T871I8R`D:7-!9&UI;CL*("`@('-T871I8R`D=7-E<CL*
M"B`@("`O+R!)9B!W92!H879E(&$@8V%C:&5D('9A;'5E(&9O<B!T:&ES(&%P
M<&QI8V%T:6]N+"!R971U<FX@:70@;F]W+@H@("`@:68@*&ES<V5T*"1C86-H
M95LD87!P72DI('L*("`@("`@("!R971U<FX@)&-A8VAE6R1A<'!=.PH@("`@
M?0H*("`@("\O($EN:71I86QI>F4@=F%R:6%B;&5S('=E)VQL(&ME97`@=7-I
M;F<@:6X@<W5C8V5S<VEV92!C86QL<R!O;@H@("`@+R\@=&AE(&9I<G-T(&-A
M;&PN"B`@("!I9B`H:7-?;G5L;"@D:7-!9&UI;BDI('L*("`@("`@("`D:7-!
M9&UI;B`]($%U=&@Z.FES061M:6XH*3L*("`@("`@("`D=7-E<B`]($%U=&@Z
M.F=E=$%U=&@H*3L*("`@('T*"B`@("`O+R!#:&5C:R!I9B!T:&4@8W5R<F5N
M="!U<V5R(&AA<R!P97)M:7-S;VX@=&\@<V5E('1H:7,@87!P;&EC871I;VXL
M(&%N9"!I9@H@("`@+R\@=&AE(&%P<&QI8V%T:6]N(&ES(&%C=&EV92X@2&5A
M9&EN9W,@87)E('9I<VEB;&4@=&\@979E<GEO;F4@*&)U="!G970*("`@("\O
M(&9I;'1E<F5D(&]U="!L871E<B!I9B!T:&5Y(&AA=F4@;F\@8VAI;&1R96XI
M+B!!9&UI;FES=')A=&]R<R!A;'=A>7,@<V5E"B`@("`O+R!A;&P@87!P;&EC
M871I;VYS(&5X8V5P="!T:&]S92!M87)K960@)VEN86-T:79E)RX@06YY;VYE
M('=I=&@@4TA/5PH@("`@+R\@<&5R;6ES<VEO;G,@8V%N('-E92!A;B!A<'!L
M:6-A=&EO;BP@8G5T(%)%040@:7,@;F5E9&5D('1O(&%C='5A;&QY('5S90H@
M("`@+R\@=&AE(&%P<&QI8V%T:6]N+B!9;W4@8V%N('5S92!T:&ES(&1I<W1I
M;F-T:6]N('1O('-H;W<@87!P;&EC871I;VYS('1O"B`@("`O+R!G=65S=',@
M=&AA="!T:&5Y(&YE960@=&\@;&]G(&EN('1O('5S92X@268@>6]U(&1O;B=T
M('=A;G0@=&AE;2!T;R!S964*("`@("\O(&%P<',@=&AE>2!C86XG="!U<V4L
M('1H96X@9&]N)W0@9VEV92!G=65S=',@4TA/5R!P97)M:7-S:6]N<R!T;PH@
M("`@+R\@86YY=&AI;F<N"B`@("!I9B`H+R\@1&]N)W0@<VAO=R!A<'!L:6-A
M=&EO;G,@=&AA="!A<F5N)W0@:6YS=&%L;&5D+"!E=F5N(&EF('1H97DG<F4*
M("`@("`@("`O+R!C;VYF:6=U<F5D+@H@("`@("`@("AI<W-E="@D<&%R86US
M6R=F:6QE<F]O="==*2`F)B`A:7-?9&ER*"1P87)A;7-;)V9I;&5R;V]T)UTI
M*2!\?`H*("`@("`@("`O+R!$;VXG="!S:&]W(&)L;V-K<R!O9B!A<'!L:6-A
M=&EO;G,@=&AA="!A<F5N)W0@:6YS=&%L;&5D+@H@("`@("`@("@D<&%R86US
M6R=S=&%T=7,G72`]/2`G8FQO8VLG("8F"B`@("`@("`@("%I<U]D:7(H)')E
M9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)'!A<F%M<ULG87!P)UTI*2D@?'P*
M"B`@("`@("`@+R\@1FEL=&5R(&]U="!E;G1R:65S('1H870@87)E(&1I<V%B
M;&5D+"!H:61D96X@;W(@<VAO=6QD;B=T('-H;W<@=7`*("`@("`@("`O+R!I
M;B!T:&4@;65N=2X*("`@("`@("`D<&%R86US6R=S=&%T=7,G72`]/2`G;F]T
M;V]L8F%R)R!\?"`D<&%R86US6R=S=&%T=7,G72`]/2`G:&ED9&5N)R!\?`H@
M("`@("`@("1P87)A;7-;)W-T871U<R==(#T]("=I;F%C=&EV92<I('L*"B`@
M("`@("`@)&-A8VAE6R1A<'!=(#T@9F%L<V4["@H@("`@?2!E;'-E:68@*"\O
M($AE861I;F=S(&-A;B!A;'=A>7,@8F4@<V5E;BX*("`@("`@("`@("`@("`H
M)'!A<F%M<ULG<W1A='5S)UT@/3T@)VAE861I;F<G*2!\?`H*("`@("`@("`@
M("`@("`O+R!!9&UI;G,@<V5E(&5V97)Y=&AI;F<@=&AA="!M86ME<R!I="!T
M;R!T:&ES('!O:6YT+@H@("`@("`@("`@("`@("@D:7-!9&UI;B!\?`H*("`@
M("`@("`@("`@("`@+R\@57-E<G,@=VAO(&AA=F4@4TA/5R!P97)M:7-S:6]N
M<R!T;R!A8W1I=F4@;W(@8FQO8VL@96YT<FEE<PH@("`@("`@("`@("`@("`O
M+R!S964@=&AE;2X*("`@("`@("`@("`@("`@*"1R96=I<W1R>2T^:&%S4&5R
M;6ES<VEO;B@D87!P+"!015)-4U]32$]7*2`F)@H@("`@("`@("`@("`@("`@
M*"1P87)A;7-;)W-T871U<R==(#T]("=A8W1I=F4G('Q\"B`@("`@("`@("`@
M("`@("`@)'!A<F%M<ULG<W1A='5S)UT@/3T@)V)L;V-K)RDI*2D@>PH*("`@
M("`@("`D8V%C:&5;)&%P<%T@/2!T<G5E.PH*("`@("`@("`O+R!.;W1E('1H
M870@=&AE('!A<F5N="!N;V1E+"!I9B!A;GDL(&AA<R!C:&EL9')E;BX*("`@
M("`@("!I9B`H:7-S970H)'!A<F%M<ULG;65N=5]P87)E;G0G72DI('L*("`@
M("`@("`@("`@)&AA<T-H:6QD<F5N6R1P87)A;7-;)VUE;G5?<&%R96YT)UU=
M(#T@=')U93L*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("\O($-A
M=&-H(&%N>71H:6YG('1H870@9F5L;"!T:')O=6=H+"!A;F0@9&]N)W0@<VAO
M=R!I="X*("`@("`@("`D8V%C:&5;)&%P<%T@/2!F86QS93L*("`@('T*"B`@
M("!R971U<FX@)&-A8VAE6R1A<'!=.PI]"@HO*BH*("H@0G5I;&1S('1H92!M
M96YU('-T<G5C='5R92!D97!E;F1I;F<@;VX@87!P;&EC871I;VX@<&5R;6ES
M<VEO;G,N"B`J+PIF=6YC=&EO;B!B=6EL9$UE;G4H*0I["B`@("!G;&]B86P@
M)&-O;F8L("1R96=I<W1R>3L*"B`@("`D87!P<R`](&%R<F%Y*"D["B`@("`D
M8VAI;&1R96X@/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)')E9VES=')Y+3YA
M<'!L:6-A=&EO;G,@87,@)&%P<"`]/B`D<&%R86US*2!["B`@("`@("`@:68@
M*&-A;E-E92@D87!P+"`D<&%R86US+"`D8VAI;&1R96XI*2!["B`@("`@("`@
M("`@("1A<'!S6R1A<'!=(#T@)'!A<F%M<SL*("`@("`@("!]"B`@("!]"@H@
M("`@)&UE;G4@/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)&%P<',@87,@)&%P
M<"`]/B`D<&%R86US*2!["B`@("`@("`@+R\@1FEL=&5R(&]U="!A;&P@:&5A
M9&EN9W,@=VET:&]U="!C:&EL9')E;BX*("`@("`@("!I9B`H)'!A<F%M<ULG
M<W1A='5S)UT@/3T@)VAE861I;F<G("8F(&5M<'1Y*"1C:&EL9')E;ELD87!P
M72DI('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@
M("`D;65N=5LD87!P72`]("1P87)A;7,["B`@("!]"@H@("`@+R\@061D('1H
M92!A9&UI;FES=')A=&EO;B!M96YU(&EF('1H92!U<V5R(&ES(&%N(&%D;6EN
M+@H@("`@:68@*$%U=&@Z.FES061M:6XH*2D@>PH@("`@("`@("1M96YU6R=A
M9&UI;FES=')A=&EO;B==(#T@87)R87DH)VYA;64G(#T^(%\H(D%D;6EN:7-T
M<F%T:6]N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:6-O;B<@/3X@)')E9VES=')Y+3YG971);6%G941I<B@I("X@)R]A
M9&UI;FES=')A=&EO;BYP;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W-T871U<R<@/3X@)VAE861I;F<G*3L*"B`@("`@
M("`@9F]R96%C:"`H)')E9VES=')Y+3YL:7-T07!P<R@I(&%S("1A<'`I('L*
M("`@("`@("`@("`@:68@*"$D<F5G:7-T<GDM/FAA<TUE=&AO9"@G861M:6Y?
M;&ES="<L("1A<'`I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&QI<W0@/2`D<F5G:7-T<GDM/F-A
M;&Q">5!A8VMA9V4H)&%P<"P@)V%D;6EN7VQI<W0G*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E
M86-H("@D;&ES="!A<R`D;65T:&]D(#T^("1V86QS*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&%P<"`A/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A<'`I.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'9A;'-;)VYA;64G72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@+CT@)R`G("X@)'9A;'-;
M)VYA;64G73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@2&]R9&4Z
M.G-T<FEP06-C97-S2V5Y*"1V86QS6R=N86UE)UTI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&EC;VX@/2!I<W-E="@D=F%L<ULG:6-O
M;B==*2`_("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)&%P<"D@+B`G+R<@+B`D
M=F%L<ULG:6-O;B==(#H@)')E9VES=')Y+3YG970H)VEC;VXG+"`D87!P*3L*
M"B`@("`@("`@("`@("`@("`D;65N=5LG861M:6YI<W1R871I;VY?)R`N("1A
M<'`@+B`G7R<@+B`D;65T:&]D72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=N86UE)R`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`G:6-O
M;B<@/3X@)&EC;VXL"B`@("`@("`@("`@("`@("`@("`@)W-T871U<R<@/3X@
M)V%C=&EV92<L"B`@("`@("`@("`@("`@("`@("`@)VUE;G5?<&%R96YT)R`]
M/B`G861M:6YI<W1R871I;VXG+`H@("`@("`@("`@("`@("`@("`@("=U<FPG
M(#T^($AO<F1E.CIU<FPH)')E9VES=')Y+3YA<'!L:6-A=&EO;E=E8E!A=&@H
M)'9A;'-;)VQI;FLG72P@)&%P<"DI+`H@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@:68@*$AO<F1E
M.CIS:&]W4V5R=FEC92@G;W!T:6]N<R<I("8F"B`@("`@("`@)&-O;F9;)W!R
M969S)UU;)V1R:79E<B==("$]("<G("8F("1C;VYF6R=P<F5F<R==6R=D<FEV
M97(G72`A/2`G;F]N92<I('L*("`@("`@("`D;65N=5LG;W!T:6]N<R==(#T@
M87)R87DH)VYA;64G(#T^(%\H(D]P=&EO;G,B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"D@+B`G+W!R969S+G!N9R<I.PH*("`@("`@("`O
M*B!'970@82!L:7-T(&]F(&-O;F9I9W5R86)L92!A<'!L:6-A=&EO;G,N("HO
M"B`@("`@("`@)'!R969S7V%P<',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A
M8V@@*"1R96=I<W1R>2T^87!P;&EC871I;VYS(&%S("1A<'!L:6-A=&EO;B`]
M/B`D<&%R86US*2!["B`@("`@("`@("`@(&EF("@D<&%R86US6R=S=&%T=7,G
M72`]/2`G:&5A9&EN9R<@?'P*("`@("`@("`@("`@("`@("1P87)A;7-;)W-T
M871U<R==(#T]("=B;&]C:R<@?'P*("`@("`@("`@("`@("`@("%F:6QE7V5X
M:7-T<R@D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P;&EC871I;VXI
M("X@)R]C;VYF:6<O<')E9G,N<&AP)RDI('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#:&5C:R!I
M9B!T:&4@8W5R<F5N="!U<V5R(&AA<R!P97)M:7-S:6]N('1O('-E92!T:&ES
M"B`@("`@("`@("`@("`J(&%P<&QI8V%T:6]N+"!A;F0@:68@=&AE(&%P<&QI
M8V%T:6]N(&ES(&%C=&EV92X*("`@("`@("`@("`@("H@061M:6YI<W1R871O
M<G,@86QW87ES('-E92!A;&P@87!P;&EC871I;VYS+B`J+PH@("`@("`@("`@
M("!I9B`H*$%U=&@Z.FES061M:6XH*2`F)B`D<&%R86US6R=S=&%T=7,G72`A
M/2`G:6YA8W1I=F4G*2!\?`H@("`@("`@("`@("`@("`@*"1R96=I<W1R>2T^
M:&%S4&5R;6ES<VEO;B@D87!P;&EC871I;VXI("8F"B`@("`@("`@("`@("`@
M("`@*"1P87)A;7-;)W-T871U<R==(#T]("=A8W1I=F4G*2DI('L*("`@("`@
M("`@("`@("`@("1P<F5F<U]A<'!S6R1A<'!L:6-A=&EO;ET@/2!?*"1P87)A
M;7-;)VYA;64G72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@A96UP='DH)'!R969S7V%P<'-;)VAO<F1E)UTI*2!["B`@("`@("`@
M("`@("1M96YU6R=O<'1I;VYS7R<@+B`G:&]R9&4G72`](&%R<F%Y*"=N86UE
M)R`]/B!?*")';&]B86P@3W!T:6]N<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1A='5S)R`]/B`G86-T
M:79E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VUE;G5?<&%R96YT)R`]/B`G;W!T:6]N<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N
M)R`]/B`D<F5G:7-T<GDM/F=E="@G:6-O;B<L("=H;W)D92<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7)L
M)R`]/B!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!R969S+G!H
M<#]A<'`]:&]R9&4G*2D["B`@("`@("`@("`@('5N<V5T*"1P<F5F<U]A<'!S
M6R=H;W)D92==*3L*("`@("`@("!]"@H@("`@("`@(&%S;W)T*"1P<F5F<U]A
M<'!S*3L*("`@("`@("!F;W)E86-H("@D<')E9G-?87!P<R!A<R`D87!P(#T^
M("1N86UE*2!["B`@("`@("`@("`@("1M96YU6R=O<'1I;VYS7R<@+B`D87!P
M72`](&%R<F%Y*"=N86UE)R`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T871U<R<@/3X@)V%C=&EV
M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=M96YU7W!A<F5N="<@/3X@)V]P=&EO;G,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)')E
M9VES=')Y+3YG970H)VEC;VXG+"`D87!P*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P<F5F<RYP:'`_87!P/2<@+B`D87!P
M*2D["B`@("`@("`@?0H@("`@?0H*("`@(&EF("A!=71H.CII<T%U=&AE;G1I
M8V%T960H*2D@>PH@("`@("`@("1M96YU6R=L;V=O=70G72`](&%R<F%Y*"=N
M86UE)R`]/B!?*"),;V<@;W5T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("1R96=I<W1R>2T^9V5T26UA
M9V5$:7(H*2`N("<O;&]G;W5T+G!N9R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=L
M;V=O=70G+"`G:&]R9&4G+"!T<G5E*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=&%R9V5T)R`]/B`G7W!A<F5N="<I.PH@("`@?2!E;'-E
M('L*("`@("`@("`D;65N=5LG;&]G:6XG72`](&%R<F%Y*"=N86UE)R`]/B!?
M*"),;V<@:6XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S
M=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VEC;VXG(#T^("1R96=I<W1R>2T^9V5T26UA9V5$:7(H*2`N("<O
M;&]G:6XN<&YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U
M<FPG(#T^($AO<F1E.CIG971397)V:6-E3&EN:R@G;&]G:6XG+"`G:&]R9&4G
M+"!T<G5E+"!F86QS92DI.PH@("`@?0H*("`@(')E='5R;B`D;65N=3L*?0H*
M0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O5')E92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T)L
M;V-K+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO0V]L;&5C=&EO
M;BYP:'`G.PH*:68@*"%!=71H.CIG971!=71H*"D@)B8@(21C;VYF6R=M96YU
M)UU;)V%L=V%Y<R==*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL
M=7)E4F5D:7)E8W0H*3L*?0H*)&ES7VUO>F)A<B`]("AB;V]L*55T:6PZ.F=E
M=$9O<FU$871A*"=M;WIB87(G*3L*"B\O(%-E="!U<"!T:&4@=')E92X*)'1R
M964@/2`F2&]R9&5?5')E93HZ<VEN9VQE=&]N*"=H;W)D95]M96YU)RP@)VIA
M=F%S8W)I<'0G*3L*)'1R964M/G-E=$]P=&EO;BAA<G)A>2@G=&%R9V5T)R`]
M/B`D:7-?;6]Z8F%R(#\@)U]C;VYT96YT)R`Z("=H;W)D95]M86EN)RDI.PH*
M)&UE;G4@/2!B=6EL9$UE;G4H*3L*9F]R96%C:"`H)&UE;G4@87,@)&%P<"`]
M/B`D<&%R86US*2!["B`@("!I9B`H)'!A<F%M<ULG<W1A='5S)UT@/3T@)V)L
M;V-K)RD@>PH@("`@("`@("1B;&]C:R`]("9(;W)D95]";&]C:U]#;VQL96-T
M:6]N.CIG971";&]C:R@D<&%R86US6R=A<'`G72P@)'!A<F%M<ULG8FQO8VMN
M86UE)UTI.PH@("`@("`@(&EF("AI<U]A*"1B;&]C:RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)&)L;V-K+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("`D8FQO8VLM/F)U:6QD
M5')E92@D=')E92P@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E
M="@D<&%R86US6R=M96YU7W!A<F5N="==*2`_("1P87)A;7-;)VUE;G5?<&%R
M96YT)UT@.B!N=6QL*3L*("`@('T@96QS92!["B`@("`@("`@+R\@3F5E9"!T
M;R!R=6X@=&AE(&YA;64@=&AR;W5G:"!G971T97AT('-I;F-E('1H92!U<V5R
M)W,*("`@("`@("`O+R!L;V-A;&4@;6%Y(&YO="!H879E(&)E96X@;&]A9&5D
M('=H96X@<F5G:7-T<GDN<&AP('=A<PH@("`@("`@("\O('!A<G-E9"X*("`@
M("`@("`D;F%M92`](%\H)'!A<F%M<ULG;F%M92==*3L*"B`@("`@("`@+R\@
M2&5A9&EN9W,@:&%V92!N;R!W96)R;V]T.R!T:&5Y)W)E(&IU<W0@8V]N=&%I
M;F5R<R!F;W(@;W1H97(*("`@("`@("`O+R!M96YU(&ET96US+@H@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=U<FPG72DI('L*("`@("`@("`@("`@)'5R
M;"`]("1P87)A;7-;)W5R;"==.PH@("`@("`@('T@96QS96EF("@D<&%R86US
M6R=S=&%T=7,G72`]/2`G:&5A9&EN9R<@?'P@(6ES<V5T*"1P87)A;7-;)W=E
M8G)O;W0G72DI('L*("`@("`@("`@("`@)'5R;"`](&YU;&P["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)'!A<F%M
M<ULG=V5B<F]O="==("X@)R\G("X@*&ES<V5T*"1P87)A;7-;)VEN:71I86Q?
M<&%G92==*2`_("1P87)A;7-;)VEN:71I86Q?<&%G92==(#H@)R<I*3L*("`@
M("`@("!]"@H@("`@("`@("1N;V1E7W!A<F%M<R`](&%R<F%Y*"=U<FPG(#T^
M("1U<FPL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1A<F=E="<@
M/3X@:7-S970H)'!A<F%M<ULG=&%R9V5T)UTI(#\@)'!A<F%M<ULG=&%R9V5T
M)UT@.B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N
M)R`]/B!I<W-E="@D<&%R86US6R=I8V]N)UTI(#\@)'!A<F%M<ULG:6-O;B==
M(#H@)')E9VES=')Y+3YG970H)VEC;VXG+"`D87!P*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:6-O;F1I<B<@/3X@)R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`D=')E92T^861D3F]D92@D
M87!P+"`A96UP='DH)'!A<F%M<ULG;65N=5]P87)E;G0G72D@/R`D<&%R86US
M6R=M96YU7W!A<F5N="==(#H@;G5L;"P@)&YA;64L(#`L(&9A;'-E+"`D;F]D
M95]P87)A;7,I.PH@("`@?0I]"@HO+R!)9B!W92=R92!S97)V:6YG(&$@<F5Q
M=65S="!T;R!T:&4@2E,@=7!D871E(&-L:65N="P@:G5S="!R96YD97(@=&AE
M"B\O('5P9&%T960@;F]D92!J879A<V-R:7!T+@II9B`H571I;#HZ9V5T1F]R
M;41A=&$H)VAT='!C;&EE;G0G*2D@>PH@("`@:&5A9&5R*"=#;VYT96YT+51Y
M<&4Z('1E>'0O:F%V87-C<FEP=#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R
M<V5T*"DI.PH@("`@2&]R9&4Z.FEN;&EN95-C<FEP=$9I;&5S*"D["B`@("!E
M8VAO("1T<F5E+3YR96YD97).;V1E1&5F:6YI=&EO;G,H*3L*("`@(&5X:70[
M"GT*"B1R=&P@/2!I<W-E="@D;FQS6R=R=&PG75LD;&%N9W5A9V5=*3L*)&)O
M9'E#;&%S<R`]("=S:61E8F%R)SL*:68@*"1B<F]W<V5R+3YH87-1=6ER:R@G
M<V-R;VQL8F%R7VEN7W=A>2<I*2!["B`@("`D8F]D>4-L87-S("X]("<@<V-R
M;VQL8F%R+7%U:7)K)SL*?0I(;W)D93HZ861D4V-R:7!T1FEL92@G:'1T<&-L
M:65N="YJ<R<L("=H;W)D92<L('1R=64I.PI(;W)D93HZ861D4V-R:7!T1FEL
M92@G:&ED96%B;&4N:G,G+"`G:&]R9&4G+"!T<G5E*3L*<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+W!O<G1A;"]S:61E8F%R+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<```
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R,S4S`#$P-#$W,S8S
M,#`W`#`R,34V,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<"QV(#$N,RXR+C,@,C`P-B\P,B\Q,"`P-#HU.#HR
M-B!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!+87)S
M=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*9G5N8W1I;VX@;&]A9$-A=&5G;W)I97,H)&1E=FEC92D*>PH@("`@
M9VQO8F%L("1D="P@)&-A=&5G;W)I97--87`L("1M:7-S:6YG4V5R=F5R0V%T
M96=O<FEE<SL*("`@("1M87`@/2`D9'0M/F=E=$]B:F5C="@D9&5V:6-E"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)SIC871E9V]R:65S)RD["B`@
M("!I9B`H:7-?82@D;6%P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H*("`@("1C871E9V]R:65S36%P(#T@)&UA<"T^
M9V5T*"=M87`G*3L*("`@("1M:7-S:6YG4V5R=F5R0V%T96=O<FEE<R`]("1M
M87`M/F=E="@G;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,G*3L*"B`@("!R971U
M<FX@=')U93L*?0H*9G5N8W1I;VX@<W1O<F5#871E9V]R:65S*"1D979I8V4I
M"GL*("`@(&=L;V)A;"`D9'0L("1C871E9V]R:65S36%P+"`D;6ES<VEN9U-E
M<G9E<D-A=&5G;W)I97,["@H@("`@:68@*"%I<U]A<G)A>2@D8V%T96=O<FEE
M<TUA<"DI('L*("`@("`@("!R971U<FX[("\O(&YO=&AI;F<@=&\@9&\*("`@
M('T*"B`@("`D;6%P(#T@)FYE=R!$871A5')E94]B:F5C="@D9&5V:6-E("X@
M)SIC871E9V]R:65S)RD["B`@("`D;6%P+3YS970H)VUA<"<L("1C871E9V]R
M:65S36%P*3L*("`@("1M87`M/G-E="@G;6ES<VEN9U-E<G9E<D-A=&5G;W)I
M97,G+"`D;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,I.PH*("`@("1R(#T@)&1T
M+3YA9&0H)&UA<"D["B`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("\O($]B:F5C="!A;')E861Y(&5X:7-T<SH@=7!D871E(&EN
M<W1E860N"B`@("`@("`@)'(@/2`D9'0M/G5P9&%T941A=&$H)&UA<"D["B`@
M("!]"GT*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI
M8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4')E9G,O54DN<&AP
M)SL*"FEF("@A075T:#HZ:7-!=71H96YT:6-A=&5D*"DI('L*("`@($AO<F1E
M.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HD9')I=F5R
M(#T@)$=,3T)!3%-;)V-O;F8G75LG9&%T871R964G75LG9')I=F5R)UT["B1P
M87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1D
M<FEV97(I.PHD<&%R86US(#T@87)R87E?;65R9V4H)'!A<F%M<RP@87)R87DH
M("=G<F]U<"<@/3X@)W-Y;F-M;"<@*2D["@HD9'0@/2`F1&%T851R964Z.G-I
M;F=L971O;B@D9')I=F5R+"`D<&%R86US*3L*"B\J(%5S97)N86UE(&ES('5S
M960@87,@<F]O="!F;W(@<WEN8VUL(&1A=&%T<F5E+B`@*$9O<B!H:7-T;W)I
M8PH@*B!R96%S;VYS+BD@*B\*)'5S97)N86UE(#T@075T:#HZ9V5T075T:"@I
M.PHD9W)O=7`@/2`G<WEN8VUL)SL@+R\@<')E9F5R96YC92!G<F]U<`H*)&%C
M=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD["G-W:71C
M:"`H)&%C=&EO;DE$*2!["F-A<V4@)V1E;&5T96%N8VAO<B<Z"B`@("`D9&5V
M:6-E:60@/2!5=&EL.CIG971&;W)M1&%T82@G9&5V:6-E:60G*3L*("`@("1D
M8B`](%5T:6PZ.F=E=$9O<FU$871A*"=D8B<I.PH@("`@)&ED(#T@)'5S97)N
M86UE("X@)SHG("X@)&1E=FEC96ED("X@)SIS=6UM87)Y.B<@+B`D9&(["B`@
M("`D:60@/2`D9'0M/G)E;6]V92@D:60L9F%L<V4I.PH@("`@:68@*&ES7V$H
M)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"AS<')I;G1F*%\H(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<R(I+"`D:60M/F=E=$UE<W-A9V4H*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92!["B`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"A?*"(D:60@4WEN8R!A;F-H;W(@9F]R(&1E
M=FEC92`G)&1E=FEC96ED)R!D871A8F%S92`G)&1B)R!D96QE=&5D+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@('T*("`@(&)R96%K.PH*8V%S92`G9&5L971E;&]G)SH*("`@("1I9"`]
M("1D="T^<F5M;W9E*"=P<F5V:6]U<U-Y;F-,;V<G+"!F86QS92D["B`@("!I
M9B`H:7-?82@D:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R;W(@9&5L971I;F<@<WEN8R!L
M;V<Z("5S(BDL("1I9"T^9V5T365S<V%G92@I*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E('L*("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E-Y;F,@;&]G(&1E;&5T960B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YS=6-C97-S
M)RD["B`@("!]"B`@("!B<F5A:SL*"B!C87-E("=U<&1A=&5?8V%T96=O<FEE
M<R<Z"B`@("`D9&5V:6-E(#T@571I;#HZ9V5T1F]R;41A=&$H)V1E=FEC92<I
M.PH@("`@;&]A9$-A=&5G;W)I97,H)&1E=FEC92D["@H@("`@9F]R96%C:"`H
M)%]03U-4(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@:68@*'-U8G-T
M<B@D:V5Y+"`P+"`Y*2`]/2`G8V%T96=O<GDZ)RD@>PH@("`@("`@("`@("`D
M8V%T96=O<GD@/2!S=6)S='(H)&ME>2PY*3L*("`@("`@("`@("`@;&ES="@L
M)&-A=&5G;W)Y*2`](&5X<&QO9&4H)SHG+"`D:V5Y+#(I.PH@("`@("`@("`@
M("`D=F%L=64@/2!5=&EL.CIG971&;W)M1&%T82@D:V5Y*3L*("`@("`@("`@
M("`@)&-A=&5G;W)I97--87!;)&-A=&5G;W)Y72`]("1V86QU93L*("`@("`@
M("`@("`@=6YS970H)&UI<W-I;F=397)V97)#871E9V]R:65S6R1V86QU95TI
M.PH@("`@("`@('T*("`@('T*("`@('-T;W)E0V%T96=O<FEE<R@D9&5V:6-E
M*3L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B36%P<&EN9W,@<W1O<F5D
M+B(I*3L*"B`@("!B<F5A:SL*?0H*+RH@4VAO=R!T:&4@:&5A9&5R+B`J+PIR
M97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+U5)+G!H<"<["G)E<75I<F4@2$]2
M1$5?0D%312`N("<O8V]N9FEG+W!R969S+G!H<"<["B1A<'`@/2`G:&]R9&4G
M.PH*4')E9G-?54DZ.FAA;F1L949O<FTH)&=R;W5P+"`D<')E9G,I.PI0<F5F
M<U]523HZ9V5N97)A=&5(96%D97(H)&=R;W5P*3L*"B\O($!T;V1O.B!M;W9E
M('1H:7,@=&\@=&5M<&QA=&4*/SX*"CQF;W)M(&UE=&AO9#TB<&]S="(@;F%M
M93TB<')E9G,B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ07!P;&EC871I
M;VY54DPH)R]S97)V:6-E<R]P<F5F<RYP:'`G*2`_/B(^"CQI;G!U="!T>7!E
M/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB=7!D871E7W!R969S
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)G<F]U<"(@=F%L=64]
M(CP_<&AP(&5C:&\@)&=R;W5P(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N
M(B!N86UE/2)A<'`B('9A;'5E/2)H;W)D92(@+SX*4V]R<GDL(&YO(&-O;F9I
M9W5R86)L92!O<'1I;VYS('EE="X*4V5E(#QA(&AR968](FAT='`Z+R]W:6MI
M+FAO<F1E+F]R9R]3>6YC2&]W5&\B/E-Y;F,@2&]W5&\\+V$^(&9O<B!F=7)T
M:&5R(&EN9F]R;6%T:6]N+@H\/W!H<"`O*B`D:&5L<&QI;FL])R<[("1P<F5F
M/2=S>6YC;6Q?8W)E871E7VQO9R<[(')E<75I<F4@)')E9VES=')Y+3YG970H
M)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]P<F5F<R]C:&5C:V)O>"YI;F,G
M("HO(#\^"@H\<"!C;&%S<STB;F]W<F%P(CX*(#QI;G!U="!T>7!E/2)S=6)M
M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2)3879E($]P=&EO;G,B("\^"B`\
M:6YP=70@='EP93TB<F5S970B(&-L87-S/2)B=71T;VXB('9A;'5E/2)5;F1O
M($-H86YG97,B("\^"B`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T
M=&]N(B!V86QU93TB4F5T=7)N('1O($]P=&EO;G,B(&]N8VQI8VL](F1O8W5M
M96YT+G!R969S+F%C=&EO;DE$+G9A;'5E/3`[(&1O8W5M96YT+G!R969S+F=R
M;W5P+G9A;'5E/2<G.R!D;V-U;65N="YP<F5F<RYS=6)M:70H*3LB("\^"CPO
M<#X*/"]F;W)M/@H\/W!H<`HD:60@/2`D9'0M/F=E=$ED*"1U<V5R;F%M92D[
M"@HD9&5V:6-E<R`]("1D="T^9V5T0GE)9"A$051!5%)%15]&3U)-051?1DQ!
M5"P@)&ED+"!T<G5E+`H@("`@("`@("`@("`@("`@("`@("!$051!5%)%15]2
M3T]4+#$I.PH*:68@*&ES7V%R<F%Y*"1D979I8V5S*2`F)B!C;W5N="@D9&5V
M:6-E<RD@/B`Q*2!["B`@("!A<G)A>5]S:&EF="@D9&5V:6-E<RD["@HO+R!`
M=&]D;SH@;6]V92!T;R!T96UP;&%T90H_/@H\9&EV(&-L87-S/2)H96%D97(B
M/@H@/#]P:'`@96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ<V5L9E523"@I+"!?
M*")2969R97-H(BDI("X@2&]R9&4Z.FEM9R@G<F5L;V%D+G!N9R<L(%\H(E)E
M;&]A9"(I+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@
M/SX\+V$^"B!4:6UE<W1A;7!S(&]F('-U8V-E<W-F=6P@<WEN8R!S97-S:6]N
M<PH\+V1I=CX*/'1A8FQE(&-L87-S/2)S=')I<&5D(B`^"B`\='(^"B`@/'1H
M/D1E=FEC93PO=&@^/'1H/D1A=&%B87-E/"]T:#X\=&@^4V5R=F5R+513/"]T
M:#X\=&@^0VQI96YT+513/"]T:#X*("`\=&@^1&5L971E/"]T:#X*(#PO='(^
M"@H\/W!H<`H@("`@9F]R96%C:"`H)&1E=FEC97,@87,@)&1E=FEC92D@>PH@
M("`@("`@("1D979I8V5?;F%M92`](&%R<F%Y7W!O<"AE>'!L;V1E*"<Z)RP@
M)&1E=FEC92DI.PH*("`@("`@("`D:60@/2`D9'0M/F=E=$ED*"1D979I8V4@
M+B`G.G-U;6UA<GDG*3L*("`@("`@("`D<W5M;6%R:65S(#T@)&1T+3YG971"
M>4ED*$1!5$%44D5%7T9/4DU!5%]44D5%+"`D:60L(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1$%40512145?4D]/5"P@,BD[
M"@H@("`@("`@(&EF("AI<U]A<G)A>2@D<W5M;6%R:65S6R1I9%TI*2!["B`@
M("`@("`@("`@("1O(#T@)B`D9'0M/F=E=$]B:F5C=',H87)R87E?:V5Y<R@D
M<W5M;6%R:65S6R1I9%TI*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1O(&%S
M("1O;RD@>PH@("`@("`@("`@("`@("`@)'0@/2!E>'!L;V1E*"<Z)RP@)&]O
M+3YG971.86UE*"DI.PH@("`@("`@("`@("`@("`@)&1B(#T@87)R87E?<&]P
M*"1T*3L*("`@("`@("`@("`@("`@("1S82`]("1O;RT^9V5T*"=397)V97)!
M;F-H;W(G*3L*("`@("`@("`@("`@("`@("1C82`]("1O;RT^9V5T*")#;&EE
M;G1!;F-H;W(B*3L*"B`@("`@("`@("`@("`@("`O+R!`=&]D;SH@;6]V92!T
M;R!T96UP;&%T90H@("`@("`@("`@("`@("`@96-H;R`G/'1R/CQT9#XG("X@
M)&1E=FEC95]N86UE("X@)SPO=&0^/'1D/B<@+B`D9&(@+B`G/"]T9#X\=&0^
M)R`N"B`@("`@("`@("`@("`@("`@("`@<W1R9G1I;64H)'!R969S+3YG9716
M86QU92@G9&%T95]F;W)M870G*2`N("<@)4@Z)4TG+"!A<G)A>5]P;W`H)'-A
M*2D@+@H@("`@("`@("`@("`@("`@("`@("<\+W1D/CQT9#XG("X@87)R87E?
M<&]P*"1C82D@+B`G/"]T9#X\=&0^)R`N"B`@("`@("`@("`@("`@("`@("`@
M)SQF;W)M(&UE=&AO9#TB<&]S="(^/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB9&5V:6-E:60B('9A;'5E/2(G("X*("`@("`@("`@("`@("`@("`@("`D
M9&5V:6-E7VYA;64@+B`G(B\^)R`N"B`@("`@("`@("`@("`@("`@("`@)SQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB9&5L
M971E86YC:&]R(B`O/B<@+@H@("`@("`@("`@("`@("`@("`@("<\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)D8B(@=F%L=64](B<@+B`D9&(@+B`G(B\^
M)R`N"B`@("`@("`@("`@("`@("`@("`@)SQI;G!U="!T>7!E/2)S=6)M:70B
M(&-L87-S/2)B=71T;VXB('9A;'5E/2)$96QE=&4B/CPO9F]R;3XG("X*("`@
M("`@("`@("`@("`@("`@("`G/"]T9#X\+W1R/B<["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"B`@("!E8VAO("<\+W1A8FQE/B<["GT*"B\O($-A
M=&5G;W)Y(&AA;F1L:6YG+@IR97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`G.PHD8TUA;F%G97(@/2`F;F5W(%!R969S7T-A
M=&5G;W)Y36%N86=E<B@I.PH*9F]R96%C:"`H)&1E=FEC97,@87,@)&1E=FEC
M92D@>PH@("`@)&1E=FEC95]N86UE(#T@87)R87E?<&]P*&5X<&QO9&4H)SHG
M+"`D9&5V:6-E*2D["@H@("`@:68@*"%L;V%D0V%T96=O<FEE<R@D9&5V:6-E
M*2D@>PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0HO+W9A<E]D=6UP*"1C;&EE
M;@H@("`@)&D@/2`P.PHO+R!`=&]D;SH@;6]V92!T;R!T96UP;&%T90H_/@H\
M9F]R;2!M971H;V0](G!O<W0B(&YA;64](G!R969S(B!A8W1I;VX](CP_<&AP
M(&5C:&\@2&]R9&4Z.G-E;&954DPH*2`_/B(^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB=7!D871E7V-A=&5G;W)I97,B
M("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F1E=FEC92(@=F%L=64]
M(CP_<&AP(&5C:&\@)&1E=FEC92`_/B(@+SX*"CQD:78@8VQA<W,](FAE861E
M<B(^"B`\/W!H<"!E8VAO($AO<F1E.CIL:6YK*$AO<F1E.CIS96QF55),*"DL
M(%\H(E)E9G)E<V@B*2D@+B!(;W)D93HZ:6UG*"=R96QO860N<&YG)RP@7R@B
M4F5L;V%D(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`_/CPO83X*($UA<'!I;F<@;V8@0V%T96=O<FEE<R!F;W(@1&5V:6-E(#P_
M<&AP(&5C:&\@)&1E=FEC95]N86UE(#\^"CPO9&EV/@H\=&%B;&4@8VQA<W,]
M(G-T<FEP960B(#X*/'1R/CQT:#Y$979I8V4@0V%T96=O<GD\+W1H/CQT:#Y(
M;W)D92!#871E9V]R>3PO=&@^"CQT:#Y3=6UM87)Y(&]F(&QA<W0@96YC;W5N
M=&5R960@96YT<GD\+W1H/CPO='(^"CP_<&AP"B`@("!F;W)E86-H("@D8V%T
M96=O<FEE<TUA<"!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@(&5C:&\@
M(CQT<B!C;&%S<SU<(FET96TB("X@*"LK)&D@)2`R*2`N(")<(CX\=&0^(@H@
M("`@("`@("X@)&ME>2X@)SPO=&0^/'1D/B<["B`@("`@("`@)'8@/2!I<U]A
M<G)A>2@D=F%L=64I(#\@)R<@.B`D=F%L=64["B`@("`@("`@96-H;R`D8TUA
M;F%G97(M/F=E=%-E;&5C="@G8V%T96=O<GDZ)R`N("1K97DL("1V*3L*("`@
M("`@("!E8VAO("<\+W1D/CQT9#XG.PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M=F%L=64I*2!["B`@("`@("`@("`@(&5C:&\@)'9A;'5E6S!=.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&5C:&\@(B9N8G-P.R(["B`@("`@("`@
M?0H@("`@("`@(&5C:&\@)SPO=&0^/"]T<CXG.PH*("`@('T*("`@(&9O<F5A
M8V@@*"1M:7-S:6YG4V5R=F5R0V%T96=O<FEE<R!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@(&5C:&\@)SQT<CX\=&0^/&5M/G1O(&)E(&1E9FEN960\
M+V5M/CPO=&0^/'1D/B<@+B`D:V5Y("X@)SPO=&0^/'1D/B<@+B`D=F%L=64@
M+B`G/"]T9#X\+W1R/B<["B`@("!]"@H@("`@96-H;R`B/"]T86)L93Y<;B([
M"B`@("!E8VAO("<\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N
M(B!V86QU93TB57!D871E($-A=&5G;W)I97,B/CPO9F]R;3XG.PI]"@HO*B!$
M:7-P;&%Y(&QO9R!O9B!P<F5V:6]U<R!S>6YC+B`J+PHD;F%M92`]("=P<F5V
M:6]U<U-Y;F-,;V<G.PHD:6YF;R`]("8D9'0M/F=E=$]B:F5C="@D;F%M92D[
M"@II9B`H(6ES7V$H)&EN9F\L("=014%27T5R<F]R)RD@)B8@:7-?87)R87DH
M)&QO9R`]("1I;F9O+3YG970H)VQO9R<I*2D@>PH@("`@+R\@0'1O9&\@;6]V
M92!T;R!T96UP;&%T90H_/@H\9&EV(&-L87-S/2)H96%D97(B/@H@/#]P:'`@
M96-H;R!?*"),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(BD@/SX*(#P_
M<&AP(&5C:&\@2&]R9&4Z.FQI;FLH2&]R9&4Z.G-E;&954DPH*2P@7R@B4F5F
M<F5S:"(I*2`N($AO<F1E.CII;6<H)W)E;&]A9"YP;F<G+"!?*")2969R97-H
M(BDI(#\^/"]A/@H@/&9O<FT@;65T:&]D/2)P;W-T(CX*("`\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](F1E;&5T96QO9R(@
M+SX*("`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU
M93TB/#]P:'`@96-H;R!?*")$96QE=&4@3&]G(BD@/SXB("\^"B`\+V9O<FT^
M"CPO9&EV/@H*/'1A8FQE(&-L87-S/2)S=')I<&5D(B!W:61T:#TB,3`P)2(^
M"B`\='(@8VQA<W,](FYO=W)A<"(^"B`@/'1H('=I9'1H/2(U)2(^/#]P:'`@
M96-H;R!?*")4:6UE(BD@/SX\+W1H/CQT:#X\/W!H<"!E8VAO(%\H(DQE=F5L
M(BD@/SX\+W1H/CQT:#X\/W!H<"!E8VAO(%\H(D9I;&4B*2`_/CPO=&@^/'1H
M/CP_<&AP(&5C:&\@7R@B365S<V%G92(I(#\^/"]T:#X*(#PO='(^"CP_<&AP
M(&9O<F5A8V@@*"1L;V<@87,@)&QO9V5N=')Y*3H@/SX*(#QT<CX*("`\=&0^
M"B`@(#P_<&AP(&5C:&\@<W1R9G1I;64H)'!R969S+3YG971686QU92@G9&%T
M95]F;W)M870G*2`N("<@)4@Z)4TZ)5,G+"`D;&]G96YT<GE;)W1S)UTI(#\^
M"B`@/"]T9#X*("`\=&0^"B`@(#P_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D;&]G96YT<GE;)VQE=F5L)UTI(#\^"B`@/"]T9#X*("`\=&0^"B`@/#]P
M:'`*("!I9B`H<')E9U]M871C:"@G+UPO4WEN8TU,7"YP:'`D+R<L("1L;V=E
M;G1R>5LG9FEL92==*2D@>PH@("`@("`D9FEL92`]("=F<F%M97=O<FLO4WEN
M8TU,+U-Y;F--3"YP:'`G.PH@('T@96QS92!["B`@("`@("1F:6QE(#T@<')E
M9U]R97!L86-E*"<O7BXJ7"]3>6YC34Q<+R@N*BDD+R<L("=F<F%M97=O<FLO
M4WEN8TU,+U-Y;F--3"\D,2<L("1L;V=E;G1R>5LG9FEL92==*3L*("!]"B`@
M96-H;R!(;W)D93HZ;&EN:R@G:'1T<#HO+V-V<RYH;W)D92YO<F<O8V\N<&AP
M+R<*("`@("`@("`@("`@("`@("`@("X@)&9I;&4@("X@)S]R/4A%040C)R`N
M('1R:6TH)&QO9V5N=')Y6R=L:6YE)UTI+"`G)RP@)R<L("=C=G,G*0H@("`@
M("`N('!R96=?<F5P;&%C92@G+UXN*EPO*%M>7"]=*BDD+R<L("<D,2<L("1L
M;V=E;G1R>5LG9FEL92==*0H@("`@("`N("<Z)R`N('1R:6TH)&QO9V5N=')Y
M6R=L:6YE)UTI"B`@/SX*("`\+W1D/@H@(#QT9#X*("`@/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1L;V=E;G1R>5LG;65S<V%G92==*2`_/@H@(#PO
M=&0^"B`\+W1R/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H*/#]P
M:'`*?0H*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T
M97(N:6YC)SL*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O<VAA<F5S+P``````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P,3<U,C4`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]S:&%R97,O961I="YP:'``````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(S,#0W`#$P-#$W,S8S,#`W
M`#`R,3$V-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]S:&%R
M97,O961I="YP:'`L=B`Q+C(V+C$P+C<@,C`P-B\P,2\P,2`R,3HR.3HQ-2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B1F
M:65L9'-,:7-T6R=S:&]W)UT@/2`P.PHD9FEE;&1S3&ES=%LG<F5A9"==(#T@
M,3L*)&9I96QD<TQI<W1;)V5D:70G72`](#(["B1F:65L9'-,:7-T6R=D96QE
M=&4G72`](#,["@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+T=R;W5P+G!H<"<["@HD87!P(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V%P<"<I.PHD<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH
M)&%P<"D["B1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PHD875T:"`]
M("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*
M)&9O<FT@/2!N=6QL.PHD<F5L;V%D(#T@9F%L<V4["B1A8W1I;VY)1"`](%5T
M:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<L("=E9&ET)RD["G-W:71C:"`H
M)&%C=&EO;DE$*2!["F-A<V4@)V5D:70G.@H@("`@)'-H87)E(#T@)B1S:&%R
M97,M/F=E=%-H87)E0GE)9"A5=&EL.CIG971&;W)M1&%T82@G8VED)RDI.PH@
M("`@:68@*"%I<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("1F;W)M(#T@)V5D:70N:6YC)SL*("`@("`@("`D<&5R;2`]("8D<VAA<F4M
M/F=E=%!E<FUI<W-I;VXH*3L*("`@('T@96QS96EF("@H)&-A=&5G;W)Y(#T@
M571I;#HZ9V5T1F]R;41A=&$H)W-H87)E)RDI("$]/2!N=6QL*2!["B`@("`@
M("`@)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1C871E9V]R>2D["B`@
M("`@("`@:68@*"%I<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`D9F]R;2`]("=E9&ET+FEN8R<["B`@("`@("`@("`@("1P97)M
M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@('T*("`@('T*
M("`@(&EF("AI<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H)'-H87)E+"`G:&]R9&4N97)R;W(G*3L*
M("`@('T@96QS96EF("AI<W-E="@D<VAA<F4I("8F($%U=&@Z.F=E=$%U=&@H
M*2`A/2`D<VAA<F4M/F=E="@G;W=N97(G*2D@>PH@("`@("`@(&5X:70H)W!E
M<FUI<W-I;VX@9&5N:65D)RD["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V5D
M:71F;W)M)SH*("`@("1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R94)Y260H
M571I;#HZ9V5T1F]R;41A=&$H)V-I9"<I*3L*("`@(&EF("AI<U]A*"1S:&%R
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H7R@B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(I
M+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92!["B`@("`@("`@:68@*$%U
M=&@Z.F=E=$%U=&@H*2`A/2`D<VAA<F4M/F=E="@G;W=N97(G*2D@>PH@("`@
M("`@("`@("!E>&ET*"=P97)M:7-S:6]N(&1E;FEE9"<I.PH@("`@("`@('T*
M("`@("`@("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*"B`@
M("`@("`@+R\@4')O8V5S<R!O=VYE<B!A;F0@;W=N97(@<&5R;6ES<VEO;G,N
M"B`@("`@("`@)&]L9%]O=VYE<B`]("1S:&%R92T^9V5T*"=O=VYE<B<I.PH@
M("`@("`@("1N97=?;W=N97(@/2!5=&EL.CIG971&;W)M1&%T82@G;W=N97(G
M+"`D;VQD7V]W;F5R*3L*("`@("`@("!I9B`H)&]L9%]O=VYE<B`A/3T@)&YE
M=U]O=VYE<B`F)B`A96UP='DH)&YE=U]O=VYE<BDI('L*("`@("`@("`@("`@
M:68@*"1O;&1?;W=N97(@(3T@075T:#HZ9V5T075T:"@I("8F("%!=71H.CII
M<T%D;6EN*"DI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H7R@B3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<VAA<F4M/G-E="@G;W=N97(G+"`D;F5W
M7V]W;F5R*3L*("`@("`@("`@("`@("`@("1S:&%R92T^<V%V92@I.PH@("`@
M("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=O=VYE<E]S:&]W
M)RDI('L*("`@("`@("`@("`@("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI
M<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?4TA/5RP@9F%L<V4I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<&5R;2T^
M<F5M;W9E57-E<E!E<FUI<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?4TA/5RP@
M9F%L<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*%5T:6PZ.F=E=$9O<FU$871A*"=O=VYE<E]R96%D)RDI('L*("`@("`@("`@
M("`@("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)&YE=U]O=VYE
M<BP@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI
M<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$
M871A*"=O=VYE<E]E9&ET)RDI('L*("`@("`@("`@("`@("`@("`@("`D<&5R
M;2T^861D57-E<E!E<FUI<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?141)5"P@
M9F%L<V4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)&YE=U]O=VYE
M<BP@4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=O=VYE<E]D96QE
M=&4G*2D@>PH@("`@("`@("`@("`@("`@("`@("1P97)M+3YA9&15<V5R4&5R
M;6ES<VEO;B@D;F5W7V]W;F5R+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!E
M<FTM/G)E;6]V955S97)097)M:7-S:6]N*"1N97=?;W=N97(L(%!%4DU37T1%
M3$5412P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S(&1E9F%U;'0@<&5R;6ES
M<VEO;G,N"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=D969A=6QT
M7W-H;W<G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D1&5F875L=%!E<FUI
M<W-I;VXH4$5235-?4TA/5RP@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1P97)M+3YR96UO=F5$969A=6QT4&5R;6ES<VEO;BA015)-
M4U]32$]7+"!F86QS92D["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG
M971&;W)M1&%T82@G9&5F875L=%]R96%D)RDI('L*("`@("`@("`@("`@)'!E
M<FTM/F%D9$1E9F%U;'1097)M:7-S:6]N*%!%4DU37U)%040L(&9A;'-E*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1&5F
M875L=%!E<FUI<W-I;VXH4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@('T*
M("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V1E9F%U;'1?961I="<I
M*2!["B`@("`@("`@("`@("1P97)M+3YA9&1$969A=6QT4&5R;6ES<VEO;BA0
M15)-4U]%1$E4+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'!E<FTM/G)E;6]V941E9F%U;'1097)M:7-S:6]N*%!%4DU37T5$250L
M(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$
M871A*"=D969A=6QT7V1E;&5T92<I*2!["B`@("`@("`@("`@("1P97)M+3YA
M9&1$969A=6QT4&5R;6ES<VEO;BA015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1&5F875L
M=%!E<FUI<W-I;VXH4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@?0H*
M("`@("`@("`O+R!0<F]C97-S(&=U97-T('!E<FUI<W-I;VYS+@H@("`@("`@
M(&EF("A5=&EL.CIG971&;W)M1&%T82@G9W5E<W1?<VAO=R<I*2!["B`@("`@
M("`@("`@("1P97)M+3YA9&1'=65S=%!E<FUI<W-I;VXH4$5235-?4TA/5RP@
M9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P97)M+3YR
M96UO=F5'=65S=%!E<FUI<W-I;VXH4$5235-?4TA/5RP@9F%L<V4I.PH@("`@
M("`@('T*("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V=U97-T7W)E
M860G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D1W5E<W1097)M:7-S:6]N
M*%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<&5R;2T^<F5M;W9E1W5E<W1097)M:7-S:6]N*%!%4DU37U)%040L
M(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$
M871A*"=G=65S=%]E9&ET)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$=U
M97-T4&5R;6ES<VEO;BA015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E;6]V94=U97-T4&5R;6ES<VEO
M;BA015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@?0H@("`@("`@(&EF("A5
M=&EL.CIG971&;W)M1&%T82@G9W5E<W1?9&5L971E)RDI('L*("`@("`@("`@
M("`@)'!E<FTM/F%D9$=U97-T4&5R;6ES<VEO;BA015)-4U]$14Q%5$4L(&9A
M;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M
M;W9E1W5E<W1097)M:7-S:6]N*%!%4DU37T1%3$5412P@9F%L<V4I.PH@("`@
M("`@('T*"B`@("`@("`@+R\@4')O8V5S<R!C<F5A=&]R('!E<FUI<W-I;VYS
M+@H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G8W)E871O<E]S:&]W
M)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$-R96%T;W)097)M:7-S:6]N
M*%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<&5R;2T^<F5M;W9E0W)E871O<E!E<FUI<W-I;VXH4$5235-?4TA/
M5RP@9F%L<V4I.PH@("`@("`@('T*("`@("`@("!I9B`H571I;#HZ9V5T1F]R
M;41A=&$H)V-R96%T;W)?<F5A9"<I*2!["B`@("`@("`@("`@("1P97)M+3YA
M9&1#<F5A=&]R4&5R;6ES<VEO;BA015)-4U]214%$+"!F86QS92D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E;6]V94-R96%T;W)0
M97)M:7-S:6]N*%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@("!]"B`@("`@
M("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=C<F5A=&]R7V5D:70G*2D@>PH@
M("`@("`@("`@("`D<&5R;2T^861D0W)E871O<E!E<FUI<W-I;VXH4$5235-?
M141)5"P@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M97)M+3YR96UO=F5#<F5A=&]R4&5R;6ES<VEO;BA015)-4U]%1$E4+"!F86QS
M92D["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G
M8W)E871O<E]D96QE=&4G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D0W)E
M871O<E!E<FUI<W-I;VXH4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E;6]V94-R96%T;W)097)M
M:7-S:6]N*%!%4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@4')O8V5S<R!U<V5R('!E<FUI<W-I;VYS+@H@("`@("`@("1U7VYA
M;65S(#T@571I;#HZ9V5T1F]R;41A=&$H)W5?;F%M97,G*3L*("`@("`@("`D
M=5]S:&]W(#T@571I;#HZ9V5T1F]R;41A=&$H)W5?<VAO=R<I.PH@("`@("`@
M("1U7W)E860@/2!5=&EL.CIG971&;W)M1&%T82@G=5]R96%D)RD["B`@("`@
M("`@)'5?961I="`](%5T:6PZ.F=E=$9O<FU$871A*"=U7V5D:70G*3L*("`@
M("`@("`D=5]D96QE=&4@/2!5=&EL.CIG971&;W)M1&%T82@G=5]D96QE=&4G
M*3L*"B`@("`@("`@9F]R96%C:"`H)'5?;F%M97,@87,@)&ME>2`]/B`D=7-E
M<BD@>PH@("`@("`@("`@("`O+R!)9B!T:&4@=7-E<B!I<R!E;7!T>2P@;W(@
M=V4G=F4@86QR96%D>2!S970@<&5R;6ES<VEO;G,*("`@("`@("`@("`@+R\@
M=FEA('1H92!O=VYE<E\@;W!T:6]N<RP@9&]N)W0@9&\@86YY=&AI;F<@:&5R
M92X*("`@("`@("`@("`@:68@*&5M<'1Y*"1U<V5R*2!\?"`D=7-E<B`]/2`D
M;F5W7V]W;F5R*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D=5]S:&]W6R1K97E=
M*2D@>PH@("`@("`@("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N
M*"1U<V5R+"!015)-4U]32$]7+"!F86QS92D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I
M;VXH)'5S97(L(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1U7W)E861;)&ME>5TI*2!["B`@("`@
M("`@("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%
M4DU37U)%040L(&9A;'-E*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D=7-E<BP@
M4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A96UP='DH)'5?961I=%LD:V5Y72DI('L*("`@("`@("`@("`@("`@
M("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?141)5"P@
M9F%L<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'!E<FTM/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R+"!015)-4U]%1$E4
M+"!F86QS92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=5]D96QE=&5;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D<&5R;2T^
M861D57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%4DU37T1%3$5412P@9F%L<V4I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E<FTM
M/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R+"!015)-4U]$14Q%5$4L(&9A
M;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@4')O
M8V5S<R!G<F]U<"!P97)M:7-S:6]N<RX*("`@("`@("`D9U]N86UE<R`](%5T
M:6PZ.F=E=$9O<FU$871A*"=G7VYA;65S)RD["B`@("`@("`@)&=?<VAO=R`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=G7W-H;W<G*3L*("`@("`@("`D9U]R96%D
M(#T@571I;#HZ9V5T1F]R;41A=&$H)V=?<F5A9"<I.PH@("`@("`@("1G7V5D
M:70@/2!5=&EL.CIG971&;W)M1&%T82@G9U]E9&ET)RD["B`@("`@("`@)&=?
M9&5L971E(#T@571I;#HZ9V5T1F]R;41A=&$H)V=?9&5L971E)RD["@H@("`@
M("`@(&9O<F5A8V@@*"1G7VYA;65S(&%S("1K97D@/3X@)&=R;W5P*2!["B`@
M("`@("`@("`@(&EF("AE;7!T>2@D9W)O=7`I*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D9U]S:&]W6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)'!E<FTM
M/F%D9$=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L(%!%4DU37U-(3U<L(&9A;'-E
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P97)M
M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P+"!015)-4U]32$]7+"!F
M86QS92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M9U]R96%D6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)'!E<FTM/F%D9$=R
M;W5P4&5R;6ES<VEO;B@D9W)O=7`L(%!%4DU37U)%040L(&9A;'-E*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P97)M+3YR96UO
M=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P+"!015)-4U]214%$+"!F86QS92D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D9U]E9&ET
M6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)'!E<FTM/F%D9$=R;W5P4&5R
M;6ES<VEO;B@D9W)O=7`L(%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F5'<F]U
M<%!E<FUI<W-I;VXH)&=R;W5P+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D9U]D96QE=&5;)&ME
M>5TI*2!["B`@("`@("`@("`@("`@("`D<&5R;2T^861D1W)O=7!097)M:7-S
M:6]N*"1G<F]U<"P@4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1W)O=7!0
M97)M:7-S:6]N*"1G<F]U<"P@4$5235-?1$5,151%+"!F86QS92D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S:&%R92T^<V5T4&5R;6ES
M<VEO;B@D<&5R;2P@9F%L<V4I.PH@("`@("`@("1S:&%R92T^<V%V92@I.PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")5<&1A=&5D
M(%PB)7-<(BXB*2P@)'-H87)E+3YG970H)VYA;64G*2DL("=H;W)D92YS=6-C
M97-S)RD["B`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@?0H@("`@
M8G)E86L["GT*"FEF("AI<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@
M("`@)'1I=&QE(#T@7R@B161I="!097)M:7-S:6]N<R(I.PI](&5L<V4@>PH@
M("`@)'1I=&QE(#T@<W!R:6YT9BA?*")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<R(I+"`D<VAA<F4M/F=E="@G;F%M92<I*3L*?0H*:68@*"1A=71H+3YH87-#
M87!A8FEL:71Y*"=L:7-T)RDI('L*("`@("1U<V5R3&ES="`]("1A=71H+3YL
M:7-T57-E<G,H*3L*("`@(&EF("AI<U]A*"1U<V5R3&ES="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1U<V5R3&ES="P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("1U
M<V5R3&ES="`](&%R<F%Y*"D["B`@("!]"B`@("!S;W)T*"1U<V5R3&ES="D[
M"GT@96QS92!["B`@("`D=7-E<DQI<W0@/2!A<G)A>2@I.PI]"@HD9W)O=7!,
M:7-T(#T@)&=R;W5P<RT^;&ES=$=R;W5P<R@I.PII9B`H:7-?82@D9W)O=7!,
M:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("!(;W)D93HZ;&]G365S<V%G92@D
M9W)O=7!,:7-T+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TY/5$E#
M12D["B`@("`D9W)O=7!,:7-T(#T@87)R87DH*3L*?0IA<V]R="@D9W)O=7!,
M:7-T*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N
M97)S)R`]/B`G<W1A='5S)RDI.PII9B`H(65M<'1Y*"1F;W)M*2D@>PH@("`@
M<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+W-H87)E<R\G("X@)&9O<FT[
M"GT*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R
M+FEN8R<["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]D;W=N;&]A9"\`````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`W`#`R
M,#`T-P`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V1O=VYL;V%D
M+VEN9&5X+G!H<```````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S
M,C``,3`T,3<S-C,P,#<`,#(Q-C8P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W-E<G9I8V5S+V1O=VYL;V%D+VEN9&5X+G!H<"QV(#$N.2XQ,"XS(#(P,#8O
M,#$O,#$@,C$Z,CDZ,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%3
M12<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N
M8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"B1R96=I<W1R>2`]
M("9296=I<W1R>3HZ<VEN9VQE=&]N*$A/4D1%7U-%4U-)3TY?4D5!1$].3%DI
M.PH*:68@*"$H)&UO9'5L92`](%5T:6PZ.F=E=$9O<FU$871A*"=M;V1U;&4G
M*2D@?'P*("`@("%F:6QE7V5X:7-T<R@D<F5G:7-T<GDM/F=E="@G9FEL97)O
M;W0G+"`D;6]D=6QE*2DI('L*("`@($AO<F1E.CIF871A;"@G1&\@;F]T(&-A
M;&P@=&AI<R!S8W)I<'0@9&ER96-T;'DN)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*?0II;F-L=61E("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1M;V1U
M;&4I("X@)R]V:65W+G!H<"<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VAE
M;'`O````````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,#<`,#$W,3<P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O:&5L<"]I;F1E>"YP:'``````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C4U-0`Q,#0Q-S,V,S`P-P`P,C$P,C``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`L=B`R+C@P+C$P+C8@,C`P-B\P,R\R."`Q,CHS,3HQ-2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["D!D969I;F4H)T%5
M5$A?2$%.1$Q%4B<L('1R=64I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O2&5L<"YP
M:'`G.PH*)'1I=&QE(#T@7R@B2&5L<"(I.PHD<VAO=R`](%-T<FEN9SHZ;&]W
M97(H571I;#HZ9V5T1F]R;41A=&$H)W-H;W<G+"`G:6YD97@G*2D["B1M;V1U
M;&4@/2!3=')I;F<Z.FQO=V5R*&)A<V5N86UE*%5T:6PZ.F=E=$9O<FU$871A
M*"=M;V1U;&4G+"`G:&]R9&4G*2DI.PHD=&]P:6,@/2!5=&EL.CIG971&;W)M
M1&%T82@G=&]P:6,G*3L*"FEF("@D;6]D=6QE(#T]("=A9&UI;B<I('L*("`@
M("1F:6QE<F]O="`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<I.PH@("`@
M)&AE;'!?9FEL92`]("1F:6QE<F]O="`N("(O861M:6XO;&]C86QE+R1L86YG
M=6%G92]H96QP+GAM;"(["B`@("`D:&5L<%]F:6QE7V9A;&QB86-K(#T@)&9I
M;&5R;V]T("X@)R]A9&UI;B]L;V-A;&4O96Y?55,O:&5L<"YX;6PG.PI](&5L
M<V4@>PH@("`@)&9I;&5R;V]T(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T
M)RP@)&UO9'5L92D["B`@("`D:&5L<%]F:6QE(#T@)&9I;&5R;V]T("X@(B]L
M;V-A;&4O)&QA;F=U86=E+VAE;'`N>&UL(CL*("`@("1H96QP7V9I;&5?9F%L
M;&)A8VL@/2`D9FEL97)O;W0@+B`G+VQO8V%L92]E;E]54R]H96QP+GAM;"<[
M"GT*"FEF("@D<VAO=R`]/2`G:6YD97@G*2!["B`@("`D8F%S95]U<FP@/2`D
M<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E
M<R]H96QP+R<["B`@("`D;6%I;E]U<FP@/2!(;W)D93HZ=7)L*"1B87-E7W5R
M;"D["B`@("`D;6%I;E]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&UA:6Y?
M=7)L+"!A<G)A>2@G<VAO=R<@/3X@)V5N=')Y)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M;V1U;&4G
M(#T^("1M;V1U;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=&]P:6,G(#T^("1T;W!I8RDI.PH@("`@
M)&UE;G5?=7)L(#T@2&]R9&4Z.G5R;"@D8F%S95]U<FPI.PH@("`@)&UE;G5?
M=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1M96YU7W5R;"P@87)R87DH)VUO
M9'5L92<@/3X@)&UO9'5L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S:&]W)R`]/B`G;65N=2<I*3L*
M("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]H96QP+VEN9&5X+FEN
M8R<["B`@("!E>&ET.PI](&5L<V4@>PH@("`@)&)O9'E#;&%S<R`]("=H96QP
M)SL*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["B`@("!I9B`H)'-H;W<@/3T@)VUE;G4G*2!["B`@("`@("`@
M+RH@4V5T('5P('5R;',N("HO"B`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH
M)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC
M97,O:&5L<"\G*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL("=M;V1U;&4G+"`D;6]D=6QE*3L*("`@("`@("`D=&]P:6-S7VQI
M;FL@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W-H;W<G+"`G=&]P:6-S
M)RD["B`@("`@("`@)'1O<&EC<U]L:6YK(#T@2&]R9&4Z.FQI;FLH)'1O<&EC
M<U]L:6YK+"!N=6QL+"`G:&5A9&5R)RP@)VAE;'!?;6%I;B<I("X@7R@B3&ES
M="!(96QP(%1O<&EC<R(I("X@)SPO83XG.PH@("`@("`@("1A8F]U=%]L:6YK
M(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=S:&]W)RP@)V%B;W5T)RD[
M"B`@("`@("`@)&%B;W5T7VQI;FL@/2!(;W)D93HZ;&EN:R@D86)O=71?;&EN
M:RP@;G5L;"P@)VAE861E<B<L("=H96QP7VUA:6XG*2`N(%\H(D%B;W5T+BXN
M(BD@+B`G/"]A/B<["B`@("`@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@
M+B`G+VAE;'`O;65N=2YI;F,G.PH@("`@?2!E;'-E:68@*"1S:&]W(#T]("=A
M8F]U="<I('L*("`@("`@("!R97%U:7)E("1F:6QE<F]O="`N("<O;&EB+W9E
M<G-I;VXN<&AP)SL*("`@("`@("`D=F5R<VEO;B`](%-T<FEN9SHZ=6-F:7)S
M="@D;6]D=6QE*2`N("<@)R`N(&-O;G-T86YT*%-T<FEN9SHZ=7!P97(H)&UO
M9'5L92D@+B`G7U9%4E-)3TXG*3L*("`@("`@("`D8W)E9&ET<R`](%5T:6PZ
M.F)U9F9E<D]U='!U="@G:6YC;'5D92<L("1F:6QE<F]O="`N("<O9&]C<R]#
M4D5$2513)RD["B`@("`@("`@)&-R961I=',@/2!3=')I;F<Z.F-O;G9E<G1#
M:&%R<V5T*"1C<F5D:71S+"`G:7-O+3@X-3DM,2<L($Y,4SHZ9V5T0VAA<G-E
M="@I*3L*("`@("`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O:&5L
M<"]A8F]U="YI;F,G.PH@("`@?2!E;'-E('L*("`@("`@("`D:&5L<"`]("9N
M97<@2&5L<"A(14Q07U-/55)#15]&24Q%+"!A<G)A>2@D:&5L<%]F:6QE+"`D
M:&5L<%]F:6QE7V9A;&QB86-K*2D["B`@("`@("`@:68@*"@D<VAO=R`]/2`G
M96YT<GDG*2`F)B`A96UP='DH)'1O<&EC*2D@>PH@("`@("`@("`@("`D:&5L
M<"T^;&]O:W5P*"1T;W!I8RD["B`@("`@("`@("`@("1H96QP+3YD:7-P;&%Y
M*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1O<&EC<R`]("1H
M96QP+3YT;W!I8W,H*3L*("`@("`@("`@("`@9F]R96%C:"`H)'1O<&EC<R!A
M<R`D:60@/3X@)'1I=&QE*2!["B`@("`@("`@("`@("`@("`D;&EN:R`]($AO
M<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N
M("<O<V5R=FEC97,O:&5L<"\G*3L*("`@("`@("`@("`@("`@("1L:6YK(#T@
M571I;#HZ861D4&%R86UE=&5R*"1L:6YK+"!A<G)A>2@G<VAO=R<@/3X@)V5N
M=')Y)RP@)VUO9'5L92<@/3X@)&UO9'5L92P@)W1O<&EC)R`]/B`D:60I*3L*
M("`@("`@("`@("`@("`@(&5C:&\@2&]R9&4Z.FQI;FLH)&QI;FLI.PH@("`@
M("`@("`@("`@("`@96-H;R`D=&ET;&4@+B`B/"]A/CQB<B`O/EQN(CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D:&5L<"T^8VQE86YU<"@I
M.PH@("`@?0I]"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N
M+69O;W1E<BYI;F,G.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V]B<F]W<V5R+P``````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#<`,#(P,3`R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O;V)R;W=S97(O:6YD
M97@N<&AP````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C`U-0`Q
M,#0Q-S,V,S`P-P`P,C$W,C4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R
M=FEC97,O;V)R;W=S97(O:6YD97@N<&AP+'8@,2XV+C$P+C4@,C`P-B\P,2\P
M,2`R,3HR.3HQ-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L
M871E+G!H<"<["@HD<&%T:"`](%5T:6PZ.F=E=$9O<FU$871A*"=P871H)RD[
M"@II9B`H96UP='DH)'!A=&@I*2!["B`@("`D;&ES="`](&%R<F%Y*"D["B`@
M("`D87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H;G5L;"P@9F%L<V4L(%!%
M4DU37U)%040I.PH@("`@9F]R96%C:"`H)&%P<',@87,@)&%P<"D@>PH@("`@
M("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G8G)O=W-E)RP@)&%P<"DI
M('L*("`@("`@("`@("`@)&QI<W1;)&%P<%T@/2!A<G)A>2@G;F%M92<@/3X@
M)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)')E9VES=')Y+3YG970H)VEC
M;VXG+"`D87!P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8G)O=W-E86)L92<@/3X@=')U92D["B`@("`@("`@?0H@("`@?0I](&5L<V4@
M>PH@("`@)'!I96-E<R`](&5X<&QO9&4H)R\G+"`D<&%T:"D["B`@("`D;&ES
M="`]("1R96=I<W1R>2T^8V%L;$)Y4&%C:V%G92@D<&EE8V5S6S!=+"`G8G)O
M=W-E)RP@87)R87DH)W!A=&@G(#T^("1P871H*2D["GT*"FEF("AI<U]A*"1L
M:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("!(;W)D93HZ9F%T86PH)&QI<W0L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*:68@*"%C;W5N="@D;&ES="DI('L*
M("`@($AO<F1E.CIF871A;"A?*").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0H*)'1P;"`](#P\/%103`H\
M<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"F9U;F-T:6]N(&-H;V]S
M94]B:F5C="AO:60I"GL*("`@(&EF("@A=VEN9&]W+F]P96YE<B!\?"`A=VEN
M9&]W+F]P96YE<BYO8G)O=W-E<D-A;&QB86-K*2!["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@('9A<B!R97-U;'0@/2!W:6YD;W<N;W!E;F5R
M+F]B<F]W<V5R0V%L;&)A8VLH=VEN9&]W+FYA;64L(&]I9"D["B`@("!I9B`H
M(7)E<W5L="D@>PH@("`@("`@('=I;F1O=RYC;&]S92@I.PH@("`@("`@(')E
M='5R;CL*("`@('T*"B`@("!A;&5R="AR97-U;'0I.PH@("`@<F5T=7)N(&9A
M;'-E.PI]"CPO<V-R:7!T/@H*/&1I=B!C;&%S<STB:&5A9&5R(CX*(#QS<&%N
M(&-L87-S/2)R:6=H=$9L;V%T(CX\=&%G.F-L;W-E("\^/"]S<&%N/@H@/&=E
M='1E>'0^3V)J96-T($)R;W=S97(\+V=E='1E>'0^"CPO9&EV/@H\9&EV(&-L
M87-S/2)H96%D97)B;W@B/@H@/'1A8FQE(&-L87-S/2)S=')I<&5D(B!C96QL
M<W!A8VEN9STB,"(@<W1Y;&4](G=I9'1H.C$P,"4B/@H@/&QO;W`Z<F]W<SX*
M("`\='(^"B`@(#QT9#X*("`@(#QT86<Z<F]W<RYI8V]N("\^"B`@("`\=&%G
M.G)O=W,N;F%M92`O/@H@("`\+W1D/@H@(#PO='(^"B`\+VQO;W`Z<F]W<SX*
M(#PO=&%B;&4^"CPO9&EV/@I44$P["@HD<F]W<R`](&%R<F%Y*"D["F9O<F5A
M8V@@*"1L:7-T(&%S("1P871H(#T^("1V86QU97,I('L*("`@("1R;W<@/2!A
M<G)A>2@I.PH*("`@("\O(%-E="!T:&4@:6-O;BX*("`@(&EF("@A96UP='DH
M)'9A;'5E<ULG:6-O;B==*2D@>PH@("`@("`@("1R;W=;)VEC;VXG72`]($AO
M<F1E.CII;6<H)'9A;'5E<ULG:6-O;B==+"`D=F%L=65S6R=N86UE)UTL("<G
M+"`G)RD["B`@("!](&5L<V5I9B`H(65M<'1Y*"1V86QU97-;)V)R;W=S96%B
M;&4G72DI('L*("`@("`@("`D<F]W6R=I8V]N)UT@/2!(;W)D93HZ:6UG*"=T
M<F5E+V9O;&1E<BYP;F<G*3L*("`@('T@96QS92!["B`@("`@("`@)')O=ULG
M:6-O;B==(#T@2&]R9&4Z.FEM9R@G=')E92]L96%F+G!N9R<I.PH@("`@?0H*
M("`@("\O(%-E="!T:&4@;F%M92]L:6YK+@H@("`@:68@*"%E;7!T>2@D=F%L
M=65S6R=B<F]W<V5A8FQE)UTI*2!["B`@("`@("`@)'5R;"`]($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O;V)R;W=S97(O)RD["B`@("`@("`@
M)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G<&%T:"<L("1P871H
M*3L*("`@("`@("`D<F]W6R=N86UE)UT@/2!(;W)D93HZ;&EN:R@D=7)L*2`N
M("1V86QU97-;)VYA;64G72`N("<\+V$^)SL*("`@('T@96QS92!["B`@("`@
M("`@)&IS(#T@(G)E='5R;B!C:&]O<V5/8FIE8W0H)R(@+B!A9&1S;&%S:&5S
M*"1P871H*2`N("(G*3LB.PH@("`@("`@("1R;W=;)VYA;64G72`]($AO<F1E
M.CIL:6YK*"<C)RP@<W!R:6YT9BA?*")#:&]O<V4@)7,B*2P@)'9A;'5E<ULG
M;F%M92==*2P@)R<L("<G+"`D:G,I("X@)'9A;'5E<ULG;F%M92==("X@)SPO
M83XG.PH@("`@?0H*("`@("1R;W=S6UT@/2`D<F]W.PI]"@HD=&5M<&QA=&4@
M/2`F;F5W($AO<F1E7U1E;7!L871E*"D["B1T96UP;&%T92T^<V5T3W!T:6]N
M*"=G971T97AT)RP@=')U92D["B1T96UP;&%T92T^<V5T*"=R;W=S)RP@)')O
M=W,I.PHD=&5M<&QA=&4M/G-E="@G8VQO<V4G+"`G/&$@:')E9CTB(R(@;VYC
M;&EC:STB=VEN9&]W+F-L;W-E*"D[(')E='5R;B!F86QS93LB/B<@+B!(;W)D
M93HZ:6UG*"=C;&]S92YP;F<G*2`N("<\+V$^)RD["@I(;W)D93HZ861D4V-R
M:7!T1FEL92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U92D["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["F5C:&\@
M)'1E;7!L871E+3YP87)S92@D='!L*3L*<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VEM86=E<R\`````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C,P,#<`,#$W-3`U`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<```````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-S0Q,P`Q,#0Q-S,V,S`P-P`P,C(U,S0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<"QV(#$N,3DN,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F
M:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN
M)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G
M.PH*)'1I=&QE(#T@7R@B0V]L;W(@4&EC:V5R(BD["G)E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["@HD9F]R;2`](%5T
M:6PZ.F=E=$9O<FU$871A*"=F;W)M)RD["B1T87)G970@/2!5=&EL.CIG971&
M;W)M1&%T82@G=&%R9V5T)RD["@IE8VAO($AO<F1E.CII;6<H)V-O;&]R<V-A
M;&4N<&YG)RP@)R<L("=I9#TB8V]L;W)P:6-K97(B(&]N8VQI8VL](F-H86YG
M94-O;&]R*&=E=$-O;&]R*&5V96YT*2D[(')E='5R;B!F86QS93LB(&]N;6]U
M<V5M;W9E/2)D96UO0V]L;W(H9V5T0V]L;W(H979E;G0I*3L@<F5T=7)N(&9A
M;'-E.R(@<W1Y;&4](F-U<G-O<CIC<F]S<VAA:7([8F%C:V=R;W5N9"UC;VQO
M<CIW:&ET93MP861D:6YG.C%P>"(G*3L*/SX*"CQD:78@:60](F-O;&]R1&5M
M;R(@<W1Y;&4](F)A8VMG<F]U;F0M8V]L;W(Z=VAI=&4[=VED=&@Z,3`P<'@[
M:&5I9VAT.C(P<'@[<&%D9&EN9SHQ<'@B/CPO9&EV/@H\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^"CPA+2T*9G5N8W1I;VX@8VAA;F=E0V]L;W(H
M8V]L;W(I"GL*("`@(&EF("AP87)E;G0N;W!E;F5R+F-L;W-E9"D@>PH@("`@
M("`@(&%L97)T*"(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(BDI(#\^(BD["B`@("`@
M("`@=&AI<RYC;&]S92@I.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!I
M9B`H(7!A<F5N="YO<&5N97(N9&]C=6UE;G0N/#]P:'`@96-H;R`D9F]R;2`_
M/BD@>PH@("`@("`@(&%L97)T*"(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=R(I*2`_/B(I.PH@("`@("`@('1H:7,N8VQO<V4H*3L*("`@("`@("!R
M971U<FX["B`@("!]"@H@("`@<&%R96YT+F]P96YE<BYD;V-U;65N="X\/W!H
M<"!E8VAO("1F;W)M(#\^6R(\/W!H<"!E8VAO("1T87)G970@/SXB72YV86QU
M92`](&-O;&]R.PH@("`@<&%R96YT+F]P96YE<BYD;V-U;65N="X\/W!H<"!E
M8VAO("1F;W)M(#\^6R(\/W!H<"!E8VAO("1T87)G970@/SXB72YS='EL92YB
M86-K9W)O=6YD0V]L;W(@/2!C;VQO<CL*("`@('!A<F5N="YO<&5N97(N9&]C
M=6UE;G0N/#]P:'`@96-H;R`D9F]R;2`_/ELB/#]P:'`@96-H;R`D=&%R9V5T
M(#\^(ETN<W1Y;&4N8V]L;W(@/2!B<FEG:'1N97-S*&-O;&]R*2`\(#$R."`_
M("=W:&ET92<@.B`G8FQA8VLG.PH*("`@('1H:7,N8VQO<V4H*3L*?0H*9G5N
M8W1I;VX@9&5M;T-O;&]R*&-O;&]R*0I["B`@("!V87(@=&%R9V5T(#T@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H)V-O;&]R1&5M;R<I.PH@("`@=&%R9V5T
M+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`](&-O;&]R.PH@("`@=&%R9V5T+G-T
M>6QE+F-O;&]R(#T@8G)I9VAT;F5S<RAC;VQO<BD@/"`Q,C@@/R`G=VAI=&4G
M(#H@)V)L86-K)SL*("`@('1A<F=E="YI;FYE<DA434P@/2!C;VQO<CL*?0H*
M9G5N8W1I;VX@9V5T0V]L;W(H979E;G0I"GL*("`@('9A<B!I;6<@/2!D;V-U
M;65N="YG971%;&5M96YT0GE)9"@G8V]L;W)P:6-K97(G*3L*"B`@("!V87(@
M>"`](&5V96YT+F-L:65N=%@@+2`Q,#L*("`@('9A<B!Y(#T@979E;G0N8VQI
M96YT62`M(#$P.PH*("`@('9A<B!R;6%X(#T@,#L*("`@('9A<B!G;6%X(#T@
M,#L*("`@('9A<B!B;6%X(#T@,#L*"B`@("!I9B`H>2`\/2`S,BD@>PH@("`@
M("`@(')M87@@/2`R-34["B`@("`@("`@9VUA>"`]("AY("\@,S(N,"D@*B`R
M-34["B`@("`@("`@8FUA>"`](#`["B`@("!](&5L<V4@:68@*'D@/#T@-C0I
M('L*("`@("`@("!Y(#T@>2`M(#,R.PH@("`@("`@(')M87@@/2`R-34@+2`H
M>2`O(#,R+C`I("H@,C4U.PH@("`@("`@(&=M87@@/2`R-34["B`@("`@("`@
M8FUA>"`](#`["B`@("!](&5L<V4@:68@*'D@/#T@.38I('L*("`@("`@("!Y
M(#T@>2`M(#8T.PH@("`@("`@(')M87@@/2`P.PH@("`@("`@(&=M87@@/2`R
M-34["B`@("`@("`@8FUA>"`]("AY("\@,S(N,"D@*B`R-34["B`@("!](&5L
M<V4@:68@*'D@/#T@,3(X*2!["B`@("`@("`@>2`]('D@+2`Y-CL*("`@("`@
M("!R;6%X(#T@,#L*("`@("`@("!G;6%X(#T@,C4U("T@*'D@+R`S,BXP*2`J
M(#(U-3L*("`@("`@("!B;6%X(#T@,C4U.PH@("`@?2!E;'-E(&EF("AY(#P]
M(#$V,"D@>PH@("`@("`@('D@/2!Y("T@,3(X.PH@("`@("`@(')M87@@/2`H
M>2`O(#,R+C`I("H@,C4U.PH@("`@("`@(&=M87@@/2`P.PH@("`@("`@(&)M
M87@@/2`R-34["B`@("!](&5L<V4@>PH@("`@("`@('D@/2!Y("T@,38P.PH@
M("`@("`@(')M87@@/2`R-34["B`@("`@("`@9VUA>"`](#`["B`@("`@("`@
M8FUA>"`](#(U-2`M("AY("\@,S(N,"D@*B`R-34["B`@("!]"@H@("`@:68@
M*'@@/#T@-3`I('L*("`@("`@("!V87(@<B`]($UA=&@N86)S*$UA=&@N9FQO
M;W(H<FUA>"`J('@@+R`U,"XP*2D["B`@("`@("`@=F%R(&<@/2!-871H+F%B
M<RA-871H+F9L;V]R*&=M87@@*B!X("\@-3`N,"DI.PH@("`@("`@('9A<B!B
M(#T@36%T:"YA8G,H36%T:"YF;&]O<BAB;6%X("H@>"`O(#4P+C`I*3L*("`@
M('T@96QS92!["B`@("`@("`@>"`M/2`U,#L*("`@("`@("!V87(@<B`]($UA
M=&@N86)S*$UA=&@N9FQO;W(H<FUA>"`K("AX("\@-3`N,"D@*B`H,C4U("T@
M<FUA>"DI*3L*("`@("`@("!V87(@9R`]($UA=&@N86)S*$UA=&@N9FQO;W(H
M9VUA>"`K("AX("\@-3`N,"D@*B`H,C4U("T@9VUA>"DI*3L*("`@("`@("!V
M87(@8B`]($UA=&@N86)S*$UA=&@N9FQO;W(H8FUA>"`K("AX("\@-3`N,"D@
M*B`H,C4U("T@8FUA>"DI*3L*("`@('T*"B`@("!R971U<FX@;6%K94-O;&]R
M*'(L(&<L(&(I.PI]"@IF=6YC=&EO;B!M86ME0V]L;W(H<BP@9RP@8BD*>PH@
M("`@8V]L;W(@/2`G(R<["B`@("!C;VQO<B`K/2!H97@H36%T:"YF;&]O<BAR
M("\@,38I*3L*("`@(&-O;&]R("L](&AE>"AR("4@,38I.PH@("`@8V]L;W(@
M*ST@:&5X*$UA=&@N9FQO;W(H9R`O(#$V*2D["B`@("!C;VQO<B`K/2!H97@H
M9R`E(#$V*3L*("`@(&-O;&]R("L](&AE>"A-871H+F9L;V]R*&(@+R`Q-BDI
M.PH@("`@8V]L;W(@*ST@:&5X*&(@)2`Q-BD["B`@("!R971U<FX@8V]L;W([
M"GT*"F9U;F-T:6]N(&)R:6=H=&YE<W,H8V]L;W(I"GL*("`@('9A<B!R(#T@
M;F5W($YU;6)E<B@B,'@B("L@8V]L;W(N<W5B<W1R*#$L(#(I*3L*("`@('9A
M<B!G(#T@;F5W($YU;6)E<B@B,'@B("L@8V]L;W(N<W5B<W1R*#,L(#(I*3L*
M("`@('9A<B!B(#T@;F5W($YU;6)E<B@B,'@B("L@8V]L;W(N<W5B<W1R*#4L
M(#(I*3L*("`@(')E='5R;B`H*'(@*B`R.3DI("L@*&<@*B`U.#<I("L@*&(@
M*B`Q,30I*2`O(#$P,#`["GT*"F9U;F-T:6]N(&AE>"AD96,I"GL*("`@(')E
M='5R;B`H9&5C*2YT;U-T<FEN9R@Q-BD["GT*+R\M+3X*/"]S8W)I<'0^"CPO
M8F]D>3X*/"]H=&UL/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O:6UA9V5S+W!I>&5L+G!H<```````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$W-0`Q,#0Q-S,V,S`P
M-P`P,C$S-#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O:6UA
M9V5S+W!I>&5L+G!H<"QV(#$N,30N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N
M<&AP)SL*"FAE861E<B@G0V]N=&5N="UT>7!E.B!I;6%G92]G:68G*3L*:&5A
M9&5R*"=%>'!I<F5S.B!7960L(#(Q($%U9R`Q.38Y(#$Q.C$Q.C$Q($=-5"<I
M.PIH96%D97(H)T-A8VAE+4-O;G1R;VPZ(&YO+6-A8VAE)RD["FAE861E<B@G
M0V%C:&4M0V]N=')O;#H@;75S="UR979A;&ED871E)RD["@HD<F=B(#T@<W1R
M7W)E<&QA8V4H)R,G+"`G)RP@571I;#HZ9V5T1F]R;41A=&$H)V,G*2D["@HD
M<B`](&AE>&1E8RAS=6)S='(H)')G8BP@,"P@,BDI.PHD9R`](&AE>&1E8RAS
M=6)S='(H)')G8BP@,BP@,BDI.PHD8B`](&AE>&1E8RAS=6)S='(H)')G8BP@
M-"P@,BDI.PH*:68@*"1R9V(I('L*("`@('!R:6YT9B@G)6,E8R5C)6,E8R5C
M)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E
M8R5C)6,E8R5C)6,E8R<L"B`@("`@("`@("`@-S$L-S,L-S`L-38L-3<L.3<L
M,2PP+#$L,"PQ,C@L,"PP+"1R+"1G+"1B+#`L,"PP+#0T+#`L,"PP+#`L,2PP
M+#$L,"PP+#(L,BPV."PQ+#`L-3DI.PI](&5L<V4@>PH@("`@<')I;G1F*"<E
M8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C
M)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E)RP*("`@
M("`@("`@("`W,2PW,RPW,"PU-BPU-RPY-RPQ+#`L,2PP+#$R."PR-34L,"PQ
M.3(L,3DR+#$Y,BPP+#`L,"PS,RPR-#DL-"PQ+#`L,"PP+#`L-#0L,"PP+#`L
M,"PQ+#`L,2PP+#`L,BPR+#8X+#$L,"PU.2D["GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]I;6%G97,O=FEE=RYP:'``````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`W-C<S`#$P-#$W,S8S,#`W`#`R,3(P,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@1&ES
M<&QA>7,@86X@:6UA9V4@86YD(&%L;&]W<R!M;V1I9FEC871I;VYS(&EF(')E
M<75I<F5D+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI
M8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z
M(&AO<F1E+W-E<G9I8V5S+VEM86=E<R]V:65W+G!H<"QV(#$N,C`N,3`N-2`R
M,#`V+S`R+S(P(#$R.C$W.C`T(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J+PH*0&1E9FEN92@G2$]2
M1$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B\J($=E
M="!F:6QE(&EN9F\N(%1H92!F;VQL;W=I;F<@<&%R86UE=&5R<R!A<F4@879A
M:6QA8FQE.@H@*B`@)V8G("T@=&AE(&9I;&5N86UE+@H@*B`@)W,G("T@=&AE
M('-O=7)C92P@96ET:&5R('1H92`G=&UP)R!D:7)E8W1O<GD@;W(@5D93+@H@
M*B`@)V,G("T@=VAI8V@@87!P)W,@8V]N9FEG('1O('5S92!F;W(@5D93+"!D
M969A=6QT<R!T;R!(;W)D92X*("H@("=P)R`M('1H92!D:7)E8W1O<GD@;V8@
M=&AE(&9I;&4N"B`J("`G;B<@+2!T:&4@;F%M92!T;R!S970@=&\@=&AE(&9I
M;&5N86UE(&]R(&1E9F%U;'0@=&\@<V%M92!A<R!F:6QE;F%M92X*("H@("=A
M)R`M('!E<F9O<FT@<V]M92!A8W1I;VX@;VX@=&AE(&EM86=E+"!S=6-H(&%S
M('-C86QI;F<N("HO"B1F:6QE(#T@8F%S96YA;64H571I;#HZ9V5T1F]R;41A
M=&$H)V8G*2D["B1S;W5R8V4@/2!S=')T;VQO=V5R*%5T:6PZ.F=E=$9O<FU$
M871A*"=S)RP@)W1M<"<I*3L*)&%P<%]C;VYF(#T@<W1R=&]L;W=E<BA5=&EL
M.CIG971&;W)M1&%T82@G8R<L("=H;W)D92<I*3L*)&YA;64@/2!5=&EL.CIG
M971&;W)M1&%T82@G;B<L("1F:6QE*3L*)&%C=&EO;B`]('-T<G1O;&]W97(H
M571I;#HZ9V5T1F]R;41A=&$H)V$G*2D["@IS=VET8V@@*"1S;W5R8V4I('L*
M8V%S92`G=F9S)SH*("`@("\J($-H86YG92!A<'`@:68@;F5E9&5D('1O(&=E
M="!T:&4@<FEG:'0@5D93(&-O;F9I9RX@*B\*("`@("1C:&%N9V5D7V-O;F8@
M/2`D<F5G:7-T<GDM/G!U<VA!<'`H)&%P<%]C;VYF*3L*"B`@("`O*B!'971T
M:6YG(&$@9FEL92!F<F]M($AO<F1E)W,@5D93+B`J+PH@("`@<F5Q=6ER95]O
M;F-E("=61E,N<&AP)SL*("`@("1V9G,@/2`F5D93.CIS:6YG;&5T;VXH)&-O
M;F9;)W9F<R==6R=T>7!E)UTL($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W9F
M<R<L("1C;VYF6R=V9G,G75LG='EP92==*2D["B`@("`D<&%T:"`](%5T:6PZ
M.F=E=$9O<FU$871A*"=P)RD["B`@("`D9FEL95]D871A(#T@)'9F<RT^<F5A
M9"@D<&%T:"P@)&9I;&4I.PH@("`@:68@*&ES7V$H)&9I;&5?9&%T82P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN
M=&8H)T5R<F]R(&1I<W!L87EI;F<@:6UA9V4@6R5S73H@)7,G+"`D<&%T:"`N
M("<O)R`N("1F:6QE+"`D9FEL95]D871A+3YG971-97-S86=E*"DI+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@97AI=#L*
M("`@('T*"B`@("`O*B!2971U<FX@=&AE(&]R:6=I;F%L(&%P<"!I9B!C:&%N
M9V5D('!R979I;W5S;'DN("HO"B`@("!I9B`H)&-H86YG961?8V]N9BD@>PH@
M("`@("`@("1R96=I<W1R>2T^<&]P07!P*"1A<'!?8V]N9BD["B`@("!]"B`@
M("!B<F5A:SL*"F-A<V4@)W1M<"<Z"B`@("`O*B!'971T:6YG(&$@9FEL92!F
M<F]M($AO<F1E)W,@=&5M<"!D:7(N("HO"B`@("`D=&UP9&ER(#T@2&]R9&4Z
M.F=E=%1E;7!$:7(H*3L*("`@(&EF("AE;7!T>2@D86-T:6]N*2!\?"`D86-T
M:6]N(#T]("=R97-I>F4G*2!["B`@("`@("`@+RH@57-E(&]R:6=I;F%L(&EF
M(&YO(&%C=&EO;B!O<B!I9B!R97-I>FEN9RX@*B\*("`@("`@("`D9FEL95]N
M86UE(#T@)'1M<&1I<B`N("<O)R`N("1F:6QE.PH@("`@?2!E;'-E('L*("`@
M("`@("`D9FEL95]N86UE(#T@)'1M<&1I<B`N("<O;6]D7R<@+B`D9FEL93L*
M("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE7VYA;64I*2!["B`@("`@
M("`@("`@(&-O<'DH)'1M<&1I<B`N("<O)R`N("1F:6QE+"`D9FEL95]N86UE
M*3L*("`@("`@("!]"B`@("!]"B`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE
M7VYA;64I*2!["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G
M26UA9V4@;F]T(&9O=6YD(%LE<UTG+"`D9FEL95]N86UE*2P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@(&5X:70["B`@("!]
M"B`@("`D<VEZ92`](&9I;&5S:7IE*"1F:6QE7VYA;64I.PH@("`@)&9P(#T@
M0&9O<&5N*"1F:6QE7VYA;64L("=R)RD["B`@("`D9FEL95]D871A(#T@9G)E
M860H)&9P+"`D<VEZ92D["B`@("!F8VQO<V4H)&9P*3L*("`@(&)R96%K.PI]
M"@HO*B!,;V%D('1H92!I;6%G92!O8FIE8W0N("HO"G)E<75I<F5?;VYC92`G
M2&]R9&4O26UA9V4N<&AP)SL*)'!A<F%M<R`](&%R<F%Y*"=T96UP)R`]/B!(
M;W)D93HZ9V5T5&5M<$1I<B@I*3L*:68@*"%E;7!T>2@D8V]N9ELG:6UA9V4G
M75LG8V]N=F5R="==*2D@>PH@("`@)&EM86=E(#T@)DAO<F1E7TEM86=E.CIS
M:6YG;&5T;VXH)VEM)RP@)'!A<F%M<RD["GT@96QS92!["B`@("`D:6UA9V4@
M/2`F2&]R9&5?26UA9V4Z.G-I;F=L971O;B@G9V0G+"`D<&%R86US*3L*?0HD
M:6UA9V4M/FQO8613=')I;F<H)&9I;&4L("1F:6QE7V1A=&$I.PH*+RH@0VAE
M8VL@:68@;F\@961I=&EN9R!A8W1I;VX@<F5Q=6ER960@86YD('-E;F0@=&AE
M(&EM86=E('1O(&)R;W=S97(N("HO"FEF("AE;7!T>2@D86-T:6]N*2D@>PH@
M("`@)&EM86=E+3YD:7-P;&%Y*"D["B`@("!E>&ET.PI]"@HO*B!);6%G92!E
M9&ET:6YG(')E<75I<F5D+B`J+PIS=VET8V@@*"1A8W1I;VXI('L*8V%S92`G
M<F]T871E)SH*("`@("1I;6%G92T^<F]T871E*%5T:6PZ.F=E=$9O<FU$871A
M*"=V)RDI.PH@("`@8G)E86L["@IC87-E("=F;&EP)SH*("`@("1I;6%G92T^
M9FQI<"@I.PH@("`@8G)E86L["@IC87-E("=M:7)R;W(G.@H@("`@)&EM86=E
M+3YM:7)R;W(H*3L*("`@(&)R96%K.PH*8V%S92`G9W)A>7-C86QE)SH*("`@
M("1I;6%G92T^9W)A>7-C86QE*"D["B`@("!B<F5A:SL*"F-A<V4@)W)E<VEZ
M92<Z"B`@("!L:7-T*"1W:61T:"P@)&AE:6=H="P@)')A=&EO*2`](&5X<&QO
M9&4H)RXG+"!5=&EL.CIG971&;W)M1&%T82@G=B<I*3L*"B`@("`O*B!)9B!N
M;R!W:61T:"!O<B!H96EG:'0@:&%S(&)E96X@<&%S<V5D+"!G970@=&AE(&]R
M:6=I;F%L"B`@("`@*B!O;F5S+B`J+PH@("`@:68@*&5M<'1Y*"1W:61T:"D@
M?'P@96UP='DH)&AE:6=H="DI('L*("`@("`@("`D;W)I9R`]("1I;6%G92T^
M9V5T1&EM96YS:6]N<R@I.PH@("`@?0H@("`@:68@*&5M<'1Y*"1W:61T:"DI
M('L*("`@("`@("`D=VED=&@@/2`D;W)I9ULG=VED=&@G73L*("`@('T*("`@
M(&EF("AE;7!T>2@D:&5I9VAT*2D@>PH@("`@("`@("1H96EG:'0@/2`D;W)I
M9ULG:&5I9VAT)UT["B`@("!]"@H@("`@)&EM86=E+3YR97-I>F4H)'=I9'1H
M+"`D:&5I9VAT+"`D<F%T:6\I.PH*("`@("\J(%-I;F-E('1H92!O<FEG:6YA
M;"!I<R!A;'=A>7,@=7-E9"!F;W(@<F5S:7II;F<@;6%K92!S=7)E('1H90H@
M("`@("H@=W)I=&4@:7,@=&\@)VUO9%\G+B`J+PH@("`@)&9I;&5?;F%M92`]
M("1T;7!D:7(@+B`G+VUO9%\G("X@)&9I;&4["B`@("!B<F5A:SL*?0H*+RH@
M5W)I=&4@;W5T(&%N>2!C:&%N9V5S('1O('1H92!T96UP;W)A<GD@9FEL92X@
M*B\*)&9P(#T@0&9O<&5N*"1F:6QE7VYA;64L("=W8B<I.PIF=W)I=&4H)&9P
M+"`D:6UA9V4M/G)A=R@I*3L*9F-L;W-E*"1F<"D["@HD:6UA9V4M/F1I<W!L
M87DH*3L*````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O````````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`W`#`Q
M-S4R-@`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82\`````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C,P,#<`,#(Q,S(S`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P,C,P,#0`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]!;G-E;$EM86=E+P``````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S
M,#`W`#`R-3`Q,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA9V4O;&%N9R\`````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,#<`,#(U-S,R`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O06YS96Q)
M;6%G92]L86YG+V5N+FIS```````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$U,0`Q,#0Q-S,V,S`P-P`P,C8V-C<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+R\@
M23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'.B!55$8M
M."!\($E33RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO
M+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%43U)3.@HO+PHO
M+R`@(#$N(%!,14%312!0550@64]54B!#3TY404-4($E.1D\@24X@5$A%($%"
M3U9%($Q)3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E;6%I;"!A9&1R
M97-S*0HO+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%(%541BTX($9/4B!%
M3D-/1$E.1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB;&4L('!L
M96%S92!I;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T('-T871E<R!W
M:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I!;G-E;$EM86=E+DDQ.$X@
M/2!["@DO+R!)=&5M<R!T:&%T(&%P<&5A<B!I;B!M96YU+B`@4&QE87-E(&YO
M=&4@=&AA="!A;B!U;F1E<G-C;W)E("A?*0H)+R\@8VAA<F%C=&5R(&EN('1H
M92!T<F%N<VQA=&EO;B`H<FEG:'0@8V]L=6UN*2!W:6QL(&-A=7-E('1H92!F
M;VQL;W=I;F<*"2\O(&QE='1E<B!T;R!B96-O;64@=6YD97)L:6YE9"!A;F0@
M8F4@<VAO<G1C=70@9F]R('1H870@;65N=2!O<'1I;VXN"@H)(DEN<V5R="!)
M;6%G92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(DEN<V5R="!);6%G92(L"@DB26UA9V4@55),.B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B26UA9V4@55),.B(L"@DB16YT
M97(@=&AE(&EM86=E(%523"!H97)E(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B16YT97(@=&AE(&EM86=E(%523"!H97)E(BP*"2)0<F5V:65W(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")0
M<F5V:65W(BP*"2)0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B
M("`@("`@("`@("`@("`@("`Z(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<B+`H)(D%L=&5R;F%T92!T97AT.B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(D%L=&5R;F%T92!T97AT.B(L"@DB1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B("`@("`@("`@
M("`@.B`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B
M+`H)(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B+`H)(DEM
M86=E(%!R979I97<Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(DEM86=E(%!R979I97<Z(BP*"2)'86QL97)Y.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")'86QL97)Y.B(L
M"@DB1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB+`H)(DEM
M86=E(&9R;VT@9V%L;&5R>3HB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(DEM86=E(&9R;VT@9V%L;&5R>3HB+`H)(DEM86=E(&9R;VT@9V%L
M;&5R>2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DEM86=E
M(&9R;VT@9V%L;&5R>2(*?3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA9V4O
M86YS96PM:6UA9V4N:G,`````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#4Q,#$`,3`T,3<S-C,P,#<`,#(W-3(S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\O($%N<V5L
M($EM86=E(%!L=6=I;B!F;W(@2%1-3$%R96$M,RXP"B\O(%!L=6=I;B!T:&%T
M(&%L;&]W<R!T:&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M('1H90HO+R!(
M;W)D92!F<F%M97=O<FL@;6]D=6QE($%N<V5L(&EN=&\@82!T97AT"B\O"B\O
M($UO9'5L92!R975S97,@2%1-3$%R96$@8V]D90HO+PHO+R!);7!L96UE;G1A
M=&EO;CH@4F]E;"!';&]U9&5M86YS(#QR;V5L0&=L;W5D96UA;G,N:6YF;SX*
M+R\*+R\@*&,I(#(P,#0N"B\O($1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M('1E<FUS(&%S($A434Q!<F5A(&ET<V5L9BX*+R\@5&AI<R!N;W1I8V4@3553
M5"!S=&%Y(&EN=&%C="!F;W(@=7-E("AS964@;&EC96YS92YT>'0I+@HO+PHO
M+R`D260Z(&%N<V5L+6EM86=E+FIS+'8@,2XQ(#(P,#0O,#DO,#@@,38Z,#8Z
M,3,@;&%N8V5R($5X<"`D"@H*9G5N8W1I;VX@06YS96Q);6%G92AE9&ET;W(I
M"GL*"71H:7,N961I=&]R(#T@961I=&]R.PH)=F%R(&DQ.&X@/2!!;G-E;$EM
M86=E+DDQ.$X["GT["@H*06YS96Q);6%G92Y?<&QU9VEN26YF;R`]('L*"6YA
M;64@("`@("`@("`@.B`B06YS96Q);6%G92(L"@EV97)S:6]N("`@("`@(#H@
M(C$N,"(L"@ED979E;&]P97(@("`@(#H@(E)O96P@1VQO=61E;6%N<R(L"@ED
M979E;&]P97)?=7)L(#H@(FAT='`Z+R]W=W<N9VQO=61E;6%N<RYI;F9O+R(L
M"B`@("`@("`@<W!O;G-O<B`@("`@("`Z(")(;W)D92!0<F]J96-T(BP*("`@
M("`@("!S<&]N<V]R7W5R;"`@(#H@(FAT='`Z+R]W=W<N:&]R9&4N;W)G+R(L
M"@EL:6-E;G-E("`@("`@(#H@(FAT;6Q!<F5A(@I].PH*"B\O($-A;&QE9"!W
M:&5N('1H92!U<V5R(&-L:6-K<R!O;B`B26YS97)T26UA9V4B(&)U='1O;BX@
M($EF(&%N(&EM86=E(&ES(&%L<F5A9'D*+R\@=&AE<F4L(&ET('=I;&P@:G5S
M="!M;V1I9GD@:70G<R!P<F]P97)T:65S+@HO+R!4:&ES(&9U;F-T:6]N(&]V
M97)R:61E<R!T:&4@;F%T:79E($A434Q!<F5A(&9U;F-T:6]N"DA434Q!<F5A
M+G!R;W1O='EP92Y?:6YS97)T26UA9V4@/2!F=6YC=&EO;BAI;6%G92D@>PH)
M=F%R(&5D:71O<B`]('1H:7,["2\O(&9O<B!N97-T960@9G5N8W1I;VYS"@EV
M87(@;W5T<&%R86T@/2!N=6QL.PH*"6EF("AT>7!E;V8@:6UA9V4@/3T@(G5N
M9&5F:6YE9"(I('L*"0EI;6%G92`]('1H:7,N9V5T4&%R96YT16QE;65N="@I
M.PH)"6EF("AI;6%G92`F)B`A+UYI;6<D+VDN=&5S="AI;6%G92YT86=.86UE
M*2D*"0D):6UA9V4@/2!N=6QL.PH)?0H):68@*&EM86=E*2!O=71P87)A;2`]
M('L*"0EF7V)A<V4@("`Z(&5D:71O<BYC;VYF:6<N8F%S95523"P*"0EF7W5R
M;"`@("`Z($A434Q!<F5A+FES7VEE(#\@961I=&]R+G-T<FEP0F%S95523"AI
M;6%G92YS<F,I(#H@:6UA9V4N9V5T071T<FEB=71E*")S<F,B*2P*"0EF7V%L
M="`@("`Z(&EM86=E+F%L="P*"0EF7V)O<F1E<B`Z(&EM86=E+F)O<F1E<BP*
M"0EF7V%L:6=N("`Z(&EM86=E+F%L:6=N+`H)"69?=F5R="`@(#H@:6UA9V4N
M=G-P86-E+`H)"69?:&]R:7H@(#H@:6UA9V4N:'-P86-E"@E].PH*("`@('9A
M<B!M86YA9V5R(#T@7V5D:71O<E]U<FP@*R`G<&QU9VEN<R]!;G-E;$EM86=E
M+VEN<V5R=%]I;6%G92YP:'`G.PH*"41I86QO9RAM86YA9V5R+"!F=6YC=&EO
M;BAP87)A;2D@>PHO+PET:&ES+E]P;W!U<$1I86QO9RAM86YA9V5R+"!F=6YC
M=&EO;BAP87)A;2D@>PH)"6EF("@A<&%R86TI('L)+R\@=7-E<B!M=7-T(&AA
M=F4@<')E<W-E9"!#86YC96P*"0D)<F5T=7)N(&9A;'-E.PH)"7T*"0EV87(@
M:6UG(#T@:6UA9V4["@D):68@*"%I;6<I('L*"0D)=F%R('-E;"`](&5D:71O
M<BY?9V5T4V5L96-T:6]N*"D["@D)"79A<B!R86YG92`](&5D:71O<BY?8W)E
M871E4F%N9V4H<V5L*3L*"0D)961I=&]R+E]D;V,N97AE8T-O;6UA;F0H(FEN
M<V5R=&EM86=E(BP@9F%L<V4L('!A<F%M+F9?=7)L*3L*"0D):68@*$A434Q!
M<F5A+FES7VEE*2!["@D)"0EI;6<@/2!R86YG92YP87)E;G1%;&5M96YT*"D[
M"@D)"0DO+R!W;VYD97(@:68@=&AI<R!W;W)K<RXN+@H)"0D):68@*&EM9RYT
M86=.86UE+G1O3&]W97)#87-E*"D@(3T@(FEM9R(I('L*"0D)"0EI;6<@/2!I
M;6<N<')E=FEO=7-3:6)L:6YG.PH)"0D)?0H)"0E](&5L<V4@>PH)"0D):6UG
M(#T@<F%N9V4N<W1A<G1#;VYT86EN97(N<')E=FEO=7-3:6)L:6YG.PH)"0E]
M"@D)?2!E;'-E('L*"0D):6UG+G-R8R`]('!A<F%M+F9?=7)L.PH)"7T*"@D)
M9F]R("AV87(@9FEE;&0@:6X@<&%R86TI('L*"0D)=F%R('9A;'5E(#T@<&%R
M86U;9FEE;&1=.PH)"0ES=VET8V@@*&9I96QD*2!["@D)"2`@("!C87-E(")F
M7V%L="(@("`@.B!I;6<N86QT"2`]('9A;'5E.R!B<F5A:SL*"0D)("`@(&-A
M<V4@(F9?8F]R9&5R(B`Z(&EM9RYB;W)D97(@/2!P87)S94EN="AV86QU92!\
M?"`B,"(I.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?86QI9VXB("`Z(&EM9RYA
M;&EG;@D@/2!V86QU93L@8G)E86L["@D)"2`@("!C87-E(")F7W9E<G0B("`@
M.B!I;6<N=G-P86-E(#T@<&%R<V5);G0H=F%L=64@?'P@(C`B*3L@8G)E86L[
M"@D)"2`@("!C87-E(")F7VAO<FEZ(B`@.B!I;6<N:'-P86-E(#T@<&%R<V5)
M;G0H=F%L=64@?'P@(C`B*3L@8G)E86L["@D)"7T*"0E]"@E]+"!O=71P87)A
M;2D["GT["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!L=6=I;G,O06YS96Q);6%G92]I;G-E<G1?:6UA9V4N<&AP
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-C,P-0`Q,#0Q-S,V,S`P-P`P,S`Q-S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA
M9V4O:6YS97)T7VEM86=E+G!H<"QV(#$N-2XV+C4@,C`P-2\Q,"\Q."`Q,3HS
M-#HP,B!J86X@17AP("0*("HO"@HO+R!#:&5C:R!F;W(@82!P<FEO<B!D969I
M;FET:6]N(&]F($A/4D1%7T)!4T4@*'!E<FAA<',@8GD@86X@875T;U]P<F5P
M96YD7V9I;&4*+R\@9&5F:6YI=&EO;B!F;W(@<VET92!C=7-T;VUI>F%T:6]N
M*2X*:68@*"%D969I;F5D*"=(3U)$15]"05-%)RDI('L*("`@($!D969I;F4H
M)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXO+BXO
M+BXO+BXG*3L*?0H*+R\@3&]A9"!T:&4@2&]R9&4@1G)A;65W;W)K(&-O<F4L
M(&%N9"!S970@=7`@:6YC;'5S:6]N('!A=&AS+@IR97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"B\O(%)E9VES=')Y"B1R96=I
M<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*"D["@HO*B!$971E<FUI;F4@
M:&]W('=E('=E<F4@8V%L;&5D.R!W:71H(&$@55),+"!O<B!W:71H(&$@9V%L
M;&5R>2!I9"`J+PHD9V%L;&5R>6QI<W0@/2`D<F5G:7-T<GDM/F-A;&PH)VEM
M86=E<R]L:7-T1V%L;&5R:65S)RP@87)R87DH;G5L;"DI.PHD9V%L;&5R>5]I
M9"`](%5T:6PZ.F=E=$9O<FU$871A*"=G86QL97)Y)RP@:V5Y*"1G86QL97)Y
M;&ES="DI.PHD:6UA9V5L:7-T(#T@)')E9VES=')Y+3YC86QL*"=I;6%G97,O
M;&ES=$EM86=E<R<L(&%R<F%Y*&YU;&PL("1G86QL97)Y7VED+"!015)-4U]3
M2$]7+"`G<V-R965N)RP@=')U92DI.PHD9FER<W1?:6UA9V4@/2!C;W5N="@D
M:6UA9V5L:7-T*2`_("1I;6%G96QI<W1;:V5Y*"1I;6%G96QI<W0I75LG=7)L
M)UT@.B`G)SL*"C\^"CQH=&UL/@H*/&AE860^"B`@/'1I=&QE/DEN<V5R="!)
M;6%G93PO=&ET;&4^"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@
M<W)C/2(N+B\N+B]P;W!U<',O<&]P=7`N:G,B/CPO<V-R:7!T/@H*/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H*=VEN9&]W+G)E<VEZ951O*#0P
M,"P@,C`P*3L*"F9U;F-T:6]N($EN:70H*2!["B`@7U]D;&=?:6YI="@I.PH@
M('9A<B!P87)A;2`]('=I;F1O=RYD:6%L;V=!<F=U;65N=',["B`@:68@*'!A
M<F%M*2!["B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W5R;"(I
M+G9A;'5E(#T@<&%R86U;(F9?=7)L(ET["B`@("`@(&1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*")F7V%L="(I+G9A;'5E(#T@<&%R86U;(F9?86QT(ET["B`@
M("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7V)O<F1E<B(I+G9A;'5E
M(#T@<&%R86U;(F9?8F]R9&5R(ET["B`@("`@(&1O8W5M96YT+F=E=$5L96UE
M;G1">4ED*")F7V%L:6=N(BDN=F%L=64@/2!P87)A;5LB9E]A;&EG;B)=.PH@
M("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]V97)T(BDN=F%L=64@
M/2!P87)A;5LB9E]V97)T(ET["B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*")F7VAO<FEZ(BDN=F%L=64@/2!P87)A;5LB9E]H;W)I>B)=.PH@("`@
M("!W:6YD;W<N:7!R979I97<N;&]C871I;VXN<F5P;&%C92AP87)A;2YF7W5R
M;"D["B`@?0H@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W5R;"(I+F9O
M8W5S*"D["GT["@IF=6YC=&EO;B!O;D]+*"D@>PH@('9A<B!R97%U:7)E9"`]
M('L*("`@(")F7W5R;"(Z(")9;W4@;75S="!E;G1E<B!T:&4@55),(@H@('T[
M"B`@9F]R("AV87(@:2!I;B!R97%U:7)E9"D@>PH@("`@=F%R(&5L(#T@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H:2D["B`@("!I9B`H(65L+G9A;'5E*2![
M"B`@("`@(&%L97)T*')E<75I<F5D6VE=*3L*("`@("`@96PN9F]C=7,H*3L*
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@('T*("`O+R!P87-S(&1A=&$@
M8F%C:R!T;R!T:&4@8V%L;&EN9R!W:6YD;W<*("!V87(@9FEE;&1S(#T@6R)F
M7W5R;"(L(")F7V%L="(L(")F7V%L:6=N(BP@(F9?8F]R9&5R(BP*("`@("`@
M("`@("`@("`@(")F7VAO<FEZ(BP@(F9?=F5R=")=.PH@('9A<B!P87)A;2`]
M(&YE=R!/8FIE8W0H*3L*("!F;W(@*'9A<B!I(&EN(&9I96QD<RD@>PH@("`@
M=F%R(&ED(#T@9FEE;&1S6VE=.PH@("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H:60I.PH@("`@<&%R86U;:61=(#T@96PN=F%L=64["B`@
M?0H@(%]?9&QG7V-L;W-E*'!A<F%M*3L*("!R971U<FX@9F%L<V4["GT["@IF
M=6YC=&EO;B!O;D-A;F-E;"@I('L*("!?7V1L9U]C;&]S92AN=6QL*3L*("!R
M971U<FX@9F%L<V4["GT["@IF=6YC=&EO;B!O;E!R979I97<H*2!["B`@=F%R
M(&9?=7)L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=7)L(BD["B`@
M=F%R('5R;"`](&9?=7)L+G9A;'5E.PH@(&EF("@A=7)L*2!["B`@("!A;&5R
M="@B66]U(&AA=F4@=&\@96YT97(@86X@55),(&9I<G-T(BD["B`@("!F7W5R
M;"YF;V-U<R@I.PH@("`@<F5T=7)N(&9A;'-E.PH@('T*("!W:6YD;W<N:7!R
M979I97<N;&]C871I;VXN<F5P;&%C92@G<VAO=VEM86=E+FAT;6P_)R`K('5R
M;"D["B`@<F5T=7)N(&9A;'-E.PI].PH*9G5N8W1I;VX@8VAA;F=E1V%L;&5R
M>2@I('L*("!V87(@<F5L;V%D7W5R;"`](&1O8W5M96YT+FQO8V%T:6]N+FAR
M968["@H@(')E;&]A9%]U<FP@("`@(#T@<F5L;V%D7W5R;"YS=6)S=')I;F<H
M,"QR96QO861?=7)L+FQA<W1);F1E>$]F*"<_)RDI.PH@(')E;&]A9%]U<FP@
M("`@(#T@<F5L;V%D7W5R;"`K("<_9V%L;&5R>3TG("L@9&]C=6UE;G0N9F]R
M;7-;,%TN9V%L;&5R>2YV86QU93L*"B`@9&]C=6UE;G0N;&]C871I;VXN<F5P
M;&%C92AR96QO861?=7)L*3L*?0H\+W-C<FEP=#X*"CQS='EL92!T>7!E/2)T
M97AT+V-S<R(^"FAT;6PL(&)O9'D@>PH@(&)A8VMG<F]U;F0Z($)U='1O;D9A
M8V4["B`@8V]L;W(Z($)U='1O;E1E>'0["B`@9F]N=#H@,3%P>"!486AO;6$L
M5F5R9&%N82QS86YS+7-E<FEF.PH@(&UA<F=I;CH@,'!X.PH@('!A9&1I;F<Z
M(#!P>#L*?0IB;V1Y('L@<&%D9&EN9SH@-7!X.R!]"G1A8FQE('L*("!F;VYT
M.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68["GT*9F]R;2!P('L*
M("!M87)G:6XM=&]P.B`U<'@["B`@;6%R9VEN+6)O='1O;3H@-7!X.PI]"BYF
M;"![('=I9'1H.B`Y96T[(&9L;V%T.B!L969T.R!P861D:6YG.B`R<'@@-7!X
M.R!T97AT+6%L:6=N.B!R:6=H=#L@?0HN9G(@>R!W:61T:#H@-F5M.R!F;&]A
M=#H@;&5F=#L@<&%D9&EN9SH@,G!X(#5P>#L@=&5X="UA;&EG;CH@<FEG:'0[
M('T*9FEE;&1S970@>R!P861D:6YG.B`P<'@@,3!P>"`U<'@@-7!X.R!]"G-E
M;&5C="P@:6YP=70L(&)U='1O;B![(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A
M;F$L<V%N<RUS97)I9CL@?0IB=71T;VX@>R!W:61T:#H@-S!P>#L@?0HN<W!A
M8V4@>R!P861D:6YG.B`R<'@[('T*"BYT:71L92![(&)A8VMG<F]U;F0Z("-D
M9&8[(&-O;&]R.B`C,#`P.R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US:7IE
M.B`Q,C`E.R!P861D:6YG.B`S<'@@,3!P>#L@;6%R9VEN+6)O='1O;3H@,3!P
M>#L*8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(&)L86-K.R!L971T97(M<W!A
M8VEN9SH@,G!X.PI]"F9O<FT@>R!P861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X
M.R!]"CPO<W1Y;&4^"@H\+VAE860^"@H\8F]D>2!O;FQO860](DEN:70H*2(^
M"@H\9&EV(&-L87-S/2)T:71L92(^26YS97)T($EM86=E/"]D:78^"CPA+2TM
M(&YE=R!S='5F9B`M+2T^"CQF;W)M(&%C=&EO;CTB(B!M971H;V0](F=E="(^
M"CQT86)L92!B;W)D97(](C`B('=I9'1H/2(Q,#`E(B!S='EL93TB<&%D9&EN
M9SH@,'!X.R!M87)G:6XZ(#!P>"(^"B`@/'1B;V1Y/@H@(#QT<CX*("`@(#QT
M9"!S='EL93TB=VED=&@Z(#=E;3L@=&5X="UA;&EG;CH@<FEG:'0B/D=A;&QE
M<GDZ/"]T9#X*("`@(#QT9#X\<V5L96-T('-I>F4](C$B(&YA;64](F=A;&QE
M<GDB(&ED/2)F7V=A;&QE<GDB('1I=&QE/2)'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;2(@;VY#:&%N9V4](F-H86YG94=A;&QE<GDH*3LB/@H\/W!H<"!F
M;W)E86-H("@D9V%L;&5R>6QI<W0@87,@)&=A;&QE<GDI.B`_/@H@("`@("`\
M;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=A
M;&QE<GDM/F=E=$E$*"DI(#\^(CP_<&AP(&EF("@D9V%L;&5R>5]I9"`]/2`D
M9V%L;&5R>2T^9V5T260H*2D@96-H;R`G('-E;&5C=&5D/2)S96QE8W1E9"(G
M(#\^/CP_<&AP(&5C:&\@<W1R7W)E<&5A="@G)FYB<W`[)RP@,B`J("1G86QL
M97)Y+3YG971,979E;"@I*2`N(&AT;6QS<&5C:6%L8VAA<G,H)&=A;&QE<GDM
M/F=E="@G;F%M92<I*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W)E86-H.R`_
M/@H@("`@/"]S96QE8W0^"B`@("`\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@
M/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T97AT+6%L:6=N.B!R:6=H="(^26UA
M9V4@9G)O;2!G86QL97)Y.CPO=&0^"B`@("`\=&0^/'-E;&5C="!S:7IE/2(Q
M(B!N86UE/2)I;6=?9V%L;&5R>2(@:60](F9?:6UG7V=A;&QE<GDB('1I=&QE
M/2));6%G92!F<F]M(&=A;&QE<GDB(&]N0VAA;F=E/2)D;V-U;65N="YF;W)M
M<ULP72YU<FPN=F%L=64@/2!D;V-U;65N="YF;W)M<ULP72YI;6=?9V%L;&5R
M>2YV86QU92(^"CP_<&AP(&9O<F5A8V@@*"1I;6%G96QI<W0@87,@)&ED(#T^
M("1I;6%G92DZ(#\^"B`@("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@
M)&EM86=E6R=U<FPG72`_/B(^/#]P:'`@96-H;R`D:6UA9V5;)VYA;64G72`_
M/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H@("`@/"]S96QE8W0^
M"B`@("`\+W1D/@H@(#PO='(^"@H@(#QT<CX*("`@(#QT9"!S='EL93TB=VED
M=&@Z(#=E;3L@=&5X="UA;&EG;CH@<FEG:'0B/DEM86=E(%523#H\+W1D/@H@
M("`@/'1D/CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)U<FPB(&ED/2)F7W5R
M;"(@<W1Y;&4](G=I9'1H.C<U)2(*("`@("`@=&ET;&4](D5N=&5R('1H92!I
M;6%G92!54DP@:&5R92(@=F%L=64](CP_<&AP(&5C:&\@)&9I<G-T7VEM86=E
M(#\^(B`O/@H@("`@("`\8G5T=&]N(&YA;64](G!R979I97<B(&]N8VQI8VL]
M(G)E='5R;B!O;E!R979I97<H*3LB"B`@("`@('1I=&QE/2)0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B/E!R979I97<\+V)U='1O;CX*("`@
M(#PO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`W
M96T[('1E>'0M86QI9VXZ(')I9VAT(CY!;'1E<FYA=&4@=&5X=#H\+W1D/@H@
M("`@/'1D/CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)A;'0B(&ED/2)F7V%L
M="(@<W1Y;&4](G=I9'1H.C$P,"4B"B`@("`@('1I=&QE/2)&;W(@8G)O=W-E
M<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(@+SX\+W1D/@H@(#PO='(^
M"@H@(#PO=&)O9'D^"CPO=&%B;&4^"@H\<"`O/@H*/&9I96QD<V5T('-T>6QE
M/2)F;&]A=#H@;&5F=#L@;6%R9VEN+6QE9G0Z(#5P>#LB/@H\;&5G96YD/DQA
M>6]U=#PO;&5G96YD/@H*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@H*/&1I
M=B!C;&%S<STB9FPB/D%L:6=N;65N=#H\+V1I=CX*/'-E;&5C="!S:7IE/2(Q
M(B!N86UE/2)A;&EG;B(@:60](F9?86QI9VXB"B`@=&ET;&4](E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B/@H@(#QO<'1I;VX@=F%L=64](B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#Y.;W0@<V5T/"]O<'1I;VX^"B`@/&]P
M=&EO;B!V86QU93TB;&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@/DQE
M9G0\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)R:6=H="(@("`@("`@("`@
M("`@("`@("`@("`@("`^4FEG:'0\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E
M/2)T97AT=&]P(B`@("`@("`@("`@("`@("`@("`@("`^5&5X='1O<#PO;W!T
M:6]N/@H@(#QO<'1I;VX@=F%L=64](F%B<VUI9&1L92(@("`@("`@("`@("`@
M("`@("`@(#Y!8G-M:61D;&4\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)B
M87-E;&EN92(@<V5L96-T960](C$B("`@("`@("`^0F%S96QI;F4\+V]P=&EO
M;CX*("`\;W!T:6]N('9A;'5E/2)A8G-B;W1T;VTB("`@("`@("`@("`@("`@
M("`@("`^06)S8F]T=&]M/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB8F]T
M=&]M(B`@("`@("`@("`@("`@("`@("`@("`@/D)O='1O;3PO;W!T:6]N/@H@
M(#QO<'1I;VX@=F%L=64](FUI9&1L92(@("`@("`@("`@("`@("`@("`@("`@
M(#Y-:61D;&4\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)T;W`B("`@("`@
M("`@("`@("`@("`@("`@("`@("`^5&]P/"]O<'1I;VX^"CPO<V5L96-T/@H*
M/'`@+SX*"CQD:78@8VQA<W,](F9L(CY";W)D97(@=&AI8VMN97-S.CPO9&EV
M/@H\:6YP=70@='EP93TB=&5X="(@;F%M93TB8F]R9&5R(B!I9#TB9E]B;W)D
M97(B('-I>F4](C4B"G1I=&QE/2),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M(B`O/@H*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@H*/"]F:65L9'-E=#X*
M"CQF:65L9'-E="!S='EL93TB9FQO870Z<FEG:'0[(&UA<F=I;BUR:6=H=#H@
M-7!X.R(^"CQL96=E;F0^4W!A8VEN9SPO;&5G96YD/@H*/&1I=B!C;&%S<STB
M<W!A8V4B/CPO9&EV/@H*/&1I=B!C;&%S<STB9G(B/DAO<FEZ;VYT86PZ/"]D
M:78^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)H;W)I>B(@:60](F9?:&]R
M:7HB('-I>F4](C4B"G1I=&QE/2)(;W)I>F]N=&%L('!A9&1I;F<B("\^"@H\
M<"`O/@H*/&1I=B!C;&%S<STB9G(B/E9E<G1I8V%L.CPO9&EV/@H\:6YP=70@
M='EP93TB=&5X="(@;F%M93TB=F5R="(@:60](F9?=F5R="(@<VEZ93TB-2(*
M=&ET;&4](E9E<G1I8V%L('!A9&1I;F<B("\^"@H\9&EV(&-L87-S/2)S<&%C
M92(^/"]D:78^"@H\+V9I96QD<V5T/@H\8G(@8VQE87(](F%L;"(@+SX*/'1A
M8FQE('=I9'1H/2(Q,#`E(B!S='EL93TB;6%R9VEN+6)O='1O;3H@,"XR96TB
M/@H@/'1R/@H@(#QT9"!V86QI9VX](F)O='1O;2(^"B`@("!);6%G92!0<F5V
M:65W.CQB<B`O/@H@("`@/&EF<F%M92!N86UE/2)I<')E=FEE=R(@:60](FEP
M<F5V:65W(B!F<F%M96)O<F1E<CTB,"(@<W1Y;&4](F)O<F1E<B`Z(#%P>"!S
M;VQI9"!G<F%Y.R(@:&5I9VAT/2(R,#`B('=I9'1H/2(S,#`B('-R8STB(CX\
M+VEF<F%M93X*("`\+W1D/@H@(#QT9"!V86QI9VX](F)O='1O;2(@<W1Y;&4]
M(G1E>'0M86QI9VXZ(')I9VAT(CX*("`@(#QB=71T;VX@='EP93TB8G5T=&]N
M(B!N86UE/2)O:R(@;VYC;&EC:STB<F5T=7)N(&]N3TLH*3LB/D]+/"]B=71T
M;VX^/&)R/@H@("`@/&)U='1O;B!T>7!E/2)B=71T;VXB(&YA;64](F-A;F-E
M;"(@;VYC;&EC:STB<F5T=7)N(&]N0V%N8V5L*"D[(CY#86YC96P\+V)U='1O
M;CX*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*/"]F;W)M/@H\+V)O9'D^"CPO
M:'1M;#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E+W-H;W=I;6%G92YH=&UL
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,C`S`#$P-#$W,S8S,#`W`#`R-S8U,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\8F]D>3X*/'-C<FEP=#X*(&1O8W5M
M96YT+G=R:71E*"<\:6UG(&AS<&%C93TB,"(@=G-P86-E/2(P(B!S<F,](B<@
M*R!D;V-U;65N="YL;V-A=&EO;BYS96%R8V@N<W5B<W1R*#$I("L@)R(^)RD[
M"CPO<V-R:7!T/@H\+V)O9'D^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!L=6=I;G,O0V]N=&5X=$UE;G4O````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,S`P-P`P,C4R-34`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]#;VYT97AT365N=2]L86YG+P``
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`W`#`R-C$W-@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T-O
M;G1E>'1-96YU+VQA;F<O96XN:G,`````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$R-S4`,3`T,3<S-C,P,#<`,#(W
M,30Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\O($DQ.$X@8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@
M551&+3@@?"!)4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT
M='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*
M+R\*+R\@("`Q+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(
M12!!0D]612!,24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@
M861D<F5S<RD*+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&
M3U(@14Y#3T1)3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE
M+"!P;&5A<V4@:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T
M97,@=VAA="!E;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*0V]N=&5X=$UE;G4N
M23$X3B`]('L*"2\O($ET96US('1H870@87!P96%R(&EN(&UE;G4N("!0;&5A
M<V4@;F]T92!T:&%T(&%N('5N9&5R<V-O<F4@*%\I"@DO+R!C:&%R86-T97(@
M:6X@=&AE('1R86YS;&%T:6]N("AR:6=H="!C;VQU;6XI('=I;&P@8V%U<V4@
M=&AE(&9O;&QO=VEN9PH)+R\@;&5T=&5R('1O(&)E8V]M92!U;F1E<FQI;F5D
M(&%N9"!B92!S:&]R=&-U="!F;W(@=&AA="!M96YU(&]P=&EO;BX*"@DB0W5T
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(D-U="(L"@DB0V]P>2(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D-O<'DB+`H)(E!A<W1E
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z(")087-T92(L"@DB26UA9V4@4')O<&5R=&EE<R(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E]);6%G92!0<F]P97)T
M:65S+BXN(BP*"2)-;V1I9GD@3&EN:R(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B7TUO9&EF>2!,:6YK+BXN(BP*"2)#
M:&5C:R!,:6YK(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B0VAE8U]K($QI;FLN+BXB+`H)(E)E;6]V92!,:6YK(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")?
M4F5M;W9E($QI;FLN+BXB+`H)(D-E;&P@4')O<&5R=&EE<R(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")#7V5L;"!0<F]P97)T
M:65S+BXN(BP*"2)2;W<@4')O<&5R=&EE<R(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B4F]?=R!0<F]P97)T:65S+BXN(BP*
M"2));G-E<G0@4F]W($)E9F]R92(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B25]N<V5R="!2;W<@0F5F;W)E(BP*"2));G-E<G0@
M4F]W($%F=&5R(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B26Y?<V5R="!2;W<@069T97(B+`H)(D1E;&5T92!2;W<B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")?1&5L
M971E(%)O=R(L"@DB1&5L971E($-E;&PB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(D1E;&5T92!#96QL(BP*"2)486)L
M92!0<F]P97)T:65S(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B7U1A8FQE(%!R;W!E<G1I97,N+BXB+`H)(DEN<V5R="!#;VQU
M;6X@0F5F;W)E(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("));G-E<G0@7T-O;'5M;B!"969O<F4B+`H)(DEN<V5R="!#;VQU;6X@069T
M97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("));G-E
M<G0@0U]O;'5M;B!!9G1E<B(L"@DB1&5L971E($-O;'5M;B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D1E7VQE=&4@0V]L
M=6UN(BP*"2)*=7-T:69Y($QE9G0B("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B2G5S=&EF>2!,969T(BP*"2)*=7-T:69Y
M($-E;G1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B2G5S=&EF>2!#96YT97(B+`H)(DIU<W1I9GD@4FEG:'0B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")*=7-T:69Y
M(%)I9VAT(BP*"2)*=7-T:69Y($9U;&PB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B2G5S=&EF>2!&=6QL(BP*"2)-86ME
M(&QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B36%K92!L:6Y?:RXN+B(L"@DB4F5M;W9E('1H92(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E)E;6]V
M92!T:&4B+`H)(D5L96UE;G0B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")%;&5M96YT+BXN(BP*"2));G-E<G0@
M<&%R86=R87!H(&)E9F]R92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B26YS97)T('!A<F%G<F%P:"!B969O<F4B+`H)(DEN<V5R="!P87)A
M9W)A<&@@869T97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("));G-E<G0@<&%R86=R87!H(&%F=&5R(BP*"@DO+R!/=&AE<B!L86)E;',@
M*'1O;VQT:7!S(&%N9"!A;&5R="]C;VYF:7)M(&)O>"!M97-S86=E<RD*"@DB
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E
M;&5M96YT.B(@(#H@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M<F5M;W9E('1H:7,@96QE;65N=#HB+`H)(E)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0B("`@("`@("`@("`@("`@("`@("`Z(")296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(BP*"2)(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*2(@("`@("`@("`@("`@("`@.B`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB+`H)(E-H
M;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(B`@("`@("`@("`@("`@
M("`@("`@("`Z(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(L
M"@DB36]D:69Y(%523"(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(DUO9&EF>2!54DPB+`H)(D-U<G)E;G0@55),(&ES
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")#
M=7)R96YT(%523"!I<R(L"@DB3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=R(@("`@("`@("`@("`@("`@("`@("`@(#H@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B+`H)(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB("`Z(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(BP*
M"2),:6YK('!O:6YT<R!T;SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B3&EN:R!P;VEN=',@=&\Z(BP*"2)5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B+`H)(E-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B("`@("`@("`@("`@("`@("`Z
M(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(BP*"2)3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B("`@("`@("`@
M("`@("`@("`@.B`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G(BP*"2));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B("`@("`@("`@("`@("`@.B`B26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(BP*"2));G-E<G0@82!N97<@<F]W(&%F=&5R('1H
M92!C=7)R96YT(&]N92(@("`@("`@("`@("`@("`@.B`B26YS97)T(&$@;F5W
M(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B+`H)(D1E;&5T92!T:&4@8W5R
M<F5N="!R;W<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W(BP*"2)3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9R(@("`@("`@("`@("`@("`@("`@("`@.B`B4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B+`H)(DEN<V5R="!A(&YE=R!C
M;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(@("`@("`@("`@("`Z("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B+`H)
M(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(B`@
M("`@("`@("`@("`Z("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N92(L"@DB1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6XB+`H)(D-R96%T92!A(&QI;FLB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")#<F5A=&4@82!L:6YK(BP*"2))
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B("`@
M("`@("`@("`@.B`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E(BP*"2));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(@("`@("`@("`@("`@.B`B26YS97)T(&$@<&%R86=R87!H
M(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"GT["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]#;VYT97AT365N=2]C;VYT97AT+6UE;G4N:G,`````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,S-34V`#$P-#$W,S8S
M,#`W`#`S,#(U,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O+R!#;VYT97AT($UE;G4@4&QU9VEN(&9O<B!(5$U,07)E82TS
M+C`*+R\@4W!O;G-O<F5D(&)Y('=W=RYA;65R:6-A;F)I8FQE+F]R9PHO+R!)
M;7!L96UE;G1A=&EO;B!B>2!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N
M8V]M+VUI<VAO;R\*+R\*+R\@*&,I(&1Y;F%R8V@N8V]M(#(P,#,M,C`P-2X*
M+R\@1&ES=')I8G5T960@=6YD97(@=&AE('-A;64@=&5R;7,@87,@2%1-3$%R
M96$@:71S96QF+@HO+R!4:&ES(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O
M<B!U<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O("1)9#H@8V]N=&5X="UM
M96YU+FIS+'8@,2XV(#(P,#4O,#$O,C`@,3<Z-#DZ,#,@;6ES:&]O($5X<"`D
M"@I(5$U,07)E82YL;V%D4W1Y;&4H(FUE;G4N8W-S(BP@(D-O;G1E>'1-96YU
M(BD["@IF=6YC=&EO;B!#;VYT97AT365N=2AE9&ET;W(I('L*"71H:7,N961I
M=&]R(#T@961I=&]R.PI].PH*0V]N=&5X=$UE;G4N7W!L=6=I;DEN9F\@/2![
M"@EN86UE("`@("`@("`@(#H@(D-O;G1E>'1-96YU(BP*"79E<G-I;VX@("`@
M("`@.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@.B`B36EH86D@0F%Z;VXB+`H)
M9&5V96QO<&5R7W5R;"`Z(")H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O+R(L
M"@EC7V]W;F5R("`@("`@(#H@(F1Y;F%R8V@N8V]M(BP*"7-P;VYS;W(@("`@
M("`@.B`B06UE<FEC86X@0FEB;&4@4V]C:65T>2(L"@ES<&]N<V]R7W5R;"`@
M(#H@(FAT='`Z+R]W=W<N86UE<FEC86YB:6)L92YO<F<B+`H);&EC96YS92`@
M("`@("`Z(")H=&UL07)E82(*?3L*"D-O;G1E>'1-96YU+G!R;W1O='EP92YO
M;D=E;F5R871E(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L9B`]('1H:7,["@EV
M87(@9&]C(#T@=&AI<RYE9&ET;W)D;V,@/2!T:&ES+F5D:71O<BY?:69R86UE
M+F-O;G1E;G17:6YD;W<N9&]C=6UE;G0["@E(5$U,07)E82Y?861D179E;G1S
M*&1O8RP@6R)C;VYT97AT;65N=2)=+`H)"0D@("`@9G5N8W1I;VX@*&5V96YT
M*2!["@D)"0D@("`@<F5T=7)N('-E;&8N<&]P=7!-96YU*$A434Q!<F5A+FES
M7VEE(#\@<V5L9BYE9&ET;W(N7VEF<F%M92YC;VYT96YT5VEN9&]W+F5V96YT
M(#H@979E;G0I.PH)"0D@("`@?2D["@ET:&ES+F-U<G)E;G1-96YU(#T@;G5L
M;#L*?3L*"D-O;G1E>'1-96YU+G!R;W1O='EP92YG971#;VYT97AT365N=2`]
M(&9U;F-T:6]N*'1A<F=E="D@>PH)=F%R('-E;&8@/2!T:&ES.PH)=F%R(&5D
M:71O<B`]('1H:7,N961I=&]R.PH)=F%R(&-O;F9I9R`](&5D:71O<BYC;VYF
M:6<["@EV87(@;65N=2`](%M=.PH)=F%R('1B;R`]('1H:7,N961I=&]R+G!L
M=6=I;G,N5&%B;&5/<&5R871I;VYS.PH):68@*'1B;RD@=&)O(#T@=&)O+FEN
M<W1A;F-E.PH)=F%R(&DQ.&X@/2!#;VYT97AT365N=2Y),3A..PH*"79A<B!S
M96QE8W1I;VX@/2!E9&ET;W(N:&%S4V5L96-T961497AT*"D["@EI9B`H<V5L
M96-T:6]N*0H)"6UE;G4N<'5S:"A;(&DQ.&Y;(D-U=")=+"!F=6YC=&EO;B@I
M('L@961I=&]R+F5X96-#;VUM86YD*")C=70B*3L@?2P@;G5L;"P@8V]N9FEG
M+F)T;DQI<W1;(F-U=")=6S%=(%TL"@D)"2`@6R!I,3AN6R)#;W!Y(ETL(&9U
M;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(F-O<'DB*3L@?2P@;G5L
M;"P@8V]N9FEG+F)T;DQI<W1;(F-O<'DB75LQ72!=*3L*"6UE;G4N<'5S:"A;
M(&DQ.&Y;(E!A<W1E(ETL(&9U;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA
M;F0H(G!A<W1E(BD[('TL(&YU;&PL(&-O;F9I9RYB=&Y,:7-T6R)P87-T92)=
M6S%=(%TI.PH*"79A<B!C=7)R96YT5&%R9V5T(#T@=&%R9V5T.PH)=F%R(&5L
M;65N=7,@/2!;73L*"79A<B!T;7`["@H)=F%R(&QI;FL@/2!N=6QL.PH)=F%R
M('1A8FQE(#T@;G5L;#L*"79A<B!T<B`](&YU;&P["@EV87(@=&0@/2!N=6QL
M.PH)=F%R(&EM9R`](&YU;&P["@H)9G5N8W1I;VX@=&%B;&5/<&5R871I;VXH
M;W!C;V1E*2!["@D)=&)O+F)U='1O;E!R97-S*&5D:71O<BP@;W!C;V1E*3L*
M"7T["@H)9G5N8W1I;VX@:6YS97)T4&%R82AC=7)R96YT5&%R9V5T+"!A9G1E
M<BD@>PH)"79A<B!E;"`](&-U<G)E;G1487)G970["@D)=F%R('!A<B`](&5L
M+G!A<F5N=$YO9&4["@D)=F%R('`@/2!E9&ET;W(N7V1O8RYC<F5A=&5%;&5M
M96YT*")P(BD["@D)<"YA<'!E;F1#:&EL9"AE9&ET;W(N7V1O8RYC<F5A=&5%
M;&5M96YT*")B<B(I*3L*"0EP87(N:6YS97)T0F5F;W)E*'`L(&%F=&5R(#\@
M96PN;F5X=%-I8FQI;F<@.B!E;"D["@D)=F%R('-E;"`](&5D:71O<BY?9V5T
M4V5L96-T:6]N*"D["@D)=F%R(')A;F=E(#T@961I=&]R+E]C<F5A=&5286YG
M92AS96PI.PH)"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0D)<V5L+G)E;6]V
M94%L;%)A;F=E<R@I.PH)"0ER86YG92YS96QE8W1.;V1E0V]N=&5N=',H<"D[
M"@D)"7)A;F=E+F-O;&QA<'-E*'1R=64I.PH)"0ES96PN861D4F%N9V4H<F%N
M9V4I.PH)"7T@96QS92!["@D)"7)A;F=E+FUO=F54;T5L96UE;G1497AT*'`I
M.PH)"0ER86YG92YC;VQL87!S92AT<G5E*3L*"0D)<F%N9V4N<V5L96-T*"D[
M"@D)?0H)?3L*"@EF;W(@*#L@=&%R9V5T.R!T87)G970@/2!T87)G970N<&%R
M96YT3F]D92D@>PH)"79A<B!T86<@/2!T87)G970N=&%G3F%M93L*"0EI9B`H
M(71A9RD*"0D)8V]N=&EN=64["@D)=&%G(#T@=&%G+G1O3&]W97)#87-E*"D[
M"@D)<W=I=&-H("AT86<I('L*"0D@("`@8V%S92`B:6UG(CH*"0D):6UG(#T@
M=&%R9V5T.PH)"0EE;&UE;G5S+G!U<V@H;G5L;"P*"0D)"2`@("`@6R!I,3AN
M6R));6%G92!0<F]P97)T:65S(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![
M"@D)"0D)("`@("`@(&5D:71O<BY?:6YS97)T26UA9V4H:6UG*3L*"0D)"2`@
M("`@("!]+`H)"0D)("`@("`@(&DQ.&Y;(E-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G(ETL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(FEN
M<V5R=&EM86=E(EU;,5T@70H)"0D)*3L*"0D)8G)E86L["@D)("`@(&-A<V4@
M(F$B.@H)"0EL:6YK(#T@=&%R9V5T.PH)"0EE;&UE;G5S+G!U<V@H;G5L;"P*
M"0D)"2`@("`@6R!I,3AN6R)-;V1I9GD@3&EN:R)=+`H)"0D)("`@("`@(&9U
M;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(F-R96%T96QI;FLB+"!T
M<G5E*3L@?2P*"0D)"2`@("`@("!I,3AN6R)#=7)R96YT(%523"!I<R)=("L@
M)SH@)R`K(&QI;FLN:')E9BP*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB
M8W)E871E;&EN:R)=6S%=(%TL"@H)"0D)("`@("!;(&DQ.&Y;(D-H96-K($QI
M;FLB72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@=VEN9&]W+F]P96XH;&EN
M:RYH<F5F*3L@?2P*"0D)"2`@("`@("!I,3AN6R)/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(ET@72P*"@D)"0D@("`@(%L@:3$X;ELB4F5M;W9E
M($QI;FLB72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L*"0D)"0D@("`@("`@
M:68@*&-O;F9I<FTH:3$X;ELB4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B)=("L@(EQN(B`K"@D)"0D)"0D@
M("!I,3AN6R),:6YK('!O:6YT<R!T;SHB72`K("(@(B`K(&QI;FLN:')E9BDI
M('L*"0D)"0D)("`@("`@('=H:6QE("AL:6YK+F9I<G-T0VAI;&0I"@D)"0D)
M"0D@("`@("`@;&EN:RYP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AL:6YK+F9I
M<G-T0VAI;&0L(&QI;FLI.PH)"0D)"0D@("`@("`@;&EN:RYP87)E;G1.;V1E
M+G)E;6]V94-H:6QD*&QI;FLI.PH)"0D)"2`@("`@("!]"@D)"0D@("`@("`@
M?2P*"0D)"2`@("`@("!I,3AN6R)5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M=")=(%T*"0D)"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")T9"(Z"@D)"71D
M(#T@=&%R9V5T.PH)"0EI9B`H(71B;RD@8G)E86L["@D)"65L;65N=7,N<'5S
M:"AN=6QL+`H)"0D)("`@("!;(&DQ.&Y;(D-E;&P@4')O<&5R=&EE<R)=+`H)
M"0D)("`@("`@(&9U;F-T:6]N*"D@>R!T86)L94]P97)A=&EO;B@B5$\M8V5L
M;"UP<F]P(BD[('TL"@D)"0D@("`@("`@:3$X;ELB4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9R)=+`H)"0D)("`@("`@(&-O;F9I9RYB
M=&Y,:7-T6R)43RUC96QL+7!R;W`B75LQ72!=+`H)"0D)("`@("!;(&DQ.&Y;
M(D1E;&5T92!#96QL(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE
M3W!E<F%T:6]N*")43RUC96QL+61E;&5T92(I.R!]+"!N=6QL+`H)"0D)("`@
M("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUC96QL+61E;&5T92)=6S%=(%T*"0D)
M"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")T<B(Z"@D)"71R(#T@=&%R9V5T
M.PH)"0EI9B`H(71B;RD@8G)E86L["@D)"65L;65N=7,N<'5S:"AN=6QL+`H)
M"0D)("`@("!;(&DQ.&Y;(E)O=R!0<F]P97)T:65S(ETL"@D)"0D@("`@("`@
M9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUR;W<M<')O<"(I.R!]
M+`H)"0D)("`@("`@(&DQ.&Y;(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9R)=+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUR
M;W<M<')O<")=6S%=(%TL"@H)"0D)("`@("!;(&DQ.&Y;(DEN<V5R="!2;W<@
M0F5F;W)E(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T
M:6]N*")43RUR;W<M:6YS97)T+6%B;W9E(BD[('TL"@D)"0D@("`@("`@:3$X
M;ELB26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(ETL
M"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(E1/+7)O=RUI;G-E<G0M86)O
M=F4B75LQ72!=+`H*"0D)"2`@("`@6R!I,3AN6R));G-E<G0@4F]W($%F=&5R
M(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")4
M3RUR;W<M:6YS97)T+75N9&5R(BD[('TL"@D)"0D@("`@("`@:3$X;ELB26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B72P*"0D)"2`@
M("`@("!C;VYF:6<N8G1N3&ES=%LB5$\M<F]W+6EN<V5R="UU;F1E<B)=6S%=
M(%TL"@H)"0D)("`@("!;(&DQ.&Y;(D1E;&5T92!2;W<B72P*"0D)"2`@("`@
M("!F=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+7)O=RUD96QE=&4B
M*3L@?2P*"0D)"2`@("`@("!I,3AN6R)$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M(ETL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(E1/+7)O=RUD96QE=&4B
M75LQ72!="@D)"0DI.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B=&%B;&4B.@H)
M"0ET86)L92`]('1A<F=E=#L*"0D):68@*"%T8F\I(&)R96%K.PH)"0EE;&UE
M;G5S+G!U<V@H;G5L;"P*"0D)"2`@("`@6R!I,3AN6R)486)L92!0<F]P97)T
M:65S(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N
M*")43RUT86)L92UP<F]P(BD[('TL"@D)"0D@("`@("`@:3$X;ELB4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B72P*"0D)"2`@("`@("!C;VYF
M:6<N8G1N3&ES=%LB5$\M=&%B;&4M<')O<")=6S%=(%TL"@H)"0D)("`@("!;
M(&DQ.&Y;(DEN<V5R="!#;VQU;6X@0F5F;W)E(ETL"@D)"0D@("`@("`@9G5N
M8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUC;VPM:6YS97)T+6)E9F]R
M92(I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92)=+`H)"0D)("`@("`@(&-O;F9I9RYB
M=&Y,:7-T6R)43RUC;VPM:6YS97)T+6)E9F]R92)=6S%=(%TL"@H)"0D)("`@
M("!;(&DQ.&Y;(DEN<V5R="!#;VQU;6X@069T97(B72P*"0D)"2`@("`@("!F
M=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+6-O;"UI;G-E<G0M869T
M97(B*3L@?2P*"0D)"2`@("`@("!I,3AN6R));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92)=+`H)"0D)("`@("`@(&-O;F9I9RYB
M=&Y,:7-T6R)43RUC;VPM:6YS97)T+6%F=&5R(EU;,5T@72P*"@D)"0D@("`@
M(%L@:3$X;ELB1&5L971E($-O;'5M;B)=+`H)"0D)("`@("`@(&9U;F-T:6]N
M*"D@>R!T86)L94]P97)A=&EO;B@B5$\M8V]L+61E;&5T92(I.R!]+`H)"0D)
M("`@("`@(&DQ.&Y;(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB72P*"0D)
M"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB5$\M8V]L+61E;&5T92)=6S%=(%T*
M"0D)"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")B;V1Y(CH*"0D)96QM96YU
M<RYP=7-H*&YU;&PL"@D)"0D@("`@(%L@:3$X;ELB2G5S=&EF>2!,969T(ETL
M"@D)"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B
M:G5S=&EF>6QE9G0B*3L@?2P@;G5L;"P*"0D)"2`@("`@("!C;VYF:6<N8G1N
M3&ES=%LB:G5S=&EF>6QE9G0B75LQ72!=+`H)"0D)("`@("!;(&DQ.&Y;(DIU
M<W1I9GD@0V5N=&5R(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O
M<BYE>&5C0V]M;6%N9"@B:G5S=&EF>6-E;G1E<B(I.R!]+"!N=6QL+`H)"0D)
M("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)J=7-T:69Y8V5N=&5R(EU;,5T@72P*
M"0D)"2`@("`@6R!I,3AN6R)*=7-T:69Y(%)I9VAT(ETL"@D)"0D@("`@("`@
M9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B:G5S=&EF>7)I9VAT
M(BD[('TL(&YU;&PL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(FIU<W1I
M9GER:6=H=")=6S%=(%TL"@D)"0D@("`@(%L@:3$X;ELB2G5S=&EF>2!&=6QL
M(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N
M9"@B:G5S=&EF>69U;&PB*3L@?2P@;G5L;"P*"0D)"2`@("`@("!C;VYF:6<N
M8G1N3&ES=%LB:G5S=&EF>69U;&PB75LQ72!="@D)"0DI.PH)"0EB<F5A:SL*
M"0E]"@E]"@H):68@*'-E;&5C=&EO;B`F)B`A;&EN:RD*"0EM96YU+G!U<V@H
M;G5L;"P@6R!I,3AN6R)-86ME(&QI;FLB72P*"0D)"2`@9G5N8W1I;VXH*2![
M(&5D:71O<BYE>&5C0V]M;6%N9"@B8W)E871E;&EN:R(L('1R=64I.R!]+`H)
M"0D)("!I,3AN6R)#<F5A=&4@82!L:6YK(ETL"@D)"0D@(&-O;F9I9RYB=&Y,
M:7-T6R)C<F5A=&5L:6YK(EU;,5T@72D["@H)9F]R("AV87(@:2`](#`[(&D@
M/"!E;&UE;G5S+FQE;F=T:#L@*RMI*0H)"6UE;G4N<'5S:"AE;&UE;G5S6VE=
M*3L*"@EI9B`H(2]H=&UL?&)O9'DO:2YT97-T*&-U<G)E;G1487)G970N=&%G
M3F%M92DI('L*"0ET86)L92`_("AT;7`@/2!T86)L92P@=&%B;&4@/2!N=6QL
M*2`Z("AT;7`@/2!C=7)R96YT5&%R9V5T*3L*"0EM96YU+G!U<V@H;G5L;"P*
M"0D)("!;(&DQ.&Y;(E)E;6]V92!T:&4B72`K("(@)FQT.R(@*R!T;7`N=&%G
M3F%M92`K("(F9W0[("(@*R!I,3AN6R)%;&5M96YT(ETL"@D)"2`@("!F=6YC
M=&EO;B@I('L*"0D)"2`@("!I9B`H8V]N9FER;2AI,3AN6R)0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(ET@
M*R`B("(@*PH)"0D)"0ET;7`N=&%G3F%M92DI('L*"0D)"0D@("`@=F%R(&5L
M(#T@=&UP.PH)"0D)"2`@("!V87(@<"`](&5L+G!A<F5N=$YO9&4["@D)"0D)
M("`@('`N<F5M;W9E0VAI;&0H96PI.PH)"0D)"2`@("!I9B`H2%1-3$%R96$N
M:7-?9V5C:V\I('L*"0D)"0D)("`@(&EF("AP+G1A9TYA;64N=&],;W=E<D-A
M<V4H*2`]/2`B=&0B("8F("%P+FAA<T-H:6QD3F]D97,H*2D*"0D)"0D)"2`@
M("!P+F%P<&5N9$-H:6QD*&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(F)R
M(BDI.PH)"0D)"0D@("`@961I=&]R+F9O<F-E4F5D<F%W*"D["@D)"0D)"2`@
M("!E9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0D)"0D)("`@(&5D:71O<BYU<&1A
M=&54;V]L8F%R*"D["@D)"0D)"2`@("!I9B`H=&%B;&4I('L*"0D)"0D)"2`@
M("!V87(@<V%V95]C;VQL87!S92`]('1A8FQE+G-T>6QE+F)O<F1E<D-O;&QA
M<'-E.PH)"0D)"0D)("`@('1A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@
M(F-O;&QA<'-E(CL*"0D)"0D)"2`@("!T86)L92YS='EL92YB;W)D97)#;VQL
M87!S92`](")S97!A<F%T92(["@D)"0D)"0D@("`@=&%B;&4N<W1Y;&4N8F]R
M9&5R0V]L;&%P<V4@/2!S879E7V-O;&QA<'-E.PH)"0D)"0D@("`@?0H)"0D)
M"2`@("!]"@D)"0D@("`@?0H)"0D@("`@?2P*"0D)("`@(&DQ.&Y;(E)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B72!=+`H)"0D@(%L@:3$X
M;ELB26YS97)T('!A<F%G<F%P:"!B969O<F4B72P*"0D)("`@(&9U;F-T:6]N
M*"D@>R!I;G-E<G1087)A*'1M<"P@9F%L<V4I.R!]+`H)"0D@("`@:3$X;ELB
M26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(ET@
M72P*"0D)("!;(&DQ.&Y;(DEN<V5R="!P87)A9W)A<&@@869T97(B72P*"0D)
M("`@(&9U;F-T:6]N*"D@>R!I;G-E<G1087)A*'1M<"P@=')U92D[('TL"@D)
M"2`@("!I,3AN6R));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D92)=(%T*"0D)*3L*"7T*"7)E='5R;B!M96YU.PI].PH*0V]N=&5X
M=$UE;G4N<')O=&]T>7!E+G!O<'5P365N=2`](&9U;F-T:6]N*&5V*2!["@EV
M87(@<V5L9B`]('1H:7,["@EV87(@:3$X;B`]($-O;G1E>'1-96YU+DDQ.$X[
M"@EI9B`H=&AI<RYC=7)R96YT365N=2D*"0ET:&ES+F-U<G)E;G1-96YU+G!A
M<F5N=$YO9&4N<F5M;W9E0VAI;&0H=&AI<RYC=7)R96YT365N=2D["@EF=6YC
M=&EO;B!G9710;W,H96PI('L*"0EV87(@<B`]('L@>#H@96PN;V9F<V5T3&5F
M="P@>3H@96PN;V9F<V5T5&]P('T["@D):68@*&5L+F]F9G-E=%!A<F5N="D@
M>PH)"0EV87(@=&UP(#T@9V5T4&]S*&5L+F]F9G-E=%!A<F5N="D["@D)"7(N
M>"`K/2!T;7`N>#L*"0D)<BYY("L]('1M<"YY.PH)"7T*"0ER971U<FX@<CL*
M"7T["@EF=6YC=&EO;B!D;V-U;65N=$-L:6-K*&5V*2!["@D)978@?'P@*&5V
M(#T@=VEN9&]W+F5V96YT*3L*"0EI9B`H(7-E;&8N8W5R<F5N=$UE;G4I('L*
M"0D)86QE<G0H:3$X;ELB2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@
M<F5P;W)T(2DB72D["@D)"7)E='5R;B!F86QS93L*"0E]"@D)=F%R(&5L(#T@
M2%1-3$%R96$N:7-?:64@/R!E=BYS<F-%;&5M96YT(#H@978N=&%R9V5T.PH)
M"69O<B`H.R!E;"`A/2!N=6QL("8F(&5L("$]('-E;&8N8W5R<F5N=$UE;G4[
M(&5L(#T@96PN<&%R96YT3F]D92D["@D):68@*&5L(#T](&YU;&PI"@D)"7-E
M;&8N8VQO<V5-96YU*"D["@D)+R](5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*
M"0DO+W)E='5R;B!F86QS93L*"7T["@EV87(@:V5Y<R`](%M=.PH)9G5N8W1I
M;VX@:V5Y4')E<W,H978I('L*"0EE=B!\?"`H978@/2!W:6YD;W<N979E;G0I
M.PH)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)"6EF("AE=BYK97E#;V1E
M(#T](#(W*2!["@D)"7-E;&8N8VQO<V5-96YU*"D["@D)"7)E='5R;B!F86QS
M93L*"0E]"@D)=F%R(&ME>2`](%-T<FEN9RYF<F]M0VAA<D-O9&4H2%1-3$%R
M96$N:7-?:64@/R!E=BYK97E#;V1E(#H@978N8VAA<D-O9&4I+G1O3&]W97)#
M87-E*"D["@D)9F]R("AV87(@:2`](&ME>7,N;&5N9W1H.R`M+6D@/CT@,#LI
M('L*"0D)=F%R(&L@/2!K97ES6VE=.PH)"0EI9B`H:ULP72YT;TQO=V5R0V%S
M92@I(#T](&ME>2D*"0D)"6M;,5TN7U]M<V@N86-T:79A=&4H*3L*"0E]"@E]
M.PH)<V5L9BYC;&]S94UE;G4@/2!F=6YC=&EO;B@I('L*"0ES96QF+F-U<G)E
M;G1-96YU+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H<V5L9BYC=7)R96YT365N
M=2D["@D)<V5L9BYC=7)R96YT365N=2`](&YU;&P["@D)2%1-3$%R96$N7W)E
M;6]V945V96YT*&1O8W5M96YT+"`B;6]U<V5D;W=N(BP@9&]C=6UE;G1#;&EC
M:RD["@D)2%1-3$%R96$N7W)E;6]V945V96YT*'-E;&8N961I=&]R9&]C+"`B
M;6]U<V5D;W=N(BP@9&]C=6UE;G1#;&EC:RD["@D):68@*&ME>7,N;&5N9W1H
M(#X@,"D*"0D)2%1-3$%R96$N7W)E;6]V945V96YT*'-E;&8N961I=&]R9&]C
M+"`B:V5Y<')E<W,B+"!K97E0<F5S<RD["@D):68@*$A434Q!<F5A+FES7VEE
M*0H)"0ES96QF+FEE4&]P=7`N:&ED92@I.PH)?3L*"79A<B!T87)G970@/2!(
M5$U,07)E82YI<U]I92`_(&5V+G-R8T5L96UE;G0@.B!E=BYT87)G970["@EV
M87(@:69P;W,@/2!G9710;W,H<V5L9BYE9&ET;W(N7VEF<F%M92D["@EV87(@
M>"`](&5V+F-L:65N=%@@*R!I9G!O<RYX.PH)=F%R('D@/2!E=BYC;&EE;G19
M("L@:69P;W,N>3L*"@EV87(@9&EV.PH)=F%R(&1O8SL*"6EF("@A2%1-3$%R
M96$N:7-?:64I('L*"0ED;V,@/2!D;V-U;65N=#L*"7T@96QS92!["@D)+R\@
M244@<W1I;FMS"@D)=F%R('!O<'5P(#T@=&AI<RYI95!O<'5P(#T@=VEN9&]W
M+F-R96%T95!O<'5P*"D["@D)9&]C(#T@<&]P=7`N9&]C=6UE;G0["@D)9&]C
M+F]P96XH*3L*"0ED;V,N=W)I=&4H(CQH=&UL/CQH96%D/CQS='EL92!T>7!E
M/2=T97AT+V-S<R<^0&EM<&]R="!U<FPH(B`K(%]E9&ET;W)?=7)L("L@(G!L
M=6=I;G,O0V]N=&5X=$UE;G4O;65N=2YC<W,I.R!H=&UL+"!B;V1Y('L@<&%D
M9&EN9SH@,'!X.R!M87)G:6XZ(#!P>#L@;W9E<F9L;W<Z(&AI9&1E;CL@8F]R
M9&5R.B`P<'@[('T\+W-T>6QE/CPO:&5A9#X\8F]D>2!U;G-E;&5C=&%B;&4]
M)WEE<R<^/"]B;V1Y/CPO:'1M;#XB*3L*"0ED;V,N8VQO<V4H*3L*"7T*"61I
M=B`](&1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"6EF("A(5$U,07)E82YI
M<U]I92D*"0ED:78N=6YS96QE8W1A8FQE(#T@(F]N(CL*"61I=BYO;F-O;G1E
M>'1M96YU(#T@9G5N8W1I;VXH*2![(')E='5R;B!F86QS93L@?3L*"61I=BYC
M;&%S<TYA;64@/2`B:'1M;&%R96$M8V]N=&5X="UM96YU(CL*"6EF("@A2%1-
M3$%R96$N:7-?:64I"@D)9&EV+G-T>6QE+FQE9G0@/2!D:78N<W1Y;&4N=&]P
M(#T@(C!P>"(["@ED;V,N8F]D>2YA<'!E;F1#:&EL9"AD:78I.PH*"79A<B!T
M86)L92`](&1O8RYC<F5A=&5%;&5M96YT*")T86)L92(I.PH)9&EV+F%P<&5N
M9$-H:6QD*'1A8FQE*3L*"71A8FQE+F-E;&Q3<&%C:6YG(#T@,#L*"71A8FQE
M+F-E;&Q0861D:6YG(#T@,#L*"79A<B!P87)E;G0@/2!D;V,N8W)E871E16QE
M;65N="@B=&)O9'DB*3L*"71A8FQE+F%P<&5N9$-H:6QD*'!A<F5N="D["@H)
M=F%R(&]P=&EO;G,@/2!T:&ES+F=E=$-O;G1E>'1-96YU*'1A<F=E="D["@EF
M;W(@*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N;&5N9W1H.R`K*VDI('L*"0EV
M87(@;W!T:6]N(#T@;W!T:6]N<UMI73L*"0EV87(@:71E;2`](&1O8RYC<F5A
M=&5%;&5M96YT*")T<B(I.PH)"7!A<F5N="YA<'!E;F1#:&EL9"AI=&5M*3L*
M"0EI9B`H2%1-3$%R96$N:7-?:64I"@D)"6ET96TN=6YS96QE8W1A8FQE(#T@
M(F]N(CL*"0EE;'-E(&ET96TN;VYM;W5S961O=VX@/2!F=6YC=&EO;BAE=BD@
M>PH)"0E(5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*"0D)<F5T=7)N(&9A;'-E
M.PH)"7T["@D):68@*"%O<'1I;VXI('L*"0D):71E;2YC;&%S<TYA;64@/2`B
M<V5P87)A=&]R(CL*"0D)=F%R('1D(#T@9&]C+F-R96%T945L96UE;G0H(G1D
M(BD["@D)"71D+F-L87-S3F%M92`](")I8V]N(CL*"0D)=F%R($E%7TE37T%?
M1E5#2TE.1U]32$E4(#T@)SXG.PH)"0EI9B`H2%1-3$%R96$N:7-?:64I('L*
M"0D)"71D+G5N<V5L96-T86)L92`](")O;B(["@D)"0E)15])4U]!7T950TM)
M3D=?4TA)5"`]("(@=6YS96QE8W1A8FQE/2=O;B<@<W1Y;&4])VAE:6=H=#TQ
M<'@G/B9N8G-P.R(["@D)"7T*"0D)=&0N:6YN97)(5$U,(#T@(CQD:78B("L@
M245?25-?05]&54-+24Y'7U-(250@*R`B/"]D:78^(CL*"0D)=F%R('1D,2`]
M('1D+F-L;VYE3F]D92AT<G5E*3L*"0D)=&0Q+F-L87-S3F%M92`](")L86)E
M;"(["@D)"6ET96TN87!P96YD0VAI;&0H=&0I.PH)"0EI=&5M+F%P<&5N9$-H
M:6QD*'1D,2D["@D)?2!E;'-E('L*"0D)=F%R(&QA8F5L(#T@;W!T:6]N6S!=
M.PH)"0EI=&5M+F-L87-S3F%M92`](")I=&5M(CL*"0D):71E;2Y?7VUS:"`]
M('L*"0D)"6ET96TZ(&ET96TL"@D)"0EL86)E;#H@;&%B96PL"@D)"0EA8W1I
M;VXZ(&]P=&EO;ELQ72P*"0D)"71O;VQT:7`Z(&]P=&EO;ELR72!\?"!N=6QL
M+`H)"0D):6-O;CH@;W!T:6]N6S-=('Q\(&YU;&PL"@D)"0EA8W1I=F%T93H@
M9G5N8W1I;VXH*2!["@D)"0D)<V5L9BYC;&]S94UE;G4H*3L*"0D)"0ES96QF
M+F5D:71O<BYF;V-U<T5D:71O<B@I.PH)"0D)"71H:7,N86-T:6]N*"D["@D)
M"0E]"@D)"7T["@D)"6QA8F5L(#T@;&%B96PN<F5P;&%C92@O7RA;82UZ02U:
M,"TY72DO+"`B/'4^)#$\+W4^(BD["@D)"6EF("AL86)E;"`A/2!O<'1I;VY;
M,%TI"@D)"0EK97ES+G!U<V@H6R!296=%>'`N)#$L(&ET96T@72D["@D)"6QA
M8F5L(#T@;&%B96PN<F5P;&%C92@O7U\O+"`B7R(I.PH)"0EV87(@=&0Q(#T@
M9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)"6EF("A(5$U,07)E82YI<U]I
M92D*"0D)"71D,2YU;G-E;&5C=&%B;&4@/2`B;VXB.PH)"0EI=&5M+F%P<&5N
M9$-H:6QD*'1D,2D["@D)"71D,2YC;&%S<TYA;64@/2`B:6-O;B(["@D)"6EF
M("AI=&5M+E]?;7-H+FEC;VXI"@D)"0ET9#$N:6YN97)(5$U,(#T@(CQI;6<@
M86QI9VX])VUI9&1L92<@<W)C/2<B("L@:71E;2Y?7VUS:"YI8V]N("L@(B<@
M+SXB.PH)"0EV87(@=&0R(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)
M"6EF("A(5$U,07)E82YI<U]I92D*"0D)"71D,BYU;G-E;&5C=&%B;&4@/2`B
M;VXB.PH)"0EI=&5M+F%P<&5N9$-H:6QD*'1D,BD["@D)"71D,BYC;&%S<TYA
M;64@/2`B;&%B96PB.PH)"0ET9#(N:6YN97)(5$U,(#T@;&%B96P["@D)"6ET
M96TN;VYM;W5S96]V97(@/2!F=6YC=&EO;B@I('L*"0D)"71H:7,N8VQA<W-.
M86UE("L]("(@:&]V97(B.PH)"0D)<V5L9BYE9&ET;W(N7W-T871U<T)A<E1R
M964N:6YN97)(5$U,(#T@=&AI<RY?7VUS:"YT;V]L=&EP('Q\("<F;F)S<#LG
M.PH)"0E].PH)"0EI=&5M+F]N;6]U<V5O=70@/2!F=6YC=&EO;B@I('L@=&AI
M<RYC;&%S<TYA;64@/2`B:71E;2([('T["@D)"6ET96TN;VYC;VYT97AT;65N
M=2`](&9U;F-T:6]N*&5V*2!["@D)"0ET:&ES+E]?;7-H+F%C=&EV871E*"D[
M"@D)"0EI9B`H(4A434Q!<F5A+FES7VEE*0H)"0D)"4A434Q!<F5A+E]S=&]P
M179E;G0H978I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E].PH)"0EI=&5M+F]N
M;6]U<V5U<"`](&9U;F-T:6]N*&5V*2!["@D)"0EV87(@=&EM95-T86UP(#T@
M*&YE=R!$871E*"DI+F=E=%1I;64H*3L*"0D)"6EF("AT:6UE4W1A;7`@+2!S
M96QF+G1I;653=&%M<"`^(#4P,"D*"0D)"0ET:&ES+E]?;7-H+F%C=&EV871E
M*"D["@D)"0EI9B`H(4A434Q!<F5A+FES7VEE*0H)"0D)"4A434Q!<F5A+E]S
M=&]P179E;G0H978I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E].PH)"0DO+VEF
M("AT>7!E;V8@;W!T:6]N6S)=(#T](")S=')I;F<B*0H)"0DO+VET96TN=&ET
M;&4@/2!O<'1I;VY;,ET["@D)?0H)?0H*"6EF("@A2%1-3$%R96$N:7-?:64I
M('L*"0EV87(@9'@@/2!X("L@9&EV+F]F9G-E=%=I9'1H("T@=VEN9&]W+FEN
M;F5R5VED=&@@*R`T.PH)"79A<B!D>2`]('D@*R!D:78N;V9F<V5T2&5I9VAT
M("T@=VEN9&]W+FEN;F5R2&5I9VAT("L@-#L*"0EI9B`H9'@@/B`P*2!X("T]
M(&1X.PH)"6EF("AD>2`^(#`I('D@+3T@9'D["@D)9&EV+G-T>6QE+FQE9G0@
M/2!X("L@(G!X(CL*"0ED:78N<W1Y;&4N=&]P(#T@>2`K(")P>"(["@E](&5L
M<V4@>PH)"2\O(&1E=&5R;6EN92!T:&4@<VEZ92`H9&ED($D@;65N=&EO;B!T
M:&%T($E%('-T:6YK<S\I"@D)=F%R(&9O;V)A<B`](&1O8W5M96YT+F-R96%T
M945L96UE;G0H(F1I=B(I.PH)"69O;V)A<BYC;&%S<TYA;64@/2`B:'1M;&%R
M96$M8V]N=&5X="UM96YU(CL*"0EF;V]B87(N:6YN97)(5$U,(#T@9&EV+FEN
M;F5R2%1-3#L*"0ED;V-U;65N="YB;V1Y+F%P<&5N9$-H:6QD*&9O;V)A<BD[
M"@D)=F%R('<@/2!F;V]B87(N;V9F<V5T5VED=&@["@D)=F%R(&@@/2!F;V]B
M87(N;V9F<V5T2&5I9VAT.PH)"61O8W5M96YT+F)O9'DN<F5M;W9E0VAI;&0H
M9F]O8F%R*3L*"0ET:&ES+FEE4&]P=7`N<VAO=RAE=BYS8W)E96Y8+"!E=BYS
M8W)E96Y9+"!W+"!H*3L*"7T*"@ET:&ES+F-U<G)E;G1-96YU(#T@9&EV.PH)
M=&AI<RYT:6UE4W1A;7`@/2`H;F5W($1A=&4H*2DN9V5T5&EM92@I.PH*"4A4
M34Q!<F5A+E]A9&1%=F5N="AD;V-U;65N="P@(FUO=7-E9&]W;B(L(&1O8W5M
M96YT0VQI8VLI.PH)2%1-3$%R96$N7V%D9$5V96YT*'1H:7,N961I=&]R9&]C
M+"`B;6]U<V5D;W=N(BP@9&]C=6UE;G1#;&EC:RD["@EI9B`H:V5Y<RYL96YG
M=&@@/B`P*0H)"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F5D:71O<F1O8RP@
M(FME>7!R97-S(BP@:V5Y4')E<W,I.PH*"4A434Q!<F5A+E]S=&]P179E;G0H
M978I.PH)<F5T=7)N(&9A;'-E.PI].PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O0V]N=&5X=$UE;G4O;65N=2YC<W,````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0U-P`Q,#0Q-S,V,S`P
M-P`P,C8W-#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RH@<W1Y;&5S(&9O<B!T:&4@0V]N=&5X=$UE;G4@+TA434Q!<F5A
M("HO"B\J(%1H92!#;VYT97AT365N=2!P;'5G:6X@:7,@*&,I(&1Y;F%R8V@N
M8V]M(#(P,#,N("HO"B\J($1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE('1E
M<FUS(&%S($A434Q!<F5A(&ET<V5L9B`J+PH*9&EV+FAT;6QA<F5A+6-O;G1E
M>'0M;65N=2!["B`@<&]S:71I;VXZ(&%B<V]L=71E.PH@(&)O<F1E<CH@,7!X
M('-O;&ED("-A8V$X.3D["B`@<&%D9&EN9SH@,G!X.PH@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-F9F8["B`@8V]L;W(Z(",P,#`["B`@8W5R<V]R.B!D969A=6QT
M.PH@('HM:6YD97@Z(#$P,#`["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE
M;G4@=&%B;&4@>PH@(&9O;G0Z(#$Q<'@@=&%H;VUA+'9E<F1A;F$L<V%N<RUS
M97)I9CL*("!B;W)D97(M8V]L;&%P<V4Z(&-O;&QA<'-E.PI]"@ID:78N:'1M
M;&%R96$M8V]N=&5X="UM96YU('1R+FET96T@=&0N:6-O;B!I;6<@>PH@('=I
M9'1H.B`Q.'!X.PH@(&AE:6=H=#H@,3AP>#L*?0H*9&EV+FAT;6QA<F5A+6-O
M;G1E>'0M;65N=2!T<BYI=&5M('1D+FEC;VX@>PH@('!A9&1I;F<Z(#!P>"`S
M<'@["B`@:&5I9VAT.B`Q.'!X.PH@(&)A8VMG<F]U;F0M8V]L;W(Z("-C9&8[
M"GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N:71E;2!T9"YL86)E
M;"!["B`@<&%D9&EN9SH@,7!X(#$P<'@@,7!X(#-P>#L*?0H*9&EV+FAT;6QA
M<F5A+6-O;G1E>'0M;65N=2!T<BYS97!A<F%T;W(@=&0@>PH@('!A9&1I;F<Z
M(#)P>"`P<'@["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N<V5P
M87)A=&]R('1D(&1I=B!["B`@8F]R9&5R+71O<#H@,7!X('-O;&ED("-A8V$X
M.3D["B`@;W9E<F9L;W<Z(&AI9&1E;CL*("!P;W-I=&EO;CH@<F5L871I=F4[
M"GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N<V5P87)A=&]R('1D
M+FEC;VX@>PH@(&)A8VMG<F]U;F0M8V]L;W(Z("-C9&8["GT*"F1I=BYH=&UL
M87)E82UC;VYT97AT+6UE;G4@='(N<V5P87)A=&]R('1D+FEC;VX@9&EV('L*
M+RH@(&UA<F=I;BUL969T.B`S<'@[("HO"B`@8F]R9&5R+6-O;&]R.B`C9F9F
M.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R+G-E<&%R871O<B!T
M9"YL86)E;"!D:78@>PH@(&UA<F=I;BUR:6=H=#H@,W!X.PI]"@ID:78N:'1M
M;&%R96$M8V]N=&5X="UM96YU('1R+FET96TN:&]V97(@>PH@(&)A8VMG<F]U
M;F0M8V]L;W(Z(",S,39A8S4["B`@8V]L;W(Z("-F9F8["GT*"F1I=BYH=&UL
M87)E82UC;VYT97AT+6UE;G4@='(N:71E;2YH;W9E<B!T9"YI8V]N('L*("!B
M86-K9W)O=6YD+6-O;&]R.B`C-C$Y868U.PI]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R],:7-T5'EP92\`````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`W`#`R-#4V,0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+TQI
M<W14>7!E+VQA;F<O````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#<`,#(U
M-3`R`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+W!L=6=I;G,O3&ES=%1Y<&4O;&%N9R]E;BYJ<P``````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,30U
M,0`Q,#0Q-S,V,S`P-P`P,C8T-#``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z
M(")E;B(L($5.0T]$24Y'.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T:&]R
M.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@
M1D]2(%1204Y33$%43U)3.@HO+PHO+R`@(#$N(%!,14%312!0550@64]54B!#
M3TY404-4($E.1D\@24X@5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@;&5A
M<W0@82!V86QI9"!E;6%I;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%312!4
M4ED@5$\@55-%(%541BTX($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@=&AI
M<R!I<R!N;W0@<&]S<VEB;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N=`HO
M+R`@("`@("!T:&%T('-T871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R
M>2XI"@I,:7-T5'EP92Y),3A.(#T@>PH)(D1E8VEM86PB("`@("`@("`@("`@
M("`@(#H@("`@(D1E8VEM86P@;G5M8F5R<R(L"@DB3&]W97(@<F]M86XB("`@
M("`@("`@("`@.B`@("`B3&]W97(@<F]M86X@;G5M8F5R<R(L"@DB57!P97(@
M<F]M86XB("`@("`@("`@("`@.B`@("`B57!P97(@<F]M86X@;G5M8F5R<R(L
M"@DB3&]W97(@;&%T:6XB("`@("`@("`@("`@.B`@("`B3&]W97(@;&%T:6X@
M;&5T=&5R<R(L"@DB57!P97(@;&%T:6XB("`@("`@("`@("`@.B`@("`B57!P
M97(@;&%T:6X@;&5T=&5R<R(L"@DB3&]W97(@9W)E96LB("`@("`@("`@("`@
M.B`@("`B3&]W97(@9W)E96L@;&5T=&5R<R(L"@DB3&ES=%-T>6QE5&]O;'1I
M<"(@("`@("`@.B`@("`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R
M9&5R960@;&ES=',I(@I].PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!L=6=I;G,O3&ES=%1Y<&4O;&ES="UT>7!E+FIS````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-3$V,P`Q,#0Q-S,V,S`P-P`P,C<P-3,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+R\@3&ES=%1Y<&4@4&QU9VEN(&9O
M<B!(5$U,07)E82TS+C`*+R\@4W!O;G-O<F5D(&)Y($U%9%1E8V@@56YI="`M
M(%%U965N)W,@56YI=F5R<VET>0HO+R!);7!L96UE;G1A=&EO;B!B>2!-:6AA
M:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;R\*+R\*+R\@*&,I
M(&1Y;F%R8V@N8V]M(#(P,#,M,C`P-2X*+R\@1&ES=')I8G5T960@=6YD97(@
M=&AE('-A;64@=&5R;7,@87,@2%1-3$%R96$@:71S96QF+@HO+R!4:&ES(&YO
M=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U<V4@*'-E92!L:6-E;G-E+G1X
M="DN"B\O"B\O("1)9#H@;&ES="UT>7!E+FIS+'8@,2XR(#(P,#4O,#$O,C`@
M,3<Z-#DZ,#,@;6ES:&]O($5X<"`D"@IF=6YC=&EO;B!,:7-T5'EP92AE9&ET
M;W(I('L*"71H:7,N961I=&]R(#T@961I=&]R.PH)=F%R(&-F9R`](&5D:71O
M<BYC;VYF:6<["@EV87(@=&]O;&)A<B`](&-F9RYT;V]L8F%R.PH)=F%R('-E
M;&8@/2!T:&ES.PH)=F%R(&DQ.&X@/2!,:7-T5'EP92Y),3A..PH)=F%R(&]P
M=&EO;G,@/2![?3L*"6]P=&EO;G-;:3$X;ELB1&5C:6UA;")=72`](")D96-I
M;6%L(CL*"6]P=&EO;G-;:3$X;ELB3&]W97(@<F]M86XB75T@/2`B;&]W97(M
M<F]M86XB.PH);W!T:6]N<UMI,3AN6R)5<'!E<B!R;VUA;B)=72`](")U<'!E
M<BUR;VUA;B(["@EO<'1I;VYS6VDQ.&Y;(DQO=V5R(&QA=&EN(EU=(#T@(FQO
M=V5R+6%L<&AA(CL*"6]P=&EO;G-;:3$X;ELB57!P97(@;&%T:6XB75T@/2`B
M=7!P97(M86QP:&$B.PH):68@*"%(5$U,07)E82YI<U]I92D*"0DO+R!)12!D
M;V5S;B=T('-U<'!O<G0@=&AI<R!P<F]P97)T>3L@979E;B!W;W)S92P@:70@
M8V]M<&QA:6YS"@D)+R\@=VET:"!A(&=R;W-S(&5R<F]R(&UE<W-A9V4@=VAE
M;B!W92!T<FEE9"!T;R!S96QE8W0@:70L"@D)+R\@=&AE<F5F;W)E(&QE="=S
M(&AI9&4@:70@9G)O;2!T:&4@9&%M;B`B8G)O=W-E<B(N"@D);W!T:6]N<UMI
M,3AN6R),;W=E<B!G<F5E:R)=72`](")L;W=E<BUG<F5E:R(["@EV87(@;V)J
M(#T@>PH)"6ED("`@("`@("`@("`@.B`B3&ES=%1Y<&4B+`H)"71O;VQT:7`@
M("`@("`@.B!I,3AN6R),:7-T4W1Y;&54;V]L=&EP(ETL"@D);W!T:6]N<R`@
M("`@("`Z(&]P=&EO;G,L"@D)86-T:6]N("`@("`@("`Z(&9U;F-T:6]N*&5D
M:71O<BD@>R!S96QF+F]N4V5L96-T*&5D:71O<BP@=&AI<RD[('TL"@D)<F5F
M<F5S:"`@("`@("`Z(&9U;F-T:6]N*&5D:71O<BD@>R!S96QF+G5P9&%T959A
M;'5E*&5D:71O<BP@=&AI<RD[('TL"@D)8V]N=&5X="`@("`@("`Z(")O;"(*
M"7T["@EC9F<N<F5G:7-T97)$<F]P9&]W;BAO8FHI.PH)=F%R(&$L(&DL(&HL
M(&9O=6YD(#T@9F%L<V4["@EF;W(@*&D@/2`P.R`A9F]U;F0@)B8@:2`\('1O
M;VQB87(N;&5N9W1H.R`K*VDI('L*"0EA(#T@=&]O;&)A<EMI73L*"0EF;W(@
M*&H@/2`P.R!J(#P@82YL96YG=&@[("LK:BD@>PH)"0EI9B`H85MJ72`]/2`B
M=6YO<F1E<F5D;&ES="(I('L*"0D)"69O=6YD(#T@=')U93L*"0D)"6)R96%K
M.PH)"0E]"@D)?0H)?0H):68@*&9O=6YD*0H)"6$N<W!L:6-E*&HL(#`L(")S
M<&%C92(L("),:7-T5'EP92(L(")S<&%C92(I.PI].PH*3&ES=%1Y<&4N7W!L
M=6=I;DEN9F\@/2!["@EN86UE("`@("`@("`@(#H@(DQI<W14>7!E(BP*"79E
M<G-I;VX@("`@("`@.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@.B`B36EH86D@
M0F%Z;VXB+`H)9&5V96QO<&5R7W5R;"`Z(")H='1P.B\O9'EN87)C:"YC;VTO
M;6ES:&]O+R(L"@EC7V]W;F5R("`@("`@(#H@(F1Y;F%R8V@N8V]M(BP*"7-P
M;VYS;W(@("`@("`@.B`B345D5&5C:"!5;FET("T@475E96XG<R!5;FEV97)S
M:71Y(BP*"7-P;VYS;W)?=7)L("`@.B`B:'1T<#HO+W=W=RYQ=65E;G-U+F-A
M+R(L"@EL:6-E;G-E("`@("`@(#H@(FAT;6Q!<F5A(@I].PH*3&ES=%1Y<&4N
M<')O=&]T>7!E+F]N4V5L96-T(#T@9G5N8W1I;VXH961I=&]R+"!C;VUB;RD@
M>PH)=F%R('1B;V)J(#T@961I=&]R+E]T;V]L8F%R3V)J96-T<UMC;VUB;RYI
M9%TN96QE;65N=#L*"79A<B!P87)E;G0@/2!E9&ET;W(N9V5T4&%R96YT16QE
M;65N="@I.PH)=VAI;&4@*"$O7F]L)"]I+G1E<W0H<&%R96YT+G1A9TYA;64I
M*2!["@D)<&%R96YT(#T@<&%R96YT+G!A<F5N=$YO9&4["@E]"@EP87)E;G0N
M<W1Y;&4N;&ES=%-T>6QE5'EP92`]('1B;V)J+G9A;'5E.PI].PH*3&ES=%1Y
M<&4N<')O=&]T>7!E+G5P9&%T959A;'5E(#T@9G5N8W1I;VXH961I=&]R+"!C
M;VUB;RD@>PH)=F%R('1B;V)J(#T@961I=&]R+E]T;V]L8F%R3V)J96-T<UMC
M;VUB;RYI9%TN96QE;65N=#L*"79A<B!P87)E;G0@/2!E9&ET;W(N9V5T4&%R
M96YT16QE;65N="@I.PH)=VAI;&4@*'!A<F5N="`F)B`A+UYO;"0O:2YT97-T
M*'!A<F5N="YT86=.86UE*2D@>PH)"7!A<F5N="`]('!A<F5N="YP87)E;G1.
M;V1E.PH)?0H):68@*"%P87)E;G0I('L*"0ET8F]B:BYS96QE8W1E9$EN9&5X
M(#T@,#L*"0ER971U<FX["@E]"@EV87(@='EP92`]('!A<F5N="YS='EL92YL
M:7-T4W1Y;&54>7!E.PH):68@*"%T>7!E*2!["@D)=&)O8FHN<V5L96-T961)
M;F1E>"`](#`["@E](&5L<V4@>PH)"69O<B`H=F%R(&D@/2!T8F]B:BYF:7)S
M=$-H:6QD.R!I.R!I(#T@:2YN97AT4VEB;&EN9RD@>PH)"0EI+G-E;&5C=&5D
M(#T@*'1Y<&4N:6YD97A/9BAI+G9A;'5E*2`A/2`M,2D["@D)?0H)?0I].PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]486)L94]P97)A=&EO;G,O````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S
M,#`W`#`R-C`W-P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,#<`,#(V-C4S`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/
M<&5R871I;VYS+VEM9R]C96QL+61E;&5T92YG:68````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$T-0`Q,#0Q-S,V,S`P-P`P,S$U,38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA$@`2`*$``````/____\``/___R'Y!`$```,`+``````2`!(```(VG(^I
MRP,/VP&A!B`-M3B)!(71('P+(`0I6I:GJG;N)(:&.5E7YNB=5.-M*K_&<)<)
M\I;,IJ0``#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+RXO0$QO;F=,:6YK````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P`#`P,#`P
M,#``,#`P,#`P,#`Q-#4`,#`P,#`P,#`P,#``,#$Q-S`V`"!,````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``<F]O=`````````````````````````````````````!W:&5E
M;```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O
M5&%B;&5/<&5R871I;VYS+VEM9R]C96QL+6EN<V5R="UA9G1E<BYG:68`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM:6YS
M97)T+6%F=&5R+F=I`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,38V`#$P-#$W,S8S,#`W`#`S,C4Q-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$2`!(`P@````"`X8"``/______
M````____________(?D$`0``!P`L`````!(`$@```SMXNMS^\)!)XR(C#V(5
MUEQ'56)@!J%%G&@GC2'@,H`,ITU=8\(@X#E;KQ>Z*6PPCV;C^F2`#^-L2F4D
M```[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO+B]`3&]N
M9TQI;FL`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``,#`P,#`P,``P,#`P,#`P,#$T-@`P,#`P,#`P
M,#`P,``P,3$W,#<`($P`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!R;V]T````````````
M`````````````````````````'=H965L````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E
M;&PM:6YS97)T+6)E9F]R92YG:68`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE
M3W!E<F%T:6]N<R]I;6<O8V5L;"UI;G-E<G0M8F5F;W)E+F<`,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-C8`,3`T,3<S-C,P,#<`,#,R-3`T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81(`$@#"`````(#A@(``______\```#___________\A^00!```'`"P`
M````$@`2```#.WBZW.[@R0,BN5C62H;PQ%0=Q/>%(HE=RLI.;2`'*$S,--RZ
M.CG\@]JD`Q1*7,8'\9=T+(,]9&]*E20``#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O
M:6UG+V-E;&PM;65R9V4N9VEF`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q-C`P`#$P-#$W,S8S,#`W`#`S,3,U,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$2`!(`YP``
M````@````(``@(````"`@`"``("`P,#`P-S`ILKP0"``8"``@"``H"``P"``
MX"```$``($``0$``8$``@$``H$``P$``X$```&``(&``0&``8&``@&``H&``
MP&``X&```(``((``0(``8(``@(``H(``P(``X(```*``(*``0*``8*``@*``
MH*``P*``X*```,``(,``0,``8,``@,``H,``P,``X,```.``(.``0.``8.``
M@.``H.``P.``X.````!`(`!`0`!`8`!`@`!`H`!`P`!`X`!``"!`("!`0"!`
M8"!`@"!`H"!`P"!`X"!``$!`($!`0$!`8$!`@$!`H$!`P$!`X$!``&!`(&!`
M0&!`8&!`@&!`H&!`P&!`X&!``(!`((!`0(!`8(!`@(!`H(!`P(!`X(!``*!`
M(*!`0*!`8*!`@*!`H*!`P*!`X*!``,!`(,!`0,!`8,!`@,!`H,!`P,!`X,!`
M`.!`(.!`0.!`8.!`@.!`H.!`P.!`X.!```"`(`"`0`"`8`"`@`"`H`"`P`"`
MX`"``""`(""`0""`8""`@""`H""`P""`X""``$"`($"`0$"`8$"`@$"`H$"`
MP$"`X$"``&"`(&"`0&"`8&"`@&"`H&"`P&"`X&"``("`(("`0("`8("`@("`
MH("`P("`X("``*"`(*"`0*"`8*"`@*"`H*"`P*"`X*"``,"`(,"`0,"`8,"`
M@,"`H,"`P,"`X,"``."`(."`0."`8."`@."`H."`P."`X."```#`(`#`0`#`
M8`#`@`#`H`#`P`#`X`#``"#`("#`0"#`8"#`@"#`H"#`P"#`X"#``$#`($#`
M0$#`8$#`@$#`H$#`P$#`X$#``&#`(&#`0&#`8&#`@&#`H&#`P&#`X&#``(#`
M((#`0(#`8(#`@(#`H(#`P(#`X(#``*#`(*#`0*#`8*#`@*#`H*#`P*#`X*#`
M`,#`(,#`0,#`8,#`@,#`H,#`__OPH*"D@("`_P```/\`__\```#__P#_`/__
M____(?D$`0``_0`L`````!(`$@``"%T`^PD<2+"@P8,(^P%8R+"A0P`"`?S[
M)W'BQ(H6(2J\:)%C1XT/0S*,>-'?/Y,H3YX$R3&E2XHD*;YTR9*BRIDP%3+$
MB;*F1)XY*P(`ZL_GS:,F08H,F;"ITZ=0`P(`.P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A
M=&EO;G,O:6UG+V-E;&PM<')O<"YG:68``````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,C,S`#$P-#$W,S8S,#`W`#`S,3(S,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$2
M`!(`H@<`X8"```"`P,#``#.9S,S,____````____(?D$`0``!P`L`````!(`
M$@```V!XNMSN)LH3PCM&Z&WJR]FF>0THA)LG16>+=I8Q#"#M1H,ZX_M)[[$"
MH4`<%HG"#D:(-#*+2@-A)258KU.%H6``>+='J);K!8"?2>UTA<4:QLYX\[V4
MA].8MOY*I_JI!PD`.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C
M96QL+7-P;&ET+F=I9@`````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,38Q,P`Q,#0Q-S,V,S`P-P`P,S$T,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA$@`2`.<``````(``
M``"``("`````@(``@`"`@,#`P,#<P*;*\$`@`&`@`(`@`*`@`,`@`.`@``!`
M`"!``$!``&!``(!``*!``,!``.!```!@`"!@`$!@`&!@`(!@`*!@`,!@`.!@
M``"``""``$"``&"``("``*"``,"``."```"@`""@`$"@`&"@`("@`*"@`,"@
M`."@``#``"#``$#``&#``(#``*#``,#``.#```#@`"#@`$#@`&#@`(#@`*#@
M`,#@`.#@````0"``0$``0&``0(``0*``0,``0.``0``@0"`@0$`@0&`@0(`@
M0*`@0,`@0.`@0`!`0"!`0$!`0&!`0(!`0*!`0,!`0.!`0`!@0"!@0$!@0&!@
M0(!@0*!@0,!@0.!@0`"`0""`0$"`0&"`0("`0*"`0,"`0."`0`"@0""@0$"@
M0&"@0("@0*"@0,"@0."@0`#`0"#`0$#`0&#`0(#`0*#`0,#`0.#`0`#@0"#@
M0$#@0&#@0(#@0*#@0,#@0.#@0```@"``@$``@&``@(``@*``@,``@.``@``@
M@"`@@$`@@&`@@(`@@*`@@,`@@.`@@`!`@"!`@$!`@&!`@(!`@*!`@,!`@.!`
M@`!@@"!@@$!@@&!@@(!@@*!@@,!@@.!@@`"`@""`@$"`@&"`@("`@*"`@,"`
M@."`@`"@@""@@$"@@&"@@("@@*"@@,"@@."@@`#`@"#`@$#`@&#`@(#`@*#`
M@,#`@.#`@`#@@"#@@$#@@&#@@(#@@*#@@,#@@.#@@```P"``P$``P&``P(``
MP*``P,``P.``P``@P"`@P$`@P&`@P(`@P*`@P,`@P.`@P`!`P"!`P$!`P&!`
MP(!`P*!`P,!`P.!`P`!@P"!@P$!@P&!@P(!@P*!@P,!@P.!@P`"`P""`P$"`
MP&"`P("`P*"`P,"`P."`P`"@P""@P$"@P&"@P("@P*"@P,"@P."@P`#`P"#`
MP$#`P&#`P(#`P*#`P/_[\*"@I("`@/\```#_`/__````__\`_P#______R'Y
M!`$``/T`+``````2`!(```AH`/L)'$BPH,&#"/L!6,BPH4,``@'\^R=QXL2*
M%B$JO&B18T>-#T,RC'C1WS]_!$RB5`F2HTD")__!--F2(H&;.',2`,DPYDR9
M,6L"4)GR9%%_0G4J%4JTZ4FA/J/2C"@R9,*K6+-J#0@`.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS
M+VEM9R]C;VPM9&5L971E+F=I9@`````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#$T-``Q,#0Q-S,V,S`P-P`P,S$S-3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA$@`2`*$`
M`````/____\``/___R'Y!`$```,`+``````2`!(```(UG(^IRP8!GP@OIDJG
MP.!"&DS<!92`9I:-1#7(&7:N$[;S`&\WGNZ&X#L`?8)BD7@,#H/,6P$`.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V]L+6EN
M<V5R="UA9G1E<BYG:68`,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`Q-3<`,3`T,3<S-C,P,#<`,#,R-3(P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y81(`$@#"``#A@(```(``____
M__\```#___________\A^00!```'`"P`````$@`2```#-'BZW/Y0D4$)N"3.
M>D&&1"B*47D$9A.LJ;*^K1LO:#Q^)B$,`EY..Y]FUVL!!T(0,3EK'A(`.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B\N+T!,
M;VYG3&EN:P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,``P,#`P,#`P`#`P,#`P,#`P,30U`#`P,#`P
M,#`P,#`P`#`Q,3<P-@`@3```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`')O;W0`````````
M````````````````````````````=VAE96P`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O
M8V]L+6EN<V5R="UB969O<F4N9VEF````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B
M;&5/<&5R871I;VYS+VEM9R]C;VPM:6YS97)T+6)E9F]R92YG:0`P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$U-@`Q,#0Q-S,V,S`P-P`P,S(U
M,3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA$@`2`,(``````.&`@/___P``@`#______________R'Y!`$```<`
M+``````2`!(```,S>+K<_O"!0(&X(,YZ189`*(K.$#U#>C)IN[)O8\;'^*T`
M(1#W:>D]C8X7^WF*PR!M&4L``#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N
M<R]I;6<O8V]L+7-P;&ET+F=I9@``````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$V,30`,3`T,3<S-C,P,#<`,#,Q,C0W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y81(`$@#G
M``````"`````@`"`@````("``(``@(#`P,#`W,"FRO!`(`!@(`"`(`"@(`#`
M(`#@(```0``@0`!`0`!@0`"`0`"@0`#`0`#@0```8``@8`!`8`!@8`"`8`"@
M8`#`8`#@8```@``@@`!`@`!@@`"`@`"@@`#`@`#@@```H``@H`!`H`!@H`"`
MH`"@H`#`H`#@H```P``@P`!`P`!@P`"`P`"@P`#`P`#@P```X``@X`!`X`!@
MX`"`X`"@X`#`X`#@X````$`@`$!``$!@`$"``$"@`$#``$#@`$``($`@($!`
M($!@($"`($"@($#`($#@($``0$`@0$!`0$!@0$"`0$"@0$#`0$#@0$``8$`@
M8$!`8$!@8$"`8$"@8$#`8$#@8$``@$`@@$!`@$!@@$"`@$"@@$#`@$#@@$``
MH$`@H$!`H$!@H$"`H$"@H$#`H$#@H$``P$`@P$!`P$!@P$"`P$"@P$#`P$#@
MP$``X$`@X$!`X$!@X$"`X$"@X$#`X$#@X$```(`@`(!``(!@`("``("@`(#`
M`(#@`(``((`@((!`((!@(("`(("@((#`((#@((``0(`@0(!`0(!@0("`0("@
M0(#`0(#@0(``8(`@8(!`8(!@8("`8("@8(#`8(#@8(``@(`@@(!`@(!@@("`
M@("@@(#`@(#@@(``H(`@H(!`H(!@H("`H("@H(#`H(#@H(``P(`@P(!`P(!@
MP("`P("@P(#`P(#@P(``X(`@X(!`X(!@X("`X("@X(#`X(#@X(```,`@`,!`
M`,!@`,"``,"@`,#``,#@`,``(,`@(,!`(,!@(,"`(,"@(,#`(,#@(,``0,`@
M0,!`0,!@0,"`0,"@0,#`0,#@0,``8,`@8,!`8,!@8,"`8,"@8,#`8,#@8,``
M@,`@@,!`@,!@@,"`@,"@@,#`@,#@@,``H,`@H,!`H,!@H,"`H,"@H,#`H,#@
MH,``P,`@P,!`P,!@P,"`P,"@P,#_^_"@H*2`@(#_````_P#__P```/__`/\`
M______\A^00!``#]`"P`````$@`2```(:0#["1Q(L*#!@PC[`5C(L*%#``(!
M_/LG<>+$BA8A*KQHD6-'C0]#,HQXT=\_?P1,HE0)DJ-)`B?_P339DJ+*E"=Q
M^@/),.9,F3%K`KA)]*10GTAIDK29L^C.I1)?)J48463(A%BS:MT:$``[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E
M<F%T:6]N<R]I;6<O<F]W+61E;&5T92YG:68`````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-3``,3`T,3<S-C,P,#<`,#,Q-#`R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M81(`$@"A``````#_____``#___\A^00!```#`"P`````$@`2```".9R/J<L#
M#U\;H=H`YK6Y[=HQT2@-`B($Z:IBAG`:+;L"\/W.>@<?Y/A"?%R>3V@Q/"I^
MRHGS"7T6```[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG
M+W)O=RUI;G-E<G0M86)O=F4N9VEF`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,38T`#$P-#$W,S8S,#`W`#`S,C4T,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$2`!(`P@```/__
M``"$X8"`____````____________(?D$`0``!P`L`````!(`$@```SEXNMS^
M,`9%:I7S$#`X#"!(=!U&<9Y$6<3*MM$AS#0<T74LXX(-O9?88$CT/8A%'7)H
M=`";NJB4D0``.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M:6YS97)T
M+75N9&5R+F=I9@`P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$V
M,P`Q,#0Q-S,V,S`P-P`P,S(U-C,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA$@`2`,(```#__P``A.&`@/___P``
M`/___________R'Y!`$```<`+``````2`!(```,X>+K<_O"024E4(VM[];Z'
MEW%118%"JI*0NJ*NP#[F!$*!8D9!+@$#(*[7(P2#/!\!*.3I*K?H+0$`.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G
M:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O<F]W+7!R;W`N9VEF````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,C4`,3`T,3<S-C,P
M,#<`,#,Q,3(S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81(`$@"B!P```(#A@(#`P,``,YG,S,S___\```#___\A
M^00!```'`"P`````$@`2```#6GBZW.XFR@/`.T;H;>K+V:9Y#2B$FR=%9XMV
MEC$,(.U&@SKC^TGOL0*A0!P6B4*#PB!$&IM%)69%71&DAH!VR]U>E]VP]CNM
M5LG,I]J)A;K56()\3J=CS?A#`@`[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P
M97)A=&EO;G,O:6UG+W)O=RUS<&QI="YG:68``````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3<W`#$P-#$W,S8S,#`W`#`S,3,Q,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$2`!(`YP``````@````(``@(````"`@`"``("`P,#`P-S`ILKP0"``8"``
M@"``H"``P"``X"```$``($``0$``8$``@$``H$``P$``X$```&``(&``0&``
M8&``@&``H&``P&``X&```(``((``0(``8(``@(``H(``P(``X(```*``(*``
M0*``8*``@*``H*``P*``X*```,``(,``0,``8,``@,``H,``P,``X,```.``
M(.``0.``8.``@.``H.``P.``X.````!`(`!`0`!`8`!`@`!`H`!`P`!`X`!`
M`"!`("!`0"!`8"!`@"!`H"!`P"!`X"!``$!`($!`0$!`8$!`@$!`H$!`P$!`
MX$!``&!`(&!`0&!`8&!`@&!`H&!`P&!`X&!``(!`((!`0(!`8(!`@(!`H(!`
MP(!`X(!``*!`(*!`0*!`8*!`@*!`H*!`P*!`X*!``,!`(,!`0,!`8,!`@,!`
MH,!`P,!`X,!``.!`(.!`0.!`8.!`@.!`H.!`P.!`X.!```"`(`"`0`"`8`"`
M@`"`H`"`P`"`X`"``""`(""`0""`8""`@""`H""`P""`X""``$"`($"`0$"`
M8$"`@$"`H$"`P$"`X$"``&"`(&"`0&"`8&"`@&"`H&"`P&"`X&"``("`(("`
M0("`8("`@("`H("`P("`X("``*"`(*"`0*"`8*"`@*"`H*"`P*"`X*"``,"`
M(,"`0,"`8,"`@,"`H,"`P,"`X,"``."`(."`0."`8."`@."`H."`P."`X."`
M``#`(`#`0`#`8`#`@`#`H`#`P`#`X`#``"#`("#`0"#`8"#`@"#`H"#`P"#`
MX"#``$#`($#`0$#`8$#`@$#`H$#`P$#`X$#``&#`(&#`0&#`8&#`@&#`H&#`
MP&#`X&#``(#`((#`0(#`8(#`@(#`H(#`P(#`X(#``*#`(*#`0*#`8*#`@*#`
MH*#`P*#`X*#``,#`(,#`0,#`8,#`@,#`H,#`__OPH*"D@("`_P```/\`__\`
M``#__P#_`/______(?D$`0``_0`L`````!(`$@``"%P`^PD<2+"@P8,(^P%8
MR+"A0P`"`?R;.%$BQ7\6(2J\B)%CQH@/0RZ,Z.]?R9,F37[<B+)E1XP1"<B<
M29/`2HDN438DF3+GS9I`;^;L>;.GT9(W189,R+2ITZ<!`0`[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]4
M86)L94]P97)A=&EO;G,O:6UG+W1A8FQE+7!R;W`N9VEF`````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C(Q`#$P-#$W,S8S,#`W`#`S
M,3,W-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$2`!(`H@8```"`P,#``#.9____S,S,````____````(?D$`0``
M!@`L`````!(`$@```U9HNMSN)4H#P#,EZ%WJR]FF>0T8A)LG16>+=E8A""#M
M1H(ZX_M)[[$!84`<%HG"@J(@1!J;126&0*U:K5+F<^O,0K_;['5<]7*/T278
MV5V2R=F5?&Y(```[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I
M;VYS+VQA;F<O```````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P-P`P,C<P,C``(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]486)L94]P97)A=&EO;G,O;&%N9R]E;BYJ<P``````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,#<V`#$P-#$W,S8S
M,#`W`#`R-S<V,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O+R!),3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#
M3T1)3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A
M>F]N+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,
M051/4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!0U0@24Y&
M3R!)3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A('9A;&ED
M(&5M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!43R!54T4@
M551&+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO="!P
M;W-S:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@("`@('1H
M870@<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*"E1A8FQE
M3W!E<F%T:6]N<RY),3A.(#T@>PH)(D%L:6=N(CH)"0D)"2`@(D%L:6=N(BP*
M"2)!;&P@9F]U<B!S:61E<R(Z"0D)"2`@(D%L;"!F;W5R('-I9&5S(BP*"2)"
M86-K9W)O=6YD(CH)"0D)"2`@(D)A8VMG<F]U;F0B+`H)(D)A<V5L:6YE(CH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B0F%S96QI
M;F4B+`H)(D)O<F1E<B(Z"0D)"0D@(")";W)D97(B+`H)(D)O<F1E<G,B.@D)
M"0D)("`B0F]R9&5R<R(L"@DB0F]T=&]M(CH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(")";W1T;VTB+`H)(D-34R!3='EL92(Z
M"0D)"0D@(")3='EL92!;0U-372(L"@DB0V%P=&EO;B(Z"0D)"0D@(")#87!T
M:6]N(BP*"2)#96QL(%!R;W!E<G1I97,B.B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(D-E;&P@4')O<&5R=&EE<R(L"@DB0V5N=&5R(CH)"0D)
M"2`@(D-E;G1E<B(L"@DB0VAA<B(Z("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(")#:&%R(BP*"2)#;VQL87!S960@8F]R9&5R
M<R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(D-O;&QA<'-E9"!B
M;W)D97)S(BP*"2)#;VQO<B(Z"0D)"0D@(")#;VQO<B(L"@DB1&5S8W)I<'1I
M;VXB.@D)"0D)("`B1&5S8W)I<'1I;VXB+`H)(D9'($-O;&]R(CH)"0D)"2`@
M(D9'($-O;&]R(BP*"2)&;&]A="(Z("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(D9L;V%T(BP*"2)&<F%M97,B.@D)"0D)("`B
M1G)A;65S(BP*"2)(96EG:'0B.B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(DAE:6=H="(L"@DB2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B.B`@("`@(")(;W<@;6%N>2!C;VQU
M;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(L"@DB2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B.B`@("`@("`@(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(L"@DB26UA9V4@55),
M(CH)"0D)"2`@(DEM86=E(%523"(L"@DB2G5S=&EF>2(Z("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(")*=7-T:69Y(BP*"2),87EO
M=70B.@D)"0D)("`B3&%Y;W5T(BP*"2),969T(CH)"0D)"0D@("),969T(BP*
M"2)-87)G:6XB.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(DUA<F=I;B(L"@DB36ED9&QE(CH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(")-:61D;&4B+`H)(DYO(')U;&5S(CH)
M"0D)"2`@(DYO(')U;&5S(BP*"2).;R!S:61E<R(Z"0D)"0D@(").;R!S:61E
M<R(L"@DB3F]N92(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(").;VYE(BP*"2)0861D:6YG(CH)"0D)"2`@(E!A9&1I;F<B
M+`H)(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(Z("`@("`@("`@("`@
M("`@("`@("`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(BP*"2)2:6=H
M="(Z"0D)"0D@(")2:6=H="(L"@DB4F]W(%!R;W!E<G1I97,B.B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(")2;W<@4')O<&5R=&EE<R(L"@DB
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<R(Z(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C
M;VQU;6YS(BP*"2)2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@
M;VYL>2(Z"2`@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O
M;FQY(BP*"2)2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(Z
M"0D@(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(L"@DB
M4G5L97,B.@D)"0D)("`B4G5L97,B+`H)(E-P86-I;F<@86YD('!A9&1I;F<B
M.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`B4W!A8VEN9R!A;F0@<&%D
M9&EN9R(L"@DB4W!A8VEN9R(Z"0D)"0D@(")3<&%C:6YG(BP*"2)3=6UM87)Y
M(CH)"0D)"2`@(E-U;6UA<GDB+`H)(E1/+6-E;&PM9&5L971E(CH)"0D)("`B
M1&5L971E(&-E;&PB+`H)(E1/+6-E;&PM:6YS97)T+6%F=&5R(CH)"0D)("`B
M26YS97)T(&-E;&P@869T97(B+`H)(E1/+6-E;&PM:6YS97)T+6)E9F]R92(Z
M"0D)("`B26YS97)T(&-E;&P@8F5F;W)E(BP*"2)43RUC96QL+6UE<F=E(CH)
M"0D)("`B365R9V4@8V5L;',B+`H)(E1/+6-E;&PM<')O<"(Z"0D)"0D@(")#
M96QL('!R;W!E<G1I97,B+`H)(E1/+6-E;&PM<W!L:70B.@D)"0D@(")3<&QI
M="!C96QL(BP*"2)43RUC;VPM9&5L971E(CH)"0D)("`B1&5L971E(&-O;'5M
M;B(L"@DB5$\M8V]L+6EN<V5R="UA9G1E<B(Z"0D)"2`@(DEN<V5R="!C;VQU
M;6X@869T97(B+`H)(E1/+6-O;"UI;G-E<G0M8F5F;W)E(CH)"0D)("`B26YS
M97)T(&-O;'5M;B!B969O<F4B+`H)(E1/+6-O;"US<&QI="(Z"0D)"0D@(")3
M<&QI="!C;VQU;6XB+`H)(E1/+7)O=RUD96QE=&4B.@D)"0D@(")$96QE=&4@
M<F]W(BP*"2)43RUR;W<M:6YS97)T+6%B;W9E(CH)"0D)("`B26YS97)T(')O
M=R!B969O<F4B+`H)(E1/+7)O=RUI;G-E<G0M=6YD97(B.@D)"0D@("));G-E
M<G0@<F]W(&%F=&5R(BP*"2)43RUR;W<M<')O<"(Z"0D)"0D@(")2;W<@<')O
M<&5R=&EE<R(L"@DB5$\M<F]W+7-P;&ET(CH)"0D)"2`@(E-P;&ET(')O=R(L
M"@DB5$\M=&%B;&4M<')O<"(Z"0D)"2`@(E1A8FQE('!R;W!E<G1I97,B+`H)
M(E1A8FQE(%!R;W!E<G1I97,B.@D)"0D@(")486)L92!0<F]P97)T:65S(BP*
M"2)497AT(&%L:6=N(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(E1E>'0@86QI9VXB+`H)(E1H92!B;W1T;VT@<VED92!O;FQY(CH)
M"0D)("`B5&AE(&)O='1O;2!S:61E(&]N;'DB+`H)(E1H92!L969T+6AA;F0@
M<VED92!O;FQY(CH)"0D@(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(L"@DB
M5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB.@D)("`B5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'DB+`H)(E1H92!R:6=H="UH86YD('-I9&4@
M;VYL>2(Z"0D)("`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(BP*"2)4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(Z"0D@(")4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>2(L"@DB5&AE('1O<"!S:61E(&]N;'DB.@D)"0D@
M(")4:&4@=&]P('-I9&4@;VYL>2(L"@DB5&]P(CH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(")4;W`B+`D*"2)5;G-E="!C
M;VQO<B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(E5N
M<V5T(&-O;&]R(BP*"2)697)T:6-A;"!A;&EG;B(Z("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(E9E<G1I8V%L(&%L:6=N(BP*"2)7:61T:"(Z
M"0D)"0D@(")7:61T:"(L"@DB;F]T+61E;"UL87-T+6-E;&PB.@D)"0D@(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB+`H)(FYO="UD96PM;&%S="UC;VPB.@D)"0D@(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N(BP*"2)N;W0M9&5L+6QA<W0M<F]W(CH)"0D)("`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(L"@DB<&5R8V5N="(Z"0D)"0D@(")P97)C96YT(BP*"2)P
M:7AE;',B.@D)"0D)("`B<&EX96QS(@I].PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE
M3W!E<F%T:6]N<R]T86)L92UO<&5R871I;VYS+FIS````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#`R,C``,3`T,3<S-C,P,#<`,#,Q-C<U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\O
M(%1A8FQE($]P97)A=&EO;G,@4&QU9VEN(&9O<B!(5$U,07)E82TS+C`*+R\@
M26UP;&5M96YT871I;VX@8GD@36EH86D@0F%Z;VXN("!3<&]N<V]R960@8GD@
M:'1T<#HO+W=W=RYZ87!A=&5C+F-O;0HO+PHO+R!#;W!Y<FEG:'0@*&,I(&1Y
M;F%R8V@N8V]M(#(P,#,M,C`P-0HO+R!4:&ES(&-O<'ER:6=H="!N;W1I8V4@
M;75S="!S=&%Y(&EN=&%C="!F;W(@=7-E+@HO+PHO+R`D260Z('1A8FQE+6]P
M97)A=&EO;G,N:G,L=B`Q+C<@,C`P-2\P,2\R,"`Q-SHT.3HP,B!M:7-H;V\@
M17AP("0*"B\O($]B:F5C="!T:&%T('=I;&P@96YC87!S=6QA=&4@86QL('1H
M92!T86)L92!O<&5R871I;VYS('!R;W9I9&5D(&)Y"B\O($A434Q!<F5A+3,N
M,"`H97AC97!T(")I;G-E<G0@=&%B;&4B('=H:6-H(&ES(&EN8VQU9&5D(&EN
M('1H92!M86EN(&9I;&4I"F9U;F-T:6]N(%1A8FQE3W!E<F%T:6]N<RAE9&ET
M;W(I('L*"71H:7,N961I=&]R(#T@961I=&]R.PH*"79A<B!C9F<@/2!E9&ET
M;W(N8V]N9FEG.PH)=F%R('1T(#T@5&%B;&5/<&5R871I;VYS+DDQ.$X["@EV
M87(@8FP@/2!486)L94]P97)A=&EO;G,N8G1N3&ES=#L*"79A<B!S96QF(#T@
M=&AI<SL*"@DO+R!R96=I<W1E<B!T:&4@=&]O;&)A<B!B=71T;VYS('!R;W9I
M9&5D(&)Y('1H:7,@<&QU9VEN"@EV87(@=&]O;&)A<B`](%LB;&EN96)R96%K
M(ET["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&)L+FQE;F=T:#L@*RMI*2!["@D)
M=F%R(&)T;B`](&)L6VE=.PH)"6EF("@A8G1N*2!["@D)"71O;VQB87(N<'5S
M:"@B<V5P87)A=&]R(BD["@D)?2!E;'-E('L*"0D)=F%R(&ED(#T@(E1/+2(@
M*R!B=&Y;,%T["@D)"6-F9RYR96=I<W1E<D)U='1O;BAI9"P@='1;:61=+"!E
M9&ET;W(N:6UG55),*&)T;ELP72`K("(N9VEF(BP@(E1A8FQE3W!E<F%T:6]N
M<R(I+"!F86QS92P*"0D)"0D@("!F=6YC=&EO;BAE9&ET;W(L(&ED*2!["@D)
M"0D)"2`@("\O(&1I<W!A=&-H(&)U='1O;B!P<F5S<R!E=F5N=`H)"0D)"0D@
M("!S96QF+F)U='1O;E!R97-S*&5D:71O<BP@:60I.PH)"0D)"2`@('TL(&)T
M;ELQ72D["@D)"71O;VQB87(N<'5S:"AI9"D["@D)?0H)?0H*"2\O(&%D9"!A
M(&YE=R!L:6YE(&EN('1H92!T;V]L8F%R"@EC9F<N=&]O;&)A<BYP=7-H*'1O
M;VQB87(I.PI].PH*5&%B;&5/<&5R871I;VYS+E]P;'5G:6Y);F9O(#T@>PH)
M;F%M92`@("`@("`@("`Z(")486)L94]P97)A=&EO;G,B+`H)=F5R<VEO;B`@
M("`@("`Z("(Q+C`B+`H)9&5V96QO<&5R("`@("`Z(")-:6AA:2!"87IO;B(L
M"@ED979E;&]P97)?=7)L(#H@(FAT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\O
M(BP*"6-?;W=N97(@("`@("`@.B`B36EH86D@0F%Z;VXB+`H)<W!O;G-O<B`@
M("`@("`Z("):87!A=&5C($EN8RXB+`H)<W!O;G-O<E]U<FP@("`Z(")H='1P
M.B\O=W=W+F)L;VMI+F-O;2(L"@EL:6-E;G-E("`@("`@(#H@(FAT;6Q!<F5A
M(@I].PH*+RHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*@H@*B!55$E,251)15,*
M("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B\*"B\O(')E=')I979E<R!T:&4@
M8VQO<V5S="!E;&5M96YT(&AA=FEN9R!T:&4@<W!E8VEF:65D('1A9TYA;64@
M:6X@=&AE(&QI<W0@;V8*+R\@86YC97-T;W)S(&]F('1H92!C=7)R96YT('-E
M;&5C=&EO;B]C87)E="X*5&%B;&5/<&5R871I;VYS+G!R;W1O='EP92YG971#
M;&]S97-T(#T@9G5N8W1I;VXH=&%G3F%M92D@>PH)=F%R(&5D:71O<B`]('1H
M:7,N961I=&]R.PH)=F%R(&%N8V5S=&]R<R`](&5D:71O<BYG971!;&Q!;F-E
M<W1O<G,H*3L*"79A<B!R970@/2!N=6QL.PH)=&%G3F%M92`]("@B(B`K('1A
M9TYA;64I+G1O3&]W97)#87-E*"D["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&%N
M8V5S=&]R<RYL96YG=&@[("LK:2D@>PH)"79A<B!E;"`](&%N8V5S=&]R<UMI
M73L*"0EI9B`H96PN=&%G3F%M92YT;TQO=V5R0V%S92@I(#T]('1A9TYA;64I
M('L*"0D)<F5T(#T@96P["@D)"6)R96%K.PH)"7T*"7T*"7)E='5R;B!R970[
M"GT["@HO+R!T:&ES(&9U;F-T:6]N(')E<75I<F5S('1H92!F:6QE(%!O<'5P
M1&EV+U!O<'5P5VEN('1O(&)E(&QO861E9"!F<F]M(&)R;W=S97(*5&%B;&5/
M<&5R871I;VYS+G!R;W1O='EP92YD:6%L;V=486)L95!R;W!E<G1I97,@/2!F
M=6YC=&EO;B@I('L*"79A<B!I,3AN(#T@5&%B;&5/<&5R871I;VYS+DDQ.$X[
M"@DO+R!R971R:65V92!E>&ES=&EN9R!V86QU97,*"79A<B!T86)L92`]('1H
M:7,N9V5T0VQO<V5S="@B=&%B;&4B*3L*"2\O('1H:7,N961I=&]R+G-E;&5C
M=$YO9&5#;VYT96YT<RAT86)L92D["@DO+R!T:&ES+F5D:71O<BYU<&1A=&54
M;V]L8F%R*"D["@H)=F%R(&1I86QO9R`](&YE=R!0;W!U<%=I;BAT:&ES+F5D
M:71O<BP@:3$X;ELB5&%B;&4@4')O<&5R=&EE<R)=+"!F=6YC=&EO;BAD:6%L
M;V<L('!A<F%M<RD@>PH)"51A8FQE3W!E<F%T:6]N<RYP<F]C97-S4W1Y;&4H
M<&%R86US+"!T86)L92D["@D)9F]R("AV87(@:2!I;B!P87)A;7,I('L*"0D)
M=F%R('9A;"`]('!A<F%M<UMI73L*"0D)<W=I=&-H("AI*2!["@D)"2`@("!C
M87-E(")F7V-A<'1I;VXB.@H)"0D):68@*"]<4R\N=&5S="AV86PI*2!["@D)
M"0D)+R\@8V]N=&%I;G,@;F]N('=H:71E+7-P86-E(&-H87)A8W1E<G,*"0D)
M"0EV87(@8V%P=&EO;B`]('1A8FQE+F=E=$5L96UE;G1S0GE486=.86UE*")C
M87!T:6]N(BE;,%T["@D)"0D):68@*"%C87!T:6]N*2!["@D)"0D)"6-A<'1I
M;VX@/2!D:6%L;V<N961I=&]R+E]D;V,N8W)E871E16QE;65N="@B8V%P=&EO
M;B(I.PH)"0D)"0ET86)L92YI;G-E<G1"969O<F4H8V%P=&EO;BP@=&%B;&4N
M9FER<W1#:&EL9"D["@D)"0D)?0H)"0D)"6-A<'1I;VXN:6YN97)(5$U,(#T@
M=F%L.PH)"0D)?2!E;'-E('L*"0D)"0DO+R!S96%R8V@@9F]R(&-A<'1I;VX@
M86YD(&1E;&5T92!I="!I9B!F;W5N9`H)"0D)"79A<B!C87!T:6]N(#T@=&%B
M;&4N9V5T16QE;65N='-">51A9TYA;64H(F-A<'1I;VXB*5LP73L*"0D)"0EI
M9B`H8V%P=&EO;BD@>PH)"0D)"0EC87!T:6]N+G!A<F5N=$YO9&4N<F5M;W9E
M0VAI;&0H8V%P=&EO;BD["@D)"0D)?0H)"0D)?0H)"0D)8G)E86L["@D)"2`@
M("!C87-E(")F7W-U;6UA<GDB.@H)"0D)=&%B;&4N<W5M;6%R>2`]('9A;#L*
M"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]W:61T:"(Z"@D)"0ET86)L92YS
M='EL92YW:61T:"`]("@B(B`K('9A;"D@*R!P87)A;7,N9E]U;FET.PH)"0D)
M8G)E86L["@D)"2`@("!C87-E(")F7V%L:6=N(CH*"0D)"71A8FQE+F%L:6=N
M(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C87-E(")F7W-P86-I;F<B.@H)
M"0D)=&%B;&4N8V5L;%-P86-I;F<@/2!V86P["@D)"0EB<F5A:SL*"0D)("`@
M(&-A<V4@(F9?<&%D9&EN9R(Z"@D)"0ET86)L92YC96QL4&%D9&EN9R`]('9A
M;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]B;W)D97)S(CH*"0D)"71A
M8FQE+F)O<F1E<B`]('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]F
M<F%M97,B.@H)"0D)=&%B;&4N9G)A;64@/2!V86P["@D)"0EB<F5A:SL*"0D)
M("`@(&-A<V4@(F9?<G5L97,B.@H)"0D)=&%B;&4N<G5L97,@/2!V86P["@D)
M"0EB<F5A:SL*"0D)?0H)"7T*"0DO+R!V87)I;W5S('=O<FMA<F]U;F1S('1O
M(')E9G)E<V@@=&AE('1A8FQE(&1I<W!L87D@*$=E8VMO+`H)"2\O('=H870G
M<R!G;VEN9R!O;C\A(&1O(&YO="!D:7-A<'!O:6YT(&UE(2D*"0ED:6%L;V<N
M961I=&]R+F9O<F-E4F5D<F%W*"D["@D)9&EA;&]G+F5D:71O<BYF;V-U<T5D
M:71O<B@I.PH)"61I86QO9RYE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"79A
M<B!S879E7V-O;&QA<'-E(#T@=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4[
M"@D)=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2`B8V]L;&%P<V4B.PH)
M"71A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@(G-E<&%R871E(CL*"0ET
M86)L92YS='EL92YB;W)D97)#;VQL87!S92`]('-A=F5?8V]L;&%P<V4["@E]
M+`H*"2\O('1H:7,@9G5N8W1I;VX@9V5T<R!C86QL960@=VAE;B!T:&4@9&EA
M;&]G(&YE961S('1O(&)E(&EN:71I86QI>F5D"@EF=6YC=&EO;B`H9&EA;&]G
M*2!["@H)"79A<B!F7V-A<'1I;VX@/2`B(CL*"0EV87(@8V%P96P@/2!T86)L
M92YG971%;&5M96YT<T)Y5&%G3F%M92@B8V%P=&EO;B(I6S!=.PH)"6EF("AC
M87!E;"D@>PH)"0EF7V-A<'1I;VX@/2!C87!E;"YI;FYE<DA434P["@D)?0H)
M"79A<B!F7W-U;6UA<GD@/2!T86)L92YS=6UM87)Y.PH)"79A<B!F7W=I9'1H
M(#T@<&%R<V5);G0H=&%B;&4N<W1Y;&4N=VED=&@I.PH)"6ES3F%.*&9?=VED
M=&@I("8F("AF7W=I9'1H(#T@(B(I.PH)"79A<B!F7W5N:70@/2`O)2\N=&5S
M="AT86)L92YS='EL92YW:61T:"D@/R`G<&5R8V5N="<@.B`G<&EX96QS)SL*
M"0EV87(@9E]A;&EG;B`]('1A8FQE+F%L:6=N.PH)"79A<B!F7W-P86-I;F<@
M/2!T86)L92YC96QL4W!A8VEN9SL*"0EV87(@9E]P861D:6YG(#T@=&%B;&4N
M8V5L;%!A9&1I;F<["@D)=F%R(&9?8F]R9&5R<R`]('1A8FQE+F)O<F1E<CL*
M"0EV87(@9E]F<F%M97,@/2!T86)L92YF<F%M93L*"0EV87(@9E]R=6QE<R`]
M('1A8FQE+G)U;&5S.PH*"0EF=6YC=&EO;B!S96QE8W1E9"AV86PI('L*"0D)
M<F5T=7)N('9A;"`_("(@<V5L96-T960B(#H@(B(["@D)?3L*"@D)+R\@9&EA
M;&]G(&-O;G1E;G1S"@D)9&EA;&]G+F-O;G1E;G0N<W1Y;&4N=VED=&@@/2`B
M-#`P<'@B.PH)"61I86QO9RYC;VYT96YT+FEN;F5R2%1-3"`]("(@7`H\9&EV
M(&-L87-S/2=T:71L92=<"B!S='EL93TG8F%C:V=R;W5N9#H@=7)L*"(@*R!D
M:6%L;V<N8F%S95523"`K(&1I86QO9RYE9&ET;W(N:6UG55),*")T86)L92UP
M<F]P+F=I9B(L(")486)L94]P97)A=&EO;G,B*2`K("(I("-F9F8@.3@E(#4P
M)2!N;RUR97!E870G/B(@*R!I,3AN6R)486)L92!0<F]P97)T:65S(ET@*R`B
M7`H\+V1I=CX@7`H\=&%B;&4@<W1Y;&4])W=I9'1H.C$P,"4G/B!<"B`@/'1R
M/B!<"B`@("`\=&0^(%P*("`@("`@/&9I96QD<V5T/CQL96=E;F0^(B`K(&DQ
M.&Y;(D1E<V-R:7!T:6]N(ET@*R`B/"]L96=E;F0^(%P*("`@("`@(#QT86)L
M92!S='EL93TG=VED=&@Z,3`P)2<^(%P*("`@("`@("`\='(^(%P*("`@("`@
M("`@(#QT9"!C;&%S<STG;&%B96PG/B(@*R!I,3AN6R)#87!T:6]N(ET@*R`B
M.CPO=&0^(%P*("`@("`@("`@(#QT9"!C;&%S<STG=F%L=64G/CQI;G!U="!T
M>7!E/2=T97AT)R!N86UE/2=F7V-A<'1I;VXG('9A;'5E/2<B("L@9E]C87!T
M:6]N("L@(B<O/CPO=&0^(%P*("`@("`@("`\+W1R/CQT<CX@7`H@("`@("`@
M("`@/'1D(&-L87-S/2=L86)E;"<^(B`K(&DQ.&Y;(E-U;6UA<GDB72`K("(Z
M/"]T9#X@7`H@("`@("`@("`@/'1D(&-L87-S/2=V86QU92<^/&EN<'5T('1Y
M<&4])W1E>'0G(&YA;64])V9?<W5M;6%R>2<@=F%L=64])R(@*R!F7W-U;6UA
M<GD@*R`B)R\^/"]T9#X@7`H@("`@("`@(#PO='(^(%P*("`@("`@(#PO=&%B
M;&4^(%P*("`@("`@/"]F:65L9'-E=#X@7`H@("`@/"]T9#X@7`H@(#PO='(^
M(%P*("`\='(^/'1D(&ED/2<M+4A!+6QA>6]U="<^/"]T9#X\+W1R/B!<"B`@
M/'1R/B!<"B`@("`\=&0^(%P*("`@("`@/&9I96QD<V5T/CQL96=E;F0^(B`K
M(&DQ.&Y;(E-P86-I;F<@86YD('!A9&1I;F<B72`K("(\+VQE9V5N9#X@7`H@
M("`@("`@/'1A8FQE('-T>6QE/2=W:61T:#HQ,#`E)SX@7`H@("`@("`@(#QT
M<CX@7`H@("`@("`@("`@/'1D(&-L87-S/2=L86)E;"<^(B`K(&DQ.&Y;(E-P
M86-I;F<B72`K("(Z/"]T9#X@7`H@("`@("`@("`@/'1D/CQI;G!U="!T>7!E
M/2=T97AT)R!N86UE/2=F7W-P86-I;F<G('-I>F4])S4G('9A;'5E/2<B("L@
M9E]S<&%C:6YG("L@(B<@+SX@)FYB<W`[(B`K(&DQ.&Y;(E!A9&1I;F<B72`K
M("(Z7`H@("`@("`@("`@("`\:6YP=70@='EP93TG=&5X="<@;F%M93TG9E]P
M861D:6YG)R!S:7IE/2<U)R!V86QU93TG(B`K(&9?<&%D9&EN9R`K("(G("\^
M("9N8G-P.R9N8G-P.R(@*R!I,3AN6R)P:7AE;',B72`K(")<"B`@("`@("`@
M("`\+W1D/B!<"B`@("`@("`@/"]T<CX@7`H@("`@("`@/"]T86)L93X@7`H@
M("`@("`\+V9I96QD<V5T/B!<"B`@("`\+W1D/B!<"B`@/"]T<CX@7`H@(#QT
M<CX@7`H@("`@/'1D/B!<"B`@("`@(#QF:65L9'-E=#X\;&5G96YD/D9R86UE
M(&%N9"!B;W)D97)S/"]L96=E;F0^(%P*("`@("`@("`\=&%B;&4@=VED=&@]
M)S$P,"4G/B!<"B`@("`@("`@("`\='(^(%P*("`@("`@("`@("`@/'1D(&-L
M87-S/2=L86)E;"<^(B`K(&DQ.&Y;(D)O<F1E<G,B72`K("(Z/"]T9#X@7`H@
M("`@("`@("`@("`\=&0^/&EN<'5T(&YA;64])V9?8F]R9&5R<R<@='EP93TG
M=&5X="<@<VEZ93TG-2<@=F%L=64])R(@*R!F7V)O<F1E<G,@*R`B)R`O/B`F
M;F)S<#LF;F)S<#LB("L@:3$X;ELB<&EX96QS(ET@*R`B/"]T9#X@7`H@("`@
M("`@("`@/"]T<CX@7`H@("`@("`@("`@/'1R/B!<"B`@("`@("`@("`@(#QT
M9"!C;&%S<STG;&%B96PG/B(@*R!I,3AN6R)&<F%M97,B72`K("(Z/"]T9#X@
M7`H@("`@("`@("`@("`\=&0^(%P*("`@("`@("`@("`@("`\<V5L96-T(&YA
M;64])V9?9G)A;65S)SX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU
M93TG=F]I9"<B("L@<V5L96-T960H9E]F<F%M97,@/3T@(G9O:60B*2`K("(^
M(B`K(&DQ.&Y;(DYO('-I9&5S(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64])V%B;W9E)R(@*R!S96QE8W1E9"AF7V9R
M86UE<R`]/2`B86)O=F4B*2`K("(^(B`K(&DQ.&Y;(E1H92!T;W`@<VED92!O
M;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64])V)E;&]W)R(@*R!S96QE8W1E9"AF7V9R86UE<R`]/2`B8F5L;W<B
M*2`K("(^(B`K(&DQ.&Y;(E1H92!B;W1T;VT@<VED92!O;FQY(ET@*R`B/"]O
M<'1I;VX^(%P*("`@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64])VAS:61E
M<R<B("L@<V5L96-T960H9E]F<F%M97,@/3T@(FAS:61E<R(I("L@(CXB("L@
M:3$X;ELB5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB72`K("(\+V]P
M=&EO;CX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG=G-I9&5S
M)R(@*R!S96QE8W1E9"AF7V9R86UE<R`]/2`B=G-I9&5S(BD@*R`B/B(@*R!I
M,3AN6R)4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2)=("L@(CPO;W!T
M:6]N/B!<"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=L:',G(B`K
M('-E;&5C=&5D*&9?9G)A;65S(#T](")L:',B*2`K("(^(B`K(&DQ.&Y;(E1H
M92!L969T+6AA;F0@<VED92!O;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64])W)H<R<B("L@<V5L96-T960H9E]F
M<F%M97,@/3T@(G)H<R(I("L@(CXB("L@:3$X;ELB5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64])V)O>"<B("L@<V5L96-T960H9E]F<F%M97,@/3T@(F)O
M>"(I("L@(CXB("L@:3$X;ELB06QL(&9O=7(@<VED97,B72`K("(\+V]P=&EO
M;CX@7`H@("`@("`@("`@("`@(#PO<V5L96-T/B!<"B`@("`@("`@("`@(#PO
M=&0^(%P*("`@("`@("`@(#PO='(^(%P*("`@("`@("`@(#QT<CX@7`H@("`@
M("`@("`@("`\=&0@8VQA<W,])VQA8F5L)SXB("L@:3$X;ELB4G5L97,B72`K
M("(Z/"]T9#X@7`H@("`@("`@("`@("`\=&0^(%P*("`@("`@("`@("`@("`\
M<V5L96-T(&YA;64])V9?<G5L97,G/B!<"B`@("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2=N;VYE)R(@*R!S96QE8W1E9"AF7W)U;&5S(#T](")N;VYE
M(BD@*R`B/B(@*R!I,3AN6R).;R!R=6QE<R)=("L@(CPO;W!T:6]N/B!<"B`@
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=R;W=S)R(@*R!S96QE8W1E
M9"AF7W)U;&5S(#T](")R;W=S(BD@*R`B/B(@*R!I,3AN6R)2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>2)=("L@(CPO;W!T:6]N/B!<"B`@
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=C;VQS)R(@*R!S96QE8W1E
M9"AF7W)U;&5S(#T](")C;VQS(BD@*R`B/B(@*R!I,3AN6R)2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2)=("L@(CPO;W!T:6]N/B!<
M"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=A;&PG(B`K('-E;&5C
M=&5D*&9?<G5L97,@/3T@(F%L;"(I("L@(CXB("L@:3$X;ELB4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R)=("L@(CPO
M;W!T:6]N/B!<"B`@("`@("`@("`@("`@/"]S96QE8W0^(%P*("`@("`@("`@
M("`@/"]T9#X@7`H@("`@("`@("`@/"]T<CX@7`H@("`@("`@(#PO=&%B;&4^
M(%P*("`@("`@/"]F:65L9'-E=#X@7`H@("`@/"]T9#X@7`H@(#PO='(^(%P*
M("`\='(^(%P*("`@(#QT9"!I9#TG+2U(02US='EL92<^/"]T9#X@7`H@(#PO
M='(^(%P*/"]T86)L93X@7`HB.PH)"79A<B!S=%]P<F]P(#T@5&%B;&5/<&5R
M871I;VYS+F-R96%T95-T>6QE1FEE;&1S970H9&EA;&]G+F1O8RP@9&EA;&]G
M+F5D:71O<BP@=&%B;&4I.PH)"79A<B!P(#T@9&EA;&]G+F1O8RYG971%;&5M
M96YT0GE)9"@B+2U(02US='EL92(I.PH)"7`N87!P96YD0VAI;&0H<W1?<')O
M<"D["@D)=F%R('-T7VQA>6]U="`](%1A8FQE3W!E<F%T:6]N<RYC<F5A=&53
M='EL94QA>6]U=$9I96QD<V5T*&1I86QO9RYD;V,L(&1I86QO9RYE9&ET;W(L
M('1A8FQE*3L*"0EP(#T@9&EA;&]G+F1O8RYG971%;&5M96YT0GE)9"@B+2U(
M02UL87EO=70B*3L*"0EP+F%P<&5N9$-H:6QD*'-T7VQA>6]U="D["@D)9&EA
M;&]G+FUO9&%L(#T@=')U93L*"0ED:6%L;V<N861D0G5T=&]N<R@B;VLB+"`B
M8V%N8V5L(BD["@D)9&EA;&]G+G-H;W=!=$5L96UE;G0H9&EA;&]G+F5D:71O
M<BY?:69R86UE+"`B8R(I.PH)?2D["GT["@HO+R!T:&ES(&9U;F-T:6]N(')E
M<75I<F5S('1H92!F:6QE(%!O<'5P1&EV+U!O<'5P5VEN('1O(&)E(&QO861E
M9"!F<F]M(&)R;W=S97(*5&%B;&5/<&5R871I;VYS+G!R;W1O='EP92YD:6%L
M;V=2;W=#96QL4')O<&5R=&EE<R`](&9U;F-T:6]N*&-E;&PI('L*"79A<B!I
M,3AN(#T@5&%B;&5/<&5R871I;VYS+DDQ.$X["@DO+R!R971R:65V92!E>&ES
M=&EN9R!V86QU97,*"79A<B!E;&5M96YT(#T@=&AI<RYG971#;&]S97-T*&-E
M;&P@/R`B=&0B(#H@(G1R(BD["@EV87(@=&%B;&4@/2!T:&ES+F=E=$-L;W-E
M<W0H(G1A8FQE(BD["@DO+R!T:&ES+F5D:71O<BYS96QE8W1.;V1E0V]N=&5N
M=',H96QE;65N="D["@DO+R!T:&ES+F5D:71O<BYU<&1A=&54;V]L8F%R*"D[
M"@H)=F%R(&1I86QO9R`](&YE=R!0;W!U<%=I;BAT:&ES+F5D:71O<BP@:3$X
M;EMC96QL(#\@(D-E;&P@4')O<&5R=&EE<R(@.B`B4F]W(%!R;W!E<G1I97,B
M72P@9G5N8W1I;VXH9&EA;&]G+"!P87)A;7,I('L*"0E486)L94]P97)A=&EO
M;G,N<')O8V5S<U-T>6QE*'!A<F%M<RP@96QE;65N="D["@D)9F]R("AV87(@
M:2!I;B!P87)A;7,I('L*"0D)=F%R('9A;"`]('!A<F%M<UMI73L*"0D)<W=I
M=&-H("AI*2!["@D)"2`@("!C87-E(")F7V%L:6=N(CH*"0D)"65L96UE;G0N
M86QI9VX@/2!V86P["@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?8VAA<B(Z
M"@D)"0EE;&5M96YT+F-H(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C87-E
M(")F7W9A;&EG;B(Z"@D)"0EE;&5M96YT+G9!;&EG;B`]('9A;#L*"0D)"6)R
M96%K.PH)"0E]"@D)?0H)"2\O('9A<FEO=7,@=V]R:V%R;W5N9',@=&\@<F5F
M<F5S:"!T:&4@=&%B;&4@9&ES<&QA>2`H1V5C:V\L"@D)+R\@=VAA="=S(&=O
M:6YG(&]N/R$@9&\@;F]T(&1I<V%P<&]I;G0@;64A*0H)"61I86QO9RYE9&ET
M;W(N9F]R8V52961R87<H*3L*"0ED:6%L;V<N961I=&]R+F9O8W5S161I=&]R
M*"D["@D)9&EA;&]G+F5D:71O<BYU<&1A=&54;V]L8F%R*"D["@D)=F%R('-A
M=F5?8V]L;&%P<V4@/2!T86)L92YS='EL92YB;W)D97)#;VQL87!S93L*"0ET
M86)L92YS='EL92YB;W)D97)#;VQL87!S92`](")C;VQL87!S92(["@D)=&%B
M;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2`B<V5P87)A=&4B.PH)"71A8FQE
M+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@<V%V95]C;VQL87!S93L*"7TL"@H)
M+R\@=&AI<R!F=6YC=&EO;B!G971S(&-A;&QE9"!W:&5N('1H92!D:6%L;V<@
M;F5E9',@=&\@8F4@:6YI=&EA;&EZ960*"69U;F-T:6]N("AD:6%L;V<I('L*
M"@D)=F%R(&9?86QI9VX@/2!E;&5M96YT+F%L:6=N.PH)"79A<B!F7W9A;&EG
M;B`](&5L96UE;G0N=D%L:6=N.PH)"79A<B!F7V-H87(@/2!E;&5M96YT+F-H
M.PH*"0EF=6YC=&EO;B!S96QE8W1E9"AV86PI('L*"0D)<F5T=7)N('9A;"`_
M("(@<V5L96-T960B(#H@(B(["@D)?3L*"@D)+R\@9&EA;&]G(&-O;G1E;G1S
M"@D)9&EA;&]G+F-O;G1E;G0N<W1Y;&4N=VED=&@@/2`B-#`P<'@B.PH)"61I
M86QO9RYC;VYT96YT+FEN;F5R2%1-3"`]("(@7`H\9&EV(&-L87-S/2=T:71L
M92=<"B!S='EL93TG8F%C:V=R;W5N9#H@=7)L*"(@*R!D:6%L;V<N8F%S9552
M3"`K(&1I86QO9RYE9&ET;W(N:6UG55),*&-E;&P@/R`B8V5L;"UP<F]P+F=I
M9B(@.B`B<F]W+7!R;W`N9VEF(BP@(E1A8FQE3W!E<F%T:6]N<R(I("L@(BD@
M(V9F9B`Y."4@-3`E(&YO+7)E<&5A="<^(B`K(&DQ.&Y;8V5L;"`_(")#96QL
M(%!R;W!E<G1I97,B(#H@(E)O=R!0<F]P97)T:65S(ET@*R`B/"]D:78^(%P*
M/'1A8FQE('-T>6QE/2=W:61T:#HQ,#`E)SX@7`H@(#QT<CX@7`H@("`@/'1D
M(&ED/2<M+4A!+6QA>6]U="<^(%P*("`@(#PO=&0^(%P*("`\+W1R/B!<"B`@
M/'1R/B!<"B`@("`\=&0@:60])RTM2$$M<W1Y;&4G/CPO=&0^(%P*("`\+W1R
M/B!<"CPO=&%B;&4^(%P*(CL*"0EV87(@<W1?<')O<"`](%1A8FQE3W!E<F%T
M:6]N<RYC<F5A=&53='EL949I96QD<V5T*&1I86QO9RYD;V,L(&1I86QO9RYE
M9&ET;W(L(&5L96UE;G0I.PH)"79A<B!P(#T@9&EA;&]G+F1O8RYG971%;&5M
M96YT0GE)9"@B+2U(02US='EL92(I.PH)"7`N87!P96YD0VAI;&0H<W1?<')O
M<"D["@D)=F%R('-T7VQA>6]U="`](%1A8FQE3W!E<F%T:6]N<RYC<F5A=&53
M='EL94QA>6]U=$9I96QD<V5T*&1I86QO9RYD;V,L(&1I86QO9RYE9&ET;W(L
M(&5L96UE;G0I.PH)"7`@/2!D:6%L;V<N9&]C+F=E=$5L96UE;G1">4ED*"(M
M+4A!+6QA>6]U="(I.PH)"7`N87!P96YD0VAI;&0H<W1?;&%Y;W5T*3L*"0ED
M:6%L;V<N;6]D86P@/2!T<G5E.PH)"61I86QO9RYA9&1"=71T;VYS*")O:R(L
M(")C86YC96PB*3L*"0ED:6%L;V<N<VAO=T%T16QE;65N="AD:6%L;V<N961I
M=&]R+E]I9G)A;64L(")C(BD["@E]*3L*?3L*"B\O('1H:7,@9G5N8W1I;VX@
M9V5T<R!C86QL960@=VAE;B!S;VUE(&)U='1O;B!F<F]M('1H92!486)L94]P
M97)A=&EO;G,@=&]O;&)A<@HO+R!W87,@<')E<W-E9"X*5&%B;&5/<&5R871I
M;VYS+G!R;W1O='EP92YB=71T;VY0<F5S<R`](&9U;F-T:6]N*&5D:71O<BP@
M8G5T=&]N7VED*2!["@ET:&ES+F5D:71O<B`](&5D:71O<CL*"79A<B!M;WIB
M<B`]($A434Q!<F5A+FES7V=E8VMO(#\@(CQB<B`O/B(@.B`B(CL*"79A<B!I
M,3AN(#T@5&%B;&5/<&5R871I;VYS+DDQ.$X["@H)+R\@:&5L<&5R(&9U;F-T
M:6]N('1H870@8VQE87)S('1H92!C;VYT96YT(&EN(&$@=&%B;&4@<F]W"@EF
M=6YC=&EO;B!C;&5A<E)O=RAT<BD@>PH)"79A<B!T9',@/2!T<BYG971%;&5M
M96YT<T)Y5&%G3F%M92@B=&0B*3L*"0EF;W(@*'9A<B!I(#T@=&1S+FQE;F=T
M:#L@+2UI(#X](#`[*2!["@D)"79A<B!T9"`]('1D<UMI73L*"0D)=&0N<F]W
M4W!A;B`](#$["@D)"71D+FEN;F5R2%1-3"`](&UO>F)R.PH)"7T*"7T["@H)
M9G5N8W1I;VX@<W!L:712;W<H=&0I('L*"0EV87(@;B`]('!A<G-E26YT*"(B
M("L@=&0N<F]W4W!A;BD["@D)=F%R(&YC(#T@<&%R<V5);G0H(B(@*R!T9"YC
M;VQ3<&%N*3L*"0ET9"YR;W=3<&%N(#T@,3L*"0ET<B`]('1D+G!A<F5N=$YO
M9&4["@D)=F%R(&ET<B`]('1R+G)O=TEN9&5X.PH)"79A<B!T<G,@/2!T<BYP
M87)E;G1.;V1E+G)O=W,["@D)=F%R(&EN9&5X(#T@=&0N8V5L;$EN9&5X.PH)
M"7=H:6QE("@M+6X@/B`P*2!["@D)"71R(#T@=')S6RLK:71R73L*"0D)=F%R
M(&]T9"`](&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)"6]T
M9"YC;VQ3<&%N(#T@=&0N8V]L4W!A;CL*"0D);W1D+FEN;F5R2%1-3"`](&UO
M>F)R.PH)"0ET<BYI;G-E<G1"969O<F4H;W1D+"!T<BYC96QL<UMI;F1E>%TI
M.PH)"7T*"0EE9&ET;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N=7!D871E
M5&]O;&)A<B@I.PH)?3L*"@EF=6YC=&EO;B!S<&QI=$-O;"AT9"D@>PH)"79A
M<B!N8R`]('!A<G-E26YT*"(B("L@=&0N8V]L4W!A;BD["@D)=&0N8V]L4W!A
M;B`](#$["@D)='(@/2!T9"YP87)E;G1.;V1E.PH)"79A<B!R968@/2!T9"YN
M97AT4VEB;&EN9SL*"0EW:&EL92`H+2UN8R`^(#`I('L*"0D)=F%R(&]T9"`]
M(&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)"6]T9"YR;W=3
M<&%N(#T@=&0N<F]W4W!A;CL*"0D);W1D+FEN;F5R2%1-3"`](&UO>F)R.PH)
M"0ET<BYI;G-E<G1"969O<F4H;W1D+"!R968I.PH)"7T*"0EE9&ET;W(N9F]R
M8V52961R87<H*3L*"0EE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)?3L*"@EF
M=6YC=&EO;B!S<&QI=$-E;&PH=&0I('L*"0EV87(@;F,@/2!P87)S94EN="@B
M(B`K('1D+F-O;%-P86XI.PH)"7-P;&ET0V]L*'1D*3L*"0EV87(@:71E;7,@
M/2!T9"YP87)E;G1.;V1E+F-E;&QS.PH)"79A<B!I;F1E>"`]('1D+F-E;&Q)
M;F1E>#L*"0EW:&EL92`H;F,M+2`^(#`I('L*"0D)<W!L:712;W<H:71E;7-;
M:6YD97@K*UTI.PH)"7T*"7T["@H)9G5N8W1I;VX@<V5L96-T3F5X=$YO9&4H
M96PI('L*"0EV87(@;F]D92`](&5L+FYE>'13:6)L:6YG.PH)"7=H:6QE("AN
M;V1E("8F(&YO9&4N;F]D951Y<&4@(3T@,2D@>PH)"0EN;V1E(#T@;F]D92YN
M97AT4VEB;&EN9SL*"0E]"@D):68@*"%N;V1E*2!["@D)"6YO9&4@/2!E;"YP
M<F5V:6]U<U-I8FQI;F<["@D)"7=H:6QE("AN;V1E("8F(&YO9&4N;F]D951Y
M<&4@(3T@,2D@>PH)"0D);F]D92`](&YO9&4N<')E=FEO=7-3:6)L:6YG.PH)
M"0E]"@D)?0H)"6EF("@A;F]D92D@>PH)"0EN;V1E(#T@96PN<&%R96YT3F]D
M93L*"0E]"@D)961I=&]R+G-E;&5C=$YO9&5#;VYT96YT<RAN;V1E*3L*"7T[
M"@H)<W=I=&-H("AB=71T;VY?:60I('L*"0DO+R!23U=3"@H)("`@(&-A<V4@
M(E1/+7)O=RUI;G-E<G0M86)O=F4B.@H)("`@(&-A<V4@(E1/+7)O=RUI;G-E
M<G0M=6YD97(B.@H)"79A<B!T<B`]('1H:7,N9V5T0VQO<V5S="@B='(B*3L*
M"0EI9B`H(71R*2!["@D)"6)R96%K.PH)"7T*"0EV87(@;W1R(#T@='(N8VQO
M;F5.;V1E*'1R=64I.PH)"6-L96%R4F]W*&]T<BD["@D)='(N<&%R96YT3F]D
M92YI;G-E<G1"969O<F4H;W1R+"`O=6YD97(O+G1E<W0H8G5T=&]N7VED*2`_
M('1R+FYE>'13:6)L:6YG(#H@='(I.PH)"65D:71O<BYF;W)C95)E9')A=R@I
M.PH)"65D:71O<BYF;V-U<T5D:71O<B@I.PH)"6)R96%K.PH)("`@(&-A<V4@
M(E1/+7)O=RUD96QE=&4B.@H)"79A<B!T<B`]('1H:7,N9V5T0VQO<V5S="@B
M='(B*3L*"0EI9B`H(71R*2!["@D)"6)R96%K.PH)"7T*"0EV87(@<&%R(#T@
M='(N<&%R96YT3F]D93L*"0EI9B`H<&%R+G)O=W,N;&5N9W1H(#T](#$I('L*
M"0D)86QE<G0H:3$X;ELB;F]T+61E;"UL87-T+7)O=R)=*3L*"0D)8G)E86L[
M"@D)?0H)"2\O('-E="!T:&4@8V%R970@9FER<W0@=&\@82!P;W-I=&EO;B!T
M:&%T(&1O97-N)W0*"0DO+R!D:7-A<'!E87(N"@D)<V5L96-T3F5X=$YO9&4H
M='(I.PH)"7!A<BYR96UO=F5#:&EL9"AT<BD["@D)961I=&]R+F9O<F-E4F5D
M<F%W*"D["@D)961I=&]R+F9O8W5S161I=&]R*"D["@D)961I=&]R+G5P9&%T
M951O;VQB87(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUR;W<M<W!L:70B
M.@H)"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H(71D
M*2!["@D)"6)R96%K.PH)"7T*"0ES<&QI=%)O=RAT9"D["@D)8G)E86L["@H)
M"2\O($-/3%5-3E,*"@D@("`@8V%S92`B5$\M8V]L+6EN<V5R="UB969O<F4B
M.@H)("`@(&-A<V4@(E1/+6-O;"UI;G-E<G0M869T97(B.@H)"79A<B!T9"`]
M('1H:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H(71D*2!["@D)"6)R96%K
M.PH)"7T*"0EV87(@<F]W<R`]('1D+G!A<F5N=$YO9&4N<&%R96YT3F]D92YR
M;W=S.PH)"79A<B!I;F1E>"`]('1D+F-E;&Q);F1E>#L*"0EF;W(@*'9A<B!I
M(#T@<F]W<RYL96YG=&@[("TM:2`^/2`P.RD@>PH)"0EV87(@='(@/2!R;W=S
M6VE=.PH)"0EV87(@<F5F(#T@='(N8V5L;'-;:6YD97@@*R`H+V%F=&5R+RYT
M97-T*&)U='1O;E]I9"D@/R`Q(#H@,"E=.PH)"0EV87(@;W1D(#T@961I=&]R
M+E]D;V,N8W)E871E16QE;65N="@B=&0B*3L*"0D);W1D+FEN;F5R2%1-3"`]
M(&UO>F)R.PH)"0ET<BYI;G-E<G1"969O<F4H;W1D+"!R968I.PH)"7T*"0EE
M9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUC
M;VPM<W!L:70B.@H)"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B*3L*
M"0EI9B`H(71D*2!["@D)"6)R96%K.PH)"7T*"0ES<&QI=$-O;"AT9"D["@D)
M8G)E86L["@D@("`@8V%S92`B5$\M8V]L+61E;&5T92(Z"@D)=F%R('1D(#T@
M=&AI<RYG971#;&]S97-T*")T9"(I.PH)"6EF("@A=&0I('L*"0D)8G)E86L[
M"@D)?0H)"79A<B!I;F1E>"`]('1D+F-E;&Q);F1E>#L*"0EI9B`H=&0N<&%R
M96YT3F]D92YC96QL<RYL96YG=&@@/3T@,2D@>PH)"0EA;&5R="AI,3AN6R)N
M;W0M9&5L+6QA<W0M8V]L(ETI.PH)"0EB<F5A:SL*"0E]"@D)+R\@<V5T('1H
M92!C87)E="!F:7)S="!T;R!A('!O<VET:6]N('1H870@9&]E<VXG="!D:7-A
M<'!E87(*"0ES96QE8W1.97AT3F]D92AT9"D["@D)=F%R(')O=W,@/2!T9"YP
M87)E;G1.;V1E+G!A<F5N=$YO9&4N<F]W<SL*"0EF;W(@*'9A<B!I(#T@<F]W
M<RYL96YG=&@[("TM:2`^/2`P.RD@>PH)"0EV87(@='(@/2!R;W=S6VE=.PH)
M"0ET<BYR96UO=F5#:&EL9"AT<BYC96QL<UMI;F1E>%TI.PH)"7T*"0EE9&ET
M;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0EE
M9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"6)R96%K.PH*"0DO+R!#14Q,4PH*
M"2`@("!C87-E(")43RUC96QL+7-P;&ET(CH*"0EV87(@=&0@/2!T:&ES+F=E
M=$-L;W-E<W0H(G1D(BD["@D):68@*"%T9"D@>PH)"0EB<F5A:SL*"0E]"@D)
M<W!L:71#96QL*'1D*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUC96QL+6EN
M<V5R="UB969O<F4B.@H)("`@(&-A<V4@(E1/+6-E;&PM:6YS97)T+6%F=&5R
M(CH*"0EV87(@=&0@/2!T:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D):68@*"%T
M9"D@>PH)"0EB<F5A:SL*"0E]"@D)=F%R('1R(#T@=&0N<&%R96YT3F]D93L*
M"0EV87(@;W1D(#T@961I=&]R+E]D;V,N8W)E871E16QE;65N="@B=&0B*3L*
M"0EO=&0N:6YN97)(5$U,(#T@;6]Z8G(["@D)='(N:6YS97)T0F5F;W)E*&]T
M9"P@+V%F=&5R+RYT97-T*&)U='1O;E]I9"D@/R!T9"YN97AT4VEB;&EN9R`Z
M('1D*3L*"0EE9&ET;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N9F]C=7-%
M9&ET;W(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUC96QL+61E;&5T92(Z
M"@D)=F%R('1D(#T@=&AI<RYG971#;&]S97-T*")T9"(I.PH)"6EF("@A=&0I
M('L*"0D)8G)E86L["@D)?0H)"6EF("AT9"YP87)E;G1.;V1E+F-E;&QS+FQE
M;F=T:"`]/2`Q*2!["@D)"6%L97)T*&DQ.&Y;(FYO="UD96PM;&%S="UC96QL
M(ETI.PH)"0EB<F5A:SL*"0E]"@D)+R\@<V5T('1H92!C87)E="!F:7)S="!T
M;R!A('!O<VET:6]N('1H870@9&]E<VXG="!D:7-A<'!E87(*"0ES96QE8W1.
M97AT3F]D92AT9"D["@D)=&0N<&%R96YT3F]D92YR96UO=F5#:&EL9"AT9"D[
M"@D)961I=&]R+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+G5P9&%T951O;VQB
M87(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUC96QL+6UE<F=E(CH*"0DO
M+R`A(2!&25A-13H@36]Z:6QL82!S<&5C:69I8R`A(0H)"79A<B!S96P@/2!E
M9&ET;W(N7V=E=%-E;&5C=&EO;B@I.PH)"79A<B!R86YG92P@:2`](#`["@D)
M=F%R(')O=W,@/2!;73L*"0EV87(@<F]W(#T@;G5L;#L*"0EV87(@8V5L;',@
M/2!N=6QL.PH)"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0D)=')Y('L*"0D)
M"7=H:6QE("AR86YG92`]('-E;"YG971286YG94%T*&DK*RDI('L*"0D)"0EV
M87(@=&0@/2!R86YG92YS=&%R=$-O;G1A:6YE<BYC:&EL9$YO9&5S6W)A;F=E
M+G-T87)T3V9F<V5T73L*"0D)"0EI9B`H=&0N<&%R96YT3F]D92`A/2!R;W<I
M('L*"0D)"0D)<F]W(#T@=&0N<&%R96YT3F]D93L*"0D)"0D)*&-E;&QS*2`F
M)B!R;W=S+G!U<V@H8V5L;',I.PH)"0D)"0EC96QL<R`](%M=.PH)"0D)"7T*
M"0D)"0EC96QL<RYP=7-H*'1D*3L*"0D)"7T*"0D)?2!C871C:"AE*2![+RH@
M9FEN:7-H960@=V%L:VEN9R!T:')O=6=H('-E;&5C=&EO;B`J+WT*"0D)<F]W
M<RYP=7-H*&-E;&QS*3L*"0E](&5L<V4@>PH)"0DO+R!);G1E<FYE="!%>'!L
M;W)E<B`B8G)O=W-E<B(*"0D)=F%R('1D(#T@=&AI<RYG971#;&]S97-T*")T
M9"(I.PH)"0EI9B`H(71D*2!["@D)"0EA;&5R="AI,3AN6R)0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB72D["@D)"0EB<F5A:SL*"0D)?0H)"0EV87(@
M='(@/2!T9"YP87)E;G1%;&5M96YT.PH)"0EV87(@;F]?8V]L<R`]('!R;VUP
M="AI,3AN6R)(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R)=+"`R*3L*"0D):68@*"%N;U]C;VQS*2!["@D)"0DO+R!C86YC96QL
M960*"0D)"6)R96%K.PH)"0E]"@D)"79A<B!N;U]R;W=S(#T@<')O;7!T*&DQ
M.&Y;(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(ETL
M(#(I.PH)"0EI9B`H(6YO7W)O=W,I('L*"0D)"2\O(&-A;F-E;&QE9`H)"0D)
M8G)E86L["@D)"7T*"0D)=F%R(&-E;&Q?:6YD97@@/2!T9"YC96QL26YD97@[
M"@D)"7=H:6QE("AN;U]R;W=S+2T@/B`P*2!["@D)"0ET9"`]('1R+F-E;&QS
M6V-E;&Q?:6YD97A=.PH)"0D)8V5L;',@/2!;=&1=.PH)"0D)9F]R("AV87(@
M:2`](#$[(&D@/"!N;U]C;VQS.R`K*VDI('L*"0D)"0ET9"`]('1D+FYE>'13
M:6)L:6YG.PH)"0D)"6EF("@A=&0I('L*"0D)"0D)8G)E86L["@D)"0D)?0H)
M"0D)"6-E;&QS+G!U<V@H=&0I.PH)"0D)?0H)"0D)<F]W<RYP=7-H*&-E;&QS
M*3L*"0D)"71R(#T@='(N;F5X=%-I8FQI;F<["@D)"0EI9B`H(71R*2!["@D)
M"0D)8G)E86L["@D)"0E]"@D)"7T*"0E]"@D)=F%R($A434P@/2`B(CL*"0EF
M;W(@*&D@/2`P.R!I(#P@<F]W<RYL96YG=&@[("LK:2D@>PH)"0DO+R!I("8F
M("A(5$U,("L]("(\8G(@+SXB*3L*"0D)=F%R(&-E;&QS(#T@<F]W<UMI73L*
M"0D)9F]R("AV87(@:B`](#`[(&H@/"!C96QL<RYL96YG=&@[("LK:BD@>PH)
M"0D)+R\@:B`F)B`H2%1-3"`K/2`B)FYB<W`[(BD["@D)"0EV87(@8V5L;"`]
M(&-E;&QS6VI=.PH)"0D)2%1-3"`K/2!C96QL+FEN;F5R2%1-3#L*"0D)"2AI
M('Q\(&HI("8F("AC96QL+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H8V5L;"DI
M.PH)"0E]"@D)?0H)"79A<B!T9"`](')O=W-;,%U;,%T["@D)=&0N:6YN97)(
M5$U,(#T@2%1-3#L*"0ET9"YR;W=3<&%N(#T@<F]W<RYL96YG=&@["@D)=&0N
M8V]L4W!A;B`](')O=W-;,%TN;&5N9W1H.PH)"65D:71O<BYS96QE8W1.;V1E
M0V]N=&5N=',H=&0I.PH)"65D:71O<BYF;W)C95)E9')A=R@I.PH)"65D:71O
M<BYF;V-U<T5D:71O<B@I.PH)"6)R96%K.PH*"0DO+R!04D]015)42453"@H)
M("`@(&-A<V4@(E1/+71A8FQE+7!R;W`B.@H)"71H:7,N9&EA;&]G5&%B;&50
M<F]P97)T:65S*"D["@D)8G)E86L["@H)("`@(&-A<V4@(E1/+7)O=RUP<F]P
M(CH*"0ET:&ES+F1I86QO9U)O=T-E;&Q0<F]P97)T:65S*&9A;'-E*3L*"0EB
M<F5A:SL*"@D@("`@8V%S92`B5$\M8V5L;"UP<F]P(CH*"0ET:&ES+F1I86QO
M9U)O=T-E;&Q0<F]P97)T:65S*'1R=64I.PH)"6)R96%K.PH*"2`@("!D969A
M=6QT.@H)"6%L97)T*")"=71T;VX@6R(@*R!B=71T;VY?:60@*R`B72!N;W0@
M>65T(&EM<&QE;65N=&5D(BD["@E]"GT["@HO+R!T:&4@;&ES="!O9B!B=71T
M;VYS(&%D9&5D(&)Y('1H:7,@<&QU9VEN"E1A8FQE3W!E<F%T:6]N<RYB=&Y,
M:7-T(#T@6PH)+R\@=&%B;&4@<')O<&5R=&EE<R!B=71T;VX*"5LB=&%B;&4M
M<')O<"(L("`@("`@(")T86)L92)=+`H);G5L;"P)"0DO+R!S97!A<F%T;W(*
M"@DO+R!23U=3"@E;(G)O=RUP<F]P(BP@("`@("`@("`B='(B72P*"5LB<F]W
M+6EN<V5R="UA8F]V92(L(")T<B)=+`H)6R)R;W<M:6YS97)T+75N9&5R(BP@
M(G1R(ETL"@E;(G)O=RUD96QE=&4B+"`@("`@("`B='(B72P*"5LB<F]W+7-P
M;&ET(BP@("`@("`@(")T9%MR;W=3<&%N(3TQ72)=+`H);G5L;"P*"@DO+R!#
M3TQ3"@E;(F-O;"UI;G-E<G0M8F5F;W)E(BP@(G1D(ETL"@E;(F-O;"UI;G-E
M<G0M869T97(B+"`@(G1D(ETL"@E;(F-O;"UD96QE=&4B+"`@("`@("`@(G1D
M(ETL"@E;(F-O;"US<&QI="(L("`@("`@("`@(G1D6V-O;%-P86XA/3%=(ETL
M"@EN=6QL+`H*"2\O($-%3$Q3"@E;(F-E;&PM<')O<"(L("`@("`@("`@(")T
M9")=+`H)6R)C96QL+6EN<V5R="UB969O<F4B+"`B=&0B72P*"5LB8V5L;"UI
M;G-E<G0M869T97(B+"`@(G1D(ETL"@E;(F-E;&PM9&5L971E(BP@("`@("`@
M(")T9")=+`H)6R)C96QL+6UE<F=E(BP@("`@("`@("`B='(B72P*"5LB8V5L
M;"US<&QI="(L("`@("`@("`@(G1D6V-O;%-P86XA/3$L<F]W4W!A;B$],5TB
M70H)73L*"@H*+R\O+R!'14Y%4DE#($-/1$4@6W-T>6QE(&]F(&%N>2!E;&5M
M96YT.R!T:&ES('-H;W5L9"!B92!M;W9E9"!I;G1O(&$@<V5P87)A=&4*+R\O
M+R!F:6QE(&%S(&ET)VQL(&)E('9E<GD@=7-E9G5L70HO+R\O($)%1TE.($=%
M3D5224,@0T]$12`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+0H*5&%B;&5/<&5R871I;VYS+F=E=$QE;F=T
M:"`](&9U;F-T:6]N*'9A;'5E*2!["@EV87(@;&5N(#T@<&%R<V5);G0H=F%L
M=64I.PH):68@*&ES3F%.*&QE;BDI('L*"0EL96X@/2`B(CL*"7T*"7)E='5R
M;B!L96X["GT["@HO+R!!<'!L:65S('1H92!S='EL92!F;W5N9"!I;B`B<&%R
M86US(B!T;R!T:&4@9VEV96X@96QE;65N="X*5&%B;&5/<&5R871I;VYS+G!R
M;V-E<W-3='EL92`](&9U;F-T:6]N*'!A<F%M<RP@96QE;65N="D@>PH)=F%R
M('-T>6QE(#T@96QE;65N="YS='EL93L*"69O<B`H=F%R(&D@:6X@<&%R86US
M*2!["@D)=F%R('9A;"`]('!A<F%M<UMI73L*"0ES=VET8V@@*&DI('L*"0D@
M("`@8V%S92`B9E]S=%]B86-K9W)O=6YD0V]L;W(B.@H)"0ES='EL92YB86-K
M9W)O=6YD0V]L;W(@/2!V86P["@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T
M7V-O;&]R(CH*"0D)<W1Y;&4N8V]L;W(@/2!V86P["@D)"6)R96%K.PH)"2`@
M("!C87-E(")F7W-T7V)A8VMG<F]U;F1);6%G92(Z"@D)"6EF("@O7%,O+G1E
M<W0H=F%L*2D@>PH)"0D)<W1Y;&4N8F%C:V=R;W5N9$EM86=E(#T@(G5R;"@B
M("L@=F%L("L@(BDB.PH)"0E](&5L<V4@>PH)"0D)<W1Y;&4N8F%C:V=R;W5N
M9$EM86=E(#T@(FYO;F4B.PH)"0E]"@D)"6)R96%K.PH)"2`@("!C87-E(")F
M7W-T7V)O<F1E<E=I9'1H(CH*"0D)<W1Y;&4N8F]R9&5R5VED=&@@/2!V86P[
M"@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7V)O<F1E<E-T>6QE(CH*"0D)
M<W1Y;&4N8F]R9&5R4W1Y;&4@/2!V86P["@D)"6)R96%K.PH)"2`@("!C87-E
M(")F7W-T7V)O<F1E<D-O;&]R(CH*"0D)<W1Y;&4N8F]R9&5R0V]L;W(@/2!V
M86P["@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7V)O<F1E<D-O;&QA<'-E
M(CH*"0D)<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2!V86P@/R`B8V]L;&%P<V4B
M(#H@(B(["@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7W=I9'1H(CH*"0D)
M:68@*"]<4R\N=&5S="AV86PI*2!["@D)"0ES='EL92YW:61T:"`]('9A;"`K
M('!A<F%M<ULB9E]S=%]W:61T:%5N:70B73L*"0D)?2!E;'-E('L*"0D)"7-T
M>6QE+G=I9'1H(#T@(B(["@D)"7T*"0D)8G)E86L["@D)("`@(&-A<V4@(F9?
M<W1?:&5I9VAT(CH*"0D):68@*"]<4R\N=&5S="AV86PI*2!["@D)"0ES='EL
M92YH96EG:'0@/2!V86P@*R!P87)A;7-;(F9?<W1?:&5I9VAT56YI=")=.PH)
M"0E](&5L<V4@>PH)"0D)<W1Y;&4N:&5I9VAT(#T@(B(["@D)"7T*"0D)8G)E
M86L["@D)("`@(&-A<V4@(F9?<W1?=&5X=$%L:6=N(CH*"0D):68@*'9A;"`]
M/2`B8VAA<B(I('L*"0D)"79A<B!C:"`]('!A<F%M<ULB9E]S=%]T97AT06QI
M9VY#:&%R(ET["@D)"0EI9B`H8V@@/3T@)R(G*2!["@D)"0D)8V@@/2`G7%PB
M)SL*"0D)"7T*"0D)"7-T>6QE+G1E>'1!;&EG;B`]("<B)R`K(&-H("L@)R(G
M.PH)"0E](&5L<V4@>PH)"0D)<W1Y;&4N=&5X=$%L:6=N(#T@=F%L.PH)"0E]
M"@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7W9E<G1I8V%L06QI9VXB.@H)
M"0ES='EL92YV97)T:6-A;$%L:6=N(#T@=F%L.PH)"0EB<F5A:SL*"0D@("`@
M8V%S92`B9E]S=%]F;&]A="(Z"@D)"7-T>6QE+F-S<T9L;V%T(#T@=F%L.PH)
M"0EB<F5A:SL*+R\@"0D@("`@8V%S92`B9E]S=%]M87)G:6XB.@HO+R`)"0ES
M='EL92YM87)G:6X@/2!V86P@*R`B<'@B.PHO+R`)"0EB<F5A:SL*+R\@"0D@
M("`@8V%S92`B9E]S=%]P861D:6YG(CH*+R\@"0D)<W1Y;&4N<&%D9&EN9R`]
M('9A;"`K(")P>"(["B\O(`D)"6)R96%K.PH)"7T*"7T*?3L*"B\O(%)E='5R
M;G,@86X@2%1-3"!E;&5M96YT(&9O<B!A('=I9&=E="!T:&%T(&%L;&]W<R!C
M;VQO<B!S96QE8W1I;VXN("!4:&%T(&ES+`HO+R!A(&)U='1O;B!T:&%T(&-O
M;G1A:6YS('1H92!G:79E;B!C;VQO<BP@:68@86YY+"!A;F0@=VAE;B!P<F5S
M<V5D('=I;&P@<&]P=7`*+R\@=&AE('-O;VYE<BUO<BUL871E<BUT;RUB92UR
M97=R:71T96X@<V5L96-T7V-O;&]R+FAT;6P@9&EA;&]G(&%L;&]W:6YG('5S
M97(*+R\@=&\@<V5L96-T('-O;64@8V]L;W(N("!)9B!A(&-O;&]R(&ES('-E
M;&5C=&5D+"!A;B!I;G!U="!F:65L9"!W:71H('1H92!N86UE"B\O(")F7W-T
M7R(K;F%M92!W:6QL(&)E('5P9&%T960@=VET:"!T:&4@8V]L;W(@=F%L=64@
M:6X@(S$R,S0U-B!F;W)M870N"E1A8FQE3W!E<F%T:6]N<RYC<F5A=&5#;VQO
M<D)U='1O;B`](&9U;F-T:6]N*&1O8RP@961I=&]R+"!C;VQO<BP@;F%M92D@
M>PH):68@*"%C;VQO<BD@>PH)"6-O;&]R(#T@(B(["@E](&5L<V4@:68@*"$O
M(R\N=&5S="AC;VQO<BDI('L*"0EC;VQO<B`]($A434Q!<F5A+E]C;VQO<E1O
M4F=B*&-O;&]R*3L*"7T*"@EV87(@9&8@/2!D;V,N8W)E871E16QE;65N="@B
M<W!A;B(I.PH@"79A<B!F:65L9"`](&1O8RYC<F5A=&5%;&5M96YT*")I;G!U
M="(I.PH)9FEE;&0N='EP92`](")H:61D96XB.PH)9&8N87!P96YD0VAI;&0H
M9FEE;&0I.PH@"69I96QD+FYA;64@/2`B9E]S=%\B("L@;F%M93L*"69I96QD
M+G9A;'5E(#T@8V]L;W(["@EV87(@8G5T=&]N(#T@9&]C+F-R96%T945L96UE
M;G0H(G-P86XB*3L*"6)U='1O;BYC;&%S<TYA;64@/2`B8G5T=&]N0V]L;W(B
M.PH)9&8N87!P96YD0VAI;&0H8G5T=&]N*3L*"79A<B!S<&%N(#T@9&]C+F-R
M96%T945L96UE;G0H(G-P86XB*3L*"7-P86XN8VQA<W-.86UE(#T@(F-H;V]S
M97(B.PH)+R\@<W!A;BYI;FYE<DA434P@/2`B)FYB<W`[)FYB<W`[)FYB<W`[
M)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[(CL*"7-P86XN<W1Y;&4N8F%C:V=R
M;W5N9$-O;&]R(#T@8V]L;W(["@EB=71T;VXN87!P96YD0VAI;&0H<W!A;BD[
M"@EB=71T;VXN;VYM;W5S96]V97(@/2!F=6YC=&EO;B@I('L@:68@*"%T:&ES
M+F1I<V%B;&5D*2![('1H:7,N8VQA<W-.86UE("L]("(@8G5T=&]N0V]L;W(M
M:&EL:71E(CL@?7T["@EB=71T;VXN;VYM;W5S96]U="`](&9U;F-T:6]N*"D@
M>R!I9B`H(71H:7,N9&ES86)L960I('L@=&AI<RYC;&%S<TYA;64@/2`B8G5T
M=&]N0V]L;W(B.R!]?3L*"7-P86XN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH)
M"6EF("AT:&ES+G!A<F5N=$YO9&4N9&ES86)L960I('L*"0D)<F5T=7)N(&9A
M;'-E.PH)"7T*"0EE9&ET;W(N7W!O<'5P1&EA;&]G*")S96QE8W1?8V]L;W(N
M:'1M;"(L(&9U;F-T:6]N*&-O;&]R*2!["@D)"6EF("AC;VQO<BD@>PH)"0D)
M<W!A;BYS='EL92YB86-K9W)O=6YD0V]L;W(@/2`B(R(@*R!C;VQO<CL*"0D)
M"69I96QD+G9A;'5E(#T@(B,B("L@8V]L;W(["@D)"7T*"0E]+"!C;VQO<BD[
M"@E].PH)=F%R('-P86XR(#T@9&]C+F-R96%T945L96UE;G0H(G-P86XB*3L*
M"7-P86XR+FEN;F5R2%1-3"`]("(F(W@P,&0W.R(["@ES<&%N,BYC;&%S<TYA
M;64@/2`B;F]C;VQO<B(["@ES<&%N,BYT:71L92`](%1A8FQE3W!E<F%T:6]N
M<RY),3A.6R)5;G-E="!C;VQO<B)=.PH)8G5T=&]N+F%P<&5N9$-H:6QD*'-P
M86XR*3L*"7-P86XR+F]N;6]U<V5O=F5R(#T@9G5N8W1I;VXH*2![(&EF("@A
M=&AI<RYP87)E;G1.;V1E+F1I<V%B;&5D*2![('1H:7,N8VQA<W-.86UE("L]
M("(@;F]C;VQO<BUH:6QI=&4B.R!]?3L*"7-P86XR+F]N;6]U<V5O=70@/2!F
M=6YC=&EO;B@I('L@:68@*"%T:&ES+G!A<F5N=$YO9&4N9&ES86)L960I('L@
M=&AI<RYC;&%S<TYA;64@/2`B;F]C;VQO<B([('U].PH)<W!A;C(N;VYC;&EC
M:R`](&9U;F-T:6]N*"D@>PH)"7-P86XN<W1Y;&4N8F%C:V=R;W5N9$-O;&]R
M(#T@(B(["@D)9FEE;&0N=F%L=64@/2`B(CL*"7T["@ER971U<FX@9&8["GT[
M"@I486)L94]P97)A=&EO;G,N8W)E871E4W1Y;&5,87EO=71&:65L9'-E="`]
M(&9U;F-T:6]N*&1O8RP@961I=&]R+"!E;"D@>PH)=F%R(&DQ.&X@/2!486)L
M94]P97)A=&EO;G,N23$X3CL*"79A<B!F:65L9'-E="`](&1O8RYC<F5A=&5%
M;&5M96YT*")F:65L9'-E="(I.PH)=F%R(&QE9V5N9"`](&1O8RYC<F5A=&5%
M;&5M96YT*")L96=E;F0B*3L*"69I96QD<V5T+F%P<&5N9$-H:6QD*&QE9V5N
M9"D["@EL96=E;F0N:6YN97)(5$U,(#T@:3$X;ELB3&%Y;W5T(ET["@EV87(@
M=&%B;&4@/2!D;V,N8W)E871E16QE;65N="@B=&%B;&4B*3L*"69I96QD<V5T
M+F%P<&5N9$-H:6QD*'1A8FQE*3L*"71A8FQE+G-T>6QE+G=I9'1H(#T@(C$P
M,"4B.PH)=F%R('1B;V1Y(#T@9&]C+F-R96%T945L96UE;G0H(G1B;V1Y(BD[
M"@ET86)L92YA<'!E;F1#:&EL9"AT8F]D>2D["@H)=F%R('1A9VYA;64@/2!E
M;"YT86=.86UE+G1O3&]W97)#87-E*"D["@EV87(@='(L('1D+"!I;G!U="P@
M<V5L96-T+"!O<'1I;VXL(&]P=&EO;G,L(&D["@H):68@*'1A9VYA;64@(3T@
M(G1D(B`F)B!T86=N86UE("$](")T<B(@)B8@=&%G;F%M92`A/2`B=&@B*2![
M"@D)='(@/2!D;V,N8W)E871E16QE;65N="@B='(B*3L*"0ET8F]D>2YA<'!E
M;F1#:&EL9"AT<BD["@D)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*
M"0ET9"YC;&%S<TYA;64@/2`B;&%B96PB.PH)"71R+F%P<&5N9$-H:6QD*'1D
M*3L*"0ET9"YI;FYE<DA434P@/2!I,3AN6R)&;&]A=")=("L@(CHB.PH)"71D
M(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)='(N87!P96YD0VAI;&0H
M=&0I.PH)"7-E;&5C="`](&1O8RYC<F5A=&5%;&5M96YT*")S96QE8W0B*3L*
M"0ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH)"7-E;&5C="YN86UE(#T@(F9?
M<W1?9FQO870B.PH)"6]P=&EO;G,@/2!;(DYO;F4B+"`B3&5F="(L(")2:6=H
M=")=.PH)"69O<B`H=F%R(&D@/2`P.R!I(#P@;W!T:6]N<RYL96YG=&@[("LK
M:2D@>PH)"0EV87(@5F%L(#T@;W!T:6]N<UMI73L*"0D)=F%R('9A;"`](&]P
M=&EO;G-;:5TN=&],;W=E<D-A<V4H*3L*"0D);W!T:6]N(#T@9&]C+F-R96%T
M945L96UE;G0H(F]P=&EO;B(I.PH)"0EO<'1I;VXN:6YN97)(5$U,(#T@:3$X
M;EM686Q=.PH)"0EO<'1I;VXN=F%L=64@/2!V86P["@D)"6]P=&EO;BYS96QE
M8W1E9"`]("@H(B(@*R!E;"YS='EL92YC<W-&;&]A="DN=&],;W=E<D-A<V4H
M*2`]/2!V86PI.PH)"0ES96QE8W0N87!P96YD0VAI;&0H;W!T:6]N*3L*"0E]
M"@E]"@H)='(@/2!D;V,N8W)E871E16QE;65N="@B='(B*3L*"71B;V1Y+F%P
M<&5N9$-H:6QD*'1R*3L*"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD[
M"@ET9"YC;&%S<TYA;64@/2`B;&%B96PB.PH)='(N87!P96YD0VAI;&0H=&0I
M.PH)=&0N:6YN97)(5$U,(#T@:3$X;ELB5VED=&@B72`K("(Z(CL*"71D(#T@
M9&]C+F-R96%T945L96UE;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D[
M"@EI;G!U="`](&1O8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PH):6YP=70N
M='EP92`](")T97AT(CL*"6EN<'5T+G9A;'5E(#T@5&%B;&5/<&5R871I;VYS
M+F=E=$QE;F=T:"AE;"YS='EL92YW:61T:"D["@EI;G!U="YS:7IE(#T@(C4B
M.PH):6YP=70N;F%M92`](")F7W-T7W=I9'1H(CL*"6EN<'5T+G-T>6QE+FUA
M<F=I;E)I9VAT(#T@(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*&EN<'5T*3L*
M"7-E;&5C="`](&1O8RYC<F5A=&5%;&5M96YT*")S96QE8W0B*3L*"7-E;&5C
M="YN86UE(#T@(F9?<W1?=VED=&A5;FET(CL*"6]P=&EO;B`](&1O8RYC<F5A
M=&5%;&5M96YT*")O<'1I;VXB*3L*"6]P=&EO;BYI;FYE<DA434P@/2!I,3AN
M6R)P97)C96YT(ET["@EO<'1I;VXN=F%L=64@/2`B)2(["@EO<'1I;VXN<V5L
M96-T960@/2`O)2\N=&5S="AE;"YS='EL92YW:61T:"D["@ES96QE8W0N87!P
M96YD0VAI;&0H;W!T:6]N*3L*"6]P=&EO;B`](&1O8RYC<F5A=&5%;&5M96YT
M*")O<'1I;VXB*3L*"6]P=&EO;BYI;FYE<DA434P@/2!I,3AN6R)P:7AE;',B
M73L*"6]P=&EO;BYV86QU92`](")P>"(["@EO<'1I;VXN<V5L96-T960@/2`O
M<'@O+G1E<W0H96PN<W1Y;&4N=VED=&@I.PH)<V5L96-T+F%P<&5N9$-H:6QD
M*&]P=&EO;BD["@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH*"7-E;&5C="YS
M='EL92YM87)G:6Y2:6=H="`]("(P+C5E;2(["@ET9"YA<'!E;F1#:&EL9"AD
M;V,N8W)E871E5&5X=$YO9&4H:3$X;ELB5&5X="!A;&EG;B)=("L@(CHB*2D[
M"@ES96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B<V5L96-T(BD["@ES96QE
M8W0N<W1Y;&4N;6%R9VEN3&5F="`]('-E;&5C="YS='EL92YM87)G:6Y2:6=H
M="`]("(P+C5E;2(["@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH)<V5L96-T
M+FYA;64@/2`B9E]S=%]T97AT06QI9VXB.PH);W!T:6]N<R`](%LB3&5F="(L
M(")#96YT97(B+"`B4FEG:'0B+"`B2G5S=&EF>2)=.PH):68@*'1A9VYA;64@
M/3T@(G1D(BD@>PH)"6]P=&EO;G,N<'5S:"@B0VAA<B(I.PH)?0H):6YP=70@
M/2!D;V,N8W)E871E16QE;65N="@B:6YP=70B*3L*"6EN<'5T+FYA;64@/2`B
M9E]S=%]T97AT06QI9VY#:&%R(CL*"6EN<'5T+G-I>F4@/2`B,2(["@EI;G!U
M="YS='EL92YF;VYT1F%M:6QY(#T@(FUO;F]S<&%C92(["@ET9"YA<'!E;F1#
M:&EL9"AI;G!U="D["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N;&5N
M9W1H.R`K*VDI('L*"0EV87(@5F%L(#T@;W!T:6]N<UMI73L*"0EV87(@=F%L
M(#T@5F%L+G1O3&]W97)#87-E*"D["@D);W!T:6]N(#T@9&]C+F-R96%T945L
M96UE;G0H(F]P=&EO;B(I.PH)"6]P=&EO;BYV86QU92`]('9A;#L*"0EO<'1I
M;VXN:6YN97)(5$U,(#T@:3$X;EM686Q=.PH)"6]P=&EO;BYS96QE8W1E9"`]
M("AE;"YS='EL92YT97AT06QI9VXN=&],;W=E<D-A<V4H*2`]/2!V86PI.PH)
M"7-E;&5C="YA<'!E;F1#:&EL9"AO<'1I;VXI.PH)?0H)9G5N8W1I;VX@<V5T
M0VAA<E9I<VEB:6QI='DH=F%L=64I('L*"0EI;G!U="YS='EL92YV:7-I8FEL
M:71Y(#T@=F%L=64@/R`B=FES:6)L92(@.B`B:&ED9&5N(CL*"0EI9B`H=F%L
M=64I('L*"0D):6YP=70N9F]C=7,H*3L*"0D):6YP=70N<V5L96-T*"D["@D)
M?0H)?3L*"7-E;&5C="YO;F-H86YG92`](&9U;F-T:6]N*"D@>R!S971#:&%R
M5FES:6)I;&ET>2AT:&ES+G9A;'5E(#T](")C:&%R(BD[('T["@ES971#:&%R
M5FES:6)I;&ET>2AS96QE8W0N=F%L=64@/3T@(F-H87(B*3L*"@ET<B`](&1O
M8RYC<F5A=&5%;&5M96YT*")T<B(I.PH)=&)O9'DN87!P96YD0VAI;&0H='(I
M.PH)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"71D+F-L87-S3F%M
M92`](")L86)E;"(["@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YI;FYE<DA4
M34P@/2!I,3AN6R)(96EG:'0B72`K("(Z(CL*"71D(#T@9&]C+F-R96%T945L
M96UE;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@EI;G!U="`](&1O
M8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PH):6YP=70N='EP92`](")T97AT
M(CL*"6EN<'5T+G9A;'5E(#T@5&%B;&5/<&5R871I;VYS+F=E=$QE;F=T:"AE
M;"YS='EL92YH96EG:'0I.PH):6YP=70N<VEZ92`]("(U(CL*"6EN<'5T+FYA
M;64@/2`B9E]S=%]H96EG:'0B.PH):6YP=70N<W1Y;&4N;6%R9VEN4FEG:'0@
M/2`B,"XU96TB.PH)=&0N87!P96YD0VAI;&0H:6YP=70I.PH)<V5L96-T(#T@
M9&]C+F-R96%T945L96UE;G0H(G-E;&5C="(I.PH)<V5L96-T+FYA;64@/2`B
M9E]S=%]H96EG:'15;FET(CL*"6]P=&EO;B`](&1O8RYC<F5A=&5%;&5M96YT
M*")O<'1I;VXB*3L*"6]P=&EO;BYI;FYE<DA434P@/2!I,3AN6R)P97)C96YT
M(ET["@EO<'1I;VXN=F%L=64@/2`B)2(["@EO<'1I;VXN<V5L96-T960@/2`O
M)2\N=&5S="AE;"YS='EL92YH96EG:'0I.PH)<V5L96-T+F%P<&5N9$-H:6QD
M*&]P=&EO;BD["@EO<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B;W!T:6]N
M(BD["@EO<'1I;VXN:6YN97)(5$U,(#T@:3$X;ELB<&EX96QS(ET["@EO<'1I
M;VXN=F%L=64@/2`B<'@B.PH);W!T:6]N+G-E;&5C=&5D(#T@+W!X+RYT97-T
M*&5L+G-T>6QE+FAE:6=H="D["@ES96QE8W0N87!P96YD0VAI;&0H;W!T:6]N
M*3L*"71D+F%P<&5N9$-H:6QD*'-E;&5C="D["@H)<V5L96-T+G-T>6QE+FUA
M<F=I;E)I9VAT(#T@(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*&1O8RYC<F5A
M=&5497AT3F]D92AI,3AN6R)697)T:6-A;"!A;&EG;B)=("L@(CHB*2D["@ES
M96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B<V5L96-T(BD["@ES96QE8W0N
M;F%M92`](")F7W-T7W9E<G1I8V%L06QI9VXB.PH)<V5L96-T+G-T>6QE+FUA
M<F=I;DQE9G0@/2`B,"XU96TB.PH)=&0N87!P96YD0VAI;&0H<V5L96-T*3L*
M"6]P=&EO;G,@/2!;(E1O<"(L(")-:61D;&4B+"`B0F]T=&]M(BP@(D)A<V5L
M:6YE(ET["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N;&5N9W1H.R`K
M*VDI('L*"0EV87(@5F%L(#T@;W!T:6]N<UMI73L*"0EV87(@=F%L(#T@5F%L
M+G1O3&]W97)#87-E*"D["@D);W!T:6]N(#T@9&]C+F-R96%T945L96UE;G0H
M(F]P=&EO;B(I.PH)"6]P=&EO;BYV86QU92`]('9A;#L*"0EO<'1I;VXN:6YN
M97)(5$U,(#T@:3$X;EM686Q=.PH)"6]P=&EO;BYS96QE8W1E9"`]("AE;"YS
M='EL92YV97)T:6-A;$%L:6=N+G1O3&]W97)#87-E*"D@/3T@=F%L*3L*"0ES
M96QE8W0N87!P96YD0VAI;&0H;W!T:6]N*3L*"7T*"@ER971U<FX@9FEE;&1S
M970["GT["@HO+R!2971U<FYS(&%N($A434P@96QE;65N="!C;VYT86EN:6YG
M('1H92!S='EL92!A='1R:6)U=&5S(&9O<B!T:&4@9VEV96X*+R\@96QE;65N
M="X@(%1H:7,@8V%N(&)E(&5A<VEL>2!E;6)E9&1E9"!I;G1O(&%N>2!D:6%L
M;V<[('1H92!F=6YC=&EO;F%L:71Y(&ES"B\O(&%L<V\@<')O=FED960N"E1A
M8FQE3W!E<F%T:6]N<RYC<F5A=&53='EL949I96QD<V5T(#T@9G5N8W1I;VXH
M9&]C+"!E9&ET;W(L(&5L*2!["@EV87(@:3$X;B`](%1A8FQE3W!E<F%T:6]N
M<RY),3A..PH)=F%R(&9I96QD<V5T(#T@9&]C+F-R96%T945L96UE;G0H(F9I
M96QD<V5T(BD["@EV87(@;&5G96YD(#T@9&]C+F-R96%T945L96UE;G0H(FQE
M9V5N9"(I.PH)9FEE;&1S970N87!P96YD0VAI;&0H;&5G96YD*3L*"6QE9V5N
M9"YI;FYE<DA434P@/2!I,3AN6R)#4U,@4W1Y;&4B73L*"79A<B!T86)L92`]
M(&1O8RYC<F5A=&5%;&5M96YT*")T86)L92(I.PH)9FEE;&1S970N87!P96YD
M0VAI;&0H=&%B;&4I.PH)=&%B;&4N<W1Y;&4N=VED=&@@/2`B,3`P)2(["@EV
M87(@=&)O9'D@/2!D;V,N8W)E871E16QE;65N="@B=&)O9'DB*3L*"71A8FQE
M+F%P<&5N9$-H:6QD*'1B;V1Y*3L*"@EV87(@='(L('1D+"!I;G!U="P@<V5L
M96-T+"!O<'1I;VXL(&]P=&EO;G,L(&D["@H)='(@/2!D;V,N8W)E871E16QE
M;65N="@B='(B*3L*"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"71D(#T@9&]C
M+F-R96%T945L96UE;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET
M9"YC;&%S<TYA;64@/2`B;&%B96PB.PH)=&0N:6YN97)(5$U,(#T@:3$X;ELB
M0F%C:V=R;W5N9")=("L@(CHB.PH)=&0@/2!D;V,N8W)E871E16QE;65N="@B
M=&0B*3L*"71R+F%P<&5N9$-H:6QD*'1D*3L*"79A<B!D9B`](%1A8FQE3W!E
M<F%T:6]N<RYC<F5A=&5#;VQO<D)U='1O;BAD;V,L(&5D:71O<BP@96PN<W1Y
M;&4N8F%C:V=R;W5N9$-O;&]R+"`B8F%C:V=R;W5N9$-O;&]R(BD["@ED9BYF
M:7)S=$-H:6QD+FYE>'13:6)L:6YG+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N
M-65M(CL*"71D+F%P<&5N9$-H:6QD*&1F*3L*"71D+F%P<&5N9$-H:6QD*&1O
M8RYC<F5A=&5497AT3F]D92AI,3AN6R));6%G92!54DPB72`K("(Z("(I*3L*
M"6EN<'5T(#T@9&]C+F-R96%T945L96UE;G0H(FEN<'5T(BD["@EI;G!U="YT
M>7!E(#T@(G1E>'0B.PH):6YP=70N;F%M92`](")F7W-T7V)A8VMG<F]U;F1)
M;6%G92(["@EI9B`H96PN<W1Y;&4N8F%C:V=R;W5N9$EM86=E+FUA=&-H*"]U
M<FQ<*%QS*B@N*C\I7',J7"DO*2D@>PH)"6EN<'5T+G9A;'5E(#T@4F5G17AP
M+B0Q.PH)?0H)+R\@:6YP=70N<W1Y;&4N=VED=&@@/2`B,3`P)2(["@ET9"YA
M<'!E;F1#:&EL9"AI;G!U="D["@H)='(@/2!D;V,N8W)E871E16QE;65N="@B
M='(B*3L*"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"71D(#T@9&]C+F-R96%T
M945L96UE;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YC;&%S
M<TYA;64@/2`B;&%B96PB.PH)=&0N:6YN97)(5$U,(#T@:3$X;ELB1D<@0V]L
M;W(B72`K("(Z(CL*"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@ET
M<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YA<'!E;F1#:&EL9"A486)L94]P97)A
M=&EO;G,N8W)E871E0V]L;W)"=71T;VXH9&]C+"!E9&ET;W(L(&5L+G-T>6QE
M+F-O;&]R+"`B8V]L;W(B*2D["@H)+R\@9F]R(&)E='1E<B!A;&EG;FUE;G0@
M=V4@:6YC;'5D92!A;B!I;G9I<VEB;&4@9FEE;&0N"@EI;G!U="`](&1O8RYC
M<F5A=&5%;&5M96YT*")I;G!U="(I.PH):6YP=70N<W1Y;&4N=FES:6)I;&ET
M>2`](")H:61D96XB.PH):6YP=70N='EP92`](")T97AT(CL*"71D+F%P<&5N
M9$-H:6QD*&EN<'5T*3L*"@ET<B`](&1O8RYC<F5A=&5%;&5M96YT*")T<B(I
M.PH)=&)O9'DN87!P96YD0VAI;&0H='(I.PH)=&0@/2!D;V,N8W)E871E16QE
M;65N="@B=&0B*3L*"71R+F%P<&5N9$-H:6QD*'1D*3L*"71D+F-L87-S3F%M
M92`](")L86)E;"(["@ET9"YI;FYE<DA434P@/2!I,3AN6R)";W)D97(B72`K
M("(Z(CL*"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@ET<BYA<'!E
M;F1#:&EL9"AT9"D["@H)=F%R(&-O;&]R0G5T=&]N(#T@5&%B;&5/<&5R871I
M;VYS+F-R96%T94-O;&]R0G5T=&]N*&1O8RP@961I=&]R+"!E;"YS='EL92YB
M;W)D97)#;VQO<BP@(F)O<F1E<D-O;&]R(BD["@EV87(@8G1N(#T@8V]L;W)"
M=71T;VXN9FER<W1#:&EL9"YN97AT4VEB;&EN9SL*"71D+F%P<&5N9$-H:6QD
M*&-O;&]R0G5T=&]N*3L*"2\O(&)O<F1E<D9I96QD<RYP=7-H*&)T;BD["@EB
M=&XN<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH*"7-E;&5C="`](&1O
M8RYC<F5A=&5%;&5M96YT*")S96QE8W0B*3L*"79A<B!B;W)D97)&:65L9',@
M/2!;73L*"71D+F%P<&5N9$-H:6QD*'-E;&5C="D["@ES96QE8W0N;F%M92`]
M(")F7W-T7V)O<F1E<E-T>6QE(CL*"6]P=&EO;G,@/2!;(FYO;F4B+"`B9&]T
M=&5D(BP@(F1A<VAE9"(L(")S;VQI9"(L(")D;W5B;&4B+"`B9W)O;W9E(BP@
M(G)I9&=E(BP@(FEN<V5T(BP@(F]U='-E=")=.PH)=F%R(&-U<G)E;G1";W)D
M97)3='EL92`](&5L+G-T>6QE+F)O<F1E<E-T>6QE.PH)+R\@1V5C:V\@<F5P
M;W)T<R`B<V]L:60@<V]L:60@<V]L:60@<V]L:60B(&9O<B`B8F]R9&5R+7-T
M>6QE.B!S;VQI9"(N"@DO+R!4:&%T(&ES+"`B=&]P(')I9VAT(&)O='1O;2!L
M969T(B`M+2!W92!O;FQY(&-O;G-I9&5R('1H92!F:7)S=`H)+R\@=F%L=64N
M"@DH8W5R<F5N=$)O<F1E<E-T>6QE+FUA=&-H*"\H6UY<<UTJ*5QS+RDI("8F
M("AC=7)R96YT0F]R9&5R4W1Y;&4@/2!296=%>'`N)#$I.PH)9F]R("AV87(@
M:2!I;B!O<'1I;VYS*2!["@D)=F%R('9A;"`](&]P=&EO;G-;:5T["@D);W!T
M:6]N(#T@9&]C+F-R96%T945L96UE;G0H(F]P=&EO;B(I.PH)"6]P=&EO;BYV
M86QU92`]('9A;#L*"0EO<'1I;VXN:6YN97)(5$U,(#T@=F%L.PH)"2AV86P@
M/3T@8W5R<F5N=$)O<F1E<E-T>6QE*2`F)B`H;W!T:6]N+G-E;&5C=&5D(#T@
M=')U92D["@D)<V5L96-T+F%P<&5N9$-H:6QD*&]P=&EO;BD["@E]"@ES96QE
M8W0N<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH)9G5N8W1I;VX@<V5T
M0F]R9&5R1FEE;&1S4W1A='5S*'9A;'5E*2!["@D)9F]R("AV87(@:2`](#`[
M(&D@/"!B;W)D97)&:65L9',N;&5N9W1H.R`K*VDI('L*"0D)=F%R(&5L(#T@
M8F]R9&5R1FEE;&1S6VE=.PH)"0EE;"YS='EL92YV:7-I8FEL:71Y(#T@=F%L
M=64@/R`B:&ED9&5N(B`Z(")V:7-I8FQE(CL*"0D):68@*"%V86QU92`F)B`H
M96PN=&%G3F%M92YT;TQO=V5R0V%S92@I(#T](")I;G!U="(I*2!["@D)"0EE
M;"YF;V-U<R@I.PH)"0D)96PN<V5L96-T*"D["@D)"7T*"0E]"@E].PH)<V5L
M96-T+F]N8VAA;F=E(#T@9G5N8W1I;VXH*2![('-E=$)O<F1E<D9I96QD<U-T
M871U<RAT:&ES+G9A;'5E(#T](")N;VYE(BD[('T["@H):6YP=70@/2!D;V,N
M8W)E871E16QE;65N="@B:6YP=70B*3L*"6)O<F1E<D9I96QD<RYP=7-H*&EN
M<'5T*3L*"6EN<'5T+G1Y<&4@/2`B=&5X="(["@EI;G!U="YN86UE(#T@(F9?
M<W1?8F]R9&5R5VED=&@B.PH):6YP=70N=F%L=64@/2!486)L94]P97)A=&EO
M;G,N9V5T3&5N9W1H*&5L+G-T>6QE+F)O<F1E<E=I9'1H*3L*"6EN<'5T+G-I
M>F4@/2`B-2(["@ET9"YA<'!E;F1#:&EL9"AI;G!U="D["@EI;G!U="YS='EL
M92YM87)G:6Y2:6=H="`]("(P+C5E;2(["@EV87(@<W!A;B`](&1O8RYC<F5A
M=&5%;&5M96YT*")S<&%N(BD["@ES<&%N+FEN;F5R2%1-3"`](&DQ.&Y;(G!I
M>&5L<R)=.PH)=&0N87!P96YD0VAI;&0H<W!A;BD["@EB;W)D97)&:65L9',N
M<'5S:"AS<&%N*3L*"@ES971";W)D97)&:65L9'-3=&%T=7,H<V5L96-T+G9A
M;'5E(#T](")N;VYE(BD["@H):68@*&5L+G1A9TYA;64N=&],;W=E<D-A<V4H
M*2`]/2`B=&%B;&4B*2!["@D)+R\@=&AE(&)O<F1E<BUC;VQL87!S92!S='EL
M92!I<R!O;FQY(&9O<B!T86)L97,*"0ET<B`](&1O8RYC<F5A=&5%;&5M96YT
M*")T<B(I.PH)"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"0ET9"`](&1O8RYC
M<F5A=&5%;&5M96YT*")T9"(I.PH)"71D+F-L87-S3F%M92`](")L86)E;"([
M"@D)='(N87!P96YD0VAI;&0H=&0I.PH)"6EN<'5T(#T@9&]C+F-R96%T945L
M96UE;G0H(FEN<'5T(BD["@D):6YP=70N='EP92`](")C:&5C:V)O>"(["@D)
M:6YP=70N;F%M92`](")F7W-T7V)O<F1E<D-O;&QA<'-E(CL*"0EI;G!U="YI
M9"`](")F7W-T7V)O<F1E<D-O;&QA<'-E(CL*"0EV87(@=F%L(#T@*"]C;VQL
M87!S92]I+G1E<W0H96PN<W1Y;&4N8F]R9&5R0V]L;&%P<V4I*3L*"0EI;G!U
M="YC:&5C:V5D(#T@=F%L(#\@,2`Z(#`["@D)=&0N87!P96YD0VAI;&0H:6YP
M=70I.PH*"0ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"71R+F%P
M<&5N9$-H:6QD*'1D*3L*"0EV87(@;&%B96P@/2!D;V,N8W)E871E16QE;65N
M="@B;&%B96PB*3L*"0EL86)E;"YH=&UL1F]R(#T@(F9?<W1?8F]R9&5R0V]L
M;&%P<V4B.PH)"6QA8F5L+FEN;F5R2%1-3"`](&DQ.&Y;(D-O;&QA<'-E9"!B
M;W)D97)S(ET["@D)=&0N87!P96YD0VAI;&0H;&%B96PI.PH)?0H*+R\@"71R
M(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["B\O(`ET8F]D>2YA<'!E;F1#
M:&EL9"AT<BD["B\O(`ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PHO
M+R`)=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*+R\@"71R+F%P<&5N9$-H:6QD
M*'1D*3L*+R\@"71D+FEN;F5R2%1-3"`](&DQ.&Y;(DUA<F=I;B)=("L@(CHB
M.PHO+R`)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*+R\@"71R+F%P
M<&5N9$-H:6QD*'1D*3L*+R\@"6EN<'5T(#T@9&]C+F-R96%T945L96UE;G0H
M(FEN<'5T(BD["B\O(`EI;G!U="YT>7!E(#T@(G1E>'0B.PHO+R`):6YP=70N
M<VEZ92`]("(U(CL*+R\@"6EN<'5T+FYA;64@/2`B9E]S=%]M87)G:6XB.PHO
M+R`)=&0N87!P96YD0VAI;&0H:6YP=70I.PHO+R`):6YP=70N<W1Y;&4N;6%R
M9VEN4FEG:'0@/2`B,"XU96TB.PHO+R`)=&0N87!P96YD0VAI;&0H9&]C+F-R
M96%T951E>'1.;V1E*&DQ.&Y;(E!A9&1I;F<B72`K("(Z(BDI.PH*+R\@"6EN
M<'5T(#T@9&]C+F-R96%T945L96UE;G0H(FEN<'5T(BD["B\O(`EI;G!U="YT
M>7!E(#T@(G1E>'0B.PHO+R`):6YP=70N<VEZ92`]("(U(CL*+R\@"6EN<'5T
M+FYA;64@/2`B9E]S=%]P861D:6YG(CL*+R\@"71D+F%P<&5N9$-H:6QD*&EN
M<'5T*3L*+R\@"6EN<'5T+G-T>6QE+FUA<F=I;DQE9G0@/2`B,"XU96TB.PHO
M+R`):6YP=70N<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PHO+R`)=&0N
M87!P96YD0VAI;&0H9&]C+F-R96%T951E>'1.;V1E*&DQ.&Y;(G!I>&5L<R)=
M*2D["@H)<F5T=7)N(&9I96QD<V5T.PI].PH*+R\O+R!%3D0@1T5.15))0R!#
M3T1%("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',O````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,#<`,#(R-C4Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!O<'5P<R]A8F]U="YH=&UL````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,#$P-0`Q,#0Q
M-S,V,S`P-P`P,C0V-#4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/"$M+0H**&,I(&1Y;F%R8V@N8V]M+"`R,#`S+3(P,#4*
M075T:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO
M;PI$:7-T<FEB=71E9"!A<R!P87)T(&]F($A434Q!<F5A(#,N,`H*(EEO=2!A
M<F4@;F]T(&5X<&5C=&5D('1O('5N9&5R<W1A;F0@=&AI<RXN+B`@22!D;VXG
M="!N96ET:&5R+B(*"B`@("`@("`@("`@("`@("`@("`@("`H9G)O;2!4:&4@
M3&EN=7@@2V5R;F5L(%-O=7)C92!#;V1E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B]A<F-H+W@X-E\V-"]I83,R+W!T<F%C92YC.CDP*0H*.RTI
M"@HM+3X*"CQH=&UL('-T>6QE/2)H96EG:'0Z(#$P,"4B/@H\:&5A9#X*/&UE
M=&$@:'1T<"UE<75I=CTB0V]N=&5N="U4>7!E(B!C;VYT96YT/2)T97AT+VAT
M;6P[(&-H87)S970]=71F+3@B("\^"CQT:71L93Y!8F]U="!(5$U,07)E83PO
M=&ET;&4^"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](G!O
M<'5P+FIS(CX\+W-C<FEP=#X*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I
M<'0B/@IW:6YD;W<N<F5S:7IE5&\H-#4P+"`R-3`I.PIV87(@5$%"4R`](%M=
M.PIV87(@0U524D5.5%]404(@/2`P.PIV87(@0T].5$5.5%](14E'2%1?1$E&
M1B`](#`["G9A<B!#3TY414Y47U=)1%1(7T1)1D8@/2`P.PIF=6YC=&EO;B!S
M96QE8W1486(H:61X*2!["B`@=F%R(&-T(#T@5$%"4UM#55)214Y47U1!0ET[
M"B`@8W0N8VQA<W-.86UE(#T@8W0N8VQA<W-.86UE+G)E<&QA8V4H+UQS*G1A
M8BUC=7)R96YT7',J+RP@)R`G*3L*("!C="`](%1!0E-;0U524D5.5%]404(@
M/2!I9'A=.PH@(&-T+F-L87-S3F%M92`K/2`G('1A8BUC=7)R96YT)SL*("!F
M;W(@*'9A<B!I(#T@5$%"4RYL96YG=&@[("TM:2`^/2`P.RD@>PH@("`@=F%R
M(&%R96$@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B=&%B+6%R96$M(B`K
M(&DI.PH@("`@:68@*$-54E)%3E1?5$%"(#T](&DI('L*("`@("`@87)E82YS
M='EL92YD:7-P;&%Y(#T@(F)L;V-K(CL*("`@('T@96QS92!["B`@("`@(&%R
M96$N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*("`@('T*("!]"B`@9&]C=6UE
M;G0N8F]D>2YS='EL92YV:7-I8FEL:71Y(#T@(FAI9&1E;B(["B`@9&]C=6UE
M;G0N8F]D>2YS='EL92YV:7-I8FEL:71Y(#T@(G9I<VEB;&4B.PH@(&1O8W5M
M96YT+F-O;VMI92`](")(5$U,05)%02U!0D]55"U404(](B`K(&ED>#L*?0IV
M87(@961I=&]R(#T@;G5L;#L*9G5N8W1I;VX@:6YI=$1O8W5M96YT*"D@>PH@
M(&5D:71O<B`]('=I;F1O=RYD:6%L;V=!<F=U;65N=',["B`@2%1-3$%R96$@
M/2!W:6YD;W<N;W!E;F5R+DA434Q!<F5A.PH*("!V87(@<&QU9VEN<R`](&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*")P;'5G:6YS(BD["B`@=F%R(&H@/2`P
M.PH@('9A<B!H=&UL(#T@(CQT86)L92!W:61T:#TG.3DE)R!C96QL<&%D9&EN
M9STG,"<@<W1Y;&4])VUA<F=I;BUT;W`Z(#%E;3L@8V]L;&%P<V4M8F]R9&5R
M<SH@8V]L;&%P<V4[(&)O<F1E<CH@,7!X('-O;&ED(",X8C@[)SXB("L*"2`@
M(CQT:&5A9#X\='(^(B`K"@D@("(\=&0^3F%M93PO=&0^(B`K"@D@("(\=&0^
M1&5V96QO<&5R/"]T9#XB("L*"2`@(CQT9#Y3<&]N<V]R960@8GD\+W1D/B(@
M*PH)("`B/'1D/DQI8V5N<V4\<W5P/BH\+W-U<#X\+W1D/B(@*PH)("`B/"]T
M<CX\+W1H96%D/CQT8F]D>3XB.PH@(&9O<B`H=F%R(&D@:6X@961I=&]R+G!L
M=6=I;G,I('L*("`@('9A<B!I;F9O(#T@961I=&]R+G!L=6=I;G-;:5T["B`@
M("!H=&UL("L]("(\='(^/'1D/B(@*R!I;F9O+FYA;64@*R`B('8B("L@:6YF
M;RYV97)S:6]N("L@(CPO=&0^(B`K"B`@("`@("`@("`@("(\=&0^/&$@:')E
M9CTG(B`K(&EN9F\N9&5V96QO<&5R7W5R;"`K("(G('1A<F=E=#TG7V)L86YK
M)R!T:71L93TG5FES:70@9&5V96QO<&5R('=E8G-I=&4G/B(@*PH)("`@(&EN
M9F\N9&5V96QO<&5R("L@(CPO83X\+W1D/B(@*PH)("`@("(\=&0^/&$@:')E
M9CTG(B`K(&EN9F\N<W!O;G-O<E]U<FP@*R`B)R!T87)G970])U]B;&%N:R<@
M=&ET;&4])U9I<VET('-P;VYS;W(@=V5B<VET92<^(B`K"@D@("`@:6YF;RYS
M<&]N<V]R("L@(CPO83X\+W1D/B(@*PH)("`@("(\=&0^(B`K(&EN9F\N;&EC
M96YS92`K("(\+W1D/CPO='(^(CL*("`@("LK:CL*("!]"@H@(&EF("AJ*2![
M"B`@("`@("`@("!H=&UL("L]("(\+W1B;V1Y/CPO=&%B;&4^(B`K"@D)("`B
M/'`^/'-U<#XJ/"]S=7`^($QI8V5N<V4@7")H=&UL07)E85PB(&UE86YS('1H
M870@=&AE('!L=6=I;B!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!T
M97)M<R`B("L*"0D@(")A<R!(5$U,07)E82!I='-E;&8N("!3=6-H('!L=6=I
M;G,@87)E(&QI:V5L>2!T;R!B92!T:&]S92!I;F-L=61E9"!I;B!T:&4@;V9F
M:6-I86P@(B`K"@D)("`B2%1-3$%R96$@9&ES=')I8G5T:6]N/"]P/B(["@D@
M('!L=6=I;G,N:6YN97)(5$U,(#T@(CQP/E1H92!F;VQL;W=I;F<@<&QU9VEN
M<R!H879E(&)E96X@;&]A9&5D+CPO<#XB("L@:'1M;#L*("!](&5L<V4@>PH)
M("!P;'5G:6YS+FEN;F5R2%1-3"`]("(\<#Y.;R!P;'5G:6YS(&AA=F4@8F5E
M;B!L;V%D960\+W`^(CL*("!]"@H@('!L=6=I;G,N:6YN97)(5$U,("L]("(\
M<#Y5<V5R(&%G96YT(')E<&]R=',Z/&)R+SXB("L@;F%V:6=A=&]R+G5S97)!
M9V5N="`K("(\+W`^(CL*"B`@=F%R(&-O;G1E;G0@/2!D;V-U;65N="YG971%
M;&5M96YT0GE)9"@B8V]N=&5N="(I.PH@(&EF("AW:6YD;W<N:6YN97)(96EG
M:'0I('L*("`@($-/3E1%3E1?2$5)1TA47T1)1D8@/2!W:6YD;W<N:6YN97)(
M96EG:'0@+2`R-3`["B`@("!#3TY414Y47U=)1%1(7T1)1D8@/2!W:6YD;W<N
M:6YN97)7:61T:"`M(&-O;G1E;G0N;V9F<V5T5VED=&@["B`@?2!E;'-E('L*
M("`@($-/3E1%3E1?2$5)1TA47T1)1D8@/2!D;V-U;65N="YB;V1Y+F]F9G-E
M=$AE:6=H="`M(#(U,#L*("`@($-/3E1%3E1?5TE$5$A?1$E&1B`](&1O8W5M
M96YT+F)O9'DN;V9F<V5T5VED=&@@+2`T,#`["B`@?0H@('=I;F1O=RYO;G)E
M<VEZ92@I.PH@('9A<B!B87(@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B
M=&%B8F%R(BD["B`@:B`](#`["B`@9F]R("AV87(@:2`](&)A<BYF:7)S=$-H
M:6QD.R!I.R!I(#T@:2YN97AT4VEB;&EN9RD@>PH@("`@5$%"4RYP=7-H*&DI
M.PH@("`@:2Y?7VUS:%]T86(@/2!J.PH@("`@:2YO;FUO=7-E9&]W;B`](&9U
M;F-T:6]N*&5V*2![('-E;&5C=%1A8BAT:&ES+E]?;7-H7W1A8BD[($A434Q!
M<F5A+E]S=&]P179E;G0H978@?'P@=VEN9&]W+F5V96YT*3L@?3L*("`@('9A
M<B!A<F5A(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(G1A8BUA<F5A+2(@
M*R!J*3L*("`@(&EF("@O=&%B+6-U<G)E;G0O+G1E<W0H:2YC;&%S<TYA;64I
M*2!["B`@("`@($-54E)%3E1?5$%"(#T@:CL*("`@("`@87)E82YS='EL92YD
M:7-P;&%Y(#T@(F)L;V-K(CL*("`@('T@96QS92!["B`@("`@(&%R96$N<W1Y
M;&4N9&ES<&QA>2`](")N;VYE(CL*("`@('T*("`@("LK:CL*("!]"B`@:68@
M*&1O8W5M96YT+F-O;VMI92YM871C:"@O2%1-3$%214$M04)/550M5$%"/2A;
M,"TY72LI+RDI"B`@("!S96QE8W1486(H4F5G17AP+B0Q*3L*?0IW:6YD;W<N
M;VYR97-I>F4@/2!F=6YC=&EO;B@I('L*("!V87(@8V]N=&5N="`](&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*")C;VYT96YT(BD["B`@:68@*'=I;F1O=RYI
M;FYE<DAE:6=H="D@>PH@("`@8V]N=&5N="YS='EL92YH96EG:'0@/2`H=VEN
M9&]W+FEN;F5R2&5I9VAT("T@0T].5$5.5%](14E'2%1?1$E&1BD@*R`B<'@B
M.PH@("`@8V]N=&5N="YS='EL92YW:61T:"`]("AW:6YD;W<N:6YN97)7:61T
M:"`M($-/3E1%3E1?5TE$5$A?1$E&1BD@*R`B<'@B.PH@('T@96QS92!["B`@
M("!C;VYT96YT+G-T>6QE+FAE:6=H="`]("AD;V-U;65N="YB;V1Y+F]F9G-E
M=$AE:6=H="`M($-/3E1%3E1?2$5)1TA47T1)1D8I("L@(G!X(CL*("`@("\O
M8V]N=&5N="YS='EL92YW:61T:"`]("AD;V-U;65N="YB;V1Y+F]F9G-E=%=I
M9'1H("T@0T].5$5.5%]724142%]$249&*2`K(")P>"(["B`@?0I]"CPO<V-R
M:7!T/@H\<W1Y;&4^"B`@:'1M;"QB;V1Y+'1E>'1A<F5A+'1A8FQE('L@9F]N
M="UF86UI;'DZ('1A:&]M82QV97)D86YA+&%R:6%L.R!F;VYT+7-I>F4Z(#$Q
M<'@["G!A9&1I;F<Z(#!P>#L@;6%R9VEN.B`P<'@[('T*("!T="![(&9O;G0M
M<VEZ93H@,3(P)3L@?0H@(&)O9'D@>R!P861D:6YG.B`P<'@[(&)A8VMG<F]U
M;F0Z("-C96$[(&-O;&]R.B`P,#`[('T*("!A.FQI;FLL(&$Z=FES:71E9"![
M(&-O;&]R.B`C,#!F.R!]"B`@83IH;W9E<B![(&-O;&]R.B`C9C`P.R!]"B`@
M83IA8W1I=F4@>R!C;VQO<CH@(V8X,#L@?0H@(&)U='1O;B![(&9O;G0Z(#$Q
M<'@@=&%H;VUA+'9E<F1A;F$L<V%N<RUS97)I9CL@8F%C:V=R;W5N9"UC;VQO
M<CH@(V-E83L*("`@("`@8F]R9&5R+7=I9'1H.B`Q<'@[('T*"B`@<"![(&UA
M<F=I;CH@,"XU96T@,'!X.R!]"@H@(&@Q('L@9F]N=#H@8F]L9"`Q,S`E(&=E
M;W)G:6$L(G1I;65S(&YE=R!R;VUA;B(L<V5R:68[(&UA<F=I;CH@,'!X.R!B
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S9A-CL@?0H@(&@R('L@9F]N=#H@
M8F]L9"`Q,3`E(&=E;W)G:6$L(G1I;65S(&YE=R!R;VUA;B(L<V5R:68[(&UA
M<F=I;CH@,"XW96T@,'!X.R!]"@H@('1H96%D('L*("`@(&9O;G0M=V5I9VAT
M.B!B;VQD.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V1F8CL*("!]"@H@("YL
M;V=O+"`N;&]G;RUH;W9E<B!["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(SAF-#L@8V]L;W(Z(",P-#`[('!A9&1I
M;F<Z(#-P>#L@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U-34["B`@("!H
M96EG:'0Z(#5E;3L*("!]"B`@+FQO9V\@+F)R86YD+"`N;&]G;RUH;W9E<B`N
M8G)A;F0@>PH@("`@;6%R9VEN+6QE9G0Z(#`N-65M.R!M87)G:6XM<FEG:'0Z
M(#`N-65M.R!P861D:6YG+6)O='1O;3H@,"XQ96T["B`@("!F;VYT+69A;6EL
M>3H@:6UP86-T+"=A<FEA;"!B;&%C:R<L87)I86PL<V%N<RUS97)I9CL@9F]N
M="US:7IE.B`R.'!X.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U
M.34[('1E>'0M86QI9VXZ(&-E;G1E<CL*("`@(&-U<G-O<CH@<&]I;G1E<CL*
M("!]"B`@+FQO9V\M:&]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F
M9CL*("!]"B`@+FQO9V\M:&]V97(@+F)R86YD('L*("`@(&-O;&]R.B`C.#`P
M.PH@("`@8F]R9&5R+6-O;&]R.B`C,#1F.PH@('T*("`N;&]G;R`N;&5T=&5R
M+"`N;&]G;RUH;W9E<B`N;&5T=&5R('L@<&]S:71I;VXZ(')E;&%T:79E.R!F
M;VYT+69A;6EL>3H@;6]N;W-P86-E.R!]"B`@+FQO9V\@+FQE='1E<C$@>R!T
M;W`Z(#`N,65M.R!]"B`@+FQO9V\@+FQE='1E<C(@>R!T;W`Z(#`N,#5E;3L@
M?0H@("YL;V=O("YL971T97(S('L@=&]P.B`M,"XP-65M.R!]"B`@+FQO9V\@
M+FQE='1E<C0@>R!T;W`Z("TP+C%E;3L@?0H*("`N;&]G;RUH;W9E<B`N;&5T
M=&5R,2![('1O<#H@+3`N,65M.R!]"B`@+FQO9V\M:&]V97(@+FQE='1E<C(@
M>R!T;W`Z("TP+C`U96T[('T*("`N;&]G;RUH;W9E<B`N;&5T=&5R,R![('1O
M<#H@,"XP-65M.R!]"B`@+FQO9V\M:&]V97(@+FQE='1E<C0@>R!T;W`Z(#`N
M,65M.R!]"B`@+FQO9V\@+G9E<G-I;VXL("YL;V=O+6AO=F5R("YV97)S:6]N
M('L@9F]N="UF86UI;'DZ(&=E;W)G:6$L(G1I;65S(&YE=R!R;VUA;B(L<V5R
M:68[('T*("`N;&]G;R`N<F5L96%S92!["B`@("!F;VYT+7-I>F4Z(#DP)3L@
M;6%R9VEN+6)O='1O;3H@,65M.PH@("`@=&5X="UA;&EG;CH@8V5N=&5R.R!C
M;VQO<CH@(S0X-#L*("!]"B`@+FQO9V\@+G9I<VET('L@9&ES<&QA>3H@;F]N
M93L@?0H@("YL;V=O+6AO=F5R("YR96QE87-E('L@9&ES<&QA>3H@;F]N93L@
M?0H@("YL;V=O+6AO=F5R("YV:7-I="!["B`@("!F;VYT+7-I>F4Z(#DP)3L@
M;6%R9VEN+6)O='1O;3H@,65M.PH@("`@=&5X="UA;&EG;CH@8V5N=&5R.R!C
M;VQO<CH@(S0T.#L*("!]"B`@+F)U='1O;G,@>PH@("`@=&5X="UA;&EG;CH@
M<FEG:'0[('!A9&1I;F<Z(#-P>#L@8F%C:V=R;W5N9"UC;VQO<CH@(SAF-#L*
M("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C-34U.PH@('T*("`C=&%B8F%R
M('L*("`@('!O<VET:6]N.B!R96QA=&EV93L*("`@(&QE9G0Z(#$P<'@["B`@
M?0H@("YT86(@>PH@("`@8V]L;W(Z(",T-30["B`@("!C=7)S;W(Z('!O:6YT
M97(["B`@("!M87)G:6XM;&5F=#H@+35P>#L*("`@(&9L;V%T.B!L969T.R!P
M;W-I=&EO;CH@<F5L871I=F4["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-34U
M.PH@("`@=&]P.B`M,W!X.R!L969T.B`M,G!X.PH@("`@<&%D9&EN9SH@,G!X
M(#$P<'@@,W!X(#$P<'@["B`@("!B;W)D97(M=&]P.B!N;VYE.R!B86-K9W)O
M=6YD+6-O;&]R.B`C.6(W.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`P<'@@
M,'!X(#1P>"`T<'@["B`@("!Z+6EN9&5X.B`P.PH@('T*("`N=&%B+6-U<G)E
M;G0@>PH@("`@8V]L;W(Z(",P,#`["B`@("!T;W`Z("TT<'@["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C8V5A.PH@("`@<&%D9&EN9SH@,W!X(#$P<'@@-'!X
M(#$P<'@["B`@("!Z+6EN9&5X.B`Q,#L*("!]"B`@=&%B;&4N<W!O;G-O<G,@
M>R!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(V%C83L@?0H@('1A8FQE+G-P;VYS
M;W)S('1D('L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C86-A.R!V
M97)T:6-A;"UA;&EG;CH@=&]P.PH@('T*("!T86)L92YS<&]N<V]R<R!T<B!T
M9"![('!A9&1I;F<Z(#)P>"`P<'@[('T*("!T86)L92YS<&]N<V]R<R!T<B!T
M9"YS<&]N<V]R('L@=&5X="UA;&EG;CH@<FEG:'0[('!A9&1I;F<M<FEG:'0Z
M(#`N,V5M.R!W:&ET92US<&%C93H@;F]W<F%P.R!]"B`@;&DL(&]L+"!U;"![
M(&UA<F=I;BUT;W`Z(#!P>#L@;6%R9VEN+6)O='1O;3H@,'!X.R!]"CPO<W1Y
M;&4^/"]H96%D/@H\8F]D>2!O;FQO860](E]?9&QG7VEN:70H*3L@:6YI=$1O
M8W5M96YT*"D[(@H^/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!C96QL<&%D9&EN
M9STB,"(@<W1Y;&4](F)O<F1E<BUC;VQL87!S93H@8V]L;&%P<V4["B`@("`@
M('=I9'1H.B`Q,#`E.R!H96EG:'0Z(#$P,"4[(CX*"CQT<B!S='EL93TB:&5I
M9VAT.B`Q96TB/CQT9"!I9#TB=&1H96%D97(B/@H*/&1I=B!C;&%S<STB;&]G
M;R(^"CQD:78@8VQA<W,](F)R86YD(@IO;FUO=7-E;W9E<CTB=&AI<RYP87)E
M;G1.;V1E+F-L87-S3F%M93TG;&]G;RUH;W9E<B<[(@IO;FUO=7-E;W5T/2)T
M:&ES+G!A<F5N=$YO9&4N8VQA<W-.86UE/2=L;V=O)SLB"F]N8VQI8VL](G=I
M;F1O=RYO<&5N*"=H='1P.B\O=W=W+FAT;6QA<F5A+F-O;2\G*3LB/@H\<W!A
M;B!C;&%S<STB;&5T=&5R(&QE='1E<C$B/B9L=#M(/"]S<&%N/CQS<&%N"F-L
M87-S/2)L971T97(@;&5T=&5R,B(^5#PO<W!A;CX\<W!A;@IC;&%S<STB;&5T
M=&5R(&QE='1E<C,B/DT\+W-P86X^/'-P86X*8VQA<W,](FQE='1E<B!L971T
M97(T(CY,/"]S<&%N/D%R96$@/'-P86X@8VQA<W,](FQE='1E<B(^+R9G=#L\
M+W-P86X^"CQS<&%N(&-L87-S/2)V97)S:6]N(CXS+C`@/'-P86X@<W1Y;&4]
M(G!O<VET:6]N.B!R96QA=&EV93L@=&]P.B`M,"XV96T[(&9O;G0M<VEZ93H@
M-3`E.R!F;VYT+7=E:6=H=#H@;F]R;6%L(CY;(')E=BX@8F5T82L@73PO<W!A
M;CX\+W-P86X^/"]D:78^"CQD:78@8VQA<W,](G)E;&5A<V4B/D-O;7!I;&5D
M(&]N($UA>2`Q-RP@,C`P-2`P,3HP."!'350\+V1I=CX*/&1I=B!C;&%S<STB
M=FES:70B/D=O('1O(&AT='`Z+R]W=W<N:'1M;&%R96$N8V]M+R!;;&%T97-T
M(&UI;&5S=&]N92!R96QE87-E73PO9&EV/@H\+V1I=CX*"CPO=&0^/"]T<CX*
M/'1R/CQT9"!I9#TB=&1C;VYT96YT(B!S='EL93TB<&%D9&EN9SH@,"XU96T[
M(CX*"CQD:78@<W1Y;&4](F]V97)F;&]W.B!A=71O.R!H96EG:'0Z(#(U,'!X
M.R(@:60](F-O;G1E;G0B/@H\9&EV(&ED/2)T86(M87)E87,B/@H*/&1I=B!I
M9#TB=&%B+6%R96$M,"(^"@H@(#QH,3Y(5$U,07)E83PO:#$^"@H@(#QP/D$@
M9G)E92!765-)5UE'(&5D:71O<B!R97!L86-E;65N="!F;W(@/'1T/B9L=#MT
M97AT87)E829G=#L\+W1T/B!F:65L9',N/&)R("\^"B`@1F]R($UO>FEL;&$@
M,2XS*R`H86YY('!L871F;W)M*2!O<B!);G1E<FYE="!%>'!L;W)E<B`U+C4K
M("A7:6YD;W=S*2X*("`\+W`^"@H@(#QP('-T>6QE/2)T97AT+6%L:6=N.B!C
M96YT97(B"B`@/L*I(#(P,#(M,C`P-"`\82!H<F5F/2)H='1P.B\O:6YT97)A
M8W1I=F5T;V]L<RYC;VTB('1A<F=E=#TB7V)L86YK(CYI;G1E<F%C=&EV971O
M;VQS+F-O;3PO83XL(&EN8RX\8G(@+SX*("#"J2`R,#`S+3(P,#4@/&$@:')E
M9CTB:'1T<#HO+V1Y;F%R8V@N8V]M(B!T87)G970](E]B;&%N:R(^9'EN87)C
M:"YC;VT\+V$^($Q,0RX\8G(@+SX*("!!;&P@4FEG:'1S(%)E<V5R=F5D+CPO
M<#X*"B`@/&@R/E!R;VIE8W0@<F5S;W5R8V5S/"]H,CX*"B`@/'5L/@H@(#QL
M:3X\82!H<F5F/2)H='1P.B\O<V]U<F-E9F]R9V4N;F5T+W!R;VIE8W1S+VET
M;V]L<RUH=&UL87)E82\B('1A<F=E=#TB7V)L86YK(@H@(#Y0<F]J96-T('!A
M9V4\+V$^("A`('-O=7)C969O<F=E+FYE="D\+VQI/@H@(#QL:3X\82!H<F5F
M/2)H='1P.B\O<V]U<F-E9F]R9V4N;F5T+V-V<R\_9W)O=7!?:60]-CDW-3`B
M('1A<F=E=#TB7V)L86YK(@H@(#Y!;F]N>6UO=7,@0U93(&%C8V5S<SPO83X@
M*$`@<V]U<F-E9F]R9V4N;F5T*3PO;&D^"B`@/&QI/CQA(&AR968](FAT='`Z
M+R]S;W5R8V5F;W)G92YN970O=')A8VME<B\_871I9#TU,C4V-38F9W)O=7!?
M:60]-CDW-3`F9G5N8SUB<F]W<V4B('1A<F=E=#TB7V)L86YK(@H@(#Y"=6<@
M<WES=&5M/"]A/B`H0"!S;W5R8V5F;W)G92YN970I/"]L:3X*("`\;&D^/&$@
M:')E9CTB:'1T<#HO+W=W=RYH=&UL87)E82YC;VTO9F]R=6TO(B!T87)G970]
M(E]B;&%N:R(*("`^1F]R=6T\+V$^("A`(&EN=&5R86-T:79E=&]O;',N8V]M
M*3PO;&D^"B`@/&QI/CQA(&AR968](FAT='`Z+R]W=W<N:'1M;&%R96$N8V]M
M+R(@=&%R9V5T/2)?8FQA;FLB"B`@/DQA<W0@<'5B;&EC(')E;&5A<V4\+V$^
M/"]L:3X*("`\+W5L/@H*("`\<#X*("!&;W(@9&]W;FQO860@<V5C=&EO;B!P
M;&5A<V4@<V5E('1H92`\82!H<F5F/2)H='1P.B\O<V]U<F-E9F]R9V4N;F5T
M+W!R;VIE8W1S+VET;V]L<RUH=&UL87)E82\B('1A<F=E=#TB7V)L86YK(@H@
M(#YP<F]J96-T('!A9V4@0"!3;W5R8V5&;W)G93PO83XN"B`@/"]P/@H*/"]D
M:78^"@H\9&EV(&ED/2)T86(M87)E82TQ(CX*/&@Q/E1H86YK('EO=3PO:#$^
M"@H@(#QP/@H@(#QA(&AR968](FAT='`Z+R]D>6YA<F-H+F-O;2(@=&%R9V5T
M/2)?8FQA;FLB/F1Y;F%R8V@N8V]M/"]A/B!W;W5L9"!L:6ME('1O('1H86YK
M('1H92!F;VQL;W=I;F<*("!C;VUP86YI97,O<&5R<V]N<R!F;W(@=&AE:7(@
M/&5M/F1O;F%T:6]N<SPO96T^('1O('-U<'!O<G0@9&5V96QO<&UE;G0@;V8@
M2%1-3$%R96$@*&QI<W1E9"!A;'!H86)E=&EC86QL>2DZ"B`@/"]P/@H*("`\
M=6P^"B`@("`\;&D^/&$@:')E9CTB:'1T<#HO+W=W=RYC;VUP=71E<FQO=F4N
M8V\N=6LB('1A<F=E=#TB7V)L86YK(CY#;V1E($-O;7!U=&5R($QO=F4@3'1D
M+CPO83X@*%5+*3PO;&D^"B`@("`\;&D^/&$@:')E9CTB:'1T<#HO+W=W=RYN
M96]M961I82YR;R(@=&%R9V5T/2)?8FQA;FLB/DYE;VUE9&EA/"]A/B`H4F]M
M86YI82D\+VQI/@H@("`@/&QI/CQA(&AR968](FAT='`Z+R]W=W<N;W,S+FET
M(B!T87)G970](E]B;&%N:R(^3U,S/"]A/B`H271A;'DI/"]L:3X*("`@(#QL
M:3X\82!H<F5F/2)H='1P.B\O=W=W+G-O9G1W97)K+FYE="(@=&%R9V5T/2)?
M8FQA;FLB/E-O9G1797)K/"]A/B`H271A;'DI/"]L:3X*("`\+W5L/@H*("`\
M<#Y!;'-O(&UA;GD@=&AA;FMS('1O(&%L;"!P96]P;&4@870@26YT97)A8W1I
M=F54;V]L<RYC;VT*("`\82!H<F5F/2)H='1P.B\O=W=W+FAT;6QA<F5A+F-O
M;2]F;W)U;2\B/DA434Q!<F5A(&9O<G5M<SPO83X@9F]R"B`@8V]N=')I8G5T
M:6YG('1R86YS;&%T:6]N<RP@9F5E9&)A8VLL(&)U9R!R97!O<G1S(&%N9"!F
M:7AE<RX\+W`^"@H@(#QP/@H@($QA<W0@8G5T(&YO="!L96%S="P@=&AI<R!P
M<F]J96-T('=O=6QD;B=T(&AA=F4@97AI<W1E9"!W:71H;W5T"B`@/&$@:')E
M9CTB:'1T<#HO+VEN=&5R86-T:79E=&]O;',N8V]M(B!T87)G970](E]B;&%N
M:R(^26YT97)A8W1I=F54;V]L<RYC;VT\+V$^+@H@(#PO<#X*"CPO9&EV/@H*
M/&1I=B!I9#TB=&%B+6%R96$M,B(^"CQH,3YH=&UL07)E82!,:6-E;G-E("AB
M87-E9"!O;B!"4T0@;&EC96YS92D\+V@Q/@H*/'`@<W1Y;&4](G1E>'0M86QI
M9VXZ(&-E;G1E<B(^PJD@,C`P,BTR,#`T+"!I;G1E<F%C=&EV971O;VQS+F-O
M;2P@:6YC+CQB<B`O/@H@(,*I(#(P,#,M,C`P-"!D>6YA<F-H+F-O;2!,3$,\
M8G(@+SX*("!!;&P@<FEG:'1S(')E<V5R=F5D+CPO<#X*"CQP/@I2961I<W1R
M:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W
M:71H(&]R('=I=&AO=70*;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R
M;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS(&%R92!M970Z
M"CPO<#X*"CQO;#X*/&QI/@I2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O
M9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"G1H
M:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L
M86EM97(N"CPO;&D^"@H\;&D^"E)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@
M9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC
M92P*=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@
M9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@IA;F0O;W(@;W1H97(@
M;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*/"]L
M:3X*"CQL:3X*3F5I=&AE<B!T:&4@;F%M92!O9B!I;G1E<F%C=&EV971O;VQS
M+F-O;2P@:6YC+B!N;W(@=&AE(&YA;65S(&]F(&ET<PIC;VYT<FEB=71O<G,@
M;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E
M<FEV960@9G)O;2!T:&ES"G-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I
M;W(@=W)I='1E;B!P97)M:7-S:6]N+@H\+VQI/@H\+V]L/@H*/'`^"E1(25,@
M4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3
M($%.1"!#3TY44DE"551/4E,@(D%3($E3(@I!3D0@04Y9($584%)%4U,@3U(@
M24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%
M1"!43RP@5$A%"DE-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)
M5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%"D%212!$
M25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4($]7
M3D52($]2($-/3E1224)55$]24R!"10I,24%"3$4@1D]2($%.62!$25)%0U0L
M($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2
M"D-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)
M34E4140@5$\L(%!23T-54D5-14Y4($]&"E-50E-425155$4@1T]/1%,@3U(@
M4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"
M55-)3D534PI)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!
M3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3@I#3TY44D%#5"P@
M4U1224-4($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.
M0T4@3U(@3U1(15)725-%*0I!4DE324Y'($E.($%.62!705D@3U54($]&(%1(
M12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(
M10I03U-324))3$E462!/1B!354-(($1!34%'12X*/"]P/@H*/"]D:78^"@H\
M9&EV(&ED/2)T86(M87)E82TS(CX*/&@Q/E!L=6=I;G,\+V@Q/@H\9&EV(&ED
M/2)P;'5G:6YS(CX*/"]D:78^"CPO9&EV/@H*/"]D:78^/"]D:78^"@H*/"]T
M<CX\+W1D/@H\='(@<W1Y;&4](FAE:6=H=#H@,65M(CX\=&0@:60](G1D9F]O
M=&5R(CX*"@H\9&EV(&-L87-S/2)B=71T;VYS(CX*/&1I=B!I9#TB=&%B8F%R
M(@H^/&1I=B!C;&%S<STB=&%B('1A8BUC=7)R96YT(@H^06)O=70\+V1I=CX\
M9&EV(&-L87-S/2)T86(B"CY4:&%N:W,\+V1I=CX\9&EV(&-L87-S/2)T86(B
M"CY,:6-E;G-E/"]D:78^/&1I=B!C;&%S<STB=&%B(@H^4&QU9VEN<SPO9&EV
M/CPO9&EV/@H\8G5T=&]N('1Y<&4](F)U='1O;B(@;VYC;&EC:STB7U]D;&=?
M8VQO<V4H;G5L;"D[(CY)(&%G<F5E(&ET)W,@8V]O;#PO8G5T=&]N/@H\+V1I
M=CX*"CPO=&0^/"]T<CX\+W1A8FQE/@H*/"]B;V1Y/CPO:'1M;#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',O
M8FQA;FLN:'1M;```````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,3<`,3`T,3<S-C,P,#<`
M,#(T-C(Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QH=&UL/@T*/"]H=&UL/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+V9U;&QS8W)E96XN
M:'1M;````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$R-S8P`#$P-#$W,S8S,#`W`#`R-3<P-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\(41/0U19
M4$4@:'1M;"!054),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,2\O14XB(")H
M='1P.B\O=W=W+G<S+F]R9R]44B]X:'1M;#$Q+T141"]X:'1M;#$Q+F1T9"(^
M"CQH=&UL/@H@(#QH96%D/@H@("`@/'1I=&QE/D9U;&QS8W)E96X@2%1-3$%R
M96$\+W1I=&QE/@H@("`@/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B
M/@H@("`@("!?961I=&]R7W5R;"`]('=I;F1O=RYO<&5N97(N7V5D:71O<E]U
M<FP@?'P@)RXN+R<["B`@("`@(%]E9&ET;W)?;&%N9R`]('=I;F1O=RYO<&5N
M97(N7V5D:71O<E]L86YG.PH@("`@("!?961I=&]R7V-S<R`]('=I;F1O=RYO
M<&5N97(N7V5D:71O<E]C<W,["B`@("`@('9A<B!"05-%(#T@=VEN9&]W+F]P
M96YE<BYD;V-U;65N="YB87-E55))('Q\('=I;F1O=RYO<&5N97(N9&]C=6UE
M;G0N55),.PH@("`@("!V87(@:&5A9"`](&1O8W5M96YT+F=E=$5L96UE;G1S
M0GE486=.86UE*")H96%D(BE;,%T["B`@("`@('9A<B!B87-E(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@B8F%S92(I.PH@("`@("!B87-E+FAR968@/2!"
M05-%.PH@("`@("!H96%D+F%P<&5N9$-H:6QD*&)A<V4I.PH@("`@/"]S8W)I
M<'0^"@H@("`@/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H@("`@
M("`@(&1O8W5M96YT+G=R:71E*"<\<V-R)R`K("=I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(B!S<F,](B<@*R!?961I=&]R7W5R;"`K("=H=&UL87)E82YJ
M<R(^/"]S8W(G("L@)VEP=#XG*3L*("`@(#PO<V-R:7!T/@H@("`@/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H)+R\@;&]A9"!(5$U,07)E82!S
M8W)I<'1S('1H870@87)E('!R97-E;G0@:6X@=&AE(&]P96YE<B!F<F%M90H)
M=F%R('-C<FEP=',@/2!W:6YD;W<N;W!E;F5R+DA434Q!<F5A+E]S8W)I<'1S
M.PH)9F]R("AV87(@:2`](#,[(&D@/"!S8W)I<'1S+FQE;F=T:#L@*RMI*2![
M"B`@("`@("`@("`@+R]D;V-U;65N="YW<FET92@B/'-C<B(@*R`B:7!T('1Y
M<&4])W1E>'0O:F%V87-C<FEP="<@<W)C/2<B("L@<V-R:7!T<UMI72`K("(G
M/CPO<V-R(B`K(")I<'0^(BD["B`@("`@("`@("`@2%1-3$%R96$N;&]A9%-C
M<FEP="AS8W)I<'1S6VE=*3L*("`@("`@("!]"B`@("`\+W-C<FEP=#X*"B`@
M("`\(2TM(&)R;W=S97(@=&%K97,@82!C;V9F964@8G)E86L@:&5R92`M+3X*
M("`@(#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*=F%R('!A<F5N
M=%]O8FIE8W0@(#T@;G5L;#L*=F%R(&5D:71O<@D@("`](&YU;&P["2\O('1O
M(&)E(&EN:71I86QI>F5D(&QA=&5R(%L@9G5N8W1I;VX@:6YI="@I(%T*"B\J
M("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T@*EP*("`@1G5N8W1I;VX@("`@
M.@H@("!$97-C<FEP=&EO;B`Z"EPJ("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T@*B\*"F9U;F-T:6]N(%]#;&]S94]N17-C*&5V*2!["@EE=B!\?"`H978@
M/2!W:6YD;W<N979E;G0I('Q\("AE=B`](&5D:71O<BY?:69R86UE+F-O;G1E
M;G17:6YD;W<N979E;G0I.PH):68@*&5V+FME>4-O9&4@/3T@,C<I('L*"0DO
M+R!U<&1A=&5?<&%R96YT*"D["@D)=VEN9&]W+F-L;W-E*"D["@D)<F5T=7)N
M.PH)?0I]"@HO*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM("I<"B`@($9U
M;F-T:6]N("`@(#H@<F5S:7IE7V5D:71O<@H@("!$97-C<FEP=&EO;B`Z(')E
M<VEZ92!T:&4@961I=&]R('=H96X@=&AE('5S97(@<F5S:7IE<R!T:&4@<&]P
M=7`*7"H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J+PH*9G5N8W1I;VX@
M<F5S:7IE7V5D:71O<B@I('L@("\O(')E<VEZ92!E9&ET;W(@=&\@9FEX('=I
M;F1O=PH*("!V87(@;F5W2&5I9VAT.PH@(&EF("AD;V-U;65N="YA;&PI('L@
M+R\@244*("`@(&YE=TAE:6=H="`](&1O8W5M96YT+F)O9'DN;V9F<V5T2&5I
M9VAT("T@961I=&]R+E]T;V]L8F%R+F]F9G-E=$AE:6=H=#L*("`@(&EF("AN
M97=(96EG:'0@/"`P*2![(&YE=TAE:6=H="`](#`[('T*("!](&5L<V4@>R`O
M+R!'96-K;PH@("`@;F5W2&5I9VAT(#T@=VEN9&]W+FEN;F5R2&5I9VAT("T@
M961I=&]R+E]T;V]L8F%R+F]F9G-E=$AE:6=H=#L*("!]"B`@:68@*&5D:71O
M<BYC;VYF:6<N<W1A='5S0F%R*2!["B`@("!N97=(96EG:'0@+3T@961I=&]R
M+E]S=&%T=7-"87(N;V9F<V5T2&5I9VAT.PH@('T*"B`@+R\@5$]$3SH@22=M
M(&YO="!S=7)E(&5X86-T;'D@=VAA="!T:&5S92!A<F4@861J=7-T:6YG(&9O
M<BP@8G5T(&EF"B`@+R\@>6]U(&1O;B=T(&%D:G5S="!T:&4@:&5I9VAT(&9O
M<B!)12!T:&5N(&1O8W5M96YT+F)O9'DN;V9F<V5T2&5I9VAT"B`@+R\@=VEL
M;"!G970@;&%R9V5R(&5V97)Y('1I;64@86YD('1H92`H<&]P=7`I(&5D:71O
M<B!W:6QL(&=E="!S='5C:PH@("\O(&EN(&$@=&EG:'0@;&]O<"!A;F0@=&AE
M(&)R;W=S97(@=V]N)W0@8F4@<F5S<&]N<VEV92X@($EN(&9U='5R92!W92=L
M;`H@("\O('=A;G0@=&\@9V5T('1H97-E(&UE87-U<F5M96YT<R!D>6YA;6EC
M86QL>2!I;B!C87-E(&5L96UE;G1S(&-H86YG92!S:7IE"B`@+R\@:6X@=&AE
M(&9U='5R92X*"B`@:68@*$A434Q!<F5A+FES7V=E8VMO*2![(&YE=TAE:6=H
M="`M/2`X.R!]"B`@96QS92`@("`@("`@("`@("`@("`@("![(&YE=TAE:6=H
M="`M/2`Q,#L@?0H*("`O+R!A9&IU<W0@96QE;65N="!H96EG:'0*("!V87(@
M;F5W2&5I9VAT5VET:%!X(#T@;F5W2&5I9VAT("L@(G!X(CL*("!E9&ET;W(N
M7W1E>'1!<F5A+G-T>6QE+FAE:6=H="`](&YE=TAE:6=H=%=I=&A0>#L*("!E
M9&ET;W(N7VEF<F%M92YS='EL92YH96EG:'0@("`](&YE=TAE:6=H=%=I=&A0
M>#L*?0H*+RH@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J7`H@("!&=6YC
M=&EO;B`@("`Z(&EN:70*("`@1&5S8W)I<'1I;VX@.B!R=6X@=&AI<R!C;V1E
M(&]N('!A9V4@;&]A9`I<*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM("HO
M"@IF=6YC=&EO;B!I;FET*"D@>PH)<&%R96YT7V]B:F5C=`D@("`](&]P96YE
M<BY(5$U,07)E82Y?;V)J96-T.PH)=F%R(&-O;F9I9PD@("`]($A434Q!<F5A
M+F-L;VYE3V)J96-T*"!P87)E;G1?;V)J96-T+F-O;F9I9R`I.PH)8V]N9FEG
M+G=I9'1H"2`@(#T@(C$P,"4B.PH)8V]N9FEG+FAE:6=H=`D@("`](")A=71O
M(CL*"@DO+R!C:&%N9V4@;6%X:6UI>F4@8G5T=&]N('1O(&UI;FEM:7IE(&)U
M='1O;@H)8V]N9FEG+F)T;DQI<W1;(G!O<'5P961I=&]R(ET@/2!;("=-:6YI
M;6EZ92!%9&ET;W(G+"!?961I=&]R7W5R;"`K("=I;6%G97,O9G5L;'-C<F5E
M;E]M:6YI;6EZ92YG:68G+"!T<G5E+`H)"0D)"2`@9G5N8W1I;VXH*2![('=I
M;F1O=RYC;&]S92@I.R!](%T["@H)+R\@9V5N97)A=&4@961I=&]R(&%N9"!R
M97-I>F4@:70*"65D:71O<B`](&YE=R!(5$U,07)E82@B961I=&]R(BP@8V]N
M9FEG*3L*"@DO+R!R96=I<W1E<B!T:&4@<&QU9VEN<RP@:68@86YY"@EF;W(@
M*'9A<B!I(&EN('!A<F5N=%]O8FIE8W0N<&QU9VEN<RD@>PH)"79A<B!P;'5G
M:6X@/2!P87)E;G1?;V)J96-T+G!L=6=I;G-;:5T["@D)=')Y('L*"0D)979A
M;"AP;'5G:6XN;F%M92D["@D)"65D:71O<BYR96=I<W1E<E!L=6=I;C(H<&QU
M9VEN+FYA;64L('!L=6=I;BYA<F=S*3L*"0E](&-A=&-H*&4I('M].PH)?0H)
M+R\@86YD(')E<W1O<F4@=&AE(&]R:6=I;F%L('1O;VQB87(*("`@("`@("!C
M;VYF:6<N=&]O;&)A<B`]('!A<F5N=%]O8FIE8W0N8V]N9FEG+G1O;VQB87([
M"@EE9&ET;W(N9V5N97)A=&4H*3L*"65D:71O<BY?:69R86UE+G-T>6QE+G=I
M9'1H(#T@(C$P,"4B.PH)961I=&]R+E]T97AT07)E82YS='EL92YW:61T:"`]
M("(Q,#`E(CL*"7)E<VEZ95]E9&ET;W(H*3L*"@EE9&ET;W(N9&]C='EP92`]
M('!A<F5N=%]O8FIE8W0N9&]C='EP93L*"@DO+R!S970@8VAI;&0@=VEN9&]W
M(&-O;G1E;G1S(&%N9"!E=F5N="!H86YD;&5R<RP@869T97(@82!S;6%L;"!D
M96QA>0H)<V5T5&EM96]U="AF=6YC=&EO;B@I('L*"0D)("`@961I=&]R+G-E
M=$A434PH<&%R96YT7V]B:F5C="YG971);FYE<DA434PH*2D["@H)"0D@("`O
M+R!S=VET8V@@;6]D92!I9B!N965D960*"0D)("`@:68@*'!A<F5N=%]O8FIE
M8W0N7VUO9&4@/3T@(G1E>'1M;V1E(BD@>R!E9&ET;W(N<V5T36]D92@B=&5X
M=&UO9&4B*3L@?0H*"0D)("`@+R\@8V]N=&EN=6]U<VQY('5P9&%T92!P87)E
M;G0@961I=&]R('=I;F1O=PH)"0D@("!S971);G1E<G9A;"AU<&1A=&5?<&%R
M96YT+"`U,#`I.PH*"0D)("`@+R\@<V5T=7`@979E;G0@:&%N9&QE<G,*"0D)
M("`@9&]C=6UE;G0N8F]D>2YO;FME>7!R97-S(#T@7T-L;W-E3VY%<V,["@D)
M"2`@(&5D:71O<BY?9&]C+F)O9'DN;VYK97EP<F5S<R`](%]#;&]S94]N17-C
M.PH)"0D@("!E9&ET;W(N7W1E>'1!<F5A+F]N:V5Y<')E<W,@/2!?0VQO<V5/
M;D5S8SL*"0D)("`@=VEN9&]W+F]N<F5S:7IE(#T@<F5S:7IE7V5D:71O<CL*
M"0D@("!]+"`S,S,I.PD)"2`O+R!G:79E(&ET('-O;64@=&EM92!T;R!M965T
M('1H92!N97<@9G)A;64*?0H*+RH@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2`J7`H@("!&=6YC=&EO;B`@("`Z('5P9&%T95]P87)E;G0*("`@1&5S8W)I
M<'1I;VX@.B!U<&1A=&4@<&%R96YT('=I;F1O=R!E9&ET;W(@9FEE;&0@=VET
M:"!C;VYT96YT<R!F<F]M(&-H:6QD('=I;F1O=PH@("!<*B`M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM("HO"@IF=6YC=&EO;B!U<&1A=&5?<&%R96YT*"D@
M>PH*"2\O('5S92!T:&4@9F%S="!V97)S:6]N"@EP87)E;G1?;V)J96-T+G-E
M=$A434PH961I=&]R+F=E=$EN;F5R2%1-3"@I*3L*?0H*("`@(#PO<V-R:7!T
M/@H@("`@/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX@:'1M;"P@8F]D>2![(&AE
M:6=H=#H@,3`P)3L@;6%R9VEN.B`P<'@[(&)O<F1E<CH@,'!X.R!B86-K9W)O
M=6YD+6-O;&]R.B!B=71T;VYF86-E.R!](#PO<W1Y;&4^"B`@/"]H96%D/@H@
M(#QB;V1Y('-C<F]L;#TB;F\B(&]N;&]A9#TB2%1-3$%R96$N;VYL;V%D(#T@
M:6YI=#L@2%1-3$%R96$N:6YI="@I.R(@;VYU;FQO860](G5P9&%T95]P87)E
M;G0H*2(^"B`@("`\9F]R;2!S='EL93TB;6%R9VEN.B`P<'@[(&)O<F1E<CH@
M,7!X('-O;&ED.R!B;W)D97(M8V]L;W(Z('1H<F5E9'-H861O=R!T:')E961H
M:6=H;&EG:'0@=&AR965D:&EG:&QI9VAT('1H<F5E9'-H861O=SLB/@H@("`@
M("`\=&5X=&%R96$@;F%M93TB961I=&]R(B!I9#TB961I=&]R(B!S='EL93TB
M=VED=&@Z,3`P)3L@:&5I9VAT.C,P,'!X(CXF;F)S<#L\+W1E>'1A<F5A/@H@
M("`@/"]F;W)M/@H@(#PO8F]D>3X*/"]H=&UL/@H`````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&]P=7!S+VEN<V5R=%]I;6%G92YH=&UL````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,S4P
M`#$P-#$W,S8S,#`W`#`R-C(P,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\:'1M;#X-"@T*/&AE860^#0H@(#QT:71L93Y)
M;G-E<G0@26UA9V4\+W1I=&QE/@T*#0H\<V-R:7!T('1Y<&4](G1E>'0O:F%V
M87-C<FEP="(@<W)C/2)P;W!U<"YJ<R(^/"]S8W)I<'0^#0H-"CQS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(CX-"@T*=VEN9&]W+G)E<VEZ951O*#0P
M,"P@,3`P*3L-"@T*9G5N8W1I;VX@26YI="@I('L-"B`@7U]D;&=?:6YI="@I
M.PT*("!V87(@<&%R86T@/2!W:6YD;W<N9&EA;&]G07)G=6UE;G1S.PT*("!I
M9B`H<&%R86TI('L-"B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F
M7W5R;"(I+G9A;'5E(#T@<&%R86U;(F9?=7)L(ET[#0H@("`@("!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@B9E]A;'0B*2YV86QU92`]('!A<F%M6R)F7V%L
M=")=.PT*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?8F]R9&5R
M(BDN=F%L=64@/2!P87)A;5LB9E]B;W)D97(B73L-"B`@("`@(&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*")F7V%L:6=N(BDN=F%L=64@/2!P87)A;5LB9E]A
M;&EG;B)=.PT*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=F5R
M="(I+G9A;'5E(#T@<&%R86U;(F9?=F5R=")=.PT*("`@("`@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H(F9?:&]R:7HB*2YV86QU92`]('!A<F%M6R)F7VAO
M<FEZ(ET[#0H@("`@("!W:6YD;W<N:7!R979I97<N;&]C871I;VXN<F5P;&%C
M92AP87)A;2YF7W5R;"D[#0H@('T-"B`@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H(F9?=7)L(BDN9F]C=7,H*3L-"GT[#0H-"F9U;F-T:6]N(&]N3TLH*2![
M#0H@('9A<B!R97%U:7)E9"`]('L-"B`@("`B9E]U<FPB.B`B66]U(&UU<W0@
M96YT97(@=&AE(%523"(-"B`@?3L-"B`@9F]R("AV87(@:2!I;B!R97%U:7)E
M9"D@>PT*("`@('9A<B!E;"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*&DI
M.PT*("`@(&EF("@A96PN=F%L=64I('L-"B`@("`@(&%L97)T*')E<75I<F5D
M6VE=*3L-"B`@("`@(&5L+F9O8W5S*"D[#0H@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@?0T*("!]#0H@("\O('!A<W,@9&%T82!B86-K('1O('1H92!C86QL
M:6YG('=I;F1O=PT*("!V87(@9FEE;&1S(#T@6R)F7W5R;"(L(")F7V%L="(L
M(")F7V%L:6=N(BP@(F9?8F]R9&5R(BP-"B`@("`@("`@("`@("`@("`B9E]H
M;W)I>B(L(")F7W9E<G0B73L-"B`@=F%R('!A<F%M(#T@;F5W($]B:F5C="@I
M.PT*("!F;W(@*'9A<B!I(&EN(&9I96QD<RD@>PT*("`@('9A<B!I9"`](&9I
M96QD<UMI73L-"B`@("!V87(@96P@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"AI9"D[#0H@("`@<&%R86U;:61=(#T@96PN=F%L=64[#0H@('T-"B`@7U]D
M;&=?8VQO<V4H<&%R86TI.PT*("!R971U<FX@9F%L<V4[#0I].PT*#0IF=6YC
M=&EO;B!O;D-A;F-E;"@I('L-"B`@7U]D;&=?8VQO<V4H;G5L;"D[#0H@(')E
M='5R;B!F86QS93L-"GT[#0H-"F9U;F-T:6]N(&]N4')E=FEE=R@I('L-"B`@
M=F%R(&9?=7)L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=7)L(BD[
M#0H@('9A<B!U<FP@/2!F7W5R;"YV86QU93L-"B`@:68@*"%U<FPI('L-"B`@
M("!A;&5R="@B66]U(&AA=F4@=&\@96YT97(@86X@55),(&9I<G-T(BD[#0H@
M("`@9E]U<FPN9F]C=7,H*3L-"B`@("!R971U<FX@9F%L<V4[#0H@('T-"B`@
M=VEN9&]W+FEP<F5V:65W+FQO8V%T:6]N+G)E<&QA8V4H=7)L*3L-"B`@<F5T
M=7)N(&9A;'-E.PT*?3L-"CPO<V-R:7!T/@T*#0H\<W1Y;&4@='EP93TB=&5X
M="]C<W,B/@T*:'1M;"P@8F]D>2![#0H@(&)A8VMG<F]U;F0Z($)U='1O;D9A
M8V4[#0H@(&-O;&]R.B!"=71T;VY497AT.PT*("!F;VYT.B`Q,7!X(%1A:&]M
M82Q697)D86YA+'-A;G,M<V5R:68[#0H@(&UA<F=I;CH@,'!X.PT*("!P861D
M:6YG.B`P<'@[#0I]#0IB;V1Y('L@<&%D9&EN9SH@-7!X.R!]#0IT86)L92![
M#0H@(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL-"GT-
M"F9O<FT@<"![#0H@(&UA<F=I;BUT;W`Z(#5P>#L-"B`@;6%R9VEN+6)O='1O
M;3H@-7!X.PT*?0T*+F9L('L@=VED=&@Z(#EE;3L@9FQO870Z(&QE9G0[('!A
M9&1I;F<Z(#)P>"`U<'@[('1E>'0M86QI9VXZ(')I9VAT.R!]#0HN9G(@>R!W
M:61T:#H@-F5M.R!F;&]A=#H@;&5F=#L@<&%D9&EN9SH@,G!X(#5P>#L@=&5X
M="UA;&EG;CH@<FEG:'0[('T-"F9I96QD<V5T('L@<&%D9&EN9SH@,'!X(#$P
M<'@@-7!X(#5P>#L@?0T*<V5L96-T+"!I;G!U="P@8G5T=&]N('L@9F]N=#H@
M,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.R!]#0IB=71T;VX@>R!W
M:61T:#H@-S!P>#L@?0T*+G-P86-E('L@<&%D9&EN9SH@,G!X.R!]#0H-"BYT
M:71L92![(&)A8VMG<F]U;F0Z("-D9&8[(&-O;&]R.B`C,#`P.R!F;VYT+7=E
M:6=H=#H@8F]L9#L@9F]N="US:7IE.B`Q,C`E.R!P861D:6YG.B`S<'@@,3!P
M>#L@;6%R9VEN+6)O='1O;3H@,3!P>#L-"F)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"!B;&%C:SL@;&5T=&5R+7-P86-I;F<Z(#)P>#L-"GT-"F9O<FT@>R!P
M861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X.R!]#0H\+W-T>6QE/@T*#0H\+VAE
M860^#0H-"CQB;V1Y(&]N;&]A9#TB26YI="@I(CX-"@T*/&1I=B!C;&%S<STB
M=&ET;&4B/DEN<V5R="!);6%G93PO9&EV/@T*/"$M+2T@;F5W('-T=69F("TM
M+3X-"CQF;W)M(&%C=&EO;CTB(B!M971H;V0](F=E="(^#0H\=&%B;&4@8F]R
M9&5R/2(P(B!W:61T:#TB,3`P)2(@<W1Y;&4](G!A9&1I;F<Z(#!P>#L@;6%R
M9VEN.B`P<'@B/@T*("`\=&)O9'D^#0H-"B`@/'1R/@T*("`@(#QT9"!S='EL
M93TB=VED=&@Z(#=E;3L@=&5X="UA;&EG;CH@<FEG:'0B/DEM86=E(%523#H\
M+W1D/@T*("`@(#QT9#X\:6YP=70@='EP93TB=&5X="(@;F%M93TB=7)L(B!I
M9#TB9E]U<FPB('-T>6QE/2)W:61T:#HW-24B#0H@("`@("!T:71L93TB16YT
M97(@=&AE(&EM86=E(%523"!H97)E(B`O/@T*("`@("`@/&)U='1O;B!N86UE
M/2)P<F5V:65W(B!O;F-L:6-K/2)R971U<FX@;VY0<F5V:65W*"D[(@T*("`@
M("`@=&ET;&4](E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(^
M4')E=FEE=SPO8G5T=&]N/@T*("`@(#PO=&0^#0H@(#PO='(^#0H@(#QT<CX-
M"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`W96T[('1E>'0M86QI9VXZ(')I9VAT
M(CY!;'1E<FYA=&4@=&5X=#H\+W1D/@T*("`@(#QT9#X\:6YP=70@='EP93TB
M=&5X="(@;F%M93TB86QT(B!I9#TB9E]A;'0B('-T>6QE/2)W:61T:#HQ,#`E
M(@T*("`@("`@=&ET;&4](D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O
M<G0@:6UA9V5S(B`O/CPO=&0^#0H@(#PO='(^#0H-"B`@/"]T8F]D>3X-"CPO
M=&%B;&4^#0H-"CQP("\^#0H-"CQF:65L9'-E="!S='EL93TB9FQO870Z(&QE
M9G0[(&UA<F=I;BUL969T.B`U<'@[(CX-"CQL96=E;F0^3&%Y;W5T/"]L96=E
M;F0^#0H-"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX-"@T*/&1I=B!C;&%S
M<STB9FPB/D%L:6=N;65N=#H\+V1I=CX-"CQS96QE8W0@<VEZ93TB,2(@;F%M
M93TB86QI9VXB(&ED/2)F7V%L:6=N(@T*("!T:71L93TB4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G92(^#0H@(#QO<'1I;VX@=F%L=64](B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#Y.;W0@<V5T/"]O<'1I;VX^#0H@(#QO<'1I
M;VX@=F%L=64](FQE9G0B("`@("`@("`@("`@("`@("`@("`@("`@(#Y,969T
M/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L=64](G)I9VAT(B`@("`@("`@("`@
M("`@("`@("`@("`@(#Y2:6=H=#PO;W!T:6]N/@T*("`\;W!T:6]N('9A;'5E
M/2)T97AT=&]P(B`@("`@("`@("`@("`@("`@("`@("`^5&5X='1O<#PO;W!T
M:6]N/@T*("`\;W!T:6]N('9A;'5E/2)A8G-M:61D;&4B("`@("`@("`@("`@
M("`@("`@("`^06)S;6ED9&QE/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L=64]
M(F)A<V5L:6YE(B!S96QE8W1E9#TB,2(@("`@("`@(#Y"87-E;&EN93PO;W!T
M:6]N/@T*("`\;W!T:6]N('9A;'5E/2)A8G-B;W1T;VTB("`@("`@("`@("`@
M("`@("`@("`^06)S8F]T=&]M/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L=64]
M(F)O='1O;2(@("`@("`@("`@("`@("`@("`@("`@(#Y";W1T;VT\+V]P=&EO
M;CX-"B`@/&]P=&EO;B!V86QU93TB;6ED9&QE(B`@("`@("`@("`@("`@("`@
M("`@("`@/DUI9&1L93PO;W!T:6]N/@T*("`\;W!T:6]N('9A;'5E/2)T;W`B
M("`@("`@("`@("`@("`@("`@("`@("`@("`^5&]P/"]O<'1I;VX^#0H\+W-E
M;&5C=#X-"@T*/'`@+SX-"@T*/&1I=B!C;&%S<STB9FPB/D)O<F1E<B!T:&EC
M:VYE<W,Z/"]D:78^#0H\:6YP=70@='EP93TB=&5X="(@;F%M93TB8F]R9&5R
M(B!I9#TB9E]B;W)D97(B('-I>F4](C4B#0IT:71L93TB3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<B(@+SX-"@T*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV
M/@T*#0H\+V9I96QD<V5T/@T*#0H\9FEE;&1S970@<W1Y;&4](F9L;V%T.G)I
M9VAT.R!M87)G:6XM<FEG:'0Z(#5P>#LB/@T*/&QE9V5N9#Y3<&%C:6YG/"]L
M96=E;F0^#0H-"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX-"@T*/&1I=B!C
M;&%S<STB9G(B/DAO<FEZ;VYT86PZ/"]D:78^#0H\:6YP=70@='EP93TB=&5X
M="(@;F%M93TB:&]R:7HB(&ED/2)F7VAO<FEZ(B!S:7IE/2(U(@T*=&ET;&4]
M(DAO<FEZ;VYT86P@<&%D9&EN9R(@+SX-"@T*/'`@+SX-"@T*/&1I=B!C;&%S
M<STB9G(B/E9E<G1I8V%L.CPO9&EV/@T*/&EN<'5T('1Y<&4](G1E>'0B(&YA
M;64](G9E<G0B(&ED/2)F7W9E<G0B('-I>F4](C4B#0IT:71L93TB5F5R=&EC
M86P@<&%D9&EN9R(@+SX-"@T*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@T*
M#0H\+V9I96QD<V5T/@T*/&)R(&-L96%R/2)A;&PB("\^#0H\=&%B;&4@=VED
M=&@](C$P,"4B('-T>6QE/2)M87)G:6XM8F]T=&]M.B`P+C)E;2(^#0H@/'1R
M/@T*("`\=&0@=F%L:6=N/2)B;W1T;VTB/@T*("`@($EM86=E(%!R979I97<Z
M/&)R("\^#0H@("`@/&EF<F%M92!N86UE/2)I<')E=FEE=R(@:60](FEP<F5V
M:65W(B!F<F%M96)O<F1E<CTB,"(@<W1Y;&4](F)O<F1E<B`Z(#%P>"!S;VQI
M9"!G<F%Y.R(@:&5I9VAT/2(R,#`B('=I9'1H/2(S,#`B('-R8STB(CX\+VEF
M<F%M93X-"B`@/"]T9#X-"B`@/'1D('9A;&EG;CTB8F]T=&]M(B!S='EL93TB
M=&5X="UA;&EG;CH@<FEG:'0B/@T*("`@(#QB=71T;VX@='EP93TB8G5T=&]N
M(B!N86UE/2)O:R(@;VYC;&EC:STB<F5T=7)N(&]N3TLH*3LB/D]+/"]B=71T
M;VX^/&)R/@T*("`@(#QB=71T;VX@='EP93TB8G5T=&]N(B!N86UE/2)C86YC
M96PB(&]N8VQI8VL](G)E='5R;B!O;D-A;F-E;"@I.R(^0V%N8V5L/"]B=71T
M;VX^#0H@(#PO=&0^#0H@/"]T<CX-"CPO=&%B;&4^#0H\+V9O<FT^#0H\+V)O
M9'D^#0H\+VAT;6P^#0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+VEN<V5R=%]T
M86)L92YH=&UL`````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-3(U`#$P-#$W,S8S,#`W`#`R-C(Q,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\:'1M
M;#X*"CQH96%D/@H@(#QT:71L93Y);G-E<G0@5&%B;&4\+W1I=&QE/@H*/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB<&]P=7`N:G,B/CPO
M<V-R:7!T/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H*=VEN
M9&]W+G)E<VEZ951O*#0P,"P@,3`P*3L*"F9U;F-T:6]N($EN:70H*2!["B`@
M:3$X;B`]('=I;F1O=RYO<&5N97(N2%1-3$%R96$N23$X3BYD:6%L;V=S.R`O
M+R!L;V%D('1H92!(5$U,07)E82!P;'5G:6X@86YD(&QA;F<@9FEL90H@(%]?
M9&QG7W1R86YS;&%T92AI,3AN*3L*("!?7V1L9U]I;FET*"D["B`@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H(F9?<F]W<R(I+F9O8W5S*"D["GT["@IF=6YC
M=&EO;B!O;D]+*"D@>PH@('9A<B!R97%U:7)E9"`]('L*("`@(")F7W)O=W,B
M.B`B66]U(&UU<W0@96YT97(@82!N=6UB97(@;V8@<F]W<R(L"B`@("`B9E]C
M;VQS(CH@(EEO=2!M=7-T(&5N=&5R(&$@;G5M8F5R(&]F(&-O;'5M;G,B"B`@
M?3L*("!F;W(@*'9A<B!I(&EN(')E<75I<F5D*2!["B`@("!V87(@96P@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"AI*3L*("`@(&EF("@A96PN=F%L=64I
M('L*("`@("`@86QE<G0H<F5Q=6ER961;:5TI.PH@("`@("!E;"YF;V-U<R@I
M.PH@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@?0H@('9A<B!F:65L9',@
M/2!;(F9?<F]W<R(L(")F7V-O;',B+"`B9E]W:61T:"(L(")F7W5N:70B+"`B
M9E]F:7AE9"(L"B`@("`@("`@("`@("`@("`B9E]A;&EG;B(L(")F7V)O<F1E
M<B(L(")F7W-P86-I;F<B+"`B9E]P861D:6YG(ET["B`@=F%R('!A<F%M(#T@
M;F5W($]B:F5C="@I.PH@(&9O<B`H=F%R(&D@:6X@9FEE;&1S*2!["B`@("!V
M87(@:60@/2!F:65L9'-;:5T["B`@("!V87(@96P@/2!D;V-U;65N="YG971%
M;&5M96YT0GE)9"AI9"D["B`@("!P87)A;5MI9%T@/2`H96PN='EP92`]/2`B
M8VAE8VMB;W@B*2`_(&5L+F-H96-K960@.B!E;"YV86QU93L*("!]"B`@7U]D
M;&=?8VQO<V4H<&%R86TI.PH@(')E='5R;B!F86QS93L*?3L*"F9U;F-T:6]N
M(&]N0V%N8V5L*"D@>PH@(%]?9&QG7V-L;W-E*&YU;&PI.PH@(')E='5R;B!F
M86QS93L*?3L*"CPO<V-R:7!T/@H*/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX*
M:'1M;"P@8F]D>2!["B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*("!C;VQO
M<CH@0G5T=&]N5&5X=#L*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A
M;G,M<V5R:68["B`@;6%R9VEN.B`P<'@["B`@<&%D9&EN9SH@,'!X.PI]"F)O
M9'D@>R!P861D:6YG.B`U<'@[('T*=&%B;&4@>PH@(&9O;G0Z(#$Q<'@@5&%H
M;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*?0IF;W)M('`@>PH@(&UA<F=I;BUT
M;W`Z(#5P>#L*("!M87)G:6XM8F]T=&]M.B`U<'@["GT*+F9L('L@=VED=&@Z
M(#EE;3L@9FQO870Z(&QE9G0[('!A9&1I;F<Z(#)P>"`U<'@[('1E>'0M86QI
M9VXZ(')I9VAT.R!]"BYF<B![('=I9'1H.B`W96T[(&9L;V%T.B!L969T.R!P
M861D:6YG.B`R<'@@-7!X.R!T97AT+6%L:6=N.B!R:6=H=#L@?0IF:65L9'-E
M="![('!A9&1I;F<Z(#!P>"`Q,'!X(#5P>"`U<'@[('T*<V5L96-T+"!I;G!U
M="P@8G5T=&]N('L@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E
M<FEF.R!]"F)U='1O;B![('=I9'1H.B`W,'!X.R!]"BYS<&%C92![('!A9&1I
M;F<Z(#)P>#L@?0H*+G1I=&QE('L@8F%C:V=R;W5N9#H@(V1D9CL@8V]L;W(Z
M(",P,#`[(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-I>F4Z(#$R,"4[('!A
M9&1I;F<Z(#-P>"`Q,'!X.R!M87)G:6XM8F]T=&]M.B`Q,'!X.PIB;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@8FQA8VL[(&QE='1E<BUS<&%C:6YG.B`R<'@[
M"GT*9F]R;2![('!A9&1I;F<Z(#!P>#L@;6%R9VEN.B`P<'@[('T*/"]S='EL
M93X*"CPO:&5A9#X*"CQB;V1Y(&]N;&]A9#TB26YI="@I(CX*"CQD:78@8VQA
M<W,](G1I=&QE(CY);G-E<G0@5&%B;&4\+V1I=CX*"CQF;W)M(&%C=&EO;CTB
M(B!M971H;V0](F=E="(^"CQT86)L92!B;W)D97(](C`B('-T>6QE/2)P861D
M:6YG.B`P<'@[(&UA<F=I;CH@,'!X(CX*("`\=&)O9'D^"@H@(#QT<CX*("`@
M(#QT9"!S='EL93TB=VED=&@Z(#1E;3L@=&5X="UA;&EG;CH@<FEG:'0B/E)O
M=W,Z/"]T9#X*("`@(#QT9#X\:6YP=70@='EP93TB=&5X="(@;F%M93TB<F]W
M<R(@:60](F9?<F]W<R(@<VEZ93TB-2(@=&ET;&4](DYU;6)E<B!O9B!R;W=S
M(B!V86QU93TB,B(@+SX\+W1D/@H@("`@/'1D('-T>6QE/2)W:61T:#H@-&5M
M.R!T97AT+6%L:6=N.B!R:6=H="(^5VED=&@Z/"]T9#X*("`@(#QT9#X\:6YP
M=70@='EP93TB=&5X="(@;F%M93TB=VED=&@B(&ED/2)F7W=I9'1H(B!S:7IE
M/2(U(B!T:71L93TB5VED=&@@;V8@=&AE('1A8FQE(B!V86QU93TB,3`P(B`O
M/CPO=&0^"B`@("`\=&0^/'-E;&5C="!S:7IE/2(Q(B!N86UE/2)U;FET(B!I
M9#TB9E]U;FET(B!T:71L93TB5VED=&@@=6YI="(^"B`@("`@(#QO<'1I;VX@
M=F%L=64](B4B('-E;&5C=&5D/2(Q(B`@/E!E<F-E;G0\+V]P=&EO;CX*("`@
M("`@/&]P=&EO;B!V86QU93TB<'@B("`@("`@("`@("`@("`^4&EX96QS/"]O
M<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](F5M(B`@("`@("`@("`@("`@
M/D5M/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X\+W1D/@H@(#PO='(^"B`@/'1R
M/@H@("`@/'1D('-T>6QE/2)W:61T:#H@-&5M.R!T97AT+6%L:6=N.B!R:6=H
M="(^0V]L<SH\+W1D/@H@("`@/'1D/CQI;G!U="!T>7!E/2)T97AT(B!N86UE
M/2)C;VQS(B!I9#TB9E]C;VQS(B!S:7IE/2(U(B!T:71L93TB3G5M8F5R(&]F
M(&-O;'5M;G,B('9A;'5E/2(T(B`O/CPO=&0^"B`@("`\=&0@<W1Y;&4](G1E
M>'0M86QI9VXZ(')I9VAT(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&-H96-K
M960](F-H96-K960B(&YA;64](F9I>&5D(B!I9#TB9E]F:7AE9"(@+SX\+W1D
M/@H@("`@/'1D(&-O;'-P86X](C(B/CQL86)E;"!F;W(](F9?9FEX960B"B`@
M("`^1FEX960@=VED=&@@8V]L=6UN<SPO;&%B96P^/"]T9#X*("`\+W1R/@H@
M(#PO=&)O9'D^"CPO=&%B;&4^"@H\<"`O/@H*/&9I96QD<V5T('-T>6QE/2)F
M;&]A=#H@;&5F=#L@;6%R9VEN+6QE9G0Z(#5P>#LB/@H\;&5G96YD/DQA>6]U
M=#PO;&5G96YD/@H*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@H*/&1I=B!C
M;&%S<STB9FPB/D%L:6=N;65N=#H\+V1I=CX*/'-E;&5C="!S:7IE/2(Q(B!N
M86UE/2)A;&EG;B(@:60](F9?86QI9VXB"B`@=&ET;&4](E!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4B/@H@(#QO<'1I;VX@=F%L=64](B(@<V5L96-T960]
M(C$B("`@("`@("`@("`@("`@(#Y.;W0@<V5T/"]O<'1I;VX^"B`@/&]P=&EO
M;B!V86QU93TB;&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@/DQE9G0\
M+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)R:6=H="(@("`@("`@("`@("`@
M("`@("`@("`@("`^4FEG:'0\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)T
M97AT=&]P(B`@("`@("`@("`@("`@("`@("`@("`^5&5X='1O<#PO;W!T:6]N
M/@H@(#QO<'1I;VX@=F%L=64](F%B<VUI9&1L92(@("`@("`@("`@("`@("`@
M("`@(#Y!8G-M:61D;&4\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)B87-E
M;&EN92(@("`@("`@("`@("`@("`@("`@("`^0F%S96QI;F4\+V]P=&EO;CX*
M("`\;W!T:6]N('9A;'5E/2)A8G-B;W1T;VTB("`@("`@("`@("`@("`@("`@
M("`^06)S8F]T=&]M/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB8F]T=&]M
M(B`@("`@("`@("`@("`@("`@("`@("`@/D)O='1O;3PO;W!T:6]N/@H@(#QO
M<'1I;VX@=F%L=64](FUI9&1L92(@("`@("`@("`@("`@("`@("`@("`@(#Y-
M:61D;&4\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)T;W`B("`@("`@("`@
M("`@("`@("`@("`@("`@("`^5&]P/"]O<'1I;VX^"CPO<V5L96-T/@H*/'`@
M+SX*"CQD:78@8VQA<W,](F9L(CY";W)D97(@=&AI8VMN97-S.CPO9&EV/@H\
M:6YP=70@='EP93TB=&5X="(@;F%M93TB8F]R9&5R(B!I9#TB9E]B;W)D97(B
M('-I>F4](C4B('9A;'5E/2(Q(@IT:71L93TB3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<B(@+SX*/"$M+0H\<"`O/@H*/&1I=B!C;&%S<STB9FPB/D-O;&QA
M<'-E(&)O<F1E<G,Z/"]D:78^"CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M
M93TB8V]L;&%P<V4B(&ED/2)F7V-O;&QA<'-E(B`O/@HM+3X*/&1I=B!C;&%S
M<STB<W!A8V4B/CPO9&EV/@H*/"]F:65L9'-E=#X*"CQF:65L9'-E="!S='EL
M93TB9FQO870Z<FEG:'0[(&UA<F=I;BUR:6=H=#H@-7!X.R(^"CQL96=E;F0^
M4W!A8VEN9SPO;&5G96YD/@H*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@H*
M/&1I=B!C;&%S<STB9G(B/D-E;&P@<W!A8VEN9SH\+V1I=CX*/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](G-P86-I;F<B(&ED/2)F7W-P86-I;F<B('-I>F4]
M(C4B('9A;'5E/2(Q(@IT:71L93TB4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<R(@+SX*"CQP("\^"@H\9&EV(&-L87-S/2)F<B(^0V5L;"!P861D:6YG
M.CPO9&EV/@H\:6YP=70@='EP93TB=&5X="(@;F%M93TB<&%D9&EN9R(@:60]
M(F9?<&%D9&EN9R(@<VEZ93TB-2(@=F%L=64](C$B"G1I=&QE/2)3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(B`O/@H*/&1I=B!C
M;&%S<STB<W!A8V4B/CPO9&EV/@H*/"]F:65L9'-E=#X*"CQD:78@<W1Y;&4]
M(FUA<F=I;BUT;W`Z(#@U<'@[(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C.3DY
M.R!P861D:6YG.B`R<'@[('1E>'0M86QI9VXZ(')I9VAT.R(^"CQB=71T;VX@
M='EP93TB8G5T=&]N(B!N86UE/2)O:R(@;VYC;&EC:STB<F5T=7)N(&]N3TLH
M*3LB/D]+/"]B=71T;VX^"CQB=71T;VX@='EP93TB8G5T=&]N(B!N86UE/2)C
M86YC96PB(&]N8VQI8VL](G)E='5R;B!O;D-A;F-E;"@I.R(^0V%N8V5L/"]B
M=71T;VX^"CPO9&EV/@H*/"]F;W)M/@H*/"]B;V1Y/@H\+VAT;6P^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]L
M:6YK+FAT;6P````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#0S-@`Q,#0Q-S,V,S`P-P`P
M,C0T-S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/&AT;6P^"@H\:&5A9#X*("`\=&ET;&4^26YS97)T+TUO9&EF>2!,:6YK
M/"]T:71L93X*("`\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@<W)C
M/2)P;W!U<"YJ<R(^/"]S8W)I<'0^"B`@/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/@H@("`@=VEN9&]W+G)E<VEZ951O*#0P,"P@,C`P*3L*"DDQ
M.$X@/2!W:6YD;W<N;W!E;F5R+DA434Q!<F5A+DDQ.$XN9&EA;&]G<SL*"F9U
M;F-T:6]N(&DQ.&XH<W1R*2!["B`@<F5T=7)N("A),3A.6W-T<ET@?'P@<W1R
M*3L*?3L*"F9U;F-T:6]N(&]N5&%R9V5T0VAA;F=E9"@I('L*("!V87(@9B`]
M(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7V]T:&5R7W1A<F=E="(I.PH@
M(&EF("AT:&ES+G9A;'5E(#T](")?;W1H97(B*2!["B`@("!F+G-T>6QE+G9I
M<VEB:6QI='D@/2`B=FES:6)L92(["B`@("!F+G-E;&5C="@I.PH@("`@9BYF
M;V-U<R@I.PH@('T@96QS92!F+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N
M(CL*?3L*"F9U;F-T:6]N($EN:70H*2!["B`@7U]D;&=?=')A;G-L871E*$DQ
M.$XI.PH@(%]?9&QG7VEN:70H*3L*("!V87(@<&%R86T@/2!W:6YD;W<N9&EA
M;&]G07)G=6UE;G1S.PH@('9A<B!T87)G971?<V5L96-T(#T@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H(F9?=&%R9V5T(BD["B`@=F%R('5S95]T87)G970@
M/2!T<G5E.PH@(&EF("AP87)A;2D@>PH@("`@:68@*"!T>7!E;V8@<&%R86U;
M(F9?=7-E=&%R9V5T(ET@(3T@(G5N9&5F:6YE9"(@*2!["B`@("`@('5S95]T
M87)G970@/2!P87)A;5LB9E]U<V5T87)G970B73L*("`@('T*("`@(&EF("@@
M='EP96]F('!A<F%M6R)F7VAR968B72`A/2`B=6YD969I;F5D(B`I('L*("`@
M("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?:')E9B(I+G9A;'5E(#T@
M<&%R86U;(F9?:')E9B)=.PH@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@B9E]T:71L92(I+G9A;'5E(#T@<&%R86U;(F9?=&ET;&4B73L*("`@("`@
M8V]M8F]396QE8W1686QU92AT87)G971?<V5L96-T+"!P87)A;5LB9E]T87)G
M970B72D["B`@("`@(&EF("AT87)G971?<V5L96-T+G9A;'5E("$]('!A<F%M
M+F9?=&%R9V5T*2!["B`@("`@("`@=F%R(&]P="`](&1O8W5M96YT+F-R96%T
M945L96UE;G0H(F]P=&EO;B(I.PH@("`@("`@(&]P="YV86QU92`]('!A<F%M
M+F9?=&%R9V5T.PH@("`@("`@(&]P="YI;FYE<DA434P@/2!O<'0N=F%L=64[
M"B`@("`@("`@=&%R9V5T7W-E;&5C="YA<'!E;F1#:&EL9"AO<'0I.PH@("`@
M("`@(&]P="YS96QE8W1E9"`]('1R=64["B`@("`@('T*("`@('T*("!]"B`@
M:68@*"$@=7-E7W1A<F=E="D@>PH@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H(F9?=&%R9V5T7VQA8F5L(BDN<W1Y;&4N=FES:6)I;&ET>2`](")H:61D
M96XB.PH@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=&%R9V5T(BDN
M<W1Y;&4N=FES:6)I;&ET>2`](")H:61D96XB.PH@("`@9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H(F9?=&%R9V5T7V]T:&5R(BDN<W1Y;&4N=FES:6)I;&ET
M>2`](")H:61D96XB.PH@('T*("!V87(@;W!T(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@B;W!T:6]N(BD["B`@;W!T+G9A;'5E(#T@(E]O=&AE<B(["B`@
M;W!T+FEN;F5R2%1-3"`](&DQ.&XH(D]T:&5R(BD["B`@=&%R9V5T7W-E;&5C
M="YA<'!E;F1#:&EL9"AO<'0I.PH@('1A<F=E=%]S96QE8W0N;VYC:&%N9V4@
M/2!O;E1A<F=E=$-H86YG960["B`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M(F9?:')E9B(I+F9O8W5S*"D["B`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M(F9?:')E9B(I+G-E;&5C="@I.PI].PH*9G5N8W1I;VX@;VY/2R@I('L*("!V
M87(@<F5Q=6ER960@/2!["B`@("`O+R!F7VAR968@<VAO=6QD;B=T(&)E(')E
M<75I<F5D(&]R(&]T:&5R=VES92!R96UO=FEN9R!T:&4@;&EN:R!B>2!E;G1E
M<FEN9R!A;B!E;7!T>0T*("`@("\O('5R;"!I<VXG="!P;W-S:6)L92!A;GEM
M;W)E+@T*("`@("\O(")F7VAR968B.B!I,3AN*")9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B*0T*("!].PH@(&9O
M<B`H=F%R(&D@:6X@<F5Q=6ER960I('L*("`@('9A<B!E;"`](&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*&DI.PH@("`@:68@*"%E;"YV86QU92D@>PH@("`@
M("!A;&5R="AR97%U:7)E9%MI72D["B`@("`@(&5L+F9O8W5S*"D["B`@("`@
M(')E='5R;B!F86QS93L*("`@('T*("!]"B`@+R\@<&%S<R!D871A(&)A8VL@
M=&\@=&AE(&-A;&QI;F<@=VEN9&]W"B`@=F%R(&9I96QD<R`](%LB9E]H<F5F
M(BP@(F9?=&ET;&4B+"`B9E]T87)G970B(%T["B`@=F%R('!A<F%M(#T@;F5W
M($]B:F5C="@I.PH@(&9O<B`H=F%R(&D@:6X@9FEE;&1S*2!["B`@("!V87(@
M:60@/2!F:65L9'-;:5T["B`@("!V87(@96P@/2!D;V-U;65N="YG971%;&5M
M96YT0GE)9"AI9"D["B`@("!P87)A;5MI9%T@/2!E;"YV86QU93L*("!]"B`@
M:68@*'!A<F%M+F9?=&%R9V5T(#T](")?;W1H97(B*0H@("`@<&%R86TN9E]T
M87)G970@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]O=&AE<E]T87)G
M970B*2YV86QU93L*("!?7V1L9U]C;&]S92AP87)A;2D["B`@<F5T=7)N(&9A
M;'-E.PI].PH*9G5N8W1I;VX@;VY#86YC96PH*2!["B`@7U]D;&=?8VQO<V4H
M;G5L;"D["B`@<F5T=7)N(&9A;'-E.PI].PH*/"]S8W)I<'0^"@H\<W1Y;&4@
M='EP93TB=&5X="]C<W,B/@IH=&UL+"!B;V1Y('L*("!B86-K9W)O=6YD.B!"
M=71T;VY&86-E.PH@(&-O;&]R.B!"=71T;VY497AT.PH@(&9O;G0Z(#$Q<'@@
M5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*("!M87)G:6XZ(#!P>#L*("!P
M861D:6YG.B`P<'@["GT*8F]D>2![('!A9&1I;F<Z(#5P>#L@?0IT86)L92![
M"B`@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PI]"G-E
M;&5C="P@:6YP=70L(&)U='1O;B![(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A
M;F$L<V%N<RUS97)I9CL@?0IB=71T;VX@>R!W:61T:#H@-S!P>#L@?0IT86)L
M92`N;&%B96P@>R!T97AT+6%L:6=N.B!R:6=H=#L@=VED=&@Z(#AE;3L@?0H*
M+G1I=&QE('L@8F%C:V=R;W5N9#H@(V1D9CL@8V]L;W(Z(",P,#`[(&9O;G0M
M=V5I9VAT.B!B;VQD.R!F;VYT+7-I>F4Z(#$R,"4[('!A9&1I;F<Z(#-P>"`Q
M,'!X.R!M87)G:6XM8F]T=&]M.B`Q,'!X.PIB;W)D97(M8F]T=&]M.B`Q<'@@
M<V]L:60@8FQA8VL[(&QE='1E<BUS<&%C:6YG.B`R<'@["GT*"B-B=71T;VYS
M('L*("`@("`@;6%R9VEN+71O<#H@,65M.R!B;W)D97(M=&]P.B`Q<'@@<V]L
M:60@(SDY.3L*("`@("`@<&%D9&EN9SH@,G!X.R!T97AT+6%L:6=N.B!R:6=H
M=#L*?0H\+W-T>6QE/@H*/"]H96%D/@H*/&)O9'D@;VYL;V%D/2));FET*"DB
M/@H\9&EV(&-L87-S/2)T:71L92(^26YS97)T+TUO9&EF>2!,:6YK/"]D:78^
M"CQF;W)M/@H\=&%B;&4@8F]R9&5R/2(P(B!S='EL93TB=VED=&@Z(#$P,"4[
M(CX*("`\='(^"B`@("`\=&0@8VQA<W,](FQA8F5L(CY54DPZ/"]T9#X*("`@
M(#QT9#X\:6YP=70@='EP93TB=&5X="(@:60](F9?:')E9B(@<W1Y;&4](G=I
M9'1H.B`Q,#`E(B`O/CPO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0@8VQA
M<W,](FQA8F5L(CY4:71L92`H=&]O;'1I<"DZ/"]T9#X*("`@(#QT9#X\:6YP
M=70@='EP93TB=&5X="(@:60](F9?=&ET;&4B('-T>6QE/2)W:61T:#H@,3`P
M)2(@+SX\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)L86)E
M;"(^/'-P86X@:60](F9?=&%R9V5T7VQA8F5L(CY487)G970Z/"]S<&%N/CPO
M=&0^"B`@("`\=&0^/'-E;&5C="!I9#TB9E]T87)G970B/@H@("`@("`\;W!T
M:6]N('9A;'5E/2(B/DYO;F4@*'5S92!I;7!L:6-I="D\+V]P=&EO;CX*("`@
M("`@/&]P=&EO;B!V86QU93TB7V)L86YK(CY.97<@=VEN9&]W("A?8FQA;FLI
M/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](E]S96QF(CY386UE(&9R
M86UE("A?<V5L9BD\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB7W1O
M<"(^5&]P(&9R86UE("A?=&]P*3PO;W!T:6]N/@H@("`@/"]S96QE8W0^"B`@
M("`\:6YP=70@='EP93TB=&5X="(@;F%M93TB9E]O=&AE<E]T87)G970B(&ED
M/2)F7V]T:&5R7W1A<F=E="(@<VEZ93TB,3`B('-T>6QE/2)V:7-I8FEL:71Y
M.B!H:61D96XB("\^"B`@("`\+W1D/@H@(#PO='(^"CPO=&%B;&4^"@H\9&EV
M(&ED/2)B=71T;VYS(CX*("`\8G5T=&]N('1Y<&4](G-U8FUI="(@;F%M93TB
M;VLB(&]N8VQI8VL](G)E='5R;B!O;D]+*"D[(CY/2SPO8G5T=&]N/@H@(#QB
M=71T;VX@='EP93TB8G5T=&]N(B!N86UE/2)C86YC96PB(&]N8VQI8VL](G)E
M='5R;B!O;D-A;F-E;"@I.R(^0V%N8V5L/"]B=71T;VX^"CPO9&EV/@H\+V9O
M<FT^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+W!O<'5P+FIS````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`V,C(U`#$P-#$W,S8S,#`W`#`R-#,U-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O+R!H=&UL
M07)E82!V,RXP("T@0V]P>7)I9VAT("AC*2`R,#`R+"`R,#`S(&EN=&5R86-T
M:79E=&]O;',N8V]M+"!I;F,N"B\O(%1H:7,@8V]P>7)I9VAT(&YO=&EC92!-
M55-4('-T87D@:6YT86-T(&9O<B!U<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O
M"B\O(%!O<G1I;VYS("AC*2!D>6YA<F-H+F-O;2P@,C`P,PHO+PHO+R!!(&9R
M964@5UE325=91R!E9&ET;W(@<F5P;&%C96UE;G0@9F]R(#QT97AT87)E83X@
M9FEE;&1S+@HO+R!&;W(@9G5L;"!S;W5R8V4@8V]D92!A;F0@9&]C<RP@=FES
M:70@:'1T<#HO+W=W=RYH=&UL87)E82YC;VTO"B\O"B\O(%9E<G-I;VX@,RXP
M(&1E=F5L;W!E9"!B>2!-:6AA:2!"87IO;BX*+R\@("!H='1P.B\O9'EN87)C
M:"YC;VTO;6ES:&]O"B\O"B\O("1)9#H@<&]P=7`N:G,L=B`Q+C$R(#(P,#4O
M,#$O,C0@,3@Z,CDZ-#@@:71O;VQS($5X<"`D"@IF=6YC=&EO;B!G971!8G-O
M;'5T95!O<RAE;"D@>PH)=F%R('(@/2![('@Z(&5L+F]F9G-E=$QE9G0L('DZ
M(&5L+F]F9G-E=%1O<"!].PH):68@*&5L+F]F9G-E=%!A<F5N="D@>PH)"79A
M<B!T;7`@/2!G971!8G-O;'5T95!O<RAE;"YO9F9S971087)E;G0I.PH)"7(N
M>"`K/2!T;7`N>#L*"0ER+GD@*ST@=&UP+GD["@E]"@ER971U<FX@<CL*?3L*
M"F9U;F-T:6]N(&-O;6)O4V5L96-T5F%L=64H8RP@=F%L*2!["@EV87(@;W!S
M(#T@8RYG971%;&5M96YT<T)Y5&%G3F%M92@B;W!T:6]N(BD["@EF;W(@*'9A
M<B!I(#T@;W!S+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)=F%R(&]P(#T@;W!S
M6VE=.PH)"6]P+G-E;&5C=&5D(#T@*&]P+G9A;'5E(#T]('9A;"D["@E]"@EC
M+G9A;'5E(#T@=F%L.PI].PH*9G5N8W1I;VX@7U]D;&=?;VYC;&]S92@I('L*
M"6]P96YE<BY$:6%L;V<N7W)E='5R;BAN=6QL*3L*?3L*"F9U;F-T:6]N(%]?
M9&QG7VEN:70H8F]T=&]M*2!["@EV87(@8F]D>2`](&1O8W5M96YT+F)O9'D[
M"@EV87(@8F]D>5]H96EG:'0@/2`P.PH):68@*'1Y<&5O9B!B;W1T;VT@/3T@
M(G5N9&5F:6YE9"(I('L*"0EV87(@9&EV(#T@9&]C=6UE;G0N8W)E871E16QE
M;65N="@B9&EV(BD["@D)8F]D>2YA<'!E;F1#:&EL9"AD:78I.PH)"79A<B!P
M;W,@/2!G971!8G-O;'5T95!O<RAD:78I.PH)"6)O9'E?:&5I9VAT(#T@<&]S
M+GD["@E](&5L<V4@>PH)"79A<B!P;W,@/2!G971!8G-O;'5T95!O<RAB;W1T
M;VTI.PH)"6)O9'E?:&5I9VAT(#T@<&]S+GD@*R!B;W1T;VTN;V9F<V5T2&5I
M9VAT.PH)?0H)=VEN9&]W+F1I86QO9T%R9W5M96YT<R`](&]P96YE<BY$:6%L
M;V<N7V%R9W5M96YT<SL*"6EF("@A9&]C=6UE;G0N86QL*2!["@D)=VEN9&]W
M+G-I>F54;T-O;G1E;G0H*3L*"0EW:6YD;W<N<VEZ951O0V]N=&5N="@I.PDO
M+R!F;W(@<F5A<V]N<R!B97EO;F0@=6YD97)S=&%N9&EN9RP*"0D)"0DO+R!O
M;FQY(&EF('=E(&-A;&P@:70@='=I8V4@=V4@9V5T('1H90H)"0D)"2\O(&-O
M<G)E8W0@<VEZ92X*"0EW:6YD;W<N861D179E;G1,:7-T96YE<B@B=6YL;V%D
M(BP@7U]D;&=?;VYC;&]S92P@=')U92D["@D)=VEN9&]W+FEN;F5R5VED=&@@
M/2!B;V1Y+F]F9G-E=%=I9'1H("L@-3L*"0EW:6YD;W<N:6YN97)(96EG:'0@
M/2!B;V1Y7VAE:6=H="`K(#(["@D)+R\@8V5N=&5R(&]N('!A<F5N=`H)"79A
M<B!X(#T@;W!E;F5R+G-C<F5E;E@@*R`H;W!E;F5R+F]U=&5R5VED=&@@+2!W
M:6YD;W<N;W5T97)7:61T:"D@+R`R.PH)"79A<B!Y(#T@;W!E;F5R+G-C<F5E
M;ED@*R`H;W!E;F5R+F]U=&5R2&5I9VAT("T@=VEN9&]W+F]U=&5R2&5I9VAT
M*2`O(#(["@D)=VEN9&]W+FUO=F54;RAX+"!Y*3L*"7T@96QS92!["@D)+R\@
M=VEN9&]W+F1I86QO9TAE:6=H="`](&)O9'DN;V9F<V5T2&5I9VAT("L@-3`@
M*R`B<'@B.PH)"2\O('=I;F1O=RYD:6%L;V=7:61T:"`](&)O9'DN;V9F<V5T
M5VED=&@@*R`B<'@B.PH)"7=I;F1O=RYR97-I>F54;RAB;V1Y+F]F9G-E=%=I
M9'1H+"!B;V1Y7VAE:6=H="D["@D)=F%R(&-H(#T@8F]D>2YC;&EE;G1(96EG
M:'0["@D)=F%R(&-W(#T@8F]D>2YC;&EE;G17:61T:#L*"0EW:6YD;W<N<F5S
M:7IE0GDH8F]D>2YO9F9S9717:61T:"`M(&-W+"!B;V1Y7VAE:6=H="`M(&-H
M*3L*"0EV87(@5R`](&)O9'DN;V9F<V5T5VED=&@["@D)=F%R($@@/2`R("H@
M8F]D>5]H96EG:'0@+2!C:#L*"0EV87(@>"`]("AS8W)E96XN879A:6Q7:61T
M:"`M(%<I("\@,CL*"0EV87(@>2`]("AS8W)E96XN879A:6Q(96EG:'0@+2!(
M*2`O(#(["@D)=VEN9&]W+FUO=F54;RAX+"!Y*3L*"7T*"61O8W5M96YT+F)O
M9'DN;VYK97EP<F5S<R`](%]?9&QG7V-L;W-E7V]N7V5S8SL*?3L*"F9U;F-T
M:6]N(%]?9&QG7W1R86YS;&%T92AI,3AN*2!["@EV87(@='EP97,@/2!;(FEN
M<'5T(BP@(G-E;&5C="(L(")L96=E;F0B+"`B<W!A;B(L(")O<'1I;VXB+"`B
M=&0B+"`B8G5T=&]N(BP@(F1I=B)=.PH)9F]R("AV87(@='EP92`](#`[('1Y
M<&4@/"!T>7!E<RYL96YG=&@[("LK='EP92D@>PH)"79A<B!S<&%N<R`](&1O
M8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*'1Y<&5S6W1Y<&5=*3L*"0EF
M;W(@*'9A<B!I(#T@<W!A;G,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)=F%R
M('-P86X@/2!S<&%N<UMI73L*"0D):68@*'-P86XN9FER<W1#:&EL9"`F)B!S
M<&%N+F9I<G-T0VAI;&0N9&%T82D@>PH)"0D)=F%R('1X="`](&DQ.&Y;<W!A
M;BYF:7)S=$-H:6QD+F1A=&%=.PH)"0D):68@*'1X="D*"0D)"0ES<&%N+F9I
M<G-T0VAI;&0N9&%T82`]('1X=#L*"0D)?0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H<W!A;BYT:71L92D@>PH)"0D)=F%R('1X="`](&DQ.&Y;<W!A
M;BYT:71L95T["@D)"0EI9B`H='AT*0H)"0D)"7-P86XN=&ET;&4@/2!T>'0[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*"0E]"@E]"@EV87(@='AT(#T@
M:3$X;EMD;V-U;65N="YT:71L95T["@EI9B`H='AT*0H)"61O8W5M96YT+G1I
M=&QE(#T@='AT.PI].PH*+R\@8VQO<V5S('1H92!D:6%L;V<@86YD('!A<W-E
M<R!T:&4@<F5T=7)N(&EN9F\@=7!P97(N"F9U;F-T:6]N(%]?9&QG7V-L;W-E
M*'9A;"D@>PH);W!E;F5R+D1I86QO9RY?<F5T=7)N*'9A;"D["@EW:6YD;W<N
M8VQO<V4H*3L*?3L*"F9U;F-T:6]N(%]?9&QG7V-L;W-E7V]N7V5S8RAE=BD@
M>PH)978@?'P@*&5V(#T@=VEN9&]W+F5V96YT*3L*"6EF("AE=BYK97E#;V1E
M(#T](#(W*2!["@D)=VEN9&]W+F-L;W-E*"D["@D)<F5T=7)N(&9A;'-E.PH)
M?0H)<F5T=7)N('1R=64["GT["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]S96QE8W1?8V]L
M;W(N:'1M;``````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`W,#$T,@`Q,#0Q-S,V,S`P-P`P,C8R,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/"$M+2!N
M;W1E.B!T:&ES('9E<G-I;VX@;V8@=&AE(&-O;&]R('!I8VME<B!I<R!O<'1I
M;6EZ960@9F]R($E%(#4N-2L@;VYL>2`M+3X-"@T*/&AT;6P^/&AE860^/'1I
M=&QE/E-E;&5C="!#;VQO<CPO=&ET;&4^#0H-"CQS8W)I<'0@='EP93TB=&5X
M="]J879A<V-R:7!T(B!S<F,](G!O<'5P+FIS(CX\+W-C<FEP=#X-"@T*/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@T*#0IW:6YD;W<N<F5S:7IE
M5&\H,C0P+"`Q.#(I.PT*9G5N8W1I;VX@7T-L;W-E3VY%<V,H*2![#0H@(&EF
M("AE=F5N="YK97E#;V1E(#T](#(W*2![('=I;F1O=RYC;&]S92@I.R!R971U
M<FX[('T-"GT-"@T*9G5N8W1I;VX@26YI="@I('L@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<G5N
M(&]N('!A9V4@;&]A9`T*("!?7V1L9U]I;FET*"D[("`@("\O(#PA+2T@=&AI
M<R!C86X@8F4@9F]U;F0@:6X@<&]P=7`N:G,@+2T^#0H@(&1O8W5M96YT+F)O
M9'DN;VYK97EP<F5S<R`](%]#;&]S94]N17-C.PT*#0H@('9A<B!C;VQO<B`]
M('=I;F1O=RYD:6%L;V=!<F=U;65N=',[#0H@(&-O;&]R(#T@5F%L:61A=&5#
M;VQO<BAC;VQO<BD@?'P@)S`P,#`P,"<[#0H@(%9I97<H8V]L;W(I.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!S970@9&5F875L="!C;VQO<@T*?0T*#0IF=6YC=&EO;B!6
M:65W*&-O;&]R*2![("`@("`@("`@("`@("`@("`@+R\@<')E=FEE=R!C;VQO
M<@T*("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B0V]L;W)0<F5V:65W(BDN
M<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@)R,G("L@8V]L;W([#0H@(&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*")#;VQO<DAE>"(I+G9A;'5E(#T@)R,G("L@
M8V]L;W([#0I]#0H-"F9U;F-T:6]N(%-E="AS=')I;F<I('L@("`@("`@("`@
M("`@("`@("`@+R\@<V5L96-T(&-O;&]R#0H@('9A<B!C;VQO<B`](%9A;&ED
M871E0V]L;W(H<W1R:6YG*3L-"B`@:68@*&-O;&]R(#T](&YU;&PI('L@86QE
M<G0H(DEN=F%L:60@8V]L;W(@8V]D93H@(B`K('-T<FEN9RD[('T@("`@("`@
M("\O(&EN=F%L:60@8V]L;W(-"B`@96QS92![("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O('9A;&ED(&-O;&]R#0H@("`@5FEE=RAC;VQO<BD[("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!S:&]W('-E;&5C=&5D(&-O;&]R#0H@("`@7U]D
M;&=?8VQO<V4H8V]L;W(I.PT*("!]#0I]#0H-"F9U;F-T:6]N(%9A;&ED871E
M0V]L;W(H<W1R:6YG*2![("`@("`@("`@("`@("`@("\O(')E='5R;B!V86QI
M9"!C;VQO<B!C;V1E#0H@('-T<FEN9R`]('-T<FEN9R!\?"`G)SL-"B`@<W1R
M:6YG(#T@<W1R:6YG("L@(B([#0H@('-T<FEN9R`]('-T<FEN9RYT;U5P<&5R
M0V%S92@I.PT*("!V87(@8VAA<G,@/2`G,#$R,S0U-C<X.4%"0T1%1B<[#0H@
M('9A<B!O=70@("`]("<G.PT*#0H@(&9O<B`H=F%R(&D],#L@:3QS=')I;F<N
M;&5N9W1H.R!I*RLI('L@("`@("`@("`@("`@+R\@<F5M;W9E(&EN=F%L:60@
M8V]L;W(@8VAA<G,-"B`@("!V87(@<V-H87(@/2!S=')I;F<N8VAA<D%T*&DI
M.PT*("`@(&EF("AC:&%R<RYI;F1E>$]F*'-C:&%R*2`A/2`M,2D@>R!O=70@
M*ST@<V-H87([('T-"B`@?0T*#0H@(&EF("AO=70N;&5N9W1H("$](#8I('L@
M<F5T=7)N(&YU;&P[('T@("`@("`@("`@("`O+R!C:&5C:R!L96YG=&@-"B`@
M<F5T=7)N(&]U=#L-"GT-"@T*/"]S8W)I<'0^#0H\+VAE860^#0H\8F]D>2!S
M='EL93TB8F%C:V=R;W5N9#I"=71T;VY&86-E.R!M87)G:6XZ,'!X.R!P861D
M:6YG.C!P>"(@;VYL;V%D/2));FET*"DB/@T*#0H\9F]R;2!M971H;V0](F=E
M="(@<W1Y;&4](FUA<F=I;CHP<'@[('!A9&1I;F<Z,'!X(B!O;E-U8FUI=#TB
M4V5T*&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=#;VQO<DAE>"<I+G9A;'5E
M*3L@<F5T=7)N(&9A;'-E.R(^#0H\=&%B;&4@8F]R9&5R/2(P<'@B(&-E;&QS
M<&%C:6YG/2(P<'@B(&-E;&QP861D:6YG/2(T(B!W:61T:#TB,3`P)2(^#0H@
M/'1R/@T*("`\=&0@<W1Y;&4](F)A8VMG<F]U;F0Z8G5T=&]N9F%C92(@=F%L
M:6=N/6-E;G1E<CX\9&EV('-T>6QE/2)B86-K9W)O=6YD+6-O;&]R.B`C,#`P
M,#`P.R!P861D:6YG.B`Q.R!H96EG:'0Z(#(Q<'@[('=I9'1H.B`U,'!X(CX\
M9&EV(&ED/2)#;VQO<E!R979I97<B('-T>6QE/2)H96EG:'0Z(#$P,"4[('=I
M9'1H.B`Q,#`E(CX\+V1I=CX\+V1I=CX\+W1D/@T*("`\=&0@<W1Y;&4](F)A
M8VMG<F]U;F0Z8G5T=&]N9F%C92(@=F%L:6=N/6-E;G1E<CX\:6YP=70@='EP
M93TB=&5X="(@;F%M93TB0V]L;W)(97@B#0H@("`@:60](D-O;&]R2&5X(B!V
M86QU93TB(B!S:7IE/3$U('-T>6QE/2)F;VYT+7-I>F4Z(#$R<'@B/CPO=&0^
M#0H@(#QT9"!S='EL93TB8F%C:V=R;W5N9#IB=71T;VYF86-E(B!W:61T:#TQ
M,#`E/CPO=&0^#0H@/"]T<CX-"CPO=&%B;&4^#0H\+V9O<FT^#0H-"CQT86)L
M92!B;W)D97(](C`B(&-E;&QS<&%C:6YG/2(Q<'@B(&-E;&QP861D:6YG/2(P
M<'@B('=I9'1H/2(Q,#`E(B!B9V-O;&]R/2(C,#`P,#`P(B!S='EL93TB8W5R
M<V]R.B!H86YD.R(^#0H\='(^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U
M<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E
M="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P
M)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R
M/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,S,P
M,"!O;DUO=7-E3W9E<CU6:65W*"<P,#,S,#`G*2!O;D-L:6-K/5-E="@G,#`S
M,S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,P,#8V,#`@;VY-;W5S94]V97(]5FEE=R@G,#`V-C`P)RD@;VY#
M;&EC:SU3970H)S`P-C8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`Y.3`P(&]N36]U<V5/=F5R/59I97<H
M)S`P.3DP,"<I(&]N0VQI8VL]4V5T*"<P,#DY,#`G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P0T,P,"!O;DUO
M=7-E3W9E<CU6:65W*"<P,$-#,#`G*2!O;D-L:6-K/5-E="@G,#!#0S`P)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,P,$9&,#`@;VY-;W5S94]V97(]5FEE=R@G,#!&1C`P)RD@;VY#;&EC:SU3
M970H)S`P1D8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC,S,P,#`P(&]N36]U<V5/=F5R/59I97<H)S,S,#`P
M,"<I(&]N0VQI8VL]4V5T*"<S,S`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,S,P,"!O;DUO=7-E3W9E
M<CU6:65W*"<S,S,S,#`G*2!O;D-L:6-K/5-E="@G,S,S,S`P)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,S8V
M,#`@;VY-;W5S94]V97(]5FEE=R@G,S,V-C`P)RD@;VY#;&EC:SU3970H)S,S
M-C8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC,S,Y.3`P(&]N36]U<V5/=F5R/59I97<H)S,S.3DP,"<I(&]N
M0VQI8VL]4V5T*"<S,SDY,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S0T,P,"!O;DUO=7-E3W9E<CU6:65W
M*"<S,T-#,#`G*2!O;D-L:6-K/5-E="@G,S-#0S`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,T9&,#`@;VY-
M;W5S94]V97(]5FEE=R@G,S-&1C`P)RD@;VY#;&EC:SU3970H)S,S1D8P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC-C8P,#`P(&]N36]U<V5/=F5R/59I97<H)S8V,#`P,"<I(&]N0VQI8VL]
M4V5T*"<V-C`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S8V,S,P,"!O;DUO=7-E3W9E<CU6:65W*"<V-C,S
M,#`G*2!O;D-L:6-K/5-E="@G-C8S,S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C8V,#`@;VY-;W5S94]V
M97(]5FEE=R@G-C8V-C`P)RD@;VY#;&EC:SU3970H)S8V-C8P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8Y
M.3`P(&]N36]U<V5/=F5R/59I97<H)S8V.3DP,"<I(&]N0VQI8VL]4V5T*"<V
M-CDY,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S8V0T,P,"!O;DUO=7-E3W9E<CU6:65W*"<V-D-#,#`G*2!O
M;D-L:6-K/5-E="@G-C9#0S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D9&,#`@;VY-;W5S94]V97(]5FEE
M=R@G-C9&1C`P)RD@;VY#;&EC:SU3970H)S8V1D8P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*/'1R/@T*/'1D(&)G8V]L
M;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K
M/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,S,S,S,S,@;VY-;W5S94]V97(]5FEE=R@G,S,S
M,S,S)RD@;VY#;&EC:SU3970H)S,S,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/
M=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P
M,#`S,R!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,S,G*2!O;D-L:6-K/5-E="@G
M,#`P,#,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,P,#,S,S,@;VY-;W5S94]V97(]5FEE=R@G,#`S,S,S)RD@
M;VY#;&EC:SU3970H)S`P,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`V-C,S(&]N36]U<V5/=F5R/59I
M97<H)S`P-C8S,R<I(&]N0VQI8VL]4V5T*"<P,#8V,S,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P.3DS,R!O
M;DUO=7-E3W9E<CU6:65W*"<P,#DY,S,G*2!O;D-L:6-K/5-E="@G,#`Y.3,S
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,P,$-#,S,@;VY-;W5S94]V97(]5FEE=R@G,#!#0S,S)RD@;VY#;&EC
M:SU3970H)S`P0T,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,#!&1C,S(&]N36]U<V5/=F5R/59I97<H)S`P
M1D8S,R<I(&]N0VQI8VL]4V5T*"<P,$9&,S,G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,#`S,R!O;DUO=7-E
M3W9E<CU6:65W*"<S,S`P,S,G*2!O;D-L:6-K/5-E="@G,S,P,#,S)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S
M,S,S,S,@;VY-;W5S94]V97(]5FEE=R@G,S,S,S,S)RD@;VY#;&EC:SU3970H
M)S,S,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC,S,V-C,S(&]N36]U<V5/=F5R/59I97<H)S,S-C8S,R<I
M(&]N0VQI8VL]4V5T*"<S,S8V,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S.3DS,R!O;DUO=7-E3W9E<CU6
M:65W*"<S,SDY,S,G*2!O;D-L:6-K/5-E="@G,S,Y.3,S)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,T-#,S,@
M;VY-;W5S94]V97(]5FEE=R@G,S-#0S,S)RD@;VY#;&EC:SU3970H)S,S0T,S
M,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC,S-&1C,S(&]N36]U<V5/=F5R/59I97<H)S,S1D8S,R<I(&]N0VQI
M8VL]4V5T*"<S,T9&,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S8V,#`S,R!O;DUO=7-E3W9E<CU6:65W*"<V
M-C`P,S,G*2!O;D-L:6-K/5-E="@G-C8P,#,S)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C,S,S,@;VY-;W5S
M94]V97(]5FEE=R@G-C8S,S,S)RD@;VY#;&EC:SU3970H)S8V,S,S,R<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M-C8V-C,S(&]N36]U<V5/=F5R/59I97<H)S8V-C8S,R<I(&]N0VQI8VL]4V5T
M*"<V-C8V,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S8V.3DS,R!O;DUO=7-E3W9E<CU6:65W*"<V-CDY,S,G
M*2!O;D-L:6-K/5-E="@G-C8Y.3,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D-#,S,@;VY-;W5S94]V97(]
M5FEE=R@G-C9#0S,S)RD@;VY#;&EC:SU3970H)S8V0T,S,R<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C9&1C,S
M(&]N36]U<V5/=F5R/59I97<H)S8V1D8S,R<I(&]N0VQI8VL]4V5T*"<V-D9&
M,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/"]T<CX-
M"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G
M,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8V-C8V(&]N36]U
M<V5/=F5R/59I97<H)S8V-C8V-B<I(&]N0VQI8VL]4V5T*"<V-C8V-C8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E
M="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,P,#`P-C8@;VY-;W5S94]V97(]5FEE=R@G,#`P,#8V
M)RD@;VY#;&EC:SU3970H)S`P,#`V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`S,S8V(&]N36]U<V5/=F5R
M/59I97<H)S`P,S,V-B<I(&]N0VQI8VL]4V5T*"<P,#,S-C8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P-C8V
M-B!O;DUO=7-E3W9E<CU6:65W*"<P,#8V-C8G*2!O;D-L:6-K/5-E="@G,#`V
M-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,P,#DY-C8@;VY-;W5S94]V97(]5FEE=R@G,#`Y.38V)RD@;VY#
M;&EC:SU3970H)S`P.3DV-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!#0S8V(&]N36]U<V5/=F5R/59I97<H
M)S`P0T,V-B<I(&]N0VQI8VL]4V5T*"<P,$-#-C8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P1D8V-B!O;DUO
M=7-E3W9E<CU6:65W*"<P,$9&-C8G*2!O;D-L:6-K/5-E="@G,#!&1C8V)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,S,S`P-C8@;VY-;W5S94]V97(]5FEE=R@G,S,P,#8V)RD@;VY#;&EC:SU3
M970H)S,S,#`V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC,S,S,S8V(&]N36]U<V5/=F5R/59I97<H)S,S,S,V
M-B<I(&]N0VQI8VL]4V5T*"<S,S,S-C8G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S-C8V-B!O;DUO=7-E3W9E
M<CU6:65W*"<S,S8V-C8G*2!O;D-L:6-K/5-E="@G,S,V-C8V)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,SDY
M-C8@;VY-;W5S94]V97(]5FEE=R@G,S,Y.38V)RD@;VY#;&EC:SU3970H)S,S
M.3DV-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC,S-#0S8V(&]N36]U<V5/=F5R/59I97<H)S,S0T,V-B<I(&]N
M0VQI8VL]4V5T*"<S,T-#-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S1D8V-B!O;DUO=7-E3W9E<CU6:65W
M*"<S,T9&-C8G*2!O;D-L:6-K/5-E="@G,S-&1C8V)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C`P-C8@;VY-
M;W5S94]V97(]5FEE=R@G-C8P,#8V)RD@;VY#;&EC:SU3970H)S8V,#`V-B<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC-C8S,S8V(&]N36]U<V5/=F5R/59I97<H)S8V,S,V-B<I(&]N0VQI8VL]
M4V5T*"<V-C,S-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S8V-C8V-B!O;DUO=7-E3W9E<CU6:65W*"<V-C8V
M-C8G*2!O;D-L:6-K/5-E="@G-C8V-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-CDY-C8@;VY-;W5S94]V
M97(]5FEE=R@G-C8Y.38V)RD@;VY#;&EC:SU3970H)S8V.3DV-B<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C9#
M0S8V(&]N36]U<V5/=F5R/59I97<H)S8V0T,V-B<I(&]N0VQI8VL]4V5T*"<V
M-D-#-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S8V1D8V-B!O;DUO=7-E3W9E<CU6:65W*"<V-D9&-C8G*2!O
M;D-L:6-K/5-E="@G-C9&1C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N
M36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](SDY.3DY.2!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY.3DG*2!O;D-L:6-K
M/5-E="@G.3DY.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P
M,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#DY(&]N36]U<V5/
M=F5R/59I97<H)S`P,#`Y.2<I(&]N0VQI8VL]4V5T*"<P,#`P.3DG*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P
M,S,Y.2!O;DUO=7-E3W9E<CU6:65W*"<P,#,S.3DG*2!O;D-L:6-K/5-E="@G
M,#`S,SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,P,#8V.3D@;VY-;W5S94]V97(]5FEE=R@G,#`V-CDY)RD@
M;VY#;&EC:SU3970H)S`P-C8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`Y.3DY(&]N36]U<V5/=F5R/59I
M97<H)S`P.3DY.2<I(&]N0VQI8VL]4V5T*"<P,#DY.3DG*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P0T,Y.2!O
M;DUO=7-E3W9E<CU6:65W*"<P,$-#.3DG*2!O;D-L:6-K/5-E="@G,#!#0SDY
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,P,$9&.3D@;VY-;W5S94]V97(]5FEE=R@G,#!&1CDY)RD@;VY#;&EC
M:SU3970H)S`P1D8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,S,P,#DY(&]N36]U<V5/=F5R/59I97<H)S,S
M,#`Y.2<I(&]N0VQI8VL]4V5T*"<S,S`P.3DG*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,S,Y.2!O;DUO=7-E
M3W9E<CU6:65W*"<S,S,S.3DG*2!O;D-L:6-K/5-E="@G,S,S,SDY)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S
M,S8V.3D@;VY-;W5S94]V97(]5FEE=R@G,S,V-CDY)RD@;VY#;&EC:SU3970H
M)S,S-C8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC,S,Y.3DY(&]N36]U<V5/=F5R/59I97<H)S,S.3DY.2<I
M(&]N0VQI8VL]4V5T*"<S,SDY.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S0T,Y.2!O;DUO=7-E3W9E<CU6
M:65W*"<S,T-#.3DG*2!O;D-L:6-K/5-E="@G,S-#0SDY)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,T9&.3D@
M;VY-;W5S94]V97(]5FEE=R@G,S-&1CDY)RD@;VY#;&EC:SU3970H)S,S1D8Y
M.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC-C8P,#DY(&]N36]U<V5/=F5R/59I97<H)S8V,#`Y.2<I(&]N0VQI
M8VL]4V5T*"<V-C`P.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S8V,S,Y.2!O;DUO=7-E3W9E<CU6:65W*"<V
M-C,S.3DG*2!O;D-L:6-K/5-E="@G-C8S,SDY)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C8V.3D@;VY-;W5S
M94]V97(]5FEE=R@G-C8V-CDY)RD@;VY#;&EC:SU3970H)S8V-C8Y.2<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M-C8Y.3DY(&]N36]U<V5/=F5R/59I97<H)S8V.3DY.2<I(&]N0VQI8VL]4V5T
M*"<V-CDY.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S8V0T,Y.2!O;DUO=7-E3W9E<CU6:65W*"<V-D-#.3DG
M*2!O;D-L:6-K/5-E="@G-C9#0SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D9&.3D@;VY-;W5S94]V97(]
M5FEE=R@G-C9&1CDY)RD@;VY#;&EC:SU3970H)S8V1D8Y.2<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*/'1R/@T*/'1D(&)G
M8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L
M:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-#0T-#0T,@;VY-;W5S94]V97(]5FEE=R@G
M0T-#0T-#)RD@;VY#;&EC:SU3970H)T-#0T-#0R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U
M<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P,#!#0R!O;DUO=7-E3W9E<CU6:65W*"<P,#`P0T,G*2!O;D-L:6-K/5-E
M="@G,#`P,$-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,P,#,S0T,@;VY-;W5S94]V97(]5FEE=R@G,#`S,T-#
M)RD@;VY#;&EC:SU3970H)S`P,S-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`V-D-#(&]N36]U<V5/=F5R
M/59I97<H)S`P-C9#0R<I(&]N0VQI8VL]4V5T*"<P,#8V0T,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P.3E#
M0R!O;DUO=7-E3W9E<CU6:65W*"<P,#DY0T,G*2!O;D-L:6-K/5-E="@G,#`Y
M.4-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,P,$-#0T,@;VY-;W5S94]V97(]5FEE=R@G,#!#0T-#)RD@;VY#
M;&EC:SU3970H)S`P0T-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&1D-#(&]N36]U<V5/=F5R/59I97<H
M)S`P1D9#0R<I(&]N0VQI8VL]4V5T*"<P,$9&0T,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,#!#0R!O;DUO
M=7-E3W9E<CU6:65W*"<S,S`P0T,G*2!O;D-L:6-K/5-E="@G,S,P,$-#)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,S,S,S0T,@;VY-;W5S94]V97(]5FEE=R@G,S,S,T-#)RD@;VY#;&EC:SU3
M970H)S,S,S-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC,S,V-D-#(&]N36]U<V5/=F5R/59I97<H)S,S-C9#
M0R<I(&]N0VQI8VL]4V5T*"<S,S8V0T,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S.3E#0R!O;DUO=7-E3W9E
M<CU6:65W*"<S,SDY0T,G*2!O;D-L:6-K/5-E="@G,S,Y.4-#)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,T-#
M0T,@;VY-;W5S94]V97(]5FEE=R@G,S-#0T-#)RD@;VY#;&EC:SU3970H)S,S
M0T-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC,S-&1D-#(&]N36]U<V5/=F5R/59I97<H)S,S1D9#0R<I(&]N
M0VQI8VL]4V5T*"<S,T9&0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,#!#0R!O;DUO=7-E3W9E<CU6:65W
M*"<V-C`P0T,G*2!O;D-L:6-K/5-E="@G-C8P,$-#)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C,S0T,@;VY-
M;W5S94]V97(]5FEE=R@G-C8S,T-#)RD@;VY#;&EC:SU3970H)S8V,S-#0R<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC-C8V-D-#(&]N36]U<V5/=F5R/59I97<H)S8V-C9#0R<I(&]N0VQI8VL]
M4V5T*"<V-C8V0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S8V.3E#0R!O;DUO=7-E3W9E<CU6:65W*"<V-CDY
M0T,G*2!O;D-L:6-K/5-E="@G-C8Y.4-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D-#0T,@;VY-;W5S94]V
M97(]5FEE=R@G-C9#0T-#)RD@;VY#;&EC:SU3970H)S8V0T-#0R<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C9&
M1D-#(&]N36]U<V5/=F5R/59I97<H)S8V1D9#0R<I(&]N0VQI8VL]4V5T*"<V
M-D9&0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/"]T
M<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE
M=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D9&1D9&(&]N
M36]U<V5/=F5R/59I97<H)T9&1D9&1B<I(&]N0VQI8VL]4V5T*"=&1D9&1D8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K
M/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,#`P1D8@;VY-;W5S94]V97(]5FEE=R@G,#`P
M,$9&)RD@;VY#;&EC:SU3970H)S`P,#!&1B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`S,T9&(&]N36]U<V5/
M=F5R/59I97<H)S`P,S-&1B<I(&]N0VQI8VL]4V5T*"<P,#,S1D8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P
M-C9&1B!O;DUO=7-E3W9E<CU6:65W*"<P,#8V1D8G*2!O;D-L:6-K/5-E="@G
M,#`V-D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,P,#DY1D8@;VY-;W5S94]V97(]5FEE=R@G,#`Y.49&)RD@
M;VY#;&EC:SU3970H)S`P.3E&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!#0T9&(&]N36]U<V5/=F5R/59I
M97<H)S`P0T-&1B<I(&]N0VQI8VL]4V5T*"<P,$-#1D8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P1D9&1B!O
M;DUO=7-E3W9E<CU6:65W*"<P,$9&1D8G*2!O;D-L:6-K/5-E="@G,#!&1D9&
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,S,S`P1D8@;VY-;W5S94]V97(]5FEE=R@G,S,P,$9&)RD@;VY#;&EC
M:SU3970H)S,S,#!&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,S,S,T9&(&]N36]U<V5/=F5R/59I97<H)S,S
M,S-&1B<I(&]N0VQI8VL]4V5T*"<S,S,S1D8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S-C9&1B!O;DUO=7-E
M3W9E<CU6:65W*"<S,S8V1D8G*2!O;D-L:6-K/5-E="@G,S,V-D9&)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S
M,SDY1D8@;VY-;W5S94]V97(]5FEE=R@G,S,Y.49&)RD@;VY#;&EC:SU3970H
M)S,S.3E&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC,S-#0T9&(&]N36]U<V5/=F5R/59I97<H)S,S0T-&1B<I
M(&]N0VQI8VL]4V5T*"<S,T-#1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S1D9&1B!O;DUO=7-E3W9E<CU6
M:65W*"<S,T9&1D8G*2!O;D-L:6-K/5-E="@G,S-&1D9&)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C`P1D8@
M;VY-;W5S94]V97(]5FEE=R@G-C8P,$9&)RD@;VY#;&EC:SU3970H)S8V,#!&
M1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC-C8S,T9&(&]N36]U<V5/=F5R/59I97<H)S8V,S-&1B<I(&]N0VQI
M8VL]4V5T*"<V-C,S1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S8V-C9&1B!O;DUO=7-E3W9E<CU6:65W*"<V
M-C8V1D8G*2!O;D-L:6-K/5-E="@G-C8V-D9&)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-CDY1D8@;VY-;W5S
M94]V97(]5FEE=R@G-C8Y.49&)RD@;VY#;&EC:SU3970H)S8V.3E&1B<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M-C9#0T9&(&]N36]U<V5/=F5R/59I97<H)S8V0T-&1B<I(&]N0VQI8VL]4V5T
M*"<V-D-#1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S8V1D9&1B!O;DUO=7-E3W9E<CU6:65W*"<V-D9&1D8G
M*2!O;D-L:6-K/5-E="@G-C9&1D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C;VQO<CTC,#`P,#`P
M(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P
M,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](T9&,#`P,"!O;DUO=7-E3W9E<CU6:65W*"=&1C`P,#`G*2!O;D-L
M:6-K/5-E="@G1D8P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G
M,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DP,#`P(&]N36]U
M<V5/=F5R/59I97<H)SDY,#`P,"<I(&]N0VQI8VL]4V5T*"<Y.3`P,#`G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(SDY,S,P,"!O;DUO=7-E3W9E<CU6:65W*"<Y.3,S,#`G*2!O;D-L:6-K/5-E
M="@G.3DS,S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,Y.38V,#`@;VY-;W5S94]V97(]5FEE=R@G.3DV-C`P
M)RD@;VY#;&EC:SU3970H)SDY-C8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DY.3`P(&]N36]U<V5/=F5R
M/59I97<H)SDY.3DP,"<I(&]N0VQI8VL]4V5T*"<Y.3DY,#`G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY0T,P
M,"!O;DUO=7-E3W9E<CU6:65W*"<Y.4-#,#`G*2!O;D-L:6-K/5-E="@G.3E#
M0S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,Y.49&,#`@;VY-;W5S94]V97(]5FEE=R@G.3E&1C`P)RD@;VY#
M;&EC:SU3970H)SDY1D8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,P,#`P(&]N36]U<V5/=F5R/59I97<H
M)T-#,#`P,"<I(&]N0VQI8VL]4V5T*"=#0S`P,#`G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#,S,P,"!O;DUO
M=7-E3W9E<CU6:65W*"=#0S,S,#`G*2!O;D-L:6-K/5-E="@G0T,S,S`P)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-#0S8V,#`@;VY-;W5S94]V97(]5FEE=R@G0T,V-C`P)RD@;VY#;&EC:SU3
M970H)T-#-C8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC0T,Y.3`P(&]N36]U<V5/=F5R/59I97<H)T-#.3DP
M,"<I(&]N0VQI8VL]4V5T*"=#0SDY,#`G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#0T,P,"!O;DUO=7-E3W9E
M<CU6:65W*"=#0T-#,#`G*2!O;D-L:6-K/5-E="@G0T-#0S`P)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0T9&
M,#`@;VY-;W5S94]V97(]5FEE=R@G0T-&1C`P)RD@;VY#;&EC:SU3970H)T-#
M1D8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC1D8P,#`P(&]N36]U<V5/=F5R/59I97<H)T9&,#`P,"<I(&]N
M0VQI8VL]4V5T*"=&1C`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,S,P,"!O;DUO=7-E3W9E<CU6:65W
M*"=&1C,S,#`G*2!O;D-L:6-K/5-E="@G1D8S,S`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C8V,#`@;VY-
M;W5S94]V97(]5FEE=R@G1D8V-C`P)RD@;VY#;&EC:SU3970H)T9&-C8P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC1D8Y.3`P(&]N36]U<V5/=F5R/59I97<H)T9&.3DP,"<I(&]N0VQI8VL]
M4V5T*"=&1CDY,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](T9&0T,P,"!O;DUO=7-E3W9E<CU6:65W*"=&1D-#
M,#`G*2!O;D-L:6-K/5-E="@G1D9#0S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D9&,#`@;VY-;W5S94]V
M97(]5FEE=R@G1D9&1C`P)RD@;VY#;&EC:SU3970H)T9&1D8P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*/'1R/@T*/'1D
M(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O
M;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$9&,#`@;VY-;W5S94]V97(]5FEE
M=R@G,#!&1C`P)RD@;VY#;&EC:SU3970H)S`P1D8P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N
M36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](SDY,#`S,R!O;DUO=7-E3W9E<CU6:65W*"<Y.3`P,S,G*2!O;D-L:6-K
M/5-E="@G.3DP,#,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,Y.3,S,S,@;VY-;W5S94]V97(]5FEE=R@G.3DS
M,S,S)RD@;VY#;&EC:SU3970H)SDY,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DV-C,S(&]N36]U<V5/
M=F5R/59I97<H)SDY-C8S,R<I(&]N0VQI8VL]4V5T*"<Y.38V,S,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY
M.3DS,R!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY,S,G*2!O;D-L:6-K/5-E="@G
M.3DY.3,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,Y.4-#,S,@;VY-;W5S94]V97(]5FEE=R@G.3E#0S,S)RD@
M;VY#;&EC:SU3970H)SDY0T,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E&1C,S(&]N36]U<V5/=F5R/59I
M97<H)SDY1D8S,R<I(&]N0VQI8VL]4V5T*"<Y.49&,S,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#,#`S,R!O
M;DUO=7-E3W9E<CU6:65W*"=#0S`P,S,G*2!O;D-L:6-K/5-E="@G0T,P,#,S
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-#0S,S,S,@;VY-;W5S94]V97(]5FEE=R@G0T,S,S,S)RD@;VY#;&EC
M:SU3970H)T-#,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC0T,V-C,S(&]N36]U<V5/=F5R/59I97<H)T-#
M-C8S,R<I(&]N0VQI8VL]4V5T*"=#0S8V,S,G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#.3DS,R!O;DUO=7-E
M3W9E<CU6:65W*"=#0SDY,S,G*2!O;D-L:6-K/5-E="@G0T,Y.3,S)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#
M0T-#,S,@;VY-;W5S94]V97(]5FEE=R@G0T-#0S,S)RD@;VY#;&EC:SU3970H
M)T-#0T,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC0T-&1C,S(&]N36]U<V5/=F5R/59I97<H)T-#1D8S,R<I
M(&]N0VQI8VL]4V5T*"=#0T9&,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#`S,R!O;DUO=7-E3W9E<CU6
M:65W*"=&1C`P,S,G*2!O;D-L:6-K/5-E="@G1D8P,#,S)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C,S,S,@
M;VY-;W5S94]V97(]5FEE=R@G1D8S,S,S)RD@;VY#;&EC:SU3970H)T9&,S,S
M,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC1D8V-C,S(&]N36]U<V5/=F5R/59I97<H)T9&-C8S,R<I(&]N0VQI
M8VL]4V5T*"=&1C8V,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](T9&.3DS,R!O;DUO=7-E3W9E<CU6:65W*"=&
M1CDY,S,G*2!O;D-L:6-K/5-E="@G1D8Y.3,S)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D-#,S,@;VY-;W5S
M94]V97(]5FEE=R@G1D9#0S,S)RD@;VY#;&EC:SU3970H)T9&0T,S,R<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M1D9&1C,S(&]N36]U<V5/=F5R/59I97<H)T9&1D8S,R<I(&]N0VQI8VL]4V5T
M*"=&1D9&,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]
M5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,$9&
M(&]N36]U<V5/=F5R/59I97<H)S`P,#!&1B<I(&]N0VQI8VL]4V5T*"<P,#`P
M1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L
M:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3`P-C8@;VY-;W5S94]V97(]5FEE=R@G
M.3DP,#8V)RD@;VY#;&EC:SU3970H)SDY,#`V-B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DS,S8V(&]N36]U
M<V5/=F5R/59I97<H)SDY,S,V-B<I(&]N0VQI8VL]4V5T*"<Y.3,S-C8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(SDY-C8V-B!O;DUO=7-E3W9E<CU6:65W*"<Y.38V-C8G*2!O;D-L:6-K/5-E
M="@G.3DV-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,Y.3DY-C8@;VY-;W5S94]V97(]5FEE=R@G.3DY.38V
M)RD@;VY#;&EC:SU3970H)SDY.3DV-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E#0S8V(&]N36]U<V5/=F5R
M/59I97<H)SDY0T,V-B<I(&]N0VQI8VL]4V5T*"<Y.4-#-C8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY1D8V
M-B!O;DUO=7-E3W9E<CU6:65W*"<Y.49&-C8G*2!O;D-L:6-K/5-E="@G.3E&
M1C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-#0S`P-C8@;VY-;W5S94]V97(]5FEE=R@G0T,P,#8V)RD@;VY#
M;&EC:SU3970H)T-#,#`V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,S,S8V(&]N36]U<V5/=F5R/59I97<H
M)T-#,S,V-B<I(&]N0VQI8VL]4V5T*"=#0S,S-C8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#-C8V-B!O;DUO
M=7-E3W9E<CU6:65W*"=#0S8V-C8G*2!O;D-L:6-K/5-E="@G0T,V-C8V)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-#0SDY-C8@;VY-;W5S94]V97(]5FEE=R@G0T,Y.38V)RD@;VY#;&EC:SU3
M970H)T-#.3DV-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC0T-#0S8V(&]N36]U<V5/=F5R/59I97<H)T-#0T,V
M-B<I(&]N0VQI8VL]4V5T*"=#0T-#-C8G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#1D8V-B!O;DUO=7-E3W9E
M<CU6:65W*"=#0T9&-C8G*2!O;D-L:6-K/5-E="@G0T-&1C8V)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C`P
M-C8@;VY-;W5S94]V97(]5FEE=R@G1D8P,#8V)RD@;VY#;&EC:SU3970H)T9&
M,#`V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC1D8S,S8V(&]N36]U<V5/=F5R/59I97<H)T9&,S,V-B<I(&]N
M0VQI8VL]4V5T*"=&1C,S-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&-C8V-B!O;DUO=7-E3W9E<CU6:65W
M*"=&1C8V-C8G*2!O;D-L:6-K/5-E="@G1D8V-C8V)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1CDY-C8@;VY-
M;W5S94]V97(]5FEE=R@G1D8Y.38V)RD@;VY#;&EC:SU3970H)T9&.3DV-B<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC1D9#0S8V(&]N36]U<V5/=F5R/59I97<H)T9&0T,V-B<I(&]N0VQI8VL]
M4V5T*"=&1D-#-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](T9&1D8V-B!O;DUO=7-E3W9E<CU6:65W*"=&1D9&
M-C8G*2!O;D-L:6-K/5-E="@G1D9&1C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C;VQO<CTC,#`P
M,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P
M,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](T9&1D8P,"!O;DUO=7-E3W9E<CU6:65W*"=&1D9&,#`G*2!O
M;D-L:6-K/5-E="@G1D9&1C`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE
M=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DP,#DY(&]N
M36]U<V5/=F5R/59I97<H)SDY,#`Y.2<I(&]N0VQI8VL]4V5T*"<Y.3`P.3DG
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](SDY,S,Y.2!O;DUO=7-E3W9E<CU6:65W*"<Y.3,S.3DG*2!O;D-L:6-K
M/5-E="@G.3DS,SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,Y.38V.3D@;VY-;W5S94]V97(]5FEE=R@G.3DV
M-CDY)RD@;VY#;&EC:SU3970H)SDY-C8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DY.3DY(&]N36]U<V5/
M=F5R/59I97<H)SDY.3DY.2<I(&]N0VQI8VL]4V5T*"<Y.3DY.3DG*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY
M0T,Y.2!O;DUO=7-E3W9E<CU6:65W*"<Y.4-#.3DG*2!O;D-L:6-K/5-E="@G
M.3E#0SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,Y.49&.3D@;VY-;W5S94]V97(]5FEE=R@G.3E&1CDY)RD@
M;VY#;&EC:SU3970H)SDY1D8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,P,#DY(&]N36]U<V5/=F5R/59I
M97<H)T-#,#`Y.2<I(&]N0VQI8VL]4V5T*"=#0S`P.3DG*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#,S,Y.2!O
M;DUO=7-E3W9E<CU6:65W*"=#0S,S.3DG*2!O;D-L:6-K/5-E="@G0T,S,SDY
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-#0S8V.3D@;VY-;W5S94]V97(]5FEE=R@G0T,V-CDY)RD@;VY#;&EC
M:SU3970H)T-#-C8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC0T,Y.3DY(&]N36]U<V5/=F5R/59I97<H)T-#
M.3DY.2<I(&]N0VQI8VL]4V5T*"=#0SDY.3DG*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#0T,Y.2!O;DUO=7-E
M3W9E<CU6:65W*"=#0T-#.3DG*2!O;D-L:6-K/5-E="@G0T-#0SDY)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#
M0T9&.3D@;VY-;W5S94]V97(]5FEE=R@G0T-&1CDY)RD@;VY#;&EC:SU3970H
M)T-#1D8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC1D8P,#DY(&]N36]U<V5/=F5R/59I97<H)T9&,#`Y.2<I
M(&]N0VQI8VL]4V5T*"=&1C`P.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,S,Y.2!O;DUO=7-E3W9E<CU6
M:65W*"=&1C,S.3DG*2!O;D-L:6-K/5-E="@G1D8S,SDY)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C8V.3D@
M;VY-;W5S94]V97(]5FEE=R@G1D8V-CDY)RD@;VY#;&EC:SU3970H)T9&-C8Y
M.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC1D8Y.3DY(&]N36]U<V5/=F5R/59I97<H)T9&.3DY.2<I(&]N0VQI
M8VL]4V5T*"=&1CDY.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](T9&0T,Y.2!O;DUO=7-E3W9E<CU6:65W*"=&
M1D-#.3DG*2!O;D-L:6-K/5-E="@G1D9#0SDY)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D9&.3D@;VY-;W5S
M94]V97(]5FEE=R@G1D9&1CDY)RD@;VY#;&EC:SU3970H)T9&1D8Y.2<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*/'1R/@T*
M/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G
M*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$9&1D8@;VY-;W5S94]V97(]
M5FEE=R@G,#!&1D9&)RD@;VY#;&EC:SU3970H)S`P1D9&1B<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P
M(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P
M,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](SDY,#!#0R!O;DUO=7-E3W9E<CU6:65W*"<Y.3`P0T,G*2!O;D-L
M:6-K/5-E="@G.3DP,$-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3,S0T,@;VY-;W5S94]V97(]5FEE=R@G
M.3DS,T-#)RD@;VY#;&EC:SU3970H)SDY,S-#0R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DV-D-#(&]N36]U
M<V5/=F5R/59I97<H)SDY-C9#0R<I(&]N0VQI8VL]4V5T*"<Y.38V0T,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(SDY.3E#0R!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY0T,G*2!O;D-L:6-K/5-E
M="@G.3DY.4-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,Y.4-#0T,@;VY-;W5S94]V97(]5FEE=R@G.3E#0T-#
M)RD@;VY#;&EC:SU3970H)SDY0T-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E&1D-#(&]N36]U<V5/=F5R
M/59I97<H)SDY1D9#0R<I(&]N0VQI8VL]4V5T*"<Y.49&0T,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#,#!#
M0R!O;DUO=7-E3W9E<CU6:65W*"=#0S`P0T,G*2!O;D-L:6-K/5-E="@G0T,P
M,$-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-#0S,S0T,@;VY-;W5S94]V97(]5FEE=R@G0T,S,T-#)RD@;VY#
M;&EC:SU3970H)T-#,S-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,V-D-#(&]N36]U<V5/=F5R/59I97<H
M)T-#-C9#0R<I(&]N0VQI8VL]4V5T*"=#0S8V0T,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#.3E#0R!O;DUO
M=7-E3W9E<CU6:65W*"=#0SDY0T,G*2!O;D-L:6-K/5-E="@G0T,Y.4-#)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-#0T-#0T,@;VY-;W5S94]V97(]5FEE=R@G0T-#0T-#)RD@;VY#;&EC:SU3
M970H)T-#0T-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC0T-&1D-#(&]N36]U<V5/=F5R/59I97<H)T-#1D9#
M0R<I(&]N0VQI8VL]4V5T*"=#0T9&0T,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#!#0R!O;DUO=7-E3W9E
M<CU6:65W*"=&1C`P0T,G*2!O;D-L:6-K/5-E="@G1D8P,$-#)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C,S
M0T,@;VY-;W5S94]V97(]5FEE=R@G1D8S,T-#)RD@;VY#;&EC:SU3970H)T9&
M,S-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC1D8V-D-#(&]N36]U<V5/=F5R/59I97<H)T9&-C9#0R<I(&]N
M0VQI8VL]4V5T*"=&1C8V0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&.3E#0R!O;DUO=7-E3W9E<CU6:65W
M*"=&1CDY0T,G*2!O;D-L:6-K/5-E="@G1D8Y.4-#)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D-#0T,@;VY-
M;W5S94]V97(]5FEE=R@G1D9#0T-#)RD@;VY#;&EC:SU3970H)T9&0T-#0R<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC1D9&1D-#(&]N36]U<V5/=F5R/59I97<H)T9&1D9#0R<I(&]N0VQI8VL]
M4V5T*"=&1D9&0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V
M97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8P
M,$9&(&]N36]U<V5/=F5R/59I97<H)T9&,#!&1B<I(&]N0VQI8VL]4V5T*"=&
M1C`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O
M;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3`P1D8@;VY-;W5S94]V97(]5FEE
M=R@G.3DP,$9&)RD@;VY#;&EC:SU3970H)SDY,#!&1B<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DS,T9&(&]N
M36]U<V5/=F5R/59I97<H)SDY,S-&1B<I(&]N0VQI8VL]4V5T*"<Y.3,S1D8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](SDY-C9&1B!O;DUO=7-E3W9E<CU6:65W*"<Y.38V1D8G*2!O;D-L:6-K
M/5-E="@G.3DV-D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,Y.3DY1D8@;VY-;W5S94]V97(]5FEE=R@G.3DY
M.49&)RD@;VY#;&EC:SU3970H)SDY.3E&1B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E#0T9&(&]N36]U<V5/
M=F5R/59I97<H)SDY0T-&1B<I(&]N0VQI8VL]4V5T*"<Y.4-#1D8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY
M1D9&1B!O;DUO=7-E3W9E<CU6:65W*"<Y.49&1D8G*2!O;D-L:6-K/5-E="@G
M.3E&1D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-#0S`P1D8@;VY-;W5S94]V97(]5FEE=R@G0T,P,$9&)RD@
M;VY#;&EC:SU3970H)T-#,#!&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,S,T9&(&]N36]U<V5/=F5R/59I
M97<H)T-#,S-&1B<I(&]N0VQI8VL]4V5T*"=#0S,S1D8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#-C9&1B!O
M;DUO=7-E3W9E<CU6:65W*"=#0S8V1D8G*2!O;D-L:6-K/5-E="@G0T,V-D9&
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-#0SDY1D8@;VY-;W5S94]V97(]5FEE=R@G0T,Y.49&)RD@;VY#;&EC
M:SU3970H)T-#.3E&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC0T-#0T9&(&]N36]U<V5/=F5R/59I97<H)T-#
M0T-&1B<I(&]N0VQI8VL]4V5T*"=#0T-#1D8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#1D9&1B!O;DUO=7-E
M3W9E<CU6:65W*"=#0T9&1D8G*2!O;D-L:6-K/5-E="@G0T-&1D9&)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&
M1C`P1D8@;VY-;W5S94]V97(]5FEE=R@G1D8P,$9&)RD@;VY#;&EC:SU3970H
M)T9&,#!&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC1D8S,T9&(&]N36]U<V5/=F5R/59I97<H)T9&,S-&1B<I
M(&]N0VQI8VL]4V5T*"=&1C,S1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&-C9&1B!O;DUO=7-E3W9E<CU6
M:65W*"=&1C8V1D8G*2!O;D-L:6-K/5-E="@G1D8V-D9&)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1CDY1D8@
M;VY-;W5S94]V97(]5FEE=R@G1D8Y.49&)RD@;VY#;&EC:SU3970H)T9&.3E&
M1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC1D9#0T9&(&]N36]U<V5/=F5R/59I97<H)T9&0T-&1B<I(&]N0VQI
M8VL]4V5T*"=&1D-#1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](T9&1D9&1B!O;DUO=7-E3W9E<CU6:65W*"=&
M1D9&1D8G*2!O;D-L:6-K/5-E="@G1D9&1D9&)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\+W1A8FQE/@T*#0H\+V)O9'D^
M/"]H=&UL/@T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+P``````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#`W`#`R,C4W,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?86)O=70N9VEF````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,C<`,3`T,3<S-C,P
M,#<`,#(U,#,V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2```"
M+HR/B<#M#TQ4=$Z:K&);[GMH6.8M'!F`DIJ69M=FK/BB\^R&>#R&>6^!"$\]
M2@$`.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N
M7V-E;G1E<BYG:68``````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`U`#$P-#$W,S8S,#`W`#`R-C,U,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@```AR,CZG+[0&BG/-9
M2.MUN8/->1_(B!19BNC*MD8!`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]A;&EG;E]J=7-T:69Y+F=I
M9@`````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#$P-0`Q,#0Q-S,V,S`P-P`P,C8U-C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`(`!````
M`/___R'Y!`$```$`+``````2`!(```(<C(^IR^T!HISS/8JE=3GOUF$?$U+C
M4E;GRK9'`0`[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]I;6%G97,O961?86QI9VY?;&5F="YG:68`````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q
M,#4`,3`T,3<S-C,P,#<`,#(V,#(T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y81(`$@"``0````#___\A^00!```!
M`"P`````$@`2```"'(R/J<OM`:*<\SU*K8:X;]9)WQ5F8U("Y\JV2`$`.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7V%L:6=N7W)I9VAT+F=I9@``````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`T`#$P-#$W,S8S
M,#`W`#`R-C(P-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@``
M`AN,CZG+[0&BG//90^EMN8-M>1&XB!K)B>C*M@4`.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]B;&%N
M:RYG:68````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`W,``Q,#0Q-S,V,S`P-P`P,C4P,3``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA$@`2`(```/___P```"'Y!`$`````+``````2`!(```(/A(^IR^T/HYRT
MVHNSWIP7`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8VAA<FUA<"YG:68`````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`R,3<`,3`T,3<S-C,P,#<`,#(U,S,W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y81(`$@"B!P"`
M`(#`P,"`@(#_`````/\```#_______\A^00!```'`"P`````$@`2```#5'BZ
MW-XB/A>#E;.&P:^@QL4-@A5\C!!ZI648Z-&^I@L+Q5(21$"_`D`D)S,19I&@
MD+@[]GP1@!"G:%F.T.A09^W=D@4BU_0-3V0EF/G,%;/?\#@\`0`[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V5D7V-O;&]R7V)G+F=I9@``````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,C8U`#$P-#$W,S8S,#`W`#`R-34Q-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$2`!(`LPL``(0``'L`A(2$>WM[
M_P#_`/___P``__\```#_____````____````````````````(?D$`0``"P`L
M`````!(`$@``!&)PR4FKE4K=K?.VGO=-6J((VEB:RY"EU;HH@U`/.(XM28()
MAN"@0!Q@>B1@4$`L&'<2G&UZ$U`TM=-A*P@``D^2J[4]#+Z`,"DJF+H_`X1\
M0*BK*P(Y0E`GW"E25#8CA(44$0`[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM
M86=E<R]E9%]C;VQO<E]F9RYG:68`````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(U,P`Q,#0Q-S,V
M,S`P-P`P,C4U,38`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA$@`2`+,*``"$``![`(2$A'M[>_\`_P#___\``/__
M````_P```/___P```````````````````"'Y!`$```H`+``````2`!(```18
M4,E)*TTX:RO3Q!^G>!TYBI>)IJL%#G`<N]Y@W$.A#[1BWP)=@5=Y"00P))(R
MT`@.4$$`$"!R!M##@`JP6@9'L%*`&B#.`X+:6Q&<$0(U@<T4@^^MO%X1`0`[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8V]P
M>2YG:68`````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-38`,3`T,3<S-C,P,#<`,#(T-S`P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81(`$@"1`P```(````#_______\A^00!```#`"P`````$@`2```"/YR/
MJ<L6#]L)HHHG![4TR-X!XJAL%F`)8@(^Z*DB9H4^*NE<T)O&>5J#4``388`'
M;`0AO@7RI!Q)B9FJ]8HH```[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V-U<W1O;2YG:68`````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,3`S`#$P-#$W,S8S,#`W`#`R-3(S,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$2`!(`@`$`
M````____(?D$`0```0`L`````!(`$@```AJ,CZG+[0_C`D`&2B6N<=O\<=9X
MB9U)INIJ%``[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VEM86=E<R]E9%]C=70N9VEF````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#$S,P`Q,#0Q-S,V,S`P-P`P,C0U,30`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$@`2`)$"````@````/___P``
M`"'Y!`$```(`+``````2`!(```(LE(^IRQOW&IS21'%E>+O.7&U@Z"%``)1&
M"K15RZY-*L3U+-/THJ\[XU()AP4`.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I
M;6%G97,O961?9&5L971E+F=I9@``````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,S(`,3`T,3<S
M-C,P,#<`,#(U,38R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y81(`$@"1``#___\```#___\````A^00%%``"`"P`
M````$@`2```"*Y2/J<OM%@)@<9Y84];8BKUTG]=@H",^GTF&V<E)EZRD5PO!
M8XBK5.\+'@H`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O
M<FUA=%]B;VQD+F=I9@```````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3$R`#$P-#$W,S8S,#`W`#`R-C(P
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@```B&,CZG+[?^`
MG#+6,%W&E^WM45T(&.#RC4I:DB($Q_),,P4`.P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?:71A;&EC
M+F=I9@`````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#$Q-0`Q,#0Q-S,V,S`P-P`P,C8U,S8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA$@`2`)$#
M`'M[>X2$A````/___R'Y!`$```,`+``````2`!(```(>G(^IR^T/C9@SCADL
MJ'8"S44>*%B7\$$49;;N"T<%`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]I;6%G97,O961?9F]R;6%T7W-T<FEK92YG:68`````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`Q,38`,3`T,3<S-C,P,#<`,#(V-3<S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y81(`$@"``0````#___\A^00!
M```!`"P`````$@`2```")8R/J<OM"B((T\5S;36;2?Q062.59O@]6THBH[=V
MRU2&]HWG3`$`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7V9O<FUA=%]S=6(N9VEF````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3$V`#$P-#$W
M,S8S,#`W`#`R-C`V,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$2`!(`D0(```"`````____````(?D$`0```@`L
M`````!(`$@```A^4CZG+[>]",!(*6>V=&O.750"@(61Y:JDZENX+QTT!`#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F
M;W)M871?<W5P+F=I9@`````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$Q-0`Q,#0Q-S,V,S`P-P`P,C8Q
M,#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA$@`2`)$"`(```````/___P```"'Y!`$```(`+``````2`!(```(>
ME(^IRVT`'(L2T?JPA2P$XV%>J)'B>(*?QK;N"[<%`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9F]R;6%T7W5N9&5R
M;&EN92YG:68`````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`Q,C4`,3`T,3<S-C,P,#<`,#(W,C4W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y81(`$@"1
M`@![>WL```#___\````A^00!```"`"P`````$@`2```")I2/J<OM_X(,8M(F
M3W:[7OQU3"<NY#>&J!D``E"R$T0CUEWG.ET``#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7VAE;'`N9VEF````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,3`V`#$P-#$W,S8S,#`W`#`R-#8U,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$2`!(`@`$`````____(?D$
M`0```0`L`````!(`$@```AV,CZG+[0\#F"!.<U_.4=;.0:'X=>8Q:N7)MNY2
M```[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R]E9%]H<BYG:68`````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$P-@`Q,#0Q
M-S,V,S`P-P`P,C0S,S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA$@`2`)$"`#,S,YF9F?___P```"'Y!`$```(`
M+``````2`!(```(7E(^IR^T/HYRT@8NS/J'[#U;B2);FJ10`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?
M:'1M;"YG:68`````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,3,`,3`T,3<S-C,P,#<`,#(T
M-C8S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2```"(HR/J<OM
M#P$P\M5S5\93;?1]2=AY)7A2*<HZEPC%\DS71P$`.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VEM86=E+F=I9@``
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,C(T`#$P-#$W,S8S,#`W`#`R-3`P-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$2`!(`
MH@<``(``@```@(``@("`__\``/__````____(?D$`0``!P`L`````!(`$@``
M`UEXNMS^4)E!JZ6&C2"X[V"V#()AGF@@*EM6'"\A'Z56OOA!**K6OP.8L#:Z
M'8*40K`WZ@592"*K]#P>*4Q6H'HAK8X"P$%,'K=\@+1Z+05_WITO:CZ/V.^0
M!``[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]I;F1E;G1?;&5S<RYG:68`````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#$R-P`Q,#0Q-S,V,S`P-P`P,C8R,S,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA$@`2`)$"````A````/__
M_P```"'Y!`$```(`+``````2`!(```(HE(^I&>NO@FRS2H@%0+8>L!W=9(!F
M5H9&MZ@"BV+>>,7+W-CZNO=0`0`[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?:6YD96YT7VUO<F4N9VEF````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,C<`,3`T
M,3<S-C,P,#<`,#(V,C(W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y81(`$@"1`@```(0```#___\````A^00!```"
M`"P`````$@`2```"*)2/J1GKKX)LLTJ(!4"V(K`9W62`9G:`1[>$HH5FWGC%
MR]S8NKCW4`$`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D
M7VMI;&QW;W)D+F=I9@```````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C,R`#$P-#$W,S8S,#`W`#`R
M-34U,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$2`!(`P@8```````#__P``34U-JJJJ_^C-________(?D$`0H`
M!P`L`0```!``$@```U]XNMQ,,$I'C+V6#!5`_QZ0&9N(78$UK`/H`D5L%$-H
M>,9G%3.>=K<";#:KW5PYGM('\_!@,J&(:1%<!+34R0+`6J4OG;6WJ&`*7K+"
M?+W2RK&X/`8HUVH`?!Y0=_@5"0`[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]L969T7W1O7W)I
M9VAT+F=I9@`````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#$S,0`Q,#0Q-S,V,S`P-P`P,C8U-3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA$@`2
M`)$"``0"A````/___P```"'Y!`$```(`+``````2`!(```(JE(^IR^T/4Y@,
MH!E$7L`:K%7=1VU*-VJ9F:!7R'G'6BET%++/C??^#RD``#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?;&EN:RYG:68`````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`Q-#$`,3`T,3<S-C,P,#<`,#(T-C4U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y81(`$@"1``#___^`@(``
M``#___\A^00%%``#`"P`````$@`2```",IR/J<OM#^,(HE9C:S@4@%-YX#8(
M7X8*&`:HYF=0Y4RGV3JIG(8(9'XK97Z2HO&(3#(*`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V5D7VQI<W1?8G5L;&5T+F=I9@``````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3(P`#$P
M-#$W,S8S,#`W`#`R-C(S-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$2`!(`D0(```"$````____````(?D$`0``
M`@`L`````!(`$@```B&4CZG+!M_4`R;8>]&,O/NT?2%&:M"'IN#IC61VA.I,
M<P4`.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E
M9%]L:7-T7VYU;2YG:68````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$R,@`Q,#0Q-S,V,S`P-P`P
M,C4U-3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA$@`2`)$"````A````/___P```"'Y!`$```(`+``````2`!(`
M``(CE(^IRPB]P#.A6ILF=')[V'T.=5V9:$@:BJJL5IJG&+*V6```.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?<&%S=&4N9VEF
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`R,3,`,3`T,3<S-C,P,#<`,#(U,#,T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81(`
M$@"B!@"`@`"`@(```(#__P#___\```#___\````A^00!```&`"P`````$@`2
M```#4&BZW/[0E5FBH7,,7%D!`5!L8Q$&G6*B4IA>($<%[&*"^(F_GR[\0`%/
M%Q`0CL>?)P<P(@E&@8T8_4&!*J;SF511KT&H#;/E2A_!]-G";BL2`#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W)E9&\N9VEF````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,3(P`#$P-#$W,S8S,#`W`#`R-#8T-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$2`!(`D0(`@("```"`
M____````(?D$`0```@`L`````!(`$@```B&4CZG+[>]`F`%*-$]-FXOL+932
M86-RF2<'0.X+Q_),OP4`.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+VEM86=E<R]E9%]R:6=H=%]T;U]L969T+F=I9@``````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$S,``Q
M,#0Q-S,V,S`P-P`P,C8U-#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA$@`2`)$"``0"A````/___P```"'Y!`$`
M``(`+``````2`!(```(IE(^IR^W_@@QP"HK`LM@`K7#'!X841I;A-7[-F:D)
MG+TL9-#XSO=^4@``.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O
M961?<FUF;W)M870N9VEF````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-C8`,3`T,3<S-C,P,#<`
M,#(U-34V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y81(`$@#R!0`````9``!F9F;,S,S___\````````````A^00!
M```%`"P`````$@`2```#.UBZW/XPRDF7`!@((<$@WS``D0>>%V2&A$8ZZZEM
M,/O-+Q/?6VYY(A'N`0R.4D2CT->X9#"<BG1*720``#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W-A=F4N9VEF
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,C$W`#$P-#$W,S8S,#`W`#`R-#8V,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$2
M`!(`H@4`W-S<@("`@(``____````____````````(?D$`0``!0`L`````!(`
M$@```U18NMS^4)%)*VU$D,'[(`41,-GF<50`+.6):BJKN1^\2K-;QKAF93:9
M8$@LBFZAX6\2[$T"$]Q1**I*>4D?%)2<*K;+%+(`")C/:/-8`6B[W^V(/`$`
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]S:&]W7V)O<F1E<BYG:68`````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#$U,``Q,#0Q-S,V,S`P-P`P,C8R,S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA$@`2`)$"```SF0``
M`/___P```"'Y!`$```(`+``````2`!(```(YE(^IR^T/8YBTVF`"V+QW+&C>
MN($8&![HE*7M&YIG.I\LK>:9Z?:KC*O%>"M=K%6$W5C"VO("914``#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?<W!L:71C96PN9VEF````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,3<`
M,3`T,3<S-C,P,#<`,#(U-30S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y81<`%@"B!````(``______\```#___\`
M```````````A^00!```$`"P`````%P`6```#5$BZW/XPRDFKG2/KS<<;@@"&
MX4AZSFB69/EU</:5@1``]9VCC6H+@%^PQF.H`,BD$E!<;(10XDR4P]FL@:;B
MN%QJ":JJV/;UU8;`7SD&N[C?\'@E`0`[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7W5N9&\N9VEF`````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3(Q`#$P-#$W,S8S,#`W
M`#`R-#8V,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$2`!(`D0(`@("```"`____````(?D$`0```@`L`````!(`
M$@```B*4CZG+[0]C"S2`%0Y%5NWL>1LFC@G(5:C12<`JQ?),UTP!`#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]F=6QL<V-R965N
M7VUA>&EM:7IE+F=I9@`````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#$T,0`Q,#0Q-S,V,S`P-P`P,C<S,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M$@`2`(`!`````/___R'Y!`$```$`+``````2`!(```(XC(^I!NW?%%AGI@E=
ML'!GS%27QHG5LX6JAX&IJGFOE<9R>=+W:E]P](G4A`A=B%B44%:YH'&Y+```
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]I;6%G97,O9G5L;'-C<F5E;E]M:6YI;6EZ92YG
M:68`````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`Q-#$`,3`T,3<S-C,P,#<`,#(W,S$S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y81(`$@"``0````#_
M__\A^00!```!`"P`````$@`2```".(R/J0CMOP*(<]73I'F.Y7IM6*:5V$:6
M$[FFJG1UC,BZHO;E'`V=26L+\3@K!7`G-%F,Q%WDF2@``#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O:6UA9V5S+VEN<V5R=%]T86)L92YG:68`````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<Q
M`#$P-#$W,S8S,#`W`#`R-3<R-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$2`!(`H@``____S,S,`#.9````____
M````````````(?D$!10`!``L`````!(`$@```SY(NMS^D(Q)JQUJB,U[QY(G
M<N``!$"*JNE9GNT*JV5@WSC^RGR\QT!:)D>\_5A(5V;&Y-6*Q-)E.HE8K]AL
M`@`[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VQA;F<O
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`P
M-P`P,C(R-#0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O;&%N9R]E;BYJ<P``````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$U-3(U`#$P-#$W,S8S,#`W`#`R,S(Q,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O+R!),3A.(&-O;G-T86YT<PH*+R\@
M3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!
M=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O
M"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!9
M3U52($-/3E1!0U0@24Y&3R!)3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA
M="!L96%S="!A('9A;&ED(&5M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%
M05-%(%1262!43R!54T4@551&+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI
M9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM
M96YT"B\O("`@("`@('1H870@<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C
M97-S87)Y+BD*"DA434Q!<F5A+DDQ.$X@/2!["@H)+R\@=&AE(&9O;&QO=VEN
M9R!S:&]U;&0@8F4@=&AE(&9I;&5N86UE('=I=&AO=70@+FIS(&5X=&5N<VEO
M;@H)+R\@:70@=VEL;"!B92!U<V5D(&9O<B!A=71O;6%T:6-A;&QY(&QO860@
M<&QU9VEN(&QA;F=U86=E+@H);&%N9SH@(F5N(BP*"@ET;V]L=&EP<SH@>PH)
M"6)O;&0Z("`@("`@("`@("`B0F]L9"(L"@D):71A;&EC.B`@("`@("`@("))
M=&%L:6,B+`H)"75N9&5R;&EN93H@("`@("`B56YD97)L:6YE(BP*"0ES=')I
M:V5T:')O=6=H.B`@(E-T<FEK971H<F]U9V@B+`H)"7-U8G-C<FEP=#H@("`@
M("`B4W5B<V-R:7!T(BP*"0ES=7!E<G-C<FEP=#H@("`@(E-U<&5R<V-R:7!T
M(BP*"0EJ=7-T:69Y;&5F=#H@("`@(DIU<W1I9GD@3&5F="(L"@D):G5S=&EF
M>6-E;G1E<CH@(")*=7-T:69Y($-E;G1E<B(L"@D):G5S=&EF>7)I9VAT.B`@
M(")*=7-T:69Y(%)I9VAT(BP*"0EJ=7-T:69Y9G5L;#H@("`@(DIU<W1I9GD@
M1G5L;"(L"@D);W)D97)E9&QI<W0Z("`@(")/<F1E<F5D($QI<W0B+`H)"75N
M;W)D97)E9&QI<W0Z("`B0G5L;&5T960@3&ES="(L"@D);W5T9&5N=#H@("`@
M("`@(")$96-R96%S92!);F1E;G0B+`H)"6EN9&5N=#H@("`@("`@("`B26YC
M<F5A<V4@26YD96YT(BP*"0EF;W)E8V]L;W(Z("`@("`@(D9O;G0@0V]L;W(B
M+`H)"6AI;&ET96-O;&]R.B`@("`B0F%C:V=R;W5N9"!#;VQO<B(L"@D):&]R
M:7IO;G1A;')U;&4Z(")(;W)I>F]N=&%L(%)U;&4B+`H)"6-R96%T96QI;FLZ
M("`@("`B26YS97)T(%=E8B!,:6YK(BP*"0EI;G-E<G1I;6%G93H@("`@(DEN
M<V5R="]-;V1I9GD@26UA9V4B+`H)"6EN<V5R='1A8FQE.B`@("`B26YS97)T
M(%1A8FQE(BP*"0EH=&UL;6]D93H@("`@("`@(E1O9V=L92!(5$U,(%-O=7)C
M92(L"@D)<&]P=7!E9&ET;W(Z("`@(")%;FQA<F=E($5D:71O<B(L"@D)86)O
M=70Z("`@("`@("`@(")!8F]U="!T:&ES(&5D:71O<B(L"@D)<VAO=VAE;'`Z
M("`@("`@(")(96QP('5S:6YG(&5D:71O<B(L"@D)=&5X=&EN9&EC871O<CH@
M(")#=7)R96YT('-T>6QE(BP*"0EU;F1O.B`@("`@("`@("`@(E5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(BP*"0ER961O.B`@("`@("`@("`@(E)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(BP*"0EC=70Z("`@("`@("`@("`@(D-U="!S96QE
M8W1I;VXB+`H)"6-O<'DZ("`@("`@("`@("`B0V]P>2!S96QE8W1I;VXB+`H)
M"7!A<W1E.B`@("`@("`@("`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B+`H)"6QE
M9G1T;W)I9VAT.B`@("`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B+`H)"7)I
M9VAT=&]L969T.B`@("`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B+`H)"7)E
M;6]V969O<FUA=#H@("`B4F5M;W9E(&9O<FUA='1I;F<B+`H)"7!R:6YT.B`@
M("`@("`@("`B4')I;G0@9&]C=6UE;G0B+`H)"6MI;&QW;W)D.B`@("`@("`B
M0VQE87(@35-/9F9I8V4@=&%G<R(*"7TL"@H)8G5T=&]N<SH@>PH)"2)O:R(Z
M("`@("`@("`@("`B3TLB+`H)"2)C86YC96PB.B`@("`@("`B0V%N8V5L(@H)
M?2P*"@EM<V<Z('L*"0DB4&%T:"(Z("`@("`@("`@(E!A=&@B+`H)"2)415A4
M7TU/1$4B.B`@("`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\
M/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(BP*"@D)(DE%
M+7-U8VMS+69U;&PM<V-R965N(B`Z"@D)+R\@=')A;G-L871E(&AE<F4*"0DB
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@(B`K"@D)(F1U92!T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@(B`K"@D)(F1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@(B`K
M"@D)(FET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&XB
M("L*"0DB66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N(BP*"@D)(DUO>BU#;&EP8F]A<F0B(#H*"0DB56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@(B`K"@D)(F9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@
M=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@(B`K"@D)
M(G=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N(@H)?2P*"@ED:6%L;V=S.B!["@D)+R\@0V]M
M;6]N"@D)(D]+(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(D]+(BP*"0DB0V%N8V5L(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B0V%N8V5L(BP*"@D)
M(D%L:6=N;65N=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(D%L:6=N;65N=#HB+`H)"2).;W0@<V5T(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(").;W0@<V5T(BP*
M"0DB3&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B3&5F="(L"@D)(E)I9VAT(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E)I9VAT(BP*"0DB5&5X
M='1O<"(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B5&5X='1O<"(L"@D)(D%B<VUI9&1L92(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D%B<VUI9&1L92(L"@D)(D)A
M<V5L:6YE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(D)A<V5L:6YE(BP*"0DB06)S8F]T=&]M(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B06)S8F]T=&]M(BP*"0DB
M0F]T=&]M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B0F]T=&]M(BP*"0DB36ED9&QE(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B36ED9&QE(BP*"0DB5&]P
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B5&]P(BP*"@D)(DQA>6]U="(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(DQA>6]U="(L"@D)(E-P86-I;F<B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E-P86-I;F<B+`H)"2)(;W)I>F]N=&%L.B(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")(;W)I>F]N=&%L.B(L"@D)(DAO<FEZ
M;VYT86P@<&%D9&EN9R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(DAO<FEZ;VYT86P@<&%D9&EN9R(L"@D)(E9E<G1I8V%L.B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E9E<G1I8V%L
M.B(L"@D)(E9E<G1I8V%L('!A9&1I;F<B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(E9E<G1I8V%L('!A9&1I;F<B+`H)"2)";W)D97(@
M=&AI8VMN97-S.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(")";W)D97(@=&AI8VMN97-S.B(L"@D)(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DQE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(B+`H*"0DO+R!);G-E<G0@3&EN:PH)"2));G-E<G0O
M36]D:69Y($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("));G-E<G0O36]D:69Y($QI;FLB+`H)"2).;VYE("AU<V4@:6UP;&EC:70I
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(").;VYE("AU<V4@
M:6UP;&EC:70I(BP*"0DB3F5W('=I;F1O=R`H7V)L86YK*2(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B3F5W('=I;F1O=R`H7V)L86YK*2(L
M"@D)(E-A;64@9G)A;64@*%]S96QF*2(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(E-A;64@9G)A;64@*%]S96QF*2(L"@D)(E1O<"!F<F%M
M92`H7W1O<"DB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E1O<"!F<F%M92`H7W1O<"DB+`H)"2)/=&AE<B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")/=&AE<B(L"@D)(E1A
M<F=E=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(E1A<F=E=#HB+`H)"2)4:71L92`H=&]O;'1I<"DZ(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")4:71L92`H=&]O;'1I<"DZ
M(BP*"0DB55),.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B55),.B(L"@D)(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(@(#H@(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(L"@D)+R\@
M26YS97)T(%1A8FQE"@D)(DEN<V5R="!486)L92(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(DEN<V5R="!486)L92(L"@D)(E)O
M=W,Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(E)O=W,Z(BP*"0DB3G5M8F5R(&]F(')O=W,B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B3G5M8F5R(&]F(')O=W,B+`H)
M"2)#;VQS.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")#;VQS.B(L"@D)(DYU;6)E<B!O9B!C;VQU;6YS(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DYU;6)E<B!O9B!C;VQU
M;6YS(BP*"0DB5VED=&@Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B5VED=&@Z(BP*"0DB5VED=&@@;V8@=&AE('1A
M8FQE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B5VED=&@@
M;V8@=&AE('1A8FQE(BP*"0DB4&5R8V5N="(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B4&5R8V5N="(L"@D)(E!I>&5L
M<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(E!I>&5L<R(L"@D)(D5M(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(D5M(BP*"0DB5VED=&@@=6YI="(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B5VED
M=&@@=6YI="(L"@D)(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4B+`H)"2)#96QL('-P86-I;F<Z(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z(")#96QL('-P86-I;F<Z(BP*"0DB4W!A8V4@8F5T
M=V5E;B!A9&IA8V5N="!C96QL<R(@("`@("`@("`@("`@("`@("`@("`@.B`B
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(L"@D)(D-E;&P@<&%D9&EN
M9SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D-E
M;&P@<&%D9&EN9SHB+`H)"2)3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(B`@("`@("`@("`Z(")3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(BP*"0DO+R!);G-E<G0@26UA9V4*"0DB
M26YS97)T($EM86=E(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B26YS97)T($EM86=E(BP*"0DB26UA9V4@55),.B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B26UA9V4@55),
M.B(L"@D)(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(L"@D)
M(E!R979I97<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(E!R979I97<B+`H)"2)0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B("`@("`@("`@("`@("`@("`Z(")0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<B+`H)"2)!;'1E<FYA=&4@=&5X=#HB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")!;'1E<FYA=&4@
M=&5X=#HB+`H)"2)&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(@("`@("`@("`@("`Z(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<R(L"@D)(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4B+`H)"2));6%G92!0<F5V:65W.B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("));6%G92!0<F5V:65W.B(*"7T*?3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M
M;&%R96$N8W-S````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,#<R`#$P-#$W,S8S
M,#`W`#`R,S8R-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N:'1M;&%R96$@>R!B86-K9W)O=6YD.B`C9F9F.R!]"@HN:'1M
M;&%R96$@+G1O;VQB87(@>PH@(&-U<G-O<CH@9&5F875L=#L*("!B86-K9W)O
M=6YD.B!"=71T;VY&86-E.PH@('!A9&1I;F<Z(#-P>#L*("!B;W)D97(Z(#%P
M>"!S;VQI9#L*("!B;W)D97(M8V]L;W(Z($)U='1O;DAI9VAL:6=H="!"=71T
M;VY3:&%D;W<@0G5T=&]N4VAA9&]W($)U='1O;DAI9VAL:6=H=#L*?0HN:'1M
M;&%R96$@+G1O;VQB87(@=&%B;&4@>R!F;VYT+69A;6EL>3H@=&%H;VUA+'9E
M<F1A;F$L<V%N<RUS97)I9CL@9F]N="US:7IE.B`Q,7!X.R!]"BYH=&UL87)E
M82`N=&]O;&)A<B!I;6<@>R!B;W)D97(Z(&YO;F4[('T*+FAT;6QA<F5A("YT
M;V]L8F%R("YL86)E;"![('!A9&1I;F<Z(#!P>"`S<'@[('T*"BYH=&UL87)E
M82`N=&]O;&)A<B`N8G5T=&]N('L*("!B86-K9W)O=6YD.B!"=71T;VY&86-E
M.PH@(&-O;&]R.B!"=71T;VY497AT.PH@(&)O<F1E<CH@,7!X('-O;&ED($)U
M='1O;D9A8V4["B`@<&%D9&EN9SH@,7!X.PH@(&UA<F=I;CH@,'!X.PH@('=I
M9'1H.B`Q.'!X.PH@(&AE:6=H=#H@,3AP>#L*?0HN:'1M;&%R96$@+G1O;VQB
M87(@+F)U='1O;DAO=F5R('L*("!B;W)D97(Z(#%P>"!S;VQI9#L*("!B;W)D
M97(M8V]L;W(Z($)U='1O;DAI9VAL:6=H="!"=71T;VY3:&%D;W<@0G5T=&]N
M4VAA9&]W($)U='1O;DAI9VAL:6=H=#L*?0HN:'1M;&%R96$@+G1O;VQB87(@
M+F)U='1O;D%C=&EV92P@+FAT;6QA<F5A("YT;V]L8F%R("YB=71T;VY0<F5S
M<V5D('L*("!P861D:6YG.B`R<'@@,'!X(#!P>"`R<'@["B`@8F]R9&5R.B`Q
M<'@@<V]L:60["B`@8F]R9&5R+6-O;&]R.B!"=71T;VY3:&%D;W<@0G5T=&]N
M2&EG:&QI9VAT($)U='1O;DAI9VAL:6=H="!"=71T;VY3:&%D;W<["GT*+FAT
M;6QA<F5A("YT;V]L8F%R("YB=71T;VY0<F5S<V5D('L*("!B86-K9W)O=6YD
M.B!"=71T;VY(:6=H;&EG:'0["GT*+FAT;6QA<F5A("YT;V]L8F%R("YI;F1I
M8V%T;W(@>PH@('!A9&1I;F<Z(#!P>"`S<'@["B`@;W9E<F9L;W<Z(&AI9&1E
M;CL*("!W:61T:#H@,C!P>#L*("!T97AT+6%L:6=N.B!C96YT97(["B`@8W5R
M<V]R.B!D969A=6QT.PH@(&)O<F1E<CH@,7!X('-O;&ED($)U='1O;E-H861O
M=SL*?0H*+FAT;6QA<F5A("YT;V]L8F%R("YB=71T;VY$:7-A8FQE9"!I;6<@
M>PH@(&9I;'1E<CH@9W)A>2@I(&%L<&AA*&]P86-I='D@/2`R-2D["B`@+6UO
M>BUO<&%C:71Y.B`P+C(U.PI]"@HN:'1M;&%R96$@+G1O;VQB87(@+G-E<&%R
M871O<B!["B`@<&]S:71I;VXZ(')E;&%T:79E.PH@(&UA<F=I;CH@,W!X.PH@
M(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@0G5T=&]N4VAA9&]W.PH@(&)O<F1E
M<BUR:6=H=#H@,7!X('-O;&ED($)U='1O;DAI9VAL:6=H=#L*("!W:61T:#H@
M,'!X.PH@(&AE:6=H=#H@,39P>#L*("!P861D:6YG.B`P<'@["GT*"BYH=&UL
M87)E82`N=&]O;&)A<B`N<W!A8V4@>R!W:61T:#H@-7!X.R!]"@HN:'1M;&%R
M96$@+G1O;VQB87(@<V5L96-T('L@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N
M82QS86YS+7-E<FEF.R!]"@HN:'1M;&%R96$@+G1O;VQB87(@<V5L96-T+`HN
M:'1M;&%R96$@+G1O;VQB87(@<V5L96-T.FAO=F5R+`HN:'1M;&%R96$@+G1O
M;VQB87(@<V5L96-T.F%C=&EV92![(&)A8VMG<F]U;F0Z($9I96QD1F%C93L@
M8V]L;W(Z($)U='1O;E1E>'0[('T*"BYH=&UL87)E82`N<W1A='5S0F%R('L*
M("!B;W)D97(Z(#%P>"!S;VQI9#L*("!B;W)D97(M8V]L;W(Z($)U='1O;E-H
M861O=R!"=71T;VY(:6=H;&EG:'0@0G5T=&]N2&EG:&QI9VAT($)U='1O;E-H
M861O=SL*("!P861D:6YG.B`R<'@@-'!X.PH@(&)A8VMG<F]U;F0M8V]L;W(Z
M($)U='1O;D9A8V4["B`@8V]L;W(Z($)U='1O;E1E>'0["B`@9F]N=#H@,3%P
M>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PI]"@HN:'1M;&%R96$@+G-T
M871U<T)A<B`N<W1A='5S0F%R5')E92!A('L*("!P861D:6YG.B`R<'@@-7!X
M.PH@(&-O;&]R.B`C,#!F.PI]"@HN:'1M;&%R96$@+G-T871U<T)A<B`N<W1A
M='5S0F%R5')E92!A.G9I<VET960@>R!C;VQO<CH@(S`P9CL@?0HN:'1M;&%R
M96$@+G-T871U<T)A<B`N<W1A='5S0F%R5')E92!A.FAO=F5R('L*("!B86-K
M9W)O=6YD+6-O;&]R.B!(:6=H;&EG:'0["B`@8V]L;W(Z($AI9VAL:6=H=%1E
M>'0["B`@<&%D9&EN9SH@,7!X(#1P>#L*("!B;W)D97(Z(#%P>"!S;VQI9"!(
M:6=H;&EG:'1497AT.PI]"@H*+RH@2&ED9&5N($1)5B!P;W!U<"!D:6%L;V=S
M("A0;W!U<$1I=BD@*B\*"BYD:6%L;V<@>PH@(&-O;&]R.B!"=71T;VY497AT
M.PH@(&)A8VMG<F]U;F0Z($)U='1O;D9A8V4["GT*"BYD:6%L;V<@+F-O;G1E
M;G0@>R!P861D:6YG.B`R<'@[('T*"BYD:6%L;V<L("YD:6%L;V<@8G5T=&]N
M+"`N9&EA;&]G(&EN<'5T+"`N9&EA;&]G('-E;&5C="P@+F1I86QO9R!T97AT
M87)E82P@+F1I86QO9R!T86)L92!["B`@9F]N=#H@,3%P>"!486AO;6$L5F5R
M9&%N82QS86YS+7-E<FEF.PI]"@HN9&EA;&]G('1A8FQE('L@8F]R9&5R+6-O
M;&QA<'-E.B!C;VQL87!S93L@?0H*+F1I86QO9R`N=&ET;&4@>PH@(&)A8VMG
M<F]U;F0Z(",P,#@["B`@8V]L;W(Z("-F9C@["B`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED(",P,#`["B`@<&%D9&EN9SH@,7!X(#!P>"`R<'@@-7!X.PH@
M(&9O;G0M<VEZ93H@,3)P>#L*("!F;VYT+7=E:6=H=#H@8F]L9#L*("!C=7)S
M;W(Z(&1E9F%U;'0["GT*"BYD:6%L;V<@+G1I=&QE("YB=71T;VX@>PH@(&9L
M;V%T.B!R:6=H=#L*("!B;W)D97(Z(#%P>"!S;VQI9"`C-C9A.PH@('!A9&1I
M;F<Z(#!P>"`Q<'@@,'!X(#)P>#L*("!M87)G:6XM<FEG:'0Z(#%P>#L*("!C
M;VQO<CH@(V9F9CL*("!T97AT+6%L:6=N.B!C96YT97(["GT*"BYD:6%L;V<@
M+G1I=&QE("YB=71T;VXM:&EL:71E('L@8F]R9&5R+6-O;&]R.B`C.#AF.R!B
M86-K9W)O=6YD.B`C-#1C.R!]"@HN9&EA;&]G(&)U='1O;B!["B`@=VED=&@Z
M(#5E;3L*("!P861D:6YG.B`P<'@["GT*"BYD:6%L;V<@+F)U='1O;D-O;&]R
M('L*("!P861D:6YG.B`Q<'@["B`@8W5R<V]R.B!D969A=6QT.PH@(&)O<F1E
M<CH@,7!X('-O;&ED.PH@(&)O<F1E<BUC;VQO<CH@0G5T=&]N2&EG:&QI9VAT
M($)U='1O;E-H861O=R!"=71T;VY3:&%D;W<@0G5T=&]N2&EG:&QI9VAT.PI]
M"@HN9&EA;&]G("YB=71T;VY#;VQO<BUH:6QI=&4@>PH@(&)O<F1E<BUC;VQO
M<CH@(S`P,#L*?0H*+F1I86QO9R`N8G5T=&]N0V]L;W(@+F-H;V]S97(L("YD
M:6%L;V<@+F)U='1O;D-O;&]R("YN;V-O;&]R('L*("!H96EG:'0Z(#`N-F5M
M.PH@(&)O<F1E<CH@,7!X('-O;&ED.PH@('!A9&1I;F<Z(#!P>"`Q96T["B`@
M8F]R9&5R+6-O;&]R.B!"=71T;VY3:&%D;W<@0G5T=&]N2&EG:&QI9VAT($)U
M='1O;DAI9VAL:6=H="!"=71T;VY3:&%D;W<["GT*"BYD:6%L;V<@+F)U='1O
M;D-O;&]R("YN;V-O;&]R('L@<&%D9&EN9SH@,'!X.R!]"BYD:6%L;V<@+F)U
M='1O;D-O;&]R("YN;V-O;&]R+6AI;&ET92![(&)A8VMG<F]U;F0M8V]L;W(Z
M("-F9F8[(&-O;&]R.B`C9C`P.R!]"@HN9&EA;&]G("YL86)E;"![('1E>'0M
M86QI9VXZ(')I9VAT.R!W:61T:#H@-F5M.R!]"BYD:6%L;V<@+G9A;'5E(&EN
M<'5T('L@=VED=&@Z(#$P,"4[('T*+F1I86QO9R`N8G5T=&]N<R![('1E>'0M
M86QI9VXZ(')I9VAT.R!P861D:6YG.B`R<'@@-'!X(#!P>"`T<'@[('T*"BYD
M:6%L;V<@;&5G96YD('L@9F]N="UW96EG:'0Z(&)O;&0[('T*+F1I86QO9R!F
M:65L9'-E="!T86)L92![(&UA<F=I;CH@,G!X(#!P>#L@?0H*+G!O<'5P9&EV
M('L*("!B;W)D97(Z(#)P>"!S;VQI9#L*("!B;W)D97(M8V]L;W(Z($)U='1O
M;DAI9VAL:6=H="!"=71T;VY3:&%D;W<@0G5T=&]N4VAA9&]W($)U='1O;DAI
M9VAL:6=H=#L*?0H*+G!O<'5P=VEN('L*("!P861D:6YG.B`P<'@["B`@;6%R
M9VEN.B`P<'@["GT*"BYP;W!U<'=I;B`N=&ET;&4@>PH@(&)A8VMG<F]U;F0Z
M("-F9F8["B`@8V]L;W(Z(",P,#`["B`@9F]N="UW96EG:'0Z(&)O;&0["B`@
M9F]N="US:7IE.B`Q,C`E.PH@('!A9&1I;F<Z(#-P>"`Q,'!X.PH@(&UA<F=I
M;BUB;W1T;VTZ(#$P<'@["B`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(&)L
M86-K.PH@(&QE='1E<BUS<&%C:6YG.B`R<'@["GT*"F9O<FT@>R!M87)G:6XZ
M(#!P>#L@8F]R9&5R.B!N;VYE.R!]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]D:6%L;V<N:G,`````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0U-S0`,3`T,3<S-C,P,#<`,#(S,3(W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\O
M(&AT;6Q!<F5A('8S+C`@+2!#;W!Y<FEG:'0@*&,I(#(P,#,M,C`P-2!D>6YA
M<F-H+F-O;0HO+R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`R,#`R
M+3(P,#,@:6YT97)A8W1I=F5T;V]L<RYC;VTL(&EN8RX*+R\@5&AI<R!C;W!Y
M<FEG:'0@;F]T:6-E($U54U0@<W1A>2!I;G1A8W0@9F]R('5S92`H<V5E(&QI
M8V5N<V4N='AT*2X*+R\*+R\@4&]R=&EO;G,@*&,I(&1Y;F%R8V@N8V]M+"`R
M,#`S+3(P,#0*+R\*+R\@02!F<F5E(%=94TE764<@961I=&]R(')E<&QA8V5M
M96YT(&9O<B`\=&5X=&%R96$^(&9I96QD<RX*+R\@1F]R(&9U;&P@<V]U<F-E
M(&-O9&4@86YD(&1O8W,L('9I<VET(&AT='`Z+R]W=W<N:6YT97)A8W1I=F5T
M;V]L<RYC;VTO"B\O"B\O(%9E<G-I;VX@,RXP(&1E=F5L;W!E9"!B>2!-:6AA
M:2!"87IO;BX*+R\@("!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"B\O"B\O
M("1)9#H@9&EA;&]G+FIS+'8@,2XW(#(P,#4O,#$O,C`@,3<Z-#DZ,#0@;6ES
M:&]O($5X<"`D"@HO+R!4:&]U9V@@(D1I86QO9R(@;&]O:W,@;&EK92!A;B!O
M8FIE8W0L(&ET(&ES;B=T(')E86QL>2!A;B!O8FIE8W0N("!);G-T96%D"B\O
M(&ET)W,@:G5S="!N86UE<W!A8V4@9F]R('!R;W1E8W1I;F<@9VQO8F%L('-Y
M;6)O;',N"@IF=6YC=&EO;B!$:6%L;V<H=7)L+"!A8W1I;VXL(&EN:70I('L*
M"6EF("AT>7!E;V8@:6YI="`]/2`B=6YD969I;F5D(BD@>PH)"6EN:70@/2!W
M:6YD;W<["2\O('!A<W,@=&AI<R!W:6YD;W<@;V)J96-T(&)Y(&1E9F%U;'0*
M"7T*"41I86QO9RY?9V5C:V]/<&5N36]D86PH=7)L+"!A8W1I;VXL(&EN:70I
M.PI].PH*1&EA;&]G+E]P87)E;G1%=F5N="`](&9U;F-T:6]N*&5V*2!["@ES
M9714:6UE;W5T*"!F=6YC=&EO;B@I('L@:68@*$1I86QO9RY?;6]D86P@)B8@
M(41I86QO9RY?;6]D86PN8VQO<V5D*2![($1I86QO9RY?;6]D86PN9F]C=7,H
M*2!]('TL(#4P*3L*"6EF("A$:6%L;V<N7VUO9&%L("8F("%$:6%L;V<N7VUO
M9&%L+F-L;W-E9"D@>PH)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)?0I]
M.PH*"B\O('-H;W5L9"!B92!A(&9U;F-T:6]N+"!T:&4@<F5T=7)N(&AA;F1L
M97(@;V8@=&AE(&-U<G)E;G1L>2!O<&5N960@9&EA;&]G+@I$:6%L;V<N7W)E
M='5R;B`](&YU;&P["@HO+R!C;VYS=&%N="P@=&AE(&-U<G)E;G1L>2!O<&5N
M960@9&EA;&]G"D1I86QO9RY?;6]D86P@/2!N=6QL.PH*+R\@=&AE(&1I86QO
M9R!W:6QL(')E860@:70G<R!A<F=S(&9R;VT@=&AI<R!V87)I86)L90I$:6%L
M;V<N7V%R9W5M96YT<R`](&YU;&P["@I$:6%L;V<N7V=E8VMO3W!E;DUO9&%L
M(#T@9G5N8W1I;VXH=7)L+"!A8W1I;VXL(&EN:70I('L*"79A<B!D;&<@/2!W
M:6YD;W<N;W!E;BAU<FPL(")H861I86QO9R(L"@D)"2`@("`@(")T;V]L8F%R
M/6YO+&UE;G5B87(];F\L<&5R<V]N86QB87(];F\L=VED=&@],3`L:&5I9VAT
M/3$P+"(@*PH)"0D@("`@("`B<V-R;VQL8F%R<SUN;RQR97-I>F%B;&4]>65S
M+&UO9&%L/7EE<RQD97!E;F1A8FQE/7EE<R(I.PH)1&EA;&]G+E]M;V1A;"`]
M(&1L9SL*"41I86QO9RY?87)G=6UE;G1S(#T@:6YI=#L*"@DO+R!C87!T=7)E
M('-O;64@=VEN9&]W)W,@979E;G1S"@EF=6YC=&EO;B!C87!W:6XH=RD@>PH)
M"4A434Q!<F5A+E]A9&1%=F5N="AW+"`B8VQI8VLB+"!$:6%L;V<N7W!A<F5N
M=$5V96YT*3L*"0E(5$U,07)E82Y?861D179E;G0H=RP@(FUO=7-E9&]W;B(L
M($1I86QO9RY?<&%R96YT179E;G0I.PH)"4A434Q!<F5A+E]A9&1%=F5N="AW
M+"`B9F]C=7,B+"!$:6%L;V<N7W!A<F5N=$5V96YT*3L*"7T["@DO+R!R96QE
M87-E('1H92!C87!T=7)E9"!E=F5N=',*"69U;F-T:6]N(')E;'=I;BAW*2![
M"@D)2%1-3$%R96$N7W)E;6]V945V96YT*'<L(")C;&EC:R(L($1I86QO9RY?
M<&%R96YT179E;G0I.PH)"4A434Q!<F5A+E]R96UO=F5%=F5N="AW+"`B;6]U
M<V5D;W=N(BP@1&EA;&]G+E]P87)E;G1%=F5N="D["@D)2%1-3$%R96$N7W)E
M;6]V945V96YT*'<L(")F;V-U<R(L($1I86QO9RY?<&%R96YT179E;G0I.PH)
M?3L*"6-A<'=I;BAW:6YD;W<I.PH)+R\@8V%P='5R92!O=&AE<B!F<F%M97,*
M"69O<B`H=F%R(&D@/2`P.R!I(#P@=VEN9&]W+F9R86UE<RYL96YG=&@[(&-A
M<'=I;BAW:6YD;W<N9G)A;65S6VDK*UTI*3L*"2\O(&UA:V4@=7`@82!F=6YC
M=&EO;B!T;R!B92!C86QL960@=VAE;B!T:&4@1&EA;&]G(&5N9',N"@E$:6%L
M;V<N7W)E='5R;B`](&9U;F-T:6]N("AV86PI('L*"0EI9B`H=F%L("8F(&%C
M=&EO;BD@>PH)"0EA8W1I;VXH=F%L*3L*"0E]"@D)<F5L=VEN*'=I;F1O=RD[
M"@D)+R\@8V%P='5R92!O=&AE<B!F<F%M97,*"0EF;W(@*'9A<B!I(#T@,#L@
M:2`\('=I;F1O=RYF<F%M97,N;&5N9W1H.R!R96QW:6XH=VEN9&]W+F9R86UE
M<UMI*RM=*2D["@D)1&EA;&]G+E]M;V1A;"`](&YU;&P["@E].PI].PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;W!U<&1I=BYJ<P``````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(V-S8`,3`T,3<S
M-C,P,#<`,#(S-30Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"\J*B!4:&ES(&9I;&4@:7,@9&5R:79E9"!F<F]M(%!O<'5P
M1&EV+"!D979E;&]P960@8GD@36EH86D@0F%Z;VX@9F]R"B`J(%-A;5=A<F4N
M;F5T+B`@36]D:69I8V%T:6]N<R!W97)E(&YE961E9"!T;R!M86ME(&ET('5S
M86)L92!I;B!(5$U,07)E82X*("H@2%1-3$%R96$@:7,@82!F<F5E(%=94TE7
M64<@;VYL:6YE($A434P@961I=&]R(&9R;VT@26YT97)A8W1I=F54;V]L<RYC
M;VTN"B`J"B`J(%1H:7,@9FEL92!D;V5S(&YO="!F=6YC=&EO;B!S=&%N9&%L
M;VYE+B`@270@:7,@9&5P96YD96YT(&]F(&=L;V)A;"!F=6YC=&EO;G,*("H@
M9&5F:6YE9"!I;B!(5$U,07)E82TS+C`@*&AT;6QA<F5A+FIS*2X*("H*("H@
M4&QE87-E('-E92!F:6QE(&AT;6QA<F5A+FIS(&9O<B!F=7)T:&5R(&1E=&%I
M;',N"B`J*B\*"G9A<B!I<U]I92`]("@@*&YA=FEG871O<BYU<V5R06=E;G0N
M=&],;W=E<D-A<V4H*2YI;F1E>$]F*")M<VEE(BD@(3T@+3$I("8F"@D@("`@
M("`H;F%V:6=A=&]R+G5S97)!9V5N="YT;TQO=V5R0V%S92@I+FEN9&5X3V8H
M(F]P97)A(BD@/3T@+3$I("D["G9A<B!I<U]C;VUP870@/2`H9&]C=6UE;G0N
M8V]M<&%T36]D92`]/2`B0F%C:T-O;7!A="(I.PH*9G5N8W1I;VX@4&]P=7!$
M:78H961I=&]R+"!T:71L951E>'0L(&AA;F1L97(L(&EN:71&=6YC=&EO;BD@
M>PH)=F%R('-E;&8@/2!T:&ES.PH*"71H:7,N961I=&]R(#T@961I=&]R.PH)
M=&AI<RYD;V,@/2!E9&ET;W(N7VUD;V,["@ET:&ES+FAA;F1L97(@/2!H86YD
M;&5R.PH*"79A<B!E;"`]('1H:7,N9&]C+F-R96%T945L96UE;G0H(F1I=B(I
M.PH)96PN8VQA<W-.86UE(#T@(F-O;G1E;G0B.PH*"79A<B!P;W!U<"`]('1H
M:7,N9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)<&]P=7`N8VQA<W-.86UE
M(#T@(F1I86QO9R!P;W!U<&1I=B(["@ET:&ES+F5L96UE;G0@/2!P;W!U<#L*
M"79A<B!S(#T@<&]P=7`N<W1Y;&4["@ES+G!O<VET:6]N(#T@(F%B<V]L=71E
M(CL*"7,N;&5F="`]("(P<'@B.PH)<RYT;W`@/2`B,'!X(CL*"@EV87(@=&ET
M;&4@/2!T:&ES+F1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"71I=&QE+F-L
M87-S3F%M92`](")T:71L92(["@ET:&ES+G1I=&QE(#T@=&ET;&4["@EP;W!U
M<"YA<'!E;F1#:&EL9"AT:71L92D["@H)2%1-3$%R96$N7V%D9$5V96YT*'1I
M=&QE+"`B;6]U<V5D;W=N(BP@9G5N8W1I;VXH978I('L*"0ES96QF+E]D<F%G
M4W1A<G0H:7-?:64@/R!W:6YD;W<N979E;G0@.B!E=BD["@E]*3L*"@EV87(@
M8G5T=&]N(#T@=&AI<RYD;V,N8W)E871E16QE;65N="@B9&EV(BD["@EB=71T
M;VXN8VQA<W-.86UE(#T@(F)U='1O;B(["@ET:71L92YA<'!E;F1#:&EL9"AB
M=71T;VXI.PH)8G5T=&]N+FEN;F5R2%1-3"`]("(F(W@P,&0W.R(["@ET:71L
M92YA<'!E;F1#:&EL9"AT:&ES+F1O8RYC<F5A=&5497AT3F]D92AT:71L951E
M>'0I*3L*"71H:7,N=&ET;&5497AT(#T@=&ET;&5497AT.PH*"6)U='1O;BYO
M;FUO=7-E;W9E<B`](&9U;F-T:6]N*"D@>PH)"71H:7,N8VQA<W-.86UE("L]
M("(@8G5T=&]N+6AI;&ET92(["@E].PH)8G5T=&]N+F]N;6]U<V5O=70@/2!F
M=6YC=&EO;B@I('L*"0ET:&ES+F-L87-S3F%M92`]('1H:7,N8VQA<W-.86UE
M+G)E<&QA8V4H+UQS*F)U='1O;BUH:6QI=&5<<RHO9RP@(B`B*3L*"7T["@EB
M=71T;VXN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH)"71H:7,N8VQA<W-.86UE
M(#T@=&AI<RYC;&%S<TYA;64N<F5P;&%C92@O7',J8G5T=&]N+6AI;&ET95QS
M*B]G+"`B("(I.PH)"7-E;&8N8VQO<V4H*3L*"7T["@H)<&]P=7`N87!P96YD
M0VAI;&0H96PI.PH)=&AI<RYC;VYT96YT(#T@96P["@H)=&AI<RYD;V,N8F]D
M>2YA<'!E;F1#:&EL9"AP;W!U<"D["@H)=&AI<RYD<F%G9VEN9R`](&9A;'-E
M.PH)=&AI<RYO;E-H;W<@/2!N=6QL.PH)=&AI<RYO;D-L;W-E(#T@;G5L;#L*
M"71H:7,N;6]D86P@/2!F86QS93L*"@EI;FET1G5N8W1I;VXH=&AI<RD["GT[
M"@I0;W!U<$1I=BYC=7)R96YT4&]P=7`@/2!N=6QL.PH*4&]P=7!$:78N<')O
M=&]T>7!E+G-H;W=!=$5L96UE;G0@/2!F=6YC=&EO;BAE;"P@;6]D92D@>PH)
M=&AI<RYD969A=6QT4VEZ92@I.PH)=F%R('!O<RP@97<L(&5H.PH)=F%R('!O
M<'5P(#T@=&AI<RYE;&5M96YT.PH)<&]P=7`N<W1Y;&4N9&ES<&QA>2`](")B
M;&]C:R(["@EV87(@=R`]('!O<'5P+F]F9G-E=%=I9'1H.PH)=F%R(&@@/2!P
M;W!U<"YO9F9S971(96EG:'0["@EP;W!U<"YS='EL92YD:7-P;&%Y(#T@(FYO
M;F4B.PH):68@*&5L("$]('=I;F1O=RD@>PH)"7!O<R`](%!O<'5P1&EV+F=E
M=$%B<V]L=71E4&]S*&5L*3L*"0EE=R`](&5L+F]F9G-E=%=I9'1H.PH)"65H
M(#T@96PN;V9F<V5T2&5I9VAT.PH)?2!E;'-E('L*"0EP;W,@/2![>#HP+"!Y
M.C!].PH)"79A<B!S:7IE(#T@4&]P=7!$:78N9V5T5VEN9&]W4VEZ92@I.PH)
M"65W(#T@<VEZ92YX.PH)"65H(#T@<VEZ92YY.PH)?0H)=F%R($98(#T@9F%L
M<V4L($99(#T@9F%L<V4["@EI9B`H;6]D92YI;F1E>$]F*")L(BD@(3T@+3$I
M('L*"0EP;W,N>"`M/2!W.PH)"498(#T@=')U93L*"7T*"6EF("AM;V1E+FEN
M9&5X3V8H(G(B*2`A/2`M,2D@>PH)"7!O<RYX("L](&5W.PH)"498(#T@=')U
M93L*"7T*"6EF("AM;V1E+FEN9&5X3V8H(G0B*2`A/2`M,2D@>PH)"7!O<RYY
M("T](&@["@D)1ED@/2!T<G5E.PH)?0H):68@*&UO9&4N:6YD97A/9B@B8B(I
M("$]("TQ*2!["@D)<&]S+GD@*ST@96@["@D)1ED@/2!T<G5E.PH)?0H):68@
M*&UO9&4N:6YD97A/9B@B8R(I("$]("TQ*2!["@D)1E@@?'P@*'!O<RYX("L]
M($UA=&@N<F]U;F0H*&5W("T@=RD@+R`R*2D["@D)1ED@?'P@*'!O<RYY("L]
M($UA=&@N<F]U;F0H*&5H("T@:"D@+R`R*2D["@E]"@ET:&ES+G-H;W=!="AP
M;W,N>"P@<&]S+GDI.PI].PH*4&]P=7!$:78N<')O=&]T>7!E+F1E9F%U;'13
M:7IE(#T@9G5N8W1I;VXH*2!["@EV87(@<R`]('1H:7,N96QE;65N="YS='EL
M93L*"79A<B!C<R`]('1H:7,N96QE;65N="YC=7)R96YT4W1Y;&4["@EV87(@
M861D6"`]("AI<U]I92`F)B!I<U]C;VUP870I(#\@*'!A<G-E26YT*&-S+F)O
M<F1E<DQE9G17:61T:"D@*PH)"0D)"2`@('!A<G-E26YT*&-S+F)O<F1E<E)I
M9VAT5VED=&@I("L*"0D)"0D@("!P87)S94EN="AC<RYP861D:6YG3&5F="D@
M*PH)"0D)"2`@('!A<G-E26YT*&-S+G!A9&1I;F=2:6=H="DI(#H@,#L*"79A
M<B!A9&19(#T@*&ES7VEE("8F(&ES7V-O;7!A="D@/R`H<&%R<V5);G0H8W,N
M8F]R9&5R5&]P5VED=&@I("L*"0D)"0D@("!P87)S94EN="AC<RYB;W)D97)"
M;W1T;VU7:61T:"D@*PH)"0D)"2`@('!A<G-E26YT*&-S+G!A9&1I;F=4;W`I
M("L*"0D)"0D@("!P87)S94EN="AC<RYP861D:6YG0F]T=&]M*2D@.B`P.PH)
M<RYD:7-P;&%Y(#T@(F)L;V-K(CL*"7,N=VED=&@@/2`H=&AI<RYC;VYT96YT
M+F]F9G-E=%=I9'1H("L@861D6"D@*R`B<'@B.PH)<RYH96EG:'0@/2`H=&AI
M<RYC;VYT96YT+F]F9G-E=$AE:6=H="`K('1H:7,N=&ET;&4N;V9F<V5T2&5I
M9VAT*2`K(")P>"(["@ES+F1I<W!L87D@/2`B;F]N92(["GT["@I0;W!U<$1I
M=BYP<F]T;W1Y<&4N<VAO=T%T(#T@9G5N8W1I;VXH>"P@>2D@>PH)=&AI<RYD
M969A=6QT4VEZ92@I.PH)=F%R(',@/2!T:&ES+F5L96UE;G0N<W1Y;&4["@ES
M+F1I<W!L87D@/2`B8FQO8VLB.PH)<RYL969T(#T@>"`K(")P>"(["@ES+G1O
M<"`]('D@*R`B<'@B.PH)=&AI<RYH:61E4VAO=T-O=F5R960H*3L*"@E0;W!U
M<$1I=BYC=7)R96YT4&]P=7`@/2!T:&ES.PH)2%1-3$%R96$N7V%D9$5V96YT
M<RAT:&ES+F1O8RYB;V1Y+"!;(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0;W!U
M<$1I=BYC:&5C:U!O<'5P*3L*"4A434Q!<F5A+E]A9&1%=F5N=',H=&AI<RYE
M9&ET;W(N7V1O8RYB;V1Y+"!;(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0;W!U
M<$1I=BYC:&5C:U!O<'5P*3L*"6EF("AI<U]I92`F)B!T:&ES+FUO9&%L*2![
M"@D)=&AI<RYD;V,N8F]D>2YS971#87!T=7)E*&9A;'-E*3L*"0ET:&ES+F1O
M8RYB;V1Y+F]N;&]S96-A<'1U<F4@/2!F=6YC=&EO;B@I('L*"0D)*%!O<'5P
M1&EV+F-U<G)E;G10;W!U<"D@)B8@*'1H:7,N9&]C+F)O9'DN<V5T0V%P='5R
M92AF86QS92DI.PH)"7T["@E]"@EW:6YD;W<N979E;G0@)B8@2%1-3$%R96$N
M7W-T;W!%=F5N="AW:6YD;W<N979E;G0I.PH*"6EF("AT>7!E;V8@=&AI<RYO
M;E-H;W<@/3T@(F9U;F-T:6]N(BD@>PH)"71H:7,N;VY3:&]W*"D["@E](&5L
M<V4@:68@*'1Y<&5O9B!T:&ES+F]N4VAO=R`]/2`B<W1R:6YG(BD@>PH)"65V
M86PH=&AI<RYO;E-H;W<I.PH)?0H*"79A<B!F:65L9"`]('1H:7,N96QE;65N
M="YG971%;&5M96YT<T)Y5&%G3F%M92@B:6YP=70B*5LP73L*"6EF("@A9FEE
M;&0I('L*"0EF:65L9"`]('1H:7,N96QE;65N="YG971%;&5M96YT<T)Y5&%G
M3F%M92@B<V5L96-T(BE;,%T["@E]"@EI9B`H(69I96QD*2!["@D)9FEE;&0@
M/2!T:&ES+F5L96UE;G0N9V5T16QE;65N='-">51A9TYA;64H(G1E>'1A<F5A
M(BE;,%T["@E]"@EI9B`H9FEE;&0I('L*"0EF:65L9"YF;V-U<R@I.PH)?0I]
M.PH*4&]P=7!$:78N<')O=&]T>7!E+F-L;W-E(#T@9G5N8W1I;VXH*2!["@ET
M:&ES+F5L96UE;G0N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*"5!O<'5P1&EV
M+F-U<G)E;G10;W!U<"`](&YU;&P["@ET:&ES+FAI9&53:&]W0V]V97)E9"@I
M.PH)2%1-3$%R96$N7W)E;6]V945V96YT<RAT:&ES+F1O8RYB;V1Y+"!;(FUO
M=7-E9&]W;B(L(")C;&EC:R)=+"!0;W!U<$1I=BYC:&5C:U!O<'5P*3L*"4A4
M34Q!<F5A+E]R96UO=F5%=F5N=',H=&AI<RYE9&ET;W(N7V1O8RYB;V1Y+"!;
M(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0;W!U<$1I=BYC:&5C:U!O<'5P*3L*
M"6ES7VEE("8F('1H:7,N;6]D86P@)B8@=&AI<RYD;V,N8F]D>2YR96QE87-E
M0V%P='5R92@I.PH):68@*'1Y<&5O9B!T:&ES+F]N0VQO<V4@/3T@(F9U;F-T
M:6]N(BD@>PH)"71H:7,N;VY#;&]S92@I.PH)?2!E;'-E(&EF("AT>7!E;V8@
M=&AI<RYO;D-L;W-E(#T](")S=')I;F<B*2!["@D)979A;"AT:&ES+F]N0VQO
M<V4I.PH)?0H)=&AI<RYE;&5M96YT+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H
M=&AI<RYE;&5M96YT*3L*?3L*"E!O<'5P1&EV+G!R;W1O='EP92YG971&;W)M
M(#T@9G5N8W1I;VXH*2!["@EV87(@9F]R;7,@/2!T:&ES+F-O;G1E;G0N9V5T
M16QE;65N='-">51A9TYA;64H(F9O<FTB*3L*"7)E='5R;B`H9F]R;7,N;&5N
M9W1H(#X@,"D@/R!F;W)M<ULP72`Z(&YU;&P["GT["@I0;W!U<$1I=BYP<F]T
M;W1Y<&4N8V%L;$AA;F1L97(@/2!F=6YC=&EO;B@I('L*"79A<B!T86=S(#T@
M6R)I;G!U="(L(")T97AT87)E82(L(")S96QE8W0B73L*"79A<B!P87)A;7,@
M/2!N97<@3V)J96-T*"D["@EF;W(@*'9A<B!T:2`]('1A9W,N;&5N9W1H.R`M
M+71I(#X](#`[*2!["@D)=F%R('1A9R`]('1A9W-;=&E=.PH)"79A<B!E;',@
M/2!T:&ES+F-O;G1E;G0N9V5T16QE;65N='-">51A9TYA;64H=&%G*3L*"0EF
M;W(@*'9A<B!J(#T@,#L@:B`\(&5L<RYL96YG=&@[("LK:BD@>PH)"0EV87(@
M96P@/2!E;'-;:ET["@D)"7!A<F%M<UME;"YN86UE72`](&5L+G9A;'5E.PH)
M"7T*"7T*"71H:7,N:&%N9&QE<BAT:&ES+"!P87)A;7,I.PH)<F5T=7)N(&9A
M;'-E.PI].PH*4&]P=7!$:78N9V5T06)S;VQU=&50;W,@/2!F=6YC=&EO;BAE
M;"D@>PH)=F%R('(@/2![('@Z(&5L+F]F9G-E=$QE9G0L('DZ(&5L+F]F9G-E
M=%1O<"!].PH):68@*&5L+F]F9G-E=%!A<F5N="D@>PH)"79A<B!T;7`@/2!0
M;W!U<$1I=BYG971!8G-O;'5T95!O<RAE;"YO9F9S971087)E;G0I.PH)"7(N
M>"`K/2!T;7`N>#L*"0ER+GD@*ST@=&UP+GD["@E]"@ER971U<FX@<CL*?3L*
M"E!O<'5P1&EV+F=E=%=I;F1O=U-I>F4@/2!F=6YC=&EO;B@I('L*"6EF("AW
M:6YD;W<N:6YN97)(96EG:'0I('L*"0ER971U<FX@>R!Y.B!W:6YD;W<N:6YN
M97)(96EG:'0L('@Z('=I;F1O=RYI;FYE<E=I9'1H('T["@E]"@EI9B`H=&AI
M<RYD;V,N8F]D>2YC;&EE;G1(96EG:'0I('L*"0ER971U<FX@>R!Y.B!T:&ES
M+F1O8RYB;V1Y+F-L:65N=$AE:6=H="P@>#H@=&AI<RYD;V,N8F]D>2YC;&EE
M;G17:61T:"!].PH)?0H)<F5T=7)N('L@>3H@=&AI<RYD;V,N9&]C=6UE;G1%
M;&5M96YT+F-L:65N=$AE:6=H="P@>#H@=&AI<RYD;V,N9&]C=6UE;G1%;&5M
M96YT+F-L:65N=%=I9'1H('T["GT["@I0;W!U<$1I=BYP<F]T;W1Y<&4N:&ED
M95-H;W=#;W9E<F5D(#T@9G5N8W1I;VX@*"D@>PH)=F%R('-E;&8@/2!T:&ES
M.PH)9G5N8W1I;VX@:7-#;VYT86EN960H96PI('L*"0EW:&EL92`H96PI('L*
M"0D):68@*&5L(#T]('-E;&8N96QE;65N="D@>PH)"0D)<F5T=7)N('1R=64[
M"@D)"7T*"0D)96P@/2!E;"YP87)E;G1.;V1E.PH)"7T*"0ER971U<FX@9F%L
M<V4["@E].PH)=F%R('1A9W,@/2!N97<@07)R87DH(F%P<&QE="(L(")S96QE
M8W0B*3L*"79A<B!E;"`]('1H:7,N96QE;65N=#L*"@EV87(@<"`](%!O<'5P
M1&EV+F=E=$%B<V]L=71E4&]S*&5L*3L*"79A<B!%6#$@/2!P+G@["@EV87(@
M15@R(#T@96PN;V9F<V5T5VED=&@@*R!%6#$["@EV87(@15DQ(#T@<"YY.PH)
M=F%R($59,B`](&5L+F]F9G-E=$AE:6=H="`K($59,3L*"@EI9B`H96PN<W1Y
M;&4N9&ES<&QA>2`]/2`B;F]N92(I('L*"0E%6#$@/2!%6#(@/2!%63$@/2!%
M63(@/2`P.PH)?0H*"69O<B`H=F%R(&L@/2!T86=S+FQE;F=T:#L@:R`^(#`[
M("D@>PH)"79A<B!A<B`]('1H:7,N9&]C+F=E=$5L96UE;G1S0GE486=.86UE
M*'1A9W-;+2UK72D["@D)=F%R(&-C(#T@;G5L;#L*"@D)9F]R("AV87(@:2`]
M(&%R+FQE;F=T:#L@:2`^(#`[*2!["@D)"6-C(#T@87);+2UI73L*"0D):68@
M*&ES0V]N=&%I;F5D*&-C*2D@>PH)"0D)8V,N<W1Y;&4N=FES:6)I;&ET>2`]
M(")V:7-I8FQE(CL*"0D)"6-O;G1I;G5E.PH)"0E]"@H)"0EP(#T@4&]P=7!$
M:78N9V5T06)S;VQU=&50;W,H8V,I.PH)"0EV87(@0U@Q(#T@<"YX.PH)"0EV
M87(@0U@R(#T@8V,N;V9F<V5T5VED=&@@*R!#6#$["@D)"79A<B!#63$@/2!P
M+GD["@D)"79A<B!#63(@/2!C8RYO9F9S971(96EG:'0@*R!#63$["@H)"0EI
M9B`H*$-8,2`^($58,BD@?'P@*$-8,B`\($58,2D@?'P@*$-9,2`^($59,BD@
M?'P@*$-9,B`\($59,2DI('L*"0D)"6-C+G-T>6QE+G9I<VEB:6QI='D@/2`B
M=FES:6)L92(["@D)"7T@96QS92!["@D)"0EC8RYS='EL92YV:7-I8FEL:71Y
M(#T@(FAI9&1E;B(["@D)"7T*"0E]"@E]"GT["@I0;W!U<$1I=BYP<F]T;W1Y
M<&4N7V1R86=3=&%R="`](&9U;F-T:6]N("AE=BD@>PH):68@*'1H:7,N9')A
M9V=I;F<I('L*"0ER971U<FX@9F%L<V4["@E]"@ET:&ES+F1R86=G:6YG(#T@
M=')U93L*"5!O<'5P1&EV+F-U<G)E;G10;W!U<"`]('1H:7,["@EV87(@<&]S
M6"`](&5V+F-L:65N=%@["@EV87(@<&]S62`](&5V+F-L:65N=%D["@EI9B`H
M:7-?:64I('L*"0EP;W-9("L]('1H:7,N9&]C+F)O9'DN<V-R;VQL5&]P.PH)
M"7!O<U@@*ST@=&AI<RYD;V,N8F]D>2YS8W)O;&Q,969T.PH)?2!E;'-E('L*
M"0EP;W-9("L]('=I;F1O=RYS8W)O;&Q9.PH)"7!O<U@@*ST@=VEN9&]W+G-C
M<F]L;%@["@E]"@EV87(@<W0@/2!T:&ES+F5L96UE;G0N<W1Y;&4["@ET:&ES
M+GA/9F9S(#T@<&]S6"`M('!A<G-E26YT*'-T+FQE9G0I.PH)=&AI<RYY3V9F
M<R`]('!O<UD@+2!P87)S94EN="AS="YT;W`I.PH)2%1-3$%R96$N7V%D9$5V
M96YT*'1H:7,N9&]C+"`B;6]U<V5M;W9E(BP@4&]P=7!$:78N9')A9TET*3L*
M"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F1O8RP@(FUO=7-E;W9E<B(L($A4
M34Q!<F5A+E]S=&]P179E;G0I.PH)2%1-3$%R96$N7V%D9$5V96YT*'1H:7,N
M9&]C+"`B;6]U<V5U<"(L(%!O<'5P1&EV+F1R86=%;F0I.PH)2%1-3$%R96$N
M7W-T;W!%=F5N="AE=BD["GT["@I0;W!U<$1I=BYD<F%G270@/2!F=6YC=&EO
M;B`H978I('L*"79A<B!P;W!U<"`](%!O<'5P1&EV+F-U<G)E;G10;W!U<#L*
M"6EF("@A*'!O<'5P("8F('!O<'5P+F1R86=G:6YG*2D@>PH)"7)E='5R;B!F
M86QS93L*"7T*"6ES7VEE("8F("AE=B`]('=I;F1O=RYE=F5N="D["@EV87(@
M<&]S6"`](&5V+F-L:65N=%@["@EV87(@<&]S62`](&5V+F-L:65N=%D["@EI
M9B`H:7-?:64I('L*"0EP;W-9("L]('1H:7,N9&]C+F)O9'DN<V-R;VQL5&]P
M.PH)"7!O<U@@*ST@=&AI<RYD;V,N8F]D>2YS8W)O;&Q,969T.PH)?2!E;'-E
M('L*"0EP;W-9("L]('=I;F1O=RYS8W)O;&Q9.PH)"7!O<U@@*ST@=VEN9&]W
M+G-C<F]L;%@["@E]"@EP;W!U<"YH:61E4VAO=T-O=F5R960H*3L*"79A<B!S
M="`]('!O<'5P+F5L96UE;G0N<W1Y;&4["@ES="YL969T(#T@*'!O<U@@+2!P
M;W!U<"YX3V9F<RD@*R`B<'@B.PH)<W0N=&]P(#T@*'!O<UD@+2!P;W!U<"YY
M3V9F<RD@*R`B<'@B.PH)2%1-3$%R96$N7W-T;W!%=F5N="AE=BD["GT["@I0
M;W!U<$1I=BYD<F%G16YD(#T@9G5N8W1I;VX@*"D@>PH)=F%R('!O<'5P(#T@
M4&]P=7!$:78N8W5R<F5N=%!O<'5P.PH):68@*"%P;W!U<"D@>PH)"7)E='5R
M;B!F86QS93L*"7T*"7!O<'5P+F1R86=G:6YG(#T@9F%L<V4["@E(5$U,07)E
M82Y?<F5M;W9E179E;G0H<&]P=7`N9&]C+"`B;6]U<V5U<"(L(%!O<'5P1&EV
M+F1R86=%;F0I.PH)2%1-3$%R96$N7W)E;6]V945V96YT*'!O<'5P+F1O8RP@
M(FUO=7-E;W9E<B(L($A434Q!<F5A+E]S=&]P179E;G0I.PH)2%1-3$%R96$N
M7W)E;6]V945V96YT*'!O<'5P+F1O8RP@(FUO=7-E;6]V92(L(%!O<'5P1&EV
M+F1R86=)="D["@EP;W!U<"YH:61E4VAO=T-O=F5R960H*3L*?3L*"E!O<'5P
M1&EV+F-H96-K4&]P=7`@/2!F=6YC=&EO;B`H978I('L*"6ES7VEE("8F("AE
M=B`]('=I;F1O=RYE=F5N="D["@EV87(@96P@/2!I<U]I92`_(&5V+G-R8T5L
M96UE;G0@.B!E=BYT87)G970["@EV87(@8W`@/2!0;W!U<$1I=BYC=7)R96YT
M4&]P=7`["@EF;W(@*#L@*&5L("$](&YU;&PI("8F("AE;"`A/2!C<"YE;&5M
M96YT*3L@96P@/2!E;"YP87)E;G1.;V1E*3L*"6EF("AE;"`]/2!N=6QL*2![
M"@D)8W`N;6]D86P@?'P@978N='EP92`]/2`B;6]U<V5O=F5R(B!\?"!C<"YC
M;&]S92@I.PH)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)?0I].PH*4&]P
M=7!$:78N<')O=&]T>7!E+F%D9$)U='1O;G,@/2!F=6YC=&EO;B@I('L*"79A
M<B!S96QF(#T@=&AI<SL*"79A<B!D:78@/2!T:&ES+F1O8RYC<F5A=&5%;&5M
M96YT*")D:78B*3L*"71H:7,N8V]N=&5N="YA<'!E;F1#:&EL9"AD:78I.PH)
M9&EV+F-L87-S3F%M92`](")B=71T;VYS(CL*"69O<B`H=F%R(&D@/2`P.R!I
M(#P@87)G=6UE;G1S+FQE;F=T:#L@*RMI*2!["@D)=F%R(&)T;B`](&%R9W5M
M96YT<UMI73L*"0EV87(@8G5T=&]N(#T@=&AI<RYD;V,N8W)E871E16QE;65N
M="@B8G5T=&]N(BD["@D)9&EV+F%P<&5N9$-H:6QD*&)U='1O;BD["@D)8G5T
M=&]N+FEN;F5R2%1-3"`]($A434Q!<F5A+DDQ.$XN8G5T=&]N<UMB=&Y=.PH)
M"7-W:71C:"`H8G1N*2!["@D)("`@(&-A<V4@(F]K(CH*"0D)8G5T=&]N+F]N
M8VQI8VL@/2!F=6YC=&EO;B@I('L*"0D)"7-E;&8N8V%L;$AA;F1L97(H*3L*
M"0D)"7-E;&8N8VQO<V4H*3L*"0D)?3L*"0D)8G)E86L["@D)("`@(&-A<V4@
M(F-A;F-E;"(Z"@D)"6)U='1O;BYO;F-L:6-K(#T@9G5N8W1I;VXH*2!["@D)
M"0ES96QF+F-L;W-E*"D["@D)"7T["@D)"6)R96%K.PH)"7T*"7T*?3L*````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!W:6XN:G,`````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`W,S4S`#$P-#$W,S8S,#`W`#`R,S4T-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O+R`H8RD@9'EN
M87)C:"YC;VT@,C`P,RTR,#`U"B\O($1I<W1R:6)U=&5D('5N9&5R('1H92!S
M86UE('1E<FUS(&%S($A434Q!<F5A(&ET<V5L9BX*"F9U;F-T:6]N(%!O<'5P
M5VEN*&5D:71O<BP@=&ET;&4L(&AA;F1L97(L(&EN:71&=6YC=&EO;BD@>PH)
M=&AI<RYE9&ET;W(@/2!E9&ET;W(["@ET:&ES+FAA;F1L97(@/2!H86YD;&5R
M.PH)=F%R(&1L9R`]('=I;F1O=RYO<&5N*"(B+"`B7U]H85]D:6%L;V<B+`H)
M"0D@("`@("`B=&]O;&)A<CUN;RQM96YU8F%R/6YO+'!E<G-O;F%L8F%R/6YO
M+'=I9'1H/38P,"QH96EG:'0]-C`P+&QE9G0],C`L=&]P/30P(B`K"@D)"2`@
M("`@(")S8W)O;&QB87)S/6YO+')E<VEZ86)L93UN;R(I.PH)=&AI<RYW:6YD
M;W<@/2!D;&<["@EV87(@9&]C(#T@9&QG+F1O8W5M96YT.PH)=&AI<RYD;V,@
M/2!D;V,["@EV87(@<V5L9B`]('1H:7,["@H)=F%R(&)A<V4@/2!D;V-U;65N
M="YB87-E55))('Q\(&1O8W5M96YT+E523#L*"6EF("AB87-E("8F(&)A<V4N
M;6%T8V@H+R@N*BE<+RA;7EPO72LI+RDI('L*"0EB87-E(#T@4F5G17AP+B0Q
M("L@(B\B.PH)?0H):68@*'1Y<&5O9B!?961I=&]R7W5R;"`A/2`B=6YD969I
M;F5D(B`F)B`A+UY<+R\N=&5S="A?961I=&]R7W5R;"D@)B8@(2]H='1P.EPO
M7"\O+G1E<W0H7V5D:71O<E]U<FPI*2!["@D)+R\@7V5D:71O<E]U<FP@9&]E
M<VXG="!S=&%R="!W:71H("<O)R!W:&EC:"!M96%N<R!I="=S(')E;&%T:79E
M"@D)+R\@1DE8344Z('1H97)E)W,@82!P<F]B;&5M(&AE<F4L(&ET(&-O=6QD
M(&)E(&AT='`Z+R\@=VAI8V@*"0DO+R!D;V5S;B=T('-T87)T('=I=&@@<VQA
M<V@@8G5T(&ET)W,@;F]T(')E;&%T:79E(&5I=&AE<BX*"0EB87-E("L](%]E
M9&ET;W)?=7)L.PH)?2!E;'-E"@D)8F%S92`](%]E9&ET;W)?=7)L.PH):68@
M*"$O7"\D+RYT97-T*&)A<V4I*2!["@D)+R\@8F%S92!D;V5S(&YO="!E;F0@
M:6X@<VQA<V@L(&%D9"!I="!N;W<*"0EB87-E("L]("<O)SL*"7T*"71H:7,N
M8F%S95523"`](&)A<V4["@H)9&]C+F]P96XH*3L*"79A<B!H=&UL(#T@(CQH
M=&UL/CQH96%D/CQT:71L93XB("L@=&ET;&4@*R`B/"]T:71L93Y<;B(["@DO
M+R!H=&UL("L]("(\8F%S92!H<F5F/2<B("L@8F%S92`K(")H=&UL87)E82YJ
M<R<@+SY<;B(["@EH=&UL("L]("(\<W1Y;&4@='EP93TG=&5X="]C<W,G/D!I
M;7!O<G0@=7)L*"(@*R!B87-E("L@(FAT;6QA<F5A+F-S<RD[/"]S='EL93X\
M+VAE860^7&XB.PH):'1M;"`K/2`B/&)O9'D@8VQA<W,])V1I86QO9R!P;W!U
M<'=I;B<@:60])RTM2$$M8F]D>2<^/"]B;V1Y/CPO:'1M;#XB.PH)9&]C+G=R
M:71E*&AT;6PI.PH)9&]C+F-L;W-E*"D["@H)+R\@<V]M971I;65S($D@2&%T
M92!-;WII;&QA+BXN(#LM*`H)9G5N8W1I;VX@:6YI=#(H*2!["@D)=F%R(&)O
M9'D@/2!D;V,N8F]D>3L*"0EI9B`H(6)O9'DI('L*"0D)<V5T5&EM96]U="AI
M;FET,BP@,C4I.PH)"0ER971U<FX@9F%L<V4["@D)?0H)"61L9RYT:71L92`]
M('1I=&QE.PH)"61O8RYD;V-U;65N=$5L96UE;G0N<W1Y;&4N<&%D9&EN9R`]
M("(P<'@B.PH)"61O8RYD;V-U;65N=$5L96UE;G0N<W1Y;&4N;6%R9VEN(#T@
M(C!P>"(["@D)=F%R(&-O;G1E;G0@/2!D;V,N8W)E871E16QE;65N="@B9&EV
M(BD["@D)8V]N=&5N="YC;&%S<TYA;64@/2`B8V]N=&5N="(["@D)<V5L9BYC
M;VYT96YT(#T@8V]N=&5N=#L*"0EB;V1Y+F%P<&5N9$-H:6QD*&-O;G1E;G0I
M.PH)"7-E;&8N96QE;65N="`](&)O9'D["@D):6YI=$9U;F-T:6]N*'-E;&8I
M.PH)"61L9RYF;V-U<R@I.PH)?3L*"6EN:70R*"D["GT["@I0;W!U<%=I;BYP
M<F]T;W1Y<&4N8V%L;$AA;F1L97(@/2!F=6YC=&EO;B@I('L*"79A<B!T86=S
M(#T@6R)I;G!U="(L(")T97AT87)E82(L(")S96QE8W0B73L*"79A<B!P87)A
M;7,@/2!N97<@3V)J96-T*"D["@EF;W(@*'9A<B!T:2`]('1A9W,N;&5N9W1H
M.R`M+71I(#X](#`[*2!["@D)=F%R('1A9R`]('1A9W-;=&E=.PH)"79A<B!E
M;',@/2!T:&ES+F-O;G1E;G0N9V5T16QE;65N='-">51A9TYA;64H=&%G*3L*
M"0EF;W(@*'9A<B!J(#T@,#L@:B`\(&5L<RYL96YG=&@[("LK:BD@>PH)"0EV
M87(@96P@/2!E;'-;:ET["@D)"79A<B!V86P@/2!E;"YV86QU93L*"0D):68@
M*&5L+G1A9TYA;64N=&],;W=E<D-A<V4H*2`]/2`B:6YP=70B*2!["@D)"0EI
M9B`H96PN='EP92`]/2`B8VAE8VMB;W@B*2!["@D)"0D)=F%L(#T@96PN8VAE
M8VME9#L*"0D)"7T*"0D)?0H)"0EP87)A;7-;96PN;F%M95T@/2!V86P["@D)
M?0H)?0H)=&AI<RYH86YD;&5R*'1H:7,L('!A<F%M<RD["@ER971U<FX@9F%L
M<V4["GT["@I0;W!U<%=I;BYP<F]T;W1Y<&4N8VQO<V4@/2!F=6YC=&EO;B@I
M('L*"71H:7,N=VEN9&]W+F-L;W-E*"D["GT["@I0;W!U<%=I;BYP<F]T;W1Y
M<&4N861D0G5T=&]N<R`](&9U;F-T:6]N*"D@>PH)=F%R('-E;&8@/2!T:&ES
M.PH)=F%R(&1I=B`]('1H:7,N9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)
M=&AI<RYC;VYT96YT+F%P<&5N9$-H:6QD*&1I=BD["@ED:78N8VQA<W-.86UE
M(#T@(F)U='1O;G,B.PH)9F]R("AV87(@:2`](#`[(&D@/"!A<F=U;65N=',N
M;&5N9W1H.R`K*VDI('L*"0EV87(@8G1N(#T@87)G=6UE;G1S6VE=.PH)"79A
M<B!B=71T;VX@/2!T:&ES+F1O8RYC<F5A=&5%;&5M96YT*")B=71T;VXB*3L*
M"0ED:78N87!P96YD0VAI;&0H8G5T=&]N*3L*"0EB=71T;VXN:6YN97)(5$U,
M(#T@2%1-3$%R96$N23$X3BYB=71T;VYS6V)T;ET["@D)<W=I=&-H("AB=&XI
M('L*"0D@("`@8V%S92`B;VLB.@H)"0EB=71T;VXN;VYC;&EC:R`](&9U;F-T
M:6]N*"D@>PH)"0D)<V5L9BYC86QL2&%N9&QE<B@I.PH)"0D)<V5L9BYC;&]S
M92@I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E].PH)"0EB<F5A:SL*"0D@("`@
M8V%S92`B8V%N8V5L(CH*"0D)8G5T=&]N+F]N8VQI8VL@/2!F=6YC=&EO;B@I
M('L*"0D)"7-E;&8N8VQO<V4H*3L*"0D)"7)E='5R;B!F86QS93L*"0D)?3L*
M"0D)8G)E86L["@D)?0H)?0I].PH*4&]P=7!7:6XN<')O=&]T>7!E+G-H;W=!
M=$5L96UE;G0@/2!F=6YC=&EO;B@I('L*"79A<B!S96QF(#T@=&AI<SL*"2\O
M($UO>FEL;&$@;F5E9',@<V]M92!T:6UE('1O(')E86QI>F4@=VAA="=S(&=O
M:6XG(&]N+BX*"7-E=%1I;65O=70H9G5N8W1I;VXH*2!["@D)=F%R('<@/2!S
M96QF+F-O;G1E;G0N;V9F<V5T5VED=&@@*R`T.PH)"79A<B!H(#T@<V5L9BYC
M;VYT96YT+F]F9G-E=$AE:6=H="`K(#0["@D)+R\@<VEZ92!T;R!C;VYT96YT
M("TM('1H870G<R!F=6-K:6XG(&)U9V=Y(&EN(&%L;"!F=6-K:6XG(&)R;W=S
M97)S(2$A"@D)+R\@<V\@=&AA="!W92!S970@82!L87)G97(@<VEZ92!F;W(@
M=&AE(&1I86QO9R!W:6YD;W<@86YD('1H96X@8V5N=&5R"@D)+R\@=&AE(&5L
M96UE;G0@:6YS:61E+BXN('!H=6-K(0H*"0DO+R!C96YT97(N+BX*"0EV87(@
M96P@/2!S96QF+F-O;G1E;G0["@D)=F%R(',@/2!E;"YS='EL93L*"0DO+R!S
M+G=I9'1H(#T@96PN;V9F<V5T5VED=&@@*R`B<'@B.PH)"2\O(',N:&5I9VAT
M(#T@96PN;V9F<V5T2&5I9VAT("L@(G!X(CL*"0ES+G!O<VET:6]N(#T@(F%B
M<V]L=71E(CL*"0ES+FQE9G0@/2`H=R`M(&5L+F]F9G-E=%=I9'1H*2`O(#(@
M*R`B<'@B.PH)"7,N=&]P(#T@*&@@+2!E;"YO9F9S971(96EG:'0I("\@,B`K
M(")P>"(["@D):68@*$A434Q!<F5A+FES7V=E8VMO*2!["@D)"7-E;&8N=VEN
M9&]W+FEN;F5R5VED=&@@/2!W.PH)"0ES96QF+G=I;F1O=RYI;FYE<DAE:6=H
M="`](&@["@D)?2!E;'-E('L*"0D)<V5L9BYW:6YD;W<N<F5S:7IE5&\H=R`K
M(#@L(&@@*R`S-2D["@D)?0H)?2P@,C4I.PI].PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M
M;&%R96$N:G,`````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,C,W,C,R`#$P-#$W,S8S
M,#`W`#`R,S0V-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O+R!H=&UL07)E82!V,RXP("T@0V]P>7)I9VAT("AC*2`R,#`S
M+3(P,#4@9'EN87)C:"YC;VT*+R\@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,C`P,BTR,#`S(&EN=&5R86-T:79E=&]O;',N8V]M+"!I;F,N"B\O
M(%1H:7,@8V]P>7)I9VAT(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U
M<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O($$@9G)E92!765-)5UE'(&5D
M:71O<B!R97!L86-E;65N="!F;W(@/'1E>'1A<F5A/B!F:65L9',N"B\O($9O
M<B!F=6QL('-O=7)C92!C;V1E(&%N9"!D;V-S+"!V:7-I="!H='1P.B\O=W=W
M+FEN=&5R86-T:79E=&]O;',N8V]M+PHO+PHO+R!697)S:6]N(#,N,"!D979E
M;&]P960@8GD@36EH86D@0F%Z;VXN"B\O("`@:'1T<#HO+V1Y;F%R8V@N8V]M
M+VUI<VAO;R\*+R\*+R\@)$ED.B!H=&UL87)E82YJ<RQV(#$N.3<@,C`P-2\P
M,2\R.2`P,#HT-CHU,2!I=&]O;',@17AP("0*"FEF("AT>7!E;V8@7V5D:71O
M<E]U<FP@/3T@(G-T<FEN9R(I('L*"2\O($QE879E(&5X86-T;'D@;VYE(&)A
M8VMS;&%S:"!A="!T:&4@96YD(&]F(%]E9&ET;W)?=7)L"@E?961I=&]R7W5R
M;"`](%]E9&ET;W)?=7)L+G)E<&QA8V4H+UQX,F8J)"\L("<O)RD["GT@96QS
M92!["@EA;&5R="@B5T%23DE.1SH@7V5D:71O<E]U<FP@:7,@;F]T('-E="$@
M(%EO=2!S:&]U;&0@<V5T('1H:7,@=F%R:6%B;&4@=&\@=&AE(&5D:71O<B!F
M:6QE<R!P871H.R!I="!S:&]U;&0@<')E9F5R86)L>2!B92!A;B!A8G-O;'5T
M92!P871H+"!L:6ME(&EN("<O:'1M;&%R96$O)RP@8G5T(&ET(&-A;B!B92!R
M96QA=&EV92!I9B!Y;W4@<')E9F5R+B`@1G5R=&AE<B!W92!W:6QL('1R>2!T
M;R!L;V%D('1H92!E9&ET;W(@9FEL97,@8V]R<F5C=&QY(&)U="!W92=L;"!P
M<F]B86)L>2!F86EL+B(I.PH)7V5D:71O<E]U<FP@/2`G)SL*?0H*+R\@;6%K
M92!S=7)E('=E(&AA=F4@82!L86YG=6%G90II9B`H='EP96]F(%]E9&ET;W)?
M;&%N9R`]/2`B<W1R:6YG(BD@>PH)7V5D:71O<E]L86YG(#T@7V5D:71O<E]L
M86YG+G1O3&]W97)#87-E*"D["GT@96QS92!["@E?961I=&]R7VQA;F<@/2`B
M96XB.PI]"@HO+R!B<F]W<V5R(&ED96YT:69I8V%T:6]N"DA434Q!<F5A+F%G
M="`](&YA=FEG871O<BYU<V5R06=E;G0N=&],;W=E<D-A<V4H*3L*2%1-3$%R
M96$N:7-?:64)("`@/2`H*$A434Q!<F5A+F%G="YI;F1E>$]F*")M<VEE(BD@
M(3T@+3$I("8F("A(5$U,07)E82YA9W0N:6YD97A/9B@B;W!E<F$B*2`]/2`M
M,2DI.PI(5$U,07)E82YI<U]O<&5R82`@/2`H2%1-3$%R96$N86=T+FEN9&5X
M3V8H(F]P97)A(BD@(3T@+3$I.PI(5$U,07)E82YI<U]M86,)("`@/2`H2%1-
M3$%R96$N86=T+FEN9&5X3V8H(FUA8R(I("$]("TQ*3L*2%1-3$%R96$N:7-?
M;6%C7VEE(#T@*$A434Q!<F5A+FES7VEE("8F($A434Q!<F5A+FES7VUA8RD[
M"DA434Q!<F5A+FES7W=I;E]I92`]("A(5$U,07)E82YI<U]I92`F)B`A2%1-
M3$%R96$N:7-?;6%C*3L*2%1-3$%R96$N:7-?9V5C:V\@(#T@*&YA=FEG871O
M<BYP<F]D=6-T(#T](")'96-K;R(I.PH*+R\@0W)E871E<R!A(&YE=R!(5$U,
M07)E82!O8FIE8W0N("!4<FEE<R!T;R!R97!L86-E('1H92!T97AT87)E82!W
M:71H('1H92!G:79E;@HO+R!)1"!W:71H(&ET+@IF=6YC=&EO;B!(5$U,07)E
M82AT97AT87)E82P@8V]N9FEG*2!["B`@("`@("`@:68@*"%(5$U,07)E82Y?
M:6YI=%]C86QL960I('L*"2!A;&5R="@B17)R;W(Z(%EO=2!M=7-T(&-A;&QE
M9"!(5$U,07)E82YI;FET*"D@9FER<W0N("!,:6ME('1H:7,Z7&Y<;B(@*PH)
M("`@("`@(")(5$U,07)E82YI;FET*"D[7&XB("L*"2`@("`@("`B2%1-3$%R
M96$N;VYL;V%D(#T@9G5N8W1I;VXH*2![7&XB("L*"2`@("`@("`B("!V87(@
M961I=&]R(#T@;F5W($A434Q!<F5A*"=E9&ET;W(G*3M<;B(@*PH)("`@("`@
M("(@(&5D:71O<BYG96YE<F%T92@I.UQN(B`K"@D@("`@("`@(GT[7&XB*3L*
M"2`@<F5T=7)N.PH)?0H*"6EF("A(5$U,07)E82YC:&5C:U-U<'!O<G1E9$)R
M;W=S97(H*2D@>PH)"6EF("AT>7!E;V8@8V]N9FEG(#T](")U;F1E9FEN960B
M*2!["@D)"71H:7,N8V]N9FEG(#T@;F5W($A434Q!<F5A+D-O;F9I9R@I.PH)
M"7T@96QS92!["@D)"71H:7,N8V]N9FEG(#T@8V]N9FEG.PH)"7T*"0ET:&ES
M+E]H=&UL07)E82`](&YU;&P["@D)=&AI<RY?=&5X=$%R96$@/2!T97AT87)E
M83L*"0ET:&ES+E]E9&ET36]D92`](")W>7-I=WEG(CL*"0ET:&ES+G!L=6=I
M;G,@/2![?3L*"0ET:&ES+E]T:6UE<E1O;VQB87(@/2!N=6QL.PH)"71H:7,N
M7W1I;65R56YD;R`](&YU;&P["@D)=&AI<RY?=6YD;U%U975E(#T@;F5W($%R
M<F%Y*'1H:7,N8V]N9FEG+G5N9&]3=&5P<RD["@D)=&AI<RY?=6YD;U!O<R`]
M("TQ.PH)"71H:7,N7V-U<W1O;55N9&\@/2!F86QS93L*"0ET:&ES+E]M9&]C
M(#T@9&]C=6UE;G0[("\O(&-A8VAE('1H92!D;V-U;65N="P@=V4@;F5E9"!I
M="!I;B!P;'5G:6YS"@D)=&AI<RYD;V-T>7!E(#T@)R<["@E]"GT["@I(5$U,
M07)E82YO;FQO860@/2!F=6YC=&EO;B@I>WT["DA434Q!<F5A+E]S8W)I<'1S
M(#T@6UT["DA434Q!<F5A+FQO86138W)I<'0@/2!F=6YC=&EO;BAU<FPL('!L
M=6=I;BD@>PH):68@*'!L=6=I;BD*"0EU<FP@/2!(5$U,07)E82YG9710;'5G
M:6Y$:7(H<&QU9VEN*2`K("<O)R`K('5R;#L*"71H:7,N7W-C<FEP=',N<'5S
M:"AU<FPI.PI].PH*2%1-3$%R96$N:6YI="`](&9U;F-T:6]N*"D@>PH)=F%R
M(&AE860@/2!D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@B:&5A9"(I
M6S!=.PH)=F%R(&-U<G)E;G0@/2`P.PH)=F%R('-A=F5T:71L92`](&1O8W5M
M96YT+G1I=&QE.PH)=F%R(&5V="`]($A434Q!<F5A+FES7VEE(#\@(F]N<F5A
M9'ES=&%T96-H86YG92(@.B`B;VYL;V%D(CL*"69U;F-T:6]N(&QO861.97AT
M4V-R:7!T*"D@>PH)"6EF("AC=7)R96YT(#X@,"`F)B!(5$U,07)E82YI<U]I
M92`F)@H)"2`@("`A+VQO861E9'QC;VUP;&5T92\N=&5S="AW:6YD;W<N979E
M;G0N<W)C16QE;65N="YR96%D>5-T871E*2D*"0D)<F5T=7)N.PH)"6EF("AC
M=7)R96YT(#P@2%1-3$%R96$N7W-C<FEP=',N;&5N9W1H*2!["@D)"79A<B!U
M<FP@/2!(5$U,07)E82Y?<V-R:7!T<UMC=7)R96YT*RM=.PH)"0ED;V-U;65N
M="YT:71L92`](");2%1-3$%R96$Z(&QO861I;F<@<V-R:7!T("(@*R!C=7)R
M96YT("L@(B\B("L@2%1-3$%R96$N7W-C<FEP=',N;&5N9W1H("L@(ETB.PH)
M"0EV87(@<V-R:7!T(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B<V-R:7!T
M(BD["@D)"7-C<FEP="YT>7!E(#T@(G1E>'0O:F%V87-C<FEP="(["@D)"7-C
M<FEP="YS<F,@/2!U<FP["@D)"7-C<FEP=%ME=G1=(#T@;&]A9$YE>'138W)I
M<'0["@D)"6AE860N87!P96YD0VAI;&0H<V-R:7!T*3L*"0E](&5L<V4@>PH)
M"0ED;V-U;65N="YT:71L92`]('-A=F5T:71L93L*("`@("`@("`@("`@("`@
M("`@("`@("`@2%1-3$%R96$N7VEN:71?8V%L;&5D(#T@,3L*"0D)2%1-3$%R
M96$N;VYL;V%D*"D["@D)?0H)?3L*"6QO861.97AT4V-R:7!T*"D["@I].PH*
M2%1-3$%R96$N;&]A9%-C<FEP="A?961I=&]R7W5R;"`K(")D:6%L;V<N:G,B
M*3L*2%1-3$%R96$N;&]A9%-C<FEP="A?961I=&]R7W5R;"`K(")P;W!U<'=I
M;BYJ<R(I.PI(5$U,07)E82YL;V%D4V-R:7!T*%]E9&ET;W)?=7)L("L@(FQA
M;F<O(B`K(%]E9&ET;W)?;&%N9R`K("(N:G,B*3L*"B\O(&-A8VAE('-O;64@
M<F5G97AP<PI(5$U,07)E82Y215]T86=.86UE(#T@+R@\7"]\/"E<<RHH6UX@
M7'1<;CY=*RDO:6<["DA434Q!<F5A+E)%7V1O8W1Y<&4@/2`O*#PA9&]C='EP
M92@H+GQ<;BDJ/RD^*5QN/R]I.PI(5$U,07)E82Y215]H96%D("`@(#T@+SQH
M96%D/B@H+GQ<;BDJ/RD\7"]H96%D/B]I.PI(5$U,07)E82Y215]B;V1Y("`@
M(#T@+SQB;V1Y/B@H+GQ<;BDJ/RD\7"]B;V1Y/B]I.PH*2%1-3$%R96$N0V]N
M9FEG(#T@9G5N8W1I;VX@*"D@>PH)=&AI<RYV97)S:6]N(#T@(C,N,"(["@H)
M=&AI<RYW:61T:"`](")A=71O(CL*"71H:7,N:&5I9VAT(#T@(F%U=&\B.PH*
M"2\O(&5N86)L92!C<F5A=&EO;B!O9B!A('-T871U<R!B87(_"@ET:&ES+G-T
M871U<T)A<B`]('1R=64["@H)+R\@:6YT97)C97!T(%Y6(&%N9"!U<V4@=&AE
M($A434Q!<F5A('!A<W1E(&-O;6UA;F0*"2\O($EF(&9A;'-E+"!T:&5N('!A
M<W-E<R!>5B!T:')O=6=H('1O(&)R;W=S97(@961I=&]R('=I9&=E=`H)=&AI
M<RYH=&UL87)E85!A<W1E(#T@9F%L<V4["@H)+R\@;6%X:6UU;2!S:7IE(&]F
M('1H92!U;F1O('%U975E"@ET:&ES+G5N9&]3=&5P<R`](#(P.PH*"2\O('1H
M92!T:6UE(&EN=&5R=F%L(&%T('=H:6-H('5N9&\@<V%M<&QE<R!A<F4@=&%K
M96X*"71H:7,N=6YD;U1I;65O=70@/2`U,#`["2\O(#$O,B!S96,N"@H)+R\@
M=&AE(&YE>'0@<&%R86UE=&5R('-P96-I9FEE<R!W:&5T:&5R('1H92!T;V]L
M8F%R('-H;W5L9"!B92!I;F-L=61E9`H)+R\@:6X@=&AE('-I>F4@;W(@;F]T
M+@H)=&AI<RYS:7IE26YC;'5D97-4;V]L8F%R(#T@=')U93L*"@DO+R!I9B!T
M<G5E('1H96X@2%1-3$%R96$@=VEL;"!R971R:65V92!T:&4@9G5L;"!(5$U,
M+"!S=&%R=&EN9R!W:71H('1H90H)+R\@/$A434P^('1A9RX*"71H:7,N9G5L
M;%!A9V4@/2!F86QS93L*"@DO+R!S='EL92!I;F-L=61E9"!I;B!T:&4@:69R
M86UE(&1O8W5M96YT"@ET:&ES+G!A9V53='EL92`]("(B.PH*"2\O('-E="!T
M;R!T<G5E(&EF('EO=2!W86YT(%=O<F0@8V]D92!T;R!B92!C;&5A;F5D('5P
M;VX@4&%S=&4*"71H:7,N:VEL;%=O<F1/;E!A<W1E(#T@=')U93L*"@DO+R!E
M;F%B;&4@=&AE("=487)G970G(&9I96QD(&EN('1H92!-86ME($QI;FL@9&EA
M;&]G"@ET:&ES+FUA:V5,:6YK4VAO=W-487)G970@/2!T<G5E.PH*"2\O($)A
M<V554DP@:6YC;'5D960@:6X@=&AE(&EF<F%M92!D;V-U;65N=`H)=&AI<RYB
M87-E55),(#T@9&]C=6UE;G0N8F%S955222!\?"!D;V-U;65N="Y54DP["@EI
M9B`H=&AI<RYB87-E55),("8F('1H:7,N8F%S95523"YM871C:"@O*"XJ*5PO
M*%M>7"]=*RDO*2D*"0ET:&ES+F)A<V554DP@/2!296=%>'`N)#$@*R`B+R([
M"@H)+R\@55),+7,*"71H:7,N:6UG55),(#T@(FEM86=E<R\B.PH)=&AI<RYP
M;W!U<%523"`](")P;W!U<',O(CL*"@DO+R!R96UO=F4@=&%G<R`H=&AE<V4@
M:&%V92!T;R!B92!A(')E9V5X<"P@;W(@;G5L;"!I9B!T:&ES(&9U;F-T:6]N
M86QI='D@:7,@;F]T(&1E<VER960I"@ET:&ES+FAT;6Q296UO=F5486=S(#T@
M;G5L;#L*"@DO*BH@0U535$]-25I)3D<@5$A%(%1/3TQ"05(*"2`J("TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2T*"2`J"@D@*B!)="!I<R!R96-O;6UE;F1E
M9"!T:&%T('EO=2!C=7-T;VUI>F4@=&AE('1O;VQB87(@8V]N=&5N=',@:6X@
M86X*"2`J(&5X=&5R;F%L(&9I;&4@*&DN92X@=&AE(&]N92!C86QL:6YG($A4
M34Q!<F5A*2!A;F0@;&5A=F4@=&AI<R!O;F4*"2`J('5N8VAA;F=E9"X@(%1H
M870G<R!B96-A=7-E('=H96X@=V4@*$EN=&5R86-T:79E5&]O;',N8V]M*2!R
M96QE87-E(&$*"2`J(&YE=R!O9F9I8VEA;"!V97)S:6]N+"!I="=S(&QE<W,@
M;&EK96QY('1H870@>6]U('=I;&P@:&%V92!P<F]B;&5M<PH)("H@=7!G<F%D
M:6YG($A434Q!<F5A+@H)("HO"@ET:&ES+G1O;VQB87(@/2!;"@D)6R`B9F]N
M=&YA;64B+"`B<W!A8V4B+`H)"2`@(F9O;G1S:7IE(BP@(G-P86-E(BP*"0D@
M(")F;W)M871B;&]C:R(L(")S<&%C92(L"@D)("`B8F]L9"(L(")I=&%L:6,B
M+"`B=6YD97)L:6YE(BP@(G-T<FEK971H<F]U9V@B+"`B<V5P87)A=&]R(BP*
M"0D@(")S=6)S8W)I<'0B+"`B<W5P97)S8W)I<'0B+"`B<V5P87)A=&]R(BP*
M"0D@(")C;W!Y(BP@(F-U="(L(")P87-T92(L(")S<&%C92(L(")U;F1O(BP@
M(G)E9&\B+"`B<W!A8V4B+"`B<F5M;W9E9F]R;6%T(BP@(FMI;&QW;W)D(B!=
M+`H*"0E;(")J=7-T:69Y;&5F="(L(")J=7-T:69Y8V5N=&5R(BP@(FIU<W1I
M9GER:6=H="(L(")J=7-T:69Y9G5L;"(L(")S97!A<F%T;W(B+`H)"2`@(FQE
M9G1T;W)I9VAT(BP@(G)I9VAT=&]L969T(BP@(G-E<&%R871O<B(L"@D)("`B
M;W)D97)E9&QI<W0B+"`B=6YO<F1E<F5D;&ES="(L(")O=71D96YT(BP@(FEN
M9&5N="(L(")S97!A<F%T;W(B+`H)"2`@(F9O<F5C;VQO<B(L(")H:6QI=&5C
M;VQO<B(L(")S97!A<F%T;W(B+`H)"2`@(FEN<V5R=&AO<FEZ;VYT86QR=6QE
M(BP@(F-R96%T96QI;FLB+"`B:6YS97)T:6UA9V4B+"`B:6YS97)T=&%B;&4B
M+"`B:'1M;&UO9&4B+"`B<V5P87)A=&]R(BP*"0D@(")P;W!U<&5D:71O<B(L
M(")S97!A<F%T;W(B+"`B<VAO=VAE;'`B+"`B86)O=70B(%T*"5T["@H)=&AI
M<RYF;VYT;F%M92`]('L*"0DB)FUD87-H.R!F;VYT("9M9&%S:#LB.B`@("`@
M("`@("<G+`H)"2)!<FEA;"(Z"2`@("=A<FEA;"QH96QV971I8V$L<V%N<RUS
M97)I9B<L"@D)(D-O=7)I97(@3F5W(CH)("`@)V-O=7)I97(@;F5W+&-O=7)I
M97(L;6]N;W-P86-E)RP*"0DB1V5O<F=I82(Z"2`@("=G96]R9VEA+'1I;65S
M(&YE=R!R;VUA;BQT:6UE<RQS97)I9B<L"@D)(E1A:&]M82(Z"2`@("=T86AO
M;6$L87)I86PL:&5L=F5T:6-A+'-A;G,M<V5R:68G+`H)"2)4:6UE<R!.97<@
M4F]M86XB.B`G=&EM97,@;F5W(')O;6%N+'1I;65S+'-E<FEF)RP*"0DB5F5R
M9&%N82(Z"2`@("=V97)D86YA+&%R:6%L+&AE;'9E=&EC82QS86YS+7-E<FEF
M)RP*"0DB:6UP86-T(CH)("`@)VEM<&%C="<L"@D)(E=I;F=$:6YG<R(Z"2`@
M("=W:6YG9&EN9W,G"@E].PH*"71H:7,N9F]N='-I>F4@/2!["@D)(B9M9&%S
M:#L@<VEZ92`F;61A<V@[(B`@.B`B(BP*"0DB,2`H."!P="DB(#H@(C$B+`H)
M"2(R("@Q,"!P="DB.B`B,B(L"@D)(C,@*#$R('!T*2(Z("(S(BP*"0DB-"`H
M,30@<'0I(CH@(C0B+`H)"2(U("@Q."!P="DB.B`B-2(L"@D)(C8@*#(T('!T
M*2(Z("(V(BP*"0DB-R`H,S8@<'0I(CH@(C<B"@E].PH*"71H:7,N9F]R;6%T
M8FQO8VL@/2!["@D)(B9M9&%S:#L@9F]R;6%T("9M9&%S:#LB("`Z("(B+`H)
M"2)(96%D:6YG(#$B.B`B:#$B+`H)"2)(96%D:6YG(#(B.B`B:#(B+`H)"2)(
M96%D:6YG(#,B.B`B:#,B+`H)"2)(96%D:6YG(#0B.B`B:#0B+`H)"2)(96%D
M:6YG(#4B.B`B:#4B+`H)"2)(96%D:6YG(#8B.B`B:#8B+`H)"2).;W)M86PB
M("`@.B`B<"(L"@D)(D%D9')E<W,B("`Z(")A9&1R97-S(BP*"0DB1F]R;6%T
M=&5D(CH@(G!R92(*"7T["@H)=&AI<RYC=7-T;VU396QE8W1S(#T@>WT["@H)
M9G5N8W1I;VX@8W5T7V-O<'E?<&%S=&4H92P@8VUD+"!O8FHI('L*"0EE+F5X
M96-#;VUM86YD*&-M9"D["@E].PH*"71H:7,N9&5B=6<@/2!T<G5E.PH*"2\O
M($%$1$E.1R!#55-43TT@0E545$].4SH@<&QE87-E(')E860@8F5L;W<A"@DO
M+R!F;W)M870@;V8@=&AE(&)T;DQI<W0@96QE;65N=',@:7,@(DE$.B!;(%1O
M;VQ4:7`L($EC;VXL($5N86)L960@:6X@=&5X="!M;V1E/RP@04-424].(%TB
M"@DO+R`@("`M($E$.B!U;FEQ=64@240@9F]R('1H92!B=71T;VXN("!)9B!T
M:&4@8G5T=&]N(&-A;&QS(&1O8W5M96YT+F5X96-#;VUM86YD"@DO+PD@("`@
M:70G<R!W:7-E('1O(&=I=F4@:70@=&AE('-A;64@;F%M92!A<R!T:&4@8V%L
M;&5D(&-O;6UA;F0N"@DO+R`@("`M($%#5$E/3CH@9G5N8W1I;VX@=&AA="!G
M971S(&-A;&QE9"!W:&5N('1H92!B=71T;VX@:7,@8VQI8VME9"X*"2\O("`@
M("`@("`@("`@("!I="!H87,@=&AE(&9O;&QO=VEN9R!P<F]T;W1Y<&4Z"@DO
M+R`@("`@("`@("`@("`@("`@9G5N8W1I;VXH961I=&]R+"!B=71T;VY.86UE
M*0H)+R\@("`@("`@("`@("`@("T@961I=&]R(&ES('1H92!(5$U,07)E82!O
M8FIE8W0@=&AA="!T<FEG9V5R960@=&AE(&-A;&P*"2\O("`@("`@("`@("`@
M("`M(&)U='1O;DYA;64@:7,@=&AE($E$(&]F('1H92!C;&EC:V5D(&)U='1O
M;@H)+R\@("`@("`@("`@("`@(%1H97-E(#(@<&%R86UE=&5R<R!M86ME<R!I
M="!P;W-S:6)L92!F;W(@>6]U('1O('5S92!T:&4@<V%M90H)+R\@("`@("`@
M("`@("`@(&AA;F1L97(@9F]R(&UO<F4@2%1-3$%R96$@;V)J96-T<R!O<B!F
M;W(@;6]R92!D:69F97)E;G0@8G5T=&]N<RX*"2\O("`@("T@5&]O;%1I<#H@
M9&5F875L="!T;V]L=&EP+"!F;W(@8V%S97,@=VAE;B!I="!I<R!N;W0@9&5F
M:6YE9"!I;B!T:&4@+6QA;F<M(&9I;&4@*$A434Q!<F5A+DDQ.$XI"@DO+R`@
M("`M($EC;VXZ('!A=&@@=&\@86X@:6-O;B!I;6%G92!F:6QE(&9O<B!T:&4@
M8G5T=&]N("A43T1/.B!U<V4@;VYE(&EM86=E(&9O<B!A;&P@8G5T=&]N<R$I
M"@DO+R`@("`M($5N86)L960@:6X@=&5X="!M;V1E.B!I9B!F86QS92!T:&4@
M8G5T=&]N(&=E=',@9&ES86)L960@9F]R('1E>'0M;VYL>2!M;V1E.R!O=&AE
M<G=I<V4@96YA8FQE9"!A;&P@=&AE('1I;64N"@ET:&ES+F)T;DQI<W0@/2![
M"@D)8F]L9#H@6R`B0F]L9"(L(")E9%]F;W)M871?8F]L9"YG:68B+"!F86QS
M92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(F)O;&0B*3M](%TL"@D)
M:71A;&EC.B!;("))=&%L:6,B+"`B961?9F]R;6%T7VET86QI8RYG:68B+"!F
M86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(FET86QI8R(I.WT@
M72P*"0EU;F1E<FQI;F4Z(%L@(E5N9&5R;&EN92(L(")E9%]F;W)M871?=6YD
M97)L:6YE+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N
M9"@B=6YD97)L:6YE(BD[?2!=+`H)"7-T<FEK971H<F]U9V@Z(%L@(E-T<FEK
M971H<F]U9V@B+"`B961?9F]R;6%T7W-T<FEK92YG:68B+"!F86QS92P@9G5N
M8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G-T<FEK971H<F]U9V@B*3M](%TL
M"@D)<W5B<V-R:7!T.B!;(")3=6)S8W)I<'0B+"`B961?9F]R;6%T7W-U8BYG
M:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G-U8G-C
M<FEP="(I.WT@72P*"0ES=7!E<G-C<FEP=#H@6R`B4W5P97)S8W)I<'0B+"`B
M961?9F]R;6%T7W-U<"YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE
M8T-O;6UA;F0H(G-U<&5R<V-R:7!T(BD[?2!=+`H)"6IU<W1I9GEL969T.B!;
M(")*=7-T:69Y($QE9G0B+"`B961?86QI9VY?;&5F="YG:68B+"!F86QS92P@
M9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(FIU<W1I9GEL969T(BD[?2!=
M+`H)"6IU<W1I9GEC96YT97(Z(%L@(DIU<W1I9GD@0V5N=&5R(BP@(F5D7V%L
M:6=N7V-E;G1E<BYG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O
M;6UA;F0H(FIU<W1I9GEC96YT97(B*3M](%TL"@D):G5S=&EF>7)I9VAT.B!;
M(")*=7-T:69Y(%)I9VAT(BP@(F5D7V%L:6=N7W)I9VAT+F=I9B(L(&9A;'-E
M+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:G5S=&EF>7)I9VAT(BD[
M?2!=+`H)"6IU<W1I9GEF=6QL.B!;(")*=7-T:69Y($9U;&PB+"`B961?86QI
M9VY?:G5S=&EF>2YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O
M;6UA;F0H(FIU<W1I9GEF=6QL(BD[?2!=+`H)"6]R9&5R961L:7-T.B!;(")/
M<F1E<F5D($QI<W0B+"`B961?;&ES=%]N=6TN9VEF(BP@9F%L<V4L(&9U;F-T
M:6]N*&4I('ME+F5X96-#;VUM86YD*")I;G-E<G1O<F1E<F5D;&ES="(I.WT@
M72P*"0EU;F]R9&5R961L:7-T.B!;(")"=6QL971E9"!,:7-T(BP@(F5D7VQI
M<W1?8G5L;&5T+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M
M;6%N9"@B:6YS97)T=6YO<F1E<F5D;&ES="(I.WT@72P*"0EO=71D96YT.B!;
M(")$96-R96%S92!);F1E;G0B+"`B961?:6YD96YT7VQE<W,N9VEF(BP@9F%L
M<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")O=71D96YT(BD[?2!=
M+`H)"6EN9&5N=#H@6R`B26YC<F5A<V4@26YD96YT(BP@(F5D7VEN9&5N=%]M
M;W)E+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B
M:6YD96YT(BD[?2!=+`H)"69O<F5C;VQO<CH@6R`B1F]N="!#;VQO<B(L(")E
M9%]C;VQO<E]F9RYG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O
M;6UA;F0H(F9O<F5C;VQO<B(I.WT@72P*"0EH:6QI=&5C;VQO<CH@6R`B0F%C
M:V=R;W5N9"!#;VQO<B(L(")E9%]C;VQO<E]B9RYG:68B+"!F86QS92P@9G5N
M8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(FAI;&ET96-O;&]R(BD[?2!=+`H)
M"6EN<V5R=&AO<FEZ;VYT86QR=6QE.B!;(")(;W)I>F]N=&%L(%)U;&4B+"`B
M961?:'(N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD
M*")I;G-E<G1H;W)I>F]N=&%L<G5L92(I.WT@72P*"0EC<F5A=&5L:6YK.B!;
M("));G-E<G0@5V5B($QI;FLB+"`B961?;&EN:RYG:68B+"!F86QS92P@9G5N
M8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(F-R96%T96QI;FLB+"!T<G5E*3M]
M(%TL"@D):6YS97)T:6UA9V4Z(%L@(DEN<V5R="]-;V1I9GD@26UA9V4B+"`B
M961?:6UA9V4N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM
M86YD*")I;G-E<G1I;6%G92(I.WT@72P*"0EI;G-E<G1T86)L93H@6R`B26YS
M97)T(%1A8FQE(BP@(FEN<V5R=%]T86)L92YG:68B+"!F86QS92P@9G5N8W1I
M;VXH92D@>V4N97AE8T-O;6UA;F0H(FEN<V5R='1A8FQE(BD[?2!=+`H)"6AT
M;6QM;V1E.B!;(")4;V=G;&4@2%1-3"!3;W5R8V4B+"`B961?:'1M;"YG:68B
M+"!T<G5E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:'1M;&UO9&4B
M*3M](%TL"@D)<&]P=7!E9&ET;W(Z(%L@(D5N;&%R9V4@161I=&]R(BP@(F9U
M;&QS8W)E96Y?;6%X:6UI>F4N9VEF(BP@=')U92P@9G5N8W1I;VXH92D@>V4N
M97AE8T-O;6UA;F0H(G!O<'5P961I=&]R(BD[?2!=+`H)"6%B;W5T.B!;(")!
M8F]U="!T:&ES(&5D:71O<B(L(")E9%]A8F]U="YG:68B+"!T<G5E+"!F=6YC
M=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B86)O=70B*3M](%TL"@D)<VAO=VAE
M;'`Z(%L@(DAE;'`@=7-I;F<@961I=&]R(BP@(F5D7VAE;'`N9VEF(BP@=')U
M92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G-H;W=H96QP(BD[?2!=
M+`H)"75N9&\Z(%L@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(BP@(F5D7W5N
M9&\N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")U
M;F1O(BD[?2!=+`H)"7)E9&\Z(%L@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(BP@(F5D7W)E9&\N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#
M;VUM86YD*")R961O(BD[?2!=+`H)"6-U=#H@6R`B0W5T('-E;&5C=&EO;B(L
M(")E9%]C=70N9VEF(BP@9F%L<V4L(&-U=%]C;W!Y7W!A<W1E(%TL"@D)8V]P
M>3H@6R`B0V]P>2!S96QE8W1I;VXB+"`B961?8V]P>2YG:68B+"!F86QS92P@
M8W5T7V-O<'E?<&%S=&4@72P*"0EP87-T93H@6R`B4&%S=&4@9G)O;2!C;&EP
M8F]A<F0B+"`B961?<&%S=&4N9VEF(BP@9F%L<V4L(&-U=%]C;W!Y7W!A<W1E
M(%TL"@D);&5F='1O<FEG:'0Z(%L@(D1I<F5C=&EO;B!L969T('1O(')I9VAT
M(BP@(F5D7VQE9G1?=&]?<FEG:'0N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I
M('ME+F5X96-#;VUM86YD*")L969T=&]R:6=H="(I.WT@72P*"0ER:6=H='1O
M;&5F=#H@6R`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B+"`B961?<FEG:'1?
M=&]?;&5F="YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA
M;F0H(G)I9VAT=&]L969T(BD[?2!=+`H)"7)E;6]V969O<FUA=#H@6R`B4F5M
M;W9E(&9O<FUA='1I;F<B+"`B961?<FUF;W)M870N9VEF(BP@9F%L<V4L(&9U
M;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")R96UO=F5F;W)M870B*3M](%TL
M"@D)<')I;G0Z(%L@(E!R:6YT(&1O8W5M96YT(BP@(F5D7W!R:6YT+F=I9B(L
M(&9A;'-E+"!F=6YC=&EO;BAE*2![92Y?:69R86UE+F-O;G1E;G17:6YD;W<N
M<')I;G0H*3M](%TL"@D):VEL;'=O<F0Z(%L@(D-L96%R($U33V9F:6-E('1A
M9W,B+"`B961?:VEL;'=O<F0N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME
M+F5X96-#;VUM86YD*")K:6QL=V]R9"(I.WT@70H)?3L*"2\J($%$1$E.1R!#
M55-43TT@0E545$].4PH)("H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@D@*@H)
M("H@270@:7,@<F5C;VUM96YD960@=&AA="!Y;W4@861D('1H92!C=7-T;VT@
M8G5T=&]N<R!I;B!A;B!E>'1E<FYA;`H)("H@9FEL92!A;F0@;&5A=F4@=&AI
M<R!O;F4@=6YC:&%N9V5D+B`@5&AA="=S(&)E8V%U<V4@=VAE;B!W90H)("H@
M*$EN=&5R86-T:79E5&]O;',N8V]M*2!R96QE87-E(&$@;F5W(&]F9FEC:6%L
M('9E<G-I;VXL(&ET)W,@;&5S<PH)("H@;&EK96QY('1H870@>6]U('=I;&P@
M:&%V92!P<F]B;&5M<R!U<&=R861I;F<@2%1-3$%R96$N"@D@*@H)("H@17AA
M;7!L92!O;B!H;W<@=&\@861D(&$@8W5S=&]M(&)U='1O;B!W:&5N('EO=2!C
M;VYS=')U8W0@=&AE($A434Q!<F5A.@H)("H*"2`J("`@=F%R(&5D:71O<B`]
M(&YE=R!(5$U,07)E82@B>6]U<E]T97AT7V%R96%?:60B*3L*"2`J("`@=F%R
M(&-F9R`](&5D:71O<BYC;VYF:6<[("\O('1H:7,@:7,@=&AE(&1E9F%U;'0@
M8V]N9FEG=7)A=&EO;@H)("H@("!C9F<N8G1N3&ES=%LB;7DM:&EL:71E(ET@
M/0H)("H)6R!F=6YC=&EO;BAE9&ET;W(I('L@961I=&]R+G-U<G)O=6YD2%1-
M3"@G/'-P86X@<W1Y;&4](F)A8VMG<F]U;F0Z>65L;&]W(CXG+"`G/"]S<&%N
M/B<I.R!]+"`O+R!A8W1I;VX*"2`J"2`@(DAI9VAL:6=H="!S96QE8W1I;VXB
M+"`O+R!T;V]L=&EP"@D@*@D@(")M>5]H:6QI=&4N9VEF(BP@+R\@:6UA9V4*
M"2`J"2`@9F%L<V4@+R\@9&ES86)L960@:6X@=&5X="!M;V1E"@D@*@E=.PH)
M("H@("!C9F<N=&]O;&)A<BYP=7-H*%LB;&EN96)R96%K(BP@(FUY+6AI;&ET
M92)=*3L@+R\@861D('1H92!N97<@8G5T=&]N('1O('1H92!T;V]L8F%R"@D@
M*@H)("H@06X@86QT97)N871E("AA;'-O(&UO<F4@8V]N=F5N:65N="!A;F0@
M<F5C;VUM96YD960I('=A>2!T;PH)("H@86-C;VUP;&ES:"!T:&ES(&ES('1O
M('5S92!T:&4@<F5G:7-T97)"=71T;VX@9G5N8W1I;VX@8F5L;W<N"@D@*B\*
M"2\O(&EN:71I86QI>F4@=&]O;'1I<',@9G)O;2!T:&4@23$X3B!M;V1U;&4@
M86YD(&=E;F5R871E(&-O<G)E8W0@:6UA9V4@<&%T:`H)9F]R("AV87(@:2!I
M;B!T:&ES+F)T;DQI<W0I('L*"0EV87(@8G1N(#T@=&AI<RYB=&Y,:7-T6VE=
M.PH)"6)T;ELQ72`](%]E9&ET;W)?=7)L("L@=&AI<RYI;6=54DP@*R!B=&Y;
M,5T["@D):68@*'1Y<&5O9B!(5$U,07)E82Y),3A.+G1O;VQT:7!S6VE=("$]
M(")U;F1E9FEN960B*2!["@D)"6)T;ELP72`]($A434Q!<F5A+DDQ.$XN=&]O
M;'1I<'-;:5T["@D)?0H)?0I].PH*+RHJ($AE;'!E<B!F=6YC=&EO;CH@<F5G
M:7-T97(@82!N97<@8G5T=&]N('=I=&@@=&AE(&-O;F9I9W5R871I;VXN("!)
M="!C86X@8F4*("H@8V%L;&5D('=I=&@@86QL(#4@87)G=6UE;G1S+"!O<B!W
M:71H(&]N;'D@;VYE("AF:7)S="!O;F4I+B`@5VAE;B!C86QL960@=VET:`H@
M*B!O;FQY(&]N92!A<F=U;65N="!I="!M=7-T(&)E(&%N(&]B:F5C="!W:71H
M('1H92!F;VQL;W=I;F<@<')O<&5R=&EE<SH@:60L"B`J('1O;VQT:7`L(&EM
M86=E+"!T97AT36]D92P@86-T:6]N+B`@17AA;7!L97,Z"B`J"B`J(#$N(&-O
M;F9I9RYR96=I<W1E<D)U='1O;B@B;7DM:&EL:71E(BP@(DAI;&ET92!T97AT
M(BP@(FUY+6AI;&ET92YG:68B+"!F86QS92P@9G5N8W1I;VXH961I=&]R*2![
M+BXN?2D["B`J(#(N(&-O;F9I9RYR96=I<W1E<D)U='1O;BA["B`J("`@("`@
M:60@("`@("`@.B`B;7DM:&EL:71E(BP@("`@("`O+R!T:&4@240@;V8@>6]U
M<B!B=71T;VX*("H@("`@("!T;V]L=&EP("`Z(")(:6QI=&4@=&5X="(L("`@
M("\O('1H92!T;V]L=&EP"B`J("`@("`@:6UA9V4@("`@.B`B;7DM:&EL:71E
M+F=I9B(L("`O+R!I;6%G92!T;R!B92!D:7-P;&%Y960@:6X@=&AE('1O;VQB
M87(*("H@("`@("!T97AT36]D92`Z(&9A;'-E+"`@("`@("`@("`@("\O(&1I
M<V%B;&5D(&EN('1E>'0@;6]D90H@*B`@("`@(&%C=&EO;B`@(#H@9G5N8W1I
M;VXH961I=&]R*2![("\O(&-A;&QE9"!W:&5N('1H92!B=71T;VX@:7,@8VQI
M8VME9`H@*B`@("`@("`@("`@("`@("`@("!E9&ET;W(N<W5R<F]U;F1(5$U,
M*"<\<W!A;B!C;&%S<STB:&EL:71E(CXG+"`G/"]S<&%N/B<I.PH@*B`@("`@
M("`@("`@("`@("`@?2P*("H@("`@("!C;VYT97AT("`Z(")P(B`@("`@("`@
M("`@("`@("\O('=I;&P@8F4@9&ES86)L960@:68@;W5T<VED92!A(#QP/B!E
M;&5M96YT"B`J("`@('TI.PH@*B\*2%1-3$%R96$N0V]N9FEG+G!R;W1O='EP
M92YR96=I<W1E<D)U='1O;B`](&9U;F-T:6]N*&ED+"!T;V]L=&EP+"!I;6%G
M92P@=&5X=$UO9&4L(&%C=&EO;BP@8V]N=&5X="D@>PH)=F%R('1H95]I9#L*
M"6EF("AT>7!E;V8@:60@/3T@(G-T<FEN9R(I('L*"0ET:&5?:60@/2!I9#L*
M"7T@96QS92!I9B`H='EP96]F(&ED(#T](")O8FIE8W0B*2!["@D)=&AE7VED
M(#T@:60N:60["@E](&5L<V4@>PH)"6%L97)T*")%4E)/4B!;2%1-3$%R96$N
M0V]N9FEG.CIR96=I<W1E<D)U='1O;ETZ7&YI;G9A;&ED(&%R9W5M96YT<R(I
M.PH)"7)E='5R;B!F86QS93L*"7T*"2\O(&-H96-K(&9O<B!E>&ES=&EN9R!I
M9`H):68@*'1Y<&5O9B!T:&ES+F-U<W1O;5-E;&5C='-;=&AE7VED72`A/2`B
M=6YD969I;F5D(BD@>PH)"2\O(&%L97)T*")705).24Y'(%M(5$U,07)E82Y#
M;VYF:6<Z.G)E9VES=&5R1')O<&1O=VY=.EQN02!D<F]P9&]W;B!W:71H('1H
M92!S86UE($E$(&%L<F5A9'D@97AI<W1S+B(I.PH)?0H):68@*'1Y<&5O9B!T
M:&ES+F)T;DQI<W1;=&AE7VED72`A/2`B=6YD969I;F5D(BD@>PH)"2\O(&%L
M97)T*")705).24Y'(%M(5$U,07)E82Y#;VYF:6<Z.G)E9VES=&5R1')O<&1O
M=VY=.EQN02!B=71T;VX@=VET:"!T:&4@<V%M92!)1"!A;')E861Y(&5X:7-T
M<RXB*3L*"7T*"7-W:71C:"`H='EP96]F(&ED*2!["@D@("`@8V%S92`B<W1R
M:6YG(CH@=&AI<RYB=&Y,:7-T6VED72`](%L@=&]O;'1I<"P@:6UA9V4L('1E
M>'1-;V1E+"!A8W1I;VXL(&-O;G1E>'0@73L@8G)E86L["@D@("`@8V%S92`B
M;V)J96-T(CH@=&AI<RYB=&Y,:7-T6VED+FED72`](%L@:60N=&]O;'1I<"P@
M:60N:6UA9V4L(&ED+G1E>'1-;V1E+"!I9"YA8W1I;VXL(&ED+F-O;G1E>'0@
M73L@8G)E86L["@E]"GT["@HO*BH@5&AE(&9O;&QO=VEN9R!H96QP97(@9G5N
M8W1I;VX@<F5G:7-T97)S(&$@9')O<&1O=VX@8F]X('=I=&@@=&AE(&5D:71O
M<@H@*B!C;VYF:6=U<F%T:6]N+B`@66]U('-T:6QL(&AA=F4@=&\@861D(&ET
M('1O('1H92!T;V]L8F%R+"!S86UE(&%S('=I=&@@=&AE"B`J(&)U='1O;G,N
M("!#86QL(&ET(&QI:V4@=&AI<SH*("H*("H@1DE8344Z(&%D9"!E>&%M<&QE
M"B`J+PI(5$U,07)E82Y#;VYF:6<N<')O=&]T>7!E+G)E9VES=&5R1')O<&1O
M=VX@/2!F=6YC=&EO;BAO8FIE8W0I('L*"2\O(&-H96-K(&9O<B!E>&ES=&EN
M9R!I9`H):68@*'1Y<&5O9B!T:&ES+F-U<W1O;5-E;&5C='-;;V)J96-T+FED
M72`A/2`B=6YD969I;F5D(BD@>PH)"2\O(&%L97)T*")705).24Y'(%M(5$U,
M07)E82Y#;VYF:6<Z.G)E9VES=&5R1')O<&1O=VY=.EQN02!D<F]P9&]W;B!W
M:71H('1H92!S86UE($E$(&%L<F5A9'D@97AI<W1S+B(I.PH)?0H):68@*'1Y
M<&5O9B!T:&ES+F)T;DQI<W1;;V)J96-T+FED72`A/2`B=6YD969I;F5D(BD@
M>PH)"2\O(&%L97)T*")705).24Y'(%M(5$U,07)E82Y#;VYF:6<Z.G)E9VES
M=&5R1')O<&1O=VY=.EQN02!B=71T;VX@=VET:"!T:&4@<V%M92!)1"!A;')E
M861Y(&5X:7-T<RXB*3L*"7T*"71H:7,N8W5S=&]M4V5L96-T<UMO8FIE8W0N
M:61=(#T@;V)J96-T.PI].PH*+RHJ($-A;&P@=&AI<R!F=6YC=&EO;B!T;R!R
M96UO=F4@<V]M92!B=71T;VYS+V1R;W`M9&]W;B!B;WAE<R!F<F]M('1H92!T
M;V]L8F%R+@H@*B!087-S(&%S('1H92!O;FQY('!A<F%M971E<B!A('-T<FEN
M9R!C;VYT86EN:6YG(&)U='1O;B]D<F]P+61O=VX@;F%M97,*("H@9&5L:6UI
M=&5D(&)Y('-P86-E<RX@($YO=&4@=&AA="!T:&4@<W1R:6YG('-H;W5L9"!A
M;'-O(&)E9VEN('=I=&@@82!S<&%C90H@*B!A;F0@96YD('=I=&@@82!S<&%C
M92X@($5X86UP;&4Z"B`J"B`J("`@8V]N9FEG+FAI9&53;VUE0G5T=&]N<R@B
M(&9O;G1N86UE(&9O;G1S:7IE('1E>'1I;F1I8V%T;W(@(BD["B`J"B`J($ET
M)W,@=7-E9G5L(&)E8V%U<V4@:70G<R!E87-I97(@=&\@<F5M;W9E('-T=69F
M(&9R;VT@=&AE(&1E9F%U;"!T;V]L8F%R('1H86X*("H@8W)E871E(&$@8G)A
M;F0@;F5W('1O;VQB87(@.RTI"B`J+PI(5$U,07)E82Y#;VYF:6<N<')O=&]T
M>7!E+FAI9&53;VUE0G5T=&]N<R`](&9U;F-T:6]N*')E;6]V92D@>PH)=F%R
M('1O;VQB87(@/2!T:&ES+G1O;VQB87(["@EF;W(@*'9A<B!I(#T@=&]O;&)A
M<BYL96YG=&@[("TM:2`^/2`P.RD@>PH)"79A<B!L:6YE(#T@=&]O;&)A<EMI
M73L*"0EF;W(@*'9A<B!J(#T@;&EN92YL96YG=&@[("TM:B`^/2`P.R`I('L*
M"0D):68@*')E;6]V92YI;F1E>$]F*"(@(B`K(&QI;F5;:ET@*R`B("(I(#X]
M(#`I('L*"0D)"79A<B!L96X@/2`Q.PH)"0D):68@*"]S97!A<F%T;W)\<W!A
M8V4O+G1E<W0H;&EN95MJ("L@,5TI*2!["@D)"0D);&5N(#T@,CL*"0D)"7T*
M"0D)"6QI;F4N<W!L:6-E*&HL(&QE;BD["@D)"7T*"0E]"@E]"GT["@HO*BH@
M2&5L<&5R(&9U;F-T:6]N.B!R97!L86-E(&%L;"!415A405)%02US(&EN('1H
M92!D;V-U;65N="!W:71H($A434Q!<F5A+7,N("HO"DA434Q!<F5A+G)E<&QA
M8V5!;&P@/2!F=6YC=&EO;BAC;VYF:6<I('L*"79A<B!T87,@/2!D;V-U;65N
M="YG971%;&5M96YT<T)Y5&%G3F%M92@B=&5X=&%R96$B*3L*"69O<B`H=F%R
M(&D@/2!T87,N;&5N9W1H.R!I(#X@,#L@*&YE=R!(5$U,07)E82AT87-;+2UI
M72P@8V]N9FEG*2DN9V5N97)A=&4H*2D["GT["@HO*BH@2&5L<&5R(&9U;F-T
M:6]N.B!R97!L86-E<R!T:&4@5$585$%214$@=VET:"!T:&4@9VEV96X@240@
M=VET:"!(5$U,07)E82X@*B\*2%1-3$%R96$N<F5P;&%C92`](&9U;F-T:6]N
M*&ED+"!C;VYF:6<I('L*"79A<B!T82`]($A434Q!<F5A+F=E=$5L96UE;G1"
M>4ED*")T97AT87)E82(L(&ED*3L*"7)E='5R;B!T82`_("AN97<@2%1-3$%R
M96$H=&$L(&-O;F9I9RDI+F=E;F5R871E*"D@.B!N=6QL.PI].PH*+R\@0W)E
M871E<R!T:&4@=&]O;&)A<B!A;F0@87!P96YD<R!I="!T;R!T:&4@7VAT;6QA
M<F5A"DA434Q!<F5A+G!R;W1O='EP92Y?8W)E871E5&]O;&)A<B`](&9U;F-T
M:6]N("@I('L*"79A<B!E9&ET;W(@/2!T:&ES.PDO+R!T;R!A8V-E<W,@=&AI
M<R!I;B!N97-T960@9G5N8W1I;VYS"@H)=F%R('1O;VQB87(@/2!D;V-U;65N
M="YC<F5A=&5%;&5M96YT*")D:78B*3L*"71H:7,N7W1O;VQB87(@/2!T;V]L
M8F%R.PH)=&]O;&)A<BYC;&%S<TYA;64@/2`B=&]O;&)A<B(["@ET;V]L8F%R
M+G5N<V5L96-T86)L92`]("(Q(CL*"79A<B!T8E]R;W<@/2!N=6QL.PH)=F%R
M('1B7V]B:F5C=',@/2!N97<@3V)J96-T*"D["@ET:&ES+E]T;V]L8F%R3V)J
M96-T<R`]('1B7V]B:F5C=',["@H)+R\@8W)E871E<R!A(&YE=R!L:6YE(&EN
M('1H92!T;V]L8F%R"@EF=6YC=&EO;B!N97=,:6YE*"D@>PH)"79A<B!T86)L
M92`](&1O8W5M96YT+F-R96%T945L96UE;G0H(G1A8FQE(BD["@D)=&%B;&4N
M8F]R9&5R(#T@(C!P>"(["@D)=&%B;&4N8V5L;%-P86-I;F<@/2`B,'!X(CL*
M"0ET86)L92YC96QL4&%D9&EN9R`]("(P<'@B.PH)"71O;VQB87(N87!P96YD
M0VAI;&0H=&%B;&4I.PH)"2\O(%1"3T19(&ES(')E<75I<F5D(&9O<B!)12P@
M;W1H97)W:7-E('EO=2!D;VXG="!S964@86YY=&AI;F<*"0DO+R!I;B!T:&4@
M5$%"3$4N"@D)=F%R('1B7V)O9'D@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*")T8F]D>2(I.PH)"71A8FQE+F%P<&5N9$-H:6QD*'1B7V)O9'DI.PH)"71B
M7W)O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H(G1R(BD["@D)=&)?8F]D
M>2YA<'!E;F1#:&EL9"AT8E]R;W<I.PH)?3L@+R\@14Y$(&]F(&9U;F-T:6]N
M.B!N97=,:6YE"@DO+R!I;FET(&9I<G-T(&QI;F4*"6YE=TQI;F4H*3L*"@DO
M+R!U<&1A=&5S('1H92!S=&%T92!O9B!A('1O;VQB87(@96QE;65N="X@(%1H
M:7,@9G5N8W1I;VX@:7,@;65M8F5R(&]F"@DO+R!A('1O;VQB87(@96QE;65N
M="!O8FIE8W0@*'5N;F%M960@;V)J96-T<R!C<F5A=&5D(&)Y(&-R96%T94)U
M='1O;B!O<@H)+R\@8W)E871E4V5L96-T(&9U;F-T:6]N<R!B96QO=RDN"@EF
M=6YC=&EO;B!S971"=71T;VY3=&%T=7,H:60L(&YE=W9A;"D@>PH)"79A<B!O
M;&1V86P@/2!T:&ES6VED73L*"0EV87(@96P@/2!T:&ES+F5L96UE;G0["@D)
M:68@*&]L9'9A;"`A/2!N97=V86PI('L*"0D)<W=I=&-H("AI9"D@>PH)"0D@
M("`@8V%S92`B96YA8FQE9"(Z"@D)"0EI9B`H;F5W=F%L*2!["@D)"0D)2%1-
M3$%R96$N7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N1&ES86)L960B*3L*"0D)
M"0EE;"YD:7-A8FQE9"`](&9A;'-E.PH)"0D)?2!E;'-E('L*"0D)"0E(5$U,
M07)E82Y?861D0VQA<W,H96PL(")B=71T;VY$:7-A8FQE9"(I.PH)"0D)"65L
M+F1I<V%B;&5D(#T@=')U93L*"0D)"7T*"0D)"6)R96%K.PH)"0D@("`@8V%S
M92`B86-T:79E(CH*"0D)"6EF("AN97=V86PI('L*"0D)"0E(5$U,07)E82Y?
M861D0VQA<W,H96PL(")B=71T;VY0<F5S<V5D(BD["@D)"0E](&5L<V4@>PH)
M"0D)"4A434Q!<F5A+E]R96UO=F5#;&%S<RAE;"P@(F)U='1O;E!R97-S960B
M*3L*"0D)"7T*"0D)"6)R96%K.PH)"0E]"@D)"71H:7-;:61=(#T@;F5W=F%L
M.PH)"7T*"7T[("\O($5.1"!O9B!F=6YC=&EO;CH@<V5T0G5T=&]N4W1A='5S
M"@H)+R\@=&AI<R!F=6YC=&EO;B!W:6QL(&AA;F1L92!C<F5A=&EO;B!O9B!C
M;VUB;R!B;WAE<RX@(%)E8V5I=F5S(&%S"@DO+R!P87)A;65T97(@=&AE(&YA
M;64@;V8@82!B=71T;VX@87,@9&5F:6YE9"!I;B!T:&4@=&]O;$)A<B!C;VYF
M:6<N"@DO+R!4:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"!F<F]M(&-R96%T94)U
M='1O;BP@86)O=F4L(&EF('1H92!G:79E;B`B='AT(@H)+R\@9&]E<VXG="!M
M871C:"!A(&)U='1O;BX*"69U;F-T:6]N(&-R96%T95-E;&5C="AT>'0I('L*
M"0EV87(@;W!T:6]N<R`](&YU;&P["@D)=F%R(&5L(#T@;G5L;#L*"0EV87(@
M8VUD(#T@;G5L;#L*"0EV87(@8W5S=&]M4V5L96-T<R`](&5D:71O<BYC;VYF
M:6<N8W5S=&]M4V5L96-T<SL*"0EV87(@8V]N=&5X="`](&YU;&P["@D)=F%R
M('1O;VQT:7`@/2`B(CL*"0ES=VET8V@@*'1X="D@>PH)"2`@("!C87-E(")F
M;VYT<VEZ92(Z"@D)("`@(&-A<V4@(F9O;G1N86UE(CH*"0D@("`@8V%S92`B
M9F]R;6%T8FQO8VLB.@H)"0DO+R!T:&4@9F]L;&]W:6YG(&QI;F4@<F5T<FEE
M=F5S('1H92!C;W)R96-T"@D)"2\O(&-O;F9I9W5R871I;VX@;W!T:6]N(&)E
M8V%U<V4@=&AE('9A<FEA8FQE(&YA;64*"0D)+R\@:6YS:61E('1H92!#;VYF
M:6<@;V)J96-T(&ES(&YA;65D('1H92!S86UE(&%S('1H90H)"0DO+R!B=71T
M;VXO<V5L96-T(&EN('1H92!T;V]L8F%R+B`@1F]R(&EN<W1A;F-E+"!I9B!T
M>'0*"0D)+R\@/3T@(F9O<FUA=&)L;V-K(B!W92!R971R:65V92!C;VYF:6<N
M9F]R;6%T8FQO8VL@*&]R"@D)"2\O(&$@9&EF9F5R96YT('=A>2!T;R!W<FET
M92!I="!I;B!*4R!I<PH)"0DO+R!C;VYF:6=;(F9O<FUA=&)L;V-K(ETN"@D)
M"6]P=&EO;G,@/2!E9&ET;W(N8V]N9FEG6W1X=%T["@D)"6-M9"`]('1X=#L*
M"0D)8G)E86L["@D)("`@(&1E9F%U;'0Z"@D)"2\O('1R>2!T;R!F971C:"!I
M="!F<F]M('1H92!L:7-T(&]F(')E9VES=&5R960@<V5L96-T<PH)"0EC;60@
M/2!T>'0["@D)"79A<B!D<F]P9&]W;B`](&-U<W1O;5-E;&5C='-;8VUD73L*
M"0D):68@*'1Y<&5O9B!D<F]P9&]W;B`A/2`B=6YD969I;F5D(BD@>PH)"0D)
M;W!T:6]N<R`](&1R;W!D;W=N+F]P=&EO;G,["@D)"0EC;VYT97AT(#T@9')O
M<&1O=VXN8V]N=&5X=#L*"0D)"6EF("AT>7!E;V8@9')O<&1O=VXN=&]O;'1I
M<"`A/2`B=6YD969I;F5D(BD@>PH)"0D)"71O;VQT:7`@/2!D<F]P9&]W;BYT
M;V]L=&EP.PH)"0D)?0H)"0E](&5L<V4@>PH)"0D)86QE<G0H(D524D]2(%MC
M<F5A=&5396QE8W1=.EQN0V%N)W0@9FEN9"!T:&4@<F5Q=65S=&5D(&1R;W!D
M;W=N(&1E9FEN:71I;VXB*3L*"0D)?0H)"0EB<F5A:SL*"0E]"@D):68@*&]P
M=&EO;G,I('L*"0D)96P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")S96QE
M8W0B*3L*"0D)96PN=&ET;&4@/2!T;V]L=&EP.PH)"0EV87(@;V)J(#T@>PH)
M"0D);F%M90DZ('1X="P@+R\@9FEE;&0@;F%M90H)"0D)96QE;65N="`Z(&5L
M+`DO+R!T:&4@54D@96QE;65N="`H4T5,14-4*0H)"0D)96YA8FQE9"`Z('1R
M=64L("\O(&ES(&ET(&5N86)L960_"@D)"0ET97AT"3H@9F%L<V4L("\O(&5N
M86)L960@:6X@=&5X="!M;V1E/PH)"0D)8VUD"3H@8VUD+"`O+R!C;VUM86YD
M($E$"@D)"0ES=&%T90DZ('-E=$)U='1O;E-T871U<RP@+R\@9F]R(&-H86YG
M:6YG('-T871E"@D)"0EC;VYT97AT(#H@8V]N=&5X=`H)"0E].PH)"0ET8E]O
M8FIE8W1S6W1X=%T@/2!O8FH["@D)"69O<B`H=F%R(&D@:6X@;W!T:6]N<RD@
M>PH)"0D)=F%R(&]P(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B;W!T:6]N
M(BD["@D)"0EO<"YI;FYE<DA434P@/2!I.PH)"0D);W`N=F%L=64@/2!O<'1I
M;VYS6VE=.PH)"0D)96PN87!P96YD0VAI;&0H;W`I.PH)"0E]"@D)"4A434Q!
M<F5A+E]A9&1%=F5N="AE;"P@(F-H86YG92(L(&9U;F-T:6]N("@I('L*"0D)
M"65D:71O<BY?8V]M8F]396QE8W1E9"AE;"P@='AT*3L*"0D)?2D["@D)?0H)
M"7)E='5R;B!E;#L*"7T[("\O($5.1"!O9B!F=6YC=&EO;CH@8W)E871E4V5L
M96-T"@H)+R\@87!P96YD<R!A(&YE=R!B=71T;VX@=&\@=&]O;&)A<@H)9G5N
M8W1I;VX@8W)E871E0G5T=&]N*'1X="D@>PH)"2\O('1H92!E;&5M96YT('1H
M870@=VEL;"!B92!C<F5A=&5D"@D)=F%R(&5L(#T@;G5L;#L*"0EV87(@8G1N
M(#T@;G5L;#L*"0ES=VET8V@@*'1X="D@>PH)"2`@("!C87-E(")S97!A<F%T
M;W(B.@H)"0EE;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H(F1I=B(I.PH)
M"0EE;"YC;&%S<TYA;64@/2`B<V5P87)A=&]R(CL*"0D)8G)E86L["@D)("`@
M(&-A<V4@(G-P86-E(CH*"0D)96P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*")D:78B*3L*"0D)96PN8VQA<W-.86UE(#T@(G-P86-E(CL*"0D)8G)E86L[
M"@D)("`@(&-A<V4@(FQI;F5B<F5A:R(Z"@D)"6YE=TQI;F4H*3L*"0D)<F5T
M=7)N(&9A;'-E.PH)"2`@("!C87-E(")T97AT:6YD:6-A=&]R(CH*"0D)96P@
M/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")D:78B*3L*"0D)96PN87!P96YD
M0VAI;&0H9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H(D$B*2D["@D)"65L+F-L
M87-S3F%M92`](")I;F1I8V%T;W(B.PH)"0EE;"YT:71L92`]($A434Q!<F5A
M+DDQ.$XN=&]O;'1I<',N=&5X=&EN9&EC871O<CL*"0D)=F%R(&]B:B`]('L*
M"0D)"6YA;64).B!T>'0L("\O('1H92!B=71T;VX@;F%M92`H:2YE+B`G8F]L
M9"<I"@D)"0EE;&5M96YT(#H@96PL("\O('1H92!522!E;&5M96YT("A$258I
M"@D)"0EE;F%B;&5D(#H@=')U92P@+R\@:7,@:70@96YA8FQE9#\*"0D)"6%C
M=&EV90DZ(&9A;'-E+"`O+R!I<R!I="!P<F5S<V5D/PH)"0D)=&5X=`DZ(&9A
M;'-E+"`O+R!E;F%B;&5D(&EN('1E>'0@;6]D93\*"0D)"6-M9`DZ(")T97AT
M:6YD:6-A=&]R(BP@+R\@=&AE(&-O;6UA;F0@240*"0D)"7-T871E"3H@<V5T
M0G5T=&]N4W1A='5S("\O(&9O<B!C:&%N9VEN9R!S=&%T90H)"0E].PH)"0ET
M8E]O8FIE8W1S6W1X=%T@/2!O8FH["@D)"6)R96%K.PH)"2`@("!D969A=6QT
M.@H)"0EB=&X@/2!E9&ET;W(N8V]N9FEG+F)T;DQI<W1;='AT73L*"0E]"@D)
M:68@*"%E;"`F)B!B=&XI('L*"0D)96P@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*")D:78B*3L*"0D)96PN=&ET;&4@/2!B=&Y;,%T["@D)"65L+F-L87-S
M3F%M92`](")B=71T;VXB.PH)"0DO+R!L970G<R!J=7-T('!R971E;F0@=V4@
M:&%V92!A(&)U='1O;B!O8FIE8W0L(&%N9`H)"0DO+R!A<W-I9VX@86QL('1H
M92!N965D960@:6YF;W)M871I;VX@=&\@:70N"@D)"79A<B!O8FH@/2!["@D)
M"0EN86UE"3H@='AT+"`O+R!T:&4@8G5T=&]N(&YA;64@*&DN92X@)V)O;&0G
M*0H)"0D)96QE;65N="`Z(&5L+"`O+R!T:&4@54D@96QE;65N="`H1$E6*0H)
M"0D)96YA8FQE9"`Z('1R=64L("\O(&ES(&ET(&5N86)L960_"@D)"0EA8W1I
M=F4).B!F86QS92P@+R\@:7,@:70@<')E<W-E9#\*"0D)"71E>'0).B!B=&Y;
M,ETL("\O(&5N86)L960@:6X@=&5X="!M;V1E/PH)"0D)8VUD"3H@8G1N6S-=
M+"`O+R!T:&4@8V]M;6%N9"!)1`H)"0D)<W1A=&4).B!S971"=71T;VY3=&%T
M=7,L("\O(&9O<B!C:&%N9VEN9R!S=&%T90H)"0D)8V]N=&5X="`Z(&)T;ELT
M72!\?"!N=6QL("\O(&5N86)L960@:6X@82!C97)T86EN(&-O;G1E>'0_"@D)
M"7T["@D)"71B7V]B:F5C='-;='AT72`](&]B:CL*"0D)+R\@:&%N9&QE<G,@
M=&\@96UU;&%T92!N:6-E(&9L870@=&]O;&)A<B!B=71T;VYS"@D)"4A434Q!
M<F5A+E]A9&1%=F5N="AE;"P@(FUO=7-E;W9E<B(L(&9U;F-T:6]N("@I('L*
M"0D)"6EF("AO8FHN96YA8FQE9"D@>PH)"0D)"4A434Q!<F5A+E]A9&1#;&%S
M<RAE;"P@(F)U='1O;DAO=F5R(BD["@D)"0E]"@D)"7TI.PH)"0E(5$U,07)E
M82Y?861D179E;G0H96PL(")M;W5S96]U="(L(&9U;F-T:6]N("@I('L*"0D)
M"6EF("AO8FHN96YA8FQE9"D@=VET:"`H2%1-3$%R96$I('L*"0D)"0E?<F5M
M;W9E0VQA<W,H96PL(")B=71T;VY(;W9E<B(I.PH)"0D)"5]R96UO=F5#;&%S
M<RAE;"P@(F)U='1O;D%C=&EV92(I.PH)"0D)"2AO8FHN86-T:79E*2`F)B!?
M861D0VQA<W,H96PL(")B=71T;VY0<F5S<V5D(BD["@D)"0E]"@D)"7TI.PH)
M"0E(5$U,07)E82Y?861D179E;G0H96PL(")M;W5S961O=VXB+"!F=6YC=&EO
M;B`H978I('L*"0D)"6EF("AO8FHN96YA8FQE9"D@=VET:"`H2%1-3$%R96$I
M('L*"0D)"0E?861D0VQA<W,H96PL(")B=71T;VY!8W1I=F4B*3L*"0D)"0E?
M<F5M;W9E0VQA<W,H96PL(")B=71T;VY0<F5S<V5D(BD["@D)"0D)7W-T;W!%
M=F5N="AI<U]I92`_('=I;F1O=RYE=F5N="`Z(&5V*3L*"0D)"7T*"0D)?2D[
M"@D)"2\O('=H96X@8VQI8VME9"P@9&\@=&AE(&9O;&QO=VEN9SH*"0D)2%1-
M3$%R96$N7V%D9$5V96YT*&5L+"`B8VQI8VLB+"!F=6YC=&EO;B`H978I('L*
M"0D)"6EF("AO8FHN96YA8FQE9"D@=VET:"`H2%1-3$%R96$I('L*"0D)"0E?
M<F5M;W9E0VQA<W,H96PL(")B=71T;VY!8W1I=F4B*3L*"0D)"0E?<F5M;W9E
M0VQA<W,H96PL(")B=71T;VY(;W9E<B(I.PH)"0D)"6]B:BYC;60H961I=&]R
M+"!O8FHN;F%M92P@;V)J*3L*"0D)"0E?<W1O<$5V96YT*&ES7VEE(#\@=VEN
M9&]W+F5V96YT(#H@978I.PH)"0D)?0H)"0E]*3L*"0D)=F%R(&EM9R`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H(FEM9R(I.PH)"0EI;6<N<W)C(#T@8G1N
M6S%=.PH)"0EI;6<N<W1Y;&4N=VED=&@@/2`B,3AP>"(["@D)"6EM9RYS='EL
M92YH96EG:'0@/2`B,3AP>"(["@D)"65L+F%P<&5N9$-H:6QD*&EM9RD["@D)
M?2!E;'-E(&EF("@A96PI('L*"0D)96P@/2!C<F5A=&5396QE8W0H='AT*3L*
M"0E]"@D):68@*&5L*2!["@D)"79A<B!T8E]C96QL(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@B=&0B*3L*"0D)=&)?<F]W+F%P<&5N9$-H:6QD*'1B7V-E
M;&PI.PH)"0ET8E]C96QL+F%P<&5N9$-H:6QD*&5L*3L*"0E](&5L<V4@>PH)
M"0EA;&5R="@B1DE8344Z(%5N:VYO=VX@=&]O;&)A<B!I=&5M.B`B("L@='AT
M*3L*"0E]"@D)<F5T=7)N(&5L.PH)?3L*"@EV87(@9FER<W0@/2!T<G5E.PH)
M9F]R("AV87(@:2`](#`[(&D@/"!T:&ES+F-O;F9I9RYT;V]L8F%R+FQE;F=T
M:#L@*RMI*2!["@D):68@*"%F:7)S="D@>PH)"0EC<F5A=&5"=71T;VXH(FQI
M;F5B<F5A:R(I.PH)"7T@96QS92!["@D)"69I<G-T(#T@9F%L<V4["@D)?0H)
M"79A<B!G<F]U<"`]('1H:7,N8V]N9FEG+G1O;VQB87);:5T["@D)9F]R("AV
M87(@:B`](#`[(&H@/"!G<F]U<"YL96YG=&@[("LK:BD@>PH)"0EV87(@8V]D
M92`](&=R;W5P6VI=.PH)"0EI9B`H+UXH6TE472E<6R@N*C\I7%TO+G1E<W0H
M8V]D92DI('L*"0D)"2\O('-P96-I86P@8V%S92P@8W)E871E('1E>'0@;&%B
M96P*"0D)"79A<B!L-V5D(#T@4F5G17AP+B0Q(#T]("))(CL@+R\@;&]C86QI
M>F5D/PH)"0D)=F%R(&QA8F5L(#T@4F5G17AP+B0R.PH)"0D):68@*&PW960I
M('L*"0D)"0EL86)E;"`]($A434Q!<F5A+DDQ.$XN8W5S=&]M6VQA8F5L73L*
M"0D)"7T*"0D)"79A<B!T8E]C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N
M="@B=&0B*3L*"0D)"71B7W)O=RYA<'!E;F1#:&EL9"AT8E]C96QL*3L*"0D)
M"71B7V-E;&PN8VQA<W-.86UE(#T@(FQA8F5L(CL*"0D)"71B7V-E;&PN:6YN
M97)(5$U,(#T@;&%B96P["@D)"7T@96QS92!["@D)"0EC<F5A=&5"=71T;VXH
M8V]D92D["@D)"7T*"0E]"@E]"@H)=&AI<RY?:'1M;$%R96$N87!P96YD0VAI
M;&0H=&]O;&)A<BD["GT["@I(5$U,07)E82YP<F]T;W1Y<&4N7V-R96%T95-T
M871U<T)A<B`](&9U;F-T:6]N*"D@>PH)=F%R('-T871U<V)A<B`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H(F1I=B(I.PH)<W1A='5S8F%R+F-L87-S3F%M
M92`](")S=&%T=7-"87(B.PH)=&AI<RY?:'1M;$%R96$N87!P96YD0VAI;&0H
M<W1A='5S8F%R*3L*"71H:7,N7W-T871U<T)A<B`]('-T871U<V)A<CL*"2\O
M('-T871U<V)A<BYA<'!E;F1#:&EL9"AD;V-U;65N="YC<F5A=&5497AT3F]D
M92A(5$U,07)E82Y),3A.+FUS9ULB4&%T:")=("L@(CH@(BDI.PH)+R\@8W)E
M871E<R!A(&AO;&1E<B!F;W(@=&AE('!A=&@@=FEE=PH)9&EV(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@B<W!A;B(I.PH)9&EV+F-L87-S3F%M92`](")S
M=&%T=7-"87)4<F5E(CL*"61I=BYI;FYE<DA434P@/2!(5$U,07)E82Y),3A.
M+FUS9ULB4&%T:")=("L@(CH@(CL*"71H:7,N7W-T871U<T)A<E1R964@/2!D
M:78["@ET:&ES+E]S=&%T=7-"87(N87!P96YD0VAI;&0H9&EV*3L*"6EF("@A
M=&AI<RYC;VYF:6<N<W1A='5S0F%R*2!["@D)+R\@9&ES86)L92!I="XN+@H)
M"7-T871U<V)A<BYS='EL92YD:7-P;&%Y(#T@(FYO;F4B.PH)?0I].PH*+R\@
M0W)E871E<R!T:&4@2%1-3$%R96$@;V)J96-T(&%N9"!R97!L86-E<R!T:&4@
M=&5X=&%R96$@=VET:"!I="X*2%1-3$%R96$N<')O=&]T>7!E+F=E;F5R871E
M(#T@9G5N8W1I;VX@*"D@>PH)=F%R(&5D:71O<B`]('1H:7,["2\O('=E)VQL
M(&YE960@(G1H:7,B(&EN('-O;64@;F5S=&5D(&9U;F-T:6]N<PH)+R\@9V5T
M('1H92!T97AT87)E80H)=F%R('1E>'1A<F5A(#T@=&AI<RY?=&5X=$%R96$[
M"@EI9B`H='EP96]F('1E>'1A<F5A(#T](")S=')I;F<B*2!["@D)+R\@:70G
M<R!N;W0@96QE;65N="!B=70@240*"0ET:&ES+E]T97AT07)E82`]('1E>'1A
M<F5A(#T@2%1-3$%R96$N9V5T16QE;65N=$)Y260H(G1E>'1A<F5A(BP@=&5X
M=&%R96$I.PH)?0H)=&AI<RY?=&%?<VEZ92`]('L*"0EW.B!T97AT87)E82YO
M9F9S9717:61T:"P*"0EH.B!T97AT87)E82YO9F9S971(96EG:'0*"7T["@ET
M97AT87)E82YS='EL92YD:7-P;&%Y(#T@(FYO;F4B.PH*"2\O(&-R96%T92!T
M:&4@961I=&]R(&9R86UE=V]R:PH)=F%R(&AT;6QA<F5A(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@B9&EV(BD["@EH=&UL87)E82YC;&%S<TYA;64@/2`B
M:'1M;&%R96$B.PH)=&AI<RY?:'1M;$%R96$@/2!H=&UL87)E83L*"@DO+R!I
M;G-E<G0@=&AE(&5D:71O<B!B969O<F4@=&AE('1E>'1A<F5A+@H)=&5X=&%R
M96$N<&%R96YT3F]D92YI;G-E<G1"969O<F4H:'1M;&%R96$L('1E>'1A<F5A
M*3L*"@EI9B`H=&5X=&%R96$N9F]R;2D@>PH)"2\O('=E(&AA=F4@82!F;W)M
M+"!O;B!S=6)M:70@9V5T('1H92!(5$U,07)E82!C;VYT96YT(&%N9`H)"2\O
M('5P9&%T92!O<FEG:6YA;"!T97AT87)E82X*"0EV87(@9B`]('1E>'1A<F5A
M+F9O<FT["@D):68@*'1Y<&5O9B!F+F]N<W5B;6ET(#T](")F=6YC=&EO;B(I
M('L*"0D)=F%R(&9U;F-R968@/2!F+F]N<W5B;6ET.PH)"0EI9B`H='EP96]F
M(&8N7U]M<VA?<')E=D]N4W5B;6ET(#T](")U;F1E9FEN960B*2!["@D)"0EF
M+E]?;7-H7W!R979/;E-U8FUI="`](%M=.PH)"0E]"@D)"68N7U]M<VA?<')E
M=D]N4W5B;6ET+G!U<V@H9G5N8W)E9BD["@D)?0H)"68N;VYS=6)M:70@/2!F
M=6YC=&EO;B@I('L*"0D)961I=&]R+E]T97AT07)E82YV86QU92`](&5D:71O
M<BYG971(5$U,*"D["@D)"79A<B!A(#T@=&AI<RY?7VUS:%]P<F5V3VY3=6)M
M:70["@D)"2\O(&-A;&P@<')E=FEO=7,@<W5B;6ET(&UE=&AO9',@:68@=&AE
M>2!W97)E('1H97)E+@H)"0EI9B`H='EP96]F(&$@(3T@(G5N9&5F:6YE9"(I
M('L*"0D)"69O<B`H=F%R(&D@/2!A+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)
M"0D)85MI72@I.PH)"0D)?0H)"0E]"@D)?3L*"0EI9B`H='EP96]F(&8N;VYR
M97-E="`]/2`B9G5N8W1I;VXB*2!["@D)"79A<B!F=6YC<F5F(#T@9BYO;G)E
M<V5T.PH)"0EI9B`H='EP96]F(&8N7U]M<VA?<')E=D]N4F5S970@/3T@(G5N
M9&5F:6YE9"(I('L*"0D)"68N7U]M<VA?<')E=D]N4F5S970@/2!;73L*"0D)
M?0H)"0EF+E]?;7-H7W!R979/;E)E<V5T+G!U<V@H9G5N8W)E9BD["@D)?0H)
M"68N;VYR97-E="`](&9U;F-T:6]N*"D@>PH)"0EE9&ET;W(N<V5T2%1-3"AE
M9&ET;W(N7W1E>'1!<F5A+G9A;'5E*3L*"0D)961I=&]R+G5P9&%T951O;VQB
M87(H*3L*"0D)=F%R(&$@/2!T:&ES+E]?;7-H7W!R979/;E)E<V5T.PH)"0DO
M+R!C86QL('!R979I;W5S(')E<V5T(&UE=&AO9',@:68@=&AE>2!W97)E('1H
M97)E+@H)"0EI9B`H='EP96]F(&$@(3T@(G5N9&5F:6YE9"(I('L*"0D)"69O
M<B`H=F%R(&D@/2!A+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)"0D)85MI72@I
M.PH)"0D)?0H)"0E]"@D)?3L*"7T*"@DO+R!A9&0@82!H86YD;&5R(&9O<B!T
M:&4@(F)A8VLO9F]R=V%R9"(@8V%S92`M+2!O;B!B;V1Y+G5N;&]A9"!W92!S
M879E"@DO+R!T:&4@2%1-3"!C;VYT96YT(&EN=&\@=&AE(&]R:6=I;F%L('1E
M>'1A<F5A+@H)=')Y('L*"0EW:6YD;W<N;VYU;FQO860@/2!F=6YC=&EO;B@I
M('L*"0D)961I=&]R+E]T97AT07)E82YV86QU92`](&5D:71O<BYG971(5$U,
M*"D["@D)?3L*"7T@8V%T8V@H92D@>WT["@H)+R\@8W)E871E<R`F(&%P<&5N
M9',@=&AE('1O;VQB87(*"71H:7,N7V-R96%T951O;VQB87(H*3L*"@DO+R!C
M<F5A=&4@=&AE($E&4D%-10H)=F%R(&EF<F%M92`](&1O8W5M96YT+F-R96%T
M945L96UE;G0H(FEF<F%M92(I.PH*"2\O('=O<FMA<F]U;F0@9F]R('1H92!(
M5%104R!P<F]B;&5M"@DO+R!I9G)A;64N<V5T071T<FEB=71E*")S<F,B+"`B
M:F%V87-C<FEP=#IV;VED*#`I.R(I.PH):69R86UE+G-R8R`](%]E9&ET;W)?
M=7)L("L@(G!O<'5P<R]B;&%N:RYH=&UL(CL*"@EH=&UL87)E82YA<'!E;F1#
M:&EL9"AI9G)A;64I.PH*"71H:7,N7VEF<F%M92`](&EF<F%M93L*"@DO+R!C
M<F5A=&5S("8@87!P96YD<R!T:&4@<W1A='5S(&)A<BP@:68@=&AE(&-A<V4*
M"71H:7,N7V-R96%T95-T871U<T)A<B@I.PH*"2\O(')E;6]V92!T:&4@9&5F
M875L="!B;W)D97(@87,@:70@:V5E<',@=7,@9G)O;2!C;VUP=71I;F<@8V]R
M<F5C=&QY"@DO+R!T:&4@<VEZ97,N("`H<V]M96)O9'D@=&5L;"!M92!W:'D@
M9&]E<VXG="!T:&ES('=O<FL@:6X@244I"@H):68@*"%(5$U,07)E82YI<U]I
M92D@>PH)"6EF<F%M92YS='EL92YB;W)D97)7:61T:"`]("(Q<'@B.PH)+R\@
M:69R86UE+F9R86UE0F]R9&5R(#T@(C$B.PH)+R\@:69R86UE+FUA<F=I;DAE
M:6=H="`]("(P(CL*"2\O(&EF<F%M92YM87)G:6Y7:61T:"`]("(P(CL*"7T*
M"@DO+R!S:7IE('1H92!)1E)!344@86-C;W)D:6YG('1O('5S97(G<R!P<F5F
M<R!O<B!I;FET:6%L('1E>'1A<F5A"@EV87(@:&5I9VAT(#T@*'1H:7,N8V]N
M9FEG+FAE:6=H="`]/2`B875T;R(@/R`H=&AI<RY?=&%?<VEZ92YH("L@(G!X
M(BD@.B!T:&ES+F-O;F9I9RYH96EG:'0I.PH):&5I9VAT(#T@<&%R<V5);G0H
M:&5I9VAT*3L*"79A<B!W:61T:"`]("AT:&ES+F-O;F9I9RYW:61T:"`]/2`B
M875T;R(@/R`H=&AI<RY?=&%?<VEZ92YW("L@(G!X(BD@.B!T:&ES+F-O;F9I
M9RYW:61T:"D["@EW:61T:"`]('!A<G-E26YT*'=I9'1H*3L*"@EI9B`H(4A4
M34Q!<F5A+FES7VEE*2!["@D):&5I9VAT("T](#(["@D)=VED=&@@+3T@,CL*
M"7T*"@EI9G)A;64N<W1Y;&4N=VED=&@@/2!W:61T:"`K(")P>"(["@EI9B`H
M=&AI<RYC;VYF:6<N<VEZ94EN8VQU9&5S5&]O;&)A<BD@>PH)"2\O('-U8G-T
M<F%C="!T;V]L8F%R(&AE:6=H=`H)"6AE:6=H="`M/2!T:&ES+E]T;V]L8F%R
M+F]F9G-E=$AE:6=H=#L*"0EH96EG:'0@+3T@=&AI<RY?<W1A='5S0F%R+F]F
M9G-E=$AE:6=H=#L*"7T*"6EF("AH96EG:'0@/"`P*2!["@D):&5I9VAT(#T@
M,#L*"7T*"6EF<F%M92YS='EL92YH96EG:'0@/2!H96EG:'0@*R`B<'@B.PH*
M"2\O('1H92!E9&ET;W(@:6YC;'5D:6YG('1H92!T;V]L8F%R(&YO=R!H879E
M('1H92!S86UE('-I>F4@87,@=&AE"@DO+R!O<FEG:6YA;"!T97AT87)E82XN
M('=H:6-H(&UE86YS('1H870@=V4@;F5E9"!T;R!R961U8V4@=&AA="!A(&)I
M="X*"71E>'1A<F5A+G-T>6QE+G=I9'1H(#T@:69R86UE+G-T>6QE+G=I9'1H
M.PH@"71E>'1A<F5A+G-T>6QE+FAE:6=H="`](&EF<F%M92YS='EL92YH96EG
M:'0["@H)+R\@24U03U)404Y4.B!W92!H879E('1O(&%L;&]W($UO>FEL;&$@
M82!S:&]R="!T:6UE('1O(')E8V]G;FEZ92!T:&4*"2\O(&YE=R!F<F%M92X@
M($]T:&5R=VES92!W92!G970@82!S='5P:60@97AC97!T:6]N+@H)9G5N8W1I
M;VX@:6YI=$EF<F%M92@I('L*"0EV87(@9&]C(#T@961I=&]R+E]I9G)A;64N
M8V]N=&5N=%=I;F1O=RYD;V-U;65N=#L*"0EI9B`H(61O8RD@>PH)"0DO+R!4
M<GD@86=A:6XN+@H)"0DO+R!&25A-13H@9&]N)W0@:VYO=R!W:&%T(&5L<V4@
M=&\@9&\@:&5R92X@($YO<FUA;&QY"@D)"2\O('=E)VQL(&YE=F5R(')E86-H
M('1H:7,@<&]I;G0N"@D)"6EF("A(5$U,07)E82YI<U]G96-K;RD@>PH)"0D)
M<V5T5&EM96]U="AI;FET269R86UE+"`Q,#`I.PH)"0D)<F5T=7)N(&9A;'-E
M.PH)"0E](&5L<V4@>PH)"0D)86QE<G0H(D524D]2.B!)1E)!344@8V%N)W0@
M8F4@:6YI=&EA;&EZ960N(BD["@D)"7T*"0E]"@D):68@*$A434Q!<F5A+FES
M7V=E8VMO*2!["@D)"2\O(&5N86)L92!E9&ET86)L92!M;V1E(&9O<B!-;WII
M;&QA"@D)"61O8RYD97-I9VY-;V1E(#T@(F]N(CL*"0E]"@D)961I=&]R+E]D
M;V,@/2!D;V,["@D):68@*"%E9&ET;W(N8V]N9FEG+F9U;&Q086=E*2!["@D)
M"61O8RYO<&5N*"D["@D)"79A<B!H=&UL(#T@(CQH=&UL/EQN(CL*"0D):'1M
M;"`K/2`B/&AE860^7&XB.PH)"0EI9B`H961I=&]R+F-O;F9I9RYB87-E55),
M*0H)"0D):'1M;"`K/2`G/&)A<V4@:')E9CTB)R`K(&5D:71O<BYC;VYF:6<N
M8F%S95523"`K("<B("\^)SL*"0D):'1M;"`K/2`B/'-T>6QE/B(@*R!E9&ET
M;W(N8V]N9FEG+G!A9V53='EL92`K"@D)"0DB(&AT;6PL8F]D>2![(&)O<F1E
M<CH@,'!X.R!]/"]S='EL93Y<;B(["@D)"6AT;6P@*ST@(CPO:&5A9#Y<;B([
M"@D)"6AT;6P@*ST@(CQB;V1Y/EQN(CL*"0D):'1M;"`K/2!E9&ET;W(N7W1E
M>'1!<F5A+G9A;'5E.PH)"0EH=&UL("L]("(\+V)O9'D^7&XB.PH)"0EH=&UL
M("L]("(\+VAT;6P^(CL*"0D)9&]C+G=R:71E*&AT;6PI.PH)"0ED;V,N8VQO
M<V4H*3L*"0E](&5L<V4@>PH)"0EV87(@:'1M;"`](&5D:71O<BY?=&5X=$%R
M96$N=F%L=64["@D)"6EF("AH=&UL+FUA=&-H*$A434Q!<F5A+E)%7V1O8W1Y
M<&4I*2!["@D)"0EE9&ET;W(N<V5T1&]C='EP92A296=%>'`N)#$I.PH)"0D)
M:'1M;"`](&AT;6PN<F5P;&%C92A(5$U,07)E82Y215]D;V-T>7!E+"`B(BD[
M"@D)"7T*"0D)9&]C+F]P96XH*3L*"0D)9&]C+G=R:71E*&AT;6PI.PH)"0ED
M;V,N8VQO<V4H*3L*"0E]"@H)"6EF("A(5$U,07)E82YI<U]I92D@>PH)"0DO
M+R!E;F%B;&4@961I=&%B;&4@;6]D92!F;W(@244N"2!&;W(@<V]M92!R96%S
M;VX@=&AI<PH)"0DO+R!D;V5S;B=T('=O<FL@:68@9&]N92!I;B!T:&4@<V%M
M92!P;&%C92!A<R!F;W(@1V5C:V\*"0D)+R\@*&%B;W9E*2X*"0D)9&]C+F)O
M9'DN8V]N=&5N=$5D:71A8FQE(#T@=')U93L*"0E]"@H)"65D:71O<BYF;V-U
M<T5D:71O<B@I.PH)"2\O(&EN=&5R8V5P="!S;VUE(&5V96YT<SL@9F]R('5P
M9&%T:6YG('1H92!T;V]L8F%R("8@:V5Y8F]A<F0@:&%N9&QE<G,*"0E(5$U,
M07)E82Y?861D179E;G1S"@D)"2AD;V,L(%LB:V5Y9&]W;B(L(")K97EP<F5S
M<R(L(")M;W5S961O=VXB+"`B;6]U<V5U<"(L(")D<F%G(ETL"@D)"2!F=6YC
M=&EO;B`H979E;G0I('L*"0D)"2!R971U<FX@961I=&]R+E]E9&ET;W)%=F5N
M="A(5$U,07)E82YI<U]I92`_(&5D:71O<BY?:69R86UE+F-O;G1E;G17:6YD
M;W<N979E;G0@.B!E=F5N="D["@D)"2!]*3L*"@D)+R\@8VAE8VL@:68@86YY
M('!L=6=I;G,@:&%V92!R96=I<W1E<F5D(')E9G)E<V@@:&%N9&QE<G,*"0EF
M;W(@*'9A<B!I(&EN(&5D:71O<BYP;'5G:6YS*2!["@D)"79A<B!P;'5G:6X@
M/2!E9&ET;W(N<&QU9VEN<UMI72YI;G-T86YC93L*"0D):68@*'1Y<&5O9B!P
M;'5G:6XN;VY'96YE<F%T92`]/2`B9G5N8W1I;VXB*0H)"0D)<&QU9VEN+F]N
M1V5N97)A=&4H*3L*"0D):68@*'1Y<&5O9B!P;'5G:6XN;VY'96YE<F%T94]N
M8V4@/3T@(F9U;F-T:6]N(BD@>PH)"0D)<&QU9VEN+F]N1V5N97)A=&5/;F-E
M*"D["@D)"0EP;'5G:6XN;VY'96YE<F%T94]N8V4@/2!N=6QL.PH)"0E]"@D)
M?0H*"0ES9714:6UE;W5T*&9U;F-T:6]N*"D@>PH)"0EE9&ET;W(N=7!D871E
M5&]O;&)A<B@I.PH)"7TL(#(U,"D["@H)"6EF("AT>7!E;V8@961I=&]R+F]N
M1V5N97)A=&4@/3T@(F9U;F-T:6]N(BD*"0D)961I=&]R+F]N1V5N97)A=&4H
M*3L*"7T["@ES9714:6UE;W5T*&EN:71)9G)A;64L(#$P,"D["@ER971U<FX@
M=&AI<SL*?3L*"B\O(%-W:71C:&5S(&5D:71O<B!M;V1E.R!P87)A;65T97(@
M8V%N(&)E(")T97AT;6]D92(@;W(@(G=Y<VEW>6<B+B`@268@;F\*+R\@<&%R
M86UE=&5R('=A<R!P87-S960@=&AI<R!F=6YC=&EO;B!T;V=G;&5S(&)E='=E
M96X@;6]D97,N"DA434Q!<F5A+G!R;W1O='EP92YS971-;V1E(#T@9G5N8W1I
M;VXH;6]D92D@>PH):68@*'1Y<&5O9B!M;V1E(#T](")U;F1E9FEN960B*2![
M"@D);6]D92`]("@H=&AI<RY?961I=$UO9&4@/3T@(G1E>'1M;V1E(BD@/R`B
M=WES:7=Y9R(@.B`B=&5X=&UO9&4B*3L*"7T*"7-W:71C:"`H;6]D92D@>PH)
M("`@(&-A<V4@(G1E>'1M;V1E(CH*"0ET:&ES+E]T97AT07)E82YV86QU92`]
M('1H:7,N9V5T2%1-3"@I.PH)"71H:7,N7VEF<F%M92YS='EL92YD:7-P;&%Y
M(#T@(FYO;F4B.PH)"71H:7,N7W1E>'1!<F5A+G-T>6QE+F1I<W!L87D@/2`B
M8FQO8VLB.PH)"6EF("AT:&ES+F-O;F9I9RYS=&%T=7-"87(I('L*"0D)=&AI
M<RY?<W1A='5S0F%R+FEN;F5R2%1-3"`]($A434Q!<F5A+DDQ.$XN;7-G6R)4
M15A47TU/1$4B73L*"0E]"@D)8G)E86L["@D@("`@8V%S92`B=WES:7=Y9R(Z
M"@D):68@*$A434Q!<F5A+FES7V=E8VMO*2!["@D)"2\O(&1I<V%B;&4@9&5S
M:6=N(&UO9&4@8F5F;W)E(&-H86YG:6YG(&EN;F5R2%1-3`H)"0ET<GD@>PH)
M"0D)=&AI<RY?9&]C+F1E<VEG;DUO9&4@/2`B;V9F(CL*"0D)?2!C871C:"AE
M*2![?3L*"0E]"@D):68@*"%T:&ES+F-O;F9I9RYF=6QL4&%G92D*"0D)=&AI
M<RY?9&]C+F)O9'DN:6YN97)(5$U,(#T@=&AI<RYG971(5$U,*"D["@D)96QS
M90H)"0ET:&ES+G-E=$9U;&Q(5$U,*'1H:7,N9V5T2%1-3"@I*3L*"0ET:&ES
M+E]I9G)A;64N<W1Y;&4N9&ES<&QA>2`](")B;&]C:R(["@D)=&AI<RY?=&5X
M=$%R96$N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*"0EI9B`H2%1-3$%R96$N
M:7-?9V5C:V\I('L*"0D)+R\@=V4@;F5E9"!T;R!R969R97-H('1H870@:6YF
M;R!F;W(@36]Z+3$N,V$*"0D)=')Y('L*"0D)"71H:7,N7V1O8RYD97-I9VY-
M;V1E(#T@(F]N(CL*"0D)?2!C871C:"AE*2![?3L*"0E]"@D):68@*'1H:7,N
M8V]N9FEG+G-T871U<T)A<BD@>PH)"0ET:&ES+E]S=&%T=7-"87(N:6YN97)(
M5$U,(#T@)R<["@D)"2\O('1H:7,N7W-T871U<T)A<BYA<'!E;F1#:&EL9"AD
M;V-U;65N="YC<F5A=&5497AT3F]D92A(5$U,07)E82Y),3A.+FUS9ULB4&%T
M:")=("L@(CH@(BDI.PH)"0ET:&ES+E]S=&%T=7-"87(N87!P96YD0VAI;&0H
M=&AI<RY?<W1A='5S0F%R5')E92D["@D)?0H)"6)R96%K.PH)("`@(&1E9F%U
M;'0Z"@D)86QE<G0H(DUO9&4@/"(@*R!M;V1E("L@(CX@;F]T(&1E9FEN960A
M(BD["@D)<F5T=7)N(&9A;'-E.PH)?0H)=&AI<RY?961I=$UO9&4@/2!M;V1E
M.PH)=&AI<RYF;V-U<T5D:71O<B@I.PH*"69O<B`H=F%R(&D@:6X@=&AI<RYP
M;'5G:6YS*2!["@D)=F%R('!L=6=I;B`]('1H:7,N<&QU9VEN<UMI72YI;G-T
M86YC93L*"0EI9B`H='EP96]F('!L=6=I;BYO;DUO9&4@/3T@(F9U;F-T:6]N
M(BD@<&QU9VEN+F]N36]D92AM;V1E*3L*"7T*?3L*"DA434Q!<F5A+G!R;W1O
M='EP92YS971&=6QL2%1-3"`](&9U;F-T:6]N*&AT;6PI('L*"79A<B!S879E
M7VUU;'1I;&EN92`](%)E9T5X<"YM=6QT:6QI;F4["@E296=%>'`N;75L=&EL
M:6YE(#T@=')U93L*"6EF("AH=&UL+FUA=&-H*$A434Q!<F5A+E)%7V1O8W1Y
M<&4I*2!["@D)=&AI<RYS971$;V-T>7!E*%)E9T5X<"XD,2D["@D):'1M;"`]
M(&AT;6PN<F5P;&%C92A(5$U,07)E82Y215]D;V-T>7!E+"`B(BD["@E]"@E2
M96=%>'`N;75L=&EL:6YE(#T@<V%V95]M=6QT:6QI;F4["@EI9B`H(4A434Q!
M<F5A+FES7VEE*2!["@D):68@*&AT;6PN;6%T8V@H2%1-3$%R96$N4D5?:&5A
M9"DI"@D)"71H:7,N7V1O8RYG971%;&5M96YT<T)Y5&%G3F%M92@B:&5A9"(I
M6S!=+FEN;F5R2%1-3"`](%)E9T5X<"XD,3L*"0EI9B`H:'1M;"YM871C:"A(
M5$U,07)E82Y215]B;V1Y*2D*"0D)=&AI<RY?9&]C+F=E=$5L96UE;G1S0GE4
M86=.86UE*")B;V1Y(BE;,%TN:6YN97)(5$U,(#T@4F5G17AP+B0Q.PH)?2!E
M;'-E('L*"0EV87(@:'1M;%]R92`]("\\:'1M;#XH*"Y\7&XI*C\I/%PO:'1M
M;#XO:3L*"0EH=&UL(#T@:'1M;"YR97!L86-E*&AT;6Q?<F4L("(D,2(I.PH)
M"71H:7,N7V1O8RYO<&5N*"D["@D)=&AI<RY?9&]C+G=R:71E*&AT;6PI.PH)
M"71H:7,N7V1O8RYC;&]S92@I.PH)"71H:7,N7V1O8RYB;V1Y+F-O;G1E;G1%
M9&ET86)L92`]('1R=64["@D)<F5T=7)N('1R=64["@E]"GT["@HO*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M"B`J("!#871E9V]R>3H@4$Q51TE.4PH@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ+PH*+R\@0W)E871E('1H
M92!S<&5C:69I960@<&QU9VEN(&%N9"!R96=I<W1E<B!I="!W:71H('1H:7,@
M2%1-3$%R96$*2%1-3$%R96$N<')O=&]T>7!E+G)E9VES=&5R4&QU9VEN(#T@
M9G5N8W1I;VXH*2!["@EV87(@<&QU9VEN(#T@87)G=6UE;G1S6S!=.PH)=F%R
M(&%R9W,@/2!;73L*"69O<B`H=F%R(&D@/2`Q.R!I(#P@87)G=6UE;G1S+FQE
M;F=T:#L@*RMI*0H)"6%R9W,N<'5S:"AA<F=U;65N='-;:5TI.PH)=&AI<RYR
M96=I<W1E<E!L=6=I;C(H<&QU9VEN+"!A<F=S*3L*?3L*"B\O('1H:7,@:7,@
M=&AE('9A<FEA;G0@;V8@=&AE(&9U;F-T:6]N(&%B;W9E('=H97)E('1H92!P
M;'5G:6X@87)G=6UE;G1S(&%R90HO+R!A;')E861Y('!A8VME9"!I;B!A;B!A
M<G)A>2X@($5X=&5R;F%L;'DL(&ET('-H;W5L9"!B92!O;FQY('5S960@:6X@
M=&AE"B\O(&9U;&PM<V-R965N(&5D:71O<B!C;V1E+"!I;B!O<F1E<B!T;R!I
M;FET:6%L:7IE('!L=6=I;G,@=VET:"!T:&4@<V%M90HO+R!P87)A;65T97)S
M(&%S(&EN('1H92!O<&5N97(@=VEN9&]W+@I(5$U,07)E82YP<F]T;W1Y<&4N
M<F5G:7-T97)0;'5G:6XR(#T@9G5N8W1I;VXH<&QU9VEN+"!A<F=S*2!["@EI
M9B`H='EP96]F('!L=6=I;B`]/2`B<W1R:6YG(BD*"0EP;'5G:6X@/2!E=F%L
M*'!L=6=I;BD["@EI9B`H='EP96]F('!L=6=I;B`]/2`B=6YD969I;F5D(BD@
M>PH)"2\J($9)6$U%.B!4:&ES('-H;W5L9"!N979E<B!H87!P96XN($)U="!W
M:'D@9&]E<R!I="!D;S\@*B\*"0ER971U<FX@9F%L<V4["@E]"@EV87(@;V)J
M(#T@;F5W('!L=6=I;BAT:&ES+"!A<F=S*3L*"6EF("AO8FHI('L*"0EV87(@
M8VQO;F4@/2![?3L*"0EV87(@:6YF;R`]('!L=6=I;BY?<&QU9VEN26YF;SL*
M"0EF;W(@*'9A<B!I(&EN(&EN9F\I"@D)"6-L;VYE6VE=(#T@:6YF;UMI73L*
M"0EC;&]N92YI;G-T86YC92`](&]B:CL*"0EC;&]N92YA<F=S(#T@87)G<SL*
M"0ET:&ES+G!L=6=I;G-;<&QU9VEN+E]P;'5G:6Y);F9O+FYA;65=(#T@8VQO
M;F4["@E](&5L<V4*"0EA;&5R="@B0V%N)W0@<F5G:7-T97(@<&QU9VEN("(@
M*R!P;'5G:6XN=&]3=')I;F<H*2`K("(N(BD["GT["@HO+R!S=&%T:6,@9G5N
M8W1I;VX@=&AA="!L;V%D<R!T:&4@<F5Q=6ER960@<&QU9VEN(&%N9"!L86YG
M(&9I;&4L(&)A<V5D(&]N('1H90HO+R!L86YG=6%G92!L;V%D960@86QR96%D
M>2!F;W(@2%1-3$%R96$N("!9;W4@8F5T=&5R(&UA:V4@<W5R92!T:&%T('1H
M92!P;'5G:6X*+R\@7VAA<U\@=&AA="!L86YG=6%G92P@;W1H97)W:7-E('-H
M:70@;6EG:'0@:&%P<&5N(#LM*0I(5$U,07)E82YG9710;'5G:6Y$:7(@/2!F
M=6YC=&EO;BAP;'5G:6Y.86UE*2!["@ER971U<FX@7V5D:71O<E]U<FP@*R`B
M<&QU9VEN<R\B("L@<&QU9VEN3F%M93L*?3L*"DA434Q!<F5A+FQO8610;'5G
M:6X@/2!F=6YC=&EO;BAP;'5G:6Y.86UE*2!["@EV87(@9&ER(#T@=&AI<RYG
M9710;'5G:6Y$:7(H<&QU9VEN3F%M92D["@EV87(@<&QU9VEN(#T@<&QU9VEN
M3F%M92YR97!L86-E*"\H6V$M>ETI*%M!+5I=*2A;82UZ72DO9RP*"0D)"0EF
M=6YC=&EO;B`H<W1R+"!L,2P@;#(L(&PS*2!["@D)"0D)"7)E='5R;B!L,2`K
M("(M(B`K(&PR+G1O3&]W97)#87-E*"D@*R!L,SL*"0D)"0E]*2YT;TQO=V5R
M0V%S92@I("L@(BYJ<R(["@EV87(@<&QU9VEN7V9I;&4@/2!D:7(@*R`B+R(@
M*R!P;'5G:6X["@EV87(@<&QU9VEN7VQA;F<@/2!D:7(@*R`B+VQA;F<O(B`K
M(%]E9&ET;W)?;&%N9R`K("(N:G,B.PH)+R]D;V-U;65N="YW<FET92@B/'-C
M<FEP="!T>7!E/2=T97AT+VIA=F%S8W)I<'0G('-R8STG(B`K('!L=6=I;E]F
M:6QE("L@(B<^/"]S8W)I<'0^(BD["@DO+V1O8W5M96YT+G=R:71E*"(\<V-R
M:7!T('1Y<&4])W1E>'0O:F%V87-C<FEP="<@<W)C/2<B("L@<&QU9VEN7VQA
M;F<@*R`B)SX\+W-C<FEP=#XB*3L*"71H:7,N;&]A9%-C<FEP="AP;'5G:6Y?
M9FEL92D["@ET:&ES+FQO86138W)I<'0H<&QU9VEN7VQA;F<I.PI].PH*2%1-
M3$%R96$N;&]A9%-T>6QE(#T@9G5N8W1I;VXH<W1Y;&4L('!L=6=I;BD@>PH)
M=F%R('5R;"`](%]E9&ET;W)?=7)L('Q\("<G.PH):68@*'1Y<&5O9B!P;'5G
M:6X@(3T@(G5N9&5F:6YE9"(I('L*"0EU<FP@*ST@(G!L=6=I;G,O(B`K('!L
M=6=I;B`K("(O(CL*"7T*"75R;"`K/2!S='EL93L*"6EF("@O7EPO+RYT97-T
M*'-T>6QE*2D*"0EU<FP@/2!S='EL93L*"79A<B!H96%D(#T@9&]C=6UE;G0N
M9V5T16QE;65N='-">51A9TYA;64H(FAE860B*5LP73L*"79A<B!L:6YK(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@B;&EN:R(I.PH);&EN:RYR96P@/2`B
M<W1Y;&5S:&5E="(["@EL:6YK+FAR968@/2!U<FP["@EH96%D+F%P<&5N9$-H
M:6QD*&QI;FLI.PH)+R]D;V-U;65N="YW<FET92@B/'-T>6QE('1Y<&4])W1E
M>'0O8W-S)SY`:6UP;W)T('5R;"@B("L@=7)L("L@(BD[/"]S='EL93XB*3L*
M?3L*2%1-3$%R96$N;&]A9%-T>6QE*'1Y<&5O9B!?961I=&]R7V-S<R`]/2`B
M<W1R:6YG(B`_(%]E9&ET;W)?8W-S(#H@(FAT;6QA<F5A+F-S<R(I.PH*+RHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*@H@*B`@0V%T96=O<GDZ($5$251/4B!55$E,251)15,*("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B\*
M"DA434Q!<F5A+G!R;W1O='EP92YD96)U9U1R964@/2!F=6YC=&EO;B@I('L*
M"79A<B!T82`](&1O8W5M96YT+F-R96%T945L96UE;G0H(G1E>'1A<F5A(BD[
M"@ET82YS='EL92YW:61T:"`]("(Q,#`E(CL*"71A+G-T>6QE+FAE:6=H="`]
M("(R,&5M(CL*"71A+G9A;'5E(#T@(B(["@EF=6YC=&EO;B!D96)U9RAI;F1E
M;G0L('-T<BD@>PH)"69O<B`H.R`M+6EN9&5N="`^/2`P.RD*"0D)=&$N=F%L
M=64@*ST@(B`B.PH)"71A+G9A;'5E("L]('-T<B`K(")<;B(["@E].PH)9G5N
M8W1I;VX@7V1T*')O;W0L(&QE=F5L*2!["@D)=F%R('1A9R`](')O;W0N=&%G
M3F%M92YT;TQO=V5R0V%S92@I+"!I.PH)"79A<B!N<R`]($A434Q!<F5A+FES
M7VEE(#\@<F]O="YS8V]P94YA;64@.B!R;V]T+G!R969I>#L*"0ED96)U9RAL
M979E;"P@(BT@(B`K('1A9R`K("(@6R(@*R!N<R`K(")=(BD["@D)9F]R("AI
M(#T@<F]O="YF:7)S=$-H:6QD.R!I.R!I(#T@:2YN97AT4VEB;&EN9RD*"0D)
M:68@*&DN;F]D951Y<&4@/3T@,2D*"0D)"5]D="AI+"!L979E;"`K(#(I.PH)
M?3L*"5]D="AT:&ES+E]D;V,N8F]D>2P@,"D["@ED;V-U;65N="YB;V1Y+F%P
M<&5N9$-H:6QD*'1A*3L*?3L*"DA434Q!<F5A+F=E=$EN;F5R5&5X="`](&9U
M;F-T:6]N*&5L*2!["@EV87(@='AT(#T@)R<L(&D["@EF;W(@*&D@/2!E;"YF
M:7)S=$-H:6QD.R!I.R!I(#T@:2YN97AT4VEB;&EN9RD@>PH)"6EF("AI+FYO
M9&54>7!E(#T](#,I"@D)"71X="`K/2!I+F1A=&$["@D)96QS92!I9B`H:2YN
M;V1E5'EP92`]/2`Q*0H)"0ET>'0@*ST@2%1-3$%R96$N9V5T26YN97)497AT
M*&DI.PH)?0H)<F5T=7)N('1X=#L*?3L*"DA434Q!<F5A+G!R;W1O='EP92Y?
M=V]R9$-L96%N(#T@9G5N8W1I;VXH*2!["@EV87(*"0EE9&ET;W(@/2!T:&ES
M+`H)"7-T871S(#T@>PH)"0EE;7!T>5]T86=S(#H@,"P*"0D);7-O7V-L87-S
M("`Z(#`L"@D)"6US;U]S='EL92`@.B`P+`H)"0EM<V]?>&UL96P@(#H@,"P*
M"0D);W)I9U]L96X@("`Z('1H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3"YL96YG
M=&@L"@D)"50@("`@("`@("`@.B`H;F5W($1A=&4H*2DN9V5T5&EM92@I"@D)
M?2P*"0ES=&%T<U]T>'0@/2!["@D)"65M<'1Y7W1A9W,@.B`B16UP='D@=&%G
M<R!R96UO=F5D.B`B+`H)"0EM<V]?8VQA<W,@(#H@(DU33R!C;&%S<R!N86UE
M<R!R96UO=F5D.B`B+`H)"0EM<V]?<W1Y;&4@(#H@(DU33R!I;FQI;F4@<W1Y
M;&4@<F5M;W9E9#H@(BP*"0D);7-O7WAM;&5L("`Z(")-4T\@6$U,(&5L96UE
M;G1S('-T<FEP<&5D.B`B"@D)?3L*"69U;F-T:6]N('-H;W=3=&%T<R@I('L*
M"0EV87(@='AT(#T@(DA434Q!<F5A('=O<F0@8VQE86YE<B!S=&%T<SH@7&Y<
M;B(["@D)9F]R("AV87(@:2!I;B!S=&%T<RD*"0D):68@*'-T871S7W1X=%MI
M72D*"0D)"71X="`K/2!S=&%T<U]T>'1;:5T@*R!S=&%T<UMI72`K(")<;B([
M"@D)='AT("L](")<;DEN:71I86P@9&]C=6UE;G0@;&5N9W1H.B`B("L@<W1A
M=',N;W)I9U]L96X@*R`B7&XB.PH)"71X="`K/2`B1FEN86P@9&]C=6UE;G0@
M;&5N9W1H.B`B("L@961I=&]R+E]D;V,N8F]D>2YI;FYE<DA434PN;&5N9W1H
M("L@(EQN(CL*"0ET>'0@*ST@(D-L96%N+75P('1O;VL@(B`K("@H*&YE=R!$
M871E*"DI+F=E=%1I;64H*2`M('-T871S+E0I("\@,3`P,"D@*R`B('-E8V]N
M9',B.PH)"6%L97)T*'1X="D["@E].PH)9G5N8W1I;VX@8VQE87)#;&%S<RAN
M;V1E*2!["@D)=F%R(&YE=V,@/2!N;V1E+F-L87-S3F%M92YR97!L86-E*"\H
M7GQ<<REM<V\N*C\H7'-\)"DO:6<L("<@)RD["@D):68@*&YE=V,@(3T@;F]D
M92YC;&%S<TYA;64I('L*"0D);F]D92YC;&%S<TYA;64@/2!N97=C.PH)"0EI
M9B`H(2]<4R\N=&5S="AN;V1E+F-L87-S3F%M92DI('L*"0D)"6YO9&4N<F5M
M;W9E071T<FEB=71E*")C;&%S<TYA;64B*3L*"0D)"2LK<W1A=',N;7-O7V-L
M87-S.PH)"0E]"@D)?0H)?3L*"69U;F-T:6]N(&-L96%R4W1Y;&4H;F]D92D@
M>PH@"0EV87(@9&5C;&%R871I;VYS(#T@;F]D92YS='EL92YC<W-497AT+G-P
M;&ET*"]<<RH[7',J+RD["@D)9F]R("AV87(@:2`](&1E8VQA<F%T:6]N<RYL
M96YG=&@[("TM:2`^/2`P.RD*"0D):68@*"]>;7-O?%YT86(M<W1O<',O:2YT
M97-T*&1E8VQA<F%T:6]N<UMI72D@?'P*"0D)("`@("]>;6%R9VEN7',J.EQS
M*C`N+EQS*S`N+EQS*S`N+B]I+G1E<W0H9&5C;&%R871I;VYS6VE=*2D@>PH)
M"0D)*RMS=&%T<RYM<V]?<W1Y;&4["@D)"0ED96-L87)A=&EO;G,N<W!L:6-E
M*&DL(#$I.PH)"0E]"@D);F]D92YS='EL92YC<W-497AT(#T@9&5C;&%R871I
M;VYS+FIO:6XH(CL@(BD["@E].PH)9G5N8W1I;VX@<W1R:7!486<H96PI('L*
M"0EI9B`H2%1-3$%R96$N:7-?:64I"@D)"65L+F]U=&5R2%1-3"`]($A434Q!
M<F5A+FAT;6Q%;F-O9&4H96PN:6YN97)497AT*3L*"0EE;'-E('L*"0D)=F%R
M('1X="`](&1O8W5M96YT+F-R96%T951E>'1.;V1E*$A434Q!<F5A+F=E=$EN
M;F5R5&5X="AE;"DI.PH)"0EE;"YP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AT
M>'0L(&5L*3L*"0D)96PN<&%R96YT3F]D92YR96UO=F5#:&EL9"AE;"D["@D)
M?0H)"2LK<W1A=',N;7-O7WAM;&5L.PH)?3L*"69U;F-T:6]N(&-H96-K16UP
M='DH96PI('L*"0EI9B`H+UXH87QS<&%N?&)\<W1R;VYG?&E\96U\9F]N="DD
M+VDN=&5S="AE;"YT86=.86UE*2`F)@H)"2`@("`A96PN9FER<W1#:&EL9"D@
M>PH)"0EE;"YP87)E;G1.;V1E+G)E;6]V94-H:6QD*&5L*3L*"0D)*RMS=&%T
M<RYE;7!T>5]T86=S.PH)"7T*"7T["@EF=6YC=&EO;B!P87)S951R964H<F]O
M="D@>PH)"79A<B!T86<@/2!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H*2P@
M:2P@;F5X=#L*"0EI9B`H*$A434Q!<F5A+FES7VEE("8F(')O;W0N<V-O<&5.
M86UE("$]("=(5$U,)RD@?'P@*"%(5$U,07)E82YI<U]I92`F)B`O.B\N=&5S
M="AT86<I*2D@>PH)"0ES=')I<%1A9RAR;V]T*3L*"0D)<F5T=7)N(&9A;'-E
M.PH)"7T@96QS92!["@D)"6-L96%R0VQA<W,H<F]O="D["@D)"6-L96%R4W1Y
M;&4H<F]O="D["@D)"69O<B`H:2`](')O;W0N9FER<W1#:&EL9#L@:3L@:2`]
M(&YE>'0I('L*"0D)"6YE>'0@/2!I+FYE>'13:6)L:6YG.PH)"0D):68@*&DN
M;F]D951Y<&4@/3T@,2`F)B!P87)S951R964H:2DI"@D)"0D)8VAE8VM%;7!T
M>2AI*3L*"0D)?0H)"7T*"0ER971U<FX@=')U93L*"7T["@EP87)S951R964H
M=&AI<RY?9&]C+F)O9'DI.PH)+R\@<VAO=U-T871S*"D["@DO+R!T:&ES+F1E
M8G5G5')E92@I.PH)+R\@=&AI<RYS971(5$U,*'1H:7,N9V5T2%1-3"@I*3L*
M"2\O('1H:7,N<V5T2%1-3"AT:&ES+F=E=$EN;F5R2%1-3"@I*3L*"2\O('1H
M:7,N9F]R8V52961R87<H*3L*"71H:7,N=7!D871E5&]O;&)A<B@I.PI].PH*
M2%1-3$%R96$N<')O=&]T>7!E+F9O<F-E4F5D<F%W(#T@9G5N8W1I;VXH*2![
M"@ET:&ES+E]D;V,N8F]D>2YS='EL92YV:7-I8FEL:71Y(#T@(FAI9&1E;B([
M"@ET:&ES+E]D;V,N8F]D>2YS='EL92YV:7-I8FEL:71Y(#T@(G9I<VEB;&4B
M.PH)+R\@=&AI<RY?9&]C+F)O9'DN:6YN97)(5$U,(#T@=&AI<RYG971);FYE
M<DA434PH*3L*?3L*"B\O(&9O8W5S97,@=&AE(&EF<F%M92!W:6YD;W<N("!R
M971U<FYS(&$@<F5F97)E;F-E('1O('1H92!E9&ET;W(@9&]C=6UE;G0N"DA4
M34Q!<F5A+G!R;W1O='EP92YF;V-U<T5D:71O<B`](&9U;F-T:6]N*"D@>PH)
M<W=I=&-H("AT:&ES+E]E9&ET36]D92D@>PH)("`@("\O(&YO=&EC92!T:&4@
M=')Y('L@+BXN('T@8V%T8V@@8FQO8VL@=&\@879O:60@<V]M92!R87)E(&5X
M8V5P=&EO;G,@:6X@1FER949O>`H)("`@("\O("AP97)H87!S(&%L<V\@:6X@
M;W1H97(@1V5C:V\@8G)O=W-E<G,I+B!-86YU86P@9F]C=7,@8GD@=7-E<B!I
M<R!R97%U:7)E9"!I;@H@("`@("`@("\O(&-A<V4@;V8@86X@97)R;W(N(%-O
M;65B;V1Y(&AA<R!A;B!I9&5A/PH)("`@(&-A<V4@(G=Y<VEW>6<B(#H@=')Y
M('L@=&AI<RY?:69R86UE+F-O;G1E;G17:6YD;W<N9F]C=7,H*2!](&-A=&-H
M("AE*2![?2!B<F5A:SL*"2`@("!C87-E(")T97AT;6]D92(Z('1R>2![('1H
M:7,N7W1E>'1!<F5A+F9O8W5S*"D@?2!C871C:"`H92D@>WT@8G)E86L["@D@
M("`@9&5F875L=`D@("`Z(&%L97)T*")%4E)/4CH@;6]D92`B("L@=&AI<RY?
M961I=$UO9&4@*R`B(&ES(&YO="!D969I;F5D(BD["@E]"@ER971U<FX@=&AI
M<RY?9&]C.PI].PH*+R\@=&%K97,@82!S;F%P<VAO="!O9B!T:&4@8W5R<F5N
M="!T97AT("AF;W(@=6YD;RD*2%1-3$%R96$N<')O=&]T>7!E+E]U;F1O5&%K
M95-N87!S:&]T(#T@9G5N8W1I;VXH*2!["@DK*W1H:7,N7W5N9&]0;W,["@EI
M9B`H=&AI<RY?=6YD;U!O<R`^/2!T:&ES+F-O;F9I9RYU;F1O4W1E<',I('L*
M"0DO+R!R96UO=F4@=&AE(&9I<G-T(&5L96UE;G0*"0ET:&ES+E]U;F1O475E
M=64N<VAI9G0H*3L*"0DM+71H:7,N7W5N9&]0;W,["@E]"@DO+R!U<V4@=&AE
M(&9A<W1E9"!M971H;V0@*&=E=$EN;F5R2%1-3"D["@EV87(@=&%K92`]('1R
M=64["@EV87(@='AT(#T@=&AI<RYG971);FYE<DA434PH*3L*"6EF("AT:&ES
M+E]U;F1O4&]S(#X@,"D*"0ET86ME(#T@*'1H:7,N7W5N9&]1=65U95MT:&ES
M+E]U;F1O4&]S("T@,5T@(3T@='AT*3L*"6EF("AT86ME*2!["@D)=&AI<RY?
M=6YD;U%U975E6W1H:7,N7W5N9&]0;W-=(#T@='AT.PH)?2!E;'-E('L*"0ET
M:&ES+E]U;F1O4&]S+2T["@E]"GT["@I(5$U,07)E82YP<F]T;W1Y<&4N=6YD
M;R`](&9U;F-T:6]N*"D@>PH):68@*'1H:7,N7W5N9&]0;W,@/B`P*2!["@D)
M=F%R('1X="`]('1H:7,N7W5N9&]1=65U95LM+71H:7,N7W5N9&]0;W-=.PH)
M"6EF("AT>'0I('1H:7,N<V5T2%1-3"AT>'0I.PH)"65L<V4@*RMT:&ES+E]U
M;F1O4&]S.PH)?0I].PH*2%1-3$%R96$N<')O=&]T>7!E+G)E9&\@/2!F=6YC
M=&EO;B@I('L*"6EF("AT:&ES+E]U;F1O4&]S(#P@=&AI<RY?=6YD;U%U975E
M+FQE;F=T:"`M(#$I('L*"0EV87(@='AT(#T@=&AI<RY?=6YD;U%U975E6RLK
M=&AI<RY?=6YD;U!O<UT["@D):68@*'1X="D@=&AI<RYS971(5$U,*'1X="D[
M"@D)96QS92`M+71H:7,N7W5N9&]0;W,["@E]"GT["@HO+R!U<&1A=&5S(&5N
M86)L960O9&ES86)L92]A8W1I=F4@<W1A=&4@;V8@=&AE('1O;VQB87(@96QE
M;65N=',*2%1-3$%R96$N<')O=&]T>7!E+G5P9&%T951O;VQB87(@/2!F=6YC
M=&EO;BAN;U-T871U<RD@>PH)=F%R(&1O8R`]('1H:7,N7V1O8SL*"79A<B!T
M97AT(#T@*'1H:7,N7V5D:71-;V1E(#T](")T97AT;6]D92(I.PH)=F%R(&%N
M8V5S=&]R<R`](&YU;&P["@EI9B`H(71E>'0I('L*"0EA;F-E<W1O<G,@/2!T
M:&ES+F=E=$%L;$%N8V5S=&]R<R@I.PH)"6EF("AT:&ES+F-O;F9I9RYS=&%T
M=7-"87(@)B8@(6YO4W1A='5S*2!["@D)"71H:7,N7W-T871U<T)A<E1R964N
M:6YN97)(5$U,(#T@2%1-3$%R96$N23$X3BYM<V=;(E!A=&@B72`K("(Z("([
M("\O(&-L96%R"@D)"69O<B`H=F%R(&D@/2!A;F-E<W1O<G,N;&5N9W1H.R`M
M+6D@/CT@,#LI('L*"0D)"79A<B!E;"`](&%N8V5S=&]R<UMI73L*"0D)"6EF
M("@A96PI('L*"0D)"0DO+R!H96QL(&MN;W=S('=H>2!W92!G970@:&5R93L@
M=&AI<PH)"0D)"2\O(&-O=6QD(&)E(&$@8VQA<W-I8R!E>&%M<&QE(&]F('=H
M>0H)"0D)"2\O(&ET)W,@9V]O9"!T;R!C:&5C:R!F;W(@8V]N9&ET:6]N<PH)
M"0D)"2\O('1H870@87)E(&EM<&]S<VEB;&4@=&\@:&%P<&5N(#LM*0H)"0D)
M"6-O;G1I;G5E.PH)"0D)?0H)"0D)=F%R(&$@/2!D;V-U;65N="YC<F5A=&5%
M;&5M96YT*")A(BD["@D)"0EA+FAR968@/2`B(R(["@D)"0EA+F5L(#T@96P[
M"@D)"0EA+F5D:71O<B`]('1H:7,["@D)"0EA+F]N8VQI8VL@/2!F=6YC=&EO
M;B@I('L*"0D)"0ET:&ES+F)L=7(H*3L*"0D)"0ET:&ES+F5D:71O<BYS96QE
M8W1.;V1E0V]N=&5N=',H=&AI<RYE;"D["@D)"0D)=&AI<RYE9&ET;W(N=7!D
M871E5&]O;&)A<BAT<G5E*3L*"0D)"0ER971U<FX@9F%L<V4["@D)"0E].PH)
M"0D)82YO;F-O;G1E>'1M96YU(#T@9G5N8W1I;VXH*2!["@D)"0D)+R\@5$]$
M3SH@861D(&-O;G1E>'0@;65N=2!H97)E"@D)"0D)=&AI<RYB;'5R*"D["@D)
M"0D)=F%R(&EN9F\@/2`B26YL:6YE('-T>6QE.EQN7&XB.PH)"0D)"6EN9F\@
M*ST@=&AI<RYE;"YS='EL92YC<W-497AT+G-P;&ET*"\[7',J+RDN:F]I;B@B
M.UQN(BD["@D)"0D)86QE<G0H:6YF;RD["@D)"0D)<F5T=7)N(&9A;'-E.PH)
M"0D)?3L*"0D)"79A<B!T>'0@/2!E;"YT86=.86UE+G1O3&]W97)#87-E*"D[
M"@D)"0EA+G1I=&QE(#T@96PN<W1Y;&4N8W-S5&5X=#L*"0D)"6EF("AE;"YI
M9"D@>PH)"0D)"71X="`K/2`B(R(@*R!E;"YI9#L*"0D)"7T*"0D)"6EF("AE
M;"YC;&%S<TYA;64I('L*"0D)"0ET>'0@*ST@(BXB("L@96PN8VQA<W-.86UE
M.PH)"0D)?0H)"0D)82YA<'!E;F1#:&EL9"AD;V-U;65N="YC<F5A=&5497AT
M3F]D92AT>'0I*3L*"0D)"71H:7,N7W-T871U<T)A<E1R964N87!P96YD0VAI
M;&0H82D["@D)"0EI9B`H:2`A/2`P*2!["@D)"0D)=&AI<RY?<W1A='5S0F%R
M5')E92YA<'!E;F1#:&EL9"AD;V-U;65N="YC<F5A=&5497AT3F]D92A3=')I
M;F<N9G)O;4-H87)#;V1E*#!X8F(I*2D["@D)"0E]"@D)"7T*"0E]"@E]"@H)
M9F]R("AV87(@:2!I;B!T:&ES+E]T;V]L8F%R3V)J96-T<RD@>PH)"79A<B!B
M=&X@/2!T:&ES+E]T;V]L8F%R3V)J96-T<UMI73L*"0EV87(@8VUD(#T@:3L*
M"0EV87(@:6Y#;VYT97AT(#T@=')U93L*"0EI9B`H8G1N+F-O;G1E>'0@)B8@
M(71E>'0I('L*"0D):6Y#;VYT97AT(#T@9F%L<V4["@D)"79A<B!C;VYT97AT
M(#T@8G1N+F-O;G1E>'0["@D)"79A<B!A='1R<R`](%M=.PH)"0EI9B`H+R@N
M*BE<6R@N*C\I7%TO+G1E<W0H8V]N=&5X="DI('L*"0D)"6-O;G1E>'0@/2!2
M96=%>'`N)#$["@D)"0EA='1R<R`](%)E9T5X<"XD,BYS<&QI="@B+"(I.PH)
M"0E]"@D)"6-O;G1E>'0@/2!C;VYT97AT+G1O3&]W97)#87-E*"D["@D)"79A
M<B!M871C:"`]("AC;VYT97AT(#T]("(J(BD["@D)"69O<B`H=F%R(&L@/2`P
M.R!K(#P@86YC97-T;W)S+FQE;F=T:#L@*RMK*2!["@D)"0EI9B`H(6%N8V5S
M=&]R<UMK72D@>PH)"0D)"2\O('1H92!I;7!O<W-I8FQE(')E86QL>2!H87!P
M96YS+@H)"0D)"6-O;G1I;G5E.PH)"0D)?0H)"0D):68@*&UA=&-H('Q\("AA
M;F-E<W1O<G-;:UTN=&%G3F%M92YT;TQO=V5R0V%S92@I(#T](&-O;G1E>'0I
M*2!["@D)"0D):6Y#;VYT97AT(#T@=')U93L*"0D)"0EF;W(@*'9A<B!K82`]
M(#`[(&MA(#P@871T<G,N;&5N9W1H.R`K*VMA*2!["@D)"0D)"6EF("@A979A
M;"@B86YC97-T;W)S6VM=+B(@*R!A='1R<UMK85TI*2!["@D)"0D)"0EI;D-O
M;G1E>'0@/2!F86QS93L*"0D)"0D)"6)R96%K.PH)"0D)"0E]"@D)"0D)?0H)
M"0D)"6EF("AI;D-O;G1E>'0I('L*"0D)"0D)8G)E86L["@D)"0D)?0H)"0D)
M?0H)"0E]"@D)?0H)"6)T;BYS=&%T92@B96YA8FQE9"(L("@A=&5X="!\?"!B
M=&XN=&5X="D@)B8@:6Y#;VYT97AT*3L*"0EI9B`H='EP96]F(&-M9"`]/2`B
M9G5N8W1I;VXB*2!["@D)"6-O;G1I;G5E.PH)"7T*"0DO+R!L;V]K+6ET+75P
M(&EN('1H92!C=7-T;VT@9')O<&1O=VX@8F]X97,*"0EV87(@9')O<&1O=VX@
M/2!T:&ES+F-O;F9I9RYC=7-T;VU396QE8W1S6V-M9%T["@D):68@*"@A=&5X
M="!\?"!B=&XN=&5X="D@)B8@*'1Y<&5O9B!D<F]P9&]W;B`A/2`B=6YD969I
M;F5D(BDI('L*"0D)9')O<&1O=VXN<F5F<F5S:"AT:&ES*3L*"0D)8V]N=&EN
M=64["@D)?0H)"7-W:71C:"`H8VUD*2!["@D)("`@(&-A<V4@(F9O;G1N86UE
M(CH*"0D@("`@8V%S92`B9F]N='-I>F4B.@H)"2`@("!C87-E(")F;W)M871B
M;&]C:R(Z"@D)"6EF("@A=&5X="D@=')Y('L*"0D)"79A<B!V86QU92`]("@B
M(B`K(&1O8RYQ=65R>4-O;6UA;F1686QU92AC;60I*2YT;TQO=V5R0V%S92@I
M.PH)"0D):68@*"%V86QU92D@>PH)"0D)"6)T;BYE;&5M96YT+G-E;&5C=&5D
M26YD97@@/2`P.PH)"0D)"6)R96%K.PH)"0D)?0H)"0D)+R\@2$%#2R`M+2!R
M971R:65V92!T:&4@8V]N9FEG(&]P=&EO;B!F;W(@=&AI<PH)"0D)+R\@8V]M
M8F\@8F]X+B`@5V4@<F5L>2!O;B!T:&4@9F%C="!T:&%T('1H90H)"0D)+R\@
M=F%R:6%B;&4@:6X@8V]N9FEG(&AA<R!T:&4@<V%M92!N86UE(&%S"@D)"0DO
M+R!B=71T;VX@;F%M92!I;B!T:&4@=&]O;&)A<BX*"0D)"79A<B!O<'1I;VYS
M(#T@=&AI<RYC;VYF:6=;8VUD73L*"0D)"79A<B!K(#T@,#L*"0D)"69O<B`H
M=F%R(&H@:6X@;W!T:6]N<RD@>PH)"0D)"2\O($9)6$U%.B!T:&4@9F]L;&]W
M:6YG(&QI;F4@:7,@<V-A<GDN"@D)"0D):68@*"AJ+G1O3&]W97)#87-E*"D@
M/3T@=F%L=64I('Q\"@D)"0D)("`@("AO<'1I;VYS6VI=+G-U8G-T<B@P+"!V
M86QU92YL96YG=&@I+G1O3&]W97)#87-E*"D@/3T@=F%L=64I*2!["@D)"0D)
M"6)T;BYE;&5M96YT+G-E;&5C=&5D26YD97@@/2!K.PH)"0D)"0ET:')O=R`B
M;VLB.PH)"0D)"7T*"0D)"0DK*VL["@D)"0E]"@D)"0EB=&XN96QE;65N="YS
M96QE8W1E9$EN9&5X(#T@,#L*"0D)?2!C871C:"AE*2![?3L*"0D)8G)E86L[
M"@D)("`@(&-A<V4@(G1E>'1I;F1I8V%T;W(B.@H)"0EI9B`H(71E>'0I('L*
M"0D)"71R>2![=VET:"`H8G1N+F5L96UE;G0N<W1Y;&4I('L*"0D)"0EB86-K
M9W)O=6YD0V]L;W(@/2!(5$U,07)E82Y?;6%K94-O;&]R*`H)"0D)"0ED;V,N
M<75E<GE#;VUM86YD5F%L=64H2%1-3$%R96$N:7-?:64@/R`B8F%C:V-O;&]R
M(B`Z(")H:6QI=&5C;VQO<B(I*3L*"0D)"0EI9B`H+W1R86YS<&%R96YT+VDN
M=&5S="AB86-K9W)O=6YD0V]L;W(I*2!["@D)"0D)"2\O($UO>FEL;&$*"0D)
M"0D)8F%C:V=R;W5N9$-O;&]R(#T@2%1-3$%R96$N7VUA:V5#;VQO<BAD;V,N
M<75E<GE#;VUM86YD5F%L=64H(F)A8VMC;VQO<B(I*3L*"0D)"0E]"@D)"0D)
M8V]L;W(@/2!(5$U,07)E82Y?;6%K94-O;&]R*&1O8RYQ=65R>4-O;6UA;F16
M86QU92@B9F]R96-O;&]R(BDI.PH)"0D)"69O;G1&86UI;'D@/2!D;V,N<75E
M<GE#;VUM86YD5F%L=64H(F9O;G1N86UE(BD["@D)"0D)9F]N=%=E:6=H="`]
M(&1O8RYQ=65R>4-O;6UA;F13=&%T92@B8F]L9"(I(#\@(F)O;&0B(#H@(FYO
M<FUA;"(["@D)"0D)9F]N=%-T>6QE(#T@9&]C+G%U97)Y0V]M;6%N9%-T871E
M*")I=&%L:6,B*2`_(")I=&%L:6,B(#H@(FYO<FUA;"(["@D)"0E]?2!C871C
M:"`H92D@>PH)"0D)"2\O(&%L97)T*&4@*R`B7&Y<;B(@*R!C;60I.PH)"0D)
M?0H)"0E]"@D)"6)R96%K.PH)"2`@("!C87-E(")H=&UL;6]D92(Z(&)T;BYS
M=&%T92@B86-T:79E(BP@=&5X="D[(&)R96%K.PH)"2`@("!C87-E(")L969T
M=&]R:6=H="(Z"@D)("`@(&-A<V4@(G)I9VAT=&]L969T(CH*"0D)=F%R(&5L
M(#T@=&AI<RYG971087)E;G1%;&5M96YT*"D["@D)"7=H:6QE("AE;"`F)B`A
M2%1-3$%R96$N:7-";&]C:T5L96UE;G0H96PI*0H)"0D)96P@/2!E;"YP87)E
M;G1.;V1E.PH)"0EI9B`H96PI"@D)"0EB=&XN<W1A=&4H(F%C=&EV92(L("AE
M;"YS='EL92YD:7)E8W1I;VX@/3T@*"AC;60@/3T@(G)I9VAT=&]L969T(BD@
M/R`B<G1L(B`Z(")L='(B*2DI.PH)"0EB<F5A:SL*"0D@("`@9&5F875L=#H*
M"0D)8VUD(#T@8VUD+G)E<&QA8V4H+RAU;BD_;W)D97)E9&QI<W0O:2P@(FEN
M<V5R="0Q;W)D97)E9&QI<W0B*3L*"0D)=')Y('L*"0D)"6)T;BYS=&%T92@B
M86-T:79E(BP@*"%T97AT("8F(&1O8RYQ=65R>4-O;6UA;F13=&%T92AC;60I
M*2D["@D)"7T@8V%T8V@@*&4I('M]"@D)?0H)?0H)+R\@=&%K92!U;F1O('-N
M87!S:&]T<PH):68@*'1H:7,N7V-U<W1O;55N9&\@)B8@(71H:7,N7W1I;65R
M56YD;RD@>PH)"71H:7,N7W5N9&]486ME4VYA<'-H;W0H*3L*"0EV87(@961I
M=&]R(#T@=&AI<SL*"0ET:&ES+E]T:6UE<E5N9&\@/2!S9714:6UE;W5T*&9U
M;F-T:6]N*"D@>PH)"0EE9&ET;W(N7W1I;65R56YD;R`](&YU;&P["@D)?2P@
M=&AI<RYC;VYF:6<N=6YD;U1I;65O=70I.PH)?0H*"2\O(&-H96-K(&EF(&%N
M>2!P;'5G:6YS(&AA=F4@<F5G:7-T97)E9"!R969R97-H(&AA;F1L97)S"@EF
M;W(@*'9A<B!I(&EN('1H:7,N<&QU9VEN<RD@>PH)"79A<B!P;'5G:6X@/2!T
M:&ES+G!L=6=I;G-;:5TN:6YS=&%N8V4["@D):68@*'1Y<&5O9B!P;'5G:6XN
M;VY5<&1A=&54;V]L8F%R(#T](")F=6YC=&EO;B(I"@D)"7!L=6=I;BYO;E5P
M9&%T951O;VQB87(H*3L*"7T*?3L*"B\J*B!2971U<FYS(&$@;F]D92!A9G1E
M<B!W:&EC:"!W92!C86X@:6YS97)T(&]T:&5R(&YO9&5S+"!I;B!T:&4@8W5R
M<F5N=`H@*B!S96QE8W1I;VXN("!4:&4@<V5L96-T:6]N(&ES(')E;6]V960N
M("!)="!S<&QI=',@82!T97AT(&YO9&4L(&EF(&YE961E9"X*("HO"DA434Q!
M<F5A+G!R;W1O='EP92YI;G-E<G1.;V1E071396QE8W1I;VX@/2!F=6YC=&EO
M;BAT;T)E26YS97)T960I('L*"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0EV
M87(@<V5L(#T@=&AI<RY?9V5T4V5L96-T:6]N*"D["@D)=F%R(')A;F=E(#T@
M=&AI<RY?8W)E871E4F%N9V4H<V5L*3L*"0DO+R!R96UO=F4@=&AE(&-U<G)E
M;G0@<V5L96-T:6]N"@D)<V5L+G)E;6]V94%L;%)A;F=E<R@I.PH)"7)A;F=E
M+F1E;&5T94-O;G1E;G1S*"D["@D)=F%R(&YO9&4@/2!R86YG92YS=&%R=$-O
M;G1A:6YE<CL*"0EV87(@<&]S(#T@<F%N9V4N<W1A<G1/9F9S970["@D)<W=I
M=&-H("AN;V1E+FYO9&54>7!E*2!["@D)("`@(&-A<V4@,SH@+R\@3F]D92Y4
M15A47TY/1$4*"0D)+R\@=V4@:&%V92!T;R!S<&QI="!I="!A="!T:&4@8V%R
M970@<&]S:71I;VXN"@D)"6EF("AT;T)E26YS97)T960N;F]D951Y<&4@/3T@
M,RD@>PH)"0D)+R\@9&\@;W!T:6UI>F5D(&EN<V5R=&EO;@H)"0D);F]D92YI
M;G-E<G1$871A*'!O<RP@=&]"94EN<V5R=&5D+F1A=&$I.PH)"0D)<F%N9V4@
M/2!T:&ES+E]C<F5A=&5286YG92@I.PH)"0D)<F%N9V4N<V5T16YD*&YO9&4L
M('!O<R`K('1O0F5);G-E<G1E9"YL96YG=&@I.PH)"0D)<F%N9V4N<V5T4W1A
M<G0H;F]D92P@<&]S("L@=&]"94EN<V5R=&5D+FQE;F=T:"D["@D)"0ES96PN
M861D4F%N9V4H<F%N9V4I.PH)"0E](&5L<V4@>PH)"0D);F]D92`](&YO9&4N
M<W!L:71497AT*'!O<RD["@D)"0EV87(@<V5L;F]D92`]('1O0F5);G-E<G1E
M9#L*"0D)"6EF("AT;T)E26YS97)T960N;F]D951Y<&4@/3T@,3$@+RH@3F]D
M92Y$3T-5345.5%]&4D%'345.5%].3T1%("HO*2!["@D)"0D)<V5L;F]D92`]
M('-E;&YO9&4N9FER<W1#:&EL9#L*"0D)"7T*"0D)"6YO9&4N<&%R96YT3F]D
M92YI;G-E<G1"969O<F4H=&]"94EN<V5R=&5D+"!N;V1E*3L*"0D)"71H:7,N
M<V5L96-T3F]D94-O;G1E;G1S*'-E;&YO9&4I.PH)"0D)=&AI<RYU<&1A=&54
M;V]L8F%R*"D["@D)"7T*"0D)8G)E86L["@D)("`@(&-A<V4@,3H@+R\@3F]D
M92Y%3$5-14Y47TY/1$4*"0D)=F%R('-E;&YO9&4@/2!T;T)E26YS97)T960[
M"@D)"6EF("AT;T)E26YS97)T960N;F]D951Y<&4@/3T@,3$@+RH@3F]D92Y$
M3T-5345.5%]&4D%'345.5%].3T1%("HO*2!["@D)"0ES96QN;V1E(#T@<V5L
M;F]D92YF:7)S=$-H:6QD.PH)"0E]"@D)"6YO9&4N:6YS97)T0F5F;W)E*'1O
M0F5);G-E<G1E9"P@;F]D92YC:&EL9$YO9&5S6W!O<UTI.PH)"0ET:&ES+G-E
M;&5C=$YO9&5#;VYT96YT<RAS96QN;V1E*3L*"0D)=&AI<RYU<&1A=&54;V]L
M8F%R*"D["@D)"6)R96%K.PH)"7T*"7T@96QS92!["@D)<F5T=7)N(&YU;&P[
M"2\O('1H:7,@9G5N8W1I;VX@;F]T('EE="!U<V5D(&9O<B!)12`\1DE8344^
M"@E]"GT["@HO+R!2971U<FYS('1H92!D965P97-T(&YO9&4@=&AA="!C;VYT
M86EN<R!B;W1H(&5N9'!O:6YT<R!O9B!T:&4@<V5L96-T:6]N+@I(5$U,07)E
M82YP<F]T;W1Y<&4N9V5T4&%R96YT16QE;65N="`](&9U;F-T:6]N*"D@>PH)
M=F%R('-E;"`]('1H:7,N7V=E=%-E;&5C=&EO;B@I.PH)=F%R(')A;F=E(#T@
M=&AI<RY?8W)E871E4F%N9V4H<V5L*3L*"6EF("A(5$U,07)E82YI<U]I92D@
M>PH)"7-W:71C:"`H<V5L+G1Y<&4I('L*"0D@("`@8V%S92`B5&5X="(Z"@D)
M("`@(&-A<V4@(DYO;F4B.@H)"0DO+R!)="!S965M<R!T:&%T(&5V96X@9F]R
M('-E;&5C=&EO;B!O9B!T>7!E(").;VYE(BP*"0D)+R\@=&AE<F4@7VES7R!A
M('!A<F5N="!E;&5M96YT(&%N9"!I="=S('9A;'5E(&ES(&YO=`H)"0DO+R!O
M;FQY(&-O<G)E8W0L(&)U="!V97)Y(&EM<&]R=&%N="!T;R!U<RX@($U3244@
M:7,*"0D)+R\@8V5R=&%I;FQY('1H92!B=6=G:65S="!B<F]W<V5R(&EN('1H
M92!W;W)L9"!A;F0@20H)"0DO+R!W;VYD97(L($=O9"P@:&]W(&-A;B!%87)T
M:"!S=&%N9"!I=#\*"0D)<F5T=7)N(')A;F=E+G!A<F5N=$5L96UE;G0H*3L*
M"0D@("`@8V%S92`B0V]N=')O;"(Z"@D)"7)E='5R;B!R86YG92YI=&5M*#`I
M.PH)"2`@("!D969A=6QT.@H)"0ER971U<FX@=&AI<RY?9&]C+F)O9'D["@D)
M?0H)?2!E;'-E('1R>2!["@D)=F%R('`@/2!R86YG92YC;VUM;VY!;F-E<W1O
M<D-O;G1A:6YE<CL*"0EI9B`H(7)A;F=E+F-O;&QA<'-E9"`F)B!R86YG92YS
M=&%R=$-O;G1A:6YE<B`]/2!R86YG92YE;F1#;VYT86EN97(@)B8*"0D@("`@
M<F%N9V4N<W1A<G1/9F9S970@+2!R86YG92YE;F1/9F9S970@/#T@,2`F)B!R
M86YG92YS=&%R=$-O;G1A:6YE<BYH87-#:&EL9$YO9&5S*"DI"@D)"7`@/2!R
M86YG92YS=&%R=$-O;G1A:6YE<BYC:&EL9$YO9&5S6W)A;F=E+G-T87)T3V9F
M<V5T73L*"0DO*@H)"6%L97)T*')A;F=E+G-T87)T0V]N=&%I;F5R("L@(CHB
M("L@<F%N9V4N<W1A<G1/9F9S970@*R`B7&XB("L*"0D@("`@("!R86YG92YE
M;F1#;VYT86EN97(@*R`B.B(@*R!R86YG92YE;F1/9F9S970I.PH)"2HO"@D)
M=VAI;&4@*'`N;F]D951Y<&4@/3T@,RD@>PH)"0EP(#T@<"YP87)E;G1.;V1E
M.PH)"7T*"0ER971U<FX@<#L*"7T@8V%T8V@@*&4I('L*"0ER971U<FX@;G5L
M;#L*"7T*?3L*"B\O(%)E='5R;G,@86X@87)R87D@=VET:"!A;&P@=&AE(&%N
M8V5S=&]R(&YO9&5S(&]F('1H92!S96QE8W1I;VXN"DA434Q!<F5A+G!R;W1O
M='EP92YG971!;&Q!;F-E<W1O<G,@/2!F=6YC=&EO;B@I('L*"79A<B!P(#T@
M=&AI<RYG971087)E;G1%;&5M96YT*"D["@EV87(@82`](%M=.PH)=VAI;&4@
M*'`@)B8@*'`N;F]D951Y<&4@/3T@,2D@)B8@*'`N=&%G3F%M92YT;TQO=V5R
M0V%S92@I("$]("=B;V1Y)RDI('L*"0EA+G!U<V@H<"D["@D)<"`]('`N<&%R
M96YT3F]D93L*"7T*"6$N<'5S:"AT:&ES+E]D;V,N8F]D>2D["@ER971U<FX@
M83L*?3L*"B\O(%-E;&5C=',@=&AE(&-O;G1E;G1S(&EN<VED92!T:&4@9VEV
M96X@;F]D90I(5$U,07)E82YP<F]T;W1Y<&4N<V5L96-T3F]D94-O;G1E;G1S
M(#T@9G5N8W1I;VXH;F]D92P@<&]S*2!["@ET:&ES+F9O8W5S161I=&]R*"D[
M"@ET:&ES+F9O<F-E4F5D<F%W*"D["@EV87(@<F%N9V4["@EV87(@8V]L;&%P
M<V5D(#T@*'1Y<&5O9B!P;W,@(3T@(G5N9&5F:6YE9"(I.PH):68@*$A434Q!
M<F5A+FES7VEE*2!["@D)<F%N9V4@/2!T:&ES+E]D;V,N8F]D>2YC<F5A=&54
M97AT4F%N9V4H*3L*"0ER86YG92YM;W9E5&]%;&5M96YT5&5X="AN;V1E*3L*
M"0DH8V]L;&%P<V5D*2`F)B!R86YG92YC;VQL87!S92AP;W,I.PH)"7)A;F=E
M+G-E;&5C="@I.PH)?2!E;'-E('L*"0EV87(@<V5L(#T@=&AI<RY?9V5T4V5L
M96-T:6]N*"D["@D)<F%N9V4@/2!T:&ES+E]D;V,N8W)E871E4F%N9V4H*3L*
M"0ER86YG92YS96QE8W1.;V1E0V]N=&5N=',H;F]D92D["@D)*&-O;&QA<'-E
M9"D@)B8@<F%N9V4N8V]L;&%P<V4H<&]S*3L*"0ES96PN<F5M;W9E06QL4F%N
M9V5S*"D["@D)<V5L+F%D9%)A;F=E*')A;F=E*3L*"7T*?3L*"B\J*B!#86QL
M('1H:7,@9G5N8W1I;VX@=&\@:6YS97)T($A434P@8V]D92!A="!T:&4@8W5R
M<F5N="!P;W-I=&EO;BX@($ET(&1E;&5T97,*("H@=&AE('-E;&5C=&EO;BP@
M:68@86YY+@H@*B\*2%1-3$%R96$N<')O=&]T>7!E+FEN<V5R=$A434P@/2!F
M=6YC=&EO;BAH=&UL*2!["@EV87(@<V5L(#T@=&AI<RY?9V5T4V5L96-T:6]N
M*"D["@EV87(@<F%N9V4@/2!T:&ES+E]C<F5A=&5286YG92AS96PI.PH):68@
M*$A434Q!<F5A+FES7VEE*2!["@D)<F%N9V4N<&%S=&5(5$U,*&AT;6PI.PH)
M?2!E;'-E('L*"0DO+R!C;VYS=')U8W0@82!N97<@9&]C=6UE;G0@9G)A9VUE
M;G0@=VET:"!T:&4@9VEV96X@2%1-3`H)"79A<B!F<F%G;65N="`]('1H:7,N
M7V1O8RYC<F5A=&5$;V-U;65N=$9R86=M96YT*"D["@D)=F%R(&1I=B`]('1H
M:7,N7V1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"0ED:78N:6YN97)(5$U,
M(#T@:'1M;#L*"0EW:&EL92`H9&EV+F9I<G-T0VAI;&0I('L*"0D)+R\@=&AE
M(&9O;&QO=VEN9R!C86QL(&%L<V\@<F5M;W9E<R!T:&4@;F]D92!F<F]M(&1I
M=@H)"0EF<F%G;65N="YA<'!E;F1#:&EL9"AD:78N9FER<W1#:&EL9"D["@D)
M?0H)"2\O('1H:7,@86QS;R!R96UO=F5S('1H92!S96QE8W1I;VX*"0EV87(@
M;F]D92`]('1H:7,N:6YS97)T3F]D94%T4V5L96-T:6]N*&9R86=M96YT*3L*
M"7T*?3L*"B\J*@H@*B`@0V%L;"!T:&ES(&9U;F-T:6]N('1O('-U<G)O=6YD
M('1H92!E>&ES=&EN9R!(5$U,(&-O9&4@:6X@=&AE('-E;&5C=&EO;B!W:71H
M"B`J("!Y;W5R('1A9W,N("!&25A-13H@8G5G9WDA("!4:&ES(&9U;F-T:6]N
M('=I;&P@8F4@9&5P<F5C871E9"`B<V]O;B(N"B`J+PI(5$U,07)E82YP<F]T
M;W1Y<&4N<W5R<F]U;F1(5$U,(#T@9G5N8W1I;VXH<W1A<G1486<L(&5N9%1A
M9RD@>PH)=F%R(&AT;6P@/2!T:&ES+F=E=%-E;&5C=&5D2%1-3"@I.PH)+R\@
M=&AE(&9O;&QO=VEN9R!A;'-O(&1E;&5T97,@=&AE('-E;&5C=&EO;@H)=&AI
M<RYI;G-E<G1(5$U,*'-T87)T5&%G("L@:'1M;"`K(&5N9%1A9RD["GT["@HO
M+R\@4F5T<FEE=F4@=&AE('-E;&5C=&5D(&)L;V-K"DA434Q!<F5A+G!R;W1O
M='EP92YG971396QE8W1E9$A434P@/2!F=6YC=&EO;B@I('L*"79A<B!S96P@
M/2!T:&ES+E]G971396QE8W1I;VXH*3L*"79A<B!R86YG92`]('1H:7,N7V-R
M96%T95)A;F=E*'-E;"D["@EV87(@97AI<W1I;F<@/2!N=6QL.PH):68@*$A4
M34Q!<F5A+FES7VEE*2!["@D)97AI<W1I;F<@/2!R86YG92YH=&UL5&5X=#L*
M"7T@96QS92!["@D)97AI<W1I;F<@/2!(5$U,07)E82YG971(5$U,*')A;F=E
M+F-L;VYE0V]N=&5N=',H*2P@9F%L<V4L('1H:7,I.PH)?0H)<F5T=7)N(&5X
M:7-T:6YG.PI].PH*+R\O(%)E='5R;B!T<G5E(&EF('=E(&AA=F4@<V]M92!S
M96QE8W1I;VX*2%1-3$%R96$N<')O=&]T>7!E+FAA<U-E;&5C=&5D5&5X="`]
M(&9U;F-T:6]N*"D@>PH)+R\@1DE8344Z(&-O;64@7V]N7R!M:7-H;V\L('EO
M=2!C86X@9&\@8F5T=&5R('1H86X@=&AI<R`[+2D*"7)E='5R;B!T:&ES+F=E
M=%-E;&5C=&5D2%1-3"@I("$]("<G.PI].PH*2%1-3$%R96$N<')O=&]T>7!E
M+E]C<F5A=&5,:6YK(#T@9G5N8W1I;VXH;&EN:RD@>PH)=F%R(&5D:71O<B`]
M('1H:7,["@EV87(@;W5T<&%R86T@/2!N=6QL.PH):68@*'1Y<&5O9B!L:6YK
M(#T](")U;F1E9FEN960B*2!["@D);&EN:R`]('1H:7,N9V5T4&%R96YT16QE
M;65N="@I.PH)"6EF("AL:6YK*2!["@D)"6EF("@O7FEM9R0O:2YT97-T*&QI
M;FLN=&%G3F%M92DI"@D)"0EL:6YK(#T@;&EN:RYP87)E;G1.;V1E.PH)"0EI
M9B`H(2]>820O:2YT97-T*&QI;FLN=&%G3F%M92DI"@D)"0EL:6YK(#T@;G5L
M;#L*"0E]"@E]"@EI9B`H(6QI;FLI('L*"0EV87(@<V5L(#T@961I=&]R+E]G
M971396QE8W1I;VXH*3L*"0EV87(@<F%N9V4@/2!E9&ET;W(N7V-R96%T95)A
M;F=E*'-E;"D["@D)=F%R(&-O;7!A<F4@/2`P.PH)"6EF("A(5$U,07)E82YI
M<U]I92D@>PH)"0EC;VUP87)E(#T@<F%N9V4N8V]M<&%R945N9%!O:6YT<R@B
M4W1A<G14;T5N9"(L(')A;F=E*3L*"0E](&5L<V4@>PH)"0EC;VUP87)E(#T@
M<F%N9V4N8V]M<&%R94)O=6YD87)Y4&]I;G1S*')A;F=E+E-405)47U1/7T5.
M1"P@<F%N9V4I.PH)"7T*"0EI9B`H8V]M<&%R92`]/2`P*2!["@D)"6%L97)T
M*")9;W4@;F5E9"!T;R!S96QE8W0@<V]M92!T97AT(&)E9F]R92!C<F5A=&EN
M9R!A(&QI;FLB*3L*"0D)<F5T=7)N.PH)"7T*"0EO=71P87)A;2`]('L*"0D)
M9E]H<F5F(#H@)R<L"@D)"69?=&ET;&4@.B`G)RP*"0D)9E]T87)G970@.B`G
M)RP*"0D)9E]U<V5T87)G970@.B!E9&ET;W(N8V]N9FEG+FUA:V5,:6YK4VAO
M=W-487)G970*"0E].PH)?2!E;'-E"@D);W5T<&%R86T@/2!["@D)"69?:')E
M9B`@(#H@2%1-3$%R96$N:7-?:64@/R!E9&ET;W(N<W1R:7!"87-E55),*&QI
M;FLN:')E9BD@.B!L:6YK+F=E=$%T=')I8G5T92@B:')E9B(I+`H)"0EF7W1I
M=&QE("`Z(&QI;FLN=&ET;&4L"@D)"69?=&%R9V5T(#H@;&EN:RYT87)G970L
M"@D)"69?=7-E=&%R9V5T(#H@961I=&]R+F-O;F9I9RYM86ME3&EN:U-H;W=S
M5&%R9V5T"@D)?3L*"71H:7,N7W!O<'5P1&EA;&]G*")L:6YK+FAT;6PB+"!F
M=6YC=&EO;BAP87)A;2D@>PH)"6EF("@A<&%R86TI"@D)"7)E='5R;B!F86QS
M93L*"0EV87(@82`](&QI;FL["@D):68@*"%A*2!T<GD@>PH)"0EE9&ET;W(N
M7V1O8RYE>&5C0V]M;6%N9"@B8W)E871E;&EN:R(L(&9A;'-E+"!P87)A;2YF
M7VAR968I.PH)"0EA(#T@961I=&]R+F=E=%!A<F5N=$5L96UE;G0H*3L*"0D)
M=F%R('-E;"`](&5D:71O<BY?9V5T4V5L96-T:6]N*"D["@D)"79A<B!R86YG
M92`](&5D:71O<BY?8W)E871E4F%N9V4H<V5L*3L*"0D):68@*"%(5$U,07)E
M82YI<U]I92D@>PH)"0D)82`](')A;F=E+G-T87)T0V]N=&%I;F5R.PH)"0D)
M:68@*"$O7F$D+VDN=&5S="AA+G1A9TYA;64I*2!["@D)"0D)82`](&$N;F5X
M=%-I8FQI;F<["@D)"0D):68@*&$@/3T@;G5L;"D*"0D)"0D)82`](')A;F=E
M+G-T87)T0V]N=&%I;F5R+G!A<F5N=$YO9&4["@D)"0E]"@D)"7T*"0E](&-A
M=&-H*&4I('M]"@D)96QS92!["@D)"79A<B!H<F5F(#T@<&%R86TN9E]H<F5F
M+G1R:6TH*3L*"0D)961I=&]R+G-E;&5C=$YO9&5#;VYT96YT<RAA*3L*"0D)
M:68@*&AR968@/3T@(B(I('L*"0D)"65D:71O<BY?9&]C+F5X96-#;VUM86YD
M*")U;FQI;FLB+"!F86QS92P@;G5L;"D["@D)"0EE9&ET;W(N=7!D871E5&]O
M;&)A<B@I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E]"@D)"65L<V4@>PH)"0D)
M82YH<F5F(#T@:')E9CL*"0D)?0H)"7T*"0EI9B`H(2AA("8F("]>820O:2YT
M97-T*&$N=&%G3F%M92DI*0H)"0ER971U<FX@9F%L<V4["@D)82YT87)G970@
M/2!P87)A;2YF7W1A<F=E="YT<FEM*"D["@D)82YT:71L92`]('!A<F%M+F9?
M=&ET;&4N=')I;2@I.PH)"65D:71O<BYS96QE8W1.;V1E0V]N=&5N=',H82D[
M"@D)961I=&]R+G5P9&%T951O;VQB87(H*3L*"7TL(&]U='!A<F%M*3L*?3L*
M"B\O($-A;&QE9"!W:&5N('1H92!U<V5R(&-L:6-K<R!O;B`B26YS97)T26UA
M9V4B(&)U='1O;BX@($EF(&%N(&EM86=E(&ES(&%L<F5A9'D*+R\@=&AE<F4L
M(&ET('=I;&P@:G5S="!M;V1I9GD@:70G<R!P<F]P97)T:65S+@I(5$U,07)E
M82YP<F]T;W1Y<&4N7VEN<V5R=$EM86=E(#T@9G5N8W1I;VXH:6UA9V4I('L*
M"79A<B!E9&ET;W(@/2!T:&ES.PDO+R!F;W(@;F5S=&5D(&9U;F-T:6]N<PH)
M=F%R(&]U='!A<F%M(#T@;G5L;#L*"6EF("AT>7!E;V8@:6UA9V4@/3T@(G5N
M9&5F:6YE9"(I('L*"0EI;6%G92`]('1H:7,N9V5T4&%R96YT16QE;65N="@I
M.PH)"6EF("AI;6%G92`F)B`A+UYI;6<D+VDN=&5S="AI;6%G92YT86=.86UE
M*2D*"0D):6UA9V4@/2!N=6QL.PH)?0H):68@*&EM86=E*2!O=71P87)A;2`]
M('L*"0EF7V)A<V4@("`Z(&5D:71O<BYC;VYF:6<N8F%S95523"P*"0EF7W5R
M;"`@("`Z($A434Q!<F5A+FES7VEE(#\@961I=&]R+G-T<FEP0F%S95523"AI
M;6%G92YS<F,I(#H@:6UA9V4N9V5T071T<FEB=71E*")S<F,B*2P*"0EF7V%L
M="`@("`Z(&EM86=E+F%L="P*"0EF7V)O<F1E<B`Z(&EM86=E+F)O<F1E<BP*
M"0EF7V%L:6=N("`Z(&EM86=E+F%L:6=N+`H)"69?=F5R="`@(#H@:6UA9V4N
M=G-P86-E+`H)"69?:&]R:7H@(#H@:6UA9V4N:'-P86-E"@E].PH)=&AI<RY?
M<&]P=7!$:6%L;V<H(FEN<V5R=%]I;6%G92YH=&UL(BP@9G5N8W1I;VXH<&%R
M86TI('L*"0EI9B`H(7!A<F%M*2!["2\O('5S97(@;75S="!H879E('!R97-S
M960@0V%N8V5L"@D)"7)E='5R;B!F86QS93L*"0E]"@D)=F%R(&EM9R`](&EM
M86=E.PH)"6EF("@A:6UG*2!["@D)"79A<B!S96P@/2!E9&ET;W(N7V=E=%-E
M;&5C=&EO;B@I.PH)"0EV87(@<F%N9V4@/2!E9&ET;W(N7V-R96%T95)A;F=E
M*'-E;"D["@D)"65D:71O<BY?9&]C+F5X96-#;VUM86YD*")I;G-E<G1I;6%G
M92(L(&9A;'-E+"!P87)A;2YF7W5R;"D["@D)"6EF("A(5$U,07)E82YI<U]I
M92D@>PH)"0D):6UG(#T@<F%N9V4N<&%R96YT16QE;65N="@I.PH)"0D)+R\@
M=V]N9&5R(&EF('1H:7,@=V]R:W,N+BX*"0D)"6EF("AI;6<N=&%G3F%M92YT
M;TQO=V5R0V%S92@I("$](")I;6<B*2!["@D)"0D):6UG(#T@:6UG+G!R979I
M;W5S4VEB;&EN9SL*"0D)"7T*"0D)?2!E;'-E('L*"0D)"6EM9R`](')A;F=E
M+G-T87)T0V]N=&%I;F5R+G!R979I;W5S4VEB;&EN9SL*"0D)?0H)"7T@96QS
M92!["@D)"6EM9RYS<F,@/2!P87)A;2YF7W5R;#L*"0E]"@H)"69O<B`H=F%R
M(&9I96QD(&EN('!A<F%M*2!["@D)"79A<B!V86QU92`]('!A<F%M6V9I96QD
M73L*"0D)<W=I=&-H("AF:65L9"D@>PH)"0D@("`@8V%S92`B9E]A;'0B("`@
M(#H@:6UG+F%L=`D@/2!V86QU93L@8G)E86L["@D)"2`@("!C87-E(")F7V)O
M<F1E<B(@.B!I;6<N8F]R9&5R(#T@<&%R<V5);G0H=F%L=64@?'P@(C`B*3L@
M8G)E86L["@D)"2`@("!C87-E(")F7V%L:6=N(B`@.B!I;6<N86QI9VX)(#T@
M=F%L=64[(&)R96%K.PH)"0D@("`@8V%S92`B9E]V97)T(B`@(#H@:6UG+G9S
M<&%C92`]('!A<G-E26YT*'9A;'5E('Q\("(P(BD[(&)R96%K.PH)"0D@("`@
M8V%S92`B9E]H;W)I>B(@(#H@:6UG+FAS<&%C92`]('!A<G-E26YT*'9A;'5E
M('Q\("(P(BD[(&)R96%K.PH)"0E]"@D)?0H)?2P@;W5T<&%R86TI.PI].PH*
M+R\@0V%L;&5D('=H96X@=&AE('5S97(@8VQI8VMS('1H92!);G-E<G0@5&%B
M;&4@8G5T=&]N"DA434Q!<F5A+G!R;W1O='EP92Y?:6YS97)T5&%B;&4@/2!F
M=6YC=&EO;B@I('L*"79A<B!S96P@/2!T:&ES+E]G971396QE8W1I;VXH*3L*
M"79A<B!R86YG92`]('1H:7,N7V-R96%T95)A;F=E*'-E;"D["@EV87(@961I
M=&]R(#T@=&AI<SL)+R\@9F]R(&YE<W1E9"!F=6YC=&EO;G,*"71H:7,N7W!O
M<'5P1&EA;&]G*")I;G-E<G1?=&%B;&4N:'1M;"(L(&9U;F-T:6]N*'!A<F%M
M*2!["@D):68@*"%P87)A;2D@>PDO+R!U<V5R(&UU<W0@:&%V92!P<F5S<V5D
M($-A;F-E;`H)"0ER971U<FX@9F%L<V4["@D)?0H)"79A<B!D;V,@/2!E9&ET
M;W(N7V1O8SL*"0DO+R!C<F5A=&4@=&AE('1A8FQE(&5L96UE;G0*"0EV87(@
M=&%B;&4@/2!D;V,N8W)E871E16QE;65N="@B=&%B;&4B*3L*"0DO+R!A<W-I
M9VX@=&AE(&=I=F5N(&%R9W5M96YT<PH*"0EF;W(@*'9A<B!F:65L9"!I;B!P
M87)A;2D@>PH)"0EV87(@=F%L=64@/2!P87)A;5MF:65L9%T["@D)"6EF("@A
M=F%L=64I('L*"0D)"6-O;G1I;G5E.PH)"0E]"@D)"7-W:71C:"`H9FEE;&0I
M('L*"0D)("`@(&-A<V4@(F9?=VED=&@B("`@.B!T86)L92YS='EL92YW:61T
M:"`]('9A;'5E("L@<&%R86U;(F9?=6YI=")=.R!B<F5A:SL*"0D)("`@(&-A
M<V4@(F9?86QI9VXB("`@.B!T86)L92YA;&EG;@D@/2!V86QU93L@8G)E86L[
M"@D)"2`@("!C87-E(")F7V)O<F1E<B(@(#H@=&%B;&4N8F]R9&5R"2`]('!A
M<G-E26YT*'9A;'5E*3L@8G)E86L["@D)"2`@("!C87-E(")F7W-P86-I;F<B
M(#H@=&%B;&4N8V5L;%-P86-I;F<@/2!P87)S94EN="AV86QU92D[(&)R96%K
M.PH)"0D@("`@8V%S92`B9E]P861D:6YG(B`Z('1A8FQE+F-E;&Q0861D:6YG
M(#T@<&%R<V5);G0H=F%L=64I.R!B<F5A:SL*"0D)?0H)"7T*"0EV87(@8V5L
M;'=I9'1H(#T@,#L*"0EI9B`H<&%R86TN9E]F:7AE9"D*"0D)8V5L;'=I9'1H
M(#T@36%T:"YF;&]O<B@Q,#`@+R!P87)S94EN="AP87)A;2YF7V-O;',I*3L*
M"0EV87(@=&)O9'D@/2!D;V,N8W)E871E16QE;65N="@B=&)O9'DB*3L*"0ET
M86)L92YA<'!E;F1#:&EL9"AT8F]D>2D["@D)9F]R("AV87(@:2`](#`[(&D@
M/"!P87)A;5LB9E]R;W=S(ET[("LK:2D@>PH)"0EV87(@='(@/2!D;V,N8W)E
M871E16QE;65N="@B='(B*3L*"0D)=&)O9'DN87!P96YD0VAI;&0H='(I.PH)
M"0EF;W(@*'9A<B!J(#T@,#L@:B`\('!A<F%M6R)F7V-O;',B73L@*RMJ*2![
M"@D)"0EV87(@=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"0D)"6EF
M("AC96QL=VED=&@I"@D)"0D)=&0N<W1Y;&4N=VED=&@@/2!C96QL=VED=&@@
M*R`B)2(["@D)"0ET<BYA<'!E;F1#:&EL9"AT9"D["@D)"0DO+R!-;WII;&QA
M(&QI:V5S('1O('-E92!S;VUE=&AI;F<@:6YS:61E('1H92!C96QL+@H)"0D)
M*$A434Q!<F5A+FES7V=E8VMO*2`F)B!T9"YA<'!E;F1#:&EL9"AD;V,N8W)E
M871E16QE;65N="@B8G(B*2D["@D)"7T*"0E]"@D):68@*$A434Q!<F5A+FES
M7VEE*2!["@D)"7)A;F=E+G!A<W1E2%1-3"AT86)L92YO=71E<DA434PI.PH)
M"7T@96QS92!["@D)"2\O(&EN<V5R="!T:&4@=&%B;&4*"0D)961I=&]R+FEN
M<V5R=$YO9&5!=%-E;&5C=&EO;BAT86)L92D["@D)?0H)"7)E='5R;B!T<G5E
M.PH)?2P@;G5L;"D["GT["@HO*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ"B`J("!#871E9V]R>3H@159%3E0@
M2$%.1$Q%4E,*("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B\*"B\O(&5L(&ES(')E9F5R96YC92!T;R!T:&4@
M4T5,14-4(&]B:F5C=`HO+R!T>'0@:7,@=&AE(&YA;64@;V8@=&AE('-E;&5C
M="!F:65L9"P@87,@:6X@8V]N9FEG+G1O;VQB87(*2%1-3$%R96$N<')O=&]T
M>7!E+E]C;VUB;U-E;&5C=&5D(#T@9G5N8W1I;VXH96PL('1X="D@>PH)=&AI
M<RYF;V-U<T5D:71O<B@I.PH)=F%R('9A;'5E(#T@96PN;W!T:6]N<UME;"YS
M96QE8W1E9$EN9&5X72YV86QU93L*"7-W:71C:"`H='AT*2!["@D@("`@8V%S
M92`B9F]N=&YA;64B.@H)("`@(&-A<V4@(F9O;G1S:7IE(CH@=&AI<RYE>&5C
M0V]M;6%N9"AT>'0L(&9A;'-E+"!V86QU92D[(&)R96%K.PH)("`@(&-A<V4@
M(F9O<FUA=&)L;V-K(CH*"0DH2%1-3$%R96$N:7-?:64I("8F("AV86QU92`]
M("(\(B`K('9A;'5E("L@(CXB*3L*"0ET:&ES+F5X96-#;VUM86YD*'1X="P@
M9F%L<V4L('9A;'5E*3L*"0EB<F5A:SL*"2`@("!D969A=6QT.@H)"2\O('1R
M>2!T;R!L;V]K(&ET('5P(&EN('1H92!R96=I<W1E<F5D(&1R;W!D;W=N<PH)
M"79A<B!D<F]P9&]W;B`]('1H:7,N8V]N9FEG+F-U<W1O;5-E;&5C='-;='AT
M73L*"0EI9B`H='EP96]F(&1R;W!D;W=N("$](")U;F1E9FEN960B*2!["@D)
M"61R;W!D;W=N+F%C=&EO;BAT:&ES*3L*"0E](&5L<V4@>PH)"0EA;&5R="@B
M1DE8344Z(&-O;6)O(&)O>"`B("L@='AT("L@(B!N;W0@:6UP;&5M96YT960B
M*3L*"0E]"@E]"GT["@HO+R!T:&4@97AE8T-O;6UA;F0@9G5N8W1I;VX@*&EN
M=&5R8V5P=',@<V]M92!C;VUM86YD<R!A;F0@<F5P;&%C97,@=&AE;2!W:71H
M"B\O(&]U<B!O=VX@:6UP;&5M96YT871I;VXI"DA434Q!<F5A+G!R;W1O='EP
M92YE>&5C0V]M;6%N9"`](&9U;F-T:6]N*&-M9$E$+"!522P@<&%R86TI('L*
M"79A<B!E9&ET;W(@/2!T:&ES.PDO+R!F;W(@;F5S=&5D(&9U;F-T:6]N<PH)
M=&AI<RYF;V-U<T5D:71O<B@I.PH)8VUD240@/2!C;61)1"YT;TQO=V5R0V%S
M92@I.PH):68@*$A434Q!<F5A+FES7V=E8VMO*2!T<GD@>R!T:&ES+E]D;V,N
M97AE8T-O;6UA;F0H)W5S94-34R<L(&9A;'-E+"!T<G5E*3L@?2!C871C:"`H
M92D@>WT["@ES=VET8V@@*&-M9$E$*2!["@D@("`@8V%S92`B:'1M;&UO9&4B
M(#H@=&AI<RYS971-;V1E*"D[(&)R96%K.PH)("`@(&-A<V4@(FAI;&ET96-O
M;&]R(CH*"0DH2%1-3$%R96$N:7-?:64I("8F("AC;61)1"`](")B86-K8V]L
M;W(B*3L*"2`@("!C87-E(")F;W)E8V]L;W(B.@H)"71H:7,N7W!O<'5P1&EA
M;&]G*")S96QE8W1?8V]L;W(N:'1M;"(L(&9U;F-T:6]N*&-O;&]R*2!["@D)
M"6EF("AC;VQO<BD@>R`O+R!S96QE8W1I;VX@;F]T(&-A;F-E;&5D"@D)"0EE
M9&ET;W(N7V1O8RYE>&5C0V]M;6%N9"AC;61)1"P@9F%L<V4L("(C(B`K(&-O
M;&]R*3L*"0D)?0H)"7TL($A434Q!<F5A+E]C;VQO<E1O4F=B*'1H:7,N7V1O
M8RYQ=65R>4-O;6UA;F1686QU92AC;61)1"DI*3L*"0EB<F5A:SL*"2`@("!C
M87-E(")C<F5A=&5L:6YK(CH*"0ET:&ES+E]C<F5A=&5,:6YK*"D["@D)8G)E
M86L["@D@("`@8V%S92`B<&]P=7!E9&ET;W(B.@H)"2\O('1H:7,@;V)J96-T
M('=I;&P@8F4@<&%S<V5D('1O('1H92!N97=L>2!O<&5N960@=VEN9&]W"@D)
M2%1-3$%R96$N7V]B:F5C="`]('1H:7,["@D):68@*$A434Q!<F5A+FES7VEE
M*2!["@D)"2\O:68@*&-O;F9I<FTH2%1-3$%R96$N23$X3BYM<V=;(DE%+7-U
M8VMS+69U;&PM<V-R965N(ETI*0H)"0E["@D)"0EW:6YD;W<N;W!E;BAT:&ES
M+G!O<'5P55),*")F=6QL<V-R965N+FAT;6PB*2P@(FAA7V9U;&QS8W)E96XB
M+`H)"0D)"2`@("`B=&]O;&)A<CUN;RQL;V-A=&EO;CUN;RQD:7)E8W1O<FEE
M<SUN;RQS=&%T=7,];F\L;65N=6)A<CUN;RPB("L*"0D)"0D@("`@(G-C<F]L
M;&)A<G,];F\L<F5S:7IA8FQE/7EE<RQW:61T:#TV-#`L:&5I9VAT/30X,"(I
M.PH)"0E]"@D)?2!E;'-E('L*"0D)=VEN9&]W+F]P96XH=&AI<RYP;W!U<%52
M3"@B9G5L;'-C<F5E;BYH=&UL(BDL(")H85]F=6QL<V-R965N(BP*"0D)"2`@
M("`B=&]O;&)A<CUN;RQM96YU8F%R/6YO+'!E<G-O;F%L8F%R/6YO+'=I9'1H
M/38T,"QH96EG:'0]-#@P+"(@*PH)"0D)("`@(")S8W)O;&QB87)S/6YO+')E
M<VEZ86)L93UY97,B*3L*"0E]"@D)8G)E86L["@D@("`@8V%S92`B=6YD;R(Z
M"@D@("`@8V%S92`B<F5D;R(Z"@D):68@*'1H:7,N7V-U<W1O;55N9&\I"@D)
M"71H:7-;8VUD241=*"D["@D)96QS90H)"0ET:&ES+E]D;V,N97AE8T-O;6UA
M;F0H8VUD240L(%5)+"!P87)A;2D["@D)8G)E86L["@D@("`@8V%S92`B:6YS
M97)T=&%B;&4B.B!T:&ES+E]I;G-E<G1486)L92@I.R!B<F5A:SL*"2`@("!C
M87-E(")I;G-E<G1I;6%G92(Z('1H:7,N7VEN<V5R=$EM86=E*"D[(&)R96%K
M.PH)("`@(&-A<V4@(F%B;W5T(B`@("`Z('1H:7,N7W!O<'5P1&EA;&]G*")A
M8F]U="YH=&UL(BP@;G5L;"P@=&AI<RD[(&)R96%K.PH)("`@(&-A<V4@(G-H
M;W=H96QP(B`Z('=I;F1O=RYO<&5N*%]E9&ET;W)?=7)L("L@(G)E9F5R96YC
M92YH=&UL(BP@(FAA7VAE;'`B*3L@8G)E86L["@H)("`@(&-A<V4@(FMI;&QW
M;W)D(CH@=&AI<RY?=V]R9$-L96%N*"D[(&)R96%K.PH*"2`@("!C87-E(")C
M=70B.@H)("`@(&-A<V4@(F-O<'DB.@H)("`@(&-A<V4@(G!A<W1E(CH*"0ET
M<GD@>PH)"0ET:&ES+E]D;V,N97AE8T-O;6UA;F0H8VUD240L(%5)+"!P87)A
M;2D["@D)"6EF("AT:&ES+F-O;F9I9RYK:6QL5V]R9$]N4&%S=&4I"@D)"0ET
M:&ES+E]W;W)D0VQE86XH*3L*"0E](&-A=&-H("AE*2!["@D)"6EF("A(5$U,
M07)E82YI<U]G96-K;RD@>PH)"0D):68@*'1Y<&5O9B!(5$U,07)E82Y),3A.
M+FUS9ULB36]Z+4-L:7!B;V%R9")=(#T](")U;F1E9FEN960B*2!["@D)"0D)
M2%1-3$%R96$N23$X3BYM<V=;(DUO>BU#;&EP8F]A<F0B72`]"@D)"0D)"2)5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2`B("L*"0D)"0D)(F9O<B!S96-U<FET>2!R
M96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@
M;6]Z:6QL82YO<F<@(B`K"@D)"0D)"2)W:&EC:"!S:&]W<R!Y;W4@:&]W('1O
M(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+EQN7&XB
M("L*"0D)"0D)(EM&25A-13H@<&QE87-E('1R86YS;&%T92!T:&ES(&UE<W-A
M9V4@:6X@>6]U<B!L86YG=6%G92!D969I;FET:6]N(&9I;&4N72(["@D)"0E]
M"@D)"0EI9B`H8V]N9FER;2A(5$U,07)E82Y),3A.+FUS9ULB36]Z+4-L:7!B
M;V%R9")=*2D*"0D)"0EW:6YD;W<N;W!E;B@B:'1T<#HO+VUO>FEL;&$N;W)G
M+V5D:71O<B]M:61A<V1E;6\O<V5C=7)I='EP<F5F<RYH=&UL(BD["@D)"7T*
M"0E]"@D)8G)E86L["@D@("`@8V%S92`B;&5F='1O<FEG:'0B.@H)("`@(&-A
M<V4@(G)I9VAT=&]L969T(CH*"0EV87(@9&ER(#T@*&-M9$E$(#T](")R:6=H
M='1O;&5F="(I(#\@(G)T;"(@.B`B;'1R(CL*"0EV87(@96P@/2!T:&ES+F=E
M=%!A<F5N=$5L96UE;G0H*3L*"0EW:&EL92`H96P@)B8@(4A434Q!<F5A+FES
M0FQO8VM%;&5M96YT*&5L*2D*"0D)96P@/2!E;"YP87)E;G1.;V1E.PH)"6EF
M("AE;"D@>PH)"0EI9B`H96PN<W1Y;&4N9&ER96-T:6]N(#T](&1I<BD*"0D)
M"65L+G-T>6QE+F1I<F5C=&EO;B`]("(B.PH)"0EE;'-E"@D)"0EE;"YS='EL
M92YD:7)E8W1I;VX@/2!D:7(["@D)?0H)"6)R96%K.PH)("`@(&1E9F%U;'0Z
M('1R>2![('1H:7,N7V1O8RYE>&5C0V]M;6%N9"AC;61)1"P@54DL('!A<F%M
M*3L@?0H)"6-A=&-H*&4I('L@:68@*'1H:7,N8V]N9FEG+F1E8G5G*2![(&%L
M97)T*&4@*R`B7&Y<;F)Y(&5X96-#;VUM86YD*"(@*R!C;61)1"`K("(I.R(I
M.R!]('T*"7T*"71H:7,N=7!D871E5&]O;&)A<B@I.PH)<F5T=7)N(&9A;'-E
M.PI].PH*+RHJ($$@9V5N97)I8R!E=F5N="!H86YD;&5R(&9O<B!T:&EN9W,@
M=&AA="!H87!P96X@:6X@=&AE($E&4D%-12=S(&1O8W5M96YT+@H@*B!4:&ES
M(&9U;F-T:6]N(&%L<V\@:&%N9&QE<R!K97D@8FEN9&EN9W,N("HO"DA434Q!
M<F5A+G!R;W1O='EP92Y?961I=&]R179E;G0@/2!F=6YC=&EO;BAE=BD@>PH)
M=F%R(&5D:71O<B`]('1H:7,["@EV87(@:V5Y179E;G0@/2`H2%1-3$%R96$N
M:7-?:64@)B8@978N='EP92`]/2`B:V5Y9&]W;B(I('Q\("@A2%1-3$%R96$N
M:7-?:64@)B8@978N='EP92`]/2`B:V5Y<')E<W,B*3L*"@EI9B`H:V5Y179E
M;G0I"@D)9F]R("AV87(@:2!I;B!E9&ET;W(N<&QU9VEN<RD@>PH)"0EV87(@
M<&QU9VEN(#T@961I=&]R+G!L=6=I;G-;:5TN:6YS=&%N8V4["@D)"6EF("AT
M>7!E;V8@<&QU9VEN+F]N2V5Y4')E<W,@/3T@(F9U;F-T:6]N(BD*"0D)"6EF
M("AP;'5G:6XN;VY+97E0<F5S<RAE=BDI"@D)"0D)<F5T=7)N(&9A;'-E.PH)
M"7T*"6EF("AK97E%=F5N="`F)B!E=BYC=')L2V5Y("8F("%E=BYA;'1+97DI
M('L*"0EV87(@<V5L(#T@;G5L;#L*"0EV87(@<F%N9V4@/2!N=6QL.PH)"79A
M<B!K97D@/2!3=')I;F<N9G)O;4-H87)#;V1E*$A434Q!<F5A+FES7VEE(#\@
M978N:V5Y0V]D92`Z(&5V+F-H87)#;V1E*2YT;TQO=V5R0V%S92@I.PH)"79A
M<B!C;60@/2!N=6QL.PH)"79A<B!V86QU92`](&YU;&P["@D)<W=I=&-H("AK
M97DI('L*"0D@("`@8V%S92`G82<Z"@D)"6EF("@A2%1-3$%R96$N:7-?:64I
M('L*"0D)"2\O($M%62!S96QE8W0@86QL"@D)"0ES96P@/2!T:&ES+E]G9713
M96QE8W1I;VXH*3L*"0D)"7-E;"YR96UO=F5!;&Q286YG97,H*3L*"0D)"7)A
M;F=E(#T@=&AI<RY?8W)E871E4F%N9V4H*3L*"0D)"7)A;F=E+G-E;&5C=$YO
M9&5#;VYT96YT<RAT:&ES+E]D;V,N8F]D>2D["@D)"0ES96PN861D4F%N9V4H
M<F%N9V4I.PH)"0D)2%1-3$%R96$N7W-T;W!%=F5N="AE=BD["@D)"7T*"0D)
M8G)E86L["@H)"0DO+R!S:6UP;&4@:V5Y(&-O;6UA;F1S(&9O;&QO=PH*"0D@
M("`@8V%S92`G8B<Z(&-M9"`](")B;VQD(CL@8G)E86L["@D)("`@(&-A<V4@
M)VDG.B!C;60@/2`B:71A;&EC(CL@8G)E86L["@D)("`@(&-A<V4@)W4G.B!C
M;60@/2`B=6YD97)L:6YE(CL@8G)E86L["@D)("`@(&-A<V4@)W,G.B!C;60@
M/2`B<W1R:6ME=&AR;W5G:"([(&)R96%K.PH)"2`@("!C87-E("=L)SH@8VUD
M(#T@(FIU<W1I9GEL969T(CL@8G)E86L["@D)("`@(&-A<V4@)V4G.B!C;60@
M/2`B:G5S=&EF>6-E;G1E<B([(&)R96%K.PH)"2`@("!C87-E("=R)SH@8VUD
M(#T@(FIU<W1I9GER:6=H="([(&)R96%K.PH)"2`@("!C87-E("=J)SH@8VUD
M(#T@(FIU<W1I9GEF=6QL(CL@8G)E86L["@D)("`@(&-A<V4@)WHG.B!C;60@
M/2`B=6YD;R([(&)R96%K.PH)"2`@("!C87-E("=Y)SH@8VUD(#T@(G)E9&\B
M.R!B<F5A:SL*"0D@("`@8V%S92`G=B<Z(&EF("A(5$U,07)E82YI<U]I92!\
M?"!E9&ET;W(N8V]N9FEG+FAT;6QA<F5A4&%S=&4I('L@8VUD(#T@(G!A<W1E
M(CL@?2!B<F5A:SL*"0D@("`@8V%S92`G;B<Z(&-M9"`](")F;W)M871B;&]C
M:R([('9A;'5E(#T@2%1-3$%R96$N:7-?:64@/R`B/'`^(B`Z(")P(CL@8G)E
M86L["@H)"2`@("!C87-E("<P)SH@8VUD(#T@(FMI;&QW;W)D(CL@8G)E86L[
M"@H)"0DO+R!H96%D:6YG<PH)"2`@("!C87-E("<Q)SH*"0D@("`@8V%S92`G
M,B<Z"@D)("`@(&-A<V4@)S,G.@H)"2`@("!C87-E("<T)SH*"0D@("`@8V%S
M92`G-2<Z"@D)("`@(&-A<V4@)S8G.@H)"0EC;60@/2`B9F]R;6%T8FQO8VLB
M.PH)"0EV86QU92`](")H(B`K(&ME>3L*"0D):68@*$A434Q!<F5A+FES7VEE
M*0H)"0D)=F%L=64@/2`B/"(@*R!V86QU92`K("(^(CL*"0D)8G)E86L["@D)
M?0H)"6EF("AC;60I('L*"0D)+R\@97AE8W5T92!S:6UP;&4@8V]M;6%N9`H)
M"0ET:&ES+F5X96-#;VUM86YD*&-M9"P@9F%L<V4L('9A;'5E*3L*"0D)2%1-
M3$%R96$N7W-T;W!%=F5N="AE=BD["@D)?0H)?0H)96QS92!I9B`H:V5Y179E
M;G0I('L*"0DO+R!O=&AE<B!K97ES(&AE<F4*"0ES=VET8V@@*&5V+FME>4-O
M9&4I('L*"0D@("`@8V%S92`Q,SH@+R\@2T59(&5N=&5R"@D)"6EF("A(5$U,
M07)E82YI<U]G96-K;R`F)B`A978N<VAI9G1+97DI('L*"0D)"71H:7,N9&]M
M7V-H96-K26YS97)T4"@I.PH)"0D)2%1-3$%R96$N7W-T;W!%=F5N="AE=BD[
M"@D)"7T*"0D)8G)E86L["@D)("`@(&-A<V4@.#H@+R\@2T59(&)A8VMS<&%C
M90H)"2`@("!C87-E(#0V.B`O+R!+15D@9&5L971E"@D)"6EF("A(5$U,07)E
M82YI<U]G96-K;R`F)B`A978N<VAI9G1+97DI('L*"0D)"6EF("AT:&ES+F1O
M;5]C:&5C:T)A8VMS<&%C92@I*0H)"0D)"4A434Q!<F5A+E]S=&]P179E;G0H
M978I.PH)"0E](&5L<V4@:68@*$A434Q!<F5A+FES7VEE*2!["@D)"0EI9B`H
M=&AI<RYI95]C:&5C:T)A8VMS<&%C92@I*0H)"0D)"4A434Q!<F5A+E]S=&]P
M179E;G0H978I.PH)"0E]"@D)"6)R96%K.PH)"7T*"7T*"@DO+R!U<&1A=&4@
M=&AE('1O;VQB87(@<W1A=&4@869T97(@<V]M92!T:6UE"@EI9B`H961I=&]R
M+E]T:6UE<E1O;VQB87(I('L*"0EC;&5A<E1I;65O=70H961I=&]R+E]T:6UE
M<E1O;VQB87(I.PH)?0H)961I=&]R+E]T:6UE<E1O;VQB87(@/2!S9714:6UE
M;W5T*&9U;F-T:6]N*"D@>PH)"65D:71O<BYU<&1A=&54;V]L8F%R*"D["@D)
M961I=&]R+E]T:6UE<E1O;VQB87(@/2!N=6QL.PH)?2P@-3`I.PI].PH*2%1-
M3$%R96$N<')O=&]T>7!E+G-C<F]L;%1O0V%R970@/2!F=6YC=&EO;B@I('L*
M"79A<@H)"64@/2!T:&ES+F=E=%!A<F5N=$5L96UE;G0H*2P*"0EW(#T@=&AI
M<RY?:69R86UE+F-O;G1E;G17:6YD;W<L"@D):"`]('<N:6YN97)(96EG:'0@
M?'P@=RYH96EG:'0L"@D)9"`]('1H:7,N7V1O8RP*"0ET(#T@9"YD;V-U;65N
M=$5L96UE;G0N<V-R;VQL5&]P('Q\(&0N8F]D>2YS8W)O;&Q4;W`["@EI9B`H
M='EP96]F(&@@/3T@(G5N9&5F:6YE9"(I"@D)<F5T=7)N(&9A;'-E.PH):68@
M*&4N;V9F<V5T5&]P(#X@:"`K('0I"@D)=RYS8W)O;&Q4;RAE+F]F9G-E=$QE
M9G0L(&4N;V9F<V5T5&]P("T@:"`K(&4N;V9F<V5T2&5I9VAT*3L*?3L*"DA4
M34Q!<F5A+G!R;W1O='EP92YC;VYV97)T3F]D92`](&9U;F-T:6]N*&5L+"!N
M97=486=.86UE*2!["@EV87(@;F5W96P@/2!T:&ES+E]D;V,N8W)E871E16QE
M;65N="AN97=486=.86UE*2P@<"`](&5L+G!A<F5N=$YO9&4["@EW:&EL92`H
M96PN9FER<W1#:&EL9"D*"0EN97=E;"YA<'!E;F1#:&EL9"AE;"YF:7)S=$-H
M:6QD*3L*"7`N:6YS97)T0F5F;W)E*&YE=V5L+"!E;"D["@EP+G)E;6]V94-H
M:6QD*&5L*3L*"7)E='5R;B!N97=E;#L*?3L*"DA434Q!<F5A+G!R;W1O='EP
M92YI95]C:&5C:T)A8VMS<&%C92`](&9U;F-T:6]N*"D@>PH)=F%R('-E;"`]
M('1H:7,N7V=E=%-E;&5C=&EO;B@I.PH)=F%R(')A;F=E(#T@=&AI<RY?8W)E
M871E4F%N9V4H<V5L*3L*"79A<B!R,B`](')A;F=E+F1U<&QI8V%T92@I.PH)
M<C(N;6]V95-T87)T*")C:&%R86-T97(B+"`M,2D["@EV87(@82`]('(R+G!A
M<F5N=$5L96UE;G0H*3L*"6EF("AA("$](')A;F=E+G!A<F5N=$5L96UE;G0H
M*2`F)@H)("`@("]>820O:2YT97-T*&$N=&%G3F%M92DI('L*"0ER,BYC;VQL
M87!S92AT<G5E*3L*"0ER,BYM;W9E16YD*")C:&%R86-T97(B+"`Q*3L*"0ER
M,BYP87-T94A434PH)R<I.PH)"7(R+G-E;&5C="@I.PH)"7)E='5R;B!T<G5E
M.PH)?0I].PH*2%1-3$%R96$N<')O=&]T>7!E+F1O;5]C:&5C:T)A8VMS<&%C
M92`](&9U;F-T:6]N*"D@>PH)=F%R('-E;&8@/2!T:&ES.PH)<V5T5&EM96]U
M="AF=6YC=&EO;B@I('L*"0EV87(@<V5L(#T@<V5L9BY?9V5T4V5L96-T:6]N
M*"D["@D)=F%R(')A;F=E(#T@<V5L9BY?8W)E871E4F%N9V4H<V5L*3L*"0EV
M87(@4T,@/2!R86YG92YS=&%R=$-O;G1A:6YE<CL*"0EV87(@4T\@/2!R86YG
M92YS=&%R=$]F9G-E=#L*"0EV87(@14,@/2!R86YG92YE;F1#;VYT86EN97([
M"@D)=F%R($5/(#T@<F%N9V4N96YD3V9F<V5T.PH)"79A<B!N97=R(#T@4T,N
M;F5X=%-I8FQI;F<["@D):68@*%-#+FYO9&54>7!E(#T](#,I"@D)"5-#(#T@
M4T,N<&%R96YT3F]D93L*"0EI9B`H(2]<4R\N=&5S="A30RYT86=.86UE*2D@
M>PH)"0EV87(@<"`](&1O8W5M96YT+F-R96%T945L96UE;G0H(G`B*3L*"0D)
M=VAI;&4@*%-#+F9I<G-T0VAI;&0I"@D)"0EP+F%P<&5N9$-H:6QD*%-#+F9I
M<G-T0VAI;&0I.PH)"0E30RYP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AP+"!3
M0RD["@D)"5-#+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H4T,I.PH)"0EV87(@
M<B`](')A;F=E+F-L;VYE4F%N9V4H*3L*"0D)<BYS9713=&%R=$)E9F]R92AN
M97=R*3L*"0D)<BYS971%;F1!9G1E<BAN97=R*3L*"0D)<BYE>'1R86-T0V]N
M=&5N=',H*3L*"0D)<V5L+G)E;6]V94%L;%)A;F=E<R@I.PH)"0ES96PN861D
M4F%N9V4H<BD["@D)?0H)?2P@,3`I.PI].PH*2%1-3$%R96$N<')O=&]T>7!E
M+F1O;5]C:&5C:TEN<V5R=%`@/2!F=6YC=&EO;B@I('L*"79A<B!I+"!30RP@
M;&5F="P@<FEG:'0L('(R+`H)"7-E;"`@(#T@=&AI<RY?9V5T4V5L96-T:6]N
M*"DL"@D)<B`@("`@/2!T:&ES+E]C<F5A=&5286YG92AS96PI+`H)"7`@("`@
M(#T@=&AI<RYG971!;&Q!;F-E<W1O<G,H*2P*"0EB;&]C:R`](&YU;&PL"@D)
M9&]C("`@/2!T:&ES+E]D;V,L"@D)8F]D>2`@/2!D;V,N8F]D>3L*"@EF;W(@
M*&D@/2`P.R!I(#P@<"YL96YG=&@[("LK:2D*"0EI9B`H2%1-3$%R96$N:7-"
M;&]C:T5L96UE;G0H<%MI72D@)B8@(2]B;V1Y?&AT;6PO:2YT97-T*'!;:5TN
M=&%G3F%M92DI('L*"0D)8FQO8VL@/2!P6VE=.PH)"0EB<F5A:SL*"0E]"@H)
M:68@*"%R+F-O;&QA<'-E9"D*"0ER+F1E;&5T94-O;G1E;G1S*"D["@ES96PN
M<F5M;W9E06QL4F%N9V5S*"D["@E30R`]('(N<W1A<G1#;VYT86EN97(["@H)
M:68@*"%B;&]C:RD@>PH)"6QE9G0@/2!30SL*"0EF;W(@*&D@/2!30SL@:2`F
M)B!I("$](&)O9'D@)B8@(4A434Q!<F5A+FES0FQO8VM%;&5M96YT*&DI.R!I
M(#T@2%1-3$%R96$N9V5T4')E=DYO9&4H:2DI"@D)"6QE9G0@/2!I.PH)"7)I
M9VAT(#T@4T,["@D)9F]R("AI(#T@4T,[(&D@)B8@:2`A/2!B;V1Y("8F("%(
M5$U,07)E82YI<T)L;V-K16QE;65N="AI*3L@:2`]($A434Q!<F5A+F=E=$YE
M>'1.;V1E*&DI*0H)"0ER:6=H="`](&D["@D):68@*&QE9G0@(3T@8F]D>2`F
M)B!R:6=H="`A/2!B;V1Y*2!["@D)"7(R(#T@<BYC;&]N95)A;F=E*"D["@D)
M"7(R+G-E=%-T87)T0F5F;W)E*&QE9G0I.PH)"0ER,BYS=7)R;W5N9$-O;G1E
M;G1S*&)L;V-K(#T@9&]C+F-R96%T945L96UE;G0H(G`B*2D["@D)"6EF("@A
M+UQ3+RYT97-T*$A434Q!<F5A+F=E=$EN;F5R5&5X="AB;&]C:RDI*0H)"0D)
M8FQO8VLN:6YN97)(5$U,(#T@(CQB<B`O/B(["@D)"6)L;V-K+FYO<FUA;&EZ
M92@I.PH)"0ER+G-E=$5N9$%F=&5R*')I9VAT*3L*"0D)<BYS=7)R;W5N9$-O
M;G1E;G1S*&)L;V-K(#T@9&]C+F-R96%T945L96UE;G0H(G`B*2D["@D)"6EF
M("@A+UQ3+RYT97-T*$A434Q!<F5A+F=E=$EN;F5R5&5X="AB;&]C:RDI*0H)
M"0D)8FQO8VLN:6YN97)(5$U,(#T@(CQB<B`O/B(["@D)"6)L;V-K+FYO<FUA
M;&EZ92@I.PH)"7T@96QS92!["@D)"7(@/2!D;V,N8W)E871E4F%N9V4H*3L*
M"0D)<BYS9713=&%R="AB;V1Y+"`P*3L*"0D)<BYS971%;F0H8F]D>2P@,"D[
M"@D)"7(N:6YS97)T3F]D92AB;&]C:R`](&1O8RYC<F5A=&5%;&5M96YT*")P
M(BDI.PH)"0EB;&]C:RYI;FYE<DA434P@/2`B/&)R("\^(CL*"0E]"@D)<BYS
M96QE8W1.;V1E0V]N=&5N=',H8FQO8VLI.PH)?2!E;'-E('L*"0ER+G-E=$5N
M9$%F=&5R*&)L;V-K*3L*"0EV87(@9&8@/2!R+F5X=')A8W1#;VYT96YT<R@I
M+"!L969T7V5M<'1Y(#T@9F%L<V4["@D):68@*"$O7%,O+G1E<W0H8FQO8VLN
M:6YN97)(5$U,*2D@>PH)"0EB;&]C:RYI;FYE<DA434P@/2`B/&)R("\^(CL*
M"0D);&5F=%]E;7!T>2`]('1R=64["@D)?0H)"7`@/2!D9BYF:7)S=$-H:6QD
M.PH)"6EF("AP*2!["@D)"6EF("@A+UQ3+RYT97-T*$A434Q!<F5A+F=E=$EN
M;F5R5&5X="AP*2DI('L*(`D)"0EI9B`H+UYH6S$M-ETD+VDN=&5S="AP+G1A
M9TYA;64I*0H@"0D)"0EP(#T@=&AI<RYC;VYV97)T3F]D92AP+"`B<"(I.PH)
M"0D)<"YI;FYE<DA434P@/2`B/&)R("\^(CL*"0D)?0H)"0EI9B`H+UYL:20O
M:2YT97-T*'`N=&%G3F%M92D@)B8@;&5F=%]E;7!T>2`F)B`A8FQO8VLN;F5X
M=%-I8FQI;F<I('L*"0D)"6QE9G0@/2!B;&]C:RYP87)E;G1.;V1E.PH)"0D)
M;&5F="YR96UO=F5#:&EL9"AB;&]C:RD["@D)"0ER+G-E=$5N9$%F=&5R*&QE
M9G0I.PH)"0D)<BYC;VQL87!S92AF86QS92D["@D)"0EP(#T@=&AI<RYC;VYV
M97)T3F]D92AP+"`O7EMU;UUL)"]I+G1E<W0H;&5F="YP87)E;G1.;V1E+G1A
M9TYA;64I(#\@(FQI(B`Z(")P(BD["@D)"7T*"0D)<BYI;G-E<G1.;V1E*&1F
M*3L*"0D)<BYS96QE8W1.;V1E0V]N=&5N=',H<"D["@D)?0H)?0H)<BYC;VQL
M87!S92AT<G5E*3L*"7-E;"YA9&1286YG92AR*3L*"71H:7,N9F]R8V52961R
M87<H*3L*"71H:7,N<V-R;VQL5&]#87)E="@I.PI].PH*+R\@<F5T<FEE=F4@
M=&AE($A434P*2%1-3$%R96$N<')O=&]T>7!E+F=E=$A434P@/2!F=6YC=&EO
M;B@I('L*"7-W:71C:"`H=&AI<RY?961I=$UO9&4I('L*"2`@("!C87-E(")W
M>7-I=WEG(B`@.@H)"6EF("@A=&AI<RYC;VYF:6<N9G5L;%!A9V4I('L*"0D)
M<F5T=7)N($A434Q!<F5A+F=E=$A434PH=&AI<RY?9&]C+F)O9'DL(&9A;'-E
M+"!T:&ES*3L*"0E](&5L<V4*"0D)<F5T=7)N('1H:7,N9&]C='EP92`K(")<
M;B(@*R!(5$U,07)E82YG971(5$U,*'1H:7,N7V1O8RYD;V-U;65N=$5L96UE
M;G0L('1R=64L('1H:7,I.PH)("`@(&-A<V4@(G1E>'1M;V1E(B`Z(')E='5R
M;B!T:&ES+E]T97AT07)E82YV86QU93L*"2`@("!D969A=6QT"2`@("`Z(&%L
M97)T*")-;V1E(#PB("L@;6]D92`K("(^(&YO="!D969I;F5D(2(I.PH)?0H)
M<F5T=7)N(&9A;'-E.PI].PH*+R\@<F5T<FEE=F4@=&AE($A434P@*&9A<W1E
M<W0@=F5R<VEO;BP@8G5T('5S97,@:6YN97)(5$U,*0I(5$U,07)E82YP<F]T
M;W1Y<&4N9V5T26YN97)(5$U,(#T@9G5N8W1I;VXH*2!["@ES=VET8V@@*'1H
M:7,N7V5D:71-;V1E*2!["@D@("`@8V%S92`B=WES:7=Y9R(@(#H*"0EI9B`H
M(71H:7,N8V]N9FEG+F9U;&Q086=E*0H)"0ER971U<FX@=&AI<RY?9&]C+F)O
M9'DN:6YN97)(5$U,.PH)"65L<V4*"0D)<F5T=7)N('1H:7,N9&]C='EP92`K
M(")<;B(@*R!T:&ES+E]D;V,N9&]C=6UE;G1%;&5M96YT+FEN;F5R2%1-3#L*
M"2`@("!C87-E(")T97AT;6]D92(@.B!R971U<FX@=&AI<RY?=&5X=$%R96$N
M=F%L=64["@D@("`@9&5F875L=`D@("`@.B!A;&5R="@B36]D92`\(B`K(&UO
M9&4@*R`B/B!N;W0@9&5F:6YE9"$B*3L*"7T*"7)E='5R;B!F86QS93L*?3L*
M"B\O(&-O;7!L971E;'D@8VAA;F=E('1H92!(5$U,(&EN<VED90I(5$U,07)E
M82YP<F]T;W1Y<&4N<V5T2%1-3"`](&9U;F-T:6]N*&AT;6PI('L*"7-W:71C
M:"`H=&AI<RY?961I=$UO9&4I('L*"2`@("!C87-E(")W>7-I=WEG(B`@.@H)
M"6EF("@A=&AI<RYC;VYF:6<N9G5L;%!A9V4I"@D)"71H:7,N7V1O8RYB;V1Y
M+FEN;F5R2%1-3"`](&AT;6P["@D)96QS90H)"0DO+R!T:&ES+E]D;V,N9&]C
M=6UE;G1%;&5M96YT+FEN;F5R2%1-3"`](&AT;6P["@D)"71H:7,N7V1O8RYB
M;V1Y+FEN;F5R2%1-3"`](&AT;6P["@D)8G)E86L["@D@("`@8V%S92`B=&5X
M=&UO9&4B(#H@=&AI<RY?=&5X=$%R96$N=F%L=64@/2!H=&UL.R!B<F5A:SL*
M"2`@("!D969A=6QT"2`@("`Z(&%L97)T*")-;V1E(#PB("L@;6]D92`K("(^
M(&YO="!D969I;F5D(2(I.PH)?0H)<F5T=7)N(&9A;'-E.PI].PH*+R\@<V5T
M<R!T:&4@9VEV96X@9&]C='EP92`H=7-E9G5L('=H96X@8V]N9FEG+F9U;&Q0
M86=E(&ES('1R=64I"DA434Q!<F5A+G!R;W1O='EP92YS971$;V-T>7!E(#T@
M9G5N8W1I;VXH9&]C='EP92D@>PH)=&AI<RYD;V-T>7!E(#T@9&]C='EP93L*
M?3L*"B\J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BH*("H@($-A=&5G;W)Y.B!55$E,2519($953D-424].4PH@
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ+PH*+R\@=F%R:6%B;&4@=7-E9"!T;R!P87-S('1H92!O8FIE8W0@
M=&\@=&AE('!O<'5P(&5D:71O<B!W:6YD;W<N"DA434Q!<F5A+E]O8FIE8W0@
M/2!N=6QL.PH*+R\@9G5N8W1I;VX@=&AA="!R971U<FYS(&$@8VQO;F4@;V8@
M=&AE(&=I=F5N(&]B:F5C=`I(5$U,07)E82YC;&]N94]B:F5C="`](&9U;F-T
M:6]N*&]B:BD@>PH):68@*"%O8FHI(')E='5R;B!N=6QL.PH)=F%R(&YE=T]B
M:B`](&YE=R!/8FIE8W0["@H)+R\@8VAE8VL@9F]R(&%R<F%Y(&]B:F5C=',*
M"6EF("AO8FHN8V]N<W1R=6-T;W(N=&]3=')I;F<H*2YI;F1E>$]F*")F=6YC
M=&EO;B!!<G)A>2@B*2`]/2`Q*2!["@D);F5W3V)J(#T@;V)J+F-O;G-T<G5C
M=&]R*"D["@E]"@H)+R\@8VAE8VL@9F]R(&9U;F-T:6]N(&]B:F5C=',@*&%S
M('5S=6%L+"!)12!I<R!F=6-K960@=7`I"@EI9B`H;V)J+F-O;G-T<G5C=&]R
M+G1O4W1R:6YG*"DN:6YD97A/9B@B9G5N8W1I;VX@1G5N8W1I;VXH(BD@/3T@
M,2D@>PH)"6YE=T]B:B`](&]B:CL@+R\@:G5S="!C;W!Y(')E9F5R96YC92!T
M;R!I=`H)?2!E;'-E(&9O<B`H=F%R(&X@:6X@;V)J*2!["@D)=F%R(&YO9&4@
M/2!O8FI;;ET["@D):68@*'1Y<&5O9B!N;V1E(#T]("=O8FIE8W0G*2![(&YE
M=T]B:EMN72`]($A434Q!<F5A+F-L;VYE3V)J96-T*&YO9&4I.R!]"@D)96QS
M92`@("`@("`@("`@("`@("`@("`@("`@("![(&YE=T]B:EMN72`](&YO9&4[
M('T*"7T*"@ER971U<FX@;F5W3V)J.PI].PH*+R\@1DE8344A(2$@=&AI<R!S
M:&]U;&0@<F5T=7)N(&9A;'-E(&9O<B!)12`\(#4N-0I(5$U,07)E82YC:&5C
M:U-U<'!O<G1E9$)R;W=S97(@/2!F=6YC=&EO;B@I('L*"6EF("A(5$U,07)E
M82YI<U]G96-K;RD@>PH)"6EF("AN879I9V%T;W(N<')O9'5C=%-U8B`\(#(P
M,#(Q,C`Q*2!["@D)"6%L97)T*")9;W4@;F5E9"!A="!L96%S="!-;WII;&QA
M+3$N,R!!;'!H82Y<;B(@*PH)"0D@("`@("`B4V]R<GDL('EO=7(@1V5C:V\@
M:7,@;F]T('-U<'!O<G1E9"XB*3L*"0D)<F5T=7)N(&9A;'-E.PH)"7T*"0EI
M9B`H;F%V:6=A=&]R+G!R;V1U8W13=6(@/"`R,#`S,#(Q,"D@>PH)"0EA;&5R
M="@B36]Z:6QL82`\(#$N,R!"971A(&ES(&YO="!S=7!P;W)T960A7&XB("L*
M"0D)("`@("`@(DDG;&P@=')Y+"!T:&]U9V@L(&)U="!I="!M:6=H="!N;W0@
M=V]R:RXB*3L*"0E]"@E]"@ER971U<FX@2%1-3$%R96$N:7-?9V5C:V\@?'P@
M2%1-3$%R96$N:7-?:64["GT["@HO+R!S96QE8W1I;VX@)B!R86YG97,*"B\O
M(')E='5R;G,@=&AE(&-U<G)E;G0@<V5L96-T:6]N(&]B:F5C=`I(5$U,07)E
M82YP<F]T;W1Y<&4N7V=E=%-E;&5C=&EO;B`](&9U;F-T:6]N*"D@>PH):68@
M*$A434Q!<F5A+FES7VEE*2!["@D)<F5T=7)N('1H:7,N7V1O8RYS96QE8W1I
M;VX["@E](&5L<V4@>PH)"7)E='5R;B!T:&ES+E]I9G)A;64N8V]N=&5N=%=I
M;F1O=RYG971396QE8W1I;VXH*3L*"7T*?3L*"B\O(')E='5R;G,@82!R86YG
M92!F;W(@=&AE(&-U<G)E;G0@<V5L96-T:6]N"DA434Q!<F5A+G!R;W1O='EP
M92Y?8W)E871E4F%N9V4@/2!F=6YC=&EO;BAS96PI('L*"6EF("A(5$U,07)E
M82YI<U]I92D@>PH)"7)E='5R;B!S96PN8W)E871E4F%N9V4H*3L*"7T@96QS
M92!["@D)=&AI<RYF;V-U<T5D:71O<B@I.PH)"6EF("AT>7!E;V8@<V5L("$]
M(")U;F1E9FEN960B*2!["@D)"71R>2!["@D)"0ER971U<FX@<V5L+F=E=%)A
M;F=E070H,"D["@D)"7T@8V%T8V@H92D@>PH)"0D)<F5T=7)N('1H:7,N7V1O
M8RYC<F5A=&5286YG92@I.PH)"0E]"@D)?2!E;'-E('L*"0D)<F5T=7)N('1H
M:7,N7V1O8RYC<F5A=&5286YG92@I.PH)"7T*"7T*?3L*"B\O(&5V96YT(&AA
M;F1L:6YG"@I(5$U,07)E82Y?861D179E;G0@/2!F=6YC=&EO;BAE;"P@979N
M86UE+"!F=6YC*2!["@EI9B`H2%1-3$%R96$N:7-?:64I('L*"0EE;"YA='1A
M8VA%=F5N="@B;VXB("L@979N86UE+"!F=6YC*3L*"7T@96QS92!["@D)96PN
M861D179E;G1,:7-T96YE<BAE=FYA;64L(&9U;F,L('1R=64I.PH)?0I].PH*
M2%1-3$%R96$N7V%D9$5V96YT<R`](&9U;F-T:6]N*&5L+"!E=G,L(&9U;F,I
M('L*"69O<B`H=F%R(&D@/2!E=G,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0E(
M5$U,07)E82Y?861D179E;G0H96PL(&5V<UMI72P@9G5N8RD["@E]"GT["@I(
M5$U,07)E82Y?<F5M;W9E179E;G0@/2!F=6YC=&EO;BAE;"P@979N86UE+"!F
M=6YC*2!["@EI9B`H2%1-3$%R96$N:7-?:64I('L*"0EE;"YD971A8VA%=F5N
M="@B;VXB("L@979N86UE+"!F=6YC*3L*"7T@96QS92!["@D)96PN<F5M;W9E
M179E;G1,:7-T96YE<BAE=FYA;64L(&9U;F,L('1R=64I.PH)?0I].PH*2%1-
M3$%R96$N7W)E;6]V945V96YT<R`](&9U;F-T:6]N*&5L+"!E=G,L(&9U;F,I
M('L*"69O<B`H=F%R(&D@/2!E=G,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0E(
M5$U,07)E82Y?<F5M;W9E179E;G0H96PL(&5V<UMI72P@9G5N8RD["@E]"GT[
M"@I(5$U,07)E82Y?<W1O<$5V96YT(#T@9G5N8W1I;VXH978I('L*"6EF("A(
M5$U,07)E82YI<U]I92D@>PH)"65V+F-A;F-E;$)U8F)L92`]('1R=64["@D)
M978N<F5T=7)N5F%L=64@/2!F86QS93L*"7T@96QS92!["@D)978N<')E=F5N
M=$1E9F%U;'0H*3L*"0EE=BYS=&]P4')O<&%G871I;VXH*3L*"7T*?3L*"DA4
M34Q!<F5A+E]R96UO=F5#;&%S<R`](&9U;F-T:6]N*&5L+"!C;&%S<TYA;64I
M('L*"6EF("@A*&5L("8F(&5L+F-L87-S3F%M92DI('L*"0ER971U<FX["@E]
M"@EV87(@8VQS(#T@96PN8VQA<W-.86UE+G-P;&ET*"(@(BD["@EV87(@87(@
M/2!N97<@07)R87DH*3L*"69O<B`H=F%R(&D@/2!C;',N;&5N9W1H.R!I(#X@
M,#LI('L*"0EI9B`H8VQS6RTM:5T@(3T@8VQA<W-.86UE*2!["@D)"6%R6V%R
M+FQE;F=T:%T@/2!C;'-;:5T["@D)?0H)?0H)96PN8VQA<W-.86UE(#T@87(N
M:F]I;B@B("(I.PI].PH*2%1-3$%R96$N7V%D9$-L87-S(#T@9G5N8W1I;VXH
M96PL(&-L87-S3F%M92D@>PH)+R\@<F5M;W9E('1H92!C;&%S<R!F:7)S="P@
M:68@86QR96%D>2!T:&5R90H)2%1-3$%R96$N7W)E;6]V94-L87-S*&5L+"!C
M;&%S<TYA;64I.PH)96PN8VQA<W-.86UE("L]("(@(B`K(&-L87-S3F%M93L*
M?3L*"DA434Q!<F5A+E]H87-#;&%S<R`](&9U;F-T:6]N*&5L+"!C;&%S<TYA
M;64I('L*"6EF("@A*&5L("8F(&5L+F-L87-S3F%M92DI('L*"0ER971U<FX@
M9F%L<V4["@E]"@EV87(@8VQS(#T@96PN8VQA<W-.86UE+G-P;&ET*"(@(BD[
M"@EF;W(@*'9A<B!I(#T@8VQS+FQE;F=T:#L@:2`^(#`[*2!["@D):68@*&-L
M<ULM+6E=(#T](&-L87-S3F%M92D@>PH)"0ER971U<FX@=')U93L*"0E]"@E]
M"@ER971U<FX@9F%L<V4["GT["@I(5$U,07)E82Y?8FQO8VM486=S(#T@(B!B
M;V1Y(&9O<FT@=&5X=&%R96$@9FEE;&1S970@=6P@;VP@9&P@;&D@9&EV("(@
M*PHB<"!H,2!H,B!H,R!H-"!H-2!H-B!Q=6]T92!P<F4@=&%B;&4@=&AE860@
M(B`K"B)T8F]D>2!T9F]O="!T<B!T9"!I9G)A;64@861D<F5S<R`B.PI(5$U,
M07)E82YI<T)L;V-K16QE;65N="`](&9U;F-T:6]N*&5L*2!["@ER971U<FX@
M96P@)B8@96PN;F]D951Y<&4@/3T@,2`F)B`H2%1-3$%R96$N7V)L;V-K5&%G
M<RYI;F1E>$]F*"(@(B`K(&5L+G1A9TYA;64N=&],;W=E<D-A<V4H*2`K("(@
M(BD@(3T@+3$I.PI].PH*2%1-3$%R96$N7V-L;W-I;F=486=S(#T@(B!H96%D
M('-C<FEP="!S='EL92!D:78@<W!A;B!T<B!T9"!T8F]D>2!T86)L92!E;2!S
M=')O;F<@8B!I(&-O9&4@8VET92!D9FX@86)B<B!A8W)O;GEM(&9O;G0@82!T
M:71L92`B.PI(5$U,07)E82YN965D<T-L;W-I;F=486<@/2!F=6YC=&EO;BAE
M;"D@>PH)<F5T=7)N(&5L("8F(&5L+FYO9&54>7!E(#T](#$@)B8@*$A434Q!
M<F5A+E]C;&]S:6YG5&%G<RYI;F1E>$]F*"(@(B`K(&5L+G1A9TYA;64N=&],
M;W=E<D-A<V4H*2`K("(@(BD@(3T@+3$I.PI].PH*+R\@<&5R9F]R;7,@2%1-
M3"!E;F-O9&EN9R!O9B!S;VUE(&=I=F5N('-T<FEN9PI(5$U,07)E82YH=&UL
M16YC;V1E(#T@9G5N8W1I;VXH<W1R*2!["@DO+R!W92!D;VXG="!N965D(')E
M9V5X<"!F;W(@=&AA="P@8G5T+BX@<V\@8F4@:70@9F]R(&YO=RX*"7-T<B`]
M('-T<BYR97!L86-E*"\F+VEG+"`B)F%M<#LB*3L*"7-T<B`]('-T<BYR97!L
M86-E*"\\+VEG+"`B)FQT.R(I.PH)<W1R(#T@<W1R+G)E<&QA8V4H+SXO:6<L
M("(F9W0[(BD["@ES='(@/2!S='(N<F5P;&%C92@O7'@R,B]I9RP@(B9Q=6]T
M.R(I.PH)+R\@7'@R,B!M96%N<R`G(B<@+2T@=V4@=7-E(&AE>"!R97!R97IE
M;G1A=&EO;B!S;R!T:&%T('=E(&1O;B=T(&1I<W1U<F(*"2\O($I3(&-O;7!R
M97-S;W)S("AW96QL+"!A="!L96%S="!M:6YE(&9A:6QS+BX@.RD*"7)E='5R
M;B!S='(["GT["@HO+R!2971R:65V97,@=&AE($A434P@8V]D92!F<F]M('1H
M92!G:79E;B!N;V1E+@D@5&AI<R!I<R!A(')E<&QA8V5M96YT(&9O<@HO+R!G
M971T:6YG(&EN;F5R2%1-3"P@=7-I;F<@<W1A;F1A<F0@1$]-(&-A;&QS+@HO
M+R!7<F%P<&5R(&-A=&-H(&$@36]Z:6QL82U%>&-E<'1I;VX@=VET:"!N;VX@
M=V5L;"!F;W)M960@:'1M;"!S;W5R8V4@8V]D90I(5$U,07)E82YG971(5$U,
M(#T@9G5N8W1I;VXH<F]O="P@;W5T<'5T4F]O="P@961I=&]R*7L*("`@('1R
M>7L*("`@("`@("!R971U<FX@2%1-3$%R96$N9V5T2%1-3%=R87!P97(H<F]O
M="QO=71P=712;V]T+&5D:71O<BD["B`@("!]"B`@("!C871C:"AE*7L*("`@
M("`@("!A;&5R="@G66]U<B!$;V-U;65N="!I<R!N;W0@=V5L;"!F;W)M960N
M($-H96-K($IA=F%38W)I<'0@8V]N<V]L92!F;W(@9&5T86EL<RXG*3L*("`@
M("`@("!R971U<FX@961I=&]R+E]I9G)A;64N8V]N=&5N=%=I;F1O=RYD;V-U
M;65N="YB;V1Y+FEN;F5R2%1-3#L*("`@('T*?0H*2%1-3$%R96$N9V5T2%1-
M3%=R87!P97(@/2!F=6YC=&EO;BAR;V]T+"!O=71P=712;V]T+"!E9&ET;W(I
M('L*"79A<B!H=&UL(#T@(B(["@ES=VET8V@@*')O;W0N;F]D951Y<&4I('L*
M"2`@("!C87-E(#$Z("\O($YO9&4N14Q%345.5%].3T1%"@D@("`@8V%S92`Q
M,3H@+R\@3F]D92Y$3T-5345.5%]&4D%'345.5%].3T1%"@D)=F%R(&-L;W-E
M9#L*"0EV87(@:3L*"0EV87(@<F]O=%]T86<@/2`H<F]O="YN;V1E5'EP92`]
M/2`Q*2`_(')O;W0N=&%G3F%M92YT;TQO=V5R0V%S92@I(#H@)R<["@D):68@
M*')O;W1?=&%G(#T]("=B<B<@)B8@(7)O;W0N;F5X=%-I8FQI;F<I"@D)"6)R
M96%K.PH)"6EF("AO=71P=712;V]T*0H)"0EO=71P=712;V]T(#T@(2AE9&ET
M;W(N8V]N9FEG+FAT;6Q296UO=F5486=S("8F(&5D:71O<BYC;VYF:6<N:'1M
M;%)E;6]V951A9W,N=&5S="AR;V]T7W1A9RDI.PH)"6EF("A(5$U,07)E82YI
M<U]I92`F)B!R;V]T7W1A9R`]/2`B:&5A9"(I('L*"0D):68@*&]U='!U=%)O
M;W0I"@D)"0EH=&UL("L]("(\:&5A9#XB.PH)"0DO+R!L;W=E<F-A<VEZ90H)
M"0EV87(@<V%V95]M=6QT:6QI;F4@/2!296=%>'`N;75L=&EL:6YE.PH)"0E2
M96=%>'`N;75L=&EL:6YE(#T@=')U93L*"0D)=F%R('1X="`](')O;W0N:6YN
M97)(5$U,+G)E<&QA8V4H2%1-3$%R96$N4D5?=&%G3F%M92P@9G5N8W1I;VXH
M<W1R+"!P,2P@<#(I('L*"0D)"7)E='5R;B!P,2`K('`R+G1O3&]W97)#87-E
M*"D["@D)"7TI.PH)"0E296=%>'`N;75L=&EL:6YE(#T@<V%V95]M=6QT:6QI
M;F4["@D)"6AT;6P@*ST@='AT.PH)"0EI9B`H;W5T<'5T4F]O="D*"0D)"6AT
M;6P@*ST@(CPO:&5A9#XB.PH)"0EB<F5A:SL*"0E](&5L<V4@:68@*&]U='!U
M=%)O;W0I('L*"0D)8VQO<V5D(#T@*"$H<F]O="YH87-#:&EL9$YO9&5S*"D@
M?'P@2%1-3$%R96$N;F5E9'-#;&]S:6YG5&%G*')O;W0I*2D["@D)"6AT;6P@
M/2`B/"(@*R!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H*3L*"0D)=F%R(&%T
M=')S(#T@<F]O="YA='1R:6)U=&5S.PH)"0EF;W(@*&D@/2`P.R!I(#P@871T
M<G,N;&5N9W1H.R`K*VDI('L*"0D)"79A<B!A(#T@871T<G,N:71E;2AI*3L*
M"0D)"6EF("@A82YS<&5C:69I960I('L*"0D)"0EC;VYT:6YU93L*"0D)"7T*
M"0D)"79A<B!N86UE(#T@82YN;V1E3F%M92YT;TQO=V5R0V%S92@I.PH)"0D)
M:68@*"]?;6]Z7V5D:71O<E]B;V=U<U]N;V1E+RYT97-T*&YA;64I*2!["@D)
M"0D):'1M;"`]("(B.PH)"0D)"6)R96%K.PH)"0D)?0H)"0D):68@*"]?;6]Z
M?&-O;G1E;G1E9&ET86)L97Q?;7-H+RYT97-T*&YA;64I*2!["@D)"0D)+R\@
M879O:60@8V5R=&%I;B!A='1R:6)U=&5S"@D)"0D)8V]N=&EN=64["@D)"0E]
M"@D)"0EV87(@=F%L=64["@D)"0EI9B`H;F%M92`A/2`B<W1Y;&4B*2!["@D)
M"0D)+R\@244U+C4@<F5P;W)T<R`R-2!W:&5N(&-E;&Q3<&%C:6YG(&ES"@D)
M"0D)+R\@,3L@;W1H97(@=F%L=65S(&UI9VAT(&)E(&1O;VUE9"!T;V\N"@D)
M"0D)+R\@1F]R('1H:7,@<F5A<V]N('=E(&5X=')A8W0@=&AE"@D)"0D)+R\@
M=F%L=65S(&1I<F5C=&QY(&9R;VT@=&AE(')O;W0@;F]D92X*"0D)"0DO+R!)
M)VT@<W1A<G1I;F<@=&\@2$%412!*879A4V-R:7!T"@D)"0D)+R\@9&5V96QO
M<&UE;G0N("!"<F]W<V5R(&1I9F9E<F5N8V5S"@D)"0D)+R\@<W5C:RX*"0D)
M"0DO+PH)"0D)"2\O(%5S:6YG($=E8VMO('1H92!V86QU97,@;V8@:')E9B!A
M;F0@<W)C(&%R92!C;VYV97)T960@=&\@86)S;VQU=&4@;&EN:W,*"0D)"0DO
M+R!U;FQE<W,@=V4@9V5T('1H96T@=7-I;F<@;F]D959A;'5E*"D*"0D)"0EI
M9B`H='EP96]F(')O;W1;82YN;V1E3F%M95T@(3T@(G5N9&5F:6YE9"(@)B8@
M;F%M92`A/2`B:')E9B(@)B8@;F%M92`A/2`B<W)C(B`F)B`A+UYO;B\N=&5S
M="AN86UE*2D@>PH)"0D)"0EV86QU92`](')O;W1;82YN;V1E3F%M95T["@D)
M"0D)?2!E;'-E('L*"0D)"0D)=F%L=64@/2!A+FYO9&5686QU93L*"0D)"0D)
M+R\@244@<V5E;7,@;F]T('=I;&QI;F<@=&\@<F5T=7)N('1H92!O<FEG:6YA
M;"!V86QU97,@+2!I="!C;VYV97)T<R!T;R!A8G-O;'5T90H)"0D)"0DO+R!L
M:6YK<R!U<VEN9R!A+FYO9&5686QU92P@82YV86QU92P@82YS=')I;F=686QU
M92P@<F]O="YG971!='1R:6)U=&4H(FAR968B*0H)"0D)"0DO+R!3;R!W92!H
M879E('1O('-T<FEP('1H92!B87-E=7)L(&UA;G5A;&QY(#HM+PH)"0D)"0EI
M9B`H2%1-3$%R96$N:7-?:64@)B8@*&YA;64@/3T@(FAR968B('Q\(&YA;64@
M/3T@(G-R8R(I*2!["@D)"0D)"0EV86QU92`](&5D:71O<BYS=')I<$)A<V55
M4DPH=F%L=64I.PH)"0D)"0E]"@D)"0D)?0H)"0D)?2!E;'-E('L@+R\@244@
M9F%I;',@=&\@<'5T('-T>6QE(&EN(&%T=')I8G5T97,@;&ES=`H)"0D)"2\O
M($9)6$U%.B!C<W-497AT(')E<&]R=&5D(&)Y($E%(&ES(%504$520T%310H)
M"0D)"79A;'5E(#T@<F]O="YS='EL92YC<W-497AT.PH)"0D)?0H)"0D):68@
M*"\H7VUO>GQ>)"DO+G1E<W0H=F%L=64I*2!["@D)"0D)+R\@36]Z:6QL82!R
M97!O<G1S('-O;64@<W!E8VEA;"!T86=S"@D)"0D)+R\@:&5R93L@=V4@9&]N
M)W0@;F5E9"!T:&5M+@H)"0D)"6-O;G1I;G5E.PH)"0D)?0H)"0D):'1M;"`K
M/2`B("(@*R!N86UE("L@)STB)R`K('9A;'5E("L@)R(G.PH)"0E]"@D)"6EF
M("AH=&UL("$]("(B*2!["@D)"0EH=&UL("L](&-L;W-E9"`_("(@+SXB(#H@
M(CXB.PH)"0E]"@D)?0H)"69O<B`H:2`](')O;W0N9FER<W1#:&EL9#L@:3L@
M:2`](&DN;F5X=%-I8FQI;F<I('L*"0D):'1M;"`K/2!(5$U,07)E82YG971(
M5$U,5W)A<'!E<BAI+"!T<G5E+"!E9&ET;W(I.PH)"7T*"0EI9B`H;W5T<'5T
M4F]O="`F)B`A8VQO<V5D*2!["@D)"6AT;6P@*ST@(CPO(B`K(')O;W0N=&%G
M3F%M92YT;TQO=V5R0V%S92@I("L@(CXB.PH)"7T*"0EB<F5A:SL*"2`@("!C
M87-E(#,Z("\O($YO9&4N5$585%].3T1%"@D)+R\@268@82!T97AT(&YO9&4@
M:7,@86QO;F4@:6X@86X@96QE;65N="!A;F0@86QL('-P86-E<RP@<F5P;&%C
M92!I="!W:71H(&%N(&YO;B!B<F5A:VEN9R!O;F4*"0DO+R!4:&ES('!A<G1I
M86QL>2!U;F1O97,@=&AE(&1A;6%G92!D;VYE(&)Y(&UO>BP@=VAI8V@@=')A
M;G-L871E<R`G)FYB<W`[)W,@:6YT;R!S<&%C97,@:6X@=&AE(&1A=&$@96QE
M;65N=`H)"2\J(&EF("@@(7)O;W0N<')E=FEO=7-3:6)L:6YG("8F("%R;V]T
M+FYE>'13:6)L:6YG("8F(')O;W0N9&%T82YM871C:"@O7EQS*B0O:2D@*2!H
M=&UL(#T@)R9N8G-P.R<["@D)("`@96QS92`J+PH)"6AT;6P@/2`O7G-C<FEP
M='QS='EL920O:2YT97-T*')O;W0N<&%R96YT3F]D92YT86=.86UE*2`_(')O
M;W0N9&%T82`Z($A434Q!<F5A+FAT;6Q%;F-O9&4H<F]O="YD871A*3L*"0EB
M<F5A:SL*"2`@("!C87-E(#0Z("\O($YO9&4N0T1!5$%?4T5#5$E/3E].3T1%
M"@D)+R\@1DE8344Z(&ET('-E96US('=E(&YE=F5R(&=E="!H97)E+"!B=70@
M22!B96QI979E('=E('-H;W5L9"XN"@D)+R\@("`@("`@(&UA>6)E(&$@8G)O
M=W-E<B!P<F]B;&5M/RTM0T1!5$$@<V5C=&EO;G,@87)E(&-O;G9E<G1E9"!T
M;R!P;&%I;B!T97AT(&YO9&5S(&%N9"!N;W)M86QI>F5D"@D)+R\@0T1!5$$@
M<V5C=&EO;G,@<VAO=6QD(&=O(")A<R!I<R(@=VET:&]U="!F=7)T:&5R(&5N
M8V]D:6YG"@D):'1M;"`]("(\(5M#1$%405LB("L@<F]O="YD871A("L@(EU=
M/B(["@D)8G)E86L["@D@("`@8V%S92`X.B`O+R!.;V1E+D-/34U%3E1?3D]$
M10H)"6AT;6P@/2`B/"$M+2(@*R!R;V]T+F1A=&$@*R`B+2T^(CL*"0EB<F5A
M:SL)"2\O('-K:7`@8V]M;65N=',L(&9O<B!N;W<N"@E]"@ER971U<FX@:'1M
M;#L*?3L*"DA434Q!<F5A+F=E=%!R979.;V1E(#T@9G5N8W1I;VXH;F]D92D@
M>PH):68@*"%N;V1E*2`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*"6EF
M("AN;V1E+G!R979I;W5S4VEB;&EN9RD@<F5T=7)N(&YO9&4N<')E=FEO=7-3
M:6)L:6YG.PH):68@*&YO9&4N<&%R96YT3F]D92D@("`@("!R971U<FX@;F]D
M92YP87)E;G1.;V1E.PH)<F5T=7)N(&YU;&P["GT["@I(5$U,07)E82YG971.
M97AT3F]D92`](&9U;F-T:6]N*&YO9&4I('L*"6EF("@A;F]D92D@("`@("`@
M("`@("!R971U<FX@;G5L;#L*"6EF("AN;V1E+FYE>'13:6)L:6YG*2!R971U
M<FX@;F]D92YN97AT4VEB;&EN9SL*"6EF("AN;V1E+G!A<F5N=$YO9&4I("!R
M971U<FX@;F]D92YP87)E;G1.;V1E.PH)<F5T=7)N(&YU;&P["GT["@I(5$U,
M07)E82YP<F]T;W1Y<&4N<W1R:7!"87-E55),(#T@9G5N8W1I;VXH<W1R:6YG
M*2!["@EV87(@8F%S975R;"`]('1H:7,N8V]N9FEG+F)A<V554DP["@H)+R\@
M<W1R:7`@=&\@;&%S="!D:7)E8W1O<GD@:6X@8V%S92!B87-E=7)L('!O:6YT
M<R!T;R!A(&9I;&4*"6)A<V5U<FP@/2!B87-E=7)L+G)E<&QA8V4H+UM>7"]=
M*R0O+"`G)RD["@EV87(@8F%S97)E(#T@;F5W(%)E9T5X<"AB87-E=7)L*3L*
M"7-T<FEN9R`]('-T<FEN9RYR97!L86-E*&)A<V5R92P@(B(I.PH*"2\O('-T
M<FEP(&AO<W0M<&%R="!O9B!54DP@=VAI8V@@:7,@861D960@8GD@35-)12!T
M;R!L:6YK<R!R96QA=&EV92!T;R!S97)V97(@<F]O=`H)8F%S975R;"`](&)A
M<V5U<FPN<F5P;&%C92@O7BAH='1P<S\Z7"]<+UM>7"]=*RDH+BHI)"\L("<D
M,2<I.PH)8F%S97)E(#T@;F5W(%)E9T5X<"AB87-E=7)L*3L*"7)E='5R;B!S
M=')I;F<N<F5P;&%C92AB87-E<F4L("(B*3L*?3L*"E-T<FEN9RYP<F]T;W1Y
M<&4N=')I;2`](&9U;F-T:6]N*"D@>PH)<F5T=7)N('1H:7,N<F5P;&%C92@O
M7EQS*R\L("<G*2YR97!L86-E*"]<<RLD+RP@)R<I.PI].PH*+R\@8W)E871E
M<R!A(')G8BUS='EL92!C;VQO<B!F<F]M(&$@;G5M8F5R"DA434Q!<F5A+E]M
M86ME0V]L;W(@/2!F=6YC=&EO;BAV*2!["@EI9B`H='EP96]F('8@(3T@(FYU
M;6)E<B(I('L*"0DO+R!A;')E861Y(&EN(')G8B`H:&]P969U;&QY*3L@244@
M9&]E<VXG="!G970@:&5R92X*"0ER971U<FX@=CL*"7T*"2\O($E%('-E;F1S
M(&YU;6)E<CL@8V]N=F5R="!T;R!R9V(N"@EV87(@<B`]('8@)B`P>$9&.PH)
M=F%R(&<@/2`H=B`^/B`X*2`F(#!X1D8["@EV87(@8B`]("AV(#X^(#$V*2`F
M(#!X1D8["@ER971U<FX@(G)G8B@B("L@<B`K("(L(B`K(&<@*R`B+"(@*R!B
M("L@(BDB.PI].PH*+R\@<F5T=7)N<R!H97AA9&5C:6UA;"!C;VQO<B!R97!R
M97-E;G1A=&EO;B!F<F]M(&$@;G5M8F5R(&]R(&$@<F=B+7-T>6QE(&-O;&]R
M+@I(5$U,07)E82Y?8V]L;W)4;U)G8B`](&9U;F-T:6]N*'8I('L*"6EF("@A
M=BD*"0ER971U<FX@)R<["@H)+R\@<F5T=7)N<R!T:&4@:&5X(')E<')E<V5N
M=&%T:6]N(&]F(&]N92!B>71E("@R(&1I9VET<RD*"69U;F-T:6]N(&AE>"AD
M*2!["@D)<F5T=7)N("AD(#P@,38I(#\@*"(P(B`K(&0N=&]3=')I;F<H,38I
M*2`Z(&0N=&]3=')I;F<H,38I.PH)?3L*"@EI9B`H='EP96]F('8@/3T@(FYU
M;6)E<B(I('L*"0DO+R!W92=R92!T86QK:6YG('1O($E%(&AE<F4*"0EV87(@
M<B`]('8@)B`P>$9&.PH)"79A<B!G(#T@*'8@/CX@."D@)B`P>$9&.PH)"79A
M<B!B(#T@*'8@/CX@,38I("8@,'A&1CL*"0ER971U<FX@(B,B("L@:&5X*'(I
M("L@:&5X*&<I("L@:&5X*&(I.PH)?0H*"6EF("AV+G-U8G-T<B@P+"`S*2`]
M/2`B<F=B(BD@>PH)"2\O(&EN(')G8B@N+BXI(&9O<FT@+2T@36]Z:6QL80H)
M"79A<B!R92`]("]R9V)<<RI<*%QS*BA;,"TY72LI7',J+%QS*BA;,"TY72LI
M7',J+%QS*BA;,"TY72LI7',J7"DO.PH)"6EF("AV+FUA=&-H*')E*2D@>PH)
M"0EV87(@<B`]('!A<G-E26YT*%)E9T5X<"XD,2D["@D)"79A<B!G(#T@<&%R
M<V5);G0H4F5G17AP+B0R*3L*"0D)=F%R(&(@/2!P87)S94EN="A296=%>'`N
M)#,I.PH)"0ER971U<FX@(B,B("L@:&5X*'(I("L@:&5X*&<I("L@:&5X*&(I
M.PH)"7T*"0DO+R!D;V5S;B=T(&UA=&-H(%)%/R$@(&UA>6)E('5S97,@<&5R
M8V5N=&%G97,@;W(@9FQO870@;G5M8F5R<PH)"2\O("TM($9)6$U%.B!N;W0@
M>65T(&EM<&QE;65N=&5D+@H)"7)E='5R;B!N=6QL.PH)?0H*"6EF("AV+G-U
M8G-T<B@P+"`Q*2`]/2`B(R(I('L*"0DO+R!A;')E861Y(&AE>"!R9V(@*&AO
M<&5F=6QL>2`Z1"`I"@D)<F5T=7)N('8["@E]"@H)+R\@:68@979E<GET:&EN
M9R!E;'-E(&9A:6QS(#LI"@ER971U<FX@;G5L;#L*?3L*"B\O(&UO9&%L(&1I
M86QO9W,@9F]R($UO>FEL;&$@*&9O<B!)12!W92=R92!U<VEN9R!T:&4@<VAO
M=TUO9&%L1&EA;&]G*"D@8V%L;"DN"@HO+R!R96-E:79E<R!A;B!54DP@=&\@
M=&AE('!O<'5P(&1I86QO9R!A;F0@82!F=6YC=&EO;B!T:&%T(')E8V5I=F5S
M(&]N92!V86QU93L*+R\@=&AI<R!F=6YC=&EO;B!W:6QL(&=E="!C86QL960@
M869T97(@=&AE(&1I86QO9R!I<R!C;&]S960L('=I=&@@=&AE(')E='5R;@HO
M+R!V86QU92!O9B!T:&4@9&EA;&]G+@I(5$U,07)E82YP<F]T;W1Y<&4N7W!O
M<'5P1&EA;&]G(#T@9G5N8W1I;VXH=7)L+"!A8W1I;VXL(&EN:70I('L*"41I
M86QO9RAT:&ES+G!O<'5P55),*'5R;"DL(&%C=&EO;BP@:6YI="D["GT["@HO
M+R!P871H<PH*2%1-3$%R96$N<')O=&]T>7!E+FEM9U523"`](&9U;F-T:6]N
M*&9I;&4L('!L=6=I;BD@>PH):68@*'1Y<&5O9B!P;'5G:6X@/3T@(G5N9&5F
M:6YE9"(I"@D)<F5T=7)N(%]E9&ET;W)?=7)L("L@9FEL93L*"65L<V4*"0ER
M971U<FX@7V5D:71O<E]U<FP@*R`B<&QU9VEN<R\B("L@<&QU9VEN("L@(B]I
M;6<O(B`K(&9I;&4["GT["@I(5$U,07)E82YP<F]T;W1Y<&4N<&]P=7!54DP@
M/2!F=6YC=&EO;BAF:6QE*2!["@EV87(@=7)L(#T@(B(["@EI9B`H9FEL92YM
M871C:"@O7G!L=6=I;CI<+UPO*"XJ/RE<+R@N*BDO*2D@>PH)"79A<B!P;'5G
M:6X@/2!296=%>'`N)#$["@D)=F%R('!O<'5P(#T@4F5G17AP+B0R.PH)"6EF
M("@A+UPN:'1M;"0O+G1E<W0H<&]P=7`I*0H)"0EP;W!U<"`K/2`B+FAT;6PB
M.PH)"75R;"`](%]E9&ET;W)?=7)L("L@(G!L=6=I;G,O(B`K('!L=6=I;B`K
M("(O<&]P=7!S+R(@*R!P;W!U<#L*"7T@96QS90H)"75R;"`](%]E9&ET;W)?
M=7)L("L@=&AI<RYC;VYF:6<N<&]P=7!54DP@*R!F:6QE.PH)<F5T=7)N('5R
M;#L*?3L*"B\J*@H@*B!&25@Z($EN=&5R;F5T($5X<&QO<F5R(')E='5R;G,@
M86X@:71E;2!H879I;F<@=&AE(%]N86UE7R!E<75A;"!T;R!T:&4@9VEV96X*
M("H@:60L(&5V96X@:68@:70G<R!N;W0@:&%V:6YG(&%N>2!I9"X@(%1H:7,@
M=V%Y(&ET(&-A;B!R971U<FX@82!D:69F97)E;G0@9F]R;0H@*B!F:65L9"!E
M=F5N(&EF(&ET)W,@;F]T(&$@=&5X=&%R96$N("!4:&ES('=O<FMA<F]U;F1S
M('1H92!P<F]B;&5M(&)Y"B`J('-P96-I9FEC86QL>2!L;V]K:6YG('1O('-E
M87)C:"!O;FQY(&5L96UE;G1S(&AA=FEN9R!A(&-E<G1A:6X@=&%G(&YA;64N
M"B`J+PI(5$U,07)E82YG971%;&5M96YT0GE)9"`](&9U;F-T:6]N*'1A9RP@
M:60I('L*"79A<B!E;"P@:2P@;V)J<R`](&1O8W5M96YT+F=E=$5L96UE;G1S
M0GE486=.86UE*'1A9RD["@EF;W(@*&D@/2!O8FIS+FQE;F=T:#L@+2UI(#X]
M(#`@)B8@*&5L(#T@;V)J<UMI72D[*0H)"6EF("AE;"YI9"`]/2!I9"D*"0D)
M<F5T=7)N(&5L.PH)<F5T=7)N(&YU;&P["GT["@H*"B\O($5/1@HO+R!,;V-A
M;"!V87)I86)L97,Z("\O"B\O(&,M8F%S:6,M;V9F<V5T.C@@+R\*+R\@:6YD
M96YT+71A8G,M;6]D93IT("\O"B\O($5N9#H@+R\*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O:V5Y8F]A<F0N<&AP````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S4T-P`Q,#0Q-S,V,S`P-P`P,C`U
M-C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]K97EB;V%R9"YP
M:'`L=B`Q+C$S+C$P+C,@,C`P-B\P,2\P,2`R,3HR.3HQ,"!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/
M4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HD=&ET;&4@
M/2!?*")3<&5C:6%L($-H87)A8W1E<B!);G!U="(I.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PH*/SX*"CQS8W)I
M<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*"G9A<B!T87)G970["@IF=6YC
M=&EO;B!H86YD;&5,:7-T0VAA;F=E*'1H94QI<W0I('L*("`@('9A<B!N=6U3
M96QE8W1E9"`]('1H94QI<W0N<V5L96-T961);F1E>#L*"B`@("!I9B`H;G5M
M4V5L96-T960@(3T@,"D@>PH@("`@("`@(&1O8W5M96YT+F-H87)A8W1E<G,N
M=&5X=&)O>"YV86QU92`K/2!T:&5,:7-T+F]P=&EO;G-;;G5M4V5L96-T961=
M+G9A;'5E.PH@("`@("`@('1H94QI<W0N<V5L96-T961);F1E>"`](#`["B`@
M("!]"GT*/"]S8W)I<'0^"@H\9F]R;2!N86UE/2)C:&%R86-T97)S(CX*/'1A
M8FQE(&-E;&QS<&%C:6YG/2(P(CX*("`\='(^"B`@("`\=&0@8VQA<W,](FET
M96T@;&5F=$%L:6=N(CX*("`@("`@/'`^/#]P:'`@96-H;R!?*")396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82XB*2`_/CPO<#X*("`@(#PO=&0^"B`@/"]T<CX*("`\='(^"B`@
M("`\=&0@8VQA<W,](FQE9G1!;&EG;B(^"B`@("`@(#QT86)L92!C96QL<W!A
M8VEN9STB,"(^"B`@("`@("`@/'1R/@H@("`@("`@("`@/'1D(&%L:6=N/2)C
M96YT97(B/@H@("`@("`@("`@("`\<V5L96-T(&YA;64](F$B(&]N8VAA;F=E
M/2)H86YD;&5,:7-T0VAA;F=E*'1H:7,I(CX*("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2)A(B!S96QE8W1E9#X@82`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S$Y,CLB/B`F(S$Y,CL@/"]O<'1I;VX^
M"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,C0[(CX@)B,R,C0[
M(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,3DS
M.R(^("8C,3DS.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(F(S(R-3LB/B`F(S(R-3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB)B,Q.30[(CX@)B,Q.30[(#PO;W!T:6]N/@H@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C(V.R(^("8C,C(V.R`\+V]P
M=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S$Y-3LB/B`F
M(S$Y-3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M)B,R,C<[(CX@)B,R,C<[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](B8C,3DV.R(^("8C,3DV.R`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S(R.#LB/B`F(S(R.#L@/"]O<'1I;VX^
M"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q.3<[(CX@)B,Q.3<[
M(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C(Y
M.R(^("8C,C(Y.R`\+V]P=&EO;CX*("`@("`@("`@("`@/"]S96QE8W0^"B`@
M("`@("`@("`\+W1D/@H@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B/@H@
M("`@("`@("`@("`\<V5L96-T(&YA;64](F4B(&]N8VAA;F=E/2)H86YD;&5,
M:7-T0VAA;F=E*'1H:7,I(CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2)E(B!S96QE8W1E9#X@92`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2(F(S(P,#LB/B`F(S(P,#L@/"]O<'1I;VX^"B`@("`@("`@
M("`@("`@/&]P=&EO;B!V86QU93TB)B,R,S([(CX@)B,R,S([(#PO;W!T:6]N
M/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C`Q.R(^("8C,C`Q
M.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S
M,SLB/B`F(S(S,SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V
M86QU93TB)B,R,#([(CX@)B,R,#([(#PO;W!T:6]N/@H@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](B8C,C,T.R(^("8C,C,T.R`\+V]P=&EO;CX*("`@
M("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(P,SLB/B`F(S(P,SL@/"]O
M<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,S4[(CX@
M)B,R,S4[(#PO;W!T:6]N/@H@("`@("`@("`@("`\+W-E;&5C=#X*("`@("`@
M("`@(#PO=&0^"B`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(^"B`@("`@
M("`@("`@(#QS96QE8W0@;F%M93TB:2(@;VYC:&%N9V4](FAA;F1L94QI<W1#
M:&%N9V4H=&AI<RDB/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](FDB
M('-E;&5C=&5D/B!I(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](B8C,C`T.R(^("8C,C`T.R`\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(F(S(S-CLB/B`F(S(S-CL@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,#4[(CX@)B,R,#4[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C,W.R(^
M("8C,C,W.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S(P-CLB/B`F(S(P-CL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,R,S@[(CX@)B,R,S@[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C`W.R(^("8C,C`W.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S.3LB/B`F(S(P
M-SL@/"]O<'1I;VX^"B`@("`@("`@("`@(#PO<V5L96-T/@H@("`@("`@("`@
M/"]T9#X*("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@("`@("`@
M("`@/'-E;&5C="!N86UE/2)O(B!O;F-H86YG93TB:&%N9&QE3&ES=$-H86YG
M92AT:&ES*2(^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB;R(@<V5L
M96-T960^(&\@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU
M93TB)B,R,3`[(CX@)B,R,3`[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64](B8C,C0R.R(^("8C,C0R.R`\+V]P=&EO;CX*("`@("`@
M("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(Q,3LB/B`F(S(Q,3L@/"]O<'1I
M;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R-#,[(CX@)B,R
M-#,[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C
M,C$R.R(^("8C,C$R.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N
M('9A;'5E/2(F(S(T-#LB/B`F(S(T-#L@/"]O<'1I;VX^"B`@("`@("`@("`@
M("`@/&]P=&EO;B!V86QU93TB)B,R,3,[(CX@)B,R,3,[(#PO;W!T:6]N/@H@
M("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C0U.R(^("8C,C0U.R`\
M+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(Q-#LB
M/B`F(S(Q-#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU
M93TB)B,R-#8[(CX@)B,R-#8[(#PO;W!T:6]N/@H@("`@("`@("`@("`\+W-E
M;&5C=#X*("`@("`@("`@(#PO=&0^"B`@("`@("`@("`\=&0@86QI9VX](F-E
M;G1E<B(^"B`@("`@("`@("`@(#QS96QE8W0@;F%M93TB=2(@;VYC:&%N9V4]
M(FAA;F1L94QI<W1#:&%N9V4H=&AI<RDB/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](G4B('-E;&5C=&5D/B!U(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,C$W.R(^("8C,C$W.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(T.3LB/B`F(S(T.3L@
M/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,3@[
M(CX@)B,R,3@[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L
M=64](B8C,C4P.R(^("8C,C4P.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\
M;W!T:6]N('9A;'5E/2(F(S(Q.3LB/B`F(S(Q.3L@/"]O<'1I;VX^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R-3$[(CX@)B,R-3$[(#PO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C(P.R(^("8C
M,C(P.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S(U,CLB/B`F(S(U,CL@/"]O<'1I;VX^"B`@("`@("`@("`@(#PO<V5L96-T
M/@H@("`@("`@("`@/"]T9#X*("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R
M(CX*("`@("`@("`@("`@/'-E;&5C="!N86UE/2)/=&AE<B(@;VYC:&%N9V4]
M(FAA;F1L94QI<W1#:&%N9V4H=&AI<RDB/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](FUI<V,B('-E;&5C=&5D/B`\/W!H<"!E8VAO(%\H(D]T:&5R
M(BD[(#\^/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M)B,Q-C([(CX@)B,Q-C([(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](B8C,38S.R(^("8C,38S.R`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S$V-#LB/B`F(S$V-#L@/"]O<'1I;VX^
M"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q-C4[(CX@)B,Q-C4[
M(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,3DX
M.R(^("8C,3DX.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(F(S(S,#LB/B`F(S(S,#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB)B,R,C,[(CX@)B,R,C,[(#PO;W!T:6]N/@H@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,3DY.R(^("8C,3DY.R`\+V]P
M=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S,3LB/B`F
M(S(S,3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M)B,R,#D[(CX@)B,R,#D[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](B8C,C0Q.R(^("8C,C0Q.R`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S(U,SLB/B`F(S(U,SL@/"]O<'1I;VX^
M"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R-34[(CX@)B,R-34[
M(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,3DQ
M.R(^("8C,3DQ.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(F(S$V,3LB/B`F(S$V,3L@/"]O<'1I;VX^"B`@("`@("`@("`@(#PO
M<V5L96-T/@H@("`@("`@("`@/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`\
M+W1A8FQE/@H@("`@/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!C;&%S
M<STB9FEX960@;&5F=$%L:6=N(CX*("`@("`@/'1E>'1A<F5A(')O=W,](C0B
M(&-O;',](C(U(B!C;&%S<STB9FEX960B(&YA;64](G1E>'1B;W@B/CPO=&5X
M=&%R96$^"B`@("`\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D(&%L:6=N
M/2)C96YT97(B/@H@("`@("`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB
M8G5T=&]N(B!O;F-L:6-K/2)W:6YD;W<N8VQO<V4H*3LB(&YA;64](F-L;W-E
M(B!V86QU93TB/#]P:'`@96-H;R!?*")#;&]S92!7:6YD;W<B*2`_/B(@+SX*
M("`@(#PO=&0^"B`@/"]T<CX*/"]T86)L93X*/"]F;W)M/@H\+V)O9'D^"CPO
M:'1M;#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]J879A<V-R:7!T+G!H<```````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#8R`#$P-#$W,S8S,#`W`#`R,3$R,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]J879A<V-R:7!T+G!H
M<"QV(#$N,S<N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(Y.C$P(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H
M)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q
M=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["@HD<F5G
M:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;BA(3U)$15]315-324].7U)%
M041/3DQ9*3L*"B\O($9I9W5R92!O=70@:68@=V4G=F4@8F5E;B!I;FQI;F5D
M+"!O<B!C86QL960@9&ER96-T;'DN"B1S96YD7VAE861E<G,@/2!S=')S='(H
M)%]315)615);)U!(4%]314Q&)UTL("=J879A<V-R:7!T+G!H<"<I.PH*)&%P
M<"`](%5T:6PZ.F=E=$9O<FU$871A*"=A<'`G+"!5=&EL.CIN;VY);G!U=%9A
M<B@G87!P)RDI.PHD9FEL92`](%5T:6PZ.F=E=$9O<FU$871A*"=F:6QE)RP@
M571I;#HZ;F]N26YP=71687(H)V9I;&4G*2D["FEF("@A96UP='DH)&%P<"D@
M)B8@(65M<'1Y*"1F:6QE*2`F)B!S=')P;W,H)&9I;&4L("<N+B<I(#T]/2!F
M86QS92D@>PH@("`@)'-C<FEP=%]F:6QE(#T@)')E9VES=')Y+3YG970H)W1E
M;7!L871E<R<L("1A<'`I("X@)R]J879A<V-R:7!T+R<@+B`D9FEL93L*("`@
M(&EF("A`9FEL95]E>&ES=',H)'-C<FEP=%]F:6QE*2D@>PH@("`@("`@("1R
M96=I<W1R>2T^<'5S:$%P<"@D87!P+"!F86QS92D["B`@("`@("`@)'-C<FEP
M="`](%5T:6PZ.F)U9F9E<D]U='!U="@G<F5Q=6ER92<L("1S8W)I<'1?9FEL
M92D["@H@("`@("`@(&EF("@D<V5N9%]H96%D97)S*2!["B`@("`@("`@("`@
M("\J($-O;7!R97-S('1H92!*4RX@5V4@;F5E9"!T:&ES(&5X<&QI8VET(&-A
M;&P@<VEN8V4@=V4*("`@("`@("`@("`@("H@9&]N)W0@:6YC;'5D92!B87-E
M+G!H<"!I;B!T:&ES(&9I;&4N("HO"B`@("`@("`@("`@($AO<F1E.CIC;VUP
M<F5S<T]U='!U="@I.PH*("`@("`@("`@("`@:&5A9&5R*"=#86-H92U#;VYT
M<F]L.B!N;RUC86-H92<I.PH@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M
M5'EP93H@=&5X="]J879A<V-R:7!T)RD["B`@("`@("`@?0H*("`@("`@("!E
M8VAO("1S8W)I<'0["B`@("!]"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V=O+G!H<```
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4V
M-38`,3`T,3<S-C,P,#<`,#$W,S8W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!!('-C<FEP="!T;R!R
M961I<F5C="!T;R!A(&=I=F5N(%523"P@=7-E9"!F;W(@97AA;7!L92!I;B!)
M35`@=&\@:&ED92!A;GD*("H@<F5F97)R97(@9&%T82!B96EN9R!P87-S960@
M=&\@=&AE(')E;6]T92!S97)V97(@86YD('!O=&5N=&EA;&QY(&5X<&]S:6YG
M"B`J(&%N>2!S97-S:6]N($E$<RX*("H*("H@268@86X@(G5N=')U<W1E9"(@
M<&%R86UE=&5R(&ES('-E="P@:70@<&%S<V5S('1H92!C;VYT96YT(&]F('1H
M92!G:79E;B!54DP*("H@=&AR;W5G:"!T;R!T:&4@8G)O=W-E<B!I9B!I="!D
M;V5S;B=T(&)E;&]N9R!T;R!T:&4@;&]C86P@<VET92X@5&AI<R!C86X@8F4*
M("H@=7-E9"!T;R!A=F]I9"!C86QL:6YG(&QO8V%L(%523',@9F]R(&5X86UP
M;&4@8GD@:6UA9V4@<W)C(&%T=')I8G5T97,N"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O9V\N<&AP+'8@
M,2XV+C(N,3`@,C`P-B\P,R\P-B`P,CHR-3HS,B!C:'5C:R!%>'`@)`H@*@H@
M*B!`875T:&]R($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J+PH*
M:68@*&5M<'1Y*"1?1T546R=U<FPG72DI('L*("`@(&5X:70["GT*"B1U<FP@
M/2!T<FEM*"1?1T546R=U<FPG72D["FEF("AG971?;6%G:6-?<75O=&5S7V=P
M8R@I*2!["B`@("`D<&%R<V5D7W5R;"`]($!P87)S95]U<FPH<W1R:7!S;&%S
M:&5S*"1U<FPI*3L*?2!E;'-E('L*("`@("1P87)S961?=7)L(#T@0'!A<G-E
M7W5R;"@D=7)L*3L*?0H*:68@*&5M<'1Y*"1P87)S961?=7)L*2!\?"!E;7!T
M>2@D<&%R<V5D7W5R;%LG:&]S="==*2D@>PH@("`@97AI=#L*?0II9B`H96UP
M='DH)'!A<G-E9%]U<FQ;)W!A=&@G72DI('L*("`@("1P87)S961?=7)L6R=P
M871H)UT@/2!F86QS93L*?0H*+R\@1&\@82!L:71T;&4@9'5E(&1I;&EG96YC
M92!O;B!T:&4@=&%R9V5T(%523"X@268@:70G<R!O;B!T:&4@<V%M92!S97)V
M97(*+R\@=&AA="!W92=R92!A;')E861Y(&]N+"!D:7-P;&%Y(&%N(&EN=&5R
M;65D:6%T92!P86=E(&%S:VEN9R!P96]P;&4@:68*+R\@=&AE>2=R92!S=7)E
M('1H97D@=V%N="!T;R!C;&EC:R!T:')O=6=H+@II9B`H<W5B<W1R*'!H<%]S
M87!I7VYA;64H*2P@,"P@,RD@/3T@)V-G:2<I('L*("`@("\O(%=H96X@=7-I
M;F<@0T=)(%!(4"P@4T-225!47TY!344@;6%Y(&-O;G1A:6X@=&AE('!A=&@@
M=&\@=&AE(%!(4"!B:6YA<GD*("`@("\O(&EN<W1E860@;V8@=&AE('-C<FEP
M="!B96EN9R!R=6X[('5S92!02%!?4T5,1B!I;G-T96%D+@H@("`@)&UY=7)L
M(#T@)%]315)615);)U!(4%]314Q&)UT["GT@96QS92!["B`@("`D;7EU<FP@
M/2!I<W-E="@D7U-%4E9%4ELG4T-225!47TY!344G72D@/PH@("`@("`@("1?
M4T525D526R=30U))4%1?3D%-12==(#H*("`@("`@("`D7U-%4E9%4ELG4$A0
M7U-%3$8G73L*?0HD=V5B<F]O="`]('-U8G-T<B@D;7EU<FPL(#`L("TQ-BD[
M"@II9B`H*&5M<'1Y*"1W96)R;V]T*2!\?"!S=')P;W,H)'5R;%LG<&%T:"==
M+"`D=V5B<F]O="D@/3T](#`I("8F"B`@("`A96UP='DH)'5R;%LG<75E<GDG
M72D@)B8*("`@("@H(65M<'1Y*"1?4T525D526R=315)615)?3D%-12==*2`F
M)@H@("`@("`D7U-%4E9%4ELG4T525D527TY!344G72`]/2`D=7)L6R=H;W-T
M)UTI('Q\"B`@("`@*"%E;7!T>2@D7U-%4E9%4ELG2%144%](3U-4)UTI("8F
M"B`@("`@("1?4T525D526R=(5%107TA/4U0G72`]/2`D=7)L6R=H;W-T)UTI
M*2D@>PH_/@H\:'1M;#X*/&AE860^"CQT:71L93Y0;W1E;G1I86QL>2!$86YG
M97)O=7,@55),/"]T:71L93X*/"]H96%D/@H\8F]D>3X*(#QH,3Y0;W1E;G1I
M86QL>2!$86YG97)O=7,@55),/"]H,3X*"B`\<#X*("!!(')E9F5R<FEN9R!S
M:71E+"!A;B!E;6%I;"!Y;W4@=V5R92!R96%D:6YG+"!O<B!S;VUE(&]T:&5R
M"B`@<&]T96YT:6%L;'D@=6YT<G5S=&5D('-O=7)C92!H87,@871T96UP=&5D
M('1O('-E;F0@>6]U('1O(#P_<&AP(&5C:&\*("!H=&UL<W!E8VEA;&-H87)S
M*"1U<FPI(#\^+B!4:&ES(&UA>2!B92!A;B!A='1E;7!T('1O"B`@9&5L971E
M(&1A=&$@;W(@8VAA;F=E('-E='1I;F=S('=I=&AO=70@>6]U<B!K;F]W;&5D
M9V4N($EF"B`@>6]U(&AA=F4@86YY(&-O;F-E<FYS(&%B;W5T('1H:7,@55),
M+"!P;&5A<V4@8V]N=&%C="!Y;W5R"B`@4WES=&5M($%D;6EN:7-T<F%T;W(N
M($EF('EO=2!A<F4@8V]N9FED96YT('1H870@:70@:7,@<V%F92P*("!Y;W4@
M;6%Y(&9O;&QO=R!T:&4@;&EN:R!B>2!C;&EC:VEN9R!B96QO=RX*(#PO<#X*
M"B`\<#X*("`\82!H<F5F/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'5R;"D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7)L*2`_
M/CPO83X*(#PO<#X*"CPO8F]D>3X*/"]H=&UL/@H\/W!H<`H@("`@97AI=#L*
M?0H*+R\@4&%S<R!T:')O=6=H(&EM86=E(&-O;G1E;G0@:68@<F5Q=65S=&5D
M+@II9B`H(65M<'1Y*"1?1T546R=U;G1R=7-T960G72DI('L*("`@("1A;&QO
M=V5D7W!R;W1O8V]L<R`](&%R<F%Y*"=H='1P)RP@)VAT='!S)RP@)V9T<"<I
M.PH@("`@9F]R96%C:"`H)&%L;&]W961?<')O=&]C;VQS(&%S("1P<F]T;RD@
M>PH@("`@("`@(&EF("AS=6)S='(H)'5R;"P@,"P@<W1R;&5N*"1P<F]T;RD@
M*R`S*2`]/2`D<')O=&\@+B`G.B\O)RD@>PH@("`@("`@("`@("!R96%D9FEL
M92@D=7)L*3L*("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"B`@
M("!E>&ET.PI]"@HO+R!/=&AE<G=I<V4@=V4G<F4@:7-S=6EN9R!A(')E9G)E
M<V@N"FAE861E<B@G4F5F<F5S:#H@,#L@55),/2<@+B`D=7)L*3L*````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S(U-@`Q,#0Q-S,V,S`P-P`P
M,C$W-S``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP+'8@,2XQ+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(Y.C$P(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($-R;VYO<WES+"!,
M3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]&;W)M+U)E;F1E<F5R+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O5F%R:6%B;&5S+G!H<"<["@II9B`H(4%U=&@Z.FES075T:&5N=&EC
M871E9"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D
M:7)E8W0H*3L*?0H*+R\@36%K92!S=7)E(&%U=&@@8F%C:V5N9"!A;&QO=W,@
M<&%S<W=O<F1S('1O(&)E(')E<V5T+@HD875T:"`]("9!=71H.CIS:6YG;&5T
M;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PII9B`H(21A=71H+3YH87-#
M87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"A?*")#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@:&5A9&5R
M*"=,;V-A=&EO;CH@)R`N($%U=&@Z.F=E=$QO9VEN4V-R965N*"<G+"!5=&EL
M.CIG971&;W)M1&%T82@G=7)L)RDI*3L*("`@(&5X:70["GT*"B1V87)S(#T@
M)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PH*)'1I=&QE(#T@
M7R@B0VAA;F=E(%EO=7(@4&%S<W=O<F0B*3L*)&9O<FT@/2`F2&]R9&5?1F]R
M;3HZ<VEN9VQE=&]N*"=(;W)D95-I9VYU<$9O<FTG+"`D=F%R<RP@)'1I=&QE
M*3L*)&9O<FTM/G-E=$)U='1O;G,H7R@B0V]N=&EN=64B*2D["@HD9F]R;2T^
M861D2&ED9&5N*"<G+"`G<F5T=7)N7W1O)RP@)W1E>'0G+"!F86QS92D["B1F
M;W)M+3YA9&1687)I86)L92A?*")/;&0@<&%S<W=O<F0B*2P@)V]L9%]P87-S
M=V]R9"<L("=P87-S=V]R9"<L('1R=64I.PHD9F]R;2T^861D5F%R:6%B;&4H
M7R@B3F5W('!A<W-W;W)D(BDL("=P87-S=V]R9%\Q)RP@)W!A<W-W;W)D)RP@
M=')U92D["B1F;W)M+3YA9&1687)I86)L92A?*")2971Y<&4@;F5W('!A<W-W
M;W)D(BDL("=P87-S=V]R9%\R)RP@)W!A<W-W;W)D)RP@=')U92D["@II9B`H
M)'9A<G,M/F5X:7-T<R@G9F]R;6YA;64G*2D@>PH@("`@)&9O<FTM/G9A;&ED
M871E*"1V87)S*3L*("`@(&EF("@D9F]R;2T^:7-686QI9"@I*2!["B`@("`@
M("`@)&9O<FTM/F=E=$EN9F\H)'9A<G,L("1I;F9O*3L*("`@("`@("!D;R![
M"B`@("`@("`@("`@(&EF("@D875T:"T^9V5T0W)E9&5N=&EA;"@G<&%S<W=O
M<F0G*2`A/2`D:6YF;ULG;VQD7W!A<W-W;W)D)UTI('L*("`@("`@("`@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B3VQD('!A<W-W;W)D(&ES(&YO
M="!C;W)R96-T+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&EN9F];)W!A<W-W;W)D
M7S$G72`A/2`D:6YF;ULG<&%S<W=O<F1?,B==*2!["B`@("`@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(DYE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("@D:6YF;ULG;VQD7W!A<W-W;W)D
M)UT@/3T@)&EN9F];)W!A<W-W;W)D7S$G72D@>PH@("`@("`@("`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")/;&0@86YD(&YE=R!P87-S=V]R9',@
M;75S="!B92!D:69F97)E;G0N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M($9)6$U%.B!.965D('1O(&-L96%N('5P('!A<W-W;W)D('!O;&EC>2!P871C
M:"!A;F0@8V]M;6ET(&)E9F]R90H@("`@("`@("`@("`@*B!E;F%B;&EN9R!T
M:&ES+BXN("U*348*"B`@("`@("`@("`@("1R97,@/2!!=71H.CIT97-T4&%S
M<W=O<F13=')E;F=T:"@D:6YF;ULG<&%S<W=O<F1?,2==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)V%U
M=&@G75LG<&%S<W=O<F1?<&]L:6-Y)UTI.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*"1R97,M/F=E=$UE<W-A9V4H*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`J+PH*("`@("`@("`@("`@)')E<R`]("1A=71H+3YU<&1A
M=&55<V5R*$%U=&@Z.F=E=$%U=&@H*2P@075T:#HZ9V5T075T:"@I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A<W-W
M;W)D)R`]/B`D:6YF;ULG<&%S<W=O<F1?,2==*2D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")%<G)O<B!U<&1A=&EN
M9R!P87-S=V]R9#H@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S+3YG971-97-S86=E*"DI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@(&EF("@A96UP='DH
M)&EN9F];)W)E='5R;E]T;R==*2D@>PH@("`@("`@("`@("`@("`@:&5A9&5R
M*"=,;V-A=&EO;CH@)R`N("1I;F9O6R=R971U<FY?=&\G72D["B`@("`@("`@
M("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T@=VAI;&4@*&9A;'-E*3L*("`@('T*?0H*)'9A<G,M/G)E
M;6]V92@G;VQD7W!A<W-W;W)D)RD["B1V87)S+3YR96UO=F4H)W!A<W-W;W)D
M7S$G*3L*)'9A<G,M/G)E;6]V92@G<&%S<W=O<F1?,B<I.PH*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF
M:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G
M*2D["B1R96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@I.PHD
M9F]R;2T^<F5N9&5R06-T:79E*"1R96YD97)E<BP@)'9A<G,L("=C:&%N9V5P
M87-S=V]R9"YP:'`G+"`G<&]S="<I.PIR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-C4T-P`Q,#0Q-S,V,S`P-P`P,C$R-#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP+'8@,2XS,2XR+C,@,C`P-B\P
M,2\P,2`R,3HR.3HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M
M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@0VAA<FQE<R!*+B!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#$M,C`P
M-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-86EN=&5N86YC92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L871E+G!H<"<["@HO*B!-86ME('-U
M<F4@=&AE<F4@:7,@82!U<V5R(&QO9V=E9"!I;BX@*B\*:68@*"%!=71H.CIG
M971!=71H*"DI('L*("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52
M961I<F5C="@I.PI]"@HO*B!)9B!N;R`G;6]D=6QE)R!P87)A;65T97(@<&%S
M<V5D(&EN+"!D:64@=VET:"!A;B!E<G)O<BX@*B\*:68@*"$H)&UO9'5L92`]
M(&)A<V5N86UE*%5T:6PZ.F=E=$9O<FU$871A*"=M;V1U;&4G*2DI*2!["B`@
M("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BA?*")$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(I*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*?0HD87!P7VYA;64@/2`D<F5G:7-T<GDM/F=E="@G;F%M92<L
M("1M;V1U;&4I.PH*+RH@3&]A9"!T:&4@;6]D=6QE('-P96-I9FEC(&UA:6YT
M96YA;F-E(&-L87-S(&YO=RX@*B\*:68@*"$H)&UA:6YT(#T@)DUA:6YT96YA
M;F-E.CIF86-T;W)Y*"1M;V1U;&4I*2D@>PH@("`@2&]R9&4Z.F9A=&%L*%!%
M05(Z.G)A:7-E17)R;W(H7R@B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>2(I*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*?0H*+RH@0W)E871E('1H92!(;W)D95]496UP;&%T92!I=&5M+B`J+PHD
M=&5M<&QA=&4@/2`F;F5W($AO<F1E7U1E;7!L871E*"D["B1T96UP;&%T92T^
M<V5T*"=J879A<V-R:7!T)RP@)&)R;W=S97(M/FAA<T9E871U<F4H)VIA=F%S
M8W)I<'0G*2P@=')U92D["@HO*B!(879E('1H92!M86EN=&5N86YC92!M;V1U
M;&4@9&\@86QL(&YE8V5S<V%R>2!P<F]C97-S:6YG+B`J+PIL:7-T*"1A8W1I
M;VXL("1T87-K;&ES="D@/2`D;6%I;G0M/G)U;DUA:6YT96YA;F-E4&%G92@I
M.PH*<W=I=&-H("@D86-T:6]N*2!["F-A<V4@34%)3E1%3D%.0T5?3U544%54
M7T-/3D9)4DTZ"B`@("`O*B!#;VYF:7)M871I;VXM<W1Y;&4@;W5T<'5T+B`J
M+PH@("`@)'1E;7!L871E+3YS970H)V-O;F9I<FTG+"!T<G5E+"!T<G5E*3L*
M("`@("1T96UP;&%T92T^<V5T*"=A9W)E92<L(&9A;'-E+"!T<G5E*3L*("`@
M("1T96UP;&%T92T^<V5T*"=N;W1I8V4G+"!F86QS92P@=')U92D["@H@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(B5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB*2P@)&%P<%]N86UE*2P@
M)VAO<F1E+FUE<W-A9V4G*3L*("`@("1T96UP;&%T92T^<V5T*"=H96%D97(G
M+"!S<')I;G1F*%\H(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VXB*2P@)&%P<%]N86UE*2D["B`@("!B<F5A:SL*"F-A<V4@34%)
M3E1%3D%.0T5?3U544%547T%'4D5%.@H@("`@+RH@06=R965M96YT+7-T>6QE
M(&]U='!U="X@*B\*("`@("1T96UP;&%T92T^<V5T*"=C;VYF:7)M)RP@9F%L
M<V4L('1R=64I.PH@("`@)'1E;7!L871E+3YS970H)V%G<F5E)RP@=')U92P@
M=')U92D["B`@("`D=&5M<&QA=&4M/G-E="@G;F]T:6-E)RP@9F%L<V4L('1R
M=64I.PH*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE('-Y<W1E;2XB*2P@)VAO<F1E+FUE<W-A9V4G*3L*
M("`@("1T96UP;&%T92T^<V5T*"=H96%D97(G+"!S<')I;G1F*%\H(B5S(%1E
M<FUS(&]F($%G<F5E;65N="(I+"`D87!P7VYA;64I*3L*("`@(&)R96%K.PH*
M8V%S92!-04E.5$5.04Y#15]/5510551?3D]424-%.@H@("`@+RH@3F]T:6-E
M+7-T>6QE(&]U='!U="X@*B\*("`@("1T96UP;&%T92T^<V5T*"=C;VYF:7)M
M)RP@9F%L<V4L('1R=64I.PH@("`@)'1E;7!L871E+3YS970H)V%G<F5E)RP@
M9F%L<V4L('1R=64I.PH@("`@)'1E;7!L871E+3YS970H)VYO=&EC92<L('1R
M=64L('1R=64I.PH*("`@("1T96UP;&%T92T^<V5T*"=H96%D97(G+"!S<')I
M;G1F*%\H(B5S("T@3F]T:6-E(BDL("1A<'!?;F%M92DI.PH@("`@8G)E86L[
M"GT*"B\J($UA:V4@=F%R:6%B;&4@87)R87D@;F5E9&5D(&9O<B!T96UP;&%T
M97,N("HO"B1T87-K<R`](&%R<F%Y*"D["F9O<F5A8V@@*"1T87-K;&ES="!A
M<R`D<')E9BD@>PH@("`@;&ES="@D9&5S8W)I<"P@)&-H96-K960I(#T@)&UA
M:6YT+3YI;F9O36%I;G1E;F%N8V4H)'!R968I.PH@("`@)'1A<VMS6UT@/2!A
M<G)A>2@G<')E9B<@/3X@)'!R968L("=D97-C<FEP)R`]/B`D9&5S8W)I<"P@
M)V-H96-K960G(#T^("1C:&5C:V5D(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M.B`G)RD["GT*"B1T96UP;&%T92T^<V5T3W!T:6]N*"=G971T97AT)RP@=')U
M92D["B1T96UP;&%T92T^<V5T*"=T87-K<R<L("1T87-K<RD["B1T96UP;&%T
M92T^<V5T*"=M86EN=%]U<FPG+"`D;6%I;G0M/F=E=$UA:6YT96YA;F-E1F]R
M;5523"@I*3L*)'1E;7!L871E+3YS970H)VUA:6YT7W!O<W1D871A)RP@)&UA
M:6YT+3YG9710;W-T1&%T82@I*3L*)'1E;7!L871E+3YS970H)VYO=&EF>2<L
M(%5T:6PZ.F)U9F9E<D]U='!U="AA<G)A>2@D;F]T:69I8V%T:6]N+"`G;F]T
M:69Y)RDL(&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2DI.PH*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*
M96-H;R`D=&5M<&QA=&4M/F9E=&-H*$A/4D1%7U1%35!,051%4R`N("<O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;"<I.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V-A8VAE
M=FEE=RYP:'``````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$T-S8`,3`T,3<S-C,P,#<`,#(P-S$T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W-E<G9I8V5S+V-A8VAE=FEE=RYP:'`L=B`Q+CDN,3`N,R`R,#`V+S`Q
M+S`Q(#(Q.C(Y.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-A8VAE+G!H<"<[
M"@HD8VED(#T@571I;#HZ9V5T1F]R;41A=&$H)V-I9"<I.PII9B`H96UP='DH
M)&-I9"DI('L*("`@(&5X:70["GT*"B1C86-H92`]("9(;W)D95]#86-H93HZ
M<VEN9VQE=&]N*"1C;VYF6R=C86-H92==6R=D<FEV97(G72P@2&]R9&4Z.F=E
M=$1R:79E<D-O;F9I9R@G8V%C:&4G+"`D8V]N9ELG8V%C:&4G75LG9')I=F5R
M)UTI*3L*)&-D871A(#T@0'5N<V5R:6%L:7IE*"1C86-H92T^9V5T*"1C:60L
M("1C;VYF6R=C86-H92==6R=D969A=6QT7VQI9F5T:6UE)UTI*3L*:68@*"$D
M8V1A=&$I('L*("`@(&5X:70["GT*"B1B<F]W<V5R+3YD;W=N;&]A9$AE861E
M<G,H)V-A8VAE3V)J96-T)RP@)&-D871A6R=C='EP92==+"!T<G5E+"!S=')L
M96XH)&-D871A6R=D871A)UTI*3L*96-H;R`D8V1A=&%;)V1A=&$G73L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+W!R969S+G!H<```````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3`T-30`,3`T,3<S-C,P,#<`,#(P,#<Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+W-E<G9I8V5S+W!R969S+G!H<"QV(#$N,3DN,BXQ,"`R,#`V
M+S`R+S`W(#(S.C4P.C`P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O4')E9G,O54DN<&AP)SL*"B1R96=I<W1R>2`]("9296=I
M<W1R>3HZ<VEN9VQE=&]N*"D["@HO*B!&:6=U<F4@;W5T('=H:6-H(&%P<&QI
M8V%T:6]N('=E)W)E('-E='1I;F<@<')E9F5R96YC97,@9F]R+B`J+PHD87!P
M(#T@571I;#HZ9V5T1F]R;41A=&$H)V%P<"<L(%!R969S7U5).CIG971$969A
M=6QT07!P*"DI.PHD87!P8F%S92`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O
M="<L("1A<'`I.PH*+RH@4V5E(&EF('=E(&AA=F4@82!P<F5F97)E;F-E<R!G
M<F]U<"!S970N("HO"B1G<F]U<"`](%5T:6PZ.F=E=$9O<FU$871A*"=G<F]U
M<"<I.PH*+RH@3&]A9"`D87!P)W,@8F%S92!E;G9I<F]N;65N="P@8G5T(&1O
M;B=T(')E<75E<W0@=&AA="!T:&4@87!P('!E<F9O<FT*("H@875T:&5N=&EC
M871I;VX@8F5Y;VYD($AO<F1E)W,N("HO"B1A=71H96YT:6-A=&EO;B`]("=N
M;VYE)SL*<F5Q=6ER95]O;F-E("1A<'!B87-E("X@)R]L:6(O8F%S92YP:'`G
M.PH*+RH@4V5T('1I=&QE+B`J+PHD=&ET;&4@/2!S<')I;G1F*%\H(D]P=&EO
M;G,@9F]R("5S(BDL("1R96=I<W1R>2T^9V5T*"=N86UE)RDI.PH*+RH@4W!E
M8VEA;"!C87-E('=H97)E('=E(&YE960@=&AE($ED96YT:71Y(&]B:F5C="!I
M;B!(;W)D92=S('!R969S+G!H<"X@*B\*:68@*"1G<F]U<"`]/2`G:61E;G1I
M=&EE<R<@)B8@)&%P<"`]/2`G:&]R9&4G*2!["B`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`D:61E;G1I='D@/2`F261E;G1I
M='DZ.G-I;F=L971O;B@D87!P(#T]("=H;W)D92<@/R!N=6QL(#H@87)R87DH
M)&%P<"P@)&%P<"DI.PI]"@HO*B!,;V%D("1A<'`G<R!P<F5F97)E;F-E<RP@
M:68@86YY+B`J+PHD<')E9D=R;W5P<R`](&%R<F%Y*"D["FEF("AF:6QE7V5X
M:7-T<R@D87!P8F%S92`N("<O8V]N9FEG+W!R969S+G!H<"<I*2!["B`@("!R
M97%U:7)E("1A<'!B87-E("X@)R]C;VYF:6<O<')E9G,N<&AP)SL*?0H*+RH@
M3&]A9"!C=7-T;VT@<')E9F5R96YC92!H86YD;&5R<R!F;W(@)&%P<"P@:68@
M<')E<V5N="X@*B\*:68@*&9I;&5?97AI<W1S*"1A<'!B87-E("X@)R]L:6(O
M<')E9G,N<&AP)RDI('L*("`@(')E<75I<F5?;VYC92`D87!P8F%S92`N("<O
M;&EB+W!R969S+G!H<"<["GT*"B\J($EF('1H97)E)W,@;VYL>2!O;F4@<')E
M9D=R;W5P+"!J=7-T('-H;W<@:70N("HO"FEF("AE;7!T>2@D9W)O=7`I("8F
M(&-O=6YT*"1P<F5F1W)O=7!S*2`]/2`Q*2!["B`@("`D9W)O=7`@/2!A<G)A
M>5]K97ES*"1P<F5F1W)O=7!S*3L*("`@("1G<F]U<"`](&%R<F%Y7W!O<"@D
M9W)O=7`I.PI]"@II9B`H)&=R;W5P(#T]("=I9&5N=&ET:65S)RD@>PH@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@)&ED96YT
M:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH)&%P<"`]/2`G:&]R9&4G(#\@
M;G5L;"`Z(&%R<F%Y*"1A<'`L("1A<'`I*3L*("`@(&EF("@D87!P("$]("=H
M;W)D92<I('L*("`@("`@("!I9B`H571I;#HZ;F]N26YP=71687(H)W!R969'
M<F]U<',G*2D@>PH@("`@("`@("`@("`D:V5E<%!R969'<F]U<',@/2`D<')E
M9D=R;W5P<SL*("`@("`@("`@("`@=6YS970H)'!R969'<F]U<',I.PH@("`@
M("`@('T*("`@("`@("!R97%U:7)E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]P
M<F5F<RYP:'`G.PH@("`@("`@("1H;W)D95]M96UB97)S(#T@)'!R969'<F]U
M<'-;)VED96YT:71I97,G75LG;65M8F5R<R==.PH@("`@("`@(&EF("A5=&EL
M.CIN;VY);G!U=%9A<B@G:V5E<%!R969'<F]U<',G*2D@>PH@("`@("`@("`@
M("`D<')E9D=R;W5P<R`]("1K965P4')E9D=R;W5P<SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!U;G-E="@D<')E9D=R;W5P<RD["B`@("`@("`@
M?0H@("`@?0H*("`@(&EF("AI<W-E="@D:&]R9&5?;65M8F5R<RDI('L*("`@
M("`@("`D<')E9D=R;W5P<ULG:61E;G1I=&EE<R==6R=M96UB97)S)UT@/2!A
M<G)A>5]M97)G92@D:&]R9&5?;65M8F5R<RP@)'!R969'<F]U<'-;)VED96YT
M:71I97,G75LG;65M8F5R<R==*3L*("`@('T*"B`@("!S=VET8V@@*%5T:6PZ
M.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I*2!["B`@("!C87-E("=U<&1A=&5?
M<')E9G,G.@H@("`@("`@(&EF("@D<')E9G,M/FES3&]C:V5D*"=D969A=6QT
M7VED96YT:71Y)RDI('L*("`@("`@("`@("`@)&1E9F%U;'0@/2`D:61E;G1I
M='DM/F=E=$1E9F%U;'0H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D9&5F875L="`](%5T:6PZ.F=E=%!O<W0H)V1E9F%U;'1?:61E;G1I='DG
M*3L*("`@("`@("`@("`@)&ED(#T@571I;#HZ9V5T4&]S="@G:61E;G1I='DG
M*3L*("`@("`@("`@("`@:68@*"1I9"`]/2`M,2D@>PH@("`@("`@("`@("`@
M("`@)&ED(#T@)&ED96YT:71Y+3YA9&0H*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1I9"`]/2`M,BD@>PH@("`@("`@("`@("`@("`@)'!R969'<F]U<'-;
M)VED96YT:71I97,G75LG;65M8F5R<R==(#T@87)R87DH)V1E9F%U;'1?:61E
M;G1I='DG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:61E;G1I='DM
M/G-E=$1E9F%U;'0H)&ED*3L*("`@("`@("!]"B`@("`@("`@:68@*%!R969S
M7U5).CIH86YD;&5&;W)M*"1G<F]U<"P@)&ED96YT:71Y*2D@>PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)&ED96YT:71Y+3YV97)I9GDH*3L*("`@("`@("`@
M("`@)&ED96YT:71Y+3YS971$969A=6QT*"1D969A=6QT*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S=6QT+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1I9&5N=&ET>2T^<V%V92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&ED96YT:71Y+3YS971$969A=6QT*"1D969A
M=6QT*3L*("`@("`@("`@("`@)&ED96YT:71Y+3YS879E*"D["B`@("`@("`@
M?0H@("`@("`@('5N<V5T*"1P<F5F1W)O=7!S*3L*("`@("`@("!R97%U:7)E
M("1A<'!B87-E("X@)R]C;VYF:6<O<')E9G,N<&AP)SL*("`@("`@("!B<F5A
M:SL*"B`@("!C87-E("=D96QE=&5?:61E;G1I='DG.@H@("`@("`@("1I9"`]
M("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)VED)RD["B`@("`@("`@)&1E;&5T
M961?:61E;G1I='D@/2`D:61E;G1I='DM/F1E;&5T92@D:60I.PH@("`@("`@
M('5N<V5T*"1?<')E9G-;)V1E9F%U;'1?:61E;G1I='DG75LG96YU;2==6R1I
M9%TI.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4
M:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(BDL("1D96QE
M=&5D7VED96YT:71Y6S!=6R=I9"==*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@
M("`@("!B<F5A:SL*"B`@("!C87-E("=C:&%N9V5?9&5F875L=%]I9&5N=&ET
M>2<Z"B`@("`@("`@)&1E9F%U;'1?:61E;G1I='D@/2`D:61E;G1I='DM/G-E
M=$1E9F%U;'0H571I;#HZ9V5T1F]R;41A=&$H)VED)RDI.PH@("`@("`@("1I
M9&5N=&ET>2T^<V%V92@I.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N<W5C8V5S<R<I
M.PH@("`@("`@(&)R96%K.PH@("`@?0I](&5L<V5I9B`H4')E9G-?54DZ.FAA
M;F1L949O<FTH)&=R;W5P+"`D<')E9G,I*2!["B`@("!R97%U:7)E("1A<'!B
M87-E("X@)R]C;VYF:6<O<')E9G,N<&AP)SL*?0H*+RH@4VAO=R!T:&4@54DN
M("HO"E!R969S7U5).CIG96YE<F%T955)*"1G<F]U<"D["@IR97%U:7)E("1R
M96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N
M+69O;W1E<BYI;F,G.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<')O8FQE;2YP
M:'``````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C4V
M-@`Q,#0Q-S,V,S`P-P`P,C`T,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M<V5R=FEC97,O<')O8FQE;2YP:'`L=B`R+C$Q-"XX+C@@,C`P-B\P,2\Q-B`Q
M-#HR-#HP,R!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*+RH@4V5N9"!T:&4@8G)O=W-E<B!B86-K('1O
M('1H92!C;W)R96-T('!A9V4N("HO"F9U;F-T:6]N(%]R971U<FY4;U!A9V4H
M*0I["B`@("`D=7)L(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E='5R;E]U<FPG
M+"!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O
M;W0G+"`G:&]R9&4G*2`N("<O;&]G:6XN<&AP)RP@=')U92DI.PH@("`@:&5A
M9&5R*"=,;V-A=&EO;CH@)R`N('-T<E]R97!L86-E*"<F86UP.R<L("<F)RP@
M)'5R;"DI.PH@("`@97AI=#L*?0H*0&1E9FEN92@G05542%](04Y$3$52)RP@
M=')U92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B
M87-E+G!H<"<["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O=F5R
M<VEO;BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<[
M"@II9B`H(4AO<F1E.CIS:&]W4V5R=FEC92@G<')O8FQE;2<I*2!["B`@("!?
M<F5T=7)N5&]086=E*"D["GT*"B1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN
M9VQE=&]N*"D["B1E;6%I;"`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9R;VU?
M861D<B<I.PII9B`H(21E;6%I;"D@>PH@("`@)&5M86EL(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V5M86EL)RP@075T:#HZ9V5T075T:"@I*3L*?0HD;65S<V%G
M92`](%5T:6PZ.F=E=$9O<FU$871A*"=M97-S86=E)RP@)R<I.PHD;F%M92`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=N86UE)RP@)&ED96YT:71Y+3YG971686QU
M92@G9G5L;&YA;64G*2D["B1S=6)J96-T(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W-U8FIE8W0G+"`G)RD["@HD86-T:6]N240@/2!5=&EL.CIG971&;W)M1&%T
M82@G86-T:6]N240G*3L*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G<V5N
M9%]P<F]B;&5M7W)E<&]R="<Z"B`@("!I9B`H)'-U8FIE8W0@)B8@)&UE<W-A
M9V4I('L*("`@("`@("`O+R!4:&ES(&ES(&YO="!A(&=E='1E>'0@<W1R:6YG
M(&]N('!U<G!O<V4N"B`@("`@("`@)')E;6]T92`]("@A96UP='DH)%]315)6
M15);)U)%34]415](3U-4)UTI*2`_("1?4T525D526R=214U/5$5?2$]35"==
M(#H@)%]315)615);)U)%34]415]!1$12)UT["B`@("`@("`@)'5S97)?86=E
M;G0@/2`D7U-%4E9%4ELG2%144%]54T527T%'14Y4)UT["B`@("`@("`@)&)O
M9'D@/2`B5&AI<R!P<F]B;&5M(')E<&]R="!W87,@<F5C96EV960@9G)O;2`D
M<F5M;W1E+B`B("X*("`@("`@("`@("`@(E1H92!U<V5R(&-L:6-K960@=&AE
M('!R;V)L96T@<F5P;W)T(&QI;FL@9G)O;2!T:&4@9F]L;&]W:6YG(&QO8V%T
M:6]N.EQN(B`N"B`@("`@("`@("`@(%5T:6PZ.F=E=$9O<FU$871A*"=R971U
M<FY?=7)L)RP@)TYO(')E<75E<W1I;F<@<&%G92<I("X*("`@("`@("`@("`@
M(EQN86YD(&ES('5S:6YG('1H92!F;VQL;W=I;F<@8G)O=W-E<CI<;B1U<V5R
M7V%G96YT7&Y<;B(@+@H@("`@("`@("`@("!S=')?<F5P;&%C92@B7')<;B(L
M(")<;B(L("1M97-S86=E*3L*"B`@("`@("`@+R\@1&5F875L="!T;R!A(')E
M;&%T:79E;'D@<F5A<V]N86)L92!E;6%I;"!A9&1R97-S+@H@("`@("`@(&EF
M("@A)&5M86EL*2!["B`@("`@("`@("`@("1E;6%I;"`]("=H;W)D92UP<F]B
M;&5M0"<@+B`D8V]N9ELG<')O8FQE;7,G75LG;6%I;&1O;6%I;B==.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG<')O8FQE;7,G75LG
M=&EC:V5T<R==*2`F)@H@("`@("`@("`@("`D<F5G:7-T<GDM/FAA<TUE=&AO
M9"@G=&EC:V5T<R]A9&14:6-K970G*2D@>PH@("`@("`@("`@("`D:6YF;R`]
M(&%R<F%Y7VUE<F=E*"1C;VYF6R=P<F]B;&5M<R==6R=T:6-K971?<&%R86US
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W-U
M;6UA<GDG(#T^("1S=6)J96-T+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C;VUM96YT)R`]/B`D8F]D>2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<E]E;6%I;"<@/3X@)&5M
M86EL*2D["B`@("`@("`@("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/F-A;&PH
M)W1I8VME=',O861D5&EC:V5T)RP@87)R87DH)&EN9F\I*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S=6QT*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(%]R971U<FY4;U!A9V4H
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G.PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344O2&5A9&5R<RYP:'`G.PH@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O365S<V%G92YP:'`G.PH*
M("`@("`@("`@("`@+R\@061D('5S97(G<R!N86UE('1O('1H92!E;6%I;"!A
M9&1R97-S(&EF('!R;W9I9&5D+@H@("`@("`@("`@("!I9B`H)&YA;64I('L*
M("`@("`@("`@("`@("`@($!L:7-T*"1M86EL8F]X+"`D:&]S="D@/2!`97AP
M;&]D92@G0"<L("1E;6%I;"P@,BD["B`@("`@("`@("`@("`@("!I9B`H96UP
M='DH)&AO<W0I*2!["B`@("`@("`@("`@("`@("`@("`@)&AO<W0@/2`D8V]N
M9ELG<')O8FQE;7,G75LG;6%I;&1O;6%I;B==.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&5M86EL(#T@34E-13HZ<F9C.#(R5W)I=&5!
M9&1R97-S*"1M86EL8F]X+"`D:&]S="P@)&YA;64I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D;7-G7VAE861E<G,@/2`F;F5W($U)345?2&5A9&5R
M<R@I.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9%)E8V5I=F5D2&5A
M9&5R*"D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D365S<V%G94ED
M2&5A9&5R*"D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D06=E;G1(
M96%D97(H*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H
M)T1A=&4G+"!D871E*"=R)RDI.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M
M/F%D9$AE861E<B@G5&\G+"`D8V]N9ELG<')O8FQE;7,G75LG96UA:6PG72D[
M"B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=3=6)J96-T
M)RP@7R@B6U!R;V)L96T@4F5P;W)T72(I("X@)R`G("X@)'-U8FIE8W0I.PH@
M("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E<B@G1G)O;2<L("1E
M;6%I;"D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=3
M96YD97(G+"`G:&]R9&4M<')O8FQE;4`G("X@)&-O;F9;)W!R;V)L96US)UU;
M)VUA:6QD;VUA:6XG72D["@H@("`@("`@("`@("`D;6EM92`]("9N97<@34E-
M15]-97-S86=E*"D["B`@("`@("`@("`@("1M:6UE+3YA9&1087)T*&YE=R!-
M24U%7U!A<G0H)W1E>'0O<&QA:6XG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%-T<FEN9SHZ=W)A<"@D8F]D>2P@.#`L(")<
M;B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($Y,4SHZ9V5T0VAA<G-E="@I*2D["B`@("`@("`@("`@("1M<V=?:&5A9&5R
M<RT^861D34E-14AE861E<G,H)&UI;64I.PH*("`@("`@("`@("`@)&UA:6Q?
M9')I=F5R(#T@)&-O;F9;)VUA:6QE<B==6R=T>7!E)UT["B`@("`@("`@("`@
M("1M86EL7W!A<F%M<R`]("1C;VYF6R=M86EL97(G75LG<&%R86US)UT["B`@
M("`@("`@("`@(&EF("@D;6%I;%]D<FEV97(@/3T@)W-M='`G("8F("1M86EL
M7W!A<F%M<ULG875T:"==("8F"B`@("`@("`@("`@("`@("!E;7!T>2@D;6%I
M;%]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@("`@("`@("!I9B`H
M075T:#HZ9V5T075T:"@I*2!["B`@("`@("`@("`@("`@("`@("`@)&UA:6Q?
M<&%R86US6R=U<V5R;F%M92==(#T@075T:#HZ9V5T075T:"@I.PH@("`@("`@
M("`@("`@("`@("`@("1M86EL7W!A<F%M<ULG<&%S<W=O<F0G72`]($%U=&@Z
M.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RD["B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H(65M<'1Y*"1C;VYF6R=P<F]B;&5M<R==6R=U<V5R;F%M92==
M*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("%E;7!T>2@D8V]N9ELG
M<')O8FQE;7,G75LG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@("`@("`@
M("`D;6%I;%]P87)A;7-;)W5S97)N86UE)UT@/2`D8V]N9ELG<')O8FQE;7,G
M75LG=7-E<FYA;64G73L*("`@("`@("`@("`@("`@("`@("`D;6%I;%]P87)A
M;7-;)W!A<W-W;W)D)UT@/2`D8V]N9ELG<')O8FQE;7,G75LG<&%S<W=O<F0G
M73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*"%I<U]A*"1S96YT(#T@)&UI;64M/G-E;F0H)&-O;F9;)W!R;V)L
M96US)UU;)V5M86EL)UTL("1M<V=?:&5A9&5R<RP@)&UA:6Q?9')I=F5R+"`D
M;6%I;%]P87)A;7,I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`O*B!792!S=6-C965D960N(%)E='5R;B!T;R!P<F5V:6]U<R!P86=E(&%N
M9"!E>&ET('1H:7,@<V-R:7!T+B`J+PH@("`@("`@("`@("`@("`@7W)E='5R
M;E1O4&%G92@I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<V5N="D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V-A;F-E;%]P<F]B
M;&5M7W)E<&]R="<Z"B`@("!?<F5T=7)N5&]086=E*"D["GT*"B1T:71L92`]
M(%\H(E!R;V)L96T@1&5S8W)I<'1I;VXB*3L*)&UE;G4@/2`F;F5W($UE;G4H
M2$]21$5?345.55]-05-+7T%,3"`F('Y(3U)$15]-14Y57TU!4TM?4%)%1E,I
M.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI
M;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O;65N=2]M96YU+FEN
M8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]
M/B`G<W1A='5S)RDI.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O<')O
M8FQE;2]P<F]B;&5M+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'``````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S<U,0`Q,#0Q-S,V,S`P-P`P,C$V-C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`L=B`Q+C4N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(Y.C$P(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UA<FMO($1J=6MI8R`\;6%R
M:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)T%55$A?
M2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L97,N<&AP)SL*"B\O
M($UA:V4@<W5R92!A=71H(&)A8VME;F0@86QL;W=S('!A<W-W;W)D<R!T;R!B
M92!R97-E="X*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H
M)UU;)V1R:79E<B==*3L*:68@*"$D875T:"T^:&%S0V%P86)I;&ET>2@G<F5S
M971P87-S=V]R9"<I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@:&5A
M9&5R*"=,;V-A=&EO;CH@)R`N($%U=&@Z.F=E=$QO9VEN4V-R965N*"<G+"!5
M=&EL.CIG971&;W)M1&%T82@G=7)L)RDI*3L*("`@(&5X:70["GT*"B1V87)S
M(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PH*)'1I=&QE
M(#T@7R@B4F5S970@66]U<B!087-S=V]R9"(I.PHD9F]R;2`]("9(;W)D95]&
M;W)M.CIS:6YG;&5T;VXH)TAO<F1E4VEG;G5P1F]R;2<L("1V87)S+"`D=&ET
M;&4I.PHD9F]R;2T^<V5T0G5T=&]N<RA?*")#;VYT:6YU92(I*3L*"B\J(%-E
M="!U<"!T:&4@9FEE;&1S(&9O<B!T:&4@=7-E<FYA;64@86YD(&%L=&5R;F%T
M92!E;6%I;"X@*B\*)&9O<FTM/F%D9$AI9&1E;B@G)RP@)W5R;"<L("=T97AT
M)RP@9F%L<V4I.PHD=B`]("8D9F]R;2T^861D5F%R:6%B;&4H7R@B57-E<FYA
M;64B*2P@)W5S97)N86UE)RP@)W1E>'0G+"!T<G5E*3L*)'8M/G-E=$]P=&EO
M;B@G=')A8VMC:&%N9V4G+"!T<G5E*3L*)&9O<FTM/F%D9%9A<FEA8FQE*%\H
M(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(BDL("=E;6%I;"<L("=E;6%I;"<L
M('1R=64I.PHD8V%N7W9A;&ED871E(#T@9F%L<V4["@HO*B!)9B!A('5S97)N
M86UE(&AA<R!B965N('-U<'!L:65D('1R>2!F971C:&EN9R!T:&4@<')E9G,@
M<W1O<F5D(&EN9F\N("HO"FEF("@D=7-E<FYA;64@/2`D=F%R<RT^9V5T*"=U
M<V5R;F%M92<I*2!["B`@("`D<')E9G,@/2`F4')E9G,Z.G-I;F=L971O;B@D
M8V]N9ELG<')E9G,G75LG9')I=F5R)UTL("=H;W)D92<L("1U<V5R;F%M92P@
M)R<L(&YU;&PL(&9A;'-E*3L*("`@("1P<F5F<RT^<F5T<FEE=F4H*3L*("`@
M("1E;6%I;"`]("1P<F5F<RT^9V5T5F%L=64H)V%L=&5R;F%T95]E;6%I;"<I
M.PH@("`@+RH@1&]E<R!T:&4@86QT97)N871E(&5M86EL('-T;W)E9"!I;B!P
M<F5F<R!M871C:"!T:&4@;VYE('-U8FUI='1E9#\@*B\*("`@(&EF("@D=F%R
M<RT^9V5T*"=E;6%I;"<I(#T]("1E;6%I;"D@>PH@("`@("`@("1C86Y?=F%L
M:61A=&4@/2!T<G5E.PH@("`@("`@("1F;W)M+3YS971"=71T;VYS*%\H(E)E
M<V5T(%!A<W-W;W)D(BDI.PH@("`@("`@("1Q=65S=&EO;B`]("1P<F5F<RT^
M9V5T5F%L=64H)W-E8W5R:71Y7W%U97-T:6]N)RD["B`@("`@("`@)&9O<FTM
M/F%D9%9A<FEA8FQE*"1Q=65S=&EO;BP@)W%U97-T:6]N)RP@)V1E<V-R:7!T
M:6]N)RP@9F%L<V4I.PH@("`@("`@("1F;W)M+3YA9&1687)I86)L92A?*")!
M;G-W97(B*2P@)V%N<W=E<B<L("=T97AT)RP@=')U92D["B`@("!](&5L<V4@
M>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*?0H*+RH@5F%L:61A=&4@
M=&AE(&9O<FTN("HO"FEF("@D8V%N7W9A;&ED871E("8F("1F;W)M+3YV86QI
M9&%T92@D=F%R<RDI('L*("`@("1F;W)M+3YG971);F9O*"1V87)S+"`D:6YF
M;RD["@H@("`@+RH@1F5T8V@@=F%L=65S(&9R;VT@<')E9G,@9F]R('-E;&5C
M=&5D('5S97(N("HO"B`@("`D86YS=V5R(#T@)'!R969S+3YG971686QU92@G
M<V5C=7)I='E?86YS=V5R)RD["@H@("`@+RH@0VAE8VL@=&AE(&=I=F5N('9A
M;'5E<R!W:71H="!T:&4@<')E9G,@<W1O<F5D(&]N97,N("HO"B`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH@("`@:68@*"1E;6%I;"`]
M/2`D:6YF;ULG96UA:6PG72`F)B!3=')I;F<Z.FQO=V5R*"1A;G-W97(I(#T]
M(%-T<FEN9SHZ;&]W97(H)&EN9F];)V%N<W=E<B==*2D@>PH@("`@("`@("\J
M($EN9F\@;6%T8VAE<RP@<V\@<F5S970@=&AE('!A<W-W;W)D+B`J+PH@("`@
M("`@("1P87-S=V]R9"`]("1A=71H+3YR97-E=%!A<W-W;W)D*"1I;F9O6R=U
M<V5R;F%M92==*3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+G!H<"<[
M"B`@("`@("`@)&UA:6QE<B`]($UA:6PZ.F9A8W1O<GDH)&-O;F9;)VUA:6QE
M<B==6R=T>7!E)UTL("1C;VYF6R=M86EL97(G75LG<&%R86US)UTI.PH*("`@
M("`@("`O*B!3970@=7`@=&AE(&5M86EL(&AE861E<G,@86YD(&)O9'DN("HO
M"B`@("`@("`@)&AE861E<G-;)T9R;VTG72`]("1E;6%I;#L*("`@("`@("`D
M:&5A9&5R<ULG5&\G72`]("1E;6%I;#L*("`@("`@("`D<F5C:7!I96YT<UM=
M(#T@)&AE861E<G-;)U1O)UT["B`@("`@("`@)&AE861E<G-;)U-U8FIE8W0G
M72`](%\H(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B*3L*("`@("`@
M("`D8F]D>2`]('-P<FEN=&8H7R@B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<R(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<L("=H;W)D92<I+"`D
M<&%S<W=O<F0I.PH@("`@("`@("1M86EL97(M/G-E;F0H)')E8VEP:65N=',L
M("1H96%D97)S+"`D8F]D>2D["@H@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H7R@B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N(BDL
M("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@
M)R`N($%U=&@Z.F=E=$QO9VEN4V-R965N*"<G+"`D:6YF;ULG=7)L)UTI*3L*
M("`@("`@("!E>&ET.PH@("`@?2!E;'-E('L*("`@("`@("`O*B!);F9O('-U
M8FUI='1E9"!D;V5S(&YO="!M871C:"!W:&%T(&ES(&EN('!R969S+"!R961I
M<F5C="!U<V5R(&)A8VL*("`@("`@("`@*B!T;R!L;V=I;BX@*B\*("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*?0H*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF
M:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G
M*2D["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PHD
M<F5N9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H*3L*)&9O<FTM
M/G)E;F1E<D%C=&EV92@D<F5N9&5R97(L("1V87)S+"`G<F5S971P87-S=V]R
M9"YP:'`G+"`G<&]S="<I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M8V]M;6]N+69O;W1E<BYI;F,G.PH``````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O=&]G9VQE7VIS+G!H
M<```````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$S,0`Q
M,#0Q-S,V,S`P-P`P,C`W,C``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($AO<F1E($IA=F%38W)I<'0@
M5&]G9VQE+@H@*@H@*B!4:&ES('-C<FEP="!W:6QL(&1I<V%B;&4@<&5R;6%N
M96YT;'D@=&AE(&IA=F%S8W)I<'0@8GD@<W1O<FEN9R!A('9A;'5E(&EN"B`J
M(&EN('1H92!S97-S:6]N+"!W:&EC:"!W:6QL(&]V97)R:61E(&%N>2!A=71O
M;6%T:6,@9&5T96-T:6]N(&]F(&IA=F%S8W)I<'0*("H@<W5P<&]R="!I;B!T
M:&4@8G)O=W-E<BX*("H@5&\@<F4M96YA8FQE('1H92!A=71O;6%T:6,@9&5T
M96-T:6]N+"!T:&4@<V-R:7!T('=I;&P@=6YS970@=&AE('-E<W-I;VX*("H@
M=F%R:6%B;&4N"B`J"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O=&]G9VQE
M7VIS+G!H<"QV(#$N,2XR+C$@,C`P-2\Q,"\Q."`Q,3HS-#HP,2!J86X@17AP
M("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"B1R96=I<W1R>2`]("9296=I<W1R
M>3HZ<VEN9VQE=&]N*"D["@HO*B!%;F%B;&4@;W(@9&ES86)L93\@*B\*:68@
M*%5T:6PZ.F=E=$9O<FU$871A*"=V86QU92<I*2!["B`@("`O*B!%;F%B;&EN
M9RP@<V\@<F5M;W9E(&%N>2!S97-S:6]N('-E='1I;F<N("HO"B`@("!U;G-E
M="@D7U-%4U-)3TY;)V-A;&QB86-K<R==6R=B<F]W<V5R+F1I<V%B;&5*879A
M<V-R:7!T)UTI.PI](&5L<V4@>PH@("`@+RH@1&ES86)L:6YG+"!S;R!A9&0@
M82!C86QL8F%C:R!F=6YC=&EO;B!T;R!T:&4@<V5S<VEO;BX@*B\*("`@("1?
M4T534TE/3ELG8V%L;&)A8VMS)UU;)V)R;W=S97(N9&ES86)L94IA=F%S8W)I
M<'0G72`]('1R=64["GT*"B\J(%)E='5R;B!B86-K('1O('1H92!O<FEG:6YA
M=&EN9R!54DPN("HO"B1U<FP@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD[
M"FAE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ=7)L*"1U<FPL('1R=64I
M*3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]L86YG=6%G92YP:'``````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,S4W`#$P-#$W,S8S,#`W`#`R,#4S-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@4V-R:7!T('1O('-E="!T:&4@;F5W(&QA;F=U86=E+@H@*@H@*B`D
M2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+VQA;F=U86=E+G!H<"QV(#$N-2XQ,BXS
M(#(P,#8O,#$O,#$@,C$Z,CDZ,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O;&EB+V)A<V4N<&AP)SL*"B\J(%-E="!T:&4@;&%N9W5A9V4N("HO"B1?
M4T534TE/3ELG:&]R9&5?;&%N9W5A9V4G72`]($Y,4SHZ<V5L96-T*"D["B1P
M<F5F<RT^<V5T5F%L=64H)VQA;F=U86=E)RP@)%]315-324].6R=H;W)D95]L
M86YG=6%G92==*3L*"B\J(%)E9&ER96-T('1O('1H92!U<FP@;W(@;&]G:6X@
M<&%G92!I9B!N;VYE(&=I=F5N+B`J+PHD=7)L(#T@571I;#HZ9V5T1F]R;41A
M=&$H)W5R;"<I.PII9B`H96UP='DH)'5R;"DI('L*("`@("1U<FP@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)VEN9&5X+G!H<"<L('1R=64I.PI]"FAE861E
M<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T96UP;&%T97,O````````````````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$Q`#`Q-C0P
M-@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B\`````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C,P,3$`,#$W-#<V`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R\`````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,``P,C$P,30`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8P```````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S$S`#$P-#$W,S8S,#$P
M`#`R,S(T,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\9F]R;2!N86UE/2)A9&1?8VAI;&0B(&UE=&AO9#TB<&]S="(@86-T
M:6]N/2)G<F]U<',N<&AP(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M86-T:6]N240B('9A;'5E/2)A9&1C:&EL9&9O<FTB("\^"CQI;G!U="!T>7!E
M/2)H:61D96XB(&YA;64](F-I9"(@=F%L=64](CP_<&AP(&5C:&\@)&-I9"`_
M/B(@+SX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"@H\:#$@8VQA<W,]
M(FAE861E<B(^"B`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V=R;W5P+G!N9R<I
M(#\^)FYB<W`[/#]P:'`@<')I;G1F*%\H(D%D9"!A(&-H:6QD(&=R;W5P('1O
M(%PB)7-<(B(I+"`D9VYA;64I(#\^"CPO:#$^"@H\:6YP=70@='EP93TB=&5X
M="(@;F%M93TB8VAI;&0B("\^"CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S
M/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D%D9"(I(#\^(B`O/@H\
M+V9O<FT^"CQB<B`O/@H`````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3$P-P`Q,#0Q-S,V,S`Q,``P,C(W-#4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/&9O<FT@
M;F%M93TB9&5L971E(B!M971H;V0](G!O<W0B(&%C=&EO;CTB9W)O=7!S+G!H
M<"(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU
M93TB9&5L971E9F]R;2(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M8VED(B!V86QU93TB/#]P:'`@96-H;R`D9W)O=7`M/F=E=$ED*"D@/SXB("\^
M"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H*/&@Q(&-L87-S/2)H96%D
M97(B/@H@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=G<F]U<"YP;F<G*2`_/B9N
M8G-P.SP_<&AP('!R:6YT9BA?*")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(BDL("1G<F]U<"T^
M9V5T4VAO<G1.86UE*"DI(#\^"CPO:#$^"@H\:6YP=70@='EP93TB<W5B;6ET
M(B!C;&%S<STB8G5T=&]N(B!N86UE/2)C;VYF:7)M(B!V86QU93TB/#]P:'`@
M96-H;R!?*")$96QE=&4B*2`_/B(@+SX*/&EN<'5T('1Y<&4](G-U8FUI="(@
M8VQA<W,](F)U='1O;B(@;F%M93TB8V]N9FER;2(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B0V%N8V5L(BD@/SXB("\^"CPO9F]R;3X*/&)R("\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8P``````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`T-``Q,#0Q-S,V,S`Q,``P,C(T
M,S(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&9O<FT@;F%M93TB961I=%]G<F]U<"(@;65T:&]D/2)P;W-T(B!A8W1I;VX]
M(F=R;W5P<RYP:'`B/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I
M;VY)1"(@=F%L=64](F5D:71F;W)M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N
M(B!N86UE/2)C:60B('9A;'5E/2(\/W!H<"!E8VAO("1G<F]U<"T^9V5T260H
M*2`_/B(@+SX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"@H\:#$@8VQA
M<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R
M;W5P+3YG9713:&]R=$YA;64H*2D@/SX*/"]H,3X*"CQL86)E;"!F;W(](F5M
M86EL(CX\/W!H<"!E8VAO(%\H(D5M86EL($%D9')E<W,B*2`_/CPO;&%B96P^
M"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)E;6%I;"(@:60](F5M86EL(B!S
M:7IE/2(U,"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M9W)O=7`M/F=E="@G96UA:6PG*2D@/SXB("\^"CQB<B`O/@H\8G(@+SX*"CQH
M,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G9W)O
M=7`N<&YG)RD@+B`G)FYB<W`[)R`N(%\H(DUE;6)E<G,B*2`_/@H\+V@Q/@H*
M/'1A8FQE(&-L87-S/2)L:6YE9%)O=R!N;W=R87`B(&-E;&QS<&%C:6YG/2(P
M(B!W:61T:#TB,3`P)2(^"B`\='(@8VQA<W,](F-O;G1R;VPB/@H@(#QT:"!W
M:61T:#TB,3`E(B!C;&%S<STB;&5F=$%L:6=N(CX\/W!H<"!E8VAO(%\H(E5S
M97(B*2`_/CPO=&@^"B`@/'1H('=I9'1H/2(Y,"4B(&-L87-S/2)L969T06QI
M9VXB/CP_<&AP(&5C:&\@7R@B4F5M;W9E(BD@/SX\+W1H/@H@/"]T<CX*/#]P
M:'`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*3H@/SX*(#QT<CX*("`\=&0^
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_/CPO=&0^"B`@
M/'1D/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB<F5M;W9E6SP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SY=(B`O/CPO=&0^"B`\
M+W1R/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H\8G(@+SX*"CQH
M,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G=7-E
M<BYP;F<G*2`N("<F;F)S<#LG("X@7R@B061D(&YE=R!M96UB97)S(BD@/SX*
M/"]H,3X*/#]P:'`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T)RDI
M.B`_/@H\<V5L96-T(&YA;64](FYE=U]U<V5R6UTB(&UU;'1I<&QE/2)M=6QT
M:7!L92(^"CP_<&AP(&9O<F5A8V@@*"1U<V5R7VQI<W0@87,@)'5S97(I('L@
M:68@*"%I;E]A<G)A>2@D=7-E<BP@)'5S97)S*2D@>R`_/@H@/&]P=&EO;B!V
M86QU93TB/#]P:'`@96-H;R`D=7-E<B`_/B(^/#]P:'`@96-H;R`D=7-E<B`_
M/CPO;W!T:6]N/@H\/W!H<"!]('T@/SX*/"]S96QE8W0^"CP_<&AP(&5L<V4Z
M(#\^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)N97=?=7-E<B(@+SX*/#]P
M:'`@96YD:68[(#\^"CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T
M;VXB('9A;'5E/2(\/W!H<"!P<FEN=&8H7R@B4V%V92!<(B5S7"(B*2P@)&=R
M;W5P+3YG9713:&]R=$YA;64H*2D@/SXB("\^"CQB<B`O/@H\8G(@+SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E;7!L871E<R]A9&UI;B]S971U<"\`````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`,#(P-C,V`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,S,@`Q,#0Q
M-S,V,S`Q,0`P,C(W-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/'1A9SIN;W1I9GD@+SX*"CQT86<Z9F]R;2`O/@H*/&EF
M.G!H<#X*/&)R("\^"CQH,2!C;&%S<STB:&5A9&5R(CX*(#QG971T97AT/D=E
M;F5R871E9"!#;V1E/"]G971T97AT/@H@/'-M86QL/EL@/'1A9SID:69F7W!O
M<'5P("\^(%T\+W-M86QL/@H\+V@Q/@H\=&5X=&%R96$@<W1Y;&4](G=I9'1H
M.C$P,"4B(')O=W,](C(P(CX\=&%G.G!H<"`O/CPO=&5X=&%R96$^"CPO:68Z
M<&AP/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6P`````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,3<`,3`T,3<S-C,P,3$`,#(R
M-#,T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QI9CID:69F<SX*/&QO;W`Z9&EF9G,^"CQH,2!C;&%S<STB:&5A9&5R(B!I
M9#TB/'1A9SID:69F<RYA<'`@+SXB/@H@/'1A9SID:69F<RYA<'`@+SX@/'-M
M86QL/EL@/'1A9SID:69F<RYT;V=G;&5?<F5N9&5R97(@+SX@73PO<VUA;&P^
M"CPO:#$^"CQP<F4@8VQA<W,](G1E>'0B/CQT86<Z9&EF9G,N9&EF9B`O/CPO
M<')E/@H\+VQO;W`Z9&EF9G,^"CQE;'-E.F1I9F9S/@H\<"!C;&%S<STB;F]T
M:6-E(CX\9V5T=&5X=#Y.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+CPO9V5T=&5X=#X\+W`^"CPO96QS
M93ID:69F<SX*/"]I9CID:69F<SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;```````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#8S`#$P-#$W,S8S,#$Q`#`R,C8S,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\=&%G.FYO=&EF
M>2`O/@H*/'1A8FQE(&-L87-S/2)S=')I<&5D(B!C96QL<W!A8VEN9STB,"(@
M=VED=&@](C$P,"4B/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB:&5A9&5R(CX*
M("`@("`@/&=E='1E>'0^07!P;&EC871I;VX\+V=E='1E>'0^"B`@("`\+W1D
M/@H@("`@/'1D(&-L87-S/2)H96%D97(B/@H@("`@("`F;F)S<#L*("`@(#PO
M=&0^"B`@("`\=&0@8VQA<W,](FAE861E<B(^"B`@("`@(#QG971T97AT/E-T
M871U<SPO9V5T=&5X=#X*("`@(#PO=&0^"B`@/"]T<CX*("`\;&]O<#IA<'!S
M/@H@(#QT<CX*("`@(#QT9#X*("`@("`@/'1A9SIA<'!S+FYA;64@+SX*("`@
M("`@/'1A9SIA<'!S+G9E<G-I;VX@+SX*("`@(#PO=&0^"B`@("`\=&0@86QI
M9VX](F-E;G1E<B(^"B`@("`@(#QT86<Z87!P<RYC;VYF("\^"B`@("`\+W1D
M/@H@("`@/'1D/@H@("`@("`\=&%G.F%P<',N<W1A='5S("\^"B`@("`\+W1D
M/@H@(#PO='(^"B`@/"]L;V]P.F%P<',^"CPO=&%B;&4^"CQB<B`O/@H*/'1A
M8FQE(&ED/2)U<&1A=&4B(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^
M"B`@/'1R('9A;&EG;CTB=&]P(CX*("`@(#QT9"!W:61T:#TB-3`E(CX*("`@
M("`@/&EF.F%C=&EO;G,^"B`@("`@(#QH,2!C;&%S<STB:&5A9&5R(CX*("`@
M("`@(#QG971T97AT/E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4\
M+V=E='1E>'0^"B`@("`@(#PO:#$^"B`@("`@(#QT86)L92!C;&%S<STB<W1R
M:7!E9"(@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@("`@(#QL
M;V]P.F%C=&EO;G,^"B`@("`@("`@/'1R/@H@("`@("`@("`\=&0^"B`@("`@
M("`@("`\=&%G.F%C=&EO;G,N:6-O;B`O/B`\=&%G.F%C=&EO;G,N;&EN:R`O
M/@H@("`@("`@("`\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`\+VQO;W`Z
M86-T:6]N<SX*("`@("`@/"]T86)L93X*("`@("`@/"]I9CIA8W1I;VYS/@H@
M("`@/"]T9#X*("`@(#QT9"!W:61T:#TB-3`E(CX*("`@("`@/&EF.F9T<&9O
M<FT^"B`@("`@("`@/'1A9SIF='!F;W)M("\^"B`@("`@(#PO:68Z9G1P9F]R
M;3X*("`@(#PO=&0^"B`@/"]T<CX*/"]T86)L93X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+P``
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C,P,3$`,#(P-#4T`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+V%D;6EN+W5S97(O861D+FEN8P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#$W-``Q,#0Q-S,V,S`Q,0`P,C$V-S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*)')E;F1E<F5R
M(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["B1A9&1&;W)M+3YR96YD
M97)!8W1I=F4H)')E;F1E<F5R+"`D=F%R<RP@2&]R9&4Z.G-E;&95<FPH*2P@
M)W!O<W0G*3L*/SX*/&)R("\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U
M-S4`,3`T,3<S-C,P,3$`,#(R-C,Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP
M(&5C:&\@7R@B4&5N9&EN9R!3:6=N=7!S.B(I(#\^"CPO:#$^"@H\/W!H<"`D
M86QL475E=65D(#T@)'-I9VYU<"T^9V5T475E=65D4VEG;G5P<R@I.R!I9B`H
M(6-O=6YT*"1A;&Q1=65U960I*3H@/SX*/&1I=B!C;&%S<STB=&5X="(^/&5M
M/CP_<&AP(&5C:&\@7R@B3F\@<&5N9&EN9R!S:6=N=7!S+B(I(#\^/"]E;3X\
M+V1I=CX*/#]P:'`@96QS93H@/SX*/'1A8FQE(&-L87-S/2)S=')I<&5D(B!W
M:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/@H@/'1R(&-L87-S/2)I=&5M
M(CX*("`\=&@^)FYB<W`[/"]T:#X*("`\=&@^)FYB<W`[/"]T:#X*("`\=&@^
M/#]P:'`@96-H;R!?*")5<V5R;F%M92(I(#\^/"]T:#X*("`\=&@@=VED=&@]
M(C$P,"4B/CP_<&AP(&5C:&\@7R@B1&%T92!296-E:79E9"(I(#\^/"]T:#X*
M(#PO='(^"CP_<&AP(&9O<F5A8V@@*"1A;&Q1=65U960@87,@)'-I9VYU<"DZ
M(&EF("@D<VEG;G5P+3YG971.86UE*"D@(3T@1$%40512145?4D]/5"DZ("1D
M871A(#T@)'-I9VYU<"T^9V5T1&%T82@I.R`_/@H@/'1R/@H@(#QT9#X*("`@
M/&9O<FT@;65T:&]D/2)P;W-T(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z
M.G-E;&95<FPH*2`_/B(^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)U<V5R7VYA;64B('9A;'5E/2(\/W!H<"!E8VAO("1S:6=N=7`M/F=E=$YA
M;64H*2`_/B(@+SX*("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O
M<FTB('9A;'5E/2)A<'!R;W9E7V8B("\^"B`@("`\:6YP=70@='EP93TB<W5B
M;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")!<'!R
M;W9E(BD@/SXB("\^"B`@(#PO9F]R;3X*("`\+W1D/@H@(#QT9#X*("`@/&9O
M<FT@;65T:&]D/2)P;W-T(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E
M;&95<FPH*2`_/B(^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)U
M<V5R7VYA;64B('9A;'5E/2(\/W!H<"!E8VAO("1S:6=N=7`M/F=E=$YA;64H
M*2`_/B(@+SX*("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O<FTB
M('9A;'5E/2)R96UO=F5Q=65U961?9B(@+SX*("`@(#QI;G!U="!T>7!E/2)S
M=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E
M;6]V92(I(#\^(B`O/@H@("`\+V9O<FT^"B`@/"]T9#X*("`\=&0^/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S:6=N=7`M/F=E=$YA;64H*2D@/SX\
M+W1D/@H@(#QT9#X\/W!H<"!E8VAO(&1A=&4H)UDM32UD($@Z:3IS)RP@)&1A
M=&%;)V1A=&5296-E:79E9"==*2`_/CPO=&0^"B`\+W1R/@H\/W!H<"!E;F1I
M9CL@/SX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]T86)L93X*/#]P:'`@96YD
M:68[(#\^"CQB<B!C;&%S<STB<W!A8V5R(B`O/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R,``Q,#0Q-S,V,S`Q,0`P,C(R,C,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/&9O
M<FT@;F%M93TB8VQE87)U<V5R(B!M971H;V0](G!O<W0B/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)F;W)M(B!V86QU93TB8VQE87(B/@H*/&@Q(&-L
M87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F*%\H(D-L96%R(&]U="!U<V5R
M.B`E<R(I+"`D9E]U<V5R7VYA;64I(#\^"CPO:#$^"CQP(&-L87-S/2)I=&5M
M(CX*(#QS=')O;F<^/#]P:'`@<')I;G1F*%\H(E)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(I+"`D9E]U<V5R7VYA;64I(#\^/"]S=')O;F<^"CPO<#X*/'`@
M8VQA<W,](F-O;G1R;VPB/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,]
M(F)U='1O;B(@;F%M93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*")#
M;&5A<B!U<V5R(BD@/SXB("\^"B`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S
M<STB8G5T=&]N(B!N86UE/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H
M(D-A;F-E;"(I(#\^(B`O/@H\+W`^"CPO9F]R;3X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,`````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,P,``Q,#0Q-S,V,S`Q,0`P
M,C(Q,3,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")5<V5R<R!I
M;B!T:&4@<WES=&5M.B(I(#\^"B`\/W!H<"!I9B`H)&YU;6ET96TI.B`_/@H@
M(#QS;6%L;#Y;/#]P:'`@<')I;G1F*%\H(B5S('1O("5S(&]F("5S(BDL("1S
M=&%R="P@)&5N9"P@)&YU;6ET96TI(#\^73PO<VUA;&P^"B`\/W!H<"!E;F1I
M9CL@/SX*/"]H,3X*"CQD:78@8VQA<W,](FAE861E<F)O>"(^"@H\9&EV(&-L
M87-S/2)C;VYT<F]L(CX*(#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB<V5A
M<F-H(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E;&95<FPH*2`_/B(^
M"B`\/W!H<"!E8VAO(%5T:6PZ.F9O<FU);G!U="@I(#\^"B`\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)P86=E(B!V86QU93TB,"(^"B`\<W1R;VYG/CP_
M<&AP(&5C:&\@7R@B4V5A<F-H(BD@/SXZ/"]S=')O;F<^)FYB<W`["B`\:6YP
M=70@;F%M93TB<V5A<F-H7W!A='1E<FXB('1Y<&4](G1E>'0B('9A;'5E/2(B
M('-I>F4](C4P(B!M87AL96YG=&@](C$P,"(@+SX*(#QI;G!U="!T>7!E/2)S
M=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-E
M87)C:"(I(#\^(B`O/@H@/"]F;W)M/@H\+V1I=CX*"CQT86)L92!C;&%S<STB
M<W1R:7!E9"(@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(CX*/#]P:'`*
M)')E;6]V92`]("1A=71H+3YH87-#87!A8FEL:71Y*"=R96UO=F4G*3L*)'1O
M=&%L(#T@,#L*9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*3H*("`@(&EF("@D
M=&]T86PK*R`\("1M:6X@?'P@)'1O=&%L(#X@)&UA>"D@>PH@("`@("`@(&-O
M;G1I;G5E.PH@("`@?0H_/@H@/'1R/@H\/W!H<"!I9B`H)')E;6]V92DZ(#\^
M"B`@/'1D('=I9'1H/2(Q)2(^/#]P:'`@96-H;R!(;W)D93HZ;&EN:RA(;W)D
M93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W5S97(N<&AP/V9O<FT]<F5M;W9E
M7V8F=7-E<E]N86UE/2<@+B`D=7-E<BDL(%\H(D1E;&5T92(I*2`N($AO<F1E
M.CII;6<H)V1E;&5T92YP;F<G+"!?*")$96QE=&4B*2D@/SX\+V$^/"]T9#X*
M/#]P:'`@96YD:68[(#\^"B`@/'1D('=I9'1H/2(Q)2(^/#]P:'`@96-H;R!(
M;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W5S97(N
M<&AP/V9O<FT]=7!D871E7V8F=7-E<E]N86UE/2<@+B`D=7-E<BDL(%\H(E5P
M9&%T92(I*2`N("!(;W)D93HZ:6UG*"=E9&ET+G!N9R<L(%\H(E5P9&%T92(I
M*2`_/CPO83X\+W1D/@H@(#QT9"!W:61T:#TB,24B/CP_<&AP(&5C:&\@2&]R
M9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]U<V5R+G!H
M<#]F;W)M/6-L96%R7V8F=7-E<E]N86UE/2<@+B`D=7-E<BDL(%\H(D-L96%R
M('5S97(@9&%T82(I*2`N("!(;W)D93HZ:6UG*"=R96QO860N<&YG)RP@7R@B
M0VQE87(@=7-E<B!D871A(BDI(#\^/"]A/CPO=&0^"B`@/'1D(&-L87-S/2)L
M969T06QI9VXB/CP_<&AP(&5C:&\@)'5S97(@/SX\+W1D/@H@/"]T<CX*/#]P
M:'`@96YD9F]R96%C:#L@/SX*/"]T86)L93X*/#]P:'`*:68@*"1N=6UI=&5M
M*2!["B`@("`D<&%G97(@/2`F;F5W($AO<F1E7U5)7U!A9V5R*"=P86=E)RP@
M)'9A<G,L(&%R<F%Y*"=N=6TG(#T^("1T;W1A;"P@)W5R;"<@/3X@)'9I97=U
M<FPL("=P86=E7V-O=6YT)R`]/B`Q,"P@)W!E<G!A9V4G(#T^("1P97)P86=E
M*2D["B`@("!E8VAO("1P86=E<BT^<F5N9&5R*"1P86=E+"`D=&]T86PL("1V
M:65W=7)L*3L*?0H_/@H\+V1I=CX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8P``````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T,C<`,3`T,3<S-C,P,3$`,#(R,C,T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QH
M,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@7R@B061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+B(I(#\^"CPO:#$^"CQP(&-L87-S/2)C;VYT<F]L(CX*
M(#P_<&AP(&5C:&\@7R@B66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"XB*2`_
M/@H\+W`^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP
M;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S4R`#$P-#$W,S8S,#$Q`#`R,C0U-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\:#$@8VQA<W,](FAE
M861E<B(^"B`\/W!H<"!E8VAO(%\H(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(BD@/SX*/"]H,3X*/'`@8VQA<W,](F-O;G1R;VPB/@H@/#]P:'`@96-H
M;R!?*")9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(BD@/SX*/"]P/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8P``````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#<W-0`Q,#0Q-S,V,S`Q,0`P,C(T-3(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&9O<FT@;F%M93TB<F5M;W9E=7-E<B(@
M;65T:&]D/2)P;W-T(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB9F]R
M;2(@=F%L=64](G)E;6]V92(^"@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H
M<"!P<FEN=&8H7R@B4F5M;W9E('5S97(Z("5S(BDL("1F7W5S97)?;F%M92D@
M/SX*/"]H,3X*/'`@8VQA<W,](FET96TB/@H@/'-T<F]N9SX\/W!H<"!P<FEN
M=&8H7R@B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB*2P@)&9?=7-E<E]N86UE*2`_/CPO<W1R;VYG/@H\+W`^
M"CQP(&-L87-S/2)C;VYT<F]L(CX*(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L
M87-S/2)B=71T;VXB(&YA;64](G-U8FUI="(@=F%L=64](CP_<&AP(&5C:&\@
M7R@B4F5M;W9E('5S97(B*2`_/B(@+SX*(#QI;G!U="!T>7!E/2)S=6)M:70B
M(&-L87-S/2)B=71T;VXB(&YA;64](G-U8FUI="(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B0V%N8V5L(BD@/SXB("\^"CPO<#X*/"]F;W)M/@H````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,`````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,#$`,3`T,3<S
M-C,P,3$`,#(S-C0R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QF;W)M(&UE=&AO9#TB<&]S="(@86-T:6]N/2(\/W!H<"!E
M8VAO($AO<F1E.CIS96QF57)L*"D@/SXB/@H\/W!H<"!5=&EL.CIP9F]R;4EN
M<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB9F]R;2(@=F%L
M=64](G)E;6]V97%U975E9"(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB=7-E<E]N86UE(B!V86QU93TB/#]P:'`@96-H;R`D9E]U<V5R7VYA;64@
M/SXB("\^"@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(%\H(E!E
M;F1I;F<@4VEG;G5P<SHB*2`_/@H\+V@Q/@H\<"!C;&%S<STB:71E;2(^"B`\
M/W!H<"!P<FEN=&8H7R@B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B*2P@)&9?=7-E<E]N86UE
M*2`_/@H\+W`^"CQP(&-L87-S/2)C;VYT<F]L(CX*("`\:6YP=70@8VQA<W,]
M(F)U='1O;B(@='EP93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*")2
M96UO=F4B*2`_/B(@+SX*/"]P/@H\+V9O<FT^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,`````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T-#``
M,3`T,3<S-C,P,3$`,#(R-#,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T
M(CX*/"$M+0H*9G5N8W1I;VX@=F%L:61A=&5?=7!D871E*"D*>PH@("`@:68@
M*&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]N86UE+G9A;'5E(#T]("(B*2![
M"B`@("`@("`@9&]C=6UE;G0N=7!D871E=7-E<BYU<V5R7VYA;64N9F]C=7,H
M*3L*("`@("`@("!A;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB*2D@/SXG*3L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!](&5L<V4@:68@*&1O8W5M96YT
M+G5P9&%T975S97(N=7-E<E]P87-S7S$@)B8*("`@("`@("`@("`@("`@9&]C
M=6UE;G0N=7!D871E=7-E<BYU<V5R7W!A<W-?,2YV86QU92`A/2!D;V-U;65N
M="YU<&1A=&5U<V5R+G5S97)?<&%S<U\R+G9A;'5E*2!["B`@("`@("`@9&]C
M=6UE;G0N=7!D871E=7-E<BYU<V5R7W!A<W-?,2YV86QU92`]("(B.PH@("`@
M("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]P87-S7S(N=F%L=64@/2`B
M(CL*("`@("`@("!D;V-U;65N="YU<&1A=&5U<V5R+G5S97)?<&%S<U\Q+F9O
M8W5S*"D["B`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")087-S=V]R9',@;75S="!M871C:"XB*2D@/SXG*3L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@<F5T=7)N('1R=64["GT*"B\O+2T^"CPO
M<V-R:7!T/@H*/&9O<FT@;F%M93TB=7!D871E=7-E<B(@;65T:&]D/2)P;W-T
M(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB9F]R;2(@=F%L=64](G5P
M9&%T92(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5S97)?;F%M92(@
M=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9E]U<V5R7VYA
M;64I(#\^(B`O/@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!P<FEN=&8H
M7R@B57!D871E("5S(BDL("1F7W5S97)?;F%M92D@/SX*/"]H,3X*/'1A8FQE
M(&-L87-S/2)S=')I<&5D(&YO=W)A<"(@8V5L;'-P86-I;F<](C`B('=I9'1H
M/2(Q,#`E(CX*/#]P:'`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=U<&1A
M=&4G*2DZ(#\^"B`\='(^"B`@/'1D('=I9'1H/2(Q)2(@8VQA<W,](FQI9VAT
M(')I9VAT06QI9VXB/@H@("`\/W!H<"!E8VAO(%\H(DYE=R!5<V5R;F%M92`H
M;W!T:6]N86PI(BD@/SX*("`\+W1D/@H@(#QT9#X*("`@/&EN<'5T('1Y<&4]
M(G1E>'0B(&YA;64](G5S97)?;F%M93(B('9A;'5E/2(\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)&9?=7-E<E]N86UE*2`_/B(@+SX*("`\+W1D/@H@
M/"]T<CX*(#QT<CX*("`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H@("`\/W!H
M<"!E8VAO(%\H(E!A<W-W;W)D(BD@/SX*("`\+W1D/@H@(#QT9#X*("`@/&EN
M<'5T('1Y<&4](G!A<W-W;W)D(B!N86UE/2)U<V5R7W!A<W-?,2(@+SX*("`\
M+W1D/@H@/"]T<CX*(#QT<CX*("`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H@
M("`\/W!H<"!E8VAO(%\H(D-O;F9I<FT@4&%S<W=O<F0B*2`_/@H@(#PO=&0^
M"B`@/'1D/@H@("`\:6YP=70@='EP93TB<&%S<W=O<F0B(&YA;64](G5S97)?
M<&%S<U\R(B`O/@H@(#PO=&0^"B`\+W1R/@H\/W!H<"!E;F1I9CL@/SX*(#QT
M<CX*("`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H@("`\/W!H<"!E8VAO(%\H
M(D9U;&P@3F%M92(I(#\^"B`@/"]T9#X*("`\=&0^"B`@(#QI;G!U="!T>7!E
M/2)T97AT(B!N86UE/2)U<V5R7V9U;&QN86UE(B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN
M86UE)RDI(#\^(B`O/@H@(#PO=&0^"B`\+W1R/@H@/'1R/@H@(#QT9"!C;&%S
M<STB<FEG:'1!;&EG;B(^"B`@(#P_<&AP(&5C:&\@7R@B16UA:6P@061D<F5S
M<R(I(#\^"B`@/"]T9#X*("`\=&0^"B`@(#QI;G!U="!T>7!E/2)T97AT(B!N
M86UE/2)U<V5R7V5M86EL(B`@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D:61E;G1I='DM/F=E=%9A;'5E*"=F<F]M7V%D9'(G*2D@/SXB
M("\^"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)C;VYT<F]L
M(&QE9G1!;&EG;B(@8V]L<W!A;CTB,B(^"B`@(#QI;G!U="!T>7!E/2)S=6)M
M:70B(&-L87-S/2)B=71T;VXB(&YA;64](G-U8FUI="(@;VYC;&EC:STB<F5T
M=7)N('9A;&ED871E7W5P9&%T92@I.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M57!D871E('5S97(B*2`_/B(@+SX*("`@/&EN<'5T('1Y<&4](G)E<V5T(B!C
M;&%S<STB8G5T=&]N(B!N86UE/2)R97-E="(@=F%L=64](CP_<&AP(&5C:&\@
M7R@B4F5S970B*2`_/B(@+SX*("`\+W1D/@H@/"]T<CX*/"]T86)L93X*/"]F
M;W)M/@H\8G(@+SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8P``````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$W,C,`,3`T,3<S-C,P,3$`,#(R-S`W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#QD:78@:60](FUE;G4B/@H@
M/'-P86X@8VQA<W,](FQE9G1&;&]A="(^"CP_<&AP"B1M96YU(#T@)FYE=R!-
M96YU*"D["B1M96YU+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V
M:6-E<R]P;W)T86PO)RDL(%\H(DAO7VUE(BDL("=H;W)D92YP;F<G*3L*9F]R
M96%C:"`H)')E9VES=')Y+3YL:7-T07!P<R@I(&%S("1A<'`I('L*("`@(&EF
M("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G861M:6Y?;&ES="<L("1A<'`I*2![
M"B`@("`@("`@)&QI<W0@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)&%P
M<"P@)V%D;6EN7VQI<W0G*3L*("`@("`@("!I9B`H:7-?82@D;&ES="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1V86QS*2!["B`@("`@("`@
M("`@(&EF("@D87!P("$]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("1N
M86UE(#T@)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*3L*("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)'9A;'-;)VYA;64G72DI('L*("`@("`@("`@
M("`@("`@("`@("`D;F%M92`N/2`G("<@+B`D=F%L<ULG;F%M92==.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&YA;64@/2`D=F%L<ULG;F%M92==.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1I;6<@/2!I<W-E="@D=F%L<ULG:6-O;B==*2`_("1R96=I
M<W1R>2T^9V5T26UA9V5$:7(H)&%P<"D@+B`G+R<@+B`D=F%L<ULG:6-O;B==
M(#H@)')E9VES=')Y+3YG970H)VEC;VXG+"`D87!P*3L*("`@("`@("`@("`@
M)&UE;G4M/F%D9"A(;W)D93HZ=7)L*"1R96=I<W1R>2T^87!P;&EC871I;VY7
M96)0871H*"1V86QS6R=L:6YK)UTL("1A<'`I*2P@)&YA;64L("1I;6<L("<G
M*3L*("`@("`@("!]"B`@("!]"GT*96-H;R`D;65N=2T^<F5N9&5R*"D["C\^
M"B`\+W-P86X^"CPO9&EV/@H`````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]T97-T+P``````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`,#$W,S8U`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W1E<W0O97AT96YS:6]N<RYI;F,`
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#(S,0`Q,#0Q-S,V,S`Q
M,0`P,C(R-30`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&AT;6P^"CQH96%D/@H\=&ET;&4^4$A0($5X=&5N<VEO;G,\+W1I
M=&QE/@H\<W1Y;&4^"F)O9'D@>R!B86-K9W)O=6YD+6-O;&]R.B!W:&ET93L@
M;6%R9VEN+71O<#H@,#L@;6%R9VEN+6QE9G0Z(#(P.R!M87)G:6XM<FEG:'0Z
M(#(P.R!]"G1A8FQE('L@9F]N="UF86UI;'DZ($%R:6%L+"!(96QV971I8V$L
M('-A;G,M<V5R:68[(&9O;G0M<VEZ93H@,3)P>#L@;6%R9VEN+71O<#H@,#L@
M;6%R9VEN+6QE9G0Z(#`[('T*82![('1E>'0M9&5C;W)A=&EO;CH@;F]N93L@
M9F]N="UF86UI;'DZ($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68[(&9O
M;G0M<VEZ93H@,3)P>#L@;6%R9VEN+71O<#H@,#L@;6%R9VEN+6QE9G0Z(#`[
M('T*83IA8W1I=F4@>R!C;VQO<CH@(S(T-3=F9CL@?0IA.FAO=F5R('L@8V]L
M;W(Z(",R-#4W9F8[('1E>'0M9&5C;W)A=&EO;CH@=6YD97)L:6YE.R!]"F$Z
M;&EN:R![(&-O;&]R.B`C,C0U-V9F.R!]"F$Z=FES:71E9"![(&-O;&]R.B`C
M,C0U-V9F.R!]"BYB;&%C:R![(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`P,#`[
M(&-O;&]R.B`C9F9F9F9F.R!]"CPO<W1Y;&4^"CPO:&5A9#X*/&)O9'D^"CQA
M(&AR968](CP_<&AP(&5C:&\@:7-S970H)%]'151;)W5R;"==*2`_(&AT;6QS
M<&5C:6%L8VAA<G,H)%]'151;)W5R;"==*2`Z("=T97-T+G!H<"<@/SX_;6]D
M93UT97-T(CXF;'0[)FQT.R!"86-K('1O('1E<W0N<&AP/"]A/@H\8G(@+SX*
M/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^/'1R/CQT9"!C
M;VQS<&%N/2(R(CX\=&%B;&4^"CQT<CX\=&0^<&AP('9E<G-I;VXZ/"]T9#X\
M=&0^/'-T<F]N9SX\/W!H<"!E8VAO('!H<'9E<G-I;VXH*2`_/CPO<W1R;VYG
M/CPO=&0^/"]T<CX*/'1R/CQT9#YS97)V97(@87!I.CPO=&0^/'1D/CQS=')O
M;F<^/#]P:'`@96-H;R!`<&AP7W-A<&E?;F%M92@I(#\^/"]S=')O;F<^/"]T
M9#X\+W1R/@H\='(^/'1D/FQO861E9"!E>'1E;G-I;VYS.CPO=&0^/'1D/CQS
M=')O;F<^/#]P:'`@)&5X=&5N<VEO;G,@/2!`9V5T7VQO861E9%]E>'1E;G-I
M;VYS*"D[(&5C:&\@8V]U;G0H)&5X=&5N<VEO;G,I.R`_/CPO<W1R;VYG/CPO
M=&0^/"]T<CX*/'1R/CQT9#YS>7-T96TZ/"]T9#X\=&0^/'-T<F]N9SX\/W!H
M<"!E8VAO($!P:'!?=6YA;64H*2`_/CPO<W1R;VYG/CPO=&0^/"]T<CX*/"]T
M86)L93X\8G(@+SX\+W1D/CPO='(^"CQT<B!C;&%S<STB8FQA8VLB/@H\=&0^
M/'-T<F]N9SYA8W1I=F%T960@97AT96YS:6]N<SH\+W-T<F]N9SX\+W1D/@H\
M=&0^/'-T<F]N9SX\/W!H<"!E8VAO(&ES<V5T*"1?1T546R=E>'0G72D@/R`D
M7T=%5%LG97AT)UT@.B`G)R`_/B!F=6YC=&EO;B!L:7-T.CPO<W1R;VYG/CPO
M=&0^"CPO='(^"CQT<CX\=&0@=F%L:6=N/2)T;W`B('=I9'1H/2(U,"4B/CQT
M86)L92!W:61T:#TB,3`P)2(^"CP_<&AP"B`@("!`<V]R="@D97AT96YS:6]N
M<RD["B`@("!F;W)E86-H("@D97AT96YS:6]N<R!A<R`D97AT96YS:6]N*2![
M"B`@("`@("`@96-H;R`G/'1R/CQT9"!W:61T:#TB,S`E(CXG("X@)&5X=&5N
M<VEO;B`N("<\+W1D/CQT9#X\82!H<F5F/2(_;6]D93UE>'1E;G-I;VYS)F%M
M<#ME>'0])R`N("1E>'1E;G-I;VX@+B`G)F%M<#MU<FP])R`N('5R;&5N8V]D
M92AI<W-E="@D7T=%5%LG=7)L)UTI(#\@)%]'151;)W5R;"==(#H@)R<I("X@
M)R(^9G5N8W1I;VX@;&ES=#PO83X\+W1D/CPO='(^)SL*("`@('T*/SX*/"]T
M86)L93X\+W1D/CQT9"!V86QI9VX](G1O<"(@=VED=&@](C4P)2(^/'1A8FQE
M/@H\/W!H<`H@("`@:68@*&ES<V5T*"1?1T546R=E>'0G72DI('L*("`@("`@
M("`D9G5N8W1I;VYS(#T@0&=E=%]E>'1E;G-I;VY?9G5N8W,H)%]'151;)V5X
M="==*3L*("`@("`@("!I9B`H:7-?87)R87DH)&9U;F-T:6]N<RDI('L*("`@
M("`@("`@("`@<V]R="@D9G5N8W1I;VYS*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)&9U;F-T:6]N<R!A<R`D9G5N8W1I;VXI('L*("`@("`@("`@("`@("`@
M(&5C:&\@(CQT<CX\=&0^/&$@:')E9CU<(FAT='`Z+R]W=W<N<&AP+FYE="]M
M86YU86PO9G5N8W1I;VXN(B`N('-T<E]R97!L86-E*"=?)RP@)RTG+"`D9G5N
M8W1I;VXI("X@(BYP:'!<(B!T87)G970]7")?8FQA;FM<(CXD9G5N8W1I;VX\
M+V$^/"]T9#X\+W1R/EQN(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*/SX*/"]T86)L93X\+W1D/CPO='(^/"]T86)L93X\+V)O9'D^/"]H=&UL
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W1E<W0O9F]O
M=&5R+FEN8P``````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`R
M,``Q,#0Q-S,V,S`Q,0`P,C$S-#,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/"]B;V1Y/@H\+VAT;6P^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]T97-T+VAE861E<BYI;F,`````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-C(`,3`T,3<S-C,P
M,3$`,#(Q,S$R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#PA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A4
M34P@,2XP(%1R86YS:71I;VYA;"\O14XB(")$5$0O>&AT;6PQ+71R86YS:71I
M;VYA;"YD=&0B/@H\:'1M;#X*/&AE860^"CQT:71L93X\/W!H<"!E8VAO("1M
M;V1U;&4@/SXZ(%-Y<W1E;2!#87!A8FEL:71I97,@5&5S=#PO=&ET;&4^"CQS
M='EL92!T>7!E/2)T97AT+V-S<R(^"CPA+2T*8F]D>2![(&9O;G0M9F%M:6QY
M.B!'96YE=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68[(&9O;G0M<VEZ
M93H@,3!P=#L@?0IT9"![(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L
M=F5T:6-A+'-A;G,M<V5R:68[(&9O;G0M<VEZ93H@,3!P=#L@?6@Q('L@9F]N
M="US:7IE.B`Q,G!T.R!C;VQO<CH@8FQA8VL[(&9O;G0M9F%M:6QY.B!697)D
M86YA+$=E;F5V82Q!<FEA;"Q(96QV971I8V$L"G-A;G,M<V5R:68[('T*+2T^
M"CPO<W1Y;&4^"CPO:&5A9#X*"CQB;V1Y(&)G8V]L;W(](G=H:71E(B!T97AT
M/2)B;&%C:R(^"@``````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O=&5S="]P:'!?=F5R<VEO;BYI;F,`````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S8R`#$P-#$W,S8S,#$Q`#`R,C0Q-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\:#$^
M4$A0(%9E<G-I;VX\+V@Q/@H\=6P^"B`@("`\;&D^/&$@:')E9CTB/#]P:'`@
M96-H;R`D<&AP7VEN9F\M/G!H<&EN9F\@/SXB/E9I97<@<&AP:6YF;R@I('-C
M<F5E;CPO83X\+VQI/@H@("`@/&QI/CQA(&AR968](CP_<&AP(&5C:&\@)'!H
M<%]I;F9O+3YE>'1E;G-I;VYS(#\^(CY6:65W(&QO861E9"!E>'1E;G-I;VYS
M/"]A/CPO;&D^"B`@("`\;&D^4$A0(%9E<G-I;VXZ(#P_<&AP(&5C:&\@)'!H
M<%]I;F9O+3YV97)S:6]N(#\^/"]L:3X*("`@(#QL:3Y02%`@36%J;W(@5F5R
M<VEO;CH@/#]P:'`@96-H;R`D<&AP7VEN9F\M/FUA:F]R(#\^/"]L:3X*/#]P
M:'`@:68@*&ES<V5T*"1P:'!?:6YF;RT^;6EN;W(I*3H@/SX*("`@(#QL:3Y0
M2%`@36EN;W(@5F5R<VEO;CH@/#]P:'`@96-H;R`D<&AP7VEN9F\M/FUI;F]R
M(#\^/"]L:3X*/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("AI<W-E="@D<&AP
M7VEN9F\M/G-U8FUI;F]R*2DZ(#\^"B`@("`\;&D^4$A0(%-U8FUI;F]R(%9E
M<G-I;VXZ(#P_<&AP(&5C:&\@)'!H<%]I;F9O+3YS=6)M:6YO<B`_/CPO;&D^
M"CP_<&AP(&5N9&EF.R`_/@H@("`@/&QI/E!(4"!697)S:6]N($-L87-S:69I
M8V%T:6]N.B`\/W!H<"!E8VAO("1P:'!?:6YF;RT^8VQA<W,@/SX\+VQI/@H@
M("`@/&QI('-T>6QE/2)C;VQO<CH\/W!H<"!E8VAO("1P:'!?:6YF;RT^<W1A
M='5S7V-O;&]R(#\^(CX\<W1R;VYG/CP_<&AP(&5C:&\@)'!H<%]I;F9O+3YS
M=&%T=7,@/SX\+W-T<F]N9SX\+VQI/@H\/W!H<"!I9B`H:7-S970H)'!H<%]I
M;F9O+3YV97)S:6]N7V-H96-K*2DZ(#\^"B`@("`\;&D^/#]P:'`@96-H;R`D
M<&AP7VEN9F\M/G9E<G-I;VY?8VAE8VL@/SX\+VQI/@H\/W!H<"!E;F1I9CL@
M/SX*/#]P:'`@:68@*&ES<V5T*"1P:'!?:6YF;RT^:6YS96-U<F4I*3H@/SX*
M("`@(#QL:2!S='EL93TB8V]L;W(Z;W)A;F=E(CX\<W1R;VYG/CP_<&AP(&5C
M:&\@)'!H<%]I;F9O+3YI;G-E8W5R92`_/CQS=')O;F<^/"]L:3X*/#]P:'`@
M96YD:68[(#\^"CPO=6P^"@``````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]V97)S:6]N+FEN8P``````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,38T`#$P-#$W,S8S,#$Q`#`R
M,34T,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\:#$^/#]P:'`@96-H;R`D;6]D=6QE(#\^(%9E<G-I;VX\+V@Q/@H\=6P^
M"B`@("`\;&D^/#]P:'`@96-H;R`D;6]D=6QE(#\^.B`\/W!H<"!E8VAO("1M
M;V1U;&5?=F5R<VEO;B`_/CPO;&D^"CPO=6P^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+W-H87)E<R\`````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P,3<V-S,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V-34W`#$P-#$W,S8S
M,#$Q`#`R,3,R-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\9F]R;2!N86UE/2)E9&ET(B!M971H;V0](G!O<W0B(&%C=&EO
M;CTB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1?4T525D526R=02%!?
M4T5,1B==*2`_/B(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](F5D:71F
M;W)M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)C:60B('9A;'5E
M/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'-H87)E+3YG971)9"@I
M*2`_/B(@+SX*/#]P:'`@:68@*"%E;7!T>2@D87!P*2DZ(#\^"CQI;G!U="!T
M>7!E/2)H:61D96XB(&YA;64](F%P<"(@=F%L=64](CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D87!P*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^"CQT
M86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/@H\='(@=F%L:6=N
M/2)M:61D;&4B/@H@(#QT9"!W:61T:#TB,3`P)2(@8V]L<W!A;CTB-B(@8VQA
M<W,](FAE861E<B(^"B`@("`\<W!A;B!C;&%S<STB<FEG:'1&;&]A="(^"B`@
M("`@(#QA(&AR968](B,B(&]N8VQI8VL](FIA=F%S8W)I<'0Z=VEN9&]W+F-L
M;W-E*"D[(B!S='EL93TB8W5R<V]R.G!O:6YT97(B/CP_<&AP(&5C:&\@2&]R
M9&4Z.FEM9R@G8VQO<V4N<&YG)RP@7R@B0VQO<V4@5VEN9&]W(BDL("<G+"`D
M<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*("`@(#PO
M<W!A;CX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G<&5R;7,N<&YG)RP@
M)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/B9N
M8G-P.SP_<&AP('!R:6YT9BA?*")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(I
M+"!H=&UL<W!E8VEA;&-H87)S*"1S:&%R92T^9V5T*"=N86UE)RDI*2`_/@H@
M(#PO=&0^"CPO='(^"CQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/@H*/#]P:'`@
M)&]W;F5R(#T@)'-H87)E+3YG970H)V]W;F5R)RD[(#\^"CP_<&AP("1U<V5R
M<&5R;7,@/2`D<&5R;2T^9V5T57-E<E!E<FUI<W-I;VYS*"D[(#\^"@H\(2TM
M($]W;F5R<VAI<"`M+3X*/#]P:'`@:68@*&ES<V5T*"1U<V5R<&5R;7-;)&]W
M;F5R72DI('L*("`@("`@("`@("1O<&5R;2`]("1U<V5R<&5R;7-;)&]W;F5R
M73L*("`@("`@?2!E;'-E('L*("`@("`@("`@("1O<&5R;2`](%!%4DU37U-(
M3U<@)B!015)-4U]214%$("8@4$5235-?141)5"`F(%!%4DU37T1%3$5413L*
M("`@("`@?0H_/@H\='(@=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!C;&%S<STB
M:&5A9&5R(&QE9G1!;&EG;B(@=VED=&@](C4U)2(^"B`@("`\/W!H<"!E8VAO
M($AO<F1E.CII;6<H)W!E<FUS+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*2D@+B`G)FYB<W`[)R`N(%\H(D]W;F5R(%!E
M<FUI<W-I;VYS(BD@/SX*("`\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A
M;&EG;CTB8V5N=&5R(B!W:61T:#TB,24B/CP_<&AP(&5C:&\@7R@B4VAO=R(I
M(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(@
M=VED=&@](C$E(CX\/W!H<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^"B`@/'1D
M(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B('=I9'1H/2(Q)2(^/#]P
M:'`@96-H;R!?*")%9&ET(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R
M(B!A;&EG;CTB8V5N=&5R(B!W:61T:#TB,24B/CP_<&AP(&5C:&\@7R@B1&5L
M971E(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI9VXB
M('=I9'1H/2(T,"4B/B9N8G-P.SPO=&0^"CPO='(^"CQT<CX*/#]P:'`@:68@
M*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T)RDI.B`_/@H@(#QT9"!C;&%S
M<STB;&EG:'0B/@H@("`@/'-E;&5C="!N86UE/2)O=VYE<B(^"B`@("`@(#QO
M<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?*")396QE8W0@82!N97<@;W=N
M97(B*2`N("<Z)R`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&]W;F5R*2`_/B(@<V5L96-T
M960](G-E;&5C=&5D(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H075T
M:#HZ<F5M;W9E2&]O:R@D;W=N97(I*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@
M9F]R96%C:"`H)'5S97),:7-T(&%S("1U<V5R*2![(&EF("@D=7-E<B`A/2`D
M;W=N97(I('L@/SX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*$%U=&@Z.G)E;6]V94AO;VLH)'5S97(I*2`_/CPO;W!T:6]N
M/@H@("`@/#]P:'`@?2!](#\^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\/W!H
M<"!E;'-E.B`_/@H@(#QT9"!C;&%S<STB;&EG:'0B/CQI;G!U="!T>7!E/2)T
M97AT(B!N86UE/2)O=VYE<B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D;W=N97(I(#\^(B`O/CPO=&0^"CP_<&AP(&5N9&EF.R`_/@H@
M(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA
M;64](F]W;F5R7W-H;W<B/#]P:'`@96-H;R`H)&]P97)M("8@4$5235-?4TA/
M5RD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\
M=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE
M/2)O=VYE<E]R96%D(CP_<&AP(&5C:&\@*"1O<&5R;2`F(%!%4DU37U)%040I
M(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D
M(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB
M;W=N97)?961I="(\/W!H<"!E8VAO("@D;W!E<FT@)B!015)-4U]%1$E4*2`_
M("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A
M;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F]W
M;F5R7V1E;&5T92(\/W!H<"!E8VAO("@D;W!E<FT@)B!015)-4U]$14Q%5$4I
M(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"CPO='(^
M"@H\(2TM(%-P86-E<B`M+3X*/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^"@H\
M(2TM($1E9F%U;'0@4&5R;6ES<VEO;G,@+2T^"CQT<B!V86QI9VX](FUI9&1L
M92(^"B`@/'1D(&-L87-S/2)H96%D97(@;&5F=$%L:6=N(CX*("`@(#P_<&AP
M(&5C:&\@2&]R9&4Z.FEM9R@G<&5R;7,N<&YG)RP@)R<L("<G+"`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<F;F)S<#LG("X@7R@B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S
M/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4VAO=R(I
M(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^
M/#]P:'`@96-H;R!?*")296%D(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A
M9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D5D:70B*2`_/CPO
M=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP
M(&5C:&\@7R@B1&5L971E(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R
M(')I9VAT06QI9VXB/B9N8G-P.SPO=&0^"CPO='(^"CP_<&AP("1D<&5R;2`]
M("1P97)M+3YG971$969A=6QT4&5R;6ES<VEO;G,H*3L@/SX*/'1R/@H@(#QT
M9"!C;&%S<STB;&EG:'0B/B9N8G-P.SPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]S:&]W
M(CP_<&AP(&5C:&\@*"1D<&5R;2`F(%!%4DU37U-(3U<I(#\@)R!C:&5C:V5D
M/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]R96%D
M(CP_<&AP(&5C:&\@*"1D<&5R;2`F(%!%4DU37U)%040I(#\@)R!C:&5C:V5D
M/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]E9&ET
M(CP_<&AP(&5C:&\@*"1D<&5R;2`F(%!%4DU37T5$250I(#\@)R!C:&5C:V5D
M/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]D96QE
M=&4B/#]P:'`@96-H;R`H)&1P97)M("8@4$5235-?1$5,151%*2`_("<@8VAE
M8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H\+W1R/@H*/"$M+2!3
M<&%C97(@+2T^"CQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/@H*/"$M+2!'=65S
M="!097)M:7-S:6]N<R`M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@
M8VQA<W,](FAE861E<B!L969T06QI9VXB/@H@("`@/#]P:'`@96-H;R!?*")'
M=65S="!097)M:7-S:6]N<R(I(#\^"B`@/"]T9#X*("`\=&0@8VQA<W,](FAE
M861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")3:&]W(BD@/SX\
M+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H
M<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B
M(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B161I="(I(#\^/"]T9#X*
M("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H
M;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(@<FEG
M:'1!;&EG;B(^)FYB<W`[/"]T9#X*/"]T<CX*/#]P:'`@)&=P97)M(#T@)'!E
M<FTM/F=E=$=U97-T4&5R;6ES<VEO;G,H*3L@/SX*/'1R/@H@(#QT9"!C;&%S
M<STB;&EG:'0B/B9N8G-P.SPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI
M;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9W5E<W1?<VAO=R(\/W!H<"!E
M8VAO("@D9W!E<FT@)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME
M9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=U97-T7W)E860B/#]P:'`@96-H
M;R`H)&=P97)M("8@4$5235-?4D5!1"D@/R`G(&-H96-K960](F-H96-K960B
M)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T
M('1Y<&4](F-H96-K8F]X(B!N86UE/2)G=65S=%]E9&ET(CP_<&AP(&5C:&\@
M*"1G<&5R;2`F(%!%4DU37T5$250I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T
M>7!E/2)C:&5C:V)O>"(@;F%M93TB9W5E<W1?9&5L971E(CP_<&AP(&5C:&\@
M*"1G<&5R;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960](F-H96-K960B
M)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*"CPA+2T@4W!A8V5R("TM/@H\='(^
M/'1D/B9N8G-P.SPO=&0^/"]T<CX*"CPA+2T@0W)E871O<B!097)M:7-S:6]N
M<R`M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@8VQA<W,](FAE861E
M<B!L969T06QI9VXB/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=U<V5R
M+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G
M*2D@+B`G)FYB<W`[)R`N(%\H(D]B:F5C="!#<F5A=&]R(BD@/SX*("`\+W1D
M/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E
M8VAO(%\H(E-H;W<B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L
M:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4F5A9"(I(#\^/"]T9#X*("`\
M=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?
M*")%9&ET(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB
M8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D1E;&5T92(I(#\^/"]T9#X*("`\=&0@
M8VQA<W,](FAE861E<B!R:6=H=$%L:6=N(CX\+W1D/@H\+W1R/@H\/W!H<"`D
M8W!E<FT@/2`D<&5R;2T^9V5T0W)E871O<E!E<FUI<W-I;VYS*"D[(#\^"CQT
M<CX*("`\=&0@8VQA<W,](FQI9VAT(CXF;F)S<#L\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T
M;W)?<VAO=R(\/W!H<"!E8VAO("@D8W!E<FT@)B!015)-4U]32$]7*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T
M;W)?<F5A9"(\/W!H<"!E8VAO("@D8W!E<FT@)B!015)-4U]214%$*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T
M;W)?961I="(\/W!H<"!E8VAO("@D8W!E<FT@)B!015)-4U]%1$E4*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T
M;W)?9&5L971E(CP_<&AP(&5C:&\@*"1C<&5R;2`F(%!%4DU37T1%3$5412D@
M/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*
M"CPA+2T@4W!A8V5R("TM/@H\='(^/'1D/B9N8G-P.SPO=&0^/"]T<CX*"CPA
M+2T@57-E<B!097)M:7-S:6]N<R`M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*
M("`\=&0@8VQA<W,](FAE861E<B!L969T06QI9VXB/@H@("`@/#]P:'`@96-H
M;R!(;W)D93HZ:6UG*"=U<V5R+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*2D@+B`G)FYB<W`[)R`N(%\H(DEN9&EV:61U
M86P@57-E<G,B*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L
M:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4VAO=R(I(#\^/"]T9#X*("`\
M=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?
M*")296%D(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB
M8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D5D:70B*2`_/CPO=&0^"B`@/'1D(&-L
M87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B1&5L
M971E(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI9VXB
M/CPO=&0^"CPO='(^"CP_<&AP(&9O<F5A8V@@*"1U<V5R<&5R;7,@87,@)'5S
M97(@/3X@)'5P97)M*2![(&EF("@D=7-E<B`A/2`D;W=N97(I('L@/SX*/'1R
M/@H@(#QT9"!C;&%S<STB;&EG:'0B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<RA!=71H.CIR96UO=F5(;V]K*"1U<V5R*2D@/SX\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)U7VYA;65S6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D=7-E<BD@/SY=(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1U<V5R*2`_/B(@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R
M(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?<VAO=UL\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I(#\^72(\/W!H<"!E8VAO("@D
M=7!E<FT@)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@
M)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP
M93TB8VAE8VMB;W@B(&YA;64](G5?<F5A9%L\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'5S97(I(#\^72(\/W!H<"!E8VAO("@D=7!E<FT@)B!015)-
M4U]214%$*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D
M/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&YA;64](G5?961I=%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S
M97(I(#\^72(\/W!H<"!E8VAO("@D=7!E<FT@)B!015)-4U]%1$E4*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?9&5L
M971E6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SY=(CP_
M<&AP(&5C:&\@*"1U<&5R;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960]
M(F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*/#]P:'`@?2!](#\^
M"CPA+2T@3F5W('5S97(@<F]W("TM/@H\='(^"CP_<&AP(&EF("@D875T:"T^
M:&%S0V%P86)I;&ET>2@G;&ES="<I*3H@/SX*("`\=&0@8VQA<W,](FQI9VAT
M(CX*("`@(#QS96QE8W0@;F%M93TB=5]N86UE<UM\?&YE=UTB/@H@("`@("`\
M;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B4V5L96-T(&$@=7-E<B!T
M;R!A9&0B*2`N("<Z)R`_/CPO;W!T:6]N/@H@("`@/#]P:'`@9F]R96%C:"`H
M)'5S97),:7-T(&%S("1U<V5R*2![(&EF("@A:7-S970H)'5S97)P97)M<ULD
M=7-E<ETI*2![(#\^"B`@("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SXB/CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<RA!=71H.CIR96UO=F5(;V]K*"1U<V5R*2D@/SX\+V]P=&EO
M;CX*("`@(#P_<&AP('T@?2`_/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/#]P
M:'`@96QS93H@/SX*("`\=&0@8VQA<W,](FQI9VAT(CX\:6YP=70@='EP93TB
M=&5X="(@;F%M93TB=5]N86UE<UM\?&YE=UTB("\^/"]T9#X*/#]P:'`@96YD
M:68[(#\^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB=5]S:&]W6WQ\;F5W72(@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?<F5A
M9%M\?&YE=UTB("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T
M('1Y<&4](F-H96-K8F]X(B!N86UE/2)U7V5D:71;?'QN97==(B`O/CPO=&0^
M"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@
M;F%M93TB=5]D96QE=&5;?'QN97==(B`O/CPO=&0^"CPO='(^"@H\(2TM(%-P
M86-E<B`M+3X*/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^"@H\(2TM($=R;W5P
M(%!E<FUI<W-I;VYS("TM/@H\='(@=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!C
M;&%S<STB:&5A9&5R(&QE9G1!;&EG;B(^"B`@("`\/W!H<"!E8VAO($AO<F1E
M.CII;6<H)V=R;W5P+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G
M941I<B@G:&]R9&4G*2D@+B`G)FYB<W`[)R`N(%\H(D=R;W5P<R(I(#\^"B`@
M/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P
M:'`@96-H;R!?*")3:&]W(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R
M(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^
M"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C
M:&\@7R@B161I="(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI
M9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@
M/'1D(&-L87-S/2)H96%D97(@<FEG:'1!;&EG;B(^)FYB<W`[/"]T9#X*/"]T
M<CX*/#]P:'`@)&=R;W5P<&5R;7,@/2`D<&5R;2T^9V5T1W)O=7!097)M:7-S
M:6]N<R@I.R!F;W)E86-H("@D9W)O=7!P97)M<R!A<R`D9W)O=7`@/3X@)&=P
M97)M*3H@:68@*"$D9W)O=7!S+3YE>&ES=',H)&=R;W5P<RT^9V5T1W)O=7!.
M86UE*"1G<F]U<"DI*2!C;VYT:6YU93L@/SX*/'1R/@H@(#QT9"!C;&%S<STB
M;&EG:'0B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7!S+3YG
M971'<F]U<$YA;64H)&=R;W5P*2D@/SX\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)G7VYA;65S6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O
M=7`I(#\^72(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M9W)O=7`I(#\^(B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U
M="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]S:&]W6SP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D9W)O=7`I(#\^72(\/W!H<"!E8VAO("@D9W!E<FT@
M)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@
M+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE
M8VMB;W@B(&YA;64](F=?<F5A9%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&=R;W5P*2`_/ETB/#]P:'`@96-H;R`H)&=P97)M("8@4$5235-?4D5!
M1"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\
M=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE
M/2)G7V5D:71;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G<F]U<"D@
M/SY=(CP_<&AP(&5C:&\@*"1G<&5R;2`F(%!%4DU37T5$250I(#\@)R!C:&5C
M:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C
M96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]D96QE=&5;
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G<F]U<"D@/SY=(CP_<&AP
M(&5C:&\@*"1G<&5R;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960](F-H
M96-K960B)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*/#]P:'`@96YD9F]R96%C
M:#L@/SX*/"$M+2!.97<@9W)O=7`@<F]W("TM/@H\='(^"B`@/'1D(&-L87-S
M/2)L:6=H="(^"B`@("`\<V5L96-T(&YA;64](F=?;F%M97-;?'QN97==(CX*
M("`@("`@/&]P=&EO;B!V86QU93TB(CX\/W!H<"!E8VAO(%\H(E-E;&5C="!A
M(&=R;W5P('1O(&%D9"(I("X@)SHG(#\^/"]O<'1I;VX^"B`@("`\/W!H<"!F
M;W)E86-H("@D9W)O=7!,:7-T(&%S("1G:60@/3X@)&=R;W5P*2![(&EF("AE
M;7!T>2@D9W)O=7!P97)M<ULD9VED72DI('L@/SX*("`@("`@/&]P=&EO;B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G:60I(#\^(CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P*2`_/CPO;W!T:6]N
M/@H@("`@/#]P:'`@?2!](#\^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H@(#QT
M9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64]
M(F=?<VAO=UM\?&YE=UTB("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G7W)E861;?'QN97==(B`O
M/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB9U]E9&ET6WQ\;F5W72(@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=?9&5L
M971E6WQ\;F5W72(@+SX\+W1D/@H\+W1R/@H*/'1R/@H@/'1D/B9N8G-P.SPO
M=&0^"CPO='(^"@H\='(^"B`\=&0@8V]L<W!A;CTB-R(^"B`@/&EN<'5T('1Y
M<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP('!R:6YT
M9BA?*")3879E("5S(BDL(&AT;6QS<&5C:6%L8VAA<G,H)'-H87)E+3YG970H
M)VYA;64G*2DI(#\^(B`O/@H\/W!H<"!I9B`H0&-O=6YT*"1C:&EL9')E;BDI
M.B`_/@H@(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&]N
M8VQI8VL](F1O8W5M96YT+F5D:70N86-T:6]N240N=F%L=64@/2`G961I=&9O
M<FUI;FAE<FET)SLB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D%P<&QY('1O($-H
M:6QD(%-H87)E<R(I(#\^(B`O/@H\/W!H<"!E;F1I9CL@/SX*(#PO=&0^"CPO
M='(^"@H\+W1A8FQE/@H\+V9O<FT^"CQB<B`O/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<G!C<W5M+P``````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W
M,S8S,#$Q`#`Q-S<Q-P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8P``````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#8U,S,`,3`T,3<S-C,P,3$`,#(Q-S(W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#QS8W)I<'0@='EP93TB=&5X
M="]J879A<V-R:7!T(CX*/"$M+0H*=F%R(&-A;F-E;%-U8FUI="`](&9A;'-E
M.PH*=F%R(&9I96QD<R`](&YE=R!!<G)A>2@*/#]P:'`@9F]R("@D:2`](#`[
M("1I(#P@8V]U;G0H)')P8U]S97)V97)S*3L@)&DK*RDZ(#\^"B`@("!N97<@
M07)R87DH"B`@("`@("`@(CP_<&AP(&5C:&\@<F%W=7)L96YC;V1E*"1R<&-?
M<V5R=F5R<ULD:5U;)W5R;"==*2`_/B(L"B`@("`@("`@(CP_<&AP(&5C:&\@
M<F%W=7)L96YC;V1E*"1R<&-?<V5R=F5R<ULD:5U;)W5S97(G72D@/SXB"B`@
M("`I/#]P:'`@:68@*"1I("L@,2`\(&-O=6YT*"1R<&-?<V5R=F5R<RDI(&5C
M:&\@)RPG.R`_/@H*/#]P:'`@96YD9F]R.R`_/@HI.PH*9G5N8W1I;VX@;F5W
M0VAO:6-E*"D*>PH@("`@=F%R(&%C=&EO;B`](&1O8W5M96YT+G!R969S+G-E
M<G9E<BYO<'1I;VYS6V1O8W5M96YT+G!R969S+G-E<G9E<BYS96QE8W1E9$EN
M9&5X72YV86QU93L*"B`@("!I9B`H86-T:6]N(#T]("TQ*2!["B`@("`@("`@
M9&]C=6UE;G0N<')E9G,N<V%V92YV86QU92`]("<\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B0W)E871E(BDI(#\^)SL*("`@("`@("!D;V-U;65N="YP<F5F
M<RYR97-E="@I.PH@("`@?2!E;'-E('L*("`@("`@("!D;V-U;65N="YP<F5F
M<RYS879E+G9A;'5E(#T@)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#:&%N
M9V4B*2D@/SXG.PH@("`@("`@('5P9&%T949O<FTH86-T:6]N*3L*("`@('T*
M?0H*9G5N8W1I;VX@=7!D871E1F]R;2AS97)V97(I"GL*("`@(&1O8W5M96YT
M+G!R969S+F5D:71?<V5R=F5R+G9A;'5E(#T@<V5R=F5R.PH@("`@9&]C=6UE
M;G0N<')E9G,N=7)L+G9A;'5E(#T@9&5C;V1E55))0V]M<&]N96YT*&9I96QD
M<UMS97)V97)=6S!=*3L*("`@(&1O8W5M96YT+G!R969S+G5S97(N=F%L=64@
M/2!D96-O9&554DE#;VUP;VYE;G0H9FEE;&1S6W-E<G9E<EU;,5TI.PI]"@IF
M=6YC=&EO;B!C;&5A<D9O<FTH*0I["B`@("!D;V-U;65N="YP<F5F<RYE9&ET
M7W-E<G9E<BYV86QU92`]("<G.PH@("`@9&]C=6UE;G0N<')E9G,N=7)L+G9A
M;'5E(#T@(&9I96QD<UMS97)V97)=6S!=.PH@("`@9&]C=6UE;G0N<')E9G,N
M=7-E<BYV86QU92`](&9I96QD<UMS97)V97)=6S%=.PH@("`@9&]C=6UE;G0N
M<')E9G,N<V5R=F5R+G-E;&5C=&5D26YD97@@/2`P.PH@("`@8V%N8V5L4W5B
M;6ET(#T@=')U93L*?0H*9G5N8W1I;VX@8VAE8VM3=6)M:70H*0I["B`@("!C
M86YC96P@/2!C86YC96Q3=6)M:70["B`@("!C86YC96Q3=6)M:70@/2!F86QS
M93L*/#]P:'`@:68@*"1B<F]W<V5R+3YG971"<F]W<V5R*"D@/3T@)VUS:64G
M("8F("1B<F]W<V5R+3YG971-86IO<B@I(#X](#0I.B`_/@H@("`@=VEN9&]W
M+F5V96YT+G)E='5R;E9A;'5E(#T@(6-A;F-E;#L*/#]P:'`@96YD:68[(#\^
M"B`@("!R971U<FX@(6-A;F-E;#L*?0H*+R\M+3X*/"]S8W)I<'0^"@H\/W!H
M<"!E8VAO(%\H(EEO=7(@<F5M;W1E('-E<G9E<G,Z(BD@/SX\8G(@+SX*/'-E
M;&5C="!N86UE/2)S97)V97(B(&]N8VAA;F=E/2)J879A<V-R:7!T.FYE=T-H
M;VEC92@I(CX*("`\;W!T:6]N('9A;'5E/2(M,2(^/#]P:'`@96-H;R!?*")3
M96QE8W0@82!S97)V97(B*2`_/CPO;W!T:6]N/@H\/W!H<"!F;W(@*"1I(#T@
M,#L@)&D@/"!C;W5N="@D<G!C7W-E<G9E<G,I.R`K*R1I*3H@/SX*("`\;W!T
M:6]N('9A;'5E/2(\/W!H<"!E8VAO("1I(#\^(CX\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)')P8U]S97)V97)S6R1I75LG=7)L)UTI(#\^/"]O<'1I
M;VX^"CP_<&AP(&5N9&9O<CL@/SX*/"]S96QE8W0^"CPO=&0^/"]T<CX*"CQN
M;W-C<FEP=#X*/"]T86)L93X\+W1D/CPO='(^"CQT<CX*("`\=&0@=F%L:6=N
M/2)M:61D;&4B/@H@("`@/&)R("\^"B`@("`\:6YP=70@='EP93TB<W5B;6ET
M(B!N86UE/2)E9&ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H
M;R!?*")%9&ET(BD@/SXB("\^"B`@("`\:6YP=70@='EP93TB<W5B;6ET(B!N
M86UE/2)D96QE=&4B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(D1E;&5T92(I(#\^(B`O/@H@("`@/&)R("\^)FYB<W`["B`@/"]T9#X*
M/"]T<CX*"CQT<CX\=&0@8VQA<W,](FET96TB/CQT86)L93X*/"]N;W-C<FEP
M=#X*"CQT<B!V86QI9VX](G1O<"(^/'1D(&-L87-S/2)I=&5M(CX*"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](F5D:71?<V5R=F5R(B!V86QU93TB(B`O
M/@H\/W!H<"!E8VAO(%\H(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.B(I(#\^/&)R("\^"CQI;G!U="!T>7!E/2)T97AT(B!N
M86UE/2)U<FPB('-I>F4](C,P(B!M87AL96YG=&@](C8P(B`O/CQB<B`O/@H*
M/#]P:'`@96-H;R!?*")5<V5R;F%M93HB*2`_/CQB<B`O/@H\:6YP=70@='EP
M93TB=&5X="(@;F%M93TB=7-E<B(@<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B
M("\^/&)R("\^"@H\/W!H<"!E8VAO(%\H(E!A<W-W;W)D.B(I(#\^/&)R("\^
M"CQI;G!U="!T>7!E/2)P87-S=V]R9"(@;F%M93TB<&%S<W=D(B!S:7IE/2(S
M,"(@;6%X;&5N9W1H/2(V,"(@+SX\8G(@+SX*"CPO=&0^/"]T<CX\+W1A8FQE
M/CPO=&0^/"]T<CX\+W1A8FQE/@H*/'`^"B`\:6YP=70@='EP93TB<W5B;6ET
M(B!N86UE/2)S879E(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N
M="YP<F5F<RYA8W1I;VY)1"YV86QU93TG<V%V92<[(')E='5R;B!T<G5E(B!V
M86QU93TB/#]P:'`@96-H;R`D86-T:6]N240@/3T@)V5D:70G(#\@7R@B0VAA
M;F=E(BD@.B!?*")#<F5A=&4B*2`_/B(@+SXF;F)S<#L*/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/@ID;V-U;65N="YW<FET92@G/&EN<'5T('1Y
M<&4](G-U8FUI="(@;F%M93TB9&5L971E(B!C;&%S<STB8G5T=&]N(B!O;F-L
M:6-K/2)D;V-U;65N="YP<F5F<RYA8W1I;VY)1"YV86QU93U<)V1E;&5T95PG
M(B!V86QU93TB/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/B(@+SXF;F)S<#LG
M*3L*/"]S8W)I<'0^"B`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)N97<B
M(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F-L96%R1F]R;2@I.V1O8W5M96YT
M+G!R969S+G-A=F4N=F%L=64])SP_<&AP(&5C:&\@7R@B0W)E871E(BD@/SXG
M.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5S970B*2`_/B(@+SXF;F)S<#L*
M(#QI;G!U="!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB(&]N8VQI8VL]
M(F-A;F-E;%-U8FUI=#UT<G5E.V1O8W5M96YT+FQO8V%T:6]N+FAR968])SP_
M<&AP(&5C:&\@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*%5T:6PZ.F%D9%!A<F%M
M971E<B@G<V5R=FEC97,O<')E9G,N<&AP)RP@)V%P<"<L("=H;W)D92<I+"!T
M<G5E*2`_/B<B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E='5R;B!T;R!/<'1I
M;VYS(BD@/SXB("\^"CPO<#X*"CPO9F]R;3X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T
M97,O8V]N=&5N=',O````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$Q`#`R,#(T,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]C;VYT96YT<R]O<&5N7W9I97=?=VEN+FIS
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-#8`,3`T,3<S-C,P,3$`,#(S
M-#4P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H*9G5N8W1I
M;VX@='(H8F%D=F%L*0I["B`@("!R971V86P@/2`G)SL*("`@('9A;&ED8VAA
M<G,@/2`G86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7HP,3(S-#4V-S@Y)SL*
M"B`@("!B861V86PN=&],;W=E<D-A<V4H*3L*("`@(&9O<B`H:2`](#`[(&D@
M/"!B861V86PN;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H=F%L:61C:&%R
M<RYI;F1E>$]F*&)A9'9A;"YC:&%R070H:2DI("$]("TQ*2!["B`@("`@("`@
M("`@(')E='9A;"`K/2!B861V86PN8VAA<D%T*&DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='9A;"`K/2`G7R<["B`@("`@("`@?0H@("`@
M?0H@("`@<F5T=7)N(')E='9A;#L*?0H*9G5N8W1I;VX@=FEE=RAU<FPL('!A
M<G1I9"D*>PH@("`@<&%R86T@/2`B;65N=6)A<CUY97,L=&]O;&)A<CUN;RQL
M;V-A=&EO;CUN;RQS=&%T=7,];F\L<V-R;VQL8F%R<SUY97,L<F5S:7IA8FQE
M/7EE<R(["B`@("!W:6YD;W<N;W!E;BAU<FPL("<\/W!H<"!E8VAO(&)A<V5?
M8V]N=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*2`_/B<@*R!T<BAP87)T:60I
M+"!P87)A;2D["GT*"B\O("TM/@H\+W-C<FEP=#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]D871A+P``````````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P
M,3$`,#$W,S$W`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,`````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S`T,P`Q,#0Q-S,V,S`Q,0`P,C$T-38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/&9O<FT@;65T:&]D/2)P;W-T(B!N
M86UE/2)I;7!O<G1?9F]R;2(@86-T:6]N/2)D871A+G!H<"(^"CP_<&AP(&5C
M:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB86-T:6]N240B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&YE>'1?
M<W1E<"`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP;W)T
M7V9O<FUA="(@=F%L=64](F-S=B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB:6UP;W)T7W-T97`B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&EM
M<&]R=%]S=&5P(#\^(B`O/@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!P
M<FEN=&8H7R@B26UP;W)T+"!3=&5P("5D(BDL("AI;G0I)&EM<&]R=%]S=&5P
M*2`_/@H\+V@Q/@H\9&EV(&-L87-S/2)H96%D97)B;W@@=&5X="(^"B`@("`\
M/W!H<"!E8VAO(%\H(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93HB*2`_/CQB<B`O/@H@("`@/'!R93X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)%]315-324].6R=I;7!O<G1?9&%T82==6R=F:7)S=%]L:6YE<R==
M*2`_/CPO<')E/CQB<B`O/@H@("`@/&QA8F5L(&9O<CTB:&5A9&5R(CX\/W!H
M<"!E8VAO(%\H(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L
M9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB*2`_/CPO;&%B96P^
M"B`@("`\:6YP=70@:60](FAE861E<B(@='EP93TB8VAE8VMB;W@B(&YA;64]
M(FAE861E<B(@=F%L=64](C$B(&-H96-K960](F-H96-K960B("\^/&)R("\^
M"B`@("`\/W!H<"!E8VAO(%\H(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_(BD@/SX*("`@(#QI;G!U="!T>7!E/2)T97AT(B!N86UE/2)S97`B
M('-I>F4](C$B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)%]315-324].6R=I;7!O<G1?9&%T82==6R=S97`G72D@/SXB("\^/&)R("\^
M"B`@("`\/W!H<"!I9B`H:7-S970H)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=Q=6]T92==*2DZ(#\^"B`@("`\/W!H<"!E8VAO(%\H(E=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\B*2`_/@H@("`@/&EN<'5T('1Y<&4](G1E>'0B
M(&YA;64](G%U;W1E(B!S:7IE/2(Q(B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG<75O=&4G
M72D@/SXB("\^/&)R("\^"B`@("`\/W!H<"!E;F1I9CL@/SX*("`@(#P_<&AP
M(&EF("AI<W-E="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I96QD<R==
M*2DZ(#\^"B`@("`\/W!H<"!E8VAO(%\H(DAO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/R(I(#\^"B`@("`\:6YP=70@='EP93TB=&5X="(@
M;F%M93TB9FEE;&1S(B!S:7IE/2(R(B!V86QU93TB/#]P:'`@96-H;R`H:6YT
M*21?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FEE;&1S)UT@/SXB("\^/&)R
M("\^"B`@("`\/W!H<"!E;F1I9CL@/SX*/"]D:78^"CQI;G!U="!T>7!E/2)S
M=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H(DYE>'0B*2`_/B(@8VQA<W,]
M(F)U='1O;B(@+SX*/"]F;W)M/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,`````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(V
M-3``,3`T,3<S-C,P,3$`,#(Q,S`T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CX*/"$M+0IF=6YC=&EO;B!R97-E=$AI9&1E;B@I"GL*("`@('9A<B!F
M;W)M(#T@9&]C=6UE;G0N;6%P9F]R;3L*("`@('9A<B!T;7`@/2`G)SL*("`@
M(&9O<B`H:2`](#`[(&D@/"!F;W)M+G-E;&5C=$1A=&$N;&5N9W1H.R!I*RLI
M('L*("`@("`@("!T;7`@*ST@9F]R;2YS96QE8W1$871A6VE=+G9A;'5E.PH@
M("`@("`@(&EF("AI(#P@9F]R;2YS96QE8W1$871A+FQE;F=T:"`M(#$I"B`@
M("`@("`@("`@('1M<"`K/2`B7'0B.PH@("`@?0H@("`@9F]R;2YD871A2V5Y
M<RYV86QU92`]('1M<#L*("`@('1M<"`]("<G.PH@("`@9F]R("AI(#T@,#L@
M:2`\(&9O<FTN<V5L96-T07!P+FQE;F=T:#L@:2LK*2!["B`@("`@("`@=&UP
M("L](&9O<FTN<V5L96-T07!P6VE=+G9A;'5E.PH@("`@("`@(&EF("AI(#P@
M9F]R;2YS96QE8W1!<'`N;&5N9W1H("T@,2D*("`@("`@("`@("`@=&UP("L]
M(")<="(["B`@("!]"B`@("!F;W)M+F%P<$ME>7,N=F%L=64@/2!T;7`["GT*
M"F9U;F-T:6]N(&%D9%!A:7(H*0I["B`@("!V87(@9F]R;2`](&1O8W5M96YT
M+FUA<&9O<FT["B`@("!I9B`H9F]R;2YS96QE8W0Q+G-E;&5C=&5D26YD97@@
M/CT@,"`F)B!F;W)M+G-E;&5C=#(N<V5L96-T961);F1E>"`^/2`P*2!["B`@
M("`@("`@9F]R;2YS96QE8W1$871A6V9O<FTN<V5L96-T1&%T82YL96YG=&A=
M(#T@;F5W($]P=&EO;BAF;W)M+G-E;&5C=#%;9F]R;2YS96QE8W0Q+G-E;&5C
M=&5D26YD97A=+G1E>'0L(&9O<FTN<V5L96-T,5MF;W)M+G-E;&5C=#$N<V5L
M96-T961);F1E>%TN=F%L=64I.PH@("`@("`@(&9O<FTN<V5L96-T07!P6V9O
M<FTN<V5L96-T07!P+FQE;F=T:%T@/2!N97<@3W!T:6]N*&9O<FTN<V5L96-T
M,EMF;W)M+G-E;&5C=#(N<V5L96-T961);F1E>%TN=&5X="P@9F]R;2YS96QE
M8W0R6V9O<FTN<V5L96-T,BYS96QE8W1E9$EN9&5X72YV86QU92D["B`@("`@
M("`@9F]R;2YS96QE8W0Q6V9O<FTN<V5L96-T,2YS96QE8W1E9$EN9&5X72`]
M(&YU;&P["B`@("`@("`@9F]R;2YS96QE8W0R6V9O<FTN<V5L96-T,BYS96QE
M8W1E9$EN9&5X72`](&YU;&P["B`@("!]"B`@("!R97-E=$AI9&1E;B@I.PI]
M"@IF=6YC=&EO;B!R96UO=F5086ER*"D*>PH@("`@=F%R(&9O<FT@/2!D;V-U
M;65N="YM87!F;W)M.PH@("`@:68@*&9O<FTN<V5L96-T1&%T82YS96QE8W1E
M9$EN9&5X(#X](#`@?'P@9F]R;2YS96QE8W1!<'`N<V5L96-T961);F1E>"`^
M/2`P*2!["B`@("`@("`@9F]R;2YS96QE8W0Q6V9O<FTN<V5L96-T,2YL96YG
M=&A=(#T@;F5W($]P=&EO;BAF;W)M+G-E;&5C=$1A=&%;9F]R;2YS96QE8W1$
M871A+G-E;&5C=&5D26YD97A=+G1E>'0L(&9O<FTN<V5L96-T1&%T85MF;W)M
M+G-E;&5C=$1A=&$N<V5L96-T961);F1E>%TN=F%L=64I.PH@("`@("`@(&9O
M<FTN<V5L96-T,EMF;W)M+G-E;&5C=#(N;&5N9W1H72`](&YE=R!/<'1I;VXH
M9F]R;2YS96QE8W1!<'!;9F]R;2YS96QE8W1!<'`N<V5L96-T961);F1E>%TN
M=&5X="P@9F]R;2YS96QE8W1!<'!;9F]R;2YS96QE8W1!<'`N<V5L96-T961)
M;F1E>%TN=F%L=64I.PH@("`@("`@(&9O<FTN<V5L96-T1&%T85MF;W)M+G-E
M;&5C=$1A=&$N<V5L96-T961);F1E>%T@/2!N=6QL.PH@("`@("`@(&9O<FTN
M<V5L96-T07!P6V9O<FTN<V5L96-T07!P+G-E;&5C=&5D26YD97A=(#T@;G5L
M;#L*("`@('T*("`@(')E<V5T2&ED9&5N*"D["GT*+R\M+3X*/"]S8W)I<'0^
M"@H\9F]R;2!M971H;V0](G!O<W0B(&YA;64](FUA<&9O<FTB(&%C=&EO;CTB
M9&%T82YP:'`B/@H\/W!H<"!E8VAO(%5T:6PZ.F9O<FU);G!U="@I(#\^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB/#]P
M:'`@96-H;R`H:6YT*21N97AT7W-T97`@/SXB("\^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](FEM<&]R=%]F;W)M870B('9A;'5E/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ9V5T1F]R;41A=&$H)VEM<&]R=%]F
M;W)M870G*2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEM
M<&]R=%]S=&5P(B!V86QU93TB/#]P:'`@96-H;R`H:6YT*21I;7!O<G1?<W1E
M<"`_/B(@+SX*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F*%\H
M(DEM<&]R="P@4W1E<"`E9"(I+"`H:6YT*21I;7!O<G1?<W1E<"D@/SX*/"]H
M,3X*/'`@8VQA<W,](F-O;G1R;VPB/@H@/#]P:'`@96-H;R!?*")396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RXB*2`_/@H\+W`^"CQT86)L92!C96QL<W!A
M8VEN9STB,"(@=VED=&@](C$P,"4B/@H@/'1R/@H@(#QT9"!C;&%S<STB:71E
M;2(^"B`@/'1A8FQE/CQT<CX\=&0^"B`@("`\=&%B;&4@8V5L;'-P86-I;F<]
M(C`B/CQT<CX*("`@("`@/'1D/@H@("`@("`@(#P_<&AP(&5C:&\@7R@B26UP
M;W)T960@9FEE;&1S.B(I(#\^/&)R("\^"B`@("`@("`@/'-E;&5C="!N86UE
M/2)S96QE8W0Q(B!S:7IE/2(Q,"(^"CP_<&AP(&9O<F5A8V@@*"1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG9&%T82==6S!=(&%S("1K97D@/3X@)'9A;'5E
M*3H*("`@("`@:68@*"%I<W-E="@D87!P7V9I96QD<ULD:V5Y72DI.B`_/@H@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO("@D7U-%4U-)3TY;)VEM<&]R
M=%]D871A)UU;)VAE861E<B==*2`_(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@
M.B!H=&UL<W!E8VEA;&-H87)S*"1V86QU92D@/SX\+V]P=&EO;CX*/#]P:'`@
M96YD:68["B`@("`@(&5N9&9O<F5A8V@[(#\^"B`@("`@("`@/"]S96QE8W0^
M"B`@("`@(#PO=&0^"B`@("`@(#QT9#X*("`@("`@("`\/W!H<"!E8VAO(%\H
M(D%V86EL86)L92!F:65L9',Z(BD@/SX\8G(@+SX*("`@("`@("`\<V5L96-T
M(&YA;64](G-E;&5C=#(B('-I>F4](C$P(CX*/#]P:'`@9F]R96%C:"`H)&%P
M<%]F:65L9',@87,@)&ME>2`]/B`D=F%L=64I.@H@("`@("!I9B`H(6ES<V5T
M*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==6S!=6R1K97E=*2DZ
M(#\^"B`@("`@(#P_<&AP(&EF("@H)&ME>2`]/2`G86QA<FU?=&EM92<I('Q\
M("@D:V5Y(#T]("=A;&%R;5]D871E)RDI.B`_/@H@("`@("`@("`@("`\/W!H
M<"!I9B`H(6ES<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==
M6S!=6R=A;&%R;2==*2DZ(#\^"B`@("`@("`@("`@(#QO<'1I;VX@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(^/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1V86QU92D@/SX\+V]P=&EO;CX*("`@
M("`@("`@("`@/#]P:'`@96YD:68[(#\^"B`@("`@(#P_<&AP(&5L<V5I9B`H
M)&ME>2`]/2`G86QA<FTG*3H@/SX*("`@("`@("`@("`@/#]P:'`@:68@*"$H
M:7-S970H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;,%U;)V%L
M87)M7W1I;64G72D@)B8@:7-S970H)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=D871A)UU;,%U;)V%L87)M7V1A=&4G72DI*3H@/SX*("`@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K
M97DI(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*2`_
M/CPO;W!T:6]N/@H@("`@("`@("`@("`\/W!H<"!E;F1I9CL@/SX*("`@("`@
M/#]P:'`@96QS93H@/SX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'9A;'5E*2`_/CPO;W!T:6]N/@H@("`@("`\/W!H<"!E
M;F1I9CL@/SX*/#]P:'`@96YD:68["B`@("`@(&5N9&9O<F5A8V@[(#\^"B`@
M("`@("`@/"]S96QE8W0^"B`@("`@(#PO=&0^"B`@("`\+W1R/CPO=&%B;&4^
M"B`@("`\:6YP=70@='EP93TB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?
M*")!9&0@<&%I<B(I(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)A9&10
M86ER*"DB("\^"B`@/"]T9#X\+W1R/CPO=&%B;&4^"B`@/"]T9`H\+W1R/@H\
M='(^"B`@/'1D/@H@("`@/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB
M,3`P)2(^"B`@("`\='(^/'1D(&-L87-S/2)I=&5M(CXF;F)S<#L\+W1D/CPO
M='(^"B`@("`\='(^/'1D(&-L87-S/2)S;6%L;&AE861E<B(^/#]P:'`@96-H
M;R!?*")-871C:&EN9R!F:65L9',B*2`_/CPO=&0^/"]T<CX*("`@(#PO=&%B
M;&4^"B`@/"]T9#X*/"]T<CX*/'1R/@H@(#QT9"!C;&%S<STB:71E;2(^"B`@
M/'1A8FQE/CQT<CX\=&0^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)D871A2V5Y<R(@+SX*("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(F%P<$ME>7,B("\^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I
M;7!O<G1?9F]R;6%T(B!V86QU93TB8W-V(B`O/@H@("`@/'-E;&5C="!N86UE
M/2)S96QE8W1$871A(B!S:7IE/2(Q,"(@;VYC:&%N9V4](F1O8W5M96YT+FUA
M<&9O<FTN<V5L96-T07!P6W1H:7,N<V5L96-T961);F1E>%TN<V5L96-T960]
M=')U92(^"CP_<&AP"F9O<F5A8V@@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G
M75LG9&%T82==6S!=(&%S("1K97D@/3X@)'9A;'5E*3H*("`@(&EF("AI<W-E
M="@D87!P7V9I96QD<ULD:V5Y72DI.@H@("`@("`@("1M871C:&EN9UM=(#T@
M87)R87DH)&ME>2P@)&%P<%]F:65L9'-;)&ME>5TI.PH_/@H@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K
M97DI(#\^(CX\/W!H<"!E8VAO("@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;
M)VAE861E<B==*2`_(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@.B!H=&UL<W!E
M8VEA;&-H87)S*"1V86QU92D@/SX\+V]P=&EO;CX*/#]P:'`@96YD:68[(#\^
M"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`\+W-E;&5C=#X*("`@(#QS96QE
M8W0@;F%M93TB<V5L96-T07!P(B!S:7IE/2(Q,"(@;VYC:&%N9V4](F1O8W5M
M96YT+FUA<&9O<FTN<V5L96-T1&%T85MT:&ES+G-E;&5C=&5D26YD97A=+G-E
M;&5C=&5D/71R=64B/@H\/W!H<"!F;W)E86-H("@D;6%T8VAI;F<@87,@)'!A
M:7(I.B`_/@H@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1P86ER6S!=*2`_/B(^/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1P86ER6S%=*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F
M;W)E86-H.R`_/@H@("`@/"]S96QE8W0^/&)R("\^"B`@("`\:6YP=70@='EP
M93TB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")296UO=F4@<&%I<B(I
M(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)R96UO=F5086ER*"DB("\^
M/&)R("\^/&)R("\^"B`@("`\:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB
M/#]P:'`@96-H;R!?*").97AT(BD@/SXB(&-L87-S/2)B=71T;VXB("\^"B`@
M/"]T9#X\+W1R/CPO=&%B;&4^"B`@/"]T9#X*/"]T<CX*/"]T86)L93X*/"]F
M;W)M/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*<F5S
M971(:61D96XH*3L*+R\M+3X*/"]S8W)I<'0^"@``````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]D871A+V1A=&4N:6YC````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P,#(`,3`T,3<S-C,P,3$`,#(P-S(P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B1I(#T@,#L*=VAI;&4@*"1I(#P@8V]U;G0H)&1A=&5;)W9A;'5E<R==
M*2`F)B!E;7!T>2@D9&%T95LG=F%L=65S)UU;)&E=*2D@>PH@("`@)&DK*SL*
M?0II9B`H<W1R<&]S*"1D871E6R=V86QU97,G75LD:5TL("<O)RD@(3T](&9A
M;'-E*2!["B`@("`D9&5L(#T@)R\G.PI](&5L<V5I9B`H<W1R<&]S*"1D871E
M6R=V86QU97,G75LD:5TL("<N)RD@(3T](&9A;'-E*2!["B`@("`D9&5L(#T@
M)RXG.PI](&5L<V5I9B`H<W1R<&]S*"1D871E6R=V86QU97,G75LD:5TL("<M
M)RD@(3T](&9A;'-E*2!["B`@("`D9&5L(#T@)RTG.PI](&5L<V4@>PH@("`@
M)&1E;"`]("<G.PI]"@HO+R!4<GD@=&\@9W5E<W,@=&AE(&1A=&4@9F]R;6%T
M(&%S(&UU8V@@87,@<&]S<VEB;&4*:68@*"%E;7!T>2@D9&5L*2`F)B!I<W-E
M="@D9&%T95LG=F%L=65S)UTI("8F(&ES<V5T*"1D871E6R=V86QU97,G75LD
M:5TI*2!["B`@("`D<&%R=',@/2!E>'!L;V1E*"1D96PL("1D871E6R=V86QU
M97,G75LD:5TI.PH@("`@:68@*&-O=6YT*"1P87)T<RD@/CT@,RD@>PH@("`@
M("`@("1F;W)M(#T@)VUD>2<["B`@("`@("`@:68@*"AS=')L96XH)'!A<G1S
M6S!=*2`]/2`T*2!\?"`H)'!A<G1S6S!=(#X@,S$I*2!["B`@("`@("`@("`@
M("1F;W)M(#T@)WEM9"<["B`@("`@("`@("`@(&EF("@D<&%R='-;,5T@/B`Q
M,BD@>PH@("`@("`@("`@("`@("`@)&9O<FT@/2`G>61M)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS96EF("@D<&%R='-;,%T@/B`Q,BD@>PH@("`@
M("`@("`@("`D9F]R;2`]("=D;7DG.PH@("`@("`@('T*("`@('T*?0H*/SX*
M/'1R/@H@(#QT9#X\/W!H<"!E8VAO(%\H(E-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z(BD@/SX\+W1D/@H@(#QT9#X*("`@(#QS96QE8W0@;F%M93TB9&5L
M:6UI=&5R6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/ETB
M/@H@("`@("`\;W!T:6]N('9A;'5E/2(O(CP_<&AP(&5C:&\@)&1E;"`]/2`G
M+R<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+SPO;W!T:6]N
M/@H@("`@("`\;W!T:6]N('9A;'5E/2(N(CP_<&AP(&5C:&\@)&1E;"`]/2`G
M+B<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+CPO;W!T:6]N
M/@H@("`@("`\;W!T:6]N('9A;'5E/2(M(CP_<&AP(&5C:&\@)&1E;"`]/2`G
M+2<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+3PO;W!T:6]N
M/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/"]T<CX*/'1R/@H@(#QT9#X\/W!H
M<"!E8VAO(%\H(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(BD@/SX\+W1D/@H@
M(#QT9#X*("`@(#QS96QE8W0@;F%M93TB9F]R;6%T6SP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D:V5Y*2`_/ETB/@H@("`@("`\;W!T:6]N('9A;'5E
M/2)M9&%Y+VUO;G1H+WEE87(B/#]P:'`@96-H;R`D9F]R;2`]/2`G9&UY)R`_
M("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H
M(D1$(BD@+B`D9&5L("X@7R@B34TB*2`N("1D96P@+B!?*")962(I(#\^/"]O
M<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](FUO;G1H+VUD87DO>65A<B(\
M/W!H<"!E8VAO("1F;W)M(#T]("=M9'DG(#\@)R!S96QE8W1E9#TB<V5L96-T
M960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B34TB*2`N("1D96P@+B!?*")$
M1"(I("X@)&1E;"`N(%\H(EE9(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO
M;B!V86QU93TB>65A<B]M;VYT:"]M9&%Y(CP_<&AP(&5C:&\@)&9O<FT@/3T@
M)WEM9"<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@
M96-H;R!?*")962(I("X@)&1E;"`N(%\H(DU-(BD@+B`D9&5L("X@7R@B1$0B
M*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)Y96%R+VUD87DO
M;6]N=&@B/#]P:'`@96-H;R`D9F]R;2`]/2`G>61M)R`_("<@<V5L96-T960]
M(G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(EE9(BD@+B`D9&5L
M("X@7R@B1$0B*2`N("1D96P@+B!?*")-32(I(#\^/"]O<'1I;VX^"B`@("`\
M+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W,C``,3`T,3<S
M-C,P,3$`,#(Q-#(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB9&%T969O<FTB
M(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC871I;VY5<FPH)V1A
M=&$N<&AP)RD@/SXB/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I
M;VY)1"(@=F%L=64](CP_<&AP(&5C:&\@*&EN="DD;F5X=%]S=&5P(#\^(B`O
M/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I;7!O<G1?9F]R;6%T(B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F=E=$9O
M<FU$871A*"=I;7!O<G1?9F]R;6%T)RDI(#\^(B`O/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)I;7!O<G1?<W1E<"(@=F%L=64](CP_<&AP(&5C:&\@
M*&EN="DD:6UP;W)T7W-T97`@/SXB("\^"CP_<&AP(%5T:6PZ.G!F;W)M26YP
M=70H*2`_/@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!P<FEN=&8H7R@B
M26UP;W)T+"!3=&5P("5D(BDL("AI;G0I)&EM<&]R=%]S=&5P*2`_/@H\+V@Q
M/@H\=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*/#]P:'`@
M9F]R96%C:"`H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871E<R==(&%S
M("1K97D@/3X@)&1A=&4I.B`_/@H\/W!H<"!I9B`H8V]U;G0H)&1A=&5;)W9A
M;'5E<R==*2DZ(#\^"CQT<CX*("`@(#QT9#X*("`@("`@("`\=&%B;&4@8V5L
M;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@("`@("`\='(^/'1D(&-L
M87-S/2)I=&5M(CXF;F)S<#L\+W1D/CPO='(^"B`@("`@("`@/'1R/CQT9"!C
M;&%S<STB<VUA;&QH96%D97(B/CP_<&AP('!R:6YT9BA?*"));7!O<G1E9"!F
M:65L9#H@)7,B*2P@:'1M;'-P96-I86QC:&%R<R@D87!P7V9I96QD<ULD7U-%
M4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA<"==6R1K97E=72DI(#\^/"]T9#X\
M+W1R/@H@("`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H\+W1R/@H\='(^"B`@
M("`\=&0@8VQA<W,](FET96TB/@H@("`@/'1A8FQE/@H@("`@/'1R/@H@("`@
M("`@(#QT9#X\/W!H<"!E8VAO(%\H(D5X86UP;&4@=F%L=65S.B(I(#\^/"]T
M9#X*("`@("`@("`\=&0^"B`@("`@("`@("`@(#QS96QE8W0^"CP_<&AP(&9O
M<F5A8V@@*"1D871E6R=V86QU97,G72!A<R`D=F%L*3H@/SX*("`@("`@("`@
M("`@("`@(#QO<'1I;VX^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1V
M86PI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`@("`@
M("`@(#PO<V5L96-T/@H@("`@("`@(#PO=&0^"B`@("`\+W1R/@H\/W!H<"!I
M;F-L=61E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N
M("<O9&%T82\G("X@)&1A=&5;)W1Y<&4G72`N("<N:6YC)R`_/@H@("`@/"]T
M86)L93X*("`@(#PO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!E
M;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H*/&EN<'5T('1Y<&4](G-U8FUI="(@
M8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B3F5X="(I(#\^
M(B`O/@H\+V9O<FT^"@``````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+V1A=&$O9&%T971I;64N:6YC````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P,C$U-S$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]T:6UE+FEN8P``````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3,W`#$P-#$W,S8S,#$Q
M`#`R,#<U,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HD:2`](#`["G=H:6QE("@D:2`\/2!C;W5N="@D9&%T95LG
M=F%L=65S)UTI("8F(&5M<'1Y*"1D871E6R=V86QU97,G75LD:5TI*2!["B`@
M("`D:2LK.PI]"FEF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)SHG
M*2`A/3T@9F%L<V4I('L*("`@("1D96P@/2`G.B<["GT@96QS96EF("AS=')P
M;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)RXG*2`A/3T@9F%L<V4I('L*("`@
M("1D96P@/2`B+B(["GT@96QS92!["B`@("`D9&5L(#T@(B(["GT*)&%M<&T@
M/2`H<W1R<&]S*%-T<FEN9SHZ;&]W97(H)&1A=&5;)W9A;'5E<R==6S!=*2P@
M)V%M)RD@(3T](&9A;'-E('Q\('-T<G!O<RA3=')I;F<Z.FQO=V5R*"1D871E
M6R=V86QU97,G75LP72DL("=P;2<I("$]/2!F86QS92D["C\^"CQT<CX*("`\
M=&0^/#]P:'`@96-H;R!?*")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(I
M(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T(&YA;64](F1E;&EM:71E<EL\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@
M/&]P=&EO;B!V86QU93TB.B(\/W!H<"!E8VAO("1D96P@/3T@)SHG(#\@)R!S
M96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CH\+V]P=&EO;CX*("`@("`@
M/&]P=&EO;B!V86QU93TB+B(\/W!H<"!E8VAO("1D96P@/3T@)RXG(#\@)R!S
M96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/BX\+V]P=&EO;CX*("`@(#PO
M<V5L96-T/@H@(#PO=&0^"CPO='(^"CQT<CX*("`\=&0^/#]P:'`@96-H;R!?
M*")396QE8W0@=&AE('1I;64@9F]R;6%T.B(I(#\^/"]T9#X*("`\=&0^"B`@
M("`\<V5L96-T(&YA;64](F9O<FUA=%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V86QU93TB,C1H<B(\
M/W!H<"!E8VAO("1A;7!M(#\@)R<@.B`G('-E;&5C=&5D/2)S96QE8W1E9"(G
M(#\^/CP_<&AP(&5C:&\@7R@B,C0@:&]U<G,B*2`_/CPO;W!T:6]N/@H@("`@
M("`\;W!T:6]N('9A;'5E/2)A;7!M(CP_<&AP(&5C:&\@)&%M<&T@/R`G('-E
M;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H;R!?*")!32]0
M32(I(#\^/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$V,#$`,3`T,3<S-C,P,3$`,#(Q-#<U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#QF;W)M(&UE=&AO9#TB<&]S
M="(@;F%M93TB:6UP;W)T7V9O<FTB(&%C=&EO;CTB9&%T82YP:'`B/@H\/W!H
M<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB86-T:6]N240B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&YE>'1?
M<W1E<"`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP;W)T
M7V9O<FUA="(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA5
M=&EL.CIG971&;W)M1&%T82@G:6UP;W)T7V9O<FUA="<I*2`_/B(@+SX*/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP;W)T7W-T97`B('9A;'5E/2(\
M/W!H<"!E8VAO("AI;G0I)&EM<&]R=%]S=&5P(#\^(B`O/@H\:#$@8VQA<W,]
M(FAE861E<B(^"B`\/W!H<"!P<FEN=&8H7R@B26UP;W)T+"!3=&5P("5D(BDL
M("AI;G0I)&EM<&]R=%]S=&5P*2`_/@H\+V@Q/@H\9&EV(&-L87-S/2)H96%D
M97)B;W@B/@H@/#]P:'`@96-H;R!?*")(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z(BD@/SX\8G(@+SX*(#QP<F4^/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FER<W1?
M;&EN97,G72D@/SX\+W!R93X\8G(@+SX*(#QL86)E;"!F;W(](FAE861E<B(^
M/#]P:'`@96-H;R!?*")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@
M9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(BD@/SX\+VQA
M8F5L/@H@/&EN<'5T(&ED/2)H96%D97(B('1Y<&4](F-H96-K8F]X(B!N86UE
M/2)H96%D97(B('9A;'5E/2(Q(B`O/CQB<B`O/@H\+V1I=CX*/&EN<'5T('1Y
M<&4](G-U8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B3F5X="(I(#\^(B!C
M;&%S<STB8G5T=&]N(B`O/@H\+V9O<FT^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]H96QP+P``````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`,#$W,S,V`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(Q-@`Q,#0Q-S,V,S`Q
M,0`P,C$Q,S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&@R(&%L:6=N/2)C96YT97(B/CP_<&AP('!R:6YT9BA?*")4:&ES
M(&ES("5S+B(I+"`D=F5R<VEO;BD@/SX\+V@R/@H\<')E('-T>6QE/2)D:7)E
M8W1I;VXZ;'1R(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-R961I
M=',I(#\^/"]P<F4^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E;7!L871E<R]H96QP+VEN9&5X+FEN8P``````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`W,#0`,3`T,3<S-C,P,3$`,#(Q,3,V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#PA1$]#
M5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP($9R86UE
M<V5T+R]%3B(@(D141"]X:'1M;#$M9G)A;65S970N9'1D(CX*/&AT;6P^"CQH
M96%D/@H@/'1I=&QE/CP_<&AP(&5C:&\@7R@B2&5L<"(I(#\^/"]T:71L93X*
M/"]H96%D/@H*/&9R86UE<V5T(')O=W,](C,P+"HB(&9R86UE8F]R9&5R/2)N
M;R(@8F]R9&5R/2(P(B!F<F%M97-P86-I;F<](C`B/@H@/&9R86UE(&YA;64]
M(FAE;'!?;65N=2(@<V-R;VQL:6YG/2)N;R(@;6%R9VEN:&5I9VAT/2(P(B!M
M87)G:6YW:61T:#TB,"(@<W)C/2(\/W!H<"!E8VAO("1M96YU7W5R;"`_/B(@
M+SX*(#QF<F%M92!N86UE/2)H96QP7VUA:6XB(')E<VEZ96%B;&4](GEE<R(@
M;6%R9VEN:&5I9VAT/2(R(B!M87)G:6YW:61T:#TB,B(@<W)C/2(\/W!H<"!E
M8VAO("1M86EN7W5R;"`_/B(@+SX*/"]F<F%M97-E=#X*"CPO:'1M;#X*````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T
M97,O:&5L<"]M96YU+FEN8P``````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-#$P`#$P-#$W,S8S,#$Q`#`R,#<V-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\9&EV(&-L87-S/2)H96%D
M97(B/@H@/'-P86X@8VQA<W,](FQE9G1&;&]A="(^"B`@/#]P:'`@96-H;R`D
M=&]P:6-S7VQI;FL@/SX*(#PO<W!A;CX*/#]P:'`@:68@*"1C;VYF6R=M96YU
M)UU;)VQI;FMS)UU;)VAE;'!?86)O=70G72DZ(#\^"B`\<W!A;B!C;&%S<STB
M<FEG:'1&;&]A="(^"B`@/#]P:'`@96-H;R`D86)O=71?;&EN:R`_/@H@/"]S
M<&%N/@H\/W!H<"!E;F1I9CL@/SX*(#QS<&%N('-T>6QE/2)C;&5A<CIB;W1H
M(CXF;F)S<#L\+W-P86X^"CPO9&EV/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R;V)L96TO
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,S`Q,0`P,C`P-#8`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8P``````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`T,S$P`#$P-#$W,S8S,#$Q`#`R,C$W-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\<V-R:7!T('1Y
M<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*+R\@0VAE8VL@86QL(&]F('1H
M92!M86EN(&9O<FT@9FEE;&1S('1O(&UA:V4@<W5R92!T:&5Y(&%R92!F:6QL
M960@:6X*9G5N8W1I;VX@=F%L:61A=&4H*0I["B`@("!I9B`H9&]C=6UE;G0N
M<')O8FQE;5]R97!O<G0N<W5B:F5C="YV86QU92`]/2`G)RD@>PH@("`@("`@
M(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(I*2`_/B<I.PH@("`@("`@
M(&1O8W5M96YT+G!R;V)L96U?<F5P;W)T+G-U8FIE8W0N9F]C=7,H*3L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!](&5L<V4@:68@*&1O8W5M96YT+G!R
M;V)L96U?<F5P;W)T+FUE<W-A9V4N=F%L=64@/3T@)R<I('L*("`@("`@("!A
M;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+B(I*2`_/B<I.PH@("`@("`@(&1O8W5M96YT+G!R;V)L96U?
M<F5P;W)T+FUE<W-A9V4N9F]C=7,H*3L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@9&]C=6UE;G0N<')O8FQE;5]R97!O<G0N86-T:6]N240N
M=F%L=64@/2`G<V5N9%]P<F]B;&5M7W)E<&]R="<["B`@("!R971U<FX@=')U
M93L*?0HO+RTM/@H\+W-C<FEP=#X*"CQF;W)M(&UE=&AO9#TB<&]S="(@;F%M
M93TB<')O8FQE;5]R97!O<G0B(&%C=&EO;CTB<')O8FQE;2YP:'`B/@H\/W!H
M<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB86-T:6]N240B('9A;'5E/2)C86YC96Q?<')O8FQE;5]R97!O<G0B
M("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G)E='5R;E]U<FPB('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ9V5T1F]R
M;41A=&$H)W)E='5R;E]U<FPG*2D@/SXB("\^"@H\=&%B;&4@8V5L;'!A9&1I
M;F<](C,B(&-E;&QS<&%C:6YG/2(R(B!W:61T:#TB,3`P)2(^"CQT<B!C;&%S
M<STB:&5A9&5R(CX*("`@(#QT9"!C;VQS<&%N/2(R(B!C;&%S<STB:&5A9&5R
M(CX\/W!H<"!E8VAO(%\H(D1E<V-R:6)E('1H92!0<F]B;&5M(BD@/SX\+W1D
M/@H\+W1R/@H*/'1R/@H@("`@/'1D(&-L87-S/2)L:6=H="!R:6=H=$%L:6=N
M(CX\/W!H<"!E8VAO(%\H(EEO=7(@3F%M92(I(#\^/"]T9#X*("`@(#QT9#X\
M:6YP=70@='EP93TB=&5X="(@=&%B:6YD97@](C$B(&YA;64](FYA;64B('9A
M;'5E/2(\/W!H<"!E8VAO("1N86UE(#\^(B!S:7IE/2(W,"(@+SX\+W1D/@H\
M+W1R/@H*/'1R/@H@("`@/'1D(&-L87-S/2)L:6=H="!R:6=H=$%L:6=N(CX\
M/W!H<"!E8VAO(%\H(EEO=7(@16UA:6P@061D<F5S<R(I(#\^/"]T9#X*("`@
M(#QT9#X\:6YP=70@='EP93TB=&5X="(@=&%B:6YD97@](C(B(&YA;64](F5M
M86EL(B!V86QU93TB/#]P:'`@96-H;R`D96UA:6P@/SXB('-I>F4](C<P(B`O
M/CPO=&0^"CPO='(^"@H\='(^"B`@("`\=&0@8VQA<W,](FQI9VAT(')I9VAT
M06QI9VXB/CP_<&AP(&5C:&\@7R@B4VAO<G0@4W5M;6%R>2(I(#\^/"]T9#X*
M("`@(#QT9#X\:6YP=70@='EP93TB=&5X="(@=&%B:6YD97@](C,B(&YA;64]
M(G-U8FIE8W0B('9A;'5E/2(\/W!H<"!E8VAO("1S=6)J96-T(#\^(B!S:7IE
M/2(W,"(@+SX\+W1D/@H\+W1R/@H*/'1R/@H@("`@/'1D(&-O;'-P86X](C(B
M(&-L87-S/2)S;6%L;&AE861E<B(^/#]P:'`@96-H;R!?*")&=6QL($1E<V-R
M:7!T:6]N(BD@/SX\+W1D/@H\+W1R/@H\='(^"B`@("`\=&0^/"]T9#X*("`@
M(#QT9#X\=&5X=&%R96$@=&%B:6YD97@](C0B(&YA;64](FUE<W-A9V4B(')O
M=W,](C(P(B!C;VQS/2(X,"(@=W)A<#TB:&%R9"(^/#]P:'`@96-H;R`D;65S
M<V%G92`_/CPO=&5X=&%R96$^/"]T9#X*/"]T<CX*"CQT<CX*("`\=&0^/"]T
M9#X*("`\=&0@8VQA<W,](FQI9VAT(CX*("`@(#QI;G!U="!C;&%S<STB8G5T
M=&]N(B!T>7!E/2)S=6)M:70B(&YA;64](F9O<FUS=6)M:70B(&]N8VQI8VL]
M(G)E='5R;B!V86QI9&%T92@I.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B4V5N
M9"!0<F]B;&5M(%)E<&]R="(I(#\^(B`O/@H@("`@/&EN<'5T(&-L87-S/2)B
M=71T;VXB('1Y<&4](G-U8FUI="(@;F%M93TB9F]R;7-U8FUI="(@=F%L=64]
M(CP_<&AP(&5C:&\@7R@B0V%N8V5L(%!R;V)L96T@4F5P;W)T(BD@/SXB("\^
M"B`@/"]T9#X*/"]T<CX*"CPO=&%B;&4^"CPO9F]R;3X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="\`````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$Q`#`R
M,#4U-``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R
M:7!T+V9O<FU?<V5C=&EO;G,N:G,`````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,U
M-C,`,3`T,3<S-C,P,3$`,#(S-S<P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J*@H@*B!(;W)D92!&;W)M(%-E8W1I;VYS
M($IA=F%S8W)I<'0@0VQA<W,*("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I
M<'0@8VQA<W,@9F]R(&AA;F1L:6YG('1A8F)E9"!S96-T:6]N<R!I;B!(;W)D
M92!&;W)M<RX*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K
M:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!H;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]F;W)M7W-E8W1I;VYS+FIS
M+'8@,2XQ,2XT+C8@,C`P-B\P,2\P,2`R,3HR.3HQ-2!J86X@17AP("0*("H*
M("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@
M0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*9G5N8W1I;VX@2&]R9&5?1F]R;5]3
M96-T:6]N<RAI;G-T86YC94YA;64L(&]P96Y396-T:6]N*0I["B`@("`O*B!3
M970@=7`@=&AI<R!C;&%S<R!I;G-T86YC92!F;W(@9G5N8W1I;VX@8V%L;',@
M9G)O;2!T:&4@<&%G92X@*B\*("`@('1H:7,N7VEN<W1A;F-E3F%M92`](&EN
M<W1A;F-E3F%M93L*"B`@("`O*B!4:&4@8W5R<F5N=&QY('-H;W=E9"!S96-T
M:6]N+B`J+PH@("`@=F%R(%]O<&5N4V5C=&EO;CL*"B`@("!T:&ES+G1O9V=L
M92`](&9U;F-T:6]N*'-E8W1I;VY)9"D*("`@('L*("`@("`@("`O*B!'970@
M=&AE(&-U<G)E;G1L>2!O<&5N('-E8W1I;VX@;V)J96-T+B`J+PH@("`@("`@
M(&]P96Y396-T:6]N260@/2!T:&ES+E]G970H*3L*("`@("`@("!I9B`H9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H)U]S96-T:6]N7R<@*R!O<&5N4V5C=&EO
M;DED*2D@>PH@("`@("`@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@G
M7W-E8W1I;VY?)R`K(&]P96Y396-T:6]N260I+G-T>6QE+F1I<W!L87D@/2`G
M;F]N92<["B`@("`@("`@?0H@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*"=?=&%B7R<@*R!O<&5N4V5C=&EO;DED*2YC;&%S<TYA;64@/2!N=6QL
M.PH*("`@("`@("`O*B!'970@=&AE(&YE=VQY(&]P96YE9"!S96-T:6]N(&]B
M:F5C="X@*B\*("`@("`@("!I9B`H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)U]S96-T:6]N7R<@*R!S96-T:6]N260I*2!["B`@("`@("`@("`@(&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*"=?<V5C=&EO;E\G("L@<V5C=&EO;DED*2YS
M='EL92YD:7-P;&%Y(#T@)V)L;V-K)SL*("`@("`@("!]"B`@("`@("`@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H)U]T86)?)R`K('-E8W1I;VY)9"DN8VQA
M<W-.86UE(#T@)V%C=&EV951A8B<["@H@("`@("`@("\J(%-T;W)E('1H92!N
M97=L>2!O<&5N960@<V5C=&EO;BX@*B\*("`@("`@("!T:&ES+E]S970H<V5C
M=&EO;DED*3L*("`@('T*"B`@("!T:&ES+E]G970@/2!F=6YC=&EO;B@I"B`@
M("!["B`@("`@("`@<F5T=7)N('1H:7,N7V]P96Y396-T:6]N.PH@("`@?0H*
M("`@('1H:7,N7W-E="`](&9U;F-T:6]N*'-E8W1I;VY)9"D*("`@('L*("`@
M("`@("!V87(@9F]R;2`](&5V86PH)V1O8W5M96YT+B<@*R!T:&ES+E]I;G-T
M86YC94YA;64I.PH@("`@("`@(&EF("AT>7!E;V8@9F]R;2`A/2`G=6YD969I
M;F5D)R`F)@H@("`@("`@("`@("!T>7!E;V8@9F]R;2Y?7V9O<FU/<&5N4V5C
M=&EO;B`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@("`@("!F;W)M+E]?9F]R
M;4]P96Y396-T:6]N+G9A;'5E(#T@97-C87!E*'-E8W1I;VY)9"D["B`@("`@
M("`@?0H@("`@("`@('1H:7,N7V]P96Y396-T:6]N(#T@<V5C=&EO;DED.PH@
M("`@?0H*("`@('1H:7,N7W-E="AO<&5N4V5C=&EO;BD["GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E82YJ<P``````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,34S`#$P
M-#$W,S8S,#$Q`#`R,C<P,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!V87(@7V5D:71O<E]U<FP@/2`B/#]P:'`@96-H;R`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@
M/SXO<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+R(["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS```````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<W-``Q,#0Q-S,V,S`Q,0`P
M,C8Q,#4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'
M.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO;BP@
M:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%43U)3
M.@HO+PHO+R`@(#$N(%!,14%312!0550@64]54B!#3TY404-4($E.1D\@24X@
M5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E;6%I
M;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%(%541BTX
M($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB
M;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T('-T
M871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I!;G-E;$EM86=E
M+DDQ.$X@/2!["@DO+R!)=&5M<R!T:&%T(&%P<&5A<B!I;B!M96YU+B`@4&QE
M87-E(&YO=&4@=&AA="!A;B!U;F1E<G-C;W)E("A?*0H)+R\@8VAA<F%C=&5R
M(&EN('1H92!T<F%N<VQA=&EO;B`H<FEG:'0@8V]L=6UN*2!W:6QL(&-A=7-E
M('1H92!F;VQL;W=I;F<*"2\O(&QE='1E<B!T;R!B96-O;64@=6YD97)L:6YE
M9"!A;F0@8F4@<VAO<G1C=70@9F]R('1H870@;65N=2!O<'1I;VXN"@H)(DEN
M<V5R="!);6%G92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@26UA9V4B
M*2D@/SXB+`H)(DEM86=E(%523#HB("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"))
M;6%G92!54DPZ(BDI(#\^(BP*"2)%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B16YT97(@=&AE(&EM86=E(%523"!H97)E(BDI(#\^(BP*"2)0
M<F5V:65W(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4')E=FEE=R(I*2`_
M/B(L"@DB4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(B`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!R979I
M97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(I*2`_/B(L"@DB06QT97)N
M871E('1E>'0Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%L=&5R;F%T92!T97AT.B(I
M*2`_/B(L"@DB1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,B("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(BDI(#\^(BP*
M"2)0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(B`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&]S:71I;VYI
M;F<@;V8@=&AI<R!I;6%G92(I*2`_/B(L"@DB26UA9V4@4')E=FEE=SHB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(DEM86=E(%!R979I97<Z(BDI(#\^(BP*"2)'86QL
M97)Y.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1V%L;&5R>3HB*2D@/SXB
M+`H)(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(B`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;2(I*2`_/B(L"@DB26UA9V4@9G)O;2!G86QL
M97)Y.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(DEM86=E(&9R;VT@9V%L;&5R>3HB*2D@/SXB
M+`H)(DEM86=E(&9R;VT@9V%L;&5R>2(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));6%G92!F
M<F]M(&=A;&QE<GDB*2D@/SXB"GT["@`````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<P``````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30R,34`,3`T,3<S-C,P,3$`,#(U-#4T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\O
M($DQ.$X@8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@551&
M+3@@?"!)4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT='`Z
M+R]D>6YA<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*+R\*
M+R\@("`Q+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(12!!
M0D]612!,24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@861D
M<F5S<RD*+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&3U(@
M14Y#3T1)3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!P
M;&5A<V4@:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T97,@
M=VAA="!E;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*0V]N=&5X=$UE;G4N23$X
M3B`]('L*"2\O($ET96US('1H870@87!P96%R(&EN(&UE;G4N("!0;&5A<V4@
M;F]T92!T:&%T(&%N('5N9&5R<V-O<F4@*%\I"@DO+R!C:&%R86-T97(@:6X@
M=&AE('1R86YS;&%T:6]N("AR:6=H="!C;VQU;6XI('=I;&P@8V%U<V4@=&AE
M(&9O;&QO=VEN9PH)+R\@;&5T=&5R('1O(&)E8V]M92!U;F1E<FQI;F5D(&%N
M9"!B92!S:&]R=&-U="!F;W(@=&AA="!M96YU(&]P=&EO;BX*"@DB0W5T(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#=70B*2D@/SXB+`H)
M(D-O<'DB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V]P>2(I
M*2`_/B(L"@DB4&%S=&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")087-T92(I*2`_/B(L"@DB26UA9V4@4')O<&5R=&EE<R(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")?26UA9V4@4')O<&5R=&EE<RXN+B(I*2`_/B(L"@DB36]D
M:69Y($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")?36]D:69Y($QI
M;FLN+BXB*2D@/SXB+`H)(D-H96-K($QI;FLB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B0VAE8U]K($QI;FLN+BXB*2D@/SXB+`H)(E)E;6]V92!,:6YK
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B7U)E;6]V92!,:6YK+BXN(BDI
M(#\^(BP*"2)#96QL(%!R;W!E<G1I97,B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D-?96QL(%!R;W!E<G1I97,N+BXB*2D@/SXB+`H)(E)O=R!0<F]P97)T:65S
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F]?=R!0<F]P97)T:65S+BXN(BDI
M(#\^(BP*"2));G-E<G0@4F]W($)E9F]R92(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(DE?;G-E<G0@4F]W($)E9F]R92(I*2`_/B(L"@DB26YS97)T(%)O=R!!9G1E
M<B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*"));E]S97)T(%)O=R!!9G1E<B(I*2`_
M/B(L"@DB1&5L971E(%)O=R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")?
M1&5L971E(%)O=R(I*2`_/B(L"@DB1&5L971E($-E;&PB("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")$96QE=&4@0V5L;"(I*2`_/B(L"@DB5&%B;&4@4')O
M<&5R=&EE<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")?5&%B;&4@4')O<&5R=&EE
M<RXN+B(I*2`_/B(L"@DB26YS97)T($-O;'5M;B!"969O<F4B("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*"));G-E<G0@7T-O;'5M;B!"969O<F4B*2D@/SXB+`H)(DEN<V5R
M="!#;VQU;6X@069T97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T($-?;VQU
M;6X@069T97(B*2D@/SXB+`H)(D1E;&5T92!#;VQU;6XB("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B1&5?;&5T92!#;VQU;6XB*2D@/SXB+`H)(DIU<W1I9GD@
M3&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!,969T(BDI
M(#\^(BP*"2)*=7-T:69Y($-E;G1E<B(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(DIU<W1I9GD@0V5N=&5R(BDI(#\^(BP*"2)*=7-T:69Y(%)I9VAT(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@4FEG:'0B*2D@/SXB+`H)(DIU
M<W1I9GD@1G5L;"(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!&
M=6QL(BDI(#\^(BP*"2)-86ME(&QI;FLB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(DUA:V4@;&EN7VLN+BXB*2D@/SXB+`H)(E)E;6]V92!T:&4B("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F5M;W9E('1H92(I*2`_/B(L"@DB
M16QE;65N="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")%;&5M96YT
M+BXN(BDI(#\^(BP*"2));G-E<G0@<&%R86=R87!H(&)E9F]R92(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(BDI(#\^(BP*"2));G-E
M<G0@<&%R86=R87!H(&%F=&5R(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!P87)A
M9W)A<&@@869T97(B*2D@/SXB+`H*"2\O($]T:&5R(&QA8F5L<R`H=&]O;'1I
M<',@86YD(&%L97)T+V-O;F9I<FT@8F]X(&UE<W-A9V5S*0H*"2)0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M(B`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB*2D@/SXB
M+`H)(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(I*2`_/B(L"@DB2&]W
M(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(I*2`_/B(L"@DB4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9R(I*2`_/B(L"@DB36]D:69Y(%523"(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")-;V1I9GD@55),(BDI(#\^(BP*"2)#
M=7)R96YT(%523"!I<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-U<G)E;G0@
M55),(&ES(BDI(#\^(BP*"2)/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W(B`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B*2D@
M/SXB+`H)(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="XB("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+B(I*2`_/B(L"@DB3&EN:R!P;VEN=',@=&\Z(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"),:6YK('!O:6YT<R!T;SHB*2D@/SXB+`H)(E5N;&EN:R!T
M:&4@8W5R<F5N="!E;&5M96YT(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B56YL:6YK('1H92!C=7)R
M96YT(&5L96UE;G0B*2D@/SXB+`H)(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<B("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9R(I*2`_/B(L"@DB4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I
M97,@9&EA;&]G(B`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<B*2D@/SXB+`H)(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(BDI(#\^(BP*"2));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N92(@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(BDI
M(#\^(BP*"2)$96QE=&4@=&AE(&-U<G)E;G0@<F]W(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B*2D@/SXB+`H)(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(B`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4VAO=R!T:&4@5&%B;&4@4')O
M<&5R=&EE<R!D:6%L;V<B*2D@/SXB+`H)(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(BDI(#\^(BP*"2));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92(@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@
M=&AE(&-U<G)E;G0@;VYE(BDI(#\^(BP*"2)$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB
M*2D@/SXB+`H)(D-R96%T92!A(&QI;FLB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B0W)E871E(&$@;&EN:R(I*2`_/B(L"@DB26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(B`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4B*2D@/SXB+`H)(DEN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(B`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4B*2D@/SXB"GT["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R-34R`#$P-#$W
M,S8S,#$Q`#`R,S<Q,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!(5$U,07)E82Y),3A.(#T@>PH*"2\O('1H92!F;VQL;W=I
M;F<@<VAO=6QD(&)E('1H92!F:6QE;F%M92!W:71H;W5T("YJ<R!E>'1E;G-I
M;VX*"2\O(&ET('=I;&P@8F4@=7-E9"!F;W(@875T;VUA=&EC86QL>2!L;V%D
M('!L=6=I;B!L86YG=6%G92X*"6QA;F<Z(")E;B(L"@H)=&]O;'1I<',Z('L*
M"0EB;VQD.B`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")"
M;VQD(BDI(#\^(BP*"0EI=&%L:6,Z("`@("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"))=&%L:6,B*2D@/SXB+`H)"75N9&5R;&EN93H@("`@("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E5N9&5R;&EN92(I*2`_/B(L"@D)
M<W1R:6ME=&AR;W5G:#H@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W1R
M:6ME=&AR;W5G:"(I*2`_/B(L"@D)<W5B<V-R:7!T.B`@("`@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B4W5B<V-R:7!T(BDI(#\^(BP*"0ES=7!E<G-C
M<FEP=#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3=7!E<G-C<FEP
M="(I*2`_/B(L"@D):G5S=&EF>6QE9G0Z("`@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B2G5S=&EF>2!,969T(BDI(#\^(BP*"0EJ=7-T:69Y8V5N=&5R
M.B`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T:69Y($-E;G1E<B(I
M*2`_/B(L"@D):G5S=&EF>7)I9VAT.B`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B2G5S=&EF>2!2:6=H="(I*2`_/B(L"@D):G5S=&EF>69U;&PZ("`@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!&=6QL(BDI(#\^
M(BP*"0EO<F1E<F5D;&ES=#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")/<F1E<F5D($QI<W0B*2D@/SXB+`H)"75N;W)D97)E9&QI<W0Z("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)U;&QE=&5D($QI<W0B*2D@/SXB+`H)
M"6]U=&1E;G0Z("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D1E
M8W)E87-E($EN9&5N="(I*2`_/B(L"@D):6YD96YT.B`@("`@("`@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B26YC<F5A<V4@26YD96YT(BDI(#\^(BP*
M"0EF;W)E8V]L;W(Z("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")&
M;VYT($-O;&]R(BDI(#\^(BP*"0EH:6QI=&5C;VQO<CH@("`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")"86-K9W)O=6YD($-O;&]R(BDI(#\^(BP*"0EI
M;G-E<G1H;W)I>F]N=&%L<G5L93H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")(;W)I>F]N=&%L(%)U;&4B*2D@/SXB+`H)"6-R96%T96QI;FLZ("`@("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!796(@3&EN:R(I*2`_
M/B(L"@D):6YS97)T:6UA9V4Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B26YS97)T+TUO9&EF>2!);6%G92(I*2`_/B(L"@D):6YS97)T=&%B;&4Z
M("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(%1A8FQE(BDI
M(#\^(BP*"0EH=&UL;6]D93H@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")4;V=G;&4@2%1-3"!3;W5R8V4B*2D@/SXB+`H)"7!O<'5P961I=&]R
M.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D5N;&%R9V4@161I=&]R
M(BDI(#\^(BP*"0EA8F]U=#H@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")!8F]U="!T:&ES(&5D:71O<B(I*2`_/B(L"@D)<VAO=VAE;'`Z
M("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2&5L<"!U<VEN9R!E
M9&ET;W(B*2D@/SXB+`H)"71E>'1I;F1I8V%T;W(Z("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D-U<G)E;G0@<W1Y;&4B*2D@/SXB+`H)"75N9&\Z("`@
M("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(BDI(#\^(BP*"0ER961O.B`@("`@("`@("`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")2961O97,@>6]U<B!L87-T(&%C=&EO;B(I
M*2`_/B(L"@D)8W5T.B`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0W5T('-E;&5C=&EO;B(I*2`_/B(L"@D)8V]P>3H@("`@("`@("`@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V]P>2!S96QE8W1I;VXB*2D@
M/SXB+`H)"7!A<W1E.B`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E!A<W1E(&9R;VT@8VQI<&)O87)D(BDI(#\^(BP*"0EL969T=&]R:6=H
M=#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(I*2`_/B(L"@D)<FEG:'1T;VQE9G0Z("`@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B*2D@
M/SXB+`H)"7)E;6]V969O<FUA=#H@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E)E;6]V92!F;W)M871T:6YG(BDI(#\^(BP*"0EP<FEN=#H@("`@("`@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0<FEN="!D;V-U;65N="(I
M*2`_/B(L"@D):VEL;'=O<F0Z("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0VQE87(@35-/9F9I8V4@=&%G<R(I*2`_/B(*"7TL"@H)8G5T=&]N
M<SH@>PH)"2)O:R(Z("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D]+(BDI(#\^(BP*"0DB8V%N8V5L(CH@("`@("`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")#86YC96PB*2D@/SXB"@E]+`H*"6US9SH@>PH)"2)0
M871H(CH@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!A=&@B
M*2D@/SXB+`H)"2)415A47TU/1$4B.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(I*2`_/B(L"@H)"2))
M12US=6-K<RUF=6QL+7-C<F5E;B(@.@H)"2\O('1R86YS;&%T92!H97)E"@D)
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B
M86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@
M<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N(BDI(#\^(BP*"@D)(DUO>BU#;&EP8F]A<F0B(#H*"0DB/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U
M<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO
M=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO
M=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB*2D@/SXB"@E]
M+`H*"61I86QO9W,Z('L*"0DO+R!#;VUM;VX*"0DB3TLB("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D]+(BDI(#\^(BP*"0DB0V%N8V5L(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-A;F-E;"(I*2`_/B(L"@H)"2)!;&EG
M;FUE;G0Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06QI9VYM96YT.B(I*2`_
M/B(L"@D)(DYO="!S970B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*").;W0@
M<V5T(BDI(#\^(BP*"0DB3&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(DQE9G0B*2D@/SXB+`H)"2)2:6=H="(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B4FEG:'0B*2D@/SXB+`H)"2)497AT=&]P(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B5&5X='1O<"(I*2`_/B(L"@D)(D%B<VUI9&1L92(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")!8G-M:61D;&4B*2D@/SXB+`H)"2)"
M87-E;&EN92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0F%S96QI;F4B*2D@
M/SXB+`H)"2)!8G-B;W1T;VTB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06)S
M8F]T=&]M(BDI(#\^(BP*"0DB0F]T=&]M(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(D)O='1O;2(I*2`_/B(L"@D)(DUI9&1L92(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")-:61D;&4B*2D@/SXB+`H)"2)4;W`B("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B5&]P(BDI(#\^(BP*"@D)(DQA>6]U="(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),87EO=70B*2D@/SXB+`H)"2)3
M<&%C:6YG(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W!A8VEN9R(I*2`_
M/B(L"@D)(DAO<FEZ;VYT86PZ(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")(;W)I
M>F]N=&%L.B(I*2`_/B(L"@D)(DAO<FEZ;VYT86P@<&%D9&EN9R(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")(;W)I>F]N=&%L('!A9&1I;F<B*2D@/SXB+`H)"2)697)T:6-A
M;#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5F5R=&EC86PZ(BDI(#\^(BP*
M"0DB5F5R=&EC86P@<&%D9&EN9R(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E9E<G1I8V%L
M('!A9&1I;F<B*2D@/SXB+`H)"2)";W)D97(@=&AI8VMN97-S.B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B0F]R9&5R('1H:6-K;F5S<SHB*2D@/SXB+`H)"2),96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R(B`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<B(I*2`_/B(L"@H)"2\O($EN<V5R="!,:6YK"@D)(DEN<V5R="]-
M;V1I9GD@3&EN:R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0O36]D:69Y($QI;FLB
M*2D@/SXB+`H)"2).;VYE("AU<V4@:6UP;&EC:70I(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M3F]N92`H=7-E(&EM<&QI8VET*2(I*2`_/B(L"@D)(DYE=R!W:6YD;W<@*%]B
M;&%N:RDB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*").97<@=VEN9&]W("A?8FQA;FLI(BDI(#\^
M(BP*"0DB4V%M92!F<F%M92`H7W-E;&8I(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-A;64@
M9G)A;64@*%]S96QF*2(I*2`_/B(L"@D)(E1O<"!F<F%M92`H7W1O<"DB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")4;W`@9G)A;64@*%]T;W`I(BDI(#\^(BP*"0DB3W1H
M97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D]T:&5R(BDI(#\^(BP*
M"0DB5&%R9V5T.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1A<F=E=#HB
M*2D@/SXB+`H)"2)4:71L92`H=&]O;'1I<"DZ(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M5&ET;&4@*'1O;VQT:7`I.B(I*2`_/B(L"@D)(E523#HB("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")54DPZ(BDI(#\^(BP*"0DB66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(B`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO=2!M=7-T(&5N=&5R('1H92!54DP@
M=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(I*2`_/B(L"@D)+R\@26YS97)T
M(%1A8FQE"@D)(DEN<V5R="!486)L92(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"))
M;G-E<G0@5&%B;&4B*2D@/SXB+`H)"2)2;W=S.B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B4F]W<SHB*2D@/SXB+`H)"2).=6UB97(@;V8@<F]W<R(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B3G5M8F5R(&]F(')O=W,B*2D@/SXB+`H)"2)#
M;VQS.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V]L<SHB*2D@/SXB
M+`H)"2).=6UB97(@;V8@8V]L=6UN<R(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3G5M8F5R
M(&]F(&-O;'5M;G,B*2D@/SXB+`H)"2)7:61T:#HB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B5VED=&@Z(BDI(#\^(BP*"0DB5VED=&@@;V8@=&AE('1A
M8FQE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(E=I9'1H(&]F('1H92!T86)L92(I*2`_/B(L
M"@D)(E!E<F-E;G0B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")097)C96YT
M(BDI(#\^(BP*"0DB4&EX96QS(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E!I>&5L<R(I*2`_/B(L"@D)(D5M(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")%;2(I*2`_/B(L"@D)(E=I9'1H('5N:70B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")7:61T:"!U;FET(BDI(#\^(BP*"0DB4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L92(@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4B*2D@/SXB+`H)"2)#96QL('-P86-I;F<Z(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B0V5L;"!S<&%C:6YG.B(I*2`_/B(L"@D)(E-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',B("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M(BDI(#\^(BP*"0DB0V5L;"!P861D:6YG.B(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D-E;&P@<&%D9&EN9SHB*2D@/SXB+`H)"2)3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(B`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D
M97(@:6X@8V5L;"(I*2`_/B(L"@D)+R\@26YS97)T($EM86=E"@D)(DEN<V5R
M="!);6%G92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@26UA9V4B*2D@
M/SXB+`H)"2));6%G92!54DPZ(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26UA
M9V4@55),.B(I*2`_/B(L"@D)(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B*2D@/SXB+`H)"2)0
M<F5V:65W(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4')E=FEE=R(I*2`_
M/B(L"@D)(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B*2D@/SXB+`H)"2)!;'1E
M<FYA=&4@=&5X=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06QT97)N871E('1E>'0Z
M(BDI(#\^(BP*"0DB1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,B("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(BDI(#\^
M(BP*"0DB4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4B*2D@/SXB+`H)"2));6%G92!0<F5V:65W
M.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B26UA9V4@4')E=FEE=SHB*2D@/SXB"@E]
M"GT["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<P`````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`P,@`Q,#0Q-S,V,S`Q,0`P,C4V,S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+R\@23$X3B!C
M;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'.B!55$8M."!\($E3
M3RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R
M8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%43U)3.@HO+PHO+R`@(#$N
M(%!,14%312!0550@64]54B!#3TY404-4($E.1D\@24X@5$A%($%"3U9%($Q)
M3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E;6%I;"!A9&1R97-S*0HO
M+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%(%541BTX($9/4B!%3D-/1$E.
M1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB;&4L('!L96%S92!I
M;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T('-T871E<R!W:&%T(&5N
M8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I,:7-T5'EP92Y),3A.(#T@>PH)(D1E
M8VEM86PB("`@("`@("`@("`@("`@(#H@("`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")$96-I;6%L(&YU;6)E<G,B*2D@/SXB+`H)(DQO=V5R(')O;6%N
M(B`@("`@("`@("`@(#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),
M;W=E<B!R;VUA;B!N=6UB97)S(BDI(#\^(BP*"2)5<'!E<B!R;VUA;B(@("`@
M("`@("`@("`Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B57!P97(@
M<F]M86X@;G5M8F5R<R(I*2`_/B(L"@DB3&]W97(@;&%T:6XB("`@("`@("`@
M("`@.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQO=V5R(&QA=&EN
M(&QE='1E<G,B*2D@/SXB+`H)(E5P<&5R(&QA=&EN(B`@("`@("`@("`@(#H@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")5<'!E<B!L871I;B!L971T
M97)S(BDI(#\^(BP*"2),;W=E<B!G<F5E:R(@("`@("`@("`@("`Z("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&]W97(@9W)E96L@;&5T=&5R<R(I
M*2`_/B(L"@DB3&ES=%-T>6QE5&]O;'1I<"(@("`@("`@.B`@("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*2(I*2`_/B(*?3L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-#8S`#$P
M-#$W,S8S,#$Q`#`R-3`V-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O+R!),3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N
M(BP@14Y#3T1)3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI
M:&%I($)A>F]N+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@
M5%)!3E-,051/4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!
M0U0@24Y&3R!)3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A
M('9A;&ED(&5M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!4
M3R!54T4@551&+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES
M(&YO="!P;W-S:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@
M("`@('1H870@<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*
M"E1A8FQE3W!E<F%T:6]N<RY),3A.(#T@>PH)(D%L:6=N(CH)"0D)"2`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")!;&EG;B(I*2`_/B(L"@DB06QL(&9O
M=7(@<VED97,B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06QL
M(&9O=7(@<VED97,B*2D@/SXB+`H)(D)A8VMG<F]U;F0B.@D)"0D)("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)A8VMG<F]U;F0B*2D@/SXB+`H)(D)A
M<V5L:6YE(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)A<V5L:6YE(BDI(#\^(BP*
M"2)";W)D97(B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)O
M<F1E<B(I*2`_/B(L"@DB0F]R9&5R<R(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B0F]R9&5R<R(I*2`_/B(L"@DB0F]T=&]M(CH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B0F]T=&]M(BDI(#\^(BP*"2)#4U,@4W1Y;&4B.@D)
M"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-T>6QE(%M#4U-=(BDI
M(#\^(BP*"2)#87!T:6]N(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")#87!T:6]N(BDI(#\^(BP*"2)#96QL(%!R;W!E<G1I97,B.B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")#96QL(%!R;W!E<G1I97,B*2D@/SXB+`H)(D-E;G1E<B(Z"0D)
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V5N=&5R(BDI(#\^(BP*
M"2)#:&%R(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#:&%R(BDI(#\^(BP*
M"2)#;VQL87!S960@8F]R9&5R<R(Z("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#;VQL87!S960@8F]R
M9&5R<R(I*2`_/B(L"@DB0V]L;W(B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(D-O;&]R(BDI(#\^(BP*"2)$97-C<FEP=&EO;B(Z"0D)"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&5S8W)I<'1I;VXB*2D@/SXB
M+`H)(D9'($-O;&]R(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")&1R!#;VQO<B(I*2`_/B(L"@DB1FQO870B.B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B1FQO870B*2D@/SXB+`H)(D9R86UE<R(Z"0D)"0D@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B1G)A;65S(BDI(#\^(BP*"2)(96EG:'0B.B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")(96EG:'0B*2D@/SXB+`H)(DAO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(CH@("`@("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_(BDI(#\^(BP*"2)(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(Z("`@("`@("`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/R(I*2`_/B(L"@DB26UA9V4@55),(CH)"0D)"2`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*"));6%G92!54DPB*2D@/SXB+`H)(DIU<W1I9GDB
M.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GDB*2D@/SXB+`H)(DQA>6]U
M="(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&%Y;W5T(BDI
M(#\^(BP*"2),969T(CH)"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B3&5F="(I*2`_/B(L"@DB36%R9VEN(CH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B36%R9VEN(BDI(#\^(BP*"2)-:61D;&4B.B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")-:61D;&4B*2D@/SXB+`H)(DYO(')U;&5S(CH)"0D)"2`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*").;R!R=6QE<R(I*2`_/B(L"@DB3F\@<VED
M97,B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DYO('-I9&5S
M(BDI(#\^(BP*"2).;VYE(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*").;VYE
M(BDI(#\^(BP*"2)0861D:6YG(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")0861D:6YG(BDI(#\^(BP*"2)0;&5A<V4@8VQI8VL@:6YT;R!S
M;VUE(&-E;&PB.B`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB*2D@/SXB
M+`H)(E)I9VAT(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")2
M:6=H="(I*2`_/B(L"@DB4F]W(%!R;W!E<G1I97,B.B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M4F]W(%!R;W!E<G1I97,B*2D@/SXB+`H)(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B.B`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,B*2D@/SXB+`H)(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY(CH)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(BDI(#\^
M(BP*"2)2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(Z"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'DB*2D@/SXB+`H)(E)U;&5S(CH)"0D)"2`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")2=6QE<R(I*2`_/B(L"@DB4W!A8VEN
M9R!A;F0@<&%D9&EN9R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W!A8VEN9R!A;F0@<&%D9&EN9R(I
M*2`_/B(L"@DB4W!A8VEN9R(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B4W!A8VEN9R(I*2`_/B(L"@DB4W5M;6%R>2(Z"0D)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B4W5M;6%R>2(I*2`_/B(L"@DB5$\M8V5L
M;"UD96QE=&4B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&5L
M971E(&-E;&PB*2D@/SXB+`H)(E1/+6-E;&PM:6YS97)T+6%F=&5R(CH)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!C96QL(&%F=&5R
M(BDI(#\^(BP*"2)43RUC96QL+6EN<V5R="UB969O<F4B.@D)"2`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@8V5L;"!B969O<F4B*2D@/SXB
M+`H)(E1/+6-E;&PM;65R9V4B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B365R9V4@8V5L;',B*2D@/SXB+`H)(E1/+6-E;&PM<')O<"(Z"0D)
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V5L;"!P<F]P97)T:65S
M(BDI(#\^(BP*"2)43RUC96QL+7-P;&ET(CH)"0D)("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(E-P;&ET(&-E;&PB*2D@/SXB+`H)(E1/+6-O;"UD96QE
M=&4B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&5L971E(&-O
M;'5M;B(I*2`_/B(L"@DB5$\M8V]L+6EN<V5R="UA9G1E<B(Z"0D)"2`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@8V]L=6UN(&%F=&5R(BDI
M(#\^(BP*"2)43RUC;VPM:6YS97)T+6)E9F]R92(Z"0D)"2`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*"));G-E<G0@8V]L=6UN(&)E9F]R92(I*2`_/B(L
M"@DB5$\M8V]L+7-P;&ET(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")3<&QI="!C;VQU;6XB*2D@/SXB+`H)(E1/+7)O=RUD96QE=&4B.@D)
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&5L971E(')O=R(I*2`_
M/B(L"@DB5$\M<F]W+6EN<V5R="UA8F]V92(Z"0D)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*"));G-E<G0@<F]W(&)E9F]R92(I*2`_/B(L"@DB5$\M
M<F]W+6EN<V5R="UU;F1E<B(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*"));G-E<G0@<F]W(&%F=&5R(BDI(#\^(BP*"2)43RUR;W<M<')O<"(Z
M"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F]W('!R;W!E<G1I
M97,B*2D@/SXB+`H)(E1/+7)O=RUS<&QI="(Z"0D)"0D@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B4W!L:70@<F]W(BDI(#\^(BP*"2)43RUT86)L92UP
M<F]P(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1A8FQE('!R
M;W!E<G1I97,B*2D@/SXB+`H)(E1A8FQE(%!R;W!E<G1I97,B.@D)"0D@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&%B;&4@4')O<&5R=&EE<R(I*2`_
M/B(L"@DB5&5X="!A;&EG;B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&5X="!A;&EG
M;B(I*2`_/B(L"@DB5&AE(&)O='1O;2!S:61E(&]N;'DB.@D)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE(&)O='1O;2!S:61E(&]N;'DB*2D@
M/SXB+`H)(E1H92!L969T+6AA;F0@<VED92!O;FQY(CH)"0D@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB*2D@
M/SXB+`H)(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(CH)"2`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(I*2`_/B(L"@DB5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(CH)
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY(BDI(#\^(BP*"2)4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>2(Z"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB*2D@/SXB+`H)(E1H92!T;W`@<VED92!O
M;FQY(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H92!T;W`@
M<VED92!O;FQY(BDI(#\^(BP*"2)4;W`B.B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")4;W`B*2D@/SXB+`H)(E5N<V5T(&-O;&]R(CH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E5N<V5T(&-O;&]R(BDI(#\^(BP*"2)697)T:6-A;"!A;&EG;B(Z("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")697)T:6-A;"!A;&EG;B(I*2`_/B(L"@DB5VED=&@B.@D)
M"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E=I9'1H(BDI(#\^(BP*
M"2)N;W0M9&5L+6QA<W0M8V5L;"(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RXB*2D@/SXB+`H)(FYO="UD96PM;&%S="UC
M;VPB.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(I*2`_/B(L"@DB;F]T+61E;"UL87-T+7)O=R(Z"0D)"2`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(BDI(#\^(BP*
M"2)P97)C96YT(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")P
M97)C96YT(BDI(#\^(BP*"2)P:7AE;',B.@D)"0D)("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(G!I>&5L<R(I*2`_/B(*?3L*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:V5Y8FEN9&EN9W,N:G,`````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-#<R,``Q,#0Q-S,V,S`Q,0`P,C,T,C``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J($IA=F%S8W)I<'0@
M;&EB<F%R>2!T;R!H86YD;&4@82!S970@;V8@:V5Y8FEN9&EN9W,N"B`J"B`J
M(%1H92!U<V5R('-H;W5L9"!I;F-L=61E('1H:7,@<V-R:7!T+"!A;F0@=&AE
M;B!C86QL('-E=$ME>6)I;F1I;F<H:V5Y+`H@*B!C86QL8F%C:RD@9F]R(&5A
M8V@@:V5Y8FEN9&EN9R!T:&%T(&ES(&1E<VER960N(%1H:7,@<V-R:7!T('=I
M;&P@=&%K92!C87)E"B`J(&]F(&QI<W1E;FEN9R!F;W(@:V5Y<')E<W-E<R!A
M;F0@;6%P<&EN9R!T:&5M('1O('1H92!C86QL8F%C:R!F=6YC=&EO;G,L(&]R
M"B`J(&1O:6YG(&YO=&AI;F<@:68@;F\@8V%L;&)A8VL@:7,@<V5T+@H@*@H@
M*B`D2&]R9&4Z(&AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VME>6)I;F1I
M;F=S+FIS+'8@,2XU+C0N-B`R,#`V+S`S+S(T(#$V.C`U.C(T(&-H=6-K($5X
M<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<&%C:V%G92!(;W)D90H@*B\*"B\J
M*@H@*B!!(&AA<V@@;V8@:V5Y8FEN9&EN9W,N"B`J"B`J($!V87(@7VME>4UA
M<`H@*B\*=F%R(%]K97E-87`@/2!N97<@07)R87DH*3L*"B\J*@H@*B!3970@
M=7`@=&AE(&ME>7!R97-S(&QI<W1E;F5R+@H@*B\*:68@*'1Y<&5O9B!D;V-U
M;65N="YC87!T=7)E179E;G1S("$]("=U;F1E9FEN960G*2!["B`@("!D;V-U
M;65N="YC87!T=7)E179E;G1S*$5V96YT+DM%65!215-3*3L*("`@(&1O8W5M
M96YT+F]N:V5Y<')E<W,@/2!K97E(86YD;&5R.PI](&5L<V4@>PH@("`@9&]C
M=6UE;G0N;VYK97ED;W=N(#T@:V5Y2&%N9&QE<CL*?0H*+RHJ"B`J(%-E=',@
M=7`@82!C86QL8F%C:R!F;W(@82!K97EC;V1E+@H@*@H@*B!`<&%R86T@:V5Y
M("`@("`@(%1H92!K97EC;V1E('1O('1R:6=G97(@;VXN"B`J($!P87)A;2!C
M86QL8F%C:R`@5&AE(&9U;F-T:6]N('1O(&-A;&P@=VAE;B`B:V5Y(B!I<R!P
M<F5S<V5D+B!3:&]U;&0@8F4@80H@*B`@("`@("`@("`@("`@("`@(&9U;F-T
M:6]N+B!)="!G971S('1H92!E=F5N="!A;F0@=&AE(&ME>6-O9&4@87,@<&%R
M86UE=&5R<RP*("H@("`@("`@("`@("`@("`@("!S;R!T:&%T('EO=2!C86X@
M=7-E(&]N92!F=6YC=&EO;B!T;R!H86YD;&4@;75L=&EP;&4@:V5Y<R!I9@H@
M*B`@("`@("`@("`@("`@("`@('EO=2!L:6ME+@H@*B\*9G5N8W1I;VX@<V5T
M2V5Y8FEN9&EN9RAK97DL(&-A;&QB86-K*0I["B`@("!I9B`H='EP96]F(%]K
M97E-87!;:V5Y72`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@(%]K97E-87!;
M:V5Y72`](%M=.PH@("`@?0H*("`@(&EF("AT>7!E;V8@8V%L;&)A8VL@/3T@
M)V9U;F-T:6]N)RD@>PH@("`@("`@(%]K97E-87!;:V5Y72YP=7-H*&-A;&QB
M86-K*3L*("`@('T@96QS92!["B`@("`@("`@7VME>4UA<%MK97E=+G!U<V@H
M;F5W($9U;F-T:6]N*"=E)RP@)VME>2<L(&-A;&QB86-K("L@)RAE+"!K97DI
M.R<I*3L*("`@('T*?0H*+RHJ"B`J($EN=F]K960@8GD@=&AE($IA=F%38W)I
M<'0@979E;G0@;6]D96P@=VAE;B!A(&ME>2!I<R!P<F5S<V5D+B!'971S"B`J
M('1H92!K97EC;V1E("AA='1E;7!T<R!T;R!H86YD;&4@86QL(&)R;W=S97)S
M*2!A;F0@;&]O:W,@=&\@<V5E(&EF"B`J('=E(&AA=F4@82!H86YD;&5R(&1E
M9FEN960@9F]R('1H870@:V5Y+B!)9B!S;RP@8V%L;"!I="X*("H*("H@0'!A
M<F%M(&4@(%1H92!E=F5N="!T;R!H86YD;&4N(%-H;W5L9"!B92!A(&ME>7!R
M97-S+@H@*B\*9G5N8W1I;VX@:V5Y2&%N9&QE<BAE*0I["B`@("!V87(@92`]
M(&4@?'P@=VEN9&]W+F5V96YT.PH*("`@(&EF("AE+FME>4-O9&4I('L*("`@
M("`@("!K97D@/2!E+FME>4-O9&4["B`@("!](&5L<V4@:68@*&4N=VAI8V@I
M('L*("`@("`@("!K97D@/2!E+G=H:6-H.PH@("`@?0H*("`@("\J($EF('1H
M97)E)W,@82!H86YD;&5R(&1E9FEN960@9F]R('1H92!K97D@=&AA="!W87,@
M<')E<W-E9"P@8V%L;`H@("`@("H@:70L('!A<W-I;F<@:6X@=&AE(&ME>6-O
M9&4@86YD('1H92!E=F5N="X@*B\*("`@(&EF("A?:V5Y36%P6VME>5TI('L*
M("`@("`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(%]K97E-87!;:V5Y72YL96YG
M=&@[("LK:2D@>PH@("`@("`@("`@("!I9B`H7VME>4UA<%MK97E=6VE=*&4L
M(&ME>2DI('L*("`@("`@("`@("`@("`@(&4N<F5T=7)N5F%L=64@/2!F86QS
M93L*("`@("`@("`@("`@("`@(&EF("AT>7!E;V8@92YP<F5V96YT1&5F875L
M="`]/2`G9G5N8W1I;VXG*2!["B`@("`@("`@("`@("`@("`@("`@92YP<F5V
M96YT1&5F875L="@I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!E+G)E='5R;E9A;'5E(#T@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0I]"@``````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<P``````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`R,S(T-P`Q,#0Q-S,V,S`Q,0`P,C,W,3$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=F%R(&-U
M<G)E;G1$871E+"!C=7)R96YT665A<BP@8W5R26UG260L(&-U<G)E;G1487)G
M970["@IF=6YC=&EO;B!O<&5N0V%L96YD87(H:6UG260L('1A<F=E="P@8V%L
M;&)A8VLI"GL*("`@(&EF("AD;V-U;65N="YG971%;&5M96YT0GE)9"AT87)G
M970@*R`G6WEE87)=)RDN=F%L=64@)B8@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H=&%R9V5T("L@)UMM;VYT:%TG*2YV86QU92`F)B!D;V-U;65N="YG971%
M;&5M96YT0GE)9"AT87)G970@*R`G6V1A>5TG*2YV86QU92D@>PH@("`@("`@
M('9A<B!D(#T@;F5W($1A=&4H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R
M9V5T("L@)UMY96%R72<I+G9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R9V5T("L@)UMM;VYT:%TG
M*2YV86QU92`M(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("!D;V-U;65N
M="YG971%;&5M96YT0GE)9"AT87)G970@*R`G6V1A>5TG*2YV86QU92D["B`@
M("!](&5L<V4@>PH@("`@("`@('9A<B!D(#T@;F5W($1A=&4H*3L*("`@('T*
M"B`@("!O<&5N1V]T;RAD+F=E=%1I;64H*2P@:6UG260L('1A<F=E="P@8V%L
M;&)A8VLI.PI]"@IF=6YC=&EO;B!O<&5N1V]T;RAT:6UE<W1A;7`L(&EM9TED
M+"!T87)G970L(&-A;&QB86-K*0I["B`@("!V87(@<F]W+"!C96QL+"!I;6<L
M(&QI;FLL(&1A>7,["@H@("`@8W5R<F5N=%1A<F=E="`]('1A<F=E=#L*"B`@
M("!V87(@9"`](&YE=R!$871E*'1I;65S=&%M<"D["B`@("!C=7)R96YT1&%T
M92`](&0["B`@("!M;VYT:"`](&0N9V5T36]N=&@H*3L*("`@(&-U<G)E;G19
M96%R(#T@9"YG971996%R*"D["B`@("!I9B`H8W5R<F5N=%EE87(@/"`Q.3`P
M*2!["B`@("`@("`@8W5R<F5N=%EE87(@*ST@,3DP,#L*("`@('T*("`@('9A
M<B!F:7)S=$]F36]N=&@@/2!N97<@1&%T92AC=7)R96YT665A<BP@;6]N=&@L
M(#$I.PH@("`@=F%R(&1I9F8@/2!F:7)S=$]F36]N=&@N9V5T1&%Y*"D@+2`Q
M.PH@("`@:68@*&1I9F8@/3T@+3$I('L*("`@("`@("!D:69F(#T@-CL*("`@
M('T*("`@('-W:71C:"`H;6]N=&@I('L*("`@(&-A<V4@,SH*("`@(&-A<V4@
M-3H*("`@(&-A<V4@.#H*("`@(&-A<V4@,3`Z"B`@("`@("`@9&%Y<R`](#,P
M.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@,3H*("`@("`@("!I9B`H8W5R
M<F5N=%EE87(@)2`T(#T](#`@)B8@*&-U<G)E;G1996%R("4@,3`P("$](#`@
M?'P@8W5R<F5N=%EE87(@)2`T,#`@/3T@,"DI('L*("`@("`@("`@("`@9&%Y
M<R`](#(Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&1A>7,@/2`R
M.#L*("`@("`@("!]"B`@("`@("`@8G)E86L["@H@("`@9&5F875L=#H*("`@
M("`@("!D87ES(#T@,S$["B`@("`@("`@8G)E86L["B`@("!]"@H@("`@=F%R
M('=D87ES(#T@6PH@("`@("`@("<\/W!H<"!E8VAO(%\H(DUO(BD@/SXG+`H@
M("`@("`@("<\/W!H<"!E8VAO(%\H(E1U(BD@/SXG+`H@("`@("`@("<\/W!H
M<"!E8VAO(%\H(E=E(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(E1H
M(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(D9R(BD@/SXG+`H@("`@
M("`@("<\/W!H<"!E8VAO(%\H(E-A(BD@/SXG+`H@("`@("`@("<\/W!H<"!E
M8VAO(%\H(E-U(BD@/SXG"B`@("!=.PH@("`@=F%R(&UO;G1H<R`](%L*("`@
M("`@("`G/#]P:'`@96-H;R!?*")*86YU87)Y(BD@/SXG+`H@("`@("`@("<\
M/W!H<"!E8VAO(%\H(D9E8G)U87)Y(BD@/SXG+`H@("`@("`@("<\/W!H<"!E
M8VAO(%\H(DUA<F-H(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(D%P
M<FEL(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(DUA>2(I(#\^)RP*
M("`@("`@("`G/#]P:'`@96-H;R!?*")*=6YE(BD@/SXG+`H@("`@("`@("<\
M/W!H<"!E8VAO(%\H(DIU;'DB*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@
M7R@B075G=7-T(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(E-E<'1E
M;6)E<B(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")/8W1O8F5R(BD@
M/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(DYO=F5M8F5R(BD@/SXG+`H@
M("`@("`@("<\/W!H<"!E8VAO(%\H(D1E8V5M8F5R(BD@/SXG"B`@("!=.PH*
M("`@('9A<B!L87EE<B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=G;W1O
M)RD["B`@("!I9B`H;&%Y97(N9FER<W1#:&EL9"D@>PH@("`@("`@(&QA>65R
M+G)E;6]V94-H:6QD*&QA>65R+F9I<G-T0VAI;&0I.PH@("`@?0H*("`@('9A
M<B!T86)L92`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1!0DQ%)RD["B`@
M("!V87(@=&)O9'D@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=40D]$62<I
M.PH@("`@=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH@("`@=&%B;&4N8VQA
M<W-.86UE(#T@)VET96TG.PH@("`@=&%B;&4N8V5L;%-P86-I;F<@/2`P.PH@
M("`@=&%B;&4N8V5L;%!A9&1I;F<@/2`R.PH@("`@=&%B;&4N8F]R9&5R(#T@
M,#L*("`@('1A8FQE+G-T>6QE+G=I9'1H(#T@)V%U=&\G.PH*("`@("\O(%1I
M=&QE(&)A<BX*("`@(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12
M)RD["B`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*
M("`@(&-E;&PN8V]L4W!A;B`](#<["B`@("!C96QL+F%L:6=N(#T@)W)I9VAT
M)SL*("`@(&-E;&PN8VQA<W-.86UE(#T@)VAE861E<B<["B`@("!L:6YK(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@;&EN:RYH<F5F(#T@
M)R,G.PH@("`@;&EN:RYO;F-L:6-K(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@
M("`@('9A<B!L87EE<B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=G;W1O
M)RD["B`@("`@("`@;&%Y97(N<W1Y;&4N=FES:6)I;&ET>2`]("=H:61D96XG
M.PH@("`@("`@(&EF("AL87EE<BYF:7)S=$-H:6QD*2!["B`@("`@("`@("`@
M(&QA>65R+G)E;6]V94-H:6QD*&QA>65R+F9I<G-T0VAI;&0I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@("!I;6<@/2!D;V-U
M;65N="YC<F5A=&5%;&5M96YT*"=)34<G*0H@("`@:6UG+G-R8R`]("<\/W!H
M<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R
M9&4G*2`_/B]C;&]S92YP;F<G.PH@("`@:6UG+F)O<F1E<B`](#`["B`@("!L
M:6YK+F%P<&5N9$-H:6QD*&EM9RD["B`@("!C96QL+F%P<&5N9$-H:6QD*&QI
M;FLI.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@=&)O9'DN87!P
M96YD0VAI;&0H<F]W*3L*"B`@("`O+R!996%R+@H@("`@<F]W(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@G5%(G*3L*("`@(&-E;&P@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*"=41"<I.PH@("`@8V5L;"YA;&EG;B`]("=L969T)SL*
M("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=!)RD["B`@("!L
M:6YK+FAR968@/2`G(R<["B`@("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO;B@I
M"B`@("!["B`@("`@("`@;F5W1&%T92`](&YE=R!$871E*&-U<G)E;G1996%R
M("T@,2P@8W5R<F5N=$1A=&4N9V5T36]N=&@H*2P@,2D["B`@("`@("`@;W!E
M;D=O=&\H;F5W1&%T92YG9714:6UE*"DL(&EM9TED+"!C=7)R96YT5&%R9V5T
M+"!C86QL8F%C:RD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@
M8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*("`@(&EM9R`](&1O8W5M96YT+F-R
M96%T945L96UE;G0H)TE-1R<I"B`@("!I;6<N<W)C(#T@)SP_<&AP(&5C:&\@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I(#\^
M+VYA=B]L969T+G!N9R<["B`@("!I;6<N86QI9VX@/2`G;6ED9&QE)SL*("`@
M(&EM9RYB;W)D97(@/2`P.PH@("`@;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@
M("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH*("`@(&-E;&P@/2!D;V-U;65N
M="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@8V5L;"YC;VQ3<&%N(#T@-3L*
M("`@(&-E;&PN86QI9VX@/2`G8V5N=&5R)SL*("`@('9A<B!Y(#T@9&]C=6UE
M;G0N8W)E871E5&5X=$YO9&4H8W5R<F5N=%EE87(I.PH@("`@8V5L;"YA<'!E
M;F1#:&EL9"AY*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*"B`@("!C
M96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN
M86QI9VX@/2`G<FEG:'0G.PH@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H)T$G*3L*("`@(&QI;FLN:')E9B`]("<C)SL*("`@(&QI;FLN;VYC
M;&EC:R`](&9U;F-T:6]N*"D*("`@('L*("`@("`@("!N97=$871E(#T@;F5W
M($1A=&4H8W5R<F5N=%EE87(@*R`Q+"!C=7)R96YT1&%T92YG971-;VYT:"@I
M+"`Q*3L*("`@("`@("!O<&5N1V]T;RAN97=$871E+F=E=%1I;64H*2P@:6UG
M260L(&-U<G)E;G1487)G970L(&-A;&QB86-K*3L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"B`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@
M:6UG(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G24U')RD*("`@(&EM9RYS
M<F,@/2`G/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA
M9V5$:7(H)VAO<F1E)RD@/SXO;F%V+W)I9VAT+G!N9R<["B`@("!I;6<N86QI
M9VX@/2`G;6ED9&QE)SL*("`@(&EM9RYB;W)D97(@/2`P.PH@("`@;&EN:RYA
M<'!E;F1#:&EL9"AI;6<I.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@
M("`@=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*"B`@("`O+R!-;VYT:"!N86UE
M+@H@("`@<F]W(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5%(G*3L*("`@
M(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@8V5L
M;"YA;&EG;B`]("=L969T)SL*("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%
M;&5M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G(R<["B`@("!L:6YK+F]N
M8VQI8VL@/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@=F%R(&YE=TUO;G1H
M(#T@8W5R<F5N=$1A=&4N9V5T36]N=&@H*2`M(#$["B`@("`@("`@=F%R(&YE
M=UEE87(@/2!C=7)R96YT665A<CL*("`@("`@("!I9B`H;F5W36]N=&@@/3T@
M+3$I('L*("`@("`@("`@("`@;F5W36]N=&@@/2`Q,3L*("`@("`@("`@("`@
M;F5W665A<B`M/2`Q.PH@("`@("`@('T*("`@("`@("!N97=$871E(#T@;F5W
M($1A=&4H;F5W665A<BP@;F5W36]N=&@L(#$I.PH@("`@("`@(&]P96Y';W1O
M*&YE=T1A=&4N9V5T5&EM92@I+"!I;6=)9"P@8W5R<F5N=%1A<F=E="P@8V%L
M;&)A8VLI.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@(&-E;&PN
M87!P96YD0VAI;&0H;&EN:RD["B`@("!I;6<@/2!D;V-U;65N="YC<F5A=&5%
M;&5M96YT*"=)34<G*0H@("`@:6UG+G-R8R`]("<\/W!H<"!E8VAO("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2`_/B]N878O
M;&5F="YP;F<G.PH@("`@:6UG+F%L:6=N(#T@)VUI9&1L92<["B`@("!I;6<N
M8F]R9&5R(#T@,#L*("`@(&QI;FLN87!P96YD0VAI;&0H:6UG*3L*("`@(')O
M=RYA<'!E;F1#:&EL9"AC96QL*3L*"B`@("!C96QL(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN8V]L4W!A;B`](#4["B`@("!C
M96QL+F%L:6=N(#T@)V-E;G1E<B<["B`@("!V87(@;2`](&1O8W5M96YT+F-R
M96%T951E>'1.;V1E*&UO;G1H<UMM;VYT:%TI.PH@("`@8V5L;"YA<'!E;F1#
M:&EL9"AM*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*"B`@("!C96QL
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN86QI
M9VX@/2`G<FEG:'0G.PH@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE
M;G0H)T$G*3L*("`@(&QI;FLN:')E9B`]("<C)SL*("`@(&QI;FLN;VYC;&EC
M:R`](&9U;F-T:6]N*"D*("`@('L*("`@("`@("!N97=$871E(#T@;F5W($1A
M=&4H8W5R<F5N=%EE87(L(&-U<G)E;G1$871E+F=E=$UO;G1H*"D@*R`Q+"`Q
M*3L*("`@("`@("!O<&5N1V]T;RAN97=$871E+F=E=%1I;64H*2P@:6UG260L
M(&-U<G)E;G1487)G970L(&-A;&QB86-K*3L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"B`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@:6UG
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G24U')RD*("`@(&EM9RYS<F,@
M/2`G/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$
M:7(H)VAO<F1E)RD@/SXO;F%V+W)I9VAT+G!N9R<["B`@("!I;6<N86QI9VX@
M/2`G;6ED9&QE)SL*("`@(&EM9RYB;W)D97(@/2`P.PH@("`@;&EN:RYA<'!E
M;F1#:&EL9"AI;6<I.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@
M=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*"B`@("`O+R!7965K9&%Y<RX*("`@
M(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@("!F;W(@
M*'9A<B!I(#T@,#L@:2`\(#<[(&DK*RD@>PH@("`@("`@(&-E;&P@/2!D;V-U
M;65N="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@("`@('=E96MD87D@/2!D
M;V-U;65N="YC<F5A=&5497AT3F]D92AW9&%Y<UMI72D["B`@("`@("`@8V5L
M;"YA<'!E;F1#:&EL9"AW965K9&%Y*3L*("`@("`@("!R;W<N87!P96YD0VAI
M;&0H8V5L;"D["B`@("!]"B`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH*
M("`@("\O(%)O=W,N"B`@("!V87(@=V5E:RP@:71A;&EC.PH@("`@=F%R(&-O
M=6YT(#T@,3L*("`@('9A<B!T;V1A>2`](&YE=R!$871E*"D["B`@("!V87(@
M=&AI<UEE87(@/2!T;V1A>2YG971996%R*"D["B`@("!I9B`H=&AI<UEE87(@
M/"`Q.3`P*2!["B`@("`@("`@=&AI<UEE87(@*ST@,3DP,#L*("`@('T*"B`@
M("!V87(@;V1D(#T@=')U93L*("`@(&9O<B`H=F%R(&D@/2`Q.R!I(#P](&1A
M>7,[(&DK*RD@>PH@("`@("`@(&EF("AC;W5N="`]/2`Q*2!["B`@("`@("`@
M("`@(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@("`@
M("`@("`@(')O=RYA;&EG;B`]("=R:6=H="<["B`@("`@("`@("`@(&EF("AO
M9&0I('L*("`@("`@("`@("`@("`@(')O=RYC;&%S<TYA;64@/2`G:71E;3`G
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F]W+F-L
M87-S3F%M92`]("=I=&5M,2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M;V1D(#T@(6]D9#L*("`@("`@("!]"B`@("`@("`@:68@*&D@/3T@,2D@>PH@
M("`@("`@("`@("!F;W(@*'9A<B!J(#T@,#L@:B`\(&1I9F8[(&HK*RD@>PH@
M("`@("`@("`@("`@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M)U1$)RD["B`@("`@("`@("`@("`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D[
M"B`@("`@("`@("`@("`@("!C;W5N="LK.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=4
M1"<I.PH@("`@("`@(&EF("AT:&ES665A<B`]/2!C=7)R96YT665A<B`F)@H@
M("`@("`@("`@("!T;V1A>2YG971-;VYT:"@I(#T](&UO;G1H("8F"B`@("`@
M("`@("`@('1O9&%Y+F=E=$1A=&4H*2`]/2!I*2!["B`@("`@("`@("`@(&-E
M;&PN<W1Y;&4N8F]R9&5R(#T@)S%P>"!S;VQI9"!R960G.PH@("`@("`@('T*
M"B`@("`@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*
M("`@("`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH*("`@("`@("!L:6YK
M+FAR968@/2!I.PH@("`@("`@(&QI;FLN;VYC;&EC:R`](&9U;F-T:6]N*"D*
M("`@("`@("!["B`@("`@("`@("`@('9A<B!D87D@/2!T:&ES+FAR968["B`@
M("`@("`@("`@('=H:6QE("AD87DN:6YD97A/9B@G+R<I("$]("TQ*2!["B`@
M("`@("`@("`@("`@("!D87D@/2!D87DN<W5B<W1R:6YG*&1A>2YI;F1E>$]F
M*"<O)RD@*R`Q*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<V5T4V5L
M96-T5F%L=64H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H8W5R<F5N=%1A<F=E
M="`K("=;>65A<ETG*2P@8W5R<F5N=%EE87(I.PH@("`@("`@("`@("!S9713
M96QE8W1686QU92AD;V-U;65N="YG971%;&5M96YT0GE)9"AC=7)R96YT5&%R
M9V5T("L@)UMM;VYT:%TG*2P@8W5R<F5N=$1A=&4N9V5T36]N=&@H*2`K(#$I
M.PH@("`@("`@("`@("!S971396QE8W1686QU92AD;V-U;65N="YG971%;&5M
M96YT0GE)9"AC=7)R96YT5&%R9V5T("L@)UMD87E=)RDL(&1A>2D["@H@("`@
M("`@("`@("!V87(@;&%Y97(@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G
M9V]T;R<I.PH@("`@("`@("`@("!L87EE<BYS='EL92YV:7-I8FEL:71Y(#T@
M)VAI9&1E;B<["B`@("`@("`@("`@(&EF("AL87EE<BYF:7)S=$-H:6QD*2![
M"B`@("`@("`@("`@("`@("!L87EE<BYR96UO=F5#:&EL9"AL87EE<BYF:7)S
M=$-H:6QD*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&-A;&QB
M86-K*2!["B`@("`@("`@("`@("`@("!E=F%L*&-A;&QB86-K*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@9&%Y(#T@9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H:2D["B`@
M("`@("`@;&EN:RYA<'!E;F1#:&EL9"AD87DI.PH*("`@("`@("!R;W<N87!P
M96YD0VAI;&0H8V5L;"D["B`@("`@("`@:68@*&-O=6YT(#T](#<I('L*("`@
M("`@("`@("`@=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*("`@("`@("`@("`@
M8V]U;G0@/2`P.PH@("`@("`@('T*("`@("`@("!C;W5N="LK.PH@("`@?0H@
M("`@:68@*&-O=6YT(#X@,2D@>PH@("`@("`@(&9O<B`H:2`](&-O=6YT.R!I
M(#P](#<[(&DK*RD@>PH@("`@("`@("`@("!C96QL(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@G5$0G*3L*("`@("`@("`@("`@<F]W+F%P<&5N9$-H:6QD
M*&-E;&PI.PH@("`@("`@('T*("`@("`@("!T8F]D>2YA<'!E;F1#:&EL9"AR
M;W<I.PH@("`@?0H*("`@(&EF("AC=7));6=)9"`A/2!I;6=)9"D@>PH@("`@
M("`@("\O(%=E)W)E('-H;W=I;F<@=&AI<R!P;W!U<"!F;W(@=&AE(&9I<G-T
M('1I;64L('-O('1R>2!T;PH@("`@("`@("\O('!O<VET:6]N(&ET(&YE>'0@
M=&\@=&AE(&EM86=E(&%N8VAO<BX*("`@("`@("!V87(@96P@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"AI;6=)9"D["B`@("`@("`@=F%R('`@/2!G971!
M8G-O;'5T95!O<VET:6]N*&5L*3L*"B`@("`@("`@;&%Y97(N<W1Y;&4N;&5F
M="`]('`N>"`K("=P>"<["B`@("`@("`@;&%Y97(N<W1Y;&4N=&]P(#T@<"YY
M("L@)W!X)SL*("`@('T*"B`@("!C=7));6=)9"`](&EM9TED.PH@("`@;&%Y
M97(N87!P96YD0VAI;&0H=&%B;&4I.PH*("`@(&QA>65R+G-T>6QE+F1I<W!L
M87D@/2`G8FQO8VLG.PH@("`@;&%Y97(N<W1Y;&4N=FES:6)I;&ET>2`]("=V
M:7-I8FQE)SL*?0H*9G5N8W1I;VX@9V5T06)S;VQU=&50;W-I=&EO;BAE;"D*
M>PH@("`@=F%R('(@/2![>#H@96PN;V9F<V5T3&5F="P@>3H@96PN;V9F<V5T
M5&]P?3L*("`@(&EF("AE;"YO9F9S971087)E;G0I('L*("`@("`@("!V87(@
M=&UP(#T@9V5T06)S;VQU=&50;W-I=&EO;BAE;"YO9F9S971087)E;G0I.PH@
M("`@("`@('(N>"`K/2!T;7`N>#L*("`@("`@("!R+GD@*ST@=&UP+GD["B`@
M("!]"B`@("!R971U<FX@<CL*?0H*9G5N8W1I;VX@<V5T4V5L96-T5F%L=64H
M<V5L96-T+"!V86QU92D*>PH@("`@<V5L96-T+G9A;'5E(#T@=F%L=64["B`@
M("!I9B`H<V5L96-T+G9A;'5E("$]('9A;'5E*2!["B`@("`@("`@9F]R("AI
M(#T@,#L@:2`\('-E;&5C="YO<'1I;VYS+FQE;F=T:#L@:2LK*2!["B`@("`@
M("`@("`@(&EF("AS96QE8W0N;W!T:6]N<UMI72YV86QU92`]/2!V86QU92D@
M>PH@("`@("`@("`@("`@("`@<V5L96-T+G-E;&5C=&5D26YD97@@/2!I.PH@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@<F5T=7)N(&9A;'-E.PI]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]G;V]G;&5?=VEN+FIS````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C(T-0`Q,#0Q-S,V,S`Q,0`P,C0R-C0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````9G5N8W1I;VX@
M;W!E;E]G;V]G;&5?=VEN*&%R9W,I"GL*("`@('9A<B!V86PL('5R;"`]("<G
M.PH*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@9&]C=6UE;G0N9V]O9VQE+F%R
M96$N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H9&]C=6UE;G0N9V]O9VQE
M+F%R96%;:5TN8VAE8VME9"D@>PH@("`@("`@("`@("!V86P@/2!D;V-U;65N
M="YG;V]G;&4N87)E85MI72YV86QU93L*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@?0H@("`@?0H*("`@('-W:71C:"`H=F%L*2!["@EC87-E("=W96(G
M.@H@("`@"75R;"`]("=H='1P.B\O=W=W+F=O;V=L92YC;VTO<V5A<F-H/R<[
M"@D@("`@8G)E86L["@H)8V%S92`G:6UA9V5S)SH*"2`@("!U<FP@/2`G:'1T
M<#HO+VEM86=E<RYG;V]G;&4N8V]M+VEM86=E<S\G.PH@("`@("`@(&)R96%K
M.PH*"6-A<V4@)V=R;W5P<R<Z"@D@("`@=7)L(#T@)VAT='`Z+R]G<F]U<',N
M9V]O9VQE+F-O;2]G<F]U<',_)SL*("`@("`@("!B<F5A:SL*"@EC87-E("=D
M:7)E8W1O<GDG.@H)("`@('5R;"`]("=H='1P.B\O=W=W+F=O;V=L92YC;VTO
M<V5A<F-H/V-A=#UG=V0E,D94;W`F)SL*("`@("`@("!B<F5A:SL*"@EC87-E
M("=N97=S)SH*"2`@("!U<FP@/2`G:'1T<#HO+VYE=W,N9V]O9VQE+F-O;2]N
M97=S/R<["B`@("`@("`@8G)E86L["@H)9&5F875L=#H*("`@(`EU<FP@/2`G
M:'1T<#HO+W=W=RYG;V]G;&4N8V]M+W-E87)C:#\G.PH@("`@?0H@("`@=7)L
M("L]("=Q/2<["B`@("!I9B`H='EP96]F(&5N8V]D955224-O;7!O;F5N="`]
M/2`G=6YD969I;F5D)RD@>PH@("`@("`@('5R;"`K/2!E<V-A<&4H9&]C=6UE
M;G0N9V]O9VQE+G$N=F%L=64I.PH@("`@?2!E;'-E('L*("`@("`@("!U<FP@
M*ST@96YC;V1E55))0V]M<&]N96YT*&1O8W5M96YT+F=O;V=L92YQ+G9A;'5E
M*3L*("`@('T*"B`@("!V87(@;F%M92`]("=';V]G;&4G.PH@("`@=F%R('!A
M<F%M(#T@)W1O;VQB87(]>65S+&QO8V%T:6]N/7EE<RQS=&%T=7,]>65S+'-C
M<F]L;&)A<G,]>65S+')E<VEZ86)L93UY97,L=VED=&@].#`P+&AE:6=H=#TV
M,#`L;&5F=#TP+'1O<#TP)SL*"B`@("!E=F%L*"=N86UE(#T@=VEN9&]W+F]P
M96XH=7)L+"!N86UE+"!P87)A;2DG*3L*("`@(&EF("@A979A;"@G;F%M92YO
M<&5N97(G*2D@>PH@("`@("`@(&5V86PH)VYA;64N;W!E;F5R(#T@<V5L9B<I
M.PH@("`@?0I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7VAT;6Q?:&5L<&5R+FIS````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,34P`#$P
M-#$W,S8S,#$Q`#`R-#0S,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O*BH*("H@2&]R9&4@2'1M;"!(96QP97(@2F%V87-C
M<FEP="!#;&%S<PH@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!C;&%S
M<R!I;G-E<G0@:'1M;"!T86=S(&)Y(&-L:6-K:6YG(&]N(&EC;VYS+@H@*@H@
M*B!4:&4@:&5L<&5R<R!A=F%I;&%B;&4Z"B`J("`@("`@96UO=&EC;VYS("T@
M9F]R(&EN<V5R=&EN9R!E;6]T:6-O;G,@<W1R:6YG<PH@*@H@*B`D2&]R9&4Z
M(&AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?:'1M;%]H96QP97(N
M:G,L=B`Q+C$R+C(N-"`R,#`V+S`Q+S`Q(#(Q.C(Y.C$U(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`
M;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4@9&ED(&YO
M=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K
M:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!H;W)D90H@*B!`=&]D
M;R!A9&0@:&%N9&QI;F<@9F]R(&9O;G0@=&%G<RP@=&%B;&5S+"!E=&,N"B`J
M+PH*=F%R('1A<F=E=$5L96UE;G0["@IF=6YC=&EO;B!O<&5N2'1M;$AE;'!E
M<BAT>7!E+"!T87)G970I"GL*("`@('9A<B!L87D@/2!D;V-U;65N="YG971%
M;&5M96YT0GE)9"@G:'1M;&AE;'!E<E\G("L@=&%R9V5T*3L*("`@('1A<F=E
M=$5L96UE;G0@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AT87)G970I.PH*
M("`@(&EF("AL87DN<W1Y;&4N9&ES<&QA>2`]/2`G8FQO8VLG*2!["B`@("`@
M("`@;&%Y+G-T>6QE+F1I<W!L87D@/2`G;F]N92<["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@(&EF("AL87DN9FER<W1#:&EL9"D@>PH@("`@
M("`@(&QA>2YR96UO=F5#:&EL9"AL87DN9FER<W1#:&EL9"D["B`@("!]"@H@
M("`@=F%R('1A8FQE(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$%"3$4G
M*3L*("`@('9A<B!T8F]D>2`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1"
M3T19)RD["B`@("!T86)L92YA<'!E;F1#:&EL9"AT8F]D>2D["B`@("!T86)L
M92YC96QL4W!A8VEN9R`](#`["B`@("!T86)L92YB;W)D97(@/2`P.PH*("`@
M(&EF("AT>7!E(#T]("=E;6]T:6-O;G,G*2!["B`@("`@("`@<F]W(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@G5%(G*3L*("`@("`@("!C96QL(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@("`@("`\/W!H<"!R97%U
M:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<[("1F:6QT97(@/2`F
M5&5X=%]&:6QT97(Z.G-I;F=L971O;B@G96UO=&EC;VYS)RD[("1I8V]N<R`]
M(&%R<F%Y7V9L:7`H)&9I;'1E<BT^9V5T26-O;G,H*2D[(&9O<F5A8V@@*"1I
M8V]N<R!A<R`D:6-O;B`]/B`D<W1R:6YG*3H@/SX*("`@("`@("!L:6YK(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@("`@(&QI;FLN:')E
M9B`]("<C)SL*("`@("`@("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*
M("`@("`@("`@("`@=&%R9V5T16QE;65N="YV86QU92`]('1A<F=E=$5L96UE
M;G0N=F%L=64@*R`G/#]P:'`@96-H;R`D<W1R:6YG(#\^)R`K("<@)SL*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!C96QL
M+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@("`@(&EM9R`](&1O8W5M96YT+F-R
M96%T945L96UE;G0H)TE-1R<I"B`@("`@("`@:6UG+G-R8R`]("<\/W!H<"!E
M8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G
M*2`N("<O96UO=&EC;VYS+R<@+B`D:6-O;B`N("<N<&YG)R`_/B<["B`@("`@
M("`@:6UG+F%L:6=N(#T@)VUI9&1L92<["B`@("`@("`@:6UG+F)O<F1E<B`]
M(#`["B`@("`@("`@;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@("`@("`@(#P_
M<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`@("`@<F]W+F%P<&5N9$-H:6QD*&-E
M;&PI.PH@("`@("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD["B`@("`@("`@
M=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH@("`@?0H*("`@(&QA>2YA<'!E
M;F1#:&EL9"AT86)L92D["B`@("!L87DN<W1Y;&4N9&ES<&QA>2`]("=B;&]C
M:R<["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M:F%V87-C<FEP="]P<FEN="YJ<P``````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`S-38R`#$P-#$W,S8S,#$Q`#`R,C(U,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\<V-R:7!T('1Y<&4](G1E>'0O
M:F%V87-C<FEP="(^"CPA+2T*"G9A<B!D82`]("AD;V-U;65N="YA;&PI(#\@
M,2`Z(#`["G9A<B!P<B`]("AW:6YD;W<N<')I;G0I(#\@,2`Z(#`["G9A<B!M
M86,@/2`H;F%V:6=A=&]R+G5S97)!9V5N="YI;F1E>$]F*")-86,B*2`A/2`M
M,2D["@II9B`H=VEN9&]W+F%D9$5V96YT3&ES=&5N97(I('L*("`@('=I;F1O
M=RYA9&1%=F5N=$QI<W1E;F5R*"=L;V%D)RP@<')I;G17:6XL(&9A;'-E*3L*
M?2!E;'-E(&EF("AW:6YD;W<N871T86-H179E;G0I('L*("`@('=I;F1O=RYA
M='1A8VA%=F5N="@G;VYL;V%D)RP@<')I;G17:6XI.PI](&5L<V4@:68@*'=I
M;F1O=RYO;FQO860@(3T@;G5L;"D@>PH@("`@=F%R(&]L9$]N3&]A9"`]('=I
M;F1O=RYO;FQO860["B`@("!W:6YD;W<N;VYL;V%D(#T@9G5N8W1I;VXH92D*
M("`@('L*("`@("`@("!O;&1/;DQO860H92D["B`@("`@("`@<')I;G17:6XH
M*3L*("`@('T["GT@96QS92!["B`@("!W:6YD;W<N;VYL;V%D(#T@<')I;G17
M:6X["GT*"F9U;F-T:6]N('!R:6YT5VEN*"D*>PH@("`@:68@*'!R*2!["B`@
M("`@("`@+R\@3E,T*RP@244U*PH@("`@("`@('=I;F1O=RYP<FEN="@I.PH@
M("`@?2!E;'-E(&EF("@A;6%C*2!["B`@("`@("`@+R\@244S(&%N9"!)130@
M;VX@4$,*("`@("`@("!60G!R:6YT5VEN*"D["B`@("!](&5L<V4@>PH@("`@
M("`@("\O(&5V97)Y=&AI;F<@96QS90H@("`@("`@(&AA;F1L95]E<G)O<B@I
M.PH@("`@?0I]"@IW:6YD;W<N;VYE<G)O<B`](&AA;F1L95]E<G)O<CL*=VEN
M9&]W+F]N869T97)P<FEN="`](&9U;F-T:6]N*"D@>W=I;F1O=RYC;&]S92@I
M?0H*9G5N8W1I;VX@:&%N9&QE7V5R<F]R*"D*>PH@("`@=VEN9&]W+F%L97)T
M*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO
M0V]M;6%N9"`K(%`@=&\@<')I;G0N(BDI(#\^)RD["B`@("!R971U<FX@=')U
M93L*?0H*:68@*"%P<B`F)B`A;6%C*2!["B`@("!I9B`H9&$I('L*("`@("`@
M("`O+R!4:&ES(&UU<W0@8F4@244T(&]R(&=R96%T97(*("`@("`@("!W8G9E
M<G,@/2`B.#@U-D8Y-C$M,S0P02TQ,40P+4$Y-D(M,#!#,#1&1#<P-4$R(CL*
M("`@('T@96QS92!["B`@("`@("`@+R\@=&AI<R!M=7-T(&)E($E%,RYX"B`@
M("`@("`@=V)V97)S(#T@(D5!0C(R04,S+3,P0S$M,3%#1BU!-T5"+3`P,#!#
M,#5"044P0B(["B`@("!]"@H@("`@9&]C=6UE;G0N=W)I=&4H(CQ/0DI%0U0@
M240]7")70EPB(%=)1%1(/5PB,%PB($A%24=(5#U<(C!<(B!#3$%34TE$/5PB
M0TQ3240Z(BD["B`@("!D;V-U;65N="YW<FET92AW8G9E<G,@*R`B7"(^(#PO
M3T)*14-4/B(I.PI]"@HO+R`M+3X*/"]S8W)I<'0^"@H\<V-R:7!T('1Y<&4]
M(G1E>'0O=F)S8W)I<'0B/@H\(2TM"@IS=6(@=VEN9&]W7V]N=6YL;V%D"B`@
M("!O;B!E<G)O<B!R97-U;64@;F5X=`H@("`@)R!*=7-T('1I9'D@=7`@=VAE
M;B!W92!L96%V92!T;R!B92!S=7)E('=E(&%R96XG=`H@("`@)R!K965P:6YG
M(&EN<W1A;F-E<R!O9B!T:&4@8G)O=W-E<B!C;VYT<F]L(&EN(&UE;6]R>0H@
M("`@<V5T(%="(#T@;F]T:&EN9PIE;F0@<W5B"@IS=6(@5D)P<FEN=%=I;@H@
M("`@3TQ%0TU$241?4%))3E0@/2`V"B`@("!O;B!E<G)O<B!R97-U;64@;F5X
M=`H*("`@("<@244T(&]B:F5C="!H87,@82!D:69F97)E;G0@8V]M;6%N9"!S
M=')U8W1U<F4*("`@(&EF(&1A('1H96X*("`@("`@("!C86QL(%="+D5X96-7
M0BA/3$5#341)1%]04DE.5"P@,2D*("`@(&5L<V4*("`@("`@("!C86QL(%="
M+DE/;&5#;VUM86YD5&%R9V5T+D5X96,H3TQ%0TU$241?4%))3E0L(#$L("(B
M+"`B(BD*("`@(&5N9"!I9@IE;F0@<W5B"@HG("TM/@H\+W-C<FEP=#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,`````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,34W-@`Q,#0Q-S,V,S`Q,0`P,C,T,3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,L=B`Q+C4@,C`P-"\P
M."\R-B`P,#HP-SHR.2!S;'5S87)Z($5X<"`D"B`J"B`J($!P86-K86=E($AO
M<F1E"B`J+PIF=6YC=&EO;B!T;V=G;&51=6]T94)L;V-K*&ED+"!L:6YE<RD*
M>PH@("`@=F%R(&)L;V-K(#T@;F5W($AO<F1E7TAI9&5A8FQE*"=Q8E\G("L@
M:60I.PH*("`@(&)L;V-K+G1O9V=L92@I.PH@("`@=&5X="`](&1O8W5M96YT
M+F-R96%T951E>'1.;V1E*&)L;V-K+G-H;W=N*"D@/PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<\/W!H<"!E8VAO(%\H(EM(:61E(%%U
M;W1E9"!497AT72(I(#\^)R`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)SP_<&AP(&5C:&\@7R@B6U-H;W<@475O=&5D(%1E>'0@+2(I
M(#\^("<@*R!L:6YE<R`K("<@/#]P:'`@96-H;R!?*")L:6YE<UTB*2`_/B<I
M.PH@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@
M(&QI;FLN:')E9B`]("<G.PH@("`@;&EN:RYC;&%S<TYA;64@/2`G=VED9V5T
M)SL*("`@(&QI;FLN<W1Y;&4N9F]N=%-I>F4@/2`G-S`E)SL*("`@(&QI;FLN
M;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH@("`@("`@('1O9V=L95%U;W1E0FQO
M8VLH:60L(&QI;F5S*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@
M("!L:6YK+F%P<&5N9$-H:6QD*'1E>'0I.PH*("`@('9A<B!T;V=G;&4@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@G<71?)R`K(&ED*3L*("`@(&EF("AT
M;V=G;&4N9FER<W1#:&EL9"D@>PH@("`@("`@('1O9V=L92YR96UO=F5#:&EL
M9"AT;V=G;&4N9FER<W1#:&EL9"D["B`@("!]"B`@("!T;V=G;&4N87!P96YD
M0VAI;&0H;&EN:RD["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O=&5S=%]J879A<V-R:7!T+FIS````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,38R-P`Q,#0Q-S,V,S`Q,0`P,C0S,C(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J($AO<F1E($IA=F%3
M8W)I<'0@1&5T96-T:6]N+@H@*@H@*B!4:&ES('-C<FEP="!W:6QL(&]N;'D@
M8F4@<G5N(&EF(&IA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@:6X@=&AE
M('-E<W-I;VX*("H@8G5T('1H96X@:&%S(&)E96X@<F4M96YA8FQE9"!I;B!T
M:&4@8G)O=W-E<BX@270@=VEL;"!C86QL('1H92!T;V=G;&5?:G,N<&AP"B`J
M('-C<FEP="!T;R!R96UO=F4@=&AE('-E<W-I;VX@<V5T=&EN9R!A;F0@<F5T
M=7)N(&)A8VL@=&\@=&AE(&]R:6=I;F%T:6YG(%523"X*("H*("H@)$AO<F1E
M.B!H;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]T97-T7VIA=F%S8W)I<'0N
M:G,L=B`Q+C(N,BXQ(#(P,#4O,3`O,3@@,3$Z,S0Z,#<@:F%N($5X<"`D"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*B\*"B\J(%-E="!T:&4@55),(&9O<B!T:&4@<V-R:7!T
M('1O('1O9V=L92!T:&4@<V5S<VEO;B!S971T:6YG<RX@*B\*=F%R('5R;"`]
M("<\/W!H<"!E8VAO(%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ=7)L*"1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N
M("<O<V5R=FEC97,O=&]G9VQE7VIS+G!H<"<L('1R=64I+"`G=F%L=64G+"`G
M,2<I.R`_/B<["@HO*B!!9&0@=&AE(&]R:6=I;F%T:6YG(%523"P@;&5S<R!T
M:&4@:'1T<#HO+SQD;VUA:6X^('9A;'5E+B`J+PIU<FP@*ST@)R9U<FP])R`K
M(&5N8V]D955224-O;7!O;F5N="AL;V-A=&EO;BYH<F5F+FUA=&-H*"]H='1P
M.EPO7"\N*C\H7"\N*BDO*5LQ72D["@IL;V-A=&EO;BYR97!L86-E*'5R;"D[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O=')E92YJ<P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`U,#0T-``Q,#0Q-S,V,S`Q,0`P,C(P-34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($AO<F1E
M(%1R964@2F%V87-C<FEP="!#;&%S<PH@*@H@*B!0<F]V:61E<R!T:&4@:F%V
M87-C<FEP="!C;&%S<R!T;R!C<F5A=&4@9'EN86UI8R!T<F5E<RX*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N
M8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U(&1I9"!N;W0*("H@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@:&]R9&4O=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O=')E92YJ<RQV(#$N-C(N,BXQ,2`R,#`V+S`Q+S`Q(#(Q
M.C(Y.C$U(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@
M/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!(;W)D95]4<F5E"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B\*9G5N8W1I;VX@2&]R9&5?5')E92AI;G-T
M86YC94YA;64I"GL*("`@("\J(%-E="!U<"!T:&ES(&-L87-S(&EN<W1A;F-E
M(&9O<B!F=6YC=&EO;B!C86QL<R!F<F]M('1H92!P86=E+B`J+PH@("`@=&AI
M<RY?:6YS=&%N8V5.86UE(#T@:6YS=&%N8V5.86UE.PH*("`@("\J($EM86=E
M('9A<FEA8FQE<RX@*B\*("`@('1H:7,N:6UG1&ER("`@("`@("`@/2`G/#]P
M:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO
M<F1E)RD@+B`G+W1R964G.R`_/B<["B`@("!T:&ES+FEM9T)L86YK("`@("`@
M(#T@)V)L86YK+G!N9R<["B`@("!T:&ES+FEM9T9O;&1E<B`@("`@(#T@)V9O
M;&1E<BYP;F<G.PH@("`@=&AI<RYI;6=&;VQD97)/<&5N("`]("=F;VQD97)O
M<&5N+G!N9R<["@H@("`@+RH@5F%R:6%B;&5S('1H870@8VAA;F=E(&)A<V5D
M(&]N('1E>'0@9&ER96-T:6]N+B`J+PH\/W!H<"!I9B`H96UP='DH)$=,3T)!
M3%-;)VYL<R==6R=R=&PG75LD1TQ/0D%,4ULG;&%N9W5A9V4G75TI*3H@/SX*
M("`@('1H:7,N9FQO871$:7(@("`@("`@/2`G9FQO870Z;&5F=#LG.PH@("`@
M=&AI<RYI;6=,:6YE("`@("`@("`]("=L:6YE+G!N9R<["B`@("!T:&ES+FEM
M9TIO:6X@("`@("`@(#T@)VIO:6XN<&YG)SL*("`@('1H:7,N:6UG2F]I;D)O
M='1O;2`@/2`G:F]I;F)O='1O;2YP;F<G.PH@("`@=&AI<RYI;6=0;'5S("`@
M("`@("`]("=P;'5S+G!N9R<["B`@("!T:&ES+FEM9U!L=7-";W1T;VT@(#T@
M)W!L=7-B;W1T;VTN<&YG)SL*("`@('1H:7,N:6UG4&QU<T]N;'D@("`@/2`G
M<&QU<V]N;'DN<&YG)SL*("`@('1H:7,N:6UG36EN=7,@("`@("`@/2`G;6EN
M=7,N<&YG)SL*("`@('1H:7,N:6UG36EN=7-";W1T;VT@/2`G;6EN=7-B;W1T
M;VTN<&YG)SL*("`@('1H:7,N:6UG36EN=7-/;FQY("`@/2`G;6EN=7-O;FQY
M+G!N9R<["B`@("!T:&ES+FEM9TYU;&Q/;FQY("`@(#T@)VYU;&QO;FQY+G!N
M9R<["B`@("!T:&ES+FEM9TQE868@("`@("`@(#T@)VQE868N<&YG)SL*/#]P
M:'`@96QS93H@/SX*("`@('1H:7,N9FQO871$:7(@("`@("`@/2`G9FQO870Z
M<FEG:'0[)SL*("`@('1H:7,N:6UG3&EN92`@("`@("`@/2`G<F5V+6QI;F4N
M<&YG)SL*("`@('1H:7,N:6UG2F]I;B`@("`@("`@/2`G<F5V+6IO:6XN<&YG
M)SL*("`@('1H:7,N:6UG2F]I;D)O='1O;2`@/2`G<F5V+6IO:6YB;W1T;VTN
M<&YG)SL*("`@('1H:7,N:6UG4&QU<R`@("`@("`@/2`G<F5V+7!L=7,N<&YG
M)SL*("`@('1H:7,N:6UG4&QU<T)O='1O;2`@/2`G<F5V+7!L=7-B;W1T;VTN
M<&YG)SL*("`@('1H:7,N:6UG4&QU<T]N;'D@("`@/2`G<F5V+7!L=7-O;FQY
M+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S("`@("`@(#T@)W)E=BUM:6YU<RYP
M;F<G.PH@("`@=&AI<RYI;6=-:6YU<T)O='1O;2`]("=R978M;6EN=7-B;W1T
M;VTN<&YG)SL*("`@('1H:7,N:6UG36EN=7-/;FQY("`@/2`G<F5V+6UI;G5S
M;VYL>2YP;F<G.PH@("`@=&AI<RYI;6=.=6QL3VYL>2`@("`]("=R978M;G5L
M;&]N;'DN<&YG)SL*("`@('1H:7,N:6UG3&5A9B`@("`@("`@/2`G<F5V+6QE
M868N<&YG)SL*/#]P:'`@96YD:68[(#\^"@H@("`@+RH@5')E92!B=6EL9&EN
M9R!V87)I86)L97,N("HO"B`@("!T:&ES+G)E;F1E<E-T871I8R`@(#T@9F%L
M<V4["B`@("!T:&ES+G1A<F=E="`@("`@("`@(#T@)R<["B`@("!T:&ES+FAE
M861E<B`@("`@("`@(#T@;F5W($%R<F%Y*"D["B`@("!T:&ES+G)O;W1.;V1E
M<R`@("`@(#T@;F5W($%R<F%Y*"D["B`@("!T:&ES+FYO9&5S("`@("`@("`@
M(#T@;F5W($%R<F%Y*"D["B`@("!T:&ES+FYO9&5?<&]S("`@("`@(#T@;F5W
M($%R<F%Y*"D["B`@("!T:&ES+F1R;W!L:6YE("`@("`@(#T@;F5W($%R<F%Y
M*"D["B`@("!T:&ES+F]U='!U="`@("`@("`@(#T@)R<["GT*"DAO<F1E7U1R
M964N<')O=&]T>7!E+G-E=$EM9T1I<B`](&9U;F-T:6]N*&EM9T1I<BD*>PH@
M("`@=&AI<RYI;6=$:7(@/2!I;6=$:7(["GT*"DAO<F1E7U1R964N<')O=&]T
M>7!E+G)E;F1E<E1R964@/2!F=6YC=&EO;BAR;V]T3F]D97,L(')E;F1E<E-T
M871I8RD*>PH@("`@=&AI<RYR;V]T3F]D97,@/2!R;V]T3F]D97,["B`@("!T
M:&ES+G)E;F1E<E-T871I8R`](')E;F1E<E-T871I8SL*("`@('1H:7,N;F]D
M97,@/2!E=F%L*"=N7R<@*R!T:&ES+E]I;G-T86YC94YA;64I.PH@("`@=&AI
M<RYH96%D97(@/2!E=F%L*"=H7R<@*R!T:&ES+E]I;G-T86YC94YA;64I.PH@
M("`@=&AI<RYO<'1I;VYS(#T@979A;"@G;U\G("L@=&AI<RY?:6YS=&%N8V5.
M86UE*3L*("`@('1H:7,N=&%R9V5T(#T@)W1?)R`K('1H:7,N7VEN<W1A;F-E
M3F%M93L*("`@('1H:7,N7W)E;F1E<E1R964H*3L*?0H*2&]R9&5?5')E92YP
M<F]T;W1Y<&4N7W)E;F1E<E1R964@/2!F=6YC=&EO;B@I"GL*("`@('1H:7,N
M;W5T<'5T(#T@)R<["B`@("!I9B`H(71H:7,N;W!T:6]N<ULG:&ED94AE861E
M<G,G72D@>PH@("`@("`@('1H:7,N;W5T<'5T(#T@=&AI<RY?8G5I;&1(96%D
M97(H*3L*("`@('T*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@=&AI<RYR;V]T
M3F]D97,N;&5N9W1H.R!I*RLI('L*("`@("`@("!T:&ES+F)U:6QD5')E92AT
M:&ES+G)O;W1.;V1E<UMI72D["B`@("!]"B`@("!D;V-U;65N="YG971%;&5M
M96YT0GE)9"AT:&ES+G1A<F=E="DN:6YN97)(5$U,(#T@=&AI<RYO=71P=70[
M"B`@("!T:&ES+E]C;W)R96-T5VED=&A&;W)38W)O;&QB87(H*3L*("`@("\O
M($EF('5S:6YG(&%L=&5R;F%T:6YG(')O=R!S:&%D:6YG+"!W;W)K(&]U="!C
M;W)R96-T('-H861E+@H@("`@:68@*'1H:7,N;W!T:6]N<ULG86QT97)N871E
M)UTI('L*("`@("`@("!T:&ES+G-T<FEP92@I.PH@("`@?0I]"@HO*BH*("H@
M4F5T=7)N<R!T:&4@2%1-3"!C;V1E(&9O<B!A(&AE861E<B!R;W<L(&EF(&YE
M8V5S<V%R>2X*("H*("H@0&%C8V5S<R!P<FEV871E"B`J"B`J($!R971U<FX@
M<W1R:6YG("!4:&4@2%1-3"!C;V1E(&]F('1H92!H96%D97(@<F]W(&]R(&%N
M(&5M<'1Y('-T<FEN9RX*("HO"DAO<F1E7U1R964N<')O=&]T>7!E+E]B=6EL
M9$AE861E<B`](&9U;F-T:6]N*"D*>PH@("`@:68@*"%T:&ES+FAE861E<BYL
M96YG=&@I('L*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@=F%R(&AT
M;6P@/2`G/&1I=CXG.PH@("`@9F]R("AV87(@:2`](#`[(&D@/"!T:&ES+FAE
M861E<BYL96YG=&@[(&DK*RD@>PH@("`@("`@(&AT;6P@*ST@)SQD:78G.PH@
M("`@("`@(&EF("AT:&ES+FAE861E<EMI75LG8VQA<W,G72D@>PH@("`@("`@
M("`@("!H=&UL("L]("<@8VQA<W,](B<@*R!T:&ES+FAE861E<EMI75LG8VQA
M<W,G72`K("<B)SL*("`@("`@("!]"@H@("`@("`@('9A<B!S='EL92`]('1H
M:7,N9FQO871$:7(["B`@("`@("`@:68@*'1H:7,N:&5A9&5R6VE=6R=W:61T
M:"==*2!["B`@("`@("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH
M96%D97);:5U;)W=I9'1H)UT@*R`G.R<["B`@("`@("`@?0H@("`@("`@(&EF
M("AT:&ES+FAE861E<EMI75LG86QI9VXG72D@>PH@("`@("`@("`@("!S='EL
M92`K/2`G=&5X="UA;&EG;CHG("L@=&AI<RYH96%D97);:5U;)V%L:6=N)UT@
M*R`G.R<["B`@("`@("`@?0H*("`@("`@("!H=&UL("L]("<@<W1Y;&4](B<@
M*R!S='EL92`K("<B)SL*("`@("`@("!H=&UL("L]("<^)SL*("`@("`@("!H
M=&UL("L]('1H:7,N:&5A9&5R6VE=6R=H=&UL)UT@/R!T:&ES+FAE861E<EMI
M75LG:'1M;"==(#H@)R9N8G-P.R<["B`@("`@("`@:'1M;"`K/2`G/"]D:78^
M)SL*("`@('T*"B`@("!R971U<FX@:'1M;"`K("<\+V1I=CXG.PI]"@HO*BH*
M("H@4F5C=7)S:79E(&9U;F-T:6]N('1O('=A;&L@=&AR;W5G:"!T:&4@=')E
M92!A<G)A>2!A;F0@8G5I;&0*("H@=&AE(&]U='!U="X*("HO"DAO<F1E7U1R
M964N<')O=&]T>7!E+F)U:6QD5')E92`](&9U;F-T:6]N*&YO9&5)9"D*>PH@
M("`@=&AI<RYO=71P=70@*ST@=&AI<RYB=6EL9$QI;F4H;F]D94ED*3L*"B`@
M("!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG8VAI;&1R96XG72D@
M(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!V87(@;G5M4W5B;F]D97,@/2!T
M:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTN;&5N9W1H.PH@("`@("`@
M(&EF("AN=6U3=6)N;V1E<R`^(#`I('L*("`@("`@("`@("`@:68@*'1H:7,N
M;F]D97-;;F]D94ED75LG97AP86YD960G72D@>PH@("`@("`@("`@("`@("`@
M<F]W4W1Y;&4@/2`G9&ES<&QA>3IB;&]C:SLG.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<F]W4W1Y;&4@/2`G9&ES<&QA>3IN;VYE
M.R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@=&AI<RYO=71P=70@*ST@
M)SQD:78@:60](FYO9&5#:&EL9')E;E\G("L@;F]D94ED("L@)R(@<W1Y;&4]
M(B<@*R!R;W=3='EL92`K("<B/B<["@H@("`@("`@("`@("!F;W(@*'9A<B!C
M(#T@,#L@8R`\(&YU;5-U8FYO9&5S.R!C*RLI('L*("`@("`@("`@("`@("`@
M('9A<B!C:&EL9$YO9&5)9"`]('1H:7,N;F]D97-;;F]D94ED75LG8VAI;&1R
M96XG75MC73L*("`@("`@("`@("`@("`@('1H:7,N;F]D95]P;W-;8VAI;&1.
M;V1E261=(#T@;F5W($%R<F%Y*"D["B`@("`@("`@("`@("`@("!T:&ES+FYO
M9&5?<&]S6V-H:6QD3F]D94ED75LG<&]S)UT@/2!C("L@,3L*("`@("`@("`@
M("`@("`@('1H:7,N;F]D95]P;W-;8VAI;&1.;V1E261=6R=C;W5N="==(#T@
M;G5M4W5B;F]D97,["B`@("`@("`@("`@("`@("!T:&ES+F)U:6QD5')E92AC
M:&EL9$YO9&5)9"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('1H:7,N
M;W5T<'5T("L]("<\+V1I=CXG.PH@("`@("`@('T*("`@('T*"B`@("!R971U
M<FX@=')U93L*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N8G5I;&1,:6YE(#T@
M9G5N8W1I;VXH;F]D94ED*0I["B`@("!V87(@<W1Y;&4@/2`G)SL*("`@('9A
M<B!R;W=#;&%S<R`]("=T<F5E4F]W)SL*("`@(&EF("AT:&ES+FYO9&5S6VYO
M9&5)9%U;)V-L87-S)UTI('L*("`@("`@("!R;W=#;&%S<R`K/2`G("<@*R!T
M:&ES+FYO9&5S6VYO9&5)9%U;)V-L87-S)UT["B`@("!]"@H@("`@=F%R(&QI
M;F4@/2`G/&1I=B!C;&%S<STB)R`K(')O=T-L87-S("L@)R(^)SL*"B`@("`O
M+R!)9B!W92!H879E(&AE861E<G,L('1R86-K('=H:6-H(&QO9VEC86P@(F-O
M;'5M;B(@=V4G<F4@:6X@9F]R"B`@("`O+R!A;GD@9VEV96X@8V5L;"!O9B!C
M;VYT96YT+@H@("`@=F%R(&-O;'5M;B`](#`["@H@("`@:68@*'1Y<&5O9BAT
M:&ES+FYO9&5S6VYO9&5)9%U;)V5X=')A)UTI("$]("=U;F1E9FEN960G("8F
M"B`@("`@("`@='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG97AT<F$G75LP
M72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!V87(@97AT<F$@/2!T:&ES
M+FYO9&5S6VYO9&5)9%U;)V5X=')A)UU;,%T["B`@("`@("`@9F]R("AV87(@
M8R`](#`[(&,@/"!E>'1R82YL96YG=&@[(&,K*RD@>PH@("`@("`@("`@("!S
M='EL92`]('1H:7,N9FQO871$:7(["B`@("`@("`@("`@(&EF("AT:&ES+FAE
M861E<EMC;VQU;6Y=("8F('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI
M('L*("`@("`@("`@("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH
M96%D97);8V]L=6UN75LG=VED=&@G72`K("<[)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!L:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G
M(CXG("L@97AT<F%;8UT@*R`G/"]D:78^)SL*("`@("`@("`@("`@8V]L=6UN
M*RL["B`@("`@("`@?0H@("`@("`@(&9O<B`H=F%R(&0@/2!C.R!D(#P@97AT
M<F%#;VQS3&5F=#L@9"LK*2!["B`@("`@("`@("`@('-T>6QE(#T@=&AI<RYF
M;&]A=$1I<CL*("`@("`@("`@("`@:68@*'1H:7,N:&5A9&5R6V-O;'5M;ET@
M)B8@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G72D@>PH@("`@("`@("`@
M("`@("`@<W1Y;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU;6Y=
M6R=W:61T:"==("L@)SLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&QI
M;F4@*ST@)SQD:78@<W1Y;&4](B<@*R!S='EL92`K("<B/B9N8G-P.SPO9&EV
M/B<["B`@("`@("`@("`@(&-O;'5M;BLK.PH@("`@("`@('T*("`@('T@96QS
M92!["B`@("`@("`@9F]R("AV87(@8R`](#`[(&,@/"!E>'1R84-O;'-,969T
M.R!C*RLI('L*("`@("`@("`@("`@<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@
M("`@("`@("`@("!I9B`H=&AI<RYH96%D97);8V]L=6UN72`F)B!T:&ES+FAE
M861E<EMC;VQU;6Y=6R=W:61T:"==*2!["B`@("`@("`@("`@("`@("!S='EL
M92`K/2`G=VED=&@Z)R`K('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@
M*R`G.R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@;&EN92`K/2`G/&1I
M=B!S='EL93TB)R`K('-T>6QE("L@)R(^)FYB<W`[/"]D:78^)SL*("`@("`@
M("`@("`@8V]L=6UN*RL["B`@("`@("`@?0H@("`@?0H*("`@('-T>6QE(#T@
M=&AI<RYF;&]A=$1I<CL*("`@(&EF("AT:&ES+FAE861E<EMC;VQU;6Y=("8F
M('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI('L*("`@("`@("!S='EL
M92`K/2`G=VED=&@Z)R`K('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@
M*R`G.R<["B`@("!]"B`@("!L:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y
M;&4@*R`G(CXG.PH*("`@(&EF("AT:&ES+F]P=&EO;G-;)VUU;'1I;&EN92==
M*2!["B`@("`@("`@;&EN92`K/2`G/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX\
M='(^/'1D/B<["B`@("!]"@H@("`@9F]R("AV87(@:2`]('1H:7,N<F5N9&5R
M4W1A=&EC(#\@,2`Z(#`[(&D@/"!T:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N
M="==.R!I*RLI('L*("`@("`@("!I9B`H=&AI<RYD<F]P;&EN95MI72`F)B!T
M:&ES+F]P=&EO;G-;)VQI;F5S)UTI('L*("`@("`@("`@("`@;&EN92`K/2`G
M/&EM9R!S<F,](B<@*R!T:&ES+FEM9T1I<B`K("<O)R`K('1H:7,N:6UG3&EN
M92`K("<B(&%L=#TB?"9N8G-P.R9N8G-P.R9N8G-P.R(@:&5I9VAT/2(R,"(@
M=VED=&@](C(P(B`O/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M;&EN92`K/2`G/&EM9R!S<F,](B<@*R!T:&ES+FEM9T1I<B`K("<O)R`K('1H
M:7,N:6UG0FQA;FL@*R`G(B!A;'0](B9N8G-P.R9N8G-P.R9N8G-P.R(@:&5I
M9VAT/2(R,"(@=VED=&@](C(P(B`O/B<["B`@("`@("`@?0H@("`@?0H@("`@
M;&EN92`K/2!T:&ES+E]S971.;V1E5&]G9VQE*&YO9&5)9"D["B`@("!I9B`H
M=&AI<RYO<'1I;VYS6R=M=6QT:6QI;F4G72D@>PH@("`@("`@(&QI;F4@*ST@
M)SPO=&0^/'1D/B<["B`@("!]"B`@("!L:6YE("L]('1H:7,N7W-E=$QA8F5L
M*&YO9&5)9"D["@H@("`@:68@*'1H:7,N;W!T:6]N<ULG;75L=&EL:6YE)UTI
M('L*("`@("`@("!L:6YE("L]("<\+W1D/CPO='(^/"]T86)L93XG.PH@("`@
M?0H*("`@(&QI;F4@*ST@)SPO9&EV/B<["B`@("!C;VQU;6XK*SL*"B`@("!I
M9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG97AT<F$G72D@(3T@)W5N
M9&5F:6YE9"<@)B8*("`@("`@("!T>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=
M6R=E>'1R82==6S%=*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@('9A<B!E
M>'1R82`]('1H:7,N;F]D97-;;F]D94ED75LG97AT<F$G75LQ73L*("`@("`@
M("!F;W(@*'9A<B!C(#T@,#L@8R`\(&5X=')A+FQE;F=T:#L@8RLK*2!["B`@
M("`@("`@("`@('-T>6QE(#T@=&AI<RYF;&]A=$1I<CL*("`@("`@("`@("`@
M:68@*'1H:7,N:&5A9&5R6V-O;'5M;ET@)B8@=&AI<RYH96%D97);8V]L=6UN
M75LG=VED=&@G72D@>PH@("`@("`@("`@("`@("`@<W1Y;&4@*ST@)W=I9'1H
M.B<@*R!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==("L@)SLG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&QI;F4@*ST@)SQD:78@<W1Y;&4](B<@
M*R!S='EL92`K("<B/B<@*R!E>'1R85MC72`K("<\+V1I=CXG.PH@("`@("`@
M("`@("!C;VQU;6XK*SL*("`@("`@("!]"B`@("`@("`@9F]R("AV87(@9"`]
M(&,[(&0@/"!E>'1R84-O;'-2:6=H=#L@9"LK*2!["B`@("`@("`@("`@('-T
M>6QE(#T@=&AI<RYF;&]A=$1I<CL*("`@("`@("`@("`@:68@*'1H:7,N:&5A
M9&5R6V-O;'5M;ET@)B8@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G72D@
M>PH@("`@("`@("`@("`@("`@<W1Y;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE
M861E<EMC;VQU;6Y=6R=W:61T:"==("L@)SLG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&QI;F4@*ST@)SQD:78@<W1Y;&4](B<@*R!S='EL92`K("<B
M/B9N8G-P.SPO9&EV/B<["B`@("`@("`@("`@(&-O;'5M;BLK.PH@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@9F]R("AV87(@8R`](#`[(&,@/"!E
M>'1R84-O;'-2:6=H=#L@8RLK*2!["B`@("`@("`@("`@('-T>6QE(#T@=&AI
M<RYF;&]A=$1I<CL*("`@("`@("`@("`@:68@*'1H:7,N:&5A9&5R6V-O;'5M
M;ET@)B8@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G72D@>PH@("`@("`@
M("`@("`@("`@<W1Y;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU
M;6Y=6R=W:61T:"==("L@)SLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&QI;F4@*ST@)SQD:78@<W1Y;&4](B<@*R!S='EL92`K("<B/B9N8G-P.SPO
M9&EV/B<["B`@("`@("`@("`@(&-O;'5M;BLK.PH@("`@("`@('T*("`@('T*
M("`@(&QI;F4@*ST@)SPO9&EV/B<["@H@("`@<F5T=7)N(&QI;F4["GT*"DAO
M<F1E7U1R964N<')O=&]T>7!E+E]S971,86)E;"`](&9U;F-T:6]N*&YO9&5)
M9"D*>PH@("`@;&%B96P@/2!T:&ES+FYO9&5S6VYO9&5)9%U;)VQA8F5L)UT[
M"@H@("`@:68@*'1H:7,N;F]D97-;;F]D94ED75LG=7)L)UTI('L*("`@("`@
M("!V87(@=7)L0VQA<W,@/2`G)SL*("`@("`@("!I9B`H=&AI<RYN;V1E<UMN
M;V1E261=6R=U<FQC;&%S<R==*2!["B`@("`@("`@("`@('5R;$-L87-S(#T@
M)R!C;&%S<STB)R`K('1H:7,N;F]D97-;;F]D94ED75LG=7)L8VQA<W,G72`K
M("<B)SL*("`@("`@("!](&5L<V4@:68@*'1H:7,N;W!T:6]N<ULG=7)L8VQA
M<W,G72D@>PH@("`@("`@("`@("!U<FQ#;&%S<R`]("<@8VQA<W,](B<@*R!T
M:&ES+F]P=&EO;G-;)W5R;&-L87-S)UT@*R`G(B<["B`@("`@("`@?0H*("`@
M("`@("!V87(@=&%R9V5T(#T@)R<["B`@("`@("`@:68@*'1H:7,N;F]D97-;
M;F]D94ED75LG=&%R9V5T)UTI('L*("`@("`@("`@("`@=&%R9V5T(#T@)R!T
M87)G970](B<@*R!T:&ES+FYO9&5S6VYO9&5)9%U;)W1A<F=E="==("L@)R(G
M.PH@("`@("`@('T@96QS92!I9B`H=&AI<RYO<'1I;VYS6R=T87)G970G72D@
M>PH@("`@("`@("`@("!T87)G970@/2`G('1A<F=E=#TB)R`K('1H:7,N;W!T
M:6]N<ULG=&%R9V5T)UT@*R`G(B<["B`@("`@("`@?0H*("`@("`@("!V87(@
M;VYC;&EC:R`]("<G.PH@("`@("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;
M)V]N8VQI8VLG72D@>PH@("`@("`@("`@("!O;F-L:6-K(#T@)R!O;F-L:6-K
M/2(G("L@=&AI<RYN;V1E<UMN;V1E261=6R=O;F-L:6-K)UT@*R`G(B<["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)SQA)R`K('5R;$-L87-S("L@)R!H
M<F5F/2(G("L@=&AI<RYN;V1E<UMN;V1E261=6R=U<FPG72`K("<B)R`K('1A
M<F=E="`K(&]N8VQI8VL@*R`G/B<@*R!T:&ES+E]S971.;V1E26-O;BAN;V1E
M260I("L@;&%B96P@*R`G/"]A/B<["B`@("!](&5L<V4@>PH@("`@("`@(')E
M='5R;B`G/'-P86X@8VQA<W,](G1O9V=L92(@;VYC;&EC:STB)R`K('1H:7,N
M7VEN<W1A;F-E3F%M92`K("<N=&]G9VQE*%PG)R`K(&YO9&5)9"`K("=<)RDB
M/B<@*R!T:&ES+E]S971.;V1E26-O;BAN;V1E260I("L@;&%B96P@*R`G/"]S
M<&%N/B<["B`@("!]"GT*"DAO<F1E7U1R964N<')O=&]T>7!E+E]S971.;V1E
M5&]G9VQE(#T@9G5N8W1I;VXH;F]D94ED*0I["B`@("!V87(@871T<FEB(#T@
M)R<["B`@("!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=I;F1E;G0G72`]/2`G
M,"<@)B8*("`@("`@("!T>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL
M9')E;B==*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@("\O(%1O<"!L979E
M;"!W:71H(&-H:6QD<F5N+@H@("`@("`@('1H:7,N9')O<&QI;F5;,%T@/2!F
M86QS93L*("`@("`@("!I9B`H=&AI<RYR96YD97)3=&%T:6,I('L*("`@("`@
M("`@("`@<F5T=7)N("<G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&%T=')I8B`]("<@<W1Y;&4](F-U<G-O<CIP;VEN=&5R(B!O;F-L:6-K/2(G
M("L@=&AI<RY?:6YS=&%N8V5.86UE("L@)RYT;V=G;&4H7"<G("L@;F]D94ED
M("L@)UPG*2(G.PH@("`@("`@('T*("`@('T@96QS92!I9B`H=&AI<RYN;V1E
M<UMN;V1E261=6R=I;F1E;G0G72`A/2`G,"<@)B8*("`@("`@("`@("`@("`@
M='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG8VAI;&1R96XG72D@/3T@)W5N
M9&5F:6YE9"<I('L*("`@("`@("`O+R!.;V1E(&YO(&-H:6QD<F5N+@H@("`@
M("`@(&EF("AT:&ES+FYO9&5?<&]S6VYO9&5)9%U;)W!O<R==(#P@=&AI<RYN
M;V1E7W!O<UMN;V1E261=6R=C;W5N="==*2!["B`@("`@("`@("`@("\O($YO
M="!L87-T(&YO9&4N"B`@("`@("`@("`@('1H:7,N9')O<&QI;F5;=&AI<RYN
M;V1E<UMN;V1E261=6R=I;F1E;G0G75T@/2!T<G5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@('1H:7,N9')O<&QI;F5;=&AI<RYN;V1E<UMN;V1E
M261=6R=I;F1E;G0G75T@/2!F86QS93L*("`@("`@("!]"B`@("!](&5L<V4@
M:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI("$]
M("=U;F1E9FEN960G*2!["B`@("`@("`@+R\@3F]D92!W:71H(&-H:6QD<F5N
M+@H@("`@("`@(&EF("AT:&ES+FYO9&5?<&]S6VYO9&5)9%U;)W!O<R==(#P@
M=&AI<RYN;V1E7W!O<UMN;V1E261=6R=C;W5N="==*2!["B`@("`@("`@("`@
M("\O($YO="!L87-T(&YO9&4N"B`@("`@("`@("`@('1H:7,N9')O<&QI;F5;
M=&AI<RYN;V1E<UMN;V1E261=6R=I;F1E;G0G75T@/2!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O($QA<W0@;F]D92X*("`@("`@("`@
M("`@=&AI<RYD<F]P;&EN95MT:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==
M72`](&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H(71H:7,N<F5N9&5R
M4W1A=&EC*2!["B`@("`@("`@("`@(&%T=')I8B`]("<@<W1Y;&4](F-U<G-O
M<CIP;VEN=&5R(B!O;F-L:6-K/2(G("L@=&AI<RY?:6YS=&%N8V5.86UE("L@
M)RYT;V=G;&4H7"<G("L@;F]D94ED("L@)UPG*2(G.PH@("`@("`@('T*("`@
M('T@96QS92!["B`@("`@("`@+R\@5&]P(&QE=F5L(&YO9&4@=VET:"!N;R!C
M:&EL9')E;BX*("`@("`@("!I9B`H=&AI<RYR96YD97)3=&%T:6,I('L*("`@
M("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@("`@("!T:&ES+F1R
M;W!L:6YE6S!=(#T@9F%L<V4["B`@("!]"@H@("`@;F]D951O9V=L92`]('1H
M:7,N7V=E=$YO9&54;V=G;&4H;F]D94ED*3L*("`@(&EM9R`]("<\:6UG(&ED
M/2)N;V1E5&]G9VQE7R<@*R!N;V1E260@*R`G(B!S<F,](B<@*R!T:&ES+FEM
M9T1I<B`K("<O)R`K(&YO9&54;V=G;&5;,%T@*R`G(B`G.PH@("`@:68@*&YO
M9&54;V=G;&5;,5TI('L*("`@("`@("!I;6<@*ST@)V%L=#TB)R`K(&YO9&54
M;V=G;&5;,5T@*R`G(B`G.PH@("`@?0H@("`@:6UG("L](&%T=')I8B`K("<@
M:&5I9VAT/2(R,"(@=VED=&@](C(P(B`O/B<["B`@("!R971U<FX@:6UG.PI]
M"@I(;W)D95]4<F5E+G!R;W1O='EP92Y?9V5T3F]D951O9V=L92`](&9U;F-T
M:6]N*&YO9&5)9"D*>PH@("`@=F%R(&YO9&54;V=G;&4@/2!N97<@07)R87DH
M)R<L("<G*3L*("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==
M(#T]("<P)R`F)@H@("`@("`@('1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;
M)V-H:6QD<F5N)UTI("$]("=U;F1E9FEN960G*2!["B`@("`@("`@+R\@5&]P
M(&QE=F5L('=I=&@@8VAI;&1R96XN"B`@("`@("`@:68@*'1H:7,N<F5N9&5R
M4W1A=&EC*2!["B`@("`@("`@("`@(')E='5R;B!N;V1E5&]G9VQE.PH@("`@
M("`@('T@96QS92!I9B`H(71H:7,N;W!T:6]N<ULG;&EN97,G72D@>PH@("`@
M("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=";&%N:SL*("`@("`@
M("`@("`@;F]D951O9V=L95LQ72`]("<F;F)S<#LF;F)S<#LF;F)S<#LG"B`@
M("`@("`@?2!E;'-E(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D
M)UTI('L*("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG36EN
M=7-/;FQY.PH@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)RTG.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES
M+FEM9U!L=7-/;FQY.PH@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)RLG
M.PH@("`@("`@('T*("`@('T@96QS92!I9B`H=&AI<RYN;V1E<UMN;V1E261=
M6R=I;F1E;G0G72`A/2`G,"<@)B8*("`@("`@("!T>7!E;V8H=&AI<RYN;V1E
M<UMN;V1E261=6R=C:&EL9')E;B==*2`]/2`G=6YD969I;F5D)RD@>PH@("`@
M("`@("\O($YO9&4@;F\@8VAI;&1R96XN"B`@("`@("`@:68@*'1H:7,N;F]D
M95]P;W-;;F]D94ED75LG<&]S)UT@/"!T:&ES+FYO9&5?<&]S6VYO9&5)9%U;
M)V-O=6YT)UTI('L*("`@("`@("`@("`@+R\@3F]T(&QA<W0@;F]D92X*("`@
M("`@("`@("`@:68@*'1H:7,N;W!T:6]N<ULG;&EN97,G72D@>PH@("`@("`@
M("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG2F]I;CL*("`@("`@
M("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G?"TG.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N
M:6UG0FQA;FL["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)R9N
M8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O+R!,87-T(&YO9&4N"B`@("`@("`@("`@(&EF
M("AT:&ES+F]P=&EO;G-;)VQI;F5S)UTI('L*("`@("`@("`@("`@("`@(&YO
M9&54;V=G;&5;,%T@/2!T:&ES+FEM9TIO:6Y";W1T;VT["B`@("`@("`@("`@
M("`@("!N;V1E5&]G9VQE6S%=(#T@)V`M)SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9T)L
M86YK.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<F;F)S<#LF
M;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2!E
M;'-E(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL9')E;B==
M*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@("\O($YO9&4@=VET:"!C:&EL
M9')E;BX*("`@("`@("!I9B`H=&AI<RYN;V1E7W!O<UMN;V1E261=6R=P;W,G
M72`\('1H:7,N;F]D95]P;W-;;F]D94ED75LG8V]U;G0G72D@>PH@("`@("`@
M("`@("`O+R!.;W0@;&%S="!N;V1E+@H@("`@("`@("`@("!I9B`H(71H:7,N
M;W!T:6]N<ULG;&EN97,G72D@>PH@("`@("`@("`@("`@("`@;F]D951O9V=L
M95LP72`]('1H:7,N:6UG0FQA;FL["B`@("`@("`@("`@("`@("!N;V1E5&]G
M9VQE6S%=(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@('T@
M96QS92!I9B`H=&AI<RYR96YD97)3=&%T:6,I('L*("`@("`@("`@("`@("`@
M(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9TIO:6X["B`@("`@("`@("`@("`@
M("!N;V1E5&]G9VQE6S%=(#T@)WPM)SL*("`@("`@("`@("`@?2!E;'-E(&EF
M("AT:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UTI('L*("`@("`@("`@
M("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9TUI;G5S.PH@("`@("`@
M("`@("`@("`@;F]D951O9V=L95LQ72`]("<M)SL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM
M9U!L=7,["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)RLG.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M3&%S="!N;V1E+@H@("`@("`@("`@("!I9B`H(71H:7,N;W!T:6]N<ULG;&EN
M97,G72D@>PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N
M:6UG0FQA;FL["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)R9N
M8G-P.R<["B`@("`@("`@("`@('T@96QS92!I9B`H=&AI<RYR96YD97)3=&%T
M:6,I('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM
M9TIO:6Y";W1T;VT["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@
M)V`M)SL*("`@("`@("`@("`@?2!E;'-E(&EF("AT:&ES+FYO9&5S6VYO9&5)
M9%U;)V5X<&%N9&5D)UTI('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;
M,%T@/2!T:&ES+FEM9TUI;G5S0F]T=&]M.PH@("`@("`@("`@("`@("`@;F]D
M951O9V=L95LQ72`]("<M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9U!L=7-";W1T;VT[
M"B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)RLG.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`O+R!4;W`@
M;&5V96P@;F]D92!W:71H(&YO(&-H:6QD<F5N+@H@("`@("`@(&EF("AT:&ES
M+G)E;F1E<E-T871I8RD@>PH@("`@("`@("`@("!R971U<FX@;F]D951O9V=L
M93L*("`@("`@("!]"B`@("`@("`@:68@*'1H:7,N;W!T:6]N<ULG;&EN97,G
M72D@>PH@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=.=6QL
M3VYL>3L*("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<F;F)S<#LF;F)S
M<#LG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&YO9&54;V=G;&5;
M,%T@/2!T:&ES+FEM9T)L86YK.PH@("`@("`@("`@("!N;V1E5&]G9VQE6S%=
M(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@?0H@("`@?0H*("`@
M(')E='5R;B!N;V1E5&]G9VQE.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92Y?
M<V5T3F]D94EC;VX@/2!F=6YC=&EO;BAN;V1E260I"GL*("`@('9A<B!I;6=$
M:7(@/2`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG:6-O;F1I<B==*2`A
M/2`G=6YD969I;F5D)RD@/PH@("`@("`@('1H:7,N;F]D97-;;F]D94ED75LG
M:6-O;F1I<B==(#H*("`@("`@("!T:&ES+FEM9T1I<CL*("`@(&EF("AI;6=$
M:7(I('L*("`@("`@("!I;6=$:7(@*ST@)R\G.PH@("`@?0H*("`@(&EF("AT
M>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=I8V]N)UTI("$]("=U;F1E9FEN
M960G*2!["B`@("`@("`@+R\@3F]D92!H87,@82!U<V5R(&1E9FEN960@:6-O
M;BX*("`@("`@("!I9B`H(71H:7,N;F]D97-;;F]D94ED75LG:6-O;B==*2![
M"B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("`@("`@:68@
M*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)VEC;VYO<&5N)UTI("$]("=U
M;F1E9FEN960G("8F('1H:7,N;F]D97-;;F]D94ED75LG97AP86YD960G72D@
M>PH@("`@("`@("`@("!I;6<@/2!T:&ES+FYO9&5S6VYO9&5)9%U;)VEC;VYO
M<&5N)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:6UG(#T@=&AI
M<RYN;V1E<UMN;V1E261=6R=I8V]N)UT["B`@("`@("`@?0H@("`@?2!E;'-E
M('L*("`@("`@("`O+R!5<V4@<W1A;F1A<F0@:6-O;B!S970N"B`@("`@("`@
M:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI("$]
M("=U;F1E9FEN960G*2!["B`@("`@("`@("`@("\O($YO9&4@=VET:"!C:&EL
M9')E;BX*("`@("`@("`@("`@:6UG(#T@*'1H:7,N;F]D97-;;F]D94ED75LG
M97AP86YD960G72D@/R!T:&ES+FEM9T9O;&1E<D]P96X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B!T:&ES
M+FEM9T9O;&1E<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!.
M;V1E(&YO(&-H:6QD<F5N+@H@("`@("`@("`@("!I;6<@/2!T:&ES+FEM9TQE
M868["B`@("`@("`@?0H@("`@?0H*("`@('9A<B!I;6=T>'0@/2`G/&EM9R!S
M<F,](B<@*R!I;6=$:7(@*R!I;6<@*R`G(B<["@H@("`@:68@*'1Y<&5O9BAT
M:&ES+FYO9&5S6VYO9&5)9%U;)VEC;VYA;'0G72D@(3T@)W5N9&5F:6YE9"<I
M('L*("`@("`@("!I;6=T>'0@*ST@)R!A;'0](B<@*R!T:&ES+FYO9&5S6VYO
M9&5)9%U;)VEC;VYA;'0G72`K("<B)SL*("`@('T*"B`@("!R971U<FX@:6UG
M='AT("L@)R`O/B`G.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92YT;V=G;&4@
M/2!F=6YC=&EO;BAN;V1E260I"GL*("`@('1H:7,N;F]D97-;;F]D94ED75LG
M97AP86YD960G72`]("%T:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UT[
M"B`@("!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E9"==*2!["B`@
M("`@("`@:68@*&YO9&4@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G;F]D
M94-H:6QD<F5N7R<@*R!N;V1E260I*2!["B`@("`@("`@("`@(&YO9&4N<W1Y
M;&4N9&ES<&QA>2`]("=B;&]C:R<["B`@("`@("`@?0H@("`@?2!E;'-E('L*
M("`@("`@("!I9B`H;F]D92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=N
M;V1E0VAI;&1R96Y?)R`K(&YO9&5)9"DI('L*("`@("`@("`@("`@;F]D92YS
M='EL92YD:7-P;&%Y(#T@)VYO;F4G.PH@("`@("`@('T*("`@('T*"B`@("`O
M+R!)9B!U<VEN9R!A;'1E<FYA=&EN9R!R;W<@<VAA9&EN9RP@=V]R:R!O=70@
M8V]R<F5C="!S:&%D92X*("`@(&EF("AT:&ES+F]P=&EO;G-;)V%L=&5R;F%T
M92==*2!["B`@("`@("`@=&AI<RYS=')I<&4H*3L*("`@('T*"B`@("!N;V1E
M5&]G9VQE(#T@=&AI<RY?9V5T3F]D951O9V=L92AN;V1E260I.PH@("`@:68@
M*'1O9V=L92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=N;V1E5&]G9VQE
M7R<@*R!N;V1E260I*2!["B`@("`@("`@=&]G9VQE+G-R8R`]('1H:7,N:6UG
M1&ER("L@)R\G("L@;F]D951O9V=L95LP73L*("`@("`@("!T;V=G;&4N86QT
M(#T@;F]D951O9V=L95LQ73L*("`@('T*"B`@("!T:&ES+G-A=F53=&%T92AN
M;V1E260L('1H:7,N;F]D97-;;F]D94ED75LG97AP86YD960G72D*?0H*2&]R
M9&5?5')E92YP<F]T;W1Y<&4N<W1R:7!E(#T@9G5N8W1I;VXH*0I["B`@("`O
M+R!4:&4@96QE;65N="!T;R!S=&%R="!S=')I<&EN9RX*("`@('9A<B!I9"`]
M(&%R9W5M96YT<ULP72`_(&%R9W5M96YT<ULP72`Z('1H:7,N=&%R9V5T.PH*
M("`@("\O(%1H92!F;&%G('=E)VQL('5S92!T;R!K965P('1R86-K(&]F('=H
M971H97(@=&AE(&-U<G)E;G0@<F]W(&ES"B`@("`O+R!O9&0@;W(@979E;BX*
M("`@('9A<B!E=F5N(#T@87)G=6UE;G1S6S%=(#\@87)G=6UE;G1S6S%=(#H@
M9F%L<V4["@H@("`@+R\@3V)T86EN(&$@<F5F97)E;F-E('1O('1H92!T<F5E
M('!A<F5N="!E;&5M96YT+@H@("`@=F%R('1R964@/2!D;V-U;65N="YG971%
M;&5M96YT0GE)9"AI9"D["B`@("!I9B`H(71R964I('L*("`@("`@("!R971U
M<FX@979E;CL*("`@('T*"B`@("`O+R!)=&5R871E(&]V97(@96%C:"!C:&EL
M9"!D:78N"B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\('1R964N8VAI;&1.;V1E
M<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AT<F5E+F-H:6QD3F]D97-;
M:5TN:60N:6YD97A/9B@G;F]D94-H:6QD<F5N)RD@(3T@+3$I('L*("`@("`@
M("`@("`@:68@*'1H:7,N;F]D97-;=')E92YC:&EL9$YO9&5S6VE=+FED+G)E
M<&QA8V4H)VYO9&5#:&EL9')E;E\G+"`G)RE=6R=E>'!A;F1E9"==*2!["B`@
M("`@("`@("`@("`@("!E=F5N(#T@=&AI<RYS=')I<&4H=')E92YC:&EL9$YO
M9&5S6VE=+FED+"!E=F5N*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@('1R964N8VAI;&1.;V1E<UMI72YC;&%S<TYA;64@
M/2!T<F5E+F-H:6QD3F]D97-;:5TN8VQA<W-.86UE+G)E<&QA8V4H)R!R;W=%
M=F5N)RP@)R<I+G)E<&QA8V4H)R!R;W=/9&0G+"`G)RD["B`@("`@("`@("`@
M('1R964N8VAI;&1.;V1E<UMI72YC;&%S<TYA;64@*ST@979E;B`_("<@<F]W
M179E;B<@.B`G(')O=T]D9"<["@H@("`@("`@("`@("`O+R!&;&EP(&9R;VT@
M;V1D('1O(&5V96XL(&]R('9I8V4M=F5R<V$N"B`@("`@("`@("`@(&5V96X@
M/2`A979E;CL*("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N(&5V96X["GT*
M"DAO<F1E7U1R964N<')O=&]T>7!E+G-A=F53=&%T92`](&9U;F-T:6]N*&YO
M9&5)9"P@97AP86YD960I"GL*("`@('9A<B!N97=#;V]K:64@/2`G)SL*("`@
M('9A<B!O;&1#;V]K:64@/2!T:&ES+E]G971#;V]K:64H=&AI<RY?:6YS=&%N
M8V5.86UE("L@)U]E>'!A;F1E9"<I.PH@("`@:68@*&5X<&%N9&5D*2!["B`@
M("`@("`@+R\@17AP86YD(')E<75E<W1E9"!S;R!A9&0@=&\@8V]O:VEE+@H@
M("`@("`@(&YE=T-O;VMI92`]("AO;&1#;V]K:64I(#\@;VQD0V]O:VEE("L@
M)RPG(#H@)R<["B`@("`@("`@;F5W0V]O:VEE(#T@;F5W0V]O:VEE("L@;F]D
M94ED.PH@("`@?2!E;'-E('L*("`@("`@("`O+R!#;VQL87!S92!R97%U97-T
M960@<V\@<F5M;W9E(&9R;VT@8V]O:VEE+@H@("`@("`@('9A<B!N;V1E<R`]
M(&]L9$-O;VMI92YS<&QI="@G+"<I.PH@("`@("`@('9A<B!N97=.;V1E<R`]
M(&YE=R!!<G)A>2@I.PH@("`@("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@;F]D
M97,N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@:68@*&YO9&5S6VE=("$]
M(&YO9&5)9"D@>PH@("`@("`@("`@("`@("`@;F5W3F]D97-;;F5W3F]D97,N
M;&5N9W1H72`](&YO9&5S6VE=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&YE=T-O;VMI92`](&YE=TYO9&5S+FIO:6XH)RPG*3L*("`@('T*
M("`@('1H:7,N7W-E=$-O;VMI92AT:&ES+E]I;G-T86YC94YA;64@*R`G7V5X
M<&%N9&5D)RP@;F5W0V]O:VEE*3L*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N
M7V=E=$-O;VMI92`](&9U;F-T:6]N*&YA;64I"GL*("`@('9A<B!D8R`](&1O
M8W5M96YT+F-O;VMI93L*("`@('9A<B!P<F5F:7@@/2!N86UE("L@)SUE>'`G
M.PH@("`@=F%R(&)E9VEN(#T@9&,N:6YD97A/9B@G.R`G("L@<')E9FEX*3L*
M("`@(&EF("AB96=I;B`]/2`M,2D@>PH@("`@("`@(&)E9VEN(#T@9&,N:6YD
M97A/9BAP<F5F:7@I.PH@("`@("`@(&EF("AB96=I;B`A/2`P*2!["B`@("`@
M("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@
M("`@(&)E9VEN("L](#(["B`@("!]"B`@("!V87(@96YD(#T@9&]C=6UE;G0N
M8V]O:VEE+FEN9&5X3V8H)SLG+"!B96=I;BD["B`@("!I9B`H96YD(#T]("TQ
M*2!["B`@("`@("`@96YD(#T@9&,N;&5N9W1H.PH@("`@?0H@("`@<F5T=7)N
M('5N97-C87!E*&1C+G-U8G-T<FEN9RAB96=I;B`K('!R969I>"YL96YG=&@L
M(&5N9"DI.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92Y?<V5T0V]O:VEE(#T@
M9G5N8W1I;VXH;F%M92P@=F%L=64I"GL*("`@('9A<B!C=7)#;V]K:64@/2!N
M86UE("L@)SUE>'`G("L@97-C87!E*'9A;'5E*3L*("`@(&-U<D-O;VMI92`K
M/2`G.T1/34%)3CT\/W!H<"!E8VAO("1'3$]"04Q36R=C;VYF)UU;)V-O;VMI
M92==6R=D;VUA:6XG73L@/SX[4$%42#T\/W!H<"!E8VAO("1'3$]"04Q36R=C
M;VYF)UU;)V-O;VMI92==6R=P871H)UT[(#\^.R<["B`@("!D;V-U;65N="YC
M;V]K:64@/2!C=7)#;V]K:64["GT*"DAO<F1E7U1R964N<')O=&]T>7!E+E]C
M;W)R96-T5VED=&A&;W)38W)O;&QB87(@/2!F=6YC=&EO;B@I"GL*/#]P:'`@
M:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<U%U:7)K*"=S8W)O;&QB87)?
M:6Y?=V%Y)RDI.B`_/@H@("`@+R\@0V]R<F5C="!F;W(@9G)A;64@<V-R;VQL
M8F%R(&EN($E%(&)Y(&1E=&5R;6EN:6YG(&EF(&$@<V-R;VQL8F%R(&ES('!R
M97-E;G0L"B`@("`O+R!A;F0@:68@;F]T(')E861J=7-T:6YG('1H92!M87)G
M:6Y2:6=H="!P<F]P97)T>2!T;R`P"B`@("`O+R!3964@:'1T<#HO+W=W=RYX
M<S1A;&PN;FPO?G!P:R]J<R]D;V-T>7!E<RYH=&UL(&9O<B!W:'D@=&AI<R!W
M;W)K<PH@("`@:68@*&1O8W5M96YT+F1O8W5M96YT16QE;65N="YC;&EE;G1(
M96EG:'0@/3T@9&]C=6UE;G0N9&]C=6UE;G1%;&5M96YT+F]F9G-E=$AE:6=H
M="D@>PH@("`@("`@("\O(&YO('-C<F]L;&)A<B!P<F5S96YT+"!T86ME(&%W
M87D@97AT<F$@;6%R9VEN"B`@("`@("`@9&]C=6UE;G0N8F]D>2YS='EL92YM
M87)G:6Y2:6=H="`]("<P)SL*("`@('T@96QS92!["B`@("`@("`@9&]C=6UE
M;G0N8F]D>2YS='EL92YM87)G:6Y2:6=H="`]("<Q-7!X)SL*("`@('T*/#]P
M:'`@96YD:68[(#\^"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VEN9&5X+P``````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P,3<U,34`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T96UP;&%T97,O:6YD97@O9G)A;65S7VEN9&5X+FEN8P``````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C4S`#$P-#$W,S8S,#$Q`#`R,C8U
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<"`D<G1L(#T@:7-S970H)&YL<ULG<G1L)UU;)&QA;F=U86=E72D@/SX*
M/"%$3T-465!%(&AT;6P@4%5"3$E#("(M+R]7,T,O+T141"!82%1-3"`Q+C`@
M1G)A;65S970O+T5.(B`B1%1$+WAH=&UL,2UF<F%M97-E="YD=&0B/@H\:'1M
M;#X*/&AE860^"B`\;&EN:R!R96P](E-(3U)40U54($E#3TXB(&AR968](CP_
M<&AP(&5C:&\@)')E9VES=')Y+3YG971);6%G941I<B@I(#\^+V9A=FEC;VXN
M:6-O(B`O/@H@/'1I=&QE/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M<F5G:7-T<GDM/F=E="@G;F%M92<I*2`_/CPO=&ET;&4^"CPO:&5A9#X*"CQF
M<F%M97-E="!I9#TB:&8B(&-O;',](CP_<&AP(&5C:&\@*"1R=&P@/R`G*BPG
M(#H@)R<I("X@*&ES<V5T*"1P<F5F<RD@/R`D<')E9G,M/F=E=%9A;'5E*"=S
M:61E8F%R7W=I9'1H)RD@.B`Q-3`I("X@*"1R=&P@/R`G)R`Z("<L*B<I(#\^
M(B!F<F%M97-P86-I;F<](C`B(&9R86UE8F]R9&5R/2(P(CX*/#]P:'`@:68@
M*"1R=&PI.B`_/@H@(#QF<F%M92!N86UE/2)H;W)D95]M86EN(B!S<F,](CP_
M<&AP(&5C:&\@571I;#HZ861D4&%R86UE=&5R*&AT;6QS<&5C:6%L8VAA<G,H
M)&UA:6Y?<&%G92DL("=F<F%M97-E=%]L;V%D960G+"`Q*2`_/B(@<V-R;VQL
M:6YG/2(\/W!H<"!E8VAO("1S8W)O;&QB87(@/SXB(&YO<F5S:7IE/2)N;W)E
M<VEZ92(@+SX*("`\9G)A;64@;F%M93TB:&]R9&5?;65N=2(@<W)C/2(\/W!H
M<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP)RD@/SXB('-C<F]L;&EN9STB875T;R(@;F]R97-I>F4]
M(FYO<F5S:7IE(B`O/@H\/W!H<"!E;'-E.B`_/@H@(#QF<F%M92!N86UE/2)H
M;W)D95]M96YU(B!S<F,](CP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`G*2`_/B(@<V-R;VQL
M:6YG/2)A=71O(B!N;W)E<VEZ93TB;F]R97-I>F4B("\^"B`@/&9R86UE(&YA
M;64](FAO<F1E7VUA:6XB('-R8STB/#]P:'`@96-H;R!5=&EL.CIA9&1087)A
M;65T97(H:'1M;'-P96-I86QC:&%R<R@D;6%I;E]P86=E*2P@)V9R86UE<V5T
M7VQO861E9"<L(#$I(#\^(B!S8W)O;&QI;F<](CP_<&AP(&5C:&\@)'-C<F]L
M;&)A<B`_/B(@;F]R97-I>F4](FYO<F5S:7IE(B`O/@H\/W!H<"!E;F1I9CL@
M/SX*/"]F<F%M97-E=#X*"CPO:'1M;#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]M86EN
M=&5N86YC92\`````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C,P,3$`,#(P-C<P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6P`````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-#`Q-@`Q,#0Q-S,V,S`Q,0`P,C0P,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/&1I=B!I
M9#TB;65N=2(^/&@Q/B9N8G-P.SQT86<Z:&5A9&5R("\^/"]H,3X\+V1I=CX*
M"CQF;W)M(&UE=&AO9#TB<&]S="(@86-T:6]N/2(\=&%G.FUA:6YT7W5R;"`O
M/B(@;F%M93TB;6%I;G1?8V]N9FER;2(^"CQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](FQO861?9G)A;65S970B('9A;'5E/2(B("\^"CQT86<Z;6%I;G1?
M<&]S=&1A=&$@+SX*"CQI9CIJ879A<V-R:7!T/@H\<V-R:7!T('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(^"CPA+2T*9G5N8W1I;VX@=6YC:&5C:T%L;"@I"GL*
M("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@9&]C=6UE;G0N;6%I;G1?8V]N9FER
M;2YE;&5M96YT<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&1O8W5M96YT+FUA
M:6YT7V-O;F9I<FTN96QE;65N='-;:5TN8VAE8VME9"`](&9A;'-E.PH@("`@
M?0I]"B\O+2T^"CPO<V-R:7!T/@H\+VEF.FIA=F%S8W)I<'0^"@H\=&%B;&4@
M=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(R(CX*(#QT<CX*("`\=&0^/'1A
M9SIN;W1I9GD@+SX\+W1D/@H@/"]T<CX*"CQL;V]P.G1A<VMS/@H@/'1R/@H@
M(#QT9"!C;&%S<STB;&EG:'0B/@H\:68Z8V]N9FER;3X*("`@/&EN<'5T('1Y
M<&4](F-H96-K8F]X(B!N86UE/2(\=&%G.G1A<VMS+G!R968@+SY?8V]N9FER
M;2(\=&%G.G1A<VMS+F-H96-K960@+SX^)FYB<W`[)FYB<W`["CPO:68Z8V]N
M9FER;3X*/&EF.F%G<F5E/@H@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2(\=&%G.G1A<VMS+G!R968@+SY?8V]N9FER;2(@=F%L=64](C$B("\^"CPO
M:68Z86=R964^"CQI9CIN;W1I8V4^"B`@(#QI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](CQT86<Z=&%S:W,N<')E9B`O/E]C;VYF:7)M(B!V86QU93TB,2(@
M+SX*/"]I9CIN;W1I8V4^"B`@(#QT86<Z=&%S:W,N9&5S8W)I<"`O/@H@(#PO
M=&0^"B`\+W1R/@H\+VQO;W`Z=&%S:W,^"@H@/'1R/@H@(#QT9#XF;F)S<#L\
M+W1D/@H@/"]T<CX*"B`\='(^"B`@/'1D/@H\:68Z8V]N9FER;3X*("`@/&EN
M<'5T(&YA;64](F]K(B!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A
M;'5E/2(\9V5T=&5X=#Y097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,\
M+V=E='1E>'0^(B!O;F-L:6-K/2)D;V-U;65N="YM86EN=%]C;VYF:7)M+G-U
M8FUI="@I.R(@+SX*/&EF.FIA=F%S8W)I<'0^"B`@("9N8G-P.R9N8G-P.PH@
M("`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!V86QU93TB
M/&=E='1E>'0^4VMI<"!-86EN=&5N86YC93PO9V5T=&5X=#XB(&]N8VQI8VL]
M(G5N8VAE8VM!;&PH*3L@9&]C=6UE;G0N;6%I;G1?8V]N9FER;2YS=6)M:70H
M*3LB("\^"CPO:68Z:F%V87-C<FEP=#X*/"]I9CIC;VYF:7)M/@H\:68Z86=R
M964^"B`@(#QI;G!U="!N86UE/2)O:R(@='EP93TB<W5B;6ET(B!N86UE/2)A
M9W)E92(@8VQA<W,](F)U='1O;B(@=F%L=64](CQG971T97AT/EEE<RP@22!!
M9W)E93PO9V5T=&5X=#XB(&]N8VQI8VL](F1O8W5M96YT+FUA:6YT7V-O;F9I
M<FTN<W5B;6ET*"D[(B`O/@H@("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE
M/2)N;W1?86=R964B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\9V5T=&5X=#Y.
M3RP@22!$;R!.3U0@06=R964\+V=E='1E>'0^(B!O;F-L:6-K/2)D;V-U;65N
M="YM86EN=%]C;VYF:7)M+G-U8FUI="@I.R(@+SX*/"]I9CIA9W)E93X*/&EF
M.FYO=&EC93X*("`@/&EN<'5T(&YA;64](F]K(B!T>7!E/2)S=6)M:70B(&-L
M87-S/2)B=71T;VXB('9A;'5E/2(\9V5T=&5X=#Y#;&EC:R!T;R!#;VYT:6YU
M93PO9V5T=&5X=#XB(&]N8VQI8VL](F1O8W5M96YT+FUA:6YT7V-O;F9I<FTN
M<W5B;6ET*"D[(B`O/@H\+VEF.FYO=&EC93X*("`\+W1D/@H@/"]T<CX*/"]T
M86)L93X*"CPO9F]R;3X*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T
M(CX*/"$M+0ID;V-U;65N="YM86EN=%]C;VYF:7)M+F]K+F9O8W5S*"D["FEF
M("AT>7!E;V8@=VEN9&]W+G!A<F5N="YF<F%M97,N:&]R9&5?;65N=2`]/2`G
M=6YD969I;F5D)RD@9&]C=6UE;G0N;6%I;G1?8V]N9FER;2YL;V%D7V9R86UE
M<V5T+G9A;'5E(#T@,3L*+R\M+3X*/"]S8W)I<'0^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VUE;G4O````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q
M,0`P,3<S-3(`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O;65N
M=2]M96YU+FEN8P``````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,3,P`#$P-#$W,S8S,#$Q`#`R,3`P,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\9&EV(&ED/2)M96YU(CX*(#QD:78@
M8VQA<W,](FQE9G1&;&]A="(^"B`@/#]P:'`@96-H;R`D;65N=2T^<F5N9&5R
M*"D@/SX*(#PO9&EV/@H\+V1I=CX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"\`````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q
M-S,V,S`Q,0`P,3<W,#<`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,`````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,#<S`#$P-#$W,S8S,#$Q`#`R,3$S,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<"!I9B`H)&QA>6]U
M="T^:7-#:&%N9V5D*"1R;W<L("1C;VPI*3H@/SX*/&$@:60](F)L;V-K(CX\
M+V$^"CP_<&AP(&5N9&EF.R`_/@H*/'`@8VQA<W,](FAE861E<B(^/#]P:'`@
M96-H;R!?*")!9&0@2&5R93HB*2`_/CPO<#X*"CQD:78@<W1Y;&4](G!A9&1I
M;F<Z,G!X(CX*(#QF;W)M(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L
M9E5R;"@I(#\^(V)L;V-K(B!M971H;V0](G!O<W0B/@H@/#]P:'`@571I;#HZ
M<&9O<FU);G!U="@I(#\^"B`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)R
M;W<B('9A;'5E/2(\/W!H<"!E8VAO("1R;W<@/SXB("\^"B`\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)C;VPB('9A;'5E/2(\/W!H<"!E8VAO("1C;VP@
M/SXB("\^"B`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VXB('9A
M;'5E/2)S879E+7)E<W5M92(@+SX*(#P_<&AP(&5C:&\@)&)L;V-K<RT^9V5T
M0FQO8VMS5VED9V5T*"D@/SX*(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S
M/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D%D9"(I(#\^(B`O/@H@
M/"]F;W)M/@H\+V1I=CX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O<&]R=&%L+V)L;V-K+FEN8P``````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,S(W`#$P-#$W,S8S,#$Q`#`R,30W,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\=&0@8VQA<W,]
M(FAE861E<F)O>"(@=F%L:6=N/2)T;W`B('-T>6QE/2)W:61T:#H\/W!H<"!E
M8VAO("1W:61T:"`_/B4B(')O=W-P86X](CP_<&AP(&5C:&\@)')O=W-P86X@
M/SXB(&-O;'-P86X](CP_<&AP(&5C:&\@)&-O;'-P86X@/SXB/@H@/&@Q(&-L
M87-S/2)H96%D97(B/CP_<&AP(&5C:&\@)&AE861E<B`_/CPO:#$^"B`\/W!H
M<"!E8VAO("1C;VYT96YT(#\^"CPO=&0^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O
M<G1A;"]E9&ET+FEN8P``````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S0S,@`Q,#0Q-S,V,S`Q,0`P,C$S,C8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/'1A8FQE(&-L87-S/2)N;W!A9&1I
M;F<B(&-E;&QS<&%C:6YG/2(V(B!W:61T:#TB,3`P)2(^"CP_<&AP"B1R;W=S
M(#T@)&QA>6]U="T^<F]W<R@I.PIL:7-T*"1C=7)R96YT7W)O=RP@)&-U<G)E
M;G1?8V]L*2`]("1L87EO=70M/F=E=$-U<G)E;G1";&]C:R@I.PHD86QL;W=?
M861D(#T@*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG<&5R;7-D96YI960G72D@
M?'P*("`@("`@("`@("`@("!(;W)D93HZ:&%S4&5R;6ES<VEO;B@G;6%X7V)L
M;V-K<R<I(#T]/2!T<G5E('Q\"B`@("`@("`@("`@("`@2&]R9&4Z.FAA<U!E
M<FUI<W-I;VXH)VUA>%]B;&]C:W,G*2`^("1L87EO=70M/F-O=6YT*"DI.PHD
M8V]L=6UN<R`](#`["F9O<B`H)')O=R`](#`[("1R;W<@/"`D<F]W<SL@*RLD
M<F]W*3H*/SX*("`\='(^"CP_<&AP"B1C;VQU;6YS(#T@)&QA>6]U="T^8V]L
M=6UN<R@D<F]W*3L*:68@*&ES7V$H)&-O;'5M;G,L("=014%27T5R<F]R)RDI
M('L*("`@("1C;VQU;6YS(#T@,#L*?0IF;W(@*"1C;VP@/2`P.R`D8V]L(#P@
M)&-O;'5M;G,[("LK)&-O;"DZ"B`@("`D:7-%9&ET:6YG(#T@*"1C=7)R96YT
M7W)O=R`]/3T@)')O=R`F)B`D8W5R<F5N=%]C;VP@/3T]("1C;VPI.PH@("`@
M:68@*"1L87EO=70M/FES0V]V97)E9"@D<F]W+"`D8V]L*2DZ"C\^"B`@("`\
M(2TM(&-O=F5R960@8V5L;"!H97)E("TM/@H\/W!H<"!E;'-E.B`_/@H@("`@
M/'1D(&-L87-S/2(\/W!H<"!E8VAO("1I<T5D:71I;F<@/R`G8W5R<F5N=$)L
M;V-K)R`Z("=H96%D97)B;W@G(#\^(B!V86QI9VX](G1O<"(@=VED=&@](CP_
M<&AP(&5C:&\@9FQO;W(H,3`P("\@*"1C;VQU;6YS("L@,2DI(#\^)2(@<F]W
M<W!A;CTB/#]P:'`@96-H;R`D;&%Y;W5T+3YG971(96EG:'0H)')O=RP@)&-O
M;"D@/SXB(&-O;'-P86X](CP_<&AP(&5C:&\@)&QA>6]U="T^9V5T5VED=&@H
M)')O=RP@)&-O;"D@/SXB/@H\/W!H<`HD8FQO8VM);F9O(#T@)&QA>6]U="T^
M9V5T0FQO8VM);F9O*"1R;W<L("1C;VPI.PII9B`H(21L87EO=70M/FES16UP
M='DH)')O=RP@)&-O;"D@)B8@(6ES7V$H)&)L;V-K26YF;RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@:68@*"1I<T5D:71I;F<I('L*("`@("`@("`D961I=%]L
M:6YK(#T@)R9N8G-P.R<["B`@("!](&5L<V4@>PH@("`@("`@("1E9&ET7VQI
M;FL@/2`G/'-M86QL/B<@+B!(;W)D93HZ;&EN:R@D;&%Y;W5T+3YG971!8W1I
M;VY5<FPH)V5D:70G+"`D<F]W+"`D8V]L*2D@+B!?*")E9&ET(BD@+B`G/"]A
M/CPO<VUA;&P^)SL*("`@('T*("`@(')E<75I<F4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+VQA>6]U="YI;F,G.PI](&5L<V4@>PH@("`@:68@*"1A;&QO=U]A
M9&0I('L*("`@("`@("!R97%U:7)E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]A
M9&0N:6YC)SL*("`@('T*?0H_/@H@("`@/"]T9#X*/#]P:'`@96YD:68[(&5N
M9&9O<CL@:68@*"1A;&QO=U]A9&0I.B`_/@H@("`@/'1D('9A;&EG;CTB=&]P
M(B!C;&%S<STB:&5A9&5R8F]X(CX*("`@("`@/#]P:'`@<F5Q=6ER92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O861D+FEN8R<[(#\^"B`@("`\+W1D/@H\/W!H
M<"!E;F1I9CL@/SX*("`\+W1R/@H\/W!H<"!E;F1F;W([(&EF("@D86QL;W=?
M861D*3H@/SX*("`\='(^"CP_<&AP"F9O<B`H)&-O;"`](#`[("1C;VP@/#T@
M)&-O;'5M;G,[("LK)&-O;"DZ"C\^"B`@("`\=&0@=F%L:6=N/2)T;W`B(&-L
M87-S/2)H96%D97)B;W@B/@H@("`@("`\/W!H<"!R97%U:7)E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]A9&0N:6YC)SL@/SX*("`@(#PO=&0^"CP_<&AP(&5N
M9&9O<CL@/SX*("`\+W1R/@H\/W!H<"!E;F1I9CL@/SX*/"]T86)L93X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8P``````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`Q
M,C$`,3`T,3<S-C,P,3$`,#(Q-S`W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP(&EF("@D;&%Y;W5T+3YI<T-H86YG
M960H)')O=RP@)&-O;"DI.B`_/@H\82!I9#TB8FQO8VLB/CPO83X*/#]P:'`@
M96YD:68[(#\^"@H\=&%B;&4@8V5L;'-P86-I;F<](C`B(&-L87-S/2)H96%D
M97(B('=I9'1H/2(Q,#`E(CX\='(^"B`@/'1D/@H@("`@/#]P:'`@96-H;R`D
M<F5G:7-T<GDM/F=E="@G;F%M92<L("1B;&]C:TEN9F];)V%P<"==*2`N("<Z
M("<@+B`D8FQO8VMS+3YG971.86UE*"1B;&]C:TEN9F];)V%P<"==+"`D8FQO
M8VM);F9O6R=B;&]C:R==*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S/2)R:6=H
M=$%L:6=N(CX*("`@("9N8G-P.SP_<&AP(&5C:&\@)&5D:71?;&EN:R`_/@H@
M("`@/#]P:'`@:68@*"1L87EO=70M/FES4F5M;W9A8FQE*"1R;W<L("1C;VPI
M*2!E8VAO($AO<F1E.CIL:6YK*"1L87EO=70M/F=E=$%C=&EO;E5R;"@G<F5M
M;W9E0FQO8VLG+"`D<F]W+"`D8V]L*2P@7R@B4F5M;W9E($)L;V-K(BDL("<G
M+"`G)RP@)R<L(%\H(E)E;6]V92!";&]C:R(I*2`N($AO<F1E.CII;6<H)V-L
M;W-E+G!N9R<L(%\H(E)E;6]V92!";&]C:R(I+"`G86QI9VX](FUI9&1L92(G
M*2`N("<\+V$^)R`_/@H@(#PO=&0^"CPO='(^/"]T86)L93X*"CQT86)L92!C
M96QL<W!A8VEN9STB,"(@8VQA<W,](FYO<&%D9&EN9R(@=VED=&@](C$P,"4B
M/@H@(#QT<CX*("`@(#QT9"!C;VQS<&%N/2(S(B!A;&EG;CTB8V5N=&5R(CX*
M("`@("`@/#]P:'`@:68@*"1R;W<@/B`P*2!E8VAO("1L87EO=70M/F=E=$-O
M;G1R;VPH)V5X<&%N9"]U<"<L("1R;W<L("1C;VPI(#\^)FYB<W`["B`@("`@
M(#P_<&AP(&EF("@D;&%Y;W5T+3YG971(96EG:'0H)')O=RP@)&-O;"D@/B`Q
M*2!E8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)W-H<FEN:R]U<"<L("1R;W<L
M("1C;VPI(#\^"B`@("`\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D(&-L
M87-S/2)L969T06QI9VXB('=I9'1H/2(Q,2(^"B`@("`@(#P_<&AP(&EF("@D
M8V]L(#X@,"D@96-H;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=E>'!A;F0O;&5F
M="<L("1R;W<L("1C;VPI(#\^"B`@("`@(#P_<&AP(&EF("@D;&%Y;W5T+3YG
M9717:61T:"@D<F]W+"`D8V]L*2`^(#$I(&5C:&\@)&QA>6]U="T^9V5T0V]N
M=')O;"@G<VAR:6YK+VQE9G0G+"`D<F]W+"`D8V]L*2`_/@H@("`@/"]T9#X*
M("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@("`@/'1A8FQE/@H@("`@("`@
M(#QT<CX*("`@("`@("`@(#QT9"!W:61T:#TB,3$B/B9N8G-P.SPO=&0^"B`@
M("`@("`@("`\=&0@=VED=&@](C$Q(CX\/W!H<"!E8VAO("1R;W<@/B`P(#\@
M)&QA>6]U="T^9V5T0V]N=')O;"@G;6]V92]U<"<L("1R;W<L("1C;VPI(#H@
M)R9N8G-P.R<@/SX\+W1D/@H@("`@("`@("`@/'1D('=I9'1H/2(Q,2(^)FYB
M<W`[/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@(#QT<CX*("`@("`@("`@
M(#QT9#X\/W!H<"!E8VAO("1C;VP@/B`P(#\@)&QA>6]U="T^9V5T0V]N=')O
M;"@G;6]V92]L969T)RP@)')O=RP@)&-O;"D@.B`G)FYB<W`[)R`_/CPO=&0^
M"B`@("`@("`@("`\=&0^)FYB<W`[/"]T9#X*("`@("`@("`@(#QT9#X\/W!H
M<"!E8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)VUO=F4O<FEG:'0G+"`D<F]W
M+"`D8V]L*2`_/CPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\='(^"B`@
M("`@("`@("`\=&0^)FYB<W`[/"]T9#X*("`@("`@("`@(#QT9#X\/W!H<"!E
M8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)VUO=F4O9&]W;B<L("1R;W<L("1C
M;VPI(#\^/"]T9#X*("`@("`@("`@(#QT9#XF;F)S<#L\+W1D/@H@("`@("`@
M(#PO='(^"B`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H@("`@/'1D(&-L87-S
M/2)R:6=H=$%L:6=N(B!W:61T:#TB,3$B/@H@("`@("`\/W!H<"!I9B`H)&QA
M>6]U="T^9V5T5VED=&@H)')O=RP@)&-O;"D@/B`Q*2!E8VAO("1L87EO=70M
M/F=E=$-O;G1R;VPH)W-H<FEN:R]R:6=H="<L("1R;W<L("1C;VPI(#\^"B`@
M("`@(#P_<&AP(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G97AP86YD+W)I
M9VAT)RP@)')O=RP@)&-O;"D@/SX*("`@(#PO=&0^"B`@/"]T<CX*("`\='(^
M"B`@("`\=&0@8V]L<W!A;CTB,R(@86QI9VX](F-E;G1E<B(^"B`@("`@("`@
M/#]P:'`@:68@*"1L87EO=70M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`^(#$I
M(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G<VAR:6YK+V1O=VXG+"`D<F]W
M+"`D8V]L*2`_/@H@("`@("`@(#P_<&AP(&5C:&\@)&QA>6]U="T^9V5T0V]N
M=')O;"@G97AP86YD+V1O=VXG+"`D<F]W+"`D8V]L*2`_/@H@("`@/"]T9#X*
M("`\+W1R/@H\+W1A8FQE/@H*/#]P:'`@:68@*"1I<T5D:71I;F<I.B`_/@H\
M82!I9#TB8FQO8VLB/CPO83X*/'1A8FQE(&-L87-S/2)N;W!A9&1I;F<B(&-E
M;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`@/'1R/@H@("`@/'1D/B9N
M8G-P.SPO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0@=F%L:6=N/2)M:61D
M;&4B(&-L87-S/2)L969T06QI9VXB('=I9'1H/2(Q,#`E(CX*("`@("`@/&9O
M<FT@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIS96QF57)L*"D@/SXC8FQO
M8VLB(&UE=&AO9#TB<&]S="(@;F%M93TB8FQO8VMF;W)M(CX*("`@("`@("`\
M/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*("`@("`@("`\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)R;W<B('9A;'5E/2(\/W!H<"!E8VAO("1R;W<@
M/SXB("\^"B`@("`@("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB8V]L
M(B!V86QU93TB/#]P:'`@96-H;R`D8V]L(#\^(B`O/@H@("`@("`@(#QI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;B(@=F%L=64](G-A=F4B("\^
M"B`@("`@("`@/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^
M"B`@("`@("`@("`\='(^"B`@("`@("`@("`@(#QT9"!C;&%S<STB<VUA;&QH
M96%D97(B(&-O;'-P86X](C(B/CP_<&AP(&5C:&\@7R@B0FQO8VL@5'EP92(I
M(#\^/"]T9#X*("`@("`@("`@(#PO='(^"B`@("`@("`@("`\='(^"B`@("`@
M("`@("`@(#QT9"!C;VQS<&%N/2(R(CX*("`@("`@("`@("`@("`\/W!H<"!E
M8VAO("1B;&]C:W,M/F=E=$)L;V-K<U=I9&=E="@D8FQO8VM);F9O6R=A<'`G
M72P@)&)L;V-K26YF;ULG8FQO8VLG72P@=')U92D@/SX*("`@("`@("`@("`@
M/"]T9#X*("`@("`@("`@(#PO='(^"CP_<&AP"FEF("@D8FQO8VMS+3YI<T5D
M:71A8FQE*"1B;&]C:TEN9F];)V%P<"==+"`D8FQO8VM);F9O6R=B;&]C:R==
M*2DZ"B`@("`D8FQO8VL@/2`F)&QA>6]U="T^9V5T0FQO8VLH)')O=RP@)&-O
M;"D["B`@("`D9&5F875L=',@/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)&)L
M;V-K+3Y?<&%R86US(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("1D969A
M=6QT<ULD:V5Y72`]("1V86P["B`@("!]"C\^"B`@("`@("`@("`\='(^"B`@
M("`@("`@("`@(#QT9"!C;VQS<&%N/2(R(B!C;&%S<STB<VUA;&QH96%D97(B
M/CP_<&AP(&5C:&\@7R@B0FQO8VL@4V5T=&EN9W,B*2`_/CPO=&0^"B`@("`@
M("`@("`\+W1R/@H\/W!H<"`D:2`](#`[(&9O<F5A8V@@*"1B;&]C:W,M/F=E
M=%!A<F%M<R@D8FQO8VM);F9O6R=A<'`G72P@)&)L;V-K26YF;ULG8FQO8VLG
M72D@87,@)&ED*3H@)&DK*SL@/SX*("`@("`@("`@(#QT<CX*("`@("`@("`@
M("`@/'1D(&-L87-S/2(\/W!H<"!E8VAO("@D:2`E(#(I(#\@)W1E>'0G(#H@
M)VET96TP)R`_/B!R:6=H=$%L:6=N(B!V86QI9VX](G1O<"(^/#]P:'`@96-H
M;R`D8FQO8VMS+3YG971087)A;4YA;64H)&)L;V-K26YF;ULG87!P)UTL("1B
M;&]C:TEN9F];)V)L;V-K)UTL("1I9"D@/SXZ)FYB<W`[/"]T9#X*("`@("`@
M("`@("`@/'1D(&-L87-S/2(\/W!H<"!E8VAO("@D:2`E(#(I(#\@)W1E>'0G
M(#H@)VET96TP)R`_/B(@=F%L:6=N/2)T;W`B/CP_<&AP(&5C:&\@)&)L;V-K
M<RT^9V5T3W!T:6]N<U=I9&=E="@D8FQO8VM);F9O6R=A<'`G72P@)&)L;V-K
M26YF;ULG8FQO8VLG72P@)&ED+"`D9&5F875L=',I(#\^/"]T9#X*("`@("`@
M("`@(#PO='(^"CP_<&AP(&5N9&9O<F5A8V@[(&5N9&EF.R`_/@H@("`@("`@
M(#PO=&%B;&4^"B`@("`@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,]
M(F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4V%V92(I(#\^(B`O/@H@
M("`@("`\+V9O<FT^"B`@("`\+W1D/@H@(#PO='(^"CPO=&%B;&4^"CP_<&AP
M(&5N9&EF.R`_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8P``
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`S,0`Q,#0Q-S,V
M,S`Q,0`P,C$S,S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&1I=B!I9#TB;65N=2(^"B`\:#$@8VQA<W,](FQE9G1&;&]A
M="(^/#]P:'`@<')I;G1F*%\H(E=E;&-O;64L("5S(BDL(&AT;6QS<&5C:6%L
M8VAA<G,H)&9U;&QN86UE*2D@/SX\+V@Q/@H@/&1I=B!C;&%S<STB<FEG:'1&
M;&]A="(^"CP_<&AP"B1M96YU(#T@)FYE=R!-96YU*"D["B1M96YU+3YA9&0H
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P;W)T86PO)RDL(%\H
M(DAO7VUE(BDL("=H;W)D92YP;F<G*3L*:68@*"$D<')E9G,M/FES3&]C:V5D
M*"=P;W)T86Q?;&%Y;W5T)RDI('L*("`@("1M96YU+3YA9&0H2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P;W)T86PO961I="YP:'`G*2P@7R@B
M3&%?>6]U="(I+"`G;&%Y;W5T+G!N9R<I.PI]"FEF("A!=71H.CII<T%D;6EN
M*"DI('L*("`@("1M96YU+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A
M9&UI;B\G*2P@7R@B7T%D;6EN:7-T<F%T:6]N(BDL("=A9&UI;FES=')A=&EO
M;BYP;F<G*3L*?0IE8VAO("1M96YU+3YR96YD97(H*3L*/SX*(#PO9&EV/@H\
M+V1I=CX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]S:61E
M8F%R+FEN8P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S8V,P`Q
M,#0Q-S,V,S`Q,0`P,C(P,C0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/&1I=B!I9#TB97AP86YD9613:61E8F%R(B!S='EL
M93TB;W9E<F9L;W<Z:&ED9&5N(CX*(#QD:78@:60](FUE;G4B('-T>6QE/2)O
M=F5R9FQO=SIH:61D96XB/@H@(#P_<&AP(&EF("@A96UP='DH)&-O;F9;)VQO
M9V\G75LG:6UA9V4G72D@?'P@(55T:6PZ.F=E=$9O<FU$871A*"=M;WIB87(G
M*2DZ(#\^"B`@/'-P86X@8VQA<W,](FQE9G1&;&]A="(\/W!H<"!I9B`H96UP
M='DH)&-O;F9;)VQO9V\G75LG:6UA9V4G72DI(&5C:&\@)R!I9#TB=&AE;65L
M;V=O(B<@/SX^"B`@/#]P:'`*("!I9B`H(65M<'1Y*"1C;VYF6R=L;V=O)UU;
M)VEM86=E)UTI*2!["B`@("`@(&EF("@A96UP='DH)&-O;F9;)VQO9V\G75LG
M;&EN:R==*2D@>PH@("`@("`@("`@96-H;R!(;W)D93HZ;&EN:R@D8V]N9ELG
M;&]G;R==6R=L:6YK)UTL(&YU;&PL(&YU;&PL("=?=&]P)RD["B`@("`@('T*
M("`@("`@96-H;R!(;W)D93HZ:6UG*"1C;VYF6R=L;V=O)UU;)VEM86=E)UTL
M("<G+"`G)RP@)R<I.PH@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=L;V=O)UU;
M)VQI;FLG72DI('L*("`@("`@("`@(&5C:&\@)SPO83XG.PH@("`@("!]"B`@
M?2!E;'-E('L*("`@("`@96-H;R`G)FYB<W`[)SL*("!]"B`@/SX*("`\+W-P
M86X^"B`@/'-P86X@8VQA<W,](FQE9G1&;&]A="(@:60](FQO9V]P860B/B9N
M8G-P.SPO<W!A;CX*("`\9&EV(&-L87-S/2)C;&5A<B(^)FYB<W`[/"]D:78^
M"B`@/#]P:'`@96YD:68[(#\^"B`\+V1I=CX*(#QS<&%N(&ED/2)E>'!A;F1"
M=71T;VXB(&-L87-S/2)R:6=H=$9L;V%T(CX\/W!H<"!I9B`H(21I<U]M;WIB
M87(I(&5C:&\@2&]R9&4Z.FQI;FLH)R,G+"!?*")#;VQL87!S92!3:61E8F%R
M(BDL("<G+"`G)RP@)W1O9V=L94UE;G5&<F%M92@I.R!R971U<FX@9F%L<V4[
M)RP@7R@B0V]L;&%P<V4@4VED96)A<B(I*2`N($AO<F1E.CII;6<H)VAI9&5?
M<&%N96PN<&YG)RD@+B`G/"]A/B<@/SX\+W-P86X^"B`\9&EV(&ED/2)S:61E
M8F%R4&%N96PB/@H@(#P_<&AP("1T<F5E+3YR96YD97)4<F5E*"D@/SX*(#PO
M9&EV/@H\+V1I=CX*"CQD:78@:60](FAI9&1E;E-I9&5B87(B/@H@/&1I=B!I
M9#TB;65N=2(^"B`\+V1I=CX*("`\/W!H<"!E8VAO($AO<F1E.CIL:6YK*"<C
M)RP@7R@B17AP86YD(%-I9&5B87(B*2P@)R<L("<G+"`G=&]G9VQE365N=49R
M86UE*"D[(')E='5R;B!F86QS93LG+"!?*")%>'!A;F0@4VED96)A<B(I*2`N
M($AO<F1E.CII;6<H)W-H;W=?<&%N96PN<&YG)RD@+B`G/"]A/B<@/SX*/"]D
M:78^"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"@IV87(@<G1L
M(#T@/#]P:'`@96-H;R`D<G1L(#\@)W1R=64G(#H@)V9A;'-E)R`_/CL*=F%R
M(&5X<&%N9&5D4VED96)A<B`](&YE=R!(;W)D95](:61E86)L92@G97AP86YD
M9613:61E8F%R)RD["G9A<B!H:61D96Y3:61E8F%R(#T@;F5W($AO<F1E7TAI
M9&5A8FQE*"=H:61D96Y3:61E8F%R)RD["FAI9&1E;E-I9&5B87(N:&ED92@I
M.PH*9G5N8W1I;VX@9V5T0V]O:VEE*&YA;64L(&1E9FQT*0I["B`@("!V87(@
M9&,@/2!D;V-U;65N="YC;V]K:64["B`@("!V87(@<')E9FEX(#T@;F%M92`K
M("<])SL*("`@('9A<B!B96=I;B`](&1C+FEN9&5X3V8H)SL@)R`K('!R969I
M>"D["B`@("!I9B`H8F5G:6X@/3T@+3$I('L*("`@("`@("!B96=I;B`](&1C
M+FEN9&5X3V8H<')E9FEX*3L*("`@("`@("!I9B`H8F5G:6X@(3T@,"D@>PH@
M("`@("`@("`@("!R971U<FX@9&5F;'0["B`@("`@("`@?0H@("`@?2!E;'-E
M('L*("`@("`@("!B96=I;B`K/2`R.PH@("`@?0H@("`@=F%R(&5N9"`](&1O
M8W5M96YT+F-O;VMI92YI;F1E>$]F*"<[)RP@8F5G:6XI.PH@("`@:68@*&5N
M9"`]/2`M,2D@>PH@("`@("`@(&5N9"`](&1C+FQE;F=T:#L*("`@('T*("`@
M(')E='5R;B!U;F5S8V%P92AD8RYS=6)S=')I;F<H8F5G:6X@*R!P<F5F:7@N
M;&5N9W1H+"!E;F0I*3L*?0H*9G5N8W1I;VX@=&]G9VQE365N=49R86UE*"D*
M>PH@("`@:68@*'!A<F5N="`F)B!P87)E;G0N9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H)VAF)RDI('L*("`@("`@("!I9B`H97AP86YD9613:61E8F%R+G-H
M;W=N*"DI('L*("`@("`@("`@("`@<&%R96YT+F1O8W5M96YT+F=E=$5L96UE
M;G1">4ED*"=H9B<I+F-O;',@/2!R=&P@/R`G*BPR,"<@.B`G,C`L*B<["B`@
M("`@("`@("`@(&5X<&%N9&5D4VED96)A<BYH:61E*"D["B`@("`@("`@("`@
M(&AI9&1E;E-I9&5B87(N<VAO=R@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@('!A<F5N="YD;V-U;65N="YG971%;&5M96YT0GE)9"@G:&8G*2YC
M;VQS(#T@*')T;"`_("<J+"<@.B`G)RD@*R`\/W!H<"!E8VAO("AI<W-E="@D
M<')E9G,I(#\@)'!R969S+3YG971686QU92@G<VED96)A<E]W:61T:"<I(#H@
M,34P*2`_/B`K("AR=&P@/R`G)R`Z("<L*B<I.PH@("`@("`@("`@("!H:61D
M96Y3:61E8F%R+FAI9&4H*3L*("`@("`@("`@("`@97AP86YD9613:61E8F%R
M+G-H;W<H*3L*("`@("`@("!]"@H@("`@("`@("\O($5X<&ER92!I;B!O;F4@
M>65A<BX*("`@("`@("!V87(@97AP:7)E<R`](&YE=R!$871E*"D["B`@("`@
M("`@97AP:7)E<RYS9714:6UE*&5X<&ER97,N9V5T5&EM92@I("L@,S$U,S8P
M,#`P,#`I.PH@("`@("`@(&1O8W5M96YT+F-O;VMI92`]("=H;W)D95]S:61E
M8F%R7V5X<&%N9&5D/2<@*R!E>'!A;F1E9%-I9&5B87(N<VAO=VXH*2`K("<[
M1$]-04E./3P_<&AP(&5C:&\@)$=,3T)!3%-;)V-O;F8G75LG8V]O:VEE)UU;
M)V1O;6%I;B==(#\^.U!!5$@]/#]P:'`@96-H;R`D1TQ/0D%,4ULG8V]N9B==
M6R=C;V]K:64G75LG<&%T:"==(#\^.V5X<&ER97,])R`K(&5X<&ER97,N=&]'
M3513=')I;F<H*3L*("`@('T*?0H*:68@*&=E=$-O;VMI92@G:&]R9&5?<VED
M96)A<E]E>'!A;F1E9"<L('1R=64I+G1O4W1R:6YG*"D@(3T@97AP86YD9613
M:61E8F%R+G-H;W=N*"DN=&]3=')I;F<H*2D@>PH@("`@=&]G9VQE365N=49R
M86UE*"D["GT*"G9A<B!-96YU57!D871E2&%N9&QE<B`]('L*("`@(&]N3&]A
M9#H@9G5N8W1I;VXH<F5S=6QT*0H@("`@>PH@("`@("`@("\O(%)U;B!T:&4@
M:F%V87-C<FEP="!W92!G;W0@8F%C:RX*("`@("`@("!E=F%L*')E<W5L="D[
M"B`@("!]"GT["@IF=6YC=&EO;B!U<&1A=&4H*0I["B`@("!V87(@8VQI96YT
M(#T@;F5W($A45%!#;&EE;G0H*3L*("`@(&-L:65N="YI;FET*"(\/W!H<"!E
M8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP/VAT='!C;&EE;G0],2<L('1R=64I(#\^(BD["@H@("`@=')Y
M('L*("`@("`@("!C;&EE;G0N87-Y;F-'150H365N=55P9&%T94AA;F1L97(I
M.PH@("`@?2!C871C:"`H92D@>PH@("`@("`@("\O($1O;B=T(&1O(&%N>71H
M:6YG(&]N(&5R<F]R<SL@<')O8F%B;'D@82!T<F%N<VEE;G0@9F%I;'5R92P*
M("`@("`@("`O+R!A;F0@=V4G;&P@=')Y(&%G86EN(&%F=&5R('1H92!N97AT
M(&EN=&5R=F%L+@H@("`@?0I]"@H\/W!H<"!I9B`H)'!R969S+3YG971686QU
M92@G;65N=5]R969R97-H7W1I;64G*2DZ(#\^"B\O(%5P9&%T92!T:&4@;65N
M=2!I9B!S970@:6X@=7-E<B!P<F5F<RX*/#]P:'`@:68@*"1'3$]"04Q36R=B
M<F]W<V5R)UTM/FAA<T9E871U<F4H)WAM;&AT='!R97$G*2DZ(#\^"G=I;F1O
M=RYS971);G1E<G9A;"@G=7!D871E*"D[)RP@/#]P:'`@96-H;R`D<')E9G,M
M/F=E=%9A;'5E*"=M96YU7W)E9G)E<VA?=&EM92<I(#\^("H@,3`P,"D["CP_
M<&AP(&5L<V4Z(#\^"G=I;F1O=RYS9714:6UE;W5T*"=W:6YD;W<N;&]C871I
M;VXN<F5L;V%D*'1R=64I.R<L(#P_<&AP(&5C:&\@)'!R969S+3YG971686QU
M92@G;65N=5]R969R97-H7W1I;64G*2`_/B`J(#$P,#`I.PH\/W!H<"!E;F1I
M9CL@96YD:68[(#\^"@H\+W-C<FEP=#X*"CP_<&AP(&EF("AI<W-E="@D1TQ/
M0D%,4ULG;F]T:69I8V%T:6]N)UTI*2`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N
M)UTM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B!A<G)A>2@G:F%V87-C
M<FEP="<I*2D@/SX*"CPO8F]D>3X*/"]H=&UL/@H`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W!R969S+P``````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P,3<U,C4`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O87!P+FEN8P``````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3,U`#$P-#$W,S8S,#$Q
M`#`R,#<W-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\9F]R;2!M971H;V0](F=E="(@;F%M93TB87!P<W=I=&-H(B!A8W1I
M;VX](CP_<&AP(&5C:&\@)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R
M9&4G*2`N("<O<V5R=FEC97,O<')E9G,N<&AP)R`_/B(^"CP_<&AP(&5C:&\@
M571I;#HZ9F]R;4EN<'5T*"D@/SX*/&1I=B!C;&%S<STB:&5A9&5R(CX*(#QS
M<&%N(&-L87-S/2)S;6%L;&AE861E<B!R:6=H=$9L;V%T(CX*("`\/W!H<"!E
M8VAO(%\H(D5D:70@;W!T:6]N<R!F;W(Z(BD@/SX*("`\<V5L96-T(&YA;64]
M(F%P<"(@;VYC:&%N9V4](F1O8W5M96YT+F%P<'-W:71C:"YS=6)M:70H*3LB
M/@H@("`@/&]P=&EO;B!V86QU93TB(CX\/W!H<"!E8VAO(%\H(D-H;V]S92!!
M<'!L:6-A=&EO;CHB*2`_/CPO;W!T:6]N/@H\/W!H<"!I9B`H(65M<'1Y*"1A
M<'!S6R=H;W)D92==*2DZ(#\^"B`@("`\;W!T:6]N('9A;'5E/2(B/BTM+2T\
M+V]P=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](FAO<F1E(CX\/W!H<"!E8VAO
M(%\H(D=L;V)A;"!/<'1I;VYS(BD@/SX\+V]P=&EO;CX*("`@(#QO<'1I;VX@
M=F%L=64](B(^+2TM+3PO;W!T:6]N/@H\/W!H<"!E;F1I9CL@/SX*("`@/#]P
M:'`@9F]R96%C:"`H)&%P<',@87,@)&ME>2`]/B`D=F%L*3H@:68@*"1K97D@
M/3T@)VAO<F1E)RD@8V]N=&EN=64[(#\^"B`@("`\;W!T:6]N('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D=F%L*2`_/CPO;W!T:6]N/@H@("`\/W!H
M<"!E;F1F;W)E86-H.R`_/@H@(#PO<V5L96-T/@H@(#QI;G!U="!C;&%S<STB
M8G5T=&]N(B!T>7!E/2)S=6)M:70B(&]N8VQI8VL](G)E='5R;B!D;V-U;65N
M="YA<'!S=VET8V@N87!P+G-E;&5C=&5D26YD97@@(3T@,#LB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(D=O(BD@/SXB("\^"B`\+W-P86X^"B`\/W!H<"!I9B`H
M)')E9VES=')Y+3YG971!<'`H*2`]/2`G:&]R9&4G*2!E8VAO(%\H(D=L;V)A
M;"!/<'1I;VYS(BD[(&5L<V4@<')I;G1F*%\H(D]P=&EO;G,@9F]R("5S(BDL
M("1R96=I<W1R>2T^9V5T*"=N86UE)RDI(#\^"B`\8G(@8VQA<W,](F-L96%R
M(B`O/@H\+V1I=CX*/"]F;W)M/@H\8G(@8VQA<W,](G-P86-E<B(@+SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]P<F5F<R]B96=I;BYI;F,`````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`W-S<`,3`T,3<S-C,P,3$`,#(Q,S$T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#QF;W)M(&UE=&AO9#TB<&]S
M="(@;F%M93TB<')E9G,B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L
M9E5R;"@I(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB=7!D871E
M7W!R969S(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)G<F]U<"(@
M=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7`I(#\^
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A<'`B('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&%P<"D@/SXB("\^"@H\9&EV
M(&-L87-S/2)H96%D97(B/@H@/#]P:'`@4')E9G-?54DZ.F=E;F5R871E3F%V
M:6=A=&EO;D-E;&PH)&=R;W5P*2`_/@H@/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1P<F5F1W)O=7!S6R1G<F]U<%U;)VQA8F5L)UTI(#\^"B`\8G(@
M8VQA<W,](F-L96%R(B`O/@H\+V1I=CX*"CQD:78@8VQA<W,](FET96TB/@H`
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8P``````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-3(W
M`#$P-#$W,S8S,#$Q`#`R-#`W-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP
M="(^"CPA+2T*9G5N8W1I;VX@<F5M;W9E*&-A=&5G;W)Y*0I["B`@("!D;V-U
M;65N="YP<F5F<RYC06-T:6]N+G9A;'5E(#T@)W)E;6]V92<["B`@("!D;V-U
M;65N="YP<F5F<RYC871E9V]R>2YV86QU92`](&-A=&5G;W)Y.PH@("`@9&]C
M=6UE;G0N<')E9G,N<W5B;6ET*"D["GT*"F9U;F-T:6]N(&%D9"@I"GL*("`@
M('9A<B!C871E9V]R>2`]('=I;F1O=RYP<F]M<'0H)SP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.B(I*2`_/B<L("<G*3L*("`@(&EF("AC871E9V]R>2`A/2!N=6QL
M("8F(&-A=&5G;W)Y("$]("<G*2!["B`@("`@("`@9&]C=6UE;G0N<')E9G,N
M8T%C=&EO;BYV86QU92`]("=A9&0G.PH@("`@("`@(&1O8W5M96YT+G!R969S
M+F-A=&5G;W)Y+G9A;'5E(#T@8V%T96=O<GD["B`@("`@("`@9&]C=6UE;G0N
M<')E9G,N<W5B;6ET*"D["B`@("!]"GT*+R\M+3X*/"]S8W)I<'0^"CQI;G!U
M="!N86UE/2)C06-T:6]N(B!V86QU93TB(B!T>7!E/2)H:61D96XB("\^"CQI
M;G!U="!N86UE/2)C871E9V]R>2(@=F%L=64](B(@='EP93TB:&ED9&5N(B`O
M/@H\=&%B;&4^"B`\='(^"B`@/'1D(&-O;'-P86X](C(B/@H@("`\:6YP=70@
M='EP93TB8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H
M;R!?*").97<@0V%T96=O<GDB*2`_/B(@;VYC;&EC:STB861D*"D[(B`O/@H@
M(#PO=&0^"B`\+W1R/@H\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP)SL*)&--86YA9V5R(#T@)FYE=R!0<F5F
M<U]#871E9V]R>4UA;F%G97(H*3L*)&-A=&5G;W)I97,@/2`D8TUA;F%G97(M
M/F=E="@I.PHD8V]L;W)S(#T@)&--86YA9V5R+3YC;VQO<G,H*3L*)&9G8V]L
M;W)S(#T@)&--86YA9V5R+3YF9T-O;&]R<R@I.PHD=7)L(#T@2&]R9&4Z.G5R
M;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP)RD["B1U<FP@/2!5=&EL.CIA
M9&1087)A;65T97(H)'5R;"P@)V9O<FTG+"`G<')E9G,G*3L*"B\O($1E9F%U
M;'0@0V]L;W(*)&-O;&]R(#T@:7-S970H)&-O;&]R<ULG7V1E9F%U;'1?)UTI
M(#\@)&-O;&]R<ULG7V1E9F%U;'1?)UT@.B`G(T9&1D9&1B<["B1F9V-O;&]R
M(#T@:7-S970H)&9G8V]L;W)S6R=?9&5F875L=%\G72D@/R`D9F=C;VQO<G-;
M)U]D969A=6QT7R==(#H@)R,P,#`P,#`G.PHD8U]U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H)'5R;"P@)W1A<F=E="<L("=C;VQO<E\G("X@8F%S938T7V5N
M8V]D92@G7V1E9F%U;'1?)RDI.PH_/@H@/'1R/@H@(#QT9"!S='EL93TB8F%C
M:V=R;W5N9#H\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O;&]R*2`_
M/CL@8V]L;W(Z/#]P:'`@96-H;R`D9F=C;VQO<B`_/B(^/'-T<F]N9SX\/W!H
M<"!E8VAO(%\H(D1E9F%U;'0@0V]L;W(B*2`_/CPO<W1R;VYG/CPO=&0^"B`@
M/'1D/@H@("`\/W!H<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)V-A=&5G;W)Y
M7V-O;&]R<R<I*3H@/SX*("`@(#QI;G!U="!C;&%S<STB9FEX960B('-I>F4]
M(C<B('-T>6QE/2)B86-K9W)O=6YD.CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D8V]L;W(I(#\^.R!C;VQO<CH\/W!H<"!E8VAO("1F9V-O;&]R(#\^
M(B!N86UE/2)C;VQO<E\\/W!H<"!E8VAO(&)A<V4V-%]E;F-O9&4H)U]D969A
M=6QT7R<I(#\^(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1C;VQO<BD@/SXB("\^"B`@("`\82!H<F5F/2(\/W!H<"!E8VAO("1C7W5R
M;"`_/B(@;VYC;&EC:STB=VEN9&]W+F]P96XH)SP_<&AP(&5C:&\@)&-?=7)L
M(#\^)RP@)V-O;&]R<&EC:V5R)RP@)W1O;VQB87(];F\L;&]C871I;VX];F\L
M<W1A='5S/6YO+'-C<F]L;&)A<G,];F\L<F5S:7IA8FQE/6YO+'=I9'1H/3$R
M,"QH96EG:'0],C4P+&QE9G0],3`P+'1O<#TQ,#`G*3L@<F5T=7)N(&9A;'-E
M.R(@;VYM;W5S96]U=#TB=VEN9&]W+G-T871U<STG)SLB(&]N;6]U<V5O=F5R
M/2)W:6YD;W<N<W1A='5S/2<\/W!H<"!E8VAO(%\H(D-O;&]R(%!I8VME<B(I
M(#\^)SL@<F5T=7)N('1R=64[(B!C;&%S<STB=VED9V5T(B!T87)G970](F-O
M;&]R<&EC:V5R(CX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G8V]L;W)P
M:6-K97(N<&YG)RP@7R@B0V]L;W(@4&EC:V5R(BDL("=H96EG:'0](C$V(B<L
M("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H@("`\
M/W!H<"!E;F1I9CL@/SX*("`\+W1D/@H@/"]T<CX*/#]P:'`*+R\@56YF:6QE
M9"!#;VQO<@HD8V]L;W(@/2!I<W-E="@D8V]L;W)S6R=?=6YF:6QE9%\G72D@
M/R`D8V]L;W)S6R=?=6YF:6QE9%\G72`Z("<C1D9&1D9&)SL*)&9G8V]L;W(@
M/2!I<W-E="@D9F=C;VQO<G-;)U]U;F9I;&5D7R==*2`_("1F9V-O;&]R<ULG
M7W5N9FEL961?)UT@.B`G(S`P,#`P,"<["B1C7W5R;"`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D=7)L+"`G=&%R9V5T)RP@)V-O;&]R7R<@+B!B87-E-C1?96YC
M;V1E*"=?=6YF:6QE9%\G*2D["C\^"B`\='(^"B`@/'1D('-T>6QE/2)B86-K
M9W)O=6YD.CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I(#\^
M.R!C;VQO<CH\/W!H<"!E8VAO("1F9V-O;&]R(#\^(CX\<W1R;VYG/CP_<&AP
M(&5C:&\@7R@B56YF:6QE9"(I(#\^/"]S=')O;F<^/"]T9#X*("`\=&0^"B`@
M(#P_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G8V%T96=O<GE?8V]L;W)S
M)RDI.B`_/@H@("`@/&EN<'5T(&-L87-S/2)F:7AE9"(@<VEZ93TB-R(@<W1Y
M;&4](F)A8VMG<F]U;F0Z/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C
M;VQO<BD@/SX[(&-O;&]R.CP_<&AP(&5C:&\@)&9G8V]L;W(@/SXB(&YA;64]
M(F-O;&]R7SP_<&AP(&5C:&\@8F%S938T7V5N8V]D92@G7W5N9FEL961?)RD@
M/SXB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O;&]R
M*2`_/B(@+SX*("`@(#QA(&AR968](CP_<&AP(&5C:&\@)&-?=7)L(#\^(B!O
M;F-L:6-K/2)W:6YD;W<N;W!E;B@G/#]P:'`@96-H;R`D8U]U<FP@/SXG+"`G
M8V]L;W)P:6-K97(G+"`G=&]O;&)A<CUN;RQL;V-A=&EO;CUN;RQS=&%T=7,]
M;F\L<V-R;VQL8F%R<SUN;RQR97-I>F%B;&4];F\L=VED=&@],3(P+&AE:6=H
M=#TR-3`L;&5F=#TQ,#`L=&]P/3$P,"<I.R!R971U<FX@9F%L<V4[(B!O;FUO
M=7-E;W5T/2)W:6YD;W<N<W1A='5S/2<G.R(@;VYM;W5S96]V97(](G=I;F1O
M=RYS=&%T=7,])SP_<&AP(&5C:&\@7R@B0V]L;W(@4&EC:V5R(BD@/SXG.R!R
M971U<FX@=')U93LB(&-L87-S/2)W:61G970B('1A<F=E=#TB8V]L;W)P:6-K
M97(B/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=C;VQO<G!I8VME<BYP
M;F<G+"!?*")#;VQO<B!0:6-K97(B*2P@)VAE:6=H=#TB,38B)RP@)')E9VES
M=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX\+V$^"B`@(#P_<&AP(&5N
M9&EF.R`_/@H@(#PO=&0^"B`\+W1R/@H\/W!H<`IF;W)E86-H("@D8V%T96=O
M<FEE<R!A<R`D;F%M92DZ"B`@("`D8V]L;W(@/2!I<W-E="@D8V]L;W)S6R1N
M86UE72D@/R`D8V]L;W)S6R1N86UE72`Z("<C1D9&1D9&)SL*("`@("1F9V-O
M;&]R(#T@:7-S970H)&9G8V]L;W)S6R1N86UE72D@/R`D9F=C;VQO<G-;)&YA
M;65=(#H@)R,P,#`P,#`G.PH@("`@)&-?=7)L(#T@571I;#HZ861D4&%R86UE
M=&5R*"1U<FPL("=T87)G970G+"`G8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H
M)&YA;64I*3L*/SX*(#QT<CX*("`\=&0@<W1Y;&4](F)A8VMG<F]U;F0Z/#]P
M:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C;VQO<BD@/SX[(&-O;&]R.CP_
M<&AP(&5C:&\@)&9G8V]L;W(@/SXB/CQS=')O;F<^/#]P:'`@96-H;R`H)&YA
M;64@/3T@)U]D969A=6QT7R<@/R!?*")$969A=6QT($-O;&]R(BD@.B!H=&UL
M<W!E8VEA;&-H87)S*"1N86UE*2D@/SX\+W-T<F]N9SX\+W1D/@H@(#QT9#X*
M("`@/#]P:'`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=C871E9V]R>5]C;VQO
M<G,G*2DZ(#\^"B`@("`\:6YP=70@8VQA<W,](F9I>&5D(B!S:7IE/2(W(B!S
M='EL93TB8F%C:V=R;W5N9#H\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&-O;&]R*2`_/CL@8V]L;W(Z/#]P:'`@96-H;R`D9F=C;VQO<B`_/B(@;F%M
M93TB8V]L;W)?/#]P:'`@96-H;R!B87-E-C1?96YC;V1E*"1N86UE*2`_/B(@
M=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I(#\^
M(B`O/@H@("`@/&$@:')E9CTB/#]P:'`@96-H;R`D8U]U<FP@/SXB(&]N8VQI
M8VL](G=I;F1O=RYO<&5N*"<\/W!H<"!E8VAO("1C7W5R;"`_/B<L("=C;VQO
M<G!I8VME<B<L("=T;V]L8F%R/6YO+&QO8V%T:6]N/6YO+'-T871U<SUN;RQS
M8W)O;&QB87)S/6YO+')E<VEZ86)L93UN;RQW:61T:#TQ,C`L:&5I9VAT/3(U
M,"QL969T/3$P,"QT;W`],3`P)RD[(')E='5R;B!F86QS93LB(&]N;6]U<V5O
M=70](G=I;F1O=RYS=&%T=7,])R<[(B!O;FUO=7-E;W9E<CTB=VEN9&]W+G-T
M871U<STG/#]P:'`@96-H;R!?*")#;VQO<B!0:6-K97(B*2`_/B<[(')E='5R
M;B!T<G5E.R(@8VQA<W,](G=I9&=E="(@=&%R9V5T/2)C;VQO<G!I8VME<B(^
M"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V-O;&]R<&EC:V5R+G!N9R<L
M(%\H(D-O;&]R(%!I8VME<B(I+"`G:&5I9VAT/2(Q-B(G+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*("`@(#P_<&AP(&5N9&EF
M.R`_/@H@("`@/&$@:')E9CTB(R(@;VYC;&EC:STB<F5M;W9E*&1E8V]D9552
M24-O;7!O;F5N="@G/#]P:'`@96-H;R!R87=U<FQE;F-O9&4H)&YA;64I(#\^
M)RDI.R!R971U<FX@9F%L<V4[(CX\/W!H<"!E8VAO($AO<F1E.CII;6<H)V1E
M;&5T92YP;F<G*2`_/CPO83X*("`\+W1D/@H@/"]T<CX*/#]P:'`@96YD9F]R
M96%C:#L@/SX*/"]T86)L93X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R
M969S+V-H96-K8F]X+FEN8P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#,W-@`Q,#0Q-S,V,S`Q,0`P,C(P,3$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/&EN<'5T('1Y<&4](F-H96-K8F]X
M(B!C;&%S<STB8VAE8VMB;W@B(&ED/2(\/W!H<"!E8VAO("1P<F5F(#\^(B!N
M86UE/2(\/W!H<"!E8VAO("1P<F5F(#\^(CP_<&AP(&5C:&\@)'!R969S+3YG
M971686QU92@D<')E9BD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^
M("\^"CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"1P<F5F+"`D7W!R969S6R1P
M<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_<&AP(&5C:&\@)&AE;'!L:6YK(#\^
M"CQB<B`O/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]D96QE=&5I
M9&5N=&ET>2YI;F,`````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,S,`,3`T
M,3<S-C,P,3$`,#(S,C(W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G9&5F
M875L=%]I9&5N=&ET>2<I*3H@/SX*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@H\(2TM"F9U;F-T:6]N(&1E;&5T94ED96YT:71Y*"D*>PH@("`@
M=F%R(&EN9&5X(#T@9&]C=6UE;G0N<')E9G,N:61E;G1I='DN<V5L96-T961)
M;F1E>#L*("`@('9A<B!I9"`](&1O8W5M96YT+G!R969S+FED96YT:71Y+F]P
M=&EO;G-;:6YD97A=+G9A;'5E.PH@("`@:68@*&ED(#X](#`I('L*("`@("`@
M("!D;V-U;65N="YL;V-A=&EO;BYH<F5F(#T@(CP_<&AP(&5C:&\@<W1R7W)E
M<&QA8V4H)R9A;7`[)RP@)R8G+"!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z
M.G-E;&95<FPH=')U92DL(&%R<F%Y*"=A8W1I;VY)1"<@/3X@)V1E;&5T95]I
M9&5N=&ET>2<L("=I9"<@/3X@)R<I*2D@/SXB("L@:60["B`@("!]"GT*+R\M
M+3X*/"]S8W)I<'0^"CQB<B`O/@H\:6YP=70@='EP93TB8G5T=&]N(B!O;F-L
M:6-K/2)D96QE=&5)9&5N=&ET>2@I(B!C;&%S<STB8G5T=&]N(B!V86QU93TB
M/#]P:'`@96-H;R!?*")$96QE=&4@<V5L96-T960@:61E;G1I='DB*2`_/B(@
M+SX\8G(@+SX\8G(@+SX*/#]P:'`@96YD:68[(#\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W
M,S$`,3`T,3<S-C,P,3$`,#(P-S8T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#PO9&EV/@H*/&)R(&-L87-S/2)S<&%C97(B
M("\^"CQD:78@8VQA<W,](FYO=W)A<"(^"B`\:6YP=70@='EP93TB<W5B;6ET
M(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")3879E($]P
M=&EO;G,B*2`_/B(@+SXF;F)S<#L*(#QI;G!U="!T>7!E/2)R97-E="(@8VQA
M<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B56YD;R!#:&%N9V5S
M(BD@/SXB("\^)FYB<W`["B`\/W!H<"!I9B`H8V]U;G0H)'!R969'<F]U<',I
M(#X@,2DZ(#\^/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@
M=F%L=64](CP_<&AP(&5C:&\@7R@B4F5T=7)N('1O($]P=&EO;G,B*2`_/B(@
M;VYC;&EC:STB9&]C=6UE;G0N<')E9G,N86-T:6]N240N=F%L=64],#L@9&]C
M=6UE;G0N<')E9G,N9W)O=7`N=F%L=64])R<[(&1O8W5M96YT+G!R969S+G-U
M8FUI="@I.R(@+SX\/W!H<"!E;F1I9CL@/SX*/"]D:78^"CPO9F]R;3X*````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O96YU;2YI;F,`````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#0U`#$P-#$W,S8S
M,#$Q`#`R,3$V,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D<')E9BP@)%]P<F5F
M<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO("1H96QP;&EN
M:R`_/CQB<B`O/@H\<V5L96-T(&ED/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'!R968I(#\^(B!N86UE/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'!R968I(#\^(CX*/#]P:'`@)&5S8R`]("%E;7!T>2@D7W!R969S
M6R1P<F5F75LG97-C87!E9"==*3L@)&-U<G9A;"`]("1P<F5F<RT^9V5T5F%L
M=64H)'!R968I.R!F;W)E86-H("@D7W!R969S6R1P<F5F75LG96YU;2==(&%S
M("1K97D@/3X@)'9A;"DZ(#\^"CQO<'1I;VX\/W!H<"!E8VAO("1C=7)V86P@
M/3T@)&ME>2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/B!V86QU
M93TB/#]P:'`@96-H;R`D97-C(#\@)&ME>2`Z(&AT;6QS<&5C:6%L8VAA<G,H
M)&ME>2D@/SXB/CP_<&AP(&5C:&\@)&5S8R`_("1V86P@.B!H=&UL<W!E8VEA
M;&-H87)S*"1V86PI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@@/SX*
M/"]S96QE8W0^"CQB<B`O/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-3(P`#$P
M-#$W,S8S,#$Q`#`R,S(U,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<"!I9B`H)'!R969S+3YI<TQO8VME9"@G9&5F
M875L=%]I9&5N=&ET>2<I*3H@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB:61E;G1I='DB('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)$=,3T)!3%-;
M)VED96YT:71Y)UTM/F=E=$1E9F%U;'0H*2`_/B(@+SX*/#]P:'`@96QS93H@
M/SX*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IV87(@
M:61E;G1I=&EE<R`](&YE=R!!<G)A>2@I.PH\/W!H<`IG;&]B86P@)&ED96YT
M:71Y.PHD:61E;G1I=&EE<R`]("1I9&5N=&ET>2T^9V5T06QL*"=I9"<I.PHD
M9&5F875L=%]I9&5N=&ET>2`]("1I9&5N=&ET>2T^9V5T1&5F875L="@I.PHD
M;65M8F5R<R`]("1P<F5F1W)O=7!S6R=I9&5N=&ET:65S)UU;)VUE;6)E<G,G
M73L*9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&ED96YT:71I97,I.R`K*R1I
M*3H*/SX*:61E;G1I=&EE<UL\/W!H<"!E8VAO("1I(#\^72`](&YE=R!!<G)A
M>2@I.PH\/W!H<`HD:R`](#`["F9O<F5A8V@@*"1M96UB97)S(&%S("1M96UB
M97(I.@H@("`@:68@*"1M96UB97(@/3T@)V1E9F%U;'1?:61E;G1I='DG('Q\
M"B`@("`@("`@(65M<'1Y*"1?<')E9G-;)&UE;6)E<EU;)VQO8VME9"==*2!\
M?`H@("`@("`@("1?<')E9G-;)&UE;6)E<EU;)W1Y<&4G72`]/2`G<W!E8VEA
M;"<@?'P*("`@("`@("`D7W!R969S6R1M96UB97)=6R=T>7!E)UT@/3T@)VQI
M;FLG*2!["B`@("`@("`@8V]N=&EN=64["B`@("!]"C\^"FED96YT:71I97-;
M/#]P:'`@96-H;R`D:2`_/EU;/#]P:'`@96-H;R`D:RLK(#\^72`](&YE=R!!
M<G)A>2@B/#]P:'`@96-H;R`D;65M8F5R(#\^(BP@(CP_<&AP(&5C:&\@)%]P
M<F5F<ULD;65M8F5R75LG='EP92==(#\^(BP@/#]P:'`*)'9A;"`]("1I9&5N
M=&ET>2T^9V5T5F%L=64H)&UE;6)E<BP@)&DI.PIS=VET8V@@*"1?<')E9G-;
M)&UE;6)E<EU;)W1Y<&4G72D@>PIC87-E("=C:&5C:V)O>"<Z"B`@("!E8VAO
M("1V86P@/R`G=')U92<@.B`G9F%L<V4G.PH@("`@8G)E86L["@IC87-E("=N
M=6UB97(G.@H@("`@96-H;R`H:6YT*21V86P["B`@("!B<F5A:SL*"F-A<V4@
M)W1E>'1A<F5A)SH*("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@
M("1V86P@/2!I;7!L;V1E*")<;B(L("1V86PI.PH@("`@?0H@("`@96-H;R`G
M9&5C;V1E55))0V]M<&]N96YT*"(G("X@<F%W=7)L96YC;V1E*"1V86PI("X@
M)R(I)SL*("`@(&)R96%K.PH*9&5F875L=#H*("`@(&5C:&\@)V1E8V]D9552
M24-O;7!O;F5N="@B)R`N(')A=W5R;&5N8V]D92@D=F%L*2`N("<B*2<["GT*
M/SXI.PH\/W!H<"!E;F1F;W)E86-H.R!E;F1F;W([(#\^"@IF=6YC=&EO;B!N
M97=#:&]I8V4H*0I["B`@("!V87(@9FEE;&0L('9A;#L*("`@('9A<B!I;F1E
M>"`](&1O8W5M96YT+G!R969S+FED96YT:71Y+G-E;&5C=&5D26YD97@["B`@
M("!V87(@:60@/2!D;V-U;65N="YP<F5F<RYI9&5N=&ET>2YO<'1I;VYS6VEN
M9&5X72YV86QU93L*("`@(&EF("AI9"`\(#`I('L*("`@("`@("!D;V-U;65N
M="YP<F5F<RYR97-E="@I.PH@("`@("`@(&1O8W5M96YT+G!R969S+FED96YT
M:71Y+G-E;&5C=&5D26YD97@@/2!I;F1E>#L*("`@("`@("!R971U<FX["B`@
M("!]"B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&ED96YT:71I97-;:61=+FQE
M;F=T:#L@:2LK*2!["B`@("`@("`@9FEE;&0@/2!D;V-U;65N="YP<F5F<UMI
M9&5N=&ET:65S6VED75MI75LP75T["B`@("`@("`@=F%L(#T@:61E;G1I=&EE
M<UMI9%U;:5U;,ET["B`@("`@("`@<W=I=&-H("AI9&5N=&ET:65S6VED75MI
M75LQ72D@>PH@("`@("`@(&-A<V4@(F5N=6TB.@H@("`@("`@("`@("!F;W(@
M*'9A<B!J(#T@,#L@:B`\(&9I96QD+F]P=&EO;G,N;&5N9W1H.R!J*RLI('L*
M("`@("`@("`@("`@("`@(&EF("AF:65L9"YO<'1I;VYS6VI=+G9A;'5E(#T]
M('9A;"D@>PH@("`@("`@("`@("`@("`@("`@(&9I96QD+G-E;&5C=&5D26YD
M97@@/2!J.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E(")C:&5C:V)O>"(Z"B`@("`@("`@("`@(&9I96QD+F-H96-K
M960@/2!V86P["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(")I
M;7!L:6-I="(Z"B`@("`@("`@("`@(&5V86PH(FYE=T-H;VEC95\B("L@:61E
M;G1I=&EE<UMI9%U;:5U;,%T@*R`B*'9A;"DB*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&9I96QD+G9A;'5E
M(#T@=F%L.PH@("`@("`@('T*("`@('T*?0H*+R\M+3X*/"]S8W)I<'0^"CQB
M<B`O/@H\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G:61E;G1I='DG+"!?*")3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB*2D@/SX\
M8G(@+SX*/'-E;&5C="!N86UE/2)I9&5N=&ET>2(@:60](FED96YT:71Y(B!O
M;F-H86YG93TB:F%V87-C<FEP=#IN97=#:&]I8V4H*2(^"B`@/&]P=&EO;B!V
M86QU93TB+3(B('-E;&5C=&5D/2)S96QE8W1E9"(*/CP_<&AP(&5C:&\@7R@B
M3F]N92(I(#\^/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB+3$B/CP_<&AP
M(&5C:&\@7R@B0W)E871E(&$@;F5W(&]N92(I(#\^/"]O<'1I;VX^"CP_<&AP
M(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1I9&5N=&ET:65S*3L@)&DK*RDZ
M(#\^"B`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D:2`_/B(\/W!H<"!I
M9B`H)&D@/3T@)&1E9F%U;'1?:61E;G1I='DI(&5C:&\@)R!S96QE8W1E9#TB
M<V5L96-T960B)R`_/CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ED
M96YT:71I97-;)&E=*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W([(#\^"CPO
M<V5L96-T/CQB<B`O/@H\/W!H<"!E;F1I9CL@/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]P<F5F<R]L:6YK+FEN8P``````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,C,`,3`T,3<S-C,P,3$`,#(Q,34R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QA
M(&AR968](CP_<&AP(&5C:&\@*&ES<V5T*"1?<')E9G-;)'!R969=6R=U<FPG
M72DI(#\*2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1?<')E9G-;)'!R969=6R=U
M<FPG72D@.B`D7W!R969S6R1P<F5F75LG>'5R;"=="C\^(CX\/W!H<"!I9B`H
M:7-S970H)%]P<F5F<ULD<')E9EU;)VEM9R==*2D@96-H;PI(;W)D93HZ:6UG
M*"1?<')E9G-;)'!R969=6R=I;6<G72P@)%]P<F5F<ULD<')E9EU;)V1E<V,G
M72P@)VAS<&%C93TB,R(G*0H_/CQS=')O;F<^/#]P:'`@96-H;R`D7W!R969S
M6R1P<F5F75LG9&5S8R==(#\^/"]S=')O;F<^/"]A/B9N8G-P.SP_<&AP(&5C
M:&\*)&AE;'!L:6YK(#\^/&)R("\^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP
M;&%T97,O<')E9G,O;75L=&EE;G5M+FEN8P``````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,#0W`#$P-#$W,S8S,#$Q`#`R,C(S-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<"!E8VAO($AO
M<F1E.CIL86)E;"@D<')E9BP@)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF
M;F)S<#L\/W!H<"!E8VAO("1H96QP;&EN:R`_/CQB<B`O/@H\<V5L96-T(&ED
M/2(\/W!H<"!E8VAO("1P<F5F(#\^(B!M=6QT:7!L93TB;75L=&EP;&4B('-I
M>F4](CP_<&AP(&5C:&\@;6EN*#0L(&-O=6YT*"1?<')E9G-;)'!R969=6R=E
M;G5M)UTI*2`_/B(@;F%M93TB/#]P:'`@96-H;R`D<')E9B`_/EM=(CX*/#]P
M:'`@)'-E;&5C=&5D(#T@0'5N<V5R:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H
M)'!R968I*3L@9F]R96%C:"`H)%]P<F5F<ULD<')E9EU;)V5N=6TG72!A<R`D
M:V5Y(#T^("1V86PI.B`_/@H\;W!T:6]N/#]P:'`@96-H;R!I;E]A<G)A>2@D
M:V5Y+"`D<V5L96-T960I(#\@)R!S96QE8W1E9#TB<V5L96-T960B("<@.B`G
M)R`_/B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI
M(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9A;"D@/SX\+V]P
M=&EO;CX*/#]P:'`@96YD9F]R96%C:"`_/@H\+W-E;&5C=#X*/&)R("\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O<')E9G,O;G5M8F5R+FEN8P``````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,S<V`#$P-#$W,S8S,#$Q`#`R,34Q,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\:6YP=70@
M='EP93TB=&5X="(@:60](CP_<&AP(&5C:&\@)'!R968@/SXB(&YA;64](CP_
M<&AP(&5C:&\@)'!R968@/SXB('-I>F4](C,B(&UA>&QE;F=T:#TB,R(@=F%L
M=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<')E9G,M/F=E=%9A
M;'5E*"1P<F5F*2D@/SXB("\^"CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"1P
M<F5F+"`D7W!R969S6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_<&AP(&5C
M:&\@)&AE;'!L:6YK(#\^/&)R("\^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+W!R969S+V]V97)V:65W+FEN8P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,34Q-@`Q,#0Q-S,V,S`Q,0`P,C(P-C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/&1I=B!C;&%S<STB<')E9G-/
M=F5R=FEE=R(^"CP_<&AP(&9O<F5A8V@@*"1C;VQU;6YS(&%S("1K97D@/3X@
M)&-O;'5M;BDZ(#\^"B`\9&EV('-T>6QE/2)W:61T:#H\/W!H<"!E8VAO("1S
M<&%N("T@,2`_/B4B/@H@(#QD:78^"B`@(#QH,CX\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&ME>2D@/SX\+V@R/@H*("`@/&1L/@H@("`\/W!H<"!F
M;W)E86-H("@D8V]L=6UN(&%S("1G<F]U<"`]/B`D9W9A;',I.B`_/@H@("`@
M/#]P:'`@:68@*%!R969S7U5).CIG<F]U<$ES161I=&%B;&4H)&=R;W5P*2DZ
M(#\^"B`@("`@/#]P:'`@:68@*"%E;7!T>2@D9W9A;'-;)W5R;"==*2DZ(#\^
M"B`@("`@(#QD=#X\/W!H<"!E8VAO($AO<F1E.CIW:61G970H2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"1G=F%L<ULG=7)L)UTL("1A<'`I+"`D9W9A;'-;)VQA
M8F5L)UTL("<G+"`G)RP@)R<L("1G=F%L<ULG;&%B96PG72D@/SX\+V1T/@H@
M("`@(#P_<&AP(&5L<V4Z(#\^"B`@("`@(#QD=#X\/W!H<"!E8VAO($AO<F1E
M.CIW:61G970H571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*"DL
M(&%R<F%Y*"=G<F]U<"<@/3X@)&=R;W5P+"`G87!P)R`]/B`D1TQ/0D%,4ULG
M87!P)UTI*2P@)&=V86QS6R=L86)E;"==+"`G)RP@)R<L("<G+"`D9W9A;'-;
M)VQA8F5L)UTI(#\^/"]D=#X*("`@("`\/W!H<"!E;F1I9CL@/SX*("`@("`\
M9&0^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G=F%L<ULG9&5S8R==
M*2`_/CPO9&0^"B`@("`\/W!H<"!E;F1I9CL@/SX*("`@/#]P:'`@96YD9F]R
M96%C:#L@/SX*("`@/"]D;#X*("`\+V1I=CX*(#PO9&EV/@H\/W!H<"!E;F1F
M;W)E86-H.R`_/@H\+V1I=CX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W!R969S+W!A<W-W;W)D+FEN8P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#0S,``Q,#0Q-S,V,S`Q,0`P,C(P-30`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`@96-H;R!(
M;W)D93HZ;&%B96PH)'!R968L("1?<')E9G-;)'!R969=6R=D97-C)UTI(#\^
M)FYB<W`[/#]P:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*/&EN<'5T('1Y
M<&4](G!A<W-W;W)D(B!I9#TB/#]P:'`@96-H;R`D<')E9B`_/B(@;F%M93TB
M/#]P:'`@96-H;R`D<')E9B`_/B(@<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B
M(&-L87-S/2)F:7AE9"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D<')E9G,M/F=E=%9A;'5E*"1P<F5F*2D@/SXB("\^/&)R("\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F
M<R]S96QE8W0N:6YC````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$R,#``,3`T,3<S-C,P,3$`,#(Q-#8U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L
M*"1P<F5F+"`D7W!R969S6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_<&AP
M(&5C:&\@)&AE;'!L:6YK(#\^/&)R("\^"CQS96QE8W0@:60](CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D<')E9BD@/SXB(&YA;64](CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D<')E9BD@/SXB/@H\/W!H<"`D97-C(#T@
M(65M<'1Y*"1?<')E9G-;)'!R969=6R=E<V-A<&5D)UTI.R`D8W5R=F%L(#T@
M)'!R969S+3YG971686QU92@D<')E9BD[("1S96QE8W1?=F%R(#T@571I;#HZ
M;F]N26YP=71687(H)'!R968@+B`G7V]P=&EO;G,G*3L@9F]R96%C:"`H)'-E
M;&5C=%]V87(@87,@)'-E;&5C=%]K97D@/3X@)'-E;&5C=%]V86PI.B`_/@H@
M/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D97-C(#\@)'-E;&5C=%]K97D@
M.B!H=&UL<W!E8VEA;&-H87)S*"1S96QE8W1?:V5Y*2`_/B(\/W!H<"!I9B`H
M)'-E;&5C=%]K97D@/3T@)&-U<G9A;"D@96-H;R`G('-E;&5C=&5D/2)S96QE
M8W1E9"(G(#\^/CP_<&AP(&5C:&\@)&5S8R`_("1S96QE8W1?=F%L(#H@:'1M
M;'-P96-I86QC:&%R<R@D<V5L96-T7W9A;"D@/SX\+V]P=&EO;CX*/#]P:'`@
M96YD9F]R96%C:#L@/SX*/"]S96QE8W0^"CQB<B`O/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]P<F5F<R]T97AT+FEN8P``````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`T,3``,3`T,3<S-C,P,3$`,#(Q,3<T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP(&5C:&\@2&]R9&4Z
M.FQA8F5L*"1P<F5F+"`D7W!R969S6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P
M.SP_<&AP(&5C:&\@)&AE;'!L:6YK(#\^/&)R("\^"CQI;G!U="!I9#TB/#]P
M:'`@96-H;R`D<')E9B`_/B(@;F%M93TB/#]P:'`@96-H;R`D<')E9B`_/B(@
M<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B(&-L87-S/2)F:7AE9"(@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<')E9G,M/F=E=%9A;'5E
M*"1P<F5F*2D@/SXB("\^/&)R("\^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O=&5X
M=&%R96$N:6YC````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#4T
M`#$P-#$W,S8S,#$Q`#`R,C`S-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D<')E
M9BP@)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO
M("1H96QP;&EN:R`_/CQB<B`O/@H\9&EV(&-L87-S/2)F:7AE9"(^"CQT97AT
M87)E82!W<F%P/2)H87)D(B!I9#TB/#]P:'`@96-H;R`D<')E9B`_/B(@;F%M
M93TB/#]P:'`@96-H;R`D<')E9B`_/B(@<F]W<STB-B(@8V]L<STB.#`B(&-L
M87-S/2)F:7AE9"(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F
M<RT^9V5T5F%L=64H)'!R968I*2`_/CPO=&5X=&%R96$^/&)R("\^"CPO9&EV
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VQO9VEN+P``````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q
M,0`P,3<U,38`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$R,C8V`#$P-#$W,S8S,#$Q`#`R,3,R-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HD<FEG:'1!;&EG;B`](&5M
M<'1Y*"1N;'-;)W)T;"==6R1L86YG=6%G95TI(#\@)W)I9VAT)R`Z("=L969T
M)SL*)&QE9G1!;&EG;B`](&5M<'1Y*"1N;'-;)W)T;"==6R1L86YG=6%G95TI
M(#\@)VQE9G0G(#H@)W)I9VAT)SL*/SX*/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/@H\(2TM"F9U;F-T:6]N('-E=$9O8W5S*"D*>PH@("`@:68@
M*&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W5S97(N=F%L=64@/3T@(B(I
M('L*("`@("`@("!D;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]U<V5R+F9O
M8W5S*"D["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M96YT+FAO<F1E7VQO
M9VEN+FAO<F1E7W!A<W,N9F]C=7,H*3L*("`@('T*?0IF=6YC=&EO;B!S=6)M
M:71?;&]G:6XH92D*>PH@("`@:68@*'1Y<&5O9B!E("$]("=U;F1E9FEN960G
M("8F("%E;G1E<E]K97E?=')A<"AE*2D@>PH@("`@("`@(')E='5R;CL*("`@
M('T*"B`@("!I9B`H9&]C=6UE;G0N:&]R9&5?;&]G:6XN:&]R9&5?=7-E<BYV
M86QU92`]/2`B(BD@>PH@("`@("`@(&%L97)T*"(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B*2D@/SXB*3L*("`@("`@("!D;V-U;65N="YH;W)D95]L;V=I;BYH
M;W)D95]U<V5R+F9O8W5S*"D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?2!E;'-E(&EF("AD;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]P87-S+G9A
M;'5E(#T]("(B*2!["B`@("`@("`@86QE<G0H(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9"(I*2`_/B(I.PH@("`@("`@(&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO
M<F1E7W!A<W,N9F]C=7,H*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M(&5L<V4@>PH@("`@("`@(&1O8W5M96YT+FAO<F1E7VQO9VEN+FQO9VEN0G5T
M=&]N+F1I<V%B;&5D(#T@=')U93L*/#]P:'`@:68@*"%E;7!T>2@D:65?8VQI
M96YT8V%P<RDI.B`_/@H@("`@("`@('1R>2!["B`@("`@("`@("`@(&1O8W5M
M96YT+FAO<F1E7VQO9VEN+FEE7W9E<G-I;VXN=F%L=64@/2!O8FI#0V%P<RYG
M971#;VUP;VYE;G1697)S:6]N*")[.#DX,C`R,#`M14-"1"TQ,4-&+3A".#4M
M,#!!03`P-4(T,S@S?2(L(")C;VUP;VYE;G1I9"(I.PH@("`@("`@('T@8V%T
M8V@@*&4I('L*("`@("`@("!]"CP_<&AP(&5N9&EF.R`_/@H@("`@("`@(&1O
M8W5M96YT+FAO<F1E7VQO9VEN+G-U8FUI="@I.PH@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0I]"B\O+2T^"CPO<V-R:7!T/@H*/&9O<FT@;F%M93TB:&]R
M9&5?;&]G:6XB(&UE=&AO9#TB<&]S="(@86-T:6]N/2(\/W!H<"!E8VAO($AO
M<F1E.CIS96QF57)L*&9A;'-E+"!T<G5E+"!F86QS92P@=')U92D@/SXB/#]P
M:'`@96-H;R`D8V]N9ELG;65N=2==6R=A;'=A>7,G72`_("<@=&%R9V5T/2)?
M<&%R96YT(B<@.B`G)R`_/CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M=7)L(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ
M.F=E=$9O<FU$871A*"=U<FPG*2D@/SXB("\^"CP_<&AP(&EF("@A96UP='DH
M)&EE7V-L:65N=&-A<',I*3H@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB:65?=F5R<VEO;B(@=F%L=64](B(@+SX*/#]P:'`@96YD:68[(#\^"@H\
M9&EV(&ED/2)M96YU(CX*/#]P:'`*)&UE;G4@/2`F;F5W($UE;G4H2$]21$5?
M345.55]-05-+7TY/3D4I.PHD:&UE;G4@/2`D;65N=2T^<F5N9&5R*"D["FEF
M("@D:&UE;G4I.B`_/@H@/'-P86X@<W1Y;&4](F9L;V%T.CP_<&AP(&5C:&\@
M)')I9VAT06QI9VX@/SXB/CP_<&AP(&5C:&\@)&AM96YU(#\^/"]S<&%N/@H\
M/W!H<"!E;F1I9CL@/SX*(#QH,2!S='EL93TB=&5X="UA;&EG;CIC96YT97(B
M/CP_<&AP('!R:6YT9BA?*")796QC;VUE('1O("5S(BDL("1R96=I<W1R>2T^
M9V5T*"=N86UE)RDI(#\^/"]H,3X*/"]D:78^"@H\8G(@8VQA<W,](G-P86-E
M<B(@+SX*/#]P:'`@)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T
M96YE<G,G(#T^("=S=&%T=7,G*2D@/SX*"CQT86)L92!W:61T:#TB,3`P)2(^
M/'1R/CQT9"!A;&EG;CTB8V5N=&5R(CX\=&%B;&4@=VED=&@](C,P,"(@86QI
M9VX](F-E;G1E<B(^"@H\/W!H<"!I9B`H(65M<'1Y*"1R96%S;VXI*3H@/SX*
M/'1R/@H@(#QT9"!C;VQS<&%N/2(R(B!C;&%S<STB;F]T:6-E(CX\/W!H<"!E
M8VAO("1R96%S;VX@/SX\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*"CQT
M<CX*("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H;R`D<FEG:'1!;&EG;B`_/B(@
M8VQA<W,](FQI9VAT(CX\<W1R;VYG/CP_<&AP(&5C:&\@7R@B57-E<FYA;64B
M*2`_/CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@("`\=&0@86QI9VX](CP_<&AP
M(&5C:&\@)&QE9G1!;&EG;B`_/B(^/&EN<'5T(&-L87-S/2)F:7AE9"(@='EP
M93TB=&5X="(@;F%M93TB:&]R9&5?=7-E<B(@=F%L=64](CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG971&;W)M1&%T82@G:&]R9&5?=7-E
M<B<I*2`_/B(@<W1Y;&4](F1I<F5C=&EO;CIL='(B("\^/"]T9#X*/"]T<CX*
M"CQT<CX*("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H;R`D<FEG:'1!;&EG;B`_
M/B(@8VQA<W,](FQI9VAT(CX\<W1R;VYG/CP_<&AP(&5C:&\@7R@B4&%S<W=O
M<F0B*2`_/CPO<W1R;VYG/B9N8G-P.SPO=&0^"B`@("`\=&0@86QI9VX](CP_
M<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(^/&EN<'5T(&-L87-S/2)F:7AE9"(@
M='EP93TB<&%S<W=O<F0B(&YA;64](FAO<F1E7W!A<W,B('9A;'5E/2(B('-T
M>6QE/2)D:7)E8W1I;VXZ;'1R(B`O/CPO=&0^"CPO='(^"@H\/W!H<"!I9B`H
M(21P<F5F<RT^:7-,;V-K960H)VQA;F=U86=E)RDI.B`_/@H\='(^"B`@("`\
M=&0@86QI9VX](CP_<&AP(&5C:&\@)')I9VAT06QI9VX@/SXB(&-L87-S/2)L
M:6=H="(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(DQA;F=U86=E(BD@/SX\+W-T
M<F]N9SX\+W1D/@H@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1L969T06QI
M9VX@/SXB(&-L87-S/2)L:6=H="(@<W1Y;&4](F1I<F5C=&EO;CIL='(B/CP_
M<&AP(&5C:&\@)&QA;F=S(#\^/"]T9#X*/"]T<CX*/#]P:'`@96YD:68[(#\^
M"@H\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`@(#QT9"!A;&EG;CTB/#]P
M:'`@96-H;R`D;&5F=$%L:6=N(#\^(B!C;&%S<STB;&EG:'0B/CQI;G!U="!N
M86UE/2)L;V=I;D)U='1O;B(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP
M(&5C:&\@7R@B3&]G(&EN(BD@/SXB('1Y<&4](G-U8FUI="(@;VYC;&EC:STB
M<F5T=7)N('-U8FUI=%]L;V=I;B@I.R(@+SX\+W1D/@H\+W1R/@H*/#]P:'`@
M:68@*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72`F)B`D875T:"T^:&%S0V%P
M86)I;&ET>2@G861D)RDI.B`_/@H\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*
M("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H;R`D;&5F=$%L:6=N(#\^(B!C;&%S
M<STB;&EG:'0B/CP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R
M86UE=&5R*$AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*2`N("<O<VEG;G5P+G!H<"<I+"`G=7)L)RP@571I;#HZ9V5T1F]R
M;41A=&$H)W5R;"<I*2P@7R@B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+B(I+"`G;&EG:'0G*2`N(%\H(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@
M4VEG;B!U<"XB*2`_/CPO83X\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*
M/#]P:'`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=R97-E='!A<W-W;W)D
M)RDI.B`_/@H\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`@(#QT9"!C;&%S
M<STB;&EG:'0B/CP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R
M86UE=&5R*$AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*2`N("<O<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`G*2P@)W5R
M;"<L(%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*2DL(%\H(D9O<F=O="!Y;W5R
M('!A<W-W;W)D/R(I+"`G;&EG:'0G*2`N(%\H(D9O<F=O="!Y;W5R('!A<W-W
M;W)D/R(I(#\^/"]A/CPO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H*/"]T
M86)L93X\+W1D/CPO='(^/"]T86)L93X*/"]F;W)M/@H*/#]P:'`@:68@*$!I
M<U]R96%D86)L92A(3U)$15]"05-%("X@)R]C;VYF:6<O;6]T9"YP:'`G*2D@
M<F5Q=6ER92!(3U)$15]"05-%("X@)R]C;VYF:6<O;6]T9"YP:'`G.R`_/@H*
M/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"CP_<&AP(&EF
M("@A)'!R969S+3YI<TQO8VME9"@G;&%N9W5A9V4G*2DZ"B`@("`D;&%N9U]U
M<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)VQO9VEN+G!H<"<L('1R=64I
M.PH@("`@:68@*"@D=7)L(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I*2D@
M>PH@("`@("`@("1L86YG7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D;&%N
M9U]U<FPL("=U<FPG+"`D=7)L+"!F86QS92D["B`@("!]"B`@("`D;&%N9U]U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&QA;F=?=7)L+"`G;F5W7VQA;F<G
M+"`G)RP@9F%L<V4I.PH_/@IF=6YC=&EO;B!S96QE8W1,86YG*"D*>PH@("`@
M+R\@5V4@;F5E9"!T;R!R96QO860@=&AE(&QO9VEN('!A9V4@:&5R92P@8G5T
M(&]N;'D@:68@=&AE('5S97(*("`@("\O(&AA<VXG="!A;')E861Y(&5N=&5R
M960@82!U<V5R;F%M92!A;F0@<&%S<W=O<F0N"B`@("!I9B`H9&]C=6UE;G0N
M:&]R9&5?;&]G:6XN:&]R9&5?=7-E<BYV86QU92`]/2`G)R`F)@H@("`@("`@
M(&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W!A<W,N=F%L=64@/3T@)R<I
M('L*("`@("`@("!V87(@;&%N9U]P86=E(#T@)SP_<&AP(&5C:&\@)&QA;F=?
M=7)L(#\^)R`K(&1O8W5M96YT+FAO<F1E7VQO9VEN+FYE=U]L86YG6V1O8W5M
M96YT+FAO<F1E7VQO9VEN+FYE=U]L86YG+G-E;&5C=&5D26YD97A=+G9A;'5E
M.PH@("`@("`@('-E;&8N;&]C871I;VX@/2!L86YG7W!A9V4["B`@("!]"GT*
M/#]P:'`@96YD:68[(#\^"@II9B`H<&%R96YT+F9R86UE<RYH;W)D95]M86EN
M*2!["B`@("!D;V-U;65N="YH;W)D95]L;V=I;BYT87)G970@/2`G7W!A<F5N
M="<["GT*"B\O(%-E="!U<"!T:&4@96YT97(@:V5Y=')A<"!C;V1E+@II9B`H
M='EP96]F(&1O8W5M96YT+F-A<'1U<F5%=F5N=',@(3T@)W5N9&5F:6YE9"<I
M('L*("`@(&1O8W5M96YT+F-A<'1U<F5%=F5N=',H179E;G0N2T594%)%4U,I
M.PH@("`@9&]C=6UE;G0N;VYK97EP<F5S<R`]('-U8FUI=%]L;V=I;CL*?0HO
M+RTM/@H\+W-C<FEP=#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8P``````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,34R`#$P-#$W,S8S,#$Q`#`R
M,30U-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*)&T@/2`F;F5W($AO<F1E7TUO8FEL92A?*"),;V<@:6XB*2D[
M"B1M+3YA9&0H;F5W($AO<F1E7TUO8FEL95]T97AT*'-P<FEN=&8H7R@B5V5L
M8V]M92!T;R`E<R(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<I*2DI.PH*)&8@
M/2`F;F5W($AO<F1E7TUO8FEL95]F;W)M*"=L;V=I;BYP:'`G*3L*)&8M/F%D
M9"AN97<@2&]R9&5?36]B:6QE7VAI9&1E;B@G=7)L)RP@571I;#HZ9V5T1F]R
M;41A=&$H)W5R;"<L("<G*2DI.PHD9BT^861D*&YE=R!(;W)D95]-;V)I;&5?
M:6YP=70H)VAO<F1E7W5S97(G+"`G)RP@7R@B57-E<FYA;64Z("(I*2D["@HO
M+R!!9&0@82!P87-S=V]R9"!I;G!U="P@86YD('-E="!T:&4@='EP92!A8V-O
M<F1I;F=L>2X*)'`@/2`F)&8M/F%D9"AN97<@2&]R9&5?36]B:6QE7VEN<'5T
M*"=H;W)D95]P87-S)RP@)R<L(%\H(E!A<W-W;W)D.B`B*2DI.PHD<"T^<V5T
M*"=T>7!E)RP@)W!A<W-W;W)D)RD["@HO+R!3=6)M:70@8G5T=&]N+@HD9BT^
M861D*&YE=R!(;W)D95]-;V)I;&5?<W5B;6ET*%\H(DQO9R!I;B(I*2D["@HO
M+R!!9&0@=&AE(&9O<FT@=&\@=&AE('!A9V4N"B1M+3YA9&0H)&8I.PH*+R\@
M1&ES<&QA>2!E=F5R>71H:6YG+@HD;2T^9&ES<&QA>2@I.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O8V]M;6]N+6AE861E<BYI;F,`
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S8V`#$P-#$W,S8S
M,#$Q`#`R,38R-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`IG;&]B86P@)&QA;F=U86=E.PII9B`H:7-S970H)&QA
M;F=U86=E*2D@>PH@("`@:&5A9&5R*"=#;VYT96YT+71Y<&4Z('1E>'0O:'1M
M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@:&5A9&5R
M*"=687)Y.B!!8V-E<'0M3&%N9W5A9V4G*3L*?0H_/@H\(41/0U194$4@:'1M
M;"!054),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,"!4<F%N<VET:6]N86PO
M+T5.(B`B1%1$+WAH=&UL,2UT<F%N<VET:6]N86PN9'1D(CX*/"$M+2!(;W)D
M93H@0V]P>7)I9VAT(#(P,#`M,C`P-BP@5&AE($AO<F1E(%!R;VIE8W0N($AO
M<F1E(&ES('5N9&5R('1H92!,1U!,+B`M+3X*/"$M+2`@("`@("`@("`@("`@
M("`@("`@2&]R9&4@4')O:F5C=#H@:'1T<#HO+VAO<F1E+F]R9R\@("`@("`@
M("`@("`@("`@("`@("`M+3X*/"$M+2`@("!'3E4@3&EB<F%R>2!0=6)L:6,@
M3&EC96YS93H@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"`@("`M+3X*/#]P:'`*96-H;R`H(65M<'1Y*"1L86YG=6%G92DI(#\@)SQH
M=&UL(&QA;F<](B<@+B!S=')T<B@D;&%N9W5A9V4L("=?)RP@)RTG*2`N("<B
M)R`Z("<\:'1M;"<["F5C:&\@*"%E;7!T>2@D:65?8VQI96YT8V%P<RDI(#\@
M)R!X;6QN<SI)13XG(#H@)SXG.PH_/@H\:&5A9#X*/#]P:'`*"B1P86=E7W1I
M=&QE(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<I.PII9B`H
M(65M<'1Y*"1T:71L92DI("1P86=E7W1I=&QE("X]("<@.CH@)R`N("1T:71L
M93L*:68@*"%E;7!T>2@D<F5F<F5S:%]T:6UE*2`F)B`A96UP='DH)')E9G)E
M<VA?=7)L*2D@>PH@("`@96-H;R`B/&UE=&$@:'1T<"UE<75I=CU<(G)E9G)E
M<VA<(B!C;VYT96YT/5PB)')E9G)E<VA?=&EM93MU<FP])')E9G)E<VA?=7)L
M7"(@+SY<;B(["GT*"DAO<F1E.CII;F-L=61E4V-R:7!T1FEL97,H*3L*/SX*
M/'1I=&QE/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<&%G95]T:71L
M92D@/SX\+W1I=&QE/@H\;&EN:R!H<F5F/2(\/W!H<"!E8VAO("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG971);6%G941I<B@I(#\^+V9A=FEC;VXN:6-O(B!R
M96P](E-(3U)40U54($E#3TXB("\^"CP_<&AP(&5C:&\@2&]R9&4Z.G-T>6QE
M<VAE971,:6YK*%5T:6PZ.FYO;DEN<'5T5F%R*"=C<W-!<'!S)RDI(#\^"CP_
M<&AP(&5C:&\@:6UP;&]D92@B7&XB+"!5=&EL.CIN;VY);G!U=%9A<B@G;&EN
M:U1A9W,G+"!A<G)A>2@I*2D@/SX*/#]P:'`@:68@*"%E;7!T>2@D:65?8VQI
M96YT8V%P<RDI.B`_/CQS='EL93Y)15PZ8VQI96YT8V%P<R![8F5H879I;W(Z
M=7)L*"-D969A=6QT(V-L:65N=&-A<',I?3PO<W1Y;&4^/#]P:'`@96YD:68[
M(#\^"CPO:&5A9#X*"CQB;V1Y/#]P:'`@:68@*%5T:6PZ.FYO;DEN<'5T5F%R
M*"=B;V1Y0VQA<W,G*2D@96-H;R`G(&-L87-S/2(G("X@)&)O9'E#;&%S<R`N
M("<B)SL@/SX^"CP_<&AP(&EF("@A96UP='DH)&EE7V-L:65N=&-A<',I*3H@
M/SX\244Z8VQI96YT8V%P<R!)1#TB;V)J0T-A<',B("\^/#]P:'`@96YD:68[
M(#\^"@`````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]C;VUM;VXM9F]O=&5R+FEN8P``````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$P,S,`,3`T,3<S-C,P,3$`,#(Q-C4W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QS8W)I<'0@;&%N9W5A
M9V4](DIA=F%38W)I<'0Q+C4B('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA
M+2T*=F%R(%]S971(;W)D951I=&QE(#T@,3L*=')Y('L*("`@(&EF("AD;V-U
M;65N="YT:71L92`F)B!P87)E;G0N9G)A;65S+FAO<F1E7VUA:6XI('!A<F5N
M="YD;V-U;65N="YT:71L92`](&1O8W5M96YT+G1I=&QE.PI](&-A=&-H("AE
M*2!["GT*+R\@+2T^"CPO<V-R:7!T/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V
M87-C<FEP="(^"CPA+2T*:68@*'1Y<&5O9BA?<V5T2&]R9&54:71L92D@/3T@
M)W5N9&5F:6YE9"<@)B8@9&]C=6UE;G0N=&ET;&4@)B8@<&%R96YT+F9R86UE
M<RYH;W)D95]M86EN*2!P87)E;G0N9&]C=6UE;G0N=&ET;&4@/2!D;V-U;65N
M="YT:71L93L*+R\@+2T^"CPO<V-R:7!T/@H\/W!H<"!I9B`H:7-S970H)$=,
M3T)!3%-;)VYO=&EF:6-A=&EO;B==*2D@)$=,3T)!3%-;)VYO=&EF:6-A=&EO
M;B==+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@87)R87DH)VIA=F%S
M8W)I<'0G*2DI.R`_/@H\+V)O9'D^"CPO:'1M;#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R\N:'1A8V-E<W,`````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`T,3<S-C,P,3$`,#(P,3<V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$1E;GD@9G)O
M;2!A;&P*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O````
M````````````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8S,#$V`#`Q-3<P,@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R].95A49W)E>2\`````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`,#$W-#`R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+TYE6%1G<F5Y+VEN9F\N
M<&AP````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$W,@`Q
M,#0Q-S,V,S`Q,0`P,C$P-#,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE
M;65S+TYE6%1G<F5Y+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z
M,S,@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B3F585"(I
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R].95A49W)E>2]S8W)E96XN8W-S````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R,C(`,3`T,3<S-C,P,3$`
M,#(Q,S8V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R].95A49W)E>2]S8W)E
M96XN8W-S+'8@,2XV+C8N,R`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@
M)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(S0T-#L*("`@('-C<F]L
M;&)A<BUB87-E+6-O;&]R.B`C86-A.6%C.PH@("`@<V-R;VQL8F%R+6%R<F]W
M+6-O;&]R.B`C86-A.6%C.PI]"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M
M8V]L;W(Z("-A8V$Y86,["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z("-A
M8V$Y86,["GT*82P@82YF:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0IA+G=I
M9&=E="!["B`@("!C;VQO<CH@(S`P,#L*?0IA+G=I9&=E=#IH;W9E<B!["B`@
M("!C;VQO<CH@=VAI=&4["B`@("!B86-K9W)O=6YD.B`C8V-C.PI]"BYH96%D
M97(@>PH@("`@8V]L;W(Z(",Y9CEF83`["B`@("!B86-K9W)O=6YD.B`C,#`P
M.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(SEF.69A,#L*?0HN<VUA;&QH
M96%D97(@>PH@("`@8V]L;W(Z(",Y9CEF83`["B`@("!B86-K9W)O=6YD.B`C
M,#`P.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C86-A.6%C.PH@("`@8F]R9&5R+6)O='1O;3H@=&AI;B!S
M;VQI9"`C,C(R.PH@("`@8F]R9&5R+7)I9VAT.B!T:&EN('-O;&ED(",R,C([
M"B`@("!B;W)D97(M=&]P.B!T:&EN('-O;&ED("-D9&0["B`@("!B;W)D97(M
M;&5F=#H@=&AI;B!S;VQI9"`C9&1D.PI]"BYS96QE8W1E9"!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C86-A.6%C.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*
M(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C86-A.6%C.PI]"B-M96YU(&@Q('L*("`@(&-O;&]R.B`C,#`P.PI]"B-M
M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(VUE;G4@82YC=7)R96YT('L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",X-S@W.#<["B`@("!C;VQO<CH@(V1D
M9#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(SDY.3L*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED(",R,C(["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(S(R,CL*?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@,7!X
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W-I
M;7!L97@O````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P,3<S-38`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O<VEM<&QE>"]G<F%P:&EC<R\`````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$Q`#`R,3$U
M-@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]S:6UP;&5X+V=R87!H
M:6-S+V)A8VMG<F]U;F0N<&YG````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-#,`
M,3`T,3<S-C,P,3$`,#(S-S<V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````"````!`@`````
M@82QY0````EP2%ES````2````$@`1LEK/@```!5)1$%4"-=C>/:,X>E3AC=O
M&-Z]`P`K:P=+BZH.C0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O<VEM<&QE>"]I;F9O+G!H<```````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<U`#$P-#$W,S8S,#$Q
M`#`R,3`R,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<VEM<&QE
M>"]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,W(&UD:G5K:6,@
M17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(E-I;7!L97@B*3L*"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+W-I;7!L97@O<V-R965N+F-S<P``````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C$U-0`Q,#0Q-S,V,S`Q,0`P,C$S-#<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+RHJ"B`J
M("1(;W)D93H@:&]R9&4O=&AE;65S+W-I;7!L97@O<V-R965N+F-S<RQV(#$N
M."XV+C0@,C`P-2\Q,"\Q."`Q,3HS-#HR,2!J86X@17AP("0*("HO"@IB;V1Y
M('L*("`@(&)A8VMG<F]U;F0Z("-E964@=7)L*&=R87!H:6-S+V)A8VMG<F]U
M;F0N<&YG*3L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-S,Y,&(Y.PI]
M"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",W,SDP8CD["GT*
M82!["B`@("!C;VQO<CH@(S-C-V%E.3L*?0IA.FAO=F5R('L*("`@(&-O;&]R
M.B`C,6(U-V,R.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"BYH
M96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C-S,Y
M,&(Y.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V9F9CL*?0HN;&EG:'0@
M>PH@("`@8V]L;W(Z(",T935D-S(["GT*+G-M86QL:&5A9&5R('L*("`@(&-O
M;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S<S.3!B.3L*?0HN:71E;2![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C96-E9F8T.PI]"BYB=71T;VX@>PH@
M("`@8V]L;W(Z(",S8S=A93D["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9&1D
M.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#`@
M,G!X.PI]"BYB=71T;VXZ:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C.3DY.PI]"G-E;&5C="!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C-SA!-$8Q.PH@("`@8V]L;W(Z("-E964["GT*"B\J($UE
M;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A
M8VMG<F]U;F0Z(",W,SDP8CD["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F
M9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(S4X83)D
M8SL*?0HC;65N=2!A.FAO=F5R('L*("`@(&)A8VMG<F]U;F0Z(",U.&$R9&,[
M"GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-E964["B`@("!B;W)D97(M<FEG:'0Z(#%P
M>"!S;VQI9"`C.3DY.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",Y
M.3D["GT*(V5X<&%N9$)U='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O<'5R<&QE+P``````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8S,#$Q`#`Q-S(P-``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]P=7)P;&4O:6YF;RYP:'``````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`Q-S8`,3`T,3<S-C,P,3$`,#(P-C4Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]P=7)P;&4O:6YF;RYP:'`L=B`Q+C$@
M,C`P-"\Q,2\R-2`P,CHP-#HU-"!C:'5C:R!%>'`@)`H@*B\*"B1T:&5M95]N
M86UE(#T@7R@B4'5R<&QE($AO<F1E(BD["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O<'5R<&QE
M+W-C<F5E;BYC<W,`````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`U-S,V`#$P-#$W,S8S,#$Q`#`R,3(P-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T
M:&5M97,O<'5R<&QE+W-C<F5E;BYC<W,L=B`Q+C$N-"XU(#(P,#8O,#,O,3`@
M,#`Z,3,Z,#8@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD
M.B`C,C(T.PI]"@HN:&5A9&5R8F]X('L*("`@(&)O<F1E<BUC;VQO<CH@(S8V
M.3L*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*+FAE861E<B!["B`@("!C;VQO
M<CH@(V-C93L*("`@(&)A8VMG<F]U;F0Z(",T-#8["B`@("!C;&5A<CH@8F]T
M:#L*?0HN:&5A9&5R(&$Z:&]V97(L(&$N:&5A9&5R.FAO=F5R('L*("`@(&-O
M;&]R.B`C9F9F.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V-C93L*?0IA
M+FAE861E<CIH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*?0IA('L*("`@(&-O
M;&]R.B`C,S,Y.PI]"F$Z:&]V97(@>PH@("`@8V]L;W(Z(&)L=64["GT*+G-E
M;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-B8F-B9F8["GT*+G-E
M;&5C=&5D+6]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-E9CL*?0H*
M+G=I9&=E="!["B`@("!C;VQO<CH@(S(R-#L*?0IA+G=I9&=E=#IH;W9E<B![
M"B`@("!C;VQO<CH@8FQU93L*("`@(&)A8VMG<F]U;F0Z("-B8F-B9F8["GT*
M"BYN;W1I8V4@>PH@("`@9F]N="UW96EG:'0Z(&)O;&0["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C9F9C.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V%A83L*
M("`@('!A9&1I;F<Z(#%P>#L*("`@('!A9&1I;F<M;&5F=#H@-7!X.PH@("`@
M+6UO>BUB;W)D97(M<F%D:75S.B`X<'@["GT*"BYL:6=H="!["B`@("!C;VQO
M<CH@(V9F9CL*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L=F5T
M:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@["GT*+G-M86QL
M:&5A9&5R('L*("`@(&-O;&]R.B`C8V-E.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(S0T-CL*?0HN<VUA;&QH96%D97(@83IH;W9E<BP@82YS;6%L;&AE861E
M<CIH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*?0HN<VUA;&QH96%D97(@82![
M"B`@("!C;VQO<CH@(V-C93L*?0HN8V]N=')O;"!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V,["B`@("!B;W)D97(M8F]T
M=&]M.B`Q<'@@<V]L:60@(SDY.3L*?0HN:71E;2!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E964["GT*+F%C8V5S<TME>2![
M"B`@("!T97AT+61E8V]R871I;VXZ('5N9&5R;&EN93L*?0HN=&5X="!["B`@
M("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["GT*
M"B\J($9O<FT@<W1Y;&5S+B`J+PHN8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S8V.3L*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C,C(T.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L
M:60@(S(R-#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C.3EC.PH@("`@
M8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C.3EC.PH@("`@9F]N="US:7IE.B`Q
M,7!X.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M
M<V5R:68["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO
M<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",T-#8["GT*(VUE;G4@
M=6P@>PH@("`@<&%D9&EN9SH@-7!X.PI]"B-M96YU(&QI('L*("`@(&QI<W0M
M<W1Y;&4M='EP93H@;F]N93L*("`@('1E>'0M86QI9VXZ(&-E;G1E<CL*("`@
M(&UA<F=I;CH@,G!X.PH@("`@9FQO870Z(&QE9G0["GT*(VUE;G4@82!["B`@
M("!C;VQO<CH@(V5E9CL*?0HC;65N=2!A.FAO=F5R('L*("`@(&-O;&]R.B!Y
M96QL;W<["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S8V83L*("`@
M(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",V-F$["B`@("!B;W)D97(M=&]P
M.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@
M(S(R-#L*("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!A+F-U<G)E;G0@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(S8V.#L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C.3EC.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@
M(SDY8SL*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,C(T.PH@("`@8F]R
M9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,C(T.PH@("`@<&%D9&EN9SH@,G!X.PI]
M"B-M96YU(&@Q('L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["B`@("!F;VYT
M+7-I>F4Z(#$X<'@["B`@("!L:6YE+6AE:6=H=#H@-3!P>#L*("`@('9E<G1I
M8V%L+6%L:6=N.B!B;W1T;VT["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC
M<VED96)A<E!A;F5L('L*("`@("UM;WHM8F]R9&5R+7)A9&EU<RUB;W1T;VUR
M:6=H=#H@,35P>#L*("`@('!A9&1I;F<M=&]P.B`U<'@["B`@("!P861D:6YG
M+6)O='1O;3H@,3!P>#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E964["GT*
M(W-I9&5B87)086YE;"!S<&%N('L*("`@('!A9&1I;F<Z(#)P>#L*?0HC<VED
M96)A<E!A;F5L('-P86XL("-S:61E8F%R4&%N96P@82!["B`@("!C;VQO<CH@
M(S`P,#L*("`@('=H:71E+7-P86-E.B!P<F4["B`@("!F;VYT+69A;6EL>3H@
M5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@
M,3%P>#L*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*?0HC<VED96)A<E!A
M;F5L(&$Z:&]V97(@>PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`S<'@["B`@
M("!C;VQO<CH@(S`P,#L*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!L
M:2!A.FAO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["GT*+G1A
M8G-E="!L:2YA8W1I=F5486(@82P@+G1A8G-E="!L:2YA8W1I=F5486(@83IH
M;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-#0V.PH@("`@8F]R9&5R
M+6)O='1O;2UC;VQO<CH@(S0T-CL*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I
M97<N("HO"BYP<F5F<T]V97)V:65W(&@R('L*("`@(&-O;&]R.B`C9F9F.PI]
M"@`````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]P<FEN="\`````````````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P
M,3$`,#$W,#,Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!R:6YT
M+W-C<F5E;BYC<W,`````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,3,S,0`Q,#0Q-S,V,S`Q,0`P,C$P,34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O
M=&AE;65S+W!R:6YT+W-C<F5E;BYC<W,L=B`Q+C$N,3`N-"`R,#`V+S`S+S$T
M(#(R.C0S.C4P(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N
M9#H@(V9F9CL*("`@(&-O;&]R.B`C,#`P.PI]"F$@>PH@("`@8V]L;W(Z(",P
M,#`["GT*"B-M96YU('L*("`@(&1I<W!L87DZ(&YO;F4["GT*"BYH96%D97)B
M;W@@>PH@("`@8F]R9&5R.B!N;VYE.PI]"BYS96QE8W1E9"!["B`@("!B86-K
M9W)O=6YD.B`C9&1D.PI]"BYW:61G970@>PH@("`@8V]L;W(Z(",P,#`["GT*
M+FAE861E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-F
M9F8["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C
M:V=R;W5N9#H@(V9F9CL*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C
M9F9F.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["GT*+FET
M96TP+"`N:71E;3$@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"`C8V-C.PI]"BYS:6=N871U<F4L("YS:6=N
M871U<F4M9FEX960@>PH@("`@8V]L;W(Z(",P,#`["GT*+G1O9V=L97%U;W1E
M('L*("`@(&1I<W!L87DZ(&YO;F4["GT*+G%U;W1E9#$L("YQ=6]T960R+"`N
M<75O=&5D,RP@+G%U;W1E9#0L("YQ=6]T960U('L*("`@(&-O;&]R.B`C,#`P
M.PH@("`@8F]R9&5R+6QE9G0M8V]L;W(Z(",P,#`["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+W!O<W1N=6ME+P``````````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P,3<U-#4`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O<&]S=&YU:V4O:6YF;RYP:'``````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<V`#$P-#$W,S8S,#$Q`#`R
M,3(Q,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<&]S=&YU:V4O
M:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-R!M9&IU:VEC($5X
M<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")0;W-T;G5K92(I.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+W!O<W1N=6ME+W-C<F5E;BYC<W,`````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,S4Q-P`Q,#0Q-S,V,S`Q,0`P,C$U-#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+RHJ"B`J("1(
M;W)D93H@:&]R9&4O=&AE;65S+W!O<W1N=6ME+W-C<F5E;BYC<W,L=B`Q+C@N
M-BXR(#(P,#4O,3`O,3@@,3$Z,S0Z,C`@:F%N($5X<"`D"B`J+PH*8F]D>2![
M"B`@("!B86-K9W)O=6YD.B`C8C%B-SAB.PH@("`@<V-R;VQL8F%R+6)A<V4M
M8V]L;W(Z(",V-C8V.3D["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z("-D
M9&1D9F8["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S8V
M-C8Y.3L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V1D9CL*?0IA('L*
M("`@(&-O;&]R.B`C,S,Y.PH@("`@9F]N="UF86UI;'DZ($=E;F5V82Q!<FEA
M;"Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3)P>#L*
M?0IA.FAO=F5R('L*("`@(&-O;&]R.B!B;'5E.PI]"F$N=VED9V5T('L*("`@
M(&-O;&]R.B`C,#`P.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T
M:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["GT*82YW:61G
M970Z:&]V97(@>PH@("`@8V]L;W(Z(&)L=64["B`@("!B86-K9W)O=6YD.B`C
M8C%B-SAB.PI]"BYH96%D97(@>PH@("`@8F%C:V=R;W5N9#H@(V(Q8C<X8CL*
M("`@(&9O;G0M<VEZ93H@,3=P>#L*?0HN;&EG:'0@>PH@("`@8V]L;W(Z('=H
M:71E.PH@("`@9F]N="UF86UI;'DZ($=E;F5V82Q!<FEA;"Q(96QV971I8V$L
M<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3)P>#L*?0HN<VUA;&QH96%D
M97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C8C%B-SAB
M.PI]"BYC;VYT<F]L('L*("`@(&-O;&]R.B!B;&%C:SL*("`@(&)A8VMG<F]U
M;F0Z("-D.61C8S(["GT*+FET96T@>PH@("`@8V]L;W(Z(&)L86-K.PH@("`@
M8F%C:V=R;W5N9#H@(V4Y93EE.3L*?0HN8G5T=&]N('L*("`@(&-O;&]R.B!W
M:&ET93L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`P,#`["B`@("!B;W)D
M97(M8F]T=&]M.B!T:&EN('-O;&ED("-",4(W.$(["B`@("!B;W)D97(M<FEG
M:'0Z('1H:6X@<V]L:60@(T(Q0C<X0CL*("`@(&)O<F1E<BUT;W`Z('1H:6X@
M<V]L:60@(SDY.3EC8SL*("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED(",Y
M.3DY8V,["B`@("!F;VYT+7-I>F4Z(#$Q<'@["B`@("!F;VYT+69A;6EL>3H@
M5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*?0HN<V5L96-T960@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V)B8V)F9CL*?0HN=&5X="!["B`@("!C
M;VQO<CH@8FQA8VL["B`@("!B86-K9W)O=6YD+6-O;&]R.B!W:&ET93L*?0HO
M*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A<F4@9&5P<F5C
M871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K9W)O=6YD+6-O
M;&]R.B`C9CEF.68Y.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C93EE.64Y.PI]"BYF:7AE9"!["B`@("!F;VYT+7-I>F4Z
M(#$S<'@["B`@("!F;VYT+69A;6EL>3H@;6]N;W-P86-E+"!F:7AE9#L*?0IT
M9"!["B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@("!F;VYT+69A;6EL>3H@1V5N
M979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"G1H('L*("`@(&9O
M;G0M<VEZ93H@,3)P>#L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL
M2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC
M;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-B,6(W
M.&(["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U
M<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(V)F8C<X8CL*?0H*+RH@4VED96)A
M<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(T(Q0C<X0CL*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]M;WII;&QA+P``````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`,#$W,S0T`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P
M,C$Q-#0`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL82]G
M<F%P:&EC<R]H96%D97(N<&YG````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#`P`#$P-#$W,S8S,#$Q`#`R,S`W,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````!P```!D(
M`@```'+LHV\````L=$58=$-R96%T:6]N(%1I;64`5'5E(#$V($IU;"`R,#`R
M(#(S.C0U.C$X("LQ,C`PQ8$840````=T24U%!]('$`LN"0^5PF(````)<$A9
M<P``#L,```[#`<=OJ&0````$9T%-00``L8\+_&$%````5TE$051XVF.<LF@M
M`P9@/'?]'J8HR_/G'S!%F1BP`18&5@9BU>(P@0.[N2Q811FPJ,;E,JPF<)+@
M,JPFX%*+S66DF$"Y*,NY\^<Q11F]?*.PB!Z[C"7F`1[0#7.]U&#P`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O;65N
M=2UA8W1I=F4N<&YG````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,R-P`Q,#0Q-S,V
M,S`Q,0`P,C0P-C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````$````P"`8```#0,Q"!````
M!'-"250("`@(?`ADB`````EP2%ES```*\```"O`!0JPTF````"%T15AT4V]F
M='=A<F4`36%C<F]M961I82!&:7)E=V]R:W,@-"XPZB8G=0```$Q)1$%4>)QM
MC[$1@#`0PRSMOPT#T+,4%)]\R$'C0N=8^1SG=9LD%<`(83#UAW5/WV_=>U3/
M*-,A1&IT,7O4KZ-9[;6M/LYD6=Z^:(\'9AX$"=E69]<`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]M;WII;&QA+V=R87!H:6-S+VUE;G4N<&YG````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,#<`,3`T,3<S-C,P,3$`,#(R-C$S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````!````,P@"````V<7U>`````=T24U%!]('$`H6
M`1<3G)P````)<$A9<P``"O````KP`4*L-)@````$9T%-00``L8\+_&$%````
M5DE$051XVE6,L0J`,!!#C_[_QSEV$'1S4!#$.6GOKD$[A"8ON=KYLCSW5<QL
M$N7)]/T-/C*1&40P0#W".\_LV\ZH?6Z^>X:H'O-_ZIS_L_:N=3]LJ5L#OTY=
MR0.?TKT`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O;6]Z:6QL82]I;F9O+G!H<```````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,3<T`#$P-#$W,S8S,#$Q`#`R,3`P-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!H;W)D92]T:&5M97,O;6]Z:6QL82]I;F9O+G!H<"QV(#$N,2`R
M,#`T+S$P+S$W(#$Y.C,S.C,W(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?
M;F%M92`](%\H(DUO>FEL;&$B*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O
M<V-R965N+F-S<P``````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,S$U-@`Q,#0Q-S,V,S`Q,0`P,C$S,S<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE
M;65S+VUO>FEL;&$O<V-R965N+F-S<RQV(#$N-RXV+C4@,C`P-2\Q,"\Q."`Q
M,3HS-#HR,"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z
M("-C-V0P9#D["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(SDT83)B-3L*
M?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C.31A,F(U.PI]
M"F$L(&$N9FEX960@>PH@("`@8V]L;W(Z(",S,SD["GT*82YW:61G970@>PH@
M("`@8V]L;W(Z(",P,#`["GT*+FAE861E<B!["B`@("!B86-K9W)O=6YD.B`C
M8S=D,&0Y('5R;"@B9W)A<&AI8W,O:&5A9&5R+G!N9R(I(')E<&5A="UX.PH@
M("`@=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0IA+FAE861E<B!["B`@("!B86-K
M9W)O=6YD+6EM86=E.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A
M;G-P87)E;G0["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C-$4U1#<R.PI]"BYS
M;6%L;&AE861E<B!["B`@("!C;VQO<CH@8FQA8VL["B`@("!B86-K9W)O=6YD
M+6EM86=E.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A;G-P87)E
M;G0["GT*+G-M86QL:&5A9&5R(&$@>PH@("`@8V]L;W(Z(&)L86-K.PI]"BYC
M;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z("-A96)A8V$["GT*+FET96T@>PH@
M("`@8F%C:V=R;W5N9#H@(V5C969F-#L*?0HN8G5T=&]N('L*("`@(&-O;&]R
M.B!B;&%C:SL*("`@(&)A8VMG<F]U;F0Z("-A9&(V8S8["B`@("!B;W)D97(Z
M(#%P>"!S;VQI9"`C,#`P.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@[
M"GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0Z("-C-F0S9F8["GT*"B\J
M($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!B86-K9W)O=6YD.B`C8S=D
M,&0Y('5R;"@B9W)A<&AI8W,O;65N=2YP;F<B*2!R97!E870M>#L*?0HC;65N
M=2!H,2!["B`@("!C;VQO<CH@8FQA8VL["GT*(VUE;G4@82!["B`@("!C;VQO
M<CH@8FQA8VL["B`@("!B;W)D97(Z(&YO;F4["B`@("`M;6]Z+6)O<F1E<BUR
M861I=7,Z(#`["GT*(VUE;G4@83IH;W9E<B!["B`@("!B;W)D97(Z(#%P>"!S
M;VQI9"`C865B86-A.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$N8W5R
M<F5N="!["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+VUE;G4M86-T
M:79E+G!N9R(I(')E<&5A="UX.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V%E
M8F%C83L*("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!A+F-U<G)E;G0Z:&]V
M97(@>PH@("`@<&%D9&EN9SH@,G!X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@
M*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD.B`C8S=D,&0Y.PI]
M"@HO*B!486(@<W1Y;&5S+B`J+PHN=&%B<V5T('L*("`@(&)A8VMG<F]U;F0Z
M(&YO;F4["GT*+G1A8G-E="!L:2!A('L*("`@(&)O<F1E<CH@,7!X('-O;&ED
M("-A8F%B86(["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V4Y93EE
M.3L*?0HN=&%B<V5T(&QI(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#`["GT*
M+G1A8G-E="!L:2YA8W1I=F5486(@82P@+G1A8G-E="!L:2YA8W1I=F5486(@
M83IH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-A
M96)A8V$["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V%E8F%C83L*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M;V)I;&4O````````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C,P,3$`,#$W,30T`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+VUO8FEL92]S8W)E96XN8W-S````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3,V,P`Q,#0Q-S,V,S`Q,0`P,C$Q,S4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+VUO8FEL92]S8W)E96XN8W-S+'8@,2XQ+C$P+C$@
M,C`P-2\Q,"\Q."`Q,3HS-#HR,"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@
M(&)A8VMG<F]U;F0Z("-F9F8["B`@("!F;VYT+69A;6EL>3H@0V]U<FEE<CL*
M("`@(&9O;G0M<VEZ93H@,3!P>#L*?0IT9"!["B`@("!F;VYT+69A;6EL>3H@
M0V]U<FEE<CL*("`@(&9O;G0M<VEZ93H@,3!P>#L*?0ID:78N<VEM9&5V('L*
M("`@('=I9'1H.B`Q-3`["B`@("!H96EG:'0Z(#$R,#L*("`@(&]V97)F;&]W
M.B!A=71O.PI]"G1D+G1O<"!["B`@("!W:61T:#H@,C8S.PH@("`@:&5I9VAT
M.B`Q,3<["B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH9W)A<&AI8W,O=&]P
M+FIP9RD["GT*=&0N;&5F="!["B`@("!W:61T:#H@-38["B`@("!H96EG:'0Z
M(#$R,#L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]L969T
M+FIP9RD["GT*=&0N9&ES<&QA>2!["B`@("!W:61T:#H@,34P.PH@("`@:&5I
M9VAT.B`Q,C`["B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH9W)A<&AI8W,O
M9&ES<&QA>2YJ<&<I.PI]"G1D+G)I9VAT('L*("`@('=I9'1H.B`U-SL*("`@
M(&AE:6=H=#H@,3(P.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H
M:6-S+W)I9VAT+FIP9RD["GT*=&0N8F]T=&]M('L*("`@('=I9'1H.B`R-C,[
M"B`@("!H96EG:'0Z(#,Q,SL*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG
M<F%P:&EC<R]B;W1T;VTN:G!G*3L*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+VQU8V)L=64O````````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P,3<S,S``(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C8FQU92]I;F9O+G!H<```
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C`P`#$P-#$W
M,S8S,#$Q`#`R,#<V,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O
M;'5C8FQU92]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,V(&UD
M:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(DQO>6]L82!";'5E
M(BD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VQU8V)L=64O<V-R965N+F-S<P``````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3,Q,P`Q,#0Q-S,V,S`Q,0`P,C$S
M,C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VQU8V)L=64O<V-R965N+F-S
M<RQV(#$N,3`N-BXT(#(P,#4O,3`O,3@@,3$Z,S0Z,C`@:F%N($5X<"`D"B`J
M+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@9F]N="UF86UI
M;'DZ(%9E<F1A;F$L($=E;F5V82P@07)I86PL($AE;'9E=&EC82P@<V%N<RUS
M97)I9CL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C0S1#-$(X.PH@("`@
M<V-R;VQL8F%R+6AI9VAL:6=H="UC;VQO<CH@(V4V939$0SL*("`@('-C<F]L
M;&)A<BUA<G)O=RUC;VQO<CH@(S`P,#L*?0IH=&UL('L*("`@('-C<F]L;&)A
M<BUB87-E+6-O;&]R.B`C0S1#-$(X.PH@("`@<V-R;VQL8F%R+6AI9VAL:6=H
M="UC;VQO<CH@(V4V939$0SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@
M(S`P,#L*?0IA('L*("`@(&-O;&]R.B`C,#-#.PI]"F$L(&$N9FEX960@>PH@
M("`@8V]L;W(Z(",S,SD["GT*82YW:61G970@>PH@("`@8V]L;W(Z(",P,#`[
M"GT*:6YP=70@>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@
M07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@(&)A8VMG<F]U;F0Z
M("-F-V8W964["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-C8V.PI]"G1E>'1A
M<F5A('L*("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@(V8W9C=E
M93L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-C8["GT*<V5L96-T+&]P=&EO
M;B!["B`@("!C;VQO<CH@(S,S,S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F-V8W
M964["GT*+FAE861E<B!["B`@("!C;VQO<CH@(S`S8SL*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C,#-C.PI]"BYH96%D97)B;W@@>PH@("`@8F]R
M9&5R+6-O;&]R.B`C,#-C.PI]"BYH96%D97)B;W@@+FAE861E<B!["B`@("!M
M87)G:6XM;&5F=#H@+3%P>#L*("`@(&UA<F=I;BUR:6=H=#H@+3%P>#L*("`@
M(&)O<F1E<BUL969T.B!N;VYE.PH@("`@8F]R9&5R+7)I9VAT.B!N;VYE.PI]
M"F$N:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C,#9F.PI]"F$N<VUA;&QH
M96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z(",P-F8["GT*82YH96%D97(@>PH@
M("`@8F]R9&5R+6)O='1O;3H@;F]N93L*("`@(&)A8VMG<F]U;F0Z('1R86YS
M<&%R96YT.PI]"BYL:6=H="!["B`@("!C;VQO<CH@(S,S,SL*?0HN<VUA;&QH
M96%D97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B!T<F%N
M<W!A<F5N=#L*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*
M("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@(&9O;G0M=V5I9VAT.B!N;W)M86P[
M"GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@(T0X1#A#,3L*?0HN:71E
M;2!["B`@("!B86-K9W)O=6YD.B`C965E964V.PI]"B\J($%L=&5R;F%T:6YG
M('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN<F]W
M179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U;F0Z("-F.68Y9CD["GT*+G)O
M=T]D9"P@+FET96TQ('L*("`@(&)A8VMG<F]U;F0Z("-E.64Y93D["GT*+F)U
M='1O;B!["B`@("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F.68Y
M9C@["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O
M<F1E<BUR:6=H=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M;&5F=#H@
M,7!X('-O;&ED("-#-$,T0C@["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@
M(T,T0S1".#L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]"BYS96QE
M8W1E9"!["B`@("!B86-K9W)O=6YD.B`C0S9$,V9F.PI]"BYI;E!R;V=R97-S
M('L*("`@(&)A8VMG<F]U;F0Z(",P,#,S8V,["GT*"B\J($UE;G4@<W1Y;&5S
M+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z
M("-E-F4V9&,["B`@("!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(S@P.#`W
M03L*?0HC;65N=2!H,2!["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A('L*
M("`@(&-O;&]R.B`C,#`P.PH@("`@8F]R9&5R.B!N;VYE.PI]"B-M96YU(&$N
M8W5R<F5N="!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C
M,&,P8C@["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V5E93L*("`@
M(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-E964["B`@("!B;W)D97(M;&5F
M=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@
M(S`P,#L*("`@('!A9&1I;F<Z(#)P>#L*("`@("UM;WHM8F]R9&5R+7)A9&EU
M<SH@-7!X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*8F]D>2YS:61E8F%R
M('L*("`@(&)A8VMG<F]U;F0Z("-F.68Y9C,["GT*(W-I9&5B87)086YE;"![
M"B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C.#`X,#=A.PH@("`@8F]R
M9&5R+6)O='1O;3H@,7!X('-O;&ED(",X,#@P-V$["B`@("!B86-K9W)O=6YD
M.B`C939E-F1C.PI]"B-S:61E8F%R4&%N96P@82!["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C939E-F1C.PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P
M861D:6YG+6)O='1O;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B![
M"B`@("!B86-K9W)O=6YD.B`C939E-F1C.PH@("`@8F]R9&5R.B`Q<'@@<V]L
M:60@(S`S8SL*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*("`@("UM;WHM
M8F]R9&5R+7)A9&EU<SH@,W!X.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R
M9VEN+7)I9VAT.B`Q<'@["GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M87IU<B\`````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$Q`#`Q-C8U-@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]A>G5R+VEN9F\N<&AP````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R-3``,3`T,3<S-C,P,3$`,#(P
M,S$T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]A>G5R+VEN9F\N
M<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S,@;61J=6MI8R!%>'`@)"`_
M/@H@*@H@*B!`875T:&]R($IO;W-T($1E($-O8VL@/&IO;W-T0&1E8V]C:RYO
M<F<^"B`J+PH*)'1H96UE7VYA;64@/2!?*")!>G5R(BD["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O87IU<B]S8W)E96XN8W-S````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-#<W`#$P-#$W,S8S,#$Q`#`R,#8U-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*BH*("H@075T
M:&]R.B!*;V]S="!$92!#;V-K(#QJ;V]S=$!D96-O8VLN;W)G/@H@*@H@*B`D
M2&]R9&4Z(&AO<F1E+W1H96UE<R]A>G5R+W-C<F5E;BYC<W,L=B`Q+C4N-BXU
M(#(P,#4O,3$O,34@,#8Z-#$Z,#(@<V5L<VMY($5X<"`D"B`J+PH*8F]D>2![
M"B`@("!B86-K9W)O=6YD.B`C-C1A-V,Y.PI]"F$@>PH@("`@8V]L;W(Z(",S
M,SD["GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z(",V-C8["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C9F9F.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B86-K9W)O=6YD.B`C,#8Y.PI]"BYH96%D97(@82!["B`@
M("!C;VQO<CH@(V9F9CL*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-F
M9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,#8Y.PI]"F$N<VUA;&QH96%D
M97(@>PH@("`@8V]L;W(Z("-F9F8["GT*+F)U='1O;B!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C,#8Y.PH@("`@8V]L;W(Z("-F9F8["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X
M('-O;&ED(",R,C0["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(SDY8SL*
M("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(SDY8SL*?0H*+RH@365N=2!S
M='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R
M;W5N9"UC;VQO<CH@(S`V.3L*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C9F9F
M.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C-C1A-V,Y
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-E964["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+6QE9G0Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`[
M"B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@83IH;W9E<B!["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED("-E964["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P
M,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I
M;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N
M96P@>PH@("`@8F]R9&5R+6-O;&]R.B!T<F%N<W!A<F5N=#L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-B8V0V93(["GT*"B\J(%1A8B!S='EL97,N("HO"BYT
M86)S970@;&DN86-T:79E5&%B(&$L("YT86)S970@;&DN86-T:79E5&%B(&$Z
M:&]V97(@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P-CD["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C,#8Y.PI]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B87)B:64O````````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T
M,3<S-C,P,3$`,#$W,3(Q`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V)A<F)I92]I;F9O+G!H<```````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#$W-0`Q,#0Q-S,V,S`Q,0`P,C`U-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O=&AE;65S+V)A<F)I92]I;F9O+G!H<"QV(#$N,2`R,#`T
M+S$P+S$W(#$Y.C,S.C,S(&UD:G5K:6,@17AP("0@/SX*("HO"@HD=&AE;65?
M;F%M92`](%\H(D)A<F)I92(I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B87)B:64O<V-R
M965N+F-S<P``````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W
M-S$`,3`T,3<S-C,P,3$`,#(Q,3$U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE
M<R]B87)B:64O<V-R965N+F-S<RQV(#$N-2XV+C(@,C`P-2\Q,"\Q."`Q,3HS
M-#HQ,2!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F
M96(V8S(["GT*82!["B`@("!C;VQO<CH@(S0T.&8Y.3L*?0H*+FAE861E<B![
M"B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-F9CAE834["GT*
M+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9#H@(V9F.&5A-3L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C9F-C,F0P.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C9C0V,3=F.PH@("`@8F]R9&5R+6)O='1O;3H@
M=&AI;B!S;VQI9"`C9C0V,3=F.PH@("`@8F]R9&5R+7)I9VAT.B!T:&EN('-O
M;&ED("-F-#8Q-V8["B`@("!B;W)D97(M=&]P.B!T:&EN('-O;&ED("-F9C@Y
M83$["B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C9F8X.6$Q.PI]"BYT
M97AT('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F4U96,["GT*"B\J($UE
M;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A
M8VMG<F]U;F0Z("-F9CDQ83<["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A
M8VMG<F]U;F0Z("-F-#8Q-V8["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(V%A8SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-A86,["B`@
M("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M=&]P
M.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#)P>#L*?0H*+RH@4VED
M96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I
M9VAT.B`Q<'@@<V]L:60@(V9E8C9C,CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P
M>"!S;VQI9"`C9F5B-F,R.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F.&5A
M-3L*?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@,7!X.PI]
M"@`````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B;'5E
M;6]O;B\`````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,3$`,#$W-3$U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V)L=65M;V]N+VEN9F\N<&AP````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$W-P`Q,#0Q-S,V,S`Q,0`P,C$Q-C,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V)L=65M;V]N+VEN9F\N
M<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S0@;61J=6MI8R!%>'`@)`H@
M*B\*"B1T:&5M95]N86UE(#T@7R@B0FQU92!-;V]N(BD["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]B;'5E;6]O;B]S8W)E96XN8W-S````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#8T,3(`,3`T,3<S-C,P,3$`,#(Q-3`V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W1H96UE<R]B;'5E;6]O;B]S8W)E96XN8W-S+'8@,2XQ,RXV+C,@
M,C`P-2\Q,"\Q."`Q,3HS-#HQ,2!J86X@17AP("0*("HO"@IB;V1Y('L*("`@
M(&9O;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@(&)A8VMG<F]U
M;F0Z(",P,#,X.3,["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S`P,S@Y
M,SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S`Q-CAD8CL*?0IH=&UL
M('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C,#`S.#DS.PH@("`@<V-R
M;VQL8F%R+6%R<F]W+6-O;&]R.B`C,#$V.&1B.PI]"FEN<'5T('L*("`@(&9O
M;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*?0IS96QE8W0@>PH@("`@
M9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ697)D86YA.PH@("`@9F]N="UW96EG
M:'0Z(&YO<FUA;#L*?0IT9"!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS
M+%9E<F1A;F$["GT*=&@@>PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ6
M97)D86YA.PI]"FEM9R!["B`@("!B;W)D97(Z(&YO;F4["GT*82!["B`@("!F
M;VYT+69A;6EL>3H@3'5X:2!386YS+%9E<F1A;F$["B`@("!C;VQO<CH@(S`P
M,T-F9CL*?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C,#`S.#DS.PI]"F$N=VED
M9V5T('L*("`@(&-O;&]R.B`C,#`S0V9F.PH@("`@9F]N="US:7IE.B`P+CEE
M;3L*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S`P,S@Y,SL*("`@
M(&)A8VMG<F]U;F0Z(",P,38X9&(["GT*+FAE861E<B!["B`@("!C;VQO<CH@
M(S(W,#`T,CL*("`@(&)A8VMG<F]U;F0Z(",P,38X9&(["B`@("!F;VYT+69A
M;6EL>3H@3'5X:2!386YS+%9E<F1A;F$["B`@("!F;VYT+7-I>F4Z(#$V<'@[
M"GT*+FAE861E<B!A('L*("`@(&-O;&]R.B`C,C<P,#0R.PI]"G1D+FAE861E
M<B!["B`@("!P861D:6YG+6QE9G0Z(#-P>#L*("`@('!A9&1I;F<M<FEG:'0Z
M(#-P>#L*?0IA+FAE861E<B!["B`@("!C;VQO<CH@(S`P83AF9CL*?0HN;&EG
M:'0@>PH@("`@8V]L;W(Z("-F9F8["B`@("!F;VYT+69A;6EL>3H@3'5X:2!3
M86YS+%9E<F1A;F$["GT*82YL:6=H=#IH;W9E<B!["B`@("!C;VQO<CH@(T9&
M0S@P,#L*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",R-S`P-#(["B`@
M("!B86-K9W)O=6YD.B`C,#$V.&1B.PH@("`@9F]N="UF86UI;'DZ($QU>&D@
M4V%N<RQ697)D86YA.PH@("`@9F]N="US:7IE.B`Q-'!X.PI]"F$N<VUA;&QH
M96%D97(@>PH@("`@8V]L;W(Z(",P,&$X9F8["GT*+G-M86QL('L*("`@(&9O
M;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@(&9O;G0M<VEZ93H@
M,"XX96T["GT*+F-O;G1R;VP@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9#%D,60Q.PI]"BYI=&5M('L*("`@(&-O;&]R.B`C
M,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V4Y93EE.3L*?0HN8G5T=&]N
M('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S)B
M-S-D-3L*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@(SDY8SL*("`@
M(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C.3EC.PH@("`@8F]R9&5R+71O
M<#H@=&AI;B!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6QE9G0Z('1H:6X@<V]L
M:60@(S`P,#L*("`@(&9O;G0M<VEZ93H@,3)P>#L*("`@(&9O;G0M9F%M:6QY
M.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@
M-7!X.PI]"BYB=71T;VXZ:&]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(S$Q-C5F9CL*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(V)B8V)F9CL*?0HN9FEX960@>PH@("`@9F]N="US:7IE.B`Q,W!X.PH@("`@
M9F]N="UF86UI;'DZ($UO;F%C;RQ#;W5R:65R+&UO;F]S<&%C960L9FEX960[
M"GT*+G-E;&5C=&5D+6]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-C
M965F9CL*?0HN=&]O;'1I<"!["B`@("!F;VYT+7-I>F4Z(#$P<'@["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C9F9C.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@
M(S`P,#L*("`@('!A9&1I;F<Z(#)P>#L*?0HN86-C97-S2V5Y('L*("`@('1E
M>'0M9&5C;W)A=&EO;CH@=6YD97)L:6YE.PI]"F$N:&5A9&5R.FAO=F5R('L*
M("`@(&-O;&]R.B`["GT*82YC=7)R96YT5&%B.FAO=F5R('L*("`@(&-O;&]R
M.B`["GT*+FYO=&EC92!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9C.PI]
M"BYS:6=N871U<F4@>PH@("`@8V]L;W(Z(",V,#8P-C`["GT*+G-I9VYA='5R
M92UF:7AE9"!["B`@("!C;VQO<CH@(S8P-C`V,#L*("`@(&9O;G0M<VEZ93H@
M,3!P>#L*("`@(&9O;G0M9F%M:6QY.B!-;VYA8V\L0V]U<FEE<BQM;VYO<W!A
M8V5D+&9I>&5D.PI]"@HO*B!486)L92!S='EL97,N("HO"BYL:6YE9%)O=R![
M"B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8[
M"B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V1D9#L*?0HN;&EN9612
M;W=396QE8W1E9$-O;"!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F,V8S9C,["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(V1D9#L*?0HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M
M,2!A<F4@9&5P<F5C871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"!["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C9C-F,V8S.PI]"BYR;W=/9&0L("YI=&5M,2![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C93EE.64Y.PI]"@HO*B!-96YU('-T
M>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C,#$V.&1B.PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N
M<RQ697)D86YA.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(VUE
M;G4@82YC=7)R96YT('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9#H@(S`Q-CAB8CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C.3EC
M.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(SDY8SL*("`@(&)O<F1E
M<BUT;W`Z(#%P>"!S;VQI9"`C,#(S,#8T.PH@("`@8F]R9&5R+6QE9G0Z(#%P
M>"!S;VQI9"`C,#(S,#8T.PH@("`@<&%D9&EN9SH@,G!X.PH@("`@+6UO>BUB
M;W)D97(M<F%D:75S.B`U<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC
M<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,38X9&([
M"GT*(W-I9&5B87)086YE;"!S<&%N+"`C<VED96)A<E!A;F5L(&$@>PH@("`@
M9F]N="UW96EG:'0Z(&)O;&0["B`@("!C;VQO<CH@(V9F9CL*?0HC<VED96)A
M<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F,X,#`["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O8FQU97=H:71E+P``````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$Q`#`Q-S8V-0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]B;'5E=VAI=&4O:6YF;RYP:'``````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,#4`,3`T,3<S-C,P,3$`
M,#(Q,S(S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]B;'5E=VAI
M=&4O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-"!M9&IU:VEC
M($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")";'5E(&%N9"!7:&ET92(I
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O8FQU97=H:71E+W-C<F5E;BYC<W,`````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`U-3(W`#$P-#$W,S8S,#$Q`#`R,38V-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O*BH*("H@
M)$AO<F1E.B!H;W)D92]T:&5M97,O8FQU97=H:71E+W-C<F5E;BYC<W,L=B`Q
M+C$X+C8N.2`R,#`U+S$Q+S`R(#$Y.C,R.C,X(&IA;B!%>'`@)`H@*B\*"F)O
M9'D@>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@07)I86PL
M($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@(&)A8VMG<F]U;F0Z("-F9F8[
M"GT*82!["B`@("!C;VQO<CH@(S,S.3L*?0HN:&5A9&5R8F]X('L*("`@(&)O
M<F1E<BUC;VQO<CH@(S8V83L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N
M9#H@(T,V1#-&1CL*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9#H@(S8V83L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C,#`P.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V9F9CL*?0HN:&5A
M9&5R(&$Z:&]V97(L(&$N:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B!Y96QL
M;W<["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*82YH96%D97(@>PH@
M("`@8F]R9&5R+6)O='1O;3H@,#L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R
M96YT.PI]"F$N9FEX960@>PH@("`@8V]L;W(Z(",S,SD["GT*+FQI9VAT('L*
M("`@(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@
M(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",V-F$["B`@("!F;VYT+69A;6EL>3H@
M5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*?0IA+G-M86QL:&5A9&5R
M.FAO=F5R('L*("`@(&-O;&]R.B`C8V-E.PH@("`@=&5X="UD96-O<F%T:6]N
M.B!N;VYE.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z("-D9&0["GT*
M+G=I9&=E="!["B`@("!C;VQO<CH@(S(R-#L*?0H*+RH@1F]R;2!S='EL97,N
M("HO"FEN<'5T+"!S96QE8W0L('1E>'1A<F5A('L*("`@(&9O;G0M9F%M:6QY
M.B!'96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68["B`@("!F
M;VYT+7-I>F4Z(#$R<'@["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U
M;F0Z("-F,V8S9CD["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-C8Y.PI]"FEN
M<'5T.F9O8W5S+"!T97AT87)E83IF;V-U<R!["B`@("!B86-K9W)O=6YD.B`C
M9F9F.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(SDY9CL*?0HN8G5T=&]N+"`N
M8G5T=&]N.F9O8W5S('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9#H@(S,S.3L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,S,S.PH@
M("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUL
M969T.B`Q<'@@<V]L:60@(T,T0S1".#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S
M;VQI9"`C0S1#-$(X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["GT*
M+F)U='1O;CIH;W9E<B!["B`@("!B86-K9W)O=6YD.B`C-C9A.PI]"@HO*B!!
M;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A<F4@9&5P<F5C871E
M9"X@*B\*+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K9W)O=6YD.B`C965E
M.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]
M"@HO*B!687)I;W5S('!O<'5P(&%N9"!S=&%T=7,@;&%Y97)S+B`J+PHN=&]O
M;'1I<"P@9&EV+FYI8V5T:71L92!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A
M8VMG<F]U;F0Z(",V-F$["B`@("!B;W)D97(Z(#)P>"!D;W5B;&4@(V9F9CL*
M?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F%C:V=R;W5N9#H@(S8V83L*("`@(&)O<F1E<BUB;W1T;VTZ(#)P
M>"!S;VQI9"`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*
M(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z(",S,SD["B`@("!B
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V%A8SL*("`@(&)O<F1E<BUR:6=H
M=#H@,7!X('-O;&ED("-A86,["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED
M(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A
M9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"F)O9'DN<VED
M96)A<B!["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"B-S:61E8F%R4&%N96P@
M>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P-CL*("`@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`V.PH@("`@8F%C:V=R;W5N9#H@(V4Y
M93EF9CL*?0HC<VED96)A<E!A;F5L('-P86XN=&]G9VQE+"`C<VED96)A<E!A
M;F5L(&$@>PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P861D:6YG+6)O
M='1O;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@<W!A;BYT;V=G;&4@>PH@("`@
M8F]R9&5R.B`Q<'@@;F]N92!T<F%N<W!A<F5N=#L*?0HC<VED96)A<E!A;F5L
M(&$@>PH@("`@8V]L;W(Z(",P,#8["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M93EE.69F.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!C;VQO<CH@
M(S`P-CL*("`@(&)A8VMG<F]U;F0Z("-C8V,["B`@("!B;W)D97(Z(#%P>"!S
M;VQI9"`C,#`P.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"B-E>'!A
M;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`Q<'@["GT*"B\J(%1A8B!S
M='EL97,N("HO"BYT86)S970@>PH@("`@8F%C:V=R;W5N9#H@;F]N93L*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C-C9A.PI]"BYT86)S970@;&D@
M82!["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-C9A.PH@("`@8F]R9&5R+6)O
M='1O;2UC;VQO<CH@(V4Y93EE.3L*?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A
M('L*("`@(&)A8VMG<F]U;F0Z(",V-F$["B`@("!C;VQO<CH@(V9F9CL*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C-C9A.PI]"BYT86)S970@;&DN
M86-T:79E5&%B(&$Z:&]V97(@>PH@("`@8F%C:V=R;W5N9#H@(S8V83L*("`@
M(&-O;&]R.B`C9F9F.PI]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,O````
M````````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`T,3<S-C,P,3$`,#$V-#8P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+VQU8R]G<F%P:&EC<R\`````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,0`P,C`R-C``(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C+V=R87!H:6-S+V-U<G)E
M;G1486)?;&5F="YG:68`````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3,W`#$P-#$W
M,S8S,#$Q`#`R-#`W-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$)`)8`Q```____=V95_O[^_?W\^OKX^?GW_?W]
M_/SZ^?CV^/?U]?3O]O7Q]/+M\O'K]O7P]_;RN[.JW=G5Z>;C]?3S@7%AF(M_
MX=W9F(M^NK&GDX5XX=[9Q\"X\O'JKJ2:DX5WQK^X(?D$```````L``````D`
ME@``!=P@(&I8106!^&50-(G`UDFP:'ET#6"0+EX1'X#R\J6$1X!@N0PP#8:!
M-!`='`B$0B$@O2(2B4<`6T`\'`K&N)Q`-QKKKX/1X(RSB45:?2T_]`H!!WU?
M"PM<5ED(7U115UE;4%6#!TY+DE,B3$Q).ITUGS"A(J,`I:="IJFH2*NNK;!&
MK[*QGK.VM:"WNKFBN[Z]I+_"P:K%K+3)N,J\S,#.Q-#&TLC+ULW7S]G1V]/=
MU=CAVN+<Y-[FX./JY>OG[>GL\>[R\//V]?C#]_KYQ_S__@)2`SA0X#>"W4(`
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]C=7)R96YT5&%B7W)I9VAT
M+F=I9@`````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0Q,P`Q,#0Q-S,V,S`Q,0`P,C0R
M-3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EAD`&6`,0``/____[^_OW]_/3R[?GY]_+QZG=F5?+QZ_KZ^/?V\O;U
M\?CW]=C2R*^DEY&#=.7AU>CFVN_MYOGX]NKHWNWJXO7T[^?CV/;U\/W]_?'P
MZ?S\^O#NY^OIW\"XKH!P7\O#MB'Y!```````+`````"0`98```7_H"&.9&F>
M:*JN;.N^<"S/=&W?>*[OK^<T#X!P2"P:C\BD<LEL.I_0J'1*K5JOV*QV^PP(
M)!1&P]$)<,_HM'K-;KO?<*Y74HE`Q)VX?L_O^_^`@41S=1P0'PX,@HN,C8Z/
MD&N$$880#0V1F9J;G)U_DX86B)ZDI::GJ$F@$'<>J:^PL;*?7X40%A8&`;N\
MO;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4Q1@:$@.4$`\/!@+@X>+CY.7FY^CI
MZNOL[>[O\/'R\_3U]O?X^>H:!`G:$]R\$1A(L*#!@P@3*ES(L*'#AQ`C2IQ(
ML:+%BQ@S:MS(T>&""P4HW.IF((')DRA3_ZI<R;*ERY<P8\J<2;.FS9LX<^K<
MR;.GSY\P%5PXL,%0-V\#DBI=RK2ITZ=0HTJ=2K6JU:M8LVK=RK6KUZ]@PXJ=
M>H`H!8!'#118R[:MV[=PX\J=2[>NW;MX\^K=R[>OW[^``PL>3-ANA@AG`WHK
MS+BQX\>0(TN>3+DRX0P;$(?"9:"LY\^@0XL>3;JTZ=.H4ZM>S;JUZ]>P8\N>
M3;NV[=0%#E.H!,'`V-_`@PL?3KRX\>/(?Q_036&W`070HTN?3KVZ]>O8LVO?
MSKV[]^_@PXL?3[Z\^?/HTVN_<*'"@-R9(QA80+^^_?OX\^O?S[^___\`!BC@
M@`06:."!"":HX/^"##;XGTGM#>"9`1U5:.&%&&:HX88<=NAAA1(LD`!T[!F`
MP(DHIJCBBBRVZ.*+,,8HXXPTUFCCC3CFJ...//;HXX]`TCB0!$1*\(T^2":I
MY)),-NGDDU!&B:0&5**H2S589JGEEEQVZ>678(:))09DEFG`+&BFJ>::9YS)
MYIMPQBGG$&[.:>>=>)929YY\]NDG('O^*>B@A+99Z*&()AI%H(HVZFBBC#XJ
MZ:1\1DKII9BR:6FFG'::RJ:>ABJJ)J".:NJI@92*ZJJLOJ%JJ[#&NL6KLM9J
MZZ*WYJIK%;3NZNNNO?XJ;*W!#FLLJ\4>J^RHR2[K+*?-/BOMI-%.:ZW_HM5>
MJRVAV6[K;9_=?BNNG>&.:^Z;Y9ZK+IKIKNON*^V^*Z^>\]:;9[SVY@L)OOKV
MNPB__@;L!\`"%QP'P08GS`;""C=LJ,,0DQKQQ/M2;#$C#%^L,1,9;^SQ$1U_
M++(0(8_\<<DF;XQRRA>OS#+%+K\<<<PR.TQSS0K?C+/!.N\L<,\^^PMTT/H.
M3;2]1A\];])*O\MTT^L^#?6Y4D\];M56?XMUUMMNS?6U7G\];=AB/TMVV<N>
MC?:Q:J\];-MN_PIWW,#2O?/<=M^*=][$\BWSWG[#"GC@R!*>\N"&GXIXXLPR
M+O+BCGL*>>304JZRY1I/CCFEFF\N:>>>.PIZB.C8DCZSZ1"/CGJAJJ\^:.NN
M_PE[[.#2SK/M!<^.^YVZ[SYG[[['"7SPZ!)?M/'Y#H]\FLHO/TOSSL<"??3P
M4N^T]>Y.C[TIVF]/2O?>=P)^^)N,3WXFYI]?L?K>IL]^(^Z__Z_\VL9//Z#W
M6VM__GWLS_\>_OO?P03HK``2T`T&/.#"%,BV$```.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C+V=R
M87!H:6-S+W1A8E]B;W1T;VTN9VEF````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,C`Q`#$P-#$W,S8S,#$Q`#`R,S`V-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$4``$`A"``W>/5V^'3_O[^
M\O3NYNG@VN#2_/S\]??R^?GWZNWDX.36Y>C>[O'J[?#I[_+KXN7:^/CV]_?U
M\_7PZ>SC^OKX^_O[Z^[G=V95X^;;Y.?=_?W][._HX>39\?/NX./8Z.OB+```
M```4``$```4&X"6.9%F&`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]T86)?
M;&5F="YG:68`````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4V-``Q,#0Q
M-S,V,S`Q,0`P,C(U,S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA"0"6`,0``+>NB._MY>#<S.SJX/'OZ>?DV-?2
MO-70NMO6Q/W]_?3S[>CEV_;U\OCW]/'OZ.OHWMS8QNWKXMG5P?#NY^[LX_KY
M]^/?T-C3O\6^G\?`H]_;R[RTD.[LY.7BU.SIX-/.MR'Y!```````+``````)
M`)8```7Q8"(^1K8!@`AAB->("?0Y<%4]&&TW#'-(.X9BF%E4>`J"8[)1()4<
M"H`G)`0HD6E/,:$,/("M-?)XA*ODQ2*<##P*'0M@.!D4+`+-W,%Y=#00$@`$
M$Q$+%H$7@P$#"P(0%P:+=@((!I)6E):8C`65EY.>FZ&?G)J@F:*HG:6DHZFM
ML*^LLZ>FJK>QM*NVKKRXOKFUP+*_NKW%PL;#Q\2[RM#!TLG3S]7(UM3:V=S8
MWL[?S>+,Y,OFT=OAY>C=X.[CY]?OZ_+P[.KQZ?/Y[?;U]/K\!038CR"^>_L0
M"BS([^"_A@D?*C08<2#$A0XM3KP4`@`[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]L=6,O9W)A<&AI8W,O=&%B7W)I9VAT+F=I9@``
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V-#8`,3`T,3<S-C,P,3$`,#(R
M-S$W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y89`!E@#$``#5T+JWKHC2S+79U,'BWM#IYMO]_?S>VLG6T;O7TKWS
M\NSKZ-[LZN#W]O/P[N?N[./GY-CZ^OC)PJ;4S[C-QZW0RK++Q*G`N)?EXM3<
MV,;8T[_/R;#.R*[*PZ?\_/OO[>4A^00``````"P`````D`&6```%_V`@CF1I
MGFBJKFSKOG`LSW1MWWBN[[`D0(:@<$@L&H_(I'+);#J?T*AT2JU:K]BL]NF)
M*`B""R`8*9O/Z+1ZS6Z[W_"X?$ZOV^_XO'[/[_OC#0H."P<2"`8-B8J+C(V.
MCY"1DI.4E9:7F)F:FYR=GI^@H:*5"@H,$`0#%QBEK:ZOL+&RL[2UMK>XN;J[
MO+V^O\#!PL/$Q;D.#PL8!QD=%`[0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?H
MZ=L?R:C,80_Q\O/T]?;W^/GZ^_S]_O\``PH<2+"@P8,($RKLMZ#`L@P#$`1@
M0+&BQ8L8,VK<R+&CQX\@0XH<2;*DR9,H4_^J7,FRY<<%"R`\'*`A`,R;.'/J
MW,FSI\^?0(,*'4JTJ-&C2),J7<JTJ=.G0PNXRZ`A08`"6+-JW<JUJ]>O8,.*
M'4NVK-FS:-.J7<NVK=NW<..2E4D`8@*)$/+JW<NWK]^_@`,+'DRXL.'#B!,K
M7LRXL>/'D"-++HR!`+.[$P(0V,RYL^?/H$.+'DVZM.G3J%.K7LVZM>O7L&/+
MGDT;-3,-``0("'"@M^_?P(,+'TZ\N/'CR),K7\Z\N?/GT*-+GTZ]NG7D&2!J
MF%"APH8``\*+'T^^O/GSZ-.K7\^^O?OW\./+GT^_OOW[^//K;Z\!`7<.%%`0
M0`($%FC@@0@FJ.#_@@PVZ."#$$8HX8045FCAA1AFJ.&&'';X(`+^";`!!19T
M$`"(**:HXHHLMNCBBS#&*..,--9HXXTXYJCCCCSVZ../0,X(P`0"5`!@!R8"
MH.223#;IY)-01BGEE%16:>656&:IY99<=NGEEV"&*>:854Y`9`4D=B!!`&2V
MZ>:;<,8IYYQTUFDGF686F>::=_;IYY^`!BKHH(0RF2>:)?)9Z**,-NKHHY#&
M>>B>;$9JZ:689JJIH),F6NFFH(8JZJBD0MFIFI^6JNJJK+8*Z*F*NBKKK+36
MNB6LJ=JJZZZ\RHIKK\`&*^RFOPYK[+'(!EILLLPVZ^R8RSXK[;342AEM_[78
M9OOLM=IVZVVPW'XK[KB^GDDIN>BFRVJXZK;K+J3LOBOOO,J:ZRF]^.;[JKVH
MZNOOOW+&"_#`!&,I<,$()^SDP0HWC####D?\+\025TPOQ19GW"[&&G<\+L<>
MAZPMR"*7/"W))J?,+,HJMSPLRR['S"O,,M=,*\TVY[PNO['J[//+/.?Z\]"[
MXDSTT9<:C?32CBK-]-.$.@WUU']*3?75=5J-]=9P:LWUU]`&#?;838M-]ME1
MFXWVVE6KS?;;6;L-]]Q=RTWWW6'K>2_>?.>-:+]]!_ZEUX*_37CA:Q^.^-F*
M+SYVXXY_#7GD6T].^=667SYUYIH_S7GG2W\.^O_1HH\^=.FF^XQZZCFOSGK-
MKK\><^RRMTQ[[2G?CGO)NN\><N^^=PQ\\!D/3WS%QA\?<?+*-\Q\\PD_#WW!
MTD\_</763VQW]F1CSWV^WG]_\?;B<QU^^>^>C_[&Y*]/M?KNHPM__!^W3S_3
M\]_O;?[ZCVQ__T3C'P"K)<`!GNQ_!M19`1/HK`4R<&4(?*#,'"C!8U&P@D#3
M&^`P>+H(<C!W'OP@[T(HPM^1L(3".R$*BZ?"%2*OA2Y<'@QCZ+P9TC!Z-KPA
M]7*HP^OQL(?:TV#/@"BR"Q)Q548\8JF2J,11,;&)H7HB%(GUPRFFKXI69)\0
MA99%ATFQBY;Z(ACAA<4C,=9OBV:4F!C3R*@ULK%0;GSCH.(HQWJAL8X/*R,>
M"1BT$```.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU8R]I
M;F9O+G!H<```````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#$V-P`Q,#0Q-S,V,S`Q,0`P,C`Q,C4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@
M:&]R9&4O=&AE;65S+VQU8R]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y
M.C,S.C,V(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(DQO
M>6]L82(I.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,O<V-R965N+F-S<P``
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<V-C(`,3`T
M,3<S-C,P,3$`,#(P-#8Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]L=6,O
M<V-R965N+F-S<RQV(#$N,3`N-BXX(#(P,#4O,3$O,#(@,3DZ,S(Z-#@@:F%N
M($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@
M9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@07)I86PL($AE;'9E=&EC
M82P@<V%N<RUS97)I9CL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C8S1C
M-&(X.PH@("`@<V-R;VQL8F%R+6AI9VAL:6=H="UC;VQO<CH@(V4V939D8SL*
M("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S`P,#L*?0IH=&UL('L*("`@
M('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C8S1C-&(X.PH@("`@<V-R;VQL8F%R
M+6AI9VAL:6=H="UC;VQO<CH@(V4V939D8SL*("`@('-C<F]L;&)A<BUA<G)O
M=RUC;VQO<CH@(S`P,#L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@
M(V,V9#-F9CL*?0IA+"!A+F9I>&5D('L*("`@(&-O;&]R.B`C,S,Y.PI]"F$N
M=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"BYH96%D97(@>PH@("`@8V]L
M;W(Z("-F.3`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V8Y,#L*
M?0HN:&5A9&5R8F]X('L*("`@(&)O<F1E<BUC;VQO<CH@(V8Y,#L*?0HN:&5A
M9&5R8F]X("YH96%D97(@>PH@("`@;6%R9VEN+6QE9G0Z("TQ<'@["B`@("!M
M87)G:6XM<FEG:'0Z("TQ<'@["B`@("!B;W)D97(M;&5F=#H@;F]N93L*("`@
M(&)O<F1E<BUR:6=H=#H@;F]N93L*?0IA+FAE861E<CIH;W9E<B!["B`@("!C
M;VQO<CH@(V9C,#L*?0IA+FAE861E<B!["B`@("!B;W)D97(M8F]T=&]M.B!N
M;VYE.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P87)E;G0["GT*+FQI9VAT('L*
M("`@(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@
M(S`P,#L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PH@("`@9F]N="UF
M86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT
M+7-I>F4Z(#$Q<'@["B`@("!F;VYT+7=E:6=H=#H@;F]R;6%L.PI]"F$N<VUA
M;&QH96%D97(L("YS;6%L;&AE861E<B!A('L*("`@(&-O;&]R.B`C9CDP.PI]
M"F$N<VUA;&QH96%D97(Z:&]V97(L("YS;6%L;&AE861E<B!A.FAO=F5R('L*
M("`@(&-O;&]R.B`C9F,P.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z
M("-D.&0X8S$["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9#H@(V5E965E-CL*
M?0H*+RH@1F]R;2!S='EL97,N("HO"FEN<'5T('L*("`@(&9O;G0M9F%M:6QY
M.B!697)D86YA+"!'96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R
M:68["B`@("!B86-K9W)O=6YD.B`C9C=F-V5E.PH@("`@8F]R9&5R.B`Q<'@@
M<V]L:60@(S8V-CL*?0IT97AT87)E82!["B`@("!C;VQO<CH@(S,S,SL*("`@
M(&)A8VMG<F]U;F0Z("-F-V8W964["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M-C8V.PI]"FEN<'5T.F9O8W5S+"!T97AT87)E83IF;V-U<R!["B`@("!B86-K
M9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V8Y,#L*?0IS
M96QE8W0L;W!T:6]N('L*("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N
M9#H@(V8W9C=E93L*?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C,S,S.PH@("`@
M8F%C:V=R;W5N9#H@(V8Y9CEF.#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"`C,#`P.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*
M("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(V,T8S1B.#L*("`@(&)O<F1E
M<BUT;W`Z(#%P>"!S;VQI9"`C8S1C-&(X.PH@("`@+6UO>BUB;W)D97(M<F%D
M:75S.B`U<'@["GT*+F)U='1O;CIH;W9E<B!["B`@("!C;VQO<CH@(V8Y,#L*
M?0H*+RH@06QT97)N871I;F<@<W1Y;&5S+B!I=&5M,"P@:71E;3$@87)E(&1E
M<')E8V%T960N("HO"BYR;W=%=F5N+"`N:71E;3`@>PH@("`@8F%C:V=R;W5N
M9#H@(V5E93L*?0HN<F]W3V1D+"`N:71E;3$@>PH@("`@8F%C:V=R;W5N9#H@
M(V9F9CL*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R
M.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V4V939D8SL*("`@(&)O<F1E<BUB
M;W1T;VTZ(#)P>"!S;VQI9"`C.#`X,#=!.PI]"B-M96YU(&@Q('L*("`@(&-O
M;&]R.B`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B
M;W)D97(Z(&YO;F4["GT*(VUE;G4@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9F9F.PH@("`@8F]R
M9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V9F9CL*("`@(&)O<F1E<BUL969T.B`Q
M<'@@<V]L:60@(S<V-3L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C-S8U
M.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!C
M;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C,&,P8C@["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(V9F9CL*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED("-F9F8["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",W
M-C4["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S<V-3L*("`@('!A9&1I
M;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N
M96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V4Y93EE.3L*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C93EE.64Y.PH@("`@8F%C:V=R
M;W5N9#H@(V8V9C9F-CL*?0HC<VED96)A<E!A;F5L('-P86XN=&]G9VQE+"`C
M<VED96)A<E!A;F5L(&$@>PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P
M861D:6YG+6)O='1O;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@<W!A;BYT;V=G
M;&4@>PH@("`@8F]R9&5R.B`Q<'@@;F]N92!T<F%N<W!A<F5N=#L*?0HC<VED
M96)A<E!A;F5L(&$@>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V8V9C9F-CL*
M?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B86-K9W)O=6YD.B`C93EE.64Y.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@
M(S`P,#L*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*?0HC97AP86YD0G5T
M=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@,7!X.PI]"@HO*B!486(@<W1Y;&5S
M+B`J+PHN=&%B<V5T('L*("`@(&)A8VMG<F]U;F0Z("-F9F8@=7)L*")G<F%P
M:&EC<R]T86)?8F]T=&]M+F=I9B(I(')E<&5A="UX(&)O='1O;3L*("`@(&9O
M;G0M<VEZ93H@,3%P>#L*?0HN=&%B<V5T(&QI('L*("`@(&UA<F=I;CH@,#L*
M("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O=&%B7W)I9VAT+F=I9B(I
M(&YO+7)E<&5A="!R:6=H="!T;W`["GT*+G1A8G-E="!L:2!A+"`N=&%B<V5T
M(&QI(&$Z:&]V97(@>PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T
M86)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T;W`["B`@("!M87)G:6XZ
M(#`["B`@("!P861D:6YG.B`S<'@@,35P>#L*("`@(&-O;&]R.B`C-S8U.PH@
M("`@8F]R9&5R.B!N;VYE.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED
M(",W-C4["GT*+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&-O;&]R.B`C,S,S
M.PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T86)?;&5F="YG:68B
M*2!N;RUR97!E870@;&5F="!T;W`["GT*+G1A8G-E="!L:2YA8W1I=F5486(@
M>PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]C=7)R96YT5&%B7W)I
M9VAT+F=I9B(I(&YO+7)E<&5A="!R:6=H="!T;W`["GT*+G1A8G-E="!L:2YA
M8W1I=F5486(@82!["B`@("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z
M('5R;"@B9W)A<&AI8W,O8W5R<F5N=%1A8E]L969T+F=I9B(I(&YO+7)E<&5A
M="!L969T('1O<#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9F9F
M.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@("`@8V]L;W(Z
M(",Y.3D["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+V-U<G)E;G14
M86)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T;W`["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(V9F9CL*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]B=7)N=&]R86YG92\`````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`,#(P,C(S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+VEN9F\N<&AP````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q,``Q,#0Q-S,V,S`Q,0`P
M,C$V-3<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H96UE(&)Y.B!%<FEC($IO;B!2;W-T971T97(@
M/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@4&QE87-E
M(&-O;G1A8W0@=&AE('1H96UE)W,@875T:&]R(&9O<B!A;GD@;6ES<VEN9R!S
M='EL92X*("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8G5R;G1O<F%N9V4O
M:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-2!M9&IU:VEC($5X
M<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")"=7)N="!/<F%N9V4B*3L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]B=7)N=&]R86YG92]S8W)E96XN8W-S````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,T,3<`,3`T,3<S-C,P,3$`,#(R,C$V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J*@H@*B!4
M:&5M92!B>3H@17)I8R!*;VX@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P
M:'ES:6-S+G5T97AA<RYE9'4^"B`J(%!L96%S92!C;VYT86-T('1H92!T:&5M
M92=S(&%U=&AO<B!F;W(@86YY(&UI<W-I;F<@<W1Y;&4N"B`J"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+W-C<F5E;BYC<W,L=B`Q+C8N
M-BXS(#(P,#4O,3`O,3@@,3$Z,S0Z,3(@:F%N($5X<"`D"B`J+PH*8F]D>2![
M"B`@("!B86-K9W)O=6YD.B`C9C!B,#8P.PI]"F$@>PH@("`@8V]L;W(Z("-C
M-C`["GT*83IH;W9E<B!["B`@("!C;VQO<CH@(V,V,#L*?0HN:&5A9&5R('L*
M("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V,V,#L*?0HN:&5A
M9&5R(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*"BYS;6%L;&AE861E<B!["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C-C`["GT*+F-O;G1R
M;VP@>PH@("`@8F%C:V=R;W5N9#H@(V8Y8V4X83L*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C8S8P.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z("-F
M9F8["B`@("!B86-K9W)O=6YD.B`C8S8P.PH@("`@8F]R9&5R+6)O='1O;2UC
M;VQO<CH@(S,P,#L*("`@(&)O<F1E<BUR:6=H="UC;VQO<CH@(S,P,#L*("`@
M(&)O<F1E<BUT;W`M8V]L;W(Z("-F,&(P-C`["B`@("!B;W)D97(M;&5F="UC
M;VQO<CH@(V8P8C`V,#L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@
M(V1F.68S9CL*?0IA+G-M86QL:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C
M9F9F.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B86-K9W)O=6YD.B`C8S8P.PI]"B-M96YU(&$Z:&]V97(@
M>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-F,&(P-C`["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C9C!B,#8P.PH@("`@8F]R9&5R+71O
M<#H@,7!X('-O;&ED(",S,#`["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED
M(",S,#`["B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@82!["B`@("!C;VQO
M<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8V]L;W(Z("-F9F8[
M"B`@("!B86-K9W)O=6YD.B`C9&8Y9C-F.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED("-F,&(P-C`["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI
M9"`C9C!B,#8P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",S,#`["B`@
M("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",S,#`["B`@("!P861D:6YG.B`R
M<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PIB;V1Y+G-I9&5B87(@>PH@
M("`@8F%C:V=R;W5N9#H@(V8P8C`V,#L*?0HC<VED96)A<E!A;F5L('L*("`@
M(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-F,&(P-C`["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(V8P8C`V,#L*("`@(&)A8VMG<F]U;F0Z("-F
M,&(P-C`["GT*(W-I9&5B87)086YE;"!A('L*("`@(&)O<F1E<CH@,7!X('-O
M;&ED("-F,&(P-C`["B`@("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A9&1I
M;F<M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@
M(&-O;&]R.B`C.3`P.PH@("`@8F%C:V=R;W5N9#H@>65L;&]W.PH@("`@8F]R
M9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N
M93L*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!L:2YA8W1I=F5486(@
M82P@+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!B86-K9W)O
M=6YD.B`C8S8P.PH@("`@8F]R9&5R+6)O='1O;2UC;VQO<CH@(V,V,#L*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O8V%M;W5F;&%G92\`````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$Q`#`R,#`P,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]C86UO=69L86=E+V=R87!H:6-S+P``````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`
M,#(Q-C`P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA
M9V4O9W)A<&AI8W,O;65N=2YP;F<`````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,#`U,``Q,#0Q-S,V,S`Q,0`P,C,R-#,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```QX````T
M!`,```#VR_/`````&%!,5$4?+AL21"(I/2)G;$`**1+___________]OCHOX
M````"7!(67,```!(````2`!&R6L^```/MDE$051XVJ6<;8*RO`Z&B[H`.KJ`
M$5T`"@M`Z?[7=.A'DCMI<7S>TU\CEC;)E8]2ZK@0IM1&?PG!;\TY=YRF81AN
M4VG/H;1[H/:.'[>>U&6[;[L0;^^WJR?N%]:'RRT.'\)KZW$)\/4T/7RZ+7U,
M8^6^O:-VTOVW#H=MKO/$;=PZ'4C&3>P\8FJEUXAC;-/,68.L3YY%!J`VC0<9
MDPRQ]>S,U"#D4G1-,\\TFS4CM*O/EN,Y'75WI$*>L<EC2*/G>88T>^[P\,(C
M`FGR*!>\5Y9)*(E'LO;4;1\W<+L\LNW\U`1R(W%2RU_/H6YO]J]BPQK'-FP9
ME.<:?J-U/`!A*1T`Z<KTXD([/*[DG<*#%2(=HF/Z\[O)(U\2K1:2:)/@I_#P
M1;32BI]WOF$4P9'%6B>P9I-'2+):'ED#^:!PV`EG4?_^(3PFGFFSVG97DNV0
M>32!!`DVXI&TXIYU!`Z0+/*%J(5S:I#$PV\\6F`K?UM9GFVZWRX/@!;(OK?#
M0Q*+1/8#Y`!%8<*D&-K$MD\XMBMOS+^N'1Y1S>CL/Q%'RCV2GCCP%!+,6*)7
MO[#'M'"`58A';WBDA*5XO#_PH'#///(@)_-]_,:W>+PX#$X2V7L\UCPOZ_*!
MQT-*A\Y5.>D,P&-IA\<MD=R^W,*^U(*53>^]F1S#V/#P'+8UCZNJI='*6_A-
MOL%C,T*QO58@R:D32%`\G*G72:=D/GTU-S+YB2R>)[L2CP%XK-FX1./'^(@%
M0@:+>MXYMK0R^SQN>;*E&"5'&9O>VP`9+8\.@#"T5GB@538@=^<>%8_>\)AU
M'(\F@W#"*CR,S0N/:X/'R^0CL-;UA_(I?:]2S54M2EI$2/9$$'@H@]QWTA4G
MNIH'5]HJ0$Z0+Y!'\0Q9K`$.;:S"H_^#1]"BND\\3L&VI?A>@\=BRK6Q%@&1
MV&'7T(O$O,R8VSS>BL?S+QXW($D\RM)U)=.CF?\KCRN43>"Q[/%P[UN;QVAY
M+,"CD9,^\!@UC[6U(J39ID\\AF*_]0\>%OB=A:<KLAQ*")::Q^@X:/9YN)H'
MI$3HH.SQ'D+DX5OUPQW$4S[S@/BX_U\\I@\\:)4BSO7S)8_A`X]@>=QE#.`Q
M(8^)+'7^D@=W.0B-SSQZ-41O>2@E(@^=E+[C<:W75ZM:EP3_,$Y/TL<.M$K)
M.B6#F(0UMW"4X&[SN(/T>=Q;:/$X:Q[\Y'S6//`!!!+6F;N<HL&I@\]>I;UT
M"+%^E(C0X>&>4XO'K>+!Z6K3"2'!GSG#[/$H/?/D+1XNCH%).,MJ`F1F>ZEL
M,@./5:FBO2E>.4\88\3C3'#8'G;E5'AD:);'!#PP@(9J?24\>AC!U3R>FH<.
MC['!8\%ET[3'@QZO`(<V\I!6;)LBCGFX?*VS7;<`R89\6#LH'J+)'44M+CNU
M>)SY@QCD80,DW7^<Q<>8QQFZX(P_0VN!M92PZ`%'ON,X[?`H.%ALX1$&I2-A
M2TY]]=4#R$HWQP\OWP;R2X.34N52%4LW38,-\6SS(!S`(VX35CS<F3^H;)BS
MO.$A?TJV03.U>"BK#+KR,*U]'KX_:5>1#1Q,5LF"'`;/G/&K\)BD$(H(/TT>
M1YKK,$"],H4-5YG$`XTOFH`P1"/=@&9/BI+)9ZWSE'<UC`W0/4F6699E%8^K
M!0(\%*<%-^<,#Q4<(@$DL9?E,>6-+?HHX9%O/D%X6+]WBH?$8KSTUD"N.N]Z
M$?TV&QZH[U+NJ<+@@CPFNU@8P4M2W+9Y7`(\1P*/CGF`FRX'XF%<]P./2\6C
M>D#LBP79"I1(7M$'GT5O\"P,CRA+@X<.Q2:/P2S<1?!;62RY<D'[9>Y/4<"Z
M/30/VPR/0Q3UB"XC"2>-J+,/\O!B]:DLWBY?\[B$FL=H=F#[8D'D43)[C)6;
MA:EYA!#>EL<1(Y%YA,$"4;80N6]4#,JRUB0$R6XSY.*'KS7=YY%D/:++=&+K
M!@\//$B2/%(C/#;)CSCWX3./Z:1N?A&/"7DD(.=DHTJOTTOAP`!!K36.3SS*
MCA^7EFSIA5]GZ)SP\NK%E>)AJH9Q)/;:;"&G0EA,O19W9'_M//*@Z\S#AH?A
M@3LOF/NYZ9NI?!@>$Z>0VL_LBH(#Y!>4AAWX'1Y7^':KST_@X;)?(@\,D/,N
MCUT@#1XQ$%$"LO1:'EF`?X/'^C4/6<E<FS+N\9B_Y`'KHDO-HX@R>GAEF-<+
MEH<LO4Y;+!P'X9$>FEQ9DOF:QU3S,'FDP6.H>`RW4;L$C?!0,_(RLDAR,CPL
MCEQ9_BN/+$S<;FGQ&`9=0$8='D7D!H^HD@J0:7Y_Q^-6'H[_*P^3#5H\:@E2
M:_-XM7E,^SS<+H_+GSR6PN-(/%;&$=-"@X=Z;`@J0(!'TDGSV(^/J`)GV2GS
M6/9YG#_R:`=(*U_)XRN%L.(A1VPT#S1J*U^9Y15L%?MFD6N$AY,%[\K6W/1^
M:A[/'1X4(5@_XB!8/K[E<9ORGMNW/-A_^/M6@(PM'@;'D7EXU7JJ9*CTNLMC
M<88'!\C5MYX_@$?<3>M8'N!1)K8\AILS.P07$..@E[M@!T=GQ-H\4G*B<EYN
MBH[2-7F\9//QO_(8&\E*5OSK0ZF8\X?EL1QW>"S.\J`5UI74T`+.('8TKP.S
ME&BBB9_%0,SCU_+P2@Q1S6:*>*D8_/[^Q.-6[H@\/&N!6CO-@QY@+PT>=ML.
M#5318,LL-8Z:A\_UM7X>K`V@GSKW>*S%5I+E*1UP^QDLC\&DJQC-IPI'%:\I
M/(K![[K<E(EY>TND[[SB(>"/6I,U\P"30"9H\Y@,C*.RC%*Q;_"X\(X1#732
MX2$3!3-?NGF-QK`\J)^X`><#I($\GGQ$*-^!`JO6V71QG(C'#?:ED,=!PF,D
M5VKQ6%!9T>1Q:?"8X:74!QZ&;Y`WBK(D&5`4+T[K@@&B1\1]/];*)X^\R:S1
M/U?#P^OG'R_[A#)@M!GQZ$G!42E6'/L\U>T)=)%'%TVYR&19*1;!2(?E">RO
M4O@*W[=YC,C#>&HQ6U*!O8W61R5`7L(CJ.2R*!YS@&,5P",E")*R/`?<]G@$
M'1Z#C!=YY#.-64[K:S)@BP=&VY-X=&5>65S-D,+K<JX>?<-.0Q[*/^76_?!8
MBMET/UX@F>8X54-X*!Y!C=.)I]^+F*#[V.3Q4N&1.(XV:%UCGRI>&"G4=WC<
M](<N6_H-[#%&ZW*N%F]_\(!R7_&``$';+6RVL^IW&G:`"`\LHT<E(,[7@:,7
MV=Z*1X<\WG<)$.81&"_(U/*U^/?#_\WC#,'RT!OVG,,I1(VSJ)V(QQZ/P!;>
M5@\)CK<\)LM#X7#.ZWYO$5$S^8:'.'0T-^,HLLV@O.'Q+AN0+^01[WH@C_PF
M"50;08C2H<'C*03.6$QFP'%CG_<J7T.Z^@<>^4AG2%[2-WF<./]E-Y"HZ50_
MQ4/))3R<I"NS7@O`'WGD`)&ADR6!=1CX72E$U3WN'R@>FS@]6AIX/`NQ#SPZ
M+^\ZDM5`SVVLHL*/\42JYIBNNC]Y)*77B==)5NC`SW6A\!CHP43U.PVFM7B<
MA`>FP'T>]_3-4_'`V'MG9B5"\"ZO>5P;QY,5#_PUE.%1WG4\.1[`]6X3KU/>
M)C$4L81'+#Y?\R@*'*W0L2_P6.D\#'3-/,S>]+7%`_[\Q`,*01+M1[3'\QT5
M#^JW\5C5*KQR_P:/VQX/7GX5EYC-RRS@H?)T$:L7'L/D]W`LP.,N%?VHY*')
MN',\_',@.6IN?^:KC9I9(@2I'[C@_9%"$%?4GWG<N8((CR![*H>&M5W-HP4D
MVSS5J[YU%/L7>02-XT)I%'C<=GDX\OEW^<E>JVUS72"8\K5#$430C52J0PN'
MXF&7"#L\+@$<91M!TI79QP0>(1;`G.ON4*=*C'S!HP$D72[+AP:/7Z=XJ#,3
MA8<7'G&BJZ9059D0\A&SM<EC=/)Z5O,8,))&EHD3Z_5+'IBNX`$$LVI<&1V*
M_FT>)6'U);9H"2R3^J'U"K?B4?_*`UWKN+O9R]*^;+I2"^DG^`[P(UF5/79X
M=!1UH,FA$GV$D*W#H\DCW\@[:JOF<3$XJ`K\>H/##\"#BD_@4XPTWMF:^K'#
MPT1(WG1F'D_+HS<\,$`N3(=X2"[5O2_9EZ(L>!*_Q:-^PZM^]<L\>)AW'1Z1
MQPI9XL@CR>.U4SSDYWPI64E5[KQO\K@K'K,Y5=KYZI4Z[;E9'B9`U!9I7_&X
M>LL#`D3@J&`;Y"@\H$L^I\Z1-WG`&\77T?``T?%TU$<>4]XUU4&U99=7]J%1
M\T##'?*HEZS$P_`8(!HBCS>$C"]+5:.7Y_V389='GO;*/*:*AR^+E#I`^HJ'
MT+S7Q4;6.Q\3%O#(<3?*PX$$"`KTIL0JF1YY//FN\O\,8O]0A!Z54!`=O)>?
MY""#1ENCSU'QF8L0]WC)TZ,UIJ('&>%H?IIE>_U\Y.'+'B6HSU8^53STO;K6
MU#S:`0*O3-+(41'B(;Z$AP>)1\YVE@?8!<.)DJP2:E+GH0;Z*771+VO0H<L1
M#WY>*S]VR<9`2Y.%TPMX;2?3"V.]*B">@-09JP^61YWL/O-@%YX)SJWBD1KS
M8`W!/UXIT__F(M%9'D_1N"HW8(@B#\K9_=";]=>9TIW4E0%_-RD\[FD/_/R1
M1S`\I-OC*QZEO-D`.54\!ML01U_SH`"9"4YZ/?=O/#;GR"\<G$H+S$-N4]4F
MJWPV/!#'YO57KWA,AL>PRX-FKM+5-GS\?<L_\-!&+0ZR)#%T@)R"Y6'#PSP2
M-'BL@J-L&GW)8^0^$_$XYB_^B8<`$;V`A_^:QUEXO%H\'OXK'M[R<,:HPN,P
MZ`#I0\6CPH$\X$$@&"#R]S/*]@6/1\^NL:F:7Y`>,2]\RT.?P5!AO/&@GUXI
M'K")"3SH5&&*CS-Y)UNZE]^5'F?<&RS2Y?_K,I&R?H]'%BB>[3[@8\76\82E
MY$\>O6OS2%:3Y)7CXV(*5<7CH;LX)_E*>(0='F\EVA$"9#%^\\/U7/%@:T+]
M\(J'+5SX`J4_5B=T(X\`PN.^Z%%W%7-J'J[%8S=?,8VL\`F!*!Y3WBVJ>.A#
M`QZ.\N3AA<?8Y/$K.2F\?E`SWJ&<T[]948Z3NUWH4:7PN#1YT-5[<*4W^,_H
M@$=MIQL?L"C>!UGET/;O+!P;L2<G5SPBDCN<<RY:BX(T6E!`9JPEY=7D#H\;
M"=WBX0R/%7C$+\4J/Q"X)/GHJB8JG"GK;"-(]I<]&4^[6MM%^D=KXD`C*M_8
MLYT,#VCT"_+96"2I+`'B[*DP2,,JP\2OLCC9_1I`UIJ'.<(A/+@R-GG$W..$
M!_]C'3G!U%4*]_LXV#691W0MC__V"WC\"`^5+'CH,N&YXO$[\2_=:A[%"]E)
MU1?X2^PV#UE)Y+G.I&N@_]+0B!!)5^3A%\OCAT8KGZG#"WEL0.A-WO\``G/6
M?,NMS^T`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V%M;W5F;&%G92]I;F9O+G!H
M<```````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C`R`#$P-#$W
M,S8S,#$Q`#`R,30S,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O
M8V%M;W5F;&%G92]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,U
M(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(D-A;6]U9FQA
M9V4B*3L*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O<V-R965N+F-S<P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(P-``Q,#0Q-S,V,S`Q,0`P,C$W
M-C0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O<V-R965N
M+F-S<RQV(#$N-RXV+C,@,C`P-2\Q,"\Q."`Q,3HS-#HQ,R!J86X@17AP("0*
M("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z(",Q9C)E,6(["B`@("!S8W)O
M;&QB87(M8F%S92UC;VQO<CH@(S5D-60V,#L*("`@('-C<F]L;&)A<BUA<G)O
M=RUC;VQO<CH@(S5D-60V,#L*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E
M+6-O;&]R.B`C-60U9#8P.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C
M-60U9#8P.PI]"F$@>PH@("`@8V]L;W(Z(",S,S8["GT*82YW:61G970@>PH@
M("`@8V]L;W(Z(",P83(Y,3(["GT*82YW:61G970Z:&]V97(@>PH@("`@8F%C
M:V=R;W5N9#H@(SDY-CL*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@
M("`@8F%C:V=R;W5N9#H@(S,V,SL*?0HN:&5A9&5R(&$Z:&]V97(@>PH@("`@
M8V]L;W(Z(",Y.38["GT*+FAE861E<B!A('L*("`@(&-O;&]R.B`C.3DV.PI]
M"F$N:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C.3DV.PI]"BYS;6%L;&AE
M861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",S-C,[
M"GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@(V-C83L*?0IA+F-O;G1R
M;VP@>PH@("`@8V]L;W(Z(",P9C`["GT*+FET96T@>PH@("`@8F%C:V=R;W5N
M9#H@(V-C83L*?0HN8G5T=&]N('L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PI]
M"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C.3DV.PI]"@HO*B!-96YU
M('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K
M9W)O=6YD.B`C,68R93%B('5R;"@B9W)A<&AI8W,O;65N=2YP;F<B*3L*?0HC
M;65N=2!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-M96YU(&$N8W5R<F5N="![
M"B`@("!B86-K9W)O=6YD.B`C,S8S.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@
M*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD.B`C,S8S.PI]"B-S
M:61E8F%R4&%N96P@<W!A;BP@(W-I9&5B87)086YE;"!A('L*("`@(&-O;&]R
M.B`C9F9F.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!C;VQO<CH@
M(V9F9CL*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I97<N("HO"BYP<F5F<T]V
M97)V:65W(&@R('L*("`@(&-O;&]R.B`C9F9F.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V]R;F9L
M;W=E<B\`````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-#$W,S8S,#$Q`#`R,#`U-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]C;W)N9FQO=V5R+V=R87!H:6-S+P``````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`,#(Q-C4U`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O9W)A<&AI
M8W,O=&%B7V)O='1O;2YG:68`````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(P,0`Q,#0Q
M-S,V,S`Q,0`P,C0T-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA%``!`(0@`-WCU=OAT_[^_O+T[N;IX-K@TOS\
M_/7W\OGY]^KMY.#DUN7HWN[QZNWPZ>_RZ^+EVOCX]O?W]?/U\.GLX_KZ^/O[
M^^ONYW=F5>/FV^3GW?W]_>SOZ.'DV?'S[N#CV.CKXBP`````%``!```%!N`E
MCF19A@`[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+V=R87!H:6-S+W1A8E]L969T
M+F=I9@``````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,#,`,3`T,3<S-C,P,3$`,#(T
M,3$U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y80<`E@#C`P"ZR=3M\O38X>?____&T]S<Y.GS]_C#T-K*UMW>YNOR
M]O?0V^*^S-?CZ>W_______\L``````<`E@``!'APR%$(D(&1%(9BA2(.AV"<
M1G,HJ+$LK8&8+5+$-G[7.YKSNB!PZ.N=?D5ADG@TRIS(IE+*?$ZMU2AVR:5V
MM]XP>*PM0\]7<QJ=97_5[;4\3G^[Q7#[7%_'W\E_>7Y[@WV`A(>&@HE\C86.
MC(^2D92+EH&8B)>:?Q$`.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O8V]R;F9L;W=E<B]G<F%P:&EC<R]T86)?<FEG:'0N9VEF````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q-S,P`#$P-#$W,S8S,#$Q`#`R-#,P-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6&0`98`
MA!``PLK-O<O6PM#:S-??T=SCWN;JWN;KYNWP[?+T\?;Y[_?Z\O;Y\_?X]?;X
M]??Y\_C[____________________________________________________
M____________+`````"0`98```7^("".9&F>:*JN;.N^<"S/=&W?>*[O;R`0
M#HA002P:C\BD<LEL.I_0J'1*K5JOV*QVR^U&'89!H"!,F,_HM'K-;KO?\+A\
M3J_;[_B\?L_O^_]S#H('`080#XB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"A
ME8*#`0X+J*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,&UI((#!`S(R<K+S,W.
MS]#1TM/4U=;7V-G:V]S=WM_@X=7$8`+BY^CIZNOL[>[O\.CD"`$-]O?X^?K[
M_/W^_P`#"AQ(L*#!@P@3*ES(L*'#AP/).0@0KZ+%BQ@S:MS(D9E$BAU#BAQ)
MLJ3)=A_^3ZI<R;*ERXXI7\J<2;.FS6@Q;^K<R;/GQIP^@PH=2E0;T*)(DRH=
M>G2ITZ=063:-2K6J58M3KVK=RM5;UJY@PXK%.7&LV;-HDPD"F;:MVZMKW\J=
MZS0NW;MX?=K-R[>OS+U^`PLF"7BPX<,7"R->S%B=XL:0(W-[++FR96F4+VO>
MC"PSY\^2/8,>O5@TZ=."3:->G5<UZ]=R7<.>C58V[=MA;>/>K54W[]]1?0,?
MKE0X\>-,RR)?#E<Y\^=0C4.?_M<Y]>O)V6+?WE,Z]^\AO8,?GU$\^?/QS*-?
MSTX]^_?GW,.?[]4Z_?N)[>/?_TX^__]D:0?@@/+H1^"!]0G^B.""V_C'X(`.
M/OA?A!+N1V&%]UV(X7P:;OA>AQZN!V*(YXU(XG@FGOA=BBINQV*+U[T(XW0R
MSOA<C38NAV..Q^W(XW`^_OA;D$+N1F21MQV)Y&Q*+OE:DTZN!F64ITU)Y6A6
M7OE9EEINQF67EWT)9F5BCAE9F68VAF::I1G()GMKOFE8G'*FYF:=Y-&)9U]Z
M[MG:G7YRUV>@=`U*:&R`'DJ=H8JVQ6BCM24**7./3CI6I9;F)FFFQ&'**5>>
M?MK;IJ+R%FJI59V*:G"DKDJ;JJ[6U6JL3\Y*JY2VWEIEKKIBR6NO6_X*K)?"
M#AMFL<:2B6RR9R[+K)K./MNF@M)@XDIMM;M>BZVOVFX;;+?>$@MNN,>.2ZZR
MYI[;;+KJ0LMNN]/"RZV\H,%*[TKVWGM2OOJ6Q&^_(_T+<'C1#IR6P`;_5'#"
M9B',,$8./XS5PA*#%7'%\%R,L3L:;]S>1"$``#L`````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O8V]R;F9L;W=E<B]I;F9O+G!H<```````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C`R`#$P-#$W,S8S,#$Q`#`R,34Q,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8V]R;F9L;W=E<B]I;F9O
M+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,U(&UD:G5K:6,@17AP("0*
M("HO"@HD=&AE;65?;F%M92`](%\H(D-O<FYF;&]W97(B*3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V-O<FYF;&]W97(O<V-R965N+F-S<P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C4R-P`Q,#0Q-S,V,S`Q,0`P,C(P-34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RHJ"B`J("1(;W)D93H@
M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O<V-R965N+F-S<RQV(#$N."XV+C0@
M,C`P-2\Q,"\Q."`Q,3HS-#HQ,R!J86X@17AP("0*("HO"@IB;V1Y('L*("`@
M(&)A8VMG<F]U;F0Z("-F9F8["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82P@
M1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.PI]"F$@>PH@
M("`@8V]L;W(Z(",S,SD["GT*82YF:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*
M?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S`P,#L*?0II;G!U="!["B`@("!F
M;VYT+69A;6EL>3H@5F5R9&%N82P@1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A
M+"!S86YS+7-E<FEF.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E
M<CH@,7!X('-O;&ED(",V-C8["GT*=&5X=&%R96$@>PH@("`@8V]L;W(Z(",S
M,S,["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R.B`Q<'@@<V]L
M:60@(S8V-CL*?0IS96QE8W0L;W!T:6]N('L*("`@(&-O;&]R.B`C,#`P,#,S
M.PH@("`@8F%C:V=R;W5N9#H@(V9C9F-F8SL*?0H*+RH@4VED96)A<B!S='EL
M97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@
M<V]L:60@(S`P-CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`V
M.PH@("`@8F%C:V=R;W5N9#H@(V8S9C=F.#L*?0HC<VED96)A<E!A;F5L(&$@
M>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V8S9C=F.#L*("`@('!A9&1I;F<M
M;&5F=#H@,7!X.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#)P>#L*?0HC<VED96)A
M<E!A;F5L(&$Z:&]V97(@>PH@("`@8F%C:V=R;W5N9#H@(V-C8SL*("`@(&)O
M<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!T97AT+61E8V]R871I;VXZ(&YO
M;F4["GT*(V5X<&%N9$)U='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*
M?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&)A8VMG<F]U;F0Z
M("-C8V-C934["B`@("!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(S`P-CL*
M("`@(&-O;&]R.B`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z(",P,#`[
M"B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I
M9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@(&9O;G0M=V5I9VAT.B!N;W)M
M86P["GT*(VUE;G4@83IH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)O
M<F1E<CH@;F]N93L*("`@('!A9&1I;F<Z(#-P>#L*?0HC;65N=2!A+F-U<G)E
M;G0@>PH@("`@8F%C:V=R;W5N9#H@(V8S9C=F.#L*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C9&1D.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L
M:60@(V1D9#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@
M(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,G!X
M.PI]"B-M96YU(&$N8W5R<F5N=#IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*
M("`@('!A9&1I;F<Z(#)P>#L*?0H*+FAE861E<B!["B`@("!C;VQO<CH@(S,S
M,SL*("`@(&)A8VMG<F]U;F0Z("-C8V-C934["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S,S.3L*?0IA+FAE861E<CIH;W9E<B!["B`@("!C;VQO
M<CH@(S`S8SL*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*?0IA+FAE861E
M<B!["B`@("!B;W)D97(M8F]T=&]M.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UI
M;6%G93H@;F]N93L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PI]"BYL
M:6=H="!["B`@("!C;VQO<CH@(S,S,SL*?0HN<VUA;&QH96%D97(@>PH@("`@
M8F%C:V=R;W5N9"UI;6%G93H@;F]N93L*("`@(&)A8VMG<F]U;F0Z('1R86YS
M<&%R96YT.PH@("`@8V]L;W(Z(",S,S,["B`@("!F;VYT+69A;6EL>3H@5F5R
M9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P
M>#L*?0HN<VUA;&QH96%D97(@82!["B`@("!C;VQO<CH@(S,S.3L*?0IA+G-M
M86QL:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C,#-C.PI]"BYC;VYT<F]L
M('L*("`@(&)A8VMG<F]U;F0Z("-D9&0["GT*+FET96T@>PH@("`@8F%C:V=R
M;W5N9#H@(V4Y93EE.3L*?0HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP
M+"!I=&5M,2!A<F4@9&5P<F5C871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"![
M"B`@("!B86-K9W)O=6YD.B`C965E.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@
M("!B86-K9W)O=6YD.B`C9F9F.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z(",P
M,#`["B`@("!B86-K9W)O=6YD.B`C8V-C.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED(",S,S,["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C
M,#`P.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C8S1C-&(X.PH@("`@
M8F]R9&5R+71O<#H@,7!X('-O;&ED("-C-&,T8C@["B`@("`M;6]Z+6)O<F1E
M<BUR861I=7,Z(#5P>#L*?0HN8G5T=&]N.FAO=F5R('L*("`@(&)A8VMG<F]U
M;F0Z("-C9&8["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0Z("-C-F0S
M9F8["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@>PH@("`@8F%C:V=R
M;W5N9#H@(V9F9B!U<FPH(F=R87!H:6-S+W1A8E]B;W1T;VTN9VEF(BD@<F5P
M96%T+7@@8F]T=&]M.PH@("`@9F]N="US:7IE.B`Q,7!X.PI]"BYT86)S970@
M;&D@>PH@("`@;6%R9VEN.B`P.PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P
M:&EC<R]T86)?<FEG:'0N9VEF(BD@;F\M<F5P96%T(')I9VAT('1O<#L*?0HN
M=&%B<V5T(&QI(&$L("YT86)S970@;&D@83IH;W9E<B!["B`@("!B86-K9W)O
M=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]L969T+F=I9B(I(&YO+7)E<&5A="!L
M969T('1O<#L*("`@(&UA<F=I;CH@,#L*("`@('!A9&1I;F<Z(#-P>"`Q-7!X
M.PH@("`@8V]L;W(Z(",W-C4["B`@("!B;W)D97(Z(&YO;F4["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(S<V-3L*?0HN=&%B<V5T(&QI(&$Z:&]V
M97(@>PH@("`@8V]L;W(Z(",S,S,["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R
M87!H:6-S+W1A8E]L969T+F=I9B(I(&YO+7)E<&5A="!L969T('1O<#L*?0HN
M=&%B<V5T(&QI+F%C=&EV951A8B!["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R
M87!H:6-S+W1A8E]R:6=H="YG:68B*2!N;RUR97!E870@<FEG:'0@=&]P.PI]
M"BYT86)S970@;&DN86-T:79E5&%B(&$@>PH@("`@8V]L;W(Z(",S,S,["B`@
M("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]L969T+F=I9B(I(&YO
M+7)E<&5A="!L969T('1O<#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C9F9F.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@("`@
M8V]L;W(Z(",Y.3D["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A
M8E]L969T+F=I9B(I(&YO+7)E<&5A="!L969T('1O<#L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C9F9F.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]B<F]W;B\`````````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3$`,#$W,#(T`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V)R;W=N+VEN9F\N<&AP````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$W,``Q,#0Q-S,V,S`Q,0`P
M,C`T-C,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V)R;W=N+VEN
M9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S0@;61J=6MI8R!%>'`@
M)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B0G)O=VXB*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]B<F]W;B]S8W)E96XN8W-S````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(U,C0`,3`T,3<S-C,P,3$`,#(Q,#$U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+W1H96UE<R]B<F]W;B]S8W)E96XN8W-S+'8@,2XV+C8N
M,B`R,#`V+S`R+S(R(#(R.C4U.C`W('-L=7-A<GH@17AP("0*("HO"@IB;V1Y
M('L*("`@(&)A8VMG<F]U;F0Z(",U,#4P-3`["B`@("!S8W)O;&QB87(M8F%S
M92UC;VQO<CH@(S4P-3`U,#L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@
M(V-F8V9B8CL*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C
M-3`U,#4P.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C8V9C9F)B.PI]
M"F$@>PH@("`@8V]L;W(Z(",U,#4P-3`["GT*83IH;W9E<B!["B`@("!C;VQO
M<CH@(S4P-3`U,#L*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S4P
M-3`U,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E8F5B9#<["GT*+FAE861E
M<B!["B`@("!C;VQO<CH@(S4P-3`U,#L*("`@(&)A8VMG<F]U;F0Z("-B8F$[
M"GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C-3`U,#4P.PH@("`@8F%C
M:V=R;W5N9#H@(V)B83L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C
M9&5D96)B.PI]"BYI=&5M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E8F5B
M9#<["GT*+F)U='1O;B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-3`U,#4P
M.PH@("`@8F]R9&5R+6)O='1O;3H@=&AI;B!S;VQI9"`C,C(T.PH@("`@8F]R
M9&5R+7)I9VAT.B!T:&EN('-O;&ED(",R,C0["B`@("!B;W)D97(M=&]P.B!T
M:&EN('-O;&ED("-C9F-F8F(["B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI
M9"`C9&5D96)B.PH@("`@8V]L;W(Z("-F9F8["GT*+G-E;&5C=&5D('L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-C9&-D8V0["GT*+FET96TQ('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-E-F4V9&4["GT*"B\J($UE;G4@<W1Y;&5S+B`J
M+PHC;65N=2!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-B
M8F$["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*?0HC;65N
M=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(V)F8F9A83L*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+7)I9VAT
M.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@
M(S`P,#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D
M9&EN9SH@,G!X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)0
M86YE;"!["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@
M8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["B`@("!B86-K9W)O=6YD
M.B`C8F)A.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`Q
M<'@["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+P``````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#0Q-S,V,S`Q-@`P,3<U,#(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R\`````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$Q`#`R,3$S-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V%L:65N+FIP
M9P``````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(R,C0`,3`T,3<S-C,P,3$`
M,#(R-S(V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1
M`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"
M!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B
M<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"
MP\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!
M`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"
M=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7
M&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY
M>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)
MRM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_B&\
M<:7#9^.=>T;1HS=J=<N[*VCL+)XXX[F:Y/F:9:V:`M(MG=O)IUN;9?*N1"LM
MNB121(O[5?LH_"C79M+BT?1QJ]Q?WT:V6GVNKG3K.&^T72K""[TO4!*=/LI)
M&BAN;RTMIX)5@O("KS0W-RHNQ^3_`,:_A3^T-\'/CY<_#SQAX;U"'XTIX3\`
M_%.[\-^%K>\\2:CIFA_$KX0^'/C?I<$EK9)J$CQ:-\-O%=A<^(K)OM-KH=E:
MZG:7LTFGV%Q,?<?V;O\`@HY\2?@KKFD3^*M!TSXAZ':^39S6S[-*U1=)D^UK
M<1V][#;3QK>117,*Z=<)!&UM;6*V)\VROKV.;_7?)/%S@/+.(>)*$,9C,%7Q
M.,J4LAJ9AA8+)\/3C[14*>*QF7U<3-V=6*G5AAJD9JM"I5Q-.A!4Z?\`(GBO
MP5Q=QWP3P[1X:679UAZ66X+,,=AUF%.GC\U5?"TJF%KX9XBEA<)+#U*N'C4=
M26*P52K3E6EAH1KTJ*/Z7X=8O/`FIZ=I/B.2*UT"6S2.VU&VT^%;J[OM%TK3
M]%G&IV]M+?W$5G<FV74+4(;K48A<Z5:3WZVUM?V%K^V/[$OPO3QAX35Y-/"#
M4&U34Y[G2+69[Z]MM#N9[>Q@O9[QKJUBO+>>VU>^MA:6XB>TM7\JU_M![R\K
M^=+]I?XO_"_XR_L;_`C]KCX'^*Y--A\/?'+P=\.OCCX2F>_BU[PW_P`)K:_V
M<)7TZ\M[34+J;48-2AUQ/+LA8-I-I9W5GY4FMZ-J-O\`U&?\$\?%FD?#W]@[
MQY\:KBYU9?$9\%^-KGPC&=6E2\%O%X%O(;5+B^FFNHDU)_$NJ6KQW>FZ=IXD
MU.^>X>RGGN7N)O,\1\1/*^&?[1R''2K9GC<=1R:%#!0C&AF5>OC_`*KEM:I[
M*<[4YQD\=*I>K1K_`%6CC,*O9?5Z\_XES+*7F=')*>;4Z_"6(Q>.S/),_P`=
MC\-&E5R:>1S=3-L2L+B>5SS+^RG3H8:HJV*P^88_-,OH4YT9SK>S^K_A!XB^
M"_PGUX:'XY\;Z>]]KL`O]*N+6Q/F7*36,#PVS&*=W*V\1>=+C[?;VMM!?S7<
MTB:=<+<7.[XG^(OA36]:^W:!*TNB2W/V>?5)K.[L-/TZV-G<7EK+?:I<1O8O
M<N7TVP^S7-W:WT,E[!:SP+<6KQR_S0_$?_@HY^RG_P`$Y/$&J^+/VNX]1^.7
M[4FO:39>)O!OP&\'1:;>ZGX5\-ZCINF-X0F^(UQ;ZI:Z-X!NM<TB[T[5&T_Q
M'JMUXKOO#EOJ5[_PB$.F:_8:3??#WQ&_X.SOVD+[7=$UG3?V#?A!\/\`X=:S
MIEQ>:3I>K^(/%LFM^(;<,EM9ZGHWCFT\+>%M,NK"WN+1TO9+?PK?K<SM<Q&_
MMG9U/X#G>78&AQ;CJD<=B\\K+"4:6/QRKPHX#"5>24M,%@,#CL11G*/LH?[4
ML'3AB(QBU.-2I3IUE?@SX@>(OAY3I9+PVL7%9IB<PH9EBYY7D>)XIS"K1ITY
MU,NS',L1@(8O)LOIJ=+!2P^&K4U4PN)E6KUZ<</1E_:U]CM3RNJV:J>56:'4
M4E"GD"58K&>)9`.'6.>:,-D)+(H#L5^!GP[_`."_'[-OC'X?^!?%WB7P9JOA
MKQ'XJ\'>&/$>O^'+/QI\/[RST#6]<T2QU/5=$M;N[UC1+JZMM*OKJ>Q@N+G1
MM(N)XH%EFTRPD9K6(KRU@L6TG%8N<6DXSA04H23LU*,OJZO&2=T[*Z=].GXA
M7\%_$S#UZU"?`$.>A5J496S*@US4YN$K./$,HM76\92CVDUJ?Q"Z5^V_^U?^
MSM^VYX/_`&K?#?Q!U&/XZ_!G3O!GP_\`#_C&6WTV6]U_X;>`_A;I7P0T/P]X
MDN;>R4:JVO?!;3;#P?KNNSHOBB59I=8@U+3_`!)!;7]G\_?'.;X+_$CXI)K?
M[*WPU^('@/0/&L=_KEY\$M3DN?&-O\+/%6J>+/%$]O\`#3X9>+Y==\2>-/B7
MX#\.>#U\)PZ1XR\=V^B>.=5U9]>MM7T1H=.L]9UCZ@_:Q\*>(/!OQ#T?X]^'
M;2VA\%^/9\:8RVD[/X>\4V=G]C\2>#?%\%S:6=[9ZI=W']HSZ8UZ(+FZTEI+
M;3GM;K0+ZRT?]5OV!-7LHHD\0Z#H5CK4)TK7];UR[M=.CN_$DEMI^E3W6CMH
MTFI06=];:A>QZOI^C0Z5ID\]K=6^L2/=1)?R7,FF_LV7^$O"/BABZ_&W#O&6
M)P_#6;UY9W@L'4P.%ACL)EF(QF(H4\M^M/%X:"Q658EXK`SISP$Z3Q>"Q%.E
M*=3FQ"_U=X[\1L?X2\/Y'BJW"D,9CHX+#Y-7IX/-*N"RZCF&'PT54AB\+_9]
M>$\)3O"M@J]*I&O7C55.E.&%?MI_!O[:'[4W_!1+]HOXG_#+XF?MJ?#O6/AI
M9?$?P#\+OACHMA%\);WX*^%?B!X7^%.HZOI?AKQ6=!AM],?5?%>BW'B36+FP
M\6Q&%K$P6.G:"+'P_H6E:18?W>Z3JOQ2^`/_``1JTOXO_`?X:'XF?%V#X-:K
M\0?@=\.],MH_$%[XB\71>+;'3_"USK^GI8VP\41^`H]47Q=XD\-PWD%QK^D^
M&[_0855]3BDM?Y*/VL3XW_:I\:^"G\._#KQ%XHT3P';:W>W>M:;X:O/%-W\.
MO`-C<>'X!XQ\;7L#SV?A[PSH-]=2S1WYDM-.\/W7B"6UEU-[:274E_KN_92\
M8_$?5_V>O@S\`YU\(6VL6?@OQ5X-^&GAZ]U^UL?$WQ1\/_#FVMK?XL^(_A'X
M;;6H-1\7:)X4GUO2)?%7C71FET+0];NFLYX+B_U"*"V]WQ'X)I\*\(Y)PM0X
MFE++<MXIP6+KRS7%8#"XS#Y53R[-\17I8*I"A2PT(4L5F%'%153#25'"T\16
M47[.M*'\;<?<>4.+<HX+S=\$9?B<^I2QRI9%DE7'SRV>84N)LCP>%QN<SIUW
MFL\/4X7P&-PV+JSQE/$K&ULFJ5:OU2.'HU?\WK]O_P`4^#_BO^T5XQ^/WA'P
M'X[^%M_\>]2UGXI?%#X9>,-#@M]*^'_QHUW7=1C^*VB^!/%=A::/I7C'P+K'
MC2#5/&GA-M-\,>'H/!>@>+-+^',\>LWWA&\\1:KZ?^TW^WS^U3_P40^&_P"Q
M)^RUXH\&^%-4TS]D7X<6WP1^`?A#X+_#W6;7Q9XOBN=*\)Z#;W7B;2[#4->D
M\5>-+_3?!WAVRB'A_3-'L?-COKNUT.+4=8U:ZO?],;]E_P#83^#_`(&UFVT'
MXQ_#[P3)H5UX4BDO],\7:+;W^A:N]I;K<ZS!<:1K]IJ&GV-SJOG3M>VVDW2V
M3PKJ5G=7%S.EC;W*^/?`G[-O[//BG4/%GPY^$?PM^&^C65[J>H:QXPT;X?:7
MI4^@^#O#^G/9:E>W-]HMA'JUG+'97D6D6D=G!)I[R7MPL]NHOKJYG_!ZN%X1
MPN>YKE62YGFF9T?J/]I/,:^58".#JPA''T\5.AGU3-:M>C6Q."J8R.)Q5+#5
M*M55L1.OAY>V6%P_[)B_I18G+L@R3-I^'^7YYFE//<SX8R++Z7&4Z/$#QM+`
MX?&RE7X<H\.XK%X;+Z5"KA,)2>+K5\5B*]"A.D\14J4L96_F&^!'_!OO^TAK
M?P/^#>M>(?@WH.E:_J_PJ^'FJ:YIFN^.-:TG7--UC4/".CW>IV&LZ4&QIFJV
M=[-/;ZCIXXL[R.:V'$=%?K/K'_!R%X'\):OJGA7P]\/_``AJ&@>&=1OO#^AW
M^M27,&LWVCZ-<RZ=IEYJT%MI-W;0ZG<V5M!-?Q6]U<P1W3RI%<31A9&*^2_X
MF8S;"_[-A<CX4EAL/^XP[JQXEJ570HVITG4J1S&,:E1TXISG&,8SDW)1BFE'
M[^EX-<?9C2IYAC<ZSS!XS'TX8W%X2CE?!BHX7$XJ,:]?#4OK&/>(5.A5G.E#
MV[=912]JW-,_BA_9F\??#OXR?"OXQ?!/XQ>)/$6L^,/B+<V>H?#C6+B72K_0
ME\537TDVL>(_$^OZD^H:VOB*^GD6SMM9T[3=5N'>>[N-9FAECM9I?ESP-XU\
M8_LK?%?5O#-Y=O=^'TU*UL/%&B7D=W;6TEJZ0R1ZBML(9[C3M9TVVG!F>.">
M3>DUA*M[&JO7A/A[XE>(M+T_1-`AO(1H>D>(+KQ/I$#V-G=3V^NZU:Z+87=W
M-J]U:OK]]:7^GQ>';/[!=Z@UC9A;:_LM.L;N^UQ-,_0N_P##GAS]K;X8>&]3
MO[OP[X6^,UE<7OA+0==OM:T*W'CB30;2PO)-%\:6=I.VL:.[IK6G6/A;QEJN
ME6>AWTMPGA_[:+;2+K^R8^COXWX#@=3X3XH:H994S!YIPSQ(Y5N;AG-*M&5'
M&Y=CUA_WV(X9SZU"6)I2]O1RC,:3S*AA8PS'.:M3^C^,N#L!Q)A<;1QF#CF&
M!S+!K`9QEDE!PQ5&,E+#YA04H.4,RRYW=&K1G2KSI<CC.K7P6`I+])OV>?VJ
M_$'A#2OC%HOPWU?4?"][\8_@]J7PO\=2Z?<0:7XCMM`UJ^:4-H>NQ12:A'-H
M^H6<<YN+6-+5['6A;2FWOKYUL/ZSOV#_`-B/X::OX3_8[_;@CU_QQJGQ3_96
M_9)T[]B_1]+U;Q#(O@CP]J_ACPTWA?QK\0?".FM<6\VC>(?B=9W<UQXOUVUE
MMIM6AU1UNTM9/MB)_G?>!X?&=YXJ\):>USK'@_Q9X*U?2_"/CGPW?)8:AJU[
MK.FWMS<Z5KT=OKCR0PWM_<7%O;7#>9I>G:M8VZ*U^EQ8#5+_`/OG_9!\/?M.
M7_[,'P\U*7]IW0_#7PV\4Z9XQ\:7'A_X=?!ZTM[J#4M0>PNAI^D^(?'OC/Q%
M'?ZW!X>T^XNIY8?#TJZ!XBBU*RN+W4+/3;:-?[&\:L+2XAR7)\SRS%93E4LY
MQ48XS.*V#Q&-PF>9?B\KP]-4(PPV$QTWB89;&MA*.*G&AB*4L$Z.$Q<J#A3Q
M/^:/'.7X?PGK9KE]3-L5&.;8+$9?A,NPV,KX+,\GS2E4K+"5L1C:>`S#$SRG
M]W6KRIX15(8O#8W#Y?B9PK9A8^XOC9\0-:\;FX\-PW5VFKF[OK=)=*N6EN[&
M[EMM1\/I#9WKC4OM$^IZ?-97$EBUG/%I=P9K&YBU*>XO+.R_GJ_X*Q_MAZ1^
MR)\.+WX!Z/J<OQ!^-GC*3POXI_:$U?QPMUJ5N;>Q%AXQ\,?"33T75;>R7PY;
MZ[J)UGQ5::3>KJ&I:L\-C#K*+I,EKIWT7_P4T_X*/>`OV/\`0!X?^&SZ=9_'
M>]@@AU/3;RZM]1L_A?#]DL7TN5;:>PA@NO%NKV,EM=!]4NI9-"DO+B[NK8ZX
ML$^F?PK_`+1'QI^(/Q:\9G6O&=]X@O\`6-1AM;BQF\0-J(N3I5W%`FC7-I!J
M<;.NF3:;LG\/SBU>S.A076J6D=Q86\6FM_$?BCXDX?`9)4\..$Y3P^$<H+B/
M$4H4J;G6H5858991Q%*=5UL+3JQ]I7A2K3PU2K##S=3$UZ3JQ_9?HM^!F.KX
MW+/%CC'#8B-/ZL\;PWA,QJTZN89GF.*K0JOB3&>SJ8CDR_#1I)9!3GBJOUWV
MO]IJG]7I8#&YEC7_`,3/&=Y?7MY'K=W9QW=W<7*6EL8DM[5)YGE6VMT6)52&
M!7$42A5"QHH``&**^;GF0NY-K82DLQ,KZIX0WR$DGS'^TV5_<[G^\WVB^O9\
MD^;=W$FZ9ROYH/\`04<\TR"SE2619#9:G,9%=E<S+X1LKM92X(8R+=7U[<JY
M.X7%Y=3`^9<3,_LWPZFF@U:R\B62'R[W6X8_*=H]D-K<ZC]FB381MCM_(@\A
M!A8O)B\L+Y:;2B@#]"_C7))#X^_8GUZ%WAUWQ-JMQIWB36HF:/5O$&GZ?XT\
M)PV%CK>HH1>:K9V,+O%9VU_-<06T3M'"B*Q!_N;\-^(O$%K^SUI"VVNZQ;KH
MWP]N-2T=8-3O85TK4;;0IWM[_31'.HL;VW=$>&ZM?*GB9%:.12H(**_T0X._
MY,/P#_U^XE_]5M,_S@^E?_R<[A?_`+`J'_JSPQ_`_P#ML:KJFH?$_P`4R:AJ
M5_?2/X@F1Y+R\N+EW3S]2;:[S2.S+N@@;:21F&(XS&F/@#6=5U/7+K3KG6M2
MO]8N(E_L2*XU2\N-0GCT;0]>TGP_HND1RW<DTB:9I&@,VAZ78*PM=/TAFTVT
MBALB8***_P`\9_'+_%+\V?Z,87_=L/\`]>*/_IN)Y9_;&K?]!34?_`VY_P#C
MM%%%2;G_V0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V%L>2YJ<&<`````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3`P-#4`,3`T,3<S-C,P,3$`,#(R-#(R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/_8_^``$$I&248``0$```$`
M`0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!````````
M```!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!
M!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/D
MY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'
M"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!
M"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)
M2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*C
MI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S
M]/7V]_CY^O_:``P#`0`"$0,1`#\`_%KP/\1)M,AL?#WQGT+4I_"5L%%SXCTZ
MVN[\6%C.RB&XDO(2[6UI&88Y8KAPUP#$=NW9S^A?PZU30M&MSJWP8^*O@[Q[
MIEP+.XFTS5M8MM-O[_#$>5K>C:JEJUQ<6\,KP:?K>G7/]JS![E+O3=95;=;/
MY1\`?!WP;\*=+74/C+^W[X.\"(K)+<:7KWA*&XBDMIDW2Q)8M<S37[OO@\Z&
M&'>3Y0;DICZY\/\`[1G_``3:L/"=KI6D^/?@Y\6_B9IEW&;KQ-HO@?5?!&I:
MC!$':!)++4;2-+FXD)9D>"XF#&++JF8L_P`0<8Y>\=&IBL@RK-\SPTJ\O:?V
M/E.88K)JU23UJ5J&8Y/1I4YSJMTW7PF9/EE=<K<73?\`I+DO%]'"?5<ISS,Z
M>!QKJ*BLKS;$Y)5S.G"F[PC4Q."S&M"K3C*,/9NM&-2E!4X-^Y8]V\1Z7\#?
MB!\,IY/$W@:[\,^/[=+N>PTIOM>A7#W\ET@.H:!K\*V>BWEC,T47VM)["TN;
MF,VBWT#`0FOSSU7]C^5_#^L_%/XD^./`OPFL[6WOIK>^T;Q'I$OBVYM(II#;
M'6;`ZEI7A^6-XT0>1#>6MY.IG"P7;*!%_5O^R5J'[/GQQ^"J:[X:T/09DL;>
M&VGMA90*;*2VACG#268F@5R9@$<!',PE;S`,_-_*7_P5,\%>+X/VUX_#'B']
MF/QO\6O@7H^A-I>A>$O#/B-/ACH'B74==2ZN&\5#6K.6[AU+6;.\G@^SB\LY
MVCCTQ+>1PKQ@+@7(<\6.PU!YWALDR_,Z6+K8O&8CZIB*N6K`8C#2Q&7T\-F6
M(P^$A7Q59S@X8FI4I*,*E>5#$/DH5/$S_P`0XTL+G&#P^0YACLQR_'X>.&RZ
MO3KXM8RMBVHT<5"6$PN,Q5*A2IRI5XU,+0J<].=.G*=*FZE6GT/P'_X*`_"'
MX.VUAX?OM?\`V<?B#IVFH+5O$&FZ;?>$]>6%)#`TFKP#3]1NIY$\U3>7:PR6
MB2^4T4\WF;E_72^\&>!_VL_A8NM+X=T72XK[3S-X>UO1Y9KF2\C\H26S/=WE
MG9W+PHSJ8YA!$)T=0V[RD"_A?_P3[_X(]?&#XR:C<+\:M+L/@=^SM-XGU+6]
M?:WATZ[^,7C32H6M;6W\!:OXS>&#4(_"L!TY9+K2M.6TTN^N+V:[O+:YF,+1
M_P!1]EX:\)>$;32/!GPTTJ#3O!'A6PL_#?AZVM-R0I8:9%':(DDGR+<2NT!,
MS*H4MC&>W-XCY)PCE6(P=?AC.L3C\RCB95\95C+!.@Y.//'V4L#"EA.?VCC*
MHL)"%*#YZ?*K21Y7!O%O&&9RK8CB/AZAP]B:5/"3PE*%3-)XCV+E.4Y8ZEF.
M(;C#$PE3A1I5,,G+#PJ3C&G#V4I_SF:I^PI?1:GJ,4FBPRR1W]W&\K:;`[2N
MEQ(K2,YB)8NP+%B26)R3DT5_2V?#NE2$R2Z#9M*Y+R,;>W8M(W+L6*9)+$DD
M\D\FBOEUQWQNDDL6K))*\%>RY4NF^WX;Z7_2?[<R!ZRR;+')V<GR-7;Y+OYM
MO[S_`#DK;X>W_B/1O&FB^*/AK\7?%7QGU;6-,O\`PEX[T0RZ_P"'7TV,2KJ.
MBZFE]$DYCF6YM7@OK>;S;`0.ZF,LA/MGA_\`9J\76NF>%;CQU9Z7X6TW0]4U
M77]&\*Z5;3?VE:WNJQ:997(U?Q#<E]4N8FETFRN4M);A[>UFFNFA`:>0GZ*^
M#OC_`,4>%K*'4-#OIM:T35=/2:V@MG68V\%U#M1EADW//N&^(+`R^0L(1\JZ
M`>RR3:CXQMGGA=&GCC@%W;W#RV=XB$RO%$();<ED5ED(19"B$9PN0:_L/-.+
MLVPF*5%4,MP6"IMP>+^N5'55>,%14*6%?*J&B]G-)R51.516YG;^7>$_"3(,
MTP\<UKXO-,VS.JJ;A@9OV5%.I5CBXU:]6C!RS.H^955.<X<DN64H\T)1?[#?
M\$2_B7J.D>(O$'P]NM4F>TNK%M3"M<RD/+#.+>3R]\F^1581;V8<X2OZ#OB]
M\*M$\4Z)-J,FF6FI:WID$TEF$L[>8>2TAG>VR8F(65L,4!`9MS$$DU_*%_P3
M4UYO`W[1>BZA>I>0V^IV>K:*VZ(R1*\D;2QAE7(D02IYFUU`60*X&>1_71X8
MO/'OB/P_I=SH5M#I$%S<6;SZEJ\`D>[M()(&G,<4H+$W,0D2-^RM(`<,:_#,
M^CEU?-\_P$J4JU/&5:.8TZ=&E[:U;'PC>K>$7&$(5TW-[O=.ZN?H&<X?'9;#
MAK-L/66"Q"RZC@:D\16EAW*I@:M>@Z<OM3;PZA32U<N1)]&?FC?>)_%MYJ;^
M'K2WN-'LDWP7,3B2.8L&`=4`(VKE<D#`.X'!QFOKOX,_"A=9L(GOYY1%''&4
M=@5(*F9PN3U"LS,H'"L[D#+L3W/Q!^"6EZ[XJAU71-0M]+U]G+74$D@2QNG:
M260.L$:D`[-_GA0N1Y`?.Q-O2^"-0UKP=+:>%O$]D^F37#7$NEW$S)##JEHA
M`:ZM]S_:9(=SKM*@*H<8ZBOS?!9/B,%FT?[6H*6"@_94JL%SX;GD_=C*45RP
MDN973LU/W=[GJYEQ%0S#(Z,<AC'"X^K1C7Q>&E24*T(\E.=2I3NVY1J\GM%K
M9PE&5HI)*"3X<6\<CQ@L0CL@)4$D*Q4$G'?%%>Q%XF);*'<=V1-<X.><C+=#
M17U;RC+KO]S#?^:7>/GY?@K]3\]6>XU))UY75D]([Z7_`%_I,_S2O^"?/BK3
M-6\3CX.>,&GT[5M,NYM0TFWO)&B-]I)N!'>6UI-(05&FES<6=DA"&"Y'E(%7
M-?UF6GA#X>>$/@5XDUB/P;H&LWNGZ%-_9DUQH.F:G=2R_9]XNHB]K+<1>9%"
MA8Q%6#%V)RV:_C[U?P9+_P`)C!XY\!ZG<^'O%_AO4K#6-#U*"'?YP2./*70&
MT'3)U<V%[;,V(HQ;J(RB8']-'[#O[6?AWXL>!)_"'B]/['\:Z99MI7B/P[?J
MD02Z6TEC:XL'W+#<Z5?+NDM7PY*[XW`"@'[CQ^X(X@PU7`\4X7"XRME%*4GF
MF'I.HJ.%KQC&4L0U1O4E2G&TI2=^6M)QNH)GF_1Q\<N%>)LCI<&//<#2S_"5
M*.,RZA4Q5"AC<;A<5+#S>#I>VJ0C6Q6%?M8>RIR3G"GRQ3D[/YG_`&:/C-H'
MP]^*6E:SXD^&UJVDWNH77VW6M/AO9-4M9)FGEBFLM/F)C1K1)!'(T1B\M)(U
M.5(`_H=NOV]-5UO4?#/A;X4>!;77+!-*L+=];UW5(4ELS+:I#]GT[PSIBM>7
M6HY<O&F\"*15+<S&OY,?VL=$^*_P=^*?_"9_#G7#=>'['Q*FK:IX.U"*TNO"
MNO:-,6^U:)J\<4;S65O>V?VF.VU"T426=RL3Y5_**_I9^Q__`,%6?V>_@1\,
MK_\`M#]ECQ%9_%6TU)M>\+ZK8:K::WIT3HT<[6BZM<D:Q-:01M#'$M[+</.3
M(JHOV8@_/5.'LTQ^%PO$7#F(C2P.<82E'&ULOG5Q&)HQP\:U?ZM4P\XRK.;@
MHM5*48TXQ3<VHIR/WO-L5PYF&95\IS+(<[SK/,IES91@JE7`8#)<=0S*$53Q
M5/'5,714/J^*M#%4*T'6E4G.E2I8J+5&O_1JOQ-UGX5?`#XH_M&_$KP[?:+X
M4^%_A+6_'WBFYU2UMD\9ZKH^B&UMK[2?"?A8SZ1"_B.[:[4Z'#K6OV\.ISK]
ME:PU&27-K^4__!.K3?VH/VDGN/VXOVG_`!QK][XA^*FO:B/AE\+H[J]MO`?P
MW^&VDW!LUM/#/AES]BTI)+ET-O<D7&HWD44=]<7TXN(MORUXL_:@_:;_`."S
M7QM\&?!R7PC_`,*<_9F\-:I9^(/%?A;1]1DU._UR>!X;V;6O$.II#;BV$MS;
M6SZ5IK27&R7[3*%B>U0G^E+P=X$\.>!]/\.^"O#=BFF^&?!GAW2?"NC:?#'$
MEM96.FVT:BV18E2-Q),7N9G"A9))<G<R$U[&9X2CALK>28:I/$OVF'6,Q-;$
M4:M2,HUJ.)5%4:,JE.A.M6I.M6Y*DJE*-'#0K*G4KU::_.LQPM7AG_A2S3#T
M<MX@SNGC5A,EAA\33AD^2U>6G.I*>,I4,3B,3BY1>'R^K/#X;#4\'0S.>%HU
M,/7R^M3]0AG'E18M(B/+3!:)"Q&T8+'NQ[GN<T5:$%P``-N`!CIT[=Z*QC@:
M=E^[GLNW]W_@_?\`=^8.I0;?N1W_`)I]X^?K]WEI_F<6BJJC:JKG&=H`SN))
MS@#.3USU[UUWA*^O=+\4:/>Z9>76G7GVRWA^UV-Q-:7/E2S()(O/MWCE\N0`
M!TW[7``8$`445_>'%G_).9I_V!5?_24?XV\`_P#)P^%O^Q]E7_JPHGZ5>(O^
M)F(1J/\`Q,!-H)247O\`I8E0QQN4D$_F!U+HCE6R"R*Q&5!'QMX#L+$>.[^V
M%E:"WMYYI((!;0B&"0&<B2&+9LC<%F(9%5AN;GDY**_A[A[_`)$.;?\`895_
M]*1_TI<#_P#([R?_`*]K_P!*H']4/_!+O0]%T[P+=WNGZ1I=C>7=W8R7=W9Z
M?:6UU=2,-15I+B>"%)9G8*`SR.S$``G`%?JWH;N][<;W9_\`2T3YF+?(CRE$
MY)^5"S%5Z*6;`&3117R.!_WO$?\`8=7_`/=4_'?&#_DM\Y_[`</_`.H^"/06
M9@S`,P`8@`$X`STZT445](?BI__9````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O86YG<GEB;WDN9VEF````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(P
M-0`Q,#0Q-S,V,S`Q,0`P,C,T-30`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA00!!`/<`````````,P``9@``F0``
MS```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9
M,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_
MS`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F
M,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,
MS#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S
M,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9
MS&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`
M,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EF
MS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_
M,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PS
MS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,
M,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`
MS/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9
M,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__
MS/____B_)```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"'Y!`$``-@`+```
M``!!`$$```C^`+$)'$BPH,&#"`566;ABQ<(J"2-*G"BQ2L.+#1E>A$BQHT>"
M&C%FM&)1Y,>3$C-6`2!R8\D5+!VN0$E3(,:'+44R!,`38\V/.JU8R;F19,^>
M%W].?$FTH="'.)'RG#I3*4*+3"^R'+I"Z%.M6F/"K&JUX,BL*G,BK1*(:Z!5
MJQR6-=NT94^H5@*Q6K62Y=M5>><.%(FT;M>\>JWM'5HE+RM6@00KS#A6+$R6
MC5<%NHPYD+7/BEF!5BP96TF++"W?M:*9LT//H!^/9D43*U1LAF\V]HH8KNC1
MP*VA1!O3LD.23/6*_AT<>+7GU:Q%/@F6*&O`&?\VWSXZ^N?I'T/^4F9HY7';
MQ]ZYJP<.WF-6UFS96@.<>+U]X*N&)\6V-S/DQL_=)^!W95T$%TFK0!?<8\S%
MMHILG\'%WEQ#:<8:=-4\!EAO#UISS8?7P)489(&\-9ID;'6((5R:K0(B*T*Y
MJ.%>\^D58A6K?$:;8`OEI>!H<($8"%8E%MD6CM^Q%J%@K#&(87HPYH7=6+R-
MQ990RT$VUUM/=JFCA20YE"-H))4)VWQ\;9E@EQA^V5:82)+96&-GPL6158&P
MZ25P>XT)FF^*C5;D7%6PHN>>#C*GV79"M?>3CX?^B-^;CC47I607KH@A9'[R
M":&E<)6&(W2`/?<88P^R"&J)`9)6FD+^+"YT:HQ#[L86@WN]V19LFKTZ4(]%
M]DGJ@_WA5=]>N?J*T%OHM1K;KO6%IIFCR@[$5Z/$.C>;A=5*5")O"W$)79]M
M=3L1M$4RUA6+R)E+D6,E7MG88;;=Z6Y"\`YYY%!?/71O1"5J!A5>R.TVU+\&
MT3>D2N3U6&]#"!.TV9QX/>252+V5B'!<_`KE%$-S8N07L;W>&W!:#H$L'ELC
M:NDN8##>AA-E-\W(K;O7.3JS2P;".*V]ROIFA4$AI;C7?MB4:2ZQR1;T$I(,
M,A1QC-&%ZG17*_!:(M(O!^P;M65FG2MJ+"&\*[;4XC960U/U9'9>:!_$=EA4
M3;VKU09QUG9EW1%C@_=!>P=.5M\1!;[WX*9!3+A`5AB.%$$8+VZ:X!9!OK93
MDF]&%58IOU0<XO=6.;!Q=(-N+E=.P;UU4SP!C;-85LQG46N7K^WZO7JG7!GE
MD@_F.%5R]9YW2ST*'U%.Q;\:$```.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+V%P92YJ<&<`````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`V,3``,3`T
M,3<S-C,P,3$`,#(R-#`P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R
M`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$
M`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"
ML<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=8
M65IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JR
ML[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY
M^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$
M`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)R
MT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H
M:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BY
MNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"
M$0,1`#\`XCXD?M>>*_BSX_B^$7[-OAS3[YO%WBF;PEX*U>%X8_$WC37+ZYAM
M+#5K!]<-A%X1TZ\B@CO94O3;RZ9:E=:\47UAIT&L6<?S-9W_`,?_`!-XJN]+
MUW3?$\>O:.'L[W4/%EE9:)+H1N=-CU"*'4&UJU,4`EL+G3]=-I=Z:^M3Z)"Q
MT>2SM[^[>Y^'OA5XYO9/&VK>-=-N[/4=<\%^';3QQX,\*Z5XQ2\E'B[P]XI\
M.?\`"+ZQ?W^C6MOJFBZ$KRV^IQW]Q_:&JS76J"VT?Q'86T?AJ/5?U<^%NI?$
MG4O@C8?$O7/"_BG7?B1XN\/>'-:C\/646LZWJSV.IZ-I%O;W?B+5+J'[=H]]
M=WUO+IZ:7#''KOB;5K3Q!JL6W4+C3S#\[2]FFW[*-Y2CRR<+RJ-13NW.*E>7
M)&247JU=I6;/JY3K5G>5:?NIMQC)*$(W2248724>:2;:?NZ)MM#=.DM].MUU
M#Q!XF\57.I6<5L+'2M*L[6'P_HUUXF\606RP'5[K3+F*\C@M[33='LGAT2+5
M[:ZUB\UVZUS2FO-.LK/M_A]^U&_PZE\/2^`_''C+X4>(I(8KW3WU74KW6M#&
MDOI,HTBZU2TU22?1M<M+B6.VGU;3]1U.^@U2*RL[)Q::[9.A\/\`",7QRFU"
M]\1>(O"/B'PYH?A?2;+4;Z2'3_\`A&[CQ#I=K=:)XBMM*TY]5TN[U'Q%?N;J
M[OI_"FGZMI4-YIES>VXN-!35-3N-6\)UOQ?X@^*%\R^*X;L7]C=S1:<FA^%I
M;G4#*_[F]TR2U@O;*)(X[32I-2MI]0-Q>3);7%NUY;PQ6]N=T[6YKK5?#9M:
MQBFU&[LW)/33DL[JZ3AR>BA=O6W/S1YK:NTI-6:46E?7G37*TKK^M;]CO_@I
M;X?^*]QI/PJ^,\6EZ)XCU263P]X>\;6$,FE^&O$]Y;PS64GA^_LTO=572?$Y
MN(H+&`V^HI9ZMJ5Z-.M[+2-1CL;+5?T4N;?3AJ$B6%S>K#/`"TTR+B]A11+Y
M4TKQ*&:2027-K`0LSW"QF%/.BDMV_@[^'6LZ8_C+PW\/=2@!BL[S4=5EUQ]7
MM-<\+_\`"#%;S[?JFJZ9=W5C:IINBVU_XD)UBY#:?8+J?B2SB\"ZIXHU&XMK
MK]M_V./^"J.A_#'4=-_9[^+7Q,\/?&[P(D^E>`O!WQ>\.?V]<>)/`6I3:7X>
MT'4;7Q:_B?P]HYUKP]_:%_+JL6MZ==:Y'!:PZS:Q^(_$8TVUM7RE%5+*G5<9
M)M/D4;[1<DD^:,FHM2<4GS)W6D=8<6O>2=-.RDKZ-MKWDI15M4UMRZ):-I/^
M@@!"`7MKO>0"^+2W<;C][#21-(PSG#2,SMU=BQ))1;>)TU6W@U2RUS4;NSU*
M&*_M+K3M22?3[FVO$6X@N+&:WE-O-9S12));2P$PR0,CQ'85HKD]FWKRU===
M*5^W53:?75-IZ:ZZ/EDG\+6W1_W/\G]Q_EE?LS_'V/\`9\_:&TWQK;66EZKX
M=OY1X1\7/+-J<$5]HM]KVE:I=:_%>R:WJE\DVG:WI&F:VKVVJP'5K#3&LFN-
M,?4Y[NW_`%0_:?U?]HS7_'<'A/X/ZY?>$-"A2PO+"UT^_P!=_M:PTB&^?3FN
M;X6+VUI<ZOI]Q;Z?.L6IFPT=YH)_->,3S&7\-_A;)8W'Q7^',WB&\>+3)_B%
MX0DUS4)G\R2.QE\2:>VIWDLDJ3EW2W:>=WDCFW,"SI)DJW];GA']F)=6U:Z\
M>_%+PWX+?1=6\'FT\._#+5=2NIK6YT2*,ZKX6UK6-(U"XCL]&L!+X6AN='\)
M-:Z;:_V5/<^)HM5&FVUI#J_=[-R481;YN5*[MK:UG-V<G%OI&+NWMRWM-&7-
M&=]%SJ22;32;5U%+1-I+66UFTW+?\BM-_:9_;$^#BZ=KEOXEUOQ3?:;X1B:#
M0=9.L:C::IHJWMWK-HVJ26NBB3Q#K7]HW^L7>F7<NF^&K&?39ELXY-@O=)O>
MJTK]K6U^)-C?O\4OA4EKXWU5+XMXB>_U*RUM;'3M3&HROXBO9+>\_M34--C:
MQ-MX>\5W.MZ;X>T&VM](TW0U@T!9K']&OBA\+/$>JZ&B?%3X86?AW5+'0K:Q
MUWXEZ-K)UF]UWQ';76G0VJV'A[2_AKI,OA%;C4?$$=Q</<:E9^$=$AM)-!U"
MVUQMPA_(S6="']K^(+1+'4;"VDDGM#IMWMBDL%FNVTYK2!);5+.&XN6N;F>:
MZ^Q6K?VG;W5\\$AOEMM(QDZD$N6;J14M5/F::4;I*+;Z<KYH16J7FEK+W+*2
MY;QTLDI)\T(RYDUH]URRDTM4M4;_`.U)XAU[66_MCX3:WJ=AK?CR^?PU>ZA'
MXHU"TN_LM[<74^OZ_.J:7:QV&@2:>NG6T6DM/+)!9W=AJ&BM<WWA_5+30X_"
MS^)OA)X<\3V&KZM>:9>:QX7>76HHVT9KW6G6PU"'2K77]+6XL889WU*=8GGU
M&TBUO3SJMY?66GSS36NES?'?Q3^._B3PSX\FTWPU!I=P/!^G6=HUWXA@>XN'
MU200M?W,5H]Y86FHEY+BQ62VNM)F)DL'O/L45O#(R]IJWCS4_$$-[XBUBXOM
M--I8^)I;R:WN-)\02:]-I]A"=6T&UU'60MM8ZIIMEX<GU70F:RO[2XT^/6;'
M6/#>GZG!9PWL3;52,DD[J?LKRO*4G3IIS;?-[RM*4(JU_<4=79S%J2DVY*2<
M.=15H*/-*Z5K63;Y6[Z>\Y7T:^N;+]KSXL:!9VFA:9\6/$]KINBVT&DZ?;6F
MIZPMK;V.G1)9VD%LMG.]HMO#!#''"MJ[VPC51`S1;22OR_O_`!UXH@OKR'3#
MX/NM-AN[B+3[J_\`$.AO?7-C',Z6EQ>-;Z[IL#7<T`CDN&@TZPA:9G,5E:H5
M@C*PMB7JGA]=5=QOK:U^:TKZK=7TU5[&JJP22Y\5HK:.=M.UM+>FG8[+X:?!
M/PYJ4BW^NO+K6GOI\]T%E>>PLF\^VMS9P02Z+?SFYU&.XGCE$D.L/8/:F2;R
MKB*%7F_K<^-VI>(]$E^&_BSPKXPT3Q)X.B^!WPHO?#CZOK-CIL?BF/1_`_AE
M=/T#3KYM)U#P5J3+<Z-:Z=:V>M^,_"]A<W%GJ\%QX@B?0K6-?QV^'W_!*']L
M.%O'OB/Q_:>"OAIK?PW\'ZWXC7P!X[UCQEJ$TNIOIFNZ\CZ9>>&/`?CG3H+]
MO#,E_I%^MQJ_AV^AU;3I?#>FZ5J5Y8SZ;X<_2;X=ZQXZ/@K0?V</'RW6IZS\
M/+?Q?I/PZ^(?@JYC\5Z7XE\(3Z;<>,6\,WKWVH1:A->Z1:6J:SH_@S6_[)\4
M:/X7UWP_H&L_#\SZ]8QUHO:5*,Y.O&,KIJ;E!KWKQ<.6Z@O>LG&R<M;.\DUI
M0BJ=6*]A-QE%>[RRB].62ES6<M4VT]5%I-KW;/Q[Q+\5?%WQ`\36'AS6K:[T
M#5/$D\$6D:78WFG>-H;6SGAFLM/M;GQMH%]K'@ZPU%-71+W^SM5N,1W4\FZP
MOK&ZL-3A^&?VZ_$'A?X1_$ZVU'>\\]OX`\+RZG:26?\`9IF\0:@O_$NTY-/C
MMID&H3>%-,T'5KB2XN])O[Z]<ZMK6CV$\4TJ?>OAGXH+X7.AOX;\/>'&U.^T
M^ZUN/6=92.+POK?AG3KUKS4GM"FIZUJ7CJ9YKJ32;RQNM,TNSFFTO3[0>*]2
MMWL]0E^.?B[^P3/\<_B>_C.;QT(?A[\5X8=>O?''BO5;)_'_`(+.E7>K^'K+
M6[GP7I>C6:7VGV-Y;:^^J:'JDOA>P>]G7PPOB;2([CPYX@TF:4JBA&,ZT)1_
M=6=-WG%7YM5*=23M%)Q3O*"YDXO0TQ$(SO[*G/G<I.7/[L+)15U:,(^]*33D
MK1:<>6UVS\%+[7M:\1^(=5UZ[N5.K:I#J]Q>S);,Z-#)I=U'>0I##!<LBMIX
MEMEG=3Y((NKJ[A"37L?TKX;\11VWPSO!:ZM?1W\\?AS4;];::R#Z=#8ZI%/J
MFM,]KI5A)#'9Z5816&@Z-97_`(BTB.R\-6^D7UE'?VU]X<LOU?\`A_\`\$6?
M"!O]6\*_$7]HR[TC5I/".IZW#83^")OAU?1/!\0O!WA$?9[K7[C6](\6+9W>
MIZ-+=:!=:YH\DC:W#J&@+/:V%WKD_P!E^!O^"+7[*^D:[HV@?%?XE?M(7FC:
M&OB:U^(MMX#N/AKJ$W@W3I/#%W9WF@>*]0T*R\8MH/B:WN?"5I?:EJ7B2Q;P
M9I6@R:=:Z=K#3W>@CP_M4G":2@U[K26BUC9V4=4WS6<+*]GNM4I<M/"5XWE.
M#ZM^\FXR7*VI).7*TFI:I.2T6NW\N/\`PC?Q+3Y=(NM6?2E^73'M?%EO+:OI
MZ\636TBWUDLD#6PB,+BSM`\95A;0`^4A7]?FJ?\`!$?]AUM3U%K:[^,-Y;M?
MWC6]W?\`Q&\+B_NH3<2&*YO1!^Q5>P"[GC*RW(AO+N(3,_EW,Z;97*P]O+JJ
M%^K]C.6ON]5/7??K9/JC?^SJW\M9>7M$K;=/9Z;[=-NU_P!E/BKH^D:=>_%+
M4=/TO3K'4%A\)R+?6=C;6MXKZUHFDZEK#K=01).'U;4=>UV_U-@^;^]UK5KJ
MZ,L^HWDDWYD?'#P3X,T_PYK?Q'L/"/ABR^(<7Q1T6VB\>6F@:5;>,X[:#X9^
M.[R"W3Q1#:)KB00W=E9W442WPCCN;2VG11+!$R%%-?'2_P`<O_;CI?\``7_<
MM_Z33/SIMK.TO?A5^V-+>6MM=R^#_P!HQI_"4ES!%/)X6FU6^^),^J3>''E5
MVT274IH()K^33#:O>2PQ27!D>-"OT)\(K&R7XY?LUZ.MG:KI'C7X=_LH:CXR
MTM;>(:=XMU#Q%XH\6:9X@OO$UB$%MKUYKNFJNGZQ<ZK%=S:G8@6EZ\]N!'11
M44?X7_;R_P#3E04OXE/TC_Z1$_5'P196=GX8L;2SM+:UM)7^"&I2VMM!%!;R
MZCJWPUTSQ+JE_)!$B1/>ZEXBO;S7]0NF4SWFM7=SJMS))?3RSO%\0?#GAZPM
MO'WB*QT'1;/Q!X8U_4U\-:[::78V^L>'EOKOX)3WJZ'J<,"7NDK>3(DUT+">
MW%Q*BR3!W4$%%<D_@G_UZG_Z;Q!Z#VI?XZ/YX0^;IO$7B"YFFN+C7=9N+BXE
MDFGGFU.]EFFFE<R2S32R3L\DLCLSR2.S.[L68DDFBBBN5[_-?G`[H[+T7Y'_
MV0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O874N:G!G````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(S-0`Q,#0Q-S,V,S`Q,0`P
M,C(R-3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!
M_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($
M`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R
M@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ
M<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W
M``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8
M&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#_`#_Z
M*_HO/[`7["?Q5^&BZ1X?\._M)?L^_&S2]-O7;7_$.B^)M=\*:C+;6-[<J?&G
MP?\`$NDKXY\/W/GV4UO/K'PG^('QDT6PAAEU37]%T"T$EO;_`#MIG_!(?XA>
M$?`?CKQY\9]&\6:-X:T[X@_#/P7\/?'7A_4M-O/A[\0--\:^'?C+KFKZSX<U
MY-$NS>WFF-\-='ACL[M=/N](_MBY@U_1?MC6]O!YN/S?`99E^-S''U_JM'+J
M*Q&,I5J=2.)HT755'VD:/+>O34[VJ8=U:<HQE*$Y1LW]?DW`W$7$&=93D.38
M:CF&-SS%?4\LJ4,12^J8C%.A]8C0EB9N,,-5E3Y?W6*5"I3E*,*T*<KI?BS1
M7[]?M.?\$2?&'@7]H+Q)X'^`ME\1M:^"6KZ)\,_&OP;^*OQ6U?P7X9TWQOX0
M^)O@;PUXKT^&P\2:QIGP_P!#\;^(M*O]9U+0M6T_P#IVH7L%_HNH6D6DS7%L
M?/9\5/\`@@YXY^`'PBOOC'^T+^T7X0^"OAH&1M#N?''@#Q%X<M_$4L.)[C0?
M#VA^-]7\#_&#Q=XHCL2MQ!:^!_@WXHT*Y>YT]9?$5E%=RS6?0\=@6L)[/&X;
M$5<91P^(I87"U5B\9&EBHQE1E7PN'56OAU)35W5A"*M-M\L)M<-3A3B"BL5.
MOEE?#X?!XC&86KC<7*E@\#/$8!R6+HT,9BZE##XFK2LKTZ%2I4;G3C&#G5IQ
ME^!%%>Z^&/@C>^*M2-GIFIW5Q;RW#VEA-'H[FZOIY',-FL-E'?3.\DDKPF2W
MCDD<LPM89'F=&KU7QQ^Q9\1OAYK5YX8\9#6?!WBJP$+WGAGQSX+USP=KMHD\
M8EB:\TK5F&H6OFH0]N9;41SQE9$DV,&KZ2AP[G&)BI4,&ZG,I.,57PT:DHQM
M>4*<JT9SBF[.4(R2:LVF?-.K!7NW9;M1DTMMVE;6ZMKK?2Y\:T5]+_\`#,GB
M;_H8]"_[]ZA_\CT5T?ZI\0_]"NO_`.!T/_EOG^?9D^WI?SK[I?Y>?Y]F?U'^
M&?A79^,+&SUWXJ^//VVO@+X)U;3&U;P]9_&_Q?H#_$7Q;8AO-_M#PK\*M+N[
MOQ3=:!&JVTMSXN\1V/A/PC;1Q3W]QKD-I;B0=/H^B_LV_$7X-_'31?@M^T=\
M>_B+X[^"WA7PY\7M1\!^-=>TCQ9X*U'P<?B1X/\`AC>ZK)J'AJ>]\(VGB+0[
M;XC:)J,<'A/Q+XXTNVT]=2M9M<@NHWAG_G[\5_&;XL?%:*\N_B+\0O$_B^36
M;R34M:;5[Y9&\1:D[V\AU'Q+-#%;W'B>_MKBV!L[KQ"U_-I[JXL60,;B?JO@
MI\2/C+X`\0Z]I'P2U#7X?$?Q9\*7?PEUO0?#>CIK^I^-O#/B/6="U>;PA%I`
ML-1N[U[_`%[P[X?O[6/3(%U,:CIED]G,CJ5?X7-_`W+<XR+-H*5'"8_%8#$+
M+:,,7C7@*&*G23P]?%8BM*I7JPI349J,:5.FW=U*4X\L(_T1PA](OB7ACB7A
M_'U*]3&Y;@,TP%7-JM3+LJ_M+%Y72Q5.>883!TJ5*AAL-4Q>&]K0]HZLZT>9
M.EB:,N><_P"KKX):M_PC'[/OP)\2>,O^"N7Q%_9N\0_$GPW\25^%GP<\367B
MB\\)(OPC\02^#)?!7A3QKXC^*7AGX8>&-5N;.7PS_8&FZWJW@]1:>(X-/T^"
M2&:9G_G;_P""E7Q_^+WQ<^(2^&?'WQ9^(_Q1U-K2+1['5?B3X%\)Z%?:-HMC
M<ZA)JEK;ZUI'BKQ1J3*+A%2S6TNKKP]KVD:I+J6EZQ=P7,?G_,W[6_C[]IVR
M\.?##X(_M`:;XN\.:;X&TK5O%?PZ\+^+O!MKX8NM+T?XPV'A+QKJ6IVEY+I%
MEK.KVWBC3D\+ZH(M1O+^+2E9(K)-+N)M2MI_&O![Z]J&FZ,->UG6=3@T2P^Q
MZ)9:GJ5]>6NAZ8\[7$.G:79W4OEZ;;O.6N9(;6,0LR(/NE0.GP]\)<%D4LBJ
M5<55Q&;87`T:>;3PN;9IB\IK5J<5%UL'3Q&)5%*2C2;_`-EA3BW5A&DH1BX^
M9XL>.69\<9AQ1A,+A\)1X:Q^;8K&9-'&<,\+Y?GV"P->O*K#`XO'Y;EJQE7D
MC5G!RGF%>M*<:5:IBJM7VDI_9GP__9%UJ7]E;5OVH]"^*WP&72O!?C)_"OB#
MX/3_`!3L=(_:(T>V:Z\-6ND>,+/X<:G;6%WKOAG5=6\2(B:AX:U/4[^U>QO+
MJ]T^"WM9Y+:S\?OVJ_V@/VE_^$%OOVA/BIXE^+&H?#/PI'X(\':YXQ>QU#Q'
M8^&89C=IIVI>)_L<6O>(F%R9;N34O$^I:QJ;W,]W<R7CSW=R\WSS;F.*!9&P
M&=F&2!DG)`4-QA3LS\S!0<DD#IYUXV\3R65NMM9L'U"\?[-:0`%@TK/&A0$$
M`^6)`9<X#R&*$D*SHO\`1D:='*\/+$8J6'Q-2C.I4P$_JE*G7P="K3C3CAX5
M%*3G)Q;ASQ]E*I&IR3BU=O\`GQU%-1C34J;G""KI5)2C4E&5^=QLN5?#RP?,
ME))ILZ-_%]@CLAEARC,I^:)>5)!^5[E6'(Z,JL.A`.117C__``KQI_W\UU?/
M+-^]E=+=I$>23YW99)2\KJS,2KR.[L"&=F8DDKS_`.T\[>JPL;=+U(7M[MKK
MFWVNO-]U<4*?\SZ?:]/+U_'Y]=8D-9VI&?\`CWB'*LIRJ*IX8`XR#M;&UEPR
MDJ03Z'\,_B9X@^#/Q!\'?%;PHVE)XE^'_B+2O%>A2:SX>\,^*;"+5=&O(KVQ
MF?0_&.C^(/#EY/#<11R63:EH]\EM>+;W<,0N8(77\R&UG6'SOU;4FRS.=U]=
M-EWQO<YE/S/M7<W5MHR3@5&^IZE(C1R:C?.CJR.CW=PR.C`JRLK2$,K`D,I!
M!!((P:^)EQ=2E1=&6`E-2I.E)2K1Y9)PY)*4?9OW9)M.-WII?6YV*C)24E*S
M3335[IIW33[IJZ?<_3K]MO\`;C^('[=W[0MU\;?C=-X/T'5+N*#2M/TGP]9K
MI^F:1X<M[^[NX+2%M0GNM5NDGN;J\O+A[NZDLTU.^U*[L;'3HKN:T'`Z3XV\
M#16\<:^*_#<3R`L5?6-.A"*BGRTR\Z*@6-05C8A@[%``S;*_/6BO.R[B6IEB
M<</@</[/EC",92FG"$5913C962O]GK=W*K477<Y5:DI3G)SG/2\I/5M]-];*
MWJ?I/<>+?#HB62#6])N!(F;<PZC9RQLI7<DA9+EE$;E@YVN=V\F,$9(^:KWX
MI^'HO%?V^^2_U2TM(F2T;3EMI`K.21(S7%TD<LS*\C.ZLP1WB)/F0-"GS;16
M^8<7XW&^Q]G0I8?V515+<SJQDU;E3C*,5:+3:3YMU:S5WG3PL*=[R<K];6_5
MZ'V6O[1'@D*H_LGQ.N%`VK9:257``VJ?[:7Y1T'RKP!\HZ45\:45'^N6=_SX
M;_PGCY>?]7]+'U.CVE_X$PHHHKY4Z@HHHH`****`"BBB@#__V0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)A8GDN9VEF
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-#<`,3`T,3<S-C,P,3$`
M,#(R-30U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y81T`*@#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`
M,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`
MS```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S
M`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\S
MF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S
M_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F
M9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9F
MS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9
M,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9
MF9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,
M``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,
M9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,
M_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_
M,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__
MS`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````A^00!``#8`"P`````'0`J```(_@"Q"1Q(
M4."*@@@3$CPX<`7#A@H5/L0&`,!"`!,C&G1HT")$C0XY-F0X,6-$C!^QE329
M<`5*E1L7:BP8\J`5@R-GML0)LZ=.A`=)JF3YTR'&)RIJBBSJ4`^@4L]6K8I:
MBA0@/4^(CM0S]9G7KV"?E=)S4V(54F'3AAUK<@574FC5AB4%=96>DE:F8HTK
MURLI/7'O#JPRU2Z@KE[UZ($Z=W'4*@;C_DU;905?L(``^3U8Y6OFM%<O?YT<
MM:EGS7W5<O7Z!(">TZE5QW7YVNOGV&$_KW+8V6]MW%\!/R.E`MN3KF.!CZX-
M*"CJ9\*!CPT\T`ICTK'_2H8\<+7AU'\!Q5LEQ;UA%<7A24F%:_6J\%+GL])<
M`:@*U/"*G<)%;#=\68'HZ7$68G+]1=A5$UFQ&"DKJ/"$?J5$"-=5\EEGU7_8
M*/C74!4I9=1+5@""H4!/8.B0%5>DF&(75ZQ0XD\J57%>(*TD4N.-7>3W4Q69
MZ4%C(D`"V4H79XTUDV6/=1%DD(C($%=S&A%FFQ4V!CFD%:-IA4UO8EF!R)*M
M7/$;E!%9Y]5N5W@A"")L*NB5D3/E-9R'#AT'W4]6J*>'1(O!N&5Y?@8$`#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O8F%R8F%R:6%N+FIP9P``````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,3$T-P`Q,#0Q-S,V,S`Q,0`P,C,U-C(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#[E\7_`+1OB?X60^'_``/\2O[.\/:MI$^J
MZ-IJV.N6>JVUZVDFVTZ_DM+B::UEO-(F^SPG3M02VM;@(81<V-FVXU\@?M#?
M\%</AA\'_!%_)-=VVH^(8M+U.?3].T>]M[S6+^[AMT::*^GTV246*W4]PFE6
M\>J3;+:5Y--LS<)9I;M]#?&+]G;X=?M1^"?&>A^)8]<@UDWNOZKH&M^&)8X?
M$&AS:>[P0:[::S<P.^G06.+0W4$LUR]_"7BN8KZ+[1(/XZ/VX_V8_CK^R?\`
M&SP+\+?%-AIWBJ?QOXITW7OA%XNM;W0IM.^)>G:7K7]DZ58:Q:Z?=Q6&G7,/
MB'4;.QUNUU6/28H_/2^FL].@EDFD_%\ER7!9WBWA<17C)0IXJ5?"QE2G*MAZ
M*4I\_M)<BA'2,TI*M)2:C&5VS^NE+)<)E>*S7$4L73Q6`6'5.A+W<+5Q%>K&
MC3GRP?MJBJ-MK25.*]V7*VD]G]IG]K/XU_M*:E\5/'GQ"U^5_"_PW.B:9H?@
M73W+^#M/\:>.4N%L]&N=*:0:3XAO?#&C:9KVHZQ_:%CJW]H:[H-K+<PV=K=3
MV<?R58_#?5O$'PW\:?$?QC>W>BOH-]I,&GQ:Y;PB\\57&L13?;H[)II!<VSP
M11VE[>WER]QI<NG-+/IYGDLY;9?IW]I3PHFJ_$#XJ6VA>(/"5Y\/Y_C%X:UK
MQ+JWA_6K'3=&USXN2_#JWF^(7A#P(->GDOSI%A-I_C73OA1J/B'38/!^IQV&
MM:/I6JRZIJNCZ#J?G'[6&K>%-<\%?##PGX+\0VOBU_AWI;Z!#K=E9^(_"6IZ
MUX9WZC/IEK\4OAWXJ4WGA_XF^&9V&E/J&G:[X@\,ZWX>CLI+75[TI`S?M>3P
MP&6U,-EV#6%P&!4I553HTX4*6'P^&I494LO3Y%*#QRJN$VFJE*47.<H/EO\`
M*X[`8JG1JXRME]7$XI85RA&G2ITXQGBJ\Y*HHQY)NM"@J7+0H1<JD;SA2E&[
M7P#//"Q9&6Z(VA;="%DB0,)$F$F^-2T4PD=%.$+HQ><R&28M^[?_``3A_:SU
M/Q[8ZC\#/B1JVIZWXHT&QD\0^`_%>M7_`-L;4?"EDMK!J/@GQ-J%Q*;B:]T;
M45T^Z\)Z[>32SRZ7<:AH=_=I]C\/P'\)KC3+BW=%N$,0E("!D.XQ`#S)BL(<
M&*)R(W<-N)RP&W&?8OAC+\2OAQ<:?\</!US;:;-X5O)KG3FDO8);NZLI)#8:
MV;KP]-*QUKPD]K--H_B<3JVFWNFWFH6$L;KOG@^TR_.O]7\9A,PI8BE2G*M"
ME)8B<I4L9"6DL-6UDI1D_?2JM4TXI\VQ^=4<HS+-:F,P-++L=BUA\'B,;B50
MPU><\!@\%&D\1B\3&G'GITJ?M8:5K*;GRP4VFE_7!%JMND4:":)`D:*$.GV[
M%0J@!2TA\PE<8R_SG&6^;-%?DAIW_!4'PA)I]A)J7PHU]-1DLK5[]-.\3:"^
MGI>M!&UTMB^IZ)=ZD]FLYD%L^H75S?-`$-W<33F21BOV'_B(&6=:CB]+QY,7
MHWR76E*VEVM-.W0\5<*9AIK2Z?\`+W`_W?\`IY;I^"\S^L']G#_@H#^PG^S_
M`.!/$7BCXZ_M#>`-.U6;P+';Z;H>@^(;3Q1XFU:\U"VUA[R"TT;0EU!(+J6=
M[E8WU%YM4N[R5;2+2G:WEL[7^3'_`(*I_MD_!G]N'XV>![SX46WBI+WPEKEU
MX-^&]WJ=G8>$_#^GZ5XDUZVGO)O$6MZUK6H:OJ:/KT\>JZ5=FR\"QV']IWVI
M:R\TCZ;INA?D#<>-/$=RHM[?5$MXY+D7,%[Y%C+?QNM^;@3K?"TNM3#K(4CC
MBMI+*6YR\5TC0H8(.-DF:2=9(Y6N6EEB,<K0.[O/(RJLDAEN5N6>1I&,CM>(
MLLLGF2.TX#S?R[PYP7E6085<M26-S*$L7.&/G"-%<V-5I^TY5"4E%J.DDX)*
M\8W9^A9GG4,7FE;$*EB'AJU;"3JX2I->Q4,+)2ITJ$'+2+]Z[DXN4W&4G*R:
M_J^^!O\`P3A_X)^:9\'?"_Q*_:(_;MTOQM_:M@NH3_"[X&:%H$-E9Z3X=DLM
M;U;1OB5=ZGK>I_%V'2;NRTJ>:\UCPQ8^`A:Z6+'Q%X:\=7&H3L]A\$_&KP%^
MQK\,/C5\0?"?P=D^,?QV\-^!M:-GK?Q)U_5_A7X@^&=E!+HVFZU9VO@KQMI.
M@1?VK>:8)[U;CQ1XMU_1]"L;;1KO4GC\=:E+"]S^@7_!-#X3?LY3^$_A)^V?
MXZ_:RT[PE^T1XQ_9R_:#,_P\^(LFCZ?XIUCXCV/A/XE?!^3XM:A\:?$FJ#QA
MJ7P^5M5T";1M`U[3+RPUSXK1Z?X;\+76J^#O`^N/HNO^Q-\4/^"?FKZUX;^"
MUG^P9^RIK7Q5\-_L_P"IZK'XXU^W\5:[K7@WX@^"KOPY::7XN\>^&O$EYH7A
M+XM>,M?DU@^,;W2?"DESK;Z9I$NBZ?XMU$W`L](_&WC<9A\;F.'EA\UQ<Z4I
MXG'YM*#KX+#UN:I4Q>.Q\,ODUA:45"A1PM-4H0:ER2I2J6Y?W[#9ACL53H9W
M+'9SG&`E1H9;@LJAC:&35L%AXX1UL!@LOP.-P>#P=6C2E%87%9A2C*M%\TEC
M*TZ\JLOYFOC7\(/%/@81:GJ_A3QCX/TWQ!IND>,?#^C^-_#ESX=\23_#SQ7I
MMOJ_P_\`&$D`L;%+FT\4:7%<7EIK&F)!I6KR!=6T^VMH+^*UCATG5FM/AS!)
M%#;#2X/A]>Z7=RB1'NH=7F\3ZJ-+L=);=YZ22W%_>IJ]E+%(JV#V4\TC!K=%
M^Q?VO?%'Q!U3]I7XC:+\7=`NO#6J7^C:7?6VB?VL/$6B16/C'3[;QUH7B#P7
MJ<4>E6EYX+^(MKKUCXFTK4]/\.>%/MRZB\_B;PEI/C:7Q5?ZQ^;OB:PO]`?4
M_#,%Y-<:+=7-GJT4;)M61X`9$26(J`)K<7#Q2;%GFC*>6"[C:O[!A\//,</@
M<MQ6)P]5X>.%S:EB:7-*A6P]=5$J<%)1DY494W%NI"-:3UDF['Y]CL7'(8X_
MBW*\+7A2S?`YCD6882,6Z^$S#"5,/6HK%QQ,JE5Y=F=2C*E5IP=14Y1ASJ$.
M9KEHX[Q8XUC-JT:H@1BNF$L@4!6S-"LW*X/[U1)_?`;(HH$L@`'G:@<`#*R3
MA3CC*AI%8+Z!E5L=0#D45]L_8-[:-_S-Z>[UMYO^D?C*C-)).5DDE:L[:<J7
M_+S;;[V:LM^)]HMUNLP1W,)+11`*AB,7"0/*\4152;V02/)"TQA"NV'9C6TH
M\J,BX69E^TM:D%8MJ[H\$W$APD:&1G#QQ!E.TE1M(]S\$_!'XJ_$B^BT_P"'
MWPQ\1^)WN+BVLDFL-'26U\W4GCAT^W>]O&@2.:_GFCMDB6ZMRCI).(G)W/\`
MLI\"O^"'?Q[O/#]CKWQ;TJ[^&/B7Q!";[P\NMZ'HVHRV,3N8Y)$TZ/QEH\FG
M^(K;4L6:ZQXB>2QMKB10OAN_3R+Q?G\TXER/)J5>>,S#"PE0E*%:G[1U*D)1
M:A-2IT54JJ4).TH*#:;O:[L?64N&\RQ6*IT\3:A3J<T/:5\-7PW.^6$DZ<*E
M*G.K3G":E"O3C*A4YERU&AO_``17^*FC:M8?M'?L;:E!\+[7XA?'+X<ZG8_!
M67XT^!];^)'PQ\27-XVC:E\7?@WXV\)Z!?6.L:_I&H^&/`WACXE^"-)T;4])
MEMO$O@*]FLY=8N[F'PYJOTK^U?\`LR_LE_!3PEJ:>`/BE^S+^RUX^U5=(UGX
MA_#KPO\`'C2OV@_CQX`\9WMJ]P_AGX4^*['Q;H!L?#,=_9:?=:QJ^K_`W1_&
M=GJEC&R>-?#EO=36K_7'[.O_``2`^$'[,5[X:\=:UXEU#7_B58:SI_BRUU=;
MVSN=1\)>+=(ENKOPSKOA_5(H=*TVZN?!VJW=IXFT[2+/PVEE/KNGZ6GB"\UG
M2+66TN?NK2?BGX@NT\9VGA3_`()<_LU_&GXGZ/X@NC\7OBDUW^S#<7FO>*[+
M2+/5-)\;WUM\5KNY^).@Z=JGA2XT[5-)TO1M(UF/29UN+'PY%J\$9A3\"S'B
M')\UXCS+^R<5B\+@,3BJ6:IU:>'I5(YFZ4*=3%4H2P56DZ%65*C[*E*5-TTI
M\E&+K55+]#RQ5>'L)0Q.(I4,5*$'A,3"GBL/A4L"ZL)4X)SI^VA4IKF@JV!]
ME5Y90IUG4<8RE_*I^W]HVDO\7?AI'HWGVZG]E[]GR6RNM1N8[M7TJ[UCQY?Z
M!JFK:GI=K:02"Z\&6>E7\6HI#I^FZNEQ#)96VFVD^FZ=%^<GQ+\/0WTJ7>B&
M5K**>=[>2]C)D>V21KEQ/FYV0NRO`YMB\TP83PP7-TMK/+']^?MDZ/\`MB?M
M$_M8:MXD\3?LW>,O#?C7]H`6NO?#[PYH]J=8TOQ1\,O`;3>#](70?$FG[/#%
M[X/\,WNFWY\4:@NK6&@IKQM?[5MM,MK&PT\?K#^RO_P0\O/%:66I?'_4;CQM
MK9A9[GP1X+EOM'^&WAQFN7W1Z_XULQI_B#X@WMF95U*]?0+CPQX82^$\$3Z_
M&567[JKG.7\'83**-7%2QV-I86E&EAL%)XG%-R<IRC.,%4ITXN4Y)1Q,H1@[
MQARJ.GIRJX7.<OS=9E"6"PE6HZD:D/:4*5IU'*/-[7V-2K5III.24JDU*\I2
M3YC^3DV>J9.[2KMVR<NC2[&.>67#$;6/*X)&",$BBO[^H?\`@BU^R]:0Q6K?
M`'1W:VC2W9_^%=27>]H5$9;[7/K_`)]UN*D_:)OWLV?,D^=C12_XBQ1_Z)K,
MUMHZ^&O]G1^]YZ^K[*_Q']@9+TS^KY?\)J?:VOM-=H^NG<]@_P""<_P_\!P>
M`/VZ/$\'@GPC#XDT3]H/XWVNC>(8O#>C1ZYI%M%_PCMQ%;Z9JR60O[""*>_O
MIXX;6XBC2:]NY%4/<S,_TOXM`G^,'@H3#SA<1:E<7`E_>">>3XU^.8GGF#Y$
MLSQ6UO$\C[G:.WA0L5BC"E%?DGB%_P`C[B__`+*?//\`U8Q/<PO\?*?^Q5D7
M_JHPYWOQJL[,^`KB[-K;&[M]#O9(+DP1?:())+ZWAD>&;9YD;O"JQ.R,K-$J
MQL2@`K\</V*M3U*7_@JGH.GR:A?26&J_`R>YU2Q>[N'M-2N+/]HKX:6]I/?V
MS2&&\FM8->UR"WEN$D>"'6M6BB94U&\68HKSE_O</^P>G_Z<B>WD/_(EX@_Z
M]UO_`$[$YG]@+_BIOB9XBN_$?_%07<7BSXEZ#'<ZW_Q-;B/0]`UO5WT+1DFO
M_M$B:5HKWEV^DZ<K"STYKJY:SAA,\I;^HSX.6-E'X1LQ'9VJ">[N/."6\*B;
M>;U'\T*@$FY(XU;?G<L:*<A5`**];(?^2BS7_K]+\F?-\??[IA/^O='_`--H
M\`U37=;BU/48X]8U6..._NTCC34+M$1$N)%5$59@JJJ@*JJ`%````%%%%=<M
MWZO\SPH[1](_E3/_V0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+V)A<G0N9VEF````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(Q-C(`,3`T,3<S-C,P,3$`,#(R-34S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y824`)0#W
M`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`
M9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`
MS/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S
M,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PS
MF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F
M`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF
M9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F
M_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9
M,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9
MS&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,
M`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,
MF6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,
M____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_
M9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_
MS/___P#__S/__V;__YG__\S____XOR0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````A^00!``#8`"P`````)0`E```(_@"Q"1Q(L*#!@P@3%B2!C2'#A@HC
M(@2@8E1%%20<2MPHD,2H9B";I1I%`@!$C@I)I`H9$B,VDR@3JF09TN+#AS$)
MJJ!)TZ;&G`T_\J0Y$B,2G!QG#AUJ$2;*G4N7DD0)P&/4I2IB`@"P\FI/I!))
M0/7*,BM*CZ.ZBDREEN?4I"I6R!TU2JY=H33-;ES!JF]?N7[[5L$+,A58F:RN
M6;EVC15?QI`=?TV:&/)CQ9%7M-4;MG+CRY`_JS5\-K!CSYE''TYI%W!HQI)K
MKI:9ENVH*JA9#09I,Z='MKQQ_UTAU"=0%<BAUIW+TDG:MQPK`F?9EK=SZ&$)
M>[TX&Z%2LLTJ4):,:15\,XM`&TIGR[[H6-+I&V:<GYPP_/@$T58/C]^@6*8N
M]3?0=Y,)V-!^O'&&7T5NR87%"MUM1,(5Q+57%Q98"()AA`IMY>&'('Y84$``
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M8F%T;6%N+F=I9@``````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$Q-``Q,#0Q
M-S,V,S`Q,0`P,C,P-C(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S
M```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9
MF0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,`
M`#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-F
MF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_
M`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8S
MF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,
M`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`
MF9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9
M`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_
MF9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF
M`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,
MF<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S
M`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9
MF?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_
M)```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"'Y!`$``-@`+``````@`"``
M``C^`+$)'$A08("#!1,:5*CP($*&`Q]"C.APHL$5%@TZ#&#QH)6,V`X"0$"R
M)(*"#C]V#&"R9<F0*3.R=.E2P$:5$$?:W!A`@`"3.SU.!!"4Y\&?)(OB;&C4
M*%*E.9LV_<ES*4JI4ZM"Q,HU)L.#@59T;7KR:X!`@0",Y5DVH<-`UP))74&7
M;=NK`:R@W8@6+:NT=K_FL:*6[[7#UUB1O4LPP+-G5HS"C2N5),6(CR&OW6A9
M(,F-F9]YM$)Z8Y4J@3V;=!RZ=>;3J#FW;<G:=6O8=LNNSI,YCV_?MT_G/KFZ
M=1[$O%]7(6&4)H+:CW__?@S;0'.7!VWWIB[\.NWDH8$JASXMUOOSS^"U<R_L
M_2!)`.EMGV:.];/[YP&J:!=NG2O[F?CE-UYY:P4$`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]B97)T+FIP9P``````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`W-S`R`#$P-#$W,S8S,#$Q`#`R,C4W-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/XFOV;?AK?_`!<^*W@?P%8Q
M&YN/$&NVD!4;YFBLY)HXI6:.T8W,31>0K^5(D;-#&CQK,QA5_P#0J^%7PS\,
M?#/P!X(\&Z996-E_PBGAJQLX)(XV\L/#`IN[Q!<PV^X_;9'NY6,$,L,TX:18
M3<$2?R/?\$+?AEI7B[]H^\\3:U:+=P>#M(DU:V^UP,]C;SS.+3[83<F6TB=)
M8HHK:=(HI?MDD:1W7VJ"!5_I=_:I_;L^$W[)&G:3?_$"TU.6\\12W+V.E:9%
M#-?SI!:P/'<76V0);Y4K%)YKN8DC3EC#/%;_`,3_`$F,;F/$/%N3<$Y-AL3C
MZ^'HSQ\\!A/>J5L56A)P2IN=Y1HX>$ZDV[QA*I)P:O8_H#P_PCPV65<QJ5*5
M&-9RBZM:2IQA3A[C=2K-J,8S:Y(Q;M+E2O)R3?VGNLS*UQY`>:,OF=+4W$F8
M3=0L%E@CFW.JQW"&)7::/S!#)&DLZ1/4DO(H#?"1K>W$48=<7KA)5^T3*QVB
M`+;RN\L:3R(AD\ZY1)9%1+>=OP.\7_\`!<[X0VQF_P"$:\%ZOJ\UI-(EM+?*
MEGY=UYSNL[I)(@CBD8"X6VE'FEX(GEB#PQ+#\S>,O^"U'Q:\;RR:;\+_`(41
MVMY=J-CZF]SJSVKNRQ*4CMH+5%FE%RA6XE3Y)8IR=NXQVOXA@O!GQ(QR37#E
M3+Z3LYULSQN%PE.BKJ5YQG7]JH)<TI/V3DW&UE))R^W>:9+2FHU,WPU:I?DC
M3PRJXJM*4907+"&'IU;S;:4=/9VYM6TC]<O^"B'P9\&_&']G/XA3Q1Z=I^O6
MFEOJMG>W<%O;M-=:5<R/:G9';_:;NZEB'E6;0*SJ\<*3NSQ2O!_$3XIA:TC:
M&8>7-'/>1G:[12*Q,2O.[.LP1H45HG*L3'&D<L"N$^S+^W2^&?\`@J#^W5X9
M?6]+\,^+'^&UU>SVCS(4T+0MVEVXN;FVNFN7B\T(9&F2.6W2::ZFMX8E?=9(
M/QR^+WAG5/!GB+7O"&LI<PZIX?U>]TO5`8VADBOK&4Q7(<'SI(YD8SLGEF7?
M+&R!)"XN(_ZX\%>%<TX)RF>29OFN!QN)KXM9A2P>7U)UHX*E/V>'K)U9)7YZ
ML(QDH4U"/LY>S7-SRE^><9YAA<U4<3@H8ATL-#ZI*OBX*G*;3=2%)0YG44:?
M++D=:7-=R6RM'RR$2^5%A2@\M,)\D6P;1A?+,<ACVCC89'*8VEV(W$I8Q(\:
M/E3N16R&CP=R@Y&(YA@YXQ-*/263[Q*_9I3P_,[PIWN[_NZCUOKK]<C?7K9>
MBV/A(QJV5I5TK*UI12M;2W[AZ=M7ZL_KH_X)3_L)?$#]CVU\5^*OB;XB\&:I
M?>,M%TE[+2?#OV'4KW1[F6(3W%C>7R&:[%Y9I.(YY+E;!&/FVT#2LD<UG]Q_
M'K]FCX9_M#:=86'Q!T:'51IDS36,DL4;2VY97\Q$G+).D4C>6QC638'C0J$_
MUD?DGPG_`&G/A5XG?X?:?HOC/0M2\5>+]$;5+C0;*_%Q=B,10RO+/''<&.VG
MMO*N-T<]O:RO#.L9B5?,N*^U;;4$EC2550L=\<Z2E5$)!,$S'<60F*1L1E7;
M<P#1LQ4D?YC<<\6<89IQ=/B7.O;Y-GS?)1JX3#U\LE1A0E4PL98;WG4<+TZL
M75C*7M)^V;;NTOZ=RG(L)D6`I87+JL,=@I04?WGL\1"::]HX58SYH24^93BI
MZ.G*DK15DO,?@;_P30_8G^"_PM\4?&KQU\(M)\>WVA:)K7BN^M9M/_M,:;IW
MAV&XU62U\/Z4GV</?S0VZ.L,M[>!YEBA26#?-;0_.WAWP_\`LF?M1_"CQ+\=
M_P!G[X)3?`S6_#?BRY\$ZS8ZMI2:9#JD`M9KB2_L+9($\FX=;2*"[G@AAD5[
MN)]M[>6PBK[UT;XA^/\`P?;:E#X;O=/O]!NX)DN?#VNVDE]ISHZ3QWDMJ()X
M2LUX#MD!$SSK&!(RB;YOFOXA?$/5M2N9/!\6D^$_"WAFT>YU=-(\-06VEL);
MF6.WN)+J*RF>&-[6W=%FOK:UCNI)T`N-3MK:ZDTVW_8L?XO\.9CX:T<EJ/'X
MKB-Y4L+7==U:M668QM?,)8VM.-Z,JRIU_80G*+C>@Z,J7-)>%PYP3GRXX><X
M?%86EA88OZVW1E&DH8-M.I@OJ,*:@VXS=*%-Q]BN5SE*"Y4^TMM7^//@G6_V
M6[;X0^*/#?A+X">%?"*VWQ>\,SWUC;ZUJGB:[6X@D,L48D:];4I3&+&2UE/E
M74CRI<RW`L[I/XR/V_\`4VU']IGXS7DVGG2'/CS6BUK$'"Q,[RW0FF,43Q0N
MPD+[)H)95+K$,NDID_K+M_&`BO+/3YKHM#:7D2FUN;BY$3W#,_R3:>THDN89
M%=F$KHMF[W%N;87$KH]I_)I^WTT1_:4^+,L,L\D4OBV\.^<QP%WFD+M,PM;:
M.*.YD#D1LOD!IAN@@A$SI#]_X'\?X[C+B"MAL9E^'P4<LR'"QC]7=5>WJ3Q>
M'H3JVDN6$*D8+W(\THMOD<W%R?C>)'!D>%<I595)U99CF->LZM:G%3Y.6I7I
MPE-R;J2IJIO)IMRO4=Y7/C)-H1`ZP;PJAM\@W[@`&WY\X[LYW9FE.<YD?[Q*
M:MQ%M7&YAM&&58RI&.JD$@@]002,=#17]-2H4N9\U>2E=\R]E5T=]5\3V>F[
M]6?BBK:*RIVLK7=-NUNONK4^Y_\`@F5\/_BKXN_:?\#ZYX.@UA;;PC]KUJ_O
MEDN8(4L8K.6Y%N)&VK/#=F-8C;*S"83G;&R/.Z_U#:+^U7X2\/7ZZ!XSO8O"
MNK:?)'8RV>MSZ=81C=;/<331*\D1:680B))D^U+"Z26\SO+)(X^1/V7O`&L?
MLT?!OP#%X0MM'M_'&KRZ1K.OW/GPIJ<C7\L41T^YCE#R36[07;1R07=P(+97
MAN)6OU^S2)]V_'CPU\/FU5O!_P"T'\,]/U"QU33H]5@U73H(8[W3EU='EQ%J
M&V)H6L);H>?$XD:*%(Y9W6\G@,G\H>.N%P/%N:4N(GEF,J9+EU2KD%+$Y9"B
ML5:C4>)>-4:T84L32E*O-JDW'EC::J-2:G^^>&52GD^`GD>-5'%X[,(PS58.
M>)Y*]%U(0H^QHIIQ=2,*48U:=I2FY6BH/DD]:/\`:@^%,]G)(WB[P\8;@X$@
MU2TMY(YB$\T&-XPK26KRP2.S%_-A43M$D<RHOP%X\_:1\,ZGXYU630M7T;4#
M!M4&*02^8ZVUM<K<32SPXN(IC+;AK52'389))(I$VTWQ%_P3P_9Z\8^;<_"[
MXSV>C,LQDET+Q#?-(H`:15,DOVJWGLQ;^3=%9[JV6/$D3".WM7FN+;YI\8_\
M$X/'7@NTUO6--^*_@.^L].M?MA,=]>)=BR>(70,J0!Y#Y<2A7D,4ZRR_:%2)
M+FW\H?E/#W#?AG"I5G6XIQL*M2$:,<+F665,&XSJ3IM0FZ;KQJ.]E:G*,;N_
M-*/-%?M>6YGA\EQM#$4<EJXUUW[.I@'4Q<,72;2A?DJY=AZ7-4;2A.E6EK*/
M,DVD_2YOB[XE\1ZW::1HUQ-+<736UE'!:^4+%XY9XXY!'%)OMQ+L=9@[@1,R
MB!42ZGG^T?B!^V;#)8_'[XE01ZH=4B/B2X66\!<!F54E%N\C1J[M`LSHJ&1A
M+/'*3'#(CW!_=+X%?!KQ)X,^%?Q2U_X:01>,?B5HG@_5=8D\2Z[.MOIGA.[L
MK25=0&F07-JM[#)%;1.R-*1<K/+;"V07'DSI_/#9>'?$?Q0\0ZWK.N:HQNI+
MR]?4KZ\<W%S=W=Q=W$TY3<D+$&>7<90C(2)`S(3"B_T?X*</T?[8SG'Y1AX4
M\KPL*.5T*\Z$J5;,:\:M+%5L6X2A[6&$HR@J-"3G&52K.NZD&E`_,_I#<8X3
M,<+D61++8Y9B\)]8QF*H1J4IRPSQ,:=*&&J>Q;@ZU.%*\XS?M()VBHI-S\8&
M]@"0@)&2':`L,\X8AB"P[D$Y.3DT5]?Q_!?P+;QQVY@UF8P(L)F76@%E,2A/
M,4+9A0K[=P"@#!X`%%?TH\FS*_NRK*/V4H-)1Z))5K6MM;3L?RDJM*RO!MVU
M?,M7U?\`#/W'^)6HZA;>.;]K:^O+<V?BKPO#:&"ZGB-K";>Q<Q6YC=3!&7^8
MI%M4M\V,\U^VO[22)J7P@^#FKZBJW^JWGA6P%YJ=ZHNM0N@-!MIP+F]G$ES.
M!.JS#S96Q*!)]\`T45_,<_\`DW-+_KUEO_IJ!^U8K_DXU3U?_JNPQ^#/Q;N;
MC0_$\4>B7$VCQO8:<KII4LFGHZPZAI<,*LMHT(98H;NZBC!!"1W-PB@+-(&X
M)=9U@:@Y&JZD#:PS?92+ZZ!MO.>_DF\C$O[GS7=WE\O;YCLS-DL22BOR3-/]
MX?\`AG^50_J/(?\`D6X__L#J?^JZ9^N?PGTO3(/^";'[26HP:=8PZ@_P;O;U
M[Z*TMX[QKR:+,UVURD:SM<REF,DY<RR%F+.<FOXU/A)//)K;B2:5P=3F!#R.
MP(\FQFP0S'(\V667_KI)(_WG8DHK^I?!C_D4O_L+Q7_I5<_DCQJ_Y+;/O^PO
M_P!OI'U91117[I+=^K_,_'C_V0``````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B97)T
M,BYJ<&<`````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,S4P`#$P-#$W,S8S
M,#$Q`#`R,C8U,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/X<O$UH+37-6MRQ98[G*$Q[&"L#(%V;FVX#$9W$$#/L*VBZ)?\`B37=)\/:
M/:W&H:GJ^I6>DZ?:01*T]W?7TT4%O;P(6VF25I`%W':"<-\N379>/T#>*+V[
M>V>!]2ABN8;7"%F,JB`1JVY8RP/S!G*)DA6*CYQ^CG_!(7X6Z'JO[2:_M!?$
MC2[FY^#_`.S)X-UGXQ>*[XZ?-<6]Y?:!9O#H,6FI=0"RU"ZAU=;&]FMI7(,*
M3H(YDA9V^NXIS^/"W#&;YS-Q4\+2]I3BK2KU*U17PL*-&-ZM656LZ<(J$)6;
M5[*]_!X(R*MQ/G&295!2D\;5HTI1C[SC3C",Z]62@Y.%.E1C4J2E*RLG;4_H
M%_9&_P"""7PFL/A1X$LOV@/$GB+6?'3:?/KOBV/P?J,&FZ99^(_$`M=0N]&@
MU*YLY%U"32=)AM+!A;1J'U"XU.Z01/>F"+W3XX_\&ZW[-'Q.\$:AX9^$OCCQ
MC\*O&]QIWD>']0\17<.L^&9-32X%W:RZS;01:;,+.ZNEA@OYHIFE@MGEFCCF
M91"WZF?LG_M+_"7]JOX=:;\2_@WXHCUVP6S`U70KF."/Q?X;NYUE6.WUGPQ%
M<74VF'4KF*,6ETMLEEJ,6+;3=3DNG6-?I7QO\3/`WPN\+3^*_B)XVT#P-H%M
M'=R3^(/%.O6&FZ4(H+A+-3:FXDCN+F>6\GL[$0:>MR(-1NH[2XN+<!IQ_DMF
MGB[XITN-Y8W$8O/*6/I9I]=JY#)OVE/#U*L7!U*49-1A.ZC/F5X1DW/E2=O]
M#LTX.X+>0+*,)@LD6#Q.4T<MCFL*:BHU*5/E52,Y1NJS]V3A%JIS6NFO=/\`
M-6\<?!CX=_LW^+]5^%'[05_XRT[XT_#6YUCPCXK\$6NBS2Z?I.LZ7?W$YEAU
M::>&&]T>Y:W1=/U1+*-=1@NHK^TMY[!)+B/Q5/%>B"TOK73YM/L$:*_-FFJ0
MI+=20RQ2"!!(@C$4L@*JA96"N0<$`U^_/_!R1\(=#E_:%^!'[1'A.U36+;]H
M_P"&-N^HZUIXFNM,\0Z[X/M-/CBU6*:W-NUY=/H6K^&-2F<VUDL4ES-:6D+6
M*W%M<_S.Z_9-%?7,5M;C'FVD)CDC*-!,I4-&Q_>LGFM\N&V8S\S+UK_5?P^X
MO_UWX,X7XJY(P_M&AB*=:$4URXC"25'%1E&U[TZETI?#):P;24C_`#2XSX7I
M9-Q+F^25*\XK!8I4J-1N[DI\M2"5M4I1;NFDK];NT>WA\72PPQ1>99GRHHX\
M^:HSL4+G&PXSC.,G'J:*\I:TD!(,.""01ES@@\C.><45]G==U]Z/F_[,H_\`
M034Z=)?W//T_K?T76=,SX@\&KXDM;K3K/5+O3+34ENK.YL[@:6=1CCU%EM[C
M)!CMFF(/F8)`^8=1_=G^S7^SO^S?\`?A'=^'_A+X7^R>$3X<\#GXHZP]W?W6
MH>+=,2.W3Q/JUR/,NUM_LFB:IJ]]9V&F0K-'=16K1W3S01M7\.OQB\1>*_$E
MAX7NO%FNS:W=6T,MHMW]E@L[@`VL%Z4>2(X>2<7!B#YCV%?,YW!1_41_P2%_
M;;T_5?A+X:\-?%?4[K2-2OIY-`T/Q+KJE='\2ZAI$\-JME;ZA=6Z64>J10;)
MKS2KN8M!;QF2-[W(C/\`,/TD<OSK%<.Y-G67UIQI8+&4Z.8X#ZPJ$<11I3C*
MC)^_&3E)Q27)&4XW37O)G]K_`$,\QX<I\2Y]@,PP-.6?8O+L5/A_.:]-SHY?
M4ES4W2G2G&T5[&<O>G:%DU*2CO\`4GQ)_P"">/BG0OC?\3?C%_P3WUBZ_86T
MWPQJG@32OA^=7^(%_K'PZ_:5T3Q!H>J7OB_QIH.GZ,VK3^&[CP]JUM9P:CX7
MN=$NM#OVU4M/:V,D$AN?6/V:O^"5%Q^T+^T3XFA_X*#_`!&_::_:*?X>_`O0
MOBMX9\87>EII_P"R9J_B#68/#$E[X,TOQP=>COM:U;P[?>(HM$U'P#IFBZ'H
M^O:UX0\5:W/J.=(71+^[\+_CIX)G\4>+K3PNEA80:9XL\1V\=LO]IB*SB:[6
M<RPQR^;!;6VLL(_.AMT>UN8E>,2(DQ*?JC\(_$]QJ?A1KU]9\2/I-S<*J>&;
M?7KRX\,V21I<F36[32;IXS%?ZH+VZAU.X,\MU=+*1)<LC212?R5G?B9C,EGF
MF*QG#="@L;E<<)AL1"A1>(^L3@Z:3S'%<F(GRRDM=&VE&+N]/ZCXF^CZ\EX7
MRS,\EXBGCL35SQ9MBLSHXKZ[E\H8BHIK!4\)&=2G1E'DG"":BY.<O:64*=_R
M&_X+J?LL_%CXN?L]?`KQ;^SQIFF2^(/V>]=\7ZA?^&84430_#<^$?#:0:SX9
MT<*QUI?"4.CK/=06XM;C991[+>[=%AD_BU^,OP_T/P#J%OX>@^)O@G7=2NO!
MEOXY?7]!UN:ZN;+5=5$LNK>"/$6GR6*W%QXDB@2>26U8V/\`9BX^:8_,?[:O
M^"NO[?>D?LV>'/#?@?POX;N_%?Q:\:^!_%FHZ%"VJV=OH>BZ;/!/IFNWVJRV
M\HNQ>6<2SQ:3IMAO:[:V6?S(R1#7\5.F_"-M3N/'<GC;P-\1KGQKI?B6[L/$
M_AN62R\+3:)XBOWM;C0[&VNKG1=2NI]6N+35+@WT%Q*HO;.%+9Y;8W9F@_J'
MZ+>99]1\/%2SC!U<+EV$K57EE2I9JHL9-5*[C%.4TN>3O)Q2ZW:/XO\`'GAG
M(:?&N6U,KQ%3$9Q/`SQ>?8".'K?[+B7/V>&4YNDJ4W*FU*T)S<+VJ)2NCX__
M`+2UT<+)"ZCA7W2_,.S?ZC^(<_C17ZR:=^P)X#O=/L;R>?QG;3W=G:W,UN?$
M]HQ@EG@262$LMB%8Q.Y0D``[<@`<45_2/]LX!.WUN.FG3^[Y??\`]O'Y/_JM
MC79K+9]'_"E_=_O+M^?9GQI\0[%+OPC?SL\1DT[4=+GMXG"G[2EW!:VD4/SR
MPK&L]M!)=,QD4*/W+,O^O'ZN_P#!*G]H;X>0_!GXR?`#XR^!4^)OPV36_#_B
MW4].>WCNM1T+2[F/5=.O_B)H%G;0OKD=SHL\6DRZW-IK/;BRU!FF:7[%B[_*
M[4Y;;4UU#PM?J4UB:S7^R$FBCMQJ][<6\K:$U@LWFP3?9I1]A4.6CE9O-<(`
MT-?K5_P0#^%W[.'Q=^./Q?\`!WQ(^+!^$WQSOO!%E8_!"XU7RK'P5XBN;[4=
M1;Q#IM]JL[Q3(((K/PV\N@-&8M3-Q<6T/EE#YGS/B9@,#F?">/H8BE4K3IXA
M3H5J-HRI58/FIUH)K65.2C+6,DVK-::]'@[Q)C>&.)<NS.C6IR45&&(A.+4*
ML9\D94:D>5N5.HO=:49*TI<U]$?JA\'_`/@G9\(_&Y/CGX<_M1ZQ;Z==7<4E
MOH^DZBG]NZ;8>42;:\GMY3)920)(/($P^W6C1*RK)*H6OJ7PE^RSIMCXX@L-
M9_:U^*WC"VM+J*'3/AAX%\=Z]>:E+!%M:.+6YW^Q>19%$:>^FGT\V:0F1)KA
M(]TP_2OP=_P1X\-ZYJ4'BWXB6>D>&=;TV^D%W+\/=;OM+C\10P/&+*_O+;2=
M1TK2]4LM5&'NE:WM[U(7>-+EI"L@^2_^"W/Q=^'G_!.?]A#Q'\-/V>=(T+PS
M\2?C.EQX-L/["D:PN].\%:G97J^/_&@U'284GNKZ/3''AW2;Z^O8KG^T-;L]
M35V:U-E<?P_A>'.(N*L[I9='-Y8[#8C$_5*L\?DU.&(E3YU3Q"AC%!^^H.?+
M.5"$>9)J2T/]",7X[<'9#P[C\5A\JK8>M+VDYY11JX5Y74Q4(0GAJM"+PB=.
M*K3YU!N$TE=VNI'\H'_!1#X^>`OVP_VS;OPGX-U>'P7X"^&%AJWPK^&/C0W<
M%QX<@\1>&C?:?INO76KPK?ZI>Z/XRO[6_C^USV-O+<)J%I?[88Y"4^P/$?PY
MU[Q5X1TOXB0>,?A[XDO=>\*W3?'#2_$7BG3;;QK??$'P]HWAB&_UKP]IBM%?
M>(QJ-[<O/INMQQ:;<):6QL(=.G=_.7^;6UU_5K;3/)TZXEL[S=<7<.HV(AL[
MN&]N(8HKF62XAM_M,[201?9;5C<H;&V?;"3.@G;ZVN?BK\28]/\`#.@OXNUR
M[BT'3-&MH;W5+J&_FL[B^MDUO19TUA+2UO8[J&RFCAW7C7L4DEG'<2QLA^S)
M_>&6\%Y!EG#.69)2>9X"GE=!8>FXUZ;CB7R*,:DU3FWH_>?-J[-6NU;_`#JQ
M7B5G+XNS/BG&*GC)YWC*BQ-*:YOJ=#FO24;WO%NT$H)^[[UE=L_=31=<\'IH
M^DHGA2`HFFV*H5L8G4JMK$%(=]65V!`!#.JLPY8`DBBOQNTK]JWXF66EZ;92
MZ9X0NI;.PL[62ZDTJZ\RYDM[>.)YY,:D!OF9#(V`!N8X`%%?,/@6-],TK-7T
M=YZK2S_#\/-GWJ\8[)?[-A]$O^7/;E_N]+?^2^9\Q>.26\#_``]O6):\ATZZ
M,-VQ)N8C#>>*3$8YSF6,Q&.,Q[7&PHFW&U<6/#EY=Z<WCC5-/NKBPU.SLM!O
M+34;*>6UOK6[BM-9EBNK:[@:.X@N8Y88I(YXI%E1XHW5@R*045]?Q)_R)\3_
M`-?/T1^4<'?[[A?^OU#_`-/(_;[P-^UE^U1X<^#]E;^'OVE_V@="M_[/N?W&
MC?&7XC:7#\D<>S]U8^)($^3`V_+\N!C&*_*[]KCQ9XJ\6?%/]IN^\5>)?$'B
M:]MO'/@6SMKSQ!K.HZS=6]I>6^KW%W:P7&HW-S+%;W5Q;6\]S!&ZQ3S00RRJ
MSQ(RE%?DOAY_R.J?_897_4_3^/O^1*O^PM?^EQ/C>S1/)3Y%YEMP?E'(+C(/
M'.>_K7UMH<$$OQ%\9VDD,4EJGA?P;*EL\:/;K*G@&#9(L+`QK(G\+A0R]B**
M*_><;_"I?X_U1_/D_AK_`/7R'YP/G:_EE6^O566156[N555=@JJ)G```.``.
M`!P!P****X#=[_-?G`__V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)O8F%F971T+F=I9@``
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R,#``,3`T,3<S-C,P,3$`,#(S-#`R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y824`)0#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`
M,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`
MS&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS
M`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,S
MF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS
M__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F
M9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QF
MS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9
M,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9
MF?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,
M`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,
M9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,
M_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_
M,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_
MS&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````A^00!``#8`"P`````)0`E```(_@"Q"1Q($(#!%003
M*ES(<.#!AA`C%@0@L2)$@Q8S*L2HL2,VCMA6&!A)$J''A!Q7,)#`DB6#`R9/
M"L2XHJ5-"0=@RIP)P,#*FRUSZCQI$`#0FPQ`=BQZ]*92C45_-DU*D:A!)%BS
M:L7Z-&-1$D7#?GWH\2H2L&(-DLBJPBH,.6S8(`F+)*X<&`S:E@5@`Y">N&'C
MZ@%T0T),J`"X!`KT-[">Q8&X'/8*`'(@-H$M!YIL<<4*RYB+LM',6>(**X&Z
MQ+@!*+3!T5QN*+92&N(*+ET:')#0&BT)-H19RJ[=L";+!A*XR)D+`(D<+C>)
M,_1ITT9C`&STV+#)P$!'D21]7EIACL1*]_#2*QI(ZWWGPA5IT[OWZ-ED_9#W
M[PO,S]^^9XKVA22@@`C%9&!"AR$$@&?[$=C?0`SB=R"$'PU8H(4$4M@@00E^
MM.!^'\(7XH`DBAB@AO.EJ.**++H7$```.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O8F]O+FIP9P``````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,#<T-``Q,#0Q-S,V,S`Q,0`P,C(T,C(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#
M``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MP``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%
M!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q
M%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*C
MI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ
M\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`
MM1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!
M"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=8
M65IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ
M_]H`#`,!``(1`Q$`/P#\`S\;SI7Q@@\#^$)%\,>%++41)J][IUG+:W?B#0-'
MU*:WNK":YM;:RDM_#NN26DU[)I<=E.!`+=)%9O-CC_=']B7]MGXP_#>2]TO0
MOB-XMT30K;63KVEV5MK7B-8[32KT6QM-,%I:ZG_9=O97(GMT,"6US;)%!+`U
MBF`\WP-\<O\`@DC\>_V%/VQ?B%I_Q::T\4_`[QCKNJ6OP$^,=MJUAJ4/Q$L)
M?&*ZAX-T?Q'IFB73ZUX&\86UO:W]UJF@:Y8VVGSZGI>H+IFM:UH9LS<]UXGU
M32?A?X%\1;IUTZ^LXKQ]?UQVN(X_#ND66G7EW=ZC=K)')]K?2XM+^W0V\:23
M7YLA:QONGE63^2?&N&&Q>:Y7E.!J5)YO['+I1QN%JSC7H8J5:$WB(8BARUJ5
M:BFX2A3J[*G&G3J3DG+^Q_`2AE6)X?S/&9O1P5;+XU,7'V&,I0G05.G3A&M.
MLJJE2=.,5/GE*+N_=M:*D?T:^'O^"DW[3?C:XL/$6G_$W2].MM+TW3=,T^SO
MM`MHM(U:*]@GO[_5M5AMW%T-9M98A;0W]NBM+#-Y-Q;P1M)/6UX?_P""P'[4
MFA2ZE:W7AKX=>,+N[%CJ<4VH:;KT<>C0V;Z59ZC%#%IWBG2K:;2I;9)&2.6Y
MCGMM7FU">&2ZCG,,7\['[+'[1GP>^+/AJXU?0/%$_B2'2?M6A"2XTG7='6'6
MH_[%7=!974(GN5MTU"WE,[I)%/:SY0AX\I]/^'(9;OQ7J,NLW4T]AJ%M%'I:
MFWEMA)!+&/(4R1K!-;16KW<$VR7,LL)AN)79YFV_C^+XT\1N#<SQV#S'.<_C
MC<OHM5:682QRQ+J-Q4>>EB&X\T*<J4I1JTFI)W=Y7O\`:T_"3@3B_!PS+(L%
M@/[,Q&(4,%5RZA!T*M*$U[2U2BE.4.:-36,DDO=>JLOZL/@E_P`%:?@#XQTG
MPM;_`!535OA/XPU:VOAJD%WH^IZIX0L;NS$JK%#XATU+U4CE@L94C^U0KYEX
M#;PNSR1[_P!(/"'Q<^'WC[2-+UWP=XMT/7],UFQBU33IK.X=9IM,EBBF&I26
M-RD%_:V4<<T1N+BZMH4MF<17!BF!C'\*OQ+\63^%[NR2VN/,LK&2&:&S5A.;
M8+Y,CE)WFU*4?,S2AC=#8Y9\$EU/S3\7?C5KFHZ1>E_$U[%X;.FVEUJNGG[0
MUI<:C:68N+)C'(GDW-Q#ILMO86R1Q"SA\QKUX\0W(?\`2^$?I!<98FIE]',<
MDRS'83%0@WB8_6<-C9-PI14+T/:T95G=-Q^K2<I32]JE91_/^(/HW993P^*Q
M639[B:%6A%S^K8J%#$8=I25]4L'B*25.7-RRC-_NYO9I/_1.N/B=\/+.XGM+
MWQYX.LKRUFEMKNRO/$NB6]W:7,#M%/:W5O)>K)!<6\JO%/#(H>*5&1P&4BBO
M\G[4/VS=:TR_OM-MC#%;:?>7-C;Q_P!J:7#Y<%I,\$2>3_8Y\G9'&J^5D^7C
M9DXHK^@8<5<75(0FN%Z24XQFD\15NE)1:3M%JZ4K.S>MM=3\;?AM@T[/B?`W
MO9VI-KILW4NUV?FOG^F%E\7?'?QT%KXH^*WQ!U3Q3<VVG0V\5_K'BO6=40X5
M9A=YUS5-1NGN";E[J9WDC<PQD%"Q<'XK_:]\/_%;XK^`M<T'X2W6E_;-0U"S
MT[Q-)<W?V4:IX/TX74VI6D%Z8[JR_L[69A8V^HVU[&T=[ILE_:WL3VMPT,GV
MOK?P:U7PY\"-#\7:4D]O<ZKXFGT9()3F21?[&M-2MG:2S`$4FV2=%>9S&PLG
MB*[I%+?.5GX.\8>(9K;PWI=U>VFL7-XLTEHD\A2XM<I%?3).+^TB_=C+RVDR
MYD1?W?F.WEK_`"5D694\#G4<[I5L,WEV/C7H4L>EB*-)473KQJ5:<JL95()Q
MBTY2;<FFE>"M_:V;<.Y;F_#N.P.&4<#A,7@L7EE6>74XX>%"SC0K\M2C2G&G
M?GUC)6BE9VYKE7_@GE^SAXP,7B[5=:T;1-`\3>+/%GBWQ7/HGAAM(L_!6D7N
MJWL\"V/A#0O#&AZ5H.D:(=$^RQVEC;V#/IBP/'8O;Z1+%96WZ\^,/@-XB\+:
M=<W>MVKV]MK-N9++4;>.6/3M)C@NFMY+>*0V'EP7)PKW7V9[CSO/17\O`%=9
M^Q!H?AGX406EOK,+WTKZI973WEU$+K<TWA^QAO3:VS))/:P75Q'J&+7)?;Y7
MFET#F3]JOC)+\#?B=\-+3PN]U#X>U"9XKNRF^S2QO!/>:E:WLR6HM[0P+;^4
ML<$^1\C+(&/&:^!XYS'/.->(,ZXHGB</%RG&O"FU*FL1&A[&FJ="K.,U&*I4
M7+DJ-\TDK-N33\;(,=4X`P7#/#."R[,Z^386,\,\?&G4JQIQE.K7EC*E*DI-
M*5:LYJ=M(N]MC^!V;]HC5/#7[>GB+X<^,M?\:365KX<T[PYX>L]+U+0]'\%+
MXDU#1O#&JQ>*O']IK,.IZKX@AA\/:KXC2U3P_?>#?$VE>*]'\-WM[JVMZ5<^
M)-+U+V;]H9+^S\"7UQ:64QT2"TO)KM500B.QQ.;F6.0RVMA(\-C$MM+]I18$
MCCFCB+6T,0KZ8^+OPM\&^!OVC/&;^.?`GA_5/$6DWT=UX6\47?ARSNM:EMM0
MM+>25K;7/LV]=.CCDC@CM[EC"D4"6]ND;#)V_#FEZ5JEIK-GXBL-)O-.&H33
M"RU9+>;1Y8O)1G-U`2UK-'+$6@E@>&1W@:0.I#JU?I^8\79-;@O,<#D4</\`
MV+D&5X?&QH^P5/-ZM-R=7%8>6'CI5J3J2526)4JO-.$92E&E!+@R3A;B3#T^
M-\1B<X>,I<19[CLURW$3J59K!8?&1J.E2E&M&G"-.BWR>PHQC3?-*5DY2;_F
MZE\/:WJ<LFI6NE72VVH2/?6ZPZR8X5@NV,\*Q()W"1".11&@9@J8`8XR2OZ;
MKG]H?P?H-Q/H5CX"\`6EEHLTNDV=K;^!K=(+:UTZ1K.WMX4M?#$MJL,,4*1Q
MK;2RP*BJ(9'C"L2OUN/CEG:452\/,9.FDE3D^(\&G*"4>633P":<HZV:33DD
MTNGX-/PPKN<G4XPP"J.3=11R^;BIWCS)-8BS7,M&M&FK>?[JV/P<OO%'[/WP
MY\'ZNMB+>VMM/B2PCTR:"]M-0DTHQ7#F>\>-WTV"&66XT]=$BN;-%N'5+N6T
MBFE3N?V;?^":FDZ=J_\`PGWB&UBU)+J348M'EO+::]2!;Q[4VUW'!+J*I;S0
M>6SI/!:07N#L2\4`(GZ$^#/"UMX5\+VGA74M'UB^T6V^S;KC3Q#J>IQ7J1&&
M\T[[5:164-QH3Z?%N>VBLC-%-)-<7$K02(D?L^G_`!)\+^%_!-YIOAR[MO$>
MO:?IE]<Z7X2DF-KJ=Q'8VTRVFF6J,CS)?B^%E800B&57DD>-&+%%3\2X-X3P
M>.S;"XC-:\:5.EAH5))U8TU6Q-&$(^PG1=:-3%4I<LVE!5'-N*C"7O6Y>(O$
MC.\-EF9Y7DTZE+"YGF%>5>%-3G2]ABJTJDKUHIT,*_:*#E.?LY+W_:34531_
M/E\??V=-1_9O^*[Z;;ZQJT_ASX@ZYKVL3/HUK<SW6E>(M8\0QW8UR:+5+^:Y
MFL=-L+S5O-TZUU&WC9(7V+-(T$$UCP'H&N_&;Q5X1\#_``U\6KXVU#3[N>X\
M0@>%&M)=(MM7TK36TB$W>NR:=%/-]DN+J\\K3M1$$,6FR#5/M-U-I]C7U-^V
M1^T+\7_%?@'4;CPO^RE>+\21ILO_``BNI^-I]2N+2TM=3GMK=[J6TTK1+#4;
MBY@M)KN.6W@U&R^R:B]JLUS);W$AA^S/V(O$GPD\/IH<_P#PI3QI\/?&/B2U
ML=.OS+X;TS7_``Y;7^G6-Q%+?+XMT&QL9HK1XHMLK:UI5E/:^9;V0N+J.);N
M7[N7`N1YKF$LO>)G@,NQE2$Y-*MAI3A7UG2BJU*5ZE.O*#I\\8J,)6ES**M^
MIP\8,WR?PPPM7%9/3QF;TJ;R^GBZ6)R;%T)5J4'&&*KX>C.IF$J,</%7E2E&
M%6M37MHS5.FH_E__`,%7?V$/#GA:Y\"_$];A-2N(?#$6C^(1?6]NC075L=/M
M+*ZMM1@GN;E))H#+YD!LC9*D6Q)_,D1J_/-OV7M#^'_[*UW\4M9T2.35_$/C
MV*UT'PT=0FMM4_X12/P?<7UQXECTJSOWUO6+>XN$ATF.>RLC&UU+'!$GVEEC
M?^S/XO?#SX;_`!CTD:7XLMO#6KZ3Y]J)6U.+3+BS>*WC:1()7OHI;>&.60!"
M)$^=Q$L95@`?Q-_X*5^&C\4=&\`?#C]GG3[K^Q?!ES#X:UBU\#W\VGP:)"UO
MK.EW%QJMGX;T.1V\(V,%W!8ZV]YXCM]'@>[MHK[2H;BXTVYNOB.->#_]5<RQ
MDL-CE'AJA.BLGP:Q,ZM:;E3P\9U*5G)5849RK8NHY*[G."LXIQ/"X"\6,9GF
M599PQ7C-YG+'5:N;YUB)4Z>$_L_#RJUZ-*I*$(U*<ZU11PDI*<83H1C3DI-M
MR_EI3X(:9JB)J<NG1Q2ZBJWTD9U?483')=@7#H8KG48[B(HTA4QW$:3H1ME1
M9`R@K^E[P+_P3_L8_!/@Z/7(?"]QK4?A7P\FL7!5(S/JB:19KJ$QC6Z14,MV
M)G**B!=VT*H&`5Y:\0N(HI1IU,0J<4E!.6(NH+E44]=U%6\_FSU)YCPQ&<HR
M>72DI-.3JXB\FFDY/_:4M7KTO?S=OTJTR\N[+PC916=U<6D5SK-R]Q';3RP)
M.\K1K*\R1,BRM*L<:R,X8N$0,2%7'YR?M&>*O$_AZR^'>HZ!XCU[0]0NI=*D
MN;[1]8U#3+RX=I]0G9Y[JRN()YG:>""9FD=B988I"=\:%2BO;R__`'W)?\=+
M_P!*1^#S_P!VS;_!+_TNH?M5X`TW3O$'@+X?WNO6%EK=Y=^`HY;J[U>U@U*Y
MN98TTQDDN)[V.:6:1&GG9'D=F5II2"#(^?)OVKI9/!?PUT23P=(_A.234-)B
MDD\,NV@N\5UK-M%<QNVEFU9H[B/]W.C$K,GR2!EXHHK^AL\_Y%L?^P3#_P#I
MJB?F6"_A8;_L:8C_`-)K'A_A7Q'XAO[".&^U[6;V*?2].EFBN]4OKF.:7^TM
M;7S)4FG=9)-L,*[W!;;%$,XC0"'P[I6F6_Q"6^M].L(+V[\<RZ5=7D-G;Q75
MSI=])$;W3;BX2-9IK"\,LINK.1VM[@R2&:-][9**_G;BG^+EG_7Z7_MI^I<.
M?[MG?_8'+_U*/M\Z+HX)`TG3`!P`+"U``'```BP`!T%%%%>-4_B3_P`;_P#2
MH'AR^.7^+]8'_]D`````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B
M;WEA;F1M;W=E<BYG:68`````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,C`R`#$P-#$W
M,S8S,#$Q`#`R-#$T-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$Z`$8`]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````#H`1@``
M"/X`L0D<2+"@P8,($RI<R+"APX<0(TJ<2+&BQ8L8(0(`L`+;1@`>L5FQDG'B
MQX]66`4*M&+EQY(/K:`<&8AC()DG.\)<N.)DSHU65N($NA-A3Y]`<08%>K+H
M0:0H?5HYVM0I0:A,L5:U*E!J4JI2<7(=>/2:V;-F65VK>?+FQK$#-[(*BK;N
MM8]N03IEM*COHBT`U*(-:@7MQKQZ8?+UVQ=&X4!VUYX=^G;G8K]G#!2^MOGL
MBKIL7^YDW+@SY,%U60%XG#@CZ;X`3G/N++EN8%8B1Y..`0!U9,-J`Q5]#;@N
M[<BG8PQ_O3JMS!5T?U]C%:,OHY*O%YV);7;E"I72.?Z'R6XQ>]\85;ZO#&]V
MA?E%UR>^[PMX]53I5JJ_CQ]Q_OF-,-@DF&%G^,??0_Z]%H8!W!F6X"(2/4A<
M@VO!\&"$$I)VQF?=Z>=?1)=EB-EF5FQQ(40B9@>#65:,ER!$(:;8UPV%67&#
MA`C*R-@6-XU4XHD,-:*C7SP:Y^*'#`W95QBT!6?BBPO%HN0B,;!B)6?=60BE
M0DJ&P1MO*G$8B)9(<JDCCRTNXAATD`5RXY8(Q2CA&8'$8.(9,=PTV9'S+:2C
ME_IMQY&#"1YXD(@!`F"`B]O!0"-:!@`99X8PQ'!#@`8`$N"-6]!&YGY^2A@&
M``72%V"I19X5:9D)R6D>`/YO8K;J(C2NY%*IYC42Y(,QS.K7HGXM>-*3YAF*
MD)3^;8=K8Y^J.6R?#B7H*&DWD$KM27R2IJM#R)H'@Z_:`9!MN!N!2UI$0F8W
MZK*+&!`K:1\12QZZKVV7;0S-,O81N^=*E*Y?,7BXI+CFU0<`JQ!UNRYI[KZ7
M*,'03B2D`?+2FB]C#[\[;T4"+[)PP>5NA+!"-+&TFEZ+V3M?M0;P!G&Q#-4D
MG$A+C2007[#ZM]&-Y8YLT%PNQ68R20+!<#%CHUI;[<L;&W28S#*-Q)%])_/+
ML,@>[QQQ082MUA)+T)W,$6Y66*UOSK`ING5<(UF)VTTU^3B56ZQPL?)&N+H\
M;F)?"`5EI5!+T?P24(!H&`,76PAZ<+`?96<L03VR)+5J0=EZ4]VDA0&6VAYO
M87"V$:4T5T&VWJSAPP"8V.E'#?OU>$FNGN%Y@6%XO@7H<)DNXNMP->*J7XUL
MF_OPQ!=O_$`!`0`[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F]Y86YD
M<&,N9VEF```````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,U,0`Q,#0Q-S,V,S`Q
M,0`P,C,T,C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA0`!``-4A`/_>.?___P```%)24JVMK1@8&#DY.7-S<U)*
M$*V4*>?GY\;&QHR,C#DQ"!@8`,:M,7-C&.?&.8Q[(?_>4G-C,:V<:U)**5)2
M.8R$2CDQ(:V<4L:M0JV4.7M[>XQ[.:VE>XR$8P``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"'Y!`$``"$`+`````!`
M`$``0`;_P)!P2"P:C\BD<KD$.!^"J*`@-1BDT<,`RXTROT6G.-'H*@)HQ>",
M;J<#!$%#3!=/P,1Z'<)P^]L*5`,$!P<$;50/>G1)BXYT4&YQ$(^.D6@+`H=N
M6T<3E6((FP.9!`-S>J)M%72J:`,%?P)X0Q=J;@8#?VB$!`D`$0D0&(,&``FZ
MNY*T>4X($`D.!@RF:`=G`\S:S%13`X,$#`IJ`KFP40[9VV!C6(-=Y0P#?0OU
M"@0*#`?=L^N->J0.;=F%SXT"`YLP"9!0J0FH.IJ482I`L<`!!Q$624@68(`#
M"$H>+DH0D0$"D7I(+F@C@".O?DP^)6"PLHT!-E,*7`E8P`.D_P2*'B$PI\Y?
M`5,%&B!PH.\;Q:`(_$EM=NQD,`=E$&A%8*'`U*](!(7H)\6!!`15BH+]PB_*
MMV]7<L*KLM:(&"A2VL)C,-==72$0W;XK)[&-J4);&F34,U4/A"E8:K99@/`/
M3317@CK2]NAF@'J%)\?RX[%A3)%,0^_29[:.5FB_G"3YA%*,!`%_MIA=_#`B
MFI:?QQH(4[M.@TT'3A9WTH#C`=Q^8`Y9GFY<%+Z\(6F91Z$5QS@)7ZE%0AO`
M@S+@#*%I>F]`;``4T#1?5>?!6;>O_`$8))F`@<_A(7(!!2`PP$%*"!&@X((,
M$K`.!(2P$0`U`?S7D1@)-JCAAAKJY_^,,P+YQ\E?VY@GP`']39-0+B2VZ.)?
MPPTQG@$6O$B+7E7H1,`"6L3%A5<V&H'C%`901`@5%4DQ7HNRA>"C`5H8&4<Y
MS_75DHMT.`#/D.=8&6-==-SFUI1SZ;1%%$,R"0PT4ER#A7^2%<:7''6`58>6
M44#)ETMJY!+@9XD\<L<ZJ701)R9_$##:%I0\0F@="11PQI0$A;=20@=AY"AG
M>L3W"G2J$>*'`0Z8AH=0ATITSP'B&"2`<IM]49XC$8PFIP('Y%+(&6HX\%ZL
M(:$D@:W*A*/``A4AH)D8M0X0%T,.%=>`A7Y0%D4#$F2@U+)T'-<&+%?\LQQ)
MI+VZ'*@!"-#_`2=7`K:<&.@6T&AQ$E`;AX2O?#EK<:X(D%UM)WY+;1K2A?#N
M`Z080L6O]4'PS![$^M8&`T`2)U*]'9FBB0'SUF'*(*R$<H!AZ*)1L;B0GN7`
M**5\0T<P'ZQ,GQC3SN/?7*<>,_)D.V?<'C024*#@`0]80`T#';LVRCH31#"(
M&X5@]DT?F,"Z004,!Y,`27UM,\$@5`>@0,D&#=+`UB__@DRHVR`00,\=X=@`
M158H5087"-QMI1?::'`--0I"60UEH1#UUN&()WZX/P]LC0H"`VQ'S0*F.!#D
M%Z'\H@K8U^1W>1,D74:.>M9T]+E#":#5$DVX4KE`(*>C#BL")-%!!E+LN&\3
M!``[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]B<F5T+FIP9P``````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$R,#`W`#$P-#$W,S8S,#$Q`#`R,C4W,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#_V/_@`!!*1DE&``$!```!
M``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q
M008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+C
MY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&
M!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R
M@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR
M\_3U]O?X^?K_V@`,`P$``A$#$0`_`/[X*^(_^"E/CWPK\*O^"?O[9?Q1\8^!
MOAI\3=*^&O[-_P`6OB!8_#WXQ^$+7Q[\+O&?BWP9X.U3Q)X!\.^./!]ZCVVO
M:!JGCK3?#EK=V;M;L/,2>*^T^6)+ZW^W*_FH_P"#FCXG?MA^$_V7O@Y\(OV:
M?&6B>&_AM^UCXW^(G[./[2FDZ'X"N?B'\>_$/PXU[X7:YX\U\?!_P_/-9Z+J
M>F67PH^'WQHM_'GAZ/4=,\=>+[C5?!7A?X?7]MJFJ7T@RKUJ>'HU:]:2A1HT
MY5:LWM"G!.4YRMJHPBG*36J2;2;T+I4YU:E.E37-4J3C"G%;RG)I0BKZ7E)I
M*^EVKV1_%7_P3SL/%V@_&/\`9)^*OQ;_`&D?V/?V:_@A^U'\3?'?[0/C+Q-X
M"USX:_!/XQZ1X4^"WQCU73O&7[.OB>W^$MO\,?%/PS^'?QR\>V/A^?P7\-+C
M4H_AM:>$_#&@>)/`%CIEGX-U3P?JGZ:?\%*O^"S7[/<'[8^F:=^S]^U1^W3X
M-'PQL=5\">,?B1^SKXI^&'BC]FQ/$GAO3?$NI>&]>\/?L^_$"23PI^T/]L\<
M^)H?#/Q-UKQ!XF\`:3-X6\$VJ^`[_P`:Z?>6>H3_`&5_P1K_`."-W[&_PU\$
MW7[3</Q-L?VT=#^-?@+Q5\,[:U\?_!_3_#GPM.CZ/\6XGUV:X^%/Q+TG6?$F
MF>+=)\1_#32]`O;;Q1,EUH&JZ1XB`MBNHQ0Z?^4?[6__``;F_MQ:9^U!\6K?
M]D_0/@]XQ_9V^/7B._ETWQ%JK?#CP5!\'/"OB+QOI7Q`/AFX\-:S9ZAX@\(P
M^!/$.A:;X8TWQ-\"+'4=<U_P+'_8XT_2M!\7^+_`</\`/5?B#PYXCX[Q\\TS
M*>`AE&68G"4/[1I4LLRW%8NK4:S*5:CF6#A7>88=QIT'A<:O9XJ5!6P]9^VA
M/]@CE'&>3<*8.C@\%'%/,,QHXF?U*M/'XNE0I4X/!*E5P.*G16"K7J5%B,*[
MTHU6W6IQ]C-?V+?LR_$.]M_V3O`_Q0^,O[1OPI^-MOI_@O6_%?B/]IWPKIFD
M?#OX9^-?`^D:GKE]I7Q&U'2I=9U31O"<J^!K'3+SQV;;56T2R\26GB"2RCL]
M*FMK6W_,GXP?`;]I[XT?\$G_`-I3PCX\NK?P7^TE_P`%>OVZO@EXK^!G@#Q1
MIE_X)U+P'X!\=>)OV8O#OP\^%7Q@TVRTRRM_"7B#P/\`LH?LW:I??%?1+V_U
M:6^.D:WX5DUOQ7XWUN'2-5^*_P#@H#_P3@_:&^$/['G[$_[&7PB_;-\7>./A
MUXW_`&E?V:/V:(O@O\8?#O@/2/@]JWB3Q)-XUUNZU;Q1XS^&_@"T^.&H?#6?
MQ]9Z;JEIX!UKQ1XMLM#T58K:T;5-0\.>%;K1OVU_X)WZM^V+^W;^W7XO^,G[
M8_PW^#OPU\%?\$P_$GQ%^"GPYT?X#?&6^^('@[QC^V'\4/`>FV'Q$\9WLEN\
M5Y?K\+/V</B(O@1?#GC.STL^&?$?Q>\0$Z7>^+K#4[+X=_GG"O!/]M<4Y%BL
MDS?)L=E%;BF7$N:.GAHX#,\)DW#&:T<=E-#"8"MA\.WA\TS=X;#YM2P.#C@L
MN^J82-'$SI58J.G'>=XMX7"Y7CL'7P57+LNPJ:GB'B56Q^+P:HU).K3K5X35
M&E3G+#5<56^M5(SQ$YP527*_Z0K:VMK*VM[.SMX+2TM((K:UM;:*."VMK:"-
M8H+>W@B5(H8(8D6.**-5CCC5410H`!4U%?V:?C`5^"/_``5:L?$OB[]O3_@E
M7X*6.]U3X>>'-$_;J^/OB;0TE6+2['QG\-O"7[/_`,,/AQX\OPM[93S77AH?
MM`>+?#6F0XU*T\SQ[<SW6D22P6FK:-^]U?BK^U)XLT?Q3_P4>L?!\^DWI\0?
M`+]D#P%XDT/6&U"*XT^;2OVJ_CA\1++Q5I4.E16EU>Z?>QWG['/@FXN;R":)
MM5AN+2*YT^Z&E:7<)\+XEXW^S^!.):^MYY>\)'E;34L?6I8).Z:MR^WYF[VM
M%WOL_LO#W"+&<:<.TI6Y:>80QDE*/.I+`0J8WV;A9N?M'AU3Y(IRES<L=6F?
M,_[%_P`/WT7XM?MV_$[3=0\2P^#/BA^TW:VW@7PO>:TUYX+T]/AG\$_A9\/O
MB=XK\-Z1!K6M:?8ZAXG^-6B?$ZU\330M'>:C-X;T^'48(YK%[5OO<^423O?)
MWG`A11G/R#"RX56&2V!B,X55<<C\+X?'O[;'_!,RXEG\7?#KPW^V1^P)+XG^
M-/Q"\7_$/]GOP+XBM_VP?A?XT^-WQ=\5?&CQ#XG\<_#/4O'VH>#?''PYTKQ7
M\0O$6GW;?#W2]/UKP_X4:#Q1KHTU/!]S:>-?V,^$?QA^%?Q[^'OA[XL?!?QU
MX8^)?PX\56]W<^'O&/A/5['5-&U$:;>SZ9>0K(D2RP7VFZA:W>FZOI-[#;:E
M::E:W-GJ%I;7EK/!'_$/$F`Q<:RS15J&899B%0PF$S/!R=2C..#PU/"X>EC8
MR2K8+,JF%P\,17PN,A2Q,G.=91G!N9_3.2XN@E/`2C7PV8TI5L1BL)BXPI5N
M;$XBI7KU<.YRG#$X&.(K5*5*MA9U*490]E>+2C'P7]K;]G7PC\=#\#_%/C3X
M[^/_`(%6W[/WQ?T7XW>"];\$ZA\']*LO^%KZ%I][I'@K7=?NOBW\-?B!HEZ/
M#,&N:\-,\.O;Q^']0EU^9_$6E:S>:;H4NC_.?[`6F?#K]FS]IO\`9W_9P_X)
M_?M/?%?XP_#O7OC-\3=;_;F^&]CJ'A?]I+X?7^L7?P)^-NI>(?CI^T3\?K;X
M7^,?%/P,^..O?%CPU\)+'^PK3XK_``\T+Q[K]CX=\*3?#2RC\87?B2/S3_@M
M-^RYK_[<OPQ_9(_8L\'W_A_0/&W[27[8OA7P[I/C;Q)HOBK7(/`6E>$/@A\>
M_BAXN\:6>F^&I$N-0N;+PWX,O-)G@U$?V,VGZO?W=Y+I<=E_PD^C?!G[*WPX
M_:/_`&`?VJ?B!^R5\'_'6F_\$\_VV+OPSI7Q=^'O[*LWQ6UCX[_\$Q/VQO""
M1W_A'5/BSI7A/X@V5A\6O!WB3Q-=_#O6=(\1ZEHGC+PQ\2O"'@OP9I?B1+'7
MM/T'Q=I5K^K>'N)I<*9'EG&V=9OQ%A>'\/BL;0QE/)\KPU7+\'A:&)?[_/*T
M9SS/'9<ZN(QF(KPP.`QLLLHT*^-Q57`X:"K'Y7XA8O#8K,L?DN&RK*JV85,+
M@ZCS#%XC$/%J<J:<:6"IJU'#5(48TN1UJM*%9S?[NK4J.+_O3HK^*>]_X.^Y
MO@[>W?PB_:+_`.">/Q+@_:#^%EU<?#CX[0>`_B+H5AX&A^,O@>5_#/Q/B\&6
M-]IOB^]LO"D?C;2]<3P[:7GBWQ1=6^D"SAN/$6MS(^IW)7]>TJ]"O2I5Z%>C
M6HUJ<*M&M2K4ZE.K2J14Z=2G.,G&<)PDI0G%N,HM--IIGX4X33<7"::=FG&2
M:::335M&FTF?VL5^87_!0;_@E5^S_P#MZ3^%/BC<_P#%FOVP/A$NA7GP!_:U
M\'Z0NH>./AWJ?A3Q/'XR\.:/XL\.'5-%T;XO_#"/Q`+UM6^&GC2Z-A)I^O\`
MBA?"^K>$-;UZZU]?S)_X+]?\%O/B'_P3UO?#G[,7[*FE>%;G]I[Q;\.;7XR^
M+_&GQ$T35]6\*_##X.:IXQE^'.C7OAC2;66PL?%?Q(\2^*XM2?3+?4M0;0/#
M6C>&=1NM;L;^[US0XHO\]+]H7X^?'/\`:X^)6I_&/]J3XK^*_CI\3-8"?:_$
M'C.6R73+!5T[2-,:T\+>#-'M--\&>#M,:VT33E&G>&M"TZ$F`/,9Y7DE?'%R
MP[ISH8BG"M3JP<949Q4XSA/FA)3C)<O*XW6[;NURI:O?#*M&I"M0J2I5*52,
MHU8MQE"<'&<91:=^9.S6R32=^W^A%^SE^T=XN7XW?M"?L9_'+6?`,?[6_P"R
M1KOAK2_B7'X!U`0>#_BMX'\8^%=`\:^`?C#X-\+ZEJ%SXBT;3-;\,>+?#\7C
M?PQ=OJB_#KQIJ3>'1XAU".[TF[N&?%G]EK6=,^/MO^WE^RU#/IG[1^C^"]5\
M.?$GX'+XKMO`7P<_;'\/0Z7=V=CX?^)VKV>B:S+X=^)6@I%H\G@3XL:CIM])
MID^B>"_"OC"#4O!<&GS:3_$+_P`$I?CM:?LE_MN_"WXM7FE:CI7PH\1:A:_`
M3XR^)-"TM[FUT[3OC1#K"_#G2[G3X+JQ2]GO/B!X)L/%]S!IL6J^($\+_#WQ
M/J&GZ)JS::EM7^AY\-OB!X&U_P`9>.?A]H_B+3;KQ_\`#VW\-7_C7PP!<)K6
MCZ'XTLKR[\):I<6]Q;P`:/KLFD:S#I&LV$]WINI7^B>)=(9SJ?AR_AT_^,_$
M;(*G!/$E?$Y)AYT<IS7+IUOJ_)5J81X.O-83,<MQ/ORD\*ZTZ3CS5(3H+%X1
MT*M&O&A5C_5O".=X7C+A.E_;-:G4SS*<QH8.6)=6E3QE;$**Q&7X^GI2OBXX
M:G62<J=?VRP6+]I3JPG6C'Y6_:3_`&J+_P#9B\6_\$K?VD?C'I]C\(]'U/\`
M;`\#_#?X_>&M7\?:-'X4^&FF?M"?LO?'KP+KK>,_B3I^FW'A_4/#GP@\=Z[H
MFO7NN26VG^'O%%YX6L7;5O#EK.FJV7O7_!Q7X!\!P_L`:O\`M1MX@\"^`?V@
M_P!CSQ_\.OC3^S5X_P#&.NV/AJ63QMI'CKPW-XC^&&G7UU<6LFMM\5?!%IX@
M\-IX-226'Q#J/]G)=P-8V]VP]A^+WPB^'GQW^&7C?X-?%KPM:>,OAI\1="O?
M#7B[PSJ%_J6FP:UH.JJ(IX$U#2;W2-:TZX#1PW%EK.B7^EZMI5W##J%A?6=Y
M;VUQ;_PZ_$W]OOQ[\*OAOJOCGQ!\>OB]\;_VL)?`WC/]CW_@F_\`M#^(M(TW
MPEXT^&/_``3^\&_%76[KQ5^U[XB;4O$&O7/B#XL_M-:9KEU\!/AC\0-,\/V?
MBZP\-?#+4O'C?$2XUW1[J#Q)^H>!N;X'.>%,YX;Q>6TZE#*\7[;$4ZU*.*P&
M(PV<5,15HX>5*M[6<E3JX6M"5/$*K&5/V<Y5IWG&G^3^*^5UL%GF7YM2Q"D\
MRPZI049*GB*=;+HX>G4J.S5.*E3Q%&<73<&I\\8T5RPE5_HZ\$_\'(O[%FG^
M#/"5A\8?BOH7P@^+=CX8T&S^*7PE\8?#/]H;6O%OPN^(UMI5I#XW^'7BG68_
MA[I2:MXC\$^)DU/PUK>III>FI?ZGIEU=+868E%O&5_GF_P!@Z0_SW6GV>H7+
M?-<W^H6EK=7][.W,UW>W4D)DN;NYD+37-Q(2\TSO(WS,:*^$J_1'\-YU:DZ?
M$GB'AZ<ZDY4\/1S?()4:$)2;A1I2Q'#->O*G2C:$'7K5JSC%.K5J3<IR^36?
MXQ))X3+9.RO)TL0I2=E=OEQ$8W>K?+%1O:R2T/ZO_P#@Z656_P""H'BDLJDI
M_P`$N/@RR$@$JQ_;=U9"RD\JQ1F7(P=K,O0D'^5>BBOZLQG\9_X8_D?/8;^$
MO67YGT#>2R:=_P`$[OC)XIT^1[#Q-H__``4`_93M-(\16;M:Z[I5KIW[.?[5
M.NZ?;:;J\!34+&WL=;O;S6+.&UN(H[75;NYU"!4NYY9G_O4T+5=4M/\`@M#X
MIT&UU*_MM#UW_@F5X=UK6]&M[RXATK6-9\,_M??$73_#>K:KIT<BV>H:GX?L
M/%/B>QT2_NX9KK2;/Q'KUM82V\.KZ@EP45^%^-_\#*_^R;S[_P!3N&C]5\*O
M]YS'_L:97_Z;S0^[/VKM7U;P[^S!^T;XC\/ZGJ.A>(=#_9X^+&NZ+KNC7MSI
M>LZ/K>G>!==O=/UG2]4LI8+[3]5L+R&*[LM1M)X;NUN8HYX)HY45Q_GL?\%3
M;"QT3]JVY\,:-96FD>&O!OPQ^&_A3PAX>TRVAL-#\*>%K#2KG4+'PUX;TFU2
M*PT/0+._U;5;ZTT;2[>UTZWO-3U"YAMDFO;EY"BO%^CS_P`B_B__`*_9#_Z3
MFAV^+G^]<.?]>,S_`"P!^<M%%%?T(?DA_]D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B=6YN
M>2YG:68`````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,38S`#$P-#$W,S8S
M,#$Q`#`R,C<U-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S
M`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,
M`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S
M,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,
M,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S
M,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,
M9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS
M9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,
MF0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DS
MF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,
MF?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8S
MS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,
MS,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S
M_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,
M_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(?D$`0``V``L`````"``(```"/X`
ML0D<2+"@P8,($Q8DP;"APH<"&:ZP$JAB("LD(")D2/&BE8\@,VHD2`*D29,K
MD&ALR/&DQ9<K1!Z4V+'BQY>L<NID57'%S)H[*^Z\1K0H4588%PK5>32GT:<Z
M`_DDJ2<0JVNL5JQ@9>WETJ`]%WI*=I6G5BL\I0(@L<*K5(8&`7PB._3H10`1
M6<J,^ZF4M6O6G-J5.G(@B3U7L0KFF7:OQK9U<UI-&[,PMK:3=0I*G-9*3,<)
MV7I-/-AF98A(,`LV*ODE:(,DA#XU&CCHU(T42<\._-5L:-F[=_(4!$WR:VRQ
MK09?+9SP3^50=1>-FO2@ZJ?09[>^71#`]:+99U%CO7C\.]'-XJ?W/)Z[*&_I
MZC-S'YB[J]#)TSEG9^6X8]JT%CG%RBI_,38=7O0I9V!ZX_TWW5Z0_9>9<*U=
MM%5.\P&@X88<=N@A`$B0L)9``0$`.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+V-H87)L:65?8G)O=VXN9VEF````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(Q,#$`,3`T,3<S-C,P,3$`,#(T-#,R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y82``(`#W````
M`````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`
M9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`
M_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S
M,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\S
MS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F
M`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]F
MF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F
M_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^9
M9@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9
MS)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,
M,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,
MF9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____
M``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_
M9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/__
M_P#__S/__V;__YG__\S____XOR0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```A^00!``#8`"P`````(``@```(_@"Q"1Q(D""`@PB=*%RH$$!!@P@C,ISH
M)*'#A]@`4-S(4&/#BP\]<J0H\B/&DB,7HJR(,>-$$C!CREP)LJ!,F"EI8B3!
M\:;/F"P?_OSYK*A1HR1J8@.J\&914@J/2GT&$J<3F5!)Y=FZE12IJ4=!-N7I
M->M7L&BI#H0I$`!8)V>?.4FKMJ!;HV?G'H6:5FE&HW,UXKW+=RI"NT7A4M7[
MC!1AQE-)D1AX,''>KW'ETI7<UC'@O(J?TFT\.:/GT:B?E39]-S5:SA!=IW4<
M4C9:OVUM&V[9&O#'B+M;_I6KT&ODWK2%#Y?M&#?BU,W9('$>>_9!-M*G*X=X
ML&QS`-BE'V/7OMTNPO#CPY,OWQ:)^^GJT4NG;O?]>_!(Y,_'%A``.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8VQO
M=VXN:G!G````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,S0Q,@`Q,#0Q-S,V
M,S`Q,0`P,C(W-C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````_]C_X``02D9)1@`!`@$`R`#(``#_P``1"`"^`)8#`1$``A$!
M`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H
M(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RO_Q`&B```!!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!`P,"!`,%
M!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()
M"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!
M`0````````$"`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&
M$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KB
MX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`
M"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@!'
M=44L[!5`R23@"@:3;LCSKQ/\8?"^@Z@MFUP]Y(,B0VPW",CL37+4QE.#MN>]
MA.',9B(<]N7U,G_A??A?_GC??]^ZS^OTSJ_U2QG=!_POKPO_`,\;[_OW1]?I
MA_JEC.Z-;P_\8O"FKK<F2[-B8<<7(V[QZBKAC*4NMCEQ/#>-HM6CS7['5:+X
MLT+6HYGTW4[:98B%<AP,$]/Y5O"M"6S/-KY?B:#2J0:N:+:G8*,F\MP.G^L%
M5SQ[F"P]5[1?W'`?%+3-4\4+96_A[Q)=:&;:0R230?\`+7C@>]<%3,(QE:"O
MYF\,%)QYI')Z;8_$OP?$9M)UV'Q=$!))+8WXV2,<#&Q^N>.GUIT\PBW:2)J8
M1Q5TSHOA1\9M(\<W$FEW<+Z3X@@4F6TG.`Q'WMI/7'H>:[TTU<Y;.]CTG^TK
M'_G\M_\`OX*7-'N:>PJ_RO[@_M*Q_P"?RW_[^"CFCW#V%7^5_<']I6/_`#^6
M_P#W\%'-'N'L*O\`*_N#^TK'_G\M_P#OX*.:/</85?Y7]P?VE8_\_EO_`-_!
M1S1[A["I_*_N)(+RVN'*07$4C@9*HX)`IJ2>Q,J4XJ\E8GID!0`4`>"?M-^(
M-3LQIVDVEP8;&Y1GF"'#.01@$^E>;CZDE:*V/MN$L'1J<U:2O)/0^>*\H^^L
M%`!0`E`$D<LL0/E2.F>H5B,T[M$RA%[JYVWP?T*[\3^.H);EYSH>C_O[ER24
MFF_ACS73!*-)REN]O0^(XDS&I'$1PF%=N5>\UU;Z>B/I-W,CL[=6.<>GM7*>
M*DDK(0$@@@D$<@CJ*!GB_P"T+X$%S9?\)OX=MWBUVR<&^CME_P!?'_SUP.X[
MUZ&%J\R]E)Z,X6Y86M&M#H[K_(\@BU"6YACN(;F4QRKNX<\'O7#)2A)P?0_6
M:4Z.)IQQ%-:35_GU'?:KC_GXF_[[-+F9I[*'8/M5Q_S\3?\`?9HYF'LH=@^U
M7'_/Q-_WV:.9A[*'8/M5Q_S\3?\`?9HYF'LH=C2\.>(]3\/ZQ!J6GW4BW$1Z
M,Q(<=U/M5TZLH2YDSFQ>`HXFDZ4UHS["^'/BV'QGX:AU2&%X')*2QM_"XZX/
M<5[M"JJL.8_*,TR^6!KNDW?L=16QYP4`?.'[4_\`R&=%_P"N+_S%>5F/Q(_0
M.#OX53U1X97FGVH4`%`!0`Z**>XEC@LTWW4K!(5]6/0_AU/L*J$5)V>W4Y<9
MB'AZ$JD?BMIZ]/NW]$?5/@'P[%X3\(6.CQ$%D'FSL&R'E;EF'XU=:ISRN?F%
M*#3<Y;LZ"LC82@!\;!7^895@4<?WE/44TVF14@IQ:/D+QEHL7A'QYJOAN)D:
MWW_:K4JV=JM_`?>NK$1<X*M\F?1<)Y@DG@)]^:+_`#7^1GD$=17)<^T::W"@
M`H`*`"@#ZM_9L/\`Q;I?^OA_YU[6!_A?,_,.*_\`?O\`MU'JM=I\R%`'SA^U
M/_R&=%_ZY/\`S%>5F/Q(^_X._A5/5'A@YZ<_2O-/M5KL1R/,`WV6RNKUT(5A
M`A8*?0GU]JJ,8OXY*/J>3F&=8?!2=-ISFNBZ>K[^1#97HNKF:U>"2VO(3AH)
M>&JZM%TXJ:=XOJBLJSBCF,I4X+EFOLOJNY+IT6IZ[J[Z?X9M$O)(4+3R/PJ_
MC4U70PU)5<5+E3>G<\S,.(9T\1]7P45/E^)O:_9'H'P.\-WUY\0KJYUJTA*:
M-$!F*3B*=^@/O@-^=;QJ4OJZG1;M)]>R_0^9S#,*^/K)8A)<BV6UW^I[_P")
M=8MO#WAO5-:OVQ;V<)8<9W2$?*,?7%8TH.<E$XZ]3DCH<5\!/%VI^-/!-]?Z
MVR27EM>^6LBKMW(W0$>W:M\71C3DE$Y\+5E*5F>B,<*Q]!FN0]!;GGWB_P"(
M1\+_`!;T;PS?1VXT74($+W#G;)%(V<'=TV].,?C79##J=)R6YYKQ,U4,O]HK
MP2FM^&VU6TMU;5M-.XRQ*?,FB[@8Z\=*,+5Y9<CV9I5C>*J0T>_F>+3:'IMM
MH.G>(]#OKYM&FD,-^MPF]K9NQX[9XS7G1Q=:=>>$KQ7M$KQMI?\`K<]O+\RG
M@Y1K0DW3D[2OK;S^10NYXK:/S"QD5O\`5+'\QE]`HK>G"4W;;OY>I]WB\91P
MM+VTW=-:6U<O0NIH/BJ>P6_MM#9;7!9HY6_>D#K@5B\9@(S]E*K[WEL?-SXC
MQ4FIT:"4.J>_R,W3[V&^A:2,F-D)$D;]8\>M=-6C*D[/7MYGO9=F=#'TG5IN
MUMT_L^OD)9ZC9WDC1V\X+J?NMP6^GK14H5::O):!@\VP6,FX4*EVNCTOZ=S[
M!_9\TZ[T[X>6XO(Q&9I&EC&<DJ3QFO7P46J6I^=\35H5,<U'HK/U/2ZZSYX*
M`/D[X]^)+CQG\1H/#G@ZQ6\O-.0I/<E@8\GDC/08Z5Y69U,/1A[7$2M%?>SZ
M/),VQ&"A*&'BG)OKLD8VC?#35[BRWZ[J%K9W3-@PPC+1IZ@]"37R6(S[#PG;
M#P<EW?5GUF'SC%UJ,O;JTG\+CI8](T73;/1-.BL=,A$-M'Z\LY[LQ[DU\YB<
M14Q%1U*KNW_5D>?A\-&E#E>KZONSGO'/P^T_Q<#=$O9:LJ;8[N(8#GMO]17H
M99G=;`>Y\4+ZI]/0Y<7@8S?/3=I=T0>']`L/ACX)U&XGF9K@QEKN[7^-OX50
M>F:TQ>-JYSC(1BM+^ZNW=LPP^'IX*BYS>MKEOX$I_P`(OX0O?$7C+4_L*^(+
MQ7B-RISP#M8_[V3_`-\U]O7IKW:5):11X=&H]9RU;95^+7Q;\&:UX!\0:%I=
M[<W%]/M6)A$0DA!'(/I6N'PM2$U)HSKUU/[BI^S?XL\*>'O!5WINI^(8K;4;
MB;[3)'.NU(U7C:I[DT\92G.5TB<--0:E?H>ZW%U;0Z?)>SW$45DL7FM<.V$"
M$9#9]#D?G7G<K;LMST_:124CY7_:5U_1M:^(^E7NCZE!J%I%:Q"22W;(7#9(
M^N*]G"P<:;3/&J/WKGMVG?&+P#K3?85UB6S(M54R7,153A>0/>N">%J)\UCL
MIXA*/+N87A/PJ/#FFSV$-];:SX;OB9K%C'S)$_+!_7K7R7$<E]:C4BG&5M_3
MMZ=3VLJI\U"4)[7*GAKP)H_AW599XY(YR'+V-M<,"UMGV/7VKAQF<8C%TE%J
MVGO-=?ZZGJT91I8>.%3T3O?UZ+LCK69PY+%@_?->2DK:&R2MIL>6?$+P$-4\
M2Z;)H4$MN=29EU1H@!&B#'S^Q//UKZG*<Y]CAIK$-/D^"^]^WH>-B*5:G6<:
M#LJBM+S1?\2?##1I/!;:?HD#+J-BK2VMT3B29NI#GT-<^$X@Q*QGM:[]V6C7
M1+R%6RQ0HKV>DEMWN>M_L\^/]*\0>"--TR6YAM]:LT,,UI)(-[;."X'H:_28
M1BHKEV/EZU:I5J.=5WD]SUT<BJ,CS;XR?%*V^'UK!;165Q>ZU?1L;&%$RC,#
MCYCV'-3*481<I.R0XQ<G9;GEWP_TJZTK0II-3MX(-7U&=[F\,(Y8L<@'TQGI
M7Y=GN/CC<6ZD'>*T7;Y'VF5X3V%)<RU.C`'I7CGIE#6]2.F6<<D<#7%Q-,EO
M!&.`9&.%W'LN>IKMR_`RQM=4D[:7;\EN<N,Q*H4^:URKI7PMUN[NQ>^+O%]V
M7E!::PTSY41CT"N>,"ON:>'P%&*C"DG;ON_,^:=3&5'?GM?^O4SM5^!=YJUL
M;;4?'M]<6H?<D4ENQ`],^IK>C+#4)<]*DDS*K#$U%RSE=>J/6=&TJ'3M`TW2
MIA%?)8P+`LEQ$'W;<X;!Z'FLY59.;DC6.&BX<LNYYS\=/!'AJ7X;:[JT&AVU
MMJEJRRQW%HFUF8GG<.FWVKJPM>;FHMG-B:$8;=AGP7\&>%-5^%&@7NJ>&]-O
M;N1I-\TJG<Q!/)-/%5YQFTF3AZ$:F_1'INHZ5I^J:9_9FI6<=SII"@VK$A"%
M^Z..P]*XHU)1ES+<[IT8RCR['S]^TSX3T'1M-\*+H.C6>EBZF=9I+=#[`9]?
M6O4P=:4[\SV1YM>DH2<5W/9/#_P\\*Z'I^DQIH.FW-[:V\;"]DBRSL1G<5/?
MZUQ5,34;T9TT<-"<>9B^.O#FJ>(=/BLM&UJ#0X`/G9+8LW7(V8^Z/6N=T\/5
M:>(CS6>AO+V]/2AHCD=2^!FAW]F9%UK61XC(#?VK-+N5G'?8.0*Z:=>G"*IQ
M@E'L83H5FW4<KO\`KY'%>`O%NK6_BVZ\&>*HYIM0AD<073+AF`Y^<>A`R#7S
MN>Y+2I4OK>'TCU7^1Z>79C-U/95=?,]-R<$9.#U'K7R1]$&3G(/-`'GWQ,\$
MV5]I=UK.C6QLM>M09P]J"#<XY(8#OQVKZ+(\ZK8>M&E4E>F]->AXF8Y9"<'.
M"U/I;X=ZG=:SX&T+4;\*+NYM(Y)0JD#<1SP>E?I35F?(IW.,^+E[HEKXDT)+
MZYM8-6FCD2V\T88KQN&[L*^1XJIXF=./LTW!;V_#0][)*M*G*7/N]CG%9'&8
MY(Y%_O1MN4_0U\"TUNK'U,)QFN:.PIH*)].U*QTO4+>?4[B.W@D<0K)(<+O;
MA03VYKU<EO\`6E97T>QQ9C)1H._<[>Y:.T662^FCM8(5+RS3-M1%'?/2OLHP
M<I<J/"E5C&'.8/@GQ"_BK1IM6&G2V%BURT5EYQ^>YB'_`"U([`]JNM25-VO=
MF5"M*;::T-ZL3I$E1)89895#Q2H4D1AD,IZ@^U-.VHI14MR#2=.L]+TV.RTV
M&"RT^#)5!B..//7VIRDY.\F2HQALM?(CEUC2(KN"UEUK3%N)RPB07*G<5QN!
M/;&15^QJ6O8YXXVE)VB]A=2TS3=?L'M+R.QU6TBD$CQ(ZS"-QT)'8TESP=UH
M6JE*J_\`,N9R%]`H4>P'05F;J*BK(-I8%595<@["WW=W;/MFFK7U%-R46X[G
M$>#?'R:KX@F\,>(K(Z%XM@8@6KMF"Y`Z&)CSDCUKJJX>T>>&J..GBG>TSRGX
MWV4MI\;O#S:+$L>I7"HTR0.!(W/S;\?[(/X4JW)]0JJOLEU[]/Q)5_;Q=/N>
MGOC>V.F:_,%L?:J]A%^9@`1D]*>PWH9G@:34/&GQ"GL=.W6?A_17'VZ9DRUW
M)VC4D?*![<U]ODO#M*=!5\1JY:I+HOU/F,PS:K&JZ=/2Q]$@```=!7VBT/GC
ME?'W@#P]X\M+:#Q)8_:!;OOB=&*.OJ-PYP?2BX'S+-K(^$GC2^\&Z\SS>'_,
M\ZPN5!+P(W(!]1V-?+9_P]/%/ZS05I]NDO\`@GM9=F+H6A4VZ,C\6_%NWAMV
MA\%P/J5UY9>6YDB.V`>H'<UYF5\(XC$2;Q*:2Z+=^OD=V*S>ZM15_P`B]8Z[
MH'C[X:RR^)+U+40J#?&,X:&0?==1WSZ5Q5,)B\KS%+"QYKOW?-=4_0:KT\7A
M'[3=&;\,AXO^(YL?#OB"ZNI?`NGS">2>6+!N$7[D9;N#Z5]Q4E&E#F6DGT[,
M\",74E9:_J?2SL&8;5"(H"HBC`11T`KRF[NYZT(*$>5#:115UG48M&T2]U6X
MA:XBM5!\E3@NQZ?A2E+E7,;X7#2Q6(AAX.SEU['B>O\`BG6_$=LL&L72FUW>
M8L$(V@>BG'4"O,JXF4M+GZ#@\IP>"DY4(^]:UW^9Q5YX4T:[`\RU9&#%MR.0
M<GK6U/,\5#:5SDQ/#^!KJTH):]--S%U8:EX!N+?7?!M]=V>&"SKYA8$]L@]0
M?>O6R['/%2=*OJ^A\CQ#D<,#!5L.K1V:_4^H_AUXD3Q=X(TS6A<)/=2J4O65
M=H$XZC';BEB*?LYM'C86IS1L=$>1@]#Q6!U'$?%#X;VGCQK&Z.H2Z5K]@NVU
MO$'#CJJMW&#WKKH8ET]'JCAKX>_OP/#?`OV_PQ\6K[3O'T,IU^[7RX;ZX?(!
M[,&/4,!@'WKBXCHSKX)3H/W8N[7?_AMR\LJ1IU_?UN>A_$7Q7_PA^C0W$4*7
M&I7,OEVULX)$@'WCQZ5\GDN52S/$>R5^5+5K?R1[^88[V$5RZMG$VOQ,\9:I
M'+%IOARVMKC<L:SN"/*8G`.#UK[*GX?OEE4DY.,=UW/.IXS&8B\*<-?,^GOA
M'X/G\&^%S;:A?&_U.[E:ZN[C&`TC=A["OH*4(TZ<:<%:*6A\Y4E*4W*6[.VJ
MR0H`^:/C/''+\1+H30PS;85V^:@;'TK]#R.A3J8"+DKZL][!.]!75_4XV%(X
M"QMX((2XPWEQ@;QZ'U%>O'#4HWLCK4K?"DO1'%W?A2W\1^,M/\,^&[>&VN;@
MF6ZD\_Y=HY.1[=<=:_/^)(X7"R2IQU6OW]#RL5"GSJG35N^I]7E].\&>#$$L
MHM=%TN(+\S_*#['@DGTZU\'[]66G4V7)26NYYAJ?QYTQ;T_V'HVHZKIJ@;KN
M.)E`/<8([5M]64=)S2?:Y4)5:BYZ5.4DNJ3L=[X,\>>'O&<ERGA^^\^2W"EX
MW0H^".H5L$@'C/2LJM"=/XD%.M&>S-'QGICZQX2U"T@C:6[4>9`BMMY'7Z_2
MN:K'F@T>KE>*6%QL*LW:.S_KIZG@=O,D\(>-U8`[&*GHPZCZUX]2$H2<9*S/
MT6%6G47-3DFNZ=R2I+.,^(]R]U%::#96\UQ?W<BLB1J23SP!ZDU[F2T'SNNW
MHM#XKB['0]FL*E[SU/J7P!H*>&?!&BZ0MJEK/%"'NHE;=^^/4D^M;UZG/-L^
M3PL.6+9YOXZ^,%U;:_?^'/".GK<:G;%HY;BX.Q$.,'`/)(;/M6GLZ=*FJM9V
M3-Z-*MC*KHX=7:\[&)\.?B_?:/?0^'/B&'>2:4>5J;$853V?'!&>XK1TJ=>'
MM:#T[&5:%?!5?98A69W'QR\!6/C#PU+J9NC!J>FP&6VN@VY)(P-VWCL>Q&:C
M"UG3ERM:,QK4E-<\6>%>![JYU^-=8UJXEO;RT`M[8R_=A4#J!W;WK]#X1R;"
M4(2K4XV;D=&$G*LO:U'=K1>7_!.MN996C+F1VD3YD/<'L?>ONH1BG:VC.UR<
MM).Y]3_#_4'U/PAIES-=)<SF("21<?>[Y`Z&OR[-*"HXJ<(QLKZ'SF(AR5&D
MK'0UYYB%`'S5\901\1+O..85/!K](X??^P1]6>[@OX*]3B+F9;:VFN'4NL*%
MRH[XKU*]3V=-S[(ZFU%.3Z&W^R_82ZA)XC\5W3J[7$@MHT9<LG\60WICBOQ;
M.L7+$57*74\O#-U*CF^I5^/L:ZC\6-)TRX=Y;(V"R/;ACMSZD5Y\ZLJ.#E4@
M[.YW91AZ>*S!4ZJO'4ATW2KN>WE72=,GN8+=?WGV=<B,>]>!"C5KWDM;'Z>Y
MX;#*-.<E"^R?4YHZ2VE7MOK7A4FVU*";S28F*F5?XD]LUWX;,9QE[/$/W;6]
M/,^=SCAR$J;GA8I3O?U\OF?1'PZ\9VOC70CJ5G$;.ZMY/*N;-G+/`P[L3ZUV
MUJ7(TUJGU/BJ51MNE4^);K]#E_'?PI76=4NM7\+ZFVC:K<X,\0&893W8KV-'
M/3FE&M'F2^\WI5<1A6Y4)M7.4/P:\;`$KXOM">V8:7L\%_S[-O[6S+_G[^!U
M?ACX-:1I'B:PUV^U"\U74K?#!)CE6D'0@>@["K^L<L/9TXV7D<E6$ZU1U:TK
MONR3XZ?$>U\':1/IMM<NWBF^7]U'`_S6H/\`&Y'?T%7AL.YRYI;(PK5TER0^
M7]?U<\@\'Z`]C#"%@DNM9O6&]5.YY'/;/I[UY.+Q$\96Y(?"MC](R7+*67X;
MVE2RE:\F^AN?%CX?76FP6]IJI@DNY(O.M)H^,..J$?U[UO&-3+JRUT>YR5UA
M>(,+.5&+YH/2_P"#^?8]L^'5_>ZIX"T:?6]/^QW@@\B6V9,`JO`;'H175745
M.\7='PN&4K2A)6:?XGSKXM\/Q?#KXK?V?'?O)IFJQ_:$C`Y3<3M5A['O7V?"
MV8.-91D[)Z>5^AG0DJ5?EOHS<8$$@]17Z<CU&K'T#\!?^1#C_P"NS_SKX#B?
M_?GZ(\;,/XWR/1J^=.$*`/DGQ06/BO6BSNY^U-RYR?I7ZQ@K?5:=E]D^DI?P
MX^ASOB*4P^']1<123'R2NR/KR.OT%9YA/DP\W:^G0*KM2D[7T/9/@.8F^$'A
MSR?*R$D$GEXSG?\`Q>]?AN+_`(K.'!?"S#_:!\-75[I^F>)]&M!)=Z.Q.H21
MG$K6_;`[@<U5%*K3E1EU7XFD*SPF*A76B3Z=NI8^`GB6&'77MX[B!=,U1/,C
M:0X+2#H!_A7)E525&LZ-33H_T/K^):$,?@(8NC>3CV_E?<ZOXE_#%;J2;5_#
M4:QW39:>T7A93_>7T;^==>8Y8IKGIK7L>?D/%#II8;&.\>DNJ\GY'EGA#69O
M"6OSWD%LICN2$U&U88,@'\7^\*\2EB9TU[.3T7]6/J,=DF$QL'))*;U4E^3\
MCH+SXWZ9IVM7D&HZ%?KHJK_H%Y$N7G;NKCM[5[%*G3K1]R6O5=CX#&X3'8*H
MU6C\UJOD-'Q_\(9&[3-9"Y&3Y?0>M:?4Y=T<?MZW\K^XQ?$7Q=\1ZU!<Z?X0
MT-](CF;$6KW+8D6+U`[,:SE5PM!7E+F:Z([J.49ABI*+ARI]7M_7D<=HGAA?
MMLEQ.)]:UF9_,>YD!=MU>;7QU?$OEA[L>R/LLOR'"X"/M*S3EW?Z'T+\//",
M/@JRN/$OBBXCANA"0$.-MNG7'NQ_^M7KX'"1PD'5JZ,^?SO.)9K4C@<%&\;_
M`/@3_P`D>(_&'Q=)J-Y>>(K-#"A=(X8ISG<@/4#L37!&4<;C.5K3\CW*RJY'
ME2A!IRB[OY]/,^B--G-UHNDW#`AI;*)\'MD=*TE'E?+V/BZ53VEYVM=W^\\-
M_:7;2_[<\'(@B_MWSR92/O\`D9^3/MUQ7T'#O-]:AVYCCJ_QXV[_`/#F3+_K
M'K]ECL>O+<]_^`C*?`J*&4L)GRN>1SWKX+BA/ZZWY(\3,/XOR/1Z^<.$1F"J
M68@*!DD]J$KZ(#Y)\3,K>*=99&5E-RV&4@@_0CK7ZS@TUAJ:?\I])2_AQ]#+
MN(?M%M/!O*>:A3<.HR*NO3]I3<>Z+MS)Q[HT/V5]?AMI-:\)S'$XE-S`2#ND
MQPPQVP.:_%,VP[A4?D['D862C)Q9[_>6D&HV%W87N[[+>0M#+M;:<$>O:O)C
M+E=SMK0YXV1\H:=8W_@OQ5=>%=<5HWCE\W3V/S*XSD%6&,__`*Z>945.*Q-+
MYGO\+YG[.3P=5Z/;]5_PZ/I[X??$V#6)4T[6DCL[L(!'+N^24@<Y)^Z?;Z\U
MV8'-(5O<GH['%G?#$\-%UL.^:-]5U7;U_K0T/$/PTT76$OKJ#?'J%T"Z3ALJ
M&[''I6E?*Z-5.2W9S8'B;%X9PIRUA'2WD>3ZE\-_%-A-%%]A%Z67<9+=@RJ1
MV^;'->%5RG$0>BOZ'VE'B/+*\7)RY;/9K7\+E0>`O%)./[$GQ_P#_&LO[-Q7
M\K-?[;RO_GZOQ_R-/2_A=XFU*U,LL45D?,VF.Y?YL=V`&1712R:O+5I(YL1Q
M3E]"?*FY:=%IZ:V/7]#\/Z%X#TF:[9EBVH#/<RGEL#M_@*]^AA:.#AS?B?"X
MO,,;G%94UKKHE_7XGB7Q&\:3^++T[B8-'@.Z*!C@''\;^_MVKY['YA+$3Y8;
M=#]!R;**6547*3]]K5]O)>1Q/PVT)/B1X_CO+B#SO"VC',^^3:)7_A^4<G)_
M3O7HX:C]3H>]\<OP/B<[S+^T<0E2^".B\WW/IM5+,J1H`!\J(@P%'8`5ANS!
M)0B?+'Q?U>R\7_&2PCT1_,738EAGE92JED)W8[\=.<5]=PWA:DJ\$N]_D>?%
M>TQ"Y>YKN<N2.A-?K"6A[#=V>K_L\W%O%?ZQ;O*%NI=KK&2?F4=P.E?*\5PF
MX4YI:(\W,4VHOH>WU\2>2(ZAU*L`5(P0>]--IW0'R-X@$2>)-8CM@JPQW3*%
M48"^V*_6<*Y/#TW+=Q1]+3OR1OV*-;E&#K%C=Z??Q^)/#=PUGK=E^\W1_P#+
M8#J,=S_.OF,_R:GB:;JQ7O?G_P`$Y,3A^=.I#=?B>M_"CXQ67C6_?1]<MH=&
M\09_<IDB*Y]5Y^Z_MWK\NQ6!E1>QR4<4T[3_`.&.G^)G@>'QQIEM:R7)TW4[
M*3S+>[V9=#_=/M7+2J<EXR5T]T=4HNZJ4W9IW31X%J5[K'AS4+G3_%VCW$!M
M\"2]@C)A93P'R.QX_.N:KE-USX>5_)[GU&`XMLU#%QMYK8ZWPI\5KS3]/<:7
MKD+VSMPEV>8SZ`'H*F-7'8;W+/\`,[:M+)<R2K2:7H[?>=AH7QMU!(6@F2QU
M.Y+;E:.0*0/3`K>&:XBG']Y'YLXJG#66XFI_L]7ETVW-3_A=.HXS_8D./7S#
M3_MV79#7!6'>U9_<9NL_&36+B*(V45IIXC.Z5W8,&'ISTK.IG%:=E!6.BCPC
M@L.I2KR<E;TL>9>(?'][K5Q=*LFHZ[(7622&S0M%&>@YZ"I6%QF)]ZH^5/O_
M`)"J9QE>6VIX:-Y)=-[>;-_1OA1XC\5Z9(?%DS^'[??@6ELN]IE'4L?Y5T4:
M-#"RYH>\^[Z>A\]CLYQ680]G+W8]4GN>Q>$?"&F>#-&&FZ%9M!;2,'<LVZ25
ML=6[TJU:4WS39Y]%4XZ1>J,7XE^*%T32I].T]HYM=NDV)'NXMU/!D)'0@=/>
MO;R/A_%9I^^A[M)/XGU\E_F:.,JJ]W8\.T32(-)MA'&1+<'/F7)'S2DG/-?K
M6`R^G@Z:A%:]S6E1C2C9?>:-=YH=_P#`K_D?9/\`KU:O`XF_W%?XCCQ_\'YG
MT37YZ>(%`'F'Q2^'$>MA]7T-4@UA%S(@&%NAZ'_:]#7TV29Z\-:A7U@_P_X!
MWX3&.'N3V_(\%?=&[QSQO#*A*O'(,%2.HK[M6:O%W1[&^P"1000PR*=F/4SM
M3T?2M4F:>]A(NR!BYA;:Z$=&'O7EXO*,/B;N<=;&=2A3JN]1:]T=EX4^('BC
M1F6UUV[MM>TF,_+,1MNRO937R4^!8U9RM4:TT]?/R.>G@Y4Y/WM.G?YH]$M?
MB+X;U.**PN9EV7(Q);W$8*#OM8GZ5\_7X0S;#QE/E4E'JMWYHJ6'OJT17W@'
MX?\`BJY?59=%L[J5QM:2SDV(<?[([UXM26*PLO954XOLSFE@X\W^9S^M?`CP
M9J&H17>GR7^B;$VF*U;<&/\`>R>AJ5C9VM)7]2?JLX-.F[/NG833O@?HMA<0
MO!XCUEH4D#O`X!67'\)/8'BLZE6E4^*FKG90Q.84+*G4:5[]S;\9^%/A]8^&
MKJ^\2::+;28B-[+,0S-V5?4^U1AH<M1.FM3;,,RQF(I>RKU;K^MSSS3/C3:Z
M=ITFF?#KP9]D@W>5:7#*`C_[4A[GOUKWJ&2XO%RC)*Z?4\>E2<M(1;O]QDW?
MC?XG:KJ3W;:U:Z($"A+>,`HQ`P3WZU[F&X.JRB^?1HZ5@:TOBLAGAVXU?1;B
M^O8=?O+K4M04I>3RG*D'D[!V/O7TF$X6P%)1=>GSM:J_];'52PM.GJ]6*B[2
MQ+/([?>DD;<S?4U]+HE9*R71;'0V.H$(S*JEF(`'<TTK[`>N_`SPMJ$>H/XB
MNA]GM)(C'#$P^:0?WO85\CQ+F-%T_JL-9)W;[>1YN/KQ<?9K<]LKXL\H*`"@
M#"UKPEH>M74=QJ6GPS3H"`^,'GUQUKNPV98G#Q<*4VDS:G7J05HLH?\`"N_"
MW_0)A_,UT?VWCO\`GXR_K=;^8/\`A7?A;_H$P_F:/[;QW_/QA];K?S!_PKOP
MM_T"8?S-']N8[_GXP^MUOYA&^'7A9E*MI,)4]0<T+/,<M?:,/K=;^8Y'QO\`
M#>]TV6RU[X9F.QUFP78;"1O]'O8B>58=`WO7FX^M4QVN(?,UUZDO$U)-.3N:
M?A0>*=3,B:_X;BTAHX@V];Q9EE?N``/E'UKQ*F7S7PNYUT\='[2.A31[LN`P
M55)Y(;D5E]1K=C:6-I):'C?B#X;^+?B5X\@C\:VITKP=9AOLUO:72L21T+<<
MENY[5ZF'PZI+S/,J57-GKMO\./"MO:16L&D01P1($5%R!C_&O8HYIBJ45&$[
M)&D<76C%14M$+_PKKPM_T"8?S-;?VYCO^?C#ZW6[F7K7PG\/:C-`\"2V(C!#
M+`<!_KFNK#\1XNDFI>]?N:0QU6*UU*'_``IC0_\`G\O?^^A6_P#K3B?Y47_:
M-3L'_"F-#_Y_+W_OH4?ZTXG^5!_:-3L7-(^$?A^POA<3&:\4#B*<Y4'UK&OQ
M+BZL.2-H^:(GCZDE9:'H4:+&BHBA448``X`KY]MMW9Q-W'4@"@`H`*`"@`H`
M*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`
M"@`H`*`"@`H`*`/_V0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8V]C:WDN
M:G!G```````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S8V,0`Q,#0Q-S,V,S`Q
M,0`P,C(W-3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!
M`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#
M`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D
M,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BY
MNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$`
M`P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0`
M`0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E
M\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W
M>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^
M"^BBBO[(/GS]KO\`@@;^TO9_!'_@H!X&^#WCVXGU/X`_MKZ=?_LD?&CP%='5
M;[PYXP3XN0R^&OAL-1T+3Q+#/J*?$/4=%\,1:_-#'/H'A/QIXXA34=.TS6=9
M>;]VOV6/V%/&MW^V%_P0Q\"ZC;36_B;]DGX1?M?>+OC1J-[)'>^(-(\"_`O]
MJ;XF:-\,CJ(L[B71O[.\4?$+Q;I6@>'[73M6NFL;#5/$%W#'>V>A)%=^0_\`
M!`;_`(-K_'?[4ND?!W_@H%^U/\0/&?P+^#UIXKT'XE?`#X>>"+*QTWXP?%!O
M!7B"#6/#/Q)U76?%.DZOIGP_^&>H>(-&M+CPPO\`PC>L^*/B7X;6X\2:#<^#
M/#.H>"_&?BK^W;4O^"=EQHOCK7?B_P#"3]J/XV>%_BOK/A'P[X.O)_B9I/PP
M^,OPX\1:+X0UWQCXB\,:-XR\,7O@KPC\1E\.Z9JOQ`\6W<FE_"GXR_""_P!2
MEO[)=1UNXM]&TNWMO\;_`*;_`-'[Q2XX\2N,_$+Z.F:<#8;-N+_"S,N$>,\N
MXFS7.,JAG/%M/P^\7/"7+<WP+P?#^:Y77QU#@3Q@S*E+'X_$4*-7,>#N#,OK
M2CEU+%8S!_H7#6;X'#8+"X7-J>*Y<-F%/%86K1I4:O+AUCL#CJM&K&K7C.$/
MK>5P:IJB^>CC<15C-MTU+_'W_:.\+ZKXE^*'[2/QK\(>%=1M_@J/VF_&OA/3
MO$C&P?2=/UCQSK_Q%\7^"O"<=U9"WL]1U&;PCX2UW4)VT2V?3["VTZWDNA81
MZQHD=[\SU_6Y_P`%K?@#!^R1^Q]\%_\`@G58^%_A_P#LJ?#']DRZF^*GC5M<
M\?Z;\1_B3^W-^T9X]\->)/#'PW^*GP;T'2K#2O'OBCPG/IEGXWN_BM\6_BEX
M=^%?P\^'3:SJOP:^']IJ.I_!7PI\,/$G\D=?WY]%WQ&SWQ"X$S:/$/"N.X-Q
M7!O%.:\#Y=D.9/ZUF>&X?X7C0R7(\7GF;8.MC<AQO$&?8+`QXJQV#R#-<VPF
M28+/\JRO$XZOCJ&(JU/E,ZPE+"8JG[*O'$1Q%"GB9U8>[!U:UZE6-.G)1JQI
M4I2]A&56%.525*<XQ46DBBBBOZ4/("N\^'/@+5_B#XGTG1[+1?%.IZ.^M^'K
M'Q/?^%-&GUB^T+1]:U>WTV74"JH+*VN/+DN/[-.IW-G9W-[$L$ES$GF2)5^'
M/@C5/B9\0O`?PWT.6&#6OB%XT\+>!M'FN$DDMX=5\6Z[8:!ITMPD6)&@CO-0
MA>8(0WE*V&7J/]5#]FS]G/X;_LJ_`[P'\#/A#H`T;P'\.]'LM&AG$$?VW6=8
MN(Y;G5O$WB2]@BBCOO%'BW4X]1UW6+QUC-W?37;6\4-K!'!!_G)^T!^GSE?T
M+\KX)RK"<%3X]XQ\1(YU4PF7SS]<.8+),BRGZIAL7F^)QRR?.ZE?%XG&9A0P
MF58*.#A3J3I8W$U\0HX.&%QGZ[X5>%=;Q&K9G6J9K#*<NREX6%6M]6^MU\1B
M<7[9T:%*DZ^'A&$51<JU2=2]YTH4Z<W.4J7X6?#?X:_'#PO\%O"'[&G[$GQ$
M\?\`A/XQ^)OB]^V9I?P[D?2_`?P_L];^'>E>"?AQ)\`/V&Y?B)^TYK>K:5\:
MO`GA/QA=7O[1OQD^%/Q]\(^&OV@]%^#FA?M!?"CX6_#^:+P=KVC>./[-/V-+
M;6O"UU\2?A>NL67B/PY\/])^%4'BC4-#U3Q1KW@7PI^TKJGA_61^T1\*?A-K
M'BR<:@OPI\)3Z;\/_%N@^&8[.:#P/XF^(_C/P@NJV9T?_A7?PX_#K]HO0_@+
M\,/AOX$\'ZEIWP\\'R_%;]KSX16WPVT[Q`/"UCHWB7]I+XQ_M":;XP:_U&/Q
M:EQI.K1^(O$&J>+O%'Q.LKNUU5=9^&Z^/].NM$UK19KO0;O^H_P_X>\-^#-`
MTSPWX6T/1/"GA?P_816&CZ!X?TRPT+0-$TRT3;#9:9I6G06NG:;86T8Q%;6L
M$-O"@PB*HK\:^AO])'.?I/>&^=\;9UPG#ABOD_&.8\-8>O@J->AE.>8/"X'+
M\=A\=A*6)Q&.JT<71IX^&$S3#QS#,*5/%T?:T\9*.(>&PO5XF\$X3@//<)E.
M#S-YC#$Y52QU2GB)^TQF"JU<36I\DG25&C["7L*CP\EAJ+J0E-U**JPEB,1^
M,W_!??\`X)S^"_\`@H?_`,$\_B[H5X)-)^*WP&\/>*_VB?@SXATG2K.ZUK4?
M'?PN^''C^YTCX>7]XYBO!X1\>KK-]X?UFVCFFBL[B^LM?@T^[U/1[%1_CTJP
M=5=3E64,IP1D,,@X.",@]"`?6O\`>5^(L/VOX>^/K5O#K>*EG\'>*+;_`(1<
MP?:QXI6;0;Q3H2VL5Y9R7"ZP9#I9MS>6$DS3-&MQ`KI<5_@\ZGI5YH.I:EH6
MH/ILE_HFH7VCWTNC:QHOB+1Y;S2[J6QN9=(\0>&[_5/#VO:5+-`\FG:UH.IZ
MCHNJV;07^EWUW8W$$\G^B_A/BJBK9O@7.])TL/BHT]^2I&<Z,YZ3_=^UC.$?
M>@_;>Q]R:]A-/\IQT5:G*VMW&_=;V\[:]=+Z[HI4445^TGG'M?[-/Q0TOX'_
M`+1_[/GQJUS3-0UK1/@]\<OA)\5-9T;26MUU75M*^'GQ`\/>+]1TW2VO)[:S
M&IWUGH\UM8&\N(+3[7+#]JFB@\QQ^GO@W]L#XZ_MV?\`!4N']H*3]K[PY^PK
M:W&H>(+OPU\5/B3\0[/3?!'P&^!7@[3Y-2L_`&F:)XEU.WT3XA:MK^GZ3:QW
M_P`,K#3ET7XN?$[7=6U?5/#^FZ3K&L7&E_BO7U?^Q]\0?V7/`OQ+U6W_`&Q/
M@OXB^,WP0\8>%+SPWJD?@/Q!<^&OB9\.]>75M&UK1?B)X`O(-9\/6FK:M9+I
M-]X8U'PQKVM67A_5-"\4ZG?77GZEH^D0M^">+'AKP+6QF=^,6:>%E?Q6XRRG
MPYS'@&APYAL'D^<X_,^"LVS>EF7$F291D?$>,P&08[&YE3YJE>AC<3"MF.'P
M<<JPLG+%U,-B_KN&<ZQM&K@LCEFL,MR>OG6&S3$.MB,7@L+]=P]*5+#5<9B\
MOI5L;2H1;4'4ITJGU=R==17+*2_J%^)'CO\`X)'_`+>?[0G[-T]__P`%)?VO
M/VB?VF/A/\2/AE#\']"\:_"W3_#WPF\?ZI%\7_"UYJ_A*#P'X._9B^&GP]\/
M7'BWPYI=C;^+/'.FVVC:C)9:!IVJ:Q<_&*;2=*T6O])&0#&\Q>:\6Z2-0$W[
M]CK^Z,C(B2.CO&&+H,.RLZHS&O\`/`_X)D?$3_@@SI'[4O[._P`(OV5]1TCX
M4^*OB=\3?"'BSXA?%[X]77C70-8MM'^#VO)\9_!GP7T/QY\6;ZX\+:7K?Q6^
M*&@^`OAIJ/@_PS)I7AWXD>"K?Q!I>M:SX@\=P_#RQ\3?W[?#[XS?";XLWGBF
MR^%OQ'\&_$=_!-Y8Z9XMNO`OB#3O%>E>'M9U"&XNH/#VJ:WH4]]H]KXFBLH(
M]1U#PT]\->TG2]1T/5-4TZST_P`0Z%<ZC_,_A1G\>(.%93R[P"S?Z.G"V39G
MBLBX4X%SWA2/`695\JPL*.)K9TN!\-6Q.7\-99B\UQ>983*Z%"L\3F=+`5LZ
MQD*7]H4(+ZKCW$1Q.;8>K5S+A[-LPJ8&C5S'&\,U\9B\N=6;E['#SQN.Q&)Q
M&,Q>'H*G"M5E5J^SIRHX:5:=2A.-/XI_X*__`!A\*?`O_@F3^VOX^\8_$C6/
MA3I@^`/CSPC9^+_"\EI#XV37OB!I,O@?P_H?P_N+W4](AL?B!XHU;Q!:>'?!
MFL_;,^'?$.IV'B,VUY'I+VDW^*M&GEQQQYSL14SC&=JA<XR<9QG&3CUK_5+_
M`.#IKX3?\%'OC[^PTOPG_8V^%5I\1O@-+K.D>-?VK-,\'S2^(?CMXLT;P=KM
MCXA\">%_`OP[32[BZUKP5X?\6Z/IGCOQY+X4N+WXAWVJZ1X(@T/35\&Z;\1D
MU+_*V!!`((((!!!R"#R""."".01UK^N/"K"X>.%S+&>WISQ=2M"A]659.I0P
M\(J?M9T$TXK$U'RJI)-26&48--5$_P`VQTGS0C9J*3=[:-OHGY+IYZ]!:***
M_6S@"BBB@!"`000""""",@@\$$'@@C@@]:_WK_#?AOP[X-\.Z#X0\(:!HOA3
MPGX6T;3/#OACPOX;TJQT+P[X<\/Z+90Z;HVA:#HFEP6NFZ1HVDZ=;6]AIFEZ
M?;6]E865O#:VL$4$4<:E%?AWBW_R,>'O^P+-_P#T_E9Z6`^"K_BI_E,_@#^'
MO[6/[4\_PG\)>+I_VEOV@)O%FJ_MO>&/".I^)Y?C)\19/$.H^%#\5K+1#X8O
M]:?Q&=2O/#QT4G2#HMQ<R::=+)L#;?9"8J_GM_X.%_#OA_PQ_P`%@_VO++PU
MH6C>'K/5;?\`9Q\::I::'I=EI-MJ7C'XB_LE_`?X@?$'Q9?P6$%O%>>)O'7C
MSQ-XD\;>,M>N$DU3Q/XN\0ZYXDUNZOM9U:_O;@HKS?##_DI*G_8LQ7_I["EX
MW^"O\<?RD?B_1117]!GE'__9````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O9&5V:6PN9VEF````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S(R-0`Q,#0Q-S,V,S`Q,0`P,C(W,C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA0`!``/<`````````,P``
M9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F
M_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_
M9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S
M_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,
M9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`
M_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:9
M9F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;_
M_YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF
M9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,
M_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS
M9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9
M_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`
M9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F
M__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___
M9O__F?__S/____B_)```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"'Y!`$`
M`-@`+`````!``$````C^`+$)'$BPH$`K!A,J7,BPH4,6#@E"C$BQXL`5%B=:
MW-BP!,>/(`UZM!@@I$F!23:6/!DRI46,+$&VH6,1"I28'Y.TV;@3Y\8GD#9&
M\KD1"J0G!&TJ31CI)M&*D-@,;`.I:E4V(P="<ME0H\^JV*!$@D2K;-FJ;6!B
MBQIQ)5$VD)#`-4N75E6D:Z4Z5.LSB5RR=>L>!1JTJU><3T@`#DPW*A*P79\*
M),PX<%3(!;WR]4FULN?"!=VRD"%YK>?/!ED@%*AZX.&00$]7UBN1X&J!;D\F
M65SY,EW:K#6V'IC;9.?/E,U"FF-;+0O-..=6GA.HU!S>M'H>5&L%.LLG;#S^
M7PIT[5J@Z\IIJX9IQ0KIX">A4,5N]I*>\N5+73++!BZ;).W!)$-WKMW6DE7*
MG74??N7I`5A5=K'1WD3MV68@2%:<AV!XR['"8'FLS''661)6..%`5U1X$GG7
ML*+'=?Y9X>&'U\#EFUU/3+B"%<Y9<05+,X*H!W@D'&`%C2%>1595.[9W(C:J
M7?C1"BNP"&(@*QP`P)$?!G)5$OVU@5243C9)X$E:<MFB=6R04"6#K`1B(Q()
M.6GGF2=E>44KUUAGU7^!5!?H=4MR5="`3CXGV1R7_&G591"2J)"=I6&SFZ./
M9BIIG>Y5BDU_H/X):G^/;3K0I3F^AM-\C_:7:53^<VU%T&YEL?&$JC%!^"""
MC<7JE$#20;("$K_Z!)ZF])UU5T&^Q0479YFR@<1?O&6JW4!&V6@C),6&=)QR
M5DW[X+2V)@1F57+%*B5'1BE+XI*E0GI40?(]^EBXZW+TH+;[*KGO$S==&N&H
M_1D:TK#P/E%J>C8VIB2))=Q[U68RD:"M"?1%RMABW'YJ,:GY;A05PM(FVZO&
M5N%5\K(Q4?57PY[]A\T3K$+2QJ]I/0$P4:Q*UQN=#K7Q)%$Z_24;7@Q!D2.>
MDH5WVG(.)=$DKC'Y/%U#4`#HI*<+>\8<0RFUL'6EKG[VM4(EL*>B9+M9+5BW
M!#WA$J6E^<>K8`LI/1!UW9(M.2IV!F,[QZ^(AFQ2NW8YJERW+"0!)AL]KDTT
M=KS:G-"CVI%9&JUW`W;MK$N>'275)L7:=5F?%S0?TF:R?6^H?@<-]4%C^P2%
MQ4JZ"NO9"^F\=Z(XU2MJJU:E[M#0++':DTZO6NZI0R<P1,<<HP9>6D```#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V1I9VEM;VXN9VEF````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P
M,#``,3`T,3<S-C,P,3$`,#(S,C0R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y84$`00#W`````````#,``&8``)D`
M`,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``
MF3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`
M_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S
M9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DS
MS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F
M,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EF
MF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9
M`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF9
M9LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9
M_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,
M,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,
MS#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_
M`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_
MF3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG_
M_\S____XOR0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````A^00!``#8`"P`
M````00!!```(_@"Q"1Q(L*#!@P@3*ES(L"%!68'T6`EDS:'%BPD#!0*TL>)`
M:-`.81QY,2(@4H"L&`QD917)EPNM5/DSLXK!)U:NP-QYD(LU0%4`Z;EIQ<H>
MGD@%LK*V)>A!*"SV6`&4=*<UEE,/6EEQA<65HE5?@D68$XK1G"K#CDQ[L,J>
M*U]5YE2+;:+%0`CAZD0K<*A:*S(LLD(H52"4KW0)VFW8*F]:*X?I%E4)EZW"
MP0MQ)B[Z]>T5EPLQQZ2+5V#.R@Q+)6[(4:!>N*(1EEX]T'+MHE&N1#&J!YI"
M*+1K)Y3Z%DOE5K$+LEQ]FF%.J44#7;.67#C=*V\M2H0"+5H@5M>@_K%*3K$J
MYZ^5M]HVR%'6-5:"P%\+[Q';JE;U=[Y.OUZA^_FER!<>:*R(QY,,+)C%PH(8
MN>1>--2Q\MTLT;RG%"N@*62-+-'(0N%\@9@22((R1+%@@BNP8%-HULPW7X'1
M[!%(A4MAHP<B@4`CBWB-$:3C?RZ*V,J0"6[%@@PK/&$1D!6*QTHI@<P"XG@"
MSN<D-L_(U^)TR`F"""O(;;4"3/])62`KRD`IG8M2;NEB-.!%,XMX:@HRI"FM
M?#G;2U6"5*"(:[KYX3526GD-H*8D:@J80PY9'4G@M0@G-!15Z.)\EF*Z)42)
M*I,HF..U(DN&/$%S*30B2KEHA5+.4NBE_E+N44JBLS:*'X15;>@BJE&6`M@5
M%5J3J8NMA`=EFK."Z>*C5KD8Y42E?&7*I2Y>H9$57%"Z*'+S4>A;8M#,^1T+
M46)%(:O7X(C(1%9`]!TKELZ9GUH16L-"%S(<((,5X18*S0I=""*##*Q<@>-X
M\\U+&RNS3(3O%01?(V>Z,0S,PD1XZH$P-`JO)C$B5W0!&"*8@GAO%P%;,6>`
M'=.FD8"%6F/%`2NL('$@7\6''"+!(<0P*P^R"8T5\4E,:*'C"=+S005>:FF+
MA[AI:;@T+FT0E56:$J!&LT@H,81=!\*SU06U6K(UR"$W'KI-PD?V0>)=VJ*=
MW4+XXG>FO'W0_B%56A/SI1I%M*?>`AVR:)6$$BOA*K)T13A!H4XGR"&"!")(
MY8@L*HN$T2#VN%+6M-C*G/""">?.K"""2+2?8X/P>X<(/0OJ:5L^.-G6H"I+
MA!6R:G<K@<B"NM*/CQK(*JM@F&FA.P9R"""KI-1?S]&K8KTJ4\'J+"#6&Z**
M(501OLKUA:A"$[560J]**J]@8P@5>NM1116&_)&**MBD5.RK'7*Q2BI_".`6
M_A"^X,R/>]<S7Q[RH(HJJ"U4R.$>3?ZP/NO19'H[B9[ZU@=`+9""%%2H0A[R
M9*L(`N5Z]UL?4%:4%`FIXB2`2$4J8%&(%(YB@6,RR"KR@(P\C"*!X=A((0%;
MPY-`/"$EL@"*]PH!"/7E`0]^*4@I5-%#4GSOA5<$"B"X,#:81&L%5?#5"E10
M/@)6@0JJP$,>E+02;"S0>H7XPQ9J^,)5/.$)$MI)S59PB$"L`$DT`43-5)"'
M*CPAB@3980!3@3Q9'&(+310;*[:BD9?XD04K",3`:O8'+AQB!3%8@1[8B)`%
M4M`0R6/%$>=GA3PMZ'8-$9-*_KC'*ASB"2P()0L1LHH_Y&$57*C9%?9(2\#L
MD2?'%(@?YV>1)LZO9ELQ`#%S6#.8Y)`@F-1C,@5RS=9Y\YO@I$M````[+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]D:6QB97)T+F=I9@``````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#`U`#$P
M-#$W,S8S,#$Q`#`R,S(T-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_
M`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF
M`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__
M,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F
M,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_
M,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F
M9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_
M9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!F
MF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_
MF9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]F
MF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_
MS&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QF
MS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#_
M_S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF
M_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____
M^+\D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(?D$`0``V``L`````"``
M(```".(`L0D<2%`@``#8#B)4F)!AP8<%`3P[.)&B0F3($$+<V/"9QX\@,VKD
MN%$BR)`C24(T>=)C1I4<6;9\"7-ERX\T:T:\Z3*E3H,\G^7\F?":3)1$#1HU
M^I&B4)\U`2Q5:%+B4)U2LS:=^#1I4:T>)5J%"M-BR[%)G9YT>K5L4)QD21Z]
MV;:LVIEQW?*L&S4H7[UT\ZJ<"[>D8,(]#>=%[#`BU9)-J5XSNO(@I+B2)VL^
M6!D2Y8<`+FN>K/!S1,_7+H.&)-JHU,UD7YL>6/K@Z,TK/3>F+?LVZ=@*5=-N
M[1OWP(```#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1O9RYG:68`````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(Q,#8`,3`T,3<S-C,P,3$`,#(R,S<R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81T`
M'@#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``
M9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`
MS,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S
M,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DS
MF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F
M`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF
M9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F
M_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9
M,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9
MS#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,
M`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,
MF3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,
M_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_
M9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_
MS,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````A^00!``#8`"P`````'0`>```(_@"Q"1Q(L*#!@PA7*$3(D.$*
M5JQ6-)Q(\.&?0!(I&E2XP@I&5A<S)F1HQ4I'BQ@=ICP8**+"0#!-)F0E\^`*
MF"TAKMS("J9(@AB#0J3Y<^#-HRR/YNQ95.#)G=@XWKPV=&C-BB9W`E`"\2'5
MJDR;=M2J1--'L#KU0"(!@(1;``^U;E7R$&T@M6RLD$#"EX25B`4!`"BQ5*<5
MO'I8Z5E!8D5BJ%&S#@U4D@0D-HG1,BVHU'#;RYDU$\4ZMJ1@))A%6RTJ4>I>
M)*%57W7X5_5JC1VKXM0]FR'<VC0IYQZ-V^1?C"6-;RZ>U0I<P;\AJVS>.OE-
MZ9Q+OJ3YW.3VW@2))()UKGU\4Z?"S9>O"AY]5IS:M>.DW-XI@*C0!6/3OR+_
M?8$!`0`[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O9&EN;RYG:68`````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$W,0`Q
M,#0Q-S,V,S`Q,0`P,C(U-30`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```
M_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"9
M9@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#_
M_S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F
M9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,
M_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S
M9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9
M_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`
M9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF
M_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_
M9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS
M_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,
M9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`
M__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^9
M9O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/__
M__B_)```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"'Y!`$``-@`+``````@
M`"````C^`+$)'$A0(`F!``X67,B0(8F'#QM*G`@QXL2+!2M:Q,B11$(D'$-B
M(U%BHTB')4K0J?.$3HF3"TNLH$/GR9Z;=%;`)%BBSDTH=?1`V?,DD,Z=V%;L
M^;1G!92B1@,9W4F"SJ>K4'):,;IB*LP22T%]RBG3*(`5);\N9?ID15NG,Z&L
M4'$2+%,KI$@]R?I$SY,G>5<<Q6@7\+.\?TD]*U7JV6*]''LVS5LE;V/'F!U#
MQOBDS@I253YG'JWY"6&YB!63'JU'H<2J@/6J7HUY\\0D-0&MT$,[<RE2="G*
MU2-X]FI2>8"?[JM"]&A2E_,&IUB3.`#`ES7G:4RJ-4?<4/Q7(FD.?7$>0(?]
MB@3O5T7SOGD1N^Y(9T]X0,3;NG>/5"E1MRXA55!/5RW5E(`$(;%"'5==1<=\
M2)'@U$T%OH1@4H$((A=04*1TX0J"M"*(($;)=,5@#`4$`#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D=6-K+F=I9@``````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,3,V`#$P-#$W,S8S,#$Q`#`R,C4U,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$@
M`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8`
M`&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9
M`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`
M,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9
M,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``
M9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:9
M9F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`
M9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9
MF3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`
MF<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9
MS`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`
MS)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9
MS/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`
M_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9
M_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(?D$`0``V``L`````"``(```"/X`L0D<2+`@-@`(#2I<6!`A
M`"L0`3"<V!"BQ8@4*3Z\:%%B1H8;.5KQ^%'A0X<H1Y8T"6"%RQ6!6*U(N++A
MRQ565K`*-+.FS9LQ79*LB;)HT8Q&`RE=RG0I"Z,$C4J=2O4@581[LFK=<^+I
MU:]8L.X!D!6AUZ]3QSXBRW;MB:M6TP)8"R#L7+93!U(=>PTKPKYOI>H%<,W*
MM6L[_1YFNW@L@)B%^THD?+AR9;*.!]7%^M:R98>'9SI<T5<K`%(`3G`E++KE
MXK^>#[,Z[9"4,=0(40>*W3=NT;ZW@]L>;HRP8)`(A2MWZ%/@:>7#AQ)UN)RY
MS^?$L]^6KM'VU^T3BSR*GADL>["6"%L/37\SZ\P+4@E@OBGZ('V7>T03N$"@
M?W_^+>5W7TOW"546`!<DF*!?!39HX%9%0=A@0```.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V5I;G-T96EN+FIP9P``````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$P-C4`
M,3`T,3<S-C,P,3$`,#(S-#4V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`
M,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*
M"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A
M""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U15
M5E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>H
MJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V
M]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!
M`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P
M%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#
M`0`"$0,1`#\`_&TL!G@\=21@#/OSGMG_`#E000".A&1]#2K_`*Z,$&7:?FB2
M-F7D$C<XP#P<\8()QC(S3;F:.UA>\O?+T^T^V20M/=3VEMLC\TJGD64MR+FY
M!^4*Z%05._8`"!R5ZL5>V(5)K3:+U3C?=/H]_N&Z6)<4Z-)UW)+1)Z-VT]UI
MO7T^9PGQ%TO1_$?AZ6'Q#>2VWA[3`VJZO;6\>H&QU.31/^)M):ZA%I5O>:E=
MZ;BS)U"WLK.YN+FS6>"WB>5U6OT__P""97_!2WQ7^R7;/XK\#_'?1-3_`&7/
MA[XZ\->'/VD/A-K.F:+>^(?`/PO^).HZ]\-?#?Q5\/Z3!J?@'QAK$'AWXFOX
M8T;Q)HW@7Q;K>N>'Y]6L]6M/^$IT*WN_M7RA^R=\9_`_P,_:<^!?[0?Q:\/S
M^*/V5?#WC/Q)X(^+OB[3_"5OXJ\/>!_%?C'X>>,-&\*>(39GQ%Y5U=^&_&$%
MYJVK>!)[/6-2L]'\&Z]>27UZ(!;M[M^U_P#\$8],T[]OWX>^%/A:NH0_LU_M
MG:%\:]0^&'B.S_LQ/#/ACX@R_#KXA_$[X>^`+"_L--^PW/@76_$"Z2WPUT?5
M_P"U?$WAKPA%//K_`(GU[Q/8P>)H/`EF4ZDOWJNDTGJEHG'F?3HF[Z7=M]3Z
M+`Y)4J8"%=U'2Q:FG/#<J;E'1VM*\O>LUI9];K<_;[X(_M">"OVD/VE_VQOB
M]^S?X4^)WPQ^,$.L7'A7]N7]CCP'XN\.^))_VM?V3YEU;X=^#/V_/A!<:9X-
MTW3[+X]^`)&77_#>B>#_`!EXMU3XG:!X9B\)V%YJ^F_%7X7?$;QE?_9'_P""
M<_\`P4@UC0OV?_V7/VA_%7PY^(O['W[(O[4WPA_:E_9U_:%UG5]9\+?M!>+O
M"?@!]:UJR^%_B[X:R6>L^)/`FM:BGBJTF\1Z%XPBTV;X;PZ78>$+:[\4-=1W
M-?-G_!!_]D?XV>'/CE\!?VQ_%OCIO#VG6/P*\3_L@_'/X1>(-(N=&\6V/C#X
M17GAGPSX8TK0;ZS?34M/`V@V?@KPA=7FHZE'K)O]0^'^L:=875O9/HNF:7^D
MWQ5_;M_X*'>`_P#@JW\#OV,/"OCC]ACQ5\._BTVO^,9O#FB^"_C9>>-_AQ\#
MM"\&^,/&MWXM^)WB>Z\=KX?U;QEXHTWPCJ6H^%K'PO;*^IR>'+71K30;'3+[
M6_$VE^M@,;A*_-3IU8J:M'D3NV[1TNVWM_*]DM>AY>89=CL).,ZV';A42<;Q
M:<5=:Z=.^_GH?O+>^'/$]S>7=RNB>!KE;BZN)UN)[/Q9!-.LLKR"::!--N$A
MEE#;Y(EN)UC=BBS2A0[%=?+XEU@2R"/X;>.IT$CA)H)OAMY$R!B%EA^T^.;>
MY\J08>/[1!!/L*^;#%)N12O3LO/[W_F>7:76EVZO^Y?KYL_S*O\`@GA^P=\6
M/^"G7CO7=9U#6=<^&O[(_AG7+K1]=\8Z$\2_$_QQKZ6UP^G>&OA]:WT3Z);:
M1#=PQ#7-9U6VEN(8;343!=1DQA/ZC?@)_P`$H?V"/V9[+3/^$6^#7A+QSXQT
MNY^S2_$#XO:59^.O$#B*%K.XOM1_MF35?#MQJ=^OFR7USI>G0V$EW/+-810P
M&%5^L?V>O@1X+_9D^#OPV^$7P\T[3]+T#P5X1\/Z/?W.EV%IIA\3ZE;:1#%J
MOB+5_L44`U2_UZ_EO=2NM0O!/<WKWLEQ<2R/.[-T?Q5^)_PS^"OPV\:?%WXA
MZ[;>!/A[X`T*[UJ]UJ6S34(;+2=$6.[DO8-&*,ERT7B,6?A?2O#J1;-?L[I=
M.CAE@E\H_B.;9CF6-QZHT9U(1C+D:C.2O:5N9Z^\WU;>NVBLC^DLHX8RW),'
M3Q^)]E+FI0JRC*$6DW&#MJFEKIHMM7>Q^3__``6MTWPEX#^`?PP_:'\2Z/H_
MB'X<?!K4/'?@KQ?\,I--;3?#^L^&OCA\.-=_9VTG6IB87LM!;P1XQUK0_&/A
MO5+>WB/A7Q#H[:[I/V34+O49[O\`F(^!O[4/A;]BWPQ^S9XD_9K_`&B]=^)F
MJW'CRU^,?[6G[).L>")/#OPQ\`7/P_\`$\7BK1I_AA\5];N]?\.:2FJZ9&^B
MWT>C:1H2:Y)=V_A5Q)IVO7.F2?TE?M5_%?\`;)^.?[.'Q*U[]J#_`()^?$/X
M?_\`!.+QOH&@:[XB\?\`A?XG_#OQI^U+X(^%V@^+M-\6:9^T;>_!7P]HZZYH
M-G\//$UMI_C_`,9>'/$$E]H%MX>T[7-2\2:%J>CIJ%M>?)O[,G_!%SX8_M"6
M</C[Q]^UKX+^.G[/GCWPYK5GX7\*?`WP?X;^$NH>*]*U:U:VL]7^)^O>$K'3
M;3QAXV\"!K7Q3)IME!#?KK_AZQN)08[9TKZC"UZ^`P<:F84U/VDHI\[4_=DH
M6NG?5)RZ]XMQ:U^"S*C1SO/8YGDV,I4IP<(O!T;PBW":=E&*2YI:+2+U:=V9
MWP^_X*8_M+?\%#?BK\/M+T'Q_P#![]@;]F&W^(\/C3Q;KVN_'CP=K/QY.BZ7
MK^G?$;1M*32_$^E7P_L>_P#$?A/1DDT93%HT]I?:G-?VEU;WNI6]]^F?_!8/
M3=-UW_@F1\1OVH/AYXI$T/[.WC;X"_%?X7?%/P9?Z;K.M:W\1+']H/P/X1T7
MQ3X3UO184T'Q.VC'XE^)=;T+0/$ECKEEI_B?^R=#T+3K+2KF:TKY6_8/_P""
M??P-^#7QVB_8B_;&_9C_`&;OCU!>7'_"U_V;_P!J.[^"?@O6+GQ_\'(=2'A;
M4/AW\6?$FH>&+G5=4^(&CZ+>7QT>\UJ^N+V+6X=,:"19EBD'Z7?\$^O@YK_[
M5'C#XB?M-_%[Q#X*\._L3^%?B?\`%CX4?L._L;_#A]*L/V<-*\)?!OXC:[\/
M+?XY?$OX8Z>8/AKXQ\;Z5KO@F^^(/@RZ\5>'KJ30;?4].\5Z7=6FJ:%H]Q'U
MY;A<)F&.AB\)-49X>:ER4ER*?+_-&.ZM)+7LM-%?#B/,<?E="&'QU%5:N)BO
M8NI[ZIN32?)S+W7=.\EKK?5NZ_+OQK_P<U?%WP)XR\6^"/'GP";PUXY\&^)M
M>\*^,_#EP/C-;SZ!XK\/:K=Z1XBT2:WLO$L-G!+I6L6=Y820VD,5M$\#)!&D
M2HH*_GR\5_`O]MWX[^*?$OQPMHM?N[;XRZ_K'Q6M[KQ#HGAG4]?N8/B)J-SX
MOBN-<U*Z,USJ&L31ZPLFIWUQ-+/=WK3SRR222,Q*^O\`]J_FE]_I_DON^_\`
M.?K6)Z02VT[?#IMY_P!:W_0WX?\`_!??]OWP;HFG>%OB;^S3\*/B>NBZ/8:#
MI_BCPG+X\\.ZOJ,6DVD5A87?BB>[U/Q!H$<BVMO;Q37%A9V[77EB:<"\EF<_
MK5_P36^*WQC_`."MSZ]X]_:A\%_!?P-^SC\%/VA_A+IMS^SGX3L?%'C+5_CE
M\1;2T\[PM!\6=<\6:WKGAG6?`?P_6*#XE)\+?#'A+PVGB3Q?X;T_4M9EFFB:
M(_S4L"H0L"HD.$+#`<@D$(3PQR",#/(([5]*?L;?M/\`QB_8O\5_$.;X>S>'
M-;\/_%'Q%X+\=:YX$\2?VGILD^O?#*_AUOPMJ6E>)M"@U22WFFO=?N+@V<VF
MF=%TV\@?<T<YA\BAE&`PLZ>*G&,IQC&4].9J7N\SDG?=W;5M[VLKI>W4XKS_
M`!6&>"GC)R@UR1@DY-1M%*%XIVLM'>[T3\S_`$<]/^(/A75=/\<VDF((O!7B
MF#PQX@9$EYO-1N(+$7#K;/%<233&Y$<[12I<2QL\:R*S@C\"/C5\!]+_`."6
M_P`=9?C-\*(K+P1^P-^T1\4=7M?V@O"S65II?@[]F'XZ^.#$WPE^)OPL@M+/
M39O#'PW^*WCM-%^'/Q*TRU62Y\#?$OQ+X93P;?:#I>H:GI]U^7'P<_X+A_&K
MXF?'+QE^S]I_[-_PVOKO]JJRURY\'ZCX@^-]YH^D^+_'=KHU_?:+!8>([SX+
MZQ%H6O:=J%M!?V?@KQ=HNI6/BJYMH_#NH10VNIRSQ?5?[2W[;WQ8_:._9`^)
M_P"Q)^U)_P`$MOVRO&GC;X@^%[KPMKEA\--;\#^,O!C:EHUS;:YX+\3Z/\;8
M[Q/#RWMEK&C:5J>F:Q:_"/2;'PS=65K'?+&=\RZ8]8#&8;ZO6ER3BGR/16D_
M@:6V^WGH8<.4L^R['PQ^#P3JT%6I^V=U-**G"4TTV[-QU6E[[:+7]H3(MO):
MZCI\]K#<6'AYA9RV6H6]I]CDN&77=,U;2;O4UN;.TTOQ)K<%A!I/BRY@N-9/
MB*\TZ[GN;IXQ$W\I'[/OCKP;^R]\+OV[?^";GPJ_;LMO'G[&WB7X8>.=<TO]
MH/0?"_B+3/&O[,'C37]9N-`UOPAXAU&'1M$\+>)_"WQ(\'>'-8TFZU+038V6
MF^,(M6\76^D2ZM<QW]A\P6__``4&_:/\$?LGZI_P3D^(?C5_#/C'X2^$=1@_
M:(_:M\-^)K;5/%'P,^'4/B)]4TCX2ZE!H<4O@KQ!\4;-?%5E\$->O]0\6Z!)
MX;OM2L?"UQHS>)O`&H:5>87[!'PH\3_&:'P1\0K;P[-\-_V2/`7B#4)_`_P>
MO[:ZUN;XO^+O#]O=7NG?%#Q_?>3IG_"01Q>)8['5I[71K"ZBTOQ+/H,T]\4@
MVS3P9P=C(8BMB,1C'+"UIWI>S5W%62O[JYHZ6Z+S5E9?6\8\08+.:%",<*Z>
M-PT/WDI)IQ>]TY:NS;2Y7HGU=V_"/A]J_P#P4Y\$^`O!'@SPQ^RM=^)?#7A'
MPAX:\,>'O$=IX)DNK7Q!H>@:-9:5I.MVUS+?M+<6^JV%I;W\,\K&2:.X61R6
M8FBOW\NOAMJ#75RTGBKQ0TAGF+FRGA6S+F1BQM%+,5MBV3`NYL1;!DXS17Z?
M_JEAO^@ZK_X#/R\O-_AV9^=<R_F7W_UV7W'\Y\\LD$5Z\,CPN=-NR6B=HV)5
M'"DLA!)```).1CBL3P=(]WH;&[=[HF&$DW#&<DE$8DF4MDD\DGDGGK117YU+
M^)C/^O?_`+:C7`_[VO\`$_\`VT\J_:MN+C1_`L.M:1/-I6L:1XVDETG5M-E>
MQU+2Y=C)YFG7UJT5U92;69=]M+$VUB,X)%?W<?L`^)?$>M_L%_!76]9\0:WJ
M^LIX/F"ZOJ>JW]_J:A-`NG0+?W<\MVH1U5E`E&UE##!`-%%?-YA_O=#_`*^4
M?_3E,_5^$O\`D39C_P!A*_.D?P9V-W=ZG^P5^TYKNI75QJ&M^)OVA?@O:^(]
M9OII+O5?$%M>_P#"(:K>6^MZC.TEWJL%WJB)J5U#?S7$=Q?JMY*KW"B0?UJ_
M!+2],TKX3_#VPTO3K#3;&#PU9M!9V%G;V=K"T]EITD[16]O''#&9G57E*(#(
MZAGW$`T45^U\%_[J_3](GYSG?_(SK>B_0]5V)_=7_OD?X4445]B>$?_9````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]E;&UE<F9U9&0N9VEF````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,S`S`#$P-#$W,S8S,#$Q`#`R,S4V-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$@`"``]P`````````S``!F
M``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_
M`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F
M`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_
M,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF
M,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_
M9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF
M9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__
MF0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69F
MF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_
MF?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-F
MS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_
MS,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F
M_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;_
M_YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F
M__^9___,____^+\D````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(?D$`0``
MV``L`````"``(```"/X`25092+!@%0#8$BI<R'"A0(,&232<V/`AQ((2)Y+(
M6/$B1(X)-PX$J5"D1XP`4CY4<5"C18\J6%:1Z21FRXIR7AJ4.;.*DRJDGI%Z
M0C*DG)P0;0Z426K5LZ>E2*G`B;2@TIY`A3[5*I4AB:-5L2X=&)14T*=FA8+\
M"I;$$YX%SY("M#5/GJ<K'((]ZM9J5K1;`ZLMN3<GSY]G!2M>Q9'M415FW_Y5
M3)DQ8;!/MCJE_.SNUB=!+1M]G)ASYQ6ET#Y9L8I48[!(3&M^LLISGE5`\UZ6
MXT0V6E;0;+/*XUKOT=B^]5BS)IRX[M%RD*/-DSJP<E95GCJQ<K<K]-YH2:&5
M6E%:#RLKK)_5E#LUI)/HX8F3<"+7[@K;3JBC;4P"N=D\*KR766";;46*7<^(
M5M)9\AU%7V`'0NA9<0Q!UEH>CCUX(&+3I>9=1>1)M5=F@!Q8FUW$"=4>1=AL
M5-B#SY1RVW!FK5"41N^-N)6,U$F%!(L5;83$<:69Y<1&&P%9$D%(0H:6C3D>
MJ62+?LV$8DPNYC0E-@#L--*1,:G`%D@!`0`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V5L;6\N:G!G````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8Q-#$`,3`T,3<S-C,P,3$`,#(R
M-3<S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$
M`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%
M!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()
M"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!
M`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!
M`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:
M)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#
MA(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3
MU-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^.?VB_\`
M@V9.B>#M?\1_`OXA7FO:]9V_VFVT/Q'_`*'_`&IS[=/_`*^>*_#?X&_M%_M<
M?\$L/CA=:7_Q57@FZTW4#;>(/"NJD_V+KUCGOIG35O;J>OM7^HSXSM]!\/Z9
M+JEO+>36FFZ/KFI:A#!<_;+VZ_LO3N1VK_+L_;F_;6^+/[</QB\4>,?&_P#9
MV@^'!K%];>!_`^E:/IUG9>&-$_M'_B6:</\`B3_VWJVKC_F9=<)/0]`<5^)\
M(9OC>(<++"YDH9GERC:TV[JUNF]TK\UU:U[:\M_V#/<!#!8IYIECEEF92DY)
MP;6LG>RM9ZOU=TK']%7B3]I_X4_\%7OV<M9_X4/\0M2_9P_;;\*^'[[6]'\-
M^'-8/AO1?BS?:7IW_$S\.\?]![_F6M=_Y&/PYXCS_P`RM7XP_L2>,/V[_B[\
M:XO@C\*[K4OB1?Z]<?VEX_\`#GQP_P")QX+T+0]+)TSQ-XB\<ZIJW_(J:1H/
MJ3GI_P`(L?\`A*,5\#7'P%_:!^`W@+X1_M/^%+37M-\+^*I[_6O"_B/0[@C^
MRK[POXC.E]B.<Z9D=LXSP<5]!7G_``5$_:SU?PCXN\$>'IAIWB?XA`:;XA\8
MZ%X?-GXTNM#TP$Z9X<_M/2@#_9*ZOJ>IZR<@C.J'!/!;NPW#/#JP>/R_#91D
M>9Y?F3DE.3A&IE%N7FNTW*]];\S2:T:;L>GA^.^-<%7P..K\49]E^/RWELO^
M%;EE:UKIW4D[VV:U\[G[[?M3>/\`_@DU^Q<9=&\47VN_M!?&T:?9C6/!WPK\
M4:EX<^&7AC7/^8EI^F:H#_;0']K@Y')(P25^85^"_P"VE_P40\)?M5:;X6L-
M+^#0\*ZSX#M_[-\+_$"X\4ZCXD\:77A7D_\`".>)M3U;_D+:1H./^*9_Z%WH
M.>O@]Y^R[XH\!>&O"7QC_:HL/&'AO0?B1?WQ\'Z']GQXU\9#3!_Q,]1_XF__
M`""=('_$MSK>O=<^QK^F;_@BO^RK_P`$BOVX;/QE\.I/@]X\L_C;\,?#]CXL
MUC0_B-XH_MBR\4:&=2_LO_A(O#6I^$_[`_M;^PO^)9_PDFB'0.NJXYSQGA<H
MX:X-PLLSP&"<U@(^]*+O":5KZN_,DW9WNF_DS;B?C_Q"X_G"AQ/GCS#!PE%T
M\HE=5(M<MI*]FGI?3S;UN?RO6'[7G[2>EV-EIEEXV\0066G6EO86D`U,*(;6
MSA2WMX@N?E$<4:(%[;<45_I;6_\`P2M_8/L[>"TB_9W\"S16L,5M'*?#HE,L
M<"+$DAEQ^]WJH;S/X\[N]%?,_P#$3N$7J\OA=ZO3J[7^UYO[O6W<LYX^22CG
M^81BDDE=:)<ME\DK?+R5_2+/X]^`_%-EI>LZ%XDTW6+7R/LMO/!J`_TH@'\?
MS_2OYU?VG_\`@CW^Q)XL^+^L_%KPGXI\=^%;7Q3X@OO$E_\`!WPY<>'3X7NK
M[5"=4U,:9J?_`"&O"FD>NAD'_J5LU\;>$_&_C+X?Z:8O!=_J4TNO7'V800?\
MNOT]?\YK]J?AOH=KIW@C08O$D7]I:S-;_:=0OM5M_P#CZOO[.S_9W7GG';(]
M3SC^<.,..\VX"RAK)L<UF&9IQ23:LFK/E[-)Z.RLU?<_T#K?1CX:P.9+&8C&
MK,L`I<RR:5]'=.^O9ZM>3.)E^''@.7X>:!\-;GPMII\">%?#_P#PC?A?PX8/
MMNBZ9H>E_P#,/TWGOZ]SU/45Y)I_[,'[/WAOQ%:^+='^''A6'7=-(N;?58-'
M'^BGC\3W/TK[7N-/\.1I%+'I6F^5-_SPX_R!G'^37!^((]&MX;^6.ULX983_
M`,^_VSGZ]2/S/:OYGPG%^>O$RF\QSWFG)RE_PL/EE)M2E=7U3;=[WTOH?I%#
MPYR3&5HQKY;DBBDDO^$>-TERI*^EVE'=;VW9^7G_``5`_9]^+/[>.@_!"U^%
M&E:%J7Q5^"GA[Q7HEMX5GU#3?#E]\1?`_BC^RM4`\,C5B-$_M;0CI?.?^$?/
MB+PYJV>>`>L_X(A_L"_M`?L5?''Q[^U)^TQHL7PL.F_##7/!/P_\$7'B#P[>
M:SKU[XHU#2O[3\1:F-)U?7_[)TC0-)TP\YY\1$<#G/N7C_Q(=#F_X2+1XM,A
MUG0?^)WI\$%AS_Q*^?\`.>M?,'Q+_P""@OC?Q1X=^P>']*GFEO+?_2/]'^QF
MUS^/8_G^>?[#\/\`Q!S[-N"EDN+2E9*+FUS3Y>9-7;N]-;O>VG-;0_GCQ1^C
M8EQ9@LWX>P2BLQW25HWNKZ+1+HELNVQ^\5Y_P4)^'\%W=027]I+)#<3Q22M/
MN:1XY61Y&;'S%V4L6[DYHK^/^X\1>,[F>>YNV1;JXFDGN0J><HN)7:28"7/[
MT"1F`D_C'S=Z*^F67</.S<==&_7W;]/+^K._RJ^C[G6G[Q]/_;;=?3[O/7Z'
M\`:I%<>.O#?A>WE\Z*SUBPN=0GYL_P#P69/_`%#/>OW,N?'^C3Z5%%)#-/%]
MGL?W%C<?8_?^I[U_.?X0\22QZ_H/BBW\X13ZO]IN)_\`E]^P_K_CGVK]6=0\
M:12:!:RV\LWV74_L-S<3SV_\N17\^^+N3XC&X_).7=->BVO=+[[?Y'^BV#R[
M#YT[JZ\[6>Z:N_6Q]#ZQXLTO[-:PZ7+>0R_\>UQ!/_H?'_0.[]!_];G%>&:Y
M\0Y8TEADOYIHH;?_`$>#[1[_`/(.[^OY9KQO7/'G[_\`=W4,T7_'SY]O_H?V
M3Z]?[6[>P->7ZI\0_LT/E277DQ0W%]<_O_KQD<'KZ"O@\MX:K75XW>E]->GE
M^730]NEE6%P"OB''1::JWGU_KKY=1\1_&%U<6%_+%+-YOV?_`$>#[0?MMU_/
MW'/_`-:OS)TN35([/S9+7SH8;C[3Y$%Q_P`>O\_3\>OM7T9X[^*>ER>';^6X
MNA-?P_Z-;007'_04_P`\\U\TZ?;Z7'?RR6VO^3+-_P`?%C/;_P">?S]>:_H3
M@3)Z^!P&-TLM+)Z:7B]$^]GT^\_/\]S/#X['X+ZLU[KZ.Z5K7T5[:_KU.C/B
M&W4E3&JE201D<$'!'7L>**G72K!%5'DL7=%"N_V`Q;F489O*_P"6>X@GR_X,
M[>U%?;^Q?6_WHY^9^7W+_+R7W'0Z>JPZ).L*B)4NO#&T1@1A<9QM"X`QVQBO
MK99YSX)\(.9I2Z>$3,CF1RRS?\]5;.5E_P"F@(;WHHK\UXTWI>L?S@?;\-?[
MO_VXO_;3Q36[Z]EW>;>74NRX&SS+B5]O3[NYSM_#%<9XPN[K^S#_`*3<<7/'
M[Z3CZ?-Q117AY3\</2'_`+:?-\0?\BA^M0^;?%<DCW_AI&D=DEA^T2HSL5EN
M,?Z^122'F_Z:L"_^U72:$23JSDDL7Y8\L>>YZG\3117[;@_X?_;O_MT3\PX<
M^./^)?G`CW,>K'\S1115'W1__]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]E=FEL+FIP9P``
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,C`T`#$P-#$W,S8S,#$Q`#`R
M,C4W-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_
MQ``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!
M`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<`
M`0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9
M&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/[&_&OQ
M-L]&U/6%M(FO;XW<I2VM@JDQI(T4<<\\\D;Q`NA;,*.V3@@`"OD7QT_Q!^+&
MIQ6%_.UMX?@N60Z#I#[!=('PCZK<1/YLL+E%(+KF'<YC+,Q:O-/B+\4/%6M:
MKJEGX<\.V.GV'G2&/6]6NYKF^O\`?(9)+F,H+>6SY,H5&9V*A>@KWW]GCQ#;
MW5KIMA=6\9UF%8$U"1Y'DEOMA/FRR2,Q=2OS[(R<,2"01G/\;\0^(F&XDSS$
MY+6K8BOEM7%5<.Z6#J3I8:O%5ITJ;Q52[JUJ*G:K+!THJGBU%*K*KSR@_P!>
MPF08G*<!0S!48TJSC#WYI2KTG."?-!)2C3J.$O9J=1-QO[K7*K?*?QW^(OQ!
M_9P\-0^(/!'AY-=U3RUT^\=K2ZN;#PQIL)\Y8M)M[8+<NP9E-PRR1K.\DDGW
MW>OSFM_^"MW[16D>)K*VGO/"6JZ)=:BL-YH%SIU[]L\H$&2%KB1UNHIRCP*F
M%=(V^1HWD"H_]!7[07P^G\4>'=0BTBWMFU*ZTV[2WB>.0*\\D0^RQB6*(DS%
M_*41Y^0%CW7'\>/QU^%7PZ^'>M?$K1_%^@^/M!^(B>(KF;P]XMTG5HY])@O]
MWVC4M%\1Z5=W4=W:QAE<V]TJ(@TV9BS(QBDKP,UP..X>Q=HX[-JM&4USXBA2
M51SQ%9Q;Q-2BJ_OP?+&'U2A"I45*A!/"RIJ7)[N6/`YIATI87!NJG3IN=;$>
MP<(64E-SYE%.FTH*4URWFY3?*F?T\^"_C'X9_:F^"<WB/39(++4[_2!9ZW8I
M&[K9W4R+NM)0JPM'-:RQ$>64!8_+O&,GXX\5_'CQ)X!\"S_"FVGGAU6'7&M[
M?4[:0^=_8D+":!$D\[]TXF5"TA+?*OS(0<5^4'[`?[2/B+X2ZSXB\*W]KJ.H
MVGBVP!B<-/<:3!+;-+:6]_=^0)3;_:%"3K<?<\QR'>1P8S^A?B;X@_`WQ!X9
MGDO_`!/HO_"?S+->*;[41:I:Q1J&B27YD+^:2514&YGVC!!(KY+-\TQF%QM2
MCA,;/"YJ\KQ6%KX^-:"I8_!UZ:<82<7&I7KRNZ5+V<'S5*,*U3X:D8>OE^6T
M84$L3AG6P7UZG*A";M.C-0IR4ZDERN5%4ZJ;5^6HIQ=M%;FKCXU^(9YYYIM:
M+32S2RRLR7A8RR.SR%BK[2Q8DD@8)R1Q17SA+X^T5)94%VL@21U$D6HKY3A6
M(#QY3/EMC<F>=I%%?.)<0-)^WS=WL[NK73=^5WLJB6M[Z)+7;77T7*C&3BL'
MA+)V7^RX5Z)I+7V;[KJ]]^W]$4'P?AU.VDO1%##]LA,P81-`H61GQ!#D;>/-
M#DID[B6'!Q7SAXJUG4?@CXNLW6-2\CO)`R2;6N/LLP/$A^4HS2C*%5+*"-X&
M17UE!\0#_8]II_VAL11VT<1LQG8VQ`(VBFZR`CYG5MK<#->0>+/AS:?$'7K/
M4/$.^;3K3S&$"S^3(\)5@\<JEU(1I%1BJLP.`2<C%>]Q)A,JP.%AB\EEBJ.9
MQG[6-:I).$9N;5:]-1CS.]ITZS<H13J)JJO9PI^%E>.J<WL<UM4P3IQA*E!-
MSERNT5'FLMU&S=G=*^CN>5S_`+17Q$^(,DFA>";:\C\0WLYC6]O+J--/M3""
M7C>7RW:W>.2)?+8,QVMMR0>/F;Q?^PGI/Q=\0ZOXI^/6M75SXOU7]Q%_PCDB
M0QV8F<*][<RA%BN+MHT5$>4,X5WPRB1A7VCJOCCX>_`-%CTO1+2XEE>5I;"S
M"-?3NDCD^2#YTC2%68/@JI'.%YKYQ^'_`.U?K/QN\7^-SH]CX;\&Z+X/U"*V
MGCUO5[:#7[^2X.8TL=+G?RG>W5]PE#E6D,2;=Q*UQ?VCB?JN#QF*QN9X_&2J
M-TL+"C5I8:G3]V4Z\XU:O*W*ZJU*K=X<LIP3=CNI4W^^6!PU#`X2<H4_;59*
M6(E*5G&GSQISY(^[S-6E91_B6^+Y[^('[`WPC^#O[/\`\7_$'AK5?$K^*XM!
MU/['XHUJYD^VQK;QM-9Z/96EKF`B:1FBDFCC5I@T:G"*%'Y#_LC_`+-7B;XT
M?%'P_P"%K;1/$VFMH=Q<:UX\\47NI-'X=C\,P7"P10BSEMA.-1AA$GVF#[6R
MF[,(14C+1G^C7]I'4O'-K^SG?_:8C+/K>LV^)A;QRM>6%]=6T5M%%`K!F:24
MK+"``22`<@D5YY^R'\*O$_PUT_QEX[\;6#:++XE\-&UTS3)%%M/'%`DD\MUJ
M.X,QE&-J@D</LQ@X'O<,8K,,[SBO@I95BZ.6^QP;QU:5.6$>'G3I1;IR<&HU
M825:-&C7F^>4(SK4DWRIY8_V>$RJC4>+IO%+%5?JM%5/;RE2J8F%&4U"W_+J
M-!MUG:R;2=E$X.;X(_`G39I=.C\-)>1V$CV27DB+YETEJQ@6YD^7[\ZQB5O]
MIS13KM[I[JY=40J]Q,REI2C$-(Q!90A"D@Y*@D*>,\45^E<_#L?=^J\/KE]V
MW)'2UE;7$O;7KWU[?.6Q#U^MXC6SUE6O]GRWV]=.Y]M:->Z-K*6FI6MRLVG0
MR17"JEP61C&H6&,JW*AV)=@1@A@,?*!72>,OB3I_A;3;J2[6."TL8!([12M-
M(5A*S2*8D4RMOP`S*0I4D$$&OSQ_9U^+TMAX@M?"/B6]6YL[\G^RVN2%M_,4
MO*L,9,X>0F20H^0PC1$8@`U]]7O@6R\5VTDR6EI=QW=OYB6\S+<LTK,25BN%
MB+11,@*QR9,3+E`Y;@_E>$Q4.)J-/$X"C'V]-/ZQ3K8>$VI2IT6YK#S;C[*J
M_8U,/14[3F[5$XN2/8Q6!EE&+>'S&5Z<)6BZ<I*,X<RM'VJ]Y6TA/W79W5I+
M4\9\-?$[X6^(;UO%OB"Z\.Z+)--<VMK=^)-0B"LL,C1W)MK6^QY;ND>2>.&X
MZMC\\?V]/`WPN\.:KX'^*GPA71XT\2:O>P>)9_"&KI?Z?>206T-[9ZA>6]K(
MUO9RI=0.KI$W+1!SB0M7T)^TK>_$_P"!YT#5(O@YHVO:4]W.);RYTJVU[1I+
M&'*30M':Q.]O((RL<BD++"Q=I`":^'M#TWPS\>?&,=I\/O!WBWX?:KXJUVQG
M\5>$M)=[WX=ZF\X8SS"PO,W.C7.))6U&.T\A)WC,;?O$<UXTIYU4G2P&*PM>
M6-AC:4?J]6C7A7Q-.I",W"=+!-U)5:ZJ1AA*$<-*C4J<KJXB4*<JT/?PE'!T
M55QRQ<:>$GAI\\HU(5(1E&G=756$7S1MNY)R5W=7T_17]G^+XK?&#P5X9U;X
M@:M'-X'T1M*O=.MY[.:\GU:[TN6.?3EMY&2-([>V>`1W89I"A4@,1@U]:_%#
MQ+%;>$;Q(D22>>*:R,:3,6,P7=*@M9-T@4J2.#SP!DX-:_A7PQ;_``Q^'7A_
MPKI&QHM&TBWM(_-55C-Q"(PS&0)(S`W#NGS,KEUVM/(_)\#^*6MO*^GZ=YCQ
ML@EG-N\L3(UQ<E=L\C!O."$3!T+C85!.=I)K]XPV`PW"F0U(TJ518RLL++&Q
MKXBKC/;YE4A"C:4JTZJC.A>%/#TZ4HTZ=.E2ES2C32?Y].O4S7,*?.DJ:YXT
M(QC%*CA8R4H4XJ,8_%*;E4DW>=2I*5HWLO#6N)"S'RW7))V^5=#;S]W&.,=,
M=J*OM'<AB#Y1.3DB>WP3GDCY^A/(HKX)1PZLI5Z%U9.\Z"=UR7O[SL[IWU?7
M4^B4*6GN5^G_`+;_`'?/3Y=F</\`$[2M+TKP#\,]6TO3;#3=575[(KJ=A9V]
MGJ"EHH=Q%Y;QQW(+9.[$G.3G-?IY\$I'ET_09)7>21K.VW22,7=L1<99B6.,
MGJ>Y]:**PR7_`)*'`_\`8NR[_P!0L,+-O]Q?_87BO_3]0]R\26]O=Z/KD5U!
M#<QHE[MCN(DF1=PFW;4D5E7=@;L`9P,YQ7Y(_LP6=I'\;/BZ\=K;HUMK1-LR
M01*UN?M%V,P,J@Q''&8RO'%%%?3U/^3D<*_]AV9?^H%4\JA_R3F:_P#7[#_^
MG('W3XS=_P#A'O,W-Y@^R`/N.\!KF$L`V=PR22>>2<GFOC;QU+(=>U#,CG]W
M9I]]ON%-I7K]TJ`I7H1QC%%%?2<5_P#(LP__`&$4/SB<>5?[VO\`"O\`TY3.
M2).3R>I[GUHHHKYVG\$/\,/RIGUL=EZ+\C__V0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]F96UA;&4Q+FIP9P``````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P
M-S4P`#$P-#$W,S8S,#$Q`#`R,S$U,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#_V/_@`!!*1DE&``$"`@!.`$X``/_``!$(
M`+X`E@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'!P8("A$+"@D)"A4/$`P1
M&18:&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q-#`K-"@K+"L!!P<'"@D*
M%`L+%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*__$`:(```$%`0$!`0$!```````````!`@,$!08'"`D*
M"Q```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*Q
MP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA9
M6F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1``(!`@0$`P0'!00$``$"
M=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7
M&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY
M>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)
MRM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^J:`
M"@`H`*`"@`H`Q?$_BK0?"MJ+CQ%J]EIT;([H+B8*\H0`ML7[SD9'"@GD<<B@
M#B[3X\_#6ZNH;>+Q/&LDKA%,MI/&@).!N9D"J/4D@#N:`._T76M*UVU>ZT34
M[+4K9',;2V<ZRHK``E25)&<$''N*`+]`!0`4`%`!0`4`%`!0`4`%`!0`4`%`
M!0`4`?,?QJ_:/CM/.T;X<S;[V*;9-J[1H\0"X)$(.0^3D%B,8!V[MP8`'RE=
MW,]Y=375W-)/<S.9)997+/(Q.2S$\DDG))H`BH`*`/6/A_\`'OQKX3N@+O4)
M->T]WW2VVIR-(_)7.R4_.IPN!DE1N)VDT`?67PO^+OA?X@6MM'97L=GK;H#+
MI=P^)5;#$A"0!*`$8Y7.!@L%)Q0!Z)0`4`%`!0`4`%`!0`4`%`!0`4`%`'SE
M^U#\8-1\+72>%?"MS'#?3VQ:_NDYEM@Q&Q8V#?(Y4,3E<@.A4@\@`^/J`"@`
MH`*`"@"6TN9[.ZANK2:2"YA<212Q.5>-@<AE(Y!!&010!]6_`3]H*UDL(M`^
M(E_Y-W%MCM-5FR5G!(4+,W\+#/\`K#P0"6((RP!].4`%`!0`4`%`!0`4`%`!
M0`4`17=S!9VLUU=S1P6T*&2665PJ1J!DLQ/```R2:`/S+\5:]?>)_$>HZWJL
MF^]OIFFDP6*KGHJ[B2%484#)P`!VH`RJ`"@!#TH`0,#[&@!U`!0`4`?3G[-/
MQMCT^&R\'>+I]MHOF?9-5NKI$CMD5`5A?=C"_*^UBQ.650,8P`?65`!0`4`%
M`!0`4`%`!0`4`>)?M7>/'\*>`QHMI%)]N\0I+;K,-NR*%=HESD')97V@`?Q$
MY!49`/AZ@`H`*`"@!I4&@`&<]3B@!U`"$@=:``<B@#[2_9$\=_V]X.E\,ZA/
MNU+1<>1O?+26K'Y<98D[#E>`%53$*`/?:`"@`H`*`"@`H`*`"@#X$_:*^(MK
M\0_&\<^D-<_V-I\/V:V\UB%E.XEI0A^YNRHYY(12<'Y0`>64`%`!0`A.!0`@
M!/)_*@`W#-`"@@]*`&/]Z@!R=*`.F^'?C#4?`WBVPUS2Y)`T+@3PH^T7,.07
MB;((PP'7!P<$<@4`?I!I.H6NK:59ZEI\OG65Y"D\$FTKO1U#*<$`C((X(S0!
M:H`*`"@`H`*`"@#Y#_:/^.7]L_:O"?@NZ_XE7,=_J$3?\?78QQD?\L^Q;^/H
M/ER7`/FV@`H`*`$)P,T`-7).30`K'`H`CH`5?O"@!7/.*`%CZ&@!]`'Z`?LS
MW,]U\#_#$EU-)-(J31AI'+$*L\BJN3V"@`#L`!0!Z=0`4`%`!0`4`?#W[17Q
M-\6:EX\UG03<7NC:38/+9"RAE>/[3&>#)+TWB1<$`_*%(QG)9@#Q*@`H`*`"
M@!K]/QH`4#`Q0`QCD_2@!!R:`'G"CCK0`SJ:`)`,#%`"T`?;?['.H75[\)9H
M+F7?%8ZG-!;KM`V(5CD(X'/SR.<G)YQT`H`]SH`*`"@`H`*`/G+]ICX*S^(Y
M+GQAX4CDFUE47[=8@EC=*JA0\8_OA0!L'W@./FX<`^/J`"@`H`*`$(R*`#F@
M"*@!0<&@`ZF@!ZC`]Z`'4`%`'VW^QSI]U9?"6:>YBV17VIS3V[;@=Z!8XR>#
MQ\\;C!P>,]"*`/<Z`"@`H`*`"@`H`_.KXYZ5/HWQ?\6VMT\;R2:A)=`QDD;9
MCYJCD#D+(`??/7K0!PU`!0`4`%`!0`TJ*`$V>]`#@`*`%H`*`"@#]!?V<=/N
MM,^"GA:"^B\J5X9)U7<#E))7D0\'NCJ<=1G!P:`/2:`"@`H`*`"@`H`^!/VH
M?^2Z>)O^W;_TFBH`\LH`*`"@`H`*`"@`H`*`"@`H`Z_X3^#)_'OCS3-#B$@M
MI'\R\E3/[J!>7;.U@I(^521C<R@]:`/T%UK6=!\&:`EQJMW9:1I-L@BB#$1H
M`JDB.-1U.U3A%!)QP*`/$?$O[5'AJR\R/P_HVI:I*DQ3?.RVT3H,_.K?,W.!
M@,BG!YP1B@#SN[_:J\8-=3-::-H$5L7)BCEBF=U7/`9A(H8@=2`,^@Z4`>_?
ML^>/]5^(W@R]U?6[>R@N8=0>U5;-&5"HCC8$AF8YRY[^E`'IU`!0`4`?G+\9
MO$]KXQ^)VOZYIZXLKB94@;)_>)&BQJ_(!&X(&P1D9QVH`XN@`H`*`"@`H`*`
M"@`H`*`"@#V/P!\6;+X5Z-JNG>$M(CU/5KMXS-K%W.XAEV=DM]JL$&YPI+!C
MNW,!_JU`/,?$OB'5_$^JR:EX@U&YU"]?(\R=\[06+;5'15!8X50`,\`4`95`
M!0!])?L4:]8V7B/Q%HES)Y=[J4,,UMN*A7\K?N49.2V)-P`!X5CQB@#Z\H`*
M`/FW]J/XP_V1#?\`@;0%SJ%Q#Y>IW,B?+#%(F?+0'JS(PRW10>/F.4`/D.@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`.I^%OBK_`(0GX@:+X@:+SHK.;]\@
M7<QB=2DFT9'S;&;&3C.,\4`?I+0`4`?(?[3/PG\5ZC\0-3\3Z#I=SJNFW<,#
MR?9E5I(G"B+8(PQ=^$5LA<`-_LDT`>!:[X<UOP_Y']O:-J6F>?N\K[;:O#YF
M,9V[@,XR,X]10!E4`%`!0`4`%`!0`4`%`'??&:V_LC7=&\.-I_V"?0M&M;6X
M3SO-WSNIN)6SR!^\N'&`2..."``#@:`"@#5T+PYK?B#S_P"P=&U+4_(V^;]B
MM7F\O.<;MH.,X.,^AH`U/^%<^-_^A.\2?^"N;_XF@"WI?PK\>:G?Q6EMX1UM
M)9,[6N;1X(Q@$\O(%4=.Y&3QU-`'M'PE_9JU--5L-8\=RVUM!;3+-_9*!9VF
MVL?EE;E`I(4X&_<K$'::`/K*@`H`*`"@#AO'GPH\'>.))+C7='C_`+0=&47U
MLQBF!*A0Q*\.5"KC>&`QTP2"`?.7QB_9S_X1+PYJ7B'PUJUS?V5GM=[&X@W3
M)%P'?S$X;!^8_(H"Y)/R\@'SO0`4`%`!0`4`>Q_LI>&M.\1_%:-M461UTJV.
MHP(C[09DDC"%L<D`ONQQD@9R,@@'%_%WQ*GB_P")7B'6X6C>VN+DK;O&C('A
M0".-L-R"412<XY)X'2@#D*`"@#J?AEXTOO`'C&RU[3T\[R<I/;&1D6XB889"
M1^!&00&53@XQ0!^C>DZA:ZMI5GJ6GR^=97D*3P2;2N]'4,IP0",@C@C-`%J@
M`H`*`"@`H`*`"@`H`_/_`/:$^'B?#WQY);Z=#(FA7R?:+`LS/L'1X]Q`R5;M
MDD*R9))H`\QH`*`"@`H`^@OV*V@_X61K*M'(;DZ2Y202`(J^;%N!7&222N#D
M8P>#D$`'S[0`4`%`!0!]>?L:^-_MVA7W@V\?]_IV;JRXZP,W[Q>%Q\LC`Y))
M/FX'"T`?25`!0`4`%`!0`4`%`!0!XO\`M9>%_P"WOA7-J$$.^]T:9;I2EOYD
MAB/R2*".54!A(QY&(AGID`'PS0`4`%`!0!['^R?K\&A_%^UANA&L>JVTEB)9
M)0@C8E9%Z_>+-&$`XR7'T(!R'Q:\"7W@#QC?Z9/!<_V;YS?8+N1&VW$6`PPY
M50S*'4-M&`V1Z4`9]SX%\46OA)?$]UH=[#H3.B"ZDCV@[@"K;3\VPY`#XVDD
M#.>*`.;H`*`.Y^!FJSZ-\7_"5U:I&\DFH1VI$@)&V8^4QX(Y"R$CWQUZ4`?H
MK0`4`%`!0`4`%`!0`4`4/$.E0:[H&IZ1=O(EM?VTEK*T1`=5=2I*D@C.#QD&
M@#\P*`"@`H`*`+6DZA=:3JMGJ6GR^3>V<R3P2;0VQT8,IP00<$#@C%`'Z2^!
MO%VD>-_#EOK6@7'G6DORNC<20N,;HW7^%AD>Q!!!(()`)?&?AK3O&'AC4-!U
ME9&L;U`KF)]KJ00RLI]0P!&<CCD$9%`'YP>*M!OO#'B/4=$U6/9>V,S0R8#!
M6QT9=P!*L,,#@9!![T`95`%K2=0NM)U6SU+3Y?)O;.9)X)-H;8Z,&4X((."!
MP1B@#]1*`"@`H`*`"@`H`*`"@`H`_+&@`H`*`"@`H`[3X4_$75_AQXC74M*;
MSK27"7EB[8CN4'8_W6&3M;&02>H+`@'Z`>$?%.B^,-&75?#>H1WUBSM&9$!4
MJPZJRL`RGH<$#@@]"#0!YM^T9\)7^(FC6^H:*8T\1::C"%6"J+N,\^4S]000
M2I)V@LP.-VX`'Q'K^C:CX>UF[TK6K22SU"U?9-#(.5/7Z$$$$$9!!!!(-`%"
M@#]$/@GX^L?'W@BQNHKW[1J]K#'#J<;JJ2)/M^9BHXVN0S*1P1D<$$``[Z@`
MH`*`"@`H`*`"@`H`_+&@`H`*`"@`H`EM+:>\NH;6TADGN9G$<442%GD8G`50
M.223@`4`>O?#SX;?&+0KJ#Q!X2T:]TVY='C#32P1.RDX*O#,P.,C(#+V5AV-
M`'VCX/N->NM`M9?%>GV5AJS(IEAL[@S(#M!.<J-IW;AM!<#`^=J`#6O"?AW7
M;I+K6]`TG4KE$$:RWEG'*ZJ"2%!8$XR2<>YH`\QUW]FOX>ZEY'V.VU+2?+W;
MOL5X6\W.,;O.#],'&,=3G/&`"+1?V<?#NA73W6B>)_&.FW+H8VEL]0CB=E)!
M*DK$#C(!Q["@#TFT\.ZI!=0RR^,]?N8XW#-#+#8A)`#DJVVW#8/0X(/H10!T
ME`!0`4`%`!0`4`8'Q!U"ZTGP%XEU+3Y?)O;/3+F>"3:&V.D3,IP00<$#@C%`
M'YH4`%`!0!M>$?"VM>,-972O#>GR7U\R-(8T(4*HZLS,0JCH,DCD@=2!0!]1
M?#K]EW3+'9=>.[[^U)^?]!LG:.`?>'S2<._!5AC9@@@[A0![QX8\*Z#X5M3;
M^'=(LM.C9$1S;PA7E"`A=[?><C)Y8D\GGDT`;5`!0`4`%`!0`4`%`!0`4`%`
M!0`4`>!?MC>*O[)^']IX?CBW2Z[-\[LN52*%D=L'(PQ<QXX(QNZ'%`'Q=0`4
M`>^_!7]GW5]?U6'4O'-A<Z7H,7S_`&6;]W/=D,1L*_>C7CDD`D$;>NY0#Z]\
M->'M(\,:5'IOA_3K;3[),'RX$QN(4+N8]68A1EF))QR30!J4`%`!0`4`%`!0
M`4`%`!0`4`%`!0`4`%`'Q)^T/H_C/QC\5-5O+/PMXDN--M-ME9N-+DVE(_O%
M652&5I#(P;))##IT`!S_`(7^`?Q"\0?9I/[%_LRTGW?O]2E$/EXS]Z/F49(P
M/D[@].:`/JCP#\"O!?A'^R;O^S_[1URPP_\`:%P[_/+S\XBW;%P3\O!*X!R6
M&Z@#U.@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`/_]D````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9E
M;6%L93(N:G!G````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(Q-34`,3`T,3<S
M-C,P,3$`,#(S,34U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/_8_^``$$I&248``0("`$X`3@``_\``$0@`O@"6`P$1``(1
M`0,1`?_;`(0`!@0%!@4$!@8%!@<'!@@*$0L*"0D*%0\0#!$9%AH:&!88%QL?
M*"$;'24>%Q@B+R,E*2HL+2P;(3$T,"LT*"LL*P$'!P<*"0H4"PL4*QP8'!PK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK_\0!H@```04!`0$!`0$```````````$"`P0%!@<("0H+$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?H!``,!`0$!`0$!
M`0$````````!`@,$!08'"`D*"Q$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q
M!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V
M-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*
MDI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:
MXN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#ZIH`*`"@`H`*`"@#,
MU3Q#HNDW"P:KJ^G64[+O6.YN4C8KDC.&(.,@\^U)M(I0E+5(OV\\5S;Q3VTJ
M2P2J'CDC8,KJ1D$$<$$=Z9+5M&24`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!
M0`4`%`'C/QB^$MUXFU:;7M`G@%Z\2B:TEROG,JD!E<D@,0$4+@#C)(K.<+ZH
M[*&)4%RR/!98->\$^(H7EBNM*U:U;?&S+@\$KD=G4X89Y5AGJ*RU3.V\:D>Z
M.[\-?'+Q/IUVS:SY&L6K=8W1877@_=9%P.2,Y#=.,=:I5'U,9X2#7NZ'I_@[
MXW>']:W1:TO]B71E5(ED<RQR`]]X4!<'KNP`,'/7%JHGN<U3"SC\.IZ?87MK
MJ-I'=:?<P75K)G9-!('1L'!P1P>01^%:',TT[,GH$%`!0`4`%`!0`4`%`!0`
M4`%`'G?Q<^+6@_#2UA741)>:M<HSV]A;D;R`#AW)^XA8;=W)ZX5MIP`?-MW\
M3_C=XMM9KW1K/5H])O4*)_9&CLT0&-C>7+L9P<@\A\@YP1@8`.`MOAG\0]?U
MEE?POK\E]=N\CSWUL\0=N69GEEPN3SRQY)[DT`6]2^$OQ)\,75E='PUJR7(?
MS()=.Q</$R$$-F$L4()!!..G'0T`3>#/C1XP\/:B6U#5+K7]*G(6\T[5)C.E
MQ'@@J&?<4R&/(X)`W!@,4`G;5'M_PX\1_"3XDZBT.H^'X-`UV3:!:R7;10S$
MML582C*K-]S*[5)+'`;!-3R1-EB*B5KFAXW^`LEK:?:?!]W/>2+M#6=VR!VY
M.663Y5XX^4@="<]!4.GV.FGB[NTSSOP3XJUKX;>(K@M8NKNJQW5C=AXR5R&!
MQQAL9PQ!P&/!S4)N+.BI3C5CN?47P^\::;XVT47NGGR[B/"W-JS9>!SV/JIP
M<-W]B"!M&2:/,JTG3=F=/5&84`%`!0`4`%`!0`4`%`!0!\*?M9Z5/I_QGU"Z
MF>-H]2MH+J$(22JA!%AN.#NB8\9X(^@`/N'2=0M=6TJSU+3Y?.LKR%)X)-I7
M>CJ&4X(!&01P1F@"U0`4`8'C'P;X>\96"VGB;2;;4(D_U;2`B2+)4G8ZX9,[
M5SM(R!@Y%`'R'\:O@!J?@WSM6\+"YU7PW%#YL[2,IGM<8#%P`-Z\[MRC@!MP
M`7<0"7X%?'K4?"EU9:)XMN9+SPPJ+!%(4W2V`!.""!N=!G!4Y(`&W[NU@#ZV
MUCPYX:\86,5QJ%A8:E#<0H8KM,%FCSN79*OS;3G/!P03V-)I/<N%24/A9\[>
M*?#VO?![Q;!JVB3O)ILC%8+AAE9%/)AF`P,X'MG&Y<$$+BTX.Z/0A.->/++<
M]N^%?Q#L_'&F%'"6VM6Z@W-J#P1T\Q,\E2?Q4G![$ZQE<XZU%TWY'=U1@%`!
M0`4`%`!0`4`>!?%;]I#2/#%^VF>$[>V\07?DDO>)<_Z-"Y'R`%0?-]6`*@<#
M=G.T`\[\*?$3XW_$G69)/"DD=I8LX1Y([&);2VQL#?O)59B?F#%0S-@D@8XH
M`^C=8^'6D>*?#FEZ;X]7_A)+NRR_VZ5?LTC.?O$>3MVJ>/E!QA5SN(S0!U6D
MZ?:Z3I5GINGQ>396<*001[BVQ$4*HR22<`#DG-`&=<>+O#=M<2P7/B#1XIXF
M*21R7L:LC`X(()R"#VI<R+5.;U29'_PFGA;_`*&71/\`P/B_^*HYEW'[*?9F
M_3,PH`\,^+W[/6D>,[^\UK0;K^Q]<GR\B%-UM</AN64<HS$KEQD<$[2Q)(!Y
M#\&OBCJ_PC\1S^#O'<%S'HT<Q22*0;I-.<\[TQG=&V=Q"Y!!WKDDAP#[(1K/
M5=-5D:WO=/NX<@@B2*:-A^(92#]"#0"=M4?+_P`5/"LOPQ\6Z=JOAJ^>""Y9
MY;0`DR6[+C<A)X9<.`,YR"0P/5L)+E=T>G1J>VBU)'NWPK\;Q>./#INVC2WU
M"W8174"L"`V,AU&<A6YQGN&&3C)UC*Z.*M2]G*W0[.J,0H`*`"@`H`\"_:_\
M:7WA[P=8Z#IZ;/[?\U)[D2,K1Q1F,L@`QG?O`.3C;N&#NR`#@/V??@):^(]*
MM_$WC>.Y&GS;_LNF$&+[0A5=DQ=6#!3EL+A2<*V2IP0#ZWM+:"SM8;6TAC@M
MH4$<442!4C4#`50.``!@`4`>6?M+^-=:\"_#VWO_``W/';7USJ$=J9WB$AC4
MH[DJ&RN3Y8'(/!/?!`!-KC:AX]^&=C8ZD6TB_OK>WFO%6+(5\*[(4;YE`;MN
M!&!DGD'RZN/U<4NIZF'PG*U-OH>/WOP>UZ+SVMKK3[A$W&-=[*\@'08*X!/U
MQ[]Z2QD'NCKY6<[J'@'Q18PK+/HUPREMH$!69L_1"3CCKTK58BF]F+E8G@WQ
M;K?@369YM-(CD(,5S:7*'8Y&1AUR""IS@\$<CH2#O&5M495*4:BM(^HOA7XW
MB\<>'3=M&EOJ%NPBNH%8$!L9#J,Y"MSC/<,,G&3O&5T>96I>SE;H=G5&)\^_
MMB>#(-4\$P>*H1''?:.ZQS,<`RP2.%VYVDL5=E(!(`#2=S0!?_9(\:?\)%\/
MVT*=+DWN@;8FGEDWK+%(SF,`GD;0I3;T`5<'G``.T^.NC_VQ\-=4V0>=<66V
M[B^?;LV'YVZ@'$9DX/X#.*B:NC?#2Y:B/!?@7XFE\/>/+.`EVL]49;2:-<GY
MF.(VQD#(8CDYPK-@9-90=F=V)I\T&^Q]<UT'E!0`4`%`!0!\<_MK:A=2>/="
MTUY<V5OIGGQ1[1\KR2NKG.,G(B3@G'''4Y`/I?X0:K9:U\+_``O>Z:D<=L=/
MBB\J(.$B:-?+=%WDL0K*R@DG.,Y/4@&WXE\0Z1X8TJ34O$&HVVGV29'F3OC<
M0I;:HZLQ"G"J"3C@&@#X_P#'OB";X[?&/3]'TN20^%[%V$,BPF-UAPIFE)PQ
M!8J`NX`?ZL$`ELY5ZJI0<C6C3=2:B?3E?.GNA0`4`<QXV\%Z;XLA0W1>"]B4
MB*YB`W`<X5A_$N3G'!ZX(R:VI5I4]MA-7/GNRN-4\'>*8+@1O;:GITX8QN2`
M2.JG:1E6'!P<%3UP:]:$TTI1,9Q4DXL^R/!/B&+Q5X7L-:@@>W2Z4DQ.02C*
MQ5AD=1E3@\9&.!TKJ3NKGCU(<DG$X?\`:A_Y(7XF_P"W;_TIBID'@/[%O_)4
MM4_[`TO_`*.AH`^RM1LX-1T^YLKR/S+6YB:&5,D;D8$$9'(X)Z4#3:=T?$UN
M9?"/C:(W*)<3Z/J(,B1N0LC12<@,1D`E>N/PKFV9[#]^&G5'W!72>,%`!0`4
M`%`'S'^V5X%NKVVL?&MC\\5C"+._1I`-B&3]TZKCGYY&5N2>4P,!C0!S_P"R
M!\1;72+^Y\&:JUM;P:A,;FSN78JSW!")Y1[?,%!7IR"/F+*``>Y_%'X-^&OB
M1JMGJ6M3:E;7MM#Y`DLIE7S$W%@&#JPX+-@@`_,<YXP`9/A'X5^'?AO<W']A
MBZN+FY0;[J\=7E"Y^XI55`7(SP,D]2<#'DYA)\ZCTL>I@8KE<NMSIZ\X[@H`
M*`"@#QC]H.VA6ZT2Y6,"XD26-WR?F52I48SC@NWY_3'H8*6C1$EK<[']EK4?
M-T#7-,\K'V>Z2X\S=][S%VXQCC'E=<\[O;GTZ;T/-QD?>3-O]J'_`)(7XF_[
M=O\`TIBK0XCRO]AS_F=?^W+_`-KT`?4]`'R=^T+H\6E?$>XE@V!-0@2[*)&$
M",<HW3J24+$\<L?J<*BLSU,++FI^A]/>%M0EU;PQI&HW*HL]Y9Q3R+&"%#,@
M8@9).,GUK9.Z/-FN632[FG3)"@`H`*`*&OZSIWA[1KO5=:NX[/3[5-\TTAX4
M=/J220`!DDD``DT`?G?\6+[POJ/CS4[KP-926>B._P`BMPCM_$\:8!C0GD(<
MX_V00B@%[P_\4_B#X0@%EI_B#4;>$PQ"."[43K'&%S'Y:RAMBE6!&W`(V]0!
M233V&TUN?>&MK.MK8+=R1RW(0B62*,HC-A<E5)8J">@)./4]:\W,OL_/]#T,
MO^U\OU,BO+/1"@`H`*`/-OCW_P`B?9_]?Z?^BY*Z\'\;]"9;#_V5/^9H_P"W
M;_VK7KTNIYN-^R>G_%WPT_B_X:^(=$A61[FXMBUND;JA>9")(URW`!=%!SC@
MGD=:U.$\<_8X\.:WX?\`^$O_`+>T;4M,\_[)Y7VVU>'S,>=G;N`SC(SCU%`'
MTE0!\O?M-3Q2_$&U2*5'>'3HTD56!*-OD;!]#AE./0CUK"IN>E@U[GS/H+X>
M_P#(@^&O^P9;?^BEK:.R.&K\;]3?IF84`%`!0!\F_MMZ]OU7PUX?BDN5\F&2
M^F3.(GWMLC.,\LOER]1P'X/)H`L_LU>`+?3="B\5:G:YU6\W&S,@.8(.@8*0
M,,_)W<Y0K@C<V?(QU=RE[-/1'J8.BE'G>[.&_:Q@F7QYI=PT4@@DTU420J=K
M,LLA8`]"0&4D=MP]:Z,O:]FUYF&.3YT_(^O[^]MM7T73-5T^42V-U$LT,FTK
MO1U#*<$`C(]<&HS&+Y8R+P$ES-&57E'I!0`4`%`'FWQ[_P"1/L_^O]/_`$7)
M77@_C?H3+8?^RI_S-'_;M_[5KUZ74\W&_9/?JU.$*`"@#XS^+NH_VI\2O$-Q
MY7E;+HV^W=NSY0$>>@Z[,X[9QSUKGF[L]>A&U-(^M?!UG/IWA'0[*\C\NZMK
M&"&5,@[76-01D<'D'I6ZV/+J-.3:[FO3("@`H`*`/D/]MO2/)\4^&M9\_=]K
MLI+7R=GW/*?=NW9YSY^,8XV]\\`'L7PV_P"2=^%O^P5:_P#HI:^=K_Q)>K/>
MH_PX^B/%OVO?^93_`.WK_P!HUWY;]KY?J<68?9^?Z'O'PLU&'6_@CX2N[19$
MC@LHK=A*`"6A!A8C!/!9"1[8Z'BML?%NE?LS'!22JV[H\=\%^(-1^%?B:;PG
MX\N))]*U"X>XT_6Y78HS,1N#EB=H+'+?W68DY5MXYJM..(C[2GNMT=-.<J$N
M2IL]F>ZUYQW%?4;ZTTRSDN]1NH+2TCQOFGD$:+D@#+'@<D#\:<8N3LD)M)79
MF^$_%&C^+=.DO_#]Y]KM(Y3"S^4Z8<`$C#`'HP_.KJ4I4W:2)IU(U%>+.0^/
M?_(GV?\`U_I_Z+DK?!_&_0<MA_[*G_,T?]NW_M6O7I=3S<;]D]^K4X0H`*`/
M,M=^#GA._P!=N]<OYK^)99C<W$(N%6$G.Y\DKN`)R3AAC)QCC&<HQ6K.F&(J
M64(H]%T^]M]1LH;NRF6:WE7<CKT(_H>V.U5"<9Q4HNZ9C4IRIR<)JS18JB`H
M`*`"@#PS]KOPC)K_`,.8M7LK?SKW0YC,Q&\L+=QB7"C(."(V)/148Y'((!Q/
M[,/C&TN_"W_",W<T$%_8RM]EC9@K7$;EI#M!;+,IWYP``NWWKR,?1:GSK9GJ
M8*JG'D>Z+/[5_P#R3O3O^PK'_P"BI:67_P`1^G^0\=_#7J>A_LXQ&;]GS0$7
M.[;<D8&<XN93C]*]'$P<Z4DC@P\U"HFS@-7^'NO>.OB'>2^/7C/A;3G9M+BL
MY%3S0Q3Y6X+XVIA\D'<?D.*\V.(A2IKV7Q/?^OZ\ST)4)U:C]I\*V/,?ASX"
MUS6-:\7)X*\37>E:38W#P6]W%,X6^96;R@7CPI&WDL,XW@A3NKKK5X1C'VD;
MM_@<M&C*4I<DK)?B8'B71M7N?A]X9\9>(->O]8L+J[D@:SGN'\R'YF!\MVWC
MYA"<G`P=O#=M(3BJDJ<8V=B)PDZ<:DG=7/L#0-#TSP]IR6&B6,%E:+@[(4QN
M.`-S'JS8`RQR3CDUXLYRF[R=SUX0C!6BCA_CW_R)]G_U_I_Z+DKHP?QOT"6Q
M/^RK/*UOXE@:5S`C6[K&6.U682!B!T!(5<GV'I7KTNIYN-6S/>JU.$*`"@"E
MKEI)?Z+J%G"566XMY(D+'@%E(&?;FLZL'.G**ZHUH35.K&;V33/'/!WB>Z\$
MW]UI>L6LOV;>6DB51YD;X'(YPP(`[XQ@@^OAX;$RPLG3J+0^DQF#AC8*K2>M
MODU_7^3\O:-/O;?4;*&[LIEFMY5W(Z]"/Z'MCM7O0G&<5*+NF?,U*<J<G":L
MT6*H@*`"@`H`^4_C)^S?J-QK-]K7@!;)K:X?>=''[@Q$[0?+9CL()+M@E`HX
M4'@4`>5^,O"OQ4UBPN[WQ7I6LSVGAV+RI);E`%1`2"Z_\]ONY:1=W`!9L8-9
MPI0A?E5KESJ2G;F=['T1^QG<SS_"F]CFFDDCM]6ECA5W)$:^7$VU1V&YF.!W
M8GO6A!Z+<QB*YEC4DJCE1GV-?-U(J,W%=&?04Y.44WU1@>$_"^C^$M.DL/#]
MG]DM))3,R>:[Y<@`G+$GHH_*G4JRJ.\F*G3C35HH/"?A?1_"6G26'A^S^R6D
MDIF9/-=\N0`3EB3T4?E14JRJ.\F%.G&FK11M5F6>>?'2VFG\%1R1)N2WNTDE
M.0-JD,N??EE''K75A&E4^1,MBC^RSJ$4>KZ_IS*_GW$$4ZL`-H6-BK`\YSF5
M<<=C^/KTF>?C5HF?1-;'GA0`4`%`'.^.?#4?B;2!`'6*[A;?!*RY`..5)Z[3
MWQZ`\XQ7+B\,J\+=5L=N!Q;PU3FW3W/'/"'B.\\+:RHG-S]C5V6YM,XYZ$[3
MT8$#T/&,C->'AL1+#SUO;JCZ3&82&*IZ6O;1_P!=/^'/>-%U.WUC2[>_LBQ@
MG7*[EP00<$$>H((KZ*E5C5@IQV9\G6HRHS=.6Z+M:&04`%`!0!5U;3[75M*O
M--U"+SK*\A>">/<5WHZE6&001D$\@YH`^0_V/M<DT'XC:QX7U*/[++J4)7RI
MHG$HN("Q\L_W<(TQ.X=5`R#P0#ZA\01%+\OR5D4$<>G&/T_6O%Q\'&K?N>O@
MIIT[=C,KB.L*`"@"AX@LY-1T'4K*!D66YMI(4+G"@LI`SCMS50?+)-]P9X)\
M(-=/A/XC63Z@[VMO*S6=X'55V!N!NW8VA7"$G@@*?H?=A)7N<>(ASP:ZGV%7
M0>2%`!0`4`%`')>//!]IK^GS3V\*QZJBEXY4`!E('",>,@X`!/3Z9!XL7A(U
MHMI>\>C@,?.A-1D_=_+S7]:GD_@OQ#/X3UR1IX93`W[JY@.588/7!_B4YZ^I
M'&<UXV%Q#P]35:=4?08W"QQ=*R>NZ?\`71GT'#)'-$DL+K)$ZAD=3D,#T(/<
M5]*FFKH^/::=GN.IB"@`H`*`/C/XGRI\)OVGK?Q'%!&]C<NNHM"A:1_+F#1W
M!PQ'SEO.91G:,KVX`!]>ZW;B:Q=@,O'\P^G?]/Y5R8VGSTF^J.K"5.2HET9R
MU>&>P%`!0`4`>+_&WPG#;;-?TZ#8)9-MZJ`XW'[LF`,#)R"<\DKQDDUWX2JW
M[C(DNIV7[//C[[?:1>%-3_X^K6)FLYVDSYL8.?+()SN4'C'&U>@V\^I3ET/-
MQ5&SYT>W5H<04`%`!0`4`>5?&/PY*[C7K81>4B+'<J`%;.<*^?XNH7U&!U'3
MQLSP[?[U?,]_)\6DO82WOI_E^H_X+ZXIBN=&N9U#!O-M48G)!SO`[8&`<#U8
M\\X>5U]'3;]/U%G6&U5:*\G^G]>AZE7L'@A0`4`%`'S[^V9X:?4O`>FZ]`LC
MR:/<E90'4(L,V%+$'DG>L0&/[QR.X`-K]E3QO_PE/PY32KI\ZEH.RU?C[T!!
M\EN%`'"E,9)_=Y/WJ`.YU&W-M>21XPN<K].U?/8BG[.HXGNT*GM(*1YKX[\?
M2Z%JAT[3;>"6>-5:62;<0N03MVC'."ISGOC%=N$P"JPYYO0^MR?A^.+H^WK2
M:3O9*WWWU\U:QRTOQ1UUU`6#3XSN!RL39.#DCECP>GX\8/-=BRRBNK_KY'LQ
MX6P:>KD_FO\`([3PK\0[#6[Q+.Y@:QNI&Q%N<,C],#=@88\\8[=<G%<&(R^=
M*/,G='@9CP[6PM-U82YXK?2S7RUT^?RMJ=;J5A:ZG8365_"D]K,NUXVZ$?T/
M<$<@\UP1DXNZ/G3YW\?>#M3\!ZM93B8"WN6::PN(9?G4*P(R<`AP"AR!C)X/
M!Q[<;\JD^J.:,XS;CV/2_A?\:X(-/BTSQK+.9(OEBU$(9-R`'B4#YBW`&X`Y
MSSC!8[1J=SDK85MW@>YZ1J=GK&F6^H:9<)<V=PN^.5.A'\P0<@@\@@@\UJG<
MXI1<79EN@04`%`$5W;Q7=I-;7"[X)D,<BY(RI&",CVJ914DXO9E0FX24H[IG
MS?JMG=>&O$DL`?%S93!HY,#G&&1L<CD8..?0U\M4A*A5:ZI_\,?:TJD,314N
MDE_PY]&Z==QW^GVUY"&6*XB65`PY`8`C/OS7U,)J<5)=4?%U(.G-P>Z=BQ5$
M!0`4`4-?T;3O$.C7>E:U:1WFGW2;)H9!PPZ_4$$`@C!!`(((H`^#K:77O@/\
M7V:2"25K-W4)(3$FHVC$@-\I(PP`8?>"NHR"5(H`^VM#UK2O'7ABUU70KJ&:
M*54?`D5F@8JK&.3:3M<!AE<\'%<^)H>UA9;G1AZWLI7>QYGX]^'W]M:A+>V4
MZV]^0%E27)20C`!R,[2`.P(.!TY)X\-C707LYK1,^^R;B'ZK25*I&\.C6ZOK
M\]?2WGL<38>!-=LM6CDN]#BU*TBDP\7VM8UF7IPP8,/4'Z9!Y%>A_:%!KXK?
M)GT-;/L'5HM4ZSA)K1\K;3]+-/S_``?4]#O]'N?$D=C:WFD:?H&@PR&XETZS
M96DFFY4%F50`-OISC\-O+6S&,4U3U?<^6HXRG@7.I3JRJU6N53E>RCOHFVV[
M]]/QOVMA;FZNDB&=I.6([#O7F4*3JS43YZM45.#D=3?V5KJ-I):ZA;075K)C
M?#/&'1L'(R#P>0#^%?0GAIM.Z/G'QQ\#=9M=0FN/"WD7UE+*2EKO$<D"DL0N
M7;#*HVC=NR2>G>L94WT/0IXN+5I'F'_$_P#">H?\Q31;V2+_`*:6\C1D_@2N
M5^F1[5&J.GW9KN?8O@&YUF\\'Z7<>)H/(U=XLSH4"'J=I*CHQ7:2.,$D8'0=
M$;VU/)JJ*FU'8WZ9F%`!0!Y5\<-/_P"09J21?WH)9-W_``)!C/\`O\@?7M7C
M9K3^&=O+_+]3W\DJ_%3;\_\`/]#K?AG>M>^"M.:29998E:%L8R@5B%4@=#MV
M_H>]=N`GS4(W>W]?D>?F=/DQ,K*R>OW_`/!.HKL.`*`"@`H`XOXK?#K2/B/X
M<;3=57R;N++V=\BYDMG/<?WE.!N7."`.A"D`'Q[X<USQ9^S[\0KZTO;&.5I$
M5+BWDD?R;N'>"LL3#`S@,%<@[=S@KG(H`]VT']HGP/XBTQI/$7VKP]J,0^XT
M3W*/DMPCQKD\`$[E7!;C.":YL3AXU5?JCHP]>5)^10UCX]^"+#R?LL]_J>_.
M[[):E?+QC&?-*=<]L]#G'&?-C@:KWT/0EC:2VU/-?$/[1VLW=L(M"T:TTUV1
MU>6:4W#`D?*R<*`1R?F#`\<<<]<,OBG[SN<L\?)KW58[']F+XN:]KWCJ;0/%
M6I174=[;,]H3:JC^<GS%08U`P4\PG=_<&""<'LIT84U:"L<M2K.H[R9]45H9
MA0`4`%`!0`4`%`'G7QMN(ET"PMF;$\EUYBK@\JJL"<_5E_.O+S62]FH];GM9
M)!NK*71+]?\`@$OP4_Y%6Z_Z_6_]`2JRK^"_\7Z(G.OXZ_P_JST"O2/'"@`H
M`*`"@#Y]_;4MH&^&^C730QFYCU9(TE*#>JM%*64'J`2BDCOM'H*`/-?@;\%O
M#OQ*^'MYJEU>ZM8:M!<RV@>.6-X2P165_+*!L#S`"N_G:>1G``+/_#-'_4V?
M^4W_`.VUYG]I?W?Q_P"`>C_9_P#>_#_@GH.E?!3P5IVE7-HNGR7$\]O)`U[<
MN))5#?Q*"-BNO&&"@C'N<\LL95D[W.B.$I)6L?+VGWFN?"[XB"X@$<>LZ/<,
MN)(RT<@P5/#`$HZ,<'@X8$$'!KVX34XJ2ZGD3@X2<6?H)X!\3VOC+P=I/B"Q
M79%?0AVCR3Y3@E73)`SM<,N<`'&1P:HDWZ`"@`H`*`"@"KJ>HV>EVC7.H7,5
MO`/XG;&3@G`'<X!X'-14J1IKFD[(TI4IU9<L%=GSYX@U:]\7>(DE,2B:9E@M
MX5(`4$_*N3C)R>I]>PX'S-:K/$U;]]$?88>A#"4;7T6K9[KX0TF30_#EEITT
MJRRPJV]E&!EF+$#V&<9[X[5]%AJ3I4E!]#Y3%UU7K2J)63-BMSF"@`H`*`"@
M#P+]M+_DENE_]AF+_P!$S4`6OV.["YL/A'/<W<8C@O=2FN('+`[XPD<9;@\?
M-&XYQTST(-)M)78TFW9'=U\R?0A0!X[\??A'=^+--;Q-X8LXY-6LU(NK>-3Y
MM[&`,%<'YG0#IC+`X!)55/KY>Y.+OL>7CU'F5MSQGX'_`!:U'X:ZR4D$EYX=
MNG!O+('E3T\V//`<`#C@,!@XPK+Z!PGVYX#\;:#XYT:/4?#M_'.I16FMRP$U
ML3D;9$SE3E6'H<9!(YH`Z2@`H`*`.:\7>,=.\-8BN!+->NF^.!%QD'(!+'@#
M*X[GVKDQ.,A0T>K['=A,!4Q.L=%?<\4U?5]8\6:E']H\VZG^80V\$>0@ZD*H
M]N_)P!D\5X-2K5Q$M=7V/IZ-"CA8/ET75L]8^'G@F/08EOM159-5=>!U%N#V
M'JWJ?P'&2?9P6"5%<\_B_(^?S',77?)#X?S_`*_KR[BO0/*"@`H`*`"@`H`^
M4_VB_#WC7XC?%FPT#2="O5T>P18K>^EA86I:15>65I=F```JE<MS'P-S;:`/
MH#2M$C\(^`]'T*R:/R[*".W>2*(1"4A?G?:,X+-ECR>2<DUQ8^3C2TZLZ\%%
M2J:]$4Z\4]<*`.KTBU>TM-DA&]FW$#MTX_2O>PE%TJ=I;GBXFJJD[K8\/^-7
M[/5KXQU6;7?"MU;:7J\_S7-O,A$%RY89D)7)1L;B<*P8XX!+,>DYSP'2_!GQ
M9^&WB.*]T;0M;M=2,)'FV-N+R-D;(*ML#H>5SM;D$*<=#0!]F?"OQ/JOBOPE
M#?>(-!O="U:-S#<VUU`T0=@`?,C#?-L.>,]"",G&2`=?0!YO\0_'S:;*VFZ%
M(IO4;]_<8#"(C^$`\%O7TZ=>GE8W'\CY*>_5GMY=EGM%[2LM.B[^?]?EOYUH
M>C:MXNU240NTTP7=-<W+DA1C`W-R<G&`.>GH#CRZ5&KB9Z:^;/9KXBCA(*^B
MZ)'MOA/PIIWAN`?94\R\9`LMR_WGYSP/X1GL/09SC-?08?"PH+W=^Y\OB\;4
MQ+][:^B.@KI.,*`"@`H`*`"@`H`*`!@&4JP!4C!![TFDU9C3:=T5)=-LY&!:
M!0<8^7*_RK"6%HR=W$VCB:L592)+:T@ML^3&%)ZGJ?SJZ=&G3^%$5*TZGQ,G
MK4S"@`H`*`(KNXBM+2:YN&V00H9)&P3A0,DX'M4RDHIR>R*A!SDHQW;/F35K
MS^T-5O;W9Y?VF9Y=F<[=S$XSWZU\G4GSS<N[/N:5/V=.,.R2/HCPEHL>@:!:
MV"A3*J[IG7^.0_>.<#([#/.`*^GPU%4::@?&XO$.O5<^G3T_K\38K<Y@H`*`
M"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@"OJ-I'?Z?<V<Q98KB)HG*GD!@0<>_-
M3."G%Q?5%TYNG-36Z=SC].^&FCV&H6UY#<Z@TMO*LJ!I$P2I!&?EZ<5PPRVE
M"2DF]'_70]*IF]:I!P:5FK=?\SN*]`\H*`"@`H`*`"@`H`*`"@`H`*`"@`H`
M*`"@`H`*`"@`H`*`"@`H`*`/_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]F<F%N8RYJ<&<`````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$R-C<T`#$P-#$W,S8S,#$Q`#`R,C<T,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/K+_@Y@TCQ?K7[</_!,\?#B
M3X;S_$/0/A1^UMXB\+:!\4)M4M=!\53VVH?!BWU;P]8WFD3)?V>O7GA:7Q'=
MZ?>PV>L16,>GW5WJ&EOI\5S<VWY!_LQ?M<?#CQ;^T%\#/C7^W%X%\;_L^?L^
M?`+QIKW_``A7C?1M)U3XT?L_?$O]L*UU+0_!MA%J_P`5_AQX,U71K71?A#IW
MB34M=\+75KKUWX=NO&\E[J<OB"]B\-G3M3_4K]HW_@C=X%^)7C32/C%\&/VD
M_P!I#X:_&'P#H^M:?\+)_BQ\1M9_:I^&WAI_$'AW4O#_`(EBG\)?M$7/Q$\1
M-8^,K>^$?B"T3QM/80Q1QM9Z9)/;PO7Z<^"_@+X'TC]GOQ!^S1\*;/PUX'\&
MS?##QG\-M'L_#NE+!X:\.7VN:;JFGW^HCP]I=Q';B>'6M7U#5;JRFNX634KJ
M>1K@WI3S?Y2XT\1.%<[JT\?A<)7Q,\7@HY94JU(SRW.,FPM=5X9@XXE4LPP%
M6%:EB(1P\/8XZ5.JL?5IRPM186K6_H_ASPTXFR>EB(YC6H86.`FLPPM.$J6/
MP&:8J,Z3P])T%6P6,IU*52DIUJLJV%BE'"4YQQ%*=:-'\5/@;^S)K?\`P7AL
M_B+^VM^WE^U;\2?V5_\`@F9J'QLL?V<_V5O@3\/O$VG_``ZD^,%[_P`)M;^$
M/!7BSQU<^*+3Q=X'37=;^*.N>%M"TV[U;2?&6KZK\1;;Q'X/T-_"&A^'?#EY
MK/-_\%-?^#?_`."O_!)KX':U^W%^SE8:O^UY\%OA!I=S!\5_V5OVOM4UCQ3H
MT.M?$);GX<^'_CSX4OO@SH_P\TG4[WX?ZWXE\(OXA\)^-/"S:?\`\(/;^+=<
ML?&^A^([3PU>:'];?L+_`+:'[$O[/W[*?P=_X)H_\%G/A?>?`/Q5^PS\74U[
MX"_$SXF>$?BW+\!/CUK?P1^(&IZ[X%^,_P`'?B#H_AZS^UZGHEUXC9;OPYJ?
MF:'JV@7T'GK>VNM:UX1T32_X*]_\%R_@#^V?\)]1_P"":O\`P3<T/QO^V1\6
MOVJ7TOP;XXUOX=>$[S3O"NC?!F8G6/B,O@WQ/XO;2%?Q_+I6G-I]IKNH^&-3
M^'O@RS3Q'KGBK58+G1+73;S^B,MP/#F#X<H8?+EA:'#\<%>%;"XGV%%X>-&]
M7$RQN'G1Y*KIPE.MC/:PJW4YU*J=V?A>.Q><8C.:U;&>VJ9K+%/GIUZ/MJBJ
MRJKDH+#5HU>:"G*,:6&Y)QLXQC!W2?W%_P`$W_\`@D1_P1Z^`_AGXM_\$^KW
MP5\(/VN_VJOA3X,^%OBC]L;Q=\5/APNM^)[F\^,.EW7B7P6_AVYU[3[S2O!'
M@^?3M)^U>%_"?@#7[C4="T*71[_QEJFJ>)O$-YKFLVOV0M!^%G_!)S_@IM^T
M]^Q'X&-O\#/^">/Q$_8XLO\`@H3X=NOBGX[L+3X8?!KXO^'?B[X0^`?QCL_"
M7COQO/%J6D>#/%6C^)OACJ.L:1XQ\8ZM8^&M;T6S_P"$??3+'Q`]@N-X&_X+
MV_\`!+7X=?M#?&"?]HSX+?%C]AO]L1O`/PWT/XQK\4/A+I7BGQ=XXT?0/!5W
MXV\#^&)?'?P%USXIQ>+KG3%\17F@^!;3Q?\`V!XOUJ76-%TNTT2UFF;1M'_G
MQ_;J\;_!_P#;X_X*%?%+XQ?M;?L&?M1>(O&7QQ^#C?`C_@DW^S'J>@>,?A?X
MM^+>H_"/7[K3[GQ?\;=/\-_$#PS\2?`&I^*_B'XQU?Q)IMSXHTGPUX#\'?`^
MQ\5:KKJ^)=>TGPSJVL]>-SG!X'#8>O&^85L=*G]1PN6>QKXG,7*-.3E@XSKT
MZ=>%'#3^LUJKK1A#!TZF(<HPC9<V&RZOBJU6DW'"T\-&3Q-;'2G2HX51YDE7
M<:<ITY5:R]C3A&G*4J\X4K-R;/[G_P#AXQ_P3W_Z/N_8U_\`$G_@E_\`-Q17
M^>9HO_!GO_P5,U+1])U'4?%7[,/A[4+_`$VQO;[0-2^)?B*[U'0[RZM8I[K1
M[^ZT7P-JFCW-[ID\CV5U<:3J>HZ9-/!))87UW:M%<2%>OS/O_P"4Y_Y^OX=M
M?/Y?3_P.*[?=O\ODS]:OB=\"/V_/^"7O_!0S]B+]DC1_V[[C]HW]E#]IIOB%
M<>#M,_:0\#0ZG\1=!T#X3KX=\1?$7P1J/Q,T71+_`,0:OXR'@NYE;X6:Q<>*
M--\)_;?,T74_!V@6<=C/J'Z7_#_]GGQMX/\`&7Q_NO!_QAA^'VD_''XQ>`_B
MYHMWX5\#G4/%OA?6[&R\&:3\4M+UJ_\`'GBCQOX.UZS^*FA^";#PG;R^&?`7
M@#_A#=)U+4=8MXM5\;RMXP/W_P#\%?/V//BK^T[\!?`/Q'_9H69_VM_V1/BM
MH'[0'[/VE+XH_P"$2L/B#/I\<WAWXH_!C7=7N)5TJVT;XN_"_5O$GA5Y=41+
M-]4?2K'4K^Q\/W^O&;\Z_@%^T3X(_;>_9UE^('P=\5^*OASJ'B72_$/A35"+
M'0H_B=\$OB-IS7VA:QINJZ#XBT[Q!X>_X2CP7XAM9Y;2+6M'UOPMKRV=O>&T
MUC0;[9<?RSXQY'5R;,\)C\LP6#P.49A0IX7'5J6`P<J,L9#'?7H5\;2IX62J
M<[4(1E6IUJV(CA<13JNK&O*-7^F?"/-</GN48_*<SQN,QN<X.6)Q.64:V/Q2
MJ/!ULN^H5,-A)UL2HPC3NYRIP=*G0EB*%>BX3P_/AOKCX[?%']F'P-X1N;;]
MIKXB_`CP=X'U"_TG2KNV^.GBWP!X;\*:AJ\JS:QHFGW4'C^^M]$N]2E.DW&J
MZ3;2?Z5,FBW5_;Q>9:O/'^*7Q!\2_P#!$[]HSXP1?$7X<_M\VO[('Q?^&G@'
M4_@[-\1?V??VA;?]DBP\3?#"[\7:WXC/@K0M5\:Z%8_"KQWX;B\;:EJ7C8ZQ
M\-;2YNM4U*XTC6M2UO4M'3P_O^X_V:?^"=W['?P%U+6?%]]\-;;XO?&?QAI\
M$7Q%^/7Q\O;_`.+_`,3O'U_%,EUJ.J:CJGCB\UC2?#DFMW;27VJ:1X`T;P?H
MMRUC81?V9>W$%@D'WGXM^$'P8^)>@VF@>./A=\-_'?ANUT*^\,Z?I7BGPAX=
M\0:58>'+NU73[C0=+BNM/GCL]+ELX$LWLK/[/9^6JQ"WC6(-7X_@\PR7(J[C
MA,;Q153C4ISQN%JX'+:$O:4HPKI996IYE'%T:CYZ<5B,7A9NG&E7G3A47L*?
MUN893G.,2AC\!DM*2<*L,-7ABL;52ISYJ7+CZ4\#&E.'*I2>'H5H1FZE"-64
M?WD_'/V1OV6OV8/V;O`1NOV9?#^B3:?\3+/1_%'B#XLQ>)[SXC>-OC0]W'=7
MVE^,?%WQ8UC4-=UWXA+?1ZU?ZCHTS:Y<Z'86NMS1^%[/3=&D%E'X;_P4A^%_
MQ(C\*_"G]L_]G;3+C4/VH?V"/&E[\=?AAID.I7EM#X]^'SV-K#^T-\&IM&M=
M'\16^N3?%WX5:9>>&]+TV'3[76H?$J:/_8?B/06DNH[W[L^&WPR^'?P;\&:/
M\._A/X)\,?#WX?\`AW^T!H?@SP9I%MHGAC1H[_4+O4KJ+3=%LX[>WT^"YU+4
M;N[VVZ1Q1O>,+9(FC\I?S"^*1^)'_!77QS=_L3?LM0^(-)_8STWQ@FC?MS_M
ML6UEJ6G^!O$7@SPOJ;0^.OV5?V==<OO#YTCXC_$?QM>>3HOBOQWX3\07FB?#
M+1;35(?$-IJB:[I.FZGZG`.%XCS[CW`X_(JV,Q6)PF8T\;B<TQ\GST<MC45&
MK/,)JK.+=;!2GAGA*=:;K*4Z%'FIJ4H^/Q9B,ERGA/%87-J6'H4<5@ZF'HY?
M@XI*IC90C5C'"Q<(\OLL7&%?VU2"=.ZK5'[5KF_7[X:_\%??V-/BC\.?`'Q,
MT.;]H&RT3XB^"O"OCK1[.^_95_:)U"^M-+\7:%8>(-/MKR_\*_#?Q)X7O;J"
MTU"&*XN_#?B+7]!N9D>;1]:U73WM[Z<K[6^&G[.OP4^$GPX^'_PI\$?#;PCI
M_@SX9>"?"GP]\(V%QX?TB]N++PQX+T*P\-Z!:3WD]DT]W-;:5IMI#+<S,99W
M1I9"7<FBO[P]G+_G_6^ZAY?]./7[_(_E+G7_`#[I_?5\O^GOD_O\C^93P/\`
M\%\/V]?@[=WDG[8W[#7PJ^)G@S3-;:ZUWQK^QQ\0O%.E>,-+\$1^%GNKJ_\`
M#WP3^+\.LR^/]1TSQ+I]]%=/!\5_"DVH:;?V=GX?T#5[W3FO-8_*/_@I5\<M
M=^/?_!5W]GWQY_P0C3P)J?B/XE_L[>%?C)^TK\5/AC9:UI?PU^(6L_$_Q#XR
MU;3Q^U[IUS';^!I+[PEX-2SNBWB70X?BEHWB_P`7:AX1N)?^%B>'_#^@Z#_1
M7XM_8KTC5?!@\1P"%[IK.'4VLI@;G9OFF"RQ1-!=V\NZTN%OKF]N6AE%OFW>
M*P,4]Q+^`/PX^('A;_@E+_P43^+'AZ[^`/Q%\<?`[]L+X8>%OC)XI\2?"/X?
M:SXOU/X0>)?A'J_B+PWXPUD>'?#WS>)_!5Q)XTT;Q+\1+BRTY_$.DW_B;0KR
MWTS7GU>/^T/F^,5C8\-YI4RW*:&?8^&&DL-E>+IQK4,5S\D*RJ49RBL4H475
MQ$<*W_M-6G2I4VJG(W[_``K/!_V]ERQV98K*,&\0G7S#!5'1Q.'<$YT71K)?
M[/SUHTZ4L3::P].=2M*,XQE$].^-7[37_!87]A+X'GX^_M-^`_V(_BU\)O`5
MEH>M_%'5O"?B7XE^`_'EQ<^*?%</AFR^''A]#I5_H4/B6VUG5M,TBQ\0Q>#]
M8T7[*GVK5;>1R]]-]"?M2?\`!6?XO?L;_L[_`/#1'CG]A#X@VWA36-8\.:1X
M6U'Q7^U#^QZGA7Q9XA\3S"272]&U/X4_&?XT^./$6IP:+8ZIKDECX;^&VNWU
ME::6VHZX?#F@MJFIQ_`7_!;7_@IU^QO^T)^RO\`/AW\$/CKX<\;:'XJ_:L\-
MZA\9?!\D?CGPM?Z=\-?A#IWBB36O#WQ:^$.HZ+HWQ+AT.\\?77@W5-$T?Q/X
M&&CZYJ7A*&_TX22:?::E8_+_`/P2.^`&@_M"?!_]H7X:?%GP5I7QA_8M?XKV
MNI_L_P!EXYLO$<5AI/B+4]$UF?QS-\,K?6K#2/&/@^SM(]=TS3XO%F@3:5<+
MJ<GB>ZT][F9O%MQ-^0\$>'63\4Y)'->+>&89;F3S+'TU@<+3Q^21>&HU*4(T
M\7@HUXRH26(AB:?[FGAVJ+I1BDXJ;_3>+_$+.<HS&>4Y!Q#6S#+%@L&_K6,E
M@,XJ*NX2E*KA<=+#RG)NDZ,I<]:LY5E6<IN,E&/W+X0_;J^`W[8EKXEU7]OO
M_@I'(G[.5YK&JZ]:?L3_`+`7[+7[:-[KGQ5T*#7-,O-/^"_Q-_:[D^!_A'4=
M4TYAIE[X0UO3/AC<^`I?'7_"1W'B'5?'G@;1X1H-C^YGP1_X+C?\$QO@)X)^
M&OP7TGX$?M?_`+(/P/\`"_AV[\.?#J;QM^P]\;/#?PUTNP\,VIN9-#TI/!GA
M[QIX@U/5KJ65YKNXM]$U2^U'6;V;4->OVO\`4)[R?\@_V>O'?B#]D']H;P7_
M`,$]OB9K,GB?X8^,?`&N>*OV-_BCJSI;>(K[1?!,L'_"2?L[>*TMH+F+5O$O
MP\\/.^N>'/&MW_9\>K^$(;#3M2^V^)&BBF_9WP3X<M=3>#SA;R,KIN=C$D9D
M^TND4?VV18K:WC23<9KJ2=255C%,;>)9K?\`<LHR3*<APBP63Y=@\NPZ:E*G
MA*$:2G/EC%U*KC:=:M*$8QE6K2G4DHPYI244?C^89GF&:UWB<RQF)QE9JRGB
M*KFX1NVH03]RG3C*3<:=.,(1NU%*]ST.Y_X..?\`@B[8W%Q9:C^VUHFDZA9S
M2VM_I>L?!?\`:0T?5]-O;>1H;K3]5TG4_@[::EI>HV<Z26]]IVH6MM?65S'+
M;7=O#/%)&I7;77[+7A^XNKF=O#W@F[:>XFF:ZN[.075R9)&<W%R#87!^T3%O
M,FS/.?,9LS2_?8KT]7LU;I[KVTZW\_ZLS@NO/^K>7]?)GU-XC`_X1'Q(V!N&
MEW8#8&0&TW4"P!Z@$JI(Z$J">@K^57]M75M4T[_@KI_P2]L]/U+4+"TU[PO^
MV[I.N6MG>7-K;:UI</PJMM<ATW5H()$BU'3XM;T71]8CL[Q9K9-5TG3=06,7
M=A:S1%%33^W_`(H_^FJ8_L4_\'_MTC[C\>^"/!>M:;J%AK/A#POJUCJFDWMK
MJ5GJ>@:3?VNHVTUYI]K+;WUO=6DL-W!+;:CJ%M)%<))&\%]>0LICNIU?N?#N
MFZ=IFBZ1;:;I]EI]M!IMI'!;V-K!:00QM;6X:.**"...-&$,0*HJJ1%&"/D7
M!13?\2/^"I_Z53&O@E_BC^4S\J_^"L[OI4'_``3U\3:6[:;XDL/^"E/[..@V
M/B"P8V>MV>A^*-*^(-KXFT:TU:W,=_;Z5XBMK*SM]=TZ&X2SU>"TMHM0AN(X
M(E3]Y?AE'&WBSP[;-&C6TVO-;S6[*I@EMVU*8-!)$08Y(2%4&)E*$`97@445
MIT7J_P`HDGWKX?FEFT'1)II9)99=(TV2661V>221[.%GDD=B6=W8EG=B69B2
M222:***R73Y?^XS-=/E_[C/_V0``````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]F<F5D9FQI;G-T;VYE+F=I9@``````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S0P`#$P
M-#$W,S8S,#$Q`#`R-#0V,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_
M`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF
M`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__
M,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F
M,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_
M,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F
M9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_
M9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!F
MF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_
MF9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]F
MF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_
MS&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QF
MS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#_
M_S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF
M_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____
M^+\D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(?D$`0``V``L`````"``
M(```"/X`L0D<.)`$$@``"")<N)"@PX?8#@)`@HVAQ8D0(5[<>#'C0(X@+7H,
M2;*AQI`K2)$"H(+4*E(J`.1!2.(D1U+/<J9<E7-ES)$3-_+,^8S4BI1'`=7T
M6#$HPZ$Z`[%:(74%4X$&$>J)N8+HLU4D5DP5N_1JQ16EC.(DNFJ%E:EORUXE
ML=;K,SU&64TMM8*$7[,MG]@MBO<HJ2>E5KV4^Y`$H"=UV2:&RI:Q0P`[[1H]
M.OBK98(M.?<TK'8PJ<]8<:KL"=EE4<B*%<-D2H+R896BC9)0H>(H18^UO:;4
M7==H'E)I5="&VO9V2J^W>RK/&#QG6YY@6T*'G%/IPX5UV[X278%PIVS!STHQ
M!@`!PH'G7[OVM.@7/MC+$"Q8<(^V^?B+KGGF$!(E'`#!!1=`,)Q\1:G`!AL+
MB::>0R1TTLD*!UY@P0$'`%!<7V'AUET`"15DX248(IC@>Y$I9E=;"4!08H6=
M\#;'"@:JR%]D=@%BH(Q8U:C2$Y=<F"&"_)4R&"`KQ!B`B2KP=)B%`>2(I()U
ME<+D`!`\">504ZIP8X8</L`BC@%PV2%!%49)E%HJ7%*E!2O*^*.!!URR5$``
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V=A<F9I96QD+F=I9@``````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(S,#0`,3`T,3<S-C,P,3$`,#(S,S<V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y82``
M(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``
M9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`
MS,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S
M,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DS
MF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F
M`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF
M9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F
M_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9
M,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9
MS#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,
M`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,
MF3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,
M_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_
M9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_
MS,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````A^00!``#8`"P`````(``@```(_@"Q"1PH$(!!$@03DC`((*'#
M@0P!S$'HD$2>B`\=1B0Q46$>%1@S$C0X<>(EBM@LJBAI4.1(`"0NJ8B)DD0G
M$BI.MG0ID*.*3IU.3D3",2;0E2AYVNPTDT31B4Y_WN1),*83H$"=S+F*U<E)
MJCU/7L(:U"A6L4D?PLQS<\4*IVX!N(7[%NC"C`N7KF#%RBW?O7T!PSSIM");
MICA97;OVEP3@Q:Q`2OU:-:L?%:BJ\.V;Z5,FP*RJH%+AY^I=B#`Q4T'%6H5K
M%2L^K7B-F?7JG*>Q#<8L;32JWJQ1.0G^VW=OJ36/_G9-W#73VJU5'+<[<&FG
MX=&=!]O^G#EKKKD/HF;='@PH^?/FMX/?61"`BO/PXZ/?GKM])_GXS_\,1KGR
MS:5.Y,=5)X.E5=U"!NV''V(,&4@0$@==DM]V.@&`A$A.$356@!-J=5!:3ME$
MF((35CA6B"F51=A8[TT8S$\K&N4484Z99).+N$$U(T).884@"2Z6EY>/%-W(
M'4SW!7E3DD*&Y9571@;YXB5/4@9320N1I>6696'94'L1A2GFF"$%!``[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O9V]P:&5R+F=I9@``````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,T-``Q
M,#0Q-S,V,S`Q,0`P,C,Q,3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```
M_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"9
M9@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#_
M_S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F
M9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,
M_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S
M9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9
M_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`
M9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF
M_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_
M9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS
M_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,
M9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`
M__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^9
M9O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/__
M__B_)```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"'Y!`$``-@`+``````@
M`"````C^`+$)'$BP(```2$@47,BPH4`D!Y$XG-B0!(F#%BEJQ$9"11X]@$#J
M4:%PX\*.>O(X40%HA1-`(4F:'$A"3\H2`*J0J@*`Q,N0)2EBS)-GQ0H``9Q4
MN0A`A4=2>H(Z/(AT12!6@:P$`&"5%2LK'O-097B1!-&+@:Q=L_85P-5KU]I2
M!7#R+"!215G!A6;%RHJOT-8&ZID2(T&S5520POL7;MQ`?P/'M6)VL8HJ40]7
M7FQ5+=:C:06OR+,8+\O,#UF6+GK5JA6N5R&3+DW*HQZZ`FO2WND4@%^J3IWL
MAGH9]V;:*IPXF7O0B<KA>(.2&/Z<U'*JPJW/I@VHY/'5M%7".J<]?K?WN^&A
M#[=8?K%WZNIWMU_</3?Z^-")4O>^'7_X_JM)!U]^\Y56'TVSM717?X#D81&`
M`19D5DNL/+&@<BM=E-U^9%7Q5X5Z+$9:2M7MYJ!#:,5EH8@8[M9@1A/!%M<*
M]^VFQU$':5257I"%2-N-*[QV%$4DK!``"U8M599%L'FU`@L!3$0""U!268(3
MHSCA4Q5:6N$DE2Q(=1B850:05):CY)$E"0$\2::8')%9)90&F(FEFDX<2:6>
M80X4$```.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G<F5E;FAE860N9VEF````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`T-C(R`#$P-#$W,S8S,#$Q`#`R,S4U,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6%!
M`$T`]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8`
M`&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9
M`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`
M,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9
M,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``
M9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:9
M9F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`
M9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9
MF3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`
MF<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9
MS`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`
MS)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9
MS/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`
M_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9
M_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(?D$`0``V``L`````$$`30``"/X`L0D<2+"@P8/85@!8"`"A
MPX<0(R)4R'#A"HD8,:ZX^)#ABD"MKEUC=<V*PHPH#U+DB'!A()(B6<$,U#"E
M32L5`5`TJ)"%R&N!6*Q@<67D"BLV,ZX\))-5()HU!P*P$E/&`P0L'CR0(8@5
MRZ007<JT(H/JM9U29R+@RDJ052NLHH(]R,*B("L/+NBU\"`0T(U2?\J`\',D
M@K4YYQ9DZ#?O!0@6]#X0:3(M90A-`V'+R7#@1HLV&8J,+"-'%P06+,1D"<!O
M200;5ZA0`<!`C"U;:"^,L;GB5X@4S2*2$5(P9I&<=2X,PSS,(D:,#!G2O4(Z
MHUC88QU2B-;A0BX_`_[)*%S2`B+D#`W`J`VCN?/GTL7DKF(HN_U8T@W%T/E0
M(<QKI[DFD@P7P,20#3PDZ!YSBSP'771;0'??A+$`XI%*`!36Q04RP,1*7C^Q
M0)L-8)2X8!B,./@@([#`0N&$AG"Q'W\$*43>!7R])$-D/UD1@WH\F.A>@RNN
MB)]T+]['16>>`?`?4`^D)N5X(E41!@PD"MD<D884R2(7LZG`19+9/;%0C0!0
M65@@*R#P`"+%78-?D%INZ25T+HH!B'Y<K,#%*MC59Q\@NA&$TPI/BH0(4N3%
MP@B==3H'79<KNHC=(3K1%D.?*JP00WX4R87-H8F2]],AAH11(A@GHNBEB_[2
M'1(#))"L``A@33)ID$NFFLI*=%E&JB(C8N`)BRHJ[$<++4APEY)%O9(7"+'!
MLCHD=&'$L((8TGER"1LD`+`L)!XAI9%=T:ZDPJK6+MCI?TY9@1,))+#!!BVT
M0H+$F>?J1%Z\Z2$8:1A;:"N@M$[)AJ^]2)`06G(<I3>P:-&:2A&XOTD4ZH4"
MA;JJ>^LM5+&I.`&`!!M(@!7;028!4*<!OI7::UT)(>&)8@\9\/&5R25Z%WG\
MRH"S0SCMG!RZ(PGR+XU#.Z10NV$<S1`+\IJZ&6]->^>RJCPG9\@6-6W,$-99
MMP2`>[IQ)@9MN7*6<=F]N0=S3@:`+6JN>CQAYOYG=^.\7'-S5[2%(?P65+(>
MR21NIF]E+V0#X)QM(<94!RVD1RF))U-*N!69VS1.!C`7^!-ZY`W:8@"4KD+F
MB9-0BB>Z-OUWVI@GKD?AGCVA>>FLJX!Y[$,O=$,8NB'.NB=F%G1Y,GIPE[GQ
MP`<?^GK&LZYXV``D7@I_&UF_.-P"G;V?)\FL1+[M%.E>RA,$`?!$[<F<_C98
M`&S!`P"EW+X0;=8OWSP+X:O($U:2D-,-;07M21U#5%`%]UDO<1P16T6D8D"<
MR89XBUN(W:JG/0INI&6@V1@`Y\*TLX5A8XS8@D)<Q[R3;*144#&9OOHF$7.5
M3"JBJXAT"N@^CP`@!O[1D@$`[D4+W#E-5-B+2NBB5A%N(46$GI+92*H`B66%
M:WX%"57'&/*8,]4O#(';GR%P54"9C(P555P6LXQHD$-QSPH'0(!>#L"0+1"/
M,]+I5``!(2^9L<(*:AS7OK`8/D2Q:2%YR<L.=$#'"*60,RHPA*Q4(,7"W(MS
M1"07#9M$$C:AY@)NV@$HS_:@Y'PJ!F;IE8<N<8F*(`%?;-S5"D02B,A<X"H[
MV`$"0N>@M'$F3KT"B154`0B']:9AL90E*PAT@5SJX#!?#$.J4NC+A0!B9"*I
M3O+:%ST,(4`'S<SE#NBX1!480`7<(EQ.*AF3&!FQ9>?ZI@[$&809>(IX=/X$
M``-CM#%LEB06S@(+3A!P`*T$X:!!*(-"O9`#&<S`"S/87PP.L:0,1>L05HC%
M*DZB&(5$]`!<(`-"%:K01)`A$2:E2"17T:=2R80+];'0)C.B$P^)E*0E16DB
M^-80A4P458*RSW:2^2S7!,(D,L"I3DUJA:/RZSLODE4W4V*25LAD!0>0`0N\
M4`:4=M6D0F0<10`UH5`14B."8`A)N_#"LW1A48B(GEDEV+38J+6K73B`658@
M`T2,)992.RM-^6.1+B@T!ZX!0!=,@BBG,*UM4TV*0LRUD`3!0`:+E0D`\FD1
M>(+OB+E*$'4T2Z.2<>RSAN,FB>X7/J?>38NH[76("H+$VLUXUB$CC&WEVA,&
M'JB@D(_5+4H`P%OF!'"FPNU(<4_8&^0FMR7M:5#4FOO<T*A`4L3J5'"K&Y$?
M2G-2=A,L=YM$J15%=KRH*^^#NH->V1:I2^X4+W=W8RRA$K6]):O"=2:TBO..
MER(QV.^$_`NW@```.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G<F5M;&EN
M+FIP9P```````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-C,T`#$P-#$W,S8S,#$Q
M`#`R,S(W-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#
M$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#
M`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S
M8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H
M:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#
M`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!
M`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q
M%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X
M>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(
MR<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/YW
M/B9^RGJW@GPKJ7B71M877XM)O;ZYO;46S07<'AI%5K2^8F7R)+FQS-)KC*(K
M:.Q1+RW6,6MVEQ\F-:7,+E9[6:'$US:N9X9XUCN+55^UQN`H<362RQRW$6&>
M$-&9HRKA6ZZV^(GBRS1TM-9U6V#7NHWJ>5KOB)5C?4[5K6YB,/\`;!M[F-T\
MHRR7L-U=7JVT%KJ5Q>V"O:/[M\.O@CXK\<MIE])HT]GX8U#Q/H>K2^+]-O\`
M1;...QTZUO+;Q!8V.B2W4D5^\>IO#!H>JVVFOHEFMKJLVEV=QIVH1:?7]48J
MAA^*\ZPN$X,X:S#+JE?#MULL>(Q&<TJ<J=2%%XU8RC0G7PN&=3$86E6EB</]
M6H2E[>IB*-&51TOU_'9%PQXM<5Y?@O!W@7B#A^O+#THYCD'M,5Q)@H1ISIP>
M:+'TZ+J9=AY3J1PF(GF;I8"->>%KU<=A88BO'#]O\/OV>='^(_@I==_L*7P/
MJ3QA+"Y?59/$.A>*(]WG&Z;3YU75-%LQ/;6RP7&D>);F:6VN;V(WERI:)?EO
MXA?#;Q!\-=5.C>(5B6\3;\\61:WD4AD,%_I$TFQM2TN=8W0W(B@NK*\BFL]4
ML+"4V9O/TJM?&FF>$-&CTGX?>%Y!HMN))+OQIX^U*[\%^%FO95A$E_J'B'Q#
M9S:SXBOV;S/MGV6PFD"V$MI'<0QVR);^=_&2RA^(GPKU+Q/JC>$7UO1-8M--
M\+ZGX<;4]0;5QJDEEI]QX<9=8TBQEBN;RZOP]M)$NH6UI<V]KJ>^REL[B:#]
M'X@X+X:K\-4)93C:4N+\HRBIF.:UL'3G#),\PN7T?:X^6%JK!8#`588>%:*P
M>99;1?UET883'UL=C)>UC_3GB;X"^'>8>'__`!BT\/0\1^%.'7FN9YAEV&6"
MR#B.AEF#GB,TA&6&RW+,DQ,HT,/5A@LRRG"T:=3&4Z6'S2O5QN-E5G^;)!`4
MG'S#(PRDXW%?F`)*G*GY6`;;AL;64GI?"^EB_P!1BN)KLV-EITB7U_<QR3V]
MW!8V[!I[C3ITADB_M%)VL[/386;S9]7U'2X4@EBDG>'N-/\`A9KVMZ[HWA;0
MX=3\023:8NN3BP0C3_\`3KD6PEM;UEET^PT^:*"SCF\1W\@L)_(E:Q&I206%
MC?\`0_&32/\`A7<]GX`M)K>6:QL[-_$-U:VD<FG7^K7=C->G3K<W@>YL[/P[
MIVLV#Z9;L;F>\N]5N?$]]/!KEQYC?C4,!C7@JN9U<'5IY;1Q-/!O%5J<H8?$
MX^K[2I1RVC*<&JV(GAJ%?$XJ%.,OJ>%I5)5W"I.C"I_&>'X"SO*,OS/BO/\`
M*J]#A[A_&X'`3JU5S87-\_Q=/ZQA<APF(C^YQ?[NE7Q&:U,/5=+"8##UDJ\L
M77R^CC.DMOVE]:T:W@TBR\#?#2.RTJ&+3;2.;PU<ZI*EK8HMK;I+J=OXIM[?
M49%BB17OX+>"&[8&XBAB2144KY<HKWJ?&W%E.$*<,[Q$(4XQA"%/#X*$(1@H
MQC&$%A6HPBHI1BF^5:7/:AX]^*U*$*=/BO%TZ=.,84X0I4*<(0@E&$(4Z=.%
M.$8QBE&$(QA%)1C&,4DE569@J@LS$*JJ"69B<``#DDG@`<D\"ON'X`?#+4=+
ML=;\>?$'0()O#FO_``_UZT\"W7_"S=2^%NN^&O'-]I,-SX(^)^C/I6E:MI.N
MC1;O3H3JWASQG:V=CXQT.^U?_3-/NYM+\6V/R9X"B\/7'BS18/%*W+:%)>VY
MOQ96ES?7K0P31W306EK;;VEGOE@;3P)+>[B6.[=C"CJES;_0!^+OA_QO\>OA
MWJ7Q).MO\(_#WBG24U'PMX+,B:E9^%X[U5U+3_#CZ?>01ZAXFOM-CCM4OXKB
MVL)M3=;*UN#H-O;7<WSM>/#U+(LZQV>T,ZS*M0PU3^R\GX:S.OE.=5ZV'I_7
M:V-IYC@JE/'8-4/94:.7T\/5P\\SS&K'#RKT\-0Q3>7A[_J+DF5XWBKB_%YM
MC,QCF6%RKAOAOA[-H95CYUU[*MF.?9KC52K5,%EN68:O367TXQC5S7,JGLJ5
M2EA\%CJU/[K\+Q?"+6O@V=.U[0KKXI?&33?B_P"'?&VF_M!:C\5["]\&>`?@
MY8^#9X_%/PZF\!:1=MX:NO%-WXQMKN>Y\1SZ#,FH>'-1MI&\2Z1/X5M]/O\`
MR64:MX\;7[[QMX@N=#T%YH+WX9WES;PZ-H>HVUQ-J.@:;J5SI\OVG4-.U"34
MO$OA36+.?4;E+V[\(^(_!FK6=O!%K:W\GUI\"?C!_P`$IOAQXR^&NO\`Q\TG
MXY?$C2M+UG2?%_C'P1XCL;37?A[XVT*3]E"ZTC4;9?!7A_58M!UGQ!)^TUH$
M6H:-:>(+BV\/II/C#2+63Q;)X8\":G?^*O@3X[_MH:]^THGA;PC/X`\)>$?!
MWP^^%%KX,T&*P6\OO$6N'X>_"/X<>!]+\4>-=5NI_L&L:YJ'A[X$?#>._L['
M2-+T.&YT."2TL%V$R?$<&>,F;9KQWB^'^&_"WQ(H\%9YF.-XSX]XG\4^(\R6
M"S+-,\RW,LEX=X7X0P=7-,;B:>49#5R#*LPQV786=7#9%5S&E/#\[QU>G5_>
MZ'CQD6"S3+<OR3`9E6RW-<ZS/,>(L/G>?9AC:O$6:XO(5D^386O##UZ^(P>1
MY?C)8+&8...S/.,5.M2<UB*&'H^SJ?3/PK2"]NO'7B'3A$N@7OB2#PYX72$B
M:W.@^!M*L_#(FL[P<7-A/K5IK<EIM,L:+OD2YG\]BORK^V'X$%KJNF^.+6-8
M[;6HUL+]S+*$_M_3;-VCD?[1=P6-NVJ^';)+?,4=Q>7<WAG3K.VMU>>>63[M
M\.G3$T;2H-+LK'2;4:5I]U!H^GI;P6^FVMY$9((8;:WB@CBMPRSQQ,EO#'(T
M,NQ`4=5\F^-%_P"'?$W@?QWX2M;VTU/Q%I'AZY\3-IMK$VH26#^'Y&U.(7S0
MV=_:6,UV^G3V,5EJ0C.HK+-8M#+!/,I_OSC3AK+\9X;5LLK8O!QQM&-?.LKK
MKV.$I8C/W/%YI5H8&A5]FJ<<?/$8[`PP\$JM+"8J<$E*#:_LWQ=X`ROB?P.S
M3AK'X_`/-'AL9Q)D^+:]E2K<5TZF.S^K0RC#5Y^WI4\94Q&99;A,'24Z^$R[
M%.A&E)473?Y!T58NXHH+NZ@@F-S!#<310W#0O;M/%'(R1S&WES)`9442&&0E
MXBVQ_F4T5_&<6I14E>TDFKIQ=FKJ\9)2B^ZDDT]&DS_%QIIM-6:;33W36C3]
M"O77>"='76-<C1[I;*.Q@GU1[EIC"(5TZ,W;./(N(-0FD58F^RV>E;M2U._^
MR:392V-QJ$6HVF['\(O']SX73Q=9>&M5OM$S?>=>VUL'2!=.F@M+[S+8RC5(
MFTZ^-]:ZE+<Z9;6%M_9MW/!?7=O%/);\58:GJV@W,4]E-<6%U%-I^I6S[6BF
M@NK5H[_2=3M2P#P75N72YL;V$I)Y$\B+(]I=SQS;5\-7H+"O%86O1IXNGA\5
M3CB:.(PWUO+ZLX2E6P[DJ-2I1KT'+V->C.,)N494ZT;J:^BIY1BLBQN18OBK
M(<XPV49C'"9E1AB,-BLM>;Y15=.K'$Y=B*]*FL3A:]&<*E.OAI\M:C4BZ.(I
M>UIUX_L;X<T$>'_A[X'\,77PW_9O\;Z-X3\4CQO]K^+?P-TNU\=W&FW'PTM?
M`DO@[Q;X\\#>(?#>K:OX=TY;&R\5C3M5>^F@\:6@U:36)[.*33KGC_CIXHTS
M]IY?@=X/LOAW^SOX8U'X-^%D^&E]KG[,GPBO?`'A^Y\*S+;R:IJ_Q/\`%+^+
M->TSQ?XUD2VOKC3;&QN-)NK/6O%/B#4I=)87<TTGYBWOCSQ+XCO;4^*/$&K:
MO;>:OG)K&JZKJEGN\^ZFMYKFUO9=2'V.SDN\O8V%O`);6#R[=8;YS>U^BGAW
MXE?##XSC3/AG:6VJZ'%]E35=4T"R2VL]#U".P^UB^\)IJ>C7B"XM1<JNIS&V
M@M[/5M-MOW<I6XG@C^KX=\.O`WB+BNCF>7\$87AW/\NJ.ID7UWBGB*4LVS//
MIXS`9E'+\*L=_8&45L5''XBECZD\!FM66&S&,\ORYXO#8>6$_MCPZK^`7B7G
M6,P.1<%Y/PCFE&IE>'RC*N(^(<TKXOB_&5JM11P^5*6*J9;D,Z<L)AHXC%2P
MF?XBC#&S>5Y6\=3H8B'I?Q'\/6GC?PY-/H>GZ%XEU"U=HBOD:#J,]W;"WG:3
M2(+S46C@@,EQ/:7,D!U324EC1HYKQ()Y8I_&X/#'BOPEX.\<Z[K>EV7A^PL?
M`WC&"XTJSF\/^&=&O)Y-+U%K.73O"_@H7.E27,]R8X(]0\3:QJ^H1P745OI]
ME:7;7<MU[=#\/K+PMKUAKGP_T_2O#D-U<06?BW0K"U:STG6=).(X;RWTVUN;
M32K#6='D9KF+4(;+[1=VDEY:7'VEGMXQ\K?M&_M`V\]OKOPTT;2+L!-3-EJV
MK7%T(K74+?1M0C2]TZ""V'VB2QN=5L[S3=0D6]M9FBT^ZLC$4OWDM_Z%XYHY
M+E5+,.)N(_K669XZ.)R_`X#+<8J^5\28AX&H\%44:F"AB$X1G[+%RJRPDL#.
ME74*M6C6IXC&?TKXLYCPYP=E.<<?\<5J_#W$^'R_'91D6!RS%+,,DXDS5X*O
MBLHGA5/**>/JM5G2ACHXZ.$H9=B:%>7[W#U*&.QWPA?6\MI?7EI.@CGM;JXM
MYHU9&5)8)GBD0-$J1L%=2H:-%0@9157`!56BOY)BFHQ4FG)))M)Q3:6K46Y-
M)O5)RDTM+O<_QQE)RE*3T<I.32VNW<_;/X8V5GI_@?0[.PM+:QM(?[3\JULX
M(K:WB\S6-0ED\N"%$B3?*[R/M4;I'9VRS$G\H?C/;P6GQ'\9V=K#%;6EEXL\
M06EE:V\:0VUI:K<QW"VUK!&JQ6]NL]Q<3"&)4C$L\T@7?*[,45^[^,/_`"2W
MA5_V*ZO_`*ILH/\`0OZ5O_)D?`W_`+%66?\`K,Y.>55]+_LGJO\`PM[2&P-P
MM-74-@;@K:)JA8`]0&*J2!P2JD]!117Y/PI_R5O"/_96<,?^KW+S^3/`;_D\
MWAE_V662?^IE,_5FOPV\:RRR>+?$J222.D'B'78H5=V988CK%],8XE8D1QF:
M:64H@"F6620C>[$E%?O7TA_]WX1_[#,W_P#47"']J?3W_P"1'X<?]C3B/_U%
MR@YBBBBOYG/\T3__V0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V=R;W9E<BYJ<&<`````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#<Q,C4`,3`T,3<S-C,P,3$`,#(S,30V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/_8_^``
M$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%
M`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!
M?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:
M)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`
M```````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A
M,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU
M-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_B$U#P]=65Q)$TDJ
MO)<.EI#/$\'VAYWC5/(:0+YS/(1$JQ;BS.H`+5!-9ZK;`0SPO#*RHHC&Y7PT
MNU-J$!B[R1E$`&68,H&017[<_P#!*'_@G5J7_!2;]J&7X>:SJUWX6^#?P\TW
M_A87QI\26,LC:HWAT3VEK9>&-,N;>.5(_$.N75VD:MN2-=*M-;N5&ZT+)^E/
M_!?[]D+PE^P9\./@5X=^"?PY\/Z)X5^(>HZ_X>A\7_\`"*:5KDN@:=X/MX%\
M/>&8=:OV62QU77TU2YO&OY7-_?6]EJ-_91RVEA>R0_(9_7P&6YO0R?"5.?%M
MKV\ZT_9PHTG9TW&4;W;2U3LKVMT/N\#.>)HRQ6)3C0A&*4:24IRTC?27:ZM9
M/STL?R7PZUKVE"9%>[\F7`NK>X$@\SRB@>V<-C8PW*QR-RA2".M9FK:K)J]V
M+EXS;*JQV\5GO:6'$BA'<R*2%;RW90&(Y=>Y&?WC_8R_8\U/]H7_`()W_MC?
MM)?$O0]+C\._`+2]?B\%?$?5[,K/?WMIX9O]2U70K&]:*&'45T/4TTG3X)[9
MYDE_M2++;S"K_BX?"VH3"VO)8+/3HK-#(D!`$,<N$BCAM]P!NIIEFANI@"QM
MT"AP`X)]/(H9KFT\=@J=>/L\-?\`?>U<J,KVO>;2LXV2E'6W?MKC:F5T7AE@
MUC,1BL5R+"X3V$74G45O:<ZBKQA>W*]VDSV;P5\'OC9\-/A/HO[2WAZTU'3M
M'/B>#2]&\5:;!#>S^$_)CNW_`+7N99(WAT>Z(MVLK&[N621YKV.RLPUY>6RG
M^T+_`(-G/VWOVG_C@/CQ\`_C3X@UOXC_``Z^$W@70O$7@OXAZ]I_VK7_``CK
ME]J<=A=?#Z_UUH8AJ5CKEG/'KNBV+>9?VD>DW:R`!J_FR_X)_?M]?&[]A&T\
M3:#-\+O#?QH^"WQ!T^Z3Q5\*OC3X9U*[\%:M!,8([R;2M3\I+>"*XC!219#<
MVMSI\U_#!;RZA)9,G[=?"#_@XN^#'PB^'%]X/\#?L$^%?A3##+%>V?AOX/\`
MBGPWX8\$ZA>7.Y9I]59_!+SRZA$&6)]3O8-146IM;2T'F)=LGD9WP;G.,I>Q
MPN%R_&\[_P!X6(G%PF^7F24$[\NJW5V]7IKZ,,7#"UZ,L9+$Y?#DC&OA<5AW
M%0E%*\J4I)1DY;KFT]3^SN36[$R.6U6S1B[%D_X2"6+82QROE%<Q;3QY9^YC
M;VHK^%[4/^#D7XJ27]])9_LK>!XK-[RY>UCN/%7B:YGCMFF=H$GN8$M(;B9(
MBJR3PVMM%*X:2.WA1A&I7RJ\).+G9VAT_P"7T_[OG_5O2W;_`*R9'?\`W?'/
M7=4L/9_#JO>V=G_3.K_X-GOVM_@]\#?B3^T7\&/B'JW@OPAK'QQLO`?BCP%X
M@\3SQ:`NOW'@=O$>G:CX-L-9OI;>&#4K]-?CO;2Q$C->Q6)98G/EM7]<?[1G
MB?\`8Y^(OPEUK3/VF;'X/>-_AQ#)%KM[I?Q>?PY=>#K>^TR(7::N9O%"M%97
M-O\`+9V5[IP9YVDFMU62&6X6O\H[Q)K,6H:G:ZJ%MK4V=K;0Z;;)L1E\A52>
M7Y5::V>1CN%Q"$E4,0'"2,&MW7CNZU:TNK.\OM5F\JW6VT^+6-7N]2M(X3M>
M:"*.6Y@ME@9XU<>>[R;T10C!V(_3,_\`#:EG><ULV>:5:$:JIQY8QIZ*GNN9
MM.SOH_+HSX;+\]JT,#+#QPU+FE)WJ\\^:VEO=^'9+=:G]%O_``6%_P""G?PB
M^(GP[TW]A;]A;PGX*\(_LQ>&K^UE\8WOPP\.IX9\*>+-;M[V2[T_X<^'=,TI
M--37/#T-[96NKZKXA31YAXLUR#0QI^H2V%E?PS=-^PK^Q'X-^%7@'2O''Q*\
M(^$_%'QG\2VL&N3S>*]!LM?M/AQ:W?D7$'A[P[IFK6US91Z];61TYM?U.>%9
MA?7ES91.@M;M*_G[_9"T9/&_[3'P@T'4U-[H[>+(+V>TGA(6XM-%M+K5Y;:6
MV0-;A)6L5AA8L78L$3(<U_8'I-VX^U+O$+1K`EQ+!B6.)V0":-@H98T)CMV=
MFVA28@V/,7../I4>',)2R/+JCC&LN:MB(R?M)RJ-.3;3L[M;;+H?UW]&K@C`
M\14<SXRSO"4L;+!8RGEN!52G!PHNG0]K*K%6^/FM%Z6LVWT1V%YYL5K_`&<F
MDZ*VF)$9;;37TK3;C3+0F-HI2VF;'TNZ,RS,=L,$:PQET$B9*-^._P"V]^P;
MX0U_P]K?Q,^$_A;1]$\:VUE/K.J^#-`M9M)\.>.YU9A-*=/A$EM%JB-*LD,E
MF_)62!8R9QC]:M0U80B-+L221QKE9K=MEP-R$!H')V1OM+$-)\FP,,YQ7DGB
MS7[*WL)6NK^/[/#'*8$7:R,LP:(?;V8D/(CRJ6FC/DK@JQ#,H/BX7-Z^5MS5
M:48TI1M2<Y.,I>ZY3;=W>;W2TT/ZAXK\,N'>,<FQ658[),$G6IT_88FC0A3Q
M%*=2"?M(5(I-N]O=E9*UEH?QB7/BSPY:7$]K>3:C9WEM-+;W5HUI=AK6YA=H
MY[8AE#`P2JT1#`$%>0#Q17[E>)?V5_@UK/B/7]871;15U;6M5U)0L46T+?7T
M]T`/EZ`2X'M17U2XWE9?O-TOM/KR_P#R7]6U_B*K]'&4*M2$<5C^6%2<8_O.
MD967VNR73KYN_P"&GB[0_$'A;4[C3?$NEZKX>U&"ZNY7TC6].NM*O[.&66,'
MS[6XBA$49E9%@X&\,/+W#-8@O;=5,4L9$@&<$8;`QR%(SCYAGCNHSSFOU)_:
ME_:/\)>+->GM_C+\'=8@N#-'!#J0.D"\5X029--UBT52(HU<EK:[R2&21\,B
M9_)CQ'J.EOK&JS>%VNX=%NK^>YLX+N1))(H@0B"Y;!:2XVM\DL7[DH)!U*XX
M^'N-5G>#]K7P;IU>2,VJ4IRPZ<N5N/.]?=>DK:IJS2:/Q/BKA''\(X[$9=C/
M=KT:CC"G63A4G"_NS:2M>23>FCWVM?Z:_9)\:Z7X$_:/^$_B6]N&L[*#Q7:6
M=[-=(S6<5KJ22V$TER."T$:W!=\$%53>2$5S7];S^)?"\-S%$MP;J?4E9[74
MDD,0EM[DB6(Z;AA###Y=LC"2<GY=N#AQG^&I-:O%966<QF.2.021'RI/,BE2
M2/RYA@QNDB)*"&!(C*_Q<_L%^SQ^WVDWA>R\.?$>]-MXKT9+?3],U^XN7AM-
M7TR*,0)'<2`D6]Q"KH!N*^8B22$DK7#Q.JE6-#&8.G&4HPA:*DVFTES*^]UY
M:+OV_J'Z+7B/D'#U/-.&.(L;+!4\QQ,<9EWM'%0GC%15*K3ES.RIZJ5][[JV
MI^^VM>/O#UHZ)%*TTL2F:-!NBBN+N/$"^?+(0MS,$FD^:`F,C<>H%?+?Q-^(
M>@VVCZG>7=[/)/'<)(+:QD5WMR2R$Q2*S)&8Y7C1WFQ$F_8Q#NH/Y\^,/VPM
M,M7F72I8KF&"XBC4PW5S?1W$LR/,T]M(P,<D:^659HV;:6`Z$U\(_$O]J35-
M0EN6LY98;F6YO"(_,D"N9#A8YXV/R1L#YJDC[\28/.*^)I87,\95E&M24:=7
ME;ES2TUC>U^B?7\WH?U'Q?XR<'<-9=4GA\VPV,Q<%%PITJD97J4X**I>XV[+
M175GOT/T)F^.>H0S2Q?:M''E2R1XN%+7`V.5Q.P(!FX_>D<%]Q'%%?AQ/XXU
M^XGFN'UG4]\\LDSX,N-TKL[8XZ98XHKZ-9/*RT6RZK^Y_E^?8_D.IX]XB=2<
ME@)6E.4E:57[4DU;[U;Y=]/V+_;:L+%_AKJ+M96C/`B&%VMH2T):PGR8F*$Q
MDX&=A&<#/2OPSTT`Z?:9`.7?/'7ENM%%>%X:_P#(DQ?^.I^=,Y/I5?\`);X3
M_KUA/_;BY*JB<@*`-G0`#^[Z5,'=6@*LRD2(058@@[6Y&"***^[7^Y1_Q/\`
M.)_-%/\`Y'62_P#816_]M.AAO+QG13=7)4,"`9Y2`=KC(!?`X)''8FN>F9I+
MTF1F<FX&2Y+$\-U+$T45ST?A7_;WYQ/9Q_\`O4_^PM_FCIECCP/W:=!_"OI]
M****I=/E_P"XSZ2.T?2/Y4S_V0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VAO;65R+F=I9@``````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q,S``,3`T
M,3<S-C,P,3$`,#(R-S,P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`
M,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`
MF9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S
M```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S
M9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S
M_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F
M,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]F
MS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9
M`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9
MF0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9
M_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,
M9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,
MS)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__
M,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_
MF9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____X
MOR0`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````A^00!``#8`"P`````(``@
M```(_@"Q"1Q($(!!``03*ER8\"`2)"082F1(`L!#$A@S3MQ(`@D`$BI&-1O9
M;)2*B!L7=@Q)LF5)%2E5CG+BLN4HE#$'JJA9$V9.@21$\K2),R:)H2Y-@LRY
MD^>H%5!7J&!UC=4*HTZM4*VZ8BLKGQ./UNQZK2Q75EJ+,F3I<H59LUU9L5*[
M=N0*H62ME/VJHB\2HZ-,LASU1&[5)T)OQOP8<N;(IWWODE2<TB(`MC8#2SWY
M-V5$@TTG;P9$BI0>NA*#)GVBI[1KTZAE.BZYHO5KU[%5LJU]^_7IGV*;J=`S
MO#?LGZ&'8SQYTB#&G]B"%W^=)W?8R2IN6Y\8NAGOTK^A-@N4*O0EZ?#BXT)-
MW%?%1_'1S5J5_'CJU9]0M^XE;Y=K3O7ZR7598%-5M1TV!R7HG((,$A00```[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O:'5M<"YJ<&<`````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,3(T,0`Q,#0Q-S,V,S`Q,0`P,C(V,#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````_]C_X``02D9)
M1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!
M`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#
M``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H
M*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0``````
M``$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!
M40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/D
MY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#\O_!?P_\`#WA3QHEIX+\`
MZK8Z[K>O'3_'6NZO:6"7ESX<O'61IDB>_N='M]-M/#UQIL5A\VL3IY:R7N)V
MELH/=/%:7&B6-CX:M$N[Z.^\*>'O-L?#VB7OVW1+;7K>YO6F\.>("/#7A>VN
M]/T>ZMO$&I7LEIK]J$NY=+-NE_;3R'TBV\/Z;X1L=`UW4?"=MH<FG:G<:;XI
MNSJ^AW?AZ"ZN[M=0U**TT[[9=R6L4]^LFF3&"1'CU1+[S'+G:OD/Q/BUS5M6
MTVYT]`FL:3?Z"N@2I=ZCJ6F_V'!?[[#PO#J!FCT!,V%VJW<,)\Y+M7M))8A#
M);K_`"/7QV(S.LI8J=>6)HQYH2DY*,;<JLN6R=K[.Z];']IT,EH9=@G'#<BA
M)OFIQ5T_:0M*3O=ZJ4D];:^K/T2_X(Z_\$W/@)_P4!\:>)OB_P#'K0K_`,1_
M"SX`6_A?P1IWPDTW5Y-"\._$KQY*-4BMO%OCKQ;X=CL=3US3=`\-Z5X6\:S:
M%HNM6L/]K^.I[?4%E?PI<Z'XB\%_X+V?L*_LR_##]N3X(^&/@WX=T3X=>$/&
MWPE_X2/XA^$_ASJMMX:U#4H;'5YM#T^\LH9=+NO#5O?:U#8#45=]$U&;6KJ/
M4M6N[BZNM1><XW[&GQA_:2^&?P4_:`\)?!1/&7PV^%W[3-O=>$OB+XQEM)F^
M(GA'Q;=V,NCW'BOX+1Z=-HD(LK*UOO$/AZ?QG8:E?P>'GF>VFM#XB\,:-JFD
MM\2?#V75],^'/A;QUX^\;_$1/@=H[>'OACXC\?ZY9^*O%7AKPW+K/BK5[FSE
M\7ZW-JVN^)=*T:]U75-7TM;_`%+Q#!X8T2^L/#T'V'3]'L],LOM\%Q+A<OR7
M"X.A[*GF<\9#GK2BYSE%PJ^ZFVWJ^6UDNNFS7P-/@W&9IG]?%9@Y3RF>&>%I
MTH\L(6A3BZ<9)1BK0DJBBKN35GS:V/Q6^,G[`GBWX;?!O]E_XD0>,_`6H:1^
MT%!\;+C2/$.F1^(+KQ4T_P`,?B!;>#[S3]:^'EYI%OH]D]OJFHO9:,='UVZ?
MQ9I%@=4SI=]!J$<OSMX_^`>IQ?#7X=:Y\/\`P]XNO=4GEU.3Q[>Z/:ZIJ5K!
M!XHM;*Z\%7VBWWAW3HM+U+2VLME[<F338C#+>S122"59)'_;;XN_M(_"V_\`
M@G^S/\&=<^)WP9U(?`/XS_%;XG^&O''A[XJZ[XC@T3X=?&JTEN?&'PP;P.NB
M2>%05\1VT7BJV\76/CZP7PIJ$EQHNI^&8=1@U;6K_P":?ASX;\(0:Y\*O"&C
M_&_PWH>B>+?%5M_PD_B/6YKW2+7PKX1^(4]I8Z#?7?AZT_L[5=:\-Z?"MOK-
MOK%C9RZ'8:=KEC'HC:SH<>GZK??1?ZUYUAU!UZ-'$QA&-15:E!R<7:-[2:;2
M7,[:V\D[->-E_A_D&8SIX+^T982O/%8K#Q<JT:CITHN;ARI7=VX0DDTW%^[=
MVN?"4'@?]L>.&&/3/`GQ2.FI%&FGF'PS8K";%4"VAB64^:L1@$9C$O[P)@/\
MV:*_;:^^`_AJUOKRU'[<'[$R"VNKBW"'Q!\1E*"&9X]I4^$GVE=N"N]\8QN;
MJ2H_UW=]<)@KWZTEO[OGZ?>_E^I0\`<O<8/_`%OQNL8_9EU4/^G?]7];>9>&
M)=&E\0:AJVJ^$-=TGQ)X6O+"P^)NJZGK5GJM@=9U>RMM9C,EGXHT^WTZ_P!?
ME?4(]0AT33;R^EFN9VE,]HC_`-G6W3Z@DMA>:AJFGZWXON7NO$WAJV'@?7=%
M\*:4T5YK<L1\,>*KO^SCHDFC)>ZE8W*WMI%)<O%:3VM\Q`FW2?-]WKFC?$+4
M_$_AGXTZW-XMNM(U>ZU[PKXM\^\@TWX?7]]?:A=WUGXF8./!?BB>]\27=O8V
M%SI-E9:MHD,HAN=19H<1=WJ'B71-(LO%>C^-V*VRZ%K&@106T.E:GKNKZOJV
MFZ)I3Z_=>(I[?5H]`;PO'HJ:=X:UT)-8V=JT\EQIUY=3+<1_"5,NG3BHRE/G
MNDXV]Q+1.SM>_2U[:=58*6-H5/W<,6VK7:YD]$XKKY]M==#Z?UNX\53:I:Z1
MJ^VXU318=(D\/6FBQ^-?[/TV&WT^$7,$VLP:SIMO>:\FHRW0U'1]%DBTO671
M]3^R++=29_/?]HWXDZCXS_:`T']G*\^)NI_""YTOP?IJ:!JI\4?\(7\/=;^(
MGB[5_#EYJ6M?&;QCK7BK2-1\._"70_`L]T/$5MHGASQ5JTNLQW^DV^C:H%\R
MX]I/Q+A\;7,_A.V;5M/L-%\.275MXK\93I<Z=J^O:[;QVNC>%OA_I<-I<:QJ
M&B>'-&AD_M#5)+ZRUF[U&UEU&QU>RTV:WLH_R1_:I\'W=MXFM?B)I5[J6H>"
M=8BB\+WNI:E=SPS7HT&*&"PN7L1]JEU!?)LTO[2]O9;K48I[B2![T6,<&G6O
MM\(9/A*N?866+PU.LEK'GCS)3;II-:V3M)J^ZZ>]8^3X]S?%Y=PW5GE^+JJ<
M:T6E3DDX_NJBYDTK[/E[>]VL>O\`Q&\$?!KXK?%76]8^(O[=7[$?PRTZ;Q!X
M&\/-)^SS^S1^TOX4^"FG^$[]]9\(^,M7\/>'O`O[+7P[T2]DTG1-'\,>(O$O
MB>_@U*?XE:1XP@OK?Q/XA\:R:[HB>*>+_CW^TUXB\/>'?A_XR_:C^-/QB\"?
M">;3]-^$VBZ_\3OBAXI^&WAW2/!K6VF>&[SX>^"OBE9Z5=>%/#::3HVD0Z+X
M6OO!OAR*PTFTTZTU/PS;:C!=,_B4GBV-FC&FG3]'B+_:+*2RLU:>/S?WT+12
M$O)9I'-)+=?9D*6LMQ<2O=VTX6)(K=B-9UZ[L]!TM1?ZE?R3"U73%DFOI/-D
MB-Q-=)!!<SS2O<W9GD>SL+C=$7-Q(MQYK#^B_JV6*A7>-IPCAX)0TIQ;:Y(O
MDO:]GOZI:H_DNAG'$#S+"U<NJUZ>*BY5I5'4;=G)*4ES:)MR5[6TVLMOTP\/
M?\%HO&GA_0-#T'4_V9?V9_%6HZ)H^F:1J'B?Q%X$\?R>(/$=[IME!976O:[)
MI'Q4T?29-9U>>&34-3?2](TK3FO;B=K+3;&V,5K$5^7NJ_#I](U34M)U+5;T
MZCI=_>:=?F#3QY)O;*XDMKHP^:5E\HSQ2>7YBK)LQO`;(HKXIY3PY=VC&U]/
MW:V^[^K^EOU^/&_B.HQ_X5\1HH_\O5T4?[O2W_DOF?:<T_C"&'4]`O=9\/6?
MAS1Y;FZDCN=/N?#NCQW.HW&C:K->:-<2-_:.HSZHFEVS7"W]S>"UDO\`48D5
M+CRKB)D/QV\2>(/%=UJ6KG^P%UC45FM=0\J[N]&N&M(TT^TMHKRY_M=+O3[>
MWM8K6WM-2184CB1+LW=PDMY-^Y_[2G_!&+XJ^&M3U#2?V:OC3-\2HIK>ZU;P
M5\.OVC?"UKX+U7Q;X9BLK=['1OA7^TSX?E\7?L^^.O%IF:>WM/"/Q"B^"GCM
M[6W2U7P[J<UN^MZA^67PO\"3:GIWB?X>_$G2G^'WB3P!K+>$?$_P[\:6D?A?
MQ)H?B379Y[VQB\0V=MO:73M1EEGDT_Q#:W\FDK;7%@3$%#0GX')^(^$N(\+[
M3*,VRO-:%.,'5E&4:<\.IQ356=)R522BK1>EESJ]FTW^AXC`YMA\3+"T\)4P
M=2C43G7JTYNG5@KQ=)2M9\TKVE&Z?LY)2?+(S=!NKG2=2TV[%]JLNLZG<ZMK
M.IQ:+J.CSQP1?V<;**XN+J+4IY-'GET]8VT^QALHK9;.:)4M%!`$$7B31[$V
M:R7.MZ8+2P&E:#;>+V\,ZOIFJ->`W;&?P*?"FC7NG3PI.=.M+W_A+'_M.S@M
M]58QO>M&GHO@W]C7QIXFTW6/`/PU\6ZO9>.K"?4O$?PL\.V/BBUUWPUXT>.5
MM5\2?#&2YT[3=*B;QY#9:A#J.D^&`LMYX@LY5N[*\@%U%!!\]?%/7O%7@[4K
MV7XH_`*?2&\%:-_PC>JZAX'\?>/O#EG9>,K94L@/&&@^.$\1V6G^(+.*WEN[
MWP9I>EZ;>M&!MU:1V:[G][!9)B*4X9IE=2GBZ',X^VP\E#V3LIM\K?-[O+O9
MKMLCHQV19YCL#.I7P*E@N2SG"FZT*D]+1E3O>":4GS[*S75V\U\0^`/V=[N\
MU"#7M.^+_P`.=<N[6?5(M5TNT\-W^BZSJ*:E(=1M;+PG#IVJ7\6GR6KJ+.6/
MQ8YMW2268,H^R0]E\'-5_9)^%WQ`T;Q)\0?ACX]\:?"7PBOB>]\4^'O#?C:U
MLOB9XIU2]T'4--\-7^F?$#2+?2$\$^'+>[ET_4]=T6#2'NI(U*C4UN?,NY?T
MB^"__!+;PS;?L[^'OVX/VV_'?B[P_P#`;1=.\1_$KQ+\&[+3=2T[Q!XQ\&?9
MK[2/@O%HNL'?K-KXG^+7C+Q7H,&BV:V5EH$N@V#SWETUS,+M?RL^'J6^O:SJ
MFE:M:Z??V/A[P5#X&TVUTG3M,8SZGJK:;X3\/Z1YDFF,=6U(ZG?:9INIRWHU
M*28Q7*VE[*#%?OVPSZ.:T,1A\+F5;$8FAB%3Q.$IV32C%<TY2E&SY9.,6EK[
MT;)I)GSU#PUS#"SCCJV5991P[PLZE.I.JU47O4VH^RYERWB^:]_=ZI7LO[1/
MV7?^"#_["?QV_9G_`&=OC?'^R]XRV?&3X%?"/XJI_:WQ2-WJNSXA^`/#_BY?
M[3N[B?[1<ZAC5Q]MN)SYTUSYDDOSLU%?U'>$X/#O@?PKX9\%>'M-M?#^@>$/
M#^C>%]#T'2K*SMM+T31_#^G6VDZ9I&FV_P!F;[/8:;96D%E9P[F\JWACCW';
MDE7]6Q&EWBT]+KVE/1^Y=?!TL_N/F9+&*34<!A'%2?*U3KM.*<;--3UNDW=>
M5NA_/;_P3"\2^(_'^C>)-$\=Z_K?C71K_P`'07-]I'BW5;[Q)IE[<E;MS<7=
MAK,][:W$Y<!S+-$\FX!MV0#7X:_M]VEK>:Q\'=>N[:WNM<UOP+\?M(UG6KB&
M.?5M7TGPQ^U5\4-#\-:7J>HRJUY?Z=X>T33[#1]#LKJ:6VTG2K&ST^PBM[2V
MAA0HK_-/P9_Y'C_[%\/_`$]1/[1X_P#^2AXI_P"P[`?^H,SX^^+VM:QX9\%W
MUYX;U;4_#UWHGA5?$6C76AW]UI-SI'B"S\3ZK:6FNZ9/82V\MAK%K:6UM:V^
MIVC17L%O;P0Q3K'%&J\7\0OB)\0/B/X,^$&@_$/QUXQ\>:'K/P^\3:_K&C>,
M_$^M^*-*U77;JW\837.M:EIVN7U]9WVK7$Q,L^I74,MY-(2\DS,<T45_HOPY
M_NJ_[!I_E$^*R_\`Y%&/_P"O4O\`TY$_=C]KXFW_`.";_P`%[*W)@LY/@_\`
M\$V-*DM(3Y5L^F?VE^S_`"?V:\";8FL/,N[M_L;(;??=7#>7NFD+?S3?LLV%
MC_PUE\`-,^Q6G]FS?\%#/@!HTVG_`&:'[%+I$?QL\%Q1Z5+:;/(DTV.*..)+
M%XS:I'&B+$%10"BO@/#[_D><2?\`8=7_`/3E(X^-/^28RK_L74__`$E'^J9=
M*INKDE5),\Q)(&2?,;D\4445^NO?YK\X'\U+I\O_`'&?_]D`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VEC97-K871E:VED+F=I
M9@``````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,P-S0`,3`T,3<S-C,P,3$`,#(T,3`V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y82@`/`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`
M,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`
MS&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS
M`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,S
MF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS
M__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F
M9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QF
MS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9
M,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9
MF?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,
M`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,
M9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,
M_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_
M,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_
MS&;_S)G_S,S_S/___P#__S/__V;__YG__\S___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````L`````"@`/```"/X`$0D<2+"@P8,(";)*Q+"APX<0
M(TIDR&KAQ(L8(U;,R)'CQHX@)7X,2;+AR)(D-R+R<D6&RRM=O"!"*1+1E14`
M<NK4N4+&E98RO-!D966GT:,Y`UB9F?+HBJ=0D0)@(30D*Z-6<`)88855H$!>
MG^H\T,7J3I<Y5["ZQHKKVHI9TUX!V38GBZ);U[*U`O::7[A:YWH4Q&*%%Q8Y
M`_EE&VB%XL5LZZZXPO0B*T2"K@C"J39RX\>,^];=*GCB2,YKOS:V\A>L8[^!
MSE:&.!(Q@+>.`W4-O9NMUIRE:5M,U"4GZVM9P>JMJ-?WSA6S'8Y$A-JW6\B0
M1^L4)')X(B\X=_YK=5LQ^^^<7:)3])[H2@``8&-OU<TW.U+HK1Z>9'C3;?B*
M?2V&%T]I!2*((%;(D!Y[B63V%%\/UK>8=O,9E]5D65WA'69/-?9@A]D-:!QG
M%RH65D'G;=5A>7^)F%9B>#W6F%0\Z<:5<C,:Q554!1+EXE$VIDBCBBJ2J-57
M]SDFY$XB*@>@4Q?N%.164BGY'(\Z)N=87,]EZ>%-0\)XH5@\69&<:LK!]J!\
M-)+GXHY9-8<=8U#QE:-1,I8Y8YQS8C<:5U<XI=R8=_+9IU<Y3K;D%7R=>51R
MAT(EZ7D0SJ?:DI!FYV%7`([G(5<_(I75<7]Q]I699IH:GH<$2E74<?Y$0=4<
M8#ORQ%5>S*6HJ%H7=F6FG*@*"1U$"GF5UHTF_EJJ6+G]QB!$@NP$5VM\Q7JK
ME$4]^Q!U/09XS:>AZJ3M0UVLT(5N<+VUZ6_GX33NMHE0!V>J+)25D$"LM#)+
MG_E!2R),W&74EKZM%&RPOM?,`I$5!P1,EWH-M9*POQ!;IJW$"1]<,%$:%[PO
M=@?O%[&^LY1L\BRM:$CRR1V?+/+(&C?T5'`"SR00PGU"-DM=,A!<,$97R?JS
MQQ_WBPB7:GWL%\HB02?01/O:U*Y#'B_6KTD.3Z2O%0$$\%2]*V0]\KY7M_5N
M(OMNIN`*![!-\T,2*YQ(1?NB?'75*,O[M205Z67$]$8%]\ETO#X)4K%$?WL7
M,TW274/1O9!'CDA;A@L4$```.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]J97)I+FIP9P``````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`W-#4T`#$P-#$W,S8S,#$Q`#`R,C8P,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#_V/_@`!!*
M1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!
M`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!
M`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F
M)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````
M`````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&
M$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KB
MX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/RS^%WB*\MUT2TEENK0
MO<:#)(PC$D<,=O#;27,YF\EG\F#^S07@`&]IU)D4Q`2_TB_LZ_M0?"3P[X6T
MYO'?BK1+*.TAO$O+M]+U36%>RD&HZAI(FC'AS4;73%"E4-_*88X3:!#=QF[$
M)_'7X%_`N34O#=[XOGO$0Z;_`&K=PZ=!;P7=U-IT3SRI$EN+O[2?-&G?9?\`
MCT.P7AE.XP"&?ZO_`&4?B[^W)XK\7V_@/X1_"CP)XQ\'^(?$DWAZXTZ?P.WB
MVX\/V-G`ODMXBBM(-+N#9)92W"SOJWV31UFDMXKBX%S+9JWY7+#5\ZJO#X"%
M.=:$I*5.=:E0MR6O9UITXN^]DV?V+@Z<N%LF>,QT7*ECUB)Q3O/EHQLI5.6/
M,XVO?WDI:.U[G]3?P5\;^"/B!H>G7OP\\<^"_$VA75M8O>ZCIWB72Y999$TN
M4B&/3;77+,VEV;NZM+.12&FB@>>8P-M:*OJ..ZNTT/4!=7.I/;"X^S6EAI_]
MI(([W17O].O;&&Z>^M;2^1R5N([(W6V^3?<B,_8"S?B+JOPFTOX+>*_%.O>)
MM"\->#?%W@*PM?&DOC;X/6VI>#-*OFU:VMEU'PWXA\*:+/-H]LMI=1Q:<;1M
M=U&2[N;FVU81PC2VM+K].OAY\0_^$G^$/A_XJ:=)-+)K]II>NBSL3;?;+AM0
MCGUP:7*;C0[B>[72$8Z9>SFXLO[6>[CU)S8&T%E<]>6YG/!U'ES=/FHS<:D?
M:0?[Q64HJ2;B[6W3<7T?1_C/&?!]3ZOA<\P^8*&$S"KAYT4H.4;8MITK]N;L
MTG'[48[GB/[7'[7^D_`KP3;R^"/#6C_$+XD>;X:71=#CU*#PY:1Q:JNJW>IS
M^(OLWAF35[Z32!I"6T?AK3M1U=]>OKZU)%J;7[5!_+S_`,%"?VAOVHOC%X*\
M6_#WXS_$'23H7B"#2-5L/AY\,=*DMOAYI%E::9IFHM!J-WJ-I#K2^+M.$UI;
MWMG<&.&V%W?*4GD@25?TT_:DT6Z_::_;$\-:3#\#_%OC+6K;PY'IUO9>(O'-
MS\,/!$MM<:Y<V:ZAI#^'](\57-]?>']1AL+[^TH%T6[BA-TIOK>$2PWGY,?\
M%&4T?0_`G@GP-I/PR^)'PL^(7PWG\0>!O&2ZUXV37=#O[?PG"_AV35]`UR_T
MG3)?%NEZEK&J^?JFO:A.NIW5Q9:9:QVWE+-/']I@*F$JXM?6HP4N6+BXKGOH
MK6<4U?UN]%?8Y,=DU7(L&N2<*F,Y$ZTH2BDDU%I7YN5N[>B?G:[/Y_\`^T+J
MW_<#3FD$'[D2&X(+B/Y`Y'D]6V[OQHKI;7Q1IT-M;PW%KILMQ%!#'/*6D)DF
M2-5ED)6U=27<,Q*NRG/#,,$E?9JGAM/W<>GV5_=M^GWOY?$NOB;]=_YEY?\`
M`_I:?U6?L2S$PZ#X5ET>=K&U2.U<7-QJ;V45VL6KR+-;)'IEW9FYEM-1B=8[
M6"ZN%BDE"QO#YTJ?N3H?[*GPLTFZM/$VD:5X9TW7-7O(AJ=W?3VMM;7%U<OI
M+-->K%J-G&?*@CFD:"[M;.]E`;_1DC$K)_/!^S+XIN=%\817-U:06R:EJNJ_
MV9/<*MP;E[:\M+*,(VDS66J02168"JZZJ4VP.KJ6F4Q_U-?"/Q>=6T.PU>XO
MM5TC3$A2[DET[5ET![B)+6WMKE7ET_3)=2OX(MIN&L]1N+I[AHD9K^)H5,OX
M/A)X1YO*..C4POL)3J.M3DVIN;3C%JG=OL[IK7T1_47B!B,QI\.Y54PN&C6A
M6PF(PDZ;J48\DIJ,8-*4T[MM--+=6;L?GG^W_P"-/#_@GPO_`,*?\.27+7OB
MN:6>_P!1\/W<\.D:B-)36FM]/LULK&[L;>*YCTZWN4MFMY[B:62)!J`6%DNO
MLS]C*_U'7/V;?"6FK8:_);Z7/X:T>**2TNEDECCM;*WU8/)%8"2-8X$DN;A7
MC*)+%#I[2![U+B/\MOVW?@_\5/%?Q]\7?%_4S)KO@.U@\/V/@#PSIB1WM[-?
M6\FAVTUP9-3BA$TXO=.U.[E58S--&9;,`)<27,7Z=?L4O?7GP]66X\.G2D0Z
MGJMK%JN@V%AJ%K?ZEJFC76IN=,1[E6@%_H=FT=T)(S!&[VH4B?S%QPCP5?-)
MU'@:K52I7E1E%W]I2H2CSU$];::N,K-]%L>9Q9E]+!>$N3TW7HRQT*F"Q%6$
MJU-5H.E;VT%!R4K4K))Q34TWR7/H'5_AOJ6GV>JW^E>(H/#]FZ:U)]LMH-$3
M5=,T;4]2OP9M(F%G)K&BA]-OK^"YAEENHHKP6TI83M$L7\??_!9SXY/<Z[#X
M-\&Z#XAT#X<SPZ?X;\.>*]4BNHM0\9S>';HW?B/48Y5EM;F2SU/5!,^H'SY;
M6YN+BTN)$9[.%9/[8=:.H?V%OD345M3$T=VK70DT*.&ZBOGU"YECDN!;,MWJ
M4NG-%8"V@;3[>.ZD6\EC\R)O\_C_`(+"?M$V7[07[4_BVR\($?\`"L_@Q)>?
M#OP5]G:%+"[N[.6R/BF_MHX!L@35=7RUNNVYQ'ILC?:Y1,5C_3<DH8>KC83A
M3E2PT\/2J4E*[<N9+WFG>23:TYM;)Z'X"\UQ>.HUYRG*HI8BLH5):.4(\D8:
M2LTK*RT2UT25S\?)O"QGFEG6[TJ-9I9)5C;18I6C61RX1I&O`TC*"%+L`SD%
MB`3170_V9=GD--@\C_1T/';G[4N?K@9]!THK[;V=M$]/^&_X/]/3QN6M?9_^
M!1\O/R7W??\`T@_`O5H)!IVKV-DT-GI^IB[ME37+"Z_LZVU"YLC/.L0T.S>Z
M13=#Y1/%NP`0"0R?L+-\:;SX<_">7XK>(I;C5/!NDW+:;;Z9H6DM<ZOYANK:
MU$US#_:^GQ_V?=6<M[)-,ID-O.EM%Y$PG\Z'^23]E[]K;2K6"'P]XKOXM,$Y
MM+?04GMII)[B9)M/M6@NB[V:0)&!).9C+/NDC2'R?WGG1_T2?!7Q[X8^)GA:
M.SO-4LM;T?5-(@LHO#HUQC'<2F1O-:33;31=5DL91):),EW,DD6,P,ZM,A/X
M1G^6UL+4G4H4YU).*4Y*,E9Z>[=VO9^;3U^7];</9UD7$6$PN!Q<'BEA&JLY
MJ,DN6\79)I)VMT3?WGM?PU_;P\+^*+ZTUB70/%^HI_:"7VFA='U"..Q-O<O<
M+;3-8:AJK6ZWS07MT;I[=HK;S!`8IVVL_P"A/P\_:]\)>(+"724O?$MU)>7M
ME<:6D4FKSR0BZ^U/J%K-#>Z-9PFQTT3%II$NC)(\<2^5&AD9/"?V:?V5=&T'
M2FU'1]>BT2'4[%@NGZ@+6YLWFT_[5>!EF"Z7=Q"Z+"Q5?LTHC\T3&.5@$7ZY
ML/"WA7X9Z'?>,?'&K:7I>B>!O#FO:Y<WMW'IUEIEO8WNHQ:?/>D'4+AKB.RM
MGVI++]GDFDU!$\B+:7?DRC!XZI4P=>GB?8T_88ZC.+A)M5:KBH+1._-W2:TN
M[&?'V?>&>(RYY?1P6(K9C0IQ@JC6(ITTXIJ,5&I&,;IIIR6DDVM8Z/Q__@H7
M^T#I7[-G[&GQ8\9OJPBU_P`1Z9J?@;P39S1RVZZEXOUB.WT^3[+<_;)3%)IV
MEZE<ZHKI:/OEM?LX:%F^T1_YXVOR1MJ.I3W%RL5Y<W+?:UC:29I`2[6ZSM)*
M0TKS+?7%Q=8#SM<)&500[I?UC_X*S_\`!0P?MA?$V+P;X.OKQ/@C\-M0N'\)
MO'JFW3M;U^W:.TU;Q(+5+*)0UX%@2"$S7'DQQOMN9?,^3\?9H$N9([[[=`]I
M+:0V]QM4R7,UY')-(+DGS%V(T<KH5P^U@AWG<`/VGA[+JN'P6$EBIJI6AAJ=
M.4UT<?L/6^G?;4_EJO55ZD:5)48<\N2FI1MRWT;:=M5KUU[(D#N`!Y5LV`!N
M+29;W.'QSUXHJM_9Z?PPRE>QW@9'8XV\9'.**^@Y)=OQ7^9P7K_U./E_G^#[
M'7^)88;;7O#9MHHK<@0,#!&L1#'7M+!8&,*=Q!()ZD$C/-?L'^R5J.H6^HS/
M;WUY`XO=`0/#<S1.$?\`M`NH9'4A6(!9<X8@9!P***^6SS_=*GJ__2D?L/AO
M_%K?]>'^3/["?V;%63P%H]Q(H>XCTRT>.=P&F1WO;!7=)6RZLRLP9@P+!F!)
M!.?R2_X+_:SK&D?L8:!'I.K:EI<>L?$G2;'5X].OKJR35;*3PWX@FDL]26VE
MB6^M9)HHI7M[D2PM+''(R%D4@HKY'*/]WA_U_J_^VGSW%O\`R-L9_P!P_P!#
M^-#4;>W32+>-((4C2=0J+$BHH:$LP50H50S<L``">3S6=#%$LL`6.-04&0J*
M`>4Z@#FBBOU+`_[M3]%_Z3$_.\3_`!?^W5^I*S,&8!F`#$``G`&>G6BBBNLS
M73Y?^XS_V0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]K
M:60N9VEF````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S<W`#$P-#$W
M,S8S,#$Q`#`R,C0P-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$O`#``]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````"\`,```
M"/X`L0D<2+"@08(`$AY<R+!AP80E(D*96$*APXL.`4S<R)$B`(P@'W8<N?%C
MR)`:H40$4`4/GBHE5)8\"3)EQ1)X`)30HS.E2IH7=7J$@J<B3Z$4@39$.I&E
M'P`O(6XLH91A3(Y.5_BIHO,J%)-5#?KD6$6/'I42FX8].)9CVI%@UPKL&K&N
MW;LKY0Y<(;,NR;=YY8XM<>"`UXD(6+!`X%:OSQ*+"U\M@:`P@@>,9RY-&!?A
M5!J!$K)HD7@%YP,LO'[40\KD"H2<XRJT>:"%:0`':(`^*MJK0#W)JCPAE2S/
MP-A@9^M\4F4%"\X(6M!`@)R%X8@"GR1+!KSX<>38+/XF[$XJ<>$6>JH<J$Z*
ME&F!5;8#?PT[_,?9X;<3U^.<?.7U`(Q&G'L"K4"<?D_,Q9E]RN47W'80DJ*=
M>XJ-9M9VMR6D7WL,)M<@`,F0TAV$W$&87G=5$,?50"$NN*!8LP$7'XDTTDA*
M?+?!IR"#,(*U`G<SUB@DCO;55R1LLLDXHI`1EF62;!;!*):,*3()816>)#C7
M0YTIV&5X\=T89(UEK7@D1E$^M%.(551)8IE/IGG2"EHJ6`*6(J979G-Q?@D2
M<4\\89I67.E4EEE\&JD4`!.Z=X`?J*!2!0M0(&#I>CWZV="$0,84J:2ZZ0;!
M<VS)B9%V\JV`&J1^D*287MX$L;9=6LZ%:FL+7VFJE';JC8;K1BW\"H5U*<+*
M8C*FL0"!;L'BJE@++.AAC35F&3O<"GQ"8>L#%:VP0BFKK"*M'L:&)^T30JWT
MQ"K4ELDNN>4^,>TJ@F++[K36T%O*M._!RA*^``><K[P\04'?6@"L(/"\X0(L
M'$PQ';RH2O?F*^X*%25<UBJEE!((QFJ5BM^6<S75TUW?0225P6C>E]QA9-7Y
M&$=/^-'RF=BL4)1=;=89'LQWHN(S0_>%AQ`>?B2M=)?88DPGJ[H>9W1G"=6,
M[D).H<+JU>4&5:^F`0$`.P`N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+VMI<FLN:G!G````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3(S-C``,3`T,3<S-C,P,3$`,#(R-3<W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!
M```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$
M$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ
M-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!
M`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'
M87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7F
MY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_H*\#_$SP/\`$KQ9X\\-^"]4
MTKQ!%\,?%NE_#WQAXL\.:II>H^'+7XH?;+BY\3?"[2;ZXUF#^W_'/A#P_P#V
M)>>+](^R:18^';GQ=X>TV37[WQ%;^+/#OA3\E_\`@K]=:]</\';.'Q!?>&=!
MU/\`9G_;<TK4/$VC6;ZK%J/C#4=3_9M\2_`7P1X9GLY+>X/CCQW\=?A[X4T/
MPYH\ZO>ZOJ=I=>#M%U26^O;A=)^\OV/OV>]'_9+_`&=OA9\)M/M;N/QA#X1T
M&^^,.JP3W]SJ7B?XT>(M*7Q?\0_%WB#6A>Q.^K75]K%AX<C\0Z]!J?B*PT+P
MUX2\/IJ2:;X/\.6NE_GO^W-\)?"/_!0#XXZU\/?'FM^,?AE\//V0-:M+:;4_
M!NI000_%[QK\2_"O@_Q'XV@\5:K=VMY!X;\*^`_`=WX0T3X;^)/['O;+6KW7
M?%USITOA^S\/7L=I_`."JY/PYFM7%8W%2IX7`4')KZK]85;VJ5&*G27,HM2<
M7!VDDW>2E%2B?W)@*.)S&MA94:M.,:]6UJO*X66CM>+Z25[--V2NKMO\]/V5
M_P!A/X??M'^`OC'\6O%7Q9E\._&GXT^++_7_`!1H/P1U_P`$WMM\-;W5?$MW
MXPO_`(:^)=,6[\5Z#X2TKQ%X@\*Z)\49_#6LR:5XCT23P[I'AJ\:W\>:%?7-
M?1?BC]E/X"_"'QIX;\*^,_VD/C=XS\1?$C5OB+XJ\"_`3PDO@7X;:CJ.K_$"
M2W\1Z[?MX@!\-Z/I7AOQ#,MA>:=X;\9>,_#VE^)$TOP\]G!K\NE:1-#V6F_L
ML?LW7'@/P=X&_9Z\1OX4\%?$KXV>%O$/C"Z\%?$3Q-XSN/%__"&?#WXN:_IN
MCK?7_C+4="7Q/"US<76M6=IXJTM5T&R_X3OQ%?:GXZM=7NO$GNOQ4_X)_P#[
M,?[0WQ!\7>,/B;\-[G7_`(B?$6Z@U6+QKX;\;:II_C/PE!H]K*VG>(OA1%>W
MWARQOK"U.FJ]AK6FW=]ICZ+=VH.@:I>&#5#^?YCQM3J\3UZ&*SS,L-E6.A.=
M"M'*$ZE&%N6$$W*,H0BDTE&JN1-R@N:I*1^LRRY8'!4HT*N!EBZ2YU12@E4;
MY=)**:FMY--2>BV;2?#>"/#G[/\`X#TW2?V7_&?[,L^G_"2]U@0VFA?&/1M=
MD^)'ASXC:OX+FT/P=JOB;0_$>A^*?#UYHGC/1?"EEX!\+>/OAKXH\=6^D>);
M;2_!NEV6@:AXUTOP]X6\`\4_LOOX?_:O\7V.GG]H3]H)OA1X-^'WB'X%66@_
M'/X01CX*_#:?6/$]GXU\(&U^,5QK.OZI;Z0]OIMYX-\#^'K74O"7BSX/ZO/X
M<\37FI:U\--.U^#]'O@ROQB^`'PE^)L/Q=ETKXV:M\"?#GBQO@Y\7[;4[/3?
MB?\`%#X.Z=X<O_B%I/@[Q7)?+HEX\NB/8VF@VEG<^,M3_MD:I>>*]<35_$?A
MD:EJGPM9_!:QT/1?V6_VP+W7_C;HG[4OQC^-'P1^,.J2Z]J0?X3?$[7/$FB1
MMI6G:-J_P^OM<U+2?AOX5^$WB9_@MX-U;PW<:Q9Z1IFJ>'?ASXZ\.'1]:\5O
M9].09GAZ53&3PW$>.S>A4E[!2Q*K2:JU)>U52/M*D)1BXI4V[/EM&$H>TE.<
M/G,7BL95@HYC3PU*M6DX4:,(**C9<UU&*LG**;=M=.9W22?H7B_]GSX#^.?%
MOBCQM(/VXKB3QAXBUOQ3)._@;]GFR>9_$&I7.K-*]GKOP,N-;M&D:[+M;:S/
M-JL!8Q:A+)=I,[%>2>)O^"PW[0'PR\2>(/AMJG[$$7C/4_A[K>J^!]1\8^&O
MB;XTO/#GBR_\)W]QH-YXE\/W<?@74([K1-=N+"35-*N$O[Y)["ZMY5O+E6$S
ME?:1H8V24N>&J3UQF&3U47LZZ:Z:-7Z,^:_L]]F_O_33KTT^X_HD6>SU#QD]
M[;ZO9:_::MJ:7T%Y9R6>HK)IFM_9]6BFN;]4:*>>WT[31<Z9J%NR:%J7A^2/
M4!`\4D;#^3O]I'XD^`-2\)?%?XN^*=8^.6A?'[QK^U[XG^&$WQ.\6V7P:^*?
M[)NGZ5\*/C=\2]"\%:CH.@:]H?C74=7T3X*?`>.?0O`HTS2++5H_%&J^(H==
M?4-.T32H=._I1^,WAJ_/P&^.'ASX>2Z=X:\3S?!+QGX8\#7]A;W.GP:"8/!=
MSX>\.P^1I9A3RH-)CM;+1[?2(H1H.FV^L1(L0L+81?@Y\`O%'A_XR_"#]D?P
M)\.?@Q\$M2TGXB^"+KPUI=I\6O\`A';S0/"WQ:^&'@#Q-KGQ8UN:SM-,^*EK
M9?\`"X[K6+35=(\4:M'H7B;4+N2]AO-,TR?5=:TZ;BP.=2I8+$YC5P=/$K%.
MA1E[2,)2?(IUHQ:J74N9PYE+EG&#@KVYDI:9)E&!K\]/$8C%4U2I*>'EAIS@
MJ=1N"DY..JCRZ:M<VO6S/JKXF_L[^%/V?_C=\!_CEIG[:7[5EM9>*O%\/[/W
MQ1\7WK^"/C7J$WPNU?X>_%SXR3R6Z1?`76](MK#4_&'@_P""&@7>M0:5JOAJ
M'1-=U"PFCGT_P_?7S^+^.V'Q+\=?!WPO\)/BWX=_X*"0>/;GQIXD\<G2O`7P
MM_9P^+OPH\<?#RST33/!WB_0OBIX8\+:+::/XEE\8^)-*LM2M-1T^WENM$\#
M^)[;4M8U*UFU)[GTKPM9_L]_#+Q#9^'OB]\`-&_8J\9S2I9^%O'>DC3/"WPZ
MU6<6ZZ%+HOACXW>!#HGB;P]XF_L_Q"V@ZG#XIL]$GU/2;F]\.7$=K8^+[RQT
MWH['QYX2_97\;:KXFTB_^&VG_LG_`!?\2_#_`,-:RWA'Q!X-70?@9XZTR;5O
M!/AKQ#HWA[P_?>&/#M_;?$B.>;PY)!I&B_V;X<US3]$\2^/?$9U'7=274/,Q
M7$F,KTN9</4\=.C2G3PL?J=*7M-'>'[M35XQJ0M%SM:+4KR<8/T9\,06)A7_
M`-:91<9+DIRQ53VL=(^Z[RYY+>RC=N6BLVDN+\0>/?VI]!_:A\)?%35?@A^U
MVOP]UR*UOM7^"(\0?"SX@?#G1O"7AZY\,6_C;Q)H%C\,OBSHOA_5?$"V_B'P
ME=:5;:W\.M=\0>)]0M[Q])F72=.L;2TZ+]G?]I33+_\`9G^'GPS^#G@I8?%X
MU/XP_&&#5_B;8:[X)^$'PO\`AEJ?QB\7I\/?CIKGBNWLX_'>B>'O%::YJNE_
M#W3O#OAF?6;W49_$^A6?BOX?^$(+;Q=J/Z8ZE:7%N]Y:FY:TGDNX9KNZTVWE
MAN7CM+IM6BO1<V*ZEI$FK0W8M;.WUB?4[+4(4L8[>"YM[=?(K\4/B[\!/@EX
M7^$>C?#?;XNU+X3:-JGQ-M_VJ_BAX6FOK&S\.>"O@_X<T3XV>)O!?CU?#%W:
MZ1JOB'5_`>G:!\*/V=O!?C^X\0_#[1/$/CZY\2Z!%I%Y<VFWY3A'BS+>(,4L
MKQ.3SP..PN,4ZF%HQG"%.G[U/FE2E)I2G>,$HN%W%QBG*=CW<TRJI@LJECJM
M>EBXT$YJNE[2IMS*7/;F=[:VYGS-.^FOT#J/_!.S1?B1J%]\1+?]J[X3ZC;^
M/;RZ\:0:A>?L<W6O7=]#XIG?7(KRZUQ;:)=:N;I+Y9Y]66*-=1E=KP1H)@H*
M]ZF\)_\`!1.TFEM+G_@HG^S]\'KFUEDM[CX2:!\)O#^M:%\+9X6,<OPYT36)
M?AY/+JVD>")%;PSINI2S327]GID-T\LC2ER5^RI96DE]2K::;3Z6\_+\7Y6_
M)'Q')MM8JO9NZLZ5K7C_`-.GIIW?7>VOZ4^&ENAK-M'()KN2.ZM]"OHX(!>Q
M6MS<7%HE]/\`9A;SV]E';VDM]IMY<,\MA=-J7VJZ-S#:Z_)<_P`_OP'O_AQ\
M*?V1/`C?%WQ%H7ASP1\'?'?QZ^%M]K&NBU_L_P`+7/@;X_?$JV_M+P^M[`94
M\82Z3KGAG0+.]T?0[L6]E!:QZ3)':I`!^:+?\%#/V[_B`?#MYJG[1/B'P]=^
M%X?[#T&3P+X/\$>$]-&K6`EU6\U77$\-:5J%IKEQJ&E^)-/TV;P_K.@MX;M3
M;:A;V'AS38[_`%&VF@^!7[1?BB_\80?LY?&'^P/BQX5_:V_:?\!^(]5N]<ET
M[P;!X.U3XF?$O0]-^)?B&/P5HL?PSM=6UCQ+J5]X9A26RGTKPUI/B.WO+RQT
M1;&PUZVN_&GPY0I8.MA:5>=?V<Z6)AAZ5249.%)2E4C23AI)QERIV;;348SN
MD_Z*P?AIQ7PC&6:9AA\)/+N25*K*I2A4@XJ_+*47%\R5V[VTN[M;GR1\2_\`
M@IG^V?\`#/XL_'NW\!^/]:^(7P)M/B!XGT"3P7^T5X=3]HKX;:=I<=YJUMH%
MCK-K\5U\9R37]Q:WLT%A;ZDWAY8VO)X&T?2?-FT^";X-_&/XW?MY_'#X?_LR
MO\&?V-/AO<?%34DN?&'B'PI^Q+^S-\(->T/X=:%I1\8?$;5M-\8Z7X4F\8VG
MBF\\+^"M6U&#6]*\4^![Z^'AS5+#0;V_.L^'(X_Z>5_9-^`6NZIXA^)^O^$-
M`TG7M=T&![_7/M&G:%HTFF:-:PKI&MZY:>.+R;X<67BNQTDV5QJWC;4O#_B'
MPEK$ECXDN+.>UUM-+T[4/BW1?VS?^">WPR^./QEUCP3:Z]\3?&UI\))=,OOB
MK_9NOZ_K/Q`OI]6(TCP1\)OAOJ&B^$]!T^PL6TCQM/XA^(D?A_X/:/=PQ:;!
MJ/B/6O"&MP:KK/U7#/BQE&;9;C\IR/@:>&S#+L''#ULPKX*G&-:K*<:"E[?V
M<6Y\_-.3<FY\RYVTW(_%.*.!\/@\U_M;$\15,*ZF(>(CA<+"I5@X2Y9<GLH)
MQ4(IKELN5R4H-W34?T@_8QUF5?V,_P!GRV\>^+-:E_X1[POXT\.Z3XMUG3LZ
MWJW@_P`"?&+Q[I/P^2XT1/"EKJ]EKNB_#3P[IJ7+/86>A:SIWA[68[O66U&%
M_%5YR'[#/P$\!_M":;\=OCAJ=CX^\0_"?Q_\?=?T+X7:)J'C;Q3'X/\`C'X5
M\+3P:EKGC+QK\._`>LZ_X0^*OA;QW\3GDT+1_#?C'0O$NCR^!O"N@S>+O#NC
M2V"0VGXU^+O'OQR^)'A?4+"\^$GA_P"'7P5\.?#/Q'\/OV?_`("^*?$OC2+5
M=.^$-UX3^&-OXAT'49M*CTJX\0?$#XL_!CQQX0\<:#XUC^):P>(_A'X9\=:3
M\/;SPOKVK^(_%UAUUO\`\%)?V\=5\#>$?#7@GQ;\.?V;_!WA2#Q9:>%['P1X
M`^%7C3Q4FC:AX@\:^)O"/@Z35=0\(:E\-_!?A;PA\-KS2?#.@^(/#FAV_B*_
M'A2TOM2US4]6U34K^^^=P'`N5Y=CL=Q%C:]'#9MFKC3G2ART_803=9.E&G-K
MFDI<E1QYN645'VDDW)_;9+PQQ?QM@J.5\+.MCL+/7%3Q.$G1ITZ+LZ=3GE!\
MR]IM'I'X5&*BE_8%%=ZS/%'-!<Z%<02QI+#<->Z1>M/%(H>.9KV31=2DNVE0
MAS=/J-^]P6\UKVZ9S/(5_)+9_P#!2K]MW[):_P!D_M&ZU<:5]F@_LRX7P!\-
MHEGT_P`I?L4RQZ5\((=+C$MMY3A--ABL$#;;.-+<1J"N_P#L]?\`0SQ?_@Z7
M]W_IYYK^F[>W_P`2S<:]</@[^FO3_ISZ?AVU_)+PE!!]CU!/)BV'6&N"GEIM
M,\MP!).5Q@S2!$#R8WN%4,QVC'H?P]5;CPY\?]2N%6?4?#OPE_:CU?P_?S`2
MWNA:KX.^$W]L>$=3T>Z<-/IFH>%=6N;G5/#E[9207.AZC<3WNF2VMS+)*Q17
MH8#_`)&?_<*7_I2/ZS\3?^2"J?XW_P"FS['_`&O_`(D_$75?V%/V18=4\?>-
M=2B^)/Q0_9PN_B+%?^*M=O(_'UWJ7PS\?Z]J-SXU2XOY%\57%_KGAWP_K-[-
MKHOY+K5M#T?49VDO-,LIH/M?0_#7ASPG#/JGA;0-$\-:E<V?[<^G7&H^']*L
M=&OI]/T3_@IU^Q#I>BV,UWIT%M<2V>D:9KVNZ=I=L\C06%AK6K6EHD5OJ-Y'
M,45IPO\`PZ?_`&'XG_TF1_%4?][Q'_7G#?\`J6C^>CX5>(=?\2^+#=^(]<UC
MQ!=Z%H_PAFT2ZUO4[W5;C1IM+^&>B>%M,FTJ:_GGDT^73O#'AKP[X<L)+1H7
ML]!T#1=(MS'I^E6-O!]*?&Z62+PSX@\N1X]_PFU2Z?8[)ONH_C#H=BERVTC=
M<)93SV:3',BVLTMN&$,CH2BN7BS_`)&^']:1_>?@;_R3?_<*'Y1/'#I.E,2S
M:9I[,Q)9C96Q)).223'DDGDD\DT445Q+I\O_`'&?JDMWZO\`,__9````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VMR>71O;BYJ<&<`````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`Q,S8`,3`T
M,3<S-C,P,3$`,#(S,38T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R
M`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$
M`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"
ML<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=8
M65IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JR
ML[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY
M^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$
M`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)R
MT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H
M:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BY
MNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"
M$0,1`#\`_A%N&B2]4SJSPK,S2*K["4#L6*O@KN4?,$R&D("*06!'[V?\$NO^
M"0_Q[_X*4Z+?>)O">N^'_AA\!?"6MCP[XX^,WB6RGU=I/$D-A::@OA'P?X,M
M;J/4-5U>6">-Y;J[F%OI[RF\F26TM9+23\+/#ZV\NNZ=]L@FO!)<M%;6=L-\
MTU[.'@M@8T(<+)=2VL29`625@B[R&6O]8W_@E_\`LG:%^Q3^Q3\$?@A:Z=!:
M^)H-$7QY\3]0BM4A?6?B/XZACUC6)=1R"9KS0[`:+I<$HVB!21"L;/*7_I#B
MWBZOPMD>.J8'$4UCLPJRH8>BW[R5&G1G.K)7349*:C!KF?-"3LE=/YS*LDHY
MYF.!PN+P\JF$PD?K-:HXITO>;A[-2LWSQ<$VO=5I+5VT^>/V5?\`@B#^P-^R
MUI6GVK^`=5^/7B^V%M=7WBWXSRQZQ;SZG%M:26S\$V;6?A?3+))-TEI%J6CW
M;[UBPWVA8Y$_1C7/@?\`!>\T:;P_%\'/AI_8DL1\S15^&>@0Z6?+4-&J16^F
M0V:*CHC(!&$W(I"[L&O8=8U5(4D<W;`B)V,CD32,\:EX59I?,=U,H0!6)4$C
M`K\]OVC/BQX[77K^RTKQ5JFD:;!#;V\6F6,T<*O(;<RS,SQQK/\`,%+X\PA<
M80*.!_,^=>(&<QJ3KYKCL9C*S4;*-:2IPA*,9JG'WE[L6V]D]6]+'[=P]PCA
M)UZ>`RS`Y=0@ES>VE2YIWD^[INSLEI?5[/J?)?[67_!-?X:^.O!6O7_PC\83
M?LQ^,+?3[PV.JVC6M]\/8+R8^7]HUCP5-=/:C3WB>6&>6TM8X[`2C4+F&YM[
M66"3^#7_`(*5_LE:_P#`/XS:M?+'X7OK2]T[1+[5KGP?JHUWPU=7EQ:QVU[X
MCTV\Q#.NF:OJ4$DMPDRLNG37WE1O%!%$L7]L/C76]1O[=1KE_>:S%?.\<]OJ
M-Y<7,8C8GSA,)I"'0H6RKAEYX&17\[__``4MTC29_'7P%\7W-OIM[I!O_%_@
MSQ/H-^TBV&L>%+$VNOWVDWIADCD-O);1WBV@#J(WDC@5A:EH:Z.#N,:O$6:T
M<AJ8=.GC^94YU)RG)5.5)N=VW&+2C:R>MVD>CQYP?5RCA^MFSQ3J5,OJ4W*-
M&$8QY)N,5&*25^65VV[>ZT]7H?@_X?\`VQ_VK_#&@Z)X;\.?&?XB:5X>\/:1
MINAZ%I=E>R+9Z;HVDV4-AI=A:*MHRBVL[&W@MX`&8"*-`"1S17IVK_`OX1R:
MMJ<FF_$SQ#I^G2:C>O86$'V>2"QLFN96M;.&0EB\5M`8X8W+$LB!B3G-%?I,
MO#+$\S_<]7K>?=?W/ZLO(_*8\18RT;8J"5HV3J2O:T?\OZOI\\_"O4;?1/B7
M\-]:OX'GM-*^('@W5;Z!0C>?8Z5XDTR\N+-R=RHEX1&'EF'DP^4I_>2,L3_Z
MJOP6_;-U#XH>+[GX<>/_`(4^(_@S\0M-TG5-2T^#Q!>1R^%?'^E>'+;PVGC/
M7?A[JWVF2?7]'\)/J&BQZC(VFK<))=SJLYBMU"?Y8WPY^$WQ,\<>"_BO\3_"
M7A6_U3P7\"O#_AKQ=\1_%:6TYTGPOI_BCQ]X6^&WABTNK_9]@&HZ_P"-/&.@
M1Z?8F87[PZ9?7]O$+>RNI5_U2/A=:?"'XP^"O#G[0<6FV^I^-8?@MI'@_3-0
MGL;6\U/P_+XB\)^%[?Q2FBW4\<\]I::WJEE:7.L):*D5Q]G+S+MWY\;QEGAG
M'*,90Q47B(8C,,-**FI4E[/"8:I&,K74:G-5E=/7:Z5D?1^'G)%YGAL;AZDJ
M#HX.M&4*3E-K$5YT^:%[+D_=.[O;1_$W8Y75?^"D/[%UWK%QX??]H/P%I>L:
M?J5MIE[IOB+^V?#T4MS)*^/L=WJ5L1<*3:RHKQD12-A5P66OFOXK?$KP[XG\
M1ZMXD\+:MI_BO2KZ8R6=_I.IP75BQ,#Q121RB&.,1A'YWC#+G&7((O?%[_@E
M?^RY\8--U)5\.:/IGC/Q3I7A?3;J[U75YM.U6QMO#U_!KL%SX/G=+DVUU-=V
MSQZC<PP"YNM.GO+.>=H)"J^9S?LI?!W]E+2H_">E_$CQ9XMOI+)YM?\`A]!-
M9ZS8:9##$TD%Y=^(=2NFU"Q\^9(HUAM8U1F98HXH2XD7^:LTEC,3A5.M*#G*
M,9.<9-QLHQ5FVKW26NGE<_H3(J.5TLQ<L"JG)*$5&%2FXU+I*+?\B4G'2T^J
MVV/$]1_M;Q.MU:VT>Z4I/]KD3]U90(%=U+7[@0QDLH4^40\A/E(0[K7X<_\`
M!5?X<7.D>&M*U&Q\3Z=JDGPI\;>'O^$_L[6UN8/[+M_B)8VUCI:17-\7MYGE
MN&B2Z!!#6OGX'-?M-J7Q+C\9:AH6A1PVGA;PCIFM6B+H>FI<-/?6\-W&\YU*
M[Q+=W9\N-I!YLLJQ.JN@C*!E_"W_`(*F_$9K>+Q?\/\`6[Z.TUW]HGXL:7XU
MGTN\N8Y(M#^&WPAMGT3P]$L1M5=7\1ZK=6\T9\Q+A4#S)(1$H'M^$\L34XPR
MI81.M6AB*:?+&3A%*47)MV5EK;K=>5SS/$VJL+PIG4,=.G2HXB@O8PE).K*<
M7I)1NXV>B5I7OTVO^5L>O^$8(TA3PWHTJ0HL2R_;P/,6-0BO@2`#>`&P!@9X
MXHKB(M>L+2**T'AC3&%M&EN&%M&^X0J(P=[@L^0N=S$LV<L22317^D"Q.)LD
M\*KZ7TI[^[?KYO[_`+OX;YYNS3JVTMIZ6_3\.VOG7P@_:C^*WPK^#7[2_P"S
MIX?U*./X:_M6>'?`V@?$G0)@BA=1^&?Q/\*_%'PCK]LIC,D5[IVK^$9-*D!:
M/9I^M7K964P>9_:_^P]\:)OVD_V*_@)X8\&6OCG0M>NOA_%IOB;7O!GC_1/"
MWB&'Q'X*O?['US1K'2M9UNWN+ZS\1)IL5_)>6<<=_;6UR\5I/#:EH6_B^^/?
MPCN-.UCX@>./#FG0:=9_#WQL_A7QUI7VJ)KC2]5FU:]TC1-3TZTD/G7.F:R+
M.);J4Q&"WO6@C#M)-,D?WA_P3>_X*`^"OV?;6/X;?'E;*[^&UQJ%[J?A_P`0
M77AJV\4WWAS4-0EMI;_3+V-85U6VL[ZYT^RV7MK>12:0SM?VS1QQ3I+_`"EQ
MOD53,_#_`!D\%2J8C&X3.?[=C4FW[6IEN+PN"P\HT+MN<G/#596;4&MIO9?O
MWA_G='+N(JM/,\5'#4)X">7.*A3G26+HUZLZ7M')JW)*HT[)R22]WHOZVD\-
M>*_!-SI\+>*/B]+XD"0V4/AWXAW.MW<VCK%*LEO+I^IW][JD-_YDJ(9)%NF1
MH2ZDM$Q1O+/BG\2OL7G3N]TNHZYIUK=:VE\L`ECN8H[BUGB$X037$+WZV]\D
M,SO%$81Y,:+E3Y5IG_!0/X/7/@^:]^%/Q/\`!U[::PLT,L.N>/M8\<6ND6DD
M#")=#M-6DN+S3;\.46WL[BZG6&X*(@!&*^0M3^(]CXVOX[RW/C;7-(MOEOKQ
M],DM-0N((C))<K8+/MLP%@>=K5Y8TCE?8)YT7,L?\EU7BZ4G1?UQNE)PG0J0
ML[MJ25N9_8E&.^_-ZG]4Y>J59*O#V-2B\/&2KTE3C%I1CS/FNG>Z<MMFO0ZW
MQ#KVK^)=.U$:1K6IZ'#%!+;MK&F2/:7:WDQ\J-K.>#RWB8R.B/Y+(K1-(L@9
M"ZG^;;]IG5_'7A_Q58ZG\6=6O/$FG_$BUUKQ'X!U35M?DU[Q%HG@?P]X[\3^
M#-)MYK>:::2W-Y-X<N+Z&.X/F74=VMU.9S;Q/'^G7[9G[<?AOX8>&H?A=\##
M:>)O&&LQSK"\>-3B\(1W"[+E]5N+17_M+Q3%;?:?M.DP^?I^F)OU!;EVM`C?
MBO\`"SXB[_%=WX5\;^'K#QUIOC=_#?A[4YM9MSJ7B'0="TG67O;FV\'WMSYE
MUHL<TL][)J#6MQ:RS6DEU+(SW*I*O[OX-4,?EN/EF#HTL-+$/V&%A5@V_;6A
M+VLG9M1?,HWBV_==EV_G3QCS7+<RIPR[#XBI7CAY^VQ?LZEX*-VG23<N;VD7
M#GY6E&S2;U;6_!\0/AL8(2=0O@3%'D2VN)`=@R)`JA0^?OX&-V<<45R>K>'O
MV<]/U74["S\1^.[ZTLM0O;2UO3I\*&\MK:YEA@NBB*JH;B)%E*J`JE\```"B
MOZ6>-XFN[ULLWU_VC$+M?_F']?O^[\1CB<K2BEE^,>B2?L%KI&S^+KH_N\K_
M`&[^V8B6^H?MBB!%@$OQ+C640J(_-6#Q?X+F@638%WK#--+-$&R(Y99)$`=V
M)_)^^9ELG*LP+M#O()!?,&3N(Y;)))SG)))ZT45\GC/^1#3_`.R5RS_T]C#K
MK_\`(UQW_8WQO_IZ)ZY\$M<UJQ\6^'K>RU?5+.!=9L'6"UU"[MX5=KH;G$<4
MR(&/=@N3W-?M;\9_B!X\CTOPO81^-O%T=CJ&J>&M/O[)/$FLK:7UA>ZMIUI>
MV-Y;+>B&YL[NUEEMKJVF1X;BWEDAE1XW9245_->8_P#(PK?]?H_^D4S^E>&O
M^2?C_P!>Y?\`IN)\=_$_3--TSP=\=M5TW3['3]4T?4])TW2=2L;2"TO]+TZ;
M6M)BFL-.O+>..XL;*6.66.2UMI(H'221&C*NP/YXZ.[Q:?XIU&)VCU"#P_IT
ML-]&Q2\AEF\0:=%-)%=*1/')+$[Q2NCAI(W9')5B"45^K<(?[QEG_80__2*9
M_/V?_P`?,O\`'_[>CTC3(87TW3W>*)G>QM&9FC5F9F@C+,S$$EB22222223S
M1117[:]_FOS@?G+W^:_.!__9````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;&EN=7@N9VEF
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8T,``Q,#0Q-S,V,S`Q,0`P
M,C(W-C0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA/`!'`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`S
MF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,
M``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`
MF3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9
M`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_
MF3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F
M`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,
MF6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS
M`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9
MF9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P`
M`,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQF
MF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_
M`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\S
MF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,
M`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"'Y!`$``-@`+``````\`$<```C^`+$)'$BP
MH,&#4%8<7,BPH4.&"0%(G`C@P,.+&!NRH,A1HL*,(#%N[#AQQ0J)(5,V)$G1
M2J"3`%3*)!B`Y40K5DP"^#A3I<V2,"6RZ)ERY$^21$,>M9D49,VE025":8KQ
MJ4Z*)G-&W4GU8DTKK%ZV9$762L>N#P.L8'7M6J";9-FRVHK680"P+N=*#&0M
M9Z"P'.LV#!#(R@&P,/^>7,LJL."%+'#N++5"A0HKJR8JIOAXX=VY*OZ,2C5J
MU!\5))RP*N6X<T$6`58!RI.J=FU5H_*06O6DM>N!-?^0:I:*&:IFR)&K4N7$
M]V]L&_.,(HZ*67+DJ50!<OZ;Q8K1J5#^5;^>2E1NCD.?"]R(9Y3QY.%%R1_5
M?.=B]>L!5)&>JMDH^7[X(5PI54CDTDGX07<`*:10(1J``9)2"C2KJ+!380`$
M@-]&@<@"R&QYY%$%(*60U999]J&D7@`!F,+**J6$^&$IJT#3UC6L',"1AMW=
MU4HK9*TBY"ILW7C-+"A2E-YCL`509)`OLB*+D6WIQ5U7'!H95Y%4'IGD1$NB
MM1$47'9I)HXDA=G41H2=Z2:.%IZ%94UKO7FFE7(F!9M'@5!I39E5;@D823P2
M9=0*?[5BI#5=;OD7*RANI6913P'PEYU4"KJ8CISU9!18F)KYIULE*=E3``?4
MU&>H;EIYE8K^*L&V49VLNFF625%-*M)3J]9ZYELZ!55H2`',"JBO6@855:R\
M(NNF-<J:&A*;M':I*++1EC0MBSL]ZVR240U[T:R6MOIMJ9V*Y!$`Q][8KIU?
M7LF05=4VZNQ;+&6T)Z[O.ML6ODBI2U&_SEJ#[U8Q8920$U20H$*_!/MI#33U
M*<EB1H&0LAP@ESWI;UO/A%RQ1"2PX%U&I8S6C"IYJ%!%NS:RNAS+':F51T;2
MP5>%"O4B:TUI-'=4Q7(762$*<M;YUQRB_EIC#6FIX$$"1RJ00AI#^^4A&G'&
M7#<*GU/Z:LTJI:7B!VH3J9"'*N4M)!HS24]G'=S(%6A@Q%3"6-K^?W@XX;<3
MHHTFRD)^-`/WX4E;UU\I<0(`*JMZ_U?:'X&7U@PJJ91RD"C%'6XXXM8%;6"M
M%)K'C'F2&V,,XJJ08A#GGH-.=W85KW"MF3&W!4TI[9U>FBBJ=_WYU07]\7GB
MLO<WBH4D6%'K*BOTOGKPS`CO^2BN#_1V[,EGE\<3@-QNYUPDM+<Z<JO3_;GA
MHVDND!_N59_T\8C7-F&H!I^D`ORR,].YY_X!Q$#X)[_Y=8]!N;M3DE1@.L2M
M[WC^&<5``,&Y],'-@J"+(!5*9"8@B25M!)R;<:ISN+T1)&==PV#_NL8<%3SA
M460)1"`BPA$G$/!XXK&.,5!7D#QPCCB!\T-:`=,W"JE-;2D2L>$HTH?!TF3/
M('_`0Q[\(!_478=^YNG;$9>2F@<=KFO,^`]&JD`%*59.;M@118@:QQ&$.:P]
MI8E;;E1"A3KBH8J2\X,6>7(1*5;1/'^@`E'(Z`0\1!$/?7-"2E3@(,K](0^"
MI,K?G.!"F:B`87BH8X*>$Q```#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VQI<V$N9VEF````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q,#8`,3`T,3<S-C,P,3$`,#(R-34Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`
M,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`
MS&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS
M`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,S
MF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS
M__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F
M9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QF
MS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9
M,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9
MF?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,
M`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,
M9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,
M_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_
M,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_
MS&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````A^00!``#8`"P`````(``@```(_@"Q"1Q(L*#!@P@3
M*ERH$``)@P\9-ARE@J`*BA(3`FB&$=O%9A4%D@"0<:"*9AQ5?.3X\&)$C0!B
M`EB)LB9*E:.:O41((J?-GT!1[D1X,JA1H0Q['C6J8B3)A$67!ATUU*)/J3\[
M%HQ)$^C%E5]'K4`(X"I0)V)5KLA)0@6`%8'&'NQJ<]035M>NL7HB%B\K*X&J
M"J0+<@7>O'H-(V8EERA0BG\17S-L)2^KD'/-UE2\V+#?Q@8)H[1[F/',%4VA
M:J98-*V*M1Q'C7K*DT3;FQ2/JG0KD41*V2`UU]2JL&?%F:P)RQ8,4>15U@YM
M2R\Y."M5ZA`UI\8^4*9FYAD!)`0Z[9,X=YFL&*.>#5XB5\\KW@;F[EQV3+CX
MZ6.3R;\_;80!`0`[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O;&]V96)I<F0N9VEF````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C(W,``Q,#0Q-S,V,S`Q,0`P,C,T,S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA)0`E`/<`````````,P``9@``
MF0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9
M``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_
MF0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F
M`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,
MF3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S
M`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9
MF6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD`
M`)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEF
MF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_
M`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPS
MF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,
M`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`
MF?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9
M`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__
MF?__S/____B_)```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"'Y!`$``-@`
M+``````E`"4```C^`+%A`T"PH,&#`A,F/$A0H4``UR)*G$C1X$)J&#-2:_AP
M8D&/!"E>`S"0FK.3*%&2'"@1P*Z7$$>^W!4SXDH`)E/J)!D3@+"9$'T"]?@P
MITZ5+%WN$I8L4B2ENVKM>FJSJ#."*0$@#?HR6;):3E_6&DMU94FM5XT9TXKU
M6$BER821'4NW[$64QH`!0WO2+=>H<ND*MEORY)X]`/0"V(/2KTRQ@NL2QKES
M;TK'CZ-&=AKT[DZ^SC`_C@R6<.'/ET.VA$R6ZLBBH(_V5;TZJE/79G%2CIVZ
MYNK;/1_J-NE6]FR6%9\&%TXY-._&-T76S(VQ>7'C;A?Z;GG7^G/H#AF64C^I
M]9CY[\X=J@^?L_QYX^G7KV].OB#\^/(5TK]_-'O^A<?P)]MY_X5GGH"7^5>@
M=@?R=YY9"^H'@'D45D@A1Q&J1Y"%'/J587[B(?2A?*R4:"(`)K*"8HDC*I1B
MBBN6&*.)([X(XXTSLI*AC3>>F".+$?*H(D$^$IGBCCP65&2.']J(XI,K_JAC
MDTY6>62+0F8Y94```#L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M86QE,2YJ<&<`````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,C<S`#$P-#$W,S8S,#$Q`#`R,C8T
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#_
MV/_@`!!*1DE&``$"`0#(`,@``/_``!$(`+X`E@,!$0`"$0$#$0'_VP"$``8$
M!08%!`8&!08'!P8("A$+"@D)"A4/$`P1&18:&A@6&!<;'R@A&QTE'A<8(B\C
M)2DJ+"TL&R$Q-#`K-"@K+"L!!P<'"@D*%`L+%"L<&!P<*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*__$`:(```$%
M`0$!`0$!```````````!`@,$!08'"`D*"Q```@$#`P($`P4%!`0```%]`0(#
M``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H
M*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ`0`#`0$!`0$!`0$!`````````0(#
M!`4&!P@)"@L1``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!
M"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)
M2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*C
MI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S
M]/7V]_CY^O_:``P#`0`"$0,1`#\`^J:`"@`H`*`"@`H`*`"@`H`*`"@`H`*`
M"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H
M`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"
M@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`)`ZF@"K=:A:VJDSSQH!ZM2N-1;V.<U
M3Q]H=@"&NE=AV6DYI&T</-]#G+WXOZ/%@0HSMW&<8J?:(T6$EU,>[^-$8F9;
M>U4J!_$W-+VAHL'W9RNI?&C4VE/D2QQ@<;53-3[1FBPL%N9%U\7/$5V1Y<UR
MJKWBC`S2YV6L/370@N_B#XIGMP%N;UU<<C<%/Z4N9E*C370S/^$N\2_W]2_\
M"6_QHNRO9Q[%:[U_6;P@W<%U.1T,LI;'YTKC44MD0?VE?_\`0/?\Z"@_M*__
M`.@>_P"=`%^'Q?K-LBI-+J,$(X&R=L#\`:=V1R1?0Z#1_'&KQ`-::M<,"<[9
M'W9_.CF9+HP>Z.Y\+_%"\BN2FM8FB;HR+@K5QJ=SGJ816]T]@TO4+?4K1+BU
M</&PR"*U3N<,HN+LRW3)"@".XFCMX7EF8)&@R6)X%`TKGAOCWXG"2_:VTR]B
M@A0X+%P"U8RGV/0HX9)7D>9ZIXLCOF:*35RTI/16))J+LZE!+9&796L>H1LY
MN;EUW?Q@K2*+8T6TWABI+>N:`+265NA)$:Y/6@!ZVL"MN$2`^N*`)515&`H`
M^E`"T`%`!0`4`%`",JL,,`10!GWNEQ3A3&3$RG(*<4`,M+R2&X^S7H"DG]V_
M9A_C0!ZQ\*?%)TZ_73[N3_1YCA2>QK2$K:')B:7,N9'NBD$`CH:V/-"@#(\4
MZ''XATHV$UQ+!$S!G,?5A@\'VY_2DU=&E.?([V/-I_@/X>6-C:,!,3D-+&&Y
MJ/9HZ%C)=4<3K7PA\46\\CZ?<6AA4X0+%R?>H=-F\<5![G,:MX0\6Z1&TEW*
M1&O4I;YJ>5FJJP>S,^WOFA_=W'GR29Y)B(I6-+H0ZS^]\L6MQG.`=E`RU8W4
MMP[B2W>(*>"W>@"Y0`4`%`!0`4`%`!0`4`5K^V6YMV1AR.0?0T`1Z->O*G.4
MFA;!^H[T"/I_X>:U_;?AFVG<@SH/+D'N*Z(NZ/)KPY)M'351B%`!0`4`-DBC
MD7$B*P]",T`4)]$TV8-YEE`=W7Y!2LBE.2ZF#KG@+1]0MV6.W6&7'RL@QBDX
M)FL,1.+/#?$NA76@Z@]M=(0N?D?'#"L&K'I4ZBFKHR*1H%`!0`4`%`!0`4`%
M``:`,6W<6^O2P[3^]7<#0![-\#]0DCUJYL<DQ31[\>A%:4WJ<>,C[J9[96QY
MP4`%`#9B1$Y'4`T`9GABZFO-)26X??(789^AI(J2LS5IDA0!R7Q(\/C6]`E\
MI,W,/SI@<GVJ9JZ-Z%3DD?.\L;Q2-'(I5U."#VKG/53N,H&%`%BWL[FX($$$
MCY_NJ318ER2W+<^A:I!$9);&=4'4E#3Y6)5(OJ9I!!P1@TBQ*`"@`H`P=1#1
M^(;*12,."I%`'I7PNN?LWC"R)<HKG:??/:JAN88A7IL^C*Z#R0H`*`(+Z40V
M4\K=$0D_E0-;F'\/;I;WPM;7,8(21F8`_6DMBJBM(Z.F0%``1D8-`'G_`(S^
M'EMK,C7-DP@N3UXX:HE"YU4L2X:,YNP^$MPQ!O;Q5&>0@J53-98Q=$=/H_PS
MTBRYN`UPV<C=5*",98J;V.PL]+L;*(+;VT4:CT6JL8.3>YQ&L>,;V_OKO3O"
MNDIJ1M_EEE=MJ*WI[TF^QI&"2O)V/-?&.G7RO+>7NC2:?(.7$?SHWOD=*SE$
M[*-5;7.6`.Q7P0K#(..M9G5<2@84`8FK?\AK3_J:`.W\#_\`(TZ=_P!=13CN
M95O@9].5TGCA0`4`4]:_Y!%[_P!<7_D:&-;G-_"3_D0M-^C?S-*.Q=7XF=A3
M,PH`*`"@"E/JEI!?PV4LRK<S`E(\\F@=G:Y=H$17:/):S)&<.R$*?0T`C#\$
M:!_PC^D""38UR[L\LBC[Q)I)6+G+F9N7-O%<PO%,BO&XP01U%,@\9FT&/4-.
MU_3;6)0VE7!\ACUVD9(K-JZ.VG4<9)OJ>9LI5BI&"#@UB=XE`S$U;_D-:?\`
M4T`=OX'_`.1IT[_KJ*<=S*M\#/IRND\<*`"@"GK7_((O?^N+_P`C0QK<YOX2
M?\B%IOT;^9I1V+J_$SL*9F%`!0!7U&\AL+&:ZN'"11*68DT#2N['(>"M.75K
MIO$]^C&YGR+=6_Y9Q]L?6I7<TF[>ZCMZHR"@`H`CN)D@@>61@J("Q)["@#C/
M`-HMT-9U49\G4IRR*1_".,U*-9NUEV/&O&=@--\1WEN/NAR1^-825F>G2ES0
M3,.D:F)JW_(:T_ZF@#M_`_\`R-.G?]=13CN95O@9].5TGCA0`4`4]:_Y!%[_
M`-<7_D:&-;G-_"3_`)$+3?HW\S2CL75^)G84S,*`"@#A?'DHUW4+3PQ:R*6E
M82W>#RL0/3\34O70UA[JYCM;6!+:VC@B4+'&H50.P%49$M`!0`&@#BO$6JKK
MFJ?\(YI<FY^MY(O(C3T^IJ7KH:17*N9G6V%I%8V<5M;H$BC4*H%40W<\=^-&
MBBVOX=2B'RS?*_UK&HNIWX2=URGF-9G:8FK?\AK3_J:`.Y\"JS^*M."@D^:.
ME5'<RK?`SZ:KH/'"@`H`IZR"VDW@49)A8`?@:&-;G'?"W5;&U\'Z?:7-U%#<
MKN!C=MK`Y/8U,7H:58OF;.[CE2108W5@>X.:HR'4`(_W3]*`/-OA;IR3ZYXA
MUNXD>6]DNF@#,?NHIX`J8]S:J]%$]*JC$*`"@#+\2WD]EH\\MI"\UP1M14&3
MD\9I,J*NREX,\/Q:%IOS`/>SGS+B4CEF-"5ASES,Z&F097B31+;7=-DM+M<@
MCY6[J?6DU=%TYN#NCYR\3:)<:#JLMI<*<`_(V.&'K7/)69ZU.:G&Z.0UW*75
MC*H^828SZ"D:'HWPKY\9V'U/\JN&YSXG^&SZ+K<\H*`"@`(!&#TH`P-:\(:+
MK`S>649?LZ_*1^(I-(N,Y+8Y6WTY/!GC'1K.QN+F6UU+?&T4LA8)M&012V9;
M?/%M]#TFJ,1'^XWTH`X7X4?\>VN?]A"3^=3$UJ]/0[NJ,@H`*``T`%`!0`4`
M<C\1/#4.N:1))L_TJ%28V_I4RC=&]"JX2\CYD\26D\D*Q1J3(DHR/3!YKG/5
M/1_@W;"?Q=`6)!BC+#Z@5=/<Y\4[4SZ"K<\L*`"@`H`*`.#^)7^CZQX4OH_]
M<FH"(9Z;6!!J6:T]FO([P=*HR$?[C?2@#BOA?;36]MK'G1LF^_D9<CJ,]:F)
MK5>WH=M5&04`%`!0`4`%`!0`DBAT*L,@C!H`\$^)_A>32M4>[MHC]DE.20.A
MK"<;,]/#U>:-GN2?!4'_`(2XG''DM3I[AB_@/>*V/,"@`H`*`"@#F?'-I%<6
M^F22KEH;Z)T/H<X_K29<'OZ'3#I3("@!%55'R@#Z4`+0`4`%`!0`4`%`!0`4
M`5[ZRM[ZW:&ZB62-NH846&FT[HS]$\.:9HLCO86RQNW5N])12+G4E/=FQ3,P
MH`*`"@`H`P?&/_'E9_\`7W%_Z$*3+AN;PZ"F0%`$-Q=06ZEIYDC`[LV*`L96
MH>*=(L$#7%[$,C(`.2:5T4H-F9_PL+0/^?IO^^#1S(KV4C33Q3HY\K=>Q(9!
ME0QQFBZ)Y)&O#/%.H:*17![J<TR22@`H`*`"@`H`*`"@`H`*`"@`H`R_$FD+
MK>FFT::2'YU=7C."I!R*35RHRY7<P#:^+=-D"VES:7UN,`+,"K8^M+4J\&5=
M3M_&^IWOEP3V6FV6!EER[Y[XHU&N1+N$?P[AN9/-UG4KR]<XR&?"_E1RA[6V
MR.C@\+Z/"L06QB)C&%+#.*=D1SLN?V1IW_/E!_WP*+"YF4]4\+Z1J<82ZLHF
M"]"!@BBR&IR6POA_P]::%YHLVEVR')5W)`^E"5@E)RW-FF2%`!0`4`%`!0`4
M`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!
M0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`
M%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0
M`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0!__]D`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]M86QE,BYJ<&<`````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-#<V
M`#$P-#$W,S8S,#$Q`#`R,C8U,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_V/_@`!!*1DE&``$"`@!.`$X``/_``!$(`+X`
ME@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'!P8("A$+"@D)"A4/$`P1&18:
M&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q-#`K-"@K+"L!!P<'"@D*%`L+
M%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*__$`:(```$%`0$!`0$!```````````!`@,$!08'"`D*"Q``
M`@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152
MT?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ`0`#
M`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1``(!`@0$`P0'!00$``$"=P`!
M`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:
M)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#
MA(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3
MU-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^J:`"@`H
M`*`"@`H`BN[F"SM9KJ[FC@MH4,DLLKA4C4#)9B>``!DDT`<!K7QJ^'6C726]
MWXJLI)&0.#9J]TF,D<M$K*#QT)STXY%`!HOQJ^'6LW3V]IXJLHY%0N3>*]JF
M,@<-*JJ3ST!SUXX-`'=:7J-CJUA%>Z5>6U[92Y\NXMI5DC?!(.&4D'!!'U%`
M%J@`H`*`"@`H`*`"@`H`*`"@`H`*`"@"*[N8+.UFNKN:."VA0R2RRN%2-0,E
MF)X``&230!\T?$;]J*Q6PNK+P'8W,EZV^--2O$5(X\$!9(X^2^1N(W[<';E3
MRM`'S%XE\0ZOXGU634O$&HW.H7KY'F3OG:"Q;:HZ*H+'"J`!G@"@#*H`*`"@
M#T[PC\=/'_AJ10FN2:I;!V=K?5<W`<E=O+D^8`,`@*P&1TY.0#Z(^%?[1V@^
M)Y(=.\4QQZ!J90DW$DH%I*54$_.Q!C).XA6R,`#>20*`/>*`"@`H`*`"@`H`
M*`"@`H`*`"@#X>_:$^-4_CNZDT/P]))!X5A?DX*O?L#P[#J$!&50^S-S@(`>
M)4`%`!0`QFP<"@!5;.!WH`=0`4`>L?![XUZ]X&UFW35+N]U;PZ42"6RFF+F"
M->%,&XX0J/X>%8<''RLH!]SZ!K.G>(=&M-5T6[CO-/NDWPS1GAAT^H((((."
M"""`10!?H`*`"@`H`*`"@`H`*`/#/VPM>_LSX5IID<EMYNK7L<+QR']X8DS(
MS(,]G2,$X(`?'4@T`?$E`!0`4`)0!&QR:`$H`<&(H`<K`_6@!U`'K'[/?Q3G
M^'OB>.UU*[D'A6^?%[%L,GE-C"S*`<@@A0V,Y4'AB%P`?>-I<P7EK#=6DT<]
MM,@DBEB<,DBD9#*1P00<@B@"6@`H`*`"@`H`*`"@#X^_;9U6>;QGX>TADC%M
M:Z>UTC`'>6ED*L"<XQB%<<=SUXP`?.5`!0`C'`H`CSGZT`)0`4`%`#PO'H:`
M%4]CUH`=0!]6?L=_$-YHY_`VJ31A84:XTLE54D;BTL><Y8Y;>!@G'F9.```#
MZBH`*`"@`H`*`"@`H`^*?VS+F"?XK64<,T<DEOI,4<RHX)C;S)6VL.QVLIP>
MS`]Z`/!Z`$/`S0!&22:`'H.,XH`8PP:``=>*`'JH'UH`"V3@=:`$VG'O0`N[
M@^M`'1?#7Q/)X.\>:'KRO*([*Z5IQ$BN[0GY954-QDH6`Z=>HZT`?I=0`4`%
M`!0`4`%`!0!\"?M0_P#)=/$W_;M_Z314`>64`%`#"G/%`#02.]``#SSS0!)D
M`9H`;RQ]!0`O"B@`&3["@!2H(H`;LYZ\4`?I1\*/^26^#O\`L#6?_HE*`.IH
M`*`"@`H`*`,OQ5KUCX8\.:CK>JR;+*QA::3!4,V.BKN(!9CA0,C)('>@#\VO
M%6O7WB?Q'J.MZK)OO;Z9II,%BJYZ*NXDA5&%`R<``=J`,J@`H`*`$(!ZT`,8
M8-``N,\]:`'$X&:`!5YR>M`#J`"@`H`_27X4?\DM\'?]@:S_`/1*4`=30`4`
M%`!0`4`?+'[9WC2^AFT[P7;)Y5E/"FH7,RR,&F^=U6,J.-H*;CG.3MZ;>0#Y
M8H`*`"@`H`*`$-`"%3V-`##G\:`#)]:`)%.1F@!:`);2VGO+J&UM(9)[F9Q'
M%%$A9Y&)P%4#DDDX`%`'Z?Z3I]KI.E6>FZ?%Y-E9PI!!'N+;$10JC)))P`.2
M<T`6J`"@`H`*`*NJ:C8Z382WNJWEM9646/,N+F58XTR0!EF(`R2!]30!^:OC
M/Q+J/C#Q/J&O:RT;7UZX9Q$FU%``554>@4`#.3QR2<F@#%H`*`"@`H`*`"@`
MH`2@`VCTH`*`%H`]8_9E\&3^+/BAI]T1(FGZ*ZW]Q*N1\R,#$F=I&6<`X.,J
MKX.10!][4`%`!0`4`%`&7XJT&Q\3^'-1T358]]E?0M#)@*67/1EW`@,IPP.#
M@@'M0!\<>)?V9/'&F>9)I#Z;K47G%(T@G\J4ISAV63:HZ#(#L03QD9-`'C>O
MZ-J/A[6;O2M:M)+/4+5]DT,@Y4]?H00001D$$$$@T`4*`"@`H`*`"@`H`*`"
M@`H`M:3I]UJVJV>FZ?%YU[>3)!!'N"[W=@JC)(`R2.2<4`?HA\(?`MK\/?!%
MGHT'S7;8GOI1(762X95#E<@87Y0`,#A1GG)(!VE`!0`4`%`!0`4`%`'SE^V9
MX/?4/#&F^*;2./S-*<P79"*':&0@(2Q()"OP%`/^M)XP<@'Q]0`4`%`!0`4`
M%`!0`4`%`'UY^R3\-+&STBS\?7-U]JO;V&6&VMV@4+:8E9&8,226(3`(VX#,
M.<\`'TE0`4`%`!0`4`%`!0`4`<W\2]&?Q#\/?$>E0VD=Y<W6GS);PR!<--L)
MC^]P"'"D$XP0#D8H`_-6@`H`*`"@`H`*`"@`H`*`/T:^"NGVNF?"7PC!8Q>5
M$^F0SLNXG+R*)'/)[N[''09P,"@#M*`"@`H`*`"@`H`*`"@#EOBIX@_X1;X<
M^(M96Y^RSVUE)]GF\O?MG8;8OEP0?WC(.1CGGC-`'YM4`%`!0`4`%`!0`4`%
M`!0!^BOP,U6#6?A!X2NK5)$CCT^.U(D`!W0CRF/!/!:,D>V.G2@#N:`"@`H`
M*`"@`H`*`"@#YW_;2CU>7P1HRV=EYVC17IFO;E5RT#A=D6>>%;S)`3C&0HR"
M0"`?'-`!0`4`%`!0`4`%`!0`4`?7G[%.O6+^%M=\/^9MU*&]^W;&*C?$Z(F5
M&<G:8_FXP-Z<\T`?25`!0`4`%`!0`4`%`!0!E^*/#^F>*="N=&UZV^U:;<[?
M-A\QDW;6##YE((Y4'@]J`/D?X@?LQ>)-+NC+X-GCURQ=\+#*Z07$0)8C=N(1
M@`%!8$$D_<`%`'(?\,_?$W_H6?\`R?MO_CE`!_PS]\3?^A9_\G[;_P".4`<A
MXN\"^*/!\C+XDT.]L8U=8Q.\>Z%F*[@JRKE&.,\`GH?0T`<W0`4`%`!0`4`;
M_@;Q=J_@CQ';ZUH%QY-W%\KHW,<R'&Z-U_B4X'N"`000"`#]$/`WB[2/&_AR
MWUK0+CSK27Y71N)(7&-T;K_"PR/8@@@D$$@&_0`4`%`!0`4`%`!0`4`%`!0`
M4`%`'@_Q]^#?A>\\!ZOK6@:19:3K&F6QN$>U7R(I(X\LZM&HVDE2V#@'(4%M
MH(H`^*:`"@`H`*`"@#5\->(=7\,:K'J7A_4;G3[U,#S('QN`8-M8=&4E1E6!
M!QR#0!]C?!K]H#2/%EA/;>,;G3="UFWR^^27R;:X3/!1G;Y6&0"I))ZC(R%`
M/;K2Y@O+6&ZM)HY[:9!)%+$X9)%(R&4C@@@Y!%`$M`!0`4`%`!0`4`%`!0`4
M`%`'+?%?_DEOC'_L#7G_`*)>@#\VJ`"@`H`*`"@`H`EM+:>\NH;6TADGN9G$
M<442%GD8G`50.223@`4`>\?![X,_$JZ\RYBU74O!.FW&/-?S9(IYMN\#]RK*
M3@_WRO#Y7=0!]CZ7:S65A%;W-_<ZA*F=US<K&)'R2>1&JKQG'"C@=SS0!:H`
M*`"@`H`*`"@`H`*`"@#EOBO_`,DM\8_]@:\_]$O0!^;5`!0`4`%`!0!?T#1M
M1\0ZS::5HMI)>:A=/LAAC'+'K]```22<``$D@"@#[A^"OP0TCX>>3JMY)_:/
MB9H=DEPW,5N3G<(1@$9!"ECR0#C:&*T`>O4`%`!0`4`%`!0`4`%`!0`4`%`'
M+?%?_DEOC'_L#7G_`*)>@#\VJ`"@`H`*`-KP9X:U'QAXGT_0=&6-KZ]<JAE?
M:B@`LS,?0*"3C)XX!.!0!^@'PI^'6D?#CPXNFZ4OG7<N'O+YUQ)<N.Y_NJ,G
M:N<`$]26)`.TH`*`"@`H`*`"@`H`*`"@`H`*`"@#EOBO_P`DM\8_]@:\_P#1
M+T`?FU0`4`%`$MI;3WEU#:VD,D]S,XCBBB0L\C$X"J!R22<`"@#[<_9>^&3^
M"_##ZUK-O)%X@U9!OAGB57M(0250=6!;AF!(_A!4%#D`]MH`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`YOXF6T]Y\-_%=K:0R3W,VDW4<442%GD8Q,`J@<DDG``H
M`_-6@`H`VO"/A;6O&&LKI7AO3Y+Z^9&D,:$*%4=69F(51T&21R0.I`H`^UO@
MK\$-(^'GDZK>2?VCXF:'9)<-S%;DYW"$8!&00I8\D`XVABM`'KU`!0`4`%`!
M0`4`%`!0`4`%`!0`4`%`!0`4`?GKXX^'&JV_Q?UWPGX8TR2]DBN=]O!:;I!%
M!(5:/>S?="K(@9F.`>I[T`>G?#K]EW4[[9=>.[[^RX.?]!LG62<_>'S2<HG(
M5AC?D$@[30!]4>&O#VD>&-*CTWP_IUMI]DF#Y<"8W$*%W,>K,0HRS$DXY)H`
MU*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"
M@#__V0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]M86XN:G!G````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`W,34T`#$P-#$W,S8S,#$Q`#`R,C0Q-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/XU;O[;;7!F/EV\:.Z.ZO&K
MB*:"6(NYD(1H"QC#/TA&]R1D$?KY^RG_`,$Q/CS\:_&OP0^&W@WX+:3\1_B!
M\=/!UCX_MK[XBZOXI\$>`?AYX3C?2O$4FGW4VG6D<E]XCC\#:AX?UC7+_4'O
M;.`>(=$LK:Q^V:BOVO\`(R],,LLEL9'`O+-H6\S$@:7]]Y"0P#,AEFG:.VE<
M`K':7$]P<):R,O\`J/?\$6_VA/"W[4OP+\,?M5W]CH?@;^S/@W\*/V9_#%KJ
M;Z1HEKJGCKX2:!8Z-\:O$'AN&5+=+G3]?\;W'AO1([VU>0F#2K;3Y9-\$:4`
M?D+\-_A#^RM_P3"^*&B_`']K+]C+X1OK-K+J%KX3^.?C7P+HWQ%\">,/APPM
M-6U'6O`.K>*-&N;M?&6HZS-?:/XVO?$MOI.IVVA6=O8V=A;+IDES/]=?"[]F
MK_@W4_:-O!/X;_97^"G_``F/B#4]6N+[0M-U?Q1I<<=Y->S7=F\PTKQ&8[+3
MM36:X_LR\T:SALX7D^R+`C1[E_1W]O?PO^R-\>/ACK'P7_:?\1?"SP_J5PR^
M)?".G>+O%5AX3\7::RSO%$_ANX%Y%JME/KD`M[.;44W17,D(MC&SPY/\U/B3
M]A#X!_`OX>:O\:_@1\2]5MM6\*^)[1_#'B[PWXOTW6=#TC0H-8BL]?T[Q7J=
ME_:?]N/:W4]QIMYJEQ)#>Z1"RW,EO#=:+9"<`_.K_@NQ_P`$;[?_`()_>(=%
M_:!_9VM=5US]C#XO:[%HNFK=RW>K77P3\?7$,]Y%\/?$.IR37MWJW@GQ7;V=
M[JWACQ#J$T%PVK6/]BJTC30B?^<:.XDB)\]OGX0NS>:Y=4"R%'C)#0&57,)!
M.8R"6))-?Z6/Q=N?%WQ]_P""0G[='PJ^/.CZ//JWA/\`9T^)?B=Y;,6TIT&_
M^'6F'Q5X0UZWBD@A,<)O['3-5MY+)/-L+N+7-)%PUO,B#_-IGLDN8FG\ITE9
M(9)$(+&/?:PRQ'S%RCF2W>&>0IQ%)*]NV)('``,G9*W(>`@\C(.<'GG/-%5"
M9`2`1@$@<GM].**`.POK.V$,I2<P)L9)BP+2&-D<3%XH\RW$:,;8+$P6.-I'
M</ND(K^W#]@K]EGXM?$K_@GW^S=^U3^S3X#\`?"/PYX8^$NE77Q(\4^)/$*^
M-?&*^)O@OXU\;-\3O&?P[3QMI]WIWPIL5M=&A\>>&&\&Z5JMQKGCB6>/6Y1I
MKV^/XE+^95#M!#%DC]Y.88L(\8DF@C#NPG`)21KA44HB+$Q/)Q_HH?\`!L'X
MT\1?M"?\$D/B)^S[XHU!-*TCP!X_^*7PD\+^*-.OWO=<T[0O&6E/XNEGO-$N
MEM_L5[HFK>*;W4M*DDG#:U;SA$C^S:3*[`'IG[7?PA^-O[0'B7]@S0_'WCK2
M+BY^)?[/#Z[K.JGPUX:T:;QM\2YYK3QEKWA47UOHKV7P]UW4_!5_:Z=X3\4W
M6CZWIEUK&ERP3:-IER\]Q<\5X1_8$\._`#X1_'/7_P!J;XH?#O7/A[\3OA9X
ME\&_%&)_"6G>'+Z;Q!K8U'0/`=U9:GX*1?#.K^++"[U+PUH::M9^&I-4\3ZP
M9-0:]GA^QV-EZA\7O$/Q;^%G[2]AX9U#Q!XE\??`SX,:)X)^&>C^"O$&@Q^!
M;R)]#\&V,<OCCPUKYU'5=7U6#3[6&VGDU[S8+;Q=XEO];33XGM$MGF^Q/'_P
MP\!_M+?$SP&_B-)=:\`P>!-#\6V6AZXQ&E:1<G[58:P=*MXGCAA\6W$173]>
MUZ[674]*@MOL$-I#+'=RQ`'\MG_!/[]HWXL>,/V?OVV?V3?BQ+XF\,?&KPC^
MQ1^U-:Z5_P`)GI]Q8?\`"W?A?X8^'OB?3]"\2V(U"UT]_$-@EEHTEK'XCL[6
M2VNFL3(92ZLU?R"Z8LDEOIR*K%9+"WN4\QC\Z?8[?S@"?]8L<S.-P+`*T8.!
M@5_61^U'^W/I>F_M"_MC_MZ^*/@NOA_PMI?[,VL_\$\_V'M`U#7;N0_$#6/$
M'B/Q7\-M<^(E@]MHQTT:)X/^'\/B+6M8\/W$L]Q&L?AW2,%Y(9;GYK_X-VO^
M";GP$_X*-ZM^W!X0_:!\/W&I^%?`7P!\">$_!OC+1&BBUGX9?$+Q3KVJW-GX
MY\-7,$4$$OB/2]&\(0QI87L;K=:/>W]E(!.X,0!_-O*T:R2*6LD*NZE&NX59
M2&(*LI<%64\$$`@C!YHJ+XFZK-X$^)/Q!\$65Y<:]9^#?''BSPK::Y`VBVL&
MM6WA[7K_`$B#5H;627S+:+48K-+R."3YX4F$;?,IHH`VC/%=9G#%)7MY(-Y^
MZ2625<1X_N)<1"3!RTZIG)Q7]=?_``:E?'#X7W'BC]L?]C3XN_$^[\!:7\6M
M&^&WQ4\#:(OBVZ\"W7B6Y\#W5WI?Q!@T7Q393Z;>VT][8PZ!_:FF6VIQ3:EH
M`OOLT:JMU-7\A$KJ;E8U(*,64;`.-JM(RX&<%45Y#Z(&<_*IK]R?^"%__!.S
MX4_M]_%/]HS5?C%\2/'7PIT/]F[P%X1\3>%_%7A;4O"^D6*^*_&VMZOX?NM-
M\37'BY9;2?2[CP_:79_LZR&G&YD=+C5=3BM;2SV`']:?B_1OV'KW1/C1\0?'
M/QD_9(^)WCGPYK^FZ/X4U#]G&\\;_#;Q[\/T@\3ZA)I4OCOQMJGQ;\777C./
M2=.LK6RO=*NM,M;.74)-7NFMXTG=F\N\9?\`!1W]G#X&?LR:%\$?@K\5=`^(
M/QPU+P5JUCYC>-++Q-I_PSM/$%SJ45S\0/'/C%9_[&N;K1X)]5U71]`6]%[-
MJMY#:NCR+'&/Y$/VLHU^`GQF^)'PL^(7QXT[Q6O@#Q7<Z%H6M^"-6BUC5/B3
MH3Q01^#?%LLVASRZ;%HM[X.M]+NYS%)>::E_>7D=A?2HR$>M?L?>(_V<IM<T
M.6UB\.:G<ZB)GBN=7T%O,N6M;F/5+JUDU+5()9+-K2WAE807!%NTTLK1H3(]
M`%_]J7XZ_"'XB>(/A)\.K;P]H7Q*T']G*P_:<_:&^)_A74[[7)_`&NZC%X53
M5/!'@:[O=`U33+N;3;A8-`77+73M0M(M82_>U@U*.X>]CD_J9_X-PK?QAX9_
M87\5?M-?$?P_X+T'Q[^VCXL\26WPJ\*?#;P3X<^'GA+0?A1\!_!6M>'?#UIX
M5\*>'['3Q-HUEJ>G>)+HWEU;7>JWMQ<W%[J6I7\LK7MU_*E^T7^R+\:?&7[4
M?QKA^%O@;Q!XD\/_`+:_Q#^$'[-_P,\?:#X=FF\`3WGQ1U?P[>_$#1I_&-EI
ML/AG1-2\+:%X4.F:I`UWYD5EJ&I"8(=/NU@_KP_8J^(?PN^'G[75IX8\.ZU&
M/@%^R[\&-,_8N_9HT#3C9VMOXIE\+V6AZ/XQ\;V=M%,-/LF\>>+HY]0UKQC=
M;H?M%W8V+7+RZ_:QW(!_F9>,I-,U3Q?XKU/5M4-MJNH^)-=O]3M[RX@M;N#4
M+S5+JXO8;JVF9)K>YBN9)$G@E1)(95:-U5E(!7I/[1G@31M)_:$^.VE:/K?A
M:XTC3/C+\3]/TJ>"\M;^"?3;+QOKEM8S0W]M-);7L4EK'$\=W;R207*,)HG:
M-U8E`'-:N2GA?7KM"4NHK/26CN5)6XC9]4:-V288D0M&JHQ5@6154Y4`5][^
M";R[T+_@FI^TT-$NKC1QK'Q#^$$VK#2IY=/_`+4FLO`.K2V4NH_9&A^VR6DM
MQ/):O<^:UO)-,\11I'+%%`'YPV[,UWXA0DE+:'3TME))6W1F:1E@4\1*SR2.
MRQA07=V()9B?NO\`9)M;:'PQX@O(;>"*[34(REU%#''<(7GT@.5G11*I8<,0
MP+#@YHHH`_MG_9GN+C3_`(0_L306$\UE`FG?MJ^,EAM)7MHE\7^'?V.O&\GA
M_P`5K'"R(OB30I+N[DT;7`!JFF/=7#65U`TTA;\IO@U/.W@CX9P&:4PZW^T]
M\(_#^LPF1S%J^@W?@[Q)K-UHFIQD[+_2+G5[B?5;C3;H2V4VI3S7TD+74CRL
M44`?RP?M0Z-I'A_]IC]HG0=!TK3=$T+1/CI\6](T71=(L;73=)TC2=-\?^(+
M+3M+TO3K**&ST_3M/LX8;2RLK2&&VM;:&*""*.*-$!110!__V0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M87)G
M92YG:68`````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,34W`#$P-#$W,S8S
M,#$Q`#`R,C<R,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S
M`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,
M`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S
M,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,
M,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S
M,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,
M9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS
M9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,
MF0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DS
MF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,
MF?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8S
MS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,
MS,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S
M_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,
M_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(?D$`0``V``L`````"``(```"/X`
ML0D<"*"@P8,($P(8R%`@B0$0(TJ<.%'`PH8#'U+<2#$`QH8!.(J$*(#$1X<C
M1UH\B4UCRHT>66(+N5%```$0;]HD:?(D"9P4!:P8I0*`BE%&1]T$T//DS8E)
MFQ$=-17I2IDS)0:@ZF34"J-#O1K$"H"B"JE/6%V[QFJ%"E9M_S3]Z)+DT15J
MU[)=L9:5"JPS@0X(\*>H7KUXK;!B"I@FQ*-OK>AM"Y?57)\2!=S-NQ?L9:=`
MHXY*R_;)J&92/SL=`.`T:JENA[XF2N*O3(U&7Z-V_5K%T=2W(;8>Y63W[]FG
M:6-]&N!X4=_0F9)0_5$GB=Z\J5*_75#W;!7;`4U?]][,-F"6X[V'%T^"]^OI
MY^E"JNV^&0DVZWV2@#0?\E'&\6$TW7Z0J,!?4?@%R)!L1/FGG((#G47>;OE]
M=%1]LU4(4D$D,*7012<%!``[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+VUA=6PN9VEF````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P,C<`,3`T,3<S-C,P,3$`,#(R-38Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y82``(`#W````
M`````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`
M9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`
M_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S
M,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\S
MS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F
M`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]F
MF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F
M_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^9
M9@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9
MS)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,
M,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,
MF9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____
M``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_
M9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/__
M_P#__S/__V;__YG__\S____XOR0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```A^00!``#8`"P`````(``@```(]`"Q"1Q(L*#!@P@38EL!H.$*A1`),FQ(
M$<##B`DG5J1X$6-!C1LY>I18<85)DR5'"BP)B41+2"!53C0)Z24)6C!GCJ18
M$PDD6D`A^81$T>/,FT*!TO))BX3.B`X!_&2&2BDJ9C@M-HPX$X!+9DZ4.F'6
M4JM%B!P;NOP9M*Q9`&@=EB5Q$RA=KS"+9N18DRW.MC4U=C184NU/NDA)1-5[
ML+!:G#6;IF5,>')DETB)OH6+<.-$S#874R;I^:3IDR$'#PS)NG7%QJYC;S0(
M4K9KDRIS*YQ=%*[OW+^#8Q.N4GCOX<B+KT9N'/CRX%M'ZYY.O?KT@```.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;65L
M;VXN:G!G````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3(Q,P`Q,#0Q-S,V
M,S`Q,0`P,C(W-#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(`
M`A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1``
M`@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152
MT?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`
M'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%
M!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D
M-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`
M/P#X&_:T_;4\??M/?L__`+.OCWXTZ[:7.OZ-\3_"$WQ0\0Z"OA5?%6H6`UK6
M-,\1Z?X?\::79PZM+IT%DMCI^BV,-RD5Q*+J2YA%Y<W>ZCXJ^$'[4?[>?PO^
M(/[.#;/$GBSPA\6/A?XP_9U\7_'G6O!_PBM_"W@2XM;;P_J"VFJ^)=8L1JMO
M=^%KN'P5JMCX4TV\N]3T_P"'6A?VA;7,VEVL4/U'^Q?^S5\(_#OPK\'ZA=_`
MCXH_M(V\VMZK?Q>,/&6A_!SP-^SG!8:UJL/C+1=-^"?PX_:!\0IX]\6Z-I.H
MZS=Z9X9^+&H:+<:UK*6<FO\`@Y]*TRZ2W/Z+>/);70O!MG9_&?P#:^&_"_B?
M58O"WA;P)XC^)_C']H"_\8>()Y[J"VL+'PYI-UX-T:S-G<7=\6U7X87^IW%A
M<7%VTHT9'NM0D_S;Q/$V2<+YMA\OR2A@\1F.2YUF&/P>,G14ZF`@\1'$VC9O
M&4(.-"OA:^&JRC?#UN6I3=E*/YG2S##SJ4J4ZC515(RDN:5G96OT3WNI=S\'
M_P!DG_@@?^T-XQ\2_$+X?^./VG_AU\#O%?@^WU'7]<TS2OA;\9O&'B&_\,P>
M)9]$N?$O@R^UBQ^&4>J:=9>*/M&FH@F2#4;BT?68)K_P_=V&JW7V5HO_``29
M^*^D^/\`P[^S7=?''PQ^T#X;_9]U75AXUN;+2-6^%/@7PI8>))9[_P`.^&?B
MG\0Y_$/B+3-.\1>--4U*.\U7P#\*%^+OQ1C\-W]K>Q:%X?T.XMH[/]Q/B5\0
MY?AA^SUXKD/Q2UWX>>*?A!X"'CKPO+\0(K_XN>,?!>B&TL/"^H)%HYTO7=1L
M/A3XSOKB_P#AK=0>/M:\16FF/;VFH::?&^N>%3+I/`_`7Q5X3^`OPHU;PI;;
M?B5X1U'X@>-O&UYKOAC5O'>C^'_$^M:I#I.EW.K>)=$TNVL-9U6&UT&?2M.^
MS>(WU#2E\*6VBZ=X=\J\O-0G;SLY\:.(<Z>(>)KY3AH8[%QP]#!1P5*%*MC,
M/'F^L1Q$J:K8V"I5FY495[PJ.C--.$;^].CE.-K4Z->JJ<:MFN5V<JB>EU'3
M5\W,WJU\C^5?]M'X1_M]^#/BG^SE\-_VUO@/X+^&OP:\&_'GPQI_P_\`&OPB
M^`OP-T[X5VG@32_&$LFJ>&O#?[07P@\'6^I^+=$M-,>VU"?1/BRESJMSK^G7
MU_XPM8_%-IJSI<^%_P`;?$K_`+-WQMU.P^+FM^`/&GQDO?CMX[\>?$.WM(PK
M"[UR]T#^T8O[-%C;Z#JGBCPKX2TO1HM1TZ$7,T%SKOB*)FO38,W]<OPF^*O@
MCQ#JFL>!=,^$_P`/_'T'A4G3OBAX=^%2_#^/4_#]IJ-E)-I]KXO^`7Q0DL]8
M\)Z7=Z!J4#7%K:-JVBM%>33VL7D7J+7Y,?MS_P#!//\`9?\`B7IMO%^R];^#
MOV4OBO;^)M+OM%^!OQ>\._$/X3?`#XIPVM]/K=WX0\%:CXGT;6OA=X)\4>)8
M=-M+CP[<^'=4LO!_B?Q?)+I@BTR_67[-]7E'C%@L\JY7PSQ#DKR2MA\SP-2.
M882+EE^)PD:L<17C4I8CFK4*%:I'#5)*7UFC4E3A*=2RIV\[.\IP5:%.G0G[
MF'G%)IJ[DD^J24KM:IZNT5[SBCM/"_\`P5_^'EAX9\.V,/[3N@^#X;+0M(M(
MO"5S\2-'L+GPM';:?;PIX<N+&W\/""RGT14&F2VD`$-M):M#&`B+17\I/B[]
MJSXC>$?%?B?PIXD\7WFB^(?#'B'6O#VO:-X@^$HU+7M)UK1=2N=-U33-;U%=
M;F6_U>POK:>UU*]66475Y%-.)'$FXE?O<?#7`249*G4:DE)-0A9IJ+35J#5F
MNS>^^NGSW^K]7I[1K3K+;W/^#^/F?T7^%/VVOA;\4/AEXI_::U>3_AGWX\?$
M/4+_`.%/PM^+>K:9JWQJ_9_^&#Z+J^H:#X5\)W'@B?0=9;P?#XRT_2[SQ5XF
M\9Z=H'B5M6U^X@TR[N[=--AT^R];TO7[;_@G_P#!OPC^TCXVT36O&'Q+^.^O
MZYIL'QG^(_Q$U7XHZ7+X(\#>#M1\6^'?%6J^-=`%MK5_X/\`B:^C:OJT7P-T
M2X\&>(9]7\3Z%X(\<^*M.T?0YSX$_%/X8ZE/HGP#_9-L=<72+>`_'._O=9L]
M0M[==(6QT7Q7\</%.B6@BE3[-90Z=XGNX_L-H$6.WU"S@N[=8YXTD'KGC+]L
MWXW?#?Q1\/[;P/9VOQ(\-^)O%'B32_BC\&_B)'_PDOP3^)U[XL/@J1+?QGX5
MUMKO3I_%]AJNF7VI^'_$=G8R7=I/;VM^)UOD>6OSO_4KAC.<7#*ZF%HX##U\
MTS7$X['T*DG4JY;E,,1A,+@\0U:O]7ISPTJU2,97<XT^=24IQ?E4L/[RI?%4
M55U>=M\UDFM)-\S2<N]M-5W_`'NA^'6L:C^QG\6M`TSQ7\8_C_\`$']I?X4_
M\+.\26,6F:'X>\4:KX@^)^@V6F67@W0?!O-SX4L/`_@AVTRV\*^)9+Y](MS?
MV^GB.QNO+;W7]@7X+?$_Q]^R]H>C^(T^-?B_4-"N_%G@5=8\;7'@&U31](TD
MK9Z-X>L]0O+"WUCQ)96.CS6>B:C+XPUO5+RVO[6]\-:2;+P7I^BZ=:_`^C?M
M;>%="U4?$?1?$=Y\*M!T_6[+Q5),E[=BV\)VVE:G%;ZUIUCXA2=#;VUW!$^A
M6$B")VL;@V,QD5I0WF'_``3[_:R\8_##Q1\:?`/[0_QPUR6W\</8_&'X*^%=
M4UO5KI+J[U+4;S_A*M.\&ZI;SB*[NM4\)ZSX6L]62^>.1M9TJ]T]A)'I\2K_
M`#KB>$\SQW"G'RK86KBZ679[A,]P>,]A"C2C0C*="5#*VJ25&A&@L/*NDJ?M
M.5-[*)[>45*4Z5:G7DVZ=9.,T_>BU%V2;NTKRV79+K<_4/Q-^S/\,-1T[4;?
MXFZ3<S^&O@W\1I?AO]A^$%Y-9_'_`/9'UW6I-(UW2=;\)^/-.UWPSK6G_"V[
MT3QAX*\3^(/"M[XL\9>&O`<?BR]NO".F:3\._"UQX8TXTW]H[X1?#?PG\;/V
M8_VD/'/P^\;>(O@_XBTSP3X@U#Q:UGXY\8?'?X,>+]$M/$'PO\7?$(0Z'9:+
MI]YKNFW>I^#_`!@VGV`GT[Q)I5U<F6]<-J-U^:'[5/[;7Q+\0?%?XZ>`O#=[
MJ?PU\"^(?V-].UN"ZTZ,6\GQ)\2^$=;^(NBW?B:XAM98Q:Z]IVBZIIO@C^VI
M@U_+H/AS3+%;G^S;>SMX_P`L?%'Q"UFY_:0^+OCJ+5)KVU\5?L^?!'Q#?Z-(
MNE/<ZGKFK:9K\^CO%J=Q%+*MR8EEFDE,K3M-=W67._`RCP/G/%&55\'CJT\'
M@Z.64,YRS$8>4WCZ>,GC\EITJ7UN"YHT9T<7B%5H<W+&K3:JWE3N>G+V'+)T
MJDI2N[\S;;6U];K2UU+W=&[-WL?MY!J?PJTR"'3?!_[7OQ'\+^$M/BCLO"WA
MG_A76E^(/^$=\.6B"#1-"_MZ^62]UO\`LC3([73_`.U[QWNM2^S_`&RX=I9G
M)*_(G2?'<U_I6F7T]W?V4U[I]E=S60N-&Q:2W-M'-):C$&,6[N8ACCY**^CA
MPMQM&,(_ZSYT^6,5_O.+=[**W536^NO6Z,.>?\TO_`G_`)GSYXITW0]=^$7P
M8\-))IVI:,OB&RTSQ;I\MY9W6GS^,HK_`,8Z9XMUFPUF*&+5[65/%K7^K:6M
MO*)+1-5*1.A=BWSU\<Y=?D-CXABOM3M8/`VM^$]5M]#T'3C=7]SK^O\`B>Y@
MTJYM3?S37XU?3(M-M--M;%HOLMY9WLUV^7U*X\S[/U[PY'8^"]*M]4T#28X_
MAO\`&?5H=2T9X;>_N)95^)B6=I':ZO+IFGR3_:;'Q!I<US.MLBWDA$S278V7
M4OSA^TKI@\+VUCXCM[S5=,\3^==7MA;P6<>H&_M_"$4WC.Y344D!B%AHCZ;=
M7SZS+NU.*8RV5HPAA11_1U"G&CFN7M4G.57$9PZ<(_:>(E1<T^52TDE-R?+*
M[;E9NU_)H)<V%=E=QLW;?WDM>Z\NQ[=XGT&?QS;>);#3KJ\-K:Z5?ZK8^%Y)
M0/"GB>_>;3TT/3/'.A1)#:ZMI6FSV(NYO#VI6MSIFFZLMS%80)%%$3M>'-1\
M5:9\:==\/_$#QGI7Q*TN/X3V/BJQNK+2;31K3P#XWT[7/#.O:IX;\.6K0IJ&
MB:/I&EZW:WES<H8[7Q"^I-I@\ZTL(8(MOX62Q7>FW?B&SFTZ9?$.EZ5JOVFP
MB\RPF6_D%ZGDQ7,>=-MI'G,JP7D9BA+G8BQ[17@.O^*M?F_:?\7P:W?"\NO$
M?A&X\-9DNFOX],L=(T/PMK^A:-IFK:4UMI[SWDFCZA?P6EC%$UI-/-#*KWD=
MS(_PN$GCL=A^*<BFX_5(9=F&*=%W3IU*%:BU%1NE:*YM/ANV[;6Z,/%*=9I)
M?O>RZ1?]?)=CLO%/Q#\5O\>FN/&.F:)+X2\:_"?5/A9X-&DZ[;7%_P"'])BU
M75?$&O07;/&;'Q!J#7*70GL3$MM%I%UI^GWF^2W;'R_8:OXUL[+PMI\C6$.N
M:]\$;>ZUR>"XNIK2UTCX1W6E6G@]8HKN1WMM9N;:_O+;6(XML4>LSZS':A;:
M8JW;>(CJDWQ<^&"W0L1HR:/\1+#[5/->+=O9:A_8T6MW%]%(TDC:B;:2"S2>
M5FFECDNLN4G=3Y5=MX@UC2=.U?0;2SW6OPH\?P:M/?3W=M<630_$Q],CM[.1
MML@CG,'VVQB1@B0W$9C"@C/WO#6!3R_+:$J5/]]E-*F[04+/"ULPPL;N+5VY
M48U))KWZD5*6I[U&C&HHI)7NNBNU[MU>VVWHCZ7M_$;B"$+>6X`BC`!L5R`$
M7`/R=A17KO\`8/A*#]Q/=:5%-#^ZFB-I,3'+'\DD9/E<E'4J3WQ175_JY4[S
MZ=_[GGY_U9'K_4H]H_\`@,?+R_JWI?T#XRR2?\(+\8'\Q]]KK'P1NK5]S;K:
MZNO"W@2\N;F!LYAGN+NTM+J>:,K)+<6MO/(S2PQLOCG[7\447@.2ZBBCCN6\
M3^'(6N(T5)S%J>A);ZE$9E`D,>H6]U=07R%MMW#<SQ3B1)I%8HKIP_\`O^!_
M[&>9?^E2/SK#?[Y1_K[2/;?"*K:Z9K;6RK;MY?AR',`$)\I38QK%F,*?+6/]
MVJ?="?(!MXKX:^)$:77[4/CJ.Y1+E-/^(FGRV"3J)DL98/A*[02V:R!A;20L
MS&)X0C1EF*$$G)17Q.1_\C[C#_L39O\`^D1/5PO\2M_C7_I!V&IP0+XO^"+K
M#$KW=AX[DNG6-`UR[:)H5TSW#``S.UR3<%I"Q,Y,I/F'=50_Z1H6@I/^_2X\
M!?"-ITF_>+.VI?&#3;;43,K[A(=0M@+>]+AC=0`13^9&-M%%?9<+_%DO_8-6
M_P#5ECSV</\`Q(?XH_\`I,3]D!X0\)S`33>%_#LLLH$DLLFB::\DDCC<\DCM
M;%G=V)9W8EF8DDDDFBBBOUM=/E_[C/I8[+T7Y'__V0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+VUI8BYG:68`````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-38`
M,3`T,3<S-C,P,3$`,#(R,S<T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P`
M`/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`
MF68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`
M__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S
M9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PS
MS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F
M,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QF
MF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9
M`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR9
M9O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9
M_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,
M,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,
MS&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_
M`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_
MF6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S_
M___XOR0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````A^00!``#8`"P`````
M(``@```(_@"Q"10(H*#!@P@3#EPX,*%#$A!)Y)F8!P!#A@X+(HD(D:)'BQ<)
M.MP8T:/)@B&Q9>0HT>3'E"LYNGP9\B'+F11!7DS(LB/.BC`1]O0Y4R=&G@`"
M%%1:\.1!C!LS(KR6D:I.`"0A2MWZE&">H0:D2B3AL.'$@BS%?B6+T&Q%`#W#
M\IS(UN!"`&?1RGS;E&C7NSE[NFQ)<^=9P3]SIE2YE"42IW`5+V8<X.;'@@8D
M+SXHF*U6O$`GPTT:%\"<TZ<KAMY<=VC6QU\G$_P,-RU<V*M9UZT=$<G!L[+U
M[JZ-6_-FWCR)`A<-@&K4Y#Z-UFQ^C2KMARB/%ZQN??A)Y@>Y#&<LO-.A^(29
MEU\,"``[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;6]N:V5Y+FIP9P``````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`R,#,Q-P`Q,#0Q-S,V,S`Q,0`P,C,Q-#(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````_]C_X``0
M2D9)1@`!`@$`R`#(``#_P``1"`"^`)8#`1$``A$!`Q$!_]L`A``&!`4&!00&
M!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H(1L=)1X7&"(O(R4I*BPM
M+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RO_Q`&B```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@L0``(!`P,"!`,%!00$```!?0$"`P`$$042
M(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V
M-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KA
MXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&A
ML<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%56
M5UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>H
MJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X
M^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`)`&2<"@"A?ZO96,'FS3`IG'R?,:I1;.FC@ZM67+%%,>*-,(!\U_^^#3]
MG(Z/[+Q'8/\`A*-,_P">K_\`?!HY&']EXCL'_"4:9_SU?_O@T<C#^R\1V#_A
M*-,_YZO_`-\&CD8?V7B.Q-9:_I]W+Y<4I#?[2XJ9)QW,ZN7UZ2YI(THIHY21
M'(KD=<'.*5CDE"4=T/H)"@`H`*`"@`H`*`"@`H`:[JB%G(50,DGM0-)MV1S&
MH^,;6(,E@AN95."!TK54WU/8H9-4EK5?*CGY]:U.=I2TVV*7^#^Z/2KY8GJ0
MP6'@E9:HH*"HQN)'N:9TMW%H`*`"@`H`3GL2#[4`2VMS=63E[*8J['+9/6AI
M/<BI3IU5:HM#?MO&3B6)+BV(C'$CC^=0Z1YE3)59N$M>B.ETK5K35(F>SE#;
M3@CN*S<6MSR,1A*N'=JB+]2<P4`%`!0`4`%``2`,GI0!PGBS6FOY38V,A6W4
M_O9!_%["MH1MJSZ3+<$J*]M56O1&#&B1`")0OOW-:'IRDY?$QU(0E`!0`4`%
M`!0`4`+0`$Y&#R/2@06KR65ZEW8MY;K]Y!T:AZJS"HHU:;IU=4=UX;\01ZNK
MI(GDW"?\LV/)'J*QG#E/G,?E\L-9IWB^INU!YH4`%`!0`$X!)Z"@#A?$7B)[
MV22RTYBL*G$LO<^PK:,+:L^DP.6JDE5J[]$8*@*NU>E6>DW=W84`%``>.M#:
M6X`/F.%!)^E"=]M0VW)4M[AQE(&(JE&3Z$.I!;L<;6Z'_+`TW3FG87M:?\Q&
MT<J_>B85'O?RE*47LQF1TYS2NMBK"TP$H`6@`1I(YDF@<I,G(84":C*+C)73
M.^\,:P=6M&,BA)HSM8>OO6,X\K/FLPP?U:>FJ9LU!YX4`%`&-XKU#[!I,IC<
M+/(-J#UJX1NSORW#^VK*ZT6YY[;ILA&1B1N7]S6[/J9N\O(E12S;1UHC%RER
MK<ANRN+)&R'YAD>M5.$H.S$I)BP1F0GL/4]*TP\%+FYD*<E$Y#QI\1O#O@YC
M!=7"W.H8SY49SCZU+<*#5];G%7QL8.TF>8ZI^T1=2PO'INDHC9X<^E$\5&,O
MW:/,ECFT^5'+WGQ+^(.KN+JS>:"#^%8UX-<-?-(74922:'3CC*T;QC<A'CCX
MDLRD7-UE>?NUA_:=):\Y?U?'?RFE:?'/Q78.4U"W21UX.]<5ZBS'GC>*1E+&
MU8Z.)Z!X8^.^C:M+!;ZO;?8Y7PI<?=S3]O!I*VK.NACX-I-V/68TBEC22VN(
MY$D&Y<-DD4_8-NU-W/35:^C0P@AMI4Y]*Q=T[-&J::N2>6H(5ID#G^$MS6KH
MR32>[,_:J^PQT9&PPX['UK.47&7*S1--:!#<SV-Y!=6TA7:V)1V*TFDU9A*E
M"M3=.:]#U&UGCN;>.:)@R.,@BN=JQ\;4IRIR<9;HEI$`2`"3T%`'GGBR\_M#
M4UB&UK>(_*R^M;P5D?4Y;1]C2YNK,LDD^_:J.Q'E?QX^(,GA>Q@T/0YMNM7'
MS3N!DQ+VQ[FM:CC1C9/WNYY&-QCB^6.[V.1\&?$/Q?X7N++_`(3&WFET&X(#
MS2+R@/?-<E#-(RJ\O-=F$/K.'M.JG;\B/XH_%>^\1:I_87@=Y$T]\+YL8P\I
M_H*WQ>-4(N[LNXJV)G6DJ='5LA\.?"B.0-<>*;F6XN)1G;&Q)3ZFODZ^;S<E
M[):>9[>%X?AR-UW>1VND>#=&TA`MM8128_YZ`'->;4Q-6I/G<SV</@,/1I^S
MC$UD2*)`B6T<:#HH7`%8OWG=G="E&"Y8[#AY?41)^5*R[%\K[E2]TW3;^"6&
MYL;=O-&&<(-U:1J3C;E=K'//!TI-MJ]SEK;X7^%X)69EN')!PK-P#7;/-,1)
M6O8\F/#^'B[V.2U;PSXQ\,7#W^C:G<7$$!R@20DA?3%>MA,ZA&2C\+[]#R<3
MDV*I+GI2YO+J=MX4^.XN-!NK;6;4+K\,9%M(!\LK>A'8U]`\?%1O-:'#1QDF
M^22U[=V>9WEO\0=8O+C5G%\LCDN=KE0!["O,EFM)/G<Q_4<PJ3YE%IGJGP(^
M(]_KU\?"_B9PTT:$P3L,-D?PM7HTL3&<>6>M]F/#8JHJCA->\CV,@AF5QGL1
MZT.+B[/<]J]]4;W@&[%O/-IS,S$_.O/"CTK.HKZGF9S1YXJNO0[BL3YT@OY8
MX;.9YF"H%.2::6IK1A*<TH[W/+B`LLFW[I/%=!]C>Z5QR,%8$]`:NG-0E=B:
MNCYQ^/\`ID^E?$Z'6[NW\_3[]5\ANP8#&/PZUS9EAY.+Y7:YX%O88E3DK_YF
M-X_\0:M;Z##H=Y=0WIN@&78.4'8?6OF\OP]*=3VL4THGK9MC*L(>PDDY2['4
M?#7P[9^$?#<NLZ\J0WKC>"_5$]/K7-CL6\354:>J6WF=V69:L%3]I4M>UV^W
MD)%XC\3^.KJ:U\#6/V33XQ^^O9N!^?:NBG@L/2?^TS]Y]#AKYO7K3Y<,M+[L
MCM_"7BZYC=M%\66E_=0-^\A1^5-8NKA(3Y:U)Q7<T^LX]MJ-9-#I_%?C+P\Z
MQ^(M`:[C48::$<-3AA<-B9?N:EO(F.;XC#PM7I_-%F+XFV+V[23Z7=0RKUBV
MU-3+:M.?(VCKI9_2G3YDF41\4[B]C=-)\-W3W'9MN0*V>4Q6]1',N(DG>4&T
M6K;XC2V85/%6AW-BQZ2[#@UC++[K]S-29U4<Z]Z]6+A%]3N;&[@O;&*\LI5G
MM)1D8.:\^46FXR1[L)QJ*\7Z,\N^,'@T/$WB'2(EC\O!GC0?^/5Z^68UJ7L:
MFJ>Q\SGN71Y?K%/XEOY^95T7QAK6N1Z;-'<K:V^F@?:\G`E4?_6J,1A:.'G)
M37-S;>1EA,QQ&)4%%VY?B?<;X,E?Q9\:XKS08#%$'WG:,`*.I/UKZ'*(/#QC
M&:O^AY>(Q4:N.=6FKK^M3ZDN6#3L1VXKTJVM1GMTTU'4;`[17UO(CF,!AN8>
ME9/8<XJ5.46KZ'J-O*DT*/&X=2.".]<S/CIQ<9--6,KQ@H;P_<@]./YU</B.
MW*W;$Q.!/6MCZ8.X'KQ0!S/B+7O#,^H7WA;Q'"ES<6D!N(@RY\LXXQZ5TJ.G
M))W/)Q3IU9)Q^+<^:?`]D=?^(1G<%X()2X'7@'BOG<WQ"ITFHJUR,GP\L5BN
M>;^$]/\`BIH]]XE.E6-EGR#,/."]EKPL%B*>&YIR[:'T>98.K7A&$7[M]35^
M+]\/!/PLL]*T-1:K/B,F,8)XYYKFRJF\3CG5GK;4\/'N%&G)1TZ(\W_9O\[_
M`(3*:16?;Y1#G/!^M>MQ%K15^YR9/%.4O0^CGF8ET<*Z9Z,,U\BM'>.C/IG2
MBT5!IVF3S[Y;"!G[G:*MUJK>LM69NA&*T1XUX\^)]SHGC!+#P]:6UO;P.!(0
M@R_M7TF"R5N@Y5V[M'E8K,O83]C"S[L]GO;.QU[388M8M(YH[N`,P(^Z2.U?
M-TZD\/4O3>J9WRI*M1<7MV/%OA]#/X>^(6L^&=[/8)N>(,?NCM7TN,4:V'AB
M6K2>YEE%:I1JRPKUBM4>@75N+RRN;0C*RJ5(/<5Y:DUK'<^HJPA.-I[-'SOX
M=\.G5_'#>'!?"S@EG*,[-A0`:^UH.,H1G45W8_-9TN6O.E!VC<^M/"7@S2/`
M%@=.TB-9;MP#+>]2_P"->G&<:<?=W/7P>&ARJ:5E^)KC@5DE8]$;-_JF!Z&F
MAQ^(]$\*J%T:$+TQ7//<^6S%WKL;XN_Y`%S^'\Z</B'EG^\Q.`/6MCZ<?#_K
M!['-;8=)U+,F>QXA<Q+;R?$OQ1,AN+L?N(7D'"`\<4ZO[J4IQ/#45^\K=5HC
MD?@);*+J\O=Q,I4C':OD,XJMR4#T>':2DY29WWC37[GPOHPU2RB6617P5;IB
MO+PU%5JBI-VN?1YE7='#RFE>QM7UA8_$KX>V4EZVUIUWHR?\LGKGPN)GE6*F
ME&_1W/!E2AC:7JAWPW\#0^"-/NE60323_?G;C`]JG,<QEC)*VRZ&N%P5'#I*
M&KZFY'J^C/#<2QZM;NMMGS<..,5Q.C532<=]CH6*B[VZ')Z)\6?"VK:K+IN9
M+7?E$N)#A6]Q7H5<GQ5."J6O^AQ4L?3K3<%+;\3R;6?`6J1_$J**U#:E9S3B
M5;I1N3;G)R?:OH(9G"K@VY.TDK'E1RZ7UM12T;N?2S210(CS2+';P1C>YZ*`
M*^+C"=1\L%>1](VH09XKX5G&M_%;6M<L<OI2`Q+-CAC[5]/B%[+"0HS5I=CB
MRUSQ.+G57PI61Z#`"96QW!Q7EGU-3X3YTMK9[CQSJ:(K%Q(YRIY7GK7WF73C
M&,7)]#\XFO\`:I^K/I?X0:F=5\%RAY7F>U?87?K7H24O9-S7H>IA9NZ39UXZ
M"N<]`;-_JS30X;GHOAC_`)`\/TKGEN?*YA_'8SQ=_P`@"Y_#^=.'Q%99_O,3
M@#UK8^G!20P(..>::;3NA-:'(>(='N)=+\6PF")=%N(=\8`Y+XY-=$%[2]SS
M:M-PYK]4>'_`>[*:K?6+E1'M)!/7-?(9S3BK3ZFO#LY*4HI:'JVJ:?;ZMI\]
MA>INBE!&/2O#A*49*4=T?7UJ<:D'&6S6IEQ^(=%^%OA1;-YFNKHL3#;YRWX^
M@KJKT:N:UE-*R2U9\K.E0RQ.#DVGKYGF=_XX\:>/;QK/24EBA<X\N`8`'N:]
M..`P>"CSU-SS(8W%8BIR4=+_`)>IM^#_`(+:JUV9/$=TUK9-RZ1N<R?6N7&Y
MY2MRT5=]^QT87*W%MU)7\EU.GU#X#Z/>QR?V5?20S@?NPQR":XZ/$%:#_>JZ
M-:F5X=.[31Y_::SXS^$>M_9[Q&EM-V"DHW1R#V/:O4E0P>:T[P=FNQY_M*^$
M?++6+9[5I/B'0?'GAJ;RKD1"5<3VV<,#W%>#.AB,NQ*G%:]&>Y"<,9'DINZ*
M6E:;9:/9FRTF#R;0'..['U-;UJU2M/VE5^\SZ#"X6&'IJ$%:PS7+U=-T*]O6
M<)Y,9()[FHITW4FH+=L,76]C2E/LCR+X1V,NK:OK6J3;A$D3,S8ZD]J^\PM"
M*BE+9'YU2E*=1U7LSZ`^%6GMIO@G,D8B:ZE+`=R/>NZK.]+E>Y[.$@T_Q.JZ
M<5S'>,F_U9IH<-ST7PQ_R!X?I7/+<^5S#^.QGB\,=`N=B,YXX`]Z</B*RRWU
MF-V<`>M;'TPE`R2%5F,EK,-T$Z%"O:M:+?/R]+&-:*<+]4?)^IVI\!?%IHI%
M,5HTW/IM)KR,UPWM:<HVVV/&R_$SPV,36B;L>I^._$L/AG1?[07$CW(Q;KZG
M'6OE<-AY8B?*M.Y]IC,=3PU%SGTV\V>6?#WP9J7Q'\02:GJ[NFFHVZ:9OXO]
ME:]G&8REEU%4Z>Y\A3PU7'2>(KO1[>?IY'7?%*RUGP5+;7O@^`VNE1`!I(ER
M<_[7M7%EM2ABTXU]9/HSMS"E4ITHRPZM;>QZ!\-O&*^.?#DEVZF.\L@!<IV)
MQU'UKR<QP"PE=4XO26QME^-C5A>VNQY1\2/BEJ6IZK%I_AE)[5;=]I9!\TC`
M^GI7O83(5AKRQ6M_N.'&9A-U?8X>[U^\]BM[$>+/`4%CXMM@+F>,9)'S(>QS
M7SKK/"8ISH/1,]2KAE6C:2Z:H^<?%.@:S\-/$ZM&[F'.Z&8?=D7T-?84*E+,
MJ%[>OD>!+VN6UU.D]/ZT/:?!6O)XJT".^C`6=/EEC'4&OG<1AY4*CA(^VP&.
MAB:2G'KOY,\V^-'BZ"\":)I[%EB;,[@\$^E>KE.$E?VTUZ'SN?YA?_9X/U_R
M/6O@+X4?0?!9N=4B4MJ`#JF/X3TK["E%4:?/+[C@P&&O&[ZGHR*J(L:#;$OW
M5]*QJ5'4ES/Y'LQBHJR%J"ALW^K--#AN>B^&/^0/#]*YY[GRN8?QV:<REX75
M<9*D#-2<D7:29Y?>6\MI>RPW./-)SQ72G=:'V-*I&I34H;$/?`Y/I0622(T`
M1Y6"..50GDU;HSY>==.AFJL)/E1XY^TEX3_M+1(_$%HK&>WXE4#^&MZR]M24
MUT/(S"@W'F['@\FI:EXNU'2=.N9"R1[88E'0#UKP(8>&&C.I'=ZLXJF*JXIP
MIS>BT/K?1]/CT;0K+2X$6-88P&"C&37P-:JZU5S;OJ?848Z)OHK%F1$F@>"X
M198'&&1AD$5$9.+YH[FMM;K<I:/I&FZ'!)!HMJEK#*=SJ@^\:NK5G6=ZCNS*
ME0C36BMJ$&BZ1!=/<PZ?;BY?EI-@R36L\=BJE-4IS;BM@5)*I[6WO=R\Q+=>
MW2N8U6AD>,/#EMXN\.W&EW0'G8W0RXY0UV8#'U<%4YJ;]U[HY,5A85HVGLSY
MK\.^(]1^'&L:M8F`22,#$0QP`>S5]=7P]/'TXU(NQ\_A\5/+JDJ;5_ZW.H^!
M_P`/G\8:W-KVO0G^QH7+MN_Y;29SCZ5[>%H))7V2,,-"5>LZDE>[/IH%`BQP
MC;"@PB#HHK2=3GEN?1QARH*10E(!LW^J/<]AZTT..YZ+X7W?V/!O0H<=#7//
M<^5S"WMW9W-6I.(X3QI8O;ZC'=1[I#,<;?[M;TW?0^DRJNITG3>ECROQOX_D
MTB^&A^$K%M7\1/P4496+W-=5.2IQ;M=AB<1*W+#5G&F\O?`.L+XG^(>NK?:Q
M.A":1`^[R\^HZ#%11FX-U*FES@C:D_;5):OHBM?_`+1,-Y9W5K)H"/!.I4JQ
MSP:R^LR5^4F>.C=<J.1^`FDPZMXUNKUH-MO`"\>1PASP*^=SG'SP]#DCO+<W
MRB,75E-QOV/HMV+.2>O2OB4K(^I2LA*8!0`4`%``K%'5AU!H8-75CP7]I/0H
MK76+'5H4PMRNV3`XR*^LX>KRE3E!]#YO.:<FHU7LM#K].^-_AG0_#VD:5I]@
MYBAA`F"+@;L<_6OKJ5:$H>^8T\71IZKM]QL:#\;_``IJDICU(26`SPQ'%:SJ
M4)6C%&]/,(-V3^\])@>*YLXKRPF2YLY1E'C.>*SJ4O9ZQU1Z%.M&IL%9FQ-8
MP376J6T5M'O96R_H!0VDB*TX4Z,I3=CU%!A%&`,#M7,?&O5BT"*&MV;7NG30
MHP20CY6(Z546TU8Z,+65*JI/8^/OB%\1M'\*W5_9^"HB=<E+17=^Z\J>^T^M
M=U>MR)0@SOQ6)C"\:>[_``.*\%^`]0\52R:OXAFF6%SN#2DEY3^/:OE\?FKB
M^2D[OJ^QW9;D<JC57$Z1?3JSI/&WA#0?#OABYN;"$_:2F-S\UP4<97KUH0D]
M+GJ8C*\+0H5*C5M-#;_9P0#PQ>,(SN:8Y?%8\0O]XO0XLGIQ6&Y^K9ZN2!7S
MQ[%B189&!9ML2#G=(<"B^MD9RJ1CYG/:MXT\,Z0&^U:M`9%.'13DBNNC@<15
M=E%F53$0IMJI)(L:9XH\-ZJ(_P"SM8@D9^@+8(/I6=3"5Z;M*#'0K^V3E"S2
M-B2-XB-X^4]&'0USIHVC*,M@10Z2IGYF0A?KCBGU3)JWY=#P'7[W4M1T#Q!X
M=\1.C:C8RF:WW=2GM7UE&E'VU/$4%HU9G@UIRI4:E'$.[>J*WPO\&:'KWA62
M\U%':Y$I7(/05KF&-JT:W+':QOE&64<30YI*[N;VI?"C1;M66PD:W8CY68]#
M7'#-,0I)O5'J5,@POLVK6?<YK0-?\1_!_P`1BTO2]QI,Q^:/.4=?5?0U]/EN
M9PJ*ZVZH^8G2JY?5Y:FL6?2NC:U8:YH]OJVDN)+>Y'R)W#>E>E4HV7/3UB>U
MAZBJQT>G<]#\&:3-IMB[W6//F.XCNH]*XZDDWH>)FN+A7J)0V1T59GE!0`'I
M0!X)\9/@[X?EOV\8VZ"V>W;S;R!1\DWOCL:XL>YQHOD/5R2G3GBXPFKW>ASM
MW?6=MI*ZA<2I#8!-R`'`^E?)P@Y-0BM3]!JU8T%)R>V[.'\?:M9>(?`MQ<6#
MAE3L*Z\*I4L5&,U9GG8Y1Q.!G.F[JQPOP\^)]_X.TJ73X[=)K61]_/4&O9QV
M4T\55523Z'QF#Q_L%9JZN>D3_'/3(=+22*Q,MZPY4]%->)#(*LJK4G:)ZE;-
MJ7+>%[]CSC5_$GC3Q\1$C7#69D^6.$%57ZFO;I8;!X+:USS92Q6)CS):7.ST
MSX%,;>.74[\F9URRKV-<4>(Z=.MK"\$=E/*%*-ZDM2AXK^"]WIUJ;K0[EIG4
M9,>>?PIT\_I5:CYHVBWH7+)[0<J4K,/AO\2=5\/:G'H7BYI7T\G:&F'S1'Z]
MQ2QV4T:\'5P^YGA\;4H3Y,1OT9[/;^*?#LUP%@U*(D$$98<U\U/"5X*\HGM4
M\2JONIJYY9\?=$CM;@^)HY2C7:")-IX>OI>&L14E"=%.R1Y.9X>E"'M;^]L3
M?!2*1/!,FY<;I25]Q6.:R3KZ=CU^'DUATWW.HMM<TB[OGL8+M&NU."F>]<4Z
M%2$5.2T9Z]'&TZM1TX.[1F_$O28]8\(7,=P0KVH\R-L<Y%:X.LZ59274YLRP
MD,10E'YHZ#]D7PWJ$OA^ZO=521=.\W-JC@C)[D>U?;PQ$XTW!;,^%HXV5*E*
ME'=L^FATK`X0H`*`"@"&\M8+RV>WNHEEA<89&&0P]ZF45)69<)RA)2B[-'RG
M\9/@;X@?Q"C^%YI;CP[<ON>VW\VA[X'<>E<4Z=/"PYH0NSU(8FMF-50Q%3EC
M_7XE.R\&:1I?AW4-*L))9KB6,K()>H;'85\Y/&3G656:]Y=#[*EEWL\*\/'2
M,NIYG\*IM"M?$=UH?BVT$EO<,8DE(YB?.*][&X>M7I>VH3Y6E>W<^0P,E1KR
MP\HIN]CV_3_AEX0TJ5FCLOM6_D-)SQ7RKS?&2CRMGMPP5+F<E!)G465M9:?&
M(],LHK5!V"UPRG.;O)W.F%%1CRMZ$I)))+$DU-C705'=#E3^=%A.*>YA>*O"
M.@^++-K?5;402]5NHA\RFNK"XZMA9<T'?R.7$X;VL'%J_P"AYA+\`[G[26L]
M<46H.?,<8(%>W_K$GI[.YXW]D\MK3=SF/BEK[:BVF>#=-N?MEOIQ$?V@G/F/
MTKNP%#V2EBZBM=;$XVK&JXX2@KN^K?5GK'A739-$\/V=G,5>01\E?I7AU)^T
MG*?1L^TPV'C3HQI+HM?4\G^(/@6\\-N_B+2KO]P9=Y7=AXR3^HKW,%C8UU["
MNM;?>?+9EET\+4>(PK>FK\O^`?0'P2\/S^./#=CKOB>W:.W7Y8X","XQ_&?:
MHI9/:LW-^ZMBZW$M\-[.BO?:]Y]O0][M;>&UMT@MHDBA085$&`!]*]U*RL?*
M$M,`H`*`"@`H`*`.+\3>`M/U2XEO[5?(U`J=I7A2WO7EXO*Z=9N<=)'T&7Y_
M7P\51GK`^7/C1\&?$.BSV^NZ=$;QYY,2I:H2T;]CBM<#1JTZ7LZVIAF^-H8C
M$JMAER_Y]S<\)?$F/2[=-"^(=K<:3JMN@V2RQD!U[9KP,?D56,W.CJGTZG9A
M,VC4:YW9]>S/1=)OK36+'[;I=Q'/:_W\XKP*D94Y<DU9GMJHM//L6HD,QQ&T
M?_`FQ4MI=2IR4%>0YX'3.YHN/1P:+K<F-6,MALJ1V\)FO+BW@@`R7>0<"B,N
M?X=2766O*KV/%?B5\7;5(+S2/#I,H;*-<@\'UQ7TN!R.5XU*KMY'CXO-X*+5
M+67<XOX1^&XK[5O[7UDR):P'?&=I_>-7H9KCHTH^QCNS7(\GKUFL7):7T\_,
M]\TNRU#7;E%TNSD>WD.P7&/E2O"I4:E5\M-:=SZS$5Z&$@W6DDUTZL[G3?A+
M:WL$/_"4N+IHGSY2'Y''N*]W"95[-\U1ZGRN8<2\ZE3P\;1DNIZA;6\5K!'!
M;QI%#&H5$08"@=`!7M-W/D4DM$2T#"@`H`*`"@`H`*`"@`H`Y[Q-X*\.>*)X
M9M?TBUO9H>$>1>0/3/I3C)Q=T*45)69S^K_"S1[S4K"YL6?3H+;@VUO\J/\`
M45Q8O`T<5?G6O<]#+\QK8)ODU5NI3\;?"/3_`!)IOV6#4+NP;.?,A/-<F!R3
M"X6?/:_J;8C.<35I.GW,GP_\#;/2H4CDUS4+G:.2[=:Z*^68:K4YN6R[$4,U
MQ%*E[.]_,Q]4_9PT_4[^26Z\0ZF;=SDP;OEKO]EAXV=.FD<53%8FH[.>C%L?
MV9/"5N^Z:>ZFQT!-95H2FK1=BL-5C2J*<H\UNC/5/#G@C0]"T6/3+>RBD@7J
M9%R36%+`TH1::NWNV=N*SC%5ZOM.;EMLELC?LK.WL8%@LX4AA'14&!73"G&F
MN6*LCSZM:I6ESU'=D]69A0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`
M%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0
M`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%
M`!0`4`%`!0`4`%`!0`4`%`!0`4`?_]D`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O;F5O+FIP9P``````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-S<R-@`Q,#0Q-S,V,S`Q,0`P,C(T,S(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````_]C_X``02D9)1@`!`0``
M`0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````
M``````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A
M,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3
ME)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'B
MX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%
M!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B
M,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'
M2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:
MHJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ
M\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^)6767,\;'RHEDDPTK,%5V!SM5BP!
M9B-H`))SCKQ6-XWU:34+%;:W*B*79!(Y+F+=YBE@SQ98%1\[`9PH)<%`PKS>
M76+QQL#@M"S21ASPQ_BQSR0,D;>X^E:"7$L@LX%W7$,R/<72,ZQ[2R.9(UD<
MX0LFX<G."<>E>="GB:*IU:>'IU:=%RG[Z7,Y1C'GY8R:;Y5R/JKRU:OK]`L8
M\9*<*BM4Q=2%'$SVYZ]2<5[LG92<KQ44M6]%KH_V7_X)+?LQ?MS^-M7\7^*/
MV6/#=WI%EXEL#X2O_BG=77ASPS'IEJ)A;ZK#HGB+7(+^>*&[AN7T/6M0TO2-
M:NM(T_5+F\33+JYB2UE_=>3_`((<?MT:W-X!T+Q+XQ^%M]X:75KR>XUSPIHR
M:?/X,^T))K]O-)/H]G/?>+=)\&:A8_V5\/K?6KI;KP99ZYKIT35H]/UB\\-O
M]??\$X+[7M-_94^"GA?X8>&-3M-+M?!^BZAJ.E6^B30?8]8\4:=!K=Q?7^J0
M6P-RMV@TUHFD?$@U+3W3(N[<R?J3IWQ"^*L.FP:/J&L:=!*59AIT%U;2W+)`
MJ3LCQ32H,;#$7#D?+(I'+IG_`#N\0OI&\3QXLS>CE=#+<#A,'BYX5+&865:5
M25.2O4A5<7&4'>,5RNRE&:MLE_<.3^!4*?"F2O+L1EJQV)PE/%XRE7QM:AB:
M,:JNU5HT9ITX\D>;]Y!3:U;22O\`S'ZI^P=^V=^PC\;-/^-L'CS3/$W@+X=6
MVH0W_P`3+C1;WXGV[?#WQ%)+X?\`']OK'POUJ&P.O72^']:U>X_X1ZP%SKMY
M&F[0(I=96P5ORP_X+3?MV^&_VUK+]D]_#6KN^K_"OX<_$30O&NF2F.6\M_$.
MK_$B]TBT\0:IJ-KG0YM0\?\`@WX=^&/&;Z=H\CG3M'U7PU&6:%)GD_LQ^*OC
M;QCX?\.:_P"*?&-E,^@6-O?&=5TO35TC3[34+"YC-SKNI2M)9:98S6CS7#7-
M\T4+6L<LH?8K./\`.=_;#T[0M*_:.^,>B>$+2_MO#VE^-=6T+1(+PQ7$LUM8
MZE/!=S2&$%8BL]JZV.T8?34=HR8T8C]<^C;QG7\1^)LQK<0T\-_:&59?[7"X
MS#4%AL-["2E&-%<T(J=5SE4<DI-\K5DE=O\`-O'O@>AP-P=D]7*:^"F\TQJP
MV/HX/%3Q/-B>6FYSFI2=17BZ:VY;15M]/E!&38F60G:N3E>3@9/7N:*Z]-%L
MPJ@M("%`(!.`0.<>U%?UP\5--_O'H_\`GY#HX_\`R+_`_F2.3NT?W;V7V-/L
M>7K]S[Z<;"^]@[E4VY8EP0,*I)4C&26`V@<$EAT/-?0'PA^$GB?XAQ:G?Z5I
M^K2:+X8U?P2OB;4K4B:+2[3Q[XFL?".DF6W"DQW-S=Z@9-+2<I'<W%M(P#I!
M/M\#MBJ7^R1VAMYI'CDEVL/+MWS'<*-J2'<T3R1`;&PS@$#-?I%^Q+\2?AOI
M7@[X]?"3Q[H_@2+4_B)X$O?%'@/QIXB\1_V/-X9^(_@KP_J@\&6-O'K-Y9:/
MJ]S*^KW,^DV,UU)(GB6&Q:TCDO;>"`<V?5\=0RG$8C+/>QF"EAJL*<KJ-2G7
MQV#HU>1I>^X4G4G.*4G&*4FK'I<%X+*L;Q/E=#.L5*A@G6KU>7FY5'$8?`8N
M>%G+I'_;IX)IR>O*UTNOV[^)&E?M/>#_`!!/X7\&V/BK0/`W@&UDT?X,_P#"
M,?M.^(O@[:Z;!I8TG3SJEK%X363P]JFO^(K47_Q`O9?%%Z^E:AH<NK^$].L]
M2OK6#2KC[8^#'P^_;3'[/O[57BGQM\1HO%'C_P"%'A5]2\#^*++6$L8/%;-I
M;W-U8SZ';>#/"KVTFFZ/8QZU)>:MX:L+B?3[W1M)-S?:CH.HV[<Q^Q+^T9XF
M^*^C:;_PE,FIVVL:)H&CV;ZEIJ[]5U1[73K:PM[?6+"TM+NTGU2UN=/O?+TR
MSSJD\I^S0PR7,B1MZ[\:_P#@I3\$OV2]0^*WP:^+?PV^.$_B_7]#GT[5IM*\
M'>'K+P!<S^+KK0-1TV#P9XMD9+_QG?I\--2T[Q%K47B)8!I6L6-]HD)74I(K
M8_YT9MG7$^/SC$<'X+@7`XO$Y7*EB:U94,'6<XU*=*K-J5>?M(Q=6HXS5*,8
MN4O?;DKQ_P!.\=@\CP67X3C'+\[Q6&I\5U)854::;=/!QKRI47427N*.&BM9
MVLE[NK2/R/\`B+\0_P#@H-H-_''XC^*/QD^)/Q%M_#(C\-:SX0^.K:?X9TVW
MO]&BU/Q+I=M\,])M/#NBZIH^@WEQI^C_`!4/BCPUXAMO$FM7&CV6C7>G;WO8
M_P`1_P!JWP3=>%OC7\0XDM[>TM[;5?#E_JFGVNFFUTZPUOQ1X<M-8O=*"Z7-
M>:++>Z1J%WJ6DV&HVMX\GB+3K.]UB%)(3.\?]87[1WQ_TWPE\%O#^OZ?.^M2
M:QX7\+ZOX=L_$VFII&OZ]ITVESPZ)=^)+.UMEBT--?AN=-OO&*7TMO'I.M:C
M<07C1W.AM''_`#:?&;XC^']9^!?Q5\=^.38^*?BC\=/B1I\.D7FFZMII7P;I
M?P[U#38XM4U/1H)&O-.N);#[?X4T2"ZC@.JZ/?7&M6YN(+1Y*_I7P6X@S+,8
MXZ-3@_"Y+]2ME5=QP]##RG6IJ%6=2G2H^[R6K<R:M+FT4;7<?P7QWX8X;P.3
MTL)_;D\57H82&=4IRG%S;K2G35.*NG)WI:6VNVWI9_!ZS6X4`VT((`!!M9P0
M0.005R"#US17`?;F//VH'/.=W7W^]17[O]1EWG_X"_+R\G_3T_B7^UH=,9B^
MGV)^7^?X^3(=3C6/4;V+&X1W%PB0[MK,6N`B*HX)/(8`#)"DU-!INM:?;Z=K
M1TK4(+*ZNFCTS5FM[@6$]U;'S)8[:\*?9IY(`A,R1RL\2JSNJA35S556+7M0
ME;(A^TW<,A*95XY3/!<1!BI5#(CM#YH(\EW$@8%01+/JUWJMOIEG<W*&/2=/
MDM+"!Y`+>WA-T&L[98]H#S1W)CN+FZ'S26R-YY=(RU>Y&$98>A*5G"4W3J):
MM+E@VG9W7:TE:UT]!8NG*AF>8>STE2K2=&?V9J,TDXNUI)M/WEU35]#]NOV(
M?VFM8TBWFM=-N=-T_P`6#2-'N[.]\26'B#4O"^DZH1::M9^(/$%EX:CDUDV4
M1OIKNSEMT5)+J&%W8VZ3$?>'Q,_:1^._BC5+^?Q_KE]KFL:FZ:OIU]X4_8V/
MCSX?ZJZ6UWHEOJ?A_P`3GXNV'B&\%QHHL+*\C\6^'[?^S+*.74+&(7]G:D_C
M7??!GXD?`?PK^S?\5M(U"ZAC^(7PNTWXB>#O%-CI5P--U-=;U>Z;6?!KS2S6
M%AJVJ>']4BU'2+_2XKXWVGZ!>V%S-;JDMNLOUKIO_!73]I7P[X%N/"%KIW@$
M!)Y;.2\6UU:SO+2YE06@MVT;4;Z\T^\2%G$P"HR02*+F,+)"C+_-/%7A]B)Y
M_B\]X8R'(LSE+$.AC<9B<9[+'4'%J4J48PA5_<153GNXJ\W4C)*T6?VSX;^*
MF`P7#&"RGBS$9C1C#"JIAE1PE&K2<>2,(MSK.+4^:+34?=V:W:'?M=_M->.M
M9^%<.D?$CQ%X7UWQ0VI6&CZ':>$M`U#1X]!T?3W@NH;35+#5KC5+JVGNC;+8
M"RTO46$5S<)$^Z+>K?A'K6H75]/J+SQ2J;FZ-VEM_I$<=DTLFXN('VA3-'E!
MN'*G<IX7'Z*:-I?Q8_:R^+/ANTO;:7QKXL\2Z\MGI6@06XTRSEO(KA9-4O+J
M&*,&'0-*M?-NO$FMLBV7AW2(;S5]2N+6TLIIH_D_]I3X>I\'OC1\5?A39W^J
MZUI/@+QYX@\/^'=<UBW_`+/O]<\.0:I=OI_B26R>**1D\8VOV#Q+:[=ZP6MR
MHC9X79Z_5^`<IRG)*4L%2I8..8XO_A1QM'!UI5E&M45.C)N,[2A:5))Q24=+
M*^Q_.WB_Q)CN)LV_M+#UL;6RK#TE@,/4Q="-#W85:E54XNG>G**C6O>[E[SZ
M)-?.N\^@_7_&BIRL63EESWR5SGWHK].L^S_K_AU]Y^+>T79_U;_/\/6W1ZV3
M]OU$9.#?7N1DX/\`I;'^=9-J`;JU4@$-<P*P(R&5I4#*0>"&!((/!!(/!HHK
MBP_^Z1_[?_\`3:/9QO\`O_\`VY+_`-3*I_H07G@3P1KO_!(+XQ^'];\&^%=9
MT'P3^R]\%/$G@S1-5\/:1J&D>$?$5W\*1J=UK_AC3;NSFL]`UJYU*./4+C5=
M*AM+Z:^C2[DG:X59!_&%JR(=1^'<)53%JG@K0+_4XBH,>HWQMI$-[?IC;>79
M3Y#<W`DF*_+OQQ117Y#P+_R,^,O^QEC_`/U'PY^SY]_R*LA_[%>&_P#3]0_I
ME_X([^&_#L?['G[3?C*/0-%C\83?'QO`LOBM-+L4\22^"8+?3-<@\'2:ZL`U
M1_"L.MV5GK$7AYKHZ1'JEI;:@EF+N"*9/Y[/^"P%O!;?MR_%V&VABMXEB^'6
MV*"-(HUW?"[PB[;4C55&69F.!RS$GDDT45P>'?\`R<?-?^Q8O_3]8X.,O^3?
M8+_L;O\`],8<_,@(F!\J]!_"/\****_>3\.73Y?^XS__V0``````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;FEN:F$N:G!G
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q,@`Q,#0Q-S,V,S`Q,0`P
M,C(W,S(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````_]C_X``02D9)1@`!`0```0`!``#_VP!#``L("`H(!PL*"0H-#`L-$1P2
M$0\/$2(9&A0<*20K*B@D)R<M,D`W+3`],"<G.$PY/4-%2$E(*S9/54Y&5$!'
M2$7_VP!#`0P-#1$/$2$2$B%%+B<N145%145%145%145%145%145%145%145%
M145%145%145%145%145%145%145%145%147_P``1"``R`#(#`2(``A$!`Q$!
M_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($
M`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R
M@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ
M<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W
M``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8
M&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#URLC6
MM6EM)(;.S57O;C.S=]U!W8^U:]<FK^;XBU&>3[T;+`F>R@9/ZT`6H]&M<^;>
M;KV<_>DG.>?8=`*+NT"V#PV>+<]1Y8Q@U;WY7;W'05!)*'7.:`*_A"VM4AGD
M$6+Y&\N9VY)],>U=-7,:"V/$.H*@Q'Y2%AVW<_TKIZ`"BBB@`KC;MY;#Q'<P
M>4'^V,)(R6"CI@]>]=E7+>,+;<]E=-Y@CB8JS1G!0G&TY],B@#,N+K6KDM]D
MMA#&K;';?T_VB?3Z59M7D'FS/.TL)`$;D8S@<GZ$U(D`GA#7<]W,"/\`5S,"
M`?<#@T13F]DD*;3!'\N<<,>X'M0!H>%8&-E+?RC$EZ_F`?W4'"BM_-<=:2:E
MHUN\-E''<VY.8UE;:8L_S'M5D6^K3J9)=7='/\$2`*OMS0!U&:*YG^SKSOK=
MSG\**`.BN)X[:"2:5ML<:EF/L*Y-Y-0\01M)<3FRT]P=L"*"\B^K$^M:_BE\
M:,\?/[V1(_S-9AN3<ZB(8>(+?'F%>A..%H`SYM&DM8!%%=7<ELRX*H063_$5
M82Z:&VM+6VA62X:/*J@P@4=6/I6EYF?F;@DX^E-1@.<8P.*`%M;1D827,PEE
MZ#`PB>N!5J:6.!#([*@49))JO<&06TI1]C[25;_:JEIP.O7R)<(/LT$:RR+_
M`'W/0'V'6@"+_A(0>5MI&4]&'<>M%=B$4````#MBB@#'\3_\>-O_`-?47\ZQ
MM+_X\ICW,[_^A444`32D\<]Z=;DE>O>BB@">YXLIR.HB8@^G%.\(@"VNR`,^
M?C\-HHHH`Z*BBB@#_]D`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]P86EN=&EN9V)I<F0N9VEF````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,C,S`#$P-#$W,S8S,#$Q`#`R-#(W-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$E`"4`]P`````````S
M``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,
M`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S
M`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,
M,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS
M,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,
M9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS
M9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,
M9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68S
MF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,
MF<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,S
MS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,
MS)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S
M_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,
M_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S
M__]F__^9___,____^+\D````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(?D$
M`0``V``L`````"4`)0``"/X`L0D<2+"@0``&$RI<>!"`PX<0&4IL""#0BA40
M,SJ4J"HA1(P:0S+L:/!C2)$+\9`L>+*E1"<J5Q($0`V`LYLX;=:<B,T)3#PL
M:3JSZ<R8T:'.=D[$\S,HM9S`HAJ[J70BPI)";P*("HQHTHT+,SJ%ZA#GUZL*
MQ<[,.K2KU[,,:0(X=@PL-H=/M;ZE:M?C4+K4:B+$:[:PUL!H2_X]1E4PV\(Z
MY]:-*]ELW<<XZ_)56Y*N9<*&-3<&8,8,GL0#'S*^>3EO8=%)$9<^C3HU7;J@
M7Y?%B1B/[],>;[<V[.RRV=Z_:U.$N/KSWIJU:OE6'CPT@-/'`42?SO-N\\S7
M+WEDW,Z]^US=>"ZHO_";]ESJG:VW=W\;?O#OQ3/6[\NSLG/5N/'7GV3"%7A9
M=V&U)&!"K#3(BD$..A2A@PY.1.&%%$K8(``8-LA0AQFRHJ&(('K(8(D;CL@A
MBB>B^-"$++:(848IKMBA1"7:R.&.-IJ(8(@7]EAA00$!`#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W!I8V%R9"YJ
M<&<`````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<W,3<`,3`T,3<S-C,P,3$`
M,#(S,3$S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1
M`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"
M!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B
M<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"
MP\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!
M`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"
M=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7
M&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY
M>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)
MRM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_IE\
M?_;Y[#3=:DTZZTZ?2]8M#(;N,JL=O;?Q^;&7!#\Y^7Y?5NM>$_MJ_M`ZM\'?
MAMX;L_ACI^B^*?CK\:O$<7PT^`7@R_F@!O?']U%JNN7?CWQ''''>@^!OAOX&
M\,^*?&'B74+M+.WA6RT'1&GMM1\5Z<8/JSXM>*/!WA7P/XQ\5^.];DTCP)X6
M\%:WXG\3ZE!%=BWT?3?#VC7^OZI?:E/9VNJ_9!;:;I=[,RE'SY(&X%J_(KQ1
M\1_BKXX/C?XZ^//A<_@_5_"7[.T'B#X-_#6V?Q\?B#HWPP^*/C+7M7O/#_C#
M5WL?)LO'OQ"U/X,_#O4==33--ENO"EUIWA/2-?>ST_Q-K$-M_GGB\;3R_+7F
M-6G6KS:FH2A5FO?<;4V[/EY%4MS)*[@I6DFTU_9>2X9YMF,,/RPITG*-TX1L
MTI1YE=VE=IV[)O5:I/Z6_98\'Z#\&_"-YX-L]4G\<^,O&D^H:S\7_B-XHBE3
M5OC3X]GOKM]2\2>*?M7D37_AM-9U36#X:\&:=J6FIX9DTVQ\#?V[J6CW"SP8
M>O\`P]TS]ES6=3^/7PEU+7-*^",^IWFH?&[]GK2/#>J>)_#&CZ;XIU"X@\7?
M%+X):7INIZ+XH\':KX7TFUO_`!/\0M'\&:AJOAWQ?X=\/>*M2T?1O#\6CV,F
MM_E39?\`!0SXB_!+X@>'=(_:5^#'A'2O`ESI?PW/C3Q%\(/$EYJVH?"/7_C/
MX8\;_$SPKX%\8Z3XY@\.#3/B#8^$?AWXIUOQ)HGAW5/$^E:)KOAFTOY_$3MX
MMLK:UZGX7_\`!3[XT?M;?M7:;\,/V<+KP?\`L_?#=O#VN>+OAYXJ^+?P]\1>
M)[WX_P"H>'[K4M7.AZ-K']J:+X:\%>'_`!%'X.U;Q?X9TN"^GUB+7?#E_J%K
MI'B^;P_ILWAGXK(LD\5Y9B\?B%"&6N];E=>C6BXWNN6<'/F3MHE.R3<FN6[?
MT/%&5Y5@)^RRZ%-591CS<LI13NDFVFIV:BVTU%.ZBFTK6_H5\`^)-&\5Z=9Z
MQX)U_3O%WAKQ?IVF^+?"6OZ/K6EZ_HOBG0]1L[*-+_3[S2[N[N/$NE/]M'AV
MUFU*UGUA_`^G:E8WFB:?=V:ZO/HZA:ZJ\4L.L2H&,-U#;KP?L_V;^+S\CS-_
M3&U-OJU?G3\&?B-%\+/VX/C9\#K_`,,/9_#[XU>/OA9\1O#<V@>(HKW0_#OQ
MR\>?`#QUXE^(VG-I/B#6O^$@\2V'BW0/@[XGOH+73?#*:&D7]NZS_9&B2B>T
MB_5"^L+&^C,,GF7$7^E<9*/_`*3_`+8R?DZ?[7?%?IU.>*J<F+G4DUZI*R=F
ME9)/:W,[MN]VME\1AHJAB91J0C:7+O!*4K1CNM4FG=VC9+5VOJ8,8TEHXV>1
MMQ1"W^D1?>*@MW]<T537P-I!528YB2H)/[T9./3SN/I17I+.*&GN2Z?\O)_W
M?/R?W??E>E?9[_SR_N_WO)?=ZVYWXH>!](^(OPV^)'P^\56,5WX=^(/@/QKX
M,\26%V]Y;V^IZ;XST:^T&Y-S#IEW;F06NFZG?0^6'0W'G9$EN5!K^8+_`()J
M_M`?M+>,=5_9L^'7[0FG^*-2^U_`OXSZGH'C37(=#U;1?'7PJO\`4?`$G@?Q
M7-K.FW]]<W&I>`_'OPWM(]:GUF$:AHVH?M!Z5X=\<Z83XATO4I_ZLYYI8K<2
M>5+%'Y/E,(`B;O\`:_>23=NHY^I[?AG\!_!_BKX9?'?]M?P)X@\%:EHD6A?&
M_P`=?$7P1K-S<W&FZ!+\'OCG>Z/XETW1_A7>VFNQ&*R\/_$/X?:OX4^*^@Z9
M8V^GZ9KFO>$_%NK+XM71_#'AW3_@<XSJA@>#>(:4L%]=JX!*="5TI4G*U)<M
M_C7/5C*4>64FH\Z<.1SC];PM1<L>ISJJC4VO9)V4HJZBGND]&DW>R6O*GX3<
M^(IO&_P;\8_L07'P?U>__:/\;_M5?$O5O''Q0^*OPMO%T?X>^!O&GQ8UFSF_
M:%3Q#XITN[M-=^)?_"CK_2OAI\,AX6O_`/A,!<1V.M6MW;Z-H/B0O];_`++V
MA?'?X>:UX=_9UT#Q5\+++X$?LE^/_%-AX:N/-UO7_CKXV\#?$WPU\1A\#-'\
M87,VEVNC7%G/X0\:2:D_BRW&GZOXNU;P=INB:Q.LFH^);_5N%^(7[07AKX8_
MM)?!GX+7^N0Z'9>(-&OW\2WLVDZ=9>#(/'/BK49]#^`?@GQ9XF&I:$?`,E[K
M/A'XS>*?`UQ;7E[XEUSQ%X+BU[29+S5M9U/4+VS\2/'\&F_MS_!KQ+\,O%M]
MXF\*VFC^$/@S^UUX.\&:OI]KX+\)Q?%;QEJWP]^!\GQ(UZYNU6;X@:5\1/BE
MIFI>#/!BG3O$.EZ;X3U7P[<RV<<MIJ3>+EG$G%><X'+,'"G4RW"XJFZLXN;7
MM;M\CNHW@KV5.,4DHRC*ZA+F7T>=Y-A,)4>);6(K)7?+.4ULG-*$IV2:YHJ^
MG-*TDVK.CX1M-2\%?\%1_"NMWOQ'\/)=_%_QI\:;&;X7ZC+X,U*#PE\.?!O[
M+GPLT_1-8AUD3^)/$7A_Q?XHU:QDG>^TG6=-8Z!I7BSPKI_V<>)_%NKZI^[\
M-RV?W9,:]FEC"9_\>(_R<\9K\I/$?A'PI9?\%'/V0?B`^FFY\9^.?V;OVG/#
M&OFW34;'13K_`,'KCX=&R\37?AVPL&E-SI6D^+OBEX)GU*XU:Q75[CQ'X7F`
M@-O%82_J5910);;4>6Z?GEKCS",=>"J_3@_ABOT?`4,50R?`+%5XXA5OXEHP
MBW:T4FX1C9V2;<7K>[;E<_-\;:KC/W.CLFTEWZZ];WOHGY+2W1+?R;5^:'H/
MX?:BLT+``!Y3<`#_`%A[?\!HKJ^JT/Y/_)I>7GY?B^YYUE_7R_R1RD5Y%.F9
MH$,?_/`J_;_;W^_7R^GUK\Z_VY=>U+X7>-OV7_C_`']Y<)\&]$\2?$#X!_'6
M\AL[/4M7TGPO^T7/X#M_A7XX5Q%;16C>%?C#X+^'[S7$UK-'96>H:]/=WCK<
M3K)^AH\W[3M`9$_Z:I'&./4>:W;MFO.?B?\`#/PA\:/A9\0OA1\0-/FU+P?X
MY\$ZCX5\2:?IA!U6"/5X96L-4T]2,S:E#J:WFK:/<(89-)N].@,;S-MD3X"%
M2CAJ.)PV+P_UG#X^RQ5-K6:EH^66KA-:N+5DG9V:LCZ6I*5&O'$4FZ=--2O%
MO?:SU3=]=$UJ^O7\G_#WA'1?'?[4G[6_@_Q_X<\,^)M&O/`'[(NEVOA6'3K#
M7]&O="T;PC\>(H]%T^QO%N(]2L-&\<Z7K%R\,6NVD-E%KKS:K8:\/"OA4Z5Z
MUXV^#/PX^&/PI\*^$/AGX4L/`UK=_M0?LB^(-5TS2+1+_5)]>E_;=^"VIW/B
M'4Y+^/5;K7)FMK'Q"-;\2^*=0UYY-1T?1])\':[K,<)O-8^;/#'PY^)V@?M`
M?%7X1_$;XG:_X>^(>E_!%/"?A'XF)J6C:UXA^)GP3\,ZYX=MO@]\9=`U?QGI
M<GA#2OBOX*7XB?$;P3^T:TAU)-`UOQ=\.=1\--XX'C72K9/8M?\`!&J?#+P;
M^SU^S5\$_B!/I_BCQW\:?#&AS>(O'GBCQ?\`%#Q[J/A'3/!VN:A\6?&>L6LW
MB3PW?^%?$'@[6AX>^)7PFUZ]DF\(>"_$%M\(]/N?#WAKQ+XABTBZ\_"Y=5AQ
M/D]!8S%4\!^X<,-[.4X.$*22FZBYIN$9)0C"+DDN:$E34.67W.*J826`^LJI
M*2G'FYD^6*:Y8^]*2NKQ3;4G*ZCIJXW^@_V;;RW^./[37[0_[1VFZ@;?PE\-
MC>?L8_`Z_LVUF:VUF[\.^(?^%D?M.^.]2$D`AN;#Q/X_OO#G@+3KJR,4=S??
M#2]@CU"58C##^AD)B=/.G01_],;64I_X\%8GT^[WKQSX)?"SPK\`_AEX-^$7
MP[MUTOP=X1\*6/A?PY<ZAJ%S?SZQIFA'4=2N?$NKZTCA]9\2^*KO7I_&.KW$
MEK;SRZSK=V\D]SM5S[#96\471-G/W&EW_D2%X_"OT_$TJ>65*.$=ZN'I6]C"
M[NM%NU=MN]WJ];W;>I^=8>G%U9U'K)R=G=K1K33IM]]VK7L:OV^V_O\`\O\`
M&BLTO:DDB`<DG[Q_^(HKH6J3[F7L*7\B^^7^?E_5V<O;*L@/F*LG`^^`WI_>
MS4?B.22V/AF:VD>WF>VT\/-`[12L(QJ!C#21E7;89)"F2=N]]N-S9**^"J[1
M]5^<3T,5_N:]?T1^,_[:.IZE#_P6&_X)G^'8M0OHO#^L?"S]JNSU?0H[NX31
MM5M)%UG47M=2TQ9!97UL^H:9IU\\%U!+$UYI]E=%3/:0/'\G>*?%WBN'_@NC
M_P`$_-$B\3^(8M%G^#'C[3)](CUK4DTN;3?^%N?M1:;_`&?+IZW(M)++^SO#
M?AVP^R/"8/L6@Z+:^7Y&EV,<!17W.$_Y'62_]@?_`+EJ'94_Y)J/^.7_`*7$
M_IFL(XX_$^KVL:(EM;2:6+>V156"`/I&G1,(85`CBW1QI&VQ5W(B(<JH`CN2
M1=8!(''`)`[]J**K./\`?5_B_0\K";?=_P"DFBP&3P.I[#UHHHIQV7HOR)/_
MV0``````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+W!U9F8N:G!G````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#<V,C8`,3`T,3<S-C,P,3$`,#(R-C$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/_8_^``$$I&248``0$```$``0``_]L`
M0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$
M!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B
M<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'
M2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ
M\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$
M`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&Q
MP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-45597
M6%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY
M^O_:``P#`0`"$0,1`#\`^0O@UX6O?BQXG>QMA<Z;H6G.&\2:[,D,9TRT\LQP
MPVQ++'?7=XD4UIIMG%!.7E*^:$B2Y9?U'US1=&\/?#S0M.5?L%E;V*VJ*ZX%
MO:6\]N+221F=%<SR7#7$KJ-S33/+(3*[EOP:_9*\!?'[XP_MBRZ?X'^*/C+P
M#\(?A5%X/\?>/;33]7UB7PCKVFV"V=]9^']5T&TUNQTW6+[QEJ=[K'A2W;4(
M=1?P_8WFM>)WL+FRTN[L9/VD^)%UJ'Q"\<:;X.TR9KB?5I98+&#SYHK.UAL+
M)+^^E-I$JVTRV<-G+/'YKP11B"$0ND31FOK,UP2P&14,!A:<JN:9_1I^SC"W
M/2HU.5QDZB]V+E?2+DFN63E9:G-@*V+J9X\7F,I8+"9+*<E"JITO:5O8QFN>
ME449N,H2C5IR2=.<*M*<)RC+3\I_VI=>\9:W^TWX1\$?`CP._P`2]=U3P:^M
M_$"UL4\A=*MYYY+/P[J)U?4+^PT72WGAT26*=M7N0EZW]G1VO^FR0L/>=%_9
M@^*TMC#<ZK;:!IMR(BUQ:7&KBXD5I5RL96RM+JVW(ZL6,$CA67<#NA4C](/#
M_P`*-$^&T2^'=`L+&Z\4ZQ="X\0>)H=*AMM8\3:M%\EE)J,DDDUU=1V%E"-)
MT>*\O)XM(TN)=.TP6UE;)$UG7Y)=.,]N0C?9IA&ICCB8O$D@$[!MI$LC!G:1
MF=@4#*9"DDF/DL7PW@LFPF%PN-J3J8NGATIJ,H1O*/OSUO)U&G+24>9<B@[H
M^IRWB/$9GB:V(PBC]6KUU.#G9N%-QC"E*,4_=C)P<N623YY3NE>Q^3/C;X5>
M,?`R+>^(-.>2P+VT4>IVDD5Y:K<NUXZO*&02VT0C@F?[1+9N58V^')D2&O,4
MBBCBR6F>>,_,-S%1+Y'[J5HV83JOF^9M+1Y9&#PJL@EQ^N-UI]MK5K=VFH6D
M,\4ZFUDM;Q$NX#;"!4`DA<-','N&*EI8RNYEC,S+U_/7XX_"^X^'6KV^IV$D
M4WAS6]0O!;!(88(M)NI!))'I31BZN"8X+-+N:SG5(@%LY(_*MS!OK\NQ>(A0
MQ2A&,H0JRFJ;DXZ2CKRW^%OK%MK9IIMH_4,+"5;#2>U:$8NI#3E3Y8R7+VU5
MGJ_BLNJ/)19QL`P-T`P#`*!(H!YPKJA5U&<!P2&'()!S15&/7%$:!-2LF4(H
M5C)M++M&&*K`RJ2,':K,HS@$C!HJU5I.SY:CO9_Q:>OP?WNNGW^17LO^G<_N
MCY?WO+^M;_6W[`5Q#X$_8Y/Q$M)QJ?C;XR^+-=&N"T:"Q_LC2OAO(EGHMCJ5
MT%:]FO)=3\3>([E]T0@BLWL"NR0@2^F?\$QOB3XA_:!^)/[57Q*\2:!8)X:^
M&OB/0_`/PT=E:[18[:\\86'BS5K/6[V)#)<ZP\F@/.;!HH$AL8[5#-'+;SM^
M5_[+W[5]A\./@A<_!KQ#9:M<'2O$&O:SX2U71[6S:*ZL?%$IO]=M=2;4KNRN
M+>5[NWCGM=L$[P^=/&AMH8+8/^W'_!'?X)W?PU_8R-Y=SK/J'CSQ/XLUF^O"
MLR"Y6Q\8Z_8!W$@1`Y2Q@1C!%&LD\<H8@EJ_J'(*.&QCRVKSQKU,)EF&52+3
M<Z-94HQFG=OED\0YS:?23M9M(_G;Q-SS$YAQ+Q3FC4J>%S#/L92PMTHTJN!4
MH8?+XPC&,4J=/+Z5"G:/*HJ$$HIII_3VK?VU!KU_KUO:-"OE7D5K>0I*T(>U
ML!;R0"99%0W,MK.7;>S/&S#(091?A7]G_2_CQKMIXNU3XY^'[CP+J.H:_=W>
MF:%J'CK0_%%NND-IGA_R;NS3P_J^M0:2DFI0ZPT&@B2&;3C))F%DF@G?[^^*
MDL=C;6;H[F339+DV\3>6`BW<C)=3-&%!W2QKO/FB3:NR--@6O@+XC?M6?"'X
M1>*/`/@WXAWGBSPYJ'Q!DUFYM?%MUI6E2_#O3%LK[18$TS4]8DUS^T;+5`VI
M-<2VD.AS6$6FRV=VMTKFXMU\+B[+</4Q].I6YI5Z5*+@X-I*,W-2=EI9\W+)
M6U4&GKJ1P;CHT,*\3[L544,/>5Y13H2;MRM6U4K1DVG=WW=S3^/GCWQ3\%/A
MOXM\9^$/`NH?$'7-+T>/^R]#TO1+G69+C5-1U[3],COIK>RB.HW-AHMN]SK&
MK0P3VLITJTN7%Y8#?=IY[XAU2X^+W[*.D?$GQ;I-MIGB"]^%VF_%*[T[3[2X
M:+3-7@\)2:W=QZ;!=R7E];Q7'FSM#9L]U>1V\DEJ);B6-?,]@TKQ]\._%FIW
M%MX-^*_@/Q1K$%K<:NWA[PSXKTOQ#K!T1)X)6U9K?1+JX^P6RW%U;1.9Y([B
M&:1K>2WA:1&AO>+;DZCX$\::7<B%HX/!WB"URZ^3$S2Z#>0R))(FR8J%E#&1
MBTQWNS!V`)_F[BC_`&>O3IJA*FZ%12IS=VZL)6ERN^NKC'56:LK:-H_H3AE4
ML76KXZEBW6AB*4:2I0E>E3<5%N6]KW:5KR^)O1GXA0^.O![11,OB&\16C1E5
M@C,JE00K,=-8L0,`L6))&23UHK!N/AE8&XG,>N7\,9FE*0Q/&T4*;VVQ1L=I
M:.-<(C%5)4`E0>**\]8G+6DW+%W:3?O3W=KZ\Z\^B]._K/`YC?2I0M?3]WTO
M#S\OP9\O:"+C0/%B:;=VQM7&IWUG<QS)ON()@)'FW+$ZHWER.5B1GD1G=VB=
MAMED_L,_X)U>)--U3]C/PSI-IN4^#)?'NCZ@CHZQQW-SXP\5>(L0+YLQE,ME
MK=K)$6BA`F=%=0$:6OP4_P""D7P]T/X=^#-`^)NBV4</CR;Q+I^A:7Y@#VNK
M1WD<4MS;ZRMND`E,%E:W31SQ3I)'$\ZX2-VMW^T_V*]?NOV2[;Q%X>_:(\2:
M?X$LOVJ_#W@?Q3\(+#6+B6QFT36/!/AIKWQYHWC&34;2SM_"5W"?'/ARVTAK
MV>2.\OE&FS7D6JO':W/]G\$Y#CJ6+Q5H*=#%49Q4XMN<9X9PK*FTDKU(P=>3
M3:M&+D[J-C^/.-\=AIY?A[U.2=#&4IN*44K5.2+D[;>_4HMNVBJ)=F_O?X^>
M);>VN+L'S@D.Q)HU3=$6\QFM9$!=9751($?)1E*D[G$@"?F7\8?!>@_&+PDW
MASQ!8VEW!INJ0:WHMW>VWVJ'3=<LK?4K6SO&@?+21M;ZS>VEY`HW2Z9=7T,$
MEO/<QW,7T3XLN_$'BQ-1.E76G^(K72S=OIUR=9LG%_IGFB-!;WL^JQV5U:P6
M*1B"XAF6.5HDBAEE,L23?,%SXTN8&DAU1([)@\\$J.CQNS6\YC$:J]PT@1'+
M0ML0+&WD+(R(`%\3CO+\2JBJ.C6]C*G4A&T7'FYE:46TTURMMI[M+3JSZGP]
MS*.!EAJN'JT%B\+B,/BZ+DJ=:,*M.4:U*;I58RIU%S0M.G4BXR3M)/9Q?L\_
M!?X??`:VO8?"VC:0_B#4+F5M7\20:;'9W<Z-96-I<:=:SKYM_::&;BPCO4T]
M[V;-[,]S-*\O(^J/%FKK8_#?QE,T3%Y]"UF$RLZRJ9+^T%I;1HP?#DSS[Q&"
MJI"F-V\!&^/;_P",GAGPW/!<:QK5I:VZI%&51;AYTD=Y0B-:V\4MT4RCJ9O*
M^S`!P)`2M</^T#\4_$7Q*^"'B/Q#\#GTOQ5;_"BPN/B=\0;DW+6VFZ9H_A;0
M+O6H;+5EEOK"\G22&"XU*[TF"6WO[FVTII(I/M;6-O=?SGQ%D]>I[/V46]8P
MC.I5=E.HXTZ<9SDFX+F:3WW2MJK?O^59Y#$8K%8NO+#PJUIU,7B/84Z5"$FW
M[2M['#T8PIQ=HR<8045HDK6/GV[UTPW5S"EW,B17$T:)ND^54D957FV8_*`!
MR2>.2>M%?&6F?M,^#=0TW3K_`%JW>/6;VQM+O5H[%KJ.R34[FWCFOTLT=IW2
MU6Z>46Z/-,RQ!%:60@N2OGO]2,^6GM*6EE92NM.5;^SU]?/3I?U/];LB>JQ$
M[.SUT=GR[KFT>KTZ:?/]6_\`@KF2?A;X2!)(C^)D`C!.0@'AOQ$0$'10"`0%
MQR`>PKU[_@X,FE@TO]C*Z@EDANCH/QMS<Q.T<Y_XF'P'7F9")#\KNO+?=9AT
M8@E%?Z!\'_PZ'_8=FO\`Z@UC^+N)?][I?X<)_P"XC^;G3O''C728F&E>,/%.
MF!2Y4:?X@U:S"E]4FWE1;7<>-VYMV,;MS9SDYK:Y\3?B1+!K<<GQ!\;R1^?(
MNQ_%>O.FTZ?<@KM:_(VD1Q@C&"(TS]Q<%%>7QU_N<?\`K]4_])1[O#7^^P_Z
M\1_]*9Y4_BWQ5<:+;6MQXF\03VLDBW$EM-K.HRP27#H^^=X7N6C>9LG=*REV
MR<L<U^MW[#=Q<0?\$]_VY;J&>:&YO-+^+MC=W$4KQSW5E9_`:WGM+.YF1A)/
M:VLUY=S6UO*S102W5S)$BO/*6**_FOB#^!3_`.PK!?\`J32/U+)/][C_`-@6
M._\`4>1^1>EVUN^F:<[V\+N]C:,[M%&S,S6\99F8J2S,22222222<T445[<M
MWZO\S@/_V0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W)E9&-R96%T=7)E+F=I9@``
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,T,C4`,3`T,3<S-C,P,3$`,#(T,3,S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M84$`0@#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`
M9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`
MS)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S
M,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68S
MF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F
M``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F
M9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F
M_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9
M,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9
MS`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,
M`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,
MF0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,
M_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___
M9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_
MS)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````A^00!``#8`"P`````00!"```(_@"Q"1Q(L*#!@P@3*ES(
ML*'#APJM0&'!8@7$BQ@3/MFX,:/'CY@NS>$(Y:/)AYTNB9R#[<G)EPMWI9PS
MAXY+F#@-[@HV$PJ=G$`'[MJE<@Z4)R6#`J5#A^8</4JQ,55*<T]0*)=^!J4)
M%:<5.KLP:07J=.$**U:N"+HR,&T@07N^7AI*-&K9A"N@Y`&4[!F4%2OTZ"GU
M[)FG2YB&7O(4%=M=@WE7<"P5:*,*R7F>J:2+V*I2%C016J&X0H6*)Z2>E`;\
M!!"R2\$4,VX,Q2A"BD](D%!A135@P'J0=0H6>]?LJ*!O8H/"',H5%JI)E.;X
M>\4>4IT.$QT;-/E&R16I_O^6_MW)$Z=%-Q\?N((%G:R>,R+E^)UU[_H<T:N\
M-',QP;RU;7:)27LX1=]&:/E&'TT"=C*<@X`0!,4>3<WA26S<8>34'))QA%9O
M'>I'5##")),,*35UM9PG>C`X%R8$CC229!TJF-\<^ZDD#"FE>-))370PUQ0@
MY\V1W25)M95D0T>)IX(3+#!W7I$Y*J92'AR91Y--5`XHT(3,[1*?0U.J=II@
M+1;IHDHIB:0'1P``4..!`JT`ED@JT3'F0M"19,4G%-*D)H[[S9%':O?%*>=E
M'29I)U%S)&;<0Z/19T4@GS1YHXND\,C:$XK&22,+_Q6ZV2X9+B31>8+MH>F!
M_JAU*MBGH0)P6Z$X#J4B1-^E=<45$MT'V&6F!2`=8+4"$`!!`4A695$>^>8%
M7('$M8)N*AQ;G6^_*;JL0.$1FF-H&57$0A=K`5O:;M<R.AVWR"I+$'2Y[C=4
MJ@\!9D47@8PV[&K3"9;EIRO8^M\3]LXUU'H72=:%NM7]]H0>G7IBY(^JP5G0
M"G/!IK!*#$/4'F`R!!+(%5WH8<6&.1:UD8'5!8"PPG0M_%%D)`/;6Y,;XBCH
MRXO]QBC"BG'FI4=22@SKTH)R^803$=?+&:HG-;<T=0L*.M)IDK%WGH`=X]LP
M?1'/^;*!]&W,8-$POC1RV9]NVK-M!'U-:"=BX?3V];:;JGE)'H_->U1-$P)5
M4=E]%X4>2XWA!?>!(_WX,^.-.QZQW/D567E$ARM]WDP9;[BY0E`DF+6!#&XY
M>D3WJ>:$UD[EX0E'JR>$5A6XGZT[3>9943MDO^F!>Q68.[7D[W4"=GCNF3_M
M!(M[(O_71M,S[Y033U*._+P=U?F$]><1K_WV`FU$ZL9R5T%^0><=CPV-*Z2^
M/EI[U/]>R-BTKOKV5AP6TIV>P!]S).*^RJ%%2`G+T_H0(B6YM4QLVWO5Z00$
MP=_UZ6KH"0O^I'<UR.6I@J/3E-D@1Z@%'B0\'?2)"4^(0OHP9X4*T1=27@C#
M&MKP(P$!`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]R96DN:G!G````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$P-C<U`#$P-#$W,S8S,#$Q`#`R,C0R-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JSX&?$WQIJWP-\%?%=]/T;
M2-:\-ZK\3;[PS86>HW&DZG9:7XG\'^.O`7A'6M#NXYK]]=^)1F\4Z9JLNGRS
MFY\0^(X8O-V-Y"P^6_%KXCW'PL_9HETN34KB;Q-XOUW3/@C!KOB%]/GUSQ98
M>%;.'PYXH\8![&SLK:.SL-,TS6_#_AK3;6V@TSPY;W5Q-X>L=-U;4M1U*\Y7
MP;\2;/PC^S9X4?3EM7E^'%SXS\>M9L1!Y?B_5-<FTKX96(^SQM#"VCZMK,&L
MD?8YI(IM+TR=%,<$\%W\A>(-,\7?'7X$V3^#]28Z%^R[^S5'\4O&^IW!NM7U
M#Q!=^.?&=UI.IWVFWEY:6-M-XBTZWL]:\6.42VB\N"[9XUA8>7^[8F&79)A,
M/G,71HK`X&AAY3C&,6G)1C:_SML_6Q^.91A,RS3$N+A4G[:O6Y&^9\M-)-1]
M%TZZ>I^F7Q1\<K;?'C]E;P3IDCMI-[J.H^,DB7[/#ILUC<>#XO!OA.:XM_+"
MRP6EA>W0MHU*!+@BX@:.8!J[[X>?%B#Q'\,/'/Q3AF:XL(];^)VL:>'!*BW\
M!7NI06$.`0QCOK6TLS,JL#---(86@1DC3\L/B5\0?$VD>-?@7-XHT_5!XD^`
M7PX\'>"/'6L&!K6VN?$/@'Q1J&K,UA&;B:(+XN^'&G-XUTUCJ=[))I]AJ!6&
M<-%'%])_LQ?$;P;JG[&VHQR:G!96.K>,/!/A71L_\?6I'XP>)O!5OX6L[=22
MIU+7XM7GGNW\LPRPP786WC.6'T64\19;CL-1E0Q,(2G.$9335TI.-W?79:O_
M`"L89GE-;"U(QKR=I2C%MWO%-Q7^5_EOK?[[MM9UKP3\._AZUR3JFOVTOPUT
M'57U2%+T?;M1U[2/#NKEK8"!;F6!M<O)+6&421M#:Q)<QW2+,)O0--\:>&M"
MUJQ&J6NE:_;ZD?&'P\\8_#^>S_M"T^*'@26:23XE?#S6]0N6E>ZO;C1;[4-5
MT!KEY)="\2+87ELZV5O)I\WS]\>CK6L>/_A%X=L+J'1O!'@/XM^#OBA\9/&1
MNTATJQ\*^'(-=?1-`G?/S2>+=7TV]U]XE)DF\.^$]1>V-M/J^FWMGYO\/?B9
M)JGA3]G_`.(&OZ7JND^-==\.?M9_%K5/!TL<$FH6=MX=CO=.OHKI?(*Q7[P/
MI^F9E#7'VB65XG0J/+SS;%9!GV%Q^0PQ%+'5HU7#62E)-V2:LU]IK6VZ3T.:
MG@L7EE98N$Y5\/&2GLG&*BXRNM.EK_=='?\`C/\`X*N^!OA7XP\6?#"P^(/P
M%UVQ^''B77?`5EK?B7P+XD3Q'K-IX/U2Z\/6^J^($T[7].T]-;U&'3DN]56Q
MT^PLUOYK@6ME:P!((RO3Q\(?A#XM`\5ZC\,?`U[J'B<#Q#?WD_AC1;J>[O-:
M_P")E=7,URU@[7$L\]R\LD[.[2N[2%F+$DK\9?AYB8MQ5>JDFTDI.R2:5E[W
M17M\O,^G7%=)I/FCK9_9Z\OYW_'R/YZ-`\5^-M+\.>/_`(;>(+`V?B`^,=<6
M6"&Z\JZ/B'P1J=G<:GI]LLLQ^S&U1;;5+>UE)F-J#_I`D(F7Z*_9'E\3^&/`
M'B/3Y?V5/!?QE_X7QXOOO!GPJ\4?%;Q!?:=\+/#'A'P3X6\=_$K4F\:W_A^U
MN-9U#4[SPS>7W@SPUX+T>Y@U;Q#XSO=(L-.D$TZVTT/[7/A#1_!W[0WQ`UB+
M03!-XD/ASXIP:A9AGC_X236=(;0->U&&&4RPO]OU#2+H:I;-')'-"8$VH2S/
M^FW_``18^)/@_P`977CK]F3Q#JNFR+X3\=:+\5/!?AW4I;6PN]/\,ZQ!<6NK
M6FE1"T4IJ^GZYX>T?6-+O[18=5T]?$=DUK?13F*:.O%)9GDO`F6VA/$.6(I3
MS"3YG[>G4E"-)56OL1;35GI=7-?#C-:V;1RS'T:\HT)04Y\EOAGRJ;^%[Q;U
M\^Y^7?[+]AH'[<&E7B:1X&\+?LT^._C5\&=?\3:=\)?"OBWQEX]\&:E\:_V=
M_%.J:!HNK>)8?B5-?>)/`^H^//AOJ^M:?9:%8ZQ%<Z;X'+W[Q7D\.7]S^%/P
M5F^%'Q6^-7P9U/0VU'PI^S[I_P`./B\F@I=$ZPVM:;XVT6P^#LNDSRZ=::2J
M:0OB+Q!;O/=VZ6Z#P7!,]S:0V=TT_P#4=^S1^P9^S/\`LA>'/%_A+X2^#]<O
MM+\>>++KQ5K5WXVU2#Q/KZSWFD7.@_V5H_B"33[+5=/TV#3KVZ@MREX^J2>>
MR7NJ74&(AZ1H?P>^!^M^,O%'Q-\)Z3H^I>*]2@T;X?>+_$VF7[ZR+F[^'=WK
MNF'PE=VJW"J7T_6M5\175VMQ<RLM\RLLD*QE&_":'$/$V$PN9TL-/V"M2EA8
MTY_PHRE"ZIIW>UUK=OR>I^I9SD>19I+W95)7:6S5_AOVLVWIIIN?S6?%GXL>
M&_AQXW^'GP-^.?Q$_9Z^&&M:SXZUGXE>*O#7CC2?C-XXU?XBWNC6(T+P7\/[
MCP'X)TG3?'L7@S0_"=_"8M3TW2]?L++PU97%S/X@O+B2[O[F%1XOTGX,Z!^T
M3K5W\-?%/A[QM\6;RR@^('P=^(>B^+O`^C?"GXK'XLZ3>V;:?<)#J_AZ?Q7\
M1O'?A.&:PDU/6;C1K30M"37--MY[&]EO/IO_`(*,_P#!&WXA?%K]H'X*?&W]
MC/2?!7P^\:^#-2UZ_P#&_P`3[?Q[9>!_C1#XDN_$UA#IOB[1-6D\+:OJ.K:I
MI6BM/96NARZFFEZA:*FGO#$\OVI;G[3?_!-#X)_L:_L>_P#!07Q7X0\7G3-!
M^,6DZ#+\,_AAI6F'PU\/_AQKME;^'_"'AC1O!VDB6.TL_&?CC5+:Z^(OQ*U.
MR\L^(-8:\U"QM=$L)1`OIY!G.=8+%T<7A:N(CF%3$49XKE=YU4JT').]U9Q5
MGIJ^9IZ)#SOAK)<OP.$HT*M&O0>#J2Q="&M>G)4V_P!]-MQ:5KNVK71'A/P(
M_:)U.U^!_P`&K:X+33VWPI^'<$\TD`FDEFA\(:/')*\I.97D=69I#R[$L>31
M7Y1_#WXW_P#"*^`?`_A<V?CRZ/AOP?X:T$W5MX=EEMKDZ/HMEIYN+>0%A)!-
M]G\R)P2'C96R<YHK^FUQ!CI)2>#E>23?N]79_K^?9G\\/"97=VE3M?2S=K7C
M:VNVW];_`%M^W%X7US6_!^F^-]+FF@UCPKI&OZ=?VB1K<W$NC:M"+C2;VX**
MI?\`L[68!)&V^.*.UN[U63S)(YH?$/V-O&OBCP=^V3\,OB7X4%M':W5EHV@Z
MYIL9TW3]0\93>*[<>)?#&BZ-J=VIM[?5=5_X1S3O#]OIEVC2WPCM+6UO+*YD
M:]'Z3:K8:?KVGW6CZC96FI6>KV$NBZK83K+)'J.F71*3Z?.(YHKCR9D=X/\`
M1Y[>X$<C"*>.79(OX^>-/@Q-^SK>>(-<\0SZWXH\,>+/'=AH'A7Q+HDLUUK-
MIX:TO0-*NO`FHW6EVMN6T_Q!X>37?$,$=UIEK;7=Y)I^EQZ=%#>1S27G/XDR
MAFV'GDZQ*EE]2FFXR:]G'V*4J4')+1*226J?R/C?!7C&.$]AE+J-QI.%.%&^
MRO&/*NKNM-]?R_O:?6[GQ9X$C?3)+6WOHX+2"<:O?OIUM;7L[0R7EAJUQ:17
M<UK-%8/-Y,,3QRWEPB_99T!45X3^QAX:^%'PV^#EG\*_`GCV#XC7EOXO^)GQ
M!\0SZNE]H7B+5=9^)GQ&\1^,M9:[AU&WLKG4ET74_$5YHVD7T!AB/AVTL()8
M;R]274+C\WO^"87_``47TGXB^)O#_P"S]\=!9?#SX^^+/"UGK_@8ZCK6?#W[
M0GPL\)ZKJGAOPA\1OAIJ=I$^C:]KMO=Z7-IOC#PRNH6?B_2+S1KW4A:2Q7]C
M9P_O9<;EM;NZGCC2VDLG.JW=W/IL-U8Z?9JT^_4];GTVVTRRL;=4:XCBDUZS
MG1%+7$<A#U_*E#+JD<5C%]:FZE*I!*$Y6HJG"4>51Z-*U[ZW21_84X8JGAG4
M='V,<4^6C[5<CC&5EI=*V]U;5::Z(R=4N[2PAU-[[5=-T6QTJRDU"_UK4#/!
MH^E6]O$;F47$XG2:=(TC,MPB3B218V$3(Q4C^4;_`(*<_M02?MI_M!^&OV:+
M-M6C_99^"^C7/Q!^)GC#1M1FM_\`A<?B:XTVYE\4:=X9M4ENH[32/!VDVT_@
MG1KN:WN;VXUW4[>."[GN2BC[Z_X*=?\`!2_X3^'/A7J/PJ^$NKW'C77O$,6M
M:MK'C;29'C^&/A#P[X7FM[77WTSQ++8HOQ.\2V-J-6G&G^##JFA0WEM!;ZSJ
M=C;?:)3^"O[-^HZAX2M/!>/"*+J'B#PMI?C_`,1G63=ZI8:'?:?J&B:SX`\*
M7^I?:8C=BQ\<W<?Q-\6V5D\-OK3Z5::9']CM!=6UU^N<,Y=EF5Q>?9MC,$U-
M.<(U91]^2LU%*Z5FTDOEI8_-^,<_I9)@:^6U-:CHU%*-]:C<+<K;?,U+9ZVL
MS]A_#?PR^#UKX=T"V_X0+P_H?V?1=*@_L5/#7B'4$T?RK&"/^RUO_P#A)T^W
M+I^W[(MYM7[2(1-M&_`*_->XU'4KBXGGOO'WBVXO9II9;RXBU:Y@CGNI'9[B
M:.&`1PPI+*SND4,:11JP2-%0!05]'_Q%3+$]*.!2TMMLN6W7R_K6W\U+B>6G
M_"<NG1_W/R_3U/H&2:94OV66162UG9&5V#*P@D8,I!!5@P#`@@@@'J*^0O\`
M@J'<W&F_L1_M%:GIT\UAJ6F:-\/+_3=1LI7M;[3[Z"^(@O;&[@:.XM+N$(@B
MN8)(YHPJ['&T8**KB;_<*_\`B1\-X/\`_)8X;_L-PO\`Z?I'\T_[2_C;QGX<
MTCX0WOA[Q=XGT&\\!_$37[_P/=Z+K^JZ7<^#+^YL_#U]<7OA2>QNX)?#MW<7
MJ+>3W.D/9S2W2K<2.TP#C^J[Q5\9/B]X\T7]@3P%XY^*GQ(\9^!?&FJ_""R\
M8^"_%GCCQ/XB\)^++/4_$FAV>I6GB7PYK&J7FCZ[;:A:75S:WL&J6=U%=VUQ
M/!.DD4LBL45^"U/]WQW_`',?^ER/]/\`CC_=LD_[",)_Z<HFY_P6+MK:U^(G
MPGT&VMX+?0[3]FWQ5%::-!%'#I5K'!J^LI!';Z=&JV<*0JB+$D<*K&JJ$`"@
M#EX_W&A>"((/W,"?#?3=D,7[N)?]!MONQIM1>@Z*.@]!117@<6?\DIEW_7VC
M_P"G*9_*/C#_`,CV7^+]8F+1117P1^2/?YK\X'__V0``````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+W)E:3(N:G!G````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3$W,3$`,3`T,3<S-C,P,3$`,#(R-#<W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/_8_^``$$I&248``0$```$``0``
M_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!
M`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-1
M80<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8
MF9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;G
MZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*
M"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"
MD:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-4
M55976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6F
MIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V
M]_CY^O_:``P#`0`"$0,1`#\`^"/B!\0].O/^"AOP#\2Z1XON[KP9>?'7X[?`
M[3[>WUE;GPU9:+\%?V>/V9_$FF3P+;W;:7!>6_CWXE_%6VG\E@EI=WDT26]K
MJ-UJAN/W8_;J^*"Z9^Q\?C)HFH/97<_A?X="&[M+G9,N/C'X$\&ZFEI/;7"R
M-/'H?C"T9$CN2R1.AD_<.B2_Q^>"-`O++]GFZ^)%Q\2_"=I\0/@KXX\%?M$:
M%IU]X@TFYN%O?CAJ6H^"OB[/+IL5W/>M9:2GA_X4KJ`>SN&NIO%&E1:79_:;
M>_%?T3?"OQAX#_;@_8,^(OPQ\"WNI3S:'X:\4:786M]#JMM+I\VHW'B"Y\",
MUSJ\=A"UW8^(_AOH?ABZ\F\N+<ZIX'O);RY$5_97^K?H'`_&5'.<)F*Y7#,Z
M.-Q.*^KU=)UJ>(5).5!5'RSC!TZBG&#DX^ZY)*46_@O$'@*MP]F>2/EIXC!R
MR[`J52G4HU8TZU*[_?*$I.G*=&I1J*=6,>?F:3<X3C'Z]_X+(>)_B9X97]G_
M`.)_P\L;[6=&\.Z+J6H>+DTE=5N,VRVOPA^,-K);QZ4PACDET7X0^*K.S>XF
M0/?:D4A)2XNIH?H']MWPUX=^(VH^,/CDEQ;ZOIOQ&_X)H_MJ?#;1KV`126-W
MXE\(W7@#XZ^%K&[NE2X\R_O_``QI_CQM)0W<TK6L6J7-G`MM#J-TGS[X]^.W
M_"YO^"<OPL^-WAV*VNQXH^&OA741+<0I+!?R?#7Q_HW@[Q[H5S#>P1C3X]1T
M'3/%7AR[G*&2RM?$5W/;K>/;6S/\W_#[XX:K\0_^">O@SP1XJ\2:>==_9R^/
M>B>`_&^JI-9VS:S\)/B#X#\;_!EM65MUM!*FOZ%\6O#5O<6=I<WFI175M.BF
M2:SGFAY.*WAZ^4YCA:,HRKX6C7Q/+K"<,-BY3IJK%R4?<@X*346^1I.45N5P
MY3K83B7*L<\-5K8..=8:DIQI2J0DU2PF)G3:C&3A.=.I;WE%RM))N5.2C\J?
M#WQCXL^-7[`7[0O[+WB[7/#ECXN_9:N-,^+'P4T?7;]+75/$/A3X4VD6K?!W
MQI]EO;B:_P!5@U#P;J?B;X<>*;K2;"WM[W4-)&EVMY%;VT\2\C^P]\</&'PY
M73%\.:QXBTS6]&L]+\1>&-!UJUUW2+;PIX4/]GZE9Z=J5_H5S;"Z@^&7B?2F
M\,^+[9A'_P`([\._$7A3P=<FVU._N87\VUNS^*6AV7@OXU?#+]GCQ%\0KZS^
M$FI_!GXPZQ/K'ASPO:M\,]9?[3JUK;Z7J^NVGC34KWP_K-AX7\1^'M5L?`C0
M7US;7FCVVHC^V[^SF^9O!5S\:O$7A<0_#_P-+J6N^&M0UOXS>$=9\._%;PS)
MH6I>&19P6/Q.\$:]=:DNAS76F>.YO$NLZ[K6AI+KNHZ+IWC07>CSSGPGILFF
M?B>2>(^(YN'N)*]6C*<,-_8'%>!=:E5YJ>#G+#RQ56G&I.*>(POLZUI?O85*
M$^>,6X)_TKQ/X54H9EQ9PK@L-BJF&S%?V]P9C%@L31<JN+E'$0PN&E5H4Y57
M1KRGAU*FI4YQKTIQG*CSSC_:+X<_X+9?"C1?#V@Z/XQ\%:]<^+M)T;2],\57
M%E>_".YLY_$EA8P6NN36ES=Z_P#:[BVEU.*Z>">Z_P!(EB9))OWK-17\;T/[
M>_[/6FQ1:=XYGO?#7C;3XTLO&/AR7X2R^)I?#_BFU40>(-$D\1V^G&#Q!)I6
MK1W=@^MP$PZJT!OXSLG6BOW"&7<,5HQK0X@RI0JQC4@GF&&5HS4)133J)JR=
MFFEM+;I_.CPW$]"3HSX?S53HOV4_^$[$?%3<82WI7WCUUWOUM6\*S_'WXF>-
M_A%\`_V8?@!_PL#QU-X7O;[PM<ZG'K]KX7U#P[:^%[E_&B7EV-#T$WL/]@3Z
MCJ%Q!ITU^EA=QZ#KI:TET^"\B\U^#7Q*^(7[%?[4T_@C7O`P\$?$/5M9U[P+
MXX^&'@O7[7QAH.IZ;I5[=66N:5XJTC5;O3_%7PZU2'4]/TO6O`5SJGA>XU'Q
M3IDECMU"+3[NV2Y_77]A?X<-\*OVHOAA\(_$FN7>OZC\+O&@N?!?Q0M[.]T#
M4=4\+3Z+XK\0Z!J7A[5Q>0W-K))HUA<^&M6NM"UJ19#I%_ITLU]$]G:W7Z*?
MM!_\$FO`7QR_;77]NP?$^Q\*ZW'XH\*^,-;\`Z-\,]\VN^*O"^DZ+8'75\;)
M\0=)FTFYUVY\/Z;JOB"WB\(:D+UH[BWEN)5O;F:OY`R[B_*^"\?BZ6.P6-RG
M.LMQ6)J1J^TQ%1XFK*;M4YI^[*G-+6FH6CS))ZW7]N<0\%X[CK"Y7BEG]#.^
M&>(<ORR='#RP7(\O@J%*E##JG0A&;JT91;G-5'+1<\4FC\C?@1\;O`'[,,GQ
M(^!/B7Q6OB?]F'XB:]J/C?X*^(IWM8Y_#X\8:+;WGQ3\&>)KNX8:##XB@E\3
MZ.EA86.+1-5TF]%O`\[SS7*_".[UOPMXAOO$VFV-E-X,^+W@F[\!^,]4AN;5
M-,^'GQ!37[:6Q\6"QBLGMCX:\-:Q&GBX:E=7$-]9>&7\3&[L[Q=*TRSE_1#P
M%^RE\`/C/^T/\3OV-[KP_8ZE8^(/!L/CWPSXKBT>VN]0^$'C#PXNF0ZI;++/
M`@\0_P#"9:/KV@-(MT=/LMW@N.>7[1=W-RFF_=OPK_8"^%_PGMO%'AB+38_$
M=EXG>&^N_MB?9]*TR^:.XL=7@T?P[)=ZA;Z3IVJQ+:RW>EVNHMI[RFYV6Z?:
M'=M^)_&;%9ME64YHL#.&816-P=6,H..%S?*,9&$9X7$4VH2B\.G*5"<6W4;5
MW'0RX3\$,IX<SS/LCS+,U5RRI'`8RG4P\W]?RO-<'.I4PF/H49W4XXB,W#%4
M*LH2I0ERRNXH_/+X9?\`!-C]I/\`:@UL:KX5UOX?^$/A+JOANX@UKQ7\3]+L
MO'7BSPAJ^OSVVH31?#+X93M-X(LKY/!M]IFH6/Q8\<Q^*/&.H70V>&M"T+P]
MJ,6HM_)[XI^$?Q_^''[6?C7P3\)Y?BCJ7C[X5?$SXA>'M0U;7M',&J:I\2?"
M/QH\1_#NWAT"'PK!H+VUGXEDL]`LK/0]2D@U&^UO5;RQCTR32)K8'_3S^$OP
MKE^'/@S3;/P8@\,:;;6-O;0P6=YJ)4QQ6X@MH?*-S$L$$4(6.-(_.2V@BAMX
M=T42A/AGQ'_P3H_8W\*_$?QM^T3J'PSBUSXE^)=>\2?%+Q)XDU/QMX^U'3'\
M5WFI2^,]6\17>CR^(CI1)UC2D\1,E[`\8U`2!IO,N!*?-ROB_#95DM.E4R25
M&6(BY4HU,/3G3Q-+$<RE*,(J51XBI.<8R3;<DU*ZU.O'\(95FW$F,Q>.SFMB
M\/AH-863Q-6B\-7P_LI*G.<:MJ&$P_(YTU1G"W(HR;M9?QB_$?P7^V/X6^(?
MCSPQKW[*/ASXA:YX<\9^*-!UGQ]IGPA^*FIZ=XXU;2-<OM/U'QAI^I67C2RL
M]0LO$UY;S:U:7UI9VEM=P7L=Q!;012)$A7]$_C7X[W4/C+Q;#H=GIKZ+%XFU
MZ+2'?Q%J=H[:7'JMVFGLUK)HSR6S-:"$M;NS/"28V8LI)*VCA_$>24J7AW1=
M*23IMSDFZ;Y7!M=&XN]NFW77HY?!]:5O'+-(UEI5BJT;1JJWM$M]%)-+5Z):
M]5^)OPH^-?Q6^!?C/P;X/T7XDV3_``5T36-?U&;PIXOTC3->\&?#+Q5?Z99Z
MGI6JW]['?Z%XBTO2/%[Z[I]N@A\4VFB:%K</A[4]2L[K3M0M;&OZ[/A%\0M(
M^-_PTT7Q78RPVTVM:7<P31VM[#<7FE:]$TNF7RW&!&D,PDM&>.UN(EDDMIX9
M(@A)=_XH;;3/%7Q'\*7WBK1(-`\1?&7X2Z3J%A\=/A;X=TN\&B_%/PMJMO;M
MX?N-*TJYL4U?6=6T?0]1OM2M&U^.RAT^YU#Q7HUC=ZMIDT-NOW=^QQ^WS-^R
M_P#\(1K?C"_U75_@E\21JUGX7\2^)-;M=5UA-;\&I=MXETKQE)I=]-H$&O:5
M'XBT&ZTVY1K.[U_P?>6FK6UMJ<6B^(K_`$K]"^D5P!7X@K4^->$*D,5AZF'C
M6Q>`@\/3G*,XTJE/&X2JU[3$*<.>G7PSTP\J$9I<V);?YK]'/Q`P&48+%\#\
M2\^7XJGBZ\\HS6O.<L,L7"I&G7RC&RF^7#/VGLY4L3'5>TE!.R/O[X#^#?VP
M?V'/VU?C?XNTKP1JOQW\&_M%CP/!=>-[6PETN?X;-\/O#GBQ+337LX(M46]T
MOQ-JGC*]@O)8VTN;2M12Q>[:\L[FWA7]Y?"&N:QK&F6VH>)O#7_"-ZO*[I=:
M7)=BYGM;<1F;[2[K!;_*TI89,2X*@;]I*U\QQ?$WP/\`'_P8-:TG5?%>E6>I
MI!-(?"7B75/`_B"TDTJ]=$BLM=\+:EINKVWEM:,;E[>^F@GA9O(E>VG#/UGP
MZ\(^%]+DO;FXU7XHZY(5A^Q1>-OC+\4O$^GP20W%K<VUS_8^L^*]0LEG-S!%
M*]["R7;JC0"5+>6>.;^/<;F,\?/#T,QQ<Z-;`X2E@:-&%)4J:C1IQI1=>-/E
MIPKM4X\[Y4W--N[;;_KC%97B*%'$U,#P[AHNO7GCL?FOUSVE6K5QTO;U(THO
M6K0A.I/V34G'D?NI7U^U;_Q!J>G>'+BZ@N9-0:UL3<V.E12V\,^H+9Z>;FWL
M+9I8MD<E_.?LL<\CR;'<;(R5K\9OV[_BA\8Y/@1J'B+Q1JN@?`K3M(6[G'AZ
M*ZM_B!_9>I+HU]:6_C+Q5JMO#9O>6]I?:Q:Z6GA+1V:XU;5([&UT"[EUZ^T^
MPO/T_P!9UZ6VT<K%(K3W,IMFP\C"%9H9+BZO`78$VZ'+R.JB3>^3`[EY7_`?
MX]?'?P=\>OVVK?X%V'V_Q/H_[->CO\0/'MX[V"_#_P`/^,/#FIZK>6__``D,
M]K=7%SJ?C'X<_9G\=Z%8W]K>^'?#7B/2/!'B4Z;J?B.QBNM+_0O"_+<TXPXM
MRK)L+.5>-.M2Q-;%56ZKPF%PK]I4E&4KNE%M*&CBGHM3\B\099?PGP/GV?9H
ME"4,/7I8+!4;4UC<;BVJ,*<Z24562=5U.62DERMI7,/P'^S9^V1XG\#^#/$N
MF77[+L>F^(?"GAW7-/C^)MCXV\$_$F.QU;2+._M$^(/@RWO7@\)>.$@N(U\6
M>&('>'0=>%_I43,EHI)7Y@_%'_@HU^TC'\3/B+'X(\4ZT?!B>.O%R>$3<7<D
MTY\,+X@U!=`\^:2>:26;^RA:>9(\TKN^YFD<DL2O]%XY3@XQC'FQ+<4HW3G9
MV25UKL[JWJ?YV/,,-*3D\%"[=W?#QO=N+U]WS5_GV1\.:9JNJ:1_P5I\$ZEI
M.I7^EZC)XTU>VDU#3KRXLKV2WE^$&AQ2P/=6TD4[PR1SS1R1-(4=)I492LC@
M^P^$M-TY/C;_`,%1OALFGV2?#JY^&GQ4U&Y\`K:P+X*N-0\/:MX?\3:!?3^%
M1&-"EO-#\222>(-'N9+!I],UMWU:R>"_9K@E%?DF3?\`)+97_P!BJA_Z3$_8
M\_\`^2OXB_[*+%_^G$?H)_P;W:SK&I_L[Z[%J6JZEJ$5EJD4-G%?7UU=QVD1
MN/$Z&*V2>618(RB(I2((I554C"@#^HJRYM[4GDDV@)/)(R_!)ZCV/%%%?P[X
MA?\`)0\6?]C/"_\`I<S_`$9X"_Y-]PA_V`/_`-,4CQ?]L_4+_1OV4?VEM9T>
M^O-*UBQ^!_Q!:RU73;F:QU*S8>'KYPUK?6KQ75NP=5<&&5"&56SD`C^6']@5
M$C^#O[=-Q&BQSMX_\06K3HH69K:7X<_"%Y;<R*`Y@E>>9Y(2WENTTK,I,CDE
M%?L_T4/^2BQ/_8+6_P#2S^7/I7?\DOA_^PC+?RJ'/>%--TZ?POX;FFL+*::;
M0-'EEEEM8)))9)-.MGDDDD>,L[NQ+.[$LS$L222:***_N&6[]7^9_&L/@C_A
MC^2/_]D`````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]R>74N9VEF````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,#<P`#$P-#$W,S8S,#$Q`#`R,C0T,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+``````@`"````C^``$$"`"@H,&")`"0(+%B(8DG*A`^62AP8$&"!!.2
M,*#0P,(5I)X8<*("6142*E1L'"A`0$&7%!$"\+A"A9,\JAB2J))LX9,\"P.T
M#&"`5:`5"!-&5$@BSYQG#_,XL>9D19Y255D*9,7*2B`K*IE.5$'*R3.5I$B4
M`DH"SQ-D)598#'34VK5K=&LN5/'D25H5I9KJ`:`'**`G*^0"L)+8"JN[UTI9
ML7)2)402(1&3&'7Y#XG!BZT47/$8,N0G`5#^K*S0"<,G`!33U9BX"M>[T`(Y
M"03EB9YD?)^<;*B2((!`K!:NLI:GH(K'@%0$6KLJ3YXGJZHX(752,\$KU_C^
M.I.#K&%U@VJY5M%CZ)H30*L<JL@(?D5A3ZKR5+$&B''!*M<\0XI=SR1&D0$#
M#01>4\B0THD3>MAU#30-`;#*7:Q8`QL)"2:84'U/,)<'*7E8\XP>7*A0`H=Z
MD#)*%;$UU*$`!+%P314J0)/',ZLX8XTUI4##QPJ"+`2(-4A`L<<5";8D0$(V
M)K?<,\<L=Y<U7SGQ1"?5:&A%*='(Q1*-!K2"%V$!CH+,E==80\H>`CX#S8!M
MEB"4DPEA"(`*>8SBS(`27OE,)\M!(Z%<3L*$(0DW=3(H*6U"!LTHI!S3IEVL
MV)GH0+-<LPJ?G8QBC3..0N9F,@+^^(PUT+320J+^!4'F1"<D6M.@CS]:@]^J
M;9(2$BNS8.$D4;AMYV`U`G;BC*'0.(,$%9Z0`D@RI$AW5RL(/$D"AML]0]XS
MR(RRJJJDR-$M<PQ!U@H+Q$ZX936T/J/F,]4\,8>OSSSCU#-]69$(9(EX=-<J
M<L@9:C6D(&.-*DC\P157>E3A;5I6W#7++#/=%4@5R"!K";CBNKD"(,@%\L2)
M.^YFVD"LR/),*>(^,X<3JX2+#+W)Y)JO',[P6S%D'`$"32E4"C@*$CL>XPFE
M)STD(`DW5P&>Q0H%LLJJ"1]#"AY(X%%I@ZMF>$U9/T9LVDR!C&@BJ\Y(Y<2Y
M0()=V(^=K'`V853("1D@*TZ8.X=-><@AAW7FTCOH<Y#-))#B!RUND'&./]YX
M0```.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O<V5X>2YG:68`````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C$V,0`Q,#0Q-S,V,S`Q,0`P,C(V,3(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA)0`E`/<`````````
M,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!F
MS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_
M,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,S
MS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,
M,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`
MS&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9
M,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_
MS&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF
M,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,
MS)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS
M,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9
MS,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`
M,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]F
MS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__
M,___9O__F?__S/____B_)```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"'Y
M!`$``-@`+``````E`"4```C^`+$)'$BPH,&#"!,J7,BPH<.'$",J!*""(("+
M$A&J4)$JU0H5'U,U2[5Q1<:!')M-&YEJE,AI*T>:S`@@U4J2&W.^7`F2YLB-
MHHP)-29JH\UI)"52'.4D*+.G4(DZ>>D1(D>2HJ!JA5JTF=>9#E5X56&,V="G
M9XT!\-H,;,.K9(WE%#J7KDBW"U6X5)&56:D]I9[^#6RV:-6P'0&4]5LBKHH2
MA,URQ*M0[RC%@C?251%9[N&WHRXO-KM8J%;/E"=B1;O5+%K#J1/"I3M:\M"4
ML36.I=OW:=&A:YM5?)B2+S-1384BS]IUK%65J9(7S1D4^<[/#,7"Q"FJNW>C
M,+=/YS:H'>9/BB6QK3CZ$V)-MLTN'X0['N'%^P`2WC_)O[__@_AALY^`!.9'
MH%(6)9B?@09&%"!&`S$XX$D+*IB@4OL-6&&`_W7HX8<@>A@0```[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;6EL97DN
M9VEF`````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3(P`#$P-#$W,S8S,#$Q
M`#`R,S$Q-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F
M`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_
M`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F
M,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_
M,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F
M,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_
M9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF
M9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_
MF3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EF
MF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__
MS```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9F
MS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_
MS/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F
M_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG_
M_\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(?D$`0``V``L`````"``(```"/X`L0D<
M2+"@P8,($RI<R!#;BA4J(*YHJ/"A"C^H4$F3ADHB18(/J6#<2))DQXD4JX@L
MR;)DQX8J_;2<N9$*RH0J5[;TH^)B214`;AI<045G2Z```,C<F#0H0J)^EK9L
M"D"%1FE(`1R$:M0E50!4-OII*E0@5*E'J:K8B"KK4)%H68ZE2I)*TX)<X[K,
M"L"DVX%$X=(4VW1MW;N`17:=R=-G23]V02K6.[@E*JV)!5?>C-ELT:@S>V[F
M6/:L7J!7!ZLPJ.*SWK%6![=]"YFRW=B6(Q(,%,A*Z]J,JZ9F"W0@;]Z^)]-L
M;#5C3Z?8CO?N_7NQ22H]L]LT/MU*[^2:-RZ_W-W]>VNXE$U6.2C=NQ7?Y\.S
M;5O68/OW0,_7QO[PH\#C[EGDD7\$%F@@00$!`#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+W-M=7)F<RYG:68`````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(Q,#$`,3`T,3<S-C,P,3$`,#(S,3,S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y82``(`#W````````
M`#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`
M9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``
M_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS
M,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``S
MS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF
M`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!F
MF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF
M_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"9
M9C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9
MS,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,
M,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,
MF<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_
M`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_
M9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#_
M_S/__V;__YG__\S____XOR0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M^00!``#8`"P`````(``@```(_@"Q"1Q(4*`5``@3(K12L*%#;`M979M(<2(K
M``P?-D0HL:)'BA<S:L38\:-)BP!&ECS)\EK*C2UC4GPYT,I*F2Q7$`0@TXH5
MF31MRF1U$<`*EC1YQI3HT^<*A$<KZA2H%"=(HJR>0MW94V%%HC0'`KCY\>"%
MLQ<`I$WHL.I)LVC/KD"+$691A!X1TE5[X>G9NCLOQH5Z#6[:B7A=_BVH-^Y:
MK7\K5E4;%N+?QH_YNI6<EC%:`HW5^CV,F*="A53C@G:LN;1IS(OY?G;<-_)I
MVF</RA[<>&[:%7-WL]:->S=4W+09ZL8,&WGQG00&0Q+NG.Y&Z=.=GP9\G2ZD
M[-5%'SXTO'8[:XUB$U:/*_ZA;/7(%Z)/37L[V_GTJU>>'Q``.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<V]N:6,N
M9VEF```````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$V-@`Q,#0Q-S,V,S`Q
M,0`P,C(W-#(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA'P`@`/<`````````,P``9@``F0``S```_P`S```S,P`S
M9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9
M_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`
M9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F
M_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_
M9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S
M_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,
M9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`
M_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF9
M9IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G_
M_\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF
M9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,
M_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S
M9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9
M___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"P`````'P`@```(_@`!"!Q(L*#!@P0O
M`!!0L$`!`1`C"G#H$*)`9!B1";Q01F#$A1)#1GQH$0!&@64ZDA0IL0#!E24W
MJAPX4:1+`#MV"(194B$`ESI_VL1Y[5I0GAM_`M7)\^:.HD:%2DSJ]-K.ED2A
M)MJYDFI6JS"!%@50=&O%GC\!)(+J<:%8JP*OF>T*0.'-M333DAT;=^Y'`"H9
MXAT(%RI<LG[1/E1[V+!APHD9UMW)V*ICQXBO_KU@5_#ESW*53JWK\R;?@H[G
M&E3H06A<DQDU[BU+,)CMI*T+QLX8-[1`V\%."C2P5_=NV0./RS9`_&!PY;L/
M&LAM\#ETWAJ1M_99^[IRV`,Y7',$`-S[=^'$.78D;_[XQ>7-4_ZV?IT@;P#3
M/;26/[]]QML`4,<9>//1AQ%PP!4DWD4%#H0@@`5)MN!)NR48(7G!3;:10A1"
MAZ!'##VG(8?9^7>;12(BI.**!04$`#L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]S<&5E9'DN9VEF````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,S0T`#$P-#$W,S8S,#$Q`#`R,S$Q-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$@`"``]P``````
M```S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9
M`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\`
M`/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9
M,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`
M,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"9
M9@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`
M9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^9
M9O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`
MF68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9
MF<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`
MS#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9
MS)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``
M_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9
M_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`
M__\S__]F__^9___,____^+\D````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(?D$`0``V``L`````"``(```"/X``0@<2+"@P8(DL"E4"("4LX>D(CZ<2+$B
M15()%P*@J**C0XL@.2[$MG$BJ5$J`)!0\3%D18P:G9%*N?(/098N*ZK0.)/$
M08$X<T+,2`+BJ)\`5`B=N)/DPQ4J?!XDT3(GS)(RC_X,*G1GR9D#2>3I1+;3
MG)5+9?I\^$2KBCEE.^59,8<K1)EX'PJD2&(%JQ5CR?JENZ(E*:@=511VMG>B
MWVM_!;."3-CAS#R8,Z_0:E*@7Q5R/4?.$U4%9JEB23<^/)#5VY0"79,E?9I@
M:H$1Z9X-.Z>UZ;AO?<[I3:)W4MZH\T@52&)E7.7-B\.V.?!M9K/,YP2..SO/
MG,U`W\+.AEWP[&_@I#TR;CBS;)ZIVCL^M]OX?"<5@`I?)LU=[F**JP%&UDJY
M;<=='D]4I5=#$'5TFGS]S;892,SA=))I!AX877/TD0`))!M&=UIQJ'E("R2T
MG-C71P!@0T**)WX(HDH?(@$)C2E"@@2,-RK%F(LHTM(<BC>^F*.))]H(8G,J
M.=0BD#+:."0M-M)"XY`SCJ3"40M%]^&1-8(HXX<^C:10F69B.66**FUHYIMO
MMHF$AQZ"".>=>'8Y9T9YCA00```[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W5S+FIP
M9P``````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$U,C$`,3`T,3<S-C,P
M,3$`,#(R,C8T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1
M`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!
M`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P
M)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!
M``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$
M``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A
M)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V
M=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`
M_CW`^"WC'PDNH?#7]FCPQK_CRTT+QGXP^+GA6UF^.NF^&OA+X<\%>,]"UK0]
M6\$^)+O]HWQ)J'BK0?$/AQIO"?C^+Q7I?]KZ?H5]JD/A.\T?Q=+H?Q$TG#&@
M_`?5?!'B^\3X%_$'Q3:^&K'X;7?_``N?X0>,/&/P^\#_``\\0>/])T^;Q#X6
M^-&C?$3P1^T/%XFT_2=;T_5_#GPYO?"FN_!S4=2U&R\7:Q?2?$&PN_#6B^%=
M:\O?#'C#X:Z9\./B'J?P[^&6A?`+PK\<;?X3?%_P)\)?$^M:O^U!X[F\;^']
M9C^'OB7QW%=Z>M]IMA;:[/J/A7Q#J>FV5MX,\/WL-GJFD->>)+5CS7B;7_'&
MM^']=L/'FK:[\.O$^J^#O@=IO@_X1>%_A8/!F@_&;PM:6<4G@_Q%XBL?#:>&
M=+U1K?1);#Q)H'B;5-#\2WOBRXU6U?2[J*W6TEA_L*OX?\&XC#>Q>39>J&(J
M/$/$.5;!U\/]3S"-6GAZ-?`U,/6J*MAI-.3J>PQ-&E'ZW0JX=8NWE1S#&04T
MO8QE.*2<L/AIRC_L_*ZD(5X3C#G4E.*<'%U9<U!*JH6Z;4-;_9PFCT_X7Z9\
M#O@MI&GM\3WT^#]J[6?%'[6VK_;?A_IVBZ#I:KJ_@_3O&FF:?>:OYS2>,O&%
M[X?^%FC7T^LZ\-.\/>%?"?AM-,TZ'<;XO^#_`!AX>\->"?&?A#X*?"3PQ\-_
MA[\3%\$_$3P'^RM\.]5\2_&_Q1I$FH)\/M(\8>(-<T+^VKRRVVFD>%)/%NKW
M6M:Z/LEYK?CB^U[Q;J^J:ZN-X\3Q3:^+$;QEX(M_"?Q'3XR:5<7'[#4WPW^*
M'A'0(Y=?\'^'9[#Q9I/A);V)+-O&$B:?8S^&X+C3M:NQ=Z5+I-I?^&;R.PL?
M*VO-,\+6<1\4Z;H7Q8-[\,?%F@Z9X1O=5^)>ER?L_P"M:CXJU2WL;J2&.?0]
MFK>'-<N[[6++0+R^U?PQ?:GX@EFUZQU(WMO/J.&$X2X3RG$*K0R+#3I*HZM!
MXW+:..=6G[.-*<X5,QY<52YX5)5:5:C.-.I!0KQP.%]I3<5+,L;3=-4\6Z%.
M<Y.2HMT&W!P]A3K5,,_;1<ITXQI0G5G%5>>4Y^UJTZT_V:_X(Y_LX?LR?M+_
M`+35]X9_X*4P?!'X,?L\?%7]F_6/B%HWB75U^$7P5?Q[JW@;Q_X6\&>!W\.7
M6F#PYXE^'L'FZ7XK.I7/P0D^%6K_`!'N-!N;[XCZGXXT._\`$-MX@_8/XG?\
M&ZG_``2[^,_C>^/[*G[4WA[6=,M;?4UL/#7P*^,VG>(=+BLQ>7E[I#>*I?'B
M_'?Q6_BV."X:SUS4-&U/2/"_]@6?AR2P\+)K:>(=6UO\>?\`@AY^PK\#/VM_
MVW4^$'QK_:&N+'X>6'['>N?&E_$_PSUJQL;OP;KO]N>!I;WX;:N_CWPSJ6GP
M:GH$OB36CKNGZ/87"3ZC$MQ87DGG7"O_`%Q:U_P0!_X)8:-9Z5-?_MV_$;2&
M\2:_#X0\-W&I_$GX$B#4?%-_+>6NFZ;;VY\#6LM[)=7%E<-;1Q3P1WT$)DMK
ML0RQ7!_D'QQP><Y-QU361Y%E<,EGDF`K16%XDJ\,U:E6<\71J.O@\+B?[,6*
M@DJ4J[P52K44*,JSAB:452_L[P.R+P3S[P^='C7C[BG(>.X9MC:.'R[#>"6`
M\4<FPN50]C7H5*F*CE]#.I^VKUL;6K8+#9]A%A914>7WJT:WX8G_`(-??A0Q
M+6OCOXN7]JQ+6U]:?%_X5M:7L!YAN[5I?@C#*UO<1E9H&EABD,3J7C1B5!7Z
M)7G_``0#\,Z9=W6FV'_!4_P/86.GW$]C96,/AKQIY-E:6DK6]M:1?V7\4XM,
M\JVAC2&/^SHHK':@^R1I;^6H*_"G/C)MM93G*3=TO^(@81V717>>1;MW<4WK
M=*[1^R/@3P#3:7C7X:63LN?Z)?C$YV6BYW2PKI.6GO.FW3;NX-Q:;_@M;5;!
M/#FBV>O>)=8\3^!K>;XN#P?\-(O$VJ_VI\//$FI:'IT.D^*-5TVXTNV\.P1Z
M]JJ>%[S6)_#S&7Q'9^$;NTU#[$^GV5K707/BCPO#X,\;Z+K^C'XU^+=6\#_"
M,^!OBN_B;XC:;=_`2#1);!_$/A`>'KZ&TT3Q!:>3>P_#TMJ$=WX>TJ2TL[_P
M??LUZJ5_5-\8O^#4OX^?"G4;^7X+_M]_#7XB^-/$6FZ[IWBRZ\0^`O$_@70[
MW0/%VEZC9ZU8W7B/P_XH^*M_JEYK'V@PZK8WN@6J):WG]I)?3W<<,#^`:/\`
M\&RW[?N@>&?&/@S1_P!I_P#9RTWPKX\?PZOBW1+36/BJMCXDA\,ZW=:CHK:K
M"?A@"[Z,91JEA$KLK:C<7%E)+'!$E_/_`*6OCWA.4Z<\#Q%0GAX2HJE/GQ.#
M?)3DY492P^+P^'Q-5Q]K*4U4;PU7#UJ^73E/!2J.7^9L,)7E[15*$:3A.M2E
M%JE[2G5BZE.5)PJ58M159J$ZTU.I14%6A)RI<K_!U/&6F^)-,L+GQE<ZYK7Q
M#7XU_"N[U?\`;QB\5?&;Q%>>`O"$W@VVL;#P!)X9U6UTDWVL>$AX>FUC0M31
M+?Q']F\&ZOHGAE=1T6VTO4K+SB34-5\-7OB&+PCXUU'PMIWBCP7\1/#'B/XC
MZE<^-+?2?CUID'B;4]5O(-(B/A>34[*'Q78VOAO1VT75P+9]6LVE\2ZWIG]J
MW%M;_P!;_P`*O^#2/Q_XT\`6_A;7_P#@I9X4\#-J5[;>)_%/PZ3X0^(]2\$K
MXK\/V"Z;;:W:75Y\6?#EIKDUE:>*]2TO0-=U/PUHNM26=QK\$&GVML+L2>R7
M7_!F'\0]9T+0].O/^"H'A;5/#7AZRUF?PW97'P,UF]T71=.:^^U>()M&@D^-
M\EE861U*X^T:O)9K%`+V?S;MA/+N;:7B3P!*A.C6XEH1Q*C&K#GPG$>*<9>T
MHQG252>4N>'ISH4*,/;8:;N^>*A.E4C)%'`8U\M>A@\7[/VCINM!KEJUHP7M
M*=*HI*G'E@JCY(1J.$U451RDI\GX)_\`!'G]@&3]N?XD_&6+PKXFM/A%_P`*
ML\"?".ZOG\4Z5J7BJ_U.3QGHFKPZQJ6DQ6U[X?$-GK^N^'E\06=M=">WM-%U
M:TM[:[N#:03W?]6?P6_X-JOAKXEB_MGXE?MOQII,L5PD6A^&OAYH?A?Q19W4
M5Q)!"VI'Q#X]\2VD=M=+&]S"8;9R\"Q!9"]Q+]B_)C2/^#=#]MOX8>(O',0_
M:E^$GCB&T;0?!OAZ]TS5OB#I%_>>%?`!U'P]X;B-LVB-H]G;V^C2P306-OKM
M]:VP-Y]GU#49I_M-Y]?_``\_X((_%_Q58:=H/Q9_:Y\+>'[TZI86%@-*\)^)
M_'/AB&W<)9PZQJVI^)?%?@2;2FM5GD%V8=(OXXK437"W0$C6R?PCXSY?@>(O
M$7.LUR_@6KQA&4<JHX/-GQ)/+LMK8?#93@XN-#"U:E/#TJ-.K&O2JTI<TZF+
M53$RE.>(DI?Z7?1O\6\=P=X19+PY7^F)E?@3D7M<_P`5CN#\!X*4N,N)<)C<
M;GN*@ZM;.,+@<3GU7&8FC]3QV'Q%U##9=)9;)QC@7*E^G/\`Q#)_L8_]'@_%
M;_O_`/"G_P"5E%?+Z?\`!K\DBJZ?\%!_AJZ.JNCI\(@RNC`%65A\9"&5@058
M$@@@@XHK\E_L":=GX-X)-:-/C*DG?W='>O\`GWUZW_HM>,&'DDX_M+.)6FDT
MU]&C,6FGRM-/^RFFFFFGY^M[_CO_`(("_M\Z9HNOZO>_MS>(/$B:197=X'N]
M6\=FQN4TBWU":SN+B:X^(UYJ=MIT9GNF^T1Z->ZA86U]=SQZ3+(]Q;O\!:O_
M`,$;_P#@I/.\<UA^U5X$@`:"%[:'XV?'CI/>DW%V7D\`0+MMX9WF,(!<PVPM
M[8$F&(?;5S_P1F_X+KR2F23]LK[7(^=TQ_;`^/;L=C-$FYKCP]'(VZ.-'3@X
MB>-6V2*\4?@U[_P3@_X+`3Q*EG^WU]AE$@9I?^&E_P!I>YW1A7!C\N7P0%&6
M*MO!R-FT<,:WIY)A74I5(^'O&N'DK\[>>3JTVFT[3C7J5IM1LTI0A&;3O9/4
M\S$>*.>T<+B\+B?IA_1?SS#ITIX?#Q\+,/EN)BZ6EL/6R?"9+1BZZ5*56G7Q
M<Z494E"-112B<_\`#C_@D;_P4HCU+1=/UC]L3PGX5L]:O=.@UW4]#^,?QH%[
MI\$[A"\UG)X9\-Z)J$FF/<3`/=^(=(T\1>9(]]!'YD[_`*!V?_!O_P#\%#-1
M@=[W_@I)XGTYO.(^S:GKWQ:GEDV[I1<@Z;\0M3M]C2W5R%WSK.)6N':)5E$D
MOP+HG_!.#_@L8H#ZE^WA<*41E*7/[4O[2KNYGLM&D3:MMX/N8B+.:._LY)9)
M$EEN$FN(UEANA<2_1GA[_@CY_P`%SM6TBRU72?VW6MM-U."&_LBW[7G[1EF;
MFVNH8I8+L6Z^%`Z+/"R%//2.8J%+1A=A+JY%A,/*37AWQIBDJC:2S[$4Z4&Y
MM<M..%KP:BN7FC:.JLW*VJ,/XJ\19NJ=.?TR/HP\-S]C&G4A'PJR?,<57A1I
MT[3Q.+S[+<RCB9J-58>I-XZ?P67-)N3\T_:3_P""%_\`P40\"0Z=-H7[95MX
MOUG5KC4G:]\3^/\`XI>$!?0:+#;PH-.OM,N?']]J$LZW-M%';:Y;^&H;>.2S
MD-XYAN;:V^8O#/\`P2#_`."G"WMPFJ?M&>#[>T:&4QRZG\</BY<(TD<UN+<(
M+'P=JEQ%-+%)<M)&(UMU$2[KB5S$J_8?Q#_X))?\%M?#&C?:?&'[<*#2[]WT
MB&YG_:P_:*UFW^U7]K=R&UDL3X2GED22WLYI)EEM_LDJ((992SA#\HV?_!+W
M_@L%!K5I<2?M?K))97]C#;ZJ_P"TY\>I;:*VLBMM;7Z%="M]56#3X8+62RM4
MMDG%O$D/D1&);9U'(L-6HROP'QGA82:;H?VS*HYRE:[52K3K5XM.,7=U*:4F
MV^6*3<5O%?.\LS+"RA]+/Z-&?XFC34*>:?\`$-J&`I86G1M&-.>#R_%95E5:
M/LZM2FHPP6*E4H4:48>TJN4*?Z`:#_P0G_X*,ZUH>C:S_P`-T>/E_M;2=.U/
M;9^*O&%S9K]OLX;K%K<WOQ=TF]N+8>;B">[TO3;J6+;)<:?9RL]O&5\T?\.Y
MO^"NW_1]W_FS_P"TW_\`,/16JRG!I)?\0UXT=DM7Q'C;NUM7;,DKNW1)=DK*
MW%+Q!XDE*4E]-_Z,D$Y-J$?!;A9Q@F[J,7/@B<^6*22<IRE9:R;U/Q;F_;3_
M`&Q[E0EQ^UG^TQ.@8.$F^/'Q3E4.`0&"OXJ8!@&8!@,@,1G!-5O^&QOVN_\`
MHZC]H_\`\/A\3?\`YJ***\W!?[O'U?Z'V_$O_(TE_P!>*'_I!PUI^V7^U_;Z
M[I=A!^U9^TE!8QQ:E#'90_'/XGQVD<-M>:S#;1);)XH6%(K>&""*"-4"Q10Q
M1QA5C0#T"#]M']L6VW?9OVL?VE[??MW^1\=OBE%OVYV[O+\5+NV[FVYSC<<8
MR:**Z,Q_W:'_`%ZH_P#I\\;@W_D=XC_L:8O_`-5M(=-^VG^V/<J$N/VL_P!I
MB=`P<)-\>/BG*H<`@,%?Q4P#`,P#`9`8C.":\-O_`-L;]KJVU_5M0M_VJ/VC
MX+^:YN;:6^A^.'Q-BO);>.94CMY+E/$ZS/"B6]NJ1,YC58(550(D"E%&4_PZ
M7_7V/_I,R?$'_>,5_P!BN7_I>#/:?^&QOVN_^CJ/VC__``^'Q-_^:BBBBK,S
M_]D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]S=&%N+FIP9P``````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-30V`#$P
M-#$W,S8S,#$Q`#`R,C8Q-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`
M,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_
MQ`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C
M0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-45597
M6%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X
M^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($
M!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B
M<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$`
M`A$#$0`_`/TA^%__``0\\0^'!#;:/XX\#Z=K$N)==UG0?"_B7Q-XKU^[DAC6
MZU?Q;XKU,:%J.N:I>8(OM0U?6O\`2)762*&$2>4/HY/^"'WC&4R32?'.Q7A2
M(C\,K:5N%P5Q_P`+2A@4#&!MW97&]BVYC_1;H^D0Z7:06L"*J+&!/\N3<3`)
MOGE9RSEB5(52655.!@``?&?[3O[5_C?]G[XX_LE_"KPI^R9^T1^T'HO[2OQ!
MU+P)XO\`BE\&O#>HZW\/OV9],TS5O`M@/''QQU5;:71O#OAJ]L_'>H:[;SZG
M>Z.]SH7@+Q?)IEUJFNVFC:)<?B.$\$N'<1"%;/Z^98['55[2I%8ZI[.@U92I
MIMR4G=WYJ:H05G^Y;LX_D^/\"/"3$8R=5\.9CCY1DXSQ.<<4<28S$5]4U.+I
MYI0H8:/>A0P\8.^O+:Q^/US_`,$:+S3+HVMS\?I[2X:,'[/+\'KV%6#-@O%-
M;?%>XMYX5*%1-$TD9)Y8';NKM_P1C^(%[;,?"'QAT/6%1G#MJ7@S4=!B:155
MCMGAU[58&R.#F0S!E`90AC)_HM^(MA:3^'Y+J>.2*6PELWMWM8T:X1I+J*W,
M<8+Q(8W24B2-G$;!%)!*KCYW_;!_:;TS]B7X&77QAD^!_P`?OC]8:7XF\*^'
MO^%8?LQ?#6'XH?%*_'B/5X-*_M&U\+7/B+PO;'1K"XN(Y]3U6XU:!+*XFL[(
M)>2ZG;VTOFTO`G))9IB(U9XB.4PA"=+DKRG7DY-IT^:HMTHIO[.NEVV:8OP"
M\$:V#I1I<'U:./G-PE&GG_$B@H1Y;33_`+6>LF^VC6O1/^?3QK_P2%_:]\.Q
MSS:#8>!O&,5NK2HNG^+H=+OG=78*JVVJV\(0J521IENHA&"SQW=NT8N8_@7Q
M_P#\$P/VU/A]J6O?$[X9?!:Y379+5?\`A*?`EAXG^'NJ^%/B%=E8K0SHGA+Q
M3JNI>%?&"P//-;^)[/0G74[A!8^)[/4K2222/^['P[J\?B?PSH'B&/2];T5-
M?T/2=9CT?Q'ILNB^)-(35+&WODTW7M'N6\[2-<T\3BUU/3IV\[3[^&>V<^9"
M37E_Q.\*7B6=WXD\,6FFCQ)%8W$*+?R7UCIU_=3O9VVGG5=5TR*ZN]+M(IBL
M6H:A;:=J5U;6-Q=W\5G?I8R:?>&:^#6!RG"UL7D.-QU1<C>+R[%2IU:&*IM)
M.\6E'FHJU:/-)6E3C9W/(RSZ./AU'$RI87'\39+#$J=.I"EF6%Q^7XA5$XJ&
M.P.89=7CB()-*F^95H5%3J4Z]*K%5H?Q5Z7^S_\`M,ZEIFG:C<_LM?M':9<7
M]C:7L^FR_!_Q0\NGS75O'/+8R/`M[`TEH\C0.T-Y=Q,T9,=S.A$KE?U+^!OV
MC/@-X]\$^#_'.E^/=#TG3/&?A;P_XLT[2O$]W#HWB73+#Q%I-IK%II_B'1[^
M[GOM*URRM[R.VU;3;R::[L;^.XM;B62:)W)7X\^#Z',_]GJ+7;V.&:6L=-[O
M9?TT=K^AGP(VVN+<V2;NDLJRJR3L[+]P]MMWZO6_Z3AB`N#D=QU'X'K[_KWI
MCA2[_O)-S!``K8"C';;R0PR?FW!224VDDGQ31O'^H6-JMO>VJ7R1!4BE6=;>
M78J!55Q]EE4E=I`8'<P()(Q@W+[XCWDR,EGI\5J[@AII9_M)7(P"(OL\2M@=
M074'VY)_JFGQYD#P\:ZJ5/:\CG4POO>TCHKQBVN3F3LK*235W>Z/WJIPSF].
MK*FJ4?9N7+&L^5QMTLN;FNTNL6]UMMT7CS6H+6SM[#9;W-Q<W$,K6TJ0RAK>
M!FE)"RB1=[2(GEML.%5\$'D=A:20ZE!:WUK<.(I0LJR0M$PF0;OW4Y,;@QY:
M0;5*D,?,1E<*R_,US+<W5Q)=3S&6>3+-+(<F1B<\H%VQ*<L<)NP<#!ZC>T'Q
M-=^'6*1J;BPD8>99O)RN!Q)%,49E8.Q)CP$D``+*>GRV7^(D)9OB:F-C.&78
MB,:6'497EA(QDOWE2*5W.2?O;WLK;._N8SA.<<NPRH7GC8-U*KY+*IS*/N)O
M9QL[:I:ZM+5?1BY50JA0J`*%`P%"@`!0.,`8],=!P!7,>,957P]J<<RN\5Q:
MS6DD:(K^;]H7RE1R\L*QH[NL;R>=$P60K"WGM#CET^)^C%5S9ZJ6*D.L=M;L
MBD(2062Z.Q6(V(2`P)7*KFN)\2^+;CQ"%BCM9(=-"NOV66;RY;I95$$RW;I'
M*1"L+S,D&'2:3RU=HP-Z_1YMQMD-/`UUAL7+&U*U+D5.ESQG#GLM.:*6E[R=
M]KK8\;!</9G5Q5%5\/4PU.-12G4DX-6A[RVD]VK+JGJS^--O^"?'[>/QQ9OC
M5\-]+\2^!?AW\8"?BCX"\$ZY%XITK6O!W@OX@'_A+/"WA76-+6S`TW5/#VAZ
MO8Z1J%@`!9W=G-;CB.BO[!V=I&,C#:SDNR[B^&8Y(WE4+X)QN**6ZE5S@%?B
MKS.FW?ZK7U?\Z[Q[_/\`'S/TA82=E^_I]/\`ETF].7KSZ[;];+NRKOD4E0,I
MU!^4$G^?<]J^2_VM?V[_`-E7]A+PGX=\;_M6?%K3?A9X>\:>(AX3\)O=Z%XR
M\3:AKFOK92:A+:Z9I/@+PMXLUA8+6TC:;5+^\THV%C&UN3<^==06\GT1X,\;
M>&/B'X:T;QCX)U[1_$OAGQ!9K?Z7JNE7L<\-Q;R)'(F(F,=W'*D<T?VN"[MK
M2YL9G6UN[>*<[!^<'_!4_P#X)<_"[_@II\(M)\->*/$&O>`/B]\+[/QQJOP`
M^(^DWK-I/ASQ;XRTS0;75=.\;^'I-'U%/%/@#Q-?>#_!B^*=-LGTWQ!!;>'H
MI?"6MKJMS?Z?6.5?V=B<5AECL0_J-2HHU:^%@ZCC=7NE:=DGNVI)K2UWH\1B
MO;8+V^65</BIU(J5&5*O&K&:\HP49-;7:DNF]U?P:?\`X..O^"2L%V]HOQ]\
M67+Q-,'\GX'_`!MPRP3/;2A&G^'EFH=)E(^8E64$J&!!'VK^R;_P4V_8=_;E
MU/6/#O[-?Q[\.^,_&.A6D%_JW@;5])\6^`?&5OITK3J=2L?#GQ%\-^$M0U_2
M[1+9I]8U;PPGB'1]"6>W_MG5-/>YAMH_YEOV9_\`@TXU&2/Q!??MB?M+V5E?
M237MOX/\._LK6.I>)].,<LMI=6OB+Q-X\^+/@WPP\-W=1MJ!7P-I_@.1?L_V
M"_A\>W"W,EK!Z?\`\$Z?^#=+]I']D+_@H5\+?VA?B5\;?@KXQ^!/P7USQ3XH
M\-2>#I_B+'\3?'.N7_@GQ'X>\$E_"&J>`E\*^%'TG4=;%[XZDTKQ]XH)TK3K
MK0]-N=5N+J^@TC[K'Y/P`\-B?J6<XF&,HX>O5P[J4J;>+J45%JA3Y8I2FF[R
MM=N+5K;OY_#X[B2E6HSK89*$VXSC*,W9I:N,>;:ST3OLUL?V$1.LD,1+LT3)
M&ZG<XX(!3'(8#IA>`!P1C(JR`JC(P-P')P<X^N2.OXYYJJ)5D!;<@.UII=KB
M2-(XU,UP\<T89)1'$LCQNH"2[5(9%;<OS5\=?VJ_@O\`L\"S'Q`\337.OZA;
MO/I/@3PK;1:WXQUB$+"[&"-[RQT+2(5BNK6[FN?$NL:1#]E$AL7O[I1:M^:8
MC%8;!T)8K%UJ=##4E&56K7J1HQA!R4;RG-.,9.]HIIN4VHI79[F,S'`X!8=X
MW$>RJXR=*CA</3I5,1B<1B:\HTZ&'P^'HJ5;$U\16G&CA\/AX5*]:I*%.E3J
M3FHGT]MN&^98+AE;E66VF964\@JRQD%2,$$$@CD'%%?@'J7_``5+^)KZCJ#V
M'PL^',%BU[=-90WY\57=]#:-/(;>*]NX-9LH+J[CA*)<7$-G:133!Y([:!&$
M2%?!/Q5X$3:_MS#Z.V\'U2_GMU_K6WZ9'PH\4IQC)>%?B8E)1DE+A*K&24E%
MVE&6-C)-<VJE%235FDW8_,JP\<>-?A_J6F:YX#\7^*/!.MW%U;P3ZQX1\0:M
MX;U6>">14FAFU#1KNRNY(ID1$EC>9DD5%5U(4`?UY?!^66_^%VCWE]))>W<V
ME6#S75V[7-S*\L<S2O)/,7E=I&)+LS$N22Q)HHKRO!__`))RI_U]I?\`IMGY
MGQQ_R?WQ`_Z]X;_U/K'=V$<<K[9$212DF5=5<'E.H8$5F>*28;B%(3Y2[5;;
M%^[7<O*G"8&5/(.,@\BBBOURE_O6"_QS_.!O4_WZMZT__4O`'Y+?\%9/B%X^
M\!?"OX6W'@;QQXO\&7&N^+'TW6Y_"?B76O#LVL:==>&_$7VFPU671[VS?4+*
MXVKY]K=M-!-M7S(VP,?B7X:`OK'3KR]`O+N\N@;RZN@+BYNC+<A93<SR[Y9S
M(I*R&5FWKPV1117\^>-W_(OH?]Q/_2YGB_1D_P"4L*G_`&2G$'_IB1]5_P!G
M:>ORK8V84<`"VA``'```3``'``X`HHHK^+S@Q'^\5O\`K]4_]+B?_]D`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]T:&]M87,N9VEF````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,C0Q`#$P-#$W,S8S,#$Q`#`R,S$Q-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/X`L0D<*)`5JT"!K%@!P!#`M88$(TH4
MV!#`B8N/'EU[>.TB@(D@+5X<F?'1'E8,5W@$&5&D-)4>"SQB@1+`"I4?60ZT
M>!/F"0`%+M!,B5/GSA,]1P(56E.I48HC/>Y9.E3DSZ?8K/[<\^A"UZ$^<QJU
MV)`KI$?$5BAD&*%MVZ<`W+;ENN?:BHIQ(Q`@\)9E7KU\]]P$8+`PP[U[=>8M
MP+A`0U96"JM%B5AQV\:/U08R:`4A@,I^+S-F6+AP9\.)0T?`3)C50\ZO*1.P
MO'ITZX.<2W^>K9JUP4`K6-U$:'`W;=:$5P2Z]EOY;MXA1=O&[9IYPHJ6\3[>
M/+DFP[%MM7\S1$C^,&B0D-KN%8\W$.+4$],#)M`PD'B#[_VFW]NS]<W."%FQ
M@ESZ1<#=2Y#=9MIMA.D'B7`W)5A8@`(JM)!"(4$"B8#_6;C'AWMH*.*(#HX(
M"0`BHFBB&X&X`4F)++J8XD,FVA?(BP[::*)XRJT`ETW`:?>0>%BQ9Z18V`0$
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-U
M<&5R;6%N+F=I9@``````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C8`,3`T,3<S
M-C,P,3$`,#(S-#4T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``
M,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`
MF<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S
M`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS
M9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S
M_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF
M,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!F
MS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9
M`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9
MF3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9
M_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,
M9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,
MS,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_
M,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_
MF<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````A^00!``#8`"P`````(``@```(
M\P"Q"1Q(L*#!@P@3*ES(L*'#AQ`C2IR($(#%BQ@S9EP(@!8M2"!#BAP)B0T;
M``D[TF+&C--'DC!-HC2HDIFQER'9(-DITMA-DR<+UKPID@TG8RR-N0SITJC,
M@36EX2R)5)I5:3:GLE'Z-.K2G%6O6F6&DPTS:9QD`C#)B2S)K6?%8J4%]&S:
MH&N-3AT95N[5NS.QY=T[TJ-A2VVM`A9JDC#,D+0X+:8)U.3CMT\KLN5:N7/.
MH`KS)O:+M65)T!S9MO1X-"FGTX$9YH7D&&CLAK,QHX8HNK*ES!-%LYQ,43!;
MXL6-VT[.>#=S@1:?2Y]./6%````[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O<WEL=F5S=&5R+F=I9@``````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C4V-``Q,#0Q-S,V,S`Q,0`P,C,V-S$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA(``@`/<`
M``````@```@(``@("!```!`0$!@``!@("!@0$!@8$!@8&"$``"$(""$0$"$8
M$"$8&"$A(2D``"D0$"D8&"DA(2DI*3$0$#$8&#$I*3$Q,3DI*3DQ,3DY.4((
M"$(0$$(8&$(I*4(Q,4)".4)"0DH0$$HI*4HY.4I"0DI*0DI*2E(8&%(Y.5)*
M2E)24EH``%H0$%HI*5I"0EI*2EI:6F,``&,I*6,Y.6-:6F-C8VL``&LI*6M:
M6FMK8VMK:W-K:W-S:W-S<WMS<WM[<WM[>X0``(0("(1[>X2$>X2$A(P``(R,
MC)0``)00$)08&)24C)24E)P``)R<G*40$*48&*6<G*6EI:TI*:VMK;6MK;6U
MK;6UM;VUK;V]M;V]O<:]M<:]O<;&M<Z]M<[&O<[.QM;.QM;6SM[.O=[.QM[6
MSM[>SM[>UN?>UN?GUN?GWN_.QN_>UN_GUN_GWN_OWN_OY_?OY_?WY_?W[__W
M[___[___]___________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_V596"'Y!`$``/\`+``````@`"````C^`/\)'$BPX#\#%PPJ7+@P`L.'$!U"
MG$AP`8T%+OY]8/"!XD,#`@(`(+#`XT0"$```"$##Y,,+`E0"&`#")4,",E4.
M(%#3YK\5#@B(E#F`*($0%"TXF.#@08(".0N(**J3`P.($K:,2;-&RY4>"72F
M^#*#Z@`.(JZ^U#"&#9TY7'H4'9"B#1D%1054B#)B`E.F%A1:8'N'C5R5&<JL
MR9!BA`(E8FZ$,6-&#1LQ&@(;!"&FB@*B(\BP61,E08,+1:9,L>)F#9LQ8!(6
MI#$!0@$%N!5`2(%&31`/1(A`63*\28@,,X"@,"B!Q9`KEM>L&8.$QXT/-)(,
MAU+<S)@,6"K^K"!XP<F:.77PW,$SIPJ;.&5@T*"QI/X2(CK8D.&`@P5Y)W'8
MH9YZ=Z#1`AEMT!$&#"ID1X0*-9Q1QH%@W""#0`PH$<=Z'-K1QA%B])#"&$J@
ML2"$7IR1QA%ED%%3#`)-4`4=`]Z11QQ:M%%''&(`D88:):XAQ@\\`"&&&#T)
M)($3;7!XAX=?S&'''6H(,8(80XP!QXIHC,&%!A,4-$$9--I(!Q=:S+%>'$>H
M4<8/./#0@X]D@*G0!&1T,0>!==`A()5(Q!$'$&K$T48<8R1I4`-*S#B@'7G<
M0:42:]2QQA%QJ)?H0P0\H(243K)1AA%JX,&F&D^Z")%%%SRQH8=38VA`P0UE
MU*%&H'>HZA$%3Z01JVPKA``&J7BPH8%+)2C@UT`VQ-B#''>,(9M))134[#\.
ME%'8L3XM-,$:>*@19K<*:<!&80^0:Y`%8JBW1KH3!00`.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]T
M:6=G97(N9VEF````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S$T`#$P-#$W
M,S8S,#$Q`#`R,S$P,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````"``(```
M"/X`L0D<2%`@`!(%$RI<.)`$B3D(&4I<2"+0"H@3,Q(DH<(A@(\?(P[LZ'!B
MQT[!@G4B`1(`Q(A..G6ZM$)DPB<H4^I<&?)2IY.=5JQ8M<KFP!67=NI4R?+@
MSB=$K5D#D%`%@!4I5Y+(J1)DUB<65U@K6M#J4&O/5H3,R9-$RJ%#B:Y(R'*5
MU+&KU+H-]G!K2A6K#I94>-6N4*).@QWD>LGJQ!46I>;-F_.CRI@L,X:46A-M
MIY@?>7;Z.+&I6&M"T>(<O=7A2HD=#]J5O.J93M<K91K="*DW)*A5\JK@FM7U
M[H:0>NWR/33X"A5+@P$]CHT$I%VT:/E6\4RJ[>@J7ZI3]$W^M/?H6I%(M$X>
MZEW4SXYE=7()),.#O4F<O9L7[5^4(%&'S4&%O8<:`%(=\UE76XE'ET6SO?>1
M=RN@Y!J#"T&VGV032@5=,#$Q%1)%!8ZEUUT?%G?0)0)6Y]"+;)RV2HI\+:98
MB]@@00(;,<Y6TU)^=7400QZIL.%PX*7$$@DL+@28@28FF=)B/&48H8G$18=D
M4PR=E5=B2X6XU&+KM90E4WLIB5)````[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+W1R:6XN:G!G````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3`T-3(`,3`T,3<S-C,P,3$`,#(R-C$S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!
M```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$
M$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ
M-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!
M`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'
M87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7F
MY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_C$LM,&MZE?M:`I:0)<WP=D$
M:I;+,JP)((U:&)I/-C54&$+`JC!1S[_\%;&U_P"$AM57;YZS`#YSG<D5R`?E
M/!VDG@=^0,5P7PWM[`67B.?4#+%HU^+72VO7BCB<$V][=1K$&+Q).9/L<H'V
M@)%,;5)%='6>+H/AKH7CW5/&OAC0_@KX;\9?$;QYK.LP:-I7@WPSX0UKQEK>
MM:S?SO8:5I.AZ!H-G/J.NZGJ<LLL-IIUB'N;B["1VXED`2L.,\&Z^60Q$9T_
M;YC3Q4ZD%92I3=6*@W!?#0E&3A2JW:ER2CTN]_#3$8?*,TP]:M2F\+@:U!SJ
M-PE548U%":I*HX.K6IRBYU:49*2YDXIWLOZ\_P!D"]O$.BR"U1(XX[>*7Y)#
M%,T,(246A\P2$PL%2?SB6$$L,D:AQ<.O[U_"?4I5BM#`(YFDC@21EV2ASY,)
MD*L`NX1;G7``8HN"&D`W?R?_`+"7[;'A7Q5)%X0URU_X1/QYI2A7TJ:/R8;G
M5?L5O970TR2[OS=S3O/>%DLY4BOFA>=IH(HRKS?L+\4/VU=9_99\-_VA'X+\
M0^);RRMSJ-NMMI$46AV;,MY<Z<_B#7[W4K/3]!TT2::%U34-1>,PPF:[@M[\
M$Q-_%^<4JV`SB-*O3J8>NZT.2"C:>LDE*G>W-&26C5N:-G:Q_J!4>!XKX7H8
MW+,5A<?@ZF$:<Y2=H<E).<*R5YTITY:3IM<RM>S3/VC\:Q0ZAHEVMQ#"S2P2
MH&D@AE,:,(U?8+B.502O(WQNA(0NC*H6OX/O^"\OPSMO`WQR\%ZQIVA/9:9X
MK\/:U?RS:>D$5I?^(;35(;>_>TME@M'\\1W&G-=F-A:R)=PPI;/>6VI:IJG[
M._L__P#!0W]I3]L+5O#TVL?M`?LQ_`/P7)K,&DZI=>%=$U[Q3XG.IZD)H-+T
M54\4'4_`-[=ZMK5MI.C6UI<:KINH&'Q+%)I6FZEK7]E:5=>0_P#!:GX&ZUXM
M_9?\%^.9WLO&FJ_#CXE:K>2>(+72IM.N-2\+ZEIMS<7NK"T>YG%C<3QZ3;:C
MJ<&DK:VK3V44]K'!:6-OIMMZ^1*KDG'64XVMB:*I8F<Z%93E*-7EK4*J4JD9
MP45-2M)ZR2<6D]#\GSW(:N8>%O$&3TX3GB<3@EB<NI4J=:5+VN'Q--JEAI3I
MQ59\M&46X)2CS>]%IZ_SO^"?^"57[<_Q$\&>$?B!X0^`WC+6/"?CKPQH'C'P
MOJUOI&J/;ZIX=\3Z5::WHFHP.FGLC0WVFWUM<Q,K,K)*I5B""2O[]?V8+:S^
M''[-7[//P\.FV,I\!_`WX2^##)<>'-1GN)#X7\`^']#+SSQ7]E%-,YL=TLL5
MG:1R.6=+6W4B)"OHY^-&<1J3C2PV"=.,Y1IMTTVX)I0N_8ZMQY;N_5_+X&C]
M'_(U2I+$KB58A4Z:KJ.(PZBJRC!55%-)I<_.DFD[-72Z?YV/Q,^$FH_##5/'
MOP\UFX.[1?%7AF]@NREHLFHZ%XGT749=/UD+92SV:+<6MMI]VUM`6ELIKE[&
M\M[:YM9[=/N_]D/]GK7K*XTWQ/JC>%;SP'9M9:L+W6OAU\-O%=IJ`4:I<P+K
M.D^-]#\5KJ,%MJ;_`&>.VN;.:!D+J\7D%!'W_P"U]ID-_P"$-+G;1;&Y5Y=2
MTEM<EBM&O]+?4(-^G:;;RR[[M(+N]\VYQ#$EG]HT^$SW-K<36:7'BGAK]I73
M_#?[/4_@B]U*WM-;TZUM]/FA::7[5,UKK+G8T2VTB@Q1K'NVL?,\QI!G8S5_
M;'TM?#O%^%G'-')N'<3C*^5S5"67U%2K4:^$P=>I4Q6!PT*\''F^HX>:R^&,
MI3@J\L)5?)"I[2E2_DKZ!?B+D/B_P%6XLXNH99@LVH4<9#,*.*J87%X',L=@
M(8>EFTL5@Z[J0A2S/$49YM]4KTY1PZQ>&IIU(>RJ5N<^!>M_\+>_X*2:1XCT
MA?MK?$?]H+7?$,GDM<@ZU)K^M7^H:IJ<C:@Z7$*ZU=IJ.IRV:M;_`&-+AK.Q
M@MHTM85_LV_X*)_LBM\=O`B7?@RT:T\0>#]5TZ\M-26/1;R`Z'#:21PP:KIO
MB"&YMKS39KNY@:^2S-GJ,ABM@NH65G;B:+^&;]A;Q-J'A?\`:O\`@/XFTQ6?
M4X/B)I45N$0^9C491I[RE@CL_DPW5RVUHSE?-^:,NSK_`*0U[XL@\.37TNJH
M]S81:?<0:V\\EQ$+3S1&PN[PE;ATC,;K++<3`I;1R^9)*L9!K^%O$5TJ6;Y4
M\1%I4L'0DZSUE#V4J\;RE?FG/GE"3=VW[-:<J=_[I\*L?FCRVIFV64Z$W6SS
MB%_V0J<*>%Q4,8LEJ3H^S@E1ARX>M/#X=2Y:?+B)0<9:\OY>?LI_\$U;+3-"
MT.3XH:)HFNQ^#O$6D>(?#DD5QXFEU/03INN>+=>AL_`^JZW\2/%P^&6D3:WX
MGUC5/%.E?#*W\$V'Q$GO[N+XB6/B[S([B#ZI_:I^#?AWXMVWA#X87MG;0^"/
M#VOVGQ`\8W9\G[-I?A/X9VNH:]=S7!O[FS#6FHZC!I/AR^W7$[K8:Y=7<EA?
MQVTT:?3N@>.-(TC2]2MM-N%@+Q+Y*V]P\\;"0SNS;BL[NC+,[1*LJ+&64(=J
MJJ_S?_\`!;7Q#\5O%GB#X`>`_#OB37]%^&_BF7XD77Q4L-+UUK#2];LO#^H?
M#O5_"B^*-&6XA'B"WEU.SU&/2-,O;2[M(]1-U>N";65#IP'PSC_%KQ!X3X9R
M^KF>:9CF>(CA\16H4O;U<-@Z3J3JRPT:2O2I4,$JU>K7JR5"A2BYU*E.$)-8
M>(7%U'P>X+X[X_S?!Y+D/#W#6"Q&-RG+J5+#Y51Q6-QRP^&ISQ-*K3IK$8O%
MXZK0PE"*5:O7Y:%"C2GRTZ3YSQ__`,%0OC]-X[\:S>`_$/A&Y\#R^+?$DG@R
MYUGP1:IK%QX4?6;UO#L^K)_8\6W4I=(-G)?+Y46VZ:4>6F-H*_-PZM?`D*U@
M5!^4R64SR$=C(XO%#N1]Y@JAFR=HS@%?[P8;Z-O@5A<-A\,O##(ZZP]"C0]M
M6JX]UJRI4Z=/VM5QS",75J<LIU'&,4YMM12LC_G=Q?TP?I%8K%8G%+Q3SK#+
M$XBM76'PZHPH8=5JCJ*C0@\LDXT:2E[.E%RDXPA%7=KOV?XH>"H_'?@+Q'H0
M"O?SVHFT93):Q-_;=H3?:8JRW6([5+NYM5TN6_9XX[)-1\Z:18]P;\-O&.BW
MEMXAU?2-0L[FQF6Y$&I17L1LWTRYL2B:HE[#<^2T%W'<QRI)%.L,RW(9'1I=
MR5^LO[8?Q6U/X5_`KQ'-H5Q<:?XD\8ZEH_A'0M9TZXDM=5T":\^TZQ>:IIUW
M#<6UW92Q:7I5Y:K>6CB>UNKFUD1B`8Y?R*LM=U:^LXM6N=7U+4/$>H6\VH:Q
M?ZO?W%Y>7LVLM<7+W4=S/.][?3*EY,+XN\TRR10S,S)EU_&?I\9CD&,X@R#*
M,%&J^*,MR6&(S&M&I'ZL\+B\1BY9=A9TK.HL=0C#$XR-1.,%AZ]--.4KO]M_
M9LX3B3!\*\28K,9TO]4LUSB:R?#RI3>)>,PU/"X;-L1&K)JD\#C.;#8-4TN?
MZS@:LE)*4U+[Q_X)X_!/X4^._P!H;PM=ZM\8KWP-9^'8-7\2Z(/[1\/:'X@U
M#7M"TY+W3=+TIM6DGAU&]O\`49?*@T6UL8;[5;.UOTM+ZU:*>[M/[F/A]\;O
MA9XF\$P^)/%'C/PKJ5YJ/AU+3Q+H]]JFBRO87GV.V&HV6HZ9<7T]Q;/&ML#=
MPSF9V6\WM"R7%JL?\-W[(O[*FN>-M=TW7M,O?"E^]]86U[8Z6FJ2:;YFZ53;
MWMIJ-D+6[TJ:SN)?MJ3B9$N+C2XHE2XF%G)'_6;^R3^RII_PS\.Z/K?COP'H
M<GC&U36;<W%Y'H.O6UM+>3V)FU*+5?-U2XU#4[XV=PR7QGMO[.@N[BPMK>(7
M%_->_P",?B)BI5\R<?KLJSPT%"G&4*<G"3352-XI2<4V[N<;7O9[)_\`0GX>
M<*<-X3PQP^/Q.,J93G&,Q,Z]'*<%1J.IB7*:46L17;A1A55'"MSI.4E"C&*7
M,?<7AS3K":-X[&ZCN[&=Q#:7DAB9Y$BFEB82RK(T!=&0P^8DBP`H2-L>`/YO
M/^"D/Q2T3XC_`+16HZ7X6U"ZU#1/AKX>B^'=P9F4Z9-XMTC7_$>J>)[[34CE
M;_2;>75K#PIJDTT$$G]H>%;F$"2WAMY*_H`^,/AGQM??`7XS^&?A)>W&A>.[
M[X:^--%\%:[H5Z^E7_A[QAXAT'6+7PWJ>EWUG+:3Z?JEOK5]:W=G?64Z2V5Q
M$E]))'Y88_P^?`#XC^+/&S^.M*\;7FLZMXHT36%U*\U'Q->7]SXCOI/$&IW[
M^(7U:347FNIKW3]:65[FYFE%QG5HK6X5Y;:2:3^L?V<5#AF/B_CL=G%:K_K!
M#A_,,+PS2C:&'IUL72KU<;4KV?,ZE3*\#BJ6%@FJ;YZ].2E*=-'^=/[3O-N+
M*_@G0RS*>2MD6)XCRS$<55*CY\5/!996PBP%"C**5-?\+&)P&+QRTE!4Z;C%
M0YW#WG>X[+^9_P`**L&T8DD$<DG_`%C?_$45_N'K_3_X'K_3T_Y_%.EI\/3]
M//[_`)]T>`?\%*Y)%\*_"R%7=8G\1Z_*\2LPC>1;#3HUD9`=K.L<DB!R"P21
MU!VNP/Y\^$V8:KX7()!+VZD@D$J^U'4GN&1F5AT925.02***_P`T/IL?\GPS
MS_L`X9_]4.$/]5/H)_\`)G>&_P#L9Y__`.M#F)^\G_!)7YM8@W?-B9%&[G"I
M=:>R*,]`I`*@<*1D8-?U\>'V;_A!_#AW-DP6V3DY.5N6.3GG+<GU//6BBO\`
M)_C;_D=9E_UZ?_I<C_<;(_\`D@>!_P#L&I?G(W?!0#_#G1BXWEXKQG+?,6;^
MU[GELYW'W.37\#FL?N/^"B7[5<<'[E'^+_[2$+I%^[1X8_CB[)$RIM#1HT<;
M(A!561"`"JD%%?O_`-!?_E(?AS_L(PWYUS^#_IW?\H\\>_\`8;F?_IF![XO0
M?0?RHHHK_H(/^=Y=/E_[C/_9````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O=F%M<&ER92YJ<&<`````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,#(P-P`Q,#0Q-S,V,S`Q,0`P,C,S,#``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````_]C_X``02D9)1@`!`0```0`!``#_
MVP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"
M`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A
M!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%
M1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9
MFJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?H
MZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+
M_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1
MH;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U15
M5E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::G
MJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W
M^/GZ_]H`#`,!``(1`Q$`/P#Z-^%7[%'AK]M?]I+]GM_V@/`5]XR^&'["/P9^
M%GQ6^,NJ^)=-'A:'XI_$W6_#>E>'/A9\(]<&L*-2AE\1ZGX9U#XH?$'3?$B&
MXO/#BZ!H-O83Q^,;2WO?V#_;"\:>$/%GQ/\`V7O`_P`<?&WAGP'X\^*GC%O"
MW['UCHES=>(?$'A_X@>+?!>L76A^.-4\'Z?I4.D6<-E=Z'HS^';CQ-K5Y%J.
MK7$^DZ7H7@^>33XY/3_A#\!]7\8?"C7K[0(;W3V_:._:>_:A^,GQ.>T@O[2+
M6M7UWXHZ]X0\&V.H:Y]HCU#3M(T[X:>%;33=2-K(+YM-LI;+P[-9ZGJT#M^?
M?_!3KQ7\"_V5/'?[#_@*PTFP\8_$/Q#^W5^Q[>>./BWKSVUIK7A^YTCXE>%K
M?P]H7AV]TF(:?X.\*C0H]1:P\$:(;71=%T":))H(UTFR6,`_/RUM_&'[3_Q\
MTOX0^(K;XX?\%-_VN[OPZ-0^)GAWQ%X]\0^#?V//V1]%O=2GMXM"^.MMHI\`
M^&F\4:9/;:_J<?POT^XT2[N8+FST_6;CQEJ-Q.9O9[#Q!^U+_P`$[O'/@;X+
M_%GX%?"WX/Z9)%JWQ<^"[_"N74?&GP4\8?$GP',GBV/0M'FDTRW\1>'_`!,_
MA$^.=/O8+W1[$7-A#:G4]5-AH6AWD_ZW?L[?'/\`9!_8L_;=\=?L(WQT3X=?
M'']K/XD?$W]H'0;V2W%O'XQ\1:GK$]KX5\"W>J7`5/[;O_AUX=T[Q%X!ADF;
M2=5L])\16#1Q:]'#%<?9_P`3_@W\*?'7Q`TGX%_'/P?!X\^'GC74_$'Q/^!D
MVJ?VA)=?#OX@Z1HFL6OCWP[IFLZ?-'?Z5;#0]9O?$?AFUNIS8FUU7Q/X9AM_
M[(\-Z7:``_`?X/?M@?#%?V@_VUOVU_AK^Q_\2OB7\"?@/J^K6/C;]H'4M7O[
M5[+4SJ\^M_$&/P5K6L^?XM\5^(=%@*:GK6GZ"^G?#CP/\/1;^'=/MA-,1K_[
M5_"K]H;X(?%+XD?%#0&\8^$/%?[/OQ@^'WB+Q)<Z3XH;3+SPQ#?:9H\.J?$V
MZU"76&&GP>"_B'\,_$6A^*-1TW4E&D+/X:\7:S<6^DPS36MS]J?#7X=_"7P7
M\,)OA!X.\/:"W@;POI%[X-\0Z*EGIKV6LNVCPVWB"/Q&UK:V^GZOK.L6=RLW
MC"=XIOM&HW%S;W+S2Q2K'_*S^P5_P3#N?%GA+QOX5^)_BBXU/]F#XI_'7XA^
M%?@;\*M-UR71Y/&O@+PG/XC\"0:]J7C.QU33O&LOPETGX4Z3:WDGA_2;J*Q\
M1^*K;PEH%_%/I2K`@!]8:/\`\$PO^"4'C;2-*\9_#SX\?&_2?`'B[3;'Q/X&
MTKP7X^U(^#M,\'Z]:Q:KX9T_PF;_`,)W=\?#-EHMW96V@F]NKF[_`++CM?M%
MQ--OD8K^@'PCX!^%GP^\*>&/`7A.R\->'?"O@CP]HOA#PSX?1KF-="\/^&M-
MMM&T;1UCFUE9HUTS3K*VLE251(H@"R`,"**`/#/V%?&)\4_`O7])OY;<ZW\*
M/CC^TG\&_$<OV9;=;>_^'OQM\<:;;3S0N6<+?:#%H>J2LY'VR*]M[A]V\.?Q
M]_:@_9!\)?M5_&[P=X;\1ZMK5MXK\6:YXF^(6G:^OE:A=>"X]9UBVL?#/B:P
MT>\\R.XUGPMI6I6]XVHJ(KJT98+6UF^W76GM!]E_LZ^($_9]_P""C'[57[+'
MB24S?#+]M;2_^&XOV;/$<5V\N@:QX@GT+PK\._VG/AI8:M`Y@;5[6_T3PA\3
MM.B@F^U77ASQCJ&K60$=G<&+Z'\&?!W2KG]K[XA^-)I99=-\*Z!H?A30[7RH
M_M$-YH"^$_&XL9Y&!,UM$/$ELUN<E6B,+OB8RD`'\U7[>/\`P3)_:G_X*QZ9
M\,OVS_A]XXL_A[^V)\*9+ZVA^$NNZI:^#-#USPIHWCSQ!XT^"GB3X9^+]!^R
MZGX?U+1]`MK6XGO=:&K^)M-\9^'=4TO4UGTY;LO]@_#GXX?\%2_'OA/]F'P=
M^W%\`O$/PT^+OP;UCQ'JOC?X@?`G6+35?%'B32=9^&NM>`_!&LZYJ2:GJ'PX
M\#?$+X@ZUJNJ6-EX.E\0ZM%K_B"#1=;FL_!NCZSH.G7/VCX*\11?"SXZ_`+Q
M79:*-5\/^`O%G[4_P(^/&LM=2R:C\.O#WA+XHZA9_"[Q7<Z?-+]@T_P)967C
M<2:UKBK9?V(/$HFDFDL[NX6+V;XS>$-7TZU\7_M-?$WX[>*/#D-K\8?`5UI?
MA'0/BVEO\)+3]F;P#X\L+VZ\-:OX"MKJ]\.^,/$GQ!\$?\)7XWUV>PT[5O$?
MB&>_TKP\+A-'T&VL``?ST?%S_@N+^VG^V-\9_AU^QU_P2N^!'Q.^!_@G4O&&
MG>$?&WQ/^,7PPGO/C;>Z?::]"/'][8^&+]=3\'^"--TZ:35M-\2:YKFHZSXC
MOO$MQ?3+)X=L3-<Z5]O?L(_M1V_[8_\`P4Q\:>&/@7X2U3PE^QE_P3F\/^'_
M`-G;X8:5?VD%K?>*OB'XNU[Q-HGQ)^(<UO(9Q;:5+=>&;C1M%-G=S/<Z=IK7
M["SDU.YT^V]=^.OQFUSXN?LY?$S2_P!ESP5\2?V2]"^-?Q1D\#:3XT2]OO`_
MQ&\<>+-=T&QUGXB^-/`^E0O;:OX'^$G@CPUJ?B#Q3XB\;S_V;>^)_&%Y9P:'
M;0"^9I>C_P""*W[,_ASX&>&_C?9^#["1/#M[\5OAK86MU#)/J%UO\+^&_%'B
MG6KK7-5U>1[^\U>[U+Q*!JVHW5Q/.U^TMPEP$ND#`'H?Q<O/$`^*WQ.$-]?K
M"/B%XT$2QQZMY:Q#Q)J0C5-MT%V!<!=H"XQ@`8%%?CU\:OVH/CIXH^,GQ:\3
M>!8/&5_X(\1?$WQYKO@Z^L]*UQ[2]\*ZOXIU74/#UW:M#F%K:XTBXLYH&B)C
M,3J4.TBB@#]&?AO^S/\`')/V4_ACXVMOB'JWBB3X7?$'Q/\`%'X-:RGA_4]=
M^)?[&/QI^''B/Q'X(U3PYI%C`NH^)OBA^SAXWCLM8\$_&?X3R0GX@V?A/7-6
M/AFU\4ZC<);:1^IW[''[0?PY_:8M-<^('A34M`TCXC^'M=U;P]\<?A0FJP:I
MXB^'GQ#?2O!EE=VKW5IL;5/">IV>BVNM>#?%LEB]MXI\.:YI4T,/A_6X->TF
MT\4_X)N?M#_%CXJ?#WQEXD^-7PDO/A[HK:G-XF'Q4MY-+@^'7C3Q6-8U;PW\
M1KOPO!!J=OK6EB]\8Z3JNK75I-I0@M=0U/6XGG>"1%K[_NO@O\'M=\0V'Q$'
M@;PM_P`)C;V%]#;>./#EA;Z3XCFT_65!NP/$7AR.SU._AG,UQ-9+)>SPI)<7
M$\86:6<D`^*_A?\`!#X3_%3XL?M/Z%\1O"$6JGP/^TAK'C.S8ZYJEG%-+\1?
MAEHUA>P:NNE:O;VE[I#6=FVK1Z7J%H@CU,Z1?7$;7MI#/7R+?_L]6OAO4?"Q
M^"^L:UX3GOM-TJ'5-.77K?Q'?>*-3^,'B[Q)X9\#_#Z5=6GO9?#$-]X#L6^(
M?Q$\5I*?$NE^'?#3W/AF73]3O[VZN>[?Q-XM_9K_`&S?B9J/_"=E_A+K?Q%\
M'KXF\'3ZWHWC3X^?$'4E^#=E9^'?#WA+PAJ%]%XGU_P7/<:G'KCW/AJWU7Q9
M>ZQX%U?2W0V<#V\WN6F_&;P?K_QOL?BU?>'?%/PQ^`/PR\+>(-4U?5_%'P[\
M0:*VO_&3QKHGA33;#5/%T,6F/+X%D^'GPFLY-+,_CBXT.YL+?Q1:V]K9V.D1
MV+W(!O\`ACX;7W]J>%O!ECX9N4L+&TU'1/!4.IVYMHK;P/X<5]=\0?$'Q,N'
M?3M9^,/CZ[\/Q6NFR8N%\)RSV-]YLD5['7E7[0VH6'[,'P^\`_L1?LR7]P_[
M2?[9'B[5?#?@I8HQ=W'PM\"_V7I-I\<_VD?$45L`=-\(_"GP/:3:CX>CO7B;
M7OB#K/@_PKIRS)J&J+%ZW??MC:9XI\.ZKJO[&?@'Q-^V5XW\=W,:^'_%7AF(
M^"_V?K*RFA<:3>^*OCIXDCM?"/\`P@>D6[7=]>R?#Y/B#XMO9+K4[O0/"VIZ
MCJDS5T_[*/[(GB'X4^-/B!^TM^T!XLTWXQ_MB_&?3M,TGXB^/M)TN\T;P1X"
M\!Z1>'4?"OP&^!.AZE-))X<^%/@S4IKF[OM6O_+\4?$GQ*M[\1/%EO;:EK-I
MI6D@'U9X&^#/PP\!>"?!_@7P[X)\-P^'_!?A;P_X3T.*XTC3KZXBT?PYI-IH
M^F1SWMS:M<7DR65G`LMU.S37#AII6+NQHKO/*TD\R6UO-(?]9,;'S3*_\4AD
M$#"0NV6+@D.3NR<YHH`^)?V';&RD\`?'K0GL[5]$L/VI_P!H31K'1GMXFTJR
MT>X\1VLMQI5IIQ0VEOIL\M]>R36,,*6LLEY=.\3-<2E^3_8;U;5)3\1O#LNI
M:A)X?\,?$7Q]I/AO0I+RY?1O#VE:?X_U*TL-,T/3&D-EI.GV5J!;6EE806]M
M;6_[F&-(_EHHH`Z#4O"_AGQK\,OVGM3\9>'="\6ZEX>\7_'R/0-0\3:1I^O7
MVAIX:M]+N?#B:/=ZK;W=QIB:!<P07&BK920#2IX8I;$021HR_,GQHOKWPC^Q
M[^T1J'A.\NO#%_:_\$Z?V@?%]M>^'KB71;NW\6%O%LY\407.FO;30^(C.B3'
M6XW74C*JR&YWJ&!10!]\?L::%HGAW]DK]F31?#^CZ5H>C:9\`/@];Z;I.CZ?
M::9IFGV\OPZ\,7,L%E864,%K:0R7#-/)%!%&CS,TK*7)8_2P1`00B@CH0H!'
MR[>"!Q\OR\?P\=***`'Y(Z$_G1110!__V0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]V86UP:7)E,BYJ<&<`````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,C8W`#$P
M-#$W,S8S,#$Q`#`R,S,W-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`
M,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_
MQ`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C
M0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-45597
M6%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X
M^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($
M!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B
M<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$`
M`A$#$0`_`/ZU_A3HGA?XY_&'PA^U!\,;E;[]G[XT?L0Z1X1\$W5AI)TRTTRW
MU[Q[-XNC$<*W`LM%N=9\/^)='E;0A9_:;[6-%2X#6`LK^"3\A?!O@WQY_P`%
M`_\`@CU^V7_P34\6>#H]/_:F_8MT35OV=/#,%WIJ6MMXIUKX/1C5/V<_'GAY
M]3ELVLKCXDZ%X3TG16U03M:6UW>W.J7,?V.]\E^A_P""3?B7]MCX!?LIZ9X!
M^`W[&=_\4_V8)_&U]?\`[/'Q:^)_[0_AKP+XAUWP;XY^(FMR^)O'&K?"K5--
MU#Q1X"^'>C6`MM:T?PI;3^(-?$%S?WNF/J]E=M,W[VZ?XQ^#_AWX\Z[\.X_%
MFE-\>?'W@'1?B)K_`((M;D?VDG@/PG<Q>$E\;:C8FWECTW3$O[F+2;6_\07L
MFH:F;2>RT>W>WTN[9`##_9T'A/X3?!_X%?`>ZN].\.>(/A_\&_AEX070+J_C
MN!9WOA[P?H&D76@IJS3O9WVNZ;=62O>:0MX-5NK&6WUB.&6.07!^CM2U&/2M
M-N-1G@NY$M+8SRVUK"+F^5%.';[/"S^:(@"6,#,K88H&7!'\_O\`P5*\1^)M
M/T/XO^*?V7?%WQ%^&/QU^%ITOQ9XK\?0^/#<Z?X*-_>:-8P:+XU^`GQ#@_LG
MQ5\&OB_I&FV<.C^-?",FLZ/+XD6;099M"\01W%B?A?\`X(P_\'#-U\;?B=:?
ML7_MVW/AKP1\6[S4#X?^$GQALXY/#G@WQGK]E!MN?AGXLMM8NI9/#/BNYF"G
MPEY^H_9]=00Z-/>)K?V*37`#]_\`]M[QEX7\9?L?_M&7?AOQ'IYUWX?_``TU
M?XN:="V;?6+"^^"]Q9_%RUN#8ZH+.XLH;75?!]E8ZAJ-K.5T^:2VN(KRSO8(
M(Q]4:QHG@3XX?#C2QXAT/3O%7A+QAH^D>);*UNE,QE74M%@U+3+K2=3B^QWV
ME:O'!=Q7&E:Y8366H6LJ*]O+;DA1<^(_PM\`_%GP]J/A7XA>&K+7M*U?3-8T
M6]BE:>UNKC2_$VBW?AS6(([ZVEM[N&&YT[6KJSDMA>.F#$X#SP6TD?P?_P`$
MY_$OQ.\(>'OB=^R-\7_$MEX@\:?L>>*1X!T+6X;*T>_\5?L\ZJ]]-^S?XEUF
MZAUEY+GQ#9_#KP_'I?C"[>R\^_U.-ED=M56YG<`^A8/@G^T;800V.E?M<^*4
MTNRBCM--37?AM\-M=UM+"V00V:ZSKEYHCWFLZJMND8U#5;MVN=1NQ->3LTLS
MDE?6*1(J(IC3*JJG*1DY``.2J(I.>I55![*!P"@#XC_X)T:EI]Q^QO\``CPK
M;V$&@Z]\'_`ND_`+Q]X;$$,-UX:^)'P->;X8>-M%OX8"1;2P>*/#.H7VFVTA
MC:\TC5++Q&1<6^NVEQ)RNBP_#3X!?MT_%+5/%>J:CH_B+]M+PW\+KGP9K_BA
M;0>&=1\5_!7PUJ7A34OA-X5\4'R;?2M5A\*OI7Q"L/!>H77]H:S>ZCXU\0>%
MK>^AMM<AB_`O]E/_`(*:?%_]G3]N328/VJ_#O@C0O@Y^U^GASPMX[^*WPPU*
M\D^%6L?&O3;;3O"?PO\`C]IVAS0+-X5N?'FFV%G\+/C-8:"9M-TW4K?X:>,-
M0MK)H]7NO$/]0W[0G[/_`,)_VH?A'XJ^"_Q<\.P^(?!?BRQMY)((;RXTS5_#
M>IV4\EWH'C/P;KFD3VNI^&?&GA77$M]:T'Q)X=U*QU;3-2M8+BSU`%8D<`\_
M_:A_8W_9E_:LT[0KS]H;X=:1XHG\`KJEQX?\176M>(O"]YH4.I6T;:KI]]K'
MAK7/#5S?^%;M(8;C5]%UJ^FT*_GB\Z2Q6<JU?P@?\%-?^"47P=_9>U;XF?MB
M_`;]LG]G#Q=9Q>*!KG@_]ENYMK#Q%XGU2S\6W5AHE_I6A:=XR\5>+!XIM;*P
MGFU^>YU/3]2N-+O)3+$\,D$#)^[/P)_:X_X*E_L!_M*_&3]D']I_X5>._P!O
M?]F_X*_#NS^('P[_`&FO".G::?VD-3^#GBC4]2TGP'<^(M/AO[.W^*.I:7JF
MBW7ACX@3VNECQCI.LBRU@B\T6_AG;]4_AW+^P]_P57TOPE^T#X,UB'XC:7\/
MWN_"TNCR^&/#6FZAX2U^XE&I:II&OR>(/!U[XRTC6;<>;IETWAWQ)8Z;<BT$
MUL9([@7)`/YUOV!O&7[8?P9_X)[-^T%\6?V]OVGM0\1^#/BE8?"W1OV??(\.
M_%#1['4KR'PKJ?P6\+ZSXI\>6=OXST1_BO>ZO:6NF>)SJ&O^#&\+:AI\D?E:
MA*EV/ZJ/V0_V8-1^`NB>(_%WQ)^(6L_&+]HGXO3Z+XC^.'Q.UR:V5=0UO2-/
MDM+'PKX(T*RM[?3?#?PZ\+RWNHV?A;1[:W2X%FT=]K=UJFNSW.I/P'[8GP9_
M88\/?`SQWX__`&GO"'@OPI\,O!WA/3H=:\:V]UJ/AKQ396.@6MGX<\+VFA:U
MX=N-+\0:EXKLKI-!T?P%80SWFLW'BIM'M-,M))8+*.Y[K]ACXC_$GXG_``%M
M/%/Q%EUJ^BD\3:]I7PZUKQCI-OH7Q%\1?#;23IEII=_\2],TO9HI\?QZN==T
M+5[WP_:6&BZM%I-CK5G;HVHSS3`'V@!@`;=F`!M&`%_V0%)`QTX)''!Q10%V
M@+UV@+G`&<<=!P/H./2B@#\!OVM[KX;_`!V\'ZYX2_:3_P""+G[3WB;X(ZE9
MPI%XW\`Z-\#M;^)6F0F.>]CU&V^'GPI^+$WQ7\-)`(FAU*YM&^WR0>=8RZ?)
M%<2V3=5_P2)_;M\!?%"+Q7^Q1/\`&A/BSXV^`NGR7WPC\=>(;#5_#7C[XH?L
M^V6KQ:3H%O\`$;P1XEL=$\5>$_C5\&)7M_A?\9=&U#1DFN-0T[0OB"ES?V?B
M^00?N<44!4"A50C:B?(BE7#KM5<*,,!VY&5.5)!_-[]K_P#X)^>!/C#XHTG]
MIWX(Z'X4^%/[=OPF2?Q#\&/CW:V$NFMJFL6>G7-FW@7XP+H;6LGC?X7^,]-G
MF\&^+K35[75-8TO1KVWU7PU=Z9J>E6UW$`='XQU,Z/\`\%)O@^FKQ)IFF>*O
MV.?COX>\*:W=I<PP^)O%VD_%SX,>(]=\,VMVL45G<:SI/@O3=2\16FF[GU!-
M'@UO5;2UO[&PN_)S?`'BGX)_![XZ^/\`X'?LQ^#;?Q?\5?BO\3-0^+7QY/A^
M72M.\$?#&2YTGP[X?U;6?$NHVT<$4,Z:?I6E6^E>"-%BO[VY\276IS:G?6=W
M)>/)I?"GQG\&O^"BW[/D5S\0O!=QX<\8^#O%=YX6^*GPWN]5N="^*/[./[0/
M@R&30/%&DVOB;0+K3]9\.>)="BU'5O\`A'?%F@7E@_BGX?ZY:W%E//H7B'4;
M2Y_`[2OV?OVMOV*_BS\=M&_X)Z^,_AK<>!?A=-J-M\9_V@_VD?AWKOA+1M,M
M8/#-_P",/$X\6_&I]3O_``GX_N_AQ-<:!HVD>&O!GA6X,/BZ[U+7O&V@NFD0
M+.`?L%_P4'\0>`-;\4^&O",_B+3?B%\5M,TW3O#/P4_9\N_#=GXB\)P_M*?'
M/4T\)_!_XR^.H+R34M*OM2^%_A'2/B%XX\+Z-JME=G1-`\*>.?B%96W]I:;X
M>G'Z9_"_X?Z-\*?ASX%^&WA^6XGTCP)X3\.^%+"]N9&>]U*#P_H]KI$>I:E,
M9)'NM0OX[475[<32323W,C2O([!6'Y%_\$Q_V3_&USHGPS_;)_:;M-*7XL^-
M/A];^+/"G@<3ZWK6K>$]7^*.@02^//B[\6?&7BH0Z_XV^.WCCPH^D^#-7?4M
M*T/PM\*?`&DVGPR^'6F:=INH>((M2_;`9P-PP<<CT/<?>;O_`+3?[QZT`(``
M```````.@`X`'L!12T4`-C)*(22244DGDDD#))[DU4NN+>Z<</%!>RQ..&CE
M6W5%DC;JD@5W4.I#!78`X8@E%`'Y+_!M$T+_`(+0?MH:'HB+H^B^(/V//V4/
M&NO:/I2C3]+UOQE)XU^,7AV3Q;J^GV@AM-2\32>']'TG0GUZ]AFU5M&TO3M+
M:[-E96T$7TA^W'96>J^"_@5H6IVEMJ.B:]^V!^S+IVNZ-?P17FE:UI[_`!;T
MN\>PU;3KA)+34;-[NW@NFM;R&:!KF&*<H98T92B@#[7+,43+,?WJGDD\C3'D
M!Y/42`2`]G`<?,`:O!50!$541!M55`555>%55&`%```````P.***`"BBB@#_
MV0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]W86-K;RYG:68`````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,C`U`#$P-#$W,S8S,#$Q`#`R,C<R-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/X`L0D$0)"@P(,D")(XB*V@0X8-'19$
M"*DB)!(8)3X<J-$@-A(60U[LZ%$C$H\@189,J/$@P9,G"Z94*9+E1(@.2;"9
M2;-F3)P.>PJM2`()1(P["0X=NI"B1:47EZK$Z)2H3*DC`>B\*)`G)(5",6;,
MR?5C3:\7,:Y@=>T:JQ4%W^ZL2I/$VK9X\;X-X+9I5Z9L\PI^VY<A6HL)!2N^
MMA;NT956`2QNR\H*J[>!_%+4J3&PXA6!U@;P:)@-R;N*X\K$:5,CZKRJ";+2
MS%GBY15V4\O628(5`*>M)5.^;"4O7*T5DW9E<S%IW+8KHGMVBYOYR.48+9HF
M>)?M6\^6WV-FY.@U.("[W*=3;@I@*D.':PN^INZR)D3#OB7"#5#"Z$#$FMW7
M6V<!F'""7UI1=9^`[55T'BLEG'#";PM6^-Y,O:U@X(046E@A3[T%(.$)!7;H
MX6.1`;"A"2:8>*)A)#T4$```.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W=I
M;FYI92YG:68`````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3(`,3`T,3<S
M-C,P,3$`,#(S,3$R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``
M,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`
MF<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S
M`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS
M9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S
M_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF
M,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!F
MS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9
M`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9
MF3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9
M_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,
M9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,
MS,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_
M,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_
MF<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````A^00!``#8`"P`````(``@```(
M_@"Q"1Q(L"````43*AQX$"%!`*1(.5Q($4"S9\T0-FPHD>)"BQB?';Q(4F1#
MCP9#7@2@LF7&@RBQ@20YTV7(DQ550FPY\N:SCAY9EBPIU"50F`9)#35:%.)&
MG`R7+CU(ZN9!DT@%UI2*D:I4B5EEVOS*]2)0K57+CK4Y4:O:MSI3PB7JLJW;
MM5.5\DQ8=*[(O7S]TGSZ$>]8`&[<V&6XU?#@BHK[.NY:$9+EGG,7:VUH&5)#
MMB'/&NQ\T$UGSX<W*@1PVC-KTE?-1D1,>&!KV*V?OGY]V>'MT[Q_>S8-7*#P
MSJ:#X\Z-\+CSX;<A9G3-N37QYY=IZE3N.?KOHG6Y"%,_^%UOLX```#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O=VEZ87)D+FIP9P``````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,30W-``Q,#0Q-S,V,S`Q,0`P,C,Q-#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_]C_X``02D9)1@`!
M`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`
M``````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01
M!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"
M`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A
M<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7
MF)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;G
MZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^?>[M+6_M;FQOK:WO;*]MYK2\
ML[N&.YM;NUN8VAN+:YMYE>&>WGA=XIH94>.6-V1U96(/E?@M[OX/V7B+P=8?
M&._\>:7\3]2TSQUX\^#VB^$==TK5OAG%\$;+Q=X4\&?$7XK:O<:1X2^&^L:)
MIWPR\4^)]9\&W_PTO_B1+X:\%'XIZMX[MO@_=:7J^B^)O7*VO@[\-?@KX:\4
M>%_VEOBU\$_"'Q3/A_\`:L\!1:;X5\0_$#1;_1/B)X7^#,'@?XF?&GP7XR^$
M&JZ)K<E_8>(=,\2?!#PMK-YK]G<>"=1^'OCOQ/X?:UU?4_&5G=_#S^YOI,+B
M3!XWPCSS@V&)J\3X#C>6'R[#87`8+'?VD\7@9OZCCX8WV*EE2=%XO&4\#C\!
MFKAA^?`UY4XXS#ULN"'E\UGU#-,)'%8-Y4\364L36PLJ5*A6A"O4HUJ6'Q<*
M6*C1KSGA:N(PU?#_`%BG2HR@IUJ=6G]A?$;_`()Q_MH_"2_L])^(_P`$;[PI
MJMWX3TCQM)I6H^,_AP^IZ1X=\2^*)O!/@^;Q/I]IXQN;OPCJ7CSQA::EX8^'
M7A[Q3#H_B+XB:[HVOZ7X(TK7[S0-:BL/9O%7_!'_`/;:\*>"[;QE=>`M/O5E
M-Q!=Z+8:C<2W.F:C9Z2_B:[T[5?$+6"^`]"N+?PD(]>V>)O%VA37<K/X>TR"
M_P#$SV.DW_R_8?ML_&;Q-\1/#W@OPQX0CUSQWJ%_X&\9^)?#7AV-M9TGQKJ>
ME>*WMM%U70?"MQXTTCQG\,?"6D:7X+^`_P`";FP\&^-?#5U;_#CPK%KUIXP\
M5_$+3-!T6OZF/^"8TG[6/[67Q"\>?"GXT?&GX<:E\)?#6M_#']M;0=7^"ND?
M$C5/`6NW/C*'P/JOP&\%>"]1^,%EX7\8:C\-OAW=?#W3O%?AR+QCX>TWXP_#
MOQQ\/]'N?%NJMXMUV]&A?B>?_2>\:,BS_*LGS[(^#\DQ^#G5P7$64Y5@L\S>
M-//J-?$PK8.KCL7*E&MD*HX95<+G&`EA*N)I5J->K'#QQE*CA?5PO"_"^)R?
M.L30QV85L1A\1.IE.-Q53"X/#8O+J4\-!*>!I+%XJCF==8F$H86I5EAW)S4,
M4U@,4Z_\</B3PSXA\':W?^&O%>B:GX=U_2Y(XM0T?6+*?3]0M&F@BNK<S6MR
MD<JQW-I/!=VLP4Q75I/!=6[RV\T4CX=?Z-_[77_!(#]EC]H7X,>)?"^LV?C#
M0/%VG^%WM/`/C_PA+XKUWQ#X4\1:1JNIWO@?44\!6_B:T\)>-;.VAUW5]"\5
MZ)KNF0C6;'Q!XFU_P]XB^&7BG7=;\92?Q@^#/V#/'7@SXN>,OAS\2M-CE\4?
M#OQC?^&]0%E'>MX>U#^S;R2+3]8T.YU33=.U#4M)\2VZV7B'PUJ9TRW_`+0\
M-W]AJ<=LJ7#Q5_1O!?TA,IXIR2;EE.(CQ?2JTL+#AS!SJ5(9C4J4DUF&&QE2
MC[/"9;SQJO$QKNOB<`HPHI8ZM7PGUKX:OE%2E4NJD5A]&ZTW%.%VTH.'-S3E
MM9Q2@VUS.%]/SJ3PWKDB)(FG3E7574DQJ2K`,"5:0,IP1E6`8="`>**_H^@_
M8X\*M!"UQ]F6<Q1F=5=PJS%%,BJ!;R@*'W``2R@`8\Q_O$KZ5YKXUR;E#(>"
MXP;;A&<LUE.,6TXQG)9C!.23M)J$+M-\D=$\U3RS2]3%7TO:=&U]+V_=O35]
M7Z[V_FEJGHGB>WTS6_'WAJV\.>#IM1\1^%/`K:EXJOK+6M7\:66C6GB/Q/>V
M^BZ0=5U"Z\&^$]-NM4TJ"[&O>&=!L/B'J2IKWAZ\\41^"]3UC0-<N5PWA_3S
MIWC#Q\SW&G/+KM[H7B`6MO=RRZA;V7_".Z;X;M+B_M)+>-+87M[X;U>.V,,\
MT,D5@'#F=[F&U]_Q"PN#QM7@'#X^BIX9>(N08I8B5.=:&"QF783-LRRJM*E#
M63Q.:X/`Y92J2:AA:^/I8R5UAW%ZY/7KT/[4EAW'GJ9-CJ$H/E4ZE"O[*EB5
M2DX3<94\/*KB)\DJ4IT:-6DYNG4G2J;6H>)=2\`^)?A_\1M`M[Y?$/@_QCIL
MUGJ^F13M>Z9INH[K76;>2XLIX;ZSL=8A6#3A?Q0ZA!H.M2:%XMNM/9?#:7UA
M]/\`['W_``4%\6_\$I/B!X=^(-MI.I>,?``M/!/P;^*?A>R>TU^-='T3QI\1
MM>T&WTS2=>\2W\,&O^!/!NG>(-/B@O;JS\/ZWXHM-,\375AK6C6/AC4[;Y-\
M>^'YO$7AF_MK$$:U9QS:CH$R)`T\6K0VMQ"D4$L]Q9?93J=I<7FB7-U;ZAI=
MY#8:G=FSU73+DQ7UOXQ\9_%7CNYT:ZN?$>DZ2]R+SP9XM\2S?VS>73I)H-[X
M=TG2;G0-7N+2QOX/%\^I#Q!;QWFD3RKH/AR:ZOK>PTB+7%T:Q_DCZ3G#6;X7
MC#&<5K"8BCD5;(,JJ/-:<*LL'+,\/B99?_9V(KQH>SHXVM%X.I1H2CBJE7"T
MY5Z52E3I8KZK[W"E&&/K8++XU(JO6QCH2IR=*+E1K.FXQA*KB,.FZM6T*476
MH1EBOJT'[64XTI_TH:/_`,%3?VQ/^"@WB;X=?M<Q^"OCIX<\:?"_XB>-/VJ/
MV=_A5H_P^^*GCG]D?Q-X"^`'A2^\):9\(]`^']_-X/\`A]\8_$7AOQ]XMUK_
M`(7G^T?JFL:7\2O!WB+4+Z_^#?C#2O%D/[//[+6G?JO'\:_AW^U1XNUC]IOX
M=6]M'H_Q3L=$UZY+-!)JUMKNH:'IEQJFD:[!:^(?$VG:/X@\,(\/AK5M)TC4
MI;2SGL7MKB:YU6+5+R\_";]@.P_:&^!7[%OQM\2_#G]GKQEX`^"FL>%_$^O2
M?M!ZCX'\9>#=/U[P[I_PI^)6L:5JVD>,;C2HM`\76\>M:/IMGX`N_"&L"\U@
M?%5KC4-'\/\`AOQO\1/&WA3[T_X)I^(=)G_9SE^'MHUM%JWPF^(WQ&\,ZO80
MW]EJ36L'B#Q;JOC_`$/R+VUOI9]1TRTTGQ9!X=LM3U#2/#>I2W/AW4=-U;29
M];TG5=8U3X3Z*5/!4_%.M&CF&-Q3Q-+/\1B*./QF)Q#PN.GA,NQD,MPL,1*U
M##4L.X8VAA,+"&#IQBZM)2J>TG/T.+I8F.#PE*O@\/A'1P&#H4I4,)A\-+$T
M*6*QE-XK$3PON8G&5:BE1Q-?$.6)2H4J-5\T/:5OT'HHHK_3<_.3_-_\(_M-
M?%3PI9W&G2WUGXFMDG:&"7Q?#J>J76G%+R(W1CU,7&CZC=1S2ZC(-GB+5[I[
M.WAT^TBFT^.`1ZC[7X2_:&U#4K?QU\3+SPM"U[X?\)_#?0;[1;+5)+:TU*[N
M_$6K(VJQS2Z==:G8VIE\32&TTY[+66B6#R[34;[[7<W4/R/XW\!W7@36((8K
MW3]?\.7WGW7A?QGHTMO=:/K^GVVM0VTK6^I64\EJNH:7+BUUBW:^T^[TV^E:
MV.H3:;)I5SJ&G9:7>V7P<U#68[LHFM?$;0O#=WIJ!R@GTG1-:O(4U.S@F1I(
MY9+BVO%M9--N3+>Z1;W%P]\\Z06'^4F9\?\`B9D?U7A[,^),VI3R'.,GQN#P
MN:3H9E/"XW*L72S'*ZU"OC(XMU\-[M.>%=/$5\!B\%5HQC'$Y=4A"7Z[A\#E
MV(<\7AL%3D\3@\1"K+"*5"DZ&(2PV)C.-*$(1<57G*2G2I5%[&<8RHUXPY?O
MSX9_M,^!O']Q8:1?I-X3\2:A-!:VFGWTWV[2KZ\NWO\`[-8V&NQ6]O&+UH[.
M-/LVL66BRW=_=0V.BKJ^Z.>7LOC_`/!>77_A]H'C/2-.TC3]7NO$FHW&M7KZ
M0]SK.M^%=-CT'18M3M[[3);K4#%H%Q=ZWOTC^QIIM;CL#'+J-A<:9X5T[Q)^
M0Z(`!(S1HC;(F:X^T-(D)M&N+<2W`DMIA&]HSZ?-'%'!%=6RA]-MM0GC!A_H
M<_8<\):+\39?V<_A=XD>Z\.>#M)\//!XFT2[N-3LM+M7LO#%WXW^)\,-IIFM
M^%;CP1=^-;/P_`OC#Q@VK2^(M3U2335MK>Z\.>'/$_A]OKN*/&C/?$+@A<'<
M28?#5<?1S+"YB\\PF'E1Q.,P&%PN+IXG#5,%A\/+#4LQKSQ"I4\7@I8*A.G5
M6'EETX2K1Q'G83!U.&LRP^;9;6E3G[]-4_:1DJ<E5I5+I5).4Z$H))T\13Q$
M823?M9U(TYP^LOV(_P!HC2M+^&/PR^$VF^./B\/"OA"_TCP]XU^&WQB&NVXT
MRUU:]LX_$RI\/(H;7PWJT6FZ=>ZMX!TYT\/:I,NELT82]\11Z7KZ_IS_`,$I
MO#4%[XT_:*^`&N>,]1N-5T*70O%7AC49O"DF_P`0Q>&+71O!NO\`Q&O+_P#M
M:]2*R\?^&]0^&$^D:1-XCUZRUBTL(?&GA+5;6*Z\7:=J7YI_';X:+\#_`(V>
M(WTB:[?P?XP\::?9P3/%XDDT_2=:U"PT&_L=(;[1JU[%<N;+Q7J%A?RVC'2;
M.^O?A[,NA:)96UU)7T=IOQ8UK]EC]HGX$_M4>'[DVFE?$;PU>)XWTGPX4U[5
M]5TNPFL_`_Q'L8K"?QGIL=_KGB?0?%GA/2;B2\\2:IJ_C[XA06#^*M*\`SZ)
M)<7'Y-P?F&8<&XW#YMEV<8^CG.`Q&.Q.%Q=2=&H\-.I0KRI4*4L92JX;ZCB(
M4:.$J8>M.A*I#%8S+H1KX/$QCB=L[QL,^Q3J/`X3`*=+#4\3A\#1E2P]=TJ4
M%+%U%24^:=7FEBJ\:52K.-:G&KB8K$TN8_HGU7]E'XW:7JFI:8-!\+WPTZ_O
M+$7L/Q.^%]A#>"TN)+<745CKWC'1]<LXKCR_-CM-9TC2]5MU<0ZCIUC>)-;1
M%?L+X*MO@/XZ\&^$O&W@SPOX]U_P?XQ\,Z#XJ\*:]#IWQ/L8=;\->(=*M-7T
M+5XK&_FTV^LX]2TN\M;Q+6]T[3[NW680W%E:S(\$97[,_I5^(,&X3ED//%\L
MKU<+!\RLG>#RN3@[[Q<I.-VN9VN>'2R#`3ITYNAQ(W.$)-T^&L?4IMRBFW3J
M0Q,HS@[WC.,I1E&SC)IIO_'[\(^']!7]HSXH>"UT32%\'3^$[2:?PF--LAX:
MFFL+3X97]C++H0A_LN22ROM5U2]M'>U+6]WJ5_<PE)KRX>3W6WTS3=$_X)5?
MMWZIHNGV.D:G<_\`!0#X7_#>YU'2[2WL+ZX^':Z3XE\4KX"GN[2.*XE\%KXG
M\%>#?$8\+22-H8U[PEX9U<6/]H:#I5Q:%%?G_CA_R1W`_P#V<BO_`.O1S$^L
MX>_WS.O^R5C_`.LFS\;;UFBEC2)FC06=DP2,E%#76F6@N6VJ0-UP.)SC,PXD
M+"O[5_V+?#V@6'@;X5:W8Z'H]EK2:EI$Z:O::996VJ+/KD7P@T[6IEOX8$NU
MEUC3[FYL=4D$H?4+.XGM;LS02R(Q17Q6$_C_`/<AF/\`ZCUCAQW^\X7_`+&V
M!_\`3N6B_MT:CJ%W\$_B+<W=]>75SIOB2/3M.N+BYGFGL-/U/XJ?M#Z3J5C9
M2R.TEK9ZAI7A[0-,O;:!HX+O3]#T>SG22VTRRC@X#]MB^O=(_9!\(C2;RZTL
M6_QK^#R0#3KB6R$*2_LYP>+94B%L\7EK)XJO;SQ-(J;0_B"[N=98'4IY;ERB
MJJ_%C?\`L$PW_I^N>77_`(>6_P#8PQ7_`*@H_#&;POX9N)9;BX\.Z%///(\T
MTTVD:?++-+*Q>2661[=GDDD=F=W=BSL2S$DDT445\>]_FOS@?K^'_@4/^O5+
M_P!(I'__V0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W=O;'9E<FEN92YJ<&<`````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3$V-3<`,3`T,3<S-C,P,3$`,#(S-C8Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/_8_^``
M$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%
M`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!
M?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:
M)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`
M```````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A
M,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU
M-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_3SXU>-M7\1?'7X[
M?`[6--M-*N?$EWXA\#>`_%NJ_9-.M/#/B-?%/A[QA+<ZWK$L)&G>`O$[_#G1
M]9OM4CEO+O3;^&.9K.VAU752/QL_;+U3Q#\:[+X<?`^&RT?7['PUXE@^.>J:
MK9WJ2Z7!\*_!G@#QGIMQ?B\MA.]W=ZG?ZGX:T;39+>.;2]57Q`+^VU`V;B1?
MUJ_:J\'ZY\(M/^$_QE\/R0?$SX3^.9M82R^&^H7MO;^++6`C[;<^&M!\6WEE
M?ZK/?6FF23:1IGAOQ7J.I:;8PK-X?MUT&TLK":S_`!J^,'[05IX(T'X6?$_X
M:Z?:PZE-\3/!OP\MM+UZQT:XTOQ)^R]X_P##OQ(N=6^'7C2YO#J<?A[7[7Q'
MIOAWP_:Z[!=6]]H'B1;?0+K5A9"6R;_-_P`#O#M<)>-'A/G.?9=@\RR'"<88
M5<.YSPYCYXO#16/EC886>(HX_"9;CL)BJM6K3CCX5Z#HUY5L9+`5,7]7Q.(/
MU[/.-LOXO\(/$3(LCEBL#F-/A/$5,RR_.L!'#U:>(A2I8>MBL-7PU7&4:^$E
M1I4ZE.-%U)8:4*2Q;I.HJ<NS^#/Q6^$%D?%'CCQEJ%GX<\!?`/\`9U\":7KN
MKW._S8?&$^L^+]>U721I=JMQ+);32^+O#^GZ+%:)->:A>W5S!';+Y-N;CW/]
MA_\`X*4?$+X6?$BUDN/#'CG6=-\2>*OA[J+_``W_`.$8U+4?$-SX?\0>%_BB
M8;V(>1:VXAUB[M=`O=$N+2\U'2;P:=K(GU:S5(;F3^:'XH^/K?2?VFO&?A29
M]93X)>*OB_\`\)U>_"C59WAO=0L_"-O-'X"\-^(8Y)89[RUB_P"$EM]1U;3;
M^^ET59=+$!CN(]/D0_M)\/OVO/&WA>R\9?'#7]6MD_:,^))T'1_!>LZ#%+8W
M&DZ+X3FU6UT/3X-*>WA;Q!IF@:=J-LL.IZU920R3Q3:B]N[1>'$TK_91YEQ5
MGO$<^&\MR/`5.%\'A<5B,]X@S"NZ?+BZ^-<LOR;)\-&#EB\9C&ZF)Q6(J.E0
MRW"4J3Y,7B<32PK_`)$RK!93D7!.6YSFN>5/]8,=2I++LFP-*,Y_[)A,-'&Y
MIFLIIRH9?3O/"82E2G*MF&-A."]GA,//&4OZDX_VF_#WQ8\!^*_'^C^$;VZM
MGAU`Z)I*3Z5J>HZ3]DM+I1<:R(;M$L$O)D+Q*T:RE(9L&3"/7\UW[4O[0>J^
M'_BYIOC.+0]3L+_PUK^@^);)G2`VT=]INM6][`DJM/%$R32V9C\L)MV1M$K[
M/G;Z4^$?Q@C\)Z'IG@3P]<W.N:UXJ@@M=:N9!I6H1Z:]PTEO%Y^IV=O)&;N#
M[;)(]K%>W=KYJR11NT<;JWIG[4'[)1UOX`>,O$DFDQW7B!O"^HW]AJ$EM.KV
M&H6=C<30M%EC%?`2A711YJLS!0%"C;^M9!D^&R:CB:4^>$\3*-/!2E5O&3A!
MKX9II4XR?(Y<S<W[ZW1\MF^9XO,Z$71:=2BE4K:=4E)Q=DO?E%)J.JCI"]DV
M?#%Y:6_B2[NO$6F_$K5])T[7[F?6M/TJ;STETRRU65KZUT^5([^6-)+*">.V
M=(Y945HR$D=0&)7Y;VOQH\2Z=:VVGROJJ26$$-G(BR6^%>UC6!U'FPM+A6C(
M'FLTF!\[%LDE>Y_:-9:.O45K)KV$7:W+=7YM;>]_5CE7$."LN:BKV5[5L0E?
M2]DEIJM.VG;7]L/^"W7[8WC+6?A/^SUKOAV'P?I-U\0-:\(?$[09?!'A/4;2
M;4+[6K1M<\,P:-JT7B'Q$_B!+J:73XDOM1L_#>N33C%QX8TN>YDTVW_%+0/C
M+\6OA'^T7X9T+]L'PE-:_"CXR:KX1L_%_@KP5KL4&D)KGB.V@T_P/!XOTIH)
MK/4;3PWKNF6-_P#$G0M*U&SL;NW6[ENI-5O+'0-)GRO"OCZQ^(OAGPS\&?BI
MXP\1?\*KT#Q/>>*M!CL4GU77/AOXV%M?2:=XK\(6PU"RQ,^I21VM]HFJ2ZGX
M0GM=5O-8U#PSJFJ:;I-[9_4/[3OP8\.>+;(?MK^.-`NY?@QX#\&6.;RQL;W0
MO!/B/]H-K8>%/!GPBTW4[O5KZUU'Q!;ZEH?CCQK?67@?4(O"&E?#WPWX5UW3
M]+MM*\<Z<1_FI@'PWBN&Y\$9EA9Y3EN>TLRRK.,-D^2XW-LQQ6;YA6JUL@S?
M`9G&JJN3/"5Z=6MAL3["O/#YM]5I/'X*->A6Q7]<\8<"YMX6Y_5S&$99O*$L
M/FG#F?2QW]G8%Y;A9>PS#+<1A%14<;F4E*C1QV$IXNG"C@I_650QL9RAAOU\
M^`W[#'P7?Q9\4?$GQG^!/PS^)5GX>UG4+*RT3Q+X?LYO#_@>ZL-1\0"#P_X6
MO;KP[YI\'V]WJ`%O`+'2IK.RL-*L5L[V.!([?\*[O4+7]DG]I+6_AO\`M0?"
MJ'X9:U:KIVM:=J$'AGPE:?#'6=(FV2)K'@6\TDM;ZL+F.54&R&RNK2[M9;+7
MY-(O4BB;^A[P+^TK%K_P>U!=7\1Z9X<\1_&CX;?!S]H;P!''I\EYIGCG1_'F
MD:!XT\4IH%]$KVMQ<^'M2OK_`$G4-)B%Q=6FHV%[H<_V74+62T?XPM]=\8_M
M/>'8=4_:S\(_!'6_&B76I6/@KX;?#EM.\4Z?X3\,'[.^K:?XFURR5GUWQ/#<
M6<!\3:T%%LEP@A:7S(6DK^0_`OZ2GTF?#['<5Y'Q]FN4XW@/(JN%X8X=A6RW
M+(\:8&&+A.AEV<Y+F,Z,I8C+L)1P.85LPH<1X3'8BE1C@Y1Q-##K"/'_`-#8
MGZ-OA]QS2ROC&AE&/PD<0ZF?XC`T:V9SRS/5'"Y1B<3A,7AZ<L#&@ZV89F\)
MAZN68RCS58XJ=&G.I@\75PWZ1?\`!/3_`(*3_L;>$/$UK8:??^&Y-0\2ZGHE
M@=:F/A>YUD7=Q-/%8%+BYU1+NUCAEF9((M&1/(#2,+0R!%D_3/\`X*`?$O0K
M3X0>+?'FFA+[P1XI\/0S7<^BR0W-S8^*(X;N*'5M2'GK;1:;J]K::=IT=Q!.
M[P:U!`[PO-KDDQ_CT^//[!?[.V@>`)O%7PMT"_/CC5=1L]&\+ZI\&=*\7^*?
M!V@>*?$FJ6>B^#]0\6>.=/N+KX?^%;4^(+ZTMBYU:]NED%THCAO(@L?WY_P3
M\^//Q4\=_L_?'/\`8B_;$\3ZF/BEX?74HO#;ZHEA9:WJ?PTU&ULHXKJWMXK*
MW36'\)>(M.OYEO(H9;JTN5TF[N9@TQD?]IX4\7,X\/L?A>.I<:9QQWPW#-\/
MC>)<-Q6OK/%M'"XBMAJ.+Q.78[#5<13S/+Z5.<,/44ZF%_LO'3P$73GAYXF.
M&UX]\$LHXRP%1<.<&_ZG9A2P3PV'P.6\ZR*%>E3J/!PJX7$T,+CLMKU9TIUH
MRE1QF'S'"4\95IXUUX1C7^/;S0_A_J%W=7XLK&47MQ/=B66V@$DHN96F$D@0
M,@=]^YPC%0Q(4D8-%<[?_LD?M76%]>6%GX&U?5[2RN[BTM=6TZ]T]]/U2VMI
MGA@U&Q?S!OL[V)%N;5L#=!*AP,XHK_5*CXT>$%>E2K4_$_@B5.M3IU8.7%&6
M0DX5(PG%RA/%QG!N,KN,HQE%NSBFDC_/ZIX8<8PJ3A4X,S]5(3E":_L?&.TX
MR2DKK#M.TKJZ;3TU:;/QYLK"XTZ_M]1M5VJQ19X\;HKG*>4PD`7<KR,5E8AE
M"\,2N=E?MS\"O'X_;P_9;^$W_!/3Q+9Q^;\+/BWXC_:"ETR5;>RTKXK:!X/^
M%'B?PSX1\%1R6+)J2:_HEWJ>E0WMLT#)K?A;1D/]IM?*^GM^,5M`_P"\;<J0
MGRWCC+$,\@8@;2SGR]P&05*+C:CN5(6OJ+]F[X>?$C7?&5E?>`'UZPUJS,5_
MI^MZ3%?6T^FO%>VKI)9WELB&"YBE,;I<I+&8W3AB2BG_`#(XPS&.6Y1B\V_M
M:.2XO+\'BH8;-UB'A?JL:^&J49RG6NG^[57VM.?O2HUZ="O3_>T*?+_JQGF3
M\-\35,JRO,\%2QT<%F^#SO!8.M36,PRS+`U*<XK%X7VE%8O+L;&G[',,'*5.
M.(P]2<7)349+[D_8BU3X6V'Q%\;?##]J^71KGX,?!^'XPZUX3\&>.[35M1TO
MX>>(="AN[C6K7P#8:1I]YKGAK5O%LVK>"]9?0O"D>CVOBA+*:341.VC1,G3_
M`+(O[&OBGQ/X2\.-X,/Q*T'X,>*@=:\1>(O%D^A:'XD\?Z+>V9UG0[7P_P"%
MO#NN7&JZ+X7D,=WJ>KR6.LM-K%CJNBS1QB`6^J5]'?&__@FM\?/CW\/H_C)X
M*M=.\2?'&[TVVG^)6GSVMUI7BCXJ6>DZ$NF>%[C0_L45EX8M/%GAR*2^M+J:
MYM-,G\?:7J]U!XFU74=6T[3;MO$OV>/@1#\,/@-\3_ACI'BGXQ?$[]F36--\
M*W9^#GQ3U+4OAOX\_90\0V*:[JGQ)\"?&;_A#+GPI\2O$GA7Q_J4^GW7@OPW
MHRWNBZAHWAWQ#;ZCX.O?#_B==9UO^9UQ]P_XC\'9WG7`_&N$S#%4\URO+,]R
M6E+ZU6PE3+9U\OQ]3+L/BJ^&P5+-Z=7$QSC(5F>+RO+LUPT,3F#Q\<YP^&P=
M#Z/"9K/!<:2J9=E5/&8JI#%X>I.GBZ=3`\/XNM+#5,!]8P^&H1KK"9E!XG"X
M['T\)CL9];A@Z>'RBG36+J2^I-1\<Q_M4>)O@=X6_9WO=;T/]EO2OC+X?U"X
MUK3;[PQJ7A7XWZ]\(==T3Q1XLT[X?Z:VHWOBSPS\+=`ET#PKX\TW7M>T?PSK
M/BS78IO#WAG3%\/V'B9]-N?%OX%S0_M2_`3XM>#XO.U?0OB+HW@_XERQ@+?7
M?@7XL7=WX4N3/"-PDLK#4;E=5\HRHP>T21#+,Z(?/?A%\:VTKQ/XE\9:7#IN
MG:W?6%CH?AD7UAI<&MZ=H_V2];77LK#3;>TT&QU'Q'&ELTMIX>TN&ST#3[7[
M)I%W<WFL>*M5US]"/V<=,\+"U\8?$OQQK"2:AI>BR>*-0O[VZ0:8LGAG5=,U
M'0M/MU$MO:)+96[ZC=.D@WLLDD\SNT8,?S.!>-J9UE^`R_!X++,KRW#9M@L1
MEZ:KT,32SR%.GCWC<P6%P-3.,95P4JT*N8XG#X5NK&G0P>$P&`PF$PE#V\3*
MMPO#$0S;'5LRQ.98:%;&3DW*MC<;&KSX>.!P_P!9QCP6$RUK#V4:^(=;,%BL
M?BJ^+J8J=>KX1!\4[K3X8;"2%S)8Q1V<A5VVE[9!"Q7$>-I9"1CC&,<45\>Z
M=#%K6GV&L7?FI=:M96NI7**SHJ7%]`EU,JHL85%625@%4`*````,45YE:CP]
M3K5::@K0JS@O=AM&:2^WV2_'NCNH\.\73I4I2H6E*G3D[QJ:-Q@W?1;-OML]
MK*W\^19A"^&8?O;1>"1\KQ_.O^ZV3N'1LG.<FOZ5_P#@G]I&E1>#_#DL>F:?
M'*WA_1MTB65LDC;O[,#;G6(,=P9@<DYW-GJ<E%?I/TP_^33XW_K[4_(_-^!_
M^2DQ?_8)5_-G]3W[+=M;FWN";>$F*UT%(B8HR8T:VN\K'E?D4[5RJX!P,C@5
MYO\`&_P/X+_X2_\`:)C_`.$0\+^7XA^&177X_P"P-)V:XNF7>NMIJZPOV3;J
M8T]KV]:Q%Z)Q:&[NC;^6;B7>45_&GT1?^3,8/_LLN(?_`%(J'XSE7_)S.-?^
MP;(__5]DI_(1\.XHH/A_\5=0ACCAOX)X[>&^B18[R&W^S/\`N(KE`)HX>3^Z
M1PG)^6OJ5M2U%/V;_BLRW]ZK'P5?Y9;J=2=]AK^[)$@)W;$W9^]M7.=HP45_
M66,^.7_89EG_`*BX,_?,^_Y.)EO_`%XK?^G*1^+.K:[K:ZKJ:KK.JJJZA>*J
MKJ%V%51<R@``38``X`'`'`HHHK]&H_PJ7_7N'_I*/W![_-?G`__9````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]W;VUA;BYJ<&<`
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,S8W`#$P-#$W,S8S,#$Q`#`R
M,C<W,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_
MQ``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!
M`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<`
M`0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9
M&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/Q+_P""
ML_\`P5N^-_\`P4_^-*:Y+<>)?AW\#?"1U#0?A%\&="UFZ7[%I.J2,;O6O&_]
MDWL.F^)_B/XI:.'3_$%U:3W>AVL,=KI^@>=I-Y>7(^TO@M^S;^Q'^Q;\,O@Q
MJWQ>^%WAG]MGX]?$VVT#XE^,K'5K7Q!;?"CX,>`H%U'Q=XG^%/ASPS#/H$7B
M'X@:='X2\8Z)X\U_7UATZ7Q`D=AHFG6<\$MR/YK9KJ\L9+6ZL4FM)K>6*[MK
MI6GB\BY@=989EEAEMY4:*54<-%<02*5W1S1-AU_I(_X)3_L4?&#_`(+*>-?&
M)N_CE??!7P]\"=#G\7S^(=.L(/'.J:E\0?$VK0V5KH7B+0=6U/2K:71]<MK#
M5[C4M1?4KIM;TR'6+_REUEQ&0#[O^$W_``6&\+?"BUL/`W[-'[.'[/O[/OP^
ML+GPIK&MV'P_^&NDKXHTSPK_`,(S=ZQXVMEUBZM#>77B+Q3KHT^]M5.LW?\`
M94;P0.H2X4/<T3_@K%XQ_:,\#7UO\;_AK\$_C#'XA\3MJFH>%/B)\./!'C*R
MT3P3`UG=V6F:OJWB/3XI8+BX72X[G4M9EOK>XUG5A>0OY.C6=W<1_II^RQ_P
M0B_99_9Q^'K:9\;85^.7QIU#_A-]&\7:O%J>I:-\,X_#.LZA<V5AX;\/^')X
M=2U,0Z3H<D%[;WLMW#J>F:G&&TF1_*AKTS]LG_@EY\'?B1\!O$$7[._@?P?\
M./V@O"<UMXS\&:QI7AJVU#2O%VI^']'/AU-'\5:`TJ6^H6-[X?"6EN.+M-0M
M(;QX&FOUW@'XP_\`!1C_`((]?`']HO\`87UG_@H9^P[\-O!'P>^*'@&QUGQG
M\5?V=?A#XFG\:_#GQ5X3\+L+CQC/H.AS6$I\'?$7P9H#OXAO--\/S36>I1V*
MZ=98FDA#_P`>EA):7,,$\"HR30I,)(W$JE60NK#86#*R?,NW.]1QGG']_P#_
M`,$:OV@/&-E\=[3X"_&>S\.:=X4\76FK:+X?O?#>J6^J_#WQ#JNBVMWI]WX+
MU3PMJ3?:/#][-ICS[%DB>UD@MKK1[XO=%4'\8/[>/[,GBW]D7]J_XF>`=?\`
M#/\`PC/@7QYK>N?%7X'2JSW-GJOP7\8>,/$]WX'N;&\51:W$]H+230M52T>6
M/3+H1V-P8Y@(@`?(ANK($@SP9!(.4;/'KQ166\!+N?+?EF/$;$<D]#M/'IR:
M*`,`-L/^D,'@?"@,ZNJ@]V21)HV7'57BE1APT<BDH?ZF?^""7_!0KPM_P3I^
M#?Q*\6P>`;OXEW'Q@^/GA[P=\58(_"7C>WU;P9X5T#PRT?@"/2OBC9VFH?#Z
MZUW4K6_\4:S#X!8V&NZW)9RQ6<'FQM+%_+,V$@9`_"(Q,BEO,C`'WU\L-(&4
M?,I168$`J"<5_<E_P:S:%^S[X_\`V/OVT_"_Q/\`A_H?Q(\5_"SXPZ1\:[CP
MI>:4FL>(;CP[/\,Y-'\/ZAH>B7J^6;VQO_"VOV>EZI:K)=IJD*M;(]U<>4X!
M^J?_``4>_:5^)T7[.7P5^)_[(NI^(_$O@_XT3W?B'Q!XG\`VUEHWCG_A`-'M
MKFY?3H/$GB]K:S^%$L?B:TU#2/&WB"]>&ZT34="L[:-HK^\A@D\2_P""-'Q_
M_:B_:;\0?M%)XCG\=6'PQ\)>#?"]W\'_`!7\6_%MUXZETGXD^(9-9ATC2+77
M[CPSHNL^(AH&F6:7'C:VFO=0AT6[FM$1':>V63]6?@5^T+^RK\6GB^$_[-VF
M7&N?#'X7_#;2;ZQ\1Q^"-8TOPEX>?Q+?WMN_P\O;7QMIUGJ5UXPNF,6O>*+5
MXO(N+F\CU75A!>M:I/\`5_AZ.WTEK>QT^WTY+!I(C9Z=I-A;6MG,=ZP021:5
MI]K!;M.]N[RQ30M,VU6E3>JE@`?P!^%?'_QS^&7Q=^.FK?%33=:\!^,M'^.O
MC'1=9=(9=!>P\=Z3J^KV_C/QS\/YX8X[R3P:-:%Y<:7(L7V.XBUVWM5E8HBG
MZ9_X+`?#VP_:X_X)7?#O]K*V0ZS\4OV0?BSX9T;5]6LK6VG>R^!OQPM8_#6I
M:-J%WM%Q/I7AWXJZ)8ZCI-X_[FTL=9U&XA<99CP?_!9K]O'P7^T1_P`%*3^S
M_P#"'24F7]G'PKXC^#GB+6H_[.73/&_Q/B\56'C/QAH-F=-)6?3[6'[1IFG:
ME=-)>6_B!'AO'#1RI7UI^R-\/M8^/_[/7[5G[,/A2VO?%?@?]H_]CSXK6>A2
M27"K/HGB/1]&E\7?#[4]0LGWD:]#XI\/+H=QIR(NH68N[J18EF!%`'\26+A?
ME81AEX8&0@AAP01D8(.01C@T55BU[3[6*.UU6V6UU2VC2#4K6>18I[;4(5$=
MY!-'*5DCEAN%DCD215='5E<!@110!S[M<2*3$HPH)0Q@%BPY7=C/!..2,<]J
M_H7_`.#;?]HOQ;^S]_P45\/V-OK`T3P;\>/`NO\`[.NI7^L&27PE:?%/Q?HW
M_"3_``*&M&.YLHIS>^-?#;V4:K>V]Z^G:_?M9ON=FK^?V$F"%@P\R4RO:0VS
M)*LES?(`HT]$A5KA[MY"L/V>W1[K<ZK'&9&13^U'CWX`:]\)/A!^SW\#K5HO
MA9\2?#?A9/CSXM^(>B_:%\6:Q^T/K]_I?BGPAILMSI\D36=WX:\&7G@[0-$\
M/6MQ%#X;OK/5-4@==0>9``?UI?L=?$C_`(*/?\-,Q_#KXQ^+_#_C+PQJ>J^*
M)/B=X?\`%W[/7C/X=1>!)O#EUJMK+XF\'>/4\*>&O#GV3Q%]KN;7PIH]S<ZY
MIFNR7%M'=ZMY%O+,OMO_``4H_P""GGA/]C;2;;X+?"J]L/B5^VK\9K6XTGX.
M?!K0+N&]O/!5YK*R:='\6/BQL>5?"'ACP<9!J5K9W,=M_:PLIK6S:20D#\)?
M#W_!1G_@L_\`M$_L[?%WP$WQK^%>AZI^SCXA^%7PZ\6?%SP[-9^"?CQX_P##
M/Q=DL=/\`^--"2UBU.&_U?4K>.XU'Q!KF@1^%[NR$""&YGU"5)#^=O[%_@3X
M?Z#\8?$.G?%;XB^)]!\1^);^YU/6/B-I/B8>'O&?B+Q6;PO<R:SXI.C:UXFO
MIIKRUO9D1M7A60S[EB`8&@#\Z_A%HOB/1?V@?'\FHZHVL^+_``OXN\;V/B;Q
MAJMRHUC4/B'X?U^+5IO$E^ETWVEX-=U'^U+<2.,7D>LP6L;.T2+7]'?_``39
M_:,\-_!W]J70/&5GJ&I:+\/-7^*5F]_IM[<K?:;X?M_'T]A-/"!"X6QT/5]1
MC\4:C:?:C':VUQ!#IR,'D\NOR\_X*(?L\^!_V./VNH/$WP1LKO6?V??VE_"G
MA;QI\)/%]CXCN/%EO>>-[.WTS3?C=X1\2>+IA(+;Q/H/CFSU?Q%XEM[QX[QK
M^?2K@0163`M]W_\`!.[]C#XP_M->--2L?`5UHG@[X:^%+8V'QP^.'B)[C5?A
MYH?AQ?(UOPWH'@JVTR1%\;?&7P;JFFSW*>%K74(_#VBPVUO?ZI>VD&HR/0!\
M]?M/?\&VW[7WB3]I7]H;Q%X$LXE\#Z]\<OBUK7@U;;3;PVZ^%-4\?>(+[PZ(
M/*@,9A&D3V8B\LE-FW82N**_KOT[X]?LX^$-/L/"6I?\%A?BPFH^%[*U\.WZ
M7?Q/_9$M;I+W1((]-NEN;6]^$=]>6UPL]M()K>[O;RYAD#1SW5Q*KS.4`?R.
M_P#!K[\/?`/Q!_:F_:WN/'O@?P?XWN/`_P`!-9U/P5/XO\,Z+XEF\'ZE;^'8
M[N#4/"\NLV5Z_A^^@NXTNH;O26M)X[A$F219%##WCX[6MM<?MA?`B.XMX)TO
M?BW\<+F\2:*.5+NXTWPLQTZXN5=6$\U@;>`V4LH>2U,$)@:/RDVE%`'E_P"S
MJS+\3?\`@IJBLRI8V?[,-M8JI(6SM[#Q%'<V-O:J"!;PV5Q%%/:10A([::-)
M851T5A\`_'5FL/BU\07L&-D\GC_QOYCVA-L[_P!FZH5T[>T.PM]@5F6RW$_9
M0S"#RP3DHH`_H:^&GA7POXG_`&8OV5/`'B7PWH/B'P)J'[3_`.RWIM_X*US1
M]/U;PE>Z=K.L>)[C6+"[\-W]O<:-<V6JW$,,^I6LUD\%]-%'+=1RNBL/VA_X
M+6._PJ_88^.&B?"]V^&^BZ5\$/&E]I>D>`F/@_2]-O4>VC2\L-/\/'3K2SND
MCEEC2XMX8YE221`X5V!**`.A_9,_94_9>U?]E;]F?5M6_9N^`FJ:KJG[/WP:
MU'4M3U'X/?#R]U#4=0O?ASX;N;R^OKRY\.RW-W>7=S+)<75S<223SSR/+*[R
M.S$HHH`__]D`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]W;V]D:64N:G!G````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P
M-3`P`#$P-#$W,S8S,#$Q`#`R,S$Q-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,`
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_`
M`!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&
M!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4
M,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)
M2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R
M\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U
M$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)
M(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA9
M6F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JR
ML[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_
MV@`,`P$``A$#$0`_`/[?OVCOVB/!O[,OPXE^(?B_P]\1_&\]WJD7AOP=\./@
M]X$UOXE_%3XE>,KO3=5U?3O!?@'P9H437&K:_?Z;H>KWRO?76E:)I]AIM]J6
MMZSI>F6ES>1?DI\;OV_?"GQ`T*P_:Q^'?P8^-?@SXE_\$R_CGI%_^V9\`OC9
M\,9/"7Q]\#?LB?&OP-XH\,_%'QWH/A.QUW7-)\6^'$\-0:7\?O!NN>`O$GB`
M^-;7X#ZSX<T6>ZN9=4T&^_=^6VMYY+:6>WAFELYFN;.26*.22UN&M[BS:XMG
M=2T$S6EU=6K2Q%)#;W-Q`6,4TBM_-5\5OC!\.?VI?^"FOB+XF?LZ:IJ&K?#/
M]G/]GCQ9^SE\=/BEX;MK^S^&WQK^.>N?%?P[K_A[X>Z5KK6D6A_$^[_9?T?P
M1XXCUWQ#HL^K6?A'Q!\:?^$4T[6X+M/%VDO^+_2"\7<M\"O";B_Q0S3#X7,*
M?#>`A5R_)L5F,<J_MK.Z^(IT,FRJAC%A\75A5QN/J4:=14L'BYPP\:N(]E&E
M0KS/I^#>&ZW%O$679!0G*C+'U)QJ8E4W6CA,/3I3JXG%3I>THJHJ-"$Y0@ZU
M%3J^SASMR4)?7'[8_P"V7^S1K>H?\$ZOVB?AW^UK\";[X1>!OVWO"-]X_P#&
M6D_'#PY;^!1X%^+O[-'[1?POTZ^\2>(=-\5Q>$[*Q_M?X@^'+NV7QI!/93M,
MEK82:9K-U8WB?7WPL_X*`?!3]HKXFQ^!?V5;77OVI_!.E-:I\0OVC?@?J?@#
MQ-^S1\/KR\M[:XA\.S?&"\\;:7X?^(/C:U@U+2M0UWP7\)/^$^USPQI-S/-X
MC@TO58;;1;_\F_$O[,O[.OC#X;:U\'/$?P-^%&I_"GQ'J\7B#7?AV_@/PU;^
M#]5U^"ZL[V+7;S0;/3K?3Y=:2[T^QG&K&`:AOM(";@B-0/I?X%>`OVA-(^&E
MS^S5^Q%\0_@/^R=X2\%Z"_B/P/)JW[/MY\5M*T>[DU+4!K7AG2_!.E?$WX6>
M&?#GA_6=9U72-?U+58$UG5[W4KKQ7=/:+J>KKJR?Q!]&W]I1DOCCXF9-X89Q
MP'B>%\UXJS?.:619CAL?AZ^7QPF!RAYCEV&QWUBI*M7SC,)X+%8"JJ-&AA:<
M5A*E*M*525*A^I\;^".-X4R+$YYA\UCF.'P%#"RQ-#V4X5?:U:SI8O$P2BH4
ML+2BZ,HP<JM63E/GG:G'VG[945\2?LE?&G]J[QGJWQ`^$W[7G[-@^%WQ,^%P
ML+@_&KX7:Q8:]^RQ\<M"U[4M8M?#VL?"2[U_Q#_PM;0/$ZV6C3WOCCX<>+_"
M]X/`2W.C+)X]\0MK]@B_;=?ZB0FIJZNFG:47;FA*R;C))M7LTTTW&46I1<H2
MC)_@KT"BBBK`_E,^(W[5'[37_!4KXS?M!>!?!?Q%\;?LQ?\`!-_X)_%/XA?L
M\N_PJU&#PG\>OVS_`!K\-O$-UX1^)6K7GQ8TJ_U#Q#\+_P!GVUUW1[S2=`M/
MAO/X4\;^/](U'5+/Q/KNEA+K0]+W?'G[+8T;X&?"SX0_LI>(5_9NB^!WC[X9
M^,OASIOA:75['P3>Z-X,\51:CXK^'GC_`$G2;VVU/Q=X,^(WAG4/%6F>*+2]
MU)KW4_$.KVOBO4KR^U2RD>Y^@?&?_!+[]MKX'_%'XJW/["'Q8_9DU/X"?&KX
MM^*OC5=_#G]JW3OBPOBCX)^./BKXDU+Q=\74^'OBOX7)>CX@>"-=\6ZAJ/BS
MP[X.\86WAK5M"U'Q#J>F?\)Y/I-A8Q3\;?\`["__``6ZT?5+F\T;XY?\$PO'
MNG7=N%31]>^%W[4'PQCTBZ"R8FL;[2?'/Q1N[VWW+%YUMJ#&2?SG:&ZLA;+'
M=_XL_2C^C3].CQI\7\[XGPN*X6QWA_PKQ`\7X8\,XCB;+WD/]E4F\/A*V)X9
MQF&K8?&9SBL)6KPSZOQ!A[UOK&.P6%K/)GA<.OZ=X%XX\*.&^&<'@*U/,:&<
MYA@XTLZS&EERCCZ>(52G.3IX_"R52GAJ&(BJ^`5"4JRAAZ5>O3^M.*GU,OQ:
M^'D/Q;LO@3+XDA3XKZE\.=4^+5CX1:PU;S[GX>:+XFTCP=JOB2/5/L']AF&Q
M\2:_HVF3V!U,:L'U"WN%L&LRUPO5?LW>#_&7Q:^/.@?M4?L;?%+X3ZYXA^#'
MC[XB?L=_M=_#'XDZQX[T.S?X?Q0:9XMNX;+3-+\.:]=Z9\6O`'CY/"WBOP%<
M7FA>']#\=_#_`,0^)8(_'$WAWQ1X>U>R_(J]\(?MV_LP>(?VBO@U^T-X;\)_
M$W]O#Q)\/_!'[0?A?XJ_LV_$F:ZT+XT?LRZ-\<X=!U_X&_"JQ^+?@^74_@#X
MS\,Z'J'B_P`)^'89_AWJGP^L?%7CNP^)&I^*KW6VUG6V^TO!'_!2K]I_XM?M
M_P#[+W[/O[/V@_"7X7_#3Q1\:9'_`&E)O"/P-U*XT;QCH7A7P7XA;5_@+X._
M:*\5ZP-'^.OQ(^&_A[1I/%7Q*\6_"CX8^%/#7P]T?PNVB:I\0;'Q&]A\-_%?
MQWT-/HX\.>"GTE)R\4>(*^6\>\&UZ/"O#O"."Q&-S6IG/$F></X#%8KC3&/)
MLFGE^7^'M;!<0T,#P?+/,SI9AFF?X:I4Q."PV9X6&3X;T?$SCC'<4\$P61X*
MGB,FS-O,,=F%>C0P]/"X/"XNM[')^?$XYU)Y[">#5?'1P5&4?J\Y+!U)TJ=7
M$3_=K]IK]O?]C_\`8VU/PIHO[37QW\(?"/5O&^EZ[K7A?3]?AUV]NM3TKP[)
M90:G>F+0-(U=K&%KO4+33]+_`+1%HVO:I(^EZ$NI:C!<6L7A/[`W_!0K3?VL
M8_BAX?\`B;X?L?@9\4M`^)6MZC\-?A3XTU>RTGXA>-_V9/&MU:ZU^S[\7)O#
MES,CQ:AXG\/:HOA;QIX?TF?5Y?`_Q+\->(_!6N7*:U9!;C\X/VLOC58Z;^WQ
M^V)\1EM=9\?6?PA^#G[)'[+O@'PAX,C;7]8\4?'C7-3^+OQ5U'X.>%-+TJ&X
MN+CXE^,)/CG\$+2^L;R*5-(T[4_"VK:G<Z3HD>K75O\`1WPJ_P""2/Q-UOX]
M_!OX[?MG?M2:%\>_#OP=U#PS\7O!'[-?@[X#^%OA]\/OA]^TYX=NM.U30/'>
MA_%MM:U/XL^,?`WPZU."YO?!/@_Q-_9\FK>([7P_XQ\9WNJ2:'IOARR_TPR+
MQA\6>,O'_C7P_P"%/#SABIX5^%F:Y;P_QIX@9OQ3FF$QV;9KG_#>2\0PP7"6
M68;(,5@J^:<*?79X?B#+\;BG2K_6L(HYEE$IT_KGX;B^&^'\MX2RW-\PSO&1
MX@SS#5,9EF1X;+Z-6GA\-A\=B\)[?,L3/&4ITZ.8PI4ZN#G2I.=)4JS='%*H
MEA_W$HHHK^ISX,*\R^,_AKXD>,OA3X_\*_"#XE#X._$[Q!X8U/2_!'Q2_P"$
M6T+QM)X$U^[A,=EXDM_"WBBVOO#6L7FG,6ELK?Q!IFLZ+'=^1<ZIH6NV4,^D
M7OIM%)JZ:=[--.S:>NFC333[---;II@?Q/\`P7_92_;._8U_;LTKXU?\%"]0
M^'^L:Q^UK\&+KX2_#WXL>$]9\-^([ZZ^,>E>.M5\<:A\+?B[XWM_"'@OQ9XG
M^(WBGX<^%-%\3>&->URTUGP/"NAWWPU\`Z]I,5AX:\&/[=_P4)^''AS2/A-\
M2/VC?#WQ(^(_P*^/'@GX6:UX2^&/QT^''Q@^(_PDO_AF^H'7=2&H:K??#?5;
M/5M2^'3>)-0TKQK\7?":Z?J^D>.=,^'OA>?QAIMQIG@NQU'1OZF/C=\!_@[^
MTE\.M9^$OQV^'7ACXH?#O7GM9]1\+^*K!;VS%]I\PN=-U;3KA&AO]&UW2KD+
M=:1KVC7=AK.DW2K<Z=?6TX$@_GI_X*,?L$_\$RO^"<W_``3C_:3UG_A3G@_4
M+KXO>*_"NBV?Q(_:4\7:]\;?%?AWX@^+KK2=`L_$GA[XG_'#Q#XI\3^!=2\.
M:#I6J>(]`N/#&NZ1>-XIT^QFAF-_):SV_P#FUXQ?09Q6;^.&5_2"X#\6\Z\.
MX9!EF6XO.\IRW*,5F&;8B7#CJXG%0RC-,'G>5U84\_P=&%#,*.)P^.JU\?7Q
MF)Q$<PACJV'7[7P[XK_5^%,7P=FW#F$SUXV6/I83&8G%T:%'"QQU)1H>VP]7
M!UJ;67U[5J5=XBA&G1I45-QE0=6?XE_L/6_B7P+_`,%-O^">'Q(T'XQZ'\;_
M``KXC_:=_:L\/?$+P_IOP]\=^&/@/\,_$>N>&/A9X%M/&GABQ^)DD/Q&\:?&
MKQO?_M&VNI:E^U1\3]0U'XB^//%/B4^&KR[UO2/$*K-_:Y^U3XP_;"^&6J?#
MWXE?LW?#'PE^T%\//#D'BBV^-_[/XU?3_!7QF\7Z9?\`]BW&@>*O@EXY\4:M
MI_@"7Q;X073M9C7X?^-KCPWHOC:+6WL&\8Z'?KINIZ5_&'^Q#XIN?VH?VV_V
M-_#7@4V?C6_^)G@D?M=_'3_A&[F]^*FE>$OB%\4_VZ_@O\2[V;Q1XJTK1+SP
MM;:3X'_9_P#V2F\#^%M/\9Z3X,\+Z9=6W@RTM-&U_4[[2$O_`/0$K]\^B/C.
M+,9X7XW!\68+%83%9;Q3Q'A</B\;0PV'QN9^TSC&XRMCL17RO+\FP68+VN(C
M0IYCAL)0JYE0H0QN.E4QN*Q-2?R'B#2P%/.J%3`U*<O;9;@'7HT_:?N:M+#4
MJ$N>%>4ZM"5:5.=986:4<-"<*>'4L(L/*7YGO_P5"^'4#M#>?LM_M^6-Y"S1
M75E<?LA_$=Y[.YC)2>UG>U6YM6FMY0T4C6UQ/`SHQAFEC*NQ7Z845_57X_UY
M'PC=VVDDFVTE>ROT5VW9;*[;[MO4****!!7C'[0?PW^'?Q3^#_COPO\`$[P%
MX+^(_AD>&=?U,>'?'GA;0_%^A#4K+0M36SU`:1X@L=1T\7UH)YA;7?V?SX!-
M*(I$$CY**QQ'^[U_^O-7_P!(D..Z]5^9\M?\$P/A/\+/A_\`L6?LTZOX#^&G
MP_\`!.K:O\#/`>FZKJGA'P;X<\-ZCJ>G6%M/=6-AJ%[HVFV5S>V5E<WMY<6E
MK<RRP6T]W<RPQI)/*S_H9116P@HHHH`__]D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+WAE
M;F$N9VEF````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-S0`,3`T,3<S
M-C,P,3$`,#(R-38Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``
M,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`
MF<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S
M`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS
M9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S
M_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF
M,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!F
MS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9
M`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9
MF3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9
M_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,
M9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,
MS,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_
M,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_
MF<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````A^00!``#8`"P`````(``@```(
M_@"Q"1Q(4""`@P@/%ES(D&#"AP@;2C28<`6`%1@33F3X$*-'CQ$W.JSX\:-"
MD10M7C29,2,`E-@.JE0)4:-(F36='-3Y\.9%A"1VYG'BA-30H"<G/D1Z\)G3
M9Z1Z;ORYDP11G7F>Y0%@%>G4GSJ[!B7ZC"O7K3X/;ATZU,E0K631?A6:A]13
M4DZ>0I6K%*A;4G;WV@6,]^57BU;SU+7[UZG1I`T1(G:K&+#>O9`YKN1*0G'=
M/$]"9RUL6*),E8D7>W:LTV)?ER0Z+[Z\]>=KBRNZ5M9+VK7IS;FO-H;*T_;O
MEE8I"R].M71!R0=3?U8,?69FG#0I+WZ,'<`3`'6=6N.,#H"R9:B207X/3[$Y
MB?7GG=9>B1A^RH3OR\=WRA-D_KHQU13;=_MIE5Y]`$35'$)7Z7?9,\5E1`TU
MZ25$E!]^4(/54UD9")T3&>:$X8@4%B68AZ<!$&)````[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VUI;64O````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,@`P,C`T,C4`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]A=61I;RYP;F<`
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S<R`#$P-#$W,S8S,#$R
M`#`R,C(S,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````84$Q4
M10```+V]`(2$A/__`,;&QO___P```````(ZE7?$````(=%).4_________\`
MWH.]60````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```!G241!
M5!@9!<&Q#<,@%$71!\)R&P5E`5*\-@T3V$R`_A[@YJZ?<P2L$Q#PSH!@_VY`
M4-LP%KN7\(-VG25L]!E=85"]9CD,JJ/GPZTI?:?"H)5Z"8-8M82-(+7P@V"]
M;F,!*0,"U@G\`<FQ)<?GX)S1`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VUI;64O8FEN87)Y+G!N9P``````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#4U,P`Q,#0Q-S,V,S`Q,@`P,C(T,3<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3````8%!,5$4````P,#!"0D)8
M6%AN;FYP<'"\GG.\HGN,B8:9F9F]J(>\K92^MJ^\M['`KY'"LYK#NJ?&P;;E
MS*?IU;C.SL[>WM[MW<?NX,GHXMGQY];JZNKT[>+W\NO]_?T```````!_+KH/
M````'W123E/_______________________________________\`S1EV$```
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```!Y241!5"A33<KA
M%H(@#(9AC6^FF">-#(FM^[_,9J<![^''>+;NHSE+Y^X'^]GB)E=`M#=$I0#I
M>\K4&Q!$1L*E@"C(OHS-!83YN-4+C7.:&V#F=#1`NJ=8@9@2X>4-&)E21*B0
MH7_@:I!3C"&$Q_"';5O7^^S]8-#7OG6*$JF5@9WQ`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M:6UE+V-O;7!R97-S960N<&YG````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(S,S0`,3`T,3<S-C,P,3(`,#(S,C<V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```P!03%1%``0```4```0'``0+``(.#!(@"@P9
MLTTV@"\<=CHO"```3U9@;8.86'^>?K#3<:W2B\SL4Y2J`#0]S2T)_Z6$_[.>
M_\"Q6A0,*P``&0``"P```003``@?``PK`!$N%6!SDMW@`"83TQH(OQ0#RS@N
MK2T@BA8`MT8DG"@`H3,`:Q,`D%@W5TD^]/__``H,J-')``X`QQL1_]#*_[ZY
M_]+&_^/#_\*'_\%J_[-2_]!V]*1='0``\_3F#2`>J+VXH24=_^#:_^7B_^#1
M__G/_^.:^K9'_\1%_[U(ZK]C#0H`\O_Z``<.M,/*"@``I#,C_]?(_^[D__':
M]NBW[MJ$^\M/_\8[]L!"[<]O``<`X/GV``<?M[[;%``(IQX`_^#!_^G0_^_,
M[,F/YKYF_\%%_[@S_;I%X;=E$0P`[OW_```SLK/L$@`>J2P`_]RP_KJ5],69
M],Z-^\UU_[Q%_]%2_]!CJ7TT!@$`W.[_`!)`M,'V"P`GAS8`__&]_^&S[M*@
MW,!_]-!Z_\9;\:\_OX4BT*]HS.[M`!<FH=+A``D,>4`5)```%0``#0``&@X`
M$0$`/1H`&P``"P(``!`$``T,'U57D\C"'4<Q``0,1%);7&YX:7Z/B:6[D[C3
MB++(BJ^W`!X4``<C``\R``@R``@S``@I`!,E``HF<I.R``D'%#M"`!8F1F^%
M``@C+4YO``4I1V2,+E)@``PB'E9O`!`K0W:1``XF+$M@``4;````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````F1/3'P```0!T4DY3________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________`%/W!R4````!8DM'1/^E!_+%````
M"7!(67,```!(````2`!&R6L^````:4E$050HSV/\SP`"C!#P$\CZS\'(^(T;
M*L#XEH%1F!$%W&/A1Q5@0!,XS,#"AR+@PT!("WZ!VA:P`,30M2&,C!/!*AC!
M3I\!4Y4`%6!8".3\9V*,8H`)@,!RQ@@&A,!*J)X`%J@T!\Q:`"+`$[4PPS%Y
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O9&5B+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R,@`Q,#0Q-S,V,S`Q
M,@`P,C$V-34`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````P%!,
M5$4````P,#!"0D)86%AL;&QP<'":``"N``"V``&Z*BJY*3*[6EG```#*.3G"
M7UK%967:>7B\GG.\HGN,B8:9F9F]J(>\K92[M*V\M['+DH7"DI+`KY'"LYK#
MN*/<JJ?@L*_DM+3&P;CES*?HU;?+RLG4SL;9T,/=W=WLW,3FWM3NX,GIXM?Q
MY=3JZ>GS[>+V\>S\_/P`````````````````````````````````````````
M``````````````````"ES>*7````,G123E/_________________________
M________________________________________``U0F.\````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````K4E$0508TT7.Z1*"(!B%8>U+
M(\5M7,MR2<<-$+S_FXLEI_<7/'-FP#ID<";/EH9954$&)S`A8XZ0HL$-,(JY
M<$:1V0I<[/D^\MK4N5XT8'=D;`X\QJI4`;J!"**VQ2,GI0)\0!#-K,,]HX5>
M'!`^N8C11$GQ6W1>&^-RI9M9N"`:WR\GNBRY>04$)RN1]\$`NN]\IW09AH\!
M^=-FH]L@(3$`??AXO^HZ3TZP_WT!9%8<21%\580`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O96YC
M<GEP=&EO;BYP;F<`````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,P-@`Q,#0Q
M-S,V,S`Q,@`P,C,S,C(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M```!#E!,5$4````$`P(%!`,("`@)"0D+"P<3$0X:$PL6%A8<'!P@'1P>'AXO
M*2$K*RLM+2TN+BXX.#A-34V!6BMR<G*J;RND<39Z>GJL<2ZM<S*@=T2C>TN$
MA(2D?DZH@4RT?CZG@E*G@E.X@#ZJA%6KAUBLAUBZA$*KB%BZAD>\AT:\B$FZ
MB4NOC5ZMC62\BDRPC5^]C$ZED7:^C5";EY3&EEW'FV2HHY[*GVBJJJK+I''.
MI'#-IF[-IG;0IG3,IWO0J'3/JWRQL;'/K'O-K(/.K8/4K'G5KG[2LHG5LH38
MM8R\O+R^OK[6NI3`P,#!P,#"PL+:OIK@PI[APIS@Q*#?Q*/AQ*#BQ:'CQJ+2
MTM+;V]L```![0$@>`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9
M<P``"Q,```L3`0":G!@````'=$E-10?4#!02+`1^#@'Y````C'1%6'1#;VUM
M96YT`$UE;G4M<VEZ960@:6-O;@H]/3T]/3T]/3T]"@HH8RD@,C`P,R!*86MU
M8B`G:FEM;6%C)R!3=&5I;F5R+"`*:'1T<#HO+VII;6UA8RYM=7-I8VAA;&PN
M8WH*"F-R96%T960@=VET:"!T:&4@1TE-4"P*:'1T<#HO+W=W=RYG:6UP+F]R
M9V>*QT<```"9241!5'C:8V#`#B*!`(G++18>$>$IS`P7D/82X.04=)"&\?G\
M6$`4OSE,%Z\/F,7A"Q-@,^)B961DXC%EA]I@$!0<[._O[VTM!%$2&>IAIB(O
MKR"E*0X5"'/5<[>W=[30$($*A-B8*,G(R$BJPE0$6NJX.3DYVRI*0`4"7*RT
ME9759#7DH`)VQH:&6EKZNNJBD0B?00`V?P,``.(=%XJG_UT`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI
M;64O:'1M;"YP;F<`````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(T
M-P`Q,#0Q-S,V,S`Q,@`P,C(Q,#$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`
MZ0``=3```.I@```ZF```%V^27\5&```#`%!,5$4```#____JZNLS3VTU46](
M87Q6;89T@I%ZAY6*E)^XP,G`Q\\Q3FPU46X[5G(^6'-"77A#77A$77='7WA0
M:(!7;H9>=(MD>8^=JK>/F*&ZPLJ]Q<W*T-;0U=I\B).,EI_&S=/8W-_>X>/L
M[>U+2TG^_O[]_?W[^_OQ\?'N[N[M[>WL[.SKZ^OJZNKHZ.CFYN;EY>7DY.3C
MX^/@X.#%Q<7$Q,3#P\/"PL+!P<'`P,"_O[^^OKZ]O;V\O+R[N[NXN+BVMK:U
MM;6TM+2SL[.RLK*QL;&HJ*B@H*",C(R*BHJ%A85V=G9L;&Q=75U45%134U-`
M0$`G)R<F)B8='1T7%Q<6%A;___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!),<WO````5W123E/_
M____________________________________________________________
M_____________________________________________________P"^8S7C
M````"7!(67,```L2```+$@'2W7[\````KDE$050HST70U1:"0!2%X5EVC-W8
M+1:(K0-*V(B*ROL_B@C'Y7_YW>V-#`/],KXA`S6M6N,%^D$GF'*YL[/V'@%4
M8E2]Z"E=KG=D0\:?"^-"\MQX`^`:SN,JIND)0+KLBX>P=].;VM"BH@$';=:?
M`73+"6=D*XJ#!4!_""T!Q)>D'35)EU<`#T91%95AGFL`65=NI]M.WQ$`AF79
MT8CC.,&&.2&$YP6S@P7_^=8!'PK-+=,D-RAA`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]I8V%L96YD87(N<&YG````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S(S`#$P-#$W,S8S,#$R`#`R,S`U-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,```#`4$Q410```!86%BLK
M*R\O+T-#0U5556AH:'5U=7Y]>']]>)-".*=%/H!_>=1-08*!?(.!?(6$?^>>
M/(J*BI&0B9*0BIR:E)V;E:">F*.@FJ6DG:>GIZRIHZZMI;2QJK2QJ[:VML#`
MP,K*RL_/S]C5S=G6SM75U=[;U>#?U^+AV^7CW^;EX/___[V]O0``````````
M````````````````````````````````````````````````````````````
M`````+9I(J\````M=%).4_______________________________________
M____________________`*7O"_T````!8DM'1#\^8S!U````"7!(67,```!(
M````2`!&R6L^````<TE$0508TV/000,,Y`@P(`.0`*.4$#L;*RL+"PLS$UB`
M05M;45M;05M;7EL9(J`DPRDC(R`#)$6@*M3%M30EE97%E&4@`JIR?')RO-S<
MW'(P%1IB:LK<@H)<*"JXN;BX8"J4Y7AD9/B`ADI+,&!U&"&_``#DAQXB-H^Q
MR`````!)14Y$KD)@@@``````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VUI;64O:6UA9V4N<&YG````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#0S-``Q,#0Q-S,V,S`Q,@`P,C(R,3,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0!`,```#MW>)2````,%!,5$6$A(3____&QL;_``"$``````"$
MA```_P``A``````````````````````````````"80_+````$'123E/_____
M______________\`X"-=&0````%B2T=$#QBZ`-D````)<$A9<P```$@```!(
M`$;):SX```!I241!5`C7-<W!"8`P#`70Z@*:2!W`@PNT>TC5H#>ET!FZ@EO'
M).(_/?X/Q#D-,[L&`+#[T7,T>-H$XSP7#(MKD*@,46[&HY:P"/"H]WYI<T[M
MJL#T$%J3H!@PYP^>Z)M`?PC:22,@R\4OQ/XE#[E,VE8`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M
M:6UE+VUA:6PN<&YG````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R
M-C(`,3`T,3<S-C,P,3(`,#(R,#4T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``
M@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%DY./2TM)^_OXI:6C]_?U
M^OKYP,"_C8R&O+NW^?CTMK2NW-K4V]G3VMC2D9"-^_KW^OGVZ>?BXM_8D(V'
MW=K4VM?1^??S^/;R]_7Q\O#LDY*0W=G2W=K5Z>;AX]_9C8N(^OCU]_7RZ^GF
M]_7S[^WKEY22LK&QH:"@_____O[^_?W]^_O[^OKZ\?'Q[>WMZ^OKZNKJZ.CH
MYN;FY>7EY.3DX^/CXN+BX.#@S\_/RLK*Q,3$P\/#P<'!OKZ^O;V]O+R\N[N[
MK:VMJ*BHHZ.CH*"@GY^?GIZ>G9V=G)R<FYN;FIJ:A86%=G9V:VMK75U=0$!`
M'AX>%A86`0$!````____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````N+5Q&````%5T4DY3
M____________________________________________________________
M____________________________________________________`+"A!\\`
M```)<$A9<P``"Q,```L3`0":G!@```"[241!5"A31<[70L(P&$#A&F9M92_9
M(P(M5H&FLI<MM"*B)'G_9^$/4CB7W]61.+O$_22F:9H^FM\$P+;M6>_3%P##
M,#:'XR^C]`J.L_WX?C@QW!0"\/8.]<<,XP@5H.]<U_6\*0!^I`(&(G,A`/]0
M`.]K;Q*R%!`+"A@28EG6&J`8R@!,EJLUY/Q%.Z\M@.LZ8P&4SCV7`#BGW;B$
M$)+E6M*'%U1(Y.N-2BWU#^TG556SBE*NAB_`Z3U^!NY>.TD6"DM$`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;7-E>&-E;"YP;F<`````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,V,``Q,#0Q-S,V,S`Q,@`P,C(U-C<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````&%!,5$6$A(3___\`
M````A`#&QL8```````````!<<%\J````"'123E/_________`-Z#O5D````!
M8DM'1`<688CK````"7!(67,```!(````2`!&R6L^````74E$050(UR7*,0Z`
M,`Q#T10CL6*5$W1A38\`RH$J,>3Z).V?K">+#XD.%Q^,-A=5GLIR"U``MB9=
M(WM>^2JP,X8'V10$I:CV]0&"R)2@GN?!BC+'98\MR7)8EJ/-?A8(%\\-,\(H
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]M:6UE+VUS<&]W97)P;VEN="YP;F<`````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$P,S8`,3`T,3<S-C,P,3(`,#(S-C<V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P```,!03%1%@7^`P;_`__[_?X&``0$`___B
M___C___]P,"^=W15__.S__'/__#/__#1@$``I64E_]V\>CX<GV-!TE(1TU,2
M>SP;?#T<?3X=?#T>H6)!H6)#KBX`K2T`K"P`J2H)SD\N`0``_____O[^P<'!
MP,#`@8&!@("``0$!````````````````````````````````````````````
M````````````````````````````````````````````````````SW^?Z@``
M`$!T4DY3____________________________________________________
M________________________________`,)[L40````!8DM'1#\^8S!U````
M"7!(67,```!(````2`!&R6L^````JTE$0508TU6/6Q+"(`Q%8WU0V[2@*!5%
M:BIB=\'^=V6@CC,>?N#.X4X"*:6X`!#Y`3F@0E5%3J"7@S5\_$@44TP@&RPH
M3S0S8-!I/_H1;0B!P@P6M5->>1QR3\B&P>W^S["XV[%Q_AEWC>A.V:C%TG&S
M1CLT-`D1WN`58MMV72/KNG2,WIKCX7J1O1"E@T=?\X5"AE:/$DPT+>M,2Q"Y
MORY&>)8O+UYA,W_Y`+N]'=>Z37F-`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M:6UE+VUS=V]R9"YP;F<`````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`S-C``,3`T,3<S-C,P,3(`,#(R-#0R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`0#````[=WB4@```!A03%1%A(2$____``````#_
MQL;&````````````^T&S=0````AT4DY3_________P#>@[U9`````6)+1T0'
M%F&(ZP````EP2%ES````2````$@`1LEK/@```%U)1$%4"-<EC;$-P#`(!$F:
MU)@L@"E2V\H"MCR0.]8/3ZXZ3D)/OBFXG'QS<#IUP,=#&K=PK7]98Y*IB7%(
M:[W,$:)F)I#6YUM6%E%ACA+O60R@8.)&^;>R+`"IR0<XL1=[)^+'7`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O;6EM92]O;V]?8V%L8RYP;F<`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,S$V`#$P-#$W,S8S,#$R`#`R,C<P-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`$`P```.W=XE(````84$Q418"`@````/___\#`P```@(``@```____
M_U;LI^$````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9
M<P```$@```!(`$;):SX````[241!5`C78RAG``-QAG(F)2!0!C&,00#$,&!F
M8#!&$U%2PBUB`A,)@8H8AD!%TD)0=<'L8H:)"(*!.`#8_!6)URW5I@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M;V]O7V1R87<N<&YG````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q,P`Q
M,#0Q-S,V,S`Q,@`P,C(W,S<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#M
MW>)2````,%!,5$6`@(````#____`P,``_____P```(```/^`@```@`#_____
M___________________!9+?3````$'123E/___________________\`X"-=
M&0````%B2T=$#QBZ`-D````)<$A9<P```$@```!(`$;):SX```!8241!5`C7
M8_C/``;R#/^9E(!`&<00-A8V!#-,0D*"%4`,4Q<7929^L$B06@%$1"D]$20B
M$J16)@Q6#!0`ZS)2#1.&,AJ5(8R(2<JH)L/L8C8&`2!#$`SD`4,R(+#$1;^O
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O;U]I;7!R97-S
M+G!N9P``````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-#<`,3`T,3<S-C,P,3(`
M,#(S-#<R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```!A03%1%
M@("`````____P,#`@```@`"```#_____T"[!``````AT4DY3_________P#>
M@[U9`````6)+1T0'%F&(ZP````EP2%ES````2````$@`1LEK/@```%1)1$%4
M"-=C*&<``W&&<B8E(%`&,IB-00#(8!0$`9"4$%!*&,QP<5:%,(R-4J$B9J)@
MAC!0$Y@!T@1F*"D+@PUD4E(0@#(,#8T@#&%E(12[!"%V`0!+G1,13\`*;0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;6EM92]O;V]?;6%T:"YP;F<`````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,C0V`#$P-#$W,S8S,#$R`#`R,C<S-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(!````+7Z-^H````"8DM'1`"`1S6@$@````EP
M2%ES````2````$@`1LEK/@```$I)1$%4*,^UD$D.@#`,Q/QTGI:?F4,IJ#!5
M$1+Q,=9D060S@T(34M4HU(V'L$Q0!F)":QRM/*(KSG>XE"\)BQU>7/'K)RMR
M"CA#=AJU@3HN%F2X`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VUI;64O;V]O7W=R:71E<BYP;F<`````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#,Q-``Q,#0Q-S,V,S`Q,@`P,C,S,38`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0!`,```#MW>)2````&%!,5$6`@(````#____`P,```/__________
M__]L?[^4````"'123E/_________`-Z#O5D````!8DM'1`<688CK````"7!(
M67,```!(````2`!&R6L^````.4E$050(UV,H9P`#<89R)B4@4(8R&)BA#"8P
MP\7%"2X"4>,"!,[H(D[*!-4X*:&H838&`2!#$`S$`9N!%.SLG&(#`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE
M+W!D9BYP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,38`
M,3`T,3<S-C,P,3(`,#(Q-S`S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```P!03%1%````@````(``@(````"`@`"``("`P,#`P-S`ILKP!`0$
M"`@(#`P,$1$1%A86'!P<(B(B*2DI555534U-0D)".3DY_WR`_U!0U@"3S.S_
M[];&Y^?6K:F0,P``9@``F0``S````#,`,S,`9C,`F3,`S#,`_S,``&8`,V8`
M9F8`F68`S&8`_V8``)D`,YD`9ID`F9D`S)D`_YD``,P`,\P`9LP`F<P`S,P`
M_\P`9O\`F?\`S/\````S,P`S9@`SF0`SS``S_P`S`#,S,S,S9C,SF3,SS#,S
M_S,S`&8S,V8S9F8SF68SS&8S_V8S`)DS,YDS9IDSF9DSS)DS_YDS`,PS,\PS
M9LPSF<PSS,PS_\PS,_\S9O\SF?\SS/\S__\S``!F,P!F9@!FF0!FS`!F_P!F
M`#-F,S-F9C-FF3-FS#-F_S-F`&9F,V9F9F9FF69FS&9F`)EF,YEF9IEFF9EF
MS)EF_YEF`,QF,\QFF<QFS,QF_\QF`/]F,_]FF?]FS/]F_P#,S`#_`)F9F3.9
MF0"9S`"9``"9,S.99@"9S#.9_P"9`&:9,V:99C.9F6:9S&:9_S.9,YF99IF9
MF9F9S)F9_YF9`,R9,\R99LQFF<R9S,R9_\R9`/^9,_^99LR9F?^9S/^9__^9
M``#,,P"99@#,F0#,S`#,`#.9,S/,9C/,F3/,S#/,_S/,`&;,,V;,9F:9F6;,
MS&;,_V:9`)G,,YG,9IG,F9G,S)G,_YG,`,S,,\S,9LS,F<S,S,S,_\S,`/_,
M,__,9O^9F?_,S/_,___,,P#,9@#_F0#_`#/,,S/_9C/_F3/_S#/__S/_`&;_
M,V;_9F;,F6;_S&;__V;,`)G_,YG_9IG_F9G_S)G__YG_`,S_,\S_9LS_F<S_
MS,S__\S_,___9O_,F?__S/___V9F9O]F__]F9F;__V;_9O__I0`A7U]?=W=W
MAH:&EI:6R\O+LK*RU]?7W=W=X^/CZNKJ\?'Q^/CX__OPH*"D@("`_P```/\`
M__\```#__P#_`/______6").MP```0!T4DY3________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________`%/W!R4````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````6TE$050HD5V.RPU`(0@$N7FQ#OLOC&1#!;PEHL*;B^[P">+N
M\F`(8<E<4JM"L?BL`P5I@M2)%%PZXP=8%T-_`HHN=+=<,1`]P!$C`E15]NFY
MX(ZP9$V\G**>^P&ZF93#$VX9AP````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<&AP+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#0Q-S,V,S`Q,@`P,C$W,3<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP``
M`"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#
M`%!,5$5[>WL```"]QL;___][A(1[A+TY0EJ$C+V4G,;O[_?>Y^^MM=;>WN_W
M]_]"0EJ,E,;&QMZUO=:]O=Z,E+W.UN><I<XY.3D8(2D8(2$Y0D*<G*7_____
M______________\@("`A(2$B(B(C(R,D)"0E)24F)B8G)R<H*"@I*2DJ*BHK
M*RLL+"PM+2TN+BXO+R\P,#`Q,3$R,C(S,S,T-#0U-34V-C8W-S<X.#@Y.3DZ
M.CH[.SL\/#P]/3T^/CX_/S]`0$!!04%"0D)#0T-$1$1%145&1D9'1T=(2$A)
M24E*2DI+2TM,3$Q-34U.3DY/3T]04%!145%24E)34U-45%1555565E975U=8
M6%A965E:6EI;6UM<7%Q=75U>7EY?7U]@8&!A86%B8F)C8V-D9&1E965F9F9G
M9V=H:&AI:6EJ:FIK:VML;&QM;6UN;FYO;V]P<'!Q<7%R<G)S<W-T='1U=75V
M=G9W=W=X>'AY>7EZ>GI[>WM\?'Q]?7U^?GY_?W^`@("!@8&"@H*#@X.$A(2%
MA86&AH:'AX>(B(B)B8F*BHJ+BXN,C(R-C8V.CHZ/CX^0D)"1D9&2DI*3DY.4
ME)25E966EI:7EY>8F)B9F9F:FIJ;FYN<G)R=G9V>GIZ?GY^@H*"AH:&BHJ*C
MHZ.DI*2EI:6FIJ:GIZ>HJ*BIJ:FJJJJKJZNLK*RMK:VNKJZOKZ^PL+"QL;&R
MLK*SL[.TM+2UM;6VMK:WM[>XN+BYN;FZNKJ[N[N\O+R]O;V^OKZ_O[_`P,#!
MP<'"PL+#P\/$Q,3%Q<7&QL;'Q\?(R,C)R<G*RLK+R\O,S,S-S<W.SL[/S\_0
MT-#1T='2TM+3T]/4U-35U=76UM;7U]?8V-C9V=G:VMK;V]O<W-S=W=W>WM[?
MW]_@X.#AX>'BXN+CX^/DY.3EY>7FYN;GY^?HZ.CIZ>GJZNKKZ^OL[.SM[>WN
M[N[O[^_P\/#Q\?'R\O+S\_/T]/3U]?7V]O;W]_?X^/CY^?GZ^OK[^_O\_/S]
M_?W^_O[___\'Q@QM````('123E/_________________________________
M________`%Q<&^T````)<$A9<P``"Q,```L3`0":G!@```!;241!5"C/G8])
M#H`@#`!+2%L%4=R]\?]?&I"R7)WC9-JT$"*J`I\`0806BL@#^E>A.J+`!$$I
M$'D8#36%G9C=7`OK%O1K4[`WN"W=CAV/DR[Y15'B?N1;N2!D7KFP"".%W##Q
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM
M92]R<&TN<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#,W
M`#$P-#$W,S8S,#$R`#`R,3<S,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,```&`4$Q415A86-[>WKRWL9F9F?___^KJZFUM;?S\_'!P<,[.SC`P
M,(F)B6MK:T)"0DM,2U985EM=6V1D9&EI:4Y/3KZBH.*RL/;U]>+@WH^)A&YO
M;B$B(4M-2W-S<\S,S._O[]*_OL!H9<%13=S'PN?@V;ZVKU)34@<'!A\@']_?
MW_[^_OOX];Y&0KM`.\[(O[RNER8F)0("`O[^_?KX]/CT[(U*1HX7%+:$?0``
M``P,#$9'1L3$Q&1B7HB">,"UH[RKD'9Y=KZ[N(Z.BQL<&[:PJ!<7%[.JG!`0
M$,V^J;RHBG]^>KZVJKRPGKNLE;RFA0<'!U)24LG$OM[8SLB_L];+NM7(L]+#
MK-#`I<^[GKRC?_3MX?+HV/#DT.[>R.S:O^G6N.?1L.7,I[RA>,;!ML2]K,.X
MH\*SFL"OD;^JB+ZE?[V@=KR><___________________________________
M_________________________________________________S1O*TL```"`
M=%).4_______________________________________________________
M____________________________________________________________
M______________________________________________________\`.`5+
M9P````%B2T=$?TB_<>4````)<$A9<P```$@```!(`$;):SX```"L241!5"B1
M3<XM#L)`$`7@]]+"-E4$@0/7!$-P]`8$AZWF(IN>`(_"8JMJ,&@(%ZB#8%!@
M^"G;PFZ[I$_-^\3,4`*(4>=7:("ZL7"4M.!H8%$JV0"'S$O1``CE4FE8TN;:
MNU.N]'3NGP:&+@S(*!YF0&`@XYASLV-D^C-C2$Y3'"8*[J=%[AG.D'I\^/7:
MG0&@BY?W%GF;6WWVR%O''D[JQR(+FPH6L+"NP,<_7Z/A,A"\6WNR`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6EM92]S8W)I<'0M:G,N<&YG````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,S8P`#$P-#$W,S8S,#$R`#`R,S`T-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`$`P```.W=XE(````84$Q4182$A````,;&QO__`/___X2$`/_______^,7
MU7D````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P``
M`$@```!(`$;):SX```!=241!5`C78V"``$8&]O)R!B"A",0%)B:*8`9+:)"`
M.)!1X&*BR`1FN(8*"H*DP$K`:IA#@\11=3$PACJ!%3L)B!B!&"R&S,Y@J0(E
M1B6(8D&@,4`&DQ(8*#((0@$`@+<6DNH<%!<`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V]U
M<F-E+6,N<&YG````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,R,0`Q,#0Q
M-S,V,S`Q,@`P,C(V-#0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2
M````&%!,5$6$A(3___\```#&QL8``(0```````````"+Z11]````"'123E/_
M________`-Z#O5D````!8DM'1`<688CK````"7!(67,```!(````2`!&R6L^
M````/DE$050(UV,H9P"!\G*&<D9!04$A=AA#`,904H<P!(7!#!<7"$/$4<01
MG2&(2PJN"V$.E,%L#`)`AA(8J`,`HQ04*-AK*I,`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+WAM;"YP;F<`````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T,#,`,3`T,3<S-C,P,3(`,#(Q
M-S(U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```#!03%1%@("`
M____P,#``````("``/__``"``(````#_````````````````````````````
M(0U&O0```!!T4DY3____________________`.`C71D````!8DM'1`\8N@#9
M````"7!(67,```!(````2`!&R6L^````4$E$050(UV/XP``"_/\9/@B"@`*,
MH<@/91@;`QF*(BZ"BL(,'T03'4,24X$,-4%7]T0Q99"(2P581%!1+`VL!JQ+
M$,1P`0)'`B)0QF=C"```4UT@!ZCE6@@`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M8W!P+G!N9P``````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,S,Q`#$P-#$W,S8S,#$R`#`R,S(P-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`$`P```.W=XE(````84$Q4182$A/___\;&Q@``````
MA/___________]PZ/BD````(=%).4_________\`WH.]60````%B2T=$!Q9A
MB.L````)<$A9<P```$@```!(`$;):SX```!&241!5`C78RAG`('R<H9R1D%!
M02%V&$,`RA`V-H<P!(5`#!$701$PPT7$T<4)RH"*P-0@1&!JX+K@YL`83$H@
M`&08@X$Y`/#Z%8)31K%5`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O<V]U<F-E+6@N<&YG````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#,Q-@`Q,#0Q-S,V,S`Q,@`P,C(V-34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0!`,```#MW>)2````&%!,5$6$A(3___\```#&QL8``(0```````````"+
MZ11]````"'123E/_________`-Z#O5D````!8DM'1`<688CK````"7!(67,`
M``!(````2`!&R6L^````.TE$050(UV,H9P"!\G*&<D9!04$A=AA#`,904@<R
M1!P%!851&2XN,!$11Z(90`,%41C,QB``9"B!@3H`LT847F<V?G\`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W-O
M=7)C92UJ879A+G!N9P``````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-C0`,3`T
M,3<S-C,P,3(`,#(S,S4T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P```&!03%1%(2$A0D)"````0B$A4E)2_WM[_SDY>R$AO5I:_P``W@``O;V]
MG#DYG```6EI:,3$Q____A(2$G'M[I82$G)R<:VMKSL[.WM[>[^_OC(R,K:VM
M4UOO4UOO4UOO4UOO4UOOHJ8Z^P```"!T4DY3________________________
M_________________P!<7!OM`````6)+1T0?!0T0O0````EP2%ES````2```
M`$@`1LEK/@```(%)1$%4*!4%P4E"`@$0!+#J$A=$M%T'O>3_OS0)0`8(8!H@
M0-H"`=(V3`2D;0>=@#1W;4P;D-/]PV-CFB#3I_OS<\?,A)E<7L[GZ^M;0J3[
MOA_7Z^=^!9DDW[L_/[N7(&E[V=W=/8K,-,?N[NY1Q"1[^YWYOAU%D&/"G/X&
M02;0@7_$:Q%<MU!D^P````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M<'ET:&]N
M+G!N9P```````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C`W`#$P-#$W,S8S,#$R`#`R
M,S<U,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!@4$Q412$A
M`$)"`````'M[`#DY`&-C`'M[>P``_UI:`(2$`$)[`&.<`"'>``#_``![`"%:
M``"]```Y`$*]`+T``#D``#F]`"&<`'L``/__________________________
M_____WK"'8L````@=%).4_______________________________________
M__\`7%P;[0````%B2T=$'P4-$+T````)<$A9<P```$@```!(`$;):SX```"4
M241!5"A35<_!DL(P#`-01<'L*G%;$J`<]?]_R:%E!G33.W@LV`8*_`ELUDL-
M?L.U_I4?J/\UP)/`(DEJ$<<=E`BIY[)*M&ULO?>\C5RE8ML8F3G&''.>8-X?
M6PYF%PZX/W,E]J[C%[Q>),ORZ80?1DLI2),$;-X6*4(!1138G*DCT1IA<Y\Y
MVSYG(6G8YKH-\ASS!C)C$!L;CW>6`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUI;64O=&5X="YP;F<`````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#,Q-0`Q,#0Q-S,V,S`Q,@`P,C(Q,3,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0!`,```#MW>)2````#U!,5$4```"$A(3&QL;___\`
M```L9:@&`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,`
M``L3`0":G!@````'=$E-10?4#!03"PG;N*46````-TE$051XVF-@8'```08&
M!A9#(#`!,H2=00`H)&P,!$8H#!,7$V=T$1<R1&`,(240`#)87$"``0#Y7!5J
MW)+KX0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+W9C87)D+G!N9P``````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`W,C$`,3`T,3<S-C,P,3(`,#(R,C(W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```,!03%1%`@H>`D8"6FIR9IH"EJ*NMK[&R<[6A)&:
MFF8RSM;>SIIF&B8RVN+J*C(Z_LZ:-D).OLK2XN;J_O[.BI:B3EIBOL;.YNKJ
M1DY:U-OC"A(FVM[JDYZJN\++R]+;ZNKJPLK44UOO4UOO4UOO4UOO4UOO4UOO
M4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO
M4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO_AJ^$0```!%T4DY3
M_____________________P`EK9EB`````6)+1T0_/F,P=0````EP2%ES````
M2````$@`1LEK/@```(U)1$%4&--=S]$2@B`0!=`-%)7(I#)(V-W__\L6=&CR
M/MR',W=@%I938%$UKW"_73\`"RAJ>;N((-"7Y+PRXM3]8!^E`B&$%)B<M8[:
M@@W9QSP>BR0;@=D>T/<K,U(<QXV>[0TDK;6JX/-J<(H%+C048#88M\U[^78'
M[("<E]H!NR074*UA*-?`?YW/_P*UK@^6N%).H@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]V
M:61E;RYP;F<`````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S4S`#$P
M-#$W,S8S,#$R`#`R,C(S-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=
MXE(````/4$Q410```)F9F<S,S/___P```*E^#I@````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!,,
M*-B0(X\```!5241!5'C:3<S1#8`P"(3A&Z'5+@"R`0MH>_O/Y&E:X__TA0``
MJBI0>V;:PE$FR(D,E(5J.LH::-V[72UPDFXC`MC<C9J@>;\&!:JAJ^_/#]IV
M?\"W&V=3$5^@_*X<`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92\`````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,P`P
M,C`W-#8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;6]B:6QE+V)O='1O;2YJ<&<`````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,V
M,C8T`#$P-#$W,S8S,#$S`#`R,C<V-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#_V/_@`!!*1DE&``$!`0$L`2P``/_;`$,`
M!@0%!@4$!@8%!@<'!@@*$`H*"0D*%`X/#!`7%!@8%Q06%AH=)1\:&R,<%A8@
M+"`C)B<I*BD9'RTP+2@P)2@I*/_;`$,!!P<'"@@*$PH*$R@:%AHH*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*/_"
M`!$(`3D!!P,!(@`"$0$#$0'_Q``;```"`@,!````````````````!00&`0(#
M!__$`!D!`0$!`0$!```````````````!`@,$!?_:``P#`0`"$`,0```!]4`(
MOEGKGE6L6:NNC>5;FL;^7M9<H^OD]3C9.9KC*8IUE'E'0D*=ZILCG51F5KA5
MI#?1/&[<][,H>_0\=:8*',EZ`QU```#S+TWSRYYV;S_T/>:G!N]6N5^.FMQI
MCI@0=<YF^&.G#(Z[XJ+WY2!OMS[ZQC.<V$G>Y9Z86M:_-UVSU&Z26T#'0```
M*/>*5<^?>E>;O=XO1Q@-1D-AA7*W#"*QPQ)A6=,]^+6,:$;D;HSUSCHN'*+E
M-^G%*L&=YKLZO:Q#]`\Y]/SI\!G8```4F[5"YHJMTMWBQ*I?I<U3.<>OU99T
M"P(D7:]%B<^_1./!ANF.NFK5G6=(9IV5PTFKK]WFJS7I$>XU]:\F]BSJ8!G8
M```56U5M/.&JMSUY5#U&M5N:]?A5J9,I(-LWJIM5;AN/TD="/OWW-.G3>6DS
MYE@:KM_10\=;93>%5UYN["=!T7^T^.>SXUD":```"N6.OIYJX3.NO-JH;:35
M/<LD[$PC35KMUJK&5UF;LU"[3.Q'4/?-$8L8^MSM#TDYZ*+%T-8YKF*\X^Q>
M-^R8T`30```('Z!/,G:1YUYL]<J9IE@CQVB0&E<JU<,HLME:7EXA5/K"[J_Z
M+`E;K*9ZQLR2<(7=N5S)<D3V;QCV?&@":```!`_0)YB^0V#ISG5^P*FNMH\]
M9Q;J5HX.$JLSZWZ625+48MSYB+N@96<;6C4188?3G)B)">ZNJYBN2)[-XU[+
MC0!-````A?(D\OL->L/3G-QG1J.NE;I#CV'*JU=EU$4Z+T327QXQ!L6DBVLS
M'.PIT90QACCV!:Q7I$]D\=]BQH`F@```2.TJ>66*N67ISEJ6M;:N$VEV.%/!
MS"7L*IUG;$5A'$Z+!AA:PK332T2JMR$)IT659(7L5R1O8O'O8<:`)H```$KI
M.GE%EK-FZ<YD:6-5"=8$Z;S%G(B36Z9;7'JKO,E2%.@M8)[3JHID/JC10,1:
MWR+JN8KDX^O^1>NXT`30```*FJQ/(;+6K'TYLHDE4U,X-+-+2Y4JLH\TWY5'
M@NHHO[2>YN:=#7GSF1!+!`5$QAXLE+F2U,>M^3^L8T`30```+F,)/&K%7+!T
MYMZQ9LM*NBWBEEY1^645BLVU7#=%TBQ(==Q*U1.*WEU9]DV@*EFIE_RD+JL9
M*TD>J^8>GXT`30```1Y&AX@Z3LNG*P[\]6N_./TE6[[L[,J6P5";88Z*XCV2
M5]\959"?\")/Z0Y.F(<RWFI:IT=^CT*^XT`30````'C.9R?ISMZICQ7#VH6G
M)W0)["N?6KM:[;.9.;7.-JX"K-<:ZF+$@CRVA;(6R(7E?L&G!*W1LWRWH'_/
MH`*````!YW2_4/*-XNC%!8*7I;=M+685JRRH@6N);MVK'62S:UWE$.SQ6>K4
M'#*(B@LFJZ<^O!(B)KPCU>6&.@``````1_"O?/,[FMVZ@6#>;=F/(FL8SJ!J
M6!C!M@BDC*J$6(UR:Z[\C6+T7HOM5*]DS6`&=@``````0IH>"'JGDVN=B>5!
MK5CPHZ4RUA[$HBA+5RMUD].?&61PAXN9'';DG%'WF2O;]C;'0`````````#%
M9LXGAC'UJIW*B7'ZV=3.`,X,FN#;IPP2M(_`PAM5B*3Z9VSG8`H`````````
M``&,@8R`````&,@`!C(````````!_\0`,1```00!`@0$!04``P$``````P`!
M`@0%$1(0$Q0@(2(Q-`85,#)"(R0S04,E-4!@_]H`"`$!``$%`N%@;$#D?`M1
M]U:W'EW`$Y;L_A_X92:+')N>,.57NOY<&/<;NRC>;%ONK9`'-"S[HQE*":U-
MEU:ZM=8NL76LNM76KK5UJZU=8NL76+K%U;I[!'3N\GH!YICJZZPK?N.[+-XX
M6>L75T')GVSLSZCGSZFM8*9Z]UYE#=F1J]@A$.])Q3M2YT==.P0I%F,<0BL.
MK;ZRPC?K]V6C^IBB;#,G;5K55Z[]EJN0[M5=C5JY0J5%Y0Z5]P`%&Q*$I!L@
M(1!AL%Q`"1I5P1!";H\E/S&P3:MW91OW47Y=BJ7>+A8HK\M'[=KK:M.W1U3I
M2,A#B*,G1Y^%B?A!_-@&TI]V9\MJ[':3%6%&2G;U(2E;*OD?FGC3C7)L,N21
MT8D03B(DHRZ2*ETK)@L[D/RE">]M#IJV0(I8NVS"J7:Z'E+%9-8@499ZJU-?
MUAHZ4.[X@;S6?.&O/9)SF/*Q4MXBQ7R<;<9G(R8\W49NZNVND!7!T[%G(DA;
M6)/SIHZ*+L4=&R6F:9YQ1;DUU))*)9*]D-L0UKF-'*?D-+67Y8QM*/=\0_Q@
M=MW(<=S`F;K209VR.%UD.Z6O*L2N=#`R\+>9-)R3VK:MJVK:K@N=4I3ZNB8.
MCD)`,1=5D'QN*#1C=TY<'VA''51^^HVVKW9]OV_AJ:#V*;;AOCLA&P'=JK(!
M6(V,(-YO#*TFQ3/R'$[19EHM%HAC9U*&U5+1JJY.1.JM&@*=>8I0*5H-D;.J
MK,Y[!5#[Q^$.[.^U_*M+:]\&]H2D`M>Z^V5ARO$8X2++4>(?4.V6K16U:)HK
M1V3Q=H867ZIA,9=2.+1E`!+-K1F>=LD8L,156;6QWYSVOY`3*S4C-VYE>87@
M=/,@WYNJKRZ;(;5L6U-%1BHP66,P*^.?D57MJ$"$:Q:%60ZQ;3PA$<9(JH^[
M[\W[3\J_&<&FQ:3ZCMD$S0"=7JLMN+N,2.U:,RDT8O&*,2((6"/?M#K$*IFJ
M55-[EU`J"!QDBJG[OOS7L_RK\=6X/XHE8)%&%D2>N:!J>2>"&>!(#D.+VLG`
M*M637%CZMH(I57(AC$)G?5:MQ=%57W/?FO9_F#A)R6;/R<*)B"C4CV*LA%@6
M*U=%`,B>C%G>G.2'2#!1;:O%UZ(EIM\:%XZEAF9CBLT$.3$@_H55O<]^9]G^
M=9.JQ.GOR*-LESM&(XYPN4Y595S1.)_!2MQW1C>FI0R$$]R0T,L"Q31G=)0Z
M,,+%N?-YTB3OD;IZ$7C3=%57W/?F?9_G6]'5VMSV`1N86;S33+MKRT%BG_<%
M_<7#-&K6!:=ZLKP]TC"(^0&U*Q8F[5L<<8<=5.\K^[53E$,&:5Z:=%53W7?F
M/9?G6].%@`SLPK0%UFQ%LGLM3K=*.]N!:+OM+4G(V$VBC-I7IO<,\([6&6HH
M6J\6YUB:C3UGP=&]*?N^_+^R_P!*_HI2:+2N!90LBFHR=.[OP=M6>@T9,V0B
MMV0=2K6#H`1@APU=2)&*>X%D,L"-P-Z4?>=^7]E_I7^U`C&Y>YX1V#T:AV/C
MC5U7M,27T"3:$8@L'8=:D-ISJ[<G4B!5B<T*,J'O>_+^R_TK?:I2>I?<$2RG
M9>"A<=Y7ZT;0:!^<(Q8B@,5NRT<1*;2P[LBU;H%6ML5W?1@2A&#%YH9Q@I"B
MLL?:"L+D@1EC_?=^6]C_`*5_M5@,+`Y<VG+7G#''2+$V#Q6LBN\9Y6_/G@H7
M>96G>=B#L[FS>D2VM94X%YM6IO'#S*Q>C!ZM63$X&],;[_ORGL?]*WV\/Z)C
MPRER;T%.G:L(0H!'D*\Y2&0-F(Q2:+59*<AUFC&>1.I4B#)_R*>F0J``5>/!
MT;TQ?O\`OR?L7_DK_:C&B-;;LFF8P4(XR\?[-7"9?+QLN@9T.A6@[\92:+-.
M4WE&U%#M-S$Z-Z8K_L._(^R?^2K]JQY&^8&B,UW>SJ[C0F3&+5*WBGAYG\%(
MXF74A33:2E'=PE-WFU3DS>WHIVIO',Q8E6E-R571_3#^.0[[_LY_RUO17HO7
MLU3QWP(\V#/<\@L>IB2O*%@KQ=Z,8/4!4("=*M)K&*$H')7L&GL$&#PJXT[$
M#.44[15\SV20@PX.C^F$\<CWW/&J7^2IZ+1I,:B0+BM04/,K%AJ\,.*31YO)
MS60,YB5I3C0<TMU<\MF<GN>P-R5:I^H`S/")K@`MS+5Y5:PZHTZ/Z8!M<AWG
M\0&_DJ)N)!C*TL75=QXZK"2NU&LQ8I:ZA<JNGN5&4LA&2JTIN56*0+$FQ0$*
ME6"GXR5CT^'&_==[MX6O`M1U'T*1AQ@.R5=/;TZEQ2B[2;A_4@CDFK@9-X<7
M3SUDU6S)$#8BJ]AB\)(Z^&H^;Z&4CLMU'4/2[+:>^0\WP[SZ>Q$18V@DQLQ$
MB6"G8@SM(TD\CQ36X,[.SLMW,>M8J#F6&X@Q<N5SRY525A?#D=*WT,_';=K.
MA/X7J[V`4K3LAV&T/8_5D7G`PLG1'D>T40ZHJI'YMJQ`,2P$<9M<;;N$V53:
MMAP\_KY$5JS$,*,)6+#J:L>N%CMQ_P!#XF'^H!_&N_@RMTX64[V*KPNU)-:O
MCTQE5ZP3E>GE26&.*N2(HS.TXN=Y/EB]38,)B`KV7JRZRFS3R6]Q4)DG_3HK
MJ?B2K#EU_H?$`M]&+Z2IS4?3A,(2(8QBX60#L#C5NU5UMB"^8%=3^9VFI41U
M.$X1FS5*S)O*W"2-)8T?/R'T3#8HK$'$>L31P3U;OU6O#5F6K/VNINK$U\,@
M^G\35-I8.JIM$.>K?0))W6QW4;`^J;73@[J3HLD[.4M(#5JWTK((6`6Z\ZM@
M;H!M$,NJW+5:]FJOU26:]2NXP-1"QR2\=5*2=U.6B.1?#U'ZN9Q[70Z/"8G4
M-R:4F7,7,6Y;EN6Y1+M36G4[#R6]>+IH.I^5'*L10>Z:,6BWU-%E<5"XQ1%J
MD#89E"T-TQ:SK2JZY5=UR`+IPKIPKIPKD`9<NLRUJQ4K((HMV",?<L=B269#
M%`4/KF",T3X`,GG@#,A8&>WY`OD,E\ADOD,U\A(OD)%\A*OD)5\A,OD5E#P"
MJXNM66G_`,7_`/_$`"41``(!`P0!!`,````````````!`A`1(`,2%#$P!"$B
M41-`0O_:``@!`P$!/P$D=HT?4O3^#%ZJ#.1`_/IG(@<B!R(')T_LY&F3]9&W
MQ$V_=B[PD(:O7V+(=BRK%7&1[PET*C1M+,VFTLS:)49'!]"%18L58X/H5-34
MVD'+^L8J+?R)Q@E]%Z1P?0J2BG[NB=6RY*4I5C@^A>2.#Z%2];87HR.#Z%XV
M1P?0J*MJJK(X,5+5W&[%D<&+R1Q5+E\KUCBL;%LEUG?.]5BQ4M2Y?%9->-+-
MHN7PO2XO"XFTL6+&TVFW]?\`_\0`(Q$``0,#`P4!`````````````0`1(`,0
M,`(4,00A(D!1$__:``@!`@$!/P%:;5^E_3R"/25`MM46WJ+;U%M]:VU3XMK4
M^+:U%3Z/43Y(`:>P1AIL(=[=[DM8\0T\W!3V>SIX&`YL<+V,!S<"10N8#G$U
MS`<XGN8"3S,!E,!E,!E,!=\1]$^B8BS7=/(Q'$6D9`XS,'"3A=.G3ITZ=/Z_
M_\0`0!```0,!`P@'!@0&`04``````0`"`Q$2(3$$$"`B,D%181,C,#-2<7(D
M0F*!D:$4-(*B!4!3DL'PT41@8[&R_]H`"`$!``8_`LSFN%1F:J[I!57X%5&'
M\E5RK]$QF\"_,''W1V-6[3;PJK5-%?0K9^ZV/NMC[K8^ZV/NMC[K8^ZV/NMC
M[KN_NMC[K8^ZV/NMC[K9'U6X*KC56G;#,[?2=-_)R(S&1O=NVN1TG1M+&4PM
M;TZ.Z@95"KHL<-Z<V2@&Y3&@U6U"J714I6@Q4A-`X7A6&V&W8O0KCHAK1>4&
M-W??,%)R8!IS#FJ9J%6F7Q?_`#HTZJSN.\(OM76+"`ZFG'>FBHK:^RGI9H\4
M"LGHJ4I7>HPTMM@4*LV8Z74=O36UK0:%&B]4%YWNT)W<].0<0,PSE^3T!.+=
MQ1;@\8M/;!Q-&<>*LL%!H.<B>+M-AY*JLG-T63MZ27AP76Y0UO)JM=/K<5J3
MAWFKV-=Y%=T4&2U:X[E:<1D\?%V)^2UC/+YFBOBF9^M5R>>_PR+VACF$*K(9
MW#T+5R27YA:L?1A:S_W+J9G-Y$JG\0BU?&W!6HW5&<!,YG3B/)!V:/)H#1[]
M_A'%=/!)TC#M'_E7$ME\*Q6.:WBXW-"_$Y5UF5OO`/N*KR24"\5"-J\YNBGO
M:4,DF=6,]T_-BL5>C!$.DE==1=+*.J.T`=E5SP^6G">:,;]EUR$<EP&/DG/D
MQE1!O"Z3([G>%='E;#=OHJM>,SB[NLGW<47'2/C;>$Q_OX.5ZK(X`*QDC"V/
M?(5:VYM[RC:4D7]-VKZ2K9^6:(?"-./U+!.L]\T4'D@<"$*G7&(S4F8'*N2S
MV7<"O$P?-3N=M.=>JF[EHWW*]2PQ1.DM&H`59+&3,^)6LHE=/)SP0Z$MLC<-
MV=YKU=-;_A<LS?+39ZLU0NDC'F."JTT\E>K(-D;RK0Q3AQ"D;S"QJ-&X53G/
M-ZREPWN3;;B`%01U:-Z+XSM;EK%4CV=[D(V"@&9HY]@WU:%J.YW#BK@?)=4Z
MR_@J/&8@[+M,H5VG:RN7A:-Y5F/6D5N?59P5E@H,\?J'8?JT:/%5:A=>K&4Q
MVV\0NHD%KPG%8:[4(Y-K-K7(#><U7+_PLO<57!O-8]-)P:OZ,2J!;=Q.C'ZA
MV'ZM'%7+6%5P*ZN4D<'7J1[MYK<@R4_5;+J<A55UW'#9*I<T\\?HG!@=0\=Z
M-DM;4[Q5>TSODY;EU<8"OTH_4.P_5H?AX#9IMNX("3*)"\\U7)\H/D53*H[O
M$%5AJ,^LP?)5CE>Q:^4RD+9J?B6J`/(9[$+3*_@U5D>V!OW6ME4E5:M]+%OJ
M@X8'.SU#L/U:$[3[QJH'5%HUJJDK7I9YKI\CV=[.*#VYK,372.^%:N36?45?
M`T^17M$#V<U5AJ,SFL=8@;MR*SDUDD8\4X@X6M51U=[_`/A/M8*('&F=GJ'8
M'ST`Z.Z5N'/DJ2,`E&XB]-NM4Q:=Z8WH@0'5LVKD0[><!N64,;LXJ+)JV6F]
MQY+V9[(6,'A4;YM5]*E#6%#S1::$\$R:"YCCK-4CF^&J8TTI2]3&UTFJ!;`I
M\E@*E6G4:T*TX%N3#]VA'ZAV!\]&D@O&#MZZLMG;P=<5UV1RCR5C),E<VN+B
MJ5M/=M%1Y2W9V3R3'-EH&WTI5%KG5=3$JE1O'U1-UGBF9/%?Q*L^[2B+71F7
M)]Q:M6*;R#%U&36/BD5O*G],_AN&C'ZAV#O,:%ZVE<X*XJ\YJ&\<%:R:5T)X
M8A7&"1=WD[?FO:<JNX1A686T!Q.\YKEBKW+;"U'`Z$?J'8.\QH/;+W4>[B5T
M;(F=&V@-&[RM:%GR"M9(\N;X'(L?J2#%I[&I0=W49W^\?DJNC?([X]Z'4-IO
MU1<OQ&3:CFX@)K_$,\7J'8/^6@ZMS9+P5:8]P)?:-Z`;>2KQJFE+^54V5ETU
M*ARUMMMQ5IQ5IH;#'Q?O5796X^E:N4RA58YLPX8%%KA8D&+2JH95E%"7&D3#
M_P"TTF1KKZU9@A>?]-5M'_356?>=<`HX]X%^>+U#L'Z%B3Y'@J3WQ[I`AT9!
M0!&"X,:%.\;)43)=AHM4YH-C<W:K?@KF-90TU<$WF2VB?7<ZBBF9<]/LXV%D
MQBLET6YV"=7%[K1INS='%ULO!JZ?*C:F]UNYNA#ZAV$FC0WA6HBZ%WPX+J\I
MC=ZE[5E#;'!J$<8HU-GAO>S$<59D(J/=>J,%PX(VAO59'M"#J$9,S?QS%^1R
M6*XL=@O^G'->TY27#@Q4A8&\]^C#ZNPET.).Y5;DUW,KK\GD:..*U':'6Q@G
MBNKDG9Y.6ME&4'YJMBV>+S5<L]ZZMCGGD%7\.?J%T<C3')P=H0^KL)?+0G>_
M%NJ.28T"_;>:YK4?5R>)J$65[]E_'-6JO6VU;;5<5CF$<0M2'<JSTD?B!N4;
M6V0UW#<C0@.%WS5H[;<"HW'$C/%Y]A+Z=#IV]V^YW(HO&+MZDLAWO5^JP=9!
M=O3XY6GE5.C=>67)K(Q:D?LA,&5$RRO]T&@0D;"UHYKNF?15A)B=R7X?*OTN
MXISC@%%-9<ZV:RV<:)Y]RT0RO!8!.NK4U-4,E@O<<>2:QN#13/'V$OIT"'BK
M3N5K)-9G],[E9?6)W!RU'M->!1MO:7;@$^9UUO!`N\-RB)CZ6$`ZH-+TZ.3:
MOH.2LBT`3_A$R;1N4--JJ>SWBVB$#GEKFW%M:(`4:T<UK25/`*D+>BA\15([
MR=IQWZ`\CV$@^'2I*QKQS5P>WR*K9+S\1S"ALR-P*LY5"[U-7>EOF%WU?DJ9
M+$][N*Z?+-O<S-:>VCO$%?),0JMB!/%U^DX\&]@44,UIR;>R&ULVL2K43XI?
M(JSE,9B/$X*Z\:&M%&?TKN8_[5=0>0T++`7.Y+!K/,HV'1R4W!$4LO&(.A,[
MD.QD'Q9\G#MFTF".0$N.HT"]-)D!93"F!5B2R:[BNDAJZ#>W@FN9@<U,3P"U
M<G>K\G>J/JP_$%=F<2;,3<2-_DA#"6UIC7%%Q>^AW!RVMU,,?-0EN+KCH2.X
MN[%_._/1G>-O:J/N>VXUW*Y'I(Y+9[LC<J2"A+;PIH]S3<F9,PTK>X\E&R`!
MI>ZS:WJ>(N+A&10E7\MRO`<T\0FAIKD[]WA3W#@FMA:UVK?7%6G1Q!M@5H/]
MOS%SJ!'*Y+FBYE=^A'SO[%C^(T+=;$WB"]HB+V>-BOF+>1:NCR6LCRB9.\?>
M>2$IV7BE59=Y@C<C0EQ<:N<=ZH<,<T4$5[JIT9WBBZ'*ZL(P=Q53E-?(*SD4
M+WGB4)<O=:X1A4W<,]%&S@WL;7@.C<M>&,GTKJHV,\AF+)14+V:1LS/"[%==
M_#B?):G\-=\U2RS)XU6MN4^_FI(T.'-5_#Q_14:`T<KM&)O.I[)S#@X43F'%
MIIVN*Q["2<^D=F,I;@ZYWGVE!F_#U/2*_2#&[1P3(AN%_9OB?LN3HGXC[]G9
M@=9-:J-LCK3AB5T]@=)Q5VE^)E'H'^>UJSOF[//DBUP(<-V:[L<%CI6W]PW'
MF@!<!VUIFI-QXJQ,PM.:]7K:5TB[Y=\%WX7?!=Z%>\+$*Y79@^>K(ON4&1BR
MT8`?R%F5@<.:K%(Z/EBM6=GSN763@'X0OS)_M7YD_P!J_,_M7YG]J_,_M7YG
M]J_,C^U?F&_1?F&_1=['1=;/_:%5K+3N+O\`LS__Q``J$``"`@$#`P0"`P$!
M`0```````1$A,4%181!Q@9&AL?`PT2#!X?%`4/_:``@!`0`!/R'HC,Q8$@9X
M";"1\E]DG5+XA#D)[C3K/2>LD_Q?69D#'>*'.J[GDL"9%>TN_P#**(I\D(M4
M,9\O\"U+AK`\3;#894[B$^JOL$H0W"(,#M_?8Y]/QZ9B$=PA.08'I*[C'/L(
ME@;DK;5<ZO8;)F&1)N$Y^J_GYP7N2*Q!RG=*+U.PU-K_`*-&>NEQX0U[XO,$
M8N8-V_:1&%-MV&P6O^V(U<#.?M%HJX-&-Z;.1I,5G1I<=5M9&YM;GA;F$.S>
M[HPKDF9_./67U1>G19"6(E-1'`R*;W:6?\%-2G*=IK'2.C:SLPL(]&W<F,D]
M25MT^0T$=FVGEB-KI%]A93<9%\Q0E*-&)X-BC)2#';O8]^D$%UF7"6[)6R^9
MD:9G8\:1S`J7\^_,-J<6+=R^CO*S1.V+1OJ+833?G[1N-#B"*Z,CP2:,3:/W
M)D1&YVZ9%<W26]"!(V_T$/?R<LA1A)D3'9>#ZL4OYW'#5?)[3(+"13A%E<S1
MUW/0LY'.)"LCGRDLNS!NG"T#Y$T8IED7,Z*TBY%WAE)3ERFP69]E[EE:Y*TQ
MJ&AJF$RG?$81W-1MM3R(ZLQ*0V3NV[RV%!1^Q(,Z)CUIWD/W_P`_G!O&7H_]
M%H>'PQZ;P(0*2W]5_1/_`.<\"+I2MF,[<96QD\DRWJRSSRW2;P/V]#$A:7&X
MZF9O<IQ@?A1!F-$ZH8W_`.,):W1IFD3UAC(XPRRD(ENRC[D*:+AJ?!22)-(G
MDBW?ZO\`FOE5[#;6FVST9F`FVX2W[(:BDWT6B$8)BM-3*)1T5Q>.Q*/P>1>!
M,DDB-IIB=SK<-J7^CW9;<B""X"786T@O+ZD_8+S(OF2\FQ*IU&[5HQ]\D(7*
MACL(BD33IHO"KGH?H?+'H98\9*]OYR-^ZZ*QDN'+?0CJ0U+(@FF#(9_?5>1H
MU'C?JAB?,;H*WB4MRM<L-E_KH]HBRYAK8H;-+0PX,1T8_.DU^F?8YKLC"&T%
M2&2Q*-)V]"4A4NM1L6%)"XB0MD_FGT[,:#D,L2R@\7N)PF6'@T-HY]T*<=O<
M+X^0],W8B6<IWL0P<K5YZ""Z6).9,$G.$1HAJ;M)"E=V1;0)"78*QM;P,UT#
MGN!QAO'<D\U+_@+P>[>Y1,YJ0C^:SVOPQG%%4187HQ-X&6R+IY<34H7I"<EX
M]2#70NDX>E>=P;QK?S@Q)!>:<)K80NG>*<L2FSN>7[%5."#`Q$S_`&?X,/9\
M,9T+HRB!H]4>PA3*Z^M1%V[V7H&4:?06Z'4)(J;U$>"8)NMXE'1G'>BW']2V
MR!J]C!N:B@K^.B;-'^8[\BZ37I@8E/J7^#XGPS)T&@_`^()IY$%H30T38W$B
M2WI)?V*?2<!_IDC`\_ADN<_+@^J&C'PVA$Y:9/+>%C6`$3E^@IK(TQ#--SCT
M(1%S#&Y!S9)Z8F+&^QK^#XGPQB\#I#HE!+3*\:4PD3-HQG'CSH05^`QBBB)K
M811WB02A7![HY_L>3+F218[&(EEME)+ULVR2+'=BZ6-%8O"[QBE?39(M+1*Z
M6+/M-_P7\']C^0E(P@=28%Y0IZD7N\51"@+=L>5*V:0,3IRTD-93*V&A+@G,
M90A#.$^`22D%G'84HC'X#%FOI]OLA&WYLLB,6L>PA*H3;6K;B,Y4LK=A<=S`
MQ/K-_P`'LO\`8_F)7H:Q+QB\AK7#I";M5>6!,SRFQ76.2G:F>DFTD&`N'`]K
MI[V#HV);21MO22$IFU@12U(;E[!S6L8P14G!IM,@ZBQ)ZMB"*KH`@U:7K#W)
MZ^,%-@=:G^N1WA(P,3[C?\'M9_?IMSDR)VS"D\E(?EXVO"2@3PC%"VQ-2D66
M*2_(N0UR')/(?9#JF35=2&^=C<E8PRKG00Q.IP-QPTSU#2Y0FIM\$V]WX%*?
MT6KQ&>R4)+01CT/NM_Q8+TL#>$B@B^593=N_T-9_!D1D;"6(3<M<C`*#UE71
MI.2'U"^Y(]9H9?<8E"%.J!Z_N%,Q+EP,K7Y&!]A8S3H?3;_@7^&)Y+UY@]PN
MI92&',U@?L362LOHQ03Z8P14,IE$*2.CM2/K+Z299,0,0ZN]G'R.0;!O(OR(
M\LG`?@0GJP9@S[+?\'NOET6Z65X.3L(*<DNHE1<R%.RD=IF^3)35`_EJW9]Q
M]:Z$8(20OO/#[[$>.+*#(9S!-IG4#.@0I[4DI$#2C:7(4TV'$.25*H&7RWR@
M2U;J&9)\QUW#,67^M?X/B_)_;KM*:RG+$(IXD*\[#9Z$=/,$D,HG/*4#+4]1
MQ`J.LCR6=7C4,1V$=3DEI0J2889(V$(I\\9<,R(8'CAM:DCE.20U7[A%L+7Y
MBL>"):W6MD56RE<7*%_1L=L9F$^EK^#XOR/YD.GL99"9E/`V;UM\!8RK8,UR
MULD8$]WN)EPMD+RIUU.1*V,@RD>Y9X'5%;F)MDQJ9+V#[<"7.9'+@NHE/86^
MW.%ZE@1G4\C->C,6[7\'L%\HIYCRI)"JVH26V*@6Q*9=["*'L+)0^-?0^YZ-
M[K/27(9[=9!K4NU.EM!JBDJI*J$MB([$@=5J=Y<_L%T&+8F>"A'349A?PS/G
MZD>;[=`_<L6V%A>105IL>)F@A;AHT10FL,GO93@9)+0(;1Y0G/6[F*7V*\,J
M:,)0QTO%33E\"E/BS<%K788Z.%=$DU[$Z@5>MZR5PR)T-1<LP,@GX%61?)UT
MY3T`%<%).6B&1WAGA[CIU$B6C$%BAEEC)+>W;@GNJ-WDL<\HN2T9#B73?P.R
M<;UZ"Y"V\.#H2)&^^#T2X&C3>J;XD**%I\$5&BTS4L_L-H@[N?(=.07L)^'^
M!8/(R]QJ"Q8U**0VPQG?=+R=FXNTV3BBQX;LHR/+"FI<B3;(EKR*-ZU_<9PD
MDAR+NH7Y:;"(U'H1%V46`^*%+8Z"P_V`W79%LCZBE!%0N^C1YUKC%YTN'1S,
M3'9GM^!.8;X,_<G")"/)VP(OUR.7:91:@O(AZ0DHQ&AQFC&\BESB>.U:*K?B
MF',]:D364+VNX[._&L-GHM2CU)%#/>MD/CJR$^^?G\$R]Q8VSZZ9Z$AC28G]
M@3W1TVFH+0YG6ED>1;;2#&MR7338R^<H8;WQ7"I[1Y$0]#9"H052T]IF*V=9
M.L=O:CG+I@/3/`#[Z?AXR;Y+46"\LV6\$JZ$&E6Y-G+L7J21ML\ILL,TLL2G
M&,@=O'!+,D?$%U%XL]&]!*;9P.K'*6AD-L$][*TB/L[BTR1"<2GL23M@5&DS
MW#=LAKTQ&R/:;7HO]_#XT]A>B9!@J8G[O8>1-B!+X#\(+A%<PV(+4-9D0WPT
M!;4G-L2QZ<$)6G?]A$44S+M8$C4VF6&R?`@KFOQ)S(=H86&TH)[ER.BV(&1X
M$DV,I1B-Q4+E)]PP&H:8#WN?N_#%HH_3_I"9U.%#9(T5:W<BR9RDL:[H;>#8
ME(S9T&S8D-IOZ$N6K6I%AB=G)%M!,%M&J5:9#EZ+0\1OHQR>_)QUD$I!QPX/
M&<=,386<#R81$DE),+IH&B&CD2_#7<R>'70*$AYZ)>H>3O9H-I:;QOU%;LV`
MJ]5V&?`/ZPLQ-YD2)_<+*LLRX%$6K-ECL=SBRR#^$G,A5QH*-1]AB),GBUZ!
M61^',^1DWK(@K@7.)3TTZ,R.Q,E39)ZLBY8U+3U$Y$!KHY&016S0,#K_`*_C
M8LXX-/\`1&R8DV+M$YZ2>1LDD6)'&BLFH3$8-!BIB8,#+HZ$+HPIB-9;";D!
MM4EJ]?Q0+3E,?Z(;OKANB%JQJ*6(3(E9%XH<B5R221(X]TA/B2.IHW&49BCI
M=@D(A8U)34;I@C\<$9DI9;`VQ!#;<D@4$EH6]$-Q*^F(T&-31#P*IT&=I,U(
MZ2S:="8EITMNV$$P(26B_+A`_1)\>X;TAZ/LR!DQU&DT+3EY-L^1,T+R;7J=
M`W/4'^P"R%Y-Y&@2%0:W<5WEPQ493C0?^!KVG09I5L@AC97!AOL3(AM]O]GV
M/[.?]]SZ?]'!^NX]KZOV/_8?L_ZT_P"C'+'=2_T/;GP_VL?>L9_^,TGD@C^,
M=(Z00-2O_F?_V@`,`P$``@`#````$/.F=KQ;CSGR0_&'?//*E/MNN#\.&BPF
M.///*C!-`XV,1Y^NE9///,>%G#)4.94),H,///.H2)O=,##,.]\/////J(&'
M(7,.8;W:%///*M"%_420>N-\.////+M)/C/,+,)']%/////@)&:%$!1'*'`%
M///.B"!6*$PV$"%-////%H",2=(T^+$,&%///`(!#=N&`&#N&,-///%2#-+A
M$'$%D9`%///+*/*@&.07#+U((?///(.%U'-IJ&$R.!////`.)+8)]]#;%.-/
M///$S(`6&/(#=((_////&(V'005`/??E//////"0A--'>LH]_////////'/+
M'+#+//////_$`"`1``,``@,!`0`#```````````!$1`A(#`Q87%`0;'_V@`(
M`0,!`3\0%&D&A*CT/\/J?8^I]SZGRGV$8W90=M\1-8/XK7S+"JLTZ`)?A>1^
M\5B5Z52#,3G#311<0HQ3(-/D&+!*IS;&EK,3$)%XBWC_`$.O!\@A!HD;17@A
M,%R(21B272$>(BLK(+1'A](*L018JZP(B8C-XA%U`9$Q1'DYS/'`WBBL;-\S
MQU)S/S*C\XJ*L5%9\<TY$(^BDRJQ&1XJRIXXZO"+*R\0A1!<?[A<J7IGL@*/
M<*4J)+@C8M<Y2I199916"2_C?__$`!\1``("`@,!`0$````````````1`1`@
M,"$Q84!1D?_:``@!`@$!/Q`E4$W*3IHC^G@>1Y'B>T]9XC9Q@@(B40=,.Q,D
MH%%<C+D7ZIR0]".=0!Q1Q9,S/0JEA.SC-Q&A%8L&,,+2&(8QTZ+2'2$*1"T'
M8=*!TPZ8LW;!8H6;M:D=,<4Q3F[8*D*EK&'2%3'K*E(II:S%BAZPIR%H2HQT
M@HI"J2V"QEI%@I^00&_F_\0`*A`!``(!`P,#!`,!`0$``````0`1(3%!46%Q
M@9&AP2"QT?`0,.'Q0%#_V@`(`0$``3\0_A)+V_)D?6=$FXZ,WBQWT(/C?9/"
M&KU4<&`&3UFMFNUY_@HKK_"\7+0:ED;?PN7A.(M3>IA+BE6^^)7R3G?L3*HR
M;G,LLL'41?NE9\QHA@+"T+]'ZD+'<2=D(]&I737)#4+ZNRO;CQ'<U!3+S?%<
M187R8]'$IG6TO[SXA'Q'5:Q^]I_QWXB:BNF/X@M'?[XC1JCO(%&!W_1-W'];
M3]'^(-_7XA2VK?WM%?Q/Q!_A/Q"V_?Q&E]\'XAE?MVZSA:%M)JOJ?1LPN2TN
MLL`;M$(,%PZW1?U5BI6`9]"?Q4O<LT(**&;OS&+M%;YJ\MX0$$<E.CI*-)3J
M7UE/+ZQ*V/24FS$8OS=@$I(MU6UO.EL>P:H$;U:!Z2FR[9NWB*=86;<XU<<5
M`O&H0"^72!C/:0;IWN6P`OL4'%=X)(0IIMX>(%-T>DSU]92Z(>\%=JB7PKGA
MN+@.=]H#F+"SR,&TK24#O%@Z`=U%^WUHTFSV1^(HHLU":]660\-I19T2Q&S.
M2,$QMP'??M#&/?:4B##`:[ZHVK<[QU407506](S>66M7B",E<%JTTUVB>8A.
MPK.(V$5<(;^48`JTUK>M0<2((8`X.T%\(HU$#F4AI0RZ&\YS$..4;'OTC;"+
MN%H'0XTB9B!I,5C-<U-P"7"[H"_CZ[G[;W`/S*PE/;'ZE%,L=)0)92UF$ZPL
ML)]-R;O:'O0B"R]QV=I<C.J41U!\;RFU5;US!FRI:]>BW)+"TG%)45=2NHD^
M8@W0-KAO6+U'HOXTF3=?*VQ,-IC2I2@WW-(P!OG2@$TI<4?8=6X7,,H97R;O
M6!9B^>)0M1*U<416/DP4K&WO0?7DJE':Q'`#3Y6:PV86UP[]!FUC84L$#F2Q
MMK*\"TWXJ-8*@4*AMEC*<V*)0NL4L2!5OA"N9=RAT2GVB$J45;IJ)B3N$GHE
MOO+E;J63RS?I+4N%L]CCVFYQJ/`9E@`+B<C68BOG<#!D5='WJ>T,GT!#?M*D
MXKI/QQTTE\TQJ[J(+HF%:/66"."8`==(4C5SU,%+9[&SX?6FV>9!/93?E5_#
MOYBA8M5S9S&3Y'9O!!K"A.HMCK-NYP4].947BX;=(>%ARPBE<``L4M>WQ&.L
MV(0T2WZ10K=2ZZ$LR/0H76H]G0X6Z34+32L5'^+A?=@;5N^BN;$2Z`IO5@W`
MC22="(W8FK<(RTT$\IN](=4)J,T=@-XXUZ.WD:COF4=B'O,@NM[Q:+5>L?GZ
M\(V]</Q!T!$M$^Q*Y.QO0@YR9EJS04UO2/MM4428HB;(ZP&/+T%<+CO<6VEL
M%U_"Y4[&B[_?VA(4>S[W"2O^@$'R\1:U0Z=I9M#Q84-_P!:P@\.)7%F&Z*UB
MT%4#S9]ON1$=&S')SBI["K?`Q&?M%H.5V.Q%$"PM+]_W;8?;U1J.H\^9G/6N
M[MNR,4&2]$U.>T61RW<VC?KAKQCYOQ%%%+PN(&9`M!4KG"Q@%`681-"5$61U
M.O4C5^C$HSO*[8R0\^B7T).)I70$WR5'..[\*^[":IP'</E%=H7A>)9H0'?8
M)P@V4%+R01RJ"6+L::T/2#90T?/F`S&*WN_=\L,!"J0'%0P39UED[82D:G1$
M-EMZ<XYCK9"AH'$9YG!-F:'M7UE=P?>`<8EX._3CM!L[#U<(`:%JK@7^8>2O
M7('<VE&=4]1T@/'%&5'I'*EW.M]-)<?.?-/O!!6ES#NQ34G0G1ED!THH#+Z]
M0/8_[+(A%J\C[)"T!M6E\PO9C<$TBERKCK%6.P&9<$+>X<.T6:RK8C+_`&0,
M\QW9>*S-OZM0(`7M[?7<^&A39",'4#6U/'$0ES:SQUM`@@Z`\;QB0<W8>E;1
M@X'#>$[P<Q:V,?JJB]*5CXT\,+&K-;-XK:HD5BD<@CR3%`:3H[$U&H/2B@/0
ME38+ZP8FB%>WYB!AV;7H;18%(M;U0?9V`:]X<>FDU.LM/0P<?6"[B`X-\DUI
M<W+9ZZ]8V'_S!_,,%U;%T^-_,LPT3]IUETI&MF[J?:%D9V*>/UM\QDI!F@:I
MX9?5:^SV8UE"MFM)9H:!PU_[$NJI[1J00Y::;G)*'AZ`6RW,H'?!T@%5G\QZ
MJT*;Y10LBT9P/WI$[+&'3J=_>-H5;"N/^>)B90<ND:Z])./KS'2!=H;0UE-G
M2.C*$U+@6J+O\04HIW,>\K@DW;">2,KD-V^1B8Z(`UY?E'&X4-5O0_9`^@2H
M?4]ZAAP*\JY2_,3::Q8G$0@\V`>RS/-2X5H2D=BKI$`=[U\7'J,K&&I';P$4
M'&:Q3S&1QU3M]HRC1XR0#I7DJ)4/\8QQ"1Q_0!@JW:CHHRS:4<Z+NCM7,#!_
M<MR@:E0\LTT9<B;1H.L113"KIZFI$-$["HO8WDR>FD5>77VU\W/5ZC[5!ZHU
M4O\`=0=9]Z7D*'R,*DF^0]".<SWKVTE7$`4P:?$NWG*P+T"%V'C0-_VI>;;6
M:6PT[>$19]'N(8$,2X@X^O-O;[`BTP%T'6);/JSJZ-\0>P_9HLX':H42TT!K
MIJPT1<J`9S=TW3684X,1O<)48#![CAZP[08LS=G-[1Q9MK]/5T/6!V2U&AXG
M2?=K]H4-'*/=A9JR*]DV99J<OI`^/IU7N[6[#E;RC:[R]X=/24-X"+TS&E*-
MED-2D:]8!7BHZ=)=@NQ(9!Z1W6:W6"SY*./K.;AOX!EN-8ET%]H4X/L"Y=9@
MZ='*2BEU.I!J3`@\DEV`0%G@3#&CYF*W95IVC4@H%`!N9C""C2[1PSD89;0-
M'<J8@Q@=3)VAMIY0,!.]LUHFSVM\3K"`GJ<,8IR[Q9,L:M+J+YN-%8CI:T`O
MO&K04I2*!/-1`Y%-"*5@,/I"%G0-@V"2*8`4'!L'V@US6Z06)O)Q]8MG;W;_
M`#',L&*YB<D<,`<]8MAS+\/X-DISTHK/X]XP"S+A#C)5\1V"2I;;"T'I%>":
M19L=(>2`Y0W=(`IZ*2\QOYBRM0@6Z5[33U+BZ"B8UQ+$C@3+9>)I%'-'EX.L
M27ZS@JI?CT(]L)RYA/MBU+/08.P3;<2^!N]9H"@H10.`X@YQ*8D%)Y@LS]!^
M9Q]9OI)''E<)+G,JP33>'LPEVB6AZVCUJ*WRZ,7ZH(+AW>7QB$`(;*IZ0PK`
MN^\._-%!W2\EK:^B7?O*&K-P?O*U,<B[WQ$0MUU'EB#A9;V>?@*.D'!MITE#
M:]C5]^8S4*V,I55R5/>5SDM5^=O$*/&%L"*\@U'E#ETF77+V?B<?6'8^Y4<P
M4+3B9MT+B35-%!MFM3M47!WH5C$UMJ](*!=D+LTBH[U>B.,F8*?',53!2.3I
M&V[*4`'QF)K57(V2[T(G`7%,D>\U:3%5KVBY@"SKYV[0F;JVN'E<L/TS7)5&
MBZ/"'%N*&"9?P7*.MZ$V%S0'9AL_C"SYDX^O/I)%^ZIL%FI8Q7&GQG7OCY64
MBSE-[--7$:R``%V+/8@\(%2V0`D.L%Q=(PQ:44AS!^&NWCH;]I4%IKB='#[I
M``RMNGI5P=X0AAS>(/:,TV!UNO:<!RBG;F+W8)Z$)@&@-=/^^($CY@)P"UOS
M%,A8F3-4;<^T)T%JH%-@TP7Q4S3G5DM"MXCVT#JU\?PPD*>S)Q]8OH+](6JQ
MAA-JS*Q*33%N=8QO&U->DS&\OX=R]$V8#J8!UHW-;2]DP%U055QWA58UXD(H
MXHI=+SI-)8T06,U$H_\`=]5*M:ANH`55@R\&95=8S.D!D:(#E6>8,^(`SDN%
ME-K,HJW7?.\T$X)J=JL$;&&%K5B;G[Y1ZUI"`N1.K>\#(K?/\I<1)Q]9OH"]
MGYB@D+=91C&LH!IE;5B;%NK7<9>&EW&`]:#8'W(.&+K^U0!&89^7/(>8Q0%-
MIRZ=<S*6Y**5HZP1191*RVT#+*!ZTJZTSC2+-!45'I$E?+6O=T=^\Z!585BJ
MJI8^F:]QFIF)S7<]HN=6>=+?B)*LH,]Q9])T>DRX2A?2.%N1;Z-SCZQ?1:#T
M(>!I5[3!]4:QP!]X(8ACIG9>(P[I_/43Y?5&_)9)A*X+S&=V^\!&@._L0:SY
M@T>MD7V`:4!+]G&@L^(2%71:/L>T4%J0,!NH(CT.ERRI;M>,?:-`S4JH[\1_
M6M$-^6/>>:4+[Q=I45#V=Y;K5.M<0X_A+*.#Z3CZQ8]+Z(_$QJQ6IQ-KRRH%
M%AI1:USUC-1=TZ55T*Z;,&LR6N1H8T<Q=#71XN:P8=H!BK03IKLQ"\<@P/P,
M(,"-TS$PYM"H@<$GNPL$GF/^>\`&@163,JC@)VNH-['5*EZV(%4T<M"E7*2R
MY*35%@QG#37TBF<":FJTJT'M'N)Z0OHS1B"\S7Y8@A0W9/H+\3CZ^HQ,:+I#
MQ#>;:%0<2M2XRL].LL:6S@Z'R^8L^X+N@RPT:.D;.JC)Z6O>5V-[[F6P6[OB
MHV^3CEY/6.LK;K?V!O"OFT;A;:GM<OT$(J5KEU[RFL*H:V:U@KKRD:NI;LTA
M%IV^BA)D6P<T1U#OQK4:TW/M#?\`T0,#-S6#TB23J`!16?0Z1#.5`Y;W7&)A
M%8+U*NTHN,7@?,P+LE8=T'Z0V^HGA;\%S!H9)H[RS7V2JY)[#AFIMQUT%L@=
M,KIK;WY=I>)2L@OEFLRB84!<Y=H[@5"JG1$IZL6C.SJS418^"BVM1(5`,[D#
M>)`Q;S3U^^>\.IPM75;OE%.D:P<P:^DQOO*\BXP3=`/%\/2HQ]0H!UUUB)+:
M/9\RQ'00E.AO"G1-;*\N)GO"JJCJ#[![X/NS;ZJCT&A]8-0)$MQ@S20VT>\;
M&Z'G2-VHU]7_`*1LN^"/49K)X?$!<X@P`H'!$"_JF#>STFCD9BIPU#B4W857
MXB-T&E-"ND0%X!X%%#1^=X5;U!=OLEK7JMWXJ/F;OE;;VB'N!^".`_IBO7'M
M%!;"591Z;>)C%R@7%#_KY1^8?7=NA3U*ENW:CX:C@'>+DL5BIWOB/MBJR$+6
MFG:.ZLES`76&W10Y.S2!.W!I+2@JR0/-?("194VKD>A$!,FZ/NN4?I<5\E,K
MJTJ]?^RRU*"U(UE*U]&`$33).*&O>/Z=*/'&EX;V:G(B,GGJ?Q6,5&:F"SY7
MX0_HTANG?&1[0+UTBI>9N6=]$;IZ,#Y>P,T'0CJVH+.:N7+%1U`H;'`[Q#=V
MVNI.D,L2U%1:E&JRSJM+UX-(;8+HN0YS4`\LD9#K0<^LN+@[%[Q)4:982"^&
M>OM4W8VAC`UJC=O1*AM03F!JX%4(LX&17EU8(O+7@BK8X[14NDK!#:T1V!^Z
M_IO=!8GN?FY05S3V)3@BCH%=E[P0@%$9*MN=YGSJMNZW>-XML$-0K!A%WN$[
MR^WHN)FHIG0[$PFJVUK7#WN4F!V*O7+1::C;4$P+;S7F<%"B+COI$>CK`GKF
M4@9/"#Q'7IP^=(E?A06.HZVA8U0PEVJK$"DVK?3V@,P45+`8XP925XS"DJ76
M6@W:FZIN=Z'L3;^BMC47J_P(A!MS$-<PR+:KO?,/6\=Z#O`VE3']"51MM$3%
M<1W;D;556`59CL,/*7N9T(&`/5`1B]\Z(7%GS*;%U:`70:2M2(/0$<=IL!OL
M)4*K(SZ'^R]N=6OGO+*Y&L;<=B-W.EPIT$_V,'_]&WO*T!F+#U;1`?\`I*#@
MZ15*E6TUDM:KK=$`HR,X:S_2[C8W^C=/2-P9J"V+@U:LHNZS`[M!VV])S`_)
M=Z)T"+OD'AF$I4TN7`QL,+RN8I`KBA3N_,HP3JQOV9<7_=U^Q%!8JB_4MCT:
M6HI]GFXF8VC3GE<<SH5VB]6="4P>A43=K57^Z^9<U]T,%X@*LE"D?V+B4Z_T
M@=:"^IKW-8*]<0$?Q&I2`X9E2X%%D:`9MB6N'I%BS$Q:C7F&UFM5<?4N*:J5
MJ?"PLKJ>9CJ=N$!!5X9S:2L5#L)GF/8OO`R7,2$S'<Q49-S+]P_JUUFRCDJ@
MH7U>G6*:5B6P5UA)1;Q*VF(MHT8EQ"[KB*53"&C`$X3>+46&[@V\Q6X!G)K#
MH]MSJ#FH0!;RPUB=3#+-)27B:PB`*FZIT)<$J`JW5_52`:M5FCL.I17:(;L"
MT-KH1U6)<@]X?"U\0JX,5E.8NI(LZT@7>57#+-'$&%=ZLO0A=+],-)AK6/II
M=;ZQK$8E`M26-*-H@)>T2E:B]9OND3)6N7.TKS_64T76X8!2P'(G[,I#JBDX
M?[*0(4I)6E3+H\,I7`/,+Z8`H5@<5YQ/%YFP^\T?+LO-/;2"J6PO"[(-J-KO
M%"F1#>!VC!5)+E+EA;TED%:TX_/7CK#S@&4!H']J'(U5=XF8E%<'`-?%1<A8
M7(>@S<FN=X-3/$'H37N5LF5O5[F+M%W$-KRL!^*CULA]03%Q\E`,(3I*PJ.@
MNKEY\4*NT.AUE9]04?Z_7^^J-6-2)6179U)T;*^VT?>73]MFL#-ZU-7=2;7T
MDA?F1_T4=8^<.V'G"8SF?>!V?W.L_8/F8U^RXBY-O7Y9\0K3]%"\4'M*8UQI
MT_\`%H@>\I$KFW%5M*_BB5"F\)7]('64E(:#OYE'_P`O_]D`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUO8FEL92]D:7-P;&%Y+FIP9P``````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C8Q-0`Q,#0Q-S,V,S`Q,P`P,C,Q,38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````_]C_X``02D9)1@`!`0$!+`$L``#_
MVP!#``8$!08%!`8&!08'!P8("A`*"@D)"A0.#PP0%Q08&!<4%A8:'24?&ALC
M'!86("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#`0<'!PH("A,*"A,H&A8:*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"C_P@`1"`!X`)8#`2(``A$!`Q$!_\0`&``!`0$!`0```````````````@$`
M`P;_Q``7`0$!`0$````````````````!`@`%_]H`#`,!``(0`Q````'T>NXW
M4RR39:IE50SI-C.AV&4$EP><9E.V,D6[.*YUSHEM9-6V,<R(H8'H!$LBAEAS
M*2K*RJ*HRRHFM0GH3`]`4!T,42C+SRTU;+0T54KIS=RD71=E4DHF!8BR6)04
M9H[:7,/9/FKEL6IZ(6Y=.=9CM)I-$(PF:11VTU.G-(F%<NFNZ8*H5,<S)FG2
M63"72B*FV$OFMNE"H:Y.AT9'CL*2;6'&QL*.DBMIMI=AMVPEM9=LEVVVFVTF
MPP[#)L;;;/\`_\0`&!`!`0`#`````````````````6`P0%#_V@`(`0$``04"
MCSAF=@C3(?\`_\0`&A$``@,!`0```````````````3``$2`00/_:``@!`P$!
M/P&'5X*CVX"\PX'@I91__\0`&A$``P$!`0$```````````````$1($`0,/_:
M``@!`@$!/P$6WA$]@]PGR?)2YO'_`/_$`!00`0```````````````````(#_
MV@`(`0$`!C\"#O\`_\0`&Q`!`0$!`0$!`0```````````0`0$2`Q03#_V@`(
M`0$``3\APN:;RYG)OV;F&ER,#>8XR3Y+[YY<]I),Q!&<C.;S.3,SC$1Z<\LS
M.,1$1<CSR9F9F<$1$1$:S/@S$1A$1&,S.,SA$81$,7<9F9F<(C"(B[G9F9F9
MF(^1A@8NZSC,S,1'@9W75F9F(A\]N^.ZSOV[%WUW>YV_<7"^?P-[=\?,_]H`
M#`,!``(``P```!##;WG94P#O\J%ANN(M6T#_`,)+=[UV)S4^H`>OFA%!BNC=
MRLL]N#!A&3E<$L7Q=:(@'QM0N\C_`(`0P0'`0/_$`!H1`0$!`0$!`0``````
M``````$`$1`A,5'_V@`(`0,!`3\07]E++;>PY]@1;,I9;8;8MLEELLL\!'D6
MS/DS,1PLZ),D(OL%DDR2)9!!!9;?3;4DEED$',DR>,LL@LCG_\0`&A$!`0$!
M`0$!`````````````0`1$"%!4?_:``@!`@$!/Q#/A""`LD)"3H((7BPLF"3A
M$$'#&9+(B.!"9GA$,6S,LML,,.VPS']2R\/'($0VRRRSPX,-LLLL\__$`!X0
M``,``P$!`0$!```````````!$1`A,6%!42"A_]H`"`$!``$_$$J)4J0C7="5
M<-R":I";F"H:F%#UY$'1-0X%H2@DZ0(ZN;)N&B$\(K<$H(00T8-P::."V;3T
MWT02DV]"5=%41A"(:I")]'6($'2_&*V1Z</,&OP@0B%1">83!!$L*&JDOS!%
M*,()1*JB<$J)3"$QL3!!$/10FH)AJ)\%0B%L59&3<'!H()D^O,-ACJ'1UD01
M$U1Z=P3!JB0>SZ]-6:L0Z3_1:>#8)AJ3^`@]#TT$'MC?</@U9A&0V#=&&P8X
MR/6'`Q]HPS&(%!?<(&&0B_3@8;!MP9!BC#7`Q12C$#=P;")1B+3B8)IB<GHT
MZ,Q185%U1ANEP,QD,Y@S71_W`M"=G@HQ.9*RZ@W<*/8VX,SO1NG7A3X1@FT)
MPNJ448J+Z-PHU*.%1N^!M-^#'PAQ"_'^B<$Z4J+J"=$X-.E&Z<4J0;JA=0^0
MOP4__]D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+VQE9G0N:G!G````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#,P`#$P-#$W,S8S,#$S`#`R
M,C,W,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!`0$L`2P``/_;`$,`!@0%!@4$!@8%!@<'!@@*$`H*
M"0D*%`X/#!`7%!@8%Q06%AH=)1\:&R,<%A8@+"`C)B<I*BD9'RTP+2@P)2@I
M*/_;`$,!!P<'"@@*$PH*$R@:%AHH*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*/_"`!$(`'@`.`,!(@`"$0$#$0'_
MQ``;``$!``,!`0$`````````````!@($!0,!!__$`!@!`0$!`0$`````````
M``````4#``(!_]H`#`,!``(0`Q````']4&VE#VD1266./MYND`V;(,E\F-L8
MRDL-K3W./>D!&+$-%\:-L8VDO+>T=WCWIOH5BP#)<_)4DS26&[I[G.ZSX$8L
M`R9*3-/+4EEMZOISNX^A&*\,F2\C81=);F/MX\Z@?`;%B&C)N&O(&DNYH]C@
M[4H!8L@T9.P1W.RCSKFE`;'_Q``C$```!@(!!0$!```````````#!`40,S0"
M(0$1$B(Q1``@_]H`"`$!``$%`F-0>S!_9[C>3GH,;1K:B%(ZA"!;%O@R.HPE
M;>5T"1U*$G;^P&1U.$C;^L&1U/+1&W]8$KJ,I&W]8,KJ,Y&YG=!E=1L$K@^C
MX$SJ-@KHZ<T?`F=2G"T=4N.AH&9U.7T=5>/$*1U7V+HV?Q[R(>77^%GCJ7-Z
M,X>0`7';^!R[@__$`!T1``$$`P$!``````````````$``A`Q`Q$R,R'_V@`(
M`0,!`3\!3TWZ\"7VL7H)=:Q^@DVL?8DVF=B76F=B76J=N76C2PG;!M?_Q``=
M$0`!!`,!`0`````````````!``(#$"$Q,A$S_]H`"`$"`0$_`4Q//C2;;I3<
M&VZ4O!L:4G!L:4GS-MTI.3;4<@VVIF@/PO_$`",0``(!!`$$`P$`````````
M```!`@,0('%R$5%A@1(Q08+_V@`(`0$`!C\"M,1!=H"P8B>A8>Q%;%;M7WBM
MVK[Q5J_+'X_BM7Y"PFO"M7V+"7%6K[%@^-JWHCA_`B7F)'"/$6RE+NFB.%/0
MME&?:1'>%%^6+9+I]].I&7O"#7Y-"%HE!_<7T(L__\0`)1```@`#"`,!`0``
M``````````$1(7$0(#%A@:&Q\$%1P='Q_]H`"`$!``$_(;'A2@8',?TG3@6$
M]W&AG-$]4:D5'T#M>435"?*AP<3N=3(F6I/V8(D2CN=K(GUG71&%1BMWOPFU
MG51#RZBM:Y$B+=BN[)'(N-E(W-G"'?@CD\7.LS&W$E,]AMW@5NUC0U$I]IAN
MF0K>RHVJ%IGZ;_Y<6&<_(XD)/YA+7N8_VR$R)<\:>J8\+FDR!M9B#<"'I,D+
M"X>T0Q'J,B<9DC:DP[SS_!2R#/_:``P#`0`"``,````0\M,\\UTR\!Z\\8Q#
M\H$R\L\R\DZ_\BA__\0`'A$``@("`@,```````````````$0$2`A,6%!<9'_
MV@`(`0,!`3\0'MT*0FTJ4)@3C5G8XW#?<N-1K[\#E=V5""Z/`7&!/<'_Q``>
M$0$``00"`P`````````````!`!`1(3%AH2!1<?_:``@!`@$!/Q":7EO/406[
M6Z?@&_S@4QC-^(4SC1X8-3II-4TM`"CMJ(R(_\0`)A`!``(!`P,$`P$!````
M`````0`1(1`Q05%A@7&1L<&AT>$@\/_:``@!`0`!/Q#3*G?\C4;E.A":[M_I
M')Y4STP=-<6=E^;C37X3*MCO(OW#=/`^R8:TCV?%RI7(0[YTSP/W'8[P2]:D
M!^EA6^A/;0@&WMJJ)YA@5Q#E';'0P,5J0W-["V(.2!JNP@U)C-<RT0^&.^C-
MQX(*9>?I<,:J=E7_`'O%Y744+G*!B#>MZ.%H8O%C/]0_49,J!Q>M@PW3V4^Y
M1G6+[T&5Z)]3##NI[QMK4[NMO:/4594N6X[(?DF'<@-:V$X6B#:8+/>T?#-A
MVQ_%?X"?P%F*JKBJPI)QA?9+F])[M3FM1LYR=LX1*KJ'(+AW6@^)0IVH^&YF
M_3+KA0*[*+E+(8,Y2\%CW$JIE0TWM?T249E?*-Y__]D`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92]R:6=H="YJ<&<`````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`T,``Q,#0Q-S,V,S`Q,P`P,C(U-3<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````_]C_
MX``02D9)1@`!`0$!+`$L``#_VP!#``8$!08%!`8&!08'!P8("A`*"@D)"A0.
M#PP0%Q08&!<4%A8:'24?&ALC'!86("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#
M`0<'!PH("A,*"A,H&A8:*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"C_P@`1"`!X`#D#`2(``A$!`Q$!_\0`&P`!
M`0$!`0$!`0``````````!0`&!`<#`0+_Q``9`0$!`0$!`0`````````````#
M!``!!0+_V@`,`P$``A`#$````=$2N7(\2N1?%Z=VE*FM5NXTQ0J*C]*4,]*+
MT!D1LDJMW'$KCQ4?T8F9Z4.]<#<):K=QXS(L;_4Q(WT8MVZ&X2U6[D!&1I'^
MI:A=\6_:(7-:K=QX+N=D=$=L.^/TE+A[C2JW<=G-%G96;SFGRUTOJW1Q]A_=
M5NX@Z@3NS55S>K=-&E5N_P#_Q``F$``!`0<$`P`#```````````$,P$"`P4@
M,C0`$!$2(20Q(D%#_]H`"`$!``$%`M?L9)Y8-O(M#]XWV(M+6\B41;QE(ZTK
MQ*(MXRY"LIQ*(B@RY2DHQ*(B@RY2DHQ*(B@RY2DHP]VZ?O%6*4E.'0^H)>4I
M*L/=NG[Q-$JRS#HB-_(1$A:7,]2A^X;P)%R`F>K1$NXZCM7'Q]VZ8SO$(U_4
M-O(N\5O$,!WL5'^.^7AF=1]__\0`'A$``@$$`P$``````````````1`$`!$Q
M,@(@(4'_V@`(`0,!`3\!F#R_29H$%,T04S5!3,(*9@=)GRBY/O.U'+__Q``<
M$0`"`@,!`0`````````````!!!`@$3$R`B+_V@`(`0(!`3\!1/UBB/9@PET8
M,);@PENB.Z(;-$QCQFG_Q``C$``!`P0"`@,!```````````!``(@`Q!Q<H'!
M$6%!46)2_]H`"`$!``8_`ERJP_?5J>(E5Q@V;$JMJ+#,2JN@MS$I^G=N8N3]
M.T%S%V4_3M!<Q=E5-$$,Q=E5L!!#,795<XLV+LJK[=U9D790]DFU/$7*F/IM
MJ>L0W^CX13L*EK`E>?A@\V>J8_,/_\0`)!```@`$!P$!`0$```````````$1
M("$Q$$%1<9&AL6&!P>'_V@`(`0$``3\A:H0@Z'Y<7*%#D82J1YKJ_P`*3L.*
MDT&/E^KPWCO)G::^S*5+&^3,[)RE%DL[_),SL8RUO?Y(SL,92UODL.T*G:)[
MA%Y,CL=@77R]P2\B5W!Y/I:%A]&Y'@Q:GQ%2$#]WW*]K4(V=,Y@5(0%RF@S1
MME=Y`ZOLA80-'DC00Q7=?)CY;9%V:"(_B39J!!,Y?Q?T>#%96A'?))/_V@`,
M`P$``@`#````$-/W_.N-_+O5_.C?_&&?_&0'_#;'_'@'?/_$`!P1``(#`0`#
M```````````````!$!$Q(5%AH?_:``@!`P$!/Q!24^!9'V1B'X7L1B&X0L,0
MO(C$/:BJX+(:DAPQ9#TMD"R/_\0`&Q$``@,!`0$``````````````1``$3$A
M8:'_V@`(`0(!`3\0K*39[#J^):0]EI#W+FEV:.K6&'4%P]AU"(&PPK__Q``G
M$`$``@`#"0`#`0$````````!`!$A,5$@06%Q@9&AL<$0T?#A\?_:``@!`0`!
M/Q`E&IEK'A]'2Y:YO>\>[F*&MR@&ZIV4V!''I!2,U@;^3Y0@U#AN8J7_`*E^
MPR_-5U2A:,ST1M6KCAN;V5/@["8<;BLC*ST18C)'8OL/43&W`\&P?$.#I`[H
MZ?ZBKGS%_1@V*]/<?<Q7RGK,$/Y&C8P/F+LGF8>6]/QLW_-&QZ'Y%>K]&70W
M#NWX3K95Q_2;#P=?DK3N^C"5+:[Y_28^?*N:^(9?G)T?D"OPO,*<SPM]S%SY
M6=R/,,OSB(A32K3O%&E.8T!^V*N:_9T+Y$,OS2KTBKZ#LW^XK%MT[RWH$57C
M+LP6[U5V'-T@T.8]ZEL/*DT4M]QC;6"PBY+>X=@%=P*]H+V%JT2_`P5&3AR!
MA.7)X+^QF<WU[!-;T)>%VAQ3Z*5MTQELW#ZY$<A27QL?_]D`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4O=&]P+FIP9P``````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,3`Q-C4`,3`T,3<S-C,P,3,`,#(R,C4R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````/_8_^``$$I&
M248``0$!`2P!+```_]L`0P`&!`4&!00&!@4&!P<&"`H0"@H)"0H4#@\,$!<4
M&!@7%!86&ATE'QH;(QP6%B`L(",F)RDJ*1D?+3`M*#`E*"DH_]L`0P$'!P<*
M"`H3"@H3*!H6&B@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H_\(`$0@`=0$'`P$B``(1`0,1`?_$`!L``0`"`P$!
M```````````````$!0(#!@$'_\0`&0$!`0$!`0$```````````````(!`P0%
M_]H`#`,!``(0`Q````'ZH```````QTDA$V&]YZ```````````&%#N7U9SU?N
M6VFGT5-IHB;]PSULD;JO%O0])\[]FOJCYKU\U=C-```````0==-4Z8.B%<82
M9VNIV>4&O-O(^F7E1\Y,,F;^;A,Z^MT6VS5;+.H;<]Q\WRB_IR%-BP````$'
M?`V8W,6='TC.9XJ--+J^CQTC6>EEY8X8&>&LQHSUZYFD[SG63=O/W]<Z^9LK
MR1]"X;9'3OF.46```-!"V:.?N**QPRZ<LH^^,5/<_+>ICKU'E*+GRG]+;"KP
M+/778%E$C\T>]917E<\O<,MS3@LIN_O?G?T3GT#-``5%OS>S*XKJ.4Z\YK'3
MLR?-&D@\]VL'-I+>IKIOJ_.:D%Y[1XE]!II1A,F6FSYM\RJ<_<?69>XLJ#]'
M^>=?'3H1%@`.+[#A+C?6R=%\T.=,Y=*"+U^7E]/.RKC.=IH_1-<A&[ECAMO:
MF\O+O/"D\N\2H\MQ3Y6NCKQA8Y1_;Y=UM!\CI]"'/H`!&X8Z<\=1L66T^']A
MZ3>61L^C=]]-SP#PPQ,8C-Q&;%K3Z_RYT$[\OIPY]0/_Q``K$``!!`$#`0@!
M!0`````````!``(#!!(%$1,@$!0A(B,P,T`5)#$R-%#_V@`(`0$``04"_P`\
MD!&6,+O$*$C#]HD`37H8D[4Y)">_R)T"+*86%%<-<IL$X7>-0KJ'6@H;D,WU
M"0T6+[6(BS93Y*=<F_9D7#/*A1:A4B"[K$C3B*-$("Y`C<R38(9E'?M5'5-0
MAL#Z$T[8P]\MI\LU>DI'6+CHJS&(`!%P"=.QJ-R(+OL:%N(H2M*!W1`<I:;7
M(6)H1W<.;0U-T:BE;*SW;$^*;&9C=O[J"L&]DCPP37O%E34+*9H+BAH5<(Z+
M73]"B4FD6(UG;K&O=#TUP<B`X/@?7D;QWFU;$E62K8;89[<\F*9%D=2N&=\$
M(C:II1$VO!-J4E6C!5;TE$!RNZ:UZAF>Q\3Q(U6(#DQPNPUY75I8)6S1^S([
M!K&9+6+7$RM$(VHG%I:;EZ)K8H]UNLEDMUNB5NB5JU</CHR[]FZF!@EF:V:+
M3K/#*/$>P_U)K$H@AB#I9NRP[%FC/#+N:Y%R+-9+)9(O62R4\@$-'XNS]Q2/
M%-8;@_2Y^2+KE=A'66MS;O:,6]EAG)`\N:^M=$S.1<A7(N5<JY%FLUFK=AUJ
M2LT9=MD'";::'39N*QUW7*`^!=S7>BY7.0:<H[NQ;*'C-9K);K=2W(HDY\]L
M01`-B8(V]%+X'>2:J_D@ZKCO5+^.E5&T2DD#%&_,<[,6/R%BHR92Q3,7'#NT
M3K>Z%E>*_6%&,.44;`F5W/+6A@Z:_EN6QL_1WY0=5EV[]0=CIS?!BL;;,Y70
M8'&N'8[%;%.KM>G:<UR_%K\84W3$VD&H1%JQ>N-RP<L3T?QGO!:&_P`W2\[,
MF/FU0^FFM+BV(+$?0(!3H@41L9SZ5X;C1G;6>FQ\+_EU+^PHV[,^G8'A-XPS
M^,.FG:SV_P#_Q``D$0`"``0&`P$!`````````````0(0$3$#$A0@(5$$,$$R
M0/_:``@!`P$!/P'^5NAF,QF,QF%$5]+B^(;+BA,IE,I83[$Z;VQ\22VM#5!,
M3INK]DA,J5*E9127*(779$^!VFG2=).+J<-R&^R.PS#P8H[6%X;^LT:[-(NS
M2+LTJ[-*NS1P]C\-=D?B-*L/(E1\BOLQ!W1A\0^KR?VS[/\`_\0`)!$``@$!
M"0$``P````````````$1`@,$$!0@(3%!43`2,D#_V@`(`0(!`3\!_E2D_$@@
M@@=)'Q5/;$C@;)))P@=.M(2G!O4AH:G5&\?%8,:T4K<7.+6,X)8LJT4<B+6W
MHL^>1WY=(SS\,X_#./PSC\,X_#.U>"OK[11?$W%6Q,J4/C10+LM-ZOE=/T6C
M_\0`.1```0(#!`@$`P8'`````````0`"`Q$A$C%!4000("(R87&1$R,P4D"!
MH10S4V*QX31"0U!RDM'_V@`(`0$`!C\"_M]2JO;W7WC>ZH]O?XJM%?-2@0R>
M@6\1#'YBO.TQHZ+>TIY7\1$[K<TPCJO(TICOG);[2X=U*,R16X\=#\)-U`MU
M6G'PV>YRQCQ%*"P0V\E.)%<MXS5RN5RW'$=%Y<4D<U+3=&#OS-O4]"C2=['*
MQ'!ES5]EWP.94F=\E^-'4XCB&Y!5"H%4A55X[K#NKQW5"J&:J%-ALE>'I;?&
MA?4+QM"?:;EB%8BU"M,,QZTFWYHEQDP7E>!H0DW%RFZI5%52ABT50>&WG1>=
MI'^H57Q3\U*<3NMR+$'6JG!C!WT7GL,L_P!U+'(JBDX+Q=%,CEFB6BQ''$S5
M-M^(]2RWB*F[A"^SZ/1@O(UDDJFY!&*\MN]BXW[<B)A%T#==E@58B4>,2IXX
MZA%@FS$;<472LQF\34$'-]*:M.O*$""=]U_)<]1*;`:=T<1_5-9#$FBX>EXK
M1OM^H33GNG6-(@WCB&838L/A=52=PXJGHRP"<\W`)T:+>3K;_D/U42U>1+7?
MZ#R<E/-XE]=AVCNX'[S>JFK)O'H$KJF0&]2I:W-7C,HX'>Y%<\1Z0@0*C$IK
M658S',XG8#V<;#:";$;<X30G=<?0:WYHG)18F`,AL^+"%<1FIP"6O]F*E&!!
MS4VD'IM5=:.07X4'$E6((-DWNQ=^RELQ(1_INIT.IAY;9Y)[^2&9U"A)-P"N
M(E@4XB9LF5%.1'53%'9KS&B*WG?W5"^$>87EZ0Q_S7`T_)?<M[+><QG8+SM*
M+N3:KR8,S[G_`/$#%,\N2IM2PB,_1`HC([9.94O=1#4VTUQ$[VWA/`)G/=+K
MY*('L(;:'`G4=*>[:R5Q5Q56?17'LJ3[+^97'LN$JC"N$JXJXJX[$!WYI=]3
MAF-H]-6CLYZJ*M5</@*A;M%(J?M(**;SVG]$%`'+4/A`4_HFG-H3.NQ__\0`
M*1`!``(!`P,#!0$!`0$``````0`1(3%!46%Q@1"1L2`PH<'1\$!0X?_:``@!
M`0`!/R'_`,_1`[LT9^$$_FFKSL((Z(_]-Z8.L`;OZ1PY[D8VRZ/XB9>B%9JF
M=$/W%=`\)>S71<R_"F:&</W,(]';R8A9D/0?^1P@&[#4S=EU>Q+#JMKV(\&M
MK>E]H1>VE/Y%5I>PU\36V.N9@'T/B4+EGJ29P)LK)6J?!4./7S3"5`X60043
M9</G_A="]'CO,MT-=D,4?*#+8EHU$%,C`,1-!G3>:D?./F8#W3.K7_>(Q1X#
M#K0[G[@BP'1N'43XC]X=$:@O8]IBZ,>5&_-(D"CBG4[0L-/O55^KA-6-DWB-
MJ6"-9NFY5RL`"A1%BS&MN#NPLHF`+#P&69X7W?Q,RI4O<_:RDO.P_4881V_R
M,&U[(MZULVYM*;C](N)]@^'>'J]-1U)4`DNE/79T)&$\_DZD&Y0ND=&`<0\'
MW&R.IP3+%9%8\576\Z0<`7"V%0*U=^QUB1:O.WL<L)4O4%%QZ*12XP0Y$FHF
M(-_GSQ+W+:/@>G64D(,!V8.S+`F6'Q*8<#K<G2/`X'W(@6';A^T;K78Y8NX2
M/0P9&R"U,M6$QI=&#EVC:;&C@U?[I!R%H":]8F(N/&9QIK!VC9]!'C%M04*_
M)0P^UGB.L*;0)-L?,1(;"CP\1K)M@?N(!5CD?LJLNU_95484!1VSL;$>"'$9
M%T5L`>%9?>%]X@W]!+*S?F)Y@;1ZX]<TD1S3V^R%I>"7,(.C+':ENVXB@<<S
M-]Z?;['.58[S`5UP_L=IE?&2@'F7+95&J8[P1I`#_%.L*HT2#<U]*YOZ'JCG
M=QOJRRZQK:OF7!HXIA,"C_`,4=HL/11&`O4FT!B-=4GP?8IH[H5BL([S?@!&
M;>ET0Z$TIS!X8I&&5.';DCD98II*PWJN68)5EUU8.6J]#EA2!W5B"@#54>7]
M2@!@<H.#C\F"*%])J^NI7.)U$OY!^Y[EFZ*T>Y]=O#A+*=&Q6/(LN`A0T#*P
M%;:I"D9<D`NEV].9V!J-,Q9O`F-`;X>Q^XI;O\/<_D"8C82OYS#XU_B;0/..
MT_5H]X[F=[?CB(Z9NW^'[8N>FAT[`P2B#S+5A!]"*W<#RK^%E`2U^3W^O.6I
M*'D/<PT.GI=1#=:.N(;`""UW/S`P`4LK@-,9(:RVZ!OW9UN%^/8F.ECM-8[Y
MM-./RBC0>RG*+PP!MEKF^N2`4;Q'_P";-W\4`_E*-2\>@PBG`E]@DK%X9_BF
M/JL/"98#EG>%T[$T#I*`//$'J5[2O3VI7&(2I7H$J54K'IM*E7Z$TP>Y,ID_
M$1@I(PCJ#X1EQYR2D]1]2KO([[\[(/\`4=8%3?U-)QZ;0^MF\8S:;0.==3!]
M?Q'?:_"F(\?GZ/_:``P#`0`"``,````0\\\\\\\T\T\\\\\\\\\\\TRHDT0`
MX\\\\\\\\0P<P000LL<T\\\\\L,\(LP-I(4(LT\\\\L4L0P$0D,@4X`\\\VX
M$(<\\X\$XD0<\\\T(`L(0P@($,($<\\\`B_\!``@`=B\@`\\_\0`&Q$``@$%
M`````````````````1$`$"$P4&#_V@`(`0,!`3\0Y(`````````"&H```5`$
M`P)@(`(L8A4A5__$`!L1``$$`P````````````````$`$2%`(#!@_]H`"`$"
M`0$_$+@`'@```````#W0`H)B6S&!`@AF343O8?_$`",0``$"!04``P``````
M``````$`$1`@(4!0,#%!46%QD:'_V@`(`0$``3\0R-$(D0I=A2``]!26.(1@
M0($`@````D$0*`!B`=$!0H*B!QH"E0"`@4)`0`%`0!!!`4`!%`("@V*``+&`
M`,"(WFQ(*`!"0!`0"D*`A`!`!0```*$4```H``%`.0`/PB%@H:((@`1`1(``
M```$0```)`"$`(@*(```0``(`0`"``0`(2`4$0```$J&H`,]A;"`@`A`*`"`
M``@``4)``!0``$2%(0``````("B%!]H=S8TPA`-YD*",```A`%,0`$T@````
M!`#`!```"B0!2&`]&$D`Y$)@"0```0A"```````4@`0```S(`(6$$_0+````
M0`@`&!0(@"`@``````40`6,``")@,B```*K%=$`0```````"$````*$`````
M`$!0``(0@`````1`(5%F`'NY`,"`````````$@``0`!1""0`!`"B``0"`2`(
M``$``44`!0``!@"`XK`P$$,$`*``!(``))```2```2(A2"D```$"400(,4*(
M``H!`;APZA"`F`"`(`0```0!0``(```A4"%A!@BAOS*`@!1\D0@,F0$R:#)H
M`F0)`SHH^E"X;%`^[B*&.X2#_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VYA=B\`````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,P`P,C`R-C,`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V)O='1O;2UG<F5Y+G!N9P``
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#<S`#$P-#$W,S8S,#$S`#`R,S(T
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!14$Q410``!5-3
M4W=W=X&!@86%A8V-C924E)>7EYJ:FI^?GZ6EI:>GIZRLK,/#P\3$Q,;&QL?'
MQ\C(R,G)R<O+R\W-S=/3T]75U=;6UM?7U]O;VTM+2SAO354````!=%).4P!`
MYMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%
M!]0,%!$O.'@*D.0```!C241!5'C:;8U7#H`P#$/#"'NT*:/D_@<E!5%2@;_L
M)\L&$/$MB.+=CG6EP>H(2PTV,BGP'V#M"\*^-V'C.>*.%AE%S&.G)2*5`YF=
MS@!9/R59.DV:A2BK=8%#/FB06RSXIW$"H&L)@<Q6X!T`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VYA=B]B;W1T;VTN<&YG````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#0W-P`Q,#0Q-S,V,S`Q,P`P,C(S,#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````5%!,5$4````(#1$J0ULS4FXW67@_
M98A%;Y9)=)Q,>:-0@*U;B+)?B[1GD;B1L,R5LLZ7L\Z:M<^;MM"<M]&>N-&@
MNM.DO=6OQ=JRQ]NUR=RVRMV^T.$````4M"1X`````7123E,`0.;89@````%B
M2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01+@Q`
MI540````9$E$051XVFV-60Z`(`Q$ZU+W!0HNR/WO:=&()?J^.B^3#@#C;R#B
M=SW6E12K-5A*L9%*A?L(K5\1_CM%+)XAWYG%$B+FL=,2D<C!S%9F@*R?DLR=
M)LULQ"FYQ,$;-/`L%OZG<0+$^@G-P?I?#`````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]N878O9&]W;BUG<F5Y+G!N9P``````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`T-3``,3`T,3<S-C,P,3,`,#(R-S`P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P```$A03%1%````4U-3=W=WA86%C8V-E)24EY>7FIJ:GY^?
MI:6EIZ>GP\/#Q,3$QL;&Q\?'R,C(R<G)R\O+S<W-T]/3U=75UM;6U]?72TM+
MM7`.]0````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+
M$P$`FIP8````!W1)344'U`P4$3$!\TXG,P```%E)1$%4>-IC8"`*B$,`DH`H
M/S<;*[*`L*``"S.R@(@`'ZJ`&(8`/S]"`&2^&!_(#)A%XIP"0D!#65B8X&HX
M!`0$D/@@$5Y!9#X#`R,7#PH?J(9='-T[.#T*``^-!6T2HQVW`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V1O=VXN
M<&YG````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#4T`#$P-#$W
M,S8S,#$S`#`R,3<T,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,`
M``!+4$Q4104`"@@-$2I#6S=9>#]EB$5OEDETG$QYHU"`K5N(LE^+M)&PS)6R
MSI>SSIJUSYNVT)RWT9ZXT:"ZTZ2]U:_%VK+'V[7)W+;*W0```(9?Z@<````!
M=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&```
M``=T24U%!]0,%!$P$QGL9SH```!:241!5'C:8V`@"DA``)*`&#\W&RNR@(B0
M(`LSLH"H`!^J@#B&`#\_0@!DOCB?`%``9I$$IZ"PD``+"PL37`V'@(``$A\D
MPBN$S&=@8.3B0>$#U;!+H'L'IT<!*N<%G#41(%\`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]F:7)S="UG<F5Y+G!N9P``
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0V-0`Q,#0Q-S,V,S`Q,P`P,C,P
M-C8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````2%!,5$4```!I
M:6EV=G9W=W=Z>GJ!@8&-C8V7EY>9F9FLK*S'Q\?(R,C)R<G*RLK+R\O,S,S-
MS<W.SL[0T-#1T='3T]/;V]O?W]]+2TM"F7`E`````7123E,`0.;89@````%B
M2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01,@RF
MT@A-````9DE$051XVH6/V0[`(`@$[:$]Q-J3_?\_K8J:U)=.0@+#`XM2+0!R
M4\2#O"B"4@?^"K"'(`)\G-=]W7X1`:;=.VO=.H5A0<=N(R(7F(,PH0:3T2*2
MZ2-C%M'4*T9R##6';I.VO_SR`NZ."&10MEC>`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]N878O9FER<W0N<&YG````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`U,#8`,3`T,3<S-C,P,3,`,#(R,3$V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```%=03%1%````'"T]*4):*D-;+4=@
M,U)N-%-O/V6(276>2WBB9Y&X:)*YFK7/F[;0G+?1GKC1G[G2H+K3H[S4I+W5
MIK[5JL'7J\+8KL39K\7:OM#AQ-3CQ=7D````EC(2%@````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4
M$3$6<)VB]````&A)1$%4>-J%C\D.@"`,1-UQA8J*BO/_WRE2))&++VG2OAXZ
MS;(4`*%YQ8FP>(7T'>Q7P&HP+&#7S1QFUP,+6+EHFB8:6S?TR"^:E9+DZ)P0
MKDH1:%AX4SQ403PF7A&<HXPYZC1I^LLO-_%,"AQ[;Z;K`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;F%V+VQA<W0M9W)E>2YP;F<`````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P-3`S`#$P-#$W,S8S,#$S`#`R,C8W,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```!14$Q410``!%-34W=W=X&!@86%A8V-C924E)>7EYJ:
MFI^?GZ6EI:>GIZRLK,/#P\3$Q,;&QL?'Q\C(R,G)R<O+R\W-S=/3T]75U=;6
MUM?7U]O;VTM+2W.6.@0````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP
M2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$R+>J[&!,```!K241!5'C:
M?8_;#H,@$$31BBU>86@5Y_\_5&"A#Z;V)&1W3O9A4.HW+(.L0A8>7S'DC6"Z
M2L"PBOVSA1#>,$T1S@/.>JPC1<RPU@'PRXN<HGCJ0AN#CJ_O$CF+$'+.HO1H
MI8>^-GWP[B]_.`&%:@F!_@#I/@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]L87-T
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4P-0`Q,#0Q
M-S,V,S`Q,P`P,C$W,S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M````5%!,5$4````(#1$J0ULS4FXW67@_98A%;Y9)=)Q,>:-0@*U;B+)?B[1G
MD;B1L,R5LLZ7L\Z:M<^;MM"<M]&>N-&@NM.DO=6OQ=JRQ]NUR=RVRMV^T.$`
M```4M"1X`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,`
M``L3`0":G!@````'=$E-10?4#!01,A2UOI`;````:DE$051XVGV/R0Z`(`Q$
M<<%]@8(+SO__IT#1@U%?0MIYZ6$0XAVD`5R"%QRWZ.(&0K@*F!:7V-?-.;=0
MFR6A+9%6EN8>+$:CE"8B.S7`X$4M$[D/TK^J#,3,@HDYBM0CYQ[RV;3`UU]^
M.`&QB0G-5`N:OP````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&5F="UG<F5Y+G!N9P``
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-#(`,3`T,3<S-C,P,3,`,#(R
M-C8T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```$503%1%````
M:6EI=G9V=W=W>GIZ@8&!C8V-EY>7F9F9K*RLQ\?'R,C(R<G)RLK*R\O+S,S,
MS<W-SL[.T-#0T='1T]/3W]_?2TM+!6U78`````%T4DY3`$#FV&8````!8DM'
M1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$3,0J\AE
M0P```%9)1$%4>-J%CTD2@#`(!..^!$1-PO^?*E$X&$OMVW11##CW`I>Y$)RX
MR,07EK<]Q!!I8LVP$GJ/\W"**N$"`"B,.M'T2F<[Q-29UKK$W%JR^;OT^<L'
M!QWK!4V>PL-)`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;F%V+VQE9G0N<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-#4T`#$P-#$W,S8S,#$S`#`R,3<R,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(`P```"@M#U,```!.4$Q410```!PM/2E"6BI#6RU'
M8#13;S]EB$EUGDMXHFB2N9JUSYNVT)RWT9ZXT9^YTJ"ZTZ.\U*2]U::^U:K!
MUZO"V*[$V:_%VL34X\75Y````"BH+NH````!=%).4P!`YMAF`````6)+1T0`
MB`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$R-F#>T?\`
M``!7241!5'C:8V#``231^6@"DN*2:'P!20B`\86$1<1$1`4X):%\'D$!/FYN
M/BYVL`"C!!\_+R\/'Q!P0%4PLT$!*\P,H`@3"+#`[`**H-@"$B'D4DR_X`$`
M;?T%U@-5])4`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VYA=B]R:6=H="UG<F5Y+G!N9P``````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#0T-P`Q,#0Q-S,V,S`Q,P`P,C,P-30`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3````2%!,5$4```!34U-W=W>%A86-C8V4E)27EY>:FIJ?
MGY^EI:6GIZ?#P\/$Q,3&QL;'Q\?(R,C)R<G+R\O-S<W3T]/5U=76UM;7U]=+
M2TNU<`[U`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,`
M``L3`0":G!@````'=$E-10?4#!01,RIMQ+SQ````6$E$051XVHV.60Z`(`Q$
MZXY;&5S:^]_4B(`):N+[F]=)ID1?Z$/D1GN];QZ8:'1?-Q%98(H@K`,L.\S#
MU=$1S!:`FSIOM*T#96@TU4G*<27EN)7EET_I+P<O+05M)ZK3U0````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O<FEG
M:'0N<&YG````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-3,`,3`T
M,3<S-C,P,3,`,#(R,3`U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P```$M03%1%!0`*"`T1*D-;-UEX/V6(16^6272<3'FC4("M6XBR7XNTD;#,
ME;+.E[/.FK7/F[;0G+?1GKC1H+K3I+W5K\7:LL?;M<G<MLK=````AE_J!P``
M``%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8
M````!W1)344'U`P4$3,:2QV,70```%E)1$%4>-J-CED.@"`,1'''C0ZXM/<_
MJ1$!$]3$]S>ODTR5^D(>(C?2RWWS6!V-[.O&S`MT$00Y@(S#/%P=&:TQ!,!-
MG3?2UH$R-)KJ).6XDG+<RO++I^HO!TKW!9R9EHVB`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W1O<"UG<F5Y+G!N9P``
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#4S`#$P-#$W,S8S,#$S`#`R
M,C4S-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!(4$Q410``
M`&EI:79V=G=W=WIZ>H&!@8V-C9>7EYF9F:RLK,?'Q\C(R,G)R<K*RLO+R\S,
MS,W-S<[.SM#0T-'1T=/3T]O;V]_?WTM+2T*9<"4````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$T
M"8#B6T0```!<241!5'C:7<_K#H`@"$!ANDA9D)4F[_^FT5H+.?_XQF0"B`TT
MN4B+J(47_,9;!VU2Q<T\2#/3AD:D'COA+U+3F10^>:YE)NS-62DK*YA'LX?"
M#M+B($YS&"V8G]WX/@ADH<52L@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VYA=B]T;W`N<&YG````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#0W-``Q,#0Q-S,V,S`Q,P`P,C$U-S4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````5U!,5$4````<+3TI0EHJ0ULM
M1V`S4FXT4V\_98A)=9Y+>*)GD;AHDKF:M<^;MM"<M]&>N-&?N=*@NM.CO-2D
MO=6FOM6JP=>KPMBNQ-FOQ=J^T.'$U./%U>0```"6,A(6`````7123E,`0.;8
M9@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4
M#!01,S,)KQ0Q````7DE$051XVEW/20Z`,`A`41QQK%CGROW/*:8Q4OZ.%U)2
M`-:!Q)>3.I2J"'8CED$:WYS.@0I.9C>C$@[K,N$O'/SF!3YYK^WD,%=G^1Q)
M0#VZ6SC(@!\,]$U;EQK4SQ[][`H<;.]B'@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]N878O=7`M9W)E>2YP;F<`````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`T-#$`,3`T,3<S-C,P,3,`,#(R,S4U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```$503%1%````:6EI=G9V=W=W>GIZ@8&!C8V-EY>7
MF9F9K*RLQ\?'R,C(R<G)RLK*R\O+S,S,S<W-SL[.T-#0T='1T]/3W]_?2TM+
M!6U78`````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+
M$P$`FIP8````!W1)344'U`P4$30B+%ZB!````%5)1$%4>-J-S-D.@"`,1-&Z
MU8U:%9C__U0QAHA-2+Q/S$D#4:7&;$28+1T^VVU<".*Q.WX%44]-D`4I+X[;
M^Y%OPBH)BD^]A2`&=#$PC]/0E_!$_[H`QWP%3?LQ$R,`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W5P
M+G!N9P``````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#4T`#$P
M-#$W,S8S,#$S`#`R,30Q-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,```!.4$Q410```!PM/2E"6BI#6RU'8#13;S]EB$EUGDMXHFB2N9JUSYNV
MT)RWT9ZXT9^YTJ"ZTZ.\U*2]U::^U:K!UZO"V*[$V:_%VL34X\75Y````"BH
M+NH````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!
M`)J<&`````=T24U%!]0,%!$T$9..PQ(```!7241!5'C:8V#``1C1^)(2DJA\
M<3YF210^#S\;DHBDN)`@+QM"1%)<0%@`*``3D00"$3X>-B80`Z9&C)L/*(!D
MJ`BZ@"@?FH``%YH`)SL'*PNR``0P$`<`#LT%UGZM[G(`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,P`P
M,C`T,S8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M=')E92]R978M<&QU<V]N;'DN<&YG````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,#(P`#$P-#$W,S8S,#$S`#`R,S8Q,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%````!0(
M`P```+I7[3\````,4$Q419"0D````/___P```+$OIH8````$=%).4___``#3
M#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@(````````````"`@("``("`@("`@(``@("`@("
M`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`0("`@`"
M`@("``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`0("`@`"`@("
M``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("
M`@("`@(````````````"`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("5R("U8/XR/``````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O=')E92]F;VQD97(N<&YG````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q,C<P`#$P-#$W,S8S,#$S`#`R,C0Q-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(`P```"@M#U,```&`4$Q41?WSU/WVW***5/KDL+^$.\*-.G9;)+^(
M.O?KR^SFVJR69L:4/N7<R_?=G_3FP/OHN?SVYJ^:;//0@_#DQMW">;ZQF.7.
ME.'4L/SLPOG;>LF[H-"^F[^%.\"*._;NWN/#@JZ??Z6-6)^'4-?)K/;9EN#3
MK\^M5<.0/-_3O8QK-'=5(NWGW<BRB*F38<&+.[JH@M>X8?G;>_76C-#%K?CA
MJ.K9K/O=?7-8(__[\<.1._SCD/[WY/SIJO[OP?_UTWM4(OWPRZ"&3____P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%*X3_X```!#=%).4___________________________________________
M_____________________________________________P!!8@3O`````6)+
M1T1_2+]QY0````EP2%ES````2````$@`1LEK/@```())1$%4&--ES]<:P4`0
M0.'=Z#U!=$%$%YWH:[S_0YDA@R\YE__=$<]`(@QI`'#_8%F54@Z,'_22`@-*
MVQ+`XUM>>T.MDSGYJ;B)4!CI1S]KYB%$8A>NE"+8+>[</DN0:]^XRIC`25RY
M<I]@TSISJR:"78S6#Y_6PSE"`R:*FWK=\.T+K[DUCU88@X$`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O=')E92]F;VQD97)O<&5N+G!N9P``````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,S4U`#$P-#$W,S8S,#$S`#`R,S,P,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```&`4$Q41?WSU/WVW/OHN7-8(Z**5,:5
M0L2YH\2,/??MUL:\I[JEBN#!AX=O/=BL4_/OY^C4H?+4DOCAJ*F38<K`K9A\
M4IR"2>#3K]O3PJ64;\RM7OKDL*6-6,:60>ODU9F#5/OKO_C:>ZR69H%I,\[!
MIN#(A8UL-/7MV??KR]ZW;>[@OKJH@IF%6?3:HL61/X9M.MJM7_3FP.'4L-#%
MK>/"?]FO89ET,Z^:;/;<C?_Z[<*0.__RR?_VW/SEEOO>?OWJL/WPR_SLPGM4
M(J"&3_______________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________P1"A,4```"`=%).4___________________________________
M____________________________________________________________
M____________________________________________________________
M______________\`.`5+9P````%B2T=$?TB_<>4````)<$A9<P```$@```!(
M`$;):SX```!Z241!5!C38ZA'`PR8`LP@@"3`;,C(R"C&C"2@S@`$S'!U#,SV
M<&#`#!9P0`"(`!.3L8PE!#@"M3$P2^FP<EA`@!J?.`\#LZ`)MS44:,HR`[4(
MZ,I;00&_,DA`7\,.!E2808:RF]O`@"1(0)77%@84P-;6.R(`,S;?`@"T34;?
M=EBG0@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O=')E92]J;VEN+G!N9P``````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,S`U`#$P-#$W,S8S,#$S`#`R,C`W-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``K\@W!8KI````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````903%1%````
M____I=F?W0````)T4DY3_P#EMS!*````-TE$051XVF)@9(!#@`!B8&2$((``
M0D8``01$C&`&5A(@@!CP,"$`JP*``(*0]&("!!@2<Y@(`@`XE@&"^PI?*P``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+W1R964O:F]I;F)O='1O;2UD;W=N+G!N9P``````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#$U-P`Q,#0Q-S,V,S`Q,P`P,C0R-S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!0````4`0,```"W1X].````!E!,5$4```#___^EV9_=`````G123E/_`.6W
M,$H````6241!5!A78_S/\)&1)!SV&T(W%&*C`1_`)S6Z\9=?`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E
M+VIO:6YB;W1T;VTN<&YG````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,#,`
M,3`T,3<S-C,P,3,`,#(S,S(Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````4````%`@#```!
MS5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\````!E!,5$4```#___^EV9_=`````G123E/_`.6W,$H`
M```U241!5'C:8F!D@$)&1H```F((`@@@.`("@`#"3P($$`,>)@0PP@$2$R"`
MZ,L$"#`DYC`1!``^<0&&@DF8,P````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]L96%F+G!N9P``
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S,P`#$P-#$W,S8S,#$S
M`#`R,C`T-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````84$Q4
M16YM=9.1G,_,V/___P```/___P```````,%CRF(````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!,M
M,$=CKCH````Y241!5'C:8V!@8'!Q<7$`4@PLCDJ*8(:3D[$1B,&B#&6XN$`9
MCDI*$(:3L3$E#*`Y$+M<7&"V0P``/6<27`BUH(,`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O;&EN92YP;F<`````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#,P,0`Q,#0Q-S,V,S`Q,P`P,C(P-C(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````&4$Q410``
M`/___Z79G]T````"=%).4_\`Y;<P2@```#-)1$%4>-IB8&2`0X``8F!DA""`
M`$)&``$$1(Q@!E82((`8R&,"!!"$I!<3(,"0F,-$$``_4P&'P_V4C0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]T<F5E+VUI;G5S+G!N9P``````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`S-C$`,3`T,3<S-C,P,3,`,#(R,C<T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```4````%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\````"5!,5$60D)````#___^)`$\A
M`````W123E/__P#7R@U!````7TE$051XVF)@8F1B8&("8D8F@``"T@Q`P,0$
M$$!`Q`@2`D&```)),C'A(@$""$PRPI@,$.U@)B,C(QBCB,+4`@001#-^)E07
MN@)&1N+50@%`@"$QR19D0%-!#4'RG00`1+,"U']6M%P`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E
M92]M:6YU<V)O='1O;2YP;F<`````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S4T
M`#$P-#$W,S8S,#$S`#`R,S4R,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%````!0(`P``
M`<U0W:D````$9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/`````E03%1%D)"0````____B0!/(0````-T4DY3__\`
MU\H-00```%I)1$%4>-IB8&)D8F!B`F.```)B!B!@8@((("!B!`F!($``@20@
MTMA(@``"DXPP)@-$.YC)R,@(QBBB,``00,0PH;K0%3`R$J\6"@`"#(E)MB`#
MF@IJ")+O)`!'I0+6O/JDQP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O;6EN=7-O;FQY
M+G!N9P`````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,T-@`Q,#0Q-S,V,S`Q
M,P`P,C,R,#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!
M34$``*_(-P6*Z0```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P````)4$Q419"0D````/___XD`3R$````#=%).4___`-?*#4$```!4241!
M5'C:8F!B8F*`8H```F(&(&!B`@@@$`<D!((``01C8R<!`@A"PI@,$.U@)B,C
M(QBCB,(`0``1PX3J0E?`R$B\6B@`"#`D)MF"#&@JJ"%(OI,`3&D"V65>_-``
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VUI;G5S=&]P+G!N9P``````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`S-38`,3`T,3<S-C,P,3,`,#(S,#(S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````4````%`@#```!S5#=J0````1G04U!``"OR#<%BND`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\````"5!,5$60
MD)````#___^)`$\A`````W123E/__P#7R@U!````7$E$051XVF)@8F)B`&-&
M)H```M(,0,#$!!!`(`&0$`@"!!",C9T$""`("6,R0+2#F8R,C&",(LH$M`4$
M``((51MV)E07N@)&1N+50@%`@"$QR19D0%-!#4'RG00`27<"UU!#0:0`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O=')E92]N=6QL;VYL>2YP;F<`````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,S0T`#$P-#$W,S8S,#$S`#`R,S`Q-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````%````!0(`P```<U0W:D````$9T%-00``K\@W!8KI````&71%6'13;V9T
M=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````E03%1%````D)"0____\OT?
M)0````-T4DY3__\`U\H-00```%))1$%4>-IB8&)B8H!B@``"8@9&1B`)$$`@
M#DB($0@!`@C&QDX"!!"$A#$900#*!%*,#$"`(@H#``%$#!.JBXERM0`!AL0D
M6Y`1RF&DHB#Y3@(`<,$"^T4;)Q(`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R
M964O<&QU<RYP;F<`````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,V
M-P`Q,#0Q-S,V,S`Q,P`P,C(Q,S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,`
M``'-4-VI````!&=!34$``*_(-P6*Z0```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P````)4$Q419"0D````/___XD`3R$````#=%).4___
M`-?*#4$```!E241!5'C:8F!B9&*`8H``8F!B8@`")B:```(B1B";B8&1@0D@
M@(!L)A`;.PD00&"2$<9D@&@',QD9&<$8112F%B"`()KQ,Z&ZT!4P,A*O%@H`
M`@R)2;8@`YH*N"`CT8+8:#*=!`!`E@+0YPH+]@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W!L=7-B;W1T
M;VTN<&YG````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-C0`,3`T,3<S-C,P
M,3,`,#(S,S4T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````4````%`@#```!S5#=J0````1G
M04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQ
MR64\````"5!,5$60D)````#___^)`$\A`````W123E/__P#7R@U!````8DE$
M051XVF)@8F1B`&,F)H```F(&(&!B`@@@(&($LID8&!F8``((),'$A(L$""`P
MR0AC,D"T@YF,C(Q@C"(*`P`!1`P3J@M=`2,C\6JA`"#`D)AD"S*@J8`+,A(M
MB(TFTTD`0X@"TJ-$18L`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]P;'5S;VYL>2YP;F<`````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S8R`#$P-#$W,S8S,#$S`#`R,S`R-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``K\@W!8KI
M````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````E03%1%
MD)"0````____B0!/(0````-T4DY3__\`U\H-00```&!)1$%4>-IB8&)B8F!B
M!&(F)H```F(&(&!B`@@@$`<DS,#(P`000#`V=A(@@"`DC,D`T0YF,C(R@C&*
M*`P`!!`Q3*@N=`6,C,2KA0*``$-BDBW(@*8"+LA(M"`VFDPG`0!(3`+5@:.2
M``````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W1R964O<&QU<W1O<"YP;F<`````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#,V-0`Q,#0Q-S,V,S`Q,P`P,C(V-3,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0```!ET15AT4V]F
M='=A<F4`061O8F4@26UA9V5296%D>7')93P````)4$Q419"0D````/___XD`
M3R$````#=%).4___`-?*#4$```!C241!5'C:8F!B8F)@8@1C@`!B`#*!@(D)
M(("`""S,P,C`!!!`,#9V$B"`("2,R0#1#F8R,C*",8HH$]`6$``((%1MV)E0
M7>@*&!F)5PL%``&&Q"1;D`%-!5R0D6A!;#293@(`15H"TS4)<68`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T
M<F5E+W)E=BUJ;VEN+G!N9P``````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P
M,30`,3`T,3<S-C,P,3,`,#(R-C8V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````4````%`@#
M````NE?M/P````E03%1%````____````<\:#<0````-T4DY3_P``1.[P,P``
M`:])1$%4>`$!I`%;_@`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!
M``$``0`!``$``0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!
M`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!
M`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!
M`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!
M`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`3U)`8*<4[F3`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]T<F5E+W)E=BUJ;VEN8F]T=&]M+61O=VXN<&YG````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$P,C0`,3`T,3<S-C,P,3,`,#(U,#8Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````4
M````%`@#````NE?M/P````]03%1%````____````````````@FO25@````5T
M4DY3_P`````(#\$]```!KTE$051X`0&D`5O^``$!`0$!`0$!`0$!`0$!`0$!
M`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!
M``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!
M`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!
M`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$``0`!``$`
M`0`!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!
M``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!
M`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!
M`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!
M``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!0L(!
MAKX,7;,`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]T<F5E+W)E=BUJ;VEN8F]T=&]M+G!N9P``````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$P,30`,3`T,3<S-C,P,3,`,#(T,3$S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````4````%`@#````NE?M/P````E03%1%````____````<\:#<0````-T
M4DY3_P``1.[P,P```:])1$%4>`$!I`%;_@`!`0$!`0$!`0$!`0`!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0`!``$``0`!``$``0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`3Z]`89`
MI&Z1`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]T<F5E+V)L86YK+G!N9P``````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`R-C(`,3`T,3<S-C,P,3,`,#(R,C,P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````4````%`@#```!S5#=J0````1G04U!``"OR#<%BND````9
M=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\````!E!,5$7___\`
M``!5PM-^`````7123E,`0.;89@```"5)1$%4>-IB8$``@`""(X``0D8``80?
M`000F0@@@.B+``)L^"$``;8``?2%K84`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O=')E92]R978M;&5A9BYP;F<`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,S(W`#$P-#$W,S8S,#$S`#`R,C8T-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`$`P```.W=XE(````84$Q416YM=9.1G,_,V/___P```/___P``````
M`,%CRF(````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``
M"Q,!`)J<&`````=T24U%!]0,%!,N`$J7S54````X241!5'C:8V!@<7%Q80`!
M%B$E$0<P0]E8107&,'*`,L"J@`PE)1$(P]A8A7R&D!+4'!<7F/U@``"A^0S+
M!`=&O0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O
M<F5V+6QI;F4N<&YG````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`Q-``Q
M,#0Q-S,V,S`Q,P`P,C(V-38`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,```"Z
M5^T_````"5!,5$4```#___\```!SQH-Q`````W123E/_``!$[O`S```!KTE$
M051X`0&D`5O^``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!
M`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!
M`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!
M``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!
M`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!
M`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!
M`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!
M``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!
M`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!
M`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!044!A]7QV($`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O<F5V+6UI;G5S+G!N9P``````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3`R,``Q,#0Q-S,V,S`Q,P`P,C,P-3<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!0````4
M"`,```"Z5^T_````#%!,5$60D)````#___\```"Q+Z:&````!'123E/__P``
MTPY4A@```:])1$%4>`$!I`%;_@`"`@("`@("`@("`@$"`@("`@("`@`"`@("
M`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("
M`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("
M`@("`@("`@("`@`"`@("`@("`````````````@("`@`"`@("`@("``("`@("
M`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(`
M`@("`@`"`0(!`@$"``(!`0$!`0(``@("`@`"`@("`@("``("`@("`@(``@("
M`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"
M`@("`@("`````````````@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("
M`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("
M`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`E6*`M3QS3FM````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+W1R964O<F5V+6UI;G5S8F]T=&]M+G!N9P``````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,3`R,``Q,#0Q-S,V,S`Q,P`P,C0S,#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!0````4"`,```"Z5^T_````#%!,5$60D)````#___\```"Q+Z:&````!'12
M3E/__P``TPY4A@```:])1$%4>`$!I`%;_@`"`@("`@("`@("`@$"`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"
M`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("
M`@("`@("`@("`@("`@("`@`"`@("`@("`````````````@("`@`"`@("`@("
M``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("
M`@("`@(``@("`@`"`0(!`@$"``(!`0$!`0(``@("`@`"`@("`@("``("`@("
M`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(`
M`@("`@`"`@("`@("`````````````@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"
M`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`E7P`M9B
ME9->`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W1R964O<F5V+6UI;G5S;VYL>2YP;F<`````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3`R,``Q,#0Q-S,V,S`Q,P`P,C,W-C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!0````4"`,```"Z5^T_````#%!,5$60D)````#___\```"Q+Z:&
M````!'123E/__P``TPY4A@```:])1$%4>`$!I`%;_@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`````````````@("`@`"
M`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("
M`@("``("`@("`@(``@("`@`"`0(!`@$"``(!`0$!`0(``@("`@`"`@("`@("
M``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("
M`@("`@(``@("`@`"`@("`@("`````````````@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`EHZ`MESO^NV`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6UI;G5S=&]P+G!N9P``````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3`R,``Q,#0Q-S,V,S`Q,P`P,C,V,#(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!0````4"`,```"Z5^T_````#%!,5$60D)````#___\`
M``"Q+Z:&````!'123E/__P``TPY4A@```:])1$%4>`$!I`%;_@`"`@("`@("
M`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("
M`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("````````````
M`@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("
M`@`"`@("`@("``("`@("`@(``@("`@`"`0(!`@$"``(!`0$!`0(``@("`@`"
M`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("
M`@("``("`@("`@(``@("`@`"`@("`@("`````````````@("`@`"`@("`@("
M`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("
M`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`EG4`M<!_K*L`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6YU;&QO;FQY+G!N
M9P`````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R,``Q,#0Q-S,V,S`Q,P`P,C,V
M,#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_````#%!,5$4```"0
MD)#___\```#/D=W4````!'123E/__P``TPY4A@```:])1$%4>`$!I`%;_@`"
M`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("
M`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("
M`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`0$!
M`0$!`0$!`@("`@`"`@("`@("`0("`@("`@(!`@("`@`"`@("`@("`0("`@("
M`@(!`@("`@`"`@("`@("`0("`@("`@(!`@("`@`"``(``@`"`0("`@("`@(!
M`@("`@`"`@("`@("`0("`@("`@(!`@("`@`"`@("`@("`0("`@("`@(!`@("
M`@`"`@("`@("`0("`@("`@(!`@("`@`"`@("`@("`0$!`0$!`0$!`@("`@`"
M`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("
M`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("
M`@("`@("`@("`@("`G1N`ON4%E&H`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+7!L=7,N
M<&YG```````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R,``Q,#0Q-S,V,S`Q
M,P`P,C(W,#<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_````#%!,
M5$60D)````#___\```"Q+Z:&````!'123E/__P``TPY4A@```:])1$%4>`$!
MI`%;_@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"
M`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("
M`@("`````````````@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("
M``("`@$"`@(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`0(!`@$"``(!
M`0$!`0(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("``("`@$"
M`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("````````````
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"
M`@("`@("`@("`@("`@("`@("`E)R`M#)#J(=`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V
M+7!L=7-B;W1T;VTN<&YG````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R,``Q,#0Q
M-S,V,S`Q,P`P,C0Q,S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_
M````#%!,5$60D)````#___\```"Q+Z:&````!'123E/__P``TPY4A@```:])
M1$%4>`$!I`%;_@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`````````````@("`@`"`@("`@("``("`@("`@(``@("`@`"
M`@("`@("``("`@$"`@(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`0(!
M`@$"``(!`0$!`0(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("
M``("`@$"`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("````
M`````````@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`E+8`M+7WSW>`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R
M964O<F5V+7!L=7-T;W`N<&YG````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R
M,``Q,#0Q-S,V,S`Q,P`P,C,T,S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,`
M``"Z5^T_````#%!,5$60D)````#___\```"Q+Z:&````!'123E/__P``TPY4
MA@```:])1$%4>`$!I`%;_@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("
M`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("
M`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`````````````@("`@`"`@("`@("``("`@("`@(`
M`@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("``("`@$"`@(``@("
M`@`"`0(!`@$"``(!`0$!`0(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"
M`@("`@("``("`@$"`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("
M`@("`````````````@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("
M`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("
M`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`E:\`M,!FKD#`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%L97)T<R\`````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#0Q-S,V,S`Q,P`P,C`W-S$`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+V5R<F]R+G!N9P``````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3(R`#$P-#$W,S8S,#$S`#`R,C8R-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,```!@4$Q417%Q<8```+<`
M`-T``&HF&J8``#<``/_,F4PS&EX:#7<S)DP``(!F3%E`)G-90(0``+^9<YT:
M#=FF<^:R@(QF0(!9,VHJ*H@:#?*_C,R99LP``%$J*F(J*O___________QPQ
M[_H````@=%).4_________________________________________\`7%P;
M[0````%B2T=$'P4-$+T````)<$A9<P```$@```!(`$;):SX```!?241!5!C3
M;8_!"L`@#$,+@387O>V\___+I:V,*4L1S%-*8K?D2WFW]`"H`V\@3P^RB:67
MS2EB^<X7P/_!B*EA;FX0)7T<&YAB&Y!P@&-'7#A`):ND;'72[K;DJZU_^C\9
M%PD"C7>B(P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%L97)T<R]M97-S86=E+G!N9P``````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3`P,0`Q,#0Q-S,V,S`Q,P`P,C,Q,3``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3````P%!,5$4````,$QH4&R,5&R,<(RLC.$TR
M1EPO2V<P2V<S3VPT3VPU4G`Y5G1$6&P]6GA`6WA*6FU"7GQ&8H!*9H1+9H-.
M:HA5;8=3;XU4;XQ7<Y%;=Y5E=HE?>))@>)%?>YEC?YUG?YIH@Z%LAZ5NAZ%W
MAI9]BIB!EJV`F+.'FZZ6J+V8JKV9K,"<K+VBLL.EM,:FM<BPO<[_________
M__________________________________________________^F=RM[````
M0'123E/_____________________________________________________
M______________________________\`PGNQ1`````%B2T=$/SYC,'4````)
M<$A9<P```$@```!(`$;):SX```".241!5!C3=8]7#L(P$$2'$II-Z(2$$GH)
M=4Z0^]^*W8TH0F(^++VW8WF-_"<H3LM'8)N=3_LV7J)Z/ZQ7Z2*95`J!AS"9
MQ-%0*<=4YV0<C08UJ,BLK]SOF+@)DQ3NA2:N.B>5O8F+]DGEEHG=1NZ3PBZ`
M/7M<"I/>-5`L5I[/M._JI??JW7'HFP'^?^X[3X8-)<-`E=/[`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%L97)T<R]S=6-C97-S+G!N9P``````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,3<U-``Q,#0Q-S,V,S`Q,P`P,C,Q-3,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3```#`%!,5$4$`@0\4B0<*A1,>BP,
M&@0T/B1L>EQ,6CPL*BP,#@1TDEP4%A1<>D1\FFP$"@0\9APL*B0\/CQ49DQ<
M>CPT,C0<(A2$FG0D,A04(@Q,7D0,#@R$GFP,"@Q,;C1$2CP$!@0\5B0D+A14
M?BP4'@P\1C1\BFQ,5D0L+BQ\EF0<&AQDADR$FFP,"@1$:B0L+B1$0D1<:E1<
M?CPT-C0<(AP,$@P``-<!`/0``'<`7FT`@&D5"O<`>'>H2][D`.<2`!(`````
M`_D!`)L``/0``'?(F.#E`$D2FOL``'?P``Z([-GY_?1W?W>(&N(<`MCT`/1W
M`'?_.-#_YV?_$A7_```W`("0`&CT`!5W``#$E``>Y@#E$@!W````J@``FP`5
M]```=P``LP``FP``]```=P`XN`#'Z0`6$@`````$)-@!`.<%`A(!``#<@!CB
M:``2%1H```!^7MX`@.<`"A+`>````B<```````````#_)`#_``#_`@#_``#_
M`&S_\%O__>7_?W<`=&@`YL``$A8`````1F@``,```!8`````,&@`Y\``$A8`
M``!K\```B,``^18`=P!8^0`#FP``]```=P`&X`?V20#D^P!W=P`/(P`>HP#E
M]`!W=P``*P`!HP``]```=P!XY`!DY@`!$@``````R```*``5Y0``=P`4``#E
M```2`````````&P``%L``.4``'?@>#;X9``2%0````#P`/^(`?_Y`/]W`/^(
M!#8<*0#TY0!W=P#_!%3_Y_+_$A+_```W9`"0+P#TY@!W=P#@``P8`.CE`!)W
M````:/X`P%@5%DL`````;^P`$.<`Y1(`=P!X_UMD_V(5_TX`_P``""`!Z.@`
M$A(```!DF&\O$!#FY>5W=W<`;+X`;^@`3A(```"J*,B'EO\*3O]X`'^X`(@&
M`>@6`!(```#<!&CFY\`2$A8```!>`&^``1`*`.5X`'<`P&@`W,``3Q8`````
M``$`,```````7```50``3@``4P``3P``4FX`5/T`148`1`!\Y!I"`````712
M3E,`0.;89@````%B2T=$_Z4'\L4````)<$A9<P```$@```!(`$;):SX```!X
M241!5"@5!<$)#L%```#`H>XV95E1)=:9BL;M_V\S`P```-ME"0#J87'($P!I
M7:QB3`#,%X=/4P(P?W=CLP4>.U[7:1T3L&S;L\OQ%QJ`ZK8>3.YU!*"_N6;C
M,`*@ND^R,@!`572^`0#L3R$'`+W9$P`0<P!``O`'>`$'TG+0!TD`````245.
M1*Y"8((``````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L97)T<R]W87)N:6YG+G!N9P``````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q-@`Q,#0Q-S,V,S`Q,P`P,C,Q-#(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````,%!,5$41$1%W=W<F
M&@`\/#RF@!K_S#-`,PT````-#0US60WROR8S)@`O+R____________\1SM"E
M````$'123E/___________________\`X"-=&0````%B2T=$#QBZ`-D````)
M<$A9<P```$@```!(`$;):SX```!;241!5!A7+<:Q"0,Q`$-1+2D4LH=(8W"5
M43*+2X_CYN"GN'O5$W`F(&"-)\V=J]D@./8$P4H'")H&Q-4T&W&<>B*67U\/
M1)TZZ*K?/V?KV*D]M>X,U;;MZ//X`^1#4M`M*IF'`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R\`````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,3,`,#(P-3<Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO```````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,P`P
M,C,T,S8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\`````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8S,#$S`#`R-#(Q-P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S`N
M<&YG````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(R-C$`,3`T,3<S-C,P,3,`,#(U,#8R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`TW!=IXI7D`
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```0^241!
M5$C'U97+;QM5%,8_SXSM<>S$3MRQ$]L)L1/L0HB:($H%10A+%2R*6B2D2A&B
M"UBB+FCA'V"'A-0598$0K!"@(B2DEDJ-D-4N$EIHG*9*B&L[\?L=C^WQ:R9V
M.![$HB1ND-C`6%<SOC/W=\_]SG?/!?ZOE^9Q+U=65QU#@Y;3+46Y6,CGH=?I
MT%84:#0:Z#@6&I;#`*^#S6:'EF.7<OG\1]9A2])NM^\^%I[+Y4YLA")7.WMP
M#9DM,!AX`G#J@$ZW"Y9ET6RUT)9E9#-95,4=/#'NP%&O]SU!$*[T&%P_^+V5
ME3>,9JMK@.?!L0QT6DX%<M1J4AWELH@[ORRAT>@]5["K=-%IMS#E=E^@X?WA
MD4CDY;4'OW_0K59AL9A)!D8%J@-(#K%<1B:=P</-$)X^ZH-K5.@R+'?+,^V%
M8<`0_XMS(/R++[]B!/L8YW"ZD$NGX70Y(1&<Y_7@]7JT6FU4*C7J'\/"PKF`
MP6"X1NV3OW.8@^!GSYS]M+=LEM-"[@+)3![9;`&93`[A2)2D:"&62*#9;*+3
MZ2P?!.X+W]K>]B22&8B5BJIM=&L;9K,),CDEF<SB[F]!51)9WE7ST._:)PM%
M<VGA_#M:P>Y`FY9?EQKD"`6;H0@8AE'[1+&J&JU8V.E%WA>^+_+OOOWAI>$1
M.VNWCT*J-Y`OEI#/%]&@9PW]DJD,RCLE@-6A2/=KUW]R2E)MZ!_!E^[>@U40
M4"B4$'H8!4,;9F+""2U9D6$T,)F,ZG<6"_$X/5;7'KP="-QZ]E#XXN*B+KH5
MUH8VUM5D[74[\/F>A*+(V(XE$8O'52L*-@%Z/8]ARS`2Z0*"J^N7::RQ+YQ@
M1EE6KO!Z[G3/:E*M2JV&C8U-!(/WR9)Q<@FY@R94*`<LJX'-;B-?#^#&S9MS
MR4PV0/I/'YA0CN,$2M*[9;&"7);J".U,HW$057),)A6G_WK:2+7>=V@U6W^Z
MA"1CM%HUT13`<T_YO*<(%=Y7N&A6-A9+7%I<#'P<V"E#$X_":1E!@_0WE4OD
M]P0$81D;00GUL?-PTII'S%84=1S,8BGL<T]*?K^_ZG`XSM'$N4<BIXZ.)#6J
MQ^;GP6;3F#[Y`M)4H)P#/*3\%JPCG\-ER^&SG!V#'C?\<_.(U^O0MAO+4T['
M6\_,S$3[:MYJR:/1K>3[MTMEN(Y842?[!JL2&I421?@-I$H=]^X/8VJRC1'-
M'C)B`ROTOBE)@8/`C\#O_!KDUQ(I;ZI4A$#ZBE1*^7P*M>+7&#3<P(_7GX?"
MG,)JV`$KN237JD-0VA7_R1?7#]VA0T8>HUH6_B$>DY,3%\3*VNLU^?9KGIGO
M\?/R!(Z?>!,=?@QSQ\O-F=F9BQ&J,WK&6*2#X>JA\/%Q5])4K;DUM&1%EF/U
M>E5W;%9Z)97RZX]8SZ0]GME790U7-SG=79_7&__79Z`HEC^,A$.7B\7B_'_N
M@/X#RG'V`-Z*9CP`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O,2YP;F<`````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,R,@`Q
M,#0Q-S,V,S`Q,P`P,C4P-C$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@
M*M2@````!W1)344'U`$,#3H:XM[6P0````9B2T=$`/\`_P#_H+VGDP````EP
M2%ES```+$@``"Q(!TMU^_```!%])1$%42(GME%],VU44Q_?HLS$Q633RY)OQ
MQ<QD,8MN$DFF4]D883`'3*#0CK^%_@&$,N!78(7^$2@=Q1;Z#]K2C8Z6L0(%
MU@+R3\J_TM"61<7!8+`!+8ZPK]=&,#/CP<0'33S)S<D]N?=S3[[GG'OLV/_V
MK[4J4;V*P>2:.JWW5/\(T#D\$MYK'PR*ZV1!G<$,AW,86OTM4`)QL*%14>KU
M^M_[VU"'TWG=V-Y.E5=4KA3R*'Q;+X-2I4.KW@BY4@V!J`YIF7G@E56NI*32
MJ3Z[G7(X')2=^`ZSF7*[%ZAGS_;>/@3N[^\?#P0"DUZO=[*<HIZ3!8K/1W8.
M$WDL-IBY!%92`FF##"P6"[34-##2,Z!0*L'F%H#/KP"/QPO=:6O38WW]<<0A
MG+P4MK&Q"8?#"3:;#8%``&M7%[G$1VEI*<1B,5AY+-AZ>E!148',K.R0ET@D
M*"HJ1DU-#9J;6Y"5G4/D<\X&@L%W#N$[.X&PF9E9=%HL(:!>KT='1P>$8@G)
MFH4VLB\K*X/-9H-.UXJ"@D*HU9K0HQF9V22F"^T3DNE87OZEY@6=53I]!)?H
MJS>:H-9HH=%H2):]D,N;0E"A4`BA2`252H7^_OZ0!#+934BE4L1>28"2R).1
ME8.81`;J9$V[6UO;9P[TCE"HM(^J:QNAUK:2C,V@B.:_0[CY!=`;#.!P."@N
M+D9]?3U(T0BT`7<Z.\'AYN-:>CH:Y7)<^BH1D7')**&JX/7Y(@[@;UWG"Y8D
M,@4:FEJ0F$3#Q=@K./O%!43&Q"/^:QJX!))&9X!Q+1UQ\5<1%1.'\(BS.''R
M%&*OTA%Q+A(?GXM"4@8'Y54B^/S^/PLZ[UZ0<BJ%H/-(AW"+D<@LPNEST0C_
M["*B&4QP29S]33GR^$*DYQ;B\^AXG/SD2WP0_BG.7TY!%#T7";0,,/.+8;5:
M%S8W-]\]A/?/N,/DK@5\2,]&FX'HWM4#F;(%0GD+8FZJD,GF@OI.@_,B&422
M6FB-MU$B;8)`6`M&:362FUM!ADUA;#?%/WRX<N*%@KI6UD^+!D=1)*[U64:G
MG^>*ZN%>\,`\ZT5B@P+3[@5,/?@)8\3[B*\V6=!QMSLP-C&]G&NQH^[VG<W=
MW=T++YW*^_Z?Y[7W>C$R,M:<W>W82ZNJQJ)O"9:1"0R,C&+`Y4&2LA7=]YTP
M."9QJ5F/OJ'A9>>XRZJUV?>F7*[++P6OK&\R\H=<.XF<0@R,3H#9;H7.:(1U
M?!HI2CWNVOI0U3V$>"+#Q)3KUVI+/W(5+?`L^G##TH=*K3YXY%\BF?#4I!HZ
M45)&^0.!H(E,J^GQQA-/^>`$TF^(,#?G1N/P)`R]=BPM+9W9VMXV!8.[#TP]
M3B2HV]$W.74TW+6Z46,;_V%-H5"<.HA-NCSO6^86?S1W=CFWMK9H&T^?TLC?
M0R-M^_H?[?O1R/3\$\/0]_#X_)5'PLG!5_?V]M[X:WQU]=%Q4OG7CKJWMK;^
MIM^_%$;.O7(D_#]IOP&%;2%;T^KIU0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q
M,"YP;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,C<T`#$P-#$W,S8S,#$S`#`R-3$T-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P--QW)%#TO
M````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$24E$
M051(Q^V374S:9Q3&>[WL8M=+EIDV:;*+KKW:DFW9VM4L+NU%FS:IIFJ5;?+7
MJE70JE695J=H503\`.5+$$%!P"\4/R<JBM*)HJ#&#]`.II7*9A6TSF?_WKAU
MK<VR[;)/\N9-SON>WSE/3LZ)$V_T7\3F5D7?H:<1>D-/]/\"=+I<[\PZYK3%
M+*Z6)ZK?5ZHTD"G5^\5E'*UQ:.3+?PVV.QPGF[1ML\4</AIU>LA;]6"K6J`B
M[]!\-D*2L_8EFC9_T\B$O\<T1E<.C_OGG2[_[N[N^Z\%Z[O[3\H4ZM$2;@WD
MZC9H.WH0PZK!AU5-N)J>BU.23IRJ5.&#\`2<+96`PBS'QW4=D+5WP>5R!;T6
M7L2JO%I05@5]SX\8,IDQ-OX03%DC(L0JA#&*<*-"BO.AT0@._08W6;4@=`.(
MY,IA'#;]NKW]]+V7@'Z__^VI:5M4G:PA2J'2[%?4UD&K[X6FW8`::2,R'G"0
M(U6`R,I!2GD-PBCQJ!!(P5-JH+`OXE9,/,HXE9*LG/PHK]?[T0MP@406Q!-*
M42V20]*@1EVC#DVZ3K09^E'&KT-<:A:$BD90XY.@;&D#3R`&I[(:U35"](V:
M023244D6H]W+0W-+Q_S>WO[9([A:UV$I8O-1)6Y`[Z`)]:I6=/89T3TP@N=Q
M:@(-`J$8M-1TC(Z9,3$^CIR\0F0P\J%NUN(!BPLIV5`DD8*"HA(XG<Z0(S@]
M,\_!K95!UM2*AY/3$,I5**\6(2FK$,SR:C2J=5"I5&0!$0P&`SJ[ND")3<*U
M\&]AZ.G#[50&"%H6HN/HR&.68'EY^4_X@''$<IN>"297B&JQ`G?S6`BG)N/R
M#0H2[_T`H52)S.P<L'EBI&7?1WAT#,Z'7,'G7U]#[!TZKD?$X!:1!$H<#75R
M96!S<_/B$?S1D]V@6LL3G`YC()VT&EL@P!4R@99=@$_3Z_%5:`P8;`G.)?`1
M0:$BE\E"<%@,*-1X9)8)<89@@\C(G6C6:A4>CR?RA8%*9P)!J>TN7(YE8-;I
M@;C=B&G;#`R+.SB7J4.+OAN3JS[<%73!,3>'WJD5-!L&X'9[D-RR@C!F$Z:F
MIXE7K_K6OLE@MF%RRH:4KG5<2N/!N;J&H04WV/4:S+NW0&\8QZ!E!C,;`814
MC$/9VKVTL;4MNJ\8A*ZCJW-]??VME\!;_M\O$FV>C:COR_&38PD72H=01&[G
M_"^_@2HPPFRQ0FW?QAFZ',,35H@LF_@L5825-3?4U@WPFON>'1P<1+RRZWK[
M'NL+_CS2<@H/'ON>^D=F7?ZU1S\_JS1O(3A#1-JU(5&SB.^*Y;#9YU*GG1M^
MDW7NP.7=P26^%66J`?^QZZY9V&.5*@P[,IF,^(N;"$:/V\?ABUT[.SM:]\9C
M[:;7JR67X_3S]\/#PT3KJB]`Y9&SL"_T'PLG+7T2"`1N_CU.3OTZ>2X<E^?S
M^2*7EI8(\L^[)][HG^H/D2P#*1P74*0`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$Q+G!N9P``````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-C(`
M,3`T,3<S-C,P,3,`,#(U,30V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`X,&QZ#R7L````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```1_241!5$C'[95;3)IG&,>[9#'+KMS%DEUM
MWNUF27>Q;#=+Y@[9FF7IVG5IK+%&L1YJ.V/KG%,)U7B86">"XCR!H"@B*B@"
MHE(0000%%44$/*$6-![P?(S][Y4E)FW:IFEVM>Q-WGSYGC?/[WO>__M_WN_"
MA?_'ZPZ+U?H--3L_@9I;F.!9?!S]KT#7U]>+U1JMA%5>M50G%$/8(D6#6'K<
MU"*1G)R<?/5:T-W=W6"'T\4O*JU\4E4G@KRK!T;3$`:'K.A2ZU#(J@*=P3[6
M&0;MXQ/VT/6-C>!7AAM-P_S2ZCI4\IO0)E-"W*X`M[$5(JD2\AXMU!H=_F!4
MX,<P"JA9N:BLX?)?30I2!:.<<\AODJ!;H\>0Q0K]@`G-4CG4?7J8+:,HJ>0C
M.2,/F7D,1-]-P[5PRA.=7E]^>GKZ]G.AJVMK5_D-S5'=C_HLC+\X:)0H(._M
M0YVX`XPJ`?*9U>"+VL&J%N!64CKHS$KT#PY!K3.B5BA!=6T#1&TR7@Z=$;6]
MO?WI4_`Z8;.#S1&@C,@ADBK`(0F=/?_`TW**$7N/!GH9%ZE9#U'#$V#4-@ZG
MTX6^`3/:%&HTM'2`S:G';P\*P*[F,<[!JEY-?@&SXI1)JI(H>B!3/8*@I1,&
MLQ7\YG;<H]*17<C&@'F$0"<"L\]@#NB?36?B3S8'0R.VP`XB;Z>BA%USN+^_
M_W4`GII!8S`J>"CGB8BF8Q#+NL"J$2"WN!))Z7EH)%6-$*#=,84)^R3$':K`
M6C21YTIX#%)H!:"7<G`KF8J87]+`(K(2:2X%X/9)1WX:+>\T]R$+U?5BY!2Q
M$9N<CFN1B;A\(QXE%7PTMLI0Q1="(&['@\(R7(^^BR]_",.W5V[B)JGV[$.1
M<4F(N7,?'7(EB)TOG4OC]7H=O/H&)))M?G?Y9T1$Q2$L@D*>L;B=E`I*TJ\(
M2\E$."4>E+@[@?G3]0C<B(Q!5&(**!G9H-*R()6V8W5UU4F<<_$<3CKNZL+B
MXRCCZ+A%UBG'[-P<N!H#Y*I>V&RV\NFY^3VE6HMABP5ZZRC*B52#)C/&QR=@
M&;6A5]L'MWN:Y_/YHHZ/CY]VR\;63A"G?RB#*U$<KJRL&#:W=].YO?I]44L;
MR'M84X_.KS59SJKZGJ\UQA=R&K"PN#3AFE_(%?2;,>_Q*`\.#I[O<P)_1^^>
M[RJK;\3TS(Q&V6\*G7"XO+[E%=O1T=%%09?&+U-VPSXY^87).M;HGID%<42Z
MP3KV.U>IAL,Q)7EA9[H]2^_->!:=7J\/VSL[<7+'C*>LK@G+R\NU*VMKM"GW
MS(G7YZM56L??+Y*J8""=NK.[^[EO996D+1WY?,L?O1">J=2%T`1MZ.I18]7O
M_Z3?X7:URI6'Y#I(*I:JA$SB>^O(2)98:PAN5JEA&1FUV!S.4('6B-9>S<%+
M[Q3#M"=$:QTC7><\J_8M<L"?[>WM19ZMF5RS0KUI^"R>1>)!1*8$8K4/79[%
MC\WV*4RZW"^'DX0W-S<W0[:VMD+(P;SQS-J[Y%#/XL'/Q(/\?G\(R?O@O_5[
M_!NA%%<GTG"]L`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M,3(N<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C0P,0`Q,#0Q-S,V,S`Q,P`P,C4Q-#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@P3$%A!
M20````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!(Y)
M1$%42(GME&E,TW<8QTWV9MFRS)=F2XSO?+$8=9LQ6S+C03(W-49@,Q.%68Z5
MJ@/I4"A%H!U72VD+R%5HQ=)R%-I"6TI/H(>4XU]*H10VK0K#H>"`S`D)P^]^
MD,RE<TNV;*^6/>^^_^/SW,^6+?]Y$X@KME]B9NPPFLS;_Q7@O?O3KP0F@O1B
M@8A^O:;^J;"B!BJU]NF&=KK<._\1W-;GJJR4*M#0I$*/PP6O;Q16>R^*1%5@
M<?C4[=#=TK\--73;MAK-]H;\TLIG\M8.M'4:(6U20]79C7:="3W.6ZBH;<`G
MGS.>\<55*Y6U]1?_,KQ85'VP4%BU";7T.G'+,PBUWD3@1KAN#:"CRP+B&$EI
MV8@\FX1C46?65&WJ<W\*7%E9><DWZM]VXZ9\FT9G#!2+JZ$W]\%D=Z&UPXCJ
MAA8T:;J(=B*G4(3DM&M0MNN)4S,V`JFNN[$T,?D-C5,DW/;CDR>OA<%=_0,[
MM'HC:F5R7*]KA%)MV(2V:(W@54B1D)(-5KX(F5\+P6070&^R8G+J6PQY1Z$S
M]T*J4"%?4`XVEP^3K4\8!C=9>ZKS>&4HKU=`9^J!5-F.+DLOW(->"&MNXAR=
MB89F#<F&//,,P3\V#LKGA[Q5BPJ)'(->/]0&,[Y(8R.+4SCU\-&CW<_AF3G<
MH)@TJ:Y1A1'_V&;*,M+$O!(R&21:`XET9-2/B>`DG/U#D#2V(:M`A)C$+Y'"
MXD*F5".-9/09[1+2LW)`4=31YW")K"&8<O4:)#=;T4+*D<N[CJ14-J+C+H#+
M+X=[8!C=UEYTF6UH5'6`<24/QT_3<.1D#&(9Z:"3'IQ-3,69^`M@7F7!Y_/]
M!K\W_=UP2ID$$;&).'@R&@>B8[!SSS[LB3B!G;O>QJG+F=C_P2$<2TY%Q/%(
MO/M1)':_=Q![#W^,?<>BL.?041R(2<"N=_:CIJ9V]?NYN2//X<&%Q;C,;B=.
M)##`KZD#JZ@$\60*HC@\T-A<G)<V(^X\#26*5IRF)2&N68?#D:=!^RH#R>DL
M,&J5^)1;`DYAZ3+9[-BPA@;GYA-9I"1E!%SMIF#M=8!KZT=J;@$,?6Y8R:RK
M2*V;[0YH/<-(5FB1GE^(4E)"N],%9J<=C+Q\^/W^8!AX?7W]3>MDB'(,45!Y
M`X@GTU$EO8'!0!`&LC39%C=JFU7@#8XC@9T#Q_`(W-0(1!8G:)7UD"F4&`Y.
MD64;F+ES)_16&/S!\A,AVT$AFR>`H,>#*T4"\/167.:703[HPUFQ!/PZ&5*5
M'>`(RY&GLT':KD56AQ4L424XVFX4RA3P>KV:M;6UU\/@9<-!(:.I$U62^I_O
M/IQ?Z1^?`-OD0C([%^*>?J3P1?"-!U8G0O=7C)1_/;ZYD]P6"0+WIE<=U.A:
MEF<,3!8;3J=+0.`OA\%;O0&A3*/[R6RVT#?T[1^6[4*]!5U6VRHQS?+RLF9I
M:>G5C7=R[T2_4*V#Q^.A%A<7MRI\DQEBFQMJC>;!_./''[YP5TC-WR<>8W[5
MY,Z\L;"P0"?`V-]_2YR="H5"])F9F<U[3O[;.SL[NZ%?!/]O?V2_`"@"/7J9
M?!_U`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q,RYP;F<`````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C0V
M`#$P-#$W,S8S,#$S`#`R-3$U-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@``
M`.`JU*`````'=$E-10?4`0P.#`L#--D?````!F)+1T0`_P#_`/^@O:>3````
M"7!(67,```L2```+$@'2W7[\```#,TE$051(Q^V5NT\;613&4U%3TFV4)DVD
M[?8/2)IM5]HZHDR5)AU::24"38B#8@R*27:]7CLA!,S@!TD<;`.V\8P]X]?8
M'MOR8\:/\1M#LD&`%?3E>)!6*2)%*!0IN-+17,WC=^_WG7/N7+ER.7[($8O%
M[FWO[##!8)#9W]^W?C<P(V6OR4HMDTI)1Z5R^5.WVT6M5L>./X2M+?]1/I^?
M$D5QY-Q@556OI5)I-I,M0*XTH#8[6@SG1;F.%=L[+"V[8+&\F*,%?CT7/)O-
M9F1%0;?30:O30T*J82N0!LMGT6BVX?,G\=A@PY-GZWABM+8W-SUA699'OPFF
MEVX*T?B@T>JBU>ZB6.E`$.OPLSG4U1;*LHHU!XO-K3@BL0(81P"Z1P8$`H'H
MWM[>]:]"^_V^CA*VE$C$ZV6Y`JE00S*K("04\<83A]/-@XT6X'@3H>"@5%1T
MNCTHM1:$F(A7*ZOP>GU\)!)9.CP\O/WE;G^*\(*2+U91HH_X>`[;;`HEI0%.
MR,'XEPN.UQR2Z3+"@J190[O4E*3S%<I'&VJC"2Z:)Q5SM(CW^.#@X)8&3R02
MLVFI@+<D-5NH:I',E%!6FO#X13"N761R9?3[>P3MH:JVZ7D9;I^`5XR?WJ\@
M+A;!.%G,/)R#P6!`+I<[2S39,2N3%2FIA&:K`U&J(,AFL+[!PN8(HE)5T24+
M>KV>EH=`6,*_+[V8-]IALKC)L@BL+WV:NH<Z/186%D"E>@;_\.'];9[GWX?8
M,'S;NW"^WH;9ZJ2*>$YAU>X%@BQ8ED68C\+\G,&LWH*91V8\_7L%-H86<'FP
M;G?A_OVIH?=Y4OGS_[Z3A[_9[?;Q<#@23222X'D!N[LA<%P825$$Y034J5A=
MM>'!@QF8_C%C8N(/3$U-0Z?3#>;G%\:-1N/XD$%]\LM7JV8P&(P>'Q^/??SX
MWQC9,$:JQDY.3K1KM5J=65M;@]/IA-ELQG!.0"PN+AY=Q!GSY_+R,DPF$W6G
M18LAG..X[X=3#5_=V-B(>[T>Z/5ZK%!M3TY.DE6K=R_DA*2S9-3M=F-Z>AH,
MPQR0QPPING$A\-/3TY%&HW$G%`K=H4;Y_?*'=.[Q&>K9P4!7*NHW`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q-"YP;F<`````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,3$P`#$P-#$W,S8S,#$S`#`R-3$T,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%P``
M`!<(!@```.`JU*`````'=$E-10?4`0P-."5FCIE^````!F)+1T0`_P#_`/^@
MO:>3````"7!(67,```L2```+$@'2W7[\```#U4E$051(Q]V524\;9QC'TW-;
MJ8=&JGI(J'K@4JE?H<=\@!QZH>+2BD,^!$I41:@+P0DD(!.,B1=B&S`E%!M[
MO#M>\3J>L3UXM\=K;5:#3/CG&0Y%58M4FI[R2B.-1L_[>_[/.C=NO->G7"[?
M=+O=0R:3::C9;-[Z7Z#[^_MWT^GT6+%8#":32?C]`223[+'9;!X[/3T=_L_@
M;O>/$9[/]5A.0+U>1Z?3`:E&.)*`2FV`T^D*=SKM7Z\-)MB]7"XWJ-9J:#1;
MR.9%L'P)._%=E,HBMIDPIF<->/Q$?AX(1OJ)1.+>OX93*OHU422U;53$-D+Q
M,K;M<22Y'.J-%LQ,%,^5)FCU+OPRJ81<OC"@NHQ<">SU>I_Z?+[/1%&<B2>2
MYX5R'=*3$D3X(D4X?3QV"S6$H@*65UP(13+(%40$=W@HEY9!Q29$+T+GZ\/#
MPX__`B\62UPBP2+%\<CL%N&/9A%A\[![62PM,]"M>6#WI+"VX46(@*U6"ZUV
M&^5J$Y5J'3Y?`*9M.T4Q#X[C)O\$Y_/Y[R(Q=B\038/-E!",\G#[DZB*35*:
MQ;/Y5[#:=U"JB,@7*@1N$[@#/EN$R\>B6FM`)%N[F\5//\LP,3%Q"7<ZG9/I
M;!Z,*WX!$/(UQ+D"_.$,5C9>(QCF"%!'FY1*X`1?P*8E!*7&`L4+,[R!%#9-
M0>A6/!?P\?'Q2W@FDYF,Q>)(\3GD2U4$(@(VS6$H5!:HM!84Z9M8;Z#1:*!6
M;V';$</L\U=X]%@/C<Z.+68'*[^Y*2VO<?_^CS`8#)=P*L!M&I2XQ6(]5FN6
M,26;P?R""K(G<LAD3Z'3&_!"I8%>K^\;C>MGLW,+F'ZJP*,I.=D^(]M%ZOUE
M+"VICBT62SR5XF[_K6.VMK;&""`9@7H75BN#0""`@X,#S]'1D68P&-REU#R@
MKO!XO5YHM5JX7"ZDTQDX'`Z02/G9V=F'_]B.-'7#L5@LK%`H+BY:K5:P+"M-
MY[?]?O]+FM"%;K<[3:/_!;7MZ.KJ:H]V#F@=D*`E9+,"]O;VAJ[L=U*_2NH/
M7K[4->@=!$4T&NTRC*V]MK8F*3VG2+252D6IT6C>S,W-0:?301"$'CF.D.//
MKX13<4<HQ!_L=OL=NO20+FQ0@:!1J[&^OH[-S=]!@P):#QL>C^<AS_,VA\,)
M2M7JM78,Y?@#"OE[AF&D8EXH-!J-D-32]U')IMELW1*$W6](\5?7A7\BU6!F
M9@934U-0JS6@5$AIDGI^])UW.J5IF-(0E!PL+BY>.*%BXN3DY-WATJ%E=M-F
MLX6H,SBJQQU2/D11??3^_GO?`FQ49\\02%VJ`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S$U+G!N9P``````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S-S8`,3`T,3<S-C,P,3,`,#(U
M,34V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!
M#`TX-7LYB1H````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=
M?OP```*+241!5$C'[51+3YI1$/4GN.BBJZ;K[MITT473L.E/Z*:+_H2F:=*]
M24T^$V.-1'E'0<$`/A"#$0UQH1(@/'P0BH`2P53"0P%)$%`YG9FT7=B739=Z
MDQO(O7?.G#ESYNOIN5NW;W6[W4>7EY>JDY,352*14$4B$=75U=7]_P5]2Z#*
MQ<7%Y^/C8VQN;F)C8P-.IQ/E<MD#0*$WRMG9F9),)A5*J-#9^Y^`Z/`>LZ''
MFG:[O56I5+9RN5R3P-%JM>#S^3`_/P^OUXO)R4DL+R^C5JN!$N/T]!1K:VO(
MY_/\VZ+X#]?!DP0.8B'L`H$`YN;F4*U642J5!-SM=O_8`P,#V-W=13J=!DF%
M_?U]V.UVV&RV&N&\_B4XLPF%0A)HL5C@<#BPL[,#H]$(J]6*Z>EI`>&[8K&(
MP\-#A,-A23(U-86%A86ZQ^-Y<QW<Q>5'HU%HM5J,CX\+(#/B<ZZ$2Q\9&1%@
MO5Z/1J,AE<W.SDK,X.`@AH:&8BZ7Z]UU\%[2JH]T2S*03J>3H%@LMD45]9&N
M1F(DP.OKZU(-O1?)5E=700V5NXF)B8=_<LAC2M!.I5+"BOZ7MK>W`YE,)L[]
MJ-?KLKDO=";54'7MHZ.C9V0`&R5[\%MPEH<2@/4G7XN.P\/#4DDVFQ6VK#4S
MY]Z,C8UA;V^O0^^?_]7;#,[`G4X'P6"0-11W<)*9F1E)R#Y?65F1IFLT&IA,
M)G:9ZR;@O;1;[%]N)EE+7#(Z.@J_WR_-+10*6%I:@L%@8(TY:;?9;'ZZT602
M^,=ODU?DP6%F9K/Y"^FI\,22#.[^_GXL+BXZU&HU-]WRS^-/+)^2?U44K*)F
M/?E^3LU[=7!P<!Z/QU_2W3E]:U[<?8%OP?H*48V9-"+GH$D`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S$V+G!N9P``````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,3(`,3`T,3<S-C,P
M,3,`,#(U,30V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T
M24U%!]0!#`TY"Z-#I?`````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(`
M``L2`=+=?OP```17241!5$C'W97-3V)G%,9GT46;=M$F31>SJ6FF.]-T-;.=
M31L777311=.D&9?]!Z:956.[L4['L;83M2J*SB`@#!=$^1`1^10!4<#+11!!
MN'!!^12PT=$^/?<NIIDX:<VD29.2O(LW)_=WGO<Y'UR[]K_\M=OMZWM[Z:YB
ML3@6#H<YI\O%\3P?6EE9Z3H[.WOKE<''QZU;N1R?YW;3.*I4T.ET4#JLPNT-
M0*=;0"02D==J]2]>!=S-\X7D?I:'4*ZB4*J"%ZK@]GBD,@*TS"JF9QEH--J&
M(`@,)>Z^,CR3/6@*AQ6T2*UPV(`OF(+1$L!&B*-[#4NV$`:'U1@99S`P,$(O
M85IDW3\GJ#?J7^^P\6=YH0*>%,>2!;@#2=C=$4E]/)G'8]4J+/8P0I$T%BWK
M^/71.*Q6*W-Z>OHYG7<N0:O5&A/>VMI*)I.-;%Y`,)*"/[P+FRL"E<XIG15G
M%"JM$]:5(`Z/ZFBV.LCP1V`3&9A,UL:RS5Y1*I5LM5J]^QR<R^5NAL*Q8I3+
M8B\KP!N(P>8,83]7@B<0Q_"(%OHE']A='C$V@^;Q,5KM$QSP94F`<%C'4;4)
MAR>&'P<&,3HZ.O0<OKV]/11ETS"8U[&7*2!!A0OO[(,E"_0F'Q;,/J3V>;0[
M)Q)4$A",XZG!A6F%!=%X!I[U'3Q6VG'__C#Z^OI>A&>R.8)E42C7X`LDL&C=
MP(QB&7/S*]2"-1RWVNBTVRA7&C"3+2,3!CSX68D)N0D:,<D3"_1&-Q5X"&-C
M8W_!J95Z6#9^Y/;Z8339H-.;,3XYAP</QS'TBPPFBQWV51>"P1`<3B\4J@4\
M');CIT$9?IN8@UIKA,Y@AE*EP=34U%$BD>AYH:#-9O/33"9S0J^@XIBD$^>X
M/U*I5(<F$Q:+!;.SLUA:,D$FFP+#Z.'UKL/M]L#O]TMQF4P&E\O5\[+!>7-K
M:WN2&H8^<&-A80&;FYL"J>A=6UN#T6B$V6S&S,P,M%HM8M&H/YU.6SP>#[+9
M+%975^DXQ$1W+L$YCNMR.IVD;$D":#0:T/TN);AAM]O]8DR$ZO4&3$]/BY!>
MVB^SH5`(*I4::K5:$D!W[A*\5"I=IU'.!X)!3$[*6@S#E`T&P\=BC'K_;5(=
M%FTAA6FZ@Y;:=]5JY1M27M[=W8V(8++F6Y9EWWWI=`*X1<%D/!YWM-N=?H(,
MDTWW<OG<O?)A^<-ZO=Y/T(\*A0(*A2((#MJ:CD:C^0%]UT_GUM^.__GY>??%
MQ7DO[8H#K?8IYN?G0;:`"OT>)7_MXN)B0O1X8V-#JHO#X0#9\\F5%Q?M[-M4
M=3Q1S,'G\TE>DY?K!/\R%HO5EI>7(:I74%SL%K+T]RO#Z?FW(Y&HI$Q4+4(.
M#@[6Q1BUXE=BAXB%E\OE4IS6Q]7A]/37\_G\]RJ5BJ-%Q'F]7JY6J]T08V3!
MH\7%15BLUB(5\)E"H1BA&7G_7_GKH[Y_@ZP9(L]OVFRV'W0ZW6?_R7_PGR8Y
MZU2LPLFE`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3<N<&YG````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C(W-``Q,#0Q-S,V,S`Q,P`P,C4Q-38`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!<````7"`8```#@*M2@````!W1)344'U`$,#3D>SIY!&P````9B2T=$
M`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!$E)1$%42,?5U<MO
M5'44P/'O?<W<Z73::6>FTW;ZL`5:$`S%2%`QAD:C"PP8%QI"U$27AH6@_X`[
M$Q-6DK@PNB-17+!`$VIC08/8`"WET=+']#6OV\Y[YKYFYLZX<H&T8.)&?]N3
M?')RSN^<`__7)SPN.'U[NMOG:SMJ56NG-S8V4=PNG(H)"+@4!4&2:5(5PAUA
M9%G^7=-2GP7:VV/A<+CV6%S3M$-S\TL7J@UZ6EK]-'E4%$5&`.KU!J(D85L6
MIFV32B8IYK/T]T;8/33T42@4.@<@;X??FIIZL[DUT.-3511)0I%E9$E&ED3*
MND$VF^?&Y#7*NDXN5Z!6JU.M.NP8'#P%;(\O+2V]?.?NW"?U8I%>OQ]!$"CI
M.@(@RS+Y;(Y$*L'<W#Q[=@_1TQFJBY)\=7"@'X_J7OO+V1+_^IMOQ5"X2^Z.
M])"*)XGT13!*.FZ/BNIV8UD6Q7R9GIXN3IYX9\+C\5SR>#Q?_-T1M\*/'SO^
M92Y70%9D*O4:\82&EM)()C06EZ+HIL':>@S+-'$<Y_I6\+;X\LK*X'HL02Y?
MHI`O$HTNX_/[J%0KQ&-);MR<8?[!'':EAB1)V_ZV1\IBFN:9$^]]H(0ZN[$M
M"[VL8U<J/%B((@HBMF63RQ=H`.G-+([C;(L_DOGY[R^^U!8(2YWA3LJZP48Z
M@Z9M8I0-!"">2)+/9A%$%^ELADL__A0IETLM_PB?G+Q!(!AD8S/#PD(401#H
M[^_%I<A(HDBSUPN`W]\"LHO;=^Z^.S%Q]=DGXF/CXZZ%A7EE8786PS2IU^OL
M&=Y%M5HANK+&RMHZDB(1Z@CA5IMH\P=83Z2Y.3-[=FQ\W+LM;IJFMU*IGO,V
MN8^:EHU>+**7BMR?G6-Z>H;-9`S#,'`<AVJUBBQ!1SB$VN1A[/+ED5@B->$X
MSLXM&RK+<H@&'^;R>;34!FY5Q>OU42@42,;7<*MN2N42DBQC6R:B*-$01$1%
M011%IJ9O/_?T\*Y7@<5'%I?C.-+JZOJ9L9^O?'XEFZ6QMDRD-8C5T4YS+D.E
MODY7UV_<NVE0"K]/1!9I;PV05B1:\YG%X8&!\NCHD6)W=_?;DB1I#V4N29)3
M+AO%D0,C2*D$NPZ_0*+>(-+DHJS=)QC\BIX.C7/Q+GP[=G!D_WYBAHEL&==W
M1CI/[MV[+[IMS2W+[HPNKW_\:R9';[`=W8'I8@FCD*'=_P/E@L'43(#^OAKM
MU$GE36X52ICETL16\$/X]3^FU9G5^%`\DR:HJN2J-NIFC&+Z.WQ-OW#QTO/8
MPJO<BX8)M+6Q8>N$JG9A]/"+]Y\XH7Y?,S6WBU&_AX&G^DX5BH4W2O;DZP/#
MYQF_%N'@H;>HNSLY<+!@[MNW]_1B4L/=XDV'P^$+3\1[^[IBS<72@"`TJ%8J
MJWJIX!K9ESN2U%YQAX+'$H.#S[Q6$22]I7=G?6AH:.U?W\!\/O?ITN+\V70Z
M?>`_=Z#_!`Y._!JS\M!W`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\Q."YP;F<`````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S4V`#$P-#$W,S8S
M,#$S`#`R-3$V,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'
M=$E-10?4`0P-.2[H1W&W````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2
M```+$@'2W7[\```$>TE$051(Q^64ZT_:5QC'^VY[N25=VNS-^@<L6?9B-EG2
MM>E:;;;IM.MF.N^S%[5>VM5;7:N3>;]AU2(B5D%!BH@@@@BB@(@@(JB@6(IS
M0T44HVYQ7F;ZW9%E)DV3;69[M9WD).=W\LOG.<_S?;[/L6/_Z45K8+Z1GD,Y
MQ6IK/V6WVU_Y5Z!/G<XK+`X_@5K',-70'X/#ZT0-C5%JG9R\\(_`6KTQBLGB
M;K1P!9#(^V&V6*'1CX+>S$%!&75!K=%V>3R>UXX,ELG[D^L8+;_26WCHZ):#
M]40$OK@7`G)6:8;1QA<A*B$=^85E.SR^@)5'*?C[04JIM.UFC@`RI1K#!A-Z
M^S7@=O9`H]-C4*M'12T3J=D41-R\BX_#KN)!?@'K3X$>S_)Q>A/[I-Y@HGU;
M5/F\LT>!OD$=1+TJ,-L$:"*[7ZT#K:D-\:DYJ&5RT"U7H;:Q%??R2Y\/Z?2T
MVYD/3KI<WQ]_":X<4,\\8K)136ORI\\52""4*@B$B^2L`MS^I@24BGHDI>>!
MW2Z`?686-OL,9"0KOE@.2G$ELO**()$IEK:VM@(.P:-CYNC\TIK-NB:N'\P3
M]J!=*(71;$4+3X28I$Q_*90DDW[U$":F;)BP3:.G;P#5#2RH2*E4&AUR"JH0
M<SV)!+7/[NWMO>.'W\G.H]:0GQXR6C%*@"*9$DU<(:KJ6;B;6PHVKPO&L7%,
MSS@P;K6AM4."0BH#\6DYB$[,\)?M?E$U8LGY4O!E,!H;,3\_?\D/[^U34',+
M*U''8*%+JD3)0R9N95(0_E4:$C/RH!@8\K^XIT]%VE*%=!+PL^ADG`^)Q.=Q
M*4C)_@Y7X],0GYR%D+`KJ*?3,3<W]SM\8V/S+>.8U99:0D4,I00?A8;C[,5@
MO'<V".]'QN.+Z[<0%AY%=B1"KZ4A*/8F`LY<Q.D/`A$0=0-GRNMQ+C`8(9?#
M$1T3BRZ1:,?G6_O0#_?N[KWK7M](82RM(4(ZB-+*2O!%8C1W"G%!/8:HXG+4
M\_AHY@L0I[<@L)I.!"Q!(:T1Z?1&A-*;<:>@&.W27BB5_=W$7-&'@B:L[5$?
M+?I@FI@$D]T&_L@H[GE_ALPT#K%61]J-]/7<,@I'S%`9C6A@L=!AF4*$8P$=
M$BG46BU2IN=Q@WC!8K'4O-"&&8X?J/%T)MC"+EB6EF%=]."6<@CW*ZLPXUV%
MS;T(AF$,:155L#L<F/*MPS0WC^3F5B)\.[1+7M#%4F25E($,-ND+<-*7GYC-
M9AK[QV5\JAL'B\,Y$`0VQRS*O)OXDMA?IS?`[79C=7L'06,.Y+(Y<+E<T)'`
MYR?GD5]>A6<NE]SG\[W^DHGV@5<=O^R4"4WF[8YAPVZ.TXW'8@FLRRO[7*5J
MNWQB!M7$H0ZG$[+99]NM`YK]W&D7GO0I()^>W=4;1[<W-W^Z]I>S)=*]_G:B
M>?II'9=/5/>E'MREN3RRKSLE&#$89`??BLVMU#BK<X<CZH;3Z3QWI,FXLK)R
MFH`/55]<7#RQL+"00$ISXH\[K]<;O;JZFD#<^.:1X/_O]1L@LD#Q#QA`\P``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$Y+G!N9P``
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-S$`,3`T,3<S-C,P,3,`,#(U,34S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````7````%P@&````X"K4H`````=T24U%!]0!#`TZ`X:U?@$````&8DM'
M1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```/&241!5$B)[=!+
M;Y1E`,7Q_W-YW[E0.QV@4Z8MVE9;1<70`(F!&+9N1%T:/X,;5YH8%_HMW+@C
M2HQQH\0%8B/$60!N1&MI@>*43J>=S.V=>6_/Q04;PP=P8?AMSNXDY\!3_RL"
MP%K[PL/M!S^LKZ\?M]9BK:5>KW\Y5:U>N'WKUM++K[R*`.[<N<.9LV=)TS%;
M6_=(XC''GUTDRU*BX0`I%=8Z:C,UEI=7+BIK[8IS[I(G.8ESNEP*]:.=;=UH
M-,Z>.+$\O;FYKG=V6GIAH:X;C1LZ'H_TT2.3>F)B0@<:_?/5JWIN?E:OK"SH
M4KF@V_MM_><?ZWIV;NZ2S+)L*8[C,\(GK*U=Y>;-VYP_MTJ_UZ';:5$J*IK-
M)J%."`.!R8?T>WM<_OHK#O;;6&M)X@231_QZXQ<*89FW+E[\;F9F9DO&XS'[
M[199TB4:'K#]8(M"D"&E)4UZ>!?3Z[1)DPAC8EJ/VLS5)WGCW$D:C0:')IZA
M/QB2)ST&_0,ZG0Z5RM0[Q6)Q0^I`?[1_<(#)1^!SXE&,=SG66KR+P><DHP'.
M#L$;_M[>X<<KUYFI57GW[?/<O?L[#^]M`@G.9K1:NSS:V6$41<@LRR_L[K;P
M=DRE4J1:+9*F7:*HCS$QI2(X85'"X%W*BR_-$!8ME[_YGMEC$U0J!:+A`$&.
M$(9!O\?FYB;-G2;:6DN2)/0',:=7%\DRR]JUW^@<C&ANMSFU.L_[[[W.WEZ+
MOS::G#YUB#.K"RPO5=FXNT6KU>.YXU7VV[L,HPCOINCWNK3;;42KU?)KUWYB
MKW6?_;TFSCJ&_9ARJ4AU:@HG<CK=+E&44BZ4F#Y2Q9#3[?6P5A$4)YDHETG3
M`8-AS-'I.G/S\RPN/H\60N"%0(H"T[5%I+,<JWF,R7'68`U4)ZI,E2W>@[66
M("Q3KU4(`@U2H[5&JJ,@-4A%(2Q0*I?1A4*!(X</$PT&.)."![Q#YQG&&H0/
MP8-U#@`I)4J'**5`")36Z+!`4"BAE,9:@Y`2K15::WUONC:SE&89HRC"&(,U
M.2Y/<<;@G`7`.8=4"N\<0DJ\!Z4D0@BD5`@A45H3A`4F)R>IUV<1\7C\9IS$
M5T:C$8/!$&LMUF1DF2'/TL>E4F),AA`"YSU:::SS!$&`<XX@"`G"X/$JI:E4
M*M1J-82U]K`QYC7O_1?.N>-`"."]=\88Y[T72JG`>Y\YYT(@DU*&0@@`;ZU-
MI92AUAH>GVJ44EXI]8G@"=;:CX$RL`%<!Q:!#X#/@$__E0#WE5(?6FL_!\9`
M%_A6*=5^LO>I_\8_V6<+;00#OMH`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O,BYP;F<`````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,R-P`Q,#0Q-S,V
M,S`Q,P`P,C4P-C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````
M!W1)344'U`$,#@$X"4K&1`````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+
M$@``"Q(!TMU^_```!&1)1$%42(GME%U,FE<8QWNYZV7)DF;+O-K=LINE2YIE
MS>K,3#:WM+8ZK:T?M8K?K0HJ:A5$7D0J`A,0E8*"**!$J:`6OPO5^C696F$%
MM-M<M:*V*K@:^]\KF2Y=ZL6276S)GIN3]SGG^9W_^WR<$R?^MW^M\012548N
MW=!EOJOZ1X"VT0<A_8,C?I%$YF_5WX'5-HH670<XMX3^VGH%R^7R?/2WH5:;
MK:RMO9U@5W!7BAD$:B1U4*HTT.K;T:!4@R<0(S6+!D8Y=R4Y)8T8&!@@;#8;
M,30T1!B-1L+A<!(O7NR]?P3<W]\_Z?/YIETNUS2;(%ZRV00(@H/LG%S0\O*1
M2R5AS#)(:V7D=QZ2*2E(S\B"0J%$/KT(%1458#*99`P!G4X/KW<]]`A.WA2T
ML;$)J]4&&HT&'H\'<W<W.!P.6"P6A$)AP&_IZP.'!&7=R`[L'?A+2DK!KZY&
M4U,3;F3GX)[--N?S^S\X@N_L^()F9^?0U64*!&FU6G1V=D(@_`XYU#QH=3J4
MEY?#8K&@I;45A47%4*N;(1*)`A>UM+2@N;D9\4EI6%[^E?]*GE4:;2B]M!QZ
M0P?4S1KRH(94.0"Y_#8)94,@$*):((!*I0*96Y0R&)#)ZB"12A$=<R6@.BN;
MBJB$=(AE\MVMK>W@PWR'*E2:I_P:60!\H/A`_=#P,.B%1=#K]2@HH*.TE`&Q
M1().HQ%2:2U,)E-@/S,S"_7U#8B.3<3YF"0PB4JXW.[00_A[99Q;B\):):0-
M34BX1D'$I5B<BXA"V,4KB$ND@$XO1%I:.C(R,A$3=Q47(J,0$OHE3IT^@TM7
M4Q$:=AZ??Q6.Q,Q\L'D"N#V>/POZ<,$A+>`*D,:H0#:=@?C<FSC[=22"PR(0
MD4X%G<E!?C$+-$XU,JDW\4UD'$Y_<0Z?A(0A_'(R+J91$4_)0@Z]%&:SV;&Y
MN?GA$7QH=B&HP>[`F93K9#\;H.[N0ZVR"?SZ1GQ;I\;U_"(0MS4(%]9!(*J!
MIJT#3.EM5%6+D<[B(ZFQ%4*Q3*'3M\4]>;)RZI6"VE>\9P4CXR@1B=VF<?M+
MFE`"A],)XYP+";4*V!<<F%GZ&1/DZB;7*H,)QIY>W\34[#+5-`1QQYW-W=W=
M"Z^=RGN>7QYJ[O9C;&RB,;O7NI?*K<*/[D68QB8Q//8`PW8GKBFUZ"7G0&^=
M1G2C#H/W1Y>MDS/F9LOPWHS=?OFUX!7O9GKA??M.//GKP^-3R&TWHT7?AIZ)
M.5!(8(^E'Y6]5L1*Y9B<L?]612K-5:C@?.1&I6D07(W6?^Q;(IIR\E/T76"6
M<SP^G]]`3JMA?>.9DSTRA4R>$//S"Z@?G8:^?Q`>CR=X:WO;X/?O+AGZ;(A7
MMV-@>N9XN'UU@V^9_'Y-+I=_>NB;MCL_-LT_^LG8U6W;VMJB;#Q_3B'?'@K9
MMF__T;Z?C?VP\*QM=!Q.SR+W6#AY\,V]O;UW_NI?77UZDJS\6\?%K:UYWUUZ
M_#C(N[[^QK'P_Z3]#NY%(78IO;S5`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R,"YP;F<`
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q-C`S`#$P-#$W,S8S,#$S`#`R-3$T,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P-.BU:8W/.````!F)+
M1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```#$$E$051(B>U3
M2T\3413^9N;.HYVV4Q[R2`DL)""F1$S41(PA)FQ,7/@/C"Y<N6/CSI6)>Q/C
MSH4[-R[<L7"A!(A&7CY0@:A0*"!!:*<SG4[;\9R1,0TN7&LXZ<GM/??<[WSG
MNV>`(_NO3#H<R.5RV;<?/K8&00`A!`;Z^C:325.>F)QNL]TRAK(GJR?Z^R8X
M=W)J>OC+1E[K[FBO7[PP_.*OX"^GII^N*\FKD"34/!=6J?@VU902&]`'_%H=
M<=_Q,KIR?77M6U7*''_D2L+44:M^7YB[<>OFM<>-6'*Y7-9]W[_CNNYLL5B<
M=4K.I?BQ5KQ[,X_%5_/X^G5MT#;,@?7\-A9G9J&VM^LS[Y8>*%;30R1,\_7X
M<^BZ*I!(W?^TM#Q+.,]*I5)'K5;3A2S+=QW'&=O>WD:A4,#69AZGLH/8;S71
M9K6A9-O(Q!6\7UM!;T)#?TS!W,Y.NOMX-V2[A'3=P?SX./;W;.M3RACR7&>H
MIZ<G7Z_7+\O$?HRJ@#:ALTX90T>K96%I)8?/RVM(RD1,UY&F6%R6H"LRF@T5
M9KU"Y&.X,CJ"$U0LJ`=PZ5V(+.C-;@N2!;N[NQ1T?S^":Q>1^[:*\^=.HUKU
M2/X`5B(.DH_.)52\"LH$T-'9B1_[-IJ:T["HL*II2"83!`P&'Q$:!5*I5#@9
MI!4,8NTXM,8,Z)J`4`+D\YL8S/:'LN4WMQ"+QRBW"%GJQ,B%L]!4E2@%4(4"
M5L&C00A5L&T[V-O;`W?`+14*^W#+7MA#5Z83FJ:'9S6:%+[H."[,A$E%)3BN
M!Z]2086\6*0.TBER"RTM+:$+B4:.9YI=(2VY/?J%G3"P[U<@D\ZRK)"#SA('
M[Q,08XI)*@3%8WHS5.I`493PC.VW+#0UH>ZL*S-D-FP,U&B_2"AA?@A`)!B4
M]QQG)[YAGN#++(=-8^6Z3@@<=<*%(I"HPZ@8QSG&^6P1:\Z)\EF6>[&8,2J$
M<L;WDV%R=(&!HN1H/?R_D7'4D6$8O#X)/W\"ZZ4+71%8=#G:-Q9I-&87@3?:
M09&%/RX<V;]M/P%6'IYA15G6S`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R
M,2YP;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W,S8S,#$S`#`R-3$T,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P-.P.?KD]`
M````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```#M4E$
M051(B>V4RV]491R&G^\[Y\R<Z=POK<,P7#K3B`(B"QJA5A$,\<+*#2Y,C"O7
M^G^8Z-;$E0L71C>&BQH(!;Q!);4DB%IMZ+3T>N;6]LS,.><[WW%1(?X-A&?U
M+GYY\^2W>.$)CQ7B89B>OFF[V]WC0DC\(+SC#[:.C-8/^'8\,=]8F'MFT'<I
M5VKW"\5B8>;VC8P0`J*(8FDW@[Z+V^L"D"_LYL3$Y))IFG^;#\L[[;5R.J6O
M;FVY[-U[Z,M.LWFN[3QP=^\9FRIDO+/DP/.V?PC\9&U/.:I(*;!,@_7F*I81
M,K;/(B)B97V99M/Y!/A0/BQO-=<QC9"UY?NTV^USZ2&X>?.G9,_MG$W8'OFT
MQG$6)J5A5JY,W>/S+RYCQWWNWOV-P&LS-S?/IY^=Y_R%JRPM+KVC@F#BD?D+
M)TZ=65N^0S:7H]U:I3B:QG$Z;'8=VAL.81BBM(6[[7)B\C4>-.[Q8#UD^M=_
M.'SX$&8\1KWV-.E,B5*I.*RUSDB`0;__;J3YR-T.&*N/$>D>B42:;K>+L[["
MW/P:=_]8Q8S%F9V^@;>UP?BQ0WSU]77B]A"F:5,?W4NM5L;M;2&$N"0-8]94
M2N6ZG=:;BXL+&;>ON';]-K=^_H7AXOO$9$0JE69B<A)OX)%(V/PU\PV52IY;
MT[^SLKC$2Q/'2"2R7+\VPW=7ICCP[!&44J>!@U)K?;S3W7Q[<?Y/"","9?!<
MO8J4-ME\B4QFF(L7+O/MQ<LH9:+C1?:,'J35ZG+RY1<IYY-H%;)_M,[I5TXQ
M/CY.W$[,``O"][S7&XN-2S].?4][8Y5&H\'^D016JL1\8YF1D3*-N5G&JB5D
M:A<K3H=JM4H0^`AIT''62*93#*7RJ$@2^#XG7WUC]?FC1]\RA1#$8C%2R2&"
MED>M%*-:SN/U>U@C,2RC0^UHG4HI1VO3)1U)I+>"T@)?:8:38%L1W<XRRDRP
MJUHCE\MLJB#HFUIK>J[+5M>AD(J3*Y:Q3`,Q9!$5D@@$&E`:,JDDJ506A$`(
M0`A"#:$PJ402925Y:E^=8J%PT4XD9DW#-#<+A>)&J;Q_>'MM'@]%)`P,*8DB
M3>`/4"I`:PV`0&''#"Q#((5$"K#0*`R$]A`(I)3_W0*]7N_CIK/Q@;.ZA!JX
MZ#"`""(=$.D0`!WI1ULA!1A2(!`(PT!*$\.*8R6SE';M:V:SN?=B\?AY`:"4
M&O,]KQKX'BH,48%'I#5:1SL&.S.R\XK_(W8LI6%A62:F&2-NVSW+LF[QA,>/
M?P$7!*F'6&3[=`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(R+G!N9P``````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W,3$`
M,3`T,3<S-C,P,3,`,#(U,30U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`X+,A-PQ]`````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```-6241!5$B)[51=;R)E%'Z&F6&``::1*BT%
MAM1MPFZ[75,;W5@3HUTOUKU;C=?^A/T%)OX8;S0QQICHE2'67G3CWIBN@+$K
MU78H'0:H98;Y8L;SOEA,XS_8[$D(`^][GG/.\SQG@!?Q7(5P]7!Q<9$R#.-N
MN]W&SLX.NMTN^]O7-.U9O]^OI]/IOX?#X<`TS=KV]C9\WX<D20C#$.:Y.0>L
MU6I.<:GX^!IXUS`^^_G)DT^3R20FDPD$@1_9BXN+C<%@\,"Q;4.2Y6?9;/;M
M.(XY\'@\!A7%>:^'4FD%01A`EJ36[KU[-UFR=`7^1Z?S\>7E)0>E*:"J*G*Y
MG'IP</!@8V,=AX>'I7*Y7&*`BJ+`MFUT.AU4JU48IZ<HK:S@UZ=/(4KB?(K$
MU0-+4C,J]O?W,!J-D$@(R.?S1(^!?$YCA3C@T=$1[YHUL;FY"<>Q$4Y#6):%
MZ72*^_<_^#^XKNL8VV-\^/`C^)Y+%R-.3Z52Y9.P;F.Z5WRY0%P*$$41]7H=
MJ90"+:_AUJV;G)I6JW4=G$31W8F3[IL]'!]WL+Z^`==U>3=;6UOH6WT.IB1E
M>&,+2?HF;G%R<H*D+,.Q+]%L-K&_U\#R4C$=3:?Z'#R*HD?M5E-???4&>KUS
M:-H"F+!]TX1,R8RR(`@X;2EU@;I-$34RTP%J-@<EE<%RL8@[=VY3(5LGP1_]
M1PNIO[R\!'?BXKW=730:/V!`W9X1W[^U6S@[,\AN9Q@-^WC]S;<(]!>P*;NG
M?V$X&$"F2914&JLWZMC[L<'M.7>+D$B@0FK_^7L3WWSY$];T$@+?0:%6@&\=
MHU90$)%H&='!]U]]CM5JB6B*\-I:":$WA#L<X;NOOT`017CGW??GG$NSQF,:
MVX->7D+E%8V``L2D/',$449G(8D9\[6XNW6;\\_.V">.!;)CA3<H2`HJU?)U
M<$D4C6QNP;,459F0D)[/@!,(`Q^NYW'PJY"E!#DG"8FL*B9$7I(5]L,8D2`1
MYV/>T+4-)2&:`\NLCRP30_*YST$])@=E1[R8\._MF)*9MV<_9K0J2@HY,H*^
MNF:]5%C\A`SQ[1R<%N"-P/<SK%.;W,'>'2&M<\SJ1U.27N2+)<S<1:L>8E89
MW#ELR3*9-++9G"-*TF.\B.<O_@'9;99C?N6NW`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(S+G!N9P``````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$Q-#8`,3`T,3<S-C,P,3,`,#(U,34P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````7````
M%P@&````X"K4H`````=T24U%!]0!#`T[*#,2M@`````&8DM'1`#_`/\`_Z"]
MIY,````)<$A9<P``"Q(```L2`=+=?OP```'S241!5$B)[9+)CA)1%(9_JAH(
M0S$V0S%);!-(H-N-07KKRL?0MW#E"_@6+GP`HXD+,9U(NA,W+@D+`B1@F"D(
M\^@Y)ZE.]QN8R-G<FUOG_N?[_UO`J4[U3Y3%W&RWV_/I='I6J53>]_O]:ZO5
MBN/QB,UF`[O=CMUN!YO-AO5Z#8O%`I_/AUJMAE`HA&@TBF:S*7V:YD&Q^/*3
MP^'X<&:*D]#/U6J5+9?+<+E<F,_G(MCM=F5?*!30Z7203"9Q=WL+/1:3/DW3
M4"J5L%PN07#(YR]Q=75YPYK*0QLLPF1,G4JE0-.1R63@\7A`@T4L'`[CG&@;
MC0:\7B_J];J<^_U^`;BX>/J'[GU\)+[?[[%8+*0QD4C(RI04%W*YG%!QCZ(H
MR&:SB$0BXLR,28_I2*?31)[_Y70Z?S\2YVPGDXG8U*,Z#,.0(8/!`*JJWF?O
M=KMEY<'T-N*DU6I!550&^D+NWYJ:RN%P*-+%.\KL"9,ST6@\$O)>KR>7F78X
M',H0/N=(&((?DUU4JU6Y1T!?B=XPQ2UD]3D->#>;S5C@&5E]T6ZW$0@$)":R
M"/[&KG@?HX=D4A8F%P9E_FT\'K^B.+;T-F_B\?CW>W$\*!+.D*UK)J6!\NMQ
M<:Y\QL5OP.?\=Y"343`8_$S$KZE_0T`_<*I3_6?U%TN*\1^R2?GJ`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(T+G!N9P``````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$Q,C4`,3`T,3<S-C,P,3,`,#(U,30V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```7````%P@&````X"K4H`````=T24U%!]0!#`T[.5FBEO(````&8DM'1`#_
M`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```'B241!5$B)[5+)JE)Q
M'/X\'A5G<9X3#!04[^8BWFVK'J/>HE4OT%NTZ`&BH$5&D""T:2DN1`4-G`><
MQW[?'T[<^P9!?IO_]..;S@%NN.&?@,G8'(_'X'*YU!N-QMO1:/1@L5APO5YQ
M.!Q@L]EP.IU@M5JQW^]A,IG@\_G0:K40"H40C4;1[7;5N\?C0:52^6"WV]_I
M!KD0_=CM=OE:K0:7TXG5>DU!#(=#K&5?+I<Q&`R03"91K]<1B\7@E#FWVXUJ
MM8KM=@LQAV*QB%*I])V<VN,8)*$S75RGTVDX'`[D<CGE1H35.1P.(Q@,*J=>
MKQ?M=EN),`D-9+/9W^+Z_1/R\_F,S6:C!NF.:RJ54NX+A0(6BX6:T30-^7Q>
MB;`JHZ9X/(Y,)D/G/\7$KR?D[)8$C,G(L]E,B8S'8YC-9B7"[ETNEUHIS#>*
M]'H]-2.&/DGZUP:G=KE<*D)<E\Z>L18.3Z=31<*^>::SR60"7=?5/2NA"=;#
M%,UF$Y%(!//Y_+.XGQOD)HEZ)P)O5JL5"9Y+U/M^OP^_WZ]J8L]\8RKN&9].
M22Q"\TZG\T52OI`ZCO)M7B42B:]_R?$(0IP3]P_L5035KT6P5]X1K(?W_#ND
MBFD@$/@HCE_*_$$,?<,--_QG^`,_EO$=7&0H,P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(U+G!N
M9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,S0`,3`T,3<S-C,P,3,`,#(U,30W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X`#ZCL4@H````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```.I241!5$B)
M[91+3%QE%,=_<^=Q9^X,<X?R&)!Y`65XM$"%"2E%&Q%CM:EIXM*HL7%O5R[<
MN3!JHC&N3$P7)BYTT[2)QEA;`RLBJ9:*@X5"H<[08889F)?#,*\[UV^(+NS*
MM>$DYW[W?.?U/^=\.7!$1_1?R9#-9H.?KNQ<^FPEAU8W<%;.LVRPDRX9.6[2
M>?^TE_?"*::T')X3O;RSDL>^M\>5J4Z^WJY0V4VS9[&RF-=0ZS4N^^VIR^=&
M/CD,/CL[^\+GU;;OK\5UC*OK.'<BY,]?0(MN8W&W,7;_'EO#_1CF%E%G1ED.
M)S`_T<+(7HIT5SN9!UM4>OP<9$M(#AO>1*(\HR4_>/O5ISZ4TNDT!4E#3R49
M^/TJ_LP:%8%`F;LNSAQW(C'BI3R/!+JE0@WUYUN,W+_!ZB\_L97?(UNI43`;
M,-V^C7WQ)INMQ^1L\N#=1"(Q;6K`/R:^OE`08^`M]-_NTM6E(K_Y.G^6ZM22
M&]BLX^2=,F:K!=EEP]8=I'UWGGW%1-XB(=E,Z(([U3H&=Q/Q6PD6%O8Y#!X2
MBM):C.AW5[%H15YZ\0+AN\L\>S;$:J"'H38G]^K;^.P2OTK0/7228L')20OD
M9(TNNY$E@TY0;67$;N)AI4(^G\=4*I7PF*''*)SZW30IHA*SSN:#)8:?&R6M
M6ND7@_VC7&+<J5'V^!BI%-!L$AY9(FJ5&5;,*"<"^+M5MF)Q%)'0Z6Q!*A:+
M:#MB2.D$6K6,0S9CBS_"5"MCW(Y@JQ:1XU&T^`:6K55>N_@TQ]N:T5(QE$P"
M2R:&O+W.\V<&:)$5%JY=Q^TJTMO;BVEZ>II(),+I;C-)>Q?CX^-$HU&FGO3@
M40R,>27<QBHA?XU`<Q--U5UVX[OX]0W:#0%J<AJWH0UW+2E:FF'25V7TU"DF
M)B8P=79V4B@4T'6=@X,#&G+C!7F]7IJ;FU$4Y1#%VOHZ'H\'3=,.[QL`G$XG
M=5VTLSN`5^CFY^</_<],3MX4-F')8K',Y7*Y*YE,!K/9_*75:KU1K59QN]T$
M`H'-4"A$K5:C/QC$Y_-]K*KJG5@L1E#(@X.##`[TT]O3LYE*I1!QF)F9*??U
M]?TH0,5,(GA9H/BF4JF\+(9;M-OM7PG4:9O-]HK+Y7I#)#DO*KK8VMJJ"MT/
M#H?CH?")"38*?;CQ*D357PB?2^+N7$='Q[<"X$?_V@-B#4PT5L'?_Z[]_?UG
M1$)'0Q:M&!()QOZQ%7*[X`X>(V$?%&Q]_/Z(_B?T%_0&DE6L-_9.`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O,C8N<&YG````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(Q,@`Q,#0Q
M-S,V,S`Q,P`P,C4Q-#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@
M````!W1)344'U`$,#@`CFC0^Z0````9B2T=$`/\`_P#_H+VGDP````EP2%ES
M```+$@``"Q(!TMU^_```!!=)1$%42(GM5$E/6U<8Y2=D4W55J;LNN^BBFW33
M-@IJU2[;31=1I2(K"6K:)D0D$0TE,34)F#`$@J7@,(2$4$R#L?$4!T_8&#_C
M><#P/#^,8^/A&<RDTP^K)9NJ2M,N<Z6G>^^[3^>>[YSSOKJZ-^-U1Z%8^M3C
M\0BBL9B`UF__+Z`[.SLGLMFL;''1FO1ZO3"9S`B'5Q7_"32=YL[[_/X=D]E2
M-1I-"(37H#>[H-3:(;XS@$AD;>2UP9<=S([+XT>:V\#FBQR":TG,JFS0/F<@
MGS>@I_>N7ZE4?O"O@0\/#ULTSXR';#P--I:`V>[%TWD+AA\\QN`]">Y+1]'2
M*L38^,.8;<GN#`1#SD0B>>J5P!/)Y,=/IF?W3$M>3,\:<4-X%]=_Z<*#D3',
MS2DANB7&F6\;<+;Q(E5B@4)MP)Q2O6>S.\[L[^^_][>@J52J4Z%43:C4NJ1:
MOXAY/8/VCB$,#(U`KE!CJU#`]O8V<EM%S*D,:/R^"0V"<^@?E&)R>AY3,CEB
ML9B=+GCK&)0V)^+QQ/"RPWD86D_![6=K^HHZ)9B6_8[\5@'%,H]5=@.!2`J,
M)PIN,T]5F='6?@_?-33BJZ^_P?G&'TBJ<83"X7>/P8E1O<OE!C%')OL"P4B<
MRK5!HS.@4"R"KVPCF2F2]A%H%ER(K'-D<A&S\TL8&I9C=$*#-F$?/OO\2S1?
MN0:69<7D6WT-?)UEZUUN/\5M';-*`[IZQ]`NN@.'TX,$ET<\G8,ODH&)P*V.
M$))<#I:E,!Y-+6#%%T,TD87%'B0)NW'RY$<0B6[!X_%RI5+IDSJ>+[^_8#"%
MFJ^V4FD7<%/X*YPK;H364EAR1<!X6>B,;DC'-)#)K=`:O)B1F^$+LJB0!R6^
M@CB12*8YF,Q6C#Z<PH\7+\.^O(P:>S)*//%H$GJ##58FA$AT`T=I<7K7L)DO
MT3J$`<E38AP@D!PX+HLRSZ-0XA$FGPQ6'XJE,OE3@N:Y&Y>:V]#=W8._LGUI
MQ>6J^D)Q&&P^TII'B.7@"Z=@M`6)\6*-:2Y?1*52J8%ZZ5NYV@[IN`KW1U5P
MN%BHGCDQ*3/@IZ;K:&JZC&-C-S*9`!N-8Y681!.;Q#98DT$B56)FSE*[<(MB
MR)?+2&WDH=0QZ!N<@;AW"A.DOU++U.12Z6PX>^X";MP4O@0O%`I?D!%[OTW/
MH']`@IZ^(73<[D%K6P=:?A9B6#J.@4$)S:-X_&0&G>(^='4/TCQ$/UHGA:`3
MW3W]$'7<QI6KUZ#5ZEZ"'PW*\VDNDY&MK+AD%,_P42>TV^U@&`8.A\-RM/<'
M`O#Y?+!:K?2.@5ZOAT*A@,UF2SN=3AF=R2B.LFJU*ONG'O,A/8*]O:K@X.!`
M0.MW_IQK^]W=73K;$_`\+Z"J!=2>3[]2?WDS_@"EY9'"QOVJ10````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R-RYP
M;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-#,P`#$P-#$W,S8S,#$S`#`R-3$U,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.`00F);K#````
M!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$I4E$051(
MQ\V527,;512%LV#!-EM8X+^0+5O^!RL65(H%&RBR@H(B184D<N(8B(GCQ$:)
M+%N6+%F6;,UR:[!DM6;UJ*E;\V1;DFU9T^&UBHT34I`*"[KJ]>OQN_>>>UZ]
M:]?^#P<PO4V&2IG?%?0^IN,Y,LS3<9^9#(^9\?!D,AX>8T+FZ>B4P71(QN@&
M^?;Z6\+'=Z;C'@:]`D[J$30D+RH%#RIY#^KD^J061K_#8'+9(>R1E9P^^+=9
MWU*R.VE$49=]D+)>\!D[1,:!+..$3.XK11\*K`/EG`^#OJ0$</XS>#K^3`$W
M9`IRSHNBZ$:>=Q&P'7S2BI!+C73(`)8V@8D8D3S4@:/UZ+4YD&J=;ZR`:'A]
M.CRV*AE+@@<%WHV"X$:)!,D1>)@R@`[:X-W78'?U.T3<:R3(#I(D6.90B]%%
ME;#'G[])9[.B<9%W0DC9(&8<2-!V)*(NQ&@?6%Y$,,+`X?9#O?`-W'H5,J2"
M=,2$@&T%$N<A[`OY;[.?CL\9I7EYSD%^,"-RN`]!%'':[:)_?HX$D\>6Z0`V
M%PW3SBZ<YF=(A?1(!'4(VI;A-\YCT%7T'\Z]!E?LIKA"2%EQ1&WA*$*C5&NA
M6*HCFLK!ZJ012XFHMSI(L0+T&RN@]I\CX%J?]6)?_3U:I00PN9A[U2$?C0:=
M0D&1)&%%P+V!7<L^PC$.)FL8.J,/>\Y#9#A%&A9[KA@,9A^VS2[$,UDXG"Z8
MU'<@"T&EL4>OPE67YRV2P1^@[!K8K5MP'X2P:7#C]Q4#]FP4HO$D/%X**ZMZ
MW)U?A5KK`BN4(%7;",=SV#::P68BF$Y&S&N9][OU0C@41#+#X2"8P(;!":?+
MAT@LC5*YBE:KA6J]CA"=QOV'S[&^L8VB)!.9VH@D"7PW"%\@C,O+BZOPL[.S
M&]E<H=SMG^&XVT<LD8'+&T"I4D&CV4**E^$/LPA%.92K=1+X``\6M;BG>@R-
MU@`A)\.P&X!YSX?CD].K\&ZWJ^*$`BKU-JC##%YJ=TA6)=0)6*HT$4G)<%))
M%*0RQ'P)&IT7%OL1T=V/7Y<T6%/K<4B+2+)Y\(+P"KS7_4JKW1Q\?>M;W/SB
M2[@]7K!B"8P@(13+P>Y-$AA-`#Q,EO#,CDH%E5H#:0)\M/@8RT_7\,.//R,0
M"%R%CX;#3P+!8,.X8X&'"I%&%>#V)T@`B3B&QY/G%NAW?#B*\@B&&=3J3;0[
M'5*%##Y'*FPTD23KX-[\;Z!I^BJ\U^NIHK$8T34-7RB%@EQ!/)U#7JK"1>30
M&0]F&;;:K5D/<L4*T9^'5N^%FXJ#$V7L.:*X_=,"'`['5?A@,%!Q'`]>+"*;
M+X//EF;:;YG(4M<ZD2^6T22N:!+'2.7&S/N+2]M8^$5/O@E`L^4AST*X<_<1
M*,I_%3Z93#[N=#I5CA=F7M[<,F+YF0;S"ZODAT5LZO0PF79@-IM@<SA)$]?(
MNS6HB"67GJB)]]?Q8ET']8N72*72-U];_L/A\$.>Y^?:[?;36JW.R++,B-D\
MPW$,4ZWD3ZOE/&J5'&1)G+!,FDDD4XS?'V18EF,:S6;\P<.%.8O%,A>/1]][
MVVWOT[_VSW??0_^KXT^TJJ_'_D_#20````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S(X+G!N9P``````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,Q,#,`,3`T
M,3<S-C,P,3,`,#(U,34P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4
MH`````=T24U%!]0!#`X!%#N2JJ<````&8DM'1`#_`/\`_Z"]IY,````)<$A9
M<P``"Q(```L2`=+=?OP```70241!5$C'K55K3--7',6X+,XE+IFO96X+R3YL
MF=O<3+81=0_=S#!;XF,1T$T<ZK`3H@@B#(R!30'!\BA0Y"WR!L>CT!=("[:4
M5RFTA9:6`GU`2TM+>0D%BF>7)O/#<(G+O,D_]\O_=^ZYY_Q^][BY/>.:LNL"
M#`8M#`:]A]OS7C83UU[/R$99><7_!P<<P;9)L])JG:!AQ>QN55&FR[)\H1J0
M]V%EU-WAF*)9+&;E\O)R\-\U3J=S,_EVK`%S.A>\!P:Z*2-:+<4^95__V&F*
M5?6DHX%3A*5'0DR)/T5)_/OH$B;AL>,!AI59J*LMA<.Q$+NR/+'>9M513"93
MR^+B(G4-^/+BV`F=ZBY8M6G0:H<9<!K4=KD7BFE[H11X8ZIA$XJC7D5QRAY,
M2K\!(_-#\-@W@!6CVC'=S&AIRD"KJ!5ZO<Y]#;C#7KMNWIP8:.OY&L6I!R&L
M]X>F\1/0`S<AQ&<+?`]MQO<'WH&OUWY<H^S&5=]M4/`\L:#QAKQN)Q(3HB<Z
M.SN.C8T9UCU5Y\<K<Y1%<PXFV2^!'K0-4>=>1^B1C;AV<CMBPXZ!RRJ'4J5&
M34T%0G[>!7[::Q@L>1%)D;L@ES6K`>=G3S'/&6JU*'N&U&V&&7,^U,QW$7UF
M.W[SWX/:DA3P&ZL@D72A6Z9&98T`?S):D'@S%#?.;$5V^!9PB[[$XG0IYF9&
M#7-S,]7_!#\Y9ZFJ5/(.H>G.6\BY]@8*;^Y"9P<?XNYN%!85(2T]`_'49-#2
M<R%LDZ%_0(N<V[^@-&(K1-EO@Y'M@=+\"'*#7N4:]BL.F?O25`D,#_>A.FH3
M.!D_("X^'M3$1#!9+/3V2L%D-R`Y)16Y>;GH%,M0<B\=ETZ\AZMG=^/RN:^0
M1KV*(8WR]!-0^T2'1Z_PHH=:1#EJT\1!5+@7[.LOX^:5[\#B-D&NT,`T;H'9
M,@$CV:5]:MQ.SL;%H'#$Q-.1GED$OD`"*?F/?B<'2<G)TQP..U^CT7BX6<=Y
MD#:?AK1F)ZIB7L'Y8SL0>&H?&-6E,)K&":@5<I4![=T#Z)"H,#HV#F9#)Z@I
M90@-CT5H6!38#<W0CIHA;.]!5DX>8F+^@$JE@IMYM,Y#(?3?SZE.T*<E1B+C
M3C8*[A5@?-P,J]7F*NJ4#H,GD&%$;X1AS(R:^C945`O(+D)*6@%NW4J`4CV"
M!KX$M4PA,K-R(&QMC71)0QZCI+BX6R@L*2-ZYJ-'IL#@B`D#0V,0RT;0+%*@
M2=`'F5(+#J\'576MT`P;7'(-#!I07E&%F+@XI-%SD9Q6@B3:70@$0JR^!Q]T
MB;OZDVFI$+2V0=[7#YEB""+Q`.0$C"^4(Z^P@;2?""UM"K`;NS`X9(#59G-)
MIAL=AW[4Z*IC<IH1>?T&&$P^&IMX<+--VCPY7`XQI0M-+5+"3@<9,4W<J\:8
MR4)T[$=!<0,D4C4FK%:8S1878YW!A/:N?G!Y$@)N@FI0CWIN%X)#PLCM[Z&/
M'$8D&?7D\_E0J(8@[%`2$RU0:0P$?)`<)D-UG8CHJ75UB\W%=H*8JT1Y53,R
M\Q@H+&U"([\'%54"L!](<-S+&[34]%42Y6X+"XZ#/;U2)XO-1J]<@3[24@_;
M%;A/)C$KCXG\0C89^1$,:_6K0>$RM8[3CI3T^TBD51*YA,1(,>D8(>J8C?#Q
M\49M;>TJ$4^7H4M+BV>;>(VSEX/\<>%7/T1$1"(L+!1!%P[C^-$O$'KI"$+.
M?PY_GX\0?-$/(8&'$13P(ZY<"49```6!`6=QZB<O^/F=`IU.A]%HU!`O/WXR
M3+,S4]Z,FDI*5G8.A<5B47LE0E04A",OFPJ%O!KB^F^1&O8F:`D!$#7349(7
MAKC8:'"Y7+`Y;"JCIB)#WM<'G4X728#W_&L*D9ML6%EQ1)M,>J79;'0ET;R1
M.EU./X`VT</I^=E^=^N$CJ94:9@DC=Q)N&P@-1M)*KD3X!?^<^PMS;;;N36_
M@XRU_;D']/PC2X!..[BJ9\"SUOP%ROJOY-O;JI@`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\R.2YP;F<`````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3<W`#$P-#$W,S8S
M,#$S`#`R-3$V,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'
M=$E-10?4`0P.`2;S1?LG````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2
M```+$@'2W7[\```$#$E$051(Q[V5.6^=51"&GSGG?,OY?#<O%SMVY"4$"R$B
M\@.H0XUD*!`E$D4J&B00582@2$.+1(405?@!X1=0`&F00BSAQ#:Y<;Q=W\W?
M_;9S*!P[()8$H3#5*8X>S<P[\PX\PY"G_>B]^P2P0"JB/OQ/<.?*2?'ELA?Y
M6GP!WJ\""G"(K'L,HLR&][RME.D^-=S[ZAU<OH8?O^;+$44^P'F'1R$XM-)H
M8U%!'22ZB40W1)DOG@CWWGV`&W^,&ZDBW64X[#/.2ZJJPCF/T4(4Q8AWV"3!
MUF9!-QS*?B2B/OU;^$G&V><NWU/#_D,&HQ3G%=EX#!Z<<R@E1'%$,<[)BY)6
M(V)F;AD3SSI4_*Z(/JO`_+['N'S-ESVUT[G+WL&0K'"@-$H4KJH8#7H$VB`X
ME`ZHO&=OO\MA=\C*JE*A;:\Y5WYSJH$\`M>KLK@QZ.]=N;]YFZWM'?+JI/SF
MY`RU6I,@"%!*H;5FT.^1CC.\!R@YW-EBLE7CPNHEGCNW\JW6>DTI,SC-_-KA
MX?Z5.[=_HG=T0!#7F;8)UEJ2Q!*&!A.$1%&,#F)B.\'Q:$A1%GCG$1%Z>[^R
M\<LZ:>ZOS,TM7`/>.X5_J<2_Z5T^CU)$44P8!$2!X(J4H]XN46S)[`0FK"'*
MX+W'.T_E*HPQ5!X&_3YFMT-MH@:/YI:JJMZHG)M3ZD1?K12138B2!CJ(R<<9
MPT$?5Y:D@T.*<9\\'U.4Q8D6PP'W-^[@JXR5E>>9G&H_AH]&Q_;!@X=J.$P1
M!*4U(A`80V`4L8VQ-B:9:*"U0BN(HQ!<15ED:*4P48(23Q('A&'XAVGY;&GQ
MW.O#;F=I>VN;LB@8IRWR;(Q2"B<QB&)[ZQ[][CY)O8D.8BHON*IDG`Z)8\/"
M^5FLM0Y(S^"MUN2F*P?IZL4%LOXN1P<=2ETP+`?@/;B*X=$!!P\[E&5!HS%-
ME$R0-)LTVFWJ-J3=.,_R\B(F"-=/O>=LSE$A4^U9%N<:J%Z'V/68B#3[G4V.
M!WV,:*:"G-QGS$W'--K3F+A.8W::]#C#5QDVJ>/E,?+L)=Z_9<+&C[-+B_S\
MPW<\Z&QB:W7R+*-_U*59;[+TXLM,3,X0V9@BRPEMS'@T!&69FVMBHA:(V3C+
M]VSUQ=Q#XIN-F8LL7;I$7I7T>T>,TF,\X$4P880([&_>Q5<EB."<IY$(]<D%
M4`G>R]4_P94R751X`UUWJZ^\R@N7+^-%"$4AH@B3":JR(K8)\ZLOT9R=1>&I
MV9"I]CQBF@X)KHO(SI-=L1JH^W=OL7[K>^(@)K`U;',:K4`;39PD-&>FJ;?F
M$=-ZLBO^E9\7Z0''_2Y9FIY4J#5Q8HEKK4<]3D"9ZR+F_7]WB82OO*\N_/,E
MDJLBLB.BQO_K#7VF\1O]9^:]9@A8)P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,N<&YG````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(S,#``,3`T,3<S-C,P,3,`,#(U,#4W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X%*^F80IX````&8DM'
M1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1-241!5$C'U=7+
M;QMU$`?P[^YOU[N;V''L9+.I[83$*>XC04D1I:BJJD:JX%#4(B&!JJH<X(AZ
MH(5_@!L24D^4`T)P0U2%`U++(T0*%5+35FJ<M+2-&SN)';_M>-\O>VU.'$KC
M%HD+_*XC?32:^<T,\']]U-."R>5D)!`(G7":K?/E:@TLQ\*S+8"BX&-94(2!
MP/L@#4GP,>1&J5SZ>"`<WI(DJ?54O%PN'WJ86KO2ZM"QOOX@>@0!#$-`=8!V
MIPV:)K`=&X[CHE@L097K>&XDBKV)Q/NB*%X"`*8;?F=IZ8W>X$`LP/-@"0'+
MT*`)`4L(--V`HLJX??,&+-/`=D-!J]5&J]G"1#Q^#D!W/)U.'[U[[^&';55%
M.!0$*`)-MP!TP#(,&ML-%$L%I%93V+<W@>BPV*8)<ST^/@:!Y[)_.3OB7W[U
M-2U*$28:C:&XE4=D=!2:ID,0./`<!]NQH<H:8K%=.'/Z[05!$*X*@O#IWQUZ
M)_S4R5.?-1HR",O`:7>0+Y11K%11*E203F=@F"8V<ENP+`N>YRWN!'?%US<V
MXKFM`AJR`EG6D%E?1ZC/#[?E(ILOX?;M9:165^&Z+1!"NOZV)\IB6=:%T^^\
MRXI2!+;MP-!-V*Z+U50:-$7!=&S(B@H*%&K5;7B>UQ5_(O-O+W]_)!26B"0-
MPS!,5*IU5"MUF(8)FJ)0S)>A-+9!$1]JVW5<O?9C5->UOG^$+]Y:PH`HHE:M
MX]&C#"B:PNAH%#Z6!:%I!/P]Z``(!OM`$0[+*_?.+BQ<?_&9^-S\O"^366-3
M#^[#M"VTVQ[V[=F-9M/%QF8.Z]D<",-`'!+!\3SZ^T/(%JM86OGCXMS\?&]7
MW+*L7M=M7N)Y]H1M.]!5%8:FX?Z#5223*R@5LC!-$U[;0ZO9!$,H#$E#$'IZ
M\/,O<S-;A=*"YWF[=VPHPS`B.GBOT5!0J53@XSCT]OJAR-LH%O+@>`Z:IH%A
M&3BV!9HF`$6#9AA0%(VEY,I+^_<\?QS`VA.+R_,\LKF9NS#WZ\(GOS4:Z&RN
M(Q8<A#D4AK]11[.=@RC>Q(.D!F/X+*(,C7!?&#4?BZ!<6]LS/J[/SAY3(Y'(
M6X20\F.9$T(\73?5Z0,S8$I%3!Q^!<5V!Y$>'EHU#3'T!6)#97Q>EA"8F,#L
M]`RRA@'6,A=WCQP],SDYE>E:<]MVAC/KN0]^K\N(#0[`]("DJL-2:ACLNPQ=
M,7!G)82),0=AM%&432PI.BQ#7]@)?@Q?O)7D5[+Y1+Y>@\AS4-PF^&H>:NT;
M!(2?\,.UE]&DCV-Y+8*!_A"JM@&QY2BS1P[??^:$]OO]:/E\F`T*&!L;/2>K
M=U]7W>NO3>S_#O,W1G#PT)OP^&',')2MJ1<FSV\6RR!T;TV2I"O/Q$=&=VWY
M56V<HCIHNNZFH2F^Z2GC6+XPRXF#)POQ^-2K#L48@6B\G4@DLO_Z!LIRXZ/T
M6NIBK58[\)\[T'\"T;3]$X8W@O0`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O,S`N<&YG````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<U,``Q,#0Q-S,V
M,S`Q,P`P,C4Q-3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````
M!W1)344'U`$,#@(0%](]?0````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+
M$@``"Q(!TMU^_```!75)1$%42,>ME6M,DV<4Q_$6`O&:N<1YF74Q2W3[X'0Z
MS/33LCF_$)ENR\PRYX=E+))M,9O)!M/%&Q.1"LA%6["`E`)"+2VT6NZM%"BT
M4%IZA=(K??OV0JG2T@O_O9",9(,E+O-)3I[DR?/\SGE._N><A(077%-^ZSF;
MS0*[S9J2\++7E%OD%_`8J.6P_S\<")_W>EU:TDT4($[0`F,9`4[):>BT*C7B
M=MIL.%#@)@EM+!8[_]>;>#S^"F7;EL!BT9G/=:/R](F)\73_E'_57,R9K5,4
M0BQB(?)<BN>*?6#G[(5<>@MSX0Y8]&40--4B&HUDQZ/$*I]W(MU%D%V12/36
M$G@D//F%65>%)FXI+!9S$V(V0T!]"C7T@S!(3F&J=1/8ES9"4)Z"J.D8!,QW
MT2Z\!L2=AI!?V-0IO@.)5`JKS4E;`G_N$ZT(.2YG>.1'P2D\C@'A=S"W'431
MCQMP\<O-N/+U)OR0M@F_?+L?XOR]N)ZQ'6KQAWBF3X.*_S;H>==)N;S_$[O#
MN>)?\AQ*CQ+E"`@2<??\9N1GO(:V2\D8N;$&BH*MD#`^AD)2B[X>,:I9V6AG
M[H>)G01ZUB&,J#H-0/2]9:#1G]TNK7+<V&L+$I48:WX+E3^MQWCA:@2K5Z+O
M[CZH^EM@U*M!$&[*2(R9K>!45R(G\P0>E7^$T%0=@M,.6S`8Y/X3?MKKJ*\W
M2-+PE+D3%5D[X&*L1J1A)099!S`LJP-)DK`["<B'3.CI'Z7@=O0.ZI%?U(A"
M>@YJRLZ"4Y$)]<BP=JE:PAI:Q,^!6WH4PM_78ZXV`1Y.(KH:LS#I(D"X/3"9
MG118!Z7*A$G"`U&;`@T\*1ZW*W"/48':FC(J"'>`DN-7"U`OT9>BE'Z?,B;]
M)LUON@8E]P@T>6LAH;^)9L8)J%5RC!JL&-%:\+1?#UY+'[IEHVCK4H'7+%OX
M`4EZ8+;8(1`(T-S<3*E&QM%H-"D)WLE6C$C/PBC<"P\_"9S?UJ'EQC[(NOD8
M&AJ&8F0,DMY1C$],+D18RA1`KC1@0*FCSASP^7RP.0AHJ0#<;I+ZG1U5[$?H
M[^]'@M?!31F5GDSQV01JYT@FQ(P#>%)W'=T]*B@I\/QEM=:,4;T%S4\&T"$9
M!E4L\'@\%-2%P6$3^*(^</E/%QRT=0VCJ*0<HL=B+.8\&C:<F7$5PB@ZA`Y>
M-HP&'2PV)Y6."8@[E6!5B_&D?1!NT@N2`L];CUP/)DN(@N)&U'$EE`,9N`(9
M[E=4HZNS`XMJ\3BX4X.//T,G^PBZR@[#Q#L#2>,E"-D745EZ&7=RLU!9?`&M
M/#K$#Z]")F:BAD5'R9U;*"DN!;,D&\5%M_&P@0<NEP>%0I&[J/-@@%!.^<9L
M(7\%)GB[T'9E`R7'9$Q7)R+`20))F9M2SS0W"3XVM5>MQ5#!!C3D[D9'_7$8
MU950*KIL>H.1+Q2V;-%HU(E_D^-<C$B/V2]@HGX]F)D[H&3L!GE_(WSE:Q!Z
ML`+A!PF89JV"F[D.SJIM\/$2(2E>"T9>*D+/3,M7Z$+T<].OQ_P->F-K"JH*
M3V*H^P("`X?1GK\%G3DT6-AOH#5O)U2ENV"O?16\FY3C@0_@[]V#^MOO0"CD
MD3,S,ZG+PN.Q@-:DO@<>]RXE*6*Q*U;F'H2F\U-$NK="G+<.53?W8U;]/LJN
M[L'H$`O1L-;@->>3#6PZI%))"=6NDY?MYWJ=/-WE<J3/SLXNZ>>QL50\S-L.
M?L.OF'O.1V_''V@5"VSSJ8C%(JGC)D7)O#Q#X1#MA2:1B[!K7:[)A4D4(8L#
M]?>.H;>W.X#8.(TDK04ZX_ABDZ("2HY&HS2J]%?_Y[$W&^SSBWA78#09_2]]
M0(=#Y#FKU02'PWGN1=_\">4#?/OB][B+`````$E%3D2N0F""````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S,2YP;F<`
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,3(T`#$P-#$W,S8S,#$S`#`R-3$T-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.`B+?!6S]````!F)+
M1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```#X4E$051(Q\65
MO6Z<112&GS,SW__^>..-8TQD80LMB2(BT7`+O@%*2KKT2"!$A:"(*"EH420:
M;H!K0`*$(B1,",9)[-AK>^/]=O?;[V=F*+R)B0(D`B%./7HT\\XYSX'_L.1%
M#WIO/P82H!#1[_\KN'=E#]0M?+F)K\#;`:``A\@V$H.$=T%N(.JAB)Z_$-R[
M^AW<["W<=,O7(^IZBG-NP?88I=!!B@1+H+L@T4U1P;O/A7MOW\/F']$<J6IV
M2#ZK*&N/<^"<QV@A#`.4;T@30YRM0'#1H3L?B.A/_A)^=N/IYVZ^JR;YB'PN
M>*\IB@+!XZQ%*2&.(LJJHJEKNBU-?^4E3+KNT*U/07WX.")Y*F,W_Y)FN)6/
M=LD+1=T`(B@1JOF,X=X#PCA%JH(@:X,.\,ZRW`M96W\-PC60:$-4L,,BQ$6I
M6[C95E4,.<D]=>T`AU)@`D,]GV.]PP2&X<$]CN[?06F-"6/V]T;D)_?`G@+^
ML\=$<YY)M>GK$V:SDK)L,$H00(E@RX(PBGCY\CI:*[B\P7PZ`=?@$*RU[-SY
MA:OM/B;K;OX)O,8U!77C$>]PC4,IC:U*1GOW,6E&$$8H\0110A`G6.<0.7O9
MR7"/8C*BG9QWI#H?$#NH&D=5>VQC,<801B'CXR-VMF^SO_,S35DR&^=X/-X[
MZK*@*DN\,M1.,YU,`3]8#-R3S!.\4]6\Y/31*0J/M1:\Q345)@A0(H1QS'PZ
MP585V@3410[>$P0A)DYIK`6\6DSRDU@*1+FFKM3T>$@4I[1[/9RMR99ZO'+E
M.E&2<K2_R^'=;=;67\66'90.2-L=1(=$<8K1&A`'%$]N?N8*M9TD$:$6\L-]
MBGQ,739HI6BU.^3#`QYN_\@L/^7HP2[CX0%!$)-TNBBE2+*45J<+R/9C]YQ_
MJ(1$:8<L"SFZG_/H8)]6M\OQWCVF^2E*%%IIDCBCO;)*MW\)'48+(4"2)L1I
M&U3,L]TBX5T=]:]<NKS*[6^^Y?#!#DF[2U7-R4<CVITNZX/7:5U8)DH2ZJHF
M3!+FDQE*:U8O=3%Q?R&S/W3+6;FW4=G7[?X&&]<&%(UE?#IB.IWA/(@H3!0C
MHCC^[5>\:P#!.4<66UI+:V<20VX\`Q<5C5#I5P0K[LH;;S*X?@UT@#$1*$V0
M9+BZ)DI35@=7Z5Y<`1&R!);[?21<<4AT$U$/GV_%^E#M[]SFI^]_(#(I0=(F
MZ2VCM6"T)TXBEBZTR9;6SL"Z^_=6?-;GDZUJ=D@Q'E$6,SP:K35Q&A*W>IAH
M&<S2B_O\Z4TDM_#5)GX.W@\6`P)BQDBX]X\VT7-V*,!W(OH+_L_Z'<\-TN/H
M.\'F`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S,R+G!N9P``````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-34`,3`T,3<S
M-C,P,3,`,#(U,34T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H```
M``=T24U%!]0!#`X"-5S6Z3H````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``
M"Q(```L2`=+=?OP```2Z241!5$C'K55M;%-E%&[9)',(AA4RG(84G&!B8I00
MUD#X@2:"_B#`+S61J8FXA!@3`V80DRV(#C_PHT,G(!O$(7.X=>W&!EOM/FB[
MLJU=U][UXW;=VGO[N:[MNJW=VE$?W]L5U+1$3':3)V_;O/<YI\]YSCD\WD,^
M;I==1`#NY"WWT]OYF8@`W+DLA'Z?2Q(*>L1(>H5!KYI227<CX.ZEN.\+"U%Q
M<,IKCL?C']V[GTPF!01/9A#YO*[5M$5;QC*VLD@DD@,LE@P/-K'4P->(1WO@
MMU6!E@G`CE;@SX02X];?H514(Y%8J$HD$CDD4-FDW]5+/I_-()^>#@EILQ(#
MW9^`=>IE2'IH/W,1NN:GX=?NA_GF3DQ*<D&U;</TV&%8Y=N@5QX#=V]V-B33
M*K^%::05'K=3F$$^-S?+]WJ80_K;)P.66UMA4[\!I^I5G#]>@*IWU^+3MP2H
M?#T?XB,%:*A\"GT_K@:KW@N6*H?IUDLP_G$@,#S4=8@HP,^J,2=%<-)`4VW/
MP_CS2E2\O0$_''D,JE.Y"%WB(WZ5AT@='[HO5J+EQ!HHSFV%_=KCF&@1@!YM
MH;GWLUO-[9`X["HV&OH-YJZ7<>+-`M1_D(?H+WQ`0N+>^`>D/,Q?Y6/HS"K(
MOQ)@1";"?*09T3F&G9D)2S+()^Q&L49^''<:-^-"^5+&*>)60B8GZ"-0I2%?
M"A*_QH?Q7"',C<_!T%Z";ME[L%HTY@SR1)P5S@8[X-#L0]4[:U-2I#*6IPF'
M"0P$>H)^`@4O%9C]*0\]XB<PVKX=/L<51*;=I?=)B7U$FIYJD5%U[*#7=@94
MQRZ<(L7C-$Y)T)<FMI%@CORE4Y\.V,XC_VX%3)>*8>_<F;)KP*VDN$8CEA;Q
M/.YQW.X\#95T#TR2]7`VDD(25W#%2Y&KTMF.YP&>#4L!#.G?.SEI>+ASMA#3
MTAS04@%4S;O1W5$!QD&#QS(64?>-XR(?HZ"X!AEJVH[3AP4I5_PK<SHG:^:Q
M^A4PUQ:#:GTQU6`^IX)2W#@I<DY8_QX3\7BD-.QK`BW?A8O'UJ7LEJ&Y/GW>
M*RIQ3?#RH[#6;P+3OP^QZ2XD%SV93<0R)K.RXRBTTA<@K]F"FY4%F/\/M]QM
MX&.JO@C&>B&&&C=AL+L<C-,LSM+^04DD;&<79II)BY>@Y?0Z:(F/X[]F\;ED
MB3A8NPKFNHWP:O:"ZP^;Y3;K8L<E#^Q09J*;'I,58>SJ&O2??Q:&ZD*P-7DI
M5W!%YC3FI.`RIJ\4PWW]$9+,#LS-V!_<H602\L?HD4,&16G`V+$#CN$/$:$.
M8+"V$%3=)EAJGX&&N,)XH1CC#5N@NUP$WYW78%+LQT371NC5XL#"?&Q_5O)@
M<(I,Q1X,]'Z.23^3GHH7H&M:FHI>Y1[X)2LQW+`5/MU!&&6;X;14X^XB2^L&
MKLLT\H^A&VBM"8="^5G6&$/F^7"9S^LLB\5B]^?Y2/^7B,_U(,Q^#T?;>M#J
M][$8Z\/HX#=0]UQDN7MC-BIGW&ZH"4YY$(M&A0^UB;CB!"9=J4UD&OKNH+;]
M%3#6E@B2?F$@X!;;QXSWBT>61#Z!D"#W?Z\\O58B4BNJX',;PLN^H$,AO\C%
MTO#[G$<?]IV_`,`2&#[\GX0E`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S,N<&YG
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C$R-``Q,#0Q-S,V,S`Q,P`P,C4Q-#8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@,):J*D_`````9B
M2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_````^%)1$%42,?%
ME<EN7440AK_J[M-G\AT<W\3A*@FRA6X2,4AL>`6_`$N6[+)'`B%6"!812Q9L
M4:1L>`%>@H"($'(&[#CQ$,]W/GW.Z6;AZY@H0"(0HM:EKTM___47_(<EK]H8
M0OT%D`(3$?W)OX('7\R#ND4HE@D.0MT#%.`16442$/L0Y`:BMD7T])7@P9<?
MXL?OXT<KH3RB+$=X7Q/0"#5::4R4(U$+=`LDOBDJ^NBE\!#JCZF'GU/M*3?>
M83!VN-)3>_!>H74@MA$J5*2I(<TO0'3>HYN?BN@O_Q(^F_@;/WVDAH-]AE.%
M#XK)9(*(X.L:$2%)+%7A<&5)*U=T+G8QZ16/GOL*U&>G$LES&OOI;:J]E<'A
M.H.)HO0G+8)03<?L;C[&)#GB)MB\@6A#[3V=>4OWRE6P79!X252TQNR#9J5N
MX<<K;O*4@T'`50&\1PG82'#%E#H$HLBPM[/!WN/[B-:8.&%K\XC!P0;4QT#X
M^I1HSC1QRZ$\9#R>4A051@D@*!'*:86U,=U+5U!:$2XO48R'$#RA\M1UQ=J]
M!UQO=#!Y:_E/X"6^&N,JD!#P58TH15UZ#IX\)LHR(FLA@(TS(IL0ZOH$8BT'
M3S>9#`]II&>.5&<+4O=<Y:G*0%V5:&.($TM_;Y?U^S^SM7:/LBB8C@:$X(&`
M*R:4KB"(IO2:T7`$A-YLX9YIGA*\<M."XZ,^2L#[&KRGJAQ&6Y0(<9)0C$9X
M=_)X.1X00B"*(J(DHZIJ(*C9)C^398(H7Y5.C?=WB>*$N7/GJ*N*9JM-=.TM
MXB1G?VN#G0>K=%]_@ZALHDQ$VFB!CK!)CHDB0#PP>3;Y25;HU32-,48QV-UF
M.NA3.8?2FKE&B^'>#MOW?F$ZZK/[9)W^SC;6).3-)EHITCQEKM$`9/4T>\X^
M5"+BK$6>&?8V!ASN;-%HM=G??,2P?TRD#4I%Q#:E=>$UFIU%C(U/W4"69219
M`U3"BVX1^U#'"]<6+UWD[IT?V'ZR3M9H4KHI_<,#FLTVEWMOTYA?(,E2G"N)
MTQ0W&J&UYOQB$Y-T9F'V![><E/\`E7_?Z"RQ=/4J154Q/#YD-![C?0#1V"1%
M:<W^^F\$7Q$0:@]9XIEK=T]"#+GQ`EQ4?(C*OB-:]-?>?8_>.V\21&&U1AF#
MS3)\Y;!IRL7>=5KG%T$@3VH6%CJ(O>"1^":BME^>BN6.VEJ[RZ\__D1L<FS6
M(&TOH+5":T^:)K3/S9&WNR=@W?K[5'PQSX<K;OR42?\(-QD1Q*"4(LDLR=P\
M)EX`TW[U/'_^$LDM@ELF3"&$WFQ!0$P?L9O_Z!*]Y(8"W!'1W_)_UN^:0M;7
M4-[QB`````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\S-"YP;F<`````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-C8S`#$P-#$W
M,S8S,#$S`#`R-3$U-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*``
M```'=$E-10?4`0P.`QN9&]6T````!F)+1T0`_P#_`/^@O:>3````"7!(67,`
M``L2```+$@'2W7[\```%0$E$051(QZV5:VQ391C'BT-1(D8C&(W(*D82/OF!
M!*?A`\9$)CC$$6/\XB51F2'$C#"\0,*XN"T,!<H(H)ML0UR8&=VEFX-MI5MW
MZ;IV:W>ZGO6<;=VY]/3TWL/6K>U6_KYE@I+Q`1-.\L_SGI/W_,YSGO=]_X]*
M]8"71QS/(D(ZJA[V=:.U.(L(Z?A0@#Y9T(9#D@8I61WT]CFZZS<CX.ER("6I
MX_&8)A3TTHE$8N^=^:E4ZEFB%Q>!9*^T@AT=S!,%-D]1E`Q@_G6;12L,]Y]`
M(M8)WV@11IM60:*+<"MAQ,1H'7IOG$0R&2].)I,9H9"<Y_.)G63\TR)X.!Q6
M,W0GS(:#$#BJD63'^/AR6.M>@6]P!YS-;T+0+L.([C5$V4]`7]\`6]<^I.=-
M384:A[J/PVEK)FO"J1?!2;9+O!X^UV8\$&!;U\/5^R7\UITPG<T$<V$-(I>>
MA_+[<^`K5F.X8AV<M6L@FC^$Y#H"JCT'PX8O(`J,9FXN^<0B."G#7E*_8@\_
MQ%AU6T%=?1M#=9]C['H^I+Y"2):3\-G.(#!\]G9DC3]CI.<L;(8BC!GSP3KU
MB,=G,3\_?_@>,%F$`ED6XR[:!#?;`EMW"1PMWT`P%L`W=!1AYC04L0%1V0@E
M:$<DX(*/ZP9+7<?P0!,8>S,DP0*_WP-%B<;GYN8.D=HONP,_*4EN&-M+86S)
M@[FI`*)^#Y2!78C;/\;LR$>89;]"S%V`:;$$T\(E!+DF"'0SZ"$=[)9Z4)8Z
M6$Q_@F5LF)F9`?E`]EUX/#X##]\!JN<P[*U'(/07(TP50J%_P!2['[')?,2$
M?$SS^W"3/88@4P:/_0+8@6K835?@,)6!9]MP4XFD2P/"S%9-W0SOCH3$N"S:
M,3YR$5;](3`=!R'U'X4R>A13$X6(B=]A1MJ'N%QP.\:X;Q%ECL/K^`43`[_!
MWEL-UEH!]T@E?)X!!&1:2T[R)I7D&8>QK00]NIV@6G:`OD86L?T`^-YC\-M+
M$':5(LH70?$48<I7@BA7B/#8042=A?#:3H,SEV&H[02XSEV@=)O17?\6NJX=
M`L^YH!)X)DO?_'V6S-]P<-1Q##:1/5R3#5&W#;(^!Y)Y.]D=1/:<!0V1YX-;
MX>\ATF\#?W4SG#7;8&_9@DFJ&#[!X$CS)B?I?VTB&8]\&I5K,=JV"=2IQY&J
M(;M3IT+*H,(M$Y&%W%M)-)-GG61\C8SK59#+5\!1]3(XT[N(1=N0FO,L/D2B
M,$KWM.Z&I7$#1JHR$:U:!EPED%8":2-`(U$/&7<L@-&@0N*/#'`$3%W.A+GV
M55@,^\GI=FH6P:/1L%:)<,),M`&NEHVP:9Y"M/)1W+I"0"1#-/\CW4+&B<N/
MP'W^&0R6KX78MP6*OQ8NNDL0!;?VOBZ8-BMATL!,UJV$N_I)L%6KX?GU:03+
M'T/RTA(B%92+2V^7@KNH)G^X#F+=8QAN?`.QZ3$F_?Y]P6EO&1]SY%*&SP*.
MOS:"&]R#J9'W8*E8!:92C;'J=1@H6PGJ?"8F:M9CN/(%^/IR0'?DPJ-_B6S'
M,X'X[,SV^\)#H>""*W:6(!3PW..*WH'WX>U\!S+)TD;`OL%<.)O6PN,LQ?R<
MR%A-5QI-[?MA-3><"X=#RQ?!!8%;P1`_]WFY/')\_^/GI4A,&Q#A3F&2^+F[
M]VLD8]V@S!KT=U4(Z7GCXW2&>\)Q+A24$(O%U`_4B41^0AOPBYITYZ'-9SX8
M:LD&[](JZ<X4"$@:AK'=73QB5,N)U$1+_W?+HZQ-62;]CY`]MLA#;]#AL#]+
MY!GX9&[W@[[S-^18B)Q:5U_:`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,U+G!N
M9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(R-C8`,3`T,3<S-C,P,3,`,#(U,34W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X#,MNI3=@````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1#241!5$C'
MU97+:UQE&,:?<YE;)I-,YIK,3&(R32?5I+01;;$4<2#HHF+$12&("KJ4+FSU
M'W`G"%V9A2"ZTTH1!$-!$QBJTEA-,DD3DR:3R67N]SEGSIDS]_&=$1<UF49P
MHP?.8B[?[WV^YWV^]P/^KP_SN!_]JWZ'P=!WI52M74\E4]!H>)0K=;"H0Z52
M@>%X=&E5L-OL4/'\O40B_J')9`K;[?;:8^&)1.+BUG;@=K7)N'I[C=#IM"U`
M>T&CV03+<2B72E#*9<1C<8CY#(8'G1CS>-ZU6JVS+0;?";ZTO/*JP6AV&;1:
M\`1J@?G6R[&0Y"*RV1Q^NW\/LBPCFQ-0JS50K=3@=KNOT?+.\-W=W><?K&^]
M+XHB!HU&,`R#`D%:JEM%<KD<8K$H'FYMXZDS8W#V6QL,R]\]Y1Z&3JLY_(MS
M+/RSS[]@K?8!WN%T(1&+P>%T0BI(;6NT&@U*9(>0+\#I&L#,S%6?3J>;H_?C
MOW/8X^#3KTQ_DLOEVS94Z@U$R--8,DUJ$PCL!E$LEG`8CJ"D**C7ZXO'@3O"
M]_;WW:%P##E!1*M(<&\?IIYN5*I5A*)Q_+KDQ_;6%B6G!H[ZT>DY8HNB*#=F
MWGQ;9;4[:/MER%*1(%50<L"P+,KE"O)YL1VT="K;4MX1?D3YK:^_N=QGMG-V
M>S\EH8AD.H,D65*4%7#4T4AK1]D,P*F0SF;QW=P=IR05>OX1?/'^"LP6"U*I
M#'9V@NVD#`TYH5;Q!&=AZ.YJ_\]H)!ZOPH/U]3=\OKM/GPB?7UA0[P2V53N;
MFRA2LQJ-.LZ,C:):K6#O((R]PS`X:K+59J'3JD-?KPG[D126US9NTEI]1SAY
MK2<_9_4ZS16EY75!I/@5L+GY$*O^-22CAY228KM@A7SGR"-;OPUZ?1=^^'[^
M?#@:]Y'_H\<VE&)GI2:]D\OGR>,4U&H-]-T&B(*`6.20E&I0D`IMY26E]&=*
MR#*69@S+,EA>67WFR;'34X0*'!E<5)4[.`C=F)_W?>2C$]C<#\+59X9BM:`[
MET&E$<*`8Q$;2P44[&_!27LV]9J15O/HS6<"8R/#DM?K%1T.QU4JG'A$.7U1
MEZ2B>&YR$FP\BM.7GD.TT8"KBQ0G]V`Q?PJ7+8[9\``,IT;@/3>)$*6)5^3%
MT<&!U\?')X(=/:=,]P?W0N_]F,EAT&*"3/'UBQ)D(4,*;T$2BEA9->.)P1I,
M:"*6I\]"`8HL^8X#/P)?_,6O73N(>"*9-*PT"85*&=I4"&+Z2QBZ[N#;N8LH
M,U/8"-IA-O8A59)AJ94%[^5+OY]X0HV&;M0T:GB-.@P/#UW+"\++0OGGET8\
M7V'A)R>>O?`:&II^3%X0E(FSX]</:,YPK#Y-%\/M$^&#0P/A;K$PPC!-FLN5
M`UD2U.<GI!=BR2F-U38==;O/OEAA.+EG:+3A\7@.__4=F,_G/M@-;-],I].3
M_[D+^@_>]/GVV2>O<`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O,S8N<&YG````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8T,0`Q,#0Q
M-S,V,S`Q,P`P,C4Q-34`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@
M````!W1)344'U`$,#@0-(H[V(@````9B2T=$`/\`_P#_H+VGDP````EP2%ES
M```+$@``"Q(!TMU^_```!2Y)1$%42,>ME6M,DU<8Q]_W;0O>F/,RLV11B\O,
MW)?-Q6BW^<68;'Z93OVTF8ULB1O+W*8N3G?S@L$H4T,:400<0PW,BA0H*CB@
M@*50;J6E]/)2+NW;*RV]0&NAI?QW*FPN*4M<XDE.3L[).;_SG/]SGN>AJ*=L
M=MN@B'0D1NI9-T5]MJBY+AL-][.?#=SMLDE]8TXQXD[AF/.A3EFY%5Y'BRXQ
MGYR<$/O&7(;IZ>CAO_?'X[$5I+^4!'(Y;6FLL3N3LPYD!H-!'MFT1=UYA^OO
M.(]HN!EN\UD8JY>#ZS^!F:@"PZ9R*)NN8#H:KD4\O-KG<V9Z1JW-L=CDA21X
M(.`7#AB;T=%T')REMQIQ!SMJ*82N8@T\7>]CZ.XFN"KY,-_=B(#A0Q@;WT1/
MTW?`>!]"`:=2W9H#O48&A]TB3(*'0B':Z;#N43_\V</6KL-`ZT?PJ;9#=2$5
M`SD"A(L83!=3>%3`8"PO!>X;?#AKMB!0M1MLV5OP%KP.1]WI`T0!>EZ-$U)X
M1S6L4?8:["4"#.<M1*"`QN19&LYL&H]R&;A.THAFT0C_0,-[/`V!HP)$?Z00
MRD['1$M1+3%R6?)7LX](+4-M7-A7#F?+VS"+!0@5TYBIH#!UGL&E?0LQ=(0'
MZ3X>!O8S:-G+8/@+&K5[>7#OI]'X^?-HD5R$W^>YFP0?&=2(.QH.H:L\'8WG
MTV"_Q&#F#@74$2FN+H#L2S[8GW@H^Y2']J\%*-R?BL%?&.1E+((E2X"\`R_@
MWJW/8#*J#$GPZ*1%..&K@[7U/4B/+87[*@/("+R!P/^@476(!_4Y'FX=Y*'[
M%(.*0WP,BVE<R^3#=IE&Z:DUL+%%"`8<&4_^LMLF:F^Z(-*V'M[M'#B'OGM;
MD9NQ!),W:*"&P!44(G(*OW^?"I-D,23$^OYB!J7'>#"5\%!^F#BVG$'9KZMA
MTY]&(AX2`4>^M(ARV(?1_.`,%%7;8:A8"7-9"BY^O!B1?\'#;0PZRE)A5RZ%
MJC0%'CD?([(4J(L6P'*9@:8P#:I\/O05RZ&L>`?RVM.P6DR@."LK>E!S4N2T
M-.ILNA/HD+R!,_O2X"R<DZ69PHR*0DQ#8UK/0TQ+(ZXFKZDGOZB21N@Z`\.U
M5V"XLQ%6<MYMD>L2/,N(\4F:F)H*9/A=%3`V;47>MRO1<IR'&2F!_SEK/<@%
MT)#>,S=/K%=1&"U>`L/UE\$I=R`<J$<\YD@.(JM%;U#4?H/.ZLUHN+P>MX\L
M0ZB$2%,]!Y+/0>5S<[(>*V5@O[D&^AOKT"E)1Y?\"(GN?O$\X>^3!OU#7"18
M"7W-)DBSEJ/^Q))9[2NI68EJYL;*63!7\!QQ;CK<;3LP[KD-D_XA9[,-2_\S
M0FTC3:Q9N@KFTC2TYF]`]\45Q&DIY!4,HC>)<XG&7B)%PF)=R3HX;PN@E6U!
M:-S,)L[/"R:9D&99[1YMPR>>OON;,=)[$..Z#]!6M`I]OPEA)$Y3Y*R"-G\M
M1FZ]"FW)BW"KWH5!O@N6AM7H58H]X=#$SGGA8V->H<G0A+:&+'@]ML=9T6TM
M0(]T/5R=.S&JV(;12@'4D@WP].R"3K86P_UBDG(Y5JV25+?7'X6ZH_J*W^=;
M-$\9LY)\KLYTNZR9D4@D*9\'N%Q89"MA4F:2>0OZ.G*AD.=SB7TLV\\;,FNO
M^,8<B$0>"9^J$MFX(:G78W]<B0Q=.;M[[FV#U20-(NX6>CP.\="@YA_G$8,6
MQ6)30G(9_W^7O-YNJ:A=?@9NA];_S`NTWS\JLG,#(*7LJZ<]\Q=RQ0HEN9,4
MIP````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-RYP
M;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,3<R`#$P-#$W,S8S,#$S`#`R-3$U-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.!"J'A$-)````
M!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$!TE$051(
MQ]V56TP39A3'?5JVQ$4?%I(MF:F)(7%!-S(R9FBP;+&8,%@!A3&A@..68;ET
M*B7"8+K0%A!PZ.2N0)%+6]H*K(*TY6(!2TOO!5HT&.F8*9,"`V2$_/?).PAC
M3_N2\W;R.Y?_.>?;M^]_^UZ^G-]O=SRA*/L&*(/#(Q1E_^"F]3\:I@QIM!2S
MU4I97%RD;&QL>.P*/*8WG-$:S'?-XW8,/=9"HS=A>'0,(UH]M$;+INE-9DS8
M'9B<M!MLMO&4V=G9=]\()DXQ#U4#[KYA+73F"4P^?0['M!-3SYP8GYJ&S3$-
MK6D<HP8K)%T]J*V]@YY>)=P+"W7;@DF9!T5B29-:,P:]U0ZCS0&+_2F!/B/P
M&>A,-G3UJ/!=,@O1S'C$GT\`C\^'1J/!ZNIJZ[9PA4)):VIN@_B^'",Z(ZP$
M/&JT;9IIW($>U2,(VJ2HJ*R$4JDBT-'UWMY>CM/IY)#$#FP++RPJ#KU>5@ZA
MM`N=W0J2J14RN0H#KUM$6M&M&D!QV6UT='1.K*RL?+*^OGY\QT(^UFA766P.
MFH122#H?H+%5!MEO"C2+.U!1=P]EO]8@\?M,M`I%^EV/7U%QR6I2*AMU`B&J
MZIMQH^(.!$(9[C:WXV;M/;`NYH%Q-A8W;U7L#NYP/!&$142#S<D#GY2>5W`=
M6;E<7.65H[B\&A>O%"`N^0=$1"<C-"S"WC>H/K1C.*^P5)+]$Q_L[*LD0#XX
M^7SP2F^C]%8=JNM;P,GCX^RY)#`3TA`3GX*\:USNCN&1W\9)(F.22':9B(Y/
M175#"WZIK,>E'"YR?RY!/O<&4MDYI#6YB(I-05PBRVDT6?K?"&YH%!PY=3ID
M-(@1N9G=N?@+X)55()&5A=<!,[+R";P4*>G92+N42ZK@(38I':R,RW^WM(JH
M6X+)2+TG:&H9\@\(A-=Q'WSZ&15^_G0$T(/A[4,%E49'^#=,1#$3$,2((H)&
M(^CK"`1^%8X3U"^0SKXLV1).9O4#4M[SU`MI^/R$'S[V]L%)&@T,1BAH`5_"
MZY@7/#T]</3H89RB!\+_9`!"0A@(#@Y!6/@9M$NDK\AV,K<,,#,SXZM6J^UB
ML1@-C8UH:Q/^5555S2WD7[%QKWV$HH)W\&-.U"N12"23R^5D0ZO*9;+[*N+7
MI-/IN&MK:[[;]ITX>+G=;AHY7+2YN3_]%(H'P1V2H!?ZD?VPZ-Y&OR)IGOAX
M+"\OTY:6EMXBI_80L8.[7B:7:S;4J"^!PWP`-94,]/<<QO!@Y/R>/PDB,$.G
MJ9Z;,'Z(AUWO8TQ';HR&@S%M\][A(^H,[I3E"+JDONB6USB7EY<D"PM_Y+A<
M,_0]PU_\SN,:M)E0*-JM1&CO__3O)&)Y3CDF3KM<KF/_EO$/_32U3W/CF=T`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S,X+G!N9P``````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-S<`,3`T
M,3<S-C,P,3,`,#(U,38S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4
MH`````=T24U%!]0!#`X%`JLJVO(````&8DM'1`#_`/\`_Z"]IY,````)<$A9
M<P``"Q(```L2`=+=?OP```0,241!5$C'W95K3)-7&,?]M&R)BWY82+9DIF8+
MF7%N<W-A!"+%Q<HB,$J`;@+%H5@,E)LP2@0!S5HJ<AE(N(-"P5):2A%$NK:L
MU`(K+:7T`K1@<-`Q`Y/;`!DA_YWQ'82Q3WN3?][SX3F_\YSG=@X<^-]^+U[,
M'[0[)BC*GEZ*IJ^?HE1K*"HB]9,^2J].3S%;;)2EI27*YN:FRY[`@\:A(/V0
M^9YYQ`ZMS@B=<1A]`X/HUQNA-UFV9"0:M3LP-F8?LMI&HF=F9MY\)9@8A<M5
M/0OJ/CT,YE&,/9V"8]*)B5^=&!F?A,TQ"?WP"`:&+&CMD*.ZNA9RA0H+BXLU
M.X+)-0\W2Z0-6MT@C-8QF&QV6,8F"/09QI]-PS!L0X>\&U'1,0AC1N)B)`LY
M?#YT.AW6UM::=H0KE2JJH%$$25LG^@TF6.U/,6"R;6EXQ`%Y]Q,T-$E15EX.
ME:J;0`<V%`H%Q^ET<HACAW:$W\[-I><5%J.YM0/M7<HM3]L>J]#S3XA(*.3=
M&O#S2]#VL'UT=77UDXV-C8]VG<A?=/JUN*14"$122-L?H[Y)!MDC!822ARBK
M;411:0VBKL:C220V[KG\<N_DK[%BDU`C:$95G1`_EM5"T"S#O0<MN%O=B+CD
M3-!#F+A;4KHW.*EI06!(.!(Y6>`7E"*+FX?O,[BXR2_"G>)*)%_G(N+*-02%
M1L&/SK#_K-$>V36<R\^7IF7SD9B6C23.37`R^<@I*$-!234J[S]`6F8.`;/`
MO,Q&Z,6KR+K%Y>T:SK@0(?TF/(IXEX"P2#8!"E%4<1\IZ3QDW,I#%J\0L=<R
MP$Z^`48X"Q&78IRF8:OZE>"Z>L'[9WW\![[R"][:&!H9"WYA.5CL5#"8T8A+
MR23P`D3'<\@Z@]PJ!]^QXL!.3/U+V"3VW!9,2NHM08.P][3W.1P_\1E.N7G"
MPXN&,S1_?/JY)SRI-`0Q0G&!>0GG`Q@("`[#^:]#X.,;"'>/,TA(3)%N"R>U
M^H[98IF*82?A"W</?'SR%+RHWJ#3`T'U_I(<>!RNKBXX=NPHSM+.X;27-WS]
MZ?#S\T=04#!:I*TO27<RMSU@>GK:3:O5VB42">KJZR$2-?]945'!N\V_;OLA
M^P/D<M_`C?1O7XK%8EEG9R?IT(IBF:RMF]@UZ`T&WOKZNMN.<2<&'RXL+%#)
MX*+.S?WAH5)U^;5+?9\;^P_"8G@=:N65>6+CLK*R0EU>7GZ-C-HC1(?WW$RS
MLS-TDS$?#O,A5)4'0"T_BCX-8W[?CP1)<(!!5SDW:GH7/W6\C4$#F3$Z#ODW
M[!_>KTW@C5O?0T>K.[HZJYPK*\O2Q<7?T^?FIFC[AC__+8<WI(^'4MEB)8D^
M^9^^G219KN..49_9V=D3_Y;Q-[DCM4"!``@K`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,SDN
M<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,W-``Q,#0Q-S,V,S`Q,P`P,C4Q-C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@447_YOHP``
M``9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!(E)1$%4
M2,?ME&M,FV44QTG\8C3&?22:+/O&![.,:<BBB0O;2+;(=!D0B0,!R\#"4"X=
M<FFYE;%"N;RT0*'E4@J4.RVTE-X+M`7*I2U@:2$ZV`04Q2G-YB!!]O<!$[0:
MDQG]9#S?SO.<]W?.>_[G.7Y^_WDKYPM/?L+(/J76Z$[^*\#5U=477*XE>EEE
M-9TODCRA:H7HE2F>'/H6ZT3`/X*/F\T"H;@#;5U],)HGX)A?@'[4@M+J>N2S
M.?;5M;6JOPU5:8TGU'J3I*12\+2C=P@RQ0A:NF3H5V@@5VHP:ID$3R3!^W')
M3ZOX=;L"47/*,\/+>`W!'*H!?4-JZ,>LL-IF(1O6HD^AAG5J&D,C>I14"9"8
MD8>PZ$2$1MS8[QE0?/B7P-W=W><<BRY_<;O47ZX<6>+R15#IQX_:T#.HAE#2
M@RZ9"EJ3!06<:M`9^>B4C9"D>I3R1&AHENRXEU=H[-(J_T>/'[_D`R<5G1HD
MU8E(C^N:V@AH&+VD\I[!$937B9&0R@2SA(?<$@H9S#M0:0U87OD"LXX%*+5C
M:)'VH:2"#V9Q.;3&<<H'KC.,-A1Q:U#;+"7!HQ!W#I#*QV"==J!:V(88^FU(
MNN6_GDW-8-&U!/O\(CKZ%*AI;,<,22)3Z?!Q!@M,-F?EN^WM,\?PG()B#T_4
MAL:./C@77)#V#Q,1!U%8+D#.'0HJC8&<+\+M689E:I;$]8-UEX<;":E(S2E&
M:Y<<C+R["(]-1B:S`':[_<HQO$DL\:1FY4/4UGO4XT)N'1+3F8B(2P&;_-&A
MJ!K#&%0Z$PXGZ-9G1;@:2<.E:U&(2<H\TB`Z,0T?Q">#D96+^?GYW^#WO]J8
M2^4W(B0F`<'7(G`^/`H!@4$(#'D7`:=?Q_6T')Q[^P)"Z6D(N1J&H'?"<>;-
M8)R]&(J@T`@$7KB"\]$W<?J-<Q"*1'M;6UN7CN&>[1]C<S46O)>8@@IA$W)*
M*T"CZA'.YH+&8N,C<3?B:/&HD/8BDI:(V"XE+H9%@G8[&TF9N:`WM".278KB
MLBKO^L9&C(^@GJWM!"9I24UC"QHF[&2^S6";II%:R,&P>1(Z,M_]MCETF\P8
MFII#DG00Z>P25)&),EFL8"A,2&)SB-`NCP_XX.#@5?W*?;MYUH%^APOQ1-CZ
MEE9,NSQ03\X@7S\!46</N#,NW&05P#SGQ(3="4IO`4W0#+&T$W.>%4S:IM?O
MW5M]S0?^S<XCBF6V(X];B8I1&[)**U&N,B*]G(_VF7E$\YO`;6I%.JFVN)J/
M(J41+?URL!0&Y/`$8`]JP&F5PNETRO?W]U_V@?/M;BJY2X'ZQN:?U[[=WK6Y
MW&!IK4AB%8)GFL*G7`H+2^X]]^J#7;5]\2"^6X%:H0B>!^M[XXZ%?:;M<S"8
M+%BMUDH"?]X'WNM8HL1RY4\ZG9Y^Z'_Y@]=$D6<]8C#N$9-[O5[YSL[.BX=W
M[4[W%#6@A,UFLY.S$QT.3S;/.($!F>QK\G`N_VFOD)Z_13)&_6[/O/+]PX?T
M':\WYH^Q)-EULN?I9"*.]CGY[NSFYN:A?]GO?WL6^P4/`3VM%.T+I0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\T+G!N9P``````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C<R`#$P
M-#$W,S8S,#$S`#`R-3`W,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`J
MU*`````'=$E-10?4`0P.""8BAT!N````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,```L2```+$@'2W7[\```$1TE$051(Q]65RV\;51C%S[QL)['K^!6[MI.T
M3G"K)E531*F@J"*HHHNB%@FI4D'=P!)U00O_`#LDI*XH"X1@AXJ*A)!:'B%2
M6A!)2TGLM$J"8^=A.X['[\>,QY[Q@\]&+$KC!HD-C'3ED4?W=\\]Y_ON!?ZO
M#_.DCX%@P&TR6<[4M/IE,9V&H-.AH2J=:3I!`,/QZ#4(<`XXP?/\K"@FW[=9
MK7&GTUE_(EP4Q>,KH?"->HOQ[NGO1X_!`('G.Q,:K18XCH.B5%%3:TAN;Z-4
MR&%XT(.#?O_;#H?C6IO!=X//+RR\:C3;O":"\@0B97\.CD59KB"?*^#>W5]0
MJ<C(YXNHUYNH:PV,^'R7:'IW>"02.?G@X<J[S5()@_UF,`P+698[W]H+%/)Y
M;"<2"/T>PJ&#!^!U.9HLQ]_Q[1^F'>JC?W%VA'_ZV>>LW;F7]WB\$`GB]@Y"
MDF08:!<&O1[5:A7%8AE>[UZ\?N'\3$]/STT:'_Z=P^X$/W?VW$<%VJH@\%`;
M36QMBT@FTZ0VB7`D0E94$(UMH:HH:#0:<SN!N\+7-S9\L7@"N4()^4(1:^OK
M,)N-4.L:XELB[MT/DB7+%&:]$VRWYS%;%$6Y<N'BFX+#Y4:M6H,L50BB864U
M`I9A2&T5!5JTK2N3SK65=X4_IOS+ZU^_8+$[.9?3!8FJ(IW.(I7*0*%%6"K$
M1$+L!,IP`C*Y+&[>^M8C2>4]_P@^>_\WV.QVI#)YK*ZN@6%9#`UY.OZS]&XR
M]E%W,&03\3@=@HL/+\[,W'EZ5_C4]+1N+;(JA):7.J$UFPT</#`"35.QL1G'
M9C0&3N`PX+!2Y?3`:K$BMIW&0G#I*LWMZPHGK_M45;UF,`AGJFVORP4:92PM
MAQ`(+"*5B$)I+T@>:S65@F3@&!@`50J^_V%J(IY(SI#_HSL&2LWA0(MYJ]UM
MHIB"GFK::#)1>%DDJ=;U!CW*Y1(I%SJA<M2IY!FH>>B'P4(@^,RA`T^=(E3X
ML8.+5N4V-V-7IGZ\_<'M7`ZMZ!H\%CL4NPVF?!9:*P:[_2Z6`V7(KHOP\"RL
M9ALRE(6YD`G[]^^37IJ<++G=[O-4GN(CRNF/AB152A-')\`G$Q@]\1P2S18\
MO3I(J778K)_`.R#BXY03)M\()H],($8V\55Y;M1S\HVQL?&UKG5./KM"JQOO
M_)S-8YS4RK4F`N2Y10,IO`ZI*&,^:<'(<`UU-+%=J&!>*>.P5IG9"?Q(H'._
M+A@6HW%_/)N!@_PMJBH,Z2V4,E_`U/,=OKGU+#3V%()A-VS]%J2J,AQ:K3AY
MXOFE73NTW]B+ND[`I+D7^_8-72J6'KQ24G\Z/7+H*TS/#N'8\=?0TKMP]%A1
M&3\\=CE,YXV>[<O0Q7!C5_C@H#=N+)7W,TP+FJIN2N6B[LB8].)68E+OL)]-
M^'SC+]-)(AN]HTV_WQ_]UW=@H9!_+Q(.7<UD,D?_<Q?T'VJ\^9(;T?Y@````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0P
M+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(S-3$`,3`T,3<S-C,P,3,`,#(U,30V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X&!1YC')(`
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1V241!
M5$C'[91;3-IW%,=]7/;4+'M:MJ0/>URR+%O:+&MVL75MTZBS,=;82[051[56
MNU:GM>*\(:#R1U$$5`3Q@H`@"%[X"P(B%`'%6K5BZV4V6^IM=?$6C'[WKP^F
M36O2-'M:=I+?R^_W.Y]S?M]SSB\DY'][5_.-CIUB%+'IN05,^I.9V81_!;JR
MLLJUV!U:ODCR5*Y0HU6E06.K.MC0U*9=6UL+?2?HQN;FD<FI:5EY5>V>N+$-
MAEXSG&XO[GN&T6L9`(L0HIA-!/L'G.-^_^CW5*`C;PUW>WRRZKI&B&0*M.N[
MH::6I$4#94<7NLE^D!8[2@@!PB\D((M1"(&X0?96X!=9\(7UVU*%%J1U$![?
M"!PN-U04V&QU8,@W#)Y0BK3L8MQC\I!P(PN1L5?W^LQ603`8?/^-T.65E2BY
M0A5/`7R\F@:T:(PPDG8T*O7@B>0HJ:B%K$V'RMHFT-+N@L438L#E09_-"6FK
M%C5B"13M.FEQ:64\)>NQ5^!-"O5D55T3!'5RZOG=J*<<#"8;FE5Z9!5PD70K
M!YPJ"3+SRU`K;8'_P4-,!0*P.X?0T6W9OU=-^6;FL2`0BH@#L,EL97(J1+O\
MNF9H#29T]EK1I#901?1!KM3A%P8+^:55<`X-8^3!V#[8ZKB/+M**?$XER@42
M>(?]:&AIQ^7K&2@IYV\O+2V=W(?_RB@B"*$,-0T*#'G]5`%[\")0$5=(:5N$
M9K4>P_XQC$\^PL.)2:CTO2BD.B8A]2XB8FFXD\<!FU\/6GH.XI,S4,#BXO'T
M])E]>.#Q##./R=TM+.-#+%>A@,HR*3T;YZ\D(RHN$3RQ;#^`6-J*9HT!O[$K
M$9-P`Z'A<3CUTR5<_/DVXF]FXTI2&N+BZ>!5\C$[,W/F0)IGRZO"@K8.G+A&
MQX_G(A!^-1F?'?L&9Z/C$,GFXWCH:5R@I2+LSCV<^"$,D3$7\>7I"'S]71C.
M7[N)LX4<7$I,0BZ#@4&7>XHJZN<'\/KAJ:/%5@_.T>B0*C4HJV]$4W,K^,8^
M1(OEX'!YT/<[D$Y4H[9.`H%*A[(:(:JJQ$A5&)`BK(-&VR$UFRWQBXM+KW;+
M[W_][6PGS6AM4Z+(.H0D+A^34P&0_G%DL`F03C=*30.PN#TP><=`;^]!>U?O
M$X=[1,*0-D.MTSW?W-R,?JW'%U?73C*]$XL9!!].GQ\T=1?2<ABP>$;![K'!
M8K-#1`6,$3:@Q]*/2M*!J!("UD$WE)XQ-/:8=RB-+[]Q@-2/YHD4LPN)UU,P
M/3L?%"M4T'<:P1\<02R+AZX>$KG==M`*F=!J.S(--@<J*&FZ!SR@:TS@M:FW
M#AUYW=0\D5%&0"@2S5)Z':?&6/GTCV=:5J_U^>VL7,S.S7N<+G?0:#1.!@*!
M+[:VMK3KZ^M:->G83J3DL[M<A\,W-C:)\8F)Y<Y.P[<O[WN]WA&;S>:DGOSI
M^L9&`O7O?/7R^>S<W)\FDL3"P@+G4/CN[MX'.SL['[]6B\6ECZCUX6%^R\O+
MG\S-S1^E[KP7\I^R?P#<:#&%9C&U^0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O-#$N<&YG````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q-``Q
M,#0Q-S,V,S`Q,P`P,C4Q-#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@
M*M2@````!W1)344'U`$,#@8:DVL19P````9B2T=$`/\`_P#_H+VGDP````EP
M2%ES```+$@``"Q(!TMU^_```!%E)1$%42,?=E<M/8W44QV?A0J,+38R+V4C,
MN"/&U;"=C8:%"Q<NC(D9EOX#8V9ET`TCSH",$T">!2E]3I_T01^4ODM;6DKI
MNZ4MO>WM^T$+!H;QZ[E=,#%,%(V)B4U^Z;V_<^_GG-_W/.Z-&__+7Z_7NYE.
M9P98MCP;"`1B-ILM5B@P?I/)-'!^?O[&/P9WCH^'C@I,(9[,H%9OX.3D!)5:
M`S:G%S*9"J%0B-=H-C_[V^!NMSO(%(O)3*Z`<K6.8KF!`EM'+,T@E6,AE9O!
M6Y5!+)&V69:5D^/!:\.SN7R'K3;0/3D%6VW#[4]!K?=BQQ^C^R8T1A\>38DP
M/:_`@_&?Z22*;K%8_&L'S5;GRX-([!D7*4,1AQ-%.+PI;-E#8&@OFBA@36B&
MWAS`;BB##;T'/SV9@UZ_*3\[._N4UEM7H(U&0QX(!(.)1+*=+Y3@"Z7@V4W`
M9-V'4&;M+Y,U!*%T&YLF'ZJU%HY[/>28&B+Q++0Z0]M@W*H+!(((L>Y=@H^.
MCF[[`P>E<"S?U]3A/8#1ZL=AODS744Q-2Z#0N!!),@A'#M$Y[J+;.T6>J6(G
MD`!;::#6Z,#B"./!]Q.8F9F9O(13YB?WHQDH=6YD<B7$,PP"!X>()!C:\T"E
M<R%U6.SGH$=5DZ8`7+XHGJKL6.;KL1_-PN&)X!>!">/CCS$Z.OH"OK>W-YG)
M'1$LAQ)%X?;%L;&Y@Q6^`>MB,U5,$\?='JCN428YM$8O)5.)AY,"+/"T$"MM
MX*WIH=BP$WP"L[.S+^!42L/1:+1F=[JAUIH@4^HQM[".AQ-S^/'Q$K1Z,\P6
M&WP^/RQ6%_A")2:FEO'#HT7,SJ]#)%%#KM1A72#!TM)2+1Z/#_^Q:3J=C[/9
M[&DP&(16J^VO:"SV6RJ5.K':;%PU8'5U%1L:#187%R&7*^"D8.QV!SP>#]GU
M_7V[W3[\LL9YG>19X.#T`%0J%79W=UF*8F1[VPJU6MUWN+*R`JE4BG`X[$FG
MTWH.GLOEL+6U!8O%PCFZ>P5.L@Q8K=9+@$0B`<V2>^3@EMEL]G`V#JI0*+"\
MO(P=KW>$YLNJW^^'4"B"2"2B`#9`][$K\'*Y?+/$L@6OUXN%A<6N7"ZO*)7*
M#SE;,IE\4Z?3!3A9*+I,(IG@DOM-HU'_RN%P5!*)1(@[&4GS-07Y]DN[$\!0
M)!))T@,62O(80:=(IOLTP.Y7*M7W6ZW6&$$_H%8'M^KU&FAJ6EKMSGOTWABM
MH3]M_XN+B\'GSR]&6+:4ETJ?0BP6PV0R([BW]PXY?X7L\YS&7!*YO'`ZGYV=
M?W3MP<4PS!W2&VMK:W"Y7'VM?3Z?F^"?4R*;!H.A'SF?OPZ2!23IK]>&-YO-
M.]2U_<@HF03A<Q7AYFP:C>8+A\,)^@>/Q^O;:7Q<'TY'?[50*'PK%`IC-(AB
M3J<S1@YO<3:JD"<<>--@*%$"GY'CZ7:[_>Z_\NFCNG\M?'`PZ?7Y;AN-QN]D
M,MDG_\DW^'>LX.MGIJPOSP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T
M,BYP;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,S$R`#$P-#$W,S8S,#$S`#`R-3$T-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.!B_%V-5$
M````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$5TE$
M051(Q]V5R6\;=13'>^``@@-(B$,O1*C<(L2IN?8"RH$#!PX("9$C_T!13RAP
MB1K:F)0J25N;.B&.G=C8\1+O2[P[MN,%[UOL>&R/G7@<.[:#DJ9\>>-#*Y0*
M`D)"8J2?-+]Y,Y_W?M^WS)4K_\MK,!A<+19+8RS;7(I$(AFGRY5AF%K8:K6.
MG9V=O?:/P;WCXXEJM<9D<B4<MML8#H=H'G!P>H)0*C6(Q^-BKM/YY&^#^_W^
M>*U>SY?*#%@",BR'>K.-?*F&0IF%0F7'XQ45-N2*;H-E58/A</S2\')EO\>V
MVA@,A@0_@B]<@-88Q$XX0_L.MBPAW)W?P,(#!6[/+M))-OOU>OVO'1P='7V>
M3&6>,(TV1<LAD:O#$RS`[HZAQK:1SC%8E=E@LD6P&R]ARQC`#_<?PF@TJ4Y/
M3S^F]<8%*,=U5)%(-)K+Y;L5AD4H7H!_-PNK,P:9TDEKF^[CD"FV8;*&<7!X
MA./^$.5:&\EL!7J#N6NVV-M2J33%<=S-9^!JM7H]'$DT$ID*:=J@2),P.\,H
M[;-TG\;\@@*;6SZD\PP2Z3(HV>B39/NU%@*1'!HDW0'7@\.3P,SM.2PN+@J>
MP2GS@D1Z#YL&'XJ5!K(E!I'D'E(D@=H0@(:>Y_?JZ`]/"'I"[[#PAM)0J%UX
M+#'B%W+H]B?QD]2*V=E[F)Z>?@Z/QF*"O4J58!4T6AWX0UGH3#L0KYDAD=NH
M!#LD09_``[3:71A(E@6A!G>^ET*XK(=<[2$G)FSJW`2?P]+2TG,XE=)D*IT^
M='O]T.HM4*H->"A<PQW!(PCNB:`WV6"SNQ`*A^%P^2"1:3`W+\9W=T5X\&@-
MZW+MZ!NI5`Z1Z,?#;#8[^<>FZ?4^+)?+)]%H%'J]?K3HI=\*Q<*0.I.O!JRL
MK&!K:XL'0*7:A)>"<;L]"`0"9#?2<Q%<+M?DBQKGU5@L)N3A;K<;&HT&N[N[
M+#F8VM[>AE:K'3E<7EZ&0J%`(I$(%(M%(P^O5"JPV^UP.!R\HR\NP-/I])C3
MZ1Q%Q@/D<CD?Q4UR<,UFLP5X&P]5J]40B\78"0:G:+ZLA$DJF6P=Z^OK%(`.
MM,]<@#>;S:O4RDPP&(10*.JK5*H6@=[G;?E\_G6#P1#A9:%3E&A/W3OXFN/:
M7WH\GE8NEXOS)R-IOJ(@WWQA=P*82*52>7K!08-JAB#S)-.M*L/<:K5:[U+W
MSA#T/6IU\*O=/@1-34>WUWN'OINA-?&G[7]^?C[^].GY%,LV]A6*G[&QL0$:
ML:!\O$7.7R+[(UYC/HE\7GB=3\_./KCTX*K5:C=(;ZRNKL+G\XVT#H5"?H)_
M2HGLF,UFT-2$1+(VJA:2]-=+PSN=S@WJVE%DE,P1A*+U\S:JF,\\'N\H\7QB
M>3N-C\O#Z>@O,PSSC4PFR]`@RGB]W@PYO,;;J$+NZW0Z&$VF!B7PB40B6>AV
MNV__*[\^JOM7$LFD(!@*7;=8+-\JE<J/_I-_\.\1`.M1RR!1C0````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0S+G!N9P``````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,30`
M,3`T,3<S-C,P,3,`,#(U,34P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`X'!0=X+=,````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```19241!5$C'W57+3V-U%)Y_@(4+7;B:A0OC
MQLQ"^0-<."M7)JZ,\;'`Q,SH*#J2`8-`"V&8BXQ"`2D,E#XH[6WINZ5T@#YX
M%*&\+L,S4%J>27EV8'A\GO.+D7G$2*)QX4UNVIQ[[W?.^;[OG-^5*__+*YO-
MOKJTM'1U=755DT@DE(F)"263V8F'([&7_Q'PWMY>;C*92L[,S&-A<1';V]O8
MW-S$H]EY!'NBPR,C8WF'AX?O7PH,P"MTRV=G9W)O;Z_<U=4U:[%8X?8$$.CN
M@=<7I-^'D.U.Z/0RJN\WH:FI><=H-,IC8V.RR^62@\&@/#0T))^<G'SZ/`57
M-S8V$`Z'T=+2@K*R,K2WZU&F4J&BH@*UM76X>[<*G/#'DA*H5&H8C29ZIYW^
MJ]#6ID-U=34J*RN1R62D%\!75E9@,!CH(R.!U<+E<N/>/4E\K-/IT-#0@%`H
M)&)55570Z_54?1,D21+QTM)2F$RFS:.CHW>>`2=.78%`0``3)3";S7"[W:BI
MN4\5_836UE9HM5IT=W>CHZ.#0+6BD.;F9JC5:I#8HENWQS<W-36=\R=P.IU^
M>W!H.&VU.6&SV1")1"#+,@8'!Z$NKX#19$)C8Z.HU._WDZ`]?U2M11,E+"TM
M@\?C@:9!"X<GBJ'XR`4M4U-34ORW!'ZI?P"K;$-?7Y^HLK^_'[>_OP.GTXGZ
M^GI1,7=GL5A$5R0\5.H*:#3TS&S%SW4&V!PQF,R6"_"9F1GIT>PL^L,#T+4;
M</.K;_'%C7Q\\MD-?%=0CCN%Q2@N+D%A41$*"XMPZYL"?$S//OSH<^3?5J.@
ML!RW\G^`SN@CC`0<#L<%.`EPG:K?BD2BQ)D?MJX`]$8'M4F</K!0-T[X`R'1
MR<#``.S.;C1J.U%9]2L]EV$PV1$,11!Z&":WQ;9H'JX_[?$OCX^/LUM;6X("
M\BMQ:D`B,8Y%&B#R,,R=G8+G3OKU>KU4A!>1:`P^?X!$;0'Y6\2I2.7Y`9+.
MS\]!$\<M";Y93+O=#D51A)CL$G911X=9%#`\/(Q4*B5\;K5:0:80G2TL+*3(
MY]>>`:?)Q-S<G!@,]C.[@@=J9V<'T]/3PJ)\,Q@+.S\_+XKI(>>PP!QCEXV/
MCV-W=U=Z&CR'P-]\_/AQDL'JZNJXRG0T&LURTM/34^YD@>U),4Q.3H(II/TC
M_,U%\5QPE\ED\BV*Y[RP7XB:7`)3DQ7;::@\M!'37'TL%L/Z^KJ6DY`VHB.V
M*VO#])`A3NA]-254'QP<O/17R^L]ND.49)1!N%5>`TP3NX06DA#8Z_6)Z61Q
M.1%1]/5E-F,>"\M4D#`"E(>&>6YM;</&QB;1$A/B^GP^+"\O"P/05GQ"5^[?
M@;]!X'D$_N0PFQ7NT&@TM%]J!#74/D@7$6?;L6OB\3CSS.#O7J;Z(DHP30D4
M6L$*<:J,CH[2"911.$8)%*(H15/-^V2%3BBFZH-_[?@CT:[M[^]+).#K:VMK
M$OG]M?_\#/X=%^-$NJM;MP<`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M-#0N<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C<U,``Q,#0Q-S,V,S`Q,P`P,C4Q-34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@<7],%<
MFP````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!75)
M1$%42,>M56M,DV<8K:)!40S+_&%T,Q`3-]V/J=.-Z?RU+&0Q(=.QN2W+7,R2
ML;`M1C.3J5-'IFP!1"X"0KEU*U#`EEZP2+GUPJV4%FA+Z07:4EKX^O5"02Z]
MGGTT&<D&2USFFYSD^_&^)R?G.=]Y:+1G/'->:X;-9L&TS99,>]YGSBGT"GAE
M8+'J_C\YL'+9[9[5D4ZB`&$BT3>1X6,^^`0&O5J#\'1BP.\K(`A"Y_?[+__U
M)A()OTAAWSJR4&CI_+AN,-UB,:=[O=Z82,B1I5,60]1:C<"B#(NJ(ZC-?@6#
MLAQ$_%VPZBL@X+$0#`:RPD$BQN.VI!-.4AP,!G/7D0=6')^:QW\'E_T05JN9
MAY#-,*?Y&'6Y;\(@3<.\,!ZUMQ/`JSB)X$0*!/1CZ!3>`<(.P[*WE2?I*$%?
M_P!L]MG$=>2+GM9-R_;,;UV#I\$J>A\*X3<P=YS`@TL)N/GY;F1^^0(NG4O`
MM:^/091_&'>_VP=U>PJ>ZL]BE/\:\N_=)A6*P7..&6+3O_B\G!XD*N$3Q.+A
MY=THO+(?HEMQ&,N)@2)_+WKH*5!*6)#WBL"LSH*(?A3&VNW(NW$"ZM%N`Q!\
M:P/2X`\D,:8R&_MM"TX&3"V'47,E'I.%6S'/W`QYV>M0#CR!4:_!+.$$Y2TF
MS%.H8]8@Z\=4-%>E8'FN`0OS=MO"P@+GG^2?N>U-C0;IAY"6)Z'Z^LN8>;@%
M_L;-4%0?QTAO(UPN$O89)P:')]`[,$:1V]`_I$=A23.*[F>CKO(BZAFWH%&/
MZ-:G946;&)BKAT/V#H0_[T*$18.K+A82]D^8F24HM2X8)NV0R<>A&C5AAG"A
MM4,)-E^&MBX5RLH9:&RHA(LD?%0<OXB2NHF!9)7L^V13SU=GO::[4').0I.[
M$]*\@V@I_P":$3FT>BO4XQ;TR/7@/AZ`I$^##LDH]=V'28L=I,L%LW4:/!X?
M@I862&5]]5JM-IGFGFF'6G81QM9#</&WH_[&#@A^.X(^"1_#(\-04BJEE`V3
M5@>>="I12A=@4&6`0J6/$GL\GM7X06>8@I-TPV2>!H/9#+E<#IK;SDD>Z_DH
MV6,3:!R:ZV@K.XXG#7<A[AV%2CT1O:S6F3%&J6]I4Z!+-D(-E:1FX(J2#@T;
MP1/V@\/OP9C!B@[Q"$K+F6AO;\.:Y\$5PX7EF7P8A<?1Q<V"T3`.J\V!T3%+
M5'$U4X2VSJ&HNE4;5M&KT(->+41!,1L-'"G8@CYJ!KVHKF&@N[L#:VEQV3ES
MRM8TB)FGT%V9#!/W`J3L6Q#6W@2C-!-%.3?`*+Z*#FX>1$V_H$]$1UU-'DJ*
M<E%27`IZ21:*BO+0T,0%F\/%T)`R9RWG"SY"Y?-:;,M>!LS<)(@R$S!;N0/S
M];$@67%P1K$-\YSM\#"WP5>U$\/Y5!WD'H3DT1D8-0RHE&*;7F_D"X6/]VBU
MFMB_Q3$2)M)#]JNP-.X"G<KZ4-D!.*L2X*G<BE`M#?X_:)BKBH&S,AYVQCYX
MFW=`6AP/>NX9/%VP;/R'1M5'YO<'/&R]57P:Y;GG,2RYBCG%V^C,WX/V@@,P
M5B1!G)<(36D2IEF[P<T^`'+P/7CZ#Z'Q_A&TM`C(I:6EU`W)PR&?SJ2I0#.;
M#I(DHJTXKTT#\]X;T(K3$)#LA8C*/R/[*%:TIU!QYU6,#5<AN*(SN,WYY*/:
M/,ADTA*JKN,V['.]7IT^,^M*IQ9`M,_'E85K?1Z:2$53WDO@/[J&R!(?`UV_
MHEW$M:U:$0X'4B=-RA*2=&)Q<3'QF38104RO;:(`6>QK*GL7_7V=/H0F$SVN
MZ0*]<7*MI"A!<102*6SYSVO/OS#@%7(R830:O,]]0:\LDQE34R;8[8Z,9WWS
M)Z]V?1:A_-;1`````$E%3D2N0F""````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T-2YP;F<`````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#(T
M`#$P-#$W,S8S,#$S`#`R-3$U,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@``
M`.`JU*`````'=$E-10?4`0P.!RJLJ1"*````!F)+1T0`_P#_`/^@O:>3````
M"7!(67,```L2```+$@'2W7[\```%H4E$051(B9656TR:9QS&>[';)ENRNUVL
M%[O:LF2[V9+=[&XQ6[:UW5)K#S:=UJ[:M=IJK;8J'BC60U$\@`HB*@HH?("`
MR$$!141$/%0HGK&Z5JM23]4J\NR%I6FL:YM]R9,WW_?E_3W_[_\^[_L=.?*>
M*[C_XA.BB+?HN_?-?Q<XA:@C&%C![M84-M<\86UO>+'_<A[!O:4E\IY)5/A_
MH-\$]S<]@=V5G8U5)Q;_MN&QKQMSLY:P'OMZL/"X%ZN+O=A9'\/^WDJ0S*DE
M.OI^>&"M8._%%):>],`WVQV6UV/`([<!8Z-:C'M,F)HTD7L]W"-M6%ZP(ACP
M@\"%[S0@+]."+V?W_4M]!&H)0T+PZ2DS@>E@UO/AM+>BOU>,8:<"+H<,HX,4
M_(O]KPQJWP:.#0;6]S?]PYB9-F-RO(N,EC`\--JM$A@T->BU-$%82T>GE@?/
M0]V_)OT2;/F'B,&&CW`^>Q/\$9$VL#V-I_-=X19,>#LQ00PFO`98S4TP&^M)
M>_3A>Z.6"T,[%Z-#ZC#<8JS#S+@.^[M/0M4SWX0?"P96\7)C&+X9<[@BAYU"
MITX`H;`:<J4"4DH*OH`'G89'OD),JI5B:(""O4<$O;H*O5VUV-N:>`M\;QG/
MG]DQ/=F%+D,3RMF5X`J:H&S7HZ_?230`5;L!C"(6"HMRH:"X<)#>A]1M%$`A
M>8"-U1&$XTOVQR'XXGPW;%8I2E@EJ.(WHD6N@;!5`;Y0`I%,!4.7!0J5%M=2
M[^)45!0R,I)AU-7#9A%"0Y5A8R74]Y600<0A^,RX$9P*!D02*;K,5O0/.&'N
ML4%"P*&QRV)%&HV.Q+0<T`L?X$)</-*S:'#86DEK.&111PE\_2!\_?GRL95G
MD^@E"\?A\M$J5Z.-M*"A28(R#A>,XC(T-DN06UB"A.0[$,O:8'<XH=(:4,+F
M@<7*1X.@'&O+KE>1?`V?F)BB*CAL5-540=:F1;V8"L.%8BG2:0S$WTQ#:04'
MMS+SR',]QMP>/'SHAE*C@URE`[=>A*Q[Q5#*:A'8VQ01^(=A\,+\W-?<^J:%
MJCHAI$H-U%HC1%(ENJU]X<I#P(KJ.KB&AL-0NV,0^DX3!(U-R,R[#S4Q4ZH[
M</-N'DZ=.8>!0=?KM*PL+S/+*SG$O1E6FQU2N0I%S#)D,YBX3;M'S,@V]WC@
M=C^"<]"%*EX]4N[2<.:/2S@;FP!Z`3/\95>3TQ`=>QDVN^,U?'UM_6A9975'
M`;,<G-H&Y!>S$)>0A!-G+N!T]$6PJ_FH(VD)Q;)!),75I!0<CSJ/B!._(_+"
M)<1?2T)4S!7$7$U&[)6$G>&1T90#.??.S-VBE=4@-OX:+MW)P4_'3^)*%@,_
M_'(2L;=I^/&W2$03P-F+E_$S,3T5EX!?R1@5GXC(\]&(2:<A-9.&1K$L^]"Y
MXAAQ>U+9=6AN:87&U`T.OP%%"CWBXN-`%]0A\MQI<#D,I*6G(J.D`I$)UR%L
MKB0J![N6AQL5/"C4VEW_ZNJG!\"D+5^:+-;Y8A8'?*D*#\HJH'>.XD9F+B0*
M"<FV%`:C'"55%7`-R%'-YR$]XP[*&R6@%$K(^ES(8A1"U6'\\U#58^Y'3)'1
M3#)K1*E23U8]!U*%.IR6&GD[Z&PN&I7MN%Y8#G%+"U0J"A35@FP"#\6SE03`
M,>`<(JG[_`!X9WOM>Y-W>NVO+#K)-.7/+F9ML`0B)!640B"6(;NV&0R2''YS
M"W(*2U&FZD0FO0!M9/-DY!>#+54C,3L_E'GJ4-7CXQ,1E,F*]#P&9F=];.(>
MPY=0@<2\@E!%%-6F@=,UB,U-?R79^K;[@A:4<ZJP_>)Y!TE%8Z6(0E)F;B`T
M[[_@'T].>JFI:>]3TOLO0L]T1M--IVL(4S.^;\D>B-C:](?^]!\L+3VAF7NL
M&!X>,H5./=_<_%?]`X.P]=FW#X')]0]P41`MQI).?`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O-#8N<&YG````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<V,@`Q,#0Q
M-S,V,S`Q,P`P,C4Q-C(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@
M````!W1)344'U`$,#@<ZL1X`[@````9B2T=$`/\`_P#_H+VGDP````EP2%ES
M```+$@``"Q(!TMU^_```!7])1$%42,>-55M,FF<8;K*+)4N6)4MVLYON>C?+
M=K7L:DFSK!?+LETN67JWS&Q+UF:+3;.V-NE:7;5%K58\@Y:3U`):1104D/./
MG`7D+(*BR$$!L2@\>\&N2;N>ON3]3]_W/=_S/N_A/W7J%0.HOHW:X5G4'JM1
M+0#'NZ@=I1KWAM6_58LBH'*6'CX]]::#%G]#&P=0S1-V#$<E-XHY!L6LX>1.
M=GS@H;DP'9@&D0C1GB_>!/@T:I5[M<H&2OD5;&_JD8CKL;&^_-02<1TR*0WV
M=XVH%.VT/$$''&R12Y^]&KQ6*1^58]C+,(BOZQL6\"]BS:=JF,^C0#BH;MBJ
M:PZ1P!Q*63-MBS\YX"4>T,0E8EPM9HT-AJ&`&K[5>2S,2V#0BF#6BZ%5\;!B
MD<"Y,@4[(VV8QS;YY(!-$`;K1<`?4I"6BSD7HF$-5JP*+"])8+<Q."CE$0Q&
M,2630C;)Q@-A/QX(>F&S2.%VS,!NE<'GDN+H8*T>Y&.Z?/4\>!..L]A.+,)B
MF(39;$8H'$<FNX>]_0)VTADDDBG(I#)P1WHP,GB7O!'"2S)9#&(L*D:1V]91
M@+=)GO+99\&KA:;C<A`KYFDPC`7YO1-0KR^&9;T#2QHS8NM)F,P.='?UH(O5
M@4%V-]0J(7EX'S.2/D1\TY1!T7J:_O`<^%Y3/LU@63U'H"5D<WN(1#=AL?JA
M6K1@?2-%[+.0RI0033R"5F>'2"3%8/\@=&H^YJ8'H5%R43T,$_,*G@+G\OL?
MY')99L4\@VAT@]BNDP5A,'FPI+9B5JZ&S1[`XI(!0M$T5KV1AER)9!IVAP<C
M`QW@CW5#+J/2*/OK67,"_KA2.>UT>CQNSQK\_B`\WC"4*@8N=P!&DPU<KI"8
M3I,<;JA4RPB$*/\/RLB09^[5$#:W=NB@')Q.-T;Z6E$I45!KCT_`(]$(R^GR
MDYLV8A0@QB$8C`YBM0.]T0D>[R%6;"Z*08'D*C8"&PC%H=-;P>=+X0_$&H%?
M4!K`OMN&W92S7K'C#7"CT<#:2NW`YO`CM;U+BS>(I9=T-A)C.;VOHU`L-=CN
M%XJP,"Z(Q;,8'!C&Z"AIK=""+Y!1+%3@#/=B9YMDH7[3`-\OE,[9[*M[)`U,
M)@OFY$IP1L=QIYV%WKM]T.DL\'A68;/9&G&8G)Q&/WL(W9V=&!WAT_LL!#PA
M)`^G(1COP_Y^LI[LGSP-:#R^^;U.I^=8&09]]^[AKS]_P>\__X@_?CV'EDL7
MP&IO1=>==K3=N$G/-W#]RGE<OG@>MV^UDMT$N_LZ[G,ZD4P$7URA2VISDU:K
MQ\/)!Q!P66B]=AXMS3_A2O//:/O[*JY>_`U#@\/H[""@X3;*$!8$E"&:I062
MB8I.+\?A84%!X.\^`VQS>-_3&1B)0J&D`F(PQAG!E(2#H9[+Z/RG&;?;6HCU
M-;![VL$=9<-!Y:ZA'B,6CL/G\V)2/($)(1^Q6+SY?ZP)_/2"4E?F<KA5D5`(
M@4""=#I9R^ZL5O1J$=B]+'1UD"2W6M!/$A@T0GB<<HAX;(R/<4CWJ7I<*KE\
MWO'2=CLK5TJFIN;2<KE"DLUF8X>'AUVUVC'#F&8T>NT<-I-.[*0"."@DD<EL
M4CN(![92Z2F#T8KT;J;IE;V<//C:Z_5^&XMO?:?1FG?K%;D6B"Q4CBH?U1M;
MJ52\,"M748>,P&JU0Z^WM%)UOT7YWW10+G_\VC]1(KGUN<EDS8]Q^1@9&FZD
M7J%8E-;GHK$-J=7JP/S\(@1\'N6\=4"G6W[GM:#_#8?3_:5"09MY8UA8T%+Y
MBQ".Q(WU.:52;93)9A")1#`\-`#QA!C^-7_G&X.3).\;3':16,@!ES.&1X_D
M"(;"9^IS+I?KC%P^3ZQ%X/,F$`H%42CLEU^$\R\$GT'$[ZC55@````!)14Y$
MKD)@@@``````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T-RYP
M;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-S0V`#$P-#$W,S8S,#$S`#`R-3$V-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P."!-T-(1-````
M!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```%<TE$051(
MQX65VW,3=13'O]E[FGO:IDF:WJ`IK5#*50='QV%0T!E]<N#1\6]P1%]U?%"?
M?."=$8<''WSPB9$6H6#+H`B.M*4M+2G-I;FG:9/=)KN;7<\N3D&!\LOL;+*;
M_9QSON=\?^O`2Y;1:G33:12F^A/]<IEF:_N>@SYP<'2PGP/L/;HTQ[!2ZLG]
MG<%G"?JV`]I)0R]#TV3HFK)]7Y3<8!B)*"+Q_726KM+ETQ2@LB.<P`%`GS*T
M_"N*7(3<,*&J39B&`8?#`8;EP/$\6&AP.44*Y`'#AXGHG*3'/[0".%X`CE+&
MY]7&VJE:O0IE2X-IFMA2M@C*V`%8E@4O"E`;3:I(0\`G(MC>!4'JM@)8%7S\
M`GCM*O3R\5(E2V#5!EM%6F?3-)!-I<`+@ITYQPMV,,-HP>?SH+>G!ZP0L21Z
MS_&<K/?)]<*==&I1*!2J**P[X!:;4#3I<8!F`9L*`TEDH%37X`OZ$8N%X/5Z
MH<@U1*,!A,-]U.>(RCTG\:_^N#,C,)P?+E\G1GM\X#@6AI6]=9#>EN:R+./^
M[!Q6LCED"TD<.]J'5JN%U&H.[>T=$+B6\`S\YJV[:.\<(`!#4,YB498<&/I2
MDQNH5JN8&!^'4J^A5B^#9^KHB71#;7;9E>77,NC?W8^0I.,_\/$KU_;,+RSV
MQH>&$0@&[%F2905;6PVPE/WFQB;6URM(KMS%ZX=C"'0>@4M4(9#^O"C9#,GI
M1+5202A4`_,T/)E,'V<Y\5"5`,5\CIID4*;KT'7-KD)35>1S>;0Y?:3S;H1#
M3H0B47`"3_>:MJE$2;(GR%K;<&JD*(K\0+5:ML=,536L)!+8W*PAD5C![[=N
M(I7.8#691B&?1F)I`0U%MJ%RK09)<L+M]4&@"JQQ!8FR+4MB)1TQ#?VSI>5'
M5%(7!6MA@V08C,=)%H6"Z4AE"/IPF:K)06FT(YO)P%NOP^OWPT]-M/K#TWAZ
M?0&8#M<3.,^SWTU>GX;'YT.I5(%*QF@V5?P],PN)-*W598)N/#8U(U)`S9:I
MS>6RG[=ZTM);-/<L_`$_!7HJ\WMSR\.]O3UV<QH-A5QG0&^1M=LD^'TN9',Y
MY-;2MNTE=S^:N@][]HW:)K(,I9&,EIE\@7:XW1V4`W-]6_-T>A7KE%DRE<'"
M@V5RFQ>Q[BZJ0$>E*A-`A-]/!HE$:#0E)+,R,O3?9H,FB>5LN#7_H<X@;6(>
M2XMO;'BE7.R>G5N4\H6BW4@G/>SV>)#.%+%$@0K%HFVD-I>;LC,1CL;`2^VX
M='76OLXP#C*0M8$Q<'D&FJ;#^05AK]FR3-V\_6DAO]9?+A5)!C=84<34]#2*
MN2P,F+:>09I[J[$T4F28!LU_':7"&J:G;N/XB3=H3^F&SQ\E\<5O&;;M2]CS
M0BM7*.L,RYI67?E\A@S4@2I!LVM):G"`++V`Q+)!.YX+\N8&5>5%B_35=`/S
M*W6<X*.TQPPVX.#/$?WK9UX6ER>GYZ_\>7>8K58P=N@`9A\\Q.&](WA02N"=
ML7.X/#&"]/I^'!N-@W=[,;^8P)EWQS8Z0I%K@4"/)HBN,__?2KA_#73Z_E(J
M/-P=1M_A`W"0&?8;^+DK)!Z)]7\?"P=7P6,$!X?B&**M8<-PX(-8#+OB@Y\X
MG=[S+WKA,`1VW5M,OO_7HXR_IR,(,]B)WR9^17O0^Y92^B542>>Q^LB#KF@9
M\5U1I%7@QO@5RZEG14&X@!T60T9YL\ZP']VY,6G/*ZO3T^H&U*WQ0%_\HC`S
M<PKERFN8OLZAN55#E>:]36`P.KJW1*^RUDYPCF48>$P->P9BB._NO^1TB@'U
MX-:QCJX?<>&'`(Z^>A*R4L>^`W4,C8Q='&SI1Y2AOGQ'P#N!EZQ_`"(<=I4@
M?G\V`````$E%3D2N0F""```````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S4N<&YG````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-S0`,3`T
M,3<S-C,P,3,`,#(U,#<T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4
MH`````=T24U%!]0!#`X(.:^/39L````&8DM'1`#_`/\`_Z"]IY,````)<$A9
M<P``"Q(```L2`=+=?OP```2)241!5$C'W95)3!MG%,=SBJJF!PX]]1!QZ[&W
M1,JA2D5516I516V:2+2!!`+%90D0S&*"C=EL@K$]-HOQ-C9>,(M9;%.,"9C5
MQI6-L4T**02Q"(Q!JD"$I2SZ]X-641#J$K6GC/3I&WWSYO?>_-\R%RZ\]9>8
MJKF<\C`WVN7Q7OY?@)N;F^^N12(I`JD\I9JJV^4+:]#CZ-]5TOJ4N=FY#_\3
M?'#852>1-Z)!K4-W[P"\_DDX1]RHI.2@ZI4^4ZLYZHVADX%`E*A.<3V363!K
M(]#)8`AMUEYT_O@4FF8+.NT#B&?DX&9LTCZ;6Z;EEO$__M?P"?^DEEU>!7U+
M!_J'7+`Z!E$LD(%53L%LL<,Y.HZT/"X^OY.(3[[X!G?N)AS.O9B_^X_@X^/C
MJ.'1L?W22A&!>.`8=$%E[`!?JH;:V`Z/UP]Q@Q8)&040R_60*`Q(SF01Z;2;
MX?!:PJC+\_XYJ$[?]%X)3WBOL]ONJQ;7P&BVHM7J@-YL@U#6B*S'?)0*9>"2
M+WCPD(4:I1X^?Q#^0`BVOB'4*#2GN5'I3*MRA>K*&;@_$)0QV3SPJ`:8VFV0
MZUK18NG%D.LG2%5&Q#%R(2).ZC3-,+99$)IZAMG960P0B4Q==O3TCZ"%[(P<
M#BJJA,]75E8_.@7O[NY6E%<*COD2):1*`\8\OE-#FV,(S9T]*.11*"*K;W`,
MP:F?$0A.P=X_#'V;#<SB*K#*A!@;]Y%WC;B=D`YF(1M>K_?&*7QA84$4GYP*
M2JZ#J:.;Z#J).MJ$TFH9?F!R45VK1NC9-*9GGI.(I]!-9*@0RQ&?FH\;M^XC
M.9L-=F4-DC(+B3T'N8^+,>'W_P%_N;U=04EKC[,+.*A5Z7!2V_FE0MRZEX;/
MOHK#]UF%,!`I:'TS5/J6TQS<3\_'IS>_0\R7L<C(Y8!95`$FNQR)C`PT*%3[
M:VMK,:\T7PZOR21F"QH[+'A2)4`>\9[!+$"10`PF58?4C"R4\*J0^HB%V/@D
MY!?S\2`U&XR,'.+4!$-3,SC%)5"JZ2VB=]R9A&I[G-$"VH!ZI8I$3R.7&'I]
M/K1/SB"!+X9*34.K-X+6ZH@-#?7(.+KL?1@<&D8)K0-56P^'HP_A<'CZ7"G.
M;+YT.2<"L!.#1)D6MTE$:HT6D@8%^-5B#+@]2!=0,+2VH://B<1*(6B=#HTD
M8BG="+?;C8F)B=SM[>VS=?YBX]>8`N_T>B*+@ZZG3J209')*RTGVM6!*ZB$0
MBE!"VOYKG@BC+C<D>C/X"C4,QB8\(CU!-;4>[N_O\W9V=JZ>BUHSLR1B](XB
M.X]U%/IEKF!Z<7EK?-QSF%;^!+'YA1!3$B23BN&J-(A$UG_K[7?"'PS"W-6%
M3)(338MY[R];WCZ_*JIOM^S06GW*J^$U-<-KLM@@)5I:K;83+6U[>WL=1T='
M5\@]+!8+%$1_!IL+?VAJX._FR;7#P\-O7S\[.#BXNK*RLKRXN(BEI24EV2_^
M:7MQ8V-#>=*=\_/S"(5"('/_^AN/7@+Z@#B))NO2Z^?KZ^N7MK:VH@DT.A*)
MG#Q_Y^WZ[_X.LS51]1?]Q7X`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-BYP
M;F<````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,U,0`Q,#0Q-S,V,S`Q,P`P,C4P-S``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@D/>2[I0P``
M``9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!'9)1$%4
M2,?EE.M/FV48QO=-/VHRL\4O[@\P,7X91HUS4P?&R=R8([(!8S#M!BNX#`H;
MXUBDE$$9A[9`@;U`2^F)0J&4MIQ**8=26@ZEA:Z(*U`J)8`&.4AV^5#CDF6)
MNN@G?9([[_,^>?.[G_>^KOL^=.@_O<IY@M<8:>G'J,:F8W:[_:5_!3KG<EV@
MA!(:I[S27,ZK@K!9CE)N=8%M<O+C?P0VF$8BJRGQ1JU(#I5&#XO5AG[3*'BU
M0C#9G,6^?D.+U^M]Y87!'1I]0ED5]2O_H1C2-@VH9B4DRD[(R+Z[?Q!":2LB
MO[F%[#SVCE@BHS)SF'\_"8O#W:X5RJ#6]6%PV`RUOA\BN0K]1A-Z#284EM>`
MSLC&)9+@S/D(I&<QJ3\%>KTKAZMKJ*,$QLW*+WXB;]>AJ]>(ULX>U`@5).30
M]QG!K6E$+/TNR@1"M&FZR;,1J5D%3P:,)FY22L91M_O[P\_!=3U]#IZ`0@FW
M)E`*H4P%18<V`$E@,)%T-Q\YA5S$IV2CODD&N\.)Z1D'.KL-D+1JD)-?#$9F
M/E1J[?+6UM;QI^#1,4M4;F'99D5=$V0J#9H5[6A2=&#$8L5#L1+1-Y)QOTP`
M;>]`H.83TW82,VCOZD%))85NPV#@K]*8Q8B^=@.34_;9O;V]MP+PI-1,SL%'
M#ZH:8+;8T-*A0ZVH!<4\"K?O%:!>W$+.K8';CD],H5ZJ`I/#1VS2G4!B0:,,
MF:S2P/YT:!BJJJNQL+`0$H!W=FDY]_**0!P"I5J'_%(!$E)R$'Z5CNO)F=#V
M#$!';MU.+*DB=;Z=P4)8U'6<#(W`ES$WD9#*Q%>QB8A-8.#3<^'@\?F8GY__
M';ZQL?G&B,4VG<A^@#A2MY"SX7COU&<X?B($[UZ.Q<6OXW$^/!+GPB_CBVMT
M!%^A(>B#TWCG1#""HFEX/_\!3@9_CM"PBXB*OH(6I7+'[U_[*`#W[>Z][5G?
MN%FUO(9+ZAZPBHJ)KUM1)U?@$\,X(EE%X(FEJ)/(<'7(AM,E?"(@"WG<:J3P
M!;A068=O<[^#1*V!7J]O(\T5]510VMH>IV+)#_/$)`0-C9`,C2+-]S,TI,XJ
MXNUR`?&U>P6YIC'TC(RBDJ(@M4[ADG,14E4'\;X!\<['H,G;8;5:2Y^Q8;+S
M!TY,127J%2VP+J]@8LF+>+T1Z44<.'RKF/8LH6K(##K[/NQ.)Z;\ZS#/+R"A
MK@$UHB88EGW@MZK!8+%!!EO',W#BRS,6BX5;_W@%9P>M:!")#@3!M',6;-\F
M(DC[&X>&L;BXB-7M'01;9I%1+X3;[8:1)#XUN8!LHM<CMUOC]_M??:Z)]H&7
MG;_LL!7F\6WIX/#N'9<'M:TJV%9^W!?INK<+)QPH(5YVNEQ0SS[:;NCMW\^8
M<:.Y2XLNQ]RN:7AT>W/SI[B_G"V7/>MOQHW9YWAB"5'=3S\X2YSWJF\I5!@:
M'E8?O&LWM^@Q-M>.4-D&E\OUX0M-1@(-(O%4]:6EI2.D+#2/QW/DCS.?SQ>U
MNKI*(]WX^@O!_]_K-ZO,02C,Z.%W`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\W+G!N9P``````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#<R`#$P
M-#$W,S8S,#$S`#`R-3`W-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`J
MU*`````'=$E-10?4`0P."2VL3JBG````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,```L2```+$@'2W7[\```$QTE$051(Q]V574R35QS&O=^6>#$7HXF2[&)9
MLF0FNW%+MB5N;+H)V\2,!84A:*A:76%VM"*@I:VE6-O2EO+VA7Z\_2YMWT);
M2J%\.2B"?/A1:;`4)<.I*%@U4P<;SUY9MLSIO#"[\B0G)SD7O_,__^<YSUFQ
MXH4>(R.CJWXX(DCCE1]+NS(]O>Y_@<[/SV^/=/6R;$[W&85&!Y661*2KY[[)
MYF(M+"R\\=S@NW?OYIH=[I3)[D&3MQG=/;T(AL)P>OTHK3R.HP+QR.1DDKX0
MNTC?NW>/GIZ>IJ>F+M.SL[.O/1,<BT^P+0[/HE)'P=W2"H>G!04U6KRN]&&?
M6(G5VA:L-/?BS8(2K)=9(+#[\*XN`([9`Z_7F_9,.&5S/E"39OC;NM`?/8V>
MOB@X"A+I>C^VE)W$1Z80-K#+\0ZK%.E*"S(49FRA0B#<S9B8F'@2/C<W]RIE
ML:Y.)*?JJJ2*)0?=BO:>?OC#W3`Y?>!*U2BV!)`OJ@6;=.'K7?M0K2)1;?2@
MYG0"!^4$U'7UM:KZQG5S\_.O/`;OZQ^(DT8KI,IZN/UA4*X6-#.5$^8F'*ZJ
M02&'CSI/&-\+9="U=.*H1`:"LL)`61`8NX2<@KVH$,E06B%&;U\TS`B^=AE\
M[MSY/*%4?D>CM\/F"<(3:(>!Z>/@R%GX0IW@'!8A>S<;[D`(7-X1=/P813?3
M+JE2A:KC4G1%!U'"KX"KN0T%!WBH4:AQ??;FYF4XI[1"KB1,D&F-B`Z.(!CI
M@=[NA8YR@ELI02UA@+Q6#4)'0B@2PV:W@R1)L`YRL;^$#ZO-@>S<`A2756'G
MG@,02DY@,CGU)]P?ZI#S!1(HZHWPM4:80_0XR!<BMZ@8.XI*X*(#<#1Y(9,K
M8++:EZOE\LJ0]4T>OLC.AU!<C4QFS2WB8`^[&$2#'M>N7]_\EZ?7#PV/QHX1
M#FS:4X[/M^4@ZUL6WD_/1$9.(3)X6GR6M1,<_C%LW2_`IQE9R,K)Q\:/,_%A
M>@:*&.#V76SL+&3=)\B&V[%8S,`P5_XMJ'MJ(8WK'L57^\J@J=/B[/D+S'5M
M:/1UX(.J9E3+58C$;^*32CM"H39T]`]#JM"@N[L;%RZ.,X*7PDO[&ACH2T]8
M,75_H99L.<7T6`R13(T:91W<'B\(3PB9>WDX-30*1U]LV983/]]&D>T<2+,#
M`P,#<-/-X!TNA\/I0C@<?MSGJ8=+:X_WW;Y\2-T$B]V)W3PQMF;G0:LWXX1W
M`*2!@LW?CN_DYF7K4?U)O'V`0*U6!ZY0#O%)#6B:3B42E\8F)Q-K'H/W_/2[
M?%/CY67Q3H_%P!:I0)"-X!LBV'C(@/*C51`Q(DOK#=`;C*BW^E!268WV4P/8
M5A=%8273LDB$?NISUXP]E'\I,$(BK?GMQHT;_)F9F3O7;LX]V.^[LK1Y!PLF
MB@)A,*&A40^7RP6!4(A@:RL&IU/8P'/"Y`[\.CX^_M93X:E42M[9V?E+,!AD
M_7._+1P>>U2I2JV&1%(-RFR&T61"N+T=R61RA,F1AT:C$4PB=OUG4"TM+;VW
MN+BXX]_[3'QN9R8K'H^?>52U6J.![*0<9HL5\?AX_JU;M_(8,(O)DC7/G>W,
MX:L&AX:&F]SN>"*1&+8[G&E7K\Z\_.+^O7\`<;IE0W%DWZ8`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S@N
M<&YG````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(Q-C``,3`T,3<S-C,P,3,`,#(U,#<P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X*`UNU]JL`
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```/]241!
M5$C'[91=3)M5&,>7J/'*9$83O3*[,_%B6>)'=F-23=0MCAAOW!(U86YJ59(9
M.@,3-V"B3;"EE`7*^DU+^_9#U@]H*6N@@Z[TBPK=1@.RIH!(6?F0[T(I_'W>
M-[:)4=-=:N)S<][SY+R_\S__YSGGT*'_XU\9.SL[@E@L9DLFD[:%A04;&R,C
M([9X/&X;'Q^W93(9F]_OMTU,3+SUMX!\/O_*^OHZ;W%QD4<`7CJ=YD;ZD4>`
M_A>,M_!)8PO>T/?B&64O7JR7XJA(BW?:#'A/:<6;S1JH5"K^7\"Y7.[4ZNKJ
M4B*10"`0P.#@($*A$-AY*I5",!A$F2.$URJJ4&8/XN6S7^#5JN]PLD:(4WH/
MR@PW<490C7`X[-G>WJXL@O?W]Q_/9K/RF9D9>+U>Z/5Z:#0:='5U@8X*.BH&
MAX;0X(W@M*`&W_3X\6'Y6>@8,ZXI-:CM'<8%C17\"U_"X_%@;FYNBL0^4;#C
M!-F!R<E)#M[9V0FE4L6-#H<#T6@4GKX^F`(_X>.+E\#<"N-]@HO:Y/BJ^FLH
M'!Y4U-1!I]-A8&``T]/3V-W=E13AFYN;8)7[?#YT='2@J:D)$DDSZR'<;C<Z
M='K<]`_C//\S,'8GG.Y>J(QF?/IY!;0&!@U"(60R&9Q.)W?2(IQL>9K@-M;;
M_OY^3K%"H8!6JX75:N74L!NP\\I*`7X0B2!M:2%8.QH;&U%5506CT8CV]G9$
M(A%00X`$%^$G:"=05V!L;(RSQF0RP6`PP&PVP^5RH;N[&W*Y'$)2*)%(.*A`
M<!%JM1JU=75HHAQK"]L,Y#G(\R+\,$TT*RLK^]2W7%%:KRO1UB;C++)8+-QQ
M%52'YI9K8!@&M;5U:&UMA=UN1ZOL.NJO?LO]QXHCD?ND_/L_M2.I%Z^MK3'S
MZ86YLBLJ:/1&MA4]Y"%#Q6;Z0G'O5;D)`SZ?E\U-34TQL3OCGIH.#\X++N?)
M#H;L95C./][&I=7-U[N&XKG[R22VLSO'"GG'T*AE9.P>EI>7CQ=RB=G,,5\\
M"5\@G"UYS;.Y_%-7S,$;C+WW@)0TD&6/_F%=^P?2G@.MY09^6ULOPJ,_SR?$
MG2[8'<YW2[\AN3V^R'T7"IT)L[.SU47+<GN,RQ_[-1`8%E)]GBOD;:')M$!J
M@$@LYI6$_Y)9X2?NSR`<B;Y-_G.07/[@D8:>A*51_>,:%:N\N/;!\F.3,^F%
MT3MW#=2"ATO"C]<[^*<O-2,2C?H*N;W\0;DZD()4K<?&QD9=(7]O]H'FC-B!
MC\Z=$Y8$LV$.3O'M7C_FY^>+</+[^<S2,I]N,)^^7RKD4TOK&H=_%/[;MQ\.
MSCXX5,@C])`]6VHM>[/)IB-;6UM//A3\/Q6_`VVM+6<D3TRB`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O.2YP;F<`````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38R-@`Q
M,#0Q-S,V,S`Q,P`P,C4P-S<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@
M*M2@````!W1)344'U`$,#@H4V&9S;`````9B2T=$`/\`_P#_H+VGDP````EP
M2%ES```+$@``"Q(!TMU^_````R-)1$%42,?M54U,$U$0GG:W?[2II:WI'UAK
M0\I/-"2&F\&#&@]$CQHOQ&N/QAB-1T_&1&/DXL&#\>!!!(ER,$+1F!B1&()2
M6RV68B&HE;;;=EL*VW:=>70;(`0]&R=YW;?S9K[YYF=?`?[+/R4J95,NET_A
M>B0(`A2+1:;3:#2@U^N!XSBVF(-*!;(LP_KZ.JRMK4&E4F%G)I.)G@-&H_$Q
M[J>V@"-@=&%AH3T>CT,JE6*@-IL-/!X/VV^6:K4*HBA"+I=CB\@0$8?#`5U=
M76F[W7X>`XVJR1BC7UI=7?41$Y5*#3S/,X:2)`'J&6"M5F-L":A0*+``.IT.
M+!8+6[0G&\S>AF?'R(>G'TS3C6`ZBHYOC!4!$0BE72J5F",%(U`*7"?%[$A7
M+RWS)=L&N%JM?H`.9R@(&5(0`M!JM2P+/&^4AAS)AIX4E!8!DJW3Z619*/WA
MZV7,(*!$3;%:K<R96"CEH7T^GV_46V%&C:4]V1`A`B6=(@IX!QX8*;K!8&`.
M5&MB3*7`"=APK`-24"6P(D2,_$FGZ%E#T?$Y1DZ8S68!4Y,^?1?@VZ\5\/O]
MA4`@('B]7F%/LUV<6?P)V6)1;FUM%=QNM^!RN0JRU@BO(S'`=\GG\PE8EED$
MO[WCX(MBZ>+`:*CR<&A(3B02W8I^-AR[_';JO9Q,)D<47?QKTOOB0VSFZJT[
M<CJ=?K(=B]^NF)J.2%Z^"IT=W8/()EEO8O#^R-BUQ502_";#=<768C5?R$7"
ME7,GCTN8]<!V+/7F%TFJ].<X_L9P:(*;B\6F<78S]<;U>FQFK==B_H%E*BKV
MJ6SA['CXR^'YI<4JEG5B5^8(WG30;=-93_<E`VUMDXH^')F'HH:#_4['W9Z>
MGEE%WVPR0%]WY^2!EI;QG4J\A?GPFQFX%WH)V6QV'AO[:F/T:B>65H2C@V,A
MB$:CC?'`^;[R[-U'ZUPVXRZ*XM!.X%N8&_3XT0@9<!UJ;^@X3CV6+X@W?4[3
M$:?#\3D8#-;OHG*)DR5Y+\_MP]Y8=KT52?!NZ<1;L1=G=AEG^^F?KE3\L/KQ
M"F@B6^S/\O\_F;^2W[$YEK:%FEIM`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O;F$N<&YG````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C(P,``Q,#0Q-S,V,S`Q,P`P,C4S,3(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!<````7
M"`8```#@*M2@````!W1)344'U`$,#@HI@`X_?0````9B2T=$`/\`_P#_H+VG
MDP````EP2%ES```+$@``"Q(!TMU^_```!`U)1$%42,>M54E+HUD435%=FP*A
M&FQL>A5PI>#"A1APX4YZFUJYD<)::*`W(HJB/R"X$"6"43?.L_)IQ%EQUG*,
M\SQ/X)C$*6K4V^<\.E*TD;;!#SZ^X;UW[KWGG/N>3O?&:W-S\\O.SLZ?^_O[
M7W3O??7W]QL&!@9D<'#0\"Z`,S,S?QP?'_N+R&_CX^/&RLI*:6EI,?+[^OK:
M?WEY6>_Q>'[]3Z"+BPL_W*;+RTN]]]_4U)1]965E^.'A8?SL[$Q:6UME>WM;
M'A\?QT]/3X='1D8$8V;.Y;JKJRL3@OJ]`-_=W=4O+B[*Z.CHC\G)R4]/3T\Q
M`'*"!CDZ.I*]O3T9'AX6!!2`R/S\O'1W=POFF>UV^Z<?N.;FYH0X+\#7UM8^
MV&RVK^WM[2>@P`U`#P$;&AJDIJ9&ZNKJ)#<W5XJ*BF1H:$CJZ^N]@3RHSDW*
M`+[B=KM_?Y4>9*0A<^GKZU.@Q<7%"JBCHT/:VMK4[0W4T],CX)TZ")):<#J=
MH:]QKMW<W-@1V3DV-B86BT7*R\L5%?R>F)@0!N43#$AO;Z^4E95)55652@*<
M.['V^\;&AK\O6I9@-Y:FJ,C/SU<9$XQ",@!!:4?24EU=K3@G3=!)T`=J;'5U
M=>D%^.WM[3=RS(PR,S,E+2U-(B,CA8Z(C8T53=,D.SM;2DI*I+"P4(*#@X4\
M0R<U1JHX=WU]_=O/=!C@9P.ZSPC.!.]26EHJR<G)$A(2(@D)"1(5%:5`$Q,3
M%5A<7)Q$1$1(?'R\='9V2FUMK<S.S@K7(W,CA#805P=0539+I/H4C&*EIJ9*
M3$R,RCHP,%"RLK(D*2E):1`>'B[1T=$2%A8F34U-S_31MJ2TL;%1B*MSN5P.
M1'/`JRXOEWEY>0K<9#))3DZ.!`0$2$I*BJ2GIZOQH*`@-18:&BH9&1GJ'P'I
M,(CN@C4=Q'VF!VW,#A,V$L6T6JWJ21'-9K/Z9E7DF?9$,JI"@L.&`I?(W=T=
MFTKOR]^6KJXNQ6E!08$JCP*Q7.K`CEQ86%!NFIZ>%C2:T%VDY!^?*ZLZ'`[+
M"W`X1<-VNG=R<J*RHH`L]=\^)RBK^1F8`;E5P(IV5*#Y;"3L=N'GY^>K5-Y;
M/BMA5K0H`=F5S<W-RGX4DSHQ&"C17FU[["4?`/H5$T\J*BK4(K:VEV?2Q&ZD
M>`S&_ZR0\R@D+&F#XS[Z!#\X.-"S;`+CW8:M5$-`)S-D!S(0@9@M&D6!HRN=
M]_?W&JJQ,3CF6>'OS[[:WP_<FO`T@1J5`:JP4V2ZB%JP%T@!]A`5$-]VSH,N
M']$C5F[-&-._Z22"2!I.(@L.!SW<8B0M2TM++MH-P2RHYIEG'!*?L87H4<DO
M__O(@Z`&\HV`CG<_H)&I86MK2PX/#_]ZZYJ_`83H3*%#H?J#`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\``````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$S`#`R-#(Q
M-P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S`N<&YG````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-#4`
M,3`T,3<S-C,P,3,`,#(U,#8V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!
M!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```$MTE$0518P]677TS35Q3',=G#?%KVY!(S7R:)B<'L
MSX,Q/K#%N&BF:$*4*?JP"%-'"#@L6XA_.T19;`)5YIQT@@PR_H.AL';5N,E(
M0$0-X*;#9<JRV5A)$TF(&CSZ.>9":W\MEF4N/!SN_=W>>\ZYYY[O]QP21"0A
M5/1/J?.H7+YZ7<;&QIZN9GVZ2XI+OI:)'</#?\G]X*S)A0@=UX>&I+JN:7)'
M=6.+[#[@>+KPX,%#<;>[Y8MO:B-U]%X9D%^'_I0;P_](?4M;^(:ER<OEH*-,
M&MN\PCS,Z/CXN,R=]X8L>GNQ)"];(0L7O:-CA(F\'1^)I=NQ9&(R,#@H??V_
MR>"U&SIZS_X4;@*O"2`_$*H(#02C]0>?Y'YFEV`P&+XA;5.FK%R[4?85E0B1
MYS9A&UC@:HD+DE3>6[E&ZAH:)GWXQ'=>D`M=LR5SV[:)'\-\N-(S7V)><[IB
MN<B#\K"__W%3;OWMU]BU><^I>ZGKTZ6@P"Z!0,`ZH]A`N,YV]<C)FF9]?`ZG
M9V2)W^^/_90UW]5)P?Y#4GK,I2-A/>P\(2;,%965L140XLV9.7K`_N41=9=,
MYFU0B"Q>DBQ1%335>^1`Z9&)^Y^L29)'HPF2NJ]07Y]LB.H![MN.?B5W`R-2
M7EZEL-N4_K[D?[M32,03C<TO\!G_?P5@JZNO7Q,(@25(+G*#WT+S(>(P;\TK
M`$X.D8G,\VSYFHD\,;P450%)!*JQW-E]44>LH@"ZC'D%Z`E.)'61V@:W'D:P
M/F4,RHZ7:QISP%55JS@`#UNS;>KZE`K(=]B3],W(^ES*GB04(_)L"ELJ``<H
M@;@XC#(`9<!$'*(J\/E\NHG-'$;9ENUY"BI&O(++V&>I`.3![R`21<PA0@B1
M8L"(@E6KUU@KH.YDEAU74H906IH\<F?X)7DW^75%*%4+4$6]@M-9):<Z/%JX
M2)2;UUZ6M+2WQ.EX5?RW`\JZ,8.8==HKHZ/WU#J'H&A@G;+Y`_7JYZ[NYX,S
MUL^T)\K%OEZ9&7!^X0Z,C`05[0"VL_,7!2QSA#B;-4((+Y,=8/1?.0#_@$WX
MB.8`>H&CC$`Y4`\">\!E[$'`,Q@_['`H"$B4N!R`@HH..O1VQ@B*<<20)M_<
M&L$8H,K-L8G=7BC%Q45:#TDN]L;M`#36ZO8H0Y'6@,F4>L2P-<:Y+66?,Z%-
MT+1S`"70``69)\`@/,,<@WPSI_I#6I`7[2$.F-YCV@X0>L,_$!H\C2&,\(V8
MUL-T=M`NX8=ZK?J8N!P@E#3IATJ/J6(,8@0',(I#5!P*!O1MF!@6II$B$L^^
M=UP.H`#!.`JA=&A.W_G)D[!N>B:<8V0/SC!2Q8@>'4]<#A!Z*!_CA)(<X';F
MA@AKA)JY:=HPB'%&'$-P`!V,T;C`TBO(FR?84O&]K-AA4X>`%=\I'V]5>&'L
MPUT;E/A3U[VF#2!"`G*6XL!>\.]RN92@K)R(RG:0#C@'"72=VYO<6JY0LG_O
M>NTZ&^I>T28R-WN.XI_&TMMQ7O)J6Z,VDU,Z`,%0$S&(UT8AQ18FVUWPIAK7
M6EE2J$67"$`XH7NGC0)N`<9#%?!OCWU/HAJFY^9-#=?7>W[4:O^?%R,@-=!_
MZ;D)9L:4X\=A)IF_D1-ID`````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M,2YP;F<````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C0V,``Q,#0Q-S,V,S`Q,P`P,C4P-C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```3"241!5%C#
M[9?I2U1A%,;]-Z)`B+Y$U(<@(BHHVA,+6BA3L$5J3+-IT28<!L8,-<M)32JC
MG"S;Q;`@FTR=,DW3+#&)H45)HP5%#1,*.?D[P[TYN6`D?8@^O'/O?9?GG/<L
MSSD3)")!@X?YTM3T0LP)N]TN5NL>24U-]:]:=NX4B\4BSHSC@>?-(]FG\\1F
M=_HQSE\IDOS\"U)552VA8=LD:'KH6IF[*$1.Y.1(@-B1AOY\^_9=<G-S=20Y
MG;(A;)-JL7+5&O^NJ]7UTMO;*\ZB<HGW5,FK=^]EW[D;OR%B?#8\KJV5NOIG
M<O9BH0S9<*>D1-C@\7C4H%%14?*\L=&O9']_OQ04%`CFQ^)8C.LN7KI<7K]Y
MXX>9,6N.M+>W2_+A%"DN+M;3)D)'9[<\>=TJ^245:@=W<;GDG+DDXW?-/P(@
M+J*M\3(F`*SA\_DT3+`"%L'A-IM-XN+BU'08@``@(-*/ILN'#Q]_(L7L/2A>
MKU=Z>KZH0^+C$\3M=NNAKJXNM3_!C47QQ]9=-B'*3("0-6&2GG5*'"F9&KD+
M5JR7@NNW)#DM0[W+.H$<&9V@[^P!V`1H^=RA=PV_6ZG(A"@N"C^6*6UM'V7=
MK7NZGG3S]M!0R7[J4W6-24O-"VEI:96.[F[!-H:-(BH;%/SON?$?`+`><&A,
M_#8`!\O*RC5'`<#WGSY]EE$!.CL[)28V5L.7)Y%(N!86%FHH,\\[\Y&;M^@(
M`,#O;(1'"5OBG?AG'L;@\-5KUW2-/;!%`$!B4IHR!I)0'P`2B<1"(PZ1`R3;
M['D+-9Q-`%*6U.4@6L!'$!E7X`"@2)P8/%GWD`?DA0G`_3$<R;3=:M<-?$--
M`#-'<C'/.YE+N@=<(>9ENQ(?_$:>DSSP0ZC[BB"`Y+KGJ323*L`+)`K&<I76
M:.4@"[DOW[@RX<9=-2`N-=@T``#I;*"R4&6B&]^J5"/[D,H\W\/&041RJKG0
MT.A3"Z,5A&',0RI1=H?\@]GX7X&_J@"Q_J#RD59;LHQ6HN)AM1@5F+HXK@J0
M-)`(O``_T/Y!.#PA'ZC-$)Z9E:6\8=1/*CC,!49S<[-6/9[D&WQB5+<A0EG@
MIF0R=,A!R`@@B`H`V`VB@O'@%-:H^B@!$S#O<KG\R3V@)&NPHD%L[/O:US>\
M`K06W!)S<I"GP<<HQ0VA65S!DS7F<0?`".0=Y:$A+(>R,`E%`.L,KBX!PNDC
M,2VL"BA",1M@`*`0MT(H@KB]T4RQSNTY@R+T1$:#Q3MGM1(-E#>4&%)0&/@6
MX?1$^!;MN3'^#)XRU>R)F,?,`*(<3XH,"M!\39@4K+6#.9HPYAB<I?>B-`RK
M``/S;+M?*_RK0#"'YNUWF(#,+3N2K8`HPHU8YYLUP*<M66T*1>D%SB.*PP6Q
M(.5FQ"R@3XLXF:=!]-+W5DL)?Y$P,41/I9B_(U9OH&5HH"DTWA]4U,KNT^?4
M#7R3JE00BH71XXV:AJ[J)A6.?^DH*5,S-X9K(%+C<KTUZB(BF.)H*$/6W"PJ
M%9K*)7L3M`JUMK3I'P>"=4P\P,T!P&R8"(U)20:9D>AM4-,3="C']PK'(:FK
MJU,!*$4-93^6P'(A>9>UJH_Y+\*OK>^OL3'8=Z,-%"9[1FKF_A>CP>,'G#^B
MDS84A!4`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q,"YP;F<`````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#$R
M`#$P-#$W,S8S,#$S`#`R-3$T,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@``
M`01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/```!)Q)1$%46(7MEUM(E$$4QWWJI>>">BAZ*>@"08$8
M@?70%DA4%)214'332@*QS*"K=L?*,KQ@%%Z*TBC3-KHHUEJV:1G$:B!M1EO;
M9I)8II9Y\G>6V7;=+;;(*.AA=KYOOIESSOSG_S]G-D)$(OR;[\&R,55N55=[
M7[).%DMV=K:T/'_N'6AO;Q?;W7M2__!1X'J?C=++UV1X3IGHP,'C^1*7D")[
M]AV0K6F')"(JVB)',S.EXT.G!+C]7M.?KJXNN5I5(QDY!1(;MT)-V5PO975"
MHG?6H;INV6%URM3"#JEY[)3D@MLR8J_C)US\G@FK$S?+IFUI"@`M>M?A;S$4
MG3DGH#,_=J64VNURK[96=^";P!9977?_OJ(^9\$21<_I='K-)R6G2&]OKT[P
M>#S2U]>GO5H`@]X^D:3*][*F_(U"O.I"B_R^;?ZR`1@#E6[;[LB&I!0)VP!X
MWK'72W-SLQS+SI7Y:]=+XG6[S(Q9J.CP#+>"#,`0/%JO5ZD!H(5[X$T48)^5
M=THJ*ZND\4ES(,PTT!L9O50_C!H[41>.B9RM%)PT=;HL69FH/8ZFQ,;+^9*2
M0+8MS"J3SI[/:H1SRB\JT?=1<S<*?*9G'"4%8<`A^P^ZW>Z0H#D<CJ#QP3O&
M?]P`20SV*1O[SQX>A&V@L:E)C["XM%R&7'B@.J6'$Z@<M;M<KF`FFE9PKLR7
M.5.;/+(\+5-FS(J1:7,6R9:'SP2^]/1\"C:0EW]*O6$`[^E'<C7YL148R+?M
M!X^I'GAN:VO[QD2\$;;)GG`=RI+AH30Z(*OP3(]FB,IGP'AF(5[0`]N`[Q45
M%=KC&46B"1K/`5N(S'6JU1&+TS7DT?'YJD;>Z0&1<=YQ:.CN,S!M2Y&*A])A
M1(1X")=W$B**G;!L9["82(PLI#@0<LY=MR(]+J]5$PL]W#AK:Y*!PM,?)E#X
M0!:OA$]/N'S'"`N'KK\86HWHW7\PE)R9$VK\+Q73GVS_;@!H%UFAU8&)?E`"
MH-:A(+1^H]KFDRIUC@!('L@5O4-;QDS:(L514`9J(*P`*+14:Y.EN.@0`,%$
M-;R5R>LV"U=+GL=;^M.>]8'63<9Y9LS2X-$*3R'^J0"('(A-IL,Q`?%.`*=;
M7JOA=>G[9=^56LTY"9MV:Z#,V5U2)N7]$B5Q@5181X!#8"8'7;+>5&,\LW-@
M)Q`R)D9?M;Y5R+F\ON@7.9P@Y9"6X`AW&-[Y;FP1(%=%4Q0"G!NHR>7T0(93
MGC%`(!A@]\SAK'&&(\Z8QAHVP3P<PP/#'>R3RD'*'$=``.1"B,1.#`J0"V,L
M)')*&\Y!A'DT<R0XQK@I@:!$$#36\MWTY-Z01V!W=6OVIG:P(TK!R5*K,IX`
M<QHZ95AJM1JA/'`U)DF#!$:?NMYH'68^N9?*P'QSF?LA!Z@`[G>=6DI9?.+1
M)_W/P0Z0$-\A&\Y([F<='R5F1['OXFZ"XV\!]@B0[]]S'A#`NZXO6L^X76*@
ML;5'+'E>Y^R,=Y`!6N/<!(=SD,,Y?."=^7R'L&$E(HKJO.0,*2PL#%I@@L,Y
MI,(!"H#A_E<<?Q1Q/C=^:]#W7\Z$@]7^!_`5VL6\7X@?!&,`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S$Q+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(S-S0`,3`T,3<S-C,P,3,`,#(U,34Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$CDE$0518
MP^V7VTO441#'_7=ZZB7H(>BE0*)Z*$@C*NA^,2/,RE(Q2K2PR.Q":DKJKJ:[
M+KEKFM6:I8EWM-0N6V;D#211,T1%)C^SG'47==G*7JJ'L^?W^YTY<Y_OS(:)
M2)C_TI^)B0DI=%2([T/RE1O2U=4E)Y/2O&134U-Z.CL[&WC?=\7VX*'L.!CK
MY9%77";9!38Y<")1X!7VZ4N_GO3V]LY+";;T)^>>16SE3^1J9KZDI&?)Z^YW
MXJYMD..G$N8I)R<G971T5#H[.R7%6JK/H8M8'@(4Q.;6MC9Q5S^3``*T=3VN
M46=LW7E$>GH^J@5*D'@A5=YY>O00YY0XJV3]YNWJRO'Q<2\;3(JK:9:9F1DQ
MYK+[1!"6LTG)ZJ"SSFKA??G,_"4&8V-CDF^]+ZXJMY`;&!HR@\L9V?*DYJ7F
MH*.\2KK?O)7<0H=Z*2XU0U:M62<+&+2_ZI([><7JZXRL`GG_H4?2LZWJRM:.
M3O5[0TN[)N;MG$)UUNZC9]23/DY9.?=D:\IUE;!BY6I=/&^)BM7=K(V1^V1;
MY`ZYEIXN`44Q,O9-HF-.JWI#0T-"Y5RP5TA#8Z-^(T78"=.B/N"@HZ-#3&&R
M8S,["<!>6ETGM77U\N?#^!<PP./46U-+FX*1<6)(#&+B+VI-DGTD%NE<9'?*
MV@T1\G5D1((R0!H91_HV-K>*L\*;RH=CSRN>D40F+P(8D#1(06*^W257;N<J
M%K-(62[#"&U(9;0$+7P,^)!QUZI%!)/:IE:M@Q?U+7J16F%!1YU`"^SX&""!
MB]B-U(B],=+7UZ=%Q$6C/HOSR'W'9=.V7?,,!@8&M$!,(;$C(?S8:>]S^*;Y
MXDI(55K*?8$3P77\06D;,*0N+CF?RO#PL#Y#LV@40$US2/S]BPD-R87"2O?B
M46`-#@Z)800^$W.#KDES(,,.D"R9!W'GX@-*%RQ84-[9%OD+J_'?5`"XH1?3
M!*C;8'"S+`K0:<$W2K+84::Y3,ZS*%4P@(;*[.%TN7R3PV\K0#U0]S14T`KA
M[F?/M6/3@/G&6,G(QG?0"D@$!@PL%!67R"\I0"%BM>GX"&$O*GLD-W/OZT(X
M^`N`@W2`%0JH0G/+[GJJ7F,V\1^9EE2`N!)3X-)J*U-+F?W`:,,4P<PI("9G
MT(*06/KQ@T<1E)V1!,50V'069DB:P_[H4POG-Q*JP%ZN`Q!"8`2NPX`I&6M-
M@\#]*(,0\-[C\2CV0X-2\$`(D(U!*,#.7?*$$)%7`0J`O%S`[204G8<=UY('
M7*0O8CE]`VN@P>58RC`&'6&`CL4=A&*UX<V>FG95##P&A(`XH0B6`<#T#5S+
MV%U:ZM!%EE,%)!TT>PX=%8O%XCV;Z\'LF9F9NKB+Y5'GDO0>WJ(S3$]/!Q^A
MZ3_$WVC)X)=8\E#KGDYIYK1;-I>O-[.@P6/T+MX_]P]J+S.=)N0JH.V@L1E#
M*FL;-<;^F4QOQT(F4=[)%V+M3\,9-#^E0$)5G9:.:66C$]]US"5N1J&;SL?Z
MS8R\.E?,_4/SI\'=\/+_UQ22`HP$N#D8FOT,C0GC_VZXU/H!8$/SU2\-594`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,3(N<&YG````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0V
M-@`Q,#0Q-S,V,S`Q,P`P,C4Q-30`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8`
M``$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P```3(241!5%C#[9?+2]11%,?]"X*@38L@B"!:U*9%
MM"BH121!B\+>%-+#,F.PIJ)1RRRSQ*B$,NQEF1*:D:-E.AHZ6HZFH^58-AC5
M]*`B%`I<B)SZG.'^FE\SAD5!5(OKW#ES[[GG]?V>8YR(Q$4N_5-=4R^7RVZ(
M8Y<K+#V05R"Y^86R9O..L"#7VRF#@X.RI:O??M_24>Z^+6<NEH@*9LR>)W,6
M+I/%*S9*_-*5$K?5X90-I6[Q-K>(=25R<2!*)_:45%1)34.+G"^]+D^?]NOW
M[7L/AD^=K/:HT67E%9+<Z)<U6;GB\_GDXZ=/T6;&-'O,!TZ=*911#Q"\L\7E
MZAY^VP[DG[LB1&?Y^F0AL`]Z'LGUFYZO<<@[7:0_(N2@B5RGWQ]64]_HE=3Z
M-GG]^I4*<37QR,FPAHR6;AD9&9&DI"1Y]OR%IHA4U=;6R8^[^3,KIK"EM5UP
M#'M[`@'-WY[,HS(F!=M2]VK2J^N:A/`U-/NT'C>G[K/V0T-#$C,1K*:[/@WG
MIAU9<NU&E<:<=>KB5:T>5_8),6&G8"P%A6T/9=K,65I)*](.RJ0I4S6BRQ(2
M=)_4&])/SB!'@64!:>#2MM9>R<G)D?3\`MG9V"$NETO6%57(!8]78P$2*-WN
M[FZ["R@P`ORCCB/C$@P&K>^`X?>G\<]1`,XIIA]60+Y!$)%O[^A44GO[[MW8
M*C$Q98\6%`I`.%1)58)/:N"["@*]C_02I<PGU4?Y&K"C*";Q&5;@$/5/.5.R
MR<X#^HD;Y!\%+"RT52):01N'0)ZI>U_[?>GK>Z**X2+(&06X"6E;"C"=B/,Z
MK^(O"G$#FD>V8,DJE;,'L>#"YD)BY1W9Y$C50&VLO:><-7'29%F??UYFSU^D
M+R[)RM.,H`SZLBG8G9:A8.KHZ57_@J_>R/L/'Q18$*(!&7M`9@LB%R%!$+G_
M5I/ZO>IXH2(2LCQ:YM:+9A^5!2`+DX)$(%M\-PQE4%H7""HG#`\/2Y4_H/LH
M!?QH!*%0R':`WXPL<O\7P?G?,H#BI?\#/1`"9@$[@P,R,_K\<@.`*O@%Y_0Z
M)B3PSB@!SOE.-X;"G.G9BC2@_&W%_90!AA]Y@$6'@J7Q'KDA'"+!HYR'P2`?
M$`T%,+V-V0#`2$B+2TK5&[B5A_`63Z%-E-/Y&1?8.](.ZV,\CI&!QT%E1HPR
M]TD1^B"RR+9K>QS>Q0O""S/JC/*E(_"H40R=XB',R)R"K-W_0!_4_1<=?,=@
M'C1GB!)Z,1)R-"W*9@"$R`4LYG$N8HCQDLO&2Z9%'B4E]#Y2PED3#>J`15_`
M*5@8.<9C@)E.;`;`?1BP]F:S\CUK;LIN_1PW?H+,7)R@%,\>.=1O]BCE-\X@
M9[&?OB#>.F/VD/+`P$!L`V!V6!TRIB40*KR%V5<?.RU.IU,N-+:)HZ!(]U0Z
M.27TAVY[M1=!V-007K*0,U<C9R(<M0B[GKW4?H1U3(LT.2Z1/WH3U7^IM4L?
MH5#I#F:"!((8`A<P#!HY;<K(T3,J"NZ'WJKW"^/C-<>950U"35#)**.?7ZWQ
MZ)C*OM+MUMY'CMESE]$6P](K/9IW.,/(::B172O*`,*4DIEM_7=A4D(C)26$
M%`5X0^^,5))1WZI]E+29W'XK)X+_F]$?:<!GUMBJN:H`FI``````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S
M,B\Q,RYP;F<``````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3$R`#$P-#$W,S8S,#$S`#`R-3$T,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R
M````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/````]Q)1$%4
M6,/MEUU/4UD4AOF=7/$+N.!&TT1"3!@3/\8I6E`TJ,21`;4ZQ$"LM5"4"I4>
MI5ALJU!;I7B&MF28$!(2\GJ>15H@!05!XQ@O=L[N/ONLSW>]:[5!4L/V5=LL
M+U=4.WB5+:A4*HEGPYZ?[#AP_RDIF4QNRKC]]U.Q!A_&=?Z/SJVK+2TMVE7&
MGDIRA8^:R;IZ]][5AZ*KKDM7=TI86?E7:VMKVMC8T*-P6+V]O0=4<?@+3V..
M*N6R>J[?4]V%7"ZG_`=7D=BL>GK#MB][E^U"-!H5H9].Y<V]?'%)Y_P#Z@\^
M43J=WA2SOKXNUW6%JUU=EVHN[FJDXR3D\_ET=&X>2@`.3DU-Z4`"4K.O5?;P
M1S2&'SERIK/*S!5UZDR?3I^^5@-:G0!06'1+&@S%!'((X\W^B*+C,Q9>DD3\
MEY8V[_E\)PP\-20EG!=*I><5&DVJ\\H#3_ND"N\7S9KQ1,9R0Q*?/<]J>B:M
MQL9&52KE+P<)DX>&AA2)1-36UB;B<N`L@'''<?3]T_@_%T#0(`<JZ<!(')^<
M]0JV9'E.9=[IXL6`]B6``H9&^7AL<L[HD&+O"`0-7-3R9P7$XW$CODS.U823
M-TB#/+@5^&(98*H3`,KF\T4K'&";>5,PZ$(SCZ..64$-O)Y;\"Q<,F[:09P4
M"]+1@J#^^Q.:2<VIY+E2K85;=T8U.#QAQ76S;T1-34U;`N[>#5JPXD[67E*Z
M"(,->5*5G*$D'$DH>.^!3IYLKZ=N4K:ZNFHFL^<Y,.!584^/5=]VKMLWD&*Q
MF+J[NTW(=C;=MP`R`ZU1QLW-S?HJ*(="(7/M)ZW&7P9\-P.H92J+NE_\N&BL
MPQGT1671>?9"VJ$,6%A8L!J@\;)03*>&J7A2_IQ#1-#>Y2M!=70$ZCKX5QDP
M,CI64PK'PBO,BE#E<'C:6.^_E66+Q,B35[KQYV,;)\:>I:V)7PCTZ=BQXQ:Y
M?1E`"*$./&;.JL[(3BJGR9=OC4:9'"`W%K\Q!,6PI4T2W@C"&(*Q+)CVK_X[
MUIX@3>1O3]76).Q9R<B!T*&1*>-N&):N\F:^8-,AS6+P8<*X'I[GS!16-E<U
M37Q'$X&Z(=2*MUXDYVU>8F"'RNE>.PS`:X2AC)Y0G5L))Q2.A[0UWA-V%!(A
M%DJ)4/4.6&!5_REP5AW4P,>N!E13`,IA[C-G?[?+]`WV/%GM[;\IT-GEG?G5
MVMIJ3,]OB)I\<\[B+HJX3U.G'W.7]@*PCXP'\OF\_'Z_Y1;#4<*>UH-2WGU3
M(J)=\=\+[XD>31.PL<?[+W'#D3$:"C&$L!,)O-]KHOW5"WXH`SX!F79C/N?C
M9-D`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$T+G!N9P``````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S
M,S,`,3`T,3<S-C,P,3,`,#(U,30W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&
M```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E
M($EM86=E4F5A9'EQR64\```$;4E$0518P^67_T^2<1#'^R/]3_RAY=QRSBPK
MFN:71CF+55HR7;*<D?@]1"E`4#10$24%%)3,S3G=+EYG#T(@A*VMU0_G>)[G
M/G?WN7O?^\YK(G(M7_3/\O**^/PA"00"YV_?3P8DE4K)[*?0A:K9;);<D2(;
MT>V4M-Q[>:[A\7AE9'1>3&W]4E-3<ZYFM5JEX$B^V.UV*;*9W$N+[;U+>@>F
M9,JY*.ET2G9W]^3Z]1L7FKV]O7)R<B*12$3*AAF+Q8I=E)."!^>'#W*I`H&-
MC'HE%$GDDI!3V$FD)+(5EQ>O)^3+=D(VMY/".U4X.CJ2I95UZ7KR5C9C<<UX
MC\6AY<A9.#L[DXV-C9Q9A\,A%HNE^)K#P\-26UM[^36I<-EK7D5*OG2Y%K16
M^_MI.3C8EV>6-^);6)"*!L`=Z8K&DK(83LJX<T5_/WOAT+21OJY'3X2D%!B8
MG)P4ZY!3O2V&8^(/;NHS.<<H!VWOW`K*8"@J_0.S<ON.J3B+-IM-P./T]$PV
M_'TY/#Q4)7X#8A!'RU"[DE<(A\/ZH;N[6SV#'0R2?5"(08S\4A4PQF$*WM/S
M5*JJPF^7\>\P0-+(`7U>E0&PX)P/2CJ+0I!(W=O;.^7KUTQE),;C<2T?W3T]
MMZ;@P>##SD'M5VBHK`&WVZW0A19<WDV%-0T.*H$RD;6VMLKQ\7$AD$`>RK``
M!T*K6PI;(#TVY=$H]K*1?5[?SD:XISUB`$H-@'FL&]R#Q\7@JE['('98E2O!
MK,_[)J2AH>'"`#U`LN9]J_H15DMFVQD:PJCQ#B=$-#`PI#U1D`.,\(%&8230
MLJ>GIQH!5X#'Z`F#RTHFD8YK:FJ21"*A2B3+Z#R7:TYQ0>B034D#\`(">.KJ
MZ@22)%E$P&\<&,8K(I%K$#8'D:JAC&=P0<CY!%)5,Y7S_/>T\_\3`(6D,QAP
M!FNPO-`1-``[227NNE(`F4Q&T41KT@"0`FP#ZX2SY$#[\LWG7U?:>MPS*/7U
M]47CZTH!T'T8-SB2&S.QH;J1,;^RUK?#C+X?GUG2"<Z6!)>RX[1W]BF'_KR8
M71H`K<]MF:?P!K=ETGN#&^)>6%,:9'5ETT)X)A`<O[).R-:7'0V420")(3`E
M)8)R&:^4JN1@I[Y0Z,3<DHR,?U3NA2%94,/K6SI22+O-[E&NAA5YE_ZQ`.&4
M3""<@Y*A7DK(=TK$2G+O?KO25%$`<!BIIJYP^D'F0`?"S.RRV,=\RN>,)8(A
M[3@T^)XR@05#!RP@!('PCHQAZ^[=!TJX)4M`:D@_E,T@I7Z,,#8R#C8WWQ:3
MR22L/CRWM+0HV?+<V-BD9UK;S"HW&V[I=_1)/=_0BT:CE<F8>N$8'H7!`1'/
MB+%_E1+:$'W.0:-<"(=DERF0OU;^$IEW='2H<S)AC!D$H-(A``I'!&P81Y]S
M"+5FHO".`!B0O\V$@)7@Z'6"(@A&%[\))%\7WH`/RA%45<ZY`3A`^&_$V%R-
M%?CG8?O'9@%43`!D@9H#-((HE>)_9QC]*?D../F$_62!OKT`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X
M,S(O,34N<&YG```````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3<W-P`Q,#0Q-S,V,S`Q,P`P,C4Q-C,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8
M,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```.1241!
M5%C#[99'2V59%(7K[SEWY-")(P450<PH!G!@3IBS8@Z(@EDQBQ%S%@/F@#FL
MXMOTLWUE:KNDF@:%R[OW>/8Y:Z>UUP])/YX_3R_KZ^MZ6HB(B%!=79WN[NZ<
MMSN9?+RPN+@HIX7+RTN]:O+J$8^/C^KIZ=':VIK2T],5$A*BSLY.'1\?_[WS
MX>%!)24E&AH:TN#@H#P\/#YQQ==M`$=#0X->;`!]7U^?1D9&E)B8J.WM;6UL
M;,C)S8F)"5NXNKK2[>VM2DM+G;Q0?7V]+186%LK;VUOO@MS?W]?7N?G'#["Z
M(VQ$HJ6E1=W=W8J-C55F9J:(\^'AH>;GYY6;F^N<Z_O[>S4U-:F@H.!I<W-S
MLQ4'E9.=G:WKZVLKF.3D9$5'1[]:+"(GY"(L+$Q^?G[V#9JVMC9E9679P>_&
M`(/S\W.YN;G)U=75##C`Q<5%C8V-'Q_PGV?A^X!?TGES<Z/IZ>D7J7OS`(SH
M=JJ2JLO/SU='1X>FIJ;LFS(O*BK2[NZN'>[4\!BEI*2HO+S<V`$N[>WMU>SL
MK&)B8JP_TM+2='%QH>#@X!?]KM/34RO=A(0$XQMN'!\?MYJ'0:C&HZ,C!00$
M*"@H2#4U-2][86%A065E9=K9V9&#P,?&QJPW@'QR<F*]45%1\2;CV`:Z#_\=
M`:0WX'9W=W=]&$1\]/'Q,9_A=Z`#>W5U57%Q<3HX.'BWF0P!D<:(`!)<2(5X
MQ,?'ZU\5$C'@E_1]-]/7/]\`_C\`:#":"DJ#:&"KZNIJ)24E69O3O<S.O[C3
M&I)W^*._O]\Z^MG?VYV,$1=!"=#BYN;FDSQP_!]Y@%8:&!A03DZ.:2:D87M[
MN[R\O#0Y.6G\`WWL[>W9]_#PL*DS3T]/)X)_%0!>@APJ06O-S<TI/#S<C$='
M1TUNP,F!@8'JZNI25%24#7VD2%55E3$G#\,!-EU963'Z1>3"Z>Q]+P5V.8P*
M:G[]_?T-/<:.T!(E1#R<Y^OKJ]345%/01(P]/*VMK<;`1`)MA";Z5`W`O,O+
MRY8.+CP[.[-PSLS,6%18<X#!8^8)Z4"],90`Q*!ZKJ(_-90=AU-`>%9966F'
M1D9&JK:VUL*]M;5E`PM`R$G"#>"\O#PM+2U9L?[CH?Y:.@!"U>,5.2XN+K;+
M48IT`.D"))Y2>$Q+ZB4C(\,`HV,=T^2WVI#"))=T!H5(1'[=@Z!`0/`>&AKJ
M)!Z^F?`;P%O/3Z5H=A*ZS:EQ`````$E%3D2N0F""`"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O,38N<&YG```````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0W-0`Q,#0Q-S,V,S`Q,P`P
M,C4Q-C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$`
M`-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P`
M``3/241!5%C#U9=M3Y)A%,?]DGX*W_BN^<9R%IE:81M-BE)RN=&#31>YR$'V
MP*(&4T@#"C,J(LTH`T2GGOP=O7CP!K*G96X7%]SW=9W'__F?8XN(M%0O_5A:
M^2I;6UO2T=&Q^]1FL\GX^(0XG<[=!]O;FU)SQ2+C6?2UW+K]1$^U!(-!&1@X
M)_:!04FE4A6AH5!(+#)F8\\EGG@E%IEW_,_D^H1_9SV0W&I>L+-0VI"^/OON
M*?1X/!Z]:7;TQN/Q6A-QA/W3RDIC/^KZQ2H6BU(L%L3E<DG=`_E"4<;O!,5[
M+RQ.E[>B(IU.2RR15JN]OI`4=B2->*8D%'Y9B8/#X9#N[A/B.#\H0T/#TM-S
M1GP^7^6`<2V93$I[>[MDLUGQ>KVUD<1O=A+9U=5E=1,U)FCF\('B<.`XF;6Z
M^DUSM9HORNNWR_(P-*<>G[]P3?"AH8!P."R)1$(BL06]-'XW))>N3"JPW%=]
M0B(^+'^1-^^7!3=,6LM@2"Z\DWRQ)#Y_6"_PNU0J26EM3::#,;$[;LAINT=S
M@.#>7KL5CS,S,S(]/:V6@%[SG30@B!P5"K5PJ!'`@?T^8OKFYJ:NO;^6N;FY
MQED@4"0Y$`B4R^;4J5X!4B@`!$VS\-MI/!P"\#?W):>`@I,V-C;DP`*BT:B`
M1FJ0A1#RW]G9J2EL*H"H0SMO,I\E\#BN8$(`%3[IC\A9NULRF8PU"R#.7`Y&
MXGH8M!EZR"ZMR/KZN@J^>7-"TPD^R@(BLPGED^C\@FI-I3^*K6]$:82+6,$[
M8`[W`'5<*@N@\EXN?M"J0Q"XA\/QF<M<Z#L[JG7`.P3!SQ4!.T%SN]TR.CJJ
M9`'RP#NFPE-0,.S.)=[3.BQ!'!L;T^(A"Z:\*2),11C!HVI),0HM`CC(,J3!
M/C4UI3C8JPGI[^]7H0BJET8M(A-=EBD<>H'I:]656!=(<,(^+6H)SV#<'R*1
M(.$G@>2W<8'`5=-U0P%<)J#LQH*VMC:UXG"6\S\Q`$P15\+":D87?\0`@/LX
M^%3\CZ*2^_I-H08!4)>4822V*!<OW1#:KZ&C/V(`.)Y/I%01<P7[J_0G\05F
MM6%>O_50(!)8:.;%6ZWWH]V7M=Y/]K@4>?MQ?V`#8&2\@9E@J.1B5I4P!MX/
M[E(>!$3[)S+0'F2#@9FEG'9PG@\Z+Y>'$9BMJ0&$V;1_6"P4>:'S(8(P`H9'
M"50)WQ)ZH@&[4>TH(#6D`,,Y3\KR^8)R,?Q\Y$B'DI[%`"H?;U#`*,$D@"=X
MC/=0+>]8<#,DCV`H%QQP!D,99J%?C.2[X7&>$26FO[KS&X+@,L9E!B06AMR>
M?*K>DM=C)X:4[S$,8\$(N##AYAR*C]N&51G/6$S:8(5NU-K:J@-T0PPPPG"`
M4H/2Z0$81XB)"CNE!SY@9UB+Z$%Y@`X6!WC<A<W@5GYSMCKT3>=+!C,NLQ,N
MC##DC&`&:GH,XY/YSX/H5;<)2A7%&(!BT^#H64T-P$,60D$O'II9M'JAG/[%
M.Q1C&`"LGG?I(`"3'3D_58:DPK0?HH)`PJ[3QTZ)UFLBI('4L?`6D/XV$P(T
MK&<VP&L6OTWKY\-T;V9I\()R<$0*]\;B7S>`**",,))GAI=ZXR(YQS#21LY1
MCD'UR.>O=$,\-O.\B=)_T8Z_`P3>G$`[&69S`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q-RYP;F<`````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-#0V`#$P-#$W,S8S,#$S`#`R-3$U-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R
M90!!9&]B92!);6%G95)E861Y<<EE/```!+A)1$%46,/5E^UKU648QQ=$V#^@
M0=2;$@+1%_9"I!<;1+&,S!BU3`M"9^I8/LSEXT!/<V[H(7?<RH=SFMO2VF/3
M=IAG.D&=@@\SM2U,6F"+ZM!I'&@P,M:W?2ZYMQW/PSP3#5]<NW^_W[GOZ_K>
MUWU]O]>]#$D9X\W^5/@J=>7[&QH:&KK]=>7:+2K_9*]&9_3W_Z*_HX^,?8CS
M<;WOIKYH:!F;<:CYB(JW>V]_N'7K'P6#;?IX?WV\CTM7>L7ROO[?U-C:%COA
MA<R7M,-;J>:V#O$<$W1X>%A//OV,9LV>HZP7LS5CUO,VQH4H7/.^$L).9:,/
MO;T]ZNZYKMX;?38>[^R,#0%J$MAQXHQ(59P'DM':WJ'5ZSV*1J.Q$W(7YVG>
M@G>TM72WR#R[B9G`![8V_;F99EFOO*Z&IJ8Q#"M'XF(7SSVNO.7+1W^,P7#U
MPK-*N<W)6L*/'*@[V)]_#5ON@J%3!B_GK47:N+E$D4@D<44QX9O0"9T\=UZU
MAYOL\'E_;^F'"H?#J8^2!9NVE:GBLX"-I'67[X!<F@_6U*1V0(J)Q`+/SCT&
METKF;'"(S9F;J:0.6AI#VEZQQ_;_8]]/JCX\T]B3XRFUTZ<:DB(X5-.JHLI/
M]6=D0(%`P!8N7O2RUG^^3A3B@>:O'^`Q_O\.X-;9R]>L@#!4@J*B-OAM?#W$
M+>:L.07(Z2J1Y\*BCZP2.6(**ZD#B@A6$[GK?+>-1,4!<IER"\@3FD@$:K^^
M*6B+,:)/F(.J_7XK8Q;X:[\T'E#>RPHV&/0)'5#OJ"?ENV1%D:K\M;:8YSM+
M.*$#>(`3A(O%=`4(Y<A$'I(Z0">9Q&06XXS(D(H15&B9T],X!S`/?8>1..(9
M(400:0:F^R,.LE][([$#^DY>U3X39?2WM26D/_H?55;F4\90V`FIDF[!YZM3
M;7O(&A<-[.8/4Y2;.UL[RZ8J_'O$5#=E$O./=FAP\"^K`18AT7Y_G>:_^ZJA
M.CU2QG?%!:)WMD]7]^5+>CCH_,`!#`Q$C>T0%GF`L-061IZ[NL[:-U+(R5,=
M</2>`*`_@;H&"\CE`'E!HYPA.4@/AGHX.<+@,QS?Y?4:2`HE+0!(4.D.K^W.
M!<`Q0)QH\LZN,8)!JOQ5A?)X2E1>7FK]D.*"!VD#0,8@EBG42%D3S+5ZS*DU
MP=DM;9\UXR]!DZX!G"`#-&2.@(#H#,\$Y)UGNC^BA1)R/02`NWM,&@"I=_J#
MH*'3!"(([YB[>KB;':)'^I'>1/>8M`"0RK**O69H.@$)`@""`HB.0\-`OIT2
MH\(+E^9;)NX\[[0`D'J<$!R'[`Z9XYPY$M[=G0EP[AM@&%E']@"8%@!2C^03
MG%0"A-VY'6)\(]4\NTL;54]P1H!A`,`'8S(M2(@*\>8(EAS\2MEKB@S0JH)-
M]CY_V0=&+X*]O66AJO<]IIPWGU!.\3:[!%*`K*4Y,!?^<]=#H!*!2*IVB`X\
MAPG<.E>T!*U=X61K\5S].YBA8T>GV"5R=<$TXS\72YBQKOY(TLODA`!0,7HB
M`4'M'-)L43(7G%[IVUUB39<,(#C(LYL[:1:P"S@^W@'_]KC`U353[4R=UC>&
MCMMXWYL1E.KY[MN[%IB'IAW_!_A[F:WC0:;M`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S$X+G!N9P``````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-S``,3`T,3<S-C,P,3,`
M,#(U,34U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```$RDE$0518P^V6[V^3513']\YW_@'&EYJ0F/""&`P!8C3@_!$UP2`8MV1+
M1,3J8K(XRR"BXY=44&/%*1(G`9G+"*C;',[&):Q.:VB8@W7M*M/1='5-%=`M
MQD;S=9]3[K.651P8#5%?W#Y/SW/.N=]S[CG?<RLD510O^UGSY#/J.AJ2)_`]
MW:0W]K6)IPE6CZ2U==LVI5*I4GO/Y./>L.Y=_4C!1UW]>C4\OU/+[J]6Y5WW
M%-32Z;3>CR5F=BE>0T-#FN5S5_,^!=_:KTT[@K9&1T?5%3JFVK5U!:U0**0%
MJ9\,//""Z9RFIJ;*PRP+>\X*]8U-^D.%`^T?:N^!0X9CWOR%*E'H[.[1L?Z(
M)?/+XU&+``-3.'?NO(5(ZO"`$N]DD'`KKAO/BS`/MKZG9=_^H+YP6$]LWJIK
M,K_-9#(2B2@0".C9V&F+OSZP4_E\7I<?YI6LLD+R14UPL/W1`5%CF4Q&?^K@
MY*F890)CGKO?;E5OW^=:65.G(]V]ECZ<E:UBBHZTM;0>,<.G-FY7?^2XXHD1
M,][\TAXK2N=DR>V5A30[3_$?)[7CFW&]&GS-*NJ.\4E[9Y%^9#6UM5I\Z".]
M_N9>=71TS&29U`\,#LJ?RHF#C4:C5IX\*4D<M+2T:&QL3)PKQW;)).9R.4\!
M!^X=R/_,,5X=#L@T'7'9#NB[5YK?471@4!06=;&I:8OFY(#&Q>!P9X]5(DU+
M)<*,B^Y<6=91R1\@4\94FROC%X-[M+;^.7N'W\H2'X:P0NOA3K5_<-2<4/\&
M_P(1$@[?0>E;WV1][SD`*HOXJ7MVQ!%&7YT<+I#[M%'CEI<-Q0/5ZZRL/0<(
M^$##L#/QD@?@XPB.0E:]KL'>624.6'"4W^\W:KK^BX2]D[0;$Q,V%@B31N(=
M?G/\8,:/IL^:@%CI0GH!\J.A&"4DC@WXOO'TN!Y<M:JTF6#-VY(3YIE.^VSR
M9[W;%[;N^W5:`2.:BJ%!+HJ;S0L!%H4\&(`.@4/&^XK,I+5\;#BN2U9B-IOU
M%(!?W.*.JO]E[?S?`4`-TM`4-(U.V_&?'D9&A?PM`.AGYAC$0%M""/0VK<KB
M/_,/,,Q"9A^CC![XRP#8&))A`R).)I-&M+PCY[*#C,T9S.A#.(Y3;EYTJ\W0
M.0.`XC"`C-W]@HU<I(ZP8#L6[T0-F;$Y0&/QI-QQN9L8]TG\<53,[;(`B(8H
M2"]G;,0^?=]C4^<8AT0(&\*4R,@(&\(07(3X#V!\.1T8!K^P*5<2*&O6_0WF
MQ`#$;(XA0!@(1(DQB_3#,&Q*^JD19!0C>J2>.F#!>P#!#CG@86.HW%TR2HX`
M5(!8^%B='O9OL#-D<>MEW;3\;BU?\[A%@=P]F17(G:Y[S@\$M:!YOZ?+YC`Y
M]RQW%-[F$[_D=6::1P&QX6";&:"(//9=U@QV?_*I@<-)5WI";6<R@GN1+WFH
MRB)#%SE9X0*'C.]<_"XF\A(`-2?B6MK0*)_/9],@>P$,]VXBP1&3`2!\;Q\>
M*=%'%QL`5+ZPRT!R1`1%;9!1="^^*,]J"^87LXU-G0&.Z&OF'-.6:+D<,./X
MCLTM)[XV&R8R,O3)T@W=8=U7566%>$5$5)4Z:Z.<%BH>I%R%`4-FBF^P/>>G
M=&WB>ZL)KL?_#Z.K'L#O+J+358IRUM(`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,3DN<&YG````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C4P,@`Q,#0Q-S,V,S`Q,P`P,C4Q-3(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P```34241!5%C#[9?_:]55&,<__T3^
M)(5%4+^5$"1"B!%!!?5#45#X0R2D(8J1Y30<.9UZO3IOFVWJ%;=QG7?L;K9E
MKCO<%[?IW29NN<EJ:].!HYO.NSO*"QN,I\_K?3G7ZRP)E/"'_?#<<\YSSGD^
MYSSG>;^?YWIFYN6+?E:]\K(M?_$%&QX>-&]V=M:>?^Y9^^C]=ZVXL""[;&YN
MSC*9C,2[ST;_Y1YMF4FGK:^OQ[S6YOTV.79*LFWKEKO[:?G`?3;^\5R#EYNL
M+5YE3SVYU)YY>IEE9@8M=*A$XLW/S]N1[\KL6%F)E1_<:V7!/7:T](!5ABLL
M4EWY'S_Q<`LX0R+1)<=Q\>:SW]O;;[UA.&1H:,B\KO/M5E$:L-'A#N,V/]0?
M-KS-3?"65UH:,KP5W%E@IVMWJ[]RQ4MJ*T\<-Z^A(:9K<CVDO"2@*T<CU<:<
M#H)+<:]KG:LYW\-?\_\QD$JEK/_2.>ON;+-8](2-C?3KT7$=P77GSVN*)01?
M,VYO;S<9X++'CQVU*Y=JK/Q0D5PY>K71EBQY0CH,)#HC%BS>:BUGRRRT;Y=E
MIL_+&$;D0=XBN#^@R8-[=NI-BK9MML(OUDOH@XC`KD+-:XV_ON9D)'N/D9%?
M92T>CUM=;51O1"@2DCQFI"JL%GVLKLX:3S=H[<3$A#TFK[!HP+R)ZZ/&4^[8
M7J"GN7"A0RU(!]6IVS>L/E8C^(%TT/_Z:ZNSD0CTTJG?%'F$*&">OO6+U4:C
MTE_L;+)75Z^T<_%Z^VKS!NN]V*S-!*`,))-)2]_JDP%H@M!E3%320@#H(Y4!
M12)AC<'Q\7%AWDLD$C9SLS5KP(]Q,;,_YFNT<)#8U)^#]9T!PA@C'B'<VWE$
M0MQ_ONYC`>KVC9C("Q#1/U6UW39\MLZJPU]+#TT)3,0T7,61$8"T;\>6')`<
MF-`[,`$D#`P,#&2!!)S#%8<EW!F.=SQ/"]=7A(*:!V0X&'")=^%6.D+C3V>$
M-%`GY/GD`A+I@U*DJ:E12.SN[KZ;GURR<K*081?J$?8L@NG1R.(![AE,3DXJ
M:R`$._%*G(NR?'I"CXXP!,>,B7_&)%?HBLH)D&"+-<0]\>_L(B`PQT;\4$6@
MN//7[^(^TAG9F?&G:S\4!_R1'-,88L&`FX=\VEI_5!_042'1!_8(X'1[60>O
M8H\+Y0[`+2'9]-0555$P&RB&!JD/83'*!.:I%:&$H9];-.9`;BVZ3]9\H!(-
MKL$C>`!.9AX>Q@-\+U<^\0,?L3A]LTOE!`<0#T_WZ`#<DG*#>0X`V;&.,0>`
M>A%(CPNPK[AHHSX(GT'!Z&#1HF\*]6Q\4R4BKD=!>9))M=AT\HR%R[_4!QCS
M!&29COBW&C,7.K!)?70<SLVAAZY=GWT\`U2/CCQ`VB-&\(2J>0Y`8.%63L<'
M<:,31^?<FI9_#MP,-Y,[W!P>>.^=-S7'&HHO/H;PYNAH&;M`A9!%Q'1("4Q`
M^PA/X.KB7$'F)R?RBLLY3A@S3SY2*O'W8H-:.E>?^6F$+*B:S1_35SXB!H`+
MSX!;F&`!XO(4AO1?Q#=,;E+.RON(T[O#TW=[\@\`M)V0RJD'<C!TJ6=J:NH>
M`<\LY)`(\'$8IT\P+=3GS[,7.ZY%X`R>_H%_(IA$7/_?]`O[^;H'V5G,!8_-
M`?X&W&<(((<3Q.\`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\R+G!N9P```````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#0W`#$P-#$W,S8S,#$S
M`#`R-3`W,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-
M00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/```!+E)1$%46,/ME]E+E&$4QOTWBJ"++BN*@KI(J&A7*FBA3"G2B"G-;'&A
M)F/:3+%L46.21I-$$:W0B\R%M$S3J2Q1E*%%22,310L+"CGY.\/[Y>22DG01
M7;SS?=^[/.]9GW/&3T3\A@_KI:FY6:R)XW:[1!TZ)(F)B=Y5F\TF#,?%2[[G
MK2.ISBR)LSN\&#?S[DAV=K;4U-3*^J`P\9N[8;,L61$H5]+3Q>?:L8;^?/OV
M79Q.IPZ'PR';@G:H%`$;-GEWY=4^DX&!`7'<*9/HLAIY]>Z]''$53.**J=GP
MI-XM3Y^]D!NW"F7$AGLE)>)VNZ6TM%0-&AH:*B\;&[U"#@X.JJ4P/Q;'8BZ7
M2U:N7BNOW[SQPLR9OU`Z.SOES-D$*2HJTM,60D]OO[A?MTO.O6JU0U;1`TG+
MR).I4_./`(B+_5'1,B$`K.'Q>"0U-4V=CD5P>&Q<G$1&1JKI,``!0$!@S@\?
MNGXB<=/#ZL?RZ=-G=4AT=(R:ET-]?7V2D)`@!#<6Q1^[#\0*468!!&X*DJ2K
M&7+B7(I&[K*`K9)34"QGSU]4[[).(._:%Z/O[`'8`FCK[E%=@TL>*3(ABHN"
M+UR1CHXNV5)<KNNX:H0-KC[WJ/?-I*VN2=K:VJ6GOU^PC;%12'6#@O\]-_X#
M`%&Q)S4F)@W`P<K**LU1`/#]QX_=,BY`3V^OA$=$:/CR)!*3DY.EL+!00YEY
MWIDGK!D^`/B=C80O84N\LXGYW-Q</9R?GZ]K[($M?`".GSJOC,%-B`\`B41B
M(1&'R`&^%_LOUW"V`$@D4K>BHD*E@(\@,E0@.P'EQNDS9^D>\H"\L`#0'\.1
M3'NC[+J!;T`9S)%<S/,>?N28IKN/"N&MG4I\\!MY3O*T>M[*^JP\X0*2JZRT
MVDHJ'R^0*!@KI;Q.*P=9B+Y\X\J8@A(U("XU;.H#P.U8FLI"E=G?^%9O-=G'
MK<SS/6H<A)Q)M!8:&CUJ8:2",,P\I++''B__8#;^%^"O"D"L4_M(71H`6HG*
M1[5B*C`<,*4"D#20"+P`/]#^03@\(1^HS5R><OFR\H:IGU1PF`N,EI86Q>%)
M0B*HJ6XC+F4!3<EDZ)!R"1D!!%$!`+M!5#`>G,(:51\A8`+F66<O0K(&CB$V
M]GWY^G5T`6@MT!(I.<@3Z>%CF!`-H5E<P1,&05C<`3`7\LY%T!"60QB8!(6P
MSO#JXG,YC2:F!0A0+L5L@`&`0&BEM#5T$=J;9HIUM.<,<_1$IL'BG;,[P_9I
M>4.($06%@6^A=#I\?(OT:(P_::H,I3-O*I89%!D$8-^T&3.U=C!'$S9OD;_.
M<Y;>"YQ1!6!@GK"*>N%?!1=SR/]HO`7(X35)J0J*(&C$.M_L9WWVJHWZS4"!
MI8XDQ4%!K$>Y&3,+Z--"KF6J&ZA'E!*"#A-#]%0*?UN$:J!E:*@I-.\/*^OE
MH-.E;N";5*6"4"Q,CS=N&J;4-.GE^)>.DC*U8'NP!B(U[GI5G17!%$<C#%ES
M]W:YT%2N.ARC5:B]K4-<]\LU6"?$`V@.`&;#1$A,2C+(C&-5#6IZ`@SA^%X7
M?UK_`'$>H:BA[,<26"XP,U>[_@G_1?BU]?TU-H;[;KR!P&0/`OTO1K\;/P`H
M0J*N_`#'40````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(P+G!N9P``````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(R,3,`,3`T,3<S-C,P,3,`,#(U,30Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$'4E$0518P^V7W4^45Q#&]__S
MJM&;WG"AB1<V36N,30P8:VT,K1A4("($95<T0C&42ENMUOB!("S[P>?"=A=?
MNBSLLJX04@@EP./^9CUO,39R86-,Y4UFS]><F3ES9IXS&Y`4V$[V\\N=N^KJ
M[E$D&E5@<W-3K:'KRN?S*A8+K[/[6]X^X7DSBD0B:FMK4Q2A.VYY@P$S!@8&
M-)TOFCE7VZ[)6WBNJN.GU-?77[9S>GI:\7A<DY.32B022J?3&A\?M_F=5?PW
M#+.SL\*!/3__*L;7;G;)9R@6BZJ]4*???G^@4]5UJC[;J(K]7^J'SFZMK:TI
ML+2T9%[B!'-S<\946,CK2NB&<KF<`HN+BW:DB8D)34U-&<&<3";%YO=PS/<C
M@/O$)=<[.G6FO4=?5-:8%QKOAW7^Q[OZ_%BU&KIN:>^!(TJ5-N!2]I@`-HZ.
MCEK$U-75ZU)3J_Y(>Q8UM>>;K/WZFQIYS](Z=/A$:<^6W06>75Y>E@G`I0@9
M&1FQ!:*8N50J92X?&QNSM:&A(3U^W&MAR+P)P)1L-FOW,SP\;$SA<%B#@X-&
M]+'.$>F!$A28@`_C%G8%_#,@JZ%,)FNI%FSOM"MF#53;GNFO"5A?7[=0?K*R
MI8K/JDI)W6C]/7OW*[RATKTGK"42"75X?0$,B"J"Y/G?6^H/QRR<^1X^?&1M
MS=EZQ9.>0<OA(Y4V#^:9`#HN^O@N7FPU,.=[!5*6$R`+:'K[SCT_W(GBP,K*
MBFT`<F:\9P96A'4P&+(7`3@F%V+1N.;GLK8>B\4L-S8V-LJ0R&8F2"A@&:M(
M)(=?"`"Z.2;)A$-]"_`!GG89"2/X[@"0/FL0ICOLSV0R90%D%!K1@F3\X;+0
M9:7+1,9D+()]"W9SX=T%[!KP_S4`[&M.%GUJB'OV0L_/YW3Z4DC!/U=MGK:J
MY8:>#@P9.G5TWM2YWG%=\?XRHE_?%-1;#0`."H6"I3N92D8#?90!*/ON^UK#
M$-:8SY7FO_JVUBJ!<XW->O%J#&P^2*34/[-@51C&,/_IP:-6#8`&P`G(Z)<6
M=(`3JC%PQD$KPODBT6';?/+T!0/TELLAFZ>2`UI!33YX,/3%8M%*DT_V53C,
M-EAFG8H"XJ"@L$$1KPEP##,&`(;@ES.`(BEXM?PT0923[!D=FS!\=X^&JSMO
M_=1M8^HA#.+#4-X$Y+M*$Z@W.'=H#,*R`")S!5B*Y1!>81T`!?[M'T#),]P[
M?.%P&=XA#L*8"L[]]8`8<P4\&R`Y7C</8`4#O,`"BG"1LQ:4YTU!,&,\Y`HY
M^CQ.$/$!L<8>6L;48AP(@I]]R":8S0!^"`JL1\'V)\4]*[3,H<@I=0H=/X2R
M?YN''Z-0[`I\%XA^.C#`&]ROJS*V$T'C"(_M1/"MKJZ^(0="OI\%NTCXT1OP
M$E8<O)S]V'FM`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O,C$N<&YG```````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(R,0`Q,#0Q-S,V,S`Q
M,P`P,C4Q-#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!
M34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P```0C241!5%C#[9;?3U17$,?Y?_K8!WTQ3=K$!TVL]J7&UM0836H,Z@.-
M%1<1J8*5$G5Q#0CKP@)9T$5:*F2UBB2B;#5(BC^P!<7P0RU(L!$4(7[E,YMS
MX59,3.3!F'V8/7O/F9G[/7-GOC,9DC+FB_TD$BUB_;VQ+K4;CY1H?&Q4M[N3
M?G7/Q+=Q[5I2]_IZ]5MCC?"5<2`G2\'#A8K7114)E[V#CP45,'WP=[.F)[JT
M:<,Z6WNZ$W,N8\&`VB,!M89S3-HJ\]0:+=#E\XUZMU>\OT)'QU7U]_?KUX:H
M"4$D$)["7]<;]-6:5<K/SM3HR+_Z;-E2M9X[J9F9F53HN1JRXO,E>C(RJ$13
MRHMY:+UXWJ[HKGGQ9+Y=\VS%`2WB+=Y'%L]!K+9<.[=O5$-]B;Y9][6MDZ,M
MEE1[`KLLC,FVX[IW*Z:5*Y:;6!@Q)F%1VO3M:H6*\RR<TJB2[6=UXEBA0C]G
MJ7!?MGV'^[V=6OKI)_82ST%/SQU%@ON5MVVM&D/9.IBUWB19G:NCN]:;\,QY
M*"_3D.+PQ?/G*0=/Q\?MP\7+BU)2^I-.A?:*-$7J@[O55)IKPO=KK@U9W7Q@
M7R'M0!E4\O_7KAN=&AX>MNKFF7SA/T(2^1%,)\V`]*7J6>.Q_9J<F+"T?3)0
MYZ4SS]&JJCD'>(/L+OU1KY&AJT9X9-NK%]V6,+&:2JL-TIUS4IST]QS`R.0^
M.3[YWS]6#RBQ=R1GLW=6=C1?%YI/&P*8QAR0SQRPH@PGX1V#0X7Y]E8Z`X:<
M#PWTF3'Q,`?`A_HIE-K#.ZQH*)[ZHBW&8ZZP.'<KU_,0O)R:,LCGRO=XY#>?
MYR%!Q_>.\RDF7PR(/HW,52.5Z*J12J3$726V5!99T^#%Z5I8)`=I`!\?@/BI
ML#3=HI(CN:+=)9J">CD65T5IB7$@7,@S.HY#*,2!GK!1WJ.^*COG&2ZYVW7"
MGCECK0X'/!Y9$``C`MRZ]?OO=*;A=&I$&&LS+F448]H"%,+L"%D!#!#%Q<76
ML+%G2J#[H\,TACUG@&+<`+@/`!MP+PJOIGJ-FRO*"FP@A8,9ZP(_9-H9=(IS
M:="`,E5`14QVT#&Z[H7.OCKRBUT&?<#Z(L`-;MV\::S*2^!O1D:8D]GFV=,A
MFW?@,&8;AF^$_YU_MFGMEU\89?,?&N?V\=*`32CH8(<]@(@J`ZVOI4&,A)?O
MS`#%A(]3^!\!%$YQP/[NS2N-[@&(+F?H.%OTW/[\/:*+'NW0!X#PTQ^X+0P.
M<],>H/[VJGVI-C#;$OB/=$3WVN"&\)^]*S4%)I=K#YE@"_,[<9^(*+E6XOL$
MKO?:]YP-G?6AZ)Q#A#V`-1__\0TQ@+-]#$`+`<36M:(W`#@03!"4'@I,%H\?
M#IH\''R@X8$Y<<^L;Q-GBQ_\X1?_+O1I)DP#</(:[E7S(,*&!LX`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R,BYP;F<`````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,C`V`#$P-#$W,S8S,#$S`#`R-3$T-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T
M=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!!A)1$%46,/ME^]/4V<4Q_FW
MC/^`B?J&.1),=-FBVS28&'4A@01,DY%T,DQG4ZVIM;0#@:X6.S:V&F#C-T@P
M0:SEAQA,E00C"7%.0W#?\3GUWO4*2TSDQ;+TQ>%Y[KVGWW.>\YSS/8<*216E
M8G^6EY<U,C*BB?&)XMNZNCH]??)$C0T-7G7W)YX7Z^OK`F-J:DIK:VM%P-K:
M6BTM+<EWOO$],'94:&UM57U]G;+9K)J:FM3;VZM`(*#%A86BUE"V6WW)L#*M
M`?T8#RK;&=9OF>^5G[VK]S/QX0KI=%JY7$[Y?-Z$8!!(5^'33XYH='34/.<#
MISA[YDQ1X?6K5^*8)[_\0I%(1'^\>&%K,'BIJ+"QL:&!FU'UIZ[:,7MO7-'M
M9$2_]W1J%T_Q(;)[`.WM[4)J:FJ4R634W'Q!/I]/,S,SFIN?MS"&PV$+'^$D
M*3P`Z52792$**`+&"M#T]+3Z^_LUOP74_(U?>_?LT>R]>_\`;&YNJB>94.7!
M?;I\H=$DZ&_0^7,G3.I/?VYK,M*BFF-'=?3P(76TQ;T>S.=S!M)V+:3PQ:^W
M"8`.\-6`7^C_QVZA#*`*LH]*'MZB19X'!P?E9"AY`L-1S(YX`.!2`*ATLHT4
M9H42R<3JZFH=/WY,B43"WD.S'@!2F'R'6]A757UL5CJ[NHP=`*(F`)F]/RN_
MW^\%@+SA'?(=]H28<!W`9M]7QJIX5UU5:0#H>@`"+7[[(=;'QL;TY\N7!H"K
M+2W?FD=4*15)G#@6<7$!"LN/#-6LO2T<]K]TA*S`H&V>*22GF"!#%P`.A\M1
M=`0"-*YO"[E$V'<SKN&>=M$+/`!0Z<10GU4BE?9N)9:6.)+J2`BV+=?"+@&4
M'?A_.4!U,1E"'%`<>Y@H]4/*.C&<"#_PS-0'4\%8<`@,=?UZ3-%HU.40Z(]&
M#2F!&8O%W+EG1P=0A`;ATP/[]]G*X#0W-V<D=>BC2@-E[,0A9Y"";^G^$)8S
M2_+L8$#RZ.#$RLK*OSL`"T*=DY.3*A0*9IPHT!T@?$Z%`1P-A4)V>HS!ICB(
M+M\QPC?>$QF>&6J)$`?8T0'H-?A=P`QA&%E<6+1PXCDKTS<G)I2E\T_MJ<_,
M`.$F@NC2$\#@JIB#8&'X\OFS5?WUYHVV.0`YWAD?<2=[[IL.A&"(\-,/6(D$
M)X?6R975U56[#D*.L[0&C!,Y(DJ.T`IQCO;@,/DV!V@+XP,_:>S7I"M#F;@&
MNZ.VCO8D3(9OQ>R=(\XW6H4C`^FXM0_F-4=N_WS+9C*G$W@<("Q/"X\M3`S@
M`-"#Z%/.GM[$A/BNT+?X_X1!'H=PL-1)Y[?=;1'#)]=V3$*<P#OZ&_=-K^<J
M'BXN;(4P;V&D(C@%>^Z=;PA[WM/S<V_E0>Z^Z9'0W#VXI?=?9L*R`\C?J/GY
MBQ"-VWH`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S(S+G!N9P``````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V,#<`,3`T,3<S-C,P
M,3,`,#(U,34R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G
M04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQ
MR64\```#&4E$0518P^U72TNR01CU9_0KPG6T<A'UA9O`91`$[2J2"*(BLJ`+
M&$'X2B5T(5,JK0PJBHHHA:(+"A5A66`7L0B_*,5NY_,\T$4P</7EXET,,O/.
MG#GSS#/G.6H`:+XW3<:!NKHZU-?70Z_70Y/=DK2!G9T=E):68FMK"]DMR3CA
M^OH:965E:&MK@]/I%#JMK:U0%`79(>3"A(J*"K2TM,#C\>!/20DZ.SO1T]/S
M%1BKU8J#@P.4EY>#D9N<G,3,S`QRY13_%V!_?Q\G)R?8V-B0D$U,3&!D9$3Z
MQ\?'8+2.CHYDSMK:6GJ4F#$-#0U86%C`Z.@HFIN;83:;9?'T]#0J*RM14%``
MD\F$V-\87EY>O@"2R20N+BY`!D-#0]+FY^?1U=6%WMY>3$U-X>;F1E*1FUQ=
M72%'@Z@"Y`+`^/BX9.'R\C*\7B^"P2`6%Q?E<=ML-OC]?DEM/G@FWR?`Z^NK
MI.SL[*QD8U-3$XJ+BU%34R-@#H=#FC>EKQ1'1;$@'H]_`3P_/\L;F)N;DQV=
MJ<DNETM$F:#M[29);3+H[N[&\/!P>BH_/C[*@WEZ>L+>WIY0]/E\<+O=N+R\
M1%%1$0P&`\;&QN0]I,7@[>T-L5A,%O!\/#>?*B>2#0'XJ,[/SQ$(!"0V.7R-
M*L#O-)6`2B"M0UFD,(7#851558FVU-;6HJ^O3V20[HK5GIZ1W^BTJJNK8;?;
MH=/I,#`P(%+*-51'ZC,+N=%HE'5T!HIBE2*?D0"%[?[^'NOKZT*`P+1V%#CZ
M94IK1T>'@%)2J9)T=O0Q'.OO[T=^?CY65E906%B(S<W-E!2WRYJEI:64XKK$
MV_P8`?J5W=U=`:"'.0V>RJE(A!OQQ-1X2C:=,OT/B:RNKN+P\%`*""-#!TTO
MQ"@T-C;"8K$@%`J)_<EX!>_O[T@D$HA$(L)Z<'!0))V@]*VL$W1F!&9!8>U@
M.$F$=8+?*?]:K58V8=3.SLXD,GEY>=C>WO[\MY!5$C(7[N[N\/#P(,1N;V^E
MAO**/L;96(>8,]%H5'[9Y_WR&C^P./:]G]NO0"6@$OB-]@\E2/A&Z>%#.@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S(T+G!N9P``````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V,#(`,3`T
M,3<S-C,P,3,`,#(U,30V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*
M8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E
M4F5A9'EQR64\```#%$E$0518P^U72TNJ413U9_0OFD<C!R%!DP;-A"!H9F%$
M$*F$!CT@"20M"C*PM#+*A(RDHM`@T8S`'O2$'DI%2*2A/=9U;>@A&#BZ.7!P
MT'/\SOKV66?OM9<*`(J?0U%P0:O5HKV]'75U=5`4MR5O(10*H;:V%H%``,5M
M*?C`[>TMZNOKT=W=C9F9&0F'WZU6*XI#*(4'&AL;H=?KL;2T)*3T]O9B8&#@
MFQB;S89H-`JU6@TR-SL[BX6%!93**?XOP.[N+HZ/C[&YN2F434]/PVZWR_SP
M\!!DZ^#@`$='1UA?7\]GB1G3T=&!Y>5E3$Y.0J?387!P4#:[W6XT-36AJJH*
M1J,1R602KZ^OWP"93`:7EY=@!&-C8S*\7B_Z^OI@-ILQ-S<'OL#E<LE+;FYN
M4*(DE@%*`<#A<$@6KJZN(A@,XN3D!#Z?3XI[?'P<^_O[DMHL>";?%\#;VQNV
MMK;@65R4;.SJZH)*I4)+2XN`.9U.&<&<OHH@#@\CG4Y_`V2S6:D!C\<C;W2Y
MG)B?GQ?]6<R!FDQ&2>V]Z![Z^_LQ,3&1G\K/S\]2,*E4"I%(1$+<WMZ6T*^O
MKU%34X.&A@8Y'NLACX/W]W>I+F[@^7ANEBH?9#0$8%%=7%P(!^2FA*^Q#/`W
MHQQ`.8"\"661PG1U=87FYF;1EM;65@P-#8D,4MW8[>D9^1N=ED:C@6-J"DJE
M$J.CHR*EW$-UI#ZSD;>UM<D^.@-ZRW@\CH(!4-@>'Q^QL;$A`4SE@`UZ@P@<
M_3*EM:>G1T#M.4FE2M+9T<=PS6*QH+*R$GZ_']75U:+Q)I-)]JSX5N#.232]
MS:\,T*^$PV$!X,;3TU.,C(Q(('P13TP6V#0,!H/X'VK[VMH:8K&8-!`RPU/2
M"Y&%SLY.#.<:R/GYN=B?@E?P\?&!EY<7)!()B9I44M()2M_*/D%G1F!*.WL'
MZ63O8)_@[[3P/#UEGX;X[.Q,F*FHJ,#.SL[7OX6BDI"Y\/#P@*>G)PGL_OY>
M>BBOZ'.=@WV(.7-W=R>?G/-^>8V?6%S[.2_M*B@'4`[@+\8_NCWX-B:--ID`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(U+G!N9P``````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R
M,38`,3`T,3<S-C,P,3,`,#(U,34Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&
M```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E
M($EM86=E4F5A9'EQR64\```$($E$0518P^V6?VC4=1C'OTXJA<@_HA()(S#4
MRB0A_^H'V()84.JLG/1[.3I04O/\IR.A#6P=$B<7,L]RM6:K;8&<.MLQC:WI
MX(:;ZU*466P8[.+2H7&XU7AWK^?X;'=NQ*"2D/OCP^?S>3[/]_UYOL_G>=[/
MXTGR<H<WI6#=MCH=O3ABPYO>)WF"I2O*M&K+=BU9&U)Y\/`T,*94N/OU@&9N
M:M2LL@WR=G;HS@5+Y,4ORNM(9;6JJJI47U^OIJ8FI5(I!0(!#0X."OGTKOB/
M%;`61S#/>"EBALUH."L<%(E$Y'5>_E.;_7XQXZU=!]JTI^LG!2(M"H?#\J+1
MJ/U:/!Z7S^=3(I&P@U@LINOT%]<'P#N2E/=>3+>4O*NB/:?$_ME0LXJ>J+8U
M,CSDSKS*8_(J]D\X8=OY*YK_Z,OFV^+0=V*_[OV=]A'[M2W=FKTRK!=;SFK#
MP%737=]_Q8+&`'@0'@A7$U6X&)<SB*I@,*C2TE*+MO;V=M/AK+^_/PN`$A^-
MC8V9$K+1T5%39IU,)I5.I^T]V?.6[/]'KU``^(<`Y"L9#F]9F&9XBZACO3S4
M:"'+^?R&GKQ0?ZNR-AL'!`["C?M;C#;N+:O(`D!\1W^VL%WQ9+%N_JS-`+AH
M;K!61??Y)P!6?]YMBN3`(UM#E@/$O*_W%]U3_*JMUWP5T^(2OY;YOY;_2-\$
M`'E0V=AK(0PO<1OFL=Y>4RNJ`^OPMQT&#%^QO^W^%[(`Q#7)X9*$I`$4WSC*
MAL,8@',1,M8&0-*XY""A."3[2##D`"%CSN5^$FS\&4EC9M*3`T`!8"9#L8[9
MG3E&+83ROP10,.#&,&!X>%B+OCRAV_?&QP?LE"M[L*93?0._&1>P?W-75$.7
MTWKZX!FC.QB-:IX>^<,*,/K5![JTM*$W#Z/N6$*3#"#%K>?+E'QZ0'@"LD%&
M5V5](><9;J5G9`UESJP[+N_C+M.%1LV03#MQ:TVK&01]NN_0N>FC;[(Z&2:$
M-?(,>/CDKUKVPR6;%T?/V$4/]%VR\="YM!$Z((M\[YALSFN[M:![2'?L:-5=
MSU28MQ@8PCRWZ4<S8-[IWXW#H>7'OCAH>PR`*/,,J!L:4<6^N$I6E1MG/?]*
MN2)#5_74ED;SB%O3;[*&FJL[$\;MU`(HW,EY/N3PO_N.O@G]JIX+DPV`J@\=
M/Z7-'S2;`3`OC(OLN3="9D!SV_=6&S`,^<+'W[;>%GGW0$HGSB?M?;GTP]V?
M:,>GK78IYX=[!FS0]^)%GI0[Q@W@CQ%0$KB8,H`,%H?5:<38NU*!'I>SIQ)P
M1B`[73P*XV.L*S4,[J!>\<.3>C,.^<@U=P"RI[@!PAZ#6",'!)DK0YRY#A,=
M<%A3AC@'!^/1HR1-R0,`.M!<6>X'#$#='UPK_[N<OQ:GP(0%`QA_`:A8G@DR
MG3U,`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X
M,S(O,C8N<&YG```````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0T,P`Q,#0Q-S,V,S`Q,P`P,C4Q-30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8
M,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```2U241!
M5%B%W9?+3U-1$,;Y8]CR#VC<ZD;=Z$H3WW&!AL0$5VI\)+Z"`15\(+Y0RD/`
M1U$I"$30`$K1%*02J$1>10K%`NUM@>#(;YIS%=M$HDB"B\.]O??<F6^^F?GF
MD"(B*3\O_>,H*9?'S]^*_>!^D4,ZNGQR,:\BONWTF2Q)3S\H&1F'%G]O?Q*<
M"(G](!0*23`4D4+'"^$^)1`(2&;F83ER])A>$VPDM<EZW=8EZS=LE,GIL&S<
MM%G.GL_Y@1.,OL_#XA^?$BL:TTW.ZA8-9NDN_G[#L/^+E#]Y)5D7<B1AP^#0
MD!+)IK**Q^)^YY6YN;EX%"VMK5+_JD.FPQ%I?=^O432W]6K(NF%^?EZJ7KBE
MIV]8K<1B,1D)3,CL;$S6K%T7]Y.;FR<G3IX2TG3[;HE<SKNA5%^[GK\,//RQ
M`:_7*RS@+=D``9-3:*MK=&L\Q):=>U,\'H^XW>T)QN(5&`Q*UZ<1>=/NDRLW
MJH0B#DU.R:>!@'P>&A<JE.?4,/1NV;)5%AF`/?."?+@[^S0WC@>-XFKP2%%9
M@R*+1J,R./)5JIZYY-;M.^K(AF)9EGKS?!S0C_#X;7Y.(I&(&J5,R"/&;A:Z
MU$%:6EIR8N!B9F9&85(RYC<(Z*N52>,J-P!9%165TNOS"36R9`-LIGRY4D2D
M\EQ6_M(-5#YYKEV/AI4^;-0^H%AV[]DG-/ZO*4PP0/]2,-NV[U39I+BH0*H4
M*:$_J,($`ZZ:6E4,E&/O_@SM`Z2%RD1>""?[4K$J"&4/-[8!.@]H&,!#,#2M
MGC_T!K2D*6>:#&3T!NAH*JI3#83#TW(H\[@V4G5UM73WC=K-Q$C`"-=H+"[9
M+&80^DZ?*`R(>MG<*5T]?G'6M*AD\B%>(U94A1!DO*.U^P?'E&0Z4@T0$W'2
M,!CBI;=G0'];"U[H4%)*-S(PZ,:Z>O=BT70ZGZJ2FD6<J#RDH4KFGN%HAAN.
MD[8RFLW5+)`0%F13I:N@F59RK4X`M!ISBL7]/P5`MZ`D]#L:5U=7+P/^454<
M:I[VI21IEF4'0&\,CXZI(J&1@?%Q_8USA(?3&0L=H4>0@F4%4%+V2)UU=/=I
MM&@*"Y$F:IH3S44N43J4D&,$H/B.8]+/RO=;`$0)U6@N@H41A`UI0?!<M4T*
M!#VBH>VU0#\G!H8^2@$85/->J5-3=+7`H>DSQ\($`+Q@`^=H:#9THV=$RZ'(
MLB(JTSCD0(S.DP:TC?MPQ%(0Z-RQ4_GV.$/2`(3Z4DM)`4`3!U>*BPBS<PO5
MR(Y=!\3I=*IAA@M7Y)Y9P7D6R2?_7\8FQ=W1K_."%+&'_Q#T^0*#L,`Q*#4U
M51F"95.T-A*B1V01WD!P2L$P`CJ[^W4,D`X4'X>5S]ZHLA,MCF$`=6<>H\.P
MQ!@!0*?/KZW*^0R6`$Z`,`*S-@!$NZFI29TSAW!HYA!'3QA@7N&<7%-H'-8Q
M2JOBU$1,:LQA$)!\QU0E73#$.]B@@!?E@ZD!*CU=+^2?Z/G03%6,G<TJ5@,`
M!13,,94!"AL4+([91QWP+39(%VEF4:`P0-TE;0W&-F<%<RJ'&1:YHR80(PJ*
M9>[9QSOSGFM!08$N[GF//?.O`\!A?45U_X^D^+\'\!T0>'68IU\/T@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R-RYP;F<`````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M-S`U`#$P-#$W,S8S,#$S`#`R-3$U-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````(````"`(
M!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B
M92!);6%G95)E861Y<<EE/```!5=)1$%46,/5E]]3&U44Q_D#=:9_1!U?G.F#
M(T^*C#Y4BW:LG5)KS5A:P2G4(&E)"1"AT)#0AD)20]K$G0(!&D)2?F;L1)/C
M?DZ\FRR;4)E.G>G#83=W[SWG>WY]SZ5#1#J:1?^L9*=E=.@[V;+&ZZN+R:>2
MS69E?LFJ+V2?;4JQ5)+'Z17W>4?'QLI]2<5'1!?F@I?DEO^V3,XD[=\UZ4AG
M5^6GP=]T(1:+-9^OR6%A7K;79T7^WA>73CZ$QV[*_N&AH.%>\*K$I@:D831?
ME/6-34E9!=G9>2'`_++GLB02BPT3Y7)9]G:>2_F@(.GTLE2KU8:&XZ3QHUI6
M@.`!L`<D`4POCLKT+SV2C`XYFW2#M3PAUMJ61!]E!,!$:34Q9#;4Q'_3)]=N
M^#7`'YSIE'QI1P*C$_4-NWN[&KE\85NCU]<_*8/^B)3V#AH;$JFLJLY8.<EM
M%.2'OC'=Y&#`Y^UB4>.PGK,TN5XW6TK-Y?+Q<6I*Z/.UJ*0?AR2;FI1G3Z;T
M]Y-$2$KK4QZ%KD"SB7@^F+NK@E^S\[^+[^N/A+I"*850K>QZ7:`*,TM!Z>^_
MKA5#$.Z$HEI!1.]68%:6TJL2"(QHLER)0@CKGR]?:OP)&$+11^-I57"QMU^N
M^OHT_*3%4TS=GWXB$Y-AB2<S>G`X..^D@_209,J4L@59/K_E3A,ERH:9V%,]
M&`H_U)QR<'1\0<Y^-:!/#L]$%MP*7D?>M((3%Y(MM8I4#C):-#0@3WZS_FH%
M=C'EK'M.)?ZQ'-;?"$763#<M*Y%BHA(YP#-P_7/M[H69`6UBI2)[7PL%-86*
M%>J?,H;U8`!*>>1*I](%RIKIHJ'`]@^K6($-*%\JCIQ31#\/#CM(4-8<#P<^
MD%%`D4S/I;1H*"SJG^*"<B`.W/)0+PH8"30*4X"Z-_V`=:IP_V!?4:'L17'-
MK0"&X2.T3#-1OEBFD:`L%)S]HD<8-72E(3Q'`1^P#)]#?O#`PV1.&\<T%@'E
M.PAPQ:6`B-.)-`A19_.E[W_5-J8;08$[*&;/Z=/ONQ5$(A'M<381=:S0C;B$
M.RBD0PDJP?4H(`8<A(GP$9]Q!6M,!-"<OS"DBHF+1X$1&`FK^,X8(]K0.(KB
M\4?"B/N_V_G-RPDVU^HM@-"0"!5MWA%MD>/YY^2$9BLV_$2_&L9`H!L&'VM0
M$$\N6,I?RAJO!G.L88RBU-`3DDF-JYC>AR"8AP"QDF.Z9EAG,QO\M^_;`VG+
MR!A%*6*,FPA@A&N;5JA=[MQO;IQ[3^Y>ZU+#`($:H4`FNEZK_A.CVT@QCA%N
M548)QN@UFI)60>AJ>HX>\]^)*=L-^,XI``!RCN@``&#M0'A&BLFU"24,"0/`
MT^:N`L5@%+:`NQ&^WPZ%%03W%T`S00R'`^3H-#D"H)YW#"/D%04_^GJ5/3`(
M'>$QWF(,<.>_N:(LP\T1.N,)X\!`7)R9#=R7`-:J'EQHN'7!BQQ$`0P-$S,?
M8")8&%:",PU/\KZ0M!38A6\O.J3,_"`J```\Z>+FWA8`-(>!ORH5%0`,#H_K
MA,,(QA#6\1"EI`+:Y#OO1((H\61T<)DC?7P#B)E/+0&`N+?WLISYL$O>>?>4
M"B$F[PPWR)Z(,*=0R%3`<R8%(X?0,PQ,9+C7,><@?H8APG\`]2BT`(#7S#6B
MP`T3M!CE8H!!$V[>F3:LLT8$"#F>F2AQGF(UJ2!J1`P0;0&0`O+,(;SBB1?J
MI0T&CPDOBE&*IR8U1(FT$`4S^G@W5V13F$0#&^V+T+XF8YA"I'(I*@3DY+2[
M^S/A'DZJD*Z/.W4?PA[V4K!T!GO-FI&CWK_&-#27WF9Y2\?Q/_?)_\X04%SD
M`````$E%3D2N0F""````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S(X+G!N9P``````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,Q,#8`,3`T,3<S-C,P,3,`,#(U,34S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/
M6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%V$E$
M0518P[6776Q451#']T$#4<,;)OAH8O#!$$-X,8;PH(D-QI`8-6`QA*A-,+1I
ML(8/@S0$*F**@50H$MA$9(%LC,`&VFI+M:75?@380JEU4P1EL5_KMEC0PL7Q
M_N8ZU[O=M5^$A[/GWG/GS)GYS\Q_SH9$),2X<6-(F/4EMN41:?SVN)2\-5="
MP[^?DXZ+%Z2CLT?J3I_VQ*N^.2NI5$J:6B]Y"\&A/SM6S-3]NG!P_4RYDAR0
MC\J/>%M0B`X6%BU:.$;'WW_(.P6OR<^)F&YW',?[\%?ZN,0K9LC6L@_EE9=?
MD)&1$4$ULPKT]0]*K*9%(M'OI*ZA0TWL'QB4MPL*LLUDT=SVS1YO^`\_-$4D
M?>%%D;O7].P,@5OGGY9#'S\EQ2\]I'BE3CR8*8`']0W?2S@<5F!!ZMTW\SRD
MSL6>D<7/S5/+\>1\YU4IV_:I7+YZ73>$(H<CTMO;IPNXB<L\`R]:0R=/56NL
M]NP[J1_JF[M4D#6T^EZ@!43_U\U<@PV5>S^32>&$\,[R#X2``LO6-4\J',OR
M9LOEQF>]_+@35RN(Z1@%CL(CM\IUXZK\^=+:_+4DD[]*4WM"]G]>K;"1`-UG
M\C08MV^/2H8%)&_[_@6RM_AA18=D`(3T4%IV[8[(TM=7RA='JQ1FE'ZRL^(_
M!0A]=>R8E):6^A!W)I***.]88/`CPV;6"@N+O-.)%="CB(V<\F6L69*_]:L5
M;"3(.W9%-3S(4@V$T'<!GXD\J(-#V>9E.B]>^)AL6ON\9@NIC*4;-FR4GIX>
MF3B=W8B@=%)AS#5P:=+UDFO4GRJ:A@(WQOC)G(C-D51_HSX'78$MLA2TU+PJ
M/W8G--MJPX]K]9*)%.KHF0=$K7$Q82;!LA3<O3.@@B!/95.T9"3"1.)Z[7S]
M/A94_1GHZQ(&-<#F6/2`AHGX4Z;D`.M:#VZZ6QIG6-#;,$=*EL^6Z)%*/RO)
MN)*2]Y3&(@>WJ57(5%=%LQ7<O%8DO^R>H>D)"9.!C/;X3YI`U`.U0)KSKGBA
MX%);H:)-V4*[MI$ZP'1R`2(GC=DX.#2LQ41)^XR#F2=JZK0*K9`04M[Z5Q%U
MP;-90S&I`F**KP"&N2UGN[5@.)&B:FB*JQ64-S+&GARF/0NT.0F_@^QII&B]
M#/]I'`SZ$_R@[8<?)6QW@[$//F.R*;<U%!G!&ZTI!L05-_@`+U*ZA\+Y2F$D
M$\D%P(1V7^5V#;.E<XX"<?SV16Y8VN+:E*N15AO,NBDK&'>X%<IU@DA,6\?D
M#7`T%8)]F<RGL8)KT$NP139(&5,PP-&BQJL@&\(4T,O[Z_*E.UZN!3W:^JC2
M#4&FFEC#J-CA)1IH=`7WM[6U^CP^(0(H(@%H!I``[S`-]PRH"4*@=.<],<L?
MK'/+8UV;IVL01J.'JQ<&3"$$CK9P^`^"03ET9@.O27>44B]4,/6"YWRG.8,.
M,TXHJXLSD0'>H<051H?)&=02=40Y$!98C#Y,W3&H<`;T0(5#)=O7OZ'[N"E`
MY-Q-Z!@8.!:)G-D-?&P"4A#@($@,TJ/8[=K!;8$#Z>5\QS"HAD)?LSI?D0-^
MGD$-KL]"X,^;5S2QL!#OH69B32R!$R7<(#B,@QFP+<3`#/Q\@Z8@4+L',7A&
MQK@2P]:N*U96XCGC`LD@^Q&`@8$5SR!8(U7B;50/W!@!:['..YQIA$LKM([&
M=PS@NH0<Z]KY@R$@-L#(1XB6=_.6M@#4]!,4P/8,ZS4<'+R+F;$@8SF#<W#&
MZN*-*LM%G#/\&Q"'`J>U"PYF,P>8I\QL!FH\8LT.M)S`:#H+<AAM,LAC-"T;
M)PDKO.#_V2&Y$+3X8I0U1/,:3\V8X,$&,6'#.`8AP`CV\<R,/FZE&,&^C!!`
MIT!%@MA`D+`PD\VLT>K(:MY)5+X#K64[-U?09#8]'&HSNH!^G':8.3",2JFM
MJE`#N=U1JK`C1(5B_L<-I[N\6Z$K1_(:;P3UY.H/T^^&[F%0+9X&_W[>IVZ8
M>]`=*=-[T?$/BGTA3''7"$8`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R
M.2YP;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-C(P`#$P-#$W,S8S,#$S`#`R-3$U-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!2))1$%46,/-
ME\]/&U<0Q_,G]M9<JEYZJ=1#E`.G*H>J51,IR:$E31Q5<026B!-P9.)88&/2
M#3B.(0:#P1!C`@&+&BI^-8D(A.QT/[-^:R^V8U#5'X=AEWWOS<S[SLQWQN=$
MY%RCZ)_M]5%YE@C*T9]S[M?I_`M96RE*>BSI?CC8GI#IH=LB1U7_>4_'RI(E
M"Y.#HA\20Q%Y.9^1<KDD!V]K1X*7SLM&*27>$4\<I7)4$?GPA_AT8MZRAF4N
M/Z;NH.Y%+BO)Q&#MY/&.Q+HO2NC[+R1R[6LI/+DKQ7Q2;/OXA)OVH<CQ&UWP
MF?B4U/_Y^,YUT)%F#8[77'YY(27EF;A,/^L7-<<&=D<'[LI,SI+%V;2L5]9D
M;KX@UDC$W;"WMRN@55DKZ08$]&]<Z:H#-9,(*/I<<>S>95DK6QJKN@^.@X%O
M/Y>'W1>DNFQ)>8I`V">AMA4#O4W+:[84V]/4&2=SP(&$C*FLICUH-BN3&GW[
MX%5[#PX/]N3I2$CZ0@&)/0HK$@0=V!87BS*>'M<$Z`O^+%/9A/^.8$VF<#`W
M8<E2:5:?8`W^)"0*P9\,`N*MS8H?I+<[)=4>#%R5@?"O,OSXOD3Z;NGFGE]^
M5'D<[54O7^;ZO:MX"O"".Q(.TA)Y</DK#0FQ*Z;#FB:OBT/-"=^4LD[";<P_
ME,S`=95RIM<-O!ZTSQ+&SO)/*SAS(KE@4N.F^%RI-B50:P6UJMU<27I92.5L
MK8_+WH;E*FH+HH/^\;N2+X41*&ZID-0J+^4C-24G%.#VZ^4I3:"!!SW*8:3O
MZNJRIC(I3"KS/1J^)?N[=27ZA[2$-DC33'I$TQIF*"].J@)3#Z3S;Z-Q37F^
M>0K0B`(6R7=JP8J'5`FU,#N;T\-X0FI33(>'[^L*LAE+7<<ZA^&GPF1*"P9O
M^-\HH59@73_C..C34R@8/$$H'*R98N+NH\D^20T&W-">!)$(C`8O:>$,W>[2
M8H+O(4*JCV@04N7<EL7D)$\V?E4/WOGA2ZU*F@35B&(JD7!BJ$UOL#7&]V]^
MHV6,@FSLIE*985JHK@.IVIK&E"[6)Q[=4#ZG[^J]6Z1SRP)1%]D,C2/:9UH7
MU7_/!_^J`PH-<#3"8X1OSIH;X4]ST-D(3<<*EY\@_?>[.0TJ`LT@O$,WK)%F
MWJ2C03\C(7J&E=NJJA`#%(&AJH5I-Z<10UNLL8=OE.KJ?,QM)!Z9GC*)#"-C
M&/ZCN5+6""S$+`-K\:3DZ>2FAU+NO"/LAQXI?48#IL3&`FQR@$7(AXYNE&,0
M8\R)$!:$!%D9GMVH_B[;.]LJO#-*L`>!%7EROK_G)QF.]2JQL;?ME`BM0I7F
MMM`KQG&*PPCK4&TN'=>1`[K%*03.-JS)$_J%84%"G7"0X7\SEO@<8%3D`)!S
M`"=PP$S(&*!!8!@'@-8T#:A;!W+G'<.@A>,(:$+AL'+:BLJ;?7]?]"'P\<.^
M*H&^.41\&SL5@G*>H,*3N',[',;YQAP!12Z#KOZ>[X3Y"QMM'="2<\J'K&<D
M@L7A4^8IR#B?"DKA:4C7:!NL-\YA[(7`$2J"Y*-BGC\)U_BXZHWO[<NP-EIL
ME:+:BXP!YF^$GSK=79_I$P=PBL&/KH&3.$CK03!.:!A3ZLW@-+-=#0GJF/:$
M07H<PKL1&J;I.*#"KPE%"^-.`\4!R*E^<ULZ\D`3&3F.P(#%YW?4`8P"/S";
MF8F;\ZXCL//.C5U&K'9DP]/W`.7_'?%^5+:4JD?!I^T)?Z.3F<&W\P#\OV['
M?P%L)>\B8SNVV0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,N<&YG````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-3,`
M,3`T,3<S-C,P,3,`,#(U,#<P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!
M!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```$O4E$0518P]67?TC4=QC'#?9'_37V5T$%(V8$453[
M(\;^,`8+6221*R/KCZUNV&QH,U<<67G9E=&17EJM>5OFBIU9V=)$TZ`TH1\:
MD@:*165$1Y<<3)`*]^Q>3WS.N^Y[5W>CC?YX_'R_W_M\GN?]>3[/^_U\3!&1
ME'#3/^7N"NFY,R"CHZ.OON;^N$U*#QR1T(RAH4?R/#!A_$.4CX'!03E1>V9\
M1LWI>BDJ<;WZ\.+%2VEL;)!=1[W1/KIZ^N3.X'VY._18ZNH;(R=\GO:E.%T5
M<K:I57B."#HV-B93I\^0N0L62MH7Z3)[[J<Z1H4HV/2-6,*.9Z&'OKY>Z>[M
ME[[^NSI>;&N+#`%J?FBYU"ZD*LH#R6`')#80"$1.R%ICDZ^6K9:=SC*=P&XB
M)O"!K:7.FJ.V*#U#:NOJQC%\W]HNV(W.26++R0G]&(&AY_HG$G>;R9KE1PZ4
M@QVX=U\>/O9I[AI:+BN\S)798K<[Q._W6U<4$\XWM\JESFM2Y3TKI\\WZWOV
M^ESQ^7SQC_+WDUZQ%^^5\L,>'4GK?O<O8M)\K+HZO@-2O-:6IPL<^PXJ7"J9
ML\$AMO"S-(GIH/;4!=E=?C"T_]].SI&_1U(DT^'4TZ<:8B(X45TOA16'Y)E_
M6*JJCBOMUF0OEBV_;A8*T6KQNSO&_]\!W.KLOJT*01&A$B25VN"W\'J(6LQ9
M<PJH&PZH1(A:4/B35B)'3&'%=$`107<6=USK4@1$Q0%R&7<+R!.:2`1JG[I@
M,4;T-^:@\FB5EC$+/#5>Y0%\L&W<JM#?Z(!Z1STI7Q95!@N*$7N]A"T=P`.<
MY&]QZ&*Z`H0R9"(/,1V0."8QF<4X^W9#@9**$51HF='3*`<P;]K',U7TTI<N
M5ZU'"!%$F@$C#OC-T@%]QU;YLXHR^DLBGPY]((O2IBM#Z5J0*N86W.X:.=[4
MK(V+!O:@?Z)D9<T7M^LC\3WQJ^K&36+NGRTR,O*7U@"+D&AHG;%VB:*Z$BSC
MM^("T=N:4J6K^Z:\'W3^SP$,#P>4[;1AY`'"4EL8>>[HN*K?2"$20G7`T7\%
M`/V!FP1$6I`:-,H8DD,PHU]H&7,P^`S'][M<"I)"20@`$N3<X]+=F2`X!@B!
M",@[N\8(!JER\X(L=)1(::E3^R'%!0\2!H",&6)1U@0SK1XC`T8[V2UMGS7A
MEZ"D:P`GR``-F2,@(#K#,P%YYYGNCVBAA%P/`6#N'DD#(/5&?Q`T=)I`!.$=
M(VAIV9'0[0'9)?U(K]4])B$`I!+G&(X)2!````1`=!SN0\BW46)4F(L4F7C]
MO!,"@`--9S`X#I%T9$[/.7@D?#=W)L`Q,@<PC/Q.]@"8$`!2C^03G%12`^S.
M[!#C&ZGFV5S:J'J",P(,`P`^&&-I@24JQ)LC6'?L#TG?5*B`\GZPZWO&=SE*
M+X*MVK9:A3]SQ13YNJA8+X$4(&MI#LR%_QZ/1P7*"D1,M4-TX#E,X*PWG&G0
M=H63XATK]=995_NA7B+S-TY6_G.Q;&EJE\W><WJ92*H(D5EZ(@%!;1S2;%&R
M(OL\#:Z]LJQ$FRX90'#"YR;-`G8!Q\,=\&^/8WNJ!N;.S9D:K3_5?%&[_3MO
M1E"J]_:MMQ:8]Z8=_P.<GIE^IU\DH@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M,S`N<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S`R-0`Q,#0Q-S,V,S`Q,P`P,C4Q-#0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```6G241!5%B%
MG9=?;!15%,:WAI`H"1$Q-N'9%[3*FT]B8DR,"<J+45.C/DC4Q!@U:DQ(3!\T
M6-((*HJT)6I1,"&LI;;1MC:R%G7%EE+H4MLNM!1LV=VR"[5U2>JX'._O#'>8
MV5GH;A].[\[,O>?O=[YS&Q&1"#(_-R>L^M!1MU*0-U]<)Y'\;+\,#Y^4O?L/
M26+TK+L]?GB/M&RY6R5B=5C1/]N?O5G/ZXMLYPII[?A=TIF,C$].FVU7YN6M
MVC6R]8V::V8],1]?>?DY.7.J0S\6"@7W0_YBEQ3V1229/"5_)L_)I=E+\O'.
M5L%YW7"DNU;&=ZV2Z(>/2.-[#\OWW[PKS;L^D):6+\-N8@(-`;=O)-X/HO]W
M=+U(84H6%A:"&N;B:S4M?^^NDI[O]@BQ!S:,M"R70F>5Y'(Y30H1>)D:CCTD
M6UZX3?H'DQH6V6+CU/1Y:6BH1XTCW=''-<1/ZS=IF*QU;V_4,JF)WKTU\E_B
M'DFWKY.%'V^7W,F-GJ->%!1#\EURW3!+2CXJC8V-H4,E%5`OG*:@N$.U2<<S
M&ZHU?QJU,R27L_ND[IW-Q95P-"#)?Z09H?#IKV_2XI,1A.QPD*SYBW'-`P/>
M$ZWWR;'WEVE1)J<R"N+?^L8D]FM".KKZ-=56&4`)YL!H10')NI#-ZN;]WQY6
M11SB'<\4$66??]6MV`TDQ+FP6:AZ8IL;QI6H*_P&KK/1*@&ZA!Q*8B8UXL5%
M'<=.-&@RGW_B3LT-A><@7=+6=K!,.)N*V%@7+6,I\3?.DA3$?GAU"0I,-31&
MLTZTK9+<S"_ZVQ\*>0@I(+L`![3%FJKEG\2#FG4:Q8DO$_7&Y(255@M[8#ZR
M$0A#7`#J[([ERC!48*9WO7XO3JI70@3,PZO4GOZ%P_P@TGXP)0UQ"I+^N5HM
M<[A]VUUZ*#.3E9[8H"H:2$PJ"NOK/Y-#/W6'%<R,O:8NX\'@D4[O$+!E!;IX
M<SZ5T:8:&#CJ]L)(WTN"=4BK^?75V@,<9J4/L(HG8`*AN>`NR,VC)-L'\:Y/
MO(-T(%;93#@V!-XA**)J>GCJ]`XYT+1)NW'TBYH``?+>/L/W2H@FA%`[`P["
M()'^3K3=""9@)W!2$HF4D'H3"@C$$ZK!VK?[5KD\4:LX4-H+*W"DM]<M3<')
MN*UKZLT!.!WE]OOD>&RQZ>1X&U)_W.O!%AJKN!O/)%L#J*M8P0W%="AA^5&Y
M%"ESHYL6>Z&QN`,V0,(?)6A@KY\R*G#`T:8F*G^A*"P\37'A:FWHOCMT\,'9
M=),6W3A%T<&KG_@Y3^N5JF-)KX`<[8E!Z`C%#(C^YEODL?M7*];!-+\1G(`#
MF$B\9WAR!J?1P_BRO5]F"1R]2-!83&B,</WC!D1303KT"!T*\5CF8J:2/3B5
MQH-;"$)9W9>1ZSC@2';Z@'H/BV.`"4]DMK-QAO<8M5<&>`>>&1J>4/Z![2`S
M>`>!.B@+$X/2%&>B)+JI)Q.@V#@18X!H$?_UP][P>`=3<K^VE,PSMRR+K<!,
MR\^?4V#A(:B&AD@?ER3&$F1(Q(GC<56.,<0:AEGM=87AP>3!&0SY+U8X3HEP
MG+TXQ+=`]$20^JM'44VJ`2!1V&BH-2L*$101'091;`UBC,@I"6=QD',X;<\`
M3,H6<(!V8;*!7!`/F*83[3HW,,@!HK1*$=[9Z#".(_[,(!CD'6=QEA7^8&\`
MA&1`^_\J#KC_@V10#Q;L6`$3K%;H%EVO[J%T7$T`,:"FQ`P!`(BSB[>AF5E,
M$O!`%E`$*!E-W#QQB):TPC/O^<X_"A"4WH6:7`Z`W,IF0J[PM`US3[TU]R4<
M@HA0R-6&2Q?_C1`Y8,5!OEMF9,)SADM[:O!1;47_C;;R66!*PO]JJ@2'S#-,
M1Y1//_6`'#]VT"V;,>KM*]+!O"@U'Y8\Q3"6'GI2P53.+;K,$E0F1%4,JDKE
M?_!K,%,X$CKY`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,Q+G!N
M9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(V-C$`,3`T,3<S-C,P,3,`,#(U,34R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58
M=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%0TE$0518P]67[4];
M=13']Q<:WQA?:+)7OE%?+)K%:$QFW+)I1F)<AH*ZS6G9&`XVVC';TL(HT"'E
MJ;!>Z`,/`[LG"'%J<'-T9[_/^=U[:<MM`8T:7QP*M_=WSO=\?^=\S^&0B!RJ
M-OVQOMHOH_'SLOTX;9\69OID[M9WXDS?M`^>K"=E.MHN\L="[7G?QW(Q)<YD
MK]@'6UD9[#PELR,=(L\>V=>^^>AU*9<&Q#_BVY.B<$*>KDF-3[X`RHH34W,F
M>F0,%)7?W9/F1%_KN])Y\K!TGWY#,<]GXR+/G];!-"<`PA>U(9K8SA_;CRW`
MK5R`!P/R;O&6+.4'I92]*=G;/0K0?Z&\."2EN:@LY6(R/]XM^:E>V5B\YKU0
MD<E4AQ*3Z#@NZ9[/92)Q7N)73NQXN)-H5?9)<>1JBZR5AN3/S505DP8@]%X[
M>T0>+*4T!)[KTC0/GFV(;&]*<)J!5O$][<V3=\!0LO6P7U:7AX6Z6)Q/ROW5
M,;E7C,KSWS)-$)@\.,B!NX4!*:^,:`'<'@@I(Z/A%LG/QF0XTFXOHS;'BCZ$
MG;PI7#XIPO"Y]Y52N'?&NF0F?44F1W]09\I'#0+C(!W^0L8CK5*<CLBCM6%Q
M1B_+M\=>E<AG;TGBXC%%!XKB9,A/9<>!J0]R;/_@%0D=?TV->\/93YV?*`+*
M9"47"2CX^I(EG6Q(QJ^>U,K(I]OLQ>O!RD&N<6_[IQT<N)`LF9HK=ZT-F-7B
MLJSO=E9[V.W:^TLQOPJI"2KQUW+4.FI(HF$?.:0"O<-8+M.KS4P1Y2>Z=SG9
MR=4H)9)`&2,/1!T,GU&-[#KSIC@S/ZJ\JA)4]8.?-Y)+1(KEYT)2EN?Z9&TA
MH9\4$8[05\J;8+4.C$=4';@/2E:8+IXZ;.L_>4$/(CO8C=`)2VQ-,YG&X"6:
M!NDE5]2%W^D!$-%`I,'HV.W`L$_IHE=`QD`2^^JH]D3_N0\U`!I!>]MVKN.`
M&^!%VM@[B-[3B2""`\BEG8.;R3P$)@."_.E*AL3BU'49_OYCY24_F]1`#6:#
ME3.NK*OE;76`-I`_Z2`T*)8G)(TUT2"A==%R6AD]_V4E;/.F4O?53$"D6!AE
MF,Z9X*;Z[_7@7P10L;<''7#)950;E/&=WG!S#3J8H.'4U2=$GY[=7.W3UL.8
M'GPB-WRGPX\+YXQ>^D$%T0O,85.6U"T!Z"(41K<PTY*%.W$U3[;*RR/"'L+8
M8D%B^N@@:2*F>RAR5C/%,1*'U&'H)89.L*HA+FQ$=#!2@"`A>SRC:YFAR@H^
MJQHP&(`;G`-DC2.R5`!FNT(*R%(W+CK;K$&Z1IB_43X6+$`@&[`$",1K/'K6
M*D``B("1DM..9Y2PF^",X`0DF`8R"DGV.O3C7UNM0K-=8WIPCD\,#6>V6S%H
MN)ZY^YNA'GK)G%&$(_YFA2006:I<,67<;0,PGIRS10,*\V8`DTE73F0<8=D]
MTKS"VU24T\DVW9.F^B]H4/20HBK-]/H3BFG%=P!!@!%<Q!?])#A`O%V*$:`+
MF0+8:`3`K0%3M6@G.@K5.(0!5)WI1A#N&?/&!@`PWE4`D3:MEX?W,EI'`*"@
M=92ZZWMC,7?K8'WALDX%;]&[WGI$C6WQR_=>UD_F%Z#8(F$)D'.I2WHM6J0F
M>-$9M(N`?__[V>U`:9B@CZ'XTW=>TAG'/P($]XR!"5-<%8PP>6"+X$[FAG8)
MXF2U(%B4FJN@*T:T)54,"((.73JM-!<R82U4NH'?80(6R%C;CL!U=_[79H$W
M'NEC_:>R:FWT+6?OF'<(NL^9\#<FF;?X5MO_<!R_`+R2^CNG?["7`````$E%
M3D2N0F""````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,S)X,S(O,S(N<&YG````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<T-``Q,#0Q
M-S,V,S`Q,P`P,C4Q-34`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB
M````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V52
M96%D>7')93P```5V241!5%C#M9=-;%15%,=?*:V(42'12$*C"7XL6!%#="$+
M7;!18T+<Z%823-Q@T,1HXDHD!%'C`JP"30S8-FB;EM9IA;;HT`\[:8#:BNV4
M*"W8CU&IM75J6J?']SOWW=?[G`\&&A>W[9NY[]QS_^?__Y]33T0\ULS,C/!;
M'R3NR>RQ$I&$9[[1A_$-TKKO`;.]K_.`/OS5N]I\X"[]\?RVN^3@*QM-T$O-
M]VDP`G>??,QL&ZZY7;JJ[G&.M6MI6G@C.=RK7V8RF2#)/ZX*<:7-,^%BGO1\
M?+?,S<V:#:WUNZ3ZG<WZ!6=)HR==1Q^6R<GQ[#0YPEX[.P?)<R]65_P+^7,Z
M(9*Y*NET.AKA0E^[YI`\4"HUN\OEV^.;HQL&ZM>)U'DA(%+KA9N\CL879>ID
MJ;E!LL0L?W/JU&II/WW"A#G7\)0LG?`,#OY*599+3]TCRTARM<S8#AFJWBJ_
MMSXAX\G=LK"P$(4:4`I>,]_J:'I9BL*)NI"K+,W*].1'6FW*/].P2M-+M9>)
M_-.O56BI>2Z[$LJ`^4^52&??+C.PQ9SE0W?XU0KI[W@Z4HPP`%7B1(JA+R0"
M6'^^360@P-\/"E`Y02(J`:@D;-(7!H*5"$I0:P(LS>W/3:;YN5[=6/W6@Z9N
M=<&J-;6CX-^U[?2W+F8'^.7:6'BO2]^?DA_/[Y79B3<T$TXTA3<OGHD=*I[.
M3?7O%E?&7,L5SBT%N!&)\@;XYLPG6NN+]?=+:B(NN(5[%=PB*T#SEZ\;._'9
MAO[2`]L5=737W;#5H.^S-!Y[328GKN4&D1>QFY>>W2A5N\K5%:]\N$K>?&&#
M3)W=)A@:!V5=`:7].O6#<O[)+>NU[DHF2V.?"S"4X-#=LC"2`<Y0N6>-(9#U
MMX3#0C\@ECS54B:]YXYD!X#?I*[,:PLHC`Z2):&;PL;!AL>-N]D`(`Y(>)#:
M;YVC`[\K:)`@"S!9;/+4O\EX^OKU93"@J_:$6F_9PZV8XB:#9.5:&>W>KB6.
M7.'RR*":">F%7M`6O!A?]@/\KN?SBD@EG#(NRM?'MN@IB7UK32:!&@%VZ,A#
MQGY]GN1D(EF@.*Z"G:%[4#]?]:B6+SVR0ZW,M;-(@-Z>9K&9N($Z&Y^1L9&#
M8>DX"/`*:L&J$-KB$_P].CIR\[:.-ES6W5)?*+1HF:R5Q"AZ([C1>UQ+@#J0
MV+TEGP/AC6Z>-P&L@EM%W7!1\&F*.SRP7PN,]'ZJOT.U.=2W4S];F#NN+&%F
M<8V?9)@A<M4Q9U:X"S>[TKY>@]$<<)J6]^]5P\">T#W29?',@/+5>W=J0JB-
MA`8O?*:MCC@D<!,E6%3!H'<\@EZ)S?%;W<H1F=OZ^`XE']ZS206)FD\?VF1<
MW4$D;P)0'ID#-9+G96ZJS=H>&O/".2FTBGCP'`M\V-^+&R!BC)QQ@LN`9O_%
M3BF,@&]4P`>,0$MG"`W>'NH:'79KIX>$DTB0!)>@+<VF]D9,,$P`9E,?1(]K
M*-'\UL.BOCJLVYN[AV/3V+6U;)N$1:/1V#=VQH0&86FR*(=N#=$C=LYB,J%>
ML!IC!7YZ8@3ZA'-S#K9-QTT@:(,T(#P5!(A);'?$SBH!&L:]8"YLAM64(9RS
M8O\I@[M<'C@=P*+)5/#W_&^%94@Y5/_4RF_>\`#IT>AT[+1$=!N^78W+:@!Z
M#N?_%>1++(8&".B.)`6=D`$PW5FJM8-(L!E64U/(!;P<Q.)O9,>A-$U@UPG$
M1P4UY6LD.1,``>2";+03^<,4GC`]^8$.7+0X';J".8G;DR"?M1^MD+'8&FU_
MO`/D=N;0:6\EO0#6ZECLCXE:(O\`N`)*.)Y^YB?+0>[X[-IQKOZPHFY(DT=6
MQ4S1_TL[1E+Y_O\K=OT+\`K`,@5>Q@H`````245.1*Y"8((`````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,RYP
M;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-C4P`#$P-#$W,S8S,#$S`#`R-3$U,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%
M6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!3I)1$%46,/5E]MO
M&U40QOL?PA.\('A#0KQ4((&0*E4JY58J)$HCTJ(&"&YPZ=6Y-78<)PV.F]I*
M7#O9Q':<JYM>HX@(%%H:=SB_.;L;K[-V$A`@'B:[WMTS\\V<;[XY.2(B1QI-
M_VRL)223Z)*=K8Q]6BD,2G&L6YR[-^V#IT]&)#]T3N3W4G"][V-Y84SFIF)B
M'VP7)!7]1(KIBR+/']O/OCO^BJQ74^(O\>UI55@ASVH2\,D+H*S,)=3FLU=E
M,FY0U']S5YH5`QWO2O2CU^7RJ3<5<ZD8%WGQK`FF60$07@1#M+'='SM;%N"V
M$^+!@%RMWI*E\JB"O7O[J@+T/UA?O"75F;@L.W'-@"IM+%[W/JC+U/A%+4PR
M<D(RU[Z47+)+$M&3NQYFDQU:_=@7;\G$E=.R:FK]Q^9X0R4-P'/'7I7K9X_*
MPZ5Q*4\;#,9S4YKFP?,-D9U-"4\SU.J^I_WKY"TP)=E^-"RUY;3`B\7YE#Q8
MFY3["T/RXM=<&P0F#Q:R8+62DGLK::WI[51$*S(1.ZW[F^X[;S<CF&-='U+O
M^?R`7B%A[X4/M*34WIF\)(7,)9F:N*S.M!X!!,8!WK-]9Z4R'9/'-5/-3(]`
M7LH__/UQ10>*A:F(G\JN`\,/<F0[NC]\30UJ5@VB.]%/%0%L6)GK"R%\,V4-
MFEHA(MDK'RLSRIE.N_&ZL'Z8;=S?_FD'AR:2+:;FREYK`Q:47+;J>YT%%[M=
M^V`IKBRD06E4F+BU/F0=M2RBJ3YR"`,]"B-!,]E>W3Y(I%W6Y&0W5Z.41&0Q
M_0J11GO/:/?_=.9M92CRJDK0T`]^WD@N4>'_O8JY+PQ(K934*R3"$?H*O0D6
M=&`\HNI.[H;V`8NZ/WM#%^9'NG0ALH/U1T[:P@::R30&']$TY$VNJ`OW]`"(
M:"!28'3L=6"J#W71J^790;6'U5&)GW]/Y7KXPC&9&>]1C:"];3LWU8`=X$/:
MF(4T$WI/)U9RUZ24BVEQ57-#F\D\!"81OS7V]?LOZY!8-*W]\P\GM"O+Q1$-
MU&(V6#ECRVACVCI[LT/S)YUR?E`5RQ.2UIIHD-"Z:#GB@I[_LM)K\X:I!VHF
M($(61AFF<R:\J?Y[/?@7`=3M[E$.:LEF-!HEXYWN<'L-.IR@X=35)T2?GMU<
M&]#6H^$Q[I$;WNGP8\-9HYM^6$'T`K/8T!+>$H`N0M=0&UJRXB35$!`,&?/.
M(?-%<YJ:C=E!TD9,]U'D@F9*8"8U@3$"8>@$1S7$A>ZD@Y$"!`GIXQE#F!FJ
M5<%G0P.&`W"#LT#5S62Z,)M0"?"N9(DAFPQPP/$;Y?..$$@G`QP0B!<-K0H0
M`B)DI#C:\8P2@N",HQWW!$,Q44BR!T`V\8T^\XX?WA&$=5P!@88SVZT8M#R>
MN><W4WK*2\;L)X[XS1&2(&2)7&$$0_L!X:2C^AXIYS?FS0`FDQXYD7&$9>](
M\XBWJ2CS(YURIZ]3IH?MP0H]1.(15LA%8*85*@T0!!C!17PIMP(R7("<$)(1
MD.G_R@6PT0J`RP'#6K23(Q&E1D^I`,%UNID@D`WSYHUG?(L!'KX\NI]30@(`
M0NLH=8_OK<7<Y<&3TH^:G7?0N]%Q5(W3(J.&*_,+4)1?Y[@!R>!C6S`F"%70
M@X"__P<YVX'25((^!L2I=UX*S#G/&)ADS%91$28/U6+VS>7ZE:2(D]6"<%%J
MKX*N&-&6L!@`!!WK^5S+S)2&J`3DGDI0!3+6MB-PTY[_M5G@C4?Z6/^I;#@V
M^N;8/>8;@AYP)OR-2>8=?!OM?SB._P2#Z?J/-<BB#0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S,T+G!N9P``````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W-3``,3`T
M,3<S-C,P,3,`,#(U,34T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*
M8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E
M4F5A9'EQR64\```%>DE$0518P[6736Q4513'QX4?+(PA,>I2%KIQP<:/C<N*
MQHVR48R)2XNX(Y@H*T43#`%###8@")$HV&AI0TFGM68B#.T$G,DPE+9,RP"=
MTND4+'4RC\ZDZ?1X?^?UOGF/F6G'$A=G/MZ[[]YS_N=__N>\D(B$L$*A('R[
M?Z(;)1=^1_C6.^/]VV3VY@X9.-GJ+K\8W2M_[%LOD@RY%_RF'SP_>'R+NVGZ
MS(N2'_E,"O&M,M#YDKLL_>-C\M?A)ZK'>K94E-'P,S*63NC-2J7BWIBZ=56R
MD1U2&GU7G.PGDA]KE\3Y8Y*?SKD+>CL_EM2!IT1Z0E*)FDOM(8G]]&QU@=\X
MPH9=ZX,TB`N+17^5?V['12I9F9^?#^Z02I[5P`$`&PBW"A'H`GYP`2!*XQ^*
M<^-+&4^<%/#4,"-=[\M(]YLR%?M4$;\]TJJ_03#2?\P]YUQ7BX:F(9I0"7FP
MX_DJDH2VE-TLX[^\+'/A5Q7[A86%(-2`LF*8C0R4F\()=-57D]"YF?T2/?JT
M1']^17(=#ZM[T[\_*K*8TBSTGG@[B"-P@.6-3*=$NW>ZB*3WRKW<:07_[MU9
MR5V/2NIBM]P<Z9>9F0D)L+A<+LOTY'E]&-8X8SN5-:6ICSQCPXGX$671V-#W
MXCC%^_AH4HS+P.VQ*NF:A9][0R<VRI*SISZ92LX%79C8L][=R&>7OWE2\8`5
M!HS:#28G)SR2#5_NE:NIW1H&IW.BFWCWP4A?6_-T/G-J5W-IK&?^PEG3!JN1
MJ.$&&J/)RE#7AN4BG!5_*+;6`AMPFLJ)8=N5CL>E/+Q)44<<$"1%W["4;W]=
M!$[F1+APK?TMK[JMP4[J%D]J/""%G`[#8.*=Q"XI9`ZJ^X6YC'Y#8:@,8Z&V
M)QF6RG_V?2&QW[;+G7-;I7SI/4\$,3;S:#QX0.*Q;H\S"@CI@CCIWNUZ.K7@
MKP/^YZ]\IP^C1WCA>8#N`!(:=.W4!UX(Z)/5**M3W,M'7M?LH&6$X@$(70>^
M7E?5KF1M,5$/$X,MFN(`B)G,J(H)7MAJ]"JRIUJ)Z!UI]1/,E\9%Z?OV.;G>
M]HC<^^&A0"7R/W7X!>4%/*G+1+S0BBM^KG*&PK(A#]+,R`I2YI>SP`:DQGK"
M1F#"1A<,>>`'*;0'`=Z*M6"K$(F#9/;!_UR-L-,VB#65\VI&R\0>9(^F%X*;
M57(K"5`'$ONCM)6Q6N0-'4`JB"JHAHN"3I-<2HX$4QW(#@UO-+Y-KRT4CRA+
MJ!*_\.,,?:]>'NMZA1-$QN:0'D&@NS*?46V9_>N4V];XS\3`?9[1:C-TAGWL
MP_"``TT@L*@B`=1(&(>C@4P_",WPV:]4E1C3Z-2("NNL<0W9HR0PA`?Z<YT4
MHF!^+0TXP`T@0G"!$.6F#%3AC$0R82&35BJ9MNS$Y4RWZ1B!X91UA*A)G?TF
MM?SV<R3@`!<1\'SVD$9[*;Q;)10I9;2PIH<N:[7*+;^-Y-K[K`<I$*`),`Z"
M&GNC_9SER3%PLXB&0-28A9O#%7*S(4T!(UIKD`[C=_'6/F\-AX$`#I`*=<8,
M_:B25HXY`S0"<HZ1(R"$U;P=#!U_329/;U*C#T"N7/R-%8UU&,J-CM)?Z;/L
MR=X@T)"$P(+GM@)@O*?LOA9AS?8:[[^O==@.P)L)Y4K4Y=+?*Y<AZ=#Z-W,(
MT!(1I54S[/4TL.7[6I;F<+H)Y<M>O/!`P/M']88*Q7!$5/0P-N(-CDUQIIX.
MT&VY#_2,L+0PGJ>!<GC32J@CO*E_2E&]-<,4392Q'RAI<4ZR1?,,O$2.@PQB
MW"-UO*7P#)`3""GU3[1KZ@6PUAT99]V9PAP`N8@2MNLUXRQ#3KW#*/%Z_>&!
MNB$J1W3-3-'_2SNF;!N]_S5K_P*:/E,\&85R_`````!)14Y$KD)@@@``````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S4N
M<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C0T-0`Q,#0Q-S,V,S`Q,P`P,C4Q-38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET
M15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```2W241!5%C#U9=O
M:-5E%,<7],+>]+("$X*R7HB^L!<2O5@1Q408PL196A"ZFERRV9S&6#3GG%MZ
MT6VNENVF;2E=-]<<=\Q[=1)M#OPSR]I"HPFVJ"[=UJ#!4!G?_!QYMGN]OWOU
MWK#PQ=GS_)[[/.><YYSS_9YG.9)RXL7^U#?LU84??M34U-3-5=\[%:K;W:R9
M'6-CO^CJ7_?-+B3IN#AZ10</=\[N:#O2I?>V^V\N7+MV73T](6W;%TS6<>[;
M$7%\=.PWM7>%$C<\F_NB=OB;="04$?,$H]/3TYH[[W$M6KQ$S[^0IP6+GK8Q
MR43IQM?EZ78ZF9F,C`QK:/BB1BZ-VGBBKR_1!%[S0^1DOPA5D@:"T7WLN$JV
M5&EB8B)Q0^&:(BU=_HHJ:_:(R'.;A`TL<+7Y3RTTR<W+U^&.CED??"?ZA9P=
M?$!%Q<4S/R;X<.',$TI[S6S%<Y&$NL3^_&O48A>*?&7N%:Q<K?+R*L5B,>^*
M8@/A.CEX1BW!+RWY''ZM:(.BT6CZ5'Y^**CRK;6J_RA@(V'=U?B)7)CW'VA-
MKX`08XD#VSYH-'>IY.(-FTTALN297*54T-D>UO;Z1KO_3Z.7M?_00D-/066U
M99]J2.G!P<^Z5+;W0_T9&U<@$+"#:U:_I"V?;A*%Z'7X[J7Q_U<`MDZ=_\X*
M"($E*"IJ@]_BZR'I,+DF"[";JT3FI66;K1)),8664@%%!*JQ/'!ZR$:LH@"Z
M3'L%Z`E.I'218$>/'4:P?ML8-.UKL3+F0*`M:#@`#U0BKM]6`?4.>U*^ZWSO
MJJFEU4;DUA+V5``.4`)Q<9BN`*`<F(A#2@7P))O8S&&4K5U?:J!BQ"NXS/%I
MD@*0]^AC3QKIH0BNAP@A1)H!(PKREBWW5D#?*6KZV$B9/'=UAO7'V/UZ+G>>
M(11T`JJ45VAH:%-K;]@:%PWLRJ4Y*BQ<K)VU#RGZ>\Q8-VT0?=T134[^;=8Y
M!$6W-+<I_]5EYM77@Z?O#,Y8[^N=KZ'SYW1OP/D_=V!\?,+0#F`'!DX98)E3
M7\39K1%",D]U@-%_Y0#\`S;A(]X`T`L<Y03*@7H0V,/1$0*>P?@NO]^<I%`R
M<@`*JMGAM]LY`RC&$4>:?'-K!&.`JN3M,E555:NNKL;Z(<4%#C)V`!H[VA,V
MAD(1QERK1QQ;8YS;TO8Y$_\(RKH&4`(-T)!)`0;A&>88Y)LYW1_2@@EY'N*`
M>WMD[0"A=_P#H<'3&,((WP@$YXSSLH-V"3_4Z_6.R<@!0EE;WVR"8@QB!`<P
MBD-T'-Y#T+=C8ECXY74^B\2M^<[(`4*/$HRC$$J'YBS/-U+".@XQQSE&]N`,
M([\3/1S,R`%"#^5CG%#B"+=S-T18(]3,W:.-MHEQ1AQ#T(,.'$G%!9Y>0=ZD
M8.V!+Y2WL<P4`2N^\]]XT^"%L545-YZ<@0=5L.(1>P`B%"!G:0[L!?^\]2`H
M+R=2LAVD`\Y!`J_.]9TA:U<HV?K^2DU/YNA8]QQ[1):\];#AGX=EI+=?FX)'
M[3&151'"8O1$#.*U4TBSA<DJ*Q:8<7IEPYYJ:[I$`,*)WYLU"K@%&(]7P+\]
MSC`A)Z>.Z]O#QVV\Z\T(2`U__\T=$\P]TX[_`8&KF9@2S6#L`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\S-BYP;F<`````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S,V`#$P
M-#$W,S8S,#$S`#`R-3$V,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]
M2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G
M95)E861Y<<EE/```!7!)1$%46,.UETMHG%44Q[\\:C9B2T$1P>)&J]"MCX5N
MM+BH8G7AVHU@!`N"8"C=J+38"$T0:4I(I8C&%!NCC0.IF6([:1Z,#2%MF=`D
M!-HF)A-J,\:,G8%Q<KR_<^=.[F2^&<<4%V>^^SWNN>?Q/_]S)A"1`%E=716N
M>B/10')?6-$WZ:XZ6;N^7?H_V64_'Q_^3&\RE^OM`U_T)]<92/)P@U4ZU?^@
M2#R0Z]U-,OK=,_8S;L9/;O>.=;*>$G;,3,?U93Z?LR]2*W,R>J11)!;('^V-
MNL;&=#IM/QCH:Y;3'^\1B03ZD?0&,G'R*4DF%\O-Y`CG=KD-4L$O9&3HC/R9
M^E4D/R^93*94P\3X>9D]OD,(`,8M?+I3<D/M&V[._="D!A(=O#BROU%^/K';
M?H`'!$8_B)GP)0+)G@F$3;]$3]ESAL[N$^DVRZ@5CAO[_HF-(W!M_>8;,M/S
MM*R<>UX69S\H&EKT@J!4=;.28&--<2(O:FL^+:GDYYKM:]\\*:E(@^2G]EH'
M;T<T"^=Z]I=G`@3D[WXILYU-UF$3E7=??D!RS8'</E`G%U^ID[Y7Z_7^Z)M[
MRGTD2P`.`"LH#`B/O=4@F<%`I:.Y7N\!R_3XVP+42F-@4CSRXW/V(X<JHX2\
MZ#5J44:DU].MX6#*I./ZX:F6QZT;O07IMKE;/ETOPP/-Q=-+%/RV<*OHU]35
M?IE+M,K:4HM:PHDDWFV,#9ZH'<X#/[75EL8P\0MG2PKP=TL*U$>3E<F^7;*\
M."2PA>]*:!"!K-+)WU>TE/Z:?$FC#AI)KUJ32N@UN;00'D2J"@@GCC9*]G"=
MID^KW,B=CL?TV=I'.Z3,!2H-[LK.OJ:;R7VVI5[.'[I/JQ\(`V>NEPTB9V82
MY19@6N^'C<7"ASJ@$)")$K@&A4`Z?JFK7`$D0/$H\F(6_Q>Z'E(%K@90T/9^
MDV4WIP#>(4B4;8D"0_YT!<IX87";\M;:5X$&EE@1]-3*RD8P@&OK.X]N<)<K
MI$2AL$R!73NV4^9']VJ*2UP@*)#)U-EGY=L#VZP5T<+&J-V,8OANK.<1\5DJ
M\,$!UT(H^+JY&FD6F`].0I&(%50<KA`\ZIY&R$:P08JA,I_.2A3$QR+%IN84
ML1'7*&V7.@XB>%5KP54AV(`G6,_?FO[OM*Y$ZQ7.EOI"-:%E(O>BH^8/B1N]
MQ\\Z`$9\+UD3PG_SO*(!4`5>^6R(,GB:Y))0$DSI03M4"6V&9_0U4*(X-0U2
MI;"?&2(LCZ%6P2YXAG*4T1QH_M'V^W5"@G&T_Q7HBC7D00U0TC<NO"@R\KK<
MB!S27LD[UC6G0,-G"@8(,ZMPX-)QRU3P`50'K?',K;G2M5TG1]P][Y8/[BY)
M8:@!0!Z/"34E3T$6O>TM4(*A!D@9BH0V4,Z:*V2FSPQQ\ZSKO8>+ZZ\[]JGN
M*Y/#4CT"AJC()V%$@2-X=SC\1!2@6*C5K;ER$"DB:CR#W]T:S/@D6#2`L``0
MBIZ0XSW4B^"1AMX94!A7H.C.@PT:)=88X@")^%CAGF_11Y-U_1&@E]"Y&_'H
MPJ`:8L4`'=']",0W4;TO<8^]S1Z,AU/A4W2BVQ^QRU(`^&`OD.L\P8C-&-!(
MQ#QC8IM:A]<!7#3Q.IOYO3H(B8#6O\D5-4WSP@@:74F+B520PL%XSN$(Y:NZ
M#`<`P,VC>D6&8CBZ>ZE!<TLZ[EQ\0172HD@+AQ`9A#73)^]IFLQ"^G_,1`6<
M5&HDH080`<H%1M,!"C8SG)!*MNDL0&DR=&&0_K\Q8<=`_@;PCM3!ENPAY#@"
M\/R)=DN]`-2J$C,F:CF9`\`*4;HZT6V?&6,9<L(F8L`7UA_NJ1O2Y/&NEBGZ
M?VG'>.7/N5N1?P`F#Y\BR6S/&@````!)14Y$KD)@@@``````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,W
M+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(S,C(`,3`T,3<S-C,P,3,`,#(U,34R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9
M=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$9$E$0518P]V7
M<6C491C'!_XA8?XC_>$_1@0J!(FAK<16V!!"&S34_E`H!C41$@J[9.YFSO.J
M3<=Q:,/FTC6WI6UI7:QY0VHF%S57RYW-Q=QP-1IU8+#58+#Q;9]'WGFWZ[Q=
MFP;]\>Q][]W[/N_S/L_S_3[/+TM25KS8G^'A85WN[E55U;&;JZ\5[5-E=9VF
M=B!_QN8E+B3HZ.D;4.7[M;=VO%?3H#=*_+<6PN&P$HXXN7'C#T7:.]1V,:*Q
ML;'$2]8\D:N#P2J=;0Z+>8*&T=%1+;E_J98N?TCY6[8J>\U36IV]-MG,O=[M
M&A\?5Y+9MY.$'^>_:!-RZ?O.Y%>TMD7T7;1'%[]NE]?K55=7--&&ZI,?V1-W
M%?F3;=CE\6K+UI?LF=L*7M&33S^3>,6*1QY3O"1M<'*]9[Y2OH+X3??!C/R0
MD9^<U#>>54=7M_I^&3(A/\@QUNH;0PH$@LG!=O)R8:&:/FE6YY6K.G6FQ0Z;
M^R8]E=8"T@EWOAVHU/ZW*E1<6F'S@AT>Y6UZ,;T"LHC-Q")P](0I*]Y_2#M>
MW6,9751:KNKCM:F3J:RL3#S!X_$8IC9L?%9Y&Q?8G/0X?.1=F[OWIW0BP"2F
MH5!(OP_,4\91N!+MU*S"..L\F!,%G9>CQ@X`$(R1"WU]O9J8F+@]I(>&AO1E
MI,,RCRP<^/4W=??V*]+199E()%"84@$)Q`$4?/O#CY:1*"2\/M\!BPQ12JG@
MTY;SJFEHM(/,4<08SX8IGQ"+Q2R%(3\H!)XY>KQ!15Z?^2*M`L@0!27^0]KY
M^C[Y#AZQD53.S5V?7L'N-]\QT(`'&!T!4&`"2:L@+_]YVPCF4<+-6`&X`-7Z
M#9M3,Q)D]\"#R_3PBI7&ZW`]Z(0`.<C_^<TE_ZA@<'#04$BX'/I`8OYSZP1*
MB3],-#T:*3,Q'+I7R+G/BS-'8S"PW0[7U6R:5/!!9@I:6PK5_M4]FBFDDQ9&
M1D9$0MTU./_G?'+7#*#>@U$8`@'DT9_ZK6XQ(O&%T/4*U#@8!"Q#5?_*@-J3
M=5-*$2YW%\-W"&LP$!>"1JM(DZ!A=-B`4#/ND0`/M1#%"%QY]5J_D2L\Z;P`
M<T$!4"$OIG-#IC-X1A[@,&T??2?NQXUP*RT#PH70):TL%R.\'@/F)`>H`'`1
M78)[':W&X:H3=C'K\';PV(=&NQ`@O(779FT`;J<=X1+X'2_0FC#W%/NMG70>
M@'6A<5B7$:]14&=E`$IX#<I1C&OQ`"%PA8:&%Z/XS8@',-K5#RI9?!LT8P/(
M>KX'7"G@5:Y0.3=C((;M]9?K0'G`#.+3!L%#C.Q#SZG339JQ`<`$]P,?:A/?
M']2I[.Q'K:SFY.1,K2]>O&A*^#_KB-N',"<G0$1&(<!UM!_P.K6.WC>^VEQH
M76B-(U7GXZ:;%8<SU()X%,TI%:/PLS,KI;^R%*Q8I9(]C]O\7/,VW5$JQGVG
MZPO$EP["Y=!J+';="C8,=T<-^/G::GUSX3[Y2E^P</ROJN'?,7>6M)5#!3,`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O,S@N<&YG````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q,P`Q
M,#0Q-S,V,S`Q,P`P,C4Q-3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$
M?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA
M9V5296%D>7')93P```1=241!5%C#Q9=;;,MQ%,>7>/"`2#QY$2)!(B$$0V(1
M)/.P$#/!XDZ,N#RX%+.2T;G,T-1=D8T9QMPJFZV$(167R5BQB8V-Q4(3DHTE
M2[8</D?^U:ZZMFP\G/Y__?U_OW,_WW/^42(2Y4OZ4U]?+\]>OA:[W?YS=U5R
MJAP\GBW>$]!73R?_#3\>%54U<O3$R5\G#F>>E76;MOW:<#J=XG?%H,^?OXCK
M48D4WW-)4U.3OY#18R9(ALTNE_.+A+4?A\;&1NG5NY_T&S!0IDY+E.C18V78
MB#&!:FXV+Y'FYF8)4+LM\OMSH]@E-VX5R^,GI8%6\/*)NUSNW7\D9K-9RLK<
M_CH<.W5>332EI`7JL,9DENESEJJ9LQ:ND+'C)_J+&#QTI/A2P`&#JBLZ2U`K
MB%]K'X3EAXC\9%!V[F4I*7LA5>_KE,@/<HR],Q<<8K7:`H-MT.*D),F[DB^E
MSRODW*4"O8S[EJ_:*"$U()UPYXZ]AR1U^VY)V9JAZT7+ULFDA#FA&9!%'"86
MUB-9R@PF2">C6=LS<X(G4WIZNF""R632FHJ-C95)<5UT37KL/W!0UX;]09U(
M81)3A\,AGVHZ2<11>.XN;?-2Q^=!NS`H?>96=*``J3%RH;*J2EI:6MHNZ;JZ
M.KGM*M',(PMK/GR4EZ_?B*ND3#.12,`P*`,2B`LP>/#TA68D#`FOQ9*FD2%*
M01E<O7Y3LG+.ZT76,.)96%04.A,]'H^F,.`'A(`SX&JRV:*^",D`,(0!M')M
MJE@R#NB3]/9%D:`,UF_>J47#!30@[\G_A)F+E$(RF!@W50N(FH<)A!84%XQX
M'Y0!8`>^#QH\1'&==71TM*K.1=Y3K9.G3/M]'M36UFH5$BZC^JC$^"GCA"HE
M_B!1ZV@$S<0B1U>!"@M2(J]&FW6)7CZ=E?"#P<G(&#BO)\G#N]TEW)(.V&AH
M:!`2ZI^5\W_'DW^F`/V>&@520`F*W/WJC?8MT(.UT0C+*ZN]LP(]#@2AEH&J
M/U+@5/9I%013".$(02AX![$'`B$P<?8\+1Z*AJ=1&P!JQ#,2Q</8!V,(:PT+
MP4G#"R`7$``48C&3&]0:P2/R`)<9^U``]^-&L)61`4(@@,4HRSR"\.F)\U2!
M=LD!.@!8M.]HI@I#"*,&_\%II@=0TW;LK!=V<3E>^VL%L)IQ!"$@*58FIZ;K
MFCF3<1*%\`"C2US\0D5=X!RBH?Z5`K@>:V`.Q$.XF!`8C6;UAC15BO\HA@=0
MFMX1/V.^=C+?,2AL!<AZO@>,5@`SHU$9;F8/B^E^:;NLJBB?-A`>XLDY^)S+
MS9.P%:!,4(#+]":^/_KT[:^]B6$O)B;&N]^S9P\O\9Y]",4Y!W&'G*`B(@H!
MKF/\`-?I=<R^OMWFCK.;#HYTG8MY/SL.=^@%OE74KE`,PVN7AHA\BQ+;GF&R
M:>,H71?FSPH[Z_](`=R7F[-`^-*!$`ZL>CS5VK#?OBWO6`7>50[7'FW9,E?#
M\5^:44?1=Q@UEHTW7)8S`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S
M.2YP;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-#8S`#$P-#$W,S8S,#$S`#`R-3$V,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!,5)1$%46,/M
ME\MOS%$4Q_L72"0V%A*)2,0""PNQ($$B&F)!/(J@\2AMDTG'8"BC1@GC$2;J
MT5!%-$T]HJ/H4]IIJZ,Z-9@6$UUX1,*F"4D737/T<R;W9WZFE2&(8''-Z?F=
M>^YY?L^1)B)IB4?_J:JNETL5E>+8NC/.]1X]*SY_L:S<Z(PS?,&P]/;VRJ9'
M+^WW+1U7`]5RYL(54<:D:3-E^MS%LF#Y!DE?M%S2-CM<LJXL(,'F%K&N)!X$
MDG1B3_FU2KG;T"(E93>DIZ='[<QU%\:E_%5U8H2RFSIEI=<GH5!(/G[ZE&SF
MD&:G+.`OOBC#"F!<\:4*=0^_;0+<)#I+UV:+YZ!?'C_MDINW:[_$X?"I4OT(
M$T$3N7"X,ZZFKC$H>8UA>?WFC3)Q-?/@B;B&W:T1&1@8D*RL+!4@1:2JIJ96
MOM_-'SE#,DG#B=,7I+TS(D^C4<V?I\`K*2G(<>[0I%?5-LG)\V72T!S2>MR8
MYU&:B/7U]4F2`JJ#@]"-._=D@],KUV[>TIA'GG1+46FY5L^.PF-"7@@SEEH*
MSH4>RX3)4[62EN7ODS'CQFM$%R]9HG16]+7^(@--WBP+2`.7<MJZQ.?SR2[_
M:<V;.W^WK"Z]+B5U08T%G4#I1B(1NPLH,`S\HXX3XQ*+Q:R_:89?G\8_1P%]
M3O%_MP)GOE?H(")/-0)J[S]\2*T2,W.W:T&A@`X'*JE*"H<:^*:":%>WUKVY
M;$J9HJ$Z430D\'%H'A"!,N42T)'MVJN_#SO""H8HX&"AK1+1NK7`IT)8P,O4
M?:C]H3Q__D)?!^0!9Q3@)J!M*<!T(L[KO(J_*,0-8![>[(49RH>F8^D+FPN9
M@<$.=.1IH-;7W%?,&CUFK*SQGY=IL^;IBPN]1]3TN>GI"E\V!30.S=0QV+X(
MQ=Z^T]316,[Z!PHHAD;6%D0N`H)TY)X[3>IWQO%B%08L#U4$;'12%FA9D)1.
MI&4OMW:(V^U6M*V-QA03H&]U1I5.4M#?WV\QC6_F\,WP$NF_J)W_+0-H->8_
MK4>[!5M#VK?T,3RS^OQT`VA5^I<^9]:Q##'G6"4`$/YN:6M7%'+D']"VI7&^
MKK@?,L#@(P]PF%"`+-[#-X!#),`/Y!F^@`\=#01@8,H&T(R`TN4K90*RLR;P
M$-ZBB-4`Y:P*'&B\YC$>Q\CHLY@B(T:9^Z0(?0!9XMBU/0[NX@7A)<>ZHPQ.
M!!XUBH%3/`09V5G@$1$>)%70'`Q&EY$A2NC%2,#1C"B;`8`<%["8Q[F((0P%
MO.0RA_"37QXE)>P_\(B<B09UP&$N8`AS$3[&8X#93FP&@'<8L.IVL^(]9T;.
M-OT=,7*43)F_5"$>&C[0;VB4\@T9^!SHB7/2+1E#`\I@[Y`&@.R@.E5L1@+>
MLFNM.')*7"Z7E#2&Q#'8>@`VW\@IZ2NL#NHL`K"I(;SDP&>OAH_<L$48?O5.
MYQ'6L2TRY+A$_C`$94P*'BDJ*M+I8#9(6A!#P`*60<-G3!D^>H;M`A['>Z8E
M!><)U.O@HY)1QCPOOUNGJRET92"@LX_*AN8NJRV&<7>+]X!BAN&SM29.K20#
M"%-NP7[K?Q<F)0Q24D)(48`W)G_F>!K:=(Z2DL1ONVI:+7[*B]G_8?2[SV=A
M5:K<*A;`+P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0N<&YG````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T,S(`
M,3`T,3<S-C,P,3,`,#(U,#8V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!
M!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```$K$E$0518P]67;4R-81C'L_G`)_.)S7RBS6:,OICY
MD-G(&+)&"&/*LK/0*F\)'4F-,RIY[1`)I8Y0:R>R4=H:A57>)AL9SASM;-H:
MEHO?U9XZQWG)R3`?KN[G><Y]7]?_ON[K_[_N0D0DQ-WT3T[N$7GX^+ET=W?W
M?C4EI4GVH>/2-Z.CXXU\=@WI_^#EXT7[2RDNM?7/*"ZOD+0,2^^'+U^^2E55
MI>P]6>+MH^E1FSQI?R7M'>_D<D6EYX09X;-EOR5?;-4WA&>/H#T]/3)F[#B9
M'#9-PF=%R,3)83IZA4A*7"L^80>ROH>VME9I:GTJ;<_:=;Q16^L9`M0DL.96
MG9`J+P\D@QV06)?+Y3DA>F6<S(M<+GLR#^L$=N,Q@0]8Z(1):C,C%DEI65D_
M!M/-.L'N-0R7N/CXOA\],#QJ'"\!MSE8\_F1`S4.]O5;A^:NLN:VPHM:&B/;
M4S/$Z73ZKB@F5-IORJV&1BF\>$7*K]OU?77L1G$X'(&/LOA\J:2F9TG.,:N.
MI/5@[BDQTEQX]FQ@!Z282"PP'\A3N%1RPJ:MZA";-CU<_#JP7;;+OIP\W3^\
M.'-ADGSK"I$H<Z:>/M7@%P'P4XX<E8_.3BDH*%+:K8R9(UM/)PN%>*K\RE\\
MQG_O`&XU-+=H`6&H!$5%;?";>SUX+>:L.07(:50BSTDI6[02.6(*RZ\#B@BZ
M$[F^L4E'HN(`N0RX!>0)320"M5]25J6+,:(/F(/\$P5:QBRP%I4H#^!#?$**
M0A_0`?6.>E*^L:9MDO^CH!BQGTO8IP-X,&_Q&DG<9M;%.(-0!IG(@U\')(Y)
M3&8QSM9M2%)2,8(*+3/TU,L!S$/?863$@DA]1N,10YH!(P[XS:<#^DY<_@D5
M9?2WPF:7#QU#96;X6&4H[(14?K>0EULDYZKMVKAH8*^>#9/HZ*F2:QDICO=.
M5=V`231=JY&NKD]:`RQ"HJ'UPE7S%=6='V7\2UP@>FUUJ#0UWY?_@\Y_'4!G
MITO93AM&'B`LM861Y_KZN_J-%'+R5`<<_2T`Z`_<)""7`^0%C3(,R4%Z,-0#
M+6,.!I_A^$&+14%2*$$!0((R]UMT=T8`'`/$$$W>V35&,$A%*S.;,R0[.U/[
M(<4%#X(&@(Q!+!2*LB:8T>HQ0ZT)SFYI^ZQQOP0-N@9P@@S0D#D".(;.\$Q`
M`/!,]T>T$"^NAP`P[AZ#!D#J#?U!T-!I`A&$=XR@63G'5>BXV2&[I!_I]76/
M"0H`J<0YAF,"$@0```$0'8>&@7PCXR@Q*KP\UJ29^/F\@P*``XS@.$32.0+.
MF2/A.X!X!APC<P##2!<C>]QX@@)`ZI%\@I-*:H`^8_0:C&^DFF?CTD9`@C,"
M#!8``!^,_K3`)RK$FR-85WA)YB:F*"`<\KYP?;S2BV#+=JY0X8]:,EJBTM+U
M$D@!LI;FP%SX;[5:5:!\@?"K=H@./(<)W#HWV*JT7>$D??=2O766E8[02^3F
MA%'*?RZ6-=5UDEQRU>]E<D``R"P]D8"@-AS2;%&RM!U3-+CVRL,9VG3)`(+C
M/G?0+&`7<-S=`?_VF'>%:F#NW)RIH?6(%.,?;T90JK7EP2\+S'_3CK\#8(F9
MDT9^-`L`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M-#`N<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C0U-P`Q,#0Q-S,V,S`Q,P`P,C4Q-34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```3!241!5%C#
M[9?=2Y-Q%,?]'[KLKB`B(J@;B5X@2RC$B\C*J+#"RI)2V,R2EJ5E2:TWRZ0R
M>G&YV!)M4TLLF(7K18-ERV9F8"^$0>!%70AUVN>,WU*W:H;=5!>_/7N>WWG.
M^9ZW[_D]22*2-'SISZ?/G^5J79-$'Y0=/2W![FZQ%A^.B)VNK!2[W2X.AV/D
M^]%77/5>69UCB>BX>*U>SM>X)3O?)OL.'9.D:=-G2/;F+>+Q>+];^=G2G^HK
M#G%Y6L1>=4G*CI^50+!'?/<>27YA<43J3*!73K9UR/;0._&V^/1_EO_)&$R,
MCP``\?EA1V?4Q:@`:`%',):NS957?7VRS;HK`I+H]+QXI9MLX.Z"M)4:2NY5
M0\;RY3(P\$&C[[O;+D^#0>E^_CRB@1A\^?)5BOU=NOI>OQ%KBU_&S\W?4C`X
M."@.ITL\-V\+M6'=O5\25D"R6WU^=;3>VZ+.FGHJ*JN0&<DI$J,@T!54(2R>
M.%<C+WI[]4HH.P-=&L[V!YTJ4WFA5I5GY>X4D$8UG3M?+<D9F3)O\3*9,'&2
MYF+JK-F:.*[)*6EZ3<_(4CE20_M$%5C=3?+VW7N9N6:#YHP:;KW3)JD%N]25
M.=E;==]9UQ#K`B\,KQ\2#FPL#!>V6"PR-#0D?SZ-?X$"<D\/TIRT&_E.6`%E
MZVRXI=U-$U-<M>X;6A_Q%(VXL1\_)?<[`EJ^6"?_T&J.=:^45U1+VLJ-VL\Q
M"L@M38/%2VZ/$B!<S*)DZ0^4@H92!J6ID2AL:I\F0@EU3Q_`GB"@5UC(F3[!
MI>\3(&P![30+5E=MR)7^_M=:C;S(/O!99I]>B2J`DI:45\CDJ=.T%Y@`W,^>
M.U][@.OTA>G:3"FE1V11:JH0KQ%!S#Q1I0&D*W&!%_$3^N2^N;E9JBIKM;EB
M@@@QTD`,AY+24JE[%H8>".A]*!2238]#VIE-@:?J5HP"!+#@<KFU98$/5QMK
M*"6@2ZH=\>N`J3FZ;0TWFF<H'BWWEW3COPD`NME=<E!KE((>S=WC#H!J@M]H
M2:8*C<%L8]&J<`!LP\BBE,<"Z*>;\`%]#T?`B1BGH:`Y",4\@^)X#I]`P/`$
M<W3BE%EZ1/@M`,9KZ`^&,TS'.99G+/Y#'Q`X3`=9`0!9%H<MHE906!0S3N,"
M(*^$TGB'IW#S99=7%>(IACFG$!GVE)_##(FG4"U4\S)\I4X``#@S69@R#`>.
MRC$`*"@,<0!"*4K(-0I0A+=F0!CNQPA\CV&HRM'0J*#0@1PUP3T`<(QG''5(
M#QPY`@"%@U<`01@07$D#SWF1W)J:P!MD^)H`(*#8(PW(,7!XA\&$UX!!%U?.
M53@8MP:<#X/*XLP6.)7Q@!)F"+GD#+;"VZHS9H^M1.\A:?9M-INV)X<W[O/R
M+++MC$/E^4^'0/H<Q>+6`(.-,S:?0YS5^.98[^O0G!&A@8^#4NJ\KIXR;@`+
M`/).QQQH:%-CYIQ'6C(/'I:R\O)?%R'*\1ST>.WOZ=?#/IYJ+83_LX]Q.@1C
M?!#A*0#8QSC[3)ZJFB:=@]1%0FW(4,W8423FD\2<5EA\GED?]VCQ4.U$BKXG
MY$3"R`*,2%VYVJB16[QNO19H0@!0^J,PF2/T\-S]BCDY1B4B_W\:?@.>\+\6
M=<U-'0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\T,2YP;F<`````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-3`P
M`#$P-#$W,S8S,#$S`#`R-3$T,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@``
M`01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/```!-))1$%46,/5E_M/DF$4Q_DG_3?\U?F+S2ZLU'EI
MHT69B9MN2+.TK(8:&<.\00B:2(E&6>2T4GH!G>O4Y^B#+W*935O%]OC`^S[/
MN7[/]QP=(N*P+_VSN;TC!P<'TMC8>/C4Z73*\/"PN-WNPP<_?AQ(R94R&?/Q
M=;G_:%I/.4*AD'1U79?.KIN22J6.A4Y/'YVPWU^(+TIBY:V4R7SZ[)4,C@3$
M-Q*4;UE+L-/*Y:6E]?KA*?1XO5Z]:7;T)A*)4A-QA'UK>[NZ'Q7]8N5R.6%U
M=W=+Q0-9*R?#CZ=D=&Q>W-V/CE6DTVF)KZ3%*NSK2ZSO]TW(3/C-<1Q<+I=<
MNGQ%7#?<<O=NKUR]VBY^O__X@'$MF4Q*?7V]9#(9&1T=+8TD?K.3R.;FYG(W
M46."9@Z?*@ZGCE,Q'-FL9+:^2?:[):OISQ*<65*/;]P:%'RH*B`<#FON(HMK
M\N+EHCQ\.BMW^IXHL#S]?DT"@M]M;$EH:E9,6HM@2*Y^T!C[`Q&]P.^]0D'R
M^;P$0@O2Z;HG;>U>\7C'5'!K:T<Y'J/1J$Q.3JHEH-=\)PT((D>6997`H40`
M!T[ZB.FDAG7T<2PM+57/`H$BR8%`H%@VUZZU")!"`2"HF84SI_'?$("_7[[N
MZ!IZ\%#V]_?EU`)BL9CL[.YJ#;)@D/;.?FEJ:M(4UA0P.S>GM//NXY=?X$DH
MF!!`A4--"-K8V"C/0J&0UY2A>2J2T,.@S=!#9G/[EQL%%8Q+I!-\%`5$%E:4
M3V++:ZJ5(G*V>)1&]O;VU`K>`7.X!ZCC4E$`9K]9_Z15AR!P#X?C,P7$A=:.
M`>4BWB$(?BX*H(0]'H\,#`PH68`\\(ZI\!2%`[MSB?>TCK(@#@T-:?&0!5/>
M%!&F(HS@4;6D&(5E`CC(,J3!/CX^KKV)[/!I:VM3H:9&3J91B\A$EV4*AUY@
M^IJ]$BL""4Y`"^8:P5C"LZ.2KHU$@H2?!)+?Q@4"9Z?KJ@*X3$#9C04T`ZSX
M-\OYKQA`=H$"86'5HHMS,8`BIQ?17OA.AX``J,M=JZ"][/:=>T+[-71T+@;@
MZ>N5E"JBY[&OIK=D['E,&Z;O?E`@$K@@NOQ>Z_W"I1ZM=\@$Y)W$_:D-@(WQ
M!I*!H9+K&54R%UV3YU.'E,>[M0^;$@C&E?8@&PS\M/E5.SC/;][J*0XC,%M-
M`P@S[(50*'`FLJSS(:''"!B>SHYW\"TS*='P3\P)U8X"I@$B`J5R'D>84^!B
M^+FAH5%)K\P`0(5B%#";D&,\"<=3ZCU4V^=]IE["S9`\@J%<=LY@*,,L](N1
M?#<\SC.BQ/17<7Y#$%S&N`RH4&P?DLCK16>O\CV&82P8`1>$>R(8TW,HYAS*
M>$8:B!!8\?E&I*ZN3L>=JAB`[S@`?4/I]`",(\2@GYW2`Q^P,ZP%;T)Y@`X6
M!WC<A<W@5GYSUA[ZFO,E@QF7V0F7_;\+!#-0TV,8G\P[HF=O$W0%%&,`BDV#
MHV?5-``/60@#O7AH9E'[0CG]BW><Q3!P8Y]WZ2``DQTYOU6&MHE2HX)`PDYG
M`=F5F@AI('4LO`6<9V9"@(;UL!Q>L_AM6C]_3/<&.^`%Y6;&KM1#?\L`!*",
M,))GAA<\/<G_Y!S#2!LY1SE&5"*?/](-478TNSA,E/Z+=OP3(]&<6POS%;P`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S0R+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(T-S<`,3`T,3<S-C,P,3,`,#(U,38Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$T4E$0518
MP]6764^341"&^R?Y%=QPI>$&)0HBH`()Q&J116TL*&H!ET):"!;92DH+TJ)%
M0!%$D*W4EA!'GX%3/N@2B!BQR>&TWW?.K.^\,]A$Q&9=^F=E;5/V]O:DN+AX
M_VEY>;FXW6ZQV^W[#W[^W),C5S)DC(7GY&G7D)ZR^?U^J:VMDYK:VQ*+Q0Z%
M#@T=G+#>GPA/2B3Z03)DOO*.29O;)^WN`=G8B@MV[B124EE5MW\*/2Z72V^:
M';V12.2HB3C"OKJVEMN/K'ZQ$HF$L!P.AV0]$-_9D><O!J6[9TSLCJY#%0L+
M"Q**SLM.,J4OD?*@[;4,!]X?QJ&^OEZN7"V3^@:[-#4U2T7%3?%X/(<'C&LS
M,S-25%0DR\O+TMW=?322^,U.(DM+2S/=1(T)FCE\HCB<.$YF;6]OR]*W#=F*
M)V3NTU<9&)Y2CQONM`D^Y!00"`0T=^.3L]+_-BR=KT:DL?6E`JOYH4?#A^#Y
MQ57Q#XZ(26L:#-'89T5(CR^@%_B=3/[0BPBL:7@B-VI<TNKRJN"JJEN9>`P&
M@]+?WZ^6@%[SG30@C!R1<2L<C@C@P'$?L8#4L`X^MJFIJ=Q9(%`DV>?SI<OF
M^O5*`5(H``1YL_#':3P?`O!W?7U=B[_C6:?L[N[*B06$0B'9W-J2X/0GQ0)"
MR'])28FF,*^`D=%1I9WY+QOB\T?2`JCPU]X)J:E[*(N+BYE92":3FC(N#XY'
M!!X#;88>EE:^2RJ54L&X1#K!1UK`^$14^20T/:M:8PLK4EYY7VF$BUC!.V".
M&T`=E]("J+SW<TM:=0@"]W`XA[G,A:I;3G&V>_4=@N#GM`!*N*6E19Q.IY(%
MR`/OF`I/43BP.Y=X3^O("&)'1X<6#UDPY4T182K""!Y52XI1F"&`@RQ#&NR]
MO;W:F\@.G^KJ:A5J:N1X&K6(3'19IG#H!::O62LQ*Y#@!+1@KA&,)3P[*.G\
M2"1(^$D@^6U<('!6NLXI@,L$E-U84%A8J%:<SW+^)P:07:!`6%CYZ.),#(!>
MZ$7>-T$M>*!&EZ#4*,-`>%;N-CX6VJ^AHS,Q`$_?16.J!*4HA"@\?6%MF.U/
M!P0BP2CXCWJ_=*5):>M:A4.1=QSW)S8`1L8;2`:&8D?):/"C]`WN4Q[/:/_>
M@;#2'F2#@=`?'9SGM^_<2P\C,%M>`P@S[1^AL-CP^+3.AX0>(YBT6A[U*%7"
MMX2^MR^H[$:UHX#4$!$,X?SJ1EPC"!?#SQ<N%BOI91@`J+`:!8P2D#R>H&3F
MX[)2+6,%7L+-O$.PP0%G,)1A%OK%2+YSEFCQC"@Q_66=WQ`$ES$N,R"AV#HD
MP>.7RYJ4[TV4P$C\-S9,N#F'XJO7FE49SU@8`%8>M[NEH*!`QYV<&(#O.`!]
M0^GT`(P#$X274%-ZX`-VAK7@32@/T,'B`(^[L!G<RF_.6D.?=[YD,.,R.^&R
M_G>!8`9J>@SCDWE']*QM@JI!,0:@V#0X>E9>`_"0A3#0BX=F%K4NE-._>,=9
M#`,WUGF7#@(PV9%SJC*T3)0:%002=CH+Z<C61$@#J6.94?:/F1"@83TLA]<L
M?IO6SQ_3O<$.2E%N9NQL/?14!B``9821/#.\X.EQ_B?G&$;:R#G*,2(;^?R5
M;HBR@]G%9J+T7[3C7WN6G#I+*ZS#`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#,N<&YG````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8T
M,0`Q,#0Q-S,V,S`Q,P`P,C4Q-3,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8`
M``$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P```4S241!5%C#S=?M2]97&`?P_KFQ5PW'V)O67A5[
M$<1:;&M2%(V5%,@P-Z-2I^[.TE:6*9HXLSM#7";B/;<,B449K=D#$1+V<&V?
MXW[J+W636"SA^'LZYWKX7M_K>\Z])B+6+![I7V5E9;2UM<7.G3OGWA8*A6AN
M;HY]^_;-O7CQXD48\TMR-AX_?AR6;-^^(W;OWAUK!@8&HJ>G)X[4%:)4*LU-
M:VQL3+.6V!@='8VIJ:E8$M?1UK-Q_?KUJ*BH2"N'AH:BIJ8F6DX5YV;-SLY&
M75U=/'OV+%AY^/!A]/;VQM6K5Q=,B?O:M6MITL3$1.1<_-.8OWGRY$E,3T_'
MP*7!I4'6UM:FP+JZNF+;MO+8LV=/PBU-N'W[=@KHT:-'*8O?;MQ(@6[:M&D!
MAT.'#L?A(]^E43AZ+*%V\N3)^0DI=S"Z5E=7)PN#@X,Y)$,1.SHZHE@LIGA>
MSB+%8/@X/#R\>AQ6C1.34#Y^_'B`1;R2,<ZT=\9G7^Q-]5.>D9&10).<`;&?
M/GTZ.CL[H[N[.]9]L#XA`4+CQ(D?HJ&A(<K+RU.N%XH7%PQ`961T/(%OX5MO
MKXU//R]/6&_8L&'^W7OO?QCKUF^,KRIJH_3S5!Y%X5=55:4(=(`0@=77UQ?]
M_?V)2)#&[ENW;@5J+`'Q^?/G:1%Z&AF'L._.G3LI17^XO6P54%8DN`U(.3]]
M^C3NW;N7<!!51H#74L8WR`#``/?[']/QT^4KL2H#``00`#'O6.NIOXAT-@Y\
M<S"Q4*,"LJ6E)=K;VQ.X.0,05B;M1A8QSE!6U<@8BA,Z/L<##WC.,@\FHS%#
MO"*0]Q11>MB92V%X>"0J]E>F.O.Z=>O6Y`GG,=$SKQ]O^20U4U]Q-,[UGE^(
M@%5YKWWGW<3WS5N^3/S/AG=Z00^X4M2<-E-2_-=QAG!A@?<B:6L[$]_6'$Y7
MF%"_7`HJ@/L668#K]@8&Z`-\T%FSS<S,I#DY`YJ(,IH@-,\V&N#I">AG#F`T
M.3F9Y&T)#UI;6R/;+#25H=XBH,>J92'CRTH:(SY:P+,%<A:=5!:'OJP!H?,D
M#>%GPN'^YLV;J<R93JRH!XS8!/2"9RF0/!OW8CE_<]KY?PD`\\%AEQL?_R7^
M_GM]`:".@\&%@;%49*2^?W]AT*V>'Z\D^<GH]LH!Z!1;$,8T-34E$7#J0@)B
M0)H\HZ9KID($`W4UBG9&6>SS;*VYU,A>Z:2S8@"B)ZP,ZWD!,*`;.=7BWG'*
MN$`Y,]_@E*YF5_.Q6+G*RLIB;&QLY3;@V`Y/U>DH.51O#J$B>SL^A_7U]2EC
M#6HN_3$O"Y0>>[83^$:#26C;V<&,-_D`D.K7B<DX<+"0E(]147-*H_3FQH\V
MIRR]EZ$YG@7N'LQ.NH)V3#$?>D31MO1]\_GH.C<6C4V%6/84"G)PE<8G$Q*(
M)>+:AH[XNKHU]NXOI/LK(Z4T)Q,,F\3%H5+2>7-V[#J8KM;:/#JZ+T5_\7):
M@ZAW[]Z-%:6,@"(BPF2P@MPBW2!#^X7RR![4I,_ISCMSJ;5[4$/*<3`KJ5*N
MJ*69]"D')H.18X%P(EMM9J_E",$85G/H>6=SDP3-53X<L=X\-I3CP8,'*W>!
M()0#"AG+&>(@^ZD$*<'(SA:4G1ZU%^?F$']<$3`.6?_R+Z%5"1%G!HAE;E.$
M#,-9,%#C4$!XP:%,\<GW5U'"G'&UPP4PRCSK=S6&EA+X!F[UAAYNX(K`7EF*
ML^.R>C+HEQ9UA(!,%P?I4`,=]?8=Y/CP;[+\G^YL3A/96846+%?S-VX[_A-G
MM&[F<K&,\@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S
M,B\T-"YP;F<``````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#,W`#$P-#$W,S8S,#$S`#`R-3$U-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R
M````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!;%)1$%4
M6,.METML5&44Q\>&2&2A01`2UFX,55RP1!,WP@+9^"`UL+&))"QLH@1QHXE*
M;,`'/K"5!&DA(2'44CH)M#2V4$)!QM+"M(6V]&$?=J;M6-(Z3>JU/7R_<_TN
M]\[<L5/"XO3._>[W.(___W^^1D0D@LU,3PM/?8E^_*1@'[R[7B+I>S'I[.R0
M$Z<:)7YGP)W>TEPI-0<+Y=C^]>Z`W_3/USN?T/4Z,%&_0JJC5R613$K?X*B9
MMC`C>XK62>G[A0^.]<Q\+-G]A@ST1O7CPL*\^R']5YTXE1'IZ>V5KIXAF9J:
MDF\/5PO.ZX1K]4725[92JK[9(N6?O2KG3GXJ1\J^E(J*8]EN<H0-.]L'R1&7
MC?Z?[I=$YD=D;FXNN,-TRW.:EO&R`FDX6RG$'IAPN^)QF3__F*12*4T*$>"+
M3NBZM%D^+WY*8NT]ZAS98N(?(TDI+2UE&T?JJU[7$'_XHEC#Y/G)OFU:)CVB
M_<Q&^3?^O-SYN5#F+JR65,<VSU$O"HHAZ3K)&6:HI:NDO+Q<\LH3]<)I"HH[
M5/O>+P6R8^M:S9_BP[DELY,GW7G!#1P-2&8/:48H?.)$@6)P8G)2BT]V]GVX
M5\B:OQ@//##@)1DW]B_3HK"`#:[$NJ7I<IM$ZV*::E+,-X`2S('9E0U(%J>R
M\%1UL]:#18SQ3A'9[.CQ>BUF("'.Q$="U>-?/2T+IR,!`Z[D!.@2<E82QQ-=
M7ES4L?OF`4WF.V\^J[FA\"R$)34U9_*$LZF(C771,H89V<^;+V'6=.Z]A]C`
M5$-C-,_^FI62&K^LO_VAD(>L#<@NJ@':?CV\3O[N>$6SWGC\17&N+A/UQN2$
MYY]CR9`DFH],!,((%X""X2@,%1B^N$F_9R;5*R$&YM%5Z@Y_T3!`E!QW0:1\
M,"7-TA2EZ\6U>C*+D5Z0Q\(+33=UH];XH*(/(C5?J@T!4G>)#!Q:KAZT73OO
M+0*V=C%E)7Y(U=KZN\N%V]=W":<C6C^6/*.$@40\X0'8QQ,68W`$[4+</$FR
M/&BI^]Y;"`,YE<F$@Q=LQAC&1E1-%X_<_4ZJ?BI6-J)K?@%DW+ZC]SP)(8O.
M@(,P2"2"XF<B[U:=P$DH$@$._"84$(@W5`./8D=6R&Q_D8L3GYP%)(V8^3WO
M)%WJFGJS`$T''[9T@WU-XB=9"$$<KWV-_?:"#(\,Z6]D;,EL'.BI#J!NR1O\
MKQF&$E9C8\.BE'\$#CB:-W]GIU@4"DCXY8'?S%TL\AP..$IJHO(7BL(FXF]I
M<=%J)?3U-7H/0+-ADQ;=.$71P:M?^%D/]<+J&.H5D(.>'(@<L3$-`CB^MFF5
M8AU,\QO#"32`CL0XS9,U-!?V`=Z6^WF6P-&+!,2B0W,(.H$^0BR><`2&(CQH
M!49/)7OV6L`:@E!5]V4DAP..3(Z>5N]1<7L;)3++;)QAG$/16<J$[J`SMSK[
ME8NH'4J([F!(!V6A8U":S$R$HIMZT@&LN-O#B9@H;<3V<(3-WO`80RGM_9KO
MO'/+@C4X'>AIZ9DA!18>@FIDB/1Q2:(M(89$W-'>HIMS&&;O/2BKO:[0/.@\
M.,-!9,G>A<B,=9RY.,2W0/1$,#;<H*@FU0"0=!(-3V2=)QMB;$1T',C&]D`.
M(W)*PEH<9!U.VS70-]!/+%WH;-`+Q`.FT7BM]@T.I,Y$:3?%&.-`2F/[KS\S
M&`<RQEI[6\0!YF9I,(8CX(#[/TBFU5HL4)Y,@RT\`2M&Z;B:D$5`38EI`@#0
M?R7)34/3L^@DX($LP`9`26OBYHE#]C`HR3OC?$_4;I!4=+6NQPDTP#:4O)20
M*SRTH>_I/Q;FOH1#"-&5HZOT:D/OY+\1(@>L.,AWJXQT>-9P:1]KVZI4]-]H
ME]X+##7U/U4VP2'SCM(1Y=O;7Y;V&^Y5DD.]>1E[T!O"^L/#=T-S&/T!,.5S
MBW[T[?B_J#)!M52[#T\$,'V[/<\J`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#4N
M<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C$R-``Q,#0Q-S,V,S`Q,P`P,C4Q-3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET
M15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```/F241!5%B%I9>[
MCTU1%(?O/X/_04&ME4CT&DJ5!!&=0J@D)!)&03&9>!04(B8R*,R$9`@R$\^0
M:!0SA5"P^?;UG5E[GWW/O<D4^YYU]EF/WUI[/?8=I91&<>6?MZ\?I!?+-_/*
M&_?N+Z8S9\^E^5MWMS:N7CJ=KMQ8*.4['9\^+F6./[]_I-'7+Y_3Q<MS:?7E
MJY1^O4NC"T]6\]?=>_:F3H0%.Z)`X`EWQ\!'/@"#=?#0D?3XX;7T<^/96!HX
MQT^>RA^Q!0/O^_8?&#,``MM\@$8`NL`P:77$]V^+&<>']97\!-<6PS_$('<9
MR"(RV`;DHZ6GV8,[\^?'D8*!P!#@PT=/9'#+*\^S%YEA<V,SK:VMYX^&%?<*
M+_B`FX27<\-$QZ#_V-=_M/3<C`O;+$*-^RP\=;\9)P41:H4$6%UX_BOK90/"
M)B1A`C9PH:,BHE9DBPI@(`C$FJ0P.=@SQ`9)%)T"`J1%PLX3(<Z$=Q7Q#F\O
MH1%@TS/:N6-7?J($FGUH>3#6*>"PT<R18<GT90]F7,-O:#*&<R].`6@H@38!
M9+*HI6,.S%0/,]=+G0]$V23B>./9#RL(M45.V"5XOG]S>S@3%5:(11+%+*R5
M%+`M^VC5S.04H&,2E0B"=9B(O">@=5,YHN@I4)!LXTE:TQU8",=VTE,`3)*'
M9.*)`IYD((K)0A`V%0#/U@LS%GF26"BB'NQ;[!<*@"MDK=K<+"1<L=!0DL>%
M"NSK+&B$2668[9`6DR7-?N$"'^O*@^;)._Y;B:PB#ZPZ+.(*]+'K"SE86(>V
M2T%;>)T"_,%W!/'5QD)),TN`#(U;5F:G@&C:MFWZ,$.S#^U0M$<4"H`=ZQT7
M@.@Q$0-I>\6V^H&S8=K:5C^99-!!%>=.:]4]:`C05.,VMMJ(G2)>K%I[%/X0
MD$&OZ^;8`D%J.CCI!2P:1@3">QSO@P#J<$>O!&%-:"Q>`V+SC0#@;X&8&G85
MD.DLLMP>8Y^A3&Q2\1H1EY&:&0!GAZ!=,38\GEXWO?:QO'[9=I"-@T``[8E2
M`=`XANRR=AD!V'DU3!2@X?,.P)YST=OU1``T$#W60-WJ5>I%TXN7,\-E1-@7
M-'S^C>@=@7U2I4XUQX2#"B7P>`,T#P3K,#,B-6B.!MEF#L"(<+PI\NY(8?&N
M5W%V.SWE<R1%,%X.'8;-(XC_:1@]&G7?88$B^:39]W:JK)/((3O8B`B-Y63(
M";&*>:<\32B\YTS9<V(908#Y[X5]]@9;,<9![7E#F]4H(SKN:T0>CPN#D<?]
M.,";`**7GD]4A@=>:J#A)Y-YPJ,L,I/VIPZC2<,"X2$/D`%T;029UGZ]_@+-
MZ3G;";P;6P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\T-BYP;F<`````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,34V`#$P
M-#$W,S8S,#$S`#`R-3$U-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]
M2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G
M95)E861Y<<EE/```!`!)1$%46(6EESUK%4$4AO,[K;7R!]@*@F`7$*LT5FEB
M$5"K$!1,L%"BC5=C(2:"5U")1F)(<!WWF;G/[MF/>V^"Q6%W=L['>SYG=B6E
MM)*I^IEXYL7^V^WZ426>^</>ZTDZ_G62/AY.RX>UM?5T\\:U=._NZDR^K^/=
M_J?T8'TU_3G92RN/'C])B&QMO\QB6>'?LP_IU8O-]/OT-.BHS1X>[&;3/+]/
M"Y2&`1A('_TX3MA`+78:ACNW;Z7K5Z\D;&*+-<@:AJ_?CC)NWC<V-I/?`X:"
MH_A3#1GP"8`2GK0,M12@SL[/LQG`/=VZWWIQ\/YA^CS]DH.!?;S(#(#<V7F6
M78.!://$`[QIO(`!%]G`A-1@*(LJ?R0&8$"HXP4@86)C,IG,BT.;6]S$=7(B
ML2[NC\3)0,)D4O&8K!L6WB&BTHUC"#9"E`FI(VQ$P\A`*$`92CJYIE(((T*\
MHPB_4;#[_$U.$OO$``,$JU%`J;&!59@1Y"FSWZQLUEE!K%>K#":@VC40:^(2
MTS4:1*";>"P;6*J%)PCYUNZ-I!$_00$:@L<W%/".96(1^<?K(/:&%'*_1$$1
MG%M$LP$RMY!@(F`6DU/"-8JBDHX"A+$&8ZQ`UQ915C)SJ6,=89AR+]9KZP-%
M!%`ET+"4:UALD`6+!T6DSMI`"0B<FP,%"#`N(!2@S"'(.]\0;A7,*I'^AF(O
M6,XV%^2@IRXZ"H")=<<N2B"8%73*VVCE&)FYP*9P9528RD,`_VUOD)'63@Q@
MAI$FBL0P]$D@\9]@#]((-'R#`0&B'2,/8<!X#0H)V#`[C[&"@%9M9_ALLD$E
MJMF17&!666EL]87-9,!*-98,^>U"W>@L*.=`0:4K8TH6S(/%,X)>D&SU/K5S
M9'R67`)`U3FH'`_S*,Z@[AP:`KF0X3&C\;(0QTU_[4$X#\A\X[,P1X/.N%Q1
M]3X51;%X*6$_OBO#DS[`D3Z(I9XCC$(Z%8,>L%0GY('LU/(HC!%Q$*.G"V+!
MY01&!#`(>5UP5#I3G'3]PSO.8,%X0K3'2C4T[FU-KS5(.WDKP#BMY=JVB[<)
MAB&`O==XJCC+O64UAO'2J8IB##IZ4>SQQ!X*^:X14\/:B[TCO4R>JAGSR'JQ
MZ@!@D*($1@S[CG&]-KPQ+7H;SPQG)B#]IBQ[_I(,:B"./:^#'`-]4KGO&E4F
MDM=F[VM>LQ:V(:AAQ(AG</^,4J'_)_%^;JXA]+`//WE?>C4S[R+UEX%90.[B
M(8DAWC%$%.(M7.-0_+-8>AI)5K:1:,-69KM#!Z.`L[=]4L1T@->B>(9>^BSP
MQBOUO3!M`&6O!;U<]U*&6`MTA9$!U%BT_`&PCOX;@'5A<;7U,00:6]!_PD5'
M,?0/2-3K((#((R<`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0W
M+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-C8`,3`T,3<S-C,P,3,`,#(U,38P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9
M=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```#R$E$0518A9V7
MNVM4012'M_%/L1+S)_CH+2RL@]A866@G0AIM%"2-E4;L1$$(P4*4B`$+BXB*
MB((015RPD+44P<>XWVR^\=S9N3>LQ=FY\SBOWYS'["BE-(+^_/Z1&//DQLVU
M].'3.&W<N3+;O7MO(YTY=SX]?7QKMK!R\7(Z=.1H^C;Y.EN8DP'_H\TGZ>7V
M>AKQ@8SKJV=G,HX=/Y'YEY8._F.1/NYLI7=O'B9'Y)9-1&V_>)W%(0HJ=B(6
MTZ#EDZ<3<R3\^OYJ=N#JZK6\>6KY0-)<J6,#F]+\@9_C-/[\K!B)^'(`#HQ\
M^WXG@X@Z0("IV,`F!*ALXD4Q$@X.X2(`X1[JR@%<XXYTDP,%*+DB@4.Y'=!;
MVWJ>+^/^@_W9AEX<.G<[]0`;)E\V"S&'VCA5>(&5A,=X+HE`Y[*]<.$"3T*.
M;YWG*HTKQH*2!%((,0B9,Q)_,&"-"';N0:BY"PB@(NR@B@`8#87.36,JAS@,
M,Z,"F2L((3!&((L%EVZO9W\Q&?^YLI4+AS.CL=:ZL?S#/>L[6B:3?26L#,X6
M<V\<M/*CSI.%`\D@8GTPD-CDH,DGZLX1%H4TF8U`(Y*[C]'(&D+F!,!@^8D1
MR6AA&0QE#LM,;#@WF!BM:<W"Q]6I&4:(=5R(B611+)%HW8EY(&&V"12USPD@
M:&"P-LF<J^XT(A$"DP!W7,!4DL<$@OB&65*[S!T0.4S2<!`7%"*ULK%SC2)L
MDXC-0J(FJ%WFC@";%L0WQ#ISK&..H&9S`0,.L`EXI#89*0/`MA*ID\X<D`%F
M"$;V&'O3V6H$(V!FS=-K@P`49L[\5ST8JA$9R-V4;Y'[0[5D(0/J&E/WGE@!
MI%8=&GPA#"EN*8UQR4BNQKEKEJ"6(7LJA\DB8+:1DGY#)(DY[]P:J"'V0E'1
MD$'E"*MK8TUUW?29:"V!+,96,8T8-*!6'DMDJV3F1-TM6J)4=P+(-5%H*K<B
M(C@:HF=ZKW+.8X#"A3[6[UC/.==K`+!0>GR>:`1*5!@K+^O404I6+-LJJ@-3
M@YI7P$(LJO9!1\FYAL(#`K[>Z@84N[J!V`Q"&Q+>^<Z"7*N;E<9ZSFOP\:;W
M7H?IV_NLL"?%!UZMT,=>_&^B`=&HV/PT!L][_XGH06Q)L:/&-97Z+7E6.;Z)
M6R^R9B4DP.@^H@#DM#8[-=]X:<-QSZ!DCB%XRYW3A/IZP)P!'+2(F-\8`_P:
M9YO4`/;,#%_(>REL&@`3`O0:0T3"M%.IWT:\RH$=8Q;MKL4`%=F[6<ME<ZJ,
M/PL^VS!.R./9H9X_1'\!EFXBARQ*W20`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O-2YP;F<`````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4P-``Q
M,#0Q-S,V,S`Q,P`P,C4P-C<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$
M?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA
M9V5296%D>7')93P```36241!5%C#[9?93U-1$,;Y>WS3%Z/QQ27&F*#1Q"6*
M&K$N(.X;BA)Q(;D8%%$,99%`*9NX4,6E+A`%+2J(-2"6`L%$'U`,#_)"@F-_
MTYRF%PI!C8E1'PZ]]]PY,]^9Y9LA3D3BHI?^:7_]6G8=M:2DM#R\>[&X0KK>
MOI6D_1GAC9&1$7G9VBH^G\]^/J+#W]$IBU<FBFYD6+F2F')(SZ,K;MJ,F6)9
ME@P/#TOD2/1">IQ.5WFEW&MLDORR&LG(=DJPIU<J;]R1%1M3PE+NVPV2YBR2
MS<U^.7(\4S9XO++$.J=FQIF("7O*`@6%Q3*A@'7>J0!QPO0Y\\0FD.!(4M1K
MM^Y7Y-P"!ZE`7V^O7A%/]??WR\,G/ID;OT8%<7A8?<AS@X.#XO%X!!P\LZ<:
MSOA[]6%%:KHXG"XAF&=<%?)SU_R9%7.SY46;I&7F2G-+F[JEN+).JJY<E2DI
M6+EFG1ZLO?5`SN:[Y$6;7TIK/.K"BNMW]7=T=-1^1S:L"T6:<!QF%9;7JK"_
MHTN,JS6;K#`RW&S+Z;(;81<?3#VLD5R=O$LV.;9(=IY3YB]:JBD^:\%2J:VK
M5QF6[0KK2JK$ZWNNAV_>]DK6^0MZ#=Y=5?5"-N3E75(94PVV*T3[H:&A05CF
MG>\D@0G^[P_CGZ-@Y]X#\N'#1_EA!5`+3@L$`O+J35>$I::D@`0AUB0.Z9Q]
MZ;*&DQJ%U"95,#0TI,)D&EF9F5,@G5WOE!JI!U*;?(BI8%E"DA*R^UJ]T@?6
M.>C8DZXH@L%N1<5W%!F"BC@+:U@FW_G=GGI*GZE&JK/^P1.MC7>!H)*7(2Y5
MP`N:<1B6$:0*<2*\!`(0X@=:1_*!8W8%Y/:ARNM:(,"FI)-/6UI$.)4B8L4O
M7RV-CYLD8</&2'@C/L`Y%!"''S]K4PN$LKGYJ<#]1`8?(3,P,&`OIA,=_6J=
MYN!VNY44<1+O<$%6B&I1=NI^H]#?QD4!0;3RD2J<[=BF"A;NWJ?LX_5Z50'7
MBID'T5IYY@`D;_9@GH[.3MO>7U3._Q8`BIW63K+37B!_ZI/\9#8)=@?EMP&@
M>LIK;FIM4Z)U=Q]IC3-.P#3\9N65:,51LJ3M+P,@I2E?N("I`Y*!5#`(H9CI
MCYL##`"4/KS!-\#`H7CMAP%0@+!<J;M:1P-NS,(@"])B\0UZQ""&S71`W4%H
M`*:Y4]C,)WAM0@"P`>T#9N26&&3$@&IYAMQ1RNTQ!@!X"_XF%Z`=>)M?0+"/
M+F3P$,T"FH;GQI$A+`%[<B,40WXH,B",VTE`O@,$0"QR@G>&)\(`94/IY(+Q
MDJ%Y%@`(J0T`\69T(>8P+G$WDR_NQ3,H)*Z`0"GNSKGHU%\`<CMRP,CA):J#
MA0[THI^9BXJ*F0,%H1O#YG@$8H;E7:[PZ$N(&(F+:Z_I/IQKAC64XGX2KKJZ
M6L^:_S&(/6,5K87<F#`'OHY^DYY/7U0)RIFY^9\#U+09@&",A`(@0)G-3=\"
M/)W$R):55NBM`4-#F+0*,+RC[[.6#3=H";S7+DLE:"L*M6$F4/B`4&W.*9)5
MWB:].15#GFQ*2U=/(4^#!3SNGQ(/Y+=WR_KTD\IJ8X4@F=RJ&@6CDTOHAH2#
M.)K)UO12ON$A/,&,'3T*_Q(38@@C8SOZV#+&((O*F$SV?S<TZSM[#L`OP#39
M_P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\V
M+G!N9P```````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-#,W`#$P-#$W,S8S,#$S`#`R-3`W-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!+%)1$%46,/M
ME]M+$W`4QWWKK3\@>JR'B`J"B*(>RK(;$51T(2NE&V47Z&I)5S/*TJ!98D@F
MF:6"76:M9""H&8M&(KF<EJ5K+M>Z*]$H3GW.^,TM5UE11/7P<[^=G7-^WW-^
MYWS/SS@1B8M<^F?YNFUR]9I=PH*4+?LD[W2Q\*F"!<U>R3AP0+Q>;[1]V.1Z
M5:W,7+`LY&/]INVR9>\1B9^5*%.FS0BI87O1Y>XY)7(U-C9*+Y]9N85BR2^2
MG0<MNEI;6^6*O5J25ZT/:=GM=AG9_D;![]ZW7RS>@'1W=XO'X^D-,R;L/BML
M2]TA7U0H*KLL)\^4*;@A(T9+E$*%K5*JZQR:S%NWG:J$@2J\?/E*0R1U>$")
M/1DDW+@!'4$AS-+24IGTZ+G4U-;*VO0,Z>?[T)-)A\,AF9F9LLOU0./?E'E$
M@L&@?'^8/[)B"C>F90@UP<76.>N%&O/Y?/)-!PUW77*J^((:\WF\X+Q4U=R4
M><D;Y(*M2M.'LYA53-&1ML+22VH("G+>Y&Y6X_3L/$F8O33L9'Q\0BC-QE/3
MZRXY]+!#CEERM.`3.KITSR+]R)*2DV5BN4UR\_+%:K7V9)G4US<T2*HG(%RL
MT^G4\N23DL1!04&!M+6U"??*M7TUB8%`(*R``[,'\N^YQC_#04YNOG;$=SN@
M[V`19WV#F,*"*/KD@,:ED,HK*K4W:5HJ$68<,W5N3$=17X!,&5-MIHP/6T[*
MJHU[=`^RF,2'(:QPKKQ"RBY=4R?4/_`I8>Z?</@=E&NWIVO?AQT`V\"E[CD1
M1QBQ0(/1COW9>M"<)6NTK,,.$`"/TSB9>,D#\'$$1R%;O'JK[EE1#EAP%+P)
M-0UTN'5/T@:[.W4L$":-Q!Y^,_R@QBL?OU`!L=*%]`+D1T,Q2D@<!_`[#3=O
M_OSH9H(U)[1TJF<Z[4;76SE;4ZN=^/Z30MH#K^X9&N0BLMG"(<"BD`<#T"`P
MR-C/]G5IR\>\QB^U,O`CY8:J_[)V_G<`4(.T&@4-.T`[?*>UD%$AOP0`O<P<
M@QAH2P@!JJ)567R_X;BM8)B%/,@894R@GP;`P1`-!Q!Q2TN+$BU[R(?!BXS#
M&<SH0SB&4T:-G2`P>Y\!0'$,W<*BT&2'%@U!$ZDA+-B.Q1X]R(S#`>IJ<BME
M`-*\Q'A/HL=5,;=C`B`:T)->Z)/#>7=RJ'&,0W1@0Y@2&1GA0/8\A/@.8#)B
M=&`8?,*F/$D(L-?[#>;$@(@YW!CQ,@8]QBPB@V$XE/13(\@H1I,-ZH`%[P$$
M.ZX$\-`Z5&X>&5%7`"I`C-FP65/*'?+B-6OHY.DR><4:C8+?S"=.D1M]\SD\
MZX0NH\LH@,EY9YFK"!_>^2XH[?ZGFIJTXA(U0!&YZXE?#?*JJA4<3JYX.Z6D
MW2=^OU_EXQ8F:F3H(B<K/."0';7:=!)\3N11`)+N-*GSE)04G08X!@SO;J+`
M$9,!(/Q>=J\Y2A]=;``PY6"6@N2*"(K:6)2:IKJ?/Y1[M07SB]G&H<8`1_0U
M<XYI2[0\#IAQ_([-Z#OWU8:)C`Q]LC3(%OKOC9KZ(2)*]+R08256'?&1HX[)
M#!@R$_F"K7S5+?W=S[0F>![_'T9_/("/V;C3JE)*TOT`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S<N<&YG````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-S8`
M,3`T,3<S-C,P,3,`,#(U,3`R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!
M!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```%$$E$0518P^V636A45Q3'`]*=.W'AQHW%@HHMN!"5
M;FJJ$"I(BU^-"P5CV@9M-`F*41/BD,:*2F8B4<=H/IIOTR1,!\F@44<EC<EH
M1]O1HC9JC4K\*H-3-&*._DZXX[R\9]*X$,$NSLR[[]U[[CG_<_[_>Y-$)"G1
M]&?)R@R9G)8E<U(6#[[-V%`@6_*WR;+4Y8,O^OO[I;2T5*Y>^\NZ/N[C:/L)
M^=@?%GV1D94KRU:OEWD+%LF"1:F2A*-M+I?T]?5)?$FB[=BY2VP^=^ZM%,Q3
M5B-9F_*E^62'7/OWN1">3NBY^;?D[=HG&<5U:N,WGY*"HAW.6P2#0?L6PYEE
MP/ZOG5#5Z)/5:W)D>CBJ0'Z4YWX5`Q^/!3ODT[DI&CTX'O:U"9@F1:-136_A
MUVGBK6S0-"D#J/%-/30U_2RAT#DA75;]VMFIY=$M]IQ_H@]SJ^\)$[.RLV7"
M]DOBF$5O[RT9-LTW,<>7M$!#LT]C/1)HEXVNW5)8]*.$+_XA`P,#FH^C@P</
M'RH20%;3?$1Q3?DV6XHO]JJ3%G]`*FX_%8_'8W7`1";0HRPTBT&*]O+[_>+U
M>K4Q`:K(O5_H?$M/'[_[5,-L"P2T4(?.7%<6Y)R(R:;<S;H[3DB#L26"?YX,
MR*1Y*\3?\;M6FSYE![A175VMBW%&9)DYN?9N!)C$E]`%(W3R-2R)1")OJ8SO
MA@.:A5+2_*-R`(6H,UU(S0T/`140#<".#J`;G4@;0UC8G;PV+\YPQDA>HK#8
M./!+X*0:)-]_X[&L^L$M4S^9J8Z1K/3B,GL?T+(LH&&,?)`_\I&SQ26KTM*E
MMJU=M0ZE8`[_%LW!P>FS(0T=7I0<J)!#Y>4J$+0V#FGUSY+GZS.XQ!W@#>`P
M"(,FE=<T:L_CD`B-NJ-=M#..+1A,3/<J66*QF(*$/(/VV/0:,94)AR_(K*]6
M.G.!?N<`@#30E/^6*X^TG.@>+(4;X$%*%@=3?GJFN\_(]&C>'[I[--_%+J^F
MD;RU3NKJZU4L8:<M`FI-N'3=_5B_3)G]N:;!9*.TO!\:?MS!T';%&30F?%+#
M&3@@>:,B4V55E8+Z;M/Y_0F`(J)1,`0F<.!U=7>K<L!13O61M.N-`J`)<`Y)
MH"4;$@0B,::^2WN?CAM7>%#'&&W,&*,3OW`WR0>E/AL'1@R`%H;"'5V_J4(A
MJ%AG5TCU8=WEJ)[<$.[[T&V5/;B"H1N9G3<DM<HO:X)_ZGA$&@`A3*YM:!*C
MK62-VO%L[HMDCSAQF"->:PMWJVR@=*@@):%<_#.'S3FG*1U*F!A(?'.$"J@1
M;J25#<F:#7E&GY!;OK$I,(<CEY7HZ%-SJT\O<!<BEU0Y\,4W;A($P+]9BQ0S
MUQ(`60&WR98-J3478+Z!"%D0(/<\U`6T,'0.[4,XN(<3$`B1,4CPS,88J##&
MOZT$-!S7&1J+JPXU)7K.!Y[)FLR0?L8X(NB)*=_IF,R8SSPS)@BN2KQ#F`GV
MM8<RMKW[F4Q;NG%PLY=0@@+1DB%&1Q,<'<TQTA@XHW4E4WJ(<Y=U'!TDQ%H:
MEA)!Y6&;D'/GRY*@0HEQM-+1-!<.N3%2`IXI`4@QI@S4=-J^.XJ&.8K)G&.*
M8"G;L%=TS?RE`Z!C`[(#+CA.)EQ3@=X<B-`/AE!SN$[IR)0U(/%-ZRT]C4'-
MZ5)I"\`<86SN-!''9$5GFT8C.].$J"*G-IN3*7/Q-^J;W7\QT"$SLPE!,7:"
M^/_3<"1[`5E)DG>LPM'^`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M."YP;F<````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C,Q-@`Q,#0Q-S,V,S`Q,P`P,C4P-S,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```1@241!5%C#
M[9==3%17$,=]KX^^]KVF)C;XT(1':Y2T)M6D$8QM%#^JI*P&J5AUK4TD-FM<
MOP`7W&QJB!O672+9"MM`)8TDHA*(4+&LB$4$":"@1$%"I-/^AISE7O:B^)$:
MC0]G[SWGS)WYSYR9_YR=(R)SK$-_^OKZ9*7[@'P2;9Q<+2TME8J*"G&Y7';Q
MQ">VA9&1$1D8&)"/=QT47>CL[)18+*;?=W5US4*'HT!]?;T</7I,ZNKJY/O=
M;@G&SLNJ]`QI;6V=DL0PS_'Q<7T"9O8F7ET`^P1PP>4!^7#U)GU&H]%)#&P6
M%Q<+`;U^_Y$L34M33PB."HR-C4EM;:T*^/U^\7J]4EY>+C4U-<E>5%Z)VURU
M8>"Y/.M'L<Y?CYNOI*"IJ4EPDI"0%C@+O'@\;H>($`<="`0D%`H)A]_1T2&^
MFX.RQ>N3A2F+-&PY):=U3L1Z>WNGHC0\/*P?H8!01B(1G2-(UG@\'@F'PY*;
MFZN*"/'0T)`]S&0/&;LN>X="9/QY_2]9N^E;?0?1V?,7)#,S4S!HCL+F\WS/
M)<U1,__IU&]B/3/VGQG$[.UY"8&)B0E;L,ZU=LD>MUO^WV-\RQ68Y*)0*2].
MA^,S96930,1)#(3),-*5CTUU0Y,+M[KETQ49"<JS*2"!H$^RD+SG^,Y55LKG
M7Z^70XT=TM#0H"A([65?I=M0:'&390A`?M`'Z7K"5R(;7-N41LA`4IIW]E&`
MBPD$**"(#/=0=2#)S\_7^J`6H!H(FG?D<5L5&/^O-C<K"A3P1`%YCU*LXQ*$
MQCYE;JL%)@1NR;Z@!H\8M+>WRY?>*HV^F7^1']%`CXZ..E/6O<$'"6B,PD#0
M%O';W7=GKH4GXT]EU<8<6S$15"NCXLJ,"KK[!VV;WP0:Q,JNT_>3%*3L/2LM
M+2UBA6MU!__?T6I\#^"-`&AK:Y.YY9,418E^5!#6^0>G_I#/,K?H?-Z1,N6!
MM),1?2\H*'QV%IIRIJ%";:;)0C+P`I1&66,<HZ[F?N7'-0=]DGWQEG;OK?L]
MNK9Q<Y:NK?DE*M_57M,]"(KK@;5-V@@9XRB'2S`(Z3`,`"@0PC)7S]B=(>7;
M'PX7"2T3(X7^@-!:84&WQZLR\*^A4)R#\)/N5P"@7?3T]"C38=#<UJ!/*(4Y
MD<$3YM?B-[1/PY!5U372?NMOO4EP_2,"._)V*F"N(^@(!H,*'"<=`7`U@2EA
M$]!BC(\8W'68LPX`WJ%L/$4Y0)ACE#GG;=8!@2,8YQTGDP"8'*`O@!`C&*4K
MX6U149'FA/5(>`<`<ABGV2`+8/:1,T"8$WYT<]16BIPQT^\_?"SP*U[1)IQD
M6F[<_D]IW''/_WNS]B>GZ]2LRO!`Z(+X2L.):Z1UX$'JX8N:\4[@`,_W9:$S
M\E(\P'$<#U7KF9.<T_='GHPYKB=XHON>@J=T7PI`ZOY?97W>SUH12>">_J/>
M4X).T:%O+CYVR;'YOE`$R%9S]7F1P?'PK?F[^+X9/6_\"Y94&YT>3C\/````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Y+G!N9P``````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C(T
M`#$P-#$W,S8S,#$S`#`R-3`W,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@``
M`01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/```!"9)1$%46,/MELM+U%$4Q_UC@C8M6K2*-E&X2JC^
MA8A:15244(985M9",)+!U)@9:WR_'\/X0`<1DY04WYJ8F>B,3-H,XHR.I_F<
M^/WFK5$1(2[._.;>>^ZYY_D])T-$,F))?\K+RV5Q<5'XZD9149'4UM='-Y*N
MQ&VLK*S(Q,2$#`P,R/;VMF1XO5ZQV^W2VMHJ'"I;.+PG6UM;DE)&RD?0J:"@
M0#HZ.J2KJTLZ.SNEHJ)"QL?'HYPC(R,J$D:^O/WK3_PY0TU-C3B=3IF;FU,G
M5E962E]?WT\=PN&PU-;6"@[MZ>E1"QH;&]4*4P*FE924Z$%=79U45U=+?W]_
ME*''_4$716^:]-OJ<DN<#F=N9^O&J>LW)';]=\S\-P)V=W<UB>KK&\S<F9Z>
MEOGY>9F<F)3AX6$9&AI2SW!&4BPM+<7'FF0C&/@7OW=W=ZM;$8I;"8[#X1"+
MQ2(M+2W)`J!`8$M.G#TGL7O.2.",_Y_FE^3D^4Q)ZP/W^X^RNKIJ,GS;V(AC
M)GZ;FYOI!1AJI:/EY67Y3\-X"`2$0B%QN]U26EJJ20/"S,S,:"92X;.SLYID
MH&-5597NQPGP>#S2V]LK-IM-@`?@@(L(&1T=U30&*\G.IJ8F_<^CI@"2`Z;B
MXF(%0`09\`%QD?SG=;1H:VN38#`8%1`(!%1MX(1\YQ54;FYNUKK@(K6`B0B`
M=V=G)RH`:<"L/5)(:%%65J9%!&$2@JE"*I4]*A>P2XK"W99^M=E8>]:_Q>4^
MYU1MVC#>?_+</-S;VY/3N4_--9AQ[U%^^EJ@YSS,RS,9@L&0::=1ZGGY^PAX
M4>U2;#;6+]^VJ].,]5-[NPP.#J87@".-KI>*.#-"=\B*Z4B!OZX`N4MM^WP^
M`66H'(/H.&MK:[J_OKZ>1`Q&G,,'P;<1Z4QDH%&Z^RH`X\+"@L(9&$!=@`O\
M!XT`$:8@\!"HFYJ:4EP`1\;&QK2#`W7<!\6,3D\]@7"@&)TO5AGS<?`1C0%?
MP!D$`Y@*"PMUND((>PQ3C`A`)(B'4-`/Y(/H^DP$H""$\GS9=[E<BE7,L"D]
M@+NP#'!GQ.!11@F\P)J'L`XKL=8@`_!1C+MX"P3E'D;@2?:036C!M118%M98
MP8"+$8S&6&VU6M65*(%U6(U%".4_EO/%(WB&9L+_6#A'%C+I5$8W2O(`2G#H
M]_LUF?(M#LF\<DV;"/%F8H.PA*GMV>M*N7@G6Y4C=.SS)4]P]>-7-KV/=XQD
MC`7H`\OPNS\@XY$D2X6ATY.?Q&)]%]=_$FGCNU_O)SYZH`*AT(X\>.N4XUF7
MM,4FGM.K&`2OWKRE%9!XOO+5H_>/7<C:5\&T"OA\F_+YRW)<LL22W=$AERTV
MR<G)27GN]?KT_F\C(;V1.;DS9C9.#,V'"":0L*D>S[4VZ!Q-3ASU@O]>@1_F
M3F"]!M[#D0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+VYA+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(W,#$`,3`T,3<S-C,P,3,`,#(U,S(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%4TE$0518
MP[V7QTID41"&?0)?P$=PY\)7<.G"E2MW(KAP*8BX$5%$!#&A8LZ8Q8`Y8,XY
M1\R".<>:^<HY[>WIMJ='G1DXX_7><RK\]==?1P\1\;`N_:^WMU<*"@ID>GI:
M/'9W=V5H:$C:V]NEO+S\;5M+2XODY>7)R,B(_7F;C?#P<(F/CQ=]T=;6)M[>
MWN+O[R_)R<EOVSC?T-`@MB/6E9:6)C<W-V)G<W9V5K*SLV5F9D924E(D.#A8
M8]S<W'S;1=!965DR/CZNFX:'AZ6VME9N;V\=PR2ZR\M+>Q>NENUA8F)"'AX>
M."E/3T_V%IJ:FH1`P2HW-U<.#@[D_/S\/4W`C(J*4D#GYN:DL;%12%<W$'U9
M69F$A(1(966E>'IZ2E%1D?3T]$A&1L:;G_S\?"T)*4Y.3NJ&DI*2=Q?=W=VR
MO[\O-34U`O9L=,AB;V]/7*;YT2(NMW!:75W54O!\='2D,5,K,KZZNA)8]/KZ
MJM_)P<'`R\N+/#X^*HYU=75:S[&Q,34*]?KZ^B0G)T<1^_7/W@"'J1;P>7EY
MR?+RLA:&Y_3T=/'S\U-#&"`BIQ%@`!0I6E55E41&1LK&QH8$!04I_+":8M[=
MW3DG$_1;6%B0Q,1$&1P<5!Q(A9^%A87J8&EI23X$\?3T5#\>'A[J03A57U^O
M'6(%KK2TU'TZTTENE?&SR^5'@/R4@>/C8RTT9:.\O!L='75-Y>KJ:MT`VSH[
M.[4A`18RG9R<"$W+=\JYLK+B',2UM369FII2X@`>:@/Z"`DR!+FBHZ,=RTC]
M\<R&L+`P#9V0H3$1\(Q1^MI*(IL!6`C_\00+(4QH:*@:I,?QBM'BXF+M]=34
M5,<4+BXNM%E\?'S$U]?WYQ</9>/6UI;*3&!@H%145"C!<&@SP"%RQ0/>,8!X
M8P!5W]G9L1D$:/;19-`=%;)%`.K(/YX`C$/@$1$1H9*)<0"E%XPNV%(@5Q20
M#70C85(-#F(,(`<&!E142(.6=U9&[42F!S7'B%GP`N/,)*MW.P.@&QL;JQV(
M5X2#LB&_>(=45(3\G1I@')EGL*"%F0(='1VJC43'-XS]<3H9R4('S\[.]'E]
M??WO91WPK)/LV_4`O>0F\<_TY$^+F4/5OS4`"F0=&U8X*?3U];7"BL3`#-@"
M"L_/S_J>8M.KUG8S=;7>?EPB@"/80U-`@OO[>T$D41>H24,@'B@,U*5UH2Y=
MAF`PA0B&&PU,I(5!"CMNEX`)11"()]J((G%/X"J)'K!`Q<@=]#9!T2^\6UQ<
ME+BX..UHMTJ`6G.83+:WMU7ZDI*2=$ACD*X&!62";Q@V<H&$LH?`^OO[M0R9
MF9DJJ2@EBS/TI$L$J"4UI0P(67-SLRHD:LCS_/R\/J,0=`%7#^YG!(WL\@W9
M08JYY[`/^-$O!H<#`@P]1A'9`1D-ST\S(#!$`%PA<<8-`R>4@[)P:T:R`P("
M='%39Q_VJ#T+9`F<!4H(##[QK=,(9J.!..<@8HHZ$P!PF@"`V\P&[K9D#%I`
MS3NFF`F4L4#I("4DY8:#<TK`]1&?^'8H`3!1?S;'Q,0HZZDK@5%GZD@F0$Y]
M^0EBL!UN&*[0*0P[$.0\P^OWUG3@`)O(""V`-$0+U$R_KJXN;2\63LS=E66<
M\HUNX.[&U(`;V.!Z3K!PB.3<:D/*09T@$M,%33!_B!`4QEI;6W4!+U`SVOF=
M*RP(<!XN.1.V#P.@/F0`P8B6KF"A"V29D)"@<+,H"<C@G`Q!@HD-*1F\*!\\
M@+AHRI=F`0C`:!0.XZ@:?``1G/..&K,/+?G]/,&8:^:W#2/*0*<XT_C_,@VY
M9?+'Q%=L_`!M65P(O0_*A`````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O5%=#;&]G;U\S,G!X+G!N9P``````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#4P
M-0`Q,#0Q-S,V,S`Q,P`P,C<Q,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```"L````@"`8`
M``'\G;&5````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P```C7241!5%C#K5@+4)7'%5[;&F*;-FG:3NO8229M
M,[:-S7223!IK,TEKC/A$34#!BHJ)2`6BP8AB)!:CYM&H$V.-RLL'ET=X/X3+
M6P5%07PA&A`113&(#U!!`N'T.[M[?_Y[>6A)=N:[^_^[9\]_]NQY[15B88H0
M,RSB%^_ED`TB,%,(X9<JQ'0+B3<3B9M8GD4_#\G3$S,L]-*6@_3\Y@/T<5&-
MGL`R<FCBW6Q,X!MV_.?%:S;@*:F6657/@TF5C?38VD(:_I]]>O"M-#N^8MJN
MYX7P3U68LDN*]LN0?#K6T$)55^^0"+*2P7K)'OTM/T7<UMY%'=1%Z_)J#(Y5
M5UMEW[T_N?EHRCUWG1I:VJFD_B9M*[U`FP[6&8N,/9LPR.'='JR'(7@PZ\(1
M(,Q2Q-B<',!&>$.-M]OI"C`YLER-_2M9:<>V04F\-$O"UD9N.@CE9I+P39'$
MQ@:9N.,;HJ'OYU-XV05CP1,?[H5^=_<D%MY)%)!QAIKO=A!K1G@GD[7J&N%P
M>A(75C?1QJ):*H7:=I354_*I!EJYYPR)V7$FXA56/M8>)F-WU+XI6G7VNOP+
M\$B_>C;@&O42<QJ_]3!-"RN5F!)>2I-"2VFR!C_SF&W>!4BJ_`HVE=,$58_M
M9FPS#9M2V#\",[LQYPLI=CNK5K??K,O'$61UTZBC,/1@;W,VQG_?3KE0XNBP
MPY1Y^JJB=HV2B]-/7Z'$B@;*@_9KFUKIZ8W%U,*GXAE['XS=HVG_^1L46GJ1
MA',XW81%]=5&?+)?<1L?<1^,I^Y2%(]_(/L7/BN1_9-K"ND67&[2CC+Y'I!6
M2=ZIE51SK96$?UHOC/G(M7-+QB]O([$H3>I6S$^$#:%?DJ'>?9)AB!CS1;\@
M2<VYPC@G1AJ,![^3(08'I)M,:'F6M`QM>_\WG)9D.)A;8":;R`F3)6P"E@*K
M@-^;B&N!""`)N*3'INC^KWKM1P8?PX9]DL7#0=9^XT9?D"%B>18[2["]<X#I
MAGVUY+*MQ#!\!CN#"S`U7('?S?.C/SV@%#LOD:5^P@A6$AXQ0H=]%:08?JER
M0<57M^EWZ_?1R"W*,CBQ&#0K$+$7IZL(^':ZL(_:[IKI<I,7<8CW324QZG/)
M["G8:D<7:'R2NFG@=4-`QTQ[VJV-J<X5TD6!9S84$6>W8>L*Z+7=Y4I2-KM`
M%5F9]L%[,0VPGJ&?!>>05WP%I9QJI'^$*>._W=Y)Y8B)PBN.GOU,Z;'NVAWZ
MW@I(NB+['I+ZI="1^F:9X5H18(:%Y%+[-UTJ"+WP7\GL<83O+\&06P0"KQ.D
M[9^IZVX[G]]<?)[VU5ZC<3N.DO"(YL.@\9%'J.YFFYR_@1TX!=V+J0YQ'C''
M:7Y"!8EQ8=*%K8ADQ>>ODZ7\LI2NHJ&97D05(<:&W<=!(=_])#B7+!57)//@
MG&I:HW-X7DV3["/++\E^978U"3?+O0]*S(B6"VJOMU$4I+*U^)/J(ZFH1;KT
MV*K<LW3GZTX:]$Z&`U.;\7O&*J8<G5ZWL(>0>`/PC"'QSQC]'*?&.5)Q&N4(
MAL`]+O2(9"JC%6!$*2Y^'@C*NDX#:.S>L!H!U2E^1B1"ZH6G##@$PFGLPE]_
MV*W=L:_Y'^G^Q[IW`AX4>M$UP`4(`&*`1#W>I'L?W?L#H9H!.?2EO=<%IC#(
M-9F8O'-F]"EUZG>!UJZN7M'F@%:'OJV/=39T<AA@KWT[O0K)F(_BMQ`N$DCN
MNXBQ85:<T$%='>YTMJIX+JCMP6.S8&FOA)(8`^=SCH`3`F[1ZAE>+\:&DQ@=
M*BL"\49"3QX2&!^YA<(.7Y3?-!)*CXK+5`V8?<PFK(Q1YO!M"M%B$<)X0#KR
MPRU)ZXV(P6WHZGS9CX]0P7/[H3KZ*8(JYQ.[@LK,"W/?#[3:"3ML38$=!BXL
M@\=1"O_AHT)%BRC#[?W\L[KL.2A[EZV'9!A$(E,%>&_"8IXCE%E86U#IM<[J
M55@^OH4I*J!P\IN+(_-.4(%F5BR)2;@?+4XCS]CC,(%(J4TQ)XY&?+!7T@Y?
MDX]P>5;6\<(+/-RQ>;<HQ=,]1FY0;@2UVK<7]N6MY&XY)I_#CM3+/NY$`UFK
M&^5S=M55>4<(R3\GWR?BKI.NG3(0]P?)XZUTV8]!+2+',T[3(RL5_Y;V3D4S
M(9(&ZPO@P(7EG4,#G9WP6GANHDX\K#UN_C$G4,,D&-'VV*5F>A1'J]:JM!IB
MK9;]GS<6R7[4^OTR$]K:#]@T\)TA[^9\2V%1LHA%Z?3#8"O]:E6>M+NG^"[G
M$DFO?%Y""Y-.TH*T,_1K=J`QH>1A.2X%<8LZ1GPKGKX+^7YV+$T,+Y-FY!QZ
MB&;O/BZS[M]@TP\%95,@9U6O>'):EOD=:-8CVM""<_@1.M_<1FOA1$6XG*PM
M/$=/?Z(TY@%S>1'.Q&WT]E)Y_URL36%6S$FJ;+Q%VP\K4_KCF@**/'J9NKIT
M5>2?^AW8[#0XT'QYUZ8)J(?%G]93P84;5'ZI159%<V)/TDG\\<"MIND.38@H
MI:NM7\OWHY>;:3;,I/Z6JIX28$(AJ%F:,,^EQ_H#=51VL07EVV9YAQD"+0]`
MV.AN85TM*N0@1&THKJ.I.\OI.1P?%YO/`#-C3]`,",P7)#=49Z];CM*SFP[0
MH*5[Y-R(#<6R/N?W*3C^Q]86T-J]->2#6]NCJ#??RSM+P04UJG;759Y-V*&(
MK68(^=\/EQZF&QU7'9RYC`SFLE.%+LXV7AIS3<_R_0O[N7D.='-[66>C@T(>
MT$ZY.E]^5U4POKHL6I"DJAF[=,;E$:=;UB[J+P@@A1[(_6N@=S8I)`O'2N3:
MS>'&V3N8D+$4SXMQC5K4#P+O@Z9?0#$!&>I[R[+ZE@D_U<!P8`=0!CP$5`)^
M0*=.B3/U>(=^7PT$F<JXNT"5?A\#N)K2J2<P03_':/K)IOE_`R--[UL`9_U\
M&6@!BH%&F]0\\2HPPB3`2B!;EVE/ZOM]+O`QD&E:-Q0XJM]?T_.OZ@]8@.?T
MQI?IV_-6K9Q&X$O@36"4_J_@$!`(N`.+-<\2W6?]#V*[0^-\C+@O`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+VUO;VXO````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,P`P,C$U-#$`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B]F:7)S='%U
M87)T97(N<&YG`````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C$W`#$P-#$W,S8S,#$S`#`R
M-3`P-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````,````#`(`P```&#<";4```,`4$Q410#_
M``@("!`0$!@8&"$A(2DI*3$Q,3DY.4)"0DI*2E)24EI:6F-C8VMK:W-S<WM[
M>X2$A(R,C)24E)R<G*6EI:VMK;6UM;V]O<;&QL[.SM;6UM[>WN?GY_______
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________________________P#_
M`!>5$&<```$`=%).4___________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________________________P!3
M]P<E`````6)+1T3_I0?RQ0````EP2%ES````2````$@`1LEK/@```QQ)1$%4
M2,?%EE]OW404Q']S=NT;DD`1$6T*R??_8$V#U%;B(03=V+MG>%C?Y#9-"SP@
M+%N6UCL[Y_]8YM]=P7\-J"\M7F5SJL;M"]_TI0]O]DLW2HCY],/?`:[WZ]HR
MD05)F4Y.;[X!N-ZOV:Q,8Q`F/)U]_"K@<N]):\]F)4;;EOG5^Y<!%\M):5Z:
MW22E`"Q+Y?SC2X"+MN,^&E;O&DY@+!3ER:PX.K]&SP9"`0E.VPB\W+_^`G"Q
MJ*S+(]RR[00<$.O=VV>`-PO1UT1(PDBR)2!3AO7NZK-,__HGZKTK4I"('+N1
MP9C8WWW&L(#D$@ZD4FH9(3)&-L:ZOSQB^&6OD$5*82L[$K9D"X>-(O\X8MBC
M4)#(*!*E`<DNH+3![%\_,1A*IE&Q34E,8E!X,*4"+8\,;SJLG3C40BB.HLO!
MGR?`FM@&B%KG6H/L:;`%%B#`Z]O-I.L%#`2I<,D>84G&&B4+,L;[C2%]<"33
M*F%+BO$@,!+(/&P,9BS6[-WE(=N("A"6(8R$13OX("PLA11TVPJP(3$1&OLL
M7PV`@D#*UD3/$@5K$L,,Q:@.(<?&$)4TSMXMN664F"(THF,CA"7DF\VD`($S
MG=A=146'UA(H/!JV;`SOMCS96*9(;;&V6&P^VDC3P6D7<AP2E>R=DI9&0)_2
M@$\>HQ0%I\'9Z+FZB-R&QI8^8<=\`.RB!A*%MO1:U!,_%A/D*(W8W1P`-U&G
M6NHTUV)/D`E3V,<S1=+NJ1]*J]41AA*9)H4E:7-](,JG)\!ML2.T+$U3C^)B
M=^M0!$H`SHZ'P+1&FL5N[B&WQZH;-Y;G3\=#X/U4:QCHGLT<=9K+%B2-/HKS
M9Z/RL@7KFMJYEQUK>%W:ECSA\/GOSQ0HW.OI0PNMCBP3*<((4D">GC\?E;>S
MUQ6(>9Y(F='B8_S%R0_OOAC&OYV4U9@2:1%#4VR3L/OQY@45O9UKBTHI10DA
M)(_7V:N;KTC6SS9%ZB[RNO2.D:?S#U_5Z8_?3?2>.7K<(,7W/WWXINQ>MW2J
MX+XNK<SUF8B^I--P94-OGN9W_T38_^^?D[\`P,#OJJOKV%(`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO;VXO9G5L;&UO;VXN<&YG
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8W,0`Q,#0Q-S,V,S`Q,P`P,C0Q,#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```#`````P"`,```!@W`FU```#`%!,5$4`_P`Q,3$Y
M.3E"0D)*2DI24E):6EIC8V-K:VMS<W-[>WN$A(2,C(R4E)2<G)REI:6MK:VU
MM;6]O;W&QL;.SL[6UM;>WM[GY^?O[^_W]_?_________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________________________\`_P#?3]G<
M```!`'123E/_________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________________________\`4_<')0``
M``%B2T=$_Z4'\L4````)<$A9<P```$@```!(`$;):SX```-&241!5$C'Q9;-
M<MQ&$(,!]'!74JI<Y3BR_?Y/%TO))7\V.=-`#E[9LJ4XR2$5'GC@\"MPNMG`
M,/AWE_!?`^/YQV]C0C\^L\*G>[A=;0`).,YW?P>\V?L(0(P8BZ?K\>.W@+?[
M86,3:+NV3D[DE\@7P*OW'%RF>04O#F"-0'7_%\"+_4:3>PO6:0346L7>RMN[
MYZKT8MW@-]@*D^G:NH5)KYOJYQ1>'*?M^!```EE+YWUN@;]K;<#]D\:].%CS
MN.")U<N9;4R=DOSP-?#]`?4R"0CI9'!ODLP?.YAY?/_E)[W^!6":,$,`@U$F
M0,:\&7&,7Q\K'$`A)8N2QB@N5.(0A.?.T]AO'U7I]@-%,1`9Q!&NM4(A8;JF
M;Z[6[X\4/H"ZK()$L"\Y-50UQ'6D>YWG[6<%`]4(6$D@9`S/KHK&WH#A]WW^
M;GU2>&5@.A00!J6AM.T0O0P"3._2)X7##$`:*E247LD8RZ<1D%`(]CH_*+R9
M01)(H+`-@,`X;5MIU!!"TM%\__*B$//28)LJ+@2Z(D8&79WT&.1D'P\`/MZ&
MW*D]"PP656(%:GJ[FD?XN0]$")"B"#LILJ$"[+I&?XBI6O0%H*P07D&"(MH\
M<Q)RB*M>@%43.5T`E<W`"*&L"!BJ2DQ&'0\'8_B30FH"3!PPCBAKM-@0;.9L
M'[@><2YE?4==I@`A";+WB33C=@6G0?>B-!XZG:*#@-!`9['65)!TF$:&XZS^
MM`=0<@(B7C:@:A[%CUM"4T5TP+L'X#3A@-2TL25&&H,DFF0O<CLM??R7!`!W
M'-L88YPV)8-P(UO1:4,=5)"JVC[/0ZTQ(@4HI>$`0>1LA*E%!1IWCV;Z96SI
MF#[5%+H:=24FPE&$$?CT\^.9WB@@AS-7C$R#4HE>$@$'E](_.-_=:P,&Z(R%
MK:NV#09!.@#00U\YWZLES&F>L\:9JS:B`Z.1D,'I_BMO57J[KB7MB<<H`#)H
M`0U@NW_BK3_L&&Z4*;)0(9TT'(+UTS-V?SN7FH.Q5$!0L"<`8?ST;#Z\WF<5
MA@-*)@EW`F+<_U5DO6R@"&=0'TW<!!_%R9-0?#LG**,H)`%!W7T[=M\NQRP(
M-*AW_R"G@3=!GK[Z#>#_/9S\"2QI0,AM3G5,`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]M;V]N+VQA<W1Q=6%R=&5R+G!N9P``
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,V-3``,3`T,3<S-C,P,3,`,#(T-C$W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````P````,`@#````8-P)M0```P!03%1%`````/\`"`@($!`0
M&!@8(2$A*2DI,3$Q.3DY0D)"2DI*4E)26EI:8V-C:VMK<W-S>WM[A(2$C(R,
ME)24G)R<I:6EK:VMM;6UO;V]QL;&SL[.UM;6WM[>Y^?G[^_O]_?W________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________`/\`S$R#=P```0!T
M4DY3________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________`%/W!R4````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^```#-4E$051(Q[66RW(41Q!%
MS\VJZI&`P.'PBQ"/__\N),!X91P>C6:F*J\7U1(:D+"]H!>]Z([3E8^;-UOF
M_UW!]P;J0P_?)&00;Q]XIZ]R>+7;#VH$1G5S]6_`;]LQDBC1;`\MY^7R6\#%
M]1:CB%)-+79NT"ER`OS\5Q8;H:65'D7TFJ'R[A'@^;8E-@(M9^'".#9&*]DN
M'ZC2ZS]OVC"`9?D8BQVQC^Q/RGB@#V\^W9`"8RQY9.ZWNT$_7U*\^AKX=$VD
MC2S`T`]C]#Y\+,V,BR^!7[:0,B"PR1I]A!3:[L']\.(4>/E),B8,(*1#J9(1
MY7A(2\>?3H#K`3+J8B72@64C\KC74O<O[P$O_@Y`N`B$C5M1&LA@9-_Y;+F^
M!VRQ-!$!\DCE*#5JJ8I^\.C][/#RK@^ONV6!//LH21Y$M=I^I(QW8_.TWP$W
M?59RUFC6:4!8ZCU#)CQNEK@+:><[A0@)\.B*/&84)$*2<M=O@=>'^^+2>DQI
M+4J+&EC2((Z[7]>01FKF@'`8#"J*1HE>ACUJ%4>-XWI"3L$A3279QIFI**HE
M)+?S,RQY/2&Q;,T4/#4O=[>2<CEG[)R*TN7U!,>*&XR0D4)A>Z#-8I%1C)<5
M"(21Y\<-$E($#H&'2UJU*G(-J<RIN<UC7AE@A4F6',?#64MN0RJWP9LY"S)V
MV@RGK%9CC$%178'+@E)(:(8T^^ATIABFIM-]W.7`1L@8L%>1>&8DND>Z2#W1
MU:V6GMRD5POQO,OK>".-+C7UB,]:>E^F7.ZD)\]^9EH#BG$II7V>A[.9M+36
MU6#!($))=`6H7GT&GC83X+$.`\BV(T*'*)EIN5S=F[BWSX@,K($]M805H=&C
MK.+1B0E\/"<2.RR0@BBS(X1[0CKBU"J?'[O"LT8"27A$*)+I/O7RU,@NGU>/
M*(2%D>S9$Z(4`^W]EU;Y^[."+<^<$6O9/%+2\O[KI?C'#^W6!V;2SLS1Q[`4
M[Q[:HA]_V.1LWO0!C"E1I/KAL97UXW8ZV?2!VFH@U"X?7XH7V]TZ'$)16E/$
MU;?7[HO]?JQ^&76S?+E$']C3<'%S[*!:-Q_^RV)?-]C;1WX=]-W_9OX!P[GR
MZMC(SY(`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B]N97=M;V]N+G!N9P``````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,S8W`#$P-#$W,S8S,#$S`#`R,S<S-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````,````#`(`P```&#<";4```,`4$Q410````#_``@("!`0$!@8&"$A
M(2DI*3$Q,3DY.4)"0DI*2E)24EI:6F-C8VMK:W-S<WM[>X2$A(R,C)24E)R<
MG*6EI:VMK;6UM;V]O<;&QL[.SM;6UM[>WN?GY_______________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________________P#_`!0ZQ*8```$`=%).4___
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________________P!3]P<E`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```H1)1$%42,?%EMMNVS`01`/.G)&E
M.(Z3^%(URO]_9OM`TI9S:_M4PH`A@$<[L]SEZN[7/ZZ[_P,L\^GX<OCQ\^^`
MU^?[`"!G>_XC<-H.EB3+=BE,S\MWP/PH5`#;-MAA.GX-O*!@6P9LZLKV]0O@
MH0Q@R2IR3*5,QN-GP+)UE5\DJ;V_AAM6LB[`VX,-4BF2FVE9$B:>SA^`G1RY
M7")(5BF2'!+&^1UPD&RKU/U%-:N25)P`][?`3ZH`-\*VVBH&B!]O@'VQ+?FN
MJ;%5XTF2,>`?*^!LN[ZTO=@VJ&G",@/;%;"UZ**J71OU1ZF8X.,%6#8R;CJN
MHE0379,`["_`P6J:^J_I,TUBD<UT`>[5-QEC(ZE84HW@[FINP(+<D5804N-;
MB'KH3PV8)=G"MGH!B6`(U%.4730UX-P"@&S3_!J2(;8DZE\:<*PR`:]\5J(W
M:R@22P4.5)%54T^H(80,L5Q##`TXH4LRO3(?`B0(B(N[I+FVF6KJ&Y".),$X
MV.,EK5[5D&34^CEMV0*SZP>W<>LQ&5E&G:"Z0#+VJ0./N'0]ZKJ@6H"D%EJ6
M#LP#;9]4>M'>V,;&#]?RGN)Z9.KUK>JZR\)F>+D"SX12#ZYWI@DX79;)N&J@
MMPEC5%Q::5LUI]@)&')8]_2)*$AWZG>927*193S=7C.[&$HIQ2U)21("P1CG
M?`LL(PR6"Y(#R3!<(S@\O;_YSJ.=B-H32886HS;A;OEP&1\'QQA<Y5>B'<;#
M\LEU?]IX-1323!N3Z_Z;^3!/=IS@MKV9R'[Y:F3MX;9.`:;3-T-QWK6TUZHC
M&9]?OQ^[Y_T8D@S#$,;=^R'ZZ6"?G[;C9C/>/YV6O_]T>%O^V\?);^ALK>9:
MB)W&`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W-U;G)I<V4O````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q,P`P,C(R-C$`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO<W5N<FES92]S=6YR:7-E
M+G!N9P```````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3,V`#$P-#$W,S8S,#$S`#`R-#0V
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````'`````T(`P```(U9_I@```!@4$Q41>RPG?V/
M=5Q4)/_Y^/##"O]9-/]S3__T*/S&M_WCVO_A%I^2@/\Z%I!^0?_NZ[Z0>?__
M,____P``````````````````````````````````````````````````````
M`)M,:Y\````)<$A9<P```$@```!(`$;):SX```"D241!5!C3?9!1$L,@"`5!
M!#%1#/>_;#%)&SN=Z?M"EU44_$]@J9'O/:8%WK4V<U0GAL54"4KJUM19'5I=
MH#'',OH%G8T:.M%SK'$TJS@,&R':])^!3,(=>T^1/ES8W*M^ID6&E/.V;;FG
M'2G:FUP0I/J>`I4R<0+'UH`N6!'#"U2.B7,:#>V\$]3(J??PCID2L,?3;$)A
M9L3T9L>I*K+0U_?]Y`5B#Q$[#7^:!`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W-U;G)I<V4O<W5N<V5T+G!N9P``````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#4S,``Q,#0Q-S,V,S`Q,P`P,C0S,#,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!X````/"`,```#$9(^N````8%!,5$7^[>KY5AG_84?_>B3_@V[_
M/!MN."#]S<7^M*?5M*F+8TO%/`RZHIBIBW[\EH+2DH+_F3/___\`````````
M```````````````````````````````````````````````*,JK_````"7!(
M67,```!(````2`!&R6L^````GDE$0508TY6060[#(`Q$;=<+D`+U_2];0Q8U
M;14I\P&6'C,#@%\*;N!&ZY[H+S8)9.Z43MAXK@YB3N9)X(0!"::'FL>$[:L;
M,`S1F#OT:=[CMQB@</5:5+74[#S2('U<C2GK(AA:]!GIP$([3@Q>%?$QA*@Y
M&J0=X<:<=<!7*`Z4+@Q;=[)15'"RE2]U<XX'B1"W<M#@6*P1W?SS7[T!C``6
M\NX=-N,`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]L87)G95]U<"YP;F<`````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$W,3<`,3`T,3<S-C,P,3,`,#(S,3`P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````A````
M"P@#````Q@T4#0````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y
M_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%````________````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````2,JW!P````-T
M4DY3__\`U\H-00````EP2%ES```+$P``"Q,!`)J<&````"I)1$%4*,]C8"($
M&-#Y#`SX5##``'85#*@`704#-H!0P8`;D.@.NJG`"@!QK0'Y++X%@`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]L969T+G!N9P``````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$W,3$`,3`T,3<S-C,P,3,`,#(R,C(V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```+````"P@#````GG*'%`````1G04U!``"QCGS[49,````@8TA230``>B4`
M`("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%````____
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````2,JW
M!P````-T4DY3__\`U\H-00````EP2%ES```+$P``"Q,!`)J<&````"1)1$%4
M&--C8$(`!G22`<%F0+`9H`#(9D!B(XNCJ$<Q!Y6$```KU`"I-7*!O@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]R:6=H="YP;F<`````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$W,3``,3`T,3<S-C,P,3,`,#(R-#$P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````+````"P@#````GG*'%`````1G04U!``"QCGS[49,````@8TA2
M30``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%
M````________````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````2,JW!P````-T4DY3__\`U\H-00````EP2%ES```+$P``"Q,!`)J<&```
M`"-)1$%4&--C8$(`!DR2`9G-`&8S0`$RFP%-'%D]ACE()`0``"O4`*F,=,D2
M`````$E%3D2N0F""````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]U<"YP;F<`````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$W,3$`,3`T,3<S-C,P,3,`,#(Q-S(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````+````"P@#````GG*'%`````1G04U!``"QCGS[49,`
M```@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@``
M`P!03%1%````________````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````2,JW!P````-T4DY3__\`U\H-00````EP2%ES```+$P``"Q,!
M`)J<&````"1)1$%4&%=C8$(`!G22@0%"09A@#@.4">(PP)A`#KIZHMA0```K
MU`"IMT+A00````!)14Y$KD)@@@``````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]L87)G95]D;W=N+G!N
M9P``````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W,C4`,3`T,3<S-C,P,3,`,#(S
M-#(R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````A````"P@#````Q@T4#0````1G04U!``"Q
MCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=O
MDE_%1@```P!03%1%````________````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````2,JW!P````-T4DY3__\`U\H-00````EP2%ES```+
M$P``"Q,!`)J<&````#!)1$%4*,]C9&(@`!B15?R#,9@&1,4_W,YD@IOQ#X<T
MBBW_L$F3[E*((B8\(885``#A*`DB7CTB*0````!)14Y$KD)@@@``````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]L87)G95]L
M969T+G!N9P``````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W,3<`,3`T,3<S-C,P
M,3,`,#(S-#`V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````+````(0@#````.$6A1`````1G
M04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```
M.I@``!=ODE_%1@```P!03%1%````________````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````2,JW!P````-T4DY3__\`U\H-00````EP
M2%ES```+$P``"Q,!`)J<&````"I)1$%4*,]C8$(`!KQL(D@&PFP&PFP&*,##
M9B""38PY1+F'*'\11^(/9P"':P'YV0*8P@````!)14Y$KD)@@@``````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]D
M;W=N+G!N9P``````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W,#8`,3`T
M,3<S-C,P,3,`,#(R,C0W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````+````"P@#````GG*'
M%`````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P
M``#J8```.I@``!=ODE_%1@```P!03%1%````________````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````2,JW!P````-T4DY3__\`U\H-
M00````EP2%ES```+$P``"Q,!`)J<&````"%)1$%4&--C8$(`!C#!P$`\FP$&
M0.(P)E@-E(FI%X6$```KU`"IO5B2_0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]L87)G95]R:6=H="YP;F<`````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W
M,3<`,3`T,3<S-C,P,3,`,#(S-3<Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````+````(0@#
M````.$6A1`````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``
M@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%````________````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````2,JW!P````-T4DY3
M__\`U\H-00````EP2%ES```+$P``"Q,!`)J<&````"I)1$%4*,]C8$(`!KQL
MHD@&8M@,>-D,4$`,FX$(-CYSB'$/T?XB@L0?S@"':P'YG8N(?0````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`T,3<S-C,P,3,`,#(Q-#<W`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A;F=E;"YP;F<`````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4W-@`Q,#0Q-S,V,S`Q,P`P,C,S,#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@````\````5"`,```"N142%````8%!,5$4```#____]
M_P#Z^OKU]?7KZ^OAX>'4U-30T-#'Q\?"PL+!P<&ZNKJXN+BPL+"LK*R;FYN4
ME)20D)"-C8V+BXM_?W]04%`D)"0@("`;&QO___\```````````````````"&
M+3L,````&W123E/__________________________________P`G-`LU````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)!)1$%4&--ECVT3
M@R`,@W.;%"H.]P)H^?\_=*UZ\QSYQ'.YI`&MR:G6T.1V2AH4?[8^.[_+7[6S
MR&KFP5)SFE*NLO-2(IMB6;;[9>3@O0\\%NNOD0$B`CA6W9,Y`,XY('`62&)/
M;A@&1YZ38)TVOF\\K9VO><RD>4JPO/8_\=#^&6_KM_L?F%[[_?]]W?[+_[Z6
M@!0%[?S'.P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]E;6]T:6-O;G,O86YG96QW:6YK+G!N9P``````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`W-C``,3`T,3<S-C,P,3,`,#(T,38T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````/````%0@#````KD5$A0```,!03%1%````_____?\`^OKZ]?7UZ^OK
MZNKJX>'AU-34T-#0S,S,Q\?'PL+"P<'!OKZ^NKJZN+BXL+"PK*RLHZ.CFYN;
ME)24D)"0C8V-BXN+AX>'?W]_:VMK4%!0)"0D("`@&QL;%!04$Q,3"`@(____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````8>&W]0``
M`"1T4DY3______________________________________________\`6"P-
M#0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"9241!5!C3
M98]M$X(@$(1W2CKL),/>B-#3^/__,=`FQ]A//+.S>PMBE%4Q(LINE40D_-GI
M6?A%?JN%189L?EF"LZUU01;NO>$LX_OYOC]QK;6NN?&Y/YC1OZ8C`6Q"VN/X
M,KV?!P74[`1B69.JJDJ19BL8VIGW,[=#X:<\.E)*D47.I_XKSD34X9[[T_WF
M@:S;<O]_7[%_\[\/OO$:++GG?@X`````245.1*Y"8((`````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M96UO=&EC;VYS+V%N9W)Y+G!N9P``````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,S4V`#$P-#$W,S8S,#$S`#`R,S,R-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````#P````\(
M`P````P(97@```&`4$Q410```/___\8@(\,@(KD?($(+#+<B))`>'XT>'Z(G
M*(4@(?Q$14L<'?EK;0(``/\$!/\8&!`"`I\6%I<7%>@C(<X?'2(%!?LG)ZT<
M&],B(9\:&805%2P'!_\J*B,&!M8F)?PP,!`#`^\O+[(E)/TW-]\Q,>4T,X,>
M'HTA(8(>'G4;&^4W-O8\//D_/PP#`_I`0/)24O=45"P/#_=551<("(0P,/*`
M?V1`0"<;&WA86/3T].;FYN7EY=K:VB`@(!\?'QL;&Q86%A45%1$1$0H*"@@(
M"`,#`P$!`?___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````--"B'@`
M``!)=%).4___________________________________________________
M_____________________________________________P`,")]5`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+))1$%4&!D%P05"Q#``
M1<'?32!(BBX2W(-#T6++Q]_]3\2,`+![&P`!SBG&F+(!@6O86"NKRZ$:A.N@
M+,TLS"^6034BAR)-7D[MJH2,G,I0ZJX[:5B2Y7AX==&U;=M-'QQ%JX_G<SNW
M[4/;;<ZNQ%Z.9_=/-Y+N'H_WHN6T_?ZL1LWGRZ@DBQP^7K\:-9]OHY`1KF,_
MOY+^OK>J$;B.GZR7LC]Q:A#@G&*,*1L0`'9O`_`/]38C`9-Z>10`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+V%N;F]Y960N<&YG````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q,#(S`#$P-#$W,S8S,#$S`#`R,S8S,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M#P````\(`P````P(97@```!@4$Q410,#`VJ2OC)"5AXH-++*XDAD@"DY28:J
MTE)24A`0$.;N]E)RDCHZ.G>?SLK:ZBXZ2IBXVO[^_DI*2D)9=5Q\HSI.9B8R
M0J*^WG*:R@H*"A86%M+B[D9>?D(^0KK.Y@```#!$DQ`````@=%).4_______
M__________________________________\`7%P;[0````%B2T=$'P4-$+T`
M```)<$A9<P```$@```!(`$;):SX```"1241!5!@9-8X+#@(A#$0+\A&1E4A9
M%W'A_K=TBK%)&]Z4S)2F%$G]7D+-.;=?EH)NNI92JH8BW*J-S!P_U4$`6U8I
M)<6V[F#@X7/._F"KX4%1B;F1@0]$G(BVOA$E+FYQ'OW61P8_B`+88&^$L9]!
M^9<9YGI_QRIY`?[G\US^PA#^^6W=.T.0^VP#+H:"'*$YOUIJ#??$(HK.````
M@W1%6'1C;VUM96YT`%1H:7,@86YI;6%T960@1TE&(&9I;&4@=V%S(&-O;G-T
M<G5C=&5D('5S:6YG(%5L96%D($=)1B!!;FEM871O<BP@=FES:70@=7,@870@
M:'1T<#HO+W=W=RYU;&5A9"YC;VT@=&\@9FEN9"!O=70@;6]R92X!55-34$--
M5#T`.A@`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O96UO=&EC;VYS+V%S;&5E<"YP;F<`````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S8W`#$P-#$W,S8S,#$S`#`R,S0V,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````#P````\(!````)'?7<$````"8DM'1```JHTC,@````EP2%ES````
M2````$@`1LEK/@```)M)1$%4*)%C^,\`@]+_I?\K_`>1"#&XE/'_\/_98!@.
M9,.40"4#_A?^KX3#0B`?H@`J60P4;/G?"88M0'8Q5`%0VABLLQ.H>"88,@/9
M(!.,0=+20+M`.B<!I9>"(0.0#3(A'*@?*)T-UCOS/]O_36`(,@6D/QLDK0"7
M7OJ?XS\OBK0"LFY6;+H)V(WI<BYDEQ/T-X%0(QCFN&,,``*((;G78D6]````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V5M;W1I8V]N<R]B:6=F<F]W;BYP;F<`````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#<W-0`Q,#0Q-S,V,S`Q,P`P,C0P,S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@````\````/
M"`,````,"&5X````P%!,5$4```#___^$.P7_<@I9*`07#PET,P7H9POB9`O>
M8PMH+@6Z40K670S(5PO+6@S?9A'_=13&6Q"Y50^>2A")0Q&/1A*,11)=+@W_
M?24N&`G?=BW4<"O_AS0L%PEF/!Y'*A4Z(A'_EDQD.Q[&?DXH'QG:70QL+@9F
M*P9"(`I0+18=$@O_HF7NEUZC:$$&!`,;&QO___\`````````````````````
M``````````````````````````````````````"_16_,````,7123E/_____
M__________________________________________________________\`
M'YI.(0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"9241!
M5`C7;8];$P$Q#(4S6S8N5:666G$INZA%^O]_G88GPWG*=\Z<20))Q-PPOR<0
MBLX8XR)_F"N-(EVQ,%=M"6`!RC8;D*+&#)0MU#$!.U2>0@CD%3H&-F@I=%T7
MR*)A:#+7A]NSOZ\S-Y)/U\?'_;3;3B7/_>*ZD?ZJD'Z*D]'<$Y&?]<91]B\O
M0V6M58/S@O_<]W/_UW\OWCD9D]IX^"(`````245.1*Y"8((````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O
M8FEG9W)I;BYP;F<`````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,34`,3`T,3<S
M-C,P,3,`,#(S-C(P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>```
M`,!03%1%````____`0,$`00%'",E.**['%!=+&AV`@<(*X69)WF+/;O7)G6'
M(VQ\.[/.-)*E!`D*'T)*:<OA*7N))G!]-9JM*'6#(6!L'UME&T]8*7:$'UED
M2,7<+7R*+W^.+76!5<G?(D!%+'-^``$!`00$`0("_/S\^_O[^OKZO;V]M;6U
MHJ*B=75U&QL;&!@8%Q<7$!`0#P\/"0D)"`@(!@8&!04%`@("____````````
M````````````````````````EF*QX0```#AT4DY3____________________
M_____________________________________________________P`[7!'*
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*))1$%4"-=5
MC\D6@C`,11,%<:2*UA$M110<(HJ4_O^?V9;#PK?*S?@"VHK((W(16)*",28D
MM4P!]ZUX0)8I6/7ZL\DHR[8F`5KRX?AX2>:GZ9E+#23\,$ZB*$KBT!<$Q`;0
M:<$(//9&!,2\Q$(QS]3!<5%B7IDZB?J!7\=W9>:U7#?/E^V_J8UT]Y<-%'C]
MJ)V[;Q+[RBRO#ZV_SG_:^?_[[P<^J!L-X?DU,0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O8FQU<V@N<&YG````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-C4`
M,3`T,3<S-C,P,3,`,#(S,S(W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#````
M#`AE>````,!03%1%````____^OH`[NX`UM8`R,@`Q,0`N+@`IZ<`GY\`FYL`
MF)@`BHH`?'P`/#P`$!``!`0`U=4-S,P,Q\<,__\?__\Y__]5"PL$$A('__@[
MV<X'X;88_],IYJ`?YY\C_9<S_Y4X\'(C_W$A_W0]]F(U_EPR_S\K_T,M_#4D
M_R09_S`I_P0$_QD8____````````````````````````````````````````
M````````````````````````````````\_A9C````"YT4DY3____________
M________________________________________________`(*/<U4````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````E$E$050(UV5/21+"
M,`S3-&["DJ:&QH&R[WO__SUB>@)TLJRQ)*-3,-?,GPG*@G?.^<`]Y\J2PE:L
MG*N23%$4ALJ\0!<L`3%&@&SHP)X,("*`(<]@M]RN),V2[,YKQZC=Z75MTSS)
MXWES==8WEV.;4I+#?9]U]@LT,=_'*?0^^P\PR?X-1NJO^6,HAGW^;[^__E__
MO0%>K!((]42$"P````!)14Y$KD)@@@``````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V-L;W=N
M+G!N9P```````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3$W`#$P-#$W,S8S,#$S
M`#`R,S,S,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````#P```!4(`P```*Y%1(4```&`4$Q4
M10```/___P``60$!R`$!OP$!N0$!KP$!DP$!A0("Y@("M@("H`("60,#6P<'
MI0T-X@8&6!,3UA45TA\?O!P<5A@<&,'"P1C-`!C"`AR6##>(+'&);KK"N<#'
MOWR!>X:.A"8I)<T``,T"`LT#`\X%!<X&!LX'!\X*"M`/#\\2$M`4%-$='=,Q
M,=,S,]0V-M5`0-=-3=A55=EB8MIF9MML;-N9F=RHJ-VTM,JEI>'AX=34U,[.
MSLK*RLG)R<?'Q\7%Q<+"PL'!P;V]O;R\O+JZNK.SL["PL*>GIY^?GYJ:FHV-
MC8N+BX:&AG]_?WEY>6YN;FQL;&AH:&1D9%!04$Y.3B0D)"`@(!X>'AL;&Q(2
M$@P,#`D)"0@("`8&!@4%!0,#`____P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````+]7T`````!A=%).4___________
M____________________________________________________________
M_________________________________________________________P"N
M@&\Q`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```/M)1$%4
M&--%D&=3`C$0AG?L>MB50*AVQ=Y-U$@43S2<+7"NE?S_7^'FCM'G0^9])LG.
M[H)+F![.I`&2<W8P"#+_/C,0$.,]G^SK,3J5^,306'^0,$?.N;4CJ5K+.7#&
MF&UCC&U+B0,PEN.5L!%6>(XQ(,\7BB6E5*E8R'N'<G;^4DIY4<V6R1S7;]`5
M0GS`][-U@$:=?YT=;.Z==*^50<!02W%46UG>%5*%"'$#;L3V^L+BFI`_MS'=
M?S;%86UU:4M<O3?IO;F#UNG^QL[Q`_C_SNI'N*?Z+7C15-]A5'_U;<!3/4(_
M7R?2RJ.C3KH/M(;Z-Q;_]H4T'R;I%V2R178EYN\U`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS
M+V-O;F9U<V5D+G!N9P``````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-34W`#$P-#$W
M,S8S,#$S`#`R-#`Q-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````#P```!4(`P```*Y%1(4`
M``!@4$Q410```/___P04!`<A!S'C,3#:,2[&+RRN*S&V,`('`B9\)DOJ2F#K
M8(CJB1PF'"ZZ+"ZW+#"Q+B^N+B>1)BB()R%(('?O=AL;&____P``````````
M`````````````````-*'6^X````9=%).4___________________________
M_____P`!-`JW`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`(-)1$%4&--M3P$.`B$,:Q2&`G*H0/?_EWH<,1?$+EG2=>LVJ$+U3#CB3-"Y
M`4O_C/\ZF<BOKJS%.5<J!Z?/TI$].Z??Q!ICK&Q[`5JS`"$$0')5L(@%8HR`
ME4+0B0FQM1:#$4>DP1^#IT7O\[<[=CR/^>Y_>>_^K^OAO^S_O6^Y?_KO`XS)
M$YXM>'U4`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]C;V]L+G!N9P``
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`P,@`Q,#0Q-S,V,S`Q,P`P,C,Q
M,C<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4```#_
M__\``0$!`P,"!04"!`0!`@(=8E<]S+4?9UPF9EP(%1./XM4_U;LZNJ0MD8`K
MBWHJAW<IA'0RGXPWK)<UI)`[KIH^MJ`ZJI8N@'$G:5XL=6E6W<4UB7HA54P5
M-C!KX,QIW,@:-C$1(R`,&!8&#`LC13\2(R!_Y=(];F4WKY@QG(<*&A=]X<YC
MLJ,=)2,!`P(;&QL7%Q<3$Q/___\`````````````````````````````````
M``````````#2%75_````-7123E/_________________________________
M____________________________________`'RUT`H````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````FDE$050(UV6/V1+"(`Q%[VBM=0$W
MT&*CXH98EQKM_W^;T#XYWJ><23(Y01W#7#$W%2(YH[4VCEOF0LD857#D]_`F
M,R%$)LOU)_"IVT$RVMY3(+G48+/H)T@//;P&TC!82[$[/Q_7XT9(S:@"T]Z/
MO:7`5=,GZWW+8=Y(Y&2MI27B?NW4!"LBRC%3+MSCHIPC9EH&H7^_/_^?_[[C
M'QNE57:04`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]C;V]L
M9W)I;BYP;F<````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,S-0`Q,#0Q-S,V,S`Q
M,P`P,C0P,C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X```!@%!,
M5$4```#___\``0$!`P,"!04"!`0!`@(=8E<]S+4?9UPF9EP(%1./XM4_U;LZ
MNJ0YMJ$XLYXWL)LRH(TRGXPPF8<WK)<UI)`N@'$G:5XL=6E6W<4UB7HA54P5
M-C!KX,QIW,@:-C$1(R`,&!8&#`LC13\2(R!_Y=(];F4WKY@QG(<*&A=]X<YC
MLJ,=)2,!`P(+#0L#`@$3$`X*!@41"PH@"PK_``#Z``#U```@```7```!```X
M`P(E!`0&`@(;&QL7%Q<3$Q/___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!KD]K[````0G123E/_________
M____________________________________________________________
M_________________P!$%A```````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```*A)1$%4"-=EC]D2@C`,13.*N+:BT%9PUXJXX%[<H_S_3]F*
M/CC>IYQ),CF!U`0Q1GQ78$@*SKF0F#'ZC)HP'PT_*C-:(H24:-1Z:A[E<V!5
M.W,;P)JD@,(M6F`/"K`J4X&`G)+N>+F8#MN$<H18<]`/:V$OT!R;_@:R7!S=
M1T$/YZ-*5'+:FOU4LOKZII2Z[APF]3WTH\9=3^^;D1;Z^+F>]_7[\__Y[P4-
M4"$G:"7_-P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N
M<R]C;V]L=&]N9W5E+G!N9P``````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,T,``Q,#0Q
M-S,V,S`Q,P`P,C0S-38`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X
M```!@%!,5$4```#____.`%*U`$C]`V?\`V<A!!!(#R@N%"(0"PX\(S,2#1$/
M#`\5%AD``0$!`P,"!04"!`0!`@(=8E<]S+4?9UP+(!TF9EP(%1,*$1"/XM4_
MU;L^T;<ZNJ0YN*(RGXPF>6L?8E<WK)<UI)!*VL`N@'$G:5XL=6E6W<4UB7HA
M54P5-C`(%!)KX,QIW,@:-C$1(R`,&!8&#`LC13\2(R!_Y=(];F4WKY@QG(<(
M&!4*&A<*%!)]X<YCLJ,=)2,!`P(;&QL7%Q<3$Q/___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#!T4KI````1'123E/_
M____________________________________________________________
M____________________________`''2CQ(````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````J4E$050(UV6/UQ*"0`Q%,_8NXEK76%A7L&!#
MQ(I1_O^?W`5>'.]3SB29G$"D0Q02Q15H\J000GJ4,-D6ZE@V:7[W+L@XYPR#
MQ4?QH=D`H[^ZF0#&*0*2D[8!YJX%KPY*`A+(U\?GX[Q?<A0$H6)GZP]]UU$<
MQGW']?V$U;Q$UMW<:^7!E>G]R+.0S^NY?'6$EJ?ND1T@JV2RQ7&@A%*_::DP
M2_W^_'_^^P(]FR;-%K+&4@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R]D87IE9"YP;F<`````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`T
M,``Q,#0Q-S,V,S`Q,P`P,C,R-C0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,`
M```,"&5X````P%!,5$4```#____&("/#("*Y'R"O'1YB$A.:'1Y%#0Z0'A^^
M+B]]'A_W/#WQ.SSN.COC-SA+'!U2(R3Y:VW(5EB90D,7!`7R(2&;%15""@GI
M(""N&!B2%!1F#@Y("@KH(R'.'QUH$`]."PM'"@I,"PM/#0S'(!_"'QZV'1R-
M%Q:#%12!%133(B'`'QZQ'1RD&AIK$1%`"@IJ$1%)#@Z#'AY*$A*.(R,8!@8$
M`0%-&AKW5%3!0D)&&!CR@'\G&QL;&QO_____?0T!````0'123E/_________
M____________________________________________________________
M______________\`PGNQ1`````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"M241!5`C794_7$L(P#/.1,%)""0'"*'M#RBPK+77__Z](*"\<
M>K*LLR1#YH"8(GXF<$PP2BD3F'.,R/FHCV<2H>,8%380J``V!;N`3!#]`(][
M\-!$9(!,C]KWV,3W]D@S!*2A\HV4TOA*4X2T>.IP(U_2\%Y(4ZLOAC73;+0,
M'VRMCFS=+=^29U(OS9?VWOKO9I5J[7J9KIR_R]^/E>I/#GF^ZZ<=OOW^^O_\
M]P9,9B+:P)!^>@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]D979I;"YP;F<`````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,30Q,``Q,#0Q-S,V,S`Q,P`P,C,S,#$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@````\`
M```5"`,```"N142%```!@%!,5$4```#____&("/%("*:&1N5&!J4&!IZ%!5P
M$A3#("*Y'R#V+C"-'1Z0'A_W/#U+'!WY:VUC$!(8!`/R(2'M("#E'Q_(&QO?
M'Q_,'!Q\$1'H(R'<'Q\.`@+/'Q_-'Q_('AX4`P/6(2'+'Q\T"`C3(B'"'Q_`
M'Q]H$A$?!06U'Q^N'AZ#'AYC'1U2&!CW5%0G&QL@&QO\_/S[^_OZ^OJ]O;VU
MM;6BHJ)U=74;&QL8&!@7%Q<0$!`/#P\)"0D("`@&!@8%!04"`@+___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````/
MYZQ0````0W123E/_____________________________________________
M__________________________________________\`06($[P````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```#2241!5!C3;9#K4L(P$(7/
M(B(-MJE(`<&[\0+15JG*BB*E[_]0;+?(C#.<R8_]SIG-;H+RO["'DVV=U'QU
MMN7S>^7Q7P\2Y8L=WRI?>C!GS!A,E2?^.33&/`RF7OG5!TYT<^"Y8O:-NV[O
M-+E^:HB!T@:N#T3`T`6V!(=NU`%2H#-R(8/-(Z(TCN,TPHMA9.:;4"LO3"8Y
MB.3,%C1;2L[AZI-^B?(%?1327]K6>OY5Y>_%D=7YS35R>OLI3G2^&(=+N6W5
MKO<3PU;['UO>_9>^3ZL-/'XSTZ94]N,`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5M;W1I8V]N<R]D979I;'1O;F=U92YP;F<`````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3`V,``Q,#0Q-S,V,S`Q,P`P,C0U,C0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````\````5"`,```"N142%````P%!,5$4```#____&("/%("+#("*Y'R#V
M+C"0'A_W/#U+'!WY:VT6!08E!@L7!0@<`P@7!`A9!1D_!!15`QTD`0W.`%*U
M`$C_`67_`688!`/R(2'M("#E'Q_(&QO?'Q_,'!Q\$1'H(R'<'Q\.`@+/'Q_-
M'Q_('AYP$A$4`P/6(2'+'Q^)%A4T"`C3(B'1(B'"'Q_`'Q\?!06U'Q^N'AX;
M!04E!P>#'AYC'1WW5%06"`CR@'\G&QL@&QL;&QO___\````````,K$#G````
M/G123E/_____________________________________________________
M____________________________`+K[<38````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````OTE$0508TVW0V7+",`P%T#O4SEJ@K&U(@91]
M$5TH)C15_O^WB&7*#$/UI"./+-DH;P/_.+WDJ?-\?/'D7?SVUX-4/+UZ+9X9
M,!?,&.[%7^;H:ZT_AGLC_C6*JE@]&+9F4]N^#))T^5FK"BA#1:]``(Q(A278
MI\P#<L#+R&>PIB3(HRC*@X0THW#^<2[NSFW_(3[5F_&W]-O[$^_QN=\8R/UV
M/F5/W5Y[Y^97!46;5F>AW'Y5(;3[^R%?_TO>)]D9A0`RVC\53WH`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]D:7-A<'!O:6YT960N<&YG````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,3`Q,@`Q,#0Q-S,V,S`Q,P`P,C0V-3<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@````\````/"`,````,"&5X````8%!,5$4"`@*NA#+^Q%9N2@+.
MIEJ@;`CXI`+^LR!:4D(N(`+5CP)F5CJW>@(>$P+]JQ']NSS^_OZ>?D+&@@+M
MG@*(6@)Z4@(/"P(>'A[&CAYJ8E*N<@)J4B+VRFXZ)@+"?@(````_>]P9````
M('123E/_________________________________________`%Q<&^T````!
M8DM'1!\%#1"]````"7!(67,```!(````2`!&R6L^````B$E$050(UV6/BP["
M,`A%[Z8#AWW$M5NUVN[__W)]&!.5A(0#X7+!7@/8@%[53%XIY1,Z8\U2(Z\5
M"B[BB,C)4AK84Q8RS&Q(<BI*7IQA:RT;)QY`E'BWXSA:)HF%E9R>E_.KL6IS
MXFL(CR%@F]#WAW"S/*58]G_U_^XW?[/6>N[^WO[CQ__7?P?#6PYTUYW,F```
M`(-T15AT8V]M;65N=`!4:&ES(&%N:6UA=&5D($=)1B!F:6QE('=A<R!C;VYS
M=')U8W1E9"!U<VEN9R!5;&5A9"!'248@06YI;6%T;W(L('9I<VET('5S(&%T
M(&AT='`Z+R]W=W<N=6QE860N8V]M('1O(&9I;F0@;W5T(&UO<F4N`5534U!#
M350]`#H8`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]E;6)A<G)A<W-E9"YP
M;F<````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`S-P`Q,#0Q-S,V,S`Q,P`P,C0T-S,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4```#____^
M&!GV'B/Y+"_N+33O-3WM.$'<1UC43%[26&^^2&FR2VRT9HVM9(Z&8I:"8)8!
M`0(#`P5E:*IU?,-9<<,!`@0"`P43%!8\:[\,#Q0P==HK9KLN;,8A38T=1'P>
M1H`;/G(F27Q8@\4<("8Q>^,"!0D<1'@L:;HL9[<<0G4K8JX]AN@G4(A*C>I2
MA,I@FNL@,4AVJN\,#Q,&"@\``0(!`@,'"0H``0$='A[_!`0;&QL3$Q,0$!`+
M"PO___\6KVV*````0'123E/_____________________________________
M______________________________________________\`PGNQ1`````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"L241!5`C7;8_'$L(P
M#$1WZ+T30A$U!H)CXX2.@/S_7V'#B1ETTM/.KB2DKI@#YD\'1[&24JJ8O_QH
M>PLBFGKGIV,>;&8G(<1ZOKNRY3@$(JUU!(1Q"E8$:&.,!D@Q6'8;/9,DB:F7
M6I(1R'*FN+H\+_O</2\#JS<+E<,MN8VJV9K560W[$:P?T=CY;3X)V'P(<ODI
M+[?4\87?H>W2[;>#<')\'2>AQ7_W__SW!L,%)@UW+'T1`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]E;G)A9V5D
M+G!N9P`````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`S-``Q,#0Q-S,V,S`Q,P`P
M,C,V,#4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4`
M``#___^G`0+]`@.U`@/X!@D$"A,<1X0P==H.(C\/)$(($R,N;,8<0GD6-%\D
M4YDF27P/%1Y`2UL<("80*4PQ>^,C5Z`/)40)%B@7-V0L:;HL9[<,'#(K8JX+
M&2P]AN@G4(@G3X=*C>H\<[\\<KXJ1FM@FNL@,4@O1V=VJN]47VX;)S8+$!8.
M%1U&``!%```R```P```L```D```7``#T]/3FYN8@("`?'Q\;&QL5%14*"@H(
M"`@#`P,!`0'___]HA0-;````0'123E/_____________________________
M______________________________________________________\`PGNQ
M1`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"I241!5`C7
M54]9&\$P$!QW$92JHQ&-H%'WS;KZ__^5I'UAGW9VOCD6B1TBCRC=8)&60@BI
M*</D<F:'NV0QN6".[_L.@SD@T1R]4"D55L!U`I)-C*=1%,W&:$@""2!_7L>;
M4_$`0?!$#:4M@'UA-Q*>X5M58!6W<>P/#4^2.:$R>A4ZS.B-/^N^WO@\!\SZ
MF_S@?D'N<;T%:;XY+)9UE#OSK)_M/_GM__??%]O;('/[A".K`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]F
M<F]W;BYP;F<`````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4T,``Q,#0Q-S,V
M,S`Q,P`P,C,S,S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````
M8%!,5$4```#___\#!@<<(R4XHKLL:':.TN,]N]<[L\X)&Q\TDJ5IR^$UGK`U
MFJT&$1,XFZTVE*4WEJ<M>XDM=8%5R=\B0$5^UN8;&QO___\`````````````
M``````````````"`-O9T````&7123E/_____________________________
M__\``30*MP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```!T
M241!5`C798]+$L,@#$,UP10"H4W+1]S_I,6P:M'*SQ[+,KJ*-.2LH%1S""%7
M+J9-HDJ6RK27>.><EVLTT&L2H)0"2*H=S.*!&"/@)1,,XDILK<7B)!!F\6.Q
MV>:Z_SHP])[[ZO_\#/_[G/[;_?]\6_Z?_[X'"PSQ[U@5Y`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O;6%D+G!N9P``````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,C<`,3`T,3<S-C,P,3,`,#(R-S0S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````/````#P@#````#`AE>````&!03%1%`@("_O[^
MHP<$_D@^WPD"L!H5VBHCO@@#[Q,'I@\-[2@?RB`9[AX6_#DO_FMGL`<#3@8"
M5C8N_EI1&AH:VAL3_GYZPA,-_BP@_`X%T@\'LQ(-RR<BNQ\:_AT1S0D$````
MR=,R5@```"!T4DY3_________________________________________P!<
M7!OM`````6)+1T0?!0T0O0````EP2%ES````2````$@`1LEK/@```)5)1$%4
M"-<UCXL2A"`(11FS-(WPT:96MO__ETNZ7889#LS`!;XLZ&KED_,\'BSH#&*\
M['G:G1YHZ/V"VGMN<,S79)*O/NO"Q&,[(:!/D#;%6\5A38UA#;$N-[2YP6']
MK)ATY],@#B&D^O*4HW,N2DEL"N@J,=>:9530[ZNR+5K+N]WG!AU[*;?J_IYW
M!!$)^/M_'VS5#W"F#=3A8<F6````@W1%6'1C;VUM96YT`%1H:7,@86YI;6%T
M960@1TE&(&9I;&4@=V%S(&-O;G-T<G5C=&5D('5S:6YG(%5L96%D($=)1B!!
M;FEM871O<BP@=FES:70@=7,@870@:'1T<#HO+W=W=RYU;&5A9"YC;VT@=&\@
M9FEN9"!O=70@;6]R92X!55-34$--5#T`.A@`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O9G)U<W1R
M871E9"YP;F<`````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-C$`,3`T,3<S-C,P,3,`
M,#(T,S8W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````&!03%1%
M````____^OH`[NX`UM8`TM(`R,@`Q,0`N+@`BHH`?'P`;FX`:6D`/#P`*RL`
M%A8`$!``!`0``P,`__\/MK86__\?NKH7__\Y__]5"PL$$A('____````````
M````````Q/=7<````!QT4DY3____________________________________
M`!>RXM<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````@DE$
M050(UV6/RQ;",`A$YR38/&PTM%*B^?__M#1VH;+BPID90+=BKLQ'!Z.28HRI
M\&#.@:Q"9F/.$WGGG*=I'Z"70("(`!1*!R?R@*H"GA*#(SG1]FPJCB*C#GX-
MKN>^-=WNEWUO^E5V_;;,IC=_MXH\ENOA?^;?YD_^[WU_]W_]]P8('0T69"N/
M:0````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V=R:6XN<&YG````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-S0U`#$P-#$W,S8S,#$S`#`R,S$T-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````#P````\(`P````P(97@```#`4$Q410```/___RL!`A@!
M`R4##`<!`Q8##`0``@(``1L$$:(PVH\LOXPKNY0NQI$MPG\GJ7HFHW\HJLJ(
MZJ<QXX@LNH<LMX$KKF8GB%\F?+1*ZKQ@ZSH@2,5V[R(<)O\``!@``!(```@`
M``$``!L;&____P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$W^BA0````E=%).4___________________________________________
M_____P`_ST)/`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`(U)1$%4"-=EC\D.PC`,1$>L)<502+,G97'^_QN)&W%`S,G/(]MC5!%S85XK
M""5GK76).[,W)#*>A=G/I+36BN;60$V&@!`"0"95L",%Q!@!18[!EG2(.><8
M-%E&Z7SO7,0_HNL]-K_-[YXOP<=)YMO^R[!=EF4SC+)?[I_WS3[<^OTUWW6:
MOOG^\O_\]P&SPA2-RV[AZP````!)14Y$KD)@@@``````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V5M;W1I8V]N<R]H86YG;W9E<BYP;F<`````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#<U,``Q,#0Q-S,V,S`Q,P`P,C0P,34`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M``\````/"`,````,"&5X````P%!,5$4```#____.7`C_<@K'60A9*`3H9PO6
M70S+6@PL%`.V5`[_=13@9Q*M3PXQ%@2>2A`1"`*/1A);+0W_?24B$04:#00&
M`P'/;BJR7B3_AS3^AC33<"O(:BDP'`[_EDP[(Q+_K7(H'QG:70S46@PC#P)0
M+1;_HF4$`@$;&QO___\`````````````````````````````````````````
M``````````````````````````````````````````````#WY:>&````*G12
M3E/______________________________________________________P`R
MJ/!<`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```(M)1$%4
M"-=EC]D6PC`(1#E&210UQKKA$MMJ(OG_'[2D+R[SQ(4S#$!1B70BM0*EY)US
M/LG($BRJ;!!E"?UL,E^NI\_'T("2+*[V5SZ^%FA3`?%H=I=;O)^V!KV`.*1S
MS#E')G0"W<`<<SMR5^?\,5?_!E2'ZM?]U#!S0W6_YJ,A(H-]S?^][^_^K__>
M76$5V_<$N#P`````245.1*Y"8((````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O:&EP<&EE+G!N9P``````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-C$`
M,3`T,3<S-C,P,3,`,#(S-#8T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#````
M#`AE>````,!03%1%````____`0$`#PL"/2D``P(`GVL!FV@!EV8!^*0"[9X"
MU8\"SXL"MWH"=DX!IG`"B%H">E(")QH!^K`?43D*_K,@XZ`=D&82AE\17D(,
M'Q<'_;L\]LINB%@!QH("PGX"EF$".B8"%0X!TX\.Q84-RHD.>%PH_L16=%DG
M]+Q3(!<(`@$``@("____````````````````````````````````````````
M````````````````````````````````C#/L+0```"YT4DY3____________
M________________________________________________`(*/<U4````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````D$E$050(UV6/VQ8!
M,0Q%L]2M$Z5%W,I4&8I)___W]/)@X3QE)UDY)Q"SF`5SJ2"3UTHI[;DR&X=9
MSG!F-BTV4LH&V]2`.#K-AH/U9M_/\7R)P/!1OV1@A7+W>CSOAZU$Q2`2KVPX
M!DN)19F3#:%RVM<('5EKZ0:H&:)W"[@240<3YZO_M%P?5__??'_YO_Y[`],U
M%SD3FHW7`````$E%3D2N0F""````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAI<'!I
M96=R:6XN<&YG`````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#$V`#$P-#$W,S8S,#$S
M`#`R-#,S-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`4$Q4
M10```/___P$!``\+`CTI``,"`/BD`NV>`M6/`M&,`L^+`LV*`LF'`K=Z`K=[
M`K9Z`J]V`G9.`8A:`GI2`B<:`?JP'U$Y"OZS(..@'9!F$H9?$5Y"#!\7!_V[
M//;*;HA8`<:"`L)^`I9A`CHF`A4.`7A<*/[$5G19)_2\4R`7"`(!`!8*`"`,
M`!H)``\%``@"`"D)``4!`"@#`#H"`/\``/H``/4``"```!<```$```("`O__
M_P```````````````+D!T?@````\=%).4___________________________
M____________________________________________________`+N(ZZ<`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````GTE$050(UV6/
MZQ+!,!"%=Y1TJ;BD[I1&*.I.ZK)Y__>2M(PQSJ_]]IR9/0O&B<@CRB=PI`3G
M7"@JF$*)3C(DQQ3&Z#/&?(SM`DQE5BN7>H-QVL;YP@#!5VF'@#BRT6:U7DZ&
M##F!9[D;)=,DZEOVG']^QY^!]4G@Z7'3F<[N.Q0$1LGJ]J*UOAX"J8K[]:--
M[QO%_;Q?L]7Z]/OK__/?"SY]'4##'%AD`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS
M+VAI<'!I971O;F=U92YP;F<`````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#$U`#$P-#$W
M,S8S,#$S`#`R-#8W-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@`
M``#`4$Q410```/___U4,&R4##<X`4K4`2/\"9?\#90$!``\+`CTI``,"`(M=
M`?BD`O.A`NV>`M6/`M*-`L^+`K=Z`G9.`7%,`8A:`GI2`B<:`?JP'U$Y"OZS
M(..@'9!F$H9?$5Y"#!<1!1\7!_V[//;*;HA8`<:"`L)^`I9A`CHF`A4.`?VK
M$1P3`A<0`WA<*/[$5G19)_2\4R89`R`7"!<.`P(!`"82"1<*!QP*!UH;%#\0
M$`("`O___P```````````````")*6>0````\=%).4___________________
M____________________________________________________________
M`+N(ZZ<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````GDE$
M050(UV6/YP[",`R$+7:!$$,@98]"0UAAE0+.^[\720M"B/OE[VSISF"]B`*B
M;`)/6@HAI*:<*53HI4+R3&&,G#'&,78&V,:J4Z\-Q[.DB^N-!8*ODCX!"633
MR_%T6$P8"H+`\2`R2Q.-'`?9?A09D[.[E\C/^WF:7G<<)8'5"MGV5JG>6ZCT
M)_]1*A?:>7[6K_DL]M[]_OK__/<">=D?;&>7%E\`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO
M=&EC;VYS+VAU<G0N<&YG````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S8R
M`#$P-#$W,S8S,#$S`#`R,S$W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P``
M``P(97@```#`4$Q410```/___P8"!P\$%!T()Y,KQWXEJJ(PVH,GL)0NQCD2
M3!(&&`,!!'XTHR`)+'$AFA@'(:<QXW<CHA8''H@LNH0KM8<LMX$KKH0NL1<(
M'X@PMH(NKFPFD3X64V8GB%\F?+1*ZI4]PI(\OHTZN+-*Z;Q@ZRL6-B,2+#H@
M2,5V[P@%"B(<)@X*$1L;&____P``````````````````````````````````
M``````````````````````````````````[Z[C\````O=%).4___________
M__________________________________________________\`6J4X]P``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"0241!5`C798_)
M$@(A#$13;AAW=`178%04Q/#_GR=ARH/:I[RD.IU`9A$EHEH!4S!::Q.H8[(*
M6<H2,]EF,AX,%Z/-MC0@!X7+Z=5=9FM4(0,9%/OVX>_SLT!#0!KES<=G]$ZB
M)DB%G8^OCE.=%XZ?.?L//2C:53_O[Y^<<\=5W<_Y**24`IN:_WO?W_U?_[T!
MGT,:S4!/FXT`````245.1*Y"8((``````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]I;F1I
M9F9E<F5N="YP;F<````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,W,``Q,#0Q-S,V,S`Q
M,P`P,C0T-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@````\````/"`0```"1WUW!`````F)+
M1T0``*J-(S(````)<$A9<P```$@```!(`$;):SX```"<241!5"B1A5&Q#<,P
M#`O0K2]X\0]^I)N/\!1DZI[%:[8>X`<Z]3N65.48&0J#@$&+HB3+"Y:.@(`(
MG2-V2@D9Q9#)>XJ+#ZQXGEAY_R6XN#&XHQIV\LT3*"=SJLS+(*8*27)@+SD5
M;`8Q5<CT4RZDE:Z&MZ&15\:*Y'B1/Q<Y3MV]]WWL`K?1NT]><?CDAWE]\NF[
M)UN;[OS_CWT!`)(B%]4D2Y<`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O;&]V92YP;F<`````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$P,S<`,3`T,3<S-C,P,3,`,#(S,34P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````/````%0@#````KD5$A0```,!03%1%````____,>,Q
M,-HQ(I0C(9`B+L8O))LE(8TA+*XK,KHQ,;4P)GPF2^I*8.M@B.J)'"8<+KHL
M+K<L-<(S*(@G(4@@=^]V_0``^@``]@``]0``]```\@``\0``[```W0``VP``
MUP``TP``T@``R0``O0``O```NP``M@``L@``GP``E0``C@``@P``>@``<@``
M+P``&QL;____````````````````````````````````````````````````
M````400<E````#-T4DY3________________________________________
M__________________________\`<9Z]C@````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"Y241!5"B19<[;3@,Q$`-0*PM#0W?"-DV6>[D5
MRJ5E=OS_'\=#6H'HXY$MV2!)N@_N)$F0]%IBC*5ZL_=91$1R[R3H_4*Z$$(G
MB]X)UBR`J@*2*^%%.B"E!'12'!XE:!K',6F0Z!B:+YJ'H]R+8*XI)3V'%`=K
M/L-25><XS;7MSP``)VW__[^C_R3=;6>T3]N;]G+Y8=O;5SOXX>K^\?EN/>U-
M>[NY7GU-ASYIF]73Q%_S^WWB7]-(\@>9\24"'H.1@`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O;7)T+G!N9P``
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$U,3$`,3`T,3<S-C,P,3,`,#(S
M,#`R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````/````%0@#````KD5$A0```8!03%1%````
M______P``0$`_^0`_>,`_.$`^=X`\]@`V+X`UKP`T[D`QJX`Q:T`OZD`LIP`
MJY@`IY$`GXL`E($`B7<`;V$`:5P`8E4`1#L`"`<`;E\`:%H`64T`0#<`/#0`
M-"T`%!$`&!0`&Q8`&A4`&Q4`&!,`(QL`#PT(0BX!#PL")1D`KW0!^*0"[9X"
MX)0"U8\"NGT"MWH"MWL"MGH"M7D"KG0":D8!IF\"B%H">E(">5$"7#X"L7@%
MLWH'_K,@_;L\!00"!@4#CEP!B5H!A5<!YY@"QH("PGX"JFX"@E8".B8"+Q\"
M_:L16#H&V)8:'14&&1,(_L16#0@`?DX!DU<!@D\!7CH%"P@$8SL)`@$`3R<%
M-A@`F"L`#`,`%A86"`@(`@("____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````O&*Y*0```&)T4DY3________________
M____________________________________________________________
M_____________________________________________________P`05I*J
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```/1)1$%4&--%
MD.=2Q#`,A'="+T<U<%0#H042S%$32DP]@SE*Z"6`_/XO@>/,S>T/K;X9:78D
M&"?X\,O&5;]@O\4+6)X'FDQZ;7'I\^;VM&0ZNMY>F=S=.C^D@BFY7/]YV;P"
M+A(R@%;/&W=?]Q]O^]^O``B(`"FE<RHX!+(L<TX(:@A3F9UE,@U1"T".W]L>
M'=OY6$2-U.ZGC4C$!*.5L(M6H5#:Y=?%;Y[GJZ)>Y/->2M3)P]/?L4JHFX./
M]I&.=P[V8DV=@QQF8F!XAB@@XKQ_MKBG6ND9YU8=E:GRWKDAQCS&1JK-?[`Q
MS^MBTZW_&-;.R^8?RIE'_/_Q\M@`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<'5N
M:RYP;F<`````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,3$`,3`T,3<S-C,P
M,3,`,#(S,34P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!0
M3%1%````____"`(%`P$"#`,(&`40XS&9VC"231$TE")DD"%AQBZ&FR1IC2%?
M+PL@,@PB&0817!Q!?"982Q<UZV"Q=3!84"$\ZHC`)@@:WS"700XLNBR!MRQ_
MKBMX<!U/PC.(NC&"M3!_;1U-B"=A=B)4<B%1ZDJHU4.9.1(I*0T>2"`X/Q\R
M[W:^Z'.YW6VPW&VO12(W)APB!0($`0`!&QL;%145$!`0____````````````
M````````````````````D)MTOP```#AT4DY3________________________
M_________________________________________________P`[7!'*````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)Y)1$%4"-=EC\D.
MPC`,1"V6%#!K"6MBH`0"A+*T-?3__XRDB`/JG/PTTG@&RB#FC+FZ()`S1&0<
M?YECC4$ZYL"OB<)("!&AFKX]YXUA9V.MW:]'15X"'\;P4^O(P(1+**[W9[-H
M(S%DA*O+[+9XS,\"*0N^.,DT3:45P6>#D%@II=T!&H;2Z3YL?7X"/>W\/X[5
MH$KO*E^HWJ_6_V_?![()'4+,:B3Z`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O<'5N:VUO:&%W:RYP;F<`````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$T-S<`,3`T
M,3<S-C,P,3,`,#(T,S<W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````/````%0@#````KD5$
MA0```8!03%1%````____A$1="`(%`P$"!0,$$0\0KSEX%P4/#`,(&`40XS&9
MAAU:XC*8VC"231$T"0(&-0PDQBZ&3A(U+PL@(@@7,@PB&0813!,T(PD87!Q!
M?"98=B14=2137QU#2Q<U=R55="]7ZV"QSE2;=3!84"$\ZHC`)@@:WS"700XL
MNBR!MRQ_G29MKBMX11$P<!U/Z#VC;1U-B"=A=B)4<B%1?2=:ZDJHYTFFU4.9
M.1(I*0T>'`L5Q%"42"`X+Q8E/Q\R[W:^Z'.YW6VPW&VO12(W)APB$00,!0($
M`0`!!@4&`-,.`*@+`*@,`*8+`*4,`*`+`)T+`)L+`)H+`)D+`)@+`)<+`)8*
M`)0+%C`8&B(:1X,X.#HN`@$!D69F&!<7Y^3DTL_/GIZ>&QL;%145$!`0"`@(
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````YW/!PP```&=T4DY3
M____________________________________________________________
M____________________________________________________________
M________________`!06NG@````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````Y4E$050H4U7.5S?$8!2%X1-&#8.C&[V;^)0/44.4F#BZC-X/
M]O__"2XB:\6^>==SMPGIY"XMI3F3:\G[5*[REDM)Y";G<TDD^>>J5'.^D(?'
M^\P:R&V-L<^:6DN>/#4P>R4%"%\#97YM==TBET>^0:C4=K4M^KZ_/-<35T"Z
MTDO9FE:5U/`,Q7L'1X6XF8U29'AV:W)_^G!JTV43D1IV-\;#,)Q8Z^@T2FJY
MN+2^,[;]4N_T624$'K?TG[S1.WWL!B#H4'?AY],AAXX'%03H\'QC'5'[PJAF
M_ZTQQ@9__P&H1JH`@%^/:E3KHF2_2`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O<'5N:W1O;F=U92YP;F<`````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S
M-#,`,3`T,3<S-C,P,3,`,#(T-#`R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#
M````#`AE>````8!03%1%````____S@!2M0!(_P%G)`$/5`0F/@4?5P@M&P0/
M%@4-"`(%`P$")`<6%08.#`,(&`40XS&9WS"6VC"231$TQ"V$:1A'QBZ&@1Y7
M+PL@,@PB&081(PD87!Q!?"982Q<U%0</ZV"Q=3!84"$\%0D0ZHC`)@@:WS"7
M00XLNBR!MRQ_KBMX<!U/Z#VC;1U-B"=A=B)4<B%1ZDJHU4.9.1(I*0T>2"`X
M/Q\R[W:^Z'.YW6VPW&VO12(W)APB&0<2!0($`0`!&QL;%145$!`0____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````AL1V1@``
M`$5T4DY3____________________________________________________
M______________________________________\`LNZQ.`````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"K241!5`C798_)%L%`$$7K$%.,
MK5'&$'/2"$'$$$F1__\FW<3"\59USUN\6Q"K$`5$[PL4>8X0PO'HPV38J&(;
MI/@QL)`SQCA:PZ?DL-AIK%S7W2R[41@#;7OP375'0`+G$)TNMU)40T$0"%P<
MQ^?9=7)@*`+5L[WI^[[I,M63@[P_FNIZY<[1(8@]&]FZK&F%.MJ>W"-#[N=3
MZ6S3DD*)7SN7:25^?_X__[T`1/PFK[I<]78`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O<F%S<&)E<G)Y+G!N9P``````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`W-S,`,3`T,3<S-C,P,3,`,#(T,C(R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````/
M````#P@#````#`AE>````,!03%1%````____S@!2M0!(_P%G)`$/5`0F/@4?
M5P@M&P0/%@4-`@`!)`<6%08.#P,*EB!EXS&9WS"6CA]?VC"2P2N!Q"V$:1A'
MQBZ&@1Y7HB9NE2-E*0H<(PD8?"98?BA:%0</ZV"Q%0D0ZHC`(`<6NBR!MRQ_
MKBMXZ#VCB"=AZDJHF3!NYEZN2"`X[W:^)APB"P,(&0<2#P0+&QL;____````
M````````````````````````````````````````````I0X<_````#1T4DY3
M____________________________________________________________
M________`$M7(F4````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````E$E$050(UV6/V1:",`Q$YRANN*%5XX86I;5HJ1K^_]^TK2\>\I2;G,E,
MT/AB=LRA@R=KM-;&<F3.U6%/NZO*V3/G):W&\]F2RN\`C54$W)^G-TC9!FQ(
M`/(A`4&&P9JR2M9U+:N,-,-%OD1VK;W7'\]%FDY?0>_O9[=)DHP6X7[P%\-.
MM[^._CX?;0>]S2]?*__??Q\$UQ_#?3."\@````!)14Y$KD)@@@``````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC
M;VYS+W-A9"YP;F<`````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S4U`#$P
M-#$W,S8S,#$S`#`R,C<V,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(
M97@```#`4$Q410```/___P,&"R=BMB9>KB5;JC!UVA<W90XA/2YLQ@D4)0($
M!R9)?(BOZAP@)B9@L0<2(3%[XP(%"2QINB%.BR!,ARQGMR!+A08.&2%-B"MB
MKBYFL3V&Z#!IMBYDKB94D2=0B$J-ZF":ZR`Q2':J[P0+%!L;&____P``````
M````````````````````````````````````````````````````````````
M`````````````````````````````/SU"T$````H=%).4_______________
M_____________________________________P"^JBX8`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```)))1$%4"-=EC\D2PC`,0S4L`4,I
MA$*`L&5#_?\_Q$E/##KYV6/)QEA%]F2K4"D'[WW(G)C=;24BZTO'RNQ.QZ6U
M=C$[:P-C=M?](\;XF&]<'L$@!D@I`48"02\6**4`5CS1*\=4=B5%Y;[-E<O$
M;/O/+53WMJ_^\GFK_^L@U5_S!S&:;V1H^=IP4N6F^_[N__GO"ZGI%LSB=6]G
M`````$E%3D2N0F""`````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]S:&]U="YP
M;F<````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<W-P`Q,#0Q-S,V,S`Q,P`P
M,C,S-3<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4`
M``#_____<@KH9PO*6`NX4`K670RN30K+6@RG2@K_=10_'04F$0.>2A"/1A(6
M"P/7:1_39Q\:#03_AS3ZA#/Q@#';="W_EDS_K7(H'QG:70Q0+1;_HF45!@$7
M!P(.`P`:!@$;"`0/`P$(`@$(`0`H`@`H`P'_``#Z``#U```Z`0`@```7```Z
M`@$;&QO___\`````````````````````````````````````````````````
M``````````````#%N-KI````,'123E/_____________________________
M_________________________________P!BI=!X`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```)Q)1$%4"-=5C^D2@C`,A'<:K:5:/!`1
MBO=1O,+[OYU-F7'&_,J7G4TVZ*68:^;40<@[8XSS/##GFJ1TSL*<-Z2LM8J:
M.$#O-4U7ZZ*<STC['NQ(+8$*6"AR##9D"Z`%"DN&40M7[;:MA.NDEQ<`ITW2
MQ;^_AQ`^Y^27_>]'Z$+W2OOE_NX6]>=AN!\'HVOT'\=#OI1_DF6__'__?0%`
M*A;SZR3)B@````!)14Y$KD)@@@`N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<VUI;&4N<&YG````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`U-3,`,3`T,3<S-C,P,3,`,#(S,S$V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````/````#P@#````#`AE>````&!03%1%````____^OH`[NX`
MUM8`R,@`Q,0`N+@`IZ<`GY\`FYL`F)@`BHH`?'P`/#P`$!``!`0`U=4-S,P,
MQ\<,__\?__\Y__]5"PL$$A('____````````````````````````LMYVB0``
M`!IT4DY3_________________________________P`4(@#:`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```'Y)1$%4"-=EC]L2`B$,0S/0
M!2]<HEM0_O]'I3+[X)JGGG:2MA@FLI+?"D8EQ1A3X6+F(*:0:<R\B7?.>=EF
M`Z,$`505D%`&F,0#K37`2R(8Q6GKK][4223JXO?B>LS[,9]^[#K]^H3Y9_X%
MCYF_XV;YMO\.TW7M/]_W=__/?Q^PF`Q'Z0PYH0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+W1I<F5D+G!N9P``````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,S8T`#$P-#$W,S8S,#$S`#`R,S,Q-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M#P````\(!````)'?7<$````"8DM'1```JHTC,@````EP2%ES````2````$@`
M1LEK/@```)A)1$%4*)&%D3$.A"`014TV;K%7H.$.7&0[#D%EK.QM;.T\`!>P
M\G9__\R"A,),?F(^O/F,#`.&*@<'#_FVO1L%1"15I*\E!7XQ8;DU<?TO*'#F
MYHI-M=+/I8`X:'+#CD.UT\L)0;!C+TE*EQ$9;W5R0F2>.&GV(#I5F5[R2;#O
M\-5A;Z9K[T^;!5ZMM_'GYKV-J9DS?WZQ'V'*(P[=4^K:`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I
M8V]N<R]T;VYG=65O=70N<&YG````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<T,P`Q
M,#0Q-S,V,S`Q,P`P,C0R,S<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,
M"&5X````P%!,5$4```#___]'$!XA!`[.`%*U`$C]`V;\!&8QXS$PWS`PVC$M
MQ"X8:1DNQB\>@1\LKBL)(PD'&0<F?"9+ZDH'%0=@ZV`)%0F(ZHD<)APNNBPN
MMRP_Z#THB"<A2"!W[W8)$@<4%PT/#0D1#@D/#`DY)1PM%A4;&QO___\`````
M````````````````````````````````````````````````````````````
M```````````````````````````````U\\"@````*'123E/_____________
M______________________________________\`OJHN&`````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"(241!5`C798_)$@(A#$2[7",:
M41!E$'#<PO__H0)>K,DI+ZGN=%!JB7B1UJ%2BEKKF*2SF,"U@I'*8@961*1X
M^`Y04F#`6@MP2`4260'..4!Q%(AFLB[G["RQ%OC.E\Y^LJ_ZP^E\?]Z.35_]
MZ3JNUH]-\^_W7XOE;-OOMWS[]WSWRS?)__??!R.B%>9GE'\=`````$E%3D2N
M0F""```````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=F%M<&ER
M92YP;F<`````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-3$`,3`T,3<S-C,P,3,`
M,#(S-C4P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%
M````____"`P1/7>W.G&M.6^J.&VG-FFB+%6$+%6#&C-..G&L.6^I+EB(*4]Z
M#ALI2(+"-UV)4(C%%"(Q#!0=0&B33'>F3GFI:)C-9I7)8I#"78FX+D-;&B8S
M>*/2C+'9EK?<P]7I$2$R"0\4`P,#`@("____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````UE<]VP```"=T4DY3____________________________
M______________________\`@U:7V0````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"/241!5`C798_)$@(A#$0;,XB@3A`WW,!!Y?\_42+E
MP;)/>4DEW4$5,1?F3P4A9XTQUG%G'C6)],C"/`[D0PB>AM9`=9JVCU,\SW:D
M705;\@<@`4=/EL&&0@0R$`,91A%.^9Z3<.GSE'-GEGU\)?OM_OJI;I>K>BWD
M?O-?;E0;JGWW;XWYU.)-JY[O+__/?V]S[`_V20QX2`````!)14Y$KD)@@@``
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W=I;FLN<&YG````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-S,V`#$P-#$W,S8S,#$S`#`R,S$V,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````#P````\(`P````P(97@```#`4$Q410```/___PX1"@8(
M`V2(':?C,:#:,'VK)FV4(FJ0(9+&+G*;)&B-(5]\)KSK8&R'-[OJ8(VZ+(JV
M*XJW+(.N*P\4!93",XZZ,8JU,%9Q'FF()[7J2J340SM((,CO=@\3!B,F'`D*
M!1L;&____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`)59<T(````D=%).4___________________________________________
M____`%@L#0T````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MATE$050(UV6/P1+"(`Q$=U10HZ`5JI5(Q?#__RB1Z4'=4UXRFTU052)%Y%-!
M*:<88\K265P@57"B+.Y"UAAC:6@-U!S&S?WY8(!"KI!$VW%].GO`4A)(),-^
M?LV>#45!Z;SJ7);YO,R;'Q-[[_D&];?]!UR9><)>][?\X0C5KN?_WO=W_]=_
M;TJN$]`$(*HP`````$E%3D2N0F""````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V5M;W1I8V]N<R]W:6YK9W)I;BYP;F<`````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#<W-0`Q,#0Q-S,V,S`Q,P`P,C0P-#,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M``\````/"`,````,"&5X````P%!,5$4```#___\&"`-DB!VGXS&@VC!]JR:-
MORR*NRN2QBZ/PBU]J2=XHR9]JBA??":\ZV!LAS>[ZF#(ZHB-NBR*MBN*MRR#
MKBL/%`56<1YIB">UZDJDU$,[2"#([W8/$P8C)AP1#0,:$00$`@`6#`,,!@$'
M`P$E#`,G!0$Y`P'_``#Z``#U```@```7```!```;&QO___\`````````````
M``````````````````````````````````````````````!,Q,)8````,712
M3E/_________________________________________________________
M______\`'YI.(0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"9241!5`C798_9$H(P#$4SVHI1!!5;;"T6=XM+^/^OLZ'C@^-]RLEZ`SV+
MR!,-$3`YH[4VCA)3H9"E"F*F8H-2""&QB@GHG:K'V_W.`J!R/9#!23U:KDH`
MB8:`-`I;-DU36H&:P"=>)_9</T+2.XOU.']]/4(7NN>!Y^/^67L+(=S/&>^/
M]ZOI)7:?%NG^X&^>YU]_?_Y__OL`>#D9#GOPL78`````245.1*Y"8((````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O=VEN:W1O;F=U92YP;F<`````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-S``
M,3`T,3<S-C,P,3,`,#(T-#`P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#````
M#`AE>````,!03%1%````____3Q`>(P0.S@!2M0!(_@-F_@1F!@@#9(@=I^,Q
MI-\PH-HP?:LFD,0M36D8DL8N7X$>&B,)7WPF$!4'O.M@;(<WN^I@R.J(C;HL
MBK8KBK<L@ZXK#Q0%L>@]5G$>$QD':8@GM>I*I-1#$14).T@@R.]V#Q,&(R8<
M$1(''A<-%`T)&`X)%`P)324<.!85&QL;____````````````````````````
M````````````````````````````````.44B/````#)T4DY3____________
M_____________________________________________________P`-4)CO
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)-)1$%4"-=E
MC\D2`B$,1%/N(FH444<8'5!&W,/__YPL7JS)*2^I[G0@I"+R1+F#1,YHK8VC
MPB04IE*"$I,X(&>,<:SB`()3]?1T/5L`5"X`&9S7D^U.`G`T!*216=FVK;0,
M-8$OO"_L._NHY^O-Y?&Z-5D?_9$=[Z/Q<Y;]X_T*^7LP["W*_9QO]>DO?_DZ
M^?_^^P(E_QPY#,>$^P````!)14Y$KD)@@@``````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W=I;FMT
M;VYG=65O=70N<&YG`````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S<P`#$P-#$W,S8S,#$S
M`#`R-3$S,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`4$Q4
M10```/___\X`4K4`2/T#9_P#9R$$$$@/*"X4(A`+#CPC,Q(-$0\,#Q46&3W,
MM3"@C@83$0L@'0H1$(_BU3_5NS[1MR:`<#JZI#FXHB9Y:Q]B5S>LES6DD$K:
MP"1J72Z`<2QU:5;=Q4[(L@<2$`@4$FO@S&O?RSZ!=B-%/W_ETC>OF#:LE0@8
M%0,(!PH4$ATE(QL;&____P``````````````````````````````````````
M`````````````````+<?XF`````R=%).4___________________________
M______________________________________\`#5"8[P````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"3241!5`C798_)$@(A#$13[BN.
MBD8%!491&!<R__]SLGBQ)J>\I+K3@38542#*'21R2DJI'!4F+3"5T)28]!,9
MYYQA$P?0.E'M+]?:`*!P+9#"5?5^W"T`0T5`$KFQWGMK.$J"4'A;.'3V4<_6
MM\]BNGEE??1'?EX.AO-=]H_W&V2S7G]\*/=SON-D=/KEZ^3_^^\+0YH>*YO5
M=9@`````245.1*Y"8((``````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W;W)R:65D+G!N9P``````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#<T-``Q,#0Q-S,V,S`Q,P`P,C,V-C(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4```#___\'#!(]
M=[<Z<:TY;ZHV::(L58,?/%T:,TXI3WH?/%P.&RE(@L)0B,4P4G<,%!U(<9Y%
M;)=&;IEHF,UDD\90=9YXH])>?Z2,L=F6M]P!`@,1(3(Y6GT)#A,*#Q0#!0;_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```2OK#+````(G123E/_________________________________________
M__\`#=##<0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"/
M241!5`C798_;$H,@#$0S30'!A=ZB2+5:__\G2[`OG>Y+<F8GR89V%;``K2,E
M[ZRUSN-@!--WW/4F0!GA'.B2+E0K*GO#,XTRTLS&[P3'<=VF/&UK9`>"Y33D
M4DH>$EO04EER>98LE9?F2_.E^3I_>U/5H\WK_M-+1.[7ME_O<TPI13[N:SY6
M??/]Y?_Y[P/I\`Z3(#-VC@````!)14Y$KD)@@@``````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R\`````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`T,3<S-C,P,30`,#(P-3<T`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%F+G!N9P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-P`Q,#0Q-S,V,S`Q,P`P,C$V
M-C<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M___5U-7'QL<B(R-45574U=6XN;D`6P``.0``.``%8`40:A`12Q$==!T22!(A
M>2$951DOA"\UBC4XB3DXA#A"E$(R;S)&F48R;#)!BD$Z>CM)ETE0GU!/G4]0
MFU!7HU=3F5-2EU)7GE=;HUM>HUYEIF5JK6IAGF%MK6T?(!^?HY_S^//H[>C6
MV];2U]+T^/3H[.C,T,SV^?996EG0T=`0:`T;;!@[?S<07@4?9A`T<1\O:QF]
MPKHY:A9'<QE-;!)#7@-(8`E#5P`Z.CGGY^;$Q,/DX]*^MI(A(!VOG7*VJ(5]
M;4M:0Q5\937"HF&)=U*YI'L[.34R,2^^O+@P)A1-/2%E42R3>$:LC%*3>U"W
MG&RVG6^WH7C4NX[ERYN\IX+'LHSNV;%G7DZ^KI'DU\#EVL7`G%^[FF:ZH'9Y
M:E'9OY3JTJO@R:3*N)K+OJM.24(;%A#BVM!,249245#X]_?^_O[Z^OKY^?GV
M]O;T]/3JZNKEY>7DY.3BXN+AX>'2TM+.SL[-S<W*RLK#P\-/3T](2$A"0D(\
M/#PX.#@V-C8T-#0P,#`O+R\N+BXJ*BHH*"@A(2$='1T;&QL8&!@/#P\-#0T,
M#`P)"0D%!04#`P/___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"'
ME#XU`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,!)1$%4
M"-=C8,`".#D%I=651<TM.;AY!(0E9(%"7+SB:JI2UD[.CF9\0F)R\D`A?DD-
M324+.RL;!WL1&0451:"0MI&QH;ZWEVV@A[^[@8ZN'E"(F;&ROB$S(3^O*#>G
MK+*F`2A46N[*UA03G9B>&I]44<W4#!2JJFML"4F)C,V(RTZK-75C!PJ9N$R:
M.CW4-]PG((NUK:.K%RC4.64FP\S",+^(J.2"[KX)$X%"6C,89DWS#&YO+2D.
MZNEGF8S-.P"1LC`[PE*8EP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O86PN<&YG````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#0U`#$P-#$W,S8S,#$S`#`R,38W,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___]4U-L<Z._]G:`<!`,P``,@``)\`
M`'\``'8``%P``!@``+$!`:P!`<X#`\P#`U0!`4T!`8H#`]`%!<X%!<P%!;L%
M!6$#`\T)"8L'!ZL*"M8-#<T-#9`)";H-#=@0$(L*"D0%!;L0$,\2$H\-#5T)
M"68*"M(8&,\8&)01$>$='9`4%.0A(=0@']<A(=$@()T9&;0=':<;&Y(8&-@G
M)[`A(>XO+[(C(Z<A(;DF)MTP+[PH*'$8&/(U-;\J*L0M+<$L++LK*\<N+AX'
M!\HP,+(J*LTR,>$X.-4V-=(T-,\S,_<^/MTX.'D?'T82$OI"0MHZ.KLR,E@8
M&.=!0.`_/OQ&1NI"0N5"0OY*2N1"0H,F)NI&1L4[._]-3>Y)2>Q(2/]/3_Y/
M3ZHU-9@O+_Y04/),3/U14?Q04/9.3NY,3.E*2OM14?E04*TX./%04-1&1K`Z
M.M)&1NY14>M04+Q!0=U-3?975X(O+^Q75Z@^/OI>7NE96:E"0OUD9,=/3X8U
M-6(G)_ID9/AE9?]J:OAJ:NUE9:A(2+=1450F)AL-#7<Z.K1>7E`K*SHA(2X=
M'1@4%!`0$`4%!0,#`____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(0+</(````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````ODE$050(UV-@P`(X.0UC6ROS-,4Y1!1T[<)2
M04):06T]I7YJW,+R1N8!B;E`(46WFJ;V1E4A075;)Y^XG'B@D&4!2TF%_V16
MEPG1A9'I::%`(>:6<E\3)9Y)$_L:BE(S([R`0LW5(09R7!)=_2FU];DQ3*Y`
MH;H$4UD^7NG@WJJRXOA`=T>@4+ZUB@"[E$YG=W9'5JBW@Q50R$-#C$U463^Y
M(",SRLO9Q@PHI"?)QB^C;1Z>E!OCZ6IO88S-.P#?\RZ$Q<1]K`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A;2YP;F<`````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,3(`,3`T,3<S-C,P,3,`,#(Q
M-C8V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____P0$-P`$-R`H6PPT8A`H2TA@DSB<RWRLVJBHR[3Y)]4U7Y$E3XDA2\5%;
MX%EA]&1M#0'`#P/`$P?%'1+$(!3/,2;<*2&?.B_213KJ2#_654KT5DSH6U'S
M3D;,6E#H<&?V#0G!#0F_%A+'&!3")"#1,B[--C/?-#*X.SC#247L0T#05U3T
M4U#D4D_B6UCQ;6KS``#,`P/.!070!07,"0G-#0W6$!#8&!C2'1WA(2'D'R#5
M+R_N-37R,##*.#CA-C75-#320D+Z1D;\04'F0D+E.SK'1D;J3T__4%#^3D[V
M4%#Y5U?V7E[Z9F7W:FK_S'@#S'8'T'P(SG@)S'L)S7H/V(83UH$3P'02TH8;
MX8XCY)0DSX0CU(@EL'4CLG8G[IXUO'\J\J0XW),TQX@PX9P[TI$WRHDUL'DQ
MTI$\_+%)Y:)$NX(XQHL__K93]K%0UIE*\Z]7\[)>Z*M<P',0Q7@6Q'P@IVL?
MOW\NU9$Z^JQ(ZJ)(ZJ1+_[15^;%5Z*E8S```?P``S@,#T`4%S`4%S0D)U@T-
MV!`0TA@8E!$1X1T=Y"$AU!\?G1D9[B\O\C4UX3@X^D)"NS(R_$9&YT%!QCL[
M_T]/_E!0^5!0]E=7^EY>]V5E_VIJ____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MNV9DJ@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"C241!
M5!C3;8P[#L)`#$3]VTV02(,H0.(.'(++<`XN24<1":4`@?@($F)[V:WA5?;3
MS`#\@+"#:5W9NU=E*6P)H`[11S4E9B;&G(H2T3[FB9@(V1\"LXK24&63?Z)4
MU'IBCT&-A#E&'/5(4'NO9B41`MEH(-!Z[Z66I]CSE=7FU;0K[*K%"YN;)=T+
MW)\G/4A(5\'SZ%:*>8F%PX+1[3+OEO"'+TU+3MB/$M.*`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V%N+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`T-@`Q,#0Q-S,V,S`Q,P`P,C$V-S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____%P\;"P</AY.FOM+F+R^BPP\Q\
MA8D`?K(%@K,,?:P=C;PAF,PMF,4KDKPLD;HNC;8SG<<MB;$XH<LVF<!!I]-&
MK-1!G,%0O>A0N^=0N.)2N^5>O^5@P>=HQ>I;H\*JP,FJO\C6Y^X"@;(1C\`2
MB+86BK<@G,L?D+PJH<\FC[<LF,(QE[XG=Y8QD[DPD;8OBZ\]L=TWG\<TE[TV
ME;E!J=$^H,9"J,\[DK1&ILM.M]]2O^A-L=A.LME2MMQ3M]U8P.=7N^!7N=],
MHL-7N-UFP>1JQ^MNR>QRR^QQR>N_TMF@L+:KN\&UQLS6Z._%UMS3X^G8YNOI
M]_SA\/7:Y^OG]/C7X^?J]OJAK*_&Q\>RL[/4U=35U=38QL#GU]+VY>'=1"3-
M023C53CY;U/O<%?@S<G#'`#`(P7&)PC%)`G`)PG'-!BT.B;O7D+V7T;76$#T
M:4_6P;WIV=;UY>*J*16H*!7K3C6Q.RBO1CF_4$/.8E;6=FO/N;?^_O[\_/SZ
M^OKY^?GW]_?R\O+N[N[EY>7DY.3AX>'8V-C6UM;2TM+0T-#.SL[-S<W,S,S*
MRLK'Q\>_O[^\O+R[N[NPL+"GIZ>=G9V4E)1_?W____\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````".ZEOA`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"9LR8%L584I"3D5W;T=9<
M7P<2FCZYJ2$^*2L]LZB]I8&Q$2C$$1D>$<1<45::RQ08$AP6"A32<_%P%5+G
M%A;DT3*R<72P`@I9NCN)2`APZAKS.GM)65N8`(7<9,TT];7Y537LY3REQ44-
M@$+RMCIJ*EP*?&)LDC)VYJ:&0"%E;W8E1=;*JNH:%O\`/U\?H%![5U]?=UQB
M>7Y*0FO7A$E3@$(QO7T]G6G)>86IQ;']$Z.G8O,.`.B[,4OM]:VO`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O86\N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-#$W,S8S,#$S`#`R
M,38W-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___[XZ._]G:#\U-B(C(RLL+!\@'P<+`1,6"B(E`59736AL*VAL&(*%/FQM
M)I662A(2`']_!UA8%(J*.I*10C0T(4E)-5960F1D3A04$#HZ-5=744M+1E-3
M4#(R,3`P+S\_/HF$`WYW+\VO`%Q,#10/`-2="LR)`.^E->B')MMP%,U5`<Q&
M`=Q@(<Q$`\U'"<HD`,,>!<XA#4I!0,X0`]XD&+L*!=$0!\P``'\``-`%!<P'
M!=8-#=@0$(L*"LP0$,\2$M(:&)01$<<8&.$='>0A(=0?'YT9&>LK*]@G)^XO
M+Z<A(=TO+_(U-?4Z.K(J*N$X./@^/M<X.,DT-/I"0KLR,N`_/OQ&1N=!0?Y*
M2O)&1L8[._]-3=M"0NY)2>Q(2/]/3_Y04/),3/U14?M14?E04/104/%04.Q.
M3M1&1O975^Q75_I>7NE96?UD9/=E9?]J:O9J:A0)"2H@(#DP,$]&1EI04%E/
M3R`='6=>7FYE961D9%%145!04$]/3TQ,3$E)24A(2$9&1D)"0CHZ.C@X.#0T
M-#,S,S`P,"\O+RXN+BTM+2HJ*B@H*"<G)R8F)B$A(1T='1L;&Q@8&!(2$@T-
M#0D)"04%!0,#`____P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"94F[<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$
M050(UV-@P`*LK#QB"K,#G6PLK>W<_"*20$+.806YD>X&&J:VKMZAB6E`(?N`
MO/P$+V-='74SSZ#8U'B@D$\6<X:OH[Z*A;:6?U1*<CA0B*DH)]C%R-#<04\S
M.CTS+@0H5%UE4E*LIJ1:J2Q:45[&4@H4JFGJG\;!Q<G+P\==V]@JSP84JE.8
M.E-02)A?1$"F0;&C9P)0J&W*#(894F+BLG*2$NW=?1.!0NS3&69.F]354E_7
M+-W9RSH9FW<`^HXPOJO6VRX`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]A<BYP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-3``,3`T,3<S-C,P,3,`,#(Q-C<U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____U=35Q\;'_O[_[>WNZ^OLU]?8
MS<W.R\O,^_S]]O?XV-G:P,'"I*:G_/[_^_W^^OS][_'R[O#Q(J+,%65_(Z/,
M):3.)J;0)J3,**3,&69_*J7-*Z;.+*C0+ZW6+:7,,;#8+Z;--*[6-['8-ZS2
M)WF4/KGA0;SD/J_4/:[20[KA1[[D0['4.)*P,X.=-XNG4,?N0)Z\5,SR/Y>S
M5<GN2*C'6LSR5+_A1Z&_4+343[+23JW,8=7Z3ZW,3ZS*9-?\6<#A2J"[-W>+
M5;;45++17<7G7<3E9M;Z:MG\7;_>;=O_;=O^:=3V5JO';-;Y9LKJ6K+/8+[;
M<MS_<MS^<=?Y;LWK9;S8>-KZ=M;V;\OH69VR?MKW7J.Y?]OX<<+<9ZW$A^'_
M@]KU;[?/B^/_@=+L@]3N?,??CN/^C>'[DN/]B]GRC=GQB]+IF>7]\?3UY.?H
M3+'-3+#,4;'.V=S<T=34S,_/W=_?^OO[U-75S,W-V-O:N+NOP\6\K*Z3V]W"
MQ\BWM+5OIZ45@'\>I:0MGYY2S,S*Y^?FS,S+A8,'H)Y6X^'9Z>CE^/?W_O[^
M_/S\^OKZ^?GY]O;V\O+RZNKJY>7EX>'ATM+2S<W-S,S,RLK*____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/)+[#P````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``J2E]?T2(QVU%*3D5'3,
M/4.`0J)J3C$1;IHR8N+RZH:VWOY`(>?HW+S4\.*B0BNOL+B4S#2@$%\IOW!)
M66U=375!OH"@4#E0B)EQTK3I;:V=S=V3^_LF39T.%.J=T%XYHZ.KJ:5G`N/$
M*4RS@$)<;.P<G%4-C?7<+!6L/#-Y@4(Y\8%V-JY!44D96=GIR0FQ0"$+54D1
M"44-8P<?7W=K,R,]H)"NDI2LLK:I1W!H@(N]I8D!-N\``-+-,(\O#,.9````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%T+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#0Q-S,V,S`Q,P`P
M,C$W,#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____.)"7,Q,7BV]RDGZ#Z]?;&RLKW^OKQ]/3?XN+;WM[3UM;0T]//TM+.
MT='-T-#*S<W(R\O'RLK[_?WZ_/SU]_?T]O;IZ^OEY^?BY.3AX^/=W]_0TM+'
MR<G$QL;U]O;L\._&R<C.R<CS[NW(``#'``#&``!]``!\``#)`P/(`P/+!07*
M!07(!07'!07("0G1#0W0#0W3$!#.&!C-&!B0$1'<'1W''!S@(2'?(2'2(!_(
M'1W/'Q^:&1FD&QO'(R/&)27))R>L(2'J+R_I+R_,*2FO(R.)'!RX*"CM-37L
M-36[*BK8,C+#+B[',##*,C+>.#C=.#C6-C;1-C7.-#3V0D+U0D*X,C+X1D;W
M1D;B04'A0D+E1433/S_F1D;#.SO[3T_Z3T_B1T?[4%#Z4%#Q3D[U4%"V/S^N
M/#SS5E;834SR5U?`1T;O65GU7E[+3D[Z9&3J7U_H7E[;6EGY:&CS967W:&C[
M:FKN:&CX;F[N;&SE;&SX>'C6SL['P,#&O[_8T='9T]/*Q,3)P\/(PL+'P<'Y
M\_/X\O+OZ>GNZ.CMY^?<UM;3SL[)Q,3Z]?7JY>7HX^/EX."^NKKV\O+5T='0
MS,S___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```W\J>I`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])
M1$%4"-=C8,`"-#3M$BIR@DSTU'2,+;TB4T!"9A%E^=&V!FK:1N:NX4GI0"&/
MS)K:XC@G"QLFW]BLPO(BH!#KM/[NQN:&>N8ZEL[VCJX>H)"\"*>,@#"[(`^7
M(H<HIS0_4$A!3(I/6$Z(EUM"3%1<4E8)*,0VL;>EK56Y:9)*_Y0)4_LF`X6J
MLP,<'=R"D_-*JRI+"G(S@$*!IOKJNL96WE&I:3&A?I[.0"%K`U4M0W.7L,3T
M^!!_'W=[;-X!`&??+F(6^>(H`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O874N<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#4P`#$P-#$W,S8S,#$S`#`R,3<P,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___]=15/)L;?F8F<Q+4+(N.7XA
M*+HT/G<T.<II<+558["3J%@Z4(]GBY)GC\ZTS'-!=YE[GL^VVG)DAK"EP%Y(
MAL*TVZ&5NEA3;(9XP61>AE-'F(Z&PFQDIG-LJI^9TA0)?RPDCG)MP(B$R;JY
MQA$+@S0ODW5QQW1QPY.0U`P+AA02B144CQ\>D"$@EB4DFR\NE4=&JT)!GU!/
MO$I)J554P554O%=6O$=&ED]-GU!/G&)@LI^>S0$"@P8(AP8&A`<'AP@(A0D)
MAPL,APT/C@X/BPX/B!`0AQ(3CQ(2CAH:F!H:E1P=DQT=ER$BG"<GGR<GGB4E
ME"4ED!\?=BPLHS`PIR\PHC$QIS$QIB4E?28G?S4UJRHJAS@YK3(RG"LKA3HZ
MKS`PC3]`M30UE#(RCS$RC#\_LS<WFC8VED)"M#P]I41$MCX_H3L[F4E)NTA(
MN49&M#T]G$%!HDQ,O$U-O4]/OT]0ODI*L%%2P$Q-LU)2P%!1NDU-LE-3OU55
MP5-4O4U-L%%1MU96P597P%A8PU96OU55O515N%!0K5)2KU]?PE-4HVAHQV=H
MQ&UMR,K*RPP0BB(FBSP^FE]APS-$J^MU<L1.3O!D8_AG9ZY/3I1+2NA[>[MK
M:^>-C/___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````*E@/"(````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)X):6GBPO83M5V<-:7
M+<RO!PIQSI[+S#*/BUO-WBM0V:2R`2C$/FO.S&FL'&R*KGYAR:5:*D`A$1[A
M&:)"8I/<?"*SRNHT;8!"?!I23#+!_(*ZX0K=U19=&4"AOBE&2AYV$]4-XOI;
MS1N-4X!"O;7%D]V=W+PC<LK:JG(SDX!"'?'R$ZP<?4+3RUN:3/-2$X!"V7IR
MJCV>`8DES36=$I:Q44"A(!<=0U__F`*S]HHBZ[3H$&S>`0#YH3(958(&B@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A=RYP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S8`,3`T,3<S-C,P,3,`
M,#(Q-S`V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____JD%#^H&#YXN/B5Q??E!6O9^IR:^]85UIN\36M<KB2%QND*:Y9*#)
M:*3,:J/+;ZK3:Z3*?K??>;#5C<7K?:K*ELSPA;/4G-/XE<;GI=C[I=;YK-KZ
MJ=;TL-KW9J''9J+'9J'&9Z''9Z+'::3*::3);*?-:Z7*:J3):J/&<:O1;JC+
M<:O0=['7=K#5<JG-=['5?+;;=JS/>*[1?K;:>:[/A+SAA;WAAK[AC<7HC\;I
ME<SOE\WPA;/1G-+UCK_?G=/THM?ZC[_=H]CYE,3BD<#=H]?X@:K$J-O\F\OI
MJMW^J=S\I]KYIMCXG\_MI-7TH]3RI]CWE;7*D<?FM./_0&E_8I"G@KC3D\;A
ML.7_0&U_@L7<;Z:UH,S8;J6S=JVZ=:FV@[C&DL;3AK7!HM3AC[O&A:^YK-SH
MH<[9J]GEM=_I<ZFT<JBS?;*]:8Z6?*6NA:ZW?:2LH<W6L>#JK=KC=:FSB;W'
MA;6^<IF@FLW7C;C`J-GBD+=XILF2A[%JB[5NBK-ME;YXHLJ&?YQKBJATLMB6
ME+-]G;V&O^2EKL^6Q.>JO=^ED;1.DK1/EKE4F;E:H<1@K]%PCJA>JLAQF+-F
MOM^!HKUOL<U\RNF.R^J2P]^,PMZ.NS(RZ5E9^G%Q____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````6`.&^`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"W
M241!5!C3;<$M3D-!%`;0[_[-S"-U70`)'H%"L`9`T1V0BFX&AV`'J!H\@B60
MH(`$655",WV\S-S;!<`YP!^$A3V6RY>3W<><\]'G:7XBS*;[9;I^WU4=2DHS
M63-ZHX<>M5DVTV(3%%?MUFY>]Y%2EF*]@?'-Y>+MURTG,9,Z@G#LY\_-B9F5
MR=TWA-5/ZN["Q,+1:;A3G(W-@YE4B'JX0_$5ZL0DPN0>'E!,O@T>A$?R4BE7
M_.,`LP-'N@(`IC,`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V%Z+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`R-@`Q,#0Q-S,V,S`Q,P`P,C$W,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____Z]?8Q.;X]0[D;)K$C+;4F
M,K4;(GI#3M`[0Y]58-YC;N9>9]==9M9G<>1K<]5W@.@<,+P`)\P`&'\#*LX%
M+-`%+,P)+<T---80-]@8/-(1*I0=0N$A1^0?0=09,ITO5.XU6?(X6.%"9OHR
M3;M&:?Q!8.<Z5L=/<?]0<OY0</E7=?9>?/IE@?=JAO\`7@``7``#7@,%8@4%
M804)80D-9PT0;!`8;A@==1TA>"$?<1\;6ALA8B$B9",OAB\H;"@J;2HUB34N
M=2XP=3`XAC@T?31"E4)&F49"C4)&D$90H%!/GD].FTY0G%`V?C5.A3D]<"%@
MBC\H5``K5@12<S1PDU$X8!-$8R=2=S!+:RU?@C]MD$TO50=ND4ISE%'RW]C(
M;E+/KZ7,KZ;),07`,`;#/1;&/!?311W-2"+/2R?.5##>8CZZ4C3&5SC073S$
M63G29$/B:DGZ>5+B;$K$7D'@:TOE;T_D<E#R>5;D<U'L=53Q?%KR@%[SB6O\
MD''%<5CZCW'6?&+VE7KCK)S+LJO;32C-53G07#_T=53*9DSN>E_UA&?SB6WZ
ME7K/+PW`.Q[*2B^;0"SD9TO89$O294SO=%CD<UG!7TOC=EW(:%+RBW3NO++!
M:5O"CHC___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"9,VI"`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```*])1$%4&--MP4M.PE`4!N#_/'IML!V8
M$,*`&&5&7)JK<`LLP449!S!B@I,2[`-HSSG7!<CW`?\0YJC*![]<S4155;\8
M*(L4D[FQB+`0%-V0R`=Y;,D3DP0(VY*B>4JY)<G25_&N.,SBY+L07>U>?]//
M!,:R[B/6F[?GY6>]B'F&XFPWR]/^I>L_&AN/&8IO"<_7KN&*/(]%0'%JS42E
M3#<V=W<P!G<6+@H53Q&1<<<?KWI5!\(4R[,`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F$N<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W,S8S,#$S
M`#`R,38U-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___P`72$]NL5!KJ#58GP$K=@DO=QLY;2)%AC9:FSI>GSM=F%%VMD)@
ME&F)PG&'KG.)KP`N=P`N=@`<2@$O=P,P>0,P>`4R>P4R>0<T?`DU>PTZ@0TX
M?0PQ;0HG51`]A!`\@1(\@!5`B!A"A!U)CA0P7B%-DA](B1](B!]%@R=/CB%`
M=2-#=B]:GB$_;R9'?1LR5BA)?C!6E"M-A#!2BRY/A2I'>#17D3)4BSA<FCA>
MFC99DD)KKC]BG4=OL$%FH4-FH3M9C$EMJDAMIT%BEE!WMU!VM4%@DE!VLTUQ
MK%)WM$9FF5!TK4)=B%Z`N&2&O6B)OV:&NFJ+P%QUGGF6Q'^;R7N5P8&<R(ZJ
MVI>OU9*IS8>:N*&UUKW+X5=[LUI[K7B!C[C%V*BUQR1$;5%H?FI^B(N5BY.3
M<+.RDJ*:88^&3]*V-)2"*\&M4;&@4LRE`=&J!Z&&%^2](=2R'[J;'N[(+]V\
M-_K50N#!/O[:2N[-2?[<4/G74/;75Z",/**01*>62LNW7M*^9\"N7LNY9]&^
M:\R>`,R?`,V@`<RA!<VB"=:I#=BK$-NO%-ZR&-*I&.&U'>O`*_+(-?7+.N&]
M./C2/OS41O_83_+03/O84??54,Z@`]"B!=2F"NB\)O___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````)KPGD`````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MP4E$050(UV-@P`*8#!/Y,NNF3NAJG]M;G&?O!A024?.+"\LJZ>Z8TS.QK,G=
M$R@D;YX0&^Z:6]`YKW_2M&9O9Z"0OD\@2XR`7%%AW_PI56U>=D`AI^!X*TX/
MP932XLG3:UH=+8!"0?X.&NQ:(=RIY14S:EML3(%"`2[:LJ)LBLF\:;-G5>=;
MF@"%?(V5Q(6DE+FB(]-G5C::&0"%K%4DA244U%DCHO@S<AJ,=(!"FM)"8C*J
M>K;,H4D\V?6Z'-B\`P"AZ#(U=0H\N@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]B8BYP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P-3``,3`T,3<S-C,P,3,`,#(Q-C4V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____*"58+BM@#@Q'#PU'%A1,
M0D!L0D!K1$)L6%:%7UV+6UF!='*>$A%+&AE2(2!5-C5R.SIP3TYZ:&>@9F6=
M4$]Y6EF%8%^+:6B3``!.``!-```Q```P`P-1`P-0!050"0E3#0U7"@H[$A):
M&!A>$1%"(2%M'R!E'R!D&1E+&QM0)R=J(2%7+R]Y(2%4)B9=*"A@-35],#!P
M*BIB+2UF+BYH,#!K,#!J*BI=-#1Q.#AY-#1P,S-N,C)L/CZ%.#AX0D*(.CIV
M,C)F1D:+/S]\04%_/S][2DJ/0D)_34V01D:#24F(2$B&24F'4%"33T^13$R+
M4%"13DZ-45&24%"045&14%".1D9\4%"-5U>27EZ865F/9&2>966=:FJB(B-9
M*RQD.CMQ_O-*>W$`?W4%O:X*V\X4FI$F7%<86$\`?W,!<F@'CH(*@W<-W\TX
MW<X^S+(`R;``@7,!P*L#PZP$R:\%OJ<%?6\#7E0#Q[`)PZT)KIL)O:8+QJ\4
MJI@1S[@8X\PA;6(0S[D?A'<4S[@ABGL61T`-[=4OV\@UL*$JX<PX^.%"\]U&
M8ED<<6@A_N=/X<]&_NA0]^%0\^!0W,I)R[I$BX`OY]51[MM4ZM=:E8HZ03T=
M7UDK>&TK____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````3/_OA0````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``F1DM9)X9W4WE!56
M"Z@;N?@#A635G.,DIS57%974,^LY!H0"A90M8V)YYN459^?VL=M[A?D!A?0C
M1,(YVBI3<EJZA#U"`MV!0D+Q4=9,-5FI3?WY7/[!GC9`(=%H-PVVTHKV.=-[
MN8.\!2V`0K&^.DJLY6F9<PNF2/@XV24"A2*-5>19:M,S9B?/%'>U-34`"CFH
M*DCQU35V3IPT0\S*S%`7**2I*"W'W]K1,V'R5$YSDP1M;-X!`$E9,=K"=39)
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)D+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-0`Q,#0Q-S,V,S`Q
M,P`P,C$V-C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___\?2B`B0B,K32PZ63L`+P``+0``'``#,`,#+P,%,@4%,04)-`D-
M.@T-.0T*)@H0/!`2/!(801@1+A$=21TA3"$?1Q\9-AD;.1LG3B<O6R\A0"$O
M62\A/B$F1B8H2"@U7C4J2BHN4"XM3BTX8#@P4C`J2"HX7S@S5C,T5S0^9SXX
M73A":T(V6#8R43(Z73I&;D9":$)*=$I"9D)&:T9);TE-=$U&:D8[63M(;$A/
M=D]);4E0=U!,<4Q.<TY1=U%0=5!&9D90=%!7>E=>@5Y>@%Y9>%EDA61EA65H
MB&AJBFHP5B\R5#$V634_8SX_8CY!94!FA65$9D%+;4@=0!@Q5BL-+P4)+`!,
M:4(=.Q!;<T]8;TP?-PUO;4Y<3"]`(0%K-Q^)4CIM+AAD'PEK&@.E9%&*.2>>
M,"&4%0?"4T:D)!C-6U#(6D_=6%&N!0"E$`G;.C7J2D;,``#'`0#&``#-`0',
M`0'*`P/(`P/,!07*!07,!P?4"@K0"@K0#0W.#0W3$!#/$A+;%!37%!39&!C;
M'1W?(2'H)B;E*ROI+R_R-37S.CKS/C[Z0D+^2DK_34W___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"VFC@=`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+Y)1$%4"-=C8,`".#@D6+U=-$+#V;@%Q10-;4%"(OJ>KL&)!?FIL:*RNM:.
M0"$!=7>/D/2&\K+:[#!M<P<;H)"<DY=C?%-%24U+1Y*Q@UT`4,C2VT4UN:JT
MNK&].\O6WD0+*!3D%LB44EQ9W];5E^MHH:<&%/*PDN)+**MK[>R=D&9FX,L"
M%'+V$>*,R&SNZ.G/B_'75)$'"ND(\[!S1V44%N7$&6DI*\@`A<1YV;GX1:4C
MHQU-_=24F"6Q>0<`ZITL9*6MO#P`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O8F4N<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#0S`#$P-#$W,S8S,#$S`#`R,38V,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___SLZ.VAG:!\@(#H[.Q\@
M'U%2269G7@P-`A`1!L;-`+.Y`\G0!;_%$[B^%>'H)L+'*NSR->_U.O;\1M+7
M0\;,`,K,`,?-`<;,`<C.`\O.`\K,`\G,!;6Z!<O1!\?-"<[4"M'4"K2Y";F^
M"M#6#=+8$-;;%-G;%-C>&,_2&-OA'=_D(=+4'\K/'^7K*^GN+_/X/O7Z0OG^
M2OK_3_K^4/7Y4.7H6<W.#0P,`>/D(>[N+^'A.!04"A@8#2,C&3DY,')R:C`P
M+T%!0,C""LO&$=/.'-S8*N?B./#K1N+>2?;Q4.WI4O3O5<$T'L@_*M--.-U;
M1L%20.9G4]%?3>EN6MUI5^5O798M))XS*J`U+*<Y+ZD[,=M.0:P],ZX_-;%!
M-K1".+E&.[=$.KY)/KM'/<!*0.):3L5/1.=?4LM42-!73-1;4.AD6-E>4^AF
M6NMH7.!D6-UB5^=G7.5G7.1F6\TX+M9%.[=!.N!32;Y&/LM12.=?5=E<4^AD
M6^-C6F9E96IJ:F5E961D9%Y>7EE965=75U!04$A(2$9&1C@X.#(R,BHJ*B<G
M)R$A(1D9&1@8&!(2$A$1$0T-#0H*"@D)"04%!0,#`____P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````%^_-L`````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````O$E$0508TVV,,0Y!011%Y[UY,Y-\
M*E$H?ZD@46@D5J"P#VI1"+^Q`"(2>Y&H-=:@D@B%!(F8^?-G/#4WN<W)N5>(
MGP!W,>Z^U.WIFDG]7#9+%&+E9_OC_64E`"1:"11KYR#ZDD4#@%I91J[(J!-.
M#Z,!I`Z>T>@]E[&:HU&`&*QCE,G=)%RHI@@0\CPRDM1;'"J&Z"MY_QW2EJBE
M]?F$&$/!7R1D7PT2:ER!2?0^L#55PTT[A32%$-B*XD\^T,Y'(#<!S\X`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B9BYP;F<`
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C4`,3`T,3<S-C,P
M,3,`,#(Q-C8T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````_____6=H`%H``5P!`UP#`UL#!5X%!5T%!V`'"5\)#64-#6,-$&@0
M$F42%&L4&&H8'7,=(7<A'W`?&U@;)GDF)W8G(F(C(5\A+X,O)F<F*&DH-8@U
M*V\L*FLJ+7`M+G(N,'0P/I,^.HHZ,W@S.(,X-'HT0I-".H(Z1I9&0HI"2IE*
M39Q-1HY&29-)2)%(3YQ/3)5,4)Q03IA.49U14)I04)A09*ED#&<*,'PO,G<Q
M-GPU/X4^,H0K*VL@#E0`$5D#%EH).G`P0'@V3HU"3(9`48I&6YA/6Y90:)Y>
M;Z-E*GH8088O>:<-GL`=U)\0Q7\%T#\AMA8`S!L'R0T`N`P%OQ\8WCHUT#XX
MPSHTZDU&U$A"N3\[[5=0Y51.Y5U7\&]JQP``?0``?```R`$!QP$!R@,#R`,#
MRP4%R`4%R`D)S@H*T`T-R0T-B`H*TQ`0SA(2V104V!@8SA@8D!$1W!T=X"$A
MSQ\?FAD9YB8FTR<GY2LKIB$AZ2\OVR\O[34U\SHZKBHJW3@X\SX^]4)"N#(R
MX#\^^$9&XD%!_4I*PSL[^DU-ZTE)Z$A(^D]/\4Q,_%!0_%%1]U%1]E!0TT9&
M\%!0\E=7]5Y>Y5E9^&1D\V5E^VIJ____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````F;T=[`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"N241!5!C3;<'-3<-`$`;0;W<G,W8L6S@1G5!.3CGFE*XHB0)0!!(0*T99
M]G\H`-X#_C`XFL?=G#]O/HA(W_5G"S./#V6]_P0FEHTX6`SC7OWJLR-F%HJP
MF/:G<O-Q65@VS#7!X$`:F]:FEITSM3T3KEJB:V8T^=N95A6$K_#F`YZ&];+M
M4MJ]@J#;D)1?>.J[.KU?*@C+1ZI$3E@TWDMIL+BF;(ED$)?FW$K!/WX!#,I2
M#B&%N.L`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V)G+G!N9P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`Q-P`Q,#0Q-S,V,S`Q,P`P,C$V-C8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#____&Q\?)SLC$R</N\^W/
MT\[AY>"KKJKU^/0\@B#"Q\##R,'AYM\A;P`A:P`C<0,E;P4E;@4H<PDM>0TP
M>1`V>A@\AQU!B"%.ER]3F#5)A#!3D3A/C#9@ID);FD!<F$)@GD91A#MKKD]L
MK%!KJU!IIDYPJU=WLEY]M&6"N&I!A"`_;"E.AS1DID9DHT5CF4ASKU5XLEMF
MED_4V-+V^O3S]_'FZN3DZ.*%AX0O<PPQ=`\U>!,]?!U2DC%7D#ERJ59UJEF*
MO'`O9P%%?!A/@"=6BRM-=RQHFSY>BCIUIDUMFDB&L&0P:`$X;PHY;@U5@#%O
MG$EXIU'`"P#`#0/%$0?$'!+/'A3<,":P+B;2."^[-2WJ0SK&.S/61S[S4TKH
M54SS6E'H65#4.37,`@#+!`#,!P/0!P7,"`7+#0G4$0W8$Q#2&QC?(1WD(R'3
M(Q^F'1NP(B'M,R^Q)B.\*BCR-S6]+"K',"[),S#A.CC2-C3Y1D+\24;E1$+I
M24;^4D_^4E#V4$[X4U#^_O[\_/SZ^OKY^?GW]_?V]O;R\O+N[N[GY^?DY.3A
MX>'8V-C6UM;4U-32TM+0T-#.SL[-S<W,S,R[N[N=G9V4E)1_?W____\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````'\"=E`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```*A)1$%4&--MP<L1`5$0!=#[NILW
M_JHH`K"UL/"-20R62@RRD@3+&0ICBM?=`N`<X$?`$;;U0TT$FDP_OA/`?6_,
M#%.WM-L#V&2QL:Y+J\WS3FVQ7"%@&GMN9D[%X$:A>ST)2GL\WTE)N!C>*>^`
M$*W*-06F(,_PT1R"B;]GCV8HB2CS*K[.@E&5K$_4%":WMC4@&-]38N$8)215
M51!*56*2.I->S-WQQQ>,9E`B"\<`9P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F@N<&YG
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#(V`#$P-#$W,S8S
M,#$S`#`R,38V-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___]`U-MTY.L3#Q(F(B:2DI?K[_/'S\^7GY^+DY,K,S,?)R=/4
MU-#1T;BYN9J;F\<``,<!`,@!`<<!`<@#`\@$!,8$!,L%!<H%!<@%!<8%!<P'
M!\@)"<X*"LX,#-`-#=,0$,D/#]84%-D8&-@8&-88&,X8&-P='=L='>`A(=\A
M(=\C(Z0;&^(F)L\C(\@E)>4K*ZPA(>DO+Z\C([8F)NHR,L<K*[@H*.TU->PU
M-;LJ*KXL+,,N+L`M+<<P,.\Z.LDR,<8P,-$V-<XT-,LS,_,^/LHT-/9"0O5"
M0M4Z.M,[._A&1O=&1MP_/ML_/MP_/^%"0OE*2N9&1OI-3>5&1NI)2?M/3_I/
M3_M04/I04.Y,3/%.3OA14?=14?504/104/914=--3<Q/3\=-3?)S<\IN;N)\
M?,=M;<=U==%]?<=\?.B<G,V*BMB3D_O!P?6]O<:YN<:ZNMW1T<_$Q,G`P/CN
M[O/JZLG"PNWGY\.^OOOZ^O7T]/KZ^O7U]>[N[NCHZ-[>WMC8V-+2TLW-S<C(
MR*ZNKI"0D'U]?7Q\?/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````%$.(EL````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````KTE$0508TVW,.P[",!`$T-V-O_D0I-1TE'0<@/L@T4-!#:>@I>8LG`&)
MFB@VCA,;AQ:F?)H9@)\@G/&T[<QEV5JI==U45P((<41:&<N4U/-2`,$Q]G'P
MK27-=5,(FPC/(:.'"TGJ4H_O1&&'?5P,DJNR4M&81/N,T-^C5*HNA+N%:4@9
M0Z>9:@IMNDV?B"@X6LL\'?7.CPY8(D3_%-^C+MG4PD/&>#[+N7WY,'CXDP_>
MV$-T[LJ9T0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]B:2YP;F<`````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-3``,3`T,3<S-C,P,3,`,#(Q-C8U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____TL#!]^SN[N+ES,O,
MT]C8V-O;R<S,X^3DLK.STM74R]#.P<S$\/GRJ;ZHR]C*YO/EW>S:,'@@2HLX
MK\&J/(`G9*10T.;)FJ&8.V\J3HLZ9JA0:*E19Z=19J-0?+1H<9UBX._;/',F
M0G(P:ZM1;:96>)YIDKB#C**$N=6N:71E'$<)3XTS1'LM3H8W8Y])<*=9<Z1>
MD\1^E,.`?J)ON=BK'TT*.&@A1GPL2X(P4(@T4HHV6Y4^7YE"4X4[8YU&8YY(
M::5,:Z=.7Y)&<ZQ7=J]<>;%>?[5D?[-EA+EJC+UT8'=5J,"=380Q7IE`@*-N
MS]+([>SEQ</`S,?$X]G4JW%8M7MEN'EDVZ:4PZB?PJ6=V']RS<;%PEI/WL[,
MT`\%X2@=SBLAXT,XZE!&U$D_]E]7_FIA[W-JX7!J^X)ZS&ECXGARS7=R^9J5
MT9",T\'`_N_NS`<`S!0,UA4/[C<OX3XXYTA#Y$="T$4_]E).RD9`^5=0QE92
MS'=SOXB&\;BV_<O)WK2RV+6TS`8%UA`-V!,0V!00TA@8U3@U^D9"_U)/_VIJ
MG7-RS*RLR[JZV]G9_/S\^OKZ]?7U\O+R[.SLZ^OKZ.CHS\_/S<W-S,S,Q\?'
MN[N[?W]_____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=<A):`````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``K3G]M;VI)5U
MM!0EM%4T3%0""NGXS&'.*T_-S4XJR6299.8&%#*7TA"<VAP;%5W0-$W(1,X`
M*&3AHJ#F.X,C+)Q]NI:JK),M4,C>RU4D8-8L'C;.*=XRSG;60"%/=W]AQ?ZX
MD/B8(&-Q!QLKH)"'HY@^?W!$8&@DGX2AM)\E4$A>UY27-7_"],F%C5,$U/64
M@4)&HK/Z*MN3,[+2JW*89FNJ`(6X9]85MR:6=G77I'16UW-)8O,.`.#!,M(=
MJ]FR`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)J+G!N
M9P``````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`P-P`Q,#0Q-S,V
M,S`Q,P`P,C$V-S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#___\Z>3L`7P``6@``.0``.``!80$!6@$#7`,#6P,%7@4%704%
M6`4'90<)7PD-90T-8@T0;A`*0PH291(28!(8:A@12Q$=>!T?<!\?;R`95!DG
M=2<G<"<A7"$J9BHX@S@X@C@R;S)!A4$[>#M(D$A0F%!&A490EU!7G5=7F5=>
MHEY9F%EDIV1HJFAEI65JK&IJJVHP?"\P>R]!B4!FIF5%@`--A`U;CQ]PH3A#
M>0#+S0#-T`?6V13BYB;O\SK<WS[Y_4KN\4SX_%'(QP#'QP#+R0')R0'(R`/+
MRP7)R`5&1@/+R@G.S@K0T`W3TQ#8V!C2T!C<VQW@X"'EYBOIZ2_M[37S\S[U
M]4+X^$;Z^DWJZDGZ^D_[^U#W]U'U]5!64A1A7B%N:R],1PK?SR'LW37.P33W
MZ$;QXT[.O`74PQ#ATT+ZZU#4&0W=*1WI.R_&.C#0/S;U3D+E4$;Z6D_T6E#=
M&!CF)B:D&QOG*RNL(2&O(R.V)B:X*"CP-36[*BJ^+"S#+B[`+2WQ.CK',##)
M,C'1-C7.-#3+,S/S/C[Z0D+5.CKY1D;;/S[A0D+Y2DKF1D;Z34WJ24G\3T_Z
M4%#N3$SQ3D[X45'U4%#V45'___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#):G^#`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```*!)1$%4&--MP<UQPC`0!M!O_R1C0L"'S-`$-$TC*28SN67"(4:[DJ44
M`.\!3PA&']_7.)Z]:E(1O3%HR9?JHX:8,`N#<9CF'C%"C)F9&Q3[B>/]=_S1
M2L0\.A1I+OY3]$I!;$WJIV)9]W=?%R43IMX-BA+WA^MY)Z=I<H\*AA^*M[S1
MG%*KV]:@B*\262GO;'A$ZV"X%[-$;UFC;+UWO/`/"H)++*YKQ:,`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O8FTN<&YG````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#0Q`#$P-#$W,S8S,#$S`#`R,38W,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\```<$&"<L("=02
M$\<J*\<N+_)86O!?8.AA8^YE:/=K;,-76.YT=>N-CGD<'[<^0<U)3;(P-X,R
M-JU'3?_6V.C"Q.&FK6,W/Z%H<IYK=FE,5+.(E:B"D(56<<FIP81UA+"CM<"N
MRV!"<T(?7%@]<92!J8=UIFUG?#(E8Y&2MJS9R$W0/H#H:'2Q2[KBH)2C3=?6
MQ=S9OM;)J=_+G^C>T)9G,]O.P-ZA?_+=T=1R3L%'-<$\,>UO9=-A7OJ!?NF(
MA<P``,T!`<P!`<T"`LX#`\P#`]`%!<P%!<<&!M$'!\T)"=0*"M8-#=8.#LX-
M#<<-#=@0$-85$\\2$ML4%-X8&-(8&.$='>0A(=0@']0A(>$D).@F)J<;&^LK
M*]@G)[`A(>XO+[(C([DF)MTP+[PH*/(U-;\J*L0N+<$L+/4Z.LHP,.X[.^$X
M.-4V-=(T-/@^/OI"0M`[..`_/OQ&1OI'1_Y*2N1#0NI&1N%$1.Y)2>Q(2/]/
M3Y0P+OY04/9.3OI34?E04.5+2]Y(2/%04/M;6N%95_UD9/MN;O)K:[M85N=O
M;;)85NF#@?___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````+WTD4X````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````NDE$050(UV-@P`(D931Y%224
M5+R</((BTTOK@4("==T\#CU";"YN_C&Y9;5-0"&1WKY.1WM185??%G%^L;9J
MH)"BK#*?MIR\*DLHEYFE%4<)4$A*0[U=34M:D#6RRUC'J+D`*,3-614=R,0<
M')%D9VIA4IP#%.JH20AP<?8-BR^TUC/0M\T""K6FAK@[>8?&9I<W&NJ:9Z8`
MA?+"/:$N:JBP84]+!`I%^3BY^44D%=4V5>;G9"3'8?,.`#2C+F>(M_ZD````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B;BYP
M;F<`````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T,3<S
M-C,P,3,`,#(Q-C<R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____S%M=[I&2P18;W,K+9F%BDH^0_/#Y.SH[?WY_U=35_/K]
MU]78]?3VZ^OL'R`@S<[.P,@%XNLO[_A"*RP-]/M/\/A0P,,#Q<@%Q\D8U-8=
MX>,_S,X]Y>=&7V`CR\U/:6I"PL(`P+\`O[\`P<$#NKH#P\,%P<$%P<`)R<D-
MS,P0R<@2QL<8U=0=V-@AR<D?XN(OW-POYN8UO+LP>7D?[.T^U]<XUM8XS,LU
MEI8H[^]"\?%&CX\JU=5`OKX[\_--X^1)]/1/\_-0\/!1[NY0[.Q0Z^M7U]=1
M9&0G>WHR]?5JVMIDG)Q(Z^MVW]]S]O:7]?2?:6EE?'QX/S\^04%`6UM:O;D`
M1D4;]?3+T<D0P;00^?2N1T4TGI).[^K8T,['O8H`7UI,N;>QFFL'VYTAZ[50
MWI0U[)A&XM_<JZBF5U54G)J9PWU>I)6.O$,5/A`!U$HZJ5]76`D!PC,FT&!5
MN%U4EE--8P\*<1X8AT(^[+NXGV]MFFYL7@``Q`<'KQ<4+0@((0D)D2LKX4I*
MDS@WVUQ9.1H:IE%1DU13[9N;R(V,XZBGXMS<[.CHDI"0X^'A^?GYZNKJZ>GI
MS\_/RLK*LK*RHJ*BBXN+:FIJ7EY>,S,S+BXN+2TM*RLK*"@H(2$A____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````$`&-+P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```#!241!5`C78V#``KQ,K>R]W2VDA%34M?6-;9R!0ES]R9&!_K+1B1):
M>H;63JY`H1G3)O/P\PKFYBO8R9@YN#@"A=BF9_:Q3NEFJ6?JC8\)\/,`"G'.
M#,MNK:DM*^VI[N+@FY``%`J:%2K05-?8WIG7QCQQ$O=4H)"/KZ=H07%%97-5
M>5$P>TX64,C-2$<M/*6AI+"E(RED]MQY0"%S70TER:C4](RT.,78.?,7`(4,
M-)55M:2%1<3$Y2Q-;.4CL'D'`.B&,GKRN]7^`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V)O+G!N9P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`Q-P`Q,#0Q-S,V,S`Q,P`P,C$V-S8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\`7```60`#7@,%
M704%7`4)80D-9PT09Q`8:1@==1T?<1\A=B$;6ALB9",A7R$OAB\J;2HH:"@U
MB#4N<2XP=3`X@C@T>31"E4)&ED9"B4)&D$9/GD]0G%!.ETY>=UXV?C4D;P`F
M<`,K=0<S>!(ZA15*D"<_=29-C2]'?BU.AS-:E3YLL$MII4QOKU%LIU!>H#I@
M<D9A;42$C4=U>"[)RP''R@')RPW3U2>]ORS5V#KHZDCW^E'X^F3(QP;-S0G2
MTAC4U2#*RC#)RC'AX3C2TC35U#;GYT#\_$;EY4+'QCOJZD;__T_X]TWJZTG^
M_E#V]D[Y^5#V]E?Z^EYP;RKX]V7__VK*Q0;/RA+3SAKHY";U[CK^]TKR[$SQ
MZU#4ST;$O`"GH2'=U2_CVC;@V3[]]E'_^&B@D@J0A!*BD`WFTD.VIT.4=0:H
MCRV89S9]0`;-)@',(P'4)PK[:5'.*`V+'`K>,QCK12O8/R>R/2KX5S[_94WN
M8$GL7TCI;5G]>63,``!_``#.`P/0!07,!07-"0G6#0W8$!#2&!B4$1'A'1WD
M(2'4'Q^=&1GN+R_R-37A.#CZ0D*[,C+\1D;G04'&.SO_3T_^4%#Y4%#V5U?Z
M7E[W967_:FK___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!W1@)Y`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```*A)1$%4&--MP4M.`E$0!=!;
M'WB@#!RX`A9@G+LAU^$>29CHQ!C;1(+8=/?#KEO/!>@YP!^")VQ6A5.-,'=W
M?U1@M5CF'`PU,S6!XUP'R3G8U,6DKN'XS%)];#=R$I%U+7!\;/KOR+ONY6%\
M*^=+0''-@6UKSP<IKC,)1=>=QFGW8[=\_>*1$P3WE\BF*E>A+5O+O>.]#ZI[
MZ5V"3$(Q,,34%P8NDY'XQR\FXUF]#$?9MP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8G(N
M<&YG````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W
M,S8S,#$S`#`R,38W-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___UAXI@$P:P$O:@LX<294CR91B#IIGC18@F.-O%V%L0H]
M<2%1A%F'M@0Y;"%2@")/>$5FA%YYD0]#;1!";!)'<Q-(=BM5>2Q5>3-8>$%N
ME%%^HQU3?252=2Q=@TYYFF2#FSIY.P!:``!2```Y```X``-<`P5;!0E?"0U@
M#0I#"A!D$!AJ&!%+$2%X(1]P'QE4&1M8&R)B(R%?(29F)B]]+R%8(2AI*#6(
M-2IK*BMK+#!T,"YO+BUK+2IC*CB#.#1U-$*20C)N,D:71DF224^<3U"=4%":
M4%"74%&745>;5V2C9&JI:F6A93!W+S9W-3^"/EJ768JHB0I?!2-T'56=31UI
M$E*21HVGB$-^,WR6=7.L7E^11D6('3-V!72I3*O`F7:H2'&B.'FG0K+#G9W%
M9&V5,5:*`&R%/7N439.^/GV=.Y*Z+W"6`XVJ-'6+-;;34*2]/G>*+:G%09.E
M2L+99<SA:+W->H&1,I>E2L+0>*"V#9ZQ,+;%6*N_$*:T09BE&K3#)];C3M;E
M4:*L'+*[,<3-.L+)&-SB2+_%0L+%`,?*!>+F*_+U0O;Y:L[.#=35(.'A.-74
M-N?F0/[^2N#A0NKI1N[N2?[]3_W]4/;U3NWN3?;V4/'Q4/;V5_CW7O___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-"+P/`````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````P4E$050(UV-@P`)4U0R5?+V3.WHR0G3T+5W<@4)J>LY^,25ME<6M
M-7%F3FX>0"%M^Z"TSE)1%F:>K-[L,"]7H)!Y;/F\+DE!.0D!]KJI+0F!0*&<
M_OF3JCBEA(05F2)GS9Z6#Q0J6S!E8@&KB)B\-'?JW.F3:X%"/DE-$QKYQ645
M9+@J9K2G6P.%//W#\[HS>=DX^!+G%$79F0*%''0U5.+K&Z*#JYM3'&TM3(!"
M!IK*ZEJAN7TS"R,";*R,C;!Y!P!]ZS)VH@;*#0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]B<RYP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P-#8`,3`T,3<S-C,P,3,`,#(Q-S`T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____.SH[:&=H``,/
M`P4-(4&P3G3V9&AV`##,`S/."3?-#3S6$$#8"2%J!1`T'4OA(4[D'TK4+USN
M*$J\-6#R+E''-%C20F[Z1G#\06GG0F?E3WC_4'C^4'CY,CYC`#3'`#/&`"B;
M`!53`SC.`AMC!3O0!3C+!3C(#4#1$$/3&$?.'4[;(5/@&3N=&SZD(D>O+U_J
M-67M*D^[,%?&.&/=-E[10G#V1G7X.E_'1F_F3WO[4'WZ4'KU5W_R7HCZ262S
M:H_[98;C&$.L&4.M(4NS+EB^06G,4WK:88;B7'[498C@*5&O)T^D/62^67S(
M1V.@3FNJ6GBY:(K3:(?*'R(I/6.L1VRY/UN6;H_4'R`@*RT%IJ@*Y^E`U-9$
M\?-03D\:YNA2%A8`@X(%R<H(Q,0.U]80GI\-;FT-W-T;WMX=S<X;X^(A[>PO
MX>(NVMLM[^\UR,@PN;HNT-`TTM(VQ,4T]_="[>Y!^OI&T=(\X^)"Y^=&_/Q/
M_/Q0]/-.]?90]O90Y>9,\O-4\?)7,#`O04%`#`L#`@$!,"\O9F5E:FIJ9&1D
M7EY>65E95U=74%!02$A(1D9&.#@X*BHJ)R<G(2$A&!@8$A(2$1$1#0T-"@H*
M"0D)!04%____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````:MSZM0````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5!C39<\]+D11&`;@
M]_V^]QQ')E&8*31",84EZ*Q"I55JB<0"9@HV8"$2G4)$JU.(1"NB$''OG7M^
M+&">'3S`&D)[DTDJW5_I-]Q#U*.0SQ>S\M8/E28/,A"WP^KJ<*MV)$E:NQ/&
M>G$]O.8=1GW;_+V`L*6D^$2/2H%YN#$LK'L.I_,@1GE950BF=/1U\F':3-XJ
M"4&_T[/]@Y&]XEA;2Q!\^W*7#Y+T.<NM_H`XOI]Z\!!E)==6VLOZ!_^R)T%M
M(,Y_>@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)T
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#0Q
M-S,V,S`Q,P`P,C$W,#``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___^XL[74U]O$R<O1U-7-T=*HK[#9VMJBHY^QK9VTK(VY
ML9/#OJW'I$5]60!\6`##BP'"B@+)CP7'CPK*D@W%CPV(8PK.F1B0:Q'/G!^:
M=1G=J"?3H2?.G2>D?B'9IR_LN#6NB"K>KCC=K3BXD3+BLT'#FSO#G#OHN4B[
MEC[NP%#MOU#0J$;RQ5?QQ5?UR5[URE[EO%GYSF3XS63TRV7ZSVCSRF7[T&K[
MT6JVG%Z\J7FWJHG,D`?)DQ7$D!;-EQS!CQO.F!_#DA_.G2R_DS'CLD#6J$#H
MN$C,HT/$HE*YF$[3RK:VKZ"[MZ[*EBOGSIJXJY3RKTS!70V=AGK#JY^HG9CW
M@E#(O+>X;%&Y94GAS,76QL'9RL7'.1#82"'`01^D.1NL0"&O0B.V1B:X2"B[
M2BK*42^^32S`3BW'43#)4S'F:D;-7S[9947T=5#E=%+#8TC??F'B?V3FB6WM
MD7C8B'+*@&O1AG#IF(+@E'WCEX+?EX/>F(7GH8[2F8G8H)'DJYK(F8O3-`W#
M3"['3C#2537,4C/763K\<4_H:4G\<E#O@63RA6CKA6OFGX[GIY?`CX.LAGVI
MEI'!,A'/433Z9T;R:T[V;U#NBG.CGIVUF)/9N;/JV-?>T-#!P,#___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!I7S89`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```,%)1$%4"-=C8,`"^`6D-2SU5"2$A9SE9!2#PH%"`I*JYH9J4B*.
M5K[S?0)*9P"%Q)6,3#1E105=O?R8Y\VM+@`*R>N:Z2C8V8O9^O/.F5E9D@<4
M4K?05W'PYN*V#F6-[8]NF`H4,C5P<]'BG#R;B85C0FU1;A90R-C#TX9]5F1Z
M$UMC3U='=@902-N=)RQDTL3ZXKZZF(KVS!2@D#)?8-24PHBJ:=W3R\I;4I.`
M0D[!"7'-\36]G?DY;:UIR8G8O`,`/.4QY-R*F/X`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O8G<N<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#,U`#$P-#$W,S8S,#$S`#`R,3<P-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___[SB]2^<S#2;
MRS2;RB!A?C>DU#B?SC>=S#B=RSN>RT"FU$2OWD.HUT.IUT>FT3)UDTBFT4^R
MWU.VXTVITSM^G#^%ID6-KT>0LF#![4Z8NVC,^&7$\%";O56CQEBER6.YX%VL
MT5ZOTW'.^56;NFW%['71^VN_Y6R^XUZEQG##Z'S5_GW4_7W5_7O0^'O1^'G.
M]'_0](O4]I#;_7.GOW2GOW.FO7BLQ'2GOGNNQ7FJP'RMPX2VSH>YSY/$VY;'
MW8JWRVR.GI&\T:+2Z'^EMJ;5ZI.\SIG"U:_=\K'=\JG3YZ3-X++=\K#;[Z;/
MXI:ZRZO3YKG@\BZ<S"^=S3"=S#2BT3BASB=MBT"LVSVCSU&ZZ%:^ZT^OV$>7
MN5:TW&/)]4^AQ$B2LE:KSV.ZWW+4_G75_V['[G'+\G?5_7?3^W3+\7G'Z8;9
M_875^(FPP4$\.45`/6AC8'IU<C,M*D0^.TE#0$M%0E--2EA23U9035I446)<
M618/#!D2#QL4$1X7%",<&28?'"TF(S(K*#<P+4I%0Q</#$=!/U1.3&!:6&-=
M6V)<6F]I9W9P;O___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-"H[8@````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````MDE$050(UV-@P`+8V,2T
M3(P4A;A8.?A$9-7U0$*"JL9Y&J+<+)P\PE(J.@9`H8BDG%RUV'#F$';>&)FT
MK'2@D%,`4Z"SC9FIA:V]BZ>OMP=0J*VXJ+RYOK:^J;6LNKNKLQ`HU-=;4=+0
M7M?84EI5TU/940`4"O)QM#:WM+)S<//R\W?/=P4*9<='A0:'148GI&9FI"0G
MQ@&%%`6`+N('NDC74%-)7EH"*`1WD;ZVLH*<I#@V[P``+'LI>D`Z_S@`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B
M>2YP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C8`,3`T
M,3<S-C,P,3,`,#(Q-S$P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____U"XQU34VX3P]YT%#B3@Y^HR-\)J<`,P``\P#!<T%
M#=$-$-40'=P=(>$A&Z,;(:TA(J\C+^HO*+HH->\U*KLJ+L4N,,8P-M$U--`T
M0O9"1OI&0N)"1N9&3_M/4/M03O-.4/50!<(`",4##,<'&=$4*MXF*K(F,;TM
M/NLZ-\<S0M<^3O5*4.I,5?51#KX%$,$*([<3I"4!HR4!JRT*IS`-MCL8Q$TK
MHT8LK4TQTE\^N58ZVVQ-S&9)V&]1MD8JS'-HNR\BP38JS```QP``QP$`Q@``
MR`$!QP$!S@,#R`,#Q@,#?0("RP4%R@4%R`4%QP4%S`<'S0D)R`D)S@H*U@T-
MT`T-R0T-TQ`0RA(2UA04?0P,V!@8SA@8S1@8X1T=W!T=?!`0X"$AWR$AU"`@
MSQ\?XB8FTR<GY2LKFAT=D!P<[B\OZ2\OV"\O[34U[#4URC`P[SHZW3@XSC0T
M\SX^^D)"]4)"^$9&]T9&VS\^XD%!X4)"N#8V^4I*ZD9&PSL[^DU-_T]/ZDE)
MZ$A(^D]/^E!0[DQ,^5!0\4Y.^%%1]U%1]%!0[5!0Q$5%\E=7\5M:]5Y>Y5I:
M^&1D\V5E^FEI^VIJKDU-YFIH]G5U]75T^WM[I%55T&]O____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````I*5ND@````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"O241!5!C3;<'-6<,P#`;@3[(?V3*!2Z%3,!)K<&$!SER8H8S0
M";I(RX&?0YTF`1)+#-"^+W"&\"!YO?[=?]9!KTJG-T^,HZYNYZ]^'$1SR=<"
MQO;^SOOO.H0B.1>9$/%*]O-13ZV3HJK+!$:U^?TXS9I44_;A#XS.'NNI#REE
M41Z?&PCI93.:,U-@=C/?1=!;K<Y$(;";FR-B83\PLZ1(2VNM@6'N1!0E<%O,
MS7'!/W9#3O7]$+5-`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V)Z+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#0Q-S,V,S`Q,P`P,C$W,#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^!)F&"*&.$
M+6:,,FR1075S-%V'17"13'F:4X"M9)-/%SV,-7"80'J:1'YK,5A]/6>J5X^W
M9YW&A;&"*6:15'Z\<*2Y<Z-Y'F*A3(NT:*"<48JP7)RX:*1[(6>&,G.LJZRK
MG_MD5LN`==R8C?4V*,P\+LP_,,XO)HM(/,]-/]5?4>M93=A'/J=C5>%01KEA
M5MQ83L1A5M)>4\QR9OAC6-5W:_YG7=I[;OYR9^YO9.9K8=]L8=]Z;?ET:.QP
M9>5T:>IB6<=Y;?)_=/]Y;O%X;>YW;.Q]<O:"=OV!=OMN9=1^<_&#>?:*?_J!
M>.F/A?V2B/^0A?>4BO^+A<]63<);4LI02+)?5L][<?+&POH[--9%0-)$/[!,
M2+QF8.=;5])U;_9M:=1[=^2)A?>DH/X?''\T+]`R+LPV,LP].-A*1N$P+I1=
M6>Y34,=A7>%O:_I:6,Y34;MH9.5Y=O]X=?F"@/J/C].0DM6[O/:_P?:#AL*)
MCL>TN_QX@\US@,NBK?*3T9*3R9&LY:F;RYF8R96NV:O3_<_;_]>4S8R-S(.<
MS)3"^KG"\KNFYIF5S(J:QI%OFF;%];J[Y*V:NHO)S,>#CW.FLY%K;S595TAS
M9CFPHGBXK(N@E8"9=3JJAH;___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_;(+3`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`">'@$
MQ$0D9!3D)45Y^86$Q8%":3E%*67Q277UA='9N04EI4`AS7#_`/OREJ[.Q@H=
M4Q<O-Z"0GG>@JTK3E(G3IC>KFGM&V@*%G()]]6NZY\Z8-[^WTM+#P1@H%.1G
MK5W=KSASUM2>*CM'LS"@4("[KH9RZX39<R9W*%E9F(0"A7P,M=350MKZ)K5'
M.=M$&!D`A?)C,C/2LY(;:E,3BQ/RXF*!0FPL3,RL?%*R<M+<7)P<@NS8O`,`
MJFDR#,;OSH4`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8V$N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P
M-#$W,S8S,#$S`#`R,38U-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___]75U/;S\N3@W\J[N-*XL]/#P,X=!<HD#-`D#=<I
M$=(N&.$T'=U$+\0_+;(Z*LU$,?]D3_)@3/ME4=171M9G5LAB5,QR9LYT:/V1
M@LYX;.2/@^"8CL:*@?ZSJ?ZTJOZYK_>VK<V9DLR=EOS/R<RKIG\,`,P;!,P8
M!<H<!<T>"=8D#8L7"I0@$>(W(=,S(<LU);`P(>Y#+[(R(Z<N(;DV)KPY*,$\
M+,I!,.%).-)%--5(-O=2/^!0/OQ81N550NY;2>Q;2/EB4/%@4,M82?IP7O1O
M8/US9/AT9?][:L]E6,QQ9=J`=>Z9CM2(?OBEFLJ&?=*+@^&9D.ZEG/&LH_FT
MK/VXK__'P/S*Q/3-R/K3SLVQKLH2`'\*`,X4`]XF&-0O'Z<H&^LZ*_I/0L=(
M._Y?4.=62^=I7]2,A<T.`<P0!<\<$M@Q)_(^-<<W+L\\,_I,0MI#.KLZ,N=*
M0.I/1O]63?U:4?973O9@5^EA6?S/S/+.S-S,R\P)`)T=&?(Z-;\P*O]O:-+#
MP_[Z^MC5U?W\_.SKZ^?FYOO[^_KZ^OGY^?;V]O+R\N[N[NOKZ^KJZN7EY>'A
MX=[>WMC8V-;6UM'1T=#0T,S,S/___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````&%!TD````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````P4E$050(UV-@P`+BU.OE&'LFL:G,F#Y%IL$^#2BDKE>LU-7!
M[FJH-G627Z&0,U!(5Z`JO'U*C$96YN3^@#(11Z"0J6A3:*VW.">76$:40KFP
M'5`HU:LRN%DSEH-;/R]2L<+!&BCDZ5;BSZH5K\-KG*(:5FIC"13R<,J5GJ%L
MD)!L*]\94B1H`11RX<N1F#'--]U=JJU7MH#?#"ADQ9/M,[V5I::ZA7EB4+ZY
M$5`H4;M.<NJDONB([@E,@8TF2=B\`P#8ES&H&P[$Y0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C9BYP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P,S0`,3`T,3<S-C,P,3,`,#(Q-C8U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____QTM-P517
MA0<B?@`>BR0_F#A3__[_?'N`Z>COX>#G!052!`0M"`@T$!!9(2%H)R=N-35Z
M.CI^1D:)3$R.4%"065F75U>465F6:FJC:FJAG)RGT]/=YN;LV=G?V-C>ZNKO
M.SQN9F>>$AAB0TJ(T]3:P<G0Q,O1NLG#X.OF[/+M"6823)Q2`5H!`58!#5X-
M&&89)W$G+G8O*VLL.GTZ39I-/7D]2(U(28Y)0X%#49E13H].4Y-37:-=7J!>
M9*1D:JAJPL?"Y^SGUMO6Q,C$[_/OY^OGTM;2NKVZ"F@',G,Q<JMQ5J)1"UT`
M#EX#+FDF59A,69I0'6@2.7XO-G(M/'HS2(@^\O7QO\\0X.M.LKH`MKX%M+L%
MN\(8GJ,AJ:\HM+HNO\0TS-(XT=="S,H`S<L#S,H)U=0-X.$=U-,?6%@-IZ4;
MLK$COKTJRL@PU-0UZ>I&9F8L24DT8F);X.#?UVPAZWTO]HU0\XI0BCH4?2L*
M?"P*O6A*JU$UL%H^S```QP$`R0$!QP$!S`4%RP4%S`<'S0D)U@T-TQ`0WA@8
MTA@8X1T=Z"8FZRLK[34U]3HZ]4)"^$9&^D]/P4].V%U=RE=7VV1BW=S<_O[^
M_?W]]?7U\O+R\?'QZ.CHU-34S\_/IZ>G____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````UIK!/`````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"U241!5!C3;<'!30)A
M$`;0;[X9W,5D)6LTF&A#-L&=4(4)-X_&`CAZ\VX+-F`!9J,<A,0`R_XS0P'Z
M'O"'H)E5K[W_+/N'2H7D-R$U#W63I>0-555A&%ZD<O/"L.O/O!((5C%_'NK=
M>C09>P@_'@7WD_7HV"VV=O$DM^+R9M"O81/:-=IIVX<[B-_]SH-"RMB/A]9A
MN&26+*&,J9UEWKT;VB%#O)"E.8_,A*&R$(I0<IJ9F?C'"5C=4/::?HW0````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V-G+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T,0`Q
M,#0Q-S,V,S`Q,P`P,C$V-C0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____0-38`?0``?``%R`4)QPD-R0T*B`H2RA(8SA@8
MS1@1D!$?T"`?SQ\9FADGTR<AI"$PV"\JKBHXW3@XW#@RN#)!XD!!XD$ZPSL[
MPSM(Z$A&T490[E!0[5!7\E=>]EY>]5Y9Y5ED^61D^&1F]&5H^FAE\V5J^VIJ
M^FI%QP!&QP%'Q@-)QP5+QPE.R0U2RA)7S1A<T!_L\C7O]3K;X1W;W1W?Y"'B
MZ";BY";EZROEYROI[B_IZR_M[S7S^#[U^D+X_$;'QP#&Q@#(R`''QP'(R`/&
MQ@/+RP7*R@7'QP7,S`?(QPG.S@K0T0W0T`W6TQ#3U!#3TQ#6UQ36UA39VAC8
MV!C<VQW?X"'@X"',QP#+Q@#-R`'-R`//R@70S`?3S@K4T`WIIR_LJS7OKCKU
MM$+WMT;YN4KZO%#SL#[ZNDWZNT^C&QNL(2&N(R.U)B:X*"BZ*BJ]+"S#+B[`
M+2W),C'&,##.-#3+,S/0-C7U1$+5.CKW24;;/S[A0D+Y3$KZ3TWE1D;J24GZ
M3T_Z44_Z4%#Z4E#N3$SQ3D[X45'X4E'W4U'T4%#T45#V45'___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"XZ)A$`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+I)1$%4&!EES\L2P3`8AN&THFGKO"!:ICK(,,7&K;D%%^'^
MQ,J,PU#)G[2)6/N6S[R;#Z&_>:CAM>*>*#^:96%T::Q./O)"TI6@*C9-"/<+
MAGR$2;O6$EB:ED[RTE$4826`T<G[#.N\TC_J@(`EG;ZPVL^,4(Y:4LK%,'UR
MOL\".%J$D5$P']%'B'<T?JM#Y2HE\O'P'IR+402ZMK6KQ"P9W$*^'0=6J*HV
MKLHF_6N3;R@AH*TQ]N^-@R\MK$^\.2-(*P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V@N<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#,T`#$P-#$W,S8S,#$S`#`R,38V-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q41=74U<?&Q\'"PK*S
ML]35U.#@W]W=W,W-S,O&Q>/>W?KO[?#IZ,9Y<<O#PK$5![4;#;(:#:@9#+<>
M$+4>$+,>$;PA$[4?$JD>$;XC%<,F&+PG&;@F&;XJ':TI';@N(;HO(\<V*,@V
M*<`T)\X[+<`V*H4I(=)"-<]"-;@\,=E).[@_--9*/KE!-J0\,L],0+E$.JQ!
M-^-62<Y-0L%)/L=,0;I(/<M.0\!*/]%11K-&/-U93<U42-E93;U-0Z-#.NIB
M5=!73,A32=]>4M5;3[9-0]Q=4M=;4.1C5]M>4^MF6LM83N9D6=]B5\%53,)7
M3==A5L=94-]E6KQ53.1G7=YF6[I63.IN8^%K8=AI7]%E7.5R9^MX;<EF7<]J
M8>=Y;NM]<^-Z<.J#>NZ*@>R)@.V-A>NDG<N?F\6;E\:=F?7$P,>@G/G0S._C
MXK41!^5:4?CW]_____[^_OW]_?S\_/O[^_KZ^OGY^?7U]?+R\O'Q\>[N[NSL
M[.OKZ^CHZ.7EY>'AX=[>WMC8V-;6UM34U-+2TM'1T=#0T,[.SLW-S<S,S,K*
MRL3$Q+R\O+FYN;*RLK"PL*>GIY24E(N+BW]_?P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'XD+.\````)
M<$A9<P```$@```!(`$;):SX```#"241!5`C78YB"`1BF3)ZLZA(?;B8O(B`F
MHZQ77`@2FF@7%V7AEY&N(ZJH:5-0!A2:U!<;[:84U-GA*ZEFZ%-2!12:T)P0
M:"(7RMX:HVYE'U+!"A1B+(@P2N/E:&ODY,[T]*]K`0KEESJJ9'6V-]57E69[
M>S%T`86*JC6DM4QY&FI2DQ(];-F9@$*5;++"?+D!M>7)>:[6EMV]0*'Z%G%^
M,8G('*X4)P=C@YY^H!!+AZ"0E(*V>UBPL[F^+O,$H!`&```QMU`EO%&Q3P``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]C:2YP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C(`
M,3`T,3<S-C,P,3,`,#(Q-C8U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____YNWF[_7OW.+<*(TA-IDO-H4P.HLT1:4^1)@^
M4*Y*3Z1)5[%05JU0)H8=(FD;,I`I*'$A*G0C+GDF+WLH/I\U,7TJ-8(M,X`L
M-H0N0)PW.(<P.XLS/(TT/H\V3*E"0I0Z1YD^4*Q&3JA&2IU"1Y,_3J)&5K%-
M4:9)6+)/6;)05:E,6K)15JQ.6K%16:]06K%25*),8K=:7JY79+5<.HDQTMC1
MRM#)Q,K#\_GR]?KT[/'KX.7?S<W,S,6_T<K$V-+-S\G$Y^'<?S8`S%<!S%H&
MS%P*SV(2S&,6U6D9T6<9E$D2U&P@UW(HW'DPL60JX8`YW'\[YH=!ZXY)\)51
MTX-']9I7^:!>Z)99_JEJ^:9HRU0`S58#RU8#S5P-S%X.RUX/BT$+SV(3U&H@
MG5$:TFTDIEDBX7XXNVPSQG0[QG4[\9)0ZY-3_*-D_*1E_J=H]Z%E]Z-F_JYT
MS,7`V-',S<;!X=K5]O#L_O[^_/S\^OKZ^?GY^/CX]?7U\O+R[N[NZ^OKZ.CH
MY.3DX>'AWM[>V]O;V-C8UM;6U-34TM+2T='1T-#0SL[.S<W-S,S,____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````[2X"?`````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"K241!5!C3;<L["L)`%$#1-R\SYH,I%$.T$=R"(+@`:[?E
M7FS<AV*I"S!$4UI(()GW<;356QZX`#\9V,#"I6XX<+"_MJ,\N2!`8N/FY"R(
MHLEB!PAS^^2Q6*.D692X+I`;E%(;/#"?4W3\(6L?-%G"EEAR-!V!A5B(ZG9&
MS"9(+X&8O)\607C=2U]68;S[0O48A%2%;CX0427-*@B@"+-\20TBTRXR+V41
M^-,;\%-;$+OK)%T`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-K+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#0Q-S,V,S`Q,P`P,C$V-S``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^2.3JM
M?H!B042::G";@Y+.M\B5?8]20$^JFZF%;89Q4'>]K,%<4U^NH[1I5'^LI+C`
MM])F6Y"4BK]E7W\S)W5018<V+'A&/H9.1I.,AKHM)GDN)WHS+'\U+GXZ,X4X
M,GX]-H8]-H-"/(=)0I)(0HU(0HLZ-6].2)%?6:584Y!O:;1P:K-S;;=J9*=H
M8J-T;K9V<+AW<;EU;[9U;[5S;;%V<+6$?KMG8Y."?JV"?JQR;Y,I(W@N*'HO
M*7LP*GPP*GLP*WTR+'XS+8`R+'PT+G\V,((V,8$]-X=`.HM"/(Y-1Y512YE6
M4)U:5*%"/G=>6*=@6ZA6499<5YY43Y!23HYD7ZM'1'I84Y1C7J=>69U?6IU<
M6)EK9K!I9*MN:;)D8*%O:K%M:*UR;;5H8Z1K9JAM:*IV<;AN::MW<KAV<;9W
M<K5T;[!E89A\>+MZ=K2%@;]D89",B,*!?K1\>:AX=:)J9XZ7E,:(A;)Y=IZ<
MF<F!?J9A7WR=FLB<F<0X-8!'1(Q85)YK::5J9Y]]>KN"@+F!?K6(AK=Q;Y1Y
M=YVDHLLM*WX\.X9J:9-;8:#-A7M_6E7-HIS+?'.F?WK?L*JN6%'5?G>G95_-
M?WC3AH"04T^Y;&>80#YF*BK___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!:7?W\````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"
M./EJ9PCQ"O8[R<BI)<;K&@.%6"9.F35U$C.KA%.H=4E=<0Y0:-[L"=,G3YO+
M)-98VA2NU]T.%!+E8I_)SR;0X-(2$I1B4F`%%.(0D9XCW,O-H]0<E9!EEEH&
M%+)H-1!7M.V1E.I(,C+7C^P""A6F:WK(VKM[^[7E9V?&:O<!A7*#E1WMW+Q\
M`ZLKDF/"BLJ!0M$JKK+.GCY:.H;UE7F6-@%`(75Y60<%5?^X#-.TFJK."`UL
MW@$`+)`QC7_:DP<`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O8VPN<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#(Q
M`#$P-#$W,S8S,#$S`#`R,38W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%0````T(`P``
M`'%,U5(```!@4$Q410``V@``_SDXWC8V_WL`C$I'_UI9_\X``.D``/\``.=Y
M>X0`B:48C(1Y_[V^QK6V_[W'__^-B]G:V=;;_^_O[^_W]_?W[________P``
M`````````````````````````%BW;1@````!8DM'1!\%#1"]````"7!(67,`
M``!(````2`!&R6L^````2DE$050HS[7*.1*`(!`%T?[B*#JNX'+_FYI2:.H+
MNQH`:%)I03:;*=RE"W4YAZH>J-O6NI[()'N_DE35A+?N[M->&AD^Q-]J_-`_
M8;P-5(HDRTL`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-M+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`P-0`Q,#0Q-S,V,S`Q
M,P`P,C$V-S(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___\Z;3L`2```1P``+0``+``#2P,#2@,%2@4)3`D-40T*-PH24Q(8
M61@1/A$?8"`?7Q\91QDG9"<A4"$J62HX=#@X<S@R8C([:SM(@4A0B5!&=T97
MCE=>DUY9BEEDFF1DF61EF65HFVAJG6HP:R]!>D!FF&5XEVH4/0`5/@$9004<
M0PD@20U8>4AMC%XK4!A!8R_@Y"'I[B_'RC#.T33S]S[;WS[Y_4KJ[4GZ_E#T
M^%"DI!NLK"&OKR.VMB:XN"CN[C6[NRJ^OBS#PR[`P"W&QS#)R3'.SC3+RS/0
MT#;U]4+5UCKY^4;<W#[AX4+Z^DWEY4;JZDGZ^D_\_%#N[DSQ\4[X^%'W]U'U
M]5#1P1#8R!WBTRO/PC7UYD;>T4+WZ4_TYE'MW3KKW4S*HP73A!#00@W;3!W'
M(@#,%@?*#0#+$`70&`W8(QCB+R;L/C7T3$+E3T;Y5TWQ5T[X6U'(``#'``"[
M`@#(`0''`0&]!`'+!P/*`P/(`P/)!06\!07`"0?("0G1"@K."@K,#0W($Q#9
M%!36%!3`%1+9&!C/&!C1'QWB(2'?(2'2'Q_B)B;E*RO**2?M+R_I+R_L-37O
M.CK@.#CS/C[V0D+W1D;Y2DK90T'[3T_Z4%#U4%#J6%?___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"5O-L[`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`)Y)1$%4&--MP=%M0C$,!=!KQW$>%+5B`R0D5F0I!F(%/BBMA%Y"[#@=H)P#
M_$/(M/LYG>OS6=?']6M7+@S:Z*%XJVTAHJUF,%1+S'5MK$0IYQ<82Q%+M3U^
MA93+<`CR\K)9OYV4G&?O8'SV3?>V9U9B,@L(NM\M4CD680H;`XS^T<=4T9R8
M8X1#X#<WSIHE30_S`*.[":M*HH@9,?'&'RN!3RM6VIS+`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O8VXN<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,C`U`#$P-#$W,S8S,#$S`#`R,38W-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```&`4$Q410```/___]4U-L<Z.[*7*I1Q$;N7
M,NFX6?:"5W\2`'\0`,TB"<P:`XL7"L\D$O]W:/=V9<P4!<X?#=0M'\P*`)T@
M&?UM9,P(`<P)`:<E(?%44-1+1O]O:LT!`,P``,P"`'\``,T!`<T"`<X#`\P#
M`]`%!<P%!=$'!\T)"<T-"=0*"M8-#<X.#=@0$,\2$ML4%-X8&-(8&.$='>0A
M(=0@']0D(.@F)J<;&^LK*]@G)[`A(>XO+[(C([DF)MTO+]TP+[PH*/(U-;\J
M*L0M+<$L+,<N+O4Z.LHP,,TR,>$X..$Y.-4V-=(T-,\S,_@^/OI"0MHZ.N=!
M0.`_/OQ&1N=!0>5"0OY*2NI&1L8[._]-3>Y)2>Q(2/]/3_Y04/),3/U14?9.
M3OM14?E04/%04/975_I>7OUD9/AE9?]J:O___P``````````````````````
M````````````````````````````````````````````````````````````
M`````(DS8M$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MGDE$050(UV-@P`(4.$4C9#B\#-7D5'6-'8-C@4)<K&P"J2'"FG+*VD;6_C%)
M0"%>%G:Q:$LA<44M`PN_R,0HH)"D-+^4'1^/K+J^F5M8?%P04(@Y(\734%`$
M8E!"J`]0*#TUT)1;'FI0.),[4"@MVE)'0@EJ4("'"U`HV5Y/10YFD*^S+5#(
M$^XBH$&N#E9`(1,-F(O"O=V=;,RQ>0<`\/HCW.:+KT0`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O8V\N<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#`T`#$P-#$W,S8S,#$S`#`R,38W,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___Z$4%J49&J(9
M&ZXD):LK++LT-I$O,)TV.,I'2:<]/KY)2K%$1=986L-24]IA8])>8`$CA0$C
MA`HKBPTMB1@YER=$F2M+IBM$C#)+E3Y=M3I4H4UJOTACLDEDLU%MOV1]Q@<H
M?`DJ?`TN@1@VA1HZC"Q+FRM"?S51F#]>JS)*B#A1D41>H$]MMU%LL%9RN55O
ML6-O?D96:':%E72!D(&/GH"-G(J6I#I+7#Q-7D!0851D=65UAEMH=6]]BX^;
MIU)B<<VM`,RM`]&R!\^R$MN]%.C*)MW"+_78.N#'/O[C2O+93/WC4?'84-2_
M1LRK`']K`,VM`<RL`<ZM`]"O!<RL!<VM"=2S"M:V#<ZO#=BX$(MV"MZ^&-*T
M&)1_$>'!'>3%(=2W'YV(&>O,*]B\)^[0+Z>2(?+3-;*<*N'&.-*Y-/C:/OK=
M0KNE,OS?1N?,0>7+0L>P.\:P.__B3>[42>S22/_C3_[B4/;;3OO@4?G>4/;<
M5_KA7NG26?WD9/_G:/?@9?_G:L0/`,82`\47"<X<#=DK'<TM'Z(E&ZTN(^<^
M+[DU*L0[,,]"-?-00N121OA<3_)<4/___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"3RDMT````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````G4E$05085V6/,1+",`P$
M)5F."<F$#`T-O^`EO(8OY'7Y`PUT5&&P%2RCI*#)E3MW.W,`FR!<X=@?Y#5%
M\5450CT00-=T\Q23,'OO=PX(FGVOZ1V_Q,Q5<`(,S>,T2M9"A$14=$$7.?]%
M&)?6&`.)8JKQ0ZBY-73/29<9.7+%!(;Z&%:18Q.5DI\(K:B:V`BJI42$(1M!
M7DFQWFW[!W[Z^4PA53]1=0````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C
M<BYP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T
M,3<S-C,P,3,`,#(Q-C<W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____`AI-!"I\"2^`.UN?2FRU/UJ50UV55W&I15>`77*?
M97JH@IC)"2]^%#J*'#^))4J8'#5I.%RH/%F3/5B05'6Z1V.>6GBW5&ZB36*+
M;8G$:(.Y5FJ4>9+&=HV\@IO.E:*[765UEZ2]F*2]H*S%K+C1<7F)N\??R-3K
MS]KQNL39T-GKHZ_%EI^PR];KS]KM<W54SL[*LK*O___\^_OX^/CU[N[KZ^OH
MWM[;U-31S<W*BXN)_?W[Z>GGS,S*EX]T[.OHHW]3I7U1V-31K&,[KW-<KU(^
MM$@[OC\UV;6R^M;3RC8NP#LSP3TVV$E!QTE"O44_MD,]N44_X%5.XEE2Y%I3
MQ4Y(Z&-<YV-<WV!9X&=AXFQFY7%KT&IDXGARXGESN&=BR)V:MI>5P:&?\<G'
MS*NIW;JX^M32[\S*[LS*MA40MA\9OB4>Q2LDQS4NN34OTD(\N3DUO3PWUD=`
MKCXYS4M%P$E$T51.SU--M$E$U5E3U%I4V5U7UUQ6Z&1>XV1>FD1`Y69@RV%>
MZ79Q['ETZWETY7=R[']ZQFQH\(^+R9J8UZJHS*.AY+NYOB(?T**B_O[^_/S\
M]O;V\O+RY>7EY.3DX>'AV-C8TM+2T-#0S,S,Q\?'O+R\L+"P____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````@L;W+0````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#!241!5!C39<]12@)1%`;@__SWSBA,TC#YDB*2"B6!FY`VXJ9<
MD$\]"NH(6AF"@3"FB8HY]UP7X+>##[@A(&(3NBS2@T3D/EX+&D%![84G1PI%
M@J%%Y11Y:S9)[KU7%<+BK2B3YF='S<?K=]ND_MWB'(RK@_]5R^6CPDCJ4Q"E
MM);F.VWQ)6P_-U1`N*=)/4SL%Q?&N-F\"8O5HCON!CG3\O)'[W4#09^$5U7U
MI#4B/<'C[]T^_GL@LR3SB=L>;S^X`I[D3+>)Z+3W`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V-U+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#0Q-S,V,S`Q,P`P,C$W,#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____Z9VCW;6Z_
M6USQ@H/RW=Z^'"B['2NR(CS+L;BH56UI%#=+`B^7:I=2`&$_$(\L"J-H7JP$
M`7AW=KJ`?\6+BM*GIO:<F^8``,8#`\L%!<H%!<<&!\D&!L0+"\D-#=$/$,P0
M$-,6%](8&,T='=L?(-<A(=\9&9TG)]X=':`O+^@D):PR,N4U->TK++@Z.^PP
M,,4X.-TV-=`R,L-"0O0X.,U$1?(Y.<U&1O<Z.\-,3/=&1N104/I/3_E(2>)'
M1^!14?=04/-24O%65OE34_%75_%J:OI24K]45,%75\!=7<EK:]1H:,EN;LM\
M?.*,C.]\?-2#@]R5E?2+B^&4E.Z<G/";F^ZFIO.IJ=*VMMZMK<ZCH\+5U?G.
MSO&JJL.OK\BYN=+'Q]_5U>S@X/;%Q=C@X/76UNH#"<R-CJO$Q>R8F;?1TO>^
MO^!E:\F@I?2?H<J:ILRIL\_4U,W.SLC-S<?,S,;___GX^/+KZ^7HZ.+>WMC^
M_OG]_?C[^_;U]?#N[NG@X-O;V];8V-/$Q,"YN;7R\N[1T<W/S\O][>;'BX3H
M?G?/(AQ_``#$"0F)"@K*$1'2(""C(2'1+"S=,"^R*BKA.#C?.#CM4%#C4U/+
M5E;?8%_L:6CK=W;VV=GL[.S,S,S___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````##5`+[`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`">(4U
MK-S=C%1D)*65U/4L;8%"O3Q"^6%!OEX>GMX^_@'!H4"A_JG=G?.;2\I*BZLK
M*\KK&H!"DV8QS>$JBH]/2$Q*3DE+3P4*L<R;.YU=0%9>6=/`VL75P0(HQ,HV
M>V(?OY2"JK:IG9.-L2%0B'GFY`G<>7Z!(>'B$1)BHB)`H1E3>KH6M#=5U=?4
MMC5VM+0"A:9Q\!461$9EY<3&Y4;'9&<"A3@%,^04U73-'9WMS4ST=;2P>0<`
M8#8RK_S]W%@`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8W8N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P
M-#$W,S8S,#$S`#`R,3<Q,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___\6XNL.YN^79W/?K[MC-T-3)S.K?XN+7VO7J[;*H
MJ[VSMLB^P?+HZ_'GZNG?XL.VNO+EZ?'EZ<W"QL>YO\"SO,_"R\"RO&]K;C`K
M9D,]B59/J'1NN6IEGW9U@#@RDCLUDCLUD24A6C\XESTVDCXWDT`YE3\YDT`Y
MDSTWC$0^F4(\E$0^ET=!FTM%H$I$GD(]B%%+I$Y(G#<S;E),GU=1J$(]?EQ5
MKU1.H%I4K#\[=TI&B$9"@&)=LV=AMU-.DVMENVYHOEM6G5%-C%%-BF)=IG1N
MPFEDL'ARQ6MFL%I6E']YS7QWR7MVQW%LMG9QOF-?GH%[RW]YQWIUP8)]S(-]
MS'ETOH%\RH-]RH%\R&YJJX6`QWUXNW!LIX%\O8N&S(-^OY&,TX^+T9"+S960
MTUU;?45"FD],I593HV)?LUA5H%!.BUE7EG1QPH%]T6EFJG%NMH.`SVEGHXJ'
MTH:#S(:#RYR9V6-B?F5D?6%?H%54BWAVO'AVNXJ(TXB&S%I9?G=VG(V-I(F)
ME]?.G=#%DH2!<<.XC.;;K\6\GKRPG<J]J]K/Q>1;-=)8,\=`']=++LE;1<<W
M',8U',T^)+U3/_-O5M5D3OI\9.IT7NAS7?9^9_B,>/___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$!*(S4````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````OTE$050(UV-@P`*4E:T#4V,\C#64U`VL'/W"0$(FWBD)_I8Z
M2FIZ,O:>H5%`(2G7Q.0`,UU%56TC._>@R'"@D&UT4KR<I*&6BKZ%DV]$B!=0
MJ+B\OEF^.JTB(RNOJ*ZTI@`HQ,_7TBDHP=3=RB+$*LPIP@P4FC.KKW_RI"D3
M>J?-F#US^L2I0"$!]O8N,5'QG@XN+@XV7AYNH%!A9GI#979C4WY)66U!56X.
M4,A44T':I2TNUB=8ULW9P<8<FW<`C7`PN%65#=T`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C>2YP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-#8`,3`T,3<S-C,P,3,`,#(Q-S$S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____[>OM_/O\
M^_K[^/?XWMW>S<S-R<C)RLK+K*RMW-[@^OS]T-+3Z.OLS]/4Q\O,S]34]_S\
MT]C8R<W-S]+2\?/S^OO[^?KZ^/GY]O?WZ>KJT-'1Z_/QKL2UN<"[N,^^@Z>)
MN\&\J,FIK<.MP=7!\O;RS=#-]?;U]/7T[>[MXN/BU=;5QL?&T=K0]_?VX>'@
MR<G(L9R%[.?CR,"[PTH&OT@&OTH*PGQ4TI=WQYI_UL2ZV,[(P4D(PTD)R507
MV79%QW!!PFU!V8)7WYMYQ(MMZ*N-R*:5V\&SY,N^RTH0T9N![LJY\^[L]>_M
MW=K9[>OK^_KZR,?'Q\;&^_O[^OKZ^?GY^/CX]?7U]/3T\_/S\O+R\?'Q[N[N
M[>WMZNKJZ.CHYN;FY>7EXN+BX>'AX.#@W=W=W-S<V]O;V-C8T]/3T='1T-#0
MSL[.S<W-R\O+RLK*R<G)R,C(Q\?'QL;&P\/#P,#`OKZ^N[N[N+BXMK:VKZ^O
MKJZNI*2DFIJ:D)"0B(B(?7U]?'Q\____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````4\T<F@````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``AJ;
MZDI#HM-RBXKSLU+CPD.`0DWUE5$:R:)%Q46\W-(1H1%`H8::I'`^81,!$4$;
M3U]Q_7B@4*V,>("UNY.%E:6+CX1D;#I0J#10S-_1S-S4R\%8*#0F)1<H%!FA
MS>]J9VOO[.;'$YF4HPL4"DO(XE0R\O;0DV66BM<Q+`<*:646<,@KRBDHJX7&
M9N2750&%TO**2]C5550U66(,<DLKN8!".45!A3EL3*S,D8G9P175M=B\`P##
M=RT=9`&`3@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V-Z+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-P`Q
M,#0Q-S,V,S`Q,P`P,C$W,34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____&``/9*"FE`QFC#BIS"$!M$5)I$E`V$'`U%'77
MU]@%#9997\(%$)4,%I,P.:X`"%T.%V(1&G$F,:-06\8`%*`!%9T)&YL-'Y\*
M%FH2):48*ZH8*:$G.*HA+84P0*\J-HXX2+@X2+9!4+L[1Z)(6,)&5+!79LQ+
M6*U>;-%D<M5H==AF<])J>-AT@-E35W2OM=T,()X?,:908,=B:Z3GZ?-YA[^P
MM,7&Q\?@X-_-S<SRY^;.`P/0!07.!P?/#0W4$!#;%!3>&!C;'1W>(2&C&QOB
M)B;F*RNK(2'H+R^N(R.U)B:W*"CL-36Z*BJ]+"S#+B[`+2WO.CK(,C'%,##J
M.SK.-#3*,S/R/C[0-C7T0D+5.CKV1D;;/S[%.3G@0D+X2DK0/S_E1D;Y34WT
M34WI24GY3T_Y4%#Q3D[M3$SX45'T4%#V45'D3T_Y65GT6EKDV=GEV]O^]/3\
M\O+V[.S8S\_2R<G^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV]O;U]?7R\O+N[N[K
MZ^OHZ.CGY^?DY.3AX>'>WM[;V]O8V-C6UM;4U-32TM+1T='0T-#.SL[-S<W,
MS,R=G9W___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!\'[!B`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```,!)1$%4"-=C8,`"A`PF6S+6M_=.FM3?U=9850$4$A0V-:MI
M[9DX:4)W>U,-8RU02$J15]^0>\*DB3T=S76,U4U`(7EU'5$!30OKOLZ6AHK*
M1BN@D*J>AK(LCY%Y6:%-27%I43E02%=+Q5A"C(^=.2PUOR`O*1XHI*TF)RG.
MR>KL$9F2FQ83$@`4,E&0YF>S=W(/3LS.BHL(\@$**<EPL=@YNOK%9F0FA`?Z
M>@*%1#B8;!U<O*+3<Y*C0OV]W;!Y!P`6Z#!B',3\:`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9&4N<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#,T`#$P-#$W,S8S,#$S`#`R,38V-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]`U-L<Z
M.^=G:#H[.\:0`,>2!=.>$,V<&*R&(>RZ-=ZQ.,ZD-/?'1LB-`,F/`\J4!<B0
M"=&7#=RD'=^K(=*>'Z1\&^JS+Z^&([B0*+N0*L.:+M&D-?;!0N&U0N:W1OO(
M3_K+4/'$3L>:,/7$4,>$`,:%`\R*!\J,$M:5%.*C)K:%)MB@+\"/+>^S.LN8
M,]NG/OF_2NZW3/C!4>ZY4,@,`<<,`<X4"LD7#=DB&-,P)^4U*[XS+,DZ,?-'
M/M5".OI63>I12>A02/9:4?EK9,L``,<``*T!`,@#`ZT#`\\%!<P%!;('!\<)
M"=`-#=<0$`L!`;(2$KT4%-(8&-L='>,A(<\@(,HF)NDO+_$U-9,A(<8P,,(O
M+^$X.-(T-/5"0M@Z.OQ&1N)!0.1"0N5&1L<_/OY04/I/3_5.3O104.-*2ME,
M3/575^-14=E04+Y&1O5>7O1E9?YJ:A,*"A8-#1`*"B$8&#0K*R\G)T<^/C`J
M*E!(2%5-35E145!)26!966MD9&IJ:F5E95Y>7E=75U!04$]/3T9&1D)"0D%!
M03@X.#4U-3(R,B\O+R$A(1\?'QT='1D9&1@8&!$1$1`0$`T-#0D)"04%!0,#
M`____P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````+ZCH,8````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````M4E$0508TV7/L4T#
M01`%T#_S=P\P(!*@(PJ@"R,'!$@$2%`$<F`28OJ@#)"($"(Q3GQWOIW]2P%^
M'3Q@CP%XOGMD=YCGJSK5T(,#R_+D.:?YBZ+5!B3<_V0KV_B\_J`YS9#P?;%<
MK+>C\E<^FE$3'&^\^1NF(.D69=S!<:M^-Q6FS*YCO%88KC1*S=WIE-3>$S9C
MJ+E;HC<U"8:3JG8\G/8\MUB?:=,;+J,:+75,I1X,TN_^!__K3%8FB"AF+```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]D:RYP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#(`
M,3`T,3<S-C,P,3,`,#(Q-C<R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____T1$2Z"\P_VYO_6YOQ[N\RL7$__GXY^'@S0$`
MS```?P``S0$!S`$!S@,#S`,#T`4%S`4%S0D)U`H*U@T-V!`0BPH*SQ(2SA45
MWA@8WAH9TA@8E!$1X1T=VQX>Y"$AU"`?G1D9Z"8FIQL;ZRLKL"$A[B\OLB,C
MN28FW3`OO"@H\C4UORHJQ"TMQRXN]3HZV#,SRC`PLBHJIR@HZSDYX3@XU38U
MTC0TSS,S^#X^^D)"NS(R]4-#X#\^_$9&P38VY4)"_DI*S3T\ZD9&QCL[_TU-
M^$M+[DE)_T]/_E!0\DQ,_5%1]DY.X$='VD5%^U%1^5!0_E-3\5!0\E55\514
M_UI:_5I:[E55[%14^UU=U$Y.Z5E9_61D]V5ES%Y>SE]?U&QLVW%QU'!PY'Q\
MX8"`[HF)S(2$T(>'UHZ.S(F)W:*B[+*R^L+"_\G)T+^_V,G)Y-75\N/CX=/3
M_.[NY=C8TL;&_O'Q]NGI__/SS,+"UL[.X=K:U<_/U,[.^O3T^?/S^/+R[NCH
MZN3DTLW-SLK*S<K*]O;VY^?GX>'AV-C8T='1S\_/S<W-S,S,____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````E\[#R@````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"[241!5`C78V#``GAXE%SSVE-EA+@%Q11T[+U`0K(V<;D=
MB<+<_*)RZM:>@4`A<>.8V)RN!#Y>$2E5*[<`#Z"0231+:'9//!>3/+-M4'B(
M'U"(K;*BN*6O*K^@L*BDO**T#"C46,]9U];76EW35,_1T%S+#A1BC324S.I-
MEC9U#XN*\'=V``H%:TD(I'<G*1LX^7C;6>II`H7,@"[*Z$H!NLC7T4)?6PTH
MI`AT469G&M!%+N9&NAHJV+P#`"^2*\LB&S\E`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V1Z+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`T,@`Q,#0Q-S,V,S`Q,P`P,C$W,3$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____N1TCX
MYNC4RLO5U-7Y___X_/S!PL*RL[.RS\;9Z>/!R<3U^_<->2`%:A(@<R-*G$T`
M70``7```.0`#7@,%8`4%7P4)80D-9PT-9`T0;!`*1`H29Q(8;!@13!$==1TA
M>R$?=!\?<R`?<1\951DG=R<OA2\A72$J9RHXAC@XA3@X@S@R<#)!C$$Z>CL[
M>3M(DTA(DDA0F5!&AD97GU=7GE=>I%Y9FEEDJ61EIV5HJVAJK6H"8@$E=20H
M>"<P@2\P?B]!BT!FIV4.80<470DC:!@960HD7Q-1AC[@X-_5U=3-S<S2T,QE
M0Q)A/@UI,`%F+0!E+0/OY-[8M:>2-A2N1RRT;6'FMJZIBX;$KZO]]_:=&`;Y
MZ.:I$`/'E9"D%`KBM[3,``#,!07B65CGY>7>W-S.S<W^_O[]_?W\_/S[^_OZ
M^OKY^?GX^/CV]O;U]?7R\O+N[N[KZ^OJZNKEY>7DY.3AX>':VMK8V-C6UM;2
MTM+0T-#/S\_,S,S*RLK'Q\?$Q,2_O[^\O+RYN;FPL+"GIZ?___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#.J!:V````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+M)1$%4"-=C8,`"
M1$14]6W,=`1XZFHJRPJS,D!"\KI6YGI*'E'I5>5%.8RY0"$930M+0WO_F'"6
MM.(\QNPBH)"&B;6Q@U^<.Y=O:D%&9J$74,C`QE3++3F0/S(ED3TCO[0:*.1L
M[J3LFA3$%\\4P99;PEH/%+(T4I.R#4BPXV8&&E3APP$4,G:4%15R"0T+B04:
M5-O8`A32EA,7%I-6]`R.!AK4T-P*%%*1$!:55%`7Y,TM\:YOXFS#YAT`3U8K
M9Y<4FGX`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O96,N<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0S
M`#$P-#$W,S8S,#$S`#`R,38V-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/____E04;T`#L(%$[X%%,08):4A*[$H,[PO.<<T
M/]4X1-5"36-=8"`2P3@MN5Q0Y%Q1W1`#O3$GK3PPSCXTPTD_U0<`Q&5DXVQI
MU0$!S`D)S`T-SB(BTB<GV"LLPC(RS#,SQCHZVCDXT41#XDE)[DA([$E(YE!0
M^6!@]F1D_6AH]&NLLV:^N3Z5@4!Y:)F;FF*#:I.:E#M..EIN3V5Q75UD6$A,
M1:[!?Z2T>+C#?FAR'%)8)XB/)\S*`,[-!,W+"M;5#=32(*>G(=W<+^OI/.#@
M/N?E0?[^2G5U(_+R3/W]4?'Q4-341O_^:(F(0<S&`'][`-#)!<S&!=C2$(N'
M"M+-&)20$>'<'>3>(9V9&>[H+^'=+).1'O+L-;*N*K*O*N'<./CS/OKT0KVZ
M,KNW,OSW1I.0*\;".__Y3>[I2>OF2/_Y3_[Y4/OV4?GT4*>E-Y62,?;Q5Z>C
M/OKV7NGD6?WX9/?S9?_Z:K&N5,K'9\"[6\._8ZJF5]//<-S7==71=^#<B(R$
M(Y*.4J"4+6EE0JB>@I-T6(![=YQ^;=2'7LA5*).'@^=K4J6&A/!*1H)M;,P`
M`,T#`\T)"=8-#<8:&>`='=0@'Z<;&[(C(^XP,+\J*LHP,-4V->I&1O544O__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````!CRJ4T````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````O$E$0508&66/O0X!41"%Y\[]L2+81"$B2I52--Y"IZ;Q
M%IY!%!I/XCU6(T%'PU;+[MZY,V[O5"=?ON(<@+\H6$"SD]9Y$0*BM4EC;P!<
MJTN99U;81^L0#)@DE>](#_&5DW/H(WJ7.9>#:^;=---:***Y$5^>2Y*Z-[/"
MX:1@PK[B(5.0]KTKQ#<$";6(+)9V)1)\8-#@JR*HAQM/JLLS=OHJ:'EAM?L0
M*KWEZ%<*#A07H2G2]3$"ELW?'8`?S+ACH*V`6H0`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]E92YP;F<`````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#8`,3`T,3<S-C,P,3,`,#(Q-C<Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____.SH[
M-C4V:VMLXN+CQ\?(3$Y3(B0H,3,W0$)&4E18:6MO`@4*"0P1)RHO.SY#$#5G
M&E:E&U>H$39I&E*=&E*<'EJJ'UJI'UFF(UVJ(EJC*&.R)5J@*F2R&CUM(DE]
M,&:O,&:N-W"^.G._-VVT*E"$0G>]/6VN28'-383-.F"13G_!6Y':!0@,58?+
M16VC7I/95XC)3'6L9IK@9YG=9IC;8Y/478K'7(G%9I72;)G7<J'>:I+&>:3>
M=J#8?:CB%!<;%AD=35!44E591TI-'R`@LK.S[.WLX>+AU-74.CHY04%`U=74
MS,S+9F5E_O[^_/S\^OKZ^?GY]O;V\O+R[N[N[.SLZNKJY>7EY.3DXN+BX>'A
MV-C8UM;6U=75TM+2T-#0SL[.S<W-S,S,RLK*Q\?'P,#`O[^_O;V]O+R\N+BX
MM;6UL+"PJZNKIZ>G:FIJ7EY>6EI:5U=75E9645%14%!03T]/3DY.1T='1D9&
M0D)".#@X-34U-#0T,S,S,#`P+R\O(B(B(2$A'1T=&!@8%Q<7%!04$!`0#0T-
M#`P,"0D)!04%`P,#____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````DW(?Z@``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#`
M`@0%U8P=K'64)(4DY%2T#$V!0B(*!G8V1JI2PN(RRIJZ)F9`(7EM6WM+#5DQ
M46E%=7US*PN@$(<K#S>GHQXOGQ._`+N+,Q=0B*F@N*:UAZ&GH[FVJJRBN@XH
MY%_HX];-T-O9TEA=7E;%W``48BEK:.OJ:F^JK2PI*JWVK@<*>?IE9F=GLL6S
MAGM$)Z;GY`&%8A)24A)CHT(#`T(B$]*R<H%"7LDI27$Q84&,P1&^J1GN^=B\
M`P"K\"Y5BU[=!`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V5G+G!N9P``````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T
M-0`Q,#0Q-S,V,S`Q,P`P,C$V-S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#____#&!K%&1J'&1K&OK_5SL]965LV-C?"PL5&
M1TGU]OAH:6K'RLSL\/+W^?K)R\S#Q<8B(R/W^OKQ]/3.T='-T-#[_?WZ_/SA
MX^/=W]\?(!_(R<C&QK4V-C5-34Q'1T9:6EG)R,'?V\33Q87*N7/MZ^+3QYK3
MM%3>Q'/@T9[KX<#+PZG+P[[&OKO'``!]``!\``#(`P/+!07(!07("0G0#0W3
M$!#.&!B0$1'<'1W@(2'/'Q_+(2&:&1G&(R/I+R_5+B[M-37=.#CU0D*X,C+X
M1D;1.SOB04'#.SOZ3T_[4%#U4%"L.3GP4U/R5U?U7E[W86'H7%SE6UOT963S
M967[:FKC:6GV=77BVMJDGI[7T-#)PL+X\?'OZ.CMYN;;U=70RLKZ]/3LYN;$
MP\/\_/SW]_?V]O;U]?7R\O+GY^?EY>7DY.3CX^/2TM+1T='.SL[*RLK$Q,3!
MP<&ZNKIN;FYL;&QH:&A04%!/3T].3DY&1D9"0D(_/S\X.#@U-34T-#0R,C(P
M,#`O+R\N+BXJ*BHI*2DH*"@E)24C(R,A(2$='1T;&QL8&!@0$!`-#0T)"0D%
M!04#`P/___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#APUMR`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```+Y)1$%4&--MS#T.`4$8QO'W:W:Q=ED1)U`JG(5$G$&C
MTW$!%;U(=!J%A#LH5+0JB4;K:^R,,3W_\LF3'\!/"$V,HUC?[B83D5#4A@!S
M8?&MM<V869$@$!RJ%6;'^V,4)4E<"$"@$R*^\LN&V[65`T)OI8$-S+.<<^ZJ
ME%'FZE\N()Z7#!*VB&7E+0SE0?KA,#,B2KI^2M9IO3:\G$^77K*-5GEOC4K2
MGUAS-Y9(A'E`,./^]&.U_0`N",<$?_H"][(]I"TOU:``````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O97(N<&YG````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W,S8S,#$S`#`R,3<P,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___Y8Q
M-*Q05,AV>[ER>I=88G=-;I5TE*>+J8=QD&!MIH.2RH&2QF%UIEU[M3]:C$]P
MJD9AE$ADETQHG4YKGU!MHE9SJEAUK%]^MGJ?X7N@X'"0RGN<V5Z'S5-SJ66)
MQ6J-R59]N6N9X'.=W4^9*U>9.%V;/FNK3"AS`"IW`V*G/G>P5S)T!3A]#4"`
M&&NG0G.P37:P3W>O42YP`#)S!3U^$$F('4V,(5J8+U^<-6^J1FZD27>P4':M
M4'JN44N!&#UP"I6V:H^;3%]@#7%K(WUV-'YR/;MJ"L)Z(\:!*Z%X1?.V;JMW
M0+I;![E=!_&M;+E?$LQ[->N@8H4_";U@&<>"2]1]1:YO1[A("KE)$;Q0&W4\
M']I]3\]M0+8\"K4^#-QX4.2#7MJ"8,]S5KQ$(L%-,+980NN&;+,H#*<H#.:#
M;=5#*N5:0L=/.J!#,N]G4&X5![LE#;`B#[0G$,<Q&KXQ'<4W),,[);HV),<\
M*<Q!+<E%,M-)-=9..\M30^)@3NIH5.IK6.%W9[<:!KT>"F\4"+4@#K,B$+DD
M$K4D$;HI%KPL&GL>$L8Q(;LR(80E&94V*MU20=U;2ME92^MK6]QI6N!O8NEZ
M;G01"+0@$<`C%;HG&NU?4]UG6^IX;ZY#/,!.2?___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#5ZO\`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@
MP`)F%L:X.^FHZ9N:Z)I96%G;`H7:)BR8WQSAZJBII6=N:6!D!Q3JS4_.2*R9
MDQ7BXJ"J;6AL`Q2:&!8P+RBTHWUV7YJOL[V&.E`HW2<I+M4CLZNL>M+<J2G>
M;D"A[.!PSRB_DIZJNH:FQLD+V8!",V*]`OTCN\MK<PNFLW+Q"0*%IN5%)\1W
MEN9,8>'D55"2%P$*U5?.:FGM9^;@D591Y!<7%0(*5105,[%SRRE+R<I(2H@)
M"V#S#@`;)C+Q94(]]0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]E<RYP;F<`````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M-3``,3`T,3<S-C,P,3,`,#(Q-S`R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____>UU@AVEWJK@HM,,KWN@F[_4ZT=DSRL\S
M^/Y*R,H`RLP#S,X'UM@4XN4FYN@KM;DFS,XMP,0M[_(ZV^`^W-X^^?M*[?),
M^/U1^/I1[?%0T=-&^?MD^?QH]/9E^OQMQ\0!Q\4!RLH%S<P*T,\-R<<-T],0
MOKX4V=D8V-88V]P=W]\AY>,KZ>DOI*4A[.TUOKXLQL<PKJPJR<DQSLXT\_0^
M\O`^T-`V]?5"U=8Z]_=&X>%"P\,[^OM-Y>5&^?A-ZNA)ZNI)^OI/^OI0[N],
M\?%.]O=1]/10]O51Y>19TM)6[^]LB(8*\_!CY=U-Z>)FGY<\I98.HH\7H84E
MC&P1P:ISM)-%NHPUNHQ.PW\\S)IOP%<&QEL'V'$CCDL9JELAZ8$UP6TNVWXX
MWH5"]Y=0Q%,"TF$0CTT>M6$HS'$T]8Q&R5\9[XY.JE<IC652]X)>Q2L`>QL`
MQRX#QC()SS<-CRT1VD8=SD8?Z%@O]&E"MT\RXF1!^71/]'10](9EE59$;#DO
MR```QP``?0``?```R@,#RP4%R`4%R`D)T@T-TQ`0SA@8W!T=X"$AT2`?FAD9
MI!L;ZR\OKR,C[34UNRHJQS`PW3@XT38U]D)"^$9&YD9&PSL[^T]/_%!0]5!0
M\E=7^VIJ____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````@*2J"`````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```#!241!5`C78V#``EI:)\Q9N&!Z3T=S>W??E%GS@$)%
M9=7U!345)87%I>655;5U0"%?8R\?;R$U1245+5US!T]'H)"^C%Q8?@@/-R\?
MOXBXE*L84,A6(2"J(5!#65W'P-K%S<84*"3O%YW'Q!RNJJUGZ>QA;V$$%)+U
MC\QHC(_0%#"S<W>R,C$$"DESL`2%!K.RL7-)2HAR"@L"A9)S8M)BT^,2LU-S
M4[*2,A.`0OV=36U=O9-FSIT_>\:TJ9,G8O,.`!]E,O'N;H#)`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5T+G!N9P``````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S,@`Q,#0Q-S,V,S`Q,P`P,C$W,#,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____A
M(23Y45;*25K47&U=:XR`FL`4>+@GB<4,=*@YF<L0=J97KM`CBZ]AMM)>K\,V
MAY-EN\@-<7T4<G`YBXIFL+!`BX9$CHF-R[AJK)59FWUMKX=9F7!VKX-AG&X`
M6Q`)8!9AG&EMIW8=="0M>"\Z>#L`6@``.```-P`#7`,%7@4%704-90T0:!`8
M:A@121$=<ATA=R$?;Q\94QDO@R\UB#4X@CA"DD(R;C)&ED9!B4%/G$]0G5!0
MFE!7G%=>HEYEI65JJVIDG&2(P8@N:"I3GDU7GU%>FUEIJ60/10HR@BM%DCY/
MDTA/E$ESJ6Q\LW64G"'&SR_<YCK)TC[D[TK;Y$SE[U';Y%#`R4;I\FCW_E;*
MS0SEYT'HZD;Z_$[X^E[,RP'-S`[2TAK4U2#7UBC!P"S,RS+)RC'AX3C2TC74
MU#;9V#KEY4/'QCON[$GKZDG^_E#V]D[Y^5#Z^5+V]E?[^F7W]V;__VK,,`#=
M6"_@9#[R<TSQ=E#,,0///A*Y2";$4"W/5S.],QKF=F?,``#.`P/0!07,!07-
M"0G6#0W8$!#2&!CA'1W4(!^G&QNP(2'N+R^R(R.\*"B_*BK'+B[*,##A.#C5
M-C72-#3Z0D+E0D+J1D;_3T_V3D[Y4%#___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#GP_ZF
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+-)1$%4&--M
MP4U.`D$0!M"OJ@N;&=`1$A>@F+A!EU[)*W@%#L"!7)IX!O9N6!A)",+873\<
M0-\#_B`\8;R_L[ZW*DE$TKN`\N#65??1<DK,!,%#322;W9'SY)$*90AR1U[N
M/V_\NQGR*!R"16N'\M'QQ>0PGE(U,)KMMOY:>:X:RE_N8,3UT`>71DMM9WJE
M#D&6+NK+ZHW+:Y]S!`3S'[5&U,GGYNH&P<F,$J^;Q&8>$?C'&9V64*IQ1UZL
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O9FDN<&YG````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,#0U`#$P-#$W,S8S,#$T`#`R,38W-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___\W,SL'!QL7%R?'Q]._O\<;&R/O[_/+R
M\^_O\-W=WMK:V\W-SL+"P[>WN`4181`;:R$L>34_BCA"A30]>T90F4)+C#M"
M>E!:GTY7FE=@GFIRK7I_HI.8NIJ>N:JNRP<591TK>!TK=S9!?T%,C5!<GE=B
MH%YIIF9PJ7Z'NF9ME82*K&QPB+"UU*>LR;*WU;W!VP458PL;9@T<:Q`?;10C
M;!DH;1PI;R`O=Q\M<R`M<R<T>2@U>2T\@R\^B"HX>3`\=SM*CT)0ESA$?CY*
MB$%.BT)/C$92D4]<H%!;D%]JH55?C7)]LGB#MH>1OZ.IR9:;LP068P068@<8
M90D;90P=9PP<90\A;!LK<5=DG4U8A&AUK%YIF'6!MFUXJ6]ZJ[6WP,[0V;_!
MR=S>YN3F[K_`Q,+#QOK[_+*SL]35U-75U/[^_OW]_?S\_/O[^_KZ^OGY^?CX
M^/;V]O+R\N[N[NOKZ^KJZNGIZ>7EY>3DY.'AX=[>WMC8V-;6UM34U-+2TM#0
MT,[.SLW-S<S,S,K*RL?'Q[^_O[R\O+N[N[*RLK"PL*>GIYV=G924E(N+BW]_
M?____P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````%6RKK\````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````ODE$050(UV-@P`(F3.A-UU)W3VYI::RM*LG+`0GU
M=;+ZJCHDMC3559<6,!8"A?J[*G*];<S3FNMKRHH8\TN!0KJ!AOJN9N':LCIR
M`7H&"O)`(0D9:9'(T&`!02%A,4DI<5&@D*:&JE584(B)DKVSIYJ'BB-0R#_>
MR\78*,(M*B;.+R'6)QHHQ,7#Q&RA:)G$R9'!QLW+QP\4JFYH8;<VM4O)RRFN
M;&CKZ`8*936WL-@J.Z4R%I9GM[9G]F#S#@#PGR]>Y"("30````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]F:BYP;F<`````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T,3<S-C,P,30`,#(Q-C<S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MG8N1KI.>IXZ9WL72E8J08DQ9N*BSFW^3BFF"O["\H)N@9UQHR[K-O[3%@&F.
MT<?>?G>?J:'+<G"+FYK':FN(4E:54EJ9<7^SM,C499.JK\_?J]#A:9NP:IJO
M;)VQ=Z.V<9RML-#=L,'(>+/(<*6X:YZP;9ZPA[_3<J"PA;G,=J2UE\WAC+S-
M<9>E<YBEG<[@=YNHFLC8G,K:I]3DIM/CA*:SJ]?G?IVIJ=+BF+W+E:RU<*[#
M:J.V;)^P;)ZO<:6V;Z.S;J*R;J"Q=JJ[<Z6U<*"P@;/$>ZNZD<?8?Z^^<)FG
MA;7%A+3$98B4BKG(D,#0;I.?D+_.>Z.PA*Z\E<33>J"M>)ZJAJ^]@:BU?J6Q
MG\_>AZVZI-+AE\'.B[&^J=;DG<;3K-CFH,G6K]GGI]#=IL[;M=SIM,?-:Z"P
M>[/$=JBW>ZFW?JRZA;/`@:VZ;9&<@*JVC+?#I]CGDKW*J=CFJMCF;J.QKLS4
MG*RNT-[=L+2?RLVKPZE?N[BQX:5`[K%-O;JVVZIKV,BTSGLOYYYBJZ:CQZRD
MZJ23YXIVZI:$XJ"3NT<TT%]+]8!KZG]JPFU>[XIYWX1SE&)9YJN@J5=*['UM
M[(1TUWAIN89_][>NOT<X@3`FQHN(=4I(M'IXQ:2C____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````ZCQ=
MVP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C7
M8V#``MAYQ28*\O%+RCNKJ6KJEJ0"A>9/F35I]M1Y"WSL+)G:ZZ5,@4)SIW7U
M3^B;TZMOR];:T-AA"!02X6"=P<TL(*Z07577UMP4#!1B$1:=*23!R:6H75G;
MV9(9"A22D;4V5Y*6*_+S4NF>/IDG#RB4D9+OF%61XQ$84U[=4Q,;#A1*+];1
ML'?SUC-)+%->:!-B`!0JS757=_(,,#9+3HN/C#8J!`H5:#FXN/J&Q5E8)25$
M103Y8_,.`*'P,O$,[RM8`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V9O+G!N9P``````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C`T,@`Q,#0Q-S,V,S`Q-``P,C$W,#$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#____%"`G""0K`$Q7!'"'**S"_+3*\+S79
M/4*X.S_#047E3U343%#745;K6V#F7&#H:6WH<'2T(RJ\+37)/4774%>\2U')
M45CC86C.6F"S3E3F:G#>9FW?;G3J?X6G,#NP-T&S2%*K.$2V04W`35C+6F7"
M7FCZ^?J?CZ"6AYJ4AIC2R=?*PM"[LL*&>I&BFJVLK*W=[OFCOLV_W.RIPM#)
MY/3'XO&\U>2GO<JIO\N\T^#.YO2)F:+*X>ZQQ="[S]K5Z_?.X^^TQ<^(L<>4
MOM2QT."4K+B=ML.EOLNZU.*NQM/%W.C,X>S6Z_:/M\G8[??(Y?'!S,S$SLZ^
MQ\?O]_?&S,SW_?W\_?RQL:_\_/OU]?3Q\?#AX>#>WMW;V]K.SLW-S<S#P\*Y
MN;B+BXK[^OC,R\G+RLC^_?S[^OGW]O7N[>SJZ>CIZ.?=W-O3TM'/SLW'``#+
M`0''!07,!P?3$!#,$A+<'1W4)R?C04'S5U?<V]O(Q\?'QL:YN+B;FIKZ^OKX
M^/CU]?7Q\?'M[>WIZ>GFYN;@X.#>WM[3T]/2TM+1T='0T-#.SL[-S<W+R\O(
MR,C'Q\?#P\.[N[NXN+BOKZ^DI*20D)!]?7U\?'S___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````:WB!F`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```+M)1$%4&--MP4%*0F$4!M#ON_?'0/0%U<"!H`-1
M*DEP"\U;0//VX3+<A`MP#R).!)UH$#RJ03Z4"E[OWML"ZAS@#V+*?+UYF+4&
MMUZZ64P$\"#CIV38T3T$"8O/*V&0Y3[\X%9#PK:V[8A;_?6]4&W&"0F[%'EQ
M_W(BJ4HS)'Q'59K'D:I*MT#"3?;6?F:GQP\A[3+F"5WMYY7HV?F%B(@0@N&H
M407YE:VN.1J/EQ"(@"',XE'O"O()__@%?$5-+`"L)QH`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9G(N<&YG````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#$U`#$P-#$W,S8S,#$T`#`R,3<P
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_]`U-N[M\0``QP``Q@``?`,#R0,#Q@4%QPD)R`T-R0H*B!(2RA@8S1$1D!\@
MT!D9F2<GTR0DQ"4EPR$AI"DIQS`PV"LKQ#`PS2HJKC@XW3@XW#(RN#DYRD%!
MXCH[PSLZPTA(Z$9&T5!0[5=7\4Y.U5Y>]5E9Y61D^61D^&AG^F5E\V9E\VIJ
M^F5EY7EY\X2$^,?'R\/#Q\+"QM?7V\_/T\[.TM[>X<;&R>_O\-O;W/K]_L[3
MT\C-S<;+R^GN[OG]_?7Y^?/W]]_CX];:VN7FYM+2S]'1SLO+R,G)QNSLZN'A
MW]C8ULO+R=[>W=G9V-(8&-\A(=LD)*0;&ZPA(>DO+Z\C([4F)N4S,K@H*.PU
M-;LJ*KTL+,,N+L`M+<<P,,DR,<8P,,XT-,LS,_,^/O5"0N]!0=4Z.O=&1ML_
M/M`\/.%"0OE*2OI-3>5&1NI)2?I/3_=.3OI04.Y,3/%.3N!(2/A14?=14?10
M4/E65NU34_986,>PL,VVMM6_O]_)R>G4U/+=W>_;V^/0T/?CX_;BXLC'Q_O[
M^_?W]_;V]NSL[.+BXM/3T]#0T,W-S<S,S,K*RLC(R,?'Q____P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````+*-
M43(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````IDE$0508
MTVW!P4T#,1`%T#_CC6-C*RC%<$-1"D"B!"KB2A6((B@!T0E9>==CSZ<`>`_X
M0Q!1[L]?3]?E_?(M^73WJD"NE0_;!HHN)44LB*4X_5A)B34=&Q0YA]["@"<Y
MI3PZ%M326C#XI!3Q;8>B[GWMX/P8DF)_(Q3#?FR0GR4$;?N+06&K3?+P>'-A
M'VY0;&W,<""?;=K>;4)Q&Z;!2499IT_B'[_D,UD(NIC:?P````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]G82YP;F<`````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(P,#8`,3`T,3<S-C,P,30`,#(Q-C8T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____(3QC*$1L-%)]4'&@`"=>!2QB!2QA
M$#=L&#QM(4=[-5F++DQT.%F&1FF:0F&,3FZ;!RU:"2]<'SE9)T)B+DIK-5)T
M576<#S1?$SEE(TAS)4AP-5F#.UE[2&N32VJ.576:0%E:+4A(+TE),TY./%14
M4&IJ1EE95FQL3F)B8WM[5FIJ<8F)<XF)<8:&=XV-8G=V`$,`09=!7J]>`6L`
M!&T#"F\)#G8-$E41'H,=('X?,),O0Z)",WHR4*M/4:A09K%E!FX`.IHU/X8[
M;KIJ!$4`!$0`"W(%#'`%%GP0'GP8)XHA'6`9/9,X3*A&5JY07*Q7(WL!(WH!
M*X(*+8`-(%<*.8X81)$G2ITK0'LJ7:T^:K=-8ZI(9*M);;=1<:]9?;]DP,0`
MO\,#Q,@'Q,<2SM(4W-\FGZ$ATM4OZ>TZUMD^\_9*Z.M,\O91R\Y&Y^I0]?AH
MR<@`Q<4"P\,"R\H#S<P%R<D%RLD)R\L*T](-QL8.U=00UM89S\X8WMT=X>`A
MTM$@T=$HXN,LZ^LO[^XUN[PLR,@PT=`TW]XXQL8RTM$V\/`^]_="T],Z^OE&
MY.-`XN)"Q<0[Y^9&_/Q/]_=._/M0Y>5)\_).Y^=*]O50]/12\_-7]_=>]_=E
M]O5E_?QJ____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````Q)2KM`````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"?241!5!C39<_!4<-`$`3`F=F53J:$'[QY\N+A
M,!POX1"$H2@P%J>[VR4`=P8-W"'.G#>N8T2=I6WEF^-2)OOY7'I0$K\(QXO/
M[&U$RB1:PO%4E+5'2C0I`X[78__XK<UGGQZ*Z@;A<5S_]F9NODS>]H20^_?>
MZ>;+4K)E@CBU$:DQN2S5(MZ)8X^@1+NM>3W<,HCG45DHU4-&S<S+_0?_:99/
M2P>OJLH`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=E+G!N9P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(Q,0`Q,#0Q-S,V,S`Q-``P,C$V
M-C4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```!@%!,5$4```#_
M__^(-39Q<''__O\Z.SM?8&"5EI7Q[>QJ``!G`0!K`0%I`0%L`P-K`P-N!05M
M!05K!05P!P=R"0EN"0ER"@IO#`QU#0UP#0UX$!!T$A)[%!1T%!1_&!A^&!A\
M&!AX&!B"'1V&(2%](!]D&QN*)B:.*RN!)R=J("!K(2%]*"B2+R^"*BIM(R-R
M)B:),"]T*"B6-35_+2UW*BI\+2U^+BY[+2UY+"R:.CJ",C&`,#"$,S.0.#B(
M-C6&-#2>/CZB0D*-.CJE1D:2/SZD1D:60D*G2DI^.#B;1D:I34V:1D:J3T^>
M24F<2$BJ4%"B3$RJ45&E3DZI45&G4%";2DJC4%"R9&2S9V>U;F[%OK[=U]?.
MR<G#OK[[]O9$0T/.S,RSL;%85U?=W-SQ\?'=W=W4U-3+R\NGIZ=J:FIH:&@U
M-349&1D3$Q,"`@+___\`````````````````````````````````````````
M``````````````````````````!MGMGA`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```*))1$%4"-=C8,`*LEDS$MWE!3CY)94,G?R``KDY
M69EL<1K"G+SBBMH.WL%`(6;VM)2T!!,>;E$Y-7O/(!^@4'HJ2W)2O!&7D+2J
MA5N`OS-0*":6(RHZ4DL0;%"@JQU0*"(\1$=&3`!BD!>3%5`HS%==@H='5!9L
MD*.E.5`H5%^*CQ-FD+69'E#(1@'B(A>00:8&FD`A91&8BSQLK8QU5;!Y!@#=
M'R"B:9:M$@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=I+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-``Q,#0Q-S,V,S`Q
M-``P,C$V-S8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___]Y$A/:-C?/<'&/3D___O_5U-7'QL?*S<W^___4U=7&Q\?!PL+G
MY^;@X-_-S<S(Q,/Q437Y7D+\74;E64/Q9U>KGIW_5D^]GIW,``![``#.`P.)
M`P/0!07,!05V!07-"0F="`C6#0W8$!"1#0VX$A*O$Q/2&!CA'1VO&!CD(2'4
M(!^X&QNG&QO`(2"P(2&8'1W/*"CN+R^R(R.T)26\*"B_*BJ6(2''+BZ%'Q_*
M,##A.#C5-C72-#3`,S.P+R_E0D+J1D;^4%#V3D[<1D:.+BWY4%"<-C:(,"_,
M4E'\:6G\;F[I;&S,:&BT86'0='.P966.4E+QC8RY;V_=AH7$>'C/@8'@CX_Q
MH:#2BXNUEY>OH*#X]?7[^?GX]_?=W-S/SL[^_O[]_?W\_/S[^_OZ^OKY^?GX
M^/CW]_?V]O;U]?7R\O+Q\?'N[N[L[.SKZ^OJZNKIZ>GGY^?EY>7DY.3AX>':
MVMK8V-C6UM;4U-32TM+0T-#.SL[,S,S*RLJ[N[NRLK*GIZ>=G9V4E)2+BXM_
M?W____\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"[/6X\`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+U)1$%4"-=C8,`"VMJ:>1BSRJKKZFHJ2G-2DD!"+0V9:<55XC&UE65Y:8SI
M0*'6QJ+D_.@@*S=6R8(,QM0\H%!3%5MN0J"2NJE65'92<@X_4(@#:%"BI[0"
MDX5_7%)62350*#Z-CYO30U;5T"&`*[V0O1XHE)Q?42NHJZ9O[^H;FU<NP`L4
MB@QE\?,R8A85\_8)C@@/"P$*V6C(2\FI:`N).+LXVEF:&0"%=!2E9)0UC84E
MW)ULK<U-]+!Y!P"2/BT;-=4)*0````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O9VPN<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#0S`#$P-#$W,S8S,#$T`#`R,3<P,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/____E04=535-:NK\;'Q^#@
MW^G1T,T!`,P``,T!`<P!`<X#`\P#`\P$!,P%!=$'!]`)"<T)"<P)"<X-#=0/
M#\\2$ML4%-@4%-(8&,P8&-(<'-0?']0@'^0B(J<;&]@G)[`A(;(C([DF)MTO
M+]TP+[PH*+\J*L0M+<$L+,<N+LHP,,TR,>$X.-4V-=(T-,\S,]HZ.M8Z.O)$
M0^`_/N=!0>5"0NI&1NY)2>Q(2/),3/904/%04/M75\]+2^A75\I-3?UD9.ID
M9/EM;?UQ<?9S<_]Z><QA8?IY>/^!@?I^?OB`@/V<G.&.CO^DI.&9F<Z-C?JS
ML_ZXM]*7E^ZSL]ZHJ-BCH^>VMLRDI,ZFILVFIO;)R>&ZNOK0T.[+R]2UM??6
MUO_BXOSIZ<R_O__W]__Y^?;R\N7AX=+.SM#.SL?%Q?7T]/[^_OW]_?S\_/O[
M^_KZ^OGY^?CX^/7U]?+R\N[N[NOKZ^CHZ.3DY.'AX=[>WMO;V]C8V-;6UM34
MU-'1T=#0T,[.SLW-S<S,S+N[N[*RLJ>GIYV=G924E(N+BW]_?____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$@G7?P````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````O$E$050(UV-@P`*ZNMI94Z/]@Y.;
M&VHJ2O)R0$(=+0D>IC)"4@&UE:4%C(5`H<Y6=A=+!1%N+M'0LB+&_%*@4%N=
MGXV*&"^'@+A]=DYN"1M0*"O%55=:F$]00LXX*2<M/0,HY.T5'A\5$<D2$Q?K
MYNS$[``4<K0,:VQNJJLJ*TJTM3#4T00*V:C:-3?75Y<7Y_A8F1AH*`.%="7Y
MW3-!+@JR-M/74E,$"LD*<?(8^88$>C*9ZVFK*\EC\PX`V#0N,]O3E\@`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G<"YP;F<`
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S,`,3`T,3<S-C,P
M,30`,#(Q-S`S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____U34VQSH[_V=H?SL\S%]ASF)CS61FUFMLE$Y/X7AZU'1U[HF*
M^IB:NW)SYXZ/_Z&C^9^@TG9ZY(2(L&EL\I28O'-VQWQ^X8Z1_**FY927_JBL
M^J:H]J.F]ZBKS&9KT&EPS&=NV'1YTH2(2;U64L5?8-%M2YM45*=>;M%Y9;UO
M9[EPC/"7BNN50KE.*7,P1KU21;I11[M34,5<3;U95,%?8-)K1)%+7L9I<>!]
M<=]]7;)F;<AV@>N+@NN-B.Z3?]R(BN>3F?&BU-4@S;T)X=(XTI<8S'\!YZ)`
M]K-7SG4-\9M0V'(GS%@%_XUJS",`S1$!W3\OSQL2^F=>S`8`S0$`S```S0$!
MS`$!S@0#S`,#T`4%T0<'U`H*U@T-S@T-V!`0BPH*SQ(2VQ04WA@8X1T=Y"$A
MZ"8FZRLKV"<G[B\OIR$AN28FW3`O\C4UQ"TMP2PL]3HZRC`PLBHJS3(QTC0T
MSS,S^#X^^D)"VCHZX#\^_$9&Y4)"_DI*ZD9&_TU-[DE)[$A(_T]/_E!0\DQ,
M_5%1]DY.^U%1^5!0\5!0U$9&Z5E9_61D^&5E____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````?856WP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"T241!5`C78V#``@P,+'2<G;3,C/0-3<RM[!R`0JQ<_/*R`CP<;.R<W+Q\
M@D)`H:22GMZFK(3(B+C4S(J&CD:@4$XWBT]0<G18;$I&45U;:S50B-G?R\W=
M+S0F,3V_IJ6]M@PHU!?BZ>(:$!6?EEW9W%G/5`P4ZFWR]?8(A!I455H(%.K*
M"XX.AQE47I`+%)(45E)05!81DY*1DU:1$!<%"EF:&JNJJ5O;Z^HYVFK;:&I@
M\PX`*X8P#Q?/^D8`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V=R+G!N9P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`U,``Q,#0Q-S,V,S`Q-``P,C$W,#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^(AYI!0*-*2;@[.I);
M6JF1D-4``%`*"H@,#(D.#H@.#H<1$8X6%H\8&(L8&(D:&I`='9DD))HO+Z<W
M-ZDP,)0Q,94M+8DX.*,T-))"0K<V-I8N+GP[.YXC(UU`0*@[.YLF)EY&1JI2
M4\)!09I*2JI$1)E45+M96<186,)34[986+Q<7,%<7+E45*!J:L=M;<=@8*IL
M;+QQ<<-X>,YW=\IF9JEG9Z=_?\MP<+-K:ZEJ:J=O;ZUN;JMN;JIM;:E^?K]Y
M>;9X>+1V=J]34WN.CM&-C<]Z>K*/C\Z&AL%]?;2(B,.`@+5K:Y>=G=IT=*&6
MEL^'A[J;F]68F-&0D,:0D,2&AK9^?JNDI-Z>GM:FIMV6EL>5E<:LK.&JJM^E
MI=><G,JLK-R;F[B=G;J>GKJ>GKFFIL*@H+NHJ,.@H+JRLLVTM,[!P=RMK<6L
MK,3#P]R2DJ7.SNB=G;'0T.FGI[O5U>[1T>G2TNFQL<77U^[%Q=J]O<6_O\:\
MO,."@H?*RM'$Q,NVMKR3DYCQ\?CIZ?#?W^;<W.//S]7-S=/#P\F^OL3S\_GQ
M\??N[O3FYNSAX>?:VN#!P<;Q\?;DY.G5U=JSL[?S\_?%Q<C?W^'DY.5X>;&D
MI=SHZ>_GZ.[-SM.JJZW___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C;_PV`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"..2;U0TL8SWL
MK6V=?$*BXX!"2J[3@MT3\U*34]*S<XO*RH%"]0MF39\2),##S2<LRJ*EJPT4
MDO7N,6%VF='=U3EQ7N_D_JE`(5;VN0K\8A;F5HZ>_I%1H;Y`(;>DF4:J,N)R
M:GJ&IF;&;/I`H9:VAMJZFL:.]M;>O@GS)S4!A70D!;DX>85$I%4T-905I22`
M0F&S'6SLG+T"Y\0GQ(1'!/@!A?*STC(R<PI*JBJJ*TN+"YFP>0<`3[8RW<:V
M1_4`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9W0N<&YG
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W,S8S
M,#$T`#`R,3<P-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___]38VWR^Y(+#YQ50;1=.:2=\J"9XHBA\IRAYHRU]I2^`J2)9
M=3%^ISB$JD*7PC^0N#V(K2M@>C%JAD&*L#5QCSESD#QWEDV7O#YZF$N1M4)_
MGD:$HTN,K4B'IE*7NE>@Q$Z.KE*4M4N(IE>;OV"LTENCQU*2LDV*J%*1L&BV
MW5*/KE:5M5J:NE20KEZAPDZ%H&*DQ5R:N6FMT&:HR6.DQ&ZSV'"WVG*YW'&W
MVW&XVVZSU6FJRW"TUFVPT7.XVW.WV6ZOT':VUG6TTX#"XWV]W7V[VH&_WH"^
MW7:OS("[VH;"X(C#X>[R]/3V]U>IT5.AQT6!GD5\EE&/K6>QU5R>OF^]XVNU
MV6>KS&^SU&*<N&JHQLW2U#^0K4N8LS.)IC2*IS>-JCZ5LUREOG&VS83'W(W0
MY^7IZL_6ULG0T-'7U]_EY=OAX?C]_<[0T/7V]LC-R[6YM[W&P:&NI>WQ[K/%
MMY*AE:2PIFJ#;'Z3?L32PVR&8GV.=J"SF%MQ2W&&8FV`7\')N[3"IXN:?'F"
M;'%]7X*'3ZZP?]G9U\7%Q,C$6,;$A).2?Z^KH/[^_OS\_/KZ^OGY^?+R\N[N
M[N3DY.'AX=34U-+2TM'1T<[.SLW-S<S,S/___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````&8_-,<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````P4E$050(UV-@P`)8V41TT@NFS9@S)U]0($`['"C$)FSHG98S??:<6;&2
M@:&6%D`AWF`OS]3LKJ+RF4SJ:E:.)D`A\6@?IY3BFH[VRC+S"`=[`Z"0OJ^S
M:GQ%2T]W8QVS=929,E#(P]U(-*ZDK:^WOIG%SE17"2CD:BO-EUC8VE!5Z^\6
MJ1<B#Q2R4>#G2LCJ;*HNS7,)TU*1`0HI"G%S)&5.G3RAWR]&0S-(`B@DR,/)
MGIP[92+CI`QC.5DI,6S>`0"'>S$FD!!Z%P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]G=2YP;F<`````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-3``,3`T,3<S-C,P,30`,#(Q-S`W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____@WAZE'V(4DA:<%Z'
M64IN5TY]3DEH;&6.241F+2=>5U**.#9?0T6`$!=8&21C(2QM%"%@5&*@$R9F
M`!A=!1YB)S^!/E*(.TZ!`AYD!B!@!R!@""%A"2)B"R5D#"=G#"5C#RAE$RQK
M#1Y)$RMH%S!N&#!K'#=W'C5P(CMY)3QU+$-Z,4F%+4-Z)#9B-4V)+3]N-4J!
M.E*++3]J/U>2,T9V,D5T/%.*.4U_.$Q]-TIZ1%N51U^9-DAS/U.%/E!^1EN.
M1%B*1UR/4&:?1UR.2U^35&NB4VF@3F.736*546::5FRB4VB=56J?5VRA56F<
M7'"A87:H8G:G9WRN76^=:'RL:7RL;'^O:7RJ;H&P`10_`A0^!21H!2-D%"]M
M&35T$R9/'#9P(T"`(CQV&RY:-$N!3VRK2F2=/%%_15N/46NE4FRE4FNC3&*6
M5FVB25V*5&J>67"E:X&S`"-H`")F`R5J!29L"2IM#2]S$#%U'3Z!'SY](4&$
M&S1G(CML(3EI+U"0)C]P-524*D-V*T5W,$I^,$I]-$^#-E&'0F&B1F2B/UJ/
M1F*94&ZK266<4&REA*:C>*R>8Z^58K>65\247ZF"0+)F2)IBA(AAN+1AG(N(
M8UE9____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````;U)/-0````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``J*C4S.+BXP3
M8DO+JVJ;N_N`0C&)=I'!62E"_''*6@:V[A.`0BHFH6%>.B(L<P0T=&T\_/N!
M0OH%$0%&\=PSIK.)F[KX>/<`A1RB`B4TQ;BF36'FR_#Q=>X`"H4'.6HKB7),
MG#2;)]?/3;(=*!22IZ<J*\4[>2J3<+ZGO74K4*@P35U.1D%PYBS.'&\G*_,F
MH)!%DJ*TO%HR.VNVKZNEF6$#4*BFHJ2LLKJQ*WU";V=;2WT=-N\``-'-,:4?
M]D9.`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=Y+G!N
M9P``````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`Q,@`Q,#0Q-S,V
M,S`Q-``P,C$W,3$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#___\W;39%>D1&<45<B5MDE&-";$!3AE%1?4]?D%UCD6$O4RHU
M6C`W73([838]9#A!:#Q=B%=AC%MFDF!DCUYHE&(_9CE0@4E&;T!#:CU(<$)+
M=$5*<D1-=D==C591>TMAD%E6@$]:A%-GE6!JEV-IEF)JEF-%;#YHBSY0="1<
M?C!VETQIA46!H5AVDU*(IV"!GUR(IF+,KP[.L1#,L!#-L!+4MQ?.LQK8NQ[;
MOB';OR';OR7DR"[DR2[4NRONTSSOU$'XW4KAR43WW4_^Y%;GT%'\XUG^Y5SS
MVUGZXEW-K@[,K@[+J@[-JP_-KP_,K@_.L!#0L1+,JQ/,KQ/1LQ70KQ74MA?-
ML!;6N!K3MAK8MQ[/L!_>P272MB3APRK@P"KHRS/ER3/7NC/KSCCRU4'UV4;Z
MWT_\X5/FRTS_Y%OYX%OUVV&_,`Z_,0_"-1+`-Q;(/!K&1"316#OA;U/O@VCU
MC72]&Q.^'A;#+"3&,RO/0CO42D/:4DOI:&'>:&+L=6]U#0B\%@Z!&!/!)A^*
M'QJ3)R+*.C.<+RJG.#.Q03R\243?65/)55#D85OM;FCQ=&[S=W+S>72[$0Z]
M%!"[%!"^'1K%+RS31D2[1D3D75OP<&[K<6____\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"A.PE.`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```*-)1$%4&--MP=%*`E$0!N#__#/C5H*)@3=>*KYG3YD0(I17@BZA;NM9
M9Z8'L.\#'A2\P]ZVW<>BZP^7S?Q9/PFH2OJ]]K8JI;$?$-1K9KWU,OH*L^(@
M3&>9-Q]&WVMA.;V"$#M&_D:SEQWO[:2"N'IFU-*L16@Q.(BIOV044:.P3KP'
M$:UG/JE2)-4S0)SB'#112L8P[@)$Y+C02"X]I(W$/_X`%\)1$+3Y1!@`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O:&LN<&YG````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#0V`#$P-#$W,S8S,#$T`#`R,3<P,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]')Q<NXLLV:CK\A
M`+XA`'<4`,`C`[\C`\$D!,,F!<(E!<`E!<`H"<<L"\DM#<@M#<(L#8,?"LLP
M$,0Q$L8V&(PF$=4\'=0\'==!(<D\'\@]'\D^()XQ&Y0N&<U$)Z<W(>).+^)0
M+ZDZ(YXV(;`^)M)++[-`*.53-;5"*KY'+KM&+;A$+*E`*L-+,<!),-=3.-93
M.,E.-,A.-,5,,^Q</LI/-<M/-N]@0NY@0M!4.K-(,O!D1MQ;0-99/O%C1]Q;
M0=M<0KY1.[U1._1I3=]@1N1D2>)B2/1K3_-K3^AF3.AG3/-L4.MH3NMI3O)M
M4?%M4>YJ4.YK4.YL4.=J4,M=1NQQ5^MP5_!W7N!P6?-\9.]]9>Y]9?:":O6"
M:O:EE,R+??#2S+\@`<0P%M$V&,U!)]]'*_-D2NIF3O5J4_!I4?9N5,E>2LA?
M2^MR6_5_:-9X9N:EFLV]NK\8`,(E#<LI$,4M&,(P'-9-..=D4,M@4,A@4.9[
M;/>+>L=W:^J4AMNQJ_;)P^5)-<-$-.]40L]30_-B3_-C4-M^<]:!>.*CG-&:
MD^6LIMVHH?S-Q\NXMKX6!<`:"=<M(=G+RLR[N\S,S/___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````';]H%H````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@P`+8V>5=XB.,
MRB>R\8A(:=KZ@H3$;6(C':5KZKD$))0L/8.!0L)Z4=$>::43BOE3T\U<`]V!
M0JIA!56%>17,3(U%F1D!/O9`(>>X\,KJJ=-8NKJ3$CK\G4R`0C&1=K*36G+;
M.AM:VT/<+`R`0M$>"D+)*3U]M4UUV>[6^KI`H5!U4<Z2Q"F]^?TYWO:F.FI`
M(4,Q7E;NLLG-#EE^3L;:&HI`(1D^5@Y!264KKR`W<P,M%3ELW@$`[LHNBB'-
M(\8`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]H<BYP
M;F<`````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#4`,3`T,3<S
M-C,P,30`,#(Q-S$Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____O$%#O5U?K$A,P:2ES41,D0\@H4U?@S5)I*"A<CM761L]
M7A5!QJ:\52=+1B50@F",4C9<>G+`1T&K``"%!06)!06'!P>'"0F)#P^+$!"2
M$Q.2&!B1(R.?)269(2%_'Q]X*"B(-#6N)R>"+BZ2+BZ,.#BH-#2;-366,S.1
M.SN?0D*L/C^84%##4E+$3DZZ2TNR557`24J/6%FI4%&79&6P)2>E+S&1,3.1
M1$:^3E'!5UFA<G3!=7C%=WO,Q<;'[?+RS='1^?S\]_KZ\?3TSM'1RLW-^_W]
M^OS\X>/CW=_?Q,;&^?KZ]/7UP\3$O+Z]T]33T=+1R,G(Y.3BTM+0_/S[]_?V
M]O;UY^?FTM+1Q\?&V]?6Q<"_[-O8R7IVQZ:DY'-OYZFGS```?P``?0``S04%
MS`4%T`T-U1`0D!$1S!D9W1T=X2$AFQD9Z2\OB1P<[S4UX3@XU34U]4)"N#(R
M^D9&Y45$Q#L[^D]/_%!0]5!0K3P\]E=7\596^%Y>^61DZU]>Z6!@\V5E_&IJ
M]6AHS5E9Y&QL]WAXP%Y>QF=GPF9FTG!PPFQJT79TQWY^T8F)V\G)^//S]_+R
M[NGI[.?G^?7U[.CHY.'AS\S,U]75Z.CHYN;F____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````23J=>P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"^241!5!C39<\Q2D-!$`;@?W9F7GQY6Z6Q,&"91B%'$,2#!'(601!L
M@YY!2&WO`=+8"7:6B9'$[,O,K`?(=X,/.$&84SO,95?,F$54[@7007=\X";Z
M&2=F@B#GCB*UO4@G@Z0.P?.3UY%O@QY;"Y)W$&[.O/F[F,:Q6[*:VIO@'$[&
M1L,5CQ)10<+^+AI=?\C*ZN'V0`[!SZ+DNOV^?M6K]4M3`H3)O@_2\>?D-YFY
MQQ<C&UBY7.X$CHJZ.?W@'WDC2?S6C&JF`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VAT+G!N9P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`S-P`Q,#0Q-S,V,S`Q-``P,C$W,30`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____7&!GH*B[T/D+[
M3D^Z"13!*S3704ON3UCOA8O#("R\,#K&-4#:1E'I4%OK7FCK96^RJ]BFH,:,
M@.,E&+Y%.-!`-,,_,[M31NE.0M1&.KE=4.U:3N5U:N]B5^6&A<@``,<``'T`
M`'P!`<L!`<D#`\@%!<L%!<@)"<<*"LX-#=`-#<D*"H@0$-,8&-@8&,X1$9`=
M'=LA(>`?'\\9&9HG)],K*^4A(:<O+^DP+]LU->TZ.O,J*JXX.-T^/O-"0O4R
M,KA&1O@_/]]!0>)*2OTZ.\--3?I)2>I(2.A/3_I,3/%04/M14?Q04/514?9&
M1M-04/!75_)35>9>7O596>5D9/AH9_UE9?-J:OLH*\Z<G=9XBKA?9WMYDKJ0
ML+6!F9IK=G)57DZWL)'&OJ%I8D_JTL;%HY?(``#'``#&``#+`0')`P/&`P/*
M!07'!07,"`C("0G1#0W-#0W3$!#*$A+-&!C<'1W?(2'0(!_,(2"D&QO7)R>L
M(2'J+R^O(R.V)B;8,"^X*"CL-36[*BK!+"S#+B[`+2W,,C'',##=.#C1-C7.
M-#3+,S/V0D+8.CKW1D;;/S[A0D+F1D;M24GK2$C[3T_Z4%#N3$SZ45'Q3D[U
M4%#X4E+M4%#\9&3\@7____\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"Z-$J&`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+A)1$%4&--MP=])`T$0!^#?
MS,[NA5Q4\J<"L09!L!$;\<52!!OP-36D#%\$)9`@'B:WLW.[8P'Z?<`?A&M:
M+==Z&+*F+LZZ^99!EXN5#6?5*)+BC,&8+S;M-.0IB,34Q0)!O^;R?;.[YYKW
M*4T&P?L'C?YF%+8<`]4*PM)S,'K@4%X]N?L/X67\'//5<2*^*V9:GP1^T-+.
MST1TZ[6Y07`\E1KEL;_H6K$R53"^3%E"ZI.HUE8;_O$+H\56K>VUSH4`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:'4N
M<&YG````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#(Q`#$P-#$W
M,S8S,#$T`#`R,3<P-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/____[V]Z:@H=74U<?&Q]35U0!O``!L``-R`P5P!05O!0ET
M"0UZ#1!Z$!A[&!V('1^#'R&((1MG&R)Q(R>`)R%L(2^8+RF`*2V%+2AV*"I[
M*C69-2Y_+C"$,#2(-#B2.$*G0CF0.C:(-D:G1D*80D:?1D^O3U"L4$ZG3DJ?
M2D*"0E";4%VN75&545VC76RZ;&NT:W&]<6ZU;O/V\^;IYMG<V<?*Q_O]^_G[
M^??Y]^KLZNCJZ-;8UM36U,_1S\G+R;[`OC:--4J+2<K,R>?GYK0``+,``'$`
M`'```+4#`[@%!;8%!;4)";T-#<$0$+T8&+@7%[<7%X01$<D='<TA(;X?'XX9
M&;HB(GX8&-<O+\DM+=LU-<XX..1"0JLR,M8_/\4Z.N=&1M)!0;8[.^I/3^M0
M4*,X..504.114>175^Q@8.=>7MM96=U;6^EC8^9E9>YJ:MIH:.QT=,S"PM#'
MQ\_&QLO"PMS3T]K1T?3KZ^?>WOWU]?ST]/'IZ=_8V/'JZM/-S?CW]_[^_OS\
M_/KZ^OGY^?;V]O+R\N[N[NKJZN7EY>3DY.'AX=C8V-;6UM+2TM#0T,[.SLW-
MS<S,S,K*RO___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````)$J:H(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````JDE$0508TVV,2P[!4!1`[[?:4DP,+<0.+,>T"1*)6(0E6`3;,2`B
MC32O??==G7.&)R<'X`>$-<RJ*C1-[%2R429G`2SS21^"]<*JQ`0"\^D8+9&*
MJA8D/JC+_K#5`@V%G)!]>&D\92Q@EF)T$=T0[([7FB$E-]LQUSI4*Z:L*;QU
M%T)BO`ETH?V8%#ES\N2+^[!_OJ*1A#(7C%UZ1"!X6T0F509;>NH,_O`%U5=%
MLE1>`<$`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]I9"YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P-#4`,3`T,3<S-C,P,30`,#(Q-C<T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____P<+"LK.SU-74
MX.#?W=W<U=74S<W,RL3!Y=_<_??T^/+ORL/`R,/!HRD`I2H!I"H!I2L#IC`)
MJS(*IC(,KC4-J#0-J3<1IS<1MD`8>BL1ND0=LT(<L$0?KT8CM4LGQ%$KR%8O
MOU$MED4JTV,^U6="SF-`H$XRQ6)!MUH]PF)"T&E)VW!-RVE(W')/T&M,VG-1
MV7-1MV%&QFI,WGM;UG=8VGU>S'99V'Y@WH)DVH-EXXYRT\W+TLS*^/+P]_'O
MZ.+@J28`HR8`:1<`HR@#K2H%JBH%J"P'=2(*MC40J342LCD4LCH8PT4AAC$9
MP$DFT5<UN4\OSEPZQ%<XW6A&P5L^KE0[V6M*VG!0VG%1T6Y0L%M#VW17Y85J
MX(-HR\3"WM?5[.7C;14`CS<AXV]0U,S*]O#O_O[^_?W]_/S\^_O[^OKZ^?GY
M^/CX]O;V]?7U\O+R\?'Q[N[N[.SLZ^OKZNKJZ.CHY>7EY.3DX>'AWM[>V]O;
MVMK:V-C8UM;6U-34TM+2T='1T-#0S\_/SL[.S<W-S,S,RLK*Q\?'Q,3$O[^_
MO+R\N;FYL+"PIZ>G____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````#X'?+P````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"^241!5!C3;8PA#L)`$$5G
M=V=W6QJ2)D@.0(*F&HWF"!C"!1"@D%208!#<@,-@:""I(*E%$IK2V:%E/3SY
M\M\'^$'`K(@"VU8U.414&!\1BENWQ\^R9(7&8#@$"3J,VZJJ&R%1*ZLN@-!_
M#-AGC?:9EM=AAO`.\^>+6&F#'128^56DSJ,[3HT3IS81G'LED[&=M.2H+A=!
M)R5_'^Z-!&9V-#=[NTF]"E;*FP\1&+O64GBUU=`PDSMHN[-R*>`/7ZA71QG4
MISZ^`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VEE
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`Q,0`Q,#0Q
M-S,V,S`Q-``P,C$V-C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___\`>P``=P``30``3``#>P,#>0,%?04)?PD-?@T*5PH2
MA!(8B!@17Q$?C1\?BB`9:1DGD2<A<2$JC"HKBRLNCRXJ?"HQCC$XGC@UEC4X
MFS@RA3(ZCCL^ESX[CCM(JDA&G$90L5!0KE!7ME=>NUY3I5-9KUEDOV1DOF1H
MP6AENV5JPVIJMVI]R'V(T(C>X=[4U]3)S,G(R\CT]O3CY>/5U]7-S\W,SLS)
MR\DPER]!I$!FO67-S<SJZ>?V]/+R\.[>W-K6U-+0S\ZG41NP6"&R6R.Y7R:\
M82CR?S6_8RK$:"W!9BS':B[*;##-;C'2<33/<#/5<S;ZBD+8=SG:>#K@?3[\
MCD;E@4+JA4;_DDWNB4GA@$7_DT_^E5#RC4S]E%'VCT[[DU'YDE#KC5+UF&#5
MAU7\HVSEE6/_J'/RH&[[J'3D:B'N=B_*:3#2;C3X@C[@>C[^C$KNADG^D5#Y
MCE#__?S]^_KZ^/?HY>3^_O[\_/SZ^OKY^?GX^/CU]?7R\O+N[N[KZ^OHZ.CD
MY.3AX>'>WM[;V]O8V-C6UM;4U-32TM+1T='0T-#.SL[-S<W,S,S___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"J!":X`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```*))1$%4&--MS+T-PE`,!&#;>2__($$#0F(/QH"E&(2>BB&@IZ!B
M`UH@<?QL'(D.KOSN=``_00@P:>=QET<XS9;W:7$(@%4S-8P!U$JLO2'(JT8-
M`YI8F16Q<RKKC'NB8TH;I#P-3FW#78>PE70FPIZ=UOWBR:SB*\*.U>DQW#B9
M2U+R8B1>N40705.1\>M]%2%V@8M^5R_A+%B2?69J20W^Y`/6@%P6!X(+DP``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O:6PN<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#0W`#$P-#$W,S8S,#$T`#`R,3<P-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/_____^_]74U<?&
MQX2'B\/'R_3X_+;,WLC8YK/`RP-%=@IQO@]TOA)ZQQ)UOQ1XPA18BR."R"-^
MP1Q1>#&$P2MRIC6%PC6%P#R/S#9]LCJ%O$>AY3%PGD68U4".QT&.QSEZJDR=
MV4>0QD&$M5BO\%.@V5VS\EJMZD^6RE^R[U6=TUZMYUZJXUVCUVNZ]&JV[F6L
MX'>_](K(]H&LS(*IQI*XUJO3\9NUR)VVR:S#U*O!TLC?\:R]RK+!S;3!R\;+
MSZJNL?7Z_K*VN=C<W]'5V,C,S^KN\0=ROQ1WOA^"RB*(TB!\OR:"Q2B`P"^0
MUBR'R328X"V"P#&&Q#N4U#-\L4>G[3R.R42;VD&+P5.O\DVDXE2L[$Z?V39M
ME4B.P&&S[F"JWVFU[&ZZ\5F4OGJ\[*.[S+G2Y-_P_.+O^,+(S.WS]\S/T?C[
M_=CF[]_FZM;;WM39W.#EZ/'W^N3J[>+HZ[W!P^GN\-35U<'"PN?GYN#@W\W-
MS/CW]]W<W/[^_OW]_?S\_/O[^_KZ^OGY^?;V]O7U]?+R\O'Q\>[N[NSL[.KJ
MZN7EY>'AX=O;V]K:VMC8V-34U-+2TL[.SLW-S<S,S,K*RJ>GI____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````*D6S2P````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(UV-@P`)$1.)2
MC%/U%$2#@B65=)*-@$+<@E))"1%"_#P>?-Z!85$Q0"%6QR+V4M?)%I83"_*S
MG8I+@$+3)S)UU-F91BJ;<;;5-[17`X58&%M[)]E+I%FIY376M_9,`@K5-E=5
M3.$2M^;0S61LZ6:>!A1JZ)HP>:JMB;:A>4939W]-)5"HO-"!+2NG+]VF/M?=
MQ:W,&2@DY^O)*^#E+Z.JKA$K+QTJ!A0*]_,1#@B)UM(W2-2,5U&4Q>8=`(M@
M,*,G#W+-`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I
M;BYP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#``,3`T
M,3<S-C,P,30`,#(Q-S`Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____J(Z4EX60U=35Q\;'\O#YR<G,HZ33IZB[F)_+?HBW
ME9['@(Z_H:W6<X6\?(NYEJ*^U=[OM<#)[/'R^O[^RLS,U-75Q\S+]_OZZN[M
MZ.SKU-C7R<W,^OW\OL+`UMK8RL[,R<W+;K1C8JI3A<9V19(P2Y<W4ID_5Y!)
M:JM8:*-8=;)DA,-SB\QZ1Y(R6J1%8)E0B,MU/Y`?.74A4YTX)'<`*7P%*7H%
M,X<--(40.8480I0=1),A-7$;/GHC1H0J0GXH5Z0U28@N4)`T7Z%"9:I&;[90
M:[!.*'P`*GX#+X`)5*0O3HXP5)8U9K)":+)&<;I/<+90Y^?FS%(`?S,`T%8%
MS%4%V&`0U%X/SF`2Y&\AG4X9V'`KZWHOX7PXLF(L^(I!_(]&QG,[_Y90_I90
M[HU,[(Q+^Y=4_:-G?S(`SE(#R5`%S%,'S58)UEP-BS\-TF(8E$01X6H=WFD<
MU&8?[GHO\H`U^HI"NV@RYX)!_Y1/^9)0]I97^IM>Z91<]Y]E_Z5JS[BKW<>[
MX,S`_NC<\=W2U,.YZ-##IY:-]=W1_>?<\MW2_^OBPJ^ML9V<^/?W_O[^_/S\
M^OKZ^?GY]O;VZNKJY>7EX>'ATM+2S<W-RLK*____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````.T*-R`````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"Y241!5!C3;<%-3@)!$`;0KWZZ>\`@!")(-'@JSN"*L'$+'D!7
MQIUW\2ZP(!&"1B$P,%-='D#?`_X@C)'2J%YV5\8LMQMY4UP5*9GU3S90%1H2
M%/'S[B,?K'>]O5F+:(9B.(C)O/7@S^=^%:D$(=2O0K/*C>+<E?F>\?3R_DC?
M9<7GGZG0A$$8&85C.)QR(4J1;:%((:=`O;VW:W>/)12=:+D0Z5X>R=SS#HK<
MR?3%;:&+?<-WWL0_?@%1.$=6NGDVX`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VEQ+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`T-P`Q,#0Q-S,V,S`Q-``P,C$W,3,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^(&QSS5E?Y
M>'G*PL//R,G]]O?\]?;QZNO;T]7\]??PZ>LO+B\M+"T_/C]Q<'%C8F-655;5
MU-5/3U#W]_C\_?[)R\S#Q<8B(R/.T='BY.3BX^/V^OGN\O#BZ>6\P[[&U,F\
MVK^CMZ6FN:C&V\B.LY%OGW)@E6!HE6B7NI>AQJ&&HX:;LYO.X<['V,>ONZ^X
MP;CI\.D?(!^[P+OK\.OJ[>K&R<:^P;[@XN#5UM72T]+(R<CL]>LV-C7'Q\;;
MUM7'``!]``!\``#(`P/+!07(!07("0G0#0W3$!#.&!B0$1'<'1W)'1W''!S@
M(2'/'Q^:&1G/)27))R?I+R_M-379,S/=.#CU0D*X,C+X1D;B04'E1433/S_#
M.SOZ3T_Z4%#U4%"N/#SR5U?U7E[Z9&3J7U_H7E[S967W:&C[:FKE;&S&O[_5
MSL[*Q,2DGY_NZ.C?V=G0S,SX^/CV]O;HZ.CFYN;1T='&QL:\O+QW=W=R<G)P
M<'!A86%45%104%!/3T].3DY-34U&1D9%145"0D(Z.CHX.#@U-34T-#0S,S,P
M,#`O+R\N+BXJ*BHH*"@A(2$='1T;&QL8&!@0$!`-#0T)"0D%!04#`P/___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!+9+&8`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"G)P#
MX[*2P[W<'%T]_4.C$H!"SMZ1&2G1`>Z.+AX^(1'QB4`AIJ1LEO388#_?H+`8
MYM3,-*!0?A$'#U=>#BM;;B$G.W>!`U!(0DQ.345<05E=45Y6255:"BA44FRI
MJ6-@J*NAKV>KK25L`Q02+2NOL#`QMY(Q,S(MM;:O!`I5U[7Q\G7QBP@*5-74
M"C6U`(7:)T]GF#YE0D=S?6-K9V__!*"0\32&&5,G]K0VU#?;=?=)3L+F'0#]
M5S">O;>-"P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M:7(N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0Q`#$P
M-#$W,S8S,#$T`#`R,3<P-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/____I14LMT==-[?,FRM./AXOKX^OS[_.+AXL_.S][=
MW\3#QOO[_/+R\\_/T/3U]M#1TL?,S/7Z^N[R\LG,S/7W]\_1T<?)R<;(R/3U
M]?+S\^7FYN+CX\W1T/K\^_+T\T^94DR53@!S``!R``!(``!'``-T`P5W!05V
M!0EV"0U]#1"!$!B!&!%:$1V*'2&/(1^$'QED&2^:+S6?-3B7.$*I0C)_,D:M
M1D&=03J*.U"S4$^Q3U"N4%>P5UZU7E6;566W96J^:E:85F:E9H[`CL'&P<_3
MS\'#P3IF.6.H8G*U<5Z-78+"@86^A)#,CY#+CXG!B*#3GNKLZ-'3S_;U]/?U
M]-#.S<?%Q,6LJLBJJ.G'QL>RL<@``,8"`LD#`\H&!L<'!\@)"=$-#=,3$\T:
M&MP='=$@']\C(Z0;&ZPB(NHO+Z\C([LJ*K@I*>PV-L<P,,,P+]$V-=TZ.<XV
M-O9"0O=)2>%#0^9&1OM/3_504/%04-MR<<QL;,=I:<9M;-!T=-9\?,IU=>*)
MB;5R<MB+BMN/CL!\?,N%A>V?G_BIJ.^BHOBKJ^VEI>6EI=>FI>&\O/GV]NSI
MZ>KGY\C%Q:.AH>WKZ]O9V?KY^?CW]^?FYM/2TLG(R,C'Q_;V]M75U;V]O?__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````!?DW^@````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````NDE$0508TVW!,3($41`&X+^[_YGWS,Z04*6*#"<0*%4"T4:;
M2QV#*JE@E<`AW()4Y!!R&66Q.]W:`?@^X`_!`89:_>O;5PU)VA,AM2DQ>HPT
M,Z6`V+/EX)_=2^YVHBH"Q6PR.VVU.3HNC[66Z11`7W<FW59CO-LLP_K:!@AV
MVLOJ;-^?<WO417TCYB+Z<')SF/?7[:(/G@OF'I%)K:FRU(PKXO7=0\E2;B\]
M(AS$1[B:6FL7,?Y$)O[Q"V50/^2)H[Q'`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I<RYP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T,3<S-C,P,30`,#(Q-S`W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____VWAYK9ZO
MJ9FLE(*BEH6DH)6JT<3=S\/:DH*DFHFOHY.XQ+?5GH^SLJ7$CG^HS\K<HIVV
M#@V+#@V)'1R3553$`0&%`0&#`P-4!@:'!`15!`14!P>'"0F)"@J,"PN+#`R)
M#0V,"@I>$A*0%!28$Q.1%A:5&!B7'!V3%!1G(R.>)B:C)R>B)268*RNF'Q]X
M)B:&)26`)R>",#"?-36M+2V/.CJS.3FP.CJR*BJ!+BZ,+2V),S.8/CZU,S.3
M-366.3F=/CZH.SN?1T>[/S^F2$B[2DJ^3$R_3$R^34V_24FT1T>M3$RW2TNR
M45'`45&^4%"Y557#5E;$5E;#557`4U.\65FX>WNX=W>E?W^OIJ;=FYO.IJ;;
M!PJ*#`^,)"BE(B:9'1]R,C:P.SZK-SF/BHO&D9/-FIO4B8J[J:K@;G*P=WNZ
M/TRD15*I4E^U8F["2U.-<W_/@X[<?XG1AI';0%"H<7S`<7NXEZ+DS"P@T"TB
MUC8KSCTSUD4\X51+VU!)[F5<[&IAREQ4U6);^G9NYVYH^GUTZG1L_X%X^7]W
M_X=_^HB"^(V'RB,<U&MH^9F6\J">_*VKQPT-S2$ARBLHT41#Q5)2QUQ:S%]>
MX'AV[HF(SWMYXHR*Q'EX^YV<\IF8____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````%88K\0````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``J0E
MD]B[>5-$%:44U'4M/8*!0C):J9SM_(DBLG)JVJ9N0:%`(66K<(XF/B4)<7D-
M?3NO`&^@4&%%I6"#4%EN7GY!47%I23E0:-ZDB4Q3IL^8V3]K]H3Y"^;.`0KU
M]K1-FSRUMJZ^L;6SJZ.E&2B4E9[#W,>2'9&6$1T;DQD5"10*-%'AJA)0U3%W
M]_=UM34S!`HY:<:S5G,G6'B&A/DXVML8`87TA./8:GB27<1"_9P=K(T-L'D'
M`#FK,J4&D>R+`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VET+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R-@`Q
M,#0Q-S,V,S`Q-``P,C$W,3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____0-3;HU=8`<```;@``1@`#<0,#<`,%<P4)=`D-
M=0T*40H/=P\0=Q`2>A(3>Q,7>Q<8?A@161$;@1L?@Q\?@B`98ADEA"4GB"<A
M:B$J=2HXE3@XDS@R?C(ZACL[ASM(HDA0J5!&E$90IU!7KE=4IU1>LUY9J%ED
MN&1DMF1HNFAEM&5JNVIIN&ETP'3"RL+!R<&^QKZ]Q;W2VM+)T<F^Q;[+TLO:
MX=KJ\.HPCR\\E#M!G$!FM67-S<SJV]K2&QO>(2&C&QO;)R>K(2'H+R^N(R.U
M)B:W*"CL-36Z*BKE-C6]+"S#+B[`+2W(,C'%,##.-#3--#3*,S/R/C[T0D+5
M.CKW1D;O1$3;/S[@0D+X2DK0/S[D1D;Y34WI24GY3T_Y4%#W4%#Q3D[M3$SX
M45'T4%#V45'@2TOY65CM557V6UO0O;W6P\/>R\ORX.#_[N[ZZ>G][>WVYN;^
M_O[\_/SZ^OKY^?GX^/CU]?7R\O+N[N[KZ^OHZ.CDY.3AX>'>WM[;V]O8V-C6
MUM;4U-32TM+1T='0T-#.SL[-S<W,S,S___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#NE&4L`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```*])1$%4&--MP3%2`D$0!=`_/3L[PQ:+@F51!D9D)-Z"S)N9
M&IMZ`(]A2)4F),:$*MO-_&D/(.\!_P3T6);K8=<G?.U#60PO'3#FT3UU:"'*
M?)8@Z,O0)N^"UU"N9EDA6)1HMR9OY/.8,PT1-W/5XVJ[J7SPB)-^".YMK<I6
M2<G)7AL$1SO\T"M)%]7'"H'>_=(;R2IN]#,$]FF,B:P(;3(C!#J=I7/6I_C^
M[6P-%_P!2+5;NG;TAW\`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:FTN<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#0W`#$P-#$W,S8S,#$T`#`R,3<Q,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___SLZ.S8U
M-FAG:!\@("LL+`UV#3J;.@1M`01L`0YW#1)Y$">+)C:)-4*706NX:A1Z$%&G
M3BB)(5>M4`QQ`R>('2>!'TZ@1@UP`!%T!1)S!15T"21^&#N9+T"<-4.5.$VH
M0E*J1EFP3UJM4&&N5QUY#4:*.QM\"C./(2)]`S*+%$B-,&6U2C*#`#F)!X?$
M7E.<'6*C&'2S*U>7!86X0H*S&(2Q)V&!&9S*-8^R`)&U!Y*L*LGF4:6[`[;+
M%,_B+]_N9;S)`+_-"L?0-.;Q/F-D4(B)&\S,`']_`'%P`"TM`,W-`6UM`:FG
M`]#/!<S,!<W-"=;6#4Y-!=?8$,_/$N'A'>CH)FEH$:^O'^OK*[*S(W9V&-73
M+\?'+OKZ0KN[,D%!$OS\1JBG+___3>SL2+JY.O+R3,&_/NOJ4')R*,3$3WEY
M-:FI41H:#9&035E9,VMK0F9F4"@H(4)".%-323(R,3`P+S\_/D%!0+JV`+"L
M`]71(>;C/O'N9)&066!?2@\.`&9E96IJ:F1D9%Y>7E=75U%145!04$]/3TY.
M3DQ,3$E)24A(2$9&1D)"0CHZ.C@X.#0T-#`P,"TM+2HJ*B<G)R8F)B$A(1@8
M&`H*"@D)"?___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````*)H:!L````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(UV-@P`*\
M/"W4!5059*4EI7@T+9,R@4*-$0F.!OSB,I*BW(8.\=EN0*%94^OK4LW5N#@U
MS*)J\]M[@$(S^EB*DD/M]/3MP],:VKLK@$),S6T39P97^8?4Y/1U=/5/`@HU
MM5:RSO:N#@J++>SLZ&.>#!1JZ9V6Y^OC;&3LFI);.J&,#2C449[HYV&MS<NA
M:YN>43!E.E"H)";`R4106%Y)1,C4)2ZK&"@4&6BEQ2XFIZBL(L&G8Q/MCLT[
M`%?Q,@9R=(O;`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]J;RYP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#<`
M,3`T,3<S-C,P,30`,#(Q-S$R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____RAL<^VMLSY.4R0$&P4)&Q[6YX=W@]?+U\N_R
MY>+E[>OMT<_1Q,+$NKBZ]O7VY^;GTM'2Z^OLT]G<O<7%W.'A.CL[[_'QY>?G
MY.;FUMC8[_#PXN/CV-G9R\S,TM33.4A`*7TP-H8Z`'L``WD#!8`%#7X-$(,0
M'8L=(9`A&VH;(7(A(G0C+YLO*'PH-:`U*GXJ+H4N,(<P-(XT0JI"1JY&0I]"
M1J-&3[)/4+-03JU.4*]01I!'/W<_6:!93HE.:*UH:*=H;K!N(RHC&1H9[_#O
MP<+!-I`U1X!&6I=9#FH`+C(K044^7%]9861>96AB&!L4(20=4U9/&1L40U()
M1$H(:&AE>2T%:E!+%@,`LRT?IA(#:C<R600`SFADOG%OR0``?P``R@4%R0D)
MS@T-B`H*SQ(2SQ@8S1@8BA,1SR`@TR<GHR$AVS`OL2HJR#`PX3@XW3@XU#8U
M\5!0YTQ,[5!0PD5%Z5E9T%)2^&1D\W=WX82#\965RZ*B]-G9^>3DN[BX_/S\
M^OKZ]_?W]/3TX^/CT='1R,C(:FIJ7EY>5U=74%!03T]/1D9&0D)"04%!.#@X
M-34U+R\O(2$A'Q\?'1T=&!@8$!`0#0T-"0D)!04%`P,#____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````.]6\_`````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```#`241!5`C78V#``N*B7,4[NR=.G\TP>\:427T]0*&DK-CP
MK@E39S',F3EM<G\O2"@MOR(^4M$E,"3(QS?8/\`/*)1;R5Q2G-`HZBXO)RDA
M(Z4`%"IOJ"W*2"ZHDY9U:VYJ;6L'"E77UV2G)#*QB`FW-`D("G4`A:I*<U)9
MV=A%.'@XN;AY^?B!0F5YZ3%A2LJV]H[.3EX.GG9`H<+,"&\U#2T#,RMK<Q,C
M?1V@4'2HBJJZIIZII8V%A[&AKC8V[P``Y-PQ?ZF3QPL`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VIP+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3(S-0`Q,#0Q-S,V,S`Q-``P,C$W,3$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```!@%!,5$4```#______O_5
MU-7'QL?4U=7&Q\?!PL*RL[/4U=3GY^;@X-_=W=S5U=3-S<S`(0"_(0#!(P/#
M)07$*`?)+0W,,1#2.!C4/!W802'?2BOB3B_L7#[V[>N_'@/'*0K(*`S.,13#
M,1;*9%+I>V?TAW/VCGSWD8#8A7?!&@'`&`&_&`'$,AS;/";;/2;E2C7H43KN
M64+';6#UD8+'>F[-@'7(@7?@H);ZMJO5G)/WMZ[QO[C,IZ+;O[N_%0"_&@7.
M*!3R6TKS7DW)E8_3NK?RZNK8U-3X]_?^_O[]_?W\_/S[^_OZ^OKY^?GX^/CW
M]_?V]O;R\O+Q\?'N[N[L[.SKZ^OJZNKIZ>GGY^?EY>7DY.3AX>':VMK8V-C6
MUM;4U-32TM+0T-#/S\_.SL[-S<W,S,S*RLK'Q\?$Q,2_O[^\O+R[N[NYN;FR
MLK*PL+"GIZ>=G9V4E)2+BXM_?W____\`````````````````````````````
M``````````````````!5I!6J`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+9)1$%4"-=C8,`"BHKRV1C]H^)34A)B(@,\W4%"!5E^WN'.
MIL;6L5%!WHP^0*'"G#"/8`M%+4UY]1!?1J\@H%!>'%.@C;8LO[""CI6[1P`W
M4(@%:)")G8"0J(2>D;M_1#Q0R,V;B]705E!$7,I`S2>4.14HY!$<D^2D(2<F
M*>UH&13-QPX4"N1)3$E1LM?5=U!UX4Y,SP8*@5WD:J:L8BX3$9^6F0L4XDQ.
M28*X*)0W-8,C#YMW`/";)^?DRXHD`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VME+G!N9P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-``Q,#0Q-S,V,S`Q-``P,C$V
M-S8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M__^3%A>Z+S#`-3;!/3ZT.CNZ24KG?7ZH75['+S;(.3_33U6]3E+(55K57V/I
M;W3W>'WQ=WR],3CG;7/XAHP#`@,_/C]X?GY]@8$Z.SNHVK9MJ'T`<!L#<AT)
M="(->R<?@S<;9RTB<C4PF4@J>STPA$0VC4I1K68AB#A$IEA*H%TPC$%1KV1?
ML&YEFF]OE7:>R:8A@#!GFG!QH'F&LHUXGW^!J8B@RJ<`;!`%;Q48>R<A;"PH
M=C,N?SHTB$$XDD5=JVF/N)4%<!)"F$V7EY:;@6"HCV^;9E#$E']13DVC```^
M``"C!06U"0DT`P.6$1&\&!B\(""W)B:@(B+,-36[,3&U,#!;&!C+.#B]-#2^
M.3CF1D;60D+004#/0D+#/S_41D;J3T_G4%!@(2'?3D[B4%#,2$C@5U>\2DJ[
M2DI3(2'96EGE7EZ[3T_D967K:FK49&2@3$S5:&CM=W?:;6W7<G)9+R_UA(3J
M@8'TB(C-='3IA(2D75WWF)@;&!A`/3U54E)H965S<7&6E96BHJ*4E)2,C(R*
MBHJ)B8EW=W=J:FIE965A86%>7EY04%!/3T]&1D9"0D([.SLU-34R,C(O+R\A
M(2$='1T9&1D8&!@1$1$%!07___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!0
MHM^``````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+U)1$%4
M"-=C8,`*9DIU-TV>-4>L?O;T*1/[02*SI_;T-3>F1#1XS9@V:0)(2+RWK;53
MLC8KDU.BJZ/%M1TH5%1=5U.<%Q#-&E)84E%560848BO(B`ST]0D.RPZ-24Z-
MCP(*Y>?&!?EY^S,GE,<FI26RA`.%1$5XN+F$F=)SV(4$!?CY>(%"%J8FQOHR
M'J4<GM*&3N9F!D`A!VLK2V<C'3=W/4<7>SM;&Z"0HKRLG(*FBI:NAK:ZFJJR
M$C;/``!SZ3$`8-]UB`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O:V<N<&YG````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#0V`#$P-#$W,S8S,#$T`#`R,3<P,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/____K60O')-<N<`<J/`]*7"O.].LR+
M`<N.!<^/!\V3#=F=%-R@&/:_/LJ)`,F%`.6D)LN!`=2-#>*=(>NJ+\E[`,V'
M$MV4'>BB*_NV2ORY3<IY`]&#"N6:)MB#%-%C$,I8!=%?)_6"1OB(3\4Z`,D^
M!\5!"=9/&/:`4<M'&/1V1NA?-<0L`^MA.O)U4<$G`=E$(<M!']1/+_5Q4,`A
M`+\A`'@4`'@5`,(C`[\C`\,E!<,F!<`E!<$H"<HM#80?"LPP$,0Q$L8V&(PF
M$=4\'=A!(<H]'Y4N&9\Q&\U$)Z<W(:HZ(^--+^).+Y\W(;`^)M)++[-`*.93
M-;9"*KY'+KM&+;A$+,%),*E`*L-+,==4.,M/-<E.-,5,,^Q</LM/-N]@0M!4
M.K-(,O%D1MQ;0-99/MM<0KY1._1I3>!@1M]@1N1D2>)B2/1K3_5L4.AG3.MI
M3O)M4>]K4/%M4>AK4.=I4,M=1NUP5^QQ5_!W7N!P6?1]9/-\9.]]9>Y]9?:"
M:L`?`+\>`,$A!<HJ#<(J#<PN$,<R&,DY(-]'*]=1.-=2..]=0MQ:0?-E2N1B
M2>)?2/5H3^AE3/-H4.MF3N]I4/5_:.YF4/___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````&S$D8L````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````OTE$050(UV-@P`(LS#TR&BJZVYN;K!W=@E/R
M04(NR?55O4;JJKHMKGZ)><5`(8?(ZMH)2MPL'+(:G?&9)3E`(?_R:67&XJP"
M7#QR>GU%!6E`H8R&RBXM3C%%!1%FY<F%Z;%`H;JJU`YU?AEA"5$FE>G9"1%`
MH9I<KU8#(39>23YI_?ZDJ'"@4&F@DU6CFKP@NY3FI+2XL`"@4+2SK9E-FZ&.
MMLF4]-C0(&^@D+N=J:6]JV_/Q*E9,1$A/I[8O`,`_%HP7'9OO.T`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K:"YP;F<`````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S(`,3`T,3<S-C,P,30`,#(Q
M-C<V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____PQ(6A`X0P!47Q!<;TAL?SBHMWS$TL"LMTC4WNS(TJBXP[41&]5)5Y$Y1
MXDY0\5=9Z%58X%U@]&EKQ7!QZ*FJ\[.TR`X3QC<[P&]QW(Z0SX:)ZJ&C\[.U
M'!2>+22L0#B[44K(6%#%6U/,$0J73$:W%1.</CVL#`N9!PAA#`R:#Q"=$1*=
M&1FE(R2F&1EU*"FR*BNI*2F..SO!,3&8-SBB0D.Y34[..CN;2DJ^65K56EO1
M9VC4;F[4``VH``AI`Q"J!1&L!1*I"16J#1FQ$!VU&"2Q'2F](2W"'RNT&2&&
M&R..(BR9+SO,-4#0*C.D,#JO.$/#-C^X0DW91E+<.D.N1E#,3UG?4%O@4%K:
M5V'::G/DU+RO^.3:S:R=Z]/)_^KAWL&VS)F,SIV1X;6KUJRC[L&X^M+*S()T
MV)6*^ZVB\K.JS4@XT59&S&9;T(!WSR\AZ$8XS$0YY&5:S2,8_VQCSA(-TBHC
MV"PGIR4AP3`LRC4PS3<QTCDTU3HVVCXZYT9`X$0^Y4="_E!*QS\[ZDM&[DY)
M[$U(\E%,_591]E-.\550U$M&_%Y8]EQ7^F)>_6AD_VQH^&IE_VYJS`,#VQ04
MP!04P1@8U"`@W3(O]3XZX3LX_E)0^5!0UDY.____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M.%'(-`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"S241!
M5!C3;<$Q3L1`#`70;WLR$42*5JR$1$\!)Z#E7%L@6@[`&3@--10H-4N!Q$91
M)AZ/S0'@/>`/PCV&(<>ZF$F2G--+PE?>YFAE86&1)`2"G/5D:WVFQV_N2/R'
M<-AW.KY=O]/-Q^TQQ_;`&/JVF\HD-NE\16I(&.UTWK1RS/2YJ^9(\%(F->_<
M93FJ!P@7I<9E[8-IBZ?#R5?"77%7)2(.X3'\-6&OE9/DG+B91PO\XQ=3%UHG
M:HU[M@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+VMI+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`T-P`Q,#0Q-S,V,S`Q-``P,C$W,#4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____$.COZ9VB^BXS+H:*^EIK4QLRF
MH*J8F*B>I,2JKL)788J<H[]48I)@;Z.!C;M^A9^+D:BVO-)078=Q>YR4H,6`
MBJER>9"*DJV?J,2!B)ZIL<MD<)1C<)-S?9I]AI^'D*N<IL&>IKYP=H>1F*R,
MDJ0]4(!58XA47WN'E+9X@IR:IL6HLLQ^A9>[Q=V8G[!O?J!YAZ=J=8YS?IAF
M<(:2G[N3G;.-E*.SNLEU@9F&CZ&ZQ-E!685*88M[B:/`S-W7V<7,UB&[Q`7$
MRQ##RB??YCW$QI+>WX_2T@W=W!VRI@"[IP"PEP.U@@>YB`FN=0#MR'[!;Q2X
M70';@C7#?T>W1`&U.`._3Q_`/PVX,@7#*0##(@7M:%?&%07!&0K+)AC81CC<
M3T'<,2;Y;FK*:69]``!\``#'#@V)"@K0%!#'%!+8&1C.&!B0$1'<'AW@(2'/
M("":&1G5)R?F*ROI+R^D(2'9+R_*+2SM-37P.CJN*BK=.#C/-#3S/C[U0D*X
M,C+X1D;W1D;</S[C0T+A0D+Y2DK#.SOZ34WE1D;J24GH2$CZ3T_[4%#Z4%#N
M3$SQ3D[X45'W45'U4%#M4%#01D;Q5U?23D[U7U[E65GV8F'X9&3S967[:FKZ
M?7O^C(KXE)+___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````MQIR4`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"TM*+VE-B$Q/BHF.R"BH;
M>T%">0US9B1%^/OX1N:7UO=,!@IE5L^<W5V<$18<GU-2US&I"RA4-I5Y2GEV
M>(!?4')5V\3^9J`0T]QI-;E1WLXN3B%-?1-::X%""^:U%%:$NGIZN07.G]4Y
M/14H9,/-QL(I:N'NX:COP,[*80T4,C.TLU47X>,7$-/1,K*WT@,**2IH"\K+
MBO/*Z"J9"TE+:`*%5$TT>.0DE:6XA"T-U(Q-5;!Y!P#*KC*V^'VT[P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:W`N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W,S8S,#$T`#`R
M,3<P-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___\<Z.ZYK>+MYAK&&C\F9H[%T@;!T@<F,F;>#C]:AK:9]AKR/F>*ONLV?
MJ>6TO]VNN9MR?,>6I=NPOK.#DZ)_B]BLN]NQO]FQOZ9UAZAWB6=)5*AYBK"`
MD;R-GLJ=K=ZTPWM<:`43@0,,4`D8A0H8@Q4CCATJCB8TG!PF;"`K=3E&K#Q(
MHS9!DTE7N4M8N3U(DTQ9KU5CP%1AOE9CO5MFNVUWQP47A0@9A@T?B!$BCB$R
MG",TE2<S?S5%JR\[B3M(G,O.SN7GYLR9E.NWLXL2#.LW+KDM)L\[,^!&/OY3
M2O]83_)43/%84/M<5,MN:=!V<-B"??VQK,P)`<T.!<H-"-06#=L9%-XD&^0G
M(<XE'\\E(-HM)^XU+]TT+_([-<0T+?5".LHU,+(P*LTU,=(Y--4Z-OI(0OA)
M0=H^.N!"/OQ,1N5'0NI+1NY-2?]53_Y64/)03/U94?933NY33.M/2_M54?E5
M4.EI9/:+B/N6D\>GIO+;VM$)!\L)"=@0$.$='=PG(^@J)NLL*\\I)Z<C(<$O
M+/4^.OA"/OY.2O]13?U54=-+2,A(2,Q.2])44?UE9/AE9<M85M%L;.&"@,61
MD->@G\B;FL>;FLN?GM2HI\ZCH_S2T?'Q\<[.SO___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`/7MB=D````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$
M050(UV-@P`)45+0,S<UT-=245=4U=0Q,@$(R2F(B$L*BLE+2<O(*XHJ20"&W
ME,I@UZ#HD-#P2/=,'_]2H%!;[]QYT^?/"*N+:.[HZBG*!@HQ5==.;9U<T]\0
ME9!36)*;!A2:5.4\I;[/:4)C7$9!15YZ,E!H8MGLF;.FS6EJZ>PNS\]*;0<*
M^<7'!+@$QC8G>1?[>GDF>@"%V+@XF-E9.+GY!`3Y>5EYA(!"ME86EM8V]OK&
MID:.>@YVVMB\`P!ONS)7\YKX[`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]K<BYP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-#4`,3`T,3<S-C,P,30`,#(Q-S$T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____X$]6I1`QGE%JF"%*7@-`:@U3
MU=35Q\;'A%6:2D26(!V;F9?7"@J/&!B:*RNF+R^Q/CZQ1TBX.SVLD)+8AHB_
MAXJZ\?+Z]O?]Z>KOP,;&S=+2\/7UT]?7^?S\U-75P<+"LK.SI*6EU-74K["O
MQ<6_^_OYU]?5<W-RZ>GHY^?FX.#?S<W,DY.2__;P_/7TZ):4SJ6DS0$`R@``
MT`4%T0<'S`X.VQ04S4`_S$A(U(^.SZJJ^/?WS,O+_O[^_?W]_/S\^OKZ^?GY
M]O;V]/3T\O+R\?'Q\/#P[N[N[.SLZNKJY>7EY.3DX>'AW]_?WM[>W=W=VMK:
MU-34TM+2T='1T-#0S\_/SL[.S<W-S,S,RLK*R,C(O[^_O+R\N[N[N;FYN+BX
MM+2TL[.SLK*RL;&QL+"PIZ>GI:6EI*2DH*"@G9V=FYN;F9F9E965E)24DY.3
MD9&1BXN+B8F)A86%A(2$@H*"@("`?W]_?'Q\>GIZ=W=W<G)R;6UM:VMK8V-C
M2DI*0T-#/3T]____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=`5'P@````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"^241!5`C78V#``BHJLI7=7?Q"HJ+"PE.\
M'>U!0OD9^7EAP9%1$6'5]>&,SD"AHM2<XD(Y(RM+ZP#5\F(M3Z!0>K!OKK2-
MN;&9A:%L5HR;#E"(D]$E4(;%Q)29E<E`WM4G!"ADZZ2M$,G-QLXCR*7O[,T1
M#11R\(HN4Q/GXQ<0XE5/CM55!`JY!]4V:8:*B0B+2FI4U24E`(7\0@H:&A-]
MI23L/4IK].+2@$(JD7:5F?Z>3HS.WO$E*4KIV+P#`(CJ*JZ!TAAS`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMY+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#0Q-S,V,S`Q-``P
M,C$W,C0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#___^KDIN>@H[9P,M:14^UHZR3=H9]5&^YJ[7%K[]B6&)[8GZUJ[K(O-!?
M27:@FJ9Q8XAK7X"9C;0^,&B'?*B4B[!P:X`],6I327QC6HM".7!<5(AO:)=Z
M<Z(W+VM22H)73XI=591&0&M43GQ84H!Q::%?68AR:Z)U;:1V;Z1]=JI\=:=Z
M=*,P*6<U+FHU+FDW,&PW,&LY,FXY,FT[-'`\-7$]-G$\-6Y!.G5#/'A$/7A#
M/'1'0'M'0'I+1'Y(0GA/28)028)33894389.2'T_.F1;5(]848I43H-<5HY@
M69)A6I)(0VU43GY,1W)<5HEE7Y=02W=.271E7Y9J8YMO:*)74H!P::%<5X9N
M:)YD7H]X<:IN:)MU;Z5H8Y)X<J=L9I9[=:ES;9UP:YIY<Z5T;IY]=ZI\=J>+
MAK.(@Z^*A:\V,&XU+VPT+FHW,6U(0GYB799/2WEE8H!F9'D[-W,[-W)'0WB"
M?ZZ*B*="0'AS<HJ#@YA?9I:9H:"BKZ>YS;2@NI&NQ9N6GX;(HGRYFI#J@VWG
MBG?S@&NJ64N^:5OI@W+NB'>185CVMZSCJJ"W0S/`2SB`,27/7TW7<&&YA7UR
M2$7#B(2Q<7'___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#/`T+P`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])
M1$%4"-=C8,`"6+E+NOBX>&OS#8RM70*UTH%"TWJG]O3U3Y\AD6OII!26G@$4
MFM39WM$V>>($D5)[]YK*I#2@D#@;2S<G$T^YF9VB6F.=9CQ0B%E8;(I@%3N'
ME7.A:$MK;"10**M"EE]:+T=2P3LBNZ%>*APHE)GL698G;U[@%14CT-0L5`04
MT@VP,=(WM?4(34B7JRY6\0<*13N8Z`-=%!*7GIHHXQ>L#!1RM=`WM'3TT=#6
M25%7#?)UP^8=`$?I+^I,RB,H`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O:WHN<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#0V`#$P-#$W,S8S,#$T`#`R,3<R-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___P"&S`"'S`&(S`*(RP.)S@.*
MS@.(S`6+T`6*S`>+T0F*S0V3U@V-S@V,S1"5V!B;WAB4TAV?X2&AY"&BY!^7
MU1^7U!MXIQIQG2NIZR><V"*#LR&`L"^N[B^O[B:(N2B*O#6Q\C6R\BN0PBJ-
MOS&BVBV1Q"Z4QS"7RC*9S#BGX3BIX32=TC.;SSZX^#:?U3:@U$*\^D*]^CJD
MVD:__$&OYS^IWS^JWT*NY3J8QT:RZD:SZDW#_TFV[DFW[DBT[$_$_TR[\E'#
M_4Z\]E'#^U#`^5#!^5"[\5?!]E[&^EJXYV3)_67%]VK-_PF*R!60S"N>TS6.
MN$2OXT2PX4[#^E#%_EK!\6O,^AB1Q@R,NR^IUU7#[%S`YUN]X5_$Z1^0M2F8
MO4R^XV'(ZQV6MU3!XA2.KAB0KAF/K&G*XR"1J$JYT#>@LT"RR!9<8SJ"B%2@
MIW;+TH#/UU6TNUS!QX'4V1I>846EJ7/-SB=I:%FZMG7(Q3N=E3Z@F#J:A5&N
MCVV[D4)W5%ZJ=HC,E8[)EH*VBIW7I7:W>FN78X.[=ZK<FT%I,:S;FK3CHVZI
M4W&H4;#=E7.G3H:V6WRI1+_@=:C%4Y2Q-LS`"MC+$/___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"T'^$D````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````OTE$0508TVV+30[!0!A`O^G,&+3J)]7$
MCL3.7H+$29S#,=S!0B(22^>1IE$+(81.YU>--6_Y\A[`#PB6W=4@TFDF9(71
ML#/8$1!\HLWUH@0AN-8,'D#`9Q+QDUC$V9ZU?2*<XD'CGLW1B$1%+[E9"1Z@
M:IG.Q@%&N-4/49&[RK/V4GKH7'\J8XK".(65%9MZU\OR.#E*I=U8H:5ZK^\H
M'D97J>RW$JQ4C&[#:>/%N5;6*1(<*,%^^T1Y;JPV\(</47150_3?GM\`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L8BYP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#<`,3`T,3<S-C,P,30`
M,#(Q-C<W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____S!\AS2@JL"@I\D5&_%98_EI;T<+#_>_PV\W/U,[/BX:'SLG*__[_
MU=35Q\;'U-75P<+"_/_^SM71O\G#[//NN,&ZLL*UR\S+*V4CY>WDDJ>/=I-P
M>J%Q@:)Y57A,1&DX*UP9-V$A\/'O/5D98G0_JZR@Y^?FX.#?S<W,M[:MHG54
MM85EW+FNT*RBQ+BWS```?P``S@,#T`4%S`4%S0D)S`L+U@T-V!`0T!`0S!`0
MTA@8X1T=V!L;?Q(2Y"$AU"`?SB`@G1D9TB,BIQL;Y"PLUBDI[B\OLB,C\C4U
MORHJRC`PE"0DX3@XU38UO#`P^D)"U#DYQS<V_$9&X4)!TCT]ZD9&QCL[_T]/
M[DI*_E!0^5!0Y4M+]E=7^EQ<NT9&YUA8_VAH_VIJ^6AH^G1T]WIZS+N[S+R\
MS\#`_.OKW<[.S\+"N:VMX-+2\N3D\>3DWM?7__CX^/'QZ^3DV-+2LJVM_??W
M^_7U[NCH[.;FZ>3D^/?WW=S<_O[^_?W]_/S\^_O[^OKZ^?GY]O;V]?7U\O+R
M\?'Q[N[N[.SLZNKJZ.CHY>7EX>'AVMK:V-C8U-34TM+2S\_/SL[.S<W-S,S,
MRLK*IZ>G____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(_A:K`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#`
M241!5`C78V#``HR,G".2X_QL3`U-+!V\0J*!0O:^"6FIB4',3$[N?E'Q22E`
M(9ZRZO*J4EYU;>["DN*BBDJ@T/0)?.VUD\05%42Z6^OJVS2!0@*,+;T3)665
ME.55&NI:>B8"A6J:-`2GR$BIJLE),S9W\4\#"M5W]D^>*BJAHRLFW-C1IR4$
M%"K(SDS/X.#2U\OBS,_+,<@%"H6Z6)M;V;FQLK''Q88%![``A1S-#(TM;#T"
M(V/"_7V\/5VQ>0<`W?HO]\0B_^0`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VQC+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`U,``Q,#0Q-S,V,S`Q-``P,C$V-S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#___]33U%\=XQB77Q345U65&F2
MD*<Y-7@[-W=#/W]`/'E,2(9C7I]75(E/3'I@7));6(AR;JAG9)AM:I]K:)QK
M:)IB7XUO;)]B7XQT<:9S<*-C8(Q_>[)^>[!]>:YZ=ZM]>JR#@+..B[MK:8V1
MCKV4D<"3D+]<6G9W=9@R+W8C(4DD(DH_/'X].GI`/7I&0X)*1XDN+%5(18-&
M0W](18%*2(,U,UQ23XM/3(575))13H=13XA448M!/VL^/&5.3']858Q(1G-?
M79A;6)!*2'5&1&YC89QI9J)C8)A>7))44H)03GQ758565(-?78]<6HIA7Y%U
M<JUG99EU<JQI9YMY=K!F9)585H!A7XN!?KA\>;!V=*A_?;2`?;1U<Z:!?K5U
M<Z5_?;)^?+&`?K."@+&"@+"(AK>`?JN.C+R.C+F-B[B3D;]D8W8S,7-"08-.
M37=K:J-=7(QL:YA\>ZQ45'V0D+!)25,P,#%X>8$W.4(R-#,("0@#`P`)"0<>
M'AL;&QD;&A%C85CDMB'HN":UD2#UQSKJPD;^U%"^H4'AL!V=>12IA!CNNB^^
MF"OZR$++JDH8%0U)1CZ>=A#RNS7\R$;^SD_YRE#(IDXJ)AT2#PJ#?WM*2DH0
M$!`%!07___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"Z4EM8`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"=+3M)7.4/#55\O2,
MK3S"$H!"VN81V>DB+JSE!EP6[B&QR4`AHX(,Y41;F?H&<4-G(=FD&*"06[&J
MHA</6VU=+F]A=(J"&%`H4CU5V)2O8M[<.6E!<?(2_D"AK'0):UV-FHDSJ]FC
MY*0#!8%"F?&.^I95LWKZ)E6J284'>`.%2@1,.$H;NUO:)C25B1;Y\0.%@LTX
M\YDF-T^9VC%C=JBOCQ-0R(9;BZ6UJ[=_VO3V3F8'5SMLW@$`FZ`QN]-8(4,`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;&LN<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0U`#$P-#$W,S8S,#$T
M`#`R,3<P-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___P9#`!A6$2F"'Q5S"6ZW9!10"B5^&"MJ(3R.+S1U*D24.$6&.U6A
M2%RH4%&41FFS7G"U97:[:A=0`!=/`,SA-<34)O+X/O3Z0OO[3?__3^;F2?GY
M4,W)&.GD1NC9+]3".LBO%-F[*]BV'>[*5\F>(8!E&?#'4<&-"L*5,__2:LR(
M`,R)`="+!<V+"=*4&-VC+]JG0>RV2)=A`)EE!9YM$L"''=>;*ZI\)\^=/NBP
M2KR00/K!7LRC5\2>6=>O:-:)#=ZA.I=Q,KJ"+L-V$."=1K9C`+=E`;=G!;MI
M![MN$L1[)\:$.^.<3N>@4<%Z-*A7#>2//I94&^B54.:54,Q8`[-0!<Y?#=1L
M(.&`./&44,Q6`,Y8`[9/!_VD9/>@9;%%`>2$2N:&4*X]`+I*$.2!3<9F..)^
M4=9F.MUX4+=$&,A0)LY9+\Y:+ZDK`==J3J49`*8=!;`G$*PO&+(W'\Q,-=A=
M1J@:!;PT(:\=#;1$-K@H':$T*J4W+=!63*$)`)TO**HX,*LW,==949$F(<DZ
M-;(X-<-(0L%&0M144)H``*`#`YT#`YH#`Z`*":,*"IX-#:D4%+DD(9(C(Y@F
M)J`L+*@P,*\T--)$0M!"0KP_/M)&1L5&1LE)2=A/3]9/3\Q,3/___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"7L:_8````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MODE$0508&67/L0X!010%T#=OAC5B$;(VF8@0B49$PP\H_)-_\A_4$E'91",*
M!&N%W7WSC-HM3^XM+L!?!`3<'$3IS+?L9442^Z6"BQ@W;TG5W"M7_1AZ,2@H
MJ)Q?IAT]UHDQ[\X$$+`@<LN4T.=3KF-&CI2TS)9B3[&*CYI^0_LC3#>IW"*.
M:J[U)&(KI#F_A<]88D<Z)\N(8MZ?+CHZ8S=T4,1,F%;JGUIE>0,)EL,@/S1Z
M2G>?H0E6N[\[`%]V\U/^2MW5<`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]L="YP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$Q,#$`,3`T,3<S-C,P,30`,#(Q-S`W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```5````#0@#````<4S54@```8!03%1%W=P`W]X`WMX`W=T`VMP`X>``V]H`
MR,8`^OD(^_H)__X._OT/__\6_?L2[.@!__\+__T$__L"__\)__H&\>@`V?\0
MV?\.V/\/V/\-VO\-W_\1W/\.X?\3W?\0SO<%=?\%=?\#=/\$=/\"<_\&=/\.
M</\/=?\4<O\39/(((N\`(>X`(.\`'^T`&>D`'>T`&^L`#]X`!OP`!_T`"/P`
M%/\`$?P`$_\`$OX`!_(`,^(+,^()->0-->0+-N,+..`%-MP`.M\%-]\&+=0`
MEY`,EY`+E8X*E8X)DXX,DX\2D8\4CHX4B8H2@X0-M2X`M"T`LRT`L2\`KS``
MK3``JBT`I2D`X0T!X`P`X`T`X0X`WPL`VPD`^@4,^08,^@4*]P,#^`0#^`0$
M]@,%\`$$Z0$`Z`$`X@``X`$`WP(`V@$`TP``````````````````````````
M````````````````````````````````````````````````````````````
M````_H&=V@````EP2%ES````2````$@`1LEK/@```#Y)1$%4*)%C88`"1B@%
M!BP<J*(0819V!E0`$65C_`^&C!":"2+*A5V4&-M@HM0V%RC,@.3>_R@F<*"*
M0DP``'IE)O7W!?A!````'71%6'1C;VUM96YT`$-R96%T960@=VET:"!4:&4@
M1TE-4#F$.24`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]L=2YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,S4`,3`T,3<S-C,P,30`,#(Q-S$W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T`4&\C4VIYV>
MU=35Q\;'R,G-QL?+]O?[Y>;JV-G=R,G,O;[!^/G\Z>KMY^CKU=;9T]370FN_
M1G##16[`16Z_1W#!2W+`47G,4'G)5'K&4W?!5'C!8(C87X;467S&7(')3FRG
M2F:>9(?07X#%5W:S4W"J<9CF<);B8'^]7'JU9X?);Y'69(/`=);=:XO*@:;Q
M@*7O=IC:87NQ=933B*OSA*;K?9[?BJWTA:;K:H6\<H['B:KN@)S6D[/TCZSI
ME[7TD:[HS<_3Q\G-^?O^\O3WU-75Y^?FS```?P``S`$!S@,#S`8&S0D)U@T-
MS0X.S`X.V!$1U!86E!$1TAD9SAD9X1T=BQ(2U!\?Y"(BWB0DG1H:[B\OZS<W
MV#(RX3DY^D)"NS(RLC,R_$='YT%!^$E)QCL[_T]/_E%1^5!0_UA8[%)2[E-3
M]E=7^UQ<^EY>]V5E_VIJZ6)B_6UMS;Z^T</#S+Z^V\W-S\+"Z-K:W=#0_O'Q
M]>CHX-34_?'Q\N;FU,K*__3T\>;F^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[N
MZNKJY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,RLK*____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````&8MNS`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"V241!5!C3;<$Q2@-1$`;@
M_Y^9MUGW81#/DRIE0,@)!"]@+8B6X@T\0\!>.QN+%+E)($AB<#?[WHP'T.\#
M_B`6N,RY[(^]ORW;U4UZ$:!K.O\9AL*KI-=&&*;Y@OVIJFBK;3*'X?6!G)R[
M4T1#Z2":\;E10ZU>2IBE6\'CT\>[PCUJO5>]2R"F(D?.8AVS^&QDY(&8'[[Z
M,,LY2;C'L#%L=R=G<I/",G@I,'Q7FJ;N;&)CE2#QCU_LNDF9^_9S;P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQV
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#0Q
M-S,V,S`Q-``P,C$W,C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____!I:[@Q,V#$#A2"B.#$3F%$SN'%3V+&$"'&#^(&T%=
M$RV2($B6)DUE&S6;+%.?,%>B,UJ8-%>>-UNQ1VR`-$ZU2W"E1F>:06"Y476F
M2FJ\57FK3V^S57:Q5'2O4W.V6'F:2F:^77^V6GJF4W#(<I"ZG*;%J++2M;_#
MK+3KT-GNU-WGS]?QVN*"##:##SB$$#F#$#F'$SR(%3Z%%3V.'$6.'46*'421
M($B+($:3(DJ+(4>*(4:0)TR2*4Z/*T^A,5F4+E)N(SYU)D*E.5]\+$F$+TUV
M*D5_+DNJ/F6=.EV>.UZ',U&N0VF--E6)-5.P16N6/%R1.EF3/%NE16>?0V2L
M26R<0F*E2&F+/5F[57FK3F^]5WN_67V00U^V5GB41F+`7("^6W[`78"_78"[
M6WW`7H&]77^Z6WVW6WRA4&V]8X/%:8JX8X&W8H#":HFU8X#$;(O%;HW#<8[)
M=9/+?)BYFJ6]GJG1N,'6O<;FS=:YI*SZ^?KY^/GX]_CW]O?N[>[IZ.GFY>;@
MW^#5U-74T]3-S,W,R\S^_O[+R\O)R<G___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````>0+T?`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+9)1$%4"-=C8,`"6%F=$TMS0NU,C3@L!?VBTT%"_%$E!3%.7$;L
MY@)>4BD90"$>L<)B>6%N%D-./E?Q.&4YH)!'MEJ6CQ6;@8FUD&ALJJ(T4*A&
M3[>22;V\0D.365NGNDH+*-10U]S6T=7>VM)8VUG?U-8-%"K+#W.PM;$7"4_+
M+<I358H'"JEX6QCH&_,Z!LHD)T0&^;L#A23@+LJ4E0SV=0,*.7$9LIL!7924
MH1`1$N#I@LT[`%SR*EN4OJ'T`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O;'DN<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,C`T`#$P-#$W,S8S,#$T`#`R,3<R,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```&`4$Q410```/___P!P&@!P&P!&
M$`%Q&P%Q'`-R'0-Q'05T'P5S'P=V(0ET(@IY)`IX)`U[)PUW)@I1&Q!^*A)Z
M*Q2!+AB%,AA^,!%9(AV(-B&,.A^#-QEB*B:0/QMG+2>(/BN41")R-2%O,R^8
M2"%J,R9W.2AY.S"/1C6=336<33".1BM^/RI[/2Z"0BV`0"IU.SJA4CJ@4C"%
M1#"$1#2+23.)1SZD5CB53C:-2D*G6CJ23C)^1$:J7D&<5C^74T*<5TJM83J'
M33N'34VO9$:@6TVN9$FD7DBB74^P94^P9D^O9E"P9TRG8E&P9TZJ9%&O9U"M
M9E"L95"L9E"I95"H94:465>N:UZT<EZS<EFH:V2X>&6U>&BZ>V:U>&J[?3*'
M162X=____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$>_[2P````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````G4E$050(UV-@P`)86*0=8D/-Q+B8.(4D-:R]0$+B5E%A-E(\S.S\
M$DH6'OY`(4&]B'@W.0%6-CY1>5,7/U>@D')(=+"F,`<KMXB,OKV?MRU0R!%N
MD+JUEZ^=,5`H)AQND'N`L[DA4"@2;!`OT"`G/U?+."V@4)":,`<ST"`#>Q]O
M6Q-=%:`0PD5`@W14%8%",(,\`YW-C;059+%Y!P#5\QJ8R<Y+C`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6$N<&YG````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S<T`#$P-#$W,S8S,#$T`#`R,3<P-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%0````T(`P```'%,U5(```,`4$Q41>4``N$``MH`
M`=P``.<``.H``,8``-05`,@&`-,&`-H``.4%`-```-X#`.4``.D``.@``.,`
M`/\(&/L.&.\3%><0#>0)`^0(`.8*`.$3`-(;`-LM"M\K"M<5`.,0`.0/`=T2
M`^`-`NX%`?4#`O,#!.T#`N8``/<`!.P``MH%`-$,`-(2`-,7`-$:`,@?`,$O
M`,`S`-@]#<<>`-@9`-,1`-@E!\\1`.T(`O@$`_<%!/($!.P"`_\)#?H&!NH.
M`N@A"O$Z&O%*(.1*&--$"MA2%<M%".)/&>E)%_%!&.TY%/1&(?$R%NT&`/D!
M`?<!`O,!`.L``/X``/8``/```.D-`.$C`-@V!<A"`\1#`<T]`+XD`,0E`.9"
M#=DU`MTQ`^0D`.\9`/8%`/X"`?P"`_```?D!`/X&`/\'`/('`-D-`,P@`,L_
M`=95$<Y``,(N`+HF`-U'#-,V`-TN`-\0`/,-`/H#`/\!`?X!`_@``/(``.X`
M`/4%`/L%`/$"`.0"`-P2`-LQ`-Q,#\9)!K]-!KA&`,!#`=$X`-PE`.4,`/T`
M`/@*`/8&`/<!`/0$`.X1`.4=`-0H`,DN`-)#"=U5&=Q4&K\P`-<W!]D?`.P2
M`/4(`/P#`/\"`/\"`OL!`O0``/L"`/L``.\'`.$>`MLS#-4^$=<Y#-P7`.4/
M`.H4`/`E!^XW%>LT$NH<!.@%`/@#`/T``OD``/X%`_T$`O(*`.(;!MLI"]0K
M"MHA`^T'`/D-`NX@"^DA"ND2`.@!`/D$`?$``/0$`_@&!?D'!?<(!?8-"/40
M"O`-!NL$`/@%`?H!`/@#`O<)!O@*!_@&!/<"`?L#`_D#!/0!`^X``N8"`.H%
M`O($`O@$!/X&!_H"`_D%!?0$!?,#`O8"`OL"!OP#!^T!`^@``M<'`-P(`.,&
M`.4"`.L!`/`$!.X$`^H"`.<#`.4%`^,$`.`!`.(``.\!`>8``N``````````
M`````````````````````````````````````````````````````)8:9A,`
M```)<$A9<P```$@```!(`$;):SX```!Y241!5"B18V1@!('__YD9$>`3HQ`C
M-J".5=0&JV@@IM!K,<94K&JK4+F?7ZDPO&=D[,*J=A8KFL`)2\:3C!L9H+P?
M'R3!],XWKPL9#\`5/9<"4V!5EQG]-@.IA0D)"QD9B_H9"_H\=C,R/H2JU+@)
M(I6S7G7Y;F$$`'2Q'Y#4<M7Y````'71%6'1C;VUM96YT`$-R96%T960@=VET
M:"!4:&4@1TE-4#F$.24`````245.1*Y"8((`````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6,N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0T`#$P-#$W,S8S,#$T`#`R
M,38W-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___\<\/?]G:-6SM,'"PK*SL]35U.#@W]W=W-75U,W-S,T!`,P``'\``,T!
M`<P!`<X#`\P#`]`%!<P%!=$'!]`(",T)"<P)"=0*"M8-#<X-#=@0$(L*"L\2
M$ML4%-@4%-X8&-(8&)01$>$='=(;&^0A(=0?'^0D))T9&>@F)NLK*]@G)^XO
M+Z<A(=TO+_(U-?(X./4Z.K(J*N$X./@^/OI"0N$[.](W-[LR,N`_/OQ&1N=!
M0?Y*2OQ)2<8[._]-3>5%1>Y)2>Q(2/]/3_Y04/),3/U14?M14?E04/Y34_90
M4/%04-1&1O975_996?I>7NE96?UD9/=E9?]J:O]L;,ZDI,RBHLVDI-:LK.&X
MN-2OK^['Q\JJJOK4U.?$Q/_:VOG5U>K(R/K9V?C9V?[^_OW]_?S\_/O[^_KZ
M^OGY^?CX^/;V]O7U]?+R\O'Q\>[N[NSL[.OKZ^KJZNCHZ.7EY>3DY.'AX=[>
MWMO;V]K:VMC8V-;6UM34U-+2TM'1T=#0T,_/S\[.SLW-S<S,S,K*RL?'Q\3$
MQ+^_O[R\O+FYN;"PL*>GI____P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X@A_\````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````O4E$
M0508TVW!,4X"010&X'_>SLZ;F07$Q#5&KL0%;$D,)Y`*2WL;#;&THJ;U`A[`
M,]A("`$!Y^UCQP/`]P$G#'H87-?RO=HD%V*LX@<!=?]*5]M=LNS9!0O"1?\F
M;]>_B3RSCS:!<'F[D.7FH,X%]MS^@?#EAS][0:P"=[JV:6$QRMHYYEP8(C+F
M_>[3@JK(E*61]#KVD><@A)DCJ&HC]V[&TR<0_$,!U:,('$]*,B`\EVA5I7DK
M^87IT>",?]IU0DA69)WY`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]M9"YP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P,C,`,3`T,3<S-C,P,30`,#(Q-C<T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____U34V`!>4.$NS4&+%9'73`!!:
M`QJ6`QJ5#2.8'S2C(3*`05:V.DN@.TR>66N_9'?197;/:'O39GC-`!N1!1^3
M"2*4"AMF$BN9$">($BJ+$BF)&#"<$2)N&C*2'S>@'#*+&2IW)SZE,$:J*CR*
M.$ZP,D24/5&A2%V\1EFK4&7"5VS'7G+,5&:U:GW3:7K%=(7,*#Z3=7]2=7LQ
MFI\*J:X/QL@*L[4+O<`1R\T:RLPP?7X^S,P`SLX#S,P%S<T)PL(-TM(86ED+
MY.0AU-0?N;H;T]0F[NXOX>$X^OI"__]/_OY0^?E0>7@GW-Q(U-)&Z^Q>K*@!
MIJ$!R\@UT\HU]NQ.[^91T,(%ULD-V\T8T,(FZM]&J)D4<&@4XM1"Z]U-TL9*
ME8U)95H#4D@)@6L`@VT'B'8GG(H[>FY!9DD`@%<AICP%L4<0_%A&_V!/^V%1
MX2L=ZSDK]4LZU4$UY4Y"\EI,V!X0Y"$AIQL;L"$A[B\OLB,CN28FO"@H\C4U
MORHJQ"TMP2PLQRXNRC`PS3(QTC0TSS,S^#X^^D)"VCHZX#\^_$9&Y4)"_DI*
MZD9&_TU-[DE)_T]/_E!0\DQ,_5%1]DY.^U%1^5!0____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````8^0&)@````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"L241!5!C3;<%=2D-!#`;0+W,G-W#U@C]8
ML45:T.WYZ`I<H$LH]4$1"OI06I.9)"Y`SP'^(`A6^X?-CWJLUB2S/!7@EFM&
MCR"R81H9!9?R>8A]O[Y1HEE847&X&M+.[@N=.XWLAH*![W+Z%I'9&I,V%'#L
MY"OM[34F8GT.%'A?9!NV[R<ETO82J%CJ,8.6CZ2GA7GOJ&CJ1O1QT?N4S=U1
M899<9SI2&3,\$O_X!9;`5`%+B2FO`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUG+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R,``Q,#0Q-S,V,S`Q-``P
M,C$V-S0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#______O_'QL?4U=7&Q\?5UM74U=0G?0HTA!1/GB]&ABQ.C34[C1A!CR%-
MG"M-C3%?JSY6F#I5D3ILMDUFJDE=F4)OM5$W;QM+EB8]=2$_>"-#?29$?BA'
M@BI9HC5*A2U>ICI1CC-FKT)IL$9AH4)LLTIFIT9QM%!LK$QRM5%NKTYJI4],
MARY/BS!5E#53D#1>G#YRMT]RM5`N;@,^>@U,B!U>F"]6AC!7AC-<C#9OIT)M
MGT9ZKT]YK%#GY^;=W=RY&P7!)A#.-R'<2C7#1C3H6D;25$+K8U#C8$Z[1C?%
M$0#!#P"_$`"T#P#`$0&_$0'`$P/)%07%%@7&%0?&&0K`&`G)'0W1(1#0(A31
M)QC,)QC4+!W=,2'=,R;>.BOB/B_K1#7J1SKL3#[N44+V54;;2C[T5TKZ7U#S
M6TWF5DGS74_I6$ST75'Q75#P7U'RB'_()Q_'2D+/7%3><FK`"@/!%0W;/SC_
M_O[Z^?GX]_?LZ^O=W-S2T=']_?WZ^OKW]_?V]O;Q\?'L[.SIZ>GAX>'8V-C4
MU-32TM+/S\_.SL[-S<W,S,S+R\N[N[NRLK*GIZ>=G9V4E)2+BXM_?W____\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"6U9^"`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*E)
M1$%4&--MP3%.0E$0!=`[,W?>)RJ6;@F(R]'$PF@(%0NP<"\&.DHJMV!/B,&\
M_/]FG@O0<X`_!&^(QX<Z?-4Z%"?M78&,9^$XC<5I5@H4/7Y2NX]*,W,V***^
M4GIO3AH9#0++->N1WR*B*ID?Q)/O#]O3)")4R4P0Y.)>/INKFF7D!(*[E?8A
M;F;./CMGNRAL:0CS8G-I_3H2BHTA7^X:;R_M*L^9^,<OE]Q&E7\/<@``````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O;6XN<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#(T`#$P-#$W,S8S,#$T`#`R,3<P-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___T^!J%"#J52'K5*$J5R/M96]
MVUJ+KF>:OFJ8N8"KR5",LU:1MV":P&VERGFQU86[WHW"Y(*RT8_#XXN\W#V2
MP3R1P$*6Q4&4PD>;R4J>S%">R5:HU5ZOW&*SWW"^Z7C%[S>4Q#J5QCJ6QCJ5
MQ#N5Q3N1OSR1OT&<S$&;RT*9QT"5PT*4P$NDTTNDTE>OW5*ET5>NW%&CS62Z
MYV2YYFN[YF>TW7'$\'O,]GO(\8#.]W[*\H+,],>))]NE2-.0.,>11NRQ9<V$
M+^2?4.VH7O"O9/*R:+U@`,=T(-F,0+U=`\!A#;]G$KU7!<-H&(I'$:9C*O.I
M:K%J,NF85]V26;UL.\A8']9N.,$\`[\Q`,`X";PL"+PL";\Q#;TS$'D4`'D5
M`,8T%<<W&L0]'Y<O&9XQ&Z<W(>1-+ZDZ([`^)K-`*.93-;5"*KY'+KM&+;A$
M+,-+,<!),,A.-,5,,\M/-N]@0M!4.O)D1M99/O1F2MM<0L!1._1I3=]@1N1D
M2?1K3_1L4.AG3.MI3O)M4?%M4>YK4-H_(<]")]E/-<)',,I,-.Y:/L].-M=7
M/N1=0\94/N5B2?5K4/!I4.UI4-=A2M]F3_!P6.1K5>QQ6NUY9/6$;W@0`(0:
M"O5V9/!W99\O(>I@4/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'!(_.L````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````K4E$0508TVW!.V["4!`%T#N?!\1"((K(
M%$@I8GIZ%D)-SQ[8%:R'@B+BYR"DQ,^>&18`YP`O".M(Y==F<;3B9U4=AQ];
MQK*^?H=VDY'0_%`,$AA$'%W\MS<EJOJI@4+JGOQYOG.BWJFP#,5NPONAV>=-
M*$U_FPS%65+TC:\B)-'F`$/S0YQ2R4+L3>=0N!8>E"Y,'&;>0M&-PYAYJD1F
MV0R*4B-4]#0+;R,\\,83*.A-)ZW1/](`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M;RYP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#8`,3`T,3<S-C,P,30`
M,#(Q-S$T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____'X%#*Y)1-8E43)9H`'`G`W(J`W$I`W`K!70L!7,L!7$L"70N"7,O
M#7LS#7HT"E$C$'XW#W<S$GHW%'DX&'X\$5DJ&'T]'8A"(8Q''X-"&V<V)XA)
M(G(^(6\\+YA4(6H[)G="*'E$,(]1-9Q9*WY(*GM&+H)++8!**G5$,(5.,(1.
M-(M2,XE1.)58.)59.)19-HU40J=F,GY-1JII09MA0IQA2JUM.H=6.X=61J!E
M3:YO2:1I2*)H3[!Q2*%H4+!R3*=L3JIN4:]R4*UP4*EO4*AO1I1B5ZYU7K1\
M7K-\9+B!9;6!:+J%:[R':KN&`$88!70J!G,K#74P'8A`'X)`(H9#&6(R,IA4
M,H=//J1A.I)809Q@/Y==/Y9;0YQA/X]96*]U4J)M7+1Y6ZUV6:AT7*9T9K6!
M:K>$<K^,::^`::A^CLJB1IYB2:!D4*IL<;F(?,*2C\VB.)U5-)!/@+Z1)HE`
MH=6O&GTR@ZV-$'<F%7PL%GLL-(Y'IM"O%GDJ1Z9:CK25F;B>-99#J\:OOMK"
MT.K3)($N+(<UI+VF&'D='WXAO-*\.9,WZ/?G:+E?,849S-7'U-W.S=3'\_CM
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````,!A5JP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_
M241!5`C78V#``@(#(RP#/`TD>-BXA*1431U!0N(FOEYF3+4]G`*2"L;VKD`A
M0:TT'X>ZCNZ)-7W,T38NMD`A10\_]]+*:A;6\I9&"Q>G.*"058"G86<#7]>D
MY)()CL[FND"A#._8,-&JIM;)]>U9!=9&VD`A'SO9$.'F*;UM4_N+\F.BU(!"
M;BHB',&).=F%%;FI\7J:2D`A?3%NMJ#P]++BXLP$70UE>:"0-"\;.W]H9(I_
M4IZ1CKJ<##;O``!_.RZ1=/H08P````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VUP+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`T-P`Q,#0Q-S,V,S`Q-``P,C$W,38`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#___^^MKVTJ[37T-C&P\IH6X5_
M>)5I88QM9X>-B*.YM,Y!.WY33H=E88DH(W@C(%9'0I144))M:+564HUR;K>'
M@\&;F+\7$G<B'W8H(X,8%DLI)GHL*7LO*WPS+X,U,H8V,X(].HX\.(8J*%]"
M/HH].G\V,VXR,&=(19`Z.'%44:%34)U64Z%"0'U<6*I85:10395'1(-&0X%$
M0H!(181,28E$07I*2(923Y).2XM23Y%038U449->6Z-F8Z]?7*-I9;%C8*=A
M7J)54HQ=6IEO:[5L:;%G9*EQ;;=P;;-Q;K1?79-]>KY\>;IT<JYX=K-Y=[.`
M?;N%@L&!?KMM:Y**B+F-B[MT<I>8EL"FI,DC(7DF)'TF)'DM*WT\.I`[.G4]
M/'A-2XM759Q85IQ03X]759A<6J!,2X1A8*A=7)YH9JMK::]Q;[AQ;[5N;*]Q
M<+5A8)MS<;5E9)R`?KZ#@<$K+'PR,GY.3H5F9J=Q<;%X>+MO;ZAO;Y"UM;W*
MRM+#P\F]O<)N<*AW>;!M;J%B8X5!18E:789)37.XN<*HJ[FIJ[*1F:M[B)=S
MCJF&G*)0:6[!Q\B7KZ2^V[^5KWV`D6K*V;6IHXJZL)"EE6ZZI8#*MY2GFX[P
MZ.2XJZJYN;G___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"5#&1>`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"I*4U7(*]:_@ZU&(4
M!`T<14%"*AE!U5RS9TZ=Q1FO;>_I!102,/?W[9G"UMK.,:-%WRTO&RBD55A:
M,'V"1&VH5-\DX=R<+*"0B%B1ZQR>BKK.XJ9I@>[.UD"A$#^'MGZCN(9ZW:K)
MS4ZV5D"A$@_-LE[V\OF-F=P3*]-L3(%"^8:*DKSS(KJ[Q.>&)Z=:Z`&%4I1E
M8Z-]F)E862+3+<U,$H!"JG+\,O)*.F%1`79"2<:)ZMB\`P#4$#'F%:SLLP``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;7,N<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W,S8S,#$T
M`#`R,3<Q,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___[)K<*Z5IU](6YU_F-S%V;BGMY)RELZXT8%7B69;:K>KPGYFE\N^
MX;.KR6Q>I$`QDEA*GY:+TYN2T71OD3XRE%!%HD(YIE))K3\YA%Q3O49`BU=0
MHUA1I%Q5J65>MF9?MG-KQ'QUSC`IES@PH38NF34NF#4NES4OFC8OF3<PF3<P
MF#HRGCDRFSDRF3LTG3TVGSPUFD0\IT$ZHD`ZH#\XFD0\HT0]I$=`J$,\GDE#
MJTY&L4A"HD])KU1,M%1-LE!*JTY(IEA1ME1.JEQ6N4A#CF%:O4Q'E&5>PU--
MGU%,GE!*F55/HDY)EEQ6KVQES65?P65?OFICQ%Y9K7)KRW9PSW5OS7ART7)M
MQW!JP&YHNWUVTG-MPG]XU'UVT7ESS'UWT7UWSWITR%U9F8F#THN&UC0PG#@S
MG3LVGSPWGFIFO5U9I8)_THB&M6QK@$(_HDE'HH6$SV]NCFEIJW9VOH.#REUC
MNF-ILGA_PX*)S(V4S[7,WY:KN9FUP\KI]KS7X<#;XK;4V:?#N:>YJX^=DL/:
MQXZF>9*F8HV87Y"88)66BK*W8^N'<^B.>Y)=4=%F5/2";<)N7_")=^N&=;F!
M=_>RI>.DF*M=4<%00H$U+=9T9[E)/G1%0L-_?O___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````.&,;&X````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MP4E$050(UV-@P`)8N(LG\7'REV>HZ1K;>X;%`87F]D^=/&WZ/"8Q35/'H,AX
M9:#0K!E]$WLGS)PCJ%I15UM3I`04$F5GF\+#S%N8*5'9U-I8I@@48A46F2U0
MP,%E;E-5W])0*@\42LV-%C)321>7E*YN:V\ND04*I<6Z9*EK&5J[!N3U='2F
M>`.%DOVM=-0-+)V#(Y*ZN_*]/(!""K;Z&GH6#H'AB0G9.;Y^,D`A)R,-;1,[
M]]`8Y:@0.1\W*6S>`0"[WC&#6,D>LP````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]M="YP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$U-S4`,3`T,3<S-C,P,30`,#(Q-S(W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%:P``<P``<UI:<W-S<WM[>P``>V-C
M>WM[C(R4E)24E)2<I9R<I:6MI:VMK8R,K:VMM;V]O;V]O;W&QL;&QL[.SGM[
MSH2$UI24UM;>WH2,WM;6WM[>WN_OYX2$YXR,YYR<Y\[.Y];6Y][>Y^?GY^_O
MY^_WY_?WY___[Y24[YRE]X2$]XR4]Y24]YR<]Z6M_P``_X2,_XR4_Y24_YR<
M_Z6M_ZVM_[6U_[V]_\[._];6_][>_^?G_^_O__?W____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,,"OK@````EP2%ES````2```
M`$@`1LEK/@```"-)1$%4&%=CL(,#?2A@L+,3DT47DN,6$$97)2J'K@H.!I40
M``#K+7/9U%''`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]M>"YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P-#(`,3`T,3<S-C,P,30`,#(Q-S(Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____U34V_):7^YN=
MX.KJYNCHQM;.P\K&$GHQ)XA$`',A`$<4`W`A!7,E"7<H"W0I#74J#74K"E(?
M#W@M%X$V&'XV$5DF&GXW'X<\'X([&6,N(X,_(6LV,(]+*G4_.)92.)-2.))2
M,GY(09Q;.XA12*)B4*II1I1=4*=H4*5I5ZYP7K-W6:AP9+E\9K=]:+J`9;1[
M:KN"<+^'`&X>`$@3`W,A.H=/9+9Z9K=\[O;P<H1VP<K#NL6\T=O3B9N,E*&6
MU][8Z_+LM+VUR-#)QL[&]_CW3V9+:7MD?H5[8&=<C)5^8F$^O[NP9%`?:EDQ
M85E'5E!$?75LV-7273`1KJ:APZRFLJFHC'MZY"$AIQL;L"$A[B\OLB,CN28F
MO"@H\C4UORHJQ"TMP2PLQRXNRC`PS3(QTC0TSS,S^#X^^D)"VCHZX#\^_$9&
MY4)"_DI*ZD9&_TU-[DE)_T]/_E!0\DQ,_5%1]DY.^U%1^5!0V&9FX7!PZWQ\
M]8J*U7IZY8>'\I*2_Z"@V=C8_O[^_?W]_/S\^OKZ^?GY]O;V\O+R[N[NZNKJ
MY.3DX>'AWM[>UM;6U-34TM+2T-#0SL[.S<W-S,S,____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````W&*UXP````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"[241!5!C3;<&_+D1!%`?@
MW\R9/]?(YB:RHME:+4%%*11>2;94Z7@'SV'+;;8A6](0A4HBN6?FG#,>@.\#
M_G`XW8X+&:]#@'Z^YEF^"]CN#M4Z$4P=E13AD8>2&]'32KN;Y<@@S$OZX1>H
M_[@_EV2\]AA*F^J96>-^&QTW>,PKLXA(9;^,_&`@[/%[MWT>T_?!XTD]LDT`
M3UVH7SUKNKC\4A$$\!0/WW;*L5AH357AP:S>L>E-H&YJ'?_X!1BX7+.40TQ!
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUY
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#0Q
M-S,V,S`Q-``P,C$W,C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____UEYG$14G#14G*35#.45;66U[#96G"9VO$3%+D?H/"
M<WC-7VC'>H#7J:YD6IDT)XL9#'XY+XH:$81M9KYU;<`4"W]97<TR.:!H<=T2
M'I03(905(94;)Y4K-IX%&)8[2:8`%IT##UT8*90A,Z4X2;97:<M%4IMN?=4)
M))0D.IA'6JMA<;AT@\4_3&R.FK,C+D-*5%5_BXL^1T.;J9EF;V"NNZ1K=EFT
MO(](3BA=8SF>I6VIKE.QM4+L[$C.;FO,<&W6=W3,<6[1=G/,=G/AA(';@7[/
M>G?'>';HD(W;BHCDDH_=CXSNG9O^JZGYJ:?]KJS\KZWQJ:;^M;/*HZ+D8V',
M7U[.8F#,8F#R=7/09F3-9&/,96/J='/6:VG2:6C8<&[\A(+4<&[!963E>7C-
M;6SA>'?XA832<7#4='+VAH7:>';^BXJG7%OD?GW>?'O_D9#NB(?NB8>R9F6P
M963[DY'0>GB_;V[RCXV\;V[KC(K*>'?5@'[8@X'ZF)?AB8C2@'_NE)+\G9SX
MG)KJDI'ED([_H:"Y=73YGIW^HZ+VGIW$?GWZHZ'UGIW_IZ7/AX;HF)C_JZG[
MIZ;RH:#@E93RI:3UJ:C@GIW^M;3]M[;RKJ[NOKW5K*SZR\OJP+__TM'YSLW_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````>3*D%`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+])1$%4&--MP<$N0U$0!N!_YDR/>WLI&^F"C70MI0N)V-@0L;/R
MDAZ@*XE=A?01NJT*HFC=SIQ[I@_`]P%_$'K=>DG95^^G@XWQU3W?,3HTC3N;
M[HT]C4Y6YPF"8,ZQ-6^\MU4Q4P;#(C=9$\67@_W=JKB&X*O8^_UPIKIZ+*JL
M!L%B8H&">7G)3#D/(7@K6=69;Y_+5E+=AN!&S7((X>B!+]Q2@N!P]I,X=MJ+
M,_JTT;%!\/IM)%&BN-7>5\4_UAY)4F5-5X9E`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O;7HN<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W,S8S,#$T`#`R,3<R,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___S8U-FYS<F=K
M:&UP;9B;F'JY<WJU="YE)R-N#R5P$2=P$RIR%RQT&"]Y&SZ&*SZ!+$>,-%"6
M/4V,/%F<1U631&&E3UV:3&FJ5VVN6VRK7'*Q86B?6G*M8GBR:8_%@"US&#=^
M(SU_*DV+.U601%F52&*>45:(2':O9H.\<X>\>(>Z>)'%@EYA71U%"VAJ9WE[
M>)"2CXB*AZBJIZ6GI*"BG[*]J%QV/JVXF69G8[F[B;F[`+_#+[FZ`*>G<GIZ
M=G1T<(2$@)24D'%Q;I65DH2$@:"@G9^?G+RV!:6A([&L*KRW,,;!-<S).MC3
M1>_I3^7@5K>S2L*^4O+M:,W)6MW99OOW=N_L=?KW?+RT`\2\#<:^$,_('=+*
M(9N6&Z.=(=W6+ZZH*.#8-;FS+L2]-.KC0NOD1M;/0MO51N[G4.;?3NKC4+^Z
M?KRJ";R9!;^'"I1U1MF4/;J(2-R93\AZ+?"A:-*29ETD!*].%\M=']6<?KMG
M0<=(&'LN%-MV6KZ&=^QP4(8?"L8P$K)!*LDT&'X1`-1#+]A,..5D5:Q83<,7
M"9`K(7,'`&X+!5!04$]/3TY.3D9&1D)"0C4U-30T-#`P,"\O+R$A(1T='1`0
M$`T-#04%!0,#`____P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'XV[PP````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`(J]#DU
MM#75E!5Y^)2$1"5E@$)M=1;L\A*"O%S<_`+"XE+20*&FEGI[#EE5%1$Q=3DM
M!5T=H%!/<5EG`S.+`:NA,9NIB9D14*C0.K>HM8]ASJP94R;U3YP\%2A4;6Y9
MT]T[=_;,Z9,G]$]BF@84*B\IK>S2LW)T<O9P=W5S<`$*-;8W%]CZ^0>&A$=&
MA(4&!P&%.FKS[3QCXI+3L[(S4E.2$H!"57DV4=&QB6D!.9F^/MY>\=B\`P";
M[S(G7SH6^@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N
M82YP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T
M,3<S-C,P,30`,#(Q-C<R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____S`@,T1`4X2$DT"LRWC(X\DQ1_U]D^71Y[H"#_HB/
MJ7>"PI2>KGZ*JI&EDWJ0C8>A,"^!.SI^9F6K``!>``!;`0$\!05D"0EE#0UF
M$A)H&!AP'Q]U)R=[.#B(.#B%04&/04&+2$B8.SQ\5U>A7EZJ7EZG7%V?9&2I
M:FJP`01C7%V7<'&M*RU;*RU-=7>@&!YU24^8#A=O%1]T$Q8Q1TZ*<GFT?'^=
M%1@P14V*4EN814^0:7&B@X>:*"LWB=&49[MQ-YQ!5;1?5JQ?:<1R5K-=&V<;
M(G(C(6\A+Y0O)G<F*'DH-9\V*WXL*GLJ+H(N+8`M,(4P,(0P-(LT,XDS-HTV
M0J=".I(Z1J=&0IQ"2JI*0IA"3;!.1J!&2:1)1IY&3Z]/4+!03*=,3JI.4:]1
M4*Q04:Q14*I0,H<Q-HTU/Y<^/Y4^J-6FG,.7BZ)ZGK.,MLBDGZB/?85JS]:^
M5V$H>8-,E:$QQM-BP:*6VZ.<T5U4[Z6?\:NET#XTWE%)S$Y'\FIAX8Z(S@H%
MVQT7S!\8TBXG[CHTSUE4VY21S```S0$!S`4%S`@%S0D)U`H*U@T-V!`0Y"$A
MU"`?Z"8FZRLK]3HZ^#X^^D)"_$9&_T]/_E!0S%A8V6AHPXR+____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````7_%&2`````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#!241!5`C78V#``L1-]56T5.5E)$0EK'D;9\X&"EF6EEFH*<I*
MBAD;-+7/F,4)%+(OK[!3EI/2MN*KGSJ=HS8/**177*0C)&TB6-TR91IWB6,.
M4$A85T/!T(RG;N(D]II<MY@0H)"(NI*-0$/S!!:N0M>,A+`@H)"FD>V\UNY^
MMBJ'V/3XB$P_H)`Y?T=O%_/<`N?HU.3LT$!OH%!G6T\7:Z6+;V122E1(@(\G
M4&AR'].<?">O\,2TN*Q@?P]W;-X!`,]],@=G%!O<`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VYC+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`R,P`Q,#0Q-S,V,S`Q-``P,C$V-S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____2-3;.%!G;
M)BN>(27H.C_6/T/R2D_G3%'R458F#7\U'8E',)E:0JAH4;-B3:AK5;(<#%<_
M,W@J'&\;&I8?'GX``(X&!H<$!%4$!%0+"XL,#(D6%I41$FL;&W(G)Z(X.*XZ
M.K(Z.YQ,3+\[.XE65L1>7L%N;LX!!%8$"8P.$Y0>(Z$Q-;!$2+Y15<-05<8`
M<P`#<`,)>`D->`T8@1@=AAT?AQ\;:ALA=2$B=",H?R@OE"\J?BHNB"XXG#@T
MD30PAS!"J4)&JT9"HD)&HT90ME!/LT].L4Y0L%`VD#4B@@5@LS5MEDIUG5%Q
MEE!%9R9-<"U4>#-AA3YOE4PA,1!?AR]YICH@,05ME0"'IR&MOA+8WR;,T`72
MU@WCYT#R]E?-S0#&Q@!(2`#,S`/(R`.WMP,]/0$W-P&YN0I45`7.S@V_P`UF
M9@G>WAC3TR"DI!O8V"=T=!A+2Q+?WCB%A2?HZ%![>R_]_62UM4C__FB@H%Z^
MOG2^OGMU=5^DI)UA7@#;UA1'1`?5M!#=OQWWTU[]U6KHJBO(A`KHETC,@4GB
M)R'K-2_O-36[+"S(,##1-#3',C'O/C[W0D+3.SKZ1D;C0D+&.SOG1D;X3DW\
M3T_H2DG\4%#T3D[V4%#T4E'W9&3V9F7___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#1XB9G`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*Q)1$%4&%=MB[L.`4$4
M0.?>>>RN2A")1.VC_(%$H9#X#"4?H/<[LGJBLEZSLWOGX8J24YZ<(\0/($:@
ME4[M,_,2)2*62G1?9AJCW%(?&$Q<]6#FP5N]J[^J0O%8189N2^>:EES-U>9:
M#J)S-,DQSZ!I%R@Z*1$UDB>CD>9)*)%4CTA#(8W1WJ\#JWVFBS&FX\6"20RK
MR@[C(>A[+='Z&"(K%T]G1+[0F_"I_O`&IN]4_=2N3N8`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M;F8N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P
M-#$W,S8S,#$T`#`R,3<P-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___Y?-F*C9J0!U``!)``%V`0-W`P-V`P5X!05W!0EZ
M"0U_#0U[#0I4"A!^$!)^$A2%%!.`$QB&&!B$&!%=$1V*'1^('Q^'("&+(1EE
M&1MK&R:0)B>,)RN7*R)V(R%S(2%N(2^8+R9[)BA]*#6A-2N"+"I_*BZ'+BV$
M+3"),"IX*CJC.C.-,SB:.#B9.#2/-#"$,#:1-C2*-#ZC/D*L0CJ6.C*!,D:O
M1D*@0CJ+.SZ2/CN+.T:D1DVS34JL2DBG2$FH24^T3U"U4$RL3$ZO3DFC25&T
M45&S45"Q4%"O4$:81E"M4%"L4%NY6UFU65>R5UZW7EFK662\9&2[9&6Y96B^
M:&J_:G>[=W6N=8+`@G^W?X>]AXO"BXF^B9W4G:+6HI3#E(BQB*C:J*31I)2U
ME):VEIZ^GIBWF)JYFJS(K+[9OL[HSJJ^JM7MU=/JT];MUL#/P,3,Q.[W[O/Y
M\_'T\<O-R]/4TR"$'S"3+S*+,4&@0#^;/C^6/DR<2V:Y98:SA8&N?X.P@8NS
MB9^\GK?$MK_+OM36T_KZ^OGY^?;V]O+R\N[N[NKJZNCHZ.?GY^'AX=[>WMC8
MV-;6UM34U-#0T,_/S\[.SLW-S<S,S/___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/L/[Q@````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````OTE$050(UV-@P`)86:6L\KHFM+7.G!HIJ6KA#!(2-0_-Z9_2
MU#A]<K22J9,G4(A/.R@D>U)9A77YQ%@3.P]'H)"B=YAOUK1<-J'"/B9[=Y<:
MH)!->(!^R\PD3OZX[@0O5TL#H%!]8+5$VLQF'K&HCF1?6R,MH%"P@RQOZHPZ
M83E_1F8WLRHUH)!/I0!'1I&@C(Y?<4JMKJ8R4$A/A(LELSTF(KZD--%80T4!
M*"3.S<*>/J$GOZ"SM\%075X:FW<`2!XP(RY#,0D`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N;"YP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P,S$`,3`T,3<S-C,P,30`,#(Q-S`T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____BPX/U=35
MQ\;'R,G-QL?+]O?[Y>;JV-G=R,G,O;[!^/G\Z>KMY^CKU=;9T]37(428`#.J
M`C>K!3BN!3>K"SZM#D.U$$.V&$>S(5+#(5&W'$"0(U"P)5&P*56U)$J;,6//
M*$VC-632*U*F+E6M,ENU-F&_-%RX,EJQ.&/$1'3<1G3>0FO)1W+/4'[B4'SA
M3GC947W=/U^D37/$1VBO68+:3G"Y6GW);I3E!#JL'E+`-V&Z1G',:)#D:(W;
M:X_:S<_3Q\G-^?O^\O3WU-75Y^?FX,C'S```?P``S@,#T`4%S`4%S`@(S0D)
MU@T-V!`0U!$1SA04TA@8E!$1X1T=WA\?Y"$AU!\?G1D9[B\OV"TMZS(R\C4U
MX3@XLB\N^D)"NS(R^$1$_$9&YT%!QCL[_T]/_E!0^5!0_U-3[D]/[$Y.^U=7
M]E=7^EY>Z5Y>]V5E_VIJ_6EIS:ZNS*ZNT;.SV[V]S[.SZ,O+W<+"IY.3]=G9
M_N/C_>/C\MG9\=G9U+^__^CH^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJ
MY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,RLK*____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````)XM]D@````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"R241!5!C3;<&]<0(Q
M$`;0;W].$G,W0$0#)"Z"P"G=$)+8D8<>Z`0B)P0X<",D#!YN\)VT6A=@W@/^
M(:PQ[[IRZX<B30Q!]PRTJ;7'F`MK(R($QK&=LCU&#S'&-`D,Q390C9TY$PL1
M?8&@M@NB,*NEN&JS8;Q_?!X$M;K9F\BV`:%C[FGE9U_Y*7"FGO!Z__EU3HLA
MY3!XK=^*R[48:RZ3D>[9[`K&S>J++&,2MAEY;?'$'Y==2@&P9"!A`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VYO+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q
M,#0Q-S,V,S`Q-``P,C$W,34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____1L;/BPL3PT=.[HJ3&K*[3N+KWV=SGR\[ER<ST
MU]KVW-\!)&*+EJJFL,('*VD0-'$2-&X=0'PG2'Y!7Y)7=*25H+(%+VF(F*Z'
ME:B6I;J@K\,`,&D*-V\..W$V68,^8(FLN\X927XJ584_9I%*<Y]9@[!FC;=N
MDKE@>YF"G+B&G;8G68TZ:ITX7XA,>ZQ/>*-9A;-<?I]BAZEQE;9DA*%HAZ5O
MCJN"I<1UDJR1LM&%H[YTC:67M]62L<Z8LLFGPMNJPMFSRM^7MM#-@WWQQL+.
MO+O-/#C,6%7.6U?,8%OUDY#&>'7^H)W4BHCWI:+,``!_``#-`0'.`P/0!07,
M!07-"0G4"@K6#0W8$!"+"@K/$A+>&!C2&!B4$1'A'1WD(2'4(!^=&1FG&QOK
M*RNP(2'N+R^R(R.\*"CR-36_*BK'+BZY+"OU.CK*,#"R*BK=-C7,-3+A.#C5
M-C72-#3X/C[$,S+Z0D*[,C+/.3G\1D;E0D+J1D;_34W@143N24G_3T_^4%#^
M45#V3D[[45'Y4%#22$7R4U+]6%?Q5U;I65GH:6;R<&[18V'Z?7K;<G#H@H"G
M8%_@BXGRFYG]HZ']I:/_JJG>QL;___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````K\LVI`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+])1$%4"-=C8,`"@H*2?9W%^-O#`D.C$K.JFT!"\94!3J+B
M'H$AD0GI%8UM0*'H@NYI#B)\1<$1L:EE=:T-0*%)_M/==(2D7/LF3/3QFSIE
M,E#(UM%%6U%"P=C$U-+:SM[&"BBDJ:&F(B\KIZRK9V"D;JBJ#Q3BX6)RU^*5
MG,',PL'-R<[&"A3J*HSQ-A.0[LEK[NRHKRK/!0H5QX5YF@O*]%8WM=24YF2F
M`862P@.]+(25^AO;:DORLS-2L'D'`.T),0QW7"!O`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;G`N<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,S4W`#$P-#$W,S8S,#$T`#`R,3<R,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```&`4$Q410```/___\<*"^HZ
M/,DS-,<Z.^E.4M$F,?_K[+(P.]U>:*0!$Z``$[(N0%\`$:T8,G0",:@]:+%.
M>IE#:I5(=54;0)Y6BUT+2FLU8(E">VXJ9TX)25H559I>E]O:VT8$24<.5$(/
M6(5CJ&50>TDK<7UAI5]"D(I]O3,O?[JXWUQ:HUE8E#\_<5M;B3T]2",L?='*
MR=A+1-,0"^%`/,T_.^RAGL^;F=VXM\T!`'\``-$'!\T)"<P,"=L4%)01$>$@
M'M0@'\PA'^@F)M8F(]$E),XJ)^XO+XL?'>PU->`V-J<K*=0V-?I"0KLR,MD]
M//E&1N%!0.I&1OY/3_Y04/E04/%<6;!$0_5>7N!85OUE9/AE9?1E9?%G9OIK
M:^IF9M%K:]>#@^B2DM>(B-.3DLR4E,RFILVMK?W9V=#!P<S(R/'Q\<_/S\S,
MS/___P``````````````````````````````````````````````````````
M`````````````````,^-3J<```!N=%).4___________________________
M____________________________________________________________
M__________________________________________________________\`
MH`4\,P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```".241!
M5`C78V#``BSY1)4U<Q$`)&3G&\TEK((LY!Z6F&YJR,(MH*`!$_)*YLB2,W.T
ML+)E%U2""+'&QD3PBLM+RTA)BLFJ:ND"A:+"`UR8>!3UD<R*C$M*2S$QXE=#
M"(6:9^?D&/@Y,0NIPX2,XU,S,Q(\/?R#V42T(4(.UC:NSO9N/D$A@=Z<$CIZ
MV+P#`%*`+5K5'@Q6`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;G(N<&YG````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0S`#$P-#$W,S8S,#$T`#`R,3<Q
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_P@EC@HGC@XLDQDTEALXGAXVB2$YC!<G7BU)K"4Y?C9.IT!<O$1<KC]4G3]2
ME%)JOU=PR$M@J59MP%YTP&!UO6V"T`TIA!`KAQ$MAQ$MAA,NA`P<4A0OA14O
MA18PAA@SBQ@RB!@RAAHUCAPXCALUB!TWC"`ZCQ\XBB,]DB5`EBA"FBM$F!TN
M9BI"D"])G"M#C31-GS!'E#!(E#90I"@Z=CI4J28W;CU6ISA/FBY`?3!#@$%:
MJS-&AC=+CC9)B%!KQT9?KT)9HSI.CSA+BDQEN$ICM#Y3ES9(@CU1D4%6F49<
MHT-7FT]GMDA>ID59G%1KN3]1BU=OO$UBIUEROUAOO%!FK%MSPE1JLU9LM5%F
MJT=:E55KL$E;EUYUP5IQN%MQN%ENM%AMLF!VP6!WP5-GIV%WP5!CGUYSNF%W
MOV!VO5)CFV9ZO6R!PW"$R&9YMG*&QW.&Q'B+RF]]I9ZFN\O,S)V=<JJJ@JZN
MBG!O0G5T1W-R1GY]47]^58R+8964;XN*:)R;=ZNJA(>&:+"OB;R[FJ.2'Z64
M(;FI.J^@.LBX3*N>1]7&7L.U6,F[7MS-:=K-=::5)JZ<*[6G3M?(:=O.>___
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$#>
M^X8````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````O$E$050(
MUV-@P`)D92UBBG/]]95EE+2,G,+204)Z045YX29J,@H:!K:!*=E`(4[/@L)D
M*TTY>75=2S_1K"2@$+>PN`@/*S,3"QL7KZ.0(!]0J*6MLJ&NIJJZMKZ\HK6Y
MJ1$H-&UB7]>D]H[)G=V]$Z;V3^D!"N5'\G-(2JGHF+M%Q$?Y>-@#A1+32G,D
M%+5-W4-3$T*\7>R`0LX992720!<%IV=&^WHY6`.%C-GC#%5!+A*+#1!PM3'#
MYAT`,X$NNE0T!LD`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]N>BYP;F<`````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(P-#<`,3`T,3<S-C,P,30`,#(Q-S,Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____M&UPOG2(PHVFG&F'V\+77DA;FWR7
MIXZDMZ:V@U>&GW"CDG66S+?0AUR79EMJ?667M:C"C'&J;5*/=%B?S+_A>%ZH
M9$N;;EBGLJG)<F*D9E>A?W*YF(O2=6^1/S&33T*A3D*@5DJAA'G,B7_.F9#0
M/3*5;V:T/C::44FM1D"+<6C%?'7->W3*,"J7-2Z8-2Z7-2^:-B^9.#&<-S"9
M-S"8.3*;.3*9.S2=/3:?/3:</#6:/3>=03JB1#VD1T"H0SR>24.K2$*B3TFN
M5$VR3DBE6%&V/SJ#5$ZJ7%6X7%:Y85J]85N^3$>33DF695_"7%:O95_!4DV;
M44R95$^=:F/$7%>L6E2D6%.B9%ZU<FO+7EFI<VW,8UZP=&[-=6_-=F_->'+/
M;FG`<&J_;6B[?'71<FW#<VW"?7;1;6>W?7?1=W+(=6_#?GC1?'?/?';->G3'
MBX;5B8/0<&Z--3&<.#2@.#.:/#>D/CJF1T.L1T..:&3'6E:G;6C(=G+1>732
M>G71=7+,@G_2.#6C14.C4U&B;V[166"WZXASZ(Y[]()MP6U?[XEXXZ.8][*F
MT&14JUU1ZH1UDEM2N8!WO$I!@30MTW!FM$,]=$1"Q8%^____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````\YF]-0````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```#`241!5`C78V#``M@%2GK$^*0ZR@U-%"4#$K.!
M0C,G3^GM[YO%I&Y4(<H<WU``%)HVL:N[<\+4&0HM55XZ::JY0"%Y+K9)0IPB
MUF42XC7U*BP:0"$..;7I,JV\W)7\/.W9>K(Q0*'BYE1E3?U2)2W?V$S=E/!(
MH%!1AJ>M@;&5DW==8WYZ7$0P4*@PT-',P-+!/2PI+R>K-M0/*!3E;&%H;N\:
ME)#=),S:YJ\-%'*S,32U<_&)SM1-EA8,J?;`YAT`$ZLPG5;=VLT`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V]M+G!N9P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#0Q-S,V,S`Q-``P,C$W
M,3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M___5-3;H/#WA04*G45+_B(E!H",Z?"-1JC)"ABI6K3=)D#!0F39FNTE?JD1K
MN5`^?25EK4AOOU)PNE(V<AU&ARM.D3)4FC=FMD1QO5$^B!-!BQ=,D!]4F"A)
M?2A1AB]FJ#Q9CS5EG4!UM$QTKDYZMU-!=PGKX^+&.#'$"`#$"0'&#07)$@K.
M%0W5(!CB,RNZ,BSO13[20#KW5$WF4$GS6%',``#+`@'.`P/,`P/0!07,!07-
M"0G6#0W.#0W8$!#/$A+2&!C-&1CA'1W,&QO2'!SD(2'4(!_1'Q_4("#8)R?/
M)R?N+R_;*RO=,"_R-37*,##A.#C2-#3=.3E_(2'Z0D+G04#\1D;E0D+J1D;L
M2$C_3T_^4%#V3D[Y4%#U4%#Q4%#L4%#'0T-_+"SV5U?@4E'^7U_Z7E[]9&3R
M8&#]965_,S/Z967X966=04'_:FK_<G*+04'49&242TOWAH;QA(3&;F[]CX^[
M;V^R<&_IH:'8Q<7,P\/>U=74R\OV[>W.QL;-Q<7_]_?X\/#GW]_[]/3NY^?^
M_O[\_/SZ^OKY^?GR\O+N[N[DY.3AX>'8V-C6UM;4U-32TM+0T-#.SL[-S<W,
MS,S___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"$
M8`0$`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+9)1$%4
M&--ES[M-0T$0!="[=V87"R0[=T*(!'VX"@C(+43H!JB``(D.<$XM9(@4B<1^
MO_7;W1D*\.G@`&<"MK_KQ;Q:J:)5L^8[(E]?6HTBL.9N.X%BF8(,4ZVQ^?[>
M7RH"XM/K\W<^68J?#Q?J]5WP&&_?UMUDACO8//1?Q%4^;J9"T924]<.@*%T_
ME)X,)-UN?J#(_5B.;:`(W=Q&*`Y=:3S\J<3FYF90C*60Y#+,3.Y%\_D'_Z(X
M771-%"4>`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O<&$N<&YG````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#0V`#$P-#$W,S8S,#$T`#`R,3<P,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___\&YO=')S?W]_N7EYO+T^62`K>;K
M\[&\S<7.VYZDK;V_PO7W^@HT;Q1`>B5.@V2&LI^OQ=/;YL#&SN_R]N?J[@$O
M:0,S;`4U;@<W<`TX;P\\<1(_=!A"="%-A2=/@2E0@2]:D3!9B4)KG$AMG$YQ
MFVF+LW&0M9ZRR]S@Y0`Q:@,S:P4U;0DX;@T]=1!`>`\\<!A%>!U,@A]+?2U5
M@S->D#AACT]XIU!WH[["QNWO\<K,SMW>W[[!P[[%R<'"PK*SLY.4E,W-S-K9
MV,B_OJ\+!;83#;@6$*X4#Z\5$:\9%+X>&,$C'<4G(<PQ*\<P*]`U+],Z-=I$
M/MU(0M5&0=],1KM"/^)23=1.2>-53^)64.!74=Y54.%74\U13>1@7-U=6=!_
M?;R!?\.=G.W/SM"[NJH"`*P%`[(,"KD4%+(8%L@I)KLN*]8].K@T-,5!/N!-
M2M=/3.%44=NFI<FIJ;JEI<N_O\J^OM#%Q>[BXNC=W=/)R?WR\OCM[?CO[^WF
MYOW\_,3#P_[^_OO[^_GY^?CX^/;V]NKJZN'AX=C8V-34U,_/S\[.SLS,S+R\
MO+FYN;*RLK"PL*>GIYV=G8N+BW]_?____P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````()>00X````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````OTE$050(UV-@P`*F39MBQ]+>6>F=[N;A%Q06
M#1)RXM849NTN]\QP]PT,B8H%"DV=R,DNU-5;X97IXQ\<$1,)%)K<S<$ETM-7
MGIV5DU=87%0`%.+AM;:UL;)GR@T(C4M(C`\'"FFHJYG*&<HH,E?5U=97U[@"
MA015%:3%Q?D$M-H86QI<G!V`0I;*LCK:4OQF8LV-J4FE31.`0N9&NMJ2!O(J
MHLWM)?G)_9.`0B9ZVA+ZQDH6;*T=:2EECI.Q>0<`9_<P=D51LKP`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P92YP;F<`````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T,3<S-C,P,30`,#(Q
M-S`P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____RPT.TAP?V3(ST#4VQ#H[\F)D^F=H^'5V_&YT_W5ZS)R?U:VOS,G*VM;8
MR\G+[NWN_/W^^OO\RLO,?X>-R,W.W^3DZN[NT-34WN'A]??WV=O;R,K*^/GY
M:9F%RM#-?;"+7J!ICLB7D\29M^V\O.*^4)=0H=FAWM_><I!NJ;JEJKRDT-C-
MBZIX]_CU=X17D91][>WLH9!HHHIXHVI+YN3CL9.'Q)^:P$]`KY.1R```Q@``
M?@``?0``R0,#QP,#Q@,#QP0$QP4%R@<'R`D)R0T-T0\/B0H*RA(2S1@8D!$1
MX"$ATB`?SR`@FAD9I!L;TR<GK"$AZ2\OKR,CI"$AMB8FV#`ON"@H[C4UNRHJ
MOBPLPRXNP"TMQS`PKBHJR3(QQC`PWC@XW3@XSC0TRS,S\SX^]4)"U3HZN#(R
M^49&U#L[XD%`W#\^VS\^X4)"^4I*PSL[^DU-Y49&ZDE)Z$A(^D]/_%!0^E!0
M[DQ,Z$I*W$9&\4Y.^%%1]U%1]5!0]%!0[E!0[5!0T$9&\5=7Y513]5Y>]6!?
MY5E9^F1D^&1D]65E\V5ET5A7_&MK^VIJX65D[F]OS*"@TZBHW+&QXKZ^\]#0
M^??W\>_OT,[.S\[.R<C(^_O[]O;V____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M)/M">`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!
M5`C78V#``FSM_`O[IDG-FBW+E^T3F54.%++SSNQIGRHI("`RLSHXO:P>*.01
MW]%5Q2NFHZW`WYI65%<"%`IMYFABL5"4UU+192^HK<P%"K'UMR0SFRB)&NAI
M<%74Y*<`A;K;<OR8S-5-+8U5N1N*61.!0IVE@6Y./,J&5FKZG"49"=%`H<9P
M3T>'23*:1D+3)^:EQH8!A9*\G&U<)HL+R@G/F)`2$Q$$%/)UM;9WGR(Q=XZT
M66]<5$@`-N\``$JQ,9DBWA,,`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W!F+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`U,``Q,#0Q-S,V,S`Q-``P,C$W,#$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____&5E?(6UW/:6KCHZ7JK+"WE9?#
M>HF79XEV27N'9YJ2=Z.*?[ED6Z&4C,EY=*.BGM.DI*6^P.>$C-&>HKMU@\JV
MP.OT]?BBK\_W^?O9V]S.T=+O]/7V_?W&S,SEZ^O8WM[*S\_Z___X_?WS^/C3
MV-C(S,S`Q,2NLK+W^_OJ[N[H[.SEZ>G+S\^VN;GO\O+N\?&)BXO/T='Z^_OY
M^OKX^?G0T='/T-#;X-_8W=SQ\O'<W=S5UM7&Q\;X^??-S<G+R\G)R<C+P+;(
MN[3/A&#";DK*O+>\:4[FKIR_GI/@Q;S!43+3=V&_EHS$02V_D(GCGYK*@X''
M@H#4CHO#CHS=HJ#AIZ7\O[SSN+;(``#'``!]``!\``#)`P/+!07(!07("0G1
M#0W3$!#.&!C;'1W@(2'1(!^:&1FD&QOJ+R^O(R/M-36[*BK',##=.#C1-C7X
M0D+X1D;#.SOE1D;]3T_[4%#U4%#R5U=\,3'[:FK)5E;06UN01$3<:6CI>GKU
MBHKB@8"X:&CZDY/UDI'UFYK&?W[SGI[-C(NL>GFXA(/.EY:^EY?[^OKZ^?GV
M]?7U]/3$P\/Z^OKU]?7Q\?'N[N[M[>WJZNKHZ.CEY>7BXN+AX>'=W=W3T]/0
MT-#.SL[)R<F^OK[___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!I`_N?`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"8F(SBJLJ\E,2HN.3TW**
MRH!"E;5-[:V-+,Q,U35U]0W-+4`A(TU=%1TU%[\`9T4%564M;:"0D+G)-&EW
M-Q]_5V]94[.I-D"AB;W6<V2\/-A[?#VE)DV9/1\H-&'R+`L'`2Y.'@Y!B?Z9
M\^R`0GTSYBYP%.7CYN47MI]NZ[00*&1HI22O;BPI)B(N9V"IIZ$/%`KK"&X+
M"@ED98N(#.\.[>H$"J4G1L4EI685EI:7%.3E9F=B\PX`]?HR\:^;_9<`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&@N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,S`#$P-#$W,S8S,#$T`#`R
M,3<P-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___\TC)<U)2LNJK;$-(+X@,<TR0[DT0:\S0+DX1MI%5<U(5N!28=M280D%
M:A81=B<BA3HVE3@UA4M'HT9#E551J5).HP``:@$!;`$!:P$!:@,#;`,#:04%
M;@4%;`<'<0D);@H*<@T-=0T-<1`0>!(2=!04?1@8?A@8>!T=@B$AAA\??28F
MC!D96BLKCB<G@2\ODC4UESHZG#@XD#X^GD)"HD9&I#\_DT%!EDI*J3H[@TU-
MJ4]/JDE)GDQ,HTA(FE!0JE%1JU%1J5!0IU=7J5Y>KFIJMV5EK)B8SU148PT.
M2$5&@Q<;>9"2O'=YB=C:XX&(GL[.N?'QW-W=T<W-Q\_/R[*RL']_?M+2T>'>
MN?_[TMC.BOSXW>OAH<:^DO?OO]3.I]/-J*:CD>?/5OKA9/_J@/;B>\RUB=2^
MLLP``,X#`]`%!=$'!]0*"M8-#=@0$,P1$=L4%-X8&.$='>0A(>@F)J<;&^LK
M*[`A(>XO+[(C([DF)KPH*/(U-;\J*L0M+<$L+,<N+O4Z.LHP,,TR,=4V-=(T
M-,\S,_@^/OI"0MHZ.N`_/OQ&1N5"0OY*2NI&1O]-3>Y)2?]/3_Y04/),3/U1
M4?9.3OM14?E04,Q65LN`?_'Q\>'AX=+2THN+B____P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%`+TV0````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````M$E$
M0508TVW!L4T#01`%T#^S,[,GVUA"0B(S!5`$(<)].*,'6J$&(F=(CI'L'K!$
M2&)\>WL[<R[`O`=<(:SI^V81OW_GP;)EG7T*EOVJQ:F4051-+('QW`G5OE0V
M53&K2+A3)OTIGLW4LM>CH&6=[+'M>B)FBH"`ILBG^W<G$J:("0*/.'_$J^IM
ME^M0VYO@:<LO#TW2W-2KCPT"6K<]2^IF2F4<W<'XVAPHB2Y,A^(>@7]<`#FD
M25H"+9D?`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]P:RYP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-#8`,3`T,3<S-C,P,30`,#(Q-S$S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````______[_Q\;'\O'SU-;6NL&^S=?2
MS-;0/'9-,VX^Q=3(0')(1'A,3XI7:)9O5GM::H%LAZ.*%5,:)6`I5(A83790
MCYZ0=Z%YIKJG"DD,)F4G(E(C*UTL28!*AZ*(`$(``#X``#L``4,!`3L!!4@%
M!44%!4(%!3\%!TH'"4D)"4$)"TL+#5`-#4@-#DH.#44-$%,0$%(0$E`2%%(4
M%$\4%E86&%@9&%48%T\7'5T=&$T8'5P=(6(A'UP?(6$A&T@;)V(G(5`A+VXO
M+VTO)E<F+V@O*%DH-7,U*ELJ-7$U+5TM,&,P+EXN.'`X-&@T,&`P-FHV,6`Q
M0H!"0G]"07I!1H)&07A!0GA"1GM&3XI/3HA.3XE/27])3(-,4(E048I14(A0
M3X5/4(502'=(4(1037]-48-16(U85(=45XM758A57HM>:I-J98QE9HAF:HQJ
M:(EH;HYN>IAZDK"2C:F-@IN"HL"BH;NAL,JPK\>OY^_GV^';Q,;$U-74,F4Q
M,&$O-F8U/W0^1WU&Y^?FW=W<^/?W_?W]^OKZ]O;V\?'Q[.SLZ>GIX>'AV-C8
MU-34TM+2S\_/S<W-S,S,N[N[LK*RIZ>GG9V=E)24BXN+?W]_____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````OK*OP@````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``F;-FEZ6F^5GH::@:F3O
M$18/$IHQI2HGW$[+4D?7QB4X*A$H-'-J3V6*HUZ0H+YY:&9T0BQ0:%H_4T6#
ML92XB(FT$$=&7!-0B)FQL]1:G8O-S-Z#3R([PA\HU-;14JRMR,/*Z18<DQP9
MZ`,4:N_N*U)1%JYE%TU+E^.MEP4*=;5.+%32-,UCJ2XOD1?P=@4*]4Z8G*]A
M:.O%SUTC*>;K[@04JILTN<#`RCDD*;6Y,<!3Q@&;=P!!`#%!916*JP````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!L+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R-0`Q,#0Q-S,V,S`Q-``P
M,C$W,3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____'P<+__O_&Q\?@X-_-S<S,``#-`0',`0'.`P/,`P/0!07,!071!P?-
M"0G4"@K6#0W.#0W8$!#/$A+;%!3>&!C2&!CA'1WD(2'4(!_,'A[.("#H)B:G
M&QOK*RO8)R?-)26P(2'N+R_6*BJR(R.Y)B;=,"^\*"CR-36_*BK$+2W!+"S'
M+B[U.CK*,##-,C'A.#C5-C72-#3/,S/X/C[A.3GZ0D+:.CK@/S[4.CK\1D;E
M0D+^2DKJ1D;_34WN24GL2$C_3T_^4%#R3$SN2TO]45'V3D[[45'Y4%#Q4%#*
M1T;534WZ75WG65C]9&3J75W_:6CY:&CZ='3X>WO8T='0R<G,Q<7RZ^ODW=W2
MS,S_^?G^^/C\]O;V\/#EW]_AV]O2S<W=W-S^_O[]_?W\_/S[^_OZ^OKY^?GX
M^/CW]_?V]O;U]?7R\O+Q\?'N[N[L[.SKZ^OIZ>GHZ.CGY^?DY.3AX>'>WM[;
MV]O8V-C6UM;4U-32TM+1T='0T-#/S\_.SL[-S<W,S,R[N[NRLK*GIZ>=G9V4
ME)2+BXM_?W____\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!&.8BH`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*Y)
M1$%4&--MP3M*!$$0!N"_:[NZ9\;'PA[-S%A4\!!&)H8F!J)X-#.7!4$9Q.FI
M1Y<'T.\#_DBXA]_ZS5$I,+76^DL&NE_YR(QN+O)\#4+XIXS,*=15GBXK"+X\
M3'.A.W-3N:B/2*#S#8DC(@<')7K-.&OZL9<T[+9#3MT"&3J_S4L,HC&-K34#
M0=^_UUZX;H=JJZD@8_^U&G,^/BFIB;B!<&BR89Y.:UE^S-WPCU]2_U[R:=1"
M;P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O<&TN<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#4P`#$P-#$W,S8S,#$T`#`R,3<Q,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___YM[?))^?^+0TMJXO9J+D"XY
MECE`BE16:[R]QXV5TFIUMX*,S#)%GC5(HS=)GS='D5%EPCM)BUQKL%MGHB8Z
ME2<[E2H^E"D\CRU`DSE/K4-5ID=:K$98JE1FM%UON&=YRFQ^SE]NKCI#:G*$
MRW2%R&Y\MV]\LS9&A#A(A3M)?T]AIT%->TM7@$A4>6!IA8J5MEID?9*8HVQT
M@9B>I8F.DYR>GV1N<:Z]O96:FM78V-+5U=35U82-A[B\N3Q40$]A4EAP68B:
MB6UR;6AL:,O-RWN-=)B;E6EN869L6I^BF'^"=:&ECZ.FDF)E3V9I4ZNNE*&C
MD'AZ8H:(<X^1?8""8IV??X:':8V.=[*R@*ZNE)220:.A78&`2XF'49>69J*A
M=;BWAZBC/:^I1(%]-Y",2;>T;+>S;K"M;;NX@<&R`JV?"+FM%=3&(^[?+^G:
M-<*V+LB_._GM4.[A3N794.+63XZ',]#&3(%[+\.Z2.G>6=W358N%-JND1N+9
M8<&X4Z6?2:2>3HF%3<&\>,_`)96*(.?7-;6I+??G/JRA,J^D-L6Z1I*)-,W"
M4S@O&:Q]&(M_9,*5.+%<!:E9"K=L(;11`,9=-=QV5KLY&:XC$+$G$:2-BKBD
MH^70SZPB(,V[N[VVMO___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````!"0?HX````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`(<7)R8N-7D^24DI01D
MA115@4*.=LZLO`H&GIKZ,2;*OH9*0*'^.1/=>>3T4OT%PV+53;TU@$+,"^=9
MZO`%Y-0:-35XM&2(`(7,;=VX9+2R<X/S"ORJ2\P2@$+6-O;&XMIM<2GY-='%
MZ:(10"&6!7/9=,4JTZHZZY/*(AOC@4(SIL^<S^F57!0>%6@5ZM/A"A2:-&'R
M+':+UO;2K*#$NL)F8:#0U"G39G-(AU1D]O5T=_66JV#S#@"WTC+QV/7R9```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P<BYP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T,3<S-C,P,30`
M,#(Q-S$U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____N!05RC4VLV5FGQ8GL'>"APPJ1Q$MR+;`4"A)FGV6:D!V73]]4SI]
M-BM[GIG**R9:54^5>7.T=G&P>72OCXK&EY/&2$./1$!UAH'#<W"C>WBAY>3R
M1$"+6E>@CHO"V-?J5%*<145^75ZF&AU43U*9EYO&J*_#\??]X.#?SZRGS8%[
MS)..RY.0U)R9QP<`>`0!Q`T(RSDU\4Y)\U=3ZU10Q5E6SE]<\YZ;]*.@S8B&
MUY22Y*.A\;*PU)Z<X*FGK82#[;BVN(^-Q)F7^,7#X;2R^\K(\L/!RJ:ESZNJ
MV;:U\M+1WL'`^]W<\-/2O@``Q0,#PP8#P0<#P@4%OP4%R0T-R1`-RQ`0S!@4
MQA@8U!T=U"$=UR$AV"@DEQD9GAT;XB\OXC(OJ28CY34UM2PJYCPXP3,PP#`P
MUC@X[T5"[D)"R#HW\$9&O3L[X$E&WT9&VTA%]%)/\T]/\U!0[E!0[E)0ZU=7
MQ%-1QE53]6IJV6QJS6AGYWU[\XV+X(2"^):5\I63O8F(QY*1^;R[Z+"O];NZ
MSZ*AYL/#_-S<_O[^_?W]^_O[^/CX]?7U\O+R[N[N[.SLZ^OKZ.CHWM[>V]O;
MV-C8U-34T='1S\_/SL[.S<W-S,S,Q,3$N;FY____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````H/&#NP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!
M241!5`C78V#``C@,X_.JRC.C0@-"(F)3<DN`0JI<+%:6]37F%946U;5U#8U`
M(4%E=<V)TV;-F3U]RJ1>QIX)0"%):2D%3FU/3R_O#I]./W]?H)",K+@\'VN0
M461<FHFI66$.4$A`452"GSTP+#HQN[BT@#D#*"0F(B3'K6-M8VO7TM9JW]P$
M%!)64M.8,V/JY+ZN[GZMF7/G`854>-ET]?0=G%S=/=S:79P=@4(\3`;!X3%)
M645E^<;IJ<D)V+P#`(6D,?<&J6\]`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W!T+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`S-0`Q,#0Q-S,V,S`Q-``P,C$W,C(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____0-3;*9&7`76B2JYLZ>3L`
M6@``5P``.0``.``#7`,%704)7PD-:0T*0PH8:A@12Q$?<!\95!DA7"$J9BHX
M@S@R;S([>#M(CTA0F%!&A$9>I%Y>H%Y9EUEDIV1JKVIEI65JJ6H39!(P?"]F
MIF4)905GJ61NK6@Z?R=;H$AXK5<V=0-KGD!5<`)/8!&;JE-^@B9[?@UV=R=Q
M<4%85AV(AU?#H1FTFCR2:#_.;1W6=2?'8Q?%7!"T2025/@>Y20?#31*>3BG?
M5BO(,PVB.R2_4CR;9EJJH)[$%`'(&P>](A3A*B''``#)`0'(`P/+!07(!07*
M"0G."@K0#0W3$!#6%!38&!C/&!C<'1W@(2'3'Q^D&QOB)B;E*RNL(2'M+R_J
M+R_I+R^O(R.V)B:X*"CN-37M-37L-36[*BJ^+"S#+B[`+2W',##O.CK),C'&
M,##@.#C1-C7.-#3+,S/T/C[S/C[W0D+U0D+5.CKX1D;W1D;</S[;/S[A0D+Y
M2DKF1D;Z34WE1D;J24G[3T_Z3T_[4%#Z4%#N3$SQ3D[X45'W45'U4%#T4%#V
M45&K7%NM9&3___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#2H-\+`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+9)1$%4&--MC+T-PC`01L_VV<XE1("(
M*$"P`"/0L@X+4-,R#A(-"[`(/Z)``AQBGQ.2&E[Y]'T/X`<!).@Y&2_/%2NM
M\U%O(T%8G')]\RP1DV%F`$&C-=1<M4:E"S(E2-`FI7[?OEF9`5&L6H56)2>S
MDD_,\J1QW2H/LMH=#R+:06JJ;6R59Q;[IG%4$+ER[=M\R+RZ+ATN4O(^Q$[Q
MG7G^F$VZD/OXT!XY!G4QQ9!T^?)U'>$/7WB"1QIOPN=:`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<'DN<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,W`#$P-#$W,S8S,#$T
M`#`R,3<S,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___X@;',6WN:.>GYR3EK64H,VWO["+F:J:H+^?K,O)RK^UO,&ROKNL
MO>CEZS<VF4Q*L%54Q&!>OP``A`4%B`4%A@<'APD)B0\/BQ`0DA,3DA@8D"$A
MGR,CGR4EEQ\?>"$A?2@HD2HJDB@HB"<G@C4UL#4UKBXNEBXND2XNC#0TFS@X
MI34UECP]I$9'O3L[GTA(O$)"JU!0P4Y.NDM+LE55P$)"CE%1JDI*F%%1HEY>
ML6UNRVQLPG)RRV]OPO?W^O7U^,_/TL3$Q\+"Q>;FZ.3DYM+2U,7%Q[JZO,7&
MR?+S]??Z^O'T]._R\LG,S/O]_?K\_.'CX]W?W\[0T,/%Q6^J;&B>8EVB37Z<
M=_S]^^3DXM+2T,C(QO?W]O;V]?7U].?GYM+2T<K*R=O6U<<``'P``,@#`\L%
M!<@%!<@)"=`-#=,0$,X8&)`1$=P='>`A(<\?'\HB(9H9&<HB(LXF)<HH*.DO
M+^TU-=@R,MTX./5"0K@R,OA&1N)!0>5%1-,_/\,[._I/3_I04/104*X\//-6
M5O)75_5>7OID9.I?7^A>7O-E9?=H:/MJ:N5L;/AX>-;+R]C1T<O%Q?GS\_CR
M\N_IZ>[HZ.WGY^+<W/KU]=#,S/KZ^O___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````!N_780````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MN$E$0508TVW!L4T#01`%T/]G9\=GK^Y`LFSG9(24X`8LT0150$1`$Q1``XB,
MP#DYN6-+QA><?+<[2P'P'O`'\8"V:R]]GW-0;:(]"=#,TS@,)4L(LQ`)P>MF
MJ4'BHNVZZZLN&12RKB[-<]"7ICCE"XK[]V*<;">/6X\Y"A3)"V=OF67<?4;A
M!&(;,VG[;+Q+HY`?"C]_+ZO='.36SUZK0W$\V0]C6,T'^L6G`D%?J*:+=`AT
M(2O^\0M):CXGC?'3?`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]Q82YP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$R,C,`,3`T,3<S-C,P,30`,#(Q-C<V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```8!03%1%````____8P4J8PDL:0TQ9`XO91`Q
M<Q@\;A@Z;ADZ;!P[=B!!@2Y.C#57ET)CD$%@BT-?ATMBB%!EBE)HDUMQC5EM
MDF-UH72%J'J,MY&@Z-O@7P`G80$I7P$G7@$G8@,J8P4L8@4L90<N:`HQ:PTS
M;A`W<10Z:A4W=!@^>!U">!U#?"%'7!LV@"9+?R9*A"M08R$\B2]49B,^:R9"
M;2A$C359;RI&>S!.=BY+="U*<2Q(D3I>>#!.>C)/?C12?C13?#-1E3YA@#54
ME#YA@#94F$)FA#I8FT9IBC]=CD)AGDILGDIMDD9EH$UOEDEIH4]QHE!RFDQL
MH5%RGU!PG$YNH%%ROY*DM9^HM*&IMZ:MJY"<P*FSNJ6NOJRTV<G0Z]OB__[_
MQ\;'U-75QL?'U-74Y^?FW=W<^/?W_?W]^OKZ]_?W]O;V\?'Q[.SLZ>GIX>'A
MV-C8U-34TM+2S\_/SL[.S<W-S,S,N[N[LK*RIZ>GG9V=E)24BXN+?W]_____
M````I`\]30````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"L
M241!5!C3;<RQ#<(P$(7AL^_."<$%2H?H:+((P[`$.S`*'1(ST#$`$A(2M""(
M8_ML'%'"7W[2>P`_*=B`W&-_<'//;)IVLB.`)-4^=T=/1&96(VC(TJ=5.BW4
M5T(A&1XD,6:#;!O.OM!M.T65\Q6YMJS=NY!9^Z?04O,X<T,JI&C:YGQ!;FL3
M?!B)!M0ZZLY6'+V/0R&T"(+J;(UVO0M2Z(60#*$J1T%2BO"G#R.G2%H#[B+#
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]R;RYP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,#,`,3`T,3<S-C,P,30`,#(Q-S$R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____`"5_`R>!`R>`
M#3"%'T"0.%:B.E224&VT9'_#98#``"=]`!A.!2Q_"2Z!"B-9$C:&&#R*$2IA
M'T*.&3)J)TF3(3IS,%&9*D1]06"F.U602&BL4&^R5W:X7GR]672Q9('":(3$
M9H&_:H;%$#)U$#%T%#5X%SAX'#U_)D6".%F?,DV&/%F21F*=5&^E:8.V=8V^
MS;(`S+(`S+0`S+4`S;,!S+(!SK8#SK<#S+0#S+,%T;<'P:H'S;,)PJL)U+P*
MU+T*UKP-SK<-PJL-V+\0QJ\.V\04WL48S;<7TKH8X<<=Q;`9Y,TAY,XAU+\?
MZ,\FUL`DZ](K[M@O[MDOSKHM\MDUX<TX^.,^^N)"_.5&_NI*_^A/_NI0W<M&
M^>50[=M<T+4%]=PZSZT%U;,-W;P8Y\8F\=$U^MM"Z<Y&_N!-]=E._.!1S"L0
MU3<=WT4KZ5,ZRTLU\5]&VUA"Z&),\&A1]&9/GB8;IBPAJ2XCKS(FLC,HY4,U
MM34JNCDMMS<LO3HNPCXQP#PPR$$TQ3\SRD(V[E%"ST<Z\%5&U4D^U4L^VD]"
MWU)&\UM-XU9)\UU/\UY0ZUM.YUE,\E]1\%]1[EU0URTAXCLOP#HPR#XT[$D^
M\E5*XU-)\UM0[EI0____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````S7I5^@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"<241!5!C3;8R[#L(P#`!M
M)W5"!8@%\0U=Z*_QRRQ(#`RH%7G;I#/<>#H=P`\(!_#+-(?EG:_C]-C[&P'P
MQ:C$-5I$'-T`!(97U;`FXQ&-&U)7[DPJ(13F7K'4KNRG2HMYWCDDDK15OE25
M9.^]LEBR@@5I51MY=K8/2I6N:BV*#OTID;Y:VU['W`0-<R354VU;]>R&/)G^
M%FVB\(<O!V92)YD@/],`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W)U
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T,0`Q,#0Q
M-S,V,S`Q-``P,C$W,C(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___^L#1BL$!JQ%!ZR'BC),CRB+S?!.D.M-S[714^W/47&
M25'B55[85U_B7&786F*\("O;XNJ\Q<Y\@HBBJ*[J\OH@;K,N=+(Q;:(X=:M4
MFME/C\E8F]>UO\BTOL?'T-C4W>7BZ_,`6J0%7Z@)6J$)6J`0:;$09JP28J@5
M8:08:ZX;:ZTA>+XN@<0R?\(G8)`T>K0X@\`V?KA&E]E%C]!"BL4[>:Q`@+=&
MBL)0G=Q.F-52G]U0D<I7G=9,B;IJK.%II]UNKN/9X>CG[_;8W^7K\O@`7J<#
M8*D%7J4)8ZD)8:<-:;(,8J<==[X=<K8?<[0OA\PUB<PP=Z\W@;Q"E]E"DM)!
MC<A&D<Q/H-]0G=I3FM-8HMU7G-->I=UFJ=ZWP<G#S-/&Q\?,``#(``#)`P/0
M!07,!07("0G1#0W8$!#2&!C<'1WD(2'2(!^D&QNP(2'J+R^O(R.\*"CR-36[
M*BK'+B[',##A.#C2-#31-C7V0D+\1D;E0D+F1D;^4%#[3T_V3D[U4%#^_O[\
M_/SZ^OKY^?GW]_?V]O;R\O+N[N[GY^?DY.3AX>'8V-C6UM;4U-32TM+0T-#.
MSL[-S<W,S,R[N[N=G9V4E)1_?W____\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````>[B43`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+I)1$%4&--MP4U*`@$8!N#W^\D)8B`BH19)!!.M,O)27L*=X+9M
MJX[2`8($H3;"!!&V<Y-:XWP_'4"?!]A!>$2\/$T.5.$6WN:(@<QJ+"((S["1
M@'!*=^2]?,YU2;2Z?5T*KB]PKK.BN[K_[6-P)%^*@NRMZ;V3U%7=^6A;*&ZR
M:;9>*8M4%/.KJ>)S;B>6NCSK+/BR_5Z`</SGD5RN53@C(QK%\,=,5(I#83-W
M?V!LW%E8"Q7WR$SL\0\BY%9)M@IE-P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O<V$N<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#0W`#$P-#$W,S8S,#$T`#`R,3<P-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___X.MA`!T``!S
M``!)``!(``%Q`0-V`P-T`P5X!05V!09X!@9V!@=U!PEX"0IX"@MW"PU_#0U]
M#0UZ#0]]#PI3"A""$!)]$A-[$Q1Z%!B&&!B!&!%;$1V+'1I]&AV)'1R$'"&0
M(1^''QMK&QED&22')26()2>+)RN4*R)U(R%R(2^;+R%M(2^:+R9Z)BZ2+BA[
M*#6@-2N!+"I^*BV#+2Z%+B^'+S"(,"IW*C"',#2.-#.+,SB8.#B7.#2--#:/
M-CZC/CZA/D*J0CJ4.C*`,D"B0$:N1D*>0D.?0SJ*.T"50#N*.T:B1DFG24BE
M2$:A1DVO34FF25"T4$^R3TVM34RJ3%"P4$^N3U&Q45"O4$ZJ3E&O44:71E"L
M4%2Q5$^D4$R>3$^C3U>Q5U>P5UVV75^W7UZV7E^T7UFH64Z33F2[9%^P7V"P
M8&6X96J^:FB[:%NC6U><5U275&BW:'2_=&FL:7K">FNF:V:>9G2R=&^J;V^H
M;VB=:(7(A8;(AFZB;FVA;8C(B'"D<(&[@7:G=HC`B'FE>8&M@:#4H*S/K+/7
MLS"1+S*),3:/-4&>0#^:/C^8/ENW6F:X96VU;*;#I?___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(P(`PX````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(UV-@P`)8V52]
M\I/M9+B9N<25C-R#@4)LLJYY:9[JDH*\P@IZSB'A0"$QR\SRKHKBVH:BPI:,
MP$@_H)!N;,&4J:U9[4S55=UU,6$3@$(^^2F)'8V5S35E;9WUT1[60*')Z?UJ
M\H)2HG).$9/B?1TL@$+9_AHB[.P"TIJ.H3%!+KW&0*&X'@E./G/OA)S2IMR)
M-J;Z0"%;&6X6'D4#MYC4DB1[,T-MH)`R/S.'D)R.<TA40)^5B98*-N\``-F@
M+<N\X.43`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S
M8BYP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T
M,3<S-C,P,30`,#(Q-S`P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____)T./4EENP,GA`2>%$#22"B!6'T&5*D!Y4&VY<H2R
MAI&M`RR&`RN$"3"#$CB*&3%G*4N8.E>:.E6/2&BP)SA=2&:I3FFC5W2U1%N,
M<HS&8G>E4F*'?)/&BJ#0?9&]I;+.N,7B!"R`!BY]"S)_##%\#C2`$C>"&S^)
M*TR0'S)9.%F=)3MG1&6F2&:E6G>T8X"]9X7!:86_;8G!9'NHH;/9'C]Z/5N-
M3&:.-5%Q0%9D4V5?;GYH,'X-;K)018\A290F7Z8^9Z=)8*4Z9JQ"<K-/;*I,
M1HX=.FP;0'0A7J(U38,L4HHP5Y`T69(V9J%"<K-*:J5&=+1-=K5/=;51=[51
M<J].<Z]./X<00W8C6IXO1WPF27XH2X`J3X4M48<N5(PQ4XDP5HXS69(U6)`T
M:ZU"7I<Z;[!&8YT^8YP^:Z5&;JE)=[50<:Q,=[11=K)07Y\K@+E&@X]V2X4#
MC[]19YD4B;,OK,M*;7A)?)H%N,Y0FZ\8OLHU>'XWH*8`V=Q-D)`]L[-@L:X'
MJZ@[RL,=IIX@S+P`S;T!S+T%UL4-V,D0LJ44U,8?Z-@FZ-PZ^NU"W=`\QK,`
MS+D#S;H)T\$;Y-`AQ;4BZ]HK^.8^_.M&_NY0^NE/SK@%U+T*____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````,-LK/P````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#!241!5`C78V#``IC%!$7D6?0U557XV2R:9LT&"FGK2LF9*&BI
MJ_`)V$Z<,*<:*,3.J:@DSJ2AS&K5,F-F0ZDS4$C65-I`0H97K7)J7W]%J'LF
M4(C'3%)'F-NZK7M:;9%]>(`?4,C84(_#O&YN5VNYJUM!D+\O4,A(5,BFIV->
M3:%3<'Y.>J(/4(C+LG%R>W.9HTM@6%Y6<GP,4*AX>N>DJD@'[XS<B(#4A%@O
MH%#OE/H2.X_HM)""[)2DN"A/;-X!`,DQ,?590(Y``````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W-D+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#0Q-S,V,S`Q-``P,C$W,#<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____6/D#,P\8Y
M-CG3T=,B(R/W^OKQ]/3?XN+3UM;.T='Z_/SAX^/.T-#BX^/L\.^:KYXF<"D`
M0``#.P,)8@D%*@4-:0T.8PX*1PH2;1(8;1@8;!@?=B`?9Q\)'0DG>R<A8"$I
M;RDJ;2HXC#@XB#@[?3M(E4A0G5!&B490FU!7HE=>IUYDK&1HKVAJL&J%HX4D
M*"2AL:%Q<G'P\?#(R<@P@R]!CT!:FUEFJV5IDF,?1A$B*@`V-C5'1T9:6EF\
MNK6T@62203)L!P#'``#(`P/+!07(!07("0G0#0W3$!#.&!C#&!C%&1G<'1W@
M(2'/'Q^=&1G+(2'&(R/I+R_5+B[M-37=.#CU0D+X1D;B04'#.SOZ3T_[4%#U
M4%#P4U/R5U?X7E[W86'G6UOH7%SW967T963[:FK+P\/&OK[BVMK5S<WX\?'O
MZ.CMYN;;U=7\_/SW]_?V]O;R\O+KZ^OGY^?EY>7>WM[6UM;2TM+1T='$Q,2Z
MNKIQ<7%G9V=A86%04%!/3T].3DY&1D9"0D(_/S\^/CXU-34T-#0P,#`O+R\N
M+BXJ*BHH*"@A(2$='1T;&QL0$!`-#0T%!04#`P/___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!\%BT6`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`";)P#
MH],3PKW=7=R\_,,B8X%"PM9.J8E1`1XNKIY^(1$Q<4`A264+QV2F8!_?H-"H
M^*2T%*"0HJ:>EI4#<V9&=E9N3DY>/E!(35];55I(D(^+4X"=AX.7&RADJ6,N
M*RIA4%%>4EA05%II"A3255<05S)BK>`W*2PNJZJN`0IIF$F)&+*T-=;7&M?9
M-]FU`H549,08)D_L:V]N:&KIZ.[M`PK)R3-,F=3?U=+8T&S;V<,V`9MW`!@%
M,!WIX]A)`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M<V4N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P
M-#$W,S8S,#$T`#`R,3<Q,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___P,;O!(LNR8ZJC!'RBU"M#I1XS]5SDICZTQCX5%I
MZU!FX&1E:S-)OP`BKP`CKP$CL0,DL0HLM@H@>!@ZP"9'S"M,SBI!G3Y>W$9E
MXCI2LTUKY$]LY5!KVF1\Z&5]XP`7:P$EK`0GK@4IL`4HKP8IK0<KM`@KJ`DL
MI@HLK@XQMA$TN1$RJ!8YO!DZM1(I?Q@WHAY`PB)$QB!`N"`_KR`^J!HQB"=)
MR1PTD2$ZFB,]G#!2T"(YDBA#I357U"I$IR]*KSM<V#%,LC51NCE7QC93O$-C
MW3Y=S#-+ID=GX$!<QD-?RTQKXDEFU4=DT%!OXTQIUE%OXU%PXU%OXDYLVTUK
MV%)QXE%NWD);M$=AOEERTVF#YQ4UF5=QQVV%U7B/W(&%B*FLK6]S<YZBHI*6
MEGA[>Y27EY.6EH.&AIZAH7=Y<G%P4-:X#>'$'=2Z(.[3+\JT,-6]-OK@0N?.
M0.K21O_E3_G@4/KB7OCB9<VM"KVN:,[`@,>C#\6A#\FD$,&>$L6B%,JH%<2D
M'\VL(L:G(ZZ4)-:V+L*G,+&8+<^R-LVR.[FB/=B]2=[#3YJ(.Z>41>[39,BR
M5*"02*Z>5Z:97[*D9\J[>+BJ;Z"48<>Y?,J]@M;)DO___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````=R)/T````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````OTE$050(UV-@P`(4%<VE$R9.,E554M$QMO<*!@D9>"K$]_7H
M"BAK&]FX!T0`A40DHN7CNCHU!(5%Q25E0OR`0K91,7*1K6V:ZGH63K[A8=Y`
MH9ES9D^;T-C0/WE*]?2:63.F`H4J*TKRJ^KJ<_,*BLO*2XL*@4))&6F\.;7-
MV8FI62GIF6G)0"$>5F:FV*8.,79.;BX./C86H)"KOAJ_84NWAU10J(^+HYT5
M4,A$2TG(K+TW4#;"W\W9P=H2FW<`XBLP^)*X4R$`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S9RYP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-#(`,3`T,3<S-C,P,30`,#(Q-S`V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____P<+"LK.S
MU-74X.#?W=W<U=74S<W,OR$`P2(!OR(!P2,#PR4%P28%P2@)QRH*R2T-PBL-
MS#`0T3@8QS<8U3P=V$$AWTHKXDXOYE,UUU0X[%P^Z%H^[V!"\61&UE<^]&E-
MY&1)]&M/]6U0[VM0\6U1[6]6[7!7?W5S__#MP!\`OR$#Q"4'PB@*Q2P/PBT0
MQ"P2SC(4SC@;R#D=R3H?W$(FVD<KSD8MES(ACC`@Z58ZJD$NV%0^RU,\\V5*
MZ&5,\VI0\FM1W6)*]7)9U693PEU,WVU9^(EU]Y&`?4U%T8^$S+NX[W]MZX-S
M\8EYZ(9XMVM@^92&Y(V`^[.I?U]:IHB$U,7#U<?%RKV[^>KHPWMR]9^4SKRZ
MUL3"^.7CX=#.YM;4[M[<^NKHBX!_S;NZZMO:]^CG_O[^_?W]_/S\^_O[^OKZ
M^?GY^/CX]O;V]?7U\O+R\?'Q[N[N[.SLZ^OKZNKJZ.CHY>7EY.3DX>'AWM[>
MV]O;VMK:V-C8UM;6U-34TM+2T='1T-#0S\_/SL[.S<W-S,S,RLK*Q\?'Q,3$
MO[^_O+R\N;FYL+"PIZ>G____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````Z,7O2P````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"[241!5!C3;<L]#D%!
M%(;A,^?,F>$FB$(B"@FU0F\=]B`VH*!24DBN0F\S-D&B$8F$ZS=QSPS7J'G+
M)]\'\)."[B-I'K<W29TVFIC7!)FJIF76!T?\%3PA=!#E?MEXI0F)Z`4:KJ6,
M'VDM0]9A]MX"PCGODB1#;7AO>$?UL&H\"U%Q7U:(K56[>56!L!)9;(B3=-[/
M14L)QWQL$+SW3GHFMN-IH-R0@KQ$P-@1HPHT87A[+V[!=F9QH.!/']A'0C15
MFE5^`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W-I+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q
M,#0Q-S,V,S`Q-``P,C$W,3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___^+BIVAH;1<7G6EI[W2T]PJ,5%K<I)S?)OJ[/.<
MI+QE>*9WB;%C9V\>.W``)F8%*VH%*VD*+F<0-G05-VXA1H(A1'LU6),S58LT
M4H-&::%!8))"89,R2G`[58%!78E0<:=.;:%5=*9/;)I0;9M"57-JA;!D;GX*
M+F82-FX?1'LN3X`R378X5'\^78E&9YI8=Z9:>*.EM]$`+FL#,&X)-7$-.G<=
M280O6I0P4X$V68E":Z,X6(0Y681&:IQ/=JM0=:A#8HQ*:91>@+!FAK)LBK)J
M@Z9[E[YYD[>`F\".F:BOO<_J\/;GY^:Z&@JW&PV^'@^['A"X'1"X(A7'*1K`
M)QG","+,-BG3.BO"-RN8+22C,BBO.B_:2#NC-2SA3#ZZ0C:O/3/33D'%2#VZ
M1#K$2C_L75#G6D[75DK96U#O9EGG8U;L95KG95NG0S[;9%ZD'1BE'QJI)!ZJ
M+2BT,"O"03R<.S>[2$/05$^Q247`55'29%_;:F719V)\>'B(A(3^_O[\_/S[
M^_OZ^OKY^?GX^/CV]O;R\O+N[N[KZ^ODY.3AX>'>WM[8V-C6UM;4U-32TM+0
MT-#.SL[-S<W,S,Q_?W____\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!<36[;`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+9)1$%4&--MC3L.`5$40._OS4@0C4JCD-!9@]8*;$4C$HNP
M!"O0BX8%:&P`(9A$?,*\>Z_I.>4IS@'X`6$Z;+06HQ`$-*I^?$QP?#^7^5H8
M3,WB6(``M=NQ'J,71D<3`8&9X2;,H]_J69WZ*RM:S:M9PH9,Q`GFNA=H^[96
M-B1$%K3H>X:054ZR2PZW]`+G*[Y/`H-/-"="?E7=_5':".SNN9)(FDJFN48O
MCB\U80JE@%$1*<(?OHR+5R*B#G..`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<VLN<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#0W`#$P-#$W,S8S,#$T`#`R,3<Q-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\H#!+P/
M$LX2$[<F)^$P,L(M+LTS-/`\/O%,3?Q14O!04=5/4,=-3\I45<QB9,0-%,AT
M=\RTM;`:(_;"Q=.^O^72T_GFYYL/'9PC,[5)6)XJ/(DJ/XI)8ZEZD(]>>'M5
M=TPS6U]3=E%$;6I<AWAKDWINE(A]H&]DB%Y5>F]EBTU%:%1,;T`W8D5";$%+
M>SY2@86&B`HS<C5;E#15A$9LHCM7@4YQHU=YJVJ)M?;X^^[P\^'CYM36V0$N
M;3!4@SA?DS9:BT)MI4%GG"Y);$9LGD)DE$]XK4QRHU!WJE!UJ%R`KUZ"L6*$
MLF:'M"%/BB=4B2]BGDYOF5Q^J51QEG67P//U]^;HZLC,SZNMKN'DY<;'Q_?R
M\<QB7\P``,X#`]`%!<P%!<T)"=8-#<P0$-(8&-@;&N$='=0@']`D(<TA(:<;
M&[`A(>XO+[(C([PH*/(U-=LP,+\J*L<N+M(U,LHP,.$X.-4V-=(T-/I"0MT^
M//Q&1MX_/^5"0OQ*2NI&1O]/3_Y04/9.3OE04.M14,Q)1\R_O_[^_OS\_/KZ
M^OGY^?;V]O+R\N[N[N3DY.'AX=C8V-;6UM+2TM#0T,[.SLS,S+N[NYV=G924
ME']_?____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!RX]DT````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(UV-@P`)F
MS9H1P]@S8?*T:5,F]O=V=H"$9DZ/E1`7$VZ?.FE"7Q=C-U#(*"I:M)67/Y4O
MTL[6QCH\`BCD&AHF7RT@E"T5Z.CIXQ<2#!0RM[)4*&V+RY(),#'SMG`W!0KY
M^[HH,TO*"LH%.7MXN3DY`(4T-%64].R-#115U=2UM71U@$(\12Q,(OJ&TISU
MW%RU'.RL0*'RM*3XQ'2VPIJFYKK*DH)<H%!F<GQ"2D9>56-+0T59<7X.-N\`
M`.&N,5K$\W''`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]S;"YP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#``
M,3`T,3<S-C,P,30`,#(Q-S$Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____U=35Q\;'R<K-^_S^^?K\ZNOMU-77RLO-R<K,
MOK_!Q\G+]_G[\_7WYNCJV=O=S]'3`%F=!5VA!5R>#6>I$&>J&&FG'W&M(7:W
M&UJ()W"G(5^/*7&G+76L*&B:-8?&+G&D,'6H.(*[-'FN.8"W-GFM1I;20HF_
M3Y[84)S63I?/2I#$0G>>4(Z\2H"H7:#248BR79;";*S=:Z?3<:_=`%R?`UZ@
M"6&A'76U(F23+X;$*FV=-GZQ0I711I#%4)S3;JG4Z.KKUMC9U-75HJ2AVMW8
M;J!!?[1/?K%0B+=>C;EE.'4`(TD`.W<#/WD)1(`-2H`72G\7-5P14XT=48<?
M4H<?/V894H4B9)TO7Y,M:Z(U=:Q";Z(_9I4Z6($R8XP[6GXX@+%1@ZY9C;M@
MA*];CKMCC+)HFL)T.W8`)4H`0'L%/WD%2H003H086I(A.5H8:9HX>[!&@[50
MA;-7E<!JQ<C"^?OW[.[JS]'-RLS'R<O&Q<?"^/KU]_GT[O#KX>/>UMC3U-;1
M[.WIY^?F^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8
MUM;6TM+2T-#0SL[.S<W-S,S,RLK*____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````IU%20````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"Y241!5!C3;<$]3@)1%`;0[_Z\&=`1H4`+HXEA"VY`W8T)
MG14E#:%P-ZZ#QFAI#,1&I##1:-[,_9X+T'.`/P0WV/7')8*AJN_'<N?85,WV
M+08Y5#W9D\`Q^:A.VS:;)K>D9P6.QPLVS)*]QT+)*PB,R\H<$>RZXIZFBODB
MWQO($C$SNTT`JJM>O_'1\'"0#NKKO7T(+G<_W[2Z=M/"0CXXUI]!L;:M3:(+
M!AQ?YY3GB=KVJ/#UA"_XQR\T9$U]F9V9U0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-O+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`S-@`Q,#0Q-S,V,S`Q-``P,C$W,C$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____-TM<G
M;:LJ;JLM<*PN<*LO<:PQ=;(P<JTP<:PR=*\S=*XT=*TU=*TX=Z\Z>[4G47<]
M?K@]>K%#A+XN67]"?K1)B,%-C,5(@[@Z9Y$W8HA.B+Q6E,Q/B+Q+@K-`;YE#
M<IQ:F-!7E,H_:I))>:1@G]=>G--+>Z=?G--7C\%-?JI/@*QEHMA1@JY=E,97
MB[E3A+%HI=Q>E<99C;M8B[EHI-IKI]UOJ^)>DL!NJM]OJM]FG,QCE\59A[!:
MA[!UKN)NI-1MHM)KH,]VK^-WK^)SJMMQI]=WK^%VK-YVK=YVK-UFE+YTJ-=Z
MKMQGDKE[KMQYJ-*)NN:&M>"+N^=TFKR5P>F3N]^&I\6=O]Z8KL*MPM6SR-NY
MSN$G;:HK;ZL<1FLR<ZPS=*TY?;DW>+%(BL1#?K)/D,E(@[='@+)'=Z%6C\!2
MA;%(=9Q6B;94A[-1?J5FG,MRK>%QK.!FG,ISKN)JH,]UK^)VL.-FF,1WL.)V
MK^!WK^!TJ==[LN*`L^"`M."&N.1_H+R)J,.WT^O"R,WAX>'6UM;___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!`K(S)````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+=)1$%4"-=C8,`"
M$A*D[4("C,42V;B%)#2MJT!"H@7!#3892?&<`N)*YA5>0"'!W,!&)QF>3'D.
M$5DSAQI'H)"*3Y"O5EI<4W.RLFZ1A[LM4,@^Q$]?S#^JE2DFO-C5K=``*!1<
M;R/)RQ+:WA9I5.Y=9I(#%&ITDN-G9XZ(CFVQJ':TS-<&"M5F"W.QIE2FJX75
MN=OFZ60!A2`N2E6W*G4K,=5350`*9?"Q@5WDXNEL8JBA*(7-.P#,H"E;_`J4
M(P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O<W(N<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C(V
M`#$P-#$W,S8S,#$T`#`R,3<S,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````"0````X(`P``
M`,I*QIH```,`4$Q410``________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________W,^E=H````"=%).4_\`Y;<P2@````%B2T=$_Z4'
M\L4````)<$A9<P```$@```!(`$;):SX````A241!5!A78V0``D8X`28A+`0-
M8C(AV*0")+T(D]%L`Q,`!9``$W>_+[X`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O<WDN<&YG````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q-C4U`#$P-#$W,S8S,#$T`#`R,3<T,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%@``
M``T(`P```)I[;E$```,`4$Q410````#_`$)"0H3_A(S_C*7_I:W_K;W_O<;_
MQL[.<\[.SL[_SM;6UM;_UMX``-[>WN?_Y^\``.__[_<``/?&QO?W]_?_]_\`
M`/_.SO______________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________V8724`````)<$A9<P```$@```!(`$;)
M:SX```!3241!5!C38Q#$`OB8&,2Q`&$&$H4EP(`3A1)A8)`$`@%>%@XQ$,7,
M*P3B2T*$)5D9.4`4&R,[F"L*5<TM!%(MQ`&$4-4\7#S\/"#`#Z>YN!AH"0!Z
MI`Z>`OUO#`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O=&,N<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#0U`#$P-#$W,S8S,#$T`#`R,3<P-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___[Q25-9V=]9[?;"!@NJL
MK9Q15-US=]9X?'`H+:<]0\)B9ZY=8MI]@I\S.\:AI+B0E;:%C65`1V=%3*5Y
M@\JMMI-B<XU7:IMYB(UC=L*?K\VQP6%78;"HMWMUAK>RRXN'KC<Y;%!4@!$=
M6BXZ<C,]<W)]J51:=``36`X?7FMXJ`<=8"$W>C)#?$UAH5YOHPHB9`TE91(H
M910K;A8M:Q@O<!TU=2$W=2]&ABD\=2Y!="T_<C1'?S!#=C1'?#5(?3]2B$=<
MET)5C%%EH$=8AU5IH$%/>5-EEDU<AEYME@`:7``;7``:6P$<70$:7`,<7@,=
M7@4?8`4?7P<A8@@C9`DD90DB80HD9@TG9Q`J:A(K:!0N;ADR<A@P;!TV=2$Z
M>1\W<1LM6B8_?2<]=RM$@B(U9"$S82]'AB](AB8Y:"@[:S))A35-BC!&?2H]
M;2L^;SI2CC!#=3Y6DCA.A#9*?4)9E4):E49>F49>F$IAFT9;D#U/?$A=DD59
MC$E>DU!GGT]EGD]FGDYDFE%GGE!EG%!FG$UBEE!EF61WJ59NFXR%8:^HAJF9
M5;ZK9NC)9>#$:XJ#;.Z_6<RN9\:O?KJG?.JY7LJ;78I86-RAH/___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#G-4QL````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````ODE$050(UV-@P`)$9#5X%:3%NG1\
M@Z(2<BL;@$+",UCYV&8*B6L%1)IGE#6U`86XV%DXF)FX^54B8G.<W%KJ@4+R
M`C*<<H)2:F$F#I,G3/%P!`J)*JKS*%M)2ICJNDZ;--73'BBD;5"G9*P9JFIA
MV=X_O:_&#BC469MBY.]G:)9:K-_3VZU7`!3JR(L.]`F)22ZL<O&:Z&Z3!10J
MB0OV!KFHHJ'9V=8Z.QTHE!CN$Q@9GUG>V%I=6I2?EH3-.P"513#TS(.&!```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T9RYP;F<`
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C4`,3`T,3<S-C,P
M,30`,#(Q-S$P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____S`<+SQ88BQ,4TB,EV"DJW3(SYT5&QSP^X5!2]EM<]E]@^G-T
M['!Q_X2&`&T``&L``V\#!7@%!6\%"7$)#7\-#7@-$'D0&'\8'8@='84='X$?
M(8@A&V8;(G`C+Y@O+Y4O-9PU*GDJ-9@U,(4P,((P-HTV0J="0J1"1J9&1J!&
M3[!/1IU&3ZU/4*U04*Q04*I0$7T0(XLA-8LT-HLU2*I&0YM"4:]03ZE.7GHZ
M-U4$;:@,=:X0@KD@DL@RJMQ2J-A3:J,#-E(";*4&HM5%=:8#>:H(=Z@)@[03
M@[`;D<`D<Y8C?:$JH<\XAZLPFL,[C[4WKMM)G\=$M-Y3KM=0H\L=E;H%I<<9
ML]<PE[(OH+PUPN1"J\D^R^Q1OMU-RNE5F[P,L]0JP^(^M=!"SNQ.QN%0S^Q5
MI;<.Q\P(QLP*S-$.RL\9V-TU[?%6S,P(S<T)U-01V]L;WMX?Z.@MZ^LRN;DK
MQ,0R]?5`^/A$S\\YX.!$_OY0__]3[NY/\O)2_?U7^_M7E(LCI8L(P9X(OYT(
MPJ$3S:\MXL9-]-EISJ04?P``?P,#S`<'S0X.?PH*U"(BIR$AE"DIYT1#G2XN
MQD%!^E]?_VMK^&IJU')R]Y>7LGEXNX:%\;*R_]W=_>GIZ>GI____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````"-74^`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"N241!5!C3;<&Q30-!$`70F=E_Z_6)D(R`"I`#5T!&/]A=@`CI@@)(:,"!
MB0F0D)"<64Y`Q][\3P'PGMD?;G=:>FQ6[ST+AD4=7F&E--[FS7.-R;UV-]CV
M$7*VM7L$@'R!W9.:<CJ,WZ-'B.:VK,F>U_M+/YZ',W>P!V923^50VQ?Z3(.=
M)$E7%Z5$B-0;[%.B8CP#H%DI@WW\D!Y1$$Z2,MANZC&@MJ',[92S[!^_4M14
M_##5CND`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W1H+G!N9P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`S-P`Q,#0Q-S,V,S`Q-``P,C$W,30`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\U**=)/+M-0JUF6\9_
M=-Z*@.&'?=QX<+F!>KZGH..&@+:=E]"MI^*OJ>(E%Z0D%Z,M'ZHL'Z0M(*4N
M(:<N(:4N(J4P(Z<P)*@P)*4S)JHZ+;8Z+:\[+[$_,K4[+ZM`-:Y,/\1&.K1+
M/[Y00\-(/;)%/*0^-HY:3LI>4M)52KM=4LQ52[EB5M%63+122:U=4L!93[9L
M8-MD6<MK8-=F6\QN8MEA5\%N8]EQ9MQE6\594*QJ8,IV:]UR9]5P9=)V:]QV
M:]AE7+ES:=)Y;]:`=]R(?N)X<;E]=KZ(@<B7D-9\=ZR5C\R.B<&SK>VVL.W0
MSO+)Q^?9U_G7U?;<VOBHILVEH\AP;X?*R>2AH,>@G\:SLMC!P.6RL=/*R>F4
ME*W.SLG-S<C,S,=_?WSY^?3AX=S6UM&4E)'___OZ^O;N[NKGY^/4U-"[N[CW
M]_1\)!-[(Q/%.1_)/23%/2312"_,3#7=5S^8/BWK:5+;9U+V>6+'8U#(95+!
M8E#Y@6O(9U;0;ESP@V_;>VK0=V:D7E+YDX"N:%OIC'JZ<63&>FS0@W3UFXKE
ME8;ZI)3TH9+^_O[\_/SV]O;R\O+EY>7DY.3AX>'8V-C2TM+0T-#,S,S'Q\>\
MO+RPL+#___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!!MW$9`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+A)1$%4&--MSKT.`5$0AN&9V3E[
M=N.GH1%1*+96:*A<C!MP"V["]2B4"HVH)42$E4BLQ<Z9X_0\Y?LU'\`/A!G:
M.)&7J"(%/&=XL"NOA`5J[(WW`B$E=W'U-WNI\$)8"VG397<J2F<Y3NO6'X"@
MO=+\^1$3&9M:K<J0UI-EL1?#1Y-:U!(A`FK:>^S4M`SC^[%MY`1IYS1\C4>#
M<];;[OI)%GXMB,!KX,.I"''*<!-!)L.$E?JPP1]?'K!-P,)IPML`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=&XN<&YG
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-#$W,S8S
M,#$T`#`R,3<R,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___\S'R,`@`,`A`+\A`'@5`,(C`[\C`\,E!<,F!<$D!<`E!<$H
M"<HM#<(L#80?"LPO$,PP$,0Q$L<U&,8V&(PF$=4\'=A!(<H]'Y4O&9\Q&\U$
M)Z<W(:HZ(^-.+^).+Y\W(;`^)M)++[-`*.93-;9"*KY'+KM&+;A$+,%),*E`
M*L-+,==3.-=4.,M/-<E.-,5,,^Q</LM/-N]@0M!4.K-(,O%D1MQ;0-99/O-G
M2MM<0KY1.[Y2._1I3>!@1M]@1N1D2>)B2/1K3_5M4.AG3.MI3O)M4>]K4/%M
M4>AK4.=J4,M=1NUQ5^QQ5_!W7N!P6?1]9/-\9.]]9>Y]9?:":O'=V<$F",4D
M"<DK#<$J#<(M$-(X'<<X'<D[(-](*\Y#*^93-]=2..]>0MQ:0?%D2>)A2/5J
M3_)H3NAE3/-J4.MG3NYI4/-K4_5O5?5_:/JKGLNTL+\;`<$<`]@Z(<DV'])$
M+^E1.O-F4/!F4<=I6]9\;LMZ;L]_<LI\<..3AOFHG.*?EMZ<D^RPJ-2AFMRH
MH<V>E\VRKOKDX<A^==6,@\J&?<J+A//2SM&VL\NTL>;&P\RWM>O5T]31T?CX
M^-O;V____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````##BI%`````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````OTE$050(UV-@P`+8V*1L0WUU1;A9.84D5,U=0$)B9B'^*:71X<61X@HF
MSAY`(0'M@*"TA+K"]MJ8>",[3T>@D*)/OG=9#5-/W]3Z<BMW5TN@D$VH7U+L
MQ,ZVKL:PC"PW:P.@4+"_15Q4?W=+4W-'7HZ#L190*-!)AK^H:G+KI"D%E8ZF
M.II`(2]E80[FB.H)O0VYF9:&&DI`(3U1'E8NP9+$U(IL:P-U%5F@D"0O"SN?
MN'QRNH>]OI::G#0V[P``H_DMRGH$U]X`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]T;RYP;F<`````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$R,S8`,3`T,3<S-C,P,30`,#(Q-S(S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```8!03%1%````____Q\/$IZ2EX=[?QL?'
MQ@X`Q@\`QA``QA$`QQ$!QQ(!QA$!QA("QQ,#QA,#R14%QA4%RQ<'QQ@)S1D*
MS1H*T!P-T!T-SQT-QAL-TB`0R2$2U204V"<8V"@8S2<8S"88VRP=WC`ASRX?
MHR8;XC4FX34FY3HKJRPAZ#XOKBXCM3(FUSTOMS,H[$,U[$0UNC4JTSTPO3@L
MPSHNP#DM[T@Z[TDZR#XQQ3PPQ3TPSD$TS4$TRC\S\DP^\DT^W$8XT$(UT$(V
M]%%"U4<Z]U5&]E5&VTL^X$]"^%A*Y5-&Y%)&^5M-Z59)Z5=)^5Q/^5U/XE1(
M^5Y0\5M.[5A,[5E,^%]1]%U0]%Y0]E]1[%U0\6A=T6MC?DM']K^ZW<G'^N3B
MQ@T!QA`#R!<-R!H-R28:SRL?TS$GR#$FD",;K3,KW$,XB2THT$E`YU%(N$M#
M?30OY&-;^&QDXVQC]X=_](9^^I&+_)J3_^SKG%A5_M#.]<G'TK:U[-+1\>[N
M?W]_____4Q]*5`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"W241!5`C78V#``NKR*UC+H[+D!3D$I)3T7`*!0C$9>;'Q`:G"''SBBII.
M_N%`H>S,@M(:PV0>+A%9=5OO"%^@$'-T66U<2B*GD(RJF4=HL!M0B*FRBJ5:
MD@UHD+Y+8)"[-5"HI+@H)YV73PQD4)B7HR50J#`W+2F!6U1.W<X[PL?9W`@H
M%*DCS0\T2,W4(S3$S<9$&RADKR#(#G*1*]`@*V-=#:"0,M!%$D"#_,(\'2P,
MM%2P>0<`HJ$E=SYYUW0`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T<"YP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-#0`,3`T,3<S-C,P,30`,#(Q-S(R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____ES<\BW^`
M>FIM1CU!HIZ@K*JK14!#U=35?'I^`#NE`3RF`3NE`SVG!4"I!3^F"4&G"D.M
M#4:O#42L$$JR&%&X&$ZN'56[(5J_'U2T*V+&+V;*-6O-.&K#/G/40G?71GO9
M38#<27C.3X'=4(/=4(#848+:16ZW7(/(*UBEEZG&E*7!F:K&I+70BIBNLL+=
MP='KS=STQ-+IS-STL\'6O;^^]OGWY>CF`'0``'(``W0#!7@%!78%"78)"&<(
M"&8(#7T-$'X0&((8'8H=&'`8(8LA'X0?&VD;(G,C(6XA+YHO*'DH-9PU*GTJ
M+H(N,(8P.)@X-I$W-(HT0JE"-88U1JI&0IM"1J%&1I]'3[%/4*]04*Y03JE.
M/X(_6:Y93I5.5:!5:+IH:+1H;KUNU=C5^OSZ\_7SK:^MZNOJT]33)8$D-HXU
M1XM&6J-9V=O8R<K(TH]?NFL^CHR+0"`4DD0P>F%;B2T:MHN".C4TI%5(LWAM
MJ75K;SXW7UA7KE-.S65@T'-P>1033Q(26AT=VW%P8UI:0ST]E(V-5%!0<V]O
MCXN+M+*RL*^O_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8
MUM;6TM+2T-#0SL[.S,S,RLK*____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````-3C6HP````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"]241!5!C3;<&_2H)A
M%`?@W_GS9J(6!)9#]R!T9:$.+8%#FT,1W4A+EQ"DDTN"+D%+0Z!\H/%][WG/
MZ0+J>8`_").3Z4W]LJ_KK$>JJAO&Z?ZZ\Q#69%$1$0*#/(RX,5(182D@W+(E
M?S8B8A(G7BC:E1X>[\Z\N%FHI@5C>M]]*A0>I8Q$Q@K"+,*K+:>W82ROK/,Z
M%UQ^O*\_!U_U1>#\^"?UEHI=U9BL-+<3-SO[=C`.N7#BU%+*_1+%\8]?WGE2
MVL"6W5H`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W1R+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S,@`Q
M,#0Q-S,V,S`Q-``P,C$W,C$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____0-3;#.COZN[SQ]O;BY^;(``#'``#'`0#&``!]
M``!\``#(`0''`0')`P/(`P/&!`3+!07*!07(!07'!07,!P?("0G'"0G."@K1
M#0W0#0W)#0V("@K3$!#6%!3*%A;9&!C8&!C.&!C-&!B0$1'&&1G<'1W;'1W@
M(2'?(2'0(!_/'Q^:&1FD&QOB)B;()27E*RO()R>L(2'J+R_I+R^O(R.D(2',
M*RNV)B;8,"^X*"CM-37L-36[*BJ^+"S#+B[`+2W',#"N*BKO.CK),C'&,##*
M,C+=.#C1-C7.-#3+,S/S/C[V0D+U0D+5.CJX,C+X1D;W1D;</S[;/S[B04'A
M0D+Y2DKF1D;#.SOZ34WE1D;304'J24G[3T_Z3T_[4%#Z4%#N3$SQ3D[X45'W
M45'U4%#T4%#V45'M4%#H3T_024GR5U?U7E[E65GY9&3*45'05%3T967'4E+S
M967[:FK&5U?U@(#[AX?XB8GH@X/'<'#/>GK=F)C8EI;3HZ/)OK[MZ.C___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!%#T`=`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+-)1$%4"-=C8,`"N'ET(TMS/)1%.(3D-&T"$X!"/*H!);FA
M.N(<`M+JIG[Q:4`A6>>\RJH8&3Y>225#GZC46*"0>39+8UV!(*>8O+Y+>$I2
M,%"(N8*U5D54S5U.RS8H,3G,"RA45,Y6(\%A5*@!-"@]FLD-*)2?5=]0;""I
M"#0H(];?U1XHE&FE4%9M`3$HQ-O1$BCDH2+*)0PSR,':&"BD+<[.+Z5NXAN7
M%N'I9&>FA\T[`*?_*#DB=9A*`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O='0N<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-#$W,S8S,#$T`#`R,3<R,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___T%!0@$"
M`RHL+7-W>8N-CA`3%+&TM4Q351,7&'M_@"HO,%!96XR5EWA]?G=]?E5<73U%
M1F9O<"\R,I*8F$U04#H[.S0U-9V?GVUN;C8V-9.3DJNJJ7%O;L(B`,`A`+\A
M`,(C`\$C`[\C`\8F!<,F!<(E!<`E!<$H"<HM#<DM#<(L#<XQ$,PQ$,0Q$M$W
M&,8V&-4\'=M!(<L]'\U$)]]**^-.+^).+Y\W(;`])M)++^E4-;A$+.E7.L%)
M,,-*,=A4.,E.-.Q</LM/-N]@0O-D1MQ;0-99/O-G2MM<0K]1._1I3>1D2>)B
M2/=M4/1K3^AG3/-L4.MI3O)M4>]K4/%M4>AK4/!W7O1]9/!]9?:":K\?`<<B
M!GT6!,0D!X0="L<K$=<](<@Y(+U"+>]<0JU%,]]?1LM;1OIP6>MM5\UG5,UF
M5:=?4_*.?<^$=\-]<.Z;C>&2A;QZ;WE/2/^PHMR?E,Z5B_B\L8YL9NR[LMZT
MK,$8`,@D"LLP&-0X'^M1.=)-.O-=1MU:1?!E4/I_;-M];\21B>^]M=X[)JDP
M(961D7-Q<65E95Y>7E%144Y.3DU-34I*2DA(2$)"0CX^/C`P,"LK*R<G)QT=
M'1D9&1(2$@T-#04%!0,#`____P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-L=A,,````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)*
M>&:)2\D6U:G+J^H:V[CY`X7B*@5[^YC8LFN4M8TL7`-"@4():=6BDV>PR^74
M&I@Y^X3Y`H4L,UJKA&?/8V9MZ[3S#`GT``IY1V<UMPLQS.7JSFL*"O9R`@I%
M1;@G)Q9PSIDI(EG:DNYB#Q2*]#/5B8DMYYT^=2)'8:.#+5`HW%I?12&^ODQ@
M4K^83'Z*%5#(T5!#44TOJ:&";\(4">[B+J"0B::"DI:1>6IF![_T-):>7&S>
M`0#GKS%C`T*1'`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]T=BYP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``
M,3`T,3<S-C,P,30`,#(Q-S(U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____MWY_Q(F+LIFOH8FBN:B\VL7?74ACEGVBB&J:
MN*G&Q[7;8UEQ?&.EMZS/R+WK;F*T;VF:E(SADHO=9F*41D6V.CNV7VG+7XZX
M9I:]ILSKK<[I<Y^ZE[[6;)^\FLCCDK_8H=#L<*2_>*O&E,CBG,_IIM3LD,7=
M=I^QFLWDI-;MJ=KQCZBT=*.V=:&SC\+6>Z6V=9VME<'3J-GMH,[BK-SQI]?J
MH,[AK=WQ;ZB\;J6Y=:[#<ZS`<*>[<ZF^<*6Y<ZF]<::Z=*J^>:_#<Z>Z?;/'
M>J_#?;+%@+7(>:N^?*_!A+C+B[_3B\#3BK_2B+O.B+O-C\/69XR:DL;9<)>F
M;I6CE\K<FLW@C;O,F\W@HM3FE,'2J=GKKMWOJ]CIK]WNKMOKJ-/B;J>Z<*BZ
M>*_!@;C+@+;(@K/$B;W.A[C(G='CN.+P<:JZB[;#I]CGHM#=K-SJ@:BQ@*6H
MD+>YK]G<LMS?H<C*B[.TBJ^JL-O-JM+%N^37ILW`D+*FO.33EKFGO^;0Q.7$
MQ>C"Q.>_P^6\F[F0J<B=HL"6I,*9P>"PI\.4S>JOT^^PZX5LZ8YXE&19YZV@
MOU`]T650]()LJUQ-WGAF[XIY^+JOPVQ?[(5VNH=_P$P]@3,I<TI*____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_`]Q)@````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```#!241!5`C78V#``CAX16<*\/!+R*?8N_EJ%?8"A>9-F#U]
MQD1F)CTK]T#5_,8RH-#<J?U3^B;/F:1OXZ-1U=QC"A028F.?Q<W")Z:<;J#6
MTJ1D#!1B%1:9)BC.R:7B%Q5KIEY>`A22D9;3E964RLL,-X^+5^AL`PKE%&39
M)N>FIH5$)R1:M%<8`H62(KT<K)T]@[)UZKL4&XJ,@$(QWD[6CA[^$2:6I;4=
ME9IA0*$,5VL[EX!P[9K6ZNZZXM!@;-X!`)O0,=Y=#YV;`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1W+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3(Q,P`Q,#0Q-S,V,S`Q-``P,C$W,C8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```!@%!,5$4```#____"`0/#
M`@3"!@C'"`G/$1/?'1[5-3;)0T;?:&JI!`FI!0NK"Q"V$!6T(B;?8&3JZ.FX
MK;<S$3@K##0Q%#J<CZ`\)$HF#3:LI[&-BI"0A)XT(DI30V=216*"=)0E$SXQ
M)S]>3W)N88!R:WQ&-UQ72FL2!R4>##V!>)!!.%(4"R8;$2\L'DI`.4YM8H0R
M*4@/!R0E&$=94'`U*E5,0VN-AJ,;$D+U]?3,``#-`0',`0'.`P/,`P/0!07,
M!071!P?-"0G4"@K6#0W.#0W8$!#/$A+;%!3>&!C2&!CA'1WD(2'4(!_H)B:G
M&QOK*RO8)R>P(2'N+R^R(R.Y)B;=,"^\*"CR-36_*BK$+2W!+"S'+B[U.CK*
M,##-,C'A.#C5-C72-#3/,S/X/C[Z0D+:.CK@/S[\1D;E0D+^2DKJ1D;_34WN
M24GL2$C_3T_^4%#R3$S]45'V3D[[45'Y4%#Q4%#]9&3___\`````````````
M``````````````````#=2G&G`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```*1)1$%4&%=MSKL-PC`4A>'KQ[T.(9%`R@Y,P"@P!<NP`6O1
M0H-0H$GD9VSCH'1PRJ_X=0!^QF`GA38=W5Y[5-1LJC.'6O>=&7)*`E&U"H%#
M6.6K%"DS0MPJM"!!BF:("B5';(FB+_1FTF<?`I/UFI@)A7IRE!+C;`[IRZ'0
MR=Q'DRM2<R@<IY+/#^T2+:$8?*'GZ";$;\@&%V.AE_7+(VNG6.C//HUM2*VM
M2%1F`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1Z+G!N9P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-0`Q,#0Q-S,V,S`Q-``P,C$W
M,S4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M__^8B(^*?Y-W:H144(]>6Y!J9Z9N:Z9F9:IF9:<M+60S,VLU-6TY.7([.W0]
M/7<_/WE"0GU!07M$1(!'1X1&1H)*2HA)289;7*!45))D9:Q75Y9;6YIA8:-D
M9*525:9%1XA76:I14YM45IY@8Z]@8ZY.3XT)3R%9DFPL:C]JG'DE8S=5C650
MAUX45B0I53,2/!LC8#`91"(A3"I+@59#<4U/?EEGFW)QHGMNGGARHWUSHWT(
M,1`R7SM#>DX[:$1AE&MBD6MMGW<_=D8?(!\F71E:ADP[:2.,K753;!.+G$YS
M?"`:&AAM:@QS;P^GH%"'?B!W80>1>B(,"@-R6`4M)Q2MF%&)=T9V6`U50A"8
M>2IX82>FBT1D5"NXG%2#=5%8/0).-P55/Q"IA36SE$_&IV2LDEEA6DH\."]:
M5U`P(@DR)0U)/R\;$`"8>4FVG7P6$@VCBFRHDGD2#@I/3DT[.3@"```B(2%0
M4%!/3T]&1D9"0D(^/CXZ.CHU-34O+R\K*RLF)B8A(2$='1T8&!@4%!02$A(0
M$!`-#0T*"@H)"0D'!P<%!04#`P,!`0'___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#[
M?*-R`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+Y)1$%4
M"-=C8,`";&U-S&P<[8TTW/R3*^JK*T%"Q@Y6%J8Z^EY!.2T--5590"%#.R=G
M/2T/O\22UL;:TH1TH)"!N:6NBT]H7D];4UU&?#$;4,C,6M,],*F\MZ.Y/B*-
M65D1**1MX1V<S=#7V9(96\"A(BX"%/(,B"GL[^_RC4ME4I-4%Q,$"H7GMO<Q
M](1%%[&KRDF)"O,!A<I:>QEZHU)8E*3E922$^'F`0J[=#"&1^:P*G%RRXB("
MO-S8O`,`XIHMEL0;DN<`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O=6$N<&YG````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#(R`#$P-#$W,S8S,#$T`#`R,3<P,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___T"KS$&KS$*KS$2MSD:PT4:OT$6L
MS$BMS4NSU$ZVUDNOSE"XV%*ZVTVPSS1VBUB^WE2TTCM_E%S!X6#%Y&+(Z%JW
MU$2(G6C,ZTJ1IV7`W''3\G36]56<LGK:^&[&X5ZENW'%WW;,YX+@_H'?_&>P
MQX;B_X;A_8#7\HCC_XCB_H;>^7*]U(C@^X+6\8K<]I#A^H?2Z9;E_Y7D_9GG
M_REK?T.MS4.LS&"\V&W0[GW=^G[4[GW2[)3@]T>MPDRQQDNNPU:ZSUFVR67&
MVW?5Z6NZRW/'V8;A]'O,W6NQP(WD]HC<[H[>[I[H^+S#%[[%&;W$'L;-(]'8
M,L;---_F1+[$0<C.1^SR5MK?4MWC6/'W8NSQ8NWS;^SQ=<S&`,W(`<S'`<['
M`\S&`]#*!<S&!='+!\W'"=3."M;/#<[)#=C2$,_)$MO5%-[9&-+-&.';'>3>
M(=3/'^CB)J>B&^OF*]C3)["K(>[H+[*N([FU)MW7+[RW*/+L-;^Z*L3`+<&^
M+,?#+O7O.LK%,,W),>'<.-70-=+--,_*,_CS/OKT0MK6.N#;/OSW1N7@0O[X
M2NKE1O_Z3>[J2>SH2/_Y3_[Y4/+M3/WX4?;Q3OOW4?GS4/'L4/WX9/___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(/+;:<````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````JTE$0508&6W(L1+!0!``T-W<W>Z12112H-<:
ME=+__X"2`H4Q#$,DN<MMSO6\\@'\0-C`L9STSU<3%%D>T4X#[,O9^]VV`34O
M\8&@X%-,0SXZK^8WYL;3Y(BPF%*XU774UC)K=`<-:QU]-0R89:@4BJ2J8N@E
M#69I!HF@8=N>ZC9:XLI:YUR`#.*E<0,94Q")E]ZGNM8N&*/'.6'7.Y%4]\XK
M8[A@TW5!4OWQ!<=`4$JNB"%U`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]U9RYP;F<`````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S8`,3`T,3<S-C,P,30`,#(Q
M-S$S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____QYR>O8"#R<#(K:>MMK*VN+N^+#`L3E--4E=1.S\Z2DY)24U(96AD`P@!
M#Q,-*2TG,S<QLK.N5%5.86):L+(`968`L+(#I*8#M;<'K:\-M;<2NKP4>7H1
MK[$?UM@QI*8FQ\DOQ,8OK[$MV]X\N;LSR<L^H*$RXN1*V]U,Y>=1VMU0UMA0
MVMM>VMMES,P`HZ0`!`0``@(`S<P!S,P!T-`%S,P%U-0*I:8)SLX-V-@0BXL*
MWMX8TM(8Y.0AN;H=Z^LKV-@GL+`AO+PH\O(UQ\<NLK(JX>$XTM(T^/@^_/Q&
MY>5"__]-[NY)[.Q(U=9"_OY0]O9.^_M1Q<9!V]Q/Z>E9_?UD"0D%%!00'!P8
M)24A'!P92DI&.SLX.#@U5%106EI7/3T[;6UJK*FCO9Q?T)UEQ&8GHU(AUFXO
M[GXZVWD^^(Q*[(E,]Y!1[(M0SWI&PT<`Q$H#Q$T)S%,-R5,2U%T9UV$=S6`?
MH4P;X6LFY7(OK%4CN%XJPV8PS6TU\H)"XG]&]XQ/\8M0^9YHOB(-PRX8U$TY
MQD@U[EU'V%9#O$P[Z6-.\691Z6M7\WQJX40UW&]D/",A23,Q3SDW6T1"8$E'
M:U)0:U-1=V%??6AF*`L)*`T+7$)"BG1T____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MIBP8U0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"W241!
M5!@998\]#@%1%$;O?>^^AS!&H5#H)!*)0J*U"0N;/5B"Z+4V(!J-0B1^&B&8
M,?/NQ]1SRE.<Y!!58)K2R+.&0O=#-J)V84FSV_44;<+E?/2[#K97IEDSYO29
MYA`G#>OSE="XWKU]6P_ECMR-@9+00-`#$HL$L4!+%:.0!CMHA!JK@IC:$("\
MSI<O-JB]4Z;Q)RM4K'5B$*#A(-1_9YEWXKWG;PB*OYKDRL:*,V4(".O*#M$/
MN=A8F??8?_X`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W5K+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`U,``Q,#0Q-S,V,S`Q-``P,C$W,3,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#___^\8F.Z8F2Y<G/LEICRNKNN*S"O
M+S.Q.C^X1TO69&CA;7'E<WC@<'79@X:M;&["DI3<J*K2IZG)J:KYV]SUV]RG
M*#"G+C:H/$.^14VO04BY1DZQ0TJP1DML*R_`3E7$4UK16V+47671767.6V.3
M2D_7<7C==GW3<7;*?8'FG:'.HJ7FQ<?(N+F:#AB<$1R;$1N>$QV<$QV=%R&E
M&R6H'RFC(RR?(BNF)S&Q*S6U+SFH+#7`/$:S.4+$14[.3UC05%W`3U>G14S#
M4EK47&718VO6:G+!H*/NR<SCPL7$IZKJRLV=2E:67&7$>H9R0$FPF)W-L[CK
MT]B=8W&H<'Z7@H?`J[#`I:RVGZ75N\+:P,?FS-/&L[CLV-Y^6'":@)&/;8:U
MH;%-3WNBH[12570=*7!&4(PI+DI78)ID:Y6IK+T%$UQH;Y"FK,BBJ<=18)5C
M;9"(D*XV1WU<;*%M=YF)D[0@-W8F/'IJ>ZYU@J80,'1.9IQ4;*%19Y9SA*EH
M=YB.G\33V>?I[/,-+G(.(TXK0W-UB[AQ?YR0DI9-9(RXO<9$6GZMN,J?J+?(
MTN*ML;::K;_1XO'!R]/D[_?GP\)Z4E+%C(RM@X/,I:7%H:'PSL[OT-#2P,#/
MOK[\Z>GTX^/___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"/OZIN`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"Y*=U=E1F%G%QY.949_FS
MS@<*900(+.@O*.5D+RQ/U&1K;@0*M?8D:4^=W"<AGA+*OV!2>PU0*"P\3E='
M9):%N;"0CUA,=!!0R%G#3<;26-_(S-K>T57521HHI.ZN8&-B:&!J9>N@K.(B
M*PD4"HZ*\/80G&DG-5O4TRLV,A`H5%LW48\Y)%M1J6G*'*V$KC:@4'WW=+GX
MBBINGOR2WGDL?JE`H;E,OLDM:65\O'GIQ0T39JAA\PX`D3DR\!,AFY\`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=7,N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,U`#$P-#$W,S8S,#$T`#`R
M,3<R-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___\%A8\9G:,5K;<]R=-R!@].!@K!L;>J1D\9]?M:,C?.@H?.CI,--4KY:
M7L!B9:YA9.Z*C=%Z?M:!A.B:G+I)4+M25[U46;916,9=8L%@9=)L<:)77.!\
M@;EJ;NZ3F.:.D\)S>;=H<+V"B-*GKEQ3J2<>A#$HBEU6JF)=G"8B8TM&GW=R
MP8N&S1T:6#8RE5-/F61AMV]LOH!]S8%^R8F&T!035QH86"`?:3(P=#8U?4I)
MIT9%D%M:IVQKP7-RO7]^SST]AG%RR&9GHW%ZN*6LWZBOX&!KKHR5R\MH8LQH
M8\QN:-:`>^N;EL>#@?NPK<,S,\4V-L@[.LT_/]A.3LE-3,M14>9?7]5=7?)P
M<,]B8N)M;?=[>_)Z>MAP<.]_?\UO;^:`@-MZ>OB,C.V)B=9[>\MV=?B0D,-R
M<<YY>?*0D-!]?>.+B_>:F?*7E[MU==V,C+MW=\>`?_";F]2+BL6"@NJ=G/BF
MILR)B<6%A,.#@^F=G>B=G<R+B_2GI\2'ALR-C?6JJM:5E=^<G/BPL.^JJM>;
MFN.DI,R5E,>1D<:1D:!U=<J5E:Q_?_&SL^6JJM"<F\22DKB)B=.>GLV<F_*Y
MN/B]O>BQL?6]O.*OKM^LK/;`P/&\O.R[N_?(Q_K+R____P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"D`Y7$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````MDE$
M0508TV7/O7'"0!`&T&]_[E:')`:&,23.';H75T`!!`2,(U?C4IRZ"@\1D1G0
M2&#I]EP`KX,'/""\)CXWPVUW)S83HJVB(JG;\^G+B4E8"(INX_??N)Y>9!:L
MXO*I6$P24G^Q'Q95S0Y%+W6?2[L,(=9"_@?%NLBS3-^=2AK(<X$B>1&WMV"F
MYC<O`#Y,%RPAIJ9]JF?["H15-7%AYFY.UWF^-$?%^S`6BRE&RF.FT0^/'_P#
MH0,\OO_$$'@`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]U>2YP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-3``,3`T,3<S-C,P,30`,#(Q-S,Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____Y.CST-'4B9G`G:W4K+SBO\WO
MEIRKRM+EQ,O<>8Z\A9>_E:G4CZ')<7^>CYZ_NLSSHK+4M\CMN<KOG*G%PM'T
MH*W)GJK%I[+,M\+;Q='KK+;-N<3<U>#YJ+'%U-[UP<K>P,G=J[+!M;S,V^/U
MWN;X=HV[=XZ\?I7"?)*^?I3`?9*\@)6_AYS(BZ'-@Y?!AIG!CJ++CZ+)G+#9
MD*+(>HJII+CBJ;[HA)2TEZG,K+_GEJ?*M,CPJ+O@L\;MN,OQJKO?NLSPLL/F
MO<[QFZC#J;;1HJ['ML/=J[?0IK#$T=WVJK3(Q]+IU^+XM+W0L+G+T-KOS]CJ
MH:BVU]_OM[W)P<7-Y^OSQ,?-U-?=[O'W_/W_^/G[C:+*F;#:@I2UBYV_I[K>
ML\?MK[G,Q\_>NL#+O,'*V-WFR<W4U-C?[O+Y[/#WPL?/O<+*S-'9V=[FZ_#X
MP<3)K[.YRL[4T-3:\_?]Y^OQYNKPP\G1P,7,\/7\X>;M\/7[N;W"W^/HR,K,
M]/;XY^GKVMS>RLS.R<O-[.WNU]C8W=:Z^O39?W56__75QK^IBWU6?W58IYMX
MG9)R]NC`Z^'&X=B^KXHNDG,GN)0Y_-1PTK!>^=)X[\^$]MB1XK==Q\;$TM+2
M?W]_____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````FYQ:7`````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``N;U]G<S,DE)2HB*NWE(
M>\L!A3JG3)W5P6G*PF/(Q\HF(L8.%.J9/'O&Q+;F^A;FIL:&Z)A6H%#?]&DS
MVV6X=0R,3*P=G)R%@$)SNB9,FAOJZNXIZZO@%ZB8#!3*+DBO2$VKS,BLSBJ-
MJBLN!`JY),9JJ6MHZL=9V";9627$`X7*2L)R<W/R\L.K:LHC(VJ+@$)<`?)>
M/OY*0:IJ(2DJRL$<0"%C72UM/5YS>T%A1QL!2S-^;-X!`.]C,:FG/XDS````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9A+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-P`Q,#0Q-S,V,S`Q-``P
M,C$W,3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#___^TFYVXKK32T=*JJ:W`P,;0T-3BXN3/TM*RL[.JJZOCY>&$EF>XOJO0
MU<:7H'^VO*1\AUF+EU.?J6YY?6.RMYC&RK'&Q\#&RY_:WKS+SIG3U;?+S+G-
MS<#8V,O\_/#1T<CKZ^'AX=C2TM#N[NW5U=30SY'4RQ_,O`!_=@!_=P#.O@/-
MO0G6Q@V+@0K,O!#AT1V=DAG>SR?2Q27NWR^GG2'AU3C'O#O&NSOZ[D_QYE#]
M\63X[67,R[[,R[_U].C__O/,N`#,N0!_=`#-N@',N0'.N@/,N`/,N0/0O07,
MN@71O@?-N@G4P`K.NPW.O`W8QA#-O`_/O1+/OA+;QQ30OQ/-O1?2P1B4B!'6
MQ1ODT2'4PQ_4Q"#8QR?=S"_HV#.RI2KAT3CATCB[KS+RXD+GUT#GUT'LW4CQ
MXE#4QT;VYU?VZ%?ZZU[IVUG][F3_\&CWZF7_\6K_\FJQJ(*=G)OIZ.?2R\>A
MCX:RJJFPF)CNZ^O(Q<7^_O[]_?W\_/SZ^OKY^?GV]O;R\O+JZNKEY>7DY.3@
MX.#8V-C6UM;0T-#.SL[,S,S*RLK'Q\?$Q,2_O[^\O+RYN;FVMK:PL+"GIZ?_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")B1;6`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,!)
M1$%4"-=C8,`"M%V,+(MSDDWL>[HZVIKK:X%"6I$IA;GI,>%VW9WM90V,C4`A
M_<2\_(PX?P,Y=@D^`7X>5:"0659!9GR(1Y`BFZB0"*^P+%#(HB@[*<+;*4R>
M@U.P1$Q<!2ADFYL6Z^OL'J4L(ZU>P<PZ&2ADDQ$7X.;J9ZPD)5G.5%G*#12R
MC@_V=/8)37"HK:NNJNF?!!0RC_!V]@J,3E6H;6IEZ9LX!2BDH:NIHV=H:N78
MV*+6.X%K*C;O``!(?B_>QXU^(@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O=F4N<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#$V`#$P-#$W,S8S,#$T`#`R,3<Q,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___\,Q0JP!%ZX%&;()';,4)[T6
M*LLG.Z,G-JXN/=DZ3K@T1,A`4.-,7M=-7N-29-E28A(:FALCG#(ZN3$WFD-+
MQDU4PDY5P5A?T@P5F0\8GA@BJ!\HJBTUJCA#O$90TS<^I#M$IS]'L$Y9T&EP
MU6AOTPT;IQ<EI1TKM!\LJR`NJBHXM#`]IS0_KS9#L452S$)-P493Q%!<UU!<
MT5=BTEYJUFITW69QU@@9H1,BE!8EE1HKI1LIF1PKFR$PJ"0SI#)$Q"X^L"DT
M@4%0PT%/P#I'JT54P$A5LE5CRV%OW%9CPUMIS%MGQ%->K':!TR,UJ&%QV<;(
M$\S,`,[.`]#0!<S,!<W-"<'!"K^_"M;6#=C8$,+#%M+2&.'A'8."$>3D(=34
M']+3(>[N+_+R-<[.+]_@-.'A./KZ0OS\1N?G0>WM1O__3_[^4/GY4+2S._7U
M5>/D4/;V5^3D4?'R6?KZ7O__:O#O;&MG`&AF`-;298B!,%];,+JR83X]-$0R
M$\P``,X#`]`%!<P%!<T)"=8-#=@0$-(8&.$='>0A(=0@'Z<;&[`A(>XO+[(C
M([PH*/(U-;\J*L<N+LHP,.$X.-4V-=(T-/I"0OQ&1N5"0NI&1O]/3_Y04/9.
M3OE04%Y>7O___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(@(LNP````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````ITE$05085V6/RP[!4!1%]WG<5H(&$7,1
M?VCB._@^(R*(9U&M>^[!V-JS-=E9P!^$>69E'A_/VC@+&G3!<)^T_=4T1D%$
MA<#8VLKB^\TAM7X$*-9G2G5E)'P)+&X0D-]6^UB<7L5QXYOFME.,4N\Q&.XB
MV[C>%^8@3,OL3CEQQ=*]=M+]0.A?-3DSB;"G[RK"LHS&*GE+*5HTFS&>]GO3
M7/@KW/T_!_@`G'Q82;+:Z>H`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]V9RYP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`T,3<S-C,P,30`
M,#(Q-S$P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____W*"BO51;G%%6U7-XUGR!BE=:R*:HIS0]W'-\R&AOKV)IUWR#Z*>L
ML(*&J#M'<"<OVW^(NHB0SJ^T94)*J'V'9$1,M9F@GVIXG6%RG&]^NIVPS;3%
ME7J-95IBLJ*QO++(+R-8D8JP6U9]0#QO>'>(+#!G/4-U)S)P.45]-$2$0E*4
M3%R?;GJK`!-<'3)Z&2II+T2-*CMX/E&9.$B#46.D:WFK`QIB"B%M#21K%"IT
M&"US(3>`(35T+T2)0E62.TIY/$MY7F^G9':M`!E@`!I@`1IA`QUC!1]F!R%G
M"2)E"B)I"B-H$"EP$2EM&#!P'39Z(3I^(3I]&RU>)C^")SU[*T.%(3-E)CEL
M*#MN-4V/,$:"*SYT-4V.*CUP+4!V+D%W,$1Z.E*3-DJ!0EB:0EJ:2F&?1EN3
M15F125Z82%V73V6B3F.>4&6@4&6=5&BC4EQW`!MB`!MA`1UB`QUB!2!G!1]D
M#2=K$"IO$BML%"YS'S=U(C5G+TB),$1Y-$F`.$Z(1EZ=1EZ</U2+3V:B4&>C
M4&>B4&:?&SEM9G*'*T=V3V:,8WJ@-EN!7(=^@XV(9HQM;Y1Q3(I*99]9;(AE
M:W-IIL^.A;9DC,!J@;Y5?+90K,V*K--^E+AE@8Q;____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````3]Z],0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!
M241!5`C78V#``L3E"WD4941Z?5T]_8*BF]N`0J+L_$)\3,*2ZA85!O:IK1U`
M(4$6-BY69@%.)<O.R5/ZS;*`0FH<LKP*$M(:_M;=L^=.TFT!"HDIFW.KV,E)
M:=KVS9@S4:<!**3GG*EJJ%^F96S4,W/Z5--ZH)!+=IB5>XF/3;C)A'FSYCO%
M`H7R8ZI*B[RJ0Y/3"[JF.29$`H4:`\K=RBN#XYK:<QVT$Z,B@$(UWL4>%8%U
M:3EY&2E)\;4AV+P#`!8Q,I^#$I\L`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W9I+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`U,``Q,#0Q-S,V,S`Q-``P,C$W,3(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____'3$^^8V;&5%Y>*3YN.%=H
M,%5X/FG/SL_CX^3@X.'&QL<4(G`!%5L''6<%'V78X.JBNM32VN.6PNV;HZM8
MH>)XN?.ESO6AOMB[VOB"E*2YSN*]Q]!LI]AVK-MEE+MKF\.'O>J/I;?3YO:S
MPL_DZN]EE;MWK=&_S-7'RLO*T=/+S,RRL[.VTM%O@'^ERK?3V]?BZ.7E\>FR
MPK:KU+(FDC--IE$`EP`6DQ8?CB#4U=2-KXMQJ%^HR9W&S,2:NX*+M&RGP'2^
MS)KCZ=*IKI:0J"R?KCVVO8?F[XGAYI3M\:V7GA.?I2[F[4:\P3^LLCWV^+S$
MQI?"Q`"$AA'4V37P]%#K[4WJ[$^]P$##QDZKK$;7V%KK[63EZ&1T=3KBXW7J
M[7S?X'?K[(K4UH3R])S'R(#GZ9?6UY'P\;'O\,&SM`7DY2O0T2_U]4#N[S[R
M\4SCY$C=W5[!P89Z>F3AX</U]=K6ULGQ\>G.SL?Q\>V<G)G=W=SU\ERHIW-Z
M>52^KRJ]L4&QJ%WN[>/FU8W2T<V^FD2+BHG4J(&Q7AG28$_*5E/V]O;Q\?'A
MX>'8V-C6UM;4U-32TM+0T-#/S\_.SL[-S<W,S,S*RLK'Q\?$Q,2_O[^\O+RY
MN;FPL+"GIZ?___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#`#-]#`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"ZDNJ>1A[N(.*=2;W
M<U65!0*%XD.BTS-+)T8&5Y9G),5%)`*%VNMB8@NC1'U]7#UR\L.3FX%"TD(N
M1;D!`GS\O/IY!5YJDD`A!0E36_]L5G8VCJ8P`Q%A1:"0DI2=E4U:)U-W5XNQ
MF)RL.E!(1=#>TLR]@9FEHU9/7E-+&2C46\-I;N&6TMCFZ>VD/6767*!0WZ3I
M)HX.SJ%^">(:K3/GS`,*64^;/G6"H5%6:H6,ZHS9NO.Q>0<`^_8R2`\U(H0`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=FXN<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0S`#$P-#$W,S8S,#$T
M`#`R,3<R,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___]`U-L,Z._IG:-#6#=G>&-O@'>7K*\K'!=//$.G<+\BM`]:Y%/G>
M2L:G`-_`(>S(-<><!<RA!_/"/L>#`,YR"LAC`>)\)L=*`?6"0O>'1N]W.L<V
M`,U*&-]1(?%X3OIQ4-,P$/AL4<P;!\<1`,@7"=@W+^]$.LH:$M89%.(L)L<`
M`,8``'T``'P``,@!`<<!`<@#`\8#`\8'`\L%!<H%!<@%!<<%!<@)"<<*"<X*
M"M`-#<D-#8@*"M,0$,H2$M@8&,X8&,T8&)`1$=P='=L='>`A(=`@'\\?'\\@
M()H9&:,;&],G)^4K*ZPA(>DO+ZXC(Z0A(;4F)M@P+[@H*.TU->PU-;HJ*KTL
M+,,N+L`M+:XJ*LDR,<8P,-TX.,XT-,LS,_,^/M`V-?5"0M4Z.K@R,OA&1O=&
M1N)!0-L_/N)!0>%"0OE*2L,[._I-3>5&1NI)2>A(2/I/3_I03_I04.Y,3/%.
M3OA14?=14?104/914>U04-!&1O)75_%75_5>7N596?ED9/AD9/1E9?-E9?MJ
M:O___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````)Y+N<X````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MO$E$050(UV-@P`+T]+WSVNKBG<QU3.W=P])+@4+Z+FFM#=F>:JI&-JX!*<55
M0"&[F,;F(E];27%K1[^D_,I"H%!0+4N-NJ:)J+"6MD9N15D64(BYK3Y>3HB?
MDTM`4+JT/"<!*-32D.EE)<O#RLXM55)5P!0'%&H"&F1H(,;&(9)?79@:&PD4
MJ@EQ,-91X960X5,NRTJ,#@8*Q3M;Z)HIR8=G*"KD)$2%^@.%/"QUC&S<0"XJ
M2(Z+"/3!YAT`ED0M<)HE0N(`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]W<RYP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P,3<`,3`T,3<S-C,P,30`,#(Q-S,P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____VAT>T#4VMP`.N`$/N`43
MO`<5O0T=Q1`>T4%.YEYJYF5QLP`1M`,4LPD9N2`O&06Q#`&Y#P6[$PFZ(AC!
M)1O!0CJ[85GG<FKQ9EW2"@"]"0&\>WKR``!]``!\`P/,#0W-"@J('Q_3'!R:
M*2G3(2&G.#CA+2V01D;35E;H2DJX9&3X1TBN:&K]:6GU:6GS?7W[<W/E=W?B
M?'W#$A7.043;B(KPRP``QP``Q@``S0$!RP$!S`,#R`,#Q@,#RP4%R@4%QP4%
MS`<'R`D)TPH*T@H*T`T-S0T-TQ`0RA(2V104UA04W1@8V!@8S1@8W!T=VQT=
MXR$AX"$AWR$AT"`?HQL;XB8FUR<GY2LKK"$AZ2\OKB,CM28FV#`ON"@H[34U
M[#4UNBHJO2PLPRXNP"TM[SHZR3(QQC`PW3@XSC0TRS,S\SX^T#8U]4)"U3HZ
M^$9&]T9&VS\^X4)"^4I*^DU-ZTA(Y49&ZDE)^D]/^E!0[DQ,\4Y.^%%1]U%1
M]%!0]E%1[5!0_61D____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````97%I=`````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"H241!5!C3;<P[$H(P%(7A2R3<FX`.
M-)8NPC6Y!I=@[1JM*!A'D$?(X\8PEGK:\\T/\+,,3IFL0Z>?_9F4WM?Z)B!3
MZ/GH(TM$.B@).>RDM#PSITLU*%<0D'M?5G740JH]4;!)]2(*'V@6J,LB&I/4
M-`SS:M_+FI!T=T[J.CY>8]14-8C&7%Q2L1V60*A3R%G/6ZOMC:."OB'K0E+=
MM.0%X1:RS,'#GWT`9#U.K7;&=WH`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+WEE+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#0Q-S,V,S`Q
M-``P,C$W,38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____5U-7'QL<B(R/4U=7!PL(?(!]]?GV"@X(V-C5M;6SGY^;-S<S?
MUM//Q,'3S,K,P+W"(0!Y%`#&)07#)07/,!#!+0_*-AC#-AK;02&7+AG20B7I
M4S7.33/?5#C94SCT9$:J1S/`43OM94KW;%#N<%?E;%3B:U/Q=5SX@FK@=V+T
MA&[]\_'\\O#QY^7^]?/QZ.:_'0!Z%`!X$@#!(`/!)`G)*0W`+`_(-!>,)!'5
M.!V%)1/).1_B2B_O7$*S1C+<6$'T:$_O:%#U<EGP=%[N>F70Q,++O[W:SLSG
MV]G<T<_TZ>>FGIWX]_?^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV]O;R\O+N[N[L
M[.SKZ^OJZNKEY>7DY.3AX>'>WM[:VMK8V-C6UM;4U-32TM+0T-#.SL[-S<W,
MS,S*RLI_?W]\?'QO;V]A86%@8&!=75U86%A145%04%!/3T].3DY-34U(2$A&
M1D9"0D)!04$]/3T[.SLX.#@U-34T-#0P,#`O+R\N+BXJ*BHH*"@A(2$='1T;
M&QL8&!@0$!`-#0T)"0D%!04#`P/___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#BO.<T`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+])1$%4"-=C8,`"C(6EE;74%"1$A43$I&0558%")E8.;JZ.MF9&IN;6=O9.
MSD`A&R5M'0TY20MQ2QEY%1=-=:"0KX"!OC>_AZ"[IY>/KIXA'U"(F3$L+B4C
M(S4Q-CS0/RPF!2CD%\S#FIZ1EA07$<P8$LV4"10*B$Q,RTA/CH\*90R*2.!E
M`PIEY99555>6YN=P<&9SYQ44`H5JVKL9NCM::LN+2BKJ&IM;@$+L70P]G:T-
M%<5%Y5SU32QMV+P#`/Q*+2HF'D7T`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O>74N<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#0R`#$P-#$W,S8S,#$T`#`R,3<S,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___]74U<?&Q]SB\J2LO[O#
MU[6\S=3<[\S3Y``G>@`83`0J?00J?`DN?@PRA`PD6!U"DBU1GT!CKD%@I$]P
MN$MJK4IIJU!PM5-SN&6"P)VFNZ*KP*VVRHB.G+K!T=7=[LS3XP`I>@`93`,J
M?`4M?P4M?0TTA0\T@A`XB!@]B!$J7QI`CR%(EA]"BQDS:"E+DB]4H35:IBM%
M?#A:GD)FL#)-A$9KLSI7CT]QN%!SN5=VMEY\NUIVL&6!O&J'P\G2Y;.ZR-35
MU>?GYMC6U<"^O:0I`*4K`Z8P":XU#;E$';!$'XLW&Y9`(\A6+Z%'*JQ/,+56
M-=5G0LEG1MQR3]=Q4*M=1<S)R/KW]O;S\NWJZ>OHY^GFY:(D`*8I!:0I!;`T
M$*PY&+Q$(:I`(:I"(Y(Z(:]&*)Y"*,M6-:A)+KE2-+!-,;)0-+]6.-=G1L1?
M0L=C1=MO4-1K3J!4/K]F2]5T6+5D3,5Q6-^#9]:`9^"';=:#:M+.S<W)R,S(
MQ\O'QO[Z^=W9V-?3T_OX^/CW]_[^_OS\_/KZ^OGY^?;V]O+R\N[N[NKJZN7E
MY>3DY.'AX=C8V-;6UM+2TM#0T,[.SLW-S<S,S,K*RO___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$NESDH````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````NTE$0508TVW!/6I"41`&T&]^[GN*
MX6&P$K00"SN7EL[**@CB?M+%WJP@8**(B(4:$#%&U-R9FP68<X`[A#8>RGF\
MGF,4U1!DPMB4\LP^;NLU\T:%%U"$4CZWQB7Q5Y-6K`Y&4;SEA_?OHEI\=G\J
MAS((XJ-,%&8>8U(-3XSGX>N+P#V9]45Z`83!M//+R</,.E/>U?9CQ:6^O2;1
MK"ZWEC>6W;'B>'(GB^Y"9O9XA&)A3DRJ3.XI><(__@#[2U)W%.T;9P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Z82YP;F<`
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#8`,3`T,3<S-C,P
M,30`,#(Q-S$S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____RA,4X6)CU&AJWG!RZX&"^)&2_YR>[I.5^YV>S7=Z]M35.SH[
MOL;^M[[R0E[W4&GZ8'C[=(;NE)W/O,7](3>M*#^X+D;#-$W/0ESA3VSZ3FCR
M@8JYBY3$HJS?L[WR&S6D(CZO*D:[,$W&-E311F7F4&_UP,;;U-CG>(V"S-G2
MA9N/DJ>:F*J?KL&UL<.XHK:IJ;JO=XY^.UE`'#L?36%/`"0``",``"```!<`
M`!,``2$!`R8#`R0#`Q\#!2H%!20%!2,%!R4'"2P)"BT*#3,-$#`0$C`2$2<1
M&#08'3T=(3XA'SH?&2T9)T$G+TDO-5$U-$PT,D@R,$4P1F)&0EQ"2&1(-DLV
M0EI"4&I03F=.1EQ&3V=/4&=07G9>97UE9'EDN;VY`1T`$B\1'3H;'#L8,TXO
M36A)05<Z#"L!:79AEJ:-EZ:.@Y)YBYN!?(ISC9N$<G]I>XARN;^T<(%9+T8%
M0%82/50`*SD`D:!0BYDX>(8-@HHJG:,8L[DOK;()Y.5H;VX*M;4GBXH@KJTX
MN[I0C(Q&;FY73$Q`(R,A@8!(QP``R`,#RP4%R`4%T`T-TQ`0SA@8W!T=X"$A
MZ2\O[34U]4)"^$9&^D]/^U!0]5!0QZBH9F5E:FIJ9&1D7EY>____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````T-%^*P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"_241!5!@99<^Q#@%!$(#AG;E9>^>(1DFH1$1H=!*/(VJ=9U"@DW@'G4JG
M4LHI50HA#MWE=L7=V-/ZRV\RDXP0?X'H<_D6G>-9DJ#C(.*0Q.`@6^QV)_$4
M$6R"A-?3C[ARK(U'&2!;<B7)Y]GM+)M`*>`G`%%<W!.C=ZZ2=@:I69.8(S!B
M+D<D%:2,=A'#MWD%'E55`L1H+%V-WNM"W=M>E,]1/CL?A2?C-_R5XZ@WD\DH
MB'6[M`G!*_"OOV\L?`&V`4B$H;>>K0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+WIW+G!N9P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`T-``Q,#0Q-S,V,S`Q-``P,C$W,S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^^'""L&1Y,*BOBP,+%
M<'?+@HR[KK"YB)&DE)?LP,[[^/DW-3;:U]J,C(VWNKS)SL^)BXN_QL-D;&4;
M0A4Q7ADN<05;F35:DCAWJU>(N6HJ;0`N;P4Y>Q`^>QA)B2%LIT98ACMTK5!R
MDD%VFP-]HPV*KQUI@QN:OB]SCB-]F2J&HS".K#6IRT*AP$:QTD^NSE#$Q[MS
MEP#@Z%>JKV/#S`#%S@/%S0G-U@W8X1W-U!_F[B_R^D*AI2S?YT'W_T_R^5"K
MKT#T^EZ_PW;N\&78UQ#DXR&PKB&\NRCR\#7'QB[2T33\^T;EY$+^_5#V]$ZH
MJ)#O[^[0R@7*P`#$OE_MZ*_$NVG<TWO9R)>TGW/DK$[-=P'+=@'3?@K-?`W=
MBACJFBOWJ3[^LTWMJ$G[LU'RN&S7B"?2S\S/@#GTIVVZFX6^+@K;/13G32:Y
M1";$3"WT8#K/4S/?7S[];TKQ;DS\=%'/*`?#`0"]`P/'!P>L"@K1%!2_&!@A
M!07>)B;-*ROK.CJJ+"RT,C';/C[7/S[!.CKU2DHR$!#J3$ST45'C34W424G@
M45%"(2',='-4-35/-#1E1D9>0D)N4%!J3DXQ+R\>'1U$0D(Q,##U\O)14%!0
M3T]'1D;AX>%_?W\W-S<-#0W___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#+ZSJ/`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+U)1$%4&!EES[\.`4$0!O"=V;7G
MS\61B$KM010J"JU"(WHA"*]`H?`"GD!#2TVO$@^@N.8D<N[6CCDZYNM^F7R3
M4>)OE"@!N$\B;2EV,,S@58EYOUJPQKPL($<"T["V;:7<T!(B`"`=E`AU;VWB
M"8M$+<D()8QWZE2G\UE6(^]9R[3:Y\_']!(>A(JPOV`:-+&RB2XHE8,4C6],
M]9UL=W,!2(ED.4R-LG^C>R)<]*51T0OX>.HC1$F][_^\]`9'(TO.,9\<@@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S
M,#$U`#`R,#4V,P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]I;6%G92]C<F]P+G!N9P``````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`R-S``,3`T,3<S-C,P,34`,#(R,C,P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@$````M?HWZ@````)B2T=$``"JC2,R````"7!(67,```!(````2`!&
MR6L^````7$E$050HSWW1N17`(`P$T9&Z<S,40S,40S%R`C[0H?3/VT0RR6Y8
MHR.S8`"MN<?!R^'"ER_1FMW"R4?@^1=$_`EB?H*,5S"L81@X!MT,0G<,.HR"
M0=9RPN3?W'<#.>\OS354T,(`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O
M9FQI<"YP;F<`````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#(W`#$P
M-#$W,S8S,#$U`#`R,C(R,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,````_4$Q413"FNBHJ*H>?M8B@MHZCMX^HOY*IOY:PR)VXTIZXTJ.\U,#2
MX<+3X\/3X\34Y,?6Y<G7Y<G8Y=+>ZM3@ZP```)73<,4````!=%).4P!`YMAF
M`````6)+1T0`B`4=2`````EP2%ES```+$@``"Q(!TMU^_`````=T24U%!]0,
M%!,)%?V/F]L```!1241!5'C:A8]+#H`P"$1;%9VJ]3OW/ZNL;,$TLB!Y+PR$
M$!I%SSL=0V@9M8E'FH$TOH;DADY[E<D8S%8G/I%XW2MD.<L,)WM6C5A6T_/G
MN5(/,.,$$=/,O<(`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+V=R87ES8V%L92YP
M;F<````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$W,``Q,#0Q-S,V,S`Q-0`P
M,C,R-#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$`
M`+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```
M%V^27\5&```#`%!,5$7>WM[=W=W<W-S;V]O1T='$Q,3#P\/`P,"]O;VYN;FR
MLK*PL+"KJZNJJJJIJ:FGIZ>CHZ.BHJ*?GY^>GIZ<G)R:FIJ9F9F8F)B6EI:5
ME963DY.0D)"/CX^,C(R+BXN*BHJ)B8F(B(B&AH9Y>7EX>'AS<W-R<G)Q<7%O
M;V]@8&!?7U]:6EI75U=65E924E)145%(2$A'1T<X.#@B(B(A(2$%!04$!`0#
M`P,```#___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#Y)V#)````.G123E/_____________________
M______________________________________________________\`-\#_
M"@````EP2%ES```+$P``"Q,!`)J<&````)Q)1$%4*,]=S^D.@C`0!."*J'A0
M10Y;J0IXH-8#3X;W?S$1E!+FSR9?-KL9DC5"RH$\=8!P^1(*(*:6S0(H\"9#
MRQ,UF-GYAE\!L&`NFT=_`/5>*U]$Y2.2P=2U\?V-YW$O44!/(^T.34,>[*[X
M0E]OZ8:9L@%?RP)LHVN,G$?(POB$XJA#J8-DNXD/"7YO\_NXR/,-53G5CS3K
M?P!B#RU+L1XI;@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O:6UA9V4O;6ER<F]R+G!N9P``````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P-#$T`#$P-#$W,S8S,#$U`#`R,C4W-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(`P```"@M#U,````V4$Q410````8'"2HJ*G6*G7:+GWJ,FGJ/IGR2
MIHB@MH^HOY&HOIVXTKK&T\'2XL+2X\34Y,K9Y0```&]D$4<````!=%).4P!`
MYMAF`````6)+1T0`B`4=2`````EP2%ES```+$@``"Q(!TMU^_`````=T24U%
M!]0,%!,)+SN#0FD```!/241!5'C:K8W;#H`@#$,GHC(J2O__9^4BTV?C2?;0
MDZP5^8BC"-V3>58!6C[``H8I&2GGA-MPA[%T$P"-40$_?H*VCGFRUJVNK'SM
MLM]/7#6R`^;5H<PA`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E
M+W)A=&EO+G!N9P``````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0V-0`Q
M,#0Q-S,V,S`Q-0`P,C(T,3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````75!,5$4```!_F+2$G+>%G;>)H+F*H+J*H;J.I+R.I+V/I;V0IKZ3
MJ+^3J,"4J<"5JL&8K,*9K<.:KL.>L<:?L<:QP-&RP=&RP=*SPM*TP].WQ=2W
MQ=6[R->\R=?9X.<```"12<D#`````7123E,`0.;89@````%B2T=$`(@%'4@`
M```)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03"3G/5_<X````44E$
M051XVF-@0`=R4(`0D!61D)011Q(0961B8>=&$I!B9N7@X4<2D&;CY!40DF.`
M0S$N/D%A9$-1;4&20'8*!HE+-<065&^@J9!#5\&`HA<*`;L!"";O7*0+````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R969R97-H+G!N
M9P``````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,S0`,3`T,3<S-C,P,34`
M,#(R-S(V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@&````'_/_80````9B2T=$
M`/\`_P#_H+VGDP```1%)1$%4>-IC8,`.M!@H!/_),40=JO%__XI]_XDUA!')
MR5>OWGO&\.SM)X;7[S\S_/G[CR'.TYR!@8%!G(&!X14N`UB@]-7F!3L8YFT]
MP7#GSAT&!@8&AI_?O\+4L!+EYTFK#_PW]HCZS\#`\%_)P!KF!7VB`ZUB^D:8
M)@8<FE.AXF+(@DPPQN7+EY'%M1D8&"ZB&3`;2K]$-X0!*H#L`ESIXO_5>\]P
MJH,9DHHFKH_L-?_\+A0#F)`4OH)&ZVPTS1>NWGO&P,#`\-_8(PIG.L`&I!D8
M&)Y<O?>,H6KB$KC@DYL7&,[N6`;7RX+'@-\,#`P,BW>>AFMD8&"`:=8F-GJU
MT*+X/S3)DP2T\,0.289@!0`O`&4!>+W4?P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F]T871E+3$X,"YP;F<`````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-3<P`#$P-#$W,S8S,#$U`#`R,S`W-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,```!^4$Q410```"<G)RHJ*C`P
M,#Q!1GJ'E(.1GXB1FXZBM(^DMI:CL)6MQ9>NQJBMLIJRR)VXTJNUOY^YT9^Y
MTI^YTZ"ZTZ"[TZ&[TJ*[TZ*\U*.\U:2]U:K!V+''V\#.VL'2XL+2X\/3X\34
MY,74Y,?6Y<C7Y<K9Y<S9YLS9Y\S:YP```)%:.G8````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!,*
M!E(<B<8```!S241!5'C:C8[=&D)0$$6G)"K:?I)4XJ#8[_^"'#Z.NFK=[?7-
M[!F1`8Z(@4W=Y/YF)120I0?K2]SCRW[9T@W'Y\TS-5L*2US-A!I$A6@6+$`&
M77+BDO%Z?QZ1/0FVT&2I.Y^ESN'9V9E.X/=UK-/TF?Q/#TYU"Y-\J!(]````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VEM86=E+W)O=&%T92TR-S`N<&YG````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#0S-@`Q,#0Q-S,V,S`Q-0`P,C,P-S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3````2%!,5$4````!`0%"0D)-34V(EJ.=N-*DO-2E
MO=6IP=>OQ=K!P\BSR-JTR-RVRMRWRMZZS=_(S-+'UN7(U^3-VN37X.G5X>S9
MX^T````)QS-D`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q,```L3`0":G!@````'=$E-10?4#!03"A76HL@8````3TE$051XVHV/-Q+`
M,`@$Y7#..>W_?VK-N!"X$MTNS`$A9!<40.)R."<IB>H:&UFQS6UO!4>G&I/!
M:L?C`O8H3'^Y'[E(Y/DS^#M_'$W^DR]D.00M4QL`X`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G
M92]R;W1A=&4M.3`N<&YG````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-C,`
M,3`T,3<S-C,P,34`,#(S,#$U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```%=03%1%````*"@H*BHJ,3$QC9RJE*&MD:6XG+?1G[?.G;C2G[G2
MG[G3HKO3HKS4H[S5I+W5I[[4O</(L<?;P=+BPM/CP]/CQ-3DQ];ER-?ER=?E
MRMCEU.#K````^H$ND0````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(
M67,```L3```+$P$`FIP8````!W1)344'U`P4$PH7.*RI-````%5)1$%4>-J-
MCCD2@#`,`\V-N`(!S.7_OQ-"@TV5[;3CD4P4@;QHL6_'.25*,#!T96:$:YM<
M=$?A^UI,\8I1S`ZC4E,I7PO@Y^]&$#"_A&Q;?_DQ%,L->1H%^^LOS((`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9V]O9VQE+G!N9P``````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,C(W`#$P-#$W,S8S,#$U
M`#`R,30V-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````2P```"`(!@```%I]A7,````'=$E-
M10?3"1H(`B/TB%/C````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+
M$@'2W7[\```&)$E$051HWNU8?TQ591A^X`(J>+UZY3=Z,;1``XK`'RB&`IDZ
MO6XJ%I&2Y2@=B>D0UF;R1ZE)6DW4D&8ZEP&U;`@92;NUW%Q;6E.*_N@/MTS[
MH6UM49LKOK[GBW,[]W`.3FYLS,Z[?3OWGO/!^>[S/>_S/N\'V&&''7;880<:
M1#AF%8]"<8MC6*\S'R-1B?O#=J(RI!Y'0K;B9WB1.O0O)CCY34\COZ,=Z:_[
MU,AJ[D9>YWGDG:['_*;%0HCA!597<00.(!;5>$8!-16'AOZE\P\5(*OI*CP5
M!Y&\/$T#9=HT1&!*^5),:;B"C"\$D@_T8O+CN<..87OP!"K0BTG8.L1`-2U&
M6K/`^&5+!YSG7G%1#1?&_3_!DBS"S(]ZX2[<=M.Y<0_.4TP;AD'-4F`EXK&A
M>\M"WYN(KF'6!05">38BV^*PZGP2:CCVQ6,%[UG-?V$CXKY]%Y7:V+X&W@$W
M8LGV:.2\EX6IT^_&"%>*NLZH7ZGN:6"50YB!U>1&D;8N?O8_B(A>%#!&QB>K
MJVEX\E)0<*$';J\O&*"*G<AM<>'K76.P;?T(+.#U$S=Z+\3AVFI93XWS3[R$
MK1V[X2-`'$>J\?*5D^CYI1W7^%T_MZQ,5KMY;3N0WM"(Y*H7U7J]EW]5^LKO
M.8<GJM^]%\\JL":$EVA_ZQT/9WL,VJHC<7"+`RMY[8J"X%H5^!I@1N!,@SO#
M%!Q;^,9@@2IPX;X38R%X#7@@=_]L!$1G",1TR5\]4!_LP!\H%@$L6C0+&9>/
M0W",#,-LWE-%ALQ/KGQ;_W^1UO%/H>%GC21&L(1P:$#IW_-:%#:])9\N"D5[
M/[#TUWZQZOLZ]>+!@N7U.K],Q)D-$3AG]I@,ZW)`;`C!#_R>,`T>,FBF1_XL
MDR##;K1"5*W`)7^%YF9&1MX;,#%[[S8DG17ZC`AY%;4R`?U@,=T("C(?B-7F
M/)*#%`)8XL!W1:%8?VL_EO3.Y$MEA1M$M*=AW<48W%CHP%&SYT5.W$G:5W'1
M"<4>:M/Y_1`9D[#,;#[91;#VE,KYK+C<3-<Q/],"Y"/UC$!\Q6\!8)%9G@B5
M]N<\.%`7*@4?&$_@3L;B<%TD6O0LO[6@?\KJ%A1X"NZ`XCKKX`Q5.;E0^9DI
MP@4QU?R4-@3G4+?*0_$G%_GC:30R!=/OP*-674-/)WXG6'%12$?15_4*E-%Y
M=?UT+*G9G%E]8%U*PH?[)*L7A*)T?R36<N."JX1NC%%&4[W8PCI00.G>4W<>
M5\Z>`CMY9S<?<;>89J2UU2N8I@1+BDLZP2*SUBZT=MG7.]"]V8N_YJ8A09E?
M5X?:3+56+7C?42'TFB5]5@!83+=6N5]6*3^X8)5A_DO!3$TTZ:GTO2&U(N%]
M_T[3'DC4A*([2[E)^,;AFX>9AGWB'J!))G'I'5PG6/_Z0%GQ"$QR[4_*/*M.
M0[9@TO,93&FM7N`IY%Q;=;C4R_^JOV5Y5:T,09C:>HW:8MVTRKZ13E^7%@VC
M<8H[6!*.#N/TW!3$$DB_F,ZN<I)95JE(`3Y:B=["+#RDOQ\%V?O%/[G2SVR3
M+%#5D*:TCUED(BLQ![7*2B9N/29F)2JJ2S%5&D%+8540N,OZZBDK(@'AX&[J
MI]//&$&DCR(@'`1'OW"".%"*8FYKC=+8"5L^-S[BB8-*0UV[0[VB;G$SR?!=
M]V`&[[>YD,VU2@0':<29_W%K3F'49LF<1J&HGGNR42UP3F<ELH_O5EK%.<84
MD']+4%CUN(NT#&2<\C@\%3`$F5.[&E<)&.V"9E+YV7)]DI5J+<P`ZAA/1'A*
MHC7[9?@8.;@JW=YGF(Z-VGO):FIF59]<$+SG1N!3`A9T6C)UX)JY7%&=)Q`3
M-]7`\]1JBNI-:2O+/1T\Q_92G2!;!)E%IJD==_>?[_,A3*4^@6&!X5JX+EH&
MZJS</#7'F%H\XPJ\Z6"!8:<1?%4<AI&9*:6*[IUL-NBHTC#J+#-@[)P*^Z1V
M]K%U+"9.)^XR1U,Z<VIL$*W:[1.L?)(YIG;&;RMD?V@SJ\__4<A94*P.`:3W
M"O9HZ;8(U=(HB_"\4-Z.7013DX-5FJ(O^SZ;58;36<0L>44QC$<U=/3L:>VP
MPPX[[/#'WU13BE[P*%ZU`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V=R;W5P+G!N9P``````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,R-0`Q,#0Q-S,V,S`Q-0`P,C$S
M-#(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.
M?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^2
M7\5&```#`%!,5$4("`D4%!86%A@;&QP4%1<5%AC+TMS#Q\T.$QH.%!L1&"`0
M%AU$77E)9(%3;8EH?I:*GK2`D*(-$QD.%!I=>994;8=:<HM<=(Q3:'U:<(=K
M@9=9:GP?)2LC*"V"DZ3,U-S-T]E.9'EJAJ%*76]RCJF`EJML?(M=:WB)FZL.
M%1N)G*R!D9]R>7_<XN?=X>0E*"K(R\TU2DT1%Q0%"P=HIVDI?RDI?BHG=2@M
MA2TM@2TN@"XQAS$UBC8YDCE$C40X;CA/?D\G628P8B!/<D(9*Q`?*@T$!`(^
M/#9S<&>MJ9RII9@H)R3FX=#;UL?PZMF`?7:6:1J@<Q[4FC[1C2?6D"G:EB_=
MF#'2ESM*038:#@$2"@&J7PJL8`S$<!._;1.^;1.^;A.];!//>1S.>1QQ/PJ,
M3@TK&`1I.@J$2@VZ9A/-=AJ\;1M(1D0D%@D<$PLC&`Y33$8#`0`$`0!M:VMZ
M>7EG9V=:6EH%!04"`@(```#___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````S$L1V````>W123E/_________________________
M____________________________________________________________
M____________________________________________________________
M_________________P"3PZCJ````"7!(67,```L2```+$@'2W7[\````N$E$
M050HSV.H@H'*2C#%`.-[^OAY5<(%&)D8?/W\_&`"S.5EI17^0>%P`;?BDL(B
M[[!0N$!D=D)\HGM(L)\'5"`J*3DK-B(P`&P(2"`M,S4CSM7)V<[*OA(LD!>3
MDA[MXFAB8V4)%F#1*<C-SS$T=K"U,`4)L*JIJ!NP"XHI&EF;F8,$]`64I/5T
MM?A%N2LKP8;*JHI(*+!IR(MS0?TB(\6GK"TGR<NC"?.<L#`G)Z<PAU`5JF]A
M```B$EE50;2K&@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6%P+G!N9P``````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P-C$Q`#$P-#$W,S8S,#$U`#`R,#<U-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```!@4$Q4161D6__\S:BFB-K8M,/!HLW+K/_ZO?STJ)R8
M=*^KBK:RD7AV8_ONCMG0BI"+9_;C?,_'F?/>=/?GG?_3-_;/2?K85^2N&N2V
M.\B6'M2C*=VN-:M]%KZ-'%P_)4]/3P```(J'Y#`````@=%).4___________
M______________________________\`7%P;[0````%B2T=$'P4-$+T````)
M<$A9<P```$@```!(`$;):SX```"6241!5"C/3<_9$H,@#`70J[((1:D4ZX(-
M__^797-:'AC.369($,OA?N/UA7)/:R=/_@N>:]<)=_`[*!;"[KP&R<,,@.S%
M<E#JPTA$9@DLHO8S$,@8'QA\M@/4!&N75\`FA9",'L9,R>\/].F$5#0;4ZP1
M]>'DF(+J_*W>;4]S<QE,78LM5O?H*OBUN2VG0G+_MVU*FN,7&=\3QXR&$]\`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAE;'`N<&YG
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q-@`Q,#0Q
M-S,V,S`Q-0`P,C$Q,S8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3``
M`.I@```ZF```%V^27\5&```#`%!,5$4```#___\='1P\/#M^?7>TLZW=W-;R
M\>OAX-K4T\_0S\O+RL;(Q\/S\N[R\>WLZ^?DX]_8U]-^?'7`OK=U<VZ&@WVQ
MKJCS\.KGY-Y14$YD8V'=V]B$@7VVLZ_8U='U\N[MZN;HY>'BW]ME85Q955+G
MXM[R[NOJYN-V<W'4T<_*Q\6ZM[7P[>OTZ>,(!@7)N[0N+"L[.3BFCH7PTL?T
MX]UD3D?<O+'HR;_*537I;$KI=%3C@6;CC'2374[NEW^M>&CNJ)7PJI?ALZ;C
MNJ[9N;"H-!G?22;,2"GD42_?43#,2RWH84'78TC$8DO0:U/3;E;J>V'(=6&;
M6TS6DX/3DX+HHI'QJ9C>H9%D55'FXN&1+1:H-1MO(Q*4,!G422FZ1"F0/RW6
M?6GMD7SHL:4!```+"@I%0D(?'AX,#`S___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````8:)SL````:G123E/_________
M____________________________________________________________
M____________________________________________________________
M__________\`O.3<XP````EP2%ES```+A@``"X8!00=EMP```,))1$%4*,]C
MR&1@`"(0R``Q(5A#CH]=0ELJ%<@$RX<:*PHH\BO8N#)D@F&R8Z(^JS"'N8=;
M3`I0#9-DF$]L1#J#9$*`MY>I`5!+9'B\(="@3`;?)"=ED!E\7$:&F2!@J*LD
M"A(0UQ1C``LP\`J*@`14I;FA*G2TP`+:ZLY!8#-"7&29@0*IDM96=H%`AP;[
MN]NF98#<$>UIZ:`F;^(7%Q7%`'%IC(49&R>//8@/%M!CD)018M%0`7,AOH%X
M%^K33#0``$;Q-XI;DZ+V`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O:&5L<%]I;F1E>"YP;F<`````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,3$Q`#$P-#$W,S8S,#$U`#`R,C,Q-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(`P```"@M#U,````$9T%-00``V.OU'!2J```#`%!,
M5$7___\```#FYN@N+S165UEP<7.>I:^[O<`B)RY%2$Q86U]B96E!1DQ%24YE
M:6Y$8'Y"7'A(9()-:8=/:XE2;HQ3;XU3;8I8=))@>YAE?YMF@)QKA:%=;X."
MF+%%4%R-H+9C;WR:JKQ88&F>J[FDL;^ON\DQ3FLS4&XR3VPR3FLZ5W4\6'0_
M6G5%87U*8GI)8'A:=I,6'20-$15=>)1.97Q39WQ.7W%9;(`]2E=><80Z1$YN
M?Y!TA99ZBIN;K;\=("-A:G.KNLE;8FE"1TQ&2U"JLKI+3E&/E)E;7F%G:FVN
ML++P\?+N[_#GZ.G+S,TT46TU4FX]671-8'%^CY\O/4DS.T(N-3M.5ETB+#0^
M3%="1TMB9FG=X>1)3$[DY^E=<7OK[>Y@<WOO\/!L>7)Q?G>"B'2@H8'NUH!.
M3DX\/#PE)24.#@[___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````NN'=(`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q,```L3`0":G!@````'=$E-10?5"AP&'0%2OO>"````LDE$050HD6-@P`8X
M&&$`*I"M:"RF&ZBM(V`&$6%TE!1.3T]/U=2/A"C(LC-(2U172P\P"P>K8%21
M$N%/24]/UK.(904)9,J+"\6GJZGYFX:Q@%0PJDJ+"FIIJ*F9A'B"=63(2@CS
M`Q6H!85&@16P!=O:6%O*R)C+<4&,5&+F=7/CY'%VX>.&"#A$>_DR)?DD^+E#
M7&7/R&BEH!P3Y\WN`7,X`\@3$4ZN<#X8&#$R&C)@!0!,.1M(*A[`O0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H:61E7W!A
M;F5L+G!N9P``````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-#4`,3`T
M,3<S-C,P,34`,#(R,S`R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P```,!03%1%````4E)24U-355555E965U=76%A865E96EI:6UM;7%Q<75U=
M>'*0>721>G21>G63@'UTB'^CK*F]Q<'2RL;6S\_/T-#0TM+2T]/3U-34U=75
MUM;6U]?7V-C8V=G9VMK:V]O;W-S<W=W=WM[>X.#@X>'AXN+BX^/CY.3DY>7E
MYN;FY^?GZ.CHZ>GIZNKJZ^OK[.SL[>WM[N[N[^_O\._S\/#P\?'Q\O+R\_/S
M]//V]/3T]O;V]_;X]_?W____````9%3[K@````%T4DY3`$#FV&8````!8DM'
M1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P($APLCC)W
MUP```)Y)1$%4>-I%SML6@4`4@.%(!Y640:$B10H5413M]W\KTV3-_)??6OO`
M<22#QOUA]H_!1-<U79M2:!=+R[;L50\`1CL8XC8.`?@`P-IQ/=?;=@!OA!#P
M/#_:^0$&>*`Y!G\?A$%XZ,#L`D$0)3$ZD1$"QRA.XN3<+S7Q4DF6Q_(U96<O
M:99G^8T]IBBJ>B]*!L6SK,JJ9E"]ZJ9NOA1H/V`'%AOR[AYZ`````$E%3D2N
M0F""````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&]R9&4M<&]W97(Q+G!N9P``
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S0V`#$P-#$W,S8S,#$U`#`R
M,C4S-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````5````!\(`@```/:6?3D````)<$A9<P``
M+B,``"XC`7BE/W8```N8241!5'C:Y5EK5%-7%C[WE<?-XQ(2'DE57@K(8Y84
MBJ%HIHY6$>6A*%01""H5.Q8LE:ZQ:+4QTEH$5,J@$)W5Q[@Z=81J18T=09=4
MD>I81[!8;85!$!0D&"`AKSL_CG.)(3YFN6;6M.Z5'S?[?&>?\YV]SS[[W`O`
M<RP(`("FZ>>1.8*@3P3MV;/'V]O;Q<5%*I4:C<9?$_\GDZ\]L9\MZG[[8Q>3
MV;1FS1J'UH:&AHJ*BO\W5N7EY<SS8Z;W9/*&$9W79$P6,#QMS@M:K=:^Z;//
M/ENP,"X_?]W,F3-[>GJ><<97KERY<N4*$UR-C8U0"0"`QJ]=NV8T&HU&(U2V
MM;5U='2TM;7!IH&!`=CQXL6+)TZ<8,P>/W[\XL6+C*F!@0'8!0"`/W%.)K.1
MQ`$`(&X5?>K(_9*2DKR\/`"`2J4JV;'MU50B;)I8O?SLA@T;JJJJGH7\A@T;
M9#)9>WM[=75U1D8&15&EI:4>'AZAH:&'#Q\N*"A0J]5[]^Y=M6H515$410$`
M.CHZXN/CV]O;;]RXH=/I/OC@@VW;MI$D.3P\S)C5Z730^21)AH:&MK2TA(>'
M>WM[._%\;FYN0T.#O<9B->,$``"@9&_0%*E*I9HZ=6I,3$SIS@\7KF'%I+,X
M/,#E<!8O7OSLX5I142$4"K___ONAH:'*RLJAH:&,C(R:FAH>CZ=2J29/GEQ7
M5V<RF2B*8K/9`(#DY.3,S,Q+ERY1%.7IZ=G?WZ_3Z2HK*TF29&RZN+AH-)J>
MGIZLK"RM5MO1T9&6EN8D[!.27]Z[KS(A(2$D)$2M5AN-QK5KUUZ[TBV68@``
MFK:FOV^,6R'`A+=^;#NK?(\='4<``([N!1*)^^S9LY^=?&IJ*@!`+I?+9+)%
MBQ;)9++P\'"2)//S\]EL=GIZ>FQL+(O%NG/G3G1T---++I=W=741!*%0*,1B
M<4I*BKWG]7I]2DI*<'!P:&@H`"`X.-C)4;=;\U'!AH*WRH28U;5VG_F'B_<)
M%H80@_.6LR/GL+!'[`_+"%&P<#C[]=^KU>IG9)Z0D'#HT*'_7A9L;&PL+2W=
MMFT;C/F'CCJIIQ_)QULOF-S]!C*W#F^MYB]8@^3N)*/FC3*WF!TM7J[CV"R(
M4^8\'H_%8I$DZ;"/'B6K5Z]^QGP)1^3S^3"WC9V/2J6"S!T37L+\I+MWN]87
MO,T3HI&SV01IC)@-`,```,9!XJ@&7/^'<<1@)86T?SB8^1J+)T0``-ZA5IJV
MKEV[=L>.'0Z#C8R,6*U6J]4Z.#CX-+./B8EY%O(FDPF.:+/93";36``,>WMY
M*)I79K[9?NOZGHK=?!<D*)(%E;=_<-V>V^4JDB@4KTZ<./&GGWXZ>^9TTXFN
MU[>2$P)P\;CAI-62JIU5]?7U;#:;R^6*1**Y<^>N6K4*01`8701!_`_.=@S#
MX(@HBCYE%R?E[?Q%X3?:FM\NIU`46`?=WUEP*S(RTO[D!`#$SHN]U%SW!PV?
M[X(B"%:W'[W383&-`).1[FXW6XW"]O9V@B`L%@N.X\W-S5Y>7D-#0V*Q^%'S
M,!J-3P3`DQS'<0=87U\?C\<;&1F12"06BX4@B'/GSH6'A]L#V&PVG\]W*&^=
MY#$;>G_\)`Q%`8)@GV]%1"*1`W,`P-':HX'!$TY^V9_P.I>FK3.66$='ZN*J
MT_J9OS1-Q\7%]?7U6:U6BJ*BHJ*^^.(+>U.[=NVJJJKJZNJR6"P414V=.O7`
M@0/V@+*R,HU&<^O6+8O%`@!@L]EGSIP)"`@``"Q9LN3LV;,#`P,8ADDDDK&7
ME&7+EC4T-.AT.A1%I5)I:FKJN^^^^Q""MI.2DA*I%S=SHT#3Y/;IA4!/3\\5
M*U;0SN2--]X(>)&L;'33-#WXE=6YI>:Y3_"C/#P\:)K&<><GA)^?7W=W-S2R
M=.G2L9O"Q\>GL[,3`I1*I0,`P["6EA:]7C]QXD2G]@F":&EI,1@,<($>VN0X
MGIB8""V/DC>;S5E961,#I#(O[OSE@AW?B#5-;I\WA4DDDN+B8J?D=^_>[>5/
M5C1(-$UN92<]8E[SE+@+QX\?OVS9LM[>WK'DX8:$$A$10=-T45&1/<8>,&7*
M%)JF=^W:Y0!`$(3#X>CU>KE<[K0C)*_3Z10*A5,`BJ(;-VZ$Y!^8#@CUM"%#
MD3%$5"PI$*'_CG\#CN.MK:U.%_CJU:L<'L!P!`#P]Q/<LT?OY>;FJE2JL4B!
M0!`7%R>52FMJ:G[^^6<`P.7+E^OKZRLK*V$D\WB\^?/GCQ\__M"A0]>O7P<`
M-#<WGSQY<L^>/1!`DF1L;"RL3X1"X>G3IV&Y#@#P]?5=L&#![=NWO_[Z:[U>
M#ZE65U<W-34Q<92<G-S3TU-34S,P,&"SV3[YY)/1>=(T[3$!+SSHR@0P_.W[
M3OKR*\&^OKY./1\4ZAVKY$-D]*LO1$9&.@"@TQ`$R<O+8Y0BD0@.FI24!.MS
M!$&RL[,9@*NK*P3$Q\=#,((@65E9]I;3T],AAJ(HL]D,E?GY^3#/<SB<Y.1D
M9MTO7+@`,3DY.0P`>OZ!DUU=J4_5ED^WT'_93G_U1[KQF`D`8*,M:05(;V]O
M7%R<@S.3DI+Z^F_/3&$#`&@::?_1P./QG%\;430A(8'YRW"[=^\>]"J*HLQ<
M`0#N[NY,BF8`"Q<N=$CO\$$BD3#[0JE40FX(@C`WO.'AX>G3IPN%0I(DJZJJ
M(&=H=C3LLS/?.W+DB/ZN_K[1:#*9OJV]@;/HB)EL@NK)W2[;N>Y40$#`K%FS
M@H*"6EM;3]9I>W7_S%)S*3$<C%Z<PZW:='[SYLV;-V]V>DK9)]>Q`+/9_/@#
MV>$EBL,F9XJ<L0"KU6HP&!R0S$GY@'Q.3DY.3L[HW6Y=9K5FO_=D7"+#O*;T
MJ0X(#^\>./:W_5_56GE"X/<BLG(IGY*,UA+!TTV+<ZCMQ=M]?'PR,C+^T_K$
M/I\[)>8@3E>0Q6(QSU:KE8D[!$$8/((@(I%HRY8MC[O/[]S^IZ\.?WGSJD4B
MPP``?)%YZ7I`VPBS&2>(T0O!_;NLMM:1P)<`BX-$)UKT]P1Y>6^YNKJ.W29.
M"S(,PP``-INMOKY^QHP94-_?_Z!&X'*YC^K+;#$FO`$`6JW69K-!P@*!@$$6
M%Q>S6"R;S6:SV3@<3E)2$H?#>=R;G(]VKD-Q2T@4ZZ%@0P&+_8`Y;4._J^6K
MTP?_7&A5IXU4[[+=[;1%QF`&H^':M6M/XVVA4.CFY@;=6%Y>7EA8>/SX\:BH
M*/C2!L.PZ=.G,PYTD/CX>+AP?7U]$1$1M;6U145%A86%D+Q()$I+2X.Y8'!P
ML+*RTL?'9\Z<.7/GSDU)26&8.RERH$3-DL6DD9HF-TV3^SNEOYD4XC)SD3CK
M?<G'IR0PO:?E!O%X/*52V=O;NW[]^L#`0#=/BB_D*A0*AVR/89A6JV64OKZ^
M<-#DY.1-FS8Q08ZBJ/V1[N?GU]O;"YV/85A-38W##/W]_>V#R+Z>7[ER)4W3
M04%!]@""(`B""`L+8RPX)__M^1/>@>RM?W7=]YUT>5X8C\>;-FU:6%B8V$VP
M(/O!V?9*K%](2(A]+ZU6JU0J#08#HX'.05'TV+%CC-+'QP<..F_>/)JF%0K%
MV$TND4C.G#G3W=T-MS&*H@</'G28Y/GSYST\/,:^C9;+Y1!PZ=(E3T]/!X"_
MO_\3R+_YEI(28Q]6>R8N#>?Q>+FYN5!?7%PL\V:7U4DT36XO_\[7?A6="I?+
MQ7&<R^6>/GV:408&!N(XCN-X4E(2U&1G9\MD,@Z'0Q`$15%RN;REI86FZ=;6
M5H%`@.,XA\.Q7SY&;MZ\&1T=+1*)"(+@<#@RF<RA$N_L[%0H%!``!X6%X^/(
M=W9VSI@EYPM(BJ)*2DKLFWS\Q:GO\#5-;B]-\V76^!<JSK.]3":K^^9<45'1
MI$F3$A,3[9M^&QU[ZO"!4#G1U:X/F.3]:_AP\?2K93`8I%(I15'CQHTK*BKZ
MI7O^N?Y6]SQ_I`7_`J?OX0^;\I+2`````$E%3D2N0F""````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]H;W)D92UP;W=E<C(N<&YG````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#0R-34`,3`T,3<S-C,P,34`,#(R-3(W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(```!4````'P@"````]I9].0````EP2%ES```N(P``+B,!>*4_=@``"%])
M1$%4>-KM6'M,5-D9_^YCAN'"S'6&09`*#"(8Q[<09#89C61;!>6A&$!!E]::
MP)K82FI*NM(8K=A($&5U&W',:@Q)DR;B8TTT%1$?+24S8051'ETA78W#,@S@
M#/.Z<\_TCX.WXYT!Q:0;&OKE_G'ON;_O._=WOL?]S@&8PT(`@,_GFXO,"8*<
MRYXG`6#%BA5SEWQ?7]^U:]?F*'F/QU-;6SM'R0-`9V?GX.#@AZL]>/"@M[=W
MJK=A86%2J91AF$>/'OT('+JZNO",X>'A75U=,R,?II"\>?.FLK+R`W7JZNJR
MLK)T.MWAPX>#`MQN-\=Q;K?;;K?_".0]'@^>T>5R>3R>F2E_6C`/`-1JM<UF
M\[U/*BHJ9#+9Y,J19$I*RL#`@`A#TS0`4!1U]^Y=WW]?.CHZ\(P2B<1H-'Z@
MUB3YHW]6TC0)`*6EI=,K;-FRA:(H`(A/#DO9H,#J2J6RMK8VD#Q-TST]/4ZG
MTV*Q3&/S0P!FL]EL-@?"+!:+T^D<&QN;BKS%8IG*HY/D#>V1JSY1`,#"A0NG
M^0B=3H?Q2U/D]<UJ0WOD+WZO9,(E`""3R0P&0Z#GDY*25"H5R[)Q<7&%A84B
M@V?.G%F^?+E*I5(H%+&QL3MV[!`!ZNOK5ZY<B0$*A2(R,K*GIP>_*BHJBHN+
M8UE6I5(E)R=CE_B3+RXNCH^/9UE6J51JM=KCQX]/2?[@&14.XY,G3P;2MMEL
M6JT6@W6;V3\]4AO:(_&5LU<!`*&AH:VMK2+R@9*8F&@VFS%FUZY=$HE$!$A(
M2'CUZA4&E):6B@`4175W=]MLML6+%P>U+Y%(NKN[G4[GDB5+1*]HFL[+RPM.
MON'OD0L7A0&`5JL5,>_IZ8F/C\?]X([/50)M0WMD0UMD;%(H`*Q>O3HP[/T;
M2>$^-375Y_/5U-3X8_P!V%1]?;T(0!"$3":SV6SIZ>E!%3'YL;&Q]>O7!P60
M)%E55>5/?G("DH*?EDB^/@K/GS]7*!0LR\;$Q&S8L&'-FC4'#QX<&AJB:7+/
M[]A/ME+^D_5_RW_?[R1)LK"P,*@KY')Y=G;V@@4+FIJ:7KQX`0!/GCQI:6EI
M:&CP>KWXI[AUZ];8V-CKUZ_W]_<#P-.G3YN;F\^?/X\!#,-D964M6[8,`!0*
M16MKJ\EDPL87+5JT;=NVUZ]?W[QYTV:S8:I7KUYM;V\7XJB@H&!H:*BIJ6E\
M?!PA=/GRY:-'C[[SB=B-7SU4_R0A5.0QG$LAH?2O3RO]?8XOW:9Y`!`='1VT
MVA,$45%1(0PJE4IL-C\_GV59#"@K*Q,`*I4*`W)R<C"8((A]^_;Y6]ZS9P_&
ML"S+<1P>/'3H$$F2N/04%!0(ZVXT&C'FP($#`B"(YP%`&D+\UA`V-APZ^H/O
M93_T&5%_E\-AYQ1*Z:_JPN.UE,BKXQ;T[<,)`,C(R`C>0I!D;FZN\*A2J49'
M1P'`:K5BKY(D*7PK`,R?/]]JM0+`R,B(`-B^?;N_S9&1$7RC5JN%O"@M+:VK
MJT,($00Q/CZ.!QT.AUZO%Q0Q6VSV/X7`_X&1$XR<BED$R])ATVYPV"3/_\''
M+"87:()L_HQ_14X'Q[+LJ5.GINH@7"Z7:'J1<!PW?0_B;R$PR84F)Q#`\[S3
MZ10A(R(BIB0O$D9.I'P:'(`0/+SAP3O"J*BHCV[._.MY4&(B";J"4JE4N.=Y
M7H@[@B`$/$$02J7RV+%C'TI^&OGG$_[E=Q,T39>5E<U4EZ(H7$H00BTM+1LW
M;L3C."GPCW.:7<-DTKT-;P"X<^<.0@@3ELOE`K*VME8JE2*$$$(RF2P_/U_H
M3=_9V,Q4'EU'`!`;&UM<7#Q37=RN8#>>.W>NNKKZ]NW;.IUN:&@(+XU>KQ<<
M*)*<G!R\<",C(ZFIJ;=NW:JIJ:FNKL;DE4KE[MV[<2VPV^T-#0T)"0F;-FW*
MS,PL+"P4,?](\F/#R-1B!X"TM+2/4*=INJ2D!`>YU6JMJJK*SLYN:VO#(:K1
M:/;OWS_5R5IQ<7%B8B)>.)/)E)N;6UE9:;%8\-O-FS?GY>4E)R=C@-%HS,C(
MT&@T&HTFZ*>2`##\BN\S>9_^S=MK\@Y]SWL][SG2(RD(D],`\/CQ8U%!\L],
MG\^''2)*UXF)B2-'CNCU>LP?(2048;5:?>G2):_7BSTOLH#ERI4K0I7A>1X#
M"()(3T^_<.$"`#0V-D9'1PL`CN,XCIN8F`CB!@#X(G\4(=_;.D'(YTFT:8P^
MCTQ:0P6M00H56?9'IJ:,>_GR9596UKU[]P(K$,=Q$HF$81AA,"0D!`<D#K_6
MUM;R\O(;-VY8K5:>YQF&6;ITZ<6+%[5:;6]O;TA("$*(IFE_"UC2TM+:VMI*
M2DJ>/7MFM]LIBE*I5)F9F0:#0>@132;3SIT[N[JZ['8[7O1`.Y.GMQ1%R60R
MFJ810@Z'0\BWQ<O#"RLD"<N#%\4[5[Q_^7)4*I6>/GVZO+S\?_'TEL#5<M6J
M53*9S.OU=G9V-C8VWK]_?W!PD.=YBB;S/U?\K$02J,Q[X?AGCG_U3\3$Q.S=
MNY=AF*BH*(U&HU:KY7)Y:&@HR[*!-6;6D0]:7>KKZT^<.&$VFP%@Z\_GY94'
MX?_D`??E;\;>.0DG29(D:9JF:5KR5B(B(IJ;FT4-QJPFCV7=NG5XG_#9%TI]
M+AWH_*^/N+[KY+U>WNU"'C>/D,^'Q`9)DCQ[]NQL2XWWDP>`M6O7=G1TR!C)
MX<ORZ'@J2+?'`\_[$`^\%]PN<-J0VPENI\_M`(?=U_25R_J#*S<W=[:=CA,$
M\?X.KZ6E)2DI:7AX^)L+Z)=_H(+^^4B*>-L1@S+R'4R?D7CXC6M@8&#V'EU/
M(RS+%A45`8#IOFWX%3_3"6*73#8S\'^95?)O<FN[C<*T[-T`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H;W)D92UP;W=E<C,N<&YG````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8T-#4`,3`T,3<S-C,P,38`,#(R-3,T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(```!4````'P@"````]I9].0````EP2%ES```N(P``
M+B,!>*4_=@``#-=)1$%4>-KE66MT5%66WN?<<Q_UKCQ("`FD"'F8%"%T0F`M
M&`3L7BVX6@)M-_0,KA[^Z%)Q=*UA'!#'Z:6NH7M$H<'(0X4&!18S(#["`!F@
M-8(/D$XF2`)YF!<D(:^J5-6MNK?N<WZ<4)0Q0$7I7WU^9-4]V>><^^U]]M[?
MWA?@;W@@`'C\\<<=;NN<GQ6YDFT_?L=P4`KZ(^&0+(6CAFX``,L1JUVPNRWN
M%#MAF40VZ>_V7SAS)2JK&./2TM+''GOLWB-'B-!?H>%([6?-Y8ONL[LL/VPO
M73/Z>_P][8.^@9`D1E5%&W628.7L+DMZ5G+&E&3GW;2<EIE46)I=_V6K81B7
M+U\^?_[\G#ES[CE^!@`6+ERH*(H4CH9#<GJF.T'CQ(_>SJ&Z<RUMC;V^_F!4
M4JG!*6:$$/VMJ7HD)/=W^WL[AR+AJ"O9QG+D#GNZ4NR2J`9]85W7^_KZRLO+
M.8Z[A\A?>NDE!``U-37OO_^^+,L`D)V?/G->WICX$4((88PP?31-TS!U65(:
M+W9T-M_0-8/*\#R?E)24G)SL<KDL%HNNZZ(H#@\/#PT-!8-!7=?I<H?;ZBV?
MFCDU]0[O%QJ6OCY]58HH&..*BHJ%"Q?>VVN/*(P//OC@S)DSJJH"0%YQUO0Y
M.1BC4:(,9CG"$X9%")FFJ1EJ<#CX=<V5WJY!TS010G:[/2\O;_GRY6EI:6.>
M5U-3\]EGG_7U]=&#",MX9WERO)FCSKKEDYCM;1_NN-J/`#D<#H?#(<NRIFD\
MSPN"(`@"R[(<QPF"P'$<(81E64*(W6[/R<D9!W@`.'#@P.>??TXM,WUV3L',
MR?&B&#,":W58DRR<#6-L&$8P&#AWYF);2Y>B*(20_/S\U:M7.YW.NY[ZR2>?
MG#Y]>G!PD#Y.GSVU8.:4,1P2$X&S"HS]1GM(4PQ557T^7W=WM\_G4U65OC-U
M*X9A$$(88_J7Y_DE2Y;<?__]B08\`%BU:E4@$&AH:-`T[4IM!\N3G,*,6^`1
M)@QKX6P_G[\L$`C:[;8WWMRJ2`8AA!"R8,&"BHJ*!._;HD6+RLK*MF_?WM75
M91A&4]TUJUV8G)OV?1<C#(<1^^03:X*!H,OE^OT??F^U6@.!@*;=BJ:F:=)'
MJ@X`"(?#ER]?OBMX`/A.R'GJJ:=>>>65Z]>OZYKAZPO$@P<`A#"#27_?@"1)
M4D221$40!+?;O7CQXMFS9X_+WYQ.Y_KUZ[=MV];6UF::9E/=]=3T)+O+8IHT
M<&"$$&$(80ACDL&!04F2=%V;FC\I)4N8[$N6H[*NZIJJ:XJN:IJJ:$I4U51=
MBD0#0R(`^'R^1%YC=+RE6L089>=/'),6L"R1)""$"(*0DI*R8,&"DI*2'Q9R
MGGSRR8,'#W9W=P/`C39Q^IP4W=`1`,8,Q@QA6)ZU8IV,G,BR-H>%=R4[4G@P
M`6&,``&`;NBJIFJJHJIJ*!@^=^*;J*2(HCAN\%]]]=7P\#``N%/MR6EC>:]Y
MZUJFI*04%A9Z/)X[)7]=5U55$(0Q_\NR[/+ER\^>/1L.ATW3`%EPNCF$,&%8
M@EG#,'E.X!@!8WPS"C"$M1*&93`AF-5U'2&,L*EJ2E259"7"6SB[TZ+(JBS+
M#0T-7J]W'.";FYL510&`U`PW0_"8"\R;%Z2RLK*EI462)(_'LVS9LB>>>&*4
M'G?MVE575R=)4G9V=D5%Q9HU:^(%SI\__]9;;]76UHJBB!!RN5R;MVYRV5(Q
MPO][XL_'CU5_V]IF$03O]")%42D5)0PG"!P@.%/]Z;&/3[8V?\OQ7&E9R2]7
M5$S+]Q`F($J0DN[V]0<U36MK:QL?^/[^?L,P`,"99+WM"A,`0);EPX</TXFF
MIJ;JZNI3IT[MW[_?8K$`P.[=N]>N71L(!&(Z/77J5'5U]:%#AZQ6*P"\]]Y[
MSSSS#+UE=`B"P!$+8W(OK/_=_GT'8_,7SE^,_>8YGB/"OZW_W9YW]L4F__)U
M[7\=/+)QT\L/_F*1;FA.IQUCK.MZ(F[_'?-2G@,`-H?E-M?8N'7U1U+@R`Y'
MCQ[=L&$#->FSSSX;0QX3J*JJ>NZYYP"@MK9VS9HU,>0T7SB=3JO%LJ/RG1CR
MV,+8L%BL>][>%T,>$P@&0__R[/.7_M+D[Y&&^\,88],T_7[_.,!_^NFG](58
MCA&LW&T(O'XSH<"T:=/V[-E3557UR"./T)D]>_;T]O9NV[8M'`X#@,?CV;U[
M][%CQU:N7$D%WGWWW9Z>GAT[=H1"(0"8,F7*SIT[3YX\>>3(D2U;MO3W#^S:
M^1:5_/M5*S\X=GCO_G?N*RP8T1'+=G?W;*_<21]_\P\K_J?ZHT.']Y?,G$'-
MMJMR=V!0CDHZ3?@\SR<4\`X=.M38V.CW^V\2+W([AZ<<EIIKRY8M#S_\,``\
M]-!#)24EERY="@:#QX\?KZ^O!P"&85Y[[36JER5+EK2TM%#W_O###R]>O$CM
MMFG3IA4K5E!WNW#A0EU=G=_G!X"?E,[<],?_4'4%(YR<FORKI2L51>4XMK[N
MF]Z>&P!0Y"W<^)^O6*U61=;6K5OWC[]=K:IJ?7T](<1JM69E965G9R>:YVMJ
M:JBK`P!O8;.F3>!X=DQI31MAYAS'E965Q>9S<W,O7;H$`'U]?=3L/,_'UV%%
M146UM;4`T-O;2\W.\WR,'1!"1%$<&AJBCX5%!8HF1Z(B@YF\@AQ!$!1%Q0@'
M`@'*9#H[NA;,^YFAZZ8)""'*2D51]'@\,V;,F#1I4B)F'P%O&`9"8+4+F3D3
MIMZ7<8>JUC1N.3S-"_'L8'09%\?#8O5,O$!L!X30:-*F:ZH6-3#!^E@M@W"8
MJCA^S)@Q8[R,@P#`A$GNC"DIDSRI-J=P%SX<5X'$Z.1H!=V<)^16*F$8Y@ZK
M-$W3=3UV^S#&#&8(PV+,8$2HL@S3E,+1&$&@&]+=,,9>K[>RLG*\+(L`P+S%
MQ;=S\M'%!F%BMAH3!B&$9CM%49J:FK*RLNA\9V?G2"7K<'Q_(:U5Z$(`Z&CO
MY%D+I?==;=V2+-,\QW,CMO%X/'OW[K7;[2S+&H9!",G-S8WI-_&!`2!!Y`!`
MR*UB/G:3XX?;[2XN+J;&7+MV[;ESY[JZNM:M6_?%%U\`@,5BF3=O'@VK\:.S
MLU-1E-S<7(O5`@!??G%^Z^O;0P&YH_7ZAG_]=R6J`$!^05Y969G#X0"`MK:V
MHT>/IJ>G>SR>G)R<_/S\'X!\=)Z_.WB6H0Z+$(KW^7C+/_WTTS0#U]?7/_#`
M`T5%1:^^^BK5U-*E2\O+R[\/OKV]/1*).)V.Y;]<1F/0IC]LGC=KX8,__<7G
MY[ZD,K_^]:\<#@>M'75=?_WUUW-R<B9.G#AQXL11Y/*O!1YC3".3JJJQX!P?
MSP*!P/SY\U]XX05J"E558Y%IUJQ96[=N-0R#:BWFY*(H=G1TA$(A,1+ZYW7_
MM'#12(H219':'&.\X<5UA46%@X.#JU>OGC]_/A6(1"+!8#`8#"98P]V]JKO#
M,$U#-[34U%2_?]AFLPT,#$0B$4I7;3:;S6:+!;F77W[9Z_7NVK6KH:%!EN7,
MS,S%BQ>_^.*+24E)P\/#;K=;EF6KU4J%/_KH(U$4.8Z35-'B8';\Z8\']O[W
M\:J3[>V=`L^7S"Q>M?HW9>4_J?_Z:B@@9F1D'#]^?./&C5555=>N7:.6H+[P
M`UO7U1</)&#SD4X.QUAN=/I]`P&_WY^6EK9TZ=(?TTCS^7R;-V\>&AIB&.;O
M'BSQY$ZV\':."(0A"&$`TS`,55>ZNVY</'M9DN2"@H)''WWT'K>N$S&[HD5#
M$3]A1`6'OVUK%4/AUM96M]N=")>Z7<&[;]\^G\]GFF9*NC,YPRY%156+,@R+
M$8ZUV'1#:[[2VM?73[L@]["'20"@]9OKE-(2EB$LPQ#,$(87V'B&;YJF;JBR
MJF,-LW807'"MRZ_K^L<??SR*S"4^WG[[[=;65L,P.)Y,G^,!9&J&JAL:TJ(Q
M(F2:9M`?;F^]'HU&&8:Y]^#KO_P68X0PPAAC!F.,,(.L-F'V3PM'X3=-W0`=
M`*9Z)_;W^@9[`Z(H'CER1-?UN7/GCNO@-]YXX\J5*X9AF*9Y7VFV*\4^<@28
M8!K?N9\,"!96#$1T73]QXD1F9F9>7MX]^VA15E9FFF`:IJ$;NJ9KJJY&M8@H
MVQS"V/T<`$*8I`G.@1Y_5%*CT>C5JU=[>GJ\7F\\J[O=:&QL?//--]O;VVFT
M+Y@YN:!D2LS48S1\.)(TP3'0,QR555F6FYN;2TM+8XSHQWZTV+%CAZ(HJJIJ
MFJ8H2C0:'1H:,@S#F62=MV2&U7[;(B'HC_S?N9:!WF$:/UPN5W%Q\=RY<\=L
MFP>#P8:&AK-GSW9W=]/&`4*HJ"P[?^:4,?OVHT-C?_"KTXV2&`6`C(R,YY]_
M/L'JY0X![V_Y(RW\/X]%/&2Z+[JO`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&]R9&4N<&YG````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,34R`#$P-#$W,S8S,#$V`#`R,3,P
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(!@```!_S_V$````&8DM'1`#_`/\`
M_Z"]IY,````)<$A9<P``+B,``"XC`7BE/W8````'=$E-10?4#!4/-SJZ&X".
M```!]TE$0508TZ6336@301B&G]UN_DA7T8,5&NI!\R/!0P)"+)I$L+WX>_!0
M`C966MJ*X$TH$F^"VD,1"8@WH:"'@"V$%J%@2W(P%!1MA5BH$+7Q4!4KAF23
MS8Z'0$-D4Y"^MYEOYN'C>V8D0+"+*``G(FY&AVX3"H7^Z[+/YT,&&+S[BV>I
M)Z:'BL4BFJ:UA<@`!UPRMH/O*!0*+<5<+D=B\A(W$WTL+BVV!U0KT'O.QJ/D
MP^U".IUF>OXZ8P_L7!BO,S<WVWX&-4W0U=/!/G^&&Q-GH-)-YZ%5KDPXL=A@
M>4$C/CB\`Z#:$-$?<Z#7-$J_UW'N<6(8@JU-**[TX!_QMP?8'-+VAM4N(<L2
M>DU@M4NLYC0BH<L[:UQZ4>'KFHP0X'(;!$];<>Z5J=<%^[MDWF9>$R-F"I``
MD4PF"8?#`&2S69[/3M$_\AW7$07%`O-/RTC%\W@\1U%5%555"0:#!`*!!B"?
MS[>VI2A<&S_+0.('CDZ)F@8;ZSKEDJ!:$92V##;?]S*3>MG0^&]T72<^<(OE
M!0V+3:)#@</'+`0B5DY=M'.\S\Z7;Q^:[\`LT6B4C8\*PFBLC;K@\YK.]/T_
MS-QS,WKU3G.(IL.1)(1HFGF5*O-SY21#\3&\7F^K!;-D,AFZ/74Z%`O5BN#3
M&R>/)Z?,+>SF._\%"X6J_@P6--P`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6YF;RYP;F<`````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4S`#$P-#$W,S8S,#$V
M`#`R,3$T,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-
M00``V.OU'!2J````(&-(4DT``&V8``!SC@``U,\``'L/``!X]@``R_(``#*,
M```C34@19+(```,`4$Q410```/___^CGZ.#?X-C7V):5EM_?X-?7V.?HZ-?8
MV)66EM?8U]C8U]#0SY:6E>CGY]#/SY:5E?#P\.CHZ.#@X-C8V-?7U["PL*"@
MH):6EGY^?FUM;6QL;/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````,NY=+,````>=%).4___________________
M____________________`.P8'%X````)<$A9<P``"Q(```L2`=+=?OP```!K
M241!5"C/?8_)#H`P"$11JZV[MBZ@[?__IN"AJ9KXPNG-0`+`ARS%BK`IMP!`
M'FL1HQ`2\5GQ#,<8&Q[1/QLB_ANO&\;ESN1N=(*(A08J:29JAJ)B4>MMTYU:
ME5)KJP'",>V1_F01TM=#N``.&`S4"P>29P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]I;F9O7VEC;VXN<&YG````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$P,#$`,3`T,3<S-C,P,38`,#(R,30P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```,!03%1%````#!,:%!LC%1LC'",K(SA-,D9<
M+TMG,$MG,T]L-$]L-5)P.59T1%AL/5IX0%MX2EIM0EY\1F*`2F:$2V:#3FJ(
M56V'4V^-5&^,5W.16W>597:)7WB28'B17WN98W^=9W^::(.A;(>E;H>A=X:6
M?8J8@9:M@)BSAYNNEJB]F*J]F:S`G*R]HK+#I;3&IK7(L+W.____________
M________________________________________________IG<K>P```$!T
M4DY3________________________________________________________
M____________________________`,)[L40````!8DM'1#\^8S!U````"7!(
M67,```!(````2`!&R6L^````CDE$0508TW6/5P[",!!$AQ*:3>B$A!)Z"75.
MD/O?BMV-*$)B/BR]MV-YC?PG*$[+1V";G4_[-EZB>C^L5^DBF50*@8<PF<31
M4"G'5.=D'(T&-:C(K*_<[YBX"9,4[H4FKCHGE;V)B_9)Y9:)W4;ND\(N@#U[
M7`J3WC50+%:>S[3OZJ7WZMUQZ)L!_G_N.T^&#27#0)73^P````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]K97EB;V%R9"YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`T,#$`,3`T,3<S-C,P,38`,#(R,#`P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`0#````[=WB4@```!Y03%1%``````#__P``@("`H*"@
M_\#`W-S<P/______````:ZQ_]0````%T4DY3`$#FV&8````!8DM'1`"(!1U(
M````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$Q(KE=A-Z@```%Q)
M1$%4>-IC8&#@G`D"#$"&NH2&4"6((52AH2[)`!:?6M'),%&PHTEIDI(FA#$]
M`BHRHPBJ!J1]1AH8>#),:P$#(,,%!#R`C`X/(.B`B;B`U'0``5!J"D3$$FX.
M`.IO,6]W<W?K`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;&%Y;W5T+G!N9P``````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P-#<R`#$P-#$W,S8S,#$V`#`R,34R-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```!.4$Q410```*">E[>UL+BVL>3`0>7!1,7$P.G+8NO0
M<NS1=>[7A]?6U.[8B]C7U=G8UMK9U]O:V-S;V=[=V_/CJO3EL?3EL^SLZ^WM
M[/+R\0```'&<)Q,````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$@``"Q(!TMU^_`````=T24U%!]0,"!(=.F/]\\<```!E241!5'C:=<WA
M"H`@#$91TTK-FI6F[?U?-)7!L.C[M\O@".PG!([&&+OBG7+.9PTFQA@T)N<V
MD!2N$G*Y0?4?WK=@0YG&`\#O+2QU$\Y2*374\&')8Y8\9LECECQFR6.6O'_V
MO0?4/0\G9KL#,@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQH86YD+G!N
M9P``````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q-``Q,#0Q
M-S,V,S`Q-@`P,C$R-S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```"$````.!`,```!3,&B_
M````&%!,5$7____`P,"_O[^`@(```/\``(````````!:[7A3`````G123E/_
M`.6W,$H````!8DM'1`9A9KA]````"7!(67,```!(````2`!&R6L^````?TE$
M050H4UW/00K%(`P$T.`)=..ZI)`+%#R!WD#WUL+<_PB-3=O_Z6PBCX$8"I]X
ML@G-OP!$Y/97(KBKD.@+4$%WXF1H"<@Y>XKDUL%#EMDR8=&NE4P"]A!)9HF3
MR;6L.S"OJ91RRX2#MU1KO25BD6,#6FN/T(00?_)<83_\Q)\@*B3M:R;'A@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L;V-K960N<&YG````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S,#8`,3`T,3<S-C,P,38`,#(Q
M-#0V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```0Y03%1%````
M!`,"!00#"`@("0D)"PL'$Q$.&A,+%A86'!P<(!T<'AX>+RDA*RLK+2TM+BXN
M.#@X34U-@5HK<G)RJF\KI'$V>GIZK'$NK7,RH'=$HWM+A(2$I'Y.J(%,M'X^
MIX)2IX)3N(`^JH15JX=8K(=8NH1"JXA8NH9'O(=&O(A)NHE+KXU>K8UDO(I,
ML(U?O8Q.I9%VOHU0FY>4QI9=QYMDJ*.>RI]HJJJJRZ1QSJ1PS:9NS:9VT*9T
MS*=[T*ATSZM\L;&QSZQ[S:R#SJV#U*QYU:Y^TK*)U;*$V+6,O+R\OKZ^UKJ4
MP,#`P<#`PL+"VKZ:X,*>X<*<X,2@W\2CX<2@XL6AX\:BTM+2V]O;````>T!(
M'@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`
MFIP8````!W1)344'U`P4$BP$?@X!^0```(QT15AT0V]M;65N=`!-96YU+7-I
M>F5D(&EC;VX*/3T]/3T]/3T]/0H**&,I(#(P,#,@2F%K=6(@)VII;6UA8R<@
M4W1E:6YE<BP@"FAT='`Z+R]J:6UM86,N;75S:6-H86QL+F-Z"@IC<F5A=&5D
M('=I=&@@=&AE($=)35`L"FAT='`Z+R]W=W<N9VEM<"YO<F=GBL='````F4E$
M051XVF-@P`XB@0")RRT6'A'A*<P,%Y#V$N#D%'20AO'Y_%A`%+\Y3!>O#YC%
MX0L38#/B8F5D9.(Q98?:8!`4'.SO[^]M+011$AGJ8:8B+Z\@I2D.%0ASU7.W
MMW>TT!"!"H38F"C)R,A(JL)4!%KJN#DY.=LJ2D`%`ERLM)65U60UY*`"=L:&
MAEI:^KKJHI$(GT$`-G\#``#B'1>*I_]=`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L;V=I;BYP;F<`````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-C(`,3`T,3<S-C,P
M,38`,#(Q,S(R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```,!0
M3%1%(2$AZM3+X\6ZV[2D[M[7^O?U\N7ATJR9````C9Y\S=G"WN;7VN+1FZV)
MMY."<'UCM,:BK,"88VY7JXIZY.G=97%8Q)^-P]&U@(]P3%1"6&-.YNO@U-W)
MRM>^D*%_7VI34UQ)Z>WD86U6J+R5?(MN3%1#ML*J7FE3________________
M____________________________________________________________
M____________________%^1TEP```$!T4DY3________________________
M____________________________________________________________
M`,)[L40````!8DM'1#\^8S!U````"7!(67,```!(````2`!&R6L^````?TE$
M050HSVV/21+",`P$)Q&@P0&#3-CW_1GZ_Z\X.%29%'V:ZE,/O`>*"90"J&H!
M"C$8CFKM!#.5J"*+<6@F4XI(S,(YFUNBB"X`=R?;8,M$T14<3K9A;9OMCC$"
M#NX/1[/3F1=V';R:V8U.?DO9W!]/ENE\)?Y^X;LGG'_?9C[CZR@-,)>5\P``
M``!)14Y$KD)@@@``````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;&]G;W5T+G!N9P``````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S0W`#$P-#$W,S8S,#$V`#`R,34R-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,```#`4$Q410````X1#!<=
M%1TE&R`I&BHU)C$]+#1!+SE',T)4/4E<0E%43UM;6D]D2%-I3%Q@66QL:GEY
M=V"!2(@``)D``)DY*:(2#+`6"K$;$*H_++%--K-3/L@^*]]"'N1B1>=U6XV-
MBYF9F*BHIKBXML#`O<G)Q]#0S=75TN#@WN+BX```````````````````````
M````````````````````````````````````````````````````````````
M`````)K`/<(````K=%).4_______________________________________
M_________________P`CR:?0`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```(E)1$%4&--US]$2@B`0A>&C1IF5)I2EE8)H6.__@.V2:=-,
M_P4,WP4+>/Z$]SKU@8?K6CT![036S%##N9X@8.":"^X>`H::NE6PK4$8>CA1
MYR/R+:*%AP.E*NP-A&"X%H52)7B*6(Z7TMF/%3&!E!(E!@(]`S#T9H/5.AD?
M%L%FB)-=FN+?Y[YZ`<ZI%5-'F"Z``````$E%3D2N0F""````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VUA<%]E=2YP;F<`````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,30T,0`Q,#0Q-S,V,S`Q-@`P,C$T-3,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3```!@%!,5$4``,<!`<<"`L<"`L@#`\<#`\@%
M!<@&!L@&!LD(",D)"<@,#,H-#<H/#\H0$,@7%\`6%LP8&,T<',,='<X?'\TB
M(L,F)K`E)<0J*K$G)\XG)\\I*<4L+,8R,K0O+]$Q,=(V-K4W-[$W-\8\/+$]
M/;$Z.M0\/,D[.])`0+-!0;<^/M5&1K-"0M5)2;9*2K9-3:=,3+5-3;124J-5
M5;A24ME96:=96:I:6KE=7:=86-IB8KI>7MQG9ZEF9K9G9[EL;*EM;:YN;JQU
M=:UX>+!Z>K-\?+!V=N%W=^)\?-J#@[^'A[&'A[*(B+:5E>>AH>NKJ^NQL>BV
MMN[#P_+7U_3CX_CCX_GDY/?Q\?SR\OS^_O__________________________
M____________________________________________________________
M____________________________________________________________
M______]EOP2D````@'123E/_____________________________________
M____________________________________________________________
M____________________________________________________________
M____________`#@%2V<````!8DM'1'](OW'E````"7!(67,```!(````2`!&
MR6L^````KDE$050H%07!AR)6`0`&T'.1O4)&9LOX94OV=LVDN,9]F>_5G2-)
MLK\X,SG_*TDBR>E(`0:VDT@..Z%KNE_+6B(G;>##??59\WID'+1^'/SW/*8O
MC@K8>ZKKNGYLM6(5-M_^_/SQ\-K@B^_P_R]7+PV,6H#J4N_.%`S;@*H$^.:B
M0%4";,E75"7@4^2VAZH$VH\CN>XV-P0Z#A));F:;H)@X2R))<K>[O/3[/$GR
M#E6O*XP$OAO-`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUY86-C;W5N="YP;F<`````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,T,@`Q,#0Q-S,V,S`Q-@`P,C(R,3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C
M2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,
M5$4B(B,*#!#%QL@,$!;FZ.LE*"P,$!4H+#$W1E88'B5O?Y%\BIF6H:V@J[>[
MQM)%87Y-:H=2;HM.:(-=>94*#1!F@IY%6&MHA*!5;(,]35Y9<(AMB:58;H1S
MCJH)"PU@<H5^E:P=(B=D;WJ-F:6)D)?5V^'GZNWR\_1.9GUG@YY<=(MOBZ9%
M5F9UD:Q08W5\E:V)G;"*GK":K+VGN,=O>H09'2"1F9^0F)[)T]L)#0\2%!43
M%18-$1(1$1`8&!=+2$03"@`;#P%!)`4V'P6;6`_+=1G,=AK(=!K1>AW0>AW1
M>Q[%=1S"<QS3?1_%=!W!<QT.!P`*!0`(!``U'`(5"P$F%`(R&P-E-@=')@5;
M,0<U'00T'`233PTL&`2E7!!\10PI%P2L8!&*3`YY0PRU9!,F%00=$`.^:A6V
M9A2I7Q,M&06#20_*<AC,=1G-=AK,=1H8#@0N&`-"(P4T&P0Q&@0O&00Z'P59
M-A5%+QI,.BD:$@PD'AHI)B;,S,Q$1$0E)24='1T&!@8```#___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"OCWHK````A'123E/_____________________________________
M____________________________________________________________
M____________________________________________________________
M_________________P"7TC:^````"7!(67,```L2```+$@'2W7[\````O$E$
M050HSV-H!H$F$`"SFAE`A&V3O7T@5`0DT-!H7U</5&(+$[!SJ`P)2$MU;H0)
M.#IY^_G[N,<'P01B(SV\?#WSDK-@`B69N6[YKCD9I3"!,I?T[-#"I)0BN+41
M,6&)<1'AP3`!FYKRXJCHA`I..8@`JYF!275!%8.2CJ0E2("=5U973Z6629E+
M0D9,I)G!REQ?6EN+6UW-6$%56(.#D<&:1U137$J>Q<)(E4]54(B-P=10``GP
M,S,HH@$`:754R]SME+<`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;V9F:6-E
M+G!N9P``````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S$Q`#$P
M-#$W,S8S,#$V`#`R,30S-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U
M,```ZF```#J8```7;Y)?Q48```,`4$Q417=V=Y:5EI.2DY*1DH*!@H&`@7U]
M?GEY>GAX>7-S=,?'R,#`P:BHJ:&AHHN+C(J*BWY_?WU^?GQ]?7-T=&ML;&%B
M8IF:FI.4E(R-C8*#@WU^?7EZ>7%R<7!Q<,G*R9:7EI25E(N,BX>(AX:'AH"`
M?WM[>IF9F(Z.C8*"@8!_?WU\?'Q[>WMZ>I^>GIV<G)64E)23DY.2DI*1D8J)
MB8F(B(B'AX:%A=O;V]G9V<_/S\[.SLO+R\K*RLC(R,?'Q\+"PL'!P;R\O+2T
MM*BHJ*"@H)^?GYV=G9N;FYF9F9B8F)>7EY:6EI&1D9"0D(^/CXZ.CHN+BXJ*
MBH>'AX:&AH6%A82$A(.#@X&!@7Y^?GU]?7Q\?'M[>WIZ>GEY>7AX>'=W=W9V
M=G5U=7-S<W)R<G!P<&YN;FEI:6AH:&9F9F5E96!@8````/___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````($&M!(```!M=%).4_______
M____________________________________________________________
M____________________________________________________________
M_________________P`MMM1+````"7!(67,```L3```+$P$`FIP8````NDE$
M050HSV/(00,,$"H;"&`"V2@@AR';W!$(LL'(T=$YFR';PBH]RPD,LH`T2(";
MV\'>CLM6SL;:RM(5*,`MRQFO(Q@>JA2@;J0O#!)(3HC5TI0,-I;P-?!*``DD
MQFD+L)B9*/HQ>7O$@0085*7"0X,"_)D5/-VE00+L42IARH$2ON+R8FXQ(('H
M"(T0$SX_0T8U/1<AD$`D:Z@IO[\/4(,N;P10@$<T,R--)%4F*8%#ARTE&],O
MZ-X'`"(A3%ZZOM><`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]O<F=A;FEZ:6YG+G!N9P``````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$Q-C<`,3`T,3<S-C,P,38`,#(R,S8Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P```2Q03%1%````"0D)#`L*#@X.
M$Q(1$Q,3%Q<7&!@8&QL;'AX>(B(B1$1$55557U]?=&M,;6UM;FYN=75U=G9V
M@G=5>7EY?W]_@X%XAH1[B89^B(B(C8V-E)*+DY.3EI2,H95PFYN;G)R<HY^7
MKJ!TL*)XMJ=UJJB?J*BHNJETJZFAJZNKK*RLL:VDOJ]]M+"HM+*JM[>WW+QT
MP,#`Q,"XQ,&YR<6]QL;&R\>_ZLA[R\O+W<V8TL_(U-',U-+,U=+,V-;0UM;6
MV-?1W-S<\]Z:]-^=]>*DX>'A]N.G]^2LY.3DYN;BYN;FZ>GFZ>GIZNGGZ^KI
MZ^KJ[>SH[^[M\?'N\O'N\?'Q\O+R]//R]/3R]/3S]/3T]?3S]?7U]_?T]_?W
M^/CX_/S\_?W]_O[^____````4VW#%0````%T4DY3`$#FV&8````!8DM'1`"(
M!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$38P[=&QS@``
M`,1)1$%4>-I-C]=6PE`41`-!JC2E*DA'Z44@2I$2>A'I'0SS___`O0$6S.->
M^YPUPS#7`,Q]@&GJ#@$'0=A5@V<$5@YD9__"\5A^(>3ALZ))6Y#:'[I?U$"N
MLV#_,E8T$H#[$0SRZZ5JTHNQ0-!$#65INU.KGCY`$S(2XV>QF@\''KC:,(@_
M7@N_HW'1BC>.')DIL47B`:=,%^6@O?0`I'CV-HGAT$,$8=^[_[O.P7XICTV+
MYVL$7+>@S]$D%;=I$K&%*)P`OVTSN5"G3W$`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]P97)M<RYP;F<`````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S,`,3`T,3<S-C,P,38`,#(Q,S,Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[
M49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%
M1@```P!03%1%BWU*;V0[7E4R[M:`\O+R[>WMW]_?VMK:SL[.R,C(PL+"O[^_
MM+2TJZNKDY.3:VMK45%12$A(0$!`(2$A!P<'`0$!````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````^)IS*P```!AT4DY3____________________________
M__\`S1,NZ@````EP2%ES```+$P``"Q,!`)J<&````&%)1$%4*,^5SL$2@C`,
M1=%H?8BV2A&][___U`4,UNZXRS.9).&N,&L[<$[IE#6S0XI(:*C;9`!7GEK+
M$+!<))5MPF%N4\GEM\.,C\_[17-VNFN8&S!5E>8Q&^&CD'N@@[^^`Z03U,.I
M)L\`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W!R:6YT+G!N9P``````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3$Q-@`Q,#0Q-S,V,S`Q-@`P,C$S-#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3```!'5!,5$4````;&QM-2T=/34E034E13TM13TQ24$Q444Y4
M4DYA7EEA8%YK:F=M;6QO;FMP;VQU=75_?GM_?GR`?GR`?WR!@'Z)AX6)B(6(
MB(B-C8V.CHZ0D)"2DI*3DI&4DI"4DY"6EI:;FIB>G9R?GIN>GIZFIJ2GIZ>H
MJ*BKJJ>KJZJLK*FNK:JOKJRPKJRRL*VQL:ZSL:^SLK"TM+2YN+6\N[N\O+R^
MOKW`O[S"PL+%Q<7'QL;'Q\?+RLG/S<W.SL[/S\_1T='3T]/6U-+8U]37U]?9
MV-;9V=C:V=?:VMG;V]G;V]O=V]K<W-K<W-O=W-O>W=S>W=W?WMWBXN+EY>3I
MZ>GKZ^OL[.SN[N[T]//W]_?X^/CZ^OK[^_O___\````GLQY&`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q$```L1`7]D7Y$````'=$E-
M10?4#`@2*0@0`%&P````JDE$051XVF-@P`;B8`#&CX6"L#B8@+2CHY2"M;4+
M7"`T!`A"0[W@`A)24J$"1D8(@5`(0`A(AX:JJ*NIV4,$XDPT[4Q!P))7!B02
M9Q$3&QT;'1,3'15AI@P4B8N.#)8,=PCR\/=Q-M1C!`I8.7G[!@3ZN7FZNXK*
M@U38*G%Q<+*RLS`QL\F"!6S,C0WT=72U5#6T=11!`G+"8N(B(D*"0OQ\/-QQ
MR'X%^Q<`I`@Q*8_.#M(`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+W!R;V)L96TN<&YG````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#,P-0`Q,#0Q-S,V,S`Q-@`P,C$V-#,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0!`,```#MW>)2````&%!,5$7\T\L```#?@63>=57RH(W?@63?@63?
M@61D#[54`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,`
M``L3`0":G!@````'=$E-10?4"P43)0=M@FW7````)DE$051XVF-@8&!@%&"`
M`"%%",VHI"1`-`.N"PL#;C(<8-B%IA@`!"L#(`1$O=8`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]R96QO
M860N<&YG````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,S,`
M,3`T,3<S-C,P,38`,#(Q-#4T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```&!03%1%_____/S]\OG][_+XX^OUT>'T5J;N<L9R`IH#HMJNS^C^
MP]7WLK+^$IX2ZO;^HM;.Q.'ZNM[VKM?]*:<WHM+^7KJ"````____________
M________________________`-X9?@````%T4DY3`$#FV&8````!8DM'1`"(
M!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P6#B4D*Y<(YP``
M`'1)1$%4>-IES]$2`B$(0-%-I&4I45GS_S\U+!RWZ;YQ4&?<MK_ZRN%FA0`1
M73XP#/N]7R``^J4!.]%!_'A.L-EBY`GID&Q0'""(Q'&"JP.`B)12ZH2Q)AO5
M(1JD7)*J+K!.;0[,E/?SI=K:%Q"YVHL+^L]_WRS@"8DKQ'9L`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<F5Q=6ER960N<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C,P`#$P-#$W,S8S,#$V
M`#`R,C`R,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````"@````H!`P```+?\7?X````&4$Q4
M1;4``````.]@.PD````"=%).4_\`Y;<P2@````%B2T=$`?\"+=X````)<$A9
M<P```$@```!(`$;):SX````=241!5`C78_A_@.$S&$UR8&AP8'AX`(3.@-'_
M`P#<_P[1P'"L+0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W)H86YD+G!N9P``````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#0R-P`Q,#0Q-S,V,S`Q-@`P,C$S,#0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"$````.!`,```!3,&B_````&%!,5$7____`P,"_O[^`
M@(```/\``(````````!:[7A3`````G123E/_`.6W,$H````!8DM'1`9A9KA]
M````"7!(67,```!(````2`!&R6L^````BDE$050HD6W/00J#,!0$T$'!=3YH
MUN47_KHDD!.H)U#7B8&Y_Q&ZB$5:.IN!MQD&\A.'UIYD^9(,P%A$Q,&3%`\`
M736*.(SSO#(#/=4"6)J\`!A.K0IK$H">&$CJ1QXP4),(B\.T+&M43;EK\P[C
MMATQ:![.YR73OA^L@3#*+>)KI*9+/%G^O;CCWH=$)4M.+IH0`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]S879E+G!N9P``````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$P-3(`,3`T,3<S-C,P,38`,#(Q,30Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```/E03%1%```%$2@U$2PZ$RT\&#!"&C%`(39(
M+3E)+D-3+T96,TE:/D]<26!R3V1U66-M5&E\6&V`6G"";FYN7WF):WB">GIZ
M@(:,@(>/AH:&QW1FQW1GQW5HR'9HD)"0?9>L?IFM?YJNMX=^@9JN@YZRA*"U
MS89ZR(J`G)V=AJ2YB::\H:&AT8^$C*B]EZ6PT9"$C:F^TY&&G:FPGZFPJ+&]
MH;;$LK*RN;FYKK_-O[^_P,#`PL+"Q<7%O\O6S<W-Q\_:SL[.O]7HRM;?U-34
MUM;6U]?7R]WKS^#MV^?QYN;FZ^OK[N[N\?'Q\O+R]/3T]_CZ^?GY_/S\_O[^
M````86H!I@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3
M```+$P$`FIP8````!W1)344'U`P4$BLY:2?;+P```*I)1$%4>-I5S]46@D`4
MA>&Q"P-;%&/$#NPZHBC6V/#^#^.`HR[_RV_MFXV0\1="QGU?;5EU6SU5-9!Q
ME$M9@981<A4Y3.$@[W360PJ^@:5=,/=;/&^$?(&V!=H'SKI^)69G!M/-:FDU
M8B`WBIA6R&,&[2'`FNQJOB0#"<#IUV#BB'0LJ&-0O#S`S,;W38B7L7)RQV`Q
MMO,#SGP7"C;GHIB.)CR!E(O"_W_T`NK@-G<JJ?0U`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]S96%R8V@N<&YG````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(S-3<`,3`T,3<S-C,P,38`,#(Q-#8Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA2
M30``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%
M]O;W^?K\]?;X.$-1Z>[T:8&<77**1%-D3V!S@)NX?):R@YZ[A:"]A)VYB**^
MA)RXB:*^0T]=;X.9A9VWC*2^C:2]AYNQEZW%A):JHK7*T]WHU^#JU][FY>OR
M05%B0E)C.4=5;XFD<XVH:H*;:X*:9GR377&&8'2):X&8AJ&]B*._<XJA:G^5
M872(04Y;<(:<:G^4BZ;!:7V2C:C#7G""E*S%E:S$E*O#BY^TF*W#EZF[CI^P
MG['$D:*SL</6J[S-ML?9K\#1M<;7N<C7N<3/S-?BN<++Y^WSX^;I]??Y/4M8
M<8><HK;)U-_IUMSAT]G>\O;YU=SAN;FYL;&QD)"0>GIZ=W=W=75U<W-S<'!P
M;V]O;FYN9F9F7EY>7%Q<6UM;6%A85U=75E964E)24%!03T]/24E)0T-#/CX^
M/3T].CHZ,3$Q+R\O*RLK*2DI)B8F)24E(R,C&AH:%A86#0T-"@H*"0D)"`@(
M!P<'!@8&!04%!`0$`0$!````@("`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````0Q"UFP```']T4DY3________________________________________
M____________________________________________________________
M____________________________________________________________
M________`/_A/`D````)<$A9<P``"Q,```L3`0":G!@```#.241!5"C/8Z@#
M@ZCT[-J:O.30NCH&,#^I5-#(6UO#JRP>(A!99F+MYB?CPZ56%@H6R-"S]6?P
M9)$VY61/`0OD&[@P!;!(V6F**.6"!6KU/1C=?1T,><SX:R`".H&R4@[&6MR2
MPK5@@2)U*U<G0RT^<T?%;+!`%K.*&"^W@+BSJ'P<2"`\MII#5<+"QMZ2K2H,
M))"04UNJH"NDS"I7F0AT6&1M54516F9A36U!4@30Z3'Y02'%J75PP%`2'%U;
M6X<D4`[DQR,+Q-?6)B'QZP!.FEM.]'OPRP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H861O=RYG
M:68`````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C<T-0`Q,#0Q
M-S,V,S`Q-@`P,C$T-C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA(`,@`\0``/___^?GY_/S\];6UL+"POO[^[*R
MLO7U]=O;V_S\_/'Q\>#@X-'1T?KZ^O;V]NKJZMC8V.WM[<7%Q>CHZ,G)R?W]
M_?CX^._O[_[^_K6UM;N[N\3$Q/GY^0```````````"'Y!```````+``````@
M`R`#``7_("".9&F>:*JN;.N^<"S/=&W?>*[O?.__P*!P2"P:CR_%@9/`()_0
MJ'1*K5JOV*QVR^T.`Y=#H^(MF\_HM'K-;KO?941`82'#[_B\?L_O^_]W#`L1
M#@F`AXB)BHN,C8YE%`@/!X:/EI>8F9J;G'@2$!,"!9VDI::GJ*FJ)P0#`:*K
ML;*SM+6V6ZVOH[>\O;Z_P,$CN;#"QL?(R<I_Q+O+S]#1TM-(S=37V-G:VR;6
MW-_@X>*VWN/FY^CIB^7J[>[O\&7L\?3U]O<_\_C[_/W^)?K^"1Q($%W`@@@3
M*HQV<*'#AQ#)N2H6L:+%BZ<:8MS(L:,?C1Y#BAQY!B3)DRA3_T(QJ;*ERY<Y
M6,*<2;,F"IDV<^ITB7.GSY\>>P(=2O2AT*)(D_X[JK2ITWA,GTJ=.BXJU:M8
MKUG-RK4KLJU>PXJ]!7:LV;.HRJ)=RQ:3VK9PXR)Z*[>N73QT[^K=BR8OW[^`
ML?@-3+APM8G.#"M>+`\QX\>0LPR.3+DRB\F6,VL6@7FSY\B=/XM6''JT:<"E
M3ZN^FWJU:[BM7\L^&WNV;:^U;^N^FGNW;Z>]?PLO&GRX<9_%CRNOF7RY<YZ.
MGTMOVWRZ]9#5KVO'F'V[=XC=OXM/&'Z\>8'ESZO?EWZ]>WKMW\MO%W^^?7/U
M[^O_EG^_?VS]_2<@0]$-:"!W!1ZH(/]X"2[H('D-/B@A>A%.:"%[%5ZH(7P9
M;N@A?1U^*")^(8YH(G\EGJ@B@"FNZ"*!NKPHXS8!SFCC'C7>J",<.>[HXQH]
M_BBD&4$.:20N+1ZI9"E%+NFD%$T^*>4144YII1!57JEE#UENZ24.77XIY@QA
MCFFF"V6>J68*::[I)@EMOOEFG'*N26>=9]Z)YYAZ[OEEGWYN"6B@5PY*Z)2&
M'OIDHHHNR6BC1SX*Z9"23OICI9;NB&FF-V[*Z8R>?OIBJ**N2&JI)YZ*ZHBJ
MKOIAJZYN"&NL%\Y*ZX2VWOI@KKHNR&NO!_X*[(#"#OM?L<;NAVRR]RW+['S.
M/OM>M-*N1VW_M>==B^UXVF[[7;?>;@=NN->-2^YTYI[[7+KJ+L=NN\>]"^]P
M\L[[6[WV[H9OOK?MR^]L_O[[6L`"KT9PP:<=C/!H"B_\6<,.;P9QQ)E-3'%E
M%E\,6I(:S\EQQW9^#'*>(H_,9\DF_XERRH*NS'*A+K^,:,PR+TISS8[>C'.D
M.N],:<\^7PITT)H.372G1A\-:M)*C\ITTZ8^#76J4D_-:M56OXIUUK)NS76M
M7G^-:]AB[TIVV;Z>C7:P:J]-;-MN'PMWW,K.37>S=M\-;=YZ3\MWW];^#7BV
M@@_.;>&&?XMXXN(NSGBYCC^.;N22KTMYY>Y>CGF\FF].;^>>WPMZ_^CZCDYZ
MOZ:?#G#JJ@_,>NL&OPY[PK+/SG#MMC^,>^X2[\Y[Q;[_CG'PPF\<8_%@'X_\
MV,HO;W;SSJ<-??1L3T_]V]9?+W?VVM?-??=X?P_^WN*/[W?YY@>.?OJ$K\_^
MX>Z_KWC\\C=.?_V0WX__Y/KO;WG__LL<``/(N0$2\',&/*#H$JC`TC&P@:A[
M(`17)\$)NJZ"%HP=!C-(NPUR\'8>_*#N0BC"WI&PA,`[(0J'I\(5&H\B+G1.
MQF*(CQG2T!XVO"&'6JA#P^2PA^_X(1!!Q,,AHH9X1B0.$I,X%"$RD41%?")K
MEBC%G3BQBN"X(A:YH<4M:J.+7F11%,/(%O\PDG$:9CPCC&"H1A"RL8TC?",<
M32C'.::PCG9D(1[S^,+$\/&.?ORC'@,IR#X64C-I/.0O$JG(7C"RD62A(B0W
M\LA)TJ*2EI0%)C.YBDUR,A6>_&1&)"E*HY"RE`L))2H[H<I5;J*5KLP$+&-Y
MB5G2\A&VO&4C<JG+=9RRE_[@)3#G\LMA8FB,QIR),)/YD6(RLQ[+?":.G"E-
M>$2SFGBA)C:)N,=M8N6:WG0#.,/)AG&24PWF/&=?M*E.<:2SG8U!)CPY\LYY
M<J&>]M0"/O,I&';R,QO[_&<5`BK0*1"TH%$X*$*?H-"%4LF?#H5&0R-*A(E2
M%$L0O6@R+*K1?&3_M*/&X"A(>2#2D>J@I"8%TT=3Z@N4LK0&+GTIF58J4XG(
MLZ;WB"E.7Z#3G;:@ISY=`5"#RB::$E450SUJ-XRJU%'>M*GJ2"I4.</4J;*R
MJE9])5:S*LNM<K667OTJ+L,JUEV2M:R^?"I:N7C6M1)3K6X%:%OCRHRYTK4/
M4IUJ7J&ZUZ;V5:E_/6I@B3K8H!;6IX?=:6)QNMB:-E:FCWUI9%DZV916UJ27
M'6EF0;K9CG96HY^]:&@I.MJ(EM:AIUUH:A&ZVH*V5J"O_6=L^3G;?-;6GK>=
M9V[AN=MV]E:=OSUG<,DYW'`6UYO'W69RL;G<:C97FL]]9G29.=UD5M>8_]<=
M9G:!N=U>=E>7W[UE>&DYWEB6UY7G765Z4;G>4K97E._]9'PY.=],UM>2]YUD
M?B&YWT;V5Y'_/62`"SE@01;XCP?F8X+SN&`[-GB.#X9CA-LX8356^(P7)F.&
MP[AA+W9XBQ_&8HBK.&(IEOB))V9BBI.X8B.V>(@O!F*,>SAC'=;XAC>F88YC
MN&,7]GB%/T9AD$LX9!$6^8-'YF"2,[AD"S9Y@D^&8)0;.&4%5OF`5R9@E@.X
M9?]U>7]?QE^8ZS=F^97Y?6=F7YK3MV;SM7E\;P9?G+LW9^W5^7IWIEZ>H[=G
MY_5Y>7]&7J"+-VCA%?IWA^9=HG.W:-LU>G:/AO]=I%LW:=55^G27)EVF0[=I
MSW5Z<Y_&7*@K-VK)E?IQIV9<JA.W:L.U>G"O!ERL^S9KO=7Z;K>F6Z[CMFNW
M]7IMOT9;L,LV;+$5^VO'YEJRL[9LJS5[:L^&6K2;-FVE5?MHUR9:MH.V;9]U
M>V??QEFX:S9NF97[9>=F6;I3MFZ3M7MD[P99O#LV;XW5^V+WIEB^([9OA_5[
M8?]&6,`+-G"!%?Q?!^=7PO.U<'LU?%X/AU?$VS5Q=57\7!<G5\;#M7%O=7Q;
M'\=6R*LU<FF5_%DG9U;*D[5R8[5\6"\'5LQ[-7-=U?Q6-Z=5SF.U<U?U?%4_
M1U702S5T417]4T?G5-+_,[5T2S5]4D^'5-0;-75%5?U05R=4U@.U=3]U?4]?
MQU/8ZS1V.97=8W"]*QKMJG8]G-U-;P]9VMLN4;;3_0YQ5U/>23;WNRMC[V8"
M_,GZ[O>OV+WP;1"\F!2O,L(C7AB,]U+D6^;XQP-C\EK"/,PJ;_F6'K[SZ^0\
MZ",I^M'70O-60OW,2F_Z6:A>2J^W&>M;'XO8.\GV.9L][9'Z^=TC2?>^=VHW
M@Q_5WA/_"KA74O)Y!OSC7[7YSM<J]*/?U>E3'ZS6O_Y8LZ]]LW*_^VD=/OC9
M^OWQOU7\YI=K^=-?U_6S'Z_&?_\0EF\D^O_,_?)W>_SS#P3["\G_0H-__(=W
M__LW@%Q2@`:X`P#H(PM8-`*8@(F'@!"H4@\X@>@D@18(4QB8@3-5@1Q()!OX
M@3#0@#I"@DCC@2+8!29H(RNX-"B8@K^'?C#H>2\X@_U4@S9H!2TH(SOH-#B8
M@U30@RXBA%'S@T`()2%XA*R0A$H($$S8A,/PA%`(`$2H(E5(-48XA49PA2;"
MA5>3A5I845((A5XH(F6H-6`8AAB5AFK8?V/8A&?H(7'8-6S8ACXPAQJ"A\DC
M@W9H"GIH(7_(/'S8AZ00B!)BB,\SB(3("8CH((TH/8JXB)KPB`I"B=43B9+H
M%F^HA)9H()V(/9B8B9;PB0)"BML3BJ+H"*;H'ZOH/?^HF(J,T(KZ(8OA\XJP
MJ`BT:!^Y2#ZV>(OG1TB^6(B;>(2[*!_%>#Z]&(SMEXS*"']UV(P\-8Q`>(SN
M08WJPXS0J'_/F(V7(8TY:(WJ`8[M@XW<2(#;6(Y%=8[HN(3JN(Y.V([N&(7P
M&(]4Z(TV*([F@8_P0X[T>('S&(_Z*!X!.3_\V(^A5Y`&"8+_Z(X#Z1T-:3\(
MF9!>\)#:09'Y$Y$2>4_V.(,6:1T=R3\8F9'ZM)$P^)'289+_$Y(B>8,JN9(Z
M2)(IB)(R!),B*),"U)(N&80T^8&?$`K`F)-\$`F3D``+P``;H`$98`!*N91,
MV91.^910&952.9546956>97_6)F56KF57-F57OF58!F68CF69%F69GF6:)F6
M:KF6;-F6;OF63YD!&K`!@D`("1``",``%"`!!-"7?OF7@!F8@CF8A%F8AGF8
MB)F8BKF8C-F8COF8D!F9DCF9E%F9EGF9F)F9FKF9G-F9GOF9H!F:HBF8$D`!
M#"`'=%`!%Q``"X``$#``L!F;LCF;M%F;MGF;N)F;NKF;O-F;OOF;P!F<PCF<
MQ%F<QGF<R)F<RKF<S-F<SOF<T!F=TCF=U%F=M0D!"+``8"`&%7``"A`!#S`!
M`3">Y%F>YGF>Z)F>ZKF>[-F>[OF>\!F?\CF?]%F?]GF?^)F?^KF?_-F?_OF?
M`!J@8@(ZH`1:H`9ZH`B*GA/P`!&@!$R``0U@`0YP``)0H19ZH1B:H1JZH1S:
MH1[ZH2`:HB(ZHB1:HB9ZHBB:HBJZHBS:HB[ZHC`:HS(ZHS1:HS9ZHSB:HSK*
MH0?@`!;0`$T``"$``#L````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]S:&%D;W<N
M<&YG````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8U,3,`,3`T
M,3<S-C,P,38`,#(Q-#<W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(```,\```#10@$````%-(Q
M;````"MT15AT0W)E871I;VX@5&EM90!4:'4@-2!&96(@,C`P-"`Q,3HR,3HR
M,B`M,#8P,')J/&8````'=$E-10?4`@41%1^O/'5M````"7!(67,```L2```+
M$@'2W7[\````!&=!34$``+&/"_QA!0``#*-)1$%4>-KMVE%JVT`40-'GV(1"
M"'3_.PU.[(YD0S<0W4![SJ!!]I?^+F^8\P#`T<YS6NOY"@!'^S4O:\V*SUUX
M`#C>[[GLX;G->@&`H[W/YWS,%IZ[\`!PO+>YKOVZ[<(#P/%>9RO.?L7@Y:>_
M!8#_P':UX'FO37@`.-[I[W5JX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`.-Y]7[O+G.=UWN9]/:\K
M0Z>?_C8`_CGWN:WU3,]E?_F:S[G."`\`!]C"<UVE^=J:<UE_W-:/C]DB=!(>
M`+[=-N)LI?E<Q=DGGJ]]VKG.>>W"`\!WVX[8'F=K:^;90K,=L)W7XZ(!`$>Y
M[8/.?6Z/">=QQ&;:`>`H]WD<N<T?^<4^K/A0+:T`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<VAE;&PN
M<&YG````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S,T`#$P
M-#$W,S8S,#$V`#`R,3,R,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,```#`4$Q41?S^_%RR_$RN_)2.I!2*[$1VI!1VW#1NO#QJM#1JO"QJM#Q>
MI$1>;#Q>=#1>=#1:="Q2A#1.?$1*9$Q*3#Q*7"1*G!Q*G!Q*E#Q&7!Q*A`Q&
MC!P^="0Z7"0V5`0Z9`PN5!0J5`PJ5`0J3`PF3`PF5`PF1`0B1````/___P``
M````````````````````````````````````````````````````````````
M`````````````````````````````'9T5)0````I=%).4_______________
M______________________________________\`4O0@AP````%B2T=$/SYC
M,'4````)<$A9<P```$@```!(`$;):SX```"`241!5!C378^+$H(@$$6OEM+#
M[+&6I:34^OK_+PS7L.3`,LN=,\N`P0-5?IO7->\&%+OM%Z74YM$B7CN",%CM
M.T1'QR%-DQ,CZ__A&O>>`+(]QL"\;``BV*ND8F"R"9.1.4,4-K\9HHCAO7)9
M!-8X/[768\E9,MZFX6;>W,+__@=8L1O5)]2K&P````!)14Y$KD)@@@``````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H;W=?<&%N96PN<&YG````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8R-``Q,#0Q-S,V,S`Q-@`P
M,C(S-#8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`(```"0D6@V```!6TE$051X
MVI52/4L#011\;W<C,1A0J_2"53A(;2'8V02"8(PA_\*#0)"8"P'A()R!](K7
M*%J<C9V-Y6&XP#4)]P=2!(5(M-JU>/'NC!^85\W.SKQ9AL63XR-89`0`9+.[
M_U3[_KT@].3Z^(M(2L482JD8YTM)$`"PM[^SL;F.B(PQ1+R]OJ@;IN=Y(:.4
M0D1$O+DZGR5PSC5-`X!NMTM,L]DD$1T-PR`L`"!DWZ;ORZEDJ5@@`ZV/)\P,
M)`6`GCM\G4Q7TJF#PSO;ML-=K5:+GA<92)U(B'XO>'F>K*ZE@R"@K8PQ*26E
M18:>.WQ\Z!,F4*O52$%/,DWSBR$^U4;%<9Q<+O>]I<BPM:T!P&G]LMJHE(J%
M?#Y?+I?C?;3;[<B@E!J-1IE,IMJHV+8=##Q2_-62$&(\'A-[-O``0-=UND)$
MR[+F6^*<X^<0T^ET0H82?C80.\?$:\5%O_<'C@F!#2I@[6$`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]S<6PN<&YG````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P,3(`,3`T,3<S-C,P,38`,#(P-S<W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@
M8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!0
M3%1%_.D[^^<[_.L]^=\Y]M(V95DP3T$5;%\T6U`M7$\K850N\K9-[[1-][5$
M][5%]+)$UZYT````____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````>D/P&P```!-T4DY3________________________`+)]W`@````)
M<$A9<P``"Q,```L3`0":G!@```!5241!5"C/=8];"L`P"`3M^]UT]OZ'[4<D
M,86*X#KHBJ9/6%'0`KJ#".BO/0+L7N(*0UH)IHSG1KD"XIG`[QB(&933`1'(
MARNHW0]P2>LALA/$;W-Y`?8,$07FA8QK`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1A8E]B
M;W1T;VTN9VEF````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`T-0`Q
M,#0Q-S,V,S`Q-@`P,C(S,3<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#=A%``!`(`!`````/___RP`````%``!```"
M!(2/F04`.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]U;FQO8VME9"YP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$R,34`,3`T,3<S-C,P,38`
M,#(R,#$P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```.=03%1%
M````!`,"!00#"`@("PL'&A,+%A86%Q<7+RDA+BXN34U-@5HK<G)RJF\KI'$V
MK'$NK7,RH'=$HWM+A(2$I'Y.J(%,M'X^IX)2IX)3N(`^JH15JX=8K(=8NH1"
MJXA8NH9'O(=&O(A)NHE+KXU>K8UDO(I,L(U?O8Q.I9%VOHU0QI9=QYMDJ*.>
MRI]HJJJJRZ1QSJ1PS:9NS:9VT*9TS*=[T*ATSZM\L;&QSZQ[S:R#SJV#U*QY
MU:Y^TK*)U;*$V+6,O+R\UKJ4P<#`VKZ:X,*>X<*<X,2@W\2CX<2@XL6AX\:B
MV]O;````A$]HZ@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,`
M``L3```+$P$`FIP8````!W1)344'U`P4$BXBGC7FA@```(QT15AT0V]M;65N
M=`!-96YU+7-I>F5D(&EC;VX*/3T]/3T]/3T]/0H**&,I(#(P,#,@2F%K=6(@
M)VII;6UA8R<@4W1E:6YE<BP@"FAT='`Z+R]J:6UM86,N;75S:6-H86QL+F-Z
M"@IC<F5A=&5D('=I=&@@=&AE($=)35`L"FAT='`Z+R]W=W<N9VEM<"YO<F=G
MBL='````ATE$051XVF-@P`%\?'S0!+P=>)A1!-BYS(71=''JH>EB<_)!&,C"
MR,C$H<,*Y6NXN;L[.SL[&G%#E/AXVNO*B(M+""GR0P6\;-3LS,PL]!5XH0(>
MQMI2(B(B@K(P%:X&*K:6EE8FD@)0`1=K0V5I:3E1!3&H@*F6IJ:2DKJJ/)\/
MW!U0@,W;`.H0%TQJ<R;C`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]U<V5R+G!N9P``
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-#(`,3`T,3<S
M-C,P,38`,#(Q,38T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M``1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J
M8```.I@``!=ODE_%1@```P!03%1%(B(C"@P0Q<;(#!`6YNCK)2@L#!`5*"PQ
M-T96&!XE;W^1?(J9EJ&MH*NWN\;216%^36J'4FZ+3FB#77F5"@T09H*>15AK
M:(2@56R#/4U>67"(;8FE6&Z$<XZJ"0L-8'*%?I6L'2(G9&]ZC9FEB9"7U=OA
MY^KM\O/T3F9]9X.>7'2+;XNF159F=9&L4&-U?)6MB9VPBIZPFJR]I[C';WJ$
M&1T@D9F?D)B>R=/;"0T/$A05$Q46#1$2$1$0&!@72TA$$PH`&P\!020%-A\%
MFU@/RW49S'8:R'0:T7H=T'H=T7L>Q74<PG,<TWT?Q70=P7,=#@<`"@4`"`0`
M-1P"%0L!)A0",AL#938'1R8%6S$'-1T$-!P$DT\-+!@$I5P0?$4,*1<$K&`1
MBDP.>4,,M603)A4$'1`#OFH5MF84J5\3+1D%@TD/RG(8S'49S78:S'4:&`X$
M+A@#0B,%-!L$,1H$+QD$.A\%638512\:3#HI&A(,)!X:*28FS,S,1$1$)24E
M'1T=!@8&````____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````KX]Z*P```(1T4DY3____________
M____________________________________________________________
M____________________________________________________________
M__________________________________________\`E](VO@````EP2%ES
M```+$@``"Q(!TMU^_````+Q)1$%4*,]C:`:!)A``LYH90(1MD[U](%0$)-#0
M:%]7#U1B"Q.P<Z@,"4A+=6Z$"3@Z>?OY^[C'!\$$8B,]O'P]\Y*S8`(EF;EN
M^:XY&:4P@3*7].S0PJ24(KBU$3%AB7$1X<$P`9N:\N*HZ(0*3CF(`*N9@4EU
M016#DHZD)4B`G5=65T^EEDF92T)&3*29P<I<7UI;BUM=S5A!55B#@Y'!FD=4
M4UQ*GL7"2)5/55"(C<'44``)\#,S**(!`&EU5,O<[92W`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W=E8G-I=&4N<&YG````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C0P-``Q,#0Q-S,V,S`Q-@`P,C$V-#<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-
M``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4`
M``$'#10*'S4&$1P0*D08.%@6,U$:/5\-'B\8-E4&#10=/F`@0F0E1F88*CPO
M47(=)2T_14L[/D%I;&\C1&,H3&T<-4PI26@O57<-%R`R5G8S57,^8X8^77E,
M<)%);(M$8G].;XX>)R]]EZXS6'@M3&<^9(0^8X-*<)!8@:);>I5>?9=]G+4=
M(RB0JK^.I[Q`2U3&TMP##!,%"@Y-=95AB*=B@IM[G[M_H[^(JL1YEZ^!H;F$
MI+R!H+>`GK9]FK&-K<6`G+*)I[V+I[TY0TN9M,B;MLJ9LL:=M\J=MLF?M\JG
MO]&AN,JOQ-2KO\\N,C7(V.3'UN+-W.@'"@P1&!TI-C^!H[N7N-"4M<R7N,]]
MF*N2L,1=<'V-J+NAO=&;MLE#3U>LRMXT/4.MQ=:MQ=6JPM*IP=&\U>>DN<BO
MQ=6\TN'"U^:[T-XZ0$3`T=W+W.C&U^/%UN)*4%38Y>[9Y>W8Y.RON+ZVO\76
MX.=04U5IAIFKR-NRS^*BO,VEOLZ_V>FNQ=.[TN"^T^#'W.G$V.3(V^?&V./(
MV>3.W^K<Z?&[T=[2WN5^A8DW/4";J*_5Y.Q#14977F$&"0H```#___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!EF?-1````E7123E/_________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________`#9D&S@````)<$A9<P``"Q,`
M``L3`0":G!@```#-241!5"C/8YB"!AA`A,O$R@E"@DIP@5SALI+._,!R_Q"(
M0&]/17]S=DMIL6'"))!`:%%W>U-]>E9A0%"&+DC`H"\OKKHFL;'`UR\E9C)0
M($G9SB$B/+*C+:<A/HH!*"#@[!1F;F'9VI59IZ<($I"4\TRV,=74L??V<N0'
M:9&4=T]+M371D/%QU>8$"1B+F7G4:JFI2\1&RS*#!*8PBKOI2ZM(B5I9,S&`
M'3:9JTJ!AU>$6Y5O\F2(TR<'<["QL[(8@?@0STV9#`8(WR(#`+X69SVIX6M*
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O>F$N<&YG````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C<P`#$P-#$W
M,S8S,#$V`#`R,#8Q-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````"0````D"`P```)W_[H,`
M```)4$Q41;H`%F9F9@```(RUS$(````!=%).4P!`YMAF`````6)+1T0`B`4=
M2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$V"US:6.H````H
M241!5'C:8V```JU5#`Q2*QD8N%8P,+`M86!@6L#`P#@!*-$`DF4``%GG!*=[
M7+#T`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W!R969S+G!N9P``````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8Q-@`Q,#0Q-S,V,S`Q-@`P,C$S
M,C<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````BE!,5$4`!0`=
M'1T?)R\I*2DP,#`Q,3$V-C9)1T904$]24E)-7W-L:6=K:FER<&UF>8]P@I5T
MBJ**AX1XC:1]C)Q\D:=]D:=_F;.-F:6$GKF$GKJDH9RQL;'(Q\;*R,'2T,S2
MT=#3TL_5U-//UMW6U=78V-C;VM?>V];?WMSCXN'KZ^CLZ^KW]_?Y^/@```#=
ME\T9`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3
M`0":G!@````'=$E-10?4#`@2'0<[E;_6````?4E$051XVFV.61*",!`%@^`6
M]P5Q1Z.`H'W_ZTDV0<OYR/14O4H_(?X-/\#)P\%#:8`[+L9+4Q=[G^&9:R1R
M^<NCR/8$8>.H)QT0?(OIT[[H<1PU;69JC>"V\"56:KGIU+N:6&VBYEMIM->Q
M62K>21LF'>HWGDH^OSM'N\`;)=4.9O?[M1\`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A9&UI;FES=')A=&EO;BYP;F<`````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`U-C,`,3`T,3<S-C,P,38`,#(S,C,V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```&!03%1%````K:V4SIPQ_\YCQL;&
MA(2$[^_O,3$`G&,`8V,`__^<__\`A```_P```)S_``#_SLXQ,0``SIP```"$
M4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOOFY0A+P```"!T
M4DY3_________________________________________P!<7!OM`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```(!)1$%4&---CED6Q"`(
M!-LEXX+CDAR`^]\R@CYG^J_J`0V8&3LLP<%M#AC[+YR'=7MEL8/!$5X8UMAK
MB\D?9X+[M4QCY@1B0IR"X:WL(.9,B!"^](>4$TA+O$4I7XY$441M:@LH=$("
M6FV2D,<]D/1HK<^#//I(6KN"?BL?P5C,+VZX#"IJ)#]S`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O87HN<&YG````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,C8W`#$P-#$W,S8S,#$V`#`R,#8R-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````"0``
M``D"`P```)W_[H,````)4$Q41;H`%F9F9@```(RUS$(````!=%).4P!`YMAF
M`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,
M%!$V&:]C*:(````G241!5'C:8V``@08&!L8)#`Q,"Q@8V)8P,'"M8&"06LG`
MH+4*+`L`3F<$I_J^V2<`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L86YK+F=I
M9@``````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`U,@`Q,#0Q
M-S,V,S`Q-@`P,C$R-3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA`0`!`(```````/___R'Y!`$```$`+``````!
M``$`0`(!3``[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:RYP;F<`````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-C``,3`T,3<S-C,P,38`,#(Q
M,C<V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"Q
MCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=O
MDE_%1@```P!03%1%%Q\6%1P4'24<5V]3H[:@7798<8]K<(YJ;HMH;8IG7WA:
M7G=98'E;A9Z`@IA^9(!>8WY=46=,;HMG87M;6'!36G)5:H9D7'17;8-HAIZ!
MH;.=#1$,8WY<98!>4FA,:85B:(1A9'Y=87I::X=D:H9C:(-A9X)@6W-5;8EF
M;(AE:81B9X%@:8-B<HIL>(YR?(]WAIJ!A9F`C:&(DZ:.G*R8G*N8&B$86G%3
M'",:@)1ZB9Z#AYJ!C:"'CZ")GZV:H*Z;FZF5!PD&$A80````____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````-TUW-@```$5T4DY3________________________
M____________________________________________________________
M______\`LNZQ.`````EP2%ES```+$P``"Q,!`)J<&````(E)1$%4*,]C<$$#
M#,0)2(.`L[,S7(#1SMK&R%@"*@"4,#,0T%%5$'$&L1F<31V<F0SYU;3$1)V=
MI5B<&9SM]6SY9/@5M#0UA'@EN8$")DIRYHJR6BH:PJP\;#Q``4M!9PM=;2UE
M#G%G9U:@"K!!5EKRG.Q<$$-!5CGIJW-S<3,CW.$(`L@.(\US`**0-\]!9$BP
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V-A;&5N9&%R+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C$P-``Q,#0Q-S,V,S`Q-@`P,C$W-3,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,`
M`/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4```#_______C_
M__O+RL"IJ*"5E(W`O[>3DHR;FI2JJ*&WM:ZVM*W]^O"4DHR8EI'\^.^^N[2[
MN+'2SL;)Q;[2SL?_N$:9EI&K34'W6DS#4$CX^/CQ\?'L[.S@X.#4U-3#P\.A
MH:&(B(AY>7EC8V-.3DXW-S<R,C(9&1G___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!]6ME'````
M*G123E/_____________________________________________________
M_P`RJ/!<````"7!(67,```L3```+$P$`FIP8````>$E$050HSXV/V0Z"4`Q$
M.S+N6Q6+U[H@RG7Y_Q]4,#Q`3'0>YN'D9-+*LQ/Y`T@K;_`X%\7E6I8QQMN]
M`@+@")R`'%J#`[D@QU5//D:2K(&AZE19@[W9UFSG[M9O-F:]N6=9:!D>0FB,
M[H:FZ8!<DJ/-2KY=^NNY%PAZ%N:__-'V`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8VQO<V4N<&YG````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#0S`#$P-#$W,S8S,#$V`#`R
M,3,Q,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````S4$Q4104`
M!QP<'!T='3DY.5145%5557)R<HB(B(Z.CJ:FIJJJJKN[N\?'Q^/CX_[^_O__
M_P```!":08T````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]4$&A`("P<NQO<```!I241!5'C:78]9$H`@
M#$-95+!0F_N?UD)E&?.7-^D2YQPV.17*4D+W,M0)S#]&#)Q`%?$(/!(1GI7R
M2`B'=H'FB`BI/V0#+4([B&V$%[B`'!`FT`U9&#@G(-+'*M%MH,S'2_K*C&K=
M_^N_F],,42+]HT<`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V-O;&]R<&EC:V5R+G!N9P``````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,3,W-0`Q,#0Q-S,V,S`Q-@`P,C(U,C<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3```!@%!,5$4```"?.%,U$QQ?H(<@
M-2TRE981,C(+$@^6CG,J)QX2!@F[LYLP+2,&$1'':$E"(QBTUK@\1SU":VQF
MJJM\T=,I1D:KS[`S0#6WKY1%03,B+2H.%Q=+74L-#`FPIXFBEW:3BFPM*B$7
M%1$6#`BZL))Z<ENPI(%X<%B(?V2=DG/NUH!/1RL\."R^M)7"N9R\LI*WK(JT
MJ(2>E'0F)!PT,":$>V&_M9>]LY29CW`A'QAH6TU:4T&XK8O!N)N^M99P:%(5
M$P\:&`XC'AH:&!.HGG^DF7A333UK9$ZRIH3`MYJ6BVTN*B(=&Q6*@6=^=ES_
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________]Y6C?C````@'123E/_____________________________
M____________________________________________________________
M____________________________________________________________
M____________________`#@%2V<````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````BDE$050H%07!P4D#40!`P7F[/[M!<PR*!+0.JPMIQ1[L
MP4H$O>I!5U!G.@,`!A<`G`V7*(J8`)J!"="8@(EJWSS/U<K@0$N;0\4`EM;/
MM9^%`2QE>;]]>VH0QU_S7?=_#WT-3I2J=#6`?=O?VF9I`$MKVJP-XJ;ZQK''
MX0R\7+^>/G:9`':[/>/9/VM1%5#STJ5%`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V-O;&]R<V-A;&4N<&YG````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0R,@`Q,#0Q-S,V,S`Q-@`P,C(S,S0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```&0```#`"`(```!]#5'[````!&=!34$``+&/"_QA
M!0````=T24U%!]((#P<D'X*>ML4````)<$A9<P``"Q(```L2`=+=?OP````L
M=$58=$-R96%T:6]N(%1I;64`5&AU(#$U($%U9R`R,#`R(#$Y.C,T.C4U("LQ
M,C`PNJ0O=```!FE)1$%4>-KMG>&)'$<4A(6PX002[/W3#R<@<`("1R!P`@)'
M(!R!4`;"$0AG(&<@AR!G((=P"S)(8(.%Q/3\>;=U5:][NGMV:ZA?N[-SL]/?
MO5=3,]MS_UY9KHH>%STI>EKTK.AYT8NBET6OB]X4O2UZ5_2^Z$/13='_40^O
M%OWP>-&/3Q;]]'31S\\6_?)\T:\O%KUZN>BWUXM^?[/HC[>+_GRWZ*_WB_[^
ML.CFYJN^+??O>:$7[F!]1^B*T$-"!T6/BL`&'Q2!'?N^Z-2W$PZ6EY,':UJ.
MUD\!H-:_#H!BOF#^W]#+W0=K-L2NBY@-,CLF(F:R<F1-PM%U$-/R<J4J-L$&
MUL'+2)_UZ+2VZX\UQ<MD3>FS(CZ5/@L`Q>S8G7[=/FMNG[4VIN8^2^J/H%':
M9^W!9ZWCQ@S[=CZKG5]WS3J//*O29X$-,GF6?=9\/@N,&S/L:V&JY$C*19UG
M3>RS5A.<L_+-(].<E;?/VGF>)9T2`I_5ER/7K)X^"YRO,^=B/7V6\ZP+R+.`
MFONL+8N7R1J;9S&EJGEDZNN&^^R&0\J9)/NLG9-U>OG<2,>@5EN>Z&"9K`PU
MGXKB*RLLZQVD\96H(Z$^])FL1F2!XPTX`F4HKLS@$UG[%+2^5<D11LQDU9$5
MCR[#$:`F(K9=S0+T2:S=BIC)VLPZ@!&0^F.L8DS-JJQ0Z\?)"N6:M1E9D0CP
M%L,14\68FA4KE,0:0,S=<'3-RO5'0(3DLX!QEWI?1,PU:P.RI'8&UI'0R-4L
M:1UIY['_,EE#\ZS*D8R,-$'#>=;<>5:NUP!J;@A);3'7G9UG39-G28B!QL0D
M"@Q'.<3`]S)9??,L,$J`&NE,D*E9H&-*B#G/VE6>Q424`#I0LT`&FVMY/C<<
MW0US`2G(&&+F*=4L<'%(\GW.LR;.LUK=T"#YK(@8N`S>\#8(DS7T1/IS:S&(
M@5<8Z.Y\Q62-).NJD0[$KR^D5^)-KHE73-8V9'6@YG#ZQSL`'PD6('?#OF2!
M`R\!M8+P(`C@`Z"+6U[7828(B-^+8LUDU9+%''@P;I&:5C4K`L7@`ZA95W;-
M&NVSP.!45C&I9L6WUNW$XI5KB[<4+Y/5OAM6`@6J3\YG16HDH$"I0E7,9&U8
MLR2@P,J`(ZE1YH!*6GF3E20KQTA<!S#"<!37D?YZ[0F@R=I3GB6AD7/Y8)TF
M8)JL[GF6U'T8-*X)@8PAUZ]=L_J2Q3A="2B&-:9F,><&$E#.L_:09P&@#LH%
M&V"X)(X8H%RSICDWK&R43)HNB<G[G6?M(<^2?,U!N3S#^"PF[\]=+G0W')W!
M2Z4JOL+<HY"K695R-YPO=9#H&R+G6=.1]1\AYB:^?P@=@YA/,7^=^18F:TNR
M*CE:;\<$('PL.J8TB#63U:IF=2A5$F*CBY?)RI'%'&_F=PN1&J;EY2;0ZL::
MR9K29S']$4#W\;3LL\[.9TG%"U2Q2I_5ES63U=-G52+6W&<Q^V.?-9_/VJ[E
M-?=9*[--6#-9$_@L,)*5/LMYUF7G6:L8(HZIW^'G6(O(VV?M/,\"/EM"C#DE
M8/;GWR+[K#WX+*GEY2;08DX2G6==4I[5TV<!EQ?W.18O^ZP]^*P<1XS/\G5#
M^ZRFB$F]3RI>]EF#NN$0UACHF$;)Y%EW>GJ3M3%9IY?SGSW+9+4GR[-GF:RF
M9'GV+)/5E"S/GN6:U=UG7?3L62:K?3?T[%DF:^.:==&S9YFL)%F>/<L^:V]Y
MUIG,GF6RNN99%S1[ELEJ1I9GSS)9,^599SM[ELGJ<6Y8V2AW.7N6R>J19UWB
M[%DFJT<&?XFS9YFLP1'-V<Z>9;)&':SM'MC::LLF:SZRI`$$3S@]$D]3E7Z\
MTY4^D]6,+'"\I0<V'T\_>I?!!SSB/#[KO)(CA)C)JB4+/!P><`2HD9X)75FS
M`'T2:[<@9K(VM`Y@!*3^&*L84[,J*]3Z<:I"N69M2%8D`KS%<,14,:9FQ0HE
ML080<S<<7;-R_1$0(?DL8-REWA<1<\W:@"RIG8%U)#1R-4M:1]IYY+],UN`\
MJW(D(R--T'">-7>>E>LU@!II,AJF+>:ZL_.L:?(L"3'0F([*3"&`HQQBX'N9
MK+YY%A@E0(UT)LC4+-`Q)<2<9^TJSV(B2@`=J%D@@\VU/)\;CNZ&N8`49`PQ
M\Y1J%K@X)/D^YUD3YUFM;FB0?%9$#%P&;W8;A,D2EB]EY,&3)^6A!@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]C;VYF:6<N<&YG````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$W-C$`,3`T,3<S-C,P,38`,#(Q-#4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@
M8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!0
M3%1%````____[^_OW]_?P\/#OKZ^&QL;____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````2M?+&@````AT4DY3_________P#>@[U9````"7!(67,```L2```+
M$@'2W7[\````1TE$050HSVV/`0K`,`@#K\ZN___Q+&U!TP44/()&AHC5674`
M;0(C@U`!%G+2CG;F#8(XHP)3((Y7''3SO)1'SOX$D^C7<UD?NUX%)VP->?0`
M````245.1*Y"8((````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D871A+G!N9P``````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$R,#<`,3`T,3<S-C,P,38`,#(Q,3$V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```2Q03%1%`````0$!
M`@,#`P0$`P0%!04%!@<(!P<'"@D("0H*"@H*"PL+%A84&!@6(2`>*"<D(39(
M-C0P0T(_2$9!.DQ;24E#65A426!R3&!M75Q58%Y73V1U66-M96-<5&E\;6MC
M<G)P=G1K:WB"9WN+@'UTB(>!B8B#C(N)QW1FQW1GC(R,QW5HR'9HD(Z&D)"0
MDY&+?YJNMX=^@9JNEY6.@YZRA*"US89ZR(J`GYV6G9V=AJ2YB::\H:&AT8^$
MC*B]T9"$C:F^TY&&JZFCL*^IJ+&]MK6OMK:VNKFVKK_-P,#`Q<7%R,?"O\O6
MS<W-Q\_:O]7HRM;?U=31UM;6U]?7R]WKS^#MW][<V^?QYN;DYN;FZ^OK[N[N
M\?'Q\O+R]/3T]_CZ^?GY_/S\_O[^````<FH2,`````%T4DY3`$#FV&8````!
M8DM'1`"(!1U(````"7!(67,```L2```+$@'2W7[\````!W1)344'U`P($B<%
M\#(`@P```-1)1$%4>-IC8$A&`0P,R?$AYK9@8&_KZ.^?S)`<[F"HK0D$&IHZ
M9@YR0(%0A^`D*$@PE88(0$%0C)$X0D5B7!0C(Z,X7(4;%Y<EJSNS"%@@.BDI
MEEM+@5O80IA%%23@$>#GP^GM:F%AH6NL`A)PL#8P4F:SL!"34E-1!`G8N7@Q
M,@I;2`GQ"UK(@P1,O;R2U5TMQ/@X>"-`6JR,O'R3F80MU`1YU,-D&9*53(Q\
M(P4DN)Q57","]66!OI.1MO'48W=ULE!145249&"`^5\L65A1.%D4`+'U/8,P
MCWK;`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D871A=')E92YP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-C8`,3`T,3<S-C,P,38`
M,#(R,#`U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@&````'_/_80````9B2T=$
M````````^4.[?P```2M)1$%4.$^EDCMJPT`41;4:]ZFRB)!D`X$T(F!(;P(A
M35J#E$*"H#\1ZE1E!RJ\$/?6__][R1L8S]B2"Z.!4XES[YU!@B`(L!`!WN4?
M>-I(5W'_\L$"GM\DN%M_7L7MH\@"\/1]?Y&NZZ!M6VB:AE!5%;BN.PWP??]$
M_/[_]ONU/LIU71.Y+$NP;7L^@$(#D',YSW-P'&<^8&XR+Q=%`5F675[`R[QX
M\_!*P/8T34%5U?F`.;`5WP(#L#U)$I`DB06,XSB9C"*=C*TH8C/*412!+,LL
M8!B&R63:3.759D6(XQC",(3M=LL"</[Y0_%7P&8:@.V'P^$T`&5^)IV*;2A@
M(TH\BJ*P@/U^#T$0P&ZW(WB>!Z9I$@S#`%W7"9JF@6591!9%[E=>R++S!XNO
MDF!D\)OI`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9&5L971E+7-M86QL+G!N9P``````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q-C0S`#$P-#$W,S8S,#$V`#`R,C4V,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````"`````@(`P```//13KD```,`4$Q419D``)EF9LP``,PS
M,_\``/]F`/^9,\S,S`````````````````````````````````````#_____
M108```````#,^!(`,\K6=WQ:V7>B#]AWE`_8=QAOCP`8:X\``0````$````!
M````H/@2`)SY$@`0^Q(`,-78=_CX$@```!0`4#KY=R0```!(#10````4`.@!
M%0#0^!(``````.CZ$@!`??IW(#CU=_____]0.OEW]WSU=_6(]7<```````!`
M`#B&2``1````!`````,````8:X\`:-MA`$#Y$@#K0-1W:-MA`.S___\`````
M&&N/`!AKCP`@FO5W*9KU=QA@&``D``(`4#P5`"SZ$@`P^A(``````',Z^7<@
M8!@`?HKU=]@'%`#!CO5W/&`8`"A@&```````P8[U=P4````H`````````&)>
M&``````````!````%`#\^!(`>`$4`.3Y$@!`??IW.!SU=______!CO5W9I'V
M=X&1]G?@-?QW=)'V=X!@&`!@8!@`/&`8``#@_7_,^1(`!````"CZ$@!`??IW
MV!7U=_____]TD?9WE)KV=P<````X````*&`8``````"P51@`N#@!````%`!T
M^1(``````'3Z$@!`??IW.!SU=______!CO5W+H_G=P``%```````.H_G=Z"\
MU'<``$```0```!!>&```X/U_``!`````````````"`$``"A@&`!$^A(`````
M`+#_$@"&N^EW`(WH=_____\ZC^=W7%=#`"A@&`"@O-1W``!``"`````P.D*6
M<,O#`3`Z0I9PR\,!@*>1Y'$7PP$`````B0```"0````@`0``9&5L971E+F=I
M9@```````!C[$@#H`14````4``3Y$@`$^Q(`-/L2`$!]^G<H'/5W______6(
M]7?3F.=W```4``@`%`#DF.=WH+S4=P````````````````````!$VD0`&`(5
M`-S;%@`<`A4`;(9(`/_____H`14`GMI$`!@"%0!ST$0`Z`$5`,F+PK,````(
M=%).4_________\`WH.]60````%B2T=$_Z4'\L4````)<$A9<P```$@```!(
M`$;):SX````H241!5!C38V"'`@9V1D80S<3`SL["`.(S@'E@)H+!!)5B9H'J
M@@`6`##)`5S3D!GI`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9&5L971E+G!N9P``````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#8V`#$P-#$W,S8S,#$V`#`R,30U
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```&`4$Q410````@(
M"!`0"!`0$!@8$!@8&"$A&"$A(2DI(2DI*3$Q*3DY*3$Q,3DY,3DY.4)",4)"
M.4I*.4)"0DI"0DI*0DI*2E)20EI22EI:4F-C4F-C6FMC6FMK6FMC8VMK8W-K
M8W-S8WMS8WM[8WM[:WM[<WM[>P#_`(2$<XR,<XR,>XR,A)24A)R<A)R<C)R<
ME*6<C*6EC*6EE*6EG*VME*VMG+6UG+VUG*6MI:VMI;6UK;VUI;6UM;W&O<:]
MI<;&I<;&K<;&O=;6O<;&QM;6SM[>QM[>SM[>UM[>WN?GSN_GSN?GUN_GUN_O
MWO?OUO?OWN_OY_?WY_?W[__W[___________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________X6B]SX```"`=%).4___________________
M____________________________________________________________
M____________________________________________________________
M______________________________\`.`5+9P````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```##241!5!C3/<_]#X%@$`?P2^@I(J070F0C
M[R'#YJ6AA1#_D']=/4^YVV[??7ZXV\$W*JI<+;"`8S0!>L_WZR@!$*#WNTZ%
MX7K3V0PB8)VSMZWQO#JR[5#"OK\#_^;L%[O#JHVA__B$%?B7L2I'\)7TB7?U
M3J9>%Q!>FLF+C593DWDZG<&`+#&/6(I*%;@L@?E&M_2BEM-XAL#:-4^F/"P9
M$DI@X"X52_Q#-X'X"B,,E!"&HH*RR7.":0@:Q\;/8:(`2/P!5,`[KGAHF2T`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9&5V96PN<&YG````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,30P`#$P-#$W,S8S,#$V
M`#`R,3,P,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-
M00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8
M```7;Y)?Q48```,`4$Q4145&1G%R<G!Q<>;GY^3EY>+CX^#AX=_@X-[?W\O,
MS,G*RL'"PKN\O+J[N[>XN+"QL:ZOKZNLK)J;F^[N[NSL[.OKZ^KJZNGIZ>CH
MZ.?GY]C8V-?7U\7%Q<#`P*ZNKJ>GIZ*BHJ&AH9>7EY24E)*2DI&1D8^/CV]O
M;VYN;F1D9&%A86!@8$I*2D5%141$1$-#0S@X.!\?'QH:&AD9&186%@```/__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````)'0R"T````W=%).4___________________
M_____________________________________________________P`069V+
M````"7!(67,```L3```+$P$`FIP8````ATE$050HSXV/QQ*"4`Q%HSPUH%CQ
M@06Q($7L>OG_3S,,.J(+Q[-*3C+)7,J_H'<Y.P-85\1QLPSC:T6`92/\%.6-
M29">9(;T*?Q[MFU/74,M/&@1T:WE-IE91<8H$4/H*6FYX8T=MFUHTJA;%K_H
M@'*-0U8;#OK=`I.*+_YJM[^@9$X_LOPK'GBK*?8#9'$5`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]D;W=N;&]A9"YP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`S-S,`,3`T,3<S-C,P,38`,#(R,#$W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`0#````[=WB4@```#!03%1%@```````_P``?W]_P,#`____`(``
M`/\`________________________________UAC"VP````ET4DY3________
M__\`4T]X$@````%B2T=$#QBZ`-D````)<$A9<P```$@```!(`$;):SX```!/
M241!5`C78^CHZ&A@!!(,((8B+D8#@Z(@1(1)20)%RMC86-C8V(*AV04,#!E,
M0T$@V)#!!,1W*X8R7)R!#&,0`#'`:H`,8PB08&@4!(,.`./G*CJH?&U1````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O961I
M="US;6%L;"YP;F<`````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#0P
M`#$P-#$W,S8S,#$V`#`R,C(S-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````"0````D(`P``
M`-=/]B(```!@4$Q41>;FYOC9.$]!%65</EQ/*_&U3?:T1->N=/SI/$M+2TA(
M2$5%14-#0T!`0#DY.30T-#$Q,2XN+BTM+2PL+"DI*?___P``````````````
M`````````````````````````/X3TD(````!=%).4P!`YMAF`````6)+1T0`
MB`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]4'#@@?+"U)O]H`
M```Y241!5`C78V```TY.3BB#@Y4?S.#B8&,&L[AA#!Y&-F8!$(.7D95%$*R(
MCYU9&**-24@$9A*$9@``.U0!4E%KR;T`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5D:70N<&YG````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,V-0`Q,#0Q-S,V,S`Q
M-@`P,C$Q,S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3```!@%!,
M5$5&1D7\Z3SXV3A/015E7#Y<3ROQM4WVM$37KG3^_O[]_?W[^_OQ\?'N[N[L
M[.SJZNKHZ.CFYN;EY>7BXN+,S,S*RLK$Q,3!P<&]O;V[N[NGIZ>%A86`@(!^
M?GY]?7U\?'QZ>GIY>7EV=G9U=75S<W-P<'!M;6UK:VME965C8V->7EY965E8
M6%A145%-34U+2TM*2DI)24E(2$A%145#0T-`0$`]/3T\/#PY.3DV-C8T-#0Q
M,3$O+R\N+BXM+2TL+"PK*RLJ*BHI*2DE)24C(R,A(2$='1T9&1D7%Q<5%142
M$A(1$1$/#P\,#`P+"PL)"0D&!@;___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#VD:;_````4G123E/_________
M____________________________________________________________
M______________________________________\`K2T,<0````%B2T=$?TB_
M<>4````)<$A9<P```$@```!(`$;):SX```"P241!5!@9!<&]+@0!&`#`^7ZL
MO4*A<265"(5$01`/X;4)0B*1*Q4ZA5#L;9R8B5OW(C,RX@3:_2>(1;\=(:6J
MJLKZ^5JA)2.37KY_5!VT8H)U_)Z^;&VU9($IY[.G85,MQ033X>.P.5^V"*-I
MM/\X;"[VM&0MYL.'_KML4LIQ'*.&OZM5T8(UQW?7_;2=M!+;\U`WST+26LSF
MUP@4K0@((FFU$Q"([UUM.49&9&1&!/_N["E8KLDMNP````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9A=FEC;VXN
M:6-O````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$W-@`Q,#0Q
M-S,V,S`Q-@`P,C$V,C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````!``$`$!````$`(`!H!```%@```"@````0````(```
M``$`(````````````",N```C+@````````````````#_````_P```/\```#_
M````_P```/\```#_````_P```/\```#_````_P```/\```#_````_P```/\`
M``#_````_]C8V/_8V-C_V-C8_]C8V/_8V-C_H:&A_PY\8/\6UZ;_%<^@_QA-
M0/_8V-C_V-C8_]C8V/_8V-C_````_P```/_8V-C_V-C8_]C8V/_8V-C_V-C8
M_][>WO\15D7_%M.C_Q;3H_\-?V+_25)0_[&QL?_8V-C_V-C8_P```/\```#_
MV-C8_]C8V/_8V-C_V-C8_]C8V/_=W=W_$5=&_Q;3H_\5RYW_%<Z@_Q*RB?\+
M:5'_.D]*_YJ;FO\```#_````_]C8V/_8V-C_V-C8_]C8V/_8V-C_G9V=_PU^
M8?\6U:3_%<N=_Q;1HO\6V*?_%^"M_Q7'FO\<.S/_````_P```/_8V-C_V-C8
M_]C8V/_8V-C_W-S<_R=%/O\4PI;_%<Z?_Q7'FO\1I'__$)EV_P^1</\-@F7_
M1U10_P```/\```#_E965_]/3T__3T]/_EY>7_R9(/_\2K87_%M&A_Q;6I?\-
M=US_6EU=_X.#@_^0D)#_G9V=_\_/S_\```#_````_PZ#9?\074G_$%Q(_PZ!
M9/\4PI;_%M&A_Q70H/\1I7__1E%._]C8V/_8V-C_V-C8_]C8V/_8V-C_````
M_P```/\6U*3_%M2D_Q;4I/\6UJ7_%M"A_Q7+G?\6TZ/_#XYM_WY^?O_8V-C_
MV-C8_]C8V/_8V-C_V-C8_P```/\```#_%<N=_Q7+G?\6TZ/_%<Z?_Q3`E/\6
MSI__%<^@_Q7%F?\J1C__V-C8_]C8V/_8V-C_V-C8_]C8V/\```#_````_Q;1
MHO\5SI__#7E=_QQ11/\W243_"VA0_Q;1HO\6VJC_#'-9_ZVMK?_8V-C_V-C8
M_]C8V/_8V-C_````_P```/\7V*?_$K"(_TI.3/_8V-C_V-C8_XR,C/\+6$7_
M%M.C_Q.WCO])3T[_V-C8_]C8V/_8V-C_V-C8_P```/\```#_%^"M_PMD3O^Y
MN;G_V-C8_]C8V/_8V-C_H:&A_PY)._\63D#_F)F8_]C8V/_8V-C_V-C8_]C8
MV/\```#_````_Q7$E_\Z3$?_V-C8_]C8V/_8V-C_V-C8_]C8V/^^OK[_T='1
M_]C8V/_8V-C_V-C8_]C8V/_8V-C_````_P```/\E/SG_H*"@_]C8V/_8V-C_
MV-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_V-C8_P```/\`
M``#_````_P```/\```#_````_P```/\```#_````_P```/\```#_````_P``
M`/\```#_````_P```/\```#_````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)E96XO````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$V`#`Q-S`P,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F5E;B]I;F9O+G!H<```````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-S``,3`T,3<S-C,P
M,38`,#(P-#0Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]G<F5E
M;B]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,U(&UD:G5K:6,@
M17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(D=R965N(BD["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)E96XO<V-R965N+F-S<P``````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#(U`#$P-#$W,S8S,#$V`#`R,#<W,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH*
M("H@)$AO<F1E.B!H;W)D92]T:&5M97,O9W)E96XO<V-R965N+F-S<RQV(#$N
M-2XV+C0@,C`P-2\Q,"\Q."`Q,3HS-#HQ-R!J86X@17AP("0*("HO"@IB;V1Y
M('L*("`@(&)A8VMG<F]U;F0Z(",Q,#1E-&,["B`@("!S8W)O;&QB87(M8F%S
M92UC;VQO<CH@(S$P-&4T8SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@
M(S$S-C@V-3L*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C
M,3`T931C.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C,3,V.#8U.PI]
M"F$@>PH@("`@8V]L;W(Z(",Q,S8X-C4["GT*83IH;W9E<B!["B`@("!C;VQO
M<CH@(V9B.3$P.#L*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9#H@(S$S-C@V-3L*?0HN:&5A9&5R(&$@>PH@("`@8V]L;W(Z
M("-F9F8["GT*+G-M86QL:&5A9&5R('L*("`@(&)A8VMG<F]U;F0Z(",Q,S8X
M-C4["GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@(V9F9#,V.#L*?0HN
M:71E;2!["B`@("!B86-K9W)O=6YD.B`C9C1D-SDS.PI]"BYB=71T;VX@>PH@
M("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F)A,C`X
M.PH@("`@8F]R9&5R+6)O='1O;3H@=&AI;B!S;VQI9"`C9C=E,&%A.PH@("`@
M8F]R9&5R+7)I9VAT.B!T:&EN('-O;&ED("-F-V4P86$["B`@("!B;W)D97(M
M=&]P.B!T:&EN('-O;&ED("-F9F0S-C@["B`@("!B;W)D97(M;&5F=#H@=&AI
M;B!S;VQI9"`C9F9D,S8X.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C9C5C,30T.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@
M>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C,3,V.#8U.PI]
M"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(VUE;G4@82YC=7)R96YT
M('L*("`@(&)A8VMG<F]U;F0Z(",R.#@["GT*"B\J(%-I9&5B87(@<W1Y;&5S
M+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0Z(",R.#@["GT*
M(W-I9&5B87)086YE;"!A('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F]R9&5R
M.B`Q<'@@<V]L:60@(S(X.#L*("`@('!A9&1I;F<M;&5F=#H@,7!X.PH@("`@
M<&%D9&EN9RUB;W1T;VTZ(#)P>#L*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@
M>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V-C
M.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('1E>'0M9&5C;W)A
M=&EO;CH@;F]N93L*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I97<N("HO"BYP
M<F5F<T]V97)V:65W(&@R('L*("`@(&-O;&]R.B`C9F9F.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F5Y+P``````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C,P,38`,#$V-C4P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R97DO:6YF;RYP:'``````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#$V-@`Q,#0Q-S,V,S`Q-@`P,C`S,30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V=R97DO:6YF;RYP:'`L=B`Q+C$@
M,C`P-"\Q,"\Q-R`Q.3HS,SHS-B!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE
M7VYA;64@/2!?*")'<F5Y(BD["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F5Y
M+W-C<F5E;BYC<W,`````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#,Q,C``,3`T,3<S-C,P,38`,#(P-C,R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]G<F5Y+W-C<F5E;BYC<W,L=B`Q+C<N-BXQ,R`R,#`U+S$P+S$X
M(#$Q.C,T.C$X(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N
M9#H@(S5D-60V,#L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-60U9#8P
M.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C-60U9#8P.PI]"FAT;6P@
M>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",U9#5D-C`["B`@("!S8W)O
M;&QB87(M87)R;W<M8V]L;W(Z(",U9#5D-C`["GT*82!["B`@("!C;VQO<CH@
M(S4Y-3DU.3L*?0HN=VED9V5T('L*("`@(&-O;&]R.B`C,S,S.PH@("`@9F]N
M="UW96EG:'0Z(&)O;&0["GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z
M(",P,#`["B`@("!B86-K9W)O=6YD.B`C9&1D.PH@("`@=&5X="UD96-O<F%T
M:6]N.B!N;VYE.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z("-D9&0["B`@("!B
M86-K9W)O=6YD.B`C-30U-#4V.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@
M(V1D9#L*?0IA+FQI9VAT.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PI]"BYS
M;6%L;&AE861E<B!["B`@("!C;VQO<CH@(SEF.69A,#L*("`@(&)A8VMG<F]U
M;F0Z(",U-#4T-38["GT*+F)U='1O;B!["B`@("!C;VQO<CH@(V9F9CL*("`@
M(&)A8VMG<F]U;F0Z(",U,34Q-C,["B`@("!B;W)D97(M8F]T=&]M.B!T:&EN
M('-O;&ED(",U9#5D-C`["B`@("!B;W)D97(M<FEG:'0Z('1H:6X@<V]L:60@
M(S5D-60V,#L*("`@(&)O<F1E<BUT;W`Z('1H:6X@<V]L:60@(S<W-S<X.3L*
M("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED(",W-S<W.#D["GT*+FET96T@
M>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C965E.PI]"BYS
M96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C9&1D.PI]"@HO*B!-96YU('-T
M>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O
M=6YD.B`C-30U-#4V.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*
M(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z(",V-C8["GT*"B\J
M(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG
M<F]U;F0Z(",V-C8["GT*(W-I9&5B87)086YE;"!S<&%N+"`C<VED96)A<E!A
M;F5L(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(W-I9&5B87)086YE;"!A.FAO
M=F5R('L*("`@(&-O;&]R.B!Y96QL;W<["GT*"B\J(%1A8B!S='EL97,N("HO
M"BYT86)S970@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U-#4T
M-38["GT*+G1A8G-E="!L:2!A('L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"`C-30U-#4V.PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE.3L*?0HN=&%B
M<V5T(&QI+F%C=&EV951A8B!A('L*("`@(&-O;&]R.B`C9&1D.PH@("`@8F%C
M:V=R;W5N9#H@(S4T-30U-CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C-30U-#4V.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@
M("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C-30U-#4V.PI]"@HO
M*B!0<F5F97)E;F-E<R!O=F5R=FEE=RX@*B\*+G!R969S3W9E<G9I97<@:#(@
M>PH@("`@8V]L;W(Z("-F9F8["GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:&DM8V]N=')A
M<W0O````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-#$W,S8S,#$V`#`R,#$S-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]H:2UC;VYT<F%S="]I;F9O+G!H<```````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P-#<`,3`T,3<S-C,P,38`,#(Q-3<W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HD
M=&AE;65?;F%M92`](%\H(DAI+4-O;G1R87-T(BD["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:&DM
M8V]N=')A<W0O<V-R965N+F-S<P``````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`S,C$U`#$P-#$W,S8S,#$V`#`R,C$R-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!B;V1Y('L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F9F9F9F8["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@
M(S4P-3`U,#L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V-F8V9B8CL*
M?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-3`U,#4P.PH@
M("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C8V9C9F)B.PI]"F$@>PH@("`@
M8V]L;W(Z(",P,#`P,#`["GT*83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#`P
M,#L*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#`P,#L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F9F9F8["GT*+FAE861E<B!["B`@("!C
M;VQO<CH@(S`P,#`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F9F9F8[
M"GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V9F9F9F9CL*?0HN8V]N=')O;"!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9F9F9F9F.PI]"BYI=&5M('L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F9F9F9F8["GT*+F)U='1O;B!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C,#`P,#`P.PH@("`@8F]R9&5R+6)O='1O;3H@=&AI;B!S;VQI
M9"`C,C(T.PH@("`@8F]R9&5R+7)I9VAT.B!T:&EN('-O;&ED(",R,C0["B`@
M("!B;W)D97(M=&]P.B!T:&EN('-O;&ED("-C9F-F8F(["B`@("!B;W)D97(M
M;&5F=#H@=&AI;B!S;VQI9"`C9&5D96)B.PI]"BYS96QE8W1E9"!["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C939E-F1E.PI]"BYI=&5M,2!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C939E-F1E.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*
M(VUE;G4@>PH@("`@8V]L;W(Z(",P,#`P,#`["B`@("!B86-K9W)O=6YD+6-O
M;&]R.B`C9F9F9F9F.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P
M,#`["GT*(VUE;G4@82!["B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@('=H:71E
M+7-P86-E.B!P<F4["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I
M8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@('1E>'0M
M9&5C;W)A=&EO;CH@;F]N93L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@<&%D
M9&EN9SH@,W!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`S<'@["GT*(VUE
M;G4@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#`P,#L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C-C9A.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@
M<V]L:60@(S8V83L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,C(T.PH@
M("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,C(T.PH@("`@<&%D9&EN9SH@
M,G!X.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!C;VQO<CH@(S`P,#`P,#L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-A96%E864["B`@("!B;W)D97(M8F]T
M=&]M.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O
M;&ED("-E964["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@
M("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*?0H*+RH@4VED96)A<B!S
M='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q
M<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9F9F9CL*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VED96%S+P``
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,S`Q-@`P,38W-C<`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O:61E87,O9W)A<&AI8W,O````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$V`#`R,#4V-P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G<F%P:&EC<R]B86-K
M9W)O=6YD+G!N9P``````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-3$U-C8`,3`T,3<S
M-C,P,38`,#(S-#,R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(```*\```!T`@&````0V2Y_P``
M``9B2T=$`/\`_P#_H+VGDP````EP2%ES```N(P``+B,!>*4_=@````=T24U%
M!]4"&@L/"3E2B"T``"``241!5'C:[+UI8N/*KC280;E.[W])O8_>PK>`[]IB
M]`]Q`)!`#I1495<!]YU7MD5Q2.80B`0"^'__O__#DI:6EI:6EI:6EO:7VI)-
MD):6EI:6EI:6EH`W+2TM+2TM+2TM+0%O6EI:6EI:6EI:6@+>M+2TM+2TM+2T
MM`2\:6EI:6EI:6EI:0EXT]+2TM+2TM+2TA+PIJ6EI:6EI:6E)>!-2TM+2TM+
M2TM+2\";EI:6EI:6EI:6EH`W+2TM+2TM+2TM+0%O6EI:6EI:6EI:6@+>M+2T
MM+2TM+2TM`2\:6EI:6EI:6EI:0EXT]+2TM+2TM+2$O"FI:6EI:6EI:6E)>!-
M2TM+2TM+2TM+2\";EI:6EI:6EI:6EH`W+2TM+2TM+2TM+0%O6EI:6EI:6EI:
M6@+>M+2TM+2TM+2TM`2\:6EI:6EI:;_'D$V0EH`W+2TM+2TM[4^!3S3^AL;W
MT?BN-6:SIWU3^\@F2$M+2TM+^][`E<Z_+=`)\]T1H(I!T-P[OW=<<>XY^CTM
M+0%O6EI:6EK:#P*IHY^C`3P9`,W6N6<`+@>NW0.H%HRS`6+9^3TM+0%O6EI:
M6EK:#S`.?(X`&'H`EYWK(`"IK;^5B^!Y/Y>\-^^>1]O(8Z[3TA+PIJ6EI:6E
M_1#SF%R/J66)F=D90#KZ-UQ\EMZY<.%\I=,>"8S37F&9M):6EI:6EO8$`+2`
M#<YGZ`#85#=HMRT"8(R)\Z3]VY8,;UI:6EI:VB!PLFQC"UPEV'K_.V'0WG3>
ME[76NTQ+P'O=F*,_+2TM+>UG&@=!5]KO?2>MA#P.O+^2[R\![]O<X[2TM+2T
MM&]NHPSN")-H054NAZ^'%9%4&A+<IOUVP)N6EI:6EO9#K"6GU=/![8&SM/>"
M7_E[,O-I"7C3TM+2TM(Z`&JT($/:SP#"T6=,,/S76ZHTI*6EI:7]TV#(*YL[
MR^"F_?R^@')-JS@M`6]:6EI:6MJW![OL`)QD^_XNDW'7\K_6^\X^D(`W+2TM
M+2WMQP'=4OSJ9JWO,('/CP.T$6"5U>)0,HPA`6]:6EI:6MI?#(9L1:]6LE-K
MRSOM^SDU404X"7!M/V"^YP2\:6EI:6EI/QD`><"U52TM[>_O%Y@$R6D_UU*E
M(2TM+2WMKS8V@&\$BM/2HG[1DSQ+2\";EI:6EI;V+8!O+U%M!#"G_1M]9J9J
M6]KWM0QI2$M+2TO[)X%O]'>OPEJ"W7^K;[#1'](2\*:EI:6EI7U;LS&;"6+3
MO#XB^T>&O?P]EB$-:6EI:6G_A(UL2[^2U</$?6'BWD>N9;?BT3@?!N^+`\?R
MPO/_]#Z3EH`W+2TM+2TM`?8`2)T%4UY<::0X,0.0>X"]56IY)-;Y=\9#CSH2
MF826@#<M+2TM+2WMHO6*&7#R>`_,L@/>9@!?#R2B`URMMFT/H+^B;3VP*J\U
M<IT$N@EXT]+2TM+2TB[:*)`:#06(BF3T&-<(Q#(`SR-@>;0D<PL$OZ)MLPQP
M6@+>M+2TM+2T'P2,1UA)#H*^T6-F&.@KQR3X3/LNEBH-:6EI:6EI_Y#AR>_B
MS==(2WN')<.;EI:6EI;V#QE_PW>3V4W[;I8,;UI:6EI:6EI:6@+>M+2TM+2T
MM+2TM`2\:6EI:6EI:6EI:0EXT]+2TOY5XP^_UXS*3$M+2\";EI:6EM:TS%M/
M2TM+2\";EI:6EI:`/2TM+2T!;UI:6EI:@EMK[ZCEE98VVO=>?3QS#+S!4H<W
M+2TM[>T+(AJ_?]=[_:[WZ;7G#M)'BN+^C6`+;VC7V<]'@!L:@`X#WQOYW/NL
M=;UG0"(N`E8.W#LOW`><,=Q[7DR,H=D^\KO'(YTV./^>@#<M+2WM[8"$+P`/
M?^)>>\#CN[3G*%A`9V&,%L\6N,(`R,(`^,/$_8\\[ZR3]>SG,]]YU[W,)%OR
MB?L;=3Q0?D_QY9&^VFM/.L#W"NB]<GT..C9E<%SXP#T!;UI:6MK+@-@(:'D&
M],XN:!P\YA7/^SL,V]490`D,M@P&CAH])@8[^A,$O-X(Z&(`ID;??7TLR0*@
M^[?][Z44]9GWMY%S]<X]<]ZQ:Z#3YQ_OD%MSH8P]_Y@S,PK.T0&N,^.#+QEC
M_GWWSH\GKSES3&],U&,S`6]:6EK:90!',_7J2;C/T\V"7KO@S`+:F$$9NY/]
M*`P_X:O:G!68;+-Y#``C7MAC(*Z#@5;`U'MN@>>1ENQ`?@>\1>#Q`)CBS$V@
MV0"B'GB$^%X/Y"(X7WC_9"G[W_>?6<Z_'>^0V_\]WJP\5>]9]W-@HG/MMZW/
M#6?((CX!4`II'@?5YP78KN<#]\<AKV5M>X[+\]>:!<`)>-/2TA+L/L5.,#@+
M&XP(71[IE6S(Z+$0D+W/#4%!=4Z#K!C`CO%P/4<B?J]PWT0ONGIF4[?7BR0`
M4"SE%+R>[\DJHM.`P^/WX"$5ZPI[S@8[+,Y=76?'EO*<XGM'7W287P`*`%I6
MF`Y@ENU-B32/O]$=-ASI;=2_\`*YZK:3_+UU4O&9]^SR67TG`4V0RLT).-[-
MB=)U;]M`->QWRKX;@_/OL/-(/3/2F2''`'0]3N1?$O"FI:6E/0EV_?-<WUX<
M@>`SQ]B["?G9D1`^!>9/1LQRJM&BP^!3=F!N!4S8:V-4(*T$H-<NS_J^`M8Q
MV(;F`0#*R20:8*)!(,K85C:=ZQ;WC8;/*`Y3`"EXU^$Q+(6@]2ET6\%<I['+
MKZ[C?8:@#S3?.54WJ>[MP(';=["#PX;+P]+>-?<&&(K3'XK33J:_<V)>"N]=
MM@F=CE!TV^)Q#GKM276P_FQ[)N4"PYDOT'=8J<9=W=?IS7S*(:OG"6X@.V7)
MTM+2?KQQ^]\5@,GC^U=`:2O>C=Z%W*-I_AL'LKVG9N.9Q4\,4"DUF*`+J1`]
M9G4JALX!BR^KY/Q=_<JA5II[N6RX#(-)8T#-LN%<]`]P@>(S>,U\M%8[1:C1
M.0RECDZ)7H-WF6Y_:9R_#%YCI#LSN(YL?QK`-C9,ZGM"H[NVM@]ZVPA7??.C
M#S7Z)AI=8T90860+!@[@Y^`[[#ZH;7N.39;"P4B&-RTM[:^PJQ&:V(#<:P(:
MYA>RB-ELI;08^FC[#<&2)^.,T0Y>:"U&Z+.0?9T$^HO^%2PZ=#R+97K[)X<#
M0M%86/<%E?'GDETC8J_GN`[U<;,J7/('&N#M?=8,R>[M$_2'0O@<;+T+C'<L
M>@YF`[FYY_"NAVO];[\?XN)Y&(]\C@XXT^^)>/BRT2[/^HF1?^QUJR.^VG>X
MW7[48\+%1PEXT]+2?IS56Z!PYM<STM#^[J_3_N?-&9YE7OYU&.S5!V(879C/
MML6$Q0%=[-T4S\40(_2.CHAP6=T#T-&PH19<1X\YFBG./@AS%\U6DA("$`<'
M+'E23PZXL.^`<.X=^EU<=@J@G8$N\&P`W6'@5B8E9D=1/LJ\=BW>?-P4LK^(
M(M%H`]1.EG+D!OO1E%,9N^6Q<^+T<3I]TW5D6L\>][L$O&EI:3\7[!YSI]9)
M.,$H=3Q:Q9%:QI'-A+)SFF:`.>>T#F)0QC/NSH.Z="9WBT/8`RD,8OX:"Z]D
MK-`]VHD\8`6.W?;K,HVC(*'S/8X4-+`@52S6MOW8`DGL@+G6WG,O%@`=4#0"
MHEKG>E8NZQF@-_NW*^=^5W_C;VB?T?[."6?YU?=TY1WSA<_^P-`)>-/2TGXN
MV(VFNQ!W-H3AAT$OFW,Q1W;0:9C-7O)5!7;M0PYD_%=XZTD`PX:F0;A%W@)3
MK9?W3J`U0Y?V0,,K%OHKS_PJ,#@*--)B^UV.`;[A.\&W[B<)>-/2TKXMN+52
M/>UENL="=8`4[-G0.%OC.F3AD."^4?>I#CC!8YRC)8"7%.-LRB^4.%EJ&`P]
M4T%N!)S]22;Q%<?.G;$%[S%Q1U%1U<C=P.2]/O/]UG/WZM6]KKP)&D]T)9,L
M<N"BZ_VIOON[P&[OF6?;`Q.]KZT%DX`W+2WMVX/>\=78;+<[*R6\"94",,J_
M-W?67U,.E!2ZHJRE@F``\E#L:G@<:I6A=X'(/[@6CP*D=Q9W'@DL&`&^)0"$
MO6"%48YV!G+T7!5T0'@/V/>>I]5OO;;!T%MGLU1,'X"/5E/\">SX:&EK7AQ5
M5\#_;/A">Y<L`6]:6MK?@HZ+UH;L+\[G].TDOWBQ"<,`?'2A$]=!#,S'RD+T
MUB2K=_L[%]+7775<L=9G$*_<30MDC=[+U>MP$!R^TX&X`D?*B^][]CYBZ,/@
M6`[?`R?OO,4KES*NM\WR#M9[YNWPB=;YDZ#_T6()>-/2TKX)7IT+8>@"2#>"
M08CW8P1J8![L7F$Q&*-=CEY[?^Q>92;@^[SSZI$Q!/.?X8=>#<`RLO6'S3/?
MX)K/1'Z/I"ZF^2V8@#<M+>V/`UWOY^=`;V\EX9\.WXPO<#$B`.,-'H)>C['$
MI3OH;6U&*KW\,1O`:6G?%<Q';'"W]/1?#IRSTEI:6MH?![H_9RGYI@;,W26C
M;=WG(N5BF&PDX\J$?GY:6MJEV2JJ<N@5O8L^[]5`_$EC-AG>M+2T!+T!B/Q)
M;.-8Z$.K%ML<W*]SW.-(U]E8S[1_`Y3A.UY\5CP@\O'^J@;K.[^O'+]C(HT)
M>-/2TA+H_F/6JY85+UU\XHHL(]NA_$W]R2VX]V-!X)"XVYZCV3AXCU[QHECD
MWU@:+Y.=?^V-E])6^Q*?$=<:I"H0Z,@I5,H-//S8*;R+!MI2CT/E*ZNVW__V
MBF'^KSA#(Y_--DD"WK2TM`2Z763Q_?&NMTRP`4!?E3'_6Q5TV5=9MD`.%YX-
M`W^+\%P%RCH7LZ!(JN2AU""47F.;"\LNN__L=6..9E/U_FU5^/4:!0U`R\'^
MQ\#3LNUD^@SIG&,4?'$,G'EMKOKEP,_=ZKEITRQP`MZTM+0$N6JVW%`'^3.V
MV=D&8I-8XEL_)H;[W/DJ[=^!]KDCN;$FMG-NCH/HUP.G+K`;??W\'GVP>=R,
MCA@=<#SKA3USSV_RG;V^6!5?G/*>TGKS7P+>M+2TM!"I_(3)G2]9_[_[*P'Z
M"W\%&`5(\K;OY=8X#55KZY"X8'C4FTBP\GN!]0^;:C@AL3W=!LBNL@_3!+QI
M:6EOFLQSE>\Q$+U8PK^-I7W&][C<G2RHD-68ZPHD-5@0Z>B$`X;Y)WO0=^C%
MW^5^_CV\'T4[>/T3I;R.*?YAKSH9WK2TM`2Z;UZ81G9@^>1Y_F;SDG_\UGG1
MJOB*"@'_SMN91$!19EO:JP!P=RYA_TVV0H</MX8OZC:_N9T2\*:EI278?</B
M\TI\Q-_Y$-\(D\1;OCTY@._6L._N:<^X9*US1](+5]`+O@G0G;G_?X>Y9J>5
MV.@Y4ZT4=:??T,P)>-/2TIX$N-@8N`2[/_;F37PK>KCHS0#79W0C`/4=0-0/
M>]'CZ7\_N)>/2.\QZ%D(]4QP%%'A\?,>20^G7?5QWQ-47]7A[AV#&;_#<[9[
MB8I3%TS`FY:6]A38W:;T?P#K\J?=+,8?RE4',']HZ8AZJ@BAW%*ICW&3S9YZ
M$S.*ME=Z`3K7M"OP%<^A_9V]#',LC!:A@5:P<J_U\'3+]L0KQKHM-U#*-X[U
MN/RU]W.K%_B\N7Z_\SWE^VN5C93!44[VC'K'!4O`FY:6EG:1/.!/NED/Z#9!
MEJ/BRS;[*H%O)`DFP>\U,?YH@Y7!9QQOD.YQK8W<D2#@*]X*._V.0V<Z`7(Q
M?XVO@0841*>]NLE4Y>1%>W_S(DO9$\5%"[ECX&%QX<WM-0<YT#;M$BWL]G[_
M#?RD((R99W:?L1=Q8[Z<@#<M+6U^HOI'PA=^=-)8JQ+6$)CTP6STZB40MNSN
MZ#GFEL@K8JXC\&`4,HSW"F]['`.N5'0G-1N("BIZ<%R>>>3N>Z!KO$!'"\3.
M1+^S[L_R7_F0W#VJC3XD3.-L7^+H>Y_12L'`8'P-2)SY&P;G./RAZ6KZF8/I
M`(%/G(`W+2WMGP.[+?R'#K1Z&RB]N$(T@0=G%Y@K<9X^B'U=-YD-Y'L6+K3*
M@,U?`4Y$:!OLRD_9E:(ZKZDWRE_9;]%T+^H[9-/1"-HS*D/<TN=SNP5\-E?6
M`)8E[2R"BN))BW>\]R@-L*[*`8X"XUYH2_R3#?M@(Q2'@6-T.E2OF;9^SQKE
M]^$$O&EI:7\]P/66CY&"3;\%F\T&,7+L_L<K<$4;BW^"\V&9"0V(P."5:JQT
M(`$KB!"G,EV!V/9:8RT$#9YZWD_0(1DE"3E?810>P!H@$@XHM-<'YS*A%-J&
M/P@8O;,2QLZX6)J"`!Z9%'IAT\UGHC/V@PN3$\-P=WX:8UL]Y-D2O7[-HP?B
MQZ6*)N!-2TL+@2[P=V6_OQVZM\#N"*4\0BB*7=K]:WQ+BS"`!G_VS?32QDH#
M['+X)?H5;='<EO?H2-M\-CELLFZP!$1#50<L<NMX2@@ZU$A)X)DD([Z^]R!X
MWSC0O?B;*!O.@1X_XI.Z(X0O'@:M&"LT'(Q67V<@.":<&A[!]\5Q"W]"^MSC
M)B\`WBSJG);V+X'>>NSG'/`T?FSARA[&Y&\"[V/HZPWG[0=;-)__,C9'\^EJ
M\,,S3I0")3;92_;1>K3D8J#9>M3VJPIK\$\.L7&V/YJI.-@;^,0PQQ.C`*,'
M'YT2DS%$LG1@$+!"<0$Z`!E1V_:#=O[4U/SQ_.24EI;V[]CW`+NCLOE_'.0V
M,%BKHE$H0E!:&?I1G.2?:BT.W%/_V^&W.'8"3L*8@[V*M-9JKW"^6:^$O(PT
MWUOB=%[?(T9U,YYQL?G^83WLN[[MVH+1[4F\M50WQCI?<=A@.Z;J8&M>\$+?
M5;`Z0QK2TM(&IL!QH/(G%M#OZHI+K4T&=]Z+H)5QA344:+VY5];%1;P(AL?9
M-S12*((!-+5!I9/(`X[7$(K=FUA)LGW+W\2Y"L$!7W]Y#(#4R,68C7S(_:39
MKJ$[]%C:X\1<O^]H2`9X3Q1D">*E<;F;MX42$_"FI:5=F3#9JBX@=7^^+^C]
MT\B:TT@L7G#:P."=@OO>`C.:F6,A$;H.@:Q<%;4[R6N>32M!:"0N=0)LCB[M
M(^)7+?=AIIN"_EMY)_O)%_=4OKF?C^BKX3O-11-/1W<_B$^U.&@&S!'2<V0M
MFF3*%L\\WF(CCE+O3`EXT]+2)I48)DIX_:;%[JT0?)"2XN54[C$HJ1>($0#:
M2+OOW9TE<%Q`SD/_M2>OU6JK<!'F[WBYK^^C(WF)'@A])5CDF\!GZ[F^C>>[
M8:XF$AT)")>"!CTO!.UVWC<.2A'ZU&5>S_@[]O?]P?9$0.CMJ%,UPU/V*.74
M0^[.;>BZA+TL@P2\:6DOF_I_UL8;]?\;6QDQV`H,(LKDS/];WLK)-KB@GM=6
M<%O!JE:]O]IW,`A01E)JVFSR:#PL;7LZ<#5:IGDEH'4R#K6W88L&OOE=KEMK
M?X3O&-=_"OS\Y@NS-T?-T.G/>#0VV@;Q?9+^2(TVUWY*Y;3(R8)4_HA$SJ4\
M6HA:>:EUY!$)>-/2?O;4?^UN-\FQIVK14TPG&(!B1YA7HYK7JR=W:$DI]N)`
M>>6MXPGGIQ="TF(Y9IVLR3A8%XM2G:XG:2^!,B.M6+YVQ(TH:OTSX'`V2RQR
M^E"NUN$8F(OV7?%M3G+D$#E:#8T32(P7&G+4I[TP+&G:E^)1)3O,B5GD.P!F
M-OQNE%J\)$S@+2-`V%/1/O>B$O"FI?UKT'R;@=J,9X_R,[,86P#0S+P!3M/)
MZ*]CS.F!M1<`EM?$UK+12-<@5(PG7ZQG9A@;1JL3G;;GZ][#MU(!_6YTW&C1
M/)98AVW@7*0N+>W]C%`YB]O?L<U)<.:FUH-P\N]/-.2[`XK9\&=Q382CY;]<
M<<7?Z02.ETAV.A,B:O_,0EAR^4]+^_?`;GL*>I:^B*?E\0F;K]E*)H__7@6X
MXC9[)9*,E@,V@>Y\E;47/?HLZ))_P_46N0J1W[F`TRHX?>OYH&X>TO]Y^KSJ
M9Q[_QHJY4<?P2ZSP^)_^C>(X!O\^V]_&S_/$OL*(Z`J=@6]^9^=4T3[2=^B^
MOA^&0E,.6;\TZH$H/DR&-RWM;P>Y,RL7T%CI>$4@\A+IXF91CZK%RQ,,"OSS
M>[XU]W>V5BYG&_2W/>2T0`7<'85Y%@N=?H6W,Z]:X&3;H\#\]YM"*0/#B%'?
MM\PK].]VV%=QIHTJ'P".D(03DGAO=#1RNE<$W'./]<"G`SI'0"\.$*6WP^NI
M!4&R&=6YY-]TM3YV=K*"M\M&@'(OE@<#<Q_,.\?[RLU<GPEYM"QL/V'#\P(3
M\*:EI7G>_;M\?!W7P-%5_:I<0V>VYM0]/X\:*]FH#J;'C$;#=U$UF!*)&!,^
M>PIHOWB59A#VHUG-\[E&`*S=[F>GK22&YVC?+RRDWIHGHF>RQ380]D()=,L4
MD^JG&W*V-ZBDI^<&)Q%KU,URM0Q*Q'"HM+1^#R@Z2AZJG5!%KKI5`ZEE`$=>
MB1OU)L8W1/<8219]/0CFU-!/P)N6]A<;1RFC2RCB!:#HV6.>>"QV%ID!B#D!
MCHH"*AY[LO\=Z%>9??4KFA7E\/.74)2>F4+T=%IX;INYV[Y.5_<2H)Y_CW/1
MCY3O-)24H'.M1C+DIG5*SKY1UN<90LL]UM7"$#@.&RJGET_7)L-9RADOF)->
MZ-*7IP`?FK".KDIV'/^ON??X?J<F"^JYR'8E8HAS>/\:*`!_`MZT/X9GTMX(
M<J]B5[*3;W]MLO$W,QN]9$(6[.J]C*UXF&FZ=D2(=^,.>6Q+X=*[\Q>1SL_H
M'-<5;X/Z2`[8?=7<X"5$V:S_WKL:^?M<B]4@SU494`T1ZC75U\1(`E6OWZ*4
MR0I<-+6\^BW"X`S/J)H$UQ@)98H]M9<XBQ@$N_&E/8=BILP"+HWC;G/@XD01
MG+07P/$.5GB_9@+>M+=Y56D_]6WP;5<_=A^?*-IVKEF<@=`#BS.ZP,5;XF3E
MVF:\XVB-51F'*W@92@;U"8S`-QQ;.38;`O62))_I70RR\6SLJ?[7N!";,"@)
MY:``WG7XNA$`:'UJCD#'>CL=C&%!7\&BI0DW4AC8=\ILK*1[G&S3J&XVGN^T
MZ@D]AY*Z@K3GB%T1_Z-M"K.;TP>]G/3L+S+BYKM4H22H7\,KO.(.NN9O`K\)
M>-/2_A98^X?3PI^?G.*Z8NUY]`5QH.XTV]["K<HOC"9M3>V(RVSD20W="XOV
MRQR;M_;%YR#[>6\\PU,!(==W_<IP?[.,+#I5UMIT)2^U0Z,#VM`3V_^Z1?W8
MCW9HW0H:0'6TP25FQICV:^1_MGZ>]^[;6+8[*\&IT,:HOXU,P!RZ:2^ESE.X
M[5X4P?MNQ#E$P36O`+XI2Y:6]I>`W5?$*EZ!'IX<5DNM*HK9]&X?Q5??>1\'
MX#_!;TT2JVZAKY_+QKLI932.[@?LR^!*"6RKA[;]=RS&$&QK]-]8>@S5SSQZ
MNQ7/*L=?I906@M'S9KD-=#I13SK.:]Z!>2#$6[/`V0&$P-CP>DF[7?'-HNBI
M*@:]_AE"8</IIB_L"`Q?#8X8;#R'KS'>Q5\A_I@,;UK:7P!VY;]__'X&R)D:
MH-<N/IMG?LD,WYQANQ7>85!Y*:^C4KVM>[,;CG*=B6JEPQS@#^]P*%I]HHZ]
MK9L!W??E@UTI$87C7"/QEL/O"9*']_[_,_K6O-Z'>K651RH2C-X:8_R"!MXI
M)2[F%@4;5>=C.%Q>);+2;Y.I^(=K8\0;,]X0QG2L,H?G1:W(@6::W&S?F>4R
M9AXQ`6]:V@\'NG\*U+[B_@%T8[K&>)EK&U^L%#P'4T<B3;&)8F8C.,2&.+[\
M'0R=4*R@`ET\2E/[X*45#5KGG\,LZ!L[2KCO:P[(M^-6J=12X6"6B3"2UB5[
MGB$&SULA1@=A>?[@J#;S!;#[#,9S_P;3YP,UBBGW@'--_D<FQMFRYE&!$UFJ
MN/;'KDR3G5G,NW4]WA`"XVMM$G9;M-]O`MZTM`2[4][SRPD,LY,[5PL)UZF!
M0%^3%QZ(3Q!PG/SL/8NS$VS'5F8)RC!V:LD4,2I#'8'=`."%0--K231='LM@
MC2RZE_"#$?E':71IV;,AOT._#SIM@M(J[_MGG=]I$'[A=*.[Y]^I,G3SQEO'
M>ABXIUQ11$@V9F:OOB((C7!:Q!N4\H2DFU5%-!*/2,";EI9`=W;!Z*S)\R<3
MT&,^IY\!B.WS"1S!SAV0^UWE]Q@A,GJ@9W0?FVV@VHS_*,TDGHAYXX@2?G2=
MW@IZ)&C1^9SNGX>JP!F,;=4?/-"I_M:Y"&>:HU&$ZCFWM]?P&!OT3X/K<<YV
M%$?/`*]6Z,6@0$'?<9K9+HH*9/;B=4S?.D'O(YD3WC2!F?<+QW%]L7_C/8^)
MK$C`FY:6UH]7+>4YB?B!.;'6*GV-YD)[_1#"]9/M]-3D_!9GJ.C0VPBK_BX/
MR7DAE0A`\<)'&LZ*L^A:F2FWLT;*`[)?VC!R-)RCJ^]G\+-'N`B?BQ-%>8&$
MW<Q&-%X&;$>NHH$3@F.>GSO0\-<P"-A:+8-WC;F>$XB^NXO"$J5:U-K@//49
MIUJ8S7?XL@Z3@#<M[8<`TC<QNR.RL*^\#ASYH#U1:7:J\ZI\66DGM+[-<23X
M;#VH82+D5>M<JY0O$;[QUA9C^V$LC:3/]%@+,8B]9%R@06T!X<O`<3L^H]FN
M-7JI;K/Q56-W'/BJ\3Y2/*$%LA@Y.Z,/YB3Z-7M?]/[Q1.^.TJ$:Y7,Q\>J\
M2LH38':&G>3L4'WU=-&N"W-.RJ*32EWM1\Z%G#X=,%R5>1ZE'FJWXF7:O.)9
M$_"FI?V+`/HW7B34MQ3;N^3,DA=!M?HH5G7FQ5EQ3>[KTGK=2VBZF$535:9E
M!^PVMG\YL(@C;&$O$('5L?&FKQ=7VX`>1I^4''\."7I=Z/_"C*:G]BGH=PV6
M\4T)OSO,@-=1/;)WP#0,M"RTOX7G+O'.W9L9`0S$^/3"A7$4@E'DP!8"(4&K
M3$25)`3%=_>?T:R9@HG&CV1"SG<<;,1,O^<$O&EIWQF8OH'9?0O8O5SU=NR(
M:K%P04F]7(5@EWQO&[5RI2R;Q+D(2>DP>)]&U<B\&^LNI"Q-47@);QM!?N+;
M(QQ80W!M?W6,VF%T7(DSOR@0>P?_Y]U+=@``(`!)1$%4?,-8BR+58T0$`^(W
M=\,I2[R7&*C<PZC<F%%\<'VW&6+OJH-!C#F0$^=G[UY_TYS;*X*!TB_16[4%
MY*[7665094%VAL.NK$.R73Z]4(%L>@`9I8P5J>ZSOJ-.31:>2$M+L/N2DUY)
M/HC978Z=BQ%@BJI32=7V:]S2S"3+;5W>MUFY/_.^>.P@#IJ!E/"0!G-PF.Z)
M`6:OM,'S#='CRC`(=C'05V1!AQ<-BL9UZNN>[#5?.BH9(WK;2;P72X?797%*
M5Y]E92F>J0+1$NA2C#(X0XLEKACC%:`;51WTQ`$\_^C9#%NR'97QAX/XV7$I
MJ]G3OB_@8'X/++S]K0EF)]8E>9S.*T#167`P\S;*2!WV9B$*R$MM_P.2X4U+
M^]O![N^3MGK%.L`8RTXO7'`G_DB;Z16L+KT;EH4<Z#@)<KMP!\`EQC@:)(RF
MTKPP/*,#<'4TM=\C;(RJS=GF4"!M#3)[,D<M[-+O;#"@%Q<]`_91&ANR3Z($
M,H[0')QQE8(-`P,W@*WT2]1M2=OF-`@8=7B-:7LX_;>*LQ882(8\J:1$#KZN
MT@"]W;PJ^,>VJ%=<G.K>D..GVAT"8*)S.7);>Q"WR\3:I!ZQ*E_-R<:;4%%F
M*<NR'(!WMP2\:6G?#.B^JD3P9=FPT:W`-R#I9MA"5VYW2`*B>%7+7K;*A)4<
MZ)1]@@`>DV"3)0!=+.4ZU]E<RVS(L]Z1I'Y,1XK+>PVJ&>;=(.'$G+_;5T"T
MG*`./:2>S4%R=K#T@LZM(*HLO!(4I\)QZ=VA@`Z?V,Z'[=Q^->J9.G(R7M/3
M!XZ<F)8S0E.&EN[]66FV.BGQT9D0@$^U=2[TGS$S14"TN5(R,&FRB!!FF57J
M*L-109&DEPTWZ?1HK96W#Q0*HB68='A]<JSR,%EJ>15/!)C./&,>N*K!"1_9
M)^!-2_M&8%?^^WLO7L+J3+\+[]))3!HD^=H(W04J+ZXR.I7:[[%KAMIJEI[S
M.<99F,OA8&M_NY[6=_#"/ZF/'>E(/3]GZ""70,4<H71\%_5EZ3!?IL\:G0J%
M[(]$/^IP1M(B1U30,$P)9.ME\N*D,*A:@<X?%(4K'A9.4/;A",0[%FS$]:BQ
M"`VD0_;?W`H=(!U=!ZTM`Z-*$PS<ME-?(F>I\7T3[$^(F%T'R*YDX>K%QWCL
M1R1R[0U`^##5Z$.#'A!'^[FB)6Q!`?QHW02\:6E_(WA^^8'C3.!U#@!.H8')
M9T!C9L0HBGXMV&UK(D0K6XMW.UOJ\DXJ'9(G!.1ME.C))W,(M;:73?^**!Y#
MC]('';A8D(^EKN!;+>^6890LH0,20IW?8FE&\;*4XV;89+ZZ8.[L.!FEZQLT
M:H@PG1<'ZW%AP*MS).*FYK2ZC6'50EJM:?LD.CY#Z\-6%)/K:YB=0\&NKNOZ
MB-MU+S&*T!N)IDZ_C%1#SF(^NJ^/;CIB5Z3PFB)ER=+2O@$X?1%ZO!CF^BVJ
M)_#BLUX[\]S6'(=N=$SU`1-/QD"NY\655YVM:-N;,-[V`YEP-K60C6=R0QF<
MZ`$VNC0<D-R-C+!1!R)>FMZ^M0`^9._-=WHOH&-LX8@&V[U^X`"],[`WKHG&
M\#BW+P=%8TQTK]B]9NU%!'K0ZG<OAE1NC3\Y6XP[`O6[YA5Y0UN\D+YOY^[`
MR5CGSN1R)*)!%/IE.<"NQ]W6Q8C8\&%;P3,M9XQ'HIQEXT>GE?VLR[+4[\=$
M-B3@34O["\#N-/CI[7HV1._YDOOT%7*?17#GUB5=%HZ]%"5WX9[9.V\OLWS)
MRYD!L"/'Z:U'+:V%X9#$%D#".!YN/_=&H9(<;JDC!(#ZJ11Y"L&Z&0*Q3K"I
MGX04X-2],0OF6",<&^CLACC1!_ED<RCS!;V-YHP,QT$=7QG'G:+IJO@[/@Y;
M2(:C%<YH;%60\UH2U36][VMG%;W)E-[$6M/^?,FT@%-2;/O+`^S&O5K_?;QD
M21R0PW`B0BD*>(]-:#@<WP500\AK5B3@34O[^4"7LP?_1CW)MJ<N=4O%8A>L
MT#-E?6?6!HA%4S-((YPYFT?R[?W(/`O*19J_*&FJ%KOB$U%4L`"EO9"Z"[Z;
M0JX9/<X@^H[#=0*!4M&55)1MK_FD!ATGAQE.<,1V&946FWVEPM=0@JJMPN56
M@'-TR]#QEB&=*;KEGSV@[.>&2?!YQIN/Y8O510[L5CY+J-`6W&F)G?G.W?1U
MK'T`3=JGL(?J#+Z=V7VUH3%'C,U"&"<5Q'1A$[V/F'AS[=3A34O[P6#WE:BU
MJC9U(9SV);?"SKV]R]P@/#[;K&]I1*E)BQ$RY(6WY0/B$R8T]3$/$>(8+_G]
M#F]Z]WN6DOS7`;-#C0(A[A]K0<-<>P2TQL><,`&E5C3M(PSHP<4>V)5)9\4(
M0Q?725!,IV'`*]$'U7G0S*&E>'H6O3N!-E12VLD1L#S!M#R*9C[BH?,ZOY^#
MMN/@`K](Y)C"\635O1]=>U.KKG1VX4^RH]X[^W"=Y?6[6S8N&A7+B[,';<<E
MPYN6]I/!\X4#1]@@=B:7_J582KAI&-%,[P?8S>M,HL6AF.E69`1:T"8&NL7!
M(1U4U']^RVZC!WB><"H$6/#/+R6WMAB_3H?@(*28\BA&>ZY7U]C9Q$49V&4H
M<[L3_E8S&EO(3MQL*]^HZF3S[<6H#S0U\.K*6E$J912X4,/6^HY87''K8E6M
M=A;ZT13;.:'+=LA-"A7<P/JQ`7NW(QF>QN'H.)[^.$!9UU5FARGH'X+>UO8"
MVN\<Y2U2PU6Y8\@^`^,B9VGAM+3?"$S_5*SNBRY$7/MR%`'7O=ZW]1S:CH%[
MO@9S4F-(CN,)D]LT%;@9@9!6-AHZ#DJ@(7V&KF@=60\@NK]=+!*"UPS<:MV?
M*YT]+JG_?+\7'2'<%1;)8NP7**D!/;5STB[)%3H[32#=<*KH.ET8:!/O>(:G
MT>'M=,8K3C`K"X>5TV$[^OZ1C$6MC*(>I5<ZK@0BMM';:]5<9A5[@%[OM')H
M;'68]AW9-X!G^SQU6`P:P#P!;UK:#P.[ET'K;P"$PZD-U?XN_W#[L#M)7VTG
M3XO>T^_G)`EVB1+L'<(V=GFLZ0PQC69:3&(/M1O4O!![4D;.BLER26>Y!XGP
M)#`=BJ$=_9R=PT:DAODDO!;OJ!=QJBNML:FL,73-:%#`1.4RD#*;?6P$_<IS
MPH*B'#L3+!U4Q3$KQK>4(6%>5V>O;GWYR`N@_"'8TYFQ>8)VA!7SP@'3DQ)_
M-?`550;=`A?;OQG#FY;V9K#[JLIIPC]_.5`=FO@Q=MC4??-5B'SDKG:!5/TP
MRZ*U&_>E`E/G5H1#-_'+3O:]4L*O>#\VZL_=%`T6*4"'..\QQ%;W<@>T"NSR
M:NTW#O0O$Q/L!1"S_=;8^.S5ZK:^LU?:$J:VDYB`W8-8%&+`L/U"B@!@;(IH
M52?C)&#%_,2I`]5'>HBO"W=]\D0#@YIWUW5,@T$G;SEZ9/)J@VJM;JG0(,>I
M?D14G:2.HS8HV>XP#4H3>G/D/#=TGNE1.$/&S]>=/1G>M+3?`'I?N4X.'3A=
M.I=-$`=7&W;VAH*_7J13FR&E@)&6VE)+4(3>8VMEX7R[32;Y<9#0:ME#>_)\
M9@;9UT,D,/U780EP3;9%"2703-ATM_$U95DY2N@C+'2'2/<S/C-H(1@H*UN&
M!H"!`W0'0714$8ZL07PS/!/=V<%M,P3.PI7L_2BDI=[A?W&D*,?GV)=.XFB#
MWBH6F%&5=?%FM\ICF+CU*/Q`*6-<D0>Q4Z8M!3WM)%GQ,SKICDS`FY;VW8$N
MKW[A*<D`4TVHH$F)77U*E/;B/']"G"&*$'G36P9*G8>%8UM6:[1.--_K"[<-
M/NK&K`(:-]UNCRE_?90+/4O9MA8ZCA(SPWV03YQ!%C)N-Z^GC;HC!O$M0`-D
M&<(:+J#C,2'=?$11;:U2UF#P/<Y?CX-CLUG4PR9_\1*.J<@_##I=Z'A[$?GM
MZ1KW8D?=.>BI05E>)5(^C/\9>@]&)$V6_SMTK,<]*IT<N3NC5E`28P5I>I^Q
M]F'(1FEFF2)X:`W3S1Q)P)N6]@V![F4F:8B(X-0).>+-M\X]4#WTE!2B*770
M)7M**1O3:<#?6'5;%'(]J`9>S5Y[->9M+)Y:>U0\)38&NRP%MU*6+3[P(4/T
M`+^DO[K\[B[+EN/3`DGTN"9['J.+VJPG^SQP\9C-WNDC8,VIX8Y*I6%4I]I_
M`ERZEVC^>9D#54I7:BRJ@=>[C['BV9,@#J_I5_/KSNG?2;LM-_5@R[(4KNO#
M(78!<J]/TNV+:JVH)OI>^1H_^)><?WX-TO5JDH`W+>V5B_@6UW@5]+XZL>P:
MV'W!C;$-O>.U`G'A":\RV-;>T7;F$+17$CV=5<E;%=&IAG1E.55;X?YS$RPH
MR\%B`QZS(_HC6>[K_8^`VUY>?3?\3U".W3*W84O#([_\.T;C1F0P<Y#EWL([
M?!$,9.$+YP^,C6>\L!-T+L.!/N+%P5]-./422R\!X.@&^+L'',NR+`5+O1X!
M*`LVB;)F<//8%A8CJ3>GTR`$N8&K9N3&#J$)C/1\$:-,9M):6MKK/>WK8!>S
MZPK;@.$=(69E@@N86E@QXKV;)S7).[,1!M.,K@5+J(I'!>V!:QVB\4<*2J<&
MN\Z:`91EN3F^P6MB'Z\H%[`,2+O)M&OXT>1Q<0'Y,^,2<+T!)#*X#@?)%ACK
M8$-;Y@`O]WA?^/*BF@<7\?)L%^/@UUG:+#HF;H43S?%^]N().PHP+`5[[.XQ
M1]AC$$]LLF.S-%Q+E***;Z#YEO0X\9A=DW3&UG@<[V0)>-/27KU>X#J`N+8=
M64(=Q78.!YRL7'_20D/KJ<[G%4H(>X*8444(V=@-2-`])ICI!F(,\>2B%.V(
MNT6FV+ZRSHON8PXVEN,]7`$3B&-9'J#W&;#+H79&M9QY(+1Y!12M]VI2V+VD
MJQY3S*W2&WN@E_I'VHI.\G8XK@PW]/Q\Q\3408I.4'!5?(X3U^";YM?!@UK5
M_C@T$_O-%"NPH'$<NLHMH\Y@.Y9=%YUX)+36L;R>PTM9`5%)1]B+,Z06Z+V$
M!M&`HUVH_NUV`'3:C['J388TI*4].QD_N]WG3%V\\@6,E)D]OS![NZTM17\'
M.*Z.[L-\73VG5H8,'IIGFO+T`H<2"O"'[YA^=G&[[=B<OR7;X6Y4>V*KI3SB
MCP=YBZ.VQ(*R$&5=:=I\S'GHR=U;%^B(-R5CG!TZ"G`:6_<+3@T4AXD5!1!"
MS>02AZV\=-=Z=!]>Z(XV!7"=SK8G+'D^I2P(`OLVH^!X+X.N%[(9/O#`H(JT
M7DU1!Z]IGH'7(PPP!4E`MPZ>3/$J;I\KC3DU#-P23"U**<OM=K*W4F6'>OQ0
M9%':VIC$ODY$HQY3L/Q\"%FA#D'X"OT4N$@V4;[LQGM/P)N6=AGH[C)#MAS9
M']C+@@]P&,;2#B#T`;::16Z7G4R<!!/8)<*VI"D+_0Y]2(DJX2!V&=Y+S2RL
M7,N"^0VKQ_W1"9G0LF=`E$`U#W9K9@2*"7*1MM6)$J=9R8>H_&`G0?=^@X0O
M&#=)*!TTTYVV>.,*/895F=BHS1<%>`]@*/M2`\_PI7'T&&ED#=+.[L^CCQ[9
MY]15Z[SK4GEDNI``)5U+*-15C\R&EC(A"XL%&-N!:58CV&$(T7`Z@=*0J*BU
MAMW["L'P,UEE'!CS96IWIS3)!/.9<&(>84MG1X*9[_8YF.M:D1-NOX+5D^]$
M-[<"H1TE":\\M.Q_H7H)=+L^YG\T"`LFX$U+>Q;TOF*I?(HD=BMUH5HXW85,
M"#E6Q(EE3>FG(\B)<+77$HLVA,9,M]7("N@@0O';8GR]R`=B6-K1LI\"NJY8
M)ML+2*=\ZX.E&6=Y]_MJ:?,7LC!H9UV/%-K7TZI??6!-/R+0MHA;H0[P=;C<
M/XE2N$"7GY+MS@&@V@2X;+"=%#X,?<W;(HH%T%2JTV#4?YM:R8'^K;'':OIJ
MNI3`MVAVN%D>V`#IN.D<Y0BGG6#.<;"[G23>HVH83$^@[C)#"#6Z$"Y,\';8
M(3ZMM3U)#8K!KV^"ZVJN%0=+T$Z"JK1T[%B@M]U6H5BV^TKC7'L2GMN/^)@C
M,Z0A+>TBR'U%];2I[??&+,?6%Q"#XB/KG9:3@5A,&,332L"\@=W.%CE:!1_0
M$_H]Q=/ULVQW3+RTJAV?^FZGV(*W4C<I2@LBKDOW'`!I!W/2L>B5;RT2:,(O
M_B!87YOGHK4_^_TW9+V@J<(H4H)BP08FWW'X_/%0K!9]GK=*:'`)(9;/8L1&
M=X?#@@P)W@\GPT-2,DBF\1Z]L:C`C(DXMJ*HE/=OP%#4ES;FD08$@OV=D`.L
M1>%%1JN5+8I4;<II5OD@OA%7=T9O:H[B%*Y*2)A-Q+I54);;LNVF>4FLIJC.
M!@#[Z@O.SUO>`!L%0;JEB"<:P_8+.(61EN6\JL7PY+XV)<.;EC8-=EN@[MU@
M:F1-5HLM1LYAZ5W!!.R@MY2(']):KXTVB\#HSOZN%H"9A1CEL7T?;@M>?">6
MS.2K7E)OP;,+(WH]A#7]?K2KCO]%K_=5#"X[ZXX$8`/5S3S?2X#E&@^T]D$[
MSD!C;+%HMJYRBBY4'&C>&458.!S`(*JNU2=%\&Z<P2Z/`<+C:)S-?OE=!B"U
M^$ZH;04.5$T`*JHVY!=;W<%!8YPH;RMQ/!N/1_C#T+K=>QRI]=]=EC*JA#&*
M.@WKNRQ+68YB-'$OW>-VGY4F'"5KT)H3;76385$;.?>5`J'![MW,(\QC*>NZ
M)N!-2_L]]DQIWGIQYLP76'O*/&>_QHSE)5&)+/?B5>MI3Y"AT#M0EE(4Z%5@
MR;)"$1Y<6;!<5QZX0K[$G.2`0Q(U#AR4=.S3HG(8QN-S'^>HD[%09^:9)1T&
M4#.(MZ0E`X,US>H+:R8V9BYY43M/.JLH"!?6UL*],^&/6$CK"^@H5)1!]OU2
MO(P8@1+XF@2\HW^(E^)6(#OB@QWVT#"ZK=X^M(-?@6I$TYSJI.^JAL;>X!]B
M*`U(5DIZ>@Z&5#")PE3*X':^2$3=WS]")[)LQ6=>2;NT;ZUZPXS7-/4EMVO4
M\]Y16MT)'V'A5FI]7P93EBPM;7!]L0SFA:D7ST\DW1*.9B*/6<\&2%6:/M0D
M#\V$MB>B<7"=<1@HVBU0K\TB9DPNO[CB4.R+A-@&OKP6F(P:-IK5_*[RMH_=
M9&B@RIIN6I;EG/0G[A/+XCRH58FU4DLZL00RPTH\$$01CYUQ\GN;D1E3(38V
MMO0$NZAO<_"Q3U!`E&9E0F^X2K![7!JA6Z&>J2V4-8`).Z#BB+UV9-N*"%]Q
M?,FMBB(5F5I5-:O"GN0UK)PAS"R%H:'#ZEP#P`H]J3\C>-4$>YS$@6@BY$-N
MB_48KW$>*K`[XD0_0AEN*CEXAA)I._\L+P/&&%K8&L>:<A78YK#&',!U3Y)^
ME%HOI23@34M[)W+E#&W8$(ZLBQM@Z@:>G;;V"75TI_"8@,5_TFFPWUW7`#3S
MG-A;(0M[Z>-YL,IZ\V^R()K#\[B:H*U[UUK'&NBJ'"T5+FDU=<>[UF,!\%<*
M%X0[9ZHT:@6K>RS7%:#M#24H90P-NG$RJP,=L94,>3AKC377W8V`T%1U\PEU
M8MR5,)M.SI>X?RN#)1W==DT-_399'1?5<-.);A;:R9_0$(ZKP;$=>-X]N?=,
MY_G%_^KORB+$7B=B&2R+4MIU_AB.'0O"V5:@K9['VE*!7=N^K,:EEP,@DT4?
MXQJ%?%%.!`>)<XH!X,@PHA0'W/M.SIE8>9X[0QK2TIH#]3E/>;A$Y<1E?$T!
MR;YQC`-NZ(E*9@="?R@L$P_-7)Q;OD+O,0+S<`2Y*"'?HB=\5X2<9MF[PF;T
MWP,#*N*J]GXM,67++S]>@,HCVKYWN]U&ZG!4MJYK6;F>SQ,^.CVNSY4.HQ,"
M;%E*=H%I@RWK?SFNZ`I]DY#J"_O/3BB`0NE2N:(J=5K+!$1L7E1,M=5W.*/S
MW`OBQK7IIP*<KD1J*]O>ERU`&,X`$SSA2UCY0-9LIF_OC+(OX03EB+2OG;D6
M>M+1Q5&:@)CNPD#H=J!D.`:QILZ-0#B2N3$"*@_"$M^5$\="0@R/0,-YL$\-
MI338&':34[+84O*!Q)]'YB?@34L;@)<NO3)P/$=6E`"[2LW$]E=&P"[#R6%D
M(@H?0[#-DKTE&<Y'\;U[(!0*E%7?E((199R>I9D=&WB\4C/M-M*$_\*JSSB\
MHER(MGCFV\=-Q>L-7X\LZWWM212HUC_[51&+,[O/W%)44Y#0)$H^P.5`#I\+
MJ^#WD=:Y8!5'2IU<U4W<\H897:>7PM&SSN71!.;61F2M$`#1IC<^/$Z<4<"(
MU+3.D0!Q1>M*$_0=*C>>W02^5\_`\X7+A*@@B%R%#4S,BP=TAIZU$%`1)X#?
M"X6P8O&K%0/QN('-6!-T1`C=]PJ#49A;5!>;,"#X-8QOU!WA>7A"U>94H+@6
MT9V`-RTM!`>S'^":W`R*H_V(]GTYE:ETW%<`AM!F=KW;6SH,I<?`L0<<3RKX
M7/QI`8MS;M;SLWS.95"63/+5=A%H%,L<`[NS=:%G?*]2RDU449K=?[C?5W=K
ME)[#=="C9U(4M\X']%$8Z?<`>LQ?D+%],#Z=^$H%(EE:H=2UGG.D2*"2W.PM
MMC;]'[:2*@R(Q>^T-HQ&XKJ*K^00AQCV'ZM]3+H[Q[7/%26TE1K'>@5C*AJO
M$AR)=QK`6.H/#'2:)=8M/C:..8'&#AG\L>+-@36HKQ.'X7S2VQ64;M2"Y4R2
M1#E"$"0C>Y;39EG75>CJ%E^T5NJQ!6'8(TF^5RMYEH9/JM9(1'>P)?>NLGC%
MX]\$O&EIU\B/J<';FD2/;>J1K4M7V)"=[>AY;.7--J'LF/>S!06(JHBAZ*I/
M[*[@;-SF@KBNJ0L.^*C2)E=&A*Q/K9?JW6B3V60IXU+!M9+`;:^B=*&3/I(X
M5JVRX2ESH/:2`![P-,Z<EAO25:L$BY.;1:7(N1UL=9FAO8^A[52Z(%>!7[@,
M';R=&P_/B1CKX<[K:`DKIP[6"8B),`N:))NHOD>_")T-GVE%^S1+,`^0ED<H
M3$,5;U:QJ^=X>VULPW>:-6(NO-/(2;X:"K7W+V`II\J)F$Y9KQ`RE.EL?^/,
MJ;$0O#7,/7Y3@7&2?-+%-)SB&I2OBL9!2(8W+:TQ6+W"\,-$WS`B]N923[^]
MY>^_`I1?!<+]$\.GXU1+\U$\PIU?<50':\E@`<M0C"*]R=139P/J)=U=U2$F
M90XUV1CPK9>&9<%$A]/+^KJN@F"+X[%/K`\=UF!QON!H;0(<7;RY;4EN",S;
M%0#K=U\&W#F&GNK9T(C4(LC*-7+*'00<M</X]=Z/HWA2NP)T^E;1X,:=K[;?
M]YV38GVSFE>4$FM2K_A*<FZ\6QZ?CP%!H)%^'=LAWP5"+E>^-QTV8<L,TTM@
M+3!%%M!UOKIL,N?G9SC]&ELA'M*.10UH]\(+]_NJUY=2[P-*Y[(2V:N0*WW/
MRWA;A"^UQM*N`MX>/('#K8@+J+?-9'C3TGIST93B[=BYNR$%G<A,-A;;"5)W
M9!M4E01V@$(%).D(*P8R,RR-DL<!I(_9W47IT8Z^EY43T;;T@10[,2,!$1Q.
M]&PLJ_?[^I`ALF6?#3RTJ4%'L@J#Q[%4'"$2@7HL'YIYZ?(^Z!3.*&!-*AVB
M_^P.`PK@5B0X.:IO,8`#\?@\0Q'D=SNEAMUW$C9&QRE#H&D+[4`HC5<!`E48
M$&(TZH%G,AB#-OS$MH'\7`)2G5]`E[:S<!-!K,5)8=*J8<"#G@(*2AK9=-B]
M3'(=G&R>746?UT$(JYK9X$8SRXA;X<*4,`##J3%BV5T)8F7;[I*1ZWHOMEB0
M=1_8<DU@)K-M[D<W'AB5M`=%XEL8KALO.0VB0(Q_=QLD*ZVEI;V.\70+-=30
M8(_I\N8*H*B):HYQ'5MXY[;,9LM0R0D.`UEO]>+K5%$U#)=>!"$D;.@4MVP"
MG8U&=YT.L@GB"MET4MAZ;@,8B`A@%%4<[<ZU+%P*$;D&"$@EZDQVLQC0N6$+
M$Z/X2(6I2KNIS^UKA&$57)UDK>:HL\50=.<A3;^,SJOZ'45$"7S'!0&=+4#<
M"./;*ZU\['`(0'DRN";.03Z[C//VJK(9%,&`Z3[#'%@5$M%XCRYH5KL)G@-#
MCHQ4_[[#AJ1/LS:UVNCJ/TCFDX%[<C:<?&_1/@JKT#0+-:%*3HMFEE4+Q3$V
M?ID\Q\5]O9ND7,U]UOW-V:&A48YI#B.94\)#4A)F(F%#L]/*[5T)@?`<MP2\
M:6DECCM[&4`6U5["80Z]@/<XRC"8`<YW)S75)5MZEF,5+)=,;++Z"'+=]6(T
M/2JOB^1]Y`"@T4S]J;(I2>5`;+I;>%",]_'XC.M2>9G6K4??\9J4Y.'!1(XL
M"=`):!YC*T`4!.<38T.=I`F'M?=?+QKI@#@8V;%AQ<;[QC"[:E_TKI#2[\.1
M$\,J$4VSHR?+=VR9`W4P*\1GQ:&_FIB/O@*%!;J&J:-'ZA4=VFGCX.',,6PY
M/?U74$;\"[1&^[5RB=>)@GU.4X2&9I513QGFU<2[$1($KBL+;@BJMIW@=]W"
M&6P).)H7*;$G&[/O2,2.+&@BM7W[6Q_^>BF3SF1"=_2NE229?">IPYN6]KHB
MBVRQ#HTM;>F=-QF$'J@)0=\<3:Q9YL>,#,N"*IQYSN80H*FIO=MX$UKWL71%
MV8\:]A9(#D7;^:!)/:_0['23NL2JY>/Y@+EJOE8HZO=8.Y=%A'X@*`Y17V<7
MQ%CIT+G[/>[@1SQ@3-"C-`MI!66P.8PZ-<B2R2F//LE&E9#8`0":ZZNH"L>X
MGH"YS:.OVN1W9_<?T$X!29>%E.$94NGA*,`BRL@RV"JRGQWE@V7\-%F6H*PP
M&Z[G;%@J)XY5B7:='%8.N<4^:!Q[`L1](-K_D843J&0<CC`,>+Z+[>M.'X/4
M>>9YF:@Z[[JNN@RU<<0]U8O>^V^P),$(K#GO(6+C"&O:_M]6$5,6I$&58K&-
M7JZ'HHQLVP2\:0EV>V/O*H3TU[*)\Z$Q?7#JGF=:I%*M(;O*S:7<```@`$E$
M0535FHZM5GH,(@/Z0%_(C\]JUWS"@_:<3/TUV_Z>^#H<%#38R'092+B4"B;[
MTKJNY;;<5,QJ!R&>+/&R%-SO3@SB=FX&GSB/<(!NQ5B*?T&%BTU8;4B2>VNH
ME3=[^%1H@(XZ2886CP0(RP\1D"#&V7IE'[P=IX'N[!(`*#DR&GDSY4A!L;,N
MHQL<ZS%U*_G\?/F&.9D<N6ZMX^T=WRKV40<&]";_@<P(&LIQAZ4[^$24;$$W
M%(QF&EJ6I10L5I]+MUM0:GJV=EQW:G5UDF<=W0ZDWLD4^#D:%&$2M*RV.',"
MWK0$N[_AI/,YSQB<VI][QB-N[V!]H)(?V*-30L9L$-K3S["GL[ZPJOQULNI'
M7?6)EH:0_:)"872H.RM*J1N#`8!%)=INDDS8REV'^[[(A_ZF"W0:R''!(ZE&
MM:2(M]8%C<6.!3RA>[CO#`%@L2D_%6M5X;83#)Z:PR(5B&V!J?/]HEO5K'9X
M]BU0Q@_D+<_;`[G`(GA0E%H+QL\'@V#VMG;80VAD2`VM1)Y@BAM,+=XP'YZA
M4$^=I"-G,B9T58?N^O.3I^B@]HY4=0\6&^.B[P3.7(!ZL$#0M=1)72WP!P32
M=]MY5Y&?@`ZH[<W4`W5JAHNDL',B1",LB%ZS^W0/-1J?*%D2]J0EV)WT-G\+
MP-;+$1M30G7X\/7$^<76&RG.QU*:@9R.WN/4<P9,AK\H8:!5Y]X9%LO>XJR=
MZJ!]3Y)*<BCV*W4M>E3.!DV(7;U):9YXM:\/0]4N``C'H!U&K:39G#[`HV2T
MUQWLGFG=*UI@]XB;I?BVV#GPBH2P8(?'11<LT3`[S%E"()!$?YC18;#VJHCN
M<'&!"31@E<?*6&T)NV1L_0[HHX(-\"L8>M4;KX'=ML[PTV#7:S<54#RJ`8?N
MNU"EH$]AY]./=!O*G/M(\H7C4DAG9*^\0;_S"R>%CA-S.LQP^Z5U%H!-[A%P
M4GK[_\WX)NWO8>AWBO<AYQ@9VG.PW;!.=QV@)EL]&=ZT!+O=29W3W^VR2DU&
M#Q6X\H7\V02?O>NS6_=XM)ZI_97=B;'":8(Y7)9E\])'SH8IB%LG<L,$M_J!
MFXQ`K\T6J?/"BA5>M<!%+L*XJLAN&3&))L4Q>]M6,<KJWILU@?4CP5^XSOST
M.O!5]CM6]74;+VQ(SHN^"+"G!B$RW646.J@KRT6QH3)D`+/S"P1H,0F3KBR8
MD)D:'9^<D7GQI6[C8Z(GC3++U'=[Z6>-5NSM9(S,]D'1$9:Z\A[IS<6=`D+'
M,\N^[?QL@:YIY[":XL:<[W/(N2,GJM4=,H3G39'7`PN&]\UTR++):ZU50/PK
M0D%7">QW5KM5=GP!RCVH_)D,;UK:JX`R^]/X#%N"8U.VY3$;5DLP1'VP"X>I
M8/P$:-TZ:QZ/`2L&S3#B2$98RG);Q(>-6-=1\78G<UE.S(\0X,5EFJG$O,Z,
M:'<OF&,=2(,:3H$3%AL+1S_KA=24"\36/E!NRRUN2[C=RF$*S[Y9`892]"(L
M&2`O\Q$=P#3$W[&41I*DOQ%0A[!`LJL"R%:C`WH;N\,I]CV_UG?8.R^'P>W!
M&/;$+3`Q_MTQ?\X&=)E,FHMYO"(:B8FC<ZG3D>7O[+&/D2:QI[PB^Z+3OO!N
MR<@WR+DBK'.CP>YY2EMB_C++XTX/X:X`2C-FHNV6(9@`$/1XQ&P+^X^:#&]:
M@M97?0?C`Z]W'@`!.<'8I8;VC)L.^'&O+1[8",:S55S-B:7T@A%9+ZB/K?9S
MX5M7\0QH9!4?;OM`_%ZO!JHMI5MQ$8W2>%)SU4N*DE)`#AG;90*-T@,LR*U"
M&CQ5_3/#_\'R[NREUH5N!8WHQ=5;@Q#T(?9C`-$`OBA]1JWJ*&:AK37H=3LZ
M,1:/W*&:)9=J![9W>*/IE#A#S2Y6[YKA6*6W>V#P4M?9KEA#'HH.'K";9ZZ+
MBGW>G2P52:K&_GX<G)F$/3VKH(_X`QMNA^O".?^22A7`!W!>V$ZEDF$!LMF5
M05`:?9=GB(D0EM(HA<W2KAPW)LVV]9#.SHR\FWI98]>?8I3$YU3K7->UK.L:
M1N`EX$W[^T'N%>7J"Q"95Q$N`EU6EUPQU:2J$'^HN@_>C=%%@AJ\AHD#7C6W
M4.;)3.ST9U^2Y9%-Q3.^4"P`+MBT4FBEKGH&^&WI9@5Y6XT15+/@G>WZ?$0,
M9EW%@*84DO[>(0L'`1<Z2)HBV<G%7T&*>P7JT(^J9B!M/UQ8`OVQQL[X8_1,
M11.)<#+G68PLV)Y,=[#!I2RX'=NL^]\9#!B*1"+*A5EL-Z_W>[6P/\821'?>
ML_U5\>?B;QB/.+46^NPI/J)8R?!\!H?A@W]EUKY*I,4;3N-PG,].OXR4H*-"
MQE$'1.6HV'`(6V"ALYOCS=5B)P#*B2I-!]-3R$0I92U&#03MQ+_V#B.;066L
M^K_?5=BYHLX/0%UIHSR2].[KZK?IINR2@#?MKS?@.MOZ5AD>:*6`\;4$#<;W
M9+RD/NZI@>YMQ/G)6$/2-/1];I_]B-DFO<W:J@IEGE+%OB*^M:"D:"FEK'N-
M>3B$2[%253%H&E>K*#6K=E2+P[F(RH^W9+,=4%5ANE)8J5.7D^O)-AZ9XQ*X
M+R@+EL*59W;_8@CZ97D(X'-U)'UM3*23_\X:VTOF"U@*C^P\9P%$$(,^&CA_
M/(CGW-6Q@T64=+TMM[+<ED<YZW#T!=2U%-._Z89[Q%VN1[O72:N2<T6C0]J1
MRTY'A>/+0;PM>]QK9D4:F&UCOFG&W[EM3]?Y*@'T]_(IJ`AG.'7M'"Q=/`8=
MSB+3:F_[?+K_AVRN..9VNPG-[.*7FF^$5ZMB0:@G2"]F'=4LCX*!A:L%AA$2
M.G:%>H!<M2.U.C=&:@E$X<CNE=X2\*;]W>SNMT/?!N0.L<_U0@.1]$(E<@J'
M*=ST:B$9)C8\]F`Y;"9E._NM,^##)NV)1U9+D+B'95ET\A<ZS>?@@;V:%F1R
MBJJ(A".>;KEA`V(R>YKNEG-QET\-=O=0#NP28W+;?,$1VVQWU2.PV^WO>Y]9
M4!8NVS7*R38>R3`;NEU$IO@A$;8<S.9#Q![EOC&22NDC6/IH9<*VYUANMW);
M%O%<*/?[UZ:G6<JR/!;Y^\%^RFUSE$BJP!U>,"!E^_5V^RC+@A-X\@0<`,JR
MO2N,TM!.652JOZ/:!5BPE(]?'^7KZVM3XYC-")"0L#<@S%^@Y),;YYWA`?M!
M$5K]C1536<V7%8RBBE_%P-N!*";C[T)H$(;PC9JIE\Y\[14(V1VM8$RWWO0>
M@Q^&63,N\.")^<&9&-L]!\,.9B6]B*'%P`?,FXXUZ(O]JM+8HD*EG,<3\*8E
MV'TCL^QN3X^LE3-?J%QED9&%FJ'"YBVO9:WR*UR/?%!/T58FZ\Z$VW:?`JT!
M::5T9PTH!LH%>8/(ISB]D!-0:TW1(R91BIT_A"^-`!:"V&,^XHX/Z2-L)8,K
M,E;]O"\>+`B6]C$'"D"Y?=STMNSM5A?B`.O*=8B6(P<0311;X;J6LMS*(N*Q
M/SY^/=0Z]O;9@._*]0%\I;@\:ADY7\\`:IA`.`&WCQ-(+&51L``*R/>5DU4H
M@@LUZEC&G6U?EJ5\?'R4S\_/(XR!$R#S=(`=V1#89Q']U!7VD$Y,P'ON#A$P
M,CNX?S_9W-/IQ@;LUFV;&FS[TC20C%W%U[;L!R'[DN2?64VW1'L_C%X`OW2,
M-F<Q*)JGG'SIW\GT@9W>W/,M1NL93E=4<QXCK&#HQ)PC(KT=-0]=H^T!=NMY
MZ<Q!8*@[6)+A34N[#*;IYYS$X.`9V%ZG\'*(TFRSS'N,K>1UV<&KY,#BH6H^
MMAL0CI::!)9RR]DMW3P*=(-4X9U%59O'.,'N"39-O&N!TNID8;FO]XK=<YO&
M,#NM/B59DH).GZ(&(=VV,8C:RN>#(G&($"66SX"9E12@IX::W85UN^BZ/A).
M'DRN7.!OBHA]U(2XE64Y0RZ^[E]5$I"-_73'$\X8W8_;A\MHRDX3;Y-[SPO=
M!]PLO-J[`WB`WMOMP?16_<!M303.I'`JX:D+0)?G#JH=JG!UU.,<<-AHTE0W
MB:G=';`M"\JR?`AG\Q&7N2<C25]>>M@,'!V#RWWV4<:1&H8;)=+9KD.XHOGW
M!.JHG">/4Z4I='&HQ`#E=OLH84PLSWM<N;I.E;M=5$RQ-'2*M#B%+7OY*RK0
MQQ;#<$"J#;5@Q;.SW.^/`A,[&<)0CN4L69^`-^VO!*-3;NH,0\P.18A!S#K,
MR-5T)T<?;H#I*TMYQ'3:1V3G/D=T4\=I<,5@P&IMRI*W<C9&B>/(1G1%MS98
M;LNQ=5ZVK6L=XU9\NH"CY9W/)(LC7WU/;/*T-NEE>#LR2F24"J[O3R)&BU@@
MBFT(J+??6[0=#.?]6&`WVQ7N]P?@/1X'\&,(MQ`4+"CD6A8N93U*)CODCA"N
M=]GNVP-`>Y6R**)9?0`_HF'-07Y-@D>4CXUQOM_O3J`(BEM[T28]L3CL;*DH
M-2O9IY.E)"C=@G38FWM9`V,WF%:/_=O'3<2I/_KFQ[*4PD<[?'U]Z?`F4PP%
M48*=TW0>^WCV$[M7HYE$'6_N1;U&X3TZ0IA!\`]-*`!+*;?;4LIB$E:]).)5
MR!&R$1(CZ&%9\Z_^"@^Z^W2^;1STR%K*8)JNQP@-,P"5B\*RKO?CN+6L#]!+
MJ_NMWT.J-*3]Y<AW!G@-'.^HQU3#?;;P%P8>@98.1#R11\#/K82Q9<L[H-=M
MQW"=9A?(L\&?52!<3M1>"5G4K,'8OGGT$=16>O,T*D[:E@)%>>1P^15`:'1W
M]TFZ"$DVFFNP29&>.J6DUR_@O#]'GF#PM>NTLW*4LF6#0*+3)Q2@%.]WW6)G
M%RS]PBV"]0:6LO)>;&$+A?G+N3$-)1VUE.5V<UEIA@H%?-,D5#M)'[\^'G)+
M]]4H4P1R6J:01;5;`];C%OIE505)J-/GR-BWHL%)$OA6&S\"U#T<S]L1+UU7
MGROE]O%(%OSZ^GJP>XHAIM;)/DEVW^%U?60*"373%R3ZA-SY$,5.$#@PPG'R
MB@DA2+:U.QO+[5;?EP,X#W;7EE*D/W=4CKDW9R">'`P'4=PE*US;RB&+Z!V@
M(LW*&5]?3!]<#WZW#C>1W2(!;]I?QNY>U"#CQ"'PV;MP<HW.CS8;2;L/UWNV
M'M@.DH?/K/\9Z:'B%:_RMZJZQ/8&HQ3;Z(O..T$0P^]MKO*=TXS[8HC6D:OC
M)#&8Z"5+$X".@=9[EPF]@N)MCJYWJWE)O]J?:`-L\8Y>C*7GSS7OKXIEE!7>
MK$YO#2:PQ<JVVYMO:]71">G7KU_E"_=R__HJ*Y4>AW#[SG`%I8ZQH1&KHB>!
MG25?(8&NU2;>&U;D)^BD,T^E2R>5%?JR6D=2(/QI<0?&'[]^E8^/1P@,6<K]
MZVN+WV05!Z]!F&!D:=":"*5JD+75IHHEKXNL]6*<$SHJMI*9UA,`E)SA<KNY
MH2;UL,/#.1).'FF84L=MLLZ"W1$P1&\X0MP:(Z:[GDH*VW,+^;_>3/=(HJU'
MTJ'H8N7'4:2+GI76TOXVL/M&<KCRIN&KSK3TS)NS1;^R:PAF,<C,ECK^;6<G
MRPS@8,VRFDKQ<S<+'-);(Y"A1;!'4O"OZ1T(=7,9^C52?NT$P3S4,B1D1)6,
M-JX*\*Z!5<O#<]M6I'-,7<*4=3$F^F#WK""%"?AI`(5EVJ20AZCJ]^OCXS<V
M950U*BAG9]K[XW8KO_[[[R%)M>!@JFT<I:RXY>;+4K^3&I"=29AAD3.@V)((
M/NAA53;Y=!Q/YI+E5`-!4-C-<@E[*,K'QR,<1<_)"+2@;?@.=!@'G1T5,ZG!
MM"5DD]CNQRN3CG@2GO/K;5G*$>?`(O[5`VA=[U7\+LP<5'\6SUFJ(%R)*QE&
M]4$L^0%*)Q5*&JX$"7LL9SEAI<3@C"+IK'G+63*\:7\%T`4P-H],E"RE^:(6
M70B874Y<BP$^#97TT65KKP+Z7;VA@$X<5+3H%4UQA-<(F#SQ^8*EJ=DX^C"_
M`[]$V^U>DGHH#R5EXBK7H7[MX'MYQY!9$7%^[H:!<U\RGM2M-2+",&08\.VV
M=,=QU<1B5V"/J[3A'3:L8KD]I+^`5_86N`H5ZJ&=O]'+6A>`0#H&"U#^^_7K
M$?IQOY=U`XG+!@8>R7O%+:)231><89WK/FR3N<*W!0HV3Z/NQ]1Q)F>M*XOG
M\RKFV>`NE$?L[_U^K_1JY=A2?1)PY<50_!"<(:]+C'?X9<'JJ9.!DH]Q6!8I
M7=BIQ'*_W[<?U^!>/3X9<8U$M;:.["YZY3T:3=K12-_GG05P'3=89%QL*15]
MX@2\:7\-Z)TFPD8Q,B.ZI#,Q/H-`FX@=ET!\[]!SF]$K?ZE!T!%G1Y;[.I.@
M5)<H/K1=RWRVH;?U]BHPZ(5'6_U*'G)2]>N2_<;S3PZ9G2V;?E3_[6*)D.GG
MWN/'X3(Z,'V$CI.F,ZR]K5T2A^3:;8M1;-4;L=6I:RD\L4J:ID#96,%?'VH!
M]:XQ/'X$T-Z+1CPT?'F$!!QJ(WN"G-5=YOB<MK-='[]^59\ORU*^[O>R;DEN
M]*8-VBUH"VAT_"^%=-N9WA97DK/WK4+RH<]7\0.=;2T&]46P+`7+4KBN!4!9
MUS6.'3V>!>'XH9A?X;9__,Y&G/8Z2HV!NWM*\47K@;R5=5VW7(R::D#3":((
M<[$)HF/9UGY2FC\7J8II^QSH/OWV_+?EW%7`<KQ?BK`4*23#(AE>F0O!!+QI
M_PHB+O'^36LL<YCT&$*5\SM<)B-`Z,2.Q\@V0C2H`>\Q%X45W`0C7!I5O<)G
MWZOAB.(%@*-)BF-2;)%1-CF"'1]!LS&M.DC#I$YU0;)QI`W+WD,;B`$_AJ4?
M'H+J0:+G'.F7)XLK8?K.NBSE7K[<L`8;B\S"!OC8P:[>CF[I&]``/<FPVL2C
M'90^ML`_=!RXE^7><YO$=U9RBR%=3Z6/HH-BUW)N/W]]?9WW@5H*L%(,"-Z/
MUY[+[59^+4NY+X_$+K!=%EB%RLLB-:H?P6@*^[-*&&(DYEVY<04X_2"8<]AQ
MRJP^]JGRPI9*E>.4U2/#$SOP8DBK`@L>2#:@5_IH5/.>YF);.Q%R:-[O7Z*P
MB=$#9RGQGENQT1W%<J4E2+KSG5$9H<^&,V#[9_V<>PC/_H)NM^4`][(QZ60%
M4+#4^PM*P)OV]S&['MB9`;JH)Y,F\>H5>H^28X\!Z@!-%^R*[`A)9PV(=U=2
M5P[@\G1I]U@QR=ZQD@*CD`A#-9FBPY3*-O9"4ES=V7WU!*NR9FS5=(?/OMJ*
M/+2G[3+H9DK'`$"56Y]$-?6?VYU6]JC#/0;;X@R&1(O)KB6N?$FNO1I97(&/
MU0*(^B4_,M#WZFX.HQXIUU(Z7S#%$531%93;Q\<A\U7WC<8@%XCFU*PNA??U
M8%-9;-$V69BD/O7]?B_KNI;_?OW:P+IEI=KZQ2AQC#^`+1&/Y>OK'JI\1.$(
M=?I!:P<%CM8QS0"K;QZ6Q=MTP<\XWL'*@>+.;K?;!O)%\II3B$0EF+E3!#L.
MK(U,UR#>52=@>[FAFINI8K"Q:8+WUJUUO6\.%YU0HU&:A9TECJ9_,'!"J'9@
MO,+5S@"K).H>$I6+:(L-!'_<RK*BW+?DO,(@6%HIR#Q^2L";]G<!W5%&M[,3
MS!:+ZRO:NYAD2"W+(%#`#%BQ3:75A:"KC*%-W]%SQQU4\:ARA`UTK5NU)P9@
MA!6'-%1,SF33UG%=]-.^'1!^+!*CCDVQ(16&3`\6*V\QHWA/,$Z29$8LRPM"
M,%\\LH?W;'/N8%)5?2L-M7S?"0)[2UN@A$G];%Y?U3_[5X![-=TS=I609HV"
MTBANN\EW?7Y^*B"ULW^_1+QN[5Q&T+I^QX_B!W>Q=6S5J`33Q'.7@A0M+.(W
M__?YO_+KUW\*T`P)H*&?U?KQ\>NA8'"_%RW_%OE)3F\5_0R!X^1OAK4X>J=@
M+TNW3D\DA+/_?%MNY8Z[(6\I),L:.UY\OE#C.09J+=NF-)=QKF$:8J^LUEL+
MO[[NFIAXY5H;IB=VUL_JHWH>M#_N0/<L)G'&.2O@O"SE`P_0^TC28^P0RW&1
MT"GMKP.[(P`W8H`YZ`\/*&U3Z>)@Z-YY+)`E\-2-*+JH!-:DP5JH.Y+T+(_X
M6N+,HM8TJ7"].2MZ+"9UK[+3>DH86:U)*4U3-G".)^)6Z^I5ILRO2?/PM#.U
M/JU9T(-VMK@5+.6^WHVTW@Y^U\?VGFH^43ABQ-MPDV=P;/E!@5WJI#-Z&K=L
M1/88!IXZEE/QVF3Y_/HJOSY^E2.\U>6"XCZV+,L#]*SW0]OS8[D=A0PLV#U<
M..7%Z$G@B(V\W\O7_6O;1FW%)!IYI;U]9'*BV6GY_/PL__WW7S]9SVS[V[`-
M&%"[5R8[@;>>-^S&E*<,(HN\$&,[!*H,&JF=#W-<M=6/OA9V.&UA9WD_*Z<-
M#.*9W;%X,OEN.<3FEI\_'CQ=Z,#55[)M*%O\:F>=^=I":JQ;&1:UZ&CHT(H_
MAIZ^LR40K`6$7ESK\L)[=<'EF'\1%+XIE+LM#)EFKZ43\*;].+#K)50-`])>
MYBW:('`45$9@(!)TB#BG.JZOED7?&4Z4Y?@.G-BY)@`VDY-,`H"`;]%6JR6]
M$5"J*(WRE>21>7Z"!00Q`P*4K"SEMER37Z9@BX_%[[X!E^6('[,QH0<`X*/T
M*7<PQ`Y`$^O!4DY'8F<.+3-[3.=D^;K?R\?M-A;BT!@351E1\E&FMUB-RU.?
M>==?I2GN\&@[E+B\+D4;PR&E-_YM*Q.,:G-9*;@V'@VB$$@I'Q\?1Q+<"1B=
MC6LGN/(8G^M:/K\^16QN.:6S&O'14HK+ZH)+X+HG6.V@U_O<,NH6^.J*PA",
MW]?AR,A=!S@#H)(,VZYC$]_H>2TP]T:5]N7VAY!617E*.>-VNVTJ!:M>'XRD
M5>3<JSA7LZNDYK7&/2(HW>N+V+8+")V)P88&%V/O483C[FQ)LIIKX;P-_QFB
M!'`&&:/R4>F'S8GJB=$BM.]T[#L^87G[[8_KMNLR`@&0#&_:3[0AL-L"LJTY
M!QWP&]$;J)E=!6I-/*&,CZ4!@W`81B7Z31^U<BM;*Q?]$"%TXI)!?\(@O+0#
M5F#D`-W%QE;J<KW[N>[[I+7-SGL\9QTCJK<+J:;Q4\3<?6]AEA;+NFX+_%*.
M\I1<6;C>"^]:%NADET_`<KQO4_DI!KO[A/V0V]G/L2_,2C-3E",N9%F7I=R(
M$N[#LC<`SF>^KVL%#DB_>TN&4B:'];812`=MRRULV:?0VZ")2_WNS"H6E(_;
MK=RJS/8Y(/4H8_NI"RT<>J-UZ=D1AJDN^WM*2=WO]W*[W:JX[3JVG7XE,NML
M[\=M?=.=,ZLJ"CQ^/J\CP+>'$.UN!G9-U?,E'X>"32T53XV@*N$K'6'3CCOH
M/<.!BEL(PJXA;OEJ:E=&A7J[8-:\?:L:0J,BT.R5V.3S;@+PUO%?7Y]W`7:=
M=J71"S85Q6LP7.;65=2A:&K#U$T:]MEEB'@FF7,8+KOK_5PWG(48P=\3\*;]
M*';W$M"-@LU&PAA&RG29N/L6)FXN/'(2C9+@(+;HC+@I):#D0-O,.AL>H\5:
M+FA?`)=M"WX]%-VIM@[EPJ,$Q?<DICT&<==M/6@8'LP9O.=J[6DU<AR/+&_#
MA:P;,"QF(EXKAX"Q>+J[K;F!;0$,2L65ZAOGRE*6(BH4];8P'!=EW1C`O<>H
M2[!FOQT@##@#R<FFDAJJ-C.]2%<%IYYLOT2@'9"/O]V6I=R6_]1*/"M3MV[L
MJ&2.6"V^$R)\5NHO>"N[>D.3>1MD/W=`3.Z)I0XS;(&?&']V3-KQZ8%WOS/2
M:.8*]M$`:.#AJ'3G?%DZF7190AL_:T.@/+E%?XJLO3^;U&DU@K4"!2L'@98<
M@=Q/D9/WEJP6H-'[%F;CC5D;57#\[D0I:*UBD0LQ2/I09MYMWVT4JG/;^1'*
M<',=N6H9WW;#[O=[<^Z3?4[.Z0EXT_Y&:%R:NKFE0_[TF-UHJT4(K+,!:GWY
M'8@D%X8,+401T=@QF$"O@\=$3<'6HKM/4%OB3)';X8'(.#<0N-S.JEA'-3(B
M]$YXEIF*DPF]=/]J$4`I7#6':&-O!QP).`NE)('=_DH673S9,,=#3`RZ(=6/
M.%?3BYP^IQ0';(`!3R=!/[^.$GRP>K)T=/WH4&#;3W3"=@\(2QXP8)%0$&W%
MF,%^OS]"&)0^KFC[*N8WEDH03-1Y/(NC:7S(FSU"&QXZO5#L=TMIPR^`\E!J
MD&$-5>A"RR\$:E`+J]PRC/A#%P:"E=U+/'O,[4R8@P3[TR3)!(\BGP^*Z2YQ
M&)Q3DKXN<+2M!0O.A#6;$$:6K\\OO9/4";D%HL_UFG1H@^^1O-31WPI`VB!J
M2:<'98B]^:HE@>F=0I<S-]]0$RS4[)$QO&E_#;,;21>%S"X;``83LYXNZ%V'
MS[.<<72-!1(B%HZ,>:1]VY8K]1Q3-+-05?%!Z:M.!,_O*1&<K(&>:8^XSXTM
MX[H*'L\R`M'[7@O+4K,-"NI[HK4#Z=[%7T!H6+X39`\4S..88JZ@@DM8?!D=
M2AIG)C<YZ/"(TZSKPZ'H@1\&@T,N?-X@J^/3,>20GE6=C!!%$+?NTN?=P>I#
M/.Z,V=?7!NK$-972A>[KH<]H"B](_>E2=+SK`>@V'=7[_:L`*/_]^N]@M![L
MU^Y\]$'K#B*792F?GY_:X91A`1Z*EE3EOKTLG".W:,11O4P^&_OR!)LV\J]?
MOWS>`6CR$S`H;I^G;LMR,/3V7M3]C0#:",/32.^UI`'47.SW?36V2]EB]?WY
M^.OKKACYR*/P=U2\;FKFFDU%AJ;GZI(=M!V\WIUD[%Y67#K7LBP?E1)E<?N$
M=A/HS0?PE_P$O&E_!=AM@HS@"V&1@EX80Q`Z&26NJ"W%\'0XBQ`T'N8A8?70
M)^2ZGG&LE!XP%>.\+*@#R-!@.^TQ8C%9B]RF->](Q&-R\\+)&$11Q?L)H+[%
MT&*!VA*6BXQ<\/9*9>X:2X<NL$P+N14'.%DLJOA3ZB0E$>/8E'ORBF(X%:_4
M:U',"%E;$2$``"``241!5"ORXFA'0L_OC@8H6;_?(U[8&5M43/*VX+G8`"8V
M_=QUD#'*+,X6+RL4<+"0>VE9FLSY-IYM,*X#ZB%[@M?]OA97ULE)PCK^CH;'
M;2<;6''O8N*](;;,6?[O__YWS`OW^[W\^O7K,8ZGR%64__[[KWQ^?C[`?'%"
M$VP?9BTH)9UUR;JJZ4,ZQ!:,!>^+(D%U)P5@XXH#H%S8T%V-OB<`^E6P:\>3
MZJOG=*+U=263"4V$P)0+/(JZN-75'N=<U_N@,W_F/%@-=M@YN=CPE3.;0(=Y
M4<=2T[:QW84S3HFGO,#'FG5;J+37;:C<'AZG0FV\-^CL].Q[9TM"JK2_Q4)1
M[$YMBO"/5K)LN(`%0YE>[[:J;64/2>^$X['@Z(%=)Z:<=[!Z,T<$".$]IV'O
M@JW-G9VNI7<\Z2=H=M4PJ>OQG(N#(W!X^F>-^8%.$<V-1[[.>K"[-*+%-,\_
MZHRI%C#LMAM_#&>^WDO4%IWU;\.^75QE+O+0K'36H@UMV?CETVOQ`]1/=ISN
M5HE^EG9!`;]/M1^4K1V9@'F7?>SS\W-+?MGZKA0Z8KW+H=AM!B_:BV^FOQZ[
MIV"I).$^/S\OQ][_^O7K48I8LJ*HE2-./60=5@!'94+.1Q!5`3S-9ODORR/Y
ME46H$!C6>#]NO=_+Y^=G^?S?_\K__O>_AV.R*:+0GQ[K]^[$ZS:_.PA];;2'
M';,TBH&T9:1-TI^\HU92HHU'KKQX:(!W)A6S[G\#LY:L`FC;1VE+5_)R$%LT
MVDGR^_RY=W2&1MF=R\<<[98[[[RS';@GPYOV;9G=D=BM*:^\]Z=>E0A79-',
M@.REM#CQAYNK',YC2@4(A<']/ABRM=1Z0L5(1?10?Y]QAV1H2JUE2S8NX&B2
MT51-*WM8`_RPAE(@RDSJTKQ#SP@),%%85G7/-N(2&--1-JV@66\3RJ%Z`O3V
M<%&,#-4.0!@/BT"=0Y(N'!@30KR4#E.J%T`XX`TNR]IJN[-"6''0>TSY0MWT
M,#'WD!S[_*S"A[RD+"7TQ-,YJ.8I1ZY,CEF=O&IQI]I".,^]G'W@?O\JMX]K
M2_:OCX^R%)3_??ZO[CNT29"-+6X6'P#+47-4I0MB:46;?7Q\:&6([:J/=Z/?
MZ7J_'^\?1X$"%"R+EF2[W\,^%,DG:MFQ)<CZ"J84!M.-($SVMH`8-X3N%0CE
M9<ZWLF[.6;,XH`H'@D<!.7?K2)JI^9QFO)EJ/?#&JQFC47TD1UKO?'?:*>`Z
M\AS1V$<"WK1ORM8.R(_97<0K!`C&UTO_XDX\UPC>9L6=PO>`#<L<E]U\'+A:
M[Q>1\/O,NW#DJJQ#<L2FUG,04"<4L%=ZDX_);;GIL(9S;GTL=.M]G7PR)WX6
M4)(+GO;I;/++(=Q?876G8,!>9M@)8-,R=:B24]RPN2@W:VTUAR,8I6(M$`0'
M"S!A0$O4_ZVS5(%=*9$5=<16#'@1>JDJM&B+6ED?A2Z4H!YCH3%Z:RI/(*CZ
M['81&_9S@@Y9^_MT9*IXU,K!0EFYEEM-$W;Z__GY[>-6/OAQA#<H1^E(N-5)
MBAKLP"TA#%.8H98-#`#<IJ.*97F$,@C6?5U7/V-_[U^;E-O>?_9,?VY:WA9$
M^T!5;K$WXO6#I*J6I'OEQT`G[!YA;*3*WWB0H\O9EB8&ZA&25$12F>ZS&G/Z
MD?EQ[3N&/$^IJAQ2S6F>@UB4HU]T7'BI2U27XJACF,GH;O3F;/PN1(*)E:-+
MAC?MVS*[(P!C1'UK)O]LFBFVL<`MQ]O&I+E"$E`5C2)&^63Z`J!XC'_J$DE/
MV+*@/-87/W-:Y6))3W[7U2VEK&6M[[M1J?*^+8:2ESFXD$VV;!5)<9?='2F1
M1+J.UPSH924(8#4B94((E58QG))65.7F**KK^3+3;+#;+.WV9V$=AB?A"R`(
M8%8`PGVE`GC*[7/I-'U]?1W%%]RZK!W&36W1D]4B7(0,T^?7IR--)<$>5#QS
M2]+N`+@5P(.Y?1U0+1-*H5@RH:DM=*7)H@I@6)XLKN*E.\#'QZ\"H'Q^?JI^
M>/@8+CBMM;1+Q?[98^6$1*/;=<[S]_M:>+]OI;-Q,KM2[]GIKO).UDT)9F=V
M#X!.DR@K`;RLAB>TRR'FZM:TN=;UR-K3&NLY'*HPT/F^?MT^3)@0E9J'G#O4
M<ZVFPEJ<*=8@7Z)E)U`8H9B3),`U;+%78\,1>`GH<N'\452Z-,4P3LZ%=9WW
M[60)>--^'+,["F:CHW@%/4]BX=GCE%9MC\HN@4ZD*7MKO7R$"@9C#[\L*.N*
MN*2L(V1.LMQYKT,:]^IP"XX%KG)\2A%,CUA448[OT<AE37LLK*6,['U8UK?[
M3D.PRSBNVS+QK+]QZA>WM9[#7,O-^;BO=Y/%?+8#.^Y!3;R@H[A!K0OK),J=
MG\EJ3`%HEC&HY!`;)^WKZTLIG*AW[,4CM"3IZ&4,F/Y"GP.D]`X%NRK?<SGQ
M1-&AZ@@)[_-O@<(!RL&FGW'!=!,?SW>UEEBKL=U0@"Y1#%,"<M>277%7PV59
M.G)5@N6LI@=;6,(A%O8/J-A!'^AZ^N-H:)",DSNZ38ZNO2QZOV5[,8_*8HX,
MF6@'Z;@!$;"%XFP]$4"M3XB#@7=/2!.^4\F>^<A;)M,M$/D8T61*^1YJ:326
M.)%QUPW/I+6T;\7NC@`+SN+33:2@2N1Q$[1*G;QECO,3'<:QEO1X:9E;>P&>
MNT&'>H`#=NORP^>Q>^G8E9QT'^1F%XYZYW6-<[C,RQ$+29DX(4K(XB$ZOI>4
ME(?OD_<.>&VL(,JC0IF.J6P57$`3Q57+M@O.&IB*/>!55XBR]Z!BYDS@P^ET
M+)K-#&XARJ^\W6YEV6*?E?\#K19`%Y'[4F+'6'"2;2*@ZXU[]K+G*^0BDZ6<
MZE<JI(3E?K\_0F!0E+.DR4B=X&/G@[/@1CL>601O>G4(W2<\VZ&<L=JEN(4_
M2KF$]U4_P`(%,BDF'U+/<JK0B(Q#[4@1GWK-]CLL-K"<(DG?+WXA$F/%J"(?
MC*M,.+4):105YUA,Q,RQJ,!MQVB^Y^8*5-<2H0.M_VR)<)I\$%A'CRQ6WD6U
M@]IUD,_NC6>>:V+=$Z]UJF*")BA8UD["W'+$8:.QZLL_P9U&(Y"_GS<!;]K/
M!,>3Q\&J=[4TZ`=<\X.5G`T?+5[,\(/IE(DC]23;KI$,!3#D/"'`[[JZ$E/Q
MS_L6F4Y2D0#5Q\Q0R@NL^1_!2NA)3BZ4NW+"@P4\X]IV]F=7''A,=$O,6(<Z
M;^*Z0@\KU-6%J4G@+1*T^I00.].]W0NQG5[QM8^%?$_4L\R3MSA[D/OQ_FX"
M;[#$40[M@<$*Y)60(6^@PRI3OXRY*OH<-E'.G.]^7Q]LHD=21DNLJ1)2@W*,
M3!5!O^R+*=+$%9.<N71W5O2+8/ALP`D0&3ZC%W;MM0.@G:&SGU`K.E25WJ3F
M`!7`+&*[6_ZN/&B/FMQ!I/`LR%..+W)MK+*.B:0="K$*Y0'%>#J*NPAG2`+]
MTE(C8KM_[_'07N0.'3)CMH\=_Z.O:0XQ_F^RRMX^?DU.@_8'Z+9;>[I)6;*T
M;\3NO@L:DP-)4B,+"6V1@IE[=K*1*/E3'(H$8IDI-J<8V+UA.Z?AG)S@+.IL
ME`1U9T>_UOS.IB[+(H1CXKKT31'Q!56E+M9"D65=U[)LE8<>S[X\,K9%(L0"
M.%0&BJ_SY1&%4%6A)*LL<8_%4JI-)9LA)*XT^V&[`7S=5@>V'B$-0\Z?LRUQ
M!+I1.'^FB$4'T"%D-)_`7L>"OHXBQ^%YI"HJ4>B"?+DE2H?>XQ"M;^_!$[V&
M:K-:S00U4XRZZ,-SX5</;=]]>[PJFN`XAN<6.:HN`HC('2?DFH;%I2B"XFJ-
M>_K0193'547U&&GP58F`.L'./$0%'C6;*D.T7$?OV+DZ8YKEL5XU/!2O6F%=
M6)Q'0M]J4L=H^J]!KA;-*LW@>E?.5]_D4'7'_@)ZJGQ(`G@!RJ]?O\)B(#*Y
M[WZ_BYV'*W>2(0UI/PCL\ND#'()E@BWA&#DT!WUYLA1`"[1`@=[Z7!M[=Y0E
MO7(W$F:CS0:5XDI3C5\UTIK4YSJE>!XR9(<4F5/]J<<4-H2&=>B$E3(:P!D,
M0&JK?\/2%XPO<I)5;!T6\:]U\AIU(S>+W['MXM5,G,/@1BV@JL"M,;B]"*KW
MPA)'40E2Q*W6X)=.!2N6=HPX6UF"KD,IXQS1O'=*EC+:6,>DXXYS3&G`%_-T
M4%K40JM:`%C(WQL:T9ZL\H#X1D5B6-FM8D`I6;/GGD,44J%6$E$J$M!*SXH\
M`*NX85AK%5H1/.%J&F3=PM)HYTB>71J1OVPD&(\P&]&M6CA2;RS`60-'<F[.
M,#8L6X6]CX_R\?'AR.0)B<_-$?W\_"QW46%N%`(H1X49TI#VMX#=`-!>(HY#
MP.%OY^V379?IDD2@S9UJQMCJDYS2-)7DX8,!/=C7!JG<6!T1+-MALE^3\Q:L
MJ?C?#G"XGLQ1G:5KMG,W,+I7"Z/)_->+5Y1S[`2+4"]:454\BDDX:ENUS3K1
M53UFWFX1[RQ'WY]!GU$MI@,%HO"C8%,MYAXS5SVW3JP\PCUX'=QZ`/)^7_56
ML"CJ0,IM:RI'C$57*U1;O+1COP5T[>-$GG:_O]SO:_G?_S[KL`H.#_3C4D=8
M4B-1D3QU=Q4[1[@7H4*]PEE`W1\J#6_H+6O2"Y5H40Y0^!^#[8I&WY%;_B3K
M'9L(^)9-(6(G(/:_"597S;-&(]C^G2<M*]QU*%\6'E87A43.@B(\YV)/]FUD
M^#<B:X[KR<(114?++'L(TC:?HS//<%V-0DF?RD#P6:HTI/TER%F#R;JTXP2;
M"P<SM4I9.EX^1U3^#9"J-'=+T7(YQ927-:=>RUK*NFO4HLZ[J71>T0&'""N_
M*_;)++(T^X!JVUZ%*K"07RH^M[C7>H#CVQ9[NL?N2DU>=?]5S<M2/`V#(][N
M4`HH':JSE%I$DJ_HMO6Z;7=7]]+`7.NRMNY[E"VD$UT>H%D6%JB3X-AQ4"/G
M[@`'@*NDP`J,;.]X:_>MW(A$E#[[8V3-(D9J7>^5;J`GO%45*73:<B]A?;+3
M=%A$'D!8EG;M3SQM!GE_S*^OA\/SZ[]?NNJ9:62K#6(=X-O'1_FZWPOO/&&0
M$27?@7]=P;&X83AZV%'=BYUC#BT!KF=D99B$9QQJ4ZZ:37=C8,H_DO;8)610
M/3-=)2V56.T%,(>^:%UYKCB.?2=*2[7;67:=2AF"WGT[B=6V/="3?2Z-,;\M
M&<LBJ0\C4RBV``ZG`FT":S0-)P%OVD_`L65PSG+9,UB$$.$\^A2GRVY2,G[G
M0#TR:P,5<[UT4%4KWPD2%C]]3$_Q_D*W<MWBZDXOVF[K'#&KQ=?/C."3O9C*
MF);*_I$JNZPS?Y0]+@6\-][KHXU6KN7&FV(2]X=YQ/@N6L^TTXM4(MZ"\E!.
M.U4D:.=O^'_0)3S;#"A<JL2T/XL/GEBT7F]!L(]I!X3>=+Q_W<_0@1+%=?OW
MW0.[/:FRD\GS.H8I4&+0JP0#>ZSDF?2$N'^N=80Y;9QD4V<9C>9!U:=@=R2\
M,:S*2/NC3&,D*-![OZ_EMCN``:"5TDW1;L^OCX_RO_7S3,XSVK<\/!&K4QQ7
M)V<T<?!D(2`*`QP5Q^B!)JME7(^-8X9OZ%Z'%0@=L`=HN:R&+'%WS9)%6&!(
MDKTP#8Q7H]I&_/SH_XMR*NNV9U"L0^]N%*#0J=?3T@Y6@)(QV*2#_BWYM*[K
M(TG-RN]Y@'Z;GY=E.7:WPL5_8)E/P)OVY\#L9#Q.Z\`AF3*;@MI"=7(0!5G[
MU;,X985;DX@&2C1`'0%0\T^L&85R).AXS,(C4Q]::LA9-GN;2%19_J**U!'3
M9T(-Z!/F;E2=DMYY%&38E1E(S=;=U_4QB7Y\E-L-#<:CS;#8]Q>!7<T/B^W>
M4)E=)REIO=/SBRNE`^2QT:?.93=.VXV/%&57@Q+8:M''R8!757W1\BNDVH1Q
M(HV:!R3@+'ZL+*L%'>W2U>)99#9[*+[7T/ZN2V;[CDF]W*->B*U6;J4=JAT@
MZ1#+W9:'X@I+N96JU*\*S3!%(.S87FZW\M__@_+U^54^MSCG_2*J+XJ=F]VG
MK-K%T36V]W7,!QO:JJN%G7U>%O<F-9QZZ',7,:Y8)VV)MEM9OV_;YC:&F-YD
MJ^I`V&1=G3`L$_DLV`94]>Y33XLLMRW4Y/&YC&6EZPR=?0BG\R;;+MR=,D5N
MBNF/GMAWTZT_G0XO1\4"\E4X;)ZS;\.]UE4X"LXB>%0\E.L&A3/$9'C3OC'8
M]1SL".RR?TB\+':2K\=SLSL@%Z4A_Z0_E-M/;@)OX)E3<]JZ+9TJ6*?>[4#$
MFU?'MFB0?VR-LJX$U'[=;$8(R'@S%<LEL[_QR#S?P;P'WD;RC77@H`5I#$I]
M^(X3`Y%^>5_Z'4.5T:!8I!1/1Y:RH+"C;6GO]9'T81TJ!.PB#W"G1/&AQYT%
MBU72SL'(HH=/!</C46LC_>A\\OO]?L3O-LO`TG]V71K8##ST6##92'7800LL
M0_0#N?M#KF7!<H#$^[J66P7Z5W%]5&POG4ZZ+$NY_?HX2RV+4KRU(@W<@@?4
M7HD(I]6MOLIW`:U`8.^K5AOW`^>;^LYR1H1=+]@F4"J\9T,RS*[!`=[U>U?U
M1Q0Q()P3/B:#Y?;(OXA(DSVQ5CG]`VUGJTA"M\SY/>P[1S11/72;`9/AXX\*
M[H^GOZ]KN95;[1"8:^[A;#*,S;YW-7I0M%J/H>X3\*9]2[`[N*Z-`^-+-QK<
M*R?O&_ZT5(O!.*H``XC;%P9K@W[)JKFQDA']3;MP./%FZH9&*N?!QS?[Q+4\
M=')7*5U%!\:PE/6^%N`F%D0-9#0]*>.F(>2Q1*NJYX7#N8XY75Z5(7\\&%8.
M-=;RB^*:IK1Y32O+?5TKC4VU9-"6AJ5AZ9Q824_!(:J((+R/2N^3+,NVV%<U
MK#K5W+Q+?7Y^;<X1=7^7\=J5D[E?J@:[U$'J==^%!C^2_8<!1?I%Z@0YJ=:B
MQI<(:SB+4Q1G#]Z$J4!FUM/963H=RG5=U9@!+`M-%4/+$L^/9U:^IEX5Y*JV
M4,:3%>E%9-'I*L<NG:P":<F$1LA36!*^G9]1C6@ZU<$D?[#@40'/)')5H!4H
M]-A6!KLN[E0K0"VI-F!,@+1Z?E5>&,'.7"4-5W1(!62?1_S.CW`.BO+Q_OQ"
M]=9$,1J:NT&6%D[[CH!X\@..X@P^>?UBO$8?_C0I991(Z,N<C^/W.):'!S4A
M5O%>U*5[+6=U;)%MSTX&,2`6%TR'K;!">PN6L@#EOMZ56@8,N'A<;BTL-[$F
MV6<JYYZL89]1<%1.BN[3=2S$HJY!%:?[?*3TIC*9!?M(N[E*A[<]$@0IMJ.#
M>%7+^IB`1A8$K#]#)PL6M$KF$*:*7($")Q.T[G&_NXJ'*F2P?;981EHZ#K3Q
M[$=D_0&$?8]3'U]5O`+53&&3:278;NVN4,3(T]V#]R<;.BZ2(J%E(1UA*UF[
MU([ZC0_JH<(8*O>)M8,W51R<G@,N&'5WDT!(.D)RG+:4K@!+7G4_-4=YX2QF
M1Z>TDZ=12OEU^U#%)N3864?FS6!8MALO.)]E3_=$-5LXPLUUUC.6=**ENH24
M1W.3+WG&')]RA?W5^5C79$Z`:(P$O&G?AMD=6M8PRJ@9L'<!;,?ZJ7M]>+91
M+08!7L#T#C2#'T<YDEP!V'#*QJHIF`6A"WF%N:^@O;>H[C(Z0,&RE.6VE/O*
M;8NZ9M).O&ZI'N%<D"8B0X([GF"9$R"KT097"ZG0;(Q+MG,OU%$GIM3,,ZLP
MF9-;L[W([EB>B8*LDFV*6*!&')IU%_ROUMPS>:FJMH:!L*#`7R19/O_WN>T&
MU$%#:R659O0,CI`&R4@]DM]@*I')S>DJA("U#Q?MW%358^V#P4A1<4#V;D":
M;.\7C]AX$1_[_[/WKFMNX\BR:`8HE=USWO]1]VJ[1"+.#Q)`WD"R;,^>M:>E
M^3QVUT4B05PB(S,C>&;9A0FW-O8Q6YJA:XHGB1R9&\I^152GM,_.@DW#S/I>
M!6H,;.]21R=T>S0&?0P@#5YMLQ_\90@$LCR68=FN-<63.GO@9)[%VTS7S2D@
M#JRNF8;SYC63Y6!RKMF2.R,?EI+E1\!:M>TXIF>@O:Y01])_]PUXWZ__%6#W
M<H]V$?WM)K5?!+OWJ&+,%1-^%=!WP,=3"1:<1?IA;T"@#DM'?TF-X8UQ*`52
M-T@5YTAT,_L<H4ADS<JR,[5=68`YEP*?RZ.S0V[/*I3_*O#"VL'9+&5F6=-K
MR?4L=9ZQMO37.:DV)H]FPU.@/'N*#!.$II%P,',ME8C)0LN;.%4#TC0EJGO7
M!O0N(D-EXRP>Y'30^G6]7B]C.9T5_.P8IB%,J[;140^U[P"D@'K4C$\5/)"1
M^5I(%:J"EJO'NQ$:LK*KDYP"6I'Y<^R,^#:*'CBK=+]VMV"ZZF#T:V$J2&&`
MH6<!Q5][XAB.%/S1!`=V3'"7F^@/$`+CS&`@,Z-,H3<#TJ2+A8*[F<[S\3BT
MTR74O]MY4623F@/S;%28@,@VUXCI?.NCYYKO+D]3)VF790!:M]ZN.`$E]>>E
M_>B:E!73I1X:?!\#SG?:-^!]O_ZO@-VK%"]OH"/^.Z_Q$GK[^L;YA07=P6LN
M6:ZDTOF5\;H!5G-^Y2N)14A9BM1#%Y2J5NZ2U56;8]8VU=)HNT/6!-2IG#<=
M8S+?F-.V(M'.36?N1[[CF2=I?,/V)HB'F?N9_G]=8ZTXZ7K4X3Z6)<S#^>$-
M`W"]I)'6(X[7>\U&P\M]Z2)0+6GFG:B:K!Q[$8IAVJRZ1P)@W,19UU6V=5/*
M#&*K5\FC(@"!G6X9`L;*'!,8-#6GFHZ#K<;)P&[[V8*2LY`25;6TZ4.O,Q:1
M=5OE63Y2=BY4Q:9@MQ[CMIEKFW.Y-JC)-$1HI0R"T0D1PT>]?L-^@%S.+0.^
M@%V;7:;09'PX4?NV[]V#&F5"HNNE>9)F-`V/"9O:)/7*LLCS^;3[L:^?=OJ4
MW.QLXRD-`O&>F4B=Z10IHO=Q.!>]VT?#7".[[1<Z4/-UU8USV+9Z2)$Q/AR)
MS9\03,Z<,6)OP/M^_<<97OXON+X4`%U<*<_8U[3T(@K]<N)-1M7P<<IZ9V0:
M)DRW40-@Z.;VG-A9^3,@LF[U=.,_#2':-7&B?)#:M2:UA,JR4KBG_6.4[UD6
M!IDO$4GZPN=-6_Q*,)*RYWO-*.YY+!@+:EDW62:,Z`SHH\#WX)GYQ]OU[0KD
M<L(NIS>"^'?JD>TA"11X3+I]U!6L!NS2P%WZ6L_L6.0H\=CQ+YP\$H.UZC2$
MI00S%F2UT;1I[\X6AZ9&6%0HHU89F7_O.;G?&T*W6H]F1KHU`!.DP(PT)GMZ
M?IW]P^$G>NJ1WH.)O;PBOW0XTM:4Y?>:9T]3-E(V3T-YV3UC2H/1PX#^=;^7
MNK,.R'?]XT>?S\>NS"!C+YS5Q$,@&ZNLZSK)YKA,Q42+(CUO&D!G?FSD>QI#
M<UU_1JZL*]NG?&8B-A?O2BMD)$@BZ7^L&TRFH.BRE_?K_?H/`=WS0UK$9<M_
M"\C>87?OR(UIA\LLHKSS?J%#6J)`/1P`G1Y@$YP1FH*4Y6.NN'NCT]BS5371
MQ3HI#OMUP]C@&6?&;YQK<!LIS0;J4ZL&_'8S#DSG+;(3,HTO$)CF]ME3U@.S
M>4(%VFBT:*]FOJ[0*"C'V'S-?I!DPN:>&VU0?S"I1M_]K<I'ZJ&E?*8-/+MO
M`(?]:(TC2&OQ.[2GK0&T5S'(S1HPJ<NW01(52V\L=!53V^Z_L^[&N8MNG.;/
MMP@$E/['LLG#"9A0_U;<=ZV;57T0W[P:.]V-[$%8DDR<PM0%=7D'N32BY(V]
ME8H&[O:]2!0^FOJ!KI%U"X_&_,36XVOKZ]'TY[6$U9Q"1'(Z,U^6(J49AU!Z
M#77?I>`T?R$JXP4WWS`"LNZFJ=E=)%V1%J##U>.<-E`Z,)_X.IYB@+(L;A]T
M=!-%-2<S3:3ZY\_`-GEB:5_3;\#[?OU'P2YO`,T[];K\!8AUS_CWC*UC`"?Z
MY[(C<R:N#YF4JIUXW9^-,0P\0=+C<W[J7,%A:EJ4$_26V&3^"NA-M3@1_UZ6
M96<R'1C*YL*=II_+9D=R<CK0IL4AP:WLC(SKUM0-B%2.`X"NR_X+\V)Y/-P9
M3*-ZX7_?@UT-4D_=ER^DS$S#RC$(NV[N9DPB=(A2Z0T$QG<K1;8:F6HO8,`@
MI0<GT84`)K+,`Y-FP`%N%8M,*Q22N!`'PP.S`71;5=5<&,Q1'!.HUF,'P0H0
MPQE>;%N=TOM!``(Z<DAV3;U7-;`,U>"%;`+$5HOI?`',O^U[[@Q?=6&BC0!X
M[2R8!J,)L-?KL94YT#+.YF:*`J*`/![/8:(RVW35..VUUI%@V`&^#@A'8+./
M"10#[E.`XP/H1+U-S"JY<4_6O\)P9CA@#!R&$RD[DXP[5-WSC?/<7R=MG\(;
M\+Y?_[87<!]PSKYY!Q#/(,R5Y?>7]7M=!ZDME(=XR?=X7#)4`=]AFD\E;1R@
MY`P@.A89*7)$>(\S(XI,,2#XOFMK3'=H]0W[HB$&OL@B.1B6Y=%EK>Q83@Y`
M<<^,U\%2'%_D2CD)>S1[;W)VQ#-A<E3G<N4ILYN]"B#/QU.N^.&>;@^BF]%^
M^@8/?C[7U7S9&]?DI))4#$NLQVIO;K%/")EP/O/Y91A_6I96_YRWV)TR]:D?
M"5V*UNU;KN)#X-JDD`<EQ+R\BF=[(X]Y=*QCMS(MHP[5T$BKR*`G"Q+3$9EF
M-7"4"TC""L?@EJJ(.<O4Z&<4Q@<QJ&S79V9-<KT:O.DQ@6.-[8&@QB:QT"UE
M,6Z!PT%P_],:*MGV*)0Q5MX:6[Q)B"0E$1(9^;;QZ4`F)-,8SF(:I9*S`PK]
MY]L^MS3Y-<Q^=NQAU036./%*U,\*-J`WX/==TO!^_8<9WBLDC-L_BE#7=>=C
MII`$,X:3MTH@>,I[S0^FRXNYA\7=OD?)RP*\[NB7HAG1';GFSV33'7,"$XR$
MR=\.M-*0)5)0CII648QV=LA#"<F"OP``(`!)1$%4<LVKG%'*_AVO5&E,8G0W
M:UW>/`!$<%G+M+8\D][DMO;ZS:^MN08JE\?C6KLZI_6GXV"A771ZRK1O#0/$
M6.8#)U\$D9"Q@`+D6G:.9A]`RM9F_Y-)-J.7D_C4M@O.`UELRD619/1A&M&,
MT5]W[5(VJ:*8Q4.R"3Q1;7$A8^W#A2.-[MN>)AF1'IB4WDS)D[UIN`@BS2(,
M]089@X2,$3U`S(3M\VVH/$TMP*BKI)D-J"`9X[_%!T`Z&$$6A6?#N#_K/3C'
MI:(-51:`+JO".YDG]>]Y-K/8-1^"Y^0@)$UI'^6Z!Z`Y8"Y+2245_/IL2BNS
MDXX7&U=P?[1W^WZ]7_]+P*Y8=H,W.-U,BP]?9)KN_2!/65C<XKDBL(&E'O*&
MBNM+,WE16Y.7-<\Q1,Q(^;3S!S7#XC,%`X4.7>VR/3!,35F8""IUS)'6\UQH
M=L`.9#2_4\]P^V<.'TA`\E9L/P[T`#AA[`W`=X>!;NQ1]:H3-;5\_`%9EF7(
MTCGP-WOL\P`.@4%/'M=H<COI;]NVFC#I`^+0%.+@=&W`/YZPYNQ!KIMV^L_/
M4BTN/9\5-EF0H@%3"`7<SR6@8[*^*+N2B0<'F`742-CU5"@B!IX=N$Y^(@9R
M<`I;172C(C');%#M#4'K3=>%,YB+B`H08L0EG>V=\@@3L1H$*V$KB$8F83"2
M4!O8LRS/Q3"RJ:*'NZ[]&8\2JJAX@[$?2E'7=3P/W<J6]<40:6/:7*XM7NQL
M9K2`KI5Q(*G_U5F6RJ;.X)HD)X\JCMID=N)=P_M^_8?`[F5-[N7AK>7V>;OQ
M[#[BODD3G^RQ,H<`"6"]`2YOC2CSL:3B29FK,/#N7>OZ3MX;R=E&/KNKD>I'
M:(KQ;C]ILUXHJ>8%6SV1$?.@E[D/?4*"2/"P0+8VK-H!/3+!#`"=CW]6FC+J
M;VW:5G.IV2PR;F5)N!F"/2^+!9%K<AV]@<H7HL05;I/UK::9"KAZ-HRJZ6_4
M(DM<"SR-36T-,S.@Z/E;"3;%\7>BNJ^$V#=?)Z]UDY\_?_:FI^D>J'NW9%@4
MV^"/24"<XQQ.S`M-O7>(\V<U[VILM;(!'$T^D27KL_&J1@T^&)517S]39F2V
M^^+R0[QU<7?Z*XO@:%9K9CCI<W/1==6*.)XMQWGMN0?%O7G990[.]NH[YRHF
M#:4BNVWR'FB77CZ#+*%WV(+;C%">?9EG:..(MO=[RY*]7__W`?$%T,5MG,D_
M^MG)+F?<6J;N3W+NDZ:=O?)-):9[09NCG=VK9W%]NY!/F\>47_0%NC-V68\-
M'),8),<X`WU9K2$E+<%TS!`E.0-P<?'-'EF&HU'65#9U@*(R9<CDB!3EH>O)
M9*(3&8')1)9-J7G1/=L[Y37D+O6SZZXR!EQ>OFERH9EFM9<EFI%M5H;-WGT]
MS!26Y:&.X`NM8\EU5"-N0->`93(I@T1](I?G+`*GJUE<'2G@*WGAP!%-PQ>G
M:]PY?#5M9LIEI4[:S&<43,1H2QNG+TS\&S!9=W!S'K%9LWT/JBX7"6$"8`H&
MH?=&*E649.\9YC-68BTT+:H(!:KA2T*0>),XX6!DAQ2C6C=,C"(2,F7;-K6M
M0$D+\R;!1%?J-NYQ%NA/(3Z3-$TWJ]$6]DWWO<BR/"(C'!HV*9^O5]>'G@G<
M.VEENS=>$'%OP/M^_>]A=GF'W3TWHIS9*?PV,(9T7_@LQ2R87SN,ZU"V@<2@
M?@"K>[J?GFD^4+/H=%JOO>,=S8O,%M+>;K.>]3)JTP#A*QIQKGDG/'8-P"J%
M);)TLSF`C`.`W&IZ[`<D<*V=:\Z#>!/:H8O*VK6S9_V@M'7`!9""<J<<V:S-
MUVN5K6[V&>FFD#LU$9@<I)ZIXKS.CM[P08;;4JV499%)<!"%]:$#!.4(T8#F
M_J41_)E2A`:Z3VHC@V&.SJZ#)B">-;.%<561W&4MM1MKN*"+`GD^'V<A@(EC
MF+CFF5*%ULA%FM^%1(";O9>O66][F+D+W[!'IK_?@J#1`[K+SP7;6U?K/ZI@
ME*XX>_M7;\J$E%[J$&2R0ID![KE1(BJ2@10"QW:,G#(_>=5ZN$!J8X_D^GRY
MB=E/D!-%/$D1$?/IF*NON(CGR.`]'H\\<''S<UW74:K%$P.<</^*8$#BI*?N
M_UW2\'[]KZ%][\E6X21E,U80_O#E02`HQQ]?_S?['2A=R$RR\@17V/K-KQ1(
MY."QY3(AON04IZC&U)JYFT-@I882!4\Z+'CQWX;5G@FBJZNI9-H4E6[57N:-
M2GL5>5TOD'A.^91NKH(40&5(H;H#J#K$K)L!^W^7(F7YVM;]>HW#A%>VR#J-
M.RN<TS\#IT_":,'<&[,29DF/D:E-OFY-476*D>D*C6:363$3X\]^KS-J@+&F
M%M7,9O2I]*IW&J]!]6-2C*U%/W3`V@#[X_$X#?/SQE7NJB9*H0&&=G,LG*@Z
MYQ.'L3M?R\`6)UD6_6'U`+MTJ'OH.3M5"56[:T:@/5M_C7Z@?X4>82(PH<ZC
MI91[*CBFMGT[V=O5WG!R#HT`$7_H/$PF9W)F[NSN<GI=Y*X'O:Y;WSRFACC,
M@+K3N3OI$W@#WO?K?P>[>_-GIIP((MB]+VDFUX<A_,&EHMAI(X22K6$&9G^=
M>4Z3J6D3!B<[35:W-][$V&F>7"^2[QN>85*.8<]VRE6!2M[/EQD\N+]]A_A-
M(Q2M]4G>,'LV^WXB"-5E0^'80*KR1!JI='L?M'JD7SBXFJI#.XWAUQ/R9TI6
M>X[X@E<GSB]B_07T'-2UR9WY4\P=5'$IG1>>5Y)F..#8&3"1J!Z@2T28%-M_
M*3RF9JEI2G8#2\C0-17NP-?D,.F6-`V:XH,GR;L?4\-N^_VR%-.\:)DZ*\(*
M3=VK>FB#VGV3D_F^"P9,(Z-Z_\8(A_>6O;&J^@9(I>5AW#5\603ZY\RT8)I#
M&)*2BA$$15W@O`D9[F=D#U1+,<\>L\U'L9=UJY(E%:<`>W)&:*9[>GSV-9HK
MU<2@<')=QQL\'P^_6LVUHX/Z*ED)`TX(*(E'K;GV['??@/?]^K]%X,ZI3-X%
MP[SUIK\#=&]%M><PR6R4,WM>WAB?&4[#R7OQPH)C&!O4KX4<Y@)@'(G\\]1@
M(-,S];]PI<3A^_]UNE4.N9LK@XXK2IF*C>GOE?ARS,8]EWR-S'P`JY-N9S+.
M*JKW^%HP:MD___X#A*E@AQ;49HP]Q98T&`<SSF:?N(9'&IO=DN@R<S+61A:I
MUO/9#`MJYI)Y@TVD8TG);/6II\W9?U\D@W%V<XPR@ZIF!(&-O.YE[X?_H=@A
M.KB3K)G-/S-,`04G:V5(JB4!,K7#H2<P->O+F?-NB&*T2H3-*LSW\ZQJ/)6W
M@D57B)/$.`RVSWZJU'[V_)G48JW;YFI:,=TEF4I21J!(=_;&W4%E]G39S20#
M9FN>QP/:C8"*S,J\1RQ4I=9-37<G_:9MU6629E"R;6<E@&_`^W[]V]E=7F%$
M^9K>KLS.D5OO].NP-K*KN'X+K5F9'=\\![M9:CPK9^V,P<2^RW]&K3Q/"_G:
M80/2&)V.$BK`MXV0?H._,@#)/9>T&YEE4[[RF#'_FK+SI-)!K>3-F7TNM!\9
M6FW!FT]M#0"\#_W]<),V64&O1TK7M`;'IL#VSV$<H+KC.QL+).Y3?@AP`#"Z
M9QU8_F2Q4%^4Y$UGAK%'SG,-B3"D60@O295_+3*M=CU;22I),A>>W:?P`/4Z
M*T!9MTT^7Y_J&=[<28])T-WW-$`WY>9,&&4)]]^?O=8H9M1)U_,`:O./SI+.
M!,>54'G%B$`&DPHD0YQY\[X',I&1$^<PEH7HQH70V;@'(+Q?\\?'ASP._>NH
MGC+:/DG[++9UDTJE6W)#[C$JE.S?K$[M@(CGBEE'>CU)9N3`5&N[,=L/U:AV
M9FBT'N56W5;;60LS$2GD/&JPR0EW;6_`^W[]%M#]9;#K&9J+'YM6*046[G>Y
MW3-7IIT9K5?%;+J^RH&:K#,J2_F,O9,IXV.C>1@P$ERR9E3LA$V]>W3B2CD]
MN#7Y*-^R.EZTW^NG8L:7`;?$ST]9W@3[6S8((04_9UK]C&4*O+JVK"L#R)KJ
MVF=I-[G[V!ZF3I$*H_7:95AA66HVS3VK4:<MP;9@MC*8C/$HO=S?>WD\!`>8
MQ]GIQI,#/S'\\('Y:,S*XIU$)[D[G2$!NSC=[<+G(-D.G*,=O>R9]JAV*X&D
MO#Y?\OGZE&NOQJ@(4%0]>&C`-(&OU;NETT4&+%/9ULN8$55&C;]2?J;;TY+U
MZ<^8>@2?5"H2I]NQMA1VLF<V,((ML2)#4)C)_&6!\P#/[,$R;Q,M^[]?Z]YD
M"@/(G;R>'B/ZZZ3-NB5SSDL<&JOL"1NCZ\_%,<'M>X_'XU;6K=;:&VEU:5=Z
M`OFC,#&-2;&!VF/>*@WOU[\/$/^A]X&)R\]9U7N-;]?@.F.462W+I_%>ZS+7
M/$+IZ2-*R/PB9QMQ"[LS,&Z&,:%EX211$N"4C;K#S.\WOD?E$R"L>4)-*6J)
M)L[I\]8D*)Y1<`=';TS"F<K`UTRD;?4&E!$47`.(VE?]6,`]CTDF.].`I5$A
M&(SE#ES+K7LQ[XN=R>/K-<H'#`IU,DY-D80S!AY6CY<CZ&B*%$B*J@-IJ%ZE
ME-%\19D9STT?I5?DYAU=:YNTR*U[/:/H:_1I65R`H7_*3'<'8G.=7I5@GKGI
M.>G8=5WE^7Q*`2YT;&(&9EF6WAC5#29@F6";WF:(RJ@?+,X5/\S<09/G'6$5
M,RTT'_RY<JDTP,FFD*<_89G).#T'0J2YUT0^#;`:Y8KM_*H1T[JN\OK\[-D(
M;QH!2)A06A;L;(N(RADP=M%:D6BV/VME%C_&CV61LBR7&J--)K%6JD#)2FU"
MZ4?ODH?3U9P2.'H/!MZ`]_WZ#7;W5Q;R5T$QLQ;_K^&7&W!Z++9IA5[2?!5J
M;)7O.&1L@-5KNT[M9O/1V=?_T/&->#F:Z?;[@3=FU1JQ'$#E2Z&`$BU7Z3BC
M2F'8K=Q2C#M=XQX%CM1V.:2WT)F4RBJMCRH$\FE]Y0S,Y]81O@:SC>M^X`QG
MNE*@`!-Z]S@.H-#\?#J3*.P`.!I8(%3IL#\;JL-\'_-2<#M8TSBJE"*/YU/J
MMF<H6*M4J:*=L<R)`E5C*X@(73L/(F-*/4!#G+MEE#L\/SX,&.:9CIQ[S$VY
M0K;-2&$%@PZ(8]UAD"?=O=U9HW0VLG1HP!CD>)M6UP%(6FDI<V"K]]=!F)D^
ME-S,I=\BTOR#[J+7<LQ!I<+HF\%KZ(T+"CI8G"=2H,'6&".M[(PPEN,^/8`-
M!@6P6L=W6)%DFKOR&UWC3!,00`/P0XYL!OQX`G8_/U69BBO.O9):E,01[PH<
MZG<8==:,->)),*<#ME**E,-8XVR8.^^O:^\5F-<ZW0`][Z&EJ(=$X.P>5=G0
M&_"^7[\%>K\,9/DK[&\"0Q&EH4Y#^S-:V'R"KKFC^6\R"W5SYJIK@))!;U-K
MA(J<L$QMP>M:*7?>^/:1F(8O"0C5:;$;S\-<&/)`Y#BP[6=91JK7&'<&81P(
M'6MAC&4]RD=.YQEY-")=;:^:$H/$JFH&&DZSS%4]_QW?CO?<#VW+K`R`N<FZ
MKCWMIONZ#;,4TJL:<(KY'1^DY(UTZD3`:'`JRR(%(MNZ2EVUCUE2?($QT?9Q
MQF3=PUJ`4E($;#"K8XJV;1,<'=T);3O?7(ZY5$J1==LZB*I&NDNBHQ40U:(1
M02R`6_M=MCG1K19(B#G#7@1!GJ)%MN]B:N;"%`X-D*:Q]^[^50Z-6V^6HLL@
M:/60>>+/Q<SP79S)BTQ87!O=&"`'FQV"UJ85^[6A!@(7"-F_<UU;9[#1F@1E
M!.J`9TUW'5BH.O&V9NNVB3RNX=8.=G\Z,F66KE=[&$2L%B_4GF-9T@$(F9]C
M@?FU&M/@&%\YX1EP<::0E$TUA_I2(]ZQ\9QL^UYKN%W_&_"^7W\,Z/YN.<'Y
MQA?W5&_>T#<R\*;4D.9C<`ZP,]^><#C80Y(BI[5;=+ML:/S!X#BR@WD0132,
M"%5JO)"JR8FVX:*A^*MN+]QQ7[-=T?M;UU"/2*,&,&?46[E$UB7MZV=KW3\'
M!;D^&R2U8X-)HRIYL-&1=;P_CWL9P%X4FQU4!7J-897EL>QU:DU+$^K[ZD`O
M@&K2L,]6E!/7NFU*=_5<*JZ;79B2&4:P=U&+/5*TF1,()]/$ZY,E(2;'^*ZO
MERQE464L<D^;^WB/95D$KU6MA<9064M=C]%,.IQQ)]!LG5'BP(QM]C;#CF\R
M3"6NNC8GE*/T\HG,',:[$>H+,WD@1945@6Q'T%F%@508X)`*[&"BQJ%3[O9Y
M8M(LJ.NG283YO$OD13]+IAZ-7@TD9_]\,#.R'.Y3O-,C/4F?L,P8NL8`QAYU
MLI>NZRJOURL/.!3U/G4:5`R05GSP(AZQ-Z2']_US2T&P]YV-K]<5]V8>L[!(
MUV^?E\&PE]I$V<_X;#7H]W^_F];>KS\+AN7/5!L@179RV;?&F^\<OS)OZHJ]
M"6VA%\DIK>/+M:;?@TECTG044\M`)8TU\3YT9VM5[W.4`=0A:\-,A/T+X<<E
MY#U.N5IWF9GJHG62NRO:B82,THM7OU-5@X@?LU'#&%FEN.-K0X_8$^6U;RW8
M'4!^OX]:Z^YQG^C'D91MW40$79ZGL[@]C;?/A&59=G6"*>,UGMOZ6CMXGBI;
M^(9&VBPDZZ'MF:@@9/^!B<ZHK03792[./$.BM)JN=80DV%B_!>)6X)_=.%RI
M`A.-YSF-W:R5LTT&PZUO!L]DYME[B%4R44RAUCK5B$#+SOG[\0H5AET35^<I
M>:UC:'D#@MZOR5C3_P[--V=I<]W0&&3*&+"987MU<.('U7X]5]35`:@I'9-H
M&)0%B5FX8N;AS%_]8J^<&O@<KZU6^?S\M"E^#S'=H/EL$+,4#9Q%LL@T2/%!
M8CZ#8)J.?5,QR5A6,HOAIM*8\:<3Y_/T'GB:A7RK-+Q??YC=O</&\)HXG)SZ
M<JG9>[\6U4K\\R8C[(E"*(DH`]1.V%TM=15!M=4R#:K"/EVD.EN]45.[UJUJ
MZ:"OF3"83SMQ2&L,S0")[&Q0K'VV<"4[+[QSFI4,<J"7W%G"=7726$Q"C;S\
M@VY\V!0Y:C42;KI#6G=P:[>G=CC56H]R!@GZG%T$OY2]H2SHW,*PTAIXK:\U
MB-'#%;?8(@4K?U%9C\.&ITJMNBN\`U_:SGJCLD(+SDP`H!GKR7Y2F:1N'*A@
MUH0I3:[-`DDK%:U*1J;17C2Y&%)1NCS"K7E&NW'R0G[&']X:<'.^-)&,HY=D
MZV78M'_$`^)$I0(9(-+E(8+>T`B.D"G&)<SG8YKNYI0)A&IB%7JH2S7O_5-#
MKUONTGDZS(7]'>@QU"PJH[UR=MC@QCET=L*LGY\GI(]GR7/R'X&O<:4;ZNUB
M9M*3/%F!@]U9;`G\<!MDK4:''C."2BFJI(8ZWM")SC5.$COCL(KM?;T![_OU
M1\#N)1<X`;M*H2E5%/@JF\Q;'>Q>S`1?AL\-"$#R-%WU[*YGS'"..YFPDRGH
M%,MF31[<T'><?>C9*7MGQSX:S<)]I5WFGE73SU-K9ZH-$8DV*:U$3ZU4#(FO
M;V/BJSP8D^IT3`<3[0Z!WLB,2\:;LM>F;NLZ4ISM/K`+-:$T?5&C,7!\3F3C
MR;WF[?,UV""JH(U&:S.I4X8N%VG/R#I=6>R&7.[+_<VT(G4^?5KQ@-;&-1:J
M*N,?:EZ9K,:C=$?7IGN033,I:=SKL@P/O=F@L_8UEL^)K3)U@*R,*YBPNDSA
M=K(A3J9=47)NG/(%L(+_.I/!T8RZ_SW^O0]`4<UCXSZ8LNZ30A1$TB*`$R32
M%HAVZ[IYSX.O*6!R.0NMK6VE$;7:`JTLFP[6)QM<UI2\E"7L81WLKNMA,,$8
MS$N2K.(TUQ=,;;)]%JJ$9$8Z1>MYF+(YOS'I'H7M./LN%:$=B1`P!B=!HNIM
MF.4K.=E\WH#W_?HML'N/59V!'GWH>L'O\Z3[G#BYOAI,.(DKBCD0I,(YZ/?L
M+N*&K6N!#1B#XNN027!:6V/>>';A^EIG>X@\[@49'MZ4X[U**1W$P$<S@+EF
M3GPIC59DTL074MJ`(Z)'7I2P@,\*V1<[1D>C7-N\M>"[0([Z4G5?RA(W%Y0?
MB*F4(@0L"!+I,F-&X@V#8?'OHQGE5V>T[T'-!EAJK4,G53'S]F`3QW*Y0]QW
MD/-Z#81K56QHZC['>6";[06I(8>S\]5?1J8=IANEO#"_L^FRM<W9:"/46GI%
MN-D53(/1"9J%,F9(06TZ"@JX*B#J:UN-*8/9^S`!%["`/[T_!H6+%M!Y.W)Z
M=W>M"9T9>B2R8>*>-YWJ!].KU2@+P6:=E_OM**UX?CRG9\VZK@$`FCV$-,S^
MS+`'.BAW*-_8:YO2N1GIDM5OV+KT7/_VV,MX9A*AI:7O-85Z/H9ZTI[F"RRE
M_0:\[]=O@=W9\O`[PW7-:%Y5><7HRI<8WK2:\`1&VR4=H^>XL:2=\^3%48V0
MDLZQ>&0F[U8EM(-$OVGYJD7M9*PUTU5*D>6Q')W?0[6AE/:G]#H[7Y:AZQ5'
M`Q$<V(I>Z1Z(#"8ENL>%_=MR.+'1`3#2;L-TPJ?,OS*"MNYY9Z:31A`Y;W*I
M1\F%D;90DV>ZBB@!>*=KWK&Z6DQ?`_"S`3#[@G8Z<X'8E,WRL9AS=X7*P0?U
M`KJQ@*[UC/M"&`\.5KS-B=SG1ILP3)1/?&EUJ*6G5)-W8CB^XWL/AK,4[UH&
MX=D."@<R]2>&WH,,.OM[5N"?DN;_@Y:S6??1N,1+0=KG0W=J6"6;:H);^QQ-
M?@\PTHEGIX*>7PB$,`V9H._SX^/C",9FQB2^EAVQI.MD786GHP:"6?RGFW*1
MNWIF>Q69`6#[7&@R!E=$R9"+.SW;,=>']\#=AU1^MKQ5&MZO/P.*_\#O>RW9
M/_+&D]@O9\-@&$88P!X7,)+-JJW/K&+`1-[&)I@G`"4#MK_"J>\=K6`$AK_R
M?+7V+RXOF*[S6DF].6<"GK(*$N53W>'0[4>-H"@N!=#%SS^(*5?1,G56[.&0
MZX(82U6C$XIH>ZF!9&]"HVX8<8`G<YZBR+95*4M[KIB$1X,A"C)OV,LWTG'4
M/^ML4ST3=;ZN+8MKM3V/E5^L=:Q>1]FZ:G^_7I_'^&&4>'#2@4YE#M$#1XA?
M]$QD8(SVIV3`P,]7&#`!6N#4`QI5!0LWWTU`.>D&:+)Q>[;&HB%<;16'ZX-Q
M/?,`SY5LL(>2</XW,($P"!-$MJ]1HAJ",;/6]MZP^PN\U*^J4T?FB'!<6VVR
M5+1G32]K"0/%>2.K%19,@[4F@U4>13X^/KI=-E*X*!,YPMDC0Y>I#&R\G"8!
MPO[,=)]`ZD"HQ]!_YFR>S<Z7-EZ]_&QBEPPSGF*+J1G4)<.6GSW)-^!]O_[C
M8#=E9_GON4Z<:@!E)L;GPL&['%89`N,..!D0D0G;]_1]5M/*%"0>#@?1S<IM
M7.;(;^Y$&K-<`-XSQ:39\;!MFVS;Y@`!Y*A8C;]!25*;`UA"=RB;MQSL%@P`
M&_K'D)-[1-R8*32I6B##\(G$$<3J>\+5C-8J4A#;QQ3@M6!7`I/DI^)H,*H3
M"[-Q."&LJ_.Y9@3]@:_YO#@@H_6&C?236.*=DI/P9__]>KU4[6-5*6V('#)6
M^V%)]_Y*88(#R.C.KC.0/66@7%F(KM6O+L@PS)HD6J<N\.BP78,^,TML,V;$
M<!!]PZ3*@:#L[YO(5?GJ<G'/U&9)VN\4!9B]@0;2P%`44]KS/\KQB\?FU8`S
MC`G.WD&G9;6`D<6#[MHW0-HR_4V_&2EXHIL/B2F#>BW+(M\^O@V9/3FQQ"E%
ML&U2%1`](Q.H),\D!%%WN`^8<@!=/Y[MD6,?T:K=6?`J76+QS"!'1(RZS<QP
M,RN1PAFR3XDAJ\?]+FEXO\[/+UX5(EP??M=E".H4F*A6\TO7G"$;*(OB\R8U
MK3%Y&FU+;&!!*4JNS$,*&M!DDIK4D"OW,?>D$K]@L^@1G*Y?_;7GJUA-LF]@
MO7Z+M/5_YL^,-E;=OFZCT^RD!L"VJU?I/MZL2<[FB3B=42T;UV71O`ZH5C10
M.=E1<RLBPLBB*LFU\#Q5/;$%IJ[&;\+^`2=KS=0[BRES4(C<?F:_3@;`,X(H
M!^K\&*LR@2`M5LJ7%KB6<`K28H:-=J5(;CQIA:+3O22#+<Q:YH,+%1,KU[O[
M*E2ML563@=.\W1OV+L@$71&%W`R-KA\K2ZQ3$"W"J?;--J88DX!*^2!C1.DM
M?--GX;5WQ;H8DL'RVBC?T*D^A'F@ZJ][B59FP:O<)B54(PNP,[N]7&+F&W$\
MO.?S&94WDJ:O,T6T,[";.A^*N!KS6.J2?A"C_CT@1BL#5]E#RNXD5_.U8<@"
MM_9X$PG0.1GVY_F&=._7?3#P1;"K%ISN7_*+"NYG(%^4:SCABB/`Q>D]99M$
M6L[@-I!R-":54I)%>4>DAGF8JW_C1M[+UWYU)L!MH!"<^GKP:I1<RJBRVB[[
M=(-G9WT@JL'M=)QBN0)G<F\'X,XMD^:3MM48M\,LU.CJ("7I>&[/'DSJBI66
ML#\LFCN8\'H2ZBYHO3YP(FUB#V,]=E%OV.I7^KFO:BN1!%^Z^[PMYJQVO[&(
MB$PFO:;>C4AL*8NI#TZL84R0&T&GA."*QS72:\ZZYD</:+TN=%R+#`$I?(`]
M6=ZV:(JJ[.(XQ%&.&E&D&-^_$[L*0[]9I<[@%#3Z()3]3Z@YT4P@7/P>;8E]
M%:P&QL:>UV<&7"M@W).C1NUP6+--?5870]P\E`2,^QD5?P\NF`A!)^>[W%**
M?/OX9G2KY69FP9A.3-0=[HCO&)41;Y:G,P?(Y3-U9!CM[&VXV!J#,Y,,LREA
MJ&7`!,S7&$1?I]Z_WX#W_?HE=O=.O:F6/O**+C)3Q>+-&J1)$)KI?7+23WJY
M#>#\L_IG'AWV@+=>S1$E#H"DMQL/#.+/1M6'"#[GSZXK$VAWIR2E'.NZKB?`
M>+[>=6M`+M,$)I#'\]%KV^;#3G>@NG'4*A/'A33#"U^6VWBX```@`$E$053'
M-YMS,F%(+E7;G(7PX_'801>B;!/-`7[<_^.Q,QRUAKDY<XBRG=&9RY$]8&`$
MGYSVL3H,`@,4+$=C,#;$-VQ=W=DB,Z8H2="X::6*JV@4(LMCD:64;M\-2,+,
MCPF0-ZXE@0PM`,BR3M/=Q'16185DTR!D:F>M%)K>T8`<HK3G_W@^11<VCKT4
MXX_H?]O6W=H=$:TN<R7/@S!2!,4UFD;S#%,;H"<<8N>MJ>,&E`VT:]YC#!X@
MWJ6/(YM`F1HBT-&75'/">N_1Z%O#9*747DJM\SN4::*1QP#4I13CH!A!YL6&
MI,;-U^/KG[4MVSPM5QO+@R:^R>8A#>-;S/[OCZH1H"7/3;O0N%Z'KM5[@THR
M;+WZSAOPOE\WP"YO<KY)RN,&%TNCX&C5''G[?9+]X)?@NMT$>?.S=<.,L:E-
MF-Q6K[DLR^E@X9#.XDS+-I-#RG12E;6EG&3Z^941\M:A&L@X867#:!WW#8&L
MV^K`@4@IBSR>3UM)[:276A#P?#R[TH0&E;CQJ&U0QM[XY*6.#""&_7<[I+H,
MFTDK,S(OQRU]?/L0E"+KMHZN;)'TP`I24$ZRH"R+8W,SV:!SZ9^,M?:L"R8J
M^TRZHW3G=0@4G:M7EI*]HPK3/N/CXT,>RQ(G=>K.QMC-3T[5"3L;?F-#@^M8
M]TU2!KPDT**M&:N/JNQ[VUZ@,R4-\#Z>ZIE+D-R?=?.;ZTH`;0P"8^#N+63I
MF5'-..J?S9HAY0S8(70QDHDB!<4HNW1&.%4-H%16YP`8YS^9E17!*$E0:RGR
MD!K#"-K)<Z9FV[9A4F,6)4V3:M]/_#Q-GLTL2/'S[ZY+*:_.@YZYTJ4<2!MN
M&^"EV/F1R>_QA`1@8FW.]/?VK[V;UMZO_PR@_D,-:I[$2_I'9['KK0,,:>M8
M_NJ@\F*;H.Q6DDO9+67KD>[6]8+&:.!DPR1:HU1C'2"V:WEL!,//O03-SE]_
MAKHI`(/%A/0.<LI>\@$5V;]>KP$^%(M0:]W![,>'<DX;!V<#NX_'0VJMAA5L
MSF5`B1/"==A[8K([$RDV>5D6*:7(MFV[=JT^1`_@W=C%@L;:[M>DNYU\S3&`
M_?[)2_<Q^$-,W6PKH<F!%U-JF\[1:X#'6/MMTHZAF%4Y4OE[O0M:>U=XK,G5
M8Y$*]JNO?7Q\R**L6742NKHL`70@`+$9CV21![;,_1`2/=(=F$9FUJ:Z,7DN
MZ`U:<=<PUE8B0GD^/R37(;W_JFJ^<M8(1:OD`2<OU]7AU+IK(!!E,+M,0-B,
M07;>T#F@(VUJ7W1#'&(0G`9WZGX'/6P_EE[?E:;G8'R'G6`015::?A8WWU[K
M*I^?/Q/=:289&IO#H6/5^S.<2@6=%X[Q;,ZI[$!OGF[C2+3M?O2'*,,?[VK9
M>CVN"+:V/R#IZ^@_C1BXY7Z;;UFR]^N4V?U"M$>1$ZOR`).\6,'7.=CK!0NS
MV_S^6%R]BSVP3USICO?=MLV`%ET+..1%>5T^@J1&(>QSS,^4WY@GI#V3FG0-
MT$#O_LW'\NP'5*U[K2]-HYY.\>UVO,NR]!0?HX>QK.NJ6.MA3?E8'A;LJK^S
M&DE+*-@Z7@H%!?(L3^/@U6V#MTWX>NW7^MSOL2S+;D4L\SKC#,B?92J,A)PJ
M&EP:NYR`2`DL#A/-RHPU3<8N7031M8_)F)_+8MGIRLH@#0+UQI"\MGSO#"_R
M?#[EY\^?84M2JG%&HDW/+>N4QOD>P-;4&*7#;&VCU_N&8V$5H'8/'EW2C,ZZ
MU4OF%7D\%@%^;\_7=>^ZJ0S.9I?)SP3+YS1XH.DGH,]&90!;K":MSP!``6B0
M1B6G`Q\O&>FFMP^"X*3D*BD%Y6"!;2G,Z%WC9,^ED?`R0BKJ1[=MZV"7PCP#
MX]9T]`<]X*"R1I89Z/7/]S*-%S,8DKC6:1G'P=XFVP=%?GY^[DW.NI&0.>ED
M%(>F2A2V\,3'Y9KH>`/>]^N76=5XLMQA=!*]W41J]4O7X,,YV,^;*R!^$4#+
MN;M.Q@#-KKEW]6]4M9"Z;NY\0#QX0YIZ=2E'!;0SN]Y??1GI)NP;?5%LAB[W
MJ#HE9PX_4=WA5=9:#[86JOED!`2[48/:R8Y:VN#8!1OY^[)!8%<-\^PB95>>
M^*R?0UZ*BBE78OGKP0`W:UN9'%SZD-,*%E<'CCXH^R$`["4QR0%A[0ETGH^'
MR0#C>>B8+#CV)>NDAI;*TP>/_<CI<M-@%*KLIIPT,K9J7,]U=5DJ,II=T,G@
MF08CY#:NR4'=JUK":6J=ZHR.[D!?5L'U6)<M2.R27(TY]6YSNBF(4&6.%$K]
MY>K$7LYS*(9D63,7YT@BJ3VV7]=_X%EB)HRC@8R<M!DW@.O\GI'0Z'"@.@LH
M]1ROJAYWI@QA0SR$>6'V7`6,?869!<24S\]7<LX@JL`(7>817SC-XH:-29!Q
MY[P=0)XAV[@L2ZK3V_::6FO?:Z&E`%U(ZTR=1ZUOF!P(\_2LI.T->-^O+[&[
MOU/G`W=<G?D*7+&:=RQU?W,PU+4HW4XY5_&=:NJ<\=WTQ@)704,&IC&)1.ZS
M]K\"=,/U*G:D[3Q:O2'O6[<,K'%\NIAK[5![/!X#*"7Y+$X/*)%:MU"G)[XV
M#Q*^IV^^B@@-<WW%CFO7*TQ95"O_M&O\XI`R$M>QGEB@F*/`,_*9TV^E3<%Z
M@I*,I1)F>$ZD"#,&3PYVCJ04P<&F+>>'^,2&N"KMW2O2JJ=)2<^3B6\>LZYZ
ME%SJWT;<0Y-YU/,269'5\?RJVX.)J.R`(===2I%:*=M:I3R7N4WSS:S4K)PD
M/#L'S+6U]NQY5U>B,[/&]7"RE#(:@H^Y`K?Q!&<RKU+3&QIA,VR`R0YU>7,3
M@&>L*J:'E$["E#+JK^U:&_O#ME6I=8M9)^%TW6@C#Y^909;&.BEMN&-)#[49
M&':<B22?R&B\0\Q290>EE:2?6T+%@P(F>R!*@2.CN=H7WDUK[]>O,[L),W3K
M/2ZZHZZ<FTPMU)D"6-+Q?(>*IHZ"H=)OIVY=N;,\OS"HU[J_CFF+'HM*TW7>
M\E<.=8.O-`5F]\O$O"#49CN&"AE[*;GE)"?VE/YK2RE24-)M\LZFWDH0]*4A
M[8!0S8(<34\T[+4DS5*2I&\G\0D]@QBU<Y>R'))NDGK91WX,Z;.+!VL[-'U-
MJE88<*QFRQ3TCGJG-H+X+#,;X?:NW74.\S\>'>WZUY!U74?#4G]>-/-)LZ>I
MM)7J2#<'-D=36:RFU$8SL43!-ATY";!*H3.<:L\&B(#+N[6MZ^JLM[]H%ZYJ
MXZ^"XUDJ//N=V?N%IK;)ELB>25%?ZQD@!LW:T[/$[W70BC&3O:=RE&XX18CY
M'M/3%;(LC].(BR;S=5`6$\NRK&SI3Y[E?HW$SXUL,A*V8]I3H`:Y%*CR'SDM
M:;1;+\46<SAWF```F+JVO@'O^_5O90&G"Y4GC)U<$C3BSIL+2:3$VNDFA8F[
MY0_PJ@SG@,ZPCP$\^MY\&M%USIA!S^F=I,SQM0=W]XFXP]GVQ=,E!;.2"DYJ
MSC@9'=V1;<33F1."N1D#,VG.N`&3$[#JY/DYB1!$:05[P4LMJI\$A#JMM[,H
MN/&@K/A0/]`@J=3;T)Y%6*^DES5C9X)Y4B?(DX:\.#R4;:M6U]/\$.;+NCWZ
MDJS9U%4N2H5E\[F!$!WD-,%>K<@2E"U:0."8VC0\07XM9^.J&5I.K%EY`^AL
M6W5`!UF<UP-^_;.8E!7<*1')K*RO@)XV,Z$DR;2980*3L6-4`6+"$.M-(Y50
M=+7UC0$.Y49)+U[FC/@K08LX=VSSS%2M\UG#X&E`*A)48WQIB0A&`Z4ZC[.@
MNC5TYE/$6AM79H^4JI88$S8FA[UOP/M^W4J#\62QW6$*0\VN/G1O<Z\G%Y7E
M+S!GN>Y`.)RAI%]%B8D.,>8(:R23H&HY:9&5EIV]R[(?;IQG..GZ#1%_.:H$
M))-%SE.@J<1.4M<(@2Q+D5(6R\#0`D^>LN@Y0*+,-$@MZ$M.,4ECLJ.9(QMR
M&@8_8<R/CZRLLCP>Z;C/0\=A+#"\Z\5(C6G5@A3P,/';0FQ@F3)_C'66P5:T
M']JU2\2%J09.8RV4O<SC^7SNI0TRL:\525WO]&%,B?:]NC8SLY-KX-88*M`"
M]1G3?28KI?]F4H]#Y6*6+=G@9A?V@3H-CND6S52"S`>EN&=4E$G1\<(N-\_\
M,)?#/`D>>$)RY)[BB,$WK6E"(R:\GBY3?D+7?GLE%>=&F6J()T'%I$XXNJ--
M"!,O7Y8&-XDM/?92AF4IMC$/,6@?_0N9QKAFNF\<O?2F%9P^0[Z-)]ZONPSO
M'9.)7Z1\4V;R)DZ<JH[!Z5A^Y7+\1FYODE-3C(BM,6=:<+J7#9P"SY@BV=2N
M\4]@L%ICU:R3_L0>-@.,MMM9B8F369/Z37+=@P3?"77(G97%-"DR\*UGO!<[
M6(H@+0&DRL@@J[F.H&673WM^?,BW;]\/364:Q0<?Z+%;I-J#M,VI92G67.`B
M9-/-3J0U7Z">#LH`I3(!1CZ^!$Y!B;T<!S8J16NGPG040K9M3>?Y68!+2M=$
MUN4HVEW.W">=$82HIK10`YZ,P'1^#&!H,C.,[FP>U$XS'4&I`*81WQ?3GQ6T
M>/!;*PV3/35?UTYEB-&UF0\)Z#K+WGE;WKOGDF4>:6J%F03BW7Z8MO,_!"%9
M[:LOYS"'!'HV<#<"R=138(**P>PSE!AI=1Y.]G+(A9@Z<_J&,^`[099S0QZJ
M7RV]IR"(X:KGL:V[UK!5>E%9J-MGF'O&VA:=LTWB;2W\?GV1\<P6UI7JT-UL
M.'_E/7CVOO@2,<O)"M,1_9EC[;U!L_L/3NT_;PSZ5^[/R4GQ8@""@V@T]E%X
M%\8-QY9=B/,ZY2G(C0TQ4$@D`3K"J#-T&A%%^J"@A(/,:K6*>,I%XPS=2&/+
M+\:_UO4EZ^HZLC6VOBAJ:X?@NJX'@VD-3B[;/5I3ES@=@5::H)R^#'ZZ86'M
MP9ZMDTU81M@:/%V>4LHN[>;+?72P=X:!]+-D1M`+K8VY4DCQ:?)66SLB`YA4
M[6"_+/#"1>.<D:K2S5.AK3]Q':-S!I.8B>)DM06U`@R`6[VDEYE-"`\2R@="
M=&VM-]R`8\&S64[?`IEEI'@:-&3@3&#+JJPUMY=?2X`D,H60\_U_618I*)'M
M#J#:EK)T]2+2V',CK)WQ@)&!2_@H3MN2^Y)`Y)N[W\_"V-M1>1[J.-.$*D1>
MKU5^?OX<ML)!5U=<EA(S\GD*?)$07$891=XJ#6]F]S>4&>YX=$\M?6\PP]/?
M\V8"F.'*7Q>HY(TQ,GL+LD,&VM3T=GCAN[.#JH461[\UE(R=[0;9R$FSW[S6
MJ@"=(8K?A=$_A6(ZPDZF!>PQ-GV?.L1,XP=7$R7?(D$H,$%;0B"SLHLX3HPD
M9I\SZ[HFH-9.(.L2E;QW!Z?[P5%KE8^/CPZT@&)L4ORA30X9H**[YAF/\08*
M[[HOY>`.TU[2<=39;,7C\1@')Z)IRLPA;EA6TVH6PZY/LZZ\B<:DZ4F7?("2
M-O(9X*386,D84@>R0JVE2?\</T?(1.GU8/P?UH[WY+EE3'RMM)`@R>A,Y;K<
M<R)5YSS],XR*&'T=PBH4>(,+/5Y&J<&98(3?\U^3W)T2"M,W=89AKC`'O;T/
MH3<X-_44O8[G*Z@>#9I0\U"SOCKS8((1G"2P(%9YPNPA,&-MUD?['2U9AL&*
MIN]U`/S'X^%TE6/ZI6Z;.LM@-'CM5$*&X)4F;US/R%1NDK-'^#:>>(/="ZAP
M5<)Y_0[72';V/M-KN*HKX-=S%^8:7/&G/]2MD0/FM]PE0G7G:`08>2E6(N&F
MPV&]X?MA`&(3G':;2ND?1WZ>;!SC<XJ(;!;\"/?[-:0L',;+&R2R)ACF,-FQ
M)0R,OCO&`U#2-LN[OSMDK2K];`3+>3DG*3']25<;X-.!G`'QH&5A057=JFQ;
M/90:<(CP%S,_,BD]:VHR:RQB/`SU7';399>.LY.DN4T%MEC$=*)K0X"Z5<$3
MA[1<9*[@$QQ:%469,PS`%(,J+4,&!2!BPZA=-W`7X.45.WBE;\:D"60Z(QGQ
MOCK`7;H=L9FL?<8N3_>X%=ICLG9&1H)6/LH986B6,-0Z06FS(LE@*!4"TH^E
MA&?5`QDD":T&;O6_E4YW%DQK,&8DM7RYB5+FF;&*//:*$$0`\GP\@DK![+Q=
MUU76;9/8#^!J;CT@U,UQT/7+2`PIK'1CYDTAFL%'4@[CFPM=`+4'WDF#MJL3
M?CR?\OGSIP6LL&<JX`\Z3)`%7/;!KD-G#&>R*6_`^P:[MS;'KY.T]RS4O"?1
M],?O=F/AU\2XF;*.+=K.<G'VZ-<1ZEQ$1AL6G]T44I8IH&/$NM;`%(:=V^I#
M7CZ,D]*59KL;6+%9ILVS@LR?LW/0-3)Q.OW-@SDH*,-X(&07<N"KI;9:39\Y
M?'F=Q8"?GYABIE'50<U:3`AV)HV`RMAC!XC[N"^E#/<OE:Z%.GAZ*OP8<Y[.
M.XK'!)JA8PC4G/E$FR_,@J8C$M54U7$]2W<;_(4>43?>Y0#_VAAC6)1*_CD-
M-"=&!1VLML`!1WI8/Q-Q8P%U-*M2BK`XDSX&>F0_+D[=TR[R/]0`K@U,_/Z_
MKIN5W4*BF8IH>A`V&5KP%9A=S=`A4:V`=Y)#J`7.ZH7A$5JR\<\T>EWZ0!F4
MV.R`_Q%(5"AH`?/S^53F,_'SFZ7XZ_7J[G:I-*!F8=4Z`O)P.[@P!C;4#A`3
MJU,K/>CO&PFC#WD<]YL.OUO$RQ&<5WJSBGEP<=:-D81";M]$RDF]:WC_H:\[
MJ@QGM;.\Y!-PNT[TLM;WEQKC\%L_[>OLKMXVEYKA!:3%UPJ!9^A+I;&@:1'3
M0'<25F#"EI^K.]FZK=F@.'9@MJ\-@7@QM8)4!=2D8_9D;[K9ZF:`G)$LLS#.
MSGT.S<U-">];^UU.IR-YDFTX#3#G!=/TXX\HY]?<L5BK:X)KS5FUNWSINL_V
M,S6Q%Q[*!;..=HMHK8XOPO_R_0(J;8M^F.((GO";'KE,#`[&F(U`<S3KC3&1
MB4,>)L&WJ9VF;I1U+%TVE_6[*U;T%+*J-P-V/=.G=Q:4M,\J/LGC&;]>+Z/2
M(%W#F"8+Y%T*T^^IM0:W\KP[V/@NPGH649)WD[.BKUMM##-9A_07;HJ/+2.O
M>P6TCCF3K;H[0#9V]^.CJ[`8%TOU$#X_/^7S\W/H[_I=D?:LB<W(5(!63`#!
M21T6S3F#*%WC)/%L_YHE?#R0;^4;=UZ?KT]C;C)(##7_>8=:@!?LM&$BXCE'
MCH?W!KSOU]?PY66SFK9"Q&]?"W[AXO'%>VU-&[56X^Z5EA-P'A(P@PBS1HW?
M&1I@*O_`D"*#BZ!MY_ZIG.N)5G)/BT^>5M"\3%ARRV3IIJ_)SVL=7*W5>&B)
M>AG>(*WE=M7V.975:*H.MFMB?'%'Y#3,!!B$[(GZT#=R$0W6P^BBS5D>EIVU
MU@/0C@"A@UW34,84(`7Q>Z.U2_.,]#/DZ?_$%`[JAKGVH5O=_D04;X#D`#,<
M)AV92<+93H;8#8"9CBFU$QU<XQZ_2BL8SLR7A.AR!A/B]4"]F8'DLEZOUWK4
MET-L6IVIW;)IS*->KZI<*VDJBX'C^`Q]/WHSTNO!:--BX)G1:(8POI"HI.";
M*06YBH[/C'%"-.BOEU*,%%G0[ST"U,_/SZFASK@Y#E85W>^DEWKXSC_[3,26
M/#@3!H9*W!'H-:OV7`<:(8AJBBA76R!)^?'SIZSKZH*6(U/E,WUT?R9TB=;2
MI@;!I%/KL3TP[Y*&?R*@O9`@F];F\@H0_X+^U%W4RVN`WI?RS8]N5UM)*Q>C
M%J1)`</7[YZPO>"Y9?+E6%Y\P$Q&)FE<`C)(SMR4ZZ);2?](W;8IO`OSS#6/
MY,#8/3\M9^0,&/3?[4`9\F*0G&^/K(F5/<MKBSF-"V@;F]+/S0<T%Z+_6F9#
M2YOIOD3==6ZDCAB9OIP5C-6`'02ULSEMKCQ9MD``</HKL^;'JUTF"[-'XY2R
M'6TE"4'DD^%:"%6N<&'^8(Q7@QWM+!B,.'T`RGRS@P%#E.?'-Y%#YJ[5+MKZ
M>":I:!S@9I.?/W^([26@#89%-5"9FTT:'+W?BQK0?E_N=[V[FV]>.C,FR+-G
M,)_-LV1*%FVJDJF8U8,=9]W810ZF,['-;K_[\_/3!<TV$/02?:%GY*AM:*`7
M#0PG&UQ6)J&'S];W#RT^&YS;=64;&XLLCT=RIC$T<[Y>GWM@Y<4J>IT]4I$=
MIMRNNLV@4#'1?H8^5_!F>-^O+V#+VT#2=E/^CH<M>0UV(;&#]/:]3@1-.VLP
M\0"_9,>I(^OQ[VMAF\G[88*6+A\3`WMHFD(N',:R]VU_;]T:DXY)31JB%,.B
M-WK,GDG"'0;FO4OMX'"<&@P_,@*;SBR!'O1.)"F9U.KJND/*!=C%"?#!E#6\
M7ACJ78NU2T5/SS9)J&HRFO%>O7^=&(OJ6FE4$;0A!K.YK<=4O"`"H\138ZO#
M[SD#!LG3DKH\MJ?5+RQWT26VD"YQ"':<09>&#RL!P:##;V`PP98W&E!-7SHK
MXQM<CZ\\EH=\/#],.E[7>>J4.I2<F7!OEOK[[[\E-U!A`B5YU$5C$D1[L1<*
M^OV.=#-$R\)9H;H!]K.@L,V'EGFK>\D.H[S<:(RS&FJ8%`,#GC-L5?].DC(!
M<MJ5,%^[*O%>J]2Z'>NOQCI@,_\@F9"-32^I^2M.:8)VBC&5^*#=K<BX7T)L
MTZ"JO7XV50;)^R+::UU7>;U6$X#;3,"8&]8>]%AS+AME3O?;+DMV3WHSO&]V
M]PN_?*=VUX,2Y+(V<L-LXL:EX@20_1;PGW7^G@[.C'W@#8Y*`IMV'Q9?T8*\
M'D#>8]/;JS6K=0FQB8.4IVZ,[)>3@V*J.6</TT8!9Z"^44J!X8ZGVV#R#K"<
M,;%*Y6=\)S#B,WOG$PD,R=/`X91+FF/2.D(%;HH1[H<`E%IW18U2BM2ZI>H)
M9[HL(<TY6V@ZL]%8,3(Z`B=ITP9T8Y<[%4.+='6U@6F2:U;R*B\0!.,%%:6#
M"M&2==&0@DWBJ6H]9D2EMR`9QI-TP[CR=MW%S6,`\OW[]U`G;0**@TW5]?P0
MD<_U)7__^%LUA,$"*I&TQ7._3\98F_:7H<4ZJ,LLG!O:\:SHF.#PG.!E^B)X
MG8V#GW!P:W$0SG4?8T8Z<<C^V9Q'#\(H\GP^]H8L#2)MW==NI-)Z%(XULG^K
MFM(,7^BM@^P"41;6*E`S%M_J^@[&OJA]=0B$8$HVS#.&1]"#LJM13&SMVW77
M6N7U>EG`K$@%\TS@^GD#`7*L"M^CR$1Q"!*:F_5<?@/>-]C]16#U.P#L)JY"
M)AMT#1B_4CT,S#GAH+6)H8MI:SR9@"`G_IU6(>!@.RP0,`>!)+;,3I#1-V5=
M/@TT2]%R_KB<C("IFU6USIE\5^B,3ETK\ED!Y_ADG^=@VO(FNNLGWU+;!3B<
M?T;S!Y2*@&=B0)Y.-'N]%U(5'FF(U2"&Y&4K^BL+($LI0YXLTPPE9"G']3R>
M.]MDR%P&:E,+P9=)EB%.$X^:>)IQ,+7"Y,%0L_];,U8(`8#Z**/$OP/FY4'!
M)Z3T^N7(!+<YVE4#&-4(='F3:7XB#\`6V>&^7ZER'+C\_%2C]?A&$:3D`D7D
MV[=OLBAW0;]((!%%@'O3T(\?/\:OU:A;:TJ."$'!R)HDRBJ.<[,F/6+5+8"\
M9`@Z.#(X&N9WJ1HP$;)H8AATB-4)GD%BA/]V6LV]IS">5FV.-`U:L_.H_9XB
MLG5WL>,3PC)1IB\B08Y-Z*RNZ3(SM"4*K`>0!M5UT-3DVJTB[Q#L]>]JK![/
M0WI-EW7$HT)>GZ\@^];?C4[A@UDWS)$C@":!;(P%G`.*'CRJ=WP#WO?K"[3G
M-::Z:[+`F]__,B']"_3NK/@^=-NVFLE4DQ>N5`Z>Y_8JV`G0L_?@$LQ=DDHD
M+GAH-NE$YW@P+$6R/2_U1G`;<&OR,MJ:J@YOCN_V@ZNQ`]6#>Q,LV"I1)**<
M1MOT,%68%'=.V8RZ;3OSJ=V/#G"KK[T`0L_X0X*8/E2$QBS!H47F$ZH40%ZX
M%@(ER'+H?IYI?S:VLAU2C_K8N_,=RT(=0*D#B9-K"!WDN%@38;U1GZSR6!Y&
M.@W=JM40H&JNVP>LB;*"(BA%J(3]M9K"OHXXRD`4Z-*9@$Q'^I@,^U>#CJM:
MQ1A&VU.FWNF_3A5(C]];ED4^GA]YW3WFT?ZZKO+SQP\+/G3)@U=344UKF0E$
MR.+,-]8!/NL8;_^^0D[815?^Y-(27DHRL[G.SAH=3GN#AK!%0ZR4EJJQW==4
MFY=1R+P>"C"U-M19=WQG)/L8]H;,(=!*?MG]Q%CL8A@[M+*UFA@T9``3+A"G
MV'E;"N3Q>'1SBEEQWFM=9=W6E`3!T4@9IFMR^,VRP,S&I*U+(S$7!_(->-_L
M[GUV]P;8#1;T^'7V=0ZRLW3WOZ%9SA_2+I6^;?5@2F$B9].4(),=]<+=K+&_
M]`+PF".AF0J$5[99ED4P`4FXD"(3B-0M41M(6*RL8Q?8P=>R++L>)9W@/0;$
M()&"\@:&=(/;3-:*-Z:SU@=N8)R`'+4`.[A<EET*S#79`8FF<;,%-?)-^B#2
MM7H3FL*AY"QXF(%=)`V"K6'#!'$B!G#X>8O$S<H@JVE.U*:_HYYIK)_)ZK0S
MMMZSKU:*#ITI?SX>\O/0.K7?M2+UNI%M6D?M&XFH'',[$XC)?LM@9&`:N[PH
ME],_[5\ND&_?OSL+[_.YC2.`^/'CA]6OUB5`$FV8R6B88ILL[]6GZ<;8G2U.
MRIZN[J$@&&*T]Z*;#QK\95T90#DD^]"#Y$JK#>Q+0PM<@AS6B*/29D%\X%)9
MI6IVE<H8Q30BSL`NPEC99C^K7]PI?=F!+E2YAETI%WLE76,8=LOO=FY,^VQK
ME<_/EWH^68"$PY4O=_8+WC.(@7?>5*_MO>.TK.2[:>V?#7;Q)8#(&\PNDX4C
M_!))?/&A`S52\A[X/U+#*U%-H-8JV[;)MFZRKJM)ZP.6U?C2/:4R87/+WD9U
MW3L%-7T``"``241!5)(M=!_#WQF@?AA7=XDSJ9VX>>]`;3D`:K%BYNU_+;AH
M;!LLL]E^IM64[1:K)=[K58"F`*T%@4T?<H"+I2P1%%TY'=-%?E!I5(C3K8TJ
MI0;\BZW9+;V4X?YZ;V/?YFA!Z6.MLP2^+GCHI=[Q7_2'<GP>0ZYJZ/[6K0HK
MT[2Y3)A64U7IXH;'\W$T6MD,B&$?$TO>J_TSTUC-9;QR0.$EJWS-:&@:.K[^
M[>-#GH]'7C\-R><D1-:Z"GO#EW:':P6?#,URHFR/ZY&YJ3V[I=Z\9Y[$Z!M+
M8I;7:H"GSU;-.^.XR%BNT.9B:;K.IK;7USRK]4<%D:F89=4<91I>84LOAG;P
M:+2J=1N-5MF>+N+TT;4<&U46`U:JP<\QW;RI%A-I517T0X".SFCWE_#C8AO]
MZ(,PB#P?S_G><OQ9MVV<#R+.K`8Y*/"$RQWG^!LLC?5CV\^+-\/[SX;"7V0Y
MS[T/OF"&=OVS@0J^\F3S<__W=(`U^U7KKM4Z4BU98\]1CTL([_2-7=K[YN!B
M)KM&D9N[Q.ZPM"P'TQO,V;5;U.0^F!4<,&<,IYN:`H#%LE;0!<RJD4C?6Y<@
MHP)RAAF[5\\,9U4*XT,_F*1U6U.WIYE,G7&4HO:Z1*\%SQX71&%=8J+VC``H
M[RZCQV.1K3YVO=YM4\]2Q-01ZZ>JI'WNK?@(""T.@&'K!PBFF8I5ZFC"@Y4R
M\_N1;;[;V;QOW[\?B@02TN*S]+?_7DB_)P%%5@>;RQ@P`=W._E5ZOU$_JI\?
M3_GX]BUI-(R]C70+=ULW9Q*27#^.QL!*7U9NL92R9X:VJE7K-?8J4+3&K$_9
M%.6^=:54$G"-?H:T6;ZV^L#$VEPQK8/1QEYV88PIK,D[7/`%$>%AB1WKJ%69
M&DT/FV%UQUKCY#P8GUH"U:GJH%-*7ET)HO-AQJV88$,U8SZ7AY1B`W/?9DQ2
MUJ-1S30KN_(7U^MH]CWM,)<>9\@(H.0LI&;V1YW^F^']Q[*[5^F!K^)AW,;0
MO/MV4Z<&_"D,?WG;1B#KU);UAA=O=I.NKHIN\TH;D0+#=6,,='H<.S,Q&&I.
MK]_:U5IS""^59FK`-%L#*^4$Y7&O&=O^/9@CX'B?HAB@TO\N92\W*`7IH7A[
MYKKT7;-LA:Y#A`=T[59AF-(.TK7\6^A$D;S<!]:T`+$M/FU0NUB59CY]^_9-
MOG_[+BC[^`'J<]4S[UK':>WY'9:W2+<RE9B:]JSO:WT-)M!R5,(,#Z2II/'%
M95GD7__Z:W^6P`TVFBKEFCM,<69"($C,4N!2*W&Y,?W\T9KY>#ZZ*H,=KS@&
M3-(WM5;K$"<1?.@!UK)QHJ3G=#-89T6-0UTTAMG71YGNX6W>[7,0*8NN&S*_
M)-V'>3X";EV54NS7M*I,K78>T.H;FY(6'Y1/,ZB(\9`O=YFDJG3ICUZGH_'2
M/5.G,7]U+NEZ[B')IYOS1#EC6NB]._?1SGGF&1E2HDLDU9PS3I/S`]J:X,3J
M09.U>S.\[]=7TN+DC7<Y(7[XE>LY<;[X,QYNUP`A2F;RA$5SF]M%T]'OU'DD
MK4X9!6>`7)<%@@:]-:3%8X,`,\S<RRJ@U122<HY1JDC+[BI&53?]:`FQ#K9Z
M`T8[)(MQ:-+E#!J$:K'XU&&K?;ZI5155+A`]Y$6BQ6I>5ZG9HTFB(GET].SS
M"4#[4AK&V:G*`3(J:>D6#TI-NM@W-L6<33_OJJ5I6.GJV!$P-*O(Y^=+OG\O
M*5O:I<DP#D8ZML=;9I2R@]YMW63=MKTD:=OV>]<ZTLQ6U[Q,!XY):@'@Z"OE
MJ#/7UT7GX*B8:_V\FZ'!]V]_J4`SS]Y"9"(UIQ0C:&MJ>9JMT@$*5;.J&(8W
M5)\H^;@1+%&5%<2=[-OW;\IJFGWM-B.2%G@.G>;:2\NJTP&_!'(>!#OYQ&"B
M(%:>,LL.5`V"DXE278,SPS[-(SNH*6!7@]^:L&!UG[-YK\TG=/:*024$H\;7
MHO3N2-CN<7DLW38YGRM[\^_KM;K`)RKS<#:1$^,?G:VCG%@NTZI#!I)<`?XW
MX/V'L[N_SY+F-KJ_])8\*YN8R1PE_;7X,ZCX+@Z=BVPA;[Y1@%$'M1I,[)JI
M]12TQ53Q@*@@'*#<2RZ:'FO[I?W]BX^%X[,-47:F-(O.=EC-Q<$9-39E$$1>
MY6"`7=_5/IB>\55MY:HWVG!0F0-II%"7`]ANZ]J9Z99&U]=62NF.;G2!`]1X
M[JR:EAJ+P8)WBLM@%I#+9@2PZQ?,;,W[-'8=:@@-.)CFG>"`EP%;UVW(DPP'
MHM)&?W)%S^,J=:,L!1(V%FJGO;BQT!@9V,]]/)[R>#RD5I&M;L)*^?GCA[$T
M-@U0//'5%DG9:K%)@D,36*FK>+OJX,PV[NWCXV-G=H'SQTOK)I6UM.^/E^.Y
MF_&BI!H)T,8B]NOL:@#'G.G!#`Z[V#ID_I"5>`WA059*69:^;W2YKT4%O0?$
M*TL9+*?JJ:C:6IO>;6$V7VUCX#XNRC71!1]-`<&OO[VIK<Q[!JH<96Z44.JC
MN'1='F+K:_=2B[1>A"[#H.84'#E,M?ZJ"Y)H%WI?0^WGEO*0K$]1_\?/SY?4
MC;G+YHB6`@F`Y.>ARF.R[FYM-]TUJVMV=7#W]P:\;W;W3[[#K%GJ"V_%&Y2S
M%91)*ASY)\?GIM5;DJYB$'^'82RVWD4>6<<&#+<&>I46"P.%S(2/C<>+H'0/
M=.UL)5FSC2D,U!E_Q0RZ0&773VV;#$0W/T`XRA$$>V,#E0H%V3?EWDPE5CYH
M$`7SNH!@%C)A:3O;4XK@T*VDZO)ES?%B`]R:22ZE=%W6W>*X=F"A1>)U\-/!
M[I0VB1)K^LNVUO#7@N&]?G)O7B-SH$IZER-<LHIQ[N418BRWWP.7;:OR_+"]
MG`;(>F<[]WQ9[4D^F,C#J:P\A*"LCX?4SSHT3K5,&Q,1:L`ZAGNC!$8Y17K:
M7JRF+<S-[>?V8UGDV\>W$!!.PVM%TNN:\GH`)=83J]G</<3)[%`QL#80&>8>
M#'-%9&=J@X/<@>%*V;OUK8-?&Q^UPS<-6ZU:P[UM[;$L(LL>*&W;)C]__DR#
MZ8;@(B,M1C^0'%]'J@^(PXY>CC*J(JS1YK>-U;;M2@ZL8N74V-1!*,D4L4&)
M,72YU+6P.K?)B::]6`A)FRV[@UTI(E*DUNR$V7>#K5)>GUL/8`26@!"?14J*
M3:)`'$R0A2G1!%?6S%.BZPUX_VO9W7\W"AXR2W\"06>%[/,IGK8)]2O:-Z/R
M6]<B2K2>">-EF"I.2@1=P2UQ,*I'.AG5GO>IS_OTG(.1>&J;L-DHFU'&P<8N
MQ\&TZT/6WH$M4F)C#7""ZF$:,$S])T;JSCNI+<NRLS2P=K363\`Z;\4&H7*H
M,R`\L*XFH(17.T!C,G9^:(_/VM9M``G]*&D9IZ$6<0!>H51H75<QQ9;6:R$'
M,O2UGVKXM;A]R<#NS"T/\7NE%'D\G[*N:T_Q:U1->IU26TXTV+$$"$UTA)%X
MIIK@08Z`J`QW)<#O:3#[#C*6V[!!R"M*,.K&!XJ=.MV,H.QBJV-B0VL"84J7
MPAKUS>.SEU+D^U__<K6O-T@%-[\KJVQ;#=W^L\R?Y>IM(1-Z^CO^/H4]9=S7
M72M)P.[U%0UZ]OO>?Z1(U,11:\$P_'`-8?M]M@S24A[R[4'Y\?FIE$!RG`A/
MTQ^N>3PH<R@VNQDW:$>V9CO]7)YRN':'D6SJ(U*I5"KHRLMB+7IW>%-@KJM?
M$DFJH<T?6&89+B!*YFX`V$;K^@B*JXI'&7-_K]<JVZ8S0[0F+*&Z5HRCX"A[
M$2=2[*9\V,>H]H^XZ0`TL8+@#7C_RU]GN7W>D;B]`(;W&-[3M[R1C8U+$S+3
M>R![T_]O!`LVA9HRT8:QF2'A>`O;MHE46&M&EX.=EJ(P1MCYV'$<*NJ(WK:]
MCE'_3"F9<;L$UE1_>["L5<GLC)HVV_`S-LMU6^5C^1C`,:V/QL&,)#5Z@*!6
MJ:4<I0@[*$"9B0<CG;,F=2U(K&[C&&]U4])``Z"T.L4JA\R94A(Y4P'PC+2U
MFY\P]0<>*R@]4Y#6BI^+)_37WNQ7Y/7ZW)5(:E6'12BR,`PHM*XGQKBB#$81
M!4YVRYL8M#*7HRY;1,K2).N8WK^8NE(+RON)[24"F?.8S^?'WBSW6H?-:ZRZ
M->OB;IE8+ZL1J_DKR-?J;IBQVP8O)?CU1;;X+-'$G>7FM@D.!G_E9LQ.T@I*
M:IOD@X$\P$(1:]ZA%0)BQJ=]CV(UF0<GUU4>C.-:)_3N&1BU@![L@+8\'H(#
M\"+C$]5>HFV8"\K8&]H-*XM>'.QEZT$`]D:N95E$J`,"[YYI`_]>'RW#[6X$
M9_HH*&/I5=KUYC9\ZVJGRC)HC8BLTWO\7#-6V%4A'H_G"'=K`IQ)6==U:'B'
MK(J>XG1XO%T?HD%3H$`B4A]UY,,4JJ@2&M_H"GDWK?T#V%U<G'X7#.VT%M9+
M4?TF)I=[];L:M#`Y[?>:P-\4'U%BZ;+*[9H,LC50[8`M7*MB,JL_H#RP]0PG
M<S%U$I*'PG8R,&GR";_O`-F9D0.]X:^2$/--"YK@V;:MN_7TD@?CTK8#K^J[
MH_6.7:L0D&79K8%1=``1ZZ8-?$EJ"C4;-`/[1F;,Q32L5:5?>1KDT=47Z@,0
MD]_WY.G.DKMZ]9G;5@*(?;WXLCQ$9)^OIF[<R6WY6O+BQIH'<*B(I3P-Z!6Q
MS8T-))16QG,H1T0+V'@B-BG`G<7-53!FV9<VCLOW[R+\6]:5_?`]4%QPV^-Q
MSP,PT0;^"DB4!G*A[;(/4-8"`5@WNK_^^MX;,$V0Z4"I;2K,=O.CIO5(\Y/U
MP&^P%;L4(WU5E.JCJW;MV"^KP\ZD$F'`ARM"ZXP^I=9-'ER.)!/FV0"_-]/.
M+]VICU(Z0-51AF^L[9]7E+8N%,L/YX;8RK90Y./C*<_GAY41[!=?1KNB,B71
M#:"6_1QE8Z9VN$<4TOTDF/C4(+'2[-K>'%I<;=H5.%,01&)#L*\/*$,?PGJ'
M0CF/1F,<CM(0N#IU:(9]OR#,TJPN\0(S1SFR7H!Z%KXS8LSY-^#][X>_IX`7
MOBSA#M:5^Q;"1M1^%KGC?DT@KSX?^`,C1BEMES`6F!/BEN,@PU$/:8"?HYBN
M^NDHAQ"_G-MWZE3S+^<`0OF"W)/_83;F[)M?33R&B1WP+LLC=`Y3Y9[6=;UD
MSXIB>%^OESR?SPYZI\V"DH'=:A!C*SEIM<YUJ[VQJ:CT[-`BM2+M]QC`*"[7
M:_IF"T!)LCT>CSSID4TNI/*OYCD^'H]1RUW02V-PI$\KQ4C)V8-D@)I2M'4T
M)"L'EV88H(,)+3UU,-A%8EUDP/!@>C^!F.7Y_/_^_;O\^/'W$6A9L$ZJXBU'
MHUHGQ!@`XF3Q0&E/2X%\__9=GL^'$\N/>]U0()&C],/'-[O.]N?GSYUYHQTC
M:,OSCN7L.QC5$?@&(-<\[*I`4,34$NN:4%,VH4ITEJ/,*:P.GO`T"J11ZW&A
M`7<(%>]!Y$R_3Q_TS$%!R,``19;';N_<UZ!8DH'B:DO].`G24YBV9-7T3+2Y
M;G8TJ/LZ?@F4J*ON>C\[Z%4H79?AZ//@\7@<9YINIX,94]!:<4/;VT,9>*B`
MT)1$319HRPY19:)-5K2,,I7@<@A(R?S<WR4-_S20:ZJHY(Z,@:W%R8]L.6MH
MIHW([K#2,>5W0;*2LWSAKX]<M,N:OKUN4O/LY/21T'G/AK%E*@OG.]!;"0!9
MC432C"'Q7^VI\3OCPAT@6K,%KS;!*(ZN)@,IW8ZYU^`-Q-<[VH,RA=?-+*73
M&W7=Y"41]-X#_$5$:I<Z0X$\EL>0Y"F+E*T,6V&,C7M9EKTV>FG`>S5-@+'^
M6*Z#M$0^2$2#@V5TLX,G\U8#&&<N(=$&%[)+>*'N%9O2._&/WZ1NA.;AO/2Q
MRWS5;:_%Q``Y4(>/WVL*,#K%13MIL2MGF.8\4Q,(>_V0:YM%S(J;#]9G*?+]
M^W?Y^>.'"#?1G&2K2"Q8#DU;Q5926YCB:`#*8FZ8N]4*'R(BW[Y]DV\?SVF@
M"0^>-+LG%E2LGZO\^/OOHSR%6>F_))+2(N)*30Z&L_02*]7VIZAF:!9?)-2+
MH@Q4!LU(=B:N2BD^W3[)<'"V[PYB8K0@T.P_(4,CWH3$DT!*->*X\&_?6U""
M24V(+KLYV%6I]FLF@Z8)%EOV(F%W+<G:I0H,)M>D:GV'AXN53"PN&&[/Y^.Y
M2"GF1`KY5,JNJ%(K.]/?M8E%[^=B2L!*@?%S@Y--M+<T5F*J]()\Z3,I*WL#
MWO\FF'OB'I0#NY'ZN`**3B7ODE<T[`1G*'K.EMZ#[S-@QE]G>GGRWYP8I"E,
MMFW;G0>E-!4SYAR]CDW;L`:&DB++8P=_];,:L-OU!QLPY&C.:</_4`!1KIY#
M/[/GU%5(\0:6$9W]*26#^1+E8!/V^?%X].MNAW$;]X_GASV`;\S6Q^-Q&B2T
M9CM6)_K>##8:D/M6Y,>/G[V..1N;-.8Q@AA9E_(8D:UN\J@/5[<,Y08%"Q0(
M![EB[AD\I-A`X0%ZR3TE7%5#23D.L[(L\G@\I91#/N^S.I,-Q4PEG]FT?_7?
M.%A[>YXAW]-F$I[MLP^*>F><17)5#WM\/Y:'+/_ZE[S6=7>@.THL=OOIO6;\
MQ\\?>_:A!7;*^E8'%VG`I=8.5/WWQ[</^?[MVR7W@`S#NR]NVR9__QA@-\/X
M64-=/#,<`$3R'"Z>26:LP-J8NT/GM<3R`FT%;/5[D3NX2716+`52ZP@L>AH=
MKG2HFT:X0PE*51U#7>;Y7'ISJ@%>?LD>[U=9C_DCXANWC.-;8S2K37%Z-\<"
MU3J:"[G8E*D']S[[H7].D2?H>]YB<CFFCEN3K;U\QWX>7:-N>Z<]P!ELNGE^
M\(0<[&[BHF0?R^J@R?['<>:]8>)_'^C]"N\[L_H]<S2Z4[=[UJ26JZO$^)$2
M4ZAW^.C:TZI?P[F]THI6*<`#L5.2[BLF$N3I<Y$;M=@M]C<VJ^)M,5W:4426
MQ^-@TC"]G\Q>N#%PVV0"G3';5CX*4Q>QG,(9;U5K[9LQ#]4)''73G_(I'Q\?
MDWF89S5F8-?+B*%8;4[/#&GW(/N(/<.8E'*T'*'W=84%BJ52/C\_=\%^L369
MN>;IC2F)75Q>/Z=M7663*JA'G3=&L]RRE/[96ZV#R3E`G68$3^-H5Q[";9/'
M\W$$>NA=UEH'V`R7UXWFWERXK:L`D.?S>6,$M`L5Y/%\BO3?:]:E^S/]_OV[
M?'Z^!("\7I][D`4=N6N9*8;&OYZU..;,Q_=O\O'Q(42^%6:.Q*GJTK%6?WY^
M[LH,)W/?ZP`SQ4I(Z53*]=R:J15H$"0'P*,@]._O^PY4()C0=TJB,4/8^E$T
MMI$NX(*BD>U>A_1$ZB54D,E>$4MKUO4U1$#@<S9><[L5N#,?[R,K$L%NENFQ
M/],_PUM/M]IEN'HH[';6,#7?*N-65"UV@90%LE6M9'?\7L'<F5!UQX7*@\3H
MQIP`NFX;L(H/L%.&L&/^!KS_1:^@0?JE7[X&=1>XX38C.Y,5FYGF>C&3Z;7P
M'OM\=MWMK-YK:`/\.#V[<0/LFO=!8D>*KXUH<TMCM)<1.71_UVU3AI1C`[^>
M3Y,#$46Y*LF07#-T;EX&8YXO)GJZP#0HX-$5+`=#7;6&[M$4]_I\R?/CJ9C/
MDVK*IO<S^9$6/#E1+JL1BO$LAEUS%GPRU@"K>P\2?V!OSNGR1(=^\^?G2SZ>
MS^/Z\H?%N^LY>?#+\[DWI0R/V!Y@\,#F=:N['?!Q!][&-BY7?0JSR[8U)GI9
MBE1"N.TL$-RX<%+>I,?MY^M3MG5OC%PNU@_MY>02MZI<"BCR\>W;_NR617[\
M^"';MKJF6Q5B>C.8?J"7GAZ70PLY3QW-ZEG=Q1[`[O/UVE59Z+-)SE3#2>,8
MP,V=BC7*$FZ\)`O?&%"<4LB`6\,BY9``>ZVK_/Q\R<?'\T1N%F$?`!%8E&YI
M+,>84J?\79!Y;/1`L9UW31^Y0`%A"&N5C76OXP_9)]KQH<BZ;?+C]3KDQ""C
MXHRN3UPQN]T$B&G?J5:>,.YB')</8\`SKK,%XX"N3U>6%6H.@]RSAM1*]'ES
M^\[:+U+YLAG=!O1Y$F\B6J=3/5OX#*%+!$(%3",8]O/<[B%OP/L/87?O<9M?
M!\=?!;OG/X.4Y;W]86IA?*6\(QO#ZK0CKS3^[S"\S`#=E,0]28&K7R`IZVN=
M7A1*$;3Z4W>?-#5EF%>!N$UKUY[=#Y7`LMGSR47IJIX3DT%T=6[,6'!`MEIE
M21`=N<N?82WR/$H5SD,53%E>:#>WUHC5QAT7[)EF+ID#?%(3-'2RZ\C!R+$>
MUM=KEV:;!BYWHU(.1R<WR9KBR5XB$-'TY^O5W<1V6;83=E]4K>2D-KW54^_.
M5;]FETB*U(VR8I-''<$*W#,)`0%G[E,RBI=5VKV4(M^^?9>__^=_NJ:T-D5H
M?YD&.,%N*O'MFRR/QS!(F*74=`I>XKK7L&!=-ZG;40=O7*T4J]G>LR9VTN.=
M#7B+Y@VC6XXZ>)%#VLM%@<-2V:J*]"&M>^W[XV#5.66GQ:G<,!;ZDH?1Q0'6
M="9@`KRT33*J`HK5SI/=5(8B6@WPI/[N]5JE;@QR;=&Q\-@5ZU"@:8RO5?))
M3L*J(P0)5M_],:CY`*U(XZW1L9MH+,NB2D(NSNZC>[(>@5+_]-I&GL.,**N3
M2TPE*/8\:O)MU>RC$]F^0&]8`Z4WX/V'@-UKD'D?'O\R,WP!"&]]7W(FA&X1
M_@[@#5JWO&:-4S.9F>+;58VQ+5\:K*(W0.I:BXZ_Q;TG2^47GUT6YW%(>H-:
MFLPWFOBN;9^5,)WA,X%_-<9H_P.4UO"@/K9U/6I,E\NLR.D4PP!RWN5M.-8=
M'$C7#6Z/#THOTI?'#"!`29K/]($.E[TXOK:NJSP_GL:X833685ATAMRU+3A$
MEZQ+@JQ:(U,INXM7/=+GE4G4(?E]V7W*SJ%=X425M?!^/P(ZJ-NMDNMGE?^S
M_A_Y]O$AS^>S`^[:%3Z0!DL&;WH=E*Z)?SBV+8O\ZZ]_R8\?/V3=UG$`N^AX
M#Q`7>7X\Y7FH?YC:7[=TZ32_"*N!O/]H,0!A?:T[,*L#)'ARLQHDJT.ZF$EK
M.J[BY?VTZV/_G,.PA=7H_%:EE9K0E?T]MFT@X#/AD9E.-0X&EMK:NSK#(')Z
MY'59+=I,7U%-93C,-,H-&T]29'MM^W600RNVGU757$9-V.?2-6:S/(9N/%.@
ML._]=*`X/Z,U*0&,_>+Y6)Q#7IBF)I!H@=M6L\/X:'ZMV=Y+6])@B(=JYYV,
M3!PY=YV#L<B1D9WAF^']YX#A._B27W@?WJ=T=;'Y`#V3]Z9<.V$H,,B)9-$T
M^OXRV+W"W]'G.S.=^*)YW509XUZH0EM0EMP390=+30\7"?',+\0>8@V+)/IR
M:0FI8ALH#',&QX:X:U#`NSFVY5K![/),'Q_+;ZV=WGU?Z\ZF(I\7H-J(+>ED
M!/]%(H68920&X.!T36S;)D\^S2*V_3>(ZN_)>@E?HW(H,D!K'!P!'9A@\VS6
M)[IIK9FR5L'R,,%,`T99':B_[A\__I:Z;E*.#`"W3?[^^V_Y^?.G/)_/KDA2
MC\:[$'R)[Z"'^SJ,B+W(SH;]]==?.^A==]`K=<SU95GDX^.CJVN<98LZ0^[9
M]A:8FGFR@_=:J[Q>+_G\?(V@J*D5]-(;G`;`<`&<\EL8G?/].NR<!"?>)RZX
MHW%`Q-%#NW_6XZ,DSG[9/L?)=J>!%V5[O8X&4W'*,<=P5JV04*VC&;7*B`+U
MAQ&#\/J`?'U^RNNU6@%R2M!)U\",3G>V,]1=>-8*)#<0/=8#5!.<LRV?U=H9
M645VF_1E60Z[9)614>4=0S^<O52BUC;^>=EA$-MI?=1*]X3&D%Y2J)]*$*I.
MNB";=TS2]OEOP/M?R>Y&C^Y?A\3W?V[>_,9I?>$O(!#+MIQ<V1G+F]4%Z_I+
M?]GSNN/Y4?[5X0P;_:0.EKK#0^1$\8)[_6["JK1:6-/@Q3GHS63HO&N9EY,A
M+7_4I+R,`U>V"<N0J0J`[-!K;3J84/:T(7@Y`(&N5\9-Y;H,8V;SJ5<)%RCK
M7R84>7*P)>N7)TR4.0*XIS\_/S_EV\?'*"SQ];R]9`)&Q6$\.SO"PP2$W1'/
MCVE[%12I5*HD]42.1;,OW<1"*5X(9'VM\G@\C4R9]$,\KEUXYMC9@+?G56N5
MGS]_[M=<=AWC!]FUEK.,0RRI0+B'=O6E+/*O?_U_NT3;H7U;ED4>34+.,V6M
MKO.HE4V+-Y@[:NF`I-8J__,__R/;NJF]S-9P=K*LZ^/2BJW`";52A:O5\XO#
M1$,'(`9@!<]N*,"D>C.._6M_'L]@7L";:Y,FV.3AT&B-9`PC[8Q\FFXZCE*/
MEI6A"K:Z'*!2R8',,XR?GZ]#<M&Y9](^6R8!1V-L*NH(>/5/.I.<K">`7GJ.
M3$7%A-Z,YZ@UKK'LIU]O96")Z_$[$ES67)D8$,N>Q-;;5M>_8QH^?0;&E=E1
MU8"$!MYC?K\![W\=V'431<ZL)[YJ6Z#$'^_T6DV(1][HBKM;U9"5SMXI90BI
MHMZ@<Q>U)C_H>U4N?C,V`K!W*%.5"#0W*7'GB,C1[4R=O[)`F*SC[1'+#1K3
MVX!C?JTP!]Z>&J[F($3SH.^-.U&::%D>^V<Y9Z2NHG\`DEIKEZPRGO='VO[Y
M?/:-=`>S".-)BE36`'CO!EJZL1##:U2<_ZER=FKZP.B;/[,,1L8FBDN_)JSO
MK!1@6U?9#@DA/7]TRGXX$B'):,2N:#(!D^YO!E4.)+0QC"VT7AQ#>'Z@DE8;
M?E[N,W>R6Y9B3$L\&SPLJRF?GR]Y/!9Y/I][T$<-ZI)FQ[ZVK?N3OHC'`7)O
M[=?>Q<VQY#D#KS6OJZRO=0>[70.5;IX-\7Z=4AZ@$B;[D&7_8\8*\^OV\UP5
M1VM651L>[&M9@?(;*],$GMWM:_]>K=P_2P-_B\+&OJ7=\F+$O*_ZL@<LSX\/
M\<USPT%MO-9U35TB24[CW7QP0```(`!)1$%46&HFN<^MDAR:#$!?%"O?U5$F
M)7C=N8TVTX#9F>F;.KWZSV%A_?GS\]#A97`%9,+0,\D."&)`;LOD1#'+,JRA
MW;F9J@4I(N<->/\[8;"X(M`3L,N);>U]^NNRO20&M^D;\<YG8IK9<IOPM;6&
M9BP;*X"`93D=P3OL0P:0D?B\9B,Q0"Y.I%H@2]D/\IB>1BC:LB!@9T10BBQE
MZ;M4U4R,0%G_3)APW2!!)X?6?>>?1^-!->!K_,H!ZH]#\/5Z!3!5#EF@IKF[
M+,N1@MN-(;+T`EEOQ7#3-<*Q\<+74JNWT,+J66`R`IEX`#)AG^FR%'"ZP_KP
M;TH5C?UF0D,Q2S,J:^.T`U0[_:G/9[A!NN!(U7("5F4!D37N9@=)JH$I0(A?
MV[9M3^NKL>WC$CYK__[K]9)UK;*^-OG^UU^NI.1DN?]"=BHC)O*T?;3),\U3
MM<I:-UE?+_G\_!RI>SEJ5Q/@DJKW>%<N78W%3!HJ0G`=]$17/=6T1F7PT.O,
M<?1HC<"9];!=/LD$:I,?$[A5NS?9U/8PN-$VU^+VN:X1[(B3Y\?'OC^:/=G=
M.]$!+RF)VD;IJ?7IN:1+=R@V,^<I"-]4R-SBFKZ)BWH]*"=%Q<8>TM/=O8VF
MR7C4W9*0GS]_CB"3?M\2,P>0U/5K/>(][F&NH>[KW'5YC=@L'^"O`>^2AG\&
MZ`WPRAX^7Y0MFM657J6A>'E2P%@(7J'(VV4:KO[/I"+I-3[%B/>GM9A7J'MF
MX.&<<'0ZF1,2RXBNFSH#^WMDE9I[S.P=N9YF390$UM<J&RPSMJAT[WJH/+0Z
M1`,NC12<TQN54<O((]W800?:(40#Y-9M9PH>RW(<@NKG:^V6R[76':RK&C9]
M$.JT_"F+RPA>QZU5Q<&XTHD&A!/#C.SY!RY(U<\-S=#Y81@9WO&U==V.YCR.
MFD1SX&CW*)D`%B1@V)5:D,[B'F;]MH.E-53Y-"J\(D9OKCN`N\SK<\^"25VR
MX,U!?!V.Y=GVSWN]7B("^?[7M]Q%ZWK[RH-PG:6PMF!BJ.[)FY#6#>RUO@XI
MM)JRQ+,41C9W+#BU_8%Y%H[A^UYO>K_6FC.Q09V%A_)!M==QE'L`MM'5!(JZ
M)\LY3.Y?8\HFP.\1WA#ET)0>O0'[P#R61SH>)`R8VN?2.ECM`RRR[=`<R2S=
MZ*G-';J*A2HMZJNWJ4GHPU@'%JK!N@-"^!(<6]OJZ]:H"VYUS;HS<&$[>PSY
MH4MI$$@0Z[IIX7CBVRE9H\Y(]L&PP+5&HP[OU@G@#7C_GX6S-U49,&,HOZJL
M$$*R_-NS_?>Z^>N+P%NN[2@:R#*ID`RV:M6#R3O"C.:-3EV9U6+"UB?V0T3+
MU*CJIUD#D'.6&NF@4?A/W60DE%R=A\HN6"D/O#[W!K/C4-G'<I6"(ENM!NSZ
MATU3LTG9MBK;N@5?U`'P#N."8X2W;>LLKG'OH@9>V%4"8%V$='D`,!&8.)G>
M/%EG7:/9@Q1B+BC@`36LK6?`P2=K2!+V9`](5JD_ML,-ZBG+8[%=YSPY<VS/
MM3I(:!@9.)#NKZ&#"=?N;NMMJ9AR]?W**(S/D]21RQ*UM+ZH6LSI7MD`1+.-
M.JBRU^M3GL]'KPU/`U8%9."R26$?="RUD2J`I`H41@T"(R.PKJO\_/ESV%M/
MTN7>>GS\&Y.O3^;7&?`E?75`R*R9\\74^KI1.E+BK,ZDH!$5(GW_,1F)PZ6M
MU23K:RG'GM7VPSVC9)WIIG0%7?5`K\O/K"9B-F!;-QMDTV:*H$N_Z,O%Q#2Y
M]6!-,_$Z<.YE`1Q&&NH4&+7F&EC;8`?JO!FZZICF4?Q^<`R1T5,03QCI=4QQ
M09^V/T?8,P'FQ(%JT.V@-YSL4=GD+4OV#^)Y?^=E!.!Y!;"3!GS>^8R3ZST!
MV1=1P=0=R'P6\@]B<@T:C/+4GTZ3&@XXI"D=#\(9-B<;OKCTFUAG.B0L/Y4I
M#]PV.#"_=LRJH5&M<@N&`"$RI[?[]&DI59]U,-;0]<]&58=J@X.#9Z(:<=!+
M#1H;,J[!:4V'-+H3QJ$XYOG_9^]=UQPYDEQ!,V=F27O>_U'W;*LR&8[]$>'N
M@)DYR2RINZ69K/EZ5)<D&8R+.PP&`URB2/E[I/AC8-O=6("$`H1A.8`D`N/H
M)NRJ5Q_>FL!A/S^ZW8[;&;PP6-^$K7USEZ^"[CC.Z?^.!23G(-;UJN-^B.7:
MF.1'.63&<@M0]*BG]E'5:7]4WT^=N@`Z2,=!_]WEOAD3ZA\?'PIX1>ZQ&#1Q
MK?#"<FWHD$.R("?1)3UU>$9&L?[Q\7%*%TB.U,E.,#)LH,I&B]B"A"@B@W&.
MYZ_7IR2YPE$DW;MM7I/I3`%Z-F$SM7``WO2>UPLZ8$<_EC:VKZ2VV^4H<'M[
M(^O`<Q#N+`YZ2)KDT3X+(E)R(2#7J]MU/PA;OZE([_?[LH.;W<5.MW?NA79T
M>=;'NA2]NU')&C@BF`?%TGI2W6N>4C"]]*1<C44WK,A[6^%,7NUE_`>X,-+9
M#,\U4GZHZ*H`RK#<5O+`"*!!@/@;\/X/9'<?HM^O1-^&AV2G9L6&I?@U</VU
M]\`O_EO%%H,`6-W1JT(Z0K*21Q&FDZ(A^]T*N'IZ7L,00\)97O'+"7"60;?2
MTO++(S%?4U`LE;:,0K&`+,=`F/!6VRS*D`_?UVG@"8Y-06$%;;4FI><@"2VX
M'C6N6*TZ'M*8[<1SATI,!.P^)[@1QR')TF>KX0T3ZGF3NV`9,D"-Y]9P`M&1
M-C;B=5$F*50;XCG0-=A$WGC/Z&:;[@,'@:WAA6JD-W9HF2=655[=A`L8OC+8
M.@?,>-(>87`3.X8\#\?=[W?[_/P\!RL;)\*A"`WIY<RJ1?:\6!R50#B3\_IQ
M7%(%G_?J&+!+VOFKP\%`OY[S\Y+!C8!(P95K]1T`@Z5^@&7ML^/2K)IX,OLU
MF`JRB>K6[7Y<SA:^6O#C_EL=.NA$_AUVN!L^/JRUF[V]W::_LI-O<26WFXQH
MZ$!033*_[_O[V\42MZ#)#QKB*^61V^ZC2](I<&*N`42?\R!61RA'>;`T@$(A
M2FG?`H4E54Y#Y\<7S^8U+`<;]KU(@'JL:<=QV!\__PC^XF%V1B*;P["FA\%<
M7\$59EF_SV"^VV-_)(\=-%_S)-^`]W_3KU\%NW\BP>TK0;_R_+X0T?NKH!^A
M<MV"=LM4<&$2I-\7^ZFZ5*G&O?X5G09O4"+*Y$72XP[[`+PFC"B62[IA@L@N
MI`%$8:J]/K'PX,])[+1U'J3!-/A/B4GQ"WG=MINZN2LD83!YWMK:?.D[+5T:
M+J>(GGP\YT1TUUQWCB7E@1CH6A\YEKPACS9MB,M.\:B3Q5MZV&CB]OEYGR!I
M#;[Y_/UPKW#'#&/Z^?%S!DKD3?W<J._W>[AG79PV9K3TIAUJ%!XB]XIS_*XE
MUE;/X;K.;V]OD]6;AW6UR2VD"4;0$UG3GS]_FK=FS=H)P#AM;S!;_;!^=.O]
MF*^]M6:WMS=[N[WMPV?0YV>?%F:G=&=(AG22OX4!Q=`VPP+>%8#-K.&FQO&L
M;>4!16_4DG>W*CQ&B&VC+H[ILXDBK+WW;O_ZXU\KH*4`YK,K@G.PC#6ZXWI\
M?!R7RT>;YR2@]0EP2_]ESCH!S-O-?OOMQWD/7=]'QD599F6+B99Y$<_2H>&6
MXS[TO13D`0Z*6=9]$):5P*<KHQGWD8ZX%U^_PF"@N3YX0WLLTH)@17F@K^CA
M[-ZW0*F[%OQ,9ZBM`G5>U"V/B8!Z7J@>7K.T_GQ+&OZA[.X>N;[D=/`7(N9'
MX#`VU[?NP%^R+/L31#4>'>_COU>M_2,KIGH$:C&;&41Z`-^OA7DH>_I`C+%'
M\P72GMZK6XWW`T^.S:9KB?&*]EMK8ZP*!K;52HT]+_Z.%G$`LR4\#N],8&L7
M:P9[>[N9F5_:X?NTV)DM.!F,TU2H-2W=MVXDT34!P9]S6AP)\^-1U+D?V/2X
M-MADL._W(\51\^USNUTLL)M]?'R<A4$Q&H]^M2\Y!0^0@B1V9YRM@US-Y2UL
MHMFRC`NGC?$\?:<?/W[8'W_\(=<XM]H#FWD-?+(>]W[`_N__^W^OEOEE@=>:
M'??[.;S91[*>@L7##O/[W6ZWF_W^^^\$3!:0/8[#/C\7>[XE%&`&[W-P*3UC
M'$CA-J4URPYP21*FYW7AV+'T_MUB0F-\?CU5(GRKI:BX!UN&UQ2_6PJKD4[0
M9(:5O60].`QVV"&`>]DD(DO#+Q&J3/RC7X$AS6YOMS0;,20IJ^`<I^!(;/EN
MVF/)I'1^0>*@K[[^&`8<X1?+Z<3D81D=!Z?8\ZJ+F$F!I:QNK=G_\_OOE]SD
M^F[-US/OZSS?VFV=E^8K:GKN:4YKNDF2YOSN1-C,:]+J+<R?#&&LY$&DK6D.
M(GX#WG\L[/VK2=P_^[$/D:B.,NW?\RNL[I\#NT\,RZJ4M/G0>R[OMXX+E7%[
M]6]6#^G@\6F.*X*_$(&<BPH\9_9EXB5LOJ7&K`:]&B#EEXU2#<:B1S$\)L@1
M&$)F7OA$`9P,!#N.<SI\A#1\?!R$)1CI<R3PDA4L0+&FPGG9!C*X$)D"0H%C
M(=&,AL.<:,]:CUY83DVVW5-H%UO(`6;]_CFMZ3HSI)QT-]K-11`(<T<P]G^V
MT./?59"+Q3L]3\UJBA1;BM+]M+*['W>[7XX+*9F-_ANGMT!."G.MZMWN</'U
M/7^DB49X,JQV6H;UX[#>^P0.=OW]SX^?=K^32TD53Q9^M>;"^CNS?,S$&FC(
M1^<%UKQ3Z(!X(GKS<"64]11+N69B,2;OY\\#,[GX2#II6Y*I:FWQ:C#$D8K?
MI>%&&OSW":[$E7B(1R9[+U[1H;(#.?YTUJ8'^9\\=_1G=0ZM-,+T/#C-'?`\
MB>?[TG<-`=[+G.90_-1#__CQPZRMH508K*&M?8\*U?OQ:38<81R)U?=9I*NE
MIN;IZ;6LM@*O#/N":)@[#Z)/#Q9GWX#W?S%&QE_P)L\6M7\;X[P#A;[_#&Q9
MT#SDL6,MB[[J+WR1!T;M+[SE%JKC>41TUOHA;38:,L$O-!:`J06`^\/K4['$
MB(:S/4=EEE01$/BA<\%UA!F)(0M`9C_E*VR9-@+3%R#K".P9.1H(X';9AU.H
M1+RW/!16QA():G]4?JHH*B4$)HEGJ*I?O??3?//!_=;9':"X[I'9YA*P-D9<
M;=L!;(8&,]UWSQ[NZUU_^_&;?7Y\BCR@`Y5H7G[/A=V)[?H:P$ME*HB![W+O
M-#_9M?O]T_[O_W?8;[_]9JTU^^-??]C1CSE8:87^TP-X2RPG3\<7FO#F%LN.
M(/6ACI('B4**'G;J*@R@[07;ACE@%%?4Z`?MK%F-4I84MQM&+%N^[IQ*5B<W
M.G.-\YRNQ&UH83$>.RS`^O/G'Q0'O4)11F"&^1DCW'L_NT0-96W'#T7%:TP.
M1<)V5-OK<,*ZZZ2[17];-PE;'._)\;ORZ+J]O[^=L=MN]O'Y,;LYI[2CV=OM
M-K\O.JY`G[OY+8QP<VA2Z#PY6ZH9*-[%"`1GNL.-P;/E8BUVCYSUV%F"\PUX
M_TF8]64KLN3<\PH1^Q!6/85XF^"QAPCL10E#"0QW$@+L@2$J!!S27Q[B3>#!
M.7]%C_!%L)O:W$4)'!*@2IZYW.]A,9]==;C8K=GA6/;>PPAG/0[^)"56",60
MZ7)HM*F\.X-],G<W<46X_#`%L)HP8B@\BG7(3+TP=+/F27Y]7L?7'EZ1T]G`
MLMV7DWY9OW9EM>6!/4)Y$3KM%T[;9'1=V?EUH@*YI(WMQ-0X)5C%D;H,7%NX
MS=OU/R^8R;AYC@"05:C%>P@9H:U_!RR:(UF0:Q"\HJ&A<>\@F>R/CL5P3_C7
MO_Y%8-)G)Z#"\1K=X31T`V&LHC5WJ77&A@>@[["8M2K<9@6EK"$DB)<SWS]8
MI*\".@_7VRG],QA83-;5M+/A5L5M>R@N%ULJUF)7URM&'#LL^2US4,.0PXR0
M'`!V\V:?6![#O9\V@*<G.>SSLQ-X]03TA/T&67=YB(NG0L]CSOSX;4,0SN+Z
MGKRV**@</]MA-H(G!V-\N_DE?UIN('Y544"W^]'M=FO6T>W^^3F7O$:3?H!O
M@O+.E,I9$)K5OM2[/\^42Q1[+&G_BZ)X7>.U)GP#WO]!O](0U`-F]TM.LMA_
MUI]A;('G$HS'K*5N$Y%!J)/.:((7-7?TJ+`H&=8YC%587>$+FN.2&:A`?/2Z
MC*#/D@87:5@N:(E?8(91>,IRFDUD]E*-`FSO&PYUC5/)9H4>3[1[=4T"NRR6
M?'E2`K$P0'G^%V!V<<``V70)6C-/X1'+Z](L:[>'1_("1-'D34"I:Z2G:!?Q
M*-#%1&(`UM49Z?MH$"JF63D71HBUI=.S1ZR;\1",QO&";>8N?>(8.%*+I>J.
M6D,UZOMZ^4EW"/L#%,$%.\YX&^F&&:-ZRA1"P6(,L+2M#%MV;6[]"E8@[NKH
MTSED1`9CNER$<U<$DR!TDTND"]/V+O29"A6%2(64<`:%M13M?E2^URC[:>M-
M5R1Y,(<@EP`ZEZ%EO4(%FI+3<>'RL*BX%=9J+HSNW$4<UNT0ZX%S&;A/I`])
M]5,94YP_G4[!5-CI%_<<NYBVE3QX-KYS-9@W`'#S0%RTLR/!K#\__^TJ*C\^
M?\X3VZ)T:SA+S*'5*%G!+`161R->;+:K"RAFRFE8>TZIEPC=`H_%'^8I_0:\
M_Y,8X$<H^%??!;_VP<_4I*^`W:]\(!XI?*$LVI8L%G"R<RHM/B$`OKD@`7_N
M4D@;U8*6S+?L]5?.[9R,+5.>=LB`TVRXE<HQLH^Q1/Q';4]9`9!(_SIW755H
M(<:>SC9:!#O$U-*BF"]XY9FJQ4:9&0]8?]#I*&4C\4\;EBZFHV&?O;JYP:4<
M6/<)#V+!Q=:'&=.85Q]9^?1](+%8)YB;P0*@D`@O?6$3?(HCW,N9WSX^/A<K
M1QLM@[N>GLE@>,_?Z=*QJ`Y8*TU((4("$_<4^^HC[0(4$3W`;HC`C@X-5??!
M$`&-"QBH!D_G4)]KP>AX,&\0_&K/D`A:(P;@2,.3".5U/N_34:9;,F`&=0X0
MBS@4V5Q0'W-/6=T\R(<4[SV?2M+,U_<C1+<_[/AR=P3B4F"&,L+"H#9>'E@`
MA/6`BQOW)\]\H=6N6G>(YXN&+CVL8BFNF.*.$?8@7IN7+>0^KC5VQ60[+G2]
M.[#+WXVWS6_`^T\!LWB64_978%>43-F7/O.5%_GK[U$#-W\!4H?/>SC0Y8%%
MK/_5PX(-PV.LX6:;0*W7KP3B\-8#\/@*FPS**]]=!T1S[RQ]]$!",\.,P`#O
MOWN0.Q1#>QT(5]RI);H:=PQ0<SMC++C,7F1VJ52-Q/`HWN5-IYP1-CSLV&QG
M;]+PELSRT,GM_<5`;6&:LF8PMKXK:FUN6CU//.OD_)@>KX,S.J4XG6_9@D4;
M#Y;U+P#X(J+Y\@:5@3`;\=4+E$4I!Z+-EFOB%Z?*#2<.!N;2M:`A..L]N*A<
MP(@9O'E->OG,8U/?,NN+!%2#!VF$F6-8$:1=)<;>2Q9<41-U]A>>%'-45U\N
M>'F\B8&$I[H>P7Q62BMW[;98T,O+.GRVU,ML!5818143"/*I0/I/S^&S8.SJ
M_1Q]M9PYZ]"@AVI40=:,X_E*7=Q0B.LU\SS]$&<MTL"@ZP4E&F,"5>"4.71B
MIRGL!/[<.<JM<&1B&[V21%#98?;$IE?2J:PHA6_`^S_Y5]$F^F6PNGL]O@"&
M_:_X4JC!\!-=!)Z>ID<3X?4(56+J\`O%07HJ(U.\MW`+U-06B$L%30OBL(7Q
MHF;7URF,9EN?R&SB29&F;6`OS.VM\*T=8#)L/R@")W:?[Y6US0"3N5,@$IE"
MPL"*WFV*9MC(XO[B'BH9BV!P[R92#K"]I/$G7:%SX`;D(_W9PSJG\WWKT'&2
MND@MZJH@2K97#RKOM7<WH8#:[6:X7R$@0R]M;5HYP:CPL4+3S\57L%KK':?'
M:P#&[LTBKS?TIUE[VM)UDB<*MAT`C1'7R_*-@PF"36*PZ!`]O!Q?59@*YYF`
M27XN\K7G@(W:342?17`D[C@SV*=[+!VWK00\=CH@Y"3RG5CL,%L=.C[@`550
M!+*W*\XZ,SB+86YKA8`G+37B6C$&SL+U8'F&CG?`X@P%Z'P+$5&`W5&44D^R
MV./6\74S:Q1)/'+6FB^'&W::45]]#901K_@1N/'`$S^RNI9N.]_N=T:=@F_`
M^T]G?NVU]C6>LJ:O`;37P?(#K^!7!]4>B(3QXL>]ILB(S';U9FM@2MOVOL'R
MJ,T<_$\6`1O[,AWPLB+OL8XW]QQ#)1LW'B0$8[.X9":*SI'LZV%XC/*%)3K8
MV&C>:2H<)7A*P/MBCV+,\_*$C5_*TY!=#%H86DT&%2/QR\J4.1V,<0(:`Y2I
M0X6"FQDR(3&Y!-L$O%C-6%[;SV3-X?6S`ZL3TFAXBPN>W4TL?J.>&]OK._C%
M)*TV=X5[AU;<O4_PR->X'UT&OE98AHG6V<,3C<X^QYBQVBN5SR9X?[BH[!:V
M';,Y"Q\W="O+SGGO%BPM@Z3(G.M,P_)/UKIMZ%:QP/O0Y(M&`%/&<`Y>FOQ\
M.B8WM1*\GJ>-*UPHQPH/;O)SYAK1B7V7#@Q=#PVQ#<\]G;=X+!Y&+B&I:">#
MCTUN_=*J]F*?\<*W6IFI.(`LFO#X?6<QH6N^Q&;'^\/U_*3MJ%B_S'(\L[$[
M@X61$Q21Y5M;NGT]#0HD\?)1@UB0@<B#J?.V5=!_`]Y_`JA]T9WAR^QL566_
M,+"%!T`3.X-)]LW[(D!_ZIMK5LX>N;VJ97TL:8C,J.C(*H]4E">F1+E1LU0!
M\9W$HO(P1LK+-+44F^2HI[0UU6O1(N++@W;G!((-"SF_8\DHN33Y4JI9T"&Z
MA%.8^-PCQ"#QXHR)SLA#B8G5(,?05J/)1/7\>]:Q\F9;I%65]VAH10.\F>EU
M%V])4$3K`V:5DZ9B-S/IMKMN#L)"0=E"%"$3NZC:&K!F`#U=#R[)0-[P^+ED
M=XKU?B.U+,I(F,7*]F_C&(;\@B)_XP!2\0A#T@*S#K>Z-IY`?QCA#\]V9.Q6
M0165E9X!!MF@Y2'5.,3&]P9$*K+./7E1!U4H)P].L#78U<8>UW1?RN^A]V5I
M`>DEY9$*,KY&4C174A^.2-;C'"X@_'W1\;C3`I64K'^G3T3AS"#/5XS*#9HK
M+#D4;S><F%?)FE+7+@#)F-#W%).X;_:J-8P!JS6[D7E]UOKDS].&J`9<.3EX
M+"G2*D2^`>__,B;XS\#A\B=0,Z7;>-VO'+2;MHQV1XCZ>^+E#ZG9K+ACPXM(
MQN+'\6#RW^,\B&>%<-VFUTTNU=Z.;>L\D]6NIK6\8(T?24-RMG1<#XCU[3!5
M<<$6H`RQTK3)PP-0D//MY486A\[&)K$83]U408AW[\!A(LI%/)^]Y_L/.3P#
MV)T[94/C0?3.%D=/I`SD2K&^']FR]<P"98\N*]KWGC<?7^$<[OY2X:ZN"3P<
M64?6XDG,]CE%_BG4'[H%Z0EK'YEU6FSQ8'6?K8@J&83<(]7@W01^K-,4"[)U
MWCMJSAPR[&:/00)6$,74UG([?EI4(:5QN2N3Z(4?L%/!SX$=ZK4+^5Y8U@D+
MH+D6E0AQX^.>Z#CE)%9(4-,]M^D,N.T+MFEE"$IT'(`<0;@T745L8P6H$H52
M'E=XE$<)&SO2J)^U=BUX3H3)#KX'TS.N%^`IN58]MWE0+'+IHZL&\1,6(D08
M:W9^@)`B,IA67.;2@A31NN_R^OZ&@G]#9/HBLVMYC]J^U^M,9WPRW;9M^V?,
M;C%F[E\Y#[\@-O9?^&F-$M^\@_L7KI\GEH'7!4V5L@7`;"<+@,S(+A9$;P!4
MYPZZT,2AGMUYFZQCG"RFSTRQOKS(7I^U/I.%JVN3CVTJMNU*!E*(/TO`N6HW
M0Y\0A',=6>_">5;^B!X-<ZYK<QFULX]M9#R1)"X(;Z[,KGH`FYS7[694HC(%
M6#R4(_92Q?GEV\LWK8]'WL6[7^<`GLHQIFT:]L]>/`>=KG\_#NLA`,3=4R3'
M\!X5CUZWK/^,WQ'%9>OG_QC03@80"WB,J.IY'YBRPQ8BCR54P?(@65D5E`X9
M^D_C/LI`0,-WP.<)78^+Q.<S88ZN`X@YC"X?\QX-%G&XDLH0O(U7<Z&M\Q?/
M4[@/QU+`'1]TA+5%];/SN">\Y/9"8)*9-;1]0<;2H[UKH),]VA4@PC[,EK70
MW*$I+=!#\33!.W1=F`XIP/:9C7]?%7)SS2N(D!+1T_NN@!)^QA!6?ZS[<I.`
MF@;2/?9FUJN^&=Z_VR^WIQ772YSL+X#%F#CD[C-6$G@&F8NY]*\FKT6<@E_X
M0D4G3&!,:I6ZW6[-6&?4*6DFM?KBPUZ(H(1L94W=_+S;-"T?&>C5)@9BUQ*Y
M.?@A,AK?3\U%(_Y$16Z8>VQ&&70Y*5O;?`\Q$&ZG[F\`@\CFS(4P1*3.XB'<
M$X!'^!EN01>.)-L]A2_M:L>#U);`XXY%'.HI(!1/6IM[8+5R*V_'GJ*8;C9A
ME[PN1%TGV2<K3ZX5,1"#F2LO&%\/X0ZO/JRJZ50O4`37BO0<C./K4/UV!#9C
MNASL>XK5R=BL,@A)<#&K96D]73H6D:>L3H=XMEZ2DI40@F+]H'9Z6,1RR(=I
M4IR[L&C5XNR2Y,=,7DN@M09V:O<0H[:G?9FMX:4E9_%2"E3W]6)@SJ7$W@1B
MIB:<RFC7P#(SZ]</=D.>CPC/P)9]1$B<BYK4"TQ'0=RXKQI+6(SC>*G8Z)=/
M+GLGSW5I^?*>3#RO,%BI?Y&@HI"]&A_$:/=!DA?A(&&X+,XG6&HB[ICDC'17
M.)YO(8)+QP#?#._?FNC%G_12^`5'!'<OBT4U&'^$/Q]$S'[A&/TK&#YA,5\F
MY)O7Q32OL2&,W[?6+@L;-V]M_KG=;O-_VTT=E;9U#6U,+5S<2.UQ_&S\$$Z6
M^K(%1YQR968KM>VQ@&1,'ABO+<#.>-_;=:Y6!.HZM_(5H<`<,55C&MM#JO[U
M>^C/EE0WF,,A\)NU"JQ!E%<CDK)8("N`2&8'UQ`_EW7+```@`$E$050+,RI7
M6$+)DN[7`V7,7FF%("2*9;:^(Q<!H/0F8>NM2I-"'>X@8,&-S?V5_8;=C_LY
M?$8#0<Z0DL6\!)"871]%(`N5VC5DZ#3@Y0CM^G!/"I,6FP?!*+HU+[R:4YH`
MM7N@$F'Q^<WZX77>KE/0LJ,%BJ98]M^%A*!8H2?VXCQP%R`68`CI/0I0D*[W
M/(;XS,05<ULT;>12<3V1WX\A4Y):`&OP5!QN3I4+^GDOM>N:-5NV=K44H%ZN
M\S"I)YK9);QE?<<J8IUZ5=-+N5&"G6]IB;:]/RJ&EYERWK>$B475)2MJ*L2D
MS4)_[;J7K!`]$%N/U(&*<RX/LF/,['MH[>]+]#[503X`@%&X_U7L#&;V%N/S
M:%AM'\CP*_3T(P;Y\?NE`"RKVK%>OG<_^K79HL32>$0\IXA0"P-ZZ]4GLWMN
M[,7J(VS:T,TB)5RMI",75X4X84P,[L8]X.'Y%?\Q3S^YL\8:@9"M7?&;0S?8
MCTF[\&1OC-7DXD'.83"2989E^>`B,X3L7A"MPAX4FWC2"1'I:P@;T%/KDOQ3
M<>1UO;,!NA(,4;-$`A(V5AK5!CV"$W;L;>\]>=$^6$H"NQ@7DW6WWC_O]N/]
MQ]3&MND"D$%-C`MN[G:D\@9%0\-MQH)4YW/C3HC+MS;Z(8O55:06C;68ZE0Q
MY#&V8<WW-VCES)'WC3IASLM[:5[GMKI<,L2(/`PK7L!)7\P2"=2%!,7_\H(M
M*5RSR,G/DUARN8[P14F%#,C1\ZAAWEBN$L1\]K!D=AY,=)((L1L)GA!)\5'4
MW/:\1<FSWF?4-;LX@(:,ES8ZAWM'5A35EB@-#7+&D4QHWSQ?;$-GPL8OJ4C=
M-8RS#_HHYLGMO.)I/#%</8B_A];^IS&\">QZLF8Q*SH/)<,8'_["WRKAOB?Z
MA:]$C95QQOYX(*RHZ.*YJ%]Q,EPG,-O[Q\)JQZ_S\PHPJ#PY7=MNQ\$L96[3
M,@!$J):3U/KZOR[-FW!-L1M(TTW`/+>$N7V5/8OW]ZP[Q?I>R^#9R8-*!>16
M\Q1!7$85[UP!QF96>?E2&SOYL$O5M!M>W`0TA"_A8H"D&R8D34K$%AIGO&E@
M:`&3'RLW*P??4'E!!>U0A\E`4CQO1K:CJMLTBQ,T?28W]>#UC-7:;NL@WUJS
MM_=WKA[.@!3G;3183EV@K+5FUDX^SOH:ZG&LMC#BHI=:'1ZV>+MD$.I9JNJ&
M85_6SN`,8:%Y6%"'<"HOK.457,F/H(.FZ7N8>M@&:ZB1/C=^R??P.DT,P(RA
MCE[9X(0OD5^QE`-2!X!1%/2)9E]H8_<8`B_S>#O*(*!YS4D[NX8AFY718]?]
MT:&Z6.G@7'_5$=@-9_#MH8ZFHVLYAKK<MEW]AU?@A";%K4)"Y4!SB!<Y1,*#
M(P_$VH9G'"!6A;UCAI-TJR9Y=#_NIN2"Q]6[*,R9D>ZF,@94>YV7["`Y,B`1
M,Q/X?FMX_[Y@]Q6&-]TY0J+XTV9GM+_9,31%!/OS,`5[[.CP%..6TIVBRGO1
MH0&%<2^NQ;_A9'?+2K)J#V[^^TK^&Y@]"4;EN5WGA88TLF.7SCJ9Y6L0Q=`#
MUXI2DB\\&!IBXW,#I^%X$=.Y%C[N@KDC"0T6>%E_WZMROC"&WW4U6&=97DL/
MI+)GJ[='SX)M\+`,(VULZW8%U?8^#S_3+;/X@`X+50R\5Q9ZFOEDJ'J2V"P:
M*;X!LG%7T:W">%W'W%JSW__/_UE2A'I7"T%>/#EO=KO=K/=^#C_QYF?!X17!
M'LHA7=GHZ1I;^<+B>_%LJ/"XB*<-6M7HNQ>GWL5;>D;&7!(434Q`['ZXKG5B
M;S;>OW<:"M.!-D^!%&'2-`2PI'O*%^A=>UKE3%)-@'GIZHCX+$Y=L/KDGA9W
MGM;:R.@[,AD0/;QSXEW0.<]S:A(X,0%ZW#_'7$R(I=X]E9:4ONMZS\Y`<*:)
M;C'+5ID1[QHHGN?-UP+,<B28I6Z:@OSH>&,AQ=$?KFYBX>R0=6!U'6I+P^@[
MO:'VSL+Z&U[^_7Y]">QNT:(]X.(>-<I>^T'?UFKV:S(*>Y:<5B>.?:V0J(_W
M?ASUE/\CG%Y4GR!S192](I-%61>(NN4K$<"Q3<52!1K&BI99_L(%]L0T;"N%
M`NRPWRW+"S`E(A-<@.(WJT$8&=;E;'OLY,R)??K2_>"6P)&\CVM*5/J,!YMR
M>0[=-T70IA&Q@WZ>F7'?,.#^%&R'+9[01+!E77\W`$_R_-RS6=C<4^C=/C\^
M[/W]W;RU<"]LHB+#<=UN-_OY\^<\AZ=<:!<@L[^]HQ/`3K+#$H0^XYQ'1')8
M@WWC_\HN',U+LF/*2[`@*U=M,MP%?\$/NRI:LO\KHN2(@+.;$X///L2;.ZIK
MEXS//=!/#2H/X1&3&^5'T\S-3=("G1$ER5.8J4X6:Q=S:928AZ()P-'GB*VC
M$=4>)N,4Q,?TR]#Q4ZI7BKK]O8MPO48;7[CSS)0.,`XO[V>CQ+F.!8I7##J6
M40?6G*6R]K$;2%2K:<*D2EB<%'20SD5%,N1.UK!#LS28.'[W#7C_I@SO,VCR
M)Y0!&Z873^AC;(!F5K9^"73LW\:>85_?,KG1]DB76\U#1WE&7PG&\+@Z,O/J
M^_-[6I*Y';T7.%Y3P80]HUE;SKWGEJTR54[3UYN[AAE3Z9;Z8B'HOTZZ-80I
M;PO>E+W#@(,&M#*P2"X.TG:[OG&:6G]4PX>S"<O3R,SJ`K8CM1_IQU)TI>W>
M!`]Z<?4_N;]09^!)P4IR)O[2OHT"7M]&6<V5IJ2V:9:+%<LA(^<T>5_R%F:?
M+GUZ-[.?/W_:_3CLMQ^_V=O;;1NQFSI-8QCE]F;-FW7KIOD/JGF-NM9'CA)X
M>+ZRCG98>$6&>3H=Q.OD2U7,/GU+GWV!R&Y!LT[/76M2G.50""V^^:NTYC*0
M]"KU(79YJ<5QK3M-V5R/P25^GA=W"F+@(T_2!)*<%"G,XO1A^^NKSB8K6`=!
M9]K1K5F[9%A0*5%<=[@[A!!Y;.Q!3*QY\K$=EQ_%&G45<="9FCX#6\B]7):;
M[(13!=/("N;!=<>TH("9>5?)34QRG''<F=S=7B]/2YNO8A$9*[@O@'SN3TA"
M):2V#;Y=&OY98/=U1/NL/2ML!C+80\6V/CTT?PEA;]]_^_7PA=A@FH`GAP%4
M#$NTF,*3<PS;^@./P9EJREFU3Z=SP>UV6U/CQ"VXG2W>M]N;I=@@!@JAU<J3
M_YP:UQKY*/N&+=PPUL8M9N@]HV"WV>WM)@,SI_58GP-Z@11)#-KX[_N/'_;V
M]B[ZK_(^\;VT1+Z=UT[52AQY2!URS7"O9..>N9HMZ"V&=C+0\N=D\+0,TFGF
MDC<JGNDU++C^3[VHO00FU:>D^\\>6V>/^T'6`++9ZH#=[W?[U[_^93\_/E9J
M60S#>.!I^O[C1^BL0(O>,(V^`[OLA?MH.8YN$P/41R]JR''L4KGH-9'Q:[:F
MV-L%)&8!P4^)%\Q]-87W',@OH.8D$[#2#[5?UV_D-.`"9U.%=.5[C,$_9G?U
M>NC[5\5JL`).6GU.0F./UTDP-I_'R"N,#/["S*U9+QJG'F])KSM^*-8I3NJ<
M]FWNFN1FU=#;*BZ<F%-8,Z!9-#1<]^5^W6>)#H-R<5NAZG8U$8,_.LP,S<S:
ME@1`8F9#*I]8:P;&EJ5LP?^=O?-CQUFM#M<Y_V9X_V?"YJ_I$S8@,@4'EL6_
M9[KEJX"]8*U0T;DOX&YM2?L6M_(#"T_PNJ8/"UVQ4VSAU!'V_G)EDAA"-[N]
MO5F[6J7]P68KK4H\*FJ(D45<P+V\;3QFNFX633>W=CL7DS7!KIRY>[:Z6OMY
MF+9O3?2,\DZ!3'*7+N)+<@"K[H'A/UO%>9JR-0_3ZQX\`S%E2^_/Z#GID\63
MS`[SLBA9UX*^4?!IW3W^Y[/B#PMNYXEZ*/!.T:2!28Y2$3ZF%FRX3M:JV\?/
M#S,S^_'CQSF(MCOWP6#[[>TFTIRU7Q?N)-6`96+!&K5RLWXQ1A:#M>A%O.OH
MT[`-EEN3(40/;+P._8SC4AYL,6&7MZM/PG<Y4ECP:I41HV+X;6B&?7S_;L8.
M`.1IS5I/9B3YFITCB&UJ0P>S/P>1^VK'NXTT,UT#*CUN"_>2^`F#UC$^O]1U
MZ/R^P76@B=Y96<=.K*?\F=;5J3WEBUN(D&_-IPT:'&2OR;Z[H8-Z71<G;;3H
M7F$R$)L:)>XRN^`((1=AX$W7)^.[F88\<YPOGW/1YYH.Y7GS[7Q`O$>=9&:L
MC>=881ZN=E^EQC?@_<>QNWB>/!UUXY6.U&SFHN\@<&6_A1VX]M?!Z/8#W?9R
M!3RW]<43K"\QGM.4W5(BPRMZYG@<;7KX^N7`H*UB5BEU&A2)W^#6;J?]T=$7
MRP5M3GF(8!2*VC<,G"1Y+7.:;ETUO@.@C$4"IE&LL<89&T`_MN52NK!C`2Q8
MR,^/S\QHFHLNO+RE@UW;LV?)(V5D>1".I\=GNC!9M+EQ:_62$+0F!8\,87EL
MW%;`N`EPDN"2@$!9;UV;;A3I;![:A<*(1%!$7)97YR:`5F%K%&`Z`>+(^$\0
M<150W4[0^_;V9F^W1E/6F?D>[S$TI6_O;_;!]U``M<F.JUJ;.&5+AMPV%EN7
M7RNLS\$OOYP;UK.XBJ>A@17M]JH^S+R9MZ"(!%W/&1^,Y380@,$*>W#]#-/G
M-BZR[(33&FF$W1)P/L'E*:EHOMC21L-IZRPWOA$L*L\8:*]AP`6P.297[-$(
M3*DW]/A87P/<?/W:>0!M0W2XDR47+[&>"W!0)+/'`6*Y65V`JP+?4U[K"-[:
MGC>T!83'-2BBK.DZQ&)<S#=@(B,!R=:<W`\2*S6E;K&CMHHU99L9?%?)K9>E
MICA_>"+>LC,A_53IZ*`!&-^`]Q\$=A/@PQZ`N=NC1JMDH#^EQ6:N>/WAK_*Z
MA=5?3BO;V2RX/J"/71BP[S5Y8,9B>PI>D8D6*`+JN<VU+!W'3FG=>U_CP0$D
MCJ&=HQ\$X%$PJV8\9@REAY)>-M]CPU^1J=%H2^<*#*`+*@=U'/<[!4,8M4+S
M0L7G4MUV8/W,:BVET:4?=+IU7#XO:P#-++$#->4N>T7`@9Z-D=8"O.EW[B6]
MFB.?@88GR1\B#I7$-C=Q'MVXG7"JF4QDBW80U'Y5!DG4&E>[N&HQ/AJDDL*)
MP%:W;I_W3[O=;M-7R(M%PB_[I'$B6KN9^:<,@K*ND\%GN3*!)\37-6WM!+#S
MO+=FUKM>]^N">`+82`V`D\WK5'`QH_]$6X5<;'?J1+#=9',OA[$<JRVLGSF^
MZWCO\]]FYV4^.Y<5FQ,3V4^@WZ_TR-1?0V#UQOER_?Y\3OOL)'1U.R`0+PPS
M7]6V_)C;I=6-;&"45-1[FEN82I.8^,K"T%L8Y)L@V%/HB*P93@EMIBF(G@S9
MW';MCQ5(A.19[<A[&LL#9C"*%!K%21(K-7Y&JW71J?"A8VUT3<!N<1"9AQ.@
MGMT6M^2E[7&]'&SX]0[?@/=O\BM'--J3=OP#,)R\/LL/U.C#/<Y<-_4&;3B!
M`SP8/HM@>S215;^S^B"KW4K^F#LK,B_I/MM'Q+FT!->/(X&0J(G*S!"8E`CO
M9P0$W43]'P[1)ZO23[WC`UN"\0GO[^]VW`]B%9%`R_.$D'U5(ILH(A=D5RQS
M+%R\++H0IS!&*XV`E!,0KH!;=&V*PWW#"0)D2+\F_S/#%R"IG-LVVW[K/O60
M8=\B>XK59IW`AEBIU!:L?$-%1Z``,@Y8LOW<L$/RX,,I.D+H!L77IUU@I5$K
MG]ELN5?9GYOD%L+20:.A/6HQX_KG"@+0^P15LBM')KX-C2CLP/T*B.AZ;6,2
M"4Y4XJ)Y/X'>Z8%Z#9M1Y^,\QBD63:<006:#4.A%-XZK:9[`S`BK6-\=-L(C
M4<9F(^:Y:9#$A!DT)-J<'CL"V_UTS1@RK8XE:3B[4ET]:"]IA+N;M1&40U[B
M+0\X.LNDV/\XQ/NN()W58?)@HM>N`;-QO:)BWZF@BL:UY_EH!35Q]AGX"?,!
MSCIR&B^%0L1[]3RG$*>#"=!"[*Y[L'ET#P.(NEEX4&]OAY(--#1J@95%`(M:
MQ.+RT:XZQB[>X]+^*=:X>N(B2M8T(D3?PRGVF(D(MZH[57>XOP'O/X3A?2:?
M36;<J'T'X@#0^>!IEC@J*8#M_SUAG9>4&<@FZY%/1>3NLB?:-@$M>NIL(M*@
MJ>_IW]U#'OR$KLJ:5!/R5A4@M*(,DV]FGYJ?R61XK;1YX($+$>MO*7;W_<`1
M5E`"#S7,!<[=WM_>[>A'[4\;SS>MJ!XWX$T7P]D*UA<_8+0IFN=[6CORL$<#
M'-(*]J%G<[)IXX)&4\YV-[^W1K*9!3*J//G88O>`CI#@HJUI\$"E5:W?H='#
M+&):BH=U7Z"W8KI%R!P>NO%9+<Q`M]9F,E5Z%&?Z426YL!7AZEYJO5<!%=:R
MCCI7H[+^F]?&ERQB`/?F^1R8B13)P_J8,B),0QI<+-\""!?:WA,SATTMCQZ3
M)$<;WBV*"O;[#*UQ;0R7M0F"ICQC2B0\R"?6]YH6;1Z+HY.)'QT%1*UH.*?G
MV@-->>-6^@5^)?D,Q!BF<)EF*]K@ZEP@@BUN"[6E1[<L&8RH:@#JI:?%<III
M>>UGSUXPBNO]&DC+VT9/7:EUW3O/8WA<_R-3K,-<0)@Q<-KQ21,]7Q]8!S=F
MH+/(7CM]+=YUV8;/U"G("Z"!+3I:KC*2_'9]QC?@_8?)&3:J@KQ8;+=U34C*
M$X[U>NC!2Y#3I.S!,=GCYMS#?_"J#5M@2M^1E]S7@+@";MC?S,9D]ILTOH4T
M]:6I*?*/5*>`-?5<G2/9:"F9"-M'WQ](1*IJV$GO:ZDM&6OT6VMF0\Y0,):/
M;JPYL#(W`$\Y!^<BVB;+TU$Q^A[8^59W(+``BVX`@[#C`VW:Q0P,\/34GW8X
MY+<1TJ>BMJZ*ZN5_'QZCIRZ:SX1:PCGKM#E0`-K2=JO="+P:\I%BP45W&\%6
M]O_-0Y%RS*Z=!S<OF78&_F]O;^E<17G.VI3;U+R/PK23Z?\)8$$$G2?'8'Y>
MAI9898M>IQV&^WQ\+@JT*BZI4*YK;<Q]#:53O'(/:\UD#@44^'R/M.AXR^X=
M8\9@>@KG@4.6VXR_;ZV5>]=B<1NYQA1MYN+T5=]%B(M+5\WKNP?)%T*EL8!8
M%\IW%G_6PCJ,R=:F&-Z-A[633A24L+=>X]EEKV,RJ.VZ=\5)Q9ND;,+V&O11
M\,S!N1#.$X=*D5MR.65.UJ4%C.>/@F5\FA98"YHR(X+"N83W0^VNKN/(WKOK
M?''W$>%G[#M:^.\C9W@5]+X$+!_0P;'#_2S5+;60[;F.$B]^C\<_BU!!9E"_
ME5B4G#8VHH;=-<D64?.!]SW.QRO7SA\SM]BB17*5\$K!M1MBBD-*/+F>6:#<
MAJV_U=OM[5J\>V8X71<U/C8!3;Q8(MZ3"^;'\S>]*2N0%<YSIX6369)>%#/C
MA>W:(B7E)PV/,0@.$J*-Y5,9X6I!8$.L%JB%BL[V7QJ(<0X?.@5W(+3RP[T8
M==WDGK#T@Y;C8PL]\+A?V[#0LJ@S'\U[ZC$3N)ELZFA;FMNM-7M_?R>F<0W#
M`3D/SIO;<;\:[,3"]^L'NEBBY>SLR>Y>%^/>%WAV]Y3L)JQH[*:YS\2WUAJ%
M3&B!T@LMZ63$!T8M]/CC=6SGA$NB8>C"YAL(A!`S*C[)PL3YQ8XM%>4<)L3B
M=3L4@'#3`]3!<_G.\34:A3X_?T-K#Q`-2+^/P&&CH4B_EK:FLBYR)QC#@\DN
M:P(NI*&QR>32,7:2+W6.!H<@R/FSWEQD!8>I4XG*XC2>FKMR_`R#!I8YUCK7
M:,%!9_0K_=G>5.Q6J%D1N'I!+W>-0/L7V]SR1M>H=996.C;^WP+V3>ZQL<U]
M`]Y_",/[#%UFC<VF=84:M4;0^TSJN?W7%Q#O*XPR]5++5\7AC/V1>8K'2E/R
MT6[L5<2>J9(GKZDUN1!VJ#^,GK7`[C(SB-C\C@MYF1KEMIO=*L;ZEG:U-6NW
M9OTXYL1Y6C$WVO`XMULNJ%RM>PX;$"NR72T!;:'[`V).Y2I,@GMM+>(JM-DQ
MMM'WM8JJ]=#,8\F$QPA:JUM\#M5)+S4'M"T96[$"?(CCOC2&Z+U@0&.:DZ4B
M@@L!?H+[)AC%R`?8W>WWWW^?+"+?#SOIR_B.PQJP7:RRVJ+Y!(<@_6%,[V(;
MHW0ON0GH7O(,O?N&%(#G#RAA808S,'B=H-QMZJ@K<F2JNBYSU#$X-L!RMW"9
MXN"K9^`"6P-NTU$"KJX*SM$"2V\_[;^,6^M(#"@*4"-G6L@7;7]7^R1HN&H-
MTZF-WAJNO-AK!*]M)W`;?HU@#B=G!D<M,V%/9<#HV%?_8VU%L;@<(*ZM`C($
M^;!L`)7\T(L`$(_1[=G.#KYD@APNXV%OX0?`I>C.W:]4%%);3(2$T7CFA6V4
MW6=TU<P;34PT]6\?WG\&V`US_)J_;L\8SL"%O(!D<_.AR".7YGY,-7L-JY=X
ML_@'O,#`/GI_61Y>3+]*Q_:B4B&[U4/9"`((<4+X3":[/WG8B_;AAG5.0!LU
M,8ZMCS+$-Y1/[.W6SK2XXS`+:75.FE]'&&@4,%G;_+K'-"(>^O"PB7O)VZM%
M*X$^CG25`@A:1T"WJSC0%JWXRL<JFI(R`(Y2`GX^"XVJSY-)&ZX;R2G66#VJ
MVLA"NI+K?>A1PL!!"I8C9BT&4X2(W3XB8R_KHG;]3',%)EP(#,>/]_?WTYTA
MW`\J.2B\;KW9K=WFEHK>BZ&N\_QT7@[INS7^K'@MZ=I[+&*`8?!GT\#A_--Z
M\B\&NZ-;OX;`!JC$8+I#M\6*M;BYI>L8@ESS(NEN58Q-=%*006;7XV:)@T=P
M,S3@1"RWH'?7UOH2<O"LXCF(%EN*GHO;>7^N-4Z'FM@-XCP/-P]:9I+JR;WO
MZP&;X!S%=H$H+3`9<M4(7!>+073,Y\/F`%MV<VF6U[W<L,]WBKM^S^@FK!TV
M)\,$<KP8`%ZD='FPT+2LHS`CA*Q0*_I\ZI&<;?"H:!]/5+@8;AJ])]K=P`I^
M`][_\J]7Y0ROL+M[UI);*^*0DI[BEZ.(92M]$7D6'\(1HT;9[*_0P?Y*`E-J
MXA#*BK&.T$E:]8FTIUH.);^TU!1.S,]-_?[Y:0>P'Z0J=,K\;S<:C+)D?+ZJ
M\-VQULPX,GWN+O6"P:S=;H;>3__=Q+XA%RU%C>%%A2\._"1W&,P,\264[9ZE
M'%UR*`>;85-/*O90U*YV9GZN(1CV-H48\_JTH0)O`+)8A\%$+24(-(UC1KYO
MQ8)IM;79HDQ?'T0]T/O0Z=D'U+9++)]\!2RTFQOGJ2B6"GI@TA1/P$"QJ>XN
M#AX\V/[^_GY&"Y?3UH_^[O3`?KLUN[4SMONXKX0H#/NR"SRT`331:3!2[;+&
MHX"'(2RG'*)=*-?=9<5Q`M)K7W8QXH^=I\&V=@)V')C`Q^&;J83):+O9K8`=
M'*CB#G$;X?9PU;WP;8`'4D'_*,W.:$YB`&VO2)I54PE-[`_:\.-\M697X6/G
M(%H8NN5[BK6T(NLQ`M`$JICY;>3"L&SJ0C(.#4P.]GCZ=R<'DK6N-*=B1FS%
M*(XZ]N4&@^YT)*Y;8-TM@7:[4,Q<1S+%,Z%C'6D8U8DQ%O>G:D^_I!^QP$P%
MCT7=M@)E;VJ/^0UX_^8,[[:YO4W6LBRZ#9L9MY_]R7'X%D!^D2I^F!@!U9N%
M`;EGG_F2`L%+5VIE`D,1X9(4$P:J+9[>P@F!4"(/M;76YJ97;^"^*6QT0VFW
M6UJ@#+!H[I)`.7U>:VYO;\NLW_7_22MO?$Z[-;O=FGU^WG6".FP.J&RXBF*/
MC?'AM&P6VL"IU!L_=Z7[M,@@I.$QO6C.H+8X1Z<^N(KO=;4PH_9T],ELSGZY
M(YC`DOW6^,`6VGHH0BI.\.B6"3:WVS6=7-_S,&LM^"XO4#0\0UO3=N`TPX^%
M60H.0;SER_AG_F;3_JR=0/G';[_9V]O;P_4Q=PK.M6+D-/B56C5]@0?:!<QO
MOG[/Z7%DD8>B*/`PS<^LOSAY-&J?MDL%"P4OMS8*!^0.`EF3`MWH<*<[L0RI
MNHLDP5EJPY>CF=AQK:2MZWYINNXX^:N./+0R^5#:YBR)6+*-',!0A!VY;SIV
M50PT5.;C&\#/!7,;9[^7+(D0!0.\=9/4.F:W+8%'#Z$.5*A?I(0/ZE\TU_6Z
M+.O\%=6VO@X,4Y?L[$.GFZT/H+R"BMPK'8!.5X@5I&]D`SORRHN6EZO\QW.[
M*`SCJ1QEW7K8)B7"<Z?N7`O:M-6S;PWOWY[[W</=ISD1*(>6MNH&X(5/?@XP
ML8MN?Q&58O,%O=05>`(O.RVO%^Q&Y:E;.D1P`%)T9A)%![C/LXS=&8@2L\/3
M]KE-CNG%Z13K//1C[F9OM]NU,;K2S^S_B'W1,A::'S]^G,$1QV'WXUCF\@$,
MPF!O[<W>W]_'_,5IG\;$A7OF)Q\44HG;FNUA6U/F(0Q$AH>@<]0^%DK+L;P#
M&8Q7=.L7B&>OWZQ5YIR"%<.9"[K9C<:R(#/W9:-&4^/\VG:]<#$Y9FR#!P1W
M@NN+MC`]7@WK\>D32S\._7"6.R`77W3NQ_'U47JXML)3U\4@H%1`&;-@,/OQ
MVX\+[.)A)V=$KB)\1A_@M#5#/X(V&?,^94"[V%44':/A,-'7'2J;M8N3107*
M?0R178-W8WAN13+K7=?%MW>-_3LWBWU%L<ITO(5`+:FG0RB-`+SH*((@55-:
M4%;@IBWG;KGP'S\S?)'=W)8T.R0_<L<!ZJ@R_MN:GU[!;4?MJOP%E/\^GI,V
M[.Z&QAN%U*Q=?L(.&=SEX2]0RW]8-L>5K5^^Q;,8+YEOB091W7#);W7SFT^_
M9)M%*\L_?&F\6TFARG5-G8&)5DUG00JO]133S@0,?R9G3[@G=X<I4/#PCL&'
MG-_?W;=`G+O8^&9X_\[L[@LR`7P5E,86&@V98.=G\$C.4)"T52K5D^-[V;8W
M\;'CIL<+Z5OQ3UZ\[Q,?9`)/I4_Q&-S"AGT.#V;O/0#L30"!M-/65/+)[J'P
M!H$``"``241!5%8L/MEMD;XPHKCA^3M^W6XW.XZNIN0D,?&Q:5TM_L_[?=D.
M-=_J@Q^1_NN]EW;-_;0AL[X\7+-4W,,FOIA*_A0I4CS;X&!SPA$=+1A@1"VQ
M:50SKO/!6EWVG!9K,3%QOP;$FA=?&`]\F76PS:_4K8H23==G:(`?-XU2/'*#
M=DXZND7/S1B.@42\@XHD7)K=(K'*8W&*<EU;UZ)?0Y1]_?2P8^*A(5.'FFD#
M)UWHJ#UT(N;S0&+ON`H8'@JR%3%\;=X1<+O4PQYD.E1`P^9P6_SL&-<<(WFW
M]PPX=*/+L%64K>3WWU,+\3EDYPPD/\FVY%?4&9CG>A(%5Q#&S4-+&X7D@M86
M8?)Q#5:2_(`Z31!0:N5@FP0Q-==Y`K$&5#89S$B*G*LI%N!8\>8IH0[,'@?&
M%+)/D)?Q8$P+<LNX:^0L!QN=KA#A;/F\^-:(7_P59K(>[/$\21R^E0(7#+91
M-HNY@.?[XQOP_M?`KFT7B%<)8,?K!&H"5B\RNT\L)U/AB!+9[(_SY>-.J6%(
M?"W\U3?.L;#[,B%('*S^G@#L?O_,^C=D[]*C]ZN]QM5H-(JQR?*N36T]S/?[
M_91&;(9<QH9U>WL[!VH(8(]C//IA_:/;V]N;M=9.T,OL&&+N#6:+Z#CN)`-9
M+;B^JS9FL1`M,<B#ET`8/+`;D4*$EUZ\TK'WO5B9M996.!7(-2L&O-(0$'N7
MCL4:R'<6ZUZI1:MR&226UP)(Y>0V`,&[6*-)JQM:&IE>@2`/;*7)AKG\B[MH
M@$M06L1<.]E%N9E]_/QIO__^>^D/+4F+P4D#H;#I'7;__%3PS45;<<TDJ,04
M*.Y<RJMDS':UK$^F^?+)%:;+9"A,O%6=/7'S5@!A_I>K0\W,6P@6L3+:6\%K
M3TE7",,4O/X.IXO8+XO2%WX-#X"))C=:?Z%FW/D]UC%U`8GS^0%II<=YH/0]
M!D?PP#"2[_'2VJJYU^S(H)`/!<-A\'H#Y%`0/!E2D6D\DW12ASYU1712`.Y6
M%"3KNXGA2)@VGEIW#_,:GHDP=P_^TW1T44I2/6$T-](E,MASB37/J9//<G;C
MA7U+&OZ;D#>TC+X"_^R9E/<E=K7`'B]2QB_RL@]<R_PKQ[X1$%6ABSO`G64/
MV/1_GS/%^?B)7=ED,\?)6$2W"$![,7$3IM\?U_10/WHZS6ZNH6:7%V5K;OTX
M)B@#N8A_?GY::[?@3YH5I!-`X?SLP9Y@P[SI8'](_M)Q>T8;BU&(WXT'/'=6
M:B'F&N"I88WTY%8U$%PFN@)1!8K0R>$J;(*N\<X&;[`5RX9IM2&!V$#-+A%I
MX)48>="$-+?..?K7=^?6?-.B+VS'QF<,5ILFTIG9E2``;W9,L'9^RX_/3WM[
M?[]D#5Z"RE;DZSK=EY^?G_;Q\5.`5@4F=-U88&@`<1WB@X`N3[K[];TM2B):
M$:1@P=*L$YBH+"5#E'-DIW>KJ01VM*KP%/I>$^\\!+%L(L;$*NL"O\,W>;@\
M2-D0W#DJA\QH;&*&XM[T!=+3<A_3!S'#-&*,\8P=[[UHK5MVI@@>OG(/0HP%
M5Y2OF<J/@E]<&KS:[9'0O<'%%F+=ARVFHH;HW[/H"VO"SI?25![I"#'S<]B<
M0>Y8]\*SYIYB[GFM=-OXXT\GFO4BV5,X^"-%>2OS[-^`][_WZY?=&?X"F+T#
MI%N\YP&+?95`_;.@U[^&LY_3R?Z%X_;23[:2)^_RS#T`;;7ZJD]JBJ\-UG`;
M7*T/N[G=/S\?LNKC/0=C*V#*\M[;C^/R"T5!G++GH88V\[!?8J5=NPX>04U:
MD-VVHAWN?#B>WH/S>(F!X0V$SX<%YB/Z8:(*<S#5XJWW==(&7AGWDHY52P1X
MH^T\#&(<`;P8XM5^5;`E&E?Z_7`RB"$8;B[%@PR-0#A(T:^;J8<K+LLRUD&.
M8_CX^#C]G9L2`7M7`)OG[3@.^^.//Z28D_N\]TT78-V#(ZJV<A@0H&D5Z-70
M@$>+*+>P/5".PC:B3I?CP`E!`=@L9]BLXQZNIUL.I4!P&X"I$\<T*XG^TGFM
M39KZ!X3F9/\I`M=LI-A=T;&NG17W;``IC1[3F0F<;UCV^_QQK^^$C:0S7J`0
M,G`UGROTTI+R_$\7]A)$@3MR8$:T/E2'!\S(8@.2_:.Y38>2G?C``VBV$GS7
M>\YHN;!L(;:H9!`PK&&QS&>O9;"G=_0#YR`1TR*1NP_?@/>_Q>]^-5GMA8W[
M913XA1=HS",>88B7`2JV3.E+E<+7S'Y1L[W/?![$7]`7V'QTO`">_)UOVXH5
MT\Z=/B]<*X)S/MDKA4V:0+6;I[9TNA8D*HPRD?L`O"$6U<34O%A*L2\2%H'1
M9PL8R*4#GJ25>-`)"OM&P,FC11I<V6&^[AP5ZLJT(2SL,IP&"-.9&%G'0Q"G
M1<(C2Q9MJ7)[DJV,=BEO_'N@L#2SZ/V]AL_4.'_]3`^QS7IWH`2[9F,(\@0S
MK7EHRR-)2R;8[=W^]<<?=O1^I=&A9(CED8EF*#3L$U_K5W3QC-8-H;-`9I0D
MIMNS=CUN[8CN`Q:D-".=K?>'/NQ\SEL*$UKZ<P[,6.WQ.NXUKB%K&[E^MM=Q
MV;%HEX1@GJ-^&/H3_+5#:QNID"1G!1$Y$'#L2(!H:;T5D#U:TTMY=%PS32.V
M\[E=+:3X]\G^W(N9D,1^0];X$-!&X-!2M/98]_NPZCO[*EMRKD]R(A?EJ?,D
MP!MR/Z0]E3N@0CQ`],TZG@)=L8027AV^;\#[=V:![47+K2^]IS\>@"D:5S7A
M^03-_B()^XAX)8[$MG&'L?6[B0OW8,\6BP%X]`M<>M#'\H:X>->2%;Q`E^/!
M[]W""AA;8APO2AVQ:NC.(L0A]+<V2->!$PO>QNE>>2W4P\)2S79QB3$-,:7,
M?)\_W^<7=$N9FJ86PZ$Z*$YE)U";I";7B_INMX8&1P@C*YN]T^:&=!_G6A6)
MA0(Q2U9=YP>;-I)%$.1U4ZY2%"`<V8OHR@<LX`M<EE41_KH,[U4`MV*BN9`#
M3LWN<1R2"H>B38H';9K*`DXW[\?IAQ'\5-*;\<R/M87A6.76$N\?,Y4,>)QT
M#Q$J<9AK_E[N/T@"H!2'83H_:K69\95BLZ,N-DP=*&,H1E+GE(SK<G_A`;M\
MOZSY!WU=%]O$)$P#2H97'21@(:VX'C8VCG[&@VY5]K7N)/F9YXBU^C0G$)#_
MZ2S!U\!J!XE'`XWS''4\'PBG<!P$/?D0BWAQ+=+<3RI.D8?_XEX?)F[74+"&
M@HS-\!OP_IU9X+^6VJ5A*'^X&7I@S6J0O-D`GMCSXB\]%YX>YPQ\B8<4YRY/
M'HO,I&1)P0)*LM$%()`'C7);+E7LH9<3G24`U*"=V:K=^0H61=*^#J`@4RVN
M#@"4PJ-#4W5KDAW;XN5R9),XE]C*G>PGQ+[.-2\,*R3W.9?69L@=MEV8?&(8
M$6,W"S8:CUL!:_!HA"'P!DV@",LZJ0)C42,]W0!2BI]KJQ]Q&*W3/<'%!@&#
M`)*LL?ZTS8O<8Y[2!6C'X,G04T87@>2<8"91LUM[.W<[CEYV?Q"*I9B8Q[K"
MZAGE^\.OAXC![[#).J^ASS_'`E.TKF&H9H+@:.$&[,$Y4':/=EZN::BLNI<Z
MTB"F>&#S,^;!J]AJ;?E.BJ)%9UF7ZB,TA^F:66'?I<!Q2!],6-SX;$=FN'+4
M]`#$LJ)^,+&N&3T8KK]X(<P3BW:U1M^KY?->=#DL#'$9:LTY)Z%)0;7K;5[#
MQ&Q_MR-Z%IA%7)W7\FIZ047S[,4>R_>X.$"M]DQ/GY3CT\_U;-SSWX#WOP-D
M_R(YPU=Q;Y4#@31!('`WMT&?@.FO6*6]>NS:#C03CZ'@%:@L4ZST$08P*L]:
M%VNOIR.%5&7+K)DS@U>?+1$6I)66EE;GW'@Z3L?&!0.I_*YRW[?*$X\)-RYM
M,3E7P2\V,UP:2XIX>'$[\AB&XA2,%R;(Q2%B<5QSD7?5&?("FMK9EIG%ISK[
MG3U@#(Z(,<I.&Z7%UASI8!W35J`RV3=B\=&7R7V:$G\0WM`%6('6A)2OO%[?
M5EMX7`-4/0@L$0-[K19?(S]3%5!"9$L?L4\NK!-"0>3B.G`-*;8JN<D7&"[`
M1`K!T-DJ8729]=.BR94!+A[JUMIDTQ^OP*K+C5/MD?A81(4_I!-<&.(19@#Q
MCQ;_U*1K'M<#A265%DEI3X'1.J`&V<.K?+?6EA*)#0I]O(>=9[6CV).&>X:9
M>`.XU^6(?`Z"/W8@3G:8X=&Z!%ON$I'MEZ.G>8)JGQ8=;H%ALI<PD1!AYJ1R
MP8`4-]@P9S;=?;PH;%:'J)BSD;<\S_,WX/VW__H%*O;5]QWF[5^0Y6Y!IWNJ
MLK*:STJ+!^Q:AG\1J*^^=NR0>!#*221K`3ZY\@?B1*Z)Y^K3]CQK0SU;\5AD
M*]WS`)V`(<V,R7*"'&"0#1_6UN*9DTCHQZ7XN<YIR^P^JG'BHCV6VG%FB2EP
M]_(>C`OIVM]V&?+7QMN:`/05%1VLGX(7M0LP]QKT%K9#?CE*O'RO0ZV94K1R
M&`"*LLE4E(;8YCEMOMD<G<";DV<>DE9N,V`T"B^XW'<2QUUD22<I`JST4&7[
M*/.6[*V`TW^V]]-KMUW:VG9K9I_DQ:PC\U=[MT6>:VFT+_]9CAZ6[^O1US-W
MAQ(`@,H%LJYQV99Q&(T5S##,Q)-ZA=F8#&NM8=BHG\?EPZJLKP5-[;POO![4
M]<LO=P6Q4!0\ED<X%T`=4>)`.GBM1`L@ZFG`%L7Z4$F`U.]Y3?$+"XH<IL$V
M=QUQE2&GDY#[&?7_=0<&8SYM)32&D`875M=?)LM`G\'NW2Z#7Q=P#(-^3"`X
M[7T[<;5?R2'+92'#`CBV[2A)XBSLU,3Y1CW2YO?K1;A6W#_G/3,`]7?2VG^$
MS_UKW\K_W/MZT4)Z?.385\H%$Q"34G[Y4-U#A"_J7/<`&A?84>V48GH_/3-G
MVZ.O.%(HHZDB6-//B9?&(YX->E0/NM*D68P%./GL7I/M0#%`8I'4\Z+)&71H
M16OXU0O&+?D%!E*^L+3`YX2MV'G99/V:>V*(DX5:\`[ED]4N4#%B:N/%66$$
MNG$T\NKD5OL,4P@;L=//\J*[*P1JQLE'RJ@"NH(N]O0LL`XQIKC5GQ?;HB4#
M%HHD,=N,G87-0*&[E>W/9TQYU3Z>R.`ZIOO];I\?'W:_W^D\G($I[^_ON44+
M?8[.>@!S&"[=YN+MRM<ZLVY16UR>5X,4""GTA+M"DZEGEY`FSA*S,#&GWZ=#
M3ZPS)V8MIEH9Z'%[SVC@8M!M>R^3G(6'I3P5%B"@<Z7E(3LR>K)F0V`&O4H#
M3WN.AR3"<X`OMBK"O7`5U9Y;-8NT][`7)7E0/'<1P&,F'(^@DQ&Q/:V^+A<*
M!;XU_XP"E/(`WOHWTHQW[9S%J8%6;`,"]CM6#'I'*,*HXU94`,+OR_D.%FVQ
M\Q0ZKK&0\&)04.Z%Z]^_`>]_&OZ^Z##PD!<N;\2O))8]?BWB*OK"._N?."?N
M]3LL7S^E=-U-AILB4[J8GC!!/6--EY?C^8`W.ZR'!*Q=2RQCWDO2*-HT5^$L
M`9,:9"KS=H$B'\#<S;NOP(HZ(=EF[&II^>/+BY*TI[.X*.C&Z*\+GF)VLN0)
MKVUSJOT<:NJ]RT#1\+^<C&S\?)R1G`PFYG!4D=T^[@<!K^9BONP&ZX<9O$L;
M;[:X/=@""=73I0AJOB:7&QV;O';3FA1_X%A+H0HBL"(=R:?FD@L(E.U&9.;:
MX@1_]OA5\_ZP=KG6-0RL![C(ZPCK*[O>E_3=CN/0P44[?:(_/S^O>%J2^)C;
M_;C;_;@+@SHCNZN`@KFU^V*FX1+\(MMF$*)/D<:MZ3WMG%RI[@K'E5"HO?!U
M_9"")"YF-R3"(WA2I4$[8'JL#K_C.DT(RK+W)3Z5V:?-$"J&Q99K:YSUEP"2
MA_!DB=$OT.OBNC#T['/XU%CO;:;3]P4SR8RVW,_19*MHS;NER=Z9[.:I:<!)
M\<$Y`<'K7>4J`U&R^PD_5Y,Y]B!W&?M2;+T@;7_SNZ98D!&9?*+>N9:Q#`.@
M*%])'3P_^S`DZ0[;00K,+,<BEN;9"H8VD6F^#"XU$<XE,*@NG0G\7E_F&_#^
M5X"N?YWZK`WSONHR]AI(!=ODX"&0"IDK]0&13&D7#*KL7O2G#""'VGT=*^IS
M&G(WFUZ@:IQ%N>D;?53VY[0'MIH>!0820[JT;6[>CX*9\*`;[('!7""U7=Z=
M1RQV8&(>/S1MJ-AP`D9],ZSH=,P6`BIF^]6S[I47/V]MA00XL5B44M9:LUMK
MUU"$LKKQF"<3W[L8U\^SV!:[:U<+%;:8,A]L>3-K!NN]$0"J]8ZL=9X1EWY]
MM]OYW=[\S8[[<6Y@XO_*]CSJA+"&I-K\R>2O"B2YQ;P615RI&SM`U#ZY&ES@
M:=A1@)_7Z\%XM!N!HSRPZ*(!K-9`=AI@V<CGY]WN]_O\F314.<`05#MIKLX-
MXK5*@*718)^%"%,K-V$J,)P=!3PYF0C+&>12K5%+G1H]SL-2,JBTSO6N%0?3
MP)?H;5VQ?(!VSV)[2/)?+-H91OWL<B`8!6-'OT!/;4<695P@X`VH1W7TJA5F
MGGZ-O^^LC:>5V"_]Y[I?:L>2%`["P#-TV&<=;`SZ-$1D%;60+L.ZYRR%FS1O
MY]K%;D#1"8/N@.2:87N[3=;Z<^=#AI&]ZMB:#(].QKRM>Q535NFBW?60>#'#
M/EB^]63HFN4(NFVKM[L)485$'HTS]PUX_T._?",0?P1'O1@V^K.4JA?T*OO<
MH:I^'QJIVW/YP@-$/O893KQRQ_*PW'PD*%$*(<FL==/IU=)3LD]HNB:O42?*
M24*8K>;.=>XZ[R8DYNHAHC2VO`;;/-@=0)LQ0+?>W<A])[0*(_,2FSDF"U1R
M%TB2#!<FN!]]#OR`-A#6@G9T,9\?$_QC96O6#(V-_TG7V%9_`8#ATF8N1GH=
M\^UVNX[]D'\W5Z9J,"9+/WENBCYE+"H)X/OCO`8<G5JUQWTE-`%FMY-T[T=?
M[<A^2B*$(+8>VLU(K*J&(&3WC%'L86-0G*4#6<"TCJF;#@2&5C!9CL7"ND,W
M]KTM'\JBBPN?^?93@G2]]CC6/6G::N?C</)?8Z@S;*LXX0OBH6S)BBN7\`3J
MFB=F]:R9KG_S\6<KV\_5>C;?WT&*5M\OLY6/*Q8S*$7;5?A+H(3MV_[L61V9
M8[F.+:;%>6+5H^]L=>SB(K%Q%-%B5_6FR0+,Z\UHR1BRAW,9%4^_^J8XM`OL
MBJL/[Q.!M#AE+2'@)A1FPV.9R05<G2F_Y!C)1@VV9WJC4Y"II_QZKM0=IB6;
M#I42M-BU#-T*:RX2GGR"G;I.MHD2=ST.+5&IZ#C_MAG7JY#ZM;,W]C?@_8_#
MWI>)W&S&_!4JV+>^DHJV(HM3;5I%NLN+>%:>P4>EW&76[0Q^:CG>:D^0T?3H
M(@X2IIN5=E&LFVO,E(`V?8J0M=$*+J(^IV$[(,=2#1"Z&&^[#K-,0_L8OG:R
M%K##&EH85$H(W#@+/9TYSXQ;G)1VEF,0.#Z.+EICG\-$/N45,DC@;D<_)DLW
MI`9]NEDLMI1U;P/L\N:W9-8N0'FP8=Y\ZM\FV.U(*50=9K?!$(PH48\,DQ8\
MO/F/\W4+$HSSGCW#/)V9V6;F(`TFL\5!2J&;*))DO(<!.G$QBFR(Y4(OZ0A=
M+;EF["JY8*RYIY"VYYYZ.@B<4!50,%*BYK4:H79=^?#@$9\"5.*$MYNO8M.I
M".WSFRC_"1VTX8I;=)C=EAU3:,8MKU9HET-TD=18#D.**N%7^53SMH;33&.@
MK=!X"YOFA0L$5,HEIRH.%DW'A9:&EBJ6V#<%#G]NM4%$V4P,VY#B!02R0>.W
M'CLF7K)ZVB[7U6XPPQ&<&G1P43L&GACG\V6\9N5KF&1`QL.>ZB*R7A/7@L+6
MC7?8P23#RI]6YG^X+W2Y0"[Z]8!%JECMP:Q>'1N_9F?,=$A0_!6H2/9X0\E0
MK\O`MX6?KSR$ART@RW];^+EOP/L?E30\'@Q*D:\E<K1MKSTTLI/?H8R*5RU+
M>U0EOQ`G_(#@E>$;I/7HA0$Z3(%[##S8:8!WSL&CVH9\=Q3LP;6XQAD>6@RA
MBOQK$U$M%VU%(?I0+;<L^&_BPI3=NS!,<U/="/5C*Y*E$=',/K.\RWHH@:<!
M=B]0,5AIA,2X?OFB#JG!<'PP1,"RBH;C`KW47U]R`I:/7*"SM3;##/P"F79H
MF]<\%'Z5SRH;T(/NKD)^8I>^C=E0]URB1H#`@,V+029N^U9A`BBC"6DP1'Q<
M,R!:[)W&E$8)Q&)_%H,RNQ1!>+SLA#ST=37ZULGZKQ?`5<,G($XJE1>VR!!F
M_1>\JM'U._*UX.>2/ZL'H(V\'FB[W>2^T<'`2!A0=R?)T%R&,C4(1<$N)SZJ
M'*,(HE`QKC!=P@2>(I^IDYP`$M`]9+>FT[8"\V"`T+3[<!$"HZLN=GSF8@7)
M]PWWM\\.4K-XHJ--'$I])Y]SOO\Y!*4>0I2U`B;#?X,L:79UO+AHNQQ`.`Q'
MDO2&E(@E#*4TI6:V$0#ZB6?+\2X!QUP$L9;8A=%6/0<JP%D.I&(OKRC6?]8X
M2,+ED`-%]BUUO7Q%.A,Y@L(`_AOP_L?`[FO,[HZ,!52ON1=!A#6-[<6JU^()
M2'V"9K''WPF,\2*&3$#FBA79^`SV6*"^@(ZE!VP/I)%K`9EXADR%1IJTFJXO
M6]27QC@.R/3!$L,*+14!8.C4_<XX8VD.5V;ZVCF0TM+<LO<R2SU`8-BF0\%!
M`"*FKYWMW0;8;>AH'6;>!93`V\4R]K2@SL5OG!<KK'+BI+&/Q7Q)'1K)(LZI
MXB[G,@(.]O[5)TF]B9<]TV#I^V*O;Z=G:@/LF)(/EEVD=5@W`'-Q]=`P!M)B
MPS+(ALJ%],90<!1;H]&\8$6'9B8P#;J%SU;PU>?!L#0F@DDO!NG2[4W'T@NO
MY-/2S*7EZ@)^E7&;GL*NLJ`E6^*B*.(L".@P\Q!0$(B((OJ-0?W._L^MN'<6
MY;6*[SB93T""A%69_;\`V5K2U/ZK,/'3\\X^7FYIH(UE,*J?#K=-91.&Q=+-
M#@A0Q31.Z58=>A&+=Y;/Z;7TN#;&XK>1UM@6>&^4O.B3K7<]7-=[<#@2>)#W
MB#X7V1-I>2FO>80I^V!FI]#%`$(*3^)F=I+@:K,&DT%,0^XPR)H#VO.L2"5*
M_N`D.0E!2?&UL@]3(51Y9:_.V'K_;\#[=P#$+_S`Z\K?O^:S_2'[7'S.*QG(
M6]W5(P;Y\1&Z*[N4<NM+IO=:K$(JXV21TYY!PWLT:#:'94HCXDW>I)E88"F(
MV,A)`FBO;,E"K]F2<;=8^JRI==D`F^>A*-;##J8X!!Z4EVQ*/3`MQ[AUS@X$
MK+LU6VTQT%3N^DZK%0D?C@EFQW'IE&?B55N:UTY,<N_G-#CJ$(K%G+HD\BV2
M$]D><BS&8YA#;,Y<@1J#3MDP8O<'PM!6!70Y@,/`>3/D9J%%N=+"0G2J+39_
M2O3:V-0KZRJ_G`+Z5>0TZJCD>_NQF7Z0IB"D2Y5@]P(\O'G30$YL[YNK51FS
MA.I1BF"]5VW6@7WU_0*TK*E<&=R-!1@_+^W2^QL70.:K'<0=B&$;%IET'B@J
M-'0^!%_9SG>"30:&G8:1U`7&9*#0@UL&KX<6(G+Y6JO,J85[&7-`N6*X*PLY
M]RH1,P[E:9=T.#8T][1_C<>A.T+19#+P)V$<LJ]?`W^S`"GL)"/DI:[C9,:]
M[&=*IV%%^L)XDJ,*F!(;3-HON2.5'VPGMXDHPPNVA=/:D9[G]+P0`8$4GJE[
M+Z#GV[*#0_N&FW\-</S/`>,O:@'^U'=R>MR]?!_?MC!^`6G#-E6MWO@\.+58
M3`49T^[H0;8C,R^(YY.&M_B_TTYK6/ZXB5&]?#W6IXWW:1Z&PTSUN<G"!6%/
MTM:7,\M@7CA06*%B*7W+M!D/5"$Y)'WP`L!D[V:Q#D/ATSHGOKF1L*8_LH?L
MVACY=`VPZ][L=KN=?[XLW88UU'$<EZX6=>`!*JF#.@_P,?C.YBAV5PJ)B`(9
M#T$H&F;@5J<NS0*%OL,\UNC+"V7M^#LC`MCA;#'9$TUFBQV!)?E`YL2GM$%9
M>;>LKRN?312)CQ([NH)5O/DU+(@@MX!.X@]]]OA.O2<`'0'N^+P<<[R\BQN[
M#W0H`TH^T.+G.AG^!:X:^6^O[Z\M8/33$4%-_UL1HG#)J)Q;ZKOU%MH)]SUA
M4:5P0<)(,NLPU\'"2[?<?5H3V=/\?:?S"+=:KTO1TLVG#$)G!Z)EH&_N1"RI
MCX7K>MW'K,_F^_>4774E:#S/1GM(24I#?<+&NMZ/%O8L86+S\58[-DBF`8_S
M+VN7[Z;:>AKW/O_-U^?U:WWKH'-H=9PT/\]Q7TG%+[/Z$IYC">1+VQ3?26N_
MSKK^-T"X[V0,^&6$&Y.%8[NX\NC\M?-41%PF#\4%BE!0#.YL[P*-8;T6TQ;9
MWC`)FB:E40RDF5^66>UR8>@33'*PP6C5=SRPSW`:]&K-VAQD\B1/J=JZ(?QL
MSO?*!(1YWL!,I0%`(%$"\^)\[FD8+^]UA0!X.XOHPF;$=B]@&4"$P:46-H7>
M.07/4HJ;@+G+=6$`W0[0<2#9PKWDO^QZKJN6'<1W.;#B%V#L%]C1UFM?P+@C
MS(JY#,<\7*^XJ.!)ZZH-'<X=TD70_J=,X3/[1[[`.9RBCHVM!F%XK8G#4WDF
M`=0N1SJ73NRFRSENI/"!2$K82Y:M`:NH:8XI9O]DM^4?'N]M>'8(Z/*>'I(D
M6+.LYR6N`_+Y_-P@=HFX#>;9TLZ+CC@R>.4.\HC=]2&#0J1)D!*Y%A.-S3W@
M>DVHT%6+/BV(O37KIB$,\YB@LQM5K#4HLER=!%;"6B/G$+3!_K:E1;WNESX'
M9/N4CB1W"%BY^)12&"S8NQ;(-0G6@^690>_ANCT;AID[ID7:#`L)H4J:)JH6
M<O+$1:65.+M`AD.36L4ENBDU+X7U]9C\NI)HAS3._%O#^\^`TU]))ZXF*9^)
M`RJAOIO8(ZVA'3S6*0Q1S```(`!)1$%4\C[D;-QV-;0C:@)KL#MN[`E\[`PI
MF.#?;]?-?KUG&_Z;EZG]+BF='LS;K4G,[>UV*]MB9RMX)>-4U\UG(((MX^RA
MZPP-EKBA3H`??=&9823-X60?MIJ3[*L+-0:=P+AW6._0I%(0.]9!!N<Y=GJP
M5!!MX%JQ='9N324/=JY=WZU/4!'2UXKV_OC[WC%E&T?OUH\ND].\^-[>WDXP
MW`^YWO?[08.$Q,0[9]1G=(S>#<-FSNE[S9A8"E,)A4DG:`B/P"`G="6`X':U
MM0O;;K?DJ:``*81M\'JP\QYCT-!"R],5U`I@)$_G+O`F_&IN(<>#/#?=9*[&
MU/+*W!,K/CRBEV]KDP%)GQL[0GXYV9J1GZI(1&QX5R_]?!R&-;)8<SKPT6A-
M$:M%>B(#WXX^C]>O\Z6M\M7Z;H.Y$[LFM3@D\\'+38/BB&,H18CK[?-:$+#U
M52`)\(GWA`UGC%4X39$(IV<&BS`83>4W%XNV9&47-,H<3+)BI\>Y]!"Z`S(]
M/W][L-77#"#IITD6^/SXE,FAD^^7%UB6[?H*LF$]3UP,K6.VX*[ISGKE)7$2
M2=9U!)V`ZGD;C\^_5F#78]#^B95%_R/F'+)_\3Z/1-;$B*DL/8G=2.;430K"
M;\#[[X:VP$-8^!*.Q:OOOR=UGWY.6,`\)*G`\*>#+BQ4AKLCQD.&&.6P5(TV
MQ^)_32)780N%'^MQ=+,KU4E:WB=)*Y/IS=T.%&C`)_<SSR<&4"P8UOS%K\C=
M2XL*@^'H4MWS1'T<#UB5\EKD:G9[@=[!!'79R%=JT1P^\L!DNI'O)QU+4P<U
MJ=#=TF=T`EC=SZ&WR91<K;$QX-?1K:%-=J^S+[.[`<<)V'NW?O$][![`X/8P
M,_-CG8=V,]A]M=VNX9-A;09R'!CGJZ-K\(K3M1XT6[>41A4'@Q;NS(RBL=,&
M@H_G&%Y!'B3AU#J[9HLL&<ZS4-GH&M.V&Z26<0`,TGV@8JJ8&(<,WS@Y;I!G
MK>?FZ]CL.Q>?:=+3JT"S"[31H".Z')M:U#UHEY&=%0@D,>#KPZHN-F&0T^RR
MBUL5L3J>XZXMZ,"RCV6\TYLV^'@"SLZ!DUG5=;EZQ[+_<M6/2Y2#$Y-+,9U#
MQC'G&P")RQW>US/FMSB]?,UG,F!;/N5L!;8&*RTL,)<;3K(YH\)NBF#:Q;AW
M,[0X!Y4WI*(+-`H=G\=2@3H,K8JDA95A-QX&&:$VHVO(4NFC#@UBX#6@5]9U
M!BD^W+/+S^R0H.IX01EZ[K0]=;LHGATKXH`%Q:+>M_ES:2WUT`4:__P->/^V
MOW;52P:[:<'\$Z`Z#T:YMA6P`['Y[_*D^VX#L9G-NY=HK*&K,I1B*YS8_Q0'
M&YPA#_K`(^2NGT3M[62S8GLU24$LV7IU7$SC24FP?>CEZXH2](K_:J"!@%Q1
MKRGU2P`!DU8G.Q28Q2&_,Y0#3.CRT(F=+@B#N>Y8[(`,<+%8S0M?2%`1,$`V
M,W?=K-]`/Z-WP@#`SGH]^NYBVV71?#[H#&F8[RQXE@/%\'IMQ?3X8`9'R,1*
M\>KK/K7H]<R3WZ$M+3M_3/>.EG[:;@79^L041@\L(4S]>5?ZFT\K-W'(XN\N
MT^26?&"3W*$:"B*0Z48L\00#E^XQ6Q),OV5-G2(FB`H&::^2UW($JV:5IIF?
M&5>M<_+DNJ0*W:2+,H?*+F]6IY9XFD_?!`");=QUC6>W(J27N:-,9T.FY2^]
M,_$<0=LZ&5TO4B@%0`8;P$Z//77=3S_ST;7)1;=VL+(#`/@>'MTR2K5#)[:7
MPQ)XZ'>"N*ZL*IHXT8A[R\P0M@)`3TZTD.-0F]WW&Z4XQ(2_8[)E=<L4V"E1
MF[$"BKU]/C-="VX/\:(2QQVL#.-08)25;>5*"&X8GN<!8#N2L`[9P`:0(`ZQ
MXQOP_@?9W3\M;'@J&#@G*2EONKP9OD`%1^/K*M3`:E;$?2?+"$D[B`Q1!M+G
M0N[[PXXQM&&$%(:58D.O6>ECL/N=%@T4S.^U\'6'W6AP8$WB2QR73.C/8`5*
M\G+VLZ%-FW/IXQ`$#)M(44B2'Z#Z7O@*@<"4#K`4@MA@MM#B3R76RAW+8U?8
M-$A26[3S0NQ!CQ@R*&LV/[N;-5_GJP^Y!6#>NQTV0MV&VT`(S/!EES39BA%,
M<-GO=-$5^A6W:10;:W+\(_%H;(R]K^,""=U`L<%3_D'O.5KK8"G!Z**+Z[N3
MDX4%.[)L3\9,[`3L"+(E7U(4JC7/L][S1`^L2BLLUCI^9GJTV\IQ%=%7<[6@
M7=86EJSPYYT.((T`>)!C>#$9_FC9`Z1[X;9TU3ZI34_L@KID#;WD"ATYT!-U
ML01>2YX0XX%G@EK']$0NL"NM45:GUE,H`>2>,6/3A"E!#;&O8XAQ^&Z?UE^]
M\&!="SG3)+ST+H";6_=\5R/XHC>1DE`!-"Y9R[9Z@%*G2Z)DY)_=^`&8Z]\9
M8ZXL8L[:7(!ZNNX@3#O`@L474JPS*-&0`TV4:!C6?KYE2DT$B"$)C[RU.0Y:
MBG=Y[G56`[7?H5SKTCBH<IPH;..BE[YGVIN*\LRXHV!WHR>YV;>DX=_+T6[;
M8[8'I!'&;A/':M8R:=QX@P@;9:[`"G]#R^E<5@Q&?96MKI@'9E'J[[U6XHVD
M,+0S3-K.21D4<^,M3]G&XQP+H1AB^QFGN**"6RF5X$'`-E*[PEGJB->,%P.?
MOI&<PN2F$_HN&S@MT"D^)]Y5BY7M8$-]->C'I2T^S\')7IWMS&L+\79N4"0Q
MGI*#(OD'LJEL%L5BX3TZSB2ZRS6#>/<S\6AL6D,6`LRB@P$4#]-%O>EP)3C;
MO"<P:793YK[W,J%M=0RLC.TV*SH:,<X3&H3!@U`C5<P\>\/JXY(C9"$@".E^
MB5K+J,5=S'BOUS3G:S889,LR#@3++:QI>+>JD.9V<%O7CN4>5%"4:VVT5'+;
MMV$O?>>I_]?PF3B`6;6SLZ'_`NJ<>G4F]+6@!P?YV%J2ALPA1QEJ\WK]'396
MK*.^XKTU!*23ERTE7]GJ)G22)RB`4S]S=D^_%L]5P`V5#[W>6R,I72ZD=WLJ
ML\D2=RWWZD+RFER(F3;HETU=M3<*44%E&P?(3$_=UC8R@-#U"X.SLAZ"[B&V
M8.-PC>$$(>ROT$D4=L*D#/_.V?=AOM[+8Z:!O.9E##7;,,JUI><S2SG6D"B2
M'>,:FIORP!"8$<F6Q!Y3<,N_#?!^9<[J?Q_#Z]*,>]E_]M$*&W]`&([XGFO^
M72960VOA$9#%,TV#A04/^W=)@REX(+?P_>=I"P>EOADD"Q@>G/O+0^/*U.KL
MZ&;=<X*5N<H0!!!#O=A#VQ<1<LM[^#4DU^PX(*WCH?-E)EJ#+5U`^/D>ARRH
M`\"/(1YF',;F-W5ZE^U,:V:MO=GM9A/P2I!DV##ZQ7"/5MDY\->E7=::2RNW
MD9<KH"VVZ77?K_>[78-N8?$=5G*#H;K<2J_K6##_L=B0PO-B%`FP+1LL3*].
M:=WU7K*D$5RQG,/C8!KJEN#\)O!0%B*DO:%\1IS(DZHUZ1L/:65E7EOW.+V-
M"=[F:R"*AYN23VS110!I!RVP9^C]`AZ7?$B"&9@-)7X[M&EQ:6OB\RR@#DK\
MGDQML^:W6;S/R."9/F:E.X`EJ9:7.\0`PJ!G;=K;A>>#K<B:AY9UA\59VY-)
M7:!RAAD,!X[F*G,*/M,PLW;SZ<_-UWQ>`[>\5K#=V'7=F,"H"B#*NA!6%P8!
M5RK#T35D=KP\M^15O^`4'QYMV9R(T1RW,!CR%'5?75UQ$'.QG%NFE)?3"*UC
M[N'G9\"$*Z7#<ICK;V>A2=]5.Q"!:N/"%1O_WADEG_4PL7".]>>X-SHPQ[I3
M4$X(A$F:W:5/NKRYSW/S;P.\WV#W95N%AT#P^3FN8P1C*A&JA*JQ>#[P%=5C
M00"5CT#NKO59Z"8<IM-/N=V^,]M/,:#6:PL6Z(2IH5OOR\@\A!5;8?6]0$Z'
MP;MLE&`?3BN"@-P30!B,;I^^G<P":[L'89%BD=H)2FVU4:F5R0QK6Z/F2Z>Y
MZ)4K!W[MY._O[]9:L_O];I^?GV1;1FN8F35KAA:8*[GFIPL"LR3G1MH)M,>;
MY&0^VJU-`'.0).1V:];:;3IO]*/;86ZMK8UZL+EG^MG-[+(F8S![W.]36SBD
M+[KQC>\(B?_UBW83QEA:[T6$9F!)QGMULBP3VRAP/&F5C*9/FWM5]Z)X5CQL
M'%;$7JGBP$.;$\$^C@,KG*;JNR$111QSVR7@(?AI%GI)39ER.6\,K%3GB-1Z
M%0JZU'`U&LBR0FN(E4#%8,_:Z4<Z[CNTZ<20VO6F*GH$KV1TK#A=#QI'9MPM
M7C,/<,KG,V'$%`[@TEKPKNU=UVI7QFUYSD*ML\)],'!:[RI6@VF4ME'`A#=7
M/V!33?ET5`!T?B'Y?1>D0BJ@"E;?-7F,"ZF>G&DMN4VXZX"WW..^.BISH#D*
M<8.E.T3JPRQO5[E8,>"ILA3/X3=N4D3,1V_*JT"%':8[QRRX:*".;1$Z,ZR%
M!W!5\%LBVV+1*R52"K.I!O&&U(&OS[>DX=\G:'@!]F,K37B$C?&$855UYT.%
M0=%.C6_DRXMODZ#[F/W=@?/B!:Y&C0DT/V)V%[*[,MUS*#''\BX@UF=H`9OJ
MPUA;J$X*9TL/B3WO%X"[4<@``\ZI4QS-]Z'C[#T,+#B99L`^/^\+K+/U$OS<
M4,+@5P0EH^U^O]JRZ<0-T'F[G=K8ZYP,64#23EZ;S3%TR7U5_6^WMTLOO&ZT
MX^@7$PMA?,=GB-W8=;[/1"FS][>WJ:D;>MAQ*=[?S\_Z^/@Y!P(]F+*;+P>`
M^_V>I`P?GY]+<WU])S8Z7]?E'!8:QWP<AQW]F,PU!$AV2BA;$_+1?,MA\]]2
MD=A!FFO7T!E.#2.&CQ/!>J6MO.YK3_ZE088@OLZZEO@U:.?M:EE>PD_`=9>]
MK($LN5`0<&JVB8W6<U4-OW)0@WD[V:3Y7J?&-`U$A?^_GL'%%G&ZF@6?<&>K
M,:@,;!Q+IT6AAX;4NA<RRZ=.)HB23%/=;V`8R2F!I6Q]6K$%:FP"V.4C'F4O
MJQWMT\&!9R$2^P_5&_-:AN1BH:UUZ6I($=*"?9;)&LJ%S"(RBJ*&BKJ4PAGT
MW57ZWPP>*MA&_O-9R'=R/5!K.:?G"^(R'FPY0T1WC(7S^<!2RA]9GM4$40A>
MN>088Z)9!#I0:8BXLX&_@0K8AR-%<UT_N%/)^Y?XM,>^<C3C32EW0Y"A75;I
MG@:K9O\&O/].=M>_"'1EY=@K`&3B`%MF=?\9:V@!!:NC71SD8;)7F&OLP+"'
MXZT6S4`O%?&\=4@`M$T5WC.U!:_7W.]W>WM[RXM8.BW1YJ9BX=D3=@&3X^CG
M!MSU*$;D;J\TI1Q:$!<PF`"?WB^)PN46P,<S]&F]]Y,Q;;>Y0##[V)P&ORY`
M]_/GSSFH`I%DG!*(S\_/!>2O\]F/P]S;9(?M8E&7G&%EWK?6+L_;NQW]D'L2
M5[^RM</>W]_F,%F_P.#G_;"WMV[M=KLVY9Y:TY,-.6FFBR&.]Z:VDMW'^0JW
M^\66']=Y'-?U2&#W^LS3-XN`9RZ0-(DOVDSY]DX4(_G8RH]K#PUB6FB!)M>P
M![5W%W:N3V]I]KYES6`5HI*>+FCKM$>_5CEG$63H)+8PXG/@B(,I2,PU]-E&
M'JI4U`_+LS@XFC(A7%GB'F+&\^L6BSBD`L-R3\&7)B\.]P=W/P?@W,17FH$%
M6^ZM9+*@99V2VN/LH!!X'C(3F?<JD]%<[F7T<`\R2VTN>DZCHHPUJAZTU$;%
MIL>"3*0%,F4AVE<S#]'-Q!:Z;3NBMGF^A)28_K^KD]9L64!ZT:U9W4=/NF"A
MJ(VMN=H<.+1@&>EK,TD`/B>9J?ZU(MCF7E#ESGCLNI"OO$=ID.OGA$QE3RVF
M>/J]C`FMHL6C*1(0OMFPVOL.GO@W<;O^.#H1C['N%N<^DTH\AZ)C4:<&#7:`
MV9YJAO$0[*KUD3V&NIG[W0@$%>O#'A#=FXHYYZ??[_='%_,:I("8J1NJQ6*Q
ME^//O?>IW^.VY5RD0I^M^EY&#!1_)QFLZ\A3W.'[#[]3_C`4`X#'<=C'QT?2
MMP*G?.+'C_?)\"[M[D139K98XMNM7:QI\97<[7X<=N]];NH"RLSL\_YY!G^P
M==4%:O[X^=-^^^VWQ6@)>%FLD\_VWXCYY!MN36US?&Z<_1I,U^?'A_7CMKX_
MM.5V7HM\/V*3L)3G1O'@_@\N'/D662"_>$A+!4/5CJDZ,9[+Z=@J13&X)W=B
M2`R;0+'WD#S6@QT3R$'@<DOIS"1%K][AW8H@R2ATU)0JZ*W%!IAJ#:F[P#9L
M<IJ:%[*CS89NT7(OR)FZZK)CP9RL))T*.(8<+`_`TN2Z&T4_N^I&95`MWYM`
M[!!5NEY]UGE(T0T%WJ)S,C2@KO9YGACR\QF\3>WL915(0[YS$-=Z27HD\`<C
M0&7)U6;N(\0:@^T78[*BMREYZSV`:AKC]6E3>%UQ:>=3"MYD\H.,:`YWF03<
M1"M+35Q<7V84OQU!;*,*.M/T5<PPEEBO0\XA=VMH&*TJ<+C(\+6F=:/DMSG8
M1G-(HZ/A*W!E&&>,XN\;\/[;&-ZOO.`5U]C]#"Z^\D%E,M8V2*E8DSQ-G.\.
M@C7S>"39H-34Y$+A507XQ"+I4<`'7KQ>U^?>;K?)>/0KM>O1.<<U]=L[!*19
M@`MNKM9-J(?L5$Z2(WUA""!9Y0S<XO?6MC?/_7ZWVZU9AYW,[>4\@,"JW6XW
M<W?[^/P@_>JZ@>;PQ`7T[X=+NAH;\WY\?)ZRDA)@7M^WXTI+.Q(`/X[#_OCC
M7\H,#[]2,5FW"6RJ:?TD-7-M9[);PM%QA5KTTBJK>G(CN$3Y;]DA(8+,J#D5
M`Z\@'4+76%*781K/GIW3A[4"JP5JAR7OS51@8@,T(VAWEDVPOA$S,TD+HG.C
MZS)-[L)^]^M^KYPXV.^6]89K$$>+]BE/:+;84I;GI'A?IX&Y,00:&+@0A3I9
MYTXN$]IB*"Z%#HRQ&54@^(5E@[EH6##8^L'ZHZ<V_VCKR^1]8$)M.*-LUE1F
M'_MLG"`3.I==X3PO<;VE/<@O8',P\`/))V:2F%I?3:X7&KOMKG*(927FZ1X9
MP*RQ15KSDBF>]R0SQW3_]KDO4(SOT#23-F9V@^B>B]'EG/!8W3]Q.%.CR`ED
MADX1=\&D./!B7N8Z]I$>N=P07=+?*D>>>3(;64"FPD3=?IAHA!+K\NL;\/[;
M&%X\9C"_AH=?B@A^X<BV>H.7WS.T3"RT%"/@)&O+O2("CT&^F6W/)Q*+A1JQ
M[]C?A,[U('L_V^93T]JZW3_OQI/[$4`IL,.FZ+"B399_O;V]G?K;SWMZ/T[R
MJ2(S>>BD^4I]8YLAIX&6GS\_+\>%OCEO?@VV73ZW8'-O;G'K]#S;,0V6ID>]
M^.XZ7UK,STM_6W526%=LX;Y,R5:Q<`HLE#"&H=4XVJ?WHR]-^/23AG;H*+!%
MATX\^;$:Y;[KE#<T(O;ZV69!:@"333R=6U<7E@$8C>0C8P@&DN#F:G''C%8H
M2K<%H&F(@VC,73VC$7N1ON*E)XX(A0$[)$0_XN74I*UL_A`/^M`>;`#7N0]%
MC+D(,]G?F`M<UEJ#&,OXN'=*J.H#"$9@$IZ1LHB@82)7`H_^>X%P7U6J#%QZ
M"`9Y!$PVS^[./[E5GNW7A>AD%3;`?#]`ATFN.49IPAAR@B"M'C8.9^#OV7D?
MVD^?F&H6W.*;VR]&EMP/'!0S`:SOLR)^3L_ON.-VS)8Z)SW>O`D8GF_;C.0Y
M:ICL,<G0-KIC8QLO%XO"4JI!Q<R2M4!BDCWX$_/C.F1>PRY0-?%NS<BE@PKF
MJ:M&%,S[:4;!V1VNS+L7.*+%K@R4;?X&O/]AAO>K8%7-JOQ/O=]\_O\B$%XA
M7Q0H$PD]:/7]["A*FR-[(:@Y&%37[5L%\U&K/`:3EA42@8<-GF4]FGGL4J^-
M]/9VL^;-/CX^U$-TT;NG35`1T:L?R8N@:=J8T\]<VL$.!EL+9!U3"QS-[Z^?
M=S,TGU&Z/70!E4D/[5AB-:(Q_!P_\*"_\@7H^W&D!"JPC,%L6J:9),S]_^Q]
MV98CR:TDX!%<LEJ:___.47=EDHQPS(-OAL6#9%6W[LR9['OZ2JK*)&-U-Q@,
M9D'KF;46S#)_=I*^7RT`U=B:%!.FT@>8HB+-%H9@1]68#`08PM9-H+5K-?LF
M$^]J.7I_K=46G(?43F4V%64OFM#$,&)Y$3SW33T/0$?6!BJ[T!-T7\B$6F>A
MU&P5<V%R,X[%ME:U:,93@%IL&M@RN*6=+]B-RH\A445W=;!KHY:3"O#(Z&R@
MGK%A*:"LST1H-^#%2IW:-6WLXMYD(&(5GD)9FCZ?^Y!L_Z[JS*)]:VMP!A,E
M*59E&ESI\VF:_/8<6^LP"[(DG,LPUG`RG"3040+#BL0:5/.,,$$'!U$#D6@]
MV-_T#*#*J=?JNR&L6.%4M=B)D%V%Y15$\XFT'VW.VBE#R=R4Y8+N]`09C?W"
MX+$1:HY=A-/PXV9-T=8M**G]D5'^@&61M)R?Y!8@%@(`KGV\R0!4,HTM-I&!
M?>"5_`:,T=5*,5,+'?Y.6OOO@=U?]26.=;#OL\/,Z:F'[1-2-V"H</V?>?=.
M@&[4"C%8Z27Y1M`FMJW]^%?XF/&E(]E`<'YJ\$(O4"E5!P1@?5)*M*1EM"]S
M5M8J:*$D!WH,:_*O(R9%M[.E#*JXYT./$#N6%&48@W75S\.\A3EO^3.P>,,=
MS;3>$M-]V^I`TUC$<P6TUMQ>5?^!-FS6A7%V4/T'G^?""P4LGA'P3K\;!E=L
MG"PR,R(\[2;U]062GA)#,IN5(X1=*/8M2S/Y3G;S;\]:^^O,2@O=(WD!*+56
M?$9;)7R/\@"YS;^TN9QPZTCTUBZ[(@&I'[&\;B;G.^QD):!-UL->R,8.D79C
MPSB(!F;R16^H-0"Y@.YJS;M;[<]W&L.MEHG-RM7!=A[LD)R>8.PLG6J]@Z>K
MT82B.X'6F;,:8FK.'LVE)4/!AL61J.)7E,^M'O8*K"![@`0K;_D&MM0`'6D7
M!.;ANB$A=X+%D`T&(<J,Q8]HMP/TM^71=>!$:F"S#P&FX0S3PT+4.1FRAEG;
M]1&IU%`Q>B[FHSW=A$693HJWSF2WWB6"@7$C%<('674/P%M9M8@)"](!RDD1
M)6)K474JW[9D_TT@_+K8X/#WY%>^D]E9W,J+GX>Z)IDRH]'Q"\UC->2(9!W'
M^*Q*D#>NJ/QZ\1&=-P?@&FUKG+EVU:0U^["\[R2+T%H="$BRD8(,EDP"VR(F
MGM^OR37=\]X'R-`>2-@X_^`S8CQWQT"2`<8ALQ)<1V.^H5KHUO&)VD#AT,SH
ME!W2?I(D<8$36`]%IEW>`2/2J09>*-@NI(.-P+*KV!F1@_=/Z>4H_.^JQ4ZB
M`#+C1FVI>T9-XQB&L9^!THC>V&ULGF"1PH?%I2Z"Q+#\&L1C9V4X*XAR%5$%
M"I/3'[MB1>G)>:Z[)M\S[7('T>X`-I7.%7@038[#<0B`LDI-.UHF01)EXJ*Q
MAR)2@$!=6HJEF`@M:0%VN]WUK/2;$@Q.BNK&B?8$)C_@UT`MPY!O3]NJ13ZQ
M2_3M1$$V1:!Y7(<,Q'1\]/6(NS#V[Q`0JOXDBXKFC3LGTJ.[&7OUX%7,">0:
M*OK=V!$J_U@:9(BWT%7=6F:=C8;%/RE/X1;R8I-8O2Y=@'5RSB^I=A1,5VZ0
M)^4*=HT]<_@^#06#U'N.B82D4^BQ6XGS#2):ST[Z]\34--^`][\`=/D)8)-?
M_>`70/0`9S"A_L;'1SK9YVC=+XRNLN.8`39=N>?-V8._FL2\JU_#EV)4T.(_
MP^!;81/XP8%S0Y]X+5Y'SERJ>X7*%.RH)+=@F,B2OSQE,(L.MC-.V4SD"YFV
MFK^6;?-*?2I7PB==7NA\%(NT1+GJ82W0]6S]/%2%:<A-F)N'[ICR=F;XS$_?
MS^@98&;_/`JK%J&:5K?<.,//,Y5^L3#$QOKVW&@I"FP0K+LCQKX/M7.Z(AW3
M].@YC2RCP(;B_&M!"L,@G]&;L;;64L5$V#'RCULT8(:A&6I8B\?$*X9YJ/?'
M1I\J(_LJ01"!C=]VK[2$"37,.+VN[-YZAR(-]LVY]V#O-JFXY`8L<.B5P(8I
MZE`@L=%.8P?[,ZY%[V!O[1I&RI-7F?@[+(XZ<U:L.G;#<@;@9`KV;-[A`I"3
MLG2T[ZH#BQ-M<X*!1:=;5;[&.,K)KBO@HK`I!I^J,R!>RL%]A@(J_F:-1V@K
M1\,YA"#HP8#\/MQ(8UA.K&<\H7\T$<DH($.[2_=4BM9.$TJ&V-DQZHW5#Y4E
MZ&)@!RZZASR16VF@K-E;!?)5\3:>O_0-2?_9?Z9X[+>CZ.2%6`L=QRLB;W^O
MMB.)0R5B;:F$\H;6SF&:&X#VW`8^XEB??7=,Z4Y=(&1R53GX2$S%X?@@%%@5
M"(VP?W;(=`OMQIT`)]A-DTT=YM&4M',$"-A=BX7:0>6<U3@O#F'T%NB!K&=(
M!],8C`CO&V:IJTQF]9!P8F!_6I1RZI'"Y*Z</BDV<@;[6`X@9.@#==2ZK8H;
MY&!H01H`B*FU/VTK6)06TQKFMTE^?%@@0:ZY'C#!OTQ46Z?"@Y'JFY_Z6=A8
M0'?.B?7FG_1]$WONADT_&G@*RV6QLB0>+%RS4.KO!D/Z5Y0$QN;=J">7:D@%
M05H>=+0R>*RB7+1];DHC*8\3]PGYW"VA1#%XC6E%1C.+'@Y2!0,\CRZFVOG<
MA8%Y`R#UD(:LUQ^"0;H*N'L'2&DK>Q\`&/+671AK.KY+8O\/X]GM3L;:0<@-
M]^&`J@G`R`@L)_I@N[:R\8"-.D2]T,E^_Y2CCJAX25T_?YD3'%WB5->N87&I
M0X5Z%Y%TT8G6E1GL`6UQ9'W?W>YI?YZ\OR\G#J^M=B<:;3L]]T#5R>?@6@3=
MP:<8"N<A[*#-MX;W;V9SW]'''@PAO<(3OX5;A5X$NU"5824=:1MMM4L4#JRY
M!2AJ\:K@!0ZUQC+=%:,R`$<[Z>DBI1G:UZ\/1_TT```@`$E$051M#_"8X&-K
M/J\89M9>GK/R9:_I:.[9@BC+TWJBQ_WN.M[V8H6Z56O\?>A93#IYS4ST:Z!Z
M_"2G;ML4EX?*Z8(M\\XNP6ALLNS,ZR7JFW>6*'"3Z`F#0CDWID9OY)3),62I
M=PU%&_:K<7GS7H'FFDTK00UA`,,Y?DR"``0VK/S8%%EG":NQE^[6(4&2%NOT
M&<L@.:M"RPC9:&S+NDZ!`[3-LV:P&ZLU6%/P6C9MF3Y$UUA!6]`T72OS_(%E
M_8ZD9`(32(>FL)$&H-=O\^7.JF,C:O`M#+8Q$@-;K*F(6U/J*<:T!B:P98_;
MZF\&:"40(2-C2`K$ZFO8ND'9.+^P"2;0;7CX&7S/$W=MJUV@TDQ.$EP?#4SU
MI<57+3',)[`Y-G2,8`[&K[G'-MO]4+&8UO7(M-2B=+>Y8T;5T-M.42`[T;_/
M`>G$/AZ8/8G+IJM0#MVT&3K3H5NL7>(BXJY?N(=8R0\%D@<`MUJGW9LFW__\
M/X*FWV)EE5N8R`M\L.V-ZSC%$`JR@[=DG1>$,#)6?(RL21F;N/].P:XXKHU[
M5"?3\X]**=&Z+B&8]?2D`<\R-)RLB3O"Z5?\1"00$_,APE9!$QQS^XG+\9?$
ML2!VNC)9Z[K2Y7Q6'^X-O^/G9+2`"^-\O]W5)CF[<KU]EI(:KAIL;P(V1TQ+
M7[.0<\9]/`3GTXD^/JYT/I_I>KVJ]AT#Z.0:)>T97=ONTQMAXB+#8&;7?5"T
M%"=B+@QV8@]0QW4=+!Z;XA"M=,I?ZO\N-<Z72?OV($/;!KJZVT5E:;$OJ(NN
MYEJ0X-H/R4C?B!JPK]_7AK8X[-:PV^B+Q1^[3DYC5-F`%#)V7MH621P;CJ`G
M&W_F9VRS2)#2*+JX4FL62BY,Z[S?V#ZN7SXD@<<P0WMW!#(+/`^1-MQ?7_UW
ML-:@UZH=^'*LM[AWMW<XDI&LL-E;>`RZ]0G_P346+7'0=7-KCI![+[%8XJ!8
MP>(_6M_IR7.)U\THR+167*S;C*@E"'V0]:%X=PW]/K%K\S/S(4%4_C,?8H1T
MU%%AG_06!4"0S-QHYIU$9MVM(#'?P2`MLK[.P;6>'1M/K1^#]Z,U=+Z1Y'\=
MCQ*]`,3<D)AY$?B%CQ5H5[W*#O=6A`U+")+%XF$U4Z]"&ZH$,F3WKWMI1$\O
M^10V#[BCE\[^;=@!R5)!XVHL3TC[_ZF/XQA_<5P-V$C-P@:F#E+']#E>>C-!
MK_8"AM9@88:6=1F5-&QFG)B6-,Y/G8JAA`W?.6TSHV]ENV+ML^W@GAN&:"U6
M*2$6#4"B?$%)&9J','@&,Y..&6W^C"G1NI[H<KG$`,;<1X;*']D.!'L*1*+K
M1DKFV;(-]7$O$"0VH%<`;"9,OQ`UM4S]YPA:\(P4)>.$'7>)@P)H?7H&+8I$
M74^]4?DJKQU_`P^)D[-N0_F(+C2XL]D-2.-S(+`;,1841F.AKFNU?V++"I+6
M[O9AMZ!5BZUBM9[!A&XDD6ZL7<[B`*.6;R35%;/7VPY?C0`6)G0^B<)-D(44
MM6;P86L:B]02=R[^705PH`$>MHR-A1BSZ="QEU9%(22!>X5B>H-T,*\'U^EN
M5@/:]I<\Z_HX!ACOCZC4,5V<FV-6\<6B`+1F8"?:6=9N/UA083&EGX<H#9%5
MTB'JD]D.F]HAN@DP)F;U3#/HGTEYH9,K&'"?=<0;*X7?2X6HZ/\W!@,9[!+;
M_F>D;M;#_/N?W_AG5DS)$S+U*,9>0=MG+?Z#OWM=.4=AE*10H&T];/^+X0P!
M"+276/1_#_]5#3_#K(9.$T8_:&C@R*BZI(%M11IP.M&RI&KAUMBPN<W:$6_.
M7*W(4K*FA25!AJ@Z)G`!JXG;7J<8.)_1AE9D1<NV[1LM::%E7:&%1CTL@VL"
M$BE@PH%62^;M5/(V25ROT6@QEN<G`:.K-A5H_>W[3D)"I].)TI*<IK1\AO&&
MA(4;A95H?=6.;:M!%1:(N`W7/D,,>EMIWY;*OYPH+3P6?BOY`/`Y@$12C(N(
MUB'C<%=KT9?I^E2UDC5"%)/9#(AKSVI[;J$2&9L!C]\EYG"UL3[5V#I6DA*F
MH$`9SQL=O#&]H(!BADQ!D<D6-.TZ`AO-QYT%(JNCC]DO9F\D+0:0.]!9BYX9
MVR$"[7UFO5[UHCH1#@`RL6;&^@DF58@>ZZ`%K-4,6(7?P_<3;0`Q-ATE([E%
MB*-/LO/2#1C3_E[J=;3'+P?QUBI(ACRX3K5HLG\N.2M933:>P,T76P(@U=Q`
MT&=[6.CYHCG\?A(7;QL_'N.=L1(+^VYR(&'@`\:W=^YZQ8*$B6B&MOM_9_.^
M^+4>KW$6<1[E4=&0)?@9L*_H$DLC3S@J3+R-HB'5#,F&?]XTS=\:WK^-X7T:
M@_#>Y\V`J+SZ>W$+7`YXX9EC0+/44D=UY(X0,;UO'.^S/V?;ZI+9=Q]<4]@Q
M&PNPI*6RCM1U=@U4VDI?:"+>!8;B=%J[[G7;-TC-*2_@]BBI9JG&]<Z>*V;T
M6263U$7T>&S]^!/8`5&=?-[WO?RKV'2MW72EB@4_Y&6BV,9C/F;3D:UHWWF[
MW6A=UIXF-^Z'0#MZN%_T%KW1;S,\IU3!]-Z?65^("`PV*%-_](R?Z6'$I`S5
M8THZY\D`%*Z.'$W;R2X.F#'5C-'\7HR$0ONM-G"3H)#AP%JJ:8$%M)'H;#$^
MNP"USF"KEOH8>.H`?G9]U8;=CDU;;R5*:B"/I5E!46=C!'Q]T25#HN<74\_,
MN7<PX";NC5^KLZ71H0W^/1GR@UR[1<IK'-O8&#@`SB+HCC'J(P[6?IU8EJL?
MMOYKZTUJ)M[[<\B.N&#0R?9K&_CV8M1P8^Z4^T7$\!WM/$:/W]:`:$G,DHLN
MV$33#E983!N=P]T(6>E($XM#9U'J[5$!HIC^^LXHMY4.>O5[T^WI@F-,@0X9
M"YCAC3Y6V#%4%I`:UL$"M;3R+`BJ'9^X-8EQC3'O"MNV\,2(1\(]T+[GABG&
M;E/<%_ZV)?L?E3.\!(I-Z4ML\A-?^7QY`23#`NQ*;NU!&,LF',>E`;)QOWDV
M'#9-!-;[2'@PRG/4K'1::ZPWO,((;$0[^1`&DQT<7E/S?N4L]'ALG2&Q0TMM
M<=JVG7C?G;V8&BX5XVD,>>=ML=D>&Q'O.A%.M&0DPW```6#"=MSLV=`M=!?W
M</A2B+NG)06+B`J[GKVUE3A@G]6`2]\0NU]SL5WC^[U>;Y#E!&R4-M<`(,[H
M90S:0,.",,-P1KM^K#<TTRL'5P:J"6J10SH8UI./R(Q",,9[VP`+!8,=9H!.
M@/T5`,4IU8*#5.A&!SXPA).S3+L;'!A8]=9H2C4ZMP+]*A$H.*:"J%[<IN;L
M5<$XM%5A2"O!QDW,\\V2]/`6%FR#$1SG6$`HAZUG,EKB9'QUG7X9]-"-<6)&
MR40<%YLS.I:8G+L)#K"?%W4<1G=8QCK5[@^L%^/9S8YEQ.L6AE_@FH,`U124
M&K^PZC(-KU;N!07ZE.,U91.8P%J/XG$0W*-LF5+U[EGY$IO"3_?[>A(@R$A(
M6J(:/I>XEI:"*4/,-\I>4!JGHJ&%E"6:6H)[0:6]DW6P`ZMNP/!.'@5O5KIL
MG!.">.KZKOAD4]%2(7@7(@]W"B+DU=[YI'LM*LQ'DUO?@/>?E#D<@;I?29#@
MYS_V-$XT/,ZY?RKQKZ?$'0'"5PH`.;J@_.S$/*J>66"Z%CY:$06?RWSPE0`D
MF\,"D1EJ0P9`ACNR"V%0QRT4VM[VR7`R5D,4%"\UJG9R7YS!N"V(C&2$CA+@
M)+:2$],^9;*QH]J,P+4-Z^\F2"I"\+'ONY<Q..:&/><Q;@B`7Y/F%D7H,CM&
M`3=$Q@EN'KG3K!CRZC]*=BA:&[^7?4)<"U$S6F/0+(LWGL888B:,BHU,Y&%?
M[ZQ>"IDO'3K`IF#1Y],!-(">A+@_T<$`'+N)_J086E:@R;&2QOY+;`&'7KH,
M$>%0)*9ZKSR8]J$D2H\-#C@%&,P3'+M.6#VW<MA1Q.*'0P#`WH<\2."S_K"8
M<*"67_`G5A(CH^MLQ7MQ;,C&"C&0`,`KF\`#6-ERU?N;NG]P5O>H/]<M8MPF
M&C:@A]'D+10$)`Y:4M"<-<J[W)ZT/6<E#<'417M]]@QL;5_3V_LO\,R(+X",
MSK?=NXQ=.Y[=<W33&1K<'##?ND@A2U^-Z/0LQL:0E3G#6,]8D2I%KB5JO6O7
MEGD.EG``4SF.&$:\'4K&5,YZ#;X![]_#\;[^I_("&/X-.ED.T.\Q<!4?9=,^
M)X73!=,T+9Z@\%=`/C\#[OQZ*IWK9XC\QMU$$'E\?R(L+L$OLWLFV$$$D:@%
MY`?!F+0M$8GXVF!FU65AG"D$^*U"3@Z9WKXA"(7M0R)2QO#A<R6DSA'!'PXC
M-98J6D7MI#_9T`03YF!/R5I(%</\/`8#K:T6.4<=#1!;LIFQ\+%3]^%SK":B
MK76;9E]F271Z6&>\9!F>J2Z+0&`4:`M'$)*5'B#@YQ&`PJ2"!/K`%[*3J8@<
M!I`!K2</Z8353J:4ND8SHH9:"]<.#,9+K8!D0^KQZ$CP)E=JWY<E.^LM$B$<
ML%?L9NW@-;!K&5J4_KAN6)=.F,>CA5]H@E^UR4><<P5P:AWAV!W!=M[:L6:M
M'[83_<V?>#%V:>W>MZ<]CZI,G2,68<)$+!RFP_5W%?I$HE/#1T$J,BG<I`-A
M#$W@3AR*[L"VHADI>,EJYGL/-!_<_,U5T(2$`Y?]6C"3,>+L[Q.";AW&(#X0
M!]?B/.X1D[X6R(!G(IWJR(.\P%YA5K:*WA.8`@>2"(*$:Y[9%S(41%T^9HJH
M;\#[/P2/G[DLR`1,R<'0@I.?O2-]D`F@9M\:F[/)P9'S5'UP"#+EX!Q5-/>K
M\<+3,`2.-<X2WZ_#HH$/&&6)R?HQV4NN#E=V9#R[OJSLENRB2`'8I0.F7U3^
M.\?,NHW<-:$),[:>B0\]AU7,+HL)V/#7RH)&`D"@&%YGH$]*SC#&><7I%9$U
M*7&I^.=Z(^:DP486Z0UX(G&+-QO0P)!.Q#WR61NILQT\,>RN8NN$`0RR_ARX
M9ZE+"E@#@.;="XQ/`7!)@51+S3$PR$.G2EUJD6AH4:RW*BMV4""R50_;N'9T
MSGV0;`0+D`)R^)DYYW`U$IRV%SW494%1`[U-OH#M=5>,A?5W"QE@9X'&$*K!
MX'J`#%QC0#-,\F-QKQ+SZG]F.R@5%C\@2.G/`ZXI^IXA"]Q;VH:12P#?4D\M
MD6!Y%F/M-1Z>_JY#F[[]-?K]II1BWW;RK7V[)G,$Z`V1H9V2_)X\W`OR-&")
M[:+*4#@NZ'!#FO4-.BIJG4L4:I%UIXF>Z@+8?H<0K0L''1-1H1]6NL+`MB;3
M66OK^YJ6N@YDG<1F/I/,N=A.5S*5K+(LJ\_--^#]OXH3G@`EQ]0:QN!%Q'S(
M[C)/6V3:DY&F&>]B0;?93ZR']3,MCN%6%``YDM#*2U0LA=?0>%?[Q8'>3,][
M=J.14;+`V[IXL'CTV6)+`PE!E/QU!/YG[@P3@PZ,8)N>MFJQRIP1MNPN.3([
M>'!,8("2C)C\3S_\-9@`4HQ=')",/H_=*Y6YLX?]HXUM(,HN.G-LW4<48]PD
M,RW=0L#U89S2B&(%#5V.F.5QP=K@E=HD`&B2P?@16\^<.FW6_`:R:C$*;*Z^
M0\#DC>RI@_'!/RJ@*ZC%]`;U=FBJ/',<%!9M'<L.]+6A,V2FN;>\N?O06J=K
MM$M+1C^JV6YCYHL2)#&ZX"8IP$AL6\@BJ%4#0T(F:FH\8XRL+@P>F^"`'@$;
M_)UM6V&P0;^/("V(UMDL0Q*@"0!V/LL,Q:92W`OI3D!_]E(H!QC7AM204P]X
M@""<2,X0%04X4/PTW:T-MK*7>S48N"P+72Y7.IU67<C[R40']B++-SZ@9V88
M0FGO(U*U7L/'OM&2$MWO=R7=V[>-,K,9#J3`:W>L%=?+A4[G,WW=ONAQ?^A9
ME>9T5R;)B8($P&!J!\Y=SZ9\`][_)J"5=W[O(!Z,X99:C8U,",XCR%<7(+2=
M&0Q"F@)J)CN7#NU&CA$W4Q2.<$29QA?!AK%Q!.#EB3L%6A^03T6S60%/L>L+
MS*^U=SK\,)^#3+W?A!J1"8!-`4OQEA:;_0!)7(U-#,NQ716=OTH@JI&E%$AB
M@-G5\RYZH,KJH]6&%I1FBD4$8"IVR*.W^;)CI)J>LRO%4%82L=Z2.V!%+TSE
MJ>ON@PQG!]..KWU[_:RQ?PVL.X5*JR,*$O@LV"<5%8M#5`S:=72,4!I7@=:Z
MLG)"_;"$S7J1/"W6D,41<W-\T\HZK2#@'KI::FWR]FRQ=8.`9UE*H41]J*[:
MZB%CC,-?C16MWFNM*R`R9#%#3PQ%;0?P0DK2Q!QZ&Z?>(0#P)JQ4:XS/'>OC
M;6RM<FP`!,PI33R"M;Q`:63QG>K2%0GW(P5=6A>@@]FD@3V!OE=$Z;=MR`/:
M5XF52A`Y=C$"NG:1M'^>L-W>"[3AR^R&&!/3^53\PY5EG`F?4`$DYMI;9I2J
MXXF=ZTCU6K9!WQX$$4%&)N=UW]_<G&DGHL?C40`O`SMA0VI$,ZV6A<U4+#H?
M]T>5T^AWFZ6-+0]KNNZ]WK2_9N,6_%D`]M^`]__:?YA"#P27%2V_1B/[N?DH
M5X)RWHVNZ/#H_+2_3%B_$*3YFG_F'O#TVLVJ8CL!;%EG>?WN/`7!C=5[QS29
M(F#,GNXW+2['O`:LQ)%-UXS\5=4V6>I[8N0.K="XG<N>W67+,)"R3;=6;-%&
M-BL`XL0>U'M%&B#N[!MN)?V>`F?!>NY9@W[+]-ER`08DA<?S(I2=-$EW4&04
M`%E79;F#">[#0F-`9#@=R,38']^[/L*76'MR-H#!'"00!B!HH#P7.(#^G^K1
MY;&Q8XL=!U:ZP[<%[(&30+=5@]9XUQ2*;K.B99V:*E?W`PH(!E#CSI%)4L66
M(UMB`!.UWFG0UUQG!NN/PV[(O,-P88LO5DR?D6HH9X_4[TU:4@\?DL!9IMN&
M11(WRYI'K!N#0XJ(CCR>%'QY+S(%,@`>V^?.LUX.I'B3]28@L%7'Q'4Z)VN,
M*.<*<BL8)ARNRTJ7ZX7.I[,;&U`R'#B>;%K[#&R_,-/C\2#)F4[G$TD6>CP>
MQ#5MDVRD,S+Y,-AJJU_;L3M?+F/(;]\U%FG'RTSLUIAX$^Q^W(92%B!.^O5@
MW<T[LD?L4>GUP[\![^\RN2)_WV?A?W-^IT=5\*^X*/#S8^FZLOSR\?-SW!Y<
M,VN`&GL'6N+NZ?='@Q,FOE8G%`5)(#*'Y4$*IM\`A%YPE#!_P=%H&P0Z&G<&
M>>:'?/",AF#7#,>%+A%/WH&PF<8'3(EK-9*R7HL>+MSX)&=_FM:6B8PIOIA^
MG4N18,T&&4>+X3J`WJ<:I8I(<-R8SE29.(:?;6J&#J@B[RF&6R3=<FI(+\;-
M;(N^2,2JDTI>$CO50Z2+"?*%=G\?&)*/P`LVUX$<M^%U"8)QHN#!K"O6L`A;
M2R$>/`<Z\4L7S>/R)5,`)4I,79;1&#H<KFE,9&Q-AI91(\(:#X%-8Z8]B]U3
MEGRX13N.#*X1MF7=K<((C10X*.Y(;?JDN@MZ?1>T4,3W:'*M.2HP`O8W(A_:
M,7%D(\?#\[D56VS#*\2SKVP*#0[6?`=:9\T5!%L3LJ#]9XJZ6<QN/VC7+'&B
M];32]7*E95G&$N>8]F%)F?>=]FVGQ_:H;&VJ@4-+T4DO"ST>#_KYUU]$1'1_
MW$FRT+YO)85R6;L_?`N)26G1KA&$MF4<KNEXWA\?'_3%3(_[W74&HZ[T;,"H
M7<-L"LIP;\VYVSKB,-V0E(ES8VF5YC?@_4VP.ZLBCXC'ESC=P%C_)7NP0,;P
ME!^-G+\GME*Q%ZZ04?^XBQ&H3_T,_AL@/AQ6IU]TOHBHZ`/M[G1]M/?JS>%!
MN\A$&6CN$">`W'HKOO3],*Q6@%/6L(9IZESP4N$3@=7`?U/%<\HX?^1QU,;;
M!M6L9M2U6+4YOY9L!$,@@="<P3F#E1Y78G:<]>.M6'GH4F?0T^JVNHSN"DY;
MTV`LQV"8`8B]8:C;E*JSP1H\J><O#Q"L-SKJX+2%TK"+&Q;E`QHM+^CAB@$8
M.1O/6F#N+3"?Z2L',2!@E\1*3M&>IS:(B."S?7<)H,%!P>0*`.M089_[+-I*
MBT`.,[HO`L\WZ@^U][-:GEMAQ+Y;HX(E>!1&H\5+W1[-I5[U@B.KR.BH0Z=F
M)W!(+@!YN,B$>R=J4H$15N^3MP)WPU46R/LZ190^-'YV-/`5BGV2>X1Q,(CJ
MC5X*&[DL*WU\?-!I7<.N*OYNSD+[_J!MV^A^OX]D.!I)>07X)EI/)[K=;C7!
MDRC?X=W/F1[Y041"]_N]@ETN@+<.JZ[KVB462UK&$&\K_LWZ+R*TKBNMRT(/
M"ARBX`(GD!UAATQH>*Y+L-$*Z[6<#P(X5#>"1167[?O^9L#[MSBV_C_SS[PU
M_TN(Z_#GWQIRF^_7-!42!.S6(;TY03,RL3?@P_.9"22.BHTGU\'X$\4QL',_
M\NCZ\^3TPXG9)S=`Y!@16CTBDV:)XMO`;W<=+'X=9MV!%C:"XE$K.V@QO6)-
M@BU.>QUG)+D:3'GKY0W.D3&BDOV]JE(#MD`%@&]"%M->F]Y#UC*`-O%>\*:V
MUB%(KTHN$"4;JS;+1EM)A50++@V:G:[6;O;1\`]I0_B<=W6C$+0(G#>:[F.:
M%OHCM[TRD\3O6&!,/QLR0A9RF/63"X)0^AOC=($/B`8Z>L"G/PN8B)CC-"X+
MOE71IX)B_!"1S(<7-!@+$NG&H"/U8HJM9MUJ<%D[3]@77TSBQ2QRUOV9`N;2
MY1BB],GC_=!;B_3@D'GGB$G/P)J9#F9O1S@F?<=`X(0(MGZY7;L>$!]M0/1T
M/M/'QP<M2SK<T+=]I_O]3MOVZ-[B*@*Y#U66/V]ZVFRC>(.DO!(:4Q+W<."L
M'3\ST_E\IM-ZHF59:B`&=$SLX.NR4%J6'O@S/*I)N:(P1)2KI,$^M+>6A,R<
M%?MOHY.CK<3JG7'8`Z4E?S/@_?\'[+Y]65ZH!2*P]$I>P]%'O])-CPSZ0R'!
M+.D,?F`VE'4$&*,_X2=_^I*M+K[P$[>TQI2PL&_;']F,P9^P<0E@6S=`V[A'
M>+YT_)Y#M_/WGHFP*6+'#Q"S/EFQOQM9;83`US,V81RQ\[LTD@5G]1%,N@=>
MFT>:=PT$V'/JS,`&UF?!#E$Q]VI#V5(U76S_>QO7BX$9A;+(@C-J0IR:F;K6
MUW&U/NNY]%V76<:2^G54^E?K6M`IGOYW2K\XL4TYTBFB\;S>4/1`E>#&(Z)!
M2+,I0M]0$0#N/*RGR`0='/QC(VD=@%+,TDBWPF=>I8=5']\0K(+UT9C_DJZ!
M9>8J\P`7!R%]+TW'5_#XQ5@F'K!<^GZQZ[N)Q*$5$6FCHZE)O1L)XI!G0\&E
M.",3`C%`%=JMX9<JQPDR8P/F,440)^(#%Z)S*[:".[SW&AACL27*<YG4,TA=
M<J$'M"SQ@:$U:5GH<KG0Q_7:KT%/VB-MK_=X/.AVO]&V;8H-=S,+\`QDN'96
M0VW7/>;QG"(^W/?<__[S\Y/NZ4Z7RX6692%>5R7;0<;[=#H1,W<6>M]W8.B%
M;"!&DU6<SF?*>Z9U78K$8UWI\;CCI%]8R#+Y]+6(=>]%'XBVOR4-OX-CWYEP
M>B%P(M(`\%O.#G.<_32LP9A#\\&7'9F=S+[@:,AK%JMM72!H9IMU=$T/VOHV
M!4?><KB0^)AX"D<[Y_+V#!YAH?&,"1<-M%]@6OWPHXH7,Z$/`CI`#V*519@<
MWZ"^$-MKC78,J*2(^X3!A']D;#(S.`>;)O+>OUI(+]T+MY<6,@2:+=5'@^5V
M<LV)=&AWU::K9`@C\E<@>B[#P)Q@,`6;H3.EN2PF#CGK(15.)JKZE2Z2F<!G
MT[%H;)RZ;,KJ1`_@*'6DDE@DS)2-UQNXO!9XJV,44Y"1U\KV<`BG`27"L`GT
MY&W/J.#S;MPWT!:PAV0$BB!E9V=TU0UX.;_P0-+AP8$YYDEW!Z?_59'HNF2L
MUZ`NR:G3\GG(<O33C^MD#+Q32N:>2/]SL9TX8\6,\=#(DF/4+3JR:!<,NP_J
M8>.H;5Y\A[.R##N4-E;KK>O'!XD(W1\/RGFG=3TI^9;L.]UNMR)=,$.C^KD9
M]GJ*X030&[*?%-H+3_]NSSM]?GW2:5UI67Y02LM8FEE_[VE=:5U66M)"7U^?
MA:FU0\#`JB_+6@;U3D/WG^IU[)(-.S,QL6B+=.O8;4,]<?J&K?\PV#4OP,MV
M7&^H0WBRR\\EXK/?%PK,&CSHXJ-SE.G)/F.A+41X%>SJ+WQ^QNJGY$TZ/&Q:
M=4+*3`OK+U-VY?+"-;07YXDF5SQL]59B'+.\HT,KQ]IH/N#?8='U#'\4.*&G
MWB.];'O@.&!5B+2-TO36N9A;/22C-+GBATVHLKAJ6EI=;P8O7<U,.VLN8,T:
M..M)7XS1S3+LN/K-82>W\)Z[`U@*`!%W/_+0,>:`.?7V;E1S5:4/DV68@NX@
MA<?GMT?!2%Z[9KK_G_%-;I^M6_N3SH<Y2/LY1R#+%D.E;2RJBZ2?;3(#:>-Y
M'Y(5IF4I@T#H+4OF5Q1X`D#<_&_M,UDV\/F`6P,4UK$BPWT8SR0PH&HM'!64
M""X@)5(ZBK3Q'L?:1S<?2/[Q/</6>I^\1T<"4&):1P_E7F1D)^U9U==,#-,I
MYAC9;TIVP^C6'*SL$/&[VO>=S^?N:I!SII\_?]+7UPV>4Z)M>]#/GS_I=KN5
MW\U-=C"&U_KMD5S_#08U6:<0JFU(Q+R/XL"OBH26\AX_MHWV/??B)G:O+_]Q
M.I_H?#Z;SYOA%&#/.15IA"E\\`&UUW@\XSF6,0GI=8;D&_#^ZC_,;]!T;[.T
M\EY*V@NMZ]>^FY^V#?GIX!V8Z/%;EX">Q1C((3G*!)-!SU`YR!S$M17UNQ9[
M@QX>:63A$.CKGQ4,0O/%(@*WF!1DDX@],Q2`AH#AE@G8G474]G;?P4W7&X],
M>P1BL^%E7C)9JR(<3)%)4>2!O=G(51#"V./:D,<XEZ"ERA!4("VF$YI^*%T`
M`"``241!5!Z+U/YN;.7X_3F+VJ14;*899YP6$@`D)%I3`A]5=0X-W&;<N<";
M.%L#?=:Z@`FCV,&[U:1*<PF`D(])D2?FI6A,9;>.RM*'SAI#BD,L[?\$PAO<
MFRBQ[A\70G&`0B@W<$`<`HIH@!-UH,H>SLQI.;!LDP<I9O<:L\G=YS7YPKP^
MF"6BN;A^4)5[Z.,?O]\`=<X:9'L6,996V/..0&\O@!I+Q^.-26#-Q0PV=0"$
MW%";NT;FD<5%%[H6=HB.@YD,-J$+E\N%/CX^Z':[T9]__DF/^YU$,NW[7IC0
M;:/;UQ=]_OPL$@8"_UHFY;2&LK*(>.I%6T\X"]AI>*\BLL`%_]2?O3\*Z[QM
M^["M0T(`?GX]G8J?<+2SB="R+&"19IQ)TJ(&@[6G.#L6=[9V";P\W\$3_R3S
M>_`'S[2V$O06?U?#^P9E3;^)FST[*;]YG-ZG^CE+'$UQ'J`O-3G-4:W!$TC.
MQX5'H",1TGZC_(YKQY/"@!68UY&S8O\NNB^"?5D`;9,IO&<#FV@C%`,RF78S
M;"2D#Q*P;3N9%J#B@T.=;=7\T8M<6$2!#C9_WD,=JE5Z::ER36<CG6O?]7"Y
M)[TEY710[:NZ3,+,NT%`@O2!.H9!I&'I9,$QJT'U81<AD*(F+[ZC.!$]0)<X
M3V4\-ABQ5_I<1L_O;**>V4M3M/V;E[DDD[S5D^(P^M7$H$JP_K;[DL6Z<V`M
MR/X19PB.8"-#L5T&=9X!DVEUT,%ZJRVXM'BD5BKZ$X34Y'SYW@R^R0<:8`SK
MF#P</2JZRX6R&Z12NE?H%K@`!M(>U"/2._7CR1,Z_9F&&>5$=KN8#=Y%>289
MND"7\YFNURO=[G>ZW6Z4<^Z@5D3H=KM7SUQQ&EPE=5`LON@U.?0RU^$_B9F6
ME$K1T-C0*)FM2:V&"-O-`]SN-SJ?3G0ZG:;A)\NRT/5ZI7W?Z?&X=W9X24QI
M6>A\N52_9Z%MWVA)@]E=EJ7H[O/N-+E-[X_OLY(-D1\H1/:(^=N6[#?PX2NC
M5XHX?1THOZ7Y?2Y7D"-PVA;E%W>XMY0<!D#*:_NG/_CIL!PP3F3LJ$CK]APY
M`Y_?[7^?73-TF;>M/0J=;O3$-CE9W/%]G$0&3Z^E.9>CYY%?N7G@P<MN7"1^
M#YZ%=Z@!BB.1N4G!LZR5>-/+P4J2]6!DT\H<X0(((3"BU(51P$84]==%8N-\
MD:@U8:WGN!]O5@EZI#8X:1MJ'^)C)67H+![']T:'N(@JM'U'@$=01'O'()W)
M1IAV_]\><C$TQSSQ?AT>FD7CW'Q7N_96@<;LV,Q^N"D-9M@X`#1]KK.3:M<]
M%2>"#LRDLN\&]/:4ISYT)>H9:YI*&V+#W`HC!"\->),#7NWY&IM]DP9HH"IB
M+.^F0X9<!BA;0AD6)'B/0.MJ7\X&/I.)01?2%HC&==8,#VGG&6%<448\=:98
MXF:MP3B0@]A=06F$ZQY7.B=E8)),-VR$>^C0"7'X652;`=OG7.V[4DIT.I_I
M=K_3_?&@R_5*C_K?^S41(9R'[!(3P>=QK#^YNK(@@VS(],Z*,U=I34IT7E<Z
MG<ZT[QM]?GT-T`WK)A-3JGZ^6826)='Y?.Z#:.W8UO5$5'751][HZ^E,RYII
MSYFVO=B@G:]7.H%L(>=,7[<;7<X76IDI[SNEE.AZO=#/S\]0JI8LHVOW(6-M
M-[;MLD9]`][_$=J7PHU(7OSYZ4<?#G/YT;"6AD(O@O>WP*[\T]?0@UUYL3"Q
MG^FLJ8`!"WM?-J(4&!ME'Z:8T]<K$CPS9W%#+PXA$L6:Y"G@%E(1-AI*!<X(
M?I/1@(*'35-X4&P\8`W@$C_PHENTI*?%;:3E4SD%![I2,^FK6NZPP.9V^)'K
M@W0@*@9PX\([P)JVZFKOI-2A#S%%$ZL6HGX2NNN6BDRU;5NPO3KH&*@T/\-<
MBN@"4;5,28,$8FC/HY.#"BX8-[SK=1FOCZAWKPSB<3@LB=T%'0>L[:_$G:=_
M+Q*S2AS#YZ#[\;H"B13K*<"<EXU^5.^]``'`.A+2N(./!DP2L;85$SUD:24Y
MR%RVX36;&I>ZK_"P+,,4NQ%/7<"H9LMYNO9$H).$S'V'#@%AC+T>U&H2B65)
MVH<90BI"WW'SK#>[JYR%*!'HC0UC7*]SCZ]U_LBZ(,DR!@MS=?TXUYC@KZ^O
M$AE<0Q76=2T.#3G[5,-(7M2/*^MS`ZN_,E16PB26)=&V;05PG\Z44K4>2TRG
M]5)B?'_^5->O/9N7JC-^/!YTO5[I=#J1R!<1/?KW[CG38W]07AO+2X$&>A1Z
M:5F(.-&RKLK-H5BH%<;[M)XZ.YZ61"FML/;H+EVN705MQPC)F^CQ#"15!^+?
M:/0?_N<%YG2`77X353H'IR<_J9<C>1O%OB!G>$6#\0IP9PV"?!@`&V"HT](.
M-:1TC!9?C56(M-.VVX3:R=FT>63N(\%G1B-YFN&+KR,>HYZP#:6+\=D:4_E7
M'O-#G3N3FSPG4Y'7B:J#XDLTPQ:`[L9X6ILN'5)AHW9%L2V-;;82C6XCQHTQ
M$[W($NAX.U`UBN(L\\C2%A2OOA,8=Q&5DYH4:Q.ISP$43%Q(^I1T2FKBNPV7
MI=XZ-/<NL$JR(1<V4<L5(LP*R*J-7[4WJX5;DR>XMOO0"'L+*PT-<Q['J@'%
M`)NIWU\-8'4C0LSPEV=O]SUWT":1)RP^A/8^$UIEH9:V)E35`FD`7:T%'<QS
M4HRD&C9+^'=L?'Q)`;_A-B)N2AYE!VZ+$?W^%M:.'?&3P"VAG>J^9TII^#=C
M%X\G.]TH7J7+5])"$!]=#FB'3HQ,)%*1E$IUG.J:5L#FB?:<Z70^T_ETHL^O
MK]+JOUSHKY\_NX1A4)?0Q3"#?A+(@]H_I_5$U^N5UL:<<@'5)11B*>>V#WG`
MY7(AR;D'5`@1+>M"E].9UJ7\_)H2I24IQY.<<QE@N]WIL6WT6![T[W__JZ3$
M1?L-['F)B<ZG4[4RS/3Y]47[MJOAU5R/Z70J;'2_-AF-_"%27'!(G!3032!Q
ML7DJWX#W;Y(ST*NLVU-63NL`?D7.\*+MKXE<^AL!_J^>>P!(Y0DREH#"E`,C
ML1"02WS<,?/%X7'QY/./[-AT?:-UFS.G!IX3MD&'P)\8'_^"9F?-V?'!\^\&
M9T)K+N5^YR(_M3K!ZM<.`'00H2JF48^M6I%9&$!=8\6`%ARZ(>FLK/U=Z>PN
M*3WHL)5D<Z?KQV=QTI?V?H;/%098(.NF@+R7-B@0KQAUT]XUVD<&QCU;6Q,C
MUV##A*HN!P#J".Q&G0.E]U71PS(""12;WAC--FP$OKAI1`2/,(!$SH[8>DG#
M]>MM[WK,V;*5E>'+DIWG['#ED!Y>D@F=$5!F,];FV"N7(:C%=Q%0&R\&G+4D
M.\GDK-;RQ/-1=0:Z],2"V,%4,OD"NQ479/6F&+"A_.?9;5$-[(I0UX$*=GB,
M#&$4)3XFMP'5#/IM#CI6D9:XKS3U7%H\;UH2_?'Q021"V^-!']>/TJW)F4ZG
M4QE:V_<N5>O/!C5'"QES`&T(+T.Z(8EZM_.^T>?/GW0^%^"+4Y3WVXT2%]:7
M:RPW5XNT!@KW?2^68NLZ!M:6I1_3]7*FQ^W6BSZIXIY]WVG?-EJ712G]L$!F
M8KJ>ST7&L"R41>CV]47[8^L[-=<39R*2O-/]MM/V>%2?;@)'&\WFX'/+$3:#
M`=:QEGYK>/];JH7W2.`7!]UF`.X9V!72R3A_!UDMP2346[KE(P1J%U82Y].G
MV*^#[W9,CHE_?:XY-AI4;#$+2`,,]'Z>RL?&>]%?!HP3'GZ=8V-3<;$R9Z\E
MAL+CVFJ4^;*=VEQ*<&P;-L(XV%E0O9IF*`&SYLZM:QK]^>7*KG!_0U+GG_#B
M,7$<(=Q9W0%F!LC4PDX&4-PUS<8L7A=O;4,P#).)_(W>D6%,G^'99L4&*O-V
M:)D/YI:`Y0XD6!0%CWB=M/6G[H*&E%3[NK>'NX98E.65:EUGJ<RD@,>N%-]A
MF$_`\\34+M24,X!O[1=,H70B6H>[5"`E!Q3U-<T0>9P,>`5C?Z<ACPM`/5CE
M!W>Y.33`O6@>MY*#N$5#C$@PR==8W@SQU7U0$.WFP$D!P7_.I$-'F%WOJK4C
MFG1@J=<J):Y.#!#);;I@J0%\,H$5E;WO(#6E,<`(,J("$H-!QO;],B0WW2^9
MF?9<M+;7ZY76-='/GS>ZWTJ01`;[-?6>![FZXY'5@W_]&J8B[5G7$E5,1/2?
M__R'1(C6=:'M\2A_]^-'U^V>UI4X)3J?3\[1PSY3DIL\XUQ[`\W!HTI?FD=R
ML#OV?2HE6A/3OF?:'@]Z@(89WXJTE.")V^W>`S#:AR0D3ZI<+.'@I_&\IH#Q
M;\_%-^#]F]C=7P6*GK24IRRM>J@F&M#C[Y(P%DR>D,&OT<9Z\WZ%\>97/Y_U
MAFX!34NW>D&VZSQ^A5_Y3@J!N$2M=16J(&KR]J`,T2B:Q=T;9P/#'FA/_<K(
MVQP!DM/M;C=8Y:^[CWVD,/&HLQ42%P!Z8MO781PFJTV&V4S$G)(41,^,V4BT
M+$*>=T>`51N;D[UB""X-]&-(:+"M<4=_!P,TK+6@EG%3K+L!'3;BESD:2-33
M_!0<6VQMI->-$;B6S>]P*'O(P()..VK&&@ZO01L>4FMJB\DU`XIX/[N\A&*V
M4P*QK]*M1[&^C5G/.AB#@=FUW2G&())`'J"L!\U]SX&FL@-7N/]9O7^ZZ%%A
M"I9Q#Q@%VW(74USL%202,+7VN6+#"*-^N.NV>X>E,/P-[.8>!$(J@*$/>AHG
M`0)@.IX?WROT^XDH4)U-=T;VG>AVIW__^]^T+(GV++3M>]$05[";E8.0UIV5
M]R1U73.NN:UX7%*BZ_5*RYJZE&';MB(UV';*4KQSA826T[E*A1;*>:?'MI6X
M8"%:U@3/[(@N7J#KD253%J9VZW*UH$O,=+]O1)1H71-A@J*8"?-]S_3Y^4G;
M8Q]2CA'71IP2;5NF^[:KK:P[HY`9&!8F278X3;K$291["(Y&?@/>]\'KBXR3
MZSO+.[]P#%S=Q[WJL/#D@&;$X$'6`+WA51&W("CV0Y697``W$_Y%FEV<<F2>
M.2$4M*$#+:*S-&,M'A*A9\&HFK'W>N@H!4K9>K$U_$I#M\@!^T?6NNW%!PD\
M2/N@F(AC(*R,0&V,XJ\O!Z3[P=<_*4;9M52/"CG=RD<-[%AH.RN%C%MC%ZSL
M05U.#IZEH)`0WWT00U4,.QX&,VD_\(H.!?;Z6)LE[^J@M<D:WS'80;'V'^UZ
M/Z&4-..I'0*E^[PV9P-/@NIC#(>@/"<&`6UM`\SCQ@&(LVWO_JPD5GZOO?UO
M`IZ8*?2.;?]D,K9\&$<-`2*=?;?@415\0XH1-KXT?G#63%@(#L"M74UTW"X#
MLPY04+1&71,T$AZ[<IO(&,D]&7QKTI,&VN%EWW,;;JOGF7P03==F$]'NUE8]
MY&A!I]@U)J/OK90"!8K<?FVS+GCX-`(]RI#5HH$NQ\4L1JRK@39X=U)*=/WQ
M01_7:SV.3#]_?M+M?N_#<,Q<"@QFNMWOM.>=+N=+U3^7]R#OF1[;@YB7+GEH
M7:U=,B5*I2C8BQ79Z72FO0;-")4"YO/V1??'G?[UKW_1NJS!B'4YZL>VT^W^
M,(7YB!POS/U8U]KZF?'=[ZEI<9'MB092Q]*N^W?PQ'^!X7U!3.ON$;_P46Q[
M.'3\N[VU9=ORPJJMQR]^EBAV$JVF^*73=@S%$2@)0P*<,_=S1E=G:(8)3NPQ
M2GA%1`ZFW)A>^\-^&NS9&@MDW=`5'(M)3>H_PYZ^QPEM-DI=]O/M8?W&S"KH
MH@W/'+\C;#9L=ISA$;.K?M*YQ>O0$YZ\')ZEM_&40U/)YN&0/B2F#S0-:JSH
MTE#F0/'0%H5,,INCLZ!$`Z#^TRI(!8"#[1FP#LQ(/83@H.,@R#R!K,4Y&P2Z
MVY;B%DS/X^0Y*Q,0(9^:Z%W=<%);3%NX'#+Z[5(-5&#5(FYR@C$$._PZJZJS
M3)FWP2Y8;UIJ5M?HD@DC$>EI>:1D$SH2%D,W\,VSX2+HKSVBE.-HV#$$B6L^
M*U`?T?%L`FI$J+>75>I98G///+$2!F#@T"93;!F9AC-&!Y6)U7.2J:7\20%A
M>8P_M6<VM5?;,/DY#Q_@9*;ZO:<VPSI7[WW6EI=DV.,E);I>+CU<HC&F&'["
M4@@"KA:#E(58,G&6GJ!&-0DQ<:+3NM)I7>GC^D'__M<?]'&]ENNP[_3S/W_1
MUV<=`LO#=SK5*BUO.]WO&TG.M"XKK>E$2UKH?#[3ONWT^?FSR)AR@9IYVREO
M>U]G\KZ7YTW*WQ/F0>02LE)D"@68)Y;^+W.5;^7A_8U[3*&](46^#Z&"7W6]
M5H1#R@<^ZN/8!IO&C9#)W[9D_RS#^Q;GZ:<`>-+^G^&I9P8):BF-1F>?L,I6
MEXL;LZ]87],?"\=LWRO7U#/=K`=]HNO!$U;1@CJ)3`ZT$3=3,&`H=J*6S`"8
M*5I,A]0"<+%`/`!#-`&H^ASUV?(3<,H1*][9#@N`V7?G`L[>@73Q6>L<,#*'
M[R)95IM=)\-Y9W*P*=N$09P*QH0S&1-<&`1,;=(?%FPRPU5*8MRC8XW9/K"G
M?<"(V`JW:[O/OY?,%`0M4/=;M2\@!T6&8]Y0S]K;YKENK@"P(Q>&UD:W[/*D
MZS*<+RR(UD5K:]NW`3$R#L/-RY2(**6J#08%,MI+-2>&`K`R2>9QW-WKC49R
M$QN&#TO0JE\=3+MA@2G0R^;AB9M8^_SJ8D'<$!>R\SI-C(Q,@MW]&994;)W]
MAD85?J9U-^RY=\VZ:,NVIN=U`!Z'G(BG79=>?&1QF1ZXE#=GCQ;1/7R?=2'(
MICO5_6II6);IZ&\&BSI-YK0_$RB,EZ5H:2_G2V%*]YWV;:?[[4:4BQ:5=*DZ
M++4(GOUV#7.FM#!]7*]T.9][P$;[OOO]1E^W+R))]7=D@-VF_:\%Q.-QK^EF
M0B0+[?M.>=^*1G==>U&Q;8\J>TB4I01'].^<#'8OR<]%4)T%*0X,VQC2DW%M
M^_O99#O[7C6[#.<!ZRS.DXA4"2,[*W8["U"N"WT/K?U=#*_\AIQ!0@!S#%Y5
MZSL(J>#P:\<J$FE)Y[]W2*`:MI%?!OD]U(N,IZ<\<3:8758>("(ZUGGQH!$\
M2TB:3VZ:CD)2\@"V`%A@L9,8N)MBBBG.9=`#Z=%WZD_V+ITPY!7)!2#E9U80
MJ`$:E^9&09J9U7R(JH^,VZX#;JXU:8'WP4LXM,'<0P78*Z:!90IB=LFD*YG?
M%-1&=#T;)IF9X:?2M%.#9'IH2GL#JV0A9<'FUZ?&1G()>1O`MWL>9\6(<O7]
M)?A/*R<8!9C5JX+MFVDF('B0@\AAV^`:JY0>X&GL%3*>HTT*#A1VXE]I6ZO5
M&VLMY2@V3',;AKY:H:1<,?I%3$YR(3G7@`5V,J,1;E>']K(8;3%U9GJTN.HS
MHUPK_'.(:7ZMB!B@4-O@#6!+/2(X&1>247C%W1<;WXM=G]P!#++/XSKA@%O_
MWVP"8I(Y-XGM\)BCX^6PY6T',]FPTTJ'3!KX2B`-$2&Z7,Z%W87?^?GS+[K?
M'ST5$1=K'$QL#@U8*&0:+7]>4G\FA(BV;:?[8R>J!1^WWA)VH4`??W]L]-C_
MK``U4<Y%GO!Q/5<];/EW/9TI9Z''8X<(]?;6IQK4`OKSWEUD(SW4?6*!9,-3
MC1[>'H\1/%.UO"3#7J][49//QD(K.*@;W6Q#*=+';WY+&OXQ*O@Y4'R%\WU*
M<TK<OI^WXOG7!N]>]M:5EZ00;L,63<*):DT__\X!&%_[XE!1^P3E1JU91VV&
MR4?15#N`188C`J6&\#CD'-Q7@4$P8=/I<4R:R3Z7V="79HEZ<YGCL`%GC,`T
MGV2''D,V@4Y*WL+D,M^UA(2]%(71ZHSM+)+V[9T:@&`K-6#*#)+#*6H"8E<(
M.F_*;A-O.@0P0"=@M'TQ@]K+9SAX/QCB3;UB7P989/;>T>UY88:?-8QT94(9
M/%IUP,8HA(9P"L!.2NZA$%5@<A/'=A:Y])[+='CN3'K=>!O3BL-BG%04J8#6
MO/\YQVPV/C/2VM\`Z*B#GF3>8RU3B)C<?LUD6"QQ#TP@=4]PVES+=4!ZAAI4
M2+-KQR(2]VH8OB>E,;B6P6F@`S_V8%:_E_$`J_WS(FO)?>]1[S2)9\`[\RY=
M=N7`+@P"$D>.(5K_&O6NVK&T$(AVC_OQ";Y/#7S:?3TH^OKS1MT?6:]1K-8(
M7"?:>[!76[O3Z41I24WAT('!]GC0_7XOQ\:L]P+5^>=>R.2]))_='QMER70^
MGZL#P^C:_/S\I*_[O;^'CVWOQX@2'NGK>*8-?L:*D03N54M1^^.//^B/'S_H
M^O&#B(H>./<=L!XOK$%HN=C72!$2[BM0O0Z1&$K?SV_`^YOL[BN@]XTO>/UC
MF7X]X(%Y"K#EMPY-U,;_[+*XM%4&.;&=I3*85;SSJZ:'GWRYTP`_Q;SL9*-*
M:\E!I0(#(6)N'NO^:\Q2'DB$IRX"HENU=CI?@UE1FKHC80L'HCTQISY_3P1&
MP,1KA%W4G4R<&2;R`U>4:=_4<?[LK-/$L*[6]HE95QYL]#*ME6HU\%:;7J2<
M@Y40!,W]'J7![E6VLE^YQ'7"GD<!)/I]:87)+`$+04I/>N*1BB3]OR?*DT(H
M-Z<VCH&?BF(%Q1Y5UJULFJ(<.QKXZHEQ31-N-,;.L@];!`;0]7O74NL`O)*1
MP!#XL*+=5NQ_F\9`6@<_N0/D=K\*4$N$EE(4@(!@8E<QQ\PXD"<`:D6QV2($
MH)OC8`_24J8A\P!0#NX-..RCUHD94QHPP/Y[??>%'#C1/:G&>';2`)^)I&4?
M`U`/QE[T2N?6$X[F`2!QKB]]C-(5#YSQ7+;M05]?7T57V]C/'`,#$=_I92K)
M9__KW_^BR^E,J<%D$;K?;H4U-H6&CSO3U]-*R,[G2P^G$!+ZNA6)Q+9MX'N<
M#[%,2HG699UBAA8JP43T\?&#KA\?Q26B7B,<',Q"+L!%*`J4$76OQ_,O8]#0
MD"SM_?Z6-+S%<G*8[_Q$J_""G.%U(#WSZWW9-4SUKE\[`I$YK\H'\0S/+,FF
MCA"&-(U]B0_\,*/CYSCTP#*F%#@:S*Z'8L;<R7/`[`X-J&4/RZ](V!J0%^Y?
M?,/\!+:U].)(72RX(5$H*W#3V@?5A2U-O)Q&V_0<ZG=]#%&=H&:%,I'E8G0S
MP(W)#>P,AD3;B`7%@N@R,7IVE858/W92MF%B&&;RS8(@W8F?KC/]CRNPC>S(
MK/:7X?I@*,6(MR7S3!BMK3H?<0"%><(XTAC$LD7+:.2+8I91O,PM?2NUE*ZE
MZGHU<,W.!L^\1EU>P]JJSL3QE@A9"U*0B6\M:E;?+Q`SUMT(9D0*HV2$1S(9
M.%R4B?PH?-R#310X]<`.%6G-RK-7'R]YO1O/[0'M.1V'-_CU@EFSOU%\LK*I
MZD6E'A)%MQ0V:6YX+?&]0#<0]5B(7LNS")#R7NY1DL/N0X]-"=P@XBC>9KU6
MVOX+_?@8`1'89;S?'W2_WURD+AE20\6)8_N)<5!4VWLE3K3GG;YN7Y0>J5NW
MJ7O7NCTIT?5RI?/I-!X3YXTOY3.8:5F6KOL7D?*_4Z*ENE@TP0XNE1K;H'#"
M)`%R<(QLWN,LWPSO/\;POL7`\EM>NK^!L0-1P2N,,$T,!OCW/GT"V"5B?P^(
M<]N"FK&ZH\UCIXC9(>IX/GQ,&36=F6(.1+2`GCF096@'`''\@SR]CJ*R%1F^
M5Z;/@4VRG#'>8@9APPW*I-F0F?Z/;K#=G/3GLIKU\BU;J]T1YS$K9E.(KZ6X
M1=&R!`1M>)5@95N0JF4HX[/LJ2L+(MT.#BWQVE0_M%<C1M\R-Y;#0CTP_M/8
MU0%0ARRA_%V<7.22;R7J&/'DG@"H9G;'GG-6@0].3@%K34_Y"HG><:RI^J*)
MF6A!0WQ2!>NP_8J+7-'V84I"D<+G.F+6U+FW\R;M5(%`53E!@/8V9NWT_<5W
MLGV7R#P@9O:9HWG&2JO=:[2)/&IV+30K1PY-BW&4R=T.2SM:V#V($_>BIQ5P
MK2`K?K*YNV2(O3[FFJE"4XS_,12$?:B4],^<3B>Z=+D`>UM&W`V,7_3'CQ_T
M1[7ZBNB)\_52W4-\QZ++=P)B"N4L>\YTO]]IW_=^WDM:^O$][H\R;$=H"Z:_
M:ZD);8]MFSH6B10IQ;J>ZM!<^824%KI<KI32,F*J)=IUM;9.]PJ#XHK,WF1V
MZ6^&]S?`[CMN8\=_]9HG[HSD<9OFX:_(6^#Z+=;X67A%]#\F-FSRQB75'I]/
MSJE/@B.#Y(%*?-XP*,(4`JN(;98@CZ8#;PDT_@=&M&(&Y515/T/Z`6#!?3OQ
M&%(CZYP03-=C.YAI/@!G65T6^)Z)LS%NZ/+,:DZQ/F-*>UP>XQX!"Z:]O-AJ
M'6X,')-;%8@T'U:7DL2CI))L0TU,<I;92!CML<P]4![-MO-$OC7,44``PV>R
M%I=$F]JLL="8Q<$*#T"//K.N&1&X.6#`@8T9'BPQ*?LH@>)`)*GS;9NX32;#
MFE0@YK;YOO:!O39()M'@D_8C]OORL(9RYZ=1K9<(!9[&D38VDB>U]O,SB4'8
M#9P`5D=BB#@7%91G2.3/._$IMM<&.P9J[6$Q`W7DO+YUS+(HDQ1EIT>C:.&#
M-6N\&P*?`>?/QC>[L;TX<[$+$2\D=>APN+38:79=E(\0F(5V\'-HH'U[;'2_
M/VJ1J#LL/24Q8#;LZ/)I/='Y?-:2H50&X`:[/PJLO=J3X25[U.2T(E?XH!\?
M'V,2O?ZS[SNMZU)<)JSG$3.=SR?:MHWV?7?=-P9K&%6HV2Z0?94@DE3Y823^
M9GC_N7_XD.$]@BE/R4I^'V.S8RGYD#7%RI8/6Z?R_'-F?_?*#S\!QC-6,[3U
MI+@-I]XA?NWP^J9@_XW8T]#`/WA&!(A`.6@2"+F$*%(NH?[Z--]*-&5B8U4T
M!92L=5,\>0[U@!D%+.NP=5*-$+9MW+G-E81%UJR@>/Y^>"T>/M="6@$H4[:*
M8#+>#$JK@J/_XGGT10``(`!)1$%4_H1%TYI=OR#@K^*`$9D!.3*N#A9PJ-\E
MB@N,*!6&I"<:3MD\<H1\!S3R*J-(=4`NL6^;\1`NXR`<#K^U[VPZ8$Q0LRQ[
M=PBHK54OTV&CHYVL!XF'DX3U'PXBH3,PO!*DXZF!,8Y!(^I/.SL)VF<^,,RU
M?XJ:Z9#Q=/N0UB$KB0;'R7[Q^RWNO`=X9V?!UM:Q!EY=09`XO*:,OM8YS]GM
M&IF;<_V7\%^F+$Q25;7ZS\NW['L9_OKY^1D^`^-:D+O_/>R$QOGC^U"8V9M[
ME[M>G0(G:WP7<TNH*P-QK;#+.5?0"=;\_7V/TR[;9^4L]/GY2??[8SBUU'NT
M[WL!UY7M;F>4X-CW?:>_?OXU],*60)-9VWFP^+KK)&J`&-?M;\#[*GSE`Y/C
M%QGA0V3W!M!Z@_A]&1G+2PAU!G;YUS48<O!E3T](#JN$J"VB3,1=[,($445W
M6WP(",=[I4XV,K_0$K-&RY\/=<X*I'(PV<<V.H*'UFRB=1B2$)G\B&<+E;E&
M%L<DLZD@.*I8[`LT&;09+*8^9M\R$%/42'@AU5QASDXBT8Y?US&BV7>RS@GB
MJR8QM*)KQQ)(%RAHQ;%FD-E<-E&CW6K*W/YYE&K5CJVWZNV]8&!:@G>_$"Y>
MS4H@3W#`."JF:`;VZJ8Z89K9ZIZ,[EYZ*(%^WQ.``_5]AGUW[]U$?^EBN]FW
MGU"N(`%(Z[(4&=(*)6'(NOATX""FBB$$`SHQR((*GAMU3V)D=6V!EX!996Z6
M4^+_I>+ZD5O!#6"6J$SGCW0M"N0W&9Y;N(<(!(.DMA(N$>W=TN\]N6):]'\B
M>]V2#0=,&U9_P/JWZ[<L"YW65=]C9,<GV&!9%KI^?-#Y?`XWOBQ"VV.C/;CW
M4>1UV*EDHF5=Z'0Z]4")=JUOMR_:\PZ:9S'OH="RK*Y#UUCFQ^/1K]M>`RDN
MERM=KA<7FI2-O*P\$[8H%#NN`=(T<>]^U[JK=5<+O;XE#:]BLR?MU5F;_26\
M^692\<L,JD&-41RQ_,8U&:U+>?_S@EZC<!@,-L,M_O,.^["CS2%AP,=SJ8?3
M*04MQK!"/3CR(W>,PS\+V60.`7O7R7&LJ16AIS8<8A8.I3M3H%Y>ZP1`&][9
M6L%&;[]?^Q%K9P61YV_#\(HTTI`GV$%_(P8AF$@\/%N98GD5`:RB$`2=+&KX
M`8!I+#QDXCTL09RQ-DVV>E]^<N_U9W>FK5L4(9I/BH;&8FE:3-G+8BW8E-V@
MM4$C-;.%STSQ>)T@Y:D&-A>F$@:X2LC&")M1EH+5+ZJWK#4%'TH3O%Q@#&?U
MN.8L#MDW+6[$PHXVO+;10H96`P>04Y$.%1'?I@ELOXK[19[LC?8S^O>89T%0
MHE+/C8/.2RS):+[1I&41"7QX6:<.=JN$'A`B<.YB@KI'>(4>FBI_9R4D0_I0
M[EL"QXM(EC+LTS0P#Q,0F2GO0H_M,;QIC9=VM-8*M-$2,WU\_*!E2=T+M_W4
MMN]TW[:Q;[$9R4R)UG6E;B23P1NW_NB>]WYO'H\BNRC@G8S4D'UG9$ED:W@,
MYAAA/QQW38A4]+:;9ZA/_3?@_<<`\AO`]2VA[#'RDV?(4N3EKW93S"&(T?V$
M5]P99G_)D6!2GEPJ>4]C3"H&PI%V/KH9<\K83/KRS).70ML,GXX4W2,YO"G^
MK]B-LTHT.67`-0?V:4SS)$'5%F0SR2SQ71Y1&^RN25>)!6A5#W])?#E!SRKR
M2E3))#0C`&+>Q$$HSDV0\#]1`J+O:S"<JIP;0+O+@X*SLD\)6A\238#B/;=I
M5;`9VR$U3L/^1P-=V&PD+BHE!+8Z:]`Z?C#%*7U>0ZL!=]-9#@`W6ME+2CZP
MA`+=IZ4&C&U#=YMHH#;+N$88HQZY]\"?[7MVT@\;C"%'ZWH@+[(R@9%\QOZ=
M)1]BDR5*YF/G3I!-<9_%RK.P*..GFZ!V-!&E9T<]<&FWC\]))`XX*P!>JIQQ
M?"/1!^Y_U7O7/\\UD2\#DRP$S@<J\8Z)EP*F$US[I@$OCB9$]\>-_OSKSQ%C
MG%CM4WU=-"F.>]Z+_GR6S2+&,40&8!0;Q@'WCZ4>ZU*(BJ7&9?=G,V?Z_/RD
MO&?3S^3N1C$*0E%L-AN&&M>TT_E$$FQ<MOA**='E<J5U76G;-KK=;H/Q5;:-
M7#-CAKZW.?P($CBD8Y]QE?N6-/S/0^.7A\A^T7K7M7Q?8X:?`W?UN?SZL;^J
M4G@5]!]*@?GH>(:=T-'%E9#E-V#!M4_(R35F<KHC604?,*7L$!H%5L0,&E24
M%_BD,:')A+IBQYX]3<@;&L==]FX-^CR>-`&";U"<E6"J&L4`9.99^:QLM)Z\
MX1O)0_[`QKR`*?`M0,>-X\%'_90DPX!"/GT%83:$0K,L,H:V%,M8SR%TR0H\
M/M6D=.YMQ93&=6#6#A.=P:\LZG#YT-]C)^@;,$K)M-O-P]A\=7/.-?!`IXL5
M3*1;\FP#9#KP,='&(#5HP'?(87B`LT"_VLX%71?(1CIC=B_YH3+KNI&[\X*6
M+$C7ZVMWD5S;TUFYR5B_FF%#EYDI*P<6#.,X>%:EN1<(A#M8FT-2+"H"J@*J
M2I2QH`L"SPS:APFUR+"B(Q<BP]WC&0'P.#9P+ZG7-K?(XG9J6:#8'^UX9<?7
MI`Z](!\N$2-@8<@\,LA<TKJ4%,#:]F\_N^\[_?GY%^U92"BI^YOA6+-(^9GF
MN@(6>MN>Z<^_?M+M]E!DS;[E^KGC?N1<FPQP[?8LM.]9A^W08*5/YXNR,<1G
M#D%R%JI!&E4BDQ9:UY72LHR_:^$3-$)<=!B29N&54Q/(\W*3`]4__V9X?P,^
M\N\"MM\A=0,6<-I,?H=M_J5_6/$XSSY3CK2Y[R#Z@U;IZVRX:):)G@#2B192
MR,M3(4!2.Q9;-KQ/_[*/9@V^B(_H>+8@23S/QG';<GJMVO&B2P#:$CF'@`!/
M0MQC5%`)O>[4H8";:-WP<&J(=-,!*R31\?#AL34&@<W/1[POFP(!HR]1SSN(
M?6.1QI,.C7@[)/PG9YT@UF4%"EWT7+W!\#50X&SCH!V/PR0\A"7"%+*XZ".K
M&/;&[F5=X<T&%XOL*?!@)M/.#=KXS56C,5IL_;.1%57V=!@C3,J?&&W0NL.#
M&4Q"8$H!^QKY>,^\WI,=2K*Z>G"9L)'C^C19:W5A^"S+/KZSQ4TK)G,<5?EK
M=IV$5N%EB0I_/]C:!QI=%T&\9(!+M"WTNY5O,M-"F3+-`NH3IQXCG8DH$?=A
MQ2[+8E]HZ.`<LHN.>M932I261/N^.3TX=DV8:J1TS3M?3DLMUD3IJ(F%[O<[
M;8\=W$78.+T`J<"H,1[O64I,R[*6X(<LQ$N;(<&.CE\SAT?X2&MD*KZZ+13D
MX^.#UJKO9>+BA;UGHN6`2.H+1B)FH7W;:=OV$>YBTN7T&`@[45;O9S37(?)*
MOV_`^PK0?*+?/<`83]K2\O+OJ,:>O(KIFK7(:"[;#Y@U@Y\QNV)_^YD=&-'S
M*-\G++%85I.?2R4B/P;;_K7):9%V=Z1VL>/,H]\;4;]#`M"/ATWX!.HXIUIH
M'44[O8ZJ]R^QQ$5B<_7^$\!>-`#!3Y\UNZF*TU=:FQR3PQ!&%T\QN+EW(I,G
M!5AO`8T.V@Q)T!%`60B'DXB##/1A64:72S6>K!N$8E5C]+B)U."%V]!Z+JP&
M93J;67L-EY:J>1:,2T.[69G$1.X:.0.X@NC77Z==1=ZD[7L33*D;TU4?4M!E
M.@V>B.GNL(ED]JU[',Q!MP8.WQE?V'2MKBI<V!0P/-TOP@(YB.MMH%4(I`,2
M*\6[#RSY04'FU@-@^+M1Y`AI"RV[C['28#<0T=KV"=Z[P?:Z=T@P+IK<\Q=I
MF_LSD$6Y2Q3_W`0FROJ`G3.KU4MWZ0@XS?3/%O0O"_UD!3IEK2!,&.;`VO;L
M=KO1OA?@)G5A0_LP'6A2?(&79:$?/WZ`+``]HYE.IPM]7(G^_///T-E#N2EQ
M?5,$;9:8+N<+G4YKU<LR26:E<V-*QA9P/+_[GFG?I6AWJ6B,K]<KG=:U`'RP
MXFO2D(R=BJGUG729Q9(66O]UHGW?Z3__^=^],&$[(%2?P3[4U@N25(9HZS5+
M]?[VQR5]#ZV]2"3&NL;IP)'9T^8;.+\<)TP1J.8CS&QT5A/?5GX%B#[CN5_`
M[8(2QDC;8'5L'%<48BX=1W]'0=?K&:+B"<MH-R;V4H#PW"4:9?(@5"@RS:9`
MRLOS(@4-TO%:!O-4;J!!21U:1KD/$`A)>=$3\:%6X6"H:/:.25"4^60WZ2P!
M'_G=R7'Q>E3H]4P/:VM$.'1GHVT;@\23$`K1PYXR+.4:X\'*Y8!#GU_R@7,*
M^/2K`(,IT;$S>/(V_*TUG;;HXX/!4:\+TN"9>IO1VDD/K>P`[PH8&`9*`IL_
M!%K-*YG#B7Q<'[1'M*=5+35/RC?X".C.GC<+<"W;K*S3,`&O8U9DY(,!,7B'
M,:&N6E0,\![Z>(-C@HHNUM^A+;-$>=WBD!@.T3&0%&*)'_1>AO`((5+Z3%7'
MXC,4=,X4ZY>TCKT3"PP=#A(]WTR8W";A6I7K$29*%5LF2I5!'7*BPLAR*HPN
MLM.=;1:AQ[;1Z70N7YAUL,*V[05HKTO1^0J2-SR.6R7&L6*B']O>WXG&:N];
MIL_/K^*S&Q2Q#6QNN22F99)>B&416D^G,CS8W3>JDP,1W1\;+:<3K<L22LCL
MW<IY+S[6*9%P(LE[>8[SZ*@1K$L,UP\N@%G'6S>C/$??@/<7V=UGP1"_$N;P
MEJW84V`Z;$6BEN[A\3QAG"WGT'`D/SGIJ-.,?\:S[Y?CH`YY1HE'`#.8\;&S
M<DSDVD6S=ILJ@"#V<MJF/[K@,JD6(KW`@3D",S`L@5^QGPTT@-X^.P?O!0YV
M-+`BRKTC?KJM/CIB`\0]O\-&:=)9)#LDA@E$4W8I8'HMN]TO$8\"RNI-E3RF
M,V2DP`,W2SJAX6S`^LNU%$!5#>A"J;6F,$R%P%4H2+<C\:E;MDVNW"3PM].X
MIVSMX)XL5Y%[A1A&53E)>+LJ;,TS,`_]=4`3?NL,4"-<R6C,59I;;7\CL^O"
M"EIP!\<QW#:(P6EP`V]I#79C_PP5U*%B@TF!3"RNEL2*Y6Z'HECO!M!XJ=<T
M#:NR^IF1I1NA7`8BA\=PUF`J55@"HW4BN^&Y:"OH$=18X9#WM]5UIHY;3JG$
M,H_N@9@T3A\YK-:]>OT2R)H$GL<E+;0L*^V/1V5YI0^;<D*I>&4AJ8!)U)JV
MSVO'OFT/^OGS9^UT$`CE$@QN21@!WPKA[?&@T\<'+<NIG]^>=[H_'EU/;.=!
M6NA#6UNLUW56[\5XF=.RE`'"/1-5UGJV*&01RGFGO_[ZJTN/]M;IP**.A\,,
MUTF&'N.>2Q@."VN73M*-@6_`^[<CY#=_!%N/]&+"V#L)QTPDSRR:?O&S<9N(
MIK/#[2HP)`BE"=.+8=LYOTK;8PN?7*2JEJG81B+I25BWX<Q#1YA\=.;LND46
M9.PJ6*@6C`YT)@/0C04;Z:G3K,I"EWS\;M=RBOJ]L="*LZ(9!<'Q,*'P@?,'
ML[.E<F"W@5&)V7IV!8T![PF[%B8%C64J?U#64\:S%14'P^)J-!V$?`X\H1R"
M?+SP:/<6T-6_LP*+E#2@('Q/F>KT-FEV+;"$\_886M+4)]^9%*B:/816QTRL
MBP8F:TDUOFN`79C0-HRZLBSJK6M3')$VD4.][F!413\SS?J+!_C:*X!J+U\'
ME%A@8<'E+#=$IY;9)4KF@1=8'(J1@)`,C:XBK%LZH"E`\=S;T%$*NBX"T^\A
MZTTMH<R3*XW=+&UQUC6I$!2SY%,*3>=B-C.!*TT[\BSE#>K#AME(VB`SLAUR
M-G9YZ",^=-VBUDMF&2/"TB(IDI(H-+G!`'OE.J<ET6D%_UW15/;U>B7)6859
M](U+K;?0W6&=W'@^G>A\.M.2^A'0NJQT.JWE/+*X#FQ7V39M<BH:ZF5)=#Z=
MRB'DK3];X\1V8LFTI/IFVH&&^OE;WBG79,2\[X5%WO<B?3+2A_;/TH0.QC*N
MM$/$CDIW[VCZ#IYX3<[P%JYE^DUOV_?^_#C<E@^HJX,OXC<3TYX<MV*[C&A,
M@B1$)M^RU<S4:T4%AV@/;I(2^I,;^IV?G<Q92,+D*7!#F)"E$CPX;D[)W&>M
MC=5RAI%+3M#R$K)NJY$IA;--"MA79,@E>/HZ2?26MZN?2L?!D)F%'!*2V+EN
MX1R80*0V97.>^'.<S)$'+7QF'^SA[CL7W6/[WXP!($PP[#6`-P5M\M:.):ZZ
MM.;1R9JA3"F9E#'-B/5-D6%CX@&*F*F[*S!3:*'%TS?=#`9!XI:(]?/D4-8T
M\Q%EN(XV48I`XZ<E#CX$H9R;#AWH4^+&38'`10)(^F[_Y`:L1$;;W@S,.0E#
M.^8&DH@I21V>(J(D94-GZ)BE^KPE!G]6*+(2I^&)P@,(M.N3"N7;V3(6H:4"
MBO9Y2TJ4ZN\O7&:-:GY87W$3V$[9=]86&<H&+@L9VVY=L!(."XKZG1[W(.6X
MVYDNS-U:#!-!6=IY=ZU,`9C5'J!=]Z3BAT"252W+$KB>Z*`8JM<;G'Z:["D/
MF<J^[^58<J8$[0<6_TZUP:]E84I)*+%0XG+?N+W_)'0^G\O['X#]?@R0#EFG
M".F\KO3'CP_ZXX\?=#HM:GE9$M.___4ONEXN%9C6YT2$.%/_WY)SO?[EVEQ.
MIQ(7+&78C*LV/\$UV;<"9OMS2</#G%.Y-I]__:2\[71:%DK,M-!@SOM_UON:
MVGWO!<;8/\KWM\*F"6'*OPF22+\9WO\RN_M,O/`N6.9I5[O/7T]STX5^S3=7
M7A1?,&E&1;WDD^_@%W$Y/3EV-N)9S%M2@V.DJ^`([/G-F-5YS$X",4P<+6Q9
M6IXS/2'S/+\P;-B.\1>1#S.[<XV2N1`V6U!BSTL"/V&MB8N?0-<&CMJ**-?H
MH-D7+3A($9G^1T-#/9@$3CUQ<E*8;#2MO;4I[/*XM8DZ#H$-M,YJ@'#X@R+@
MHEP+1.P*H8,`NQ&\PLATS^/4K:\2I3;H32FC_B_KNP4:TNXW2FR85\W$CZC>
MY-O_I`<B.S-K!WK\6+9AULH]TL;^`EQ=H(RJD^M6-R_Y6-[2F4NF@]`'S?(?
M^ED;&8G3U4OD>L**)24$6YWISGV]Q["/_I7H#VW>[SUG2IR*M9?3^?L"$<]?
M)Z*1\O6>KR.F@#?=FW$=P%&"D='FH0:J0#9#^$;7?;.X+D(&K^D6>#0\;@&T
MUW<!I1+,^GE0TJ"ZMBY+23*[WQ_P'N421RQZ6+*Q\ON^T^U^IV5=A[6AMCVA
M^_VN$O9L(P@3Y3KAR4SGRX5^?'R$G;^<2R+:_;%!1XIA'QGWM-FO"1&E)9%4
MJ[4699US[H7]MFVT[56#R[[0(2'ZO-WHL=WI<KT0I43<I"8@R^GK:V*U)B36
M_UL3&<$>59^7;\#[#)J^VC.7%[KQIA7X--GA-UGAP8<:G\FG^5_O?J.\%9X1
M#=2K4(0)?,?!=B%C66*_(YC>]U"?#ZSEQ"WT:K"&]1`-FUW63RVSV\S<X`:<
MS^%CP:',>7IO[!`&?H^85K;:U*+V(9..N[4N!D9/:2^*&YES%@?\=!C(`BW;
M>(S\50=@R%HB0L/>B2T[1:P&[9C8;S2@D^32KP27A5%.Z#34X911?AXUN,EL
M7E"C),^69<K$G(;S06=Y06T'S@AM<KPQV0)M&)$,;'G2@X.M#<IQB`$;6<9H
M>;=SA\$I&5*,#IC:O4ME(GQL9)E(DF(W45ZC+)C,>IK58)ST`34)(JP77NP+
M.XH&'H;[5MLIX,-KW[<4!I"0L_+3$;XQLYZS:.F'?9/,\%L_QQ9^4%/)ALS%
M%X&MR!(!4T4Y&-JN]\YU0N$=5E9I-`EE,=9SZ'[2WITQL6^S0R&HHIZO,+@B
M*)TN:PE%CQ$>K7`U<P`QSDVV(H[$\9K99DM&A,Y(K&PCNXY?2CSWPLNP*4O)
M;6:<EA'*`=I[D4C>,V19*3%M^T:W^XW.YW.-@AYJB-OC3G_]]5<M^A+MDG6"
M6FN(I$0I+<3,=#J?Z'RYT&/;Z]I0"O0NHY+Q\Z48JD?(C:\M,<0_/[^H2:ES
MSEVW:Y,*&R./6UL&2T"B(:LR91H(>,MG?0/>OXO(/7`+B'_O.+[Q'?KWN>^M
M_`:'_!I3+:]@WDD:KO]K9'<D'$9B`7W7LPE"YZ7`+YS54&]BG2!,8:PO>AT(
M&PE%X&(1A1O'+?\7[MKAM8\?3'4<3^AT7/S$3-A;XWA#J2FFH+$MVC-13U>K
MEBBP-1UL<@!RV;#-#/_92KX&DB9LDP**;/QQ,=&J;A8<.!(0CP0GY1$$S`E:
M6C6S_+[Q&N:/88-FTDQB.R[/4K,J0A@V;6RW]Z%*&7+GMOF*<(T0Q2`+!BU<
MN0^=2<M'\@8&/2C<EPRM:$X0E)%-@AB;@38FKLX<NY&^8#7"^.Y.GVM60`&9
M1>W0$0\PV1=669:9J7Z2^;&PP'H#D^>MM=_/!PO4`'SV_P0=,;>D+P,@*`#'
M0F5=Q4%=9FNIDT>(0.!<X*)SNV886+N@J,:NB8OSEK'.=$!49=.E`/04HHAF
M)YO$HVFY6<3L#.`%#+DN_;YDT0TR"?PLH;6WKB=:ED<):L".2`M",/[!A)K[
M?A!8<!*=SR?ZNB7:=W&;2#()>"D-&\33NM):)0-:#D.T<*+K^4(I);HU!ED&
M/B=@^%-B^N/C!RWK4MQH>*=U6?I]*6YGY5Y<SB=*_(-N]QO=[JEZ]&8B+FER
M/W_^I#T7N<.^[;2F9/8,CG7@9LX`UT9F'0M-Z.4KWY*&U[C,:*CE!=#["W]]
M"-=F;*8\_=PG'FEORQGB,_H;B.H7KQOH[(B,%(%UZ]EF;WOWX,&6R/S[>IPK
MD]=83B2->#T4`+:6@OC]/'_N9FX/.+!C[X&$R>6O=09T>5!`I4Q(&?S?(GX#
M&(0L]Y8^D9<61.WQ^*&*78&'?!;MLRI0JALOFX73OML-H.&46;>[JKM=;X>:
M"7'%]\JP_U(;6Q44=&_LQNHE/=V6*+FD+P1_JDF$8`:!I0+.!O14%C=3+KI"
M'BU_?&\0+"5@>?.>:\MW#/)U%CD-;3':"6$N2N)4"Z!Q+"4&-=$FNW>/@.O`
M5:^<<*C1))RAK*(PUV,H2_G]&K]C"V:<:X!EF2WKC1[/RK$!V%V6T,E':[K'
M=^2^F5-W!VB_D;//*T]M:)')>=(FC%P6=EV''N"`##9E2@SZ70)I`+&+K+::
M971&Z/I<]F]R0LD!VVZ*#'D1OBI-]YM&<>#U(+J3J-9?Y;!"70,M`0;`83C%
M,'>@+QT0K\NJNH+C<XLXM\@!I,NELF3:]ITNG5+U#_^ZKO3CXX,^O[YHV[8P
M4KH5I=?+E4ZG$]UN-SJ=3K0L:[W^2:UUY].9UG6EQ^-1=+I`X+3WM)T/)RZ)
M:'5-2,LRO'3K]V_;3MNVT;(L=#Y?*.=,?_[Y5XGZIN&'G7,&UE;(VA\GHP-7
MG5=EVR'DJ7\]B(U#R-^`]^^0,_Q-Q.E+>EKV2/<Y0&55UKUT7OS.>9GLDTF1
M\"N7"0=2@E,W`RNBOT<L$SB3+DR*"66/HQ-_B$DQ+WKUG@-HF<DK6.:;!L4)
M3V3M>XRWJ5N@@SQSF3!%FG7U4X4^X<QC48ZKB[=>)QW9R6`%9K$P$T8G"\H5
MC)71L&82UXKM!405@3>M&"Z:.D=/^J;0Y:\TAK_&=1Q1`-PH&Q[,\TA_\F[-
MJ0VHL96,:.UQ,LX$=@WC5*4/K`&IB(X:%I!",$QTXW\O!01W@WTR[7BM!:S/
M81E)[]>736!#.Y8E+93S7EOFH-N5,9!(4JR/NO\GLMVUQ=G#25L!5-O=_7[9
MV.$ZW-7W56='98:L#%/9/BN+,<0&9P>T.;/%,QN6SJ7SP7$XEI2U$X68@E$S
MQ*2812RKDPK_&+KH[@9"J?X,VGFQ8G'M0HO2!^R(X35$1XD43>WRD/"H@@[T
M/<Q#^E'"!U+<+C/BDP;`F;63B_IZYUR"P2[^:_IGD;>A(Z,U;L_WU^<721;Z
MN%YI/:?63ASW)C%]?%R)4Z(___RS^/$&K)=(T=!^?'R0U*&R?=M+P9JDN#2D
MT3&2+/3Y^5G6Q5H@-L:YG>:^;R19:-\VVE.J01&I#*4E[N_JS\^?=+_=*2T+
M?5P_BK]O&^)31MG4_:\CH*/VGV[1I]?KQ,-'V8JKD)L2D`-]`]Z_F8I\/<;W
M*"KB1598G@-)I]T$#T\*K?./#V@V'(>+0&2VS@$\5AN[SK#0W\7D[+2>@GR>
M<8+LFOIL4\%,.T]`$R2L:4S_769ZV3&>$I<)+OHI.';KD4J`DSEF74685-`B
M:[NP(WV>O%`4J(7>7+_PU*>>P>SOK=+!Z@`&JYL<>!=`+P`:R0,\I%EX`AKF
M<X*4*>,1"E'1#+HT3N02JA(O7C<*K&<[S03I;%U3F8<4@KN8L9/$Y>\3*[%=
M!RL0Q86@B,`[M.T_F6J+N'U/UJPP<RHMTL[$9N(ZL!)IKMMP&P[1M*>P,)(:
MZ(RA).[LL=+&DY;GXGE$DHX!!I.R;>KM=3/(*#J7U=LH&O69]3=V0UJDW52P
MJ]"83DQ14Z\VDA@,UF#<BAKJ_J<)M*ZY2W:Q0`#-*DYS`)NK;+-@>1D2&-U*
MD$":T7R+-?G`"D"&PVMMNAY8YZB8T"$;%N>*.K<>6I$@'*1U*EQ6..M"IL^Q
MZ3`''"1NGYLAIEV1(?67EG6ECX^/ZIWKT;"RNJO78<\[?7Y]DDBF?ZU_=#WL
ML#`LQW%:5SJ?+W1_W*O-6E;=C)066M:E#(YM&WU]?16PMRYTO5YI62[J,J2T
MT/7C@_9M(R&BKZ\O(A):UQ(:4>S(:L$.THCV'',6NMWOM.^9;O='>4;VG?[Z
M_*EB(ZT4IP6K*&M$^+O%/!>&?NF_YW?T0?P."9E\:WA_F?F=,L)OMO9U!J.:
MF(_&D.0M((J2_HG/F'#LV_I"-/(A2%>&^1.P:]$L:W"H%A,!BL+JI>2%"2]W
M$<4AZKY42SP*I4`+LY8N/+O%]F7TMU[#V0<7```@`$E$050MNG$7GV'`"EKU
M,[:=+5,8#)50[%Z@#B)XL-@9OOO(9CL6.(8T*O\:''OSC&;PBL5)9AQDD>CI
M$Y^.)J)='52<LK,]TRQQM[*B86&%XVM#.N&C=)>%>_LW(<-5-W@R+<BFG5,,
M1HJ&^@:`[4#!,+8=F#:C^X%$322N#.:<*-!M5FL@;F"M;':YVN5CUR0CPRS6
MXY6H>V4)N>2UYB3!U:&TZ4[1+[7C]YS+1'<;Q',M3S(3^0/X-_NGC-4/#+0D
MMKA$WS>"KD%ONYM`"]>5$!Y!%C",A$$>68#M%NT;>I0$F$6SI>W>Y^Z@(<J#
MO<7<$DA]6EM]`'(>X0X\`'0DZ<#NEPX**5KP&4/JAN44^\O*,QBE%0DZ#"@#
MXX!8:;,&W;VBZ:0[4STC-320[C[VK!U^E,V:4&A?>+E>Z?/SJ[[;6B:CSEMU
MWK@Z-<P%9_?[@U*U$\M[II\_?U(6H<OU0K>O&RTIT<?U@W(ND<7M.;[==B)B
M6@#$MF,^K:<RU%:M#Q^/.UTNEQJB,0!ODM'U>CP>M*2BX;U]W6G;-R7Q:?ZZ
MRCV&Q\R"SDT4%4[5"@NV7M+&<8-(.V<X`D:T[.@;\/ZB]""2&C#]BH[5#U+-
M@&^(.&DF:QA,U!08LZ4H18%-9"@D8N?>%B5S\'M&SR9C6$<M."):'TG&^@HV
M"+Q^KCN&"5G]?\M4-Z6RU3FF;H.K1RX7N4_"*\<JI>'E8,/M;4DP?>\`1Z*0
M"9T;Q\X"24_G.Y\*<QV'4$24WG'.GY=V=7+1>2]64R3SFA#T?'V("X0";*:@
MVT+*DMSS-0;&J`DCJ1&6F%8VK+CJ-Z$^!'Q[<WT>!DC50Q=-"ZNTK8E[,I!V
MR1@.!4,G.8;VF@1!):XQ:&Z1"0>C^_8S#=18MLY.W0\-)W>/SDPCO`(!3`H"
M*S3S;V."BWD]ZG>[)5I[+E.5&`AJ-`&HU.'5)94X9V3TVXN?6CL^L?<!%PFE
M//C?$[+"!M38*%MT]$BMJP!2)4PU8\G.@YPKX.S`*"6U-.T0IM`/7RQC2@KH
MEQU@<4E[7#L/"=C7KLU,VNINN!10*+MJFF'/WB:_OIMG"]G?(P_P;GL%Q]$)
M"A[>O7;H$_UU!]/=6NGBG&YP.^A+)^M[KRSY1$@X$4N)Z97J<D"2:-]R25S;
M[WT=1RUSE_Y!JTY$:'MLM&]"ZYKTX&25.*SK2BNMM*XGHI/0NJRT[1LM*55)
M3CG>S\]/VK:-<M[[^W>_WRFE1-?+A=()];RI6O25D(OKI;#`12NLB93<AV!3
M!^#_A[UWW8XDN9&$#1Z125:U-/O^;[D[ZBXR+^'X?OC-`(<'R6J-]MMS*)T9
M=5>1F7%U!PQV:2X-ACH9(/;-.J^\FR6\(J7-K''MU9\T+&1DSN]>IG?$:A?%
M65Q^([S_=I3W[.?78C<Y29;]!/7@A&IP6FJL0#R*I;:C.7&T@P\4>L1!L'E5
M=G/0T*_5"H_\J"]R-]#@Z[]V)R,XD_%?UZFJI^^**UHEGN='-Z47^&I&/"Q(
MFBIX@2M\Q8U0Y^LSHQ2!"IU\8;M3@'*YO+B*)G\]2)%K8\EES!J-[-7C4Y%G
MKACO2/7I:!2^P:(P52>TK%8%7=@,0=ID(*)19&XS3V=Q4T\JDK[I&+].[B`%
MAIL*D8FK*2E!V/:I\T!A(S]9Z03B+L([*)`(S=V]=ATZ']7<U[*YY69"'XRE
MU54)_!QP83PS(%(O_/VHGT>2S3NU%4IS$>;$4XXRI2QN`<+1>K-5FD(D@L2R
ML*W5T:0>F:)]<PMN*)&I-IC!3AZ.SB<E^HR"O)09`(C!ERDE38<=6;>F4[7/
M(8FVV(D%B%TG^-];\S3[[6H8F0U7Z"K4!MKT]+K62%(3DR2VUV3J"NT;"DM?
M:&XA2FEPZHQLVE1$IZ<)%$3!4=&%>5\H!`<NEZU.+C9<KU<\'H]^OS)YK2E-
M#WH1+<#;[1T0X(^??_3B>-_W?@#[?C'KW.6R8[_L_;-^_?J%?_WK7UW89JW-
M%8_G':\O+Z6ASHJTI7%=>O.1ZG?M=3VQ,S6IZ7!__ODG;K?[2`1T1:YYEQS:
MLU]V_/&//\HRE?-XCB"=,J+3%+?N*A6(4#,.=AHB0I.;#N*[X/T/5<$?@:$Z
M!2-BP@WUWW6(.A?B,U*G'P0<K&UV?,B%3K\G'UXR+K18:#%=4T5<Y@>*J?G<
M)U?8T-1"H:<73MR&VT?WXM39"*QSQ(X9#7?,H\RZB&*;\%M>(^;1P^Q"82V%
M$(4TF")?C6V;W0A&826.U*YGU)-`:"7!AN.?K5$(:N<<EN2KW+NC)KX8`**X
M9\DIP@4FF`0R-G463YE(9?:.=-&ZWCE#U/)9N4'BZ7P[!RZ\"H*>9^ZCC,2U
M[&.!VQ6<W#"T%RR29!)JL=>T"J;S:IGW0Q"9S<K1Q^4F@IK?[VIW)%N_QE`;
MS)$:%S,?1IRJU:S?.G+0A,+S<TDT9D1F[CG/WKLU+&S5(*\J=H0N9GQDB\J&
M_L+8*HV*1*O?KSKG@_XC:A%3=2RD421S43D`C#;B%TD.0>V6O5-%;]@?_IH&
M-)B!6'/L-(6I,.K6>/,D=K2?-=YK;U-E"F^=*1$]'$8YH!O=6:)S]/O>TAJ4
M4O2FCI2K">00HI[T20,$1_6[O5Q^0J#8]H37[15'/O#^]D;7LOI^TSMGUCI1
MO-]N4%7\_/&SASP,K]GV#'O6="D<[X_[[,9)Z]WQ//#V_HZ?/W\,$>66QOO=
MUL\F\*R3G?:\/RHO.*54PC5XKRFYT0BM_,2NNSD?E:\/9#W,1%();A?/Z>%0
M$.?#-'CCA<?$J9C?MF3_SKI6_T9!JKZ\DD\?Q,>V9+Y0F`M'#>D&GM\K7[=:
MD"#]X9,?H*:+IVA&X;&\3D6R*<Y@#`UF6L*$<G_B2HK$)!2G=!''.98&91NA
MZADU`!;5/2EV=2;9>GJ__70OM/@$#\?38"PO=HSDO!W<]`PX])C_D_4,_08F
M=1_]CU%MZQ`8<LZZI((@^V0OU=RYT4)CC8*DY8&PJ1)R:1&Q'B_+A9:WL.LH
M2.&K0C-E_57S^\:]K5"32N[?FS21@MPAPJB1IY*0,(YYBK%7D&]Q8Y2[,7\K
M"',N8U*);+:TGZ-/+FNJ?H#0._4H+!5C=)T&,F0ME-CI@`GOQ?G!%A]:44UO
MS9:S3DWJQ-UE(;TI.&T!W0MQ5P!::[BX&`2/\V$MP3ANEIL.;V\F;)>HB&QI
M3'$](:'J`R.L4))MH<49_G?NN9L1&?LS22X5S$:2-P<0GOQ$S6(+'/$N#RTU
ML/?RSB6B^QBK7T=Y.6*G%7X^%,B"+"24$^LOG&J4[;#K'@CWD15;&O[;/W\6
MMX+'_=[OE9!;C*&#Z:"M/!]/X`?P?#SQ_OZ&R^6"E]<7:*&Q=RK)^WMQ=TA;
M*GS>-B6`]=W.6J8BFC,>]SN>URLNEPL$P+T6V"6^>$/6HS8"A2,,`#]__D3.
M&7_]]1>>SZ?C/XN)=H_V9=XFI(I3__SK+_S\\5H1_=FKKG'U/?`B5.":TL7;
M(ZMU</@N>$\+KD^BM9[K^D4*Q'FYX4H[_;OT"CU%![WI]RJJ01=^P`%L_.5#
MLL(!!0N:36K+B7AOZ0X@,;HK;>G[9.,BBPQD%M"8#EQD+D_%L#4,HAU>;!%'
M(];3!DH]"BX(CE4!2)AXQJ2889D4YJ\-E)?B-A$@>MDE+YV^7P8YPS!K5R=>
MY+`)=ONHFT<37I&A`K4;&4C5'HR1OH:^UN)@%N6@(+7L.M!3A;BQ4*)?\,*<
M?2YH+UJ2"(Z&4'MA3F[QN=I3UXI_;4.Q*V+2D->&;"D]C94\JIG4]=E.+Y((
M<A5`%0>)#)'-HJ$Y!X]=5;`+<V:5BM!DTKZRYNX*,0K3)C(:XI9$2FLQU`F8
M>V#&J34NEQ.8_#B^%0W6T[2>,[DP&%31C$W1]'N.!N$6"]6)^RR@$!,2:!8+
ML(%>B0@.ME!S`$9#3MMSX5'XF6LL)EY8FBA,X*@6,-9P_-JVZR;$F;?>X'.A
MSWBDGTQHM&Y1<]!^AX5L$97%@T]EW4CQ/33S(R?,4]O8=XZPIWZY>W&[E42S
M+5E^[(_7%QS/ATD1M-^G4Z.6->.___7?I8@^#MP?#]P>=USW"_;]TM'ZV^U6
M4%U8Y+.OA63+Q=9Y;V^_\/Z><+GL>*FN#\_G$[I93C>G4[Z_W^HY!/N/Z1IE
M6N>3S$!4X1=;R\/H.?;=J''B@+6B]'L$:WJ^"]Z3D?JG?7@_X8=[_NL2T.<#
MQ.]SA_'AWZW]?N-*E5.G3K][49A]O?X>8XBLJRJ?4KPT1K(G%P:GAE7##1ZV
M7:*3:5E\W&MF`2WLKF#1:*CLJ!ZJRV0'CI)<-6I36I%8]&"`/B?I3XQ<ARX-
M]DD28R*NAK_[4=B#4+J4T^$X`WH.K8A1!7%&^T,\0Y_7YK=5"&@H%*)QTA[&
MN+T4R#!"$T9XV7%`*U(K0<_!O$<3^=J.(]<-$&GRMFY<:.U"J/G1'$6_O4[:
M>6VI.PCP;_81/:6?;;+UH`F[V=F8Z6[T3C0'SKEG+FD[RJQQ+&Y[)AHJY;V?
M#T?Y4-4IMO;(V06Q:?R*\3K`*"1@D#AC0R9N8PV>;4XVFZWMXL9UK$W6W[>?
MHWM/#*U#8^#&T&+$QJ/W\V3TMKZ3(Z2$1\4*EUQLCD5;1&P;W2_>>7K8ITI[
M6)VGWAP*K'?R5'PN4DMU:LSB8LIXOJ>(R\S>L6+C=S&<"9Z/!ZZ;=5K8MJV/
M]`5S*EU#W8UO;U:H'OT0CN-`/@[<Y5$1Y$J!:6M3W;@2/>#=0<(YHZ"*XR#`
M\_G`\U$LS`#M$<+[I7"%'\\#^UYB@N_W!]CG5L%Z;[(\#06(]OV%:>(+^)!F
M1(E2U.:"ZTSH&+T#WP7O;R"\^AL0ZWD!>)8FI<N?^`I10'EQ60[OY>0X8N1W
M*HSEB]?&?9"(\P!U2G)UPBDCI..QF;@V7R/F9ALI*B%P@\2K47H$Q1FNK[4M
M`GK>.^8X2X$ZX;@N:"">%AAY'B_LI=RX-'J^C$C.KT@R0$CV46442&%CY9@*
ML[*N\T5!#IK-(:)8V;9)'WM";+J7E$IRWAP5T[][WJ!'HO3$J+HHCU%QT$9E
M:+(+Z?&]=B-GE&>@:,5!(9NC*+ZWTGG1&K@+\+7JR&LMP@?_THZQ)0DV[#WY
MJ$U4NG<O%7Y'KL;UU9.W?,<Q/8,M:IA'X9+&^5D*"Z6\N?>:K:B2<<M0XL(F
M9#V&,`8VOIC?5]^\3DR;)I1QK@>S5^]<-,G"?YS11&&Z#"P5P09FC#";@E#+
ME);6$%^H$QE2$1L]&V%1[GBP[1!S5D,K,=[#39_HT`9U"*T_GG!_E7E-,#:0
M,APLFM@UN?=9@R`>V\/-5+$985;[C%!28F_"3.J;6%J$C-^YO=]PO5QQV4=Y
MM6\[_OF/?^+M_1?N]\>,%H>UA_248=OH:Q%%5K>69*M!PQ-6^7C46GB_CW[^
MS[I^/(^CW\N+M.2X/+C/[#L.Q>OU%<]<0BY`36[6F*0Y_(7+\6[;5@K\8'S.
M@2NL>U&7*X#)ZQDF/>Z[X/TM1/;W7!J^]HGZ(<+[>^EE^AN_,Q?.T=@]UO"?
M&JP9ZN<84<T^G-'(1"*^)XD,:(4;"SK62FO^#C,:<5==SUH7U6`NCYE\3TC1
M60"P]]H0:JF5_3LQ[&B\$01?9T-Z@DMWH@72Z1R,9VOD6B!P:FO/J7"V3Y%A
M_RI&.*8RS^?1!Q&5]]6*)9V*D;&(MK5S/+TR>+U@3U^=$/R^$4_W?BZ>1\*:
M#*38%5^#2D$.&SK>6,W:[8-8>!/Y7JMJ<01H.R:YK.0CFW\W/KPR^,HR\X"0
M4(SOG\\G\G%,0J;VS\V6J\6H)D*YBZ_GUC?;K%3<!,_`MA4OT,?CT85J`^E+
M=:Q_V'?0)<*,#5/L]&55K-&3XHM._F0)"DS;K*7^#$1(;D:>;!7;0Y$<<@VF
M!-43,!&LQMD`[IU+DW#0NAR@"@?+1"%WD92EDW@'&L]55B=4;CS;I:\LO<]F
M%*V@&&);"&<J]OTZ-A#ULO-XBH:ZZ]+#7MS:9!HCM4X6<`F3(@QT")['@;?W
M&XY+QG[9"KH+X/IRQ9$/'(?B0(8>V17?;=N:B[;6_"C=K!93W.YY,L##$$0V
M,""[^.R,8@UF08D!V]HA:6EVR_/\+$##MM$[O>/'CU>\W]YQ/(^^-A[!Y)79
M@,7WMQS;'W_\`[?['>]O;\7^D"I6J5F52DW,E`I:USDC.C7<QF^$]]\`!?\[
M?E]_^\/UMPO?%94#2T3U,Z7R*C!,/0JL-+H-1N:,%L]V8S)]EPTCD.4E]'9`
M@A'W>6ZB3(IKE3E"ESY?@Q&`?A29!SFYK]H%;X;OUR-PA[);U.7_POXKFQ#D
MZ&"=!0S$%A%C;PZ&]"06XT+/\`6]L##@#K<"7:&GU**>/N;$B()B>7.]OD!$
M\'@\JA]EGH2`&HZ`![(*$JAY=$_.GA1**>M_EF`*V&B:9$;769WP;(0"-$-@
M7T>T8B`'(2DESE=Z%&B[MN6ZY,[WZYN[--7Z\#^]7"[%D'[;NNW1?%T&@ES\
M=#>()&PIX7*]X'*]=B[F<1QX/)ZXW^\U3M@[E)2B_7IYZ2_7D;-!PY5,J":Q
MI*<$>.3>K1$2(;2+P`2F:JAWN_?OSF(JU-?6G'M4<O1==FT,IC!\/`T-;PTL
MC=)!#AHMR2JE-&@L]:JDVO@D&=22D40FG<+C/7C#]Y6*IWF>K5/A,AQ68-!_
MMC'SZ6U*02`B)%C5F$;4&KH"K&1K8<BUGP3.%.B0/28/\OJROK__`O"*_?K'
M^"Q5O+R\XN7Z@MO]AG_]ZU_(AW;:1N.M&Y36-/3D0$*%<78TMFE9U?FY3U.T
ML;?'=^N'@$(L%-?KCO_ZYS^GM=@*?`-TW>_;D@`DW._W*8FM7P?G@9WI.4NP
MG&QSF]AIIUFA?5>L?[/&_9O\W8_BB,]*7_W-NOMS5(9Q<GX0#['(EO7#6P5;
M:$!]T&K?Y=*O1-8P.@F3_,A>IQ"-P!<RVG0<OVZ-P,L2@56'QJW2Y-8/D>TX
M^"PZ[[8NT#T.=G&(K%;6Z/YXL9Q'0#O2:Y.B^E54RZL%%3@#J95PS#C2G:R`
MPHQE8<>_D=G'\#80A^J57[A444=4-&@4Z5J?C\0-F?(T08TU7A=X2C,_+W@)
M-",;S$3G)#!X+BEMVLF=5XX+G_'90<)7NP=]HW"%*"PZ4N@)UA_;O/$M92DE
M7*[7_ON>.\M(*BJ+.:6$;=MP?;EBWR^XW6_=TBBEA,OE@M<?K[A>+P7=>7\W
M3W[.)='I>GWB]>6UCMJ;T;T5K/A%3H/IBQ7'#4$<%XQ&/-4F(-V=(=GT-2XJ
M.4:51O*A#F!.F>E<80Z\@*>_$)JOP3&OHL?%C6Q25,ACQ$*KC@GQGAQRC3DT
M8GZG!FKIT_@:4M=Y^U/LMI@@S>2]QS,,Q]EZ^@XAHY`:>#3[I=-/K2G(2DNS
M`IJ*0+/O<YCCNG6F'I@UN'UT5NC1^,=I\(R3X.7EBN?C!??[@>-XCD*@Q^7J
M)+II'%_?(*007;+K"T\K&>45`BJFB6DOBC..Y[-,5R"X7"[X\?IJ*#5__OD7
M<LYX5E&>C6\?96YR.UZN[A67RQ6_?OU%A3^FM0I*^$9[5XQ=%<G30E.C[^")
M\['T%PI(^5V<5G4MC`K&`7\+9)9YK+\J#@-<=1K%>U3.S7=BJ%?0(PT;>F.^
M8=3",[>)/2[/SH\02#7%;NPY;([2C$3&=P[5N$58#%IWXG<;H>2Z>!Z6[0BE
MM8UF24SQ,V@7=#\$+MU#00Y-MA-7#9H$0N_4.C^R=ZU78:\XC3P.[K&;W/`H
M%;#"5!>=^<G&G:'<M&W;D+;-)%LI)7'YY[91T;IEF%)*G7,)*<5"XH=RH/KJ
MW%28LTG"#D^OR,1)Y6LW^3:3VKIYES(BS4X``PFVDX)4.;AM?,U\83A#?AZM
MIY3P^OJ*?2M1HO?[O:NU+=HFPU&C;NRO/WY`5?'G7W_A5NV/VGW9]QU__/$'
M]HH<'T?E`&)XRA:QS!W7ZPOVRP5'/I"?U:B^TT5F,5:TIBMQ\,6Y)S2DM3^G
MBX;)K(.170T&TFA\JSE>UC2S$J:^1?]NFANG`O*"+HMHTABYHL#*$X\`,8[$
M?HW6HM66*VL;FP]U2-:,9,(SJ-C1/-D6CAY))EI5C[66.GRO62J&E]U<*M1:
MW)7":Q;+,H4J02C%L:W18HNFY'C,T'#C-4$)$-SO-T`5/W_^Q/5R,78YFVSX
M^>,/O%P/W&[O>'N_F>87_+QDM8XY/2*9&QMQ-%:FIKF]3W7V!)X:LR*\;0UW
MB0E6_/SQVK^D7=/G<91`BT>Q*JO$FFG;X1)8V+4H9Z@>1>":2U:S];8?TRP[
M)=!^?FE1K1C>_C?"^^_YSP<N2^><WZ^Z0?QM[D*4$<3&Y>?XIBY*<X&-K8V0
MI[Z1=#/Y:,`G7\!7`R1'YL)5U*.H<8%IZ+Z.BBM^++=DILC27DSY@"/K,'%Q
MPC,$B;B<UC52KSJ]_%)'DAVY(Z1(G7Q=5</1&+"R')(N+A)^J&B!],E5NMCH
M>=>QZ(0Z:LPH*%(J",3C\<#]?L=EW[O:>&KO>*Q=5^=N@J]M>(9I.L'7*'4D
M//7$-JWI3=(<"PBULF-8@#GN(KXY$Q=M3>BCP""M1\Y#P9]+E*[E25?$*DDU
MLM<I3,/<1QFH3T%A?^"R[R51ZBAHCT>1&+%/(OWW1`3O[[<^MFR);7T<^^L-
M__CGAI02]FTOU^P8$*6BT%(>SWM)KGH^H(^'"VT1FU`8><^:4;4:9P_OC?OA
MFNP6?1^`8`NL6$DNP3OAQ9I^&L#/![L;<"`*OZM%T#EC$>T/>M2M>\>BU:4\
M[Z7(3<9V9M!%1$;``_=KF2:%/<*;+F'N:5CH#A'<]"@*'[2;KQ%7UR^XWI&@
M%??)KR])H(<:-%EJ+/KH_S,E.LKIOD\IQMWBLE!U,O[YSW_B<MF-D'+?=VS;
MALOU@FW;\.O76^5H6^_?@7Q[K4-KVC(UZF[2(R[BO-&8H#U4PF-4YGZG8B.X
M[\5UXG*]=#ZQG]QQ8\W,CVD_DBD_D]Z':)<50S$!ZR&R6@YYUDY#\6E^WQS>
M_QL4B,_P(R8*0/QC7ZE_!80T8>:A+DHS^_N]*(@12I&X[!IN"`W%$DY"-<EK
M*^J!A,@Q,0>:"\/,OAB;MSF1\6J*L^@Y=>AP-F,F,5@6/_P!2C]14Y:>N%X/
M)9W+R3Z2C-;QN)\%$2GYZULV1E2!A2XV7PD$%2,>%R2]#6*1HTW?[1P*G^0V
M7R$)'"3:N>[[!2DEW&XW/.L8[K47%FY#[`OFL&+JMKXB4$T=*96%@8G(H#QX
M$=UPCM`^*DY;&DX6$B2VH5$\LD5X&<F#$]DL%/B==E0+O(340P$.S>/^F4"&
M<CQ;I1Q(2OCYQQ^%[UD_B_G0+*CJ!4+]L,OE4GFZ&8_'8XS7U;9-K8!.*?5B
MO-,!2##UZ]<O_*__5=3OCYKR9E!6L2A0+ZXYV8MH&R'X`-?U^J(39)5%W!??
M*/BB.Y\UDB=KC8GJEO'.V+A8+,)TQ`K-W!3'%]N3[9<ZWV/`%*)%N)2,2#!G
M-=[&S5=XV*MQ(,0X6`YBZ)21E":?XD9E:/[*N8[Y%8`F*W+C:^UU!#U1+]D0
M(P7'2RM[;LU3`T<5*6P&@7<K?SP>)1Q"7[#ONZ70U/OTX^=/B`A^O;\A'P7E
MS%G'\LY3"$,O<S4D[T5!Z(^ZQKVLOS4-K\4LT[/R\G+%R\M+0=CK!&K?MF&5
M]GP._%X&!WH)P?!TC*:+TZ0A,H_OSRN1J]G;EZE9X?WZIC3\1U#><X1WF$0/
M/I*]T1KY,XA.0)B>D13(JHGSISG+'60YPM9CG0/8%<<,.LF$ID3C;*GI.,VC
MLR?M9&LU9$ST3=%0_K/MI2`K"%-+D)E5]%QTM.\.G25$D?-<9)J7=@[JL1LH
MD99UNO##Q,P(?(1"-'1.B8NL=OIF(8)D:"6";4LE8[T*CX[C*+Z-AL7/Y>2(
MHNTC3C:VKPC@D0]K$^1:*!&K@,^$3DY"BY/G$CUPP),^Q-$9AE4/(T!M]+CO
M!8$HGI(U._[QP/5ZQ?-YA)SET1`H-MGZ,UHV8!MMVCFO5325TD9QKL"6-FS[
MAB2"1W4R:`76OFU(6^&T-HLO0/!XWKO?;HG,?:(<_K@VJ1JS9QUQP`6@%P=:
M"30-WU[MB)%2PI5`C]S%:BD-5+.E3K5_/YY/O+V]8=_V[I=[U!'FNETN]_LX
M#D#1^7^M(,B,(-9CS,<!7"Y3F$4F_J0J\'C<<;GLB\94(;)AW](HL,AR;0X;
M&"@>H]3LF"",E#%EAP?,SNY.J<%!--6H'%U/N0F+Y)/]QOZS<P;Q3`69?:I]
M(ZM86[!QZ$,/,VC?PU'+P&1!)Y1F!K$3@>4QN370(^=S`S[6`/]^1^X1YOD3
M66S@@?9DV3"QRX::(DQ$\/[VAN,X\%__]5^+,D#PX\=/O+R^XG:_XWZ_X?G(
M]1VB0K3]<P.>A,(_`FL_$5FBJR'R6C_GLE\@27!_/'"Y7'!YN5`04$?-H*IX
M>[_A=K\-X*-%T$4ICV9#;0UWAI!@<RZH=`IT*0.XF;;5-2;B1=_EG[\+WG\7
MBJN_B?!.2&7\,OC.[JM5-8^I.%G4A@@09]&UL9.M$F(_41'M24G&@)07YGH@
M9?/3D/K`Q5]'LV@Q8TNE+F+P?KY)L&_[0&UX$\,0:(CD*2C"UW;JP&&-('"V
M1&/AD]C-T)^L'_'#<?WXQU-*%47P,;<C3"!MY?_D(67\.XD8RK^GM'7EK0U?
MJ/<[9214D8Z1U\JT42MT_)Q8"H@Q/,=P$H!#EB9^B"PF"&(+7:TPR&4KA>:M
MC<[KZ"VK8MMWI.V!HQ7"&!OUB/JM(ADD;-N.G&K3<)#Q/=\_3=C2WM$^@11Q
MUK85L57]+BB0MH1K=3?HJ&7.A0>K5>+57`VPXSBRH=,T1#ZI]`)-=43$=C2N
MT52J5VNW=FK.#-[*C9XPP^&KZ*BJXNWMK?ADIH34)@#4V/81KO'(Y]$``"``
M241!5.,9W6ZWPA,^,MF.]<[-I-LI-2>^868SD<(3+!SD5*D<?#YM1`P(GL_'
M'-;A(G-S;JB[5J1;*O!/):U#QH#2V+#(;/+B_<##E__,1\R:XB`H8H/$:O,S
M/7*X-4#4./M",.?<K>YX+?("/T9@?8/<O)ZS<L%E"]@TK95Y3-\XD*$),?DY
M92<(M;[?,OD(SWH8<Y\<VJON?.=PBW$^/=$NCZ)6^Y:FWAW>".HR2JK8_7ZK
M+@=7[/MN?&R3"#9)N.P[MB38_KC@KS__Q/OM?4P11)&DR&NAR1;D8K+6D19=
MTM+A0H@;+,"/U]=N`\A3BU:$IY3P_OZ.V^TVP!DWSA2*`?>Z/Z$YGA>">@J<
MMW'D)+8N1A2;\"ENY*R:OPO>+V"XKK;1?]]'ZV<+8YT7Q),0M/X2)QIWMS%@
MT!W;S<]9?!@@<Q2].1]]H6D(0,G%SB7,BDZN\&M*$:6$(CKY^NR%V3;6XS""
MA>10VZS.)*;Y\@%58&,%7P+!E@K:]G@^>\SA.=V`5<@1%<.0C:R+ARIFG,$I
MQ$]Z&''\$FE>J^7LZUBX<L+2AGTOH0*:GX%=VJS4/SK/C6R,R#!_J+/'5*"A
M@L.V3#M=1D1PV7?<'X_88#T/,I\N[,EBU^39+%XJ9Q2HANEM9(_ZW&7%Z\LK
M?AV_BG\LK,]CYYU)^??K]0I%08J+T`IUA!Z%821LJ?#;5!7O[Y5.0?&^Q4MV
M3"<>CR=R?N(XM!=@>Q7;E<)52H!#%?VH%O_:PKN=D]4R-2P-/6S69OV1[/&E
MF-`O6V"JI7^`Q%R5ZL#I<C:^>CQ3C5)BX!9&2OL%+)9ES\<3CT^8\C^>CUFM
M+AS%F^JURE`\PTG<"!?`2'%+'*P@E"96;-EZY*L3>_FHV9SS-`6+7`WX?T>$
MKSO.[H3"/']B2_G&@$H)3!9O]CM-(=B+S=1%8/[G?`'IT6@1"XJ,<YC=`92+
MW?JNYDKN;=/&<;TM4JTM5GOA@=Q=%CI52Z<4T$Z\Z5QF2\,X<\MHUI3<EY_I
M.]KO/9\'_OS7G_79^Z,4O&"A;D4AMQVH?_?R^H*T28_)+ESV9_6R3M`,',<#
M:=MPK=J%QN>7@"K74/:V[XF4QO#EY06O+R\%+,C%@WG?=[R\7.F:EF?C<;]#
M4L(&]*;>^S-/]#<=`4RC:*6PE4#XSL_KB+*V=$A8<J(!\I0:?M0I[W?!^Z6J
M5'ZWEOWDS^FRR#:%8U"`A=\9)`$99('$(\":TVO&0`O*@F;%H4>W&RITA<-U
M^W6QW**-@X48&4UW:2-;,8\[%R4G%R0Y'SBXF*4.L*5TB0-I/=QB\M>9]M$+
M1,#SK_M"UN**24#GA7T&11*)QTUFA-\S@(Q-43Z>R.^Y+)35$JKXI<8-T7$<
M7>T.!0XG2VP-C`J-O&A#8E<%Q9R>M.T[\'B84?54+&2;9F1$#VS#Q(6(&Y/M
M>RD6&Y5C.L_G@<OUBI?K"][>WT?<:/.>30-)W/>]_WD1G>@0><$*?!JZJZIX
M?WO'\SCZN;;XWQ*`D>JF]ZP.!^48>U%<(UEW>I^T6B:U1E&U.BP0I<<@*[#\
M5<WS_1C1OF0C2F*G?"*:&L],A@-S'5VP9,Z)#D_F/CEPH^BV$3_N#[S?WO$\
MLG7Z`-'4:2.5E(!*%^'KD#7C^7@@'ZG0)'+UBZ7IE<ROZA#2^BDU1IPNTWL:
M]Y%]JY4"$3(LSSHJ.-EK-6==%$J!PX#;"+2BY?[S^=[Y/:!9T76`H_)E6TA(
M)HXW-\>`M6:+8GZ]X$VL_Z$5&UI%LT6DP>@O.A^XVS-6L*1,ZD;:83+1ZMF^
MIR1J4GH8CD/K)-[RN(?5G!F0E\92W7[AF!&F$":D5Z04BK=;<7&X7J\5O%%7
M^`&OM1!M[_-QY/(<2N,;)_SKO_\;:4OX^8\_\'P\\/Y^P^-^MU0G.LQ]V_&/
M/_XHS77.N-WOV*JC2@,-4JI"V/INC.A@P>5ZQ?U^IW6L-C@IT:(PKK,?7T_K
M2IW,F%2V#SCNW8#(Q<?W1J].M5BT]LWA7:"B'Q>G^AM5[:)@_E3PQ+PXF$5%
M/W5BQ@)*[=!A"H!8FI)-"@E>'*1S"QG9F%)<`!(:Z>1QS>B%^F+7K#WV@(61
MR58TX#D2IX(XWN?S:1"KZ9RI0)WN?QWM#?3<FI\)"X%$@_OG>*0TSK&V8F**
M.X5O.GCE+3S:Y_/`]5IC62L://Q8![J1G?!()Q4$H]EYOE_$#^4B0JM:^W@^
M8[]6.H:V`7K1#W\WCVH[YYT.9-]W2"T$6:C3BO/'\<`%%^R7'>D^D*>.IJH=
M?1W'$[?;.Y[/)VUB6@,:Q'B-MB(PYV-8[3ET\O%\0#%03[X6N=V[)-WKLON,
MMF.LUVG?=PJ+"&S6O'L`+/VG%%9'D+H%&T,<('P>F33I:"J3UVM4<`E18OCO
MWBK',4]V=,11K)SC9@THE(K7&H'\//#()50A:^Y)7UV4B#AP`ME*C3KU0G,O
M;%-[#OL&G@=/L^H1U+U#4WB`ITP2Q8BG;EQ(9C-14/=G=GP>%<VVP4QS$2V)
MT%[TT;TMTL>JU6@0,.""XY*W^T&-I:4QZ<07&_<41HR42%.R\7.TT:B[>L.W
MHDLH+?!H[A&!\V*[!QM1*^Q(/9N"54#?!TNS&&N["Y_OEFECY;N]O^/Q?H.(
MX(\__L"/GS\Z^#2>[O$.)4G`5J9`67?<*XU@@^#UY07/QQ/O;V_84L(___@#
M[]N&^^/>&YN7&O9RO]^PUVE3>4XS_OCQ`[_>?N'Q>!0GEMKYY[I672Y70,IW
M_WI[P_OM?="4#+:FUC:,]FEA.IRC<:::MB9"GLLB;J(YJ`R^6#!_CF@M&M__
M7?#^#U,1".];%KU?C1W^"&?VO]'%*Y0F,Y5O:D<VJG8<;XRPF:`JEKW4S.*'
M"\")+<$Z37848S@WLE`@,,Q6:`8T9>JVQ6PI.J$=YQ=3"''BT7%1HI=-)#<A
M4/<-;"^RX&AH1(4!QKC7%=EN[&<0^"I2VK:MY+&[`I+O?*&:7+K(I'D3,^*0
M*VJ07;I0*]Y-"'E`;M%5MU7/X<@9Q_T^\WTI(&/?]QI1JXZ#9V\J-P]3TR'2
MJ0`^_:O]_O/QP!M^8=MW$CFJ.5?1YOGZ@,BCHVX#?7.\OIIRUS[/A%\XCF9#
MF?VQ6VLKF,+#-I/E.+:ZH=]<`\''Y1TV+*J2NS.#N>;DQ<GWE[F-H]#)(P!!
M+5IKZ"]T'W/WRIR;'PYV\`VQ\?8%2C(5*/FKC>,S<9AKY#'`B7@ZV2/.+A=I
MC%Z[M5YRMW.DSW4=@`1)7R.1A%P)U.H#%K',`(@;*].?:_6:[N<<<C.I8*N"
M8^:F1D5J[@EV:18\F4*=W4N8"A!-IPRW(UQ?2VWB;`;9.24@C_5W07QJGAK.
M**#8>((F5@/0BMC6]+)N!(X_JI@%@H*!$C,'V2X1A0Z`9-^9UAB]O;WA<MFK
MI^T#+]<7;/OF-!#C7=JD%+"0V@1O/\MT[UD:QI?K!5L"?FI!AO-QX/KR4H6T
M5T`5^U:NN517FS]^O);/3JD[L4`!/3*>>B\ZB!\_<+N]5UXOQ2Y'DTTNUAN@
MH,UCUSH*"7DB#[()"=+4A6D2:..;1G'--.<_??OP+O@V7_+%U:]@NO(%=)>_
MPW[11T?GO[>+B3[X;2/H",(PU&VF1JWJ.%Z`2^@*[,1,02E&DT]?:%/'+)!H
M#;GA7H!NG2,)4GE06E$8MD9:VF;1<6O0P)0"ZX#(8<;Q3+!OD^?!.Y;*?<[P
MP@Y?!$EP0/O>A&8/@[JX.6Q-I!J6/9FX32;R5*J53M\H,(>&B&#?-MSKF$R<
M>?YG)AS9A2VTPG_?=MR.@T:H&@:6\*)F;D@M<A(5\)@BB:73`')6ZT&B\85N
M\:D34HDQ0FMH6!OA0S(A@\/2:+:7DJG!80NR4ICD(4BC<\FUV-EJL(9YM=KO
M4Y@$>_XJ1PZ[$K`5JKF+'QW"AZ$X[ZAF$&'*Z*"8-:#0&R;./FPXC(A]IAI"
MGW/"ME7!GN$$4V2V(383'Y1%:CZL@8=/C$:Z=V0UWU/FP28QQS,LMZD("\(*
MN!E7XJC)PKLZWG^D%Z/EN5'#J_1K7.00$>U_)EEN@=I[WBMW"/V^&.>3>:UK
M$\92'#G:"VU,0NY"F=PC6LRLTN<RZKU:HL9TC^@RM)FH>8]"P\RA:Y!AC2D$
M6PO%F+/=8G.#>1X'_O?_^=\EX&4K4Y[7U]=^?)?+I:.QJ&O/M@WZ@&[UF.C/
M`.!RO1A>*Z"X;M?V`/03N3_N/=HZYZ/8#BIPO5P+4%"3$5]?7DIAJC":XM8L
MJ(/W(@KA3-HL_TW"0FC'_Q7_OLRFK9.5I7!*WVC&O@O>+U,:%-&$_KP>9D=J
M^1(;(N+1_5:A[KS\5M0%]<-VB:_-,+/7P!%,N]!`(R8"1=PV;JM2.V:V9%?/
M,?6+[6LZHJ2.:27H!/^&`G8DUA=YP?U0X?P#,6.;QH&U"6=*B5IPC@^-`3KS
M6#T]9$),ZV>EE.`&0W;OH+%1/G+X[&S;7@S\'P\\GX>!S!OOM*EP]WW'OE\*
M[^SQL!9.O)A5VH9`'#)I$2NF&A0_1\LUY?I"36I00][R=&TN^]XWP6W;Z_>,
M%+&!?BY$FN2+6_P]QY_G6MB-R4@IAK,VY7E%%S-&(6:,.KBX!5+:"+$9X^3(
M:FD*\:(-OCT''=6JU!IOO]6:OAZ-G!MM(8=4&_/*BXWV/"V^`$MQ,.5!N6['
M4>A.ZCCQHXA)R$(4)DZ=@E;OX%(TIN;T(`))7$@U,5W=1).X@)%8,-:XBB9U
MC18%QAVX".[O5AK^JQ`J=)VO*0/W'?T2.T7A)>_<NHSH%^PR,ZTQ<0RP1XU9
MH#5/#P;";SG"@\/N&_<V56I:$1\(`:?!$']-F_V6P%!MV!N[N0;P>F0*ZF@?
M]0$<"((FV95%<$+U@GF?@7G-8N<('U31?NK(BHP,',#CD?%\'H53N^_(6^K%
M6Z[QXXW&X\6B37B][5NA<^0"QFR=8G+@?G\434LN]_11W4RNC?9PNY?))8#W
MZK2R[=MH/)R^+(LO84<=8)(N82/OQ31U;?HT4/78^UP"1G4$6(S7*A$%Z[O@
M_3T6PV=!WIF$H@[.U/4$J!<N9U&T#@E8H\LX+7;AOI>I#J7[G@>#:F92EJ.E
MBUU4=:8DS#U?V7R>'9H\:0[\!L]CC'H]GL>!#<-S=MLW;+HA=W>"8RC#@1//
M6*Z`J0CAB1V-H#FFEB%C7?&YO6<M(=56W)().9NYF&,1/=S?:8]S+:DY5^Q[
M-D*E,B;-W?NU7#.05_!LQ,X604+&ZZN-E0OOXIB@HS`+FSC>A%T!6<^G_>[U
MY8K]4MPICN/`X_X8L<<ZT%F1W%&QCB[VR,[D)A;\4@F)*@A!;,^&ZD09*F/B
M#=?K%9?KI8B"<NZV7>/<V/0>AGK##58;:3=K+Q7+@VR1P6+P*CN!8<<)#>*P
M&V)IN+H8QOIM3"YRS,5Y$"O>$>J<#3=YT`:JSVM%@L5[G;)H2@0OKZ]X_OEG
MOP;BC6DG0=&P/9C6RF9/1]0&786O-]NRYJ@@:0AMC`Z"`Q4TF#R1@)"NB2\Z
M98H,ICAIG1L;_EXY";J01:IB.P;?R+`+S_R="`5S3'N(TN<G_UW$#=5<T(,:
M8)UXTA/B;,))8/0>?!X-J6U"R=Q&Y(DF`HW*,E%"1C,N_1D95.^#Y!A9K<PY
M4([@_G@"*%2X/_]ZP[9M>/WQBF=U:'@^GC5J>Z/T-<6??_[516`_?_S`\W'@
M.)X]WOOM[1UO[^]FGVJOQ_O]WJG6^7''_?DH\3<533]RV2NRVPI%,26:\3Q$
MLXYDOA;T!!0_;LU%<Y(+'4/%#"J-C(5U+4,#,N]O6H$XA0W"T6]*P_^M,AG+
MM!]OOL3J]8\07J%(QD\>PK(XGJD.'_R4?LQ$'GN1!G&;=#123/D%V5PG<30#
M\&8_[XNC(%;@F9^=3PMIB5."M.](.>$XGC@\$=\5T9X3Y*UBK8;.HUQ8&RTO
MKJ'GK0+`\_&8-S$GB]9>^.B$L3-54G/&O?J>3@(VOZC7<;7?H-K8K8_#_>%$
MZ74=F1,\'WELG#I0-'[>@L"@ZI<KQ5\W;15!/#J'NM3L8A2Z<V*2=,LB@^(G
M<3'*Q.4C3OMD3>=%>3(LHEZN5URKVKK$'M^*VT$S\6^7(+>-E1+,-'<DN+E0
MI.HAW1N%K7S/,Y-OIF`:,??QK;>+ZF$"U'CE.4A:I(ADWM_?UTTMK#=F0P*%
MIC%C%#JXJKF>)Q=?7+2@(5HBN%XN>-^V,G6@8\MDL6403J!;&DHP%6O'HDK-
MI"ZF?VVRY-##5N`E^CLU"**&J+TOUGR#.%!Z#XG09(:NFR]4>7S/U[8]]SP)
M"1'@%GJRT#J$E`;,(KTAALP&O?9I;[ZX]5'<[>GB..*01A7X&[-8VOK2KD,M
M6+RYFJ:*"7*J#=%@FE+$<EOJQ%"$O&6;`+@_'GU]%@%N]WO__.,X\/)\XGHM
MG-S;_8:?/W]"J__U]7+!?=MQN]UP'`>>1\;U>L'C>9!#QQQ,T1S%V<5C%0DO
MJ^FX1WQ%C?":FV&MPN]]WW$C"['^VPGD9S_F/4;(;1B0Q"6O?YGIC?DN>+]*
M#?@$2GI>6GZE3%:#<'[VF[Z*0LO7ZO30)W?^K#EFD%O:@8@&G)Z*HGEC><\E
M41F*7@DL8I10U:+@[X&(?0/8]JT63#MROIN"T)RK!AU")-)`LAQ(=HUPI?ZG
M'C/RR6P69W9TJ38]SW8$;I,H_WL<!U*U*VL%M/$)IA_/R`8-8=K=$#155$ZM
MV`F!Q54[^,Z=,\$!;G(`[WGL4"0!+GNQT7E_?\/]\:PN">WYLQM*/K2[:HQP
M`3^%L0U+1ZP5ADO;QY$Z+,BRSOR^\APG7*]7Y./`^_L['H^G14"('YP[AHJA
M&,<("#B.PK%KX\=2_$K=K'2@]('(E'V3N7EISY:)C25?V8:LBRBP`:^OKW@>
M!XZJ%%?WLC1<.6UIHJ'T\2^)V]H]ZK[:&JS%)/#:.ITCXJ4.`Z:4A#C;6,8*
MZS35D2F(!BQL<T49>X1ZGG0[WYQ]$<O>S[&%&/]S0XI+T>KH`6K78>^@$*&F
MPU)PT$LR68%Q8]H"7*+/.N,`KWQR(Q]B7TA9.M-L0]7N"Q^S%^1UF[C.TW4%
M:VVB3!SZ-"D8:V]'W\EBPU(.E=#>]JS58)D1#=F/X7*]5CV&;>;;FIJVA./Y
M1-:,E+8::)-[0=U\PHN#PH[+?L'VCPWR*U6:U[!8+-.^"_9]@\BK^1Z_#C5[
MO[Y^U4G?D8\YS55(?Z"P8K0@8EM-1F$%<9[/X?/=.+>\[M(>S/;L&@!<D1B3
M'Z#O@A?KCOLSE>[G*`T3_'?J>2N8D<(O?9??=%/M)A7XK.E:%*'ICR*Z5LM3
M<UJC56"&@,87SF9)/<PWW0XQ,7)E[*)$G2!A"(J+@#Z!RR69$:TZ];3A+8'8
MH'YQK=>Z>:X.$=$0D('B:;V!_71-?9;QXCV>B7`:!F.T?V]6;&6QE&Y79ZX<
M%==,8/04`&;K],W#QW@:E*E&\%8/R$SJ=BX3E2RR_)/2N-NE8=EQ?]QQ?SRJ
M7VXVJW&?CK3GH**C3>AVL)]HLE['8Q.P9&R3B:'QZ^W1TYPSWM[>K(O$2$%P
MUCM2^'R@['@,A*E%):>T`?*L(\QR'02"0P\JUNWS]>/'#_SZ]6M"4M@_M8O4
M',6I\6P-&J68[AO:J+_%'Q-/MF]YOFF2,4)NA3XW7]+&R0+LETMQ`*E1T7P]
M^7</"B<H/K.#]\%HI9@&G="]AD:J%3_Y-+'CR`$-H#WK&D_R!-8&,"@>.0CA
M.+)!&<]H"HR<^L(Y4[/I[0*97^F_(W."'*S?<X0H>Z3:HL.6$SRM?R)&:.@W
MBCX-4''`QB)2N%-94K^?0RNGYCDVU\GS?G4>(WJGFN%OK68R."6!IH2?/W]V
M>[`VL6FB5)/ZYDD/]!PWGNY6/=?S,^-ZO?9_W_<=VW/KC=#E<L'UDDJ8Q9&Q
M[7L'GO)1IQNB>#XSMCH1W>HDY:^W7]VF+=+`FW.4>(^2.1.[.!8QBH`A_N8`
M%>%3[]:/=O)Z"@)^VY+]'2CX-ZK/3YKG:@QH?E"D>I[OT"V*%./[C&S<":)B
MR*ON977X9VX/;;3#RDWY'#JN`=IF?M9&$*V+?%+(V6NCIV,8CY9,BQN(N]13
MY=#1G]ZQ`Q9M0^-`HB,.?I/3]=DL4!J'!--FGR2RQ!OG]6C4"(X'#:Z[]T]M
M"S`[::@416\3D-R=Z3F?Z^5RA:(LZLT<O?%-(3-M`;#V1_PXI:T(,^XU2G@H
MH0?$;Q3>7*,:!X=,X^)Y)&YC1K-[7R+1IAVIM7C>XWG843TE:_FW6<QWV;'J
MX_'`<1P]2>]RO>!ZO>+^?^[&&24;1*L48-?K!;?;UH,K5!G-AFU\'/U\GNI(
M%="H<PNH1;I0"ER2$;JB.:0UB7_A)SYLJK'/6QW3'HNU1-"U:DZ$U='DAOK1
M.]`:'>\]S)[@`V',G1:E87&IR_C6?OUJP\=4`VY4(G%=1!.*_IG%>,S-]6$8
M/B0"09'<G!I,6$8MSLXH!6=(\'"4T%-A=N<UNSO,X1("YE6+$=DQU8_)!4GL
M.RXT9A^?H8:>H]Y51V8$TTXJ[9_P=XEFW-]O_?.V*DQ[Y@/;EK`A53^NU-_E
M?!RET=>A1Y%:,.Y[$2+_>G]'/I[8I(`!4,7S>/8$PDYC:$$WETL7=>4\]!PY
M9SQ;&NFVE?3*/-[SY,`?;A6[/=@)$C92/,=TUE!(HNDJ.9UXQX<.Q]$[STYX
MS87FN^#]'707^$(<<%`M=G_3S]N?G:&SU=[NM)24))!L,ZE#JH7+,C"2%_G@
MF$4^?3XZ+8(S9T#F<$33]G_D:+QM.U1SV1B]7R@XUI!\27F!/BWXT<,\NEI5
MCZX8YDV6BZ+#'+CC])V(#IE79@,[))P$G#5E2@5+4U=(T.$4-,\6GNR5.4;8
M16V^I:V&`V@8BB``+I=])*(%"'>C,/CG=$X>%NS[AN?QZ-GNMLNW;0Z#Y2TF
ML[P7($YK_3TA+TA1>&.C<6Q-E`@[MH>-^NU!$:LV4KSHSQ<^<^-PN]WQ\^>/
M2LFIJ6(--9-4TYB\(*EZ^=:(XUBU2KZORM9^LW):P6@^Q3Q3LR&)T-P6YTO6
M;5M+2)(TO'/]6J>#CYRJX\K[V]OL2E&/+VVI;^@%]<?8DAGU-<NPEK]K"5ZJ
M4#WL1DS_?Q3,\S1E%*2Y"];$\9C:^I(,9:$\=X=:/UQ/"8C05+X6*24;6E(_
M6\ERKCVC'%S!!:9OLF+?8AG.%X`M+&MQ'36]MDB4>7KCBF3/$>[>N=V9QKH"
M29\FS=[#7-2W29SRF.;,@00QC>W<O:2=M_.^5^!^?RLB7`'D@6Y!=$R-[ZFR
M'4#A]_YZ>^OG\00@%=3HMFB8GQF.??=TQ?:S]^JE#M/@Z!Q(Y?0M*CRU75\C
M#6D\&I0$,NUA(TAI:#6\C6E+L?LN>(..]+SHU2\!O4OG7%7_N'R2%_#E"KZ@
M#S4)*$E"3GDJ:JW30N3$0.,?LU'/+Y]\0/E@&G\B-;0N%QF=U=;T%0E1T=<X
MAT#:BH)_.!8,HZA-BNBIT!N.<$3HBU!_?$HI<UYL80H5MJK1@(ZA0;@(.WI,
MR+I'&PF1D,\\&CH6[YH2-5M2V#//7CPI=O1JQZ%!)*J6\>^V[SBJ>&*F=$3'
MH!,'1JJ'[_O[NUD`H\^3%/5-I;A)*!9C.GG^#N6^]7L6\YPQ"8A19"]`@FCE
MW%;F!XK)N];2.]=1:_<C/KEW!>6]0_&C)",!>']_)Q3.7X-:2!W/JO+>3!'$
M-!'O#`%GD39'X,Y-<$BF<9S=CI`Q1[V&>$RC]BKR276\JJK=+LFL*TDZ545$
MQIBT%>^B$TN(_V5+FT'&1Z&O(^J6T'..X/4C[=+DH%,Z^,7T8B4K3)/U:-X5
M<3R%RKY9UGE"(6[]3.0,@?8LF$0Q>V*?*49Q0G7P*/7XNSG=;Q6)+.(YO=1<
M+I+F^+W!(G:Y^1^WYS^)I56E)%9<RE[I[O.X46'^?%\_\GBFQYXKH:9EN@TR
M[F]"$$&/F"?=US"F"*EK_K@X75Q#YD$S35&,5[TL&P8KB)XCSI>%4"!&3T2]
MBCWDZZLOPR/_N^#]),*KBTI7?__;SM'@OWTRXXYG`*EN*DU1WY$CY@CI.7_"
MTAV&<MC0'&&C%76%2'?2O)V=]E%OPD!/H;Y&](-Z!/X`>#X/[)>R2:9$]D'U
M.U,=5Q[/H]L]34C7)RYS\"ZZ_$J84<V`O`1AW)R%T1:N%GK^_42[&&/J,?)7
MJS[KBR#3&H9=T_Q<&*YC31%+::/K**%#P^-1Z`>WVWOX7,!A\"9UK-[I)*F/
M69\5W5U9GPGEJOMFCA\J(]:K#=.X-6)F:R.-2::@#`7S6]7Q78]2E%6_WVW;
M"RH.Q?U68T#=5']E_'_DC/O]CM?75QS/)VZWFXU;#HNF<OVOUQ?:Y*T9?M^T
MC=/`N)9'/G!KQWI";1HV9+78Z?9VQ0?;1P<7<Z(JJ,OLFTM[7BK<[Y%2B*DX
MZVEK]?W=TH9GMKQIIN<8I*\5!HV+S@57$RFEX0-K0C5L"CB*S1IL"$'W!YT1
MPN:HXKFD_CX:IX``/>W3!8^(.H2-+9[R0HNA+O1'U#8D<,\G4PG&M793M;!`
MMHX3OC@RSW"VT=Z=5F*-%Y8H>-1T\`&J`WT&+YHG`DXLJ;:89&[R\/'&K#]1
MBVZ:I:0F/TX^^3IX_@Q(9]`40TJ\?'O'A7;C/F4)-#!]+S;6BW!3V#48+GU]
M%D2&#68O4K>K!9H3=@@RZZ*A04SY*W1\8A)B_R,N#;\GM/K_%\+[.\>O)W^P
ML.#]6]=I%@4LDG6HEVLH%E>RBC/>Q`SI:@0&RGHK+!O:83/687EK1RX&W)V7
M*2<$!M5)1,+=Z./^P+95D1*/V;H';T:.T-TSVLHBG2N(&G'"&XM:+GG0QJS2
M!Q%8EP8)M@S+/K%DAQ&KB2F6U'-X=?)I59\2WS_C\7C@T=2V&EF`54H'4QD\
M,J-J*QR0XBFEV@``(`!)1$%4WRE@TG2>QX'GVUL7OC%?UA<$`J>*;YM-<T!0
MF.]+7!SKC%QXWN<P4Y#N20D:5ZMSFU<4&YZ&5CX?SV($CQH01ILB^_3Z_SSN
M=[R\O.#]_58$B.TKLDXY-ZV8>SR>V/=+Y\%.Z(MP/#&F:R\0_.M?_QJ4%O;4
M5DI+\QZQ27#=+TBIG//M?H=JQK:E8@<(&R.NG6XB!F%/E?L]\=ZU%9F5;UJ+
MWIP/,X9NJ*QW.`"%WRAK(K(M"C58O(6\>3D&NZ/B6DL26BQM&EW0V#'OEH1W
M?>U:B%VC],C))HV`!E,(!H4FCXYU@=A)4%S[\_"(=O1,,STED=L&?%$H5NMA
MBR_VL8[]>2?_8:\Q<4XT[+KCBT6MH1I#0X&9`SY&I&9OX4E0;\C#XRA[=58U
M'M-*AB>M&A\B8&=M"DM9\-&[EJ1`]ZR[(:F98DZ3$D;IQ0,(G(=FZ9%*P-*2
M$+((%%B!PH,QY9#N_T3!^_]*L;O:5/3DQ!1?")X@MX`/U82S5<-2X"71L1*\
MSXDV61TJ.XW)/^A2-"([R!0QJU.U%R%YWIQ_H"'3@J@3ZV(JHGV"#?_M\S@@
M5>4,H1&\0SY7SX+`BI\,2NTP3UT].QU9M7VI1NBN!I4V00CJT6/'J86VC5J#
MZQ%OD!ZFUVYC-3\EIC<72MC*VB.3(Z0*9JHP#0NFISE"$4:AQ30+G6@A;`-E
M$M5XP^@."/8=4XZ9!5S2FD5R3'%M/;6Z[9H5W92BN`GM/$^W-7@C$4T7HIC:
M/#R?>']_MP5'HKA36%3^R`=N]UL/KE"7\C9=[:D(.V:ZCGMTR;6ICXISSCVB
ME%&WXEI1OJNAP7Z=Z'Z^]>_>;T/L8\)N%,B50Y\P<WM4M3M8#&2.TA$Y/8P:
MSG%<&L))K4GJ01+ANM?H`[;H7?FF>^%50R73EIRU84PI`)Q(DZY':`=&-\V'
M7W`3Q9^=LYKQN'_?3;&1,U1&A.R*@F!\<H&P<!['/EHA=9NE.!1XO==:V\B(
M%]WNZTH/X5^`'@P3K+F=*M76B%+=C^AK/^05$N$*IJ:F[VFT2;;4P&@/XNAE
M21(ZZ42_/\(<B`^,&>+E9\U7"^*ND0=J\J*V%:*7B*NED@.1S#42:L"KT]`W
MI>%W$.I/6)*%_K/X).=W@NMBT9JLH6K3LZE;$%3711D?X"32,O\L,2ILI?"K
M@>=T%FP%YA?HLBA]X.4664N80(/ZDF5,KZ%'"":40^%;U>GG+=?8\HG$Q55"
M(BXD?;Q(7,PZ1(JHHY9CXY@2*ZUA&U/:2&=?A'NIE<0/>9B&-#=F=K0L@9V0
MA*,SZX:@DS+>_Z=90CD/@K#@][I)+S2T%)+%RTB("?_N0*_'<ZXXC`\MA*8P
M!)=DG:=/'+V94BI<5LTVXCFD=XQWX7%_8/^Q(XG@R>_9=$W)CFQI=1<O/3[R
MM"54]1C8)54GB%:HA<&VI>Y0H1P_[#_+(^O.)[@XUF@?VWHQDQ>@<2'+-`@V
MNH=K$%GE;\?K$C9EOL#MB&X=X?<F41V-(^+.*GHQ8Y//<I\J3&X5@5@-B,,$
M?*##=)TQTPHDS<$8?3TT[VWJXCV/E+:0&':-:`M$XNO@QMK1!-<7>AW-[,=+
M(N$(#R(Z17].@O.<T]@:P".FP^[O=-LO?%P]4*/,20PF'FYAGVB89J-?0^+%
MVPW"%OQ0&P0R)HIS(F:_=^T8W%XP!2AY2D\'P(EB92@).NZOH*H>(C!,EC5&
M^YOO@O=W$&KY*L)KJXZ/"F5^J#\C8-,5_.S&V*>_IY^#Y",?`7/,&J#&AM^[
M+MFC(;_R:$>^>N-DJJ%TNC[J1DQ^!`T6[`=<XD#41AHUA0W(F&KS5?PGC\G<
M]PUUM*->2-R$?&@&(I@CFM5[=&A71%O[&!_1.8\A954;.C[&2/1#V)095;Y3
M!HK;_)4H.,+BGHB[%U3G)4Q#+:\N1/$I7I6RE5;U,#^(ILCOFQ"<-=CL:PH4
M)X*7EU>\O;]AU5KV2%O3[!8.]/U^-[2&>?PLRT+-HTN^.;$'81LF]JI(DIPM
ME-@)%:%W)26Q'#>+[=3'F>O8>$'%80M'T6JJWV-Z6R%/O%UN/C1`(M7='UOH
M-I,'/7G'Q80H^&=2:#HPBNYDHI&9UM"F=PT];0$DW#F(V`(R:J+LLS,[1:CJ
MQX@+B:+FILL)HAHG&#-7?2X8M7-C#7V/FH&&M`]ZR&@:4]`8)!EI;<TGW3>,
M?M<:;@7)V/ZQ!9PLIL<LU`+&)(9!%YW]_XR0K!"BK+BTKWTY5\BSZG7Z_4_&
M425A'E:,0*/!_4VP-<O$]^#CS(.RT7>(C_9KI9\7V["+RPWF4`P-UGP.O+`E
MKG443]\E[?]`07QR<S^J.X!S_N_9[TH`M2CT:W9K'WRE!/_DW=:F<91XA'"\
MO/S?=MC&$_&S)T^;G'C#`5.$.W-LB8M/^)&2($#]N`L?:&SG5V$VV0Y[XVC$
M1S^_&LFENFE+$E/\JJXMVVPTL%W`)%B<_7A"/ES%9.D2H3XVQR#F]O=$UONJ
M1%7S'+GC&I_R197::=!8$9T],]W'#-%'=E^3"+&&0:_Y_U(2BA^M5SX-)(F?
M#05"M7[WWA3!]7+%MI%@J'=7".D]W?>R;BC/HW);V?C?%#[:1_O>D]B*\>)[
M9L1'T;UK&Y=ZZDQPW!AQIY.XU.$XS-//)&@<7.CQ+':KN%8L@*T*A9+&2$@7
M\$Z9`MMS-P(>JV]&9N<!:R^FL.XCS2>U%?Q^O\A9B0^L9GV+$$?K*ZS3LQ;^
M)VN?6`VQ'8R"J/N/+X(Q8M%>_F#[+$6FTGW07*SD--M(66Z\V_.3=;:=S&T"
MI(M4,*=;45+&*9S8D0(NIC5/Q8`$Y2()\C$:W/8U*:`R:@UET>K%E@$<+0J^
MUIJY-6T.NVH-'A\?VS`VBEG-RBCWMEY7IIYEU"3'?CRPSVBJ#A*5PYM3I6<D
M2\'P_'"[3O<#^K!F$8KW%E<'2$`7U,JO_T9X@Q?R0TK#)_YNDBY-*.,G:]I/
MI!)_-;AXQNX0'I]^\E/D:R"QV]SG/">+2:W/SH??S!&GL^HVO&CT@QK8_ZVN
M$\@3=X0<P/*(@FQBD0C=CAJ=F;,KD/4S2^I:/6E5>,'@DU)=/UWJ1O;B<,^L
M:DT?/NO)["@-4]"<VNMHN&"^N0LV4Z6(:TR);JXG:8@+I;4)66=Q^:70":TR
M\WS7L%C['37-@XDY7O!/6KQG">^H01/WN[7FDIB[:]%H>O>R8M\V/-I&%$7'
M.L-\\SP:9)X+5>NR(6ZS4RZHV/>7A%O)>7@"P//Q[!QQ!&NU0I$/A::1<E6"
M7VAR(Q24(32>;DU.UHYV)1G<2LTSGSE"+_.BH&,ZQ))7:@2#EN[0T,TS<9IQ
M@R'+,0V\?_E^1]2"Z/R*OZ]V>T(E@9Y/TFIN.\PI/RM<6DPVC]^99M'XPL/Y
M(=.ZJ7T,GFLAW!(=VT0J7!'K,?*QF[ATBO9&G3)P)9H1AV9X+]N!2+K:(O$H
M5^JUY;A>F0$E7KB$N-1$/6B<5>6FW$_P7),Z!0]I*:K%W>!A*^C0;'7-<T6-
MI[W4K=M*GS/6TZ)SR&I=9&1<ID[Y:?<^BYU6^IJ@X=[?!6^$0/T;T%V!LV;6
M\P)5/HFN?OR=,VJWXO[*R3FMCD=/YUF?OVJ39U\8QB&0Q;A6S&;I/E<B5%""
M;V<(3^'V\?D:R,)LV(UX1@2BDCL#5M#K;`-SUB0$(V3FG_EK9?/HW0)-.CQU
M*Y-&OIN(Q0J,SJ^*W=#C.+X48=$[QN`2AE5,%S;B^'J!E8M'[L4B"]N:.T'_
M&9E&LU)V0V,.:BV&QLJ[8+X;NZO5./CE]14OUVNU=;OA1HEVY?>S&2>/XE>Z
MS1'HG([C*&EUJU`#D7#A&>ECT=_9:S05<Q[1Q-CDF/[0O9"E>"6W$7]?5UN`
MA,RKBU;AGZCU".7BFQ&G01>@(K^-AWM!*',2=-CCS()-$Y^<K<ALHA<@MBVS
M'L"?\ZJ5L(%Q-!`?VUYYJ!HTS9-O[4EQS`7Z<`UQ-"2R4>/1O'\6-9C@])A@
M>A?;CS1:`Z9D-$S/8,0M5K7BIQ3UH-V6,$_6:Y;;HS&M@=U,A#Y'7)KI9(=`
M#3=TVN\216SZB:$L:IQ#AS?X8GL:!?&T)\SZC&&')KWP'0WP3'T27]@+*P?F
MA%._[V1NL"&&YL*V1=\^O)]`>'_794)/=G+][.]\$<;5B-*@^OGC#*)$]1.%
M]V<HHJ>?>>)Y:[G`H6Q_689[OJR&V6EQXV/1N_A'8S%#,P,0@SS(2>?/W;<&
M"]N*"C&ILS_HB(PXAXHZZ)G2.C[7\$DZ\V^6@`_F?'W'@J<>Y.Y(X]*^)K"@
M,1Q,K?.UX!M#5%04J7.N<_]=D>8TG;M"N(E-M/)$A5"][H$I&J;%C1$PV9@9
MM&;0(NZW8C^6J[6;Y]]:PWO;"`BDC!>SFN9/B:MJ"B_B\DV"23<UZ;Z@)ZN&
M!N^N1=[BV.Q^WW4QYJ2"E,531K?*J!F]K/UWO$54BPQGCV)&CMPYC7`,&Q[A
MWX+NV`<]W7?X7%LQ[E'?R&]Y%>Q@G@TC!!:*])Z+X,9[!OGZ-A>,E?68=XTP
MQ;&;TK3O9"LY;P-FK@-6X3*1\'`T!QM];OLLXWZA>NZ<Y'R-^65HX4D1SYNM
MYFP`AAJ4EQM3:8AEM/>PR`W\;@>B19$/@;1!L6)QM[>VM"*U>7]=I.1-9F?C
MNB5GP2=BDV+%>&33!#([.AJC\9VKKPO:8/E_WP7O!PCO[U(:PI_\()KW,Y_W
M55]C":)GSPI5D?-J5SXZ#L5ZA(1`.RF(D=</BBA?$*NSN-`S/SF9JWO?+/A&
M0#[1(!B'!'&V9E3\!H#%`C!C[T^=HI']QA9UW:M[,%`Z#<W4(WJ!F`3U:$PA
M1B`V?9#KY.?O'4\7<R/-@CHE'&G/B(]0Q>*3*9.?HQ@5L<#HLBB&FF=I76#2
M\]%&@6Z]/.W&[XLX</1N_2]KIJ:I1?V+XRC^U87_F:W/I<CB3JMMG'IBE%I$
MU*<TK=8&S+GWW$R>C:ZSXXR.C4I._%PR<D.FQ4;2AH4.V[O90>PZQ:R+O,1$
M\G9N.8SQS#C6--#`K&J.:RX"!L5CM>^LA(KLZQS9F$6\W#/DMZV]0QPWQX9+
M%7+QXN8%HV>B-[\VM09"R4XPN6YZ*O+I'6J(<40CL>BIV-\%\8R#GS7H=!14
M$8!'7,1K,+7SB*_U$!8CR#*/;?-'E\&I5;Y$-`%@GO9TS!I3\GSR)=-ZQ#>A
MQ,04]NS5N;X8+@OSGFD*?KHG0\"MRT`UK\,11U,4XT8EYG^C"N4_$CSQ_W*Q
M>XI>GM>N"SLS/1TM_!9R_!D0N'K0?;I4EF6%.E$S]),5>>0OS!N2>?EU6:6=
MH)<K_\L9*39CU%5A[F2STSCE(^A;02X+`L_@\F/`V$A_C('\UXS1&"&TKM"W
M`J0%G8!'\VZ,:<=/8E8R842@`01Y4<V?H0P0$Y+@;9W\TF<VH98;;,:A"2QV
M-)])G8OQ=FP%0F1U)?$]5TIF2%+10%&H)M>L,$TB:FFL`7!+!(Q&TJ/`*.*E
MY,:QUM=W]H;C"%5_/U)8Y`Y*D;7ATZ"AG@N0CZ9;`QDCZA+9>8U0!O_53-U)
MLV,'H>M:N85</'+,L4\?,WQC"2998FWL>M/BN8[$2??KD@1N(MS,<5(7%UEY
ML6;,4P.Q%H]$LVE%P?!J)N21G0HR)74EF3C8GH+1IP4!C675:&3RAX_<('SB
MW1P]/"/*Q5U#`BY_$=M)0V2!R;&"=P<S3J?&*IEW$08T\/<VN7OE.?9-]->;
M#UKJC,][$V(W5Q-M2":[&HB-A>;WG>PQU>AE6+CLT>-8+&P]<>'\JW4&A^RB
M;BD19J_@%$M:J]52$OJSX!KO!#XWHE0X7_OO@O<#.L,R[.#3]ET!3/AE=/B#
M4O<3/F="X]??(6HX?9.U]_I`H+3^2O46#NO3#S\S'@U^)@[80[M3W@/S+F6V
M^?(%-M?D,9:^]H&5$)?3L&B7%I[`X16NP)&3HG/RA22YKAG_"Z:"T-(B[)C7
M^ZY^]$3GB2,,#(<'M=['"ZBQH]DI39B#(CNQ%4RJ7]ED$B"%KN#%.^H5D(QP
M9IL'/]3!R?R*+VJR4=;/X1U^;!V-B]OYRI&GGPU3%`-">SH)//`#R:Y\[ZBI
M]@E&+Z[=DRQ!01T^%][LGFDV;6*`V*[/1)).EGINW:IN#+';B82I8=V[]F0]
MB<;XS-&=CV6%,`>4'!KM>Q3>)YMQ<;C<LYSKA?^\5BCJ%!V\5=J+N(F:FJC8
M1`47%Y),'PAI-WYRPVCEL*FH'K+M=EM;,B[R$G,XJ5_F/^]\5\@R1K/8<GFO
M9111(S7DQ1S!.I9$?&Q_;SOB";'P*+O6\.1#SC?]J/G)JL2'C81ULMJ>)AKB
M4H0LH$"(V+%L.<X\V>\5,9H\?D1&T4_H<3\SKDN(-_U=\/YFJ7G&;?S0GU>_
M4O)^8$`K7S^G*,%\VJ#XP16+]KA=ZO0Y5LQ?:(I+H0=T^MVO^4^HZOF/AW+7
M&<GI]EX2<Y<D.%$U];^XM"![U7W$96S?9`5&MJQ0>VW9;[,ET$1HJJS$9M)%
M5_8:<@&U>-[9L-R)QZ;B#3!F__.]('1.U"S,$65#@J"$8C&6BG!*/6=3K648
M`$6"29=K3UUJX[RA)&84U@N[#`V`(X:%T&#5[D,KJ]QX:E@B7U+FC$["/(.4
M%RNT9G_5+)28[X;@&5QQ$?F\X%3DD=NR4"&B5(QDY$FD,OI+/P)R(^ZLIT7G
M^)5R'SM7D`IGR\/$%-+"#4;WML44KF;XU4K?R[Z\9]9D1A08B+XZC[59I@6Q
MPV:T386YB;4-'&HBS]T(E>5"HEBXU12QM`VZ`Q57?*\FM#K27@AZL9S#6.,:
MN=N"6&`3Q?R"E*;)%<5^0R=1*D^PS+/8W@D9FHP>&8Q<FQ`-FII&GW**C"YZ
MM!ZS'B`1L>NNFOE@(/B413,E;`"*X50AZF@'MI&WTZPZO8+70JBA/4I0G0IP
M3E/RTSR>)G5GG-F(70R*;C40(X2$8I0#/_UO']X/*`V_PR^03_UB3*Z6LR_2
MY4=-L8-R>JRR_+ZS8?3D0^M?K`4KP@M6?5TJGDI@7AQJ(T^Q*$R+#\E_J!L-
MBF@-_&YEQ8M$B"+W\V1QC(("!@;_0%9S\L7Y&3J&\QSVQZJ^^().FSD7DI&;
M!6O"V1^W>R>K1Y5=[^T0X>Y%VP,X)'@>9B_<@=;JLOV+.+(BP%;Y?FE+%C5@
M_Q1.R`(+"-5:5_5S@!G=<89;,\_W?L*^@Q1J$B::#?NODGAJXBU"#!H<-^)*
M%E^)&B:=E>DZHY+3LZ_JW!@2_1X^GB9(O,)$R6Y#3$7'E-<BK<B>S'`W5\5R
M0/W(?/^KYVGS'VW6>WQ]LHNS;M<].1J`*2)QSG]E;G+.V3R'3,WH`1P!8L\_
M(ZX)[:X(*4W'XM>)3-'325()7*!`C*C@XF2U[K'K/GM$EVM8[++/JG:#VK&.
MM^/J/LK-&U9@G-UY/?01X-EM4`9XZ"BMTNY7KEF>K!0+S4CH'I<&4ZKWF)`W
M,2=W"@DN/5_8`K_>RY:1]E#4J7;O4[AS`T5SU[_/VES&Q[NG&$UZOZ:4[I[;
M,T6V?1GC&3->O32-9.&>GP)U(:F.9,%V?$KOG-+[VB/9[>!VFI=^([PGE(;/
M%+N?%[7IHFZ-9$J_4[$OD-55/O").9H`SD;FZP>CGT"L!Y*JQFM/(R0ZB/WD
MHL.&?"DP#3_40F`K!-_[IA`*HY33KAK?/X$L-@,7/>QX%#I5[1)8@'T<N3=;
MH,U)>[F+(ZQ5TT@7\VB?A)Q0.P40@U2M-O2)BJ*1=9H'9R44UOGH5(.<M7N8
MU7*<27!&/@V59E%'W[D^PR+%/2$-F@2$.6)MOTP494SV<'0O%`%P#IML)`Y-
MY*+#^@';(M9W`EJC94,>G[<L;'Z6WK+-H)1B70WHG#3G'JKA?6H]-U7K:)FY
MYI+8S<*B6Z(V"$*YV3!^F\XK6&VSIHLPE.DS%_<(D]C4HK-8<-\C`5G[YV,5
MSQO\^Q"\SL]_XF*.W17:VI%@8X,9!>2BD:\'H[:NF)ZR:%@E[ZW)R%^U/<,1
M;U:SN@"6@/:Q<JB@.:!?YZ9]+.@,IS"$]CW.XG%N2F"]:"G-3%WC*55;P"N]
M*A>VS%NWZ+>9BM)>TJ/*_6[GGH?A%C3..]/"[3UP1:07O6KV8DZ=M&KM3N<A
M?CP$TWNM?EP:\/P5VKG*8F[L/#T76L,S0'::=G4'[?_?"._O@;B_1Y"8*$/Z
M<2&C`<7@*T>OML=R0^?E>0ZQPV>O@WSNFBTBM-1%+^CJ]R2&E.4$13*%A_.:
M#9':)//7D+K4GH::A8<%+[1Z#Y6I]^6=T&Q_W9W;@W[44'@\,1;EB:2!N+H%
M7P)TEU=Z@]*@&=';#2\:DR(8#Z^3V1=/DA&6Z7G`A0O+\"@.(W;9H/!\G:P2
MN(TCQ8RER0]3)&@P%VEPP#06S0N_8K[&0@6H?.#US;VV.B^4S,V?&V6K<C<R
M:#5^%-^:@>GTY#Q1T/O7KJAA_=VJJ70E5=`AP,*\=GZ9QAC<(^J9"W*I,B5&
MXU3GQZC^'"-CG,AF.;JZG"1J4-BVY,0(\>6$/7]M>@B$.JJ,6HH(([L=>>5&
M+$`)5[Q09:0PZ[1NL-L"<WG]U*(_%FE\3D^_<\_P\-9U7&L(..3,<-^G8\]C
M334I?S,$U9!U_XYI#3XQSVQ=F"WO?3PSJ:[GDL9L%RT]K2G2:D<XK!?%-%^9
MUK%^[WFOD(%N]\(PL4\UB>)$@'H]I=)--$+ZFSE:W5P3Q.T-,COG&(H4[^?9
M"D+5;\TCP[)X$F/&:(4;`>EI;SUDLKQ$4/(S;E:1[9B^$=Y/E'$:`)3ZY>(3
MF'FP,A5-_YX"W':`'Y_4^7><&1)(B.E^$K768$Z]XL<&FZ@XKE/48/!F8+C(
M$IV%HUZ$D/EYN:^NR!!$F73KSUI['TOX'!H$NR\^ND[=$IFLFIH%3E-I8RI"
MU:!^'ED4P617Y#?)[@+@A$@IB2D,16R7GC5&MWP!95!IEUHFA"HF259<TM+U
M`K0AFTU,ND^0[]D*.I4'W[(Y5@AY,D<3(6=0+YA%3B,Z>%QCF[BEQITA29I3
MQ7HZ$<:S43=B1N$3^Z`F1C63'5*9,`!V4K!(E1\_&G:C&^.D*3%P-7&3OF?W
MHLT%!3#*+35VJJ/<*4%4(40'B!#8Z%'S7%D-W#1F'^3QL\E'O_I1?F0Q&/G.
M^H+917Y[=3P+J-H];A[.7)"NZ"+>+<2+,4$4`+3K#FO=E6$CF^'$F$-.X;RT
M3;@0S+&R&&[$"N?`=@SUW9?^%*YU`',B&%/Y^!TQSAQ"R*Z.1CYU3FFA`"5Z
M4#>X]=LAVE(YI\675Z<J`N2Z`5W8DZGSRJ['8%!2L9E(PR*MQ[#-:UXXTACS
MF=:0EF-)PSD"[LN:E:7)LB%PJ7^NC"J?N+B&/CPY_,AH'IJX\KND77>S,=+H
M)MU?+DXUG@NO"FCYB(J!J?L_"V-8>=N*PP6_A(`WWE(JJ.'HQAV_TLXB'%H[
M$)8)M'(H2*H<J8;V`!+@U3HC;$NZA8;3>CFY#Y$YQ3+1KG7X*X1//K:HF'BL
M(MBV#?ME+SS5:&X@THL5;T3>D0<:P0NA!6'0AFLT3I]_*B129%6E7LULGV?#
MRG#7*T9U#:S2$5'F!O/(EA'>CIH2?:-E^/`,5SW76_@Y3R:GGC<G2:DBH6.\
MOJ7-<&G+M4\?+5+=,BI45OL"22U2U#GFBP2Z\;N!]95@&CO;6QT_P^U]%>T]
MP0D`+`LGA1DX5L643#=SW3&'4>@JVE?=F\_(N[KK47V0>R.8^^]:Y-K>7PU\
M5/F]C)+-9B]G"6D2WG;-N`0$U]4[/83THX#7&UZ[8"',FF?19<`U]JX8$:V!
MHZ$SN9G88YU%CTJ1V>:Y"S0-J[U-J>!B@2`,K8V"&Y1&Z#(0^.(KII4OI5-2
M'9\Y`Q7EM=')9<-[Q7O7#?B)H9FTT=HE!$F++3A',[1-G\'(ZOPLL)-/;4(8
M<&&$W]"]G,^QVMJ!PUC;%4R!`X2Z>7'[?I'OX(F_A:9^Z,80C5=_!U7^`%N,
M$F!FX%1"Z@"6""05P!*#G/S36QV-""T4QW'`3_?-2T*\PC;FRDV,$92=182T
MF?QP$1W\G9/!/L!Q@QJ?C%%:QX"L(+9,.?4CGI`DE\BDL`@MT1_4(%UCV+6E
MA.OE`@!XZ!-9<MEX.?P!L;#$+%K33)FZ8QVH"1>I(%24&YO3C=!;3+$&Y43#
MUSFV;H%GY;!%G^IR:^UM*_(TMT8##67N7L!5([0&$$JNHAE#(;6:N,^!JB5D
M'$#.2*G$^>I1><'(@*9^'`T560#Z,>;I/)/YOO6Y$L?:]H(T%><$HBQPL6;6
MDTS1H'4,/8KXT=1XVS,E>R3>+1,7!-`P_E?0T'*9^(Q\/LC:+;3@470,VRH8
M=P$A5#';Q:FB2^T6IR14>%GZBM+[LDI`XT:5D4KO;>M]=B6E[F_+E"ECX)_7
MJ*SGS+8BU-N#A<<;^/Y&:+8_!VZVVCW*FLW/MZD/'U^[ICGG@0C7SSV./$]P
MP@8AB%2F=UJ)UQYQJ,6'80CQY97KQ8%`COO;H&284!7PW].R<O9.&^O:YK!`
M+Y$D@1YZ.I7HSAE$Z;#S/;O"J(JM$XP&0#\H:>:J)3<;3?=+(3!$#J?].$7-
M$"PS+=!0/IR5W2H+X-N']^N%I[_9>E((?S6"-_XYZ87=,NP`P7@A*!H^_BZ-
MI_<RE\Q1-]X](UL2U"?.O762DI)-=8FH$74!'X5I`A!$UD*F8LZ^X#(A].++
MXU#L8**XS#,@',LHF'*\S>1G\N8LPY:1#6^+086GX)-ZGY%9E:"XC@0Q;0H7
M&=@[[UJH01WX^(TW@\BR.N,"RU(/XD>WV6EY1PKA]!^'9@[[(SLN9PI&^><\
M1FQ=/$6(BYE)"OU=FCF])C'))9_IF/T)P8L"Q;[OI>#(=QR9[X$8]"E^\HBK
MZ;B;DZU0VW@:TA:@0A"?'.6;$,L&7&&#```@`$E$052U!#UF?#Q*(]]<XXH-
M-:,]:UF-;W"246R*:2Q93(GI=[&P91JTDMGFJ_-^@5X8(YA:-$J809!J89ZA
MIJD?R+I]OWS]D0-JP!!T:1A/*_5<=$+-DW46H7L;H<(>!>SA)@VI]`(Z]QIX
MQ)G?-Y^&QNNNP(9[3,$2O;&R5"D3#!)1.#`[M=BB/)GUV^&^8/>7J(#F]4K\
M^7<+PTR^RV,-;&)12E"@9UCLM"%0:$_!%5UHZXKEK!]6*1)0`/TTI`C$LK.X
MLVL[BP]GRDL>SSO'_88Y.R3V#5`.D7AZJ#IE5O3C3SY<PD^=*)SHVY;L;R"\
M\D%>PH2CDB+^L]_7-C%KRK_^I>5('6SR-,^LYWSL3YQX\.<Y*_)Q(.>C6_2<
MTS$L%<)3&/P(7`'D(_>7;)58I<%-$AKE1/='W53<_KX8(=GJ0HG&)!7!!ZG2
M5`!TY:E$"*W+G'!WV4VLIL4ZZK2M2E>M#Z2.S^6@#2M^"D0,).*8K)D0Q'2J
M;S10-ZWD"NAA590#)(WM<@;?4BV,T$9<O@G()/[1834T"E&OQ)^WT#%:!0DS
M6"4]QJLI)7)FH.=?,2'F8?&"422EE-QF;?\[J#\(18KSHZC6$FB*'EZ_SQI$
M%K,%$3\GQ5HJARBC/U=4E-7&-]N%3P/Q)!>)BXI^+A*$U@*RSNI-O6_F=!:<
M-]H#>SYST6DXSL2OU-!Y(HIQQH1P3<#`$JS14?"[ZKS?[]:(D049\WQ;L=O^
MEY%C;R_EBZU^_VDM$>*4YZQ32-.$7N8\"62%>',QY0$&A1=J,+WH<(7^BL"L
MS>W/<J.ZY"'H%?!$HGD`,[4A-TN8WDSRGM@*TH8P3\]T$C/E]125:!_UUI2A
M2%$0.E1X2[/6J":1B5IIU\ID)RV8UY7^'F$XW$3"43Y6[[O,[YH$?M[R[=+P
M,<)[5F">,2]#)MJ'GJOV=Y4?YL\>K\YBL;GP]NCL1^CS>N,-"_W([%QMF$RJ
MW?"V;6;#GKYYBE!2JP"5L^M/+[9$F]*Z^%P)Y6R=:U\MM7757!`'@OKNEM"5
MMN*HQT)C,3$(=L<_2-@A20RZ,&UT6"QF+%)0'B4%RGXX?NT)I0:+="L1&_-K
MKJ?CFG+\K(2*>-<5,>+B@S!Z,<T%G>6G:DP>=L6U&E]/+K9[H=MIH<6[4W/Y
ML^/(%05-?>"H0='(?J<^E(35XS;&5N-N[F1\+2*G]G=FE-JOO4X%OBY"`%*:
M)PXA$BG%HC!7[\]#<U58)\Q>,[5H/#)R%6!9A-);9&7[W&\)0MQWE:'R'OZO
M,I3O(M"$$1QBZ`>>`F"?Z^RLOU8C08_*SS0>,47:JIC%HJB`*;)MXY@)1FL%
M?N3BX3UXV:?73!."9K=-Y]BC-7=>;IVCI(1M&\+2G'69"JA`Z!T,YZF>C]R+
M*)'`+6=U'5TS(-[IP/M6![#P\*ZM5+TLE;ZT`>W_H%`]((G\A<GM0)?W-Z)`
MQ'NU\<$U4(7.!67PN3S>&^X^=(ZJ=JI)7L,CI$:LCS"[*:@&$RIRH*`FO%W_
MK(&EJ'<W(D3[VZ7A=Q!>'Z+PI0_[F/'K*08KVZ'E[S@H49?%V#B>,%_A$XYI
M9H3W&?6>C&)GVU+`4Z079_*GC?Y)%HE"8D8HI@LT+[+[>?$.!,%L<L6NYMQS
MQU?L5(?H_@L52T'Q;:;ZKOA7G5>^YFDI?K1#1VO$:C*4K"I1P`7'-62CJO_4
M.U,X"N,(R(*(D6G+/T4H9O""%!^3[,?1-D1":8/*O>@%YD2SX0FMU61>;=I0
M;53&YE]I/-ZJ(TGH*WP<1_EY\+1B1H]]#&F_[X2F]&NIZPU<#;5G<$/YWU,7
M6&$Y"M=LJ0X]#4\]XB4&=6N(W6399Y#S,4K-4S'<U@3'/R3/W8;B9K(_8D6]
M4GA3H9_4^Q?D:V`B;\FRL"S_D\W]8B1T3L<*'!T$8;RQ!E.N<%D-1LW\3!M+
M,)=J)F[B(R9^C-PXF`=,2+I_'SW_&#[HQL54FJ0XXV2AG;H!#9I0D9`/RN-_
MW\Q&J&_3240.&<R?]N$?T-F_WG#_R5\>ZIU.U%$GR.Y0!NTF=^ZQ3OGSK9E.
MB[0X[4!(-(^+:PTSNNC%_2#491/?:P$1QAO8Q2IK)O_O;+R"C1^W6#_W?A9J
M0TCL\Z9F9NW3#L>C/!(+OPM>K!T:/C:1^@VX6.53IEWB.I:^X"Q(WQJ-R/6\
M6(\]6BWZ]IGS'P(K?*BV:X*KR%-R0I;P.?&>1AVX!DBQ.'ZUQK"K+B!9'H^/
MHEPF%#3,*0[.K6?1YQR,EH6"(&8:"(AWV00A!M5T!4-;!#9"TU5=:EB>:_VR
M:;7%9Z"OW?T!F.R=N,!B1%94<=0BPT9PMI%8JAN>5F[<`:?7&]>-XWV#(E%5
M<%0OKF%+5IH!3B\SMDX"(!/*+56H5O_9HSF]Z&W\L(I$2DV"0BX[4DH)FR0\
M'\_R?6G=2/;SB+Q).<+4%T[B[FE0["+DS8GC@ZX9_]8>RC9'.8\X7G'%S!1*
MX=YOF2S)<)J@9DY!!F(H37B&.$:X>YJV6Q`Z$B@]VT0:#_:,X2?L.:1J?)53
M$)S03?XI!GC0/-0T5Y:G':-^9P(L,XV`#7S@FRK@6.MZW[)6"N0(*/&BUX@*
M,#E%!']GKGO`.QZ6?#(5LA*`&/UG=?!3VW+7T&5U3I3*T>BUD3<H]L(1`XZF
MXA,?BZ"3Q7$CV]9,((WPMR%'2A:.7G9.U[P^RXTQT*P$#2C+WO%T[!,T)!\9
M99:);*=(99T\32;:GOCI'8(-QD]/9SW.:*`D`&0B/8$-\VG1[M\N#4&'_"6D
M]PM5L#AX?;PL\P>U8`!FMC,1/(K)#$M&.2\0IU*W/K6I?;=/-\G9)=0XQ`<C
MP0O#2]O7^SCR8=*02I$C'QYGY%XLP0T1A1O;M*^CY)43I:]WQ3>)<^+182?T
M\]H7`VCI`B6:$0.SS(6T#2&NJ8U#;0MW;RR<&7L7W>0BP1D1I:#[4N[-9;]`
M5?$\GDAUL=NW'6G;`%4\CP/'\72(E_W/EA(NEPN>QP%]/.HHB@H+8=%3]7;-
M1W6<&!M20UU20XQ](=$W+$4^LN,PB[$G:[RR)&J#!5*Y+N70!/OE`M6,XSAZ
M3*N2V&>@*<3Q4S4HC$BJ*6V6#U5T;CJ$%8ZRH8G\4FDL*4KB$H=R2^WLLF9G
M4V%1<SBKJS&:;\\/)B&1Z0_5)::QO9:)HK:C77\N$^#@"J$(130.'!XMI/<G
MM\U98='M17(74Q"2*69+4YG8][<7K(.:9,0Z!HB<TP"9;\STF@G9#V@TMK&+
M.<NA0-%-=R+1GTFLPZ`5]";N?(!GZ1@.K68>>2M@)E08\W7PHJZ9;J-+JSG?
M:(FZ"9FXJ1D"MPP^YBH8AG%SL6M8WY\C7\O%_5)"3[MG>;M'X2:>.X(K2'TZ
MEV2\%<.C86%9("S,M*Y(-K%,S#JG&FYU\SU0ASBE,>U9#9$E:L[!UI$Z[X.\
M#JAMCDVZG7R[-/Q]U%8_!G7/1C!<(:Z92O8ADHB9@$5,K>]^@T)M*+R=X;NZ
ML7I[T=4BG6)FJNN+PJCH$*N4#67;MD]?V[%P*;R8;RP\C`JXET$TO,;1QN+M
M./0C59]7W?*"D/5TNJ!3MVW/S]8%&:IB!"9\Z5)*V/>]+QQ''ES'7$>'V[;U
M\:3*4!^W>Y(JQYH-Z]LQ'\_G\`+>=SR?3SR?3QH_$V)7?TZ!_C.C.!G(,;LT
M2,URT&XQ5HZY_5]'/H.-OB'3PB/P6JQL:KV(?0QH7SSKAOQR?0&@>'M['UL"
MV6@U%7VEFM+(?#0`S^<#1SZ,!1,?>QNI<C'3W`X,`FGV.YTXT#T89"'\$O(N
M\W95=A.6B8?/EER>J^J_I_.7A1<KR_ME2)&;B*AKT@4:/0SJU178-G4LYR,4
MU"3BK"9)-8F+C]-RDK-K,AA)Y(UY.!AD4SRJ)7D3S6-.NA.'[#)*6U@4N;];
M4Z'!Z5?<F"F012>18X0*M^,X.C_:3@?ZN]-07\Q3J%5P1E]/H*?^OJ&?=.3X
ML$A<C`69%MF%FYXI%>L^ZG:L#21`K]]=WB<'%!'2Z/<#IGN,ZUZ>[&-!8Q$_
MY5`EBI:$@2`*=4U.7&R#`5>F;A!72GB=XGUK$DB?,`&'-YRA%XH?(;F?&0OO
M2'YLD\"1]JASQ*3C<W\7O/^S->_T4'5_QS;&)424^RRM7G1V,\NAWVSWK)L#
M[8$%0C@CDG.VN-F7FI."?(S$?H22FX5&-+3%TL_XW'[P9\:K3^VUYD)=@Z`.
MOXA/F;B1"[.L+TA4F"$8Z\&-V&)CCE'8Y.K[VD=SE<ZP;5O?S!^/ARVPM*(P
M*6'?MDF0Q0U`2]W:M@V/QV-\%AW/ON]X?7TM2/#S:5&+D^O0EJY6]`ZUMSBG
M`WM9-6<<.4\+?(L$E92P[1N./.R'RL)/(VT!,HB#JT?OX(;"NKQS^W[!ON]U
M,E$1U*S]H>H3F7I?6(0#53R?#V/+53BXN2./G`3'_JDY\I25T<@-9?]'S6VL
M6I['^3!1PA$HQ$A47)^2P,V[%_AU(&@>U27)>42TH/XR-0(BZZE=X?;J$,V6
MV"UCP<2S#PD*P+%1>T2<4=9L@Q]Z<Z&#JA,481Q0H8@;%L/-=>NP+W;]),Z"
M_&JB?[EI2SX5I*XCAQ.JL1T74QU*BE<\,>5&X*#TP%;TMZF-1FES?7(GA@LN
M[GC]]RJ:.\>,A(M#+L71,S!1"A#$BQ)KMVL"+)+M$=R18H9IS6UKR'PNE)S6
M-`^^Z#44H>0*XS%N5&[TW2F)VD\2FB1ZWKT[U9YDU]T3U!7#_?CY,X?E*C?%
MPZB3OL]MN49CDM$G<H(Y@8_OQ'?!^S?_HY_]^VGD2YS(&'`TF\MJ8S-0OA%\
M#85D7RA6\&,T$O#*WN.`MG&RC]#\1`<@KM#NB>%&YJY3P,/G&@P)1R3*GHMB
M4[!L`,2\*`E1(\2AKX.*$C2OG^V&/-KO?>XZYU@GU:S4AJC01Q5@8W!"3([C
MP./Q,+9![).95/&$#Z)@^H7V3>KY?.)VOU6Q%2%/]=G(.>-ZN11$R*1]N;0F
M\AP=GU7@W)P%*0$YIU#$TS;$'DX2V.Z(")("/UY?"^J,IQ4+*14I$&0]G,M`
M1051-N_'XXE]OV#;-\C#4D.Z@(SNS?")'K?5*,UUOO\2-3_!/T>HD1K1*0N+
MLD%$O:N&N`*3[T]*$D87SXCK.1U(N>B>J#YJ^.9A\88QJ?$OVVCN,!</$[]Y
MQ)="`4TRH6:#ZAR_M&H\8V>DS%($F)>:^OLY<Y9/G#^F\[64LG@<CNZ!/(_Z
MVY2#J`J.-^UM"CG6.O/Q.ZJ&^C"+_Z^]*]MN(\F50!8IN___5^>T9(F5N`^Y
M10#((FW??I//T4Q;%L5B+9E`()9$K$=HLYMV:F(5F=,T(MT#/Z='K!4:$I$+
MK4Y'[TM&EW!(LZBGU["MUO00AR(O\UC.CH=I!"X32#>4.T>30$O*L3[/!B?Q
M-)^/)IG=.NJ5>_Z93N9H&(CP&A:MR<S:-34*3@^*J"Z$W1`UU(PH?Z/@'C2F
MS,WGN^"]>,#L/W]72PNGV++)UM),P\@SLMMP#(-J3?QWCYIDG[_9JM186&)Z
M8E)\FD>5)>?_3"N<71H+(LY.E)6.4TQSH@@H[<.8"@HK@^Z0W1*\BA1_SBA7
M_FDSY)/.5!T*KJF'+_+*6)C3SM_GYR?$H$ITON@%R=@@K2.6=:05R=I`SY.+
MW;'8CY\]:^.XWN_W.8IGX@R/\<W%/H^1'"+&HU`7X,3.8W4^H]GHDB(RQ26\
M"?-LAU,"L4RMD3O.\R&U5CG*(<?1A6<!+5UI1%979'$I45!I4GM(B4N&@Q%=
M]@QFHVLOT@@(KPLGP'O&(V\T5H5I`R+D*)K*BETO/L-Q-#HQ<*G)Z'/X'2;1
M.]>%,"Y$518R-6@&CA-HFGWF%/C>GUMXOX7*+1/^D<K6G@5+BZ@TL<Q1$-+D
M0F^554HK%`+EI8;7S@1,*#30R6*W)]JF44H1>`&_5H^2._38DT$I<,'SGC%H
M16.A'&DY<:1MD)S'C@N,>F94FJVEJ+(CSA!ORHZCB^XSQHX"ZV559,--S39F
M+9J>#W/@#DY4BA2>`'7!F]=8$UKJNESZO6JAF&:!HZ-B>+&QT(`I+;2M6@2>
M@*IEFR:"P)#O4E>VW=^5#Z_9\[1@2U;2G!!@E^/K/(,P&KQ?'/536L8ZDHP'
MX[T=$RLM-_;03$YFO%LAY^[,1KB;!08WXX"R;M+`/.HVQ"(SD"-X@NK6=]@K
M<@7P])3.('F1K[Y*GQL\WI<5?(?99BM#'B:ZUHO+N>%:5-5:XBZ!YZ]6D[.>
M\NOSLS<ZG(2D8#-'D:6N(:&X4>?%:H;TB7:6;K<;O:8MO#T`X#S)##\+41B\
M8VX$?:$BRR3>G/N`+5/^6JN<]93CZ/0/6=R]X8Y!26[`VT2?7YO.K@K7=8G>
M,*(Y(%)FN6U=*(KV4:.HP-^CJ4+G-45WZ[)2:]<$SJUK8`WH&CH8((NSU3C:
MSB,X--MN=CI-_2D=SJVO>&_5-0XN6EJS<=;E"][C2$O?LXO`VE#P>G!ZI#D`
M825.M3/=++7B*IHA]K[XF19Q6;&LJ8]:0$O)A];RX`]L'*=+@;-4\\*X&<(A
M0O9FH:#/1@`1,@\>T![AG@V@&/BQ0D1Q77SYFD0Y6_CLUT$>E_O.H"Y(%+4%
MJVL(@)GO#<$Y69#+V@9`EV+@U6V8/8<\<)GKO3D.$0NF*SO'ZY."(`$"(\\Z
M"6M2+KHKK'/I?4#WBI)33;:3>LT%B>LO]FWIE)OO/W_(8[A\GO_F=^NFZ(6_
M;YW%S.2YR1JOPFF(J8:MDH:,0CB7B<98-R%_PI2'OR(7.77EM2J=\]$CB$#/
M.GXLDY"@A%_5&[9#=3_^/6M,#$=(RN^I%TV6-]\/JN0$W?6I-%CQ6\(5G'9/
M@.P<I<CMN/7-H@)Z"QZ+L))[TWMS"5=K8>=$*>S&B<L>C:&[8&U'NXEC3RV%
M$_O*(6]O;UP<P5MQ(IH3Q1@OGHWO.UPH1$JY.PZA3*7Y0+RC#[&&R$P\EW[Q
M]D(?2Z@/*TG)&^]?%</"G7I(4&,!E3FBD.<$[U88!5NQB.SX30ZG,3X9+1<P
M^;"-\/'J*@"\-M4'5.1C9NG*]^56XA'%5O"4U>8:6NH)K2'9:#P[=A*%.C1=
M-@E@6)@N/_(X(<`"-Z3RN6/))B=8#/M&MH;$PBI6+7#L0]'DJ`B[ZU%<((R?
M@*!'JZ;@E;KUG2<CR(??41GF.>Z^O.)!$K?.\5/.C9I-!Q!-'LON(5Y;2,T2
MD+L`CTDE**+]2_28Z\V('J8]M^JB#I2XW?-:GE0.WNQ7-0!,F3N).&#'1\R+
M6^\TJ7?$06=TSV_6I6';AHVQ?-N2_2TJ?%VSVI/OI46RQAO1OTZ=T;69A8")
MG4X[K9+-([N+3!X^8ZH&9>3!JZ4=]K0Y*@WH[$M-=XAD]<<,@0#.9'R"YQM;
M'T9/#)H#2_L3N^AXGGHG^PF"<*:Y,*^_.4UD%]W8(DLA4K4<AQRW6[?6T8G&
M/LY'LMC+Y')Z'V`3M)9AAXO,-FF:F&^&$".B4IV"O%-[&1%R*)`J9Q/^^/%C
M?JX:$#D^SR@6PZX(-S&K(E^?7W*_OZW$L#)<@=KK?_S\*2(J[_^^[X&+OK$.
MH=PJ:"0\:YHEU^VL$WE4,&&=@0ZF&P(^:!?<0M/$E5>57`.B3C86KM0(]#1!
M,7$\9"Z4AV]S]8IN)\0S,5*4J^,?(_)'IOB0DB=.D8[W-5^"M>Z6!*G#@@1]
M72U!/+,8X9U+028`"S2(37'MW^M9@1G0YDY1RJ@/"JEL[#6,-):+*>H51:*?
M>"7_:YF*_)#D"3!ILY`K,2P"IGM6>=R.J+3W1I[G;J;?L6@T-K+&B9VFL\@L
MZ?4!`:J#2**MG4ZN:^-61UW)>/MJ1J2A5LLJ\_EM<=A+DNB:\J\EHT;AM$;A
M&4,MATB1?:QYV%M=LZ_![<7`@6>Q_7GRPE.U;X3W"BUX/N%X&0[^+=M>B]CA
M[G>NB_J<T$"@74J]8-J!&8^!B"O$7CNAD],4_KDZM_8LYC[M,M;QP=*E3/=[
M=HH]FF;`(S8<D2:#9=T]K!>@O4]%LN0\J6[&3L8%&SKVHLW3C.-UH\WS/.5Q
M/N3KZTL^!T\V`0!5^:8(U#C7U9OLK:2X.)8YKC6H@A:UK\0-(4$.(X>[_?S'
MQ_OD_UKWS=T]&;`^AX5V69:U@NWSUR<C0QUM.LHA]_N]42W(%LR$Q:;[#.SM
M!.ZJNR:DRB%^P+5.^\Q11$X!*O9WC/C2/682.E)2_\-(?!:D%ND)ZM:C*:_U
MTQ;"R31DI0=%?RG./<MRI3L)ZX3LX<PX44]`\(7'DB&XDA3^-:'=("*[DL4B
MH)&B5@EB2@]N@N[N?@_^-\58=ZH`.BL\VS=K$F,LEE,LK!H%;&`#&-=V#7N"
M?P[G^@SH*^\K;/TVPV94W.1*+Z^5%G8_6*/W`H-`=`U93BZ#DF4OU`$[3O74
M)P<WF;7GSJ?5(/QFT#Y,0/A;J3DIE[7.)MPGH3;XF&`%#4S1>&V#:X^Q2&]0
MC]3DDF<NF*AID?<\]L-OA%=^7[!F\IPI:\^QO">5Z?/?_;L&86;/C\BRA;LO
M#D<Y1'K>]XFC+]F,N5\Z@_HR<K[[F)DGJ-EU61IC#&%!U)V%DV[1W2#.@_63
M_BU#U=QX#O+1UL(TJ\9EF*@J<KO=NT"MTAN.CU8=W_4$WUC<P#,;%^0I$HHF
M')>L;J/T&ZUF&[G&;9X$)C0!T%6@B:3BA+/6B::]O[_+SW_^(6&:SVD?EIDX
M>A.*XQSBK2(J)E^/+[G=;E+*(8_'4J\?MYM8;<$<TR=3F?OIN;E*,<B2FJQG
MZU%PQI/GGMN&DPGSD:9"J%<VKPB1KK*?BFB_#KR0M#A;J\;U!(X[.Q]8BO6M
M5Z?='C53&C<QRS@V/0EJ_EPSC)WC9+*U2KS5!BK=1MB+4XL%5"F'H^WH#";)
M/%%WJ8!^FA2*W001',67`/*8[@]/7`=8-*>3+H"!&PW9%0IM00]G24;4HV(I
M9<5$KQ'T<'S0:-M%EB<R(\8)S<?T,AL>N4S#F![6(%XM)=*&:HTB4"416G*^
M9$W7B$/NT&A\]!7O54RU4Z4IU/B\3"&`I$);WLM>PS)1;\C_+M"T^_LK.@\I
MX":<T.D[#D[/$V*^#0]XG`)2$E6?W*1T/F&]3[O/F=N,2+9J?I]/`;UJ2&?\
M1GB?%F=Y/6JO!DZ\7L?R9/)B-],]!O#DO1RQ(("("YGRNK71E4N_H8/3H$$,
MF4,#-?+L"=T1$X]5/JUXB>>S6M_U7F1.WRQ/L!,6Y4XS?`%?;7UQM&\H''IL
M])099'04C0L]9=4[!)UX2L:7J1R'E*,`N7_]+C-$-QP?U%9TY7P](2`5U.5^
M%*J!BCG>[SQ/,*K?735<>#7L[9E(`K_&L0R?VO&E@*:9B'S^^@R(V70;<-Z,
M2-,(_@Y@@?9X?,G;VPV>GR*W<N]I<R<)X.;YFZMRC>?"%@?4-E9^]N*:,2D,
M#KU#VY[03#C^KA\CKJ;-7.*?;9.],&94\+[5#'&!OQ<8$9NY4#J%C5KE"?#=
M?KJ4>>Y'4;&S5%0LP#I"KMTR4<<8VIQ7:U]SBJYK6,#3.BMN,YNDW7]G:Q#]
M+%I285QX/U[\>2]$BWN?0YL!M#C/&A+9,H38-^M(]_3ZB$FY&L^7D5=:$QH&
MX*4ND6$WTU89CA:KH"L8?VSR$L?34R(R>H>JSO.:\<@S(3/8Q4R;2S\Q*=,L
M;,1:]V:\B!3M?^]/4J-S#%'M$%$ZX8%R25=<K'.V=DQ[/XW)C1/6,);GD`2C
MO[8X[0?)>FA_*QS<(:Q-G=9JBO@.%*TZOA10;24-P6JB^--\%[RRYS+M=IA7
M_!!4]95LA'U-^I]XHBD7JI:7TCZ2+UN8/8(W/030"LEV'T6WY_UYT:LY%'V)
M?*M[HIJ*FA;O_K`?MYO<[RUHH-EL'7-#H"]'W;`))?E(U?UG0:L:Y:IO+LA;
M9%Q[.IT]1_2]`,^PR1A1TB*)<'`3%ZQLX3;^C%"*2#08"U5QO#?F@!7P><[&
MQ&$$G<:O]GVSGNP,`IML&OTJ0D(P4F#W`(K'^>@A%/<F@+BUAN,Q*!3NO.$!
M^1C3*`",E`IQ&T6&W*UHX@UW,W&`B?2:R-/VSAI&:+2&\7JZUJE0L^:?5A3L
M>8%0]CO]WZOM0FJ8?I3?WRX^O'/]ASW3&/-[M-8`OB,1D+;75V4*SN\`*UG3
MX5T2=M&Z"ISB>F'-M%Y79J&.O\O3%T;(A!>+90@H'KM-IQA>TY`W:P$YC/>]
M)1.)4(S"NFG><DTL(+:$BAK35<8Q98U&"$]R-WOJC-*+WNAHP6*Z*"!7<HX9
MZ\H,?^I%L:B)29U<=_^')GR):XX9JWO4)9=ZD"S3JV253JB;30)G>EL#>)3?
MGV^(`!?)*6'J"HEQCWQ3&JY0W&TQ^[P@_0,B@T_@_!.'L<MC4*Y.PV<RV]$.
M0)B4N4C0Y/;/J2$*DTA[@<_@P8[U8"B9?OO7HT*^^L6ZUF:@VD>%T\#?>_V*
MXX/)M8CQJM'2"S/Y*:@R(;[E48X^>D5EK??X7`MK5CB4H\BA*G(<#>4]O:<I
MASK5@"(:1U/C^(T672.$;0:A5"'4'.W(5N.UWO-VO\GGYU?8[.F8BM+HK%U?
M&/^J#U&`\P:"#AH%]F^<YRE63=[N;Z*J<K_?._)[4I``TP3@/8Q'L_A<A8W>
MC5%#`;-Y#E5]^`S3"'1.9R18&<Y([EFHK!&GX0X)!3**F3#Z5G&A;+!CY^FN
MA6C2)0R09QS#HD`%SIGGX*8T$&L#3$+N9Q&#Q\P<VFI=E"@MN7)ZUA8%X:C&
M.-U!?Q"@1*'P%0)7,DYL5M!69P?FUXGJ$KLX$"`6I>@+[%/APF0@=8:(=)<0
M(^SFC$4E.`<-6L2PJ_-%\+RG!H7!!7(H0(&5G%:$7B]4/!JE^*'@$L-<U!UC
M]GE'`4JN)F;A.:2`#34Q*9W_/>@&)B8GN*(XA-UA-6M3KV4GZ5H``!(K241!
M5/'AU]K_K3"]!)L%#%_!\!_D6DM-R]II+0CB-;^.D,]W:/A`%`R+9/7>XL9`
MA%A\-LC*+0'65-#.KJ&ZPQCMN^#]BVK2_@"%M6>EJ6T!O7T1Z(KDR\)KC+K]
M:Q`\M1P3TL+1CI&CX`Y?7T2K]2*AS)T:3;ILBV4]V7J9(R^WS<SH`-L:TK/C
MP=O11$*RV')5!;5/,H[OB<_7UQX618PTSL0:`!O([7:;1?GPDUV+C,7%W*4J
M21_16>=)[2Q>%D-%89&WA("BD1,M"VVM9G(<18[CF*()I(D<QR'W7DAZE?V(
M+'U[^R'G6>7Q>`1S=Y4#!MKCYBO`T9WV%OTX-4P],+5,B1;3-M8B+7'NQ\\?
M<K_?1$N1]_?WM@$XA32.BY%[3<BQ+J<1?-T,[_!%E23^M-O%0/-FUFP69+.(
M4`D.).1$()[+N^RR@F]W49?XB`$K$FR0^/B<N&@CUC6QS@E6:JIF5+LQ<V]M
MEBL2UQ>9V,2AT;ZG6,_W@/O>H!`>SV0V`4N#)(05[^::(-\,3>_9\?QBW&\B
M7",+L1H+U1T*;$Z$QMQ=C5ZH;AK1G!O6C5J2L`\%I*ZX8_$V:VG'[HNA(10<
MQ314BXR8^V:=U`@.<`"NKRV5*8$,<PI2P14']E&-Q2R?LU&6N8:.IC33Z;W]
M+HM:AF&I1\BPN\_HN7(3IADJKOENU;`7VZIL#;R5&<2R?:#'KDZJEC0NL/.;
MQO")Y#[VT^IO2L.?_OE--.]EEH+^-\=U4?U"W>J4_<#K:;ZMQUI0+!&+^%'4
MTX^#QMP2$2GG08L(TC.^B'DTS-Q<QH2\&7V5A^EDO!GYT91-^R8JK/7ZLGBT
M0D687SOK!^37-?K!V_U-CJ.)21[G@U+VV`!=B2+@G0Y&<MY$5PN:?Z_QO!M"
M0DPUC\7%.-EHG,NS5JGG*:44>?OQ-A/92O]<@R90P3S=2,RQJJ1A.S8Y@^/S
M%0'.8X'/H&SIHVCJM^XS"PC6\#AF#Y^OQV.BXPW=?8@E/*3@:B%+'*2"B7Y0
M#,IR0R'D+!_*I.-$LQK\<WWS1^$.S8\>U-XZ5=L&"3,^6CBD8$GF%RXQ;04*
M"Y4DP,7%AC(BOA#G=@\(.[2X<!5+:!/8`'EQ#KIO"#@Q+(YS+YH-D3Q-EVUL
M!Y&WNALOS\++A(K6K"A5Y^RP0V=?^;Y?5SUJB_Q?7PAGUF?C]45Y$328\/@_
M9?)_H]67)07R1/X*-P*2W).+MJ7@)XR\ZJ1^<]2IY84.ZZOILA.;]`,53GI?
M,0^(*A<`,W0H/CR]R?R&U;_Z^[;W!A]>>LX]CQC!#@W3,W^_7@N4U%O%T[/K
MS84LH*^Z#77R+CQX?`6"HKQ6"9/S]F%1153+-\+[2NUI?U!79AO4,YI#^N\T
M6I2T2T1TYMKO%SQ1<92)8^ZB"7%]/8AG+Y+\@N211-T"V`9=E].9>M_?:''P
M_'KI4FE&=7<<A=(Q443;).-UP9L!36)SGR1T$;L\UHW/QEQH2W<36+[(I1QR
MN]UFL77V<;JZ2LO(>2&/KS[/4SY^_9*?/W_*[7:3Q^/1T0R3+-U5O0@IV7##
M1MB/Z>/C0W[T]]$?C9Y0:Q-BG&>5KZ]/.<\JQW',[^$F>]8J'[\^Y#AN#2UR
M&_DH'!N?K6TD7H0QCTU%;K=#OKX>LU!:_#VA@LO<R.[Q^)+S/.5VM//U>#QR
M$$KC&5=H&]38!@S=-\1PK-M1E6WCE(C'IL-!=#=`KN?@B;?S`HV`>80$)AQ6
M@RV3.$J3C_S6HN&Y(@_BV()L72.(3VQD!@&;9F%>-C0#AG'=KE'P$Z&BZ*E;
M4@_:=4]%"L`XAA+2P^IR6A`04%GW:;:\D/5K;.V"LJR9]2CE%DU3E1,0:<L^
M0T=GC^/@J%F-:"4CS1R_O#N.ZA*P$-DK&47#%LKO"WF:E,&]@H)8?UYXC+[P
M>Q,,8ED_6X"G78F>U!LJ=T<;3$4&TK[$C@,530:]9G%JXYPFL""T39.$JS_2
M*;(&++OV63.0%;5KV-FG2,$2T-94-`$S!"*JS2'X'(2S_/;;)*ILCY?V=I'O
M@C>#P;/-Y3?JKK!)/2^2;3_2E]?H"CZ8:E^LQ_@)&G7TZ6SK@H&P7VN:,*:P
MP,R1E40O/0N==^2'6';LQB<%ZXALX[4$`>.Q:^3<!JN6@;XI]QQF&7];Z;RZ
MPZ7"-O=6S+_77E[[YKW6B+.>4C_KW/",PLL!?=W>)]:*Q7YRS_.4CX\/.;K-
M4O1CY42=K'ANU]Y;?*U1UEBP/M[?FP@0J27.M_8\'W*>J291'E\/>3Q.A_8L
M=(_>4ZI3/W!0QGE6&J$/KG3DXZU-=8R$W_]]EY___)3W]W])%**NRYL4$'\_
MFBU;-]78@!&RQ((D*G[`>YDH"YX68.)0)HT<QR3=2Y/)!W?TEEP+SU=@7@!M
MTM!\IT(K30/*ER>GP4-O:-*?QZ<J\H:I4-@$0$!JX'BXQG@[7@N^#N;^+2M8
M*7FJ<AC.+C%S?.\H14X[8>S-A2<GIEWO<UEP!:*R!E0!1GL76AJ"+7!J-:Z>
M)I9MKD#-CLN_!G4``0%W@K]1K,Y@!2QZ1;GIG,_LNB_7/MAR-+48/#$`&<'4
M,'@E&7.=U/.:.\>=[A4Q.#9TP'`)=?U>KQOA*!>JO";@,U^M@E^$!:]K+$P]
M5W_&M(^GCBR8A$`V]?=V*9,F,4$[!5_@L._X6!AN#H+F`>N0;]&:I-U26N2^
MB-1>H<(OO\YRD/>ZT,Y].^,OV3@'4("`23WS//)+)#H!4WTAGAA#1)XB)EUM
M/I%ZX_!!F+48<N"A\*N-A#9O]2B7302`2X7-^4:T#Q.=E,=<9ANV8K>#:\;E
M@%)V8<$438PC48=;FX3W\TV6]C`*+`"O-D@L#E@8%<>P&17[K&=HX%2'R,"/
M$,.M.Q=[CR)Z+INHB9WF!':KVV_V:2B*<8U"7X"+%HI<-FNTAO-__^OH7RY<
M(>0#&JGU_)&Y:9HX9=3F)8E."26T<=MR%&B/W!A%+M.UMFQ<$]']C&\YD'B:
M&`AK";)C6W]/B`(DG#0PA+;H`@$BQ&J+X]M0RC+12(^DUEJ[SVT-]]I`.4.!
MK,E>@FO8QGO4%W73JS9#VSHB7+R(!ZD3`@X%_>$"R]ZG16Y&=1BH:T9IR3QY
MPSTP(G/[RE6(5UR9@N(H#0/]#4VH*`5D>$]CGC9J#&*A:>/P6K;I*M&>SQ(W
MJN0^5U"#&[[,F&Y!A?LL5.N<2'C``[4%(Z(<*1Y&$UN=X(>/(E^3'PY?P:0R
M_/P:-RYNT'SZ8:>75'1V))S;V-L>]P2KCI:ED3L/3;U*MC[:W(?'>HWIK3C)
M_BYX7RXA8:KP\NMXMW@6+VRO5M4OH(39R_%F?E8[5\D[QB"D">(JW53`;NRA
M*<Z[SM$L>AW72%$,$,=X6^P\N7::HMSK\5#15"B'XV^K=F&\K!-QR\;_DA0+
MEAT]^;0:E-DP\D-(FM"!+FQ+-C)UR,B6AZ*2HQ9.((7C3LY&3^Y3Z!*<;[X3
M>V4/!\<99V.Y;*PK-*9T'\,)(-%K%45'@R]:S1=9.W&%D1F_21=CU-9@H`U6
M*$IQX0=3?NW-C8],78613K1I5\ADJP6G%&/`B(H/+\\LJ;Q[`2GH51*ZDVMI
MP_64R5*LP:MVX\>K<:W24N0`.L$<@?:Q1!!XE;*=Y&74!T0'55TG=S5!;(;-
M,^#!?Z!0E/;?61UJ/$6O&46J+M6]IK'P^[W$?$1R$,()_6Z?VD9B,!47<)/0
MWR`R'1NI&221+$_>)42NZ!O^&8`)7PW1TGD@DMK9GS^/HZ#(#2T0;8XY:W=$
M*+T#L1ZS;5+39Y,*2I7>+"!K;@F%"6+P(1$6&^GYOUV+9UU$C%,*=7"?D0@;
MRDIUL=W]+U7:]2R#8N0L74=S4<TUWLKH,?*5*M$Z.$I*"ZP3M!8M0L2W:$U^
M(WA"?^?'$J_19X6F[J'0Z]?IWY\$?:'@I^^K^V\6":%!MS\!XR:>YNJEQQ:K
M([0C<9U0%`E=/7:#(=J`XG@EDNZ3TZ#TN&=E:"P2+;%'$8U65:G0!8W[DW-'
MFZGZU++5M4\C[D1%G1:$3^YMCJ_%S/=X]JZX7]E4P:@+]ZFU%J8#>)%WQOWB
M:"?>[U;,(VSP^:P)2*QF:GH__NS'6^,SD!4,@JD_M"@G$Y3I(;HI8I)XTV43
MMKAR)NP+?;W.Z?9WMN\5>*J6K54HTJ@Y2&@%4U08GZL@:D(1&@I6D:[0-3^E
MK`:IC5=;TRY]7%NMRFE5ZA"9NJS3*=#4MM&K$V:V9ZKT:Y.$2@B'*2#5P+L=
MA#&\RK(_O'`H0(V!;9!8@Z`4?SZ].X./S@V?*0F\N(HWSNS3C)J>-8X/L;V)
M[[A=.$X@RNO/5T;=*0FJ7LF)1\6D=$'8,.K!W:*O#7)(E24<DRE:ZW_7(C,.
MHA>TM1>KM1V(5+'^/5Y#P[WO[/[2O1IB=4W08SW6"#;N:1B.6&^*YCH)'M.T
MSB'%0-&]R'E4=^<?Z^D0\QK10K1^IU4,NU((NHGW`MO&L0X@(/AFF4OJ=\$K
MVTWES^M+V_SE,H3@#XOKIP<%SY3??W138$?Z,/-C,&YVCB_Z1C:*UU)&`IA&
ML]W>C6DI7217*,V&KTDL/LIQR'$[<D/RC&;X.]?+=R?`+]IH6J&XE>`4D7L,
M*B6V\7V8*ZL]NAHB7T.*5O([S,<0:+)AX<HDD&##GRE-C',;BN=T7@DI-7&U
MF,**P!N.!:*G.,RF0+UI.3\4BZ/<!\EFO6B4D(`WO5VK.!'DXGG&<74>K8P_
MYPNH-!U/A!36.PJ%69P*#&4X(H(^0=#_#D*-Q9XJM_%82R(.XGNLAH)*76&#
M8]LJ*Z&+1IQP"!6_/XH)C6$&$9G>A%=`0ID_R=ZE@)P+.FKOQE$I/Q6YV6G`
M1.:'BRKY;=(73%S<9YC%(!3#NXD("?-$TI"7&*@@&]I%$YE5*,31ELPVT<IE
M$V4\"F0JZA.!JEZ@V(MCKRXTAKV*#:S=EWL`.OQHZHC!38'SQ*6)@057"8XI
M7A2'2A[IG#Z(*6XH8*N._C"+\73]7F*ZV>0F>QIDF\5SJQ=`HEY!A!8W,.0_
M$T=:TWMF%.Y&4VU(XOLN=_>4@+^'3/7/?J>K<?35=\K4^/KTL%[^[%Q\D"R:
MT,N1F$5J:!S%$-*I4V2B[#/$J&A_J^,XY#B.P$'<8(>7G]77^FG3$9`65HJN
M<Y)$2XK-,`:?]K.S,YI"C#3FT;B;'4CK^&\T`,^2?Q)++@V;,-XD+C@!4>85
ME)X6:\O8/3$A-W&HR^+((B];DV0%SPY&49P751&=Q:ZQS97&1L#)S(;74EIT
M;+CU];*0PG(;D7'D!!N,_-&:;01%%.W/DRXK)MM85^&&6S8QJ+9Y7=C<T(YL
M%F@I=R!%^,MEL`J.:Y6;*XD%#`H=,[#"USSK#E82A"D$@*#PU8NO&E(,26O*
M=(;6J$OB!!)I"1Z9]"<[*VI#XJ!`>AF>8RCXEKBRTECWNA"3M%#.$.&`GB;/
MOB^,EI"Y@QR23S1HN@'<V31\8^-B<25Z"W:)PF)E'6NU#&<-FS&^VC#=OH[7
MX:C;7'/(*I.I4Y,B@#CR;-96@ZQNS4(+O%)X:I!=BW3ZB#]3E"S17J-\L#7@
MBA]VR:"(K"ISI9_1)U,[1['P[(=F#M"7@D6_18]A$E+;=_!$OA#]O_YRN;"I
MPLXDP:[0T]^N4.!$C?:[80^7AYUOC)84VVCTO&Q*E%#0@&0.P57&992-4E16
MTHZ9_5&[\CN!=E0JJD?V,C3=)88XH5I8\,%XWWN7^E'Z-%@GFG0NF`J+AGH.
ME"9HD9!">"'ZA?PHO=%J.LK,_%KUZGH!ES8+76F2X,5K<^(=?&`TRP$GU2[\
MK!425(U;=")A`^E*.-M90(%'[*O5R:W-&A][2NR'0J"("_]H!9N9.0\6?":=
MD`V0L\QU8*T1"^W*#+"#G170%AJJ5W/>ID:C?`W3AY6&-B@&.H,>'!H*0IRB
MW'@LP:]MIWFA@>CG%PNNN;9MD</^_S4Z.(0F0S7E+'N/7DP'LR`6LM3LGSL6
M31,7=V$8OGA.;29'82J%"I[@<@$HX:[HCB$4-8SV%3^_*VZ+0XDG%2@!M7QS
MHH,8*Q:$6A1(X3RQF6Y2)S^<*%C]?BNJU-@5*DJ[KZXRCWG6`\#;-A=C[]<]
M'YXQ_:N]6$Z<@Q0^ZZ.)PJ4;WK^X9RA`-MZ52&0Y/VCTNR^3TN4$Z"X.&),;
M]4)`2]2IDE""1.3_`+M*R6:N=@G=`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O;&5F=%]M
M96YU7V)O='1O;2YP;F<`````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,3(R`#$P-#$W,S8S
M,#$V`#`R-#8S-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12```!*@``"<0(!@```+V;*;H````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?5
M!QL1%ABI#\]T````'71%6'1#;VUM96YT`$-R96%T960@=VET:"!4:&4@1TE-
M4.]D)6X``!FV241!5'C:[=R_CE1E',?A[_OOS)F!#-F$RZ"VQ=+>Q)OA%BP-
M+;>@-81:4:]@"PDT%.Z$1,*N(=FQ.,/BQA@+L^P4SY-,.<VO^.0W[WG/E!=O
MWNP#<`2^^.G'/+G89[ZSS7I[DOGNO8QYG6HTP+$3*D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`H3*"`"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0*$R@@`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A
M`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A
M`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`
MJ`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*
M0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A
M`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`K@=GVXO$P3*N"8O;ZXR$F?DOT^*67Y
M)"FE"!5P')[O=GFPV5X%ZE"I[/=[H0*.P[/=6;YY]2I)2:ZURD8%'(F7Y^=+
MF&I-K2VUM912LH\S*N`(/#H]S</M_4R]I_6>VGI*;2FUIL1&!=RRB\O+/-V=
MY>N7OZ6VGMI'^IB68-66U))N3,!M^NK77_+X[?M,8Y4^IHQI3ANKPU95G5$!
MM[M)??GSBWR[>Y=>2MH8:=,J?36G35-:'\LY56Q4P"UX='J:I[NS/'[[/J.4
MM#%EK-:9YDWZM&Q6M?6K^U1"!=RH#Y>7>7UQD>>[79[MSO+R_#P/M_?SW>Z/
M3&.5-L82J?6=C'F3L5JGML,V59:??B4_?+\W2N"FM"0G?<J#S7:Y)U6251\I
MM2V'YM,JT[S)F#?+1K5:IXWKH>I/+G0*N&E_)N]^3^9-2JUIK:>.L1R<3ZN,
MU7KYR3?-A^L)GR*5)'V^LS5#X$;ML]PP3\GA,F=/&U/Z6*5-T^%,:J1^C%3*
M5:22I*^W)Z8(?)Y0[??+M8/6TGH_/-GKAT]+2KFV25V%:KY[SQ2!FW7MW;UZ
M]9I,:DT]W)4JI1Y"5?[Q]3[FM2$"GZ=7AW?W2DI2R^&)7OG70%V%JG8W%(#/
MIWY<K_[V?U/_I9?B<CIP\YO4__$7X`1T7*&#T;4`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O:61E87,O9W)A<&AI8W,O;&5F=%]M96YU7W1O<"YP;F<`````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q-#$W`#$P-#$W,S8S,#$V`#`R-#$S-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12```!*P```$P(!@```#4BD>(````&8DM'1`#_`/\`_Z"]IY,`
M```)<$A9<P``"Q,```L3`0":G!@````'=$E-10?5!Q@/&3EF\^)Q````'71%
M6'1#;VUM96YT`$-R96%T960@=VET:"!4:&4@1TE-4.]D)6X```)S241!5'C:
M[=N]BAUE',?QWSPSY^1LH@GNQBH8;(*-D$(C1(2`))`BEY#.R]!2K\$;R$4(
MBKAH)=II$1)$#'8Y&UB7/2_S9K%A%8.5AIWB\X&G&Z;X%U_^,\Q4U^]_/@9@
MXHH1`&(%(%:`6`&(%8!8`6(%(%8`8@6(%8!8`8@5(%8`8@6(%8!8`8@5(%8`
M8@4@5H!8`8@5@%@!8@4@5H!8`8@5@%@!8@4@5@!B!8@5@%@!B!4@5@!B!2!6
M@%@!B!4@5@!B!2!6@%@!B!6`6`%B!2!6`&(%B!6`6`%B!2!6`/]9<^'F#5,`
M;%8`_X=J__%R-`;`9@4@5H!8`8@5@%@!8@4@5@#_JDF26S]_:Q+`2U,G>:V9
MY^WS%_/!JWNY7C6Y-)NGE#I5*7^=5$E5I:JJ%^Y1[3]>CCNOM*8)O#3M,.3)
M>IVO#P[RU<$ROZY6N77Q<CY:7,KK.Q=2FEE*J5/J^GFLR@O!$BO@3'S\Z%&^
M/%CFDRMOY?VQI,QF:9IY2M.<;%G_")98`6=F/0RY^^,/N7_Y:NZ-=6;G%JGG
MYU(WLY124I7Z-%A>L`-G9E%*OKGQ7AX\_2W?SYMLCH_2;589NC;#,"3CF'$<
MQ0J8AB_>>3>?_OXPR\-GV:Z.TVTW&?L^XSB<7B-6P"0VK#N[>WEP?I[MZCCM
M9IV^:S/\+5AB!4S"9]>N9?_P:8Y61^FVZW3M)D/?91S$"IB8-W=V\LN5J^DV
MZ_3;K5@!TW1[=R_?_;$\W:SZKA4K8'H^W-W-3\>'Z=LV?;M-WW49AC[)\]]M
M`*;@C<4BS[IM^KZ</`+VO<T*F)Y9*>F3C,-P<L8AR<EW5G\"SM#!8A*N,50`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O;65N=5]T;W`N<&YG````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C0U`#$P-#$W,S8S,#$V`#`R,S$R
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12`````0```#("`P```."561D````,4$Q412]<ESJ5
MS/_______RE&YND````!8DM'1`,1#$SR````"7!(67,```!(````2`!&R6L^
M````#TE$051XVF-@H#%P8'````%D`('-KE#;````%W1%6'1C;VUM96YT`&=L
M;W5D96UA;G,N:6YF;WR@-=``````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+VED96%S+VEN9F\N<&AP````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#$W,0`Q,#0Q-S,V,S`Q-@`P,C`T,C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O=&AE;65S+VED96%S+VEN9F\N<&AP+'8@,2XQ+C(N
M,2`R,#`U+S$P+S$X(#$Q.C,T.C$X(&IA;B!%>'`@)`H@*B\*"B1T:&5M95]N
M86UE(#T@7R@B261E87,B*3L*"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]S
M8W)E96XN8W-S````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3$W,S(`,3`T,3<S-C,P,38`,#(P-S8Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"\J*@H@*B!)9&5A<R!T:&5M92!B>2!2
M;V5L($=L;W5D96UA;G,@/'(N9VQO=61E;6%N<T!I+71O+6DN;FP^"B`J($)A
M<V5D(&]N('1H92!)9&5A<R!T;R!);G1E<F-O;FYE8W0@0E8@=V5B<VET92`H
M:'1T<#HO+W=W=RYI+71O+6DN;FPI"B`J"B`J("1(;W)D93H@:&]R9&4O=&AE
M;65S+VED96%S+W-C<F5E;BYC<W,L=B`Q+C,N,BXS(#(P,#8O,#,O,C0@,3DZ
M,S,Z-#<@8VAU8VL@17AP("0*("HO"@IB;V1Y('L*("`@(&9O;G0M9F%M:6QY
M.B!697)D86YA+"!'96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R
M:68["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8S%D8V5D.PH@("`@8F%C:V=R
M;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+V)A8VMG<F]U;F0N<&YG*3L*("`@
M(&)A8VMG<F]U;F0M<&]S:71I;VXZ(&)O='1O;2!R:6=H=#L*("`@(&)A8VMG
M<F]U;F0M<F5P96%T.B!N;RUR97!E870["B`@("!B86-K9W)O=6YD+6%T=&%C
M:&UE;G0Z(&9I>&5D.PI]"@HN=&5X="!["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C8V%E.&4X.PI]"@IA('L*("`@(&-O;&]R.B`C,F8U8SDW.PI]"@HN<V5L
M96-T960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V)A9#!E-SL*?0HN:&5A
M9&5R('L*("`@(&-O;&]R.B`C8F%D,&4W.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(S-A.35C8SL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`U
M,SDV.PH@("`@=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0HN:&5A9&5R(&$@>PH@
M("`@8V]L;W(Z("-B860P93<["GT*+FAE861E<B!A.FAO=F5R+"!A+FAE861E
M<CIH;W9E<B!["B`@("!C;VQO<CH@(S)F-6,Y-SL*("`@('1E>'0M9&5C;W)A
M=&EO;CH@;F]N93L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S83DU8V,["GT*
M82YH96%D97(@>PH@("`@8F]R9&5R+6)O='1O;3H@,#L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z('1R86YS<&%R96YT.PI]"@HN:&5A9&5R8F]X('L*("`@(&)O
M<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E<BUR:6=H
M=#H@,7!X('-O;&ED(",P,&(Q8C`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@
M<V]L:60@(S`P8C%B,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X93@[
M"GT*"BYL:6=H="!["B`@("!C;VQO<CH@(S,S,SL*?0HN<VUA;&QH96%D97(@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*("`@(&-O;&]R.B`C
M8F%D,&4W.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A
M;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["GT*82YS;6%L;&AE861E
M<CIH;W9E<B!["B`@("!C;VQO<CH@(S)F-6,Y-SL*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z(",S83DU8V,["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*
M+G-M86QL('L*("`@(&-O;&]R.B`C,#`P.PI]"BYC;VYT<F]L('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-B860P93<["B`@("!B;W)D97(Z(&YO;F4["GT*
M"BYC;VYT<F]L(&$@>PH@("`@8V]L;W(Z(",P,#`["GT*+F-O;G1R;VP@83IH
M;W9E<B!["B`@("!T97AT+61E8V]R871I;VXZ('5N9&5R;&EN93L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z('1R86YS<&%R96YT.PI]"@HO*B!&;W)M('-T>6QE
M<RX@*B\*:6YP=70L('-E;&5C="P@=&5X=&%R96$@>PH@("`@8V]L;W(Z(",P
M,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9C-F,V8Y.PH@("`@8F]R9&5R
M.B`Q<'@@<V]L:60@(S`P-3,Y-CL*?0II;G!U=#IF;V-U<RP@=&5X=&%R96$Z
M9F]C=7,@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9CL*("`@(&)O<F1E
M<CH@,7!X('-O;&ED(",P,&(Q8C`["GT*+F)U='1O;BP@+F)U='1O;CIF;V-U
M<R!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P-3,Y-CL*
M("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M
M;&5F=#H@,7!X('-O;&ED(",P,&(Q8C`["B`@("!B;W)D97(M=&]P.B`Q<'@@
M<V]L:60@(S`P8C%B,#L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]
M"BYB=71T;VXZ:&]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S)F-6,Y
M-SL*?0H*82YF:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0H*+G-I9VYA='5R
M92P@+G-I9VYA='5R92!A('L*("`@(&-O;&]R.B`C.3DY.PI]"@HO*B!-96YU
M('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S)F
M-6,Y-SL*("`@(&)O<F1E<BUB;W1T;VTZ(&YO;F4["B`@("!B86-K9W)O=6YD
M+7)E<&5A=#H@<F5P96%T+7@["B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH
M9W)A<&AI8W,O;65N=5]T;W`N<&YG*3L*("`@(&)A8VMG<F]U;F0M<&]S:71I
M;VXZ(&)O='1O;3L*("`@('!A9&1I;F<Z(#!P>#L*("`@(&-O;&]R.B`C8F%D
M,&4W.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-B860P93<["GT*(VUE;G4@
M83IH;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PI]"B-M
M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-A86,["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C86%C.PH@("`@8F]R9&5R+6QE9G0Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`[
M"GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHN<VED96)A<B!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C8S%D8V5D.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@
M;F]N93L*("`@('!A9&1I;F<Z(#!P>#L*("`@(&UA<F=I;CH@,'!X.PI]"BYS
M:61E8F%R("-M96YU('L*("`@(&AE:6=H=#H@-S%P>#L*("`@(&)A8VMG<F]U
M;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]L969T7VUE;G5?=&]P+G!N9RD["B`@
M("!B86-K9W)O=6YD+7!O<VET:6]N.B!B;W1T;VT@<FEG:'0["B`@("!B86-K
M9W)O=6YD+7)E<&5A=#H@;F\M<F5P96%T.PH@("`@;6%R9VEN+6)O='1O;3H@
M,'!X.PI]"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(V-A93AE.#L*("`@(&)O<F1E<CH@;F]N93L*("`@(&)A8VMG<F]U;F0M:6UA
M9V4Z('5R;"AG<F%P:&EC<R]L969T7VUE;G5?8F]T=&]M+G!N9RD["B`@("!B
M86-K9W)O=6YD+7!O<VET:6]N.B!B;W1T;VT@<FEG:'0["B`@("!B86-K9W)O
M=6YD+7)E<&5A=#H@;F\M<F5P96%T.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#(P
M<'@["B`@("!P861D:6YG+71O<#H@,'!X.PI]"B-S:61E8F%R4&%N96P@82![
M"B`@("!C;VQO<CH@(S)F-6,Y-SL*("`@(&)O<F1E<CH@;F]N93L*("`@('!A
M9&1I;F<Z(#!P>"`Q<'@@,G!X(#%P>#L*?0HC<VED96)A<E!A;F5L(&$Z:&]V
M97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*("`@(&-O;&]R
M.B`C8F%D,&4W.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PH@("`@8F]R
M9&5R.B!N;VYE.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT
M.B`V<'@["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@>PH@("`@8F]R
M9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#4S.38["GT*+G1A8G-E="!L:2!A
M('L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#4S.38["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-C,61C960["GT*+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&-O;&]R
M.B`C8F%D,&4W.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*?0HN
M=&%B<V5T(&QI+F%C=&EV951A8B!A('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(S)F-6,Y-SL*?0HN=&%B<V5T(&QI(&$N86-T
M:79E5&%B.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(S-A.35C8SL*?0H*+RH@06QT97)N871I;F<@<W1Y;&5S+B`J
M+PHN<F]W179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C
M864X93@["GT*+G)O=T]D9"P@+FET96TQ('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z('1R86YS<&%R96YT.PI]"@HN:71E;2!["B`@("!B86-K9W)O=6YD+6-O
M;&]R.B!T<F%N<W!A<F5N=#L*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I97<N
M("HO"BYP<F5F<T]V97)V:65W(&@R('L*("`@(&9O;G0M<VEZ93H@,31P>#L*
M("`@(&9O;G0M=V5I9VAT.B!B;VQD.PI]"BYP<F5F<T]V97)V:65W(&1T(&$@
M>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C,#`U,SDV.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(S-A.35C8SL*("`@(&-O;&]R.B`C8F%D,&4W.PI]"@HN<')E9G-/=F5R
M=FEE=R!D9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V%E.&4X.PH@("`@
M8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#!B,6(P.PH@("`@8F]R9&5R+7)I
M9VAT.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P
M>"!S;VQI9"`C,#!B,6(P.PI]"@HN<')E9G-/=F5R=FEE=R!D="!A.FAO=F5R
M('L*("!C;VQO<CH@(S)F-6,Y-SL*?0H*+F)O>"!["B`@("`M;6]Z+6)O<F1E
M<BUR861I=7,Z(#$P<'@["B`@("!B;W)D97(Z(#%P>"!D87-H960@(S`P8C%B
M,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X93@["GT*"G1D+FQI;F5D
M4F]W+"!T<BYL:6YE9%)O=R!T9"P@=&%B;&4N;&EN9612;W<@=&0L('1A8FQE
M+FQI;F5D4F]W("YI=&5M+"!T86)L92YL:6YE9%)O=R!T:"!["B`@("!C;VQO
M<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X93@["B`@("!B
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V,Q9&-E9#L*?0HN;&EN9612;W=3
M96QE8W1E9$-O;"P@=&0N;&EN9612;W=396QE8W1E9$-O;"P@=&%B;&4N;&EN
M9612;W<@=&0N;&EN9612;W=396QE8W1E9$-O;"!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C,61C960["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(V-A93AE.#L*?0H*=&@@>PH@("`@8F%C:V=R
M;W5N9"UC;VQO<CH@=')A;G-P87)E;G0["GT*<W!A;B!S=')O;F<@>PH@("`@
M8V]L;W(Z(",R9C5C.3<["GT*"@``````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M:V]L86(O````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$V`#`Q-C<W,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]K;VQA8B]G<F%P:&EC<R\`````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,38`,#(P
M-3<R`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VMO;&%B+V=R87!H
M:6-S+VMO;&%B+G!N9P``````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S$W
M-P`Q,#0Q-S,V,S`Q-@`P,C(S-S8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```(P````H"`8`
M```L31+&```61DE$051XVNV<>7A<U7G&?W>9J]E'THS6T;Y9MH2QP=AF-00,
M#@%CXA@,*8%2V@0,;8$"80DE)90D$"A-:!*:%-)0MZP.D(#!9C&;C5>\R;(E
M2[:UKZ-9-/N]MW\,'FDT(]L0DT*J[WG\//:]=\[YSCGO?;_W^\ZY%G1=U_DS
M,%75:&\?8M.F@^S<V<VV;1WT]?D9&`C0W^\G&E.QVXPHBH3+967:M'SJZPN9
M,Z>,L\^NQ>6R,F5'-^'+!IBNKA%"H2C5U7EHFL[O7MK!'UYMXJVW]M+9.?*9
MVI1ED05GU7+UU7/YQM)9*(H\A8PO.V!T7>?.^U[CB5]_B*;I++UT%K]\[.LL
MOO17K'UKWW'KIZK2R0^^?R%+OWXB@B!,(>3+"ICF_<-<^NU5*=>>?/A"]NSH
MX*:_?Y$2MY7*<@=Y^29L5@6;34$4P>>+XO-%Z>X9I?V`E[Z^(*IV]"%?=.$,
MGOCY9>1DFZ90\F4#3"`0H7,HP@T/;TZY_N!W3J3(%F=_6QMVFY(8D"`@RS(&
M@P%)DI+LI*HJT6B4@<%1MGT\P-OO=K%I2Q^1J#IIOW4U+E8]>PUEI3E32/DR
M`*:WS\]=]ZTF$(CPW[_Y)@_\KH?FOB@`Q7:)!RYS,SS81S0:Q6JU8C*9R,K*
M0A3%C.%$UW7B\3C!8!"_WT];>Q__N7(7K[QV@'`D,W"FU^7Q^Q>OQ>6T3*'E
MBPH87==9^=QV[OW!&CPC(<I+K:Q:>27ND@)V]*F$XS"[4,*L".BZ_IFUAJ[K
M!(-!MGW<QCT_6,>.W<,9GSOW[')6_OI*#`;#%&"^:(#Q^</<\8]O\,)+NS";
M#%Q]11T7GE>,+(N4E961EY?W^?3K"W#7/[W!LZN:,]Y_]($%7'GY:?_OA?`7
M"C"M[<-<<\.+M+8-TSC=R6TK&G#E&E`4A9*2$K*SLX^X8`.#(0X<\N'U1?",
M1+#;%)RY1NJJ<[#;E:/VKVD:=]SW!K]]9D?:O6DU=IY[\NODY^=/`68\1=]R
M]_OX_`F=$(VJ^$=C6*T*JJIQQKPB5EPW,ZV1AW^VE37O=,*$M8S'-$Q&B:<>
M/P^7\\C9QL:M75SW]R\S/!SBHO/+N'9Y)9($>7EYN-WNI(`=;[&8RIIW.GGY
M]0-T#8:PY1@IKW20XS22G6/$[XLR-!BBO=5#U!_ES%,*^:MO3L=FFQP\\;C&
MI=_Z'[;MZ)TP4_#$PZ=QP7FGI/D2C:J$PO&TMD1!.&)?1[)-6WM9NZZ3OOX@
M_D_6XUAL1GTNM]YX4O+?[Z_O9OVFGF/ZK:((..S&9&UJQK1<9IV0ARB.+6Q*
MA:JO/T1G0.7.^\]"4:3#\X1L$'GEQ1:LZB@>CX><G+&LX1=/[:8S#(^M7)P"
MF-%`C-MO>)T;_ZH:]%'"80&CT9C1T74?'N3ZVUYE-!CC+Y;5L.PB-Z(H4E%1
MD=+78?/ZHCS^Y&[6;NCCI#-*6;)B+DZ7Z:AZ9=/Z;I:N>(>K+J[@JF5UDQ;Q
M'OG!(BZX[+]0U53R_6AK/_/FC.!T.E.NW_*]#_'$5&2#F+RFQG4&._RL?O:B
M3P44?R#*37>]C^(TLW!1)6>ZC[T"W=L38.TSN_#Y?%BM5D11Y.>_:6+9W\S$
M8)`(A6*$@O%C:BL<4?GMFD-\]X<;N>O&V9Q]NCL=,!NV]C/MY!+\J@%"XVZ$
MX+T/>KEIB<+0T%!R$9]XNIFWF_U<?]M\>OUCCP='8_SHNVNY;K&=O)P@7J^7
MW-S<S&!9?XB_N7TUT9C.LHO+6':1&UF6J:FIP6*Q3`@9.D\^LX_?O'*0A<L:
MN&79+`1!0`7Z`T<E4RIFNKFIL9A53^]BWX^W</_M)V=\LK8JEPO/K^,/:_>G
M7._JC^#U>M,`T]X7XO['ST^YUK;/PUO__1'[]NVCNKHZ(T.F,Z;&M;>^Q[G+
M3Z!A5B+T?1J]T+R_C[)BC?;V=F;.3$2"@:!&?E6BK4];')@QKYS%5ZG\Z)YU
MN)Q&&NN=J8#9N'V(@C-JZ?%/?#W!T^<EQU&$S68#X-E7VGEYFX]OKIB7`I9P
M,,83][_-=RZQ,J/6C,/AH+*R$E$4TQS:US;,W]V[%E6#!?/SN7QQ*;(L4U=7
MA\F4RAC]@R&NOV<CYMI"OG7O0D11.`:09`;.&9>>P&O/[.*I9YNYYK+ZC$\M
M7]+`ZG<.I%P;],0)!`(IF9G7%R5N-M'M3?W]>Q\-4%^31202R3CV3/;#Q[=3
M=FHUSJI\>GV?(8QM&>2Z<ZQ8+!8$0>!05P#%Y:!G0EN=;1Y&AH(IUXQF`Y73
M7$CR1%\E+OGKN?SPI^_RRQ\O2`7,KO91\KYJ2W/6TQ^@HC#1D,UFX_E7#_+8
M*[TLO6$^?8&Q.!0)QWC^T7>YZ1(S#;4F'`X'5555&2=L>"3,]7>M)1R#$K>5
MZY:7(8D"U=75:6#9T^KEFN]MX;3E)Y-?XF!@](\7;[,7-?#X(V^R\(Q<W,7I
M0G;>2<58[2;"X[1)7!>(Q^-HFI9DC`W;!LFO*:1[PISMV#'$XLLL6*W68\JL
M-FP;8.V^*$NOKTA;8!W0XMK8$LJ9`3C0ZZ<P+SO)S`G?"M((8.4O-W/Q*:EM
M]/OBO/@4++_C7`Q9J7MINME*?P`Z.CK&`!.+:72&Y10`'+:=&_LXO]&*+,N\
MO\7+`R_TLO#J^?2/CCT;#<=Y\U<?<.L2(PTUQB."1=-T[GUD/3U#(21%YMIO
ME&#*DB@M+<5J38W9>]M\7''/Q\R_Z@RP*I^153(SC:.^@E6K]_'MJW+2:BP&
M6:2N.I==^X:2UYRY1B8FE1]L'<!67I'&,&%O`(<U-RVL9K)@*,ZMCS0Q[^K3
MTA9WN,O+YA<V46*-(@BPH]?`Y7<N3!?K416[%$$42?:Y:><PYH9I*0",1>(X
M33&^NJ`@J7,.6_%;PWRTH8_JV>Z4MB/!&(H$HZ.C8X#9OG<$,2\W(Q6V[QMB
M]EDF-C=%>.@/!YE[Q3SZQH%%BVML?V$3MRXQT%!CQ&ZW3PH6@!=6M[)N4S>2
M+#.[WDI#C16[W8[+Y4H5M_X85_WC=JHNF8]/5_#YCV^*J!3GT=1V@,'!08J*
MBM+NYV2;D>0Q)#ASTC.>+2VC%,^PIS!,9#1*D4-#$#@FP-SSV"YL<Z?CB1M@
M7#OA0(2V51MY^'H'=JO$D%?CYI52QC4:.N2EKCSAG]EL3JSI@3#N66:"XYX?
M:!]A>F46`#4U-2G:RK6KG>%V`?.$]MLV=G+^;'.JZ-VPPX.8[TK1(X>S"[L6
MH+W;Q/TO"=1>?$H*LVAQC4.O;^;.K^DT5ANQV6Q'!(O7'^%G*W<A?9*%+3['
MA2`(E)24I%'W[8_L0I_5B(^LXPX6@`@*$57`[_=G!(S);$CZ"5!5:D:6Y>38
M0F&5UH`!P9_J]U#;".=6&1$$(2V\3K2W-O3S<IM$S7GY::&H]:5M_.0O;-BM
M$FZWF\X1%;E037L.H+/%PT4GFC"93,BR3"BLTAXR($V(&(?V>5@Z+_'<>+`$
M0W%^]8<>3.?,36D_Z@\1;-[/N7^7"'5)P'RTVT>HI#S-F:@G@%./<_?SD/N5
M4^@/26,9E*KA>6\K]U^BTEB5A<UF.VI&\._/-1,(J4BR3'E1%I5N(SDY.6D3
MN[5IA-^U&\@_/8=P@,_%(H-19ILE8K%8QOLC_AB2G)@B08`9569,)E,2V+M:
M?01M.6GZ9:!]A!,696&Q6(XH>#V^*#<]WH[Y]#EIK.%KZ>3R61%*"JSDY>51
M6%C(YN?W$,TNS<@PPST^IEVB)-EE5ZN/D#4[;3W[N_T\_6:85>N'L5H_'M.O
MG5&"-=.QA&4(?S(_?1ZDG=MYZ%H[LB106%@X!IC-71K#V0((J9MPD;8AVONM
MV!><1%\`0$TJL>CF'3QP48S&*N68P#+BB_#*ND-(AD2W)T]/Z)5,U=-_>>80
M:E4-?2/JYU:UC!X:H?ZTK(R+&E<U.@9"25^KBA4<5BE%8ZW?.4+0FDWW\`0?
M/7[*"^6CAJ/;_W4OO26UR./G%="C,<K[VKCT&U841<'M3FB*S?M##!>;(,.<
M%(BC6$VF,?W2Y$T`QI/ZK'C23'9F<J9!``%\'A6UHQ>ZNEE<'^2:%58L)H&"
M@@(<#D<",-T#80[L]Z#M?R>M'4G0D00![VOOI\M&36/0;SDFL`"\]D$744U(
M+D)=F1%%&7LKDO085GGU@P'\X?[/M<SM,`O,OMJ1L:!XL#M`,*HG?3UGCAV`
M[.SL,<&[PTO@@_T)^AEG)U>+&&3[$0'SRGO]_.>K/2"EC]$@ZMQRBPU)A/+R
M<B1)0E5UMNSVXMW\3L;VSCXU(=H/]_E1DX_`AZV?;6(T#5&`:)T)BUFBM,1-
M7EY>XN@(P*8]?G1!(E/R5U$LLO1TA8>>#Z=7D221'S\?8>XL&W5U1R],O;FI
M-TGQH@A%3@,.AR--N^P]&,0?(6TACK==>J81Q2!@M]O3[KV]I2_I:ZY=8E:-
M$;/9G`R=JJJS<6\@,9")+VN5DK)X$ZW?$^7ZA_:"G/DH:+5;IJE#8W^?P-8N
M/^!GQ!_'&]8GG9.&BL3Y'Z,QD<EMW#,*0KIO]:42Q@G:?="KTS6DD4P`)1$-
M>.Z]&%45%KX_.R^Y1C*0&+@AL_,-E3)+3E/H#=CX[5I/.G4#U_QP/VL?-=-8
M[3ABO-[?$T+\I!]3EH!B$-+8!6`X$$>0/]]SM2Z[P!7G9"%)4@IK'`Y':S;U
M)WP58/'I%F1)(#\_/SEQ[3UA>D:TC'XV5B8V3#,=A]!UG9O^I87!@#[I&/?V
MPD,OQH`8,";@CC0GC94R9K,9413I'8[2WA]%D%-?8ED2^.D*,Q:C,,$G^(\U
M4?[CC?0]J\>>[^6*<TQ,KRT=!YCFT4F=:2B7$$61?[UE.FW]37S8E*Y`O1&X
M[/LMO/5H(X7.S/M%>SO\")+$X3$8%`%1(..D*@;Q<P6,*,!=RQ5L)H&BHJ*T
M4/K.U@$&O#%D1::J4&)6E8+1:$S9WEC?Y,_HHR!`0YF8K+9.M)5O#O+R>N]Q
M'9_-!&5YXIA^:0X@9)C7JF(!BS&1D8[?WM!UG7LK8SSY]L?I.@]X=VLOY6XG
M9K,9.1+3^/A@9%)ZG%&68`%3EL33WYO&63<WT3F8GE6T#^E<^<\M_/Z!Z9B-
MZ6T-C$23%'^8F:)Q,NJ>VA(3DB*C:I_#]CSPMU\3F5<G8K5:,PKNQBH'9\[.
M9VOS,)>?:400H*RL+`4`'^X9S3AGL@0_7P,F4Q!-:"422XWC[^_T33K7G]6F
MEPLI-9_-+9E]FUDI)*OU\H3[AP8FQT`X+N#Q>!*`V7TPS&A,1,A0;K:9H,RE
M)1TIRE58>7<MY]_5DC81`!M:XZSX63N_NKD:24IM;]@?3PK(Y+71Q%G;B5:8
MJW#FK&S6;3^^Q1=1A!O.AV^<*F`P&*BLK$R"H+O'QP,/KN'0(0]+ELSD>U?/
M8=VF%K*5`"Z7*[F'EASKOE!&EH@#K^TX_&Y&,T+V>+-G8[F>*G@G\:W.K1..
MR\1T!5]P;-Y;NR/<^&\=D_I5D*T3C2;&(F]L":;%NN2;7JQCD+04\79*G85'
MOU/&BI]W9OS-LQM"U#S7Q5V7IQ;B9%E,`TS;`,R-1#*V<]]5)9S7W'+<6,9F
MU+GC:SH+INL8#`9J:VM1%&5,5]R]ALW;NA/[0(]]1&%)+F?-*^;0H4.4E)2D
M%N;\<?;VQB?5?9_6C++.W1>K&"<Y`=KG$WAX]>1)14-I'$4Q(,LR<55GZX$H
M9%C3AU^'G[P.B'M2KL=BVA@]3K`R)]04Q).,)&]JC4PZ\!DE\8QJ_^IS<]C9
M$>$7KWLR[[J^Y*>Z:)#E"\:.4[JRLQ`-J0[MZH%`8)1,A]CFU5MX\"]+N..I
MGC\Z!IU:K7'S^1J%#AVSV4Q5515965ECM::H1E=4H7!&Q=B&9U>("TRFC.6"
M#7M#QY4E_G)!C+.GZUBMUHPI_JI-400Y<W%1$J"^.)[<Y-S=$68T+B(8TB/&
M9!4MP9`9C+*H<_.BQ![6X4Q2_J@M.KG@+8EA,!C2A*D@"#QX52%[NN.\NR>4
MG@D`*Y[T4%Z0Q:GUB8Y*\HQ($Q#<'X`MK7XJ*K2,Q;,;+W+ALDO<\F0/OM"G
M2[$%`6:6J'QK?HPY%5JR0.AVN]/Z4@PBIRZHI[U_C.UFS2Q"EN6T6`^POB4\
M*2M_6JMT:BR;$\=@,%!=79VQOY8W>A%D;\;?E^1JV$WZF.!M/3Z^.2TZ_W!>
MF#D5&E:K=0PPMRUQXAWQ,N)-_\QT5HF*Q>+(J/856>`W-Q6S\NTNO-[,@]G6
M=)"9I558+!9JW6;L-H71<&J,>;U9Y[29P[@+71G;6'Y6#G.K=!Y]J8?5NV5Z
M?,(1LY_R7(WYE7$6UL>HRM,02+P=;K<[8PK?U!%$TW7N7%[)LQ]'&`KIS"F6
M^,H,X^0A1)%8=)(%O_^/V[,P*SI?/S&"08*2DI*,8`$P&T4NF&5"B*>?ZZ@O
M4!'&1P$!%LVVX@]\>OVG2#H.DTY#D<H953',RA@C'\:`H.NZ/C`P@-^?N8.<
MG)R,QR23-*>J'#AP("E>!4%(`9BB*)26EB((`C][K9=WF](W0AK=(G<NK<1@
MF/S-"(?#='1UTW301TN_B"<HXH\(&&4=LZ)39->H<JKD6'0$$ME7;FXN+I<K
M9?\G6<S4=5[=.L+*]X<P&P3NORR?0J?UF+\*\'@\M+>W'Q>6L=OM5%=7'_F`
M^\``'1T=XP2\F/+WQL;&Y+5@,$AS<_-GC^)"(C/.R<G!Y7*E]/4G_6J@8RC*
M=U=VDNE+U=-JS7Q[83Z*?.33:;%8#)_/Q^CH*)%(!%55T74=29)0%`73)_LI
MD]5!`+H],7[]UB!-72%L60(7SXA2;`Y@^D2SC-<W4S8!3'_JSTR>?M_#ZIV9
MV6Q:819_?4XNA=F?SP=CGE&5WW_LX^W=?J(JU+HT%E;XR1*C6"P6JJJJDIG3
ME'U!`!.-ZSSX^T':!C*K?D466'2"E0L:+5B-XA_=GZ;K[.^/\=Z^(!^V!(FI
M8#9HG%,^2I4]@``4%!107%Q\S&=OIP#S)S9_6.,G;XS0X9G\DX<3W0HW?L61
M\DW,L5HXIG%P6&7KP0A;#H;Q!!-"6Q9T9CK]S,KS8Y0TC$8CY>7E:<="I^P+
M!AB`4%3CW]_SL+,W'1`Y9H'[ON;@E9=W\L\_6H,@"-QVZU?XYN6SV=X5)18'
M<Y:`)$`DKC,:T?&&=?I\*@>'XO3X5,:=F481-:8Y_)R8Z\-JB"-)$H6%A>3G
MYT^QRI<%,`#Q>)PU.P99>T!A-#Z64GYUNL+\0I4%ESY--);(OB1)8,TS5[+'
M;^2E79%C:M]AB#+-YF.:W8=14A%%D?S\?/+S\Z<^K/^,]G_Z?W/)LLRBV07,
M+!Y@78N/O3X;0U$3.1:9@WU^<JM+4YX_T!<B.\^2ML4PWFQR%+<Q0(W%1UY6
M"('$CGA^?B$NEVO26L>4?0D`<SCG=Q?FL\P9H[>WE[:^/ARZD^IJ)S4G5C$:
MT3XIE@F<.,W).QT@RQ*2H"$+.@XY3*XA3*XA1)XAA,,0^821)!R.7)Q.)S:;
M;>J_'_MS"$F93%55`H$`=KN=3H_*VZU1!.#L&H5\B\KVW?N(J1JRD/ASV"1)
M2M9@'`['40]@3]F?"6".9",C(X1"H21`)$G"8#"0E96%P6"8`LB?P/X7,#6O
M=?K,HF$`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:V]L86(O9W)A<&AI8W,O
M8F<N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C`W`#$P
M-#$W,S8S,#$V`#`R,38V-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12`````0````,(`@```-V_
M\M4````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP````'
M=$E-10?4"1$+'BA-;][6````%$E$051XVF.X<N$$$P,#`].]^P\`':`%#LYQ
MM6H`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+VMO;&%B+V=R87!H:6-S+VMO;&%B;&]G;RYP
M;F<````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3<W,@`Q,#0Q-S,V,S`Q-@`P
M,C,R-C$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```#<````H"`8```!:6V((````!F)+1T0`
M``````#Y0[M_````"7!(67,```L3```+$P$`FIP8````!W1)344'U`L$#QX=
M`=)&Y```"X=)1$%4>-J]F7N0U-65QS^_9[^[IQ_3]$SWO'H>#&"`B20@2I"L
MJ$%C1!1!"R$F&U=7L]G=,FY88\A&U]HJUVRJ3&VM68MD8\BB%1$U0H2HY*&;
M$-X#\AR8&6:&>0_=/=/=O^[?[[=_##2TW0,.S'BJ^I][;]][OK]SSO><<Z]@
MFJ;)IR"Z;G#R9#\[=[9RX$`G>_:TT]T=I[<W04]/'"VCXW99456)0,#)U*E!
M&AM#S)E3R8TWUA,(.,=]IC#1X#HZAD@F-6IK2S$,D]<W[^?7;Q_BW7>/</KT
MT!7M*<LB"[]0S^K5G^?N9;-15?G3!6>:)M]9MX477_H`PS!9MG0V__6CN[AC
MZ7^S_=VC$_;QHC5^GO[^$I;=-0M!$#X=<(=/#+#TH4UY8^N?6\)'^]MY[%NO
M$0D[J:GR4!JTX7*JN%PJH@BQF$8LIM'9-<S)4V?I[AY!-RZOTNU+IO/B?R['
M6V*;7'")1)K3_6D>>>XO>>//_LTLREQ93K2TX':IHP<*`K(LHR@*DB3EK*[K
M.IJFT=LWS)Z]O;SWNPYV[NHFK>ECGMM0%V#3*VNHK/!./+@SW7'6KMM*(I'F
MES^[GV=>[^)PMP9`N5OBF>5A!OJZT30-I].)S6;#8K$@BF)1ES)-DVPVR\C(
M"/%XG):3W?S/AF;>W'**5+HXR&D-I;SUVH,$_(Z)`6>:)AM>W<=33V]C<"A)
M586331ON(QR9POYNG506FD(2=E7`-,W+QL:ESAD9&6'/WA:>?'H'^P\.%%WW
M5S=6L>&E^U`4Y>K`Q>(IGOC>._QJ<S-VF\+JE0TLN:D<61:IK*RDM+1T4E))
M+)9@[;^\PRN;#A>=_^$S"[GOWOEY'W)<X(Z?'&#-(Z]QO&6`:Z;Y>?QO9Q#P
M*:BJ2B02H:2DY))6ZNU+<JHMQME8FL&A-&Z7BM]GI:'6B]NM7O9\PS!X8MT[
M_'SC_H*YJ75N7EU_%\%@</S@_KR[@Z]_ZPT&!I+<?G,E#ZZH09*@M+24<#B<
M(X>+)9/1V?;^:=[XS2DZ^I*XO%:J:CQX_59*O%;B,8W^OB0GCP^BQ346?"[$
MU^Z?ALLU-M!LUF#I`__+GOUG/A9@\.)S\[GEIL_E=,F!,PP#412+;KCC@U8>
M?OQMAD<RK+RSFGMN#R.*(M75U7B]A4QU-J;QX_4'V?Y_W7SVA@IN6A+%'[!=
M-KYV?MC)YE\<9-67JUEU3\.8:X^U#'#+\E^@Z_EV6;.\FF]^XWK\?O\%<.>-
M5\RE=GS8QC<>WX*FZ2R[M9R57ZE`EF7JZNIP.!P?<QN3]1N/\K,W6UE\SPR:
MYI:/FTP,PV33R\V$!8T??/O:,=<]NO8W_'K[B7QBN;Z4M8]=2S0:':UL<E8M
MHL31E@'^[JGMZ`8LG!?DWCM&@34T-&"SY5NBIR_)PT_^&7M]B`>>6HPH"O0D
MKH0Z!&Y8^AFV;&SFIZ\<9LWRQJ*K5MPY@ZWOG\H;ZQO,DD@D<@PMCT75`T,I
M'EZ[G50&(F$G7U]1B20*U-;6%@#[Z/A9UGQW%_-77$LPXJ%W^.K9L>G6&?SX
M^=^R^`8?X?)@P?S<SY;C=-M(I;(7XM$4R&:S&(:!)$G(Q8`9ALE3SW](5W\2
M295Y\.X(-HM$144%3F=^=7ZD)<;*)_<R;]4-X%2OT%K%+>AIK&;3UJ,\M,I;
MD,,46:2AUD?ST?[<F-]GY6)^+%I>_VKK<7;L[$2299H:G<RH<^)VNPD$`OG$
M$<^PZGO[B'YE'C%3)1:?V-RFEI=RJ.44?7U]E)65%<Q[2^Q(\MD+X+SY+%L`
M[FP\S0L;FI'443J]8U$`01"(1"(%[OOMYYLQ9U]##,N$`P-(HY+6!>+Q>%%P
M-KN2TQ,@6F%'EN4<ZQ>`^\FKATDD=219IJK,0DW8BM?K+8BSW8>&>/VD0O!Z
M+ZD$DR+I/HTFNT0FDRDZ/Q3/(,GR.4*$Z5$[-ILM9X0\<$.Q-&_N:$-21H>O
MG38:7Q=G_?/R'QO;T*-U=`_ID]:]:VU#-,ZW%,V_6=V@O3>9TS5:KN)Q2GF<
MD`=NRQ\[T`PA]X>&2BNJJF*WV_,V'DGIO/W'7N*IGDF]FO#8!9I6>[!:K05S
MK9T)1C0SI^NB.6X`2DI*BH/[[<XS.3.+(I3Y%3P>3T&L'6D=(9X^YPN3*$L7
M6%$5`;?;73#WWJ[NG*X^M\3L.BMVNST7/J9I7@`W&-,XT95$//<E;!8!51$*
MK`8PD,@BR/*D`@NX!58NLB!)4IXUSKODMIT]H[H*<,?U#F1)(!@,YADBI^&1
M]CB")"&?(Q]%%1`%"O(+@*J(DPI.%&#M"A673:"LK*R@*']_=R^]9S/(JDPT
M)#$[JF*U6O'Y?,530>^0EC,S0!;0LA2M]NLC-B151C<F'I@`?/,VD;D-(DZG
MLRB971/UL*`IR.[#`]R[P(H@0&5E97XO)P@7P`W$L[G@S(T-C]YM?%Q"/I4%
MLTO8L6]BDYLHPB,WP]W7"2B*0DU-34[ASJX8SSR[C;:V0>Z\<R;?73V''3N/
M4:(F"`0"N%RNPBO!7#FCB`7@6GKA\^ET4476K8IPT^%C$V8]E]7DB=M,%DXS
M412%^OIZ5%7-D<-C_[R-O^SI!&#_C_Y$*.+C"W/+:6MK(Q*)%+1/>98+^:V(
M2KX+-G=!(C%,$<]@;J.#9[\:X8F?=EVU'UY7:_#W-QN$/"9VNYUH-(K%8KF0
MS#6##DTE-+WZ0K'>D>06FXW:VMJBH9-GN8I2*Y*<OZ@G`;N.QZFN+M[(/GI[
M@(!;XA_6=Q%+CB\M"`+,C.@\,"_#G&HC5RR$P^&"LU1%Y+J%C9SLN>!%LV>6
M(<LR<A%B.^_*N4X\DS7XV@M'&4[E^YG7;O+]Y5,(AP)C*MIR>H`?;NYBZT&9
MKIAP21:L\AG,J\FRN#%#M-1``-QN-^%PN&C:.=0^@F&:!+T67MF;IC]I,J=<
MXDO3K8CB)[AQ/N^C+VPYP^\.Q0K9*2SRG64U*(HTYD:I5(KVCDX.M<8XUB,R
M."(23PM891.[:E+F-HCZ=;P.$X%1%O;Y?`0"@;QZ,-=VF29O[QYBPQ_ZL2L"
M/U@>).1WCJNSS[L@:N_7^*<-IREVFSV_WLY#BX.HLGC)#3.9#+%8C.'A8=+I
M-+JN8YHFDB2AJBHVFPV'PX'#X1A3T<[!#"^]V\>ACB0NB\"7IVN4VQ/8SL78
MQ?$XKK>"E_\PR-8#Q2E^:LC"7R_R$2I1)B5Y#P[KO+4WQGL'XV@ZU`<,%E?'
ML8@:#H>#:#2:8]`K`J=E39Y]JX^6WN)MABH+W/H9)[=<X\!I%:\:D&&:G.C)
M\/NC(WQP;(2,#G;%8%'5,%%W`@&8,F4*Y>7E8][.C>LA))XR^/=WAF@?S([Y
MQUEAE4>_Z+EL4!>-SXQ!ZX#.[M8TNUI3#(Z,DI@LF,STQYE=&L<J&5BM5JJJ
MJ@JN-JX*'$!2,_C)[P<Y<*90>:]=8-UM'MY\XP#_^F_;$`2!Q__QB]Q_;Q/[
M.C0R6;!;!"0!TEF3X;3)V91)=TRGM3]+5TPG>Q$IJZ+!5$^<6;X83B6+)$F$
M0B&"P>"XK?6)WPJRV2S;]O>Q_93*</9"/OG2-)5Y(9V%2U]&RXR69Y(DL&WC
M?7P4M[*Y.?W)^C5%8ZHKQE1W#*ND(XHBP6"08#!8M&`?KURRM)=EF5N;IC"S
MO)<=QV(<B;GHUVQX'3*MW7%\M15YZT]U)RDI=124<7EEEJP1MB:H<\0HM201
M&.T\@L$0@4"@:%*>%'#GLWTX%.0>?X8S9\[0TMV-Q_136^NG;E:4X?2H?UE5
M@5E3_;S?#K(L(0D&LF#BD5/XE!0^)4FIDL2CI,]96L+C\>'W^W&Y7%?\S'7%
M;EE,=%TGD4C@=KLY/:CSWG$-`;BQ3B7HT-EW\"@9W4`61G_G19*D7([S>#PX
M'(ZKBJ=)`7<I&1H:(IE,YL!(DH2B*%@L%A1%F70P'Y?_![H7<,0^Z$-U````
M`$E%3D2N0F""````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O:V]L86(O:6YF;RYP:'``````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S,U`#$P-#$W,S8S,#$V`#`R,#0S-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M2V]L86(@=&AE;64@8GD@4W1U87)T($)I;F=E(#QS+F)I;F=E0&-O9&5F=7-I
M;VXN8V\N>F$^"B`J($1E<FEV960@9G)O;2!T:&4@)TQI9VAT($)L=64G('1H
M96UE+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]K;VQA8B]I;F9O+G!H
M<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,V(&UD:G5K:6,@17AP("0*("HO
M"@HD=&AE;65?;F%M92`](%\H(DMO;&%B(BD["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VMO;&%B+W-C
M<F5E;BYC<W,`````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,S`P-0`Q,#0Q-S,V,S`Q-@`P,C`W-38`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+RHJ"B`J($MO;&%B('1H96UE(&)Y(%-T
M=6%R="!":6YG92`\<VMB:6YG94!G;6%I;"YC;VT^"B`J($1E<FEV960@9G)O
M;2!T:&4@)TQI9VAT($)L=64G('1H96UE+@H@*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]K;VQA8B]S8W)E96XN8W-S+'8@,2XQ,"XV+C(@,C`P-B\P,R\Q
M,"`P,#HQ,CHU-"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U
M;F0Z("-E-64U934["GT*82!["B`@("!C;VQO<CH@(S,S.3L*?0HN;&EG:'0@
M>PH@("`@8V]L;W(Z(",P,#`["GT*(W1H96UE;&]G;R!["B`@("!B86-K9W)O
M=6YD+6EM86=E.B!U<FPH)V=R87!H:6-S+VMO;&%B;&]G;RYP;F<G*3L*("`@
M(&)A8VMG<F]U;F0M<&]S:71I;VXZ(&-E;G1E<CL*("`@(&)A8VMG<F]U;F0M
M<F5P96%T.B!N;RUR97!E870["B`@("!H96EG:'0Z(#4P<'@["B`@("!W:61T
M:#H@,3`P<'@["GT*+FAE861E<B!["B`@("!B86-K9W)O=6YD.B`C9&1F.PH@
M("`@8F]R9&5R+6)O='1O;3H@+C%E;2!S;VQI9"`C,#!C.PI]"BYS;6%L;&AE
M861E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-D9&8[
M"GT*+G-M86QL:&5A9&5R(&$L("YS;6%L;&AE861E<B!A.FAO=F5R+"!A+G-M
M86QL:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P.PI]"BYB=71T;VX@
M>PH@("`@8F%C:V=R;W5N9#H@(S`P8SL*("`@(&-O;&]R.B`C9F9F.PH@("`@
M9F]N="UW96EG:'0Z(&)O;&0["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P
M>#L*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&)A8VMG<F]U
M;F0Z("-F9F8["B`@("!B;W)D97(M=&]P.B`U<'@@<V]L:60@(S`P8SL*("`@
M(&)O<F1E<BUB;W1T;VTZ(#-P>"!S;VQI9"`C.&)F.PH@("`@8V]L;W(Z(",P
M,#`["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A.FAO
M=F5R('L*("`@(&)O<F1E<CH@;F]N93L*("`@('!A9&1I;F<Z(#-P>#L*("`@
M(&)A8VMG<F]U;F0Z("-C8V8["B`@("!C;VQO<CH@(S`P8SL*?0HC;65N=2!A
M+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(V1D9CL*("`@(&)O<F1E<CH@
M;F]N93L*("`@('!A9&1I;F<Z(#-P>#L*?0H*+RH@4VED96)A<B!S='EL97,N
M("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@=VAI=&4["B`@
M("!B;W)D97(M8F]T=&]M.B`N,F5M('-O;&ED(",X8F8["B`@("!B;W)D97(M
M<FEG:'0Z("XR96T@<V]L:60@(SAB9CL*?0HC<VED96)A<E!A;F5L(&$@>PH@
M("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P861D:6YG+6)O='1O;3H@,G!X
M.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*
M("`@(&)A8VMG<F]U;F0Z("-C8V8["GT*(V5X<&%N9$)U='1O;B!["B`@("!M
M87)G:6XM<FEG:'0Z("XR96T["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S
M970@;&DN86-T:79E5&%B(&$L("YT86)S970@;&DN86-T:79E5&%B(&$Z:&]V
M97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C9&1F.PH@
M("`@8F]R9&5R+6)O='1O;2UC;VQO<CH@(V1D9CL*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L879A;F1E<B\`````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`T,3<S-C,P,38`,#$W-#<V`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+VQA=F%N9&5R+VEN9F\N<&AP````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#$W-@`Q,#0Q-S,V,S`Q-@`P,C$Q-#,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O=&AE;65S+VQA=F%N9&5R+VEN9F\N<&AP+'8@,2XQ
M(#(P,#0O,3`O,3<@,3DZ,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M
M95]N86UE(#T@7R@B3&%V96YD97(B*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L879A;F1E
M<B]S8W)E96XN8W-S````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(Q-S``,3`T,3<S-C,P,38`,#(Q-#8T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H
M96UE<R]L879A;F1E<B]S8W)E96XN8W-S+'8@,2XY+C0N,R`R,#`U+S$P+S$X
M(#$Q.C,T.C$Y(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N
M9#H@(V5E93L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C9C1E-68W.PI]
M"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-F-&4U9C<["GT*
M82!["B`@("!C;VQO<CH@(S<Q,&8Y-CL*?0IA+G=I9&=E="!["B`@("!C;VQO
M<CH@(S<T,F$X,CL*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0Z(",W-#)A.#(["GT*+FAE861E<B!["B`@("!B
M86-K9W)O=6YD.B`C93%C,F4W.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"F$N
M:&5A9&5R('L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z(&YO;F4["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B!T<F%N<W!A<F5N=#L*?0HN;&EG:'0@>PH@("`@8V]L
M;W(Z(",V931E-S(["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C965E
M.PH@("`@8F%C:V=R;W5N9#H@(V4Q8S)E-SL*?0HN8V]N=')O;"!["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C96-C868R.PI]"BYI=&5M('L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-F-F4W9C@["GT*+F)U='1O;B!["B`@("!C;VQO<CH@
M(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",Y83<X83`["B`@("!B;W)D
M97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,"`R<'@["GT*+F)U
M='1O;CIH;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-F0P86$P.PI]
M"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8S9A,6-D.PI]
M"G-E;&5C="!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C93!C,V4U.PH@("`@
M8V]L;W(Z(",P,#`["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F-&4U9C<[
M"GT*(VUE;G4@82!["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A+F-U<G)E
M;G0@>PH@("`@8F%C:V=R;W5N9#H@(V4Q8S)E-SL*?0HC;65N=2!H,2!["B`@
M("!C;VQO<CH@(S`P,#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E
M8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V5E93L*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VQI9VAT8FQU92\`````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q-@`P,3<V
M-C$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;&EG:'1B;'5E+V=R
M87!H:6-S+P``````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-#$W,S8S,#$V`#`R,30V,0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]L:6=H=&)L=64O9W)A<&AI8W,O;65N=2YP;F<`````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`Q-C0`,3`T,3<S-C,P,38`,#(S,3,Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(```!#````%`$#````[(\2?P````903%1%:Z7><ZWOQ+-S7@````EP
M2%ES````2````$@`1LEK/@```!1)1$%4"-=C8,`"_D/!`R36(%<'`![16'&N
M3H:)`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;&EG:'1B
M;'5E+VEN9F\N<&AP````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,C`Q`#$P-#$W,S8S,#$V`#`R,3,Q,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H
M;W)D92]T:&5M97,O;&EG:'1B;'5E+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O
M,3<@,3DZ,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@
M7R@B3&EG:'0@0FQU92(I.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQI9VAT8FQU92]S8W)E96XN
M8W-S````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$T,``Q,#0Q
M-S,V,S`Q-@`P,C$V-#,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VQI9VAT
M8FQU92]S8W)E96XN8W-S+'8@,2XX+C8N,2`R,#`U+S$P+S$X(#$Q.C,T.C$Y
M(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(V(P9#!F
M,3L*?0IA('L*("`@(&-O;&]R.B`C,S,Y.PI]"BYH96%D97(@>PH@("`@8V]L
M;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C-F)A-61E.PI]"BYS;6%L;&AE
M861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",V8F$U
M9&4["GT*+F)U='1O;B!["B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH9W)A
M<&AI8W,O;65N=2YP;F<I.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@
M>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-F)A
M-61E.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+VUE;G4N
M<&YG*3L*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(V(P
M9#!F,3L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V(P9#!F,3L*?0HC<VED96)A<E!A
M;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z('EE;&QO=SL*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=E;FYE=FEL;&EE
M<G,O````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#0Q-S,V,S`Q-@`P,C`U-3``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9V5N;F5V:6QL:65R<R]I;F9O+G!H<```````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-S$T`#$P-#$W,S8S,#$V`#`R,C(Q,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AI<R!T:&5M92!A<R!B965N('=R:71T96X@8GD@06ED92!&;&]R96YT
M(#QF86ED94!A;'!H86-E;G0N8V]M/B!A;F0*("H@3>EL86YI92!'87)E874@
M/&UE;&%N:64N9V%R96%U0'9I;&QE+6=E;FYE=FEL;&EE<G,N9G(^"B`J"B`J
M(%1H92!T:&5M92!I9&5A('=A<R!T;R!I;F-O<G!O<F%T92!S;6]O=&AL>2!I
M;B!T:&4@:6YT<F%N970N"B`J(%1H:7,@=&AE;64@:7,@<'5B;&ES:&5D('5N
M9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(&AO<F1E('!A8VMA9V4N"B`J
M"B`J(%1H92!N86UE(&-O;65S(&9R;VT@=&AE(&-I='D@;V8@1V5N;F5V:6QL
M:65R<R!I;B!&<F%N8V4*("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O9V5N
M;F5V:6QL:65R<R]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,U
M(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(E1E86PB*3L*
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=E;FYE
M=FEL;&EE<G,O<V-R965N+F-S<P``````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C8V-0`Q,#0Q-S,V,S`Q-@`P,C(U-#<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J(%1H:7,@=&AE;64@87,@
M8F5E;B!W<FET=&5N(&)Y($%I9&4@1FQO<F5N="`\9F%I9&5`86QP:&%C96YT
M+F-O;3X@86YD"B`J($W#J6QA;FEE($=A<F5A=2`\;65L86YI92YG87)E875`
M=FEL;&4M9V5N;F5V:6QL:65R<RYF<CX*("H*("H@5&AE('1H96UE(&ED96$@
M=V%S('1O(&EN8V]R<&]R871E('-M;V]T:&QY(&EN('1H92!I;G1R86YE="X*
M("H@5&AI<R!T:&5M92!I<R!P=6)L:7-H960@=6YD97(@=&AE('-A;64@;&EC
M96YS92!A<R!T:&4@:&]R9&4@<&%C:V%G92X*("H*("H@5&AE(&YA;64@8V]M
M97,@9G)O;2!T:&4@8VET>2!O9B!'96YN979I;&QI97)S(&EN($9R86YC90H@
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]G96YN979I;&QI97)S+W-C<F5E
M;BYC<W,L=B`Q+C4N-BXS(#(P,#4O,3`O,3@@,3$Z,S0Z,3,@:F%N($5X<"`D
M"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C,#`V,S8S.PH@("`@<V-R
M;VQL8F%R+6)A<V4M8V]L;W(Z(",V,V(U8C4["B`@("!S8W)O;&QB87(M87)R
M;W<M8V]L;W(Z(",V,V(U8C4["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S
M92UC;VQO<CH@(S8S8C5B-3L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@
M(S8S8C5B-3L*?0IA('L*("`@(&-O;&]R.B`C,3(R96)A.PI]"F$Z:&]V97(@
M>PH@("`@8V]L;W(Z(",Q,C)E8F$["GT*82YW:61G970@>PH@("`@8V]L;W(Z
M(",P,#`["GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*
M+FAE861E<BP@+G-M86QL:&5A9&5R+"!A+G-M86QL:&5A9&5R('L*("`@(&-O
M;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S8S8C5B-3L*?0HN8G5T=&]N
M('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S0Q.&4X93L*
M("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@(S8P-3DU.3L*("`@(&)O
M<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C-C`U.34Y.PH@("`@8F]R9&5R+71O
M<#H@=&AI;B!S;VQI9"`C8V5C96-E.PH@("`@8F]R9&5R+6QE9G0Z('1H:6X@
M<V]L:60@(V9F9CL*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(S8S
M8C5B-3L*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R
M.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S8S8C5B-3L*?0HC;65N=2!A('L*
M("`@(&-O;&]R.B`C9F9F.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K
M9W)O=6YD.B`C-#$X93AE.PH@("`@8V]L;W(Z("-F9F8["GT*"B\J(%-I9&5B
M87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0Z
M(",V,V(U8C4["GT*(W-I9&5B87)086YE;"!S<&%N+"`C<VED96)A<E!A;F5L
M(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(W-I9&5B87)086YE;"!A.FAO=F5R
M('L*("`@(&-O;&]R.B`C9F9F.PI]"@HO*B!0<F5F97)E;F-E<R!O=F5R=FEE
M=RX@*B\*+G!R969S3W9E<G9I97<@:#(@>PH@("`@8V]L;W(Z("-F9F8["GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O;W!E<F$N8W-S````````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S,V`#$P-#$W,S8S,#$V`#`Q
M-S4R,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;W!E<F$N8W-S+'8@,2XQ
M+C(N-"`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@*B!#4U,@
M8V]R<F5C=&EO;G,@9F]R($]P97)A+@H@*B\*"BYT<F5E4F]W('L*("`@(&]V
M97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I9VAT.B`R,'!X.PI]"@HC;65N=2![
M"B`@("!O=F5R9FQO=SH@=FES:6)L93L*("`@(&AE:6=H=#H@-3!P>#L*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+W-A9F%R:2YC<W,`````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#0V-0`Q,#0Q-S,V,S`Q-@`P,3<V-C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+RHJ"B`J("1(
M;W)D93H@:&]R9&4O=&AE;65S+W-A9F%R:2YC<W,L=B`Q+C$N,BXV(#(P,#4O
M,3`O,3@@,3$Z,S0Z,3`@:F%N($5X<"`D"B`J"B`J($-34R!C;W)R96-T:6]N
M<R!F;W(@4V%F87)I+@H@*B\*"FEM9R!["B`@("!V97)T:6-A;"UA;&EG;CH@
M8F%S96QI;F4["GT*"BYT<F5E4F]W('L*("`@(&]V97)F;&]W.B!V:7-I8FQE
M.PH@("`@:&5I9VAT.B`R,'!X.PI]"@HN=')E95)O=R!I;6<@>PH@("`@=F5R
M=&EC86PM86QI9VXZ(&UI9&1L93L*?0H*(VUE;G4@>PH@("`@;W9E<F9L;W<Z
M('9I<VEB;&4["B`@("!H96EG:'0Z(#4P<'@["GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]R=&PN
M8W-S````````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$S,#``,3`T,3<S-C,P,38`,#$W,C`T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]R=&PN8W-S+'8@,2XR+C(N,2`R,#`U+S$P+S$X(#$Q.C,T.C$P
M(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@9&ER96-T:6]N.B!R=&P["B`@
M("!F;VYT+69A;6EL>3H@5&%H;VUA+$MO;V1A:RQ(;VUA+$YA>FQI+%9E<F1A
M;F$L1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"@HN;&5F
M=$%L:6=N('L*("`@("`@("!T97AT+6%L:6=N.B!R:6=H=#L*("`@("`@("!F
M;VYT+69A;6EL>3H@5&%H;VUA+$MO;V1A:RQ(;VUA+$YA>FQI+%9E<F1A;F$L
M1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"BYR:6=H=$%L
M:6=N('L*("`@("`@("!T97AT+6%L:6=N.B!L969T.PH@("`@("`@(&9O;G0M
M9F%M:6QY.B!486AO;6$L2V]O9&%K+$AO;6$L3F%Z;&DL5F5R9&%N82Q'96YE
M=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*"BYL969T1FQO870@
M>PH@("`@("`@(&9L;V%T.B!R:6=H=#L*?0HN<FEG:'1&;&]A="!["B`@("`@
M("`@9FQO870Z(&QE9G0["GT*"BYH96%D97(@=6P@>PH@("`@9FQO870Z(&QE
M9G0["B`@("!T97AT+6%L:6=N.B!L969T.PI]"@HO*B!486(@<W1Y;&5S+B`J
M+PHN=&%B<V5T('L*("`@(&9L;V%T.B!R:6=H=#L*?0HN=&%B<V5T(&QI('L*
M("`@(&9L;V%T.B!R:6=H=#L*?0HN=&%B<V5T(&EM9R!["B`@("!F;&]A=#H@
M<FEG:'0["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]S8W)E96XN8W-S````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,C4T,#(`,3`T,3<S-C,P,38`,#$W-C<S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W1H96UE<R]S8W)E96XN8W-S+'8@,2XW+C0N-34@,C`P-B\P,R\R
M,B`Q.#HQ-#HQ,R!J86X@17AP("0*("HO"@HO*B!';&]B86P@9&5F875L="!S
M='EL97,N("HO"BH@>PH@("`@+RH@6F5R;R!O=70@86QL('!A9&1I;F<@86YD
M(&UA<F=I;G,@=&\@<W1A<G0@=VET:"!F;W(@8F5T=&5R"B`@("`@*B!C<F]S
M<RUB<F]W<V5R(&-O;G1R;VPN("HO"B`@("!P861D:6YG.B`P.PH@("`@;6%R
M9VEN.B`P.PI]"@IB;V1Y('L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I
M86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@[
M"B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8V]L;W(Z(",P,#`["GT*"F)O
M9'DN<V-R;VQL8F%R+7%U:7)K('L*("`@(&UA<F=I;BUR:6=H=#H@,35P>#L*
M?0H*<"!["B`@("!M87)G:6XM8F]T=&]M.B`Q,'!X.PI]"@II;6<L("YI;6<L
M("YI;6<Z86-T:79E+"`N:6UG.FAO=F5R+"`N:6UG.G9I<VET960@>PH@("`@
M8F]R9&5R.B!N;VYE.PH@("`@=F5R=&EC86PM86QI9VXZ(&UI9&1L93L*("`@
M(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PI]"@II;G,@>PH@("`@8F%C:V=R
M;W5N9#H@(V-F8SL*?0ID96P@>PH@("`@8F%C:V=R;W5N9#H@(V9C8SL*?0H*
M8G(N<W!A8V5R('L*("`@(&9O;G0M<VEZ93H@.'!X.PI]"@HN;&5F=$%L:6=N
M('L*("`@('1E>'0M86QI9VXZ(&QE9G0["GT*+G)I9VAT06QI9VX@>PH@("`@
M=&5X="UA;&EG;CH@<FEG:'0["GT*+FQE9G1&;&]A="!["B`@("!F;&]A=#H@
M;&5F=#L*?0HN<FEG:'1&;&]A="!["B`@("!F;&]A=#H@<FEG:'0["GT*"BYB
M;W@@>PH@("`@<&%D9&EN9SH@,W!X.PH@("`@8F]R9&5R.B`Q<'@@9&%S:&5D
M(",Y.3D["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"BYS;VQI9&)O>"!["B`@
M("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PI]"BYG<F5Y8F]X('L*("`@(&)O
M<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!B86-K9W)O=6YD.B`C93EE.64Y
M.PI]"BYH96%D97)B;W@@>PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C
M,#`P.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P.PH@("`@8F%C:V=R;W5N9#H@
M(V9F9CL*?0HN<F]U;F1E9$)O>"!["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z
M(#$U<'@["GT*+G)O=6YD9614;W`@>PH@("`@+6UO>BUB;W)D97(M<F%D:75S
M+71O<')I9VAT.B`Q-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S+71O<&QE
M9G0Z(#$U<'@["GT*+G)O=6YD961";W1T;VT@>PH@("`@+6UO>BUB;W)D97(M
M<F%D:75S+6)O='1O;7)I9VAT.B`Q-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D
M:75S+6)O='1O;6QE9G0Z(#$U<'@["GT*+FAE861E<B!["B`@("!F;VYT+69A
M;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M
M=V5I9VAT.B!B;VQD.PH@("`@9F]N="US:7IE.B`Q-7!X.PH@("`@<&%D9&EN
M9SH@,W!X.PI]"BYH96%D97(@83IH;W9E<BP@82YH96%D97(Z:&]V97(@>PH@
M("`@8V]L;W(Z(",S,S,["GT*+FAE861E<B!I;6<@>PH@("`@=F5R=&EC86PM
M86QI9VXZ(&)O='1O;3L*?0HN:&5A9&5R('5L('L*("`@(&9L;V%T.B!R:6=H
M=#L*("`@('1E>'0M86QI9VXZ(')I9VAT.PH@("`@9F]N="US:7IE.B`Q,G!X
M.PI]"BYH96%D97(@;&D@>PH@("`@;&ES="US='EL93H@;F]N93L*("`@(&1I
M<W!L87DZ(&EN;&EN93L*?0HN;F]W<F%P('L*("`@('=H:71E+7-P86-E.B!N
M;W=R87`["GT*+F-L96%R('L*("`@(&-L96%R.B!B;W1H.PH@("`@;&EN92UH
M96EG:'0Z(#`["B`@("!H96EG:'0Z(#`["GT*"F$@>PH@("`@8V]L;W(Z(&)L
M=64["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*83IH;W9E<B!["B`@
M("!T97AT+61E8V]R871I;VXZ('5N9&5R;&EN93L*?0HN<V5L96-T960@>PH@
M("`@8F%C:V=R;W5N9#H@(V)B8V)F9CL*?0HN<V5L96-T960M;W9E<B!["B`@
M("!B86-K9W)O=6YD.B`C8V5F.PI]"@HO*B!486)L92!S='EL97,N("HO"G1A
M8FQE('L*("`@(&)O<F1E<CH@;F]N93L*?0IT9"P@=&@@>PH@("`@<&%D9&EN
M9SH@,7!X.PI]"G1H('L*("`@(&-O;&]R.B`C,S,S.PH@("`@9F]N="UF86UI
M;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I
M>F4Z(#$Q<'@["GT*=&0@>PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@9F]N
M="UF86UI;'DZ($=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*
M?0IU;"YL:6YE9%)O=R!["B`@("!L:7-T+7-T>6QE+71Y<&4Z(&YO;F4["GT*
M+FQI;F5D4F]W+"!T<BYL:6YE9%)O=R!T9"P@=&%B;&4N;&EN9612;W<@=&0L
M('5L+FQI;F5D4F]W(&QI('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R
M;W5N9#H@(V9F9CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9&1D
M.PI]"G1A8FQE+FQI;F5D4F]W+"!U;"YL:6YE9%)O=R!["B`@("!B;W)D97(M
M8F]T=&]M.B!N;VYE.PI]"BYL:6YE9%)O=U-E;&5C=&5D0V]L+"!T9"YL:6YE
M9%)O=U-E;&5C=&5D0V]L+"!T86)L92YL:6YE9%)O=R!T9"YL:6YE9%)O=U-E
M;&5C=&5D0V]L('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@
M(V8S9C-F,SL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9&1D.PI]
M"BYS96QE8W1E9%)O=RP@='(N<V5L96-T9612;W<@=&0@>PH@("`@8F%C:V=R
M;W5N9#H@(V9F8SL*?0HN<V5L96-T9612;W<Z:&]V97(L('1R+G-E;&5C=&5D
M4F]W('1D.FAO=F5R+"`N<V5L96-T9612;W<M;W9E<BP@='(N<V5L96-T9612
M;W<M;W9E<B!T9"!["B`@("!B86-K9W)O=6YD.B`C9F9D.PI]"G1A8FQE+FYO
M<&%D9&EN9R!T9"P@=&%B;&4N;F]P861D:6YG('1H('L*("`@('!A9&1I;F<Z
M(#`["GT*+G-O<G1U<"!["B`@("!B86-K9W)O=6YD.B`C8F)C8F9F('5R;"@B
M9W)A<&AI8W,O>F$N<&YG(BD@8V5N=&5R(&QE9G0@;F\M<F5P96%T.PH@("`@
M<&%D9&EN9RUL969T.B`Q,'!X.PI]"BYS;W)T9&]W;B!["B`@("!B86-K9W)O
M=6YD.B`C8F)C8F9F('5R;"@B9W)A<&AI8W,O87HN<&YG(BD@8V5N=&5R(&QE
M9G0@;F\M<F5P96%T.PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PI]"B\J($%L
M=&5R;F%T:6YG('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D97!R96-A=&5D
M+B`J+PHN<F]W179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U;F0Z("-E964[
M"GT*+G)O=T]D9"P@+FET96TQ('L*("`@(&)A8VMG<F]U;F0Z("-D9&0["GT*
M"BYW:61G970@>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A
M+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["GT*"BYM:6UE4W1A
M='5S365S<V%G92!["B`@("!P861D:6YG.B`Q<'@["B`@("!M87)G:6XM8F]T
M=&]M.B`T<'@["B`@("!B;W)D97(Z(#%P>"!D87-H960@(S`P8SL*("`@(&)A
M8VMG<F]U;F0Z("-E968["B`@("!C;VQO<CH@(S`P-CL*?0HN;6EM95-T871U
M<U=A<FYI;F<@>PH@("`@<&%D9&EN9SH@,7!X.PH@("`@;6%R9VEN+6)O='1O
M;3H@-'!X.PH@("`@8F]R9&5R.B`Q<'@@9&%S:&5D("-F,#`["B`@("!B86-K
M9W)O=6YD.B`C9F9D,&%F.PH@("`@8V]L;W(Z("-F,#`["GT*"BYL:6=H="![
M"B`@("!C;VQO<CH@(V9F9CL*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I
M86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@[
M"GT*+G-M86QL:&5A9&5R('L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I
M86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@[
M"B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*?0IS;6%L;"P@+G-M86QL('L*("`@
M(&9O;G0M<VEZ93H@,3!P>#L*?0HN8V]N=')O;"!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0Z("-C8V,["B`@("!B;W)D97(M8F]T=&]M.B`Q
M<'@@<V]L:60@(SDY.3L*?0HN:71E;2!["B`@("!C;VQO<CH@(S`P,#L*("`@
M(&)A8VMG<F]U;F0Z("-E964["GT*+F%C8V5S<TME>2!["B`@("!T97AT+61E
M8V]R871I;VXZ('5N9&5R;&EN93L*?0HN=&5X="!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*"B\J($9O<FT@<W1Y;&5S+B`J
M+PHN9F]R;2!T86)L92!["B`@("!W:61T:#H@,3`P)3L*("`@('!A9&1I;F<Z
M(#)P>#L*("`@(&)O<F1E<BUC;VQL87!S93H@8V]L;&%P<V4["GT*+FAT;6QA
M<F5A("YS=&%T=7-"87(@+G-T871U<T)A<E1R964@82!["B`@("!F;VYT.B!I
M;FAE<FET.PI]"BYH=&UL87)E82!T86)L92!["B`@("!W:61T:#H@875T;SL*
M?0HN9F]R;2UE<G)O<B!["B`@("!C;VQO<CH@(V8P,#L*?0II;G!U="P@<V5L
M96-T('L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L=F5T:6-A
M+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@("!F;VYT+7=E
M:6=H=#H@;F]R;6%L.PI]"FEN<'5T('L*("`@('!A9&1I;F<Z(#%P>#L*?0IO
M<'1I;VX@>PH@("`@<&%D9&EN9SH@,'!X(#5P>"`P<'@@,W!X.PI]"BYC:&5C
M:V)O>"!["B`@("!B;W)D97(Z(#`["B`@("!H96EG:'0Z(#$T<'@["B`@("!W
M:61T:#H@,31P>#L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PI]"BYB
M=71T;VX@>PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@9F]N="UF86UI;'DZ
M(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!P861D:6YG.B`Q
M<'@@-G!X.PI]"F$N8G5T=&]N('L*("`@('!A9&1I;F<Z(#)P>"`X<'@["B`@
M("!F;VYT+7=E:6=H=#H@;F]R;6%L.PH@("`@=&5X="UD96-O<F%T:6]N.B!N
M;VYE.PI]"@HN9FEX960@>PH@("`@9F]N="US:7IE.B`Q,W!X.PH@("`@9F]N
M="UF86UI;'DZ(&UO;F]S<&%C92QF:7AE9#L*?0H*+RH@4W1Y;&5S(&9O<B!E
M;6%I;"UL:6ME(&UE<W-A9V5S+B`J+PHN<VEG;F%T=7)E('L*("`@(&-O;&]R
M.B`C8V-C.PI]"BYS:6=N871U<F4M9FEX960@>PH@("`@8V]L;W(Z("-C8V,[
M"B`@("!F;VYT+7-I>F4Z(#$S<'@["B`@("!F;VYT+69A;6EL>3H@;6]N;W-P
M86-E+&9I>&5D.PI]"BYC:71A=&EO;B!["B`@("!M87)G:6XZ(#%E;2`P.PH@
M("`@<&%D9&EN9RUL969T.B`Q96T["B`@("!B;W)D97(M;&5F="UW:61T:#H@
M,7!X.PH@("`@8F]R9&5R+6QE9G0M<W1Y;&4Z('-O;&ED.PI]"BYQ=6]T960Q
M('L*("`@(&-O;&]R.B`C-C`V.PH@("`@8F]R9&5R+6QE9G0M8V]L;W(Z(",V
M,#8["GT*+G%U;W1E9#(@>PH@("`@8V]L;W(Z(",P-S<["B`@("!B;W)D97(M
M;&5F="UC;VQO<CH@(S`W-SL*?0HN<75O=&5D,R!["B`@("!C;VQO<CH@(SDP
M,#L*("`@(&)O<F1E<BUL969T+6-O;&]R.B`C.3`P.PI]"BYQ=6]T960T('L*
M("`@(&-O;&]R.B`C,#`Y.PH@("`@8F]R9&5R+6QE9G0M8V]L;W(Z(",P,#D[
M"GT*+G%U;W1E9#4@>PH@("`@8V]L;W(Z("-B-C`["B`@("!B;W)D97(M;&5F
M="UC;VQO<CH@(V(V,#L*?0H*+RH@5F%R:6]U<R!P;W!U<"!A;F0@<W1A='5S
M(&QA>65R<RX@*B\*+FYO=&EC92!["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*
M("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F8SL*("`@(&)O
M<F1E<CH@,7!X('-O;&ED("-A86$["B`@("!P861D:6YG.B`Q<'@["B`@("!P
M861D:6YG+6QE9G0Z(#5P>#L*("`@(&UA<F=I;BUB;W1T;VTZ(#%P>#L*("`@
M("UM;WHM8F]R9&5R+7)A9&EU<SH@.'!X.PI]"BYT;V]L=&EP+"!D:78N;FEC
M971I=&QE('L*("`@(&9O;G0Z(#$Q<'@O,3)P>"!697)D86YA+$%R:6%L+'-E
M<FEF.PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C9F9C.PH@
M("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#5P>#L*
M("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@,W!X.PI]"F1I=BYN:6-E=&ET;&4@
M>PH@("`@<&]S:71I;VXZ(&%B<V]L=71E.PH@("`@;W9E<F9L;W<Z(&AI9&1E
M;CL*("`@(&]P86-I='DZ("XY,#L*?0ID:78N;FEC971I=&QE('!R92!["B`@
M("!F;VYT+69A;6EL>3H@(DQU8VED82!#;VYS;VQE(BQM;VYO<W!A8V4L9FEX
M960["GT*+FEN4')O9W)E<W,@>PH@("`@9F]N=#H@,3!P>"!'96YE=F$L07)I
M86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!P861D:6YG.B`R<'@["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-F,#`["GT*"B\J(%1R
M964@<W1Y;&5S+B`J+PHN=')E95)O=R!["B`@("!O=F5R9FQO=SH@:&ED9&5N
M.PH@("`@;6EN+6AE:6=H=#H@,C!P>#L*("`@(&-L96%R.B!B;W1H.PI]"@HO
M*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@;W9E<F9L;W<Z(&AI9&1E
M;CL*("`@(&UI;BUH96EG:'0Z(#4P<'@["B`@("!F;VYT+69A;6EL>3H@5F5R
M9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&UA<F=I;BUB;W1T;VTZ
M(#AP>#L*?0HC;65N=2!U;"!["B`@("!P861D:6YG.B`U<'@["GT*(VUE;G4@
M;&D@>PH@("`@;&ES="US='EL92UT>7!E.B!N;VYE.PH@("`@=&5X="UA;&EG
M;CH@8V5N=&5R.PH@("`@;6%R9VEN.B`R<'@["B`@("!F;&]A=#H@;&5F=#L*
M?0HC;65N=2!A('L*("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@=VAI=&4M<W!A
M8V4Z('!R93L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS
M86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@=&5X="UD96-O
M<F%T:6]N.B!N;VYE.PH@("`@<&%D9&EN9SH@,W!X.PH@("`@+6UO>BUB;W)D
M97(M<F%D:75S.B`S<'@["GT*(VUE;G4@:#$@>PH@("`@9F]N="UF86UI;'DZ
M(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7=E:6=H
M=#H@8F]L9#L*("`@(&9O;G0M<VEZ93H@,3AP>#L*("`@(&QI;F4M:&5I9VAT
M.B`T.'!X.PH@("`@=F5R=&EC86PM86QI9VXZ(&)O='1O;3L*?0HC;65N=2!I
M;G!U="P@(VUE;G4@<V5L96-T('L*("`@(&UA<F=I;BUT;W`Z(#$V<'@["GT*
M"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHN<VED96)A<B`C;65N=2!["B`@("!M
M87)G:6XZ(#`["GT*(W-I9&5B87)086YE;"!["B`@("`M;6]Z+6)O<F1E<BUR
M861I=7,M8F]T=&]M<FEG:'0Z(#$U<'@["B`@("!P861D:6YG+71O<#H@-7!X
M.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#$P<'@["B`@("!B86-K9W)O=6YD.B`C
M965E.PH@("`@=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0HC<VED96)A<E!A;F5L
M('-P86XL("-S:61E8F%R4&%N96P@82!["B`@("!C;VQO<CH@(S`P,#L*("`@
M('=H:71E+7-P86-E.B!P<F4["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(
M96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@
M('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*?0HC<VED96)A<E!A;F5L('-P86XN
M=&]G9VQE('L*("`@(&-U<G-O<CH@<&]I;G1E<CL*?0HC<VED96)A<E!A;F5L
M(&$Z:&]V97(@>PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`S<'@["B`@("!C
M;VQO<CH@(S`P,#L*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!["B`@
M("!F;&]A=#H@;&5F=#L*("`@('=I9'1H.B`Q,#`E.PH@("`@9F]N="UW96EG
M:'0Z(&)O;&0["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]B
M;W1T;VTN9VEF(BD@<F5P96%T+7@@8F]T=&]M.PI]"BYT86)S970@=6P@>PH@
M("`@;6%R9VEN+71O<#H@-'!X.PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PH@
M("`@;&ES="US='EL93H@;F]N93L*?0HN=&%B<V5T(&QI('L*("`@(&9L;V%T
M.B!L969T.PH@("`@;6%R9VEN+71O<#H@+3-P>#L*("`@(&UA<F=I;BUL969T
M.B`R<'@["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]"BYT86)S970@;&D@
M82!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E
M.64Y93D["B`@("!P861D:6YG.B`R<'@@,"XU96T["B`@("!D:7-P;&%Y.B!B
M;&]C:SL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M
M8F]T=&]M+6-O;&]R.B`C93EE.64Y.PH@("`@+6UO>BUB;W)D97(M<F%D:75S
M+71O<&QE9G0Z(#$P<'@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,M=&]P<FEG
M:'0Z(#$P<'@["GT*+G1A8G-E="!L:2!A.FAO=F5R('L*("`@('1E>'0M9&5C
M;W)A=&EO;CH@;F]N93L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["GT*
M+G1A8G-E="!L:2YA8W1I=F5486(@82!["B`@("!B;W)D97(M8F]T=&]M.B`Q
M<'@@<V]L:60@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`["B`@
M("!C;VQO<CH@(V9F9CL*?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A.FAO=F5R
M('L*?0HN=&%B<V5T(&EM9R!["B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@(&9L
M;V%T.B!L969T.PH@("`@<&%D9&EN9RUR:6=H=#H@,G!X.PI]"@HO*B!0<F5F
M97)E;F-E<R!O=F5R=FEE=RX@*B\*+G!R969S3W9E<G9I97<@9&EV('L*("`@
M(&9L;V%T.B!L969T.PI]"BYP<F5F<T]V97)V:65W(&1I=B!D:78@>PH@("`@
M<&%D9&EN9RUL969T.B`Q,'!X.PH@("`@=VED=&@Z(#DU)3L*?0HN<')E9G-/
M=F5R=FEE=R!H,B!["B`@("!F;VYT+7-I>F4Z(#$X<'@["B`@("!F;VYT+7=E
M:6=H=#H@8F]L9#L*?0HN<')E9G-/=F5R=FEE=R!D="!A('L*("`@(&1I<W!L
M87DZ(&)L;V-K.PH@("`@<&%D9&EN9SH@,G!X.PH@("`@9F]N="UW96EG:'0Z
M(&)O;&0["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED(",T-#8["B`@("!B86-K9W)O=6YD.B`C93EE
M.64Y.PI]"BYP<F5F<T]V97)V:65W(&1D('L*("`@('!A9&1I;F<Z(#)P>#L*
M("`@(&UA<F=I;BUB;W1T;VTZ(#$P<'@["B`@("!C;VQO<CH@(S`P,#L*("`@
M(&)A8VMG<F]U;F0Z("-F9F8["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED
M(",P,#`["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@
M8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["GT*"B\J($)L;V-K('-T
M>6QE<RX@*B\*+F-U<G)E;G1";&]C:R!["B`@("!B;W)D97(Z(#)P>"!S;VQI
M9"!R960["GT*"B\J($AE;'`@<W1Y;&5S+B`J+PHN:&5L<"!["B`@("!B86-K
M9W)O=6YD.B`C9F9F.PH@("`@8V]L;W(Z(",P,#`["GT*+FAE;'`@:#$@>PH@
M("`@9F]N="US:7IE.B`Q-7!X.PH@("`@<&%D9&EN9RUT;W`Z(#`N-65M.PH@
M("`@<&%D9&EN9RUB;W1T;VTZ(#`N-65M.PI]"BYH96QP(&@R('L*("`@(&)O
M<F1E<BUT;W`Z(#%P>"!S;VQI9"`C-#0V.PH@("`@<&%D9&EN9RUT;W`Z(#%E
M;3L*("`@('!A9&1I;F<M8F]T=&]M.B`P+C5E;3L*("`@(&9O;G0M<VEZ93H@
M,3-P>#L*?0HN:&5L<"!P('L*("`@(&UA<F=I;BUL969T.B`Q96T["B`@("!M
M87)G:6XM<FEG:'0Z(#%E;3L*("`@(&UA<F=I;BUB;W1T;VTZ(#%E;3L*?0HN
M:&5L<"!E;2!["B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@('!A9&1I;F<Z(#5P
M>#L*("`@(&UA<F=I;BUL969T.B`Q96T["B`@("!M87)G:6XM<FEG:'0Z(#%E
M;3L*("`@(&UA<F=I;BUB;W1T;VTZ(#%E;3L*?0HN:&5L<"!E;2YH96QP5&EP
M('L*("`@(&-O;&]R.B`C,#DP.PH@("`@8F%C:V=R;W5N9#H@(V4P9C!E,#L*
M?0HN:&5L<"!E;2YH96QP5V%R;B!["B`@("!C;VQO<CH@(SDP,#L*("`@(&)A
M8VMG<F]U;F0Z("-F,&4P93`["GT*"B\J(%-O=7)C92!M87)K=7`@<W1Y;&5S
M+B`J+PIT86)L92YL:6YE3G5M8F5R960@>PH@("`@;6%R9VEN.B`U<'@["B`@
M("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PI]"BYL:6YE3G5M8F5R960@=&@@
M>PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE.3L*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED("-E,&4P93`["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED
M("-F,V8S9C,["B`@("!P861D:6YG+6QE9G0Z(#$P<'@["B`@("!P861D:6YG
M+7)I9VAT.C$P<'@["B`@("!T97AT+6%L:6=N.B!R:6=H=#L*?0HN;&EN94YU
M;6)E<F5D('1H(&$@>PH@("`@9F]N="UF86UI;'DZ(&UO;F]S<&%C93L*("`@
M(&9O;G0M<VEZ93H@,3)P>#L*("`@(&QI;F4M:&5I9VAT.B`Q-G!X.PI]"BYL
M:6YE3G5M8F5R960@=&0@>PH@("`@=F5R=&EC86PM86QI9VXZ('1O<#L*("`@
M('=I9'1H.B`Q,#`E.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*("`@(&)A8VMG
M<F]U;F0Z("-F9F8["B`@("!P861D:6YG+6QE9G0Z(#$P<'@["B`@("!F;VYT
M+69A;6EL>3H@;6]N;W-P86-E.PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@
M=VAI=&4M<W!A8V4Z('!R93L*("`@(&QI;F4M:&5I9VAT.B`Q-G!X.PI]"BYP
M87)E;G1H97-E<R!["B`@("!C;VQO<CH@(S)A-CL*("`@(&9O;G0M=V5I9VAT
M.B!B;VQD.PI]"BYC;VUM96YT('L*("`@(&-O;&]R.B`C86%C.PI]"BYH=&%G
M('L*("`@(&-O;&]R.B`C-38Y.PH@("`@8F%C:V=R;W5N9#H@(V0U9#9D83L*
M("`@(&9O;G0M=V5I9VAT.B!B;VQD.PI]"BYM971A8R!["B`@("!C;VQO<CH@
M(S!F9CL*("`@(&)A8VMG<F]U;F0Z("-D-60V9&$["GT*+FED('L*("`@(&-O
M;&]R.B`C93@R.PH@("`@8F%C:V=R;W5N9#H@(V4T931E,#L*?0HN871T<B![
M"B`@("!C;VQO<CH@(S9A9CL*?0HN=F%L=64@>PH@("`@8V]L;W(Z("-D-#8[
M"GT*+F-O;&]R('L*("`@(&-O;&]R.B`C9C4W.PI]"BYE;VP@>PH@("`@8V]L
M;W(Z(",R-F4["GT*+G5R;"!["B`@("!C;VQO<CH@(SDV,CL*?0HN9FEL92![
M"B`@("!C;VQO<CH@(S0T-#L*("`@(&)A8VMG<F]U;F0Z("-F930["GT*+F-L
M87-S('L*("`@(&9O;G0M<W1Y;&4Z(&ET86QI8SL*?0H*+RH@1')O<"!S:&%D
M;W=S+B`J+PHN9')O<%-H861O=R!["B`@("!F;&]A=#H@;&5F=#L*("`@(&)A
M8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O<VAA9&]W+G!N9R(I(&YO+7)E<&5A
M="!B;W1T;VT@<FEG:'0@(6EM<&]R=&%N=#L*("`@(&)A8VMG<F]U;F0Z('5R
M;"@B9W)A<&AI8W,O<VAA9&]W+F=I9B(I(&YO+7)E<&5A="!B;W1T;VT@<FEG
M:'0["B`@("!M87)G:6XZ(#$P<'@@,"`P(#5P>#L*?0H*+F1R;W!3:&%D;W<@
M:6UG('L*("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@<&]S:71I;VXZ(')E;&%T
M:79E.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<CH@,7!X('-O
M;&ED(",V-C8["B`@("!M87)G:6XZ("TS<'@@-7!X(#5P>"`M,W!X.PH@("`@
M<&%D9&EN9SH@,G!X.PI]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z,30N8W-S````
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C8P
M`#$P-#$W,S8S,#$V`#`Q-S,V,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O
M;6]Z,30N8W-S+'8@,2XQ+C(N,B`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%
M>'`@)`H@*@H@*B!#4U,@8V]R<F5C=&EO;G,@9F]R($UO>FEL;&$@/#T@,2XT
M+@H@*B\*"B-M96YU('L*("`@(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I
M9VAT.B`U,'!X.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+VEE-E]O<E]L97-S+F-S<P``````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,T,P`Q,#0Q-S,V,S`Q
M-@`P,C`V,C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VEE-E]O<E]L97-S
M+F-S<RQV(#$N,2XR+C$@,C`P-B\P,R\R-"`P,#HT,#HS-R!C:'5C:R!%>'`@
M)`H@*@H@*B!#4U,@8V]R<F5C=&EO;G,@9F]R($E%+@H@*B\*"BYT<F5E4F]W
M('L*("`@(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I9VAT.B`R,'!X.PI]
M"@HC;65N=2!["B`@("!O=F5R9FQO=SH@=FES:6)L93L*("`@(&AE:6=H=#H@
M-3!P>#L*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]I935M86,N8W-S````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`U,S0`,3`T,3<S-C,P,38`,#$W-34V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]I935M86,N8W-S+'8@,2XR+C0N,R`R
M,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@*B!#4U,@8V]R<F5C
M=&EO;G,@9F]R($E%-2]-86,N"B`J+PH*(VUE;G4@;&D@>PH@("`@=VED=&@Z
M(#0P<'@["GT*+G1A8G-E="!["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]
M"BYT86)S970@;&D@82!["B`@("!F;&]A=#H@;&5F=#L*?0HC<VED96)A<E!A
M;F5L('L*("`@('!A9&1I;F<M8F]T=&]M.B`S,'!X.PI]"BYH96%D97(@>PH@
M("`@8VQE87(Z(&YO;F4["GT*+FAE861E<B!U;"!["B`@("!W:61T:#H@,24[
M"B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]U=&EL+P``
M````````````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$V`#`Q-3,W,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W5T:6PO8F%R8V]D92YP:'``````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4S-C$`,3`T,3<S-C,P,38`,#$W
M-3`T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W5T:6PO8F%R8V]D92YP:'`L
M=B`Q+C$P+C$P+C,@,C`P-B\P,2\P,2`R,3HR.3HQ-R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N
M8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]);6%G92YP:'`G.PH*+R\@1V5T('1E>'0L('5P<&5R8V%S92P@
M861D('-T87)T+W-T;W`@8VAA<F%C=&5R<RX*)'1E>'0@/2!5=&EL.CIG971&
M;W)M1&%T82@G8F%R8V]D92<L("=T97-T)RD["B1T97AT(#T@4W1R:6YG.CIU
M<'!E<B@D=&5X="P@=')U92D["B1T97AT(#T@(BHD=&5X="HB.PHD=&5X=&QE
M;B`]('-T<FQE;B@D=&5X="D["@HD:&5I9VAT(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V@G+"`T,"D["B1T:&EN=VED=&@@/2!5=&EL.CIG971&;W)M1&%T82@G
M=R<L(#(I.PHD=&AI8VMW:61T:"`]("1T:&EN=VED=&@@*B`S.PHD=VED=&@@
M/2`D=&5X=&QE;B`J("@W("H@)'1H:6YW:61T:"`K(#,@*B`D=&AI8VMW:61T
M:"D@+2`D=&AI;G=I9'1H.PH*)&-O9&EN9VUA<"`](&%R<F%Y*"<P)R`]/B`G
M,#`P,3$P,3`P)RP@)S$G(#T^("<Q,#`Q,#`P,#$G+`H@("`@("`@("`@("`@
M("`@("`@)S(G(#T^("<P,#$Q,#`P,#$G+"`G,R<@/3X@)S$P,3$P,#`P,"<L
M("<T)R`]/B`G,#`P,3$P,#`Q)RP*("`@("`@("`@("`@("`@("`@("<U)R`]
M/B`G,3`P,3$P,#`P)RP@)S8G(#T^("<P,#$Q,3`P,#`G+"`G-R<@/3X@)S`P
M,#$P,#$P,2<L"B`@("`@("`@("`@("`@("`@("`G."<@/3X@)S$P,#$P,#$P
M,"<L("<Y)R`]/B`G,#`Q,3`P,3`P)RP@)T$G(#T^("<Q,#`P,#$P,#$G+`H@
M("`@("`@("`@("`@("`@("`@)T(G(#T^("<P,#$P,#$P,#$G+"`G0R<@/3X@
M)S$P,3`P,3`P,"<L("=$)R`]/B`G,#`P,#$Q,#`Q)RP*("`@("`@("`@("`@
M("`@("`@("=%)R`]/B`G,3`P,#$Q,#`P)RP@)T8G(#T^("<P,#$P,3$P,#`G
M+"`G1R<@/3X@)S`P,#`P,3$P,2<L"B`@("`@("`@("`@("`@("`@("`G2"<@
M/3X@)S$P,#`P,3$P,"<L("=))R`]/B`G,#`Q,#`Q,3`P)RP@)THG(#T^("<P
M,#`P,3$Q,#`G+`H@("`@("`@("`@("`@("`@("`@)TLG(#T^("<Q,#`P,#`P
M,3$G+"`G3"<@/3X@)S`P,3`P,#`Q,2<L("=-)R`]/B`G,3`Q,#`P,#$P)RP*
M("`@("`@("`@("`@("`@("`@("=.)R`]/B`G,#`P,#$P,#$Q)RP@)T\G(#T^
M("<Q,#`P,3`P,3`G+"`G4"<@/3X@)S`P,3`Q,#`Q,"<L"B`@("`@("`@("`@
M("`@("`@("`G42<@/3X@)S`P,#`P,#$Q,2<L("=2)R`]/B`G,3`P,#`P,3$P
M)RP@)U,G(#T^("<P,#$P,#`Q,3`G+`H@("`@("`@("`@("`@("`@("`@)U0G
M(#T^("<P,#`P,3`Q,3`G+"`G52<@/3X@)S$Q,#`P,#`P,2<L("=6)R`]/B`G
M,#$Q,#`P,#`Q)RP*("`@("`@("`@("`@("`@("`@("=7)R`]/B`G,3$Q,#`P
M,#`P)RP@)U@G(#T^("<P,3`P,3`P,#$G+"`G62<@/3X@)S$Q,#`Q,#`P,"<L
M"B`@("`@("`@("`@("`@("`@("`G6B<@/3X@)S`Q,3`Q,#`P,"<L("<@)R`]
M/B`G,#$Q,#`P,3`P)RP@)R0G(#T^("<P,3`Q,#$P,#`G+`H@("`@("`@("`@
M("`@("`@("`@)R4G(#T^("<P,#`Q,#$P,3`G+"`G*B<@/3X@)S`Q,#`Q,#$P
M,"<L("<K)R`]/B`G,#$P,#`Q,#$P)RP*("`@("`@("`@("`@("`@("`@("<M
M)R`]/B`G,#$P,#`P,3`Q)RP@)RXG(#T^("<Q,3`P,#`Q,#`G+"`G+R<@/3X@
M)S`Q,#$P,#`Q,"<I.PH*)&EM86=E(#T@)DAO<F1E7TEM86=E.CIF86-T;W)Y
M*%5T:6PZ.F=E=$9O<FU$871A*"=T>7!E)RP@)W!N9R<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W1E;7`G(#T^($AO<F1E.CIG
M971496UP1&ER*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=VED=&@G(#T^("1W:61T:"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=H96EG:'0G(#T^("1H96EG:'0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F%C:V=R;W5N9"<@/3X@
M)W=H:71E)RDI.PH*)'AP;W,@/2`P.PIF;W(@*"1I9'@@/2`P.R`D:61X(#P@
M)'1E>'1L96X[("1I9'@K*RD@>PH@("`@)&-H87(@/2!S=6)S='(H)'1E>'0L
M("1I9'@L(#$I.PH@("`@+R\@36%K92!U;FMN;W=N(&-H87)S(&$@)RTG+@H@
M("`@:68@*"%I<W-E="@D8V]D:6YG;6%P6R1C:&%R72DI('L*("`@("`@("`D
M8VAA<B`]("<M)SL*("`@('T*("`@(&9O<B`H)&)A<B`](#`[("1B87(@/#T@
M.#L@)&)A<BLK*2!["B`@("`@("`@)&5L96UE;G1W:61T:"`]("1C;V1I;F=M
M87!;)&-H87)=>R1B87)](#\@)'1H:6-K=VED=&@@.B`D=&AI;G=I9'1H.PH@
M("`@("`@(&EF("@H)&)A<B`K(#$I("4@,BD@>PH@("`@("`@("`@("`D:6UA
M9V4M/G)E8W1A;F=L92@D>'!O<RP@,"P@)&5L96UE;G1W:61T:"`M(#$L("1H
M96EG:'0L("=B;&%C:R<L("=B;&%C:R<I.PH@("`@("`@('T*("`@("`@("`D
M>'!O<R`K/2`D96QE;65N='=I9'1H.PH@("`@?0H@("`@)'AP;W,@*ST@)'1H
M:6YW:61T:#L*?0H*:&5A9&5R*"=0<F%G;6$Z('!U8FQI8R<I.PHD:6UA9V4M
M/F1I<W!L87DH*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=71I;"]I
M8V]N7V)R;W=S97(N<&AP````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-34R-P`Q,#0Q-S,V,S`Q-@`P,C`V,#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O=71I;"]I8V]N7V)R;W=S97(N<&AP+'8@,2XT+C(N-"`R
M,#`V+S`Q+S`Q(#(Q.C(Y.C$W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P-"TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E
M*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N
M<&AP)SL*"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*"D["B1A
M<'!S(#T@)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G;F]T;V]L8F%R)RP@
M)V%C=&EV92<L("=A9&UI;B<L("=I;F%C=&EV92<L("=H:61D96XG*2P@=')U
M92D["FMS;W)T*"1A<'!S*3L*"FEF("@H)&%P<"`](&)A<V5N86UE*%5T:6PZ
M.F=E=$9O<FU$871A*"=A<'`G*2DI("8F(&ES<V5T*"1A<'!S6R1A<'!=*2D@
M>PH@("`@+R\@4')O=FED92!A(&YO;BUW:&ET92!B86-K9W)O=6YD(&9O<B!E
M>65B86QL:6YG('1R86YS<&%R96YC>2X*("`@(&5C:&\@)SQH=&UL/CQB;V1Y
M(&)G8V]L;W(](B-A86%A86$B/B<["@H@("`@)'1H96UE1&ER(#T@)')E9VES
M=')Y+3YG970H)W1H96UE<V9S)RP@)&%P<"D["B`@("!I9B`H(6ES7V1I<B@D
M=&AE;65$:7(I*2!["B`@("`@("`@97AI="AS<')I;G1F*%\H(E1H96UE<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB*2P@)'1H96UE1&ER*2D["B`@
M("!]"@H@("`@+R\@0F%S92!G<F%P:&EC<R!F;W(@;F]W+"!F965L(&9R964@
M=&\@861D('1H96UE('-U<'!O<G0N"B`@("`D8F%S961I<B`]("1D:7(@/2`D
M=&AE;65$:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)V=R87!H:6-S)SL*
M("`@(&EF("@A:7-?9&ER*"1D:7(I*2!["B`@("`@("`@97AI="AS<')I;G1F
M*%\H(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(BDL("1D:7(I*3L*("`@('T*"B`@("!I9B`H*"1S=6)D:7(@/2!B87-E;F%M
M92A5=&EL.CIG971&;W)M1&%T82@G<W5B9&ER)RDI*2D@>PH@("`@("`@("1D
M:7(@+CT@1$E214-43U)97U-%4$%2051/4B`N("1S=6)D:7(["B`@("`@("`@
M:68@*"%I<U]D:7(H)&1I<BDI('L*("`@("`@("`@("`@97AI="AS<')I;G1F
M*%\H(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(I+"`D9&ER*2D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\O($)R96%D8W)U;6)S+@H@("`@96-H
M;R!(;W)D93HZ;&EN:R@G:6-O;E]B<F]W<V5R+G!H<"<I("X@7R@B07!P;&EC
M871I;VX@3&ES="(I("X@)SPO83X\8G(@+SXG.PH@("`@:68@*"%E;7!T>2@D
M<W5B9&ER*2D@>PH@("`@("`@(&5C:&\@2&]R9&4Z.FQI;FLH)VEC;VY?8G)O
M=W-E<BYP:'`_87!P/2<@+B`D87!P*2`N("1R96=I<W1R>2T^9V5T*"=N86UE
M)RP@)&%P<"D@+B`G/"]A/CQB<B`O/B<["B`@("!]"B`@("!E8VAO("<\8G(@
M+SXG.PH*("`@("\O(%-H;W<@:6-O;G,@9F]R(&%P<"X*("`@(&5C:&\@)SQH
M,CXG("X@<W!R:6YT9BA?*"))8V]N<R!F;W(@)7,B*2P@)')E9VES=')Y+3YG
M970H)VYA;64G+"`D87!P*2D@+B`H(65M<'1Y*"1S=6)D:7(I(#\@)R\G("X@
M)'-U8F1I<B`Z("<G*2`N("<\+V@R/B<["@H*("`@("\O($QI<W0@<W5B9&ER
M96-T;W)I97,N"B`@("`D<W5B9&ER<R`](&=L;V(H)&1I<B`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`G*B<L($=,3T)?3TY,641)4BD["B`@("!I9B`H)'-U
M8F1I<G,@)B8@8V]U;G0H)'-U8F1I<G,I*2!["B`@("`@("`@9F]R96%C:"`H
M)'-U8F1I<G,@87,@)'-U8F1I<BD@>PH@("`@("`@("`@("!I9B`H8F%S96YA
M;64H)'-U8F1I<BD@/3T@)T-64R<I('L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@2&]R9&4Z.FQI
M;FLH571I;#HZ861D4&%R86UE=&5R*"=I8V]N7V)R;W=S97(N<&AP)RP@87)R
M87DH)W-U8F1I<B<@/3X@8F%S96YA;64H)'-U8F1I<BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V%P<"<@/3X@)&%P<"DI*2`N(&)A<V5N86UE
M*"1S=6)D:7(I("X@)SPO83X\8G(@+SXG.PH@("`@("`@('T*("`@("`@("!E
M8VAO("<\8G(@+SXG.PH@("`@?0H*("`@("1I;6%G97,@/2!G;&]B*"1D:7(@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)RHN<&YG)RD["B`@("!I9B`H)&EM
M86=E<R`F)B!C;W5N="@D:6UA9V5S*2D@>PH@("`@("`@(&9O<F5A8V@@*"1I
M;6%G97,@87,@)'!N9RD@>PH@("`@("`@("`@("!E8VAO($AO<F1E.CII;6<H
M<W1R7W)E<&QA8V4H)&)A<V5D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2+"`G
M)RP@)'!N9RDL("1P;F<L(&%R<F%Y*"=H<W!A8V4G(#T^(#$P+"`G=G-P86-E
M)R`]/B`Q,"DL("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)&%P<"DI.PH@("`@
M("`@('T*("`@('T@96QS92!["B`@("`@("`@96-H;R!?*").;R!I8V]N<R!F
M;W5N9"XB*3L*("`@('T*"B`@("!E8VAO("<\+V)O9'D^/"]H=&UL/B<["GT@
M96QS92!["B`@("`O+R!,:7-T(&%P<',N"B`@("!F;W)E86-H("@D87!P<R!A
M<R`D87!P*2!["B`@("`@("`@96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&10
M87)A;65T97(H)VEC;VY?8G)O=W-E<BYP:'`G+"`G87!P)RP@)&%P<"DI("X@
M)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*2`N("<\+V$^/&)R("\^)SL*
M("`@('T*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]U=&EL+W)E9V5X7W1E<W0N<&AP````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,S$V`#$P
M-#$W,S8S,#$V`#`R,#(U-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@4VEM<&QE('-C<FEP="!T;R!H
M96QP('=I=&@@<F5G97@@8V]N<W1R=6-T:6]N+V1E8G5G9VEN9RX@4'5T(&ET
M"B`J('-O;65W:&5R92!O;B!Y;W5R('=E8G-E<G9E<B!A;F0@<&]I;G0@>6]U
M<B!B<F]W<V5R('1O(&ET+@H@*@H@*B!"87-E9"!O;CH@:'1T<#HO+VUY9FQU
M9F9Y9&]G+F-O;2]P<F]G<F%M;6EN9R]P:'`O<V-R:7!T<R]R96=E>'`N<&AP
M"B`J"B`J("1(;W)D93H@:&]R9&4O=71I;"]R96=E>%]T97-T+G!H<"QV(#$N
M,RXQ,"XT(#(P,#4O,3`O,3@@,3$Z,S0Z,C$@:F%N($5X<"`D"B`J+PH*<F5Q
M=6ER92`G2&]R9&4O571I;"YP:'`G.PHD<F5G97AP(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W)E9V5X<"<I.PHD<W5B:F5C="`](%5T:6PZ.F=E=$9O<FU$871A
M*"=S=6)J96-T)RD["B1S=6)M:70@/2!5=&EL.CIG971&;W)M1&%T82@G<W5B
M;6ET)RD["@I`<V5T7W1I;65?;&EM:70H,BD["@IF=6YC=&EO;B!U;FAT;6QE
M;G1I=&EE<R@D<W1R:6YG*0I["B`@("`D=')A;G-?=&)L(#T@9V5T7VAT;6Q?
M=')A;G-L871I;VY?=&%B;&4H2%1-3%]%3E1)5$E%4RD["B`@("`D=')A;G-?
M=&)L(#T@87)R87E?9FQI<"@D=')A;G-?=&)L*3L*("`@(')E='5R;B!S=')T
M<B@D<W1R:6YG+"`D=')A;G-?=&)L*3L*?0H*:68@*"1S=6)M:70@/3T@(E1E
M<W0B*2![("\O(&1O:6YG(&$@<F5G(&5X<')E<W-I;VX@<V5A<F-H("TM(&=E
M="!V87)I86)L97,*("`@("1U;F5S8V%P961296=E>'`@/2!U;FAT;6QE;G1I
M=&EE<R@D<F5G97AP*3L@+R\@9F]R('-E87)C:`H@("`@)&5S8V%P961296=E
M>'`@/2!H=&UL96YT:71I97,H)')E9V5X<"D[("\O(&9O<B!S:&]W:6YG(&]N
M('!A9V4@86YD(&EN('1E>'1A<F5A"B`@("`D=&5X="`]("1S=6)J96-T.PH@
M("`@)'1E>'0@/2!S=')I<'-L87-H97,H)'1E>'0I.PH@("`@)'1E>'0@/2!U
M;FAT;6QE;G1I=&EE<R@D=&5X="D[("\O(&9O<B!S96%R8V@*("`@("1E<V-A
M<&5D5&5X="`](&AT;6QE;G1I=&EE<R@D=&5X="D[+R\@9F]R('1E>'1A<F5A
M"@H@("`@+R\@1&\@<')E9U]R97!L86-E(&]N('-O=7)C92P@<W5B<W1I='5T
M:6YG(&UA=&-H961?=&5X="!W:71H(%MB76UA=&-H961?=&5X=%LO8ET*("`@
M("1H:6=H;&EG:'1E9%1E>'0@/2!P<F5G7W)E<&QA8V4H)'5N97-C87!E9%)E
M9V5X<"P@)UMB75Q<,%LO8ETG+"`D=&5X="D["B`@("`O+R!C;VYV97)T(&AT
M;6QE;G1I=&EE<PH@("`@)&AI9VAL:6=H=&5D5&5X="`](&AT;6QE;G1I=&EE
M<R@D:&EG:&QI9VAT961497AT*3L*("`@("\O(')E<&QA8V4@6V)=(&%N9"!;
M+V)=('=I=&@@:&EG:&QI9VAT+@H@("`@)&AI9VAL:6=H=&5D5&5X="`]('-T
M<E]R97!L86-E*"=;8ETG+"`G/'-P86X@8VQA<W,](FAI9VAL:6=H="(^)RP@
M)&AI9VAL:6=H=&5D5&5X="D["B`@("`D:&EG:&QI9VAT961497AT(#T@<W1R
M7W)E<&QA8V4H)ULO8ETG+"`G/"]S<&%N/B<L("1H:6=H;&EG:'1E9%1E>'0I
M.PI]"C\^"CQH=&UL/@H\:&5A9#X*/'1I=&QE/E1E<W0@<F5G=6QA<B!E>'!R
M97-S:6]N<SPO=&ET;&4^"CQS='EL92!T>7!E/2)T97AT+V-S<R(^"CPA+2T*
M:#$@>PH@("`@9F]N="US:7IE.B!L87)G93L*?0HN9FEX960@>PH@("`@9F]N
M="US:7IE.B`Q,'!X.PH@("`@9F]N="UF86UI;'DZ(&UO;F]S<&%C92QF:7AE
M9#L*("`@(&-O;&]R.B`C,#`P,#DY.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(V-C8V-C8SL*?0HN;F]T97,@>PH@("`@9F]N="US:7IE.B!S;6%L;#L*("`@
M(&-O;&]R.B`C,#`P,#DY.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-C8V-C
M8SL*?0HN:&EG:&QI9VAT('L*("`@(&-O;&]R.B`C,#`P,#8V.PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V9F9F8P,#L*?0HN96UP='D@>PH@("`@8F%C:V=R
M;W5N9"UC;VQO<CH@(V9F.3DS,PI]"BTM/@H\+W-T>6QE/@H\;65T82!H='1P
M+65Q=6EV/2)#;VYT96YT+51Y<&4B(&-O;G1E;G0](G1E>'0O:'1M;#L@8VAA
M<G-E=#UI<V\M.#@U.2TQ(CX*/"]H96%D/@H\8F]D>2!B9V-O;&]R/2(C1D9&
M1D9&(CX*/&@Q/E1E<W0@/&$@:')E9CTB:'1T<#HO+W=W=RYP:'`N;F5T+VUA
M;G5A;"]E;B]R968N<&-R92YP:'`B/E!(4"!296=U;&%R($5X<')E<W-I;VX@
M1G5N8W1I;VYS("A097)L+4-O;7!A=&EB;&4I/"]A/CPO:#$^"CQD:78@8VQA
M<W,](F9I>&5D(CYP<F5G7VUA=&-H7V%L;"@D<&%T=&5R;BP@)'-U8FIE8W0L
M("1M871C:&5S+"!04D5'7U-%5%]/4D1%4BD\+V1I=CX*/&9O<FT@;F%M93TB
M9F]R;3$B(&UE=&AO9#TB<&]S="(@86-T:6]N/2(\/W!H<"!E8VAO("1?4T52
M5D526R=02%!?4T5,1B==(#\^(CX*/'`^/'-T<F]N9SY%;G1E<B!Y;W5R(')E
M9W5L87(@97AP<F5S<VEO;B`H)'!A='1E<FXI.CPO<W1R;VYG/CQB<B`O/@H\
M=&5X=&%R96$@;F%M93TB<F5G97AP(B!C;VQS/2(X,"(@<F]W<STB-B(@:60]
M(G)E9V5X<"(^/#]P:'`@:68H)'-U8FUI="E[96-H;R`D97-C87!E9%)E9V5X
M<#M]/SX\+W1E>'1A<F5A/@H\8G(@+SX*/'-T<F]N9SY%;G1E<B!T97AT('1O
M('-E87)C:"!A9V%I;G-T(&EN('1H92!T97AT87)E82!B96QO=R`H)'-U8FIE
M8W0I.CPO<W1R;VYG/CQB<B`O/@H\=&5X=&%R96$@;F%M93TB<W5B:F5C="(@
M8V]L<STB.#`B(')O=W,](C,B/CP_<&AP(&EF*"1S=6)J96-T*7ME8VAO("1E
M<V-A<&5D5&5X=#M]/SX\+W1E>'1A<F5A/@H\8G(@+SX*/&EN<'5T('1Y<&4]
M(G-U8FUI="(@;F%M93TB<W5B;6ET(B!V86QU93TB5&5S="(^"CQI;G!U="!T
M>7!E/2)R97-E="(@;F%M93TB4F5S970B('9A;'5E/2)297-E="(^"CQA(&AR
M968])SP_<&AP(&5C:&\@)%]315)615);)U!(4%]314Q&)UT@/SXG/DAO;64\
M+V$^/&)R("\^"CPO<#X*/"]F;W)M/@H\:'(@+SX*/#]P:'`*:68@*"1S=6)M
M:70I('L@+R\@;VYL>2!S:&]W<R!U<"!O;B!R97-U;'1S('!A9V4*("`@(&EF
M("AP<F5G7VUA=&-H7V%L;"@D=6YE<V-A<&5D4F5G97AP+"`D=&5X="P@)')E
M<W5L=',L(%!214=?4T547T]21$52*2D@>R`O+R!F;W5N9"!M871C:`H@("`@
M("`@(&5C:&\@(E1H92!R96=E>'`@/'-T<F]N9SX@)&5S8V%P961296=E>'`@
M/"]S=')O;F<^(&UA=&-H960A7&X\<#XB.PH@("`@("`@(&5C:&\@(CQH,3Y(
M97)E)W,@=VAA="!W87,@;6%T8VAE9"!S96%R8VAI;F<@=&AE('1E>'0@>6]U
M(&5N=&5R960Z/"]H,3Y<;B(["B`@("`@("`@)'D@/2`P.PH@("`@("`@(&5C
M:&\@)SQD:78@8VQA<W,](F9I>&5D(CXG.PH@("`@("`@(&9O<F5A8V@@*"1R
M97-U;'1S(&%S("1L;V]P7W)E<W5L="D@>PH@("`@("`@("`@("`D>"`](#`[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1L;V]P7W)E<W5L="!A<R`D;&]O<%]R
M97-U;'0R*2!["B`@("`@("`@("`@("`@("!I9B`H)'@@(3T@,"D@>PH@("`@
M("`@("`@("`@("`@("`@("\J($EN9&5N="!S=6)P871T97)N<RX@*B\*("`@
M("`@("`@("`@("`@("`@("!E8VAO("(\8FQO8VMQ=6]T93XB.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@<')I;G1F*"<D;6%T8VAE<ULE
M<UU;)7-=.B9N8G-P.R9N8G-P.R<L("1Y+"`D>"D[+R\@<VAO=R!V87)I86)L
M92!N86UE"B`@("`@("`@("`@("`@("!I9B`H(21L;V]P7W)E<W5L=#(I('L*
M("`@("`@("`@("`@("`@("`@("!E8VAO("<\<W!A;B!C;&%S<STB96UP='DB
M/D5M<'1Y/"]S<&%N/B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(&5C:&\@)SQS<&%N(&-L87-S/2)H:6=H;&EG:'0B
M/B<@+B!H=&UL96YT:71I97,H)&QO;W!?<F5S=6QT,BD@+B`G/"]S<&%N/B<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)'@@(3T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@(CPO8FQO8VMQ=6]T93XB
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!E8VAO("(\<"`O/B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D>"LK.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1Y*RL["B`@
M("`@("`@?0H@("`@("`@(&5C:&\@)SPO9&EV/B<["B`@("!](&5L<V4@>R`O
M+R!N;R!M871C:`H@("`@("`@(&5C:&\@(G)E9V5X<"`\<W1R;VYG/B`D97-C
M87!E9%)E9V5X<"`\+W-T<F]N9SX@9&]E<VXG="!R971U<FX@86YY(')E<W5L
M='-<;CQP/B(["B`@("!]"B`@("`_/@H@("`@/&@Q/E-E87)C:&5D('1E>'0@
M=VET:"!M871C:&5S(#QS<&%N(&-L87-S/2=H:6=H;&EG:'0G/FAI9VAL:6=H
M=&5D/"]S<&%N/CPO:#$^"B`@("`\/W!H<"`O+R!3:&]W('-E87)C:&5D('1E
M>'0@=VET:"!M871C:&5S(&AI9VAL:6=H=&5D"B`@("!E8VAO("<\<')E/B<[
M"B`@("!E8VAO("1H:6=H;&EG:'1E9%1E>'0["B`@("!E8VAO("<\+W!R93X\
M:'(@+SXG.PI]"C\^"@H\9&EV(&-L87-S/2)N;W1E<R(^"CQH,3Y%>&%M<&QE
M(')E9W5L87(@97AP<F5S<VEO;G,Z/"]H,3X*/'`^/'-T<F]N9SY[)FQT.R$M
M+2@_.BY\7',I*C\M+29G=#M]/"]S=')O;F<^)FYB<W`[("TM)FYB<W`[(%-H
M;W=S(&-O;6UE;G1S(&EN(&AT;6PF;F)S<#L\+W`^"CQU;#X*/&QI/CQS=')O
M;F<^>SPO<W1R;VYG/B!O<&5N(&1E;&EM:71E<CPO;&D^"CQL:3X\<W1R;VYG
M/B9L=#LA+2T\+W-T<F]N9SX@<V5A<F-H(&9O<B!O<&5N:6YG(&-O;6UE;G0@
M=&%G/"]L:3X*/&QI/CQS=')O;F<^*#\Z+GQ<<RDJ/"]S=')O;F<^(&%N>2!N
M=6UB97(@;V8@8VAA<F%C=&5R<R!O<B!W:&ET92!S<&%C93PO;&D^"CQL:3X\
M<W1R;VYG/C\\+W-T<F]N9SX@;F]N+6=R965D>3PO;&D^"CQL:3X\<W1R;VYG
M/BTM)F=T.SPO<W1R;VYG/B!S96%R8V@@9F]R(&-L;W-I;F<@8V]M;65N="!T
M86<\+VQI/@H\;&D^/'-T<F]N9SY]/"]S=')O;F<^(&-L;W-E(&1E;&EM:71E
M<CPO;&D^"CPO=6P^"CQP/CQS=')O;F<^>R9L=#MS='EL92!T>7!E*#\Z+GQ<
M<RDJ/R9L=#LO<W1Y;&4F9W0[?3PO<W1R;VYG/B`M+2!3:&]W<R`@<W1Y;&5S
M/"]P/@H\<#Y.;W1E<SH\+W`^"CQU;#X*/&QI/E1H92!R97-U;'1S('!A9V4@
M<VAO=W,@=&AE(&EN9&EV:61U86P@;6%T8VAE<R!A;F0@<W5B<&%T=&5R;B!M
M871C:&5S+"!A;F0@=&AE(&]R:6=I;F%L('1E>'0@=VET:"!T:&4@;6%T8VAE
M<R!H:6=H;&EG:'1E9"X\+VQI/@H\;&D^36EG:'0@;F]T(&)E(&%B;&4@=&\@
M<V5A<F-H(&9O<B!H=&UL(&5N=&ET:65S(&QI:V4@(B9A;7`[86UP.R(@8F5C
M875S92!O9B!T:&4@8V]N=F5R=&EN9R!F;W(@9&ES<&QA>2!A;F0@=&5X=&%R
M96%S("AT:&4@<V5A<F-H('!A='1E<FX@*')E9V5X<"D@86YD(&YO;BUU<FP@
M<W5B:F5C=',@87)E('!R;V-E<W-E9"!B>2!U;FAT;6QE;G1I=&EE<RD\+VQI
M/@H\+W5L/CPO9&EV/@H\+V)O9'D^"CPO:'1M;#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S8W)I<'1S+P``````````````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$V`#`Q-C$P-``@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S
M-C,P,38`,#$W-S$V`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U
M<&=R861E<R\R+C)?=&]?,RXP+FUY<W%L+G-Q;```````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-#8W-P`Q,#0Q-S,V,S`Q-@`P,C,R,#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+W5P9W)A9&5S+S(N,E]T;U\S+C`N;7ES<6PN<W%L+'8@,2XR+C@N
M,B`R,#`U+S$P+S$X(#$Q.C,T.C`Q(&IA;B!%>'`@)`HM+0HM+2!9;W4@8V%N
M('-I;7!L>2!E>&5C=71E('1H:7,@9FEL92!I;B!Y;W5R(&1A=&%B87-E+@HM
M+0HM+2!2=6X@87,Z"BTM"BTM("0@;7ES<6P@+2UU<V5R/7)O;W0@+2UP87-S
M=V]R9#T\37E344PM<F]O="UP87-S=V]R9#X@/&1B(&YA;64^(#P@,BXR7W1O
M7S,N,"YM>7-Q;"YS<6P*"E5312!H;W)D93L*"D%,5$52(%1!0DQ%(&AO<F1E
M7W!R969S($-(04Y'12!#3TQ534X@<')E9E]U:60@<')E9E]U:60@5D%20TA!
M4B@R,#`I($Y/5"!.54Q,.PI$14Q%5$4@1E)/32!H;W)D95]P<F5F<R!72$52
M12!P<F5F7VYA;64@/2`G;&%S=%]L;V=I;B<@04Y$('!R969?<V-O<&4@/2`G
M:6UP)SL*"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@("`@("!D
M871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("`@("!G<F]U<%]U:60@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@=7-E<E]U:60@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?;F%M92!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]P87)E;G1S(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7V]R9&5R($E.5"P*("`@
M("`@(&1A=&%T<F5E7V1A=&$@5$585"P*("`@("`@(&1A=&%T<F5E7W-E<FEA
M;&EZ960@4TU!3$Q)3E0@1$5&055,5"`P($Y/5"!.54Q,+`H@("`@("`@9&%T
M871R965?=7!D871E9"!424U%4U1!35`L"@H@("`@("`@4%))34%262!+15D@
M*&1A=&%T<F5E7VED*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T
M<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE
M*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D
M871A=')E92`H9W)O=7!?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S
M97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)
M3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E
M92`H9&%T871R965?<V5R:6%L:7IE9"D["@I#4D5!5$4@5$%"3$4@:&]R9&5?
M9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"!)3E0@3D]4
M($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2!$149!54Q4("<G
M($Y/5"!.54Q,+`H@("`@871T<FEB=71E7W9A;'5E(%1%6%0**3L*"D-214%4
M12!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T
M<F5E7V%T=')I8G5T97,@*&1A=&%T<F5E7VED*3L*0U)%051%($E.1$58(&1A
M=&%T<F5E7V%T=')I8G5T95]N86UE7VED>"!/3B!H;W)D95]D871A=')E95]A
M='1R:6)U=&5S("AA='1R:6)U=&5?;F%M92D["D-214%412!)3D1%6"!D871A
M=')E95]A='1R:6)U=&5?:V5Y7VED>"!/3B!H;W)D95]D871A=')E95]A='1R
M:6)U=&5S("AA='1R:6)U=&5?:V5Y*3L*"D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E92!43R!H;W)D94!L
M;V-A;&AO<W0["D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$54
M12!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S(%1/(&AO<F1E0&QO8V%L
M:&]S=#L*"D-214%412!404),12!H;W)D95]T;VME;G,@*`H@("`@=&]K96Y?
M861D<F5S<R`@("!605)#2$%2*#@I($Y/5"!.54Q,+`H@("`@=&]K96Y?:60@
M("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S
M=&%M<"`@0DE'24Y4($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AT;VME
M;E]A9&1R97-S+"!T;VME;E]I9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]T;VME;G,@5$\@:&]R9&5`;&]C
M86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?:60@
M("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]T>7!E("`@("`@4TU!
M3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)3E0@3D]4($Y53$PL"B`@
M("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F
M<U]D871A("`@("`@3$].1T),3T(L"@H@("`@4%))34%262!+15D@("`H=F9S
M7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P871H7VED>"!/3B!H;W)D95]V
M9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58('9F<U]N86UE7VED>"!/3B!H
M;W)D95]V9G,@*'9F<U]N86UE*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!5
M4$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@5$\@:&]R9&5`;&]C86QH;W-T
M.PH`````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?=&]?,RXP+G!G<W%L+G-Q;```````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-#<Q,``Q,#0Q-S,V,S`Q-@`P,C,Q-#8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2T@66]U
M(&-A;B!S:6UP;'D@97AE8W5T92!T:&ES(&9I;&4@:6X@>6]U<B!D871A8F%S
M92X*+2T*+2T@4G5N(&%S.@HM+0HM+2`D('!S<6P@/&1B(&YA;64^("UF(#(N
M,E]T;U\S+C`N<&]S=&=R97-Q;"YS<6P*"D)%1TE..PI!3%1%4B!404),12!H
M;W)D95]P<F5F<R!!1$0@0T],54U.('!R969?=6ED7VYE=R!605)#2$%2*#(P
M,"D["E501$%412!H;W)D95]P<F5F<R!3150@<')E9E]U:61?;F5W(#T@<')E
M9E]U:60["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($123U`@<')E9E]U:60[
M"D%,5$52(%1!0DQ%(&AO<F1E7W!R969S(%)%3D%-12!P<F5F7W5I9%]N97<@
M5$\@<')E9E]U:60["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($%,5$52($-/
M3%5-3B!P<F5F7W5I9"!3150@3D]4($Y53$P["D-/34U)5#L*1$5,151%($92
M3TT@:&]R9&5?<')E9G,@5TA%4D4@<')E9E]N86UE(#T@)VQA<W1?;&]G:6XG
M($%.1"!P<F5F7W-C;W!E(#T@)VEM<"<["@I#4D5!5$4@5$%"3$4@:&]R9&5?
M9&%T871R964@*`H@("`@("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@
M("`@("`@9W)O=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@
M('5S97)?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T
M<F5E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R
M965?<&%R96YT<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A
M=')E95]O<F1E<B!)3E0L"B`@("`@("!D871A=')E95]D871A(%1%6%0L"B`@
M("`@("!D871A=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%53%0@,"!.
M3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7W5P9&%T960@5$E-15-404U0+`H*
M("`@("`@(%!224U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-214%412!)
M3D1%6"!D871A=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A
M=')E92`H9&%T871R965?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G
M<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%4
M12!)3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H
M=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I
M9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*
M0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@
M9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#
M2$%2*#(U-2D@1$5&055,5"`G)R!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]V
M86QU92!415A4"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E
M7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I
M9"D["D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@
M3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I
M.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@
M:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M9&%T871R964@5$\@:&]R9&4["D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!
M5$4L($1%3$5412!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S(%1/(&AO
M<F1E.PH*0U)%051%(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`@("!T;VME;E]A
M9&1R97-S("`@(%9!4D-(05(H."D@3D]4($Y53$PL"B`@("!T;VME;E]I9"`@
M("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@=&]K96Y?=&EM97-T
M86UP("!"24=)3E0@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*'1O:V5N
M7V%D9')E<W,L('1O:V5N7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L
M(%501$%412P@1$5,151%($].(&AO<F1E7W1O:V5N<R!43R!H;W)D93L*"D-2
M14%412!404),12!H;W)D95]V9G,@*`H@("`@=F9S7VED("`@("`@("!"24=)
M3E0@3D]4($Y53$PL"B`@("!V9G-?='EP92`@("`@(%--04Q,24Y4($Y/5"!.
M54Q,+`H@("`@=F9S7W!A=&@@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL
M"B`@("!V9G-?;F%M92`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@
M('9F<U]M;V1I9FEE9"`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?9&%T82`@("`@
M(%1%6%0L"@H@("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%
M($E.1$58('9F<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*
M0U)%051%($E.1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N
M86UE*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/
M3B!H;W)D95]V9G,@5$\@:&]R9&4["@H`````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R,#`U+3`Y+3(R7VAO
M<F1E7W!R969S7W9A<F-H87(R+F]C:3@N<W%L```````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$W,P`Q,#0Q-S,V,S`Q
M-@`P,C8U,#0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@57-E('1H:7,@<V-R:7!T('1O(&-O;G9E<G0@0TA!4B!C;VQU
M;6YS(&EN(&AO<F1E7W!R969S('1O(%9!4D-(05(R(&%N9"!T<FEM"BTM('1H
M92!S<&%C92!P861D:6YG+B`@5&AI<R!I<R!O;FQY(&YE8V5S<V%R>2!I9B!H
M;W)D95]P<F5F<R!W87,@8W)E871E9"!U<VEN9PHM+2!S8W)I<'1S+W-Q;"]C
M<F5A=&4N;V-I."YS<6P*+2T*+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W5P
M9W)A9&5S+S(P,#4M,#DM,C)?:&]R9&5?<')E9G-?=F%R8VAA<C(N;V-I."YS
M<6PL=B`Q+C$N,BXQ(#(P,#4O,3`O,3@@,3$Z,S0Z,#$@:F%N($5X<"`D"BTM
M"D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($U/1$E&62!P<F5F7W5I9"!605)#
M2$%2,B@R-34I.PI!3%1%4B!404),12!H;W)D95]P<F5F<R!-3T1)1ED@<')E
M9E]S8V]P92!605)#2$%2,B@Q-BD["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S
M($U/1$E&62!P<F5F7VYA;64@5D%20TA!4C(H,S(I.PI54$1!5$4@:&]R9&5?
M<')E9G,@4T54('!R969?=6ED(#T@4E1224TH<')E9E]U:60I.PI54$1!5$4@
M:&]R9&5?<')E9G,@4T54('!R969?<V-O<&4@/2!25%))32AP<F5F7W-C;W!E
M*3L*55!$051%(&AO<F1E7W!R969S(%-%5"!P<F5F7VYA;64@/2!25%))32AP
M<F5F7VYA;64I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\S+C!?=&]?
M,RXQ+FUY<W%L+G-Q;```````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3<R-``Q,#0Q
M-S,V,S`Q-@`P,C,Q-C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W5P9W)A9&5S
M+S,N,%]T;U\S+C$N;7ES<6PN<W%L+'8@,2XQ+C(N,2`R,#`V+S`Q+S`V(#$P
M.C0Q.C$S(&IA;B!%>'`@)`HM+0HM+2!9;W4@8V%N('-I;7!L>2!E>&5C=71E
M('1H:7,@9FEL92!I;B!Y;W5R(&1A=&%B87-E+@HM+0HM+2!2=6X@87,Z"BTM
M"BTM("0@;7ES<6P@+2UU<V5R/7)O;W0@+2UP87-S=V]R9#T\37E344PM<F]O
M="UP87-S=V]R9#X@/&1B(&YA;64^(#P@,RXP7W1O7S,N,2YM>7-Q;"YS<6P*
M"D%,5$52(%1!0DQ%(&AO<F1E7W5S97)S($%$1"!#3TQ534X@=7-E<E]S;V9T
M7V5X<&ER871I;VY?9&%T92!)3E0["D%,5$52(%1!0DQ%(&AO<F1E7W5S97)S
M($%$1"!#3TQ534X@=7-E<E]H87)D7V5X<&ER871I;VY?9&%T92!)3E0["@I#
M4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@(&AI<W1O<GE?:60@
M("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I9"`@("`@("!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C=&EO;B`@(%9!
M4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@("`@("!"24=)
M3E0@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@(%1%6%0L"B`@("!H
M:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(H,C4U*2P*("`@(&AI<W1O<GE?97AT
M<F$@("`@5$585"P*+2T*("`@(%!224U!4ED@2T59("AH:7-T;W)Y7VED*0HI
M.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED>"!/3B!H;W)D95]H
M:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%051%($E.1$58(&AI<W1O
M<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T<RD["D-2
M14%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?:&ES=&]R:65S
M("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L
M($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@5$\@:&]R9&5`;&]C86QH;W-T
M.PH`````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R]M
M;W9E7VAI<W1O<GE?;W5T7V]F7V1A=&%T<F5E+G!H<```````````````````
M```````````````P,3`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C0T
M,``Q,#0Q-S,V,S`Q-@`P,C8T,#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R$O=7-R+V)I;B]P:'`@+7$*/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R]M;W9E7VAI<W1O
M<GE?;W5T7V]F7V1A=&%T<F5E+G!H<"QV(#$N,RXR+C$@,C`P-2\Q,"\Q."`Q
M,3HS-#HP,2!J86X@17AP("0*("H*("H@5&AI<R!I<R!A('-C<FEP="!T;R!M
M:6=R871E($AI<W1O<GD@:6YF;W)M871I;VX@;W5T(&]F('1H92!D871A=')E
M90H@*B!T86)L97,@86YD(&EN=&\@:71S(&]W;B!D871A8F%S92!T86)L92X*
M("HO"@HO+R!&:6YD('1H92!B87-E(&9I;&4@<&%T:"!O9B!(;W)D92X*0&1E
M9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%7T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*"B\O($1O($-,
M22!C:&5C:W,@86YD(&5N=FER;VYM96YT('-E='5P(&9I<G-T+@IR97%U:7)E
M7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]#3$DN<&AP)SL*"B\O($UA:V4@<W5R92!N;R!O;F4@<G5N
M<R!T:&ES(&9R;VT@=&AE('=E8BX*:68@*"%(;W)D95]#3$DZ.G)U;FYI;F=&
M<F]M0TQ)*"DI('L*("`@(&5X:70H(DUU<W0@8F4@<G5N(&9R;VT@=&AE(&-O
M;6UA;F0@;&EN95QN(BD["GT*"B\O($QO860@=&AE($-,22!E;G9I<F]N;65N
M="`M(&UA:V4@<W5R92!T:&5R92=S(&YO('1I;64@;&EM:70L(&EN:70*+R\@
M<V]M92!V87)I86)L97,L(&5T8RX*2&]R9&5?0TQ).CII;FET*"D["B1C;&D@
M/2!(;W)D95]#3$DZ.G-I;F=L971O;B@I.PH*)&-L:2T^=W)I=&5L;B@D8VQI
M+3YY96QL;W<H(D)E9VEN;FEN9R!M:6=R871I;VXN(%1H:7,@;6%Y('1A:V4@
M82!V97)Y(&QO;F<@=&EM92!T;R!C;VUP;&5T92XB*2D["B1C;&DM/G=R:71E
M;&XH*3L*"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4<F5E+G!H<"<["@IC;&%S
M<R!$871A5')E94]B:F5C=%](:7-T;W)Y(&5X=&5N9',@1&%T851R965/8FIE
M8W0@>PH*("`@(&9U;F-T:6]N(%]F<F]M071T<FEB=71E<R@D871T<FEB=71E
M<RD*("`@('L*("`@("`@("`O*B!);FET:6%L:7IE(&1A=&$@87)R87DN("HO
M"B`@("`@("`@)'1H:7,M/F1A=&$@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E
M86-H("@D871T<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3YD871A6R1A='1R6R=N86UE)UU=*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F1A=&%;)&%T=');)VYA;64G75T@/2!A<G)A>2@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YD871A6R1A='1R
M6R=N86UE)UU=6R1A='1R6R=K97DG75T@/2`D871T<ELG=F%L=64G73L*("`@
M("`@("!]"B`@("!]"@I]"@HD9&%T871R964@/2`F1&%T851R964Z.F9A8W1O
M<GDH)W-Q;"<L(&%R<F%Y7VUE<F=E*$AO<F1E.CIG971$<FEV97)#;VYF:6<H
M)V1A=&%T<F5E)RP@)W-Q;"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=G<F]U<"<@/3X@)VAO
M<F1E+FAI<W1O<GDG*2DI.PHD9&(@/2`F)&1A=&%T<F5E+3Y?9&(["@HD:7-Q
M;"`]("=)3E-%4E0@24Y43R!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?:60L
M(&]B:F5C=%]U:60L(&AI<W1O<GE?86-T:6]N+"!H:7-T;W)Y7V1E<V,L(&AI
M<W1O<GE?=VAO+"!H:7-T;W)Y7W1S+"!H:7-T;W)Y7V5X=')A*2<@+@H@("`@
M("`@("<@5D%,5453("@_+"`_+"`_+"`_+"`_+"`_+"`_*2<["@HD86QL(#T@
M)&1A=&%T<F5E+3YG970H1$%40512145?1D]234%47T9,050L($1!5$%44D5%
M7U)/3U0L('1R=64I.PIU;G-E="@D86QL6T1!5$%44D5%7U)/3U1=*3L*)&ED
M<R`](&%R<F%Y7VME>7,H)&%L;"D["@IF;W)E86-H("@D:61S(&%S("1I9"D@
M>PH@("`@)&]B(#T@)&1A=&%T<F5E+3YG971/8FIE8W1">4ED*"1I9"P@)T1A
M=&%4<F5E3V)J96-T7TAI<W1O<GDG*3L*("`@(&9O<F5A8V@@*"1O8BT^9V5T
M1&%T82@I(&%S("1R;W<I('L*("`@("`@("`D=F%L=65S(#T@87)R87DH)&1B
M+3YN97AT260H)VAO<F1E7VAI<W1O<FEE<R<I+"`@("`@("`@("`@("`@("`@
M("\O(&AI<W1O<GE?:60*("`@("`@("`@("`@("`@("`@("`@("`@)&]B+3YG
M971.86UE*"DL("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&]B:F5C=%]U:60*("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H)')O
M=ULG86-T:6]N)UTI(#\@)')O=ULG86-T:6]N)UT@.B!N=6QL+"`@("\O(&AI
M<W1O<GE?86-T:6]N"B`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1R
M;W=;)V1E<V,G72D@/R`D<F]W6R=D97-C)UT@.B!N=6QL+"`@("`@("`O+R!H
M:7-T;W)Y7V1E<V,*("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H)')O
M=ULG=VAO)UTI(#\@)')O=ULG=VAO)UT@.B!N=6QL+"`@("`@("`@("\O(&AI
M<W1O<GE?=VAO"B`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1R;W=;
M)W1S)UTI(#\@)')O=ULG=',G72`Z(&YU;&PL("`@("`@("`@("`O+R!H:7-T
M;W)Y7W1S"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@('5N
M<V5T*"1R;W=;)V%C=&EO;B==*3L*("`@("`@("!U;G-E="@D<F]W6R=D97-C
M)UTI.PH@("`@("`@('5N<V5T*"1R;W=;)W=H;R==*3L*("`@("`@("!U;G-E
M="@D<F]W6R=T<R==*3L*("`@("`@("!I9B`H8V]U;G0H)')O=RDI('L*("`@
M("`@("`@("`@)'9A;'5E<UM=(#T@<V5R:6%L:7IE*"1R;W<I.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(&AI<W1O<GE?97AT<F$*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L=65S6UT@/2!N=6QL.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M:&ES=&]R>5]E>'1R80H@("`@("`@('T*"B`@("`@("`@8VAE8VLH)&1B+3YQ
M=65R>2@D:7-Q;"P@)'9A;'5E<RDI.PH@("`@?0H*("`@(&-H96-K*"1D8BT^
M<75E<GDH)T1%3$5412!&4D]-(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@
M5TA%4D4@9&%T871R965?:60@/2`_)RP@87)R87DH)&ED*2DI.PH@("`@8VAE
M8VLH)&1B+3YQ=65R>2@G1$5,151%($923TT@:&]R9&5?9&%T871R964@5TA%
M4D4@9&%T871R965?:60@/2`_)RP@87)R87DH)&ED*2DI.PI]"@HD8VQI+3YW
M<FET96QN*"1C;&DM/F=R965N*")$;VYE+B!-:6=R871E9"`B("X@8V]U;G0H
M)&ED<RD@+B`B(&]B:F5C=',N(BDI.PH*9G5N8W1I;VX@8VAE8VLH)')E<W5L
M="D*>PH@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@('9A<E]D=6UP*"1R97-U;'0I.PH@("`@("`@(&5X:70["B`@("!]
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+P``````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`T,3<S-C,P,38`,#$V-S`S`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V-R:7!T<R]S<6PO4D5!1$U%+D]#23@`````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`R,S0S-@`Q,#0Q-S,V,S`Q-@`P,C`R-S$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1DE24U0@3T8@
M04Q,.@I4:&ES(&ES(&YO="!M>2!F:7)S="!D;V-U;65N=&%T:6]N(2!B=70@
M;7D@9FER<W0@:6X@96YG;&ES:"X*1F5E;"!F<F5E('1O(&-O;G1A8W0@;64@
M870@=&]R<W1E;D!F;&%M;6EG97(N;W)G(&EF('EO=2!H879E(`IA;GD@<W5G
M9V5S=&EO;G,@;W(@<')O8FQE;7,@<F5L871E9"!T;R!T:&ES(&1O8W,*"D%L
M;"!I('=I;&P@=W)I=&4@86)O=70@3W)A8VQE('=I=&@@2&]R9&4@:7,@8F%S
M960@;VX@3W)A8VQE(#X](#AI"G1H;W5G:"!I="!S:&]U;&0@=V]R:R!W:71H
M(#EI('1O;RX@"@I)('1H:6YK("AI)VT@<W5R92D@)U5P('1O(&1A=&4G(&%V
M86EL86)L92!D:7-T<FEB=71I;VYS"F%R92!C87!A8FQE('1O(')U;B!/<F%C
M;&4N($D@:&%V92!T97-T960@:70@;VX*4VQA8VMW87)E(#<N,2\X+C`@*#@N
M,2XV*2!A;F0@:&%V92!R=6YN:6YG(&ET(&]N($=E;G1O;R`Q+C(@*#@N,2XW
M+C0I"G=I=&AO=70@86YY(%!R;V)L96US+B!3;VUE(&1I<W1R:6)U=&EO;G,@
M87)E(&-E<G1I9FEE9"!L:6ME(%-U4T4@;W(@"E)E9$AA="X@3VX@1&5B:6%N
M(&ET('-H;W5L9"!A;'-O(')U;BX*"D9U<G1H97)M;W)E(&DG;&P@87-S=6UE
M+"!T:&%T(&YO(")N;W)M86PB('5S97(@:7,@9V]I;F<@=&\@:6YS=&%L;`IO
M<B!I<R!I;B!N965D('1O(&EN<W1A;&P@86X@3W)A8VQE($1"("AO9B!C;W5R
M<V4@=&AE<F4@87)E('-O;64@9G)E86MS(#LI"G-O(&MN;W=L961G92!A8F]U
M="!S971T:6YG('5P(&%N9"!M86EN=&%I;B!A;B!/<F%C;&4*1$(@:7,@:6YD
M:7-P96YS86)L92$@36%Y8F4@=&AI<R!I<R!T:&4@<F5A<V]N('=H>2!N;R!!
M9&UI;@IH87,@979E<B!P;W-T960@86YY(&1O8W,@86)O=70@9V5T=&EN9R!(
M;W)D92!W;W)K('=I=&@@3W)A8VQE"@I.3U1%.B!A;&P@9&]C<R!A<F4@879A
M:6QA8FQE(&9R;VT@=W=W+F]R86-L92YC;VT@9F]R(&9R964@*$%&04E+*0H*
M3F]W(&QE="=S(&)E9VEN.@H*0V%S92`Q*2`*22=L;"!A<W-U;64@=&AA="!Y
M;W4@9&\@;F]T(&AA=F4@86X@:6YS=&%N8V4@<G5N;FEN9R!A;F0@=&AE<F5F
M;W)E"F%R92!A8F]U="!T;R!I;G-T86QL(&$@9G)E<V@@:6YS=&%N8V4@(FAO
M<F1E(B`N"@HM+0EC:&5C:R!A;F0@:68@;F5E9&5D(&-H86YG92!S:&%R960@
M;65M;W)Y('!A<F%M971E<G,*+2T)8W)E871E(&%T(&QE87-T('1H92!D8F$@
M9W)O=7`*+2T)8W)E871E('EO=7(@;W)A8VQE('5S97(L(&YA;64@:70@87,@
M>6]U(&QI:V4*"6UA:V4@<W5R92!Y;W5R(&]R82UU<V5R(&ES(&EN('1H92!G
M<F]U<"!D8F$*+2T)<W4@+2`\>6]U<B!F<F5S:"!O<F%C;&4@=7-E<CX*+2T@
M"7-E="!U<"!A;&P@=&AE(&%P<')O<')I871E(&5N=FER;VYM96YT('9A<FEA
M8FQE<R!F;W(@;W)A8VQE"@ET86ME(&$@8VQO<V4@;&]O:R!A="!T:&4@:6YS
M=&%L;"!H;W=T;R!P<F]V:61E9"!B>2!O<F%C;&4*+2T);6]U;G0@=&AE($-$
M("AI9B!I="!I<R!Y;W5R('-O=7)C92!M961I82D*+2T)<G5N('1H92!S8W)I
M<'0@<G5N26YS=&%L;&5R("T@8F5T=&5R('1O(&AA=F4@6#$Q(&EN<W1A;&QE
M9"`[*0H)071T96YT:6]N.B!)9B!Y;W4@87)E(&%B;W5T('1O(&EN<W1A;&P@
M3W)A8VQE(#EI"@ED;R!.3U0@<G5N('1H92!I;G-T86QL97(@9G)O;2!D:7)E
M8W1L>2!F<F]M('EO=7(@0T0A"@EL:6ME(&-D("]C9')O;2!A;F0@=&AE;B!S
M=&%R="!I="!B>2!T>7!I;F<@+B]R=6Y);G-T86QL97(*"7EO=2!W;VXG="!B
M92!A8FQE('1O('5N;6]U;G0@=&AE($-$(&QA=&5R(&]N(&)U="!Y;W4@:&%V
M92!T;PH)8F5C875S92`Y:2!I<R!A(#-#1"U3970*+2T)9F]L;&]W('1H92!I
M;G-T<G5C=&EO;G,@9VEV96X@8GD@=&AE(&EN<W1A;&QA=&EO;B!P<F]G<F%M
M;0H)870@=&AE('!O:6YT('=H97)E('EO=2!A<F4@87-K960@9F]R(&%N(&EN
M<W1A;&QA=&EO;B!M971H;V0*"6-H;V]S92`B=7-E<BUD969I;F5D(BX@5&AI
M<R!I<W0@97-P96-I86QL>2!615)9($E-4$]25$5.5"!I9B!Y;W4*"6%R92!A
M8F]U="!T;R!I;G-T86QL(#AI('-I;F-E('EO=2!H879E('1O('!A=&-H('1H
M92!I;G-T86QL871I;VX*"4)%1D]212!Y;W4@8W)E871E('EO=7(@9&%T86)A
M<V4A($EF('EO=2!N;W0@8VAO;W-E(")U<V5R+61E9FEN960B"@ET:&4@<')O
M9W)A;2`B9&)A<W-I<W0B('=I;&P@875T;VUA=&EC86QL>2!S=&%R="!A="!T
M:&4@96YD(&]F"@ET:&4@:6YS=&%L;&%T:6]N('!R;V-E<W,@86YD('=I;&P@
M:&%N9R!A;F0O;W(@9F%I;"X*+2T)870@=&AE(&5N9"!O9B!Y;W5R(&EN<W1A
M;&QA=&EO;B!Y;W4@:&%V92!T;R!C;VYF:6=U<F4@>6]U<B!L:7-T96YE<BYO
M<F$L"@ET;G-N86UE<RYO<F$@86YD('EO=7(@<W%L;F5T+F]R82!4:&ES(&ES
M(&%L;"!D;VYE(&)Y('1H90H):6YS=&%L;&%T:6]N('!R;V=R86UM+B`*+2T)
M3F]W.B!I9B!Y;W4@=7-E(#@N,2XW(&=E="!T:&4@<&%T8V@@9VQI8F,M,BXQ
M+C,M<W1U8G,N=&%R+F=Z(&9R;VT@3W)A8VQE+B`*"4ET)W,@870@=&AE('-A
M;64@<&%G92!L:6ME('1H92!D8BUS;W5R8V4N($EN<W1A;&P@87,@9&5S8W)I
M8F5D(&EN(%)%041-12YS='5B"@DH:70G<R!I;B!T:&4@<&%C:V%G92!S;R!F
M:7)S="!U;G1A<B!I="!S;VUE=VAE<F4@96QS92!O<B!U<V4@)VUC)R`I"BTM
M"4YO=R!C<F5A=&4@>6]U<B!D871A8F%S92X@4G5N(")D8F%S<VES="(*"4ET
M)W,@;F]W(&]N('EO=2!T;R!D96-I9&4@:&]W(&)I9R!T:&4@:6YI=&EA;"!T
M86)L97-P86-E<R!A<F4L(&AO=R!M86YY"@EC;VYT<F]L(&9I;&5S('EO=2!L
M:6ME+"!O9B!C;W5R<V4@:&]W(&ET)W,@;F%M92!W:6QL(&)E(&%N9"!W:&%T
M"@EO<'1I;VX@>6]U('!L86X@=&\@=7-E(&QI:V4@26YT97)-961I82X@270G
M<R!9;W5R($1E8VES:6]N("$*"2A"5%<Z('1H92!D969A=6QT<R!W:6QL('=O
M<FL@86YD(&%R92!V97)Y('1I;64@8V]N<W5M:6YG(#LI"@E!="!T:&4@96YD
M(&QE="!T:&4@9&)A<VES="!P<F]G<F%M('-A=F4@=&AE(&-O;F9I9W5R871I
M;VXN(%EO=2!C86X@8VAO;W-E"@EL;V-A=&EO;B!A;F0@;F%M92X@3F]W('EO
M=2!C86X@8VQO<V4@9&)A<W-I<W0N"BTM"6-H86YG92!T;R!T:&4@;&]C871I
M;VX@=VAE<F4@>6]U('-T;W)E9"!T:&4@<V-R:7!T<R!A;F0@=&%K92!A('-H
M;W)T(&QO;VL*"6%T(&QE87-T(&EN=&\@;W)A8VQE<G5N+G-H(&%N9"!O<F%C
M;&5R=6XQ+G-H+B!)9B!A;&P@:7,@3TL@8W)E871E('1H92!D871A8F%S93H*
M"7)U;B`N+V]R86-L97)U;BYS:"X@"@E3:70@8F%C:R!T86ME(&$@8W5P(&]F
M(&-O9F9E92!A;F0@:&]P92!A;&P@=VEL;"!B92!G;V]D(#LI"@H)268@>6]U
M(&-H;V]S960@=&AE($EN=&5R365D:6$@;W!T:6]N('1H92!C<F5A=&EO;B!P
M<F]C97-S('=I;&P@=&%K90H)86)O=70@,B!A;F0@82!H86QF(&AO=7(@*&]N
M(&UY(#4P,$U(>BU0,R`Z+2DN(%=I=&AO=70@2F%V82!I="!W:6QL('1A:V4*
M"6%B;W5T(#$@:&]U<BX@*'1H:7,@8F]T:"!I<W0@<VAO<G0@+2`Y:2!T86ME
M<R!A<R!M:6XN('1W:6-E('1H870@=&EM92`A*0H)"@E.3U1%.B!C:&]O<VEN
M9R!);G1E<DUE9&EA('=I;&P@9VEV92!Y;W4@96YH86YC960@<&]S<VEB:6QI
M=&EE<R!F;W(@<W1O<FEN9PH)86YD(&UA;FEP=6QA=&EN9R!M961I82!F:6QE
M<RX@3&]O:R!A="!H='1P.B\O:6YT97)M961I82YA<RUD871A<V5R=FEC92YD
M92\*"69O<B!A;B!E>&%M<&QE+BXN"@D*"4%.3U1(15(@3D]413H@:68@>6]U
M(&EN<W1A;&QE9"`X+C$N-R!A;F0@869T97)W87)D<R!A<'!L:65D(&%N('5P
M('1O(&1A=&4*"7!A=&-H<V5T("AL:6ME(#@N,2XW+C0I('EO=2!-55-4(')E
M<&%T8V@@>6]U<B!I;G-T86QL871I;VX@=VET:"!T:&4@"@EG;&EB8RUS='5B
M<R!P871C:"!O<B!Y;W5R($1"('=O;B=T(')U;@H)"@E04D]"3$5-4R`_.B!,
M;V]K(&%T('=W=RYO<F%F87$N8V]M(&9O<B!Y;W5R(&%N<W=E<@H*06QL('=E
M;G0@9FEN93\@1V]O9"P@;&5T<R!G;R!A:&5A9"!A;F0@8W)E871E(&$@;F5W
M('1A8FQE<W!A8V4@8V%L;&5D(&AO<F1E"@HM+0E4:&4@9&%T86)A<V4@<VAO
M=6QD(')U;B!A9G1E<B!I="!W87,@<W5C8V5S9G5L;'D@8W)E871E9"X@3&]G
M:6X@87,@=7-E<B!S>7-T96T*"6]R('-Y<R`H;&EK92!Y;W4@<')E9F5R*2X@
M5&AE('!A<W-W;W)D<R!W:&5R92!W<FET=&5N('1O('EO=2!O;B!35$1/550N
M"@E0;&5A<V4@8VAA;F=E('1H96TA($D@:VYO=R!D871A8F%S97,@<G5N;FEN
M9R!F;W(@>65A<G,@<W1O<FEN9R!I;7!O<G1A;G0@9&%T80H)86YD('-T:6QL
M(&AA=F4@=&AE(&1E9F%U;'0@<&%S<W=O<F0@(2$*"2AM86YA9V5R(&9O<B!S
M>7-T96T@86YD(&-H86YG95]O;E]I;G-T86QL(&9O<B!S>7,I"@HM+0ES<6QP
M;'5S('-Y<R]C:&%N9V5?;VY?:6YS=&%L;$`\>6]U<B!3240^"@EI9B!Y;W4@
M<')O<&5R;'D@<V5T('1H92!/4D%#3$5?4TE$(&5N=FER;VYM96YT('9A<FEA
M8FQE('EO=2!C86X@;VUM:70@=&AE"@ET<F%I;&EN9R!`/'EO=7(@<VED/B!W
M:&5N('EO=2!A<F4@;&]G9V5D(&]N('1O('1H92!M86-H:6YE('=H:6-H(&ES
M(')U;FYI;F<@=&AE($1"+@H*+2T)8W)E871E('1H92!T86)L97-P86-E(&9O
M<B!H;W)D90H)<W%L/B!#4D5!5$4@5$%"3$534$%#12!(3U)$10H@("`@("`@
M("`@("`@($Q/1T=)3D<*("`@("`@("`@("`@("!$051!1DE,12`G/%E/55(@
M4$%42"!(15)%/B](3U)$12YD8F8G(%-)6D4@/$%3(%E/52!,24M%/DT["@H)
M5&AI<R!I<R!I;F1E960@=F5R>2!S:6UP;&4@8G5T(&ET('=O<FMS(&%N9"!N
M;W1H:6YG(&AA<R!T;R!B92!I;B!U<'!E<F-A<V4*"6QE='1E<G,N($%F=&5R
M(&$@9F5W('-E8V]N9',@;W(@;6EN=71E<R`M(&1E<&5N9',@;VX@:&]W(&UA
M;GD@;65G86)Y=&5S"@EY;W4@9V%V92!T;R!T:&%T('1A8FQE<W!A8V4@+2!A
M(&YE=R!D871A9FEL92!H87,@8F5E;B!C<F5A=&5D+@H*+2T)5V4@8V%N(&YO
M=R!C<F5A=&4@82!U<V5R('=I=&@@9&5F875L="!T86)L97-P86-E($A/4D1%
M+"!L971S(&YA;64@:&EM(&AO<F1E.@H*"4-214%412!54T52($A/4D1%(%!2
M3T9)3$4@1$5&055,5"!)1$5.5$E&245$($)9(#QY;W5R('!A<W-W;W)D(&AE
M<F4^(`H@("`@("`@(%1!0DQ%4U!!0T4@2$]21$4@5$5-4$]205)9(%1!0DQ%
M4U!!0T4@5$5-4"!154]402!53DQ)34E4140@3TX@5$5-4`H)455/5$$@54Y,
M24U)5$5$($].($A/4D1%($%#0T]53E0@54Y,3T-+.PH)1U)!3E0@0T].3D5#
M5"!43R!(3U)$13L*"BTM"6-O;6UI="!Y;W5R('=O<FLZ(#X@8V]M;6ET.PH)
M86YD(&QO9R!O=70*+2T);&]G:6X@87,@=7-E<B!H;W)D93H@<W%L<&QU<R!H
M;W)D92\\<&%S<W=O<F0^0#QY;W5R('-I9#X@86YD(&-R96%T92!T:&4@=&%B
M;&5S"@DA/'!A=&@@=&\@:&]R9&4^+W-C<FEP=',O9&(O;W)A8VQE7V-R96%T
M92YS<6P@86YD(&-O;6UI="!Y;W5R(&%K=&EO;CH@/B!C;VUM:70["@ET:&4@
M=&%B;&5S('=I;&P@8F4@8W)E871E9"!I;B!T:&4@9&5F875L="!T86)L97-P
M86-E(&9O<B!Y;W5R(&AO<F1E('5S97(*"0I/2R!N;W<@>6]U(&-A;B!C;VYF
M:6=U<F4@2&]R9&4@=&\@=7-E('EO=7(@:6YS=&%N8V4@8G5T(&%F=&5R(&$@
M<F5B;V]T($]R86-L90IW:6QL(&YO="!S=&%R="!A=71O;6%T:6-L>2X@5&AA
M="!I<R!W:&%T('=E(&%R92!G;VEN9R!T;R!C;VYF:6=U<F4@;F]W+@H*+2T)
M;&]G;W5T(&]F(&]R86-L92P@;&]G:6X@87,@=7-E<B!S>7,@;W(@/'EO=7(@
M;W)A8VQE('5S97(^(`H)86YD('-H=71D;W=N('EO=7(@:6YS=&%N8V4Z("AH
M;W!E('EO=7(@;W)A8VQE('5S97(@:7,@:6X@=&AE(&=R;W5P(&1B82`M"@EI
M9B!N;W0@:&4@8V%N)W0@<VAU="!D;W=N('EO=7(@:6YS=&%N8V4I"@D^(&-O
M;FYE8W0@:6YT97)N86P*"3X@<VAU=&1O=VX@:6UM961I871E"@EA;F0@;&]G
M;W5T+BXN"@D*+2T)=&5S="!T:&4@<V-R:7!T(")D8G-T87)T(B!I;B`D3U)!
M0TQ%7TA/344O8FEN($EF('1H92!$0B!D;V5S(&YO="!S=&%R=`H)>6]U(&AA
M=F4@=&\@961I="!I="!O<B!C<F5A=&4@82!L:6YK(&9R;VT@)$]204-,15](
M3TU%+V1B<R]I;FET/'-I9"UN86UE/BYO<F$*"71O("1/4D%#3$5?2$]-12]A
M9&UI;B\\<VED(&YA;64^+W!F:6QE+VEN:70\<VED+6YA;64^+F]R80H)*"!D
M8G-T87)T('=I;&P@;&]O:R!F;W(@>6]U<B!S:60M9FEL97,@:6X@<W5B9&ER
M(")D8G,B(&)U="!T:&5S92!A<F4@<W1O<F5D"@EU;F1E<B`D3U)!0TQ%7TA/
M344O861M:6XO/'-I9"!N86UE/B]P9FEL92\@+2!T:&ES(&UA>6)E(&ES(&$@
M8G5G(&]R(&$*"69E871U<F4@:6X@=&AE(&]R86-L92!I;G-T86QL97(@*0H)
M=&5S="`B9&)S=&%R="(@86=A:6X@+2!N;W<@:70@<VAO=6QD('=O<FLL(&D@
M:&]P90H*+2T)961I="!T:&4@9FEL92`O971C+V]R871A8@H)0VAA;F=E('1H
M92!L:6YE"@D\<VED+6YA;64^.CQY;W5R($]R86-L92!(;VUE("T@1G5L;"!Q
M=6%L:69I960@<&%T:#XZ3B`@('1O"@D\<VED+6YA;64^.CQY;W5R($]R86-L
M92!(;VUE("T@1G5L;"!Q=6%L:69I960@<&%T:#XZ60H*+2T);F]W(&-H86YG
M92!O<B!C<F5A=&4@82!S=&%R='5P('-C<FEP="!W:&EC:"!I<R!E>&5C=71E
M9"!A="!B;V]T('1I;64N($ET('-H;W5L9"!C;VYT86EN"@ES;VUE=&AI;F<@
M;&EK92!T:&ES.@H)"@ES=2`M(#QY;W5R(&]R86-L92!U<V5R/B`M8R`B/&AO
M=7(@<&%T:"!H97)E/B]B:6XO;'-N<F-T;"!S=&%R="(*"7-U("T@/'EO=7(@
M;W)A8VQE('5S97(^("UC("(\>6]U<B!P871H(&AE<F4^+V)I;B]D8G-T87)T
M(@H*"6%N9"!O9B!C;W5R<V4@>6]U<B!I;G-T86YC92!S:&]U;&0@8F4@<W1O
M<'!E9"!A(')E9W5L87(@=V%Y+B!0;&%C92!T:&ES"@EI;B!T:&4@87!P<F]P
M<FEA=&4@<V-R:7!T('=H:6-H(&ES(&5X96-U=&5D(&%T('-H=71D;W=N('1I
M;64*"@ES=2`M(#QY;W5R(&]R86-L92!U<V5R/B`M8R`B/&AO=7(@<&%T:"!H
M97)E/B]B:6XO;'-N<F-T;"!S=&]P(@H)<W4@+2`\>6]U<B!O<F%C;&4@=7-E
M<CX@+6,@(CQY;W5R('!A=&@@:&5R93XO8FEN+V1B<VAU="(*"BTM"71E<W0@
M:70*"D5N9"!O9B!#87-E(#$I"@H*0V%S92`R*0H*4')O8FQE;3H@66]U(&AA
M=F4@86X@86QL<F5A9'D@<G5N;FEN9R!O<F%C;&4@9&%T86)A<V4@86YD('=O
M=6QD(&QI:V4*=&\@861D(&$@;F5W(&EN<W1A;F-E+B!3;VQU=&EO;B!I<R!Q
M=6EE="!E87-Y+@I&;W(@;F]W+"!T:&4@;F5W(&1A=&%B87-E)R!N86UE('=I
M;&P@8F4@+2T^(&AO<F1E"@I"969O<F4@:2!S=&%R="!I)VQL(&UA:V4@<V]M
M92!A<W-U;7!T:6]N<SH**%!,14%312!#2$%.1T4@5$A%(%!!5$A.04U%4R!!
M4R!.14-%4U-!4ED@*0H*,2X))$]204-,15](3TU%/2]H;VUE+V]R86-L90HR
M+@DD3U)!0TQ%7T)!4T4@/2`D3U)!0TQ%7TA/344*,RX)66]U<B!E>&ES=&EN
M9R!$871A8F%S92!I<R!I;G-T86QL960@=6YD97(@)$]204-,15](3TU%+V]R
M861A=&$O/'EO=7(@:6YS=&%N8V4@;F%M93X*-"X)66]U<B!E>&ES=&EN9R!4
M<F%C92]$=6UP+W!F:6QE+V)D=6UP+BXN("T@9&ER96-T;W)I97,@87)E(&EN
M<W1A;&QE9"!U;F1E<@H)("1/4D%#3$5?2$]-12]A9&UI;B\\>6]U<B!I;G-T
M86YC92!N86UE/B\*"@E4:&5R969O<F4@>6]U<B!N97<@:&]R9&4@9&%T86)A
M<V4@9FEL97,@=VEL;"!G;R!I;G1O(&%N;W1H97(@9&ER96-T;W)Y.@H))$]2
M04-,15](3TU%+V]R861A=&$O:&]R9&4O"@H)5&AE(%1R86-E+T1U;7`O<&9I
M;&4O8F1U;7`N+BX@+2!D:7)S(&=O('1O.@H))$]204-,15](3TU%+V%D;6EN
M+VAO<F1E+PH*"51H92!I;FET:&]R9&4N;W)A(&9I;&4@:6X@)$]204-,15](
M3TU%+V1B<R!S:&]U;&0@8F4@82!L:6YK('1O.@H))$]204-,15](3TU%+V%D
M;6EN+VAO<F1E+W!F:6QE+VEN:70N;W)A"@I,971S(&)E9VEN.@H*+2T)8W)E
M871E('1H92!D:7)E8W1O<FEE<R!F;W(@>6]U<B!N97<@9&(@*&%S('EO=7(@
M3U)!0TQ%('5S97(I.@H)(SX@;6MD:7(@+7`@)$]204-,15](3TU%+V]R861A
M=&$O:&]R9&4O87)C:&EV90H)(SX@;6MD:7(@+7`@)$]204-,15](3TU%+V%D
M;6EN+VAO<F1E+V%D:&]C(%P*"0D@("`@)$]204-,15](3TU%+V%D;6EN+VAO
M<F1E+V)D=6UP(%P*"0D@("`@)$]204-,15](3TU%+V%D;6EN+VAO<F1E+V-D
M=6UP(%P*"0D@("`@)$]204-,15](3TU%+V%D;6EN+VAO<F1E+V-R96%T92!<
M"@D)("`@("1/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]E>'`@7`H)"2`@("`D
M3U)!0TQ%7TA/344O861M:6XO:&]R9&4O<&9I;&4@7`H)"2`@("`D3U)!0TQ%
M7TA/344O861M:6XO:&]R9&4O=61U;7`*"BTM"6-O<'D@>6]U<B!E>&ES=&EN
M9R!I;FET+F]R82!F:6QE(&9R;VT@)$]204-,15](3TU%+V%D;6EN+SQE>&ES
M=&EN9R!I;G-T86YC93XO<&9I;&4O"@ET;R`D3U)!0TQ%7TA/344O861M:6XO
M:&]R9&4O<&9I;&4O(&%N9"!M86ME('1H92!A<'!R;W!R:6%T92!C:&%N9V5S
M(&EN(&ET"@E#2$%.1T4@050@3$5!4U0@5$A%(%!!5$A.04U%4R`A(2$*"BTM
M"6UA:V4@=&AE(&QI;FL@9G)O;2`D3U)!0TQ%7TA/344O9&)S+VEN:71H;W)D
M92YO<F$@=&\*"21/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]P9FEL92]I;FET
M+F]R80H*"2,^(&QN("US("1/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]P9FEL
M92]I;FET+F]R82`D3U)!0TQ%7TA/344O9&)S+VEN:71H;W)D92YO<F$*"BTM
M"7-E="!/4D%#3$5?4TE$('1O(&AO<F1E"@DC/B!/4D%#3$5?4TE$/6AO<F1E
M"@HM+0EL;V=I;B!A;F0@<W1A<G1U<"!T:&4@:6YS=&%N8V4*"2,^('-Q;'!L
M=7,@+VYO;&]G"@ES<6P^('-T87)T=7`@<&9I;&4]+VAO;64O;W)A8VQE+V%D
M;6EN+VAO<F1E+W!F:6QE+VEN:70N;W)A(&YO;6]U;G0*"BTM"6-R96%T92!T
M:&4@9&%T86)A<V4@9G)O;2!C<F5A=&5?:&]R9&5?9&(N<W%L("T@>6]U('-H
M;W5L9"!O9B!C;W5R<V4@:&%V92!S879E9"!I="!S;VUW:&5R92`[*0H)<W%L
M/B`A+W!A=&@O=&\O8W)E871E7VAO<F1E7V1B+G-Q;`H*"6%S('1E;7!L871E
M(&D@=&]O:R!T:&4@<V-R:7!T(&9R;VT*"6AT='`Z+R]W=W<N861P+6=M8F@N
M8V@O;W)A+V%D;6EN+V-R96%T:6YG9&)M86YU86QL>2YH=&UL(W-A;7!L96-R
M96%T961A=&%B87-E"@EA;F0@;6%D92!S;VUE(&UI;F]R(&-H86YG97,N"@HM
M+0EC<F5A=&4@=&AE(&1A=&$@9&EC=&EO;F%R>2P@971C+@H)<W%L/B`A+VAO
M;64O;W)A8VQE+W)D8FUS+V%D;6EN+V-A=&%L;V<N<W%L"@ES<6P^("$O:&]M
M92]O<F%C;&4O<F1B;7,O861M:6XO8V%T<')O8RYS<6P*"7-Q;#X@(2]H;VUE
M+V]R86-L92]R9&)M<R]A9&UI;B]C871H<RYS<6P*"7-Q;#X@8V]M;6ET.PH)
M<W%L/B!E>&ET"@HM+0EN;W<@861D(&$@;F5W(&QI;F4@=&\@+V5T8R]O<F%T
M86(*"@EO;&0@*"!O;FQY(#$@:6YS=&%N8V4@*3H*"3QY;W5R(&EN<W1A;&QE
M9"!I;G-T86YC92!N86UE/CHO:&]M92]O<F%C;&4Z60H*"6YE=R`H('=I=&@@
M=&AE(&YE=R!O;F4@*3H*"3QY;W5R(&EN<W1A;&QE9"!I;G-T86YC92!N86UE
M/CHO:&]M92]O<F%C;&4Z60H):&]R9&4Z+VAO;64O;W)A8VQE.ED*"BTM"6%D
M9"!T:&4@;F5W(&EN<W1A;F-E('1O('EO=7(@=&YS;F%M97,N;W)A"@EU<V4@
M=&AE(&IA=F$@9W5I(&YE=#AA<W-I<W0@;W(@8V]P>2!A;F0@<&%S=&4@=&AE
M('-T871E;65N=',@8GD@>6]U<G-E;&8@86YD"@EM86ME('1H92!C:&%N9V5S
M(&%S(&YE961E9`H*+2T)869T97(@86QL+"!T:&4@<V-R:7!T<R!D8G-T87)T
M('5N9"!D8G-H=70@=VEL;"!T:&5N(&%U=&]M871I8VQY('-T87)T(&%N9"!S
M:'5T9&]W;B!A;&P*"6EN<W1A;F-E<R!A="!O;F-E"@I#<F5A=&EN9R!T:&4@
M5&%B;&5S<&%C92!A;F0@<F5Q=6ER960@=7-E<B!I<R!T:&4@<V%M92!A<R`@
M9&5S8W)I8F5D(&%B;W9E"@H*22!H;W!E('1H870@=&AE<F4@87)E(&YO="!S
M;R!M86YY('-P96QL:6YG(&UI<W1A:V5S("@@;7D@;F%T:79E(&QA;F=U86=E
M(&ES(&=E<FUA;B`I(`IA;F0@=&AA="!T:&ES('=I;&P@8F4@:&5L<&9U;&P@
M9F]R('-O;65O;F4*"D5N9"!O9B!#87-E(#(I"@HD2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O<W%L+U)%041-12Y/0TDX+'8@,2XR(#(P,#0O,#DO,C4@,3DZ-38Z
M,3(@8VAU8VL@17AP("0*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO4D5!1$U%````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,C4U,P`Q,#0Q-S,V,S`Q-@`P,3<U-C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*($AO<F1E($1A=&%B87-E($EN<W1A
M;&QA=&EO;B!'=6ED90H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`U+S$P+S$X(#$Q.C,T
M.C`P("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XR+C$P+C,@)`HZ
M0V]N=&%C=#H@("`@("`@:&]R9&5`;&ES=',N:&]R9&4N;W)G"@H*4'5R<&]S
M92!O9B!T:&ES(&9I;&4*?GY^?GY^?GY^?GY^?GY^?GY^?GX*"E1H:7,@9FEL
M92!W:6QL(&AO<&5F=6QL>2!E87-E('1H92!I;G-T86QL871I;VX@86YD(&-O
M;F9I9W5R871I;VX@;V8@>6]U<@ID871A8F%S92!F;W(@=7-E('=I=&@@2&]R
M9&4N("!4:&4@<V-O<&4@;V8@=&AE(&1O8W5M96YT(&1E86QS('!R:6UA<FEL
M>2!W:71H"G5S:6YG('EO=7(@9&%T86)A<V4@=VET:"!(;W)D92!A;F0@<VAO
M=6QD(&YO="!B92!C;VYS:61E<F5D(&$@<F5S;W5R8V4@9F]R"F=E;F5R86P@
M9&%T86)A<V4@=&%S:W,N"@H*4F5Q=6ER96UE;G1S(&9O<B!(;W)D90I^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^"@I(;W)D92!C=7)R96YT;'D@<W5P<&]R=',@
M870@;&5A<W0@-R!D871A8F%S97,Z"@H@("`@+2!->5-13"`@("`@("`@(&AT
M='`Z+R]W=W<N;7ES<6PN8V]M+PH@("`@+2!0;W-T9W)E4U%,("`@(&AT='`Z
M+R]W=W<N<&]S=&=R97-Q;"YO<F<O"B`@("`M($]R86-L92`@("`@("`@:'1T
M<#HO+W=W=RYO<F%C;&4N8V]M+PH@("`@+2!3>6)A<V4@("`@("`@(&AT='`Z
M+R]W=W<N<WEB87-E+F-O;2\*("`@("T@4U%,:71E("`@("`@("!H='1P.B\O
M=W=W+G-Q;&ET92YO<F<O"B`@("`M($U3(%-13"`@("`@("`@:'1T<#HO+W=W
M=RYM:6-R;W-O9G0N8V]M+W-Q;"\*("`@("T@35-$12`@("`@("`@("!H='1P
M.B\O=W=W+FUI8W)O<V]F="YC;VTO<W%L+VUS9&4O"@I->5-13"!A;F0@4&]S
M=&=R95-13"!A<F4@<F5G=6QA<FQY('5S960@8GD@=&AE(&1E=F5L;W!M96YT
M('1E86TL(&%N9"!W:6QL('=O<FL*=VET:"!N;R!P<F]B;&5M<RX@($]R86-L
M92!A;F0@4U%,:71E('-U<'!O<G0@:&%S(&)E96X@;75C:"!I;7!R;W9E9"!R
M96-E;G1L>0IA;F0@=V]R:W,@9FEN92!T;V\N("!3>6)A<V4@=V5R92!R97!O
M<G1E9"!W;W)K:6YG(&EN('1H92!P<F5V:6]U<R!V97)S:6]N(&]F"DAO<F1E
M+TE-4"!B>2!S;VUE(&]F(&]U<B!U<V5R<RP@86YD(&%R92!A<W-U;65D('1O
M('-T:6QL('=O<FLN+BX@8G5T('1H870*:&%S;B=T(&)E96X@=F5R:69I960@
M<F5C96YT;'DN"@H*0F5F;W)E(%EO=2!"96=I;@I^?GY^?GY^?GY^?GY^?GY^
M"@I9;W4@=VEL;"!N965D('1O(&AA=F4@>6]U<B!D871A8F%S92!P<F5C;VYF
M:6=U<F5D(&%N9"!W;W)K:6YG(&]N('EO=7(@<WES=&5M"F)E9F]R92!Y;W4@
M979E;B!G970@=&\@=&AI<R!S=&%G92X@($9O<B!H96QP('=I=&@@=&AI<RP@
M<&QE87-E(&-O;G-U;'0@>6]U<@ID871A8F%S92!S<&5C:69I8R!H96QP(&9I
M;&5S+@H*0F5F;W)E('5S:6YG(&%N>2!O9B!T:&4@<V-R:7!T<R!L:7-T960@
M8F5L;W<L('!L96%S92!L;V]K(&]V97(@=&AE;2!T;R!E;G-U<F4*=&AA="!A
M;GD@<WES=&5M+7-P96-I9FEC('-E='1I;F=S("AO<B!P97)S;VYA;"!C:&]I
M8V5S*2!A<F4@<V5T('1O('EO=7(*9&5S:7)E9"!S971T:6YG<R`H96<N(&!@
M=7-E<FYA;65@8"P@971C+BDN"@HJ*E!,14%312!.3U1%*BH@=&AA="!T:&4@
M9&%T86)A<V4@8V]N9FEG=7)A=&EO;B!S=&5P<R!L:7-T960@8F5L;W<@*BI-
M55-4*BH*;6%T8V@@=VAA="!I<R!C;VYF:6=U<F5D('=I=&AI;B!(;W)D92X*
M"E-P96-I9FEC86QL>2P@:68@>6]U(&-H86YG92!T:&4@9&%T86)A<V4@;F%M
M92P@=7-E<BP@;W(@<&%S<W=O<F0@=VAI;&4*8V]N9FEG=7)I;F<@=&AE(&1A
M=&%B87-E("AB96QO=RDL('EO=2!W:6QL(&YE960@=&\@;6%K92!T:&4@<V%M
M92!C:&%N9V5S('1O"GEO=7(@2&]R9&4@8V]N9FEG=7)A=&EO;B!F:6QE<R!A
M<R!W96QL+@H*"DUY4U%,"GY^?GY^"@I4:&4@;7ES<6Q?8W)E871E+G-Q;"!S
M8W)I<'0@=VEL;"!C<F5A=&4@82!D871A8F%S92!C86QL960@8&!H;W)D96!@
M+"!A;F0@80IU<V5R(&-A;&QE9"!@8&AO<F1E8&`@*'=I=&@@<&%S<W=O<F0@
M8&!H;W)D96!@*2!T:&%T(&AA<R!F=6QL(')I9VAT<R!T;R!T:&4*9&%T86)A
M<V4N("`J3F]T92!T:&%T('=I=&@@37E344PL(%!%05(@1$(@96UU;&%T97,@
M<V5Q=65N8V5S(&)Y(&%U=&]M871I8V%L;'D*8W)E871I;F<@97AT<F$@=&%B
M;&5S(&5N9&EN9R!I;B!?<V5Q+"!S;R!T:&4@37E344P@8&!H;W)D96!@('5S
M97(@;75S="!H879E"F!@0U)%051%8&`@<')I=FEL96=E(&]N('1H92!@8&AO
M<F1E8&`@9&%T86)A<V4N"@I4:&ES('-C<FEP="!N965D<R!T;R!B92!R=6X@
M87,@=&AE($UY4U%,(')O;W0@=7-E<B`H=VAI8V@@:7,@*DY/5"H@=&AE('-A
M;64@87,*=&AE(%5.25@O3&EN=7@@<F]O="!U<V5R*3HZ"@H@("0@;7ES<6P@
M+2UU<V5R/7)O;W0@+2UP87-S=V]R9#T\37E344PM<F]O="UP87-S=V0^(#P@
M8W)E871E+FUY<W%L+G-Q;`H*069T97(@<G5N;FEN9R!T:&ES('-C<FEP="P@
M:70G<R!A(&=O;V0@:61E82!T;R!R97-T87)T('EO=7(@37E344P@<V5R=F5R
M.CH*"B`@)"!M>7-Q;&%D;6EN("TM=7-E<CUR;V]T("TM<&%S<W=O<F0]/$UY
M4U%,+7)O;W0M<&%S<W=D/B!R96QO860*"E1O(&-H96-K('1H870@=&AI<R!I
M<R!W;W)K:6YG+"!T:&4@9F]L;&]W:6YG(&-O;6UA;F0@<VAO=6QD(&-O;FYE
M8W0@=VET:&]U=`IE<G)O<G,Z.@H*("`D(&UY<W%L("TM=7-E<CUH;W)D92`M
M+7!A<W-W;W)D/6AO<F1E(&AO<F1E"@I4>7!E(&!@<75I=&!@('1O('%U:70@
M37E344PN"@H*4&]S=&=R95-13`I^?GY^?GY^?GY^"@H@(",@<W4@+2!P;W-T
M9W)E<R`@*&]R('=H871E=F5R('EO=7(@9&%T86)A<V4@<G5N<R!A<RXN+B!U
M<W5A;&QY('!O<W1G<F5S*0H@("0@<'-Q;"`M9"!T96UP;&%T93$@+68@8W)E
M871E+G!G<W%L+G-Q;`H*5&AI<R!S8W)I<'0@=VEL;"!C<F5A=&4@82!@8&AO
M<F1E8&`@9&%T86)A<V4@86YD(&$@8&!H;W)D96!@('5S97(N("!9;W4@<VAO
M=6QD"G-E="!A('!A<W-W;W)D(&9O<B!T:&ES('5S97(@=VET:"!T:&ES(&-O
M;6UA;F0@*&EF('EO=2!D:61N)W0@=6YC;VUM96YT('1H90IO;F4@:6X@<&=S
M<6Q?8W)E871E+G-Q;"DZ.@H*("`D('!S<6P@+7%C(")!3%1%4B!54T52(&AO
M<F1E(%=)5$@@4$%34U=/4D0@)W!A<W,G.R(@=&5M<&QA=&4Q('!O<W1G<F5S
M"@I4:&5N(&-R96%T92!T:&4@=&%B;&5S('=I=&AI;B!T:&4@8&!H;W)D96!@
M(&1A=&%B87-E.CH*"B`@)"!P<W%L("UD(&AO<F1E("UF(&AO<F1E7W5S97)S
M+G-Q;`H@("0@<'-Q;"`M9"!H;W)D92`M9B!H;W)D95]P<F5F<RYS<6P*("`D
M('!S<6P@+60@:&]R9&4@+68@:&]R9&5?9&%T871R964N<W%L"@I4:&5S92!S
M8W)I<'1S('=I;&P@86QS;R!G<F%N="!T:&4@8&!H;W)D96!@('5S97(@=&AE
M(&YE8V5S<V%R>2!P<FEV:6QE9V5S('1O"F5A8V@@;V8@=&AE('1A8FQE<RX*
M"@I/<F%C;&4*?GY^?GY^"@I2=6X@8&!S<6QP;'5S8&`N("!,;V=I;BP@=&AE
M;B!;=V4@;F5E9"!I;G-T<G5C=&EO;G,@9F]R(&-R96%T:6YG('1H92!D871A
M8F%S90IA;F0@=7-E<B!H97)E72X*"E1H870@<VAO=6QD(&)E(&ET+B`@4F5S
M=&%R="!/<F%C;&4@:G5S="!T;R!B92!S=7)E+"!A;F0@=')Y(&ET+B`@5&AE
M;B!C<F5A=&4*=&AE('1A8FQE<R!W:71H:6X@=&AE(&!@:&]R9&5@8"!D871A
M8F%S93HZ"@I;06QS;R!N965D('1H;W-E(&EN<W1R=6-T:6]N<R!H97)E+ET*
M"@I3>6)A<V4*?GY^?GY^"@I4;R!C<F5A=&4@=&AE(&1A=&%B87-E+"!F<F]M
M(&!@:7-Q;&!@(')U;CHZ"@H@(&-R96%T92!D871A8F%S92!H;W)D90H*3F5X
M="P@>6]U('-H;W5L9"`H<F5C;VUM96YD960I(&-R96%T92!A(&QO9VEN('1O
M('5S92!W:71H('1H:7,@9&%T86)A<V4N("!4:&4*8&!I<W%L8&`@8V]M;6%N
M9"!F;W(@=&AI<R!I<SHZ"@H@('-P7V%D9&QO9VEN(#QU<V5R;F%M93X@/'!A
M<W-W;W)D/@H*3F5X="!Y;W4@;F5E9"!T;R!C:&%N9V4@=&AE(&]W;F5R<VAI
M<"!O9B!T:&4@9&%T86)A<V4@=&\@=&AI<R!N97<@=7-E<BX@(%1H90I@8&ES
M<6Q@8"!C;VUM86YD(&9O<B!T:&ES(&ES.CH*"B`@<W!?8VAA;F=E9&)O=VYE
M<B`\=7-E<FYA;64^"@I!9G1E<B!T:&%T+"!Y;W4@:G5S="!N965D('1O('-E
M="!U<"!Y;W5R('1A8FQE<R!W:71H:6X@=&AE(&1A=&%B87-E+B`@5&\@9&\*
M=&AA="P@:G5S="!R=6X@=&AI<R!C;VUM86YD(&9R;VT@=&AE(&-O;6UA;F0@
M;&EN93HZ"@H@(&ES<6P@+6D@:&]R9&5?=7-E<G,N<W%L("U5/'5S97)N86UE
M/B`M4#QP87-S=V]R9#X*("!I<W%L("UI(&AO<F1E7W!R969S+G-Q;"`M53QU
M<V5R;F%M93X@+5`\<&%S<W=O<F0^"@H*35-$12`R,#`P("AA;F0@<&]S<VEB
M;'D@35,@4U%,(%-E<G9E<BD*?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GX*"E1O(&-R96%T92!U<V5R(&%N9"!D871A8F%S92P@=7-E
M('1H92!O<W%L(&-O;6UA;F0Z.@H*("!#.EP^;W-Q;"`M52!S82`M4"!A9&UI
M;E]P87-S=V]R9"`M4R!L;V-A;&AO<W0@+6D@8W)E871E+FUS9&4N<W%L"@I"
M92!S=7)E('1O(&-H86YG92!T:&4@<&%S<W=O<F0@9F]R('1H92!H;W)D92!U
M<V5R(&EN('1H92!S8W)I<'0@9FEL92X@(%1O"G-P96-I9GD@82!P87)T:6-U
M;&%R(&EN<W1A;F-E(&]F('1H92!344P@<V5R=F5R('5S92!T:&4*/'-E<G9E
M<FYA;64^+SQI;G-T86YC93X@9F]R('1H92`M4R!F;&%G+B`@268@>6]U(&%R
M96XG="!U<VEN9R!M:7AE9"!344P*875T:&5N=&EC871I;VXL('1H96X@>6]U
M)VQL(&YE960@=&\@;6]D:69Y('1H92!S8W)I<'0@=&\@87-S;V-I871E('1H
M92!H;W)D90IU<V5R('=I=&@@82!W:6YD;W=S('5S97(@86-C;W5N="!A;F0@
M<G5N('1H92!S8W)I<'0@:6X@=&AE(&9O;&QO=VEN9R!M86YN97(@87,*=&AE
M($%D;6EN:7-T<F%T;W(Z.@H*("!#.EP^;W-Q;"`M12`M4R!L;V-A;&AO<W0@
M+6D@8W)E871E+FUS9&4N<W%L"@I)9B!Y;W4G<F4@:&%V:6YG('!R;V)L96US
M(')U;FYI;F<@=&AI<R!S8W)I<'0@;VX@82!344P@<V5R=F5R(&]N('1H92!N
M971W;W)K+`IB92!S=7)E('1H92!S97)V97(@:7,@<V5T('5P('1O(&%L;&]W
M(&YE='=O<FL@86-C97-S+@H*"D%D9&ET:6]N86P@3F]T97,*?GY^?GY^?GY^
M?GY^?GY^?@H*5&AI<R!I<R!B>2!F87(@;F]T(&$@8V]M<&QE=&4@2$]75$\N
M("!4:&ES(&ES(&IU<W0@82!C;VUP:6QE9"!L:7-T(&]F('=H870*<&5O<&QE
M(&AA=F4@8V]N=')I8G5T960@<V\@9F%R+B`@268@>6]U(&AA=F4@=&EP<RP@
M:61E87,L('-U9V=E<W1I;VYS(&]R"F%N>71H:6YG(&5L<V4@=&AA="!Y;W4@
M=&AI;FL@8V]U;&0@:&5L<"!O=&AE<G,@:6X@<V5T=&EN9R!U<"!T:&5I<B!D
M871A8F%S90IF;W(@=7-E('=I=&@@2&]R9&4L('!L96%S92!L970@=7,@:VYO
M=RX*"CQD979`;&ES=',N:&]R9&4N;W)G/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+FUS9&4N
M<W%L````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3$V-@`Q,#0Q
M-S,V,S`Q-@`P,C$V,C,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]C<F5A
M=&4N;7-D92YS<6PL=B`Q+C$N,BXR(#(P,#8O,#,O,C$@,#(Z,#<Z,S`@<V5L
M<VMY($5X<"`D"@I54T4@;6%S=&5R"D=/"@I#4D5!5$4@1$%404)!4T4@:&]R
M9&4*1T\*"D5814,@<W!?861D;&]G:6X@)VAO<F1E)RP@)VAO<F1E7VUG<B<L
M("=H;W)D92<*1T\*"E5312!H;W)D90I'3PH*15A%0R!S<%]G<F%N=&1B86-C
M97-S("=H;W)D92<*1T\*"D-214%412!404),12!H;W)D95]U<V5R<R`H"B`@
M("!U<V5R7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W!A
M<W,@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AU
M<V5R7W5I9"D**0I'3PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@
M1$5,151%($].(&AO<F1E7W5S97)S(%1/(&AO<F1E"D=/"@I#4D5!5$4@5$%"
M3$4@:&]R9&5?<')E9G,@*`H@("`@<')E9E]U:60@5D%20TA!4B@R,#`I($Y/
M5"!.54Q,+`H@("`@<')E9E]S8V]P92!605)#2$%2*#$V*2!.3U0@3E5,3"!$
M149!54Q4("<G+`H@("`@<')E9E]N86UE(%9!4D-(05(H,S(I($Y/5"!.54Q,
M+`H@("`@<')E9E]V86QU92!415A4($Y53$PL"@H@("`@4%))34%262!+15D@
M*'!R969?=6ED+"!P<F5F7W-C;W!E+"!P<F5F7VYA;64I"BD*1T\*"D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]P<F5F
M<R!43R!H;W)D90I'3PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*
M("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@(&=R;W5P7W5I9"!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W5I9"!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!D871A=')E95]N86UE(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A<F5N=',@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@9&%T871R965?;W)D97(@24Y4+`H@("`@9&%T871R965?
M9&%T82!415A4+`H@("`@9&%T871R965?<V5R:6%L:7IE9"!334%,3$E.5"!$
M149!54Q4(#`@3D]4($Y53$PL"B`@("!D871A=')E95]U<&1A=&5D(%1)3453
M5$%-4"P*"B`@("!04DE-05)9($M%62`H9&%T871R965?:60I"BD*1T\*"D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D
M871A=')E92!43R!H;W)D90I'3PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A
M=&%T<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N
M86UE*0I#4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AG<F]U<%]U:60I"D-214%412!)3D1%6"!D871A=')E95]U
M<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I"D-214%412!)
M3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E
M92`H9&%T871R965?<V5R:6%L:7IE9"D*1T\*"D-214%412!404),12!H;W)D
M95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED($E.5"!.
M3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H,C4U*2!.3U0@
M3E5,3"P*("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I($1%1D%53%0@
M)R<@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?=F%L=64@5$585`HI"D=/"@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M9&%T871R964@5$\@:&]R9&4*1T\*"D-214%412!)3D1%6"!D871A=')E95]A
M='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A
M=&%T<F5E7VED*0I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VYA
M;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T
M95]N86UE*0I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VME>5]I
M9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E7VME
M>2D*1T\*"D-214%412!404),12!H;W)D95]T;VME;G,@*`H@("`@=&]K96Y?
M861D<F5S<R!605)#2$%2*#$P,"D@3D]4($Y53$PL"B`@("!T;VME;E]I9"!6
M05)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"!"24=)
M3E0@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*'1O:V5N7V%D9')E<W,L
M('1O:V5N7VED*0HI"D=/"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?=&]K96YS(%1/(&AO<F1E"D=/"@I#4D5!5$4@
M5$%"3$4@:&]R9&5?=F9S("@*("`@('9F<U]I9"!"24=)3E0@3D]4($Y53$PL
M"B`@("!V9G-?='EP92!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"!"24=)3E0@3D]4($Y5
M3$PL"B`@("!V9G-?;W=N97(@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M=F9S7V1A=&$@5$585"P*"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD*
M1T\*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]V9G,@5$\@:&]R9&4*1T\*"D-214%412!)3D1%6"!V9G-?<&%T:%]I
M9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D*0U)%051%($E.1$58('9F<U]N
M86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*0I'3PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N;7ES<6PN<W%L````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,3<S`#$P-#$W,S8S,#$V`#`R,C`S-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+2`D
M2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YM>7-Q;"YS<6PL=B`Q
M+C0N-BXU(#(P,#8O,#,O,C(@,3@Z,S`Z,S0@:F%N($5X<"`D"BTM"BTM($EF
M('EO=2!A<F4@:6YS=&%L;&EN9R!(;W)D92!F;W(@=&AE(&9I<G-T('1I;64L
M('EO=2!C86X@<VEM<&QY"BTM(&1I<F5C="!T:&ES(&9I;&4@=&\@;7ES<6P@
M87,@4U1$24XZ"BTM"BTM("0@;7ES<6P@+2UU<V5R/7)O;W0@+2UP87-S=V]R
M9#T\37E344PM<F]O="UP87-S=V]R9#X@/"!C<F5A=&4N;7ES<6PN<W%L"BTM
M"BTM($EF('EO=2!A<F4@=7!G<F%D:6YG(&9R;VT@82!P<F5V:6]U<R!V97)S
M:6]N+"!Y;W4@=VEL;"!N965D('1O(&-O;6UE;G0*+2T@;W5T('1H92!T:&4@
M=7-E<B!C<F5A=&EO;B!S=&5P<R!B96QO=RP@87,@=V5L;"!A<R!T:&4@<V-H
M96UA<R!F;W(@86YY"BTM('1A8FQE<R!T:&%T(&%L<F5A9'D@97AI<W0N"BTM
M"BTM($EF('EO=2!C:&]O<V4@=&\@9W)A;G0@<&5R;6ES<VEO;G,@;6%N=6%L
M;'DL(&YO=&4@=&AA="!W:71H($UY4U%,+"!014%2($1""BTM(&5M=6QA=&5S
M('-E<75E;F-E<R!B>2!A=71O;6%T:6-A;&QY(&-R96%T:6YG(&5X=')A('1A
M8FQE<R!E;F1I;F<@:6X@7W-E<2P*+2T@<V\@=&AE($UY4U%,(")H;W)D92(@
M=7-E<B!M=7-T(&AA=F4@0U)%051%('!R:79I;&5G92!O;B!T:&4@(FAO<F1E
M(@HM+2!D871A8F%S92X*+2T*+2T@268@>6]U(&%R92!U<&=R861I;F<@9G)O
M;2!(;W)D92`Q+G@L('1H92!(;W)D92!T86)L97,@>6]U(&AA=F4@9G)O;0HM
M+2!T:&%T('9E<G-I;VX@87)E(&YO(&QO;F=E<B!U<V5D.R!Y;W4@;6%Y('=I
M<V@@=&\@96ET:&5R(&1E;&5T92!T:&]S90HM+2!T86)L97,@;W(@<VEM<&QY
M(')E8W)E871E('1H92!D871A8F%S92!A;F5W+@H*55-%(&UY<W%L.PH*4D50
M3$%#12!)3E1/('5S97(@*&AO<W0L('5S97(L('!A<W-W;W)D*0H@("`@5D%,
M5453("@*("`@("`@("`G;&]C86QH;W-T)RP*("`@("`@("`G:&]R9&4G+`H)
M4$%34U=/4D0H)T!714)-04E,7U!!4U-73U)$0"<I"BD["@I215!,04-%($E.
M5$\@9&(@*&AO<W0L(&1B+"!U<V5R+"!S96QE8W1?<')I=BP@:6YS97)T7W!R
M:78L('5P9&%T95]P<FEV+`H@("`@("`@("`@("`@("`@(&1E;&5T95]P<FEV
M+"!C<F5A=&5?<')I=BP@9')O<%]P<FEV+"!I;F1E>%]P<FEV*0H@("`@5D%,
M5453("@*("`@("`@("`G;&]C86QH;W-T)RP*("`@("`@("`G:&]R9&4G+`H@
M("`@("`@("=H;W)D92<L"B`@("`@("`@)UDG+"`G62<L("=9)RP@)UDG+`H@
M("`@("`@("=9)RP@)UDG+"`G62<**3L*"BTM($UA:V4@<W5R92!T:&%T('!R
M:79I;&EG97,@87)E(')E;&]A9&5D+@I&3%532"!04DE624Q%1T53.PH*+2T@
M37E344P@,RXR,RYX(&%P<&5A<G,@=&\@:&%V92`B0U)%051%($1!5$%"05-%
M($E&($Y/5"!%6$E35%,B(&%N9`HM+2`B0U)%051%(%1!0DQ%($E&($Y/5"!%
M6$E35%,B('=H:6-H('=O=6QD(&)E(&$@;FEC92!W87D@=&\@:&%N9&QE"BTM
M(')E:6YS=&%L;',@9W)A8V5F=6QL>2`H<V]M961A>2DN("!&;W(@;F]W+"!D
M<F]P('1H92!D871A8F%S90HM+2!M86YU86QL>2!T;R!A=F]I9"!#4D5!5$4@
M97)R;W)S+@I#4D5!5$4@1$%404)!4T4@:&]R9&4["@I54T4@:&]R9&4["@I#
M4D5!5$4@5$%"3$4@:&]R9&5?=7-E<G,@*`H@("`@=7-E<E]U:60@("`@("`@
M("`@("`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?
M<&%S<R`@("`@("`@("`@("`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL
M"B`@("!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E("`@24Y4+`H@("`@=7-E
M<E]H87)D7V5X<&ER871I;VY?9&%T92`@($E.5"P*"B`@("!04DE-05)9($M%
M62`H=7-E<E]U:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&5`;&]C86QH;W-T.PH*
M0U)%051%(%1!0DQ%(&AO<F1E7W!R969S("@*("`@('!R969?=6ED("`@("`@
M("!605)#2$%2*#(P,"D@3D]4($Y53$PL"B`@("!P<F5F7W-C;W!E("`@("`@
M5D%20TA!4B@Q-BD@3D]4($Y53$P@1$5&055,5"`G)RP*("`@('!R969?;F%M
M92`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('!R969?=F%L=64@
M("`@("!,3TY'5$585"!.54Q,+`H*("`@(%!224U!4ED@2T59("AP<F5F7W5I
M9"P@<')E9E]S8V]P92P@<')E9E]N86UE*0HI.PH*1U)!3E0@4T5,14-4+"!)
M3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W!R969S(%1/(&AO<F1E
M0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@
M("`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("`@("!G<F]U<%]U
M:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@=7-E<E]U:60@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?;F%M92!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]P87)E;G1S(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7V]R9&5R($E.
M5"P*("`@("`@(&1A=&%T<F5E7V1A=&$@5$585"P*("`@("`@(&1A=&%T<F5E
M7W-E<FEA;&EZ960@4TU!3$Q)3E0@1$5&055,5"`P($Y/5"!.54Q,+`H@("`@
M("`@9&%T871R965?=7!D871E9"!424U%4U1!35`L"@H@("`@("`@4%))34%2
M62!+15D@*&1A=&%T<F5E7VED*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E
M7V1A=&%T<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E
M95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H
M;W)D95]D871A=')E92`H9W)O=7!?=6ED*3L*0U)%051%($E.1$58(&1A=&%T
M<F5E7W5S97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D["D-2
M14%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D
M871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@I#4D5!5$4@5$%"3$4@
M:&]R9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"!)
M3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2!$149!
M54Q4("<G($Y/5"!.54Q,+`H@("`@871T<FEB=71E7W9A;'5E(%1%6%0**3L*
M"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:61X($].(&AO<F1E
M7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T<F5E7VED*3L*0U)%051%($E.
M1$58(&1A=&%T<F5E7V%T=')I8G5T95]N86UE7VED>"!/3B!H;W)D95]D871A
M=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?;F%M92D["D-214%412!)3D1%
M6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED>"!/3B!H;W)D95]D871A=')E
M95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y*3L*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E92!43R!H
M;W)D94!L;V-A;&AO<W0["D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L
M($1%3$5412!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S(%1/(&AO<F1E
M0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]T;VME;G,@*`H@("`@
M=&]K96Y?861D<F5S<R`@("!605)#2$%2*#$P,"D@3D]4($Y53$PL"B`@("!T
M;VME;E]I9"`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@=&]K
M96Y?=&EM97-T86UP("!"24=)3E0@3D]4($Y53$PL"@H@("`@4%))34%262!+
M15D@*'1O:V5N7V%D9')E<W,L('1O:V5N7VED*0HI.PH*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W1O:V5N<R!43R!H
M;W)D94!L;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*("`@
M('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7W1Y<&4@
M("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@("`@("!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@($))1TE.5"!.3U0@
M3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,
M+`H@("`@=F9S7V1A=&$@("`@("!,3TY'0DQ/0BP*"B`@("!04DE-05)9($M%
M62`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P871H7VED>"!/3B!H
M;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58('9F<U]N86UE7VED
M>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=204Y4(%-%3$5#5"P@24Y3
M15)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@5$\@:&]R9&5`;&]C
M86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE<R`H"B`@("!H
M:7-T;W)Y7VED("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&]B:F5C=%]U
M:60@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]A
M8W1I;VX@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?=',@
M("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C("`@("!4
M15A4+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U-2DL"B`@("!H
M:7-T;W)Y7V5X=')A("`@(%1%6%0L"@H@("`@4%))34%262!+15D@*&AI<W1O
M<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X($].
M(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@24Y$
M15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y
M7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D95]H
M:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L
M(%501$%412P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE<R!43R!H;W)D94!L
M;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@
M*`H@("`@<V5S<VEO;E]I9"`@("`@("`@("`@("!605)#2$%2*#,R*2!.3U0@
M3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,
M+`H@("`@<V5S<VEO;E]D871A("`@("`@("`@("!,3TY'0DQ/0BP*"B`@("!0
M4DE-05)9($M%62`H<V5S<VEO;E]I9"D**2!%3D=)3D4@/2!);FYO1$(["@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M<V5S<VEO;FAA;F1L97(@5$\@:&]R9&5`;&]C86QH;W-T.PH*1DQ54T@@4%))
M5DE,14=%4SL*"BTM($1O;F4A"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A
M=&4N;V-I."YS<6P`````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R
M-S8W`#$P-#$W,S8S,#$V`#`R,34T,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!S970@9&]C(&]F9CL*<V5T('-Q;&)L86YK
M;&EN97,@;VX["@HO*BH*("H@3W)A8VQE(%1A8FQE($-R96%T:6]N(%-C<FEP
M=',N"B`J(`H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YO
M8VDX+G-Q;"QV(#$N-"XX+C@@,C`P-2\Q,"\R,"`R,CHU-SHT,B!S96QS:WD@
M17AP("0*("H@"B`J($!A=71H;W(@36EG=65L(%=A<F0@/&UW87)D0&%L=6%R
M+F-O;2YA<CX*("H@"B`J(%1H:7,@<W%L(&-R96%T97,@=&AE($AO<F1E(%-1
M3"!T86)L97,@:6X@86X@3W)A8VQE(#@N>"!D871A8F%S92X@4VAO=6QD"B`J
M('=O<FL@=VET:"!/<F%C;&4@.2YX("AA;F0@3W)A8VQE-R!U<VEN9R!V87)C
M:&%R,BDN"B`J(`H@*B!.;W1E<SH*("H@"B`J("`J($]B=FEO=7-L>2!Y;W4@
M;75S="!H879E($]R86-L92!I;G-T86QL960@;VX@=&AI<R!M86-H:6YE($%.
M1"!Y;W4@;75S=`H@*B`@("!H879E(&-O;7!I;&5D(%!(4"!W:71H($]R86-L
M92`H>6]U(&EN8VQU9&5D("TM=VET:"UO8VDX+6EN<W1A;G0*("H@("`@+2UW
M:71H+6]C:3@@;W(@:6X@=&AE(&)U:6QD(&%R9W5M96YT<R!F;W(@4$A0+"!O
M<B!U;F-O;6UE;G1E9"!T:&4@;V-I.`H@*B`@("!E>'1E;G-I;VX@:6X@<&AP
M+FEN:2DN"B`J(`H@*B`@*B!)9B!Y;W4@9&]N)W0@=7-E('1H92!);G-T86YT
M($-L:65N="P@;6%K92!S=7)E('1H870@=&AE('5S97(@=&AA="!S=&%R=',*
M("H@("`@=7`@07!A8VAE("AU<W5A;&QY(&YO8F]D>2!O<B!W=W<M9&%T82D@
M:&%S('1H92!F;VQL;W=I;F<@96YV:7)O;FUE;G0*("H@("`@=F%R:6%B;&5S
M(&1E9FEN960Z"B`J(`H@*B`@("!E>'!O<G0@3U)!0TQ%7TA/344]+VAO;64O
M;W)A8VQE+T]R84AO;64Q"B`J("`@(&5X<&]R="!/4D%?3DQ3/2]H;VUE+V]R
M86-L92]/<F%(;VUE,2]O8V]M;6]N+VYL<R]A9&UI;B]D871A"B`J("`@(&5X
M<&]R="!/4D%?3DQ3,S,]+VAO;64O;W)A8VQE+T]R84AO;64Q+V]C;VUM;VXO
M;FQS+V%D;6EN+V1A=&$*("H@("`@97AP;W)T($Q$7TQ)0E)!4EE?4$%42#TD
M3U)!0TQ%7TA/344O;&EB.B1,1%],24)205)97U!!5$@*("H@"B`J("`@(%E/
M52!-55-4($-54U1/34E:12!42$5312!604Q515,@5$\@0D4@05!04D]04DE!
M5$4@5$\@64]54B!)3E-404Q,051)3TX*("H@"B`J("`@(%EO=2!C86X@:6YC
M;'5D92!T:&5S92!V87)I86)L97,@:6X@=&AE('5S97(G<R!L;V-A;"`N<')O
M9FEL92!O<B!I;@H@*B`@("`O971C+W!R;V9I;&4L(&5T8RX*("H@"B`J("`J
M($YO(&=R86YT<R!A<F4@;F5C97-S87)Y('-I;F-E('=E(&-O;FYE8W0@87,@
M=&AE(&]W;F5R(&]F('1H92!T86)L97,N($EF"B`J("`@('EO=2!W:7-H('EO
M=2!C86X@861A<'0@=&AE(&-R96%T:6]N(&]F('1A8FQE<R!T;R!I;F-L=61E
M('1A8FQE<W!A8V4@86YD"B`J("`@('-T;W)A9V4@:6YF;W)M871I;VXN(%-I
M;F-E('=E(&EN8VQU9&4@;F]N92!I="!W:6QL('5S92!T:&4@9&5F875L=`H@
M*B`@("!T86)L97-P86-E('9A;'5E<R!F;W(@=&AE('5S97(@8W)E871I;F<@
M=&AE<V4@=&%B;&5S+B!386UE('=I=&@@=&AE"B`J("`@(&EN9&5X97,@*&EN
M('1H96]R>2!T:&5S92!S:&]U;&0@=7-E(&$@9&EF9F5R96YT('1A8FQE<W!A
M8V4I+@H@*B`*("H@("H@5&AE<F4@:7,@;F\@;F5E9"!T;R!S:'5T(&1O=VX@
M86YD('-T87)T('5P('1H92!D871A8F%S92$*("HO"@IR96T@8V]N;B!H;W)D
M92\F:&]R9&5?<&%S<W=O<F1`9&%T86)A<V4*"B\J*@H@*B!4:&ES(&ES('1H
M92!(;W)D92!U<V5R<R!T86)L92P@;F5E9&5D(&]N;'D@:68@>6]U(&%R92!U
M<VEN9R!344P*("H@875T:&5N=&EC871I;VXN("!.;W1E('1H870@<&%S<V]W
M<F1S(&EN('1H:7,@=&%B;&4@;F5E9"!T;R!B92!M9#4M96YC;V1E9"X*("HO
M"@I#4D5!5$4@5$%"3$4@:&]R9&5?=7-E<G,@*`H@("`@=7-E<E]U:60@("`@
M("`@("`@("`@("`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@("!U
M<V5R7W!A<W,@("`@("`@("`@("`@("`@("`@5D%20TA!4C(H,C4U*2!.3U0@
M3E5,3"P*("`@('5S97)?<V]F=%]E>'!I<F%T:6]N7V1A=&4@("!.54U"15(H
M,38I+`H@("`@=7-E<E]H87)D7V5X<&ER871I;VY?9&%T92`@($Y534)%4B@Q
M-BDL"@H@("`@4%))34%262!+15D@*'5S97)?=6ED*0HI.PH*"B\J*@H@*B!4
M:&ES(&ES('1H92!(;W)D92!P<F5F97)E;F-E<R!T86)L92P@:&]L9&EN9R!A
M;&P@;V8@=&AE('5S97(M<W!E8VEF:6,*("H@;W!T:6]N<R!F;W(@979E<GD@
M2&]R9&4@=7-E<BX*("H@"B`J('!R969?=6ED("`@:7,@=&AE('5S97)N86UE
M+@H@*B!P<F5F7W-C;W!E(&ES('1H92!A<'!L:6-A=&EO;B!T:&4@<')E9B!B
M96QO;F=S('1O+@H@*B!P<F5F7VYA;64@(&ES('1H92!N86UE(&]F('1H92!V
M87)I86)L92!T;R!S879E+@H@*B!P<F5F7W9A;'5E(&ES('1H92!V86QU92!S
M879E9"`H8V%N(&)E('9E<GD@;&]N9RDN"B`J(`H@*B!792!U<V4@82!#3$]"
M(&-O;'5M;B!S;R!T:&%T(&QO;F=E<B!C;VQU;6X@=F%L=65S(&%R92!S=7!P
M;W)T960N"B`J(`H@*B!)9B!S=&EL;"!U<VEN9R!/<F%C;&4@-R!T:&ES('-H
M;W5L9"!W;W)K(&)U="!Y;W4@:&%V92!T;R!U<V4*("H@5D%20TA!4C(H,C`P
M,"D@=VAI8V@@:7,@=&AE(&QI;6ET(&EM<&]S960@8GD@<V%I9"!V97)S:6]N
M+@H@*B\*"D-214%412!404),12!H;W)D95]P<F5F<R`H"B`@("!P<F5F7W5I
M9"`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@<')E9E]S8V]P92`@
M5D%20TA!4C(H,38I($Y/5"!.54Q,+`H@("`@<')E9E]N86UE("`@5D%20TA!
M4C(H,S(I($Y/5"!.54Q,+`HM+2`@4V5E(&%B;W9E(&YO=&5S(&]N($-,3T)S
M+@H@("`@<')E9E]V86QU92`@0TQ/0BP*"B`@("!04DE-05)9($M%62`H<')E
M9E]U:60L('!R969?<V-O<&4L('!R969?;F%M92D**3L*"@HO*BH*("H@5&AE
M($1A=&%4<F5E('1A8FQE<R!A<F4@=7-E9"!F;W(@:&]L9&EN9R!H:65R87)C
M:&EC86P@9&%T82!S=6-H(&%S($=R;W5P<RP*("H@4&5R;6ES<VEO;G,L(&%N
M9"!D871A(&9O<B!S;VUE($AO<F1E(&%P<&QI8V%T:6]N<RX*("HO"@I#4D5!
M5$4@5$%"3$4@:&]R9&5?9&%T871R964@*`H@("`@9&%T871R965?:60@("`@
M("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@(&=R;W5P7W5I9"`@("`@
M("`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W5I9"`@
M("`@("`@("`@("!605)#2$%2,B@R-34I+`H@("`@9&%T871R965?;F%M92`@
M("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A
M<F5N=',@("`@(%9!4D-(05(R*#(U-2DL"B`@("!D871A=')E95]O<F1E<B`@
M("`@("!.54U"15(H,38I+`H@("`@9&%T871R965?9&%T82`@("`@("`@0TQ/
M0BP*("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@($Y534)%4B@X*2!$149!54Q4
M(#`@3D]4($Y53$PL"B`@("!D871A=')E95]U<&1A=&5D("`@("!$051%+`H*
M("`@(%!224U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%
M6"!D871A=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E
M92`H9&%T871R965?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U
M<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)
M3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E
M<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?;W)D97)?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AD871A=')E95]O<F1E<BD["D-214%412!)3D1%6"!D
M871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T
M871R965?<V5R:6%L:7IE9"D["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"`@("`@($Y534)%4B@Q
M-BD@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92`@(%9!4D-(05(R*#(U
M-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y("`@(%9!4D-(05(R*#(U
M-2DL"B`@("!A='1R:6)U=&5?=F%L=64@(%9!4D-(05(R*#0P,#`I"BD["@I#
M4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%
M6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?
M871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@H*0U)%051%(%1!0DQ%(&AO
M<F1E7W1O:V5N<R`H"B`@("!T;VME;E]A9&1R97-S("`@(%9!4D-(05(R*#$P
M,"D@3D]4($Y53$PL"B`@("!T;VME;E]I9"`@("`@("`@(%9!4D-(05(R*#,R
M*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"`@3E5-0D52*#$V*2!.
M3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K
M96Y?:60I"BD["@H*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?
M:60@("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@("!V9G-?='EP92`@
M("`@($Y534)%4B@X*2!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@5D%2
M0TA!4C(H,C4U*2P*("`@('9F<U]N86UE("`@("`@5D%20TA!4C(H,C4U*2!.
M3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@3E5-0D52*#$V*2!.3U0@3E5,
M3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4C(H,C4U*2P*("`@('9F<U]D
M871A("`@("`@0DQ/0BP*"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD[
M"@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S
M7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F
M<R`H=F9S7VYA;64I.PH*"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@
M*`H@("`@:&ES=&]R>5]I9"`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@
M("`@;V)J96-T7W5I9"`@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@
M("`@:&ES=&]R>5]A8W1I;VX@("!605)#2$%2,B@S,BD@3D]4($Y53$PL"B`@
M("!H:7-T;W)Y7W1S("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@("!H
M:7-T;W)Y7V1E<V,@("`@($-,3T(L"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!
M4D-(05(R*#(U-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@($-,3T(L"@H@("`@
M4%))34%262!+15D@*&AI<W1O<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES
M=&]R>5]A8W1I;VY?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A
M8W1I;VXI.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?
M:&ES=&]R:65S("AH:7-T;W)Y7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?
M=6ED7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*"D-2
M14%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N
M7VED("`@("`@("`@("`@(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*("`@('-E
M<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO
M;E]D871A("`@("`@("`@("!"3$]"+`H*("`@(%!224U!4ED@2T59("AS97-S
M:6]N7VED*0HI.PH*"F5X:70*````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N<&=S<6PN<W%L````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#4S`#$P-#$W,S8S,#$V`#`R,C`Q
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YP9W-Q;"YS<6PL
M=B`Q+C$N,3`N,2`R,#`V+S`R+S(V(#`T.C4Y.C$Y(&-H=6-K($5X<"`D"BTM
M"BTM(%5N8V]M;65N="!T:&4@04Q415(@;&EN92!B96QO=RP@86YD(&-H86YG
M92!T:&4@<&%S<W=O<F0N("!4:&5N(')U;B!A<SH*+2T*+2T@)"!P<W%L("UD
M('1E;7!L871E,2`M9B!C<F5A=&4N<&=S<6PN<W%L"@I#4D5!5$4@1$%404)!
M4T4@:&]R9&4["@I#4D5!5$4@55-%4B!H;W)D93L*"BTM($%,5$52(%5315(@
M:&]R9&4@5TE42"!005-35T]21"`G<&%S<R<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO8W)E871E+G-Y8F%S92YS<6P`````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-S<P,P`Q,#0Q-S,V,S`Q-@`P,C(Q-C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2T@:&]R9&4@=&%B
M;&5S(&1E9FEN:71I;VYS(#H@<W%L('-C<FEP=`H*+2T@,#$O,C(O,C`P,R`M
M($8N($AE;&QY(#QF<F%N8V]I<RYH96QL>4!W86YA9&]O+F9R/@H*+2T@8V]M
M;6%N9"!L:6YE('-Y;G1A>"`Z("!I<W%L("UI:&]R9&5?<WEB87-E+G-Q;`H*
M+2T@=V%R;FEN9R`Z('5S92!N=F%R8VAA<B!O;FQY(&EF('EO=2!N965D('5N
M:6-O9&4@96YC;V1I;F<@9F]R('-O;64@<W1R:6YG<PH*"@IU<V4@:&]R9&4*
M9V\*"@I$4D]0(%1!0DQ%(&AO<F1E7V1A=&%T<F5E"F=O"@I$4D]0(%1!0DQ%
M(&AO<F1E7W!R969S"F=O"@I$4D]0(%1!0DQ%(&AO<F1E7W5S97)S"F=O"@I$
M4D]0(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R"F=O"@HM+2!$4D]0(%1!
M0DQ%(&AO<F1E7V1A=&%T<F5E7W-E<0HM+2!G;PH*+2T@1%)/4"!404),12!H
M;W)D95]T;VME;G,*+2T@9V\*"BTM($123U`@5$%"3$4@:&]R9&5?=F9S"BTM
M(&=O"@HM+2!$4D]0(%1!0DQ%(&AO<F1E7VUU=F9S"BTM(&=O"@H*0U)%051%
M(%1!0DQ%(&AO<F1E7W5S97)S("@*("!U<V5R7W5I9"!V87)C:&%R*#(U-BD@
M3D]4($Y53$PL"B`@=7-E<E]P87-S('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*
M("!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E(&YU;65R:6,H,3`L,"DL"B`@
M=7-E<E]H87)D7V5X<&ER871I;VY?9&%T92!N=6UE<FEC*#$P+#`I+`H@(%!2
M24U!4ED@2T59("`H=7-E<E]U:60I"BD*9V\*"D-214%412!404),12!H;W)D
M95]D871A=')E92`H"B`@9&%T871R965?:60@;G5M97)I8R@Q,2PP*2!)1$5.
M5$E462!.3U0@3E5,3"P*("!G<F]U<%]U:60@=F%R8VAA<B@R-38I($Y/5"!.
M54Q,+`H@('5S97)?=6ED('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*("!D871A
M=')E95]N86UE('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*("!D871A=')E95]P
M87)E;G1S('9A<F-H87(H,C4V*2!.54Q,+`H@(&1A=&%T<F5E7V1A=&$@=&5X
M="!.54Q,+`H@(&1A=&%T<F5E7W-E<FEA;&EZ960@<VUA;&QI;G0@1$5&055,
M5"`P($Y/5"!.54Q,+`H@(&1A=&%T<F5E7W5P9&%T960@=&EM97-T86UP+`H@
M(%!224U!4ED@2T59("`H9&%T871R965?:60I+`H@($9/4D5)1TX@2T59("AU
M<V5R7W5I9"D*("`@(%)%1D5214Y#15,@:&]R9&5?=7-E<G,H=7-E<E]U:60I
M"B`I"F=O"@I#4D5!5$4@5$%"3$4@:&]R9&5?<')E9G,@*`H@('!R969?=6ED
M('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*("!P<F5F7W-C;W!E('9A<F-H87(H
M,38I($Y/5"!.54Q,+`H@('!R969?;F%M92!V87)C:&%R*#,R*2!.3U0@3E5,
M3"P*("!P<F5F7W9A;'5E('1E>'0@3E5,3"P*("!04DE-05)9($M%62`@*'!R
M969?=6ED+'!R969?<V-O<&4L<')E9E]N86UE*0HI"F=O"@I#4D5!5$4@5$%"
M3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@('-E<W-I;VY?:60@=F%R8VAA
M<B@S,BD@3D]4($Y53$PL"B`@<V5S<VEO;E]L87-T;6]D:69I960@;G5M97)I
M8R@Q,2PP*2!.3U0@3E5,3"P*("!S97-S:6]N7V1A=&$@:6UA9V4@3E5,3"P*
M("!04DE-05)9($M%62`@*'-E<W-I;VY?:60I"BD*9V\*"@HM+2!#4D5!5$4@
M5$%"3$4@:&]R9&5?9&%T871R965?<V5Q("@*+2T@("!I9"!N=6UE<FEC*#$P
M+#`I($E$14Y42519($Y/5"!.54Q,+`HM+2`@(%!224U!4ED@2T59("`H:60I
M"BTM("D*+2T@9V\*"BTM($-214%412!404),12!H;W)D95]T;VME;G,@*`HM
M+2`@('1O:V5N7V%D9')E<W,@=F%R8VAA<B@Q,#`I($Y/5"!.54Q,+`HM+2`@
M('1O:V5N7VED('9A<F-H87(H,S(I($Y/5"!.54Q,+`HM+2`@('1O:V5N7W1I
M;65S=&%M<"!N=6UE<FEC*#(P+#`I($Y/5"!.54Q,+`HM+2`@(%!224U!4ED@
M2T59("`H=&]K96Y?861D<F5S<RQT;VME;E]I9"D*+2T@*0HM+2!G;PH*+2T@
M0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"BTM("`@=F9S7VED(&YU;65R:6,H
M,C`L,"D@3D]4($Y53$PL"BTM("`@=F9S7W1Y<&4@;G5M97)I8R@X+#`I($Y/
M5"!.54Q,+`HM+2`@('9F<U]P871H('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*
M+2T@("!V9G-?;F%M92!N=F%R8VAA<B@R-38I($Y/5"!.54Q,+`HM+2`@('9F
M<U]M;V1I9FEE9"!N=6UE<FEC*#(P+#`I($Y/5"!.54Q,+`HM+2`@('9F<U]O
M=VYE<B!V87)C:&%R*#(U-BD@3D]4($Y53$PL"BTM("`@=F9S7V1A=&$@:6UA
M9V4@3E5,3"P*+2T@("!04DE-05)9($M%62`@*'9F<U]I9"D*+2T@*0HM+2!G
M;PH*+2T@0U)%051%(%1!0DQ%(&AO<F1E7VUU=F9S("@*+2T@("!V9G-?:60@
M(&YU;65R:6,H,C`L,"D@3D]4($Y53$PL"BTM("`@=F9S7W1Y<&4@("`@("!N
M=6UE<FEC*#@L,"D@3D]4($Y53$PL"BTM("`@=F9S7W!A=&@@("`@("!V87)C
M:&%R*#(U-BD@3D]4($Y53$PL"BTM("`@=F9S7VYA;64@("`@("!V87)C:&%R
M*#(U-BD@3D]4($Y53$PL"BTM("`@=F9S7VUO9&EF:65D("!N=6UE<FEC*#@L
M,"D@3D]4($Y53$PL"BTM("`@=F9S7V]W;F5R("`@("!V87)C:&%R*#(U-BD@
M3D]4($Y53$PL"BTM("`@=F9S7W!E<FUS("`@("!S;6%L;&EN="!.3U0@3E5,
M3"P*+2T@("!V9G-?9&%T82`@("`@(&EM86=E($Y53$PL"BTM("`@4%))34%2
M62!+15D@("`H=F9S7VED*0HM+2`@("D*+2T@9V\*"@I#4D5!5$4@24Y$15@@
M9&%T871R965?9&%T871R965?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@
M*&1A=&%T<F5E7VYA;64I"F=O"@I#4D5!5$4@24Y$15@@9&%T871R965?9W)O
M=7!?:61X($].(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U:60I"F=O"@I#4D5!
M5$4@24Y$15@@9&%T871R965?=7-E<E]I9'@@3TX@:&]R9&5?9&%T871R964@
M*'5S97)?=6ED*0IG;PH*0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ
M961?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D
M*0IG;PH*+2T@0U)%051%($E.1$58('9F<U]P871H7VED>"!/3B!H;W)D95]V
M9G,@*'9F<U]P871H*0HM+2!G;PH*+2T@0U)%051%($E.1$58('9F<U]N86UE
M7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*0HM+2!G;PH*+2T@0U)%051%
M($E.1$58('9F<U]P871H7VED>"!/3B!H;W)D95]M=79F<R`H=F9S7W!A=&@I
M"BTM(&=O"@HM+2!#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E
M7VUU=F9S("AV9G-?;F%M92D*+2T@9V\*"@IG<F%N="!S96QE8W0L(&EN<V5R
M="P@9&5L971E+"!U<&1A=&4@;VX@961I=&]R('1O(&AO<F1E"F=O"F=R86YT
M('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W-T('1O(&AO
M<F1E"F=O"F=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O
M;B!D8F%S92!T;R!H;W)D90IG;PIG<F%N="!S96QE8W0L(&EN<V5R="P@9&5L
M971E+"!U<&1A=&4@;VX@<VET92!T;R!H;W)D90IG;PIG<F%N="!S96QE8W0L
M(&EN<V5R="P@9&5L971E+"!U<&1A=&4@;VX@8V]N;F5C=&EO;B!T;R!H;W)D
M90IG;PIG<F%N="!S96QE8W0L(&EN<V5R="P@9&5L971E+"!U<&1A=&4@;VX@
M:&]R9&5?9&%T871R964@=&\@:&]R9&4*9V\*9W)A;G0@<V5L96-T+"!I;G-E
M<G0L(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7W!R969S('1O(&AO<F1E"F=O
M"F=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W)D
M95]S97-S:6]N:&%N9&QE<B!T;R!H;W)D90IG;PH*+2T@9W)A;G0@<V5L96-T
M+"!I;G-E<G0L(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7V1A=&%T<F5E7W-E
M<2!T;R!H;W)D90HM+2!G;PHM+2!G<F%N="!S96QE8W0L(&EN<V5R="P@9&5L
M971E+"!U<&1A=&4@;VX@:&]R9&5?=&]K96YS('1O(&AO<F1E"BTM(&=O"BTM
M(&=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W)D
M95]V9G,@=&\@:&]R9&4*+2T@9V\*+2T@9W)A;G0@<V5L96-T+"!I;G-E<G0L
M(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7VUU=F9S('1O(&AO<F1E"BTM(&=O
M"@H*"BTM(&%D9"!Y;W4@861M:6Y?=7-E<E]U:60@86YD(&%D;6EN7W5S97)?
M<&%S<PH*+2T@:6YS97)T(&EN=&\@:&]R9&5?=7-E<G,@=F%L=65S("@G>6]U
M<E]A9&UI;E]U<V5R7W5I9"<L("=Y;W5R7V%D;6EN7W5S97)?<&%S<U]M9#5?
M96YC<GEP=&5D)RD*+2T@9V\*````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?9&%T871R964N;7-S
M<6PN<W%L```````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8P-P`Q,#0Q-S,V,S`Q
M-@`P,C,U,S8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]D871A
M=')E92YM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#$O,3@@,3DZ-3@Z,S0@
M8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@*`H@("`@
M9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@9W)O=7!?=6ED(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?=6ED(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@(&1A=&%T<F5E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@9&%T871R965?<&%R96YT<R!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!D871A=')E95]O<F1E<B!)3E0L"B`@("!D871A=')E95]D871A
M(%9!4D-(05(H34%8*2P*("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)
M3E0@1$5&055,5"`P($Y/5"!.54Q,+`H@("`@9&%T871R965?=7!D871E9"!4
M24U%4U1!35`L"@H@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED*0HI.PH*
M0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%($E.1$58(&1A
M=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O=7!?=6ED
M*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO<F1E7V1A
M=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]O<F1E
M<E]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7V]R9&5R*3L*0U)%
M051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E7V1A
M=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"!)
M3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2P*("`@
M(&%T=')I8G5T95]V86QU92!605)#2$%2*$U!6"D**3L*"D-214%412!)3D1%
M6"!D871A=')E95]A='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T
M=')I8G5T97,@*&1A=&%T<F5E7VED*3L*0U)%051%($E.1$58(&1A=&%T<F5E
M7V%T=')I8G5T95]N86UE7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U
M=&5S("AA='1R:6)U=&5?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]A
M='1R:6)U=&5?:V5Y7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M("AA='1R:6)U=&5?:V5Y*3L*"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$
M051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@5$\@:&]R9&4["D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A
M=')E95]A='1R:6)U=&5S(%1/(&AO<F1E.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]D871A=')E92YM>7-Q;"YS<6P`````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R-38T`#$P-#$W,S8S,#$V`#`R,S4T-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7V1A=&%T<F5E+FUY<W%L+G-Q;"QV(#$N,2`R
M,#`T+S`Y+S$X(#$W.C(P.C4Y(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?9&%T871R964@*`H@("`@("`@9&%T871R965?:60@24Y4($Y/5"!.
M54Q,+`H@("`@("`@9W)O=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@("`@('5S97)?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@
M(&1A=&%T<F5E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@
M9&%T871R965?<&%R96YT<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@
M("!D871A=')E95]O<F1E<B!)3E0L"B`@("`@("!D871A=')E95]D871A(%1%
M6%0L"B`@("`@("!D871A=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%5
M3%0@,"!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7W5P9&%T960@5$E-15-4
M04U0+`H@("`@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED*0HI.PH*0U)%
M051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T
M<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O=7!?=6ED*3L*
M0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO<F1E7V1A=&%T
M<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]S97)I86QI
M>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE
M9"D["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M"B`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?
M;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y
M(%9!4D-(05(H,C4U*2!$149!54Q4("<G($Y/5"!.54Q,+`H@("`@871T<FEB
M=71E7W9A;'5E(%1%6%0**3L*"D-214%412!)3D1%6"!D871A=')E95]A='1R
M:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T
M<F5E7VED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]N86UE
M7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?
M;F%M92D["D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED
M>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y
M*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]D871A=')E92!43R!H;W)D94!L;V-A;&AO<W0["D=204Y4(%-%3$5#
M5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E95]A
M='1R:6)U=&5S(%1/(&AO<F1E0&QO8V%L:&]S=#L*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7V1A=&%T<F5E+G-Q
M;```````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,P-S$`,3`T,3<S-C,P
M,38`,#(R,S<T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?9&%T
M871R964N<W%L+'8@,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP
M("0*"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@("!D871A=')E
M95]I9"!)3E0@3D]4($Y53$PL"B`@("!G<F]U<%]U:60@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@=7-E<E]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,
M+`H@("`@9&%T871R965?;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@
M("!D871A=')E95]P87)E;G1S(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@
M(&1A=&%T<F5E7V]R9&5R($E.5"P*"BTM(%1H97)E(&ES(&YO('!O<G1A8FQE
M('=A>2!T;R!D;R!T:&ES(&%P<&%R96YT;'DN($EF('EO=7(@9&(@9&]E<VXG
M=`HM+2!A;&QO=R!415A4(&-O;'5M;G,L('1H96X@;6%Y8F4@:70@86QL;W=S
M(&QA<F=E(%9!4D-(05(@8V]L=6UN<RP@<V\*+2T@=')Y('1H92!S96-O;F0@
M;&EN92X*+2T*("`@(&1A=&%T<F5E7V1A=&$@5$585"P*+2T@(&1A=&%T<F5E
M7V1A=&$@5D%20TA!4B@T,#DV*2P*"B`@("!D871A=')E95]S97)I86QI>F5D
M(%--04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W5P
M9&%T960@5$E-15-404U0+`H*("`@(%!224U!4ED@2T59("AD871A=')E95]I
M9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D871A=')E95]N86UE7VED
M>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;F%M92D["D-214%412!)
M3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R
M;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H
M;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R
M965?;W)D97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]O<F1E
M<BD["D-214%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H
M;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@H*0U)%051%
M(%1!0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R
M965?:60@24Y4($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!
M4B@R-34I($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U
M-2DL"B`@("!A='1R:6)U=&5?=F%L=64@5$585`HI.PH*0U)%051%($E.1$58
M(&1A=&%T<F5E7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T
M<FEB=71E<R`H9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?
M871T<FEB=71E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T
M97,@*&%T=')I8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T
M=')I8G5T95]K97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@
M*&%T=')I8G5T95]K97DI.PH*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!
M5$4L($1%3$5412!/3B!H;W)D95]D871A=')E92!43R!H;W)D93L*1U)!3E0@
M4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T
M<F5E7V%T=')I8G5T97,@5$\@:&]R9&4["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]H:7-T;W)I97,N;7-S<6PN
M<W%L`````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C8R`#$P-#$W,S8S,#$V`#`R
M,S<U,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VAI<W1O<FEE
M<RYM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#$O,3@@,3DZ-3@Z-#(@8F5N
M($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@(&AI
M<W1O<GE?:60@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I
M9"`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C
M=&EO;B`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@
M("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@(%9!
M4D-(05(H34%8*2P*("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4B@R-34I
M+`H@("`@:&ES=&]R>5]E>'1R82`@("!605)#2$%2*$U!6"DL"BTM"B`@("!0
M4DE-05)9($M%62`H:&ES=&]R>5]I9"D**3L*"D-214%412!)3D1%6"!H:7-T
M;W)Y7V%C=&EO;E]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C
M=&EO;BD["D-214%412!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H
M:7-T;W)I97,@*&AI<W1O<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U
M:61?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D["@I'4D%.
M5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?:&ES
M=&]R:65S(%1/(&AO<F1E.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]H:7-T;W)I97,N
M<W%L````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C,T`#$P-#$W,S8S
M,#$V`#`R,C8Q,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VAI
M<W1O<FEE<RYS<6PL=B`Q+C$N,BXQ(#(P,#4O,3`O,3@@,3$Z,S0Z,#`@:F%N
M($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@(&AI
M<W1O<GE?:60@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I
M9"`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C
M=&EO;B`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@
M("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@(%1%
M6%0L"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(H,C4U*2P*("`@(&AI
M<W1O<GE?97AT<F$@("`@5$585"P*+2T*("`@(%!224U!4ED@2T59("AH:7-T
M;W)Y7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED>"!/
M3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%051%($E.
M1$58(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R
M>5]T<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?
M:&ES=&]R:65S("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@5$\@:&]R9&4[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]L;V<N
M;7-S<6PN<W%L````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C4W`#$P
M-#$W,S8S,#$V`#`R,C4S,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7VQO9RYM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#$O,3@@,3DZ-3@Z
M-#@@8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?;&]G("@*("`@(&ED
M("`@("`@("`@($E.5"!.3U0@3E5,3"P*("`@(&QO9W1I;64@("`@(%1)3453
M5$%-4"!.3U0@3E5,3"P*("`@(&ED96YT("`@("`@($-(05(H,38I($Y/5"!.
M54Q,+`H@("`@<')I;W)I='D@("`@24Y4($Y/5"!.54Q,+`H@("`@+2T@1F]R
M($1"<R!T:&%T(&1O;B=T('-U<'!O<G0@=&AE(%9!4D-(05(H34%8*2!F:65L
M9"!T>7!E.@H@("`@+2T@;65S<V%G92`@5D%20TA!4B@R,#0X*2P*("`@(&UE
M<W-A9V4@("`@(%9!4D-(05(H34%8*2P*("`@(%!224U!4ED@2T59("AI9"D*
M*3L*"D=204Y4($E.4T525"!/3B!H;W)D95]L;V<@5$\@:&]R9&4["@``````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;&]G+G-Q;```````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8R-P`Q,#0Q-S,V,S`Q-@`P
M,C$S-S``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]L;V<N<W%L
M+'8@,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*"D-214%4
M12!404),12!H;W)D95]L;V<@*`H@("`@:60@("`@("`@("`@24Y4($Y/5"!.
M54Q,+`H@("`@;&]G=&EM92`@("`@5$E-15-404U0($Y/5"!.54Q,+`H@("`@
M:61E;G0@("`@("`@0TA!4B@Q-BD@3D]4($Y53$PL"B`@("!P<FEO<FET>2`@
M("!)3E0@3D]4($Y53$PL"B`@("`M+2!&;W(@1$)S('1H870@9&]N)W0@<W5P
M<&]R="!T:&4@5$585"!F:65L9"!T>7!E.@H@("`@+2T@;65S<V%G92`@5D%2
M0TA!4B@R,#0X*2P*("`@(&UE<W-A9V4@("`@(%1%6%0L"B`@("!04DE-05)9
M($M%62`H:60I"BD["@I'4D%.5"!)3E-%4E0@3TX@:&]R9&5?;&]G(%1/(&AO
M<F1E.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7VUU=F9S+FUS<W%L+G-Q;```````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$P-34`,3`T,3<S-C,P,38`,#(S,3`Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;75V9G,N;7-S<6PN<W%L+'8@
M,2XQ+C(N,2`R,#`V+S`Q+S$X(#$Y.C4X.C4T(&)E;B!%>'`@)`H*0U)%051%
M(%1!0DQ%(&AO<F1E7VUU=F9S("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4
M($Y/5"!.54Q,+`H@("`@=F9S7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,
M3"P*("`@('9F<U]P871H("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@
M("`@=F9S7VYA;64@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V
M9G-?;6]D:69I960@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@
M("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7W!E<FUS("`@("!3
M34%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@5D%20DE.05)9
M*$U!6"DL"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@
M24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E7VUU=F9S("AV9G-?<&%T:"D[
M"D-214%412!)3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?;75V9G,@*'9F
M<U]N86UE*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VUU=F9S+G-Q;```````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,C4`,3`T,3<S-C,P,38`,#(Q-S0Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"TM
M("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;75V9G,N<W%L+'8@
M,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*"D-214%412!4
M04),12!H;W)D95]M=79F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.
M3U0@3E5,3"P*("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL
M"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@
M('9F<U]N86UE("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S
M7VUO9&EF:65D("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]P97)M<R`@("`@4TU!
M3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?9&%T82`@("`@($Q/3D="3$]"+`HM
M+2!/<BP@;VX@<V]M92!$0DU3('-Y<W1E;7,Z"BTM("!V9G-?9&%T82`@("`@
M($E-04=%+`H@("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%
M($E.1$58('9F<U]P871H7VED>"!/3B!H;W)D95]M=79F<R`H=F9S7W!A=&@I
M.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7VUU=F9S("AV
M9G-?;F%M92D["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W!R969S+G-Q;```````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,3(`,3`T,3<S-C,P,38`
M,#(Q-S(P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<')E9G,N
M<W%L+'8@,2XR(#(P,#0O,#DO,C$@,#,Z,S0Z,#8@8VAU8VL@17AP("0*"D-2
M14%412!404),12!H;W)D95]P<F5F<R`H"B`@("!P<F5F7W5I9"`@("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@<')E9E]S8V]P92`@("`@(%9!
M4D-(05(H,38I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`@("!P<F5F7VYA;64@
M("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!P<F5F7W9A;'5E("`@
M("`@5$585"P*+2T*("`@(%!224U!4ED@2T59("AP<F5F7W5I9"P@<')E9E]S
M8V]P92P@<')E9E]N86UE*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7W!R969S(%1/(&AO<F1E.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S8W)I<'1S+W-Q;"]H;W)D95]U<V5R<RYS<6P`````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-C(R`#$P-#$W,S8S,#$V`#`R,3<T,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+2`D2&]R
M9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W5S97)S+G-Q;"QV(#$N,BXQ
M,"XR(#(P,#4O,3`O,3@@,3$Z,S0Z,#`@:F%N($5X<"`D"@I#4D5!5$4@5$%"
M3$4@:&]R9&5?=7-E<G,@*`H@("`@=7-E<E]U:60@("`@("`@("`@("`@("`@
M("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?<&%S<R`@("`@
M("`@("`@("`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R
M7W-O9G1?97AP:7)A=&EO;E]D871E("`@24Y414=%4BP*("`@('5S97)?:&%R
M9%]E>'!I<F%T:6]N7V1A=&4@("!)3E1%1T52+`HM+0H@("`@4%))34%262!+
M15D@*'5S97)?=6ED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7W5S97)S(%1/(&AO<F1E.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S
M<6PO:&]R9&5?<')E9G,N;7-S<6PN<W%L````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#8S,@`Q,#0Q-S,V,S`Q-@`P,C,P-C``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]P<F5F<RYM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P
M,#8O,#$O,3@@,3DZ-3DZ,#(@8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?<')E9G,@*`H@("`@<')E9E]U:60@("`@("`@(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@('!R969?<V-O<&4@("`@("!605)#2$%2*#$V*2!.3U0@
M3E5,3"!$149!54Q4("<G+`H@("`@<')E9E]N86UE("`@("`@(%9!4D-(05(H
M,S(I($Y/5"!.54Q,+`H@("`@<')E9E]V86QU92`@("`@(%9!4D-(05(H34%8
M*2P*+2T*("`@(%!224U!4ED@2T59("AP<F5F7W5I9"P@<')E9E]S8V]P92P@
M<')E9E]N86UE*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@
M1$5,151%($].(&AO<F1E7W!R969S(%1/(&AO<F1E.PH`````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E
M<W-I;VYH86YD;&5R+FUS<W%L+G-Q;```````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-C<`
M,3`T,3<S-C,P,38`,#(T-S<Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?<V5S<VEO;FAA;F1L97(N;7-S<6PN<W%L+'8@,2XQ+C(N,2`R,#`V
M+S`Q+S$X(#$Y.C4Y.C$P(&)E;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E
M7W-E<W-I;VYH86YD;&5R("@*("`@('-E<W-I;VY?:60@("`@("`@("`@("`@
M5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE
M9"`@($E.5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@
M5D%20DE.05)9*$U!6"DL"@H@("`@4%))34%262!+15D@*'-E<W-I;VY?:60I
M"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@
M:&]R9&5?<V5S<VEO;FAA;F1L97(@5$\@:&]R9&4["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE
M<BYM>7-Q;"YS<6P``````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C$S`#$P-#$W,S8S,#$V
M`#`R-#<V-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I
M;VYH86YD;&5R+FUY<W%L+G-Q;"QV(#$N,2XR+C$@,C`P-B\P,R\R,B`Q.#HS
M,#HR,R!J86X@17AP("0*"D-214%412!404),12!H;W)D95]S97-S:6]N:&%N
M9&QE<B`H"B`@("!S97-S:6]N7VED("`@("`@("`@("`@(%9!4D-(05(H,S(I
M($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D:69I960@("!)3E0@3D]4
M($Y53$PL"B`@("!S97-S:6]N7V1A=&$@("`@("`@("`@($Q/3D="3$]"+`H*
M("`@(%!224U!4ED@2T59("AS97-S:6]N7VED*0HI($5.1TE.12`]($EN;F]$
M0CL*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]S97-S:6]N:&%N9&QE<B!43R!H;W)D94!L;V-A;&AO<W0["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N;V-I."YS<6P`
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#4V,``Q,#0Q-S,V,S`Q-@`P,C0T-C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2T@)$AO
M<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYO
M8VDX+G-Q;"QV(#$N,BXQ,"XQ(#(P,#4O,3`O,3@@,3$Z,S0Z,#`@:F%N($5X
M<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@
M<V5S<VEO;E]I9"`@("`@("`@("`@("!605)#2$%2,B@S,BD@3D]4($Y53$PL
M"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*("`@
M('-E<W-I;VY?9&%T82`@("`@("`@("`@0DQ/0BP*+2T*("`@(%!224U!4ED@
M2T59("AS97-S:6]N7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G!G<W%L+G-Q;```````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`U-3$`,3`T,3<S-C,P,38`,#(T-S4Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM("1(;W)D93H@:&]R9&4O
M<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<&=S<6PN<W%L+'8@
M,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*"D-214%412!4
M04),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N7VED("`@
M("`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]L
M87-T;6]D:69I960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S:6]N7V1A=&$@
M("`@("`@("`@(%1%6%0L"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D*
M*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]S97-S:6]N:&%N9&QE<B!43R!H;W)D93L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S
M97-S:6]N:&%N9&QE<BYS87!D8BYS<6P`````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#0V
M`#$P-#$W,S8S,#$V`#`R-#<Q-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7W-E<W-I;VYH86YD;&5R+G-A<&1B+G-Q;"QV(#$N,2`R,#`T+S`Y
M+S$X(#$W.C(P.C4Y(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?
M<V5S<VEO;FAA;F1L97(@*`H@("`@<V5S<VEO;E]I9"`@("`@("`@("`@("!6
M05)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO9&EF:65D
M("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]D871A("`@("`@("`@("!,
M3TY'($)95$4L"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D**0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L
M97(N<W%L```````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8U,``Q,#0Q-S,V,S`Q
M-@`P,C,V,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S
M:6]N:&%N9&QE<BYS<6PL=B`Q+C$@,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C
M:R!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*
M("`@('-E<W-I;VY?:60@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y5
M3$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*
M("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@3$].1T),3T(L"BTM($]R+"!O
M;B!S;VUE($1"35,@<WES=&5M<SH*+2T@('-E<W-I;VY?9&%T82`@("`@("`@
M("`@24U!1T4L"@H@("`@4%))34%262!+15D@*'-E<W-I;VY?:60I"BD["@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M<V5S<VEO;FAA;F1L97(@5$\@:&]R9&4["@``````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7W1O:V5N<RYS<6P`````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`U-#$`,3`T,3<S-C,P,38`,#(R,3`U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM("1(
M;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=&]K96YS+G-Q;"QV(#$N
M,BXQ,"XR(#(P,#4O,3`O,3@@,3$Z,S0Z,#`@:F%N($5X<"`D"@I#4D5!5$4@
M5$%"3$4@:&]R9&5?=&]K96YS("@*("`@('1O:V5N7V%D9')E<W,@("`@5D%2
M0TA!4B@Q,#`I($Y/5"!.54Q,+`H@("`@=&]K96Y?:60@("`@("`@("!605)#
M2$%2*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"`@0DE'24Y4
M($Y/5"!.54Q,+`HM+0H@("`@4%))34%262!+15D@*'1O:V5N7V%D9')E<W,L
M('1O:V5N7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@
M1$5,151%($].(&AO<F1E7W1O:V5N<R!43R!H;W)D93L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]V9G,N;7-S<6PN<W%L````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,#<U`#$P-#$W,S8S,#$V`#`R,C4T,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P
M,#8O,#$O,3@@,3DZ-3DZ,38@8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?=F9S("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@
M("`@=F9S7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P
M871H("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@
M($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@=F9S7V1A=&$@("`@("!605)"24Y!4EDH34%8
M*2P*("`@(%!224U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%
M6"!V9G-?<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%4
M12!)3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D[
M"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R
M9&5?=F9S(%1/(&AO<F1E.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]V9G,N;V-I."YS<6P`````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,#4U`#$P-#$W,S8S,#$V`#`R,C(T,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYO8VDX+G-Q;"QV(#$N,R`R
M,#`T+S`Y+S(Q(#`S.C,T.C`V(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?=F9S("@*("`@('9F<U]I9"`@("`@("`@3E5-0D52*#$V*2!.3U0@
M3E5,3"P*("`@('9F<U]T>7!E("`@("`@3E5-0D52*#@I($Y/5"!.54Q,+`H@
M("`@=F9S7W!A=&@@("`@("!605)#2$%2,B@R-34I+`H@("`@=F9S7VYA;64@
M("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D
M("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#
M2$%2,B@R-34I+`H@("`@=F9S7V1A=&$@("`@("!"3$]"+`HM+0H@("`@4%))
M34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P871H
M7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58('9F
M<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=204Y4(%-%
M3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@5$\@
M:&]R9&4["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]V9G,N<&=S<6PN<W%L````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#8R`#$P-#$W,S8S,#$V`#`R,C4R-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+2`D
M2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYP9W-Q;"YS<6PL
M=B`Q+C$@,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@)`H*0U)%051%
M(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.
M3U0@3E5,3"P*("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL
M"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@
M('9F<U]N86UE("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S
M7VUO9&EF:65D("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@5$58
M5"P*"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$
M15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!
M5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I
M.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO
M<F1E7W9F<R!43R!H;W)D93L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]V9G,N<W%L````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,34P`#$P-#$W,S8S,#$V`#`R
M,3,W-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYS<6PL
M=B`Q+C$N,3`N,B`R,#`U+S$P+S$X(#$Q.C,T.C`P(&IA;B!%>'`@)`H*0U)%
M051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.
M5"!.3U0@3E5,3"P*("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y5
M3$PL"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@('9F<U]N86UE("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M=F9S7VUO9&EF:65D("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@
M("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@
M3$].1T),3T(L"BTM($]R+"!O;B!S;VUE($1"35,@<WES=&5M<SH*+2T@('9F
M<U]D871A("`@("`@24U!1T4L"B`@("!04DE-05)9($M%62`@("AV9G-?:60I
M"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H
M=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E
M7W9F<R`H=F9S7VYA;64I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7W9F<R!43R!H;W)D93L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]S8W)I<'0N:6YI=&EA;%]H
M;W)D95]U<V5R+G-Q;```````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3,S`#$P-#$W,S8S
M,#$V`#`R-#4W-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+W-C<FEP="YI
M;FET:6%L7VAO<F1E7W5S97(N<W%L+'8@,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z
M-3D@8VAU8VL@17AP("0*+2T*+2T@5&AI<R!S8W)I<'0@=VEL;"!C<F5A=&4@
M86X@:6YI=&EA;"!U<V5R(&EN(&$@:&]R9&5?=7-E<G,@=&%B;&4N(%1H90HM
M+2!P87-S=V]R9"!B96EN9R!U<V5D(&ES("=A9&UI;B<L('=H:6-H('EO=2!S
M:&]U;&0@8VAA;F=E"BTM($E-345$24%414Q9+@H*24Y315)4($E.5$\@:&]R
M9&5?=7-E<G,@*'5S97)?=6ED+"!U<V5R7W!A<W,I(%9!3%5%4R`H)V%D;6EN
M)RP@)S(Q,C,R9C(Y-V$U-V$U83<T,S@Y-&$P931A.#`Q9F,S)RD["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V-R:7!T<R]L9&%P+P``````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#0Q-S,V,S`Q-@`P,3<P,C0`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+VQD87`O:&]R9&4N<V-H
M96UA````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,T-3`V`#$P
M-#$W,S8S,#$V`#`R,3,Q-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C("1(;W)D93H@:&]R9&4O<V-R:7!T<R]L9&%P+VAO
M<F1E+G-C:&5M82QV(#$N,C`N,3`N-2`R,#`U+S$P+S$X(#$Q.C,T.C`P(&IA
M;B!%>'`@)`HC"B,@5&AE(&]F9FEC86P@:&]R9&4@3TE$(&%S<VEG;F5D(&)Y
M($E!3D$@:7,@,3,P-#`N"B,*(R!4:&ES('-C:&5M82!D97!E;F1S(&]N.@HC
M"2T@8V]R92YS8VAE;6$*(PHC(`HC($AO<F1E(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,BXQ+BH*(R!)35`@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS+C$N*@HC(%1U<F)A(&%T=')I8G5T92!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+BH*(R!+<F]N;VQI=&@@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XU+C$N*@HC($YA9R!A
M='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C8N,2XJ"B,@1V]L
M;&5M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-RXQ+BH*
M(R!#:&]R82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N
M,2XJ"B,@36YE;6\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XY+C$N*@HC(%1R;VQL(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,3`N,2XJ"B,@2VQU='H@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XQ,2XQ+BH*(R!*;VYA:"!A='1R:6)U=&4@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C$R+C$N*@HC($AE<FUE<R!A='1R:6)U=&4@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$S+C$N*@HC($IU;F\@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XQ+BH*(R!4<F5A;B!A='1R
M:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$U+C$N*@HC(%=H=7!S
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,38N,2XJ"B,@
M26YG;R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$W+C$N
M*@HC($%N<V5L(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,3@N,2XJ"B,@1V5N:64@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XQ.2XQ+BH*(R!38W)Y(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,C`N,2XJ"B,@5VEC:V5D(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,C$N,2XJ"B,@06=O<F$@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,BXQ+BH*(R!';V]P<R!A='1R:6)U=&4@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(T+C$N*@HC($UE<FL@871T<FEB
M=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-2XQ+BH*(R!-:6UP(&%T
M=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C8N,2XJ"B,@36]T
M=&QE(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C<N,2XJ
M"B,@3FEC(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C@N
M,2XJ"B,@3V-C86T@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XR.2XQ+BH*(R!/9&EN(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,S`N,2XJ"B,@4F%K:6T@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XS,2XQ+BH*(R!397-H82!A='1R:6)U=&4@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C,R+C$N*@HC(%-W;V]S:"!A='1R:6)U=&4@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,S+C$N*@HC(%1H;W(@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-"XQ+BH*(R!5;&%F;W)M(&%T
M=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N,2XJ"B,@5F]L
M;W,@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-BXQ+BH*
M(R`*(R!(;W)D92!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,BXR+BH*(R!)35`@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C,N,BXJ"B,@5'5R8F$@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C0N,BXJ"B,@2W)O;F]L:71H(&]B:F5C=&-L87-S(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XU+C(N*@HC($Y!1R!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-BXR+BH*(R!';VQL96T@;V)J
M96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C<N,BXJ"B,@0VAO
M<F$@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,BXJ
M"B,@36YE;6\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+CDN,BXJ"B,@5')O;&P@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$P+C(N*@HC($ML=71Z(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XQ,2XR+BH*(R!*;VYA:"!O8FIE8W1C;&%S<R!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3(N,BXJ"B,@2&5R;65S(&]B:F5C=&-L
M87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,RXR+BH*(R!*=6YO(&]B
M:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XR+BH*(R!4
M<F5A;B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,34N
M,BXJ"B,@5VAU<',@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C$V+C(N*@HC($EN9V\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C$W+C(N*@HC($%N<V5L(&]B:F5C=&-L87-S(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XQ."XR+BH*(R!'96YI92!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3DN,BXJ"B,@4V-R>2!O8FIE8W1C
M;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C`N,BXJ"B,@5VEC:V5D
M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,2XR+BH*
M(R!!9V]R82!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,C(N,BXJ"B,@1V]O<',@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(T+C(N*@HC($UE<FL@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C(U+C(N*@HC($UI;7`@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C(V+C(N*@HC($UO='1L92!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C<N,BXJ"B,@3FEC(&]B:F5C
M=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR."XR+BH*(R!/8V-A
M;2!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,CDN,BXJ
M"B,@3V1I;B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,S`N,BXJ"B,@4F%K:6T@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C,Q+C(N*@HC(%-E<VAA(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XS,BXR+BH*(R!3=V]O<V@@;V)J96-T8VQA<W,@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,S+C(N*@HC(%1H;W(@;V)J96-T8VQA
M<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,T+C(N*@HC(%5L869O<FT@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,U+C(N*@HC
M(%9O;&]S(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS
M-BXR+BH*"B,*(R!(;W)D92!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C(N,2XQ"@E.04U%("=H;W)D95!R969S)PH)1$530R`G2&]R9&4@4')E
M9F5R96YC97,G"@E%455!3$E462!C87-E26=N;W)E24$U36%T8V@*"5-93E1!
M6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I"@HC"B,@
M24U0(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,RXQ+BH*
M(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,RXQ+C$*"4Y!
M344@)VEM<%!R969S)PH)1$530R`G24U0(%!R969E<F5N8V5S)PH)15%504Q)
M5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%1U<F)A(&%T=')I8G5T92!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+BH*(PIA='1R:6)U=&5T>7!E
M("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C$*"4Y!344@)W1U<F)A4')E9G,G
M"@E$15-#("=4=7)B82!0<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO
M<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ
M+C(V>S$P,C1]("D*"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XT+C$N,@H)3D%-12`G='5R8F%4>7!E)PH)1$530R`G5'5R8F$@3V)J96-T
M(%1Y<&4Z($-O;G1A8W0O3&ES="<*"45154%,2519(&-A<V5)9VYO<F5)035-
M871C:`H)4U5"4U12(&-A<V5)9VYO<F5)0353=6)S=')I;F=S36%T8V@*"5-9
M3E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLX?2`I"@IA='1R
M:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C,*"4Y!344@)W1U
M<F)A365M8F5R<R<*"41%4T,@)T5N8V]D960@;65M8F5R<R!O9B!A(%1U<F)A
M(&QI<W0G"@E355`@;F%M92`I"@IA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT
M+C$N,3,P-#`N-"XQ+C0*"4Y!344@)W1U<F)A4$=04'5B;&EC2V5Y)PH)1$53
M0R`G4$=0+T=01R!0=6)L:6,@2V5Y)PH@("`@("`@($5154%,2519(&-A<V5)
M9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R
M,2XQ+C(V>S0P,#!]("D*"B,*(R!+<F]N;VQI=&@@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XU+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XU+C$N,0H)3D%-12`G:W)O;F]L:71H4')E9G,G
M"@E$15-#("=+<F]N;VQI=&@@4')E9F5R96YC97,G"@E%455!3$E462!C87-E
M26=N;W)E24$U36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ
M,C$N,2XR-GLQ,#(T?2`I"@HC"B,@3F%G(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N-BXQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N
M,2XT+C$N,3,P-#`N-BXQ+C$*"4Y!344@)VYA9U!R969S)PH)1$530R`G3F%G
M(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC($=O;&QE;2!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C<N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C<N
M,2XQ"@E.04U%("=G;VQL96U0<F5F<R<*"41%4T,@)T=O;&QE;2!0<F5F97)E
M;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N
M,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!#:&]R
M82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,2XJ"B,*
M871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,2XQ"@E.04U%
M("=C:&]R85!R969S)PH)1$530R`G0VAO<F$@4')E9F5R96YC97,G"@E%455!
M3$E462!C87-E26=N;W)E24$U36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ
M-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I"@HC"B,@36YE;6\@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C$N*@HC"F%T=')I8G5T971Y
M<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C$N,0H)3D%-12`G;6YE;6]0<F5F
M<R<*"41%4T,@)TUN96UO(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC(%1R;VQL(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,3`N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C$P+C$N,0H)3D%-12`G=')O;&Q0<F5F<R<*"41%4T,@
M)U1R;VQL(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA
M=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R
M-'T@*0H*(PHC($ML=71Z(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,3$N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C$Q+C$N,0H)3D%-12`G:VQU='I0<F5F<R<*"41%4T,@)TML=71Z(%!R
M969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y4
M05@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC
M($IO;F%H(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3(N
M,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$R+C$N
M,0H)3D%-12`G:F]N86A0<F5F<R<*"41%4T,@)TIO;F%H(%!R969E<F5N8V5S
M)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($AE<FUE<R!A
M='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$S+C$N*@HC"F%T
M=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,RXQ+C$*"4Y!344@
M)VAE<FUE<U!R969S)PH)1$530R`G2&5R;65S(%!R969E<F5N8V5S)PH)15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($IU;F\@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XQ+BH*(PIA='1R:6)U=&5T
M>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,30N,2XQ"@E.04U%("=J=6YO4')E
M9G,G"@E$15-#("=*=6YO(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC(%1R96%N(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,34N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C$U+C$N,0H)3D%-12`G=')E86Y0<F5F<R<*"41%4T,@
M)U1R96%N(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA
M=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R
M-'T@*0H*(PHC(%=H=7!S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,38N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C$V+C$N,0H)3D%-12`G=VAU<'-0<F5F<R<*"41%4T,@)U=H=7!S(%!R
M969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y4
M05@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC
M($EN9V\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-RXQ
M+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,3<N,2XQ
M"B`@("`@("!.04U%("=I;F=O4')E9G,G"B`@("`@("!$15-#("=);F=O(%!R
M969E<F5N8V5S)PH@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H
M"B`@("`@("!364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($%N<V5L(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,3@N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$X+C$N,0H@("`@("`@3D%-12`G86YS96Q0<F5F<R<*("`@("`@
M($1%4T,@)T%N<V5L(%!R969E<F5N8V5S)PH@("`@("`@15%504Q)5%D@8V%S
M94EG;F]R94E!-4UA=&-H"B`@("`@("!364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($=E;FEE(&%T=')I8G5T92!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3DN,2XJ"B,*871T<FEB=71E='EP
M92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$Y+C$N,0H)3D%-12`G9V5N:650<F5F
M<R<*"41%4T,@)T=E;FEE(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC(%-C<GD@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR,"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N
M,2XT+C$N,3,P-#`N,C`N,2XQ"@E.04U%("=S8W)Y4')E9G,G"@E$15-#("=3
M8W)Y(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H
M"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@
M*0H*(PHC(%=I8VME9"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C(Q+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XR,2XQ+C$*"4Y!344@)W=I8VME9%!R969S)PH)1$530R`G5VEC:V5D(%!R
M969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y4
M05@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC
M($%G;W)A(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C(N
M,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C(R+C$N
M,0H@("`@("`@($Y!344@)V%G;W)A4')E9G,G"B`@("`@("`@1$530R`G06=O
M<F$@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($=O;W!S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,C0N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(T+C$N,0H@("`@("`@($Y!344@)V=O;W!S4')E9G,G"B`@("`@
M("`@1$530R`G1V]O<',@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@
M8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ
M,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($UE<FL@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-2XQ+BH*(PIA='1R:6)U=&5T>7!E("@@
M,2XS+C8N,2XT+C$N,3,P-#`N,C4N,2XQ"B`@("`@("`@3D%-12`G;65R:U!R
M969S)PH@("`@("`@($1%4T,@)TUE<FL@4')E9F5R96YC97,G"B`@("`@("`@
M15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT
M+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($UI;7`@871T<FEB
M=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-BXQ+BH*(PIA='1R:6)U
M=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,C8N,2XQ"B`@("`@("`@3D%-
M12`G;6EM<%!R969S)PH@("`@("`@($1%4T,@)TU)35`@4')E9F5R96YC97,G
M"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@
M,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($UO
M='1L92!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(W+C$N
M*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-RXQ+C$*
M("`@("`@("!.04U%("=M;W1T;&50<F5F<R<*("`@("`@("!$15-#("=-;W1T
M;&4@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($YI8R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(X+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XR."XQ+C$*("`@("`@("!.04U%("=N:6-0<F5F<R<*("`@("`@("!$
M15-#("=.24,@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC($]C8V%M(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,CDN,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C(Y+C$N,0H@("`@("`@($Y!344@)V]C8V%M4')E9G,G
M"B`@("`@("`@1$530R`G3V-C86T@4')E9F5R96YC97,G"B`@("`@("`@15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($]D:6X@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,"XQ+BH*(PIA='1R:6)U=&5T
M>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,S`N,2XQ"B`@("`@("`@3D%-12`G
M;V1I;E!R969S)PH@("`@("`@($1%4T,@)T]D:6X@4')E9F5R96YC97,G"B`@
M("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%)A:VEM
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S$N,2XJ"B,*
M871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C$N,0H@("`@
M("`@($Y!344@)W)A:VEM4')E9G,G"B`@("`@("`@1$530R`G4F%K:6T@4')E
M9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H
M"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@
M*0H*(PHC(%-E<VAA(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,S(N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C,R+C$N,0H@("`@("`@($Y!344@)W-E<VAA4')E9G,G"B`@("`@("`@1$53
M0R`G4V5S:&$@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC(%-W;V]S:"!A='1R:6)U=&4@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C,S+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XS,RXQ+C$*("`@("`@("!.04U%("=S=V]O<VA0<F5F
M<R<*("`@("`@("!$15-#("=3=V]O<V@@4')E9F5R96YC97,G"B`@("`@("`@
M15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT
M+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%1H;W(@871T<FEB
M=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-"XQ+BH*(PIA='1R:6)U
M=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,S0N,2XQ"B`@("`@("`@3D%-
M12`G=&AO<E!R969S)PH@("`@("`@($1%4T,@)U1H;W(@4')E9F5R96YC97,G
M"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@
M,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%5L
M869O<FT@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-2XQ
M+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N,2XQ
M"B`@("`@("`@3D%-12`G=6QA9F]R;5!R969S)PH@("`@("`@($1%4T,@)U5L
M869O<FT@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R
M94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N
M,C9[,3`R-'T@*0H*(PHC(%9O;&]S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,S8N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C,V+C$N,0H@("`@("`@($Y!344@)W9O;&]S4')E9G,G"B`@
M("`@("`@1$530R`G5F]L;W,@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)
M5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($AO<F1E(&]B:F5C=&-L87-S
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR+C(N*@HC"F]B:F5C=&-L87-S
M("@@,2XS+C8N,2XT+C$N,3,P-#`N,BXR+C$*("`@($Y!344@)VAO<F1E4&5R
M<V]N)PH@("`@1$530R`G2&]R9&4@4')E9F5R96YC97,G"B`@("!355`@=&]P
M"B`@("!!55A)3$E!4ED*("`@($U!62`H(&UA:6P@)"!H;W)D95!R969S("0@
M:6UP4')E9G,@)"!T=7)B85!R969S("0*("`@("`@("!G;VQL96U0<F5F<R`D
M(&MR;VYO;&ET:%!R969S("0@;6YE;6]0<F5F<R`D"B`@("`@("`@=')O;&Q0
M<F5F<R`D(&YA9U!R969S("0@:VQU='I0<F5F<R`D"B`@("`@("`@:F]N86A0
M<F5F<R`D(&AE<FUE<U!R969S("0@:G5N;U!R969S("0*("`@("`@("!T<F5A
M;E!R969S("0@=VAU<'-0<F5F<R`D(&EN9V]0<F5F<R`D"B`@("`@("`@9V5N
M:650<F5F<R`D('-C<GE0<F5F<R`D(&%N<V5L4')E9G,@)`H@("`@("`@('=I
M8VME9%!R969S("0@8VAO<F%0<F5F<R`D(&%G;W)A4')E9G,@)`H@("`@("`@
M(&=O;W!S4')E9G,@)"!M97)K4')E9G,@)"!V;VQO<U!R969S("0*("`@("`@
M("!M:6UP4')E9G,@)"!M;W1T;&50<F5F<R`D(&YI8U!R969S("0*("`@("`@
M("!O8V-A;5!R969S("0@;V1I;E!R969S("0@<F%K:6U0<F5F<R`D"B`@("`@
M("`@<V5S:&%0<F5F<R`D('-W;V]S:%!R969S("0@=&AO<E!R969S("0*("`@
M("`@("!U;&%F;W)M4')E9G,*("`@("D@*0H*;V)J96-T8VQA<W,@*"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR+C(N,@H@("`@3D%-12`G:&]R9&5'<F]U<"<*("`@
M($1%4T,@)TAO<F1E($=R;W5P)PH@("`@4U50('1O<`H@("`@055824Q)05)9
M"B`@("!-05D@*"!M86EL("D@*0H*(PHC($E-4"!O8FIE8W1C;&%S<R!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,RXR+BH*(PH*(R!4=7)B82!O8FIE8W1C
M;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-"XR+BH*;V)J96-T8VQA
M<W,@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XT+C(N,0H@($Y!344@)W1U<F)A0V]N
M=&%C="<*("!$15-#("=4=7)B82!#;VYT86-T)PH@(%-54"!T;W`*("!!55A)
M3$E!4ED*("!-05D@*"!T=7)B851Y<&4@)"!T=7)B84UE;6)E<G,@*0H@*0H*
M(PHC($MR;VYO;&ET:"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N-2XR+BH*(PH*(PHC($YA9R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N-BXR+BH*(PH*(PHC($=O;&QE;2!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-RXR+BH*(PH*(PHC($-H;W)A
M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XX+C(N*@HC
M"@HC"B,@36YE;6\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+CDN,BXJ"B,*"B,*(R!4<F]L;"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,3`N,BXJ"B,*"B,*(R!+;'5T>B!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3$N,BXJ"B,*"B,*(R!*;VYA
M:"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3(N,BXJ
M"B,*"B,*(R!(97)M97,@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$S+C(N*@HC"@HC"B,@2G5N;R!O8FIE8W1C;&%S<R!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,30N,BXJ"B,*"B,*(R!4<F5A;B!O8FIE8W1C
M;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,34N,BXJ"B,*"B,*(R!7
M:'5P<R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,38N
M,BXJ"B,*"B,*(R!);F=O(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XQ-RXR+BH*(PH*(PHC($%N<V5L(&]B:F5C=&-L87-S(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ."XR+BH*(PH*(PHC($=E;FEE(&]B:F5C
M=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ.2XR+BH*(PH*(PHC
M(%-C<GD@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(P
M+C(N*@HC"@HC"B,@5VEC:V5D(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XR,2XR+BH*(PH*(PHC($%G;W)A(&]B:F5C=&-L87-S(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,BXR+BH*(PH*(PHC($=O;W!S(&]B
M:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-"XR+BH*(PH*
M(PHC($UE<FL@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C(U+C(N*@HC"@HC"B,@36EM<"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,C8N,BXJ"B,*"B,*(R!-;W1T;&4@;V)J96-T8VQA<W,@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(W+C(N*@HC"@HC"B,@3FEC(&]B
M:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR."XR+BH*(PH*
M(PHC($]C8V%M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XR.2XR+BH*(PH*(PHC($]D:6X@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C,P+C(N*@HC"@HC"B,@4F%K:6T@;V)J96-T8VQA<W,@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C(N*@HC"@HC"B,@4V5S:&$@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,R+C(N*@HC
M"@HC"B,@4W=O;W-H(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XS,RXR+BH*(PH*(PHC(%1H;W(@;V)J96-T8VQA<W,@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C,T+C(N*@HC"@HC"B,@56QA9F]R;2!O8FIE8W1C
M;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N,BXJ"B,*"B,*(R!6
M;VQO<R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S8N
M,BXJ"B,*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+V-R;VYD````````````````````````````````````````````````````
M`````````````````````````````#`Q,#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q-C$Q`#$P-#$W,S8S,#$V`#`Q-S$S,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C(2]U<W(O;&]C86PO<'-A
M+V%D;6EN+V)I;B]P:'`*/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]C<F]N9"QV(#$N-"XQ,"XT(#(P,#8O,#$O,#$@,C$Z,CDZ,#D@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0VAA<FQE<R!*+B!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*
M"G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O4V-H961U;&5R+G!H<"<["@HO+R!-86ME('-U<F4@;F\@;VYE(')U
M;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A2&]R9&5?0TQ).CIR=6YN:6YG
M1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M('1H92!C
M;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D('1H92!#3$D@96YV:7)O;FUE
M;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T:6UE(&QI;6ET+"!I;FET"B\O
M('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E7T-,23HZ:6YI="@I.PH*+R\@
M1V5T(&%N(&EN<W1A;F-E(&]F('1H92!C<F]N('-C:&5D=6QE<BX*)&1A96UO
M;B`]("9(;W)D95]38VAE9'5L97(Z.G-I;F=L971O;B@G8W)O;B<I.PH*+R\@
M3F]W(&%D9"!S;VUE(&-R;VX@:F]B<R!T;R!D;RP@;W(@861D('!A<G-I;F<@
M=&\@<F5A9"!A(&-O;F9I9R!F:6QE+@HO+R`D9&%E;6]N+3YA9&1487-K*"=L
M<R<L("<P+#4L,3`L,34L,C`L,S`L-#`@*B`J("H@*B<I.PH*+R\@4W1A<G0@
M=&AE(&1A96UO;B!G;VEN9RX*)&1A96UO;BT^<G5N*"D["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+V=E=%]L;V=I;BYP:'``````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,S<U`#$P-#$W,S8S,#$V`#`R,#4V-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+V=E=%]L;V=I;BYP:'`L=B`Q+C,N
M,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($IO96P@5F%N9&%L(#QJ=F%N9&%L0&EN9F]T96-K
M+G%C+F-A/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,
M15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O
M;&EB+V)A<V4N<&AP)SL*"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N
M9ELG875T:"==6R=D<FEV97(G72D["@HO+R!#:&5C:R!F;W(@1T54(&%U=&@N
M"FEF("AE;7!T>2@D7T=%5%LG=7-E<B==*2!\?"`A)&%U=&@M/F%U=&AE;G1I
M8V%T92@D7T=%5%LG=7-E<B==+"!A<G)A>2@G<&%S<W=O<F0G(#T^("1?1T54
M6R=P87-S)UTI*2D@>PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G;&]G:6XN<&AP/VQO9V]U=%]R96%S;VX];&]G
M;W5T)RDI.PH@("`@97AI=#L*?0H*:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G:6YD97@N<&AP)RDI.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+VAT='!?;&]G:6Y?<F5F97(N<&AP````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S$T`#$P-#$W,S8S,#$V`#`R,C$T-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+VAT='!?;&]G:6Y?<F5F
M97(N<&AP+'8@,2XS+C$R+C,@,C`P-B\P,2\P,2`R,3HR.3HP.2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*
M"G)E<75I<F5?;VYC92`G+BXO;&EB+V)A<V4N<&AP)SL*"B1A=71H(#T@)D%U
M=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D["@HO+R!#
M:&5C:R!F;W(@2%144"!A=71H+@II9B`H96UP='DH)%]315)615);)U!(4%]!
M551(7U5315(G72D@?'P*("`@(&5M<'1Y*"1?4T525D526R=02%!?05542%]0
M5R==*2!\?`H@("`@(21A=71H+3YA=71H96YT:6-A=&4H)%]315)615);)U!(
M4%]!551(7U5315(G72P*("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=P87-S=V]R9"<@/3X@)%]315)615);)U!(4%]!551(7U!7)UTI*2D@>PH*
M("`@(&AE861E<B@G5U=7+4%U=&AE;G1I8V%T93H@0F%S:6,@<F5A;&T](B<@
M+B`D875T:"T^9V5T4&%R86TH)W)E86QM)RD@+B`G(B<I.PH@("`@:&5A9&5R
M*"=(5%10+S$N,"`T,#$@56YA=71H;W)I>F5D)RD["B`@("!E>&ET*"=&;W)B
M:61D96XG*3L*?0H*:68@*"1U<FP@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L
M)RDI('L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*?2!E;'-E
M('L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)VQO9VEN+G!H<"<I*3L*?0H`````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S8W)I<'1S+RYH=&%C8V5S<P``````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#$V`#$P-#$W,S8S,#$V`#`Q
M-S8W-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!$96YY(&9R;VT@86QL"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V-R:7!T<R]R96UO=F5?<')E9G,N<&AP````````````````````````````
M```````````````````````````````````````P,3`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#8R,@`Q,#0Q-S,V,S`Q-@`P,C$S,34`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R$O=7-R+VQO
M8V%L+W!S82]A9&UI;B]B:6XO<&AP"CP_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W-C<FEP=',O<F5M;W9E7W!R969S+G!H<"QV(#$N,RXQ,"XV(#(P,#8O
M,#$O,3@@,3DZ-3<Z,#8@8F5N($5X<"`D"B`J"B`J(%1H:7,@<V-R:7!T(')E
M;6]V97,@82!P<F5F(&9R;VT@=7-E<G,G('-E='1I;F=S+B!(96QP<R!W:&5N
M(&$@<V5T=&EN9R!I<PH@*B!T;R!B92!M;W9E9"!F<F]M(&QO8VME9"`](&9A
M;'-E+"!T;R!L;V-K960@/2!T<G5E(&%N9"!T:&5R92!H879E(&%L<F5A9'D*
M("H@8F5E;B!P<F5F<R!S970@8GD@=&AE('5S97)S+@H@*B\*"B\J*@H@*BH@
M4V5T('1H:7,@=&\@=')U92!I9B!Y;W4@=V%N="!$0B!M;V1I9FEC871I;VYS
M(&1O;F4N"B`J*B\*)&QI=F4@/2!F86QS93L*"B\O($YO(&%U=&@N"D!D969I
M;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PH*+R\@1FEN9"!T:&4@8F%S92!F
M:6QE('!A=&@@;V8@2&]R9&4N"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXG*3L*"B\O($1O($-,22!C:&5C:W,@86YD
M(&5N=FER;VYM96YT('-E='5P(&9I<G-T+@IR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#
M3$DN<&AP)SL*"B\O($UA:V4@<W5R92!N;R!O;F4@<G5N<R!T:&ES(&9R;VT@
M=&AE('=E8BX*:68@*"%(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*
M("`@(&5X:70H(DUU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN95QN
M(BD["GT*"B\O($QO860@=&AE($-,22!E;G9I<F]N;65N="`M(&UA:V4@<W5R
M92!T:&5R92=S(&YO('1I;64@;&EM:70L(&EN:70*+R\@<V]M92!V87)I86)L
M97,L(&5T8RX*2&]R9&5?0TQ).CII;FET*"D["B1C;&D@/2`F;F5W($AO<F1E
M7T-,22@I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1&%T851R964N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U-H87)E+G!H<"<["@HO*B!-86ME('-U<F4@=&AE<F4G<R!N;R!C;VUP
M<F5S<VEO;BX@*B\*;V)?96YD7V-L96%N*"D["@H*)'-C;W!E(#T@)&-L:2T^
M<')O;7!T*%\H(D5N=&5R('9A;'5E(&9O<B!P<F5F7W-C;W!E.B(I*3L*)&YA
M;64@/2`D8VQI+3YP<F]M<'0H7R@B16YT97(@=F%L=64@9F]R('!R969?;F%M
M93HB*2D["@HO*B!/<&5N('1H92!D871A8F%S92X@*B\*)&1B(#T@)D1".CIC
M;VYN96-T*"1C;VYF6R=S<6PG72D["FEF("AI<U]A*"1D8BP@)U!%05)?17)R
M;W(G*2D@>PH@("!V87)?9'5M<"@D9&(I.R!E>&ET.PI]"@HO+R!3970@1$(@
M<&]R=&%B:6QI='D@;W!T:6]N<RX*<W=I=&-H("@D9&(M/G!H<'1Y<&4I('L*
M8V%S92`G;7-S<6PG.@H@("`@)&1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y
M)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?
M15)23U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@8G)E86L["F1E
M9F%U;'0Z"B`@("`D9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]0
M3U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I
M.PI]"@II9B`H)&QI=F4I('L*("`@("1S<6P@/2`G1$5,151%($923TT@:&]R
M9&5?<')E9G,@5TA%4D4@<')E9E]S8V]P92`](#\@04Y$('!R969?;F%M92`]
M(#\G.PH@("`@)'9A;'5E<R`](&%R<F%Y*"1S8V]P92P@)&YA;64I.PH@("`@
M)')E<W5L="`]("1D8BT^9V5T06QL*"1S<6PL("1V86QU97,I.PH@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@('9A<E]D
M=6UP*"1R97-U;'0I.PH@("`@?2!E;'-E:68@*&5M<'1Y*"1R97-U;'0I*2![
M"B`@("`@("`@)&-L:2T^=W)I=&5L;BAS<')I;G1F*%\H(DYO('!R969E<F5N
M8V4@7"(E<UPB(&9O=6YD(&EN('-C;W!E(%PB)7-<(BXB*2P@)&YA;64L("1S
M8V]P92DI.PH@("`@?2!E;'-E('L*("`@("`@("`D8VQI+3YW<FET96QN*'-P
M<FEN=&8H7R@B4')E9F5R96YC97,@7"(E<UPB(&1E;&5T960@:6X@<V-O<&4@
M7"(E<UPB+B(I+"`D;F%M92P@)'-C;W!E*2D["B`@("!]"GT@96QS92!["B`@
M("`D<W%L(#T@)U-%3$5#5"`J($923TT@:&]R9&5?<')E9G,@5TA%4D4@<')E
M9E]S8V]P92`](#\@04Y$('!R969?;F%M92`](#\G.PH@("`@)'9A;'5E<R`]
M(&%R<F%Y*"1S8V]P92P@)&YA;64I.PH@("`@)')E<W5L="`]("1D8BT^9V5T
M06QL*"1S<6PL("1V86QU97,I.PH@("`@:68@*&5M<'1Y*"1R97-U;'0I*2![
M"B`@("`@("`@)&-L:2T^=W)I=&5L;BAS<')I;G1F*%\H(DYO('!R969E<F5N
M8V4@7"(E<UPB(&9O=6YD(&EN('-C;W!E(%PB)7-<(BXB*2P@)&YA;64L("1S
M8V]P92DI.PH@("`@?2!E;'-E('L*("`@("`@("!V87)?9'5M<"@D<F5S=6QT
M*3L*("`@('T*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V-R:7!T<R]S971?<&5R;7,N<V@`````````````````
M```````````````````````````````````````````````````````P,3`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8P,0`Q,#0Q-S,V,S`Q-@`P
M,C`T-#$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R$O8FEN+W-H"B,*(R!S971?<&5R;7,N<V@@+2!*;VX@4&%R:7-E(#QJ
M;VY`8W-H+G)I="YE9'4^"B,*(R`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<V5T
M7W!E<FUS+G-H+'8@,2XW(#(P,#$O,#0O,34@,#$Z-34Z,S(@8VAU8VL@17AP
M("0*"B,@(D1A;F=E<F]U<R(@4$A0('-C<FEP=',*(PI$04Y'15)/55-?1DE,
M15,](G1E<W0N<&AP(@H*(R!$969A=6QT(&YO;BUW96(@<V5R=F5R('5S97(@
M=VAO('=I;&P@;W=N('1H92!T<F5E+@HC"D]73D52/7)O;W0*"B,@26YT<F]D
M=6-T;W)Y('1E>'0*(PIC870@/#P@14]&"@I4:&ES('-C<FEP="!W:6QL('-E
M="!T:&4@<&5R;6ES<VEO;G,@;VX@>6]U<B!(;W)D90IT<F5E('-O('1H870@
M=&AE(&9I;&5S('=I;&P@8F4@86-C97-S:6)L92!B>2!T:&4@=V5B"G-E<G9E
M<BX*"EEO=2!C86X@8V%N8V5L('1H:7,@<V-R:7!T(&%T(&%N>2!T:6UE('5S
M:6YG($-T<FPM0RX*"D5/1@H*(R!697)I9GD@=&AA="!W92=R92!A="!T:&4@
M=&]P(&]F('1H92!(;W)D92!T<F5E+@HC"G!W9`IE8VAO"F5C:&\@+6X@(DES
M('1H:7,@9&ER96-T;W)Y('1H92!T;W`@;V8@>6]U<B!(;W)D92!I;G-T86QL
M871I;VX_(%MY+$Y=("(*<F5A9"!215-03TY312`*:68@6R`B)%)%4U!/3E-%
M(B`A/2`B>2(@+6$@(B1215-03TY312(@(3T@(EDB(%T[('1H96X*("`@(&5C
M:&\*("`@(&5C:&\@+6X@(D5N=&5R('EO=7(@2&]R9&4@9&ER96-T;W)Y.B`B
M"B`@("!R96%D($1)4B`@"@EI9B!;(")X)$1)4B(@/2`B>"(@73L@=&AE;@H)
M"65C:&\@(D5X:71I;F<N+BXB"@D)97AI=`H)96QS90H@("`@"6-D("1$25(*
M"69I"F9I"F5C:&\*"B,@1V5T('1H92!W96(@<V5R=F5R)W,@9W)O=7`N"B,*
M96-H;R`M;B`B56YD97(@=VAA="!G<F]U<"!D;V5S('1H92!W96(@<')O8V5S
M<R!R=6X_(%MN;V)O9'E=("(*<F5A9"!714)?1U)/55`*:68@6R`B>"1714)?
M1U)/55`B(#T@(G@B(%T[('1H96X*("`@(%=%0E]'4D]54#TB;F]B;V1Y(B`*
M9FD*"B,@07-K(&)E9F]R92!P<F]C965D:6YG+@HC"F5C:&\*96-H;R`M;B`B
M4')O8V5E9"!W:71H(&-H86YG:6YG(&]W;F5R<VAI<"!A;F0@<&5R;6ES<VEO
M;G,_(%MY+$Y=("(*<F5A9"!215-03TY312`*:68@6R`B)%)%4U!/3E-%(B`A
M/2`G>2<@+6$@(B1215-03TY312(@(3T@)UDG(%T[('1H96X*("`@(&5C:&\@
M(D5X:71I;F<N+BXB"B`@("!E>&ET"F9I"@HC(%-E="!T:&4@=7-E<B!A;F0@
M9W)O=7`@;W=N97)S:&EP(')E8W5R<VEV96QY+@HC"F5C:&\*96-H;R`M;B`B
M4V5T=&EN9R!O=VYE<G-H:7`@<F5C=7)S:79E;'DN+BX@(@IC:&]W;B`M4B`D
M3U=.15(@+@IC:&=R<"`M4B`D5T5"7T=23U50("X*96-H;R`B9&]N92XB"@HC
M(%-E="!T:&4@<&5R;6ES<VEO;G,@;VX@9FEL97,@*#`V-#`I(&%N9"!D:7)E
M8W1O<FEE<R`H,#<U,"DN"B,*96-H;R`M;B`B4V5T=&EN9R!P97)M:7-S:6]N
M<R!R96-U<G-I=F5L>2XN+B`B"F9I;F0@+B`M='EP92!F("UE>&5C(&-H;6]D
M(#`V-#`@>WT@7#L*9FEN9"`N("UT>7!E(&0@+65X96,@8VAM;V0@,#<U,"![
M?2!<.PIE8VAO(")D;VYE+B(*"B,@1&ES86)L92!A;GD@(F1A;F=E<F]U<R(@
M4$A0('-C<FEP=',@:6X@=&AE(&1I<W1R:6)U=&EO;B`H,#`P,"DN"B,*96-H
M;R`M;B`B1&ES86)L:6YG('!O=&5N=&EA;&QY(%PB9&%N9V5R;W5S7"(@4$A0
M('-C<FEP=',N+BX@(@IF;W(@1DE,12!I;B`D1$%.1T523U537T9)3$53.R!D
M;PH):68@6R`M9B`D1DE,12!=.R!T:&5N"@D)8VAM;V0@,#`P,"`D1DE,10H)
M9FD*9&]N90IE8VAO(")D;VYE+B(*"B,@4V%Y(&=O;V0M8GEE+@HC"F5C:&\*
M96-H;R`B268@>6]U(')E8V5I=F5D(&%N>2!E<G)O<G,L('EO=2!M87D@;F]T
M(&AA=F4@<W5F9FEC:65N="!A8V-E<W,B"F5C:&\@(G1O(&-H86YG92!F:6QE
M(&]W;F5R<VAI<"!A;F0@<&5R;6ES<VEO;G,N(@IE8VAO"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-C<FEP=',O<V5T=7`N<&AP````````````````````````````
M````````````````````````````````````````````````,#$P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`R,S(`,3`T,3<S-C,P,38`,#$W-S4S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````",A
M+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<`H\/W!H<`HO*BH*("H@5&AE
M(&UA:6X@2&]R9&4@<V5T=7`@<V-R:7!T('=H:6-H(&%L;&]W<R!F;W(@82!S
M=&5P(&)Y('-T97`@<V5T=7`*("H@;W(@<F5C;VYF:6=U<F%T:6]N(&]F(&$@
M2&]R9&4@:6YS=&%L;&%T:6]N+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP
M=',O<V5T=7`N<&AP+'8@,2XR-2XQ,"XW(#(P,#8O,#$O,#$@,C$Z,CDZ,#D@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU
M:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#
M:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L
M;RYC;VT^"B`J($!A=71H;W(@($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*"D!D969I
M;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*)'-E='5P(#T@)E-E='5P
M.CIS:6YG;&5T;VXH*3L*+RH@0VAE8VMI;F<@9F]R(')E9VES=')Y+B`J+PHD
M9FEL97,@/2!A<G)A>2@G8V]N9BYP:'`G+"`G;6EM95]D<FEV97)S+G!H<"<L
M("=N;',N<&AP)RP@)W!R969S+G!H<"<L"B`@("`@("`@("`@("`@)W)E9VES
M=')Y+G!H<"<I.PIF;W)E86-H("@D9FEL97,@87,@)&9I;&5N86UE*2!["B`@
M("`D9FEL92`]($A/4D1%7T)!4T4@+B`G+V-O;F9I9R\G("X@)&9I;&5N86UE
M.PH@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE*2D@>PH@("`@("`@("1S971U
M<"T^;&]G*'-P<FEN=&8H7R@B1FEL92!<(B5S7"(@:7,@879A:6QA8FQE+B(I
M+"`D9FEL96YA;64I+"`G;65S<V%G92<I.PH@("`@("`@(&-O;G1I;G5E.PH@
M("`@?0H*("`@("1S971U<"T^;&]G*'-P<FEN=&8H7R@B1FEL92!<(B5S7"(@
M:7,@;6ES<VEN9RXB*2P@)&9I;&5N86UE*2P@)W=A<FYI;F<G*3L*("`@("1D
M:7-T9FEL92`]("1F:6QE("X@)RYD:7-T)SL*"B`@("!I9B`H9FEL95]E>&ES
M=',H)&1I<W1F:6QE*2D@>PH@("`@("`@("1C<F5A=&5?8V]N9FEG(#T@)'-E
M='5P+3YC;&DM/G!R;VUP="AS<')I;G1F*%\H(D-R96%T92!<(B5S7"(@9G)O
M;2!D969A=6QT<R!N;W<_(BDL("1F:6QE;F%M92DL(&%R<F%Y*"=Y)R`]/B!?
M*")997,B*2P@)VXG(#T^(%\H(DYO(BDI*3L*("`@('T@96QS92!["B`@("`@
M("`@)'-E='5P+3YC;&DM/F9A=&%L*'-P<FEN=&8H7R@B0V%N(&YO="!F:6YD
M(%PB)7-<(BP@8VAE8VL@>6]U<B!I;G-T86QL871I;VXN(BDL("1D:7-T9FEL
M92DI.PH@("`@?0H*("`@(&EF("@D8W)E871E7V-O;F9I9R`]/2`G>2<I('L*
M("`@("`@("!I9B`H(6-O<'DH)&1I<W1F:6QE+"`D9FEL92DI('L*("`@("`@
M("`@("`@)'-E='5P+3YC;&DM/F9A=&%L*'-P<FEN=&8H7R@B0V]P>6EN9R!<
M(B4Q)',N9&ES=%PB('1O(%PB)3$D<UPB(&9A:6QE9"X@0VAE8VL@>6]U<B!I
M;G-T86QL871I;VXN(BDL("1F:6QE;F%M92DI.PH@("`@("`@('T*("`@("`@
M("`D<V5T=7`M/FQO9RAS<')I;G1F*%\H(D9I;&4@)7,@8W)E871E9"XB*2P@
M)&9I;&5N86UE*2P@)W-U8V-E<W,G*3L*("`@('T@96QS92!["B`@("`@("`@
M)'-E='5P+3YC;&DM/F9A=&%L*'-P<FEN=&8H7R@B66]U(&YE960@=&AE(%PB
M)7-<(B!F:6QE('1O(&-O;G1I;G5E('-E='5P(&%N9"!T;R!U<V4@2&]R9&4N
M(BDL("1F:6QE;F%M92DI.PH@("`@?0I]"@HD<V5T=7`M/FQO9RA?*"));FET
M:6%L('-E='5P(&-O;7!L971E9"X@3F]W(&-O;G1I;G5E('1H92!S971U<"!W
M:71H('EO=7(@8G)O=W-E<BP@9V\@=&\Z(&AT='`Z+R\\66]U<B!(;W)D92!I
M;G-T86QL(%523#XO861M:6XO(BDL("=S=6-C97-S)RD["F5X:70["@HO*BH*
M("H@5&AE(%-E='5P.CH@8VQA<W,@<')O=FED97,@82!S970@;V8@9G5N8W1I
M;VYS('1O('-E="!U<"!A($AO<F1E"B`J(&EN<W1A;&QA=&EO;BX*("H*("H@
M)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-E='5P+G!H<"QV(#$N,C4N,3`N-R`R
M,#`V+S`Q+S`Q(#(Q.C(Y.C`Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?4V5T=7`*("HO"F-L87-S(%-E='5P('L*"B`@("!F=6YC=&EO;B`F9F%C
M=&]R>2@D:6YT97)F86-E*0H@("`@>PH@("`@("`@("1C;&%S<R`]("=3971U
M<%\G("X@)&EN=&5R9F%C93L*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C
M;&%S<RDI('L*("`@("`@("`@("`@)'-E='5P(#T@)FYE=R`D8VQA<W,H*3L*
M("`@("`@("`@("`@<F5T=7)N("1S971U<#L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!E>&ET*'-P<FEN=&8H7R@B4V5T=7`@:7,@;F]T(&%V86EL
M86)L92!T:')O=6=H('1H92`E<R!I;G1E<F9A8V4N(BDL("1I;G1E<F9A8V4I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I
M"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC93L*"B`@("`@("`@:68@
M*"%I<W-E="@D:6YS=&%N8V4I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O0TQ)+G!H<"<["B`@("`@("`@("`@(&EF("A(;W)D95]#3$DZ
M.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@("`@("`@("`@("`@("1I;G1E<F9A
M8V4@/2`G8VQI)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1I;G1E<F9A8V4@/2`G=V5B)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D:6YS=&%N8V4@/2`F4V5T=7`Z.F9A8W1O<GDH)&EN=&5R9F%C92D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E.PH@("`@?0H*
M?0H*+RHJ"B`J(%1H92!3971U<%]C;&DZ.B!C;&%S<R!P<F]V:61E<R!A($-,
M22!I;G1E<F9A8V4@=&\@=&AE($AO<F1E('-E='5P"B`J('-C<FEP="X*("H*
M("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-E='5P+G!H<"QV(#$N,C4N,3`N
M-R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K
M;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7U-E='5P"B`J+PIC;&%S<R!3971U<%]C;&D@97AT96YD<R!3971U
M<"!["@H@("`@=F%R("1C;&D@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T<R!A(&YE=R!3971U<"!O8FIE8W0@=7-I;F<@=&AE($-,22!I;G1E
M<F9A8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%-E='5P7V-L:2@I"B`@("![
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]#3$DN<&AP)SL*("`@("`@
M("`D=&AI<RT^8VQI(#T@)FYE=R!(;W)D95]#3$DH*3L*"B`@("!]"@H@("`@
M9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D='EP92`]("=M97-S86=E)RD*("`@
M('L*("`@("`@("`O*B!7<F%P('1H92!M97-S86=E<R!W:71H(&%N(&EN9&5N
M="P@;F5A=&5R('-C<F5E;B!D:7-P;&%Y+B`J+PH@("`@("`@("1M97-S86=E
M(#T@=V]R9'=R87`H)&UE<W-A9V4L(#8Y+"`B7&X@("`@("`@("`@("(I.PH@
M("`@("`@("1T:&ES+3YC;&DM/FUE<W-A9V4H)&UE<W-A9V4L("=C;&DN)R`N
M("1T>7!E*3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]T96UP+6-L96%N=7`N8W)O;@``````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,S`P,P`Q,#0Q-S,V,S`Q-@`P,C$S-3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R$O8FEN+W-H"@HC
M(%1H:7,@:7,@86X@97AA;7!L92!C<F]N(&IO8B!S:&5L;"!S8W)I<'0@=VAI
M8V@@=VEL;"!C;&5A;B!U<"!A;GD*(R!T96UP;W)A<GD@9FEL97,@=VAI8V@@
M;6%Y(&=E="!S=')A;F1E9"!B>2!(;W)D92!U<V5R<R!I;B!T:&4*(R!W96)S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@HC"B,@66]U(&UA>2!H879E
M('1O(&-H86YG92`O=&UP('1O(&%N;W1H97(@;&]C871I;VX@9&5P96YD:6YG
M(&]N('EO=7(*(R!C;VYF:6=U<F%T:6]N+B`@3W1H97(@;6]D:69I8V%T:6]N
M<R!M87D@86QS;R!B92!R97%U:7)E9"X*(PHC(%1H:7,@<V-R:7!T(&ES('!R
M;W9I9&5D(&%S+6ES(&%N9"!I<R!T;R!B92!U<V5D(&%T('EO=7(@;W=N(')I
M<VLN(`HC($AO<F1E(&%N9"!T:&4@875T:&]R<R!A8V-E<'0@;F\@<F5S<&]N
M<VEB:6QI='D@9F]R(&%N>2!D86UA9V5S(&]R"B,@;&]S97,@8V%U<V5D(&)Y
M('1H:7,@<V-R:7!T('=H971H97(@:6YD:7)E8W0L(&EN8VED96YT86PL(&]R
M"B,@8V]N<V5Q=65N=&EA;"P@('=H971H97(@;W(@;F]T('-U8V@@9&%M86=E
M<R!C;W5L9"!B92!F;W)S965N+@HC"B,@2&]W('1O('5S92!T:&ES('-C<FEP
M="!W:6QL(&1E<&5N9"!O;B!Y;W5R('-Y<W1E;2X@($9O<B!S;VUE('-Y<W1E
M;7,L"B,@:70@:7,@87,@<VEM<&QY(&%S('!U='1I;F<@=&AI<R!F:6QE(&EN
M('1H92`O971C+V-R;VXN9&%I;'D@9&ER96-T;W)Y+@HC($9O<B!O=&AE<G,L
M(&UO<F4@;W(@9&EF9F5R96YT('-E='5P('=I;&P@8F4@<F5Q=6ER960N("!3
M964@=&AE"B,@9&]C=6UE;G1A=&EO;B!F;W(@>6]U<B!S>7-T96US(&IO8B!S
M8VAE9'5L97(@9F]R(&UO<F4@:6YF;W)M871I;VXN"B,*"B,@5&AE(&QO8V%T
M:6]N(&]F(%!(4"=S('1E;7!O<F%R>2!D:7)E8W1O<GD*5$U07T1)4CTO=&UP
M"@H*(R!-4U=O<F0@871T86-H;65N=',@*&=E;F5R871E9"!B>2!T:&4@35-W
M;W)D('9I97=E<BD*9F]R($U35T]21%]&24Q%(&EN(&!F:6YD("1435!?1$E2
M("UT>7!E(&8@+6YA;64@;7-W;W)D7"H@+6-T:6UE("LR(&`[(&1O"@ER;2`M
M9B`D35-73U)$7T9)3$4*9&]N90H*(R!)35`@871T86-H;65N=',*9F]R($E-
M4%]&24Q%(&EN(&!F:6YD("1435!?1$E2("UT>7!E(&8@+6YA;64@:6UP871T
M7"H@+6-T:6UE("LR(&`[(&1O"@ER;2`M9B`D24U07T9)3$4*9&]N90H*(R!+
M;'5T>B!T96UP;W)A<GD@9FEL97,*9F]R($M,551:7T9)3$4@:6X@8&9I;F0@
M)%1-4%]$25(@+71Y<&4@9B`M;F%M92!+;'5T>EPJ("UC=&EM92`K,B!@.R!D
M;PH)<FT@+68@)$M,551:7T9)3$4*9&]N90H*(R!3<&5L;"!C:&5C:VEN9R!T
M96UP;W)A<GD@9FEL97,*9F]R(%-014Q,7T9)3$4@:6X@8&9I;F0@)%1-4%]$
M25(@+71Y<&4@9B`M;F%M92!S<&5L;%PJ("UC=&EM92`K,B!@.R!D;PH)<FT@
M+68@)%-014Q,7T9)3$4*9&]N90H*(R!61E,@=&5M<&]R87)Y(&9I;&5S"F9O
M<B!)35!?1DE,12!I;B!@9FEN9"`D5$U07T1)4B`M='EP92!F("UN86UE('9F
M<UPJ("UC=&EM92`K,B!@.R!D;PH)<FT@+68@)$E-4%]&24Q%"F1O;F4*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M=&AE;65S7V-H96-K+G!H<```````````````````````````````````````
M````````````````````````````,#$P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,30U-C8`,3`T,3<S-C,P,38`,#(Q,C4S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",A+W5S<B]L;V-A;"]P<V$O
M861M:6XO8FEN+W!H<`H\/W!H<`HO*BH*("H@5&AI<R!S8W)I<'0@9&]E<R!S
M;VUE(&-H96-K:6YG(&]F('1H96UE<RP@=&\@;6%K92!S=7)E(&EM86=E<R!A
M<F4*("H@<WEN8VAR;VYI<V5D(&%C<F]S<R!T:&5M97,N"B`J"B`J("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]T:&5M97-?8VAE8VLN<&AP+'8@,2XS+C$P+C0@
M,C`P-B\P,2\P,2`R,3HR.3HP.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!4:&4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D
M92YO<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA<FMO($1J
M=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["@HO*B!#
M3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S971U<"!F:7)S="X@*B\*<F5Q
M=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO*B!-86ME('-U<F4@;F\@;VYE
M(')U;G,@=&AI<R!F<F]M('1H92!W96(N("HO"FEF("@A2&]R9&5?0TQ).CIR
M=6YN:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M
M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO*B!'970@86YY(&]P=&EO;G,N
M("HO"B1S:6UP;&4@/2!F86QS93L*)&EG;F]R92`](&%R<F%Y*"D["FEF("AI
M<W-E="@D87)G=BDI('L*("`@("\J($=E="!R:60@;V8@=&AE(&9I<G-T(&%R
M9R!W:&EC:"!I<R!T:&4@<V-R:7!T(&YA;64N("HO"B`@("!A<G)A>5]S:&EF
M="@D87)G=BD["B`@("!W:&EL92`H)&%R9R`](&%R<F%Y7W-H:69T*"1A<F=V
M*2D@>PH@("`@("`@(&EF("@D87)G(#T]("<M+6AE;'`G*2!["B`@("`@("`@
M("`@('!R:6YT7W5S86=E*"D["B`@("`@("`@?2!E;'-E:68@*"1A<F<@/3T@
M)RUS)RD@>PH@("`@("`@("`@("`D<VEM<&QE(#T@=')U93L*("`@("`@("!]
M(&5L<V5I9B`H<W1R<&]S*"1A<F<L("<M:2<I(#T]/2`P*2!["B`@("`@("`@
M("`@(&QI<W0H+"1I9VYO<F5;72D@/2!E>'!L;V1E*"<])RP@)&%R9RD["B`@
M("`@("`@("`@("\O)&EG;F]R95M=(#T@)&D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<')I;G1?=7-A9V4H(E5N<F5C;V=N:7-E9"!O<'1I;VX@
M)&%R9R(I.PH@("`@("`@('T*("`@('T*?0H*+RH@4V5T('5P($-,22X@*B\*
M)&-L:2`]("9N97<@2&]R9&5?0TQ)*"D["@HO*B!#:&5C:R!I9B!A="!L96%S
M="!T:&4@<F5G:7-T<GD@:7,@879A:6%B;&4N("HO"FEF("@A0&9I;&5?97AI
M<W1S*$A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP:'`G*2D@>PH@
M("`@)&-L:2T^=W)I=&5L;B@D8VQI+3YR960H)TYO($AO<F1E(')E9VES=')Y
M(&9I;&4N)RDI.PH@("`@97AI=#L*?0H*+R\D8VQI+3YW<FET96QN*"1C;&DM
M/F=R965N*"=296%D:6YG+BXN)RDI.PIR97%U:7)E7V]N8V4@2$]21$5?0D%3
M12`N("<O;&EB+V)A<V4N<&AP)SL*"B\J($=E="!T:&4@87!P<R!A;F0@<W1A
M<G0@9&]I;F<@8VAE8VMS+B`J+PHD87!P<R`]("1R96=I<W1R>2T^;&ES=$%P
M<',H87)R87DH)VAI9&1E;B<L("=N;W1O;VQB87(G+"`G86-T:79E)RP@)V%D
M;6EN)RDI.PH*+RH@1V5T(&$@;&ES="!O9B!T:&5M97,N("HO"B1T:&5M97,@
M/2!A<G)A>2@I.PHD=&AE;65S7V1I<B`]("1R96=I<W1R>2T^9V5T*"=T:&5M
M97-F<R<L("=H;W)D92<I.PII9B`H)&AA;F1L92`](&]P96YD:7(H)'1H96UE
M<U]D:7(I*2!["B`@("!W:&EL92`H)&9I;&4@/2!R96%D9&ER*"1H86YD;&4I
M*2!["B`@("`@("`@:68@*"1F:6QE(#T]("<N)R!\?"`D9FEL92`]/2`G+BXG
M('Q\("1F:6QE(#T]("=#5E,G('Q\"B`@("`@("`@("`@("1F:6QE(#T]("<N
M<W9N)R!\?`H@("`@("`@("`@("`A0&9I;&5?97AI<W1S*"(D=&AE;65S7V1I
M<B\D9FEL92]I;F9O+G!H<"(I('Q\"B`@("`@("`@("`@("%`9FEL95]E>&ES
M=',H(B1T:&5M97-?9&ER+R1F:6QE+V=R87!H:6-S(BDI('L*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("`O*B!$;VXG="!B;W1H
M97(@8VAE8VMI;F<@=6YL97-S('1H92!T:&5M92!E>'!L:6-I=&QY('-T871E
M<R!T:&%T"B`@("`@("`@("H@:6-O;G,@=VEL;"!B92!R97!L86-E9"!F;W(@
M=&AI<R!A<'!L:6-A=&EO;BX@*B\*("`@("`@("!I;F-L=61E("(D=&AE;65S
M7V1I<B\D9FEL92]I;F9O+G!H<"(["B`@("`@("`@:68@*"%I<W-E="@D=&AE
M;65?:6-O;G,I*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4W1O<F4@=&AE(&%P<',@86YD('1H96ER('1H96UE(&1I
M<F5C=&]R:65S+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&5M95]I8V]N<R!A
M<R`D87!P*2!["B`@("`@("`@("`@("1A<'!?=&AE;65S7V1I<B`]("1R96=I
M<W1R>2T^9V5T*"=T:&5M97-F<R<L("1A<'`I.PH@("`@("`@("`@("`D=&AE
M;65S6R1A<'!=6R1F:6QE72`]("(D87!P7W1H96UE<U]D:7(O)&9I;&4O9W)A
M<&AI8W,B.PH@("`@("`@('T*"B`@("`@("`@+RH@56YS970@=&AI<RP@=&\@
M;6%K92!S=7)E(&ET(&ES(&-H96-K960@=&AE(&YE>'0@=&EM92!A<F]U;F0N
M("HO"B`@("`@("`@=6YS970H)'1H96UE7VEC;VYS*3L*("`@('T*?0H*9F]R
M96%C:"`H)&%P<',@87,@)&%P<"D@>PH@("`@+RH@4V5T('5P('-O;64@9&ER
M<RX@*B\*("`@("1T:&5M97-?9&ER(#T@)')E9VES=')Y+3YG970H)W1H96UE
M<V9S)RP@)&%P<"D["B`@("`D:&]R9&5?=&AE;65?9&ER(#T@)'1H96UE<U]D
M:7(@+B`G+VAO<F1E)SL*("`@("1H;W)D95]I8V]N7V1I<B`]("1H;W)D95]T
M:&5M95]D:7(@+B`G+V=R87!H:6-S)SL*"B`@("`O*B!386YI='D@8VAE8VL@
M9F]R('1H92!D:7)E8W1O<FEE<RX@*B\*("`@(&EF("@A0&9I;&5?97AI<W1S
M*"1H;W)D95]T:&5M95]D:7(I('Q\("%`9FEL95]E>&ES=',H)&AO<F1E7VEC
M;VY?9&ER*2D@>PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@("\J($=E
M="!A(&QI<W0@;V8@86QL(&AO<F1E(&EM86=E<R!R96-U<G-I=F5L>2X@*B\*
M("`@("1H;W)D95]I8V]N7VQI<W0@/2!A<G)A>2@I.PH@("`@<F5A9$1I<E)E
M8W5R<VEV96QY*"1H;W)D95]I8V]N7V1I<BP@)&AO<F1E7VEC;VY?9&ER+"`D
M:&]R9&5?:6-O;E]L:7-T*3L*"B`@("`O*B!,;V]P('1H<F]U9V@@=&AE;65S
M('1H870@<F5P;&%C92!I8V]N<R!A;F0@8VAE8VL@9F]R(&1I9F9E<F5N8V5S
M+B`J+PH@("`@9F]R96%C:"`H)'1H96UE<ULD87!P72!A<R`D=&AE;64@/3X@
M)'1H96UE7VEC;VY?9&ER*2!["B`@("`@("`@)'1H96UE7VEC;VY?;&ES="`]
M(&%R<F%Y*"D["B`@("`@("`@<F5A9$1I<E)E8W5R<VEV96QY*"1T:&5M95]I
M8V]N7V1I<BP@)'1H96UE7VEC;VY?9&ER+"`D=&AE;65?:6-O;E]L:7-T*3L*
M"B`@("`@("`@+RH@0VAE8VL@9F]R(&EC;VYS('1H870@87)E(&EN('1H92!(
M;W)D92!B87-E('1H96UE(&%N9"!N;W0@:6X@=&AE"B`@("`@("`@("H@8W5S
M=&]M('1H96UE+B`J+PH@("`@("`@("1D:69F(#T@87)R87E?9&EF9B@D:&]R
M9&5?:6-O;E]L:7-T+"`D=&AE;65?:6-O;E]L:7-T*3L*("`@("`@("`O*B!$
M;VXG="!B;W1H97(@<F5P;W)T:6YG(&%N>71H:6YG(&9O<B!T:&5M97,@=&AA
M="!H879E(&%L;"!T:&4@:&]R9&4*("`@("`@("`@*B!B87-E(&EC;VYS+B`J
M+PH@("`@("`@(&EF("AE;7!T>2@D9&EF9BDI('L*("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@?0H*("`@("`@("`D8VQI+3YW<FET96QN*"1C;&DM
M/G)E9"AS<')I;G1F*"=;)7-=("(E<R(@=&AE;64@;6ES<VEN9R!T:&5S92!I
M8V]N<SHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<G1O
M=7!P97(H)&%P<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H96UE*2DI.PH@("`@("`@(&9O<F5A8V@@*"1D:69F(&%S("1I8V]N*2![
M"B`@("`@("`@("`@("1C;&DM/G=R:71E;&XH)&EC;VXI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0VAE8VL@:68@;VYL>2!D;VEN9R!A($AO<F1E(&)A<V4@
M=&AE;64@=&\@8W5S=&]M('1H96UE(&-H96-K+B!3:VEP"B`@("`@("`@("H@
M=&AE(')E=F5R<V4@8VAE8VMI;F<@:68@=')U92X@*B\*("`@("`@("!I9B`H
M)'-I;7!L92D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@
M("`@("`@("\J($-H96-K(&9O<B!I8V]N<R!T:&%T(&%R92!I;B!T:&4@2&]R
M9&4@8F%S92!T:&5M92!A;F0@;F]T(&EN('1H90H@("`@("`@("`J(&-U<W1O
M;2!T:&5M92X@*B\*("`@("`@("`D9&EF9B`](&%R<F%Y7V1I9F8H)'1H96UE
M7VEC;VY?;&ES="P@)&AO<F1E7VEC;VY?;&ES="D["B`@("`@("`@+RH@1&]N
M)W0@8F]T:&5R(')E<&]R=&EN9R!A;GET:&EN9R!F;W(@=&AE;65S('1H870@
M9&]N)W0@:&%V92!A;GD@:6-O;G,*("`@("`@("`@*B!M;W)E('1H86X@=&AE
M(&)A<V4@=&AE;64N("HO"B`@("`@("`@:68@*&5M<'1Y*"1D:69F*2D@>PH@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@("1C;&DM
M/G=R:71E;&XH)&-L:2T^8FQU92AS<')I;G1F*"=;)7-=("(E<R(@=&AE;64@
M:&%S('1H97-E(&5X=')A(&EC;VYS.B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W1R=&]U<'!E<B@D87!P*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AE;64I*2D["B`@("`@("`@9F]R96%C:"`H
M)&1I9F8@87,@)&EC;VXI('L*("`@("`@("`@("`@)&-L:2T^=W)I=&5L;B@D
M:6-O;BD["B`@("`@("`@?0H@("`@?0I]"@HD8VQI+3YW<FET96QN*"1C;&DM
M/F=R965N*"=$;VYE+B<I*3L*97AI=#L*"B\J*@H@*B!,;V]P<R!T:')O=6=H
M('1H92!D:7)E8W1O<GD@<F5C=7)S:79E;'D@86YD('-T;W)E<R!T:&4@9F]U
M;F0@9W)A<&AI8W,@:6YT;PH@*B!A;B!A<G)A>2X*("HO"F9U;F-T:6]N(')E
M861$:7)296-U<G-I=F5L>2@D<&%T:"P@)&)A<V5P871H+"`F)&QI<W0I"GL*
M("`@(&=L;V)A;"`D:6=N;W)E.PH*("`@(&EF("@D:&%N9&QE(#T@;W!E;F1I
M<B@D<&%T:"DI('L*("`@("`@("!W:&EL92`H)&9I;&4@/2!R96%D9&ER*"1H
M86YD;&4I*2!["B`@("`@("`@("`@(&EF("@D9FEL92`]/2`G+B<@?'P@)&9I
M;&4@/3T@)RXN)R!\?"`D9FEL92`]/2`G0U93)PH@("`@("`@("`@("`@("`@
M?'P@)&9I;&4@/3T@)RYS=FXG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?9&ER*"(D<&%T
M:"\D9FEL92(I*2!["B`@("`@("`@("`@("`@("!R96%D1&ER4F5C=7)S:79E
M;'DH(B1P871H+R1F:6QE(BP@)&)A<V5P871H+"`D;&ES="D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:6=N;W)E
M(&%S("1P871T97)N*2!["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H)'!A='1E<FXL("1F:6QE*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1L:7-T6UT@/2!S=6)S='(H
M)'!A=&@L('-T<FQE;B@D8F%S97!A=&@I*2`N("(O)&9I;&4B.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&-L;W-E9&ER*"1H86YD;&4I.PH@
M("`@?0H*?0H*9G5N8W1I;VX@<')I;G1?=7-A9V4H)&UE<W-A9V4@/2`G)RD@
M>PH*("`@(&EF("@A96UP='DH)&UE<W-A9V4I*2!["B`@("`@("`@<')I;G0@
M(G1H96UE<U]C:&5C:RYP:'`Z("1M97-S86=E7&Y<;B(["B`@("!]"@H@("`@
M<')I;G0@/#P\55-!1T4*57-A9V4Z('1H96UE<U]C:&5C:RYP:'`@6T]05$E/
M3ET*"E!O<W-I8FQE(&]P=&EO;G,Z"B`@+7,@("`@("`@("`@("!$;R!O;FQY
M(&$@<VEM<&QE(&-H96-K(&9O<B!A;GD@2&]R9&4@8F%S92!T:&5M92!G<F%P
M:&EC<R!T:&%T"B`@("`@("`@("`@("`@("!A<F4@;6ES<VEN9R!F<F]M('1H
M92!O=&AE<B!T:&5M97,L(&%N9"!N;R!C:&5C:R!O9B!T:&4*("`@("`@("`@
M("`@("`@(&]P<&]S:71E+@H@("UI/5!!5%1%4DX@("`@26YS97)T(&%N>2!V
M86QI9"!R96=E>"!P871T97)N('1O(&EG;F]R92!F:6QE<R!F<F]M(&)E:6YG
M"B`@("`@("`@("`@("`@("!C:&5C:V5D+B!9;W4@8V%N(&5N=&5R(&UU;'1I
M<&QE("UI(&]P=&EO;G,@=&\@:6YC;'5D92!M=6QT:7!L90H@("`@("`@("`@
M("`@("`@<&%T=&5R;G,N($9O<B!E>&%M<&QE.B`M:3TB+WAC9B0O('1O(&EG
M;F]R92!A;GD@;W)I9VEN86P*("`@("`@("`@("`@("`@($=)35`@9FEL97,N
M"@I54T%'13L*("`@(&5X:70["GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+VUI9W)A=&5?=7-E<E]C871E9V]R:65S+G!H<```````
M`````````````````````````````````````````````#`Q,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-38U`#$P-#$W,S8S,#$V`#`R,S4Q-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C(2]U
M<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`@+7$*/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O<V-R:7!T<R]M:6=R871E7W5S97)?8V%T96=O<FEE<RYP
M:'`L=B`Q+C4N,3`N,2`R,#`U+S$P+S$X(#$Q.C,T.C`P(&IA;B!%>'`@)`H@
M*@H@*B!!('-C<FEP="!T;R!U<&1A=&4@=7-E<G,@<')E9F5R96YC97,@=&\@
M8V]M8FEN92!T:&5I<B!C871E9V]R:65S"B`J(&%N9"!C871E9V]R>2!C;VQO
M<G,@9G)O;2!'96YI92P@2W)O;F]L:71H+"!-;F5M;RP@86YD($YA9R!I;G1O
M('1H90H@*B!N97<@2&]R9&4M=VED92!P<F5F97)E;F-E<RX@17AP96-T<R!T
M;R!B92!G:79E;B!A(&QI<W0@;V8@=7-E<G,@;VX*("H@4U1$24XL(&]N92!U
M<V5R;F%M92!P97(@;&EN92P@=&\@8V]N=F5R="X@57-E<FYA;65S(&YE960@
M=&\@;6%T8V@*("H@=&AE('9A;'5E<R!S=&]R960@:6X@=&AE('!R969E<F5N
M8V5S(&)A8VME;F0N"B`J+PH*+R\@1FEN9"!T:&4@8F%S92!F:6QE('!A=&@@
M;V8@2&]R9&4N"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F
M:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD[
M"@HO+R!$;R!#3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S971U<"!F:7)S
M="X*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO+R!-86ME('-U<F4@
M;F\@;VYE(')U;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A2&]R9&5?0TQ)
M.CIR=6YN:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F
M<F]M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D('1H92!#3$D@
M96YV:7)O;FUE;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T:6UE(&QI;6ET
M+"!I;FET"B\O('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E7T-,23HZ:6YI
M="@I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<"<["B1C;&D@/2`F2&]R9&5?0TQ).CIS:6YG;&5T;VXH*3L*)&%U=&@@
M/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*
M)&--86YA9V5R(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G97(H*3L*)&%P
M<',@/2`D<F5G:7-T<GDM/FQI<W1!<'!S*&%R<F%Y*"=H:61D96XG+"`G;F]T
M;V]L8F%R)RP@)V%C=&EV92<L("=A9&UI;B<I*3L*"B\O(%)E860@:6X@=&AE
M(&QI<W0@;V8@=7-E<FYA;65S(&]N(%-41$E.+@HD=7-E<G,@/2!A<G)A>2@I
M.PIW:&EL92`H(69E;V8H4U1$24XI*2!["B`@("`D;&EN92`](&9G971S*%-4
M1$E.*3L*("`@("1L:6YE(#T@=')I;2@D;&EN92D["B`@("!I9B`H(65M<'1Y
M*"1L:6YE*2D@>PH@("`@("`@("1U<V5R<UM=(#T@)&QI;F4["B`@("!]"GT*
M"B\O($QO;W`@=&AR;W5G:"!U<V5R<R!A;F0@8V]N=F5R="!P<F5F<R!F;W(@
M1V5N:64L($UN96UO+"!.86<L(&%N9`HO+R!+<F]N;VQI=&@N"F9O<F5A8V@@
M*"1U<V5R<R!A<R`D=7-E<BD@>PH@("`@96-H;R`G36EG<F%T:6YG('!R969S
M(&9O<B`G("X@)&-L:2T^8F]L9"@D=7-E<BD["@H@("`@+R\@4V5T("1U<V5R
M(&%S('1H92!C=7)R96YT('5S97(N"B`@("`D875T:"T^<V5T075T:"@D=7-E
M<BP@87)R87DH*2P@)R<I.PH*("`@("\O($9E=&-H(&-U<G)E;G0@8V%T96=O
M<FEE<R!A;F0@8V]L;W)S+@H@("`@)&-O;&]R<R`]("1C36%N86=E<BT^8V]L
M;W)S*"D["@H@("`@+R\@1V5N:64N"B`@("!I9B`H:6Y?87)R87DH)V=E;FEE
M)RP@)&%P<',I*2!["B`@("`@("`@96-H;R`G("X@9V5N:64G.PH@("`@("`@
M("1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)V=E;FEE)RP@9F%L<V4I
M.PH@("`@("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1G7V-A=&5G;W)I97,@/2!L:7-T0V%T96=O<FEE<R@G
M=VES:%]C871E9V]R:65S)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1G7V-A
M=&5G;W)I97,@87,@)&-A=&5G;W)Y*2!["B`@("`@("`@("`@("`@("`D8TUA
M;F%G97(M/F%D9"@D8V%T96=O<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\O($UN96UO+@H@("`@:68@*&EN7V%R<F%Y*"=M;F5M
M;R<L("1A<'!S*2D@>PH@("`@("`@(&5C:&\@)R`N(&UN96UO)SL*("`@("`@
M("`D<F5S=6QT(#T@)')E9VES=')Y+3YP=7-H07!P*"=M;F5M;R<L(&9A;'-E
M*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`D;5]C871E9V]R:65S(#T@;&ES=$-A=&5G;W)I97,H
M)VUE;6]?8V%T96=O<FEE<R<I.PH@("`@("`@("`@("`D;5]C;VQO<G,@/2!L
M:7-T0V]L;W)S*"=M96UO7V-O;&]R<R<I.PH@("`@("`@("`@("!F;W)E86-H
M("@D;5]C871E9V]R:65S(&%S("1K97D@/3X@)&-A=&5G;W)Y*2!["B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&U?8V]L;W)S6R1K97E=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1C;VQO<G-;)&-A=&5G;W)Y72`]("1M7V-O;&]R
M<ULD:V5Y73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C
M36%N86=E<BT^861D*"1C871E9V]R>2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+R\@3F%G+@H@("`@:68@*&EN7V%R<F%Y*"=N86<G
M+"`D87!P<RDI('L*("`@("`@("!E8VAO("<@+B!N86<G.PH@("`@("`@("1R
M97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)VYA9R<L(&9A;'-E*3L*("`@
M("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`D;E]C871E9V]R:65S(#T@;&ES=$-A=&5G;W)I97,H)W1A<VM?
M8V%T96=O<FEE<R<I.PH@("`@("`@("`@("!F;W)E86-H("@D;E]C871E9V]R
M:65S(&%S("1C871E9V]R>2D@>PH@("`@("`@("`@("`@("`@)&--86YA9V5R
M+3YA9&0H)&-A=&5G;W)Y*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O+R!+<F]N;VQI=&@N"B`@("!I9B`H:6Y?87)R87DH)VMR;VYO
M;&ET:"<L("1A<'!S*2D@>PH@("`@("`@(&5C:&\@)R`N(&MR;VYO;&ET:"<[
M"B`@("`@("`@)')E<W5L="`]("1R96=I<W1R>2T^<'5S:$%P<"@G:W)O;F]L
M:71H)RP@9F%L<V4I.PH@("`@("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1K7V-A=&5G;W)I97,@/2!L:7-T
M0V%T96=O<FEE<R@G979E;G1?8V%T96=O<FEE<R<I.PH@("`@("`@("`@("!I
M9B`H8V]U;G0H)&M?8V%T96=O<FEE<RDI('9A<E]D=6UP*"1K7V-A=&5G;W)I
M97,I.PH@("`@("`@("`@("`D:U]C;VQO<G,@/2!L:7-T0V]L;W)S*"=E=F5N
M=%]C;VQO<G,G*3L*("`@("`@("`@("`@9F]R96%C:"`H)&M?8V%T96=O<FEE
M<R!A<R`D:V5Y(#T^("1C871E9V]R>2D@>PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1K7V-O;&]R<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@
M("`D8V]L;W)S6R1C871E9V]R>5T@/2`D:U]C;VQO<G-;)&ME>5T["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8TUA;F%G97(M/F%D9"@D
M8V%T96=O<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("1C36%N86=E<BT^<V5T0V]L;W)S*"1C;VQO<G,I.PH@("`@)'!R969S+3YS
M=&]R92@I.PH@("`@)&-L:2T^=W)I=&5L;B@I.PI]"@HD8VQI+3YW<FET96QN
M*"D["B1C;&DM/G=R:71E;&XH)&-L:2T^9W)E96XH)T1/3D4G*2D["F5X:70[
M"@IF=6YC=&EO;B!L:7-T0V%T96=O<FEE<R@D<')E9FYA;64I"GL*("`@(&=L
M;V)A;"`D<')E9G,["@H@("`@)'-T<FEN9R`]("1P<F5F<RT^9V5T5F%L=64H
M)'!R969N86UE*3L*("`@(&EF("AE;7!T>2@D<W1R:6YG*2D@>PH@("`@("`@
M(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("1C871S(#T@97AP;&]D92@G
M?"<L("1S=')I;F<I.PH@("`@9F]R96%C:"`H)&-A=',@87,@)&-A="D@>PH@
M("`@("`@(&QI<W0H)&ME>2P@)'9A;"D@/2!E>'!L;V1E*"<Z)RP@)&-A="D[
M"B`@("`@("`@)&-A=&5G;W)I97-;)&ME>5T@/2`D=F%L.PH@("`@?0H*("`@
M(')E='5R;B`D8V%T96=O<FEE<SL*?0H*9G5N8W1I;VX@;&ES=$-O;&]R<R@D
M<')E9FYA;64I"GL*("`@(&=L;V)A;"`D<')E9G,["@H@("`@)'-T<FEN9R`]
M("1P<F5F<RT^9V5T5F%L=64H)'!R969N86UE*3L*("`@(&EF("AE;7!T>2@D
M<W1R:6YG*2D@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H@("`@
M)&-O;',@/2!E>'!L;V1E*"=\)RP@)'-T<FEN9RD["B`@("`D8V]L;W)S(#T@
M87)R87DH*3L*("`@(&9O<F5A8V@@*"1C;VQS(&%S("1C;VPI('L*("`@("`@
M("!L:7-T*"1K97DL("1V86PI(#T@97AP;&]D92@G.B<L("1C;VPI.PH@("`@
M("`@("1C;VQO<G-;)&ME>5T@/2`D=F%L.PH@("`@?0H*("`@(')E='5R;B`D
M8V]L;W)S.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP
M=',O4T-225!44P``````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#0T,C,`,3`T,3<S-C,P,38`,#$W,34V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B!(;W)D92!5=&EL:71Y(%-C<FEP=',*/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*"DEN=')O9'5C=&EO;@I^?GY^?GY^?GY^?GX*5&AI<R!D
M:7)E8W1O<GD@8V]N=&%I;G,@=F%R:6]U<R!U=&EL:71Y('-C<FEP=',@9F]R
M('1H92!(;W)D92!D:7-T<FEB=71I;VXN"E1H97D@87)E(&AE<F4@9F]R('EO
M=7(@8V]N=F5N:65N8V4N"@H*4V-R:7!T($EN9&5X"GY^?GY^?GY^?GY^?@IC
M;VUP87)E7W)E=FES:6]N<RYS:`H@("`@0V]M<&%R97,@9&EF9F5R96YT($-6
M4R!R979I<VEO;G,@;V8@=&AE('-A;64@9FEL92X*"F-O;VMI95]L;V=I;BYP
M:'`*("`@($%L;&]W<R!T;R!L;V=I;B!W:71H('5S97(@8W)E9&5N=&EA;',@
M<')O=FED960@8GD@8V]O:VEE<RX*"F-R96%T92US>6UL:6YK<RYP:'`*("`@
M($-R96%T97,@<WEM8F]L:6,@;&EN:W,@;F5C97-S87)Y(&9O<B!D979E;&]P
M97)S('1O('=O<FL@9&ER96-T;'D@;VX@=&AE"B`@("!F:6QE<R!I;B!T:&4@
M9G)A;65W;W)K(&UO9'5L92!W:71H;W5T(&YE961I;F<@=&\@:6YS=&%L;"!T
M:&4@8VAA;F=E9`H@("`@<&%C:V%G97,N"@IC<F]N9`H@("`@=&)D"@IG971?
M;&]G:6XN<&AP"B`@("!!;&QO=W,@=&\@;&]G:6X@=VET:"!U<V5R(&-R961E
M;G1I86QS('!R;W9I9&5D(&)Y($=%5"!P87)A;65T97)S+@H*:&EG:&QI9VAT
M+G!H<`H@("`@2&EG:&QI9VAT<R!S;W5R8V4@9FEL97,@;VX@=&AE(&-O;G-O
M;&4N"@IH;W)D92UR<WEN8RYS:`H@("`@4&5R9F]R;7,@82!C:&5C:V]U="!O
M9B!T:&4@;&%T97-T($AO<F1E(&-V<R!S;W5R8V5S('5S:6YG(')S>6YC+@H*
M:'1T<%]L;V=I;E]R969E<BYP:'`*("`@('1B9`H*;6%K92US;F%P<RYP:'`*
M("`@('1B9`H*;6%K92UR96QE87-E+G!H<`H@("`@0G5I;&1S(&1I<W1R:6)U
M=&EO;B!T87)B86QL<R!F;W(@2&]R9&4@86YD($AO<F1E(&UO9'5L97,N"@IM
M97)G92YP:'`*("`@($UE<F=E<R!C;VUM:71S(&9R;VT@82!C;VUM:70@;65S
M<V%G92!I;G1O('1H92!#5E,@=')E92!O9B!T:&4@8W5R<F5N=`H@("`@9&ER
M96-T;W)Y+@H*;6EG<F%T95]C871E9V]R:65S+G!H<`H@("`@36EG<F%T97,@
M;VQD(&-A=&5G;W)I97,@=&\@=&AE(&YE=R!H;W)D95]C871E9V]R>5]A='1R
M:6)U=&5S('1A8FQE+@H*;6EG<F%T95]L:6YK<RYP:'`*("`@($UI9W)A=&5S
M(&]L9"!(;W)D95],:6YK<R!T;R!T:&4@:&]R9&5?8V%T96=O<GE?871T<FEB
M=71E<R!T86)L92X*"G!A8VMA9V4N9'1D"B`@("!4:&4@4$5!4B!P86-K86=E
M(&1E<V-R:7!T:6]N+@H*<G!C+71E<W0N<&AP"B`@("!0<F]V:61E<R!T97-T
M<R!F;W(@=&AE(%)00R!C;&EE;G0@86=A:6YS="!S979E<F%L("AI;F-L=61I
M;F<@;W5R(&]W;BD@4E!#"B`@("!S97)V97)S+@H*<V5T7W!E<FUS+G-H"B`@
M("!3971S(&9I;&4@;W=N97)S:&EP(&%N9"!P97)M:7-S:6]N<R!O;B!T:&4@
M2&]R9&4@=')E92!F;W(@:&EG:"!S96-U<FET>2X*"G-E='5P+G!H<`H@("`@
M5&AE(&UA:6X@2&]R9&4@<V5T=7`@<V-R:7!T('=H:6-H(&%L;&]W<R!F;W(@
M82!S=&5P(&)Y('-T97`@<V5T=7`@;W(*("`@(')E8V]N9FEG=7)A=&EO;B!O
M9B!A($AO<F1E(&EN<W1A;&QA=&EO;BX*"G1E;7`M8VQE86YU<"YC<F]N"B`@
M("!!;B!E>&%M<&QE(&-R;VX@:F]B('-H96QL('-C<FEP="!W:&EC:"!W:6QL
M(&-L96%N('5P(&%N>2!T96UP;W)A<GD@9FEL97,*("`@('=H:6-H(&UA>2!G
M970@<W1R86YD960@8GD@2&]R9&4@=7-E<G,@:6X@=&AE('=E8B!S97)V97(G
M<R!T96UP;W)A<GD*("`@(&1I<F5C=&]R>2X*"G5P9&%T95]H;W)D92YS:`H@
M("`@1F%C:6QI=&%T97,@=&AE('5P9&%T:6YG(&%N9"]O<B!I;G-T86QL871I
M;VX@;V8@:&]R9&4@86YD(&ET<PH@("`@87!P;&EC871I;VYS+@H*;6EM95]M
M87!P:6YG+PH@("`@5&AI<R!S8W)I<'0@8V]N=F5R=',@86X@07!A8VAE+7-T
M>6QE(&UI;64N='EP97,@9FEL92!I;G1O(&$*("`@(&UI;64N;6%P<&EN9RYP
M:'`@9')I=F5R(&9I;&4@<W5I=&%B;&4@9F]R('5S92!W:71H($AO<F1E+B`@
M270@:7,@=7-E9G5L"B`@("!F;W(@<WEN8VEN9R!!<&%C:&4@=7!D871E<R!T
M;R!T:&5I<B!-24U%('1Y<&5S('=I=&@@2&]R9&4N"@H*1&%T86)A<V4@4V-R
M:7!T<PI^?GY^?GY^?GY^?GY^?GY^"D1A=&%B87-E('1A8FQE('-C:&5M87,@
M86YD(&%S<V]C:6%T960@=71I;&ET>2!S8W)I<'1S(&%R92!L;V-A=&5D(&EN
M('1H92!S<6PO"G-U8F1I<F5C=&]R>2X*"@I,1$%0(%-C:&5M87,*?GY^?GY^
M?GY^?GY^"DQ$05`@<V-H96UA<R!A<F4@;&]C871E9"!I;B!T:&4@;&1A<"\@
M<W5B9&ER96-T;W)Y+@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-C<FEP=',O8V]O:VEE7VQO9VEN+G!H<```````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V,3<`,3`T,3<S-C,P,38`,#(Q,C8P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O8V]O:VEE7VQO9VEN
M+G!H<"QV(#$N,BXR+C(@,C`P-B\P,2\P,2`R,3HR.3HP.2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!
M3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O;&EB+V)A<V4N<&AP)SL*"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D
M8V]N9ELG875T:"==6R=D<FEV97(G72D["@HO+R!#:&5C:R!F;W(@0T]/2TE%
M(&%U=&@N"FEF("AE;7!T>2@D7T-/3TM)15LG=7-E<B==*2!\?"!E;7!T>2@D
M7T-/3TM)15LG<&%S<W=O<F0G72D@?'P*("`@("$D875T:"T^875T:&5N=&EC
M871E*"1?0T]/2TE%6R=U<V5R)UTL(&%R<F%Y*"=P87-S=V]R9"<@/3X@)%]#
M3T]+245;)W!A<W-W;W)D)UTI*2D@>PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@
M)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G;&]G:6XN<&AP/VQO9V]U=%]R
M96%S;VX])R`N($%55$A?4D5!4T].7T)!1$Q/1TE.+"!T<G5E*2D["B`@("!E
M>&ET.PI]"@HD=7)L(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I.PII9B`H
M96UP='DH)'5R;"DI('L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5
M<FPH)VEN9&5X+G!H<"<L('1R=64I.PI]"FAE861E<B@G3&]C871I;VXZ("<@
M+B`D=7)L*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-C<FEP=',O8V]U;G1?<V5S<VEO;G,N<&AP````````
M````````````````````````````````````````````````````````,#$P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0Q-C``,3`T,3<S-C,P,38`
M,#(Q-C<T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",A+W5S<B]L;V-A;"]B:6XO<&AP"CP_<&AP"B\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O8V]U;G1?<V5S<VEO;G,N<&AP+'8@,2XU+C(N,B`R
M,#`V+S`S+S$P(#`P.C$T.C,P(&IA;B!%>'`@)`H@*@H@*B!4:&ES('-C<FEP
M="!C;W5N=',@=&AE(&YU;6)E<B!O9B!A8W1I=F4@875T:&5N=&EC871E9"!U
M<V5R('-E<W-I;VYS+@H@*@H@*B!#;VUM86YD(&QI;F4@;W!T:6]N<SH*("H@
M("`G+6PG("`@3&ES="!T:&4@=7-E<FYA;64@;V8@86-T:79E(&%U=&AE;G1I
M8V%T960@=7-E<G,*("H@("`G+6QL)R`@3&ES="!T:&4@=7-E<FYA;64@86YD
M(&QO9VEN('1I;64@;V8@86-T:79E(&%U=&AE;G1I8V%T960@=7-E<G,*("HO
M"@HO+R!.;R!A=71H+@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*
M"B\O($9I;F0@=&AE(&)A<V4@9FEL92!P871H(&]F($AO<F1E+@I`9&5F:6YE
M*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["@HO
M+R!$;R!#3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S971U<"!F:7)S="X*
M<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E
M<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO+R!-86ME('-U<F4@;F\@
M;VYE(')U;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A2&]R9&5?0TQ).CIR
M=6YN:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M
M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D('1H92!#3$D@96YV
M:7)O;FUE;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T:6UE(&QI;6ET+"!I
M;FET"B\O('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E7T-,23HZ:6YI="@I
M.PHD8VQI(#T@)FYE=R!(;W)D95]#3$DH*3L*"G)E<75I<F5?;VYC92!(3U)$
M15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@36%K92!S=7)E('1H97)E
M)W,@;F\@8V]M<')E<W-I;VXN("HO"D!O8E]E;F1?8VQE86XH*3L*"B1T>7!E
M(#T@(65M<'1Y*"1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T>7!E)UTI(#\*
M("`@("1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T>7!E)UT@.B`G8G5I;'1I
M;B<["@II9B`H)'1Y<&4@/3T@)V5X=&5R;F%L)RD@>PH@("`@2&]R9&4Z.F9A
M=&%L*%!%05(Z.G)A:7-E17)R;W(H)U-E<W-I;VX@8V]U;G1I;F<@:7,@;F]T
M('-U<'!O<G1E9"!I;B!T:&4@7"=E>'1E<FYA;%PG(%-E<W-I;VY(86YD;&5R
M(&%T('1H:7,@=&EM92XG*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D[
M"GT@96QS92!["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY(86YD
M;&5R+G!H<"<["B`@("`D7W-E<W-I;VY?:&%N9&QE<B`]("9397-S:6]N2&%N
M9&QE<CHZ<VEN9VQE=&]N*"1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T>7!E
M)UTI.PH@("`@:68@*&ES7V$H)%]S97-S:6]N7VAA;F1L97(L("=014%27T5R
M<F]R)RDI('L*("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*")(;W)D92!I<R!U;F%B;&4@=&\@;&]A9"!S97-S:6]N(&AA
M;F1L97(@;V8@='EP92!<(B5S7"(N(BP@)'1Y<&4I*2P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!F86QS92D["B`@("!]"@H@("`@:68@*"1A<F=C(#P@,B!\?"`H
M)&%R9W9;,5T@(3T@)RUL)R`F)B`D87)G=ELQ72`A/2`G+6QL)RDI('L*("`@
M("`@("`D8V]U;G0@/2`D7W-E<W-I;VY?:&%N9&QE<BT^8V]U;G1!=71H96YT
M:6-A=&5D57-E<G,H*3L*("`@("`@("!I9B`H:7-?82@D8V]U;G0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1C;W5N="P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D["B`@("`@("`@?0H*("`@("`@
M("`D8VQI+3YW<FET96QN*"1C;W5N="D["B`@("!](&5L<V4@>PH@("`@("`@
M("1U<V5R<R`]("1?<V5S<VEO;E]H86YD;&5R+3YL:7-T075T:&5N=&EC871E
M9%5S97)S*"1A<F=V6S%=(#T]("<M;&PG*3L*("`@("`@("!I9B`H:7-?82@D
M=7-E<G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A
M=&%L*"1U<V5R<RP@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D["B`@("`@
M("`@?0H*("`@("`@("!F;W)E86-H("@D=7-E<G,@87,@)'5S97(I('L*("`@
M("`@("`@("`@)&-L:2T^=W)I=&5L;B@D=7-E<BD["B`@("`@("`@?0H@("`@
M?0I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O8W)E871E+7-Y;6QI
M;FMS+G!H<```````````````````````````````````````````````````
M````````````,#$P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<S-C(`
M,3`T,3<S-C,P,38`,#(Q-S0P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H
M<`H\/W!H<`HO*BH*("H@5&AI<R!S8W)I<'0@8W)E871E<R!S;V9T;&EN:W,@
M=&\@=&AE(&QI8G)A<GD@9FEL97,@>6]U(')E=')I979E9"!F<F]M"B`J('1H
M92!#5E,@(F9R86UE=V]R:R(@;6]D=6QE+@H@*@H@*B!)="!C<F5A=&5S('1H
M92!S86UE(&1I<F5C=&]R>2!S=')U8W1U<F4@=&AE('!A8VMA9V5S('=O=6QD
M(&AA=F4@:68@=&AE>0H@*B!W97)E(&EN<W1A;&QE9"!W:71H(")P96%R(&EN
M<W1A;&P@<&%C:V%G92YX;6PB+@H@*B!&;W(@8W)E871I;F<@=&AI<R!S=')U
M8W1U<F4@:70@=7-E<R!T:&4@:6YF;W)M871I;VX@9VEV96X@:6X@=&AE"B`J
M('!A8VMA9V4N>&UL(&9I;&5S(&EN<VED92!E86-H('!A8VMA9V4@9&ER96-T
M;W)Y+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O8W)E871E+7-Y;6QI
M;FMS+G!H<"QV(#$N,30N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`Y(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,B!7;VQF<F%M($MR:65S:6YG(#QW
M;VQF<F%M0&MR:65S:6YG+F1E/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N
M9&4^"B`J($!A=71H;W(@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H@0'-I;F-E($AO<F1E(#,N,`H@*B\*"B\O($9I;F0@=&AE(&)A<V4@9FEL
M92!P871H(&]F($AO<F1E+@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN)RD["@HO+R!#;VYF:6=U<F%T:6]N+@HO+R!%
M;G1E<B!D:7)E8W1O<FEE<R!W:71H;W5T('1R86EL:6YG('-L87-H97,N"@HO
M+R!4:&4@9&ER96-T;W)Y('=I=&@@=&AE($-64R!C:&5C:V]U="X*)'-R8T1I
M<B`]($A/4D1%7T)!4T4@+B`G+V9R86UE=V]R:R<["@HO+R!4:&4@9&ER96-T
M;W)Y('=H97)E('1H92!S;V9T;&EN:W,@87)E(&-R96%T960N"B\O(%1H:7,@
M:7,@86QS;R!T:&4@9&ER96-T;W)Y('=H:6-H('EO=2!S:&]U;&0@<'5T(&EN
M('EO=7(@:6YC;'5D92!P871H"B\O(&%F=&5R(&-R96%T:6YG('1H92!L:6YK
M<RX*)&1E<W1$:7(@/2!(3U)$15]"05-%("X@)R]L:6)S)SL*"B1C;W!Y(#T@
M9F%L<V4["@II9B`H:7-S970H)&%R9W8I*2!["B`@("`O*B!'970@<FED(&]F
M('1H92!F:7)S="!A<F<@=VAI8V@@:7,@=&AE('-C<FEP="!N86UE+B`J+PH@
M("`@87)R87E?<VAI9G0H)&%R9W8I.PH@("`@=VAI;&4@*"1A<F<@/2!A<G)A
M>5]S:&EF="@D87)G=BDI('L*("`@("`@("!I9B`H)&%R9R`]/2`G+2UH96QP
M)RD@>PH@("`@("`@("`@("!P<FEN=%]U<V%G92@I.PH@("`@("`@('T@96QS
M96EF("@D87)G(#T]("<M+6-O<'DG*2!["B`@("`@("`@("`@("1C;W!Y(#T@
M=')U93L*("`@("`@("!](&5L<V5I9B`H<W1R<W1R*"1A<F<L("<M+7-R8R<I
M*2!["B`@("`@("`@("`@(&QI<W0H+"1S<F-$:7(I(#T@97AP;&]D92@G/2<L
M("1A<F<I.PH@("`@("`@('T@96QS96EF("AS=')S='(H)&%R9RP@)RTM9&5S
M="<I*2!["B`@("`@("`@("`@(&QI<W0H+"1D97-T1&ER*2`](&5X<&QO9&4H
M)STG+"`D87)G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN
M=%]U<V%G92@B56YR96-O9VYI<V5D(&]P=&EO;B`D87)G(BD["B`@("`@("`@
M?0H@("`@?0I]"@HO+R!$;R!#3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S
M971U<"!F:7)S="X*<F5Q=6ER95]O;F-E("1S<F-$:7(@+B`G+T-,22]#3$DN
M<&AP)SL*"B\O($UA:V4@<W5R92!N;R!O;F4@<G5N<R!T:&ES(&9R;VT@=&AE
M('=E8BX*:68@*"%(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@
M(&5X:70H(DUU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN95QN(BD[
M"GT*"B\O($QO860@=&AE($-,22!E;G9I<F]N;65N="`M(&UA:V4@<W5R92!T
M:&5R92=S(&YO('1I;64@;&EM:70L(&EN:70*+R\@<V]M92!V87)I86)L97,L
M(&5T8RX*2&]R9&5?0TQ).CII;FET*"D["@I`:6YC;'5D95]O;F-E("=4<F5E
M+U1R964N<&AP)SL*:68@*"%C;&%S<U]E>&ES=',H)U1R964G*2D@>PH@("`@
M97AI="@B66]U(&YE960@=&AE(%!%05(@)U1R964G('!A8VMA9V4@:6YS=&%L
M;&5D7&XB*3L*?0H*)&QI;FME<B`]("9N97<@3&EN:V5R*"1C;W!Y*3L*:68@
M*"1H86YD;&4@/2!O<&5N9&ER*"1S<F-$:7(I*2!["B`@("!W:&EL92`H)&9I
M;&4@/2!R96%D9&ER*"1H86YD;&4I*2!["B`@("`@("`@:68@*"1F:6QE("$]
M("<N)R`F)@H@("`@("`@("`@("`D9FEL92`A/2`G+BXG("8F"B`@("`@("`@
M("`@("1F:6QE("$]("=#5E,G("8F"B`@("`@("`@("`@(&ES7V1I<B@B)'-R
M8T1I<B\D9FEL92(I*2!["B`@("`@("`@("`@("1L:6YK97(M/G!R;V-E<W,H
M(B1S<F-$:7(O)&9I;&4B+"`D9&5S=$1I<BD["B`@("`@("`@?0H@("`@?0H@
M("`@8VQO<V5D:7(H)&AA;F1L92D["B!]"@IE8VAO(")<;B(["@HO+R`@<&]S
M<VEB;&4@>&UL+7-T<G5C=',*+R\@(#QF:6QE;&ES=#X*+R\@("`@("`\9&ER
M(&YA;64](B\B(&)A<V5I;G-T86QL9&ER/2)834PB/@HO+R`@("`@("`@("`\
M9FEL92!R;VQE/2)P:'`B/E!A<G-E<BYP:'`\+V9I;&4^"B\O("`@("`@("`@
M(#QF:6QE(')O;&4](G!H<"(@;F%M93TB4E-3+G!H<"(@+SX*+R\@("`@("`\
M+V1I<CX*+R\@(#PO9FEL96QI<W0^"B\O"B\O("`\9FEL96QI<W0^"B\O("`@
M("`@/&9I;&4@<F]L93TB<&AP(B!B87-E:6YS=&%L;&1I<CTB+R(^1$(N<&AP
M/"]F:6QE/@HO+R`@("`@(#QD:7(@;F%M93TB1$(B/@HO+R`@("`@("`@("`\
M9FEL92!R;VQE/2)P:'`B/F-O;6UO;BYP:'`\+V9I;&4^"B\O("`@("`@/"]D
M:7(^"B\O("`\+V9I;&5L:7-T/@IC;&%S<R!,:6YK97(@>PH*("`@('9A<B`D
M7W-R8T1I<CL*"B`@("!V87(@)%]B87-E26YS=&%L;$1I<CL*"B`@("!V87(@
M)%]F:6QE<F]L97,@/2!A<G)A>2@G<&AP)RD["@H@("`@=F%R("1?<F]L93L*
M"B`@("!V87(@)%]C;W!Y.PH*("`@(&9U;F-T:6]N($QI;FME<B@D8V]P>2`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]P>2`]("1C;W!Y.PH@
M("`@?0H*("`@(&9U;F-T:6]N('!R;V-E<W,H)'-R8T1I<BP@)&1E<W1$:7(I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]S<F-$:7(@/2`D<W)C1&ER.PH@("`@
M("`@("1P86-K86=E1FEL92`]("1T:&ES+3Y?<W)C1&ER("X@)R]P86-K86=E
M+GAM;"<["B`@("`@("`@)&-L:2`]("9(;W)D95]#3$DZ.G-I;F=L971O;B@I
M.PH*("`@("`@("!I9B`H(6ES7V9I;&4H)'!A8VMA9V5&:6QE*2D@>PH@("`@
M("`@("`@("`D8VQI+3YM97-S86=E*"=.;R!P86-K86=E+GAM;"!I;B`G("X@
M)'1H:7,M/E]S<F-$:7(L("=C;&DN=V%R;FEN9R<I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=')E92`](%1R964Z
M.G-E='5P365M;W)Y*"=834PG+"`D<&%C:V%G949I;&4I.PH@("`@("`@("1T
M<F5E+3YS971U<"@I.PH*("`@("`@("`O+R!R96%D('!A8VMA9V4@;F%M90H@
M("`@("`@("1P86-K86=E3F%M92`]('1R:6TH)'1R964M/F=E=$5L96UE;G1#
M;VYT96YT*"<O<&%C:V%G92]N86UE)RP@)V-D871A)RDI.PH@("`@("`@("1C
M;&DM/G=R:71E;&XH(E!R;V-E<W-I;F<@<&%C:V%G92`D<&%C:V%G94YA;64N
M(BD["@H@("`@("`@("\O(&QO;VL@9F]R(&9I;&5L:7-T(&EN("<O<&%C:V%G
M92]R96QE87-E+V9I;&5L:7-T)PH@("`@("`@("1F:6QE;&ES="`]("1T<F5E
M+3YG971%;&5M96YT0GE0871H*"<O<&%C:V%G92]R96QE87-E+V9I;&5L:7-T
M)RD["@H@("`@("`@(&EF("@D9FEL96QI<W0I('L*("`@("`@("`@("`@+R\@
M9&\@=&AI<R!B971T97(L(&UA:V4@=&AE('1R964@8VQA<W,@=V]R:R!C87-E
M(&EN<V5N<VET:79E"B`@("`@("`@("`@("1B87-E26YS=&%L;$1I<B`]("1F
M:6QE;&ES=%LG8VAI;&0G75LG871T<FEB=71E<R==6R=B87-E:6YS=&%L;&1I
M<B==.PH*("`@("`@("`@("`@)'1H:7,M/E]B87-E26YS=&%L;$1I<B`]("1D
M97-T1&ER.PH@("`@("`@("`@("!I9B`H)&)A<V5);G-T86QL1&ER("$]("<O
M)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B87-E26YS=&%L;$1I<B`N
M/2`G+R<@+B`D8F%S94EN<W1A;&Q$:7(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]B87-E26YS=&%L;$1I<B`]('!R96=?<F5P;&%C92@G
M?"\K?"<L("<O)RP@)'1H:7,M/E]B87-E26YS=&%L;$1I<BD["@H@("`@("`@
M("`@("!I9B`H(6ES7V1I<B@D=&AI<RT^7V)A<V5);G-T86QL1&ER*2D@>PH@
M("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL*("`@
M("`@("`@("`@("`@(%-Y<W1E;3HZ;6MD:7(H)RUP("<@+B`D=&AI<RT^7V)A
M<V5);G-T86QL1&ER*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H
M:7,M/E]H86YD;&5&:6QE;&ES=%1A9R@D9FEL96QI<W0I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1C;&DM/FUE<W-A9V4H)TYO(&9I;&5L:7-T
M('1A9R!F;W5N9"!I;G-I9&4Z("<@+B`D<&%C:V%G949I;&4L("=C;&DN=V%R
M;FEN9R<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?:&%N9&QE
M1FEL96QI<W1486<H)&5L96UE;G0L("1C=7)$:7(@/2`G)RD*("`@('L*("`@
M("`@("!F;W)E86-H("@D96QE;65N=%LG8VAI;&1R96XG72!A<R`D8VAI;&0I
M('L*("`@("`@("`@("`@<W=I=&-H("@D8VAI;&1;)VYA;64G72D@>PH@("`@
M("`@("`@("!C87-E("=F:6QE)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:&%N9&QE1FEL951A9R@D8VAI;&0L("1C=7)$:7(I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)V1I<B<Z"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VAA;F1L941I<E1A9R@D8VAI;&0L("1C=7)$:7(I.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`D8VQI(#T@)DAO<F1E7T-,23HZ<VEN9VQE=&]N*"D[
M"B`@("`@("`@("`@("`@("`D8VQI+3YM97-S86=E*"=';W0@;F\@:&%N9&QE
M<B!F;W(@=&%G.B`G("X@)&-H:6QD6R=N86UE)UTL("=C;&DM=V%R;FEN9R<I
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@?0H*("`@(&9U;F-T:6]N(%]H86YD;&5$:7)486<H)&5L96UE
M;G0L("1C=7)$:7(I"B`@("!["B`@("`@("`@:68@*"1E;&5M96YT6R=A='1R
M:6)U=&5S)UU;)VYA;64G72`A/2`G+R<I('L*("`@("`@("`@("`@:68@*'-U
M8G-T<B@D8W5R1&ER+"`M,2D@(3T@)R\G*2!["B`@("`@("`@("`@("`@("`D
M8W5R1&ER(#T@)&-U<D1I<B`N("<O)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D8W5R1&ER(#T@)&-U<D1I<B`N("1E;&5M96YT6R=A='1R:6)U=&5S
M)UU;)VYA;64G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&5L
M96UE;G1;)V%T=')I8G5T97,G75LG<F]L92==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W)O;&4@/2`D96QE;65N=%LG871T<FEB=71E<R==6R=R;VQE)UT[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7V1I<B@D=&AI<RT^7V)A<V5)
M;G-T86QL1&ER("X@)&-U<D1I<BDI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=3>7-T96TN<&AP)SL*("`@("`@("`@("`@4WES=&5M.CIM:V1I<B@G
M+7`@)R`N("1T:&ES+3Y?8F%S94EN<W1A;&Q$:7(@+B`D8W5R1&ER*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?:&%N9&QE1FEL96QI<W1486<H)&5L
M96UE;G0L("1C=7)$:7(I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]H86YD;&5&
M:6QE5&%G*"1E;&5M96YT+"`D9&ER*0H@("`@>PH@("`@("`@(&EF("@A96UP
M='DH)&5L96UE;G1;)V%T=')I8G5T97,G75LG<F]L92==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W)O;&4@/2`D96QE;65N=%LG871T<FEB=71E<R==6R=R
M;VQE)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1T:&ES
M+3Y?<F]L92P@)'1H:7,M/E]F:6QE<F]L97,I*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&5L96UE;G1;
M)V%T=')I8G5T97,G75LG;F%M92==*2D@>PH@("`@("`@("`@("`D9FEL96YA
M;64@/2`D96QE;65N=%LG871T<FEB=71E<R==6R=N86UE)UT["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&9I;&5N86UE(#T@)&5L96UE;G1;)V-D
M871A)UT["B`@("`@("`@?0H@("`@("`@("1F:6QE;F%M92`]('1R:6TH)&9I
M;&5N86UE*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8V]P>2D@>PH@("`@("`@
M("`@("`D8VUD(#T@(F-P('LD=&AI<RT^7W-R8T1I<GTD9&ER+R1F:6QE;F%M
M92![)'1H:7,M/E]B87-E26YS=&%L;$1I<GTD9&ER+R1F:6QE;F%M92(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A<F5N="`]("1T:&ES+3Y?
M9FEN9$-O;6UO;E!A<F5N="@D=&AI<RT^7W-R8T1I<B`N("1D:7(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]B87-E26YS=&%L;$1I<B`N("1D:7(I.PH@("`@("`@("`@("`D9&ER
M<R`]('-U8G-T<E]C;W5N="AS=6)S='(H)'1H:7,M/E]B87-E26YS=&%L;$1I
M<B`N("1D:7(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')L96XH)'!A<F5N="DI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G+R<I.PH@("`@("`@("`@("`D<W)C(#T@<W1R7W)E<&5A
M="@G+BXO)RP@)&1I<G,I("X*("`@("`@("`@("`@("`@('-U8G-T<B@D=&AI
M<RT^7W-R8T1I<B`N("1D:7(L('-T<FQE;B@D<&%R96YT*2`K(#$I.PH@("`@
M("`@("`@("`D8VUD(#T@(FQN("US9B`D<W)C+R1F:6QE;F%M92![)'1H:7,M
M/E]B87-E26YS=&%L;$1I<GTD9&ER+R1F:6QE;F%M92(["B`@("`@("`@?0H@
M("`@("`@(&5X96,H)&-M9"D["B`@("!]"@H@("`@9G5N8W1I;VX@7V9I;F1#
M;VUM;VY087)E;G0H)&$L("1B*0H@("`@>PH@("`@("`@(&9O<B`H)&-O;6UO
M;B`]("<G+"`D;&%S='!O<R`](#`L("1P;W,@/2!S=')P;W,H)&$L("<O)RP@
M,2D["B`@("`@("`@("`@("`D<&]S("$]/2!F86QS92`F)B!S=')P;W,H)&(L
M('-U8G-T<B@D82P@,"P@)'!O<RDI(#T]/2`P.PH@("`@("`@("`@("`@)'!O
M<R`]('-T<G!O<R@D82P@)R\G+"`D<&]S("L@,2DI('L*("`@("`@("`@("`@
M)&-O;6UO;B`N/2!S=6)S='(H)&$L("1L87-T<&]S+"`D<&]S("T@)&QA<W1P
M;W,I.PH@("`@("`@("`@("`D;&%S='!O<R`]("1P;W,["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D8V]M;6]N.PH@("`@?0H*?0H*9G5N8W1I;VX@<')I
M;G1?=7-A9V4H)&UE<W-A9V4@/2`G)RD@>PH*("`@(&EF("@A96UP='DH)&UE
M<W-A9V4I*2!["B`@("`@("`@<')I;G0@(F-R96%T92US>6UL:6YK<RYP:'`Z
M("1M97-S86=E7&Y<;B(["B`@("!]"@H@("`@<')I;G0@/#P\55-!1T4*57-A
M9V4Z(&-R96%T92US>6UL:6YK<RYP:'`@6T]05$E/3ET*"E!O<W-I8FQE(&]P
M=&EO;G,Z"B`@+2UC;W!Y("`@("`@("!$;R!N;W0@8W)E871E('-Y;6)O;&EC
M(&QI;FMS+"!B=70@86-T=6%L;'D@8V]P>2!T:&4@;&EB<F%R:65S+@H@("TM
M<W)C/41)4B`@("`@5&AE('-O=7)C92!D:7)E8W1O<GD@9F]R('1H92!F<F%M
M97=O<FL@;&EB<F%R:65S+@H@("TM9&5S=#U$25(@("`@5&AE(&1E<W1I;F%T
M:6]N(&1I<F5C=&]R>2!F;W(@=&AE(&9R86UE=V]R:R!L:6)R87)I97,N"@I5
M4T%'13L*("`@(&5X:70["GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]C
M;VYF:6<`````````````````````````````````````````````````````
M`````````````````````````````````````#`Q,C`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-#$W,S8S,#$V`#`R-#`R,P`@,B]U<W(O
M;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4`````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VEN9&5X+G!H<```````````````````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R-C,`,3`T,3<S-C,P
M,38`,#$V,C,W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+VEN9&5X+G!H<"QV
M(#(N,3`U+C0N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C`T(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A
M<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I
M;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RDI.PHD:&]R9&5?8V]N9FEG=7)E9"`]("A`
M9FEL95]E>&ES=',H2$]21$5?0D%312`N("<O8V]N9FEG+V-O;F8N<&AP)RD@
M)B8*("`@("`@("`@("`@("`@("`@("`@0&9I;&5?97AI<W1S*$A/4D1%7T)!
M4T4@+B`G+V-O;F9I9R]M:6UE7V1R:79E<G,N<&AP)RD@)B8*("`@("`@("`@
M("`@("`@("`@("`@0&9I;&5?97AI<W1S*$A/4D1%7T)!4T4@+B`G+V-O;F9I
M9R]N;',N<&AP)RD@)B8*("`@("`@("`@("`@("`@("`@("`@0&9I;&5?97AI
M<W1S*$A/4D1%7T)!4T4@+B`G+V-O;F9I9R]P<F5F<RYP:'`G*2`F)@H@("`@
M("`@("`@("`@("`@("`@("!`9FEL95]E>&ES=',H2$]21$5?0D%312`N("<O
M8V]N9FEG+W)E9VES=')Y+G!H<"<I*3L*"FEF("@A)&AO<F1E7V-O;F9I9W5R
M960I('L*("`@(')E<75I<F4@2$]21$5?0D%312`N("<O;&EB+U1E<W0N<&AP
M)SL*("`@($AO<F1E7U1E<W0Z.F-O;F9I9T9I;&5S36ES<VEN9R@G2&]R9&4G
M+"!(3U)$15]"05-%+"`G<')E9G,N<&AP)RP*("`@("`@("!A<G)A>2@G8V]N
M9BYP:'`G(#T^("=4:&ES(&ES('1H92!M86EN($AO<F1E(&-O;F9I9W5R871I
M;VX@9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD(&)A<VEC(&ET96US('1H
M870@87!P;'D@=&\@=&AE(&-O<F4@9G)A;65W;W)K(&%N9"!A;&P@2&]R9&4@
M87!P;&EC871I;VYS+B<L"B`@("`@("`@("`@("`@)VUI;65?9')I=F5R<RYP
M:'`G(#T^("=4:&ES(&9I;&4@8V]N=')O;',@=&AE(&=L;V)A;"!S970@;V8@
M34E-12!D<FEV97)S(&9O<B!T:&4@2&]R9&4@9G)A;65W;W)K+"!A;&QO=VEN
M9R!A<'!L:6-A=&EO;G,@=&\@;6%K92!U<V4@;V8@<')O9W)A;7,@<W5C:"!A
M<R!E;G-C<FEP="!O<B!M<W=O<F1V:65W('1O(')E;F1E<B!C;VYT96YT(&EN
M=&\@2%1-3"!F;W(@=FEE=VEN9R!I;B!A(&)R;W=S97(N)RP*("`@("`@("`@
M("`@("`G;FQS+G!H<"<@/3X@)U1H:7,@9FEL92!P<F]V:61E<R!L;V-A;&ES
M871I;VX@<W5P<&]R="!F;W(@=&AE($AO<F1E(&9R86UE=V]R:RXG+`H@("`@
M("`@("`@("`@("=R96=I<W1R>2YP:'`G(#T^("=4:&4@<F5G:7-T<GD@:7,@
M:&]W($AO<F1E(&%P<&QI8V%T:6]N<R!F:6YD(&]U="!H;W<@=&\@=&%L:R!T
M;R!E86-H(&]T:&5R+B!9;W4@<VAO=6QD(&QI<W0@86YY(&EN<W1A;&QE9"!(
M;W)D92!A<'!L:6-A=&EO;G,@=&AA="!Y;W4@:&%V92!H97)E+B<I*3L*?0H*
M<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@II
M9B`H)&)R;W=S97(M/FES36]B:6QE*"DI('L*("`@(')E<75I<F4@2$]21$5?
M0D%312`N("<O<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`G.PH@("`@97AI
M=#L*?0H*)&UA:6Y?<&%G92`](%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*3L*
M:68@*"$D;6%I;E]P86=E*2!["B`@("`D;6%I;E]P86=E(#T@2&]R9&4Z.FEN
M:71I86Q086=E*"D["GT*"FEF("@A571I;#HZ9V5T1F]R;41A=&$H)V9R86UE
M<V5T7VQO861E9"<I("8F"B`@("`H)&-O;F9;)VUE;G4G75LG86QW87ES)UT@
M?'P*("`@("`H075T:#HZ9V5T075T:"@I("8F("1P<F5F<RT^9V5T5F%L=64H
M)W-H;W=?<VED96)A<B<I*2DI('L*("`@(&EF("@D8G)O=W-E<BT^:&%S475I
M<FLH)W-C<F]L;&)A<E]I;E]W87DG*2D@>PH@("`@("`@("1S8W)O;&QB87(@
M/2`G>65S)SL*("`@('T@96QS92!["B`@("`@("`@)'-C<F]L;&)A<B`]("=A
M=71O)SL*("`@('T*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]I
M;F1E>"]F<F%M97-?:6YD97@N:6YC)SL*?2!E;'-E('L*("`@(&AE861E<B@G
M3&]C871I;VXZ("<@+B`D;6%I;E]P86=E*3L*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO9VEN+G!H<```````````
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38Q
M,C<`,3`T,3<S-C,P,38`,#$V,C0R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+VQO9VEN+G!H<"QV(#(N,3<U+C(N,3$@,C`P-B\P,2\Q-B`Q-3HU-SHU,R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE
M*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N
M8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4V5C<F5T
M+G!H<"<["@HO*B!);FET:6%L:7IE('1H92!!=71H(&-R961E;G1I86QS(&ME
M>2X@*B\*4V5C<F5T.CIS971+97DH)V%U=&@G*3L*"B\J($=E="!A;B!!=71H
M(&]B:F5C="X@*B\*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A
M=71H)UU;)V1R:79E<B==*3L*:68@*&ES7V$H)&%U=&@L("=014%27T5R<F]R
M)RDI('L*("`@($AO<F1E.CIF871A;"@D875T:"P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*?0H*+RH@1V5T('!A<F%M971E<G,N("HO"B1L;V=O=71?<F5A<V]N
M(#T@)&%U=&@M/F=E=$QO9V]U=%)E87-O;B@I.PHD=7)L7W!A<F%M(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W5R;"<I.PHD:65?=F5R<VEO;B`](%5T:6PZ.F=E
M=$9O<FU$871A*"=I95]V97)S:6]N)RD["@II9B`H)&QO9V]U=%]R96%S;VXI
M('L*("`@("1L;V=I;E]S8W)E96X@/2`D875T:"T^9V5T3&]G:6Y38W)E96XH
M*3L*("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G;F]S:61E8F%R)RD@)B8*
M("`@("`@("!I<W-E="@D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTI*2!["B`@
M("`@("`@)'5R;"`]($%U=&@Z.F%D9$QO9V]U=%!A<F%M971E<G,H)&QO9VEN
M7W-C<F5E;BD["B`@("`@("`@:68@*"1U<FQ?<&%R86TI('L*("`@("`@("`@
M("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G=7)L)RP@)'5R
M;%]P87)A;2D["B`@("`@("`@?0H@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H)W=I;F1O=RYP87)E;G0N;&]C871I;VXN:')E9B`](%PG)R`N("1U<FP@
M+B`G7"<[)RP@)VIA=F%S8W)I<'0G*3L*("`@("`@("!E8VAO("<\:'1M;#X\
M8F]D>3XG("X@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YN;W1I9GDH87)R
M87DH)VQI<W1E;F5R<R<@/3X@87)R87DH)VIA=F%S8W)I<'0G*2DI("X@)SPO
M8F]D>3X\+VAT;6P^)SL*("`@("`@("!E>&ET.PH@("`@?0H*("`@(&EF("A5
M=&EL.CIR96UO=F5087)A;65T97(H)&QO9VEN7W-C<F5E;BP@87)R87DH)W5R
M;"<L("=N;V-A8VAE)RDI("$]"B`@("`@("`@571I;#HZ<F5M;W9E4&%R86UE
M=&5R*$AO<F1E.CIS96QF57)L*&9A;'-E+"!F86QS92P@=')U92DL(&%R<F%Y
M*"=U<FPG+"`G;F]C86-H92<I*2D@>PH@("`@("`@("1U<FP@/2!!=71H.CIA
M9&1,;V=O=71087)A;65T97)S*"1L;V=I;E]S8W)E96XI.PH@("`@("`@(&EF
M("@D=7)L7W!A<F%M*2!["B`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H)'5R;"P@)W5R;"<L("1U<FQ?<&%R86TI.PH@("`@("`@('T*
M("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@
M97AI=#L*("`@('T*"B`@("`D;&%N9W5A9V4@/2!I<W-E="@D<')E9G,I(#\@
M)'!R969S+3YG971686QU92@G;&%N9W5A9V4G*2`Z($Y,4SHZ<V5L96-T*"D[
M"@H@("`@)&5N=')Y(#T@<W!R:6YT9B@G57-E<B`E<R!;)7-=(&QO9V=E9"!O
M=70@;V8@2&]R9&4G+`H@("`@("`@("`@("`@("`@("`@("!!=71H.CIG971!
M=71H*"DL("1?4T525D526R=214U/5$5?041$4B==*3L*("`@($AO<F1E.CIL
M;V=-97-S86=E*"1E;G1R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U].3U1)0T4I.PH@("`@075T:#HZ8VQE87)!=71H*"D["B`@("!`<V5S<VEO
M;E]D97-T<F]Y*"D["@H@("`@+RH@4F5D:7)E8W0@=&AE('5S97(@;VX@;&]G
M;W5T(&EF(')E9&ER96-T:6]N(&ES(&5N86)L960N("HO"B`@("!I9B`H(65M
M<'1Y*"1C;VYF6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO9V]U="==*2D@>PH@
M("`@("`@("1L;V=O=71?=7)L(#T@)&-O;F9;)V%U=&@G75LG<F5D:7)E8W1?
M;VY?;&]G;W5T)UT["B`@("`@("`@:68@*"%I<W-E="@D7T-/3TM)15MS97-S
M:6]N7VYA;64H*5TI*2!["B`@("`@("`@("`@("1L;V=O=71?=7)L(#T@571I
M;#HZ861D4&%R86UE=&5R*"1L;V=O=71?=7)L+"!S97-S:6]N7VYA;64H*2P@
M<V5S<VEO;E]I9"@I*3L*("`@("`@("!]"B`@("`@("`@:&5A9&5R*"=,;V-A
M=&EO;CH@)R`N("1L;V=O=71?=7)L*3L*("`@("`@("!E>&ET.PH@("`@?0H*
M("`@($AO<F1E.CIS971U<%-E<W-I;VY(86YD;&5R*"D["B`@("!`<V5S<VEO
M;E]S=&%R="@I.PH*("`@($Y,4SHZ<V5T3&%N9R@D;&%N9W5A9V4I.PH*("`@
M("\J($AO;VL@=&\@<')E<V5L96-T('1H92!C;W)R96-T(&QA;F=U86=E(&EN
M('1H92!W:61G970N("HO"B`@("`D7T=%5%LG;F5W7VQA;F<G72`]("1L86YG
M=6%G93L*?0H*:68@*&ES<V5T*"1?4$]35%LG:&]R9&5?=7-E<B==*2`F)B!I
M<W-E="@D7U!/4U1;)VAO<F1E7W!A<W,G72DI('L*("`@("\J($1E<W1R;WD@
M86YY(&5X:7-T:6YG('-E<W-I;VX@;VX@;&]G:6X@86YD(&UA:V4@<W5R92!T
M;R!U<V4@80H@("`@("H@;F5W('-E<W-I;VX@240L('1O(&%V;VED('-E<W-I
M;VX@9FEX871I;VX@:7-S=65S+B`J+PH@("`@2&]R9&4Z.F=E=$-L96%N4V5S
M<VEO;B@I.PH@("`@:68@*"1A=71H+3YA=71H96YT:6-A=&4H571I;#HZ9V5T
M4&]S="@G:&]R9&5?=7-E<B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W!A<W-W;W)D)R`]/B!5=&EL.CIG9710;W-T*"=H;W)D95]P
M87-S)RDI*2D@>PH@("`@("`@("1E;G1R>2`]('-P<FEN=&8H)TQO9VEN('-U
M8V-E<W,@9F]R("5S(%LE<UT@=&\@2&]R9&4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@075T:#HZ9V5T075T:"@I+"`D7U-%4E9%4ELG4D5-3U1%7T%$
M1%(G72D["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&5N=')Y+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TY/5$E#12D["@H@("`@("`@(&EF
M("@D:65?=F5R<VEO;BD@>PH@("`@("`@("`@("`D8G)O=W-E<BT^<V5T2456
M97)S:6]N*"1I95]V97)S:6]N*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=7)L7W!A<F%M*2!["B`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*%5T
M:6PZ.G)E;6]V95!A<F%M971E<B@D=7)L7W!A<F%M+"!S97-S:6]N7VYA;64H
M*2DL('1R=64I.PH@("`@("`@("`@("`D:&]R9&5?=7)L(#T@)')E9VES=')Y
M+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O:6YD97@N<&AP)SL*("`@
M("`@("`@("`@)&AO<F1E7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D:&]R
M9&5?=7)L+"`G=7)L)RP@)'5R;"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&AO<F1E7W5R;"`]($AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H
M)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O:6YD97@N<&AP)RD["B`@("`@("`@
M?0H*("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1H;W)D
M95]U<FPL('1R=64I.PH@("`@("`@(&EF("@D8G)O=W-E<BT^:7-"<F]W<V5R
M*"=M<VEE)RD@)B8*("`@("`@("`@("`@)&-O;F9;)W5S95]S<VPG72`]/2`S
M("8F"B`@("`@("`@("`@('-T<FQE;B@D=7)L*2`\(#$V,"D@>PH@("`@("`@
M("`@("!H96%D97(H)U)E9G)E<V@Z(#`[(%523#TG("X@)'5R;"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M("1U<FPI.PH@("`@("`@('T*("`@("`@("!E>&ET.PH@("`@?2!E;'-E('L*
M("`@("`@("`D96YT<GD@/2!S<')I;G1F*"=&04E,140@3$]'24X@9F]R("5S
M(%LE<UT@=&\@2&]R9&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@571I
M;#HZ9V5T1F]R;41A=&$H)VAO<F1E7W5S97(G*2P@)%]315)615);)U)%34]4
M15]!1$12)UTI.PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1E;G1R>2P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@(&EF
M("@D8V]N9ELG;65N=2==6R=A;'=A>7,G72D@>PH@("`@("`@("`@("`D;6%I
M;E]P86=E(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*"DL
M("=R96%S;VXG+"`D875T:"T^9V5T3&]G;W5T4F5A<V]N4W1R:6YG*"DI.PH@
M("`@("`@("`@("!I9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=S8W)O;&QB87)?
M:6Y?=V%Y)RDI('L*("`@("`@("`@("`@("`@("1S8W)O;&QB87(@/2`G>65S
M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S8W)O
M;&QB87(@/2`G875T;R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+VEN9&5X+V9R86UE<U]I;F1E>"YI
M;F,G.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*("`@('T*?0H*:68@
M*$%U=&@Z.F=E=$%U=&@H*2D@>PH@("`@:68@*"1B<F]W<V5R+3YI<TUO8FEL
M92@I*2!["B`@("`@("`@)'5R;"`]("=S97)V:6-E<R]P;W)T86PO;6]B:6QE
M+G!H<"<["B`@("!](&5L<V4@>PH@("`@("`@("1U<FP@/2`G<V5R=FEC97,O
M<&]R=&%L+VEN9&5X+G!H<"<["B`@("!]"B`@("!R97%U:7)E($A/4D1%7T)!
M4T4@+B`G+R<@+B`D=7)L.PH@("`@97AI=#L*?0H*+RH@5')Y('1R86YS<&%R
M96YT(&%U=&AE;G1I8V%T:6]N+B`J+PII9B`H075T:#HZ:7-!=71H96YT:6-A
M=&5D*"DI('L*("`@(')E<75I<F4@2$]21$5?0D%312`N("<O:6YD97@N<&AP
M)SL*("`@(&5X:70["GT*"B\J(%)E9&ER96-T('1H92!U<V5R(&EF(&%N(&%L
M=&5R;F%T92!L;V=I;B!P86=E(&AA<R!B965N('-P96-I9FEE9"X@*B\*:68@
M*"%E;7!T>2@D8V]N9ELG875T:"==6R=A;'1E<FYA=&5?;&]G:6XG72DI('L*
M("`@("1U<FP@/2!!=71H.CIA9&1,;V=O=71087)A;65T97)S*"1C;VYF6R=A
M=71H)UU;)V%L=&5R;F%T95]L;V=I;B==*3L*("`@(&EF("@A:7-S970H)%]#
M3T]+245;<V5S<VEO;E]N86UE*"E=*2D@>PH@("`@("`@("1U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H)'5R;"P@<V5S<VEO;E]N86UE*"DL('-E<W-I;VY?
M:60H*2P@9F%L<V4I.PH@("`@?0H@("`@:68@*"1U<FQ?<&%R86TI('L*("`@
M("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=U<FPG+"`D
M=7)L7W!A<F%M+"!F86QS92D["B`@("!]"B`@("!H96%D97(H)TQO8V%T:6]N
M.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HD;&]G:6Y?<V-R965N(#T@)&%U
M=&@M/E]G971,;V=I;E-C<F5E;B@I.PII9B`H571I;#HZ<F5M;W9E4&%R86UE
M=&5R*"1L;V=I;E]S8W)E96XL(&%R<F%Y*"=U<FPG+"`G;F]C86-H92<I*2`A
M/0H@("`@2&]R9&4Z.G-E;&95<FPH9F%L<V4L(&9A;'-E+"!T<G5E*2D@>PH@
M("`@:68@*"1U<FQ?<&%R86TI('L*("`@("`@("`D;&]G:6Y?<V-R965N(#T@
M571I;#HZ861D4&%R86UE=&5R*"1L;V=I;E]S8W)E96XL("=U<FPG+"`D=7)L
M7W!A<F%M+"!F86QS92D["B`@("!]"B`@("!I9B`H)&EE7W9E<G-I;VXI('L*
M("`@("`@("`D;&]G:6Y?<V-R965N(#T@571I;#HZ861D4&%R86UE=&5R*"1L
M;V=I;E]S8W)E96XL("=I95]V97)S:6]N)RP@)&EE7W9E<G-I;VXL(&9A;'-E
M*3L*("`@('T*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D;&]G:6Y?<V-R
M965N*3L*("`@(&5X:70["GT*"FEF("@D8G)O=W-E<BT^:7--;V)I;&4H*2D@
M>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-;V)I;&4N<&AP)SL*("`@(')E
M<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]L;V=I;B]M;V)I;&4N:6YC)SL*
M("`@(&5X:70["GT*"B\J($)U:6QD('1H92`\<V5L96-T/B!W:61G970@8V]N
M=&%I;FEN9R!T:&4@879A:6QA8FQE(&QA;F=U86=E<RX@*B\*:68@*"$D<')E
M9G,M/FES3&]C:V5D*"=L86YG=6%G92<I*2!["B`@("`D7U-%4U-)3TY;)VAO
M<F1E7VQA;F=U86=E)UT@/2!.3%,Z.G-E;&5C="@I.PH@("`@)&QA;F=S(#T@
M)SQS96QE8W0@;F%M93TB;F5W7VQA;F<B(&]N8VAA;F=E/2)S96QE8W1,86YG
M*"DB/B<["B`@("!F;W)E86-H("@D;FQS6R=L86YG=6%G97,G72!A<R`D:V5Y
M(#T^("1V86PI('L*("`@("`@("`D<V5L(#T@*"1K97D@/3T@)%]315-324].
M6R=H;W)D95]L86YG=6%G92==*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@
M.B`G)SL*("`@("`@("`D;&%N9W,@+CT@(CQO<'1I;VX@=F%L=64]7"(D:V5Y
M7"(D<V5L/B1V86P\+V]P=&EO;CXB.PH@("`@?0H@("`@)&QA;F=S("X]("<\
M+W-E;&5C=#XG.PI]"@HD=&ET;&4@/2!?*"),;V<@:6XB*3L*)&YO=&EF:6-A
M=&EO;BT^<'5S:"@G<V5T1F]C=7,H*2<L("=J879A<V-R:7!T)RD["FEF("@D
M;&]G;W5T7W)E87-O;B`F)B`D8V]N9ELG;65N=2==6R=A;'=A>7,G72D@>PH@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G:68@*'=I;F1O=RYP87)E;G0N9G)A
M;65S+FAO<F1E7VUE;G4I('=I;F1O=RYP87)E;G0N9G)A;65S+FAO<F1E7VUE
M;G4N;&]C871I;VXN:')E9B`](%PG)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP)RD@+B`G7"<[)RP@)VIA
M=F%S8W)I<'0G*3L*?0H*)')E87-O;B`]("1A=71H+3YG971,;V=O=71296%S
M;VY3=')I;F<H*3L*"B\J($%D9"!S;VUE(&IA=F%S8W)I<'0N("HO"DAO<F1E
M.CIA9&138W)I<'1&:6QE*"=E;G1E<E]K97E?=')A<"YJ<R<L("=H;W)D92<L
M('1R=64I.PH*+RH@1&\@=V4@;F5E9"!T;R!D;R!)12!V97)S:6]N(&1E=&5C
M=&EO;C\@*B\*:68@*"@D8G)O=W-E<BT^9V5T0G)O=W-E<B@I(#T]("=M<VEE
M)RD@)B8@*"1B<F]W<V5R+3YG971-86IO<B@I(#X](#4I*2!["B`@("`D:65?
M8VQI96YT8V%P<R`]('1R=64["GT*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]L;V=I;B]L;V=I;BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,
M051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<G!C+G!H<```````````
M````````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-34U,P`Q,#0Q-S,V,S`Q-@`P,34W,3<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O<G!C+G!H<"QV(#$N,S`N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(X.C`T(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H
M)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]24$,N<&AP
M)SL*"B\J($QO;VL@870@=&AE($-O;G1E;G0M='EP92!O9B!T:&4@<F5Q=65S
M="P@:68@:70@:7,@879A:6QA8FQE+"!T;R!T<GD*("H@86YD(&1E=&5R;6EN
M92!W:&%T(&MI;F0@;V8@<F5Q=65S="!T:&ES(&ES+B`J+PHD:6YP=70@/2!N
M=6QL.PHD<&%R86US(#T@;G5L;#L*"FEF("@A96UP='DH)%]315)615);)U!!
M5$A?24Y&3R==*2!\?`H@("`@:6Y?87)R87DH)%]315)615);)U)%455%4U1?
M34542$]$)UTL(&%R<F%Y*"=04D]01DE.1"<I*2D@>PH@("`@)'-E<G9E<E1Y
M<&4@/2`G=V5B9&%V)SL*?2!E;'-E:68@*&ES<V5T*"1?4T525D526R=215%5
M15-47TU%5$A/1"==*2`F)@H@("`@("`@("`@)%]315)615);)U)%455%4U1?
M34542$]$)UT@/3T@)T=%5"<@)B8*("`@("`@("`@(%5T:6PZ.F=E=$=E="@G
M<F5S=$-A;&PG*2D@>PH@("`@)'-E<G9E<E1Y<&4@/2`G<F5S="<["GT@96QS
M96EF("@A96UP='DH)%]315)615);)T-/3E1%3E1?5%E012==*2D@>PH@("`@
M:68@*'-T<G!O<R@D7U-%4E9%4ELG0T].5$5.5%]465!%)UTL("=A<'!L:6-A
M=&EO;B]V;F0N<WEN8VUL*WAM;"<I("$]/2!F86QS92D@>PH@("`@("`@("1S
M97)V97)4>7!E(#T@)W-Y;F-M;"<["B`@("`@("`@+RH@4WEN8VUL(&1O97,@
M:71S(&]W;B!S97-S:6]N(&AA;F1L:6YG+B`J+PH@("`@("`@("1S97-S:6]N
M7V-O;G1R;VP@/2`G;F]N92<["B`@("!](&5L<V5I9B`H<W1R<&]S*"1?4T52
M5D526R=#3TY414Y47U194$4G72P@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PK
M=V)X;6PG*2`A/3T@9F%L<V4I('L*("`@("`@("`D<V5R=F5R5'EP92`]("=S
M>6YC;6Q?=V)X;6PG.PH@("`@("`@("\J(%-Y;F-M;"!D;V5S(&ET<R!O=VX@
M<V5S<VEO;B!H86YD;&EN9RX@*B\*("`@("`@("`D<V5S<VEO;E]C;VYT<F]L
M(#T@)VYO;F4G.PH@("`@?2!E;'-E:68@*'-T<G!O<R@D7U-%4E9%4ELG0T].
M5$5.5%]465!%)UTL("=T97AT+WAM;"<I("$]/2!F86QS92D@>PH@("`@("`@
M("1I;G!U="`]($AO<F1E7U)00SHZ9V5T26YP=70H*3L*("`@("`@("`O*B!#
M:&5C:R!F;W(@4T]!4"!N86UE<W!A8V4@55))+B`J+PH@("`@("`@(&EF("AS
M=')P;W,H)&EN<'5T+"`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A
M<"]E;G9E;&]P92\G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'-E<G9E
M<E1Y<&4@/2`G<V]A<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'-E<G9E<E1Y<&4@/2`G>&UL<G!C)SL*("`@("`@("!]"B`@("!](&5L<V4@
M>PH@("`@("`@(&AE861E<B@G2%144"\Q+C`@-3`Q($YO="!);7!L96UE;G1E
M9"<I.PH@("`@("`@(&5X:70["B`@("!]"GT@96QS92!["B`@("`D<V5R=F5R
M5'EP92`]("=S;V%P)SL*?0H*:68@*"1S97)V97)4>7!E(#T]("=S;V%P)R`F
M)@H@("`@*"%I<W-E="@D7U-%4E9%4ELG4D5154535%]-151(3T0G72D@?'P*
M("`@("`D7U-%4E9%4ELG4D5154535%]-151(3T0G72`A/2`G4$]35"<I*2![
M"B`@("`D<V5S<VEO;E]C;VYT<F]L(#T@)VYO;F4G.PH@("`@:68@*&ES<V5T
M*"1?1T546R=W<V1L)UTI*2!["B`@("`@("`@)'!A<F%M<R`]("=W<V1L)SL*
M("`@('T@96QS92!["B`@("`@("`@)'!A<F%M<R`]("=D:7-C;R<["B`@("!]
M"GT*"B\J($QO860@8F%S92!L:6)R87)I97,N("HO"G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@3&]A9"!T:&4@4E!#
M(&)A8VME;F0@8F%S960@;VX@)'-E<G9E<E1Y<&4N("HO"B1S97)V97(@/2`F
M2&]R9&5?4E!#.CIS:6YG;&5T;VXH)'-E<G9E<E1Y<&4L("1P87)A;7,I.PH*
M+RH@3&5T('1H92!B86-K96YD(&-H96-K(&%U=&AE;G1I8V%T:6]N+B!">2!D
M969A=6QT+"!W92!L;V]K(&9O<B!(5%10"B`J(&)A<VEC(&%U=&AE;G1I8V%T
M:6]N(&%G86EN<W0@2&]R9&4L(&)U="!B86-K96YD<R!C86X@;W9E<G)I9&4@
M=&AI<PH@*B!A<R!N965D960N("HO"B1S97)V97(M/F%U=&AO<FEZ92@I.PH*
M+RH@1V5T('1H92!S97)V97(G<R!R97-P;VYS92X@5V4@8V%L;"`D<V5R=F5R
M+3YG971);G!U="@I('1O(&%L;&]W"B`J(&)A8VME;F1S('1O(&AA;F1L92!I
M;G!U="!P<F]C97-S:6YG(&1I9F9E<F5N=&QY+B`J+PII9B`H)&EN<'5T(#T]
M/2!N=6QL*2!["B`@("`D:6YP=70@/2`D<V5R=F5R+3YG971);G!U="@I.PI]
M"@HD;W5T(#T@)'-E<G9E<BT^9V5T4F5S<&]N<V4H)&EN<'5T+"`D<&%R86US
M*3L*"FEF("AI<U]A*"1O=70L("=014%27T5R<F]R)RDI('L*("`@(&AE861E
M<B@G2%144"\Q+C`@-3`P($EN=&5R;F%L(%-E<G9E<B!%<G)O<B<I.PH@("`@
M97AI=#L*?0H*+RH@4F5T=7)N('1H92!R97-P;VYS92!T;R!T:&4@8VQI96YT
M+B`J+PIH96%D97(H)T-O;G1E;G0M5'EP93H@)R`N("1S97)V97(M/F=E=%)E
M<W!O;G-E0V]N=&5N=%1Y<&4H*2D["FAE861E<B@G0V]N=&5N="UL96YG=&@Z
M("<@+B!S=')L96XH)&]U="DI.PIH96%D97(H)T%C8V5P="U#:&%R<V5T.B!5
M5$8M."<I.PIE8VAO("1O=70["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S:6=N=7`N<&AP````````````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S`W`#$P-#$W,S8S,#$V
M`#`Q-C0T,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S:6=N=7`N<&AP+'8@
M,2XQ-RXQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,#0@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52
M)RP@=')U92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,
M15]?*2D["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T%U=&@O4VEG;G5P+G!H<"<["G)E
M<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<["@HD875T:"`]("9!
M=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*+R\@
M36%K92!S=7)E('-I9VYU<',@87)E(&5N86)L960@8F5F;W)E('!R;V-E961I
M;F<*:68@*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72`A/3T@=')U92!\?`H@
M("`@(21A=71H+3YH87-#87!A8FEL:71Y*"=A9&0G*2D@>PH@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"A?*")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M(&AE861E<B@G3&]C871I;VXZ("<@+B!!=71H.CIG971,;V=I;E-C<F5E;B@I
M*3L*("`@(&5X:70["GT*"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L
M=%9A<FEA8FQE<R@I.PHD<VEG;G5P(#T@)D%U=&A?4VEG;G5P.CIS:6YG;&5T
M;VXH*3L*)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D[
M"@HD9F]R;7-I9VYU<"`]("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)TAO<F1E
M4VEG;G5P1F]R;2<L("1V87)S*3L*)&9O<FUS:6=N=7`M/G9A;&ED871E*"1V
M87)S*3L*"FEF("@D=F%R<RT^9V5T*"=F;W)M;F%M92<I("$]("=H;W)D97-I
M9VYU<&9O<FTG*2!["B`@("`O*B!.;W0@>65T('-U8FUI='1E9"X@*B\*("`@
M("1F;W)M<VEG;G5P+3YC;&5A<E9A;&ED871I;VXH*3L*?0H*:68@*"1F;W)M
M<VEG;G5P+3YI<U9A;&ED*"D@)B8@)'9A<G,M/F=E="@G9F]R;6YA;64G*2`]
M/2`G:&]R9&5S:6=N=7!F;W)M)RD@>PH@("`@)&9O<FUS:6=N=7`M/F=E=$EN
M9F\H)'9A<G,L("1I;F9O*3L*"B`@("!I9B`H(21C;VYF6R=S:6=N=7`G75LG
M87!P<F]V92==*2!["B`@("`@("`@+RH@57-E<B!C86X@<VEG;B!U<"!D:7)E
M8W1L>2P@;F\@:6YT97)V96YT:6]N(&YE8V5S<V%R>2X@*B\*("`@("`@("`D
M<W5C8V5S<R`]("1S:6=N=7`M/F%D9%-I9VYU<"@D:6YF;RD["B`@("`@("`@
M)'-U8V-E<W-?;65S<V%G92`]('-P<FEN=&8H7R@B061D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB*2P@)&EN9F];)W5S
M97)?;F%M92==*3L*("`@('T@96QS96EF("@D8V]N9ELG<VEG;G5P)UU;)V%P
M<')O=F4G72D@>PH@("`@("`@("\J($EN<V5R="!T:&ES('5S97(@:6YT;R!A
M('%U975E(&9O<B!A9&UI;B!A<'!R;W9A;"X@*B\*("`@("`@("`D<W5C8V5S
M<R`]("1S:6=N=7`M/G%U975E4VEG;G5P*"1I;F9O*3L*("`@("`@("`D<W5C
M8V5S<U]M97-S86=E(#T@<W!R:6YT9BA?*")3=6)M:71T960@<F5Q=65S="!T
M;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN
M('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB*2P@)&EN
M9F];)W5S97)?;F%M92==*3L*("`@('T*"B`@("!I9B`H:7-?82@D<W5C8V5S
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H<W!R:6YT9BA?*")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S
M7"(@=&\@=&AE('-Y<W1E;3H@)7,B*2P@)&EN9F];)W5S97)?;F%M92==+"`D
M<W5C8V5S<RT^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]
M(&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'-U8V-E<W-?
M;65S<V%G92P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`D=7)L(#T@075T
M:#HZ9V5T3&]G:6Y38W)E96XH)R<L("1I;F9O6R=U<FPG72D["B`@("`@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@("`@(&5X:70["B`@
M("!]"GT*"B1T:71L92`](%\H(E5S97(@4F5G:7-T<F%T:6]N(BD["G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["B1N
M;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A
M='5S)RDI.PHD9F]R;7-I9VYU<"T^<F5N9&5R06-T:79E*"1R96YD97)E<BP@
M)'9A<G,L("=S:6=N=7`N<&AP)RP@)W!O<W0G*3L*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T97-T+G!H<```````````````
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,38W
M`#$P-#$W,S8S,#$V`#`Q-C$Q-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T
M97-T+G!H<"QV(#$N,3(R+C8N,38@,C`P-B\P,2\P,2`R,3HR.#HP-"!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!"<F5N="!*+B!.;W)D
M<75I<W0@/&)J;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*+RH@4F5G:7-T97(@82!S97-S:6]N+B`J+PIS
M97-S:6]N7W-T87)T*"D["FEF("@A:7-S970H)%]315-324].6R=H;W)D95]T
M97-T7V-O=6YT)UTI*2!["B`@("`D7U-%4U-)3TY;)VAO<F1E7W1E<W1?8V]U
M;G0G72`](#`["GT*"B\J($EN8VQU9&4@2&]R9&4G<R!C;W)E+G!H<"!F:6QE
M+B`J+PII;F-L=61E7V]N8V4@)VQI8B]C;W)E+G!H<"<["@HO*B!792!S:&]U
M;&0@:&%V92!L;V%D960@=&AE(%-T<FEN9R!C;&%S<RP@9G)O;2!T:&4@2&]R
M9&5?571I;"!P86-K86=E+"!I;@H@*B!C;W)E+G!H<"X@268@4W1R:6YG.CH@
M:7-N)W0@9&5F:6YE9"P@=&AE;B!W92=R92!N;W0@9FEN9&EN9R!S;VUE(&-R
M:71I8V%L"B`J(&QI8G)A<FEE<RX@*B\*:68@*"%C;&%S<U]E>&ES=',H)U-T
M<FEN9R<I*2!["B`@("!E8VAO("<\8G(@+SX\<W!A;B!S='EL93TB8V]L;W(Z
M(')E9#L@9F]N="US:7IE.B`Q.'!X.R!F;VYT+7=E:6=H=#H@8F]L9#LB/E1H
M92!(;W)D95]5=&EL('!A8VMA9V4@=V%S(&YO="!F;W5N9"X@268@4$A07"=S
M(&5R<F]R7W)E<&]R=&EN9R!S971T:6YG(&ES(&AI9V@@96YO=6=H+"!T:&5R
M92!S:&]U;&0@8F4@97)R;W(@;65S<V%G97,@<')I;G1E9"!A8F]V92!T:&%T
M(&UA>2!H96QP('EO=2!I;B!D96)U9V=I;F<@=&AE('!R;V)L96TN($EF('EO
M=2!A<F4@<VEM<&QY(&UI<W-I;F<@=&AE<V4@9FEL97,@04Y$(&%R92!I;G-T
M86QL:6YG(&$@0U93(&-H96-K;W5T+"!T:&5N('EO=2!N965D('1O(&=E="!T
M:&4@/&$@:')E9CTB:'1T<#HO+V-V<RYH;W)D92YO<F<O8W9S+G!H<"]F<F%M
M97=O<FLB/F9R86UE=V]R:SPO83X@;6]D=6QE(&9R;VT@/&$@:')E9CTB:'1T
M<#HO+VAO<F1E+F]R9R]S;W5R8V4O(CY(;W)D92!#5E,\+V$^+"!A;F0@:6YS
M=&%L;"!T:&4@<&%C:V%G97,@:6X@:70@=VET:"!T:&4@:6YS=&%L;"UP86-K
M86=E<RYP:'`@<V-R:7!T+CPO<W!A;CXG.PH@("`@97AI=#L*?0H*+RH@26YI
M=&EA;&EZ92!T:&4@2&]R9&5?5&5S=#HZ(&-L87-S+B`J+PII9B`H(6EN8VQU
M9&5?;VYC92`G;&EB+U1E<W0N<&AP)RD@>PH@("`@+RH@5')Y(&%N9"!P<F]V
M:61E(&5N;W5G:"!I;F9O<FUA=&EO;B!T;R!D96)U9R!T:&4@;6ES<VEN9R!F
M:6QE+B`J+PH@("`@96-H;R`G/&)R("\^/'-P86X@<W1Y;&4](F-O;&]R.B!R
M960[(&9O;G0M<VEZ93H@,3AP>#L@9F]N="UW96EG:'0Z(&)O;&0[(CY5;F%B
M;&4@=&\@9FEN9"!H;W)D92]L:6(O5&5S="YP:'`N(%EO=7(@2&]R9&4@:6YS
M=&%L;&%T:6]N(&UA>2!B92!M:7-S:6YG(&-R:71I8V%L(&9I;&5S+"!O<B!0
M2%`@;6%Y(&YO="!H879E('-U9F9I8VEE;G0@<&5R;6ES<VEO;G,@=&\@:6YC
M;'5D92!F:6QE<RX@5&AE<F4@;6%Y(&)E(&5R<F]R(&UE<W-A9V5S('!R:6YT
M960@86)O=F4@=&AI<R!M97-S86=E('1H870@=VEL;"!H96QP('EO=2!I;B!D
M96)U9V=I;F<@=&AE('!R;V)L96TN/"]S<&%N/B<["B`@("!E>&ET.PI]"@HO
M*B!)9B!W92=V92!G;W1T96X@=&AI<R!F87(L('=E('-H;W5L9"!H879E(&9O
M=6YD(&5N;W5G:"!O9B!(;W)D92!T;R!R=6X*("H@=&5S=',N($-R96%T92!T
M:&4@=&5S=&EN9R!O8FIE8W0N("HO"B1H;W)D95]T97-T(#T@)FYE=R!(;W)D
M95]497-T*"D["@HO*B!(;W)D92!D969I;FET:6]N<RX@*B\*)&UO9'5L92`]
M("=(;W)D92<["G)E<75I<F5?;VYC92`G+B]L:6(O=F5R<VEO;BYP:'`G.PHD
M;6]D=6QE7W9E<G-I;VX@/2!(3U)$15]615)324]..PH*+RH@4$A0(&UO9'5L
M92!C87!A8FEL:71I97,N("HO"B1M;V1U;&5?;&ES="`](&%R<F%Y*`H@("`@
M)V-T>7!E)R`]/B`G0W1Y<&4@4W5P<&]R="<L"B`@("`H=F5R<VEO;E]C;VUP
M87)E*'!H<'9E<G-I;VXH*2P@)S4G*2`\(#`@/R`G9&]M>&UL)R`Z("=D;VTG
M*2`]/B`G1$]-(%A-3"!3=7!P;W)T)RP*("`@("=F='`G(#T^("=&5%`@4W5P
M<&]R="<L"B`@("`G9V0G(#T^("='1"!3=7!P;W)T)RP*("`@("=G971T97AT
M)R`]/B!A<G)A>2@*("`@("`@("`G9&5S8W)I<"<@/3X@)T=E='1E>'0@4W5P
M<&]R="<L"B`@("`@("`@)V5R<F]R)R`]/B`G2&]R9&4@=VEL;"!N;W0@<G5N
M('=I=&AO=70@9V5T=&5X="!S=7!P;W)T+B!#;VUP:6QE(%!(4"!W:71H(#QC
M;V1E/BTM=VET:"UG971T97AT/"]C;V1E/B!B969O<F4@8V]N=&EN=6EN9RXG
M+`H@("`@("`@("=F871A;"<@/3X@=')U90H@("`@*2P*("`@("=I8V]N=B<@
M/3X@87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=)8V]N=B!3=7!P;W)T
M)RP*("`@("`@("`G97)R;W(G(#T^("=)9B!Y;W4@=V%N="!T;R!T86ME(&9U
M;&P@861V86YT86=E(&]F($AO<F1E7"=S(&QO8V%L:7IA=&EO;B!F96%T=7)E
M<R!A;F0@8VAA<F%C=&5R('-E="!S=7!P;W)T+"!Y;W4@=VEL;"!N965D('1H
M92!I8V]N=B!E>'1E;G-I;VXN)PH@("`@*2P*("`@("=I;6%P)R`]/B`G24U!
M4"!3=7!P;W)T)RP*("`@("=L9&%P)R`]/B`G3$1!4"!3=7!P;W)T)RP*("`@
M("=M8G-T<FEN9R<@/3X@87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=-
M8G-T<FEN9R!3=7!P;W)T)RP*("`@("`@("`G97)R;W(G(#T^("=)9B!Y;W4@
M=V%N="!T;R!T86ME(&9U;&P@861V86YT86=E(&]F($AO<F1E7"=S(&QO8V%L
M:7IA=&EO;B!F96%T=7)E<R!A;F0@8VAA<F%C=&5R('-E="!S=7!P;W)T+"!Y
M;W4@=VEL;"!N965D('1H92!M8G-T<FEN9R!E>'1E;G-I;VXN)PH@("`@*2P*
M("`@("=M8W)Y<'0G(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G
M36-R>7!T(%-U<'!O<G0G+`H@("`@("`@("=E<G)O<B<@/3X@)TUC<GEP="!I
M<R!A(&=E;F5R86PM<'5R<&]S92!C<GEP=&]G<F%P:'D@;&EB<F%R>2!W:&EC
M:"!I<R!B<F]A9&5R(&%N9"!S:6=N:69I8V%N=&QY(&UO<F4@969F:6-I96YT
M("A&05-415(A*2!T:&%N(%!(4%PG<R!O=VX@8W)Y<'1O9W)A<&AI8R!C;V1E
M(&%N9"!W:6QL('!R;W9I9&5R(&9A<W1E<B!L;V=I;G,N)PH@("`@*2P*("`@
M("=F:6QE:6YF;R<@/3X@87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=-
M24U%($UA9VEC(%-U<'!O<G0@*&9I;&5I;F9O*2<L"B`@("`@("`@)V5R<F]R
M)R`]/B`G5&AE(&9I;&5I;F9O(%!%0TP@;6]D=6QE(&]R('1H92!M:6UE7VUA
M9VEC(%!(4"!E>'1E;G-I;VX@*'-E92!B96QO=RD@=VEL;"!M;W-T(&QI:V5L
M>2!P<F]V:61E(&9A<W1E<B!-24U%($UA9VEC(&QO;VMU<',@=&AA;B!T:&4@
M8G5I;'0M:6X@2&]R9&4@4$A0(&UA9VEC(&-O9&4N(%-E92!H;W)D92]D;V-S
M+TE.4U1!3$P@9F]R(&EN9F]R;6%T:6]N(&]N(&AO=R!T;R!I;G-T86QL(%!%
M0TPO4$A0(&5X=&5N<VEO;G,N)PH@("`@*2P*("`@("=M96UC86-H92<@/3X@
M87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=M96UC86-H960@4W5P<&]R
M="`H;65M8V%C:&4I)RP*("`@("`@("`G97)R;W(G(#T^("=4:&4@;65M8V%C
M:&4@4$5#3"!M;V1U;&4@:7,@;F5E9&5D(&]N;'D@:68@>6]U(&%R92!U<VEN
M9R!T:&4@;65M8V%C:&5D(%-E<W-I;VY(86YD;&5R+B!3964@:&]R9&4O9&]C
M<R])3E-404Q,(&9O<B!I;F9O<FUA=&EO;B!O;B!H;W<@=&\@:6YS=&%L;"!0
M14-,+U!(4"!E>'1E;G-I;VYS+B<*("`@("DL"B`@("`G;6EM95]M86=I8R<@
M/3X@87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=-24U%($UA9VEC(%-U
M<'!O<G0@*&UI;65?;6%G:6,I)RP*("`@("`@("`G97)R;W(G(#T^("=4:&4@
M9FEL96EN9F\@4$5#3"!M;V1U;&4@*'-E92!A8F]V92D@;W(@=&AE(&UI;65?
M;6%G:6,@4$A0(&5X=&5N<VEO;B!W:6QL(&UO<W0@;&EK96QY('!R;W9I9&4@
M9F%S=&5R($U)344@36%G:6,@;&]O:W5P<R!T:&%N('1H92!B=6EL="UI;B!(
M;W)D92!02%`@;6%G:6,@8V]D92X@4V5E(&AO<F1E+V1O8W,O24Y35$%,3"!F
M;W(@:6YF;W)M871I;VX@;VX@:&]W('1O(&EN<W1A;&P@4$5#3"]02%`@97AT
M96YS:6]N<RXG"B`@("`I+`H@("`@)VUY<W%L)R`]/B`G37E344P@4W5P<&]R
M="<L"B`@("`G;W!E;G-S;"<@/3X@)T]P96Y34TP@4W5P<&]R="<L"B`@("`G
M<&=S<6PG(#T^("=0;W-T9W)E4U%,(%-U<'!O<G0G+`H@("`@)W-E<W-I;VXG
M(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G4V5S<VEO;B!3=7!P
M;W)T)RP*("`@("`@("`G9F%T86PG(#T^('1R=64I+`H@("`@)WAM;"<@/3X@
M)UA-3"!3=7!P;W)T)RP*("`@("=Z;&EB)R`]/B!A<G)A>2@*("`@("`@("`G
M9&5S8W)I<"<@/3X@)UIL:6(@4W5P<&]R="<L"B`@("`@("`@)V5R<F]R)R`]
M/B`G5&AE('IL:6(@;6]D=6QE(&ES(&AI9VAL>2!R96-O;6UE;F1E9"!F;W(@
M=7-E('=I=&@@2&]R9&4N("!)="!A;&QO=W,@<&%G92!C;VUP<F5S<VEO;B!A
M;F0@:&%N9&QI;F<@;V8@6DE0(&%N9"!'6B!D871A+B!#;VUP:6QE(%!(4"!W
M:71H(#QC;V1E/BTM=VET:"UZ;&EB/"]C;V1E/B!T;R!A8W1I=F%T92XG+`H@
M("`@("`@("=F871A;"<@/3X@9F%L<V4*("`@("DL"BD["@H*+RH@4$A0(%-E
M='1I;F=S+B`J+PHD<V5T=&EN9U]L:7-T(#T@87)R87DH"B`@("`G;6%G:6-?
M<75O=&5S7W)U;G1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=S971T:6YG)R`]
M/B!F86QS92P*("`@("`@("`G97)R;W(G(#T^("=M86=I8U]Q=6]T97-?<G5N
M=&EM92!M87D@8V%U<V4@<')O8FQE;7,@=VET:"!D871A8F%S92!I;G-E<G1S
M+"!E=&,N(%1U<FX@:70@;V9F+B<*("`@("DL"B`@("`G;65M;W)Y7VQI;6ET
M)R`]/B!A<G)A>2@*("`@("`@("`G<V5T=&EN9R<@/3X@9F%L<V4L"B`@("`@
M("`@)V5R<F]R)R`]/B`G268@4$A07"=S(&EN=&5R;F%L(&UE;6]R>2!L:6UI
M="!I<R!T=7)N960@;VX@86YD(&EF(&YO="!S970@:&EG:"!E;F]U9V@@2&]R
M9&4@=VEL;"!N;W0@8F4@86)L92!T;R!H86YD;&4@;&%R9V4@9&%T82!I=&5M
M<R`H92YG+B!L87)G92!M86EL(&%T=&%C:&UE;G1S(&EN($E-4"DN($EF('!O
M<W-I8FQE+"!Y;W4@<VAO=6QD(&1I<V%B;&4@=&AE(%!(4"!M96UO<GD@;&EM
M:70@8GD@<F5C;VUP:6QI;F<@4$A0(#QE;3YW:71H;W5T/"]E;3X@=&AE("(M
M+65N86)L92UM96UO<GDM;&EM:70B(&9L86<N($EF('1H:7,@:7,@;F]T('!O
M<W-I8FQE+"!T:&5N('EO=2!S:&]U;&0@<V5T('1H92!V86QU92!O9B!M96UO
M<GE?;&EM:70@:6X@<&AP+FEN:2!T;R!A('-U9F9I8VEE;G1L>2!H:6=H('9A
M;'5E("A#=7)R96YT('9A;'5E(&]F(&UE;6]R>5]L:6UI=#H@)R`N(&EN:5]G
M970H)VUE;6]R>5]L:6UI="<I("X@)RDN)PH@("`@*2P*("`@("=S869E7VUO
M9&4G(#T^(&%R<F%Y*`H@("`@("`@("=S971T:6YG)R`]/B!F86QS92P*("`@
M("`@("`G97)R;W(G(#T^("=)9B!S869E7VUO9&4@:7,@96YA8FQE9"P@2&]R
M9&4@8V%N;F]T('-E="!E;G9I<F]M96YT('9A<FEA8FQE<RP@=VAI8V@@;65A
M;G,@2&]R9&4@=VEL;"!B92!U;F%B;&4@=&\@=')A;G-L871E('1H92!U<V5R
M(&EN=&5R9F%C92!I;G1O(&1I9F9E<F5N="!L86YG=6%G97,N)PH@("`@*2P*
M("`@("=S97-S:6]N+G5S95]T<F%N<U]S:60G(#T^(&%R<F%Y*`H@("`@("`@
M("=S971T:6YG)R`]/B!F86QS92P*("`@("`@("`G97)R;W(G(#T^("=(;W)D
M92!W:6QL('=O<FL@=VET:"!S97-S:6]N+G5S95]T<F%N<U]S:60@='5R;F5D
M(&]N+"!B=70@>6]U(&UA>2!S964@9&]U8FQE('-E<W-I;VXM:61S(&EN('EO
M=7(@55),<RP@86YD(&EF('1H92!S97-S:6]N(&YA;64@:6X@<&AP+FEN:2!D
M:69F97)S(&9R;VT@=&AE('-E<W-I;VX@;F%M92!C;VYF:6=U<F5D(&EN($AO
M<F1E+"!Y;W4@;6%Y(&=E="!T=V\@<V5S<VEO;B!I9',@86YD('-E92!O=&AE
M<B!O9&0@8F5H879I;W(N(%1H92!54DPM<F5W<FET:6YG('1H870@=7-E7W1R
M86YS7W-I9"!D;V5S(&%L<V\@=&5N9',@=&\@8G)E86L@6$A434P@8V]M<&QI
M86YC92X@26X@<VAO<G0L('EO=2!S:&]U;&0@<F5A;&QY(&1I<V%B;&4@=&AI
M<RXG"B`@("`I+`H@("`@)W-E<W-I;VXN875T;U]S=&%R="<@/3X@87)R87DH
M"B`@("`@("`@)W-E='1I;F<G(#T^(&9A;'-E+`H@("`@("`@("=E<G)O<B<@
M/3X@)TAO<F1E('=O;EPG="!W;W)K('=I=&@@875T;VUA=&EC86QL>2!S=&%R
M=&5D('-E<W-I;VYS+"!B96-A=7-E(&ET(&5X<&QI8VET;'D@8W)E871E<R!N
M97<@<V5S<VEO;B!W:&5N(&YE8V5S<V%R>2!T;R!P<F]T96-T(&%G86EN<W0@
M<V5S<VEO;B!F:7AA=&EO;G,N)PH@("`@*0HI.PH*"B\J(%!%05(@*B\*)'!E
M87)?;&ES="`](&%R<F%Y*`H@("`@)TUA:6PG(#T^(&%R<F%Y*`H@("`@("`@
M("=P871H)R`]/B`G36%I;"]21D,X,C(N<&AP)RP*("`@("`@("`G97)R;W(G
M(#T^("=9;W4@9&\@;F]T(&AA=F4@=&AE($UA:6P@<&%C:V%G92!I;G-T86QL
M960@;VX@>6]U<B!S>7-T96TN(%-E92!T:&4@24Y35$%,3"!F:6QE(&9O<B!I
M;G-T<G5C=&EO;G,@;VX@:&]W('1O(&EN<W1A;&P@=&AE('!A8VMA9V4N)PH@
M("`@*2P*("`@("=-86EL7TUI;64G(#T^(&%R<F%Y*`H@("`@("`@("=P871H
M)R`]/B`G36%I;"]M:6UE1&5C;V1E+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]
M/B`G66]U(&1O(&YO="!H879E('1H92!-86EL7TUI;64@<&%C:V%G92!I;G-T
M86QL960@;VX@>6]U<B!S>7-T96TN(%-E92!T:&4@24Y35$%,3"!F:6QE(&9O
M<B!I;G-T<G5C=&EO;G,@;VX@:&]W('1O(&EN<W1A;&P@=&AE('!A8VMA9V4N
M)RP*("`@("`@("`G<F5Q=6ER960G(#T^('1R=64*("`@("DL"B`@("`G3&]G
M)R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)TQO9RYP:'`G+`H@("`@
M("`@("=E<G)O<B<@/3X@)TUA:V4@<W5R92!Y;W4@87)E('5S:6YG(&$@=F5R
M<VEO;B!O9B!014%2('=H:6-H(&EN8VQU9&5S('1H92!,;V<@8VQA<W-E<RP@
M;W(@=&AA="!Y;W4@:&%V92!I;G-T86QL960@=&AE($QO9R!P86-K86=E('-E
M<&5R871E;'DN(%-E92!T:&4@24Y35$%,3"!F:6QE(&9O<B!I;G-T<G5C=&EO
M;G,@;VX@:6YS=&%L;&EN9R!,;V<N)RP*("`@("`@("`G<F5Q=6ER960G(#T^
M('1R=64L"B`@("`@("`@)V9U;F-T:6]N)R`]/B`G7V-H96-K7W!E87)?;&]G
M7W9E<G-I;VXG"B`@("`I+`H@("`@)T1")R`]/B!A<G)A>2@*("`@("`@("`G
M<&%T:"<@/3X@)T1"+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G66]U('=I
M;&P@;F5E9"!$0B!I9B!Y;W4@87)E('5S:6YG(%-13"!D<FEV97)S(&9O<B!P
M<F5F97)E;F-E<RP@8V]N=&%C=',@*%1U<F)A*2P@971C+B<L"B`@("`@("`@
M)V9U;F-T:6]N)R`]/B`G7V-H96-K7W!E87)?9&)?=F5R<VEO;B<*("`@("DL
M"B`@("`G3F5T7U-O8VME="<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^
M("=.970O4V]C:V5T+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G36%K92!S
M=7)E('EO=2!A<F4@=7-I;F<@82!V97)S:6]N(&]F(%!%05(@=VAI8V@@:6YC
M;'5D97,@=&AE($YE=%]3;V-K970@8VQA<W,L(&]R('1H870@>6]U(&AA=F4@
M:6YS=&%L;&5D('1H92!.971?4V]C:V5T('!A8VMA9V4@<V5P97)A=&5L>2X@
M4V5E('1H92!)3E-404Q,(&9I;&4@9F]R(&EN<W1R=6-T:6]N<R!O;B!I;G-T
M86QL:6YG($YE=%]3;V-K970N)PH@("`@*2P*("`@("=$871E)R`]/B!A<G)A
M>2@*("`@("`@("`G<&%T:"<@/3X@)T1A=&4O0V%L8RYP:'`G+`H@("`@("`@
M("=E<G)O<B<@/3X@)TAO<F1E(')E<75I<F5S('1H92!$871E7T-A;&,@8VQA
M<W,@9F]R($MR;VYO;&ET:"!T;R!C86QC=6QA=&4@9&%T97,N)PH@("`@*2P*
M("`@("=!=71H7U-!4TPG(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G
M075T:"]305-,+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G2&]R9&4@=VEL
M;"!W;W)K('=I=&AO=70@=&AE($%U=&A?4T%33"!C;&%S<RP@8G5T(&EF('EO
M=2!U<V4@06-C97-S($-O;G1R;VP@3&ES=',@:6X@24U0('EO=2!S:&]U;&0@
M8F4@87=A<F4@=&AA="!W:71H;W5T('1H:7,@8VQA<W,@<&%S<W=O<F1S('=I
M;&P@8F4@<V5N="!T;R!T:&4@24U!4"!S97)V97(@:6X@<&QA:6X@=&5X="!W
M:&5N(')E=')I979I;F<@04-,<RXG"B`@("`I+`H@("`@)TA45%!?4F5Q=65S
M="<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=(5%10+U)E<75E<W0N
M<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=087)T<R!O9B!(;W)D92`H2%1-
M3"!C;VUP;W-I=&EO;B!I;B!)35`L($IO;F%H+"!T:&4@6$U,+5)00R!C;&EE
M;G0O<V5R=F5R*2!U<V4@=&AE($A45%!?4F5Q=65S="!L:6)R87)Y('1O(')E
M=')I979E(%523',@86YD(&1O(&]T:&5R($A45%`@<F5Q=65S=',N)PH@("`@
M*2P*("`@("=&:6QE)R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)T9I
M;&4N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=(;W)D92!W:6QL(')E<75I
M<F4@=&AE($9I;&4@8VQA<W,@=VAE;B!I;7!O<G1I;F<@0U-6(&9I;&5S+B<*
M("`@("DL"B`@("`G3F5T7U--5%`G(#T^(&%R<F%Y*`H@("`@("`@("=P871H
M)R`]/B`G3F5T+U--5%`N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=-86ME
M('-U<F4@>6]U(&%R92!U<VEN9R!T:&4@3F5T7U--5%`@;6]D=6QE(&EF('EO
M=2!W86YT(")S;71P(B!T;R!W;W)K(&%S(&$@;6%I;&5R(&]P=&EO;BXG"B`@
M("`I+`H@("`@)U-E<G9I8V5S7U=E871H97(G(#T^(&%R<F%Y*`H@("`@("`@
M("=P871H)R`]/B`G4V5R=FEC97,O5V5A=&AE<BYP:'`G+`H@("`@("`@("=E
M<G)O<B<@/3X@)U-E<G9I8V5S7U=E871H97(@:7,@=7-E9"!B>2!T:&4@=V5A
M=&AE<B!A<'!L970O8FQO8VL@;VX@=&AE('!O<G1A;"!P86=E+B<*("`@("DL
M"B`@("`G0V%C:&4G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G0V%C
M:&4N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=#86-H92!I<R!U<V5D(&)Y
M('1H92!397)V:6-E<U]796%T:&5R(&UO9'5L92!O;B!T:&4@=V5A=&AE<B!A
M<'!L970O8FQO8VL@;VX@=&AE('!O<G1A;"!P86=E+B<*("`@("DL"B`@("`G
M6$U,7U-E<FEA;&EZ97(G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G
M6$U,+U-E<FEA;&EZ97(N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=834Q?
M4V5R:6%L:7IE<B!I<R!U<V5D(&)Y('1H92!397)V:6-E<U]796%T:&5R(&UO
M9'5L92!O;B!T:&4@=V5A=&AE<B!A<'!L970O8FQO8VL@;VX@=&AE('!O<G1A
M;"!P86=E+B<*("`@("D**3L*"B\J($%D9&ET:6]N86P@8VAE8VL@9F]R(%!%
M05(@3&]G(&UO9'5L92!F;W(@:71S('9E<G-I;VXN("HO"F9U;F-T:6]N(%]C
M:&5C:U]P96%R7VQO9U]V97)S:6]N*"D*>PH@("`@:68@*"%D969I;F5D*"=0
M14%27TQ/1U])3D9/)RDI('L*("`@("`@("!R971U<FX@)UEO=7(@=F5R<VEO
M;B!O9B!,;V<@:7,@;F]T(')E8V5N="!E;F]U9V@N)SL*("`@('T*?0H*+RH@
M061D:71I;VYA;"!C:&5C:R!F;W(@4$5!4B!$0B!M;V1U;&4@9F]R(&ET<R!V
M97)S:6]N+B`J+PIF=6YC=&EO;B!?8VAE8VM?<&5A<E]D8E]V97)S:6]N*"D*
M>PH@("`@:68@*"%D969I;F5D*"=$0E]03U)404))3$E465],3U=%4D-!4T4G
M*2D@>PH@("`@("`@(')E='5R;B`G66]U<B!V97)S:6]N(&]F($1"(&ES(&YO
M="!R96-E;G0@96YO=6=H+B<["B`@("!]"GT*"B\J(%1H97)E(&ES(&$@=F5R
M<VEO;B!O9B!T:&4@1FEL92YP:'`@=&AA="!W86YT<R!A(%!%05(Z.G)E9VES
M=&5R4VAU=&1O=VY&=6YC"B`J('=H:6-H(&ES('=H870@;F5W<&5A<B!T97-T
M<R!F;W(N("!4:&ES(&9U;F-T:6]N('-E96US('1O(&]N;'D@:&%V92!E>&ES
M=&5D"B`J(&9O<B!A(&QI='1L92!W:&EL92P@8G5T('1H92!014%2(&=R;W5P
M(&AA<VXG="!F:7AE9"!T:&ES('EE="P@<V\@<V]M90H@*B!P96]P;&4@9V5T
M(&%N(&5R<F]R(&EF('1H97D@:&%V92!A(&-E<G1A:6X@*')E;&5A<V4I('9E
M<G-I;VX@;V8@4$5!4BX@(%=E"B`J('1E<W0@9F]R(&ET(&AE<F4N("!)9B!I
M="=S(&$@<V%F92!V97)S:6]N+"!T97-T(&%S(&YO<FUA;"P@;W1H97)W:7-E
M('1R>2!A"B`J(&QE<W,@969F96-T:79E(&)U="!N;VXM97)R;W)I;F<@=&5S
M="!F;W(@1FEL93HZ0U-6+B`J+PII9B`H(21H;W)D95]T97-T+3YI<U)E8V5N
M=%!%05(H*2D@>PH@("`@)'!A=&@@/2!I;FE?9V5T*"=I;F-L=61E7W!A=&@G
M*3L*("`@(&EF("AE;7!T>2@D<&%T:"DI('L*("`@("`@("`D<&%T:"`]("<N
M)SL*("`@('T*("`@("1P96%R7VQI<W1;)T9I;&5?0U-6)UU;)W!A=&@G72`]
M("=86%A86%@N<&AP)SL*("`@(&9O<F5A8V@@*&5X<&QO9&4H)SHG+"`D<&%T
M:"D@87,@)&1I<BD@>PH@("`@("`@(&EF("AS=6)S='(H)&1I<BP@+3$I("$]
M("<O)RD@>PH@("`@("`@("`@("`D9&ER("X]("<O)SL*("`@("`@("!]"B`@
M("`@("`@)&9I;&4Q(#T@)&1I<B`N("=&:6QE+T-35BYP:'`G.PH@("`@("`@
M("1F:6QE,B`]("1D:7(@+B`G1FEL92YP:'`G.PH@("`@("`@("1F:6QE,R`]
M("1D:7(@+B`G4$5!4BYP:'`G.PH@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D
M9FEL93$I("8F(&9I;&5?97AI<W1S*"1F:6QE,BD@)B8@9FEL95]E>&ES=',H
M)&9I;&4S*2D@>PH@("`@("`@("`@("`O*B!#:&%N9V4@=&AE(&9I;&5N86UE
M('1O('-O;65T:&EN9R!W92!K;F]W('=I;&P@8F4@9F]U;F0N("HO"B`@("`@
M("`@("`@("1P96%R7VQI<W1;)T9I;&5?0U-6)UU;)W!A=&@G72`]("=014%2
M+G!H<"<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*?0H*
M+RH@4F5Q=6ER960@8V]N9FEG=7)A=&EO;B!F:6QE<RX@*B\*)&9I;&5?;&ES
M="`](&%R<F%Y*`H@("`@)V-O;F9I9R]C;VYF+G!H<"<@/3X@;G5L;"P*("`@
M("=C;VYF:6<O;6EM95]D<FEV97)S+G!H<"<@/3X@;G5L;"P*("`@("=C;VYF
M:6<O;FQS+G!H<"<@/3X@;G5L;"P*("`@("=C;VYF:6<O<')E9G,N<&AP)R`]
M/B!N=6QL+`H@("`@)V-O;F9I9R]R96=I<W1R>2YP:'`G(#T^(&YU;&P**3L*
M"@HO*B!'970@=&AE('-T871U<R!O=71P=70@;F]W+B`J+PHD;6]D=6QE7V]U
M='!U="`]("1H;W)D95]T97-T+3YP:'!-;V1U;&5#:&5C:R@D;6]D=6QE7VQI
M<W0I.PHD<V5T=&EN9U]O=71P=70@/2`D:&]R9&5?=&5S="T^<&AP4V5T=&EN
M9T-H96-K*"1S971T:6YG7VQI<W0I.PHD<&5A<E]O=71P=70@/2`D:&]R9&5?
M=&5S="T^4$5!4DUO9'5L94-H96-K*"1P96%R7VQI<W0I.PHD8V]N9FEG7V]U
M='!U="`]("1H;W)D95]T97-T+3YR97%U:7)E9$9I;&5#:&5C:R@D9FEL95]L
M:7-T*3L*"@HO*B!(86YD;&4@<W!E8VEA;"!M;V1E<RX@*B\*:68@*"%E;7!T
M>2@D7T=%5%LG;6]D92==*2D@>PH@("`@)'5R;"`]("%E;7!T>2@D7T=%5%LG
M=7)L)UTI(#\@)%]'151;)W5R;"==(#H@)W1E<W0N<&AP)SL*("`@(&5C:&\@
M)SPA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP
M(%1R86YS:71I;VYA;"\O14XB(")$5$0O>&AT;6PQ+71R86YS:71I;VYA;"YD
M=&0B/B<["B`@("!S=VET8V@@*"1?1T546R=M;V1E)UTI('L*("`@(&-A<V4@
M)V5X=&5N<VEO;G,G.@H@("`@("`@(')E<75I<F4@5$535%]414U03$%415,@
M+B`G97AT96YS:6]N<RYI;F,G.PH@("`@("`@(&5X:70["@H@("`@8V%S92`G
M<&AP:6YF;R<Z"B`@("`@("`@96-H;R`G/&$@:')E9CTB)R`N("1U<FP@+B`G
M/VUO9&4]=&5S="(^)FQT.R9L=#L@0F%C:R!T;R!T97-T+G!H<#PO83XG.PH@
M("`@("`@('!H<&EN9F\H*3L*("`@("`@("!E>&ET.PH*("`@(&-A<V4@)V9I
M;&5T97-T)SH*("`@("`@("!E8VAO("<\82!H<F5F/2(G("X@)'5R;"`N("<_
M;6]D93UT97-T(CXF;'0[)FQT.R!"86-K('1O('1E<W0N<&AP/"]A/B<["B`@
M("`@("`@/SX*("`@("`@("`\:'1M;#X*("`@("`@("`\8F]D>2!B9V-O;&]R
M/2)W:&ET92(@=&5X=#TB8FQA8VLB/@H@("`@("`@(#QP/CQF;VYT(&9A8V4]
M(DAE;'9E=&EC82P@07)I86PL('-A;G,M<V5R:68B('-I>F4](C(B/@H@("`@
M("`@(%1H97)E(&%R92!S;VUE('9E<G-I;VYS(&]F(%!%05(@=&AA="!W97)E
M(')E;&5A<V5D(&%T('1I;65S('1H870*("`@("`@("!D:60@;F]T(&-O;G1A
M:6X@82!F=6YC=&EO;B!T:&%T($9I;&4N<&AP(&5X<&5C=',N("!4:&ES(&1O
M97,@;F]T"B`@("`@("`@<V5E;2!T;R!H879E(&-A=7-E9"!P<F]B;&5M<R!F
M;W(@86YY;VYE(&5X8V5P="!W:&5N(')U;FYI;F<@;W5R"B`@("`@("`@=&5S
M="!S8W)I<'0L(&)U="!Y;W4@;F5E9"!T;R!B92!A=V%R92!O9B!I="X@($EF
M('EO=2!S964@82!F871A;`H@("`@("`@(&5R<F]R(&EN($9I;&4N<&AP(&QI
M<W1E9"!B96QO=R!T:&ES('1E>'0L('EO=2!H879E(&]N92!O9B!T:&4*("`@
M("`@("!C;VUB:6YA=&EO;G,@;V8@<')O8FQE;2!F:6QE<RX@($UA:V4@<W5R
M92!Y;W4@:&%V92!T:&4@;&%T97-T"B`@("`@("`@4$5!4B!A;F0@1FEL92!P
M86-K86=E<R!A=F%I;&%B;&4@*#QA(&AR968](FAT='`Z+R]P96%R+G!H<"YN
M970O(CX*("`@("`@("!S964@:'1T<#HO+W!E87(N<&AP+FYE=#PO83XI+B`@
M268@>6]U(&1O(&YO="!G970@=&AE(&5R<F]R+"!Y;W4@87)E"B`@("`@("`@
M:6X@9FEN92!S:&%P92X\+W`^"B`@("`@("`@/#]P:'`@:6YC;'5D95]O;F-E
M("=&:6QE+T-35BYP:'`G.PH@("`@("`@(&5X:70["@H@("`@8V%S92`G=6YR
M96=I<W1E<B<Z"B`@("`@("`@=6YS970H)%]315-324].6R=H;W)D95]T97-T
M7V-O=6YT)UTI.PH@("`@("`@(#\^"B`@("`@("`@/&AT;6P^"B`@("`@("`@
M/&)O9'D@8F=C;VQO<CTB=VAI=&4B('1E>'0](F)L86-K(CX*("`@("`@("`\
M9F]N="!F86-E/2)(96QV971I8V$L($%R:6%L+"!S86YS+7-E<FEF(B!S:7IE
M/2(R(CX*("`@("`@("!4:&4@=&5S="!S97-S:6]N(&AA<R!B965N('5N<F5G
M:7-T97)E9"X\8G(^"B`@("`@("`@/&$@:')E9CTB=&5S="YP:'`B/D=O(&)A
M8VL\+V$^('1O('1H92!T97-T+G!H<"!P86=E+CQB<CX*("`@("`@("`\/W!H
M<`H@("`@("`@(&5X:70["B`@("!]"GT*"G)E<75I<F4@5$535%]414U03$%4
M15,@+B`G:&5A9&5R+FEN8R<["G)E<75I<F4@5$535%]414U03$%415,@+B`G
M=F5R<VEO;BYI;F,G.PH*/SX*"CQH,3Y(;W)D92!!<'!L:6-A=&EO;G,\+V@Q
M/@H\=6P^"CP_<&AP"@HO*B!'970@2&]R9&4@;6]D=6QE('9E<G-I;VX@:6YF
M;W)M871I;VXN("HO"B1M;V1U;&5S(#T@)&AO<F1E7W1E<W0M/F%P<&QI8V%T
M:6]N3&ES="@I.PIF;W)E86-H("@D;6]D=6QE<R!A<R`D87!P(#T^("1V86PI
M('L*("`@("1A<'`@/2!U8V9I<G-T*"1A<'`I.PH@("`@96-H;R`G/&QI/B<@
M+B`D87!P("X@)SH@)R`N("1V86PM/G9E<G-I;VX["B`@("!I9B`H:7-S970H
M)'9A;"T^=&5S="DI('L*("`@("`@("!E8VAO("<@*#QA(&AR968](B<@+B`D
M=F%L+3YT97-T("X@)R(^<G5N("<@+B`D87!P("X@)R!T97-T<SPO83XI)SL*
M("`@('T*("`@(&5C:&\@(CPO;&D^7&XB.PI]"@H_/@H\+W5L/@H*/#]P:'`*
M"B\J($1I<W!L87D@4$A0(%9E<G-I;VX@:6YF;W)M871I;VXN("HO"B1P:'!?
M:6YF;R`]("1H;W)D95]T97-T+3YG9710:'!697)S:6]N26YF;W)M871I;VXH
M*3L*<F5Q=6ER92!415-47U1%35!,051%4R`N("=P:'!?=F5R<VEO;BYI;F,G
M.PH*/SX*"CQH,3Y02%`@36]D=6QE($-A<&%B:6QI=&EE<SPO:#$^"CQU;#X*
M("`@(#P_<&AP(&5C:&\@)&UO9'5L95]O=71P=70@/SX*/"]U;#X*"CQH,3Y-
M:7-C96QL86YE;W5S(%!(4"!3971T:6YG<SPO:#$^"CQU;#X*("`@(#P_<&AP
M(&5C:&\@)'-E='1I;F=?;W5T<'5T(#\^"CPO=6P^"@H\:#$^1FEL92!5<&QO
M861S/"]H,3X*/'5L/@H@("`@/#]P:'`@96-H;R`D:&]R9&5?=&5S="T^<&AP
M4V5T=&EN9T-H96-K*&%R<F%Y*"=F:6QE7W5P;&]A9',G(#T^(&%R<F%Y*"=S
M971T:6YG)R`]/B!T<G5E+"`G97)R;W(G(#T^("=F:6QE7W5P;&]A9',@;75S
M="!B92!E;F%B;&5D(&9O<B!S;VUE(&9E871U<F5S(&QI:V4@<V5N9&EN9R!E
M;6%I;',@=VET:"!)35`N)R`I*2D@/SX*/#]P:'`@:68@*"1D:7(@/2!I;FE?
M9V5T*"=U<&QO861?=&UP7V1I<B<I*3H@/SX*("`@(#QL:3YU<&QO861?=&UP
M7V1I<CH@/&9O;G0@8V]L;W(](CP_<&AP(&5C:&\@:7-?=W)I=&%B;&4H)&1I
M<BD@/R`G9W)E96XG(#H@)W)E9"<@/SXB/CQS=')O;F<^/#]P:'`@96-H;R`D
M9&ER(#\^/"]S=')O;F<^/"]F;VYT/CPO;&D^"CP_<&AP(&5N9&EF.R`_/@H@
M("`@/&QI/G5P;&]A9%]M87A?9FEL97-I>F4Z(#P_<&AP(&5C:&\@:6YI7V=E
M="@G=7!L;V%D7VUA>%]F:6QE<VEZ92<I(#\^/"]L:3X*("`@(#QL:3YP;W-T
M7VUA>%]S:7IE.B`\/W!H<"!E8VAO(&EN:5]G970H)W!O<W1?;6%X7W-I>F4G
M*2`_/CPO;&D^"CPO=6P^"@H\:#$^4F5Q=6ER960@2&]R9&4@0V]N9FEG=7)A
M=&EO;B!&:6QE<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)&-O;F9I9U]O
M=71P=70@/SX*/"]U;#X*"CQH,3Y02%`@4V5S<VEO;G,\+V@Q/@H\/W!H<"`D
M7U-%4U-)3TY;)VAO<F1E7W1E<W1?8V]U;G0G72LK.R`_/@H\=6P^"B`@("`\
M;&D^4V5S<VEO;B!C;W5N=&5R.B`\/W!H<"!E8VAO("1?4T534TE/3ELG:&]R
M9&5?=&5S=%]C;W5N="==.R`_/CPO;&D^"B`@("`\;&D^5&\@=6YR96=I<W1E
M<B!T:&4@<V5S<VEO;CH@/&$@:')E9CTB=&5S="YP:'`_;6]D93UU;G)E9VES
M=&5R(CYC;&EC:R!H97)E/"]A/CPO;&D^"CPO=6P^"@H\:#$^4$5!4CPO:#$^
M"CQU;#X*("`@(#P_<&AP(&5C:&\@)'!E87)?;W5T<'5T(#\^"CPO=6P^"@H\
M/W!H<`IR97%U:7)E(%1%4U1?5$5-4$Q!5$53("X@)V9O;W1E<BYI;F,G.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O861M:6XO````````````````````````````````````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`T,3<S-C,P,C$`
M,#$S-C$W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]S8FEN+P``````````````````
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#0Q-S,V,S`R,0`P,30U-3(`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+W-B
M:6XO8F%C:W5P;6YG````````````````````````````````````````````
M`````````````````````````````````````````#`Q,#`U-3``,#`R,S0R
M-P`P,#`W-C0Q`#`P,#$P,30Q-38P`#$P-#$W,S8S,#(Q`#`Q-C0T-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!_14Q&`0$!
M"0```````````@`#``$```!4G`0(-````+"_(```````-``@``8`*``8`!<`
M!@```#0````T@`0(-(`$",````#`````!0````0````#````]````/2`!`CT
M@`0(&0```!D````$`````0````$``````````(`$"`"`!`AH4Q0`:%,4``4`
M````$````0```(!3%`"`XQ@(@.,8"&!@#`#@-@T`!@`````0```"````-+$@
M`#1!)0@T024(R````,@````&````!`````0````0`0``$($$"!"!!`@8````
M&`````0````$````+W5S<B]L:6)E>&5C+VQD+65L9BYS;RXQ``````@````$
M`````0```$9R965"4T0`$'H'`(,```"#````````````````````>@```$D`
M```Q````0P```"X```!`````,`````````!'````#P```%P```!,````````
M````````````@@```'```````````````&H````X````5`````````!U````
M`````%D```!@````%P``````````````$0````````!C`````````%T```"!
M`````````'@````:````=P```$@````>````%0``````````````````````
M`````````````&4`````````!0```"``````````?0```$L`````````@```
M``````!G````(0```'P`````````&0```%@```!N````````````````````
M5P`````````O````/````&L````*```````````````H````8@``````````
M````>P```'(```!%`````````&P````6``````````````!Y````1````&T`
M````````6@`````````'```````````````)````<P```&@```!_````7@``
M`&8````E````0@```#<``````````P```&$`````````50``````````````
M``````````!1`````````&0```!O``````````````!T````=@```$H`````
M````-```````````````````````````````````````````````````````
M````````````````````````#```````````````````````````````````
M````````````!```````````````````````````````````````````````
M``````(````&``````````````````````````@`````````'P``````````
M`````````````````````0```"P`````````$```````````````%```````
M````````+0```#,`````````'0```"D````F````````````````````/@``
M`"(````````````````````C`````````"L````+`````````!L```!&````
M/0``````````````-0```#\````.```````````````Z`````````%(````R
M`````````!P``````````````#D````3`````````%,````8````*@``````
M``!?````)P``````````````5@`````````[````3P````````!0````````
M````````````00```$T`````````<0``````````````$@````````!.````
M`````"0```!;````#0``````````````?@`````````V````:0``````````
M```````````````+````1)4$"``````2````+`$``%25!`BJ````$@```&@!
M``!DE00(4P```!(```!Q`0``X$,E"`0````1`!0`>P$``'25!`@H````$@``
M`(,!``"$E00(4`(``!(````L````E)4$""\````2````B0$``*25!`A9````
M$@```)(!``"TE00(`````!(```"@`0``Q)4$""0````2````J0$``-25!`@`
M````$@```+$!``#DE00(.P$``!(```"X`0``])4$"%L````2````P0$```26
M!`@`````$@```,D!```4E@0(`````!(```#1`0``Y$,E"`0````1`!0`V@$`
M`"26!`BQ````$@```"H````TE@0(;````!(````2````-$$E"``````1`/'_
MX0$``$26!`@G````$@```.8!``!4E@0(M0```!(```#M`0``9)8$"#T````2
M````2`$``'26!`@`````$@```/4!``"$E@0(.````!(````!`@``E)8$",`'
M```2````!P(``*26!`AB````$@````X"``"TE@0(3`$``!(````;````Q)8$
M"``````2````3@$``.A#)0@$````$0`4`!0"``#4E@0(`````!(```!9`0``
MY)8$"+D````2````'0(``/26!`@`````$@```"("```$EP0(@0$``!(````B
M````%)<$"!H!```2````*0(``"27!`B'````$@```#("```TEP0(?0```!(`
M```I````1)<$"'P````2````.`(``%27!`@O`@``$@```$`"``!DEP0(````
M`!(```!'`@``=)<$"``````2````3@(``(27!`BB````$@```#,```"4EP0(
MB````!(```!6`@``I)<$"&8$```2````7P(``+27!`B3````$@```#H````H
ME00(`````!(`"`!E`@``Q)<$"$\"```2````;`(``-27!`@`````$@```'$"
M``#DEP0(`````!(```!Y`@``])<$",T````2````@@(``.Q#)0@$````$0`4
M`$`````$F`0(0@```!(```"*`@``%)@$""4````2````D`(``"28!`@`````
M$@```)T````TF`0(`````!(```"7`@``1!0F"`0````1`!0`GP(``$28!`@`
M````$@```$<```!4F`0(*@```!(```!/````9)@$"``````2````5@``````
M````````(````/H#``!@&B8(`````!``\?^E`@``=)@$"``````2````JP(`
M`(28!`@`````$@```+8"``"4F`0(%`4``!(```#"`@``I)@$""8````2````
MQP(``(#C&`@$````$0`-`-("``"TF`0(`````!(```!N````Q)@$"!D````2
M````V`(``-28!`@`````$@```-X"``#DF`0(<````!(```!W````])@$"```
M```2````X@````29!`AF````$@```.X````4F00(`````!(```#V````))D$
M"#D````2````Y0(``#29!`@`````$@```.P"``!$F00(`````!(```!J`0``
M5)D$",X!```2````]@(``&29!`CP````$@````$#``!TF00(<@$``!(```#^
M````\$,E"`0````1`!0`-P$``(29!`C9````$@````D#``"4F00(`````!(`
M```.`P``I)D$"'(````2````%0,``+29!`A.````$@```"$#``#$F00(,P``
M`!(````1`0``U)D$"#H````2````=@```.29!`CY````$@```!D!``#TF00(
M5@```!(````G`P``!)H$"/@"```2````+P,``!2:!`@`````$@```'P````D
MF@0(IP```!(```#M`P``X$,E"``````0`/'_@@```#2:!`@`````$@```(D`
M``!$F@0(#0$``!(````W`P``5)H$"(`````2````/P,``&2:!`A#````$@``
M`$0#``!TF@0()0```!(```!,`P``A)H$"``````2````(`$``)2:!`@`````
M$@```%$#``"DF@0(`````!(```!:`P``M)H$"/(````2````8P,``,2:!`A2
M!@``$@```&H#``#4F@0(;````!(```!X`P``Y)H$".X````2````D````'AH
M"`@`````$@`+`($#``#TF@0(V0```!(```"*`0``!)L$"%D````2````CP,`
M`!2;!`A,`0``$@```)8#```DFP0(`````!(```"B`P``-)L$".L````2````
ME@```$2;!`B!````$@```*L#``!4FP0(-@```!(```"@`@``9)L$"``````2
M````G````'2;!`B7````$@```.8#``#@0R4(`````!``\?^C````$$(E"```
M```1`/'_^0,``&`:)@@`````$`#Q_Y$#``"$FP0(6P```!(````G`0``E)L$
M""<````2````+@$``*2;!`@N````$@```+<#``"TFP0(`````!(````Y`0``
MQ)L$"``````2````O0,``-2;!`@`````$@```%@!``#DFP0(B0```!(```#$
M`P``])L$"&<````2````S0,```2<!`@`````$@```+D``````````````"``
M``"*````%)P$"``````2````TP,``"2<!`@Z````$@```-L#```TG`0(6P``
M`!(```#/````1)P$"+8````2`````&QI8GHN<V\N,@!S=')C<'D`7T193D%-
M24,`;65M8W!Y`&UA;&QO8P!V<VYP<FEN=&8`9F9L=7-H`%]I;FET`&-A;&QO
M8P!F<')I;G1F`'-T<F-A=`!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!?7V5R
M<F]R`&9R96%D`&9O<&5N`&UE;7-E=`!F8VQO<V4`7V9I;FD`9G!U=&,`9G=R
M:71E`%]'3$]"04Q?3T9&4T547U1!0DQ%7P!?7W)E9VES=&5R7V9R86UE7VEN
M9F\`9G)E90!L:6)C<GEP="YS;RXR`%]?7W)U;F5T>7!E`'-T<FYC;7``<W1R
M;F-P>0!?0W5R<F5N=%)U;F5,;V-A;&4`<W1R;F-A=`!S=')D=7``<W1R8VUP
M`&%T;VD`=6YC;VUP<F5S<P!F9&]P96X`;&EB;2YS;RXR`&9L;V]R`%]?<W1D
M97)R<`!F<'5T<P!L:6)C+G-O+C0`=6YS971E;G8`7U]S=&1O=71P`'=A:71P
M:60`<&]P96X`=G-P<FEN=&8`9V5T9'1A8FQE<VEZ90!G971L;V=I;@!C;VYN
M96-T`'5N9V5T8P!S=')E<G)O<@!G971E=6ED`&UE;6UO=F4`7U]S=&1I;G``
M<&-L;W-E`&%T;VP`9V5T96YV`%]?<W)G970`7U]I;F5T7V%D9'(`<7-O<G0`
M9G-C86YF`&9G971S`')E861L:6YK`&1U<#(`<WES=&5M`&5N9'!W96YT`'-L
M965P`'-T<G1O=6P`<V]C:V5T`'-E;&5C=`!R96%D9&ER`')E86QP871H`&%B
M;W)T`'-T<G1O;`!P:7!E`'-T<G)C:'(`8F%S96YA;64`:%]E<G)N;P!I<VEN
M9@!R:6YD97@`96YV:7)O;@!F<W1A=`!C:&1I<@!S971S;V-K;W!T`&YL7VQA
M;F=I;F9O`'=A:70`7U]P<F]G;F%M90!L<W1A=`!F;&]C:P!S:6=N86P`=6YL
M:6YK`&=E=')U<V%G90!S=')C87-E8VUP`')E86QL;V,`9F]R:P!S<V-A;F8`
M7U]I;F5T7VYT;V$`97AE8W8`<F5G8V]M<`!S>6UL:6YK`')E9V5X96,`=&EM
M90!O<&5N9&ER`'!O;&P`<VAU=&1O=VX`9V5T<'=U:60`9V5T8W=D`&=E=&AO
M<W1B>6YA;64`9V5T<'=N86T`9V5T<V5R=F)Y;F%M90!A=&5X:70`9V5T<&5E
M<FYA;64`<F5G97)R;W(`;&]C86QT:6UE7W(`7V5X:70`<W1R8VAR`&-L;W-E
M9&ER`&9C;G1L`'-T<G!B<FL`7U]?=&]L;W=E<@!?961A=&$`7U]B<W-?<W1A
M<G0`7V5N9````.!#)0@%!```Y$,E"`40``#H0R4(!1T``.Q#)0@%,@``\$,E
M"`5/```<0B4(!P$``"!")0@'`@``)$(E"`<#```H0B4(!P4``"Q")0@'!@``
M,$(E"`<'```T0B4(!P@``#A")0@'"0``/$(E"`<*``!`0B4(!PL``$1")0@'
M#```2$(E"`<-``!,0B4(!PX``%!")0@'#P``5$(E"`<1``!80B4(!Q(``%Q"
M)0@'%```8$(E"`<5``!D0B4(!Q8``&A")0@'%P``;$(E"`<8``!P0B4(!QD`
M`'1")0@'&@``>$(E"`<;``!\0B4(!QP``(!")0@''@``A$(E"`<?``"(0B4(
M!R```(Q")0@'(0``D$(E"`<B``"40B4(!R,``)A")0@')```G$(E"`<E``"@
M0B4(!R8``*1")0@')P``J$(E"`<H``"L0B4(!RD``+!")0@'*@``M$(E"`<K
M``"X0B4(!RP``+Q")0@'+@``P$(E"`<O``#$0B4(!S```,A")0@',0``S$(E
M"`<S``#00B4(!S0``-1")0@'-0``V$(E"`<V``#<0B4(!S@``.!")0@'.0``
MY$(E"`<Z``#H0B4(!ST``.Q")0@'/@``\$(E"`<_``#T0B4(!T```/A")0@'
M0@``_$(E"`=#````0R4(!T0```1#)0@'10``"$,E"`=&```,0R4(!T<``!!#
M)0@'2```%$,E"`=)```80R4(!TH``!Q#)0@'2P``($,E"`=,```D0R4(!TT`
M`"A#)0@'3@``+$,E"`=0```P0R4(!U$``#1#)0@'4@``.$,E"`=3```\0R4(
M!U0``$!#)0@'50``1$,E"`=6``!(0R4(!U<``$Q#)0@'6```4$,E"`=9``!4
M0R4(!UH``%A#)0@'7```7$,E"`==``!@0R4(!UX``&1#)0@'7P``:$,E"`=@
M``!L0R4(!V$``'!#)0@'8@``=$,E"`=C``!X0R4(!V0``'Q#)0@'90``@$,E
M"`=F``"$0R4(!V<``(A#)0@':0``C$,E"`=J``"00R4(!VL``)1#)0@';```
MF$,E"`=M``"<0R4(!VX``*!#)0@';P``I$,E"`=P``"H0R4(!W$``*Q#)0@'
M=0``L$,E"`=V``"T0R4(!W<``+A#)0@'>```O$,E"`=Y``#`0R4(!WH``,1#
M)0@'>P``R$,E"`=\``#,0R4(!WT``-!#)0@'?P``U$,E"`>```#80R4(!X$`
M`-Q#)0@'@@``Z`L(``#H(M,#`,,`_S440B4(_R480B4(`````/\E'$(E"&@`
M````Z>#_____)2!")0AH"````.G0_____R4D0B4(:!````#IP/____\E*$(E
M"&@8````Z;#_____)2Q")0AH(````.F@_____R4P0B4(:"@```#ID/____\E
M-$(E"&@P````Z8#_____)3A")0AH.````.EP_____R4\0B4(:$````#I8/__
M__\E0$(E"&A(````Z5#_____)41")0AH4````.E`_____R5(0B4(:%@```#I
M,/____\E3$(E"&A@````Z2#_____)5!")0AH:````.D0_____R540B4(:'``
M``#I`/____\E6$(E"&AX````Z?#^____)5Q")0AH@````.G@_O___R5@0B4(
M:(@```#IT/[___\E9$(E"&B0````Z<#^____)6A")0AHF````.FP_O___R5L
M0B4(:*````#IH/[___\E<$(E"&BH````Z9#^____)71")0AHL````.F`_O__
M_R5X0B4(:+@```#I</[___\E?$(E"&C`````Z6#^____)8!")0AHR````.E0
M_O___R6$0B4(:-````#I0/[___\EB$(E"&C8````Z3#^____)8Q")0AHX```
M`.D@_O___R600B4(:.@```#I$/[___\EE$(E"&CP````Z0#^____)9A")0AH
M^````.GP_?___R6<0B4(:``!``#IX/W___\EH$(E"&@(`0``Z=#]____):1"
M)0AH$`$``.G`_?___R6H0B4(:!@!``#IL/W___\EK$(E"&@@`0``Z:#]____
M);!")0AH*`$``.F0_?___R6T0B4(:#`!``#I@/W___\EN$(E"&@X`0``Z7#]
M____);Q")0AH0`$``.E@_?___R7`0B4(:$@!``#I4/W___\EQ$(E"&A0`0``
MZ4#]____)<A")0AH6`$``.DP_?___R7,0B4(:&`!``#I(/W___\ET$(E"&AH
M`0``Z1#]____)=1")0AH<`$``.D`_?___R780B4(:'@!``#I\/S___\EW$(E
M"&B``0``Z>#\____)>!")0AHB`$``.G0_/___R7D0B4(:)`!``#IP/S___\E
MZ$(E"&B8`0``Z;#\____)>Q")0AHH`$``.F@_/___R7P0B4(:*@!``#ID/S_
M__\E]$(E"&BP`0``Z8#\____)?A")0AHN`$``.EP_/___R7\0B4(:,`!``#I
M8/S___\E`$,E"&C(`0``Z5#\____)01#)0AHT`$``.E`_/___R4(0R4(:-@!
M``#I,/S___\E#$,E"&C@`0``Z2#\____)1!#)0AHZ`$``.D0_/___R440R4(
M:/`!``#I`/S___\E&$,E"&CX`0``Z?#[____)1Q#)0AH``(``.G@^____R4@
M0R4(:`@"``#IT/O___\E)$,E"&@0`@``Z<#[____)2A#)0AH&`(``.FP^___
M_R4L0R4(:"`"``#IH/O___\E,$,E"&@H`@``Z9#[____)31#)0AH,`(``.F`
M^____R4X0R4(:#@"``#I</O___\E/$,E"&A``@``Z6#[____)4!#)0AH2`(`
M`.E0^____R5$0R4(:%`"``#I0/O___\E2$,E"&A8`@``Z3#[____)4Q#)0AH
M8`(``.D@^____R500R4(:&@"``#I$/O___\E5$,E"&AP`@``Z0#[____)5A#
M)0AH>`(``.GP^O___R5<0R4(:(`"``#IX/K___\E8$,E"&B(`@``Z=#Z____
M)61#)0AHD`(``.G`^O___R5H0R4(:)@"``#IL/K___\E;$,E"&B@`@``Z:#Z
M____)7!#)0AHJ`(``.F0^O___R5T0R4(:+`"``#I@/K___\E>$,E"&BX`@``
MZ7#Z____)7Q#)0AHP`(``.E@^O___R6`0R4(:,@"``#I4/K___\EA$,E"&C0
M`@``Z4#Z____)8A#)0AHV`(``.DP^O___R6,0R4(:.`"``#I(/K___\ED$,E
M"&CH`@``Z1#Z____)91#)0AH\`(``.D`^O___R680R4(:/@"``#I\/G___\E
MG$,E"&@``P``Z>#Y____):!#)0AH"`,``.G0^?___R6D0R4(:!`#``#IP/G_
M__\EJ$,E"&@8`P``Z;#Y____):Q#)0AH(`,``.F@^?___R6P0R4(:"@#``#I
MD/G___\EM$,E"&@P`P``Z8#Y____);A#)0AH.`,``.EP^?___R6\0R4(:$`#
M``#I8/G___\EP$,E"&A(`P``Z5#Y____)<1#)0AH4`,``.E`^?___R7(0R4(
M:%@#``#I,/G___\ES$,E"&A@`P``Z2#Y____)=!#)0AH:`,``.D0^?___R74
M0R4(:'`#``#I`/G___\EV$,E"&AX`P``Z?#X____)=Q#)0AH@`,``.G@^/__
M58GE@^P,5U93B=*-=0B+7OR-?)X$B3U$%"8(A=M^*8-]"`!T(XM%"*.`XQ@(
M@#@`=!:)]H`X+W4)C4@!B0V`XQ@(0(`X`'7LN#1!)0B%P'0,@\3T4NAF_O__
M@\00@\3T:'AH"`CH5O[__^AE^/__@^3P@^P8B5PD`(ET)`2)?"0(Z*H```")
M1"0`Z*'^__^-9>A;7E_)PY!5B>6#[`B`/?1#)0@`=`_K.(UV`(/`!*.(XQ@(
M_]*AB.,8"(L0A=)UZ[@`````A<!T$(/L#&C`0"4(Z-5B^_>#Q!#&!?1#)0@!
MR<.05;@`````B>6#[`B%P'05@^P(:/A#)0AHP$`E".BG8OOW@\00H0Q")0B%
MP'0;N`````"%P'02@^P,:`Q")0CHA6+[]X/$$(GVR<.)]E6)Y5=64X'L[#<`
M`(/D\(MU#(/L$(L>B1T<Y!@(Z&HT``"#[`QH@6@("/\U&.08"&B,:`@(:``0
M``"-C>CO__]1Z&KX__^#Q!B-A;CG__]0C97H[___4NB$_?__@\00A<!U:_:%
MP.?__T`/A)(```#_-1CD&`AHFV@("&@`$```C97H[___4N@D^/__7UAJ`(V]
MZ.___U?HC!4``(/$$(7`B85@R/__#X3&!@``@^P,_[5@R/__Z'T2``"#Q!`Q
MTH7`=%2-9?1;7HG07\G#Z&WZ__^#.`)T*H/L$.A@^O__6O\PZ(CW__^#Q!!0
M:/1H"`AJ`6H!Z)9Q``"#Q!#I;O___X/L#&H`Z%QP``"-9?1;7C'2B=!?R</H
M$U$``(7`B85<R/__#X3O!0``@^P(_[5<R/__:+AH"`CH.ET``(/$$(7`=`F`
M.``/A=0!``#'A73(__\*````:@IH&&D("&H`:@#H*'$``(/$$(N5=,C__X'Z
M]`$```^/-`4``#'`.=#'A63(__\`````QX5LR/__`````'U*QX2%&.C__P``
M``!`.=!\\#'2.Y5TR/__?3"-O7C(___\,?:[!````(F]%,C__XN]%,C__XG9
MB?#SJT*#A13(__\0.Y5TR/__?.13:'!I"`AH`!```(VUZ.___U;HN/;__XV]
MZ.___S'`_+G_____\J[WT8/$#$E1C9WH[___4_^U7,C__^@'U`$`@\00A<`/
MA;,$``"+A73(__\YA6S(__]]>HN59,C__X72QX5HR/__``````^$^P$``(N]
M;,C__X7_#XYK`@``BXUHR/__A<D/CN<````QVS'V.YUHR/__#XW7````C57H
MBX48Z/__B95(R/__A<`/A`@!``"+A73(___K$XUV`$:+O+48Z/__A?\/A/,`
M```YQGSL,?8YQGT2B?:+E+48Z/__A=)U&48YQGSP@^P,:@'HVO;__X/$$.E.
M____B?91:@&-A7#(__]04N@`]?__@\00A<!T(HN%<,C__ZA_=7G!^`B%P'58
MQX2U&.C__P````#_C6S(__^+A73(__]&ZZ:-C73(__]646BM@0@(4.CK^/__
M@\00A<`/CRO^___I"?[__P^$]@,``,>%9,C__P$```"+A73(___I5/____^T
MM1CH__]HG&D("&H`:@#H&V\``(/$$.N._[2U&.C__VC8:0@(:@!J`.@!;P``
M@\00BX5PR/__Z63___^+A73(__\YQ@^-"?___XN]2,C__XN-2,C__X'O<#<`
M`(F]3,C___^QD,C__V@8:@@(:``0``"-E>CO__]2Z-'T__^-O>CO__\QP/RY
M______*N]]&#Q`Q)48V%Z.___U#_M5S(___H(-(!`(/$$(7`#X7,`@``Z/CW
M__^#^`")A+48Z/__#XX=____0_^%;,C__X.%2,C__Q`[G6C(__\/C$O^__^+
MA73(___I9_[__RN%;,C__U!H4&H("&@`$```C;7H[___5NA&]/__C;WH[___
M,<#\N?_____RKO?1@\0,25&-G>CO__]3_[5<R/__Z)71`0"#Q!"%P'1B@^P,
M_[5<R/__Z$3O`0"#Q!!0:&!K"`AJ`&H`Z-9M``"#Q!"+O6S(__^%_P^/E?W_
M_XNU:,C__X7V#X^5_?__@^P,_[5<R/__Z"',`0!:_[5@R/__Z#$/``!8Z0S\
M__^-=@"#[`S_M5S(___H/ND!`(V5>,C__XF%6,C__\>%/,C__P````"#Q!")
ME43(___'A4#(__\`````D(/L#/^U6,C__^ARZ@$`@\00A<`/A"<!``"!O3S(
M___S`0``?]N+$(M("(M8!(72BT`,B8U4R/__B850R/__=,"%VW2\A<ETN(7`
M=+2-C7C(__]0`XU`R/__46BM@0@(4NB']O__@\00A<!^E(N%0,C__\>$*'S(
M__\`````_+D&````O\MH"`B)WO.F#X7$````BYU`R/__QX0K?,C__P$```"+
MA4#(___'A"B`R/__`````/RY!P```+_1:`@(B[54R/__\Z8/A3/___^+E4#(
M___'A"J`R/__`0```,>$*H3(__\`````C9P5A,C__U!3:*V!"`C_M5#(___H
MZO7__X/$$(7`#X[S_O__@^P,_X4\R/__@X5`R/__$(.%1,C__Q#_A6C(____
MM5C(___H2^D!`(/$$(7`#X79_O__@^P,_[58R/__Z%*[`0"#Q!#I,_[___RY
M!````+_8:`@(B=[SI@^%E?[__XN51,C__\="!`(```#I)O___X/L#&CT`0``
M4FB0:P@(:@!J`.C(:P``@\0@NO0!``#'A73(___T`0``Z9[Z__^#[`S_M5S(
M___H_^P!`(/$$%!H0X(("&H!:@#HD6L``%G_M6#(___H&0T``+K_____C67T
M6UZ)T%_)PX/L#/^U8,C__^C\#```@\0,:.!K"`AJ`6H!Z%=K``"#Q!#IZOG_
M_XN53,C__X-Z"`%U'/]R#&H!_W($BYU(R/___[.0R/__Z#8```"#Q!"#[`QJ
M`.B]]O__@^P,C87H[___4&@,;`@(:-QH"`AJ`&H`Z`!K``"Z_____^EV____
MB?95B>575E.![!QA``#'A;B?__\`````QX6TG___`````,>%L)___P````#H
M94H``(7`B86LG___#X0_"0``BT4,@_@!#X1?!P``@_@"#X4X!P``@^P,:(%H
M"`C_-1CD&`AHR&T("&@`$```C97HW___4NB>\/__@\0@_W44:/AM"`AH`!``
M`(VUZ.___U;H@O#__XGW,<#\N?_____RKO?1@\0,25%6_[6LG___Z-O-`0"#
MQ!"%P`^%50@``(/L#/^UK)___^CBY0$`B86HG___B00DZ$#G`0"#Q!"%P(G#
M#X2("```@^P(_S"-M>C/__]6Z"[O__^+6P2)G;R?___\,<"-O>C?__^Y____
M__*NNP`0``#WT4F)WX/$#"G/5XV5Z-___VA:;`@(4NB$\___C;WHW____#'`
MN?_____RKO?128/$#"G+4U:-M>C?__]6Z%[S__^#Q`R-E=2?__]2:*V!"`C_
MM;R?___H%//__UG_M:B?___HO+@!`/^UU)___V@H;@@(:``0``"-O>CO__]7
MZ'SO__\QP/RY______*N]]&#Q!Q)48V=Z.___U/_M:R?___HT<P!`(/$$(7`
M#X4M!P``@^P,_[6LG___Z-CD`0")A4R?__^)]H/$$(/L#/^U3)___^@KY@$`
M@\00A<`/A,D```"+,(-]#`*)M>2>__^+6`0/A-,#``#\N1@```"_:FP("(NU
MY)[___.F#X0Z!```_+D2````OX)L"`B+M>2>___SI@^$?00``/RY#````+^4
M;`@(B[7DGO__\Z8/A(@$``#\OZ!L"`B+M>2>__^Y#@```/.F#X2]!```_+^N
M;`@(B[7DGO__N0X```#SI@^%_`(``+D%````O[QL"`B)WO.F#X7H`@``@^P,
MQX6XG___`0```/^U3)___^ABY0$`@\00A<`/A3?___^+G;B?__^%VW0:@+WH
MO___``^%N@4``("]Z*___P`/A4H%``"+M;2?__^%]G0-@+WHG___``^%T`0`
M`(/L#/^U3)___XV=Z,___^@HMP$`B1PD_S7LXQ@(:,%L"`AH`!```(VUZ.__
M_U;HY>W__X/$&&C8;`@(5NC'\?__@\00A<")PP^$`P8``%!J)&H!:'AN"`CH
M^_+__XD<).C#\?__C;WHW____#'`N?_____RKKX`$```]]%)B?.#Q`PIRU.-
ME>C?__]HH&X("%+H(O'__XV]Z-____PQP+G_____\J[WT4F#Q`PISE9HVVP(
M"(V]Z-___U?H^/#__XV-Z-___XD,).@:[O__@\00A<`/A8@#``"#[`QH[&P(
M".AB[/__QP0D]FP(".A6[/___W4(:,AN"`AH`!```(V]Z.___U?H#>W__S'`
M_+G_____\J[WT8/$'$E1C;7H[___5O^UK)___^ABR@$`@\00A<`/A;X$``"#
M[`S_M:R?___H:>(!`(D$)(G&Z,OC`0"-E="?__^#Q`Q2:*V!"`C_,(G#Z!_P
M__^#Q`R-A<R?__]0:*V!"`C_<P3H"/#__XV]R)___X/$#%=HK8$("/]S".CQ
M[___@\0,C8W$G___46BM@0@(_W,,Z-KO__^)-"3HAK4!`(N5T)___XT$U0``
M```IT,'@!0'0BXW$G___P>`$@\00.XW(G___BYW,G___B870G___?@(IP3G9
M#X2.`@``@^P,_W4(46C0;P@(:``0``"-M>CO__]6Z`?L__^)]S'`_+G_____
M\J[WT8/$'$E15O^UK)___^A@R0$`@\00A<`/A?@#``#'A<"?__\`````4/]U
M%&BM@0@(C9W8G___4XVUP)___^B(\/__5E.-E>C/__]2_[6LG___Z!P$``"#
MQ""#O;"?__\!&<"-9?1;7O?07\G#_+D.````OP-M"`B+M>2>___SIG4?N04`
M``"_O&P("(G>\Z9U#\>%M)___P$```#I)?S___RY#@```+\1;0@(B[7DGO__
M\Z8/A0S\__^-E>B?__]6Z0@!``"0_+D+````OQ]M"`CSI@^$%@$``/RY"@``
M`+\M;0@(B[7DGO__\Z8/A"L!``#\N0T```"_.FT("(NUY)[___.F#X0E`0``
M_+D/````OTIM"`B+M>2>___SI@^%S_O__[G_____4(V]Z-___S'`\J[WT4FZ
M`!```"G*4FA9;0@(ZR"Y_____U"-O>C?__\QP/*N]]%)N``0```IR%!H9FT(
M"(V5Z-___U+H*.[__XV]Z-____PQP+G_____\J[WT4F^`!```(/$#"G.5E.-
MG>C?__]3Z/WM___I(/O__[G_____4(V]Z-___S'`\J[WT4FZ`!```"G*4FA[
M;0@(ZZ*)]HV5Z+___U`QP(G7N?_____RKO?12;@`$```*<A04U+H`.W__^G3
M^O__N?____]2C;WHW___,<#RKO?12;X`$```*<Y6:(YM"`CI4O___XV5Z*__
M_U?KL%!J`5-H[&P(".CO[/__Z9+Z__]0:@%3:/9L"`CHW.S__^E_^O__4F@H
M<`@(:@%J`.B(8P``@\00QX6PG___`0```.E7_/__C8P(\/'__^EF_?___W4,
M:%1P"`AJ`&H`Z%EC``"-9?1;7KC_____7\G#@^P,:(%H"`C_-1CD&`AHF'`(
M"&@`$```C87HW___4.FE^/___(V]Z-___U,QP+G_____\JZ^`!```/?128GS
M*<M3:)UM"`B-E>C?__]2Z+GL__^-O>C?___\,<"Y______*N]]%)@\0,*<Y6
MC9WHG___4XV5Z-___U+HC>S__X/$$.G-^O___#'`5[G_____C;WHW___\JZ^
M`!```/?128GS*<M3:*QM"`B-E>C?__]2Z%;L__^-O>C?___\,<"Y______*N
M]]%)@\0,*<Y6C87HK___4(V=Z-___U/H*NS__X/$$.E3^O___(V]Z-___U*Y
M______*NNP`0``#WT4F)WBG.5FB[;0@(C97HW___4NCUZ___C;WHW____#'`
MN?_____RKO?128/$#"G+4XVUZ+___U:-E>C?__]2Z,GK__^#Q!#IY?G__X/L
M#/^UK)___^A/XP$`@\004&C$<`@(:@'I@_[__X/L#/^UK)___^@QXP$`@\00
M4&@`<0@(:@'I9?[__X/L#/^UK)___^@3XP$`@\004&A#@@@(:@'I1_[__X/L
M$.A/ZO__6?\PZ'?G__^#Q!!0:$!Q"`AJ`>DG_O___W44:&AQ"`AJ`>D8_O__
M4VC@:P@(:@'I"_[__XUV`%6)Y5=64X'L$!```/]U"(MU%%:+?1!7Z,Q$``"#
MQ!"%P+K_____=0<QTO8&!'4-C67T6UZ)T%_)PXUV`(/L#/]U#.@Y6P``B<-8
M6FBC<0@(4_\U[.,8"&BW<0@(C97H[___:``0``!2Z!OG__^#Q!13Z"+M__]9
M6VH`C87H[___4.AZ!```@\00A<")PP^$Z@```(/L#%#H=`$``(/$$#'2A<!U
MBH/L#%/H2@$``(/$$(7`=']0_W4(BQ:#XOM25^@#,```@\00A<`/A>,```#W
M!OO___]U3(/L#&H`_W4,:,!Q"`AHSG$("&BG>@@(Z'0:``"#Q""%P'0I_W4,
M:-AQ"`AJ`&H`Z%Q@``"#Q`S_=0C_-E?HKB\``+KY____Z0O___^#[`Q3Z/\`
M```QTNG[_O__@^P0Z-SH__]:_S#H!.;__XD$)/]U#&CX<0@(:``0``"-A>CO
M__]0Z"CF__^#Q!QJ`&H`C;WH[___5^C=7@``NOO____ILO[___]U#&@D<@@(
M:``0``"-M>CO__]6Z/+E__^#Q`QJ`&H`C8WH[___4>BG7@``NOS____I?/[_
M_X/L#/]U".@&X0$`B00D_W4,:&QR"`AH`!```(V-Z.___U'HKN7__X/$'&H`
M:@"-G>CO__]3Z&->``"Z^O___^DX_O__D%6)Y8M5"#'`A=)T"#'`@SH`#Y_`
MR<.)]E6)Y8M5"(72N`$```!T"#'`@SH`#Y3`R<.-=@!5B>564X'L`!```(MU
M"(7VN/____]T&HL&,=N%P'\IBT8$A<!U$H/L#%;H/>O__XG8C67X6U[)PX/L
M#%#H*^O__X/$$.O@B?:#[`AJ"%#HJ>?__X/$$(7`=$.#[!#HBN?__UG_,.BR
MY/__B00D_W8$:)QR"`AH`!```(V=^.___U/HUN3__X/$'&H!:@!3Z)%=``"[
M_____X/$$.N"@^P,_S;HE>K__X/$$(7`#XEM____@^P0Z#+G__]:_S#H6N3_
M_XD$)/]V!&B\<@@(ZZ:058GER>DG____C78`58GE5U93@>PD$```BT449HF%
MYN___VHO_W4(Z%#F__^#Q!"%P(G"#X2/`0``B=<QP/RY______*N]]&-4?^_
MLF@("+G_____\J[WT;L``0``*<LQR3G:#X>U````@^P,:@CH^>3__X/$$#')
MA<")Q@^$G````,<``````,=`!`````#\,<"Y_____XM]"/*N]]%F@[WF[___
M`(U9_W5]@^P,C7L!5^BUY/__@\00A<")1@0/A"T!``!25VH`4.B]Y___@\0,
M4_]U"/]V!.B>YO__@\009H.]YN___P!U55=HI`$``/]U#/]V!.@@Z?__@\00
MA<")!GA[@^P(_W404.@;YO__@\00A<")\0^%L@```(UE]%M>B<A?R<.Y____
M_[^R:`@(\J[WT8U<&?_I;/___Y!0BWT(_#'`N?_____RKO?122G+4VBR:`@(
M_W8$Z,OF__^#Q!!7:*0!``#_=0S_=@3HI^C__X/$$(7`B09YAXGV@^P0Z)3E
M__];_S#HO.+__XD$)/]V!&CK<@@(:``0``"-G>CO__]3Z.#B__^#Q!QJ`&H`
M4^B;6P``B?&-9?1;7HG(7\G#C78`BU4(Z6G^__^#[`S_-NB2Z/__@\00Z#KE
M__^#.",/E,$/MM%*B?&)%NO)@^P,5NBAZ/__,<GI'/___XGV58GE@^P(#[]%
M#%!J!F@"!@``_W4(Z.[]___)PU6)Y8/L"`^_10Q0:@)H`@8``/]U".C2_?__
MR<-5B>575E.![!P0``"+%>1#)0B+70@/OT(..=B+?0P/A+P!``"+->!#)0@/
MOTX..?D/A*H!``"#[`R-A>#O__]0Z*OC___H9N7__X/$$(7`B<8/C,X!```/
MA+4```"#[`S_M>3O___HQ>?__XV=Z.___X/$$.LDB?;&A`7G[___`%!J`&H`
M4^B-6@``7_\UZ$,E".@9X___@\0046C_#P``4_^UX.___^ADY/__@\00A<!_
MQ8/L#/^UX.___^AOY___@\0,:@*-G=SO__]35NB]X/__@\000`^$;P$``(N5
MW.___XG0@^!_=!N#^']T"(7`#X5P`0``B=>#YW^#_W\/A`@!``"-9?1;7HG0
MP?@(7\G#@^P,:@#H%.?__\<$)`$```#H".?__\<$)`(```#H_.;__UC_M>#O
M___H\.;__UY8:@!3Z,;A__]96VH!5^B\X?__6%IJ`O^UY.___^BMX?__7UC_
M=13_=1#H<.3__XF%W.___^AEX___7O\PZ(W@__^#Q`Q0:`QS"`C_->A#)0CH
MV>+__^A$X___@\00@S@.=%C_->A#)0AJ`FH!:/YV"`CHV.7__UO_->A#)0CH
M[.'__UG_M>3O___H8.;__XN%W.___XUE]%M>7\G#B?90:#!S"`AJ`&H`Z$%:
M``"-9?1;7KC_____7\G#_S7H0R4(:EAJ`6AH<P@(ZZ:#[`S!^@A25FC$<P@(
M:@!J`.@-6@``Z\J#[!#HL^+__UK_,.C;W___@\004&CX<P@(:@%J`>CI60``
M@\00ZZ.#[!#HC.+__UK_,.BTW___B00D5F@8=`@(Z[.#[`Q05FA<=`@(ZZ>0
M58GE5U93@^P,BW4(B47PBWT,C4;\.?B)TW8I48L7B=#WT`,&4`,34HM-\/\Q
MZ&KB__^#Q!"%P'X_`0>-9?1;7E_)PY"+%H/L"('"`!```(D64O\SZ,/B__^#
MQ!"%P(D#=;E0:`%W"`AJ`6H!Z$M9``"#Q!#KI8GV@^P,BW7P_S;H-^7__XM=
M\,<#_____^C9X?__6O\PZ`'?__^#Q`Q0:)!T"`C_->A#)0CH3>'__^BXX?__
MQP``````@\00C67T6UY?R<.-=@!5B>575E.![#P0``"+11`QR8U=$(U5%(7`
MZPN0B=:+/D&#P@2%_W7T@^P,C12-"````%+HO-___X/$$(7`B870[___#X2H
M`P``BT4,BXW0[___B0&-4P2Y`0```(L#ZQ&)TXN]T.___XD$CX/"!$&+`X7`
M=>N+E=#O__^#[`R-M>#O___'!(H`````QX7([___`````%;H&>#__X/$$.C1
MX?__A<")A<SO__\/C`$#```/CK<#``"#[`S'A<3O__\`$```_[7D[___Z"7D
M___'A<#O__\`````QP0D`!```.@/W___6EF+70B)`VH#_[7@[___Z.OC__^#
MR`2#Q`Q0:@3_M>#O___HU^/__X/$#&@`"```:@"-O>CW__]7Z/'A__^#Q`QH
M``@``&H`C9WH[___4^C;X?__BXW@[___B<ZX`0```(/A'\'N!=/@"82UZ/?_
M_X/$$.A'X/__C;78[___QP``````QX78[___`0```,>%W.___P````#IJ0``
M`(GV4(N%Q.___RN%P.___TA0BX7`[___BTT(`P%04N@OX/__@\00@_C_#X1J
M`@``A<`/CN<```"+E<3O__\!A<#O__]*.Y7`[___#XZV`0``4&@`"```:@!7
MZ#3A__^#Q`QH``@``&H`4^@DX?__BXW@[___B<JX`0```(/A'\'J!=/@@\00
M"825Z/?__^B0W___QP``````QX78[___`0```,=&!`````"#[`Q64U-7BX7@
M[___0%#H%=[__X/$(.A=W___BQ"%T@^%XP```(N5X.___XG0P>@%B=&#X1^+
MA(7H]___T^BH`0^%$O___U!J`8V5U.___U+_M<SO___HS=O__X/$$#N%S.__
M_P^%//___\>%R.___P$```"+30B+&8NUP.___\8$,P"+O<CO__^%_P^$H@``
M`(N%U.___ZA_N_____]U%XG#P?L(#X0"`0``@?O_````#X1P`0``@^P(BWT(
M_S=3_W4,:+1T"`AJ`6H`Z/=5``"#Q""+30B#[`S_,>@7XO__@\00BW4(@^P,
MQP8`````_[70[___Z/WA__^-9?2)V%M>7\G#C78`Z&O>__^#.`0/A`____^+
M30B+&8NUP.___\8$,P"+O<CO__^%_P^%7O___\>%U.___P````!3:@"-E=3O
M__]2_[7,[___Z-;:__^#Q!#I-____XGV@^P(@87$[___`!```/^UQ.___XM%
M"/\PZ*_>__^+30B#Q!")`>D@_O__@^P0Z.K=__]:_S#H$MO__X/$$%!H&'<(
M"&H!:@'H(%4``#';@\00@^P,_[70[___Z#WA__^-9?2)V%M>7\G#@^P0Z*O=
M__]>_S#HT]K__X/$$%!H*G<("&H!:@'HX50``(/$$.DN_/__Z(3=__^#.`0/
MA'?^__^#[!#H<]W__UG_,.B;VO__@\004&A%=P@(:@%J`.BI5```@\00Z4W^
M__^+10C_,&AB=P@(:@%J`.B.5```@\00Z9+^__^#[`S_M>#O___H>.#__\<$
M)`$```#H;.#__\<$)`(```#H8.#__UA::@'_M>3O___H,=O__U]8:@+_M>3O
M___H(MO__UM>_[70[____W4,Z.+=___HW=S__UG_,.@%VO__@\0,4/]U#&AL
M=P@(Z)39___'!"3_____Z'C?__]5B>564X'LL`$``(MU"(U-#(FU6/[__[H!
M````@_IC?Q.)RXL#@\$$B8256/[__T*%P'7HQT7H`````.A(W?__A<!T)8/L
M#(V-5/[__U'H1=S__X/$$#'`]H54_O__?P^5P(UE^%M>R<.#[`QJ`.B5W___
MQP0D`0```.B)W___QP0D`@```.A]W___6%IJ`FCB;`@(Z!_?__]9B<-8:@!3
MZ$/:__]86FH!4^@YVO__65AJ`E/H+]K__UA:C958_O__4E;H\-S__XD$).BH
MWO__58GE5U93@^P4:)FB&`C_=0S'1?``````Z(O8__^#Q!"%P(G&#X3N````
M@^P,:`$0``#'1>P`$```QT7H`````.CSV?__@\00A<")QP^$X0```,8``.L+
MD(M%Z(@<.$")1>B+7@1+A=N)7@0/B(L```"+%@^V&D*)%H/[_W1.BT7L.47H
M==*+5>B#[`B!P@$0``!2BTWH@<$`$```5XE-[.CSV___@\00A<")QW6J_S7H
M0R4(:DEJ`6C8=`@(Z-;=___'1>@`````@\00@^P,BTWHQ@0/`%;H;-C__X/$
M$(/X_W0KP?@(=`.)1?"+=0B)/HM%\(UE]%M>7\G#@^P,5NB#V/__B<.#Q!#I
M:O___\=%\/_____KU/\UZ$,E"&I<:@%H)'4(".ALW?__N/_____KP?\UZ$,E
M"&HF:@%HA'4(".OC58GE4X/L#(U%^,=%^`````#_=0A0Z*+^__^#Q!"#^/^)
MPW0\A<!T(XM%^(/L#(`X`'4%N']W"`A04VBL=0@(:@%J`.BL40``@\0@@^P,
M_W7XZ,[=__^)V(M=_,G#C78`@^P0Z#S:__]9_S#H9-?__X/$$%!HV'4("&H!
M:@#H<E$``(/$$(/L#/]U^.B4W?__B=B+7?S)PY!5B>564^CRUO__B<:[`P``
M`#GS?12-=@"#[`Q3Z#O=__]#@\00.?-\[^C>V?__QP``````C67X6U[)PY!5
MB>575E.#[`R+?13HC]K__X/X_XG##X3`````A<`/A<P```"+=0B%]G0D@_[_
M#X3&````@^P(:@!6Z,'7__^)PXDT).C7W/__@\000W1@BW4,@_X!="2#_O\/
MA+D```"#[`AJ`5;HE=?__XG#B30DZ*O<__^#Q!!#=#2+=1"#_@(/A+0```"#
M_O\/A/\```"#[`AJ`E;H9=?__XG#B30DZ'O<__^#Q!!##X6,````@^P0Z!G9
M__]?_S#H0=;__X/$#%!HBW<("/\UZ$,E".B-V/__7FK_Z+7;__^04&@$=@@(
M:@%J`>@U4```@\00B?:-9?2)V%M>7\G#@^P(:@)HXFP(".C'V___@\00@_C_
MB<8/A1W____KEH/L"&H":.)L"`CHJ-O__X/$$(/X_XG&#X4J____Z73____H
M@-7__[L#````.<.)QGQIZ(#8__^#[`C'``````#_=1A7Z&[9__^#[!#H9MC_
M_UO_,.B.U?__@\004%=H)'8("/\UZ$,E".C9U___@\04Z47___^#[`AJ`FCB
M;`@(Z#+;__^#Q!"#^/^)Q@^%Y/[__^G^_O__C78`@^P,4T/H8MO__X/$$#GS
M?8:#[`Q30^A1V___@\00.?-\WNEP____D%6)Y5=64X'L6`@``(M5"(M%#(VU
MX/?__\<"`````,<``````%;'A<CW__\`````QX7,]___`````,>%P/?__P``
M``#'A<3W__\`````QX6T]___`````,>%L/?__P````#HGM;__X/$$$`/A/0!
M``"#[`R-G=CW__]3Z(76__^#Q!!`#X3A`0``BX78]___BY7@]___.=!]`HG0
MC7@!4&H$:@12Z(O:__^#Q!!`#X0@`@``4&H$:@3_M=CW___H<=K__X/$$$`/
MA`8"``"#[`S_=13_=1#_<P3_=@1J`.A!_?__@\0@@[W@]____XF%N/?__P^$
MB`(``(VUZ/?__XV=T/?__XUV`%%H``@``&H`5NA.V/__BXW@]___@\00@_G_
M=!:)RK@!````@^$?P>H%T^`)A)7H]___BXW8]___@_G_=!:)RK@!````@^$?
MP>H%T^`)A)7H]___QT,$`````,>%T/?__P$```#H@];__X/L#,<``````%-J
M`&H`5E?H'M7__X/$((7`#XY;`0``BXW@]___A<E^&8G*P>H%@^$?BX25Z/?_
M_]/HJ`$/A?@```"+C=CW__^%R7X9B<K!Z@6#X1^+A)7H]___T^BH`0^%K0``
M`(.]X/?___\/A23___^#O=CW____#X47____BYVP]___A=MU->CTU?__QP``
M````4&H!C;6\]___5O^UN/?__^B)TO__@\00A<#'A;3W________#X5C`0``
MBT4(BQ"%TG0*BXW,]___Q@0*`(M=#(L3A=)T"HNUQ/?__\8$,@"+A;3W__^-
M9?1;7E_)PXV=V/?__U!H2'8("&H!:@'HRTP``(/$$.D(_O__C78`@^P(C87$
M]___4(V-P/?__U&+50R-A=CW___HY?+__X/$$.DL____D(/L"(V%S/?__U"-
MC<CW__]1BU4(C87@]___Z+WR__^#Q!#IX?[__U!H;'8("&H!:@'H8DP``(/$
M$.GC_?__B?;H`]7__\<``````%)J`8V5O/?__U+_M;CW___HF-'__X/$$(7`
M#X3`_O__Z-C4__^+"(7)=5.+A;SW__^H?W5)P?@(B86T]___@^P,_[78]___
MZ`'8__]8_[7@]___QX78]________^CKU___@\00QX7@]________\>%L/?_
M_P$```#I8O[__\>%M/?________KM(.]V/?___\/A6O]___I:/[__^A<U/__
MBSB%_W48BX6\]___J']U#L'X"(F%M/?__^EZ_O__QX6T]________^EK_O__
MC78`58GEBT445E,QR8U=%(U5&(7`ZPJ)T(LP08/"!(7V=?2#[`R-%(T$````
M4NA,TO__@\00A<")QG1'BP,QR87`C5,$B09U!>L/B02.B=.+`T&#P@2%P'7Q
MQP2.`````%;_=1#_=0S_=0CHR_O__XG#B30DZ#77__^-9?B)V%M>R<.#[!#H
MI-/__UK_,.C,T/__@\004&BI=P@(:@%J`>C:2@``@\00ZY*058GE5E.#[!"+
M=0C_=0Q6C57T4HU%\%#H=/O__X/$$(7`B<-T*XM-$(7)=22+1?"%P'4ZBT7T
MA<!T2H/L#%!6:+UW"`AJ`6H`Z(=*``"#Q""#[`S_=?#HJ=;__UC_=?3HH-;_
M_XUE^(G86U[)PX/L"%#_->A#)0CHF-+__X/$$.NRC78`5FB<=@@(:@%J`.A!
M2@``@\00@^P,_W7PZ&/6__]8_W7TZ%K6__^-9?B)V%M>R<.058GE5U93@^P,
MBT4,,<F+?0B-=0R-51"%P.L+D(G0BQA!@\($A=MU](/L#(T4C00```!2Z.C0
M__^#Q!"%P(G##X36````BP8QR87`C58$B0-U!>L/B02+B=:+!D&#P@2%P'7Q
MQP2+`````%-7C57P4HU-[%'H8_K__X/$$(7`B<9T)(M%[(7`=7N+1?"%P'0\
M@^P,4%=HO7<("&H!:@#H?4D``(/$((/L#/]U[.B?U?__6/]U\.B6U?__B1PD
MZ([5__^-9?1;B?!>7\G#5VB<=@@(:@%J`.A%20``@\00@^P,_W7LZ&?5__]8
M_W7PZ%[5__^)'"3H5M7__XUE]%N)\%Y?R<.#[`A0_S7H0R4(Z$W1__^#Q!#I
M;O___X/L$.BMT?__6O\PZ-7.__^#Q!!0:*EW"`AJ`6H!Z.-(``"#Q!#I`/__
M_XUV`%6)Y593@^P0BUT(_W4,4XU5]%*-1?!0Z'CY__^#Q!"%P(G&="2+1?"%
MP'5TBT7TA<!T.8/L#%!3:+UW"`AJ`6H`Z))(``"#Q""#[`S_=?#HM-3__UC_
M=?3HJ]3__X/$$(UE^%N)\%[)PXUV`%-HG'8("&H!:@#H74@``(/$$(/L#/]U
M\.A_U/__6/]U].AVU/__@\00C67X6XGP7LG#B?:#[`A0_S7H0R4(Z&G0__^#
MQ!#I=?___Y!5B>564X'L&!```(M="&HO4^C*T___@\00A<`/A:L```"#[`Q3
M_S48Y!@(:-5W"`AH`!```(V=^.___U/H_\W__X/$(/]U#%.-E?3O__]2C87P
M[___4.B!^/__@\00A<")QG0LBX7P[___A<!U>HN%].___X7`=$"#[`Q04VB]
M=P@(:@%J`.B51P``@\0@B?:#[`S_M?#O___HLM/__UC_M?3O___HIM/__X/$
M$(UE^%N)\%[)PXGV4VB<=@@(:@%J`.A91P``@\00Z\13:+QV"`AJ`&H`Z$5'
M``"-9?A;N/____]>R<.0@^P(4/\UZ$,E".AIS___@\00Z6____^058GE5E.!
M[+`!``"+=0B-30R)M5C^__^Z`0```(/Z8P^/GP```(G+BP.#P02)A)58_O__
M0H7`=>2#^F,/CX,```#'A)58_O__`````(V%6/[__U!6C8U4_O__48V54/[_
M_U+H=??__X/$$(7`B<-T+HN%4/[__X7`#X6*````BX54_O__A<!T2(/L#%!6
M:+UW"`AJ`6H`Z(5&``"#Q""#[`S_M5#^___HI-+__UC_M53^___HF-+__X/$
M$(UE^(G86U[)P\=%Z`````#I?/___U9HG'8("&H!:@#H048``(/$$(/L#/^U
M4/[__^A@TO__6/^U5/[__^A4TO__@\00C67XB=A;7LG#@^P(4/\UZ$,E".A)
MSO__@\00Z5____^058GE5E.![+@1``"+=0AJ+U;HJM'__X/$$(7`#X4``0``
M@^P,5O\U&.08"&C5=P@(:``0``"-M?CO__]6Z-_+__^-70R)M5CN__^Z`0``
M`(/$((GV@_IC#X^A````B=F+`8/#!(F$E5CN__]"A<!UY(/Z8P^/A0```,>$
ME5CN__\`````C858[O__4%:-G53N__]3C950[O__4N@=]O__@\00A<")PW0P
MBX50[O__A<`/A88```"+A53N__^%P'1-@^P,4%9HO7<("&H!:@#H+44``(/$
M((GV@^P,_[50[O__Z$K1__]8_[54[O__Z#[1__^#Q!"-9?B)V%M>R</'A>CO
M__\`````Z7?___]6:)QV"`AJ`6H`Z.1$``"#Q!#KMU9HO'8("&H`:@#HT$0`
M`(UE^%NX_____U[)PX/L"%#_->A#)0CH]<S__X/$$.EC____D%6)Y5=64X/L
M#(M%##')BWT(C74,C540A<#K"Y")T(L808/"!(7;=?2#[`R-%(T$````4NAT
MR___@\00A<")PP^$U@```(L&,<F%P(U6!(D#=07K#XD$BXG6BP9!@\($A<!U
M\<<$BP````!35XU5\%*-3>Q1Z._T__^#Q!"%P(G&="2+1>R%P'5[BT7PA<!T
M/(/L#%!7:+UW"`AJ`6H`Z`E$``"#Q""#[`S_=>SH*]#__UC_=?#H(M#__XD<
M).@:T/__C67T6XGP7E_)PU=HG'8("&H!:@#HT4,``(/$$(/L#/]U[.CSS___
M6/]U\.CJS___B1PDZ.+/__^-9?1;B?!>7\G#@^P(4/\UZ$,E".C9R___@\00
MZ6[___^#[!#H.<S__UK_,.AAR?__@\004&BI=P@(:@%J`>AO0P``@\00Z0#_
M__^-=@!5B>575E.![$@(``"+50B-A>#W___'`@````!0QX70]___`````,>%
MU/?__P````#'A<3W__\`````Z.7*__^#Q!!`#X0>`@``46H$BYW@]___:@13
MZ/K.__^#Q!!`C7L!#X0P`@``@^P,_W40_W4,:@+_M>3W__]J`.C%\?__@\0@
M@[W@]____XF%R/?__P^$V0```(VUZ/?__XV=V/?__^L(D$(/A+T```!0:``(
M``!J`%;HR\S__XN-X/?__X/$$(/Y_W06B<JX`0```(/A'\'J!=/@"825Z/?_
M_\=#!`````#'A=CW__\!````Z"'+__^#[`S'``````!3:@!J`%97Z+S)__^#
MQ""%P`^.L0```(N5X/?__X72?H>)T,'H!8G1@^$?BX2%Z/?__]/HJ`$/A&S_
M__^#[`B-C=3W__]1C970]___4HV%X/?__XM5".A1Z/__@\00BY7@]___0@^%
M1/___Y`Q_X7_=37HH<K__\<``````%!J`8V=S/?__U/_M<CW___H-L?__X/$
M$(7`QX7$]________P^%D@```(M-"(L1A=)T"HN%U/?__\8$`@"+A<3W__^-
M9?1;7E_)P^A+RO__QP``````4&H!C87,]___4/^UR/?__^C@QO__@\00A<`/
MA&O____H(,K__XLPA?8/A;````"+A<SW__^H?P^%H@```,'X"(F%Q/?__X/L
M#/^UX/?__^A!S?__@\00QX7@]________^EN____Z-K)__^+$(72=1B+A<SW
M__^H?W4.P?@(B87$]___Z4O____'A<3W________Z3S___]3:$AV"`AJ`6H!
MZ.Y```"#Q!!1:@2+G>#W__]J!%/HRLS__X/$$$"->P$/A=#]__]2:&QV"`AJ
M`6H!Z+Y```"#Q!#IN?W__\>%Q/?________I6/___XUV`%6)Y8M%$%93,<F-
M71"-512%P.L*B="+,$&#P@2%]G7T@^P,C12-!````%+H=,?__X/$$(7`B<9T
M18L#,<F%P(U3!(D&=07K#XD$CHG3BP-!@\($A<!U\<<$C@````!05O]U#/]U
M".C5_/__B<.)-"3H7\S__XUE^(G86U[)PX/L$.C.R/__6O\PZ/;%__^#Q!!0
M:*EW"`AJ`6H!Z`1```"#Q!#KE(UV`%6)Y8M%&%93,<F-71B-51R%P.L*B="+
M,$&#P@2%]G7T@^P,C12-!````%+HS,;__X/$$(7`B<9T3HL#,<F%P(U3!(D&
M=07K#XD$CHG3BP-!@\($A<!U\8/L#,<$C@````!6_W44_W40_W4,_W4(Z&GN
M__^#Q!16B</HKLO__XUE^(G86U[)PX/L$.@=R/__6O\PZ$7%__^#Q!!0:*EW
M"`AJ`6H!Z%,_``"#Q!#KBXGV58GE5E.#[!#HO\C__X7`B<,/B,L```"%VWYH
MC5WTB?90:@!35NB"Q/__@\000'4<Z,?'__^#.`1TYE!HY7<("&H!:@'H`S\`
M`(/$$.BKQ___QP``````BT7TJ']U!\'X"(7`=!)0:/-W"`AJ`6H!Z-@^``"#
MQ!"-9?A;N`$```!>R</H=,?__X/L",<``````&H`:.)L"`CH7\K__UE>:@!0
MB</H@\7__UA::@%J`NAXQ?__Z$/'__^+,(/$$(7V=3>#[`Q3Z('*___H_,?_
M_X/$$(7`?$!_-(UE^%LQP%[)PU!H!G@("&H!:@'H6SX``(/$$.D>____46@4
M>`@(:@%J`>A$/@``@\00Z[6#[`QJ`.BER?__@^P0Z-W&__]:_S#H!<3__X/$
M#%!H)W@("/\UZ$,E".A1QO__QP0D`0```.AUR?__D%6)Y5=64X'LC!```(LU
M&.08"(7V=`J-9?1;7E_)PXGV@^P,:#IX"`CHPPH``(/$$(7`B<8/A(H*``"`
M.``/A($*``"#[`R)-1CD&`AH27@(".B:"@``@\00A<")QG0%@#@`=2=1:-AZ
M"`AH`!```(V]Z.___U?HJ</__X/$#&H!:@%7Z&0\``"#Q!"#[`R)-1#D&`AH
M6'@(".A2"@``@\00A<")QG0%@#@`=2=2:/QZ"`AH`!```(V=Z.___U/H8</_
M_X/$#&H!:@%3Z!P\``"#Q!"#[`R)-0SD&`AH97@(".@*"@``@\00A<")QG0%
M@#@`=2=0:"!["`AH`!```(V]Z.___U?H&</__X/$#&H!:@%7Z-0[``"#Q!"#
M[`R)-0CD&`AH<7@(".C""0``@\00A<")QG0%@#@`=2=0:$!["`AH`!```(V=
MZ.___U/HT<+__X/$#&H!:@%3Z(P[``"#Q!"#[`R)-03D&`AH?G@(".AZ"0``
M@\00A<")QG0%@#@`=2=0:&1["`AH`!```(V]Z.___U?HB<+__X/$#&H!:@%7
MZ$0[``"#Q!"#[`R)-0#D&`AHD'@(".@R"0``@\00A<")QG0%@#@`=2=0:)IX
M"`AH`!```(V=Z.___U/H0<+__X/$#&H!:@%3Z/PZ``"#Q!"#[`R)-?SC&`AH
MN'@(".CJ"```@\00A<")QG0%@#@`=2=0:(Q["`AH`!```(V]Z.___U?H^<'_
M_X/$#&H!:@%7Z+0Z``"#Q!"#[`R)-?CC&`AHQG@(".BB"```@\00A<")PW0%
M@#@`=19HQG@("&BP>P@(:@%J`>B5.P``@\00@^P,B1WTXQ@(:-%X"`CH:P@`
M`(/$$(7`B<9T!8`X`'4G4&C@>P@(:``0``"-G>CO__]3Z'K!__^#Q`QJ`6H!
M4^@U.@``@\00@^P,B37PXQ@(:.)X"`CH(P@``(/$$(7`B<9T!8`X`'4G5VCK
M>`@(:``0``"-O>CO__]7Z#+!__^#Q`QJ`6H!5^CM.0``@\00@^P,B37HXQ@(
M:`AY"`CHVP<``(/$$(7`B<9T!8`X`'4G4V@2>0@(:``0``"-G>CO__]3Z.K`
M__^#Q`QJ`6H!4^BE.0``@\00@^P,B37DXQ@(:#!Y"`CHDP<``(/$$(7`B<9T
M!8`X`'4G46@(?`@(:``0``"-O>CO__]7Z*+`__^#Q`QJ`6H!5^A=.0``@\00
M@^P,B37@XQ@(:#QY"`CH2P<``(/$$(7`B<-T!8`X`'424F@H?`@(:@%J`>A"
M.@``@\00@^P,B1W<XQ@(:$AY"`CH&`<``(/$$(7`B<9T!8`X`'4G4&A(?`@(
M:``0``"-G>CO__]3Z"?`__^#Q`QJ`6H!4^CB.```@\00@^P,B378XQ@(:%1Y
M"`CHT`8``(/$$(7`B<9T!8`X`'4G4&AH?`@(:``0``"-O>CO__]7Z-^___^#
MQ`QJ`6H!5^B:.```@\00@^P,B374XQ@(:&%Y"`CHB`8``(/$$(7`B<9T!8`X
M`'4G4&B,?`@(:``0``"-G>CO__]3Z)>___^#Q`QJ`6H!4^A2.```@\00@^P,
MB370XQ@(:'!Y"`CH0`8``(/$$(7`B<9T!8`X`'4G4&BP?`@(:``0``"-O>CO
M__]7Z$^___^#Q`QJ`6H!5^@*.```@\00@^P,B37,XQ@(:'YY"`CH^`4``(/$
M$(7`B<9T!8`X`'4G4&C4?`@(:``0``"-G>CO__]3Z`>___^#Q`QJ`6H!4^C"
M-P``@\00@^P,B37(XQ@(:(MY"`CHL`4``(/$$(7`B<9T!8`X`'4G4&B2>0@(
M:``0``"-O>CO__]7Z+^^__^#Q`QJ`6H!5^AZ-P``@\00@^P,B37LXQ@(:*UY
M"`CH:`4``(/$$(7`B<9T!8`X`'4G5VCX?`@(:``0``"-G>CO__]3Z'>^__^#
MQ`QJ`6H!4^@R-P``@\00@^P,B37$XQ@(:+MY"`CH(`4``(/$$(7`B<9T!8`X
M`'4G4V@<?0@(:``0``"-O>CO__]7Z"^^__^#Q`QJ`6H!5^CJ-@``@\00@^P,
MB37`XQ@(:,AY"`CHV`0``(/$$(7`B<9T!8`X`'4G46A`?0@(:``0``"-G>CO
M__]3Z.>]__^#Q`QJ`6H!4^BB-@``@\00@^P(B36\XQ@(:``0``!J`>B2O___
M,=N^_____XL5&.08"(F%=.___XF5Y.___Z.XXQ@(_(G7B-B)\?*N]]&#Q`Q)
M4?^UY.____^U=.___^ASP/__6%IHU'D("/\UN.,8".BAO___65]H`!```&H!
MZ#.___^+%1CD&`B)A73O__^)E=SO__^CM.,8"/R)UXC8B?'RKO?1@\0,25%2
M_[5T[___Z"#`__]86FCI>0@(_S6TXQ@(Z$Z___]97V@`$```:@'HX+[__XL5
M&.08"(F%=.___XF5U.___Z.PXQ@(_(G7B-B)\?*N]]&#Q`Q)4?^UU.____^U
M=.___^C(O___6%IH^WD("/\UL.,8".CVOO__65]H`!```&H!Z(B^__^+%1CD
M&`B)A73O__^)E<SO__^CK.,8"/R)UXC8B?'RKO?1@\0,25'_M<SO____M73O
M___H<+___UA::`YZ"`C_-:SC&`CHGK[__UE?:``0``!J`>@POO__BQ48Y!@(
MB85T[___B97$[___HZCC&`C\B=>(V(GQ\J[WT8/$#$E1_[7$[____[5T[___
MZ!B___]86F@A>@@(_S6HXQ@(Z$:^__]97V@`$```:@'HV+W__XL5&.08"(F%
M=.___XF5O.___Z.DXQ@(_(G7B-B)\8/$#/*N]]%)4?^UO.____^U=.___^C`
MOO__6%IH-WH("/\UI.,8".CNO?__65]H`!```&H!Z("]__^+%1CD&`B)A73O
M__^)E;3O__^CH.,8"/R)UXC8B?'RKO?1@\0,25'_M;3O____M73O___H:+[_
M_UA::$QZ"`C_-:#C&`CHEKW__UE?:``0``!J`>@HO?__BQ48Y!@(B85T[___
MB96L[___HYSC&`C\B=>(V(GQ\J[WT8/$#$E1_[6L[____[5T[___Z!"^__]8
M6FA@>@@(_S6<XQ@(Z#Z]__]97V@`$```:@'HT+S__XL5&.08"(F%=.___XF5
MI.___Z.8XQ@(_(G7B-B)\?*N]]&#Q`Q)4?^UI.____^U=.___^BXO?__6%IH
M=7H("/\UF.,8".CFO/__65]H`!```&H!Z'B\__^+%1CD&`B)A73O__^)E9SO
M__^CE.,8"/R)UXC8B?'RKO?1@\0,25'_M9SO____M73O___H8+W__UA::(=Z
M"`C_-93C&`CHCKS__UE?:``0``!J`>@@O/__BQ48Y!@(B85T[___B964[___
MHY#C&`C\B=>(V(GQ\J[WT4F#Q`Q1_[64[____[5T[___Z`B]__]86FB<>@@(
M_S60XQ@(Z#:\__]?6&@`$```:@'HR+O__X/$#*.,XQ@(:``0``#_-1CD&`A0
MZ,^\__^+%8SC&`B)E8SO__^)U_R(V(GQ\J[WT;\`$```@\0,*<]7:+%Z"`C_
MM8SO___H3;W__XL5&.08"(F5A.___XG7_(C8B?'RKO?1@\$1B0PDZ&NZ__]9
M7O\U&.08"%")Q^B+N/__6%IHQGH("%?HGKO__XD]%.08"(UE]%M>7\G#4VA@
M?0@(:``0``"-G>CO__]3Z$FY__^#Q`QJ`6H!4^@$,@``@\00Z5/U__]5B>57
M5E.#['PQP/RY_____XM]"/*N]]&+%1!$)0A)A=*)380/A,$````Q_\=%@```
M```[/11$)0@/@Z(```"+78`#'1!$)0CK%HGVBS7P0R4(BT26-"4`0```A<!T
M(4,/MA.!^O\```!VX8/L#%+HD+O__R4`0```@\00A<!UWXM5A/PYTHG>BWT(
MB='SIG4JBT6$#[84`X'Z_P````^'40$``(L]\$,E"(M$ES0E`$```(7`#X5F
M`0``BQ441"4(.56`<QN+#1!$)0B+78#_18"`/`L`#X01`0``.56`<NLQP(UE
M]%M>7\G#@^P(:)FB&`AH@WT(".@GO/__B<>#Q!`QP(7_=-N#[`B-=8A6#[]?
M#E/H*[K__X/$$(7`#X6[````BU6X@^P,@\("4NCAN/__@\00A<"C$$0E"`^$
MG````%=J`?]UN%#HE;O__X/$$$@/A:T```"+1;B+#1!$)0BC%$0E",8$"``Q
M]HL5%$0E"#G6<Q60BPT01"4(@#PQ"HT<,70O1CG6<NR#[`Q7Z*^[__^#Q!#I
MC?[__XUV`*'P0R4(BT20-"4`0```A<!T),8#`$L/OA.!^O\```!VWX/L#%+H
M.KK__R4`0```@\00A<!UW(L5%$0E"$;KJ8/L#%?H7+O__^GT_O__.56`Z43^
M__^#[`Q2Z`:Z__^#Q!#IJ/[__X/L#/\U$$0E".@PO?__6,<%$$0E"`````#K
MP0-=A.L4BS7P0R4(BT26-"4`0```A<!T)$.*`X3`=!T\"G09#[;0@?K_````
M=M>#[`Q2Z*RY__^#Q!#KTXM-@#L-%$0E"(G8#X)U_O__Z6[^__^058GE5U93
M@>P8$```_W4(_W4,:)A]"`AH`!```(V=Z.___U.+=1")W^B3MO__,<#\N?__
M___RKO?1@\0<25%35NCSDP$`@\00,=*%P'4*C67T6UZ)T%_)PX/L#%;HF[$!
M`(D$)/]U"&C$?0@(:``0``!3Z$FV__^#Q!QJ`&H`4^@$+P``NO_____KPY!5
MB>534(M%"#';A<!T'H/L"&@)@0@(4.@(O/__@\00A<!T"8G8BUW\R<.)]KL!
M````B=B+7?S)PU6)Y5=64X'L'!```(M=#(7;BW4(BWT0QX7D[___`````'0E
M@^P(:`F!"`A3Z+N[__^#Q!"%P'00C67T6UZX_____U_)PXUV`(7_=!6#[`AH
M"8$("%?HDKO__X/$$(7`==>+112%P'1UA?]T98/L"%=35FC\?0@(:``0``"-
MM>CO__]6Z'2U__^)]S'`_+G_____\J[WT8/$'$E15O]U%.C0D@$`@\00A<!U
M88N=Y.___X7;=0HQP(UE]%M>7\G#@^P,_W44Z(J-`0"#Q!`QP.OF@^P,4U9H
M1'X(".N:Z)H.``"%P(E%%,>%Y.___P$````/A7'___]3:@!J`&A\?@@(Z+XM
M``#I+?___Y"#[`S_=13H(;`!`(D$)%-HI'X("&@`$```5NC1M/__@\0<:@!J
M`%;HC"T``(N5Y.___X/$$(72#X3O_O__@^P,_W44Z`"-`0"#Q!#IW/[__U6)
MY5=64X'L'!```(M=#(7;QX7D[___`````'0G@^P(:`F!"`A3Z&6Z__^#Q!"%
MP+K_____=`V-9?1;7HG07\G#C78`BT40A<!T:X/L#%/_=0AHV'X("&@`$```
MC;7H[___5N@XM/__B?<QP/RY______*N]]&#Q!Q)45;_=1#HE)$!`(/$$(7`
M=5Z+G>3O__^%VW4/,=*-9?1;7HG07\G#C78`@^P,_W40Z$F,`0"#Q!`QTNOA
MZ&4-``"%P(E%$,>%Y.___P$````/A7O___]0:@!J`&A\?@@(Z(DL``"Z____
M_^E.____@^P,_W40Z.BN`0")!"13:!!_"`AH`!```%;HF+/__X/$'&H`:@!6
MZ%,L``"+E>3O__^#Q!"%TG2]@^P,_W40Z,N+`0"#Q!"Z_____^G]_O__B?95
MB>575E.![!P0``"+70B%V\>%Y.___P````!T)X/L"&@)@0@(4^@IN?__@\00
MA<"Z_____W0-C67T6UZ)T%_)PXUV`(MU#(7V=&-3:$1_"`AH`!```(VUZ.__
M_U;H`K/__XGW,<#\N?_____RKO?1@\0,25%6_W4,Z%Z0`0"#Q!"%P'58BYWD
M[___A=MU#3'2C67T6UZ)T%_)PY"#[`S_=0SH%8L!`(/$$#'2Z^/H,0P``(7`
MB44,QX7D[___`0```'6'46H`:@!H?'X(".A9*P``NO_____I6O___X/L#/]U
M#.BXK0$`B00D4VAH?P@(:``0``!6Z&BR__^#Q!QJ`&H`5N@C*P``BY7D[___
M@\00A=)TO8/L#/]U#.B;B@$`@\00NO_____I"?___XGV58GE5U93@>P,$```
MBUT,,?:%VXM]$'0D@^P(:`F!"`A3Z/ZW__^#Q!"%P'0/C67T6UZX_____U_)
MPXGVA?]T%8/L"&@)@0@(5^C6M___@\00A<!UV(M%%(7`=&N#[`A74_]U"&B4
M?P@(:``0``"-E>CO__]2Z+JQ__^-O>CO__\QP/RY______*N]]&#Q!Q)48V5
MZ.___U+_=13H#(\!`(/$$(7`=46%]G4*,<"-9?1;7E_)PX/L#/]U%.C,B0$`
M@\00,<#KYNCH"@``A<")112^`0```'6$5VH`:@!H?'X(".@5*@``Z4'___^#
M[`S_=13H>:P!`(D$)%-HW'\("&@`$```C8WH[___4>@CL?__@\0<:@!J`(V=
MZ.___U/HV"D``(/$$(7V#X3^_O__@^P,_W44Z%*)`0"#Q!#IZ_[__XGV58GE
M5U93@>P,$```BUT,,?:%VXM]$'0D@^P(:`F!"`A3Z+JV__^#Q!"%P'0/C67T
M6UZX_____U_)PXGVA?]T%8/L"&@)@0@(5^B2MO__@\00A<!UV(M%%(7`=&N#
M[`A74_]U"&@,@`@(:``0``"-E>CO__]2Z':P__^-O>CO__\QP/RY______*N
M]]&#Q!Q)48V5Z.___U+_=13HR(T!`(/$$(7`=46%]G4*,<"-9?1;7E_)PX/L
M#/]U%.B(B`$`@\00,<#KYNBD"0``A<")112^`0```'6$4&H`:@!H?'X(".C1
M*```Z4'___^#[`S_=13H-:L!`(D$)%-H5(`("&@`$```C8WH[___4>C?K___
M@\0<:@!J`(V=Z.___U/HE"@``(/$$(7V#X3^_O__@^P,_W44Z`Z(`0"#Q!#I
MZ_[__XGV58GE5U93@>P,$```BUT(,?:%VXM]#'0D@^P(:`F!"`A3Z':U__^#
MQ!"%P'0/C67T6UZX_____U_)PXGVA?]T%8/L"&@)@0@(5^A.M?__@\00A<!U
MV(M%$(7`#X2)````A?]T:8/L#%=3:(2`"`AH`!```(V5Z.___U+H+:___X/$
M(/Q0C;WH[___,<"Y______*N]]%)48V]Z.___U?_=1#H?HP!`(/$$(7`=6>%
M]G4*,<"-9?1;7E_)PX/L#/]U$.@^AP$`@\00,<#KYE-HN(`("&@`$```C8WH
M[___4>C(KO__@\00ZYGH/@@``(7`B440O@$````/A6+___]0:@!J`&A\?@@(
MZ&<G``#I&____XGV@^P,_W40Z,FI`0")!"13:."`"`AH`!```(V5Z.___U+H
M<Z[__X/$'&H`:@"-G>CO__]3Z"@G``"#Q!"%]@^$UO[__X/L#/]U$.BBA@$`
M@\00Z</^__^)]E6)Y5=64X'LJ!```&@-@0@(QX6`[___`````.A`KO__@\00
MA<")A83O__]T$8N5A.___S'`@#H`#X6F`0``Z(VP__^#[`C'``````!HF:(8
M"&@=@0@(Z-6Q__^#Q!"%P(G##X3F````45-H`!```(VUZ.___U;H1:[__X/$
M$(7`#X2\````C8WH[___B8UD[___ZQBA\$,E"(M$D#0E`$```(7`="S_A63O
M__^+M63O__\/OA:!^O\```!VUX/L#%+H2K#__R4`0```@\00A<!UU(N]9.__
M_XH'/"-TBCP[=(:$P'2"@[V`[___`0^$^0```(N5@.___X72#X7S````_+\I
M@0@(B[5D[___N0@```#SI@^%3O___U%3:``0``"-M>CO__]6QX6`[___`0``
M`.B)K?__@\00A<`/A43___^#[`Q3Z`6Q__^#Q!"+G83O__^%VW0+BX6$[___
M@#@`=32#[`B-C8CO__]1:#*!"`CH^;'__X/$$(7`=1D/MY60[___@>(`\```
M@?H`P```#X1V`0``B[V$[___A?]T"XNUA.___X`^`'4R@^P(C9V([___4VA,
M@0@(Z+"Q__^#Q!"%P'47#[>%D.___R4`\```/0#````/A"`!``"+A83O__^-
M9?1;7E_)PSQ;#X1._____+^4H1@(B[5D[___N08```#SI@^%6_[__XN]9.__
M_XN59.___XI'!H/"!H3`=`L\/70/0HH"A,!U]3P]#X4,____C7(!ZQ.A\$,E
M"(M$D#0E`$```(7`="%&#[X6@?K_````=N*#[`Q2Z*ZN__\E`$```(/$$(7`
M==\Q_X`^`'49Z<C^__^+#?!#)0B+1)$T)0!```"%P'4B1P^^%#Z!^O\```!V
MX(/L#%+H;:[__R4`0```@\00A<!TWH/L"(V5B.___\8$/@!25NBML/__@\00
MA<`/A73^__\/M[V0[___@><`\```@?\`P```#X5;_O__@^P,5N@0K___@\00
MB86$[___Z43^___'A83O__],@0@(Z='^___'A83O__\R@0@(Z87^__]5B>53
M@^P0:%R!"`CH,ZO__X/$$(7`=!-1:@IJ`%#H(:S__X/$$(/X`W0%BUW\R<.#
M[`QH:8$(".@'J___@\00A<")PW3E@^P,:'6!"`CHT:W__UA::'6!"`A3Z*2N
M__^+7?S)PXUV`%6)Y5=64X'L$!```&C_#P``C9WH[___4VAU@0@(Z#JK__^#
MQ!"#^/\/A!X!``!6:@!3:&F!"`C&A`7H[___`.B8K?__@\00A<!U28/L"&B9
MHA@(:(:!"`CH3Z[__XG&@\00A?:X_____W0?4%9H`!```%/HQ*K__X/$$(7`
M=7&#[`Q6Z$2N__\QP(UE]%M>7\G#B?:#[`QH7($(".@[JO__@\00A<!TX%%J
M"FH`4.@IJ___@\00@_@#=<V#[`QH:8$(".@4JO__@\00A<")PW2W@^P,:'6!
M"`CHWJS__UA::'6!"`A3Z+&M__^#Q!#KF%!J"FH`4^A1J___@\00A<")QP^$
M=____U!7:):!"`A3Z'>N__^#Q`QJ`%-HG($(".BWK/__@\0,5VBH@0@(4^A8
MKO__@\0,:@!3:+"!"`CHF*S__X/$$.DS____@^P,:%R!"`CH@ZG__X/$$(7`
M=!-2:@IJ`%#H<:K__X/$$(/X`W0*N/_____I#?___X/L#&AI@0@(Z%*I__^#
MQ!"%P(G#=."#[`QH=8$(".@<K/__7UAH=8$("%/H[ZS__X/$$+C_____Z=#^
M__^)]E6)Y5=64X'L1"```&H`:+V!"`CH>*[__X/$$(7`B<,/B`@"``!0:``0
M``"-A=CO__]04^B(J___@\00A<")QP^(%`(``(/L#%/HDJ[__X/$$("\/=?O
M__\*QH0]V.___P`/A#4!``#HV/W__X/L#&AI@0@(Z*>H__^#Q!"%P(F%Q-__
M_P^$`@$``(`X``^$^0```(/L#&C2@0@(Z("H__^#Q!"%P'0)@#@`#X7\````
M@^P,QX6\W___`````&B<@0@(Z%FH__^#Q!"%P(G'#X0(`0``@#@`#X3_````
M@^P,:+"!"`CH-JC__X/$$(7`B<,/A`4!``"`.``/A/P```#HN_G__X/L#(F%
MP-___VH`Z+M\`0"#Q!"%P(G&#X16`0``:@#_M<#?____M;S?__]7C;W8[___
M5U/_M<3?__]0Z->%`0"#Q""%P`^$M@```%%HWH$("(V=R-___V@!$```4^B9
MI___B=_\,<"Y______*N]]&#Q`Q)45-6Z/>$`0"-9?1;B?!>7\G#D,>%Q-__
M__>!"`CI^/[__Y#&A#W7[___`.F^_O__C78`5FH*:@!0Z&FH__^#Q!"#[`R)
MA;S?__]HG($(".A3I___@\00A<")QP^%^O[__XGV@^P,:+"!"`CH-Z?__X/$
M$(7`OP&""`B)PP^%_/[__Y"[!8((".GZ_O__@^P,5N@MH@$`@\004&C8@@@(
M_W4,_W4(Z-VF__\QP(UE]%M>7\G#@^P0Z%NI__]:_S#H@Z;__XD$)&B]@0@(
M:!"#"`C_=0S_=0CHJZ;__S'`Z\R#[!#H+ZG__U__,.A7IO__B00D:+V!"`AH
M2(,(".O24VB`@P@(ZYA5B>53@>P<$```:`$0``"-G>CO__]3Z&7]__^#Q!"%
MP'0%BUW\R<-1:@!J`%/H%A\``#'`BUW\R<.-=@!5B>575E.!["P0``"+70PQ
M]H7;#X3/````_W4(:%]W"`AH`!```&@@1"4(Z!2F__^_($0E"#'`_+G_____
M\J[WT8/$#$E1:"!$)0A3Z&N#`0"#Q!"%P`^%SP```(/L#%/H=YL!`(D$)(G'
MZ-F<`0"#Q!"%P'0&BQ"%TG4D@^P,5^CC;@$`@\00A?9U1,8%($0E"`"-9?1;
M7K@@1"4(7\G#4FC_#P``_S!H($0E".B"J/__B3PDZ*YN`0"#Q!"%]G32@^P,
M4^C2?0$`@\00Z\20@^P,4^C#?0$`@\00Q@4@1"4(`.NNC78`@^P(:`$0``"-
MG=CO__]3Z$C\__^#Q!"%P'1SA<")P[X!````#X4'____4VH!:@!HX&L(".CK
M'0``,<"-9?1;7E_)PX/L#%/H3*`!`(D$)/]U"&BX@P@(:``0``!H($0E".CV
MI/__@\0<:@%J`&@@1"4(Z*T=``"#Q!"%]G2[@^P,4^@M?0$`@\00,<#KK59J
M`&H`4^B+'0``@\00,<#I>/___Y!5B>53@>P($```_W4(_W40_W4,_W44:.2#
M"`B-G?CO__]H`!```%/HC*3__X/$&/]U&%/H//[__XM=_,G#C78`58GE5U93
M@>PL$```BUT,,?:%VP^$$P$``/]U"&@$A`@(:``0``!H(%0E".A(I/__OR!4
M)0@QP/RY______*N]]&#Q`Q)46@@5"4(4^B?@0$`@\00A<!U4(/L#%/HKYD!
M`(/$$(7`B<=T/H/L#%#H"9L!`(/$$(7`=`:+$(72=6R#[`Q7Z!-M`0"#Q!"%
M]@^%V````,8%(%0E"`"-9?1;7K@@5"4(7\G#@^P,4^@#GP$`@\004&B$A`@(
M:``0``!H(%0E".BOH___@\0,:@!J`&@@5"4(Z&8<``"#Q!"%]G4[,<"-9?1;
M7E_)PY!2:/\/``#_,&@@5"4(Z&JF__^)/"3HEFP!`(/$$(7V=(Z#[`Q3Z+I[
M`0"#Q!#K@)"#[`Q3Z*M[`0"#Q!`QP.NW@^P(:`$0``"-G=CO__]3Z#CZ__^#
MQ!"%P'0VA<")P[X!````#X7#_O__4VH`:@!HI(0(".C;&P``,<#I=____X/L
M#%/H6WL!`(/$$.D7____5FH`:@!3Z+@;``"#Q!`QP.NXD%6)Y5.![`@0``#_
M=0AHJ+<8"&@+@@@(:!.""`AHY(,("(V=^.___V@`$```4^BVHO__@\08_W4,
M4^AF_/__@\00BUW\R<.)]E6)Y5=64X/L#(MU"%9HW(0("&@`$```:"!D)0B+
M71"_(&0E".AWHO__,<#\N?_____RKO?1@\0,25%H(&0E"%/HTW\!`(/$$(7`
M=4J#[`Q3Z..7`0")!"2)Q^A%F0$`@\00A<")PW1G@^P,5^A3:P$`@\0,_W4,
M:!F""`C_,^B-I?__@\00,=*%P'YXC67T6UZ)T%_)PX/L#%/H/9T!`(D$)%9H
M"(4("&@`$```:"!D)0CHZ:'__X/$'&H`:@!H(&0E".B@&@``NO_____KO59H
M/(4("&@`$```:"!D)0CHO*'__X/$#&H`:@!H(&0E".AS&@``B3PDZ,=J`0"Z
M_O___^N(5FB$A0@(:``0``!H(&0E".B'H?__@\0,:@!J`&@@9"4(Z#X:``"Z
M_?___^E8____58GE5U93@>PX$```BW4,5HM=$,>%U.___P````#H%NO__X/$
M$#'2A<`/A)$```"%VP^$Y0```(/L#%;_=0AH[(4("&@`$```:"!T)0CH&J'_
M_[\@="4(,<#\N?_____RKO?1@\0<25%H('0E"%/H<7X!`(/$$(7`#X7C````
M@^P,4^A]E@$`B00DB<?HWY<!`(/$$(7`=`:+,(7V=2Z#[`Q7Z.EI`0"+C=3O
M__^#Q!"%R750Q@4@="4(`+H@="4(C67T6UZ)T%_)PXGV4FC_#P``_S!H('0E
M".A^H___B3PDZ*II`0"+O=3O__^#Q!"%_W3(@^P,4^C(>`$`@\00Z[J-=@"#
M[`Q3Z+=X`0"#Q!#&!2!T)0@`ZZ*-=@"#[`AH`1```(V=V.___U/H//?__X/$
M$(7`='R%P(G#QX74[___`0````^%[/[__U!J`&H`:'Q^"`CHVA@``#'2Z5__
M__^#[`Q3Z#Z;`0")!"16:"B&"`AH`!```&@@="4(Z.J?__^#Q!QJ`&H`:"!T
M)0CHH1@``(N5U.___X/$$(72=+J#[`Q3Z!MX`0"#Q!`QTND-____4&H`:@!3
MZ'88``"#Q!`QP.EO____58GE5U93@>PX$```BW4,5HM=$.A8Z?__@\00,=*%
MP`^$FP```(7;QX74[___``````^$Y0```(/L#%;_=0AH5(8("&@`$```:""$
M)0CH4I___[\@A"4(,<#\N?_____RKO?1@\0<25%H((0E"%/HJ7P!`(/$$(7`
M#X7C````@^P,4^BUE`$`B00DB<?H%Y8!`(/$$(7`=`:+,(7V=2Z#[`Q7Z"%H
M`0"+C=3O__^#Q!"%R750Q@4@A"4(`+H@A"4(C67T6UZ)T%_)PXGV4FC_#P``
M_S!H((0E".BVH?__B3PDZ.)G`0"+O=3O__^#Q!"%_W3(@^P,4^@`=P$`@\00
MZ[J-=@"#[`Q3Z.]V`0"#Q!#&!2"$)0@`ZZ*-=@"#[`AH`1```(V=V.___U/H
M=/7__X/$$(7`='R%P(G#QX74[___`0````^%[/[__U!J`&H`:.!K"`CH$A<`
M`#'2Z5____^#[`Q3Z':9`0")!"16:"B&"`AH`!```&@@A"4(Z"*>__^#Q!QJ
M`&H`:""$)0CHV18``(N5U.___X/$$(72=+J#[`Q3Z%-V`0"#Q!`QTND-____
M4&H`:@!3Z*X6``"#Q!`QP.EO____58GE5U93@>PX$```BW40BWT,BUT4QX74
M[___`````%;H@^?__X/$$(7`#X3\````@^P,5^AOY___@\00A<`/A.@```"%
MVP^$.0$``(/L"%97_W4(:+R&"`AH`!```&@@E"4(Z'2=__^_()0E"#'`_+G_
M____\J[WT8/$'$E1:""4)0A3Z,MZ`0"#Q!"%P'5.@^P,4^C;D@$`B00DB<?H
M/90!`(/$$(7`=`J+,(7V#X60````@^P,5^A#9@$`BXW4[___@\00A<EU;,8%
M()0E"`"X()0E"(UE]%M>7\G#@^P,4^@QF`$`B00D5F@HA@@(:``0``!H()0E
M".C=G/__@\0<:@!J`&@@E"4(Z)05``"+E=3O__^#Q!"%TG0/@^P,4^@.=0$`
M@\00C78`C67T6UXQP%_)PX/L#%/H]70!`(/$$.N&4FC_#P``_S!H()0E".AV
MG___B3PDZ*)E`0"+O=3O__^#Q!"%_P^$8O___X/L#%/HO'0!`(/$$+@@E"4(
MZ5'___^#[`AH`1```(V=V.___U/H0_/__X/$$(7`="B%P(G#QX74[___`0``
M``^%F/[__U!J`&H`:.!K"`CHX10``.ED____4&H`:@!3Z-$4``"#Q!`QP.O&
MB?95B>575E.![#@0``"+=0Q6BUT0QX74[___`````.BJY?__@\00,=*%P`^$
MD0```(7;#X3E````@^P,5O]U"&A(AP@(:``0``!H(*0E".BNF___OR"D)0@Q
MP/RY______*N]]&#Q!Q)46@@I"4(4^@%>0$`@\00A<`/A>,```"#[`Q3Z!&1
M`0")!"2)Q^ASD@$`@\00A<!T!HLPA?9U+H/L#%?H?60!`(N-U.___X/$$(7)
M=5#&!2"D)0@`NB"D)0B-9?1;7HG07\G#B?92:/\/``#_,&@@I"4(Z!*>__^)
M/"3H/F0!`(N]U.___X/$$(7_=,B#[`Q3Z%QS`0"#Q!#KNHUV`(/L#%/H2W,!
M`(/$$,8%(*0E"`#KHHUV`(/L"&@!$```C9W8[___4^C0\?__@\00A<!T?(7`
MB</'A=3O__\!````#X7L_O__4&H`:@!HX&L(".AN$P``,=+I7____X/L#%/H
MTI4!`(D$)%9HM(<("&@`$```:""D)0CH?IK__X/$'&H`:@!H(*0E".@U$P``
MBY74[___@\00A=)TNH/L#%/HKW(!`(/$$#'2Z0W___]0:@!J`%/H"A,``(/$
M$#'`Z6____]5B>53@>P($```_W4(:!R""`AH(H(("&@G@@@(:.2#"`B-G?CO
M__]H`!```%/H!IK__X/$&/]U#%/HMO/__X/$$(M=_,G#B?95B>575E.!["P@
M``"+=0R%]L>%U-___P`````/A(L!``#_=0AHW(<("&@`$```C97H[___4NBV
MF?__C;WH[___,<#\N?_____RKO?1@\0,25&-A>CO__]05N@*=P$`@\00A<`/
MA;L```"#[`Q6Z!:/`0"#Q!"%P(G'#X2E````@^P,4.AXE`$`@\00A<")PW1R
M_W4(:'B("`AH`!```(V5Z.___U+H1IG__XV]Z.___S'`_+G_____\J[WT8/$
M#$E1C9WH[___4U;HFG8!`(/$$(7`#X6_````@^P,5NBFC@$`@\00A<")QP^$
MJ0```(/L#%#H")0!`(/$$`G0#Y3`#[;8@^P,5^@(8@$`BY74W___@\00A=)U
M6XUE](G86UY?R<.0@^P,5NC_DP$`@\004&BXB`@(:``0``"-O>CO__]7Z*F8
M__^#Q`QJ`&H`C8WH[___4>A>$0``BYW4W___@\00A=MU';C_____C67T6UY?
MR<.#[`Q6Z,MP`0"#Q!#KEXGV@^P,5NB[<`$`@\00N/_____KU9"#[`Q6Z(N3
M`0"#Q!!0:-B("`CKBH/L"&@!$```C9W8W___4^@P[___@\00A<!T+87`B<;'
MA=3?__\!````#X5&_O__4&H`:@!HX&L(".C.$```N/_____I>/___U!J`&H`
M4^BY$```@\00,<#KP8GV58GE5U93@>PL(```BW4,A?;'A=3?__\`````#X3+
M````_W4(:/R("`AH`!```(V=Z.___U/HKI?__XG?,<#\N?_____RKO?1@\0,
M25%35N@,=0$`@\00A<!U28/L#%;H'(T!`(D$)(G'Z'Z.`0"#Q!"%P'0*BQ"%
MT@^%L0```(/L#%?HA&`!`(N=U-___X/$$(7;=4:-=@"-9?1;7C'`7\G#B?:#
M[`Q6Z'>2`0"#Q!!0:"N""`AH`!```%/H)Y?__X/$#&H`:@!3Z.(/``"+G=3?
M__^#Q!"%VW2]@^P,5NA<;P$`@\00ZZ^-=@"#[`AH`1```(V=V-___U/HZ.W_
M_X/$$(7`='>%P(G&QX74W___`0````^%!O___U%J`&H`:.!K"`CHA@\``.EI
M____D%%H_P\``/\P4^B:F?__B3PDZ,9?`0"+C=3?__^#Q!"%R74=B=Z_O&P(
M"/RY!````/.F#Y3`C67T6UX/ML!?R<.#[`Q6Z,=N`0"#Q!#KU59J`&H`4^@G
M#P``@\00,<#I=/___Y!5B>575E.![#@@``"+?0A7BW40QX74W___`````.C^
MW___@\00,=*%P`^$A0```(7V#X09`0``BTT,A<D/A,8```!7:%2)"`AH`!``
M`(V=Z.___U/H^Y7__XG?,<#\N?_____RKO?1@\0,25%35NA9<P$`@\00A<!T
M1H/L#%;H#9$!`(/$$%!HK(D("&@`$```4^B]E?__@\0,:@!J`%/H>`X``(N=
MU-___X/$$(7;=44QTI"-9?1;7HG07\G#B?:#[`Q6Z".+`0")!"2)Q^B%C`$`
M@\00A<!T!HL0A=)U,X/L#%?HCUX!`(N=U-___X/$$(7;=+N#[`Q6Z*UM`0"#
MQ!`QTNNNB?97:-2)"`CI-?___U)H_P\``/\P4^@CF/__B3PDZ$]>`0"+C=3?
M__^#Q!"%R75?_+D$````O[QL"`B)WO.F#Y3`#[;0Z63___^#[`AH`1```(V=
MV-___U/H\.O__X/$$(7`=#B%P(G&QX74W___`0````^%N/[__U-J`&H`:.!K
M"`CHC@T``#'2Z1____^#[`Q6Z`YM`0"#Q!#KDU9J`&H`4^AN#0``@\00,<#K
MMHUV`%6)Y5=64X'L+#```(MU#(7VQX74S___``````^$8P$``/]U"&@HB@@(
M:``0``"-E>CO__]2Z&*4__^-O>CO__\QP/RY______*N]]&#Q`Q)48V%Z.__
M_U!6Z+9Q`0"#Q!"%P`^%7P$``(/L#%;HPHD!`(/$$(7`B<=T&H/L#%#H'(L!
M`(/$$(7`=`J+$(72#X6#````4&A)@@@(:!R""`AH(H(("&@G@@@(:.2#"`AH
M`!```(V=V,___U/HW)/__X/$&%93Z([M__^#Q!"%P'0%@#@`=693:%6""`AH
M`!```(V%Z.___U#HKY/__X/$#&H`:@"-O>CO__]7Z&0,``"+C=3/__^#Q!"%
MR74?C67T6UXQP%_)PY"`.@`/A'3___]2:``0``#_,.L8D(/L#%;HOVL!`(/$
M$.O3B?92:``0``!0:""T)0CH/Y;__XD\).AK7`$`BY74S___@\00A=)U#;@@
MM"4(C67T6UY?R<.#[`Q6Z'QK`0"#Q!"X(+0E".OEB?:#[`AH`1```(V=V-__
M_U/H!.K__X/$$(7`=$"%P(G&QX74S___`0````^%;O[__U%J`&H`:.!K"`CH
MH@L``.E&____D(/L#%;H!XX!`(/$$%!H?(H(".G]_O__5FH`:@!3Z'H+``"#
MQ!`QP.NNC78`58GE5U93@>PX$```_W4(BW4,QX74[___`````.A3W/__@\00
M,=*%P`^$ZP```(7V#X0Z`0``@^P,_W4(Z`,&``"#Q!"%P(G'#X1J`0``5VB@
MB@@(:``0``!H(,0E".A%DO__B3PDZ$V8__^_(,0E"#'`_+G_____\J[WT8/$
M#$E1:"#$)0A6Z)1O`0"#Q!"%P`^%G0```(/L#%;HH(<!`(D$)(G#Z`*)`0"#
MQ!"%P(G'=`:+$(72=32#[`Q3Z`I;`0#_=0AHR(H("&@`$```:"#$)0CHSY'_
M_X/$'&H!:@%H(,0E".B&"@``@\004&C_#P``_S=H(,0E".B9E/__B1PDZ,5:
M`0"+G=3O__^#Q!"%VW40NB#$)0B-9?1;7HG07\G#D(/L#%;HTVD!`(/$$.OB
MB?:#[`Q6Z*>,`0"#Q!!0:`"+"`AH`!```&@@Q"4(Z%.1__^#Q`QJ`6H!:"#$
M)0CH"@H``(/$$.DI____B?:#[`AH`1```(V=V.___U/H).C__X/$$(7`=%6%
MP(G&QX74[___`0````^%E_[__U!J`&H`:.!K"`CHP@D``#'2Z63___^-=@"#
M[`S_-4@4)@CHZ@,``(/$$%!H<X(("&H!:@'HL`H``(/$$.EN_O__4&H`:@!3
MZ(4)``"#Q!`QP.N9B?95B>53@^P(:/\/``#_=0AH(-0E".B+D___,=N#Q!"@
M(-0E".L<C78`H?!#)0B+A)`T!```B(,@U"4(0XJ#(-0E"(3`=!L/OM"!^O\`
M``!VV(/L#%+H6Y;__X/$$.O6B?:X(-0E"(M=_,G#B?95B>575E.![#@0``"+
M=0A6Z/_9__^#Q!`QTH7`#X21````@^P(:`$0``"-O=CO__]7Z!+G__^#Q!"%
MP(G##X1;`0``A=L/A#P!``!6:""+"`AH`!```&@@Y"4(Z.B/__^_(.0E"#'`
M_+G_____\J[WT8/$#$E1:"#D)0A3Z#]M`0"#Q!"%P'4X@^P,4^A/A0$`B00D
MB<?HL88!`(/$$(7`=`:+$(72=5"#[`Q7Z+M8`0`QTHUE]%M>B=!?R<.-=@"#
M[`Q3Z+N*`0"#Q!!0:$R+"`AH`!```&@@Y"4(Z&>/__^#Q`QJ`6H!:"#D)0CH
M'@@``(/$$.N1D%)H_P\``/\P:"#D)0CH+I+__XD\).A:6`$`B1PDZ(9G`0"#
MQ`QH_P\``&@@Y"4(:"#4)0CH!Y+__S'_@\00H"#4)0CK'8UV`(L=\$,E"(N$
MDS0$``"(AR#4)0A'BH<@U"4(A,!T&@^^T('Z_P```';7@^P,4NC6E/__@\00
MZ]:0C67T6UZZ(-0E"(G07\G#5VH!:@%HX&L(".AZ!P``@\00Z:W^__]0:@!J
M`%?H9P<``(/$$.F2_O__C78`58GE5U93@>PL$```BUT,,?:%V\>%U.___P``
M```/A-4```#_=0AHC((("&@`$```:"#T)0CH6H[__[\@]"4(,<#\N?_____R
MKO?1@\0,25%H(/0E"%/HL6L!`(/$$(7`=5J#[`Q3Z,&#`0"#Q!"%P(G'=$B#
M[`Q0Z!N%`0"#Q!"%P'03@^P,_S#H%H[__XF%U.___X/$$(/L#%?H&%<!`(/$
M$(7V#X6#````BX74[___C67T6UY`7\G#B?:#[`Q3Z`N)`0"#Q!!0:*.""`AH
M`!```&@@]"4(Z+>-__^#Q`QJ`&H`:"#T)0CH;@8``(UE]%M>,<!?R<.#[`AH
M`1```(V=V.___U/HB.3__X/$$(7`="R%P(G#O@$````/A0'___]0:@!J`&C@
M:P@(Z[N#[`Q3Z+5E`0"#Q!#I;/___U!J`&H`4^@2!@``@\00,<#KPHUV`%6)
MY8/L%&A<@0@(Z%"-__^)PH/$$#'`A=)T%E!J"FH`4N@ZCO__C5#_@\00@_H"
M=P/)PY!0:+^""`AJ`6H!Z-T&``"#Q!#)PU6)Y8M5"(/Z!;AMBP@(="1_)H/Z
M`KA\BP@(=!A_/H72N(N+"`AT#4IT8XGVN).+"`B-=@#)PXGV@_H(N*&+"`AT
M\G\P@_H&N+*+"`ATYH/Z!W79N,>+"`C)PXGV@_H#N-2+"`ATSH/Z!'7!N/"+
M"`C)PXGV@_H)N/^+"`ATMH'ZR0```'6FN`N,"`C)P[@BC`@(R<-5B>53@^P(
M:@"-1?A0_W4(Z!L/``"#Q!`]R0```(G#=`^%P'4=BT7XBUW\R<.-=@!0:#.,
M"`AJ`6H!Z`4&``"#Q!"#[`R)'4@4)@C_=?CH(9+__S'`BUW\R<.)]E6)Y593
M@^P4BW4(C47T:@!05NB]#@``@\00/<D```")PP^$P0```(7`=&V#[`R)'4@4
M)@C_=?3HW)'__S';@\00H4@4)@B#^`6Z;8L("'0D?U:#^`*Z?(L("'08#X^\
M````A<"ZBXL("'0)2'56NB*,"`B0@^P(4E9HFHP("&A%C`@(:@%J`>A<!0``
M@\0@C67XB=A;7LG#BUWTA=MTHHUE^(G86U[)PX/X"+JABP@(=,)_2X/X!KJR
MBP@(=+:#^`=T>)"#[`BZDXL("%)6:)J,"`AH18P("&H!:@'H!P4``(/$(.NI
MB?92:#.,"`AJ`6H!Z/$$``"#Q!#I+/___X/X";K_BP@(#X1G____/<D```!U
ML+H+C`@(Z5;___^#^`.ZU(L("`^$2/___X/X!'63NO"+"`CI.?___[K'BP@(
MZ2____^-=@!5B>53@^P(:@"-1?A0_W4(Z/</``"#Q!`]R0```(G#=!.%P'0&
MB1U(%"8(BT7XBUW\R<.046@SC`@(:@%J`>A=!```@\00B1U(%"8(Z]V)]E6)
MY5=64X'L<"`!`(M]"&H!:*R,"`B-M>C__O]6Z!Z.__^#Q!"%P'5;@^P,:@"-
MA9C__O]0:@575NA2CO__@\0@A<`/A6,"``"+C<C__O^+E<S__O\AT4%T$8NU
MT/_^_XN=U/_^_R'>1G5%4&A7C`@(:@%J`.C6`P``C67T6UXQP%_)PV@`$```
MC9V8[_[_4U90Z-F.__]3:'","`AJ`6H!Z*H#``"#Q"#I>____XGVQ@4@!"8(
M`%"+C<C__O^+E=#__O\IRE(!^5%H(`0F".@\C?__@\0,:@"-A93?_O]0:"`$
M)@CH4@P``(/$$#W)````B<,/A-`!``"%P'1>@^P,B1U(%"8(_[64W_[_Z&Z/
M__^#Q!"A2!0F"(/X!;IMBP@(="P/C\\```"#^`*Z?(L("'0<#X_*`0``A<"Z
MBXL("'0-2`^$50$``+J3BP@(D%)H<X((".D6____D(N=E-_^_X7;=*_&!2`$
M)@@`B[6H__[_BX6L__[_(<9&=!6+C;#__O^+E;3__O\AT4$/A><```"+C;C_
M_O^+E;S__O\AT4%T%8NUP/_^_XN%Q/_^_R'&1@^%G````(/L"%-H(`0F".C9
MBO__BYW8__[_B[7<__[_(?.#Q!!#=!&+A>#__O^+C>3__O\AR$!U0K@@!"8(
MC67T6UY?R<.#^`BZH8L("`^$2?___P^/U````(/X!KJRBP@(#X0U____@_@'
M#X4F____NL>+"`CI(O___U.+E=C__O^+G>#__O\ITU,!^E)H(`0F".C%B___
M@\00N"`$)@CKG%:+C;C__O^+E<#__O\IRE(!^5%H(`0F".B>B___@\00Z3__
M__]0B[6H__[_BX6P__[_*?!0`?Y6:"`$)@CH>8O__X/$$.GT_O__NB*,"`CI
MI_[__XUV`&@`$```C;V8W_[_5U90Z+&,__]7:(6,"`CII_W__U!H,XP("&H!
M:@'H=P$``(/$$.D=_O__@_@)NO^+"`@/A&'^__\]R0````^%4/[__[H+C`@(
MZ4S^__^#^`.ZU(L("`^$/O[__X/X!`^%+_[__[KPBP@(Z2O^__^-=@!5B>6#
M[!3_=0CHBHS__XGV58GE5U93@^P,H1SD&`@Q]H7`BUT(#X7!````@^P(_S7H
M0R4(4^B^C/__B=\QP/RY______*N]]&#Q!"`?!G^"G03@^P(_S7H0R4(:@KH
M]HO__X/$$(/L#/\UZ$,E".@UB/__@\00A?9T%5)6:-B,"`C_->!#)0CHW(C_
M_X/$$(/L"/\UX$,E"%/H6HS__XG?,<#\N?_____RKO?1@\00@'P9_@IT$X/L
M"/\UX$,E"&H*Z)*+__^#Q!"#[`S_->!#)0CHT8?__XM5#(/$$(72=3N-9?1;
M7C'`7\G#D(/L#%#H$XC__X/$$(7`B<8/A"G___]14&C8C`@(_S7H0R4(Z%2(
M__^#Q!#I#____X/L#/]U#.AQB___D%6)Y5=64X/L'(M-"(M5#(E-\(E5[.B6
MB/__BP"#[`R)1>3'1>@`$```:``0``#HS8;__X/$$(7`B<,/A"@!``"-=116
M_W40:``0``!0Z-Z&__^#Q!`]`!```(G&#XW2````Z$F(__^+5>2)$.@_B/__
MBSB%_W4I5O]U[/]U\%/H9/[__X/$$(7;=`R#[`Q3Z)R+__^#Q!"-9?1;7E_)
MPY"+3>@Q_RGQB4W@=#N#[!#H_(?__UG_,.@DA?__B00DZ.R'____,&C=C`@(
M_W7@C3PS5^A)A?__@\0@.T7@#YW`#[;XA?]TD(/L"(U4-P%24^AKB/__@\00
MA<`/A'?___^#[!")P^BFA___6O\PZ,Z$__^)!"3HEH?___\P:-V,"`A7C0PS
M4>CUA/__@\0@Z43___^0@^P(C7@!5U/H'XC__X/$$(7`#X06____B<.-112)
M?>A0_W405U/HT87__X/$$.G[_O__D%#_=>S_=?!H](P(".AO_?__C67T6UY?
MR<.-=@!5B>575E.#[`PQP#M%#(MU"+H!````<Q:#/(9_=@(QTD`[10QR\H72
M#X2R`0``BWT,P><"@^P,C4<$4.@\A?__B<.#Q!"%V[C)````#X3X````B?G\
MP>D"B=_SI8M5#,<$DP````#V110"='.+,S')A?9T2XGRB?:#^BP/A@X"``"#
M^BX/A`4"``"#^B\/A/P!``"-0L:#^`8/AO`!``"->J6#_P4/AN0!``"-0H6#
M^`0/AM@!``!!BQ2+A=)UN8/^+70+A<ET&8-\B_PM=1*#[`Q3Z-2)__^X!```
M`.MKBS,QTH7VN0$```!T(XL#B?:#^']V`C')@_H_=P:+=1"(!!9"BP23A<!U
MYH/Z/W<'BWT0Q@07`(7)#X6'````L0$QTHGV#[:"'(T("#L$DW0",<E"A<ET
M&X/Z`W;H@^P,4^AGB?__N`@```"-9?1;7E_)PXL+,=*%R>L(B?9"BS23A?9U
M^(M%$(/L#(/`!,<$DP````"-??#'1?`[````4%=J`%-2Z',H``"#Q""%P`^%
M.`$``(M-\(M5$,9$"@0`QP)X;BTM@^P,4^C^B/__BW40@\00@#X`=!HQP/RY
M_____XGW\J[WT4DQP(/Y/P^&=____XUE]%M>N`4```!?R<-J`&H`_W4,5NA/
M&P``B<:#Q!"%]KC)````#X1+____,<#\N?____^)]_*N]]'V110!C5G_=4J)
M]H/L"(U<&PI35NBVA?__@\00A<")Q@^$CP```&A@Y@D(:@134.C')0``@\00
M@_AD=,^%P'18@^P,5NA6B/__N`$```#IZO[__X/L"(U<&PI35NANA?__@\00
MA<")QG1+:&#F"0AJ`%-0Z(,E``"#Q!"#^&1TT^NZ@^P,4^@4B/__C67T6UZX
M`P```%_)PU-J`&K_5NA$&0``B30DB</H\H?__X/$$.FD_?__N,D```#I?O[_
M_X/L#%/HUX?__[@"````Z6O^__^058GE5U93@^QLB464B56D,<"+?93\N?__
M___RKHE-H/=5H(M=E(H#,?\QTH3`N0$```!U#^MRB?9"BW64B@06A,!T$83`
M>?%"BW64B@06,<F$P'7OA<EU4/9%#`$/A?8```")]HM=H(/L"`'[4_]UE.B'
MA/__@\00A<")190/A#P!``!H8.8)"&H$4U#HER0``$>#Q!"#^&1TRH7`N0$`
M```/A:0```"0N00```#\OAR-"`B+?93SI@^7P@^2PSC:N08````/A8`````Q
MVU:+?92(V+G_____\J[WT8/I!%&+=92#Q@16_W64Z*V`__^+50C_"L<$)```
M``#_=:12_W64BWV4_(C8N?_____RKO?125'HJ"@``(/$((7`N0(```!U)XM5
M"(L*BUVDQP2+`````/]U#(UUJ%;_,E/HWOO__X/$$(7`B<%T38UE]%M>B<A?
MR<.-=@"+7:"#[`@!^U/_=93HDX/__X/$$(7`B464=$QH8.8)"&H`4U#HIR,`
M`$>#Q!"#^&1TSH7`N0$```!UN.D0____@^P(C7VL5_]UE.A%@___@\00A<"Y
M!P```'68C67T6UXQR8G(7\G#C67T6UZYR0```(G(7\G#B?95B>575E.#[`R+
M112+.&H`:@#_=0R+=0A6Z&X8``")PX/$$(7;N,D```!T2X/L"/]U&/]U%(M5
M$(G8Z/']__^#Q!"%P(E%\'0B.WT,B?AV`XM%#(T,A0````#\P>D"BWT0\Z6+
M30R+512)"H/L#%/HB(7__XM%\(UE]%M>7\G#D%6)Y5=64X/L7(M-"(L!A<")
MRL=%I``````/A$H!``"#^"YT%3T",```=`X]#O\``'0'/6'_``!U"XM!!(7`
M#X2W`0``BUT,QP,`````C78`BP*%P(G3=%2#^"X/A&D!```]`C````^$:`$`
M`#T._P``#X1P`0``/6'_```/A&\!``")]H/#!(L#A<!T)8/X+G0</0(P``!T
M%3T._P``=`X]8?\``'7=ZQ&-=@"+`H7`=0@YV@^$)`$``(G>_W40*=:-?:A7
MP?X"5E+H`?K__X/$$(7`#X54`0``BU6DA=(/A*\````Q]HM]I/R)\+G_____
M\JZ)RHU]J+G_____\J[WTO?1@^P(`=%1_W6DZ)J!__^#Q!"%P(E%I`^$!`$`
M`(G'_(GPN?_____RKHMUI(/L"/?1C56H9L=$,?\N`%)6Z%>`__^+"X/$$(7)
MC5,$#X7[_O__BU6DBUT,B1.-9?1;7C'2B=!?R<.#[`QJ`>C9?O__BU4,@\00
MA<")`KK)````=`7&```PTHUE]%M>B=!?R<.0,<#\N?____^-?:CRKH/L#/?1
M4>B@?O__@\00A<")1:1T;H/L"(UUJ%;_=:3HMWS__^E[____N"X```#IVO[_
M_[@",```Z=#^___&1:@`Z?/^__^X#O\``.F]_O__N&'_``#IL_[__X/L#&H"
MZ$=^__^+30R#Q!"%P(D!NLD````/A&____]FQP`N`.EC____NLD```#I6___
M_XG"Z53___^-=@!5B>564X/L%(U%]%!J__]U".AV%```B<:#Q!"%]K@)````
M=!E0_W40_W4,5NB7_?__B<.)-"3H"8/__XG8C67X6U[)PU6)Y5=64X/L&/]U
M".C/%P``B<>#Q!"%_[@)````=$!0C47P4&K_5^@<%```@\00A<")QKL)````
M=!I0_W40_W4,5N@]_?__B<.)-"3HKX+__X/$$(/L#%?HHX+__XG8C67T6UY?
MR<.058GE5U93@^P<BT4,BW4(QT7H`````,=%Y`````#'``````"0BP:%P(EU
MW'0G@_@N="(]`C```'0;/0[_``!T%#UA_P``=`V#1=P$BU7<BP*%P'79BUW<
M*?/!^P*#[`R-#)T$````B5WP4>CY?/__@\00A<")1>P/A`@!``"+??!J`&H`
M4U;HG10``(/$$(7`B47@=$6#[`C_=1"-1?!0BU7LBT7@Z"+Z__^#Q!"%P'0;
M.=^)^'8"B=B-#(4`````_,'I`HM][/.EB5WP@^P,_W7@Z,&!__^#Q!"+7>B%
MVP^$BP```(M5Y`-5\(/L"(TTE0@```!6_W7HZ,I^__^#Q!"%P(E%Z'1]BU7D
MBUWHQP23+@```(M-\(G0BUWH0,'A`HMU[(T\@_S!Z0+SI0-%\(/L#(E%Y,<$
M@P````#_=>SH4X'__X/$$(M5W(MUW(LZ@\8$A?\/A<G^__^+7>B+=0R)'HUE
M]%M>,<!?R<.-=@"+1>R+3?")1>B)3>3'!(@`````Z\.-9?1;7K#)7\G#D%6)
MY593@^P4C47T4&K__W4(Z#H2``")QH/$$(7VN`D```!T&5'_=1#_=0Q6Z#_^
M__^)PXDT).C-@/__B=B-9?A;7LG#58GE5U93@^P0C47L4&K__W4(BWT,Z/(1
M``"#Q!"%P(G&NPD```!T&U#_=1"-5?!25NCV_?__B<.)-"3HA(#__X/$$&H`
M:@!J__]U\.@#$P``B0=8_W7PZ&B`__^+-X/$$(7VN`D```!T`HG8C67T6UY?
MR<-5B>575E.#[!"-1>A0:O__=0CH@1$``(/$$(7`B<:_"0```'0=4?]U$(U5
M[%)0Z(7]__^)PXDT)(G?Z!&`__^#Q!!J`&H`:O__=>SHD!(``%K_=>R)1?#H
M]'___XMU\(/$$(7VNPD```!T`HG[@^P,_W7PZ`05``"+50R)`EG_=?#HRG__
M_XM]#(L/@\00A<FX"0```'0"B=B-9?1;7E_)PXUV`%6)Y5=64X/L&/]U".A[
M%```B<>#Q!"%_[@)````#X26````4(U%Z%!J_U?HQ!```(/$$(7`B<:["0``
M`'0;4/]U$(U5[%)6Z,C\__^)PXDT).A6?___@\00:@!J`&K__W7LZ-41``!>
M_W7LB47PZ#E___^+3?"#Q!"%R;X)````=4*#[`S_=?#H2Q0``(M=#%J)`_]U
M\.@1?___BU4,BP*#Q!"%P+L)````=`*)\X/L#%?H]7[__XG8C67T6UY?R<.-
M=@")WNNZ58GE5U93@^P<,?8Q_X72B47PQT7L`````'A=.=8/C:8```"%TGA1
MBTWPBP2YA<`/A)0````/C-4!``"#^']V?SW_!P``#X9Q`0``/?__```/AI`!
M```]__\?``^&IP$``#W___\##X>Y`0``@\8%ZT^-=@"#Q@)'BU7PBP2ZA<!T
M1P^,B`$``(/X?P^&TP```#W_!P``=MP]__\```^&]P```#W__Q\`#X86`0``
M/?___P,/AS4!``"#Q@5'Z[E&1SG7#XQ>____@^P,C48!4.C?>/__B47LBWWL
M@\00,<"%_W1VBUWL`=XQ_SG>B77D=D>)]HGZBW7PBPR61X/Y?W=IQT7H````
M`+X!````A=MT((U6_^L0D(C(@^`_@\B`B`03P>D&2H72?^V*5>@)RH@3`?,Y
M7>1WN\8#`(M-#(7)=`@K7>R+=0R)'HM="(7;=`6+10B).(M%[(UE]%M>7\G#
MB?9&1^D-____@?G_!P``=PZ^`@```,=%Z,````#KC8'Y__\``'<:O@,```#'
M1>C@````Z73___^#Q@-'Z=7^__^!^?__'P!W(KX$````QT7H\````.E2____
M@\8"Z?S^__^#Q@1'Z:O^__^!^?___P-W(KX%````QT7H^````.DH____@\8#
MZ=+^__^#Q@9'Z8'^__^^!@```,=%Z/P```#I!O___X/&!.FP_O__BUT(A=L/
MA#S___^+30B).>DF____@\8&Z9/^__^-=@!5B>575E-*@^P0B47PB57HBT7P
MBQ"!^O_Z`@#'1>0`````#X=\`0``B='!Z0AFBX0)8*@("&8]_Q`/CI(!``"8
M+0`1``")1>PQR8-]Z``/AN$```"+7?"+5(L$@?K_^@(`#X?Q````B=;![@AF
MBX0V8*@("&8]_Q`/COX```"8C;``[___A?8/A+L````Y=>R->0$/CHX```")
M^87_ZS:0B=C!Z`AFBY0`8*@("&:!^O\0?E@/O\(M`!$``#GP?F2+5?"+!(J)
M1(K\B1R*QT7D`0```$ET38M5\(M<BOR!^__Z`@!VNHV#``#R_SW__P(`#X>=
M````P>@(9HN4`&"."`AF@?K_$'^KC78`#[_2#[;#P>((#[:$`F"4"`@Y\'^?
MC78`BW7LB77LB?DY?>@/AQ____^+?>2%_P^%T/[__X/$$%M>7\G#C7D!B?DY
M?>B)=>SKVHUV`(V"``#R_S'V/?__`@!WX<'H"&:+A`!@C@@(9CW_$`^/`O__
M_YB!XO\```#!X`@/MK008)0(".GR_O__D(7V#X@D____BW7LZX:-=@"-@@``
M\O\]__\"`,=%[``````/AXS^___!Z`AFBX0`8(X("&8]_Q`/CV[^__^8@>+_
M````P>`(#[:$$&"4"`CI7?[__U6)Y5=64X/L7(E5[(M5"(U:_H/[`0^6P8E%
M\(/Z`0^VP8E%W,=%V``````/A$`&``"#^@,/A#<&``#'1>@`````BWWPBTWL
MA<EX#HMU\`-U[#G^#X;A`0``B@>$P(A%LP^$U`$```^,4`$``+X!````N'\`
M```/ODVSNP$````AP3GS?22-=@`/OA0?B=`EP````(/`@`^%E`$``,'A!H/B
M/PG10SGS?-^)RXV+`%3__X'YKRL``'<W@?FC*P``N`$```!W$HG(F;L<````
M]_N#^@$9P(/``P%%Z`^V5;,/OII@C0@(`=_I5____XUV`#').1T`[P@(OA<4
M```/A[$````Y';"/"0@/@J4```"0C10QB=#!Z!^-!`+1^(L4Q0#O"`@YVG0F
M.<@/A(0````YVG-HB<&-%#&)T,'H'XT$`M'XBQ3%`.\("#G:==J+3=R%R71.
M#[<,Q0;O"`B!^?__```/A*0(``")R`5@K@@(=$*)PC';BH%@K@@(ZP\/ML`/
MOK!@C0@(`?)#B@*$P'7M`5WHZ4+___^-=@")QNEM____#[<,Q03O"`B!^?__
M``!UMI#_1>CI'____P^V5;.)T"7@````/<`````/A(<$``")T"7P````/>``
M```/A)D$``")T"7X````/?`````/A)\$``")T"7\````/?@````/A*4$``"!
MXOX```"!^OP```"[_____P^%C/[__[X&````N`$```#I2/[__XGVN?_____I
M;_[__XM5Z(/L#(T<E00```!3Z$]S__^)1>2+?>2#Q!`QP(7_#X0@!0``QT7@
M`````,=%K`````"+??"-=@"+5>R%TG@.BUWP`UWL.?L/AO\$``"*%X32#X3U
M!```#XQ7`P``O@$```"X?P````^^RKL!````(<$Y\WTDC78`#[X4'XG0)<``
M``"#P(`/A?T#``#!X0:#XC\)T4,Y\WS?B<Z+3:R)3=2-C@!4__^!^:\K``!W
M*8M%K(M5Y('YHRL``(T<@@^&.0(``(7;=`*),[D!`````4VLZ;X!``"0,<DY
M-0#O"`B[%Q0```^'G0$``#DUL(\)"`^"D0$``)"-%!F)T,'H'XT$`M'XBQ3%
M`.\("#GR="HYR`^$<`$``#GR#X-,`0``B<&-%!F)T,'H'XT$`M'XBQ3%`.\(
M"#GR==:+7=R%VP^$+@$```^W%,4&[P@(@?K__P``#X1K!@``B=`%8*X("`^$
M(@$``(E%R(J"8*X("(3`#X0>`0``B,*+=:S_1:R$THEUQ'ARO@$```"X?P``
M``^^RKL!````(<$Y\WTFB?:+1<@/OA08B=`EP````(/`@`^%C08``,'A!H/B
M/PG10SGS?-R)R(M-Q(MUY(D$CHM-R`^V&0^^DV"-"`@!T8E-R(H1A-(/A*H`
M``"+=:S_1:R$THEUQ'F.#[;*B<@EX````#W`````#X2?!0``B<@E\````#W@
M````#X29!0``B<@E^````#WP````#X30!0``B<@E_````#WX````#X3A!0``
M@>'^````@?G\````N/____\/A6S___^^!@```+@!````Z2?___^-=@")P^F%
M_O__#[<4Q03O"`B!^O__```/A=+^__^0BT6LBU7DB32"0(E%K(M=K(7;=%"+
M3=2+=>2+%(Z!^O_Z`@`/A\8```")T,'H"&:+A`!@J`@(9CW_$`^.U0```)@M
M`!$``(7`=1J+5:R+=>"+7>0K5>"-!+/H]OC__XM5U(E5X`^V!P^^B&"-"`@!
MS^D[_?__N">N=&_WZ8G(P?@?P?H(*<*-L@`1``"-!-*)=="--,*-!'+!X`*)
MSBG&B?"9OAP```#W_@5A$0``B46@B<B9]_Z%VXV"IQ$``'0+BU70BTV@B1.)
M2P0]IQ$``+D"````#X1L_?__A=MT`XE#"+D#`````4VLZ1[___^-@@``\O\]
M__\"``^'2O___\'H"&:+A`!@C@@(9CW_$`^/*____YB!XO\```#!X`@/MH00
M8)0(".D:____#[;*B<@EX````#W`````=&2)R"7P````/>````!T>HG()?@`
M```]\`````^$@````(G()?P````]^`````^$A@```('A_@```('Y_````+[_
M____#X6-_/__O@8```"X`0```.E*_/__O@(```"P'^D1^O__O@(```"P'^DR
M_/__QT78`0```.F]^?__O@,```"P#^GM^?__O@,```"P#^D._/__O@0```"P
M!^G5^?__O@0```"P!^GV^___O@4```"P`^F]^?__O@4```"P`^G>^___N?__
M___I!OS__X'YHRL```^'/P(``+H<````B<B)UIGW_H72#X4K`@``BTVTA<D/
MB"`"``"#?;0<#X\6`@``BWV\`WVTBUVXB3N+5<#K"HMUY(L$EHE$EOQ".U6L
M<O#_3<"+5:C_3:PQR3E5P'0TBUW`BTWDBU29_('Z__H"``^'T`(``(G7P>\(
M9HN$/V"H"`AF/?\0#X[H`@``F(V(`.____]%P(M%K#E%P')/BU6LBT7DQP20
M`````(UE]%M>7\G#BWVLA?\/A>\!``"+1=B%P'39BU6LA=)TTC')BUVL.=G'
M1:@`````QT7``````'.[BWWDQP2?`````(M%P(MUY(L<AH'[__H"``^'!P$`
M`(G:P>H(9HN$$F"H"`AF/?\0#XX8`0``F(VX`.___XM%P(7`#X3-````A<ET
M"#GY#X3!````BW7DBU6HBTVHBPR.C026B46XB<@M`!$``(E-O(V36>[__X'I
M`*P``(/X$HVSG^[__XE5M`^'B?[__X7V#XB!_O__@_X4#X]X_O__C12`C3R0
M`?>-'/T`````*?N-!)T`K```BU6XB0+IEO[__XG8P>@(,=*#^#`/AQ(!``!F
MBX0`X-8)"&8]_Q"-D`#O__]_$9@/MLO!X`@!R&:+E`#@M@D(9H'Z@P$/AN(`
M```/M](/MQR5$*T)"#M=O`^$GP$``(7_=0:+=<")=:B)^>F*_O__C8,``/+_
M,?\]__\"``^'!/___\'H"&:+A`!@C@@(9CW_$`^/Z/[__Y@/MO/!X`@/MKPP
M8)0(".G;_O__BT6\P>@(,?:#^#!W)F:+A`#@U@D(9CW_$(VP`.___W\2F`^V
M=;S!X`@!\&:+M`#@M@D(C89M____9CW1``^''/___P^WU@^W#)4TL0D(.=D/
MA5W___\/MP25-K$)"(M5N(D"Z8W]__^+5:R+=>"+3>0K5>"-!+'H@O3__^GX
M_?__C4;_9CV1``^')?___V:!^F0!#X8:____9H'Z@P$/AP____\/M]X/M\J)
MVL'B!2G:`<H/MX02N(P)"(7`#X3P_O__BWVXB0?I*/W__Y"^`@```+`?Z=CY
M__^^`P```+`/Z<SY__\/MQ3%!.\(".F(^?__#[<,Q03O"`CI3_?__XV"``#R
M_S')/?__`@`/ASO]___!Z`AFBX0`8(X(".D:_?__O@0```"P!^F#^?__F('B
M_P```,'@"`^VC!!@E`@(Z0C]__^^!0```+`#Z6#Y__\/MS25$JT)"(M]N(DW
MZ9'\__^)]KG_____Z7;Y__^)]E6)Y5=64XM]"(H'A,!X/;X!````N'\````/
MO@^[`0```"'!.?-]'I`/OA0?B=`EP````(/`@'5]P>$&@^(_"=%#.?-\XXG(
M6UY?R<,/MM")T"7@````/<````!T3(G0)?`````]X````'13B=`E^````#WP
M````=%&)T"7\````/?@```!T3X'B_@```('Z_````+C_____=:V^!@```+@!
M````Z7#___^^`@```+`?Z63___^Y_____XG(ZXF^`P```+`/Z4____^^!```
M`+`'Z4/___^^!0```+`#Z3?___^)]E6)Y8M-"%=6@_E_4XM=#'<S,?^^`0``
M`(7;="&-5O_K$HUV`(C(@^`_@\B`B`03P>D&2H72?^V(R@GZB!-;B?!>7\G#
M@?G_!P``=PR_P````+X"````Z\"!^?__``!V%('Y__\?`'<8O_````"^!```
M`.NDO^````"^`P```.N8@?G___\#=PR_^````+X%````ZX2__````+X&````
MZ77___^058GE5U93@^P,BT4,BUT(A<")VL=%[``````/B/D```"-#`,YV78B
MB@.$P'0<C78`#[;X#[ZW8(T("`'R_T7L.=%V!HH"A,!UYXM-[(/L#(T$C00`
M``!0Z"QI__^)1?"+5?"#Q!`QP(72=#<Q_SM][(G>?14/M@:#^']W,(M=\(D$
MNT9'.WWL?.N+=1"+5?"%]L<$N@````!T!8M=$(D[BT7PC67T6UY?R<.)]CW?
M````=RV)PKL"````@^(?N0$```#K#0^V!`[!X@:#X#\)PD$YV7SOBTWPB12Y
M`=Y'ZZ0][P```'<,B<*[`P```(/B#^O*/?<```!W#(G"NP0```"#X@?KMSW[
M````=RJ)PKL%````@^(#ZZ2*`^L1#[;(#[Z!8(T("`'"_T7LB@*$P'7KZ1+_
M__^)PKL&````@^(!Z7?___^)]E6)Y5.+71"+312+10B+50S'11``````B4T,
MB5T(6\GI:.[__U6)Y593@^P,BU4,BT4(:@/H:_+__X/$#&H`:@!J`+K_____
MB<;H/N[__XG#B30DZ!AM__^#Q!"-9?B)V%M>R<-5B>564U%J`&H`:@"+50R+
M10CH$>[__[K_____B<;'!"0#````Z!;R__^)PXDT).C8;/__C67XB=A;7LG#
MC78`58GE@^P4:&#7"0CHS&;__X/$$(7`=`6`.`!U'(/L#&H`Z/9H__^#Q!"%
MP'0%@#@`=0:X:-<)")#)PXGV58GE5U93@^PDBUT0QT78`````(MU#%-6Z,-J
M__^#Q!"%P'4XBWT(_+G_____\JZ#[`SWT5'H)F?__XG"@\00,<"%TG0,@^P(
M_W4(4N@_9?__C67T6UY?R<.-=@"#[`A35NB6'0$`B47@@\00,<"#?>#_=-V+
M50B)5>0QP(M]"/RY______*N]]%)C1R)@^P,C4,%B4WHB47<4.C!9O__@\00
MA<")QHE%[`^$A````(U#!.M&Z%=H__^+`(/X%G1>#X^>````@_@'#X65````
MBWW<@^P(T>>+7>R)?=Q75NC<:/__*?.#Q!"%P'0_C108B<:)^"G8B57L2(/L
M#(E%\(U%\%"-?>Q7C4WH48U=Y%/_=>#H#"(!`(/$($!TEHM-[,8!`(M=Y(`[
M`'0'QT78`0```(/L#/]UX.@N(@$`BWW8@\00A?]U"HGPC67T6UY?R<.#[`Q6
M,?;H,VO__X/$$(GPZ^;'1=@!````Z[&-=@!5B>6#[!1H8-<)".@@9?__@\00
MA<!T!8`X`'4<@^P,:@#H2F?__X/$$(7`=`6`.`!U!KAHUPD(D%)0:&[7"0C_
M=0CH2?[__\G#C78`58GE@^P4:&#7"0CHU&3__X/$$(7`=`6`.`!U'(/L#&H`
MZ/YF__^#Q!"%P'0%@#@`=0:X:-<)")!1:&[7"0A0_W4(Z/W]___)PXUV`%6)
MY5=64X/L?(M-&(M5#(LYBP*%_XE%\,=%Z``````/A.$```"+?>B-''^+=1B+
M!)Z#^`@/A]X```#_)(5TUPD(BU7HC012BTT8BT2!!*G___]_=0V%111U"(7`
M#X6-````BWWHC1Q_BW48BT2>!*G___]_=`6%111U=/9%%`%T"(7`#X3R!@``
M@^P(_W7P_W4(Z.7\__^#Q!"%P(G##X3#!@``QT7P`````(L`,=*%P'05N`$`
M``")1?")PHU``8M,@_R%R77P.U40#X.#!@``C0R5`````(M]"(/L#/S!Z0*)
MWO.E4^B<:?__@\00_T7HBUWHC3Q;BU48BS2ZA?8/A1____^+1?"+30R)`8UE
M]%M>,<!?R<.X90```(UE]%M>7\G#BWWHC01_BW48BT2&!*G___]_#X3J!```
MBU7HC012P>`"BTT8BU0(!/?"____?W0%A544=97V110$=(^+7?#'1=0`````
MBW48.5W4B5W8BT0P"`^#<O___XLXB7V8BTV8BU74BUT(,?^%R8LTDP^$\@0`
M`#';ZQ<Y\0^#3@4``(/#&(L,`T>%R0^$UP0``(L4`SGR=^J+3`,$A<EUVCGR
MZ]B+7>B-!%N+?1B+1(<$J?___W\/A#,$``"+5>B-!%+!X`*+31B+5`@$]\+_
M__]_=`F%510/A?#^__^+?1B+1#@(BW7PB470B76LQT6``````(M=K#E=@`^#
MS?[__XM5T(L*B4VHBT4(BWV`BW6HBQRX,<"%]@^$``0``#'_ZQ8YWG,H@\<8
MBU70BPP70(7)#X3F`P``BTW0BQ0/.=IWY(MT#P2%]G78.=IRV(/X_P^$QP,`
M`(U=[(7;=`.)1>R+58"#^O\/A&#^__^+1>R-!$#!X`.+=="+?#`4A?^[!```
M`'40C40P%(/H!$MT!HL(A<ET](M-K(UT&?\[=1`/@Y4$```IT8T\C?S___]0
M5XMU"(T\EHT$&HU/!%&-#(91Z&]A__^+=>R-#)T`````C11VBT70C730"/S!
MZ0+SI0-=\(U3_X/$$(E5K(E5\.GX_O__D(M]\(E]X(M-Z,=%W`````"+5>"-
M!$F+71@Y5=R+=(,(#X.Q_?__BQ:)5:"+?0B+3=R+1:"+'(\Q_X7`#X0,`P``
M,<GK%CG:<R6-=@"#P1B+%#%'A=(/A/("``"+!#$YV'?JBU0Q!(72==LYV'+>
M1P^$V`(``(-]W/\/A%C]__^X`@```.E\_?__C78`BU48BQJ%V\=%S`````#'
M1<@`````QT7$`````,=%P/_____'1;S_____QT7D``````^$/?W__XM%\(E%
MC(E%D(E%B(E5A.LF@_@'#X0K`0``@_@(#X2>`0``@T6$#(M]A(L?_T7DA=L/
MA(T```"+=82+!H/X!G70QT6X`````(M5D#E5N,=%S`$```"+?@ASR8LWB764
MB?:+70B+1;B+392+-(,QVX7)=#(QR>L1B?8Y\G,>@\$8BQ0Y0X72=!V+!#DY
M\'?NBU0Y!(72=>(Y\'+B0P^%(0(``(UV`/]%N(MUD#EUN'*Q@T6$#(M]A(L?
M_T7DA=L/A7/___^+5<R%T@^$;OS__XM%R(7`#X1C_/__BTW$A<D/A%C\__^#
M?<#_#X0E_/__@WV\_P^%G0(``(M5P(M-"(M]&(T$4HLQBTR'"(L9,?^%VP^$
M\P$``#';ZQ<Y\@^##@(``(/#&(L$"T>%P`^$V`$``(L$"SGP=^J+5`L$A=)U
MVCGPZ]C'1;0`````BTV,BUV$.4VTQT7(`0```(M["`^#OO[__XL'B46DC78`
MBUVTBTT(BU6DBS29,=N%TG0R,<GK$8GV.?)S'H/!&(L$.4.%P'0=BP0Y.?!W
M[HM4.02%TG7B.?!RXD,/A2L!``"-=@#_1;2+=8PY=;1RL>EB_O__QT6P````
M`(M5B(M-A#E5L,=%Q`$```"+<0@/@T+^__^+'HE=G(M]"(M5L(M%G(L<ES'_
MA<!T+C')ZQ"0.=IS'H/!&(L$,4>%P'0:BP0Q.=AW[HM4,02%TG7B.=ARXD</
MA<@```#_1;"+38@Y3;!RM>GM_?__A444#X7$^___A<`/A<WZ___IM_O__X5%
M%`^%#?O__X7`#X6W^O__Z0#[__^-=@#_18"+=:PY=8`/@MO[____1>B+7>B-
M/%N+51B+-+J%]NF;^O___T7<BUW@.5W<#X+/_/___T7HBUWHC3Q;BU48BS2Z
MA?;I=OK___]%U(MUV#EUU`^"Z?K__^E1^O__@WVX_P^$5OW__[@%````Z6OZ
M__^)]H-]M/\/A$#]__^+?>2)?<#I-?W__X-]L/\/A"O]__^+=>2)=;SI(/W_
M_T</A0KZ__^-9?1;7K@$````7\G#1W25@WW4_P^$\/G__[@!````Z13Z__^-
M=@!'=-:+5<"+?1B-#%*+70B+5(\(BT7PBW2#_(L:,?^%VW2W,=OK#SGQ<ZB#
MPQB+#!-'A<ETI(L$$SGP=^Z+3!,$A<EUXCGPZ^"#[`Q3Z"MC__^X9````.FV
M^?__N,@```#IK/G__[@#````Z:+Y__^P9NF;^?__B?95B>564X/L$(M=##'`
M.=B+=0AS%(L.A<ET#HGV0#G8<P>+%(:%TG7T@^P,_W44_W404XE%](U%]%!6
MZ#WX__^#Q""%P'42BU7T.=JP9',)QP26`````##`C67X6U[)PY!5B>575E.#
M[`PQV[XR````A=MT#(/L#%/HAV+__X/$$(U%\%%0:O__=0CHO?/__XM]\%L!
M]UJ-%+T`````4E#HD%___X/$$(7`B<,/A(T```"#[`S_=13_=1!7C4WP45#H
MM_?__X/&,H/$((/X9(G'=)Z%P'03@^P,4^@E8O__B?B-9?1;7E_)PVH`:@#_
M=?!3Z)[T__^)QHD<).@$8O__@\00A?:XR0```'35,<#\N?____^)]_*N]]%)
M.TT,<RN#[`A6_W4(Z-A:__^)-"3HT&'__XUE]%M>,<!?R<.-9?1;7KC)````
M7\G#@^P,5NBP8?__N&0```#KAI!5B>575E.#[`PQP(M]",=%\`````#\N?__
M___RKJ%`YPD(B<Z%P(M=$/?6OT#G"0AT+HGV@^P(4_\WZ+E?__^#Q!"%P`^$
MC````(/'"(L7A=)UX;AG````C67T6UY?R<.A0.<)"(7`=.J+7P2%VW3CBTWP
MA<ET#H/L#/]U\.@F8?__@\00@^P,5NCJ6___@\00A<")1?!T0H/L"/]U"%#H
M!%K___]W!/]U%%;_=?#H4?[__X/&,H/$((/X9(G#=+"%P'4@BW4,BWWPB3Z)
MV(UE]%M>7\G#BP?KB[C)````Z73___^#[`S_=?#HN6#__X/$$(G8Z]B)]E6)
MY5=64X/L-(M-%#';BU4(BP$YT\=%[(````#'1>@`````QT74`````(E%T,=%
MW$@```!S9(GVBW4,BQ2>@_I_=U&+?=`K?=2#_P$/AH8!``"+31"+?=3_1=2%
MR8C0="V+11`/MC08C4*?@_@9B=%W`XU*X#'2A?9U#8UQOX/^&0^&Z````)#!
MX@6-!`J+51B(!!=#.UT(<IZ+3=2%R8E-X(E-Y'0*BUT8Q@09+?]%U(M]"#E]
MX`^#H````#'2.U4(QT78_____W,;D(M-#(L$D3M%['().T78<P2)1=B00CM5
M"'+FBT7HBTWD03'2BUW8]]`K7>SW\3G##X>9`0``#Z_9QT7,`````(MU"`-=
MZ#EUS(E=R',JC78`BU7,BUT,BP23.T78<PG_1<@/A&<!```[1=AT/O]%S(MU
M"#EUS'+9BUW(BU780T*+?0B)7>B)5>PY?>0/@F#___^+112+3=2)"(/$-%M>
M,<!?R<.R`>D2____BU7(OR0```#K4#M]W+D!````=A*+1=R#P!HY^+$:=@:)
M^2M-W)`YRG)%*<J[)````"G+B=`QTO?SB<.-!`J+==3_1=2#^!F-4!9W`XU0
M88M-&(@4#H/')(G:BTW0.4W4<JBX`@```(/$-%M>7\G#BWT0BTW4,=O_1=2%
M_W0.BW40BT7,@#P&`'0"LP&#^AF-0A9W`XU"887;#[[0=`:#Z"`/OM"+71B(
M%!F+?>2+5>!'.57D=6>XD7.?7?=ER(G1P>D(B<@QTO?W`<$QVX'YQP$``'8D
MOM5!'=2)R/?F*='1Z8E5Q`--Q,'I!8/#)('YQP$``(E%P'?AC03)P>`"C7$F
M,=+W]@'8_T7,B47<QT7(`````(E]Y.FH_O__BTW(T>GKG[@#````Z3G___]5
MB>575E.#["R+31"+`8E%X(M5"#'`,<DYT,=%[(````#'1>0`````QT7H````
M`,=%W$@```!R"NLGB?9`.T4(<Q&+70R`/`,M=?&)P4`[10AR[SM-X+@"````
M#X<5`0``,=(YRG-%BW48A?8/A`X!``"+=0P/O@06@^A!@_@9BUT8BWWH#Y8$
M.XH$%H3`#XC+````BWWH#[[`BUT40HD$NT<YRHE]Z'+)C78`,?^%R70#C7D!
M.WT(#X.N````BU7DNP$```"^)````(E5V.F#````D(M-#`^^%`^-0M!'@_@)
MC4KJ=A6-0K^#^!F)P78+C4*?@_@9=V:)P9"#^2-W7HM%Y#'2]]#W\SG(#X*2
M````B<H/K],!5>0[==RZ`0```'84BT7<@\`:.?"R&G8(B?(K5=R-=@`YT7)U
MN20````IT;C_____,=+W\3G8<E0/K]F#QB0[?0@/@G7___^-9?1;7K@!````
M7\G#BW7HBWT0B3<QP(UE]%M>7\G#B?:+=0R*!!:$P'C5BWWH#[[`BUT40HD$
MNT<YRHE]Z'+AZ0C___^-9?1;7K@#````7\G#BU7DBUWHBW780RM5V(7VB5W4
M#X7>````N)%SGUWWXHG1P>D(B<@QTO=UU`'!,=N!^<<!``!V)+[501W4B<CW
MYBG1T>F)5<P#3<S!Z06#PR2!^<<!``")1<AWX8T$R<'@`HUQ)C'2]_8!V#'2
MB47<BT7D]W74B=:+5>SWTCG0#X=O____BUW@`47L.5WH<W"+51B%TG0J4(M=
MZ"GS4XM=&`'S4XU3`5+H?U7__XM-#`^^1#G_@^A!@\00@_@9#Y8#4"EUZ(M-
MZ,'A`E&+712-%+-2@\($4NA05?__BT7LBTT4B02Q1HEUY(/$$(MUU(EUZ.D.
M_O__B='1Z>DE____N`(```#IO/[__XGV58GEBT40B@"$P+K_____>`T/MM"+
M30R)$;H!````B=#)PXGV58GEBU40@_I_N/____]W"HM%#(@0N`$```#)PU6)
MY5=64U&+31"*$832BW4,BUT4>!(/ML*)!K@!````6EM>7\G#B?:`^L&X____
M_W;N@/K?=RE+L/Y^Y(I)`8/Q@(#Y/[#_=]>)TX/C'\'C!@^VT0G3N`(```")
M'NO!D(#Z[W=?@_L"N/[___]^L8I9`8C8@_"`/#\/AV4!``"*20*(R(/P@#P_
M#X=5`0``@/K@=PF`^Y\/AD<!``")UX/S@`^VTX/G#\'G#,'B!H/Q@`G7#[;9
M"=^X`P```(D^Z5S___^`^O</AJ<```"`^OL/AQ@!``"#^P2X_O___P^.//__
M_XI9`8C8@_"`/#\/A_`````/MGD"B?B#\(`\/P^'WP```(I!`XA%\X/P@#P_
M#X?.````BDD$B,B#\(`\/P^'O@```(#Z^'<)@/N'#X:P````@_.`#[;#@_>`
M@^(#B?O!X!+!XA@)PH!U\X`/ML/!X`P/MEWS"<+!XP:#\8`)V@^V^0GZN`4`
M``")%NFM_O__D(/[`[C^____#XZ>_O__BED!B-B#\(`\/W=6#[9Y`HGX@_"`
M/#]W28I)`XC(@_"`/#]W/8#Z\'<%@/N/=C.#\X`/ML.#]X"#X@?!X`R)^\'B
M$@G"#[;#P>`&@_&`"<(/MOD)^K@$````B1;I/?[__Y"X_____^DR_O__@/K]
MN/____\/AR3^__^#^P6P_@^.&?[__XI9`8C8@_"`/#]WT0^V>0*)^(/P@#P_
M=\2*00.(1?*#\(`\/W>WBD$$B$7Q@_"`/#]WJHI)!8C(@_"`/#]WGH#Z_'<%
M@/N#=I2#\X"#]X")V(/B`8G[P>`8#[;[P>(>@'7R@`G"P><2#[9%\H!U\8`)
M^L'@#`^V7?$)PL'C!H/Q@`G:#[;Y"?JX!@```(D6Z87]__^058GE4XM5$(/Z
M?XM=#+D!````=@R!^O\'``"Q`G=^B?8Y312X_O___WQN@_D&=V?_)(VPEQ@(
MB-"#X#^#R(#!Z@:(0P6!R@````2(T(/@/X/(@,'J!HA#!('*```@`(C0@^`_
M@\B`P>H&B$,#@<H```$`B-"#X#^#R(#!Z@:(0P*`S@B(T(/@/X/(@,'J!HA#
M`8#*P(@3B<A;R<.0@?K__P``L0,/AG;___^!^O__'P"Q!`^&:/___X'Z____
M`[$%#X9:____A=*Q!KC_____#XE+____6\G#58GE5U93BT4(BTT0BUT4BW`4
M,?^#^P%^,87V=$,/MD$!#[81P>`(`<*#P0*#ZP*#QP*!^O_^``!TVH'Z_O\`
M`'4M@_8!@_L!?\^+50BY_O___XER%"GY6UZ)R%_)PXGV#[8!P>`(#[91`8T4
M$.NZC9H`*/__@?O_!P``N?____]VU8M-"(M%#(D0B7$4B?F)R%M>7\G#B?95
MB>6+51"!^O__``"+30QW,X'Z_O\``'0KC8(`*/__/?\'``!V'H-]%`&X_O__
M_WX/B=#!Z`B(`8A1`;@"````R<.)]KC_____R<.058GE@WT4`5.Z_O___XM=
M$'XAB@N-02@\![+_=A8/ML'!X`@/MDL!BU4,`<B)`KH"````B=!;R<-5B>6+
M51"!^O__``"+30QW*XV"`"C__SW_!P``=AZ#?10!N/[___]^#XG0P>@(B`&(
M40&X`@```,G#B?:X_____\G#D%6)Y8-]%`%3N?[___^+71!^(8I3`8U"*#P'
ML?]V%0^V"P^VVL'C"`'9BU4,B0JY`@```(G(6\G#58GEBU40@?K__P``BTT,
M=R>-@@`H__\]_P<``'8:@WT4`;C^____?@V($<'J"(A1`;@"````R<.X____
M_\G#D%6)Y5=64XM%"(M-$(M=%(MP%#'_@_L#?D.%]G13#[9!`<'@"`^V$0'"
M#[9!`L'@$`'"#[9!`\'@&`'"@\$$@^L$@\<$@?K__@``=,B!^@``_O]U.H/V
M`8/[`W^]BUT(N/[___^)<Q0I^%M>7\G#B?8/MA$/MD$!P>`0P>(8`<(/MD$"
MP>`(`<(/MD$#ZZN%TKC_____>-*+30R)$8M5"(ER%(GX6UY?R<.-=@!5B>6+
M51"%THM-#+C_____>">#?10#L/Y^'XG0P>@8B`&)T,'H$(A!`8G0P>@(B$$"
MB%$#N`0```#)PY!5B>6#?10#BTT0N/[___]^*`^V$0^V00'!X!#!XA@!P@^V
M00+!X`@!P@^V00,!PHM%#(D0N`0```#)PY!5B>6#?10#BTT,BU40N/[___]^
M'XG0P>@8B`&)T,'H$(A!`8G0P>@(B$$"B%$#N`0```#)PXUV`%6)Y8-]%`.+
M31"X_O___WXH#[9!`0^V$<'@"`'"#[9!`L'@$`'"#[9!`\'@&`'"BT4,B1"X
M!````,G#D%6)Y8-]%`.+30R+51"X_O___WX9B!'!Z@B(40'!Z@B(40+!Z@B(
M40.X!````,G#D%6)Y5=64U:+10B+31"+712+<!0Q_^LID`^V00$/MA'!X`@!
MPH'Z__X``'0+@?K^_P``=22#]@&#P0*#ZP*#QP*#^P%^*X7V=<\/M@'!X`@/
MME$!C100Z\R-@@`H__\]_P,``(E%\'<=@_L#?SJ-=@"+50BY_O___XER%"GY
M6UM>B<A?R<.-@@`D__\]_P,``+G_____=N:+30B+70R)$XEQ%(U/`NO6A?9T
M/@^V60,/ME$"P>,(`=J-F@`D__^!^_\#``"Y_____W>RP67P"HM=\(V$$P`D
M``"+30B+50R)`HEQ%(U/!.N4#[9!`L'@"`^V40.-%!#KOXUV`%6)Y5=64XM5
M$('Z_O\``(MU"(M=#(M-%'1BC8(`*/__/?\'``!V58M&*#'_A<!U&X/Y`;C^
M____?C7&`_[&0P'_@^D"@\,"9K\"`('Z__\``'<A2;C^____?A2)T<'I"(@+
MB%,!C4<"QT8H`0```%M>7\G#@?K__Q``=@Q;7KC_____7\G#B?:#^0.X_O__
M_W[=C8(``/__B<'!Z0J!P0#8```E_P,``(G*!0#<``#!Z@B($XG"P>H(B$,#
MB$L!B%,"QT8H`0```%M>C4<$7\G#C78`58GE5U93BW44@_X!BWT,BTT0?D0/
MM@'!X`@/ME$!C100C9H`*/__@?O_`P``=B&-F@`D__^!^_\#``"Y_____W8;
MB1=;7KD"````B<A?R<.#_@-_#XUV`+G^____6UZ)R%_)PP^V00+!X`@/ME$#
MC100C;(`)/__@?[_`P``N?____]WV,'C"HV,$P`D``")#UM>N00```")R%_)
MPXUV`%6)Y5.+51"-@@`H__\]_P<``(M=#(M-%'9N@?K__P``=QI)N/[___]^
M#XG1P>D(B`N(4P&X`@```%O)PX'Z__\0`'=$@_D#N/[___]^ZXV"``#__XG!
MP>D*@<$`V```)?\#``")R@4`W```P>H(B!.)PL'J"(A#`XA+`8A3`K@$````
M6\G#B?:X_____UO)PU6)Y5=64XMU%(/^`8M]#(M-$'Y$#[9!`<'@"`^V$0'"
MC9H`*/__@?O_`P``=B*-F@`D__^!^_\#``"Y_____W8<B1=;7KD"````B<A?
MR<.0@_X#?P^-=@"Y_O___UM>B<A?R<,/ME$##[9!`L'B"(T4$(VR`"3__X'^
M_P,``+G_____=]C!XPJ-C!,`)```B0];7KD$````B<A?R<.-=@!5B>53BU40
MC8(`*/__/?\'``"+70R+311V:H'Z__\``'<:2;C^____?@V($\'J"(A3`;@"
M````6\G#B?:!^O__$`!W0(/Y`[C^____?NF-B@``__^)RL'J"H'A_P,``('"
M`-@``('!`-P``(@3B$L"P>H(P>D(B%,!B$L#N`0```!;R<.X_____UO)PU6)
MY5=64XM%"(M-$(M=%(MP%#'_ZSR)]@^V00'!X`@/MA$!P@^V00+!X!`!P@^V
M00/!X!@!PH/'!('Z__X``'0+@?H``/[_=46#]@&#P02#ZP2#^P-^)87V=;T/
MMA$/MD$!P>`0P>(8`<(/MD$"P>`(`<(/MD$#Z[N-=@"+10B)<!1;7KC^____
M*?A?R<.!^O__$`!W((V*`"C__X'Y_P<``'82BUT,B1.+50B)<A1;7HGX7\G#
M6UZX_____U_)PU6)Y5=64XM=$('[__\0`(M]"(M5#(M-%'=RC8,`*/__/?\'
M``!V98M'*#'VA<!U(X/Y`[C^____?DO&`@#&0@$`QD("_L9"`_^#Z02#P@1F
MO@0`@?O__Q``=S&#^0.X_O___WX@B=B)V<'H$,'I"(A"`<8"`(A*`HA:`XU&
M!,='*`$```!;7E_)PXGV6UZX_____U_)PXGV58GE@WT4`XM-$+C^____?CD/
MMA$/MD$!P>`0P>(8`<(/MD$"P>`(`<(/MD$#`<*!^O__$`!W#HV*`"C__X'Y
M_P<``'<'N/_____)PXM%#(D0R;@$````PU6)Y8M5$('Z__\0`(M-#'<WC8(`
M*/__/?\'``!V*H-]%`.X_O___WX;B=#!Z!"(00&)T,'H"(A!`L8!`(A1`[@$
M````R<.)]KC_____R<.058GE@WT4`XM-$+C^____?CD/MD$!P>`(#[81`<(/
MMD$"P>`0`<(/MD$#P>`8`<*!^O__$`!W#HV*`"C__X'Y_P<``'<'N/_____)
MPXM%#(D0R;@$````PU6)Y8M5$('Z__\0`(M-#'<SC8(`*/__/?\'``!V)H-]
M%`.X_O___WX7B!'!Z@B(40'!Z@B(40+&00,`N`0```#)PXGVN/_____)PY!5
MB>575E.#[!R+50B+0A2H`XMU$(E%\,=%[`````!U?(M][$<[?10/CSL!``"*
M%H32>"&(T,#H`P^VV`^V@Z"7&`@/MMJ)V8/A!]/XJ`$/A<$!``"`^BN[____
M_P^%%P$``(M%[(/``CM%%`^/]P```(!^`2UU&8M=\(MU#(M]",<&*P```(E?
M%(G#Z>D```!&B7WLQT7P`0```)`Q_XM-\,=%Z`(```#'1>0`````QT7@````
M`.M##[;"C5B_B<B#X`-&_T7@@_@!=%@/@K(```"#^`(/A`$!``"#^`,/A!H!
M``"+1>@Y1>1T2(M5[(M=X(U$&@$Y111R;8H6C4*_/!EVM(U:GX#[&0^'F```
M``^VPHU8N8G(@^`#1O]%X(/X`76HBT7H.47DC0R=`````'6YD(/X`@^%\@``
M`(V?`"C__X'[_P,```^'X````(M5[(M=X(U$&@$Y113'1>@$````<Y:-=@"+
M3?"+?0B[_O___XE/%"M=[(/$'(G86UY?R<.0@^'\P><("<^)V8G:@^$/P>H$
MP>$$"=?_1>2#R0+I/O___XGVC5K0@/L)=PP/ML*-6`3I`____Y"`^BN[/@``
M``^$]/[__X#Z+P^%Q````+,_Z>3^__^)]H/A_,'G"`G/B=F)V(/A`\'H`L'A
M!@G'_T7D@\D#Z>;^__^#X?S!YP@)SPG?_T7DN0$```#IS_[__XMU"(M-#(M5
M\(D9B584B?N#Q!R)V%M>7\G#]L$##X2/````@WWH!'06BU4,B3J+7>R+10@#
M7>")2!3I)?___XGXP>@0B?Z-D``H__^!YO__``"!^O\#``!W6(V^`"3__X'_
M_P,``+O_____#X?S_O__P>(*C9PR`"0``(MU#(D>ZZR#X?R[_____P^%U/[_
M_XM-X(7)#X7)_O__@/HM=`S'1?``````Z5_]__]&_T7LZ^[HT$7__U6)Y5=6
M4X/L'(M%"(M8*(M]$/;#`XMU#(E]\,=%[`````!U7H/_?W8DQ@8K1H/_*W5$
M@WT4`;C^____?@C&!BVX`@```(/$'%M>7\G#B?K!Z@.)^8/A!P^V@I"7&`C3
M^*@!=,6*7?"('H/$'%M>N`$```!?R</'1>P!````NP$```"#_W\/A]T```")
M^L'J`XGY@^$'#[:"D)<8"-/XJ`$/A,(````/MH*`EQ@(T_BH`<=%Z`````!T
M!\=%Z`$```")V(/@`XM-Z(M5[(U,$0*#^`&)3>1W"HM-Z(U$$0&)1>2+5>0Y
M512X_O___P^,4O___XG8@^`#@_@!=C*)V(/@_(/X&8U0078B@_@SC5!'=AJ#
M^#V-4/QV$H/X/K(K=`N#^#^R+P^%X`$``(@61H/_?W<;B?O!ZP.)^8/A!P^V
M@X"7&`C3^*@!=`3&!BU&B?J(%HMU",=&*`````"+1>2#Q!Q;7E_)PX'___\`
M``^'R0```(G8@^`#@_@!OP(````/A@<!``"+5>R#P@.)5>"+5>`Y512X_O__
M_P^,I/[__XUV`(G8@^`#@_@!#X0&`0``#X+P````@_@"#X0?`0``@_@##X5"
M`0``3XT,_0````"+5?#3Z@^VPHC9@^'\P>@&@^(_"<&-')4`````B?:`^1F-
M04%V)(#Y,XU!1W8<@/D]C4'\=A2`^3ZP*W0-@/D_#X7T````L"^)]H@&1O;#
M`W2`A?\/A7C___^+=0B)7BB+1>"#Q!Q;7E_)PX'___\0`+C_____#X?W_?__
MC8<``/__B<?![PJ!QP#8```E_P,``(G:!0#<``#!YQ"#X@,)QX/Z`HE]\+\$
M````=AR+3>R#P0:)3>#I`O___XM-[(/!`HE-X.GT_O__BU7L@\(%Z>;^__^0
MB=G!Z0*[`0```.DY____D$^-#/T`````BU7PT^H/MMJ)V8G3@^,#P>,$P>D"
M@\L"Z1/___^-=@!/C0S]`````(M5\-/J#[;"B-F#X@^#X?S!Z`2-')4`````
M"<&#RP/IY/[__^B_0O__C78`58GE5E.+10B+4"B)T3'`@^$#BUT,=$V#^0(9
MP(UP`CEU$+C^____<CN#^0%V,8/B_(/Z&8U*078C@_HSC4I'=AN#^CV-2OQV
M$X/Z/K$K=`R#^C^Q+W0%Z&!"__^("T/&`RV)\%M>R<-5B>6#?10!N?[___]^
M(8M%$&:+$(V"`"@``&8]_P>Q_W8-BTT,#[?2B1&Y`@```(G(R<.058GEBU40
M@?K__P``=R:-@@`H__\]_P<``'89@WT4`;C^____?@N+30QFB1&X`@```,G#
MD+C_____R<.058GE@WT4`;G^____?BR+51`/MP*)PF;!Z@C!X`@)PHV"`"@`
M`&8]_P>Q_W8-BTT,#[?"B0&Y`@```(G(R<.)]E6)Y8M5$('Z__\``'<VC8(`
M*/__/?\'``!V*8-]%`&X_O___WX9B=$/M\'!X`AFP>H("<*+30QFB1&X`@``
M`,G#C78`N/_____)PY!5B>6#?10#N/[___]^#XM-$(M%#(L1B1"X!````,G#
MD%6)Y8-]%`.X_O___WX-BT4,BU40B1"X!````,G#C78`58GE@WT4`[C^____
M?C&+51"+"HG(B<K!Z`@E`/\``,'J&`G"B<@E`/\``,'@"`G"P>$8BT4,"<J)
M$+@$````R<.-=@!5B>6#?10#BTT0N/[___]^+(G(B<K!Z`@E`/\``,'J&`G"
MB<@E`/\``,'@"`G"P>$8BT4,"<J)$+@$````R<.058GE5U9348M]$(H'/)\/
MAPX!```\7'04#[;`BU4,B0*X`0```%I;7E_)PY"#?10!N/[___]^[HI'`3QU
M=&$\50^%S@```#'VNQP```#'1?`"````ZQ^)]HU"R9"(V0^VT-/B_T7P"=:#
MZP2#??`)#X^W````BU7P.544#XX#`0``BA07C4+0/`EVT8U*OX#Y&7;%C4*?
M/!EW>HU"J>N],?;'1?`"````NPP```"-=@"+3?`Y310/CL@```"*%`^-0M`\
M"782C4J_@/D9#X>`````C4+)C78`B-D/MM#3XO]%\`G6@^L$@WWP!7[#@?Z?
M````=WR#_B1T"H/^0'0%@_Y@=1Z+?0RX!@```(DWZ1+___^0BW4,QP9<````
MZ?[^__^X_____^GY_O__@?Z?````=RV#_B1T"H/^0'0%@_Y@==^+?0RX"@``
M`(DWZ=/^__^-0I\\&7>[C4*IZ7?___^-G@`H__^!^_\'``!WU.O#C9X`*/__
M@?O_!P``=X7I<?___[C^____Z9?^__^)]E6)Y5=64XMU$('^GP```(M5#'<0
MB?"(`K@!````6UY?R<.)]H'^__\``'9+OPH```"Q53E]%+C^____?.#&`ER(
M2@&-6@*)^H/J`W@CC78`C0R5`````(GPT^B#X`^#^`F)V8U;`7<8@\`PB`%*
M>>!;7HGX7\G#OP8```"Q=>NS@\!72H@!Z^95B>575E.#[`B+?1"*!SQ<=!8/
MML"+50R)`K@!````@\0(6UY?R<.0@WT4`;C^____?NR`?P%U=`N+70S'`UP`
M``#KUC'VQT7L`@```+L,````B?:+3>PY310/C@,!``"*%`^-0M`\"782C4J_
M@/D9#X?:````C4+)C78`B-D/MM#3XO]%[`G6@^L$@WWL!7[#C9X`*/__@?O_
M!P``#X?:````@?[_VP``=XZ#?10&N/[___\/CF7___^`?P9<#X5U____@WT4
M!P^.4?___X!_!W4/A6'____'1?``````QT7L"````+X,````BU7L.544?G"*
M%!>-0M`\"78+C4J_@/D9=VB-0LF)\0^VT-/B_T7L"57P@^X$@WWL"W[-BW7P
M@>X`W```@?[_`P``#X<&____P>,*BU7PC803`"0``(M]#(D'N`P```#IT/[_
M_Y"-0I\\&0^'WO[__XU"J>D9____N/[____ILO[__XU"GSP9#X?!_O__C4*I
MZXN+70RX!@```(DSZ9/^__]5B>53BTT0@_E_BUT,BU44=PJ("[@!````6\G#
M@?G__P``#X;T````@?G__Q``N/____]WY(/Z"[#^?MV-@0``__^)PL'J"H'"
M`-@``(G1P>D,)?\#``"#X0\%`-P``(/Y"<8#7,9#`74/AUD!``"#P3"(2P*)
MT<'I"(/A#X/Y"0^'.@$``(/!,(A+`XG1P>D$@^$/@_D)#X<;`0``@\$P@^(/
M@_H)B$L$#X<!`0``@\(PB%,%B<+!Z@R#X@^#^@G&0P9<QD,'=0^'V@```(/"
M,(A3"(G"P>H(@^(/@_H)#X>[````@\(PB%,)B<+!Z@2#X@^#^@D/AYP```"#
MPC"#X`^#^`F(4PH/AX(```"#P#"(0PM;N`P```#)PX/Z!;C^____#X[O_O__
MB<K!Z@R#X@^#^@G&`US&0P%UC4(P=@.-0E>)RL'J"(/B#X/Z"8A#`HU",'8#
MC4)7B<K!Z@2#X@^#^@F(0P.-0C!V`XU"5XA#!(G(@^`/@_@)=PZ#P#"(0P5;
MN`8```#)PX/`5^OP@\!7Z7G___^#PE?I7____X/"5^E`____@\)7Z2'___^#
MPE?I^O[__X/!5^G@_O__@\%7Z<'^__^#P5?IHO[__U6)Y8M-$(M%#`^V$8D0
MR;@!````PXUV`%6)Y8M5$('Z_P```+C_____=PJ+10R($+@!````R<.058GE
MBT40B@`\GXM5#'<-#[;`B0+)N`$```##D`^VR`^WA`F`E1@(B0+)N`$```##
M58GEBU40@?J?````BTT,=PN($;@!````R<.)]HV"8/___SW?````=Q.*@D"5
M&`B$P'0=B`&X`0```.O<C8)`_?__@_@?=PF*@@"3&`CKX)"X_____\G#D%6)
MY8M%$(H`/)^+30QW#0^VP(D!N`$```#)PY`/ML!FBY0`P),8"&:#^OVX____
M_W3G#[?"Z]N058GEBU40@?J?````BTT,=PN($;@!````R<.)]HV"8/___X/X
M7W<5BH(`E!@(A,!T,X@!N`$```#KWHGVC8+X_O__@_AW=A6-@BC]__^#^`=W
M$HJ"*)$8".O3B?:*@AB3&`CKR;C_____R<.058GEBT40B@`\GXM5#'<-#[;`
MB0+)N`$```##D`^VR`^WA`D`DA@(B0+)N`$```##58GEBU40@?J?````BTT,
M=PN($;@!````R<.)]HV"8/___SW?````=Q.*@L"1&`B$P'0=B`&X`0```.O<
MC8)`_?__@_@?=PF*@H"/&`CKX)"X_____\G#D%6)Y8M%$(H`/)^+50QW#0^V
MP(D"R;@!````PY`/ML@/MX0)0)`8"(D"R;@!````PU6)Y8M5$('ZGP```(M-
M#'<+B!&X`0```,G#B?:-@F#___^#^`]W%8J"P)`8"(3`="F(`;@!````Z]Z)
M]HV"`/S__X/X7W<)BH(`C1@(Z]Z0@?H6(0``L/!TU[C_____R<.-=@!5B>6+
M11"*`#R?BTT,=PT/ML")`;@!````R<.0#[;`9HN4``"/&`AF@_K]N/____]T
MYP^WPNO;D%6)Y8M5$('ZGP```(M-#'<+B!&X`0```,G#B?:-@F#___^#^`]W
M%8J"D(\8"(3`=!^(`;@!````Z]Z)]HV"^/G__X/X3W<)BH+8B1@(Z]Z0N/__
M___)PY!5B>6+11"*`#R?BTT,=PT/ML")`;@!````R<.0#[;`9HN4`."-&`AF
M@_K]N/____]TYP^WPNO;D%6)Y8M5$('ZGP```(M-#'<+B!&X`0```,G#B?:-
M@F#___^#^!]W%8J"8(X8"(3`=#.(`;@!````Z]Z)]HV"@/S__X/X3W85C8+P
MW___@_@/=Q**@G!N&`CKTXGVBH(@BQ@(Z\FX_____\G#D%6)Y8M%$(H`/)^+
M30QV)0^VP&:+E`"`C!@(9H/Z_;C_____=`H/M\*)`;@!````R<.-=@`/ML")
M`<FX`0```,-5B>6+51"!^I\```"+30QW"X@1N`$```#)PXGVC8)@____@_A7
M=Q6*@L",&`B$P'0SB`&X`0```.O>B?:-@C#Z__^#^!]V%8V"^-___X/X#W<2
MBH(8;1@(Z].)]HJ"<(<8".O)N/_____)PY!5B>6+11"*`#S/BU4,=A4/ML@/
MMX0)((L8"(D"R;@!````PY`/ML")`LFX`0```,-5B>6+51"!^L\```"+30QW
M"X@1N`$```#)PXGVC8(P____@_@O=Q6*@K"+&`B$P'0?B`&X`0```.O>B?:-
M@NC^__^#^$=W"8J""(L8".O>D+C_____R<.058GEBT40B@`\GXM5#'<-#[;`
MB0+)N`$```##D`^VR`^WA`D@BA@(B0+)N`$```##58GEBU40@?J?````BTT,
M=PN($;@!````R<.)]HV"8/___SW?````=Q.*@N")&`B$P'03B`&X`0```.O<
M@?H5(```L+UT[;C_____R<.-=@!5B>6+11"*`#R?BU4,=PT/ML")`LFX`0``
M`,.0#[;(#[>$"8"(&`B)`LFX`0```,-5B>6+51"!^I\```"+30QW"X@1N`$`
M``#)PXGVC8)@____/=\```!W$XJ"0(@8"(3`=!V(`;@!````Z]R-@NC?__^#
M^`=W"8J"J&@8".O@D+C_____R<.058GEBT40B@`\GXM5#'85#[;(#[>$"<"&
M&`B)`LFX`0```,.0#[;`B0+)N`$```##58GEBU40@?J?````BTT,=PN($;@!
M````R<.)]HV"8/___X/X7W<5BH(`AQ@(A,!T6X@!N`$```#KWHGVC8+X_O__
M@_@?=A6-@I#^__^#^`]W$HJ"^(48".O3B?:*@GB&&`CKR8V"`.+__SV'````
M=A.-@A#A__^#^`=W$(J"T&<8".NIBH+@:!@(ZZ&X_____\G#D%6)Y8M%$(H0
MC4)@/!^+30QW%@^VP@^WA`!`A1@(B0')N`$```##B?8/ML*)`<FX`0```,-5
MB>53BU40@?J?````BUT,=PJ($[@!````6\G#C8)@____@_@?=Q6*BL"%&`B$
MR70UN`$```"("^O?B?:-@D#___^#^#^(T7;DC8JP_O__@_DO=PB*BM"$&`CK
MT8'ZK"```+&D=,NX_____UO)PXGV58GEBT40B@`\GXM5#'<-#[;`B0+)N`$`
M``##D`^VR`^WA`D@A!@(B0+)N`$```##58GEBU40@?J?````BTT,=PN($;@!
M````R<.)]HV"8/___SW?````=Q.*@N"#&`B$P'0[B`&X`0```.O<C8+H_?__
M@_@'=A6-@NC?__^#^`=W$HJ"2&08".O5B?:*@E""&`CKRX'ZK"```+"D=,6X
M_____\G#C78`58GEBT40B@"$P(M5#'@-#[;`B0+)N`$```##D`^VR`^WA`E@
M@A@(B0+)N`$```##58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A7
M=Q6*@F""&`B$P'1;B`&X`0```.O?B?:-@@#\__^#^%=V%8V"Z-W__X/X3W<2
MBH(H8!@(Z].)]HJ"H'X8".O)C8+@W/__@_@'=A6-@@#;__\]IP```'<0BH*`
M7!@(ZZF*@@A?&`CKH;C_____R<.058GEBT40B@"$P(M5#'@-#[;`B0+)N`$`
M``##D`^VR`^WA`F`?Q@(B0+)N`$```##58GEBU40@_I_BTT,=PJ($;@!````
MR<.0C8)@____@_A7=Q6*@H!_&`B$P'1;B`&X`0```.O?B?:-@@#\__\]EP``
M`'83C8+HW?__@_A/=Q"*@@A=&`CKT8J"@'L8".O)C8+@W/__@_@'=A6-@@#;
M__\]IP```'<0BH)@61@(ZZF*@NA;&`CKH;C_____R<.058GEBT40B@"$P(M5
M#'@-#[;`B0+)N`$```##D`^VR`^WA`E@?!@(B0+)N`$```##58GEBU40@_I_
MBTT,=PJ($;@!````R<.0C8)@____@_A7=Q6*@F!\&`B$P'1;B`&X`0```.O?
MB?:-@@#\__\]EP```'83C8+HW?__@_A/=Q"*@NA9&`CKT8J"8'@8".O)C8+@
MW/__@_@'=A6-@@#;__\]IP```'<0BH)`5A@(ZZF*@LA8&`CKH;C_____R<.0
M58GEBT40B@"$P(M-#'@-#[;`B0&X`0```,G#D`^VP&:+E`!`>1@(9H/Z_;C_
M____=.</M\+KVY!5B>6+51"#^G^+30QW"H@1N`$```#)PY"-@F#___\]WP``
M`'<3BH+`>!@(A,!T18@!N`$```#KW8V"0/W__X/X'W85C8+PW___@_@O=Q**
M@O!8&`CKU8GVBH*`=A@(Z\N!^JP@``"P@'3%@?HB(0``L)ETN[C_____R<.0
M58GEBT40B@"$P(M-#'@-#[;`B0&X`0```,G#D`^VP&:+E```=Q@(9H/Z_;C_
M____=.</M\+KVY!5B>6+51"#^G^+30QW"H@1N`$```#)PY"-@F#___^#^!]W
M%8J"0'<8"(3`=%&(`;@!````Z]^)]HV"`/S__SV7````=A.-@O#?__^#^"]W
M$(J"\%88".O1BH)`<Q@(Z\F!^JP@``"PB'3#@?H6(0``L+ETN8'Z(B$``+"9
M=*^X_____\G#C78`58GEBT40BA"-0H`\'XM-#'8.#[;"B0&X`0```,G#B?8/
MML)FBY0`P'48"&:#^OVX_____W3F#[?"Z]J058GE4XM-$(/Y?XM=#'<-B`NX
M`0```%O)PXUV`(V!8/___X/X7XC*=A^-D;#^__^#^D=V)(V!0/W__X/X'W<E
MBI&`<Q@(C78`A-)T-[@!````B!/KP8UV`(J1$'48"(32=>KK'XV1\-___X/Z
M+W8<@?FL(```LH!TTX'Y(B$``+*9=,FX_____UO)PXJ1\%48".NUD%6)Y8M%
M$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0``'08"&:#^OVX_____W3G
M#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_@?=Q6*@D!T
M&`B$P'1'B`&X`0```.O?B?:!^I(!``"P@W3KC8*`_/__@_A/=PB*@@!Q&`CK
MU(V"\-___X/X+W8;@?JL(```L(!TPX'Z(B$``+"9=+FX_____\G#BH(P5!@(
MZZ:058GEBT40B@"$P(M-#'@-#[;`B0&X`0```,G#D#R?=QP/ML!FBY0``',8
M"&:#^OVX_____W3C#[?"Z]>0/,]VSSS?=A$\[W;'#[;`#[>$`.!Q&`CKO0^V
MT`^WA!)`<A@(Z[")]E6)Y5.+31"#^7^+70QW#8@+N`$```!;R<.-=@"-@6#_
M__^#^"^(RG8?C9$P____@_HO=B2-@>C^__^#^']W)8J1Z'$8"(UV`(32=%*X
M`0```(@3Z\&-=@"*D;!R&`B$TG7JZSJ-D4#]__^#^A]V$XV!\-___X/X+W<0
MBI&04A@(Z\:*D2!P&`CKOH'YK"```+*`=+B!^2(A``"RF72NN/____];R<.)
M]E6)Y8M-"(M1%#'`A=)T$8M%#,=!%`````")$+@!````R<.)]E6)Y5=64XM%
M$(H`A,"+=0B+?0QF#[;0>&]FBUX49H7;="*-@E#Z__]F@_@4=T8/M\(MM`4`
M`(/X#G<Y_R2%S)<8"(GVC8HP^O__9H/Y(@^&'P$```^W\HDW6UZX`0```%_)
MPV8Y'(W`<!@(B<@/A(<```"0#[?3QT84`````(D76UXQP%_)PY`/MLAFBY0)
MH'`8"&:#^OVX_____P^%=____UM>7\G#N`<```"+%,5D<1@(BP3%8'$8"`'0
M9CD<E<!P&`B-2/]WJV8Y'(W`<!@(<J&0C00*T>AF.1R%P'`8"'07=G\YPG2+
MB<&-!`K1Z&8Y'(7`<!@(=>EFBQ2%PG`8"(V:U@0``&:#^P%V96:!^DG[=%['
M1A0`````Z3/___^X!@```.N$N`4```#I>O___[@"````Z7#___^X`0```.EF
M____,<#I7____[@$````Z57___^X`P```.E+____C78`.<(/A/?^__^)PNEA
M____#[?ZB7X46UZX_?___U_)PY!5B>575E.+71"#^W^+?0QW#X@?N0$```!;
M7HG(7\G#D(V#8/___X/X5P^'O0```(J#P&\8"(3`#X7S````#[<%@&X8"#')
M.=B^(0````^'Y`````^W%8AO&`@YV@^"U0```(GVC10QT>H/MP35@&X8"#G8
M="$/ALD````YT0^$M````(G6C10QT>H/MP35@&X8"#G8==\/MQS5@FX8"(J#
M,&H8"(H<U85N&`B$VP^(Y````(-]%`*Y_O___P^.5O___X@'#[X$U81N&`B*
MB&!N&`@/OO.(3P&*EF!N&`BY`P```(A7`NDM____D('[D@$``+"#=#J-DT#]
M__^#^A]W3HJ#@&T8".DI____@?NJ(```L*1T&H'[K"```+"`=!"!^R(A``"P
MF0^%#____XGVB`?IW/[__UM>N?____^)R%_)PY`YT70SB='I%?___XV+4/K_
M_X/Y1W86C;/XW___@_XW=Z>*@YA/&`CIQ?[__XJ#,&H8".FZ_O__B?(/MS3U
M@&X8"#G>N?____\/A`3____I@?[__X-]%`&Y_O___P^.<O[__X@'#[X$U81N
M&`B*B&!N&`B(3P&Y`@```.E5_O__D%6)Y8M%$(H`A,"+50QX#0^VP(D"R;@!
M````PY`/ML@/MX0)8&P8"(D"R;@!````PU6)Y8M5$(/Z?XM-#'<*B!&X`0``
M`,G#D(V"8/___X/X7W<5BH)@;!@(A,!T9X@!N`$```#KWXGVC8*P_O__@_A'
M=BV!^L8"``"PB'3@C8+X^?__/<\```!V'HV"^-___X/X-W<;BH)X2Q@(Z[R-
M=@"*@E!K&`CKL8J"N&48".NI@?JL(```L(!THX'Z(B$``+"9=)FX_____\G#
MD%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`@&D8"&:#^OVX
M_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____/=\`
M``!W$XJ"`&D8"(3`=$6(`;@!````Z]V-@D#]__^#^!]V%8V"\-___X/X+W<2
MBH(P21@(Z]6)]HJ"P&88".O+@?JL(```L(!TQ8'Z(B$``+"9=+NX_____\G#
MD%6)Y5=64X/L#(M%$(H`A,"+=0B+?0QF#[;0>'1FBUX49H7;=2.-6K]F@?MO
M`0^&#0$```^WPHD'N`$```"#Q`Q;7E_)PXUV`(V"`/W__V:#^#]W)`^WPBT`
M`P``@_@C=TO_)(4(F!@(9CD<A:`P&`B)P@^$B@````^WT\=&%`````")%X/$
M#%M>,<!?R<.)]@^VR&:+E`E`9Q@(9H/Z_;C_____#X5R____ZY'H-R?__S'`
MD(L,Q<0S&`B+!,7`,Q@(`<A(9CD<C:`P&`AWJ68Y'(6@,!@(<I^-=@"-%`'1
MZF8Y')6@,!@(=!=V1SG1=(>)T(T4`='J9CD<E:`P&`AUZ0^W!)6B,!@(QT84
M`````.D@____N`$```#KE[@"````ZY"X`P```.N)N`0```#K@HGV.=$/A"S_
M__^)T>N<#[?ZN/W___^)?A3I[?[__U6)Y5=64XM=$(/[?XM]#'</B!^Y`0``
M`%M>B<A?R<.0C8-@____@_@?B-IV)XV30/___X/Z5P^&^P```(V+L/[__X/Y
M9P^'%`$``(J3$&88"(UV`(32#X74````#[<%H"L8"#').=B^R`````^'U0``
M``^W%<`N&`@YV@^"Q@```(UV`(T4,='J#[<$E:`K&`@YV'0A#X:Y````.=$/
MA*0```")UHT4,='J#[<$E:`K&`@YV'7?#[<$E:(K&`@E_P\``#W_````B,-V
M$3T7`0``#X?0````BI@@9Q@(@WT4`;G^____#XXL____B@25HRL8",#X!`^^
MR(@?BIF@9A@(N0(```"(7P'I"O___X'[JR```++^=!B!^ZP@``"R@'0.@?LB
M(0``LID/A2S___^(%^G<_O__BI,@9Q@(A-(/A!?____KZ5M>N?____^)R%_)
MPY`YT70SB='I)?___XVS0/W__X/^'W86C8,`_?__@_@G=SV*DP!D&`CIU/[_
M_XJ3@&08".G)_O__B?(/MS2UH"L8"#G>N?____\/A!3____I<?[__XJ8$&88
M".DK____C9/`_/__@_H!=PN*D\!C&`CIC/[__XV+\-___X/Y+P^'-____XJ3
ML$88".ER_O__B?95B>6+11"*`(3`BU4,>`T/ML")`LFX`0```,.0#[;(#[>$
M"6`'#@B)`LFX`0```,-5B>6+51"#^G^+30QW"H@1N`$```#)PY"-@F#___^#
M^%]W%8J"8`<."(3`=#Z(`;@!````Z]^)]H'Z,0$``+#5=.N!^I(!``"PGW3A
M@?H7(```L/)TUXV"`-O__SVG````=PB*@D#B#0CKOKC_____R<.)]E6)Y8M%
M$(H`A,"+50QX#0^VP(D"R;@!````PY`/ML@/MX0)H&08"(D"R;@!````PU6)
MY8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X7W<5BH*@9!@(A,!T7X@!
MN`$```#KWXGV@?J2`0``L)]TZXV"</S__X/X-W<(BH)P81@(Z]2-@C#Z__^#
M^!IV)X'Z?R```+#\=,.!^J<@``"PGG2YC8+HW?__@_A/=Q2*@HA"&`CKHHU"
ML.N=N/_____)PX'Z$",``+"I=)"-@N#<__^#^`%W"(U"U.EY____C8(`V___
M/:<```!WSXJ"X#X8".EA____58GEBT40B@"$P(M5#'@-#[;`B0+)N`$```##
MD#RO=Q0/ML`%D`,``(D"R;@!````PXUV``^VR`^WA`G@81@(B0+)N`$```##
M58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_@7=Q6*@H!B&`B$P'13
MB`&X`0```.O?B?:-@@#\__^#^%]V+8'Z%B$``+#\=."-@NC=__^#^`=V((V"
M`-O__SVG````=QN*@@`]&`CKO(UV`(J"P%X8".NQBH*00!@(ZZFX_____\G#
MD%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0``&`8"&:#^OVX
M_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A?
M=Q6*@@!@&`B$P'10B`&X`0```.O?B?:-@M#^__^#^&=V%8V"0/W__X/X'W<2
MBH)`71@(Z].)]HJ"\%X8".O)@?K``P``L+ETPXV"\-___X/X-W</BH*P/Q@(
MZZRX_____\G#C8+@WO__@_@'=PB*@H@^&`CKDHV"`-[__X/X9W<+BH)`/1@(
MZ7S___^!^LHE``"PUP^$<O___XV"``7__X/X!W>WBH(@9!<(Z5C___^-=@!5
MB>6+11"*`(3`BU4,>`T/ML")`LFX`0```,.0#[;(#[>$"2!=&`B)`LFX`0``
M`,-5B>6+51"#^G^+30QW"H@1N`$```#)PY"-@F#___\]WP```'<3BH*@7!@(
MA,!T8(@!N`$```#KW8'ZQP(``+#_=.V-@O#?__^#^"]W"(J"\#P8".O6@?HB
M(0``L*ITT(V"`-[__X/X'W83C8*@W?__@_@'=Q"*@F`Z&`CKKHJ"X#H8".NF
M@?K*)0``L-=TH+C_____R<.)]E6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)
MPY`/ML!FBY0`P%H8"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ(
M$;@!````R<.0C8)@____@_A?=Q6*@L!:&`B$P'1:B`&X`0```.O?B?:-@M#^
M__^#^&=V%8V"0/W__X/X'W<2BH(`6!@(Z].)]HJ"L%D8".O)@?K``P``L+ET
MPXV"\-___X/X-W<9BH)P.A@(ZZR!^LHE``"PUW2FN/_____)PXV"X-[__X/X
M!W<(BH)(.1@(ZXB-@@#>__^#^&=WT8J"`#@8".ER____D%6)Y8M%$(H`A,"+
M30QX#0^VP(D!N`$```#)PY`/ML!FBY0``%@8"&:#^OVX_____W3G#[?"Z]N0
M58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____/?<```!W$XJ"8%<8"(3`
M=%>(`;@!````Z]V-@D#]__^#^!]V*8'ZP`,``+#Y=.*-@O#?__^#^#=V'(V"
MX-[__X/X!W<JBH)H-A@(Z\"0BH(@51@(Z[>*@I`W&`CKKX'ZRB4``+#7=*FX
M_____\G#C8(`WO__@_AG=^2*@B`U&`CKBU6)Y8M%$(H`A,"+30QX#0^VP(D!
MN`$```#)PY`/ML!FBY0`(%48"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_
MBTT,=PJ($;@!````R<.0C8)@____/?<```!W$XJ"@%08"(3`=%>(`;@!````
MZ]V-@D#]__^#^!]V*8'ZP`,``+"Y=.*-@O#?__^#^#=V'(V"X-[__X/X!W<J
MBH*(,Q@(Z\"0BH)`4A@(Z[>*@K`T&`CKKX'ZRB4``+#7=*FX_____\G#C8(`
MWO__@_AG=^2*@D`R&`CKBU6)Y8M%$(H`A,"+50QX#0^VP(D"R;@!````PY`/
MML@/MX0)0%(8"(D"R;@!````PU6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"
M8/___X/X'W<5BH*`4A@(A,!T6(@!N`$```#KWXGV@?KW````L-9TZX'ZD@$`
M`+#$=.&-@@#\__^#^%]W"(J"P$X8".O*C8+PW___@_@7=A.-@O#>__^#^!=W
M%XJ">#$8".NLBH*0,A@(ZZ2X_____\G#C8(`WO__@_AG=^Z*@B`P&`CKBI!5
MB>6+11"*`(3`BU4,>`T/ML")`LFX`0```,.0#[;(#[>$"2!0&`B)`LFX`0``
M`,-5B>6+51"#^G^+30QW"H@1N`$```#)PY"-@F#___^#^!]W%8J"8%`8"(3`
M=%J(`;@!````Z]^)]H'Z]P```+#6=.N!^I(!``"PQ'3AC8(`_/__/9<```!W
M"(J"8$P8".O(C8+PW___@_@7=A.-@O#>__^#^!=W%XJ"&"\8".NJBH(P,!@(
MZZ*X_____\G#C8(`WO__@_AG=^Z*@L`M&`CKB(UV`%6)Y8M%$(H`A,"+30QX
M#0^VP(D!N`$```#)PY`/ML!FBY0`P$T8"&:#^OVX_____W3G#[?"Z]N058GE
MBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A?=Q6*@L!-&`B$P'18B`&X
M`0```.O?B?:!^E,!``"PSW3KC8*`_/__@_A/=PB*@H!*&`CKU(V"\-___X/X
M)W8=@?HB(0``L)-TPXV"N-W__X/X'W<0BH)8*Q@(ZZR*@K`M&`CKI+C_____
MR<-5B>6+11"*`(3`BTT,>`T/ML")`;@!````R<.0#[;`9HN4`*!+&`AF@_K]
MN/____]TYP^WPNO;D%6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X
M7W<5BH*@2Q@(A,!T6H@!N`$```#KWXGVC8+H_O__@_A_=A6-@D#]__^#^!]W
M$HJ"X$@8".O3B?:*@JA*&`CKR8'ZP`,``+"Y=,.-@O#?__^#^"=W&8J"4"L8
M".NL@?K*)0``L-=TIKC_____R<.-@N#>__^#^`=W"(J"*"H8".N(C8(`WO__
M@_AG=]&*@N`H&`CI<O___Y!5B>6+11"*`(3`BTT,>`T/ML")`;@!````R<.0
M#[;`9HN4`.!(&`AF@_K]N/____]TYP^WPNO;D%6)Y8M5$(/Z?XM-#'<*B!&X
M`0```,G#D(V"8/___X/X7W<5BH+@2!@(A,!T4(@!N`$```#KWXGVC8)0^O__
M@_@_=A6-@O#?__^#^!=W$HJ"""D8".O3B?:*@I!#&`CKR8'ZJB```+"F=,.-
M@N@$__^#^#=W"(J"R$T7".NLN/_____)PU6)Y8M%$(H`A,"+30QX#0^VP(D!
MN`$```#)PY`/ML!FBY0`X$88"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_
MBTT,=PJ($;@!````R<.0C8)@____@_A?=Q6*@N!&&`B$P'0MB`&X`0```.O?
MB?:-@OCY__\]SP```'<+BH*80!@(Z]R-=@"!^B8@``"PDW33N/_____)PXUV
M`%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`H$08"&:#^OVX
M_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_@?
M=Q6*@N!$&`B$P'1:B`&X`0```.O?B?:-@@#R__^#^%]V%8V"^-___X/X'W<2
MBH+X)!@(Z].)]HJ"(#<8".O)@?HB(0``L.YTPXV"@`?__X/X'W<(BH)@3!<(
MZZR!^O_^``"PVW2FN/_____)PXGV58GEBT40B@`\GXM-#'<-#[;`B0&X`0``
M`,G#D`^VP&:+E`#@0A@(9H/Z_;C_____=.</M\+KVY!5B>6+51"!^I\```"+
M30QW"X@1N`$```#)PXGVC8)@____@_A?=Q6*@B!#&`B$P'11B`&X`0```.O>
MB?:-@J#^__^#^#=V%8V"0/W__X/X'W<2BH*@0!@(Z].)]HJ"($(8".O)@?H4
M(```L/9TPX'ZI"```+"O=+F!^J`E``"P_'2ON/_____)PXUV`%6)Y8M%$(H`
MA,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`8$$8"&:#^OVX_____W3G#[?"
MZ]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A?=Q6*@F!!&`B$
MP'19B`&X`0```.O?B?:-@M#^__^#^&=V%8V"0/W__X/X'W<2BH*@/A@(Z].)
M]HJ"4$`8".O)C8+PW___@_@W=A.-@@`%__^#^`=W$(J"`$87".NKBH(0(1@(
MZZ.X_____\G#C78`58GEBT40B@`\GXM-#'<-#[;`B0&X`0```,G#D`^VP&:+
ME```/Q@(9H/Z_;C_____=.</M\+KVY!5B>53BU40@_HGBUT,=PV($[@!````
M6\G#C78`C4+8@_@'=Q2*BO@_&`B$R71-N`$```"("^O?D(U"T(/X;XC1=NB-
MBF#___^#^1]W"(J*8#\8".O5C8+0^O__@_A?=A.-BO#?__^#^1=W$(J*<!\8
M".NWBHIP.A@(ZZ^X_____UO)PY!5B>6+11"*$(U"@#P?BTT,=Q8/ML(/MX0`
M0#X8"(D!R;@!````PXGVC4)`/"9W$0^VP@40$```B0')N`$```###[;"B0')
MN`$```##58GEBU40@_I_BTT,=PJ($;@!````R<.0C4*`@_@?=Q2*@J`^&`B$
MP'14B`&X`0```.OBD(V"8/___X/X'W8IC8(9____@_@8=AZ-@K#^__^#^$=V
M%XV"0/W__X/X'W<EBH+@.Q@(Z[Z(T.NZBH)P/1@(Z[*!^B(A``"PF72LN/__
M___)PXV",.___X/X)G<%C4+PZY&-@O#?__^#^"]WU(J"4!X8".E[____D%6)
MY8M%$(H0C4*`/!^+30QW%@^VP@^WA``@/1@(B0')N`$```##B?:-0D`\)7<5
M#[;"#[>$`$`\&`B)`<FX`0```,.0#[;"B0')N`$```##58GEBU40@_I_BTT,
M=PJ($;@!````R<.0C4*`@_@?=Q2*@B`]&`B$P'14B`&X`0```.OBD(V"8/__
M_X/X'W8IC8(:____@_@9=AZ-@K#^__^#^$=V%XV"0/W__X/X'W<EBH)@.A@(
MZ[Z(T.NZBH+P.Q@(Z[*!^B(A``"PF72LN/_____)PXV",.___X/X)W<(BH(0
M+!@(ZXZ-@O#?__^#^"]WT8J"D!P8".EX____B?95B>6+11"*`(3`BTT,>`T/
MML")`;@!````R<.0#[;`9HN4`*`Z&`AF@_K]N/____]TYP^WPNO;D%6)Y8M5
M$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X'W<5BH+@.A@(A,!T1H@!N`$`
M``#KWXGVC8(`_/__/>\```!V$XV"\-___X/X+W<0BH(P&A@(Z]&*@H`V&`CK
MR8V"\-[__X/X%W<(BH(0&1@(Z[:X_____\G#B?95B>6+11"*`#R?BTT,=PT/
MML")`;@!````R<.0#[;`9HN4`"`X&`AF@_K]N/____]TYP^WPNO;D%6)Y8M5
M$('ZGP```(M-#'<+B!&X`0```,G#B?:!^J````"PH'05C8*`\?__@_A?=Q.*
M@H`J&`B$P'0)B`&X`0```.O4N/_____)PY!5B>6+11"*`#R?BU4,=PT/ML")
M`LFX`0```,.0/-]W&`^VR&:+A`E`-Q@(9H/X_70?#[?`Z]R)]CSO=A0/ML!F
MBX0`@#88"&:#^/UUY(UV`+C_____R<.058GEBU40@?J?````BTT,=PN($;@!
M````R<.)]HV"8/___X/X#W<5BH*@-Q@(A,!T*8@!N`$```#KWHGVC8*`\?__
M@_A?=PF*@F`I&`CKWI"!^JT@``"PWW37N/_____)PXUV`%6)Y8M%$(H0A-*+
M30P/ML)X"HD!R;@!````PY"-0E\\6G<1C4(E/`-V"@^VP@5@#0``Z]ZX____
M_\G#D%6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"__'__X/X6G<9C8+%\?__
M@_@#=@Z-0J"(`;@!````Z]N)]KC_____R<.058GEBT40B@"$P(M-#'@-#[;`
MB0&X`0```,G#D`^VP&:+E``@CQ$(9H/Z_;C_____=.</M\+KVY!5B>6+51"#
M^G^+30QW"H@1N`$```#)PY"!^J````"PH'0BC8(`\O__@_A?=B.-@O#?__^#
M^!=W((J"D&\1"(GVA,!T'H@!N`$```#KR(UV`(J"P($1".OH@?JL(```L(!T
MXKC_____R<.-=@!5B>6+11"*`#P?BU4,=Q4/ML@/MX0)H#<8"(D"R;@!````
MPY"$P'@,#[;`B0+)N`$```###[;`#[>$`*`U&`B)`LFX`0```,-5B>6+31"#
M^7^+50QW&H/Y'W<+N&0`$$+3^*@!=0J("K@!````R<.0C8%`____/?<```!W
M$XJ!X#08"(3`=!V(`K@!````Z]V-@6#A__^#^%]W"8J!H!88".O@D+C_____
MR<.058GE5U93@^P,BT40B@`\%XMU"(M]#'<T#[;(9HN4"0`U&`AFBUX49H7;
M=#R-@@#]__]F@_@_=UP/M\(M``,``(/X(W=E_R2%F)@8"(3`9@^VT'G/#[;8
M9HN4&P`S&`AFBUX49H7;=<2-2K]F@?EO`0^&O`````^WPHD'N`$```"#Q`Q;
M7E_)PV8Y'(6@,!@(B<)T;@^WT\=&%`````")%X/$#%M>,<!?R</HJ0___S'`
MC78`BPS%Q#,8"(L$Q<`S&`@!R$AF.1R-H#`8"'?%9CD<A:`P&`ARNXUV`(T4
M`='J9CD<E:`P&`AT%W97.=%THXG0C10!T>IF.1R5H#`8"'7I#[<$E:(P&`C'
M1A0`````Z6/___^X`0```.N7N`0```#KD+@"````ZXFX`P```.N"#[?ZN/W_
M__^)?A3I/O___XGV.=$/A#S___^)T>N,58GE5U93BTT0@_E_BWT,=Q^#^1]W
M"[AV`/X`T_BH`74/B`^[`0```(G86UY?R<.0C9%@____@?H7`0``=PZ*@>`N
M&`B$P'0XB`?KUXV9`/W__X/[)P^&WP```(VQP/S__X/^`7<(BH$`+!@(Z]:-
M@6#A__^#^%\/AM8```"-=@`/MQ6@*Q@(,=LYRK[(````#X>8````#[<%P"X8
M"#G(#X*)````C78`C10ST>H/MP25H"L8"#G(=!T/AHD````YTW1KB=:-%#/1
MZ@^W!)6@*Q@(.<AUXP^W!)6B*Q@()?\/``"#^'^(P783BHC@+A@(A,F[____
M_P^$*____X-]%`&[_O___P^.'/___XH$E:,K&`C`^`0/OMB(#XJ+A"L8"+L"
M````B$\!Z?K^__^[_____XG86UY?R<.*@4`L&`CI__[__XUV`#G3=!*)T^E5
M____BH%`$!@(Z>;^__^)\@^W-+6@*Q@(.<Z[_____P^$8?___^FN_O__B?95
MB>6+11"*`(3`BTT,NO____]X$CQ<="0\?G00#[;0B1&Z`0```(G0R<.)]KH!
M````QP$^(```Z^V-=@"Z`0```,<!I0```.O=C78`58GEBU40@_I_BTT,=Q:#
M^EQT$8/Z?G0,B!&X`0```)#)PXGV@?JE````=!B!^CX@``"X_____W7GN`$`
M``#&`7[KW9"X`0```,8!7.O2B?95B>6+11!3BA"$THM=#'@L@/I<=!>`^GX/
MML)T-XD#N0$```")R%O)PXUV`+D!````QP.E````Z^N-=@"-0E\\/KG_____
M=]P/ML(%P/X``(D#Z\NY`0```,<#/B```.O#C78`58GEBU40@_I_4XM-#'<9
M@_I<=!2#^GYT#X@1NP$```")V%O)PXUV`('ZI0```'0D@?H^(```="B-@I\`
M__^#^#Z[_____W?8C5I`B!F[`0```.O,NP$```#&`5SKPHGVNP$```#&`7[K
MMHGV58GE4XM=$(H3C4+?/`=V#(U"T#Q$N?____]W3(-]%`&Y_O___WY!BDL!
MC5G?@/M==S$/MMJ-%%O!X@0IV@^VP8V$4,'S__\]@04``'8B/7\>``!W#F:+
MA``<Z1<(9H/X_74>N?____^)R%O)PXUV`#VQ`@``=^QFBX0`("88".O<BTT,
M#[?0B1&Y`@```(G(6\G#D%6)Y5=64X-]%`&+?0R+51"X_O___WY$@?K_````
M=D&-B@#]__^!^5\!``!W0XG6P>X$C1RUP/(7"(UV`(7;=!9FBW,"B=&#X0\/
MM\;3^*@!#X6)````N/____];7E_)PXG0P>@$C1R%X/,7".O.B?:-F@#@__^!
M^Q\#``!V'HV*`-O__X'Y;P$``'<>B=;![@2-'+4`Z1<(ZZ*)]HG0P>@$C1R%
MH.H7".N2C9H`T/__@?O_````#X:2````C8H`LO__@?FO40``#X>1````B=;!
M[@2-'+4`RA<(Z5W___^X`0```-/@2"'PB<8EJJH``-'X@>9550```<:)\8'F
MS,P``,'^`H'A,S,```'QB<J!X?!P``#!^02!X@\/```!R@^VPF;!Z@@!T`^W
M,P^WV`'>9HN4-H"G%PB)T6;!Z0B(#XA7`5M>N`(```!?R<.)T,'H!(T<A0#F
M%PCIW?[__XV:``'__X'[[P````^'Y?[__XG0P>@$C1R%@)T7".FZ_O__B?95
MB>53BUT0BA.`^B)T!XU"VCP!=U.#?10!N?[___]^08I+`8U9WX#[77<Q#[;:
MC11;P>($*=H/ML&-A%#!\___/=4!``!W/3VN````=PYFBX0`!*87"&:#^/UU
M:;G_____B<A;R<.)]HU*UX#Y`G:EC4+0/#VY_____W:9B<A;R<.-=@`][P(`
M`'<1/9$"``!WRF:+A`"4H1<(Z[H]@04``'<1/0($``!WLF:+A``@G1<(ZZ(]
M*AP``'>A9HN$`)QJ%PCKD8M-#`^WT(D1N0(```")R%O)PY!5B>575E.#?10!
MBWT,BU40N/[___]^/('Z7P0``'8YC8H`W___@_DO=SZ)T\'K!(TTG2QL%PB)
M]H7V=!)FBUX"B=&#X0\/M\/3^*@!=5"X_____UM>7\G#B=#!Z`2--(6`=!<(
MZ]*)]HVR`++__X'^KU$``'8:C8H``?__@_E?=\V)T\'K!(TTG28@%PCKJ9")
MT,'H!(TTA8!,%PCKFK@!````T^!((=B)PR6JJ@``T?B!XU55```!PXG9@>/,
MS```P?L"@>$S,P```=F)RH'A\'```,'Y!('B#P\```'*#[;"9L'J"`'0#[<>
M#[?P`?-FBY0;@#`7"(G19L'I"(@/B%<!6UZX`@```%_)PXUV`%6)Y8M%$(H`
MA,"+30RZ_____W@2/"1T)#Q^=!`/MM")$;H!````B=#)PXGVN@$```#'`3X@
M``#K[8UV`+H!````QP&E````Z]V-=@!5B>6+51"#^G^+30QW%H/Z)'01@_I^
M=`R($;@!````D,G#B?:!^J4```!T&('Z/B```+C_____=>>X`0```,8!?NO=
MD+@!````Q@$DZ]*)]E6)Y5.+71"*$XU"WSP(=@R-0M`\1[G_____=TR#?10!
MN?[___]^08I+`8U9WX#[77<Q#[;:C11;P>($*=H/ML&-A%#!\___/8$%``!V
M(CWQ'P``=PYFBX0`'.H6"&:#^/UU'KG_____B<A;R<.-=@`]/@,``'?L9HN$
M```J%PCKW(M-#`^WT(D1N0(```")R%O)PY!5B>564X-]%`&+=0R+31"X_O__
M_WX_@?E?!```=CZ-D0#@__^!^D\&``!W0(G(P>@$C1R%8.H6"(7;=!1FBU,"
M@^$/#[?"T_BH`0^%AP```+C_____6U[)PXUV`(G(P>@$C1R%`/06".O.B?:-
MF0#0__^!^R\"``!V'HV!`++__SWO3@``=Q^)RL'J!(T<E8#*%@CKHXUV`(G*
MP>H$C1R5P.46".N2C9D`8O__@?NO`0``#X:+````C9$``?__@?KO````=XJ)
MR,'H!(T<A8"=%@CI8?___[@!````T^!((=")PB6JJ@``T?B!XE55```!PHG0
M@>+,S```P?H")3,S```!T(G!)?!P``#!^`2!X0\/```!P0^VT6;!Z0@!R@^W
M`P^WT@'09HN,``"C%@B)RV;!ZPB('HA.`5NX`@```%[)PXG(P>@$C1R%`+86
M".GD_O__58GE5E.#?0P!B=:+30BX_O___WY`@?G_`0``=C^-D0#]__^!^K\`
M``!W08G(P>@$C1R%`)H6")"%VW049HM3`H/A#P^WPM/XJ`$/A8<```"X____
M_UM>R<.-=@")R,'H!(T<A0";%@CKSHGVC9D`XO__@?N_`0``=AJ-@0#0__^#
M^#]W'8G*P>H$C1R5((X6".NED(G*P>H$C1R5P)(6".N6C9D`SO__@?O_`0``
M#X:/````C9$`LO__@?K_+@``#X>.````B<C!Z`2-'(5@>A8(Z6'___^X`0``
M`-/@2"'0B<(EJJH``-'X@>)550```<*)T('BS,P``,'Z`B4S,P```=")P27P
M<```P?@$@>$/#P```<$/MM%FP>D(`<H/MP,/M](!T&:+C`#@?A8(B<MFP>L(
MB!Z(3@%;N`(```!>R<.)R,'H!(T<A2"-%@CIY/[__XV9`(+__X'[SQ0``'<1
MB<K!Z@2-')4@:18(Z<7^__^-@0!L__\][P@``'<1B<K!Z@2-')5@818(Z:?^
M__^-F0!B__^!^X\!``!W$8G(P>@$C1R%8%X6".F(_O__C9$``?__@_I/#X>1
M_O__B<C!Z`2-'(7X118(Z6C^__]5B>575E.#[`R+71"*$X#Z*(M]#(MU%`^$
M%P$``(U"WSP(#X:0````C4K0@/E'#X:$````BA.`^BH/A'D!``"-2M6`^00/
MAU4!``!.N?[___]^68I+`8U9WX#[70^'D@$```^VPHT40,'B!"G"#[;QC816
MP?/__SVM(```#X9^`0``/8,B```/AV<!``!FBX0`)%H6"&:#^/T/A%4!```/
MM\B)#[D"````C78`B<J#Q`Q;7HG07\G#@_X!N/[___]^9HI+`8U!WSQ=#X=D
M____#[;"C11`P>($*<(/ML&-A%#!\___/8$%``!W%3T^`P``#X<]____9HN$
M```J%PCK$SWQ'P``#X<H____9HN$`!SJ%@AF@_C]#X06____#[?8B1^X`@``
M`(G"@\0,6UZ)T%_)PX/^`0^.X/[__XI#`8U(WX#Y'P^'T?[__X#Y7<9%\BN(
M1?,/A[@````/ML`%BP,``#VM(```#X?!````/8$%```/AYH```!FBX0`Z)<6
M"&:#^/T/A(@````/M\")![H"````@\0,6UZ)T%_)PXU"ACP$N?____\/AIO^
M__^)RNGW_O__D$ZZ_O___P^.9O___XI+`8U!WSQ=LO\/AU;___^$R7A3@/DD
M=#Z`^7X/ML%UJKH"````QP<^(```ZZ2)]KG_____B<KIKO[__SV!!0``=^UF
MBX0`Z)<6".F!_O__BA/I`O[__[H"````QP>E````Z6O____HG`'__SV#(@``
M=]UFBX0`)%H6".D^____58GE5U93@^P,BWT4@_\!BW40#X[H````@?Y?!```
M#X>H````B?#!Z`2-'(4`]!8(A=L/A.0```!FBU,"B?&#X0\/M\+3^*@!#X3.
M````N`$```#3X$@AT(G"):JJ``#1^('B554```'"B="!XLS,``#!^@(E,S,`
M``'0B<$E\'```,'X!('A#P\```'!#[;19L'I"`'*#[<##[?2`=!FBY0``*,6
M"(G39L'K"(M-#&:#^RB(&8A1`0^$F@```+@"````C67T6UY?R<.0C98`X/__
M@?I/!@``=BZ-G@#0__^!^R\"```/AZH```")\,'H!(T<A<#E%@CI,____XUV
M`.B#`/__C78`B?'!Z02-'(U@ZA8(A=L/A1S___^#_G^-1?-W2(/^)'1#@_Y^
M=#Z)\XA=\XI5\XU*WX#Y77<^3[C^____#XYY____BW4,Q@8JB%8!Z6;___^`
M^B`/AEW___^`^D`/AU3____KL('^I0```'0=@?X^(```=$=75HM5#(M%".AC
M^O__C67T6UY?R</&`"3KG8V6`++__X'Z[TX``'8GC9X`8O__@?NO`0``=RJ)
M\,'H!(T<A0"V%@CI;?[__\8`?NEH____B?'!Z02-'(V`RA8(Z53^__^-E@`!
M__^!^N\````/AR[___^)\<'I!(T<C8"=%@CI,?[__Y!5B>575E.#[`B+=0B*
M#H#Y@(G7#X8_`0``@/G_#X0V`0``@WT,`;C^____#X['````C4%?/%8/A\0`
M``"`^:&*7@$/A,\!``"`^Z`/AJ\```"`^_\/A*8```"-0X"(1?&(1?.-05^-
M48`\"(A5\@^&4@$``(U!4#Q'#X9'`0``D(U5\H#YIHA-\HA:`70%@/FH=6V-
M0\`\/G8)A-MY8H#[_W1=#[;1C032C01"C12`T>*)5>R$VP^VTXU"OW@#C4+`
M`T7LC9!"H/__@?KQ'```#X?D`0``+=-[``"#^!5W(&:+A!*V#A4(9H/X_702
M#[?`B0>X`@```(/$"%M>7\G#C5E_@/L?=S2*%HU"?SP?N?____]W'(I.`8U9
MP(#[/@^&'0$``(3)#X@,`0``N?____^)R(/$"%M>7\G#@/FG=R>`^:)U$HI6
M`8U*7X#Y"0^&/@$``(UV`(/$"%M>N/____]?R<.-=@"`^?]TU(H6@/JG=N2`
M^O]TWXI.`8U!P#P^=@B-68"`^R!WS0^V\HT$=L'@!83)#[;1#X@V`0``@^I`
MC800H,___SWO+@``=ZAFBX0`8%D5"&:#^/UTF@^WP.DK____C4-?/%T/AZ_^
M__\/ML*-%$#!X@0IP@^V1?&-A%#!\___/8$%```/A[`````]/@,```^'@_[_
M_V:+A```*A<(9H/X_0^$<?[__P^WP.G:_O__@/ND#X2]````@/NJ#X4?_O__
MN`(```#'`A0@``#IO_[__X#Y_P^$Z_[__P^VTHT<THT$6HTT@`^VV83)C10V
MC4._>`.-0\"-A`)"H/__/;\7```/A[W^__]FBX0`($<5"&:#^/T/A*O^__\/
MM\B)#[D"````B<CIH?[__P^VP@7/(```B0?I4?[__SWQ'P``#X?3_?__9HN$
M`!SJ%@CI2____RTJ?0``@_@%#X<X_O__9HN$$O`+%0CI$_[__X/J0>G%_O__
MN`(```#'`K<```#I"_[__XUV`%6)Y5=64U:+70B!^_LP``")UP^$"`$``('[
M%2````^$_````('[7P0```^'N````(G8P>@$C32%`/06"(7V#X3<````9HM6
M`HG9@^$/#[?"T_BH`0^$Q@```+L!````T^-+(=.)V8'CJJH``-'[@>%550``
M`=F)R('AS,P``,'Y`B4S,P```<B)PR7P<```P?@$@>,/#P```<,/MM-FP>L(
M`=H/MPX/M_(!\6:+E`D`HQ8(B=-FP>L(@WT,`8A=\HA5\[C^____?A>*1?*#
MP("(!XC0@\"`B$<!B?:X`@```%M;7E_)PY"-DP#@__^!^D\&```/AHX!``"-
MLP#0__^!_B\"```/A_<!``")V,'H!(TTA<#E%@CI'____XUV`(VS`/[__X'^
MWP````^'K@```(G:P>H$C3250#P5"(7V#X3B````9HM6`HG9@^$/#[?"T_BH
M`0^$S````+@!````T^!((=")PR6JJ@``T?B!XU55```!PXG8@>/,S```P?L"
M)3,S```!V(G!)?!P``"!X0\/``#!^`0!P0^VT6;!Z0@!R@^W'@^W\@'S9HN4
M&Z"U%`B)T6;!Z0B#?0P!B$WRB%7SN/[___\/CA+___^*7?*(T(@?B$<!Z?[^
M__^)]HV+`.#__X'YOP(``'8FC;,`V___@?X/`0``#X?)````B=K!Z@2--)5@
M,A4(Z2W___^-=@")V,'H!(TTA0`T%0B%]@^%'O___XVSD-[__X/^"0^&2`$`
M`(V3P/[__X/Z#W=:9HN4&P`[%0AFA=(/A6'___^!^[<````/A(D```"!^Q0@
M``"X_____P^%<?[__X-]#`&P_@^.9?[__\8'H<9'`:KI5/[__XG9P>D$C32-
M8.H6".FC_?__C78`C8.P_?__@_@7=PUFBY0;H#@5".N9C78`C8O0`?__@_D7
M=Y1FBY0;H$`3".N!C8L`T/__@?G_````=VJ)V,'H!(TTA6`O%0CI5O[__X-]
M#`&X_O___P^.ZOW__\8'H<9'`:3IV?W__XV3`++__X'Z[TX``'8?C;,`8O__
M@?ZO`0``=VZ)V,'H!(TTA0"V%@CI#/W__XG9P>D$C32-@,H6".G[_/__C;,`
MSO__@?[?`0``=Q&)VL'J!(TTE6`N%0CIWOW__XV+`++__X'YKU$``'="B=C!
MZ`2--(7@$A4(Z;_]__^-0S'&!Z*(1P'I3_W__XV3``'__X'Z[P````^'@?W_
M_XG9P>D$C32-@)T6".F,_/__C;,`!___@?XO`0``=Q&)VL'J!(TTE<#G%`CI
M;_W__XV+``+__X'Y[P$```^'1_[__XG8P>@$C32%`.84".E,_?__B?95B>56
M4X-]#`&)UHM-"+C^____?D"!^?\```!V/XV1`/[__X'ZSP$``'=!B<C!Z`2-
M'(4@[1`(D(7;=!1FBU,"@^$/#[?"T_BH`0^%B````+C_____6U[)PXUV`(G(
MP>@$C1R%(.X0".O.B?:-F0#@__^!^[\"``!V'HV!`-S__SU/`@``=Q^)RL'J
M!(T<E4#C$`CKHXUV`(G*P>H$C1R5X.00".N2C9D`T/__@?NO;P``#X:4````
MC9$`!O__@_HO#X>6````B<C!Z`2-'(6<D1`(Z6#___^X`0```-/@2"'0B<$E
MJJH``-'X@>%550```<&)R('AS,P``,'Y`B4S,P```<B)PB7P<```P?@$@>(/
M#P```<(/MLIFP>H(`=%F`PL/M\&-'$"*BX`;#@B(#HJ3@1L."(J+@AL."(A6
M`8A.`ENX`P```%[)PXG(P>@$C1R%0,00".G;_O__C9D``O__@?OO`0``=Q&)
MRL'J!(T<E2"0$`CIO/[__XV!``#^_SW?I@``=Q&)RL'J!(T<E>`E$`CIGO[_
M_XV9``C]_X'['P(```^'I/[__XG(P>@$C1R%0.</".E[_O__C78`58GE5E.#
M?0P!B=:+30BX_O___WY`@?G_````=C^-D0#^__^!^E\"``!W08G(P>@$C1R%
M`&X2")"%VW049HM3`H/A#P^WPM/XJ`$/A8L```"X_____UM>R<.-=@")R,'H
M!(T<A2!O$@CKSHGVC9D`X/__@?N_`@``=AZ-@0#<__\]3P(``'<?B<K!Z@2-
M')4@9!((ZZ.-=@")RL'J!(T<E<!E$@CKDHV9`-#__X'[WP,```^&CP```(V1
M`++__X'ZKU$```^'C@```(G(P>@$C1R%($02".E=____N`$```#3X$@AT(G"
M):JJ``#1^('B554```'"B="!XLS,``#!^@(E,S,```'0B<$E\'```,'X!('A
M#P\```'!#[;19L'I"`'*#[<##[?2`=!FBXP`(.P1"(G+9L'K"(@>B$X!6[@"
M````7LG#B<C!Z`2-'(4@8!((Z>#^__^-F0`&__^#^P]W$8G*P>H$C1R5'!D2
M".G$_O__C8$``O__/6\!```/A\O^__^)RL'J!(T<E<`7$@CIHO[__XGV58GE
M4XM=$(H3C4+?/`MV"(U*T(#Y&'=L@WT4`;G^____?D&*2P&-6=^`^UUW,0^V
MVHT46\'B!"G:#[;!C810P?/__SV!!0``=R(]6@0``'<.9HN$`"!V%@AF@_C]
M=4JY_____XG(6\G#C78`/0T/``!W)3VO#@``=^5FBX0`O%@6".O5C4*V/#.Y
M_____W:(B<A;R<.-=@`])2(``'?`9HN$`&0?%@CKL(M-#`^WT(D1N0(```")
MR%O)PY!5B>575E.#?10!BWT,BU40N/[___]^1('Z7P0``'9!C8H`X/__@?EO
M!@``=T.)UL'N!(T<M<`R%@B-=@"%VW069HMS`HG1@^$/#[?&T_BH`0^%B0``
M`+C_____6UY?R<.)T,'H!(T<A6`\%@CKSHGVC9H`T/__@?O?`P``=AZ-B@"R
M__^!^9]1``!W'HG6P>X$C1RUP!$6".NBB?:)T,'H!(T<A<`M%@CKDHV:`%3_
M_X'[GRL```^&D@```(V*``?__X'Y#P$```^'D0```(G6P>X$C1RUH-L5".E=
M____N`$```#3X$@A\(G&):JJ``#1^('F554```'&B?&!YLS,``#!_@*!X3,S
M```!\8G*@>'P<```P?D$@>(/#P```<H/ML)FP>H(`=`/MS,/M]@!WF:+E#9`
MV14(B=%FP>D(B`^(5P%;7K@"````7\G#B=#!Z`2-'(5`[Q4(Z=W^__^-F@`!
M__^!^^\````/A^7^__^)T,'H!(T<A>#9%0CINO[__XGV58GE5U934(M%$(H0
MA-*+=0R+711X$@^VPHD&N0$```!?6UZ)R%_)PX#ZH`^'TP```(#ZC@^$Y@$`
M`(#ZC[G_____==R#^P&Q_G[5BE`!@/J@#X9M`0``@/K_#X1D`0``@_L"?KN`
M^O0/AV,!``"*0`(\H`^&2P$``#S_#X1#`0``C4J`C5B`@/DBB$WPB%WQ=!F-
M0EH\`782C4)7/`)V"XU"4#P]#X<9`0``C5/?@/I=#X<-`0``#[;!C3Q`P><$
M*<</MLN-A'G!\___/=4!```/A\\!```]K@````^'X@```&:+A``$IA<(9H/X
M_0^$T`````^WV+D#````B1[I'?___Y"`^O\/A"3___]+N?[___\/C@?___^`
M^O0/AY(```"*2`&`^:`/AI8```"`^?\/A(T```"->8")^(A%\XU"7XU:@#P'
MB%WR=@R-0E`\1+K_____=U6-45^`^ET/AP8!```/ML.-%$#!X@2)^2G"#[;9
MC813P?/__SV!!0``#X<,`0``/;$"```/A]D```!FBX0`("88"&:#^/T/A,<`
M```/M_B)/KH"````B='I;/[__XI(`8#YH'8(@/G_=3Z-=@!?6UZY_____XG(
M7\G#BD@"@/F@=NN`^?]TY@^VVHT\6\'G!`^VP2G?C91X%8D``+D#````B1;I
M(?[__P^V^HT4?\'B!`^VP2GZC9Q0:84``+D"````B1[I`/[__TNY_O___P^.
M]/W__XI0`8U:7X#[/K'_#X?C_?__A-)X18#Z7'0P@/I^#[;"=`R)!KD"````
MZ<;]__^Y`@```,<&/B```.FV_?__NO____^)T>FJ_?__N0(```#'!J4```#I
MFOW__P^VP@7`_@``B0;KOCU_'@``=]%FBX0`'.D7".GS_O__/>\"``!W&#V1
M`@``#X<,____9HN$`)2A%PCI)?[__SV!!0``=Q@]`@0```^'[?[__V:+A``@
MG1<(Z0;^__\]*AP```^'U?[__V:+A`"<:A<(Z>[]__]5B>575E.#[`R+71"#
M^W^+=0R+?12X_____W<'B!ZX`0```(/X_W0(C67T6UY?R<-J`E.-1?)0_W4(
MZ$7D__^#Q!"#^/]T*8/X`@^%U@(``$^X_O___W[0BE7R@\*`B!:*1?.#P("(
M1@&X`@```.NX@_M_#X<4`0``@_M<#X0+`0``@_M^#X0"`0``B%WRN0$```"#
M^?]T"XI5\H32#XCE`0``@?M?!```#X<<`0``B=K!Z@2-!)6`=!<(B47LBT7L
MA<`/A/L```"+3>QFBU$"B=F#X0\/M\+3^*@!#X3B````N`$```#3X$@AT(G"
M):JJ``#1^('B554```'"B="!XLS,``#!^@(E,S,```'0B<$E\'```,'X!('A
M#P\```'!#[;19L'I"`'*BTWL#[<!#[?*`<AFBY0`@#`7"(G09L'H"(A%\HA5
M\[@"````@_C_#X24````@_@"#X7&`0``@_\"N/[___\/CKK^___&!H^*3?*#
MP8"(3@&*7?.#PX"X`P```(A>`NF;_O__@?NE````#X2^````@?L^(```#X3:
M````C8.?`/__@_@^N?____\/A]K^__^-2T"(3?+IRO[__[C_____ZX.-@P#?
M__^#^"\/AX8```")V<'I!(T$C2QL%PCIT/[__X'[I0````^$U````('[/B``
M``^$%@$``(V+`"#__X'Y5P<``+C_____#X<._O__@?NKXP``#X>R````3[#^
M#X[Y_?__N%U!3*[WX<'J!HT$4L'@!"G0T>`HP8C(@^H+@^A?B!:(1@'I$O[_
M_\9%\ESI+O[__XV3`++__X'ZKU$``'<]B=C!Z`2-!(6`3!<(Z3S^___&1?)^
MZ0;^__])#X67````3[C^____#XZ-_?__N`(```#&!HZ(5@'I??W__XV+``'_
M_X/Y7P^'"O___XG:P>H$C025)B`7".GP_?__N`$```#&!ESI4/W__T^X_O__
M_P^.1/W__XV+5!S__[A=04RN]^'!Z@:-'%+!XP0IT]'C*-F#Z@N#Z5^X`P``
M`,8&CXA6`8A.`ND/_?__N`$```#&!G[I`OW__^CE[/[_D%6)Y5=64U&+31"*
M$832BW4,BUT4>":`^EQT&8#Z?@^VP@^$@0```(D&N`$```!:6UY?R</'!J4`
M``#K[8U"7SP^=G&->G^)^#P>=G>-0B`\"G9PC4(0/`D/AR(!``!+N/[___]^
MR(I)`8U9P(#[/G8+C4&`/'P/AP0!```/MM*-/%+!YP0IUX3)C12]P"\```^(
M&0$```^VV8U$&L")!K@"````ZXB)]L<&/B```.EV____D`^VP@7`_@``B0;I
M9O___TNX_O___P^.7____XI)`8U9P(#[/@^'EP```(#ZWXGX=@.-0C^$R8U1
MP`^(HP````^VP-'@@/I=C4@B=P.-2"&`^EV(3?*-6B%V`XU:PXU1WXU]\H#Z
M!XA?`78,C4'0/$2Z_____W=#C5/?@/I==U</ML&-/$#!YP0IQP^VRXV$><'S
M__\]@04``'=//;$"``!W-&:+A``@)A@(9H/X_70F#[?8B1ZZ`@```(G0Z;G^
M__^-08`\?`^&7O___[C_____Z:3^__^Z_____XG0Z9C^__^-4;_I5?___SU_
M'@``=^5FBX0`'.D7".NO#[;!C40"O^GB_O__D%6)Y5=64X/L#(M=$(/[?XM]
M#(UU\G<U@_M<=#"#^WYT*XA=\KH!````@_K_=%Y*#X7M````BE7RA-)X2(@7
MN`$```"-9?1;7E_)PY"!^Z4```!T(('[/B```'0@C8.?`/__@_@^NO____]W
MO8U30(@6Z[&0Q@9<ZZN-=@#&!G[KHXUV`(U*7X#Y/G:P:@)35O]U".@$W___
M@\00@_C_="2#^`)U?8-]%`&X_O___WZ3BE7RC4+?/%.*3@%W!XU!WSQ==F.-
MBP`@__^!^5<'``"X_____P^':/___X-]%`&P_@^.7/___[A=04RN]^'!Z@>-
M'%+!XP0IT\'C`BC9@^H0@/D^B,B(%W<3@\!`B$<!C67T6UZX`@```%_)PX/`
M0>OKZ`'J_O\/ML*#Z"&)PM'J#[;)J`&-6=]T`XU9/8#Z'HC9C4*!=@.-0L&`
M^3Z(!XU!0':XC4%!Z[.)]E6)Y5935HM-$(H1A-*+=0R+710/ML)X#(D&N`$`
M``!;6U[)PXU"7SP^#X;=````C4)_/!X/A]\```"`^H</A-8```!+N/[___]^
MU(I)`8U9P(#[/G8+C4&`/'P/AV,!``"`^M^-0G]V`XU"/X3)#XA:`0``@^E`
M#[;`T>"`^5V-4")W`XU0(8#Y78A5]@^'*0$``(/!(8U:WXU%]H#[!XA(`78,
MC4+0/$2[_____W=3C5G?@/M=#X?T````#[;:C11;P>($*=H/ML&-A%#!\___
M/8$%```/A_H````]L0(```^'R0```&:+A``@)A@(9H/X_0^$MP````^WR(D.
MNP(```")V%M;7LG#B?8/ML(%P/X``.G__O__C4(@/`H/AA____^`^H=T$(U"
M$SP!=@F`^OD/AN````!+N/[___\/CMK^__^`^H=T%(U:$X#[`78,C4(&/`*[
M_____W>EBDD!C5G`@/L^=@>-08`\?'=`A,D/MMH/ML$/B`$!``"-2,"`^M]V
M?XT46\'B!"G:C8211'+__SU/(```=TX]PP0``'<-9HN$`+#/%0CI/____[O_
M____B=CI2?___X/I/>G2_O__6UNX_____U[)PX/I0>FA_O__/7\>``!WTV:+
MA``<Z1<(Z07___\]VRD``'=V/<<A``!WN&:+A`#@E!4(Z>K^__^-!%O!X`0I
MV(V$@42A___I?/___XU"$#P)=Z1+N/[___\/CO/]__^*20&-6<"`^SYV!XU!
M@#Q\=X8/MM*-'%+!XP0ITX3)C12=P"\``'@S#[;!C40"P(D&6UNX`@```%[)
MPSU?*P``#X<^____9HN$`*A^%0CI</[__XU(O^GZ_O__#[;9C40:O^O+58GE
M5U93@^P,BUT0@_M_BWT,N/____]W"(A=\K@!````@_C_=!Y(#X6$`@``BD7R
MA,!X$(@'N`$```"-9?1;7E_)PY"#^W]W+X/[7'0J@_M^="6(7?*)]KH!````
M@_K_=$I*#X5(`@``BE7RC4I?@/D^=SB(%^N^@?NE````#X1H`0``@?L^(```
M=!B-@Y\`__^#^#ZZ_____W?!C5-`B%7RZ[3&1?)^ZZZ)]FH"4XUU\E;_=0CH
M]=K__X/$$(/X_W0P@_@"#X7E`0``@WT4`;C^____#XY@____BE7RC4+?/%.*
M3?-W"XU!WSQ=#X;B`0``C9,`W___@?J_`0``#X?+````B=G!Z02--(V@R14(
MA?8/A&\!``!FBU8"B=F#X0\/M\+3^*@!#X19`0``N`$```#3X$@AT(G"):JJ
M``#1^('B554```'"B="!XLS,``#!^@(E,S,```'0B<$E\'```,'X!('A#P\`
M``'!#[;19L'I"`'*#[<&#[?R`?!FBY0`0+L5"(G19L'I"(A-\HA5\[@"````
M@_C_=%B#^`(/A0L!``"#?10!N/[___\/CH;^__^*7?*('XI%\XA'`8UE]%M>
MN`(```!?R<.-=@"-LP#<__^#_G]W:(G8P>@$C32%P,@5".DE____QD7R7.EC
M_O__C8L`(/__@?E7!P``N/____\/AR_^__^#?10!L/X/CB/^__^X74%,KO?A
MP>H'C012P>`$*=#!X`(HP8/J$(#Y/HC(B!=W0X/`0.EZ____C9,`T/__@_H?
M=A^-LP#.__^!_L\!``!W-HG8P>@$C32%P,05".FD_O__B=G!Z02--(VTQ14(
MZ9/^__^#P$'I-____XGVN/_____I!O___XV3`++__X'ZCP<``'<6B=G!Z02-
M-(W`NQ4(Z6#^___HAN3^_XVS`*G__X'^OP(``'=+B=C!Z`2--(7`N!4(Z3S^
M__\/ML*#Z"&)PM'J#[;)J`&-6=]T`XU9/8#Z'HC9C4*!=@.-0L&`^3Z(!XU!
M0`^&MO[__XU!0>FN_O__C9,`I?__@?K?`@``=Q&)V<'I!(TTC0"W%0CIX_W_
M_XVS`*'__X'^GQP``'<1B=C!Z`2--(7`KA4(Z<3]__^-DP"#__^!^J\"``!W
M$8G9P>D$C32-@*85".FE_?__C;,`??__@?Z_`@``=Q&)V,'H!(TTA4"D%0CI
MAOW__XV3`'C__X'ZSP8``'<1B=G!Z02--(U`H14(Z6?]__^-LP!P__^!_M\.
M``!W$8G8P>@$C32%@)L5".E(_?__C9,`!___@?HO`0``=Q&)V<'I!(TTC>"`
M%0CI*?W__XVS``'__X'^[P````^'CO[__XG8P>@$C32%('\5".D&_?__D%6)
MY5=64X/L#(M%"(M5$(M]%(M8%#'VD(H*@/D;=6*-3@,Y^7\GBD(!/"AT-SPD
M=4F*0@(\0'0$/$)U/KL"````B<Z-20&#P@,Y^7[+BTT(N/[___^)610I\(/$
M#%M>7\G#B?:*0@(\0G0+/$IU"[L!````Z\LQV^O'N/_____KV8/[`0^$K0``
M``^"A````(/[`@^%_0```(U&`CGXB47P?ZJ$R7C3BEH!A-MXS(U1WX#Z!W8'
MC4'0/$1WO8U3WX#Z77>U#[;YC0Q_P>$$*?D/MO.-A$[!\___/8$%```/AYD`
M```]L0(``'>.9HN$`"`F&`AF@_C]=(`/M\"+50R)`HM="(M%\,=#%`(```#I
M1O___X3)N/____\/B#G___\/ML&+?0R)!XM5"(U&`8E:%.DC____A,FX____
M_P^(%O___X#Y7'0?@/E^="4/MOF+50R).HM%",=`%`$```"-1@'I\O[__XM=
M#,<#I0```.OCBTT,QP$^(```Z]@]?QX```^'\?[__V:+A``<Z1<(Z5[____H
ME>'^_Y!5B>575E.#[`R+51"+?0B#^G^+70R+=RBX_____W<(B%7RN`$```"#
M^/]T3$@/A5,!``"*3?*$R7@^@_X!&<"#X/V-4`0Y512X_O___WP,A?9U$9"(
M"XG0B7<HC67T6UY?R<.0Q@,;QD,!*,9#`D(Q]H/#`^O>B?:#^G]W5X/Z7'12
M@_I^=$V(5?*)]KD!````@_G_='))#X7I````BDWRA,EX9#'`@_X!#Y7`C51`
M`3E5%+C^____?*&#_@%TE<8#&\9#`2C&0P)*O@$```"#PP/K@('ZI0````^$
MDP```('Z/B```'08C8*?`/__@_@^N?____]WF8U*0(A-\NN,QD7R?NN&B?9J
M`E*-5?)25^CSU/__@\00@_C_=%^#^`)U9(I5\H32>%.`??,`>$TQP(/^`@^5
MP(U,0`(Y312X_O___P^,$O___X/^`G03Q@,;QD,!),9#`D*^`@```(/#`X@3
MBE7SB<B(4P&)=RCIZ/[__\9%\ESI$/___[C_____Z=7^___H">#^_Y!5B>6+
M10B+0"@QTH7`BTT,=!Z#?1`"NO[___]^$\8!&\9!`2C&00)"N@,```"-=@")
MT,G#58GE5U93@^P,BT4(BU40BWT4BW`4,=N0B@J`^1L/A8@```"-2P,Y^7\X
MBD(!/"AT4SPD=6^*0@(\0'0\/$)T.#PH=6"-0P0Y^'\7@'H#1'53O@,```"#
MP@2)PXU+`3GY?K:+30BX_O___XEQ%"G8@\0,6UY?R<.0O@(```"#P@.)R^O7
MBD("/$)T$#Q*=16^`0```(/"`XG+Z\`Q]H/"`XG+Z[>X_____^O$@_X!#X3+
M````#X*B````@_X"#X3U````@_X##X4(`@``C4,".?B)1>Q_C(3)>,J*6@&$
MVWC#@/DB=!>-4=J`^@%V#XU!USP"=@B-4="`^CUWIXU#WSQ==Z`/MOF-#'_!
MX00I^0^V\XV$3L'S__\]U0$```^'0P$``#VN````#X=U____9HN$``2F%PAF
M@_C]#X1C____#[?`BU4,B0*+70B+1>S'0Q0#````Z13___^0A,FX_____P^(
M!O___P^VP8M]#(D'BU4(C4,!B7(4Z?#^__^$R;C_____#XCC_O__@/E<#X2V
M````@/E^#X2[````#[;YBU4,B3J+10C'0!0!````C4,!Z;?^__^-0P(Y^(E%
M\`^/G/[__X3)#XC6_O__BEH!A-L/B,O^__^-4=^`^@=V"XU!T#Q$#X>X_O__
MC5/?@/I=#X>L_O__#[;YC0Q_P>$$*?D/MO.-A$[!\___/8$%``!W<CVQ`@``
M#X>%_O__9HN$`"`F&`AF@_C]#X1S_O__#[?`BU4,B0*+70B+1?#'0Q0"````
MZ23^__^+=0S'!J4```#I3?___XM-#,<!/B```.D_____/>\"``!W+CV1`@``
M#X<K_O__9HN$`)2A%PCIL?[__SU_'@``#X<3_O__9HN$`!SI%PCKC)`]@04`
M`'<9/0($```/A_;]__]FBX0`()T7".E\_O__D#TJ'```#X?=_?__9HN$`)QJ
M%PCI8_[__^C[W/[_C78`58GE5U93@^P,BUT0BT4(@_M_BW`HBWT,N/____]W
M"(A=\K@!````@_C_=$Q(#X6U`@``BDWRA,EX/H/^`1G;@^/]C5,$.544N/[_
M__]\'H7V=!#&!QO&1P$HQD<"0C'V@\<#B`^+30B)<2B)T(UE]%M>7\G#C78`
M@_M_=U^#^UQT6H/[?G15B%WRB?:Z`0```(/Z_W1^2@^%2P(``(I-\H3)>'`Q
MVX/^`0^5PXU46P$Y512X_O___WRS@_X!=!/&!QO&1P$HQD<"2KX!````@\<#
MB`^+?0B)=RCKCX'[I0````^$HP```('[/B```'08C8.?`/__@_@^NO____]W
MD8U30(A5\NN$QD7R?NE[____C78`:@)3C4WR4?]U".A)T/__@\00@_C_=&F#
M^`(/A;0!``"*5?*$TGA9@'WS`'A3,<"#_@(/E<"-3$`".4T4N/[___\/C!+_
M__^#_@)T$\8'&\9'`23&1P)"O@(```"#QP.(%XI5\XA7`8M]"(EW*(UE]%M>
MB<A?R</&1?)<Z?C^__^!^U\$```/AP,!``")VL'J!(T$E8!T%PB)1>R+3>R%
MR0^$X@```(M-[&:+40*)V8/A#P^WPM/XJ`$/A,D```"X`0```-/@2"'0B<,E
MJJH``-'X@>-550```<.)V('CS,P``,'[`B4S,P```=B)P27P<```P?@$@>$/
M#P```<$/MMEFP>D(`<N+5>P/MP(/M\L!R&:+G`"`,!<(B=IFP>H(B%7RB%WS
MN`(```"#^/]T>X/X`@^%FP```(I5\H32>&N`??,`>&4QVX/^`P^5PXT,G0(`
M```Y312X_O___P^,]OW__X/^`P^$\_[__\8'&\9'`23&1P(HQD<#1+X#````
M@\<$Z=?^__^X_____^N<C8L`W___@_DO=QN)V,'H!(T$A2QL%PCI[?[__[C_
M____Z:3]__^-DP"R__^!^J]1``!W%HG9P>D$C02-@$P7".G$_O__Z`O:_O^-
M@P`!__^#^%]WI(G:P>H$C025)B`7".FC_O__C78`58GEBT4(BT`H,=*%P(M-
M#'0>@WT0`KK^____?A/&`1O&00$HQD$"0KH#````C78`B=#)PU6)Y5=64X/L
M'(M="(M#%`^VR(G'BU40BW44B4WPP>\(,=N)]HH*@/D;#X7T````C4L#.?%_
M.(I"`3PH=$\\)'1G/"X/A0D$``"*0@(\0;\!````=`T\1@^%ZP,``+\"````
M@\(#C4$!.?")RWZVP><("WWPBTT(OO[___^)>10IWH/$'%N)\%Y?R<.0BD("
M/$)T73Q*=&4\20^%J0,``,=%\`(```#KNHI"`CQ`=#4\0G0Q/$%T8#PH#X6)
M`P``C4L$.?%_J(I"`SQ$=#L\0P^%<P,``(/"!,=%\`8```#KA(UV`,=%\`,`
M``#I<O___\=%\`````#I9O___\=%\`$```#I6O___X/"!,=%\`0```#I3O__
M_\=%\`4```#I/____X-]\`8/AWL$``"+1?#_)(4HF1@(C4,".?")1>`/CRG_
M__^$R0^(^P(``(I:`83;#XCP`@``C5'?@/H+=A.-0=`\&'8,C5&V@/HS#X?5
M`@``C4/?/%T/A\H"```/MM&--%+!Y@0IU@^VRXV$<<'S__\]@04```^'Z@,`
M`#U:!```#X>?`@``9HN$`"!V%@AF@_C]#X2-`@``P><(#[?`BTT,"WWPBUT(
MBW7@B0&)>Q3IJO[__XU#`CGPB47D#X^)_O__A,D/B%L"``"*6@&$VP^(4`(`
M`(U1WX#Z"'8+C4'0/$</AST"``"-4]^`^ET/AS$"```/ML&-#$#!X00IP0^V
M\XV$3L'S__\]@04```^'#P,``#T^`P``#X<&`@``9HN$```J%PAF@_C]#X3T
M`0``#[?PBU4,P><(B3(+??"+70B+=>2)>Q3I$?[__XU#`CGPB47H#X_P_?__
MA,D/B,(!``"*6@&$VP^(MP$``(#Y(G0;C5':@/H!=A.-0=<\`G8,C5'0@/H]
M#X>7`0``C4/?/%T/AXP!```/MM&--%+!Y@0IU@^VRXV$<<'S__\]U0$```^'
MT0(``#VN````#X=A`0``9HN$``2F%PAF@_C]#X1/`0``P><(#[?`BTT,"WWP
MBUT(BW7HB0&)>Q3I;/W__X3)OO____\/B%_]__\/ML&+30R)`8/X"@^$M0$`
M`(/X#0^$K`$``,'G"`M]\(M5"(US`8EZ%.DQ_?__A,F^_____P^()/W__XC*
M@.J`#XB[`0``@/I<#X2D`0``@/I^#X3F`0``#[;"BU4,B0+KN(U#`CGPB47L
M#X_<_/__A,D/B*X```"*6@&$VP^(HP```(U1WX#Z!W8+C4'0/$0/AY````"-
M4]^`^ET/AX0````/ML&-#$#!X00IP0^V\XV$3L'S__\]@04```^'B@$``#VQ
M`@``=UUFBX0`("88"&:#^/UT3P^W\(M5#,'G"(DR"WWPBUT(BW7LB7L4Z6S\
M__^$R;[_____#XA?_/__@/E<#X37````@/E^#X2[````#[;!BTT,B0&+50R+
M`NGD_O__B?:^_____^DO_/__/$Z^_____P^%(OS__X/_`71@<N*#_P(/A3D!
M``"*0@*$P+[_____#X@"_/__@\"`/)]W'P^VP(MU#(D&@4WP``(``(M=\(M5
M"(G.B5H4Z=S[__\/MM!FBX02X(T8"&:#^/V^_____P^$POO__P^WP.O%BD("
MA,"^_____P^(K?O__X/`@`^V\(M]#(%-\``!``")-^NM,?_I3?[__XMU#,<&
M/B```(M5#(L"Z2C^__^+50S'`J4```"+50R+`ND5_O__BW4,QP:E````Z1G^
M__^-0=\\/K[_____#X=.^___#[;*@<'`_@``BW4,B0[I]OW__SWQ'P``#X?W
M_O__9HN$`!SJ%@CI[/S__XGVBTT,QP$^(```Z<[]__\]?QX```^'S_[__V:+
MA``<Z1<(Z6W^__^)]CT-#P``=UP]KPX```^'KO[__V:+A`"\6!8(Z0K\__^0
MZ`O4_O\][P(``'<8/9$"```/AXG^__]FBX0`E*$7".DC_?__/8$%``!W,#T"
M!```#X=J_O__9HN$`""=%PCI!/W__STE(@``#X=2_O__9HN$`&0?%@CIKOO_
M_STJ'```#X<Z_O__9HN$`)QJ%PCIU/S__Y!5B>575E.#[!R+70B+0RB+=1`/
MML@/MM2)PXGPP>@'P>L0/0`<``")3>R)5>@/A+4```"#^P,/AX````"#_G^X
M_____W<*B?"(1?*X`0```(/X_W1O2`^%&`$``(I5\H32>&&#?>P!&<"#X/V#
MP`0Y112Y_O___WPWBWWLA?\/A;@```"+30R#_@J($0^$U@```(/^#0^$S0``
M`,'C$,%EZ`@+7>@+7>R+=0B)7BB)P8UE]%M>B<A?R<.)]C';Z7G___^0BQ2=
M1)D8"(E5Y(GVBT7D@^`'@_@%#X>5````_R2%5)D8"(GVB?*#XG^-0K\\&0^&
M_`0```^^PH/X:@^$T@4```^/8`4``(/X80^$O@8```^.)P8``(/X:`^%O@4`
M`(/[!P^%M04``,%EZ`B!3>@```,`Z5`%``"0BTT,Q@$;QD$!*,9!`D*#P0.)
M30R+30R#_@K'1>P`````B!$/A2W___^-=@#'1>@`````Z2?____H(]+^_XUV
M`(/^?XU5\@^'K`0``(/^7`^$HP0``(/^?@^$F@0``(GPB$7RD+D!````@_G_
M#X2.````277#BE7RA-(/B8`````QP(-][`(/E<"-=$`!.744N?[___\/C-G^
M__^#?>P"=!N+?0S&!QO&1P$HQD<"28/'`XE]#,=%[`(```"-2H"+50R("NG/
M`0``C78`:@)6C7WR5_]U".CUW/__@\00@_C_=!V#^`(/A4S___^*5?*$TG@-
M@'WS``^)4P<``(UV`,%MY`,/A8K^__^Y_____^E@_O__@_Y_#X>C`P``@_Y<
M#X2:`P``@_Y^B?`/A(\#``"(1?*Z`0```(/Z_W022@^%\_[__XI5\H32#XDQ
M!@``:@)6C57R4O]U".AUQ?__@\00@_C_=!J#^`(/A<C^__^*5?*$TG@*@'WS
M``^)B@8``('^7P0```^'GP0``(GQP>D$C3R-@'07"(7_#X1W!```9HM7`HGQ
M@^$/#[?"T_BH`0^$800``+@!````T^!((=")PB6JJ@``T?B!XE55```!PHG0
M@>+,S```P?H")3,S```!T(G!)?!P``#!^`2!X0\/```!P0^VT6;!Z0@!R@^W
M!P^W^@'X9HN,`(`P%PB)RF;!Z@B(5?*(3?.X`@```(/X_P^$U_[__X/X`@^%
M!O[__XI5\H32#XC#_O__@'WS``^(N?[__S')@WWL!`^5P8TTC0(````Y=12Y
M_O___P^,#_W__X-][`1T'XM]#,8'&\9'`23&1P(HQD<#1(/'!(E]#,=%[`0`
M``"+?0R(%XI-\XM5#(A*`<'C$,%EZ`@+7>@+7>R+10B)\8E8*.G"_/__B?:!
M_O\```"X_____W<*B?"(1?*X`0```(/X_W022`^%8?W__XI5\H32#XCD!```
M@?Z?````B?!V+(V68/___X/Z'P^&V`(``(V&@/S__X/X3P^'XP,``(J&((L8
M"(3`#X3&`@``B$7RN`$```"#^/\/A-?]__](#X4(_?__BE7RA-(/B<7]__\Q
MP(-]Z`(/E<"-=$`#.744N?[___\/C![\__^#?>@"=!N+?0S&!QO&1P$NQD<"
M1H/'`XE]#,=%Z`(```"+10S&`!O&0`%.C4J`BU4,B$H"Z0G___^0@?Y?!```
M#X?.`0``B?+!Z@2-/)4`]!8(A?\/A'("``!FBU<"B?&#X0\/M\+3^*@!#X1<
M`@``N`$```#3X$@AT(G"):JJ``#1^('B554```'"B="!XLS,``#!^@(E,S,`
M``'0B<$E\'```,'X!('A#P\```'!#[;19L'I"`'*#[<'#[?Z`?AFBY0``*,6
M"(G19L'I"(A-\HA5\[@"````@_C_#X3(_/__@_@"#X7W^___BE7RA-(/B+3\
M__^`??,`#XBJ_/__,<F#?>P%#Y7!C71)`CEU%+G^____#XP#^___@WWL!70;
MBWT,Q@<;QD<!),9'`D&#QP.)?0S'1>P%````BTT,B!&*1?.(00'!XQ#!9>@(
M"UWH"UWLBU4(B?&)6BCIO?K__Y"#PB#I_/K__X'^I0````^$IP$``('^/B``
M``^$U@$``(V^GP#__X/_/KK_____#X=-_/__C49`B$7RZ3W\__^0@?ZE````
M#X1G`0``@?X^(```#X2G`0``C;Z?`/__@_\^N?____\/AT7[__^-3D"("NDV
M^___@_AO#X1%`0``#XZK````@_AZ#X0``@``@_A_=5G!9>@(BU7L"57HBWWH
MBW4(B7XH,<F-9?1;7HG(7\G#C88`X/__/4\&``!V2XV^`-#__X'_+P(```^'
M1@$``(GRP>H$C3R5P.46".D._O__@_L$#X0<`0``D(/[`W8",=O!XQ#!9>@(
M"UWHBTT("UWLB5DH,<GKGHGQP>D$C3R-8.H6".G5_?__BH9@CA@(Z3+]__^X
M_____^DX_?__@_AK=;>#^P1ULL%EZ`B!3>@```8`Z4W___^)]DAUG<%EZ`B!
M3>@```0`Z3C___^0N/_____I_OO__[C_____Z0/^__^-E@#?__^#^B]W$8GP
MP>@$C3R%+&P7".E1^___C;X`LO__@?^O40``#X>M````B?'!Z02-/(V`3!<(
MZ2[[___&`ESI\?G__\9%\ESIN/K__X/[!@^%'____\%EZ`B!3>@```(`Z;K^
M__^#^P4/A0;____!9>@(@4WH```!`.FA_O__QD7R?NE]^O__Q@)^Z:7Y___!
M9>@(@4WH```%`.F`_O__C88`LO__/>].``!W2XGQP>D$C3R-@,H6".F[_/__
MC8[PW___@_D/#X?B_O__BH9P;A@(Z0G\__^-E@`!__^#^E\/AP+___^)\,'H
M!(T\A28@%PCI<OK__XV^`&+__X'_KP$``'<JB?+!Z@2-/)4`MA8(Z6+\__^#
M^P0/A57^___!9>@(@4WH```'`.GP_?__C88``?__/>\````/A[+^__^)\<'I
M!(T\C8"=%@CI)_S__S')@WWL`0^5P8U$20$Y112Y_O___P^,V/?__X-][`$/
MA*+W__^+?0S&!QO&1P$HQD<"2H/'`XE]#,=%[`$```#I@O?__S')@WWH`0^5
MP8UT20,Y=12Y_O___P^,D_?__X-]Z`$/A(S[__^+?0S&!QO&1P$NQD<"08/'
M`XE]#,=%Z`$```#I;/O__S'`@WWL`P^5P(UT0`(Y=12Y_O___P^,3O?__X-]
M[`,/A&+\__^+?0S&!QO&1P$DQD<"0H/'`XE]#,=%[`,```#I0OS__S')@WWL
M!@^5P8TTC0(````Y=12Y_O___P^,!O?__X-][`8/A!+Z__^+10S&`!O&0`$D
MQD`"*,9``T.#P`2)10S'1>P&````Z>[Y__]5B>6+10@QTH!X*`"+30QT&X-]
M$`*Z_O___WX0Q@$;QD$!*,9!`D*Z`P```(G0R<-5B>575E-6BTT0BA&$THM=
M#'@1#[;"B0.X`0```%M;7E_)PY"`^J`/AH,```"`^O]T?H-]%`&X_O___W[@
MBDD!@/F@=FN`^?]T9HUR@(GPC7F`B$7RB?B(1?.-0E\\"'=:C5%?@/I==V6)
M\@^VPHT40,'B!(GY*<(/MO&-A%;!\___/8$%``!W43T^`P``=SYFBX0``"H7
M"&:#^/UT,+H"````#[?XB=").^EN____D%M;7KC_____7\G#C4)0/$>Z____
M_W::B=#I3____[K_____B=#I0____SWQ'P``=^UFBX0`'.H6".NMD%6)Y5=6
M4U"+51"#^G^+?0QW#H@7N`$```!?6UY?R<.0@?I?!```#X>X````B=#!Z`2-
M'(4`]!8(A=L/A-0```!FBW,"B=&#X0\/M\;3^*@!#X2^````N`$```#3X$@A
M\(G"):JJ``#1^('B554```'"B="!XLS,``#!^@(E,S,```'0B<$E\'```,'X
M!('A#P\```'!#[;Q9L'I"`'.#[?6#[<+`=%FBY0)`*,6"(G39L'K"(-]%`&(
M7?*(5?.X_O___P^.4/___XI-\HU:@(/!@(@/B%\!7UM>N`(```!?R<.)]HV*
M`.#__X'Y3P8``'8NC9H`T/__@?LO`@``=S&)T,'H!(T<A<#E%@CI)____XUV
M`%];7KC_____7\G#D(G6P>X$C1RU8.H6".D'____C8H`LO__@?GO3@``=A^-
MF@!B__^!^Z\!``!W(HG0P>@$C1R%`+86".G:_O__B=;![@2-'+6`RA8(Z<G^
M__^-B@`!__^!^>\```!WEXG6P>X$C1RU@)T6".FJ_O__B?95B>564XM-$(H!
MA,"+=0B+70R+511X$0^VP(D#N`$```!;7LG#C78`/(!V(O[`=!Y*N/[___]^
MZ<=%#`(```")30B)VEN)\%[)Z4+'__];N/____]>R<.058GE4U"+51"#^G^+
M70RX_____W<'B!.X`0```(/X_W0'BUW\R<.)]H/L"&H"4HM%"(U5^NCOR?__
MB<*#Q!"#^O^X_____W39@_H"=2"#?10!N/[___]^R8I5^H@3BD7[B$,!BUW\
MN`(```#)P^A.QO[_B?95B>575E.#[!"+71"*`X3`BW4,BWT4>!0/ML")!KD!
M````C67T6UZ)R%_)PU=3B?*+10CHC,;__X/X_UI9B<%UX8H3@/JB#X0$`0``
MC4I8@/D!#X;X````@/K^N/____\/A.H```"#^/^)P76UBA.-0G\\`P^'5`$`
M`(/_`;'^#XY)`0``BD,!B$7S@^@P/`FQ_P^'-@$``(/_`K'^#XXK`0``BD,"
M/("(1?(/AA@!``#^P`^$$`$``(/_`P^.#`$``(I+`XU!T#P)#X?Y````#[;"
MC02`#[95\XT$0HG"P>(&*<(/MD7RC110C122#[;!C8Q03D'F_X'Y^YD```^'
MQ0```,=%[`````#'1>C!````ZP^)5>B+5>@Y5>P/@[X!``"+5>P#5>C1Z@^W
M!)4BN!4(.<ASW0^W!)4DN!4(.<@/AX(```!"B57LZ\J-=@"#_P&X_O___P^.
M"/___XI+`8U!P#P^=A.$R7@*N/_____I\/[__X#Y_W3Q#[;2C032C01"C02`
MA,F-%``/ML$/B$0!``"#Z$"-!`*-B$*@__^!^?$<```/A],```"!^2`9``"Z
MK"```'6R#[?*N`(```")#NF=_O__N?____^#^?\/A4O^__^*`XA%YX/`<#Q3
M#X<[_O__@_\!L?X/CC#^__^*4P&-0M`\";'_#X<@_O__@_\"L?X/CA7^__^*
M0P(\@(A%YG9*_L!T1H/_`P^._OW__XI+`XU9T(#["7<R#[9%YP^V^HT<@(T$
M7XG'P><&*<</ME7FC1QZC12;#[;!C110C;H&7^/_@?___P\`=@JY_____^FW
M_?__C8H&7^3_B0ZY!````.FE_?__C78`@?G%7```=SN!^7`=``"Z^0$```^$
M(?___RVV?0``@_@,#X?%_O__9HN4"0Y\%0AF@_K]#X4!____N/_____IH_W_
M_X'Y)%T```^'G?[__V:+E`FT_10(Z]:#Z$'IM_[__XM5[`^WA!(@0A4(C00!
MN00```")!NG3_O__D%6)Y5=64X/L+(M=$(/[?XMU#(M]%+C_____=P>('K@!
M````@_C_=`B-9?1;7E_)PX/L"%=3B?*+10CH><;__X/$$(/X_W7A@_\!L/Y^
M2H'[^0$``+J_J/__="V!^ZP@``"ZXZ+__W0@C8.`T?__@_A/#X>;`0``9HN4
M&X#D%`AFA=(/A+,!``")T&;!Z`B(!HA6`;@"````@_C_=8N#_P.Z_O___P^.
MT@```(U+@('Y?_\``++_#X?!````,<G'1>S!````ZPB)5>P[3>QS*8M%[(T4
M`='J#[<$E<)#%0@YV'/D#[<,E<1#%0@YV0^'I`$``(U*`>O2#[>4"2!"%0B)
MV2G1B4W<B<@QTKD*````]_&#PC"(5@.XS<S,S/=EW,'J`XE5W(G0L7XQTO?Q
MB57,BE7,@^I_B%8"BT7<T>BZ@R`(@O?BB='!Z06)3=")R#'2N0H```#W\8/"
M,(A6`;C-S,S,]V70B574BU74P>H#@^I_B470B!:Z!````(/Z_XG0#X6@_O__
M@_\#L/X/CI7^__^-NP``__^!____#P"P_P^'@?[__[C-S,S,]^>)5=2+3=3!
MZ0.)1="-!(G1X"G'C5<PNWX```")R(A6`S'2]_.#ZG_1Z;B#(`B"B%8"]^&)
MU\'O!;L*````B?@QTO?S@\(PN,W,S,R(5@'WYXG0P>@#@^APB`:X!````.D6
M_O__C9,0T/__@_H/=RAFBY0;@.$4".E5_O__@?NN30``NI_^__\/A$W^__^X
M_____^E3_O__@?L^,```NHFI__\/A#+^__^-B\#+__^#^3=W#6:+E!M@V!0(
MZ1'^__^!^YXU``"Z6O[__P^$"?[__XV#^,G__X/X%W<79HN4&Y#4%`CIZ/W_
M_[K_____Z=S^__^!^Q@Y``"Z8/[__P^$UOW__X'[;CD``+)?#X3(_?__C9,X
MQO__@_H7=PUFBY0;T,P4".FG_?__@?MS.@``NF3^__\/A)_]__^!^TX[``"R
M:`^$D?W__X'[;CP``+)I#X2#_?__@?O@/```LFH/A'7]__^!^U9```"R;P^$
M9_W__X'[7T$``+)P#X19_?__@?LW0P``LG(/A$O]__^-BUB\__^#^3=W#6:+
ME!N0N!0(Z2K]__^!^]9$``"Z>_[__P^$(OW__XV#N+G__X/X'W<-9HN4&Q"S
M%`CI`?W__XV3X+C__X/Z#W<-9HN4&T"Q%`CIZ?S__XV+B+C__X/Y%W<-9HN4
M&U"P%`CIT?S__XV#P+;__X/X=W<-9HN4&\"K%`CIN?S__XV3D+/__X/Z-W<-
M9HN4&^"D%`CIH?S__XV+\++__X/Y#P^'/?[__V:+E!N`HQ0(Z87\__^)]E6)
MY5=64X/L'(MU"(M&%`^VV`^VU(G&B5WPBTT0BWT4B57LP>X0,=N*$8#Z&W1!
M@/H.='"`^@\/A9T```#'1?``````04.-4P$Y^G[;P>80P67L"`MU[`MU\(M]
M"+C^____B7<4*=B#Q!Q;7E_)PY"-0P0Y^(E%Y'_3BD$!/"0/A5D!``"*00(\
M*70J/"IU0X!Y`TAU/;X!````@\$$BUWDZZ.0BT7L2(/X`7<FQT7P`0```.N.
MBD$#/$%T#3Q'=1+'1>P"````Z]''1>P!````Z\BX_____^N-BT7PA<`/A*,!
M``"#??`!#X61`@``C4,".?B)1>@/CU#___^$TGC2BED!A-MXRX-][`$/A+@!
M``!ROX-][`(/A6("``"-2M^`^09V$8#Z0G0,C4*\/#FY_____W=UC4O?@/E=
M=V@/ML*-%$#!X@0IP@^V^XV$5\'S__\]'0P```^'T0$``#WS`0``=QUFBY0`
MH$T1"&:#^OUT,P^WPHM=#+D"````B0/K*3T[`@``NJ!.``!TY3U"`@``NJM1
M``!TV3U'`@``NOE2``!TS;G_____@_G_N/____\/A*W^__^#^0(/A;T!``#!
MYA#!9>P("W7L@\X!BTT(BT7HB7$4Z8G^__\\3@^%[?[__X7VN/____\/A'3^
M__].#X6&`0``BE$"A-(/B,[^__^`>0,`#XC$_O__C5K?@\$"@/M1#X>U_O__
MBDD!C4'?/%T/AZ?^__\/MO*-%';!X@0I\@^V^8V$5\'S__\]X1T```^'A_[_
M_V:+A`"@41$(9H/X_0^$=?[__\%E[`@/M]"!3>P```$`BT7P"47LBWT,BUWL
MBTT(BT7DB1>)613IW_W__X32N/____\/B-+]__\/ML*+30R#^`J)`70=@_@-
M=!C!YA#!9>P("W7LBWT(C4,!B7<4Z:C]__\Q]L=%[`````#KW8U*WX#Y"'80
MC4+0/$>Y_____P^'RO[__XU+WX#Y70^'N?[__P^VPHT40,'B!"G"#[;[C817
MP?/__SV!!0``=T8]/@,```^'DO[__V:+A```*A<(9H/X_0^$@/[__P^WP.E(
M_O__D#W9#```=S$]/@P```^'9?[__V:+E``$-1$(Z1_^__^0/?$?```/ATS^
M__]FBX0`'.H6".NXC78`/?(A```/AS3^__]FBY0`3`D1".GN_?__Z,^[_O^-
M=@!5B>575E.#["R+70B+0RB)PP^VR`^VU,'K$(-]$'^+?0R)3=2)5="X____
M_W<+BD40B$78N`$```"#^/]T=D@/A;8#``"*5=B$TGAH@WW4`1GVC4X".4T4
MN/[___]\*HM%U(7`=2Z(%X-]$`IT.H-]$`UT-,'C$,%ET`@+7=`+7=2+?0B)
M7RB)R(UE]%M>7\G#C78`Q@</1\=%U`````"(%X-]$`IUQY`QV\=%T`````#K
MP9"!?1!?!```#X?7````BU40P>H$C325`/06"(7V=!=FBU8"BTT0@^$/#[?"
MT_BH`0^%ZP```+C_____@_C_#X1A`0``@_@"#X7[`@``BDW8A,D/B$T!``"*
M5=F$THA5SP^(/P$``#'`@WW0`0^5P,'@`H-]U`&)P@^$8P$``(/"`SE5%+C^
M____#XQ'____@WW0`709Q@<;QD<!),9'`BG&1P-!@\<$QT70`0```(-]U`%T
M"\8'#D?'1=0!````B`^*1<^(1P'!9=`(P>,0"UW0"UW4BWT(B5\HC67T6UZ)
MT%_)PY"+31"!Z0`@``"!^4\&```/AI<```"+=1"![@`P``"!_B\"```/ATX!
M``"+51#!Z@2--)7`Y18(Z?K^__^X`0```-/@2"'0B<(EJJH``-'X@>)550``
M`<*)T('BS,P``,'Z`B4S,P```=")P27P<```P?@$@>$/#P```<$/MM%FP>D(
M`<H/MP8/M_(!\&:+E```HQ8(B=%FP>D(N`(```"(3=B(5=GIK/[__XGVBT40
MP>@$C32%8.H6".EX_O__B?9J`_]U$(U5V(M%".C`P/__@_C_6EET&(/X`P^%
M@P$``(I%V#P!=!T\`@^$Q0```(UE]%M>N/____]?R<.-4`+IF/[__XI-V83)
M>.2*1=J$P(A%SGC:,<"#?=`"#Y7`P>`"@WW4`8G"#X0[`0``@\(#.544N/[_
M__\/C+/]__^#?=`"=!G&!QO&1P$DQD<"*<9'`T>#QP3'1=`"````@WW4`70+
MQ@<.1\=%U`$```"(#XI%SNEG_O__BTT0@>D`3@``@?GO3@``#X:=````BW40
M@>X`G@``@?ZO`0``#X>:````BU40P>H$C325`+86".F"_?__BE79A-(/B##_
M__^*3=J$R0^()?___S'`@_L!#Y7`C32%!````#EU%+C^____#XP*_?__@_L!
M=!?&!QO&1P$DQD<"*L9'`TB[`0```(/'!,8'&\9'`4Z(5P*(3P/!XQ#!9=`(
M"UW0"UW4BTT(B?")62CIQ_S__XM%$,'H!(TTA8#*%@CI^OS__XM-$('I`/\`
M`('Y[P````^'`/W__XM%$,'H!(TTA8"=%@CIT_S__^C,M_[_C5`"Z<#^__]5
MB>6+10@QTH!X*`!T%XM-$(7)NO[___]^"XM5#,8"#[H!````B=#)PXUV`%6)
MY5=64X/L'(M5"(M"%`^V\`^VW,'H$(EU\`^VT(G&B5WLBTT0BWT4B57HP>X(
M,=N-=@"*$8#Z&W1-@/H.#X2@````@/H/#X7Z````QT7P`````$%#C5,!.?I^
MU\'F&,%EZ!`+=>C!9>P("W7L"W7PBWT(N/[___^)=Q0IV(UE]%M>7\G#B?:-
M0P0Y^(E%X'_+BD$!/"0/A40!``"*00(\*715/"IT:3PK#X6-````BD$#/$F^
M`0```'1D/$J^`@```'1;/$N^`P```'12/$R^!````'1)/$UU8KX%````ZSZ)
M]HM%[$B#^`)W4,=%\`$```#I6____XI!`SQ!=#0\1W0G/$5U-<=%[`,```#K
M#X!Y`TAU)L=%Z`$```")]H/!!(M=X.DK____QT7L`@```.OLQT7L`0```.OC
MN/_____I-____XM%\(7`#X0.`P``@WWP`0^%$`4``(U#`CGXB47D#X_S_O__
MA-)XSXI9`83;>,B#?>P!#X3%`P``<KR#?>P"#X1.!```@WWL`P^%UP0``&H"
M4?]U#/]U".@ILO__B<*#Q!"#^O^X_____P^$R/[__X/Z`@^%K00``,'F&,%E
MZ!`+=>C!9>P("W7L@\X!BTT(BT7DB7$4Z9W^__\\3@^$QP(``#Q/#X5,____
M@_X%#X=R!```_R2U;)D8"(I1`H32#X@Q____@'D#``^()____XU:WX/!`H#[
M10^'&/___XI)`8U!WSQ=#X<*____#[;:C11;P>($*=H/MOF-A%?!\___/8H9
M```/A^K^__]FBX0`8$84"`^VS`^VP`L$C4!#%`@]_?\```^$RO[__XM]#,'F
M&,%EZ!")!PMUZ,%E[`@+=>P+=?"+50B+1>")<A3IY/W__XGVBE$"A-(/B);^
M__^`>0,`#XB,_O__C5K?@\$"@/M##X=]_O__BDD!C4'?/%T/AV_^__\/MMJ-
M%%O!X@0IV@^V^8V$5\'S__\]\Q@```^'3_[__V:+A`!`$10(#[;,#[;`"P2-
M``X4".E@____BE$"A-(/B"K^__^`>0,`#X@@_O__C5K?@\$"@/M;#X<1_O__
MBDD!C4'?/%T/AP/^__\/MMJ-%%O!X@0IV@^V^8V$5\'S__\]FB$```^'X_W_
M_V:+A`#`RA,(#[;,#[;`"P2-(,<3".GT_O__BE$"A-(/B+[]__^`>0,`#XBT
M_?__C5K?@\$"@/M-#X>E_?__BDD!C4'?/%T/AY?]__\/MMJ-%%O!X@0IV@^V
M^8V$5\'S__\]80L```^'@0(``&:+A`!`L!,(#[;,#[;`"P2-X*P3".F(_O__
MBE$"A-(/B%+]__^`>0,`#XA(_?__C5K?@\$"@/M!=@N-0IP\`P^',OW__XI)
M`8U9WX#[70^'(_W__P^VPHT40,'B!"G"#[;YC817P?/__SV9&```#X<W`@``
M/0,8```/A_C\__]FBX0`X/(0"`^VS`^VP`L$C<#P$`CI"?[__Y"$TKC_____
M#X@1_/__#[;"BTT,@_@*B0%T)(/X#70?P>88P67H$`MUZ,%E[`@+=>R+?0B-
M0P&)=Q3IX/O__S'VQT7L`````,=%Z`````#KSXM]Z(7_N/____\/A+[[__^#
M?>@!#X6B`0``BE$"A-(/B&C\__^`>0,`#XA>_/__C5K?@\$"@/M1#X=/_/__
MBDD!C4'?/%T/AT'\__\/MMJ-%%O!X@0IV@^V^8V$5\'S__\]X1T```^'(?S_
M_V:+A`"@41$(9H/X_0^$#_S__\'F&`^WP(M-#('.```!`(D!Z3[]__^-2M^`
M^0AV#(U"T#Q'N?____]W2HU+WX#Y77=M#[;"C11`P>($*<(/MON-A%?!\___
M/8$%```/A[,````]/@,``'=&9HN$```J%PAF@_C]=#@/M\"+70R)`[D"````
MB<KI__O__ST[`@``NJ!.``!T=CU"`@``NJM1``!T:CU'`@``NOE2``!T7KG_
M____B<KIS_O__XU*WX#Y!G81@/I"=`R-0KP\.;G_____=["-2]^`^5UWTP^V
MPHT40,'B!"G"#[;[C817P?/__ST=#```=W,]\P$``'>,9HN4`*!-$0AF@_K]
M=*(/M\+I9?___SWQ'P``=Y-FBX0`'.H6".E(____/8$<```/A^OZ__]FBY0`
MW',3"`^V_@^VP@L$O<"&$PCI_/O__^@GL?[_/;T9```/A\'Z__]FBX0`++T0
M".G$_?__/=D,``!W%3T^#```#X<R____9HN4``0U$0CK@#WR(0``#X<=____
M9HN4`$P)$0CI:/___XUV`%6)Y5=64X/L+(MU"(M&*`^VV`^VS,'H$(G&#[;0
MP>X(@WT0?XM]#(E=T(E-S(E5R+C_____=PN*11"(1=BX`0```(/X_P^$A0``
M`$@/A3\'``"*5=B$TGAW@WW0`1G;C4L".4T4N/[___]\,8M%T(7`=36(%X-]
M$`IT08-]$`UT.\'F&,%ER!`+=<C!9<P("W7,"W70BWT(B7<HB<B-9?1;7E_)
MPXUV`,8'#T?'1=``````B!>#?1`*=<"0,?;'1<P`````QT7(`````.NSB?:!
M?1!?!```#X?7````BU40P>H$C1R5`/06"(7;=!=FBU,"BTT0@^$/#[?"T_BH
M`0^%ZP```+C_____@_C_#X1A`0``@_@"#X5U!@``BDW8A,D/B$T!``"*7=F$
MVP^(0@$``#'`@WW,`0^5P,'@`H-]T`&)P@^$Z@(``(/"`SE5%+C^____#XQ"
M____@WW,`709Q@<;QD<!),9'`BG&1P-!@\<$QT7,`0```(-]T`%T"\8'#D?'
M1=`!````B`^(7P'!9<@0P>88P67,"`MUR`MUS`MUT(M]"(EW*(UE]%M>B=!?
MR<.+31"!Z0`@``"!^4\&```/AI<```"+71"!ZP`P``"!^R\"```/AYH"``"+
M51#!Z@2-')7`Y18(Z?K^__^X`0```-/@2"'0B<(EJJH``-'X@>)550```<*)
MT('BS,P``,'Z`B4S,P```=")P27P<```P?@$@>$/#P```<$/MM%FP>D(`<H/
MM\(/MPL!P6:+G`D`HQ8(B=IFP>H(N`(```"(5=B(7=GIK/[__XGVBT40P>@$
MC1R%8.H6".EX_O__B?9J`_]U$(U5V(M%".BPM?__@_C_6ED/A+4```"#^`,/
MA?D$``"*1=@\`0^$<@,``#P"#X31`P``/`,/A#`$```\!`^$H@(``#P%#X3;
M!```/`8/A$X%```\!W5UBE79A-)X;HI-VH3)>&<QP(/^!0^5P(T<A00````Y
M712X_O___P^,H_W__X/^!707Q@<;QD<!),9'`BO&1P--O@4```"#QP3&!QO&
M1P%/B%<"B$\#P>88P67($`MUR,%ES`@+=<P+=="+30B)V(EQ*.E9_?__@7T0
M7P0```^'ZP```(M5$,'J!(T<E0#T%@B%VW079HM3`HM-$(/A#P^WPM/XJ`$/
MA3L!``"#?1!_C477#X=4`@``@WT0)`^$2@(``(-]$'X/A$`"``"*71"(7=>*
M5=>-2M^`^5T/AT4"``#&1=@JB%79N`(```"#^/\/A$<"``"#^`(/A<0#``"*
M3=B$R0^(,P(``(I=V83;#X@H`@``,<"#?<P##Y7`P>`"@WW0`8G"#X3@`@``
M@\(#.544N/[___\/C)'\__^#?<P##X1D_?__Q@<;QD<!),9'`BG&1P-%@\<$
MQT7,`P```.E&_?__C5`"Z1']__^+71"!ZP`@``"!^T\&```/AN@```"+31"!
MZ0`P``"!^2\"```/A]T"``"+51#!Z@2-')7`Y18(Z>;^__^+31"!Z0!.``"!
M^>].```/AKX```"+71"!ZP">``"!^Z\!```/A\@"``"+51#!Z@2-')4`MA8(
MZ3;\__^X`0```-/@2"'0B<(EJJH``-'X@>)550```<*)T('BS,P``,'Z`B4S
M,P```=")P27P<```P?@$@>$/#P```<$/MM%FP>D(`<H/MP,/M](!T&:+E```
MHQ8(B=%FP>D(9H/Y*(A-V(A5V0^%E/[__X#Z(`^&B_[__X#Z0`^'@O[__^E`
M_O__BT40P>@$C1R%8.H6".D3_O__BT40P>@$C1R%@,H6".F-^___BE79A-(/
MB-S]__^*3=J$R0^(T?W__S'`@_X"#Y7`C1R%!````#E=%+C^____#XP-^___
M@_X"=!?&!QO&1P$DQD<"*\9'`TJ^`@```(/'!,8'&\9'`4^(5P*(3P/!YAC!
M9<@0"W7(P67,"`MUS`MUT(M]"(G8B7<HZ</Z__^!?1"E````#X14`0``@7T0
M/B````^$H@$``&H"_W40C578BT4(Z#BE__]96^FP_?__N/_____IB/K__XI-
MV83)#X@D_?__BEW:A-L/B!G]__\QP(-]S`(/E<#!X`*#?=`!B<(/A"X"``"#
MP@,Y512X_O___P^,2?K__X-]S`(/A!S[___&!QO&1P$DQD<"*<9'`T>#QP3'
M1<P"````Z?[Z__^*5=F$T@^(O?S__XI-VH3)#XBR_/__,<"#?<@!#Y7`C1R%
M!````#E=%+C^____#XSM^?__@WW(`709Q@<;QD<!),9'`BK&1P-(@\<$QT7(
M`0```,8'&\9'`4[IV/[__XU0`ND;_?__BE79A-(/B%;\__^*3=J$R0^(2_S_
M_S'`@_X!#Y7`C1R%!````#E=%+C^____#XR'^?__@_X!#X3W^___Q@<;QD<!
M),9'`BO&1P-)O@$```"#QP3IV_O__\8`).E=_/__BUT0@>L`3@``@?OO3@``
M#X>>````BT40P>@$C1R%@,H6".GT^___BTT0@>D`_P``@?GO````#X>&^?__
MBT40P>@$C1R%@)T6".E9^?__Z$*I_O_&`'[I`OS__XI5V832#XB;^___BDW:
MA,D/B)#[__\QP(/^`P^5P(T<A00````Y712X_O___P^,S/C__X/^`P^$//O_
M_\8'&\9'`23&1P(KQD<#2[X#````@\<$Z2#[__^+31"!Z0">``"!^:\!``!W
M<HM5$,'J!(T<E0"V%@CI1?O__XI5V832#X@@^___BDW:A,D/B!7[__\QP(/^
M!`^5P(T<A00````Y712X_O___P^,4?C__X/^!`^$5_W__\8'&\9'`23&1P(K
MQD<#3+X$````@\<$Z3O]__^-4`+IS?W__XM=$('K`/\``('[[P````^'Z_K_
M_XM%$,'H!(T<A8"=%@CIOOK__U6)Y8M%"#'2@'@H`'07BTT0A<FZ_O___WX+
MBU4,Q@(/N@$```")T,G#C78`58GE5U9348M%"(M-$(M]%(MP%#';C78`BA&`
M^GYU6HU#`CG'<B:%]HI1`74S@/I^#X3*````@/I[=#&`^@IU,HU0`8/!`CG7
MB<-SS(M%"(EP%+C^____*=A:6UY?R<.0@/I]=0TQ]NO7C78`9KX!`.O.N/__
M___KX(7V=1</MOJ+=0R+30B-0P&)/L=!%`````#KQ8U#`CG'B47P<JZ-6M^`
M^PAV!XU"T#Q'=\6*20&-6=^`^UUWN@^VPHT40,'B!"G"#[;YC817P?/__SV!
M!0``=T0]/@,``'>79HN$```J%PAF@_C]=(D/M_B+70R+30B+1?").XEQ%.E:
M____D(M5#(MU",<"?@```,=&%`````#I0?___SWQ'P``#X=/____9HN$`!SJ
M%@CKMHUV`%6)Y5=64U:+51"+10B#^G^+>"AW-X32B%7R>#"#_P$9VX/C_HU+
M`SE-%+C^____?!6%_P^%.P$``(M%#(@0BU4(B7HHB<A;6UY?R<.!^E\$```/
MA_````")T<'I!(T<C0#T%@B%VP^$-`$``&:+<P*)T8/A#P^WQM/XJ`$/A!X!
M``"X`0```-/@2"'PB<(EJJH``-'X@>)550```<*)T('BS,P``,'Z`B4S,P``
M`=")P27P<```@>$/#P``P?@$`<$/MO%FP>D(`<X/M]8/MPL!T6:+E`D`HQ8(
MB=-FP>L(A-N(7?*(5?.(V0^(L````(32#XBH````@_\!&=N#XP*-4P(Y512X
M_O___P^,-?___X7_=12+=0S&!G[&1@%[@\8"B74,9K\!`(MU#(@.BD7SBUT,
MB$,!BTT(B7DH6UM>B=!?R<.-=@"-F@#@__^!^T\&``!V-HV"`-#__STO`@``
M=TB)T<'I!(T<C<#E%@CI\/[__XMU#,8&?L9&`7TQ_X/&`HEU#.FN_O__D(G6
MP>X$C1RU8.H6"(7;#X7,_O__6UM>N/____]?R<.-F@"R__^!^^].``!V'HV"
M`&+__SVO`0``=R*)T<'I!(T<C0"V%@CIC?[__XG6P>X$C1RU@,H6".E\_O__
MC9H``?__@?OO````=ZJ)UL'N!(T<M8"=%@CI7?[__Y!5B>6+10B+0"@QTH7`
MBTT,=!>#?1`!NO[___]^#,8!?L9!`7VZ`@```(G0R<.-=@!5B>575E.#[`R+
M31"*$832BW4,BUT4>!0/ML*)!K@!````@\0,6UY?R<.)]H#ZH`^&EP```(#Z
M_P^$C@```$NX_O___W[<BD$!/*`/AM<````\_P^$SP```(U8@(U"7XU*@#P&
MB$WRB%WS#X?%````C5/?@/I=#X=&!```#[;!C3Q`P><$*<</MLN-A'G!\___
M/1T,```/AS($```]\P$```^'ZP,``&:+E`"@31$(9H/Z_0^$"00```^WVKH"
M````B=")'NE8____B?:`^HYU5X/[`[C^____#XY#____BED!C5-?@/H/=SZ*
M00(\H(I1`W8T//]T,(#ZH'8K@/K_=":-2("-0H"(1?$/ML,MH````(/X#XA-
M\(U]\'<*_R2%A)D8"(UV`(/$#%M>N/____]?R<.`^4(/A#+___^-0CP\.;K_
M____#X8B____B=#IS?[__XU!WSQ,NO____]W5HI?`8U3WX#Z70^'&`,```^V
MP8T,0,'A!"G!#[;[C81/P?/__ST`'```#X?X`@``9HN4`(!]%`@/MMX/ML(+
M!)V`>10(/?W_```/A-@"``")!KH"````@_K_N/____\/A%W^__^#^@*X!```
M``^$3_[__^C,HO[_C4'?/$6Z_____W?3BE\!C5/?@/I=#X>5`@``#[;!C0Q`
MP>$$*<$/MON-A$_!\___/8H9```/AW4"``!FBY0`8$84"`^VW@^VP@L$G4!#
M%`CI>/___XU!WSQ#NO____\/AWK___^*7P&-4]^`^ET/ASP"```/ML&-#$#!
MX00IP0^V^XV$3\'S__\]\Q@```^''`(``&:+E`!`$10(#[;>#[;""P2=``X4
M".D?____C5G?@/M;NO____\/AR#___^*7P&-4]^`^ET/A^(!```/ML&-#$#!
MX00IP0^V^XV$3\'S__\]FB$```^'P@$``&:+E`#`RA,(#[;>#[;""P2=(,<3
M".G%_O__C4'?/$VZ_____P^'Q_[__XI?`8U3WX#Z70^'B0$```^VP8T\0,'G
M!"G'#[;+C81YP?/__SUA"P``#X<5`@``9HN4`$"P$P@/MMX/ML(+!)W@K!,(
MZ6S^__^-6=^`^T%V$(U!G#P#NO____\/AV;^__^*7P&-4]^`^ET/AR@!```/
MML&-/$#!YP0IQP^VRXV$><'S__\]F1@```^'W`$``#T#&```#X?]````9HN$
M`.#R$`@/MMP/ML`+!)W`\!`(Z0#^__^-6=^`^U&Z_____P^'`?[__XI?`8U3
MWX#Z70^'PP````^VP8T\0,'G!"G'#[;+C81YP?/__SWA'0``#X>C````9HN$
M`*!1$0AF@_C]#X21````#[?`Z;']__^-6=^`^P9V%8#Y0G00C4&\/#FZ____
M_P^'F_W__XI?`8U3WX#Z77=A#[;!C3Q`P><$*<</MLN-A'G!\___/1T,```/
MA[8````]\P$``'<69HN4`*!-$0AF@_K]="P/M\+I3/W__ST[`@``NJ!.``!T
M[#U"`@``NJM1``!TX#U'`@``NOE2``!TU+K_____Z27]__\].P(``+J@3@``
M#X07_/__/4("``"ZJU$```^$!_S__SU'`@``NOE2```/A/?[__^Z_____XG0
MZ53[__\]V0P``'<4/3X,``!WYF:+E``$-1$(Z<;[__\]\B$``'?29HN4`$P)
M$0CILOO__SW9#```=Q@]/@P```^'>?___V:+E``$-1$(Z3K___\]\B$```^'
M8?___V:+E`!,"1$(Z2+___\]@1P```^'2?___V:+A`#<<Q,(#[;,#[;`"P2-
MP(83".E,_/__C78`/;T9```/AR'___]FBX0`++T0".D?_O__58GE5E.#[!"+
M31"#^7^+70R+=12X_____W<'B`NX`0```(/X_W0)C67X6U[)PXGV:@-1C57H
MBT4(Z$ZF__^)PH/Z_UA9N/____]TVX/Z`W54BE7H@/H!="R#_@.X_O___W[$
MC4J@Q@..B$L!BD7I@\"`B$,"BDWJ@\&`N`0```"(2P/KHDZX_O___WZ:BE7I
M@\*`B!.*1>J#P("(0P&X`@```.N"Z(:>_O^)]E6)Y5=64XM-$(H1A-*+?0QX
M$@^VPHD'N`$```!;7E_)PXUV`(#ZH`^&E0```(#Z_P^$C````(-]%`&X_O__
M_W[;BDD!C7'`B?.`^SYV"H#YH'9O@/G_=&J-0E\\)G8,C4(W/#"[_____W=0
MB?.`^SYW6@^VTHTTDL'F`RG6#[;9@/F@C12RC4.>=P.-0\"-A`)#G?__/8<8
M``!W0SWH%P``=S-FBX0`0!H3"&:#^/UT)0^WR(D/NP(```")V%M>7\G#6UZX
M_____U_)PX#YH'8%@/G_=9R[_____XG8Z]X]:S8``'?P9HN$`%"M$@CKNU6)
MY5-3BU40@_I_BUT,N/____]W!X@3N`$```"#^/]T!XM=_,G#B?9J`E*+10B-
M5?KH>J;__XG"@_K_6%FX_____W3=@_H"=2"#?10!N/[___]^S8I5^H@3BD7[
MB$,!BUW\N`(```#)P^@FG?[_B?95B>575E.+=1"*#H3)BWT,>!(/ML&)![@!
M````6UY?R<.-=@"`^:!V<X#Y_W1N@WT4`;C^____?N.*7@&-4\"`^CYV9X#[
MH'==C78`@/GY=4N`/OEU1HI6`8U*P(#Y/G8*@/J@=C:`^O]T,8#ZH`^VP@^&
M.`$``(/H8HV0^#4``(/H=(/X*'<49HN$$H@9$PAF@_C]#X6=````B?:X____
M_UM>7\G#@/O_=*&`^:(/AI(```"`^<8/A+T```"`^<=TBHU17X#Z)G8+C4$W
M/#`/AW?___^-4\"`^CYV$H#[H`^&9O___X#[_P^$7?___P^VT8T$DL'@`RG0
M@/N@C12"#[;##X:>````@^ABC80"0YW__SV'&```=W@]Z!<```^')____V:+
MA`!`&A,(9H/X_0^$%?___P^WV(D?6UZX`@```%_)PP^VT8T$DL'@`RG0@/N@
MC12"#[;#=C&#Z&*-A`)#G?__9HN$`."#$PAF@_C]#X0\____Z[V`^Z`/AC__
M__^X_____^D4____@^A`Z\T]:S8```^'K_[__V:+A`!0K1((ZX:#Z$#I7?__
M_X/H0.G#_O__D%6)Y5=64X/L#(M=$(/[?XM]#+C_____=P>('[@!````@_C_
MB<)T#8UE]%M>B=!?R<.-=@")V,'H"(/X(@^$R@```'=`@_@"#X2U`@``#X9$
M`0``@_@@#X7H````@?LG(```#X1L`P``@?LB(```=`R!^SX@```/A<@```"Z
M_____^NDD(/X)@^$C@(```^&*0$``#W^````#X3*`@``/?\````/A9L```"!
M^P__```/A#X#``"!^SS_```/A%X#``"!^U[_```/A%\#``"!^^#_```/A(,#
M``"!^^'_```/A(0#``"!^^/_```/A(4#``"!^^7_```/A(8#``"Z_____X'[
M9/\``.LQB?:!^Q4B```/A!H"``"!^Y4B```/A+,```"!^YDB```/A"L"``"Z
M_____X'[/"(```^$YO[__XUV`&H"4XU5\HM%".@VH___@_C_7EH/A(L```"#
M^`(/A8@"``"*1?(\QG1T/,=T=X-]%`&Z_O___P^.I_[__X@'BEWSB%\!C67T
M6UZZ`@```(G07\G#A<!UJ8'[KP````^$`0(``(V#7O___X/X`KK_____=XWI
M:_[__X/X)76#@?MT)0``#X5W____QD7RH<9%\UKKC\9%\J'&1?/RZX6`??.@
M=HJ0C9,`V___@?J?````#X?*````B=G!Z02--(U@>A,(A?8/A*\```!FBU8"
MB=F#X0\/M\+3^*@!#X29````N`$```#3X$@AT(G"):JJ``#1^('B554```'"
MB=&!XLS,``#!^@*!X3,S```!T8G+@>'P<```P?D$@>,/#P```<L/ML-FP>L(
M`=@/MPX/M_`!\6:+G`G`@1,(B=IFP>H(B%7RB%WSN`(```"#^/^Z_____P^$
MBOW__X/X`@^%2`$``(-]%`&Z_O___P^.<OW__XI%\NG#_O__N/_____KRXVS
M`*C__X'^OP```'<1B=C!Z`2--(5@;1,(Z2/___^-DP"F__^!^O\```!W3HG9
MP>D$C32-H&P3".D$____@?O-`@``#X4V_O__QD7RH<9%\\7I2_[__X'["28`
M``^$5?W__X'[028``.E$_?__QD7RHL9%\T'I)_[__XVS`*#__X/^7W<_B=C!
MZ`2--(4$:Q,(Z:O^___&1?*AQD7S\^G^_?__@?M1_@``='&!^VC^```/A<C]
M___&1?*BQD7S0NG=_?__C9,`B/__@?J/````=QZ)V<'I!(TTC>!D$PCI7O[_
M_\9%\J'&1?/"Z;']__^-LP"$__^!_J\```!W/8G8P>@$C32%H&,3".DR_O__
MQD7RH<9%\T7IA?W__\9%\J'&1?-.Z7C]___H>9?^_\9%\J'&1?/^Z6;]__^-
MDP!X__^!^L\```!W*XG9P>D$C32-8&`3".GG_?__QD7RHL9%\T#I.OW__\9%
M\J'&1?/CZ2W]__^-LP!N__^!_K\````/AW+^__^)V,'H!(TTA:!=$PCIJOW_
M_\9%\J+&1?-&Z?W\___&1?*BQD7S1^GP_/__QD7RH<9%\\/IX_S__\9%\J+&
M1?-$Z=;\__]5B>575E-3BTT0BA&$THMU#(M]%'@2#[;"B0:X`0```%E;7E_)
MPXGV@/J@#X:G````@/K_#X2>````@_\!N/[___]^W(I9`8U#P#P^B$7S#X<Z
M`0``@/K&#X2#`0``@/K'='6-0E\\)G8'C4(W/#!W8X!]\SYV"H#[H'98@/O_
M=%,/MM*-!)+!X`,IT(#[H(T4@@^VPP^&;`$``(/H8HV$`D.=__\]AQ@```^'
M/P$``#WH%P``=QUFBX0`0!H3"&:#^/UT#P^WR+@"````B0[I3/___XH1B?:-
M6GB`^P-V)(U"<SP3=AV-6CJ`^P)V%8#Z^`^&C0```(#Z_P^$A````(UV`$^X
M_O___P^.$/___XI)`8U!P#P^=V$/MOJ-'+_!XP,I^X#YH(T4GP^VP0^&B@``
M`(/H8HV$`H"Q__\]^`<``'=A/5H'``!W.6:+E`#P<A,(B=!FP>@&@^(_#[?(
M"Q2-X&T3"('Z_?\``'06N`(```")%NFE_O__@/F@=@6`^?]UE;C_____Z9'^
M__^`^Z`/AD#___^`^_\/A;3^___I,O___SWM*@``=QD]/!0``'?19HN4`$Y%
M$PCKEH/H0.EQ____/31*``!W0CW$+```=[%FBY0`I/L2".ES____@/N@#X?N
M_O__Z73^__\]:S8```^'VO[__V:+A`!0K1((Z;C^__^#Z$#IC_[__SWB30``
M#X=K____9HN4`+:U$@CI+?___Y!5B>575E.#[`R+71"#^W^+?0R+=12X____
M_W<'B!^X`0```(/X_W0(C67T6UY?R<-J`E.-5?*+10CHDIW__X/X_UI9=#.#
M^`(/A7(!``"*5?*`^L9T'(#ZQW0=3KC^____?L6(%XI%\XA'`;@"````Z[:`
M??.@=N-.N/[___]^J('[SP(```^'GP```(G:P>H$C325H-T2"(7V#X2!````
M9HM6`HG9@^$/#[?"T_BH`71ON`$```#3X$@AT(G"):JJ``#1^('B554```'"
MB=&!XLS,``#!^@*!X3,S```!T8G+@>'P<```P?D$@>,/#P```<L/ML-FP>L(
M`=@/MPX/M_`!\6:+G`E@;Q((B=IFP>H(N`(```"(%XA?`>D'____N/_____I
M_?[__XV+`/S__X/Y7W<1B=C!Z`2--(5TW!((Z5'___^-LP#B__^!_L\```!W
M$8G:P>H$C325P-42".DR____C8L`W___@?GO````=Q&)V,'H!(TTA<#4$@CI
M$____XVS`-S__X'^?P$``'<1B=K!Z@2--)6@TQ((Z?3^__^-BP#9__^#^3]W
M%HG8P>@$C32%P-(2".G8_O__Z.^2_O^-LP#2__^!_O\"``!W$8G:P>H$C325
M0-`2".FT_O__C8L`SO__@_D_=Q&)V,'H!(TTA2S/$@CIF/[__XVS`,S__X'^
MKVL``'<1B=K!Z@2--)7`LQ((Z7G^__^-BP`@__^!^;\.``!W$8G8P>@$C32%
M`(42".E:_O__C;,`#?__@?[O!```=Q&)VL'J!(TTE0!_$@CI._[__XV+``'_
M_X'Y[P```'<1B=C!Z`2--(7`>Q((Z1S^__^-LP``_O^!_M\W``!W$8G:P>H$
MC325@"T2".G]_?__C8L`QOW_@?E/1```=Q&)V,'H!(TTA>`-$@CIWOW__XVS
M`(#]_X'^[P8``'<1B=K!Z@2--)6@^A$(Z;_]__^-BP!X_?^!^=\&``!W$8G8
MP>@$C32%X/81".F@_?__C;,`</W_@?[O`0``=Q&)VL'J!(TTE6#T$0CI@?W_
M_XV+`&S]_X'Y[P$``'<1B=C!Z`2--(7@\A$(Z6+]__^-LP!H_?^!_I\!``!W
M$8G:P>H$C3258/$1".E#_?__C8L`9?W_@?FO"```=Q&)V,'H!(TTA6#N$0CI
M)/W__XVS`%O]_X'^KP$``'<1B=K!Z@2--)5@ZQ$(Z07]__^-BP`(_?^!^=\!
M```/AWS]__^)V,'H!(TTA2#6$0CIXOS__XGV58GE5E-6BTT0BA&$THM=#'@2
M#[;"B0.X`0```%M;7LG#C78`@/J@=G^`^O]T>H-]%`&X_O___W[CBD$!/*!V
M:#S_=&2-<H")\8A-]HU(@(U"7SP+B$WW=UF-4=^`^EUW:(GR#[;"C11`P>($
M*<(/MO&-A%;!\___/8$%``!W4SU:!```=T-FBX0`('86"&:#^/UT-0^WR+H"
M````B0N)T%M;7LG#C78`6UNX_____U[)PXU"4#P8=J"-0C8\,[K_____=I2)
MT.O7NO____^)T.O./0T/``!W$3VO#@``=^EFBX0`O%@6".ND/24B``!WV&:+
MA`!D'Q8(ZY.058GE4U"+51"#^G^+70RX_____W<'B!.X`0```(/X_W0'BUW\
MR<.)]FH"4HU%^E#_=0CH.9O__XG"@\00@_K_N/____]TVX/Z`G4F@WT4`;C^
M____?LN*3?J#P8"("XI5^X/"@(A3`;@"````BUW\R</HBH_^_XGV58GE5E-1
MBTT0BA&$THMU#(M=%'@/#[;"B0:X`0```%I;7LG#C4)_/!\/AK$```"`^J`/
MAKD!``"`^O\/A+`!``!+N/[___]^UHI)`8#YH`^'"@$``(U"7SPEN_____]W
M=XU9OX#[&783C4&?/!EV#(U9?X#['P^'B`$```^VPHV07____X#Y@`^VP8U8
MLW<+@/E@C5BY=P.-6+^-#)4`````C001C02"C12#@?HU#```#X=-`0``@_LI
MB<AV`XU!`@^WB(#K$0@/MI)`WQ$(`=&)#KL"````B=A:6U[)PY!+N/[___\/
MCC/___^*20&-6;^`^QD/A]T````/MMH/ML&`^8"-DW____^-6+-W"X#Y8(U8
MN7<#C5B_C0R5`````(T$$8T$0HT$PHT40X'Z/Q8```^'N````(/[6(G(=@.-
M00(/MXC`WA$(#[:2@,@1"`'1B0Y:6[@"````7LG#@/G_#X2)````C4)?@\&`
MC5J`/`N(7?:(3?=V$XU"4#P8=@R-0C8\,[K_____=T.-4=^`^EUW90^VPXT4
M0,'B!"G"#[;9C813P?/__SV!!0``=UX]6@0``'="9HN$`"!V%@AF@_C]=#0/
MM\B)#KH"````B=!:6U[)PXU!GSP9#X88____@/F`=@F`^?\/A0K___]:6[C_
M____7LG#NO____^)T.O/N_____^)V.G*_O__/0T/``!W$3VO#@``=]UFBX0`
MO%@6".N9/24B``!WS&:+A`!D'Q8(ZXB-=@!5B>575E.#[`R+71"#^W^+?0R+
M=12X_____W<'B!^X`0```(/X_W0(C67T6UY?R<-J`E.-1?)0_W4(Z'V8__^#
MQ!"#^/]T*8/X`@^%J@$``$ZX_O___W[0BE7R@\*`B!>*1?.#P("(1P&X`@``
M`.NXC9,`5/__@?JC*P``N/____]WI8'[I,@```^'L````$ZP_GZ4@?JO'```
M#X=0`0``B=G!Z02--(T`````9HN6@H41"(G9@^$/#[?"T_BH`0^$*P$``+@!
M````T^!((=")PB6JJ@``T?B!XE55```!PHG3@>+,S```P?H"@>,S,P```=.)
MV8'C\'```,'[!('A#P\```'9#[;!9L'I"`'(9@.&@(41"(G"9L'J!P^W\`^W
MVF8/MH;@F1$(9@.$&R"P$0B)P6;!Z0B(#^DG____3KC^____#X[=_O__C;,`
M./__@?ZO#P``#X>3````B=G!Z02--(T`````9HN6@I(1"(G9@^$/#[?"T_BH
M`71RN`$```#3X$@AT(G"):JJ``#1^('B554```'"B=.!XLS,``#!^@*!XS,S
M```!TXG9@>/P<```P?L$@>$/#P```=D/ML%FP>D(`<AF`X:`DA$(B<)FP>H&
M#[?P#[?:9@^VAL"W$0AF`X0;`,01".E"____N/_____I+O[__^A-B_[_D%6)
MY5=64X/L#(M5$(H*A,F+?0R+711X((#Y7'03#[;!B0>X`0```(/$#%M>7\G#
MD,<'J2```.OJ@/G7#X?#````C4%\/$^^_____P^'J0```$MFOO[_#XZ>````
MBE(!C5J_@/L]=A*`^H`/AK`!``"`^O\/A*<!```/ML'!X`@/MM()T(G#P>L*
M@^,?B<+!Z@6#X!\/OHO`F1$(@^(?B47HA<D/OH"`F1$(#[ZRH)D1"(E%[`^(
M9@$``(7V#XA>`0``A<`/B%8!``"%R0^%A@$``(7V#X6:`0``BTWHBH%@F1$(
M//T/A#4!```/MMB!PS`Q``")'V:^`@")\(/$#%M>7\G#C4$G/`5V"XU!(#P9
M#X?;````2[C^____#XX%____BE(!C5K/@/M-=A*`^I`/AKL```"`^O\/A+(`
M``"`^=H/A*(```"`^=^-7`EI#X:F````@/J0C4+/=@.-0KT\70^VTP^&K0``
M`(/"(CQ=B%7RC5WR#X>4````@\`AC4K?@/D+B$,!=A.-0M`\&'8,C4*V/#.Y
M_____W=&BDL!C5G?@/M==UP/ML*-%$#!X@0IP@^V\8V$5L'S__\]@04``'=H
M/5H$``!W.6:+A``@=A8(9H/X_70K#[?(B0^Y`@```(G(Z3W^__^-0E\\,G<*
MN/_____I+/[__XU<"4[I4?___[G_____B<CI%_[__X/H/>EG____@\(AZ4[_
M__^^_____XGPZ=#^__\]#0\``'<1/:\.``!WRF:+A`"\6!8(ZX\])2(``'>Y
M9HN$`&0?%@CI>____X7V=4.+1>R%P'6]BH/@\0P(//UTLSS_Z7'^__^+=>R%
M]G6EBH+`\0P(//UTFSS_=)</ML`%,#$``+X"````B0>)\.E=_O__C1R)C029
M`?"-#,4`````*<&+5>R-A(J8J0``Z]55B>575E.#[!R+71"#^W]W%X/[7'02
MBT4,B!BX`0```(UE]%M>7\G#@?NI(```#X3@````C8O/SO__@_DR=U%FBY0;
M_H\,"(G19L'I"(A-[HA5[[@"````@_C_#X3#````@_@"#X5!`0``@WT4`;C^
M____?A.*7>Z+50R(&HI%[XA"`;@"````C67T6UY?R<.-BP!4__^!^:,K``"X
M_____W>UOAP```")R#'2]_;!Z0*X)4F2)(G6]^&)5>2_%0```(G0,=+W][F'
M81B&BT7DB=?WX2E5Y-%MY(E5W(E%V(M%Y`-%W,'H!(J(,?(,"(/)(`^^P0^^
MEQSR#`C!X`4)T,'@!68/OI8`\@P("<+I-/___Y"+50RX`0```,8"7.G\_O__
M:@)3C7WN5_]U".C-DO__@\00@_C_=#"#^`)U:X-]%`&X_O___P^..?___XI5
M[HU"WSP+BDWO=@B-6K:`^S-W!XU!WSQ==@JX_____^D3____@/I)=S8/ML(%
MD0$```^VT:@!C4K?=`.-2CW1Z(C*BW4,@/E-B`:-0C%V`XU"0XM5#.G5_O__
MZ."&_O\/ML(%=@$``.O(B?95B>575E.#[`R+50B+0A2)PXM-$`^V^,'K"#'V
MBA&`^AMT,8#Z#G14@/H/=6(Q_T%&C48!.T44?N/!XP@)^XM5"+C^____B5H4
M*?"#Q`Q;7E_)PY"-1@0[111_W8!Y`21U)H!Y`BEU((!Y`T-U&KL!````@\$$
MB<;KMXGV@_L!=0>_`0```.NGN/_____KO(7_#X29````@_\!#X7G````C48"
MB47PBT44.47P?XM+#X72````A-)XSXI)`83)>,B-6M^`^PMV#XU"T#P8=@B-
M6K:`^S-WL8U!WSQ==ZH/MOJ-%'_!X@0I^@^V\8V$5L'S__\]@04``'=</5H$
M``!WAV:+A``@=A8(9H/X_0^$=?___P^WP(M=#(D#BTT(BT7PQT$4`0$``.D>
M____C78`A-*X_____P^(#O___P^VPHM]#(D'P>,(BTT(C48!B5D4Z?7^__\]
M#0\``'<5/:\.```/AR#___]FBX0`O%@6".N7/24B```/APO___]FBX0`9!\6
M".N"Z$B%_O]5B>575E.#[`R+50B+0BB)PXM-$`^V^,'K"(/Y?XMU#+C_____
M=PB(3?*X`0```(/X_W1H2`^%!P$``(I%\H3`B$7K>%>#_P$9P(/``HE%[(M5
M[#E5%+C^____?"&%_W4GBE7K@_D*B!9T+8/Y#70HP>,("?N+30B)62B+1>R-
M9?1;7E_)PXGVQ@8/,?]&BE7K@_D*B!9UTS';Z]1J`E&-1?)0_W4(Z`V0__^#
MQ!"#^/]T?8/X`@^%A@```(I-\H3)>&V`??,`>&<QP(/[`0^5P,'@`H/_`8G"
M=&*#P@,Y512X_O___WR6@_L!=!?&!AO&1@$DQD8"*<9&`T.[`0```(/&!(/_
M`70)Q@8.OP$```!&B`Z*3?.(3@'!XPB+=0@)^XE>*(UE]%M>B=!?R<.0C67T
M6UZX_____U_)PXU0`NN<Z`&$_O^058GEBT4(,=*`>"@`=!>+31"%R;K^____
M?@N+50S&`@^Z`0```(G0R<.-=@!5B>6+11"*`(3`BTT,>`T/ML")`;@!````
MR<.0#[;`9HN4`&"7$0AF@_K]N/____]TYP^WPNO;D%6)Y8M5$(/Z?XM-#'<*
MB!&X`0```,G#D(V"8/___X/X5W<5BH)@EQ$(A,!T/X@!N`$```#KWXGVC8(P
M^O__@_@?=B&!^A<@``"P\G3@C8(`V___/:<```!W$HJ"('(1".O'B?:*@A"2
M$0CKO;C_____R<.058GEBT40B@`\GXM5#'8=/*]W%0^VR`^WA`G`E1$(B0+)
MN`$```##D#S/=PP/ML")`LFX`0```,,\WW<-#[;`#[>$`$"5$0CKYCSO=M\/
MML@/MX0)X)01".O5B?95B>6+51"!^J<```"+30QW"X@1N`$```#)PXGVC8)8
M____@_A7=Q6*@KB5$0B$P'0IB`&X`0```.O>B?:-@J#^__^#^!]W"8J"X)01
M".O>D('Z/B```+"O=->X_____\G#C78`58GEBT40B@"$P(M-#'@-#[;`B0&X
M`0```,G#D`^VP&:+E`!`E!$(9H/Z_;C_____=.</M\+KVY!5B>6+51"#^G^+
M30QW"H@1N`$```#)PY"-@GC___^#^&]W%8J".)01"(3`=%"(`;@!````Z]^)
M]HV"^/G__X/X9W85C8(`V___@_@?=Q**@B!O$0CKTXGVBH(XCA$(Z\F!^J`E
M``"PB73#C8(0!___@_@/=P^*@B";$`CKK+C_____R<.-@I`!__\]CP```'?L
MBH(0E1`(ZY"-=@!5B>6+11"*`#R?BU4,=PT/ML")`LFX`0```,.0#[;(#[>$
M"8"1$0B)`LFX`0```,-5B>6+51"!^I\```"+30QW"X@1N`$```#)PXGVC8)@
M____@_@/=Q6*@OB1$0B$P'0MB`&X`0```.O>B?:-@@#\__\]EP```'<+BH(`
MCA$(Z]R-=@"!^A8A``"P\'33N/_____)PXUV`%6)Y8M%$(H`/)^+50QW#0^V
MP(D"R;@!````PY`/ML@/MX0)H(T1"(D"R;@!````PU6)Y8M5$('ZIP```(M-
M#'<+B!&X`0```,G#B?:-@EC___\]#P$``'<3BH(8C1$(A,!T)X@!N`$```#K
MW(V"`/W__X/X)W<)BH*`BA$(Z^"0@?JK(```L/YTV;C_____R<.-=@!5B>6+
M11"*`(3`BTT,>!$/ML")`;H!````B=#)PXUV`#R?NO____]V\`^VT`^WA!(`
MD!$(Z]R)]E6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X#W<5BH*`
MD!$(A,!T.H@!N`$```#KWXGVC8*X\?__@_@#=A6-@@#R__^#^%]W#XJ"P($1
M".O3B?:-0J#KS('ZK"```+#>=,:X_____\G#B?95B>6+11!3B@"$P(M-#'@0
M#[;`B0&Z`0```(G06\G#D`^VV&:+E!L@CQ$(9H/Z_70'#[?"B0'KW3R?NO__
M__]WV;H!````B1GKT(GV58GEBU40@_I_BTT,=PJ($;@!````R<.0C4*`@_@?
M=CB!^J````"PH'0BC8(`\O__@_A?=C.-@O#?__^#^!=W,(J"D&\1"(GVA,!T
M+H@!N`$```#KP(UV`&:#O!(@CQ$(_8C0=;OKX9"*@L"!$0CKV('ZK"```+"`
M=-*X_____\G#C78`58GEBT40B@`\GXM5#'<-#[;`B0+)N`$```##D#RD=!`/
MML@/MX0)H(T1".OEC78`QP*L(```N`$```#)PXUV`%6)Y8M5$('ZGP```(M-
M#'9'@?JG````=C>!^M````!T-XV"6/___ST/`0``=C:-@@#]__^#^"=W,XJ"
M@(H1")"$P'1%B`&X`0```)#)PXGV@?JD````=,&X`0```(@1Z^N-=@"*@AB-
M$0CKU('Z/B```+"O=,Z-@EC?__^#^`=W"(J"O&P1".NWN/_____)PU6)Y5=6
M4U&+31"*`83`BW4,>!4/ML")!KH!````B=!:6UY?R<.-=@"-6%^`^U-W?(-]
M%`&Z_O___W[BBE$!@/J@=FF`^O]T9(UX@(GYB$WR@/L'C4J`B$WQB$WS=UN-
M6E^`^UUW9HGY#[;!C11`P>($*<(/MGWQC817P?/__SV!!0``=U,]L0(``'=`
M9HN$`"`F&`AF@_C]=#*Y`@````^WV(G*B1[I<O___Y"Z_____XG06EM>7\G#
M@\!0/$2Y_____W:9B<KI4?___[G_____B<KI1?___SU_'@``=^UFBX0`'.D7
M".NKC78`58GE4U.+51"#^G^+70RX_____W<'B!.X`0```(/X_W0'BUW\R<.)
M]FH"4HU%^E#_=0CH<7'__XG"@\00@_K_N/____]TVX/Z`G4F@WT4`;C^____
M?LN*3?J#P8"("XI5^X/"@(A3`;@"````BUW\R</HOGS^_XGV58GE5U93@^P(
MBTT0BA&$THM]#(MU%'@4#[;"B0>X`0```(/$"%M>7\G#B?:`^J`/AJ,```"`
M^O\/A)H```"#_@&X_O___W[:@/K"BED!#X09`0``@/N@=G>`^_]T<HU"7X/#
M@(U*@#P&B$WPB%WQ=A6`^4)T$(U"/#PYNO____\/AZ@```"-4]^`^ET/A\\`
M```/ML&--$#!Y@0IQ@^VRXV$<<'S__\]'0P```^'>@$``#WS`0``=WQFBY0`
MH$T1"&:#^OT/A)8````/M\+K5XU+WX#Y778-@\0(6UZX_____U_)PXU"7XU*
M@#Q1B$WNB%WONO____]W-`^VP8T40,'B!"G"#[;SC816P?/__SWA'0``=TMF
MBX0`H%$1"&:#^/UT/0^WP(D'N@(```")T.GM_O__/3L"``"ZH$X``'2*/4("
M``"ZJU$```^$>O___SU'`@``NOE2```/A&K___^Z_____XG0Z;7^__^`^\L/
MA=[^__^#_@,/CJ/^__^*40*`^J`/ADW___^`^O\/A$3___^*20.`^:`/ACC_
M__^`^?\/A"____^-<8")\(A%\XU"7XU:@#Q!B%WR=@N-0AP\`P^'#____XU1
M7X#Z70^'`____P^VPXT40,'B!(GQ*<(/MMF-A%/!\___/9D8``!W<#T#&```
M#X?:_O__9HN$`.#R$`@/MO0/ML`+!+7`\!`(/?W_```/A+K^__^)![@$````
MZ?C]__^)]CW9#```=Q@]/@P```^'(____V:+E``$-1$(Z7;^__\]\B$```^'
M"____V:+E`!,"1$(Z5[^__\]O1D```^':O[__V:+A``LO1`(ZXY5B>564X/L
M$(M-$(/Y?XM=#(MU%+C_____=P>("[@!````@_C_=`F-9?A;7LG#B?9J`U&-
M5>B+10CH8H'__X/X_UI9=!2#^`-U?(I%Z#P!=#D\`G18/`-T![C_____Z\>#
M_@.X_O___WZ]Q@/"QD,!RXI%Z8/`@(A#`HI-ZH/!@+@$````B$L#ZYU.N/[_
M__]^E8I%Z8/`@(@#BD7J@\"`B$,!N`(```#I>O___TZX_O___P^.;O___XI5
MZ8/"@(@3BD7JZ]KH>7G^_Y!5B>6+11"*`(3`BU4,>`T/ML")`LFX`0```,.0
M#[;(#[>$"8`9#@B)`LFX`0```,-5B>6+51"#^G^+30QW"H@1N`$```#)PY"-
M@F#___^#^%]W%8J"@!D."(3`=$^(`;@!````Z]^)]H'ZD@$``+"?=.N-@G#\
M__^#^#=W"(J"4!8.".O4@?I_(```L/QTSH'ZIR```+">=,2-@NC=__^#^$]W
M#XJ":/<-".NMN/_____)PXV"\-S__X/X%W<(BH)8]@T(ZY.-@@#;__\]IP``
M`'?9BH+`\PT(Z7O___^)]E6)Y8M%$(H`A,"+50QX#0^VP(D"R;@!````PY`/
MML@/MX0)P!8."(D"R;@!````PU6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"
M8/___X/X%W<5BH+P%@X(A,!T6H@!N`$```#KWXGV@?KW````L/9TZXV"@/S_
M_X/X3W<(BH+`$PX(Z]2!^G\@``"P_'3.C8+HW?__@_A/=A6-@@#;__\]IP``
M`'<0BH(@\0T(ZZJ*@LCT#0CKHKC_____R<.)]E6)Y8M%$(H`A,"+50QX#0^V
MP(D"R;@!````PY`/ML@/MX0)(!0."(D"R;@!````PU6)Y8M5$(/Z?XM-#'<*
MB!&X`0```,G#D(V"8/___SW?````=Q.*@J`3#@B$P'0]B`&X`0```.O=C8+H
MW___@_@'=B&!^ADB``"P^73BC8(`V___/:<```!W$HJ"@.X-".O)B?:*@A#T
M#0CKO[C_____R<.058GEBT40B@"$P(M5#'@-#[;`B0+)N`$```##D`^VR`^W
MA`F`$0X(B0+)N`$```##58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____
M/=\```!W$XJ"`!$."(3`=#&(`;@!````Z]V-@D#]__^#^!]V%8V"`-O__SVG
M````=Q"*@L#K#0CKTXJ"P`X.".O+N/_____)PY!5B>6+11"*`(3`BTT,>`T/
MML")`;@!````R<.0#[;`9HN4`,`.#@AF@_K]N/____]TYP^WPNO;D%6)Y8M5
M$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X7W<5BH+`#@X(A,!T4H@!N`$`
M``#KWXGVC8+X_O__@_AW=A6-@BC]__^#^`=W$HJ"\`L.".O3B?:*@M@-#@CK
MR8'Z$R$``+#R=,.-@@#;__\]IP```'<(BH(@Z0T(ZZJX_____\G#B?95B>6+
M11"*`(3`BU4,>`T/ML")`LFX`0```,.0#[;(#[>$"2`,#@B)`LFX`0```,-5
MB>6+51"#^G^+30QW"H@1N`$```#)PY"-@F#___^#^!]W%8J"8`P."(3`=#^(
M`;@!````Z]^)]HV"`/S__X/X7W8A@?H6(0``L.]TX(V"`-O__SVG````=Q**
M@N#F#0CKQXGVBH*@"`X(Z[VX_____\G#D%6)Y8M%$(H`A,"+30QX#0^VP(D!
MN`$```#)PY`/ML!FBY0`X`D."&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_
MBTT,=PJ($;@!````R<.0C8)@____@_A?=Q6*@N`)#@B$P'0SB`&X`0```.O?
MB?:-@NC^__^#^$=V%8V"`-O__SVG````=Q"*@F#D#0CKT8J""`D.".O)N/__
M___)PY!5B>6+11"*`(3`BU4,>`T/ML")`K@!````R<.0/-5T#0^VR`^WA`E@
M!PX(Z^7'`JP@``#KWXUV`%6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/__
M_X/X7W<5BH)@!PX(A,!T/H@!N`$```#KWXGV@?J2`0``L)]TZX'Z%R```+#R
M=.&!^JP@``"PU737C8(`V___/:<```!W"(J"0.(-".N^N/_____)PXGV58GE
MBT40B@"$P(M5#'@-#[;`B0+)N`$```##D`^VR`^WA`E`!0X(B0+)N`$```##
M58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A?=Q6*@D`%#@B$P'17
MB`&X`0```.O?B?:-@G#\__^#^#=V,8'Z?R```+#\=."!^J<@``"PGG36C8+H
MW?__@_A/=AJ-@N#<__^#^`%W'HU"U.NWB?:*@A`"#@CKK8J"*.,-".NEN/__
M___)PXV"`-O__SVG````=^R*@H#?#0CKB56)Y8M%$(H`A,"+50QX#0^VP(D"
MR;@!````PY`/ML@/MX0)@`(."(D"R;@!````PU6)Y8M5$(/Z?XM-#'<*B!&X
M`0```,G#D(V"8/___X/X7W<5BH*``@X(A,!T3X@!N`$```#KWXGV@?J2`0``
ML)]TZXV"</S__X/X-W<(BH)0_PT(Z]2!^G\@``"P_'3.@?JG(```L)YTQ(V"
MZ-W__X/X3W</BH)HX`T(ZZVX_____\G#C8+PW/__@_@7=PB*@EC?#0CKDXV"
M`-O__SVG````=]F*@L#<#0CI>____XGV58GEBT40B@"$P(M5#'@-#[;`B0+)
MN`$```##D`^VR`^WA`G`_PT(B0+)N`$```##58GEBU40@_I_BTT,=PJ($;@!
M````R<.0C8)@____@_A?=Q6*@L#_#0B$P'1/B`&X`0```.O?B?:!^I(!``"P
MGW3KC8)P_/__@_@W=PB*@I#\#0CKU('Z%R```+"-=,Z!^G\@``"P_'3$C8+H
MW?__@_A/=P^*@JC=#0CKK;C_____R<.-@O#<__^#^!=W"(J"F-P-".N3C8(`
MV___/:<```!WV8J"`-H-".E[____B?95B>6+11"*`#P?BU4,=AT\+W<5#[;(
M#[>$":#^#0B)`K@!````R<.0A,!X#`^VP(D"R;@!````PP^VP&:+C`#@_`T(
M9H/Y_;C_____=-</M\'KW)!5B>53BU40@_H?BUT,=PV($[@!````6\G#C78`
MC4+@@_@'=Q2*BKC]#0B$R71.N`$```"("^O?D(U"V(/X5XC1=NB-BF#___^#
M^5=W"(J*X/P-".O5@?JR`P``L9!TSX'ZQ@,``+&2=,6-@OCY__^#^&=W$(J*
M^/8-".NNN/____];R<.-BNC=__^#^3=W"(J*J-H-".N3C8(`V___@_@_=PB*
MBH#7#0CK@('ZDB4``+&$#X1V____@?J@)0``L?X/A&C___^-BH@!__^!^8<`
M``!WJ(J*:/T,".E+____D%6)Y8M%$(H`A,"+50QX#0^VP(D"R;@!````PY`/
MML@/MX0)X/D-"(D"R;@!````PU6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"
M8/___X/X7W<5BH+@^0T(A,!T3X@!N`$```#KWXGV@?J2`0``L)]TZXV"</S_
M_X/X-W<(BH*P]@T(Z]2!^G\@``"P_'3.@?JG(```L)YTQ(V"Z-W__X/X3W</
MBH+(UPT(ZZVX_____\G#C8+PW/__@_@7=PB*@KC6#0CKDXV"`-O__SVG````
M=]F*@B#4#0CI>____XGV58GEBT40B@"$P(M-#'@-#[;`B0&X`0```,G#D`^V
MP&:+E``@]PT(9H/Z_;C_____=.</M\+KVY!5B>6+51"#^G^+30QW"H@1N`$`
M``#)PY"-@F#___^#^!]W%8J"8/<-"(3`=$B(`;@!````Z]^)]HV"@/S__X/X
M3W85C8+PW___@_@/=Q**@GC7#0CKTXGVBH(@]`T(Z\F-@@#;__\]IP```'<(
MBH+@T0T(Z[2X_____\G#58GEBT40B@"$P(M5#'@-#[;`B0+)N`$```##D#RO
M=Q0/ML`%D`,``(D"R;@!````PXUV``^VR`^WA`G@]`T(B0+)N`$```##58GE
MBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_@7=Q6*@GCU#0B$P'1+B`&X
M`0```.O?B?:-@@#\__\]EP```'8K@?H6(0``L/QTWH'Z&B(``+#[=-2-@@#;
M__\]IP```'<2BH+`SPT(Z[N)]HJ"@/$-".NQN/_____)PY!5B>575E.#[`R+
M?0B+1Q2%P(M5$(MU%'07BU4,QT<4`````(D",<"#Q`Q;7E_)PY"*"H3)>!:+
M70P/ML&)`X/$#%M>N`$```!?R<.0@/F@#X8F`0``@/G_#X0=`0``@_X!N/[_
M__]^OXI:`8#[H`^&&0$``(#[_P^$$`$``(#YC@^$&0$``(#YCP^$+0$```^V
M\8V&7____XV6@````(/S@(/X78E5[`^VVXG"=EB!?>PA`@``C9:]_O__=$F-
MAEW^__^#^`*-EKS^__]V.(%]["@"``"-EKK^__]T*8V&5/[__X/X`XV6M_[_
M_W88C982_O__@_H0QT7H`````'=#C99Y_O__@^LA@_M=QT7H`````'<NC012
MP>`$*="--$,/MX0VH)L-"(G#P>L()?\````#!)V@EPT(/?W_``!T5XE%Z(M5
MZ(72=$.#^G\/AR,!```/MS25')<-"(M=#`^W%)4>EPT(B3.)5Q0QP(#YCP^4
MP(/``NFL_O__@/F.#X3:_O__@/F/#X31_O__N/_____ID/[__V8QP(E%Z.ND
M@/O?=^D/MO.!QL#^``"+30RX`@```(DQZ6O^__^#_@*X_O___P^.7?[__XI"
M`H/P@`^VVP^VT(U#7X/X78E5\(VS@`$``(G"=D6!_B$"``"-4[UT.HV#7?__
M_X/X`HU3O'8L@?XH`@``C5.Z="&-LU3___^#_@.-4[=V$XV3$O___S'V@_H0
M=T"-DWG___^+7?"#ZR$Q]H/[77<MC312P>8$*=:-!',/MX0`H)L-"(G#P>L(
M)?\````#!)V@EPT(/?W_``!T"8G&B?+IU_[__V8QP(G&Z_*+?0R)%^GK_O__
M58GE5U93@^P,BT4(9HM(*#'_9H7)BW4,BUT0='.!^^4"```/A`L!``"!^^D"
M```/A/X!``"!^P`#```/A*(!``"!^P$#```/A/4!``"!^YHP``!U';H+````
MN`X```"09CD,E4#T#0@/A.,!``!"2'7N@WT4`;C^____?D6)R&;!Z`B(!HA.
M`;\"````@\8"@_M_=C>-DY\`__^#^CYW4(U7`CM5%+C^____?Q6-2T#&!HZ(
M3@&+?0C'1R@`````B="#Q`Q;7E_)PXGV.7T4N/[___]^[(@>BW4(QT8H````
M`(/$#%M>C4<!7\G#C78`@?N_I@(`=D@QP(G"9H72N/____]TO/?"@`````^$
MX````&:%T@^(K0$``('*@(#__XMU"`^WRHE.*(/$#%M>B?A?R<,QTK@!````
MZ2#___^)V,'H!@^_E`#@@0T(A=)XIXG8P>(&@^`_C0P"P>D$P>$"9HN1HE<-
M"(E-\(G9@^$/#[?"T_BH`0^$>O___[L!````T^-+(=.)VH'CJJH``-'[@>)5
M50```=J)T('BS,P``,'Z`B4S,P```=")PR7P<```P?@$@>,/#P```<,/ML-F
MP>L(`=B+3?`/M]`/MYF@5PT(`=,/MX0;(``-".D7____N@(```"X!0```.EN
M_O__9H72#XB4````C4\".TT4N/[___\/C[;^__^)TXC09L'K"(/(@(/+@(A&
M`8@>BU4(QT(H`````(G(@\0,6UY?R<.Z`0```+@!````Z1[^__^Z!P```+@$
M````Z0_^__^%P`^$&?[__X-]%`&X_O___P^.6O[__V:+#)5"]`T(B<MFP>L(
MB!Z(3@&+50BX`@```,="*`````#I,_[__XU/`SM-%+C^____#X\B_O__B=-F
MP>L(B-"#R("#RX"(1@+&!H^(7@&+?0B)R,='*`````#I8____^A_:/[_C78`
M58GEBT4(BU`H,<"%THM-#'0:@WT0`;C^____?@^)T,'H"(@!B%$!N`(```#)
MPXGV58GE5U935HMU"(M&%(7`BUT,BTT0=!''1A0`````B0,QP%M;7E_)PXH1
MA-)X&H#Z7'0U@/I^#[;"="")`[@!````6UM>7\G#C4)?/#YW)@^VP@7`_@``
MB0/KXK@!````QP,^(```Z]JX`0```,<#I0```.O-C7I_B?@\'@^'`P$``(-]
M%`&X_O___WZ5BDD!C4'`/#YV"XU!@#Q\#X?9````@/K?B?AV`XU"/X3)#X@A
M`0``@^E`#[;X@/E=C10_=@2#Z5Y"@_I=C4$A=@^#^F8/AND```"!PN8````/
MMLB#^EV)3?"-NB$!``")T79/@?\A`@``C8I>____=$&-@O[^__^#^`*-BEW_
M__]V,('_*`(``(V*6____W0BC;KU_O__@_\#C8I8____=A&-BK/^__^#^1!W
M0HV*&O___XM5\(/J(8/Z77<QC3Q)P><$*<^-!'H/MX0`H)L-"(G"P>H()?\`
M```#!)6@EPT(/?W_``!T<X7`B<)U'[C_____Z9W^__^-0B`\'`^&\O[__[C_
M____Z8C^__^#^']W3@^W!(4<EPT(B0,/MPR5'I<-"+@"````B4X4Z63^__^)
M]H/Z8G<8@_I?=!.!PJ(```#I"/___X/I0>G:_O__@<*H````Z?7^__]F,<#K
MB(D#N`(```#I*?[__XUV`%6)Y5=64X/L#(M%"&:+2"@Q_V:%R8MU#(M=$'1S
M@?OE`@``#X38`0``@?OI`@``#X3]`0``@?L``P``#X3,`0``@?L!`P``#X0F
M`@``@?N:,```=1VZ"P```+@.````D&8Y#)7`\PT(#X2$`@``0DAU[H-]%`&X
M_O___WX[B<AFP>@(B`:(3@&_`@```(/&`H/[?W<K@_M<=":#^WYT(3E]%+C^
M____?@^('HMU",=&*`````"-1P&#Q`Q;7E_)PX'[I0````^$``$``('[/B``
M``^$1`$``(V+GP#__X/Y/@^&!0$``('[OZ8"`'<^B=C!Z`8/OY0`X($-"(72
M>"V)V,'B!H/@/XT,`L'I!,'A`F:+D:)7#0B)3?")V8/A#P^WPM/XJ`$/A6`!
M```QP(G#9H7;N/____\/A'G___\/M\,/ML^)1>R-4=^#X'^#Z"&#^EUV*H'Z
MS`````^'(`$``('ZB@````^'P@$``('ZAP````^$M@$``(U1O8UV`/;"`70#
M@\!>T>J#^AX/AZX```"!PH$```"#^#Z-2$!V`XU(0?=%[(`````/A)L```!F
MA=L/B'X!``#!X@@)RHMU"(GXB58HZ>S^__\Y?12X_O___P^.WO[__\8&7(M=
M",=#*`````#IR?[__SE]%+C^____#XZ^_O__C5-`B!;KW#'2N`$```#I4_[_
M_[H"````N`4```#I1/[__SE]%+C^____#XZ._O__Q@9^Z7G^__^Z`0```+@!
M````Z1_^__^!PL$```#I3?___XU?`CM=%+C^____#X];_O__B!:(3@&+?0B)
MV,='*`````#I1?[__[H'````N`0```#IWOW__XV1>?___^GS_O__NP$```#3
MXTLATXG:@>.JJ@``T?N!XE55```!VHG0@>+,S```P?H")3,S```!T(G#)?!P
M``#!^`2!XP\/```!PP^VPV;!ZP@!V(M-\`^WT`^WF:!7#0@!TP^WA!L@``T(
MZ3W^__^%P`^$>/W__X-]%`&X_O___P^.K_W__V:+%)7"\PT(B=-FP>L(B!Z(
M5@&+30BX`@```,=!*`````#IB/W__XU1M^E(_O__Z!-C_O^-=@!5B>6+10B+
M4"@QP(72BTT,=!J#?1`!N/[___]^#XG0P>@(B`&(40&X`@```,G#B?95B>57
M5E.#[`R+50B+0A2)PL'J`XM-$(MU%'0<@^`'BTT(B4$4BT4,B1`QR8/$#%M>
MB<A?R<.)]HG',=N*$8#Z&P^%I0```(U3`SGR?T:*00$\*'1C/"0/A84```"*
M00(\0'1(/$)T1#PH=7:-4P0Y\G\ABD$#/$^_!````'0)/%!U7[\%````@\$$
MB=.-4@$Y\GZHBT4(B7@4N?[___^#Q`PIV5M>B<A?R<.0OP,```"#P0/KU8GV
MBD$"/$)T$CQ*=!4\274;OP(```"#P0/KNC'_@\$#Z[._`0```(/!`^NIN?__
M___I0/___X/_!0^'A@(``/\DO<29&`B-0P(Y\(E%Z'^.A-)XV(I)`83)>-&)
M^\'C"`^VTHV4$P#]__^-LM_^__^#_ET/MMF)\791@?HA`@``N5X```!T1(V"
MW?W__X/X`HV*//[__W8S@?HH`@``N6(```!T)HVRU/W__X/^`XV*-_[__W85
MC8J2_?__@_D0#X=G____C8KY_?__C5/?@_I=#X=5____C01)P>`$*<B-'$(/
MMX0;H)L-"(G"P>H()?\````#!)6@EPT(/?W_```/A-<!``"%P`^$'O___X/X
M?P^'LP$```^W-(4>EPT(BTT,#[<4A1R7#0C!Y@.)$0G^BTWHBWT(B7<4Z3?^
M__^-=@"-0P(Y\(E%[`^/CO[__X32#XC4_O__BDD!A,D/B,G^__^-6M^`^P=V
M"XU"T#Q$#X>V_O__C5G?@/M=#X>J_O__#[;"C11`P>($*<(/MO&-A%;!\___
M/8$%```/APL!```]L0(```^'?_[__V:+A``@)A@(9H/X_0^$;?[__XM-"`^W
M\(M=#(DSB7D4BTWLZ:']__^0A-*Y_____P^(D_W__XC1@.F`B$WS>'F`^5P/
MA)L```"`??-^#X2?````#[95\XMU#(D6BW4(C4L!B7X4Z5_]__^$TKG_____
M#[;"#XA/_?__BTT,B0'KVX32N?____\/B#O]__^`^EQT&X#Z?G1!#[;RBTT,
MB3&+50B-2P&)>A3I&_W__XMU#,<&I0```.OGC4+?/#ZY_____P^'`/W__P^V
M1?,%P/X``(M-#(D!ZX.+10S'`#X@``#KO(M%#,<`I0```.EJ____BTT,QP$^
M(```Z5S___\]?QX```^'=/W__V:+A``<Z1<(Z?#^___H8%_^_XMU#(M="(M-
MZ(D&B7L4Z9G\__]F,<#I(?[__Y!5B>53BUT(BU,4B=$QP,'I`W00BT4,@^('
MB5,4B0BX`0```%O)PXGV58GE5U93@^P\BTT(BT$HB<'!Z0.)PHG'P>H3@^<'
M9H7)BW4,QT7``````(E5Q`^$G0```(%]$.4"```/A+(!``"!?1#I`@``#X2A
M`@``@7T0``,```^$I`$``(%]$`$#```/A"0#``"!?1":,```=1VZ"P```+@.
M````D&8Y#)6@_PP(#X2(!```0DAU[C';.7W$#Y7#C51;`CE5%(E5P+O^____
M?'PY?<1T%X/_`P^%Z00``,8&&\9&`23&1@)"@\8#B<AFP>@(B`:(3@&#Q@*#
M?1!_N/____]V5(/X_W1?2`^%M@0``(I5YH32>%&%_P^%\0```(M%P$`Y112[
M_O___WP>A?]T$,8&&\9&`2C&1@)",?^#Q@.(%HMU"(E^*(G#C67TB=A;7E_)
MPXUV`+@!````BDT0@_C_B$WF=:&#?1!_=VJ#?1!<=&2#?1!^=%Z*11"(1>:Z
M`0```(/Z_P^$L@```$H/A3$$``"*5>:$T@^(H````(/_`0^$`@(``(M%P(/`
M!#E%%+O^____?)*#_P%T@\8&&\9&`2C&1@)*OP$```"#Q@/I:____XGV@7T0
MI0````^$O0$``(%]$#X@``!T2(M=$('K8?\``(/[/KK_____=X2*11"#P$"(
M1>;I<?___Y"+1<"#P`3I"/___S'2N`$```#I??[__[H"````N`4```#I;O[_
M_\9%YG[I0?___Y"!?1"_I@(`=T*+11#!Z`8/OY0`X($-"(72>#"+71#!X@:#
MXS^-#!K!Z02-'(T`````9HN3HE<-"(M-$(/A#P^WPM/XJ`$/A;8!```QP&H"
M_W40C5WF4_]U"&:)1<CH%E'__X/$$(/X_W1\@_@"#X43`P``BD7FA,!X;(!]
MYP!X9O=%R(`````/A5L!``"#_P,/A/4"``"+5<"#P@4Y512[_O___P^,8?[_
M_X/_`W03Q@8;QD8!),9&`D*_`P```(/&`X@&BD7GB$8!BW4(B=.)?BCI-/[_
M_[H!````N`$```#I?OW__V:#?<@`#X22````#XR*`0``@_\$="R#1<`$BTW`
M.4T4N_[___\/C/K]___&!AO&1@$DQD8"*,9&`T^_!````(/&!/=%R(`````/
MA"8"``!F@WW(``^(1@(``(M%R(GZ)7]_``#!XA/!X`,)P@G7BUT(B7LHBUW`
MZ:G]___&1>9<Z=7]__^+1<!`Z?O]__^Z!P```+@$````Z>'\__^#?1!_#X;5
M````@7T0I0````^$_`$``(%]$#X@```/A/@!``"+11`M8?\``(/X/KK_____
M=PZ*71"#PT"(7>:Z`0```(/Z_W022@^%LP$``(I%YH3`#XC=````N______I
M(_W__XMUR('F?W\``,'G$\'F`PGW@\\#Z5/___^X`0```-/@2"'0B<(EJJH`
M`-'X@>)550```<*)T('BS,P``,'Z`B4S,P```=")P27P<```P?@$@>$/#P``
M`<$/MM%FP>D(`<H/MX.@5PT(#[?2`=`/MX0`(``-".GK_?__@WT07`^$(?__
M_X-]$'X/A!?___^*51"(5>;I0?___X/_!0^$GO[__X-%P`2+?<`Y?12[_O__
M_P^,;/S__\8&&\9&`23&1@(HQD8#4+\%````@\8$Z6W^__^#_P(/A.0```"+
M5<"#P@0Y512[_O___P^,,_S__X/_`G03Q@8;QD8!*,9&`DF_`@```(/&`X/`
M@(@&Z=#]__^%P`^$=/O__S';@_\$#Y7#C0R=`@```#E-%+O^____#XSL^___
M@_\$=!?&!AO&1@$DQD8"*,9&`T^_!````(/&!&:+%)6B_PP(B=!FP>@(B`:(
M5@&+=0B)RXE^*.FP^___BU7`@\(".544N_[___\/C)S[__^+3<AFP>D(@^%_
MB`Z*1<B#X'_I0?W__^AY6?[_BU7`@\("Z0;]___&1>9<Z2/^___&1>9^Z1K^
M__^+5<!"Z1G___^-=@!5B>575E.#[`R+30B+02B)QHG'B<'![@/![Q.#X0<Q
MP&:%]HM5#'0+,=LYSP^5PXU$6P*%R8G#=`.#PP,Y71"X_O___WP]9H7V="<Y
MSW03@_D#=3?&`AO&0@$DQD("0H/"`XGP9L'H"(@"B?"(0@&#P@*%R70+Q@(;
MQD(!*,9"`D*)V(/$#%M>7\G#Z,!8_O]5B>6+11"*`#P_BTT,=Q$/ML")`;H!
M````B=#)PXUV`(3`NO____]X\`^VT`^WA!*@_@P(Z]R)]E6)Y8M5$(/Z/XM-
M#'<*B!&X`0```,G#D(U"P(/X/W<4BH*@_@P(A,!T/(@!N`$```#KXI"-@D#_
M__^#^#]V%8V"P/[__X/X/W<2BH(@_0P(Z]2)]HJ"X/T,".O*@?H6(0``L&!T
MQ+C_____R<.-=@!5B>6+11"*$(U"@#P?BTT,=Q8/ML(/MX0`(/T,"(D!R;@!
M````PXGV#[;"B0')N`$```##58GEBU40@_I_BTT,=CZ!^H,```!T-H'ZAP``
M`'0NC8)@____@_A?=B.-@K#^__^#^"=W(8J"D/P,"(3`=$>(`;@!````C78`
MR<.)]K@!````B!'K\XV"\-___X/X+W8=@?HB(0``L(UTU(V"(-[__X/X#W<7
MBH*<VPP(Z[V*@I#=#`CKM;C_____R<.-@O#=__^#^`]W"(J"7-L,".N;@?IS
M)0``L(1TE8V"_P3__X/X`7?1C4*=ZX&-=@!5B>575E.![(P```#V0"0$B47$
MB57`BW4(BWT,#X0^`0``B=`M,3$``(/X,@^'!@(``&:+E!+^CPP(B=-FP>L(
MB%W6B%77C476#[95U@^V2`'!X@@)RHG3B=#!ZPK!Z`6#XQ^#X!^*B^#Q#`B*
MF,#Q#`B)T(/@'\'J#XJ`H/$,"$J(1;</A14$``"`^?T/A,T```"`^_T/A,0`
M``"`?;?]#X2Z````@/G_C578=`X/ML$%,#$``(E%V(/"!(#[_W0.#[;+@<$P
M,0``B0J#P@2`?;?_=`\/MEVW@<,P,0``B1J#P@2-1=@IPL'Z`HE5@$)T;HM-
MQ#';BU$H.UV`B56PB76LB7VH?2V%_W0S5_]TG=A6_W7$BU7$_U(<@\00@_C_
M?B$Y^`^'=`,```'&*<=#.UV`?-.)\BM5K.GN````N/[___^+?;"+=<1`B7XH
MNO[___^+=:R+?:@/A<X```"0@7W`!C```,=%I`````!T/(%]P/8P``#'1:0!
M````="R+7<"!ZP!.``"!^_]1```/AT<!``"+3<`/OX0)H+$+"(7`B46D#X@Q
M`0``D(M=Q(M3*(E5A(M%I&:+G`"`[PL(B=J!X_]_``"!PP`P```/M\N!X@"`
M__^+181FB56BB4W(QT7,/C```(E%G(EUF(E]E#';A?\/A$("``!7_W2=R%;_
M=<2+3<3_41R#Q!"#^/\/CBP"```Y^`^'@0(``$,!QBG'@_L!?LN)\BM5F(UE
M]%M>B=!?R<.0BTW`@>D`K```@?FC*P``#X<3____NQP```")R#'2]_/!Z0*X
M)4F2)(E5O/?AB95T____NQ4```")T#'2]_.YAV$8AHN%=/___XG3]^$IE73_
M___1K73___^)E6S___^)A6C___^+A73___\#A6S____!Z`2*B#'R#`B#R2`/
MOL$/OI,<\@P(P>`%"="+7;S!X`5F#[Z3`/(,"`G"Z6']__^-=@"+7<"!ZQ@@
M``"#^P(/AJ(```"+1<`MH````#U7`0``#X?N````BUW`#[^$&X#K"PB%P`^(
M@0$``,'@`HN0X#H+"(M=Q`7D.@L(B85\____BT,H,=LYTXE5D(E%C(EUB'-"
MC78`A?\/A#,!``!7BY5\_____S2:5O]UQ(M-Q/]1'(/$$(/X_W1M@_C_#XX3
M`0``.?@/ARH!``!#`<8IQSM=D'+!B?(K58B-9?1;7HG07\G#B?:+5<2+0B2H
M`@^$@````(M5P('Z&B````^$%0$``%=25O]UQ(M-Q/]1'(/$$(/X_XG"#X0G
M____C67T6UZ)T%_)PXN%?/___X/L"(L4F%=6BT7$Z!G\__^#Q!#I=?___XM5
MP('J&`(``(/Z!W9NBT7`+;@"``"#^"</AY8```"+7<`/OX0;\.8+".GN_O__
MJ`&Z)P```'2&@7W`&2```+*T#X1W____LF#I</___[C^____BWV<BW7$0(E^
M*(MUF(M]E`^%Y0```&:#?:(`#X5Y_O___T6DZ4K]__^+3<`/OX0)@.@+".F1
M_O__N/[___^+?8R+=<1`B7XHNO[___\/A9C]__^Z_____^F._?__Z(12_O^+
M5<"!ZM`#``"#^B]W%XM-P`^_A`E@Y`L(Z4K^__^R&.GD_O__@7W`AP4``'0[
MBT7`+?`%``"#^`=W$(M=P`^_A!L`X`L(Z1W^__^+5<"!ZG`&``"#^@]W&HM-
MP`^_A`G@W@L(Z?_]__^XC@(``.G]_?__@7W`,PX``'1%BT7`+;`.``"#^"]W
M&HM=P`^_A!L`S@L(Z<_]__^Z_O___^GF_/__BU7`@>IP#P``@_H/=QJ+3<`/
MOX0)8,P+".FG_?__N*8"``#II?W__XM%P"T`'@``/9\```!W$(M=P`^_A!L`
MK@L(Z7[]__^+5<"!ZO`>``"#^@=W$(M-P`^_A`D0K`L(Z6#]__^+1<`M`"``
M`(/X5W<0BUW`#[^$&T"I"PCI0_W__XM5P('JJ"```(/Z!W<0BTW`#[^$">"G
M"PCI)?W__XM%P"T`(0``/=<```!W$(M=P`^_A!N`I0L(Z0;]__^+5<"!ZA`B
M``"#^E]W$(M-P`^_A`F@H@L(Z>C\__^+1<`MP"(``(/X+W<0BUW`#[^$&^"@
M"PCIR_S__XM5P('J`"0``('Z[P```'<0BTW`#[^$"8"<"PCIJOS__XM%P"T`
M)0``@_@_=Q"+7<`/OX0;`)H+".F-_/__@7W`YB4``'0G@7W`#"H``'19BU7`
M@>IP*@``@_H'=QJ+3<`/OX0)$(\+".E=_/__N.D'``#I6_S__X%]P)\N``!T
M78%]P/,N``!T2HM%P"T`+P``/=<```!W&HM=P`^_A!M`A`L(Z2+\__^XZP<`
M`.D@_/__BU7`@>H`,```@?KW````=R2+3<`/OX0)0(`+".GW^___N/T'``#I
M]?O__[C[!P``Z>O[__^+1<`M,#$``(/X7W<0BUW`#[^$&R!]"PCIQOO__XM5
MP('J\#$``('Z#P(``'<0BTW`#[^$"8!W"PCII?O__XM%P"T`^0``/6\!``!W
M$(M=P`^_A!N`Y@D(Z8;[__^+5<"!Z@#[``"#^D]W$(M-P`^_A`G@X0D(Z6C[
M__^+1<`M2/X``(/X)W<0BUW`#[^$&_#:"0CI2_O__XM5P('J`/\``('Z[P``
M`'<0BTW`#[^$":#7"0CI*OO__XM%P"T`U`$`/?\#``!W$(M=P`^_A!N@)0@(
MZ0O[__^+5<"!Z@#X`@"!^A\"```/AW_\__^+3<`/OX0)8-D%".GF^O__B?95
MB>575E.#[!R+10R+,(M5$(EUZ(M=%(LRBT48BPN+$(M]"(7VQT7L`````(E-
MY(E5X.FE````D(M?%%;_=>B-3?!1B5W<5_]7#(/$$(7`B<,/B+4```"+3>"%
MR0^$!`$``/]UX/]U\/]UY%?_5QR#Q!"#^/]U08M5\(G0P>@'/0`<``!T28M/
M+/]%[(7)#X61````BU<PA=)U-/]UX&C]_P``_W7D5_]7'(/$$(/X_P^$Y@``
M`(GVA<`/B*8````[1>`/A[H````!1>0I1>`Y\P^'K`````%=Z"G>#X56____
MBT7HBWT,BUT0B0>),XM]&(MUX(M5Y(M-%(D1B3>+1>R-9?1;7E_)PXGV@_C_
M=#6#^/X/A)4```"X_O___RG8B</KJH/L"/]UX/]UY(GXZ*/V__^#Q!"#^/\/
MA7?____I3O___XM7,(72=%6+1PB#^!)W!_\DA=R9&`B[`0```.EI____BT7<
MB4<4Z)]._O_'``<```#'1>S_____Z5_____H>$W^_[L$````Z3W___^[`@``
M`.DS____BUW<B5\4Z&E._O_'`%8```#KR.A<3O[_QP`6````Z[M5B>575E.#
M[!R+?0R%_XM="'0YBP>%P'0SBU,0A=+'1>P`````=3V+0R"%P`^%O@```,=#
M%`````#'0R@`````BT7LC67T6UY?R<.0QT,4`````,=#*``````QP(UE]%M>
M7\G#@^P(BW,4C4WPB77H45/_TH/$$(7`=*R+11"+%XLPB57D5O]U\%)3_U,<
M@\00@_C_=3Z+5?")T<'I!X'Y`!P``'0[BT,LA<#'1>P!````=6R+4S"%TG4F
M5FC]_P``_W7D4_]3'(/$$(/X_P^$AP```(7`>&@Y\'=?`47D*<:+1>2+31")
M!XDQZ3?___^+-XM5$(EUX(LR4E;_=>!3_]"#Q!"%P'@].?!W+HM-X`'!B0\I
MQHM]$(DWZ1+___^#[`A6_W7DB=CH[O3__X/$$(/X_W6>Z7G____H!$S^_XMU
MZ(ES%.@)3?[_QP`'````N/_____I`?___XM]Z(E[%.CN3/[_QP!6````N/__
M___IYO[__XGV58GE5U9348M5$(M-#(M%%(M]&(LRBQF)\HL(BP?!Z`+!Z@(Y
MPG8"B<*%TG0NC025`````"G&B47PBT40B3"+=?`I-Y"+.XDY@\,$@\$$2G7S
MBU4,B1J+712)"UI;7C'`7\G#D%6)Y8M-#(U!_E:#^"M3BW4(#X?-````@_D*
MB<N)R@^&S`````^V5@H/MX020)H8"(T4`0^V1@D/MXP`0)H8"`'*#[9&"`^W
MC`!`FA@(`<H/MD8'#[>,`$":&`@!R@^V1@8/MXP`0)H8"`'*#[9&!0^WC`!`
MFA@(`<H/MD8$#[>,`$":&`@!R@^V1@,/MXP`0)H8"`'*#[9&`@^WC`!`FA@(
M`<J*#@^VP0^WA`!`FA@(C00"#[94'O\/MY020)H8"(T<`H'[;P,``'<9BQ3=
M8!\+"(72>`XZBF`2"PB-@F`2"PAT%#'2C67X6XG07LG#D/\DC4";&`B0@^P(
M0%"-3@%1Z$)-_O^#Q!"%P(T4W6`?"PATTNO.B?95B>575E.#[`R+?0B^`!`+
M"+M*````ZP:#Q@A+="*+!H/L"`7`#0L(4%?H`4W^_X/$$(7`=>*-9?1;B?!>
M7\G#C67T6UXQP%_)PXGV58GE5U93@>R,````BT4(QT6D`````,=%H`````")
MP8U=J+XX````ZQB-=@"-0I\\&7<#@^H@A-*($W0C3G0(04.*$832>>7HR$K^
M_\<`%@```+C_____C67T6UY?R<.)V8U5J"G1@_D)?AR-0_:)193\N0H```"+
M=92_X)L8"/.F#X21````B=J-?:@I^H/Z!WX7C4/XB460_+D(````B<:_ZYL8
M"/.F=%^`?:@`="V)V8U5J"G1C5G^@_LK=CPQTH72B=`/A%@!``"+6`2!^X4`
M``")79P/A8@!``#HN@8``(`X``^%,O___^@D2O[_QP`6````Z5?___^#^0J)
MRG<H_R2-;)L8"(M=D,8#`,=%H`$```#KDHM=E,8#`,=%I`$```#I7?___P^V
M=;(/M[PV0)H8"(T4.0^V7;$/MX0;0)H8"`'"#[9UL`^WO#9`FA@(`?H/MEVO
M#[>$&T":&`@!P@^V=:X/M[PV0)H8"`'Z#[9=K0^WA!M`FA@(`<(/MG6L#[>\
M-D":&`@!^@^V7:L/MX0;0)H8"`'"#[9UJ@^WO#9`FA@(`?J*1:@/MOB(19H/
MMYP_0)H8"(T$&@^V5`VG#[>,$D":&`B-'`&!^V\#```/A^;^__^+%-U@'PL(
MA=(/B-?^__^*39HZBF`2"PB-@F`2"P@/A<+^__^#[`A`C76H4$96Z-A*_O^#
MQ!"%P(T4W6`?"P@/A*/^___IG/[__[X`$`L(NTH```#K!Y"#Q@A+="N+/H/L
M"(''P`T+"%>-5:A2Z)E*_O^#Q!"%P'7>B?"%P`^%;_[__^GF_?__,<#K[X%]
MG(8````/A-7]__^-1:B+30R[.````(E%C.LAB?:-0I\\&7<#@^H@BWV,A-*(
M%W072P^$J?W__T=!B7V,BA&$TGG;Z9G]__^+38R-=:@I\8/Y"7X=BUV,@^L*
M_+D*````B=Z_X)L8"/.F=0:)78S&`P"+78R-5:@ITX/[!WX=BUV,@^L(_+D(
M````B=Z_ZYL8"/.F=0:)78S&`P"`?:@`="2+38R-7:@IV8U!_H/X*P^'ZP``
M`(/Y"HG*=QG_)(V8FQ@(B?;H:P0``(E%#(`X`.DP____#[95L@^WO!)`FA@(
MC10Y#[9%L0^WM`!`FA@(`?(/MGVP#[></T":&`@!V@^V1:\/M[0`0)H8"`'R
M#[9]K@^WG#]`FA@(`=H/MD6M#[>T`$":&`@!\@^V?:P/MYP_0)H8"`':#[9%
MJP^WM`!`FA@(`?(/MGVJ#[></T":&`@!VHI%J`^VV(A%FP^WA!M`FA@(C30"
M#[94#:</MXP20)H8"(T<,8'[;P,``'<@BQ3=8!\+"(72>!6*39LZBF`2"PB-
M@F`2"P@/A.H````QTH72B=`/A*T```"+<`2!_H4````/A`K___^!_H8````/
MA!G\__^#[`QJ-.@L1?[_@\00A<")PW1OC12VBTV<B7`(BS25X/(,"(EP#(TT
MB<'F`HL\E>3R#`B)>!")2!B+ANCR#`C'0Q0`````QT,H`````(N6[/(,"(N^
M\/(,"(E#'(M-I(MUH(G8B5,@B7LDQP.T2`8(QT,$<$H&"(E++(ES,.FG^___
MZ%]&_O_'``P```#IDOO__[L`$`L(ODH```#K!H/#"$YT18L#@^P(!<`-"PA0
MC56H4NC^1_[_@\00A<!UWXG8ZRB#[`A`C7VH4$=7Z.1'_O^#Q!"%P(T4W6`?
M"P@/A/?^___I\/[__S'`A<`/A?+^___I(?O__XGV58GE5E.+10R%P(M5"(MU
M$(M=%(M-&'0%@S@`=1.)31")70R)50A;BTH$7LG_X8GVB4T8B5T4B740B44,
MB54(6XL*7LG_X8GV58GE@^P4_W4(Z!9)_O\QP,G#B?95B>564XM%#(/X!(M5
M"(M-$'=M_R2%Q)L8"(GV,<"#.0`/E<")0C`QP(UV`%M>R<.+&C'V@?NT2`8(
M=#.!^^A+!@AT,XDQ,<#KXHGVBT(LB0$QP.O7C78`,=N#.0`/E<,QP(E:+.O%
MD(M",(D!Z^*+0A@Y0@AUQ;X!````B3'KQN@+1?[_QP`6````6[C_____7LG#
M58GEBT4(BT`$BU4,*T($R<.-=@!5B>564XM%#(/L"(M5"(LPBQI64^B?1O[_
M@\00A<!T&C'2@#M#=!TQR8`^0W0B*<K!X@*%P'@EC4(!C67X6U[)PXUV`(![
M`5-UW;(!Z]F)]H!^`5-UV+$!Z]2)]HUE^%N-0O]>R<.)]E6)Y5=64X'LS"P`
M`#'V,<F[;P,``(UV`(N!8!\+"(7`>"J+D60?"PB!^H4```!T'('ZA@```'04
M!6`2"PB)A/48XO__B93U'.+__T:#P0A+><8QTHL,U0`0"PB!P<`-"PB+!-4$
M$`L(0HF,]1CB__^)A/4<XO__1H/Z27;7@_X!=U$QVSGS<T.+E-T<XO__,?^)
MV8N$S1CB__]#B82]*-/__T<Y\W,).93='.+__W3A@_\!=S=0_W4,C84HT___
M4%?_50B#Q!"%P'2YC67T6UY?R<-HR%,&"&H(5HV5&.+__U+H:4'^_X/$$.N6
M:-Q3!@AJ!%>-E2C3__]2Z%!!_O^#Q!#KL(UV`%6)Y5=64X'LN````&H`Z#5#
M_O^#Q!"%P(F%9/___P^$GP```(L](!0F"(7_#X2@````@#\`B?MT9S'VZRR-
M=@")W_R)\+G_____\J[WT8T4&8G7N?_____RKO?1C4P1_X!Y`0"-60%T-X/L
M"%/_M63____HT$3^_X/$$(7`=`N`.RIUO(![`0!UMORY_____XG?B?#RKO?1
M`=F)C63___^+M63___^`/@!U"L>%9/___VC7"0B+A63___^-9?1;7E_)P\>%
M9/____2;&`CI4O___X/L#&@`G!@(Z($#```QTHG'_(G&N?____^(T/*NB<N_
MF+88"+G_____\J[WT_?128/$$#'_2XF-7/___P^%^P```(T,.XN57/___X/L
M#(U$$0%0Z)Y`_O^#Q!"%P(F%8/___P^$*`(``%)35E#H-$#^_X/$$(7_=`J+
MM6#____&!!XOBX5@____`?B+O5S___]'45<!V&B8MA@(4.@%0/[_6%IHF:(8
M"/^U8/___^A30_[_@\00A<")Q@^$T0$``,>%6/___P````#'A53___\`````
MB?:+7@1+A=N)7@0/B)D!``"+#@^V$4&)#H/Z_P^$-0$``(/Z"G3;@_H@=-:#
M^@ETT8/Z(W5'ZQ:+!@^V$$")!H/Z_P^$#@$``(/Z"G2TBU8$2H72B58$>=^#
M[`Q6Z!`__O^)PH/$$.O7@'P>_R\/A/K^__]FOP$`Z?'^__^#[`A64NAK/O[_
MC9UH____@\004XU]J%=H]9L8"%;H$C_^_X/$$$@/CJT```"Z_____S'`_(U]
MJ(G1\J[WT4F)C5#___^-O6C___^)T?*N]]&->?^+C53___^%R0^%Y0```(N=
M4/___P'[C4,"@^P,@\,#4XF%5/___^@F/_[_B858____BYU8____@\00A=MT
M/HN=6/___P.=5/___RG[B=B#[`B-5:@KA5#___]2@^@"4.@=/?[_65^-O6C_
M__]72U/H#3W^_X/$$.FU_O__QX54____`````(/L#%;H\D'^_XNU5/___X/$
M$(7VO_2;&`AT$HN-6/___XN=5/___\8$&0")SXN%8/___X7`=!&#[`S_M6#_
M___HMD/^_X/$$(D](!0F".GB_/__@^P,5NB_/?[_B<*#Q!#I7/[__[_TFQ@(
MZ\"+E5#___\!^@.55/___XU*`H/L"(/"`U+_M5C___^)C53____HE4#^_^D*
M____58GE5U93@^P,BUT(A=N+=0QT%87V=!&#[`A64^B/0?[_@\00A<!U',<%
M)!0F"`````#'!2P4)@@`````C67T6UY?R<,QP/R)W[G_____\J[WT8U1_XD5
M*!0F"(GWN?_____RKHG/]]=/@^P,C40Z`HD],!0F"%#HM#W^_X/$$(7`B<=T
MHZ$H%"8(0%)04U?H3#W^_XL5,!0F"(/$#$*)/204)@@#/2@4)@A2C5\!5E/H
M*SW^_XD=+!0F"(/$$(UE]%M>7\G#B?95H204)@B)Y87`5U-T"HL]+!0F"(7_
M=0R+10B-9?A;7\G#B?92_S4H%"8(4/]U".@T/_[_@\00A<!UW8M%"(L-*!0F
M"(H4"(32B?ATSH#Z+W7&BUT(`<LQP/R)W[G_____\J[WT8/L#`,-,!0F"%'H
M]#S^_X/$$(7`B<=TFU#_-3`4)@C_-2P4)@A7Z(@\_O]96(GZ4P,5,!0F"%+H
M]SK^_XGXZ7/___]5B>575E.#[!R+=12%]HM]"(M=$'4645/_=0Q7Z%\[_O^-
M9?1;7E_)PXUV`%)J`&H#5^AY0?[_B<*#Q`R#R@12:@17B<;H9D'^_X/$#%/_
M=0Q7Z"D[_O^)P^@2/O[_BP"#Q`R)1>16:@17Z$%!_O^#Q!`QP(7;=*F#?>0D
M=5F)?>AFQT7L`P!0BU44C022C32`C1RVP>,#4VH!C7WH5^B-/_[_@\00A<!T
M&WP,,<#V1>X##X5I____N/____^-9?1;7E_)P^BF/?[_QP`$````N/_____K
MYNB4/?[_BTWDB0BX_____^O558GE4U"+70B%VW0@@^P(:@"-0Q!0Z+*^``")
M70B#Q!"+7?S)Z:>E``"-=@"+7?S)PXUV`%6)Y593BUT(BU4,@^P(BW40B9-<
M`@``C4-3_S258,88"%"!PU,"``#H.P(!`(EU#(E="(/$$(UE^%M>R>DG`@$`
MC78`58GE5E.+=0B+AI0"``"%P(V>F`(``'4L4&H`:``@``!3Z-:[``#'AI0"
M````````QX;H`@```````(UE^%M>R<.-=@"#[`AJ`%/H!;X``(/$$.O$58GE
M5E.+=0B+!H7`="LQV_:&W0(``!!U>X/L#/\VZ`TV``"#Q!#VAMT"```0#X61
M````QP8`````@^P,5N@>.@``BY:4`@``@\00A=*-GI@"``!U+U!J`&@`(```
M4^A%NP``QX:4`@```````,>&Z`(```````"#Q!"-9?A;7LG#C78`@^P(:@!3
MZ'&]``"#Q!#KP8/L"&C<HP8(:@WH.3S^_X/$$(/L#/\VB</H?C4``(/$$/:&
MW0(``!`/A''___^)]H/L"%-J#>@-//[_@\00Z5S___^058GE5U93@^P,BW4(
M,=LQ__:&W0(``!`/A0<!``"+!H7`#X4=`0``]H;=`@``$`^%+`$``(/[_W0(
MA=L/A<L```"+%H72="\QV_:&W0(``!`/A1T!``"#[`S_-NCX-```@\00]H;=
M`@``$`^%+P$``,<&`````(/L#%;H"3D``(N.E`(``(/$$(7)C9Z8`@``#X7V
M````4&H`:``@``!3Z"RZ``"#Q!"!OEP"``"!!```QX:4`@```````,>&Z`(`
M``````"XY`<``'0"L-V#[`B+'6CD&`B)AEP"``#_-(5@QA@(C4934.@+``$`
M6EE3C;Y3`@``5^C\_P``@\00C67T6UZX_____U_)PXM^$(`__XG8#X28````
MC67T6UY?R<.)]H/L"&C<HP8(:@WHT3K^_XG'BP:#Q!"%P`^$Y?[__XGV@^P,
M5NC_00``@\00]H;=`@``$(G##X35_O__D(/L"%=J#>B9.O[_@\00Z<'^__^#
M[`AHW*,&"&H-Z((Z_O^)PX/$$.G*_O__@^P(:@!3Z)&[``"#Q!#I]_[__X/L
M"%-J#>A:.O[_@\00Z;[^__^#^P-V/P^W1P&#ZP+VAN$"```"B89<`@``C5<#
M=`:`?P,C=#Z!^_\!``")V%=V!;C_`0``4%*-7E-3Z(O_``#I!O___X/L"(L=
M:.08",>&7`(``-`'``#_-:#E&`CIT/[__U!J!8U/!%&-EE,"``!2Z%7_``"-
M5PF#Q!#KIY!5B>534(M="(/L#%/HO_W__X/$$(/X_W0I@_@(=^J+4Q"`.OYU
MXO:#X0(```)T$P^W"@^W0@*)B_0"``")@^P"``"+7?S)PY!5B>564XMU"(7V
M#X24````BUX8A=MT'(U&33F#M`,```^$A@```(.[?`,```(/A(@```"+7@R%
MVW09@^P(:@"-2Q!1Z&BZ``")'"3H9*$``(/$$(M>"(7;=1:+1D2%P'4GB74(
MC67X6U[)Z46A``"0@^P(:@"-1AQ0Z#*Z``"+1D2#Q!"%P'39@^P,4.@CH0``
MB74(@\00C67X6U[)Z1*A``")]HUE^%M>R<.0QX.T`P```````.EK____@^P,
MBY.L`P``4_]2%(/$$,>#?`,```````#I6?___XGV58GE5U93@^PLC4W048U5
MS%*-1=A0BUT0_W4,C7W4BW4(QT7,`0```(E]T,=%U.F=&`C'1=CIG1@(B5W<
MQT7@`````.C`S@``@\00@WW,`70=BT70C5@$BT`$A<!T$(GV@#@M=!^#PP2+
M`X7`=?*#[`S_==#HQ\4``(UE]%M>7\G#C78`@'@!+77;@^P(:CW_,^AJ`0$`
M,?^#Q!"`.`!T!HUX`<8``(L#ZP6)]L8`+8/L"&I?4.A&`0$`@\00@#@`=>I1
M:@)HO.08"(L3@\("4NBCM```@\00@_@A=XC_)(4\GA@(QT80`P```(7_#X1R
M____@^P,5^AD.O[_B0:#Q!"#PP2+`^E?____@\,$@684?____XL#Z4[___^%
M_W00@^P,5^@W.O[_@\00A<!TVX/#!(%.%(````"+`^DI____QD9A`(/#!(L#
MZ1O____&1E\!@\,$BP/I#?___X/#!(%.%````@"+`^G\_O__4&H`:$#D&`A7
MZ/RS``"#Q!"%P(E&$`^%V_[__U%7:!R>&`C_->A#)0CHA#;^_\<$)`$```#H
MJ#G^_X7_#X2U_O__@^P,5^BG.?[_@\00B498Z3W____&1F`!@\,$BP/IF/[_
M_X/#!(%.%``$``"+`^F'_O__@^P,_W8\Z.J>``!86FH05^B<GP``@\00B48\
MZ?[^__^#[`S_=CCHRIX``%E8:A!7Z'R?``"#Q!")1CCIWO[__X/#!(-.%`*+
M`^DY_O__@^P,A?^)^`^$E@$``%#H&$```(/$$.FU_O__A?\/A!'^__^#[`S_
M=BCH>9X``%A::A!7Z"N?``"#Q!")1BCIC?[__X7_#X3I_?__@^P,_W88Z%&>
M``!96&H05^@#GP``@\00B488Z67^__^+3BR%R0^$!P$``(/L"&H05^CBG@``
M@\00A<")1<AT&H/L"(U]R%?_=BSH+=4``(/$$(3`#X2/_?__@^P,_W7(Z/>=
M``"#Q!#I&/[__X7_#X1T_?__@^P,_W8<Z-R=``!86FH05^B.G@``@\00B48<
MZ?#]__^%_P^$3/W__X/L#/]V(.BTG0``65AJ$%?H9IX``(/$$(E&(.G(_?__
MQD9=`8/#!(-.%""+`^D?_?__A?\/A!+]__^#[`S_=B3H>IT``%A::A!7Z"R>
M``"#Q!")1B3ICOW__X7_#X3J_/__@^P,5^C<-_[_@\00B48,Z7+]___&1FP!
M@\,$BP/IS?S__X/#!(%.%````P"+`^F\_/__@^P(:A!J%.A^G```@\00B48L
M:@5J`&H$4.A<TP``@\00Z=/^__^X\)T8".E@_O__B?95B>575E-6BTT,BT40
MBUT(,?:-?($$QT7P`````.L-D,<#`````(/!!(/#!#GY=!R+$872=.J%]G0*
MB=`I\$B+=?")!HG6B5WPZ]N06UM>7\G#B?95B>575E.#['2+11"--(#!Y@16
MBE44_W4,B%6WZ&NT``"#Q!"%P(E%K(G##X2#`P``B?'!Z0(QP/R+?:SSJ_=%
M&``"``!T;8MU"(MV#(7VB76P#X3D`0``@'VW`8M-L(MQ!!G`B?&#P`B-1($$
MB768C7VX,?8YP<=%J`````")1:3K$)#'!P````"#P02#QP0[3:0/A(L```"+
M$872=.6%]G0*B=`I\$B+=:B)!HG6B7VHZ]:+30B+>0R)?9"%_Y`/A'8!``"`
M?;<!&<"+=9"+5@2#P`:-1(($,?:-?;B)T3G"B56,QT6@`````(E%G.L2C78`
MQP<`````@\$$@\<$.TV<#X1G`0``BQ&%TG3EA?9T"HG0*?!(BW6@B0:)UHE]
MH.O6@^P(BTV8_S'_=0SH_+8``(E#%%F+?;!>BW<$_W8$_W4,Z.:V``")0Q"+
M=;!86HM6!/]R"/]U#.C0M@``B4,(65^+1@3_<`S_=0SHO;8``(E##%A:BTX$
M_W$0_W4,Z*JV``")`UE?BWX$_W<4_W4,Z)BV``"+5;B+3<")0P2)4SB)2RR+
M5<B+3@2+?<2)4R2+41B+1;R)>S`/MSJ)0S2)>TB+1<R+>@*)0RB)392)>QP/
MMDH&#[=R!XE+3(ES0`^V0@F#Q!"#^0F)0T0/AUX!``"#^0</A*@!``"!S@"`
M``")<T"`?;<`=`Z+592+0AR%P`^%1@$``,=#&`````"+=;"+-L=#(`````")
M=;"#PU"%]@^%'/[__XM="(7;=!V#[`B+50AJ`(/"$%+H3+,``%__=0CH1YH`
M`(/$$(M]K(UE]%M>B?A?R<.-=@"#[`B+58S_,O]U#.BPM0``B4,(B4,,6(M%
MD%J+<`3_=@3_=0SHE[4``(M]D(D#BW<$BTX(BSF!Y____P"+5@R)>QP/M@J+
M1;B+5;R#Q!#V11@$B4M,QT,4])L8",=#$/2;&`C'0S@`````QT,T`````(E#
M+(E#,(E3)'18BT80#[<0B5-`#[9``H/Y"8E#1'<\@_D'#X2.````@,Z`B5-`
M@'VW`'0'BT84A<!U8<=#&`````"+=9"+/L=#(`````"#PU"%_XE]D.F#_?__
M@_D-=<[KQHM&$`^V$(E30`^V0`'KIH/Y#0^%J_[__^F=_O__@^P(4/]U#.C#
MM```B4,8@\00BT74B4,\Z:3^__^#[`A0_W4,Z*:T``"+3<R#Q!")0QB)2SSK
MC(/_#@^$:?___X/_".N:@_\.#X1/_O__@_\(ZZ*+30B%R70=@^P(BUT(:@"#
MPQ!3Z-2Q``!?_W4(Z,^8``"#Q!`Q_^F$_O__D%6)Y5=64X/L./]U".B']/__
MB<.#Q!`QP(/[_P^$U`$``(/L"&HP:C3H]Y<``(/$$(7`B47H#X1$`@``5FH`
M:``@``"+5>B#PA")5=Q2Z!:O``"+?>B+10B+=>C'1QP,````BU`0@\<,BTT0
MB7WDQP8`````QT8$`````(E."(E5\(/$$(`Z_@^$RP$``(M%$,'@`HE%U(GV
MBW7H@P8!@U8$`(/L"&H,_W7<Z/VO``"#Q!"%P(E%X`^$J0$``(M5U(/L"(U\
M&@17_W7<Z-RO``"+3>"#Q!"%P(E!!`^$A0$``(MUX(M5Y(M]U(DRB77DC70X
M!#'_C4P>_SM]$(E-[`^#D0```,=%V`````#K4HGVBU7LBTW@*?*+000YVHDT
MN`^"UP```%!3_W7P5NA++?[_Q@0>`(M5#`%=\(/$$(72C70>`700BT78BU4,
M.5P0(',$B5P0($>#1=A0.WT0<S"#[`R-1?!0Z$31`0"#Q!"#^/^)PW6:BTW@
MBUD$QP2[`````$>#1=A0.WT0<M.-=@"+7>"+0P2#[`R)-+C_=0CH]/+__X/$
M$(/X_XG##X3K````BWT(BU<0B57P@#K^#X74_O__@_@'#X?+_O__BW7D@_L!
MQP8`````=A>+30@/MUH!#[="`XF9]`(``(F![`(``(M%Z(UE]%M>7\G#@^P(
M:@#_==SHMJ\``%G_=>CHL98``%A:BU4(BQUHY!@(QX)<`@``ZP<``(G0_S4,
MYA@(@\!34.A7\P``6%I3BUT(@<-3`@``4^A%\P``@\00,<"-9?1;7E_)PX/[
M!P^'+/[__^EG____@^P(:@#_==SH3:\``%G_=>CH2)8``(/$$(M%"(/L"(L=
M:.08",>`7`(``-@'``#_-<#E&`CKDX/L"&H`_W7<Z!:O``!?_W7HZ!&6``"#
MQ!`QP.N6B?95B>53@^P(:@!J`&H`BUT(Z'\W``"#Q!`QTH7`=6^%VW1R4&BX
M`P``:@!3Z``O_O^#Q!"+%53R&`B#[`B)DY`"``#'@_@"````````B9N8`P``
MB9N<`P``B9ND`P``C8-3`@``_S5DY!@(4.AD\@``QH.7`P```8&+#`,``(``
M``#'@UP#```0````B=J)T(M=_,G#@^P(:C!HN`,``.C%E```@\00,=*%P(G#
M=-_&@(`#```!Z7G___^)]E6)Y3'`R<.058GE5U93@^P0BW4(BUT,BY:L`P``
M,<!J`/RY_____XG?\J[WT4E14VH`:@!J`E;_4@0/OL"#Q""%P'0(C67T6UY?
MR<.#[`S_MHP"``#H\I0``%A::A!3Z*25``")AHP"``"-9?1;7C'`7\G#58GE
M5U93@^P,BU4(BX*D`P``B47PBU7PB[J4`@``,<"%_P^$QP```(.Z?`,```$/
MA<,```"#[`AJ,(M5\(N"Z`(``(T\A50```!7Z.B3``")PX/$$#'`A=L/A)``
M``"+??"#[`B+AZP#``"-4U2)4Q2)0U!J$(NWZ`(``(T,M00```!1Z*^3``"#
MQ!"%P(E#1`^$I````(M5\(G6C7L<@<:8`@``_+D(````\Z6+@I0"``"+LN@"
M``"-2TV)0PB)<SS'0T``````B5,8QT-(`````,>"E`(```````#'@GP#```"
M````B8JT`P``B=B-9?1;7E_)PY"#[`B)UHL=:.08",>"7`(``-X'``"#QE/_
M-=CE&`A6Z(CP``!97E.+3?"!P5,"``!1Z';P``"#Q!`QP(UE]%M>7\G#@^P,
M4^B4DP``,<#KZU6)Y5=64X/L&/^P%`,``(G&Z'J3``!8_[80`P``Z&Z3``!8
M_[88`P``Z&*3``!8_[8<`P``Z%:3``!8_[8@`P``Z$J3``!8_[8H`P``Z#Z3
M``!8_[8L`P``Z#*3``!?_[8P`P``Z":3``!;_[8T`P``Z!J3``!9_[9@`P``
MZ`Z3``"+OB0#``"#Q!"%_W0ZBQ^+5P2-!),YPXE%\',7B?:#[`S_,X/#!.CC
MD@``@\00.UWP<NN#[`Q7Z&;+``")/"3HRI(``(/$$%)HA````(V.^`(``&H`
M4>C;*_[_C67T6UY?R<.-=@!5B>6+30B+$>L/B?:+0@C'0"P`````BU($A=)U
M[\<!`````,G#C78`58GE5U93@^P,BW4(A?8/A-,!``"+!H7`#X37````BY:4
M`@``A=*-GI@"```/A?L!``!0:@!H`"```%/HY*@``(/$#,>&E`(```````#'
MAN@"````````QX9\`P```````,:&@0,```"+OJP#``!J`6H`:@!J`&H`:@%6
M_U<$BPZ#Q""%R70O,?_VAMT"```0#X59`0``@^P,_S;H#",``(/$$/:&W0(`
M`!`/A9`!``#'!@````"#[`Q6Z!TG``"+AI0"``"#Q!"%P`^%2@$``%!J`&@`
M(```4^A&J```@\00QX:4`@```````,>&Z`(```````")\.CT_?__@^P,_[:$
M`@``Z':1``!?_[9T`@``Z&J1``!;_[9X`@``Z%Z1``!9_[:,`@``Z%*1``"#
MQ!"-CJ@#``"+EJ@#``#'AHP"````````QX9X`@```````,>&=`(```````#'
MAH0"````````ZPZ0BUH(QT,L`````(M2!(72=>_'`0````"`OI<#````=">+
MAIP#``#K%(/L#(NXG`,``%#H8?[__XGX@\00.?!UZ,:&EP,```"+AI@#```Y
M\'0,@^P,4.@^_O__@\00BY:P`P``A=)U.8"^@`,```!T#XEU"(UE]%M>7\GI
MF9```(UE]%M>7\G#@^P(:-RC!@AJ#>A:*/[_B<>#Q!#ICO[__X/L#(N.K`,`
M`%;_42R#Q!#KM8/L"&H`4^A7J0``@\00Z:/^__^#[`AJ`%/H1*D``(/$$.GR
M_?__@^P(5VH-Z`TH_O^#Q!#I7?[__Y!5B>575E.#[!B+10B+L*0#``!6Z.CK
M__^#Q!"#^/^)Q[H!````#X2/````BXZ4`@``C8:8`@``A<F)1>P/A8(```!2
M:@!H`"```/]U[.A^I@``@\00QX:4`@```````,>&Z`(```````"-=@"+7A"#
M[`R-5?")7?!2Z)K)`0"#Q!"%P(G#=%"#^/\/A;P```"#[`C_=?!6Z*`X``")
M-"0/OMCH6>O__X/$$(/X_XG'=`2%VW2WN@$```"-9?1;7HG07\G#@^P(:@!0
MZ%FH``"#Q!#I:____X/L#(U%\%#HC<D!`(U=\(F&N`(``(F6O`(``(D<).AV
MR0$`B8;``@``BX;@`@``@\00]L0"B9;$`@``#X3=````BTWP#[<!#[=1`H/!
M!(F&[`(``(F6]`(``(E-\`-^$#M]\`^'[0```#'2C67T6UZ)T%_)PXN&[`(`
M`*@"#X3%````@^P,C7WP5^@*R0$`B9;,`@``BY;@`@``P>H)@^(!@\0,@_H!
MB8;(`@``&<"#X/Z#P`>+CJP#``!0:@!6_U$(@\00A<"Z`0````^$$?___X/L
M#/^VX`(``&H`4_]U[%#HRO'__X/$((7`B8:4`@``N@$````/A.;^__\PTL>&
M?`,```$```")GN@"``#'AO0"````````Z<7^___VQ"`/A#;___^+3?`/MQ&#
MP0*)ENP"``")3?#'AO0"````````Z17___^#R`&)ANP"``#I+?___X/L#%/H
MXL<!`(/$$(7`#X3__O__BWWP,=*)OH@"``#I\?[__XUV`%6)Y5=64X/L#(M=
M"("[6`,```"+?0R+=1!T"8"[EP,```!U*(F;I`,``%"+@ZP#``!J`597:@!J
M`&H#4_]0!(UE]%M>#[[`7\G#B?:#[`A65^C.,@``@\00A<!T#DAUQ%!65U/H
M-S$``.O44%974^A(,```Z\F)]E6)Y5=64X/L#(M="("[6`,```"+?0R+=1!T
M"8"[EP,```!U-(F;I`,``%"+@ZP#``!J`597:@!J`&H#4_]0!(/$(`^^R(7)
MN@$```!T+HUE]%M>B=!?R<.#[`A65^A*,@``@\00A<!T+$AUN%!65U/HLS``
M`(/$$.O(B?:#[`R+LZP#``!3_Q:-9?1;7@^^T(G07\G#4%974^BF+P``@\00
MZY^058GE5U93@>R\#0``BT4(]H#=`@``$,>%?/+__P`````/A8X%``"+50B+
M@B@#``"%P,>"K`,``(#D&`C'`@````#'@MP"````````=0J+DBP#``"%TG19
MBTT(5X7`_[$L`P``#X0/`P``4(M%"`7X`@``4.ALZ___7HM]"/^W*`,``.@U
MC```6XMU"/^V+`,``.@FC```BUT(QX,L`P```````,>#*`,```````"#Q!"+
M50R%TG0(BTT,@#D`=0R+=0B+GA`#``")70R+?1"%_W0(BT40@#@`=12+30B+
MD10#``"%THE5$`^$F@<``(M=%(7;#X0'!0``BT48A<!T"(M5&(`Z`'4,BUT(
MBXL@`P``B4T8BW4<A?9U#(M%"(NX!`,``(E]'(M5((72#X0*!0``BW4(QH:!
M`P```8M5"(L"A<#'ANP"```"````#X7]````BX((`P``A<`/A","``"#^`(/
MA!H"``"+?0B#OP@#```!#X?B`@``BT4<A<#'12``````#X1D!```BTT,A<D/
MA`\'``#_=0S_-<SE&`AHLP```(VU*/___U:)M8#R___H#?4``(/$#&H`:@%J
M`NA/(?[_@\00@_C_B<,/A#0'``!0:@!J`5/H@AL``(VU&/___XM5"(D"_(M%
M(+D$````B??SJUC_=0S&A1G___\"Z"X@_O^#Q!"#^/\/A/$'``")A1S___^+
M30C_L?@"``!J$%93BU4<AO)FB94:____Z,[C__^#Q!"%P`^%@@<``(MU"(L&
MA<`/A`X"``")]H/L"%#_=0CH\!X``(/$$(3`#X7I`P``@^P(:@&+10C_,.C6
M'```BU4(BX+\`@``@\00A<`/A5X#``"+30B+@0`#``"%P'0#B4$HBU4(BX)0
M`P``A<!T`XE"'(M-"(N!^`(``(7`QX'D`@``"@```'06@^P(4/\QZ"@>``"#
MQ!"$P`^%T@<``(/L#/]U".BNY?__@\00@_C_B<8/A*<!``"+30B+41`/MCJ#
M_PJ)N>0"```/A+`#``"#[`B)RO\U:.08"('"4P(``%+H:>8``(M%",>`7`(`
M`-<'``#'!"0*````_[#D`@``_S6\Y1@(:/\!``"#P%-0Z'?S``"#Q""+70CV
M@]T"```0#X1'`0``@^P(_[5\\O__:@WH)"'^_X/$$.DO`0``N`B>&`CIY_S_
M_XGVBWT@A?\/A`4%``"+50R%TG06_+D*````O_>!"`B+=0SSI@^%OOW__XM=
M((7;QT4,]X$("`^$(04``%-J`&H!BQ7(Y1@(:@&)E8#R___H/A_^_X/$$(/X
M_XG&#X2;!0``46H!:@)0Z'$9``"#Q`R+30B)`6IJ:@"-O:C^__]7Z-TA_O^#
MQ`QJ9_]U((V5JO[__U+&A:G^__\!Z.KE``"+10C_L/@"``!J:E=6Z-#A__^#
MQ""%P`^%(08``(M="(L#A<#'@P@#```"````#X7Z_?__Z0_]__^0BTT(@^P(
MQX%<`@``_P<``(L=:.08"/\U7.88"(G(@\!34.@%Y0``6%I3BT4(!5,"``!0
MZ/3D``"#Q!"+70CV@]T"```0#X6Y_O__BTT(BQ&%TG0X,=OV@=T"```0#X7=
M`0``@^P,BTT(_S'H'!D``(MU"(/$$/:&W0(``!`/A:D!``"+10C'``````"#
M[`S_=0CH)1T``(M5"(NZE`(``(/$$(7_C9J8`@``#X7'````4&H`:``@``!3
MZ$6>``!?BWT(QX>4`@```````,>'Z`(```````#_MX0"``#H?H<``%Z+10C_
ML'0"``#H;X<``%N+30C_L7@"``#H8(<``%F+=0C_MHP"``#H48<``(M=)(M-
M"(/$$(7;QX&,`@```````,>!>`(```````#'@70"````````QX&$`@``````
M`'@'B<CHA?/__S'`C67T6UY?R<.-=@"#[`AHW*,&"&H-Z-$>_O^#Q!")A7SR
M___I5?K__XUV`(/L"&H`4^C9GP``@\00Z2;___^0B4(LZ9K\__^+%7#D&`B)
M51SICOO__XGVBWT(B[<8`P``A?:)=10/A>7Z__^#[`QH"YX8".CC&_[_@\00
MA<")110/A<KZ___'113TFQ@(Z;[Z__^0BUT(BXL<`P``B4T@Z>7Z__^-=@"#
M[`R+70C_,^B+%P``BU4(QP(`````65N)T,>"7`(``-@'``"+'6CD&`C_-<#E
M&`CI]?W__XUV`(/L"%-J#>@!'O[_@\00Z43^__^0@^P(:-RC!@AJ#>CI'?[_
MB<.#Q!#I"O[__XUV`(U:`8/L#%/HA.,``(G#@\0,BT`!BTT(B8'0`@``C7L%
M:@B!P8(#``!748F-9/+__^@?XP``BU4(C4L.BWH0B8U$\O__*?F-00&#Q!`Y
M\'<-#[=3#HM%"(F0X`(``(U!$CGP=QV+E43R__\/OD("BTT(B8'P`@``#[="
M`XF![`(``(/#((G9*?F#P0TY\0^&H0$``(M]"(&GX`(``/]___^+50B`NF0#
M````=`R+112`.``/A4(!``"+30B+D30#``"%T@^$U@$``(M]"(N',`,``(7`
MBS58\A@(=`6C6/(8"%=J$&H@BT4(_[`T`P``Z&32``"+50B#Q!"%P(F"D`(`
M`(DU6/(8"`^$[@0``(/L"&H`BU4(*UH04XM%((G3@<.``@``A<!3N0$```!T
M#_RY_____S'`BWT@\J[WT8M5"%&!PGP"``!2OO____\QTOR+?0R(T(GQ\J[W
MT8M="%&!PW`"``!3B[V`\O__B-")\?*N]]%1BTT(@<&$`@``46H`Z`&I``"#
MQ#"%P'0A@^P(:@#_=1#H)84``(MU"(/$$(7`B89T`@``#X5C`@``BT4(@^P(
MQX!<`@``V`<``(L=:.08"/\UP.48".GR^___QT40])L8".E:^/__H6SD&`B%
MP`^$R?C__^GI^O__QT4,]X$(".GE^/__]H+A`@``@`^%L?[__X/L",>"7`(`
M``$(``"+'6CD&`C_-63F&`B)T.F;^___H6SD&`B)12#ITOK__U!J#(MU"%.!
MQHH#``!6Z`WA``"#Q!#I4?[__X/L"(M%",>`7`(``-0'``#_-6CD&`@%4P(`
M`%#H8.```.A'&_[__S"+70B+NUP"``#_-+U@QA@(:/\!``")V(/`4U#H=>T`
M`(/$(.GY^?__@^P(:A!H%9X8".@2A```BW4(@\00A<")AC0#```/A0?^___I
M&/O__XM="(/L"(G9QX-<`@``T0<``('!4P(``/\U:.08"%'HY=\``.C,&O[_
M_S"+?0B+MUP"``#_-+5@QA@(:/\!``")^.N#@^P(BWT(QX=<`@``TP<``/\U
M:.08"(''4P(``%?HH]\``.B*&O[_7O\P_W4,_S6LY1@(:/\!``"+10CI0?G_
M_X/L#(V%A/+__U!H``@``(V]B/;__U>-C8C^__]1_W4,Z!S;``"#Q""%P`^$
MQ08``(M(#(/Y!'8%N00```"+0!!74?\PC94<____4N@A&/[_Z`C;``"#Q!#I
MN/?__X/L"(MU",>&7`(``-('``#_-6CD&`B!QE,"``!6Z`;?``#H[1G^_UK_
M,/]U((M5"(NZ7`(``/\TO6#&&`AH_P$``(G0Z9OX__^+10B#[`C'@%P"``#=
M!P``BQUHY!@(_S74Y1@(Z;#Y__^#[`AJ`/]U%.BA@@``BUT(@\00A<")@W@"
M```/A'S]__^#[`C_M8#R__^+10C_L(0"``#HAMX``%A:_W4,BWT(_[=P`@``
MZ'/>``"+32"#Q!"%R0^$1@(``(/L"/]U((M5"/^R?`(``.A1W@``@\00BU4(
MBT(0@^P(0%#_LH`"``#H.-X``(M5)(M="`N3#`,``(G0#06B``"+?1R+30B#
MQ!"I```!`(FYV`(``'0'B=`-!:("`(MU&(7V=`.#R`B+50B+BN`"``"!R=_U
M__\AP?;%`HE-)`^$CP$``(F-*/___XMZ'(NRD`(``(L>B;TL_____#'`C;TQ
M____N04```"(G3#____SJV:KJHV=2/___XMU$(M%)(M]"(7VB8?<`@``=`R+
M51"`.@`/A7\!``"#[`Q3Z/,H``")'"3H.]X``(M-%(/$$(`Y`(G#C4`!#X0)
M`0``BU4(]H+A`@``@`^$60$``,9#`11248US`O^U9/+__U;HVGH``(/#%H/$
M$(M-&(7)=!"+?0CVA^`"```(#X4_`0``C;4H____*?-04U;_=0CH(AH``(/$
M$(3`=1:#[`S_=0CH"!L``(/$$(3`#X1"`0``BTT(@^P(QX%<`@``W0<``(L=
M:.08"/\UU.48".G$]___@^P(B=/'@EP"``#C!P``@<-3`@``_S5HY!@(4^BS
MW```BTT(BX$P`P``@\00A<!T(X/L#%#_L30#``"+D5P"``#_-)5@QA@(:/\!
M``")R.D\]O__@^P,C;6(\O__5NBEOP``BTT(B30D_[$T`P``B<KI9OW__\9#
M`0"#PP+I%O___XM5"(M"'(B%*O___\'H"(M-)(B%*____XV=+?___\'H"&:)
MC2C___^(A2S____I=/[__XMU",>&?`(```````#IO_W__U%J$%)3Z(?<``#I
M>_[__U?_=13_M63R__]0Z)9S``"#PPKII_[__U%J0/]U&%/H7MP``(U8`5A:
M:A#_=1CHNW\``(M5"(/$$(F"C`(``,=%&`````#ICO[__X/L#/]U".BPVO__
M@\00@_C_#X2K]O__2`^$H@,``/9%)"!T!XM%",9`.`&+=1B%]G1@BUT(48N3
MK`,``#'`:@#\BWT8N?_____RKO?125'_=1AJ`&H`:@+_=0C_4@2#Q""$P`^%
M6?;__X/L#(M5"/^RC`(``.AM?@``6%IJ$/]U&.@=?P``BW4(@\00B8:,`@``
MBTT(BX$D`P``A<`/A,T"``"+&(M`!(T\@XF==/+__XF]</+__XJ)@0,``#G[
MB(UO\O__#X.6`@``BW4(QH:!`P```.GB`0``BT4(B8"D`P``BTT(5XNYK`,`
M`&H!5E-J`&H`:@-1_U<$@\0@#[[8A=L/A;GU__^#[`R+50B+LJP#``!2_Q:#
MQ!"$P`^%G_7__XM%"(NXE`(``(7_#X1O`0``BY"D`P``BXJ4`@``A<F)E6CR
M__\/A'3U__^#NGP#```!#X7]`@``@^P(:C"+O6CR__^+E^@"``"--)54````
M5NC.?```@\00A<")PP^$//7__XNU:/+__X/L"(N6K`,``(UX5(EX%(E04&H0
MBX;H`@``C0R%!````%'HE'P``(/$$(7`B4-$#X2)`@``BY5H\O__B=:->QR!
MQI@"``#\N0@```#SI8N"E`(``(N-:/+__XE#"(NQZ`(``(U#387)B7,\QT-`
M`````(E+&,=#2`````")WL>!E`(```````#'@7P#```"````B8&T`P``B<MT
M)(/L#,>!M`,```````"+B:P#``!3_U$4@\00QX-\`P```````(M>#(7;=!F#
M[`AJ`(U[$%?H@I4``(D<).A^?```@\00BUX(A=MT$8/L"&H`C58<4NABE0``
M@\00BT9$A<!T#(/L#%#H4WP``(/$$(/L#%;H1WP``(/$$(.%=/+__P2+M7#R
M__\YM73R__\/@Z4```"+E73R__^+&C'`_+G_____B=_RKO?1C7'_BTT(@+E8
M`P````^$]?W__X"YEP,````/A.C]__^#[`A64^@W(0``@\00A<`/A#`!``!(
M#X7,_?__4%93_W4(Z)8?``"#Q!#IW?W__XGVZ&/4``"+70B#[`B)WL>#7`(`
M`-4'``"!QE,"``#_-6CD&`A6Z&?8``!8_[6$\O___W4,_S6TY1@(Z<#X__^*
MA6_R__^+30B(@8$#``"+30B`N5<#````=2^+?0CVA]T"```0=0B+10CI1/3_
M_X/L"/^U?/+__VH-Z!\3_O^#Q!"+10CI*?3__X/L#%'HSRP``(/$$(3`=,'I
M`O/__XM5"(M:$(`[_@^%3_S___:"X0(``(`/A$+\__]7_W44_[5D\O__5NAO
M;P``@\0,:@E6_W4(Z,D4``"#Q!"$P`^%N?K__X/L#/]U".BK%0``@\00A,`/
MA:/Z__^#[`S_=0CHE=;__X/$$$`/A>[[___IC?+__XGV4%93_W4(Z(D=``"#
MQ!#IM/S__X/L#%/HE'H``.EG\O__@^P(B=#'@EP"``#>!P``@\!3_S78Y1@(
M4(L=:.08".@WUP``6%I3BX5H\O__Z2KR__^058GE5U93@>S,`P``BW4(@+Z!
M`P````^$.`$``(N&[`(``*@!#X4P`0``BXZ$`@``A<D/A"(!``!0:@!J`&H`
MZ*0;``"#Q!"%P(V=*/S__P^$A0$``%)HA````(V^^`(``%>-C2#___]1Z*8/
M_O^+AMP"```-````@(J6EP,``%#_MGP"``#_MM@"``#_MHP"``#_MG@"``#_
MMG0"``#_MG`"``!3B%6_Z//L__^#Q#"%P`^$[````(J&@`,``%%HA````&H`
M5XA%J.BU$O[_QH:``P```(DT).C^YO__@\0,:+@#``!35N@G#_[_@\00.9Z8
M`P``#X12`0``.9ZD`P``#X0[`0``.9Z@`P``#X0D`0``B?*+AIP#``#K"HGV
MB<*+@)P#```YV'7T@^P,B;*<`P``5N@I#P``,<#'AK@"``#_____QX:\`@``
M_____^M)D(N&[`(``(/L"(/@_HF&[`(``,>&7`(``-8'``"-5E/_-;CE&`A2
MBQUHY!@(Z*/5``!86E.-AE,"``!0Z)35``"#Q!"X`0```(UE]%M>7\G#@^P(
MBXV$_O__C95[_/__B8Y<`@``C4934E#H9=4``%M?C;U[_O__5XV>4P(``%/H
M4-4``.N]4&BX`P``:@!3Z)P1_O]97_\U9.08"(V]>_[__XL-5/(8"%?'A2#_
M__\`````B5W`B5W$B5W,B8VX_O__Z`W5``"#Q!"!C33___^`````QD6_`<=%
MA!````#I'?[__XFVH`,``.G1_O__B;:D`P``Z;K^__^)MI@#``#IH_[__XUV
M`%6)Y5=64X/L#(MU"(I%(/:&W0(``!"(1?._`0```,=%[``````/A<T!``"+
M%H72#X2?`0``BXY\`P``A<ET18/L"(L=:.08",>&7`(``-X'``"-?E/_-=CE
M&`A7Z&O4``!97U.-GE,"``!3Z%S4``"#Q!"-9?1;7KH!````B=!?R<.)]H/L
M",9&4P"-EE,"``#'AEP"````````_S5DY!@(4N@EU```QH9H`@```,>&B`(`
M``````#'AK@"``#_____QX:\`@``_____XDT).@T#0``6%K_=1S_=1C_=13_
M=1`/MD4,4%;H*Q(``(/$((3`#X2\````@;Y<`@``@00```^$=P$``(L.A<ET
M+S';]H;=`@``$`^%B@$``(/L#/\VZ`4(``"#Q!#VAMT"```0#X5=`0``QP8`
M````@^P,5N@6#```BX:4`@``@\00A<"-GI@"```/A>L```!0:@!H`"```%/H
M.8T``,>&E`(```````#'AN@"````````B30DZ!W\__^#Q!"$P'4N@^P(_W4<
M_W48_W44_W40#[9=#%-6Z'`1``"#Q""$P`^%J````)`Q_X!]\P!T;_:&W0(`
M`!!U3XGX#[[0C67T6UZ)T%_)PX/L#%;HQ_O__X/$$(3`N@$````/A$C^__^-
M9?1;7HG07\G#D(/L"&C<HP8(:@WHT0W^_X/$$(E%[.D9_O__B?:#[`C_=>QJ
M#>BW#?[_B?B#Q!`/OM#KGX/L#%;HH-'__XF&U`(``(/$$$`/E,&)S^ET____
M@^P(:@!3Z*F.``"#Q!#I`O___X/L",>&7`(``-8'``#_-;CE&`B-5E-2Z%72
M``"#Q!#I/?___X/L",>&7`(``.0'``#_-?#E&`CKVH/L"%-J#>@Y#?[_@\00
MZ9#^__^#[`AHW*,&"&H-Z"(-_O^)PX/$$.E=_O__58GE5U93@^P,BT4(BYBD
M`P``BXN4`@``,<"%R0^$V@```(.[?`,```$/A=4```"#[`C'@WP#````````
M:C"+L^@"``"-%+54````4NA/=```@\00A<")1?`/A/````"+5?")UHN[K`,`
M`(/&5(EZ4,9"3`&)<A10BX.L`P``_[/H`@``_[.4`@``4_]0"(MU\(/$$(7`
MB48,#X2C````BQ"+>`2+=?")%HE^!(M`#(F3N`(``(F[O`(``(N3E`(``(GW
MB480B58(@\<<C;.8`@``_+D(````\Z6+@^@"``"+3?")03S'@Y0"````````
MQX.T`P```````(G(C67T6UY?R<.#[`B+-6CD&`C'@UP"``#>!P``_S78Y1@(
MC4M34>CFT```6%I6C;M3`@``5^C7T```@\00,<"-9?1;7E_)PX/L#%;H]7,`
M`#'`Z^N#[`B+-6CD&`C'@UP"``#8!P``_S7`Y1@(Z[.)]E6)Y5=64X/L+(M]
M"(M/#(7)#X6!````@'],`'5QBW<8@[Y\`P```@^$G````(I738#Z`1G`@^#<
M!0((``"#[`B+'6CD&`B)AEP"``#_-(5@QA@(C4934.A$T```6%I3C993`@``
M4N@UT```@\00QD=,`8U733F6M`,``,>&?`,```````!T-L='&`````"-9?1;
M7C'`7\G#BT<0A<!T%8MP!(L(B4\0B7=(B?"-9?1;7E_)P\='2`````#K[\>&
MM`,```````#KOH/L#(M'/(M/1(M?%(E%[(E-Z(E=U%;HQ,[__X/$$(/X_W2"
M@_@(#X?2````BU80@#K^#X3.````QT7@`````(M=[(E5\`'".5W@B57<QT7D
M`````.MCD(/L#(U-\%'HE*P!`(/$$(/X_XG!='.+1?")1=B+5=PK5=@YR@^"
MIP```(M%V(M=Z(M5Y(D$DXM=U`'(B0N#PP2)1?")7=2+3>"%R70&BT7@Q@``
MBU7P_T7DBUWLB57@.5WD<IR+1>!`BUWDBTWHBW7@B029Q@8`@P<!BT=$@U<$
M`(E'2.D#____BU74BUWDBT7HQP(`````@\($QP28`````(E5U.N?BU80Z3+_
M__^#^`$/AI;^__\/MTH!#[=:`XF.]`(``(F>[`(``.E]_O__@^P(BQUHY!@(
MQX9<`@``T`<``/\UH.48".E$_O__D%6)Y593@^P0BT4,@_@2BUT(BW40=PK_
M)(7$GA@(C78`C67X6[@!````7LG#A?9T"HL&A<`/A(H!``"!BPP#``"`````
M,<")]HUE^%M>R<.+#C'`B8L(`P``Z^V#[`S_LS0#``#H6W$``%A::A!6Z`UR
M``")@S0#``"#Q!`QP.O(@^P,_[,P`P``Z#9Q``!96&H05NCH<0``@\00B8,P
M`P``Z]F#[`S_LRP#``#H$W$``%A::A!6Z,5Q``"#Q!")@RP#``#KMH/L#/^S
M*`,``.CP<```65AJ$%;HHG$``(/$$(F#*`,``.N3@</X`@``BU,LA=(/A-L`
M``"#[`AJ$%;H>W$``(/$$(7`B47T=!J#[`B-=?16_W,LZ,:G``"#Q!"$P`^$
M&____X/L#/]U].B0<```@\00Z4#___\QP,>#"`,```,```#I^_[__X.+#`,`
M`"`QP,:#50,```'IYO[__XL&B8/X`@``,<#IU_[__XH&B(-D`P``,<#IR/[_
M_X/L"&H05NCU<```@\00B8-@`P``Z>/^__^)@UP#```QP.FB_O__BPXQP(F+
M``,``.F3_O__BQ8QP(F3_`(``.F$_O__@:,,`P``?____S'`Z7/^__^#[`AJ
M$&H4Z$-O``"#Q!")0RQJ!6H`:@10Z"&F``"#Q!#I__[__Y!5B>6+10B+4`2+
M`,G#C78`58GEBT4(BT`\R<.058GEBT4(BX!<`@``R<.)]E6)Y8M%"(/`4\G#
MD%6)Y5934&I4BUT(:@!3BW48Z*((_O^+10R)0S"+31"+512)\(D+B5,$B$,(
MC67X6U[)PY!5B>575E.#[!1J$&I4BW4(BWT0Z*1N``"#Q!"%P(G#=%M0:E1J
M`%/H6`C^_X/$#(M5#(GXB5,PB$,(B3/'0P0`````5H-[,`*X2J$8"'0%N!"?
M&`B-2S104>CV"/[_@\0,_W,,:@16Z.@)_O]:66H#5NC>"?[_B4,,@\00C67T
MB=A;7E_)PXGV58GE4U"+70B%VW04BT,PA<!U%8E="(M=_,GIM6X``)"+7?S)
MPXUV`(/L#%/HJP$``(E="(/$$(M=_,GIE&X``%6)Y8/L".A!!O[_BP#)PY!5
MB>575E.#[`R+?0B+=0R+71#H)0;^_\<``````(L'B5T0B74,B44(@\0,6UY?
MR>DX!O[_58GEBU4(BP*)10C)Z6<%_O^-=@!5B>564XM-"(M!#,'H`H/P`8/@
M`8M5$(I=#(@"BP$Q]H7`>".$VXM1#'4EB="#R`0YT(E!#'004E!J!/\QZ/((
M_O^)QH/$$(UE^%N)\%[)PXG0@^#[Z]F058GEBT4(BT`,P>@"@_`!@^`!R<-5
MB>53@^P@:@2-1?A0:@-J`(M="/\SQT7X"````.@F!?[_@\0@A<!T"[C_____
MBUW\R<.0@^P,:@2-5?12:@%J!O\SQT7T`0```.CY!/[_@\0@A<!TV+C_____
MZ]&-=@!5B>6#[`B+30@QP(-Y,`.*50QT*#'`A-(/E<"#[`R)1?QJ!(U%_%!J
M"&C__P``_S'HLP3^_X/$(,G#B?;'1?P`````R<.-=@!5B>6#[`CHU03^_XL`
M,=*#^"-T$(/X!'0+@_@C=`:)T,G#B?:Z`0```(G0R<.-=@!5B>564XM="(M#
M,#'VA<!U%\=#,`````#'`_____^-9?A;B?!>R<.0@^P(:@+_,^A<!O[_@\00
MA<!U+8/L#/\SZ+L'_O^#Q!"%P'3%QT,P`````,<#_____XUE^+[_____6XGP
M7LG#D+[_____Z\R058GEBT4(@\`TR<.058GEBT4(BT`PR<.058GEBT4(BP#)
MPXGV58GE5U93@^P,BUT(@'L(`(MU#(M]$'0D@^P(:!R?&`A6Z`K)``!FQP<`
M`(/$$#'2C67T6UZ)T%_)PXGVC57P4%*-0R!0_S/'1?`0````Z"D&_O^#Q!"%
MP+H!````==&#[`A6_W,DZ(&I``"#Q!!FBTLBANEFB0_KM8UV`%6)Y8M%"(!X
M"`"+50QT"<<"`````,G#D(M`)(D"R<.058GE@^P,BTT,BT4(BQ"-!(F-#(")
M5?B-%(G!X@-FQT7\`0!FQT7^``!2:@&-1?A0Z`L%_O^#Q!"%P'X,,<#V1?X!
M#Y3`R<.0]]#!Z!_)PY!5B>7)PXUV`%6)Y593@^P,BUT(4XMU#.AH*0``6%IJ
M$(M#&(/`!U#HK&H``(G"@\00A=*)0P2X`0````^$B0```(G1`TL8A?:)2PB)
M,\9#4@#&@V`"````QH-I`@```,=#3`````#'0R0`````QT,@`````(E3$(E3
M#,9#4P#&0S@`QD-0`,=#/`````#'0T@`````QX-<`@```````,>#9`(`````
M``#&@V@"````=!>#[`Q6Z$[^__^)0Q2)-"3HX_S__X/$$#'`C67X6U[)PXUV
M`%6)Y5.#[!"+70C_<P3HDFH``,=#!`````"+7?S)PXGV58GE5E.+70B+10PY
M0QQW),:#8`(```'&@V@"```!QX-<`@``@00``+@!````C67X6U[)PXVP_P\`
M`('F`/#__U%J$(U&!U#_<P3H56P``(/$$(7`=!B-%`:)0PR)0P2)<QB)4PB-
M9?A;,<!>R<.P`<:#8`(```'&@V@"```!QX-<`@``$00``.NCB?95B>564X/L
M%(UU]XM="%9J`/\SZ*3[__^#Q!"%P'0=BT,$QT,D`````,=#(`````")0PR-
M9?A;7LG#B?90_W,8_W,$_S/H*OO__X/$$(7`?^M05FH!_S/H8/O__XM#!,=#
M)`````#'0R``````B4,,@\00C67X6U[)PXGV58GE5U93@^PHBT4(QT7H````
M`/\PZ'[[__^(1>>+50B#Q!"`NF`"```"N/____]T>(!Z.`#&0E`"=7:#[`B+
M=0C&1>T`_W8H_S;HM?W__XMU#(GW`WT0@\00.?YT)HGVB?LI\U!35HM-"/\Q
MZ+OZ__^#Q!"%P(G##X[*`````<8Y_G7<BTT(@'DX``^%.P$``(!][0`/A4D!
M```QP(M-"#G^QD%0``^5P(UE]%M>7\G#@^P(:A"+51"#P@=2Z!IH``"#Q!"%
MP(G&#X0Q`0``C5@'4/]U$/]U#%/H5?[]_X/$#(U%\%"-?1!74^BTG0``@\00
MA,!T!\=%\`````"+5?"(5@2+1?#!Z`B(1@4/MUWRB%X&BTT0B`Z+51#!Z@B(
M5@$/MT42B$8"BWT(BU<DBTT(C5H!B5DDB%8#@T40!XEU#.GT_O__D(/L#(M%
M"/\PZ/_Z__^#Q!"$P'4$A=MU,H!][0!U,L9%[0&-3>]046H!BU4(_S+HQ?G_
M_X/$$(7`#XB.````QT7H`````.G(_O__@'WM`'06A,!T$HM%Z(M="/]%Z#M#
M,`^"K/[__XM5",:"8`(```+&@F@"```!BTT(@'DX``^$Q?[__X/L#/]U#.BE
M9P``@\00@'WM``^$M_[__XU5[E!2#[Y%YU"+70C_,^A(^?__@\00Z9O^__^+
M30C&05``C67T6UZX`0```%_)PX/L#(M5"/\RZ#/Z__^#Q!"$P'02BUWHBTT(
M_T7H.UDP#X(P____BT4(QH!@`@```L:`:`(```'I-/[__U6)Y5=64X/L#(E5
M\(I(.(3)B<.+=0AT#8%X&/___P`/AZ<```"+>PB+4PPIUSG^=GX[4P1T.E!7
M_W7P4NBC_/W_BU,$BTL,*=&#Q`P!^5%24^A:_?__@\00A<"Z`0```'5=BT,$
M`7WPB4,,*?Z*2SB$R70S@?[___\`=BM0:/___P#_=?!3Z"7]__^#Q!"%P'5M
M@47P____`('N____`('^____`'?5.7,8<C2+4PQ15O]U\%+H*OS]_P%S##'2
MC67T6UZ)T%_)PXUV`(M0#(G0*T,$O____P`IQ^E-____5U;_=?!3Z,7\__^#
MQ!`QTH7`#Y7"C67T6UZ)T%_)P[H!````Z[F)]E6)Y5=64X/L#(M="(L#,=*%
MP(M]#(MU$`^$H````('^_O__`'9<B?;&1?#_QD7Q_\9%\O^+2R"#[`R-40&)
M4R")V(A-\XU5\&H$Z*G^__^#Q!"$P'5R@^P,:/___P")^HG8Z)'^__^#Q!"$
MP'5:@<?___\`@>[___\`@?[^__\`=Z:)\8GRP>D(P>H0B?"(1?"(5?*(3?&+
M2R"#[`R-00&)0R"-5?"(3?.)V&H$Z$;^__^#Q!"$P+H!````=!F-9?1;7HG0
M7\G#C67T6UZZ`0```(G07\G#@^P,5HGZB=CH%/[__X/$$#'2A,`/E<*-9?1;
M7HG07\G#58GE4U.+70B+4P2+0PPQR3G"=!DIT%%04E/HD?O__X/$$(7`BT,$
M#Y7!B4,,@'LX`'0&BU,DB5,@#[[!BUW\R<.-=@!5B>575E.#["R+?12+51R-
M7#H!BT4,@?O^__\`BW4(N04```"(1=P/AID```#'1=3^__\`*7W4D,9%V/_&
M1=G_QD7:_XM&((/L#(U0`8E6((A%VXU5V%&)\.A>_?__@\00A,`/A08!``"#
M[`Q7BU40B?#H1?W__X/$$(3`#X7M````@^P,_W74BU48B?#H*OW__X/$$(3`
M#X72````BTW4@>O___\``4T8,?^!^_[__P#'1=3___\`N00````/AW7___^)
M71R(7=C!ZPB(7=G!ZPB(7=J+7B"#[`R-0P&)1B"-5=B(7=N)\%'HS?S__S';
M@\00A,!U<(7_=5:#[`S_=1R+51B)\.BP_/__@\00A,!U58M6!(M&##').<)T
M&2G05U!25NA"^O__@\00BWX$A<`/E<&)?@R`?C@`=`:+5B2)5B"$R74@C67T
MB=A;7E_)PX/L#%>+51")\.A<_/__@\00A,!TE9"[`0```.O9C67T6UZX`0``
M`%_)PU6)Y5=64X/L*(G&_S")5>S'1>0`````QT7@_____^AE]?__@\00@'XX
M`(A%WL=%V`<```!U!\=%V`0```"#[`B+1>S'``````#_=BS_-L9&4`'&1=\`
MZ)GW__^+?D@#?@3'1>@`````@\00BU78A=)T)XGV4/]UV%?_-NAH]/__@\00
MA<")PP^.WP```"E%V`''BU78A=)UVXM5Z(72#X60````BTX$BU9(BT8@.$01
M`P^%NP$``$"`?C@`B48@B48D=!*+7!$$@>/___\`BWWLB1^+5DB+!!$E____
M`(E%X'1>BWWLBP<[1>!S`XM%X`'0.488=S0Y1AP/A^,```#&AF`"```!QH9H
M`@```<>&7`(``($$``"X`0```(7`#X59`0``BTX$BU9(BUW@C3P1B5W8_T7H
M@WWH`0^&*O___X!]WP!T%(U]\E!7#[Y%WE#_-NC8\___@\00QD90`(M%X(UE
M]%M>7\G#B?:#[`S_-NC.]/__@\00A,!U!(7;=2^`?=\`=2_&1=\!C5WS4%-J
M`?\VZ)?S__^#Q!"%P`^(E````,=%Y`````#IN_[__X!]WP!T$X3`=`^+1>3_
M1>0[1C`/@J+^___'1>#_____QH9@`@```L:&:`(```'I7O___XV8_P\``('C
M`/#__U!J$(U3!U)1Z)!C``"#Q!"%P'06C0P#B48,B48$,<")7AB)3@CI!/__
M_[`!QH9@`@```<:&:`(```''AEP"```1!```Z>7^__^#[`S_-N@"]/__@\00
MA,!T#XM-Y/]%Y#M.,`^",____\=%X/_____&AF`"```"QH9H`@```>G5_O__
MQT7@_____^E9____QT7@_____^FW_O__B?95B>575E.#[!R+10B`>#@`#X1%
M`0``BUT(BT,\A<#'1>0`````#X69````QT7H`````#'V,=N)]HG:*?*#^@,/
MAJ,```"+10B+2`2+/#&!Y____P`/A/\!``"-1P0YT`^'@P```(M%Y(7`#X5>
M`0``C70W!('_____``^$$@$``(M5",=%Y`````"+2@2+?0@#3>B)7T0I\RMU
MZ"MUY(U!!(E'$(E?/(U&_(I<`02+=0B(7E'&1`$$`(UE]%M>7\G#C78`B=F+
M6T2)WBG&B77HBU$$BD%1B`0RB=HI\H/Z`P^'7____XGVBU7HA=)U18M%"(E8
M2(U5\.AW_/__B47L0`^$^0```%*-5?!2C4WL48M%"(MX2`-X!%?HF94``(/$
M$(3`#X7%`````UWLZ0;___^)]E$K7>A3BU4(BWH$BTWHC00/4%?HG/3]_RMU
MZ(/$$,=%Z`````#KE(U5\.@1_/__/?___P`/A)\```"+=0B+5DB+30@#402#
M^/^)41`/A#/____&!`(`C67T6UY?R<.+?>B%_\=%Y`0````/A)3^__]0*UWH
M4XM]"(M7!(M-Z(T$"E!2Z"ST_?\K=>B#Q!#'1>@`````Z6K^__]04HM5Z(T$
M$0'PC4@$45#H!O3]_P'^@^L$@\00Z87^__^+70C&@V`"```"QH-H`@```8UE
M]%M>N/____]?R<.+50B+<DB)\#';ZPF-=@"+30B+04@%____`(M]"(E'2(U5
M\(M%".@\^___@</___\`/?___P!TUX/X_W0"`=B+70B)\HES2.D;____@\8$
MZ2S^__^-=@!5B>7)PXUV`%6)Y8/L"(`]-10F"`!T"3'2B=#)PXUV`*"$YA@(
MQ@4U%"8(`:(V%"8(Z.Y:``"$P+H!````==KHT%H``(L5<.08"(72=!V+%6SD
M&`B%TG1L@^P(:@%J#>CP]?W_@\00,=+KKH/L"&@FGQ@(:%JU&`C'!7#D&`CJ
M#```Z-WW_?^#Q!"%P'0/9HM`"(;@#[?(B0UPY!@(@^P,:"J?&`CH&O/]_X/$
M$(7`=)V#[`Q0Z$KX_?^#Q!"C<.08".N*@^P,:`V!"`C'!6SD&`@R@0@(Z.GR
M_?^#Q!"%P`^$<O___Z-LY!@(Z6C___]5B>7)PXUV`%6)Y8/L"(`]-A0F"`!T
M$<8%-A0F"`#&!344)@@`R<.0@^P,:@#H?EL``,8%-A0F"`#&!344)@@`@\00
MR<.-=@!5B>6XE.48",G#B?95B>4QP,G#D%6)Y8/L$&C<HP8(:@WH]O3]_\G#
M58GE5E.+=0B+GI@#``"+`X7`=2!J`&H`:@!J`&H`:@!J`%/H.-#__X/$((7`
MN@$```!T(HF>I`,``%&+LZP#``!J`?]U$/]U#&H`:@!J`U/_5@0/OM"-9?A;
MB=!>R<.058GE5E.+=0B+GI@#``"+`X7`=2!J`&H`:@!J`&H`:@!J`%/HV,__
M_X/$((7`N@$```!T)8F>I`,``%"+@ZP#``!J`?]U$/]U#&H`:@!J`U/_4`0/
MOM"#Q""$TK@!````=`J-9?A;7LG#C78`@^P,BYZL`P``5O\3C67X6P^^P%[)
MPXGV58GE4U"+50B+@J`#``"%P'1>BYB<`P``BP.%P(F:H`,``(F:I`,``'4@
M:@!J`&H`:@!J`&H`:@!3Z#[/__^#Q""%P+H!````=!Q0BX.L`P``:@'_=1#_
M=0QJ`&H`:@-3_U`$#[[0B="+7?S)PXUV`(N:G`,``.N@58GE5E.+=0B+AJ`#
M``"%P`^$@@```(N8G`,``(L+A<F)GJ`#``")GJ0#``!U(&H`:@!J`&H`:@!J
M`&H`4^C"SO__@\0@A<"Z`0```'0?4HN#K`,``&H!_W40_W4,:@!J`&H#4_]0
M!`^^T(/$((32N`$```!T"HUE^%M>R<.-=@"#[`R+GJP#``!6_Q.-9?A;#[[`
M7LG#B?:+GIP#``#I>?___Y!5B>6+10C&@%@#```!R<.058GEBT4(QH!8`P``
M`,G#D%6)Y8M%"`^^@%@#``#)PY!5B>6+10C&@%D#````R<.058GEBT4(QH!9
M`P```<G#D%6)Y8M5"("Z60,````/E,`/ML#)PXUV`%6)Y5.+50B)TP-=##G:
M<Q>+#<#Z&`B)]@^V`O9$`0$#=0I".=IR\3'`6\G#BPW$^A@(#[X$`8/H88/X
M%'<'_R2%Y)\8"+@!````6\G##[9"`8`\`6@/E,(/ML)`6\G#N`(```!;R<,/
MMEH!@#P9:`^4P`^VP-'@6\G#B?95B>564X/L#(M="%.+=0SH^+7__X/$$(/X
M_[H!````=`5(=`PQTHUE^%N)T%[)PY"+0Q"`./YU[/:#X0(``(!TXU#_=1"-
MDX(#``!25NA:3@``@\0,:@E64^BV\___@\00A,!U$(/L#%/HGO3__X/$$(3`
M=$&#[`C'@UP"``#=!P``C8-3`@``_S5HY!@(4.APM@``7EB+LUP"``#_-+5@
MQA@(C4M34>A8M@``N@$```#I</___X/L#%/H3;7__X/$$$"Z`0````^%5O__
M_^E3____D%6)Y5=64X'L#`(``(M%#(7`BWT(BW40#X1G`0``A?8/A&\!``"#
M[`C_=0R-E>C]__]2Z/FU``"#Q!"`/@")PXU0`70\]H?A`@``@`^$GP```,9`
M`12-2`)05HV'@@,``%!1Z&%3``"-0Q:#Q!"+312#[`B%R74:N?2;&`CK$XGV
MQD`!`(M-%(/L"(7)C4`"=.914.B8M0``0(/$#(V-Z/W__XN7K`,``"G(:@%0
M46H`:@!J$5?_4@2#Q!R+GZP#``"-A>C]__]64%?_4SB-EZ@#``")PXD4).C?
MQ?__@\00A=MT*(UE]`^^PUM>7\G#D%!6C8^"`P``45+HV4P``(U#"H/$$.EC
M____B?:#[`S_MW0"``#H2E@``%C_MW@"``#H/E@``%G_MXP"``#H,E@``%A:
M:A#_=0SHXE@``(F'=`(``%E8:A!6Z-)8``"+=12)AW@"``"#Q!`QP(7V=!"#
M[`AJ$/]U%.BS6```@\00B8>,`@``C67T#[[#6UY?R<.-=@"%]L=%#/2;&`@/
MA9+^__^0OO2;&`CIA_[__XGV58GE4U&+70CHK^S]_X7`=1>#[`AH.9\8"%/H
M<;0``(/$$(M=_,G#D.A/[/W_A<!T$E)J$%!3Z-FT``"#Q!"+7?S)PX/L$.AQ
M[/W_B00DZ!GQ_?^#Q!"%P'0$BP#KTX/L#&A.GQ@(Z*'L_?^#Q!"%P'6_@^P,
M:#Z?&`CHC>S]_X/$$(7`=:N#[`QHMX$(".AY[/W_@\00A<!UE[A&GQ@(ZY"-
M=@!5B>6+10C'@&@#``#TK08(QX!L`P``6*P&",>`<`,``+BL!@C'@'0#``#(
MK@8(R<-5B>575E.#[!R+?0B-A_@"``"+=QB!QN\/``"+6'"!Y@#P__^%V\9%
M[P&)1>1T#8M(=(7)#X7C````B?;'AV@#``#TK08(QX=L`P``6*P&",>'<`,`
M`+BL!@C'AW0#``#(K@8(@^P(:@!6Z.%5``"#Q!"%P(E%Z`^$!0$``%.+3>3_
ML8````#_=0R-5?!2_U%P@\00A<`/A9P```!05O]UZ/]U\(M=Y/]3=(/$$(7`
MB<,/C@@!``!04_]UZ%?H"O#__X/$$(3`=-.#[`C_-6CD&`B-CU,"``!1Z-ZR
M``#'AUP"``#=!P``7EC_-=3E&`B-=U-6Z,.R``"#Q!"#[`S_=?"+?>3_5WA;
M_W7HZ-]5```/OD7OC67T6UY?R<.+4'B%T@^$%/___XM`?(7`#X4Q____Z03_
M__]1:@!H])L8"%?HAN___XD\).AV\/__6%K_-6CD&`B-AU,"``!0Z%JR``"#
MQ`QH_P$``(U'4U#_=?"+7>3_4WR)AUP"``#I=____X/L"/\U:.08"(V?4P(`
M`%/H);(``%Y8C7=3QX=<`@``V`<``/\UP.48"%;H"K(``(UE]%M>N`$```!?
MR<-0:@!H])L8"%?H_^[__X/$$(3`=1"#[`Q7Z.?O__^#Q!"$P'1$@^P(_S5H
MY!@(C9=3`@``4NC#L0``QX=<`@``W0<``.B@[/W_@\0,_S"+CUP"``#_-(U@
MQA@(C7=35NC%[OW_Z='^__^%VW@)QD7O`.G'_O__4.DJ____D%6)Y593BW4(
M:@#_=1#_=0S_-NA96@``@\00A<")PW@,C67XB=A;7LG#C78`@^P,QT8$`@``
M`/\U8.D8"/]V"/\UJ/$8"&C_`0``C48,4.AIO@``@\0@C67XB=A;7LG#D%6)
MY5-0BUT(A=MT,(L#A<!Y#HE="(M=_,GI-E0``(GV@^P(:A!0Z.%6``")70B#
MQ!"+7?S)Z1I4``")]HM=_,G#C78`58GE5U93@>R$T`(`C76(BUT(5E/HG^O]
M_X/$$#'2A<`/A;H```!F@WV2`0^'NP````^W19`E`/```#T`H```#X2G````
M46@`\```4XV]B"_]_U?HT.O]_X/L"&HO5^B%ZOW_@\0@,=*%P'1T@^P(Q@``
M5E?H/^O]_X/$$#'2A<!U7@^W39"!X0#P``"!^0!```!U3(/L"&@`\```C9V(
M'_[_4^@@[?W_B3PDZ,CJ_?]86F@`\```C;V(#___5^@%[?W_OE.?&`C\N00`
M``#SI@^4P@^V\HD<).B:ZOW_B?*-9?1;7HG07\G#B?:-9?1;7C'2B=!?R<-5
MB>564X'L"`0``(MU#&H`:`P"``#H7E(``(G#@\00BT4(A=N)&+H!````#X2+
M````@^P,QD,,`,=#!`````")<PA6Z,#^__^#Q!"%P'4YZ'SJ_?^+"(/L#(E+
M!(V5^/O__U%2_S6@\1@(:/\!``"-<PQ6Z*B\``"-9?A;N@$```")T%[)PXGV
M@^P,:@1H])L8"&CTFQ@(5HVU^/O__U;HX'```(/$'&H`:@!6Z.M6``"#Q!`Q
MTH7`B0-X"8UE^%N)T%[)PZ%@Z1@(@^P,B4,$4%;KD%6)Y5-0BUT(A=N+50QT
M%E#_=1"-0PQ04NAWKP``BT,$BUW\R<.#[`C_-<#E&`A2Z-RN``"XV`<``(M=
M_,G#B?95B>6+50B+10R+31")@F@#``"+112)BFP#``")@G`#``"+31B+11R)
MBG0#``")@G@#``#)PXUV`%6)Y5>#[`B+?0S\,<"Y______*N]]%)4?]U#/]U
M".A)Q/__BWW\R<-5B>575E.!["P$``")QHL`A<#&A>/[__\!=1]J`&H`:@!J
M`&H`:@!J`%;HN<3__X/$((7`#X3\`0``,<#\5[G_____OUB?&`CRKO?125%H
M6)\8"%;HZ\/__X/$$(7`#X5X`0``@^P,5NCWV___@\00A<")A>3[__\/A%X!
M``"#[`S_M>3[___H8.'__X/$$(/X!0^$[0$``(/X!P^%<P(``,>%W/O__P$`
M``#'A=C[__\$````Z>H```")]HMX"(M0#(/L#(M8!(F5U/O__XN5V/O__XF=
MT/O___\TD.A*Z_W_B87,^___QP0D`````.BHNO__@\00A<")PP^$$P(``(/L
M"(7_:@")^`^$Y`$``%#H2E$``%]:B8,4`P``:@"+A=3[__^%P`^$J@$``%#H
M+%$``%I9B8,8`P``BX7,^___B8,$`P``:@"+A=#[__^%P`^$9`$``%#H`E$`
M`(F#$`,``(N&C`(``(/$$(7`#X4K`0``BX8@`P``A<`/A1T!``"%V\:#EP,`
M```/A((!``"+OIP#``")NYP#``")GIP#``"#[`S_M>3[___H'MS__X/$$(7`
M#X10`0``BXW<^___A<D/A?'^__^+OG0"``"+EG@"``#IYO[__U-H_P$``(U>
M4U.-O>C[__]7Z`*M``"#Q`QH_P$``/\U_.48"%/H[JP``(G#*?.Z4@(``(/$
M#"G:4E=0Z-BL``"#Q!#'AEP"``#G!P``C67T6UZX`0```%_)PU!H_P$``(U>
M4U.-O>C]__]7Z*BL``"#Q`QH_P$``/\U!.88"%/HE*P``(G!*?&Z4@(``(/$
M#"G*4E=0Z'ZL``"#Q!#'AEP"``#I!P``ZZ3'A=S[__\`````QX78^___`@``
M`.D&____B?:#[`AJ`%#HM4\``(/$$(F#(`,``.G*_O__C78`BX9P`@``A<`/
MA8[^__^+AA`#``#I@_[__XUV`(N&>`(``(7`#X5(_O__BX88`P``Z3W^__^-
M=@"+AG0"``"%P`^%#O[__XN&%`,``.D#_O__QH7C^___`(NUY/O__X7V=!&#
M[`S_M>3[___HQ*S__X/$$`^^A>/[__^-9?1;7E_)PXGV58GE5U93@>P@`@``
M,<#&A>?]__\!_+G_____OVF?&`CRKO?125%H:9\8"/]U".C1P/__@\00A<!U
M:H/L#/]U".C?V/__@\00A<")QG16@^P,4.@YVO__@\00A<")PW0*BP"%P`^%
MG@```(M="(F;F`,``(G8Z$;\__^$P'4'QH7G_?__`(7V=`R#[`Q6Z!ZL__^#
MQ!`/OH7G_?__C67T6UY?R<-3:/\!``"+?0B#QU-7C;7H_?__5NCWJ@``@\0,
M:/\!``#_-?CE&`A7Z..J``")P2M-"+M2`@``@\0,*<M35E#HS*H``(M5",>"
M7`(``.8'``"#Q!"-9?1;7K@!````7\G#C78`@#@`#X19____@^P,5NB2W?__
M@\00@_@"N@$```!W$(72#X56____BT4(Z3[___^#[`R+`XF%X/W___]S".BB
MY_W_QP0D`````(G'Z`2W__^#Q!"%P(G##X2U````@^P(:@"+50B+@G0"``"%
MP'4&BX(4`P``4.B=30``6EF)@Q0#``!J`(M5"(N">`(``(7`=0:+@A@#``!0
MZ'I-``!:68F#&`,``(F[!`,``&H`BX7@_?__A<!T9%#H6DT``(M5"(F#$`,`
M`(N"C`(``(/$$(7`=2B+30B+@2`#``"%P'4;A=O&@Y<#````=":+?0@QTHF?
MF`,``.DC____@^P(:@!0Z!%-``"#Q!")@R`#``#KS[H!````Z0/___^+50B+
M@G`"``"%P'6/BX(0`P``ZX>-=@!5B>564XMU"(N&F`,``#GP=`V`N)<#````
M#X2Y````@^P,:@#H][7__XG#@\00,<"%VW1WBT44@^P(A<!J``^$O````%#H
MFDP``%I9B8,4`P``BT48A<!J``^$O0```%#H?TP``%I9B8,8`P``BT40B8,$
M`P``BT4,A<!J`'1M4.A?3```B8,0`P``BX:,`@``@\00A<!U*(N&(`,``(7`
M=1[&@Y<#````B=B%P(F&F`,```^4PHUE^%L/ML)>R<.#[`AJ`%#H&4P``(/$
M$(F#(`,``.O,B?:#[`Q0Z,>X__^#Q!#I-O___XUV`(N&<`(``(7`=8F+AA`#
M``#K@8GVBX9T`@``A<`/A3;___^+AA0#``#I*____XUV`(N&>`(``(7`#X4U
M____BX88`P``Z2K___^-=@!5B>564X/L#(MU"&H`Z-:T__^#Q!"%P(G##X2Y
M````@^P(:@"+112%P`^$M0```%#H=TL``%I9B8,4`P``:@"+11B%P`^$M@``
M`%#H7$L``%I9B8,8`P``BT40B8,$`P``:@"+10R%P`^$K@```%#H.$L``(F#
M$`,``(N&C`(``(/$$(7`=3&+AB`#``"%P'4GA=O&@Y<#````=#R+EIP#``")
MDYP#``")GIP#``"-9?A;,<!>R<.0@^P(:@!0Z.E*``"#Q!"%VXF#(`,``,:#
MEP,```!UQ9"-9?A;N`$```!>R<.+AG0"``"%P`^%/?___XN&%`,``.DR____
MC78`BX9X`@``A<`/A3S___^+AA@#``#I,?___XUV`(N&<`(``(7`#X5$____
MBX80`P``Z3G___^-=@!5B>6+30B+44`QP#M1/',-C022P>`$0@-!"(E10,G#
MD%6)Y5-0BUT(BU-(,<"%TG0*BT,,A<!U"(M#%(M=_,G#4(M+4/]S/%+_<Q3_
M41"#Q!"+0Q3KY8GV58GE5E.+=0B+1@PQVX7`="N+50R#PO^+31"#T?^+6`R)
MT"'(0'05D(7;=!"#PO^#T?^)T"'(0(L;=>V0QT9(`````(E>$%M>R<.)]E6)
MY8M5"(M-#(M"$,="2`````")2A#)PU6)Y8M5"(M-#(M"0(E*0,G#C78`58GE
M5U93@>P4`0``:'N?&`B-M>C^__^+70Q6Z)2E``"#Q!"%VXG?=`6`.P!U.OQ0
MN?____\QP(GW\J[WT4E15O]U".A`N___@\00,=*%P'4-@^P,_W4(Z$S3__^)
MPHUE]%M>B=!?R<.#[`AHBI\8"%#H/J4``(H+@\00A,F)PG0PC47B.<)R'NL]
MB?:`^2=T&HH/B`I'B@="A,"(P70<C5WB.=IS#8#Y7'7AQ@)<0NO@B@.$P'0$
MQ@(E0L8")\9"`0#I9____XC(Z^B058GE5U93@>P4`0``:)*?&`B-M>C^__^+
M70Q6Z,BD``"#Q!"%VXG?=`6`.P!U.OQ0N?____\QP(GW\J[WT4E15O]U".AT
MNO__@\00,=*%P'4-@^P,_W4(Z(#2__^)PHUE]%M>B=!?R<.#[`AHBI\8"%#H
M<J0``(H+@\00A,F)PG0PC47B.<)R'NL]B?:`^2=T&HH/B`I'B@="A,"(P70<
MC5WB.=IS#8#Y7'7AQ@)<0NO@B@.$P'0$Q@(E0L8")\9"`0#I9____XC(Z^B0
M58GE4X/L"(M="(N3X`(``,'J"8/B`8/Z`1G`@^#^@\`(4&H`4^ABKO__B<*#
MQ!`QP(72="&+`H/L#(F#Z`(``/^SX`(``&H!4(V+F`(``%%2Z%:J__^+7?S)
MPY!5B>575E.!["`!``!H@````(M%$(7`#X34````4(/L"&B`````_W4,C;78
M_O__5N@0I```0(/$%%#H!J0``(G#6/]U".A3H?__@\0,BU4(BX*L`P``*?-J
M`5-6:@!J`&H$4O]0!(/$((3`=7B#[`R+30B+N:P#``!1_U<8@\00A<")PW1?
M@^P(:C!J5.C#10``B<*#Q!`QP(72=#Z+30B)SHN!K`,``(UZ'('&F`(``/RY
M"````/.EBWT(B4)0BX?H`@``QX>4`@```````(E"/(E:",9"3`&)T(UE]%M>
M7\G#B?:-9?1;7C'`7\G#B?:X])L8".DB____B?95B>564X/L%(M="(N#K`,`
M`&H`:@!J`&H`:@!J"E/_4`2#Q"`QR83`#X6/````@^P,4^AIH/__C77TBU,0
MB57TB30DZ)Q_`0")QHN#X`(``,'H"8/@`8/$#(/X`1G)@^'^@\$'BY.L`P``
M46H`4_]2"(/$$#')A<!T0X/L#/^SX`(``&H`5HV+F`(``%%0Z,&H__^#Q"`Q
MR87`B8.4`@``=!N#[`S'@WP#```!````B;/H`@``4^C]S___B<&-9?A;B<A>
MR<.)]E6)Y8/L#(M-#(M5"(A-_XN*K`,``&H`:@&-1?]0:@!J`&H(4O]1!`^^
MP,G#58GE@^P,BTT,BU4(B$W_BXJL`P``:@!J`8U%_U!J`&H`:@=2_U$$#[[`
MR<-5B>6#[`R+30R+50B)3?R+BJP#``!J`&H$C47\4&H`:@!J#%+_400/OL#)
MPU6)Y8/L#(M-#(M5"&:)3?Z+BJP#``!J`&H"C47^4&H`:@!J&U+_400/OL#)
MPXUV`%6)Y8/L#(M%"(N0K`,``&H`:@!J`&H`:@!J#5#_4@0/OL#)PU6)Y5-3
MBUT(BT,0BY/4`@``Q@00`(M#$(`X`'0'BUW\R<.)]H/L"(V+4P(``/\U:.08
M"%'HZZ```,>#7`(``-D'``!:6?\UQ.48"(/#4U/HT*```(G8BUW\R<.058GE
M4X/L"(M="(N#K`,``&H`:@!J`&H`:@!J"5/_4`2#Q""$P'0)C4-3BUW\R<.0
MBY.L`P``BTHPB5T(BUW\R?_AB?95B>6#[`R+10B+D*P#``!J`&H`:@!J`&H`
M:@Y0_U($#[[`R<-5B>6+10B+@(`"``#)PXGV58GE5U93@^P0C5WP:@J+50A3
M_[*``@``Z*_9_?^#Q`QJ"HM-\$%348G'Z)W9_?^#Q`QJ"HG&BT7P4T!0Z(O9
M_?^-%+^-/)*-'+:--+^-#)N-'+:-9?3!XP2-%(M;7HT$`E_)PU6)Y8M%"(N`
MA`(``,G#B?95B>6+10B+@.0"``#)PXGV58GEN)Z?&`C)PXGV58GEN*^<``#)
MPXGV58GEBT4(#[Y`3,G#58GEBT4,C02`BU4(P>`$`T((R<-5B>6+10B+0`C)
MPY!5B>6+10B+0!#)PY!5B>6+10B+0$#)PY!5B>6+50B+@J0#``"+@.@"``#)
MPU6)Y8M5"(N"I`,``(N0O`(``(N`N`(``,G#B?95B>6+50B+@J0#``"+D,0"
M``"+@,`"``#)PXGV58GEBT4(!5,"``#)PXUV`%6)Y8M%"(N`]`(``,G#B?95
MB>6+10B+@(@"``#)PXGV58GEBT4(BX#0`@``R<.)]E6)Y8M5"(N"D`(``(M`
M$,G#C78`58GE,<#)PY!5B>4QP,G#D%6)Y8M-"*&$Y1@(B4$LH8#E&`B+%8SE
M&`B)02BAB.48"#G0B5$8QT$P`0```',"B=")01S)PXGV58GEBU4,5E.+30B)
MTXG.`UT0ZR.*`L#H!`^VP(J`H/(8"(@!#[8"@^`/BH"@\A@(B$$!0H/!`CG:
M<MG&`0!;*?&)R%[)PXGV58GE@^P(_W40_W4,_W4(_S54\A@(Z$:1``#)PU6)
MY8M5"(N"D`(``(E%",GI+Y$``(UV`%6)Y5=64X/L#(M=#(M]"(G8`T40BX^0
M`@``@^@%BU%8BW44B47PBT($A<")]P^51>\#?1@Y_G0\.UWP#X./````@'WO
M``^%O0```(H6#[["@_@:#X3G````?R6#^`H/A.L```!_.87`=%>)]H@31D,Y
M_G7$C67TB=A;7E_)PXGV@_@G#X35````?R6#^")UW,8#7,9#`2*#PP*)]D;K
MT8/X#77(Q@-<QD,!<H/#`NOL@_A<=;?&`US&0P%<@\,"Z]O&`US&0P$P@\,"
MZ\^-=@")^2GQ@<$``@``B4T0C5404%)3_W4<_U4@@\00A<")PW1[`T40@^@%
M@'WO`(E%\`^$1O___XUV`%"+10B+B)`"``"+45A75E'_4@2#Q!"%P`^$)?__
M_XU0_^L(D(H.B`M&0TJ#^O]U]$Y&Z3'___^0Q@-<QD,!6H/#`NE-____Q@-<
MQD,!;H/#`ND^____Q@-<QD,!)X/#`NDO____C67T6UXQP%_)PY!5B>575E.#
M[`R+=0B+CI`"``"+45B+0@2%P`^51?.`??,`BUT,=`^)WX`[`.L&B?9'@#\`
M=?J*`X3`B=YT%HGV@'WS`'4J/%QT%H@&1D.*`X3`=>S&!@"-9?1;7E_)PY"`
M>P$`=.1#B@.(!D;KWXGVBTT(4(N!D`(``(M06%=34/]2!(/$$(7`=!J-4/_K
M")"*`X@&0T9*@_K_=?1+0XH#ZZZ)]HH#ZYY5B>564XM5#(M="(M%$(72BW44
MB8.,````=`6`.@!U&(V+G`(``(EU#(E-"(UE^%M>R>FUFP``D(/L"%*-DYP`
M``!2Z*2;``"-BYP"``")=0R)30B#Q!"-9?A;7LGIBIL``(GV58GE5U93@^P8
MBT4(BYBD`P``4XM]#.AUFO__@\000+H!````#X2I````BTL0BW$!#[=1!XFW
MB`````^W<06#P0F%THE5[(E-\`^%D0```(7V=&6+@^P"``"H`@^$JP```(/L
M#(U5\%+HDW@!`(/$#(F#R`(``(F3S`(``(N#K`,``&H':@!3_U`(@\00A<"Z
M`0```'0]@^P,_[/@`@``:@!65U#H;Z'__X/$((7`B4<XN@$```!T&XM-[(FW
ME````(F/D````#'2QX/T`@```````(UE]%M>B=!?R<.-=@!0BX.L`P``:@=J
M`%/_4`B#Q!"%P+H!````=-B#[`Q0Z.B7__^#Q!#I0____X/(`8F#[`(``.E'
M____B?95B>564X/L"&HP:*@"``"+=0CHZ3P``(/$$(7`B<-T:%!H``@``&@`
M"```4^@35```@\0,:``0``!H`!```(U33%+H_5,``,=#6`P```!:68U#(%#_
MMJ@#``#H/7D``(F&J`,``(E;*,>#F`````$```")<RS'@X0```#`T08(B=B-
M9?A;7LG#4/\U:.08"&C8!P``5NAJE___,<#KXXGV58GE5U93@^P,BUT(@[N8
M`````8US/'Y0BT8,A<"+>RQU4H7_="Z+BY0```"%R70D@[N8`````GX;C;.E
M`@``.;>T`P``='N+AWP#``"%P'55C78`QX.8`````@```,>#A````,#1!@B-
M9?1;7C'`7\G#B?:#[`AJ`8U33%+H>E4``(/$$,=&#`````#'0SP`````QT-`
M`````,=#<`````#I?/___X/L#(N7K`,``%?_4A2#Q!#'AWP#````````ZY+'
MA[0#````````Z7;___^-=@!5B>575E.#[`R+=0B+7BR%VP^$&@(``(.^F```
M``$/CJ\```"-?CR+1PR%P`^%'@$``(N.E````(7)=!"#OI@````"#X\[`0``
MC78`@^P(QX:8`````@```,>&A````,#1!@C&AJ0"````QH:C`@```,>&E```
M``````#'AI``````````QX:,`````````,:&G`````!J`5;HBE0``(N&B```
M`(/$#(E%\(N+K`,``&H!:@2-??!7:@!J`&H94_]1!(/$((3`=2['AI@````!
M````48N[K`,``&H!_W40_W4,:@!J`&H64_]7!(/$((3`#X3-````B=B+DUP"
M``"#P%.-NU,"``")EHP```!T!H![4P!U(H/L"%>-EIP"``!2Z-*7``"#Q!"X
M`0```(UE]%M>7\G#B?:#[`A0C9Z<````4^BPEP``@\00Z\F-=@"#[`AJ`8U6
M3%+HRE,``(/$$,='#`````#'1CP`````QT9``````,=&<`````#IL/[__XGV
MC;ZE`@``.;NT`P``#X3C````BX-\`P``A<`/A*C^__^#[`R+DZP#``!3_U(4
M@\00QX-\`P```````.F)_O__D(/L"(N#K`,``%93_U`<@\00A,`/A1K___^+
MOI0````#OI````"-#/T`````*?F#[`C!X0-15N@54@``@\00A<")P8E&,'13
MBX:0````C3S%`````"G'C1SY,<")7C3'AI@````"````Z?W^__^#[`C'AHP`
M``#=!P``BQUHY!@(_S74Y1@(C8:<````4.BBE@``6%I3Z;S^__^#[`C'AHP`
M``#8!P``BQUHY!@(_S7`Y1@(Z]''@[0#````````Z0[___]5B>564XMU"(N.
ME````#'`A<ET-H/L"&HP:E3HY#@``(/$$(7`B<)T*(M.+(N9K`,``,9`3`&)
M6%"+CI0```"+1CB)0@B)2CR)T(UE^%M>R<.#[`C'AHP```#8!P``C9:<````
M_S7`Y1@(4HL=:.08".CZE0``6%I3C8:<`@``4.CKE0``@\00,<#KOE6)Y3'`
MR<.058GEBT4,BU4(BT`(BTH,B@"(`?]"#,G#58GEBU4,BTT(BT((9HL0BT$,
M9HD0@\`"B4$,R<.-=@!5B>6+50R+30B+0@B+$(M!#(D0@\`$B4$,R<.058GE
MBTT,4XM!"(M="(L0BT@$BT,,B1")2`2#P`B)0PQ;R<.058GEBTT,BU4(BT$(
MBP"+2@R)`8-"#`3)PXUV`%6)Y8/L"(M5#(M""(M0!(L`BTT(B47XB57\BT$,
MBU7XB1"+5?R)4`2#P`B)00S)PU6)Y593@^P0BTT,BU$(@'H<``^51>F+0@R+
M6@B(1>Z+2A"(3>^)7>J+6A2(7?"+0AB)1?&+2AB%R8MU"+@,````=2:+6@R%
MVW4:BTH0A<EU$XM:%(7;=0R+2@@PP(7)=`B-=@"X"````(U8`5)3B$7HC47H
M4/]V#.B'S?W_`5X,C67X6U[)PY!5B>564X/L$(M=#(M3"(M*!,="&`````"+
M`L="%`````#'0A``````QT(,`````(A-ZXM:"(A=[&:)1>F+0@R(1>V+2A"(
M3>Z+6A2(7>^+0AB)1?"+2AB%R8MU"+@+````=3&+2@R%R75.BT(0A<!U1XM:
M%(7;=4"+"H7)=1"+0@2%P'4)BUH(,<"%VW0&N`0```"0B$7HC5@!4E.-3>A1
M_W8,Z-3,_?\!7@R#Q!"-9?A;7LG#C78`N`<```"(1>B-6`%24XU-Z%'_=@SH
MJ\S]_P%>#(/$$(UE^%M>R<.)]E6)Y593@^P0BUT,BU,(BTH$BP*(3>N+6@B(
M7>QFB47IBT(,B$7MBTH0B$WNBUH4B%WOBT(8B47PBTH8A<F+=0BX"P```'4Q
MBTH,A<EU3HM"$(7`=4>+6A2%VW5`BPJ%R740BT($A<!U"8M:"#'`A=MT!K@$
M````D(A%Z(U8`5)3C4WH4?]V#.@0S/W_`5X,@\00C67X6U[)PXUV`+@'````
MB$7HC5@!4E.-3>A1_W8,Z.?+_?\!7@R#Q!"-9?A;7LG#B?95B>575E.#[!"+
M=0R+/C'2BQ]24XM-"/]Q#.BQ<`$`@\0,4_]V"(G'4.BJR_W_C00?BU4(B4(,
MC67T6UY?R<.058GE5U93@^P\BT4(BY"0````A=(/A((```"`N*,"````BW@L
M=%J+AWP#``"%P`^$]````(M5"(/L"(L=:.08",>"C````-X'``#_-=CE&`B)
MT`6<````4.A/D@``7UA3BTT(@<&<`@``4>@]D@``@\00N`$```"-9?1;7E_)
MPY"#[`B+'6CD&`C'@(P```#O!P``_S4<YA@(Z[>0BTT(BX&(````BUDLB9ND
M`P``B47(QD7,`,=%S0$```!6:@%J`&H`:@F-?<A7:A=3Z`^]__^#Q""$P`^$
MA`$``(G8BY-<`@``BTT(@\!3C;-3`@``B9&,````=`J`>U,`#X4>`0``@^P(
M5HM]"(''G`(``%?HEY$``+@!````@\00#[[`C67T6UY?R<.#[`Q7Z+?*__^+
M=0B+GI````"+3PR#PP>)SL'K`RMW!(U4,P&#Q!`QP#M7&`^'K````(3`#X7:
M````5E-J`%'HG,W]_XG9BUT(B[.0````C03U`````"GPBU,P`T\,C33"B4\,
MB77$BH.B`@``B`&+5PQ"B56\B5<,@\00@+NB`@````^$^@```(N+D````(M=
MO"M?!(T$2S'2.T<8#X?``0``A-)U;8M5"(M:,#M=Q(G9#X/.`0``BT<,D(!Y
M*`"+40QT`X#.@(/!.&:)$(/``CM-Q(E'#'+CZ:L```"#[`A25^A,R?__BT\$
M`?&#Q!")3PSI.O___X/L"(G+4('#G````%/H>I```(/$$.G(_O__B?:+AUP"
M``"+50B#[`B+'6CD&`B)@HP```#_-(5@QA@(Z?#]__^#[`R+LZP#``!3_Q:#
MQ!"$P`^%9?[__XN[N`(``(N3O`(``(M-"(EY=(E1>(N#P`(``(NSQ`(``(E!
M?#'`#[[`B;&`````Z77^__^+=0B+7C`[7<2)WG(8Z?$```"-=@#&1BD`@\8X
M.W7$#X/8````@'XI`'7JBTT(BU$LB57`BUX$@#L`="6+3B")R[@!````@^$'
MP>L#BU($T^`(!!HQP(7`=+_I:/W__XGVBU7`BP:+6@PK6@2+"(T$"XM-P#'2
M.T$8#X<[`0``A-)T2XM5"(M=P(N+7`(``(/L"(G0BQUHY!@(B8J,````!9P`
M``#_-(U@QA@(4.A/CP``6%I3BUT(@<.<`@``4^@]CP``@\00N`$```#KB(/L
M"%;_=<#_5BR#Q!#I=/___X/L"%!7Z,?'__^(P@-?!(/$$(E=O(E?#.DC_O__
MBW<,B76\BW6\*W<$4&H`5O]W!.@T,@``@\00A<")QP^$^@```(M5"(N*B```
M`(M:+(F;I`,``(E-V,9%W`#'1=T!````4&H!5E=J"8U%V%!J%U/HX+G__X/$
M((3`='N+@UP"``"+30B)@8P```")V(/`4XVS4P(``'0*@'M3``^%NP```(/L
M"%:+30B!P9P"``!1Z&R.``"#Q!"X`0```(MU"(/L#(C#QH:B`@```%?H@S$`
M``^^P^D2_/__@^P(4%'H[<;__XM-P`-9!(/$$(C"B5D,Z:C^__^#[`R+LZP#
M``!3_Q:#Q!"$P`^%;O___XN3N`(``(N+O`(``(MU"(E6=(E.>(N#P`(``(N3
MQ`(``(E&?#'`B9:`````ZX&+10B#[`B+'6CD&`C'@(P```#8!P``_S7`Y1@(
MZ6K[__^#[`B)RU"!PYP```!3Z+*-``"#Q!#I*____XGV58GE4XM-"(M1<(72
MBUT,=`^+0@2)`XL"B4%P6S'`R</'`P````"X9````%O)PXGV58GE5U93@^P,
MBWT(BW<LA?:+70S'1?`!````#X3H````@[Y\`P```71BBH^E`@``@/D!&=*#
MXMR!P@((``"#[`B)EXP```"-AYP```#_-)5@QA@(4(L=:.08".@8C0``6%I3
MC8^<`@``4>@)C0``@\00C8>E`@``.8:T`P``=#R+1?"-9?1;7E_)PY"#[`B+
MAJP#``!35O]0*(/$$(7`=2>+$S'`A=)UVL>&?`,```````#'1?!D````Z[;'
MAK0#````````Z[B)\(N67`(``(/`4XV>4P(``(F7C````'0&@'Y3`'5C@^P(
M4XV?G`(``%/H@8P``(/$$,>&?`,```````#I:?___X/L",>'C````-T'``"-
MEYP```#_-=3E&`A2BQUHY!@(Z$J,``!97E.-AYP"``!0Z#N,``"#Q!"X`0``
M`.DY____@^P(4(V/G````%'H'HP``(/$$.N(D%6)Y593BW4(@[Z8`````;AD
M````?SR#[`C'AHP```#N!P``C9:<````_S48YA@(4HL=:.08".C=BP``6%I3
MC8:<`@``4.C.BP``@\00N`$```"-9?A;7LG#C78`58GEBU4,A=*+31"X`0``
M`'43,=*%R70"BA&+10B(D*8"```QP,G#D%6)Y8M-#(7)N`$```!U$8M-"(M%
M$`^^D:8"``")$#'`R<.)]E6)Y5=64X/L#(M]"(M?+(7;#X2/`@``@[^8````
M`8UW/'Y5BTX,A<D/A48"``"+MY0```"%]G0L@[^8`````GXCC9>E`@``.9.T
M`P``#X2S`@``BXM\`P``A<D/A88"``"-=@#'AY@````"````QX>$````P-$&
M"(/L#(NSK`,``%?_5B"#Q!"%P+H!````#X61````BY/H`@``A=)T48N?E```
M`(7;#X2#````BW<LC12;P>($BXZ4`@``C30*.?&+5SAS,(GVBUE(BT$<B5I(
MBUE,B4(<B5I,BT%`BUE$@\%0B4)`B5I$@\)0.?%RV(N?E````(7;QX>8````
M`P```'0@BT\LC9>E`@``B9&T`P``QX>$````8-`&",:'I0(````QTHUE]%M>
MB=!?R<.+=RR+GJ0#``"+@^@"``"-#("#[`C!X02)AY0```!15^@W10``@\00
MA<")1SATD8N/E````(T4S0`````IRH/L",'B`U)7Z!%%``"#Q!"%P(E'-`^$
M9____XN;E`(``(E=\(N?E````(T$F\'@!(MW.`-%\(7VB47L#X1'____.47P
M#X,^____ZR.)1AC'1B``````@T7P4(/&4`^$'____XM%[#E%\`^#$____X/L
M"(M5\/]R$%?H1$@``%M:BUWPB480_W,(5^@S2```6EF+3?")1@C_<0Q7Z")(
M``!96XE&#(M%\/\P5^@22```6UJ+5?")!O]R!%?H`D@``(M5\(M:2(M*'(E&
M!(E>2(M"3(M:0(E.'(M*1(M2&(/$$(E&3#'`A=*)7D")3D0/A%C___^#[`A2
M5^C$1P``@\00Z4;___^#[`AJ`8U'3%#H'D4``(/$$,=&#`````#'1SP`````
MQT=``````,='<`````#IB/W__X/L",>'C````-T'``"-EYP```#_-=3E&`A2
MBQUHY!@(Z*6(``!86E.-AYP"``!0Z):(``"#Q!"Z`0```.D__O__@^P,BX.L
M`P``4_]0%(/$$,>#?`,```````#I7OW__\>#M`,```````#I/OW__XUV`%6)
MY8M%"(N`D````,G#B?95B>6+10B+4'B+0'3)PXGV58GEBT4(BX"4````R<.)
M]E6)Y8M%"(N0@````(M`?,G#C78`58GE5U93@^P,BU4(BX*0````A<"+=0S'
M1?``````=1B#NI@````!#XZA`0``C67T6UY?R<.-=@"-#,4`````*<&+70C!
MX0/!Z0*+>S#\\Z6+?0B+EY````"---4`````BTLP*=:-%/$YT0^#I````(U9
M$.M(C78`@_@##X0G`0``#X?E````@_@!#X2Q`0``@_@"#X6_`0``B=B)6_#'
M`P(```#'0QP4R`8(D(7`=0.)6_"#P3B#PS@YT7-7BT/TBW7P_T7PA<")<Q#&
M0QD`=0?'0_0T%"8(BT/\@_@'=%!VEH/X"P^$I0```'=;@_@(#X0T`0``@_@*
M#X59`0``BT/PQT,<2,D&",<#!0```.N;C78`BWT(QH>B`@```<:'HP(```&-
M9?1;7C'`7\G#D(M#\,=#'"C*!@C'`PP```#I9____XUV`(/X#'3C+?D```"#
M^`4/A_T```"+0_#'0QSLR@8(Z4+___^)]H/X!0^$G@```'=(B=B)6_#'`P0`
M``#'0QQTR`8(Z1[___^)]HM#\,=#',#(!@C'`PT```#I!____XUV`(G8B5OP
MQP,$````QT,<-,@&".GM_O__BT/PQT/TD.48".G>_O__@^P(B=&+'6CD&`C'
M@HP```#N!P``@<&<````_S48YA@(4>@?A@``7UA3BT4(!9P"``!0Z`Z&``"#
MQ!"X`0```.D:_O__B=B)6_#'`P@```#'0QR0R`8(Z8+^__^)V(E;\,<#"```
M`,=#'%#(!@CI:_[__XG8B5OPQP,!````QT,<_,<&".E4_O__@^P(_S5HY!@(
MBTT(@<&<`@``4>BDA0``_W7P_W/\BU4(B=/'@HP```#T!P``@<.<````_S4P
MYA@(4^BIPOW_N`$```#IC/W__XUV`%6)Y5=64X/L'(M]"(M-##F/D`````^&
MU0```(TTS0`````ISHM7,(T<\HM##"WY````@_@%=W&+512%TG4*@'LI``^%
MZ````(N'B````(MW+(E%V&:)3=S&0RD!4(N>K`,``&H!_W44_W40:@:-3=A1
M:AA6_U,$@\0@A,`/A*X```")\(N67`(``(/`4XV>4P(``(F7C````'1]@'Y3
M`'1W@^P(4.MBD(/L"/\U:.08"(V'G`(``%#HLX0``(/$#/]S((V/G````,>'
MC````/,'``#_-2SF&`A1Z+W!_?^0C67T6UZX`0```%_)PXUV`(/L"(L=:.08
M",>'C````/('``#_-2CF&`B-MYP```!6Z%N$``"#Q!"#[`A3C9^<`@``4^A(
MA```@\00Z[.-=@"-9?1;7C'`7\G#B?95B>575E.#["R)PXMX"(M`#(/X#,=%
MZ`````!W!_\DA3B@&`B+2QB+=0@!T8T$,CG!<SF)QHM#$"G.A<!T%3GP=@*)
M\%)045?HT[S]_X/$$(M#$#GP=@3&!#<`BSN+50B)%XUE]%M>7\G#B?8Q]NO@
M@^P(C4WH46H`:@K_=0A2:*#Z&`BA^/H8"/]02(@'@\0@C78`C67T6UY?R<.#
M[`B-=>A6:@!J"O]U"%)HH/H8"(L=^/H8"/]32(/$(&:)!^NA@^P(C4WH46H`
M:@K_=0A2:*#Z&`BA^/H8"/]02(D'@\0@Z["#[`R-3>A1C47<4/]U"%)HH/H8
M"(LU^/H8"/]66-E=[(M%[(D'Z]2#[`B-7>A3:@!J"O]U"%)HH/H8"*'X^A@(
M_U!0B47@B57DBU7@B1>+1>2)1P2#Q"#I5/___XU-Z%%7_W4(4NB2:`$`@\00
MZ0S___^#[`R-7>A3:@!7_W4(4N@O80$`@\0@Z2/___^#[`R-1>A0C7785O]U
M"%)HH/H8"(L=^/H8"/]36-U=T(M5T(D7BT74B4<$ZYJ)]E6)Y5=64X/L7(G&
MB=>+2`B+4D"+0`R#XB"#^`AW"O\DA6R@&`B-=@"#^@$9TH/B[(/""E*-3;A1
M_W4,_W4(Z"F,``")PXU%N"G#@\00]D=`0'49@^P,4XU5N(GPZ/_]__^#Q!"-
M9?1;7E_)PXM7'#G:=N"#^A1WVU%3`=A0C46X`=!0Z$R*``"+3QR#Q`PIV5%J
M,(U%N%#H5+[]_XM?'(/$$.NOBD4(B`'KN8M5"&:)$>NQBT4(B0&-9?1;7E_)
MPX72=&:+=0R+?0A65]\L)(/$"(7V>&G=7>#=1>#97=R+1=R)`>O2BUT(B1F+
M10R)002-9?1;7E_)PX72=!J+50R+10A24-\L)(/$"(72>"C=7>#=1>#K`]]M
M"-U=L(M=L(D9BT6TB4$$Z\??;0C97:2+1:2)`>N!V`7LH!@(Z]#8!>R@&`CK
MCY!5B>564X'L<`$``(G#BT@(BT`,@_@(=PC_)(60H!@(D(M"1(/X'G9D@^P(
M_W4,_W4(BT40@_@.?TM0BT,0/4H!``!V!;A*`0``4&BEGQ@(C;68_O__5N@=
MOOW_@\08:B!6Z$*%``#&```I\(D$)(GRB=CHH?S__X/$$(UE^%M>R<.-=@"X
M#@```.NND(/L#/]U#/]U"%!HK)\8"(VUF/[__U;HT;W]_X/$%%;H7($``.NW
MBT4(B0&+10R)002-9?A;7LG#V;V._O__9HN5CO[__[8,9HF5C/[__]U%"-FM
MC/[__]^]D/[__]FMCO[__XNUD/[__XDQBX64_O__B4$$Z[O=10C97?2+7?2)
M&>EH____V;V._O__9HN%CO[__[0,9HF%C/[__]U%"-FMC/[__]L9V:V._O__
MZ3S____9O8[^__]FBY6._O__M@QFB96,_O__W44(V:V,_O__WYV*_O__V:V.
M_O__9HN%BO[__X@!Z0/____9O8[^__]FBYV._O__MPQFB9V,_O__W44(V:V,
M_O__WQG9K8[^___IU_[__Y!5B>575E.![,P```"+2D")A33___^+0DR#X2"#
M^`V)UW<*_R2%M*`8"(UV`(/L#/]U".B17`$`B00DB<.+10B+$(N%-/___^@H
M^___BW4(`1Z#Q!"-9?1;7E_)PXM="(LSA<EFBQX/A:`"```/O\.9@^P(4E")
M^HN%-/___^B2_/__BWT(@P<"Z\>+50B+`H7)BA@/A6D"```/OL.9@^P(4E")
M^HN%-/___^AE_/__BTT(_P'KFXM%"(L85FH&V0.#[`B+A33____='"3HB_W_
M_XM]"(,'!.EU____BTT(BP&+&(MP!(G94VH/5E&)^HN%-/___^AB_?__BWT(
M@P<(Z4S___^+=0B+#H/L"/]Q!/\QBX4T____Z/?[___KVXM5"(L"A<F+``^%
MS0$``)F#[`A24(GZBX4T____Z-/[___KCH/L#/]U".AZ6P$`@\00A<"-=;B)
MP0^$N`$``(M%"(L0#[\:B5VX#[9Z`HE]O`^V0@.+70@!RL9%U`")1<#'1<P`
M````QT7(`````,=%Q`````#'1=``````QT78`````(D3Z18!``"#[`S_=0CH
M$UL!`(/$$(7`C;5H____B<$/A&4!``"+10B+$(H:B%V$BWH!B;UP____#[9"
M!8F%=/___P^V6@:)G7C___\/MGH',<"#^0B)O7S___]V`XM""(E&&(M&"(7`
MQT8$`````,<&`````'00C3Q`P><#`7X,QT8(`````,=&(`(```#I@@```(/L
M#/]U".B'6@$`@\00A<"-M3C___^)P0^$T@```(M="(L3QH54____``^_.HF]
M./___P^V0@*)A3S___\/MEH#@_D$B9U`____#X;,````#[9:!(F=1/___P^V
M>@6)O4C___\/MD(&B85,____,<"#^0=V`XM"!XE&&,=&(`$```"-!`J+30B)
M`8N5-/___XM"#(/X!W1N=V2#^`8/A'O]__^#[`B-?9A75NAN;`$`B00DB?J+
MA33____H?OC__^E6_?__,=+I+?[__P^VPS'2Z9']__\/M\,QTNE:_?__@^P(
M:@!6Z)-K`0"#Q!#KFH/L"&H!Z^Z#[`AJ`NOG@^@*@_@"=YV+G33___^+>PC\
MN0D```#SI>D"_?__QX5,____`````,>%2/___P````#'A43___\`````Z2__
M__^-=@!5B>6+50R+10B+2`B+`HH`B`'_`LG#B?95B>53BUT,BQ.+10AFBPJ+
M0`B#P@)FB0B)$UO)PXUV`%6)Y5.+70R+$XM%"(L*BT`(@\($B0B)$UO)PY!5
MB>6#[`B+30R+`8M0!(L`B47XBT4(B57\BU`(BT7XB0*+1?R)0@2#`0C)PU6)
MY8M5#(L"BPB+10B+0`B)"(,"!,G#D%6)Y5.#[`R+70R+"XL!BU$$B47PBT4(
MB57TBU`(BT7PB0*+1?2#P0B)0@2)"X/$#%O)PY!5B>575E.#[!B+10B+=0R+
M6`A6Z&Q8`0"#Q!"%P(G!=&N+%HH"B$,<BWH!B7L(#[9Z!8E[#`^V0@:)0Q`/
MMD('B4,4,<"#^0AW.HE#&(M#"(7`QT,$`````,<#`````'00C01`C13'B5,,
MQT,(`````,=#(`(````!#HUE]%M>7\G#B?:+0@CKP8UV`,=%#`(```")70B-
M9?1;7E_)Z<YI`0")]E6)Y593@^P,BT4(BW4,BU@(5NC)5P$`@\00A<")P71(
MBQ8/OP*)`P^V0@*)0P0/MD(#QD,<`(E#",=#%`````#'0Q``````QT,,````
M`,=#&`````#'0R```````0Z-9?A;7LG#C78`QT4,`````(E="(UE^%M>R>E/
M:0$`C78`58GE5E.#[`R+10B+=0R+6`A6Z$E7`0"#Q!"%P(G!=&B+%L9#'``/
MOP*)`P^V0@*)0P0/MD(#@_D$B4,(=S+'0Q0`````QT,0`````,=##``````Q
MP(/Y!W8#BT('B4,8QT,@`0````$.C67X6U[)PP^V0@2)0PP/MD(%B4,0#[9"
M!HE#%.O,D,=%#`$```")70B-9?A;7LGIKV@!`(UV`%6)Y5=64X/L&(MU#%:+
M?0CHJU8!`(G#BT<0@\00.=AV`HG84E#_-O]W".A=LOW_BP>)&`$>C67T6UY?
MR<.-=@!5B>575E.#[!B+?0C_=0SH;%8!`(M?$(/$$#G#B<9V`HG#45.+10S_
M,/]W".@;LOW_@\00.5\0=`>+5PC&!!H`BQ^+30R),P$QC67T6UY?R<.-=@!5
MB>6+30B+11"+420!$,G#58GE4X/L$(M=$%/H#%8!``$#BUW\R<.058GE5E.#
M[`R+71!3BW4,Z/!5`0`!`X/$$#E&(',#B48@C67X6U[)PU6)Y5=64X/L#(M%
M"(N0E````(72BW4,QT7P`````'5@BU4(@[J8`````;CN!P``?@1FN`0(BWT(
M@^P(B?Z+'6CD&`B)AXP```"!QIP```#_-(5@QA@(5NA@>```6%I3BTT(@<&<
M`@``4>A.>```@\00C67T6UZX`0```%_)PXGVC035`````"G0P>`#BUT(B<&+
M>S3!Z0+\\Z6+50B+6C2-#!@YRXMR.`^#\@```(GVBU,$A=)U!HU#*HE#!(L3
MA=)U!8U3'(D3BT,,BWWP_T7P@_@)B7L@QT,8`````'0@=VZ#^`0/A+4!```/
MA\,```"#^`(/A&H!```/AM(!``#'0S#@X08(QP($````BT9,@_@'=&\/A_4`
M``"#^`,/A(@!```/ATX!``"#^`$/A!,"```/AAX!``#'0S3,Y`8(QT,D`@``
M`,=&(`8```#K0H/X#0^$"P$```^'@0```(/X"P^$QP$```^&CP$``,=#,)CC
M!@B+1DR#^`?'`B0```!UDI#'0S3<Y`8(QT8@'@```(/#.(/&4#G+#X(0____
MBU4(QH*D`@```8UE]%M>,<!?R<.#^`8/A'X!```/@B@!``"#^`=TIH/X"`^%
MFP$``,=#,/SA!@CI%0$``(UV`#WY````#X*!`0``/?P````/AM`````]_@``
M``^':P$``,=#,'CD!@CI`/___XUV`(/X#'<K@_@*#X-F____@_@(QT,TS.0&
M"`^$[@```(/X"0^%?0$``,=&(`D```#K>H/X#0^$\/[__RWW````@_@(#X=6
M`0``QT,T].0&".DO____D,=#,,#A!@C'`@(```#IE_[__XGV@_@%QT,TS.0&
M"`^$V````'=_QT,D!````,=&($L!``#I]?[__XUV`,=#,"CB!@CI6_[__\=#
M-,SD!@C'1B`+````QT,D!````.G,_O__QT,P..0&".D[_O__2`^%DP```,=#
M,*CA!@C'`@$```#I(O[__\=#,$#B!@C'`@@```#I$/[__\=#,!CC!@CI;/[_
M_\=#)`````#'1B``````Z7;^___'1B`5````QT,D"````.EC_O__QT,P=.(&
M".DZ_O__QP(`````Z<?]___'0S3,Y`8(QT,D`0```,=&(`0```#I,O[__\=#
M)`@```#I)?___X/L"/\U:.08"(MU"('&G`(``%;H.'4``/]U\/]S#(M%",>`
MC````/0'``#_-3#F&`@%G````%#H0++]_^G$_/__QT,TS.0&"(/L"/\U:.08
M"(M="('#G`(``%/H\'0``/]U\/]V3(M-",>!C````/0'``")R/\U,.88".NT
MC78`58GE4X/L$(M="%/HR'/__X/$$$"Z`0```'04BT,0,-*`./YT`XU0`8M%
M#(D0,=*)T(M=_,G#B?95B>575E.#["2-1?!0_W4(BU4(_Y*$````@\00A<`/
MA:````"+30B`N:0"````BT7P#X2M````B<>+10B+B)0```"-60G!ZP,!^XM5
M"(TTS0`````ISHE=[(M:-(T4\XM%"(MP.#G3QD7G!(E5Z.L@BU,$QT,4````
M`,8"`=!EYW4%QD7G`4>#PSB#QE`[7>AS58I-YX0/==>+4P3&`@"+0PR+3>PY
M1DR)2Q1T4X/L#(U-[%&)\HG8Z#/T__^#Q!#KNXGVBWT(QX>8`````@```,>'
MA````,#1!@B-9?1;7E_)PY")1>R+=0C'AI@````$````C67T6UXQP%_)PXGV
M@^P(C47L4%/_4S"#Q!#I:O___Y!5B>575E.#[`R+31"+=0B-!,T`````*<B+
M5C2#OI@````#BWT,C1S"#XZB````.8Z4````=E:+0Q2%P`^$JP```(T4B<'B
M!(E%\(M'!`-6.(MU%(7`B7<8#X6>````BP^%R0^$H0```(L#BQB)&8/L#(UU
M\%:)^.A@\___@\00,<"-9?1;7E_)PXUV`(/L"(L=:.08",>&C````/('``#_
M-2CF&`B-OIP```!7Z--R``!97U.-CIP"``!1Z,1R``"#Q!"-9?1;7K@!````
M7\G#@^P(BQUHY!@(QX:,`````P@``/\U;.88".NZD(M'!(7`=(S&``$QP.N'
MB?;&``"+#X7)#X5?____C4L<B0_I6____Y!5B>575E.#[`R+10B+4"R+70B+
M?0B#PTB+BJ0#``"#QSR)7?")5>R)3>CK7HM-[(MQ$(`^_G4)@_L'#X;7````
M@^P(C4,+4(U7$%+H/"T``(/$$(7`B<(/A(P```"+3?"-0`R)$8E"!(E5\(U.
M`8U3_U9245#HXJK]_X,'`8M-\(-7!`")60B#Q!"#[`S_=>CHXW#__X/$$(/X
M_XG#=8V+5>R)TXG0B[)<`@``@<-3`@``BTT(@\!3B;&,````=`:`>E,`=7N#
M[`A3BTT(@<&<`@``4>B7<0``@\00C67T6UZX`0```%_)PXMU"(/L"(L=:.08
M",>&C````-@'``")\/\UP.48"`6<````4.A><0``@\00ZZ\/MT8!BWWH#[=>
M`XM5\(F']`(``,<"`````(F?[`(``(UE]%M>,<!?R<.#[`A0B<CKOHUV`%6)
MY5=64X/L'(M5"(M-"(M"+(N9E````(/"/(E5[(N`I`,``#'2A=N)1=QT5(.Y
MF`````)^"8.X?`,```%T38/L"(M]",>'C````-X'``#_-=CE&`B!QYP```!7
MBS5HY!@(Z+UP``!86HM-"%:!P9P"``!1Z*MP``"#Q!"Z`0```(UE]%M>B=!?
MR<.0BT7LBU@,A=L/A:8!``"+50B`NJ8"````=`V`NJ0"````#X2L````@^P,
MBTW<B[FL`P``_W4(_U<D@\00A<`/A;8!``"+70B`NZ8"````#X2;`0``BWWL
MBT<,A<")1>@/A`$!``"-=@"+10B+N)0```"+3>B-7PF+<03!ZP,!\XM-"(T4
M_0`````I^HE=\(M9-(T$TXMY.#G#QD7C!(E%Y.L5B?;09>-U!<9%XP%&@\,X
M@\=0.UWD#X.3````BE7CA!9UX%"-1?!05U/_4S2#Q!#KT8NRE````(T,]0``
M```I\<'A`S'`BWHT_,'I`O.KBT4(BYB4````C3S=`````(M*-"G?C03YZQ.)
M]L=!#`8```#'01`!````@\$X.<%RZX/L"(M5"/]R-%+HK/;__X/$$(3`N@$`
M```/A;7^__^+70C&@Z0"````Z=C^__^0BWWHBS>%]HEUZ`^%"/___XM=[(M#
M#(MU"(M-[(M5"(MY!(E&<(M="(L!BW7<QX*$````,-`&"#'2B4-TB7MXQX:T
M`P```````(F&N`(``(F^O`(``,>&?`,```````#I0?[__X/L"(MU"&H!@\9,
M5N@#*P``BU4(BTWL@\00QT$,`````,="/`````#'0D``````QT)P`````.D?
M_O__BTWLBT$,Z6S___^#[`B+5>R#PA!J`5+HO2H``(MU[(M%W+H!````QT8,
M`````,<&`````,=&!`````#'@'P#````````Z;S]__^-=@!5B>6+50B+30R+
M0G")2G#)PXUV`%6)Y8M%"(M`<,G#D%6)Y593BUT(BTM(A<F+10R+51!T%XUV
M`(G6"<9T#H/`_XL)@]+_A<EU[HGVB=8)QHE+<'48A<ET%,>#A````##0!@C'
M@Y@````#````6U[)PXUV`%6)Y8M%"(M00(M`/,G#B?95B>575E.#[!2+=0B+
M7BR-1DQJ`%#H[BD``%A::@!6Z.0I```Q_X/$$(7;#X2_````@^P(C4X@4?^S
MJ`,``.CQ3```BY-<`@``@\00A=*)@Z@#```/A;(```"#OI@````!#XZ)````
MC;ZE`@``.;NT`P``#X3J````BY-\`P``A=(/A;````"+EH@```")5?!7B[NL
M`P``:@%J!(U%\%!J`&H`:AE3_U<$#[[X@\0@A?]T/8V#4P(``(E%[(G8BXM<
M`@``@\!3B8Z,````=`J`>U,`#X69````@^P(_W7LC9:<`@``4NCM;```@\00
MB?:#[`Q6Z!,0``"#Q!`QP(7_#Y7`C67T6UY?R<.0@^P(QD-3`,>#7`(`````
M``"-@U,"``#_-63D&`A0Z*EL``"#Q!#I(____X/L#(N+K`,``%/_412+@[0#
M``"#Q!"%P'0#Q@`!QX-\`P```````.DD____QX.T`P```````.D'____@^P(
M4(V>G````%/H5FP``(/$$.E/____B?95B>575E.#[`R+=0@QP(.^F`````%^
M5HM^+(N.B````(N?I`,``(E-\%&+DZP#``!J`&H`:@!J!(U%\%!J&E/_4@2#
MQ""$P'4OB[Z0````BTXPC33]`````"G^C03QZP?&02D`@\$X.<%R]3'`C67T
M6UY?R<.-=@")V(N37`(``(/`4XV[4P(``(F6C````'0&@'M3`'4@@^P(5XV&
MG`(``%#HI6L``(/$$(UE]%M>N`$```!?R<.#[`A0C9Z<````4^B%:P``@\00
MZ\M5B>6+10B+@(P```#)PXGV58GEBT4(!9P"``#)PXUV`%6)Y8M%"`6<````
MR<.-=@!5B>6#[`QJ!FBQGQ@(_W4(Z`^!__\/OL#)PXGV58GE@^P,:@AHN)\8
M"/]U".CS@/__#[[`R<.)]E6)Y8/L"(!]#`"+10AT%5%J$&C!GQ@(4.C/@/__
M#[[`R<.)]E)J$&C2GQ@(4.BZ@/__#[[`R<.058GEBU4(BX*D`P``BX#L`@``
MP>@#@^`!R<.)]E6)Y5-3BUT(BXM\`P``A<ET/H/L"/\U:.08"(V34P(``%+H
MG6H``%A:C4-3QX-<`@``W@<``/\UV.48"%#H@FH``+H!````B="+7?S)PXGV
M@^P(QD-3`,>#7`(```````"-@U,"``#_-63D&`A0Z%%J``"+BZ0#``"#Q!#V
M@>P"```(QX.X`@``_____\>#O`(``/____^Z_____W2I@^P,BX.L`P``4_]0
M-`^^T(G0BUW\R<.-=@!5B>6+10B+D*P#``"+2@S)_^&)]E6)Y8/L%(M%"(N0
MK`,``%#_$@^^P,G#D%6)Y8M%#%,QTKO___\_BTT(]_.)$8M%$#'2]_/'00C_
M__\_QT$,``"`_\=!$/__ST&)401;R<.058GE5U93BTT(BSF+<02-!'\!\(MY
M"#'2]_>)$8U$,B$QTO?WB5$$,=*+`5)0WRPD@\0(6U[<<0Q?R<.058GE5U93
M@^P(BUT,BT40`=@YP[XU5S!0QT7P!P```+]Q5C02B47L<S:-=@"*`SP@="<\
M"70C#[;(B?"#X#\#1?")\L'B"`^OP0'0B?HQQL'B"#'R`=<!3?!#.UWL<LV+
M70B!YO___W^!Y____W^),XE[!(/$"%M>7\G#D%6)Y5=64X/L'(M=##'`B=_\
MN?_____RKO?1C4P9_SG+OS57,%#'1>0'````OG%6-!*)3>!S-8GVB@,\('0G
M/`ET(P^VR(GX@^`_`T7DB?K!X@@/K\$!T(GR,<?!X@@Q^@'6`4WD0SM=X'+-
MB?.!X____W]3@>?___]_5VCPH!@(_W4(B7WHB5WLZ(ZE_?^-9?1;7E_)PXGV
M58GE5U93@^QLBWT0A?\/A`P"``"`/P`/A`,"``"+50R+70B#P@B)7:PQP(E5
MF/RY_____XG[\J[WT8U,&?\YR[XU5S!0QT6H!P```+]Q5C02B4VD<S6)]HH#
M/"!T)SP)=",/MLB)\(/@/P-%J(GR#Z_!P>((`=`QQHGXP>`(,?`!QP%-J$,[
M7:1RS8M=#(M-F('F____?X'G____?SG+B77`B7W$OC57,%#'1:`'````OW%6
M-!)S,XH#/"!T)SP)=",/MLB)\(/@/P-%H(GR#Z_!P>((`=`QQHGXP>`(,?`!
MQP%-H$,[79ARS8'F____?XGQB?LS3<"!X____W\QTHEUN(G(OO___S_W]HE=
MO#-=Q(E5R(G8,=*+?9CW]CE]#,=%T/___S_'1=0``(#_QT78___/08G6#X/P
M````O____S^0BTW(C01)`?`QTO?WB57(C40R(3'2]_>)UC'24HM-R%'?+"3<
M-0"A&`B#[`C<#0BA&`B+70C='"3_10CH<)_]_]E]MF:+1;:T#&:)1;3<!1"A
M&`C9;;3?7;+9;;9FBU6RB!/_10R+79B#Q!`Y70QRD(M-R(T$20'P,=+W]XE5
MR(U$,B$QTC'V]_=6BWW(5]\L)-PU`*$8"(/L"-P-"*$8"(E5S-T<).@%G_W_
MV7VV9HM=MK<,9HE=M-EMM-]=LMEMMH/$$&:+5;+K"HGVBWVL_T6L,!>+70@Y
M7:QU\(MU",8&`(UE]%M>7\G#BWW0ZX&058GE5U93@^QLBUT,C4,(.<.^-5<P
M4,=%H`<```"_<58T$HE%G',TD(H#/"!T)SP)=",/MLB)\(/@/P-%H(GRP>((
M#Z_!`=")^C'&P>((,?(!UP%-H$,[79QRS8G[@>;___]_@>/___]_B76PB5VT
MBU40B?<Q]C,Z,UH$N?___S_'1=#___\_5E&^____/XGX,=+W]M\L)(U-N(E5
MR-U5U#'2B=B)3:2+?0CW]H/$"(`_`(G6#X2>````C5W(.<MW#>F2````B?;=
M1=2+=<R+3<B-!$D!\#'2]W70B57(C40R(3'2]W70B57,,=*+7:2+=<C_1:12
M5M\L)-[Q@^P(W`T(H1@(W1PDZ+.=_?_9?:YFBTVNM0QFB4VLW`40H1@(V6VL
MWUVJV6VN9HM%JH@#1X/$$(`_`'0EC5W(.UVD=X@K?0B#_PBX`0```'0=C78`
MC67T6UY?R</=V(E5S"M]"(/_"+@!````=>:+=<B+7<R-!':+?=`!V#'2]_>)
M5<B-1!HA,=+W]S'VB57,BWW(5E??+"3<==2#[`C8#1BA&`C='"3H&)W]_]E]
MKF:+5:ZV#&:)5:S9;:S?7:K9;:Z#Q!!FBUVJC4VXBWT(BA>$TG0;B@$QV$'_
M10@XPG3KN`$```"-9?1;7NEI____C67T6UXQP%_)PXGV58GEBTT,5U:+?0B%
MR5/'1P0`````QP<`````=$Z*$832=$B0,<`QV^L3B?:-0LE##[;0@_L'C006
M=R6*$8G&C4+0P>8$03P)=N6-0K\\&7;;C4*I0P^VT(/[!XT$%G;;B0>#QP2*
M$832=;E;7E_)PU6)Y8/L"(M%#/]P!/\P:/"@&`C_=0CHS:#]_\G#C78`58GE
M5U93@^P,BW4(BT4,`?`YQHM]$(E%Z'-BV7WR9HM5\K8,V04<H1@(V04@H1@(
M9HE5\(L?C01;BU\$`=@QTO=W"(D7C40:(3'2]W<(,<")5P2+'U!3WRPDW'<,
MV,K8P=EM\-]=[MEM\F:+3>Z(#D:#Q`@[=>ARN]W8W=C&!@"#Q`Q;7E_)PU6)
MY5=64X'LN````(V=>/___U/H5%H``/PQP(M]#+G_____\J[WT8/$#$E1_W4,
M4^A#7@``65[_=0A3Z`1=``")'"3H)%H``(/$#&H4_W4(4^@B7@``6%J-M5C_
M__]64^C?7```BT4(B?.#Q!"-2`&-M6S____&`"KK(9`/MCN)^L'J!(J"H/(8
M"(@!@^</BI>@\A@(B%$!0X/!`CGS==S&`0"-9?1;7E_)PY!5B>575E.![,@`
M``"-G7C___]3Z*A9``#\BWT0,<"Y______*N]]&#Q`Q)4?]U$%/HEUT``%E>
MC;58____5E/H5%P``(D<).AT60``@\0,:A164^AT70``6%J-E3C___]24^@Q
M7```B1PDZ%%9``"#Q`QJ%/]U#%/H3UT``(/$#&H4C84X____4%/H/5T``%]8
M_W4(4^C^6P``BU4(B?.#Q!")T8UR%.L,C78`B@,R`H@!0T)!.?)R\XUE]%M>
M7\G#C78`58GE5U93@>S8````C9UX____4^CD6```@\0,:A3_=0Q3Z.)<``"#
MQ`QJ%/]U$%/HU%P``%A:C958____4E/HD5L``(V];/___XV-6/___X/$$(G.
MBU4(.?GK#)"*`C(!04*(!D8Y^7+S@^P,4^B*6```@\0,:A2-E5C___]24^B$
M7```7UB-O3C___]74^A!6P``BW40N10```#\\Z8/DL,/E\&-9?0HV5M>#[[!
M7\G#C78`58GE5U934XM%#(U8`8/`*8M]"#G#B47PZTB)]HH3C4+00SP)=@Z-
M2K^`^1EW/HU"R8UV``^VT`^^RHH3C4+0P>$$0SP)B?Z-?P%V#(U"OSP9=R&-
M0LF)]@^VT`G*B!8[7?!RN%E;7E_)PXGVC4*IZ\.-=@"-0JGKWXUV`%6)Y8M%
M"%/&`"J+50R-2`&-6A20#[8"P>@$BH"@\A@(B`$/M@*#X`^*@*#R&`A"B$$!
M@\$".=IUV\8!`%O)PY!5B>7'!2CR&`B@Y1@(R<.058GE4X/L%(`]A.88"`!U
M*J&$\1@(_P6`YA@(A<#&!83F&`@!QP5HZ1@(L`$``,<%9.D8",`!``!T"C'`
MBUW\R<.-=@"#[`QHMGD(".A/F/W_@\00A<"CA/$8"`^%\@```(/L#&B$JA@(
MZ#*8_?^#Q!"%P'1CBA"$THG!#X3M````#[;"BQW`^A@(]D0#`0AT%(UV`$&*
M$832=`H/ML+V1`,!"'7O@^P,C5WX4S'`@/HP:/___W\/E<!J`(U<``A34>BZ
M80``BU7X@<J``0``@\0@B15HZ1@(@^P,:(JJ&`CHNY?]_X/$$(7`#X1*____
MBA"$THG!='T/ML*+'<#Z&`CV1`,!"'0108H1A-)T"@^VPO9$`P$(=>^#[`R-
M7?13,<"`^C!H____?P^5P&H`C50`"%)1Z$9A``"+3?2!R<`!``")#63I&`B#
MQ"`QP(M=_,G#@^P(4&B`Z1@(Z`</``"#Q!"CA/$8".GS_O__BA#I,/___XH0
MZZ"-=@!5B>575E.#[&R+70CVPP&+/>A#)0AT%8L5<.D8"*%TZ1@(B=$)P0^%
MY````.AS/0``@^,"=0@[/>A#)0AT%8/L"(U%F%!J`.C(F?W_@\00A<!T$<8%
MA.88"`"-9?1;7E_)PXGV@^P(_W7<_W78_W74_W70_W7,_W7(_W7$_W7`_W6\
M_W6X_W6P_W6HBU6@BUVDC322C0RVB=B^K8O;:/?NB564BT64P?L?P?@,*=B-
M#(C9!;2K&`A1V<#:/"2#[`3='"2+59B+79R-!)*-#(")V/?NB460B564BW64
MP?L?P?X,*=Z-%(Y2VCPD@^P$W1PD:)2J&`A7Z"B8_?_&!83F&`@`@\10C67T
M6UY?R<.)]E!2_S7L\1@(:&`4)@CHLIK]_X/$#&H$:&`4)@AJ$^B-$P``@\00
MZ?'^__^058GE5U93@^P,BUT(A=N+?0QU`K,!@^P,4^B*EOW_@\00A<")QG0H
M@^<@=0R-9?1;B?!>7\G#B?904VH`5NB&F?W_@\00C67T6XGP7E_)P^@$F/W_
MBQ")^,'H`X/@`8D58.D8"(E%\'47@^<8=2"+7?"%VW2W@^P,:@'HF9K]_Y"+
M#:CF&`B)#:SF&`CKVU%3:B1J!>CO!@``@\00Z]")]E6)Y8M%"(7`=`;)Z2B;
M_?_)PXGV58GE5U93@^P,BWT,A?^)_G4%O@$```"#[`Q6Z-25_?^#Q!"%P(G#
M="[V11`@=1E65_]U"%/H:I7]_X/$$(UE](G86UY?R<.04%9J`%/HPIC]_X/$
M$.O8Z$B7_?^+$(M%$,'H`XG'@^<!B15@Z1@(=1?V11`8=1^%_W3"@^P,:@'H
MWYG]_XUV`(L-J.88"(D-K.88".O;4%9J)&H%Z#,&``"#Q!#KT8GV58GE5U93
M@^P,,<#\N?____^+?0CRKHG+]].%VXG>=06^`0```(/L#%;H'I7]_X/$$(7`
MB<=T,/9%#"!U&U!3_W4(5^BTE/W_@\00C67T6UZ)^%_)PXUV`%!6:@!7Z`J8
M_?^#Q!#KUNB0EOW_BU4,BQC!Z@.)'6#I&`B)TX/C`747]D4,&'4?A=MTP(/L
M#&H!Z">9_?^-=@"+#:CF&`B)#:SF&`CKVU!6:B1J!>A[!0``@\00Z]&)]E6)
MY5=64X/L#(M]#(G^1G4%O@$```"#[`Q6Z'64_?^#Q!"%P(G#=#/V11`@=1Y0
M5_]U"%/H"Y3]_\8$.P"#Q!"-9?2)V%M>7\G#B?925FH`4.A>E_W_@\00Z]/H
MY)7]_XL0BT40P>@#B<>#YP&)%6#I&`AU%_9%$!AU'X7_=,&#[`QJ`>A[F/W_
MC78`BPVHYA@(B0VLYA@(Z]M15FHD:@7HSP0``(/$$.O1B?95B>575E.#[`R+
M70B%VXM]#(MU$'0B@^P(5U/H*);]_X/$$(7`B47P="J+1?"-9?1;7E_)PXUV
M`/?&0````'36B74,B7T(C67T6UY?R>GN_/__B?;WQH````!U*_?&``$``(G8
M=<?H+97]_XL`@^88HV#I&`ATLU!7:B1J!>A&!```@\00ZZ.#[`Q3Z%#]__^#
MQ!#KQXUV`%6)Y593@^P,BUT(4^@_F/W_@\00A<")QG4F.QU<YQ@(<PVA6.<8
M"(M4V`2%TG5%_PUPZ1@(C67X6XGP7LG#B?;HNY3]_XL`]D4,&*-@Z1@(=,CH
MJ93]__\P@^P(4^BB!@``@\0,4&HD:@3HP0,``(/$$.NF@^P,_S38Z,G\__^+
M#5CG&`C'1-D$`````/\-<.D8"(/$$(UE^%N)\%[)PY!5B>575E.#[`R+=0B%
M]HM]&`^(I0```#LU7.<8"'(1_P5PZ1@(C67T6XGP7E_)PY"#[`B+'5CG&`A7
M_W4,Z"+]__^#Q!"%P(D$\W0=BT40BQ58YQ@(B43R!/\%<.D8"(UE]%N)\%Y?
MR<.#[`Q6Z#Z7_?^#Q!"%P'5S.S5<YQ@(<RFA6.<8"(M<\`2%VW0<@^P,_S3P
MZ`_\__^+%5CG&`B#Q!#'1/($`````/\-<.D8",<%8.D8"`P```#K#.B?D_W_
MBP"C8.D8"(/G&0^$5/____\U8.D8"/]U#&HD_W44Z*P"``"#Q!#I.?___^AO
MD_W_BPCWQQ@```")#6#I&`@/A'3____H5I/]__\P@^P(5NA/!0``@\0,4&HD
M:@3H;@(``(/$$.E/____B?95B>575E.#[!"+?0C_-6CI&`C_=0Q7Z!F6_?^#
MQ!"%P(G&#XBD````.P5<YQ@(<A#_!7#I&`B-9?1;B?!>7\G#@^P(BQU8YQ@(
M_W405^CF^___@\00A<")!/-T':%8YQ@(QT3P!`$```#_!7#I&`B-9?1;B?!>
M7\G#@^P,5N@"EOW_@\00A<!U<3LU7.<8"',IH5CG&`B+3/`$A<ET'(/L#/\T
M\.C3^O__BQU8YQ@(@\00QT3S!`````#_#7#I&`C'!6#I&`@,````ZPSH8Y+]
M_XL`HV#I&`CV11`9#X14_____S5@Z1@(5VHD:@#H<@$``(/$$.D\____Z#62
M_?^+$/9%$!B)%6#I&`@/A'C____H'I+]__\P@^P(5N@7!```@\0,4&HD:@3H
M-@$``(/$$.E3____B?95B>575E.#[`R+112+=1#!Z`F+?0R)=?")1>SHW)']
M_\<``````%)65_]U".C[D?W_@\00.?")PW1RZ+V1_?^+"(7)NO____]U=O9%
M%!J)%6#I&`AT#X/[_P^$F@```/9%%`9U<X/[_P^$IP```/9%%`9T"O9%[`$/
MA)<```"%VW0J]D7L`70DZ&^1_?_'```````IWE)6`=]7_W4(Z(J1_?^#Q!`Y
M\(G#=8^0]D44!G0:,=N)V(UE]%M>7\G#B?;H-Y']_XL0ZX&-=@#V1>P!=.*+
M7?#KW9!2@^P(_W4(Z!P#``"#Q`Q0:B1J">@[````@\00Z6S___]2@^P(_W4(
MZ/L"``"#Q`Q0:B1J`N@:````@\00N/_____KFE6)Y<<%(/(8"*#Q&`C)PY!5
MB>575E.![%P!``"-51"XTTUB$(F5Q/[___=M"(M%",'Z!L'X'SG"=0Z+#2#R
M&`B%R0^$1P(``+C336(0]VT(BW4(P?X?P?H&*?*-')*-!)N-/(#!YP.+=0@I
M_HL,E2#R&`B+'+&)G:3^__\QP/RY_____XN]I/[___*N]]%)B8W`_O__B[6D
M_O__B@:$P(V=R/[__W0:D#PE=#3_A:3^__^(`T.+M:3^__^*!H3`=>?&`P!0
M_W4,C9W(_O__4_]U"/\5K.88"(UE]%M>7\G#_X6D_O__BXVD_O__BA&`^B4/
MA*P```"`^B[&A;O^__\`#X0M`0``#[;"BPW`^A@(ZQ.)]O^%I/[__XN%I/[_
M_XH0#[;"]D0!`01UZ(#Z+G3C@/HM=-Z`^FP/A#T!``"`^G-T;8#Z9'0-@/IU
M=`C&`R7I7O___XN%Q/[__X.%Q/[__P2`^F2+``^$*P$``%)J"E-0Z#16```I
MV(N5P/[__P'"@\00@?H!`0``=\&#Z@(!P_^%I/[__XF5P/[__^D2_____XW`
M_O__Q@,EZ0/___^+M<3^__^+%H.%Q/[__P0QP/RY_____XG7\J[WT8"]N_[_
M_P"-<?]T&(N-O/[__X7)?@X[M;S^__]V!HNUO/[__XN]P/[__P'W@?\!`0``
MB;VL_O__#X="____5U924^AC5```BY6L_O__@^H"`?/_A:3^__^#Q!")E<#^
M___I@?[___^%I/[___^-P/[__XN%I/[__XH0@/HJ#X6V_O__B[W$_O__0(L7
M_XW`_O__@X7$_O__!(F%I/[__XF5O/[__\:%N_[__P'K!O^%I/[__XNUI/[_
M_XH6Z;#^___H;/W__^FO_?__46KVZ=#^__^-=@!5B>53@>PH`0``C4444/]U
M#(V=V/[__U/H_XK]_X/$#/]U$%/_=0C_%:SF&`B+7?S)PXGV58GEBPVLYA@(
MR?_A58GEBU4(.Q5<YQ@(N`*Q&`AS%872>!6A6.<8"(M,T`2%R70(BP30D,G#
MB?:X"K$8",G#D%6)Y5=64X'L5`0``&HZC87(^___BW4,5HF%Q/O__^C%C/W_
M@\00A<!T'RGPC5@!4E-6C97(^___4NCJ4@``B87$^___`=Z#Q!"#[`AH$[$8
M"(U]V5?&1=@OZ'Y2``"-3=@IR(F%K/O__XH&BYW$^___1H/$$(FUJ/O__^L3
MC78`BY6H^___B@)"0XF5J/O__X3`B`,/A$H!``"`.R]UX<8#+XG>*[7$^___
M.[6L^___#X:F````B=HKE:S[__^+A:S[__^)E;S[___\.<")UHU]V(G!\Z8/
MA8````"+G;S[__\[G<3[__]TEDN*`SQ^#X2Q`0``/"X/A#`!```[G<3[__^)
MG<#[__]R#Y"`.R]T"4L[G<3[__]S\H![`7YT&(N%K/O___PYP(G>C7W8B<'S
MI@^%2/___X/L"(U=V(N5P/O__U-"4NB040``B<.#Q!#&`"_I)____XUV`(G9
MB[VL^___*XW$^___3SGY#X25````B=DKC<3[__^%R7X*@'O_+P^$G@```(G8
M*X7$^___2'X*@'O_+@^$]@```(V5R?O__SG:#X/4_O__@'O_?@^%RO[__X![
M_B\/A<#^__^-G<C[__^)G<3[__^)T\:%R/O__W[&A<G[__\OZ9_^__^-=@"#
M[`B-M<C[__]6_W4(C;W(^___Z.!0```I^XUE](G86UY?R</\.<F+M<3[__^-
M?=GSI@^%5____XF=Q/O__^E9_O__2^E3_O__.YW$^___=`J`>_\O#X6^_O__
M4&H`:``$``!H@.T8".B_0`$`@\00B[6L^___A<"-7#,!#X4:_O__@^P(:(#M
M&`B-C<C[__]1Z&)0``"#Q!"`>/\OC5C_#X5S_O__C5C^Z6O^__^)]H![_B\/
MA0#___^#ZP+IVOW__SN=Q/O__W0*@'O_+P^%1?[__Z&$\1@(B[VL^___A<"-
M7#L!#X2Q_?__@^P(4(V=R/O__U/H_4\``(G"C5C_BD#_@\00/"\/A0/^__^-
M6OZ*0O[I^/W__XUV`%6)Y5.#[`AH_P,``(M="/]U#%/H2%```"G8BUW\R<.0
M58GE5E.![``$``"+=0B+70PY\W0?@^P(4U;HY08``%E:C00#4%;H'8K]_XUE
M^%N)\%[)PX/L"%:-G?C[__]3Z'A/``"#Q!#KS(UV`%6)Y5=64X'L/`@``(VU
MV/O__XM=##GS#X2H`0``@^P(4U;HD08``%I9C10#4E;HR8G]_XGW,<#\N?__
M___RKO?1B<B#Q!!(=".*E`77^___@/HZ=!>`^B]T$L:$!=C[__\OQH0%V?O_
M_P")]H/L"%96Z![\__^#Q!"`O=C[__]^B87$]___="!1:/\#``!6_W4(Z%U/
M```K10B#Q!"-9?1;7E_)PXUV`(V=V?O__X"]V?O__R^)G=3W__\/A!P!``"#
M[`AJ+U/HH(S]_X/$$(7`B<</A"L!``"*'X/L#,8'`/^UU/?__^B0B_W_B870
M]___@\00B!_HP(?]_XN-T/?__X7)=(*)O=3W__^+A=#W__^+>!R)O<CW__^+
ME<CW__^%T@^$7____XN5U/?__XF5S/?__XGS*YW,]___BXW$]___C50+`3'`
MB[W(]____+G_____\J[WT8U9_XT\$X'_``0```^''?___XN]R/?__X!\'_\O
M#X2;````C0P>.XW,]___<V=04O^US/?__U'H%X;]_X/$#%/_M<CW__]6Z`>&
M_?^#Q!!1:/\#``!6_W4(Z#U.```K10B#Q!"-9?1;7E_)PX/L"%:-G=CW__]3
MZ)M-``"#Q!#I0/[__XL=A/$8"(F=R/?__^DM____5U*+O<SW__\!UU>-!!%0
MZ*Y5``#KD8/L#%/H(TX``(G'@\00Z<+^__^-6?[I7?___Y!5B>575E.![!0$
M``#_=0R-M>C[__]6Z'T$``!>7XV5Z/O__U)2B</HM/W__XM-#(T4&8G&_#'`
MN?____^)U_*N]]&-3#'_@\00@?G_`P``=S>#[`B-A>C[__]2`?!0Z.U,``"#
MQ`QH_P,``(V]Z/O__U?_=0CH6DT``"M%"(/$$(UE]%M>7\G#4VC_`P``_W4,
M_W4(Z#M-```K10B#Q!"-9?1;7E_)PY!5B>575E.!["P(``"+70P[70@/A'@"
M``"#[`A3_W4(Z,P#``!97HT$`U#_=0CH`H?]_UA::CK_=0CH=H;]_X/$$(7`
MBUT(=`.-6`%0:@!H``0``(V5Z/O__U+H?3P!`(/$$(7`B87D]___=33\N?__
M__^-O>C[___RKO?1B=I)*U4(.UT(B8W8]___B97@]___#X2C`0``.=$/A(D!
M``"0@^P(_W4(_W4(Z![Y__^#Q!"%P(G#='6+%83Q&`B%TL>%W/?__P````!U
M:8N5Y/?__X72=5>#O=SW__\!#X?:````@^P(C97H^___4O]U".B(3```@\00
MA<!T,3'`_+G_____C;WH^___\J[WT8U!_XM5"(`\`@`/A8T!``"+=0C&!B[&
M1@$OQD8"`)"-9?1;7E_)PS'`_+G_____B=?RKO?1C7'_B;7<]___@'PR_R\/
MA"P!``"#O=SW__\!#X9H____.9W<]___#X-<____BYW<]____#G;BW4(B=>)
MV?.F#X5$____BU4(BX7<]___@#P"+P^%,?___\8"?HG6@^P(`[7<]___B==6
M1U?H]DH``(/$$.D1____B?:+C=CW__\YC=SW__\/@Q3___^+G=SW__^+/83Q
M&`C\.=N-M>C[__^)V?.F#X7U_O__BY7<]___@+P5Z/O__R\/A>'^__^-O>C[
M__^#[`@!UU>-A>G[__]0QH7H^___?NB(2@``@\00Z;K^__\YR8VUZ/O__XG?
M\Z8/A6;^__^*`SPO#X1<_O__A,`/A%3^___\BWT(,<"Y______*N@^P,]]%1
M_[78]___C8WH^___4?^UX/?___]U".CZ40``@\0@Z1[^__^#Z0*)C=SW___I
MQO[__X/L"/]U"(V=Z/?__U/H!DH``(/$$.EN_?__@^P(`=!04NCR20``@\00
MZ6[^__^)]E6)Y8/L%/\UX$,E".B3@_W_@\00]D40!'4ZH8#Q&`B%P'5-@^P(
M_S7H0R4(_W4,Z,"'_?]:6?\UZ$,E"&H*Z!&'_?]8_S7H0R4(Z%6#_?\QP,G#
MD(/L"/\UZ$,E"&H'Z/"&_?^A@/$8"(/$$(7`=+.#[`C_->A#)0A0Z'6'_?__
M->A#)0AJ`FH!:-J,"`CH\8;]_X/$(.N+58GE4X/L#&HZBUT(4^A*@_W_@\00
MA<!T)HI0`832C4@!=`V0@/HO=`]!BA&$TG7T*=A`BUW\R<.)R$&*$>OMC4/_
MZ]55B>6+51!6A=*+=0A3BTT,B?-T.(G0*<@]_@,``'\M*<I04E%6Z&9)``"#
MQ!`YV'04BE#_@/HO=`R`^CIT!\8`+T#&``"-9?A;7LG#C9'^`P``Z\M5B>57
M5E.#[!1J.HM=#%/HL(+]_X/$$(7`BWT(=&F*4`&$THU(`70,@/HO=%-!BA&$
MTG7T*=B-<`&)V@'R=`N)T"G8/?X#``!^!HV3_@,``"G:45)35^CA2```@\00
M.?AT%(I0_X#Z+W0,@/HZ=`?&`"_&0`$`C67T6XGP7E_)PXG(08H1ZZF-0__K
MDE6)Y5=64X/L'(M5#(L*,<"%R0^$J````(M""(L8A=O'1?``````QT7L````
M`(E%W`^$SP```(M]"(H7#[;RB%7CB77DBSW(^A@(B?:`?>,`BW4(#X3'````
MB@N(3=L/ML&*#`>+5>0X#!=T;XM%"(H(@'W;`'5Y@/D@=0A&B@Z`^2!T^(3)
M#X2C````_T7LBT7LBTW<BQR!A=MUL(M]\(7_=&*+=0B`/@!T:(-]\`%U"O9%
M$`$/A*\```"X_____XUE]%M>7\G#BA.(5=L/MM(/ML&*%!<X%`=UED:*#D.$
MR77EBA.(5=N`?=L`=(F)]H3)=9CV11`!=9*+=>S_1?")=>CKA_9%$`1T"(M5
M"(`Z(W0HC67T6UXQP%_)PXUV`(H+B$W;BUT(B@OI0O___XM%[$"-9?1;7E_)
MPX/L#%+HJ$<``(/$$(!X_R-UQHM="(/L#$-3Z(Z$_?^#Q!!(B47H>+"+50P[
M`G.I]D40`G0&BT7H0.N]BWT,@^P(BT\(BT7H_S2!_W4(Z)]&``"#Q!"+1>CK
MWHUV`%6)Y8M5"(M-##D*=@^+0@B%P'0(BP2(R<.-=@"X%K$8",G#D%6)Y8M%
M#(7`BTT(BU40=!A(.0)W&[@6L1@(B44,B4T(R>E*1@``B?;&`0#)PXUV`(M2
M"(72=-Z+!(*)10R)30C)Z2I&``")]E6)Y5=64X/L#(MU$(M%#(M="(/H'(7V
MQT,(`````,=#!`````#'`P````#'0PP@````B4,0QT,<`````,=#%`0```#'
M0Q@`````=0B-9?1;7E_)PX/L"&H`C7X05^A:Z/__@\00A<")0PB)`W3>B7@(
MB7`$QP``````C67T6UY?R<.)]E6)Y5=64X/L#(M5#(M%$(/J'(M]"(7`B5<0
M='R+=1"+1PB#QA"%P'5_BP>%P(G[=#>)PNL+C78`B=.+$X72="B+2@@Y\71L
MBT($@\`0.<AUYXL*@^P,B0M2Z'KH__^+$X/$$(72==F0@^P(:@!6Z,7G__^#
MQ!"%P(G"=".)<`B+,XM%$(DRB4($B5<(B1.-9?1;7E_)PXGVQT<(`````(UE
M]%M>7\G#D#EP"`^%>/___^OLB5<(C67T6UY?R<.)]E6)Y5=64X/L#(M]"(MU
M#(/&!XL/@^;XA<F)??!T)CEQ!`^"D0```(L7A=)T%XUV`#ER!`^#MP```(E5
M\(L2A=)U[HGVBT<4P>@"#Z]'$(U>$#G#<E^#[`AJ$%/H&.?__X/$$(7`B<(/
MA),```"+3?"+`8D"_T<4B=F)6@B-0_"+7?")$RG!*?")0@0!T3M'#',6BP*+
M7?")`XMW!(DRQT<8`````(E7!(G(C67T6UY?R<.)]HG#ZYV+5QB-0@&#^@F)
M1Q@/AEW___^!>03_#P``#X=0____BQ&+7P2)%\='&`````")&8E/!.DX____
MD(72#X1,____BT($BTH(ZX2+1QR%P'4$,<#KG__0,<#KF8UV`%6)Y593BW4(
MA?:+10P/A(H```"H`@^%B0```*@!=0?'1@@`````BUX$A=L/A+\```"+5@B)
MV#G"BQMT#X/L#%#HO^;__X/$$(M6"(7;=>6+'HUV`(7;=!N)V#G"BQMT](/L
M#%#HF^;__X/$$(M6"(7;=>6%TL=&!`````!T:HM:"(/K$(D6B5H$QP(`````
MQT84!````,=&&`````"-9?A;7LG#B?"+%NL/B?:+0@B#Z!")0@2)T(L2A=)U
M[XM6!(D0ZPN+2@B#Z1")2@2+$H72=?''1@0`````QT88`````(UE^%M>R</'
M!@````#KGXM6".E7____58GE4XM="(M3!(72BTT,=!:-=@`YRG<)BT((`=`Y
MR'<EBQ*%TG7MBQ.%TG06C78`.<IW"8M""`'0.<AW"8L2A=)U[5O)PXE3"%O)
MPU6)Y5=64X/L#(M]"(MU$(/&"(L/@^;XA<F)??!T)CEQ!`^"T0```(L7A=)T
M%XUV`#ER!`^#]P```(E5\(L2A=)U[HGVBT<4P>@"#Z]'$(U>$#G#<G>#[`AJ
M$%/HP.3__X/$$(7`B<)T>8M-\(L!B0+_1Q2)V8E:"(U#\(M=\(D3*<$I\(E"
M!`'1.T<,<Q:+`HM=\(D#BW<$B3+'1Q@`````B5<$A<F)RW074O]U$/]U#%'H
MP7K]_XM]$,8$.P"#Q!"-9?2)V%M>7\G#D(/L"&H0B<-3Z$?D__^#Q!"%P(G"
M=8>+1QR%P'5:,=N-9?2)V%M>7\G#C78`BU<8C4(!@_H)B4<8#X8=____@7D$
M_P\```^'$/___XL1BU\$B1?'1Q@`````B1F)3P3I^/[__Y"%T@^$#/___XM"
M!(M*".D]_____]`QV^NBC78`58GE5U93@^P,,<#\N?____^+?0SRKO?1BW4(
MC4'_C5D'BPZ#X_B%R8E%\(EU['0D.5D$#X+/````BQ:%TG05D#E:!`^#]P``
M`(E5[(L2A=)U[HGVBT84P>@"#Z]&$(U[$#G'<G>#[`AJ$%?H9./__X/$$(7`
MB<)T>8M-[(L!B0+_1A2)^8EZ"(U'\(M][(D7*<$IV(E"!`'1.T8,<Q:+`HM]
M[(D'BUX$B1K'1A@`````B58$A<F)RW074?]U\/]U#%/H97G]_XMU\(/$$,8$
M,P"-9?2)V%M>7\G#D(/L"&H0B<=7Z.OB__^#Q!"%P(G"=8>+1AR%P'5:,=N-
M9?2)V%M>7\G#C78`BU88C7H!@_H)B7X8#X8?____@7D$_P\```^'$O___XL1
MBT8$B1;'1A@`````B0&)3@3I^O[__Y"%T@^$#/___XM"!(M*".D]_____]`Q
MV^NBC78`58GE5U93@^P,BWT(BW40@\8'BP^#YOB%R8E]\'0F.7$$#X+)````
MBQ>%TG07C78`.7($#X/O````B57PBQ*%TG7NB?:+1Q3!Z`(/KT<0C5X0.<-R
M;X/L"&H04^@8XO__@\00A<")PG1QBTWPBP&)`O]'%(G9B5H(C4/PBUWPB1,I
MP2GPB4($`=$[1PQS%HL"BUWPB0.+=P2),L='&`````")5P2%R8G+=!!6_W40
M_W4,4>@9>/W_@\00C67TB=A;7E_)PX/L"&H0B<-3Z*?A__^#Q!"%P(G"=8^+
M1QR%P'5:,=N-9?2)V%M>7\G#C78`BU<8C4(!@_H)B4<8#X8E____@7D$_P\`
M``^'&/___XL1BU\$B1?'1Q@`````B1F)3P3I`/___Y"%T@^$%/___XM"!(M*
M".E%_____]`QV^NBC78`58GE4XM="(H3A-*)V8G8=0KK'9!`BA"$TG0<@/H@
M=?2)P8GV0(H0@/H@=/B$TG7K*=F)R%O)PXG!*=F)R%O)PU6)Y5=64X'L-`@`
M`(M%#%"-E>C[__]2BW40BWT4BUT8B87D]___Z'WU__^+C>3W__\!P8/$$(7`
MB8W<]___=`GVPP$/A)(```!0:@!6C;7H^___5NC[]/__@\00]L,(#X7_`0``
M]L,$#X42`@``@^P(:B[_M=SW___HWGO]_X/$$(7`#X0E`@``]L,"#X6]````
MBXW<]___BA&$THG(=0_K(HGV0(H0A-(/A'\"``"`^B!U\(G!B?9`BA"`^B!T
M^(32=>N)SBNUW/?__\>%X/?___2;&`CI@@```/?#@`````^$=?___X/L#(V-
MZ/O__U'H.BX!`(/$$(7`#X5;____4(V-Z/O__VC_`P``48V%Z/?__U#HRCT`
M`(/$#&H`5HVUZ/O__U;H*/3__XG!*?&^_P,``(/$#"G.5HV5Z/?__U)0Z)P]
M``#I#/___XG0B<8KM=SW__^)O>#W__^Z_____S'`_(G1C;WH^___\J[WT8F-
MU/?__XN]X/?__XG1\JXIC=3W__^+E=3W__^-?#+]@?__`P``=PR!_O\````/
MAD$!```QP/;#0`^%@@```(N-Y/?__XH1A-*)R'4-ZR!`BA"$T@^$7`$``(#Z
M('7PB<&)]D"*$(#Z('3XA-)UZU")R"N%Y/?__SW_`P``=@6X_P,``%#_M>3W
M____=0CHX#P``(/$$/;#('0NP>L$@^,!@_L!&=OWTX'C@````%!3_W4(_W4(
MZ!P"``"#Q!"+10B-9?1;7E_)PX/C$'3P@^P(_W4(C;WH]___5^@//```@\0,
M:@!7_W4(Z`D!``"#Q!#KRX/L"(VUZ/O__U96Z$3O__^#Q!#VPP0/A.[]__^#
M[`B-C>C[__]14>A@[/__@\00@^P(:B[_M=SW___HN7G]_X/$$(7`#X7;_?__
MBX7<]___B<**"(3)#X2/_O__@/D@ZQ"-=@!"B@*$P`^$>O[__SP@=?&)T(UV
M`$**"H#Y('3XZ]*+A>3W__\Y10AT5E=6_[7<]___@^P,C;7H^___5O]U".A5
M.P``@\044.C0.P``6EG_M>#W__]0Z#X[``#IW?[__XG!Z;+^__^)P8G.*[7<
M]___QX7@]___])L8".D6_O__4%;_M=SW__^-O>CW__]7Z$%S_?^#Q!")O=SW
M___KBXGV58GE5U93@^P0:/\#``"+70A3BWT,5^C9<_W_,?:#Q!"%P'@0Q@0#
M`(UE]%N)\%Y?R<.)]NBK=?W_BP"#^!:C8.D8"'0H]D40$'4'OO_____KUNB-
M=?W__S!7:@!J&.BQY/__OO____^#Q!#KNX/L"%=3Z($Z``!FO@$`@\00ZZA5
MB>575E.#[!2+=0Q6BUT(4^B>=OW_,?^#Q!"%P'4-C67T6UZ)^%_)PXUV`.@S
M=?W_BP#V11`0O_____^C8.D8"'3<@^P0Z!EU_?]:_S!35FH`:AGH.^3__X/$
M(.O!B?95B>575E.![&P$``"+=1`Q__?&@````(M=#'0L@^P(C86(^___4%/H
MR'3]_X/$$(7`=3X/MY60^___@>(`\```@?H`H```=2F#[`B-C>C[__]14^B,
M<_W_@\00A<!T'5-H_P,``%#_=0CH+CH``(/$$(UE]%M>B?A?R<.0Z(-T_?^+
M`(/F$*-@Z1@(=1-1:@!3_W4(Z!<```"______^O.4%-J`&H:Z(GC__^#Q!#K
MW56)Y5=64X'L'`0``(M=#(`[?HMU"(M]$`^$@@```(/L#%/H$2H!`(/$$(7`
M=":#[`A3C;WH^___5^@J.0``6%I75N@A.0``C67T6XGP7E_)PXUV`,>%Y/O_
M_P````"`.RYT28/L"&@3L1@(4^C+.0``@\00A<!U1(7_=$!J`%-7C;WH^___
M5^CX.```6%I75NC3.```C67T6XGP7E_)PY"`>P$O#X5T____ZX*`>P$O=;''
MA>3[__\"````46H`,<#\B=^Y______*N]]&+A>3[__\IR`4!!```4(V]Z/O_
M_U?HM2@!`(/$$(7`=2:+E>3[__^-#!.#[`A15^CS<OW_6%I75NA>.```C67T
M6XGP7E_)PX/L"%/I&____XUV`%6)Y5=64X/L#(M5##')A=*-?0QT&(U5%(M:
M_(/#!X/""(/C^(M"^`'9A<!UZX/L"/]U"%'HH]K__XG&@\00,<"%]G0FB?.-
M3P2+!^L7C78`BQ&#P@>->02#XOB)&(/!"`'3BP>%P'7HB?"-9?1;7E_)PXGV
M58GE5U93@^P,BUT0BWT4@WT(`<<#`````(MU#,<'`````'\(C67T6UY?R<.#
M[`AH.K$8"/]V!.AL.```@\00A<!T#8M&!(D#C67T6UY?R<.#[`AH2[$8"/]V
M!.A(.```@\00A<!TO8M6!(D7Z[:)]E6)Y5=6@^PHBW4(_(U]V(/N(+D(````
M\Z6-1=AJ`%#H<//__XUE^%Y?R<.058GE5U93@>S,%```B95LZ___NO____^)
MA7#K___'A63K__\`````,<#&A6/K__\`QH5BZ___`/R)T8M]$/*NBUT(]]&%
MVXUQ_P^$`0<``(G1B=_RKO?1C40Q_SW\`P``#X?;`0``A=L/A.X&``!1:@!3
MC978^___4NBN[?__@\00@#M^#X3#`0``:@#_=0S_=1!0Z+PV``#'!"0$````
M:/2;&`AH])L8"(VUV/O__U96Z"+X__^#Q!QJ`(V->.O__U%6Z.PR``"#Q!"%
MP+H!````#X1K`0``#[>%@.O__Z@"=!`E`/```#T`@```#X0\`0``4&H`:@!J
M!&CTFQ@(:/2;&`B-M=C[__]65NC']___@\044.@6*0$`@\00,=*%P(F%:.O_
M_P^$%@$``(UV`%#_M6CK__]H_P\``(VUV.O__U;HS&[]_X/$$(7`#X1Y`@``
M_X5DZ___#[:%V.O__XL=P/H8"/9$`P$(C;W8Z___#X3A````D$>*%P^VRO9$
M"P$(=?.`^B-TIH#Z.W2AA-)TG8#Z(0^$QP```(#Z6P^$QP,``("]8NO__P`/
MA*P&``"`O6/K__\`#X1Q____,?:$THGYQH5/Z___``^$&`(``(H'ZSX\(G0^
MB?*$TG4(/",/A/D!``")\H32QH4WZ___`'0(/%P/A+\#``"*A3?K__]!B(5/
MZ___B@&$P`^$U@$``#PG=;Z`O4_K__\`=;F)\H32#X6J`P``B<;KJU)6:)BQ
M&`C_->A#)0CH<V_]_S'2C67T6UZ)T%_)P\8`+D#I-/[__XGVBI78Z___Z2+_
M__^#?1@)#X\X____C7<!#[9'`>L$1@^V!O9$`P$(=?50:@IHA;$8"%;HY6_]
M_X/$$(7`#X6&`P``#[9^"O9$.P$(#X1W`P``@\8*B;5$Z____X5$Z___BY5$
MZ___#[8R]D0S`0AUZHG7_+G_____,<#RKO?1C501_NL!2@^V<O_V1#,!"'7T
MQ@(`.Y5$Z___#X2/!0``@^P(:A#_M43K___H/3$``(/$$(7`B858Z___#X0!
M!0``BU`$A=+'A5SK__\`````=&^+M5CK__^+/HN%7.O__XT<QX/L#/\SB9U4
MZ___Z`(F`0"+#4SR&`B#Q!"%R8G&NTSR&`@/A$X#``"#[`C_,U;HAW#]_X/$
M$(7`#X0Z!```@\,$BQ.%TG7A_X5<Z___BY5<Z___BYU8Z___.5,$=Y&#[`S_
MM5CK___H<B\``(/$$%#_M6CK__]H_P\``(VUV.O__U;H4VS]_X/$$(7`#X6'
M_?__@^P(:@#_M6CK___HN"4!`.E@_O__Q@$`BQW`^A@(@^P(:CV)C4#K__]7
MZ#EQ_?^#Q!"%P(G"B<%T#HF%0.O__^L&_XU`Z___B[5`Z___#[9&__9$`P$(
M=>F%R0^$C`,``(UQ`0^V0@'K!$8/M@;V1`,!"'7U@^P,5NBN,P``B<.#Q!`/
MMD#_BQ7`^A@(ZP5+#[9#__9$`@$(=?0Y\W,"B?.*!CPB#X29`0``/"</A)$!
M``"+A4#K__\I^(F%2.O__XG9*?&+E4CK__^#[`B-1`H$4/^U;.O__^BJ[?__
M@\00A<")A73K__\/A%X#``"#[`B-C73K__]1_[5PZ___Z+P,``"#Q!"$P`^%
M/@,``%+_M4CK__]7@^P,:,+-&`C_M73K___H0C(``(/$%%#HA3(``(/$$#G>
MQ@`]C4@!=`^*%H#Z7'00B!%!1CG>=?'&`0#I#?S__XU[_SGW=.E&#[X&@_AN
M#X30````#X^I````@_A<#X11`@``#X\Y`@``@_@B#X14`@``@_@G#X35`@``
MQ@%<BA:(40%&@\$"ZZN#[`AJ78UW`5;&A6+K__\!Z+-O_?^#Q!"%P(G"=0?I
MK0(``)!*#[9Z__9$.P$(=?3&`@!7:@/_=116Z&'I__^#Q!"%P`^?A6/K___I
M=/O__X"]3^O__P`/A33\___&A3?K__\!Z2C\__^)\CC0#X7[^___,?;I^OO_
M_X/X<P^$L0$```^/?@$``(/X<@^%8/___\8!#4'I#____\8!"D'I!O___SI#
M_P^%9O[__T9+Z5_^__]0:@=HD+$8"%;H1FS]_X/$$(7`#X7W^O__#[9&!_9$
M`P$(#X3H^O__@\8'1@^V#O9$"P$(=?7\N?____\QP(GW\J[WT8U4,?[K`4H/
MMDK_]D0+`0AU]#GRQ@(`#X3Q`0``BU48@^P,0E+_=116:/2;&`AH])L8"(N5
M;.O__XN%<.O__^A8^?__@\0@Z8#Z__^A3/(8"(7`#X3$_/__B[54Z___BSXQ
MP/RY______*NB<N+O43K__^Y______*N]]/WT8/L"`'94?^U;.O__^AAZ___
M@\00A<")A73K__\/A!4!``"#[`QJ1&CTFQ@(_[5$Z____S90Z+SQ__^+=1B#
MQ!1&5O]U%/^U=.O__VCTFQ@(:/2;&`B+E6SK__^+A7#K___HN/C__X/$(.DQ
M_/__@?[\`P``#X?E^O__@^P(_W40C9W8^___4^C*+P``Z27Y__^#^'0/A>+]
M___&`0E!Z9']__^#^&(/A=#]___&`0A!Z7_]___&`5Q!Z7;]___&`2!!Z6W]
M___&`2)!Z63]__^+`^G\_O__BYU`Z___*?N#[`B-2P-1_[5LZ___Z('J__^#
MQ!"%P(F%=.O__W0Y5E-7@^P,:,+-&`A0Z$<O``"#Q!10Z,(O``!96XV==.O_
M_U/_M7#K___H?@D``(/$$(3`#X07^?__@^P(:@#_M6CK___H:R$!`+K_____
MZ1#Z___&`2=!Z=K\____M63K__^-A=C[__]0:,RQ&`C_->A#)0CH6VG]_X/$
M$.N[_[5DZ___C8W8^___46@,LA@(Z]S_M63K__^-G=C[__]3:%BR&`CKR/^U
M9.O__XV]V/O__U=HF+(8".NTB?95B>575E.![,````"+70S&19,`QT6,````
M`&H`:``"``"-39A1Z$KH__^+11"+$(F51/___X/$$$H/CJD```"+?12+!XM0
M!(F%=/____RY#@```+]BL1@(B=;SI@^%D0```(N-1/___X/L"(TTC20```!6
MC5V84^@\Z?__@\00A<")18@/A'X"``"+312)PXLQBT40BU6(BSZ+"(/#((EZ
M((/Y`KH"````ZPN0BP26B423_$(YT7?TC4'_BTT0B0''1)/\`````(M]B(M5
M%(UUF/RY"````(D:\Z6-9?1;7C'`7\G#C78`BW44BSZ)O73___\Q_X.]1/__
M_P''!4CR&`@`````#X\<`@``BQ5(\A@(A=(/A;L!``"%_P^5P<=%O'BQ&`B#
M^@$/MO&+$X/>_X72QT6X`````(E=P'02,<"-=@"#PP2+$T"%TG7VB46X:B"+
M11#_,&H$C5W(4^B]!@``@\00A,`/A9H!``"%_P^$^@$``(/L#&H`C4VX45=H
M])L8"&CTFQ@(C568C47(Z,_U__^#Q""%P(E%C`^,90$```^/1P$``(M5$(L"
M`T7,@^P(C0R%)````%&-79A3Z//G__^#Q!"%P(F%</___P^$,@$``(/`((F%
M;/___XM%%(L(BQF+E7#___^+?<R)6B#!YP)35X/")/]UR%+HA67]_XM%$(L8
MBWT4*?.+#XTTL8/$$(/[`8D8B;5H____B3=^,HM6!/RY$0```+]PL1@(B=;S
MIG4>@X5H____!(US_XM]$(N%:/___XM=%,9%DP&)-XD#BU40BP*%P'0GBYUH
M____B[5L____C0R%_/___X/#!(M%S(U\A@3\P>D"B=[SI8L"`T7,BY5L____
MBTT0BUT4B0''!((`````@^P,B1.+O7#____\C57(N0@```"-=9CSI5+HIP<`
M`(/$$(!]DP"+18P/A?@!``"-9?1;7E_)PX/L"&H]4NBX:?W_0(/$$(G"HTCR
M&`CI*O[__U)7:-RR&`C_->A#)0CH%F;]_X/$$(UV`/\UZ$,E"&HR:@%H"+,8
M".@<:?W_QP0D`0```.@@:?W_@^P(:#JQ&`B+E73_____<@3H,BP``(/$$(7`
M#X1-`0``BX5T____BW@$A?\/A++]__^#[`AJ/5?H,VG]_XUX`8/$$.F<_?__
M@^P,_W4(Z-'A__^#Q!"%P`^%Q0```*$T\A@(A<#'190T\A@(#X0/_O__B<.`
M.P!T4Z%,\A@(A<"_3/(8"'0OD(/L#&H`C56X4O]U"/\W4XU5F(U%R.B:\___
M@\0@A<`/B#/___^#QP2+!X7`==*#190$BWV4BQ^%VP^$NOW__X`[`'6MBSU(
M\A@(A?]TX*%,\A@(A<"[3/(8"'32@^P,:@"-1;A05_\S:@"-59B-1<CH/_/_
M_X/$((7`#XC8_O__@\,$BP.%P'73@T64!(M]E(L?A=MUJ>E>_?__H4SR&`B%
MP(U]N+M,\A@(="B#[`QJ`%?_=0C_,VH`C568C47(Z/#R__^#Q""%P'@+@\,$
MBP.%P'78,<"%P(E%C`^)&/W__^ER_O__@^P(:$NQ&`B+M73_____=@3HQ"H`
M`(/$$(7`#X15_/__BTX$B0U(\A@(Z4?\__^+=12#[`B+/O\W:#RS&`CH?V']
M_XM%$(/$$(,X`;L!````?B"+112#[`B+"/\TF6B!L1@(Z%IA_?]#BU40@\00
M.1I_X(/L#&CTFQ@(Z))B_?_'!"0`````Z"9G_?^)]E6)Y5=64X'L&`0``&AX
MLQ@(Z&YB_?]>_W4(Z`G@__^#Q!"%P`^%%P$``(L=-/(8"(7;OC3R&`@/A(``
M``"-O>C[__^0BPU,\A@(NTSR&`B%R>L4D*%(\A@(A<!U$XUV`(/#!(L#A<!T
M2XL&@#@`=.12:@!05^CRW___@\00@+WH^___?@^$K@```(/L#&H`:-N,"`C_
M,_]U"%#H]2@``(/$&/\UX$,E"%?HUF;]_X/$$.NMD(/&!(L6A=)UAX/L#&CT
MFQ@(Z+IA_?^#Q!#_->!#)0AJ'FH!:,"S&`CH,V;]_XM]#(LW@\00A?9T-8UV
M`(/L"/\UX$,E"&H@Z.1E_?]86O\UX$,E"(M=#/\SZ')F_?^#10P$@\00BWT,
MBS>%]G7.@^P,:."S&`CH56']_XUE]%M>7\G#D,8`+D#I2?___X/L"/\UX$,E
M"/]U".@R9OW_Z7/___^058GE5U93@^P4BW4,BPZ-%$F-!)+!X`.Z'X7K4??B
MB=#!Z`6#P`R+?1")!VH04.B!RO__B<.#Q!`QP(7;="'_-O]U"%=3Z*)E_?^#
MQ!"%P'4<BP>+%CG0<PZ)!HD7B=B-9?1;7E_)P\<'`````(/L#%/HWLK__S'`
MZ^6)]E6)Y5=64X/L#(M]#(L'@_@QBUT0=Q+'`P````"-9?1;7C'`7\G#B?:-
M%$"-!)+!X`.Z'X7K4??BB=#!Z`6#[`B#P`R)`VH04.CKR?__@\00A<")QG1*
M_S?_=0A34.@.9?W_@\00A<!U*XL#BQ<YT',=B0>)$U#_-U;_=0CH#V#]_XDT
M).A/RO__@\00ZX['`P````"#[`Q6Z#O*__^#Q!`QP(,[``^4P(UE]%M>7\G#
M58GE5U93@^P,BUT0BP.%P(M]#'4+,<"-9?1;7E_)PY"#[`AJ$%#H7<G__XG&
M@\00A?:X`0```'3>_S?_=0A35N@K7OW_@\00A<!T$(/L#%;HT\G__[@!````
MZ[N+`XD'4E!6_W4(Z'5?_?^)-"3HM<G__X/$$.N=58GEBT445H7`4XMU"(M-
M#(M=$'4;,=)FN/@?]_&#^!!R4H/["'8)C10;.<)R3HGVA=MU`HG#@^P(B4X0
MQT8$`````(E>"(E&#`^ORVH04>B\R/__@\00,=*%P(D&=0G'1@@`````L@&-
M9?A;B=!>R<.-=@"X$````.NGD(G0Z[!5B>534HM="(M3!#M3"'04B=`/KT,0
M0@,#B5,$BUW\R<.-=@!0:E`#4PP/KU,04O\SZ!K+__^)PH/$$#'`A=)TVXM#
M#(D3`4,(BU,$Z\*)]E6)Y5-1BUT(BT,$.T,(="")P8M3$`^ORD`#"XE#!%-2
M_W4,4>AO7OW_,<"+7?S)PU)J4`-##`^O0Q!0_S/HOLK__X/$$#'2A<")P708
MB0.+0PP!0PB+0P2)P@^O4Q!`C101B4,$A=*)T;@!````=+N+4Q#KJ8UV`%6)
MY8M-"(M1!#'`A=)T#(U"_XE!!`^O01`#`<G#C78`58GE5U93@^P,BUT(BWT0
MBTL$.?EW)SE["'9!BT,0B?HIR@^OR`,+#Z_05E)J`%&-=P'H.6']_XES!(/$
M$(MS$(GQ#Z_/`PM35O]U#%'HKEW]_S'`C67T6UY?R<.+2PR-%#F)T#'2]_&)
MQE!J4(M#$`^O\0^OQE#_,^CJR?__B<*#Q!"%TK@!````=,B+2P2)$XES".N%
MB?95B>53BTT(BT40.4$$BUT,=QJ+01")11#'10P`````B5T(6\GIKV#]_XUV
M`(M1$`^OP@,!B44,B540B5T(6\GI)%W]_U6)Y5-0BUT(BP.%P'4&BUW\R<.0
M@^P,4.A/Q___QP,`````QT,(`````,=#!`````"#Q!"+7?S)PXUV`%6)Y593
MBU4(BTH0BT($BW4,B<M(B4($#Z_>*?`#&@^OP5)0`=E14^@,7/W_C67X6U[)
MPY!5B>564XMU"(M>!(/[`7,%NP$```"+%H72=!TY7@AT&%%J$(M&$`^OPU!2
MZ.S(__^)!HE>"(/$$(UE^%M>R<.058GE5U93@^P,BUT(@\,'H>SF&`B#X_@Q
MR87`O^SF&`AT%XGVBU`$.=IS33G*=@*)T8G'BP"%P'7KC02-`````(L5Z.88
M"#G0C7,0<P<YUG)#C78`@^P,5NAG7/W_@\00A<!T-(GQC5;PQP``````B7`(
MB0?K#(GVA<!TO8M0!(M(""G1*=J)4`2-!`&-9?1;7E_)PXG6Z[SHUUW]_XL0
M]D4,&(D58.D8"'4$,<#KW5!6:B1J!>CJS/__@\00,<#KRXUV`%6)Y5=64X/L
M##'`BWT(_+G_____\JZ)R_?3C7L'H>SF&`B#Y_@QR87`QT7P[.88"'08B?:+
M4`0Y^G-1.<IV`HG1B47PBP"%P'7JC02-`````(L5Z.88"#G0C7<0<P8YUG)9
MB?:#[`Q6Z)-;_?^#Q!"%P'1+B?*)<`B-3O"+=?#'``````")!NL-C78`A<!T
MNHM(!(M0""G**?F)UP''B4@$=`Y24_]U"%?H`EO]_X/$$(UE]%M>B?A?R<.)
MUNNEZ.Q<_?^+$/9%#!B)%6#I&`AU!#'_Z]M15FHD:@7H_\O__S'_@\00Z\E5
MB>575E.#[`R+70R#PP>A[.88"(/C^#')A<"_[.88"'07B?:+4`0YVG--.<IV
M`HG1B<>+`(7`=>N-!(T`````BQ7HYA@(.="-<Q!S!SG6<EB-=@"#[`Q6Z+M:
M_?^#Q!"%P'1)B?*-3O#'``````")<`B)!^L,B?:%P'2]BT@$BU`(*<HIV8G3
M`<.)2`1T$%;_=0S_=0A3Z"Q:_?^#Q!"-9?2)V%M>7\G#B=;KI^@67/W_BQ#V
M11`8B15@Z1@(=00QV^O;5U9J)&H%Z"G+__\QVX/$$.O)B?95B>534(L=[.88
M".L3C78`B=B#[`R+&U#H4U_]_X/$$(7;=>S'!>SF&`@`````BUW\R<.058GE
MBTT(A<F+10QT$XL1A=)T`XE"!(D0B4@$B0')PY#'``````")2`3)PY!5B>6+
M30Q3BQ&%THM="'04BT$$B4($BT$$A<!T`HD0B=A;R<.+602)V.OND%6)Y5:+
M=0B%]E-T((M%#(7`=2&0@^P,BUX$5NB,P___@\00A=N)WG7KC78`C67X6U[)
MPY"#[`R+7@3_=@CH:L/__XDT).ABP___@\00A=N)WG39@^P,BUX$_W8(Z$O#
M__^)-"3H0\/__X/$$(7;B=YUPNNX58GE4X/L#&H(:@R+70SHA<+__XG"@\00
M,<"%TG0<BT4(A=N)0@AT&(L#A<!T`XE0!(D"B5H$B1.)T(M=_,G#D(G0QP(`
M````B5H$Z^V-=@!5B>6+30B)RH7)ZPZ)RHL"BTD$B0J)0@2%R77PB=#)PU6)
MY8M5"#'`ZP:)]HM2!$"%TG7XR<.)]E6)Y5=64X/L#(M="(M]#(MU$.L3@^P(
M5O]S"/_7@\00A<!U"8M;!(7;=>DQP(UE]%M>7\G#C78`58GE4X/L$(M=#/]U
M".@.6_W_B44,B5T(@\00BUW\R>D@'P``58GE4U"+50B+10PQVSG"=!6#[`C_
M<!#_<A#HO5O]_X/$$(7`=06[`0```(G8BUW\R<.)]E6)Y5=64X/L%(E%\&H0
M:``!``#H3/O__XM5\(/$$(7`B4)`N@$```!U"HUE]%M>B=!?R<.#[`AJ$&@`
M`0``Z"'[__^+7?"#Q!"%P(E%Z(E#1+H!````=-*+0T`Q_XG#B47LZQ6H!`^$
MV````,8##4=#@?__````=R&)^(M5\`^V\(M*(`^V1#$!J`-TUT?&`P)#@?__
M````=M^+7>PQTL9#)`+&0U\"QD,G"<9#+@_&0R$'QD,]!\9#/@?&0SP(QD-\
M$,9#)A#&0R,*QD,[%<9#.A;&`Q'&0UP2QD,O$\9#*A3&0T`7QD-@&L9#(B#K
M$SP-=!N+?>B(#!="@?K_````=QV+=>R*!!8QR3P"=>&Q`8M]Z(@,%T*!^O\`
M``!VXXM%[,9`6!W&0'@=QD!B'L9`3A_&0&X?C67T6UXQTHG07\G#D(/L"(M-
M\(M!6%=1_U`(@\002`^/,?___XM5\(M*(`^V1#$!P>@#@^`!@_@!&=*#XNB#
MPAF($^GP_O__D%6)Y5=64X/$@%*)QXU%B%!7B=;HT!D``(/$$(7`=`N+7;B!
M^P``$`!V#K@!````C67T6UY?R<.0@^P(5E/HOK___X/$$(7`B46$=-Y05FH`
M5^C.Q/__@\00A<")QW@T4%/_=817Z!Y8_?]9B<-85E?HX\+__X/$#&B40P<(
M4_]UA.@V,0``6O]UA.@1P/__,<#KG(/L#/]UA.@"P/__ZXI5B>534:%8\A@(
MA<"+70AT'U)H_P,``%!3Z#(=``"#Q!!0:@!34^B5T___BUW\R<.#[`QH(+48
M".A?#0$`@\00A<!T+(/L#&H`:$&U&`AH2;48"&@@M1@(4^B*'```@\0@4&H`
M4U/H5=/__XM=_,G#@^P(:$NU&`AH(+48".@>'0``@\00A<!UNU!J`&A!M1@(
M:$FU&`AH(+48"&A)M1@(:$NU&`CKL9!5B>6+10B+$(%(#``"``")!)5@%B8(
MR<-5B>6#[!!J$/]U".AT^/__R<.)]E6)Y593@>P`!```BQ4X%"8(B<8QP(72
M=`N-9?A;#[[`7LG#D%-H``0``&H`:&`6)@CH'EC]_[M@%B8(B30DZ!T0``"#
MQ!"!^UP:)@AS'HGVBP.%P'0+BT@@A<D/A:,```"#PP2!^UP:)@ARY*%8\A@(
MA<"-G?C[__\/A:````"#[`QH(+48".@\#`$`@\00A<!U'8/L"&A+M1@(:""U
M&`CH)QP``(/$$(7`#X2!````@^P,:@!H0;48"&A)M1@(:""U&`A3Z$H;``"#
MQ"!0:@!34^@5TO__6EEH8+48"%#H%!L``(GRB=CHG_W__\<%.!0F"`$```"#
MQ!"-9?A;#[[`7LG#Z`/\__^$P`^$4/___\<#`````(/#!.E%____4FC_`P``
M4%/H4!L``(/$$.N<4&H`:$&U&`AH2;48"&@@M1@(:$FU&`AH2[48".ER____
MB?95B>564S'`NV`6)@B+=0CHF/[__X'[7!HF"',8BP.%P'0'BU`4A=)U%X/#
M!('[7!HF"'+H,<"-9?A;7LG#C78`45;_<!1HH/H8"*'\^A@(_U`8@\00A<!U
MT(L+BP'KUY!5B>575E.#[`R+70B+>Q2%_P^$:0$``(LSA?8/A&L!``"+/+5@
M%B8(A?\/A+@!```Y<P0/A/@!```Y<P@/A.8!``"+#+5@%B8(B4WPBT,,BU7P
M"T(,J`&)0@P/A=````"%]HGP=0*+`HM5\(D"BT,0A<`/A>@!``"+0Q2%P`^%
M+@(``(M#&(7`#X5L`@``BT,@A<`/A8<"``"+0R2%P`^%J`,``(M#*(7`#X7&
M`P``BT,LA<`/A>0#``"+0SB%P`^%`@0``(M#'(7`#X6^`0``BW,0_+D%````
MOVJU&`CSI@^%F`(``(M5\*$XER,(B4)8BPT\ER,(BS4HER,(9HL]-)<C"&:A
M-I<C"(%*#`@"``")2ER)<DAFB7I49HE"5L="3`(```#'0E`"````ZR>0BT,8
MBU7PA<"),@^%^@```(M#$(7`#X6)`0``BT,4A<`/A0("``#'`P````#'0P0`
M````QT,(`````,=#%`````#'0RP`````QT,,`````)`QTHUE]%M>B=!?R<,Q
MP+Y@%B8(Z+3\__^!_EP:)@AS&(L&A<!T!XM(%(7)=1N#Q@2!_EP:)@ARZ#'`
MA<")`XG&#X5;_O__Z[A25_]P%&B@^A@(H?SZ&`C_4!B#Q!"%P'7,BQ:+`NO3
MD(/L"&H`:F#HR/3__X/$$(7`B02U8!8F"+H!````#X1W____BS-1:F!J`/\T
MM6`6)@CH@E3]_X/$$(LSZ0C^__^#2PP0Z1'^__^#2PP@Z?_]__^#[`AJ$%#H
M._7__XMU\(/$$(7`B488N@$````/A"?____IX/[__X/L"&H04.@5]?__@\00
MBWWPA<")1Q`/A?S]__^Z`0```(UV`(UE]%M>B=!?R<.#[`AJ$%#HY_3__X/$
M$(M5\(7`B4(<#X4F_O__N@$```#KTX/L"&H04.C$]/__@\00BW7PA<")1A0/
MA;;]__^Z`0```.NP@^P(:A!0Z*'T__^+3?"#Q!"%P(E!$+H!````#X2-_O__
MZ5'^__^#[`AJ$%#H>_3__X/$$(M-\(7`B4$8#X5X_?__N@$```#I9/___U)J
M$&@!`0``4.@Z]?__@\00BU7PA<")0B`/A#W___^)T.@2^/__A,`/A$O]__^Z
M`0```.DL____@^P(:A!0Z!WT__^+??"#Q!"%P(E'%+H!````#X0)_O__Z=C]
M__^+$XL$E6`6)@CV0`P0BW`L#X1<`0``QT!<``P9",=`6$`(&0B+!)5@%B8(
MBTWPBW@0QT%,`0```,=!4`$````QR87_=#:+>#B%_W0OBW@@A?]T*(MX*(7_
M="&+>"2%_W0:BSB%_W04BW@4A?]T#8MX+(7_=4_V0`P0=4F%R70+BP258!8F
M"(-(#`B+%)5@%B8(BTH,B<B`S`*%]HE"#`^$-/W__XI&83A&00^#*/W__SI&
M0@^#'_W__X#-!HE*#.D4_?__N0$```#KL(UV`%=J$&@``0``4.@.]/__@\00
MBU7PA<")0B0/A3G\__^Z`0```.D/_O__5FH0:``!``!0Z.7S__^#Q!"+??"%
MP(E'*`^%&_S__[H!````Z>;]__]1:A!H``$``%#HO//__X/$$(MU\(7`B48L
M#X7]^___N@$```#IO?W__U)J$&@``@``4.B3\___@\00BTWPA<")03@/A=_[
M__^Z`0```.F4_?__QT!<``@9".F?_O__58GEQP4X%"8(`````,G#D%6)Y5=6
M4X/L##'`NV`6)@B+?0B+=0SH)?G__X'[7!HF"',@D(L#A<!T#HM($(7)=`>%
M<`QU%XGV@\,$@?M<&B8(<N$QP(UE]%M>7\G#4E?_<!!HH/H8"*'\^A@(_U`8
M@\00A<!UTHL3BP+KV56)Y5-0BUT(,<#HQ?C__XL$G6`6)@B%P'0$.1AT"K@6
ML1@(6UO)PY"+0!2%P'7TN!:Q&`CK[8GV58GE5U93@>PL"```H53R&`B+?0@Y
M.(G"=&XQP.A[^/__C4__,=*!^?T```!W6HLTO6`6)@B%]@^$!P$``(M&#*@!
M=%#VQ`*)\W4",=N%VXG>#X3M````]D,-`74ABU-8BP*%P`^%X@$``(M&7(L`
MA<`/A;0```"!2PP``0``A?8/A+X```")\HUE]%M>B=!?R<.)]J@(=:RA6/(8
M"(7`C9WH^___#X5D`0``@^P,:""U&`CHK`0!`(/$$(7`=1V#[`AH2[48"&@@
MM1@(Z)<4``"#Q!"%P`^$C0$``(/L#&H`:$&U&`AH2;48"&@@M1@(4^BZ$P``
M@\0@46H`4U/HA<K__X/$$&H`:&6U&`C_=A!0Z)H3``"#Q!"+50R)V.@%]O__
MBT8,Z1G___^#[`AHS$$'"%;_T(/$$(3`#X0V____,?:0]D4,$`^$./___Z%8
M\A@(A<!T;5)H_P,``%"-G>CW__]3Z*X3``"#Q!!3:@"-A>CW__]04.@+RO__
M6EEH8+48"%#H"A,``(/$#&H*C97)]___4E>-O>CW___&A<CW__\CC9W(]___
MZ)T4``!74VH$:A;H]KS__X/$((GRZ<3^__^#[`QH(+48".B3`P$`@\00A<!U
M3(/L"&A+M1@(:""U&`CH?A,``(/$$(7`=3-0:@!H0;48"&A)M1@(:""U&`AH
M2;48"&A+M1@(ZRE2:/\#``!04^C\$@``@\00Z=7^__^#[`QJ`&A!M1@(:$FU
M&`AH(+48"(V-Z/?__U'H;!(``(/$(.DA____@^P(:,Q!!PA3_]"#Q!"$P`^$
M"/[__S'VZ=O^__]0:@!H0;48"&A)M1@(:""U&`AH2;48"&A+M1@(Z6;^__^)
M]E6)Y5=64X'L#`@``#'`BWT,NV`6)@CH]?7__S'`Z.[U__^!^UP:)@AS&HGV
MBP.%P'0'BW`4A?9U9X/#!('[7!HF"'+H,?:#YQ!T2J%8\A@(A<"-G>CW__\/
MA!X!``!2:/\#``!04^@A$@``@\004&H`4U/HA,C__UE?:&"U&`A0Z(,1``!3
M_W4(:@1J'.B2N___@\0@C67T6XGP7E_)PY!1_W4(_W`4:*#Z&`BA_/H8"/]0
M&(/$$(7`#X5Z____BQ.+`H7`#X1Y____BQR%8!8F"(7;#X20````BT,,J`%U
M4Z@(=4^A6/(8"(7`C;7H^___#X3Q````4FC_`P``4%;HAQ$``(/$$%%J`%96
MZ.K'__^#Q!!J`&AEM1@(_W,04.C_$```@\00B?J)\.AK\___BT,,]L0"B=YU
M`C'VA?:)\W0G]D8-`74ABTY8BP&%P`^%X@```(M#7(L`A<`/A?(```"!3@P`
M`0``A=N)W@^%(?___^G-_O__C78`@^P,:""U&`CH3P$!`(/$$(7`="*#[`QJ
M`&A!M1@(:$FU&`AH(+48"%/H>A```(/$(.F\_O__@^P(:$NU&`AH(+48".@8
M$0``@\00A<!UQ5!J`&A!M1@(:$FU&`AH(+48"&A)M1@(:$NU&`CKNX/L#&@@
MM1@(Z.(``0"#Q!"%P'49@^P(:$NU&`AH(+48".C-$```@\00A<!T7(/L#&H`
M:$&U&`AH2;48"&@@M1@(5NCT#P``@\0@Z=#^__^#[`AHS$$'"%;_T(/$$(3`
M#X0(____,=OI%?___X/L"&C,00<(4__0@\00A,`/A/C^__\QV^GX_O__4&H`
M:$&U&`AH2;48"&@@M1@(:$FU&`AH2[48".N:58GE5U93@>P,"```,<"+=0R+
M?1"[8!8F".AB\___,<#H6_/__X'[7!HF"',BC78`BP.%P'0.BU`0A=)T!X5P
M#'5HB?:#PP2!^UP:)@ARX3'V@^<0=$JA6/(8"(7`C9WH]___#X0;`0``4FC_
M`P``4%/HA@\``(/$$%%J`%-3Z.G%__]?6FA@M1@(4.CH#@``4_]U"&H$:A;H
M][C__X/$((UE]%N)\%Y?R<-1_W4(_W`0:*#Z&`BA_/H8"/]0&(/$$(7`#X5[
M____BPN+`87`#X1Z____BQR%8!8F"(7;#X20````BT,,J`%U4Z@(=4^A6/(8
M"(7`C;7H^___#X3O````4FC_`P``4%;H[0X``(/$$%%J`%96Z%#%__^#Q!!J
M`&AEM1@(_W,04.AE#@``@\00B?J)\.C1\/__BT,,]L0"B=YU`C'VA?:)\W0G
M]D8-`74ABU98BP*%P`^%_0```(M#7(L`A<`/A=,```"!3@P``0``A=N)W@^%
M(O___^G._O__D(/L#&@@M1@(Z+?^``"#Q!"%P'0B@^P,:@!H0;48"&A)M1@(
M:""U&`A3Z.(-``"#Q"#IO_[__X/L"&A+M1@(:""U&`CH@`X``(/$$(7`=<57
M:@!H0;48"&A)M1@(:""U&`AH2;48"&A+M1@(Z[N#[`QH(+48".A*_@``@\00
MA<!U&8/L"&A+M1@(:""U&`CH-0X``(/$$(7`=%R#[`QJ`&A!M1@(:$FU&`AH
M(+48"%;H7`T``(/$(.G2_O__@^P(:,Q!!PA3_]"#Q!"$P`^$%____S';Z1?_
M__^#[`AHS$$'"%;_T(/$$(3`#X3M_O__,=OI^O[__U!J`&A!M1@(:$FU&`AH
M(+48"&A)M1@(:$NU&`CKFE6)Y5=64X/L#(M5"(M"6(MU$(MX!(7_B?</E47O
M`WT4BUT,.?Z)7?!T-HGV@'WO``^%B@```(H6#[["@_@:#X2L````?RJ#^`H/
MA-H```!_/H7`=%R-=@"($T9#.?YUS,8#`"M=\(UE](G86UY?R<.#^"</A+\`
M``!_)8/X(G78Q@-<QD,!(H/#`HGV1NO-@_@-=<3&`US&0P%R@\,"Z^R#^%QU
ML\8#7,9#`5R#PP+KV\8#7,9#`3"#PP+KSXUV`%&+30B+05A75E'_4`2#Q!"%
MP'0HC5#_ZPJ-=@"*!H@#1D-*@_K_=?1.1NEM____D,8#7,9#`5J#PP+KD(/L
M"`^^%HM-"(M!6%+_=0C_4`B#Q!!(#XX=____Q@-<B@:(0P&#PP+I8____\8#
M7,9#`6Z#PP+I5/___\8#7,9#`2>#PP+I1?___Y!5B>53@^P0:,`(&0CH8^__
M_\<$)*#Z&`CH5^___\<$).#R&`CH2^___\<$).#V&`CH/^___\<$)$`0&0CH
M,^___\<$)$`,&0CH)^___\<$)."+'`CH&^___\<$).!U&@CH#^___\<$)*""
M&@CH`^___\<$)*!^&@CH]^[__\<$)(#M'`CHZ^[__\<$)(#I'`CHW^[__\<$
M)(!#'@CHT^[__\<$)(`_'@CHQ^[__\<$),"\(`CHN^[__\<$),"X(`CHK^[_
M_\<$),"^(0CHH^[__\<$),"Z(0CHE^[__\<$)"#H'`CHB^[__\<$)&#D'`CH
M?^[__\<$)."6(PCH<^[__\<$)("6(PCH9^[__\<$)""6(PCH6^[__\<$),"5
M(PCH3^[__\<$)&"5(PCH0^[__\<$)`"5(PCH-^[__\<$)*"4(PCH*^[__\<$
M)$"4(PCH'^[__\<$)."3(PCH$^[__\<$)("3(PCH!^[__\<$)""3(PCH^^W_
M_\<$),"2(PCH[^W__\<$)&"2(PCHX^W__\<$)`"2(PCHU^W__\<$)*"1(PCH
MR^W__\<$)$"1(PCHO^W__\<$)."0(PCHL^W__\<$)&#A(0CHI^W__\<$)&#=
M(0CHF^W__\<$)."<'`CHC^W__\<$)&"9'`CH@^W__\<$)$"0(PCH=^W__\<$
M)."/(PCH:^W__\<$)("/(PCH7^W__\<$)""/(PCH4^W__\<$),".(PCH1^W_
M_\<$)&".(PCH.^W__\<$)`".(PCH+^W__\<$)*"-(PCH(^W__\<$)$"-(PCH
M%^W__\<$).",(PCH"^W__\<$)(",(PCH_^S__\<$)"",(PCH\^S__\<$),"+
M(PCHY^S__\<$)&"+(PCHV^S__\<$)`"+(PCHS^S__\<$)*"*(PCHP^S__\<$
M)"")(PCHM^S__XL5%.0<"(/$$(72NP#D'`AT%Y"#[`Q3@\-@Z)CL__^+0Q2#
MQ!"%P'7J,<"+7?S)PXUV`%6)Y8M%",<``````,=`!`````!FQT`D``#'0`@!
M(T5GQT`,B:O-[\=`$/[<NIC'0!1V5#(0QT`8\.'2P\=`'`````#'0"``````
MR3'`PXGV58GE5U93@>Q\`0``,=N)A:3^__^-#)T`````BY6D_O__#[9$$2;!
MX!B)A)VH_O__#[9\$2?!YQ`)QXF\G:C^__\/MD01*,'@"`GXB82=J/[__P^V
M5!$I"=")A)VH_O__0X/[#WZNNA````"0BYR5B/[__S.<E9S^__\SG)5P_O__
M,YR5:/[__]'#B9R5J/[__T*#^D]^U8N5I/[__XM""(N=I/[__XM+#(N]I/[_
M_XF%D/[__XF%H/[__XNUI/[__XN%I/[__XM7%(F-C/[__XG+BW80BT@8B;6(
M_O__B968_O__B=>)C93^__^)C9S^___'A83^__\`````B=J)V??2(?HA\8N%
MH/[__PG1P<`%`<@#A9S^__^+E83^__\#A)6H_O__B;V<_O__0HGWB=Z-B)EY
M@EK!QAZ#^A.+G:#^__^)E83^__^)C:#^__]^J[H4````B?:)V#'PP<$%,?B-
M!`$#A9S^__\#A)6H_O__B;V<_O__0HGWB=Z-B*'KV6[!QAZ#^B>+G:#^__^)
MC:#^__]^PL>%@/[__R@```")\`GXB?(A^B'8P<$%"="-!`$#A9S^__^+E8#^
M__\#A)6H_O__B;V<_O__0HGWB=Z-B-R\&X_!QAZ#^CN+G:#^__^)E8#^__^)
MC:#^__]^L+H\````C78`B=@Q\,'!!3'XC00!`X6<_O__`X25J/[__XF]G/[_
M_T*)]XG>C8C6P6+*P<8>@_I/BYV@_O__B8V@_O__?L*+E8S^__\!VHN=B/[_
M_P'SB[68_O__BX60_O__`?Z+O93^__\#O9S^__\!R(N-I/[__XE!"(E1#(E9
M$(EQ%(EY&&;'020``('$?`$``%M>7\G#58GE5U93@^P,BW4(BUX<A=L/A:(`
M```/OT8D@_@W#X_#````QD0P)H"Z.````$`IPE%2:@"-1`8F4(U>)NCJ0?W_
M@\009L=&)#@`B5WPBWX$B?K!ZA")^8L&P>D8B%9?B?J(3E[!Z@B)P8A68`^L
M^1B)P@^L^A"(3F(/K/@(B@Z)^XA68XA&9(A.98GPB%YAZ./\__]0:D!J`/]U
M\.B*0?W_QP8`````QT8$`````,=&'`$```"#Q!`QTI")T8G3]]'!^P*#X0/!
MX0.+1)X(T^B+?0R(!!="@_H3?M^-9?1;7C'`7\G#QD0P)H"->`&X0````(U,
M/B8I^%=0:@!1Z"A!_?^)\(/$$&;'1B1``.AD_/__C58F_+D.````B=>)V(E5
M\/.K9L=&)#@`Z1W___^-=@!5B>6+11!75H7`4XM]"(MU#'0OC5C_@_O_=">0
M9HM')(H6#[_(0(,'"(-7!`!F@_A`B%0Y)F:)1R1T$49+@_O_==I;7C'`7\G#
MC78`B?CH\?O__T9+Z^:058GE@^P4_W4(Z#)!_?^+#>Q#)0B+51B)"LG#D%6)
MY<G#C78`58GE4U&+70B%VW0HC5,(@^P,4NC0W___6%IJ`(U#(%#H*\#__XE=
M"(/$$(M=_,GI(*?__XM=_,G#C78`58GEBT4,BU4(BPB+`HE-#(E%",GIAT#]
M_XUV`%6)Y5-3BT4,@#@`BUT(=06X!W,("(/L"%!3Z*D#``"#Q!"`>/\O=`?&
M`"_&0`$`B=B+7?S)PXGV58GER>GS/?W_C78`58GE5U93@^P,BUT,A=L/E,`/
MMO"%]HM]$'04@^P(5VI@Z/*E__^#Q!"%P(G#=$&#[`A3_W4(Z-5`_?^#Q!"%
MP(G:=0R-9?1;7HG07\G#B?;H&S[]_XL0A?:)%6#I&`AT#X/L#%/H3J;__X/$
M$(UV`#'2@^<8=,W_-6#I&`C_=0AJ)&H-Z!>M__\QTNNWC78`58GE5U93@>P\
M!```BT4(QX7,^___`````(`X`'4%N`=S"`B#[`A0C878^___4.C!`@``@\00
M@'C_+W0'Q@`OQD`!`(/L#(V5V/O__U+H/C_]_X/$$(7`B<</A,$!``"#[`C_
M=0QJ0.@<I?__@\00A<")Q@^$IP$``&@`(```:``$``"-2`AJ"(U8(%&)C<C[
M__^)G<3[___HV]O__X/$$(3`#X5J`0``4V@`@```:`"```#_M<3[___H#KS_
M_XV%V/O__XD$)(FUS/O__^CB`@``B87`^___@\00ZRV-=@#'A=3[__\`````
M@^P(C8W0^___4?^UR/O__^A)W/__@\00A,`/A18!``"#[`Q7Z(T[_?^#Q!"%
MP`^$E0$``(/L"(U8"%/_M<3[___HA,#__X/$$(7`B870^___#X3?````]T4,
M``0``'26@^P(:F#_M<3[___HMKS__X/$$(7`B874^___#X2U````46I@:@!0
MZ-H]_?]86E/_M<#[___H<`$``(N=U/O__S'2@\00A=L/E,*%THF5O/O__W06
M@^P(_W4,:F#HW:/__X/$$(7`B<-T-H/L"%.-C=C[__]1Z+P^_?^#Q!"%P`^$
M&____^@,//W_BQ"+A;S[__^%P(D58.D8"`^%N````/9%#!@/A/;^____-6#I
M&`B-G=C[__]3:B1J#>@&J___@\00Z=C^__^#[`Q6Z`VD__^#Q!")]NB[._W_
MBS"%_XDU8.D8"'0,@^P,5^C6/OW_@\00BY7,^___A=)T-(N-S/O__X/!"(/L
M#%'H8]S__U]8BYW,^___:@"#PR!3Z+B\__]>_[7,^___Z+"C__^#Q!#V10P8
M=0HQP(UE]%M>7\G#_S5@Z1@(_W4(:B1J#.ASJO__@\00Z]^#[`Q3Z'VC__^#
MQ!#I-____X/L#%?H5#[]_XN]R/O__XL'B0:#Q!"+1P3W10P``@``B48$=`2)
M\.NG:/19!PAJ"%#_-NC%./W_@\00B?#KD8GV58GEBTT(BU4,C78`B@*(`4)!
MA,!U]HU!_\G#D%6)Y8M5"%.+30R-71#K$Y"*`8@"04*$P'7VB=A*@\,$BPB%
MR77JQ@(`B=!;R<.)]E6)Y593BTT028/Y_XMU"(M=#'06C5;_D(H#B$(!0T9"
MA,!T#$F#^?]U[EN)\%[)PUN)T%[)PXGV58GE5E.+31!)@_G_BW4(BUT,=!:-
M5O^0B@.(0@%#1D*$P'0/28/Y_W7NQ@8`6XGP7LG#6XG07LG#C78`58GEBU4(
MB?:*`D*$P'7YC4+_R<-5B>53BUT(BTT,B?:*$832=`Z*`T%#.-!T\C'`6\G#
MD+@!````6\G#58GE5U93@^Q\BU44A=*+70R+?1#'192@\A@(=0?'191@\A@(
MA?]X;XUW_C'2@_XB=UN+10@QTO?WB<&*50@/K\<HP@^VPL9%V`"+592*!!"-
M==>(1=?K'(G(F??_B46$#Z_'*,$/MLF+592*!!%.B`:+382%R77@1H@#0X3`
M=`J*!H@#1D.$P'7VC5/_@\1\6UZ)T%_)PXU')#'2@_@B=^R+30B%R7@$]]_K
MAL8#+?=="$/WW^EX____B?95B>575E.#[&R+=1"%]HM=#'AZN,W,S,SW90B)
MT<'I`XT$B='@BE4(*,*(T(/`,(UUU\9%V`"(1=?K+I"X9V9F9O?IB564BU64
MB460P?H"B<C!^!^)T2G!C02)T>")^BC"B-!.@\`PB`:%R8G/=<U&B`-#A,!T
M"Y"*!H@#1D.$P'7V@\1LC4/_6UY?R<.+30B%R0^)>____\8#+?=="$/I;___
M_U6)Y5=64X'LG````(M%&,<``````(M5$(72BW4(B95@____?@J)T??9B8U@
M____BT44A<!^`O?8.X5@____?0:)A6#___^*#@^VP8L5P/H8".L'D$:*#@^V
MP?9$`@$(=?.`^2O'A63_________#X0_`0``@/DM#X0'`0``@/DPB?=U"$:*
M#H#Y,'3X,=OK&P^^P8U0T#M5#(F4G6C___]]+X/[$W\J1D.*#HU1T(#Z"7;=
MC5&_@/H9#X?9````#[[!C5#).U4,B92=:/___WS1.?</A!<!``"______\>%
M7/___P````#K.HGVBXR=:/___XG*]]H[E6#___\/C-4```"+E6#___\!RHG0
MF0^OS_=]#(F%8/___P&-7/___P^O?0Q+A=M_PX7;=1^+E6C___^)T_?;.YU@
M____#XR5````#Z_7`95<____B[UD____A?]X98M%$#F%7/___WQWBYU<____
MBU48B1KH'S?]_\<``````('$G````%N)\%Y?R<-&QX5D____`0```(H.Z>?^
M__^)]HU!GSP9NG\````/A^[^__\/OL&-4*GIX_[__T:*#NG"_O__@;U<____
M````@'01]YU<____BTT4.8U<____?HGHLS;]_\<`(@```#'`@<2<````6UY?
MR</HFS;]_\<`(0```#'`Z^:058GEBT4(BDT,C78`BA`XRG0&0(32=?5(R<.)
M]E6)Y8M-$#M-%+C_____<R`/M@$/MY0```49"(M%#(D0,<"%TG4%@#D`=06X
M`0```,G#B?95B>56BW40.W444[C_____BUT,<R</ML>+#(4`_!@(,=*%R70&
M#[;#BA0(,<"$TH@6=02%VW4%N`$```!;7LG#58GE5U93@^P,BD4<BTT,BUT4
MB$7SBU40BT48`<H!V(E5[(E%Z#'V,?_K#Y")^#'VA,!T.3'_.,)U2#M-['(&
MB?*$TG1/.UWH<@:)^(3`=$2)\H32==8/M@$/MK"`^!@(BI"@^1@(B?A!A,!U
MQP^V`P^VN(#X&`B*@*#Y&`A#.,)TN(/$#`^V\%L/MM(I\EZ)T%_)PSM-['(D
MB?&$R74>.UWH<@B)^S'`A-MT!;C_____B<*#Q`Q;7HG07\G#,<"`??,`#Y3`
MB<+KZ8GV58GE5U93@^P0BUT,BTT4BT40BW48`=@!SHE%\(EUY#'_QD7O`.L6
MD(GZ,?^`?>\`=#Z*1>\XPL9%[P!U2CM=\'(&B?J$TG1<.TWD<@:`?>\`=$:)
M^H32=<\/MC-#@'WO``^VOH#X&`B*EJ#Y&`AUP@^V,8J&@/@8"(A%[XJ&H/D8
M"$$XPG2V#[;2#[;(*<J#Q!!;7HG07\G#B?B$P+H!````=>N`?>\`NO____]U
MX#M=\'0S.UWPN`$```!T,CM=\',-BA.`^B!U$D,[7?!R\S'2@\006UZ)T%_)
MPX#Z'W<"]]B)PNNH.TWD=<@QTNOBBUWDB5WPN/____^)R^N_D%6)Y5=64X/L
M#(M5%(G6`W48BTT,BWT0.?*-'#ES*XGV.=ES+`^V`HJ`H/D8"(@!#[8"BH"`
M^!@(083`=`<YV7,#B`%!0CGR<M<YV7(-C78`C67T6UZ)^%_)PRG+4%-J(%'H
M/C7]_X/$$(UE]%M>B?A?R<.058GE5U:+=0R)]P-]$#GW4W8.@'__('4(3SGW
M=_6-=@`Y_G-UBT48BQB-=@`/M@Z+110/MI&@^1@(BPB)R(/@/P'8#Z_"B<K!
MX@@!T#'!BUT4B0N+51B+&H/#`XD:#[8.#[:1@/@8"(72="F+112+"(G(@^`_
M`=@/K\*)RL'B"`'0,<&+712)"XM5&(L"@\`#B<.)`D8Y_G*36UY?R<.)]E6)
MY5=64X/L#(M-&(M%#(M=%(G**<(YV(MU"(M]$',L4%*-!`Y0C006`=A0Z$,`
M``")71")?0R)=0B#Q!"-9?1;7E_)Z=<P_?^-=@!14HT,!HT4'E%2Z!4P_?^)
M71")?0R)=0B#Q!"-9?1;7E_)Z:TP_?^058GEBTT,4XM5$(M=".L'D$E+B@&(
M`TJ#^O]U]%O)PY!5B>575E.![(P```"+512%T@^("P$``(MU%(/N`C'2@_XB
M#X?P````BWT,"WT(#X37````C578@WT,`(E5E,9%V``/A@$!``"+312)38C'
M18P`````C78`_W6,_W6(_W4,_W4(Z/O^``")A7#___^+18B)E73____WI7#_
M__^)P8M5"/]-E"G*BH*@\A@(BW64B`:+G73___^#Q!"+A7#___^#^P")10B)
M70QWJSW___]_=Z2+30B%R70YD(G(F?=]%(G#BT44#Z_#*,'_390/ML&*@*#R
M&`B+=92%VX@&B=EUV8M5$/]%E(@"0H3`B540=$N0BWV4B@>+51#_192(`D*$
MP(E5$'7KZS.+11#&`##&0`$`C5`!C67T6UZ)T%_)PXM%%(/`)#'2@_@B=^F+
M30R%R7@E]UT4Z>K^__^-9?1;7DJ)T%_)PX%]"/___W\/A_+^___I6?___XM=
M$,8#+4/W70B#50P`]UT,]UT4B5T0Z;'^__^058GE5U93@^Q\BTT4A<F+=0B+
M?0P/B-H```")^@GR=16+71#&`S#&0P$`C67TC4,!6UY?R<.-3=B)393&1=@`
MZRZ-=@!J`&H*5U;HG?T``(G!P>$"@\00`<'1X2G._TV4BIZ@\A@(BW64B!Z)
MUXG&@_\`=]"!_O___W]WR(7VB?$/A(P```"^9V9F9I")R/?NB56$BU6$B<_!
M^@+!_Q\I^HE%@(T$DM'@*,'_390/ML&*@*#R&`B+792%TH@#B=%URXM-$/]%
ME(@!083`B4T0=!B-=@"+392*`8M-$/]%E(@!083`B4T0=>N-9?1;7HG(2%_)
MPX7_#XD>____BT40Q@`M0/?>@]<`]]^)11#I"/___XMUE(H&Z\"-=@!5B>57
M5E.#[%R+70B)V`-%#$B+=1")7<2)1<"*!H3`=!:-=@`\)70@.UW`=`J(`T-&
MB@:$P'7MQ@,`*UW$C67TB=A;7E_)PY!&B@Z`^2T/A!<!```/ML&+/<#Z&`C'
M1;``````QT6T`````,=%N`````#'1;P`````ZR*0BT6\C12`#[[!C4Q0T(7)
MB4V\=0?'1;0!````1HH.#[;!]D0'`01UV(#Y+G1/@/ELQT6X_____W15@/ES
M=%^`^60/A+````"`^74/A*<```"`^7@/A)X````[7<`/A%G____&`R5#Z4G_
M__^0BU6XC022#[[1C4Q"T(E-N$:*#@^VT?9$%P$$=>.`^6QUJT;'1;`!````
MB@Z`^7-UH8M-%(M]P"G?BQ&#110$B7VH1X72B7VL#X3#````,<#\N?____^)
MU_*N]]&-0?\[1;AV`XM%N#E%K'<#BT6H45!24^CX\___B<.#Q!!&Z<;^__]&
MB@[IX?[__XM5P"G:@_H/B5V@B56D=@>+?;R%_W0&C47(B46@BU6PA=)U!8#Y
M9'1!BWT4@T44!(#Y9(L'=#R`^75T16H`:A#_=:!0Z$ST__^)QRM]H(/$$#M]
MI`^':O[__XU%R#M%H'0N`?M&Z53^__^+312+`8-%%`17:O;_=:!0Z-+T___K
MR%%J"NOPNL.U&`CI,____XM5I#E5O'8#B56\.WV\<R.+3;PI^8-]M`%2&=*#
MXO!1@\(P4E.)39SH."_]_P-=G(/$$%!7_W6@4^@'*_W_`?N#Q!#KCU6)Y8U%
M%(/L"%#_=1#_=0S_=0CHH/W__\G#B?95B>575E.#[`R+30BA!`<9"(N1$`$`
M`(7`BWT,BW40B57PNP`'&0AT'XUV`%!6_W,$5^BM+?W_@\00A<!T%(/#"(M#
M!(7`=>2-9?1;7C'`7\G#A=MT\HL#@_@(=!2#^`EUYHM=\,>#!`<```````#K
MUU)J8(MU\&H`@<8(!P``5NA_+OW_@\00BP/KT56)Y5=64X/L#(M5"(N"$`$`
M`(E%\*$$!QD(A<"+?0R+=1"[``<9"'0?C78`4%;_<P17Z"$M_?^#Q!"%P'04
M@\,(BT,$A<!UY#'`C67T6UY?R<.%VW3R@SL)=>V+3?"+D6@'```QP(72=."+
M7?"#[`R!PP@'``!3_]*#Q!#KS(GV58GE5U93@^Q<BW4(BY80`0``C9Z`````
M,<")WXE5Q/RY______*NH00'&0CWT87`C7G_O@`'&0AT'HGV4%?_=@13Z)$L
M_?^#Q!"%P'03@\8(BT8$A<!UY#';_R2=Z+@8"(7V=/.+'H/[%7;NC67T6UXQ
MP%_)PXM=Q('#00(``(E=G(M=#,=%P``````#71"+?0R)]CG?#X.<!```@^P(
M#[X'4&C7S1@(Z.LN_?^#Q!"%P'0%1SG?<N.)_NL<C78`@^P(#[X/46C7S1@(
MZ,<N_?^#Q!"%P'4%1SG?<N,Y]P^$4P0``(%]P``!```/AT8$``!0:A!J`%;H
M&RK]_XMUP(M5G(@$,H/$$$:)=<#KA5%J"FH`_W4,Z&PJ_?^+3<2)@1`'``"#
MQ!"-9?1;7C'`7\G#4FH*:@#_=0SH22K]_XM]Q(/$$(F'#`<``.O;BT7$@\!`
MBUT,B46DQT6P``````-=$(M]#(GV.=\/@^H#``"#[`@/OA=2:-?-&`CH%R[]
M_X/$$(7`=`5'.=]RXXG^ZQR-=@"#[`@/O@]1:-?-&`CH\RW]_X/$$(7`=05'
M.=]RXSGW#X2A`P``@7VP`0$```^'E`,``%)J$&H`5NA'*?W_BW6PBU6DB`0R
M@\001HEUL.N%BT7$!4$#``"+70R)1:S'1;0``````UT0BWT,B?8YWP^#00,`
M`(/L"`^^#U%HU\T8".A_+?W_@\00A<!T!4<YWW+CB?[K'(UV`(/L"`^^%U)H
MU\T8".A;+?W_@\00A<!U!4<YWW+C.?</A/@"``"!?;0``0``#X?K`@``46H0
M:@!6Z*\H_?^+=;2+3:R(!#&#Q!!&B76TZX6+1<2+=1`%@@8``(M-Q(/^#\=%
MR*NW&`C'1<ROMQ@(QT70KK<8",=%U*VW&`B-?=B)@20'```/AVT"``!05O]U
M#%?HQB?]_\9$-=@`BTW$BY$$!P``C7(4@\00@_Y_#X>-_?__BW7$5_]TG8"-
MA#*"!@``:+&W&`A0Z,\K_?^+5<0!@@0'``"#Q!#I'O[__XMUQ(M=$('&0@8`
M`(/[/W8%NS\```!04_]U#%;H72?]_XM5Q(/$$,:$&D(&````B;(@!P``Z2C]
M__^+1<0%0@0``(M=#(E%J,=%N``````#71"+?0R0.=\/@Q0"``"#[`@/OA=2
M:-?-&`CH'RS]_X/$$(7`=`5'.=]RXXG^ZQR-=@"#[`@/O@]1:-?-&`CH^RO]
M_X/$$(7`=05'.=]RXSGW#X3+`0``@7VX``$```^'O@$``%!J$&H`5NB_)_W_
MBW6XBU6H9HD$<H/$$$:)=;CKA(M%Q`5!`0``BUT,B46@QT6\``````-=$(M]
M#)`YWP^#:P$``(/L"`^^#U%HU\T8".B'*_W_@\00A<!T!4<YWW+CB?[K'(UV
M`(/L"`^^%U)HU\T8".AC*_W_@\00A<!U!4<YWW+C.?</A"(!``"!?;P``0``
M#X<5`0``4&H0:@!6Z+<F_?^+=;R+3:"(!#&#Q!!&B76\ZX6+11"#^`@/CZ\`
M``#\.<"^N+<8"(M]#(G!\Z8/A?D```"+7<2#BQ0'```@Z<G[__^+=<2+71"#
MQB"#^Q]V!;L?````4%/_=0Q6Z,<E_?^+1<2#Q!#&1!@@`(FP'`<``.F5^___
MBUT0@_L?=@6['P```%!3_W4,_W7$Z)<E_?^+=<2#Q!#&!!X`B;88!P``Z6;[
M__]3:@IJ`/]U#.AU)OW_BUW$@\00B8,(!P``Z03\__^^#P```.F)_?__N`@`
M``#I1____XM=G(M]Q(F?,`<``.DC^___BUVLBWW$B9\T!P``Z1+[__^+7:2+
M?<2)GR@'``#I`?O__XM=H(M]Q(F?+`<``.GP^O__BUVHBWW$B9]`!P``Z=_Z
M__^+11"#^`=^!;@'````_#G`OL"W&`B+?0R)P?.F=0^+1<2#B!0'```0Z;+Z
M__^+11"#^`E^!;@)````_#G`OL>W&`B+?0R)P?.F#X60^O__BU7$@XH4!P``
M`>F!^O__D%6)Y593C;78_O__@>R<"```5NCYPP``65MH,&L'"%;H(,0``%A:
M:#QL!PA6Z/_#``!96VB\:P<(5N@:Q```BU406(F5T/[__XV%:/?__UI05N@6
MQ```@\0,_W4,_W4(5NCWMP``A<`/E<.)-"3HML,``(UE^`^^PUM>R<-5B>57
M5E.#[`R+=1"+71B+10@YWHM-#(M5%(MX+(EU\'8"B=XYT71#C1PRZPV-=@`/
MM@**!#B(`4)!.=IR\CEU\'<+BT7PC67T6UY?R<-0BU7P*?)2:B!1Z#,G_?^+
M1?"#Q!"-9?1;7E_)PXT4,>L)#[8!BAPXB!E!.=%R\^N_D%6)Y5=64XM-&#E-
M$(M=#(MU%(I5''<#BTT0BT4(A-*+>"QT)(M%&#E%$'8<28/Y_XE%$'09C78`
M#[8&#[83B@0X1D,X!#IU$TF#^?]UZHM5$%LK51A>B=!?R<,/MD/_#[9._P^V
M%#A;#[8$.5XIPHG07\G#58GE5U9348M5"(M%&(MR+(M5$#G0BTT,BUT4B47P
M=@.)5?"+??`!SSGY<RP/M@,/MA&*!#!#03@$,G3L#[9!_P^V>_\/MA0P#[8,
M-RG*B=!:6UY?R<.)]HM%&#E%$'0LO@$```!S"HE%$(G9OO____^+71"-!!DK
M1?`YP7,.B?:*$8#Z('4/03G!<O0QTHG06EM>7\G#@/H?B?!W`O?8B<*)T%I;
M7E_)PXUV`%6)Y8M%"(M5#(M(*.L#B?9"#[8"B@0(A,"(`G7SR<.058GEBT4(
MBU4,BT@DZP.)]D(/M@**!`B$P(@"=?/)PY!5B>6+31!3BT4(BU4,BU@HA<GK
M"@^V`HH$&(@"0DEU]%O)PY!5B>6+31!3BT4(BU4,BU@DA<GK"@^V`HH$&(@"
M0DEU]%O)PY!5B>575E-6BUT(BWT,BTLHBA\/MO.)=?"+51`/M@*-<@&*!`B+
M5?`X!`IU%D>$VW0J#[8&BA\/MM-&B@0(.`0*=.H/ML,/ME[_#[84"`^V/`M;
M6RGZ7HG07\G#6UM>,=*)T%_)PXUV`%6)Y8M-$#M-%+C_____<R*+10@/MA&+
M0#@/MQ10BT4,B1`QP(72=06`.0!U!;@!````R<-5B>575E.+?1`[?12+=0RX
M_____W,IBT4(BU`\BTH$A<ET&I`/MQHY\W<(#[="`CGP<Q&#P@B+2@2%R77G
M,<!;7E_)PXGR*=J*'!$QTH3;B!]U!(7V=06Z`0```%M>B=!?R<.058GEC448
M@^P(4/]U%/]U$/]U#.CH\O__R<.)]E6)Y5=64X/L"(M=#(M%$`'8BTT(BU$L
M.<.+=1B)5?")1>QS.HL6B?:+112+"(G(@^`_`="+??`/MA,/MA0Z#Z_"B<K!
MX@@!T#'!BT44B0B+/D.#QP,[7>R)^HD^<LJ#Q`A;7E_)PXGV58GE5U93@^P4
MBTT,BT4<QP``````B<X#=1`Y\7,ABWT(#[81BU\@]D03`0AT$8GV03GQ<PH/
MM@'V1`,!"'7Q.?$/A!<!``"*$8#Z+8A5XP^$S@```(!]XRO'1?``````#X3M
M````,=*X______=U%#';.?&)5>B)3>R)Q\=%Y`````"*5>-T-8U"T#P)=@V-
M0K\\&7=^C4+)C78`#[;0.U44?1DY^W=@=%:+510/K],/ML!!C1P"BA$Y\77+
M.TWL#X28````BW48A?9T!8M]&(D/BTWPA<ET7('[````@'98@WWP`8M='!G`
MQP,B````+0```("#Q!1;7E_)PXUV`#M5Z':EC78`QT7D`0```$&*$>NEC4*?
M/!EWHHU"J>EY____QT7P`0```$&*&8A=X^DQ____A=MXJ(M%Y(7`=:&+5?"%
MTHG8=*R#Q!1;7O?87\G#08H!B$7CZ0C___^+=1B+?1R%]L<'(0```'0(BT4,
MBTT8B0&#Q!1;7C'`7\G#58GE5U93@^P4BTT,BT4<QP``````B<X#=1`Y\7,A
MBWT(#[81BU\@]D03`0AT$8GV03GQ<PH/M@'V1`,!"'7Q.?$/A-X```"*$8#Z
M+8A5XP^$LP```(!]XRO'1?``````#X2T````,=*X______=U%#';.?&)5>2)
M3>R)Q\=%Z`````"*5>-T-8U"T#P)=@V-0K\\&7=FC4+)C78`#[;0.U44?1DY
M^W=(=#Z+510/K],/ML!!C1P"BA$Y\77+.TWL=&.+=1B%]G0%BWT8B0^+3>B%
MR75RBU7PA=*)V'0"]]B#Q!1;7E_)PSM5Y':]C78`QT7H`0```$&*$>N]C4*?
M/!EWNHU"J>N4QT7P`0```$&*&8A=X^E,____08H!B$7CZ4'___^+11B+=1R%
MP,<&(0```'0(BTT,BWT8B0^#Q!1;7C'`7\G#BUT<N/_____'`R(```#KB9!5
MB>575E.#[$R+?0R+11S'``````")^@-5$#G7B57,<R.+=0@/MA^+3B#V1!D!
M"'03C78`1SM]S',*#[87]D01`0AU\#M]S`^$NP$``(H'/"T/A',!```\*\=%
M[``````/A&L!``"+113'1<0`````B7W(B47`_W7$_W7`:O]J_^COZP``@\00
MB47@B57D_W7$_W7`:O]J_^CC[```,?:#Q!`[?<R)1=S'1=``````QT74````
M`'1KBT44F8E%N(E5O(GVBA>-2M"`^0F(RW88C4*_/!F-6LEV#HU:GX#[&7=!
MC5JIC78`#[;+.TT4?3.+5>0Y5=1W('((BT7@.470=Q:+5=2+1=`S5>0S1>`)
MPG5V.TW<=G&0O@$```!'.WW,=:$[?<@/A-P```"+71B%VW0%BTT8B3F+?>R%
M_P^$E````(%]U````(!R"'<.@WW0`'<(A?8/A)````"+=>R+51PQP(7VQP(B
M````N@```(!U"KC_____NO___W^-9?1;7E_)PXUV`(M%T/=EN(E5M(E%L(M%
MT`^O1;R+3;2+5;@/KU74`<$!T0^VPXE-M(E%T(M=L,=%U`````"+3;0!7=`1
M3=3I4____\=%[`$```!'Z8_^__^!?=3___]_#X-N____A?8/A7#___^+7>R%
MVXM%T(M5U'2$]]B#T@"-9?1;7O?:7\G#BT48BTT<A<#'`2$```!T"(MU#(M]
M&(DWC67T6UXQP#'27\G#58GE5U93@^Q,BWT,BT4<QP``````B?H#51`YUXE5
MS',CBW4(#[8?BTX@]D09`0AT$XUV`$<[?<QS"@^V%_9$$0$(=?`[?<P/A%<!
M``"*!SPM#X1``0``/"O'1>P`````#X0X`0``BT44QT7$`````(E]R(E%P/]U
MQ/]UP&K_:O_HP^D``(/$$(E%X(E5Y/]UQ/]UP&K_:O_HM^H``#'V@\00.WW,
MB47<QT70`````,=%U`````!T:XM%%)F)1;B)5;R)]HH7C4K0@/D)B,MV&(U"
MOSP9C5K)=@Z-6I^`^QEW08U:J8UV``^VRSM-%'TSBU7D.574=R!R"(M%X#E%
MT'<6BU74BT70,U7D,T7@"<)U1CM-W'9!D+X!````1SM]S'6A.WW(='R+71B%
MVW0%BTT8B3F%]@^%C````(MU[(7VBT70BU74=`?WV(/2`/?:C67T6UY?R<.+
M1=#W9;B)5;2)1;"+1=`/KT6\BTVTBU6X#Z]5U`'!`=$/ML.)3;2)1="+7;#'
M1=0`````BTVT`5W0$4W4ZX;'1>P!````1^G"_O__BU48BT4<A=+'`"$```!T
M"(M-#(M=&(D+C67T6UXQP#'27\G#BWT<N/____^Z_____\<'(@```.EP____
M58GE4XM%$#W___]_BUT,BU44BTT8=!6-!`.)`HE-$(E5#(E="%O)Z?#5``"X
M__\``(T$`XD"B4T0B54,B5T(6\GIUM4``(GV58GE5U93@^Q\BT44A<#'190`
M````C779QD79``^(A@```+C-S,S,]V48B='!Z0.-!(G1X(I5&"C"B-"#P#"%
MR8U>_XA&_XG.=#:_9V9F9I")R/?OB56$BU6$P?H"B46`B<C!^!^)T2G!C02)
MT>")\BC"B-!+@\`PA<F(`XG.=="-1=DIV#E%$'8#B4405O]U$%/_=0SHKAC]
M_XM%$`-%E(UE]%M>7\G#BWT8A?\/B6____^+50SW71C&`BW_31!"B54,QT64
M`0```.E3____D%6)Y5=64X/L?(M%%(7`BW48BWT<QT60``````^(Y0```(GY
MC5W8"?&)793&1=@`=3'IH@```(GV:@!J"E=6Z`WG``")P\'C`H/$$`'#T>,I
MWHGQ_TV4BWV4@\$PB`^)QHG7@_\`=]&!_O___W]WR87VB?%T.+YG9F9FB?:)
MR/?NB56$BU6$B<_!_Q_!^@(I^HT<DM'C*-G_392)18"(R(/`,(M]E(72B`>)
MT77/C478*T64.440=@.)11!0_W40_W64_W4,Z*X7_?^+11`#19"-9?1;7E_)
MPXUUUXEUE,9%US#'11`!````4/]U$/]UE/]U#.B`%_W_BT40`T60C67T6UY?
MR<.%_P^)$_____?>BU4,Q@(M@]<`]]]"_TT0B54,QT60`0```.GS_O__B?95
MB>575E-0BUT4BWT8.?N+=0RY_____W13C78`BA,/OL([121T,CM%('0M.T4<
M=$P[=1!T58M%"(M0+`^V!@^V"XH$`D9#.`0*=3\Y^W0=N0$```#KQHGV#[["
M.T4@=#@/OL([121T53G[=;(QP#MU$`^5P(UE]%M>7\G#C4,!.?ATK3MU$(G#
M=:N-9?1;7K@!````7\G#D#MU$'060T8Y^W,(#[X3.U4@=.TY^W2]BA/KK8UE
M]%M>B<A?R<.-2P$Y^70:#[X!.T4D=`\[12!U$3MU$`^$B@```$9!Z^(QP.N2
M.?ET^#MU$+C_____=(2*$0^VPCM%'(U9`71QBTT(#[;2BT$LB@P0B$WS.W40
M=!R+30@/M@:+42SK"48[=1!T"P^V!HI-\S@,`G7OB?!&.T40="__=23_=2#_
M=1Q74_]U$%;_=0CHM/[__X/$((7`#XX=____.W40=`@/OA,[521UJ+C_____
MZ0;___\Y^W2+BA-#ZX:058GE5U93@^P,BD44BUT,B$7SBW40BD48`=Z(1?**
M11R+522(1?$Y\XM%((M-*(EU[(E5Z(T\`G0GC78`.?IT((H#.D7S=$4Z1?)T
M4#I%\71?B`%#B`)!0CM=['7?C78`B=`K1>B+=3"+72R)!HD#ZPN-=@#&`2#&
M`B!!0CGZ=?2#Q`Q;7C'`7\G#B?:-<P$[=>QTLXGSB@;KMXGVQ@(`BW4(9HM&
M5H@!0T)!.UWLZZN)TRM=Z(MU+(D>BT4@BUTPB0.)]L8"`(MU"$)FBT96B`%!
M.?IU[NNH58GE5E.+312+50R#^0&+71")UG0O,<"#^0)T!%M>R<,YVG,7BT4(
MBT@@B?8/M@+V1`$!"'0%0CG:<O&)T"GP6U[)PY`QP(`Z+G71C4(!.=ATZX!Z
M`3!UY4`YV'3@@#@P=/8I\.O9B?95B>6+50R+112)10R)50C)Z>L7_?^-=@!5
MB>6+11`K10S)PY!5B>6+11`K10S)PY!5B>6+113)PU6)Y8M5$"M5#(M%%#G0
M=@*)T,G#58GEBU4,B=`#11`YT'8-@'C_('4'2#G0=_6)]BG0R<-5B>575E.#
M[`R+11`Y11AW2XM5&(72=%"+30R--`$K=1B+711&`UT8B77PB5WL.TWP="F)
MRHM]"(M%%"M5#(MW+(U:_P^V.)`/MA&*!#Y!0S@$%G0^.TWP=>Z)]C'`@\0,
M6UY?R<.)]HM%((7`=!>+31S'`0````#'000`````QT$(`````(/$#%M>N`$`
M``!?R<.+?12)3>A'.WWL=!N+1>@/MA`/M@?_1>B*!`9'.`06#X5V____Z^"+
M32"%R70IBU4<@WT@`<<"`````(E:!(E:"'84B5H,BU48C3P3BW4<B7X0*=^)
M?A2X`@```.EJ____58GE4XM=#(L#BTT(B<(K$74*#[=1!`^W2P8IRHG06\G#
MC78`58GE5U93@>P<#```BWT(BU<XA=*X`0```'4+C67T6UX/OL!?R<-0:``,
M``!J`(V-Z//__U'H0A;]_S'VBT<X@\00B87<\___ZQV)]F:)401FB5$&C11;
M_X25Z//__T:!_O\```!_38N=W//__V:+%'-FA=(/MMYU!(7V=>&-#%N-1(WH
MC8@`]/__BX``]/__A<!TN&:+001F.=!V`HG09HE!!&:+009F.=!S`HG09HE!
M!NN@:)2#!PAJ#&@``0``C;7H\___5N@0$OW_C;7H\___@\00QX78\___````
M`(U=Z(N#`/3__X7`#X29````#[>+!O3__P^WDP3T__\IT4&#[`R)C>#S__]1
M_U4,@\00A<")@PCT__\/A-T```!1_[7@\___:@!0Z$X5_?^#Q!"Y`0```(GV
MBT<X9HL$2&:+DP3T__]F.<)W&68Y1@9R$V:%P'0.#[?2#[?`*="+5@B(#`)!
M@?G_````?LO_A=CS__^#PPR#Q@R!O=CS____````#XY9____B[78\___@^P,
MC1SU"````(FUY//__U/_50R)PX/$$(7;B4<\N`$````/A&/^__\QR3N-Y//_
M_WT>C;7L\___BP:+?@2)?,L$B03+08/&##N-Y//__WSHQP3+`````,=$RP0`
M````C67T6UXQP`^^P%_)P[@!````Z17^__^)]E6)Y593BW4(BUXLA=MT'P^V
M1E:*#`,QTHH$$SC(=@:(P6:)5E9"@?K_````=NI;,<!>R<-5B>6+30R+51"+
M112)11")50R)30C)Z?VP``"058GEBT4(9L=`5O\`R3'`PU6)Y5=64U&*11R(
M1?.+71B+11`YPW8"B<.)V?PYVXMU#(M]%/.F#Y?!#Y+"*-$/OL&%P'4.@'WS
M`(G8=0.+11`K11A:6UY?R<.-=@!5B>575E.+71@[71")V'8#BT40.<")P?R+
M=0R+?13SI@^7P`^2PBC0#[[`A<!U!8M%$"G86UY?R<.-=@!5B>575E-6BD4<
MB$7SBUT8BT40.<-V`HG#B=G\.=N+=0R+?13SI@^7P0^2PBC1#[[!A<!U#H!]
M\P")V'4#BT40*T486UM>7\G#C78`58GE5U93BWT8.WT0BTT,BUT4=@.+?1"-
M-`^)]CGQ<QR*$XH!0T$XT'3R#[9)_P^V<_\I\8G(6UY?R<.0BT48.440="R^
M`0```',*B440B=F^_____XM=$(T$&2GX.<%S#XUV`(H1@/H@=0Y!.<%R]%M>
M,<F)R%_)PX#Z'XGP=P+WV%M>B<&)R%_)PY!5B>7)PXUV`%6)Y<G#C78`58GE
MBU4,BT40B44,B54(R>GO$OW_C78`58GEN`$```#)PXGV58GEBU40.U44N/__
M__]S#8M%#`^V$HD0N`$```#)PY!5B>6+51`[512+30RX_____W,.,<"!^?\`
M``!W!(@*L`')PY!5B>575E.+70R)WP-]$#G[BW48<S&+%I"+112+"(G(@^`_
M`=`/MA,/K\*)RL'B"`'0,<&+512)"HL&0X/``SG[B<*)!G+26UY?R<.058GE
M5U93@^P,BTT4BW48.?&+70R+?1#'1?#_____=$2*$0^^PCM%)'0F.T4@="$[
M11QT0#G[=$F*$XH!0T$XT'4_.?%T'L=%\`$```#KT9`/OL([12!T.`^^PCM%
M)'15.?%UOC'`.?L/E<"-9?1;7E_)PY"-00$Y\'2Y.?N)P76WC67T6UZX`0``
M`%_)PXGV.?MT%D%#.?%S"`^^$3M5('3N.?%TOHH1ZZZ+1?"-9?1;7E_)PXU1
M`3GR=!4/O@([121T"CM%('4,.?MT=T-"Z^<QP.N6.?)T^#G[N/____]TB8H*
M#[;!B$WO.T4<C4H!B4WH=%DY^W03BE7O.!/K"D,Y^W0'BDWO.`MU](G80SGX
M=#'_=23_=2#_=1Q6_W7H5U/_=0CHUO[__X/$((7`#XXV____.?MT"XM5Z`^^
M"CM-)'6QN/_____I'?___SGQB<ITH8H!0HA%[XE5Z.N6D%6)Y5=64X/L#(M]
M#(M5%#G7BUT0BW48=!(YWHGP=QU14%)7Z/@,_?^#Q!`Y\W<1C67TB=A;7E_)
MPXUV`(G8Z]^)V(T4-RGP5U!J`%+H/Q#]_X/$$(UE](G86UY?R<.)]E6)Y5=6
M4X/L#(M]#(M5%#G7BUT0BW48=!(YWHGP=QU14%)7Z)@,_?^#Q!`Y\W<1C67T
MB=A;7E_)PXUV`(G8Z]^)VBGR4%*-!#=J(%#HWP_]_X/$$(UE](G86UY?R<.)
M]E6)Y5=64X/L#(M%$#E%&'<[BU48A=)T0(M-#(T4`8M=%"M5&`-=&(UR`8E=
M\#GQ=!N)SXM%%"M]#(H0C5__B?:*`4-!.-!T.SGQ=?0QP(/$#%M>7\G#B?:+
M?2"%_W07BT4<QP``````QT`$`````,=`"`````"#Q`Q;7K@!````7\G#BWT4
MB4WL1SM]\'01BT7LBA>*`$?_1>PXT'6/Z^J+=2"%]G0IBU4<@WT@`<<"````
M`(E:!(E:"'84B5H,BU48C3P3BTT<B7D0*=^)>12X`@```.ET____B?95B>57
M5E.#[`R+11B)1>R+11"*51PY11B(5?-V`XE%[(MU#(M]%(M-[(UV`$F#^?\/
MA)8```"%R712BA:-6E^`^UAW%(I&`8A%ZX/H0#P^=D>`?>N@=SF0BA\/ML,/
MMM**F.`0&0A'1CB:X!`9"'2\#[9>_P^V=_\/MHO@$!D(#[:&X!`9""G!ZTJ)
M]HH6Z\B`?>O_=,*)]HH?C4-?/%AWN8I'`8A%ZH/H0#P^=T`XVG56BD7J.$7K
M=4Y)28/&`H/'`H/Y_P^%:____Y")=0R)?10QR87)B<AU#(!]\P!T(XM%["M%
M&(/$#%M>7\G#@'WJH`^&8O___X!]ZO]UL.E7____BT40Z]L/MLH/ML/!X0@/
MMGWKP>`(#[9UZ@GY"?`IP>NP58GE5U93@^P(BT48BU40.=")1?!V`XE5\(MU
M#(M]%(M-\(GV28/Y_P^$K@```(7)=%Z*%HU:7X#[6'<4BD8!B$7O@^A`/#YV
M4X!][Z!W19"*'P^VPP^VTHJ8X!`9"$=&.)K@$!D(=+P/ME[_#[9/_P^VL^`0
M&0@/MH'@$!D(*<:%]G1@B?"#Q`A;7E_)PXGVBA;KO(!][_]TMHGVBA^-0U\\
M6'>MBD<!B$7N@^A`/#X/AY(````XV@^%J````(I%[CA%[P^%G````$E)@\8"
M@\<"@_G_#X53____D(EU#(E]%#'VBU48.540=)B_`0```'-NBT44B540B44,
MO_____^+51"-'!`K7?`YV`^#<O___XU0`8I*_X#Y('49C78`B=")50Q".=@/
M@U;___^*2O^`^2!TZH#Y'XGX#X=%____]]CI/O___X!][J`/A@#___^`?>[_
M#X5:____Z?'^__^+10SKFP^V\@^VP\'F"`^V3>_!X`@/ME7N"<X)T.G[_O__
MD%6)Y5=64X/L#(M%$(M]#(MU%(E%\(M=&$N#^_\/A%X!``"%VP^$:@$``(H6
MC4I?@/E8#X=>`0``BDX!C4'`/#YV$H#YH`^&2P$``(#Y_P^$0@$```^VPL'@
M"&8/MLD)P8V!P%L``&:#^`&Z0*0```^&[````(V1OEL``&:#^A$/AB,!``"-
M@<`V``!F@_@$#X83`0``C9&L6P``9H/Z*@^&.@$``(V!NS8``&:#^`</ABH!
M``"-D5];``!F@_I<#X8V`0``C8&S-@``9H/X%0^&)@$``(V1`EL``&:!^N$`
M#X8?`0``C8&=-@``9H/X1P^&#P$``(V1(%H``&:!^@D!#X8(`0``C8%5-@``
M9CVN``^&^````(V1%ED``&:!^M@!#X;Q````C8&F-0``9CU6`0^&X0```&:!
M^6"B=!V-D3U7``!F@?J!`G80C8%/-```9CTK`@^'QP```+K#J```B=%FP>D(
MB`^(5P&#Q@*#QP)+2X/[_P^%I?[__XUV`(M=&#E=\'<YBT7PC67T6UY?R<.0
MBA8/ML**D.`0&0B(%T9'Z7#^__^Z0J0``(G19L'I"(@/B%<!@\8"@\<"2^NR
M4(MU\"MU&%9J(%?H>PK]_XM%\(/$$(UE]%M>7\G#NE2D``")T6;!Z0B(#XA7
M`8/&`H/'`DOI>/___[JAI```Z5S___^Z_J0``.E2____NN"E``#I2/___[KJ
MI@``Z3[___]F@?E9HG0@9H'YVOET&8V1NU0``&:!^G8"=@R-@2,R``!F/>H"
M=PJZ1:L``.D-____9H'Y6J)T&8V11%(``&:!^O$"=@R-@3@O``!F/8(#=PJZ
MO*T``.GC_O__C9&E70``9H/Z`789C8%23P``9CT4`W8-C9&U*P``9H'Z!01W
M"KJNL```Z;3^__]F@?G;^709C8$]3```9CW_`G8-C9&O)P``9H'Z7P1W"KK#
MLP``Z8K^__]F@?E=HG0U9H'Y7Z)T+F:!^:'&="=F@?G6^70@9H'YV/ET&8V!
M/4D``&8]Z`)V#8V13R,``&:!^CX$=PJZP[8``.E$_O__9H'YW/ET&8V!5$8`
M`&8]2`)V#8V1$!\``&:!^O4#=PJZK+D``.D:_O__9H'Y8:)T&8V!"T0``&8]
ML0)V#8V1&AL``&:!^@T$=PJZ];L``.GP_?__9H'Y7J)T)V:!^=?Y="!F@?G9
M^709C8%900``9CW-`78-C9$,%P``9H'ZQ`-W"KJGO@``Z;C]__^-@8L_``!F
M/=D!=@V-D4<3``!F@?K]`G<*NG7```#IE?W__XV!L3T``&8]#P%V#8V121``
M`&:!^C,"=PJZ3\(``.ER_?__C8&A/```9CWU`'8-C9$5#@``9H'Z$0)W"KI?
MPP``Z4_]__^-@:L[``!F/8$`=@V-D0,,``!F@?K"`7<*NE7$``#I+/W__XV!
M*3L``&8]DP!V#8V10`H``&:!^A4!=PJZU\0``.D)_?__C8&5.@``9H/X7'8-
MC9$J"0``9H'Z^0!W"KIKQ0``Z>;\__^-@3@Z``!F@_@H=@V-D3`(``!F@?K4
M`'<*NLC%``#IP_S__XV!#SH``&:#^&-V#(V16P<``&:#^DAW"KKQQ0``Z:'\
M__^-@:LY``!F@_@/=@R-D1('``!F@_I\=PJZ5<8``.E__/__C8&;.0``9H/X
M!G8,C9&5!@``9H/Z-G<*NF7&``#I7?S__XV!E#D``&:#^`EV#(V17@8``&:#
M^A=W"KILQ@``Z3O\__^-@8HY``!F@_@"=@R-D48&``!F@_H+=PJZ=L8``.D9
M_/__C8&'.0``9H/X`W8,C9$Y!@``9H/Z!'<*NGG&``#I]_O__V:!^7W&=`R-
M@30&``!F@_@#=PJZ?<8``.G:^___9H'YT/FZT/D```^$ROO__V:!^7[&=$AF
M@?G1^71!9H'YQOET1&:!^=+Y=#UF@?G3^;K3^0``#X2>^___9H'YU/FRU`^$
MD?O__V:!^=7YLM4/A(3[__]FND"AZ7O[__^Z?L8``.EQ^___NL;Y``#I9_O_
M_XGV58GE5U93@^P0BD44BE48BTT,B$7SB%7RBD4<BU40BUTD`<J(1?&+12`!
MV#G1BW4HB57LB5WHB47D=#\YPW0[D(UY`3M]['1<BA&-0E\\6'=7BDD!C4'`
M/#YW98@6B!.*#XA.`8A+`8/&`H/#`D<[?>R)^70%.UWD=<:)V"M%Z(M-,(M]
M+(D!B0?K"9#&`R#&!B!#1CM=Y'7S@\006UXQP%_)PY"*$8GV.E7S=",Z5?)T
M+CI5\70SB!:($T9#ZZ^0@/F@=N/^P762.E7S==^)]CM]['38BA>(%H@31D/K
MCI#&`P#&!O]#1NN$B=HK5>B+32R)$8M%((M],(D'Q@,`Q@;_0T8[7>1U\^N.
MD%6)Y8M-#(H!@\!?/%B+51!W(BG*2GX=BE$!C4K`@/D^=@J`^J!V#?["=`F0
MN`(```#)PY`QP,G#58GEBD4,@\!?/%D9P/?0@\`"R<-5B>564XM=$(MU%#GS
MBTT,NO____]S+(/Y?WX@C8%>____@_A5=TD/MXP)',49"(7)=1E;,=*)T%[)
MPY"("[H!````6XG07LG#C78`C4,".?"Z_____W?KB<K!^@B($XA+`5NZ`@``
M`(G07LG#C78`C9$Y_?__@?J*`0``=AJ-@>W?__\]K`(``'<7#[>,";I]&0CK
MFHUV``^WC`FRO1D(ZXV-D:#;__^!^N(!``!V&HV!`-#__STI`0``=QH/MXP)
MH%<9".EE____#[>,"4!Q&0CI6/___X'YHS(``'0RC9%RS/__@_I'=PT/MXP)
MY$\9".DX____C8$`LO__/8-&``!W&0^WC`G@C1@(Z1[___\/MPV0MQD(Z1+_
M__^-D8EJ__^!^BT*``!W#0^WC`F2ZA<(Z??^__^-@?0%__^#^`%W#0^WC`ED
M(1<(Z=_^__^-D=`!__^!^LT!```/A]'^__\/MXP)@!47".G`_O__D%6)Y5=6
M4XM=$(MU%#GSBWT,#[8+NO____]S/(/Y?WY`C4,".?"Z_____W<KP>$(#[9S
M`0'QC9'`7O__@?J\)@``=RT/MY0)X.48"(/Z`8D7&=+WTH/B`EM>B=!?R<.)
M]HD/6UZZ`0```(G07\G#B?:-F<`V__\QTH'[E3```'?+#[>4":`T&`CKP8GV
M58GE5U9348M=$(M5#(U#_XMU%(G7B47PA?9T$#G:<PR*`H3`>!)"A?9U\9`I
M^HG06EM>7\G#B?8[5?!S[X/`7SQ8=^B*2@&-0<`\/G8)@/F@=MG^P735@\("
MZ[Q5B>575E.#["R`?1P`QT7D`````,=%X`````!T#(M%&#E%$`^'K@$``(M]
M#(M=%(E][(E=Z(UV`(GX*T4,.T40#XSR````@WWD`\=%\`````!T&?]%Y(-]
MY`&+?>QT`XM]#,=%\`$```"-=@")VBM5%#M5&'T@BW7@#[8#BPRU1'X:"`^V
M-`&%]G4I0XG:*U44.U48?.`Q]H-]X`-T?O]%X(-]X`&+7>AT`XM=%+X!````
MZVB#_@(/A:T!``!#B=@K110[11B)VGT>#[8#@#P!`G45D$*)T"M%%#M%&'T)
M#[8"@#P!`G3LB=`K110[11A\`HG3@WW@`G\*.T48?06)TXUV`(G9*TT4.TT8
M#XU:____@WW@`0^.PP```(M%\"GP=0V+=?"%]@^%"O___S'`@\0L6UY?R<.+
M1>0/MC>+%(5$?AH(#[8,,H7)B4WP=09'Z>+^__^#??`"#X27````@7WP_P``
M`'0&1^G]_O__QT7<`````(MUW(L,]6!^&@B)3=B+5=B*`C'VA,")^0^$Y```
M`(C"B?:)R"M%##M%$`^-UP```#@1#X7/````1HM%V(H4,$&$TG7>BWW<BP3]
M9'X:"(M5Y(UY_P^V-!!'B77PZ97^__^)11#I2O[__XG:NP$````K7>")7>"+
M7>B)5>CI)?___T>)_BMU##MU$(GY?1T/M@>`/`("=11!B<@K10P[11!]"0^V
M`8`\`@)T[(G(*T4,.T40?`*)SX-]Y`)_!SM%$'T"B<^)^BM5##M5$`^-\/W_
M_X-]Y`$/CQK^__^)^;\!````*WWDB7WDBWWLB4WLZ0+^__^!_O\```!T)D/I
MI/[__XMUV(H6A-(/A#7_____1=R#?=PG#X[D_O__1^G4_?__QT74`````(M%
MU(L,Q6!^&@B)3=#'1<P`````BU70B@*$P(G9=$*(1<N)RBM5%#M5&'T]BD7+
M.`%U-O]%S(M5T(M%S(H4`D&$THA5RW7;BW74BP3U9'X:"(M5X(U9_P^V-!!#
MZ1S^__^+1="*$(A5RX!]RP!TV/]%U(-]U"=^B$/I__W__XUV`%6)Y8M5$(72
M4XM-%(M=#(M%&'0,@'P3_R!U!4IU]HGVA<!T#(!\`?\@=05(=?:)]FH`4%%2
M4_]U".BB_/__BUW\R<.058GE5U93@^P<BTT4QT7H`````,=%Y`````")3>R-
M=@")R"M%%#M%&'Q:@WWH`\=%\`````!T%O]%Z(-]Z`&+3>QT`XM-%,=%\`$`
M``"+?1`Y?>1S#(I5\(M=#(MUY(@4,XM%\/]%Y(7`=;6+5>0Y51`/ARD!``"+
M11"-9?1;7E_)PXGVBWWH#[8QBQ2]1'X:"`^V'#*%VXE=\'4$0>N!D(-]\`)T
M:H%]\/\```!T`T'KF\=%X`````"+7>"+/-U@?AH(B@<Q]H3`B<L/A+(```"(
MPI")V"M%%#M%&`^-HP```#@3#X6;````1HH4-T.$TG7ABU7@BP359'X:"(MU
MZ(U+_P^V/#!!B7WPZ3W___]!B<@K110[11B)RWT=#[8!@#P"`G440XG>*W44
M.W48?0D/M@.`/`("=.R)V"M%%#M%&'P"B=F#?>@"?P<[11A]`HG9B<HK510[
M51@/C;_^__^#?>@!#X_B_O__B<NY`0```"M-Z(E-Z(M-[(E=[.G*_O__BA>$
MT@^$9O____]%X(-]X"</CA____]!Z:W^__]1BWT0*==7:B"+30P!T5'HB/W\
M_XM%$(/$$(UE]%M>7\G#B?95B>575E.#[!"*512+=0R*11R(5?.+51"+720!
M\HA%\8M%(`'8BDT8.=:+?2B(3?*)5>R)7>B)1>1T43G#ZPJ01CMU['1&.UWD
M=$&*#CI-\G0Z.DWQ=#4Z3?-T(`^VT:%$?AH(B@00A,!TU3P"=AW^P'09B`^(
M"T=#Z\60C48!.T7L=-B)QHH(Z]*)]HG8*T7HBU4LB0*+=3"+32")#NL(Q@,@
MQ@<Y0T<[7>1U\X/$$%M>,<!?R<.058GE4XM=#(H3,<"$THM-$'@&6\G#C78`
M@/J@=A?^PG03*=E)?@Z*4P&`^J!V!O["L`)UWC'`6\G#C78`58GEBU4,@/J@
M=@W^PK@"````=`3)PXGVN`$```#)PY!5B>564XM=$(MU%#GSBTT,NO____]S
M,(/Y?W8DC8%?____/<8```!W2P^WC`F^DAL(A<EU&ULQTHG07LG#C78`B`NZ
M`0```%N)T%[)PXUV`(U#`CGPNO____]WZXG*P?H(B!.(2P%;N@(```")T%[)
MPXUV`(V1.?W__X'ZB@$``'8:C8'KW___/?T"``!W%P^WC`FV2AL(ZYB-=@`/
MMXP)4HL;".N+C9&@V___@?H-`@``=AJ-@0#0__\]?P(``'<:#[>,"<`A&PCI
M8____P^WC`D`/AL(Z5;___^-D8#,__^#^EUW#0^WC`D`&AL(Z3[___^-@0"R
M__\]?T8``'<-#[>,"0!8&@CI)/___XV1B6K__X'Z)0H``'<-#[>,";*T&0CI
M"?___XV!`%3__SVC*P``=PT/MXP)0#`9".GO_O__C9$`!___@?H+`0``=PT/
MMXP)()08".G4_O__C8'_`/__/>4````/A\?^__\/MXP)/H88".FV_O__D%6)
MY5=64XM=$(MU%#GSBWT,#[8+NO____]S/(/Y?WY`C4,".?"Z_____W<KP>$(
M#[9S`0'QC9&_?O__@?J]1P``=RT/MY0)WOD:"(/Z`8D7&=+WTH/B`EM>B=!?
MR<.)]HD/6UZZ`0```(G07\G#B?:-F5\U__\QTH'[73,``'?+#[>4"5X`&@CK
MP8GV58GE5U93@^P8@'T<`,=%Y`````#'1>``````=`R+11@Y11`/AQ<"``"+
M10R)1>B+?12)]HM5Z"M5##M5$`^,10$``(M-Y(7)#X7F`0``BUT0A=L/CML!
M``"+=0R)=>C'1>0!````BU7HB@(/MO"(1=\/MH9@EQP(B47P@7WP_P````^$
M+0$``/]%Z(G[*UT4.UT8?%N+=>"%]@^%B`$``(M5&(72#XY]`0``BWT4QT7@
M`0```(H7#[;R#[:&8)<<"(E%[(%][/\```"(5=YT0D>+1?`K1>QU#8M-\(7)
M#X50____,<"#Q!A;7E_)PXGVBT7@A<!UOHH?#[;+#[:!8)@<"(E%[(%][/\`
M``"(7=YUOC'VBPSU()<<"(H1A-*)^W1$D(GX*T44.T48?1PZ5=YU%Y!!BA%#
MA-)T*XG8*T44.T48?00Z$W3JA-)T&4:#_B</CWC___^+#/4@EQP(BA&$THG[
M=;V+?>"%_P^%U@````^V-/4DEQP(C7O_B77LZ4O___^-=@"+1>2%P`^%T_[_
M_XM=Z(H+#[;1#[:"8)@<"(E%\(%]\/\```"(3=\/A=/^__\Q]HL,]2"7'`B*
M$832BUWH=$60B=@K10P[11!]'#I5WW47D$&*$4.$TG0LB=@K10P[11!]!#H3
M=.J$TG0:1H/^)P^/C/[__XL,]2"7'`B*$832BUWH=;R+3>2%R75"#[8T]227
M'`A+B77PB5WHZ6'^__^0QT7L`````.F=_O__QT7P`````.E+_O__B440Z>']
M__\/MC3U)9<<".DE____#[8T]267'`CKO)!5B>6+51"%TE.+312+70R+11AT
M#(!\$_\@=05*=?:)]H7`=`R`?`'_('4%2'7VB?9J`%!14E/_=0CH8OW__XM=
M_,G#D%6)Y5=64X/L'(MU%,=%[`````#'1>@`````B?:)\"M%%#M%&'QRBWWL
MA?\/A?L```"+71B%VP^.\````(MU%,=%[`$```"*'HA=YP^V^P^VAV"7'`B)
M1?"!??#_````=%E&BWT0.7WH=PR*3?"+10R+7>B(#!B+5?#_1>B%TG6<BTWH
M.4T0#X>L````BT40C67T6UY?R<.0BTWLA<EUIXH&B$7G#[;0#[:"8)@<"(E%
M\(%]\/\```!UIS'_BPS]()<<"(H1A-*)\W1$D(GP*T44.T48?1PZ5>=U%Y!!
MBA%#A-)T*XG8*T44.T48?00Z$W3JA-)T&4>#_R</CV'___^+#/T@EQP(BA&$
MTHGS=;V+=>R%]G5$#[8,_227'`B-<_^)3?#I./___XUV`,=%\`````#I*O__
M_U"+?1`ISU=J((MU#`'.5NAL]OS_BT40@\00C67T6UY?R<,/MA3])9<<"(US
M_XE5\.GT_O__C78`58GE5U93@^P0BD44B$7SBD48B$7RBD4<BTTDBU4,B$7Q
MBW40BT4@`=:+72B-/`''1>P!````B77HB4WDZS")]CI%\G1'.D7Q=$(/OO"*
MAB"6'`B$P(@!=`?'1>P`````#[XRBH8@E1P(B`-!0T([5>AT&3GY=!6*`CI%
M\W7"C7(!.W7H=+J)\HH&Z[Z)R"M%Y(MU+(D&BU4@BT4PB1#K",8!`,8#_T%#
M.?EU]`^^1>R#Q!!;7E_)PU6)Y5=64X/L'(M5"(M*6(M!((M]#(MU%(E%Z)`[
M=1@/A"T!``#_=1A6C47P4/]U"/]5Z#';@\00A<`/CHH```"+5?`Y520/A,``
M```!QCE5'`^$W0```/]U$%>-3>Q1_W4(_U7H@\00A<!^7@''A-MU:HM-\#E-
M('2BBU4HA=)T98M5[(M%*`^VWHL<F(7;B=!T"P^VPHT40`^W1%,$B<*)1>P/
MMMV+12B+')B%VXG(=`L/ML&-#$`/MT1+!(G!B47P.<H/A%+___^Z`0```(UE
M]%M>B=!?R<.-=@"+52B%THM-\'6;BU7LZ]<Y52!U>_]U$%>-7>Q3_W4(`<;_
M5>B#Q!"%P'[#`<>-=@`[=1AT4_]U&%:-5?!2_W4(_U7H@\00A<!^I(M5\#E5
M)'6]`<;KVHGV_W485HU=\%/_=0C_5>B#Q!"%P'Z!`<:S`>D%____,=([?1`/
ME<*-9?1;7HG07\G#,=+I9/___SMU&'3T.WT0NO____\/A%'_____=1A6C4WP
M4?]U"/]5Z(/$$(7`N@$````/CC/___^+51P[5?`/A+<````[?1!T=O]U$%>-
M7>Q3_W4(_U7H@\00A<")1>0/C@'___^+32B%R71+BU7L#[;&BUTHBPR#A<F)
MT'0+#[;:C11;#[=$402+5?")P8E%[`^VWHM%*(L<F(7;B=!T"P^VPHT40`^W
M1%,$B47P.<%T%P-]Y.N-BT7PBTWLZ^^Z_____^FB_O__.WT0=/&#[`S_=2C_
M=23_=2#_=1S_=1A6_W405_]U".BO_?__@\0PA<!_OHG"Z7#^____=1@!QE:-
M1?!0_W4(_U7H@\00A<"Z`0````^/*?___^E+_O__58GE5U93BW44BUT0.?.+
M?0RZ_____W,0B@N$R7@2#[;!B0>Z`0```%M>B=!?R<.0,=*`^<%V\8#YWW<P
MC4,".?"Z_____W?@BEL!@_.`,=*`^S]WTXG.@^8?#[;3P>8&"=:Z`@```(DW
MZ[V0,=*`^>]WM8U#`SGPNO____]WJ8I3`8C0@_"`/#]W%HI;`HC8@_"`/#]W
M"H#YX'<)@/J?=P0QTNN#B<Z#\H"#Y@\/MM+!X@;!Y@R#\X`)U@^VRPG.N@,`
M``")-^E<____58GE5U93BW40BWT4.?Z+30RZ_____W,F@_E_NP$```!W)HT$
M'CGXNO____]W$(/[`G1-?S.#^P%T5XGVB=I;7HG07\G#C78`@?G_!P``LP)V
MT('Y__\``+,#=L9;7C'2B=!?R<.-=@"#^P-USXC*@^(_@\J`P>D&B%8"@,T(
MB?:(R(/@/X/(@,'I!HA&`8#)P(@.ZZ>-=@!5B>575E.#[`R+=0R+11`!\(E%
M[.LFB?:!^_\'``!FOP(`=FJ!^___``!FOP,`=EXQTHGV.U7H=74#=>@[=>QS
M;8H.A,D/B)T````/MM&)5?#'1>@!````BU7P#[;>BPR=`)X<"(7)B=-T"@^V
M^HT4?P^W'%$[=>R)7?")V;K_____<["#^W^_`0```'>*C00^.T7LNO____]W
MF8/_`G0N?Q2#_P%T.(GZ.U7H=(N#Q`Q;7E_)PX/_`W7LB-F#X3^#R8"(3@*)
MV<'I!H#-"(C+@^,_@\N`P>D&B%X!@,G`B?J(#NO$C78`@/G!=L&`^=]W,HU^
M`CM]['>TBE8!@_*`@/H_=ZF)R(/@'\'@!@^VR@G(B47PQT7H`@```.DW____
MC78`@/GO=X6-7@,[7>P/AWG___^*5@&(T(/P@#P_#X=I____BEX"B-B#\(`\
M/P^'6?___X#YX'<)@/J?#X9+____B<^#\H`/MLJ#YP_!YPS!X0:#\X`)SP^V
MTPG7B7WPQT7H`P```.G+_O__C78`58GE5U93@^P,BW4,BT40`?"+?1B)1>SK
M>XUV``^VV8E=\,=%Z`$```"+5?`/MMZ+#)T`GAP(A<F)TW0+#[;"C11`#[=<
M402)7?"+112+"(G(@^`_`P</MM,/K\*)RL'B"`'0,<&+112)"(L7@\(#B1>+
M"(G(@^`_`=#!ZPB)R@^OP\'B"`'0,<&+712)"X,'`P-UZ#MU[`^#I````(H.
MA,D/B77___^`^<$/AI$```"`^=]W,XU6`CM5[`^'@````(I6`8/R@(#Z/W=U
MB<B#X!_!X`8/MLH)R(E%\,=%Z`(```#I0?___X#Y[W=4C5X#.UWL=TR*5@&(
MT(/P@#P_=T"*7@*(V(/P@#P_=S2`^>!W!8#ZGW8JB<B#\H`/MLJ#X`_!X`S!
MX0:#\X`)R`^VTPG0B47PQT7H`P```.GH_O__@\0,6UY?R<.-=@!5B>575E.#
M[`R+70S\N?____\QP(G?\J[WT8U,&?^)3>SK)9"!__\'``!FO@(`=FJ!____
M``!FO@,`=EXQTHGV.U7H=74#7>@[7>QS;8H+A,D/B)T````/MO&)=?#'1>@!
M````BU7P#[;VBPRU`)X<"(7)B==T"@^V^HT4?P^W/%$[7>R)??")^;K_____
M<["#_W^^`0```'>*C00S.T7LNO____]WF8/^`G0N?Q2#_@%T.(GR.U7H=(N#
MQ`Q;7E_)PX/^`W7LB?F#X3^#R8"(2P*)^<'I!H#-"(C*@^(_@\J`P>D&B%,!
M@,G`B?*("^O$C78`@/G!=L&`^=]W,HU[`CM]['>TBE,!@_*`@/H_=ZF)R(/@
M'\'@!@^VR@G(B47PQT7H`@```.DW____C78`@/GO=X6-4P,[5>P/AWG___^*
M4P&(T(/P@#P_#X=I____#[9S`HGP@_"`/#\/AUC___^`^>!W"8#ZGP^&2O__
M_XG/@_*`@_:`@^</#[;2P><,P>(&B?$)UP^V\0GWB7WPQT7H`P```.G(_O__
M58GE5U93@^P,BW4,BT40`?")1>SK)HGV@?O_!P``9K\"`'9K@?O__P``9K\#
M`'9?,=*)]CM5Z'5V`W7H.W7L<VZ*#H3)#XB=````#[;1B57PQT7H`0```(M5
M\`^VWHL,G0">'`B%R8G3=`L/MOJ-%'\/MUQ1`CMU[(E=\(G9NO____]SKX/[
M?[\!````=XF-!#X[1>RZ_____W>8@_\"="Y_%(/_`70XB?H[5>ATBH/$#%M>
M7\G#@_\#=>R(V8/A/X/)@(A.`HG9P>D&@,T(B,N#XS^#RX#!Z0:(7@&`R<")
M^H@.Z\2)]H#YP7;"@/G?=S*-?@([?>QWM8I6`8/R@(#Z/W>JB<B#X!_!X`8/
MMLH)R(E%\,=%Z`(```#I-____XUV`(#Y[W>&C5X#.UWL#X=Z____BE8!B-"#
M\(`\/P^':O___XI>`HC8@_"`/#\/AUK___^`^>!W"8#ZGP^&3/___XG/@_*`
M#[;*@^</P><,P>$&@_.`"<\/MM,)UXE]\,=%Z`,```#IR_[__XUV`%6)Y5=6
M4X/L#(M=#/RY_____S'`B=_RKO?1C4P9_XE-[.LED('__P<``&:^`@!V:X'_
M__\``&:^`P!V7S'2B?8[5>AU=@-=Z#M=['-NB@N$R0^(G0````^V\8EU\,=%
MZ`$```"+5?`/MO:+#+4`GAP(A<F)UW0+#[;ZC11_#[=\40([7>R)??")^;K_
M____<Z^#_W^^`0```'>)C00S.T7LNO____]WF(/^`G0N?Q2#_@%T.(GR.U7H
M=(J#Q`Q;7E_)PX/^`W7LB?F#X3^#R8"(2P*)^<'I!H#-"(C*@^(_@\J`P>D&
MB%,!@,G`B?*("^O$B?:`^<%VPH#YWW<RC7L".WWL=[6*4P&#\H"`^C]WJHG(
M@^`?P>`&#[;*"<B)1?#'1>@"````Z3?___^-=@"`^>]WAHU3`SM5[`^'>O__
M_XI3`8C0@_"`/#\/AVK___\/MG,"B?"#\(`\/P^'6?___X#YX'<)@/J?#X9+
M____B<^#\H"#]H"#YP\/MM+!YPS!X@:)\0G7#[;Q"?>)??#'1>@#````Z<C^
M__]5B>575E.#[""+70R+51`!VHM-%`--&(I%'#G3B$7KB57DB4W@#X/%````
M.4T4#X.\````.UWDQT7<_____W,7B@N$R0^((@$```^V\8EU\,=%W`$```"+
M1>`Y112______W,8BWT4B@^$R0^(HP````^V\8EU[+\!````BT7<A<`/CD,!
M``"%_P^..P$``(M5\`^VQHLTA0">'`B%]HG1=`L/MLJ-%$D/MTQ6!(M5[`^V
MQHLTA0">'`B%]HE-\(G0=`L/ML*-%$`/MT16!#G!B47L#X43`@```UW<`7T4
M.UWD<PR+?>`Y?10/@D3___^`?>L`=`Z+110K1>"#Q"!;7E_)PXM%Y"G8BUT4
M*5W@Z^B-=@`Q_X#YP0^&7?___X#YWP^'1`$``(M5%(/"`CM5X+______#X=`
M____BT44BE`!@_*`,?^`^C\/ARS___^)SH/F'\'F!@^VR@G.9K\"`(EU[.D3
M____C78`@/G!QT7<``````^&V_[__X#YWP^'C0```(U[`CM]Y,=%W/____\/
MA[_^__^*4P&#\H"`^C_'1=P`````#X>I_O__B<B#X!_!X`8/MLH)R(E%\,=%
MW`(```#IC?[__XMUY"G>B778BWW@*WT4BTW8.<^)?=2)^`^/TP```(G!.<")
MWOR+?13SI@^7PP^2P2C+#[[#A<`/A?7^__^+1=@K1=3IZO[__X#Y[\=%W```
M```/AS7^__^-4P,[5>3'1=S_____#X<B_O__BE,!B-"#\(`\/W<?#[9S`HGP
M@_"`/#]W$H#YX`^'G@```(#ZGP^'E0```,=%W`````#IZ_W__S'_@/GO#X<%
M_O__BU44@\(#.U7@O_____\/A_']__^+?12*5P&(T(/P@#P_=QJ+?10/MG<"
MB?"#\(`\/W<*@/G@=Q.`^I]W#C'_Z<']__^)R.DF____B<B#\H"#]H"#X`\/
MMM+!X`S!X@:)\0G0#[;Q"?"_`P```(E%[.F0_?__*<&)R.D'_O__B<^#\H"#
M]H"#YP\/MM+!YPS!X@:)\0G7#[;Q"?>)??#'1=P#````Z3;]__^-=@!5B>57
M5E.#["2+10P#11"+712+51@!VCE%#(E%Z(E5Y`^#T````#G3#X/(````B?:+
M3>@Y30S'1>#_____<QJ+?0R*#X3)#XA<`0``#[;1B57PQT7@`0```#M=Y,=%
MW/____]S%XH+A,D/B-@````/ML&)1>S'1=P!````BT7@A<`/CI4!``"+?=R%
M_P^.B@$``(M5\`^VQHLTA0">'`B%]HG1=`L/MOJ-%'\/MTQ6!(M5[`^VQHLT
MA0">'`B%]HE-\(G0=`L/MOJ-%'\/MT16!#G!B47L#X4T`@``BTW@`4T,BW7H
M`UW<.74,<PD[7>0/@CK___^+5>B+1>0K50PIV#G"=#BX`0```',.B5T,BUWD
MB5WHN/____^+?>@Y?0QS&XGVBW4,BA:`^B`/A=H```#_10R+?>@Y?0QRYS'`
M@\0D6UY?R<.`^<''1=P`````#X8E____@/G?#X=7`0``C7L".WWDQT7<____
M_P^'"?___XI3`8/R@(#Z/\=%W``````/A_/^__^)SH/F'\'F!@^VR@G.B77L
MQT7<`@```.G7_O__C78`@/G!QT7@``````^&H?[__X#YWP^'G@```(MU#(/&
M`CMUZ,=%X/____\/AX+^__^+10R*4`&#\H"`^C_'1>``````#X=I_O__B<^#
MYQ_!YP8/MLH)SXE]\,=%X`(```#I3?[__X#Z'P^'*O____?8Z2/___^+?>B+
M1>0K?0PIV#GXB7W8B474#X_4````B<$YP(G?_(MU#/.F#Y?##Y+!*,L/OL.%
MP`^%Z_[__XM%V"M%U.G@_O__@/GOQT7@``````^'ZOW__XM5#(/"`SM5Z,=%
MX/____\/A]3]__^+?0R*5P&(T(/P@#P_=Q</MG<"B?"#\(`\/W<*@/G@=W.`
M^I]W;L=%X`````#IHOW__X#Y[\=%W``````/A[7]__^-4P,[5>3'1=S_____
M#X>B_?__BE,!B-"#\(`\/W<7#[9S`HGP@_"`/#]W"H#YX'=-@/J?=TC'1=P`
M````Z7/]__^)^.DE____*<&)R.DF_O__B<^#\H"#]H"#YP\/MM+!YPS!X@:)
M\0G7#[;Q"?>)??#'1>`#````Z13]__^)SX/R@(/V@(/G#P^VTL'G#,'B!HGQ
M"=</MO$)]XE][,=%W`,```#I"_W__XUV`%6)Y5=64X/L#(M]#(MU$)"*#X3)
M=$J*'H3;=$B$R7A,#[;1C012#[>,``+>'`A'A-N)3?`/B*X````/MM.-'%(/
MMX0;`MX<"(E%[$8YP73`B<J)]BG"C67T6UZ)T%_)PXH>B?8/MM$/ML/KZ(U7
M`SG7#X.7`0``@/G!#X:.`0``@/G?#X?3````C4<".=`/AWH!``"*5P&#\H"`
M^C\/AVL!``")R(/@'\'@!@^VR@G(B47PN`(```"+5?`!QP^VQHL,A0">'`B%
MR8G0=`L/ML*-%$`/MT11`H3;B<&)1?`/B57___^-=@"-5@,YU@^#+P$``(#[
MP0^&)@$``(#[WP^'MP```(U&`CG0#X<2`0``BE8!@_*`@/H_#X<#`0``B=B#
MX!_!X`8/MMH)V(E%[+@"````BU7L`<8/ML:+'(4`GAP(A=N)T'0+#[;"C11`
M#[=$4P*)1>SI\/[__X#Y[P^'J0```(I7`8C0@_"`/#\/AYD```"*1P*(1>N#
M\(`\/P^'B````(#YX'<%@/J?=GZ)R(/R@`^VRH/@#\'@#,'A!H!UZX`)R`^V
M5>L)T(E%\+@#````Z?[^__^)]H#[[W=ABE8!B-"#\(`\/W=5BD8"B$7J@_"`
M/#]W2(#[X'<%@/J?=CZ)V(/R@`^VVH/@#\'@#,'C!H!UZH`)V`^V5>H)T(E%
M[+@#````Z2;___^#[`A65^BTX?S_B<*#Q!#I-/[__X/L"%97Z*#A_/^)PH/$
M$.D@_O__B?95B>6#[!1H`)X<"/]U)/]U(/]U'/]U&/]U%/]U$/]U#/]U".A\
MZ___R<.)]E6)Y5=64X/L#(M]%(M%&`'XBW4,BU40`?(YQXE5[(E%Z`^#C@``
M`)`[=>P/@X\````[?>AS?XH/A,D/B,@````/MMF)7?"X`0```(M5\`^VWHL,
MG0">'`@!QX7)B=-T"P^VVHT$6P^W7$$$.W7LB5WPB=IS2X/[?[D!````=A6!
M^_\'``"Q`G8+@?O__P``L0-W:9"-!`X[1>QW&8/Y`G1#?RF#^0%T38G(`<8[
M?>@/@G/___\[=>P/@HT```")]HM%$(UE]%M>7\G#D(/Y`W77B-J#XC^#RH"(
M5@*)VL'J!H#."(C3@^,_@\N`P>H&B%X!@,K`B<B(%NNOD#'``<8[?>CKJHUV
M`#'`@/G!#X8X____@/G?=U"-1P([1>AWE8I7`8/R@#'`@/H_#X<:____B<N#
MXQ_!XP8/MLH)R[@"````B5WPZ0#___]0*77L_W7L:B!6Z*[?_/^+11"#Q!"-
M9?1;7E_)PS'`@/GO#X?8_O__C5<#.U7H#X<V____BE<!B-"#\(`\/W<^BE\"
MB-B#\(`\/W<R@/G@=P6`^I]V*(G(@_*`@^`/#[;2P>`,P>(&@_.`"=`/MLL)
MR(E%\+@#````Z8+^__\QP.E[_O__58GE5E-1BU4,BUT0.=IS#(H*A,EX#@^V
MP8E%]%I;,<!>R<.0@/G!=O.`^=]V6H#Y[W?IC4(#.=AWXHI:`8C8@_"`/#]W
MU@^V<@*)\H/R@(#Z/W?(@/G@=P6`^Y]VOHG(@_.`#[;3@_:`@^`/P>(&P>`,
MB?$)T`^V\0GPB47T6ENX`P```%[)PXUR`CG>=XV*4@&#\H"`^C]W@HG+@^,?
M#[;2P>,&"=.)7?1:6[@"````7LG#58GEBU4,@_I_N`$```!V(##`@?K!````
M=A:!^M\```"P`G8,@?KP````&<"#X`.0R<.)]E6)Y8M5$(U"`CM%%+G_____
M=Q8/M@H/MD(!P>$(`<&+50R)"KD"````B<C)PXUV`%6)Y8M5$(U"`CM%%%.Y
M_____XM=#'</B=G!Z0B("HA:`;D"````B<A;R<.058GE5U934HM-#(G/`WT0
MZU6-=@"-<0(Y_HEU\'=,#[89P>,(#[91`8T4$P^VQHLTA0">'`B%]HG3=`H/
MMMJ-!%L/MQQ&.7WPN/____]W#XG:P>H(B!&(60&X`@```(/X`G4'@\$".?ER
MJEA;7E_)PU6)Y5=64U.+=0R+11`!\(M]&(E%\.M[D(U>`CM=\'=W#[8.P>$(
M#[96`8T4$0^VWHL,G0">'`B%R8G3=`L/MMJ-!%L/MUQ!!(M%%(L(B<B#X#\#
M!P^VTP^OPHG*P>((`=`QP8M%%(D(BQ>#P@.)%XL(B<B#X#\!T,'K"`^OPXG+
MP>,(`=@QP8M5%(D*@P<#@\8".W7P<H%96UY?R<.-=@!5B>7)PXUV`%6)Y5=6
M4U>+30R)SP-]$.M6C78`C7$".?Z)=?!W30^V&<'C"`^V40&-%!,/ML:+-(4`
MGAP(A?:)TW0+#[;:C01;#[=<1@(Y??"X_____W</B=K!Z@B($8A9`;@"````
M@_@"=0>#P0(Y^7*I7EM>7\G#C78`58GER<.-=@!5B>575E.#[!B+70R+=12+
M51`!VHGWBD4<`WT8.=.(1?.)5>0/@[H```")]CG^#X.P````C4L".TWDQT7@
M_____W<6#[8##[93`<'@"`'0B47LQT7@`@```(U.`CGYQT7<_____W<6#[8&
M#[96`<'@"`'0B47HQT7<`@```(M-X(7)?GV+1=R%P'YVBTWL#[;5BPR5`)X<
M"(7)BU7L=`L/ML*-!$`/MU1!!(M-Z`^VQ8L,A0">'`B%R8E5[(M%Z'0,#[9%
MZ(T$0`^W1$$$.<*)1>AU,P-=X`-UW#M=Y`^"2?___Y"`??,`B?!U!XM%Y"G8
M*?>#Q!@I^%M>B<*)T%_)PP^V$P^V!H/$&%M>*<*)T%_)PY!5B>575E.#[!2+
M?1B#Y_Z+11"#X/Z)?>")1>2+1>"+70R+=12+3>2+5>")1>B+1>0!V0'R.47@
MB4WPB57L=@.)1>B+5>B%TG1'C78`#[83BPR5`)X<"(7)='H/MGL!C01_#[86
M#[=\002+#)4`GAP(A<ET>`^V1@&-%$`/MT11!#G'=7:#PP*#Q@*#;>@"=;R+
M?>`Y?>1T,+@!````<PV)\XMU[(EU\+C_____.UWP<Q>-=@"*$X32=4R`>P$@
M=4:#PP([7?!R[#'`@\046UY?R<.)]L'B"`^V2P&-/`H/MA:+#)4`GAP(A<EU
MB,'B"`^V3@&-!`HYQW2*@\046RG'7HGX7\G#A-)UP(![`1]WNO?8Z[95B>57
M5E.#[!2Z_____S'`_(M]#(G1\J[WT8U9_XM]$(G1\J[WT8U!_SG8<P*)V(M-
M#(T4`8M=$#G1B57HC30##X.V````B?8Y\P^#K````(U!`CM%Z,=%Y/____]W
M%@^V.0^V40'!YP@!UXE]\,=%Y`(```"-0P(Y\,=%X/____]W%@^V.P^V4P'!
MYP@!UXE][,=%X`(```"+1>2%P'YOBWW@A?]^:(M5\`^VQHL\A0">'`B%_W0+
M#[;"C01`#[=41P*+1>P/MOR+/+T`GAP(A?^)5?!T#`^V1>R-!$`/MT1'`CG"
MB47L=2L#3>0#7>`[3>@/@D____^-=@"+5>B#Q!0IWBG*6RGR7HG07\G##[X1
M#[X#@\046UXIPHG07\G#C78`58GE5U93@^P,BUT4BU48`=J+=0R+11`!\#G3
MB47PB57L<V$YQG-2D(U+`CM-['=4#[8[#[93`<'G"`'7B?H/ML:+/(4`GAP(
MA?^)RXG1=`L/MLJ-!$D/MTQ'!(U6`CM5\'<AB<C!Z`B(!HA.`3M=[(G6<Q`[
M5?!RKXM%$(UE]%M>7\G#.W7P<_"+?0B+7UAJ("EU\/]U\%97_U-$BT40@\00
MC67T6UY?R<.)]E6)Y;@"````R<.)]E6)Y;@"````R<.)]E6)Y5=64X/L/(MU
M#(GP`T402(U5&(M=%(E5U(EUT(E%S(H#A,!T')`\)70H.W7,=!+&!@"*"XA.
M`8/&`D.*`X3`=>7&!@`K=="-9?1;B?!>7\G#D$.*$XU"T#P)=O:`^BYT\8#Z
M+73L@/IL='6`^G-T&X#Z9'1Y@/IU='0[=<QTPL8&`,9&`26#Q@+KKXM-U(LY
MBU7,*?*#1=0$A?^)?<B)5<0/A(L````QP/RY_____XM]R/*N]]&-4?^-!!([
M1<1S)(72ZQ/&!@"+3<B*`4&(1@&#Q@*)3<A*=>M#Z5O___]#BA/KAM%MQ(M5
MQ$KKTXM-S"GQ@_D?C7W8#X9"____BT74@T74!(#Z9(L`=#%2:@I74.B3G/__
M@\00ZPK&!@"(1@%'@\8"B@>$P'7P0^D)____QT7(P[48".EI____46KVZ\V-
M=@!5B>575E.#[!R+70R)WXM%'`-]$(MU",=%[`````#'``````"+1EA74XU5
M\%)6_U`@@\00A<")PGXNB?:+1?"#^"MT#'=*@_@)=`6#^"!U50'3BT985U.-
M5?!25O]0((/$$(7`B<)_U(MU&(7V=`6+?1B)'X/Z`1G`@^`U@\`ABUT<B0,Q
MP(UE]%M>7\G#B?:#^"UU$#')@WWL``^4P0'3B4WLZZVX_____S'2]W44QT78
M`````,=%Z`````")7>2)5=R)1>")]HM&6%=3C4WP45;_4""#Q!"%P'Y!BU7P
M`<.-0M"#^`EW8XG".U44B57P?6R+1>`Y1>AW170\BTWH#Z]-%`'1B4WHBT98
M5U.-3?!15O]0((/$$(7`?[]U0(MU&(7V=`6+?1B)'XM=',<#5@```.E+____
M.U7<=K^)]L=%V`$```#I?/___XU"OX/X&7=(@^HW.U44B57P?)2+51B%TG0%
MBT48B1@[7>1T7XMU[(7V=#6!?>@```"`=C.#?>P!BU4<QP(B````&<"-9?1;
M7BT```"`7\G#C4J?@_D9=[N#ZE?I/____XM]Z(7_>,V+7=B%VW7&BTWLA<F+
M1>@/A+[^___WV.FW_O__BTT<QP$A````Z:?^__^-=@!5B>575E.#[!R+70R)
MWXM%'`-]$(MU",=%[`````#'``````"+1EA74XU5\%)6_U`@@\00A<")PGXN
MB?:+1?"#^"MT#'=*@_@)=`6#^"!U50'3BT985U.-5?!25O]0((/$$(7`B<)_
MU(MU&(7V=`6+?1B)'X/Z`1G`@^`U@\`ABUT<B0,QP(UE]%M>7\G#B?:#^"UU
M$#')@WWL``^4P0'3B4WLZZVX_____S'2]W44QT7H`````,=%Y`````")7>")
M5=B)1=R)]HM&6%=3C4WP45;_4""#Q!"%P'Y!BU7P`<.-0M"#^`EW8XG".U44
MB57P?6R+1=PY1>1W170\BTWD#Z]-%`'1B4WDBT985U.-3?!15O]0((/$$(7`
M?[]U0(MU&(7V=`6+?1B)'XM=',<#5@```.E+____.U78=K^)]L=%Z`$```#I
M?/___XU"OX/X&7<\@^HW.U44B57P?)2+51B%TG0%BT48B1@[7>!T,(MUZ(7V
M=3>+7>R%VXM%Y`^$`?___XUE]%M>]]A?R<.0C4J?@_D9=\>#ZE?I2____XM-
M',<!(0```.G6_O__BWT<N/_____'!R(```#IQ?[__XUV`%6)Y5=64X/L3(M%
M$(M]#`'XBU4<BW4(QT7H`````(E%S,<"`````(M>6/]US%>-3>Q15O]3((/$
M$(7`B<)^+Y"+1>R#^"MT#'=.@_@)=`6#^"!U60'7BUY8_W7,5XU-[%%6_U,@
M@\00A<")PG_2BW48A?9T!8M=&(D[@_H!&=*#XC6#PB&+?1R)%S'`,=*-9?1;
M7E_)PXGV@_@M=1`QP(-]Z``/E,`!UXE%Z.NIBTT4QT7$`````/]UQ(E-P/]U
MP&K_:O_'1;0`````QT70`````,=%U`````")?<CHZYT``(/$$/]UQ/]UP&K_
M:O^)1>")5>3HWYX``(E%W(M%%)F#Q!")1;B)5;R+7EC_=<Q7C57L4E;_4R"#
MQ!"%P'YRBU7L`<>-0M"#^`EV#XU"OX/X&0^'M````(U"R8E%[(M-[#M-%`^-
MO````(M=Y#E=U'<B<@B+5>`Y5=!W&(M=U(M%T#-=Y#-%X`G#=40[3=QV/XUV
M`(M>6/]US%>-5>Q25L=%M`$```#_4R"#Q!"%P'^.=7.+=1B%]G0%BT48B3B+
M?1S'!U8```#IW?[__XUV`(M%T/=EN(M=T`^O7;R)T8M5N`^O5=0!V0'1B46H
MBT7L,=N)3:R)1="+5:B)7=2+3:P!5=`13=3I'?___XU*GX/Y&7<2C4*IB47L
MBTWL.TT4#XQ$____BTT8A<ET!8M5&(DZ.WW(='&+=>B%]G01@7W4````@'(3
M=QB#?=``ZPF!?=3___]_<@)W!XM%M(7`="J+?>B+31PQP(7_QP$B````N@``
M`(`/A3+^__^X_____[K___]_Z2/^__^+7>B%VXM%T(M5U`^$$O[___?8@](`
M]]KI!O[__XM=',<#(0```.GT_?__B?95B>575E.#[$R+11"+?0P!^(M5'(MU
M",=%Z`````")1<3'`@````"+7EC_=<17C4WL45;_4R"#Q!"%P(G"?B^0BT7L
M@_@K=`QW3H/X"70%@_@@=5D!UXM>6/]UQ%>-3>Q15O]3((/$$(7`B<)_THMU
M&(7V=`6+71B).X/Z`1G2@^(U@\(ABWT<B1<QP#'2C67T6UY?R<.)]H/X+740
M,<"#?>@`#Y3``=>)1>CKJ8M-%,=%O`````")3;C'1>0`````QT7(`````,=%
MS`````")?<#_=;S_=;AJ_VK_Z%.;``"#Q!")1=B)5=S_=;S_=;AJ_VK_Z$><
M``")1=2+1129@\00B46PB56TBUY8_W7$5XU5[%)6_U,@@\00A<!^<HM5[`''
MC4+0@_@)=@^-0K^#^!D/A[0```"-0LF)1>R+3>P[310/C;P```"+7=PY7<QW
M(G((BU78.57(=QB+7<R+1<@S7=PS1=@)PW5$.TW4=C^-=@#'1>0!````BUY8
M_W7$5XU5[%)6_U,@@\00A<!_CG5SBW48A?9T!8M%&(DXBWT<QP=6````Z=W^
M__^-=@"+1<CW9;"+7<@/KUVTB=&+5;`/KU7,`=D!T8E%J(M%[#';B4VLB47(
MBU6HB5W,BTVL`57($4W,Z1W___^-2I^#^1EW$HU"J8E%[(M-[#M-%`^,1/__
M_XM-&(7)=`6+51B).CM]P'0GBW7DA?9U+HM]Z(7_BT7(BU7,#X1?_O__]]B#
MT@"-9?1;7O?:7\G#BUT<QP,A````Z3[^__^+11S'`"(```"Z_____[C_____
MZ2K^__]5B>575E.![!P!``"+11"+51@]_P```(VUZ/[__XM=#,<"`````'8%
MN/\```"+?0P!Q^L3BY7D_O__`<.-0O^#^&1W'X@61HM5"(M"6%=3C8WD_O__
M4?]U"/]0((/$$(7`?]&+712),U+_=1A3C8WH_O__4>@+AP``BT44BS"-O>C^
M__\I_@-U#(M=%(DSC67T6UY?R<.)]E6)Y5=64X/L?(M%%(7`BWT,QT60````
M`(UUV<9%V0`/B*0```"XS<S,S/=E&(G1P>D#C02)T>"*51@HPHC0@\`PC5[_
MB$;_ZS"-=@"X9V9F9O?IB56$BU6$B46`P?H"B<C!^!^)T2G!C02)T>")\BC"
MB-!+@\`PB`.%R8G.=<V+39"%R70$2\8#+8G^`W40.?>)?91S)HH#A,!T((M-
M"(M16%97#[[`4%'_4B2#Q!"%P'X)`<=#.?=RW(GV*WV4C67T6UZ)^%_)PXM=
M&(7;#XE1____]UT8QT60`0```.E"____D%6)Y5=64X/L?(M%%(7`BW48BWT<
MQT60``````^(^@```(GZC4W8"?*)393&1=@`=3'IV0```(GV:@!J"E=6Z!&8
M``")Q\'G`H/$$`''T><I_HGQ_TV4BW64@\$PB`Z)UXG&@_\`=]&!_O___W]W
MR87VB?%T.+YG9F9FB?:)R/?NB56$BU6$B<_!^@+!_Q\I^HT<DM'C*-G_392)
M18"(R(/`,(M=E(72B`.)T77/BW60A?9T"?]-E(M-E,8!+8M]#(G^`W40.?=S
M.(M5E(H"A,!T+XGVBTT(BUE85O]U#`^^P%!1_U,D@\00A<!^%`%%#/]%E#EU
M#',)BU64B@*$P'73*7T,BT4,C67T6UY?R<.-7=>)793&1=<PZY*%_P^)_O[_
M__?>@]<`]]_'19`!````Z>O^__^)]E6)Y5=64X/L3(MU$(M=#(7VB=D/A/\!
M``"+?1"+!RG8B<+!ZA\!T(/@_HT\&#G[<QN`.P!U%HI#`3P@#X0#`@``/`D/
MA/L!``"-=@`Y^0^$Q`$``,=%U`````"`.0!U"H!Y`2T/A/X!``"+113'````
M``"*`83`=0J`>0$K#X0W`@``QT70\+_^"L=%S%PO[RO'1<@/````A,`/A7@!
M``"*00$\,`^$\`$``(/H,#P)#X=B`0``@\$"#[;PC5D0.?MV*(G[ZR20@#D`
M#X4]`@``BD$!@^@P/`D/AR\"``"-%+8/ML"--%"#P0(YV779.?D/A!<"``"-
M61(Y^\=%W`````")3>2)7>")7:QV!HE]K(UV`(`Y``^%%@(``(I!`8/H,#P)
M#X<(`@``BUW<C12;#[;`@\$"C110.TVLB57<==(Y^0^$@@$``(`Y``^%?@$`
M`(I!`8/H,#P)#X=P`0``#[;0C4$".?B)5=B)1<0/A-8!``"`>0(`#X7,`0``
MBD`!@^@P/`D/A[X!``"+7=B-%)L/ML"-'%"-002+51`Y^(E=P(D"=!6`>00`
M=0^*2`&#Z3"`^0D/AC("```[==`/ARD"```/A`L"``")=;"[`.AV2(M%L/?C
M:WVP%XG#QT6T`````(G0`?AI5;0`Z'9(C3P0N60```"+1=SWX8E%Z`%=Z(E5
M[(M%P!%][#'V`47H$77LZQV0BU44BTT0QP(A````B1G'1>@`````QT7L````
M`(M%Z(M5[(/$3%M>7\G#B?:#P0(Y^0^#_?W__X`Y``^%]/W__XI!`3P@=.4\
M"73AZ>3]__^#P0(Y^<=%U`$```!THHMU%,<&_____\=%T/A??P7'1<RNE_<5
MQT7("````(H!Z?W]__\Q]HUV`(/!`CGY=&>`.0!U!H!Y`3!T[HU9$ND%_O__
M@\$".?D/A%/___^*`>FW_?__.TW@=6*_`,J:.XGP]^>)PXM]$(M%W(G6B0\Q
MTHM-U`'#$=:%R70']]N#U@#WWHE=Z(EU[(M%Z(M5[(/$3%M>7\G#BT74BWT0
MA<")#W0K]]Z)\)F)1>B)5>R+1>B+5>R#Q$Q;7E_)PXG+*UWDT>N)\/<DG4#I
M'`CKE8GP,=+KU(EUL+L`Y`M4BT6P]^.+?;")P]'GB=#'1;0``````?AI5;0`
MY`M4C3P0N0H```"+1=SWX8E%N`%=N(E5O(MUV!%]O#'_`76X$7V\BW74BT7$
MBU40BTVXBUV\A?:)`HE-Z(E=[`^$@/[__X%]O````(!R"'<P@WVX`'<JBT6X
M]]B+5;R#T@#WVNE(____BWW,.7W<#X+I_?__BU7(.57`#X;=_?__BTW4BU44
M,<"%R<<"(@```+H```"`#X45____N/____^Z_____^D&____C78`58GEBT40
M*T4,B<+!ZA\!T-'XR<-5B>6+1131X,G#B?95B>6+51`K50R+112#XO[1X#G0
M=@*)T,G#C78`58GEBT4,BU40BTT4ZPZ)]L8``(A(`8/J`H/``H/Z`7?OR<.0
M58GEBU4,B=`#11"-2@$YP7,&@'C_('0$*=#)PX!X_@!U]H/H`CG!<^^`>/\@
M=.TIT,G#D%6)Y8/L%&@`GAP(_W4D_W4@_W4<_W48_W44_W40_W4,_W4(Z$S1
M___)PXGV58GE@^P4:@#_=23_=2#_=1S_=1C_=13_=1#_=0S_=0CH(]'__\G#
MD%6)Y5=64X/L$(M-#(M=%(M%$`'(B=Z*51P#=1@YP8A5\XE%Y'-BB?8Y\W-<
MC4$".T7DO_____]W%`^V.0^V40'!YP@!UXE][+\"````C4,".?"Z_____W<4
M#[8##[93`<'@"`'0B47HN@(```"%_WXTA=)^,(M%Z#E%['4R`?D!TSM-Y'*B
MB?:`??,`B=AU!XM%Y"G(*=XI\(G"@\006UZ)T%_)PP^V$0^V"RG*Z^R+5>PK
M5>CKY)!5B>575E.#[`R+30R+712)SP-]$(G>`W48.?ES9XUV`#GS<V"-00(Y
M^,=%Z/____]W%@^V`0^V40'!X`@!T(E%\,=%Z`(```"-0P(Y\+K_____=Q0/
MM@,/ME,!P>`(`=")1>RZ`@```(M%Z(7`?B>%TGXCBT7L.47P=2T#3>@!TSGY
M<IR#Q`R)^BG>*<I;*?)>B=!?R<,/MA$/M@,IPH/$#%M>B=!?R<.+5?`IPNOO
MD%6)Y5=64X/L%+K_____,<#\BWT,B='RKO?1C5G_BWT0B='RKO?1C4'_.=AS
M`HG8BTT,C10!BUT0.=&)5>B--`,/@[8```")]CGS#X.L````C4$".T7HQT7D
M_____W<6#[8Y#[91`<'G"`'7B7WPQT7D`@```(U#`CGPQT7@_____W<6#[8[
M#[93`<'G"`'7B7WLQT7@`@```(M%Y(7`?F^+?>"%_WYHBU7P#[;&BSR%`)X<
M"(7_=`L/ML*-!$`/MU1'`HM%[`^V_(L\O0">'`B%_XE5\'0,#[9%[(T$0`^W
M1$<".<*)1>QU*P--Y`-=X#M-Z`^"3____XUV`(M5Z(/$%"G>*<I;*?)>B=!?
MR<,/OA$/O@.#Q!1;7BG"B=!?R<.-=@!5B>575E.#[`R+?0R+110YQXMU$(M=
M&'00.?-W&U)34%?HCL#\_X/$$#G>=P^-9?1;B?!>7\G#D(GSZ^&+50B)\8M"
M6"G9:B!1C10?4O]U"/]01(/$$(UE]%N)\%Y?R<-5B>575E.+70R)WP-]$#G[
MBW48<S&+%I"+112+"(G(@^`_`=`/MA,/K\*)RL'B"`'0,<&+512)"HL&0X/`
M`SG[B<*)!G+26UY?R<.058GE5U93@^P8BD44B$7SBD48BUT,B$7RBW40BD4<
MBTTD`=Z(1?&+?2"-0P$!SSGPBU4HB77LB4WHB7WD#X/3````C7$!.?YS7HUV
M`(H#A,"(1=]U*HI%\SA#`0^$N0```(I#`8A%XXI%\CA%XP^$O````(I%\3A%
MXP^$V0```(I%WX@"B`&*2P&(2@&(#H/"`HU.`8/#`HUS`3MU['-VC7$!.W7D
M<J6)R"M%Z(M=,(M]+(D#B0>-0?\[1>AV+H!Y_P!U*(!Y_@!U(HGVQ@`@QD#_
M`(U8_X/H`CM%Z'8.@'O_`'4(@'O^`'3BB?:)\.L6Q@(`Q@$`QD(!((U(`<8`
M((/"`H/``CM%Y'+E@\086UXQP%_)PXUQ`>N-C7L".WWL#X,[____B?N*!^E3
M____BWT(9@^V1U6(`6:+3U2(#F8/MD=7B`)FBT=6B$(!C4X!@\("Z3S___^)
MR(M=+"M%Z(D#BWT@BUTPB3O&`0#&!@"+?0AF#[9?5X@:9HM'5HA"`8U.`8/&
M`H/"`CMUY'+;Z7?___]5B>53BTT0BU4,23'`@WT4`HG3=`-;R<,YRG,2@#H`
M=0V`>@$@=0>#P@(YRG+NB=`IV%O)PXUV`%6)Y8M-#(H!@\!?/%:+51!W&BG*
M2GX5BE$!@/J@=@W^PK@"````=`3)PXGV,<#)PU6)Y8I%#(/`7SQ7&<#WT(/`
M`LG#58GE5U93BW40BWT4.?Z+50RY_____W-3@_I_=D>-@ES___\].`$``'=*
M#[><$MB='0@QR87;=#.-5@(Y^KG_____=R>)V8')@(```(G+P?L(B$X!B!Y;
M7KD"````B<A?R<.)]H@6N0$```!;7HG(7\G#B?:-BCG]__^!^8H!``!V&HV:
MZ]___X'[_0(``'<6#[><$M95'0CKF(GV#[><$G*6'0CKC(V"H-O__SWB`0``
M=AN-B@#0__^!^2D!``!W&@^WG!+`+QT(Z63___\/MYP28$D=".E7____C9K@
MS?__@_L)=PT/MYP2:BL=".D_____C8(`LO__/51-``!W#0^WG!(`61P(Z27_
M__^-BH1C__^#^69W#0^WG!(HNQL(Z0W___^-FN%A__^!^X$!``!W#0^WG!+"
MM!L(Z?+^__^-@O\`__\QVSWD````#X??_O__#[><$A[Q&@CITO[__U6)Y5=6
M4XM=$(MU%#GSBWT,#[8+NO____]S0X/Y?WY(C4,".?"Z_____W<RP>$(#[9S
M`8T4,8'B?W\``(V*W][__X'Y-P4``'<N#[>,$K[R'0B#^0$9TO?2B0^#X@);
M7HG07\G#C78`B0];7KH!````B=!?R<.)]HV:W]C__X'[3@(``'8:C8+?S___
M,<D]74<``'>]#[>,$EY!'0CKLY`/MXP2'N(=".NHB?95B>575E-1BU4(BT4,
MBS*+.(M=$$N#^_\/A+(```"%VW1:BA:`^H!V&X#Z_W06BDX!B$WS@^E`@/D^
M=DR`??,`>#Z)]HH/#[;!#[;2BH@@1!X(1T8XBB!$'@ATN`^V3O\/ME__#[:1
M($0>"`^V@R!$'@@IPHG06EM>7\G#BA;KQ(!]\_]TOHGVB@^`^8!VMX#Y_W2R
MBD<!B$7R@^A`/#YW0P^VTL'B"`^V1?,/MLD)PL'A"`^V1?()P3G*=3Q+2X/&
M`H/'`H/[_P^%4/___XGVBU4(B3*+=0R)/C'2B=!:6UY?R<.`??(`#XE8____
M@'WR_W6MZ4W___\/MMJ#^W^)T'9D@^M!#[;$C3S`C31XC12VC;Q30J#__V:+
MM#\@11X(#[;1@>X`?P``@_I_B<@/M]Z-2K]W`XU*P`^VQ(T4P(T\4(TTOXV4
M<4*@__]FBXP2($4>"('I`'\```^WP8G:*<+I#?___X/K0.N:58GE5U93@^P,
MBT48B47LBT40BE4<.448B%7S=@.)1>R+=0R+?12+7>R-=@!+@_O_#X2N````
MA=MT5HH6@/J`=AN`^O]T%HI.`8A-ZX/I0(#Y/G9(@'WK`'@ZB?:*#P^VP0^V
MTHJ(($0>"$=&.(H@1!X(=+@/MD[_#[9?_P^VD2!$'@@/MH,@1!X(*<+K7HGV
MBA;KR(!]Z_]TPHGVB@^`^8!VNX#Y_W2VBD<!B$7J@^A`/#YW5@^VTL'B"`^V
M1>L/MLD)PL'A"`^V1>H)P3G*=4]+2X/&`H/'`H/[_P^%5/___XGVB74,B7T4
M,=*%THG0=0R`??,`=`Z+1>PK11B#Q`Q;7E_)PXM%$.OP@'WJ``^)2?___X!]
MZO]UFND^____#[;:@_M_B=!V9(/K00^VQ(T\P(TT>(T4MHV\4T*@__]FB[0_
M($4>"`^VT8'N`'\``(/Z?XG(#[?>C4J_=P.-2L`/ML2-%,"-/%"--+^-E'%"
MH/__9HN,$B!%'@B!Z0!_```/M\&)VBG"Z5[___^#ZT#KFI!5B>575E.#[`B+
M11B+51`YT(E%\'8#B57PBW4,BWT4BUWPB?9+@_O_#X3"````A=MT8HH6@/J`
M=AN`^O]T%HI.`8A-[X/I0(#Y/G94@'WO`'A&B?:*#P^VP0^VTHJ(($0>"$=&
M.(H@1!X(=+@/MD[_#[9?_P^VL2!$'@@/MH,@1!X(*<:%]G1PB?"#Q`A;7E_)
MPXGVBA;KO(!][_]TMHGVB@^`^8!VKX#Y_W2JBD<!B$7N@^A`/#X/AZ0````/
MMM+!X@@/MD7O#[;)"<+!X0@/MD7N"<$YR@^%G0```$M+@\8"@\<"@_O_#X5`
M____B?:)=0R)?10Q]HM5&#E5$'2(OP$```!S58M%%(E5$(E%#+______BU40
MC1P0*UWP.=@/@V+___^-4`&*2O^`^2!U&8UV`(G0B54,0CG8#X-&____BDK_
M@/D@=.J`^1^)^`^'-?____?8Z2[___^+10SKM(!][@`/B>O^__^`?>[_#X5(
M____Z=S^__\/MMJ#^W^)T'9B@^M!#[;$C13`C310C3RVC91[0J#__V:+M!(@
M11X(#[;1@>X`?P``@_I_B<@/M]Z-2K]W`XU*P`^VQ(T\P(T4>(TTDHV\<4*@
M__]FBXP_($4>"('I`'\```^WP8G>Z9S^__^#ZT#KG)!5B>575E.#[`R+11"+
M=0R+712)1?"+31A)@_G_=#F)]H7)=$B*$X#Z@'89@/K_=!0/MGL!C4?`/#YV
M.8GXA,!X+XUV``^V^HJ'($0>"(@&0T9)@_G_=<F+31@Y3?!W9HM%\(UE]%M>
M7\G#B?:*$^O4_L!TT('G_P```,'B"`GZ#[;"@_A_C7B_=P.->,`/MM:-!-*-
M!$*-%("-A%="H/__9HN4`"!%'@B!Z@!_``")T&;!Z`B(!HA6`8/#`H/&`DGI
M4____U.+7?`K71A3:B!6Z)NY_/^+1?"#Q!"-9?1;7E_)PY!5B>575E.#[!"*
M512(5?.*51B(5?**51R+10R(5?&+51`!PHM-)(E5[(M5(`'*.T7LBUTHB4WH
MB57D=$(YT70^C7`!.W7L=&"*$(#Z@'9=@/K_=%@/MG@!C4?`/#YW9(@3B!&*
M%HA3`8A1`8/#`H/!`D8[=>R)\'0%.TWD=<*)SRM]Z(M5,(MU+(DZB3[K"9#&
M`2#&`R!!0SM-Y'7S@\006UXQP%_)PY"*$(GV.E7S=!\Z5?)T*CI5\70OB!.(
M$4-!ZZ^)^(3`>>/^P'62Z]V0.W7L=-R*!H@#B`%#0>N2D,8!`,8#_T%#ZXB)
MR"M%Z(M5+(D"BWT@BW4PB3[&`0#&`_]!0SM-Y'7SZY*058GEBT4,BA"`^H"+
M31!V&/["=!0IP4E^#XI0`8U"P#P^=@V$TG@%D#'`R</^PG3XN`(```#)PY!5
MB>6+50R`^H!V#?["N`(```!T!,G#B?:X`0```,G#D%6)Y593BUT0BW44.?.+
M30RZ_____W,P@_E_=B2-@5S___\]K0,``'=+#[>,"?BU'PB%R74;6S'2B=!>
MR<.-=@"("[H!````6XG07LG#C78`C4,".?"Z_____W?KB<K!^@B($XA+`5NZ
M`@```(G07LG#C78`C9'PW___@?H"`P``=AJ-@:#;__\]X@$``'<7#[>,"8!D
M'PCKF(UV``^WC`D`<1\(ZXN-D0#0__^!^BD!``!V&HV!X,W__SV#````=QH/
MMXP)@$4?".EC____#[>,">!*'PCI5O___XV1<LS__X/Z1W<-#[>,"01"'PCI
M/O___XV!`++__SVE40``=PT/MXP)P&D>".DD____C9'4!O__@?K]````=PT/
MMXP):!$=".D)____C8'0`?__/;4!```/A_S^__\/MXP)X`,=".GK_O__B?95
MB>575E.+71"+=10Y\XM]#+G_____<T(/MA.#^G]^1(U#`CGPN?____]W+L'B
M"`^V<P&-##*-F<!^__\QTH'[#WT``'<(#[>4"2"\'@B#^@$9R??1B1>#X0);
M7HG(7\G#C78`B1=;7KD!````B<A?R<.)]E6)Y5.+70R*"XU!?SP>BU40=@>-
M02`\''<6*=I*?A&*4P&-2L"`^3YV$H32>`>)]C'`6\G#@/K\=_:)]K@"````
M6\G#58GEBU4,C4)_/!YV#8U*((#Y'+H!````=P6Z`@```(G0R<.058GE5U93
M@^P,BTT,BT40C3P!BUT4BT48`=B*51PY^8A5\XE%[`^#KP```#G##X.G````
MD`^V,8U&?SP>=@B-5B"`^AQW:HGX*<A(?F.*40&-0L`\/G=5BA.-0G\\'G8'
MC4(@/!QW2XM%["G82'Y#BD,!B$7K@^A`/#X/AY(```"!YO\```#!Y@@/MD$!
M#[;2"<;!X@@/MD,!"<(YU@^%B@```(/!`H/#`NLBD(32>%B*$X'F_P````^V
MTHJ&8+T@"(J28+T@"#C0=5A!0SGY<PD[7>P/@EK___^)30R)710QR8!]\P!T
M#(M%&#E%$'8$B440D(7)B<AU!HM%$"M%&(/$#%M>7\G#@/K\=Z/I1?___X!]
MZP!YFH!]Z_QWE.E=____#[;(#[;:*=GKM8GQ*='KKY!5B>575E.#[`B+50R+
M112+31@!P8G7B4WP`WT0B=&)PSGY#X.<````.UWP#X.3````#[8QC49_/!YV
M#8U6((#Z'`^'Q0```)")^"G(2`^.N0```(I1`8U"P#P^#X>G````BA.-0G\\
M'G8+C4(@/!P/AYD```"+1?`IV$@/CHT```"*0P&(1>^#Z$`\/@^'I@```('F
M_P```,'F"`^V00$/MM()QL'B"`^V0P$)PCG6#X7?````@\$"@\,".?D/@F7_
M__^0B5T4B4T,,=N+10PY^`^$@````#GXO@$````/A(@````Y^',6C5`!D(I*
M_X#Y('58B=")50Q".?AR[HG8@\0(6UY?R<.$TG@BBA.!YO\````/MM**AF"]
M(`B*DF"](`@XT'5804/I\O[__X#Z_'?9Z2G___^`?>\`>="`?>_\=\KI2?__
M_XUV`(#Y'XGP=ZWWV.NIBTWP.4T4=)\Y^+X!````#X5X____BT44BWWPOO__
M__^)10SI9?___P^VV`^V\BGSA=L/A6_____I./___XGS*=/K[8GV58GE5U93
M@^P,BUT,BTT0BU44`=F+11B)3?"-/`([7?!S0CGZ<SZ*"HU!?SP>=@>-02`\
M''<:B?XIUDY^$P^V<@&-1L`\/G8TB?"$P'@IB?8/MO&*AF"](`B(`T)#.UWP
M<L")]HM5&#E5$'<HBT40C67T6UY?R<,\_'?5D(@+0T([7?!SWSGZ<Y2*`H@#
M0D/KS(UV`%"+?1`K?1A7:B!3Z)"R_/^+11"#Q!"-9?1;7E_)PXGV58GE5U93
M@^P4BD44BDT8BWT,B$7SB$WRBD4<BTT0BU4D`?F(1?&+12`!T#G/BUTHB4WL
MB57HB47D<UDYPG-5D(H/C4%_/!YV!XU!(#P<=QR+=>PI_DY^%`^V=P&-1L`\
M/G9@B?"$P'A6C78`.DWS=&LZ3?(/A*(````Z3?$/A+(```"("T=#B`I".WWL
M<P4[5>1RK(G6*W7HBTTPBWTLB3&)-^L+C78`Q@,@Q@(@0T([5>1R\X/$%%M>
M,<!?R<,\_'>IB`M'0X@*0CM5Y'.[B@>(`T=#B`+KL(UV`(UW`3MU['.-B@Z(
MR(/`?SP>B?>(3>-W-HM-["GY27[.BD\!C4'`/#YV"83)><"`^?QWNXI-XX@+
MC7X!0X@*ZZW&`@!'Q@/_0D/I8/___XC(@\`@/!QWE^N_B=`K1>B+32R)`8MU
M((M],(DWQ@(`Q@/_0D,[5>1R\^E<____C78`58GE5U93BW40BWT4.?Z+30RZ
M_____W-=@_E_?D>-0:0]FP```'=5#[>4":AM(0B)TS'2A=MT/HV+7____X/Y
M/G9BC48".?BZ_____W<GB=K!^@B(%HA>`5M>N@(```")T%_)PX/Y7+M?@0``
M=-2(#KH!````6UZ)T%_)PXV1;_S__X'ZP````'8FC9GPW___@?L"`P``=R4/
MMY0)@"8A".N-B?:('EM>L@&)T%_)PY`/MY0)GF4A".ER____C8$`V___/6\!
M``!V&XV1`-#__X'Z_@```'<:#[>4"<`!(0CI2O___P^WE`G`&2$(Z3W___^-
MF0"R__^!^X%&``!W#0^WE`F@."`(Z2+___^-@8EJ__\]*0H``'<-#[>4"5*5
M'PCI"/___XV9_P#__S'2@?OD````#X?T_O__#[>4"5[`'@CIY_[__U6)Y5=6
M4XM=$(MU%#GSBWT,#[83N?____]S'X/Z?WXDC8)?____@_@^=QT/MXP2_K@A
M"(D/N0$```!;7HG(7\G#C78`B1?K[8U#`CGPN?____]WYL'B"`^V<P$!\HV:
M7____X/[/G8LC8K`?O__@?E^`P``=R@/MXP2P+`@"(GV@_D!B0\9R5OWT5Z#
MX0*)R%_)PY`/MXP2_K@A".OBC8)A=___/5T7``!V&HV:P!___S')@?MD"@``
M=\4/MXP2(*\?".N[#[>,$D)S(`CKL9!5B>564XMU$#';BU4,.?)S%HUV`(H*
MC4%?/#YV!(3)>`]#0CGR<NV)V%M>R<.-=@"#PP*#P@+KU56)Y5=64U&+50R+
M=1"+?12)5?"%_W01D#GR<PR*"H3)>!)"A?]U\9`K5?")T%I;7E_)PY"-07\\
M'G8(C5D@@/L<=Q6)\"G02'X.BEH!C4/`/#YV%(3;>`N-65^`^SYWR$+KP(#[
M_'?P@\("ZZ:-=@!5B>575E.#['R`?1P`=`R+11@Y11`/A^X```"+31"+=1B-
M1#$"C568@_A0B564#X?Q````5O]U$(M=E`-=$/]U#(U[`?]UE(E]D.BEJOS_
M@\0,Q@,`_W48_W44_W60Z)&J_/^+11C&1`,!`(M-$(/$$(7)O_C___^+791^
M)8UV`(H3A-(/B+(````/MO**AJ"\(0B#[PB(`XUQ_T.)\87)?]Z+31B%R;_X
M____BUV0?B6-=@"*$X32#X@2`0``#[;RBI:@O"$(@^\(B!.-<?]#B?&%R7_>
M@^P(_W60_W64C7V8Z-VM_/^#Q!`[?92)PW0.@^P,_W64Z'BO_/^#Q!"-9?2)
MV%M>7\G#B440BTT0BW48C40Q`HU5F(/X4(E5E`^&#____X/L#%#H%JK\_X/$
M$(E%E.G[_O__C78`#[;"C02`P>`"C;!@P"$(BX!PP"$(J!")=8QT`X/O"*@@
M=#&#^0%T+(I#`8A%BP^VP(TT@/8$M7#`(0@0=!:*18N(`XA3`8UQ_D-#B?'I
M$/___XGVC7'_BTV,@WD$"`^.^_[__U&-4P%64E/H2*G\_XM-C(GX`D$$@^@(
MBTT0BU642XA$"O^#Q!!#B?'IT?[__XUV``^VPHT$@,'@`HVP8,`A"(N`<,`A
M"*@0B76$=`.#[PBH('0Q@_D!="R*0P&(18,/ML"--(#V!+5PP"$($'06BD6#
MB`.(4P&-<?Y#0XGQZ;#^__^)]HUQ_XM-A(-Y!`@/CIO^__]25HU#`5!3Z+2H
M_/^+382)^`)!!(/H"(M-&(M5D$N(1`K_@\000XGQZ7'^__^-=@!5B>575E.#
M['R+51"+31B-1`H"@_A0QT60`````,=%C`````"-?9@/ARL"``"+=1!05HT<
M-_]U#(U+`5>)393H3*C\_X/$#,8#`/]U&/]U%/]UE.@XJ/S_BT48@\00A?;&
M1`,!`(GQQD6+^(G[?B20BA.$T@^(I@````^V\HJ6H+PA"(!MBPB-<?^($T.)
M\87V?]V+31B%R<9%@OB+791^)HUV`(H3A-(/B`H!```/MO**EJ"\(0B`;8((
MC7'_B!-#B?&%R7_=BUT8.UT0=@.+71"-##N-=@`YSP^#D`$``(MUE(H61HEU
ME(H'1SC0=.@/ME__B5V,#[9^_RE]C(GVBTV0A<ET#H/L#/]UD.C^K/S_@\00
MBT6,C67T6UY?R<,/ML*-!(#!X`*-L&#`(0B+@'#`(0BH$(EUA'0$@&V+"*@@
M=#2#^0%T+XI#`8A%@P^VP(TT@/8$M7#`(0@0=!F*18.-<?Z(`XA3`4-#B?&%
M]ND<____C78`BU6$@WH$"(UQ_P^.!/___U%6C4,!4%/H_*;\_XI%BXM5A`)"
M!(/H"(M-$$N#Q!"(1`__0XGQA?;IW/[__XUV``^VPHT$@,'@`HVP8,`A"(N`
M<,`A"*@0B;5\____=`2`;8((J"!T-8/Y`70PBD,!B(5[____#[;`C32`]@2U
M<,`A"!!T%XJ%>____X@#B%,!C7'^0T.)\>FO_O__C7'_BXU\____@WD$"`^.
MF?[__U)6C4,!4%/H7:;\_XN-?/___XI%@@)!!(/H"(M-&(M5E$N(1`K_@\00
M0XGQZ6O^__^#[`Q0Z'^F_/^)QX/$$(E%D.F__?__B?:+11@Y11`/A(3^__^Y
M`0```',+B440BWV4N?____^+=1"-%#<IVCG7#X-B_O__B@<\('4/1SG7#X-3
M_O__B@<\('3Q/!^)38P/AT+^___WV8E-C.DX_O__58GE5U93@^P@BT40B47P
MBT48.T7P=@.+1?!0_W44_W4,Z#IM__^)QRM]#(/$$(7_B?G&1>_XBUT,?B"0
MBA.$TG@N#[;RBH:@O"$(@&WO"(UQ_X@#0XGQA?9_X3E]\`^'F0```(M%\(UE
M]%M>7\G#D`^VPHT$@,'@`HVP8,`A"(N`<,`A"*@0B77H=`2`;>\(J"!T,(/Y
M`70KBD,!B$7G#[;`C32`]@2U<,`A"!!T%8I%YXUQ_H@#B%,!0T.)\87VZY>)
M]HM5Z(-Z!`B-<?]^A%*-2P%645/H[*3\_XI%[XM5Z`)"!(/H"(M-#$N#Q!"(
M1#G_0XGQA?;I7/___U"+5?`I^E)J((M=#`'[4^@GJ/S_BT7P@\00C67T6UY?
MR<.058GE5U93@^P,BUT,BD44BW40`=Z(1?.*11B(1?*)=>R*11R+522(1?$[
M7>R+12"+32B)5>B-/`)T)HGV.?IT((H#.D7S=$4Z1?)T4#I%\716B`%#B`)!
M0CM=['7?C78`B=8K=>B+13"+72R),(DSZPN-=@#&`2#&`B!!0CGZ=?2#Q`Q;
M7C'`7\G#B?:-<P$[=>QTLXGSB@;KMXGVQ@(`0\8!_T)!Z[&)T(MU+"M%Z(D&
MBUT@BW4PB1Z-=@#&`@!"Q@'_03GZ=?3KMHGV58GEBTT0.TT4N/____]S(`^V
M`0^WE`!@VR$(BT4,B1`QP(72=06`.0!U!;@!````R<.)]E6)Y5:+=1`[=113
MN/____^+70QS)P^VQXL,A6#4(0@QTH7)=`8/ML.*%`@QP(32B!9U!(7;=06X
M`0```%M>R<-5B>564XM=#(H3,<F$THMU$'@)6XG(7LG#C78`#[;"+:$```"#
M^%UW%XGP*=A(?A`/MD,!+:$```"#^%VQ`G;3@/J.=`V`^H]T)#')6XG(7LG#
MB?$IV4E^[`^V0P$MH0```(/X/KD"````=J?KURG>@_X"?M4/ME,!@>JA````
M@_I==\8/MG,"@>ZA````@_Y=N0,````/AG?___\QR>NL58GE#[95#(V"7___
M_X/X7;D"````=A>!^HX```!T#S'`@?J/````#Y3`C4P``8G(R<.)]E6)Y5=6
M4XM-%(M=#(7)BW40B=IT%SGS<Q.-=@`/M@*#^']W%$))=`0Y\G+PB=`IV%M>
M7\G#C78`B==".?)S(CV.````="8]CP```'0L+:$```"#^%UW"HH"/*!V!/[`
M=<.)^"G86UY?R<.)]HH"@\!@/#]VKXGXZ^H/M@)".?)RS(GXZ]Z-=@!5B>4Q
MP%.+30R+71`YV7,6BA&`^HYT%8#ZCW08A-)X'$!!.=ERZEO)PXUV`$"#P0+K
MVHGV@\`"@\$#Z]"#P`*#P0+KR%6)Y5=6BTT0BW44.?%3N_____]S?0^V$8/Z
M?WYKC7D".?>[_____W=IC9I?____@_M=#[9Y`7=DC8]?____,=N#^5UW38'Z
M]`````^/6@$``,'B"(V4.@"`__^-LE_>__^#_EV-2H`/A]X````/MY0)_A(C
M"(M-##';A=*)$702NP(```#K"Y"+10R)$+L!````B=A;7E_)PXUV`('ZC@``
M`'1M,=N!^H\```!UY(V'7____X/X77?9C5$#.?*[_____W?-#[91`HV*7___
M_S';@_E==[R!__0````/CZ,!``#!YPB-%!>-FE%=__^#^Q6-BH!___\/A\P`
M```/MY0)@D0C"(M-#(D1NP,```#K@8V77____S';@_H^#X=P____#[>T/P!6
M(PB%]HM]#(DW#X5)____@'D!``^%4?___[L"````Z4?___^-@E_=__^#^%UV
M&(VZ4-S__X/_2G<:#[>4"8`-(PCI!____P^WE`D^$",(Z?K^__^-FE_;__^#
M^U)W#0^WE`G>"B,(Z>+^__^-LE_:__^#_E5W2`^WE`D>"",(Z<K^__^-!%+!
MX`0IT(M=#(VT1VF%``"),[L"````Z<G^__^-LA5=__^#_@9W*@^WE`GB0R,(
MBTT,B1'I)/___XV"7]G__X/X-W<J#[>4"9X%(PCI=_[__XVZ'UG__X/_&W<J
M#[>4";X[(PB+30R)$>GO_O__C;I?V/__@_]0=RH/MY0)W@(C".E"_O__C8(^
M6/__@_@,=RH/MY0)UCDC"(M-#(D1Z;K^__^-FE_7__^#^Q]W2`^WE`F>`",(
MZ0W^__^-F@Y8__^#^PQW2`^WE`E<.2,(BTT,B1'IA?[__XT$?\'@!"GXC;Q"
M%8D``+L#````BU4,B3KI[_W__XVR7\___X/^77<J#[>4"=[O(@CINOW__XVR
M7U;__X/^+W<J#[>4"9XU(PB+30R)$>DR_O__C9'?SO__@_I==RH/MY0)'NTB
M".F%_?__C;I?5?__@_]6=RH/MY0)WC(C"(M-#(D1Z?W]__^-@=_-__^#^%UW
M+`^WE`E>ZB((Z5#]__^-@E]4__^#^%9W+`^WE`D>,",(BTT,B1'IR/W__XGV
MC;G?S/__@_]==RH/MY0)GN<B".D9_?__C9I?3___@_M==RH/MY0)7B4C"(M-
M#(D1Z9']__^-F=_+__^#^UUW*@^WE`G>Y"((Z>3\__^-D=_.__^#^EUW*@^W
ME`F>(B,(BTT,B1'I7/W__XVQW\K__X/^77<J#[>4"1[B(@CIK_S__XVQW\W_
M_X/^77<J#[>4"=X?(PB+30R)$>DG_?__C9'?R?__@_I==RH/MY0)7M\B".EZ
M_/__C;G?S/__@_]==RH/MY0)'ATC"(M-#(D1Z?+\__^-@=_(__^#^%UW*@^W
ME`F>W"((Z47\__^-@=_+__^#^%UW*@^WE`E>&B,(BTT,B1'IO?S__XVYW\?_
M_X/_77<J#[>4"=[9(@CI$/S__XV9W\K__X/[77<J#[>4"9X7(PB+30R)$>F(
M_/__C9G?QO__@_M==RH/MY0)'M<B".G;^___C9'?R?__@_I==RH/MY0)WA0C
M"(M-#(D1Z5/\__^-L=_%__^#_EUW*@^WE`E>U"((Z:;[__^-L=_(__^#_EUW
M*@^WE`D>$B,(BTT,B1'I'OS__XV1W\3__X/Z77<J#[>4"9[1(@CI<?O__XVY
MW\?__X/_77<J#[>4"5X/(PB+30R)$>GI^___C8'?P___@_A==RH/MY0)WLXB
M".D\^___C8'?QO__@_A==RH/MY0)G@PC"(M-#(D1Z;3[__^-N=_"__^#_UUW
M*@^WE`D>S"((Z0?[__^-F=_%__^#^UUW*@^WE`G>"2,(BTT,B1'I?_O__XV9
MW\'__X/[77<J#[>4"5[)(@CITOK__XV1W\3__X/Z77<J#[>4"1X'(PB+30R)
M$>E*^___C;'?P/__@_Y==RH/MY0)GL8B".F=^O__C;'?P___@_Y==RH/MY0)
M7@0C"(M-#(D1Z17[__^-D=^___^#^EUW*@^WE`G>PR((Z6CZ__^-N=_"__^#
M_UUW*@^WE`F>`2,(BTT,B1'IX/K__XV!W[[__X/X77<J#[>4"1[!(@CI,_K_
M_XV!W\'__X/X77<J#[>4"=[^(@B+30R)$>FK^O__C;G?O?__@_]==RH/MY0)
M7KXB".G^^?__C9G?P/__@_M==RH/MY0)'OPB"(M-#(D1Z7;Z__^-F=^\__^#
M^UUW*@^WE`F>NR((Z<GY__^-D=^___^#^EUW*@^WE`E>^2((BTT,B1'I0?K_
M_XVQW[O__X/^77<J#[>4"=ZX(@CIE/G__XVQW[[__X/^77<J#[>4"9[V(@B+
M30R)$>D,^O__C9'?NO__@_I==RH/MY0)'K8B".E?^?__C;G?O?__@_]==RH/
MMY0)WO,B"(M-#(D1Z=?Y__^-@=^Y__^#^%UW*@^WE`E>LR((Z2KY__^-@=^\
M__^#^%UW*@^WE`D>\2((BTT,B1'IHOG__XVYW[C__X/_77<J#[>4"9ZP(@CI
M]?C__XV9W[O__X/[77<J#[>4"5[N(@B+30R)$>EM^?__C9G?M___@_M==RH/
MMY0)WJTB".G`^/__C9'?NO__@_I==RH/MY0)GNLB"(M-#(D1Z3CY__^-L=^V
M__^#_EUW*@^WE`D>JR((Z8OX__^-L=^Y__^#_EUW*@^WE`G>Z"((BTT,B1'I
M`_G__XV1W[7__X/Z77<J#[>4"5ZH(@CI5OC__XVYW[C__X/_77<J#[>4"1[F
M(@B+30R)$>G.^/__C8'?M/__@_A==RH/MY0)GJ4B".DA^/__C8'?M___@_A=
M=RH/MY0)7N,B"(M-#(D1Z9GX__^-N=^S__^#_UUW*@^WE`G>HB((Z>SW__^-
MF=^V__^#^UUW*@^WE`F>X"((BTT,B1'I9/C__XV9W[+__X/[77<J#[>4"1Z@
M(@CIM_?__XV1W[7__X/Z77<J#[>4"=[=(@B+30R)$>DO^/__C;'?L?__@_Y=
M=RH/MY0)7ITB".F"]___C;'?M/__@_Y==RH/MY0)'MLB"(M-#(D1Z?KW__^-
MD=^P__^#^C)W*@^WE`G>FB((Z4WW__^-N=^S__^#_UUW*@^WE`E>V"((BTT,
MB1'IQ??__XV!WZ___X/X77<J#[>4"1Z8(@CI&/?__XV!W[+__X/X77<J#[>4
M"9[5(@B+30R)$>F0]___C;G?KO__@_]==RH/MY0)7I4B".GC]O__C9G?L?__
M@_M==RH/MY0)WM(B"(M-#(D1Z5OW__^-F=^M__^#^UUW*@^WE`F>DB((Z:[V
M__^-D=^P__^#^EUW*@^WE`D>T"((BTT,B1'I)O?__XVQWZS__X/^77<J#[>4
M"=Z/(@CI>?;__XVQWZ___X/^77<J#[>4"5[-(@B+30R)$>GQ]O__C9'?J___
M@_I==RH/MY0)'HTB".E$]O__C;G?KO__@_]==RH/MY0)GLHB"(M-#(D1Z;SV
M__^-@=^J__^#^%UW*@^WE`E>BB((Z0_V__^-@=^M__^#^%UW*@^WE`G>QR((
MBTT,B1'IA_;__XVYWZG__X/_77<J#[>4"9Z'(@CIVO7__XV9WZS__X/[77<J
M#[>4"1[%(@B+30R)$>E2]O__C9G?J/__@_M==RH/MY0)WH0B".FE]?__C9'?
MJ___@_I==RH/MY0)7L(B"(M-#(D1Z1WV__^-L=^G__^#_EUW*@^WE`D>@B((
MZ7#U__^-L=^J__^#_EUW*@^WE`F>OR((BTT,B1'IZ/7__XV1WZ;__X/Z77<J
M#[>4"5Y_(@CI._7__XVYWZG__X/_77<J#[>4"=Z\(@B+30R)$>FS]?__C8'?
MI?__@_A==RH/MY0)GGPB".D&]?__C8'?J/__@_A==RH/MY0)'KHB"(M-#(D1
MZ7[U__^-N=^D__^#_UUW*@^WE`G>>2((Z='T__^-F=^G__^#^UUW*@^WE`E>
MMR((BTT,B1'I2?7__XV9WZ/__X/[77<J#[>4"1YW(@CIG/3__XV1WZ;__X/Z
M77<J#[>4"9ZT(@B+30R)$>D4]?__C;'?HO__@_Y==RH/MY0)7G0B".EG]/__
MC;'?I?__@_Y==RH/MY0)WK$B"(M-#(D1Z=_T__^-D=^A__^#^EUW*@^WE`F>
M<2((Z3+T__^-N=^D__^#_UUW*@^WE`D>KR((BTT,B1'IJO3__XV!WZ#__X/X
M77<J#[>4"=YN(@CI_?/__XV!WZ/__X/X77<J#[>4"5ZL(@B+30R)$>EU]/__
MC;G?G___@_]==RH/MY0)'FPB".G(\___C9G?HO__@_M==RH/MY0)GJDB"(M-
M#(D1Z4#T__^-F=^>__^#^UUW*@^WE`E>:2((Z9/S__^-D=^A__^#^EUW*@^W
ME`G>IB((BTT,B1'I"_3__XVQWYW__X/^77<J#[>4"9YF(@CI7O/__XVQWZ#_
M_X/^77<J#[>4"1ZD(@B+30R)$>G6\___C9'?G/__@_I==RH/MY0)WF,B".DI
M\___C;G?G___@_]==RH/MY0)7J$B"(M-#(D1Z:'S__^-@=^;__^#^%UW*@^W
ME`D>82((Z?3R__^-@=^>__^#^%UW*@^WE`F>GB((BTT,B1'I;//__XVYWYK_
M_X/_77<J#[>4"5Y>(@CIO_+__XV9WYW__X/[77<J#[>4"=Z;(@B+30R)$>DW
M\___C9G?F?__@_M==RH/MY0)GELB".F*\O__C9'?G/__@_I==RH/MY0)'IDB
M"(M-#(D1Z0+S__^-L=^8__^#_EUW*@^WE`G>6"((Z57R__^-L=^;__^#_EUW
M*@^WE`E>EB((BTT,B1'IS?+__XV1WY?__X/Z77<J#[>4"1Y6(@CI(/+__XVY
MWYK__X/_77<J#[>4"9Z3(@B+30R)$>F8\O__C8'?EO__@_A==RH/MY0)7E,B
M".GK\?__C8'?F?__@_A==RH/MY0)WI`B"(M-#(D1Z6/R__^-N=^5__^#_UUW
M*@^WE`F>4"((Z;;Q__^-F=^8__^#^UUW*@^WE`D>CB((BTT,B1'I+O+__XV9
MWY3__X/[77<J#[>4"=Y-(@CI@?'__XV1WY?__X/Z77<J#[>4"5Z+(@B+30R)
M$>GY\?__C;'?D___@_Y==RH/MY0)'DLB".E,\?__C;'?EO__@_Y==RH/MY0)
MGH@B"(M-#(D1Z<3Q__^-D=^2__^#^EUW*@^WE`E>2"((Z1?Q__^-N=^5__^#
M_UUW*@^WE`G>A2((BTT,B1'IC_'__XV!WY'__X/X77<J#[>4"9Y%(@CIXO#_
M_XV!WY3__X/X77<J#[>4"1Z#(@B+30R)$>E:\?__C;G?D/__@_]==RH/MY0)
MWD(B".FM\/__C9G?D___@_M==RH/MY0)7H`B"(M-#(D1Z27Q__^-F=^/__^#
M^UUW,`^WE`D>0"((Z7CP__^-L=^2__\QTH/^0@^']_#__P^WE`F^?2((BTT,
MB1'IZO#__XVQWX[__X/^77<-#[>4"5X](@CI/?#__XV1WXW__X/Z77<-#[>4
M"9XZ(@CI)?#__XV!WXS__X/X77<-#[>4"=XW(@CI#?#__XVYWXO__S'2@_\%
M#X?\[___#[>4";PU(@CI[^___XGV58GE5U93BWT0.WT4BUT,N?____]S#(/[
M?W\1B!^Y`0```%M>B<A?R<.-=@"#^UP/A+\```"-@U[___^#^!1W.`^WE!O\
M@"((A=)T;(U?`CM=%+G_____=\F!PH"```")T,'X"(@'B%<!N0(```!;7HG(
M7\G#C78`@?O7````#X1D`0``@?OW````#X1D`0``C9-O_/__@_HX#X;@````
MC8O_^___@_E0#X>R`0``#[>4&_YX(@CKD(/[?7Y#C;.?`/__@_X^#X>;````
MC5-`B!>-7P([712Y_____P^'0/___XH/B$\!N0(```#&!X[I>O___P^W%6J"
M(@CI2/___X/[7(@?=<J#^WX/A/````"-@U____\]W0```'9OC;,S_O__@_X/
M#X=,`0``#[>4&X88(PB%TG1FC5\#.UT4N?____\/A]G^__^!PH"```")T,'X
M"+D#````Q@>/B$<!B%<"Z;O^__^!^Z4```!T)X'[/B```'60Q@=^Z5+___\/
MMY0;GGHB".F\_O__#[>4&_X:(PCKGL8'7.DS____C;,`(/__@?ZK`P``=V"-
M5P([512Y_____P^'9?[__[A=04RN]^;!Z@:-'%+!XP0IT]'C*=Z-3J&-0O6(
M3P&Y`@```(@'Z8;^__\/MQ4T@B((Z53^__\/MQ4R@B((Z4C^__\/MQ7\'2,(
MZ2C___^!ZZSC```QR8'[JP,```^'`O[__XUW`SMU%+G_____#X?Q_?__N%U!
M3*[WX\'J!HT,4L'A!"G1T>$IRXU"];D#````C5.AQ@>/B$<!B%<"Z<+]__^-
ML_#?__^#_BMW+0^WE!N`0"((Z=#]__^!^_4!``!T6(V3.?W__X/Z%G<U#[>4
M&U(6(PCIG/[__X'[`R$``'1<@?LK(0``='B-@W#>__^#^`-W50^WE!MB/2((
MZ8C]__^-BWS\__^#^0QW&0^WE!NB%",(Z5S^__\/MQ4.'",(Z5#^__^-@U;\
M__^#^"1W/0^WE!L,%",(Z3C^__\/MQ6,@"((Z4#]__^-DR[>__^#^@)W,0^W
ME!O8/"((Z2C]__\/MQ6*@"((Z1S]__^-L_[[__^#_@UW)0^WE!LB$R,(Z?#]
M__^-BP#>__^#^3UW)0^WE!L`/"((Z>S\__^-DZ[[__^#^@UW)0^WE!MF$B,(
MZ<#]__^-LZ[=__^#_AEW)0^WE!L<.R((Z;S\__^-B^K>__^#^0QW)0^WE!O$
MV"((Z9#]__^-@W[=__^#^`5W)P^WE!N8.B((Z8S\__^-@_ZQ__\]%P$``'<_
M#[>4&[Q\(@CI7OW__X'[I2(```^$$0$``('[$B,```^$T@```(V3`-O__X/Z
M2W=%#[>4&P`U(@CI0OS__XGVC;/2L/__@?XX`@``=PT/MY0;Y'4B".D1_?__
MC9."KO__@?J7`P``=R4/MY0;!&HB".GV_/__C8M@VO__@_DO=R4/MY0;8#,B
M".GR^___C8O6JO__@_D\=RT/MY0;+&(B".G&_/__@?OO)0``=%:-L_O9__^#
M_@%W)P^WE!N",B((Z;K[__^-@X&J__\]MP8``'<]#[>4&P)4(@CIC/S__XV#
MP-G__X/X`G=,#[>4&P8R(@CIB/O__P^W%9A_(@CI?/O__P^W%9!^(@CI</O_
M_XVSIZ/__X'^D@(``'<Q#[>4&PY!(@CI0?S__P^W%9I_(@CI2?O__XV3EMG_
M_X/Z!7<H#[>4&Z8Q(@CI,?O__XV3_J#__X'Z1P(``'<E#[>4&QPW(@CI`OS_
M_XV+`-#__X/Y''<H#[>4&T`>(@CI_OK__XV+HI[__X'Y,@$``'<H#[>4&^0O
M(@CIS_O__XVSO\___X'^O0```'<G#[>4&SX<(@CIR/K__XV#6IW__SWU!```
M=R</MY0;5",B".F:^___C8,`LO__/18'``!W)0^WE!N`TB$(Z93Z__^-LU"8
M__^#_DEW)0^WE!N@&"((Z6C[__^-D]*J__^#^C5W*`^WE!NDPR$(Z63Z__^-
MD^R7__^!^@,!``!W*`^WE!NX%2((Z37[__^-BX6J__^!^>\!``!W*`^WE!LJ
MOR$(Z2[Z__^-B\^6__^!^0X$``!W*`^WE!M>"R((Z?_Z__^-LX&H__^!_AP#
M``!W)P^WE!OBM"$(Z?CY__^-@ZF2__\]K0```'<G#[>4&[(!(@CIROK__XV#
M1*7__SUM`@``=R@/MY0;B*DA".G$^?__C;/BD?__@?ZQ````=R@/MY0;I/XA
M".F5^O__C9.UHO__@?JH#@``=R@/MY0;"H<A".F.^?__C9,5D?__@?KY`0``
M=R@/MY0;"ODA".E?^O__C8OXD___@?GK````=R@/MY0;L&<A".E8^?__C8L&
MC___@?GB````=R@/MY0;#/,A".DI^O__C;/UDO__@?[^!@``=R</MY0;JE<A
M".DB^?__C8,(CO__/:8,``!W)P^WE!NPUR$(Z?3Y__^-@]Z+__\](P0``'<H
M#[>4&QQ!(0CI[OC__XVSQ8#__X'^"0$``'<H#[>4&PJ[(0CIO_G__XV3HX?_
M_X'Z/P8``'<H#[>4&R8L(0CIN/C__XV3H'___X'Z]P(``'<H#[>4&\"R(0CI
MB?G__XV+RH#__X'Y(@0``'<H#[>4&Q06(0CI@OC__XV+D'S__X'YJ0```'<H
M#[>4&T"K(0CI4_G__XVSC7S__X'^)P@``'<G#[>4&SK](`CI3/C__XV#T7O_
M_SU1!```=R</MY0;`J$A".D>^?__C8/)<___/=\```!W*`^WE!ORZ2`(Z1CX
M__^-LVAW__^!_B0!``!W*`^WE!O0E2$(Z>GX__^-DYQR__^!^@`"``!W*`^W
ME!MXXR`(Z>+W__^-DRQV__^!^LL!``!W*`^WE!NXCR$(Z;/X__^-BV5P__^!
M^9<!``!W)0^WE!O*VR`(Z:SW__^-B\AS__^#^6QW*`^WE!L0BB$(Z8#X__^-
ML[=N__^!_G`!``!W)0^WE!MNU2`(Z7GW__^-@T=S__^#^&)W)P^WE!LNB"$(
MZ4WX__^-@S%M__\]&0$``'<H#[>4&R+0(`CI1_?__XVSFW+__X'^``(``'<E
M#[>4&[:"(0CI&/C__XV3_6O__X/Z?G<H#[>4&[K,(`CI%/?__XV38W#__X'Z
MYP0``'<E#[>4&V9T(0CIY??__XV+B6K__X/Y;G<E#[>4&_+((`CIX?;__XV+
MB&K__X/Y;G<H#[>4&]!G(0CIM??__XVSY&G__X'^6`(``'<G#[>4&^C"(`CI
MKO;__XV#XVG__SU/`@``=R4/MY0;YF$A".F`]___C8-89___@_@>=R4/MY0;
MD+T@".E\]O__C;-59___@_XA=R4/MY0;:EPA".E0]___C9,E9___@_I\=R4/
MMY0;*KP@".E,]O__C9,?9___@_I_=R@/MY0;_EHA".D@]___C8MJ9O__@?G5
M````=R@/MY0;]+@@".D9]O__C8ME9O__@?G"````=R@/MY0;ZE<A".GJ]O__
MC;-89?__@?ZR````=R</MY0;4+4@".GC]?__C8-69?__/=$!``!W)P^WE!L,
M4B$(Z;7V__^-@Y%D__\]"0$``'<H#[>4&Z*Q(`CIK_7__XVS&F/__X'^-P$`
M`'<H#[>4&Q1+(0CI@/;__XV3&V/__X'Z&`$``'<N#[>4&W:L(`CI>?7__XV+
MAF'__S'2@?DK`0``#X=1]O__#[>4&XQ%(0CI1/;__XV+YF'__X/Y!'<-#[>4
M&_*I(`CI0/7__XVSBV'__X'^`@$``'<-#[>4&S:G(`CI)?7__XV#<V#__X/X
M$W<-#[>4&\:D(`CI#?7__XV3_P#__X/Z7'<-#[>4&Q[E'PCI]?3__XV+'0#_
M_S'2@_D"#X?D]/__#[>4&SKC'PCIU_3__XUV`%6)Y8M-"(M%$(M5%%.)002-
M1!#^BUT,B4$(BT,LQP$\%"8(B4$,BU,TBT,PB5$0B4$46\G#C78`58GE5U93
M@^P4BWT(BP=FBQ!FA=(/A8P```"+7P2)7>R+1PB)1>B+7>R+3Q"+5PP[7>B)
M3>")5>1W7XGV#[8SBU<4B7<<#[9+`8U#`H72B4\@B47LB4<$B57P=!`[1>AW
M"X7V=0>`>P(`=$N0BUW@BQ2SA=(/A((```"+7>0/M@0>#Z_(C01*9HL09H72
M=1>+7>P[7>B)!W:C@\046UZX_____U_)PX/``HD'#[?"@\046UY?R<.*0`$\
M0':OA,!XJX/Y0'ZF@_E_?Z$/MM")R,'@!HT4$(M%\`^WE%"`W___A=)TAXU'
M&(D'C4L$B=!FQT<8``")3P3KM(GVB?/!XPB-%`N-3QB)T(D/B?&-L@#,__\-
M`(#__\'Y!X'^M1D``(E7(&:)1QAFQT<:``!W$8V!@/L``(E''(/$%%M>7\G#
MC;(`LO__@?ZE40``=PN-@4#[``")1QSKWXV!P/L``(E''.O4C78`58GEBU4(
MBT40B4($`T44BTT,B4((BT$LQP(\%"8(B4(,BT$TB4(0BT$PB4(4B4HDR<.)
M]E6)Y5=64X/L#(MU"(L&9HL09H72#X2C````@\`"B08/M\*-9?1;7E_)PXM6
M)(M:6/]V"%>-??!74O]3((/$$(7`B<,/B"8!``"+5?")T<'I"(7)#X46`0``
M@>+_````@_I`#X8'`0``@_I_#X?^````BTX@B<C!X`8!T(M6%`^WE$*`W___
MA=(/A1T!``"+7AR-=@"+1>R+%)B%T@^$B````(M]Z`^V!#L/K\B-!$IFBQ!F
MA=(/A5____^)!HM>$(M.#(M&)(M06(E=[(E-Z/]V"/]V!(U]\%=0_U(@@\00
MA<")P@^.D````(M%\(M^!`'7B<.+5A3!ZP@/MLB%THE>'(E.((E^!'2*A=MU
MAH/Y0'Z!@_E_#XX.____BT7LBQ28A=(/A7C___^)W\'G"(T4#XU.&(G0B0Z)
MV8V:`,S__PT`@/__P?D'@?NU&0``B58@9HE&&&;'1AH``'<IC8&`^P``B48<
MC67T6UY?R<.+7AR+3B#I&O___XUE]%M>N/____]?R<.-F@"R__^!^Z51``!W
M"XV!0/L``(E&'.O'C8'`^P``B48<Z[R-?A@!7@2)T&;'1A@``(D^Z6+^__]5
MB>575E.#['R)183_=0S_=0A0C46X4(G6_Q+_=13_=1#_=82-?8A7_Q:#Q""-
M=@"#[`R-3;A1_U8$B3PDB</_5@2#Q!`YPXG!=12%VW_AA=MX2HG8*<B-9?1;
M7E_)PX7;?NR%P'GHBT6$BU`LBW@T#[8"P>`&BQ</MSP0.?MU4(/L#(U=N%/_
M5@2#Q!"%P(G#?^DQP(UE]%M>7\G#A<E^LHM%A(M0-(M`+`^V`(L2P>`&#[<<
M$(GV.<MUEX/L#%?_5@2#Q!"%P(G!?^PQP.O%B=@I^.N!B?95B>575E.#['R+
M50B+6EB+31B+0R`Y312)1>@/A*,!``"-=@#_=1C_=12-=?!6_W4(_U7H,=N#
MQ!"%P`^.0@$``(M5\#E5)`^$@P$```%%%#E5'`^$.P$``/]U$/]U#(U-[%'_
M=0C_5>B#Q!"%P`^.#P$```%%#(3;#X6]````BUWP.5T@#X2,````BWT(BTWL
MB=C!Z`B+=S2)RHE%B(EUD,'J"(M'+`^V/!")?>2+=8@/M@0PB46$#[;!#Z_'
MBWV0BQ27C01"B47@#[;##Z]%A(L4MXT$0HM5X(72B47<#X33````A<`/A,L`
M``"+180Y1>1V3]'@B478_#G`BW7@BWW<B<'SIG5ZBU6$BTW@#[<$487`=6R+
M11@Y110/A0'___^+51`Y50P/E<"-9?1;7@^VT(G07\G#C78`BUWPZ4?___]S
M'(M=Y-'C_#G;BW7@BWW<B=GSIG4IBU7DBTW<ZZV+7>31X_PYVXMUX(M]W(G9
M\Z8/E\`/DL(HT`^^P(7`=)2Z`0```(UE]%M>B=!?R<.)]O]U&/]U%(U]\%?_
M=0C_5>B#Q!"%P'[8`444LP'II/[__XUV`#'`.=D/E<#I3____XM-$#E-#.E:
M____D(M]&#E]%'1-_W48_W44C77P5O]U"/]5Z(/$$(7`?I2+5?`Y521T-3E5
M('4U`444_W40_W4,C4WL4?]U"/]5Z(/$$(7`#XYI____`44,BUT8.5T4=;,Q
MTNE<____`444Z^R+11@Y111T[(M]$#E]#+K_____#X0^_____W48_W44C5WP
M4_]U"/]5Z(/$$(7`N@$````/CA[___^+51P[5?`/A"8!``"+31`Y30SK,(GR
MT>+\.=*+=;")WXG1\Z9U$HM]M(M=L`^W!'N%P`^$'P$``(M=E`%=#(M5$#E5
M#`^$O0```/]U$/]U#(U=[%/_=0C_5>B#Q!"%P(E%E`^.L?[__XMU\(M="(M]
M[(GPP>@(BTLTB?J)1;R)38S!Z@B+0RP/MAP0B5VXBTV\#[8$"(E%M(GX)?\`
M```/K\.+78R+%).-!$*)1;")\"7_````#Z]%M(L4BXT<0HM%L(7`=#6%VW0Q
MBW6T.76X#X<^____<SF+1;C1X/PYP(MUL(G?B<'SI@^%2?___XM5N`^W!%/I
M-?___S'`.?</E<#I*?___[K_____Z0W^__^+1;C1X(G!.<")W_R+=;#SI@^7
MPP^2P2C+#[[#Z?[^__\!113_=1C_=113_W4(_U7H@\00A<"Z`0````^/NO[_
M_^G'_?__BWT0.7T,=*C_=23_=2#_=1S_=1C_=13_=1#_=0S_=0CH&OS__X/$
M((7`?@N+=90!=0SI?O[__XG"Z8G]__^058GE5U93@>P,#@``BT4(BU`<A=+'
MA3SR__\`````N0$````/A%$!``")U_PQP+G_____\JZ)SO?6C;TH\___N08`
M```QP,:%://__P")E4CS___SJXF54//__XG7C506_XVU2//__\>%./+__P8`
M```QV\>%-/+__P````")E13R__^)E4SS___'A53S__\`````QX58\___````
M`(FU]/'__\>%"/+__P````"-=@")^3F]%/+__^LHB?:*$8#Z('05@/H)=!"`
M^@UT"X#Z"@^%^0$``(GV08N]]/'__SE/!'?8,=*+M?3Q__^+!H72B48(B0X/
MA#$#``"#^@8/A/8#``"#^P%T?'X1@_L"#X2/````B[U(\___ZY2%VW7T@_H$
M#X3(`@``BY50\___4(N%%/+__RG0@_@==@6X'0```%!2C;WH\O__5^BH0___
MB3PDQH7F\___`&C7P!@(:.+`&`AJ?HV%://__U#H/E#__X/$(+D!````C67T
M6UX/OL%?R<.#^@1T"8/Z`0^%.P<``+L"````B94X\O__Z7'___^#^@4/A6L'
M``"#O3CR__\$#X3'`0``@[TX\O__`0^%P`<``(NU]/'___R-O8CR__^)T?.E
MC8U(\___B[U,\___B8WT\?__BXU(\___B[58\___.<^)M2SS__^)O13R___K
M(8H1@/H@=!.`^@ET#H#Z#70)@/H*#X52`P``03F-3//__W?=,=*+G4CS__^#
M^@6)G5#S__^)C4CS__\/A)L!``#\N04```"-O4CS__^-M8CR___SI8N]3//_
M_\>%,//__P````")O13R__^+A53S__^#^`,/A%<!``"#^`(/A'X!``!(#X2,
M`0``@;TT\O__@`````^#(P<``(V]Z//__P.]"/+___RY!@```(VU*//___.E
M_X4T\O__@X4(\O__&+L!````Z47^__^`^B8/A&H"``"`^CP/A&P"``"-0I\\
M&0^&R````(U"OSP9#X:]````@/I<#X7+````BY7T\?__BWH$C4$".?B)O1#R
M__\/@[$```"`>0%U#X6G````B<&+A?3Q___'0!``````ZSD/OCF-1]"#^`F)
MPG86C7>?@_X%C5>I=@N-5[^#^@5W(8U7R872>!J+M?3Q__^+?A#!YP0!UXE^
M$$$YC1#R__]WO[H%````Z6;]__^+A5CS__^[`0```(F%*//__\>%-//__P``
M``#'A3CS__\`````QX4\\___`````.E@_?__#[[RBY7T\?__B7(00;H%````
MZ1O]__^Z!@```.D1_?___X4\\___Z:[^__^+C5CS__^)C3#S___I?O[__[L"
M````QX4X\O__!````.D/_?___X4X\___QX4\\___`````.ET_O___X4T\___
MQX4X\___`````.O?BX4T\O__A<")A03R__\/B#7]__^#[`QH``0``/]5#(/$
M$(7`B85`\O__N0$````/A!G]__]1:``$``!J`%#H87S\_\<$)``!``#_50R#
MQ!"%P(F%1/+__[D!````#X3K_/__4F@``0``:(";(PA0Z,!X_/^+C03R__^#
MQ!"%R0^.,`$``(U=Z(N5!/+__^LL#[:S`?3__XJ&@)LC"`^VBP7T__^+M43R
M__\X!`YS`X@$#H/#&$H/A#P"``"+NPCT__^%_W3*_X4\\O__Z^2+E5#S__]0
MBX44\O__*="#^!T/AY0```!04HV="//__U/HV#___XD<),:%YO/__P!H[<`8
M"&CBP!@(:GZ-E6CS__]2Z2O\__]!N@0```#IF?O__XNU]/'__T&+5@0YRL=&
M#`$```!V!8`Y/'1)N@$```#I=?O__X#Z)G1@@/H\#X1]!```C5J?@/L9=@N-
M0K\\&0^'S@,```^^^D&)O5CS__^Z!0```.F$_/__N!T```#I8O___XN]]/'_
M_XM'#$%`.<J)1PQVI8`Y/'6@@_@"?N2Z`0```.D0^___0;H$````Z4G\__\Q
MTI"+A4#R__^+')"%VW40BPR5@)<C"(NU0/+__XD,ED*!^O\```!^VHN5//+_
M_XM="(N%1/+__XN]0/+__X72B4,LB7LTQT,P`````'4',<GI0_O__X/L#&@`
M(```_U4,@\00A<")0S"Y`0````^$)?O__U=H`"```&H`4#'_Z&MZ_/^#Q!`[
MO03R__]]P(UUZ.M>C78`BY8$]/__@_H_#X;N^O__@_I_#X?E^O__@_L_#X;<
M^O__@_M_#X?3^O__P>(&C8P:P.___XM="(M3,&:+`(N='/+__V8#0PQFB01*
M1X/&&#N]!/+__P^-7?___XN>"/3__X7;=.:+E@#T__\/MLZ-A@#T__^!XO\`
M``")A1SR__\/MH&`FR,(#Z_"BQ2-@)<C"(T$0F:#>`(`#X1A____N0$```#I
M6?K__XUV`,>%`/+__P````"+G03R__\YG0#R__\/C:'^__^-5>B)E0SR___K
M'_^%`/+__XN]!/+__X.%#/+__Q@YO0#R__\/C7?^__^+C0SR__^+M0SR__^+
M@0CT__\/MKX!]/__A<")O2#R__\/MKD%]/__=;>+E4#R__^+'+J%VXF=&/+_
M_P^%AP```(N%1/+__P^V'#B#[`S!XPE3_U4,@\00BXU`\O__A<")!+D/A*+Y
M__]24VH`4.CS>/S_,=N#Q!")]HNU1/+__P^V!#X/MI>`FR,(#Z_#C0P2#Z_3
M@^P$T>"+M4#R___1X@,$O@,4O8"7(PA14E!#Z$)U_/^#Q!"!^_\```!VNXL<
MOHF=&/+__XN-#/+__P^VL03T__^)M?SQ__^+E0SR__^+A43R__^+G2#R__\/
MMHH`]/__#[84.`^V@X";(PB-'``/K\'1X(N-(/+__P,$C8"7(PA14XNU&/+_
M_P^OE?SQ__^-%%904NC)=/S_BYU$\O__#[84.XNU0/+__P^OE?SQ__^+#+YF
MBSQ1BX4,\O__9@.X#/3__X/$$&:)/%'I??[__XN54//__U"+A13R__\IT(/X
M'78%N!T```!04HVUR/+__U;H`SS__XDT)&C_P!@(:.+`&`AJ?HV-://__U'&
MA>;S__\`Z5;X__^+E5#S__^+A13R__\IT(/X'5=V!;@=````4%*-G:CR__]3
MZ+H[__^)'"1H#\$8"&CBP!@(:GZ-E6CS__]2QH7F\___`.D-^/__@/I<=1>-
M00*+O4SS__\Y^',*@'D!=0^$R@```+H&````Z:3X__^+E5#S__^+A13R__\I
MT(/X'5-V!;@=````4%*-G4CR__]3Z$L[__^)'"1H(L$8",:%YO/__P#I;OO_
M_XN54//__XN%%/+__RG0@_@=5G8%N!T```!04HV=:/+__U/H$#O__XD<)&@V
MP1@(QH7F\___`.EC]___08N53//__SG*QX54\___`0```'8%@#D\=!2Z`0``
M`.D*^/__@#D\=?&#^`)_[(N%5//__T%`.<J)A53S__]WY+H!````Z>3W__^)
MP<>%6//__P````#K00^^&8U#T(/X"8G"=AJ-<Y^#_@6-4ZEV#XU3OX/Z!0^'
M)/O__XU3R872#X@9^___B[58\___P>8$`=:)M5CS__]!.<]WN[H%````Z8?W
M__^058GE5U93@^Q\_W40_W4,BUT(BD4<4XU]N(A%AU?_%8@H)0B#Q!#_=1C_
M=113C76(5O\5B"@E"(/$$(GV@^P,5_\5C"@E"(DT)(G#_Q6,*"4(@\00.<-U
M!(7;?^"`?8<`=`8QTH7`>`2)VBG"C67T6UZ)T%_)PXGV58GE5E.+=0R+71"+
M312+51B)512)31")70R+10B)=0A;7KJ(*"4(R>G?[___C78`58GE5U93@^Q`
MBUT(BT-8_W40_W4,4XMU%(M]&/]0&(/$$%#_=0Q3C46X4/\5B"@E"(/$$.M"
MB?:+#HG(@^`_B=H#!\'Z"`^OPHG*P>((`=`QP8D.BQ>#P@.)%XL.B<B#X#\!
MT`^VTP^OPHG*P>((`=`QP8D.@P<#@^P,C5VX4_\5C"@E"(/$$(7`B<-_JHUE
M]%M>7\G#B?95B>575E.#[#S_=1C_=13_=0B+11"-?;B+70R#X/Y7C308_Q6(
M*"4(@\00ZR.-=@"#[`Q7_Q6,*"4(@\00A<")PGX1B='!^0B("XA3`8/#`CGS
M<MR+?0B+1RR+5S0/MCC!YP:+$CGS#[<4%W,3B=#!^`B)]H@#B%,!@\,".?-R
M]/9%$`%T`\8#`(M%$(UE]%M>7\G#58GE5U93@^Q\_W40_W4,BUT(BD4<4XU]
MN(A%AU?_%8`H)0B#Q!#_=1C_=113C76(5O\5@"@E"(/$$(GV@^P,5_\5A"@E
M"(DT)(G#_Q6$*"4(@\00.<-U!(7;?^"`?8<`=`8QTH7`>`2)VBG"C67T6UZ)
MT%_)PXGV58GE5E.+=0R+71"+312+51B)512)31")70R+10B)=0A;7KJ`*"4(
MR>D+[O__C78`58GE5U93@^Q`BUT(BT-8_W40_W4,4XMU%(M]&/]0&(/$$%#_
M=0Q3C46X4/\5@"@E"(/$$.M"B?:+#HG(@^`_B=H#!\'Z"`^OPHG*P>((`=`Q
MP8D.BQ>#P@.)%XL.B<B#X#\!T`^VTP^OPHG*P>((`=`QP8D.@P<#@^P,C5VX
M4_\5A"@E"(/$$(7`B<-_JHUE]%M>7\G#B?95B>575E.#[#S_=1C_=13_=0B+
M11"-?;B+70R#X/Y7C308_Q6`*"4(@\00ZR.-=@"#[`Q7_Q6$*"4(@\00A<")
MPGX1B='!^0B("XA3`8/#`CGS<MR+?0B+1RR+5S0/MCC!YP:+$CGS#[<4%W,3
MB=#!^`B)]H@#B%,!@\,".?-R]/9%$`%T`\8#`(M%$(UE]%M>7\G#58GE5U93
M@^PLB<.)5?"+L`@!``"+N`P!``#K'X/L"`^^!E!HU\T8".CW<_S_@\00A<!T
M*4:)LP@!```Y_G+=BW7PB3Z+BPP!``"+5?")2@2X10```(UE]%M>7\G#BWWP
MB3>+@P@!``"+5?")0@2+LP@!``")=>#\N00```"_P,T8"/.F#X6$````B[,,
M`0``.77@B77H<T&Y`P```(MUX+_%S1@(\Z9T,(M5X$*)5>2+=>2+1>@YQHEU
MX(FS"`$``',61HEUY/RY`P```(MUX+_%S1@(\Z9UU_RY`P```(MUX+_%S1@(
M\Z9U#8-%X`.+5>")DP@!``"+1>"+7?")0P2-9?1;7KA#````7\G#BW7@B@Z#
M[`@/OOF(3>]7:,G-&`CH_7+\_X/$$(7`=!V+1>!`B8,(`0``BUWPB4,$BQ,/
MO@*-9?1;7E_)PX!][R(/A*$```"`?>\G#X27````B[,,`0``ZR>+3>"#[`@/
MOCE7:-#-&`CHJ7+\_X/$$(7`=1'_1>"+5>")DP@!```Y=>!RU(M%\(MUX(EP
M!(L8ZQZ#[`@/OCM7:-?-&`CH<W+\_X/$$(7`=#!#BU7PB1H[7>!RW>LCC78`
M@^P(#[Y&_U!HU\T8".A*<OS_@\00A<!T"TZ+3?")<00Y\W+<N$D```#I7_[_
M_XM5X$*+NPP!```Y^HF3"`$```^#H0```(MU\(L.B@&+=>#K&(G60CGZB9,(
M`0``#X.>````BT7PBPB*`3A&`77CB=:+5?")<@2+DP@!``"*`C@!=&N-60&+
M1?")&.L>@^P(#[X[5VC7S1@(Z+YQ_/^#Q!"%P'0T0XM5\(D:.?-RWKA3````
MZ=3]__^#[`@/OD;_4&C7S1@(Z)%Q_/^#Q!"%P'3=3HM-\(EQ!#GS<MRX4P``
M`.FF_?__BWWPBP_K@8U*`8F+"`$``(M]\(L/BW<$ZX*+=?"+#NED____D%6)
MY5=64X'L/`$``(M%#(M5"(M=$(M-"(/J@`'#B96\_O__B9$``0``B8$$`0``
MB<>)@0@!``")G<#^__^)F0P!```YV(UV``^#U````(`_/`^$U0```#N]P/[_
M_XF]X/[__W,A@#\\ZQJ)]HGX1XM="#N]P/[__XF["`$``',&@'@!/'7FB?Z)
MO>3^__^+G>#^___K(8GV@^P(#[X+46C7S1@(Z*=P_/^#Q!"%P'0P0XF=X/[_
M_SG[<MTY\W,ED(/L"`^^1O]0:-?-&`CH?G#\_X/$$(7`=`M.B;7D_O__.?-R
MW(N5X/[__XN%Y/[__SG"='2+70B)P8N#&`$``"G1A<!T8U914E/_T(/$$(N+
M#`$``(N["`$``(F-P/[__^M&C67T6UXQP%_)P\>%U/[__P````#'A=#^__\`
M````C97@_O__BT4(Z-[[__^#^$-U((M5"(NR#`$``(NZ"`$``(FUP/[__SN]
MP/[__^G5_O__C97@_O__BT4(Z*O[__^#^"\/A$P%``"#^"$/A/4%``"#^#\/
MA!0$``"#^$D/A6$(``"+10B+D``!``"+C>#^__^+G>3^__^)UBG+*W4(C7P>
M@8'_@`````^'Y`0``#N5O/[__W83Q@(NBWT(BY<``0``0HF7``$``%9345+H
M2VK\_XM5"(N*``$```'9B8H``0``Q@$`BTT(BY$4`0``@\00A=(/A7,#``"-
M=@"-E>#^__^+10CH_OK__X/X28G#=`F#^%,/A:`#``"-E=C^__^+10CHX/K_
M_X/X/8G##X15`0``@_A3=`F#^$D/A7D#``"+?0B+EP`!``"+C>#^__^+G>3^
M__^)T"G+*T4(C708@8'^@`````^')`0``#N5O/[__W83Q@(NBW4(BY8``0``
M0HF6``$``%!345+HBVG\_XM%"(N(``$```'9B8@``0``Q@$`BTT(BY$4`0``
M@\00A=(/A:<```"+50B+F@`!``"+O>#^__^+C>3^__\I^3F=O/[__XG8<@_K
M7$LYG;S^__\/@\,"``"*$X#Z+G7LB<8IWH#Z+G1*A?]T"#GQ#X5\!```BW4(
MBY8<`0``,<F%TG4RQ@,`BT4(B9@``0``A<D/A-3^__^X`0```(UE]%M>7\G#
MC78`BA.)QBG>@/HN=;9.Z[-1*T4(@\"`4/^UO/[___]U"/_2B<&#Q!#KM%"+
MF0`!```IRX/#@%/_M;S^__]1_]*#Q!"%P`^$./___[@!````ZZ6-E=C^__^+
M10CH<OG__X/X270)@_A3#X4D!0``BWT(BY<``0``BXW@_O__BYWD_O__B=`I
MRRM%"(UT&(&!_H`````/A\$"```[E;S^__]V$\8"+HMU"(N6``$``$*)E@`!
M``!04U%2Z"AH_/^+50B+B@`!```!V8F*``$``,8!`(M-"(N1%`$``(/$$(72
M#X4D`0``BUT(BXW8_O__BX7<_O__BY,8`0``*<B%T@^%Z@```(M%"(N8``$`
M`(N]X/[__XN-Y/[__RGY.9V\_O__B=AR$NFO````2SF=O/[__P^#10$``(H3
M@/HN=>R)QBG>@/HN#X2=````A?\/A'O^__\Y\0^$<_[__\>%R/[__Q\````Y
MC<C^__]V!HF-R/[__U#_M<C^__]7C4V(4>AA9_S_C4,!NQ\```"+O<C^__^#
MQ!`Y\\9$/8@`C;UH____=@*)\U%34%?H-F?\_X/$$,:$'6C___\`5XU=B%-H
M4,X8"/]U".A9:_S_@\00N`$```#I'?[__XH3B<8IWH#Z+@^%8____T[I7?__
M_U9045/_TH/$$(7`#X0%____N`$```#I[?W__U>+F0`!```IRX/#@%/_M;S^
M__]1_]*#Q!"%P`^$N_[__[@!````Z<+]__^04XN9``$``"G+@\.`4_^UO/[_
M_U'_TH/$$(7`Z9;]__^-E>#^__^+10CH;O?__\>%U/[__P$```#IS_O__XUV
M`(H3Z3W]__^*$^F[_O__@_LO#X0I`@``B[74_O__A?9T88/[/P^%'P,``(M%
M"(N8``$``#F=O/[__XG8<PZ`.RYT"4LYG;S^__]R\HM5"(N*'`$``#'2A<D/
MA7<"``#&`P"+?0B%THF?``$```^%"OW__XV5X/[__XM%".C<]O__B<.+C=#^
M__^%R71(BT4(B[```0``.;6\_O__B?!S#H`^+G0)3CFUO/[__W+RBU4(BXH<
M`0``,=*%R0^%.`(``,8&`(M]"(72B;<``0``#X6H_/__@_L^#X5L`P``BUT(
MZ5GZ__^+50BX`0```,<"5&\@9,="!&5E<"#'0@A834P`Z7O\__^-E>#^__^+
M10CH2/;__X/X20^%/P(``(MU"(N]X/[__XN>``$``(N-Y/[__RGY.9V\_O__
MB;W,_O__B=AR$NEH`0``2SF=O/[__P^#OP$``(H3@/HN=>R)QBG>@/HN#X2(
M`0``BY7,_O__A=)T"#GQ#X6H`P``BW4(BXX<`0``,=*%R0^%*0$``,8#`(M%
M"(72B9@``0``#X79^___C97@_O__BT4(Z*OU__^)P^D<____C97@_O__BT4(
MZ);U___'A=#^__\!````Z??Y___'A<3^__\?````.8W$_O__=@:)C<3^__]0
M_[7$_O__5XV-:/___U'H;V3\_XU#`;L?````B[W$_O__@\00.?/&A#UH____
M`(U]B'8"B?-64U!7Z$1D_/^#Q!#&1!V(`%>-G6C____I"?W__XM5"(N:``$`
M`#F=O/[__XG8<PZ`.RYT"4LYG;S^__]R\HM]"(N/'`$``#'2A<ET&%(K10B#
MP(!0_[6\_O___W4(_]&)PH/$$,8#`(M-"(72B9D``0``#X7@^O__C97@_O__
MBT4(Z++T__^)P^EF_?__BA/II?[__U<K10B#P(!0_[6\_O___W4(_]&)PH/$
M$.FZ_O__5BM%"(/`@%#_M;S^____=0C_T8G"@\00Z6S]__].Z7+^__]2*T4(
M@\"`4/^UO/[___]U"/_1B<*#Q!#IJ_W__XH3Z4'^__^#Z"&#^#-W!_\DA>C.
M&`BX`K$8"%)0:'3.&`C_=0CH<6?\_[@!````Z3CZ__^-0]^#^#,/A]<```#_
M)(6XSQ@(@^@A@_@S=W#_)(6(T!@(N-S-&`A74&CAS1@(Z[ZX_\T8".OPN-S-
M&`A24&B@SA@(ZZFX_\T8".OPN`;.&`CKZ;@,SA@(Z^*X$,X8".O;N!C.&`CK
MU+@<SA@(Z\VX(,X8".O&N"3.&`CKO[@HSA@(Z[BX+,X8".NQN`*Q&`CKJK@&
MSA@(ZXZX#,X8".N'N!#.&`CK@+@8SA@(Z7;___^X',X8".EL____N"#.&`CI
M8O___[@DSA@(Z5C___^X*,X8".E.____N"S.&`CI1/___[@"L1@(Z3K___^#
MZ"&#^#,/A]@```#_)(58T1@(C4/?@_@S#X>@````_R2%*-(8"+C<S1@(4E!H
MP,X8".G*_O__N/_-&`CK[;@&SA@(Z^:X#,X8".O?N!#.&`CKV+@8SA@(Z]&X
M',X8".O*N"#.&`CKP[C<S1@(5U!H,,X8".F(_O__N/_-&`CK[;@&SA@(Z^:X
M#,X8".O?N!#.&`CKV+@8SA@(Z]&X',X8".O*N"#.&`CKP[@DSA@(Z[RX*,X8
M".NUN"S.&`CKKK@"L1@(ZZ>X),X8".E;____N"C.&`CI4?___[@LSA@(Z4?_
M__^X`K$8".D]____OQ\````YSW8"B<]15_^US/[__XU-R%'H,&'\_XU#`;L?
M````@\00.?/&1#W(`(U]J'8"B?-24U!7Z`YA_/^#Q!#&1!VH`%>-7<CIUOG_
M_[C<S1@(Z;/]__^X_\T8".FI_?__N`;.&`CIG_W__[@,SA@(Z97]__^X$,X8
M".F+_?__N!C.&`CI@?W__[@<SA@(Z7?]__^X(,X8".EM_?__N"3.&`CI8_W_
M_[@HSA@(Z5G]__^X+,X8".E/_?__C78`58GE@^P,:"`!``!J`/]U".CG8_S_
MR<.058GER<.-=@!5B>6+50R+10B)D!@!``#)PXUV`%6)Y8M5#(M%"(F0%`$`
M`,G#C78`58GEBU4,BT4(B9`<`0``R<.-=@!5B>6+50R+10B)D!`!``#)PXUV
M`%6)Y8M%",G#58GEBT4(BX@$`0``BX`(`0``.<B)RG8*@#H*=`M".=!W]BG(
MR<.)]HG10CG0Z_&058GEBT4(BY`$`0``BX`(`0``,<DYT'8*@#H*=`M".=!W
M]HG(R<.)]D%"Z_)5B>575E.#[%2+=0R+50B%]HG1#X0*`@``BT4,BS@Y^G02
MB@(\(`^$C`$``#P)#X2$`0``.?D/A)0!``"*`3PMQT7,``````^$`0(``(M%
M$,<``````(H!/"L/A$T"```\,,=%R/"__@K'1<1<+^\KQT7`#P````^$"0(`
M`(/H,#P)#X=(`0``00^V\(U9"#G[=AR)^^L8D(H!@^@P/`D/AU4!``"-%+8/
MML"--%!!.=EUY3GY#X0_`0``C5D).?O'1=0`````B4W<B5W8B5VD=@:)?:2-
M=@"*`8/H,#P)#X=V`@``BUW4C12;#[;`08T44#M-I(E5U'7>.?D/A%0"``"*
M`8/H,#P)#X>.`@``C5$!#[;`.?J)1=")5;P/A*,!``"*40&#ZC"`^@D/AY0!
M``"+7="-!)L/MMJ-!$.-60*+50PY^XE%N(D:=`^*40*#ZC"`^@D/AF0"```[
M=<@/AUL"```/A#T"``")=:B[`.AV2(M%J/?C:WVH%XG#QT6L`````(G0`?AI
M5:P`Z'9(C3P0N60```"+1=3WX8E%X`%=X(E5Y(M%N!%]Y#'V`47@$77DZS:)
M]D$Y^703B@$\('3U/`D/A6G^__]!.?EU[8M%$(M-#,<`(0```(D1QT7@````
M`,=%Y`````"+1>"+5>2#Q%1;7E_)PXM%S(M]#(7`B0\/A+,```#WWHGPF8E%
MX(E5Y(M%X(M5Y(/$5%M>7\G#C5WLB5T,B@(\('1Q/`ET;8H"A,"-N?__``!T
MD3PMQT7,``````^%__W__T$Y^<=%S`$````/A'+___^+=1#'!O_____'1<CX
M7W\%QT7$KI?W%<=%P`@```"*`3PP#X7W_?__,?9!.?D/A&G___^`.3!T\HU9
M">GQ_?__B?9!B@$\('3Y/`ET]>N(03GY#X0:____B@'IH_W__XGP,=+I2?__
M_XEUJ+L`Y`M4BT6H]^.+?:B)P]'GB=#'1:P``````?AI5:P`Y`M4C3P0N0H`
M``"+1=3WX8E%L`%=L(E5M(MUT!%]M#'_`76P$7VTBW7,BT6\BU4,BTVPBUVT
MA?:)`HE-X(E=Y`^$O?[__X%]M````(!R#`^'@@```(-]L`!W?(M%L/?8BU6T
M@](`]]KIN?[__SM-V'1"B<LK7=R)\/<DG:`H)0B)PXM]#(M%U(G6B0\QTHM-
MS`'#$=:%R70']]N#U@#WWHE=X(EUY(M%X(M5Y(/$5%M>7\G#OP#*FCN)\/?G
MZ\&+3<0Y3=0/@K?]__^+?<`Y?;@/AJO]__^+3<R+51`QP(7)QP(B````N@``
M`(`/A33^__^X_____[K_____Z27^__^)]E6)Y8M-"(L1B@(\^G<*C4(!B0$/
MM@+)PSS[="\\_'00//UT&(U""8D!BT(!R<.)]HU"`XD!#[="`<G#D(U"!(D!
MBT(!)?___P#)PXU"`8D!R;C_____PY!5B>53BU4(BPJ*`3SZ=PV-00&)`@^V
M`3'26\G#//MT.SS\=!0\_70@C4$)B0);BT$!BU$%R<.)]HU!`XD"#[=!`3'2
MZ]2-=@"-602)&HM1`8G0)?___P`QTNN^C5D!B1JX_____S'2Z["-=@!5B>56
M4XM=$(/[`(MU"(M-#'<9@?GZ````=R&(#EN-1@%>R<.#^P!V+HUV`,8&_HE.
M`8E>!5N-1@E>R<.#^P!WZX'Y__\``'?;Q@;\9HE.`5N-1@->R<.!^?___P!W
MS8G+B<J-1@'!ZPC!ZA#&!OV(3@&(6`&(4`);C48$7LG#D%6)Y5=64X'LK```
M`(M]"(M%#`'XBU48.<?'19@`````B46$QD6#`,9%@@#'`@`````/A%D"```/
MM@>+%<#Z&`CV1`(!"'05D$<[?80/A#X"```/M@?V1`(!"'7L.WV$#X0K`@``
M#[8/BS7`^A@(]D0.`00/A!<"``#&18\`B?J00CM5A'0*#[8:]D0>`01U\,=%
ME`````"*':`I)0B)T2GY#[;#.U6$B)UG____QT2%J``````/A'<%``"`O6?_
M__\"=B4[581S%XUV``^V"O9$#@$(#X7/`0``0CM5A'+L.U6$#X0$!@``BAVA
M*24(.)UG____#[;+=@</MHUG____BA6B*24(#[;".<B(E7/___]V`HG!N`$`
M``")P]/CB@VF*24(T^`)PX/C#XF=8/___XM=E(/[!HB-<O___\=%D``````/
MAX$!```[?80/A'@!``"*%P^VPO9$!@$$#X1H`0``B;U\____1XU*T#M]A`^V
MT70ZB@\/ML'V1`8!!'0N@'V/`'04Z1,$``"-=@"*#P^VP?9$!@$$=!2-0=!'
MC122#[;(.WV$C111=>*)]HGY*XU\____@?H_0@\`B4R=J`^'9`4```E5D(E4
MG<B*@Z$I)0@\`1G2@^("0CM]A(E5I(E]B`^$.@4```^VC7/___\YV0^$F0,`
M``^V%:4I)0@YV@^$-P,``#M]A'1IBA</ML(/MD0&`:@0#X3+`P``QX54____
M`0```(C9TZ54____BXU@____(8U4____D`^VPO9$!@$(=!*+E53___^%T@^$
M;`0``,9%@@%'.WV$QD6#`702BA</MLH/MD0.`:@0=<RH"'7(#[:%<O___SG8
M#X38`P``B7V(Z;T"``"0BT48QP`!````N/[___^!Q*P```!;7E_)PSM5A`^#
M+O[__P^V`O9$!@$$#X4@_O__0CM5A'+LZ17^__^0B=\K?92+38B)?9SK%(UV
M`,=$G:@`````QT2=R`````!#@_L'=NJ`?8\`#X78`0``#[:%9____XM<A:B%
MVXE=H'2"BWR%R(M5$(DZ#[8UH2DE"(M<M<B)6@2)G7C___\/M@6B*24(BW2%
MR(ER"(FU=/___P^V':,I)0B+=)W(B7(,#[8%I"DE"(M<A<B)6A")G6S___\/
MM@6E*24(BUR%R(F=:/___XE:%`^V%:8I)0B+7)6H@_L%#X>@`@``N`8````I
MV(L$Q0`I)0@/KT25R(E$E<B+51")0AB`/:<I)0C_=""#_@P/AR<#``"[#```
M`(GP,=+W\XM%F(TT`HM=$(ES#(M%$,9`'`"#?:`"#X09`@``@WV<`@^&F@``
M`('_#R<```^'C@```(.]>/___PP/AX$```"#O73___\?=WB#_A=W<X.];/__
M_SMW:H.]:/___SMW8?9%%`%U%(N]>/___X7_=%&+M73___^%]G1',<"+=82#
M?9P##Y?`.76(=""+71")0R"+%<#Z&`@/M@'V1`(!"`^$T@(``$$[381U[#'`
M@WV<`P^7P(M]$(E'(.D<_O__B?:+19"%P'4CBUV$.5V(="2+%<#Z&`B-=@`/
MMCGV1#H!"'0(03M-A'7PZPF+31C'`0$```"+?1`QP/RY"0```/.K@<2L````
M6UZX_____U_)PXM]R(M=$(D[BT7,B4,$BW70B7,(B;5T____BW74B7,,BUW8
MB85X____BT40B5@0BU7<B5`4B95H____BU7`@_H%B9UL____#X<``0``NP8`
M```ITXL$W0`I)0@/KT7@B47@BU40B4(8Z8[^__^`/RX/A(@!``")]D.#^P9W
M%3M]A'00BA</MLKV1`X!!`^%_?O__X!]@P`/A%O]__^`?8(`#X51_?__]D44
M`@^$1_W__XMU&,<&`0```.D&_?__D(`_5`^%7OS__T?KK/]-I(-]I/\/A`/\
M__^`?8\`=2+IY/O__XH/#[;!]D0&`00/A.C[____3:2#?:3_#X3;^___C4'0
M1XT4D@^VR#M]A(T44771Z<3[__^H"`^%+?S__^E__/__BUV0A=L/A-S]__^#
M_T6-A]`'``!V!HV';`<``(M5$(G'B0+IO_W__XM%X.D-____BT25R.EN_?__
M@_D$=!&#^0AT#(/Y#<=%H`(```!V!\=%H`0```"+5:!*B56DQD6/`>F*^O__
M0X`]IRDE"/\/A!K\__^-5P([580/AP[\__^*1P$\370(/&T/A?_[__^*!SQP
M=`@\4`^%MO[__XG7.WV$QT68#`````^$W_O__P^V%_9$%@$(#X31^___1SM]
MA'7LB7V(Z8C^__^+51C'`@$```#IQ_O__T?'1:0%````Z6W^__^+31C'`0$`
M``#IROW___9%%`(/A8[^___'1=@`````QT74`````,=%T`````#'1<P`````
MQT7(`````,=%E`4```#IP_G__T/I._[__XM-&,<!`0```.E?^___BU48QP(!
M````Z2;]__]5B>575E.#[%R+50R+10@!T(M-$(E%P,9!'`"+710Y10C'`P``
M```/A%<"``"+?0@/M@>+#<#Z&`CV1`$!"'0=_T4(BW7`2CEU"`^$-`(``(M=
M"`^V`_9$`0$(=>.+1<`Y10@/A!L"``"+10B`."T/A!P"``"+?<`Y?0@/A`,"
M``"#^@L/AQ@"``"+7<`Y70C'1<0`````=$&+10B*"`^VP8L=P/H8"/9$`P$$
M="R)]HM%Q`^^\8T4@/]%"(M-P(U\5M`Y30B)?<1T#XM]"(H/#[;!]D0#`01U
MUHM-"(M=P#G9="@/M@&+%<#Z&`CV1`(!"'08_T4(BW7`.74(=`V+?0@/M@?V
M1`(!"'7HBU7`*U4(@_H!QD6^`,9%OP`/AJH!```Y30@/A*$!``"+10@/M@B+
M'<#Z&`CV1`L!!`^$B@$``(MUQ(EUR,9%OP&^`0```(M%P#'2.44(=#2+?0B*
M#P^VP?9$`P$$="60#[[Y_T4(BTW`C122.4T(C517T'0/BT4(B@@/ML'V1`,!
M!'7<B52UR$:#_@1T4XM-P"M-"$E^':"H*24(BU4(.`)U$0^V>@'V1#L!!'0&
M0HE5".N2@_X$="B`?;X`=0J`?;\`#X3]`@``N00````I\<'A`HU<M<C\P>D"
M,<")W_.KBTW0BW7`*W4(3GX,BT4(@#@N#X0'`@``QT78`````(`]IRDE"/]T
M5(M5P#E5"'0KBWT(#[8'BQ7`^A@(]D0"`0AT&/]%"(M%P#E%"'0-BW4(#[8&
M]D0"`0AUZ(M5"(/"`CM5P'<6BUT(BD,!/$T/A$X!```\;0^$1@$``(/Y.W\,
MBU74@_H[#X[3````BTT4QP$!````D+@!````C67T6UY?R<.+31!`2L9!'`&)
M10CIT_W___]U%&H#_W404O]U".@%]O__@\04@_C_#XSU`0``#Y3"C67T6UX/
MML)?R<.+7<`K70A+?A&*#:@I)0B+50@X"@^$\0```+BMB]MH]VW$OQ^%ZU&)
MT8M=Q(M%Q/?OP?L?P?D,*=F)5:2)3<R+3:3!^04IV8E%H(G(]^^)TXG(F<'[
M!2G3C12;C3R2BT7$P><"NV0```"9*?GW^\=%R`````")3=")5=3IH_[__XMU
M$(E6%(M5P(M]R(M=S(M%V#E5",<&`````,=&!`````")?@B)7@R)3A")1AC'
M1B`"````="2+%<#Z&`B)]HM-"`^V,?9$,@$(#X0E`0``08M%P#G!B4T(=>0Q
MP.G:_O__BWT(B@<\<`^$WP```#Q0#X37````/&%T"#Q!#X69_O__B54(Z9'^
M__\/MGH!BQW`^A@(]D0[`00/A/K^__^+1<1"O@(```#'1<@`````B47,QD6^
M`8E5".E&_?__BE`!#[;ZBS7`^A@(]D0^`00/A.+]__^#10@"BT7`C5K0.44(
MQT6T!0````^VTW1,BT4(BA@/MOOV1#X!!'0]QT6T!````(U#T/]%"(M=P(T4
MD@^V^#E="(T45W08BT4(BA@/MOOV1#X!!'0)_TVT@WVT_W71BW6TA?9T"XM=
MM`^O%-T`*24(B578Z7']__^+1<R)50B[#````)GW^X/"#(E5S.FU_?__BW44
MQP8`````Z<C[__^+?10QP,<'`0```.FW_?__C3RU`````(U=R%"-1_Q0C0P[
M48U5V%+HIAW__[D$````*?'!X0+\P>D",<")W_.K@\00Z>/\__^)]E6)Y593
MBUT(A=N+30R+=1!U7H7)#X2V````@<-L!P``@?NQ!P``=P.#PV2)RHT$V\'B
M!8T$PRG*C02``<*#^0*-=#+A=TY+N!^%ZU'WXXG1P>D%C01)C5`#P?H"A=N)
MV'AGP?@"`?!;*=!>R<.-=@"!^\<```!VHHG*C03;P>(%C03#*<J-!(`!PH/Y
M`HUT,N%VLY"-#(T7````N&=F9F;WZ8G0P?D?P?@"*<@IQK@?A>M1]^.)T<'I
M!8T$28U0`\'Z`H7;B=AYF8/``^N4B?8QP(7V#X5`____6U[)PXGV58GE5U93
M@^Q,BWT(BQ^%VXM/!(MW"`^%?`$``(7)#X3D`0``@<-L!P``@?NQ!P``=P.#
MPV2)RHT$V\'B!8T$PRG*C02``<*#^0*-=#+A#X=P`0``2[@?A>M1]^.)T<'I
M!8T$28U0`\'Z`H7;B=@/B(D!``#!^`(!\"G0+:CZ"@"-'("-%)B-'-"+3PS!
MXP(IPXT$S0`````IR,'@!0'(BW<0P>`$P>,'`<.-!':+3Q2--("-!+$!PXLU
M0!0F"(V4,_#Q__^#[`B)=:R-=;B)5;2-7;164^@)4?S_BU<,@\00.U7`QT6P
M``````^$O@$``(M/$(M?%(M'""M&#(/X_P^-E@$``+@!````*U8(C01`C03"
MC13%`````"G"*TX$P>(%`<*-!$G!X@2-!(`K'HT,@@'9BUVL@^P(C909$`X`
M``%-M(E5K(U%M%90Z))0_/__1;"#Q!"#?;`!=QJ+5PP[5<!UBXM/$#M-O'6&
MBU\4.UVX=8&)]H-]L`(/A)8```"+=0R+?:R+3;2)/HUE]%M>B<A?R<.0@?O'
M````#X:`_O__B<J-!-O!X@6-!,,IRHT$@`'"@_D"C70RX0^&D?[__Y"-#(T7
M````N&=F9F;WZ8G0P?D?P?@"*<@IQK@?A>M1]^.)T<'I!8T$28U0`\'Z`H7;
MB=@/B7?^__^#P`/I;_[__XUV`#'`A?8/A&G^___I#?[__Y"+5PR+3@@YR@^$
M7/___XM'""M&#(/X_P^,EP```(/X`7X&N/____^0*<J-!$"-#,*-%,T`````
M*<K!X@4!RHM/$(G+*UX$C01;P>($C1R`C02:BU\4B=\K/@'X/1`.``!T7#WP
M\?__='"+3;2+71#&`P&+=0R+?:R)/HUE]%M>B<A?R<.#^`$/CF;^__^X____
M_^E<_O__BT\0.TV\#X4Y_O__BU\4.UVX#X4P_O__Z;;^__^X`0```.EJ____
MC3Q)C32_P>8"]]XIW@-UM(V.$`X``(E-M.N3C01)C0R`C12+BTVT*=&)3;3K
M@%6)Y8'LA````&H`Z.!-_/^)19186HU%R(U-E%!1Z+Y._/^+5=R!PFP'``")
M59B+1=B+5="#Q`R)5:1`C5634HE%G(M%S(M-U(E%J&A`%"8(C468B4V@4(M-
MR(E-K,<%0!0F"!`.``#HD/S__\G#B?95B>4QP%?\BWT(N0D```#SJXM%#(M5
M"(E"(%_)PXUV`%6)Y8/L$(M%"/]P%/]P$/]P#(!X'`"ZP\T8"'4%NO2;&`A2
M:/C2&`C_=0SHT$W\_\G#B?95B>6#[!2+10C_<`C_<`3_,&@)TQ@(_W4,Z*Y-
M_/_)PU6)Y8/L"(M%"/]P%/]P$/]P#/]P"/]P!/\P:!C3&`C_=0SHA4W\_\G#
MC78`58GE4U&+30B+42"#P@(QP(/Z!(M=#'<S_R25.-,8")"#[`C_<13_<1#_
M<0R`>1P`N,/-&`AU!;CTFQ@(4&CXTA@(4^@X3?S_@\0@BUW\R</&`P`QP(M=
M_,G#B?:#[`S_<0C_<03_,6@)TQ@(Z]2)]O]Q%/]Q$/]Q#/]Q"/]Q!/\Q:!C3
M&`CKNE6)Y5-1@#V`[1@(`(M="(M%#'082%)0:(#M&`A3Z"X0__^#Q!`QP(M=
M_,G#@^P(@^@"4%/H?TS\_X/$$(7`=0;V11`0=2>#[`Q3Z#T0__^#Q!"`>/\O
M=`?&`"_&0`$`4&C_`P``4VB`[1@(Z[#H1DK\_XL`@^P0HV#I&`CH-TK\_X/$
M#/\P:B1J$.A9N?[_N/____^+7?S)PXUV`%6)Y5-3BTT(BA&`^GYT)8#Z+[@!
M````=!:#[`AJ.E'H"$W\_X/$$(7`#Y7`#[;`BUW\R<.`>0$O==^AA/$8"#';
MA<!U!XG8BUW\R<.#[`Q0Z*O___^#Q!"%P'3ILP&)V.OEB?95B>564XM5"(H"
MA,")TW0,/"]U#8!Z`0!U!XGVNDFU&`B#[`Q2Z#Y)_/^#Q!"%P(G&=76*`SQ^
M=$\\+W02@^P(:CI3Z(!,_/^#Q!"%P'1)4&C_`P``4VB`[1@(Z/`.__^#Q!"`
M>/\O=!,M@.T8",:`@.T8""_&@('M&`@`C67X6XGP7LG#C78`@'L!+W6OH83Q
M&`B%P'4YD,8%@.T8"`"-9?A;B?!>R</H"TG\_XL`]D4,$*-@Z1@(=,+H^4C\
M__\P4VHD:A'H';C^_X/$$.NL@^P,4.C#_O__Z6K___^)]E6)Y5.![`P$``"+
M70A3C87X^___4.@:Q?[_@^P(:BZ-'!A3Z,!+_/^#Q""%P'0%BUW\R<.#[`Q3
MZ&\.__^#Q!"+7?S)PXUV`%6)Y593@^P,BT4(#[]8#E#H^TG\_X/$$(7`B<9X
M1O\-=.D8"#L=7.<8"',-H5CG&`B+3-@$A<EU"XUE^%N)\%[)PXGV@^P,QT38
M!`````#_--CH@;#^_X/$$(UE^%N)\%[)PY#H)TC\_XL0]D4,&(D58.D8"'2M
MZ!1(_/__,(/L"%/H#;K^_X/$#%!J)&H$Z"RW_O^#Q!#KBXUV`%6)Y5=64X/L
M'(M=#(7;C578=4'&1=ARC479@^P(Q@``4O]U".@K2?S_@\00A<")Q@^$$`$`
M``^_>`X[/5SG&`AR,O\%=.D8"(UE]%N)\%Y?R<.)]H-]#`%T4H-]#`)T8/9%
M#`AU4L9%V'>-1=G&`"M`ZZ>0@^P(BQU8YQ@(_W40_W4(Z'"P_O^#Q!"%P(D$
M^W0T#[]6#J%8YQ@(_P5TZ1@(QT30!`,```#KG9#&1=AWZ6+___^-=@#&1=AA
MZZR)]L9%V'+KI(/L#`^_7@Y6Z*%(_/^#Q!"%P'A[_PUTZ1@(.QU<YQ@(<R.A
M6.<8"(MTV`2%]G06@^P,QT38!`````#_--CH-*_^_X/$$,<%8.D8"`P```#V
M11`9=0HQP(UE]%M>7\G#_S5@Z1@(_W4(:B0QVX-]#``/E<-3Z.6U_O^#Q!`Q
MP.O7Z*E&_/^+.(D]8.D8".O`Z)I&_/^+"/9%$!B)#6#I&`@/A'3____H@T;\
M__\P@^P(4^A\N/[_@\0,4&HD:@3HF[7^_X/$$.E/____C78`58GE5U93@^P<
MBT40A<"+?0B-5=AU5L9%V'*-1=F#[`C&``!25^CV1OS_@\00A<")Q@^$@P``
M`/\%=.D8"#L]7.<8"',<BQU8YQ@(BU3[!(72=$7_#7#I&`C'1/L$!````(UE
M]%N)\%Y?R<.0@_@!=!>#^`)T/J@(=1;&1=AWC479Q@`K0.N6D,9%V'?KC(GV
MQD788>OHB?:#[`C_=13_=0SHOJ[^_XD$^X/$$(L=6.<8".NEQD78<NO$Z*%%
M_/^+`/9%%!BC8.D8"'25@^P0Z(Q%_/^#Q`S_,&HD:@_HKK3^_X/$$.EW____
MB?95B>575E.#[$R+10R+30B+&-GNBU40.=G9P,=%Y`````#'1=P`````QT78
M`````,=%U`````#'1=``````QD7+`,<"`````'-3BA$/ML*+/<#Z&`CV1`<!
M"'02D$$YV70[BA$/ML+V1`<!"'7O,<"`^BT/E,"%P(G.B47D=0:`^BMU"Y!!
M.=ET$XUV`(H1@/HP=3U!.=ET!#'VZ_#=V(M=#(!]RP")"P^$]P```-W8BTT0
MW05@TQ@(QP%4````BW7DA?9T`MG@C67T6UY?R<.0@/HOB4W,?CR`^CE_-]D%
M3-,8".L%C78`V<H/OL*#Z#!0W,K9RD':!"2#Q`0YV0^$,P(``(H1,?:`^B]^
M!8#Z.7[6W=J)R"M%S(#Z+HE%X`^$.0$``(#Z90^$EP```(#Z10^$C@```(M=
MU"M=T(7;#X17____#XS>`0``BWW@C30[@?XT`0``#X9N`0``V<G=X=_@@.1%
M@/Q`#X2V`0``@?XU`0``=Q?=!5#3&`C9R=WAW^#=V?;$`0^%EP$``(MUV(7V
M#X4#____W=G&1<L!Z?K^__^#[!#=%"3=7:CH$D/\_X/$$(7`W46H#X3^_O__
MZ>C^__^+==P#=>"%]@^$9/___XU3_SG*#X99____B<Y!BA$QP(#Z+0^4P(7`
MB478#X5*`0``@/HK#X1!`0``.=D/A#\!``"*$8A5PP^VPO9$!P$$#X0L`0``
M@7W4#B<``'\1BW74C12V#[Y%PXUT4-")==1!.=ES#XH1B%7##[;"]D0'`01U
MTHM=V(7;#X3D_O__BUW4`UW0Z=_^__^-4_\YR@^&SO[__T&)3<2*$0^VPO9$
M!P$$=#79!4S3&`CK`MG*#[["@^@P4-S*V<I!V@0D_T70@\0$.=D/A*T```"*
M$0^VPO9$!P$$==7=VHG(*T7$B47<#X5I_O__A?8/A&'^__^)\>E:_O__W=B#
M^V/9Z'X4W058TQ@(B?:#ZV2#^V/<R7_VW=BX9V9F9O?KB=C!^@+!^!\IPHT\
MDM'G*?O=!-W`*24(W`S5("HE"(M5V(72WLET!][YZ8#]___>R>EY_?__W=GK
MI/?;QT78`0```.D4_O__W=HQTNG4_?__0>FY_O__B?'I^_[__]W:,=+I6/__
M_XGV58GE@^P,BU4(C8+__P``C4W\48E%^(U%^%!2Z(C\___)PXGV58GE5U93
M@^P,BUT,,<")W_RY______*NBW4(]]&+1BB-?!G_B47P@#L`=!A0BT985U-6
M_U`$@\00A<!T#P'#@#L`=>B-9?1;7E_)PP^V`XM5\(H,$(@+0^O-B?95B>57
M5E.#[`R+70PQP(G?_+G_____\JZ+=0CWT8M&)(U\&?^)1?"`.P!T&%*+1EA7
M4U;_4`2#Q!"%P'0/`<.`.P!UZ(UE]%M>7\G##[8#BU7PB@P0B`M#Z\V)]E6)
MY5=64X/L#(M]"(M=#(G>BT<H`W40B47P.?-S%U&+1UA64U?_4`2#Q!"%P'01
M`<,Y\W+IC67T6UY?R<.-=@`/M@.+5?"*#!"("T/KS(GV58GE5U93@^P,BWT(
MBUT,B=Z+1R0#=1")1?`Y\W,74(M'6%935_]0!(/$$(7`=!$!PSGS<NF-9?1;
M7E_)PXUV``^V`XM5\(H,$(@+0^O,B?95B>575E.#[`R+70PQP(G?_+G_____
M\JZ+50CWT8M"*(MU$(U\&?^)1?`Y^W,Z4(M5"(M"6%=34O]0!(/$$(7`=#&-
M2/_K`I!)@_G_=-R*%HH#1D,XT'3PN`$```"-9?1;7E_)PXUV``^^!HUE]%M>
M7\G#@^P(BTT(#[X6BT%84E'_4`B#Q!!(?\X/M@:+3?`/MA.*!`A&0S@$"G2-
MN`$```#KN56)Y5=64X/L'(M%&#E%%+O_____#X32````B?:+=12*%@^^PCM%
M)`^$GP```#M%(`^$E@```#M%'`^$P0```%"+70B+<UC_=1C_=113_U8$@\00
MA<")PW0[BTT,`<&+51`YT8E-\'=5_#G`BW4,BWT4B<'SIG5&BT7PB44,`5T4
MBWT8.7T4#X0'`0``NP$```#KB9"+71`Y70QT(8M-#`^V,8M%%$&+70@/MCB+
M4RR)30S_112*!#(X!#ITPXUE]%M>N`$```!?R<.)]@^^RCM-('1A#[[Z.WTD
M#X3(````BTT8.4T4#X4U____BW40.74,#Y7`#[;`C67T6UY?R<.+?11'.WT8
M#X0R____B7T4Z2K___^-=@"+=0S_112+?1A&.7T4B74,<U.+510/O@H[32!U
M2(M%$#E%#'1A4(M5"(MZ6/]U$/]U#%+_5P2#Q!"%P'3#5XM%"(MP6/]U$/]U
M#%#_5@2+30S_112+?1B#Q!"--`@Y?12)=0QRK8MU&#EU%`^$8____XM%%(H0
MZ4'___^+51`Y50SI5/___XUE](G86UY?R<.+?11'.WT8=%D/O@<[121T\CM%
M('53BUT0.5T,#X0B`0``5HM-"(MQ6/]U$/]U#%'_5@2#Q!"%P'4)BW4,1HEU
M#.O`4XM="(M#6/]U$/]U#%/_4`2+50R--!"#Q!")=0SKH3'`Z>?^__\[?1AT
M](MU$#EU#+C_____#X31_O__BA\/MLL[31P/A%P!``")?>Q1BW4(BT98_W48
M5U;_4`2#Q`R+50B)1>B+>EC_=1C_=>Q2_U<$@\00A<`/A0H!``"+5>Q"B57D
MBWT(#[;SBT<LBAPPB%WCBTT0.4T,<V:+5>B%T@^$BP```(M=#`-=Z#M=$'=<
MBT7H_#G`BW4,BWWLB<'SIG5*B5T,_W4D_W4@_W4<_W48_W7D_W40_W4,_W4(
MZ#+]__^#Q""%P`^.'_[__XM=$#E=#'0+BU7D#[XZ.WTD=9*X_____^D"_O__
MB?90BU4(BWI8_W40_W4,4O]7!(/$$(7`=4"+=0Q&B74,Z6+___]0BU4(BUI8
M_W40_W4,4O]3!(/$$(7`=<2+70R+10@/MCN+<"R*3>,X##YUL/]%#.EA____
M4(M%"(MP6/]U$/]U#%#_5@2+30R--`B#Q!")=0SI#/___U*+30B+>5C_=1C_
M=>Q1_U<$`T7L@\00B47DZ=[^__^-1P$[11@/A)C^__^)QXH8Z8_^__^)]E6)
MY5=64X/L#(M=#(MU$#'_.?-S((UV`(M5"%"+0EA64U+_4`2#Q!"%P'04`=B)
MPT<Y\W+CC67T6UZ)^%_)PY"-0P&)PT?KZ56)Y5=64X/L#(MU%(M=#(7VBWT0
MB5WP=!\Y^W,S4(M5"(M"6%=34O]0!(/$$(7`=!<!V(G#3G7AB=@K1?"-9?1;
M7E_)PXUV`(U#`8G#3NOFA?9TY"M]\(UE]%M>C4<"7\G#B?95B>575E.#[`R+
M=12+70R%]HM]"(E=['0>C78`BT=8_W404XU5\%)7_U`@@\00A<!^!0'#3G7E
M*UWLC67TB=A;7E_)PU6)Y5=64X/L#(M%$#E%&(M]"(M=#,=%[`````!W5HM-
M&(7)=%N-#`,K31B-<0$Y\XE=\',_C78`@^P(BT=<:@#_=1C_=13_=1A35_]0
M!(/$((7`=%90BT=85E-7_U`$@\00A<!U`K`!`</_1>PY\W+'C78`,<"-9?1;
M7E_)PXGVBU4@A=)T%XM%',<``````,=`!`````#'0`@`````C67T6UZX`0``
M`%_)PXMU((7V="V)V(M5'"M%\(M=[(-](`''`@````")0@2)6@AV$(E"#`-%
M&(E"$,="%`````"X`@```.N0B?95B>575E-6BD4<B$7SBUT8BT40.<-V`HG#
MB=G\.=N+=0R+?13SI@^7P0^2PBC1#[[!A<!U#H!]\P")V'4#BT40*T486UM>
M7\G#C78`58GE5U93BWT8.WT0BTT,BUT4=@.+?1"--`^)]CGQ<QR*$XH!0T$X
MT'3R#[9)_P^V<_\I\8G(6UY?R<.0BT48.440="R^`0```',*B440B=F^____
M_XM=$(T$&2GX.<%S#XUV`(H1@/H@=0Y!.<%R]%M>,<F)R%_)PX#Z'XGP=P+W
MV%M>B<&)R%_)PY!5B>575E.#[`R+?0R+510YUXM=$(MU&'02.=Z)\'<=45!2
M5^A\-_S_@\00.?-W$8UE](G86UY?R<.-=@")V.O?B=HI\E!2C00W:B!0Z,,Z
M_/^#Q!"-9?2)V%M>7\G#B?95B>6+50R+11")10R)50C)Z?\Z_/^-=@!5B>57
M5E.+70R)WP-]$#G[BW48<S&+%I"+112+"(G(@^`_`=`/MA,/K\*)RL'B"`'0
M,<&+512)"HL&0X/``SG[B<*)!G+26UY?R<.058GE5U93@^Q,BE44BW4DBD48
MBDT<B%77BU4@`?*(1=:(3=6+12B+30@#12")5<R+45B)5;2+30B)1<@QTHM%
M(/=Q4(M]#(M=$%"-!!]05U&)==")1;R+5;3_4A"#Q!`YV',HC1P'B5V\ZR"0
M.D76#X2M````.D75#X2D````BUTHB`-#B5TH1X@&1CM]O'0<.W7,=!>*!SI%
MUW70C5<!.U6\=,B)UXH"Z]2)]HGP*T70BU4PBWTLB0*)!^L'C78`Q@8@1CMU
MS'7WBTT(C57BBW%8C4784E"+30@/MWE65U&+72C_5B0/OOB#Q!#K"XGVQ@,@
M0SM=R',?C30?.W7(<^]05XU%V%!3B?/HT37\_X/$$#M=R'+BD(UE]%M>,<!?
MR<.+50B+6EB+30B+12`QTO=Q4%!6_W7048GW_U,0*WW0@\00.<=V!8MUT`'&
MB?`K1="+32R)`8M=((M],(D?D(M5"&:+6E2('D8[=<QU\8M]"(U5XHMW6(U%
MV%)0#[=/5E%7BUTH_U8D#[[X@\00ZQ"-=@#&`R!#.UW(#X-W____C30?.W7(
M<^M05XU-V%%3Z"LU_/^)\X/$$.O<58GE5U93@^P<BT48.444N_____\/A,8`
M``")]HM%%(H0#[[".T4D#X23````.T4@#X2*````.T4<#X2U````4(M5"(M:
M6/]U&/]U%%+_4P2#Q!"%P(G#=#N+30P!P8MU$#GQB4WP=TK\.<"+=0R+?12)
MP?.F=3N+1?")10P!712+31@Y310/A/L```"[`0```.N)D(M=$#E=#'06BW4,
MBA9&BWT4B74,B@='.-")?11TSHUE]%M>N`$```!?R<.0#[[Z.WT@=&$/OLH[
M320/A,@```"+?1@Y?10/A4'___^+11`Y10P/E<$/ML&-9?1;7E_)PXM]%$<[
M?1@/A#[___^)?13I-O___XUV`(MU#$:)=0S_112+=1@Y=11S4XM]%`^^#SM-
M('5(BU40.54,=&%0BTT(BW%8_W40_W4,4?]6!(/$$(7`=,-7BU4(BT)8_W40
M_W4,4O]0!(M]#(TT.(EU#/]%%(MU&(/$$#EU%'*MBT48.444#X1C____BW44
MBA;I0?___XM=$#E=#.E4____C67TB=A;7E_)PXM]%$<[?1AT60^^!SM%)'3R
M.T4@=5.+71`Y70P/A!8!``!6BU4(BT)8_W40_W4,4O]0!(/$$(7`=0F+=0Q&
MB74,Z\!3BUT(BW-8_W40_W4,4_]6!(M-#(TT"(/$$(EU#.NA,<#IY_[__SM]
M&'3TBU40.54,N/____\/A-'^__^*#P^VP3M%'(A-[P^$1P$``(E]Z%&+50B+
M0EC_=1A74O]0!(/$#(MU"(E%Y(M^6/]U&/]UZ%;_5P2#Q!"%P`^%]0```(M]
MZ$>)?>"+=1`Y=0QS9HM%Y(7`#X2+````BUT,`UWD.UT0=UR+5>3\.=*+=0R+
M?>B)T?.F=4J)70S_=23_=2#_=1S_=1C_=>#_=1#_=0S_=0CH2OW__X/$((7`
M#XXK_O__BTT0.4T,=`N+5>`/OAH[721UDKC_____Z0[^__^)]E"+50B+6EC_
M=1#_=0Q2_U,$@\00A<!U.HMU#$:)=0SI8O___U"+10B+6%C_=1#_=0Q0_U,$
M@\00A<!UQ(M-#`^^,0^V?>\Y_G6V_T4,Z6?___]0BW4(BT98_W40_W4,5O]0
M!(M]#(TT.(/$$(EU#.D2____4HM-"(M96/]U&/]UZ%'_4P0#1>B#Q!")1>#I
M\_[__XU'`3M%&`^$K?[__XH8B<>(7>_IH?[__Y!5B>575E.#[`R+70R+=1`Q
M_SGS<SV+30B+05A64XU5\%+_=0C_4""#Q!"%P'X^BTWP`<,/ML6+%,7$*B4(
MA=)T&P^VP0^^!`*-!`>->`$Y\W+#C67T6UZ)^%_)PP,\Q<`J)0B)^(UX`>OD
MB?9#ZZ*058GE5U:#[!2+512+=0B+?0R+11"%THEU\(E%Y(E5](G^=1$Y^'9-
MB?J+1?#W=>2)Q^L)D#E]]'87,?^0QT7L`````(M5[(/$%%Z)^%_)PY`/O47T
MB<>#]Q]U33MU]'<*BU7D,?\Y5?!RTK\!````Z\N-=@"+1>2%P'4.N`$````Q
MR3'2]_&)1>2)\#'2]W7DB47LBT7P]W7DBU7L@\04B<=>B?A?R<.0N"`````I
M^(E%Z(GYBU7TT^*+1>2*3>C3Z`G"B?G39>2)5?2*3>B)\M/JB?G3YHM%\(I-
MZ-/H"<:)^8GP]W7TB=:)Q]-E\(M%Y/?G.?)W#P^%/____SM%\`^&-O___T_I
M,/___U6)Y5=6@^PPBU44BT40B=>-3?")QHM5#(M%"(7_QT7@`````,=%Y```
M``")3>R)1=R)5<QU/CG6#X:B````]_:+3>R%R8E5W'0;BT7<B47@QT7D````
M`(M%[(M5X(M-Y(D0B4@$BT7PBU7T@\0P7E_)PXGV.WW,=A^+50B+3<R)5>")
M3>2+1>"+5>2)1?")5?2#Q#!>7\G##[W'@_`?B474=6$Y?<QW!3EUW'(0BU7,
MBT7<*?`9^HE%W(E5S(M5[(72=*&+1=R+5<R)1>")5>2+3>R+1>"+5>2)`8E1
M!.N%A?9U"[@!````,=+W]HG&BT7,B?KW]HM%W(E5S/?VZ3W___^0N"`````K
M1=2)1=B)^HI-U-/BB?"*3=C3Z(I-U-/FB=>*3=B+5<P)Q]/JBT7,BDW4T^")
M1<R*3=B+1=S3Z`M%S(E%S(I-U/?WB57,TV7<]^8[5<R)1<AW"G42BT7<.47(
M=@J+3<@I\1GZB4W(BT7LA<`/A.K^__^+3<R+1=PK1<@9T8E-S(G*BDW8T^**
M3=2)1=S3Z`G"BT7,T^B)5>")1>3IK?[__XGV58GE4U*[_$$E"*'\024(ZPJ-
M=@"#ZP3_T(L#@_C_=?186\G#Z&\T_/_#````+V%D;6EN+V)I;@`E<R5S+V1O
M;6%I;E]B=0`E<R]V87(O8F%C:W5P7W1A<VMS7VUN9RYL;V-K`&UA>%]B=5]P
M<F]C7VYU;6)E<@!L;V-A;`!D;VUA:6X`9G1P`"5S.B!#86XG="!L;V-K(&9I
M;&4@)7,*`&1O;6%I;E]B=2!U=&EL:71Y(&ES(&YO="!E>&ES=#H@)7,*`%=A
M<FYI;F<Z('5N86)L92!T;R!F971C:"!F<F]M(&1A=&%B87-E(&UA>&EM=6T@
M;G5M8F5R(&]F(&)A8VMU<"!P<F]C97-S97,N(%-E="!T;R`E9"X*``!54$1!
M5$4@0F%C:W5P5&%S:W,@4T54('!R;V-E<W-E9#TG9F%L<V4G`````%1H92!B
M86-K=7`@<')O8V5S<R!W:71H('!I9"`E9"!E>&ET960@=VET:"!E<G)O<B!S
M=&%T=7,N"@```%1H92!C:&EL9"!P<F]C97-S('=I=&@@<&ED("5D('=A<R!T
M97)M:6YA=&5D(&)Y(&]T:&5R('!R;V-E<W,N"@!54$1!5$4@0F%C:W5P5&%S
M:W,@4T54('!R;V-E<W-E9#TG=')U92<@5TA%4D4@:60])R5D)P```%-%3$5#
M5"!I9"P@<F5P;W-I=&]R>2P@;V)J7W1Y<&4L(&]B:E]I9"!&4D]-($)A8VMU
M<%1A<VMS(%=(15)%(&%C=&EV93TG=')U92<@04Y$('!R;V-E<W-E9#TG9F%L
M<V4G($%.1"`H3D]7*"D^/41!5$5?041$*&QA<W1?8F%C:W5P+"!)3E1%4E9!
M3"!B86-K=7!?<&5R:6]D($A/55(I*2!'4D]54"!"62!O8FI?:60L(&]B:E]T
M>7!E($]21$52($)9("A.3U<H*2U$051%7T%$1"AL87-T7V)A8VMU<"P@24Y4
M15)604P@8F%C:W5P7W!E<FEO9"!(3U52*2D@1$530R!,24U)5"`E9```56YA
M8FQE('1O(&9E=&-H(&)A8VMU<"!T87-K<R!F<F]M(&1A=&%B87-E.B`E<PH`
M36%X:6UU;2!N=6UB97(@*"5D*2!O9B!B86-K=7`@<')O8V5S<V5S('=I;&P@
M;W9E<F9L;W<@<&ED<R!A<G)A>2X@4V5T('1O("5D+@H```!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!T:&4@;7ES<6P@9&%T86)A<V4*`````$-A;B=T('!E<F9O
M<FT@9&]M86EN(&)A8VMU<"!O<&5R871I;VYS('=H:6QE('-E<G9E<BUW:61E
M(&1U;7`O<F5S=&]R92!R=6YN:6YG`"`M+61O;6%I;BUN86UE/0!B=5]D=6UP
M9FEL95]N86UE7W!R969I>`!B=5]M87A?9'5M<%]F:6QE<P!B=5]E;6%I;%]T
M;P!B=5]E;6%I;%]F<F]M`&)U7W-E;F1?96UA:6P`=')U90`E<R\E<R]D97-C
M<FEP=&EO;BYC<F]N`'<K`"`R/B8Q(#XO9&5V+VYU;&P`1E107TQ/1TE.`$94
M4%]005-35T]21`!B=5]S<&QI=%]F:6QE`&)U7W-P;&ET7W-I>F4`8G5?9G1P
M7W-E<G9E<@!B=5]F='!?;&]G:6X`8G5?9G1P7W!A<W-W;W)D`&)U7V9T<%]B
M87-E9&ER`"`M+69T<"UP871H/0`@+2UD=6UP+69I;&4M<')E9FEX/0`@+2UM
M87@M9'5M<"UF:6QE<ST`("TM9G1P+7-E<G9E<CT`("TM<W!L:70M<VEZ93T`
M("TM96UA:6PM9G)O;3T`("TM96UA:6PM=&\]`"5S)7,O9&]M86EN7V)U("TM
M9G1P+6)A8VMU<"`M+7)O=&%T92UD=6UP+69I;&5S`%-%3$5#5"!N86UE+"!P
M87)A;7-?:60@1E)/32!D;VUA:6YS(%=(15)%(&ED/25D`%-%3$5#5"!P87)A
M;65T97(L('9A;'5E($923TT@4&%R86UE=&5R<R!72$5212!P87)A;65T97(@
M;&EK92`G8G5?)24G($%.1"!I9#TE9```1'5M<"!C<F5A=&5D(&)Y(&-R;VX@
M8F%C:W5P(&UA;F%G97(*`````"`M+61E<V,M9FEL93UD97-C<FEP=&EO;BYC
M<F]N("TM=F5R8F]S90!314Q%0U0@8F%C:W5P7W!E<FEO9"P@54Y)6%]424U%
M4U1!35`H;&%S=%]B86-K=7`I+"!53DE87U1)34535$%-4"A.3U<H*2DL(%5.
M25A?5$E-15-404U0*$1!5$5?041$*&QA<W1?8F%C:W5P+"!)3E1%4E9!3"!&
M3$]/4B@H54Y)6%]424U%4U1!35`H3D]7*"DI("T@54Y)6%]424U%4U1!35`H
M;&%S=%]B86-K=7`I*2\H8F%C:W5P7W!E<FEO9"HV,"HV,"DI*F)A8VMU<%]P
M97)I;V0J-C`J-C`@4T5#3TY$*2D@9G)O;2!"86-K=7!487-K<R!72$5212!I
M9#TG)60G``!54$1!5$4@0F%C:W5P5&%S:W,@4T54(&QA<W1?8F%C:W5P/492
M3TU?54Y)6%1)344H)60I+"!P<F]C97-S960])V9A;'-E)R!72$5212!I9#TG
M)60G````17)R;W(@;V-C=7)E9"!D=7)I;F<@9&]M86EN7V)U(&5X96-U=&EO
M;@H```!B86-K=7!?9&]M86EN*"D@97)R;W(Z('=R;VYG(&)A8VMU<"!R97!O
M<VET;W)Y('1Y<&4@<W!E8VEF:65D("<E<R<*`"5S)7,O9&]M86EN7V)U("TM
M8F%C:W5P("TM<F]T871E+61U;7`M9FEL97,`56YA8FQE('1O(&9E=&-H(&EN
M9F\@9F]R(&1O;6%I;B!B86-K:6YG('5P('!R;V-E9'5R93H@)7,*````56YA
M8FQE('1O(&9E=&-H('!A<F%M<U]I9"!F;W(@9&]M86EN(&)A8VMI;F<@=7`@
M<')O8V5D=7)E.B`E<PH``%5N86)L92!T;R!C<F5A=&4@9&5S8W)I<'1I;VX@
M9FEL93H@)7,*``!5;F%B;&4@=&\@9F5T8V@@<&%R86US(&9O<B!D;VUA:6X@
M=VET:"!I9#TE9#H@;F\@<W5C:"!R;W<*`&)A8VMU<%]R97-T;W)E+FQO8VL`
M)7,O)7,O)7,`+2UD;VUA:6XM;F%M90`M+71U<FXM;VX`56YA8FQE('1O('1U
M<FX@;VX@9&]M86EN("(E<R(N``!5;F%B;&4@=&\@;&]C:R!F:6QE(&9O<B!D
M;VUA:6X@(B5S(CH@)7,N`````%5N86)L92!C<F5A=&4@;&]C:R!F:6QE(&9O
M<B!D;VUA:6X@(B5S(CH@=6YA8FQE(&%L;&]C871E(&UE;6]R>2!B;&]C:RX`
M`%5N86)L92!T;R!U<&1A=&4@<W1A='5S(&9O<B!D;VUA:6X@(B5S(CH@)7,N
M`````%5N86)L92!T;R!U;FQO8VL@)R5S)R!F:6QE.B`E<PH`06X@97)R;W(@
M;V-C=7)E9"!D=7)I;F<@8VQO<VEN9R`G)7,G(&9I;&4Z("5S"@!5;F%B;&4@
M=&\@;W!E;B!F:6QE("(E<R(Z("5S+@````!%<G)O<B!O8V-U<F5D(&1U<FEN
M9R!E>&5C=B@I.@HE<P````!V86QU97,@,"PQ+#(@;F]T(&%L;&]W960@9F]R
M('9A<FEA8FQE<R!F9%]I;B`F(&9D7V]U=`H``"P@<&]S<VEB;&4@<F5A<V]N
M("T@3E5,3"!P87)A;65T97(@:7,@86)S96YT(&EN('5T:6Q?97AE8RAP871H
M+"!A<F<Q+"!A<F<R+"!.54Q,*2!C86QL+@H`````5&AE(&-H:6QD('!R;V-E
M<W,@=VET:"!P:60@)60@<W1O<'!E9"!B>2!S:6=N86P@)6D*`$5R<F]R(&]C
M8W5R960@9'5R:6YG(&9O<FLH*3H*)7,`17)R;W(@;V-C=7)E9"!D=7)I;F<@
M=V%I=&EN9R!T:&4@8VAI;&0@<')O8V5S<R!W:71H('!I9#H@)60Z("5S"@``
M``!4:&4@8VAI;&0@<')O8V5S<R!W:71H('!I9"`E9"!K:6QL960@8GD@<VEG
M;F%L("5I"@``9F]R:U]E>&5C*CH@<F5A9"AP:7!E*2!F86EL960Z("5S"@``
M=71I;&ET>2`E<R!F86EL960@*')E<W5L=#TE9"DZ"B5S````<&]P96Y?97AE
M8SH@=V%R;FEN9SH@9F%I;&5D('1O(&%L;&]C871E(&UE;6]R>2!F;W(@8V]M
M;6%N9"!O=71P=70@8G5F9F5R"@```'!O<&5N7V5X96,Z(&9A:6QE9"!T;R!E
M>&5C=71E(&-O;6UA;F0Z(&9O<FL@;W(@<&EP92!C86QL<R!F86EL960L(&]R
M(&-A;FYO;B!A;&QO8V%T92!M96UO<GD*`````'!O<&5N7V5X96,Z(&9A:6QE
M9"!T;R!A;&QO8V%T92!M96UO<GD*``!P;W!E;E]E>&5C.B!C;VUM86YD(&9A
M:6QE9"!C;V1E.B`E9"`L("5S"@```'!O<&5N7V5X96,Z(&9A:6QE9"!T;R!E
M>&5C=71E(&-O;6UA;F0Z("5S"@``9F]R:U]E>&5C=E]P:7!E<SH@9F]R:R@I
M(&9A:6QE9`!F;W)K7V5X96-V.B!E>&5C=B@B)7,B*2!F86EL960Z("5S"@!F
M;W)K7V5X96-V7V=E=&]U=&5R<CH@<&EP92@I(&9A:6QE9`!F;W)K7V5X96-V
M7V=E=&]U=&5R<CH@9F-N=&PH3U].3TY"3$]#2RD@9F%I;&5D```E<R!E>&5C
M=71I;VX@9F%I;&5D("AN;R!O=71P=70I`%5T:6QI='D@;F%M92`G)7,G(&ES
M(&EN=F%L:60N(%5S92!O;FQY('5T:6QI='D@;F%M92!W:71H;W5T('!A=&@N
M`"X*`$-A;FYO="!A;&QO8V%T92!M96UO<GD`0V%N;F]T(&9O<FLH*3H*)7,`
M0V%N;F]T(&%L;&]C871E(&)U9F9E<CH*)7,`0V%N;F]T(')E860@8VAI;&0@
M;W5T<'5T.@HE<P!E<G)O<CH*)7,`0V%N;F]T(&5X96,@)7,Z"B5S`&5R<F]R
M.B!N;VYE`&9O<FM?97AE8W8Z(&1U<"@I(&9A:6QE9#H@)7,*`&UA;&QO8R@I
M(&9A:6QE9#H@)7,`)7,@97AE8W5T:6]N(&9A:6QE9#H*)7,`)7,O861M:6XO
M8FEN+R5S`'=A:70H*2!F86EL960`9&%E;6]N:7IE*"D@9F%I;&5D`&9O<FLH
M*2!F86EL960`<F5D:7)E8W1I;VX@9F%I;&5D`&9O<FLH*2!F86EL960Z("5S
M"@!04D]$54-47U)/3U1?1`!(5%101%]62$]35%-?1`!(5%101%]#3TY&7T0`
M2%144$1?0DE.7T0`44U!24Q?4D]/5%]$`%%-04E,7TU!24Q.04U%4U]$`$94
M4$1?0T].1@!%<G)O<CH@1E101%]#3TY&(&YO="!D969I;F5D"@!&5%!$7T-/
M3D9?24Y#`$944$1?0DE.7T0`3D%-141?4E5.7U)/3U1?1`!714)?4U1!5`!%
M<G)O<CH@5T5"7U-4050@;F]T(&1E9FEN960*`$Q/1U)/5$%410!%<G)O<CH@
M3$]'4D]4051%(&YO="!D969I;F5D"@!-65-13%]605)?1`!-65-13%]"24Y?
M1`!01U-13%]"24Y?1`!01U-13%]$051!7T0`34%)3$U!3E]23T]47T0`34%)
M3$U!3E]605)?1`!04D]$54-47U)#7T0`1%5-4%]$`$5R<F]R.B!$54U07T0@
M;F]T(&1E9FEN960*`$-!5$%,24Y!7TA/344`1%)714)?4D]/5%]$`$125T5"
M7T540U]$`"]A9&UI;B]C;VYF+W-E='1I;F=S`"]A9&UI;B]B:6XO9&YS;6YG
M`"]A9&UI;B]B:6XO;6%I;&UN9P`O861M:6XO8FEN+W5S97)M;F<`+V%D;6EN
M+V)I;B]F<%]W<F%P<&5R`"]A9&UI;B]B:6XO<FU?<&1?=7-R`"]A9&UI;B]B
M:6XO;6%K95]V<G0`+V%D;6EN+V)I;B]W96)S<G9M;F<`+V%D;6EN+V)I;B]R
M;5]F<FT`+V%D;6EN+V)I;B]I;G1E<F9A8V4`+V%D;6EN+V)I;B]D;VUA:6YM
M;F<`+V%D;6EN+V)I;B]C:&MC;VYF:6<`+W9A<B]C97)T:69I8V%T97,`17)R
M;W(Z($A45%!$7U9(3U-44U]$(&YO="!D969I;F5D"@``17)R;W(Z($A45%!$
M7T-/3D9?1"!N;W0@9&5F:6YE9`H`````17)R;W(Z($A45%!$7T))3E]$(&YO
M="!D969I;F5D"@!%<G)O<CH@44U!24Q?4D]/5%]$(&YO="!D969I;F5D"@``
M``!%<G)O<CH@44U!24Q?34%)3$Y!34537T0@;F]T(&1E9FEN960*````17)R
M;W(Z($944$1?0T].1E])3D,@;F]T(&1E9FEN960*````17)R;W(Z("5S(&YO
M="!D969I;F5D(&EN('!R;V1U8W0@8V]N9FEG(&9I;&4`````17)R;W(Z($Y!
M345$7U)53E]23T]47T0@;F]T(&1E9FEN960*`````$5R<F]R.B!-65-13%]6
M05)?1"!N;W0@9&5F:6YE9`H`17)R;W(Z($U94U%,7T))3E]$(&YO="!D969I
M;F5D"@!%<G)O<CH@4$=344Q?0DE.7T0@;F]T(&1E9FEN960*`$5R<F]R.B!0
M1U-13%]$051!7T0@;F]T(&1E9FEN960*`````$5R<F]R.B!-04E,34%.7U)/
M3U1?1"!N;W0@9&5F:6YE9`H``$5R<F]R.B!-04E,34%.7U9!4E]$(&YO="!D
M969I;F5D"@```$5R<F]R.B!04D]$54-47U)#7T0@;F]T(&1E9FEN960*````
M`$5R<F]R.B!#051!3$E.05](3TU%(&YO="!D969I;F5D"@```$5R<F]R.B!$
M4E=%0E]23T]47T0@;F]T(&1E9FEN960*`````$5R<F]R.B!$4E=%0E]%5$-?
M1"!N;W0@9&5F:6YE9`H`17)R;W(Z(%!23T150U1?4D]/5%]$(&YO="!D969I
M;F5D"@`O971C+W!S82]P<V$N8V]N9@````!U<&1A=&4@9&]M86EN<R!S970@
M<W1A='5S/25U('=H97)E(&ED/2(E<R(``%5N86)L92!T;R!U<&1A=&4@<W1A
M='5S(&9O<B!D;VUA:6X@=VET:"!I9#TB)7,B.B`E<RX`````9&5L971E(&9R
M;VT@4&%R86UE=&5R<R!W:&5R92!I9#TG)7,G(&%N9"!P87)A;65T97(])R5S
M)R!A;F0@=F%L=64])R5S)P``9&5L971E(&9R;VT@4&%R86UE=&5R<R!W:&5R
M92!I9#TG)7,G(&%N9"!P87)A;65T97(])R5S)P!5;F%B;&4@=&\@8V]N;F5C
M="!T;R!M>7-Q;"!D871A8F%S90H`````56YA8FQE('1O(&1E;&5T92!P87)A
M;65T97(@)7,@9G)O;2!087)A;65T97)S.B`E<P```&1E;&5T92!F<F]M(&1O
M;5]P87)A;2!W:&5R92!D;VU?:60])R5S)R!A;F0@<&%R86T])R5S)P``56YA
M8FQE('1O(&1E;&5T92!P87)A;65T97(@)7,@9G)O;2!D;VU?<&%R86TZ("5S
M`````&1E;&5T92!F<F]M(&UI<V,@=VAE<F4@<&%R86T])R5S)P```%5N86)L
M92!T;R!D96QE=&4@<&%R86UE=&5R("5S(&9R;VT@;6ES8SH@)7,`<F5P;&%C
M92!I;G1O(%!A<F%M971E<G,@*&ED+"!P87)A;65T97(L('9A;'5E*2!V86QU
M97,H)R5S)RP@)R5S)RP@)R5S)RD`56YA8FQE('1O('!U="!P87)A;65T97(@
M)7,@:6YT;R!087)A;65T97)S.B`E<P``<F5P;&%C92!I;G1O(&1O;5]P87)A
M;2`H9&]M7VED+"!P87)A;2P@=F%L*2!V86QU97,H)R5S)RP@)R5S)RP@)R5S
M)RD`````56YA8FQE('1O('!U="!P87)A;65T97(@)7,@:6YT;R!D;VU?<&%R
M86TZ("5S````<F5P;&%C92!I;G1O(&UI<V,@*'!A<F%M+"!V86PI('9A;'5E
M<R@G)7,G+"`G)7,G*0```')E<&QA8V4@:6YT;R!M:7-C("AP87)A;2D@=F%L
M=65S*"<E<R<I``!5;F%B;&4@=&\@<'5T('!A<F%M971E<B`E<R!I;G1O(&UI
M<V,Z("5S`%PB)P!-65-13%]53DE87U!/4E0`+V5T8R]M>2YC;F8`6VUY<W%L
M9%T`+W9A<B]L:6(O;7ES<6PO;7ES<6PN<V]C:P`O=&UP+VUY<W%L+G-O8VL`
M4%-!7U)53E]-3T1%`%!305]$0E](3U-4`"]E=&,O<'-A+W9Z7VUO9&4`+W!R
M;V,O=GHO=F5I;F9O`'!S825D`%!305]$0E].04U%`&%D;6EN)60`4%-!7T1"
M7TQ/1TE.`"]E=&,O<'-A+RYP<V$N<VAA9&]W`%!305]$0E]03U)4`'-E="!F
M;W)E:6=N7VME>5]C:&5C:W,],`!L;V-A;&AO<W0`<'-A`&%D;6EN`&1O;6%I
M;G,`:'1Y<&4`)74`<&%R86T`;6ES8P!V86P`56YA8FQE('1O('%U97)Y(&%N
M;VY?9G1P.B`E<PH`861M:6Y?96UA:6P`56YA8FQE('1O(&1E9FEN92!A9&UI
M;B!E;6%I;`H`:61N7W1O87-C:6DH*2!F86EL960Z("5S`%-%3$5#5"!M87@H
M:60I($923TT@)7,`56YA8FQE('1O(&1E9FEN92!M87@@:60Z("5S`'5N<F5C
M;V=N:7IE9"!04T%?4E5.34]$10!D8E]C;VYN96-T.B!F86EL960@=&\@8V]N
M;F5C="!T;R!D871A8F%S93H@17)R;W(Z("5S`````&1B7V-O;FYE8W0Z(%5N
M86)L92!T;R!O<&5N(&%D;6EN('!A<W-W;W)D(&9I;&4@)7,Z("5S````9&)?
M8V]N;F5C=#H@56YA8FQE('1O(')E860@861M:6X@<&%S<W=O<F0@9FEL92`E
M<SH@)7,```!D8E]C;VYN96-T.B!I;G-U9F9I8VEE;G0@;65M;W)Y('1O(&%L
M;&]C871E(&YE=R!O8FIE8W0N`%5N86)L92!T;R!Q=65R>2!P87)A;65T97(@
M8GD@<75E<GD@)7,Z("5S"@``<V5L96-T("5S(&9R;VT@)7,@=VAE<F4@)7,]
M)R5S)P!S96QE8W0@:7!A+FEP7V%D9')E<W,@9G)O;2!D;VUA:6YS(&0L(&AO
M<W1I;F<@:"P@25!?061D<F5S<V5S(&EP82!W:&5R92!D+FED/2<E<R<@86YD
M(&0N:60]:"YD;VU?:60@86YD(&@N:7!?861D<F5S<U]I9#UI<&$N:60``%5N
M86)L92!T;R!Q=65R>2!)4"!A9&1R97-S.B`E<PH`9V5T7VEP7V%D9')E<W,Z
M(%5N86)L92!T;R!C;VYN96-T('1O('1H92!M>7-Q;"!D871A8F%S90!S96QE
M8W0@<W1A='5S(&9R;VT@9&]M86EN<R!W:&5R92!I9#TB)7,B`````%5N86)L
M92!T;R!G970@<W1A='5S(&9O<B!D;VUA:6X@=VET:"!I9#TB)7,B.B`E<P``
M``!5;F%B;&4@=&\@9V5T('-T871U<R!F;W(@9&]M86EN('=I=&@@:60](B5S
M(CH@<W5C:"!D;VUA:6X@:7,@;F]T(&5X:7-T+@!5;F%B;&4@=&\@9V5T('-T
M871U<R!F;W(@9&]M86EN('=I=&@@:60](B5S(CH@97)R;W(@=')A;G-L871E
M('-T871U<R!V86QU92!F<F]M(&-H87(@=&\@=6YS:6=N960@:6YT+@```'-E
M;&5C="!V86P@9G)O;2!D;VU?<&%R86T@=VAE<F4@9&]M7VED/2<E<R<@86YD
M('!A<F%M/2<E<R<``%5N86)L92!T;R!Q=65R>2!D;VUA:6X@<&%R86UE=&5R
M("5S.B`E<PH`````<V5L96-T('(N=F%L=64@9G)O;2!D;VUA:6YS(&0L(%!A
M<F%M971E<G,@<B`)"7=H97)E(&0N:60])R5S)R!A;F0@9"YP87)A;7-?:60]
M<BYI9"!A;F0@<BYP87)A;65T97(])R5S)P!S96QE8W0@<BYV86QU92!F<F]M
M($1O;6%I;E-E<G9I8V5S(',L(%!A<F%M971E<G,@<B`)"0D)('=H97)E(',N
M9&]M7VED/2<E<R<@86YD(',N='EP93TG)7,G(&%N9"!S+G!A<F%M971E<G-?
M:60]<BYI9"`@86YD('(N<&%R86UE=&5R/2<E<R<``'-E;&5C="!L+G9A;'5E
M(&9R;VT@9&]M86EN<R!D+"!,:6UI=',@;"`)"0D)('=H97)E(&0N:60])R5S
M)R!A;F0@9"YL:6UI='-?:60];"YI9"`@86YD(&PN;&EM:71?;F%M93TG)7,G
M`````%5N86)L92!T;R!Q=65R>2!D;VUA:6X@;&EM:70@)7,Z("5S"@````!S
M96QE8W0@*B!F<F]M(&1O;6%I;G,@9&]M+"!D;G-?<F5C<R!D;G,@"0EW:&5R
M92!D;VTN:60])R5S)R!A;F0@9&]M+FED/61N<RYD;VU?:60@86YD("@H9&YS
M+G1Y<&4])T$G*2!O<B`H9&YS+G1Y<&4])T-.04U%)RDI(`D)86YD(&1N<RYH
M;W-T(&QI:V4@)W=W=RXE)2<```!S96QE8W0@*B!F<F]M('-U8F1O;6%I;G,@
M"0D)=VAE<F4@9&]M7VED/2<E<R<@86YD(&YA;64])W=W=R<`````56YA8FQE
M('1O('%U97)Y('=W=R!P<F5F:7@Z("5S"@!5;F%B;&4@=&\@<75E<GD@=W=W
M('-U8F1O;6%I;CH@)7,*``!S96QE8W0@82YS=&%T=7,@9G)O;2!D;VUA:6YS
M(&0L(&%N;VY?9G1P(&$@"0D)"0D)"0D)=VAE<F4@9"YI9#TG)7,G(&%N9"!A
M+F1O;5]I9#UD+FED````<V5L96-T(&@N9G!?<W-L(&9R;VT@9&]M86EN<R!D
M+"!H;W-T:6YG(&@@"0D)"0D)"0D)=VAE<F4@9"YN86UE/2<E<R<@86YD(&@N
M9&]M7VED/60N:60``%5N86)L92!T;R!Q=65R>2!F<F]N='!A9V4@<W1A='5S
M.B`E<PH```!S96QE8W0@:"YF<"!F<F]M(&1O;6%I;G,@9"P@:&]S=&EN9R!H
M(`D)"0D)"0D)"7=H97)E(&0N;F%M93TG)7,G(&%N9"!H+F1O;5]I9#UD+FED
M``!S96QE8W0@8RYE;6%I;"!F<F]M(&1O;6%I;G,@9"P@8VQI96YT<R!C(`D)
M"0D)"0D)"7=H97)E(&0N8VQ?:60]8RYI9"!A;F0@9"YI9#TG)7,G``!5;F%B
M;&4@=&\@9&5F:6YE(&-L:65N=',@96UA:6PZ("5S"@!S96QE8W0@:60@9G)O
M;2!D;VUA:6YS('=H97)E(&YA;64])R5S)P``9V5T7V1O;5]I9"@I.B!D;VUA
M:6YS(')E8V]R9"!N;W0@9F]U;F0@:6X@1$(@9F]R("<E<R<*``!5;F%B;&4@
M=&\@<75E<GD@9&]M86EN($E$.B`E<PH``'-E;&5C="!N86UE(&9R;VT@9&]M
M86EN<R!W:&5R92!N86UE/2<E<R<`````56YA8FQE('1O('%U97)Y(&1O;6%I
M;B!N86UE.B`E<PH`26YV86QI9"!L96YG=&@`4'5N>6-O9&4@97)R;W(`4W5C
M8V5S<P!5;FMN;W=N(&5R<F]R`$%#12!P<F5F:7@@9F]U;F0`04-%('!R969I
M>"!N;W0@9F]U;F0`5F5R:69Y(&5R<F]R`$-O;G1A:6YS(&YO;BU,1$@@8VAA
M<F%C=&5R<P!#;VYT86EN<R!M:6YU<P!)8V]N=B!E<G)O<@!#86YN;W0@86QL
M;V-A=&4@8G5F9F5R`%-T<FEN9W!R97`@97)R;W(`06QL;V-A=&EO;B!F86EL
M960`)7,H)7,I(&9A:6QE9#H@)7,`;F\@:&]S=&YA;64@9F]U;F0@:6X@55),
M`')E9V-O;7`H*2!F86EL960Z("5S`')E9V5X96,H*2!F86EL960Z("5S`&ED
M;E]T;V%S8VEI7W-A9F4``%XH9G1P.B\O?&AT='!S/SHO+RD_*%M>0%TK0"D_
M*%M>+SI=*RDH+BHI/R0`)7,Z(``*4WES=&5M(&5R<F]R("5D.B`E<P```$-A
M;B=T(&%L;&]C871E(&UE;6]R>2!F;W(@97)R;W(@;65S<V%G90!X;BTM````
M``````````````````````````````````````!@C0@(````````````````
M``````````````````````$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0("`@("`@("`@("`@("`@("
M`@("`@("`@("`@("`@("`P,#`P,#`P,#`P,#`P,#`P0$!`0$!`0$!04%!08&
M`0$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!'FYN;FYN;FYN;FYN;FYN;FYN;FYN;HW-S<W.C8W-S<W-S*RMS<
MW-S*RMS<W-S<W-S<W-S<`0$!`0'<W-S<YN;FYN;FYN;PYMS<W.;FYMS<````
M``````````````````#JZNGFYN;FYN;FYN;FYN;F````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#FYN;F````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#<YN;FYMSFYN;>
MW.;FYN;FY@#<W-S<W.;FW.;FWN3F"@L,#0X/$!$2$P`4%18`%P`8&0#F````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````;'!T>
M'R`A(N;FW```````````````````````````````````(P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MYN;FYN;FY@``YN;FYMSF``#FY@#<YN;<````````````````````````````
M```````````````````D````````````````````````````````````````
MYMSFYMSFYMS<W.;<W.;<YN;FW.;<YMSFW.;F````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````<`
M````````````````````"0```.;<YN8`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````!P``````````
M```````````)````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````'````````````````````
M``D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````<`````````````````````"0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````!P`````````````````````)````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"0````````!46P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````)````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````"0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!G9PD`````````````````:VMK:P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'9V``````````````````!Z>GIZ````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-S<````````````````````````````````````W`#<
M`-@`````````````````````````````````````````````````````````
M````````````````@8(`A```````@H*"@@``@@#FY@D`YN8`````````````
M````````````````````````````````````````````````````````````
M`````````-P`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````!P`)````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````)````````````````````````
M``````````````````D`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````"0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#D````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````YN8!`>;FYN8!`0'FY@````#F`````0'FW.8!````````````````
M````````````````````````````````````````````````````````````
M````````VN3HWN#@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````"`@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````!H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````.;FYN8`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#8V`$!`0```.+8V-C8V```````````
MW-S<W-S<W-P``.;FYN;FW-P`````````````````````````````````````
M``#FYN;F````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````1
M`!$`$0```0`"``,`!```$04`!@`'``@`"0`*``L`#```$0`1`!$`$0`1`!$-
M``X``!$`$0`1`!$`$0`1`!$/```1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$1```!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$1```1`!$2```1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$1,``!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1````````
M`````"``(,R(`&$`(,R$`#(`,P`@S($`SKP`(,RG`#$`;P`QXH&$-``QXH&$
M,@`SXH&$-`!!S(``0<R!`$',@@!!S(,`0<R(`$',B@!#S*<`1<R``$7,@0!%
MS((`1<R(`$G,@`!)S($`2<R"`$G,B`!.S(,`3\R``$_,@0!/S((`3\R#`$_,
MB`!5S(``5<R!`%7,@@!5S(@`6<R!`&',@`!AS($`8<R"`&',@P!AS(@`8<R*
M`&/,IP!ES(``9<R!`&7,@@!ES(@`:<R``&G,@0!IS((`:<R(`&[,@P!OS(``
M;\R!`&_,@@!OS(,`;\R(`'7,@`!US($`=<R"`'7,B`!YS($`><R(`$',A`!A
MS(0`0<R&`&',A@!!S*@`8<RH`$/,@0!CS($`0\R"`&/,@@!#S(<`8\R'`$/,
MC`!CS(P`1,R,`&3,C`!%S(0`9<R$`$7,A@!ES(8`1<R'`&7,AP!%S*@`9<RH
M`$7,C`!ES(P`1\R"`&?,@@!'S(8`9\R&`$?,AP!GS(<`1\RG`&?,IP!(S((`
M:,R"`$G,@P!IS(,`2<R$`&G,A`!)S(8`:<R&`$G,J`!IS*@`2<R'`$E*`&EJ
M`$K,@@!JS((`2\RG`&O,IP!,S($`;,R!`$S,IP!LS*<`3,R,`&S,C`!,PK<`
M;,*W`$[,@0!NS($`3LRG`&[,IP!.S(P`;LR,`,J\;@!/S(0`;\R$`$_,A@!O
MS(8`3\R+`&_,BP!2S($`<LR!`%+,IP!RS*<`4LR,`'+,C`!3S($`<\R!`%/,
M@@!SS((`4\RG`'/,IP!3S(P`<\R,`%3,IP!TS*<`5,R,`'3,C`!5S(,`=<R#
M`%7,A`!US(0`5<R&`'7,A@!5S(H`=<R*`%7,BP!US(L`5<RH`'7,J`!7S((`
M=\R"`%G,@@!YS((`6<R(`%K,@0!ZS($`6LR'`'K,AP!:S(P`>LR,`',`3\R;
M`&_,FP!5S)L`=<R;`$1:S(P`1'K,C`!D>LR,`$Q*`$QJ`&QJ`$Y*`$YJ`&YJ
M`$',C`!AS(P`2<R,`&G,C`!/S(P`;\R,`%7,C`!US(P`5<R(S(0`=<R(S(0`
M5<R(S($`=<R(S($`5<R(S(P`=<R(S(P`5<R(S(``=<R(S(``0<R(S(0`8<R(
MS(0`0<R'S(0`8<R'S(0`PX;,A`##ILR$`$?,C`!GS(P`2\R,`&O,C`!/S*@`
M;\RH`$_,J,R$`&_,J,R$`,:WS(P`RI+,C`!JS(P`1%H`1'H`9'H`1\R!`&?,
M@0!.S(``;LR``$',BLR!`&',BLR!`,.&S($`PZ;,@0##F,R!`,.XS($`0<R/
M`&',CP!!S)$`8<R1`$7,CP!ES(\`1<R1`&7,D0!)S(\`:<R/`$G,D0!IS)$`
M3\R/`&_,CP!/S)$`;\R1`%+,CP!RS(\`4LR1`'+,D0!5S(\`=<R/`%7,D0!U
MS)$`4\RF`'/,I@!4S*8`=,RF`$C,C`!HS(P`0<R'`&',AP!%S*<`9<RG`$_,
MB,R$`&_,B,R$`$_,@\R$`&_,@\R$`$_,AP!OS(<`3\R'S(0`;\R'S(0`6<R$
M`'G,A`!H`,FF`&H`<@#)N0#)NP#*@0!W`'D`(,R&`"#,AP`@S(H`(,RH`"#,
M@P`@S(L`R:,`;`!X`,J5`,R``,R!`,R3`,R(S($`RKD`(,V%`#L`PJC,@0`@
MS(C,@0#.D<R!`,*W`,Z5S($`SI?,@0#.F<R!`,Z?S($`SJ7,@0#.J<R!`,ZY
MS(C,@0#.F<R(`,ZES(@`SK',@0#.M<R!`,ZWS($`SKG,@0#/A<R(S($`SKG,
MB`#/A<R(`,Z_S($`SX7,@0#/B<R!`,ZR`,ZX`,ZE`,^2S($`SY+,B`#/A@#/
M@`#.N@#/@0#/@@#.F`#.M0#0E<R``-"5S(@`T)/,@0#0ALR(`-":S($`T)C,
M@`#0H\R&`-"8S(8`T+C,A@#0M<R``-"US(@`T+/,@0#1ELR(`-"ZS($`T+C,
M@`#1@\R&`-&TS(\`T;7,CP#0ELR&`-"VS(8`T)#,A@#0L,R&`-"0S(@`T+#,
MB`#0E<R&`-"US(8`TYC,B`#3F<R(`-"6S(@`T+;,B`#0E\R(`-"WS(@`T)C,
MA`#0N,R$`-"8S(@`T+C,B`#0GLR(`-"^S(@`TZC,B`#3J<R(`-"MS(@`T8W,
MB`#0H\R$`-&#S(0`T*/,B`#1@\R(`-"CS(L`T8/,BP#0I\R(`-&'S(@`T*O,
MB`#1B\R(`-6EUH(`V*?9DP#8I]F4`-F(V90`V*?9E0#9BMF4`-BGV;0`V8C9
MM`#;A]FT`-F*V;0`VY79E`#;@=F4`-N2V90`X*2HX*2\`."DL."DO`#@I+/@
MI+P`X*25X*2\`."DEN"DO`#@I)?@I+P`X*2<X*2\`."DH>"DO`#@I*+@I+P`
MX*2KX*2\`."DK^"DO`#@IX?@IKX`X*>'X*>7`."FH>"FO`#@IJ+@IKP`X*:O
MX*:\`."HLN"HO`#@J+C@J+P`X*B6X*B\`."HE^"HO`#@J)S@J+P`X*BKX*B\
M`."MA^"ME@#@K8?@K+X`X*V'X*V7`."LH>"LO`#@K*+@K+P`X*Z2X*^7`."O
MAN"NO@#@KX?@KKX`X*^&X*^7`."QAN"QE@#@LK_@LY4`X+.&X+.5`."SAN"S
ME@#@LX;@LX(`X+.&X+."X+.5`."UAN"TO@#@M8?@M+X`X+6&X+67`."WF>"W
MB@#@MYG@MX\`X+>9X+>/X+>*`."WF>"WGP#@N8W@N+(`X+N-X+JR`."ZJ^"Z
MF0#@NJO@NJ$`X+R+`."]@N"^MP#@O8S@OK<`X+V1X+ZW`."]EN"^MP#@O9O@
MOK<`X+V`X+ZU`."]L>"]L@#@O;'@O;0`X+ZRX+Z``."^LN"]L>"^@`#@OK/@
MOH``X+ZSX+VQX+Z``."]L>"^@`#@OI+@OK<`X+Z<X+ZW`."^H>"^MP#@OJ;@
MOK<`X+ZKX+ZW`."^D."^M0#A@*7A@*X`0<RE`&',I0!"S(<`8LR'`$+,HP!B
MS*,`0LRQ`&+,L0!#S*?,@0!CS*?,@0!$S(<`9,R'`$3,HP!DS*,`1,RQ`&3,
ML0!$S*<`9,RG`$3,K0!DS*T`1<R$S(``9<R$S(``1<R$S($`9<R$S($`1<RM
M`&7,K0!%S+``9<RP`$7,I\R&`&7,I\R&`$;,AP!FS(<`1\R$`&?,A`!(S(<`
M:,R'`$C,HP!HS*,`2,R(`&C,B`!(S*<`:,RG`$C,K@!HS*X`2<RP`&G,L`!)
MS(C,@0!IS(C,@0!+S($`:\R!`$O,HP!KS*,`2\RQ`&O,L0!,S*,`;,RC`$S,
MH\R$`&S,H\R$`$S,L0!LS+$`3,RM`&S,K0!-S($`;<R!`$W,AP!MS(<`3<RC
M`&W,HP!.S(<`;LR'`$[,HP!NS*,`3LRQ`&[,L0!.S*T`;LRM`$_,@\R!`&_,
M@\R!`$_,@\R(`&_,@\R(`$_,A,R``&_,A,R``$_,A,R!`&_,A,R!`%#,@0!P
MS($`4,R'`'#,AP!2S(<`<LR'`%+,HP!RS*,`4LRCS(0`<LRCS(0`4LRQ`'+,
ML0!3S(<`<\R'`%/,HP!SS*,`4\R!S(<`<\R!S(<`4\R,S(<`<\R,S(<`4\RC
MS(<`<\RCS(<`5,R'`'3,AP!4S*,`=,RC`%3,L0!TS+$`5,RM`'3,K0!5S*0`
M=<RD`%7,L`!US+``5<RM`'7,K0!5S(/,@0!US(/,@0!5S(3,B`!US(3,B`!6
MS(,`=LR#`%;,HP!VS*,`5\R``'?,@`!7S($`=\R!`%?,B`!WS(@`5\R'`'?,
MAP!7S*,`=\RC`%C,AP!XS(<`6,R(`'C,B`!9S(<`><R'`%K,@@!ZS((`6LRC
M`'K,HP!:S+$`>LRQ`&C,L0!TS(@`=\R*`'G,B@!ARKX`Q;_,AP!!S*,`8<RC
M`$',B0!AS(D`0<R"S($`8<R"S($`0<R"S(``8<R"S(``0<R"S(D`8<R"S(D`
M0<R"S(,`8<R"S(,`0<RCS((`8<RCS((`0<R&S($`8<R&S($`0<R&S(``8<R&
MS(``0<R&S(D`8<R&S(D`0<R&S(,`8<R&S(,`0<RCS(8`8<RCS(8`1<RC`&7,
MHP!%S(D`9<R)`$7,@P!ES(,`1<R"S($`9<R"S($`1<R"S(``9<R"S(``1<R"
MS(D`9<R"S(D`1<R"S(,`9<R"S(,`1<RCS((`9<RCS((`2<R)`&G,B0!)S*,`
M:<RC`$_,HP!OS*,`3\R)`&_,B0!/S(+,@0!OS(+,@0!/S(+,@`!OS(+,@`!/
MS(+,B0!OS(+,B0!/S(+,@P!OS(+,@P!/S*/,@@!OS*/,@@!/S)O,@0!OS)O,
M@0!/S)O,@`!OS)O,@`!/S)O,B0!OS)O,B0!/S)O,@P!OS)O,@P!/S)O,HP!O
MS)O,HP!5S*,`=<RC`%7,B0!US(D`5<R;S($`=<R;S($`5<R;S(``=<R;S(``
M5<R;S(D`=<R;S(D`5<R;S(,`=<R;S(,`5<R;S*,`=<R;S*,`6<R``'G,@`!9
MS*,`><RC`%G,B0!YS(D`6<R#`'G,@P#.L<R3`,ZQS)0`SK',D\R``,ZQS)3,
M@`#.L<R3S($`SK',E,R!`,ZQS)/-@@#.L<R4S8(`SI',DP#.D<R4`,Z1S)/,
M@`#.D<R4S(``SI',D\R!`,Z1S)3,@0#.D<R3S8(`SI',E,V"`,ZUS),`SK7,
ME`#.M<R3S(``SK7,E,R``,ZUS)/,@0#.M<R4S($`SI7,DP#.E<R4`,Z5S)/,
M@`#.E<R4S(``SI7,D\R!`,Z5S)3,@0#.M\R3`,ZWS)0`SK?,D\R``,ZWS)3,
M@`#.M\R3S($`SK?,E,R!`,ZWS)/-@@#.M\R4S8(`SI?,DP#.E\R4`,Z7S)/,
M@`#.E\R4S(``SI?,D\R!`,Z7S)3,@0#.E\R3S8(`SI?,E,V"`,ZYS),`SKG,
ME`#.N<R3S(``SKG,E,R``,ZYS)/,@0#.N<R4S($`SKG,D\V"`,ZYS)3-@@#.
MF<R3`,Z9S)0`SIG,D\R``,Z9S)3,@`#.F<R3S($`SIG,E,R!`,Z9S)/-@@#.
MF<R4S8(`SK_,DP#.O\R4`,Z_S)/,@`#.O\R4S(``SK_,D\R!`,Z_S)3,@0#.
MG\R3`,Z?S)0`SI_,D\R``,Z?S)3,@`#.G\R3S($`SI_,E,R!`,^%S),`SX7,
ME`#/A<R3S(``SX7,E,R``,^%S)/,@0#/A<R4S($`SX7,D\V"`,^%S)3-@@#.
MI<R4`,ZES)3,@`#.I<R4S($`SJ7,E,V"`,^)S),`SXG,E`#/B<R3S(``SXG,
ME,R``,^)S)/,@0#/B<R4S($`SXG,D\V"`,^)S)3-@@#.J<R3`,ZIS)0`SJG,
MD\R``,ZIS)3,@`#.J<R3S($`SJG,E,R!`,ZIS)/-@@#.J<R4S8(`SK',@`#.
MM<R``,ZWS(``SKG,@`#.O\R``,^%S(``SXG,@`#.L<R3S84`SK',E,V%`,ZQ
MS)/,@,V%`,ZQS)3,@,V%`,ZQS)/,@<V%`,ZQS)3,@<V%`,ZQS)/-@LV%`,ZQ
MS)3-@LV%`,Z1S)/-A0#.D<R4S84`SI',D\R`S84`SI',E,R`S84`SI',D\R!
MS84`SI',E,R!S84`SI',D\V"S84`SI',E,V"S84`SK?,D\V%`,ZWS)3-A0#.
MM\R3S(#-A0#.M\R4S(#-A0#.M\R3S('-A0#.M\R4S('-A0#.M\R3S8+-A0#.
MM\R4S8+-A0#.E\R3S84`SI?,E,V%`,Z7S)/,@,V%`,Z7S)3,@,V%`,Z7S)/,
M@<V%`,Z7S)3,@<V%`,Z7S)/-@LV%`,Z7S)3-@LV%`,^)S)/-A0#/B<R4S84`
MSXG,D\R`S84`SXG,E,R`S84`SXG,D\R!S84`SXG,E,R!S84`SXG,D\V"S84`
MSXG,E,V"S84`SJG,D\V%`,ZIS)3-A0#.J<R3S(#-A0#.J<R4S(#-A0#.J<R3
MS('-A0#.J<R4S('-A0#.J<R3S8+-A0#.J<R4S8+-A0#.L<R&`,ZQS(0`SK',
M@,V%`,ZQS84`SK',@<V%`,ZQS8(`SK'-@LV%`,Z1S(8`SI',A`#.D<R``,Z1
MS84`(,R3`,ZY`"#-@@#"J,V"`"#,B,V"`,ZWS(#-A0#.M\V%`,ZWS('-A0#.
MM\V"`,ZWS8+-A0#.E<R``,Z7S(``SI?-A0#AOK_,@``@S)/,@`#AOK_,@0`@
MS)/,@0#AOK_-@@`@S)/-@@#.N<R&`,ZYS(0`SKG,B,R``,ZYS8(`SKG,B,V"
M`,Z9S(8`SIG,A`#.F<R``.&_OLR``"#,E,R``.&_OLR!`"#,E,R!`.&_OLV"
M`"#,E,V"`,^%S(8`SX7,A`#/A<R(S(``SX',DP#/@<R4`,^%S8(`SX7,B,V"
M`,ZES(8`SJ7,A`#.I<R``,ZAS)0`PJC,@``@S(C,@`!@`,^)S(#-A0#/B<V%
M`,^)S('-A0#/B<V"`,^)S8+-A0#.G\R``,ZIS(``SJG-A0#"M``@S)0`XH""
M`.*`@P#B@)``(,RS`"X`+BX`+BXN`.*`LN*`L@#B@++B@++B@+(`XH"UXH"U
M`.*`M>*`M>*`M0`A(0`@S(4`/S\`/R$`(3\`XH"RXH"RXH"RXH"R`#``:0`T
M`#4`-@`W`#@`.0`K`.*(D@`]`"@`*0!N`%)S`&$O8P!A+W,`0P#"L$,`8R]O
M`&,O=0#&D`#"L$8`9P!(`,2G`$D`3`!.`$YO`%``40!2`%--`%1%3`!430!:
M`,ZI`$L`0@!E`$4`1@!-`->0`->1`->2`->3`,ZS`,Z3`,Z@`.*(D0!$`&0`
M,>*!A#,`,N*!A#,`,>*!A#4`,N*!A#4`,^*!A#4`-.*!A#4`,>*!A#8`->*!
MA#8`,>*!A#@`,^*!A#@`->*!A#@`-^*!A#@`,>*!A`!)20!)24D`258`5@!6
M20!624D`5DE)20!)6`!8`%A)`%A)20!I:0!I:6D`:78`=@!V:0!V:6D`=FEI
M:0!I>`!X:0!X:6D`8P!M`.*&D,RX`.*&DLRX`.*&E,RX`.*'D,RX`.*'E,RX
M`.*'DLRX`.*(@\RX`.*(B,RX`.*(B\RX`.*(H\RX`.*(I<RX`.*(J^*(JP#B
MB*OBB*OBB*L`XHBNXHBN`.*(KN*(KN*(K@#BB+S,N`#BB8/,N`#BB87,N`#B
MB8C,N``]S+@`XHFAS+@`XHF-S+@`/,RX`#[,N`#BB:3,N`#BB:7,N`#BB;+,
MN`#BB;/,N`#BB;;,N`#BB;?,N`#BB;K,N`#BB;O,N`#BBH+,N`#BBH/,N`#B
MBH;,N`#BBH?,N`#BBJ+,N`#BBJC,N`#BBJG,N`#BBJO,N`#BB;S,N`#BB;W,
MN`#BBI',N`#BBI+,N`#BBK+,N`#BBK/,N`#BBK3,N`#BBK7,N`#C@(@`XX")
M`#$P`#$Q`#$R`#$S`#$T`#$U`#$V`#$W`#$X`#$Y`#(P`"@Q*0`H,BD`*#,I
M`"@T*0`H-2D`*#8I`"@W*0`H."D`*#DI`"@Q,"D`*#$Q*0`H,3(I`"@Q,RD`
M*#$T*0`H,34I`"@Q-BD`*#$W*0`H,3@I`"@Q.2D`*#(P*0`Q+@`R+@`S+@`T
M+@`U+@`V+@`W+@`X+@`Y+@`Q,"X`,3$N`#$R+@`Q,RX`,30N`#$U+@`Q-BX`
M,3<N`#$X+@`Q.2X`,C`N`"AA*0`H8BD`*&,I`"AD*0`H92D`*&8I`"AG*0`H
M:"D`*&DI`"AJ*0`H:RD`*&PI`"AM*0`H;BD`*&\I`"AP*0`H<2D`*'(I`"AS
M*0`H="D`*'4I`"AV*0`H=RD`*'@I`"AY*0`H>BD`00!'`$H`3P!3`%0`50!7
M`%D`8@!F`&L`<`!Q`'0`=0!Z`.*(J^*(J^*(J^*(JP`Z.CT`/3T`/3T]`.*K
MG<RX`.:OC0#IOI\`Y+B``.2XJ`#DN+8`Y+B_`.2YF0#DNH4`Y+J,`.2ZH`#D
MNKH`Y82_`.6%I0#EA:L`Y8:"`.6&E@#EAJL`Y8>@`.6'M0#EB(``Y8J;`.6+
MN0#EC)4`Y8R:`.6,N`#EC8$`Y8V<`.6-J0#ECH(`Y8ZV`.6/B`#ECZ,`Y9N7
M`.6<GP#EHZL`Y:2"`.6DB@#EI)4`Y:2G`.6ELP#EK9``Y:Z``.6ON`#EL(\`
MY;"B`.6PN`#EL:X`Y;&Q`.6WFP#EMZ4`Y;>Q`.6WO@#EN;(`Y;FZ`.6YOP#E
MN[0`Y;N^`.6\BP#EO),`Y;V0`.6]H0#EO;,`Y;^#`.:(B`#FB+8`YHF+`.:4
MKP#FE+0`YI:'`.:6EP#FEJ0`YI:Y`.:7H`#FEZ4`YINP`.:<B`#FG*@`YJR@
M`.:MH@#FK;D`YJZS`.:OBP#FKY0`YJ^;`.:PCP#FL)0`YK"T`.>!JP#GB*H`
MYXBV`.>(NP#GB+\`YXF'`.>)F0#GB9L`YXJL`.>.A`#GCHD`YY.<`.>3I@#G
ME)@`YY2?`.>4J`#GE+``YY:+`.>6D@#GF;8`YYF]`.>:K@#GFK\`YYNN`.>?
MFP#GGZ(`YY^S`.>DN@#GIK@`YZ:^`.>IM`#GJXL`YZNY`.>QLP#GL[@`Y[RV
M`.>]D0#GOHH`Y[Z]`.B`@0#H@(P`Z("2`.B`LP#H@;\`Z(*)`.B'HP#HAZH`
MZ(>S`.B'O`#HB(P`Z(B;`.B(GP#HB:X`Z(FR`.B)N`#HF8T`Z)FK`.BA@`#H
MH8P`Z*&C`.BEO@#HIHL`Z*>2`.BH@`#HL+<`Z+&&`.BQE0#HL;@`Z+*=`.BU
MI`#HM;``Z+:S`.BZJP#HNXH`Z+Z;`.B^L`#HOK4`Z8*1`.F%B0#IAX8`Z8>,
M`.F'D0#IE;<`Z9:``.F8G`#IFK8`Z9JY`.F;J`#IG9$`Z9V>`.F=H@#IG:D`
MZ9^+`.F?K0#IG[,`Z:"!`.FBJ`#IHYL`Z:.?`.FFE@#IIID`Z::L`.FJJ`#I
MJY@`Z:N?`.FLI0#IK*\`Z:RR`.FLO`#IK9H`Z;.E`.FYM0#IN;\`Z;JE`.FZ
MNP#INX,`Z;N-`.F[D0#IN[D`Z;N]`.F\C@#IO),`Z;R@`.F\NP#IO8H`Z;V2
M`.F^C0#IOIP`Z;Z@`..`D@#EC80`Y8V%`..!B^."F0#C@8WC@ID`XX&/XX*9
M`..!D>."F0#C@9/C@ID`XX&5XX*9`..!E^."F0#C@9GC@ID`XX&;XX*9`..!
MG>."F0#C@9_C@ID`XX&AXX*9`..!I.."F0#C@:;C@ID`XX&HXX*9`..!K^."
MF0#C@:_C@IH`XX&RXX*9`..!LN."F@#C@;7C@ID`XX&UXX*:`..!N.."F0#C
M@;CC@IH`XX&[XX*9`..!N^."F@#C@8;C@ID`(.."F0`@XX*:`.."G>."F0#C
M@HCC@HH`XX*KXX*9`.."K>."F0#C@J_C@ID`XX*QXX*9`.."L^."F0#C@K7C
M@ID`XX*WXX*9`.."N>."F0#C@KOC@ID`XX*]XX*9`.."O^."F0#C@X'C@ID`
MXX.$XX*9`..#AN."F0#C@XCC@ID`XX./XX*9`..#C^."F@#C@Y+C@ID`XX.2
MXX*:`..#E>."F0#C@Y7C@IH`XX.8XX*9`..#F.."F@#C@YOC@ID`XX.;XX*:
M`.."IN."F0#C@Z_C@ID`XX.PXX*9`..#L>."F0#C@[+C@ID`XX.]XX*9`.."
ML^.#B`#AA(``X82!`.&&J@#AA((`X8:L`.&&K0#AA(,`X82$`.&$A0#AAK``
MX8:Q`.&&L@#AAK,`X8:T`.&&M0#AA)H`X82&`.&$AP#AA(@`X82A`.&$B0#A
MA(H`X82+`.&$C`#AA(T`X82.`.&$CP#AA)``X821`.&$D@#AA:$`X86B`.&%
MHP#AA:0`X86E`.&%I@#AA:<`X86H`.&%J0#AA:H`X86K`.&%K`#AA:T`X86N
M`.&%KP#AA;``X86Q`.&%L@#AA;,`X86T`.&%M0#AA:``X824`.&$E0#AAX<`
MX8>(`.&'C`#AAXX`X8>3`.&'EP#AAYD`X82<`.&'G0#AAY\`X82=`.&$G@#A
MA*``X82B`.&$HP#AA*<`X82I`.&$JP#AA*P`X82M`.&$K@#AA*\`X82R`.&$
MM@#AA8``X86'`.&%C`#AA[$`X8>R`.&%EP#AA9@`X869`.&&A`#AAH4`X8:(
M`.&&D0#AAI(`X8:4`.&&G@#AAJ$`Y+B)`.6;FP#DN(H`Y+BM`.2XBP#GE+(`
MY+B9`.2X@0#EI*D`Y9RP`"CAA(`I`"CAA((I`"CAA(,I`"CAA(4I`"CAA(8I
M`"CAA(<I`"CAA(DI`"CAA(LI`"CAA(PI`"CAA(XI`"CAA(\I`"CAA)`I`"CA
MA)$I`"CAA)(I`"CAA(#AA:$I`"CAA(+AA:$I`"CAA(/AA:$I`"CAA(7AA:$I
M`"CAA(;AA:$I`"CAA(?AA:$I`"CAA(GAA:$I`"CAA(OAA:$I`"CAA(SAA:$I
M`"CAA([AA:$I`"CAA(_AA:$I`"CAA)#AA:$I`"CAA)'AA:$I`"CAA)+AA:$I
M`"CAA(SAA:XI`"CDN(`I`"CDNHPI`"CDN(DI`"CEFYLI`"CDNI0I`"CEA:TI
M`"CDN(,I`"CEA:LI`"CDN9TI`"CEC8$I`"CFG(@I`"CG@:LI`"CFL+0I`"CF
MG*@I`"CIAY$I`"CEG)\I`"CFEZ4I`"CFH*HI`"CFG(DI`"CGI+XI`"CED(TI
M`"CGB;DI`"CHLJ$I`"CGI9TI`"CEBK0I`"CDNZ,I`"CED;PI`"CEK:8I`"CG
MFZ,I`"CDO($I`"CHLX<I`"CEC90I`"CGI:TI`"CDO)$I`"CHAZHI`"CHA[,I
M`#(Q`#(R`#(S`#(T`#(U`#(V`#(W`#(X`#(Y`#,P`#,Q`#,R`#,S`#,T`#,U
M`.&$@.&%H0#AA(+AA:$`X82#X86A`.&$A>&%H0#AA(;AA:$`X82'X86A`.&$
MB>&%H0#AA(OAA:$`X82,X86A`.&$CN&%H0#AA(_AA:$`X820X86A`.&$D>&%
MH0#AA)+AA:$`Y+J4`.6%K0#DN(,`Y+F=`.:@J@#FG(D`YZ2^`.60C0#GB;D`
MZ+*A`.>EG0#EBK0`YZ>8`.>4MP#I@:D`Y82J`.6-L`#FLZ@`Z:"%`.2\D0#E
MAID`YJVC`.6WI@#EC[,`Y8R[`.6NEP#EK:8`YYNC`.2\@0#HLX<`Y8V4`.6D
MG``S-@`S-P`S.``S.0`T,``T,0`T,@`T,P`T-``T-0`T-@`T-P`T.``T.0`U
M,``QYIR(`#+FG(@`,^:<B``TYIR(`#7FG(@`-N:<B``WYIR(`#CFG(@`.>:<
MB``Q,.:<B``Q,>:<B``Q,N:<B`#C@J(`XX*D`.."I@#C@J@`XX*J`.."JP#C
M@JT`XX*O`.."L0#C@K,`XX*U`.."MP#C@KD`XX*[`.."O0#C@K\`XX.!`..#
MA`#C@X8`XX.(`..#B@#C@XL`XX.,`..#C0#C@XX`XX./`..#D@#C@Y4`XX.8
M`..#FP#C@YX`XX.?`..#H`#C@Z$`XX.B`..#I`#C@Z8`XX.H`..#J0#C@ZH`
MXX.K`..#K`#C@ZT`XX.O`..#L`#C@[$`XX.R`.."HN.#C^."FN.#O..#B`#C
M@J+C@ZOC@Y7C@J$`XX*BXX.SXX.8XX*:XX*B`.."HN.#O..#JP#C@J3C@XOC
M@[/C@J_C@ID`XX*DXX.SXX.!`.."IN."J>.#LP#C@JCC@KGC@J_C@[SC@XCC
M@ID`XX*HXX.\XX*KXX.\`.."JN.#L^."N0#C@JKC@[SC@Z``XX*KXX*DXX.J
M`.."J^.#J>.#@^.#B`#C@JOC@ZWC@ZKC@[P`XX*KXX*9XX.MXX.S`.."J^."
MF>.#L^.#G@#C@JWC@IGC@JOC@ID`XX*MXX*9XX.+XX.\`.."K>.#I>.#JN.#
MO`#C@JWC@IGC@ZOC@K_C@IGC@[P`XX*MXX.M`.."K>.#K>."K^."F>.#J>.#
MH`#C@JWC@ZWC@Z'C@[SC@XCC@ZL`XX*MXX.MXX.OXX.#XX.(`.."K^."F>.#
MJ>.#H`#C@J_C@IGC@ZGC@Z#C@XCC@[,`XX*OXX.KXX*[XX*9XX*DXX.M`.."
MK^.#K>.#O..#C0#C@K'C@[SC@KD`XX*SXX.KXX.*`.."L^.#O..#F^."F@#C
M@K7C@J3C@J_C@ZL`XX*UXX.SXX.!XX.\XX.@`.."M^.#JN.#L^."K^."F0#C
M@KOC@[/C@X$`XX*[XX.SXX.(`.."O^."F>.#O.."N0#C@X;C@IGC@K<`XX.(
MXX*9XX.K`..#B..#LP#C@XKC@XX`XX..XX.#XX.(`..#C^."I..#A`#C@X_C
M@IKC@[SC@KOC@[/C@X@`XX./XX*:XX.\XX.$`..#C^."F>.#O..#K..#JP#C
M@Y+C@IKC@J+C@KGC@XCC@ZL`XX.2XX*:XX*OXX.K`..#DN."FN."LP#C@Y+C
M@IGC@ZL`XX.5XX*AXX.IXX.#XX.(XX*9`..#E>."H^.#O..#B`#C@Y7C@IGC
M@X/C@K?C@J?C@ZL`XX.5XX.IXX.S`..#F.."K^."O^.#O..#JP#C@YCC@IKC
M@KT`XX.8XX*:XX.+XX.2`..#F..#J^.#A`#C@YCC@IKC@[/C@KD`XX.8XX*:
MXX.\XX*WXX*9`..#F.."F>.#O.."OP#C@YOC@IKC@J3C@[/C@X@`XX.;XX*9
MXX.KXX.(`..#F^.#LP#C@YOC@IKC@[/C@XCC@ID`XX.;XX.\XX.K`..#F^.#
MO..#LP#C@Y[C@J3C@J_C@ZT`XX.>XX*DXX.K`..#GN.#@^.#CP#C@Y[C@ZOC
M@J\`XX.>XX.SXX*WXX.GXX.S`..#G^."K^.#K>.#LP#C@Y_C@ZH`XX.?XX.J
MXX./XX*9XX.\XX.K`..#H>."J^."F0#C@Z'C@JOC@IGC@XCC@[,`XX.AXX.\
MXX.(XX.K`..#I..#O..#B.."F0#C@Z3C@[SC@ZL`XX.FXX*BXX.S`..#JN.#
M@^.#B..#JP#C@ZKC@ZD`XX.KXX.2XX*:XX.\`..#J^.#O..#E>."F>.#JP#C
M@ZSC@Z``XX.LXX.SXX.(XX*QXX*9XX.S`..#K^.#@^.#B``PYX*Y`#'G@KD`
M,N>"N0`SYX*Y`#3G@KD`->>"N0`VYX*Y`#?G@KD`..>"N0`YYX*Y`#$PYX*Y
M`#$QYX*Y`#$RYX*Y`#$SYX*Y`#$TYX*Y`#$UYX*Y`#$VYX*Y`#$WYX*Y`#$X
MYX*Y`#$YYX*Y`#(PYX*Y`#(QYX*Y`#(RYX*Y`#(SYX*Y`#(TYX*Y`&A080!D
M80!!50!B87(`;U8`<&,`Y;FSYHB0`.:8K>62C`#EI*?FK:,`YIB.YK*[`.:@
MJN6\C^2\FN>DO@!P00!N00#.O$$`;4$`:T$`2T(`34(`1T(`8V%L`&MC86P`
M<$8`;D8`SKQ&`,Z\9P!M9P!K9P!(>@!K2'H`34AZ`$=(>@!42'H`SKQL`&UL
M`&1L`&ML`&9M`&YM`,Z\;0!M;0!C;0!K;0!M;3(`8VTR`&TR`&MM,@!M;3,`
M8VTS`&TS`&MM,P!MXHB5<P!MXHB5<S(`4&$`:U!A`$U080!'4&$`<F%D`')A
M9.*(E7,`<F%DXHB5<S(`<',`;G,`SKQS`&US`'!6`&Y6`,Z\5@!M5@!K5@!-
M5@!P5P!N5P#.O%<`;5<`:U<`35<`:\ZI`$W.J0!A+FTN`$)Q`&-C`&-D`$/B
MB)5K9P!#;RX`9$(`1WD`:&$`2%``:6X`2TL`2TT`:W0`;&T`;&X`;&]G`&QX
M`&UB`&UI;`!M;VP`4$@`<"YM+@!04$T`4%(`<W(`4W8`5V(`,>:7I0`RYI>E
M`#/FEZ4`-.:7I0`UYI>E`#;FEZ4`-^:7I0`XYI>E`#GFEZ4`,3#FEZ4`,3'F
MEZ4`,3+FEZ4`,3/FEZ4`,33FEZ4`,37FEZ4`,3;FEZ4`,3?FEZ4`,3CFEZ4`
M,3GFEZ4`,C#FEZ4`,C'FEZ4`,C+FEZ4`,C/FEZ4`,C3FEZ4`,C7FEZ4`,C;F
MEZ4`,C?FEZ4`,CCFEZ4`,CGFEZ4`,S#FEZ4`,S'FEZ4`Z+&(`.:;M`#HLX@`
MYKN1`.2XL@#ECZ4`Y:61`.66AP#EI8@`YH>V`.>9J0#GOH4`Z)B_`.B>N@#H
MH[@`Z8*/`.:H@@#FM)L`YX.9`.>/G@#HD+T`Z86J`.FGL0#DNH(`Y8VU`.:L
MA`#GB)L`Z)BM`.FXG@#EM9``YK^K`.B7C0#HI:0`YHN)`.B'F`#HH)\`Y;N*
M`.:<EP#FM:H`YXN\`.F#C@#DOH8`Y8:W`.6+G@#FDX0`YJN3`.>(D`#GFZ<`
MZ)B&`.B9G`#HMZ\`Z9RR`.FMKP#IM[H`YZ*,`.>EOP#GMJ``Z(^)`.F,A`#H
MJY8`Y:.?`.6\A`#GL:``Z(&^`.>)H@#GHXH`Z+."`.F;MP#EHY@`Y;&B`.:H
MDP#FMYH`YKR/`.>TKP#GN+<`Z9F+`.6+D@#H@HL`Y8><`.6'C`#GJ)P`Y[:^
M`.B/L0#IF;4`Z*Z``.:+CP#HJ[X`Y+BY`.6OIP#F@)(`YXZ'`.>5L`#EC)<`
MYZ.[`.2^OP#EOJD`Y+B-`.:SC`#FE;@`Y[2B`.6/@P#EH9X`YYR!`.B1B0#H
MJJH`YJZZ`.:RB`#FB[X`Z(NE`.:.H`#GE:4`Y+JN`.6%J0#EAXD`YJ*!`.>S
MIP#HB:\`Z*N2`.F'CP#EB[4`Y9&"`.6[K`#FEX4`YK^^`.>DJ@#IEJT`Z:FJ
M`.FZEP#INXX`YIN&`.:MMP#HO:(`Y;FT`.:&D`#FB(``YI*:`.:\HP#GA8D`
MYY*)`.>GB@#GM[0`Z(&O`.B\I@#HDZX`Z8"C`.F-B@#EB)<`Y8JC`.62O0#G
M@X@`Z*."`.6[B0#EO[4`YHV[`.:NK@#GL+X`YXVU`.2[I`#EF[D`Y;:Z`.:`
MG`#GCK(`YY&I`.>^F@#H@88`Z8BT`.F;M@#IG8@`Z:"8`.2^BP#GIJX`Z8:T
M`.F:N`#F@Z$`Y+J&`.6#F@#EKZX`Y;"_`.:6F0#GAXX`YYF"`.B3O`#I@;P`
MYIJ(`.F8K@#EBHD`YIV[`.:?LP#FM8$`YKJ<`.>0B0#GE9D`YZ&K`.>TD`#I
MH9X`YHBN`.F9N`#E@*L`Y;29`.:WJ@#HO*H`Y;Z+`.:%A`#FH)<`Z9J&`.6(
MJ0#ED(\`Y;&E`.:8DP#FG8X`YJ*H`.:SI0#GD(8`YY>B`.>]N0#HHX\`Z*.A
M`.F;H@#EC+\`YKJZ`.60G0#GAY``YY*8`.B7N@#IFJ,`Z;&7`.FZGP#FGI<`
MYK>+`.B'J`#GK*``Y[*2`.>+@`#G@ID`Z*V8`.2[@`#HC+8`Y8BZ`.6(AP#E
MNJ8`YHN3`.>SE@#EKH4`YK2>`.::M`#HO+L`Z9F-`.6[DP#EA8``Y9>``.6A
MF@#FF;0`Y8>>`.>,J@#GFXH`YZ2\`.>EG@#GI:4`YZ:/`.F=E@#GLKX`Z)B2
M`.BKN`#I@+@`Z8.]`.FCKP#IH[P`Z:2H`.FVM`#DOJX`Y8.G`.6%C0#EBXD`
MY8ND`.6-D0#EEIT`Y9B&`.69J`#EH8``Y:*H`.6QI`#F@I0`YH6H`.:&C@#F
MA[(`YI6/`.:7H@#FFI$`YJ*%`.:UMP#FN)H`YKRB`.>%K@#GB*L`YY"B`.>B
MD0#GI8D`YZ6(`.>ED`#GI98`YZ:-`.>FC@#GJ8``YZJ!`.>O@`#GN(D`Y[F!
M`.>]L@#H@(4`Z(>M`.B)N0#HD9<`Z*20`.BFE@#HK($`Z*RY`.BSDP#HM(@`
MZ+ZV`.F;HP#IG[\`Z:"[`&9F`&9I`&9L`&9F:0!F9FP`<W0`U;35M@#5M-6E
M`-6TU:L`U;[5M@#5M-6M`->9UK0`U[+6MP#7H@#7E`#7FP#7G`#7G0#7J`#7
MJ@#7J=>!`->IUX(`UZG6O->!`->IUKS7@@#7D-:W`->0UK@`UY#6O`#7D=:\
M`->2UKP`UY/6O`#7E-:\`->5UKP`UY;6O`#7F-:\`->9UKP`UYK6O`#7F]:\
M`-><UKP`UY[6O`#7H-:\`->AUKP`UZ/6O`#7I-:\`->FUKP`UZ?6O`#7J-:\
M`->IUKP`UZK6O`#7E=:Y`->1UK\`UYO6OP#7I-:_`->0UYP`V;$`V;L`V;X`
MVH``V;H`V;\`V;D`VJ0`VJ8`VH0`VH,`VH8`VH<`VHT`VHP`VHX`VH@`VI@`
MVI$`VJD`VJ\`VK,`VK$`VKH`VKL`VX$`VKX`VY(`VJT`VX<`VX8`VX@`VXL`
MVX4`VXD`VY``V8D`V8K9E-BG`-F*V93;E0#9BMF4V8@`V8K9E-N'`-F*V93;
MA@#9BMF4VX@`V8K9E-N0`-F*V939B0#;C`#9BMF4V*P`V8K9E-BM`-F*V939
MA0#9BMF4V8H`V*C8K`#8J-BM`-BHV*X`V*C9A0#8J-F)`-BHV8H`V*K8K`#8
MJMBM`-BJV*X`V*K9A0#8JMF)`-BJV8H`V*O8K`#8J]F%`-BKV8D`V*O9B@#8
MK-BM`-BLV84`V*W8K`#8K=F%`-BNV*P`V*[8K0#8KMF%`-BSV*P`V+/8K0#8
ML]BN`-BSV84`V+78K0#8M=F%`-BVV*P`V+;8K0#8MMBN`-BVV84`V+?8K0#8
MM]F%`-BXV84`V+G8K`#8N=F%`-BZV*P`V+K9A0#9@=BL`-F!V*T`V8'8K@#9
M@=F%`-F!V8D`V8'9B@#9@MBM`-F"V84`V8+9B0#9@MF*`-F#V*<`V8/8K`#9
M@]BM`-F#V*X`V8/9A`#9@]F%`-F#V8D`V8/9B@#9A-BL`-F$V*T`V838K@#9
MA-F%`-F$V8D`V839B@#9A=BL`-F%V*T`V878K@#9A=F%`-F%V8D`V879B@#9
MAMBL`-F&V*T`V8;8K@#9AMF%`-F&V8D`V8;9B@#9A]BL`-F'V84`V8?9B0#9
MA]F*`-F*V*P`V8K8K0#9BMBN`-F*V84`V8K9B0#9BMF*`-BPV;``V+'9L`#9
MB=FP`"#9C-F1`"#9C=F1`"#9CMF1`"#9C]F1`"#9D-F1`"#9D=FP`-F*V938
ML0#9BMF4V+(`V8K9E-F&`-BHV+$`V*C8L@#8J-F&`-BJV+$`V*K8L@#8JMF&
M`-BKV+$`V*O8L@#8J]F&`-F%V*<`V8;8L0#9AMBR`-F&V88`V8K8L0#9BMBR
M`-F*V88`V8K9E-BN`-F*V939AP#8J-F'`-BJV8<`V+78K@#9A-F'`-F&V8<`
MV8?9L`#9BMF'`-BKV8<`V+/9AP#8M-F%`-BTV8<`V8#9CMF1`-F`V8_9D0#9
M@-F0V9$`V+?9B0#8M]F*`-BYV8D`V+G9B@#8NMF)`-BZV8H`V+/9B0#8L]F*
M`-BTV8D`V+39B@#8K=F)`-BMV8H`V*S9B0#8K-F*`-BNV8D`V*[9B@#8M=F)
M`-BUV8H`V+;9B0#8MMF*`-BTV*P`V+38K0#8M-BN`-BTV+$`V+/8L0#8M=BQ
M`-BVV+$`V*?9BP#8JMBLV84`V*K8K=BL`-BJV*W9A0#8JMBNV84`V*K9A=BL
M`-BJV878K0#8JMF%V*X`V*S9A=BM`-BMV879B@#8K=F%V8D`V+/8K=BL`-BS
MV*S8K0#8L]BLV8D`V+/9A=BM`-BSV878K`#8L]F%V84`V+78K=BM`-BUV879
MA0#8M-BMV84`V+38K-F*`-BTV878K@#8M-F%V84`V+;8K=F)`-BVV*[9A0#8
MM]F%V*T`V+?9A=F%`-BWV879B@#8N=BLV84`V+G9A=F%`-BYV879B0#8NMF%
MV84`V+K9A=F*`-BZV879B0#9@=BNV84`V8+9A=BM`-F"V879A0#9A-BMV84`
MV838K=F*`-F$V*W9B0#9A-BLV*P`V838KMF%`-F$V878K0#9A=BMV*P`V878
MK=F%`-F%V*W9B@#9A=BLV*T`V878K-F%`-F%V*[8K`#9A=BNV84`V878K-BN
M`-F'V878K`#9A]F%V84`V8;8K=F%`-F&V*W9B0#9AMBLV84`V8;8K-F)`-F&
MV879B@#9AMF%V8D`V8K9A=F%`-BHV*[9B@#8JMBLV8H`V*K8K-F)`-BJV*[9
MB@#8JMBNV8D`V*K9A=F*`-BJV879B0#8K-F%V8H`V*S8K=F)`-BLV879B0#8
ML]BNV8D`V+78K=F*`-BTV*W9B@#8MMBMV8H`V838K-F*`-F$V879B@#9BMBM
MV8H`V8K8K-F*`-F*V879B@#9A=F%V8H`V8+9A=F*`-F&V*W9B@#8N=F%V8H`
MV8/9A=F*`-F&V*S8K0#9A=BNV8H`V838K-F%`-F#V879A0#8K-BMV8H`V*W8
MK-F*`-F%V*S9B@#9@=F%V8H`V*C8K=F*`-BSV*[9B@#9AMBLV8H`V+79A-N2
M`-F"V83;D@#8I]F$V839AP#8I]F#V*C8L0#9A=BMV878KP#8M=F$V+G9A0#8
ML=BSV8C9A`#8N=F$V8K9AP#9B-BSV839A0#8M=F$V8D`V+79A-F)(-BGV839
MA-F'(-BYV839BMF'(-F(V+/9A-F%`-BLV80@V*S9A-BGV839AP#8L=N,V*?9
MA`#B@)0`XH"3`%\`>P!]`..`E`#C@)4`XX"0`..`D0#C@(H`XX"+`..`C`#C
M@(T`XX".`..`CP`L`..`@0`Z`#\`(0`C`"8`*@`M`#P`/@!<`"0`)0!``"#9
MBP#9@-F+`"#9C``@V8T`(-F.`-F`V8X`(-F/`-F`V8\`(-F0`-F`V9``(-F1
M`-F`V9$`(-F2`-F`V9(`V*$`V*<`V*@`V*D`V*H`V*L`V*P`V*T`V*X`V*\`
MV+``V+$`V+(`V+,`V+0`V+4`V+8`V+<`V+@`V+D`V+H`V8$`V8(`V8,`V80`
MV84`V88`V8<`V8@`V8H`V838I]F3`-F$V*?9E`#9A-BGV94`V838IP`B`"<`
M+P!;`%T`7@!\`'X`XJ:%`.*FA@#C@((`XX.[`.."H0#C@J,`XX*E`.."IP#C
M@JD`XX.C`..#I0#C@Z<`XX.#`..#O`#C@[,`XX*9`.."F@#"H@#"HP#"K`#"
MI@#"I0#B@JD`XI2"`.*&D`#BAI$`XH:2`.*&DP#BEJ``XI>+`/"=A9?PG86E
M`/"=A9CPG86E`/"=A9CPG86E\)V%K@#PG868\)V%I?"=A:\`\)V%F/"=A:7P
MG86P`/"=A9CPG86E\)V%L0#PG868\)V%I?"=A;(`\)V&N?"=A:4`\)V&NO"=
MA:4`\)V&N?"=A:7PG86N`/"=AKKPG86E\)V%K@#PG8:Y\)V%I?"=A:\`\)V&
MNO"=A:7PG86O`,Z1`,Z2`,Z4`,Z5`,Z6`,Z7`,Z9`,Z:`,Z;`,Z<`,Z=`,Z>
M`,Z?`,ZA`,ZC`,ZD`,ZF`,ZG`,ZH`.*(AP#.L0#.M`#.M@#.MP#.NP#.O0#.
MO@#.OP#/@P#/A`#/A0#/AP#/B`#/B0#BB((`Y+B]`.2XN`#DN8$`\*"$H@#D
MO:``Y+Z[`.6`@@#E@;H`Y8*9`.6#CP#CDIX`\*"8N@#EA90`Y86D`.6%MP#P
MH)2<`..2N0#EA:<`Y8:-`/"@E8L`Y8:7`.6&I`#DNXP`Y8:L`.6&M0#PJ8>?
M`.6(@P#CDY\`Y8B[`.6)A@#EB;(`Y8FW`..4E0#EBX<`Y8NZ`.6,A0#EC(8`
MY8V)`.6-F@#EC;,`Y8V]`.6-OP#PH*BL`.>!L`#ECXH`Y8^?`/"@K:,`Y8^K
M`.6/L0#ED(8`Y9*>`.60N`#ED8@`Y9&H`.62H@#ED[8`Y920`.65DP#EE:,`
MY9:$`.66F0#EEJL`Y9:S`.67@@#EG)8`Y9R7`.69D0#EF;0`Y:.N`.6?C@#E
MG[0`Y:"-`.6>BP#EH+(`Y:"Q`.6BK`#PH9.D`.6CL@#EH[<`Y:2&`.6DF@#E
MI*(`Y:6B`/"AFJ@`\*&;J@#EIZP`Y:B;`.6HIP#EIY@`Y:FF`..;K@#PH8VJ
M`.6LB`#EK+X`\*&GB`#EKX,`Y:^8`.6OLP#PH:R8`.6OOP#EL(8`Y;RS`..>
M@0#EL:``Y;.``.6RC0#PH;>D`.6U@P#PH;>F`.6UK@#EM:L`Y;6\`.6WH0#E
MMZ(`XZ"O`.6WO0#EN*@`Y;B]`.6YJ0#CH:(`\**&@P#CH;P`Y;JP`.6ZLP#E
MNK8`\*J.D@#PHHRQ`.B(@0#EO*(`XZ.'`/"CBK@`\*:'F@#EO:(`Y;VK`..C
MHP#EOIH`Y;^-`.6_EP#EO[D`YH*!`..DN@#CI)P`\**;E`#F@X<`YH6(`.:%
MC`#FA8X`YH6Z`.:&L@#FAJ0`YH:O`.:'G@#FB)``YHB;`.:)G0#FBK$`YHN4
M`.:-D`#PHJR,`.:,O0#FB[P`YHVH`.:.@P#FCZ0`\**OL0#FD*(`YH^%`.:.
MJ0#CJ*X`YI&I`.:1O@#FDIT`YI&W`..IK`#FE:P`\*.`B@#FEZ,`YINX`.:9
MB0#CK)D`XZR(`..KI`#EAI(`Y8:5`.:<@`#FFIP`Z(*M`.2/F0#FG)L`YIRA
M`.:=G@#FG9,`\*./@P#CK8D`YI^Z`.:>A0#FH9(`\*.1K0#FHHX`YJ"?`.:D
ME`#CKIT`YJ6"`.:FHP#FIZH`YJJH`/"CFJ,`YJN;`..PF`#FK*$`\*.BIP#F
MK90`X[&.`.:ML@#FKI\`YJZ[`/"CJHT`\*&TBP#PHZNZ`.:QC@#PH[*\`.:R
MOP#FLXT`YK&G`.:TE@#FM+X`YK6I`.:UN`#FMH4`\*.TG@#FM+0`YKBO`.:Y
MK@#CM+,`YKN+`.:[AP#PH[N1`.:WN0#FO:X`\*.]G@#PH[Z.`.:_A@#G@+D`
MYX">`.>`FP#CMI8`YX&*`.>!O0#G@;<`YX*M`/"@E*4`YX6%`/"DB:,`YX:<
M`.2.JP#GB*@`YXBU`.>)D`#PI)B(`.>*@`#GBI4`\*2<M0#PI*"4`.>-N@#G
MCHL`X[JL`.>.I0#CNK@`YY&'`.>1G`#GD;$`YY*%`.>3B@#CO)L`YY2D`/"D
ML+8`YY2^`/"DLI(`\**&GP#GF)``\*2^H0#PI+ZX`/"E@80`X[^\`.2`B`#G
MF[0`\*6#LP#PI8.R`/"EA)D`\*6$LP#GG)X`YYR?`.>=B@#D@+D`YYZ+`.2!
MA@#D@I8`\*60G0#GH8X`YZ.,`.2#HP#PI9BF`/"EFIH`\*6;A0#GIZL`Y(2O
M`.>IB@#GJ8\`\*6EO`#PI:JG`.>JK@#DB((`\*6NJP#GKX8`YZ^)`.2(IP#P
MI;*``.>SD@#DBJ``Y[.H`.>SHP#GM(``\*6^A@#GM:,`Y(R!`.>WAP#GN((`
MY[F%`.2,M`#PIHBH`/"FB8<`Y(V9`/"FBYD`Y[VZ`/"FC+X`Y[Z5`.>_N@#P
MII.:`/"FE*,`Z(&@`/"FEJ@`Z(&P`/"CC9\`Y(^5`.B"L@#HA(,`Y)"+`.B$
MO@#EJK4`\*:>IP#PIIZU`/"CCI,`\*..G`#HB(0`Z+Z>`.21JP#HBI$`Z(J+
M`.B*G0#EBK,`Z(JQ`.B*LP#HBKT`Z(NF`/"FK+P`Z(R=`.B-HP#HCJT`Z(RC
M`.B.O0#HCZ<`Z(V3`.B/B@#HCXP`Z(^<`/"FL+8`\*:UJP#PIK.5`.24JP#H
MD[$`Z).S`.B4E@#PIX^*`.B5I`#PIKRL`.25G0#DE:$`\*:^L0#PIX.2`.25
MJP#HF9``Z)FG`.B9J0#HFJD`Z)J(`.B<C@#HFZ(`Z)VY`.B<J`#HG:L`Z)Z&
M`.2UEP#HGZ$`Z*"!`.27N0#HH:``\*>9IP#HHY<`Z*.>`.28M0#HH[H`XY*[
M`/"GHJX`\*>EI@#DFKX`Y)N'`.BJH`#HJZT`Z*Z*`/"GLJ@`Z+*K`.BS@0#H
MM)L`Z+6W`/"GO*\`\*"@A`#HMXL`Z+:\`.BWL`#PH*.>`.B[E`#HO+@`\*B7
MD@#PJ)>M`.F"E`#I@[$`Z821`/"HG*X`Z82;`.F(N`#IBY<`Z8N8`.F)O`#I
MC[D`Z9"5`/"HK[H`Z9:+`.2FE0#IEK<`\*BUMP#DIZ8`Z9N#`.6VL@#IG*,`
M\*F%A0#PJ8B:`.2IK@#DJ;8`Z9^@`/"ID(H`Y*JR`/"IDI8`Z:"+`.F@J0#P
MJ9:V`.FCH@#DK+,`Z:2I`.FFIP#IIX(`Z:>^`.2OC@#PJ:RP`.FLD@#IL8``
MZ;.]`.2SC@#DLZT`Z;6G`/"J@XX`Y+.X`/"JA(4`\*J(C@#PJHJ1`.2UE@#I
MN[X`Z;R%`.F\CP#IO)8`\*J8@```````````````````H````/__``"H````
M__\"`*H```#__P8`KP```/__"`"R````__\,`+,```#__PX`M````/__$`"U
M````__\4`+@```#__Q<`N0```/__&P"Z````__\=`+P```#__Q\`O0```/__
M)0"^````__\K`,`````Q`/__P0```#4`___"````.0#__\,````]`/__Q```
M`$$`___%````10#__\<```!)`/__R````$T`___)````40#__\H```!5`/__
MRP```%D`___,````70#__\T```!A`/__S@```&4`___/````:0#__]$```!M
M`/__T@```'$`___3````=0#__]0```!Y`/__U0```'T`___6````@0#__]D`
M``"%`/__V@```(D`___;````C0#__]P```"1`/__W0```)4`___@````F0#_
M_^$```"=`/__X@```*$`___C````I0#__^0```"I`/__Y0```*T`___G````
ML0#__^@```"U`/__Z0```+D`___J````O0#__^L```#!`/__[````,4`___M
M````R0#__^X```#-`/__[P```-$`___Q````U0#___(```#9`/__\P```-T`
M___T````X0#___4```#E`/__]@```.D`___Y````[0#___H```#Q`/__^P``
M`/4`___\````^0#___T```#]`/___P````$!__\``0``!0'__P$!```)`?__
M`@$```T!__\#`0``$0'__P0!```5`?__!0$``!D!__\&`0``'0'__P<!```A
M`?__"`$``"4!__\)`0``*0'__PH!```M`?__"P$``#$!__\,`0``-0'__PT!
M```Y`?__#@$``#T!__\/`0``00'__Q(!``!%`?__$P$``$D!__\4`0``30'_
M_Q4!``!1`?__%@$``%4!__\7`0``60'__Q@!``!=`?__&0$``&$!__\:`0``
M90'__QL!``!I`?__'`$``&T!__\=`0``<0'__QX!``!U`?__'P$``'D!__\@
M`0``?0'__R$!``"!`?__(@$``(4!__\C`0``B0'__R0!``"-`?__)0$``)$!
M__\H`0``E0'__RD!``"9`?__*@$``)T!__\K`0``H0'__RP!``"E`?__+0$`
M`*D!__\N`0``K0'__R\!``"Q`?__,`$``+4!__\R`0``__^Y`3,!``#__[P!
M-`$``+\!__\U`0``PP'__S8!``#'`?__-P$``,L!__\Y`0``SP'__SH!``#3
M`?__.P$``-<!__\\`0``VP'__ST!``#?`?__/@$``.,!__\_`0``___G`4`!
M``#__^L!0P$``.\!__]$`0``\P'__T4!``#W`?__1@$``/L!__]'`0``_P'_
M_T@!```#`O__20$``/__!P),`0``"P+__TT!```/`O__3@$``!,"__]/`0``
M%P+__U`!```;`O__40$``!\"__]4`0``(P+__U4!```G`O__5@$``"L"__]7
M`0``+P+__U@!```S`O__60$``#<"__]:`0``.P+__UL!```_`O__7`$``$,"
M__]=`0``1P+__UX!``!+`O__7P$``$\"__]@`0``4P+__V$!``!7`O__8@$`
M`%L"__]C`0``7P+__V0!``!C`O__90$``&<"__]H`0``:P+__VD!``!O`O__
M:@$``',"__]K`0``=P+__VP!``![`O__;0$``'\"__]N`0``@P+__V\!``"'
M`O__<`$``(L"__]Q`0``CP+__W(!``"3`O__<P$``)<"__]T`0``FP+__W4!
M``"?`O__=@$``*,"__]W`0``IP+__W@!``"K`O__>0$``*\"__]Z`0``LP+_
M_WL!``"W`O__?`$``+L"__]]`0``OP+__WX!``##`O__?P$``/__QP*@`0``
MR0+__Z$!``#-`O__KP$``-$"__^P`0``U0+__\0!``#__]D"Q0$``/__W@+&
M`0``___C`L<!``#__^@"R`$``/__ZP+)`0``___N`LH!``#___$"RP$``/__
M]`+,`0``___W`LT!``#Z`O__S@$``/X"___/`0```@/__]`!```&`___T0$`
M``H#___2`0``#@/__],!```2`___U`$``!8#___5`0``&@/__]8!```@`___
MUP$``"8#___8`0``+`/__]D!```R`___V@$``#@#___;`0``/@/__]P!``!$
M`___W@$``$H#___?`0``4`/__^`!``!6`___X0$``%P#___B`0``8@/__^,!
M``!G`___Y@$``&P#___G`0``<`/__^@!``!T`___Z0$``'@#___J`0``?`/_
M_^L!``"``___[`$``(0#___M`0``B@/__^X!``"0`___[P$``)4#___P`0``
MF@/___$!``#__YX#\@$``/__H0/S`0``__^D`_0!``"G`___]0$``*L#___X
M`0``KP/___D!``"S`___^@$``+<#___[`0``O0/___P!``##`____0$``,@#
M___^`0``S0/___\!``#2`___``(``-<#__\!`@``VP/__P("``#?`___`P(`
M`.,#__\$`@``YP/__P4"``#K`___!@(``.\#__\'`@``\P/__P@"``#W`___
M"0(``/L#__\*`@``_P/__PL"```#!/__#`(```<$__\-`@``"P3__PX"```/
M!/__#P(``!,$__\0`@``%P3__Q$"```;!/__$@(``!\$__\3`@``(P3__Q0"
M```G!/__%0(``"L$__\6`@``+P3__Q<"```S!/__&`(``#<$__\9`@``.P3_
M_QH"```_!/__&P(``$,$__\>`@``1P3__Q\"``!+!/__)@(``$\$__\G`@``
M4P3__R@"``!7!/__*0(``%L$__\J`@``7P3__RL"``!E!/__+`(``&L$__\M
M`@``<03__RX"``!W!/__+P(``'L$__\P`@``?P3__S$"``"%!/__,@(``(L$
M__\S`@``CP3__[`"``#__Y,$L0(``/__E02R`@``__^8!+,"``#__YH$M`(`
M`/__G`2U`@``__^?!+8"``#__Z($MP(``/__I02X`@``__^G!-@"``#__ZD$
MV0(``/__K03:`@``__^Q!-L"``#__[4$W`(``/__N03=`@``__^]!.`"``#_
M_\$$X0(``/__Q`3B`@``___'`N,"``#__\8$Y`(``/__R`1``P``RP3__T$#
M``#.!/__0P,``-$$__]$`P``U`3__W0#``#9!/__>@,``/__W`1^`P``X`3_
M_X0#``#__Q``A0,``.($YP2&`P``[03__X<#``#R!/__B`,``/4$__^)`P``
M^@3__XH#``#_!/__C`,```0%__^.`P``"07__X\#```.!?__D`,``!,%__^J
M`P``&@7__ZL#```?!?__K`,``"0%__^M`P``*07__ZX#```N!?__KP,``#,%
M__^P`P``.`7__\H#```_!?__RP,``$0%___,`P``207__\T#``!.!?__S@,`
M`%,%___0`P``__]8!=$#``#__UL%T@,``/__7@73`P``804)!=0#``!F!1\%
MU0,``/__:P76`P``__]N!?`#``#__W$%\0,``/__=`7R`P``__]W!?0#``#_
M_WH%]0,``/__?04`!```@`7__P$$``"%!?__`P0``(H%__\'!```CP7__PP$
M``"4!?__#00``)D%__\.!```G@7__QD$``"C!?__.00``*@%__]0!```K07_
M_U$$``"R!?__4P0``+<%__]7!```O`7__UP$``#!!?__700``,8%__]>!```
MRP7__W8$``#0!?__=P0``-4%___!!```V@7__\($``#?!?__T`0``.0%___1
M!```Z07__]($``#N!?__TP0``/,%___6!```^`7__]<$``#]!?__V@0```(&
M___;!```!P;__]P$```,!O__W00``!$&___>!```%@;__]\$```;!O__X@0`
M`"`&___C!```)0;__^0$```J!O__Y00``"\&___F!```-`;__^<$```Y!O__
MZ@0``#X&___K!```0P;__^P$``!(!O__[00``$T&___N!```4@;__^\$``!7
M!O__\`0``%P&___Q!```80;___($``!F!O__\P0``&L&___T!```<`;___4$
M``!U!O__^`0``'H&___Y!```?P;__X<%``#__X0&(@8``(D&__\C!@``C@;_
M_R0&``"3!O__)08``)@&__\F!@``G0;__W4&``#__Z(&=@8``/__IP9W!@``
M__^L!G@&``#__[$&P`8``+8&___"!@``NP;__],&``#`!O__*0D``,4&__\Q
M"0``S`;__S0)``#3!O__6`D``-H&__]9"0``X0;__UH)``#H!O__6PD``.\&
M__]<"0``]@;__UT)``#]!O__7@D```0'__]?"0``"P?__\L)```2!___S`D`
M`!D'___<"0``(`?__]T)```G!___WPD``"X'__\S"@``-0?__S8*```\!___
M60H``$,'__]:"@``2@?__UL*``!1!___7@H``%@'__]("P``7P?__TL+``!F
M!___3`L``&T'__]<"P``=`?__UT+``![!___E`L``(('___*"P``B0?__\L+
M``"0!___S`L``)<'__](#```G@?__\`,``"E!___QPP``*P'___(#```LP?_
M_\H,``"Z!___RPP``,$'__]*#0``RP?__TL-``#2!___3`T``-D'___:#0``
MX`?__]P-``#G!___W0T``.X'___>#0``^`?__S,.``#___\'LPX``/__!@C<
M#@``__\-"-T.``#__Q0(#`\``/__&PA##P``'PC__TT/```F"/__4@\``"T(
M__]7#P``-`C__UP/```["/__:0\``$((__]S#P``20C__W4/``!0"/__=@\`
M`%<(__]W#P``__]>"'@/``!H"/__>0\``/__;PB!#P``>0C__Y,/``"`"/__
MG0\``(<(__^B#P``C@C__Z</``"5"/__K`\``)P(__^Y#P``HPC__R80``"J
M"/__`!X``+$(__\!'@``M0C__P(>``"Y"/__`QX``+T(__\$'@``P0C__P4>
M``#%"/__!AX``,D(__\''@``S0C__P@>``#1"/__"1X``-<(__\*'@``W0C_
M_PL>``#A"/__#!X``.4(__\-'@``Z0C__PX>``#M"/__#QX``/$(__\0'@``
M]0C__Q$>``#Y"/__$AX``/T(__\3'@```0G__Q0>```%"?__%1X```L)__\6
M'@``$0G__Q<>```7"?__&!X``!T)__\9'@``(0G__QH>```E"?__&QX``"D)
M__\<'@``+0G__QT>```S"?__'AX``#D)__\?'@``/0G__R`>``!!"?__(1X`
M`$4)__\B'@``20G__R,>``!-"?__)!X``%$)__\E'@``50G__R8>``!9"?__
M)QX``%T)__\H'@``80G__RD>``!E"?__*AX``&D)__\K'@``;0G__RP>``!Q
M"?__+1X``'4)__\N'@``>0G__R\>``!_"?__,!X``(4)__\Q'@``B0G__S(>
M``"-"?__,QX``)$)__\T'@``E0G__S4>``"9"?__-AX``)T)__\W'@``H0G_
M_S@>``"E"?__.1X``*L)__\Z'@``L0G__SL>``"U"?__/!X``+D)__\]'@``
MO0G__SX>``#!"?__/QX``,4)__]`'@``R0G__T$>``#-"?__0AX``-$)__]#
M'@``U0G__T0>``#9"?__11X``-T)__]&'@``X0G__T<>``#E"?__2!X``.D)
M__])'@``[0G__TH>``#Q"?__2QX``/4)__],'@``^0G__TT>``#_"?__3AX`
M``4*__]/'@``"PK__U`>```1"O__41X``!<*__]2'@``'0K__U,>```C"O__
M5!X``"D*__]5'@``+0K__U8>```Q"O__5QX``#4*__]8'@``.0K__UD>```]
M"O__6AX``$$*__];'@``10K__UP>``!)"O__71X``$\*__]>'@``50K__U\>
M``!9"O__8!X``%T*__]A'@``80K__V(>``!E"O__8QX``&D*__]D'@``;0K_
M_V4>``!S"O__9AX``'D*__]G'@``?PK__V@>``"%"O__:1X``(L*__]J'@``
MD0K__VL>``"5"O__;!X``)D*__]M'@``G0K__VX>``"A"O__;QX``*4*__]P
M'@``J0K__W$>``"M"O__<AX``+$*__]S'@``M0K__W0>``"Y"O__=1X``+T*
M__]V'@``P0K__W<>``#%"O__>!X``,D*__]Y'@``SPK__WH>``#5"O__>QX`
M`-L*__]\'@``X0K__WT>``#E"O__?AX``.D*__]_'@``[0K__X`>``#Q"O__
M@1X``/4*__^"'@``^0K__X,>``#]"O__A!X```$+__^%'@``!0O__X8>```)
M"___AQX```T+__^('@``$0O__XD>```5"___BAX``!D+__^+'@``'0O__XP>
M```A"___C1X``"4+__^.'@``*0O__X\>```M"___D!X``#$+__^1'@``-0O_
M_Y(>```Y"___DQX``#T+__^4'@``00O__Y4>``!%"___EAX``$D+__^7'@``
M30O__Y@>``!1"___F1X``%4+__^:'@``__]9"YL>``!="V$*H!X``&(+__^A
M'@``9@O__Z(>``!J"___HQX``&X+__^D'@``<@O__Z4>``!X"___IAX``'X+
M__^G'@``A`O__Z@>``"*"___J1X``)`+__^J'@``E@O__ZL>``"<"___K!X`
M`*(+__^M'@``J`O__ZX>``"N"___KQX``+0+__^P'@``N@O__[$>``#`"___
MLAX``,8+__^S'@``S`O__[0>``#2"___M1X``-@+__^V'@``W@O__[<>``#D
M"___N!X``.H+__^Y'@``[@O__[H>``#R"___NQX``/8+__^\'@``^@O__[T>
M``#^"___OAX```(,__^_'@``"`S__\`>```.#/__P1X``!0,___"'@``&@S_
M_\,>```@#/__Q!X``"8,___%'@``+`S__\8>```R#/__QQX``#@,___('@``
M/@S__\D>``!"#/__RAX``$8,___+'@``2@S__\P>``!.#/__S1X``%(,___.
M'@``5@S__\\>``!:#/__T!X``%X,___1'@``9`S__](>``!J#/__TQX``'`,
M___4'@``=@S__]4>``!\#/__UAX``((,___7'@``B`S__]@>``".#/__V1X`
M`)0,___:'@``F@S__]L>``"@#/__W!X``*8,___='@``K`S__]X>``"R#/__
MWQX``+@,___@'@``O@S__^$>``#$#/__XAX``,H,___C'@``T`S__^0>``#6
M#/__Y1X``-H,___F'@``W@S__^<>``#B#/__Z!X``.8,___I'@``[`S__^H>
M``#R#/__ZQX``/@,___L'@``_@S__^T>```$#?__[AX```H-___O'@``$`W_
M__`>```6#?__\1X``!P-___R'@``(@W___,>```F#?__]!X``"H-___U'@``
M+@W___8>```R#?__]QX``#8-___X'@``.@W___D>```^#?__`!\``$(-__\!
M'P``1PW__P(?``!,#?__`Q\``%,-__\$'P``6@W__P4?``!A#?__!A\``&@-
M__\''P``;PW__P@?``!V#?__"1\``'L-__\*'P``@`W__PL?``"'#?__#!\`
M`(X-__\-'P``E0W__PX?``"<#?__#Q\``*,-__\0'P``J@W__Q$?``"O#?__
M$A\``+0-__\3'P``NPW__Q0?``#"#?__%1\``,D-__\8'P``T`W__QD?``#5
M#?__&A\``-H-__\;'P``X0W__QP?``#H#?__'1\``.\-__\@'P``]@W__R$?
M``#[#?__(A\````.__\C'P``!P[__R0?```.#O__)1\``!4.__\F'P``'`[_
M_R<?```C#O__*!\``"H.__\I'P``+P[__RH?```T#O__*Q\``#L.__\L'P``
M0@[__RT?``!)#O__+A\``%`.__\O'P``5P[__S`?``!>#O__,1\``&,.__\R
M'P``:`[__S,?``!O#O__-!\``'8.__\U'P``?0[__S8?``"$#O__-Q\``(L.
M__\X'P``D@[__SD?``"7#O__.A\``)P.__\['P``HP[__SP?``"J#O__/1\`
M`+$.__\^'P``N`[__S\?``"_#O__0!\``,8.__]!'P``RP[__T(?``#0#O__
M0Q\``-<.__]$'P``W@[__T4?``#E#O__2!\``.P.__])'P``\0[__TH?``#V
M#O__2Q\``/T.__],'P``!`___TT?```+#___4!\``!(/__]1'P``%P___U(?
M```<#___4Q\``",/__]4'P``*@___U4?```Q#___5A\``#@/__]7'P``/P__
M_UD?``!&#___6Q\``$L/__]='P``4@___U\?``!9#___8!\``&`/__]A'P``
M90___V(?``!J#___8Q\``'$/__]D'P``>`___V4?``!_#___9A\``(8/__]G
M'P``C0___V@?``"4#___:1\``)D/__]J'P``G@___VL?``"E#___;!\``*P/
M__]M'P``LP___VX?``"Z#___;Q\``,$/__]P'P``R`___W$?```D!?__<A\`
M`,T/__]S'P``*07__W0?``#2#___=1\``"X%__]V'P``UP___W<?```S!?__
M>!\``-P/__]Y'P``207__WH?``#A#___>Q\``$X%__]\'P``Y@___WT?``!3
M!?__@!\``.L/__^!'P``\@___X(?``#Y#___@Q\```(0__^$'P``"Q#__X4?
M```4$/__AA\``!T0__^''P``)A#__X@?```O$/__B1\``#80__^*'P``/1#_
M_XL?``!&$/__C!\``$\0__^-'P``6!#__XX?``!A$/__CQ\``&H0__^0'P``
M<Q#__Y$?``!Z$/__DA\``($0__^3'P``BA#__Y0?``"3$/__E1\``)P0__^6
M'P``I1#__Y<?``"N$/__F!\``+<0__^9'P``OA#__YH?``#%$/__FQ\``,X0
M__^<'P``UQ#__YT?``#@$/__GA\``.D0__^?'P``\A#__Z`?``#[$/__H1\`
M``(1__^B'P``"1'__Z,?```2$?__I!\``!L1__^E'P``)!'__Z8?```M$?__
MIQ\``#81__^H'P``/Q'__ZD?``!&$?__JA\``$T1__^K'P``5A'__ZP?``!?
M$?__K1\``&@1__^N'P``<1'__Z\?``!Z$?__L!\``(,1__^Q'P``B!'__[(?
M``"-$?__LQ\``)01__^T'P``F1'__[8?``"@$?__MQ\``*41__^X'P``K!'_
M_[D?``"Q$?__NA\``+81__^['P``[03__[P?``"[$?__O1\``/__P!&^'P``
MQ!'__[\?``#__\`1P!\``/__QQ'!'P``RQ'0$<(?``#6$?__PQ\``-T1___$
M'P``XA'__\8?``#I$?__QQ\``.X1___('P``]1'__\D?``#U!/__RA\``/H1
M___+'P``^@3__\P?``#_$?__S1\```02"A+.'P``$!(6$L\?```<$B(2T!\`
M`"@2___1'P``+1+__](?```R$O__TQ\``!,%___6'P``.1+__]<?```^$O__
MV!\``$42___9'P``2A+__]H?``!/$O__VQ\``/\$___='P``5!):$MX?``!@
M$F82WQ\``&P2<A+@'P``>!+__^$?``!]$O__XA\``((2___C'P``.`7__^0?
M``")$O__Y1\``(X2___F'P``DQ+__^<?``"8$O__Z!\``)\2___I'P``I!+_
M_^H?``"I$O__ZQ\```D%___L'P``KA+__^T?``"S$K@2[A\``.($YP3O'P``
MOA+___(?``#`$O__\Q\``,<2___T'P``S!+___8?``#3$O__]Q\``-@2___X
M'P``WQ+___D?```$!?__^A\``.02___['P``#@7___P?``#I$O___1\``.X2
M$`#^'P``___Q$@`@``#U$@```2```/D2```"(```__\```,@``#__P``!"``
M`/__```%(```__\```8@``#__P``!R```/__```((```__\```D@``#__P``
M"B```/__```1(```___]$A<@``#__P$3)"```/__!1,E(```__\'$R8@``#_
M_PH3+R```/__```S(```__\.$S0@``#__Q43-B```/__'Q,W(```__\F$SP@
M``#__S`3/B```/__,Q-'(```__\W$T@@``#__SH322```/__/1-7(```__]`
M$U\@``#__P``<"```/__31-Q(```__]/$W0@``#__U$3=2```/__4Q-V(```
M__]5$W<@``#__U<3>"```/__61-Y(```__];$WH@``#__UT3>R```/__7Q-\
M(```__]C$WT@``#__V43?B```/__9Q-_(```__]I$X`@``#__TT3@2```/__
M&P""(```__\,`(,@``#__PX`A"```/__41.%(```__]3$X8@``#__U43AR``
M`/__5Q.((```__]9$XD@``#__UL3BB```/__71.+(```__]?$XP@``#__V,3
MC2```/__91..(```__]G$Z@@``#__VL3`"$``/__;A,!(0``__]R$P(A``#_
M_W83`R$``/__>!,%(0``__]\$P8A``#__X`3!R$``/__A!,)(0``__^'$PHA
M``#__XL3"R$``/__C1,,(0``__^-$PTA``#__XT3#B$``/__DP0/(0``__^/
M$Q`A``#__Y(3$2$``/__DA,2(0``__^4$Q,A``#__\0$%2$``/__EA,6(0``
M__^8$QDA``#__YL3&B$``/__G1,;(0``__^?$QPA``#__Y\3'2$``/__GQ,@
M(0``__^A$R$A``#__Z03(B$``/__J!,D(0``__^K$R8A``"M$___*"$``/__
MJQ,J(0``L!/__RLA``!%`/__+"$``/__LA,M(0``__]V$R\A``#__[03,"$`
M`/__MA,Q(0``__^X$S,A``#__[H3-"$``/__'0`U(0``__^\$S8A``#__[\3
M-R$``/__PA,X(0``___%$SDA``#__T\3/2$``/__R!,^(0``___+$S\A``#_
M_\X30"$``/__T1-%(0``___5$T8A``#__]<31R$``/__M!-((0``__]/$TDA
M``#__Y@$4R$``/__V1-4(0``___?$U4A``#__^435B$``/__ZQ-7(0``___Q
M$U@A``#___<362$``/___1-:(0``__\#%%LA``#__PD47"$``/__#Q1=(0``
M__\5%%XA``#__QL47R$``/__(11@(0``__^2$V$A``#__R848B$``/__*11C
M(0``__\M%&0A``#__S`492$``/__,A1F(0``__\U%&<A``#__SD4:"$``/__
M/A1I(0``__]!%&HA``#__T,4:R$``/__1A1L(0``__^4$VTA``#__W83;B$`
M`/__U1-O(0``__^Z$W`A``#__T\3<2$``/__2A1R(0``__]-%',A``#__U$4
M="$``/__5!1U(0``__]6%'8A``#__UD4=R$``/__711X(0``__]B%'DA``#_
M_\8$>B$``/__911[(0``__]H%'PA``#__\0$?2$``/__;!1^(0``___7$W\A
M``#__VX4FB$``'`4__^;(0``=A3__ZXA``!\%/__S2$``((4___.(0``B!3_
M_\\A``".%/__!"(``)04__\)(@``FA3__PPB``"@%/__)"(``*84__\F(@``
MK!3__RPB``#__[(4+2(``/__N10O(@``___#%#`B``#__\H402(``-04__]$
M(@``VA3__T<B``#@%/__22(``.84__]@(@``[!3__V(B``#P%/__;2(``/84
M__]N(@``_!3__V\B````%?__<"(```05__]Q(@``"A7__W0B```0%?__=2(`
M`!85__]X(@``'!7__WDB```B%?__@"(``"@5__^!(@``+A7__X0B```T%?__
MA2(``#H5__^((@``0!7__XDB``!&%?__K"(``$P5__^M(@``4A7__ZXB``!8
M%?__KR(``%X5___@(@``9!7__^$B``!J%?__XB(``'`5___C(@``=A7__^HB
M``!\%?__ZR(``((5___L(@``B!7__^TB``".%?__*2,``)05__\J(P``F!7_
M_V`D``#__QL`820``/__#`!B)```__\.`&,D``#__U$39"0``/__4Q-E)```
M__]5$V8D``#__U<39R0``/__61-H)```__];$VDD``#__YP5:B0``/__GQ5K
M)```__^B%6PD``#__Z45;20``/__J!5N)```__^K%6\D``#__ZX5<"0``/__
ML15Q)```__^T%7(D``#__[<5<R0``/__NA5T)```__^]%74D``#__\$5=B0`
M`/__Q15W)```___)%7@D``#__\T5>20``/__T15Z)```___5%7LD``#__]D5
M?"0``/__W15])```___A%7XD``#__^85?R0``/__ZQ6`)```___P%8$D``#_
M__45@B0``/__^A6#)```____%80D``#__P06A20``/__"1:&)```__\.%H<D
M``#__Q,6B"0``/__&!:))```__\;%HHD``#__QX6BR0``/__(1:,)```__\D
M%HTD``#__R<6CB0``/__*A:/)```__\M%I`D``#__S`6D20``/__,Q:2)```
M__\W%I,D``#__SL6E"0``/__/Q:5)```__]#%I8D``#__T<6ER0``/__2Q:8
M)```__]/%IDD``#__U,6FB0``/__5Q:;)```__];%IPD``#__U\6G20``/__
M8Q:>)```__]G%I\D``#__VL6H"0``/__;Q:A)```__]S%J(D``#__W<6HR0`
M`/__>Q:D)```__]_%J4D``#__X,6IB0``/__AQ:G)```__^+%J@D``#__X\6
MJ20``/__DQ:J)```__^7%JLD``#__YL6K"0``/__GQ:M)```__^C%JXD``#_
M_Z<6KR0``/__JQ:P)```__^O%K$D``#__[,6LB0``/__MQ:S)```__^[%K0D
M``#__[\6M20``/__PQ:V)```___'%K<D``#__[(3N"0``/__=A.Y)```___5
M$[HD``#__[83NR0``/__N!.\)```___)%KTD``#__XT3OB0``/__DA._)```
M___+%L`D``#__[`3P20``/__E!/")```__^Z$\,D``#__Y83Q"0``/__S1;%
M)```__^;$\8D``#__YT3QR0``/__GQ/()```___/%LDD``#__]$6RB0``/__
MTQ;+)```__\P%,PD``#__]46S20``/__013.)```___7%L\D``#__ZL3T"0`
M`/__!@#1)```___9%M(D``#__VP4TR0``/__UQ/4)```__^T$]4D``#__]L6
MUB0``/__BQ/7)```__^3!-@D``#__T\3V20``/__F`3:)```___=%MLD``#_
M_\0$W"0``/__;A3=)```__]I$]XD``#__QT`WR0``/__WQ;@)```___A%N$D
M``#__YH$XB0``/__QP+C)```___C%N0D``#__^46Y20``/__5!3F)```__^E
M!.<D``#__\8$Z"0``/__IP3I)```___G%NHD``#__TT3#"H``/__Z19T*@``
M___V%G4J``#___H6=BH``/___1;<*@```1?__Y\N``#__P<7\RX``/__"Q<`
M+P``__\/%P$O``#__Q,7`B\``/__%Q<#+P``__\;%P0O``#__Q\7!2\``/__
M(Q<&+P``__\G%P<O``#__RL7""\``/__+Q<)+P``__\S%PHO``#__S<7"R\`
M`/__.Q<,+P``__\_%PTO``#__T,7#B\``/__1Q</+P``__]+%Q`O``#__T\7
M$2\``/__4Q<2+P``__]7%Q,O``#__UL7%"\``/__7Q<5+P``__]C%Q8O``#_
M_V<7%R\``/__:Q<8+P``__]O%QDO``#__W,7&B\``/__=Q<;+P``__][%QPO
M``#__W\7'2\``/__@Q<>+P``__^'%Q\O``#__XL7("\``/__CQ<A+P``__^3
M%R(O``#__Y<7(R\``/__FQ<D+P``__^?%R4O``#__Z,7)B\``/__IQ<G+P``
M__^K%R@O``#__Z\7*2\``/__LQ<J+P``__^W%RLO``#__[L7+"\``/__OQ<M
M+P``___#%RXO``#__\<7+R\``/__RQ<P+P``___/%S$O``#__],7,B\``/__
MUQ<S+P``___;%S0O``#__]\7-2\``/__XQ<V+P``___G%S<O``#__^L7."\`
M`/__[Q<Y+P``___S%SHO``#___<7.R\``/__^Q<\+P``____%STO``#__P,8
M/B\``/__!Q@_+P``__\+&$`O``#__P\802\``/__$QA"+P``__\7&$,O``#_
M_QL81"\``/__'QA%+P``__\C&$8O``#__R<81R\``/__*QA(+P``__\O&$DO
M``#__S,82B\``/__-QA++P``__\[&$PO``#__S\832\``/__0QA.+P``__]'
M&$\O``#__TL84"\``/__3QA1+P``__]3&%(O``#__U<84R\``/__6QA4+P``
M__]?&%4O``#__V,85B\``/__9QA7+P``__]K&%@O``#__V\862\``/__<QA:
M+P``__]W&%LO``#__WL87"\``/__?QA=+P``__^#&%XO``#__X<87R\``/__
MBQA@+P``__^/&&$O``#__Y,88B\``/__EQAC+P``__^;&&0O``#__Y\892\`
M`/__HQAF+P``__^G&&<O``#__ZL8:"\``/__KQAI+P``__^S&&HO``#__[<8
M:R\``/__NQAL+P``__^_&&TO``#__\,8;B\``/__QQAO+P``___+&'`O``#_
M_\\8<2\``/__TQAR+P``___7&',O``#__]L8="\``/__WQAU+P``___C&'8O
M``#__^<8=R\``/__ZQAX+P``___O&'DO``#___,8>B\``/__]QA[+P``___[
M&'PO``#___\8?2\``/__`QE^+P``__\'&7\O``#__PL9@"\``/__#QF!+P``
M__\3&8(O``#__Q<9@R\``/__&QF$+P``__\?&84O``#__R,9AB\``/__)QF'
M+P``__\K&8@O``#__R\9B2\``/__,QF*+P``__\W&8LO``#__SL9C"\``/__
M/QF-+P``__]#&8XO``#__T<9CR\``/__2QF0+P``__]/&9$O``#__U,9DB\`
M`/__5QF3+P``__];&90O``#__U\9E2\``/__8QF6+P``__]G&9<O``#__VL9
MF"\``/__;QF9+P``__]S&9HO``#__W<9FR\``/__>QF<+P``__]_&9TO``#_
M_X,9GB\``/__AQF?+P``__^+&:`O``#__X\9H2\``/__DQFB+P``__^7&:,O
M``#__YL9I"\``/__GQFE+P``__^C&:8O``#__Z<9IR\``/__JQFH+P``__^O
M&:DO``#__[,9JB\``/__MQFK+P``__^[&:PO``#__[\9K2\``/__PQFN+P``
M___'&:\O``#__\L9L"\``/__SQFQ+P``___3&;(O``#__]<9LR\``/__VQFT
M+P``___?&;4O``#__^,9MB\``/__YQFW+P``___K&;@O``#__^\9N2\``/__
M\QFZ+P``___W&;LO``#___L9O"\``/___QF]+P``__\#&KXO``#__P<:OR\`
M`/__"QK`+P``__\/&L$O``#__Q,:PB\``/__%QK#+P``__\;&L0O``#__Q\:
MQ2\``/__(QK&+P``__\G&L<O``#__RL:R"\``/__+QK)+P``__\S&LHO``#_
M_S<:RR\``/__.QK,+P``__\_&LTO``#__T,:SB\``/__1QK/+P``__]+&M`O
M``#__T\:T2\``/__4QK2+P``__]7&M,O``#__UL:U"\``/__7QK5+P``__]C
M&@`P``#__P``-C```/__9QHX,```__]K%SDP``#__VL:.C```/__;QI,,```
M<QK__TXP``!Z&O__4#```($:__]2,```B!K__U0P``"/&O__5C```)8:__]8
M,```G1K__UHP``"D&O__7#```*L:__]>,```LAK__V`P``"Y&O__8C```,`:
M__]E,```QQK__V<P``#.&O__:3```-4:__]P,```W!K__W$P``#C&O__<S``
M`.H:__]T,```\1K__W8P``#X&O__=S```/\:__]Y,```!AO__WHP```-&___
M?#```!0;__]],```&QO__Y0P```B&___FS```/__*1N<,```__\N&YXP```S
M&___GS```/__.ANL,```01O__ZXP``!(&___L#```$\;__^R,```5AO__[0P
M``!=&___MC```&0;__^X,```:QO__[HP``!R&___O#```'D;__^^,```@!O_
M_\`P``"'&___PC```(X;___%,```E1O__\<P``"<&___R3```*,;___0,```
MJAO__]$P``"Q&___TS```+@;___4,```OQO__]8P``#&&___US```,T;___9
M,```U!O__]HP``#;&___W#```.(;___=,```Z1O___0P``#P&___]S```/<;
M___X,```_AO___DP```%'/__^C````P<___^,```$QS___\P``#__QH<,3$`
M`/__(1PR,0``__\E'#,Q``#__RD<-#$``/__+1PU,0``__\Q'#8Q``#__S4<
M-S$``/__.1PX,0``__\]'#DQ``#__T$<.C$``/__11P[,0``__])'#PQ``#_
M_TT</3$``/__41P^,0``__]5'#\Q``#__UD<0#$``/__71Q!,0``__]A'$(Q
M``#__V4<0S$``/__:1Q$,0``__]M'$4Q``#__W$<1C$``/__=1Q',0``__]Y
M'$@Q``#__WT<23$``/__@1Q*,0``__^%'$LQ``#__XD<3#$``/__C1Q-,0``
M__^1'$XQ``#__Y4<3S$``/__F1Q0,0``__^='%$Q``#__Z$<4C$``/__I1Q3
M,0``__^I'%0Q``#__ZT<53$``/__L1Q6,0``__^U'%<Q``#__[D<6#$``/__
MO1Q9,0``___!'%HQ``#__\4<6S$``/__R1Q<,0``___-'%TQ``#__]$<7C$`
M`/__U1Q?,0``___9'&`Q``#__]T<83$``/__X1QB,0``___E'&,Q``#__^D<
M9#$``/__[1QE,0``___Q'&8Q``#___4<9S$``/__^1QH,0``___]'&DQ``#_
M_P$=:C$``/__!1UK,0``__\)'6PQ``#__PT=;3$``/__$1UN,0``__\5'6\Q
M``#__QD=<#$``/__'1UQ,0``__\A'7(Q``#__R4=<S$``/__*1UT,0``__\M
M'74Q``#__S$==C$``/__-1UW,0``__\Y'7@Q``#__ST=>3$``/__01UZ,0``
M__]%'7LQ``#__TD=?#$``/__31U],0``__]1'7XQ``#__U4=?S$``/__61V`
M,0``__]='8$Q``#__V$=@C$``/__91V#,0``__]I'80Q``#__VT=A3$``/__
M<1V&,0``__]U'8<Q``#__WD=B#$``/__?1V),0``__^!'8HQ``#__X4=BS$`
M`/__B1V,,0``__^-'8TQ``#__Y$=CC$``/__E1V2,0``__\/%Y,Q``#__R<7
ME#$``/__F1V5,0``__^='98Q``#__Z$=ES$``/__I1V8,0``__^I'9DQ``#_
M_ZT=FC$``/__'Q>;,0``__^Q'9PQ``#__[4=G3$``/__N1V>,0``__^]'9\Q
M``#__R\7`#(``/__P1T!,@``___''0(R``#__\T=`S(``/__TQT$,@``___9
M'04R``#__]\=!C(``/__Y1T',@``___K'0@R``#___$="3(``/__]QT*,@``
M___]'0LR``#__P,>##(``/__"1X-,@``__\/'@XR``#__Q4>#S(``/__'AX0
M,@``__\G'A$R``#__S`>$C(``/__.1X3,@``__]"'A0R``#__TL>%3(``/__
M5!X6,@``__]='A<R``#__V8>&#(``/__;QX9,@``__]X'AHR``#__X$>&S(`
M`/__BAX<,@``__^3'B`R``#__YP>(3(``/__HAXB,@``__^H'B,R``#__ZX>
M)#(``/__M!XE,@``__^Z'B8R``#__\`>)S(``/__QAXH,@``___,'BDR``#_
M_](>*C(``/__V!XK,@``___>'BPR``#__^0>+3(``/__ZAXN,@``___P'B\R
M``#___8>,#(``/___!XQ,@``__\"'S(R``#__P@?,S(``/__#A\T,@``__\4
M'S4R``#__QH?-C(``/__(!\W,@``__\F'S@R``#__RP?.3(``/__,A\Z,@``
M__\X'SLR``#__SX?/#(``/__1!\],@``__]*'SXR``#__U`?/S(``/__5A]`
M,@``__]<'T$R``#__V(?0C(``/__:!]#,@``__]N'U$R``#__W0?4C(``/__
M=Q]3,@``__]Z'U0R``#__WT?53(``/__@!]6,@``__^#'U<R``#__X8?6#(`
M`/__B1]9,@``__^,'UHR``#__X\?6S(``/__DA]<,@``__^5'UTR``#__Y@?
M7C(``/__FQ]?,@``__^>'V`R``#__R$<83(``/__+1QB,@``__\Y'&,R``#_
M_T$<9#(``/__81QE,@``__]E'&8R``#__W$<9S(``/__>1QH,@``__]]'&DR
M``#__X4<:C(``/__B1QK,@``__^-'&PR``#__Y$<;3(``/__E1QN,@``__^A
M'V\R``#__Z@?<#(``/__KQ]Q,@``__^V'W(R``#__[T?<S(``/__Q!]T,@``
M___+'W4R``#__](?=C(``/__V1]W,@``___@'W@R``#__^<?>3(``/__[A]Z
M,@``___U'WLR``#___P?@#(``/__#Q>!,@``__\G%X(R``#__YD=@S(``/__
MG1V$,@``__\#((4R``#__P<@AC(``/__"R"',@``__\[%X@R``#__P\@B3(`
M`/__:Q>*,@``__\S&(LR``#__V,8C#(``/__7QB-,@``__\W&(XR``#__Z<9
MCS(``/__BQ>0,@``__\K&)$R``#__Q,@DC(``/__%R"3,@``__\;()0R``#_
M_Q\@E3(``/__(R"6,@``__\G()<R``#__RL@F#(``/__+R"9,@``__\S()HR
M``#__S<@FS(``/__HQ><,@``__\[()TR``#__S\@GC(``/__0R"?,@``__]'
M(*`R``#__TL@H3(``/__3R"B,@``__]3(*,R``#__U<@I#(``/__H1VE,@``
M__^E':8R``#__ZD=IS(``/__6R"H,@``__]?(*DR``#__V,@JC(``/__9R"K
M,@``__]K(*PR``#__V\@K3(``/__<R"N,@``__]W(*\R``#__WL@L#(``/__
M?R"Q,@``__^#(+(R``#__X8@LS(``/__B2"T,@``__^,(+4R``#__X\@MC(`
M`/__DB"W,@``__^5(+@R``#__Y@@N3(``/__FR"Z,@``__^>(+LR``#__Z$@
MO#(``/__I""],@``__^G(+XR``#__ZH@OS(``/__K2#`,@``__^P(,$R``#_
M_[4@PC(``/__NB##,@``__^_(,0R``#__\0@Q3(``/__R2#&,@``___.(,<R
M``#__],@R#(``/__V"#),@``___=(,HR``#__^,@RS(``/__Z2#0,@``___O
M(-$R``#___,@TC(``/__]R#3,@``___[(-0R``#___\@U3(``/__`R'6,@``
M__\'(=<R``#__PLAV#(``/__#R'9,@``__\3(=HR``#__Q<AVS(``/__&R'<
M,@``__\?(=TR``#__R,AWC(``/__)R'?,@``__\K(>`R``#__R\AX3(``/__
M,R'B,@``__\W(>,R``#__SLAY#(``/__/R'E,@``__]#(>8R``#__T<AYS(`
M`/__2R'H,@``__]/(>DR``#__U,AZC(``/__5R'K,@``__];(>PR``#__U\A
M[3(``/__8R'N,@``__]G(>\R``#__VLA\#(``/__;R'Q,@``__]S(?(R``#_
M_W<A\S(``/__>R'T,@``__]_(?4R``#__X,A]C(``/__AR'W,@``__^+(?@R
M``#__X\A^3(``/__DR'Z,@``__^7(?LR``#__YLA_#(``/__GR'],@``__^C
M(?XR``#__Z<A`#,``/__JR$!,P``__^[(0(S``#__\@A`S,``/__V"$$,P``
M___B(04S``#___(A!C,``/___"$',P``__\&(@@S``#__QDB"3,``/__)B(*
M,P``__\P(@LS``#__SHB##,``/__1"(-,P``__]1(@XS``#__UXB#S,``/__
M:R(0,P``__]X(A$S``#__X4B$C,``/__DB(3,P``__^?(A0S``#__[(B%3,`
M`/__N2(6,P``___,(A<S``#__]\B&#,``/__[R(9,P``___\(AHS``#__P\C
M&S,``/__(B,<,P``__\O(QTS``#__SDC'C,``/__0R,?,P``__]0(R`S``#_
M_UTC(3,``/__;2,B,P``__]](R,S``#__X<C)#,``/__D2,E,P``__^>(R8S
M``#__Z@C)S,``/__LB,H,P``__^Y(RDS``#__\`C*C,``/__RB,K,P``___4
M(RPS``#__^<C+3,``/__]",N,P``__\$)"\S``#__Q<D,#,``/__)"0Q,P``
M__\N)#(S``#__S@D,S,``/__2R0T,P``__]8)#4S``#__VLD-C,``/__=20W
M,P``__^%)#@S``#__X\D.3,``/__G"0Z,P``__^F)#LS``#__[,D/#,``/__
MPR0],P``___0)#XS``#__^`D/S,``/__[21`,P``___T)$$S``#__P0E0C,`
M`/__#B5#,P``__\8)40S``#__R4E13,``/__+R5&,P``__\Y)4<S``#__T,E
M2#,``/__4R5),P``__]@)4HS``#__V<E2S,``/__>B5,,P``__^$)4TS``#_
M_Y0E3C,``/__H25/,P``__^N)5`S``#__[@E43,``/__PB52,P``___/)5,S
M``#__]8E5#,``/__XR55,P``___S)58S``#___HE5S,``/__#298,P``__\7
M)EDS``#__QPF6C,``/__(29;,P``__\F)EPS``#__RLF73,``/__,"9>,P``
M__\U)E\S``#__SHF8#,``/__/R9A,P``__]$)F(S``#__TDF8S,``/__3R9D
M,P``__]5)F4S``#__ULF9C,``/__829G,P``__]G)F@S``#__VTF:3,``/__
M<R9J,P``__]Y)FLS``#__W\F;#,``/__A29M,P``__^+)FXS``#__Y$F;S,`
M`/__ER9P,P``__^=)G$S``#__Z,F<C,``/__IR9S,P``__^J)G0S``#__ZTF
M=3,``/__L29V,P``__^T)GLS``#__[<F?#,``/__OB9],P``___%)GXS``#_
M_\PF?S,``/__TR:`,P``___@)H$S``#__^,F@C,``/__YB:#,P``___J)H0S
M``#__^TFA3,``/__\":&,P``___S)H<S``#___8FB#,``/__^2:),P``___]
M)HHS``#__P(GBS,``/__!2>,,P``__\()XTS``#__PPGCC,``/__$">/,P``
M__\3)Y`S``#__Q8GD3,``/__&2>2,P``__\=)Y,S``#__R$GE#,``/__)2>5
M,P``__\I)Y8S``#__RTGES,``/__,">8,P``__\S)YDS``#__S8GFC,``/__
M.2>;,P``__\\)YPS``#__T`GG3,``/__0R>>,P``__]&)Y\S``#__TDGH#,`
M`/__32>A,P``__]1)Z(S``#__U0GHS,``/__6">D,P``__]<)Z4S``#__V`G
MIC,``/__8R>G,P``__]G)Z@S``#__VTGJ3,``/__=">J,P``__]W)ZLS``#_
M_WLGK#,``/__?R>M,P``__^#)ZXS``#__X<GKS,``/__CR>P,P``__^8)[$S
M``#__YLGLC,``/__GB>S,P``__^B)[0S``#__Z4GM3,``/__J">V,P``__^K
M)[<S``#__Z\GN#,``/__LB>Y,P``__^U)[HS``#__[@GNS,``/__NR>\,P``
M__^^)[TS``#__\(GOC,``/__Q2>_,P``___()\`S``#__\LGP3,``/__SR?"
M,P``___3)\,S``#__]@GQ#,``/__VR?%,P``___>)\8S``#__^$GQS,``/__
MZ"?(,P``___L)\DS``#__^\GRC,``/__\B?+,P``___U)\PS``#___@GS3,`
M`/__^R?.,P``___^)\\S``#__P$HT#,``/__!"C1,P``__\'*-(S``#__PHH
MTS,``/__#BC4,P``__\1*-4S``#__Q0HUC,``/__&"C7,P``__\<*-@S``#_
M_Q\HV3,``/__)"C:,P``__\H*-LS``#__RLHW#,``/__+BC=,P``__\Q*.`S
M``#__S0HX3,``/__.2CB,P``__\^*.,S``#__T,HY#,``/__2"CE,P``__]-
M*.8S``#__U(HYS,``/__5RCH,P``__]<*.DS``#__V$HZC,``/__9RCK,P``
M__]M*.PS``#__W,H[3,``/__>2CN,P``__]_*.\S``#__X4H\#,``/__BRCQ
M,P``__^1*/(S``#__Y<H\S,``/__G2CT,P``__^C*/4S``#__ZDH]C,``/__
MKRCW,P``__^U*/@S``#__[LH^3,``/__P2CZ,P``___'*/LS``#__\TH_#,`
M`/__TRC],P``___9*/XS``#__]\H`/D``.4H__\!^0``Z2C__P+Y``"'&?__
M`_D``.TH__\$^0``\2C__P7Y``#U*/__!OD``/DH__\'^0``7QK__PCY``!?
M&O__"?D``/TH__\*^0``IQG__POY```!*?__#/D```4I__\-^0``"2G__P[Y
M```-*?__#_D``!$I__\0^0``%2G__Q'Y```9*?__$OD``!TI__\3^0``(2G_
M_Q3Y```E*?__%?D``"DI__\6^0``+2G__Q?Y```Q*?__&/D``#4I__\9^0``
M.2G__QKY```]*?__&_D``$$I__\<^0``12G__QWY``!)*?__'OD``$TI__\?
M^0``42G__R#Y``!5*?__(?D``%DI__\B^0``72G__R/Y``!A*?__)/D``&4I
M__\E^0``:2G__R;Y``!M*?__)_D``'$I__\H^0``=2G__RGY``!Y*?__*OD`
M`'TI__\K^0``@2G__RSY``"%*?__+?D``(DI__\N^0``C2G__R_Y``"1*?__
M,/D``)4I__\Q^0``F2G__S+Y``"=*?__,_D``*$I__\T^0``_QC__S7Y``"E
M*?__-OD``*DI__\W^0``K2G__SCY``"Q*?__.?D``+4I__\Z^0``N2G__SOY
M``"]*?__//D``,$I__\]^0``Q2G__S[Y``#)*?__/_D``,TI__]`^0``(QK_
M_T'Y``#1*?__0OD``-4I__]#^0``V2G__T3Y``#=*?__1?D``.$I__]&^0``
MY2G__T?Y``#I*?__2/D``.TI__])^0``\2G__TKY``#U*?__2_D``/DI__],
M^0``_2G__TWY```!*O__3OD```4J__]/^0``"2K__U#Y```-*O__4?D``!$J
M__]2^0``%2K__U/Y```9*O__5/D``!TJ__]5^0``(2K__U;Y```E*O__5_D`
M`"DJ__]8^0``+2K__UGY```Q*O__6OD``#4J__];^0``.2K__USY```E*?__
M7?D``#TJ__]>^0``02K__U_Y``!%*O__8/D``$DJ__]A^0``32K__V+Y``!1
M*O__8_D``%4J__]D^0``62K__V7Y``!=*O__9OD``&$J__]G^0``92K__VCY
M``!I*O__:?D``&TJ__]J^0``<2K__VOY``!U*O__;/D``'DJ__]M^0``?2K_
M_V[Y``"!*O__;_D``(4J__]P^0``B2K__W'Y``"/&?__<OD``(TJ__]S^0``
MD2K__W3Y``"5*O__=?D``)DJ__]V^0``G2K__W?Y``"A*O__>/D``*4J__]Y
M^0``J2K__WKY``"M*O__>_D``+$J__]\^0``M2K__WWY``"Y*O__?OD``+TJ
M__]_^0``P2K__X#Y``#%*O__@?D``*,7__^"^0``R2K__X/Y``#-*O__A/D`
M`-$J__^%^0``U2K__X;Y``#9*O__A_D``-TJ__^(^0``X2K__XGY``#E*O__
MBOD``%<7__^+^0``Z2K__XSY``#M*O__C?D``/$J__^.^0``]2K__X_Y``#Y
M*O__D/D``/TJ__^1^0```2O__Y+Y```%*___D_D```DK__^4^0``#2O__Y7Y
M```1*___EOD``!4K__^7^0``&2O__YCY```=*___F?D``"$K__^:^0``)2O_
M_YOY```I*___G/D``"TK__^=^0``,2O__Y[Y```U*___G_D``#DK__^@^0``
M/2O__Z'Y``"%*O__HOD``$$K__^C^0``12O__Z3Y``!)*___I?D``$TK__^F
M^0``42O__Z?Y``!5*___J/D``%DK__^I^0``72O__ZKY``!%*O__J_D``&$K
M__^L^0``92O__ZWY``!I*___KOD``&TK__^O^0``<2O__[#Y``!U*___L?D`
M`'DK__^R^0``?2O__[/Y``"!*___M/D``(4K__^U^0``B2O__[;Y``"-*___
MM_D``)$K__^X^0``E2O__[GY``"9*___NOD``)TK__^[^0``H2O__[SY``"E
M*___O?D``*DK__^^^0``K2O__[_Y```E*?__P/D``+$K___!^0``M2O__\+Y
M``"Y*___P_D``+TK___$^0``6QK__\7Y``#!*___QOD``,4K___'^0``R2O_
M_\CY``#-*___R?D``-$K___*^0``U2O__\OY``#9*___S/D``-TK___-^0``
MX2O__\[Y``#E*___S_D``.DK___0^0``[2O__]'Y```'(/__TOD``/$K___3
M^0``]2O__]3Y``#Y*___U?D``/TK___6^0```2S__]?Y```%+/__V/D```DL
M___9^0``#2S__]KY```1+/__V_D``$TJ___<^0``%2S__]WY```9+/__WOD`
M`!TL___?^0``(2S__^#Y```E+/__X?D``"DL___B^0``+2S__^/Y```Q+/__
MY/D``#4L___E^0``.2S__^;Y```]+/__Y_D``$$L___H^0``12S__^GY``"C
M&?__ZOD``$DL___K^0``32S__^SY``!1+/__[?D``%4L___N^0``62S__^_Y
M``!=+/__\/D``&$L___Q^0``92S___+Y``!I+/__\_D``&TL___T^0``<2S_
M__7Y``!U+/__]OD``'DL___W^0``WQC___CY``!]+/__^?D``($L___Z^0``
MA2S___OY``")+/___/D``(TL___]^0``D2S___[Y``"5+/____D``)DL__\`
M^@``G2S__P'Z``"A+/__`OH``*4L__\#^@``J2S__P3Z``"M+/__!?H``+$L
M__\&^@``M2S__P?Z``"Y+/__"/H``$L9__\)^@``O2S__PKZ``!7&?__"_H`
M`,$L__\,^@``Q2S__PWZ``#)+/__$/H``,TL__\2^@``T2S__Q7Z``#5+/__
M%OH``-DL__\7^@``W2S__QCZ``#A+/__&?H``.4L__\:^@``Z2S__QOZ``#M
M+/__'/H``/$L__\=^@``]2S__Q[Z``#[&/__(/H``/DL__\B^@``_2S__R7Z
M```!+?__)OH```4M__\J^@``"2W__ROZ```-+?__+/H``!$M__\M^@``%2W_
M_S#Z```9+?__,?H``!TM__\R^@``(2W__S/Z```E+?__-/H``"DM__\U^@``
M+2W__S;Z```Q+?__-_H``#4M__\X^@``.2W__SGZ```]+?__.OH``$$M__\[
M^@``12W__SSZ``"_%___/?H``$DM__\^^@``32W__S_Z``!1+?__0/H``%4M
M__]!^@``62W__T+Z``!=+?__0_H``&$M__]$^@``92W__T7Z``!I+?__1OH`
M`&TM__]'^@``<2W__TCZ``!U+?__2?H``'DM__]*^@``?2W__TOZ``"!+?__
M3/H``!L@__]-^@``A2W__T[Z``")+?__3_H``(TM__]0^@``D2W__U'Z```K
M(/__4OH``)4M__]3^@``F2W__U3Z``"=+?__5?H``*$M__]6^@``I2W__U?Z
M```5*___6/H``*DM__]9^@``K2W__UKZ``"Q+?__6_H``+4M__]<^@``N2W_
M_UWZ``"]+?__7OH``+TM__]?^@``P2W__V#Z``#%+?__8?H``,DM__]B^@``
MS2W__V/Z``#1+?__9/H``-4M__]E^@``V2W__V;Z``#=+?__9_H```$M__]H
M^@``X2W__VGZ``#E+?__:OH``.DM__\`^P``___M+0'[``#___`M`OL``/__
M\RT#^P``___V+03[``#___HM!?L``/___BT&^P``___^+1/[``#__P$N%/L`
M`/__!BX5^P``__\++A;[``#__Q`N%_L``/__%2X=^P``&B[__Q_[```?+O__
M(/L``/__)"XA^P``__^\$R+[``#__\43(_L``/__)RXD^P``__\J+B7[``#_
M_RTN)OL``/__,"XG^P``__\S+BC[``#__S8N*?L``/__71,J^P``.2[__RO[
M```^+O__+/L``$,N__\M^P``2B[__R[[``!1+O__+_L``%8N__\P^P``6R[_
M_S'[``!@+O__,OL``&4N__\S^P``:B[__S3[``!O+O__-?L``'0N__\V^P``
M>2[__SC[``!^+O__.?L``(,N__\Z^P``B"[__SO[``"-+O__//L``)(N__\^
M^P``ER[__T#[``"<+O__0?L``*$N__]#^P``IB[__T3[``"K+O__1OL``+`N
M__]'^P``M2[__TC[``"Z+O__2?L``+\N__]*^P``Q"[__TO[``#)+O__3/L`
M`,XN__]-^P``TR[__T[[``#8+O__3_L``/__W2Y0^P``___B+E'[``#__^(N
M4OL``/__Y2Y3^P``___E+E3[``#__^4N5?L``/__Y2Y6^P``___H+E?[``#_
M_^@N6/L``/__Z"Y9^P``___H+EK[``#__^LN6_L``/__ZRY<^P``___K+EW[
M``#__^LN7OL``/__[BY?^P``___N+F#[``#__^XN8?L``/__[BYB^P``___Q
M+F/[``#___$N9/L``/__\2YE^P``___Q+F;[``#___0N9_L``/__]"YH^P``
M___T+FG[``#___0N:OL``/__]RYK^P``___W+FS[``#___<N;?L``/__]RYN
M^P``___Z+F_[``#___HN</L``/__^BYQ^P``___Z+G+[``#___TN<_L``/__
M_2YT^P``___]+G7[``#___TN=OL``/__`"]W^P``__\`+WC[``#__P`O>?L`
M`/__`"]Z^P``__\#+WO[``#__P,O?/L``/__`R]]^P``__\#+W[[``#__P8O
M?_L``/__!B^`^P``__\&+X'[``#__P8O@OL``/__"2^#^P``__\)+X3[``#_
M_PPOA?L``/__#"^&^P``__\/+X?[``#__P\OB/L``/__$B^)^P``__\2+XK[
M``#__Q4OB_L``/__%2^,^P``__\8+XW[``#__Q@OCOL``/__&R^/^P``__\;
M+Y#[``#__QLOD?L``/__&R^2^P``__\>+Y/[``#__QXOE/L``/__'B^5^P``
M__\>+Y;[``#__R$OE_L``/__(2^8^P``__\A+YG[``#__R$OFOL``/__)"^;
M^P``__\D+YS[``#__R0OG?L``/__)"^>^P``__\G+Y_[``#__R<OH/L``/__
M*B^A^P``__\J+Z+[``#__RHOH_L``/__*B^D^P``__^V!J7[``#__[8&IOL`
M`/__+2^G^P``__\M+ZC[``#__RTOJ?L``/__+2^J^P``__\P+ZO[``#__S`O
MK/L``/__,"^M^P``__\P+Z[[``#__S,OK_L``/__,R^P^P``___`!K'[``#_
M_\`&T_L``/__-B_4^P``__\V+]7[``#__S8OUOL``/__-B_7^P``__\Y+]C[
M``#__SDOV?L``/__/"_:^P``__\\+]O[``#__S\OW/L``/__/R_=^P``__^L
M!M[[``#__T(OW_L``/__0B_@^P``__]%+^'[``#__T4OXOL``/__2"_C^P``
M__](+^3[``#__TLOY?L``/__2R_F^P``__]++^?[``#__TLOZ/L``/__3B_I
M^P``__].+^K[``#__U$OZ_L``/__42_L^P``__]8+^W[``#__U@O[OL``/__
M7R_O^P``__]?+_#[``#__V8O\?L``/__9B_R^P``__]M+_/[``#__VTO]/L`
M`/__="_U^P``__]T+_;[``#__WLO]_L``/__>R_X^P``__][+_G[``#__X(O
M^OL``/__@B_[^P``__^"+_S[``#__XDO_?L``/__B2_^^P``__^)+__[``#_
M_XDO`/P``/__C"\!_```__^3+P+\``#__YHO`_P``/__@B\$_```__^A+P7\
M``#__Z@O!OP``/__K2\'_```__^R+PC\``#__[<O"?P``/__O"\*_```___!
M+PO\``#__\8O#/P``/__RR\-_```___0+P[\``#__]4O#_P``/__VB\0_```
M___?+Q'\``#__^0O$OP``/__Z2\3_```___N+Q3\``#___,O%?P``/__^"\6
M_```___]+Q?\``#__P(P&/P``/__!S`9_```__\,,!K\``#__Q$P&_P``/__
M%C`<_```__\;,!W\``#__R`P'OP``/__)3`?_```__\J,"#\``#__R\P(?P`
M`/__-#`B_```__\Y,"/\``#__SXP)/P``/__0S`E_```__](,";\``#__TTP
M)_P``/__4C`H_```__]7,"G\``#__UPP*OP``/__83`K_```__]F,"S\``#_
M_VLP+?P``/__<#`N_```__]U,"_\``#__WHP,/P``/__?S`Q_```__^$,#+\
M``#__XDP,_P``/__CC`T_```__^3,#7\``#__Y@P-OP``/__G3`W_```__^B
M,#C\``#__Z<P.?P``/__K#`Z_```__^Q,#O\``#__[8P//P``/__NS`]_```
M___`,#[\``#__\4P/_P``/__RC!`_```___/,$'\``#__]0P0OP``/__V3!#
M_```___>,$3\``#__^,P1?P``/__Z#!&_```___M,$?\``#___(P2/P``/__
M]S!)_```___\,$K\``#__P$Q2_P``/__!C%,_```__\+,4W\``#__Q`Q3OP`
M`/__%3%/_```__\:,5#\``#__Q\Q4?P``/__)#%2_```__\I,5/\``#__RXQ
M5/P``/__,S%5_```__\X,5;\``#__STQ5_P``/__0C%8_```__]',5G\``#_
M_TPQ6OP``/__43%;_```__]6,5S\``#__ULQ7?P``/__8#%>_```__]E,5_\
M``#__VLQ8/P``/__<3%A_```__]W,6+\``#__WTQ8_P``/__@S%D_```__^)
M,67\``#__Y`Q9OP``/__FB]G_```__^7,6C\``#__X(O:?P``/__H2]J_```
M__^>,6O\``#__Z,Q;/P``/__MR]M_```__^H,6[\``#__[PO;_P``/__P2]P
M_```__^M,7'\``#__[(Q<OP``/__U2]S_```__^W,73\``#__]HO=?P``/__
MWR]V_```__^\,7?\``#__\$Q>/P``/__Z2]Y_```___&,7K\``#__^XO>_P`
M`/__\R]\_```__^$,'W\``#__XDP?OP``/__F#!__```__^=,(#\``#__Z(P
M@?P``/__MC""_```__^[,(/\``#__\`PA/P``/__Q3"%_```___9,(;\``#_
M_]XPA_P``/__XS"(_```___+,8G\``#___<PBOP``/__T#&+_```___5,8S\
M``#__Q4QC?P``/__VC&._```__\:,8_\``#__Q\QD/P``/__8#&1_```___?
M,9+\``#__^0QD_P``/__1S&4_```___I,97\``#__TPQEOP``/__43&7_```
M__^,+YC\``#__Y,OF?P``/__[C&:_```__^:+YO\``#___4QG/P``/__J"^=
M_```__^M+Y[\``#__[(OG_P``/__MR^@_```___\,:'\``#__\8OHOP``/__
MRR^C_```___0+Z3\``#__]4OI?P``/__`3*F_```___I+Z?\``#___@OJ/P`
M`/___2^I_```__\",*K\``#__P<PJ_P``/__##"L_```__\6,*W\``#__QLP
MKOP``/__(#"O_```__\E,+#\``#__RHPL?P``/__+S"R_```__\&,K/\``#_
M_S0PM/P``/__.3"U_```__\^,+;\``#__T,PM_P``/__2#"X_```__]-,+G\
M``#__U<PNOP``/__7#"[_```__]A,+S\``#__V8PO?P``/__:S"^_```__]P
M,+_\``#__W4PP/P``/__>C#!_```__]_,,+\``#__XXPP_P``/__DS#$_```
M__^G,,7\``#__ZPPQOP``/__L3#'_```__^V,,C\``#__[LPR?P``/__RC#*
M_```___/,,O\``#__]0PS/P``/__V3#-_```__\+,L[\``#__^@PS_P``/__
M[3#0_```___R,-'\``#___<PTOP``/__!C'3_```__\+,=3\``#__Q`QU?P`
M`/__%3'6_```__\0,M?\``#__R0QV/P``/__*3'9_```__\5,MK\``#__S@Q
MV_P``/__/3'<_```__]",=W\``#__T<QWOP``/__&C+?_```__^:+^#\``#_
M__4QX?P``/__MR_B_```___\,>/\``#__]4OY/P``/__`3+E_```___I+^;\
M``#__Q\RY_P``/__*C#H_```__\D,NG\``#__RDRZOP``/__+C+K_```__^V
M,.S\``#__[LP[?P``/__V3#N_```__\5,>_\``#__Q`R\/P``/__1S'Q_```
M__\:,O+\``#__S,R\_P``/__.C+T_```__]!,O7\``#__T@R]OP``/__33+W
M_```__]2,OC\``#__U<R^?P``/__7#+Z_```__]A,OO\``#__V8R_/P``/__
M:S+]_```__]P,O[\``#__W4R__P``/__>C(`_0``__]_,@']``#__X0R`OT`
M`/__B3(#_0``__^.,@3]``#__Y,R!?T``/__F#(&_0``__^=,@?]``#__Z(R
M"/T``/__IS()_0``__^L,@K]``#__[$R"_T``/__MC(,_0``__\I,@W]``#_
M_[LR#OT``/__P#(/_0``___%,A#]``#__\HR$?T``/__2#(2_0``__]-,A/]
M``#__U(R%/T``/__5S(5_0``__]<,A;]``#__V$R%_T``/__9C(8_0``__]K
M,AG]``#__W`R&OT``/__=3(;_0``__]Z,AS]``#__W\R'?T``/__A#(>_0``
M__^),A_]``#__XXR(/T``/__DS(A_0``__^8,B+]``#__YTR(_T``/__HC(D
M_0``__^G,B7]``#__ZPR)OT``/__L3(G_0``__^V,BC]``#__RDR*?T``/__
MNS(J_0``___`,BO]``#__\4R+/T``/__RC(M_0``__^L,B[]``#__[$R+_T`
M`/__MC(P_0``__\I,C']``#__R0R,OT``/__+C(S_0``__]2,#3]``#__QLP
M-?T``/__(#`V_0``__\E,#?]``#__ZPR./T``/__L3(Y_0``__^V,CK]``#_
M_U(P._T``/__5S`\_0``___/,CW]``#__\\R4/T``/__U#)1_0``___;,E+]
M``#__]LR4_T``/__XC)4_0``___I,E7]``#___`R5OT``/__]S)7_0``___^
M,EC]``#__P4S6?T``/__!3-:_0``__\,,UO]``#__Q,S7/T``/__&C-=_0``
M__\A,U[]``#__R@S7_T``/__+S-@_0``__\O,V']``#__S8S8OT``/__/3-C
M_0``__\],V3]``#__T0S9?T``/__1#-F_0``__]+,V?]``#__U(S:/T``/__
M4C-I_0``__]9,VK]``#__V`S:_T``/__8#-L_0``__]G,VW]``#__V<S;OT`
M`/__;C-O_0``__]U,W#]``#__W4S<?T``/__?#-R_0``__]\,W/]``#__X,S
M=/T``/__BC-U_0``__^1,W;]``#__Y@S=_T``/__F#-X_0``__^?,WG]``#_
M_Z8S>OT``/__K3-[_0``__^T,WS]``#__[LS??T``/__NS-^_0``___",W_]
M``#__\DS@/T``/__T#.!_0``___7,X+]``#__]XS@_T``/__Y3.$_0``___E
M,X7]``#__^PSAOT``/__[#.'_0``___S,XC]``#___,SB?T``/__^C.*_0``
M__\!-(O]``#__P@TC/T``/__#S2-_0``__\6-([]``#__QTTC_T``/__)#22
M_0``__\K-)/]``#__S(TE/T``/__.325_0``__]`-);]``#__T<TE_T``/__
M3C28_0``__].-)G]``#__U4TFOT``/__7#2;_0``__]C-)S]``#__VHTG?T`
M`/__:C2>_0``__]Q-)_]``#__W@TH/T``/__?S2A_0``__^&-*+]``#__XTT
MH_T``/__E#2D_0``__^;-*7]``#__Z(TIOT``/__J32G_0``__^P-*C]``#_
M_[<TJ?T``/__OC2J_0``___%-*O]``#__\PTK/T``/__TS2M_0``___:-*[]
M``#__^$TK_T``/__Z#2P_0``___O-+']``#___8TLOT``/___32S_0``__\$
M-;3]``#__\(SM?T``/__T#.V_0``__\+-;?]``#__Q(UN/T``/__&36Y_0``
M__\@-;K]``#__R<UN_T``/__+C6\_0``__\G-;W]``#__QDUOOT``/__-36_
M_0``__\\-<#]``#__T,UP?T``/__2C7"_0``__]1-</]``#__RXUQ/T``/__
MD3/%_0``__]+,\;]``#__U@UQ_T``/__7S7P_0``__]F-?']``#__VTU\OT`
M`/__=#7S_0``__]]-?3]``#__X8U]?T``/__CS7V_0``__^8-??]``#__Z$U
M^/T``/__JC7Y_0``__^S-?K]``#__[HU^_T``/__W#7\_0``___L-3#^``#_
M_P<3,?X``/__]34R_@``___Y-3/^``#___TU-/X``/___34U_@``__]E$S;^
M``#__V<3-_X``/___S4X_@``__\!-CG^``#__P,V.OX``/__!S8[_@``__\+
M-CS^``#__P\V/?X``/__$S8^_@``__\7-C_^``#__Y050/X``/__F!5!_@``
M__\;-D+^``#__Q\V0_X``/__(S9$_@``__\G-DG^``#__S,32OX``/__,Q-+
M_@``__\S$TS^``#__S,33?X``/___35._@``___]-4_^``#___TU4/X``/__
M*S91_@``__\M-E+^``#__P435/X``/__X`15_@``__\Q-E;^``#__S,V5_X`
M`/__-398_@``___U-5G^``#__V436OX``/__9Q-;_@``____-5S^``#__P$V
M7?X``/__`S9>_@``__\'-E_^``#__S<V8/X``/__.39A_@``__\[-F+^``#_
M_UT38_X``/__/39D_@``__\_-F7^``#__T$V9OX``/__8Q-H_@``__]#-FG^
M``#__T4V:OX``/__1S9K_@``__])-G#^``#__TLV<?X``/__3S9R_@``__]4
M-G3^``#__U@V=OX``/__7#9W_@``__]@-GC^``#__V4V>?X``/__:39Z_@``
M__]N-GO^``#__W(V?/X``/__=S9]_@``__][-G[^``#__X`V?_X``/__A#:`
M_@``__^)-H'^``#__XD&@OX``/__B0:#_@``__^.!H3^``#__XX&A?X``/__
MDP:&_@``__^3!H?^``#__Y@&B/X``/__F`:)_@``__^=!HK^``#__YT&B_X`
M`/__G0:,_@``__^=!HW^``#__XPVCOX``/__C#:/_@``__^/-I#^``#__X\V
MD?X``/__CS:2_@``__^/-I/^``#__Y(VE/X``/__DC:5_@``__^5-I;^``#_
M_Y4VE_X``/__E3:8_@``__^5-IG^``#__Y@VFOX``/__F#:;_@``__^8-IS^
M``#__Y@VG?X``/__FS:>_@``__^;-I_^``#__YLVH/X``/__FS:A_@``__^>
M-J+^``#__YXVH_X``/__GC:D_@``__^>-J7^``#__Z$VIOX``/__H3:G_@``
M__^A-JC^``#__Z$VJ?X``/__I#:J_@``__^D-JO^``#__Z<VK/X``/__IS:M
M_@``__^J-J[^``#__ZHVK_X``/__K3:P_@``__^M-K'^``#__[`VLOX``/__
ML#:S_@``__^P-K3^``#__[`VM?X``/__LS:V_@``__^S-K?^``#__[,VN/X`
M`/__LS:Y_@``__^V-KK^``#__[8VN_X``/__MC:\_@``__^V-KW^``#__[DV
MOOX``/__N3:__@``__^Y-L#^``#__[DVP?X``/__O#;"_@``__^\-L/^``#_
M_[PVQ/X``/__O#;%_@``__^_-L;^``#__[\VQ_X``/__OS;(_@``__^_-LG^
M``#__\(VROX``/__PC;+_@``___"-LS^``#__\(VS?X``/__Q3;._@``___%
M-L_^``#__\4VT/X``/__Q3;1_@``___(-M+^``#__\@VT_X``/__R#;4_@``
M___(-M7^``#__\LVUOX``/__RS;7_@``___+-MC^``#__\LVV?X``/__SC;:
M_@``___.-MO^``#__\XVW/X``/__SC;=_@``___1-M[^``#__]$VW_X``/__
MT3;@_@``___1-N'^``#__]0VXOX``/__U#;C_@``___4-N3^``#__]0VY?X`
M`/__US;F_@``___7-N?^``#__]<VZ/X``/__US;I_@``___:-NK^``#__]HV
MZ_X``/__VC;L_@``___:-NW^``#__]TV[OX``/__W3;O_@``__].+_#^``#_
M_TXO\?X``/__X#;R_@``___@-O/^``#__^`V]/X``/__X#;U_@``___C-O;^
M``#__^,V]_X``/__ZC;X_@``___J-OG^``#___$V^OX``/__\3;[_@``___X
M-OS^``#___@V`?\``/__-38"_P``___]-@/_``#__S<V!/\``/__138%_P``
M__]'-@;_``#__SDV!_\``/___S8(_P``__]E$PG_``#__V<3"O\``/__.S8+
M_P``__]=$PS_``#__RLV#?\``/__/38._P``__\%$P__``#__P$W$/\``/__
M31,1_P``__\;`!+_``#__PP`$_\``/__#@`4_P``__]1$Q7_``#__U,3%O\`
M`/__51,7_P``__]7$QC_``#__UD3&?\``/__6Q,:_P``__\Q-AO_``#__^`$
M'/\``/__/S8=_P``__]C$Q[_``#__T$V'_\``/__,S8@_P``__])-B'_``#_
M_\<6(O\``/__LA,C_P``__]V$R3_``#__]43)?\``/__MA,F_P``__^X$R?_
M``#__\D6*/\``/__C1,I_P``__^2$RK_``#__\L6*_\``/__L!,L_P``__^4
M$RW_``#__[H3+O\``/__EA,O_P``___-%C#_``#__YL3,?\``/__G1,R_P``
M__^?$S/_``#__\\6-/\``/__T18U_P``___3%C;_``#__S`4-_\``/__U18X
M_P``__]!%#G_``#__]<6.O\``/__JQ,[_P``__\#-SS_``#__T,V/?\``/__
M!3<^_P``__\'-S__``#___TU0/\``/__OA)!_P``__\&`$+_``#__]D60_\`
M`/__;!1$_P``___7$T7_``#__[031O\``/__VQ9'_P``__^+$TC_``#__Y,$
M2?\``/__3Q-*_P``__^8!$O_``#__]T63/\``/__Q`1-_P``__]N%$[_``#_
M_VD33_\``/__'0!0_P``___?%E'_``#__^$64O\``/__F@13_P``___'`E3_
M``#__^,65?\``/__Y196_P``__]4%%?_``#__Z4$6/\``/__Q@19_P``__^G
M!%K_``#__^<66_\``/___S5<_P``__\)-UW_``#__P$V7O\``/__"S=?_P``
M__\--V#_``#__Q$W8?\``/__%3=B_P``__\;-F/_``#__Q\V9/\``/__+39E
M_P``__\9-V;_``#__Z<A9_\``/__'3=H_P``__\A-VG_``#__R4W:O\``/__
M*3=K_P``__\M-VS_``#__S$W;?\``/__-3=N_P``__\Y-V__``#__STW</\`
M`/__03=Q_P``___O('+_``#___,@<_\``/__]R!T_P``___[('7_``#___\@
M=O\``/__`R%W_P``__\'(7C_``#__PLA>?\``/__#R%Z_P``__\3(7O_``#_
M_Q<A?/\``/__&R%]_P``__\?(7[_``#__R,A?_\``/__)R&`_P``__\K(8'_
M``#__R\A@O\``/__,R&#_P``__\W(83_``#__SLAA?\``/__/R&&_P``__]#
M(8?_``#__T<AB/\``/__2R&)_P``__]/(8K_``#__U,AB_\``/__5R&,_P``
M__];(8W_``#__U\ACO\``/__8R&/_P``__]G(9#_``#__VLAD?\``/__;R&2
M_P``__]S(9/_``#__W<AE/\``/__>R&5_P``__]_(9;_``#__X,AE_\``/__
MAR&8_P``__^+(9G_``#__X\AFO\``/__DR&;_P``__^7(9S_``#__YLAG?\`
M`/__13>>_P``__])-Y__``#__TTWH/\``/__[1RA_P``__\A'*+_``#__R4<
MH_\``/__*1RD_P``__\M'*7_``#__S$<IO\``/__-1RG_P``__\Y'*C_``#_
M_ST<J?\``/__01RJ_P``__]%'*O_``#__TD<K/\``/__31RM_P``__]1'*[_
M``#__U4<K_\``/__61RP_P``__]='+'_``#__V$<LO\``/__91RS_P``__]I
M'+3_``#__VT<M?\``/__<1RV_P``__]U'+?_``#__WD<N/\``/__?1RY_P``
M__^!'+K_``#__X4<N_\``/__B1R\_P``__^-'+W_``#__Y$<OO\``/__E1S"
M_P``__^9',/_``#__YT<Q/\``/__H1S%_P``__^E',;_``#__ZD<Q_\``/__
MK1S*_P``__^Q',O_``#__[4<S/\``/__N1S-_P``__^]',[_``#__\$<S_\`
M`/__Q1S2_P``___)'-/_``#__\T<U/\``/__T1S5_P``___5'-;_``#__]D<
MU_\``/__W1S:_P``___A'-O_``#__^4<W/\``/__Z1S@_P``__]1-^'_``#_
M_U0WXO\``/__5S?C_P``__\(`.3_``#__UHWY?\``/__73?F_P``__]@-^C_
M``#__V0WZ?\``/__:#?J_P``__]L-^O_``#__W`W[/\``/__=#?M_P``__]X
M-^[_``#__WPW7M$!`(`W__]?T0$`B3?__V#1`0"2-___8=$!`)\W__]BT0$`
MK#?__V/1`0"Y-___9-$!`,8W__^[T0$`TS?__[S1`0#<-___O=$!`.4W__^^
MT0$`\C?__[_1`0#_-___P-$!``PX__\`U`$`___'%@'4`0#__[(3`M0!`/__
M=A,#U`$`___5$P34`0#__[83!=0!`/__N!,&U`$`___)%@?4`0#__XT3"-0!
M`/__DA,)U`$`___+%@K4`0#__[`3"]0!`/__E!,,U`$`__^Z$PW4`0#__Y83
M#M0!`/__S18/U`$`__^;$Q#4`0#__YT3$=0!`/__GQ,2U`$`___/%A/4`0#_
M_]$6%-0!`/__TQ85U`$`__\P%!;4`0#__]46%]0!`/__0108U`$`___7%AG4
M`0#__ZL3&M0!`/__!@`;U`$`___9%AS4`0#__VP4'=0!`/__UQ,>U`$`__^T
M$Q_4`0#__]L6(-0!`/__BQ,AU`$`__^3!"+4`0#__T\3(]0!`/__F`0DU`$`
M___=%B74`0#__\0$)M0!`/__;A0GU`$`__]I$RC4`0#__QT`*=0!`/__WQ8J
MU`$`___A%BO4`0#__YH$+-0!`/__QP(MU`$`___C%B[4`0#__^46+]0!`/__
M5!0PU`$`__^E!#'4`0#__\8$,M0!`/__IP0SU`$`___G%C34`0#__\<6-=0!
M`/__LA,VU`$`__]V$S?4`0#__]43.-0!`/__MA,YU`$`__^X$SK4`0#__\D6
M.]0!`/__C1,\U`$`__^2$SW4`0#__\L6/M0!`/__L!,_U`$`__^4$T#4`0#_
M_[H30=0!`/__EA-"U`$`___-%D/4`0#__YL31-0!`/__G1-%U`$`__^?$T;4
M`0#__\\61]0!`/__T19(U`$`___3%DG4`0#__S`42M0!`/__U19+U`$`__]!
M%$S4`0#__]<63=0!`/__JQ-.U`$`__\&`$_4`0#__]D64-0!`/__;!11U`$`
M___7$U+4`0#__[034]0!`/__VQ94U`$`__^+$U;4`0#__T\35]0!`/__F`18
MU`$`___=%EG4`0#__\0$6M0!`/__;A1;U`$`__]I$US4`0#__QT`7=0!`/__
MWQ9>U`$`___A%E_4`0#__YH$8-0!`/__QP)AU`$`___C%F+4`0#__^468]0!
M`/__5!1DU`$`__^E!&74`0#__\8$9M0!`/__IP1GU`$`___G%FC4`0#__\<6
M:=0!`/__LA-JU`$`__]V$VO4`0#__]43;-0!`/__MA-MU`$`__^X$V[4`0#_
M_\D6;]0!`/__C1-PU`$`__^2$W'4`0#__\L6<M0!`/__L!-SU`$`__^4$W34
M`0#__[H3==0!`/__EA-VU`$`___-%G?4`0#__YL3>-0!`/__G1-YU`$`__^?
M$WK4`0#__\\6>]0!`/__T19\U`$`___3%GW4`0#__S`4?M0!`/__U19_U`$`
M__]!%(#4`0#__]<6@=0!`/__JQ."U`$`__\&`(/4`0#__]D6A-0!`/__;!2%
MU`$`___7$X;4`0#__[03A]0!`/__VQ:(U`$`__^+$XG4`0#__Y,$BM0!`/__
M3Q.+U`$`__^8!(S4`0#__]T6C=0!`/__Q`2.U`$`__]N%(_4`0#__VD3D-0!
M`/__'0"1U`$`___?%I+4`0#__^$6D]0!`/__F@24U`$`___'`I74`0#__^,6
MEM0!`/__Y1:7U`$`__]4%)C4`0#__Z4$F=0!`/__Q@2:U`$`__^G!)O4`0#_
M_^<6G-0!`/__QQ:>U`$`__]V$Y_4`0#__]43HM0!`/__R1:EU`$`___+%J;4
M`0#__[`3J=0!`/__EA.JU`$`___-%JO4`0#__YL3K-0!`/__G1.NU`$`___/
M%J_4`0#__]$6L-0!`/__TQ:QU`$`__\P%++4`0#__]46L]0!`/__012TU`$`
M___7%K74`0#__ZL3MM0!`/__!@"WU`$`___9%KC4`0#__VP4N=0!`/__UQ.[
MU`$`___;%KW4`0#__Y,$OM0!`/__3Q._U`$`__^8!,#4`0#__]T6PM0!`/__
M;A3#U`$`__]I$\74`0#__]\6QM0!`/__X1;'U`$`__^:!,C4`0#__\<"R=0!
M`/__XQ;*U`$`___E%LO4`0#__U04S-0!`/__I03-U`$`___&!,[4`0#__Z<$
MS]0!`/__YQ;0U`$`___'%M'4`0#__[(3TM0!`/__=A/3U`$`___5$]34`0#_
M_[83U=0!`/__N!/6U`$`___)%M?4`0#__XT3V-0!`/__DA/9U`$`___+%MK4
M`0#__[`3V]0!`/__E!/<U`$`__^Z$]W4`0#__Y83WM0!`/__S1;?U`$`__^;
M$^#4`0#__YT3X=0!`/__GQ/BU`$`___/%N/4`0#__]$6Y-0!`/__TQ;EU`$`
M__\P%.;4`0#__]46Y]0!`/__013HU`$`___7%NG4`0#__ZL3ZM0!`/__!@#K
MU`$`___9%NS4`0#__VP4[=0!`/__UQ/NU`$`__^T$^_4`0#__]L6\-0!`/__
MBQ/QU`$`__^3!/+4`0#__T\3\]0!`/__F`3TU`$`___=%O74`0#__\0$]M0!
M`/__;A3WU`$`__]I$_C4`0#__QT`^=0!`/__WQ;ZU`$`___A%OO4`0#__YH$
M_-0!`/__QP+]U`$`___C%O[4`0#__^46_]0!`/__5!0`U0$`__^E!`'5`0#_
M_\8$`M4!`/__IP0#U0$`___G%@35`0#__\<6!=4!`/__LA,'U0$`___5$PC5
M`0#__[83"=4!`/__N!,*U0$`___)%@W5`0#__\L6#M4!`/__L!,/U0$`__^4
M$Q#5`0#__[H3$=4!`/__EA,2U0$`___-%A/5`0#__YL3%-4!`/__G1,6U0$`
M___/%A?5`0#__]$6&-4!`/__TQ89U0$`__\P%!K5`0#__]46&]4!`/__010<
MU0$`___7%A[5`0#__P8`']4!`/__V18@U0$`__]L%"'5`0#__]<3(M4!`/__
MM!,CU0$`___;%B35`0#__XL3)=4!`/__DP0FU0$`__]/$R?5`0#__Y@$*-4!
M`/__W18IU0$`___$!"K5`0#__VX4*]4!`/__:1,LU0$`__\=`"W5`0#__]\6
M+M4!`/__X18OU0$`__^:!##5`0#__\<",=4!`/__XQ8RU0$`___E%C/5`0#_
M_U04--4!`/__I00UU0$`___&!#;5`0#__Z<$-]4!`/__YQ8XU0$`___'%CG5
M`0#__[(3.]4!`/__U1,\U0$`__^V$SW5`0#__[@3/M4!`/__R19`U0$`__^2
M$T'5`0#__\L60M4!`/__L!-#U0$`__^4$T35`0#__[H31M4!`/__S19*U0$`
M___/%DO5`0#__]$63-4!`/__TQ9-U0$`__\P%$[5`0#__]463]4!`/__0110
MU0$`___7%E+5`0#__P8`4]4!`/__V194U0$`__]L%%75`0#__]<35M4!`/__
MM!-7U0$`___;%EC5`0#__XL36=4!`/__DP1:U0$`__]/$UO5`0#__Y@$7-4!
M`/__W19=U0$`___$!%[5`0#__VX47]4!`/__:1-@U0$`__\=`&'5`0#__]\6
M8M4!`/__X19CU0$`__^:!&35`0#__\<"9=4!`/__XQ9FU0$`___E%F?5`0#_
M_U04:-4!`/__I01IU0$`___&!&K5`0#__Z<$:]4!`/__YQ9LU0$`___'%FW5
M`0#__[(3;M4!`/__=A-OU0$`___5$W#5`0#__[83<=4!`/__N!-RU0$`___)
M%G/5`0#__XT3=-4!`/__DA-UU0$`___+%G;5`0#__[`3=]4!`/__E!-XU0$`
M__^Z$WG5`0#__Y83>M4!`/__S19[U0$`__^;$WS5`0#__YT3?=4!`/__GQ-^
MU0$`___/%G_5`0#__]$6@-4!`/__TQ:!U0$`__\P%(+5`0#__]46@]4!`/__
M012$U0$`___7%H75`0#__ZL3AM4!`/__!@"'U0$`___9%HC5`0#__VP4B=4!
M`/__UQ.*U0$`__^T$XO5`0#__]L6C-4!`/__BQ.-U0$`__^3!([5`0#__T\3
MC]4!`/__F`20U0$`___=%I'5`0#__\0$DM4!`/__;A23U0$`__]I$Y35`0#_
M_QT`E=4!`/__WQ:6U0$`___A%I?5`0#__YH$F-4!`/__QP*9U0$`___C%IK5
M`0#__^46F]4!`/__5!2<U0$`__^E!)W5`0#__\8$GM4!`/__IP2?U0$`___G
M%J#5`0#__\<6H=4!`/__LA.BU0$`__]V$Z/5`0#__]43I-4!`/__MA.EU0$`
M__^X$Z;5`0#__\D6I]4!`/__C1.HU0$`__^2$ZG5`0#__\L6JM4!`/__L!.K
MU0$`__^4$ZS5`0#__[H3K=4!`/__EA.NU0$`___-%J_5`0#__YL3L-4!`/__
MG1.QU0$`__^?$[+5`0#__\\6L]4!`/__T1:TU0$`___3%K75`0#__S`4MM4!
M`/__U1:WU0$`__]!%+C5`0#__]<6N=4!`/__JQ.ZU0$`__\&`+O5`0#__]D6
MO-4!`/__;!2]U0$`___7$[[5`0#__[03O]4!`/__VQ;`U0$`__^+$\'5`0#_
M_Y,$PM4!`/__3Q/#U0$`__^8!,35`0#__]T6Q=4!`/__Q`3&U0$`__]N%,?5
M`0#__VD3R-4!`/__'0#)U0$`___?%LK5`0#__^$6R]4!`/__F@3,U0$`___'
M`LW5`0#__^,6SM4!`/__Y1;/U0$`__]4%-#5`0#__Z4$T=4!`/__Q@32U0$`
M__^G!-/5`0#__^<6U-4!`/__QQ;5U0$`__^R$];5`0#__W83U]4!`/__U1/8
MU0$`__^V$]G5`0#__[@3VM4!`/__R1;;U0$`__^-$]S5`0#__Y(3W=4!`/__
MRQ;>U0$`__^P$]_5`0#__Y03X-4!`/__NA/AU0$`__^6$^+5`0#__\T6X]4!
M`/__FQ/DU0$`__^=$^75`0#__Y\3YM4!`/__SQ;GU0$`___1%NC5`0#__],6
MZ=4!`/__,!3JU0$`___5%NO5`0#__T$4[-4!`/__UQ;MU0$`__^K$^[5`0#_
M_P8`[]4!`/__V1;PU0$`__]L%/'5`0#__]<3\M4!`/__M!/SU0$`___;%O35
M`0#__XL3]=4!`/__DP3VU0$`__]/$_?5`0#__Y@$^-4!`/__W1;YU0$`___$
M!/K5`0#__VX4^]4!`/__:1/\U0$`__\=`/W5`0#__]\6_M4!`/__X1;_U0$`
M__^:!`#6`0#__\<"`=8!`/__XQ8"U@$`___E%@/6`0#__U04!-8!`/__I00%
MU@$`___&!`;6`0#__Z<$!]8!`/__YQ8(U@$`___'%@G6`0#__[(3"M8!`/__
M=A,+U@$`___5$PS6`0#__[83#=8!`/__N!,.U@$`___)%@_6`0#__XT3$-8!
M`/__DA,1U@$`___+%A+6`0#__[`3$]8!`/__E!,4U@$`__^Z$Q76`0#__Y83
M%M8!`/__S187U@$`__^;$QC6`0#__YT3&=8!`/__GQ,:U@$`___/%AO6`0#_
M_]$6'-8!`/__TQ8=U@$`__\P%![6`0#__]46']8!`/__010@U@$`___7%B'6
M`0#__ZL3(M8!`/__!@`CU@$`___9%B36`0#__VP4)=8!`/__UQ,FU@$`__^T
M$R?6`0#__]L6*-8!`/__BQ,IU@$`__^3!"K6`0#__T\3*]8!`/__F`0LU@$`
M___=%BW6`0#__\0$+M8!`/__;A0OU@$`__]I$S#6`0#__QT`,=8!`/__WQ8R
MU@$`___A%C/6`0#__YH$--8!`/__QP(UU@$`___C%C;6`0#__^46-]8!`/__
M5!0XU@$`__^E!#G6`0#__\8$.M8!`/__IP0[U@$`___G%CS6`0#__\<6/=8!
M`/__LA,^U@$`__]V$S_6`0#__]430-8!`/__MA-!U@$`__^X$T+6`0#__\D6
M0]8!`/__C1-$U@$`__^2$T76`0#__\L61M8!`/__L!-'U@$`__^4$TC6`0#_
M_[H32=8!`/__EA-*U@$`___-%DO6`0#__YL33-8!`/__G1--U@$`__^?$T[6
M`0#__\\63]8!`/__T190U@$`___3%E'6`0#__S`44M8!`/__U193U@$`__]!
M%%36`0#__]<65=8!`/__JQ-6U@$`__\&`%?6`0#__]D66-8!`/__;!19U@$`
M___7$UK6`0#__[036]8!`/__VQ9<U@$`__^+$UW6`0#__Y,$7M8!`/__3Q-?
MU@$`__^8!&#6`0#__]T68=8!`/__Q`1BU@$`__]N%&/6`0#__VD39-8!`/__
M'0!EU@$`___?%F;6`0#__^$69]8!`/__F@1HU@$`___'`FG6`0#__^,6:M8!
M`/__Y19KU@$`__]4%&S6`0#__Z4$;=8!`/__Q@1NU@$`__^G!&_6`0#__^<6
M<-8!`/__QQ9QU@$`__^R$W+6`0#__W83<]8!`/__U1-TU@$`__^V$W76`0#_
M_[@3=M8!`/__R19WU@$`__^-$WC6`0#__Y(3>=8!`/__RQ9ZU@$`__^P$WO6
M`0#__Y03?-8!`/__NA-]U@$`__^6$W[6`0#__\T6?]8!`/__FQ.`U@$`__^=
M$X'6`0#__Y\3@M8!`/__SQ:#U@$`___1%H36`0#__],6A=8!`/__,!2&U@$`
M___5%H?6`0#__T$4B-8!`/__UQ:)U@$`__^K$XK6`0#__P8`B]8!`/__V1:,
MU@$`__]L%(W6`0#__]<3CM8!`/__M!./U@$`___;%I#6`0#__XL3D=8!`/__
MDP22U@$`__]/$Y/6`0#__Y@$E-8!`/__W1:5U@$`___$!);6`0#__VX4E]8!
M`/__:1.8U@$`__\=`)G6`0#__]\6FM8!`/__X1:;U@$`__^:!)S6`0#__\<"
MG=8!`/__XQ:>U@$`___E%I_6`0#__U04H-8!`/__I02AU@$`___&!*+6`0#_
M_Z<$H]8!`/__YQ:HU@$`__\9.*G6`0#__QPXJM8!`/__RQ.KU@$`__\?.*S6
M`0#__R(XK=8!`/__)3BNU@$`__\H.*_6`0#__WH%L-8!`/__*SBQU@$`__\N
M.++6`0#__S$XL]8!`/__-#BTU@$`__\W.+76`0#__SHXMM8!`/__/3BWU@$`
M___.$[C6`0#__T`XN=8!`/__>@6ZU@$`__]#.+O6`0#__T8XO-8!`/__7@6]
MU@$`__]).+[6`0#__TPXO]8!`/__3SC`U@$`__^M$\'6`0#__U(XPM8!`/__
M5CC#U@$`__]8!<36`0#__\@3Q=8!`/__63C&U@$`__]]!<?6`0#__UPXR-8!
M`/__7SC)U@$`__];!<K6`0#__\01R]8!`/__<07,U@$`__]B.,W6`0#__Q0`
MSM8!`/__93C/U@$`__]H.-#6`0#__VLXT=8!`/__;@72U@$`__]T!=/6`0#_
M_W<%U-8!`/__;CC5U@$`__]Q.-;6`0#__W0XU]8!`/__:P78U@$`__]W.-G6
M`0#__WHXVM8!`/__?3C;U@$`__^`.-S6`0#__WT%W=8!`/__6P7>U@$`__]Q
M!=_6`0#__VL%X-8!`/__=`7AU@$`__]N!>+6`0#__QDXX]8!`/__'#CDU@$`
M___+$^76`0#__Q\XYM8!`/__(CCGU@$`__\E..C6`0#__R@XZ=8!`/__>@7J
MU@$`__\K..O6`0#__RXX[-8!`/__,3CMU@$`__\T..[6`0#__S<X[]8!`/__
M.CCPU@$`__\]./'6`0#__\X3\M8!`/__0#CSU@$`__]Z!?36`0#__T,X]=8!
M`/__1CCVU@$`__]>!??6`0#__TDX^-8!`/__3#CYU@$`__]/./K6`0#__ZT3
M^]8!`/__4CC\U@$`__]6./W6`0#__U@%_M8!`/__R!/_U@$`__]9.`#7`0#_
M_WT%`=<!`/__7#@"UP$`__]?.`/7`0#__UL%!-<!`/__Q!$%UP$`__]Q!0;7
M`0#__V(X!]<!`/__%``(UP$`__]E.`G7`0#__V@X"M<!`/__:S@+UP$`__]N
M!0S7`0#__W0%#=<!`/__=P4.UP$`__]N.`_7`0#__W$X$-<!`/__=#@1UP$`
M__]K!1+7`0#__W<X$]<!`/__>C@4UP$`__]].!77`0#__X`X%M<!`/__?047
MUP$`__];!1C7`0#__W$%&=<!`/__:P4:UP$`__]T!1O7`0#__VX%'-<!`/__
M&3@=UP$`__\<.![7`0#__\L3']<!`/__'S@@UP$`__\B."'7`0#__R4X(M<!
M`/__*#@CUP$`__]Z!237`0#__RLX)=<!`/__+C@FUP$`__\Q."?7`0#__S0X
M*-<!`/__-S@IUP$`__\Z."K7`0#__STX*]<!`/__SA,LUP$`__]`."W7`0#_
M_WH%+M<!`/__0S@OUP$`__]&.##7`0#__UX%,=<!`/__23@RUP$`__],.#/7
M`0#__T\X--<!`/__K1,UUP$`__]2.#;7`0#__U8X-]<!`/__6`4XUP$`___(
M$SG7`0#__UDX.M<!`/__?04[UP$`__]<.#S7`0#__U\X/=<!`/__6P4^UP$`
M___$$3_7`0#__W$%0-<!`/__8CA!UP$`__\4`$+7`0#__V4X0]<!`/__:#A$
MUP$`__]K.$77`0#__VX%1M<!`/__=`5'UP$`__]W!4C7`0#__VXX2=<!`/__
M<3A*UP$`__]T.$O7`0#__VL%3-<!`/__=SA-UP$`__]Z.$[7`0#__WTX3]<!
M`/__@#A0UP$`__]]!5'7`0#__UL%4M<!`/__<053UP$`__]K!537`0#__W0%
M5=<!`/__;@56UP$`__\9.%?7`0#__QPX6-<!`/__RQ-9UP$`__\?.%K7`0#_
M_R(X6]<!`/__)3A<UP$`__\H.%W7`0#__WH%7M<!`/__*SA?UP$`__\N.&#7
M`0#__S$X8=<!`/__-#ABUP$`__\W.&/7`0#__SHX9-<!`/__/3AEUP$`___.
M$V;7`0#__T`X9]<!`/__>@5HUP$`__]#.&G7`0#__T8X:M<!`/__7@5KUP$`
M__]).&S7`0#__TPX;=<!`/__3SANUP$`__^M$V_7`0#__U(X<-<!`/__5CAQ
MUP$`__]8!7+7`0#__\@3<]<!`/__63ATUP$`__]]!777`0#__UPX=M<!`/__
M7SAWUP$`__];!7C7`0#__\01>=<!`/__<05ZUP$`__]B.'O7`0#__Q0`?-<!
M`/__93A]UP$`__]H.'[7`0#__VLX?]<!`/__;@6`UP$`__]T!8'7`0#__W<%
M@M<!`/__;CB#UP$`__]Q.(37`0#__W0XA=<!`/__:P6&UP$`__]W.(?7`0#_
M_WHXB-<!`/__?3B)UP$`__^`.(K7`0#__WT%B]<!`/__6P6,UP$`__]Q!8W7
M`0#__VL%CM<!`/__=`6/UP$`__]N!9#7`0#__QDXD=<!`/__'#B2UP$`___+
M$Y/7`0#__Q\XE-<!`/__(CB5UP$`__\E.);7`0#__R@XE]<!`/__>@68UP$`
M__\K.)G7`0#__RXXFM<!`/__,3B;UP$`__\T.)S7`0#__S<XG=<!`/__.CB>
MUP$`__\].)_7`0#__\X3H-<!`/__0#BAUP$`__]Z!:+7`0#__T,XH]<!`/__
M1CBDUP$`__]>!:77`0#__TDXIM<!`/__3#BGUP$`__]/.*C7`0#__ZT3J=<!
M`/__4CBJUP$`__]6.*O7`0#__U@%K-<!`/__R!.MUP$`__]9.*[7`0#__WT%
MK]<!`/__7#BPUP$`__]?.+'7`0#__UL%LM<!`/__Q!&SUP$`__]Q!;37`0#_
M_V(XM=<!`/__%`"VUP$`__]E.+?7`0#__V@XN-<!`/__:SBYUP$`__]N!;K7
M`0#__W0%N]<!`/__=P6\UP$`__]N.+W7`0#__W$XOM<!`/__=#B_UP$`__]K
M!<#7`0#__W<XP=<!`/__>CC"UP$`__]].,/7`0#__X`XQ-<!`/__?07%UP$`
M__];!<;7`0#__W$%Q]<!`/__:P7(UP$`__]T!<G7`0#__VX%SM<!`/__31//
MUP$`__\;`-#7`0#__PP`T=<!`/__#@#2UP$`__]1$]/7`0#__U,3U-<!`/__
M51/5UP$`__]7$];7`0#__UD3U]<!`/__6Q/8UP$`__]-$]G7`0#__QL`VM<!
M`/__#`#;UP$`__\.`-S7`0#__U$3W=<!`/__4Q/>UP$`__]5$]_7`0#__U<3
MX-<!`/__61/AUP$`__];$^+7`0#__TT3X]<!`/__&P#DUP$`__\,`.77`0#_
M_PX`YM<!`/__41/GUP$`__]3$^C7`0#__U43Z=<!`/__5Q/JUP$`__]9$^O7
M`0#__UL3[-<!`/__31/MUP$`__\;`.[7`0#__PP`[]<!`/__#@#PUP$`__]1
M$_'7`0#__U,3\M<!`/__51/SUP$`__]7$_37`0#__UD3]=<!`/__6Q/VUP$`
M__]-$_?7`0#__QL`^-<!`/__#`#YUP$`__\.`/K7`0#__U$3^]<!`/__4Q/\
MUP$`__]5$_W7`0#__U<3_M<!`/__61/_UP$`__];$P#X`@"$./__`?@"`(@X
M__\"^`(`C#C__P/X`@"0./__!/@"`)4X__\%^`(`&2W__P;X`@"9./__!_@"
M`)TX__\(^`(`H3C__PGX`@"E./__"O@"`!TM__\+^`(`J3C__PSX`@"M./__
M#?@"`+$X__\.^`(`(2W__P_X`@"V./__$/@"`+HX__\1^`(`OCC__Q+X`@#"
M./__$_@"`,<X__\4^`(`RSC__Q7X`@#/./__%O@"`-,X__\7^`(`V#C__QCX
M`@#<./__&?@"`.`X__\:^`(`Y#C__QOX`@#H./__'/@"`.PX__\=^`(`3Q?_
M_Q[X`@#Q./__'_@"`/4X__\@^`(`^3C__R'X`@#]./__(O@"``$Y__\C^`(`
M!3G__R3X`@`).?__)?@"``TY__\F^`(`)2W__R?X`@`I+?__*/@"`!$Y__\I
M^`(`%3G__RKX`@`9.?__*_@"`%4J__\L^`(`'3G__RWX`@`M+?__+O@"`"$Y
M__\O^`(`)3G__S#X`@`I.?__,?@"`"TY__\R^`(`+3G__S/X`@`M.?__-/@"
M`#$Y__\U^`(`-CG__S;X`@`Z.?__-_@"`#XY__\X^`(`0CG__SGX`@!'.?__
M.O@"`$LY__\[^`(`3SG__SSX`@!3.?__/?@"`%<Y__\^^`(`6SG__S_X`@!?
M.?__0/@"`&,Y__]!^`(`9SG__T+X`@!K.?__0_@"`&\Y__]$^`(`<SG__T7X
M`@!W.?__1O@"`'<Y__]'^`(`>SG__TCX`@!_.?__2?@"`(,Y__]*^`(`ASG_
M_TOX`@"+.?__3/@"`#4M__]-^`(`CSG__T[X`@"3.?__3_@"`)<Y__]0^`(`
MG2S__U'X`@";.?__4O@"`)\Y__]3^`(`HSG__U3X`@"G.?__5?@"`*LY__]6
M^`(`KSG__U?X`@"S.?__6/@"`+<Y__]9^`(`NSG__UKX`@#`.?__6_@"`,0Y
M__]<^`(`R#G__UWX`@#,.?__7O@"`-`Y__]?^`(`U#G__V#X`@#8.?__8?@"
M`-TY__]B^`(`XCG__V/X`@#F.?__9/@"`.HY__]E^`(`[CG__V;X`@#R.?__
M9_@"`/8Y__]H^`(`^CG__VGX`@#_.?__:O@"``,Z__]K^`(``SK__VSX`@`'
M.O__;?@"``PZ__]N^`(`$#K__V_X`@!%*O__</@"`!0Z__]Q^`(`&#K__W+X
M`@`=.O__<_@"`"$Z__]T^`(`)3K__W7X`@"W%___=O@"`"DZ__]W^`(`+3K_
M_WCX`@"_%___>?@"`#$Z__]Z^`(`-3K__WOX`@`Y.O__?/@"`#XZ__]]^`(`
M0CK__W[X`@!'.O__?_@"`$LZ__^`^`(`3SK__X'X`@!3.O__@O@"`%<Z__^#
M^`(`6SK__X3X`@!?.O__A?@"`&,Z__^&^`(`9SK__X?X`@!K.O__B/@"`&\Z
M__^)^`(`<SK__XKX`@!X.O__B_@"`'PZ__^,^`(`@#K__XWX`@"$.O__CO@"
M`'4I__^/^`(`B#K__Y#X`@#G%___D?@"`(TZ__^2^`(`C3K__Y/X`@"2.O__
ME/@"`)8Z__^5^`(`ECK__Y;X`@":.O__E_@"`)XZ__^8^`(`HSK__YGX`@"H
M.O__FO@"`*PZ__^;^`(`L#K__YSX`@"T.O__G?@"`+@Z__^>^`(`O#K__Y_X
M`@#`.O__H/@"`,0Z__^A^`(`R#K__Z+X`@#,.O__H_@"`$DM__^D^`(`T#K_
M_Z7X`@#5.O__IO@"`-DZ__^G^`(`W3K__ZCX`@#A.O__J?@"`-TZ__^J^`(`
MY3K__ZOX`@!1+?__K/@"`.DZ__^M^`(`[3K__Z[X`@#Q.O__K_@"`/4Z__^P
M^`(`52W__['X`@`)*?__LO@"`/DZ__^S^`(`_3K__[3X`@`!.___M?@"``4[
M__^V^`(`"3O__[?X`@`-.___N/@"`!$[__^Y^`(`%CO__[KX`@`:.___N_@"
M`!X[__^\^`(`(CO__[WX`@`F.___OO@"`"H[__^_^`(`+SO__\#X`@`S.___
MP?@"`#<[___"^`(`.SO__\/X`@`_.___Q/@"`$,[___%^`(`1SO__\;X`@!+
M.___Q_@"`$\[___(^`(`62W__\GX`@!3.___RO@"`%<[___+^`(`7#O__\SX
M`@!@.___S?@"`&0[___.^`(`:#O__\_X`@!A+?__T/@"`&P[___1^`(`<#O_
M_]+X`@!T.___T_@"`'@[___4^`(`?#O__]7X`@"`.___UO@"`(0[___7^`(`
MB#O__]CX`@!Y*?__V?@"`(P[___:^`(`D#O__]OX`@"4.___W/@"`)@[___=
M^`(`G#O__][X`@"A.___W_@"`*4[___@^`(`J3O__^'X`@"M.___XO@"`&4M
M___C^`(`L3O__^3X`@"V.___Y?@"`+H[___F^`(`OCO__^?X`@#".___Z/@"
M`,8[___I^`(`RCO__^KX`@#..___Z_@"`-([___L^`(`UCO__^WX`@#;.___
M[O@"`-\[___O^`(`XSO___#X`@#G.___\?@"`.P[___R^`(`\#O___/X`@#T
M.___]/@"`/@[___U^`(`B2K___;X`@#\.___]_@"```\___X^`(`!3S___GX
M`@`*//__^O@"``\\___[^`(`$SS___SX`@`8//___?@"`!P\___^^`(`(#S_
M___X`@`D//__`/D"`"@\__\!^0(`:2W__P+Y`@#5*___`_D"`"P\__\$^0(`
M,#S__P7Y`@`T//__!OD"`#@\__\'^0(`/3S__PCY`@!!//__"?D"`$4\__\*
M^0(`23S__POY`@!-//__#/D"`%$\__\-^0(`53S__P[Y`@!://__#_D"`%X\
M__\0^0(`8CS__Q'Y`@!G//__$OD"`&P\__\3^0(`<#S__Q3Y`@!T//__%?D"
M`'@\__\6^0(`?#S__Q?Y`@"`//__&/D"`(0\__\9^0(`B#S__QKY`@",//__
M&_D"`)`\__\<^0(`E3S__QWY`@"9//__'OD"`)X\__\?^0(`HCS__R#Y`@"F
M//__(?D"`*H\__\B^0(`KCS__R/Y`@"R//__)/D"`+<\__\E^0(`NSS__R;Y
M`@"_//__)_D"`,0\__\H^0(`R3S__RGY`@#-//__*OD"`-$\__\K^0(`U3S_
M_RSY`@#9//__+?D"`-D\__\N^0(`W3S__R_Y`@#A//__,/D"`.4\__\Q^0(`
MZ3S__S+Y`@#M//__,_D"`/$\__\T^0(`]3S__S7Y`@#Y//__-OD"`/X\__\W
M^0(``CW__SCY`@!1*O__.?D"``<]__\Z^0(`##W__SOY`@`0/?__//D"`!4]
M__\]^0(`&CW__S[Y`@`?/?__/_D"`",]__]`^0(`)SW__T'Y`@`K/?__0OD"
M`#`]__]#^0(`-3W__T3Y`@`Z/?__1?D"`#\]__]&^0(`0SW__T?Y`@!#/?__
M2/D"`$<]__])^0(`2SW__TKY`@!//?__2_D"`%,]__],^0(`5SW__TWY`@!;
M/?__3OD"`&`]__]/^0(`O2G__U#Y`@!D/?__4?D"`&@]__]2^0(`;#W__U/Y
M`@"1+?__5/D"`'$]__]5^0(`=CW__U;Y`@#M+/__5_D"`'L]__]8^0(`?SW_
M_UGY`@"=+?__6OD"`(,]__];^0(`ASW__USY`@"+/?__7?D"`)`]__]>^0(`
MD#W__U_Y`@"5/?__8/D"`)D]__]A^0(`G3W__V+Y`@"B/?__8_D"`*8]__]D
M^0(`JCW__V7Y`@"N/?__9OD"`+,]__]G^0(`MSW__VCY`@"[/?__:?D"`+\]
M__]J^0(`PSW__VOY`@#'/?__;/D"`,P]__]M^0(`T#W__V[Y`@#4/?__;_D"
M`-@]__]P^0(`W#W__W'Y`@#@/?__<OD"`.0]__]S^0(`Z3W__W3Y`@#N/?__
M=?D"`/(]__]V^0(`]SW__W?Y`@#[/?__>/D"```^__]Y^0(`!#[__WKY`@"U
M+?__>_D"``@^__]\^0(`#3[__WWY`@`2/O__?OD"`!8^__]_^0(`&S[__X#Y
M`@`?/O__@?D"`"0^__^"^0(`*#[__X/Y`@`L/O__A/D"`#`^__^%^0(`-#[_
M_X;Y`@`X/O__A_D"`#P^__^(^0(`03[__XGY`@!&/O__BOD"`$L^__^+^0(`
MDCK__XSY`@!0/O__C?D"`%0^__^.^0(`6#[__X_Y`@!</O__D/D"`&`^__^1
M^0(`9#[__Y+Y`@!H/O__D_D"`&P^__^4^0(`<#[__Y7Y`@!T/O__EOD"`'@^
M__^7^0(`?#[__YCY`@"5*O__F?D"`($^__^:^0(`A3[__YOY`@")/O__G/D"
M`(T^__^=^0(`D3[__Y[Y`@"5/O__G_D"`,$M__^@^0(`F3[__Z'Y`@"=/O__
MHOD"`*$^__^C^0(`I3[__Z3Y`@"I/O__I?D"`*X^__^F^0(`LS[__Z?Y`@"X
M/O__J/D"`+P^__^I^0(`P#[__ZKY`@#$/O__J_D"`,@^__^L^0(`S3[__ZWY
M`@#1/O__KOD"`-8^__^O^0(`VC[__[#Y`@#>/O__L?D"`.,^__^R^0(`Z#[_
M_[/Y`@#L/O__M/D"`*DI__^U^0(`\#[__[;Y`@#T/O__M_D"`/@^__^X^0(`
M_#[__[GY`@``/___NOD"``0___^[^0(`"#___[SY`@`,/___O?D"`!`___^^
M^0(`%#___[_Y`@`8/___P/D"`!P____!^0(`(#___\+Y`@`D/___P_D"`"@_
M___$^0(`3QG__\7Y`@`L/___QOD"`#$____'^0(`-3___\CY`@`Y/___R?D"
M`#T____*^0(`03___\OY`@!%/___S/D"`$H____-^0(`3S___\[Y`@!3/___
MS_D"`%<____0^0(`6S___]'Y`@!?/___TOD"`&L9___3^0(`8S___]3Y`@!H
M/___U?D"`&P____6^0(`<#___]?Y`@!T/___V/D"`'@____9^0(`?3___]KY
M`@""/___V_D"`(8____<^0(`BC___]WY`@"./___WOD"`),____?^0(`ES__
M_^#Y`@";/___X?D"`*`____B^0(`I3___^/Y`@"I/___Y/D"`*T____E^0(`
ML3___^;Y`@"V/___Y_D"`+H____H^0(`OC___^GY`@#"/___ZOD"`,8____K
M^0(`RC___^SY`@#./___[?D"`-(____N^0(`US___^_Y`@#;/___\/D"`-\_
M___Q^0(`XS____+Y`@#H/___\_D"`.P____T^0(`\#____7Y`@#T/___]OD"
M`/@____W^0(`_3____CY`@`"0/__^?D"``9`___Z^0(`"D#___OY`@`.0/__
M_/D"`!-`___]^0(`%T#___[Y`@`<0/____D"`!Q`__\`^@(`($#__P'Z`@`D
M0/__`OH"`"E`__\#^@(`+4#__P3Z`@`Q0/__!?H"`#5`__\&^@(`.4#__P?Z
M`@`]0/__"/H"`$%`__\)^@(`14#__PKZ`@!*0/__"_H"`$Y`__\,^@(`4D#_
M_PWZ`@!60/__#OH"`%I`__\/^@(`7D#__Q#Z`@!B0/__$?H"`&=`__\2^@(`
M:T#__Q/Z`@!P0/__%/H"`'5`__\5^@(`*QK__Q;Z`@!Z0/__%_H"`#L:__\8
M^@(`?D#__QGZ`@""0/__&OH"`(9`__\;^@(`BD#__QSZ`@!/&O__'?H"`(Y`
M__\``````````,``P0#"`,,```$"`28"Q`"B'L4```#-`0`"`@(```````"@
M'@```!X`````!`$``````````````````````````````````````AX`````
M``````````````````````0>``````````````````````8>````````````
M``8!"`$````````*`0``````````#`$```````````````````````#'````
M``````````````````````````````````````H>```````````.`0``````
M```````,'@```````!`>```2'@`````.'@``````````R`#)`,H`O!X2`10!
M%@'+`+H>`````!H!!`(&`@```````+@>````````*`(8`1@>```:'@``````
M`````````/0!'`$``"`>'@$@`0``````````Y@$`````````````````````
M```B`0`````````````````````````````D`0```````"(>)AX````````>
M`@`````````````D'@```````"@>`````"H>````````````````S`#-`,X`
M*`$J`2P!,`'/`,@>`````,\!"`(*`@```````,H>```````````N`0`````L
M'@```````````````#`>````````````````````````Z`$`````````````
M,AX````````V`0``````````-!X`````````````.0$`````````````````
M```````]`0`````````````V'@```````#L!```\'@`````Z'@``````````
M```^'@``````````0!X``````````````````````````$(>````````````
M``````````````````````#X`4,!``#1``````!$'@``````````1P$`````
M````````1AX```````!%`0``2AX`````2!X``````````-(`TP#4`-4`3`%.
M`2X"U@#.'@``4`'1`0P"#@(`````H`','@``````````Z@$`````````````
M``````````!4'@``````````5AX`````````````````````````````````
M`````````````````````````````````%0!``````````!8'@``````````
M6`$0`A("````````6AX```````!6`0``````````7AX`````````````6@%<
M`0```````&`>``````````!@`0````````````!B'@`````8`EX!````````
M````````````````````````````````:AX``````````&0!````````````
M`&P>`````!H"8@$``'`>`````&X>``````````#9`-H`VP!H`6H!;`$``-P`
MYAYN`7`!TP$4`A8"`````*\!Y!YR'@```````'(!=AX``'0>````````````
M`````````'P>``````````````````````````````````!^'@``````````
M````````````````````````@!Z"'G0!````````AAZ$'@``````````````
M`````````(@>````````````````````````````````````````````````
M``"*'HP>````````````````````````````````````````````````````
M`````````/(>W0!V`?@>,@(``(X>>`'V'@````````````````````#T'@``
M``````````````````````````````````!Y`9`>````````>P$`````````
M`'T!`````````````)(>`````````````````````)0>``````````#@`.$`
MX@#C``$!`P$G`N0`HQ[E````S@$!`@,"````````H1X```$>``````4!````
M``````````````````````````````````,>````````````````````````
M```%'@`````````````````````''@`````````````'`0D!````````"P$`
M``````````T!````````````````````````YP``````````````````````
M```````````````````+'@``````````#P$`````````````#1X````````1
M'@``$QX`````#QX``````````.@`Z0#J`+T>$P$5`1<!ZP"['@`````;`04"
M!P(```````"Y'@```````"D"&0$9'@``&QX```````````````#U`1T!```A
M'A\!(0$``````````.<!````````````````````````(P$`````````````
M````````````````)0$````````C'B<>````````'P(`````````````)1X`
M```````I'@`````K'@``EAX``````````.P`[0#N`"D!*P$M`0``[P#)'@``
M``#0`0D""P(```````#+'@``````````+P$`````+1X`````````````````
M`#4!`````````````````````/`!````````````````````````````````
M`````````````````````#$>````````````````````````Z0$`````````
M````,QX````````W`0``````````-1X`````````````.@$`````````````
M```````````^`0`````````````W'@```````#P!```]'@`````['@``````
M```````_'@``````````01X``````````````````````````$,>````````
M``````````````````````````#Y`40!``#Q``````!%'@``````````2`$`
M````````````1QX```````!&`0``2QX`````21X``````````/(`\P#T`/4`
M30%/`2\"]@#/'@``40'2`0T"#P(`````H0'-'@``````````ZP$`````````
M``````````````!5'@``````````5QX`````````````````````````````
M`````````````````````````````````````%4!``````````!9'@``````
M````60$1`A,"````````6QX```````!7`0``````````7QX`````````````
M6P%=`0```````&$>``````````!A`0````````````!C'@`````9`E\!````
M````````````````````````````````````:QZ7'@```````&4!````````
M`````&T>`````!L"8P$``'$>`````&\>``````````#Y`/H`^P!I`6L!;0$`
M`/P`YQYO`7$!U`$5`A<"`````+`!Y1YS'@```````',!=QX``'4>````````
M`````````````'T>``````````````````````````````````!_'@``````
M````````````````````````````@1Z#'G4!````````AQZ%'@``F!X`````
M`````````````(D>````````````````````````````````````````````
M``````"+'HT>````````````````````````````````````````````````
M`````````````/,>_0!W`?D>,P(``(\>_P#W'ID>``````````````````#U
M'@````````````````````````````````````!Z`9$>````````?`$`````
M`````'X!`````````````),>`````````````````````)4>``````````#M
M'X4#````````````````````````````````````````````````````````
M``````````#!'P```````*8>I!X``*H>``````````"H'@``````````````
M``````````````````````````````````````````````#\`0````#B`0``
M````````````````````````````````````````````````````````````
M``````#`'KX>``#$'@``````````PAX`````````````````````````````
M`````````````````````````````-(>T!X``-8>``````````#4'@``````
M``````````````````````````````````````````````````````!,'@``
M```L`@````!.'@``````````````````````````````````````````````
M``````````````#;`=<!`````-4!````````````````V0$`````````````
M`````````````````````````````````````*<>I1X``*L>``````````"I
M'@``````````````````````````````````````````````````````````
M``#]`0````#C`0``````````````````````````````````````````````
M``````````````````````#!'K\>``#%'@``````````PQX`````````````
M`````````````````````````````````````````````-,>T1X``-<>````
M``````#5'@``````````````````````````````````````````````````
M``````````!-'@`````M`@````!/'@``````````````````````````````
M``````````````````````````````#<`=@!`````-8!````````````````
MV@$``````````````````````````````````````````````````+`>KAX`
M`+0>``````````"R'@``````````````````````````````````````````
M````````````````L1ZO'@``M1X``````````+,>````````````````````
M```````````````````````````````````````4'A8>````````````````
M````````````````````````````````````````````````````````````
M`!4>%QX`````````````````````````````````````````````````````
M````````````````````````4!Y2'@``````````````````````````````
M``````````````````````````````````````````````!1'E,>````````
M````````````````````````````````````````````````````````````
M`````````-P>VAX``.`>``````````#>'@````````````````````#B'@``
M````````````````````````````````W1[;'@``X1X``````````-\>````
M`````````````````.,>``````````````````````````````````#J'N@>
M``#N'@``````````[!X`````````````````````\!X`````````````````
M`````````````````.L>Z1X``.\>``````````#M'@``````````````````
M``#Q'@``````````````````````````````````NA^&`P````"Y'[@?````
M``````````````````@?"1\```````````````````````````````"\'P``
M``#('X@#````````````````````````````````&!\9'P``````````````
M`````````````````````````,H?B0,`````````````````````````````
M```H'RD?````````````````````````````````S!\`````VA^*`P````#9
M']@?``"J`P```````````````#@?.1\`````````````````````````````
M``````````#X'XP#````````````````````````````````2!])'P``````
M`````````````````````````````````.H?C@,`````Z1_H'P``JP,`````
M`````````````%D?````````````````````````````````````````^A^/
M`P```````````````````````````````&@?:1\`````````````````````
M``````````#\'P````!P'ZP#`````+$?L!\``````````````````````!\!
M'P````````````````````````````"V'[,?`````'(?K0,`````````````
M```````````````````0'Q$?````````````````````````````````````
M````=!^N`P```````````````````````````````"`?(1\`````````````
M````````````````QA_#'P````!V'Z\#`````-$?T!\``,H#````````````
M````,!\Q'P````````````````````````````#6'P```````'@?S`,`````
M``````````````````````````!`'T$?````````````````````````````
M`````````````````````````````````````````````````.0?Y1\`````
M``````````````````````````````````!Z'\T#`````.$?X!\``,L#````
M````````````4!]1'P````````````````````````````#F'P```````'P?
MS@,```````````````````````````````!@'V$?````````````````````
M`````````/8?\Q\`````TA^0`P``````````````````````````````````
M````````````````````````````````UQ\```````#B'[`#````````````
M``````````````````````````````````````````````````````#G'P``
M````````TP,`````````````U`,`````````````````````````````````
M`````````````````````````````````````````-`$``#2!```````````
M````````````````````````````````````````````````````!```````
M````U@0```$$````````````````````````````````````````````````
M``````````````````````````#!!```W`0`````````````````````````
M````````````````````````````````````#00```````#B!!D$``#D!```
M````````````````````````````````````````````````````````````
M`````````.X$#@0``/`$`````/($````````````````````````````````
M``````````````````````````````````#1!```TP0`````````````````
M````````````````````````````````````````````4`0``````````-<$
M``!1!```````````````````````````````````````````````````````
M````````````````````P@0``-T$````````````````````````````````
M`````````````````````````````%T$````````XP0Y!```Y00`````````
M````````````````````````````````````````````````````````````
M``#O!%X$``#Q!`````#S!```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"L
M'@````"V'@``````````````````````````````````````````````````
M`````````````````````*T>`````+<>````````````````````````````
M```````````````````````````````````````"'P0?````````````````
M```````````````````````````````````````````````````&'X`?````
M``,?!1\`````````````````````````````````````````````````````
M``````````````<?@1\`````"A\,'P``````````````````````````````
M````````````````````````````````````#A^('P`````+'PT?````````
M```````````````````````````````````````````````````````````/
M'XD?`````!(?%!\`````````````````````````````````````````````
M````````````````````````````````$Q\5'P``````````````````````
M```````````````````````````````````````````````````````:'QP?
M````````````````````````````````````````````````````````````
M`````````````````!L?'1\`````````````````````````````````````
M````````````````````````````````````````(A\D'P``````````````
M````````````````````````````````````````````````````)A^0'P``
M```C'R4?````````````````````````````````````````````````````
M```````````````G'Y$?`````"H?+!\`````````````````````````````
M`````````````````````````````````````"X?F!\`````*Q\M'P``````
M````````````````````````````````````````````````````````````
M+Q^9'P`````R'S0?````````````````````````````````````````````
M```````````````````````V'P```````#,?-1\`````````````````````
M`````````````````````````````````````````````#<?````````.A\\
M'P``````````````````````````````````````````````````````````
M````````/A\````````['ST?````````````````````````````````````
M```````````````````````````````_'P```````$(?1!\`````````````
M````````````````````````````````````````````````````````````
M````0Q]%'P``````````````````````````````````````````````````
M``````````````````````````!*'TP?````````````````````````````
M`````````````````````````````````````````````````$L?31\`````
M````````````````````````````````````````````````````````````
M````````````4A]4'P``````````````````````````````````````````
M````````````````````````5A\```````!3'U4?````````````````````
M``````````````````````````````````````````````!7'P```````%L?
M71\`````````````````````````````````````````````````````````
M`````````%\?````````8A]D'P``````````````````````````````````
M````````````````````````````````9A^@'P````!C'V4?````````````
M``````````````````````````````````````````````````````!G'Z$?
M`````&H?;!\`````````````````````````````````````````````````
M`````````````````&X?J!\`````:Q]M'P``````````````````````````
M````````````````````````````````````````;Q^I'P````#-'\X?````
M````````````````````````````````````````````````````````````
M``#/'P```````-T?WA\`````````````````````````````````````````
M`````````````````````````-\?````````````````````````````````
M`````````````````````````````````````````````````````'`P<3``
M````````````````````````````````````````````````````````````
M````````````````<S!T,```````````````````````````````````````
M``````````````````````````````````````!V,'<P````````````````
M````````````````````````````````````````````````````````````
M`'DP>C``````````````````````````````````````````````````````
M````````````````````````?#!],```````````````````````````````
M``````````````````````````````````````````````#0,-$P````````
M````````````````````````````````````````````````````````````
M`````````-,PU#``````````````````````````````````````````````
M````````````````````````````````UC#7,```````````````````````
M``````````````````````````````````````````````````````#9,-HP
M````````````````````````````````````````````````````````````
M`````````````````-PPW3``````)P8B!B<&(P8G!B4&QPG+"<<)S`E'"TL+
M1PM("T<+3`O&"\H+Q@O,"\8,R@S&#,<,Q@S(#$8-2@U&#4P-V0W:#=D-W`W9
M#=X-````````````````````````````````.`-N(C@#8"(X`V\B!P,>'@(#
M-`$'`Q\>!`/>`0$#^@$!`P@>`0,N'@0#*@(!`_X!!`/?`0$#^P$!`PD>`0,O
M'@0#*P(!`_\!!P-D'@<#91X'`V8>!P-G'@$#>!X!`WD>"`-Z'@@#>QX'`YL>
M#`/N`00#[`$$`^T!!`/@`00#X0$&`QP>!@,='@0#,`($`S$"#`/O`10#[!]%
M`[0?10/$'T4#]!\(`P<$`0,#!`@#W@0!`PP$"`/F!`@#]`0(`_@$"`/L!`$#
M4P0(`]\$`0-<!`@#YP0(`_4$"`/Y!`@#[00(`U<$#P-V!`\#=P0(`]H$"`/;
M!`@#Z@0(`^L$5`8D!E0&)@94!L(&5`;3!E0&P`8\"2D)/`DQ"3P)-`G7"Y0+
MO@O+"U8,2`S5#,`,U0S+##X-2PW*#=T-+A`F$`0#.!X$`SD>!`-<'@0#71X'
M`V@>!P-I'@(#QAX"`\<>`@/8'@(#V1Y%`X(?10.#'T4#A!]%`X4?10.&'T4#
MAQ]%`XH?10.+'T4#C!]%`XT?10..'T4#CQ]%`Y(?10.3'T4#E!]%`Y4?10.6
M'T4#EQ]%`YH?10.;'T4#G!]%`YT?10.>'T4#GQ]%`Z(?10.C'T4#I!]%`Z4?
M10.F'T4#IQ]%`ZH?10.K'T4#K!]%`ZT?10.N'T4#KQ]%`[(?10/"'T4#\A]%
M`[<?10/''T4#]Q\X`YHA.`.;(3@#KB$X`\TA.`//(3@#SB$X`P0B.`,)(C@#
M#"(X`R0B.`,F(C@#02(X`T0B.`-'(C@#22(X`VTB.`-B(C@#<"(X`W$B.`-T
M(C@#=2(X`W@B.`-Y(C@#@"(X`X$B.`/@(C@#X2(X`X0B.`.%(C@#B"(X`XDB
M.`/B(C@#XR(X`ZPB.`.M(C@#KB(X`Z\B.`/J(C@#ZR(X`^PB.`/M(IDPE#"9
M,$PPF3!.,)DP4#"9,%(PF3!4,)DP5C"9,%@PF3!:,)DP7#"9,%XPF3!@,)DP
M8C"9,&4PF3!G,)DP:3"9,)XPF3#T,)DPK#"9,*XPF3"P,)DPLC"9,+0PF3"V
M,)DPN#"9,+HPF3"\,)DPOC"9,,`PF3#",)DPQ3"9,,<PF3#),)DP]S"9,/@P
MF3#Y,)DP^C"9,/XP````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````DP"4`)4```````$``@`#``0`!0"6``8`
M!P`(`)<`"0`*``L`#``-``X````/`!``$0`2`!,`%``5`!8`%P``````````
M```````8`!D`&@`;`!P`F``=`!X`'P`@`"$`(@`C`"0`)0`F````)P`H`"D`
M*@`K`"P`+0`N`"\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````,```````````````````````````````````````````
M`````````````````````````#$```"9`)H`,@";```````S````````````
MG````````````#0`-0"=````G@`````````V```````````````W````GP"@
M`#@`H0``````.0```````````*(````````````Z`#L`HP```*0`````````
M/```````````````/0`^```````````````````````````````````````_
M`$``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$$`0@``````````````````````
M``````````"E`*8```````````"G`*@`````````````````J0"J`*L`K```
M`````````````````````````````````````````````````*T`````````
M````````````````````````````````````````````````````````````
M`````````````````$,`1````````````````````````````````````$4`
M1@````````````````"N````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"O`+``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"Q`+(`LP"T````````````M0"V````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"W````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````90%F
M`6<!:`%I`0``:@%K`6P!;0%N`6\!<`$`````<0$``'(!``!S`70!````````
M````````=0$``````````````````'8!=P%X`7D!>@%[`0``````````?`%]
M`0``?@%_`0``````````````````````````````````````````@`$`````
M@0$`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'`````````$@```!)````2@``````````````
M2P```+@`````````3`````````!-``````"Y````N@``````3@````````!/
M````4````%$``````````````%(```!3`````````%0`````````50!6`%<`
M`````+L`````````6```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"\````````````````````````
M`%D``````+T```!:`%L`O@!<````OP````````#`````````````70``````
M``#!`````````,(```##``````!>``````#$````7P!@`,4`80```,8`````
M````QP```````````&(`````````R`````````#)````R@``````````````
M````````RP``````````````````````````````````````````````````
M````````````````````````````S`#-````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#.`,\`
M`````````````````````````````````````-``T0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````&,`````````````````````````````````
M`````````````````````````````````````````````````````-(```#3
M``````````````````````"$`84!A@$`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````U```````````````````````````````````````````
M`-4``````-8`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#7````````
M````````````V```````V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"'`0````````````````````!D````
M`````````````````````````````````````(@!````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B0$`````````````````````90``````````````````````
M````````````````B@&+`0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````V@``
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(P!````
M``````````````!F`-L`````````````````````````````````````````
MC0$`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````W```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#=``````".`0```````&<`````````W@``````````
M`````````````````(\!D`$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````)$!
M``````````````````!H`-\`````````````````````````````````````
M````D@$`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"3`0``````````E`$```````````````````````!I``````#@
M``````"5`0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````.$`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````.(`XP``````````````````````````````````
M`````````````````````````````````````````````````````````.0`
MY0````````````````#F`.<`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````:@!K````````````````````````````````````````````````````
M````````Z`#I````````````````````````````````````````````````
M`.H`ZP``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````;`!M`.P`[0#N`.\`\`#Q`&X`;P#R`/,`]`#U`/8`
M]P!P`'$`````````````````<@!S`````````````````'0`=0#X`/D`^@#[
M`/P`_0!V`'<`_@#_```!`0$"`0,!>`!Y`````````````````'H`>P``````
M``````````!\`'T`````````````````?@!_`````````````````(``@0``
M`````````````````((`````````````````@P"$``0!!0$&`0<!"`$)`84`
MA@`*`0L!#`$-`0X!#P$0`0```````!$!```````````````````2`0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````!,!`````````````````````(<`````````
M````````%`$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````%0$``````````````````(@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````6`0``%P$``!@!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````!D!
M```:`0``&P$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````!P!```````````=`0`````>`0``````````````````````
M```````````````````````````````````````?`0``(`$`````````````
M`````````````````````````````````````````````"$!````````````
M````(@$``",!`````"0!```````````E`0``````````````````````````
M````````````````````````)@$`````)P$H`0``````````````````````
M`````````"D!*@$`````*P$L`0`````M`2X!+P$P`0``````````,0$R`0``
M```S`30!````````````````````````-0$V`0``````````````````````
M`````````````````#<!`````````````#@!.0$``#H!````````````````
M.P$\`3T!/@$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````_`0``````````0`$``$$!``!"
M`0``0P$``$0!``!%`0``1@$``$<!``!(`0``20$``$H!``!+`0````!,`0``
M30$``$X!````````````````B0``````B@``````BP``````C```````C0``
M````````````````````````````````````````````````````````````
M````````````````@@&#`0````!/`0````````````````````!0`0``````
M````40$``%(!``!3`0``5`$``%4!``!6`0``5P$``%@!``!9`0``6@$``%L!
M``!<`0````!=`0``7@$``%\!````````````````C@``````CP``````D```
M````D0``````D@``````````````````````````````````````````````
M`````&`!80%B`6,!``````````````````````````!D`0````````$``@`#
M``0``!$%```1`!$&```1!P`(``D``!$`$0H``!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$+``P``!$-``X``!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$/
M`````````````````````````````````````````$-(05)3150`05-#24D`
M551&+3@`U#(%"/TQ!0A@-04(@C,%".$R!0C4-`4(JS(%"*LR!0BK,@4(````
M```````#`````````*#8"0@#`````````.#E"@@!```````````````%````
M`````(`4"@@%`````````"`4"@@%`````````(`2"@@%`````````"`2"@@%
M`````````$`0"@@%```````````0"@@%`````````&`/"@@%`````````"`/
M"@@%`````````*`-"@@%`````````$`-"@@"```````````````&````````
M`*`-"@@'````_?___^`)"@@(````_?___P#H"0@$````^____X#H"@@`````
M````````````````````````````````````````````````H``````````@
M````````````````````@!8````````@`````````````````````"``````
M```@`````````````````````2`````````@`````````````````````B``
M```````@`````````````````````R`````````@````````````````````
M!"`````````@````````````````````!2`````````@````````````````
M````!B`````````@````````````````````!R`````````@````````````
M````````""`````````@````````````````````"2`````````@````````
M````````````"B`````````@````````````````````"R`````````@````
M````````````````+R`````````@````````````````````7R`````````@
M`````````````````````#`````````@````````````````````````````
M``````````````````````````````````````````````,`````````X.4*
M"`,`````````0&4*"`$```````````````4`````````(!0*"`4`````````
M@!(*"`4`````````(!0*"`4`````````@!(*"`4`````````(!(*"`4`````
M````0!`*"`4``````````!`*"`4`````````8`\*"`4`````````H`T*"`4`
M````````0`T*"`4`````````8-L)"`(```````````````8`````````H`T*
M"`<```#]____X`D*"`@```#]____`.@)"`0```#[____@.@*"```````````
M```````````````````````````````````````````````````````````!
M```````````````````````````````"````````````````````````````
M```#```````````````````````````````$````````````````````````
M```````%```````````````````````````````&````````````````````
M```````````'```````````````````````````````(````````````````
M```````````````)```````````````````````````````*````````````
M```````````````````+```````````````````````````````,````````
M```````````````````````-```````````````````````````````.````
M```````````````````````````/```````````````````````````````0
M```````````````````````````````1````````````````````````````
M```2```````````````````````````````3````````````````````````
M```````4```````````````````````````````5````````````````````
M```````````6```````````````````````````````7````````````````
M```````````````8```````````````````````````````9````````````
M```````````````````:```````````````````````````````;````````
M```````````````````````<```````````````````````````````=````
M```````````````````````````>```````````````````````````````?
M```````````````````````````````@````````````````````````````
M```A```````````````````````````````B````````````````````````
M```````C```````````````````````````````D````````````````````
M```````````E```````````````````````````````F````````````````
M```````````````G```````````````````````````````H````````````
M```````````````````I```````````````````````````````J````````
M```````````````````````K```````````````````````````````L````
M```````````````````````````O```````````````````````````````[
M```````````````````````````````\````````````````````````````
M```]```````````````````````````````^````````````````````````
M```````_``````````````````````````````!`````````````````````
M``````````!;``````````````````````````````!<````````````````
M``````````````!=``````````````````````````````!>````````````
M``````````````````!?``````````````````````````````!@````````
M``````````````````````![``````````````````````````````!\````
M``````````````````````````!]``````````````````````````````!^
M``````````````````````````````!_````````````````````````````
M```",```````````````````````````````````````````````````````
M``````````````````4`````````(!0*"`4`````````@!(*"`4`````````
M(!(*"`4`````````0!`*"`4``````````!`*"`4`````````8`\*"`4`````
M````H`T*"`4`````````0`T*"`(```````````````8`````````H`T*"`<`
M``#]____X`D*"`@```#]____`.@)"``````````````````````%````````
M`"`4"@@%`````````(`2"@@%`````````"`2"@@%`````````$`0"@@%````
M```````0"@@%`````````&`/"@@%`````````*`-"@@%`````````$`-"@@"
M```````````````&`````````*`-"@@'````_?___^`)"@@(````_?___P#H
M"0@``````````````````````P````````#@Y0H(`0``````````````!0``
M``````"`%`H(!0`````````@%`H(!0````````"`$@H(!0`````````@$@H(
M!0````````!`$`H(!0``````````$`H(!0````````!@#PH(!0`````````@
M#PH(!0````````"@#0H(!0````````!`#0H(`@``````````````!@``````
M``"@#0H(!P```/W____@"0H("````/W___\`Z`D(!````/O___^`Z`H(````
M```````````````````````#`````````.#E"@@#`````````$!E"@@!````
M```````````%`````````$`6"@@%`````````(`4"@@%`````````"`4"@@%
M`````````(`2"@@%`````````"`2"@@%`````````$`0"@@%```````````0
M"@@%`````````&`/"@@%`````````"`/"@@%`````````*`-"@@%````````
M`$`-"@@%`````````*#D"0@"```````````````&`````````*`-"@@'````
M`````.`)"@@(``````````#H"0@$````^____X#H"@@`````````````````
M````(@``````````````````````````````)@``````````````````````
M````````)P``````````````````````````````+P``````````````````
M````````````.@``````````````````````````````/```````````````
M````````````````/@``````````````````````````````0```````````
M````````````````````````````````````````````````````````````
M```#`````````.#E"@@#`````````(`6"@@!```````````````%````````
M`(`4"@@%`````````(`2"@@%`````````"`2"@@%`````````$`0"@@%````
M```````0"@@%`````````&`/"@@%`````````"`/"@@%`````````*`-"@@%
M`````````$`-"@@"```````````````&````_?___Z`-"@@'`````````.`)
M"@@(``````````#H"0@$````^____X#H"@@`````````````````````````
M``,`````````X.4*"`,`````````0&4*"`$```````````````4`````````
M@!0*"`4`````````@!(*"`4`````````(!(*"`4`````````0!`*"`4`````
M`````!`*"`4`````````8`\*"`4`````````(`\*"`4`````````H`T*"`4`
M````````0`T*"`(```````````````8```#]____H`T*"`<`````````X`D*
M"`@``````````.@)"`0```#[____@.@*"```````````````````````````
MH.<)"&#F"0BIYPD(@.4)"+'G"0B@XPD(NN<)",#B"0C'YPD((.()"`*>&`B`
MX0D(S><)"*#7"0C6YPD(8-H)".#G"0A@V@D(````````````````````````
M````````3F%M97!R97``2U)"<')E<`!.;V1E<')E<`!297-O=7)C97!R97``
M<&QA:6X`4T%33'!R97``25-#4TEP<F5P`&E30U-)````````````````````
M````````````````00```%H`````````````````````````80```'H`````
M````````````````````J@``````````````````````````````M0``````
M````````````````````````N@``````````````````````````````P```
M`-8`````````````````````````V````/8`````````````````````````
M^````"`"````````````````````````(@(``#,"````````````````````
M````4`(``*T"````````````````````````L`(``+@"````````````````
M````````NP(``,$"````````````````````````T`(``-$"````````````
M````````````X`(``.0"````````````````````````[@(`````````````
M````````````````>@,`````````````````````````````A@,`````````
M````````````````````B`,``(H#````````````````````````C`,`````
M````````````````````````C@,``*$#````````````````````````HP,`
M`,X#````````````````````````T`,``/4#````````````````````````
M``0``(($````````````````````````B@0``,X$````````````````````
M````T`0``/4$````````````````````````^`0``/D$````````````````
M``````````4```\%````````````````````````,04``%8%````````````
M````````````604``%\%````````````````````````804``(<%````````
M````````````````B04``````````````````````````````PD`````````
M````````````````````!0D``#D)````````````````````````/0D``$`)
M````````````````````````20D``$P)````````````````````````4`D`
M````````````````````````````6`D``&$)````````````````````````
M9`D``'`)````````````````````````@@D``(,)````````````````````
M````A0D``(P)````````````````````````CPD``)`)````````````````
M````````DPD``*@)````````````````````````J@D``+`)````````````
M````````````L@D`````````````````````````````M@D``+D)````````
M````````````````O@D``,`)````````````````````````QPD``,@)````
M````````````````````RPD``,P)````````````````````````UPD`````
M````````````````````````W`D``-T)````````````````````````WPD`
M`.$)````````````````````````Y@D``/$)````````````````````````
M]`D``/H)````````````````````````!0H```H*````````````````````
M````#PH``!`*````````````````````````$PH``"@*````````````````
M````````*@H``#`*````````````````````````,@H``#,*````````````
M````````````-0H``#8*````````````````````````.`H``#D*````````
M````````````````/@H``$`*````````````````````````60H``%P*````
M````````````````````7@H`````````````````````````````9@H``&\*
M````````````````````````<@H``'0*````````````````````````@PH`
M````````````````````````````A0H``(L*````````````````````````
MC0H`````````````````````````````CPH``)$*````````````````````
M````DPH``*@*````````````````````````J@H``+`*````````````````
M````````L@H``+,*````````````````````````M0H``+D*````````````
M````````````O0H``,`*````````````````````````R0H`````````````
M````````````````RPH``,P*````````````````````````T`H`````````
M````````````````````X`H`````````````````````````````Y@H``.\*
M`````````````````````````@L```,+````````````````````````!0L`
M``P+````````````````````````#PL``!`+````````````````````````
M$PL``"@+````````````````````````*@L``#`+````````````````````
M````,@L``#,+````````````````````````-@L``#D+````````````````
M````````/0L``#X+````````````````````````0`L`````````````````
M````````````1PL``$@+````````````````````````2PL``$P+````````
M````````````````5PL`````````````````````````````7`L``%T+````
M````````````````````7PL``&$+````````````````````````9@L``'`+
M````````````````````````@PL`````````````````````````````A0L`
M`(H+````````````````````````C@L``)`+````````````````````````
MD@L``)4+````````````````````````F0L``)H+````````````````````
M````G`L`````````````````````````````G@L``)\+````````````````
M````````HPL``*0+````````````````````````J`L``*H+````````````
M````````````K@L``+4+````````````````````````MPL``+D+````````
M````````````````O@L``+\+````````````````````````P0L``,(+````
M````````````````````Q@L``,@+````````````````````````R@L``,P+
M````````````````````````UPL`````````````````````````````YPL`
M`/(+`````````````````````````0P```,,````````````````````````
M!0P```P,````````````````````````#@P``!`,````````````````````
M````$@P``"@,````````````````````````*@P``#,,````````````````
M````````-0P``#D,````````````````````````00P``$0,````````````
M````````````8`P``&$,````````````````````````9@P``&\,````````
M````````````````@@P``(,,````````````````````````A0P``(P,````
M````````````````````C@P``)`,````````````````````````D@P``*@,
M````````````````````````J@P``+,,````````````````````````M0P`
M`+D,````````````````````````O@P`````````````````````````````
MP`P``,0,````````````````````````QPP``,@,````````````````````
M````R@P``,L,````````````````````````U0P``-8,````````````````
M````````W@P`````````````````````````````X`P``.$,````````````
M````````````Y@P``.\,`````````````````````````@T```,-````````
M````````````````!0T```P-````````````````````````#@T``!`-````
M````````````````````$@T``"@-````````````````````````*@T``#D-
M````````````````````````/@T``$`-````````````````````````1@T`
M`$@-````````````````````````2@T``$P-````````````````````````
M5PT`````````````````````````````8`T``&$-````````````````````
M````9@T``&\-````````````````````````@@T``(,-````````````````
M````````A0T``)8-````````````````````````F@T``+$-````````````
M````````````LPT``+L-````````````````````````O0T`````````````
M````````````````P`T``,8-````````````````````````SPT``-$-````
M````````````````````V`T``-\-````````````````````````\@T``/0-
M`````````````````````````0X``#`.````````````````````````,@X`
M`#,.````````````````````````0`X``$8.````````````````````````
M3PX``%L.````````````````````````@0X``((.````````````````````
M````A`X`````````````````````````````APX``(@.````````````````
M````````B@X`````````````````````````````C0X`````````````````
M````````````E`X``)<.````````````````````````F0X``)\.````````
M````````````````H0X``*,.````````````````````````I0X`````````
M````````````````````IPX`````````````````````````````J@X``*L.
M````````````````````````K0X``+`.````````````````````````L@X`
M`+,.````````````````````````O0X`````````````````````````````
MP`X``,0.````````````````````````Q@X`````````````````````````
M````T`X``-D.````````````````````````W`X``-T.````````````````
M``````````\``!</````````````````````````&@\``#0/````````````
M````````````-@\`````````````````````````````.`\`````````````
M````````````````/@\``$</````````````````````````20\``&H/````
M````````````````````?P\`````````````````````````````A0\`````
M````````````````````````B`\``(L/````````````````````````O@\`
M`,4/````````````````````````QP\``,P/````````````````````````
MSP\``````````````````````````````!```"$0````````````````````
M````(Q```"<0````````````````````````*1```"H0````````````````
M````````+!``````````````````````````````,1``````````````````
M````````````.!``````````````````````````````0!```%<0````````
M````````````````H!```,40````````````````````````T!```/@0````
M````````````````````^Q```````````````````````````````!$``%D1
M````````````````````````7Q$``*(1````````````````````````J!$`
M`/D1`````````````````````````!(```82````````````````````````
M"!(``$82````````````````````````2!(`````````````````````````
M````2A(``$T2````````````````````````4!(``%82````````````````
M````````6!(`````````````````````````````6A(``%T2````````````
M````````````8!(``(82````````````````````````B!(`````````````
M````````````````BA(``(T2````````````````````````D!(``*X2````
M````````````````````L!(`````````````````````````````LA(``+42
M````````````````````````N!(``+X2````````````````````````P!(`
M````````````````````````````PA(``,42````````````````````````
MR!(``,X2````````````````````````T!(``-82````````````````````
M````V!(``.X2````````````````````````\!(```X3````````````````
M````````$!,`````````````````````````````$A,``!43````````````
M````````````&!,``!X3````````````````````````(!,``$83````````
M````````````````2!,``%H3````````````````````````81,``'P3````
M````````````````````H!,``/03`````````````````````````10``'86
M````````````````````````@18``)H6````````````````````````H!8`
M`/`6`````````````````````````!<```P7````````````````````````
M#A<``!$7````````````````````````(!<``#$7````````````````````
M````-1<``#87````````````````````````0!<``%$7````````````````
M````````8!<``&P7````````````````````````;A<``'`7````````````
M````````````@!<``+87````````````````````````OA<``,47````````
M````````````````QQ<``,@7````````````````````````U!<``-H7````
M````````````````````W!<`````````````````````````````X!<``.D7
M````````````````````````$!@``!D8````````````````````````(!@`
M`'<8````````````````````````@!@``*@8````````````````````````
M`!X``)L>````````````````````````H!X``/D>````````````````````
M`````!\``!4?````````````````````````&!\``!T?````````````````
M````````(!\``$4?````````````````````````2!\``$T?````````````
M````````````4!\``%<?````````````````````````61\`````````````
M````````````````6Q\`````````````````````````````71\`````````
M````````````````````7Q\``'T?````````````````````````@!\``+0?
M````````````````````````MA\``+P?````````````````````````OA\`
M````````````````````````````PA\``,0?````````````````````````
MQA\``,P?````````````````````````T!\``-,?````````````````````
M````UA\``-L?````````````````````````X!\``.P?````````````````
M````````\A\``/0?````````````````````````]A\``/P?````````````
M````````````#B``````````````````````````````<2``````````````
M````````````````?R```````````````````````````````B$`````````
M````````````````````!R$`````````````````````````````"B$``!,A
M````````````````````````%2$`````````````````````````````&2$`
M`!TA````````````````````````)"$`````````````````````````````
M)B$`````````````````````````````*"$`````````````````````````
M````*B$``"TA````````````````````````+R$``#$A````````````````
M````````,R$``#DA````````````````````````/2$``#\A````````````
M````````````12$``$DA````````````````````````8"$``(,A````````
M````````````````-B,``'HC````````````````````````E2,`````````
M````````````````````G"0``.DD````````````````````````!3````<P
M````````````````````````(3```"DP````````````````````````,3``
M`#4P````````````````````````.#```#PP````````````````````````
M03```)8P````````````````````````G3```)\P````````````````````
M````H3```/HP````````````````````````_#```/\P````````````````
M````````!3$``"PQ````````````````````````,3$``(XQ````````````
M````````````D#$``+<Q````````````````````````\#$``!PR````````
M````````````````(#(``$,R````````````````````````8#(``'LR````
M````````````````````?S(``+`R````````````````````````P#(``,LR
M````````````````````````T#(``/XR`````````````````````````#,`
M`'8S````````````````````````>S,``-TS````````````````````````
MX#,``/XS`````````````````````````#0``+5-````````````````````
M`````$X``*6?`````````````````````````*```(RD````````````````
M`````````*P``*/7`````````````````````````-@``"WZ````````````
M````````````,/H``&KZ`````````````````````````/L```;[````````
M````````````````$_L``!?[````````````````````````(?\``#K_````
M````````````````````0?\``%K_````````````````````````9O\``+[_
M````````````````````````PO\``,?_````````````````````````RO\`
M`,__````````````````````````TO\``-?_````````````````````````
MVO\``-S_``````````````````````````,!`!X#`0``````````````````
M````(`,!`",#`0``````````````````````,`,!`$H#`0``````````````
M``````````0!`"4$`0``````````````````````*`0!`$T$`0``````````
M`````````````-`!`/70`0```````````````````````-$!`";1`0``````
M````````````````*M$!`&;1`0``````````````````````:M$!`'+1`0``
M````````````````````@]$!`(31`0``````````````````````C-$!`*G1
M`0``````````````````````KM$!`-W1`0```````````````````````-0!
M`%34`0``````````````````````5M0!`)S4`0``````````````````````
MGM0!`)_4`0``````````````````````HM0!````````````````````````
M````I=0!`*;4`0``````````````````````J=0!`*S4`0``````````````
M````````KM0!`+G4`0``````````````````````N]0!````````````````
M````````````O=0!`,#4`0``````````````````````PM0!`,/4`0``````
M````````````````Q=0!``75`0``````````````````````!]4!``K5`0``
M````````````````````#=4!`!35`0``````````````````````%M4!`!S5
M`0``````````````````````'M4!`#G5`0``````````````````````.]4!
M`#[5`0``````````````````````0-4!`$35`0``````````````````````
M1M4!````````````````````````````2M4!`%#5`0``````````````````
M````4M4!`*/6`0``````````````````````J-8!`,G7`0``````````````
M```````````"`-:F`@```````````````````````/@"`!WZ`@``````````
M```````````````/`/W_#P`````````````````````````0`/W_$```````
M``````````````````````````````````````````````````````````"^
M!0````````````````````````````#`!0``````````````````````````
M``##!0````````````````````````````#0!0``Z@4`````````````````
M``````#P!0``]`4````````````````````````;!@``````````````````
M```````````?!@`````````````````````````````A!@``.@8`````````
M``````````````!`!@``2@8```````````````````````!M!@``;P8`````
M``````````````````!Q!@``U08```````````````````````#=!@``````
M``````````````````````#E!@``Y@8```````````````````````#Z!@``
M_@8`````````````````````````!P``#0<````````````````````````0
M!P`````````````````````````````2!P``+`<`````````````````````
M``"`!P``I0<```````````````````````"Q!P``````````````````````
M```````/(``````````````````````````````=^P``````````````````
M```````````?^P``*/L````````````````````````J^P``-OL`````````
M```````````````X^P``//L````````````````````````^^P``````````
M``````````````````!`^P``0?L```````````````````````!#^P``1/L`
M``````````````````````!&^P``L?L```````````````````````#3^P``
M/?T```````````````````````!0_0``C_T```````````````````````"2
M_0``Q_T```````````````````````#P_0``_/T`````````````````````
M``!P_@``=/X```````````````````````!V_@``_/X`````````````````
M````````````````````````````````````````````````````````````
M```````````!``X````````````````````````````@``X`?P`.````````
M````````````````````````````````````````````````````````````
M``````````````````!``P````````````````````````````!!`P``````
M```````````````````````.(``````````````````````````````/(```
M```````````````````````````J(``````````````````````````````K
M(``````````````````````````````L(```````````````````````````
M```M(``````````````````````````````N(```````````````````````
M``````!J(`````````````````````````````!K(```````````````````
M``````````!L(`````````````````````````````!M(```````````````
M``````````````!N(`````````````````````````````!O(```````````
M``````````````````````````````````````````````````#P+P``^R\`
M````````````````````````````````````````````````````````````
M````````````````^?\`````````````````````````````^O\`````````
M````````````````````^_\`````````````````````````````_/\`````
M````````````````````````_?\`````````````````````````````````
M``````````````````````````````````````````````````#8``#_WP``
M````````````````````````````````````````````````````````````
M``````````````#0_0``[_T```````````````````````#^_P``__\`````
M``````````````````#^_P$`__\!``````````````````````#^_P(`__\"
M``````````````````````#^_P,`__\#``````````````````````#^_P0`
M__\$``````````````````````#^_P4`__\%``````````````````````#^
M_P8`__\&``````````````````````#^_P<`__\'````````````````````
M``#^_P@`__\(``````````````````````#^_PD`__\)````````````````
M``````#^_PH`__\*``````````````````````#^_PL`__\+````````````
M``````````#^_PP`__\,``````````````````````#^_PT`__\-````````
M``````````````#^_PX`__\.``````````````````````#^_P\`__\/````
M``````````````````#^_Q``__\0````````````````````````````````
M````````````````````````````````````````````````````````X```
M__@```````````````````````````\`_?\/````````````````````````
M`!``_?\0````````````````````````````````````````````````````
M``"`````GP````````````````````````#=!@``````````````````````
M```````/!P`````````````````````````````.&```````````````````
M```````````,(``````````````````````````````-(```````````````
M```````````````H(``````````````````````````````I(```````````
M``````````````````!@(`````````````````````````````!A(```````
M``````````````````````!B(`````````````````````````````!C(```
M``````````````````````````!J(```;R````````````````````````#_
M_@````````````````````````````#Y_P``_/\`````````````````````
M``!ST0$`>M$!````````````````````````````````````````````````
M```````````````````````?`````````````````````````'\`````````
M````````````````````````````````````````````````````````````
M`````````````````````````*```````````````````````````````(`6
M```````````````````````````````@````````````````````````````
M``$@``````````````````````````````(@````````````````````````
M``````,@``````````````````````````````0@````````````````````
M``````````4@``````````````````````````````8@````````````````
M``````````````<@``````````````````````````````@@````````````
M``````````````````D@``````````````````````````````H@````````
M``````````````````````L@`````````````````````````````"\@````
M`````````````````````````%\@```````````````````````````````P
M````````````````````````````````````````````````````````````
M```````````````````````@````````````````````````````````````
M````````````````````````````````````````````````00````````!A
M````````````````````0@````````!B````````````````````0P``````
M``!C````````````````````1`````````!D````````````````````10``
M``````!E````````````````````1@````````!F````````````````````
M1P````````!G````````````````````2`````````!H````````````````
M````20````````!I````````````````````2@````````!J````````````
M````````2P````````!K````````````````````3`````````!L````````
M````````````30````````!M````````````````````3@````````!N````
M````````````````3P````````!O````````````````````4`````````!P
M````````````````````40````````!Q````````````````````4@``````
M``!R````````````````````4P````````!S````````````````````5```
M``````!T````````````````````50````````!U````````````````````
M5@````````!V````````````````````5P````````!W````````````````
M````6`````````!X````````````````````60````````!Y````````````
M````````6@````````!Z````````````````````M0````````"\`P``````
M````````````P`````````#@````````````````````P0````````#A````
M````````````````P@````````#B````````````````````PP````````#C
M````````````````````Q`````````#D````````````````````Q0``````
M``#E````````````````````Q@````````#F````````````````````QP``
M``````#G````````````````````R`````````#H````````````````````
MR0````````#I````````````````````R@````````#J````````````````
M````RP````````#K````````````````````S`````````#L````````````
M````````S0````````#M````````````````````S@````````#N````````
M````````````SP````````#O````````````````````T`````````#P````
M````````````````T0````````#Q````````````````````T@````````#R
M````````````````````TP````````#S````````````````````U```````
M``#T````````````````````U0````````#U````````````````````U@``
M``````#V````````````````````V`````````#X````````````````````
MV0````````#Y````````````````````V@````````#Z````````````````
M````VP````````#[````````````````````W`````````#\````````````
M````````W0````````#]````````````````````W@````````#^````````
M````````````WP````````!S````<P````````````````$````````!`0``
M`````````````````@$````````#`0``````````````````!`$````````%
M`0``````````````````!@$````````'`0``````````````````"`$`````
M```)`0``````````````````"@$````````+`0``````````````````#`$`
M```````-`0``````````````````#@$````````/`0``````````````````
M$`$````````1`0``````````````````$@$````````3`0``````````````
M````%`$````````5`0``````````````````%@$````````7`0``````````
M````````&`$````````9`0``````````````````&@$````````;`0``````
M````````````'`$````````=`0``````````````````'@$````````?`0``
M````````````````(`$````````A`0``````````````````(@$````````C
M`0``````````````````)`$````````E`0``````````````````)@$`````
M```G`0``````````````````*`$````````I`0``````````````````*@$`
M```````K`0``````````````````+`$````````M`0``````````````````
M+@$````````O`0``````````````````,`$```````!I````!P,`````````
M````,@$````````S`0``````````````````-`$````````U`0``````````
M````````-@$````````W`0``````````````````.0$````````Z`0``````
M````````````.P$````````\`0``````````````````/0$````````^`0``
M````````````````/P$```````!``0``````````````````00$```````!"
M`0``````````````````0P$```````!$`0``````````````````10$`````
M``!&`0``````````````````1P$```````!(`0``````````````````20$`
M``````"\`@``;@``````````````2@$```````!+`0``````````````````
M3`$```````!-`0``````````````````3@$```````!/`0``````````````
M````4`$```````!1`0``````````````````4@$```````!3`0``````````
M````````5`$```````!5`0``````````````````5@$```````!7`0``````
M````````````6`$```````!9`0``````````````````6@$```````!;`0``
M````````````````7`$```````!=`0``````````````````7@$```````!?
M`0``````````````````8`$```````!A`0``````````````````8@$`````
M``!C`0``````````````````9`$```````!E`0``````````````````9@$`
M``````!G`0``````````````````:`$```````!I`0``````````````````
M:@$```````!K`0``````````````````;`$```````!M`0``````````````
M````;@$```````!O`0``````````````````<`$```````!Q`0``````````
M````````<@$```````!S`0``````````````````=`$```````!U`0``````
M````````````=@$```````!W`0``````````````````>`$```````#_````
M````````````````>0$```````!Z`0``````````````````>P$```````!\
M`0``````````````````?0$```````!^`0``````````````````?P$`````
M``!S````````````````````@0$```````!3`@``````````````````@@$`
M``````"#`0``````````````````A`$```````"%`0``````````````````
MA@$```````!4`@``````````````````AP$```````"(`0``````````````
M````B0$```````!6`@``````````````````B@$```````!7`@``````````
M````````BP$```````",`0``````````````````C@$```````#=`0``````
M````````````CP$```````!9`@``````````````````D`$```````!;`@``
M````````````````D0$```````"2`0``````````````````DP$```````!@
M`@``````````````````E`$```````!C`@``````````````````E@$`````
M``!I`@``````````````````EP$```````!H`@``````````````````F`$`
M``````"9`0``````````````````G`$```````!O`@``````````````````
MG0$```````!R`@``````````````````GP$```````!U`@``````````````
M````H`$```````"A`0``````````````````H@$```````"C`0``````````
M````````I`$```````"E`0``````````````````I@$```````"``@``````
M````````````IP$```````"H`0``````````````````J0$```````"#`@``
M````````````````K`$```````"M`0``````````````````K@$```````"(
M`@``````````````````KP$```````"P`0``````````````````L0$`````
M``"*`@``````````````````L@$```````"+`@``````````````````LP$`
M``````"T`0``````````````````M0$```````"V`0``````````````````
MMP$```````"2`@``````````````````N`$```````"Y`0``````````````
M````O`$```````"]`0``````````````````Q`$```````#&`0``````````
M````````Q0$```````#&`0``````````````````QP$```````#)`0``````
M````````````R`$```````#)`0``````````````````R@$```````#,`0``
M````````````````RP$```````#,`0``````````````````S0$```````#.
M`0``````````````````SP$```````#0`0``````````````````T0$`````
M``#2`0``````````````````TP$```````#4`0``````````````````U0$`
M``````#6`0``````````````````UP$```````#8`0``````````````````
MV0$```````#:`0``````````````````VP$```````#<`0``````````````
M````W@$```````#?`0``````````````````X`$```````#A`0``````````
M````````X@$```````#C`0``````````````````Y`$```````#E`0``````
M````````````Y@$```````#G`0``````````````````Z`$```````#I`0``
M````````````````Z@$```````#K`0``````````````````[`$```````#M
M`0``````````````````[@$```````#O`0``````````````````\`$`````
M``!J````#`,`````````````\0$```````#S`0``````````````````\@$`
M``````#S`0``````````````````]`$```````#U`0``````````````````
M]@$```````"5`0``````````````````]P$```````"_`0``````````````
M````^`$```````#Y`0``````````````````^@$```````#[`0``````````
M````````_`$```````#]`0``````````````````_@$```````#_`0``````
M``````````````(````````!`@```````````````````@(````````#`@``
M````````````````!`(````````%`@``````````````````!@(````````'
M`@``````````````````"`(````````)`@``````````````````"@(`````
M```+`@``````````````````#`(````````-`@``````````````````#@(`
M```````/`@``````````````````$`(````````1`@``````````````````
M$@(````````3`@``````````````````%`(````````5`@``````````````
M````%@(````````7`@``````````````````&`(````````9`@``````````
M````````&@(````````;`@``````````````````'`(````````=`@``````
M````````````'@(````````?`@``````````````````(`(```````">`0``
M````````````````(@(````````C`@``````````````````)`(````````E
M`@``````````````````)@(````````G`@``````````````````*`(`````
M```I`@``````````````````*@(````````K`@``````````````````+`(`
M```````M`@``````````````````+@(````````O`@``````````````````
M,`(````````Q`@``````````````````,@(````````S`@``````````````
M````10,```````"Y`P``````````````````A@,```````"L`P``````````
M````````B`,```````"M`P``````````````````B0,```````"N`P``````
M````````````B@,```````"O`P``````````````````C`,```````#,`P``
M````````````````C@,```````#-`P``````````````````CP,```````#.
M`P``````````````````D`,```````"Y`P``"`,```$#````````D0,`````
M``"Q`P``````````````````D@,```````"R`P``````````````````DP,`
M``````"S`P``````````````````E`,```````"T`P``````````````````
ME0,```````"U`P``````````````````E@,```````"V`P``````````````
M````EP,```````"W`P``````````````````F`,```````"X`P``````````
M````````F0,```````"Y`P``````````````````F@,```````"Z`P``````
M````````````FP,```````"[`P``````````````````G`,```````"\`P``
M````````````````G0,```````"]`P``````````````````G@,```````"^
M`P``````````````````GP,```````"_`P``````````````````H`,`````
M``#``P``````````````````H0,```````#!`P``````````````````HP,`
M``````##`P``````````````````I`,```````#$`P``````````````````
MI0,```````#%`P``````````````````I@,```````#&`P``````````````
M````IP,```````#'`P``````````````````J`,```````#(`P``````````
M````````J0,```````#)`P``````````````````J@,```````#*`P``````
M````````````JP,```````#+`P``````````````````L`,```````#%`P``
M"`,```$#````````P@,```````##`P``````````````````T`,```````"R
M`P``````````````````T0,```````"X`P``````````````````U0,`````
M``#&`P``````````````````U@,```````#``P``````````````````V`,`
M``````#9`P``````````````````V@,```````#;`P``````````````````
MW`,```````#=`P``````````````````W@,```````#?`P``````````````
M````X`,```````#A`P``````````````````X@,```````#C`P``````````
M````````Y`,```````#E`P``````````````````Y@,```````#G`P``````
M````````````Z`,```````#I`P``````````````````Z@,```````#K`P``
M````````````````[`,```````#M`P``````````````````[@,```````#O
M`P``````````````````\`,```````"Z`P``````````````````\0,`````
M``#!`P``````````````````\@,```````##`P``````````````````]`,`
M``````"X`P``````````````````]0,```````"U`P``````````````````
M``0```````!0!````````````````````00```````!1!```````````````
M`````@0```````!2!````````````````````P0```````!3!```````````
M````````!`0```````!4!```````````````````!00```````!5!```````
M````````````!@0```````!6!```````````````````!P0```````!7!```
M````````````````"`0```````!8!```````````````````"00```````!9
M!```````````````````"@0```````!:!```````````````````"P0`````
M``!;!```````````````````#`0```````!<!```````````````````#00`
M``````!=!```````````````````#@0```````!>!```````````````````
M#P0```````!?!```````````````````$`0````````P!```````````````
M````$00````````Q!```````````````````$@0````````R!```````````
M````````$P0````````S!```````````````````%`0````````T!```````
M````````````%00````````U!```````````````````%@0````````V!```
M````````````````%P0````````W!```````````````````&`0````````X
M!```````````````````&00````````Y!```````````````````&@0`````
M```Z!```````````````````&P0````````[!```````````````````'`0`
M```````\!```````````````````'00````````]!```````````````````
M'@0````````^!```````````````````'P0````````_!```````````````
M````(`0```````!`!```````````````````(00```````!!!```````````
M````````(@0```````!"!```````````````````(P0```````!#!```````
M````````````)`0```````!$!```````````````````)00```````!%!```
M````````````````)@0```````!&!```````````````````)P0```````!'
M!```````````````````*`0```````!(!```````````````````*00`````
M``!)!```````````````````*@0```````!*!```````````````````*P0`
M``````!+!```````````````````+`0```````!,!```````````````````
M+00```````!-!```````````````````+@0```````!.!```````````````
M````+P0```````!/!```````````````````8`0```````!A!```````````
M````````8@0```````!C!```````````````````9`0```````!E!```````
M````````````9@0```````!G!```````````````````:`0```````!I!```
M````````````````:@0```````!K!```````````````````;`0```````!M
M!```````````````````;@0```````!O!```````````````````<`0`````
M``!Q!```````````````````<@0```````!S!```````````````````=`0`
M``````!U!```````````````````=@0```````!W!```````````````````
M>`0```````!Y!```````````````````>@0```````![!```````````````
M````?`0```````!]!```````````````````?@0```````!_!```````````
M````````@`0```````"!!```````````````````B@0```````"+!```````
M````````````C`0```````"-!```````````````````C@0```````"/!```
M````````````````D`0```````"1!```````````````````D@0```````"3
M!```````````````````E`0```````"5!```````````````````E@0`````
M``"7!```````````````````F`0```````"9!```````````````````F@0`
M``````";!```````````````````G`0```````"=!```````````````````
MG@0```````"?!```````````````````H`0```````"A!```````````````
M````H@0```````"C!```````````````````I`0```````"E!```````````
M````````I@0```````"G!```````````````````J`0```````"I!```````
M````````````J@0```````"K!```````````````````K`0```````"M!```
M````````````````K@0```````"O!```````````````````L`0```````"Q
M!```````````````````L@0```````"S!```````````````````M`0`````
M``"U!```````````````````M@0```````"W!```````````````````N`0`
M``````"Y!```````````````````N@0```````"[!```````````````````
MO`0```````"]!```````````````````O@0```````"_!```````````````
M````P00```````#"!```````````````````PP0```````#$!```````````
M````````Q00```````#&!```````````````````QP0```````#(!```````
M````````````R00```````#*!```````````````````RP0```````#,!```
M````````````````S00```````#.!```````````````````T`0```````#1
M!```````````````````T@0```````#3!```````````````````U`0`````
M``#5!```````````````````U@0```````#7!```````````````````V`0`
M``````#9!```````````````````V@0```````#;!```````````````````
MW`0```````#=!```````````````````W@0```````#?!```````````````
M````X`0```````#A!```````````````````X@0```````#C!```````````
M````````Y`0```````#E!```````````````````Y@0```````#G!```````
M````````````Z`0```````#I!```````````````````Z@0```````#K!```
M````````````````[`0```````#M!```````````````````[@0```````#O
M!```````````````````\`0```````#Q!```````````````````\@0`````
M``#S!```````````````````]`0```````#U!```````````````````^`0`
M``````#Y!`````````````````````4````````!!0``````````````````
M`@4````````#!0``````````````````!`4````````%!0``````````````
M````!@4````````'!0``````````````````"`4````````)!0``````````
M````````"@4````````+!0``````````````````#`4````````-!0``````
M````````````#@4````````/!0``````````````````,04```````!A!0``
M````````````````,@4```````!B!0``````````````````,P4```````!C
M!0``````````````````-`4```````!D!0``````````````````-04`````
M``!E!0``````````````````-@4```````!F!0``````````````````-P4`
M``````!G!0``````````````````.`4```````!H!0``````````````````
M.04```````!I!0``````````````````.@4```````!J!0``````````````
M````.P4```````!K!0``````````````````/`4```````!L!0``````````
M````````/04```````!M!0``````````````````/@4```````!N!0``````
M````````````/P4```````!O!0``````````````````0`4```````!P!0``
M````````````````004```````!Q!0``````````````````0@4```````!R
M!0``````````````````0P4```````!S!0``````````````````1`4`````
M``!T!0``````````````````104```````!U!0``````````````````1@4`
M``````!V!0``````````````````1P4```````!W!0``````````````````
M2`4```````!X!0``````````````````204```````!Y!0``````````````
M````2@4```````!Z!0``````````````````2P4```````![!0``````````
M````````3`4```````!\!0``````````````````304```````!]!0``````
M````````````3@4```````!^!0``````````````````3P4```````!_!0``
M````````````````4`4```````"`!0``````````````````404```````"!
M!0``````````````````4@4```````""!0``````````````````4P4`````
M``"#!0``````````````````5`4```````"$!0``````````````````504`
M``````"%!0``````````````````5@4```````"&!0``````````````````
MAP4```````!E!0``@@4``````````````!X````````!'@``````````````
M`````AX````````#'@``````````````````!!X````````%'@``````````
M````````!AX````````''@``````````````````"!X````````)'@``````
M````````````"AX````````+'@``````````````````#!X````````-'@``
M````````````````#AX````````/'@``````````````````$!X````````1
M'@``````````````````$AX````````3'@``````````````````%!X`````
M```5'@``````````````````%AX````````7'@``````````````````&!X`
M```````9'@``````````````````&AX````````;'@``````````````````
M'!X````````='@``````````````````'AX````````?'@``````````````
M````(!X````````A'@``````````````````(AX````````C'@``````````
M````````)!X````````E'@``````````````````)AX````````G'@``````
M````````````*!X````````I'@``````````````````*AX````````K'@``
M````````````````+!X````````M'@``````````````````+AX````````O
M'@``````````````````,!X````````Q'@``````````````````,AX`````
M```S'@``````````````````-!X````````U'@``````````````````-AX`
M```````W'@``````````````````.!X````````Y'@``````````````````
M.AX````````['@``````````````````/!X````````]'@``````````````
M````/AX````````_'@``````````````````0!X```````!!'@``````````
M````````0AX```````!#'@``````````````````1!X```````!%'@``````
M````````````1AX```````!''@``````````````````2!X```````!)'@``
M````````````````2AX```````!+'@``````````````````3!X```````!-
M'@``````````````````3AX```````!/'@``````````````````4!X`````
M``!1'@``````````````````4AX```````!3'@``````````````````5!X`
M``````!5'@``````````````````5AX```````!7'@``````````````````
M6!X```````!9'@``````````````````6AX```````!;'@``````````````
M````7!X```````!='@``````````````````7AX```````!?'@``````````
M````````8!X```````!A'@``````````````````8AX```````!C'@``````
M````````````9!X```````!E'@``````````````````9AX```````!G'@``
M````````````````:!X```````!I'@``````````````````:AX```````!K
M'@``````````````````;!X```````!M'@``````````````````;AX`````
M``!O'@``````````````````<!X```````!Q'@``````````````````<AX`
M``````!S'@``````````````````=!X```````!U'@``````````````````
M=AX```````!W'@``````````````````>!X```````!Y'@``````````````
M````>AX```````!['@``````````````````?!X```````!]'@``````````
M````````?AX```````!_'@``````````````````@!X```````"!'@``````
M````````````@AX```````"#'@``````````````````A!X```````"%'@``
M````````````````AAX```````"''@``````````````````B!X```````")
M'@``````````````````BAX```````"+'@``````````````````C!X`````
M``"-'@``````````````````CAX```````"/'@``````````````````D!X`
M``````"1'@``````````````````DAX```````"3'@``````````````````
ME!X```````"5'@``````````````````EAX```````!H````,0,`````````
M````EQX```````!T````"`,`````````````F!X```````!W````"@,`````
M````````F1X```````!Y````"@,`````````````FAX```````!A````O@(`
M````````````FQX```````!A'@``````````````````H!X```````"A'@``
M````````````````HAX```````"C'@``````````````````I!X```````"E
M'@``````````````````IAX```````"G'@``````````````````J!X`````
M``"I'@``````````````````JAX```````"K'@``````````````````K!X`
M``````"M'@``````````````````KAX```````"O'@``````````````````
ML!X```````"Q'@``````````````````LAX```````"S'@``````````````
M````M!X```````"U'@``````````````````MAX```````"W'@``````````
M````````N!X```````"Y'@``````````````````NAX```````"['@``````
M````````````O!X```````"]'@``````````````````OAX```````"_'@``
M````````````````P!X```````#!'@``````````````````PAX```````##
M'@``````````````````Q!X```````#%'@``````````````````QAX`````
M``#''@``````````````````R!X```````#)'@``````````````````RAX`
M``````#+'@``````````````````S!X```````#-'@``````````````````
MSAX```````#/'@``````````````````T!X```````#1'@``````````````
M````TAX```````#3'@``````````````````U!X```````#5'@``````````
M````````UAX```````#7'@``````````````````V!X```````#9'@``````
M````````````VAX```````#;'@``````````````````W!X```````#='@``
M````````````````WAX```````#?'@``````````````````X!X```````#A
M'@``````````````````XAX```````#C'@``````````````````Y!X`````
M``#E'@``````````````````YAX```````#G'@``````````````````Z!X`
M``````#I'@``````````````````ZAX```````#K'@``````````````````
M[!X```````#M'@``````````````````[AX```````#O'@``````````````
M````\!X```````#Q'@``````````````````\AX```````#S'@``````````
M````````]!X```````#U'@``````````````````]AX```````#W'@``````
M````````````^!X```````#Y'@``````````````````"!\`````````'P``
M````````````````"1\````````!'P``````````````````"A\````````"
M'P``````````````````"Q\````````#'P``````````````````#!\`````
M```$'P``````````````````#1\````````%'P``````````````````#A\`
M```````&'P``````````````````#Q\````````''P``````````````````
M&!\````````0'P``````````````````&1\````````1'P``````````````
M````&A\````````2'P``````````````````&Q\````````3'P``````````
M````````'!\````````4'P``````````````````'1\````````5'P``````
M````````````*!\````````@'P``````````````````*1\````````A'P``
M````````````````*A\````````B'P``````````````````*Q\````````C
M'P``````````````````+!\````````D'P``````````````````+1\`````
M```E'P``````````````````+A\````````F'P``````````````````+Q\`
M```````G'P``````````````````.!\````````P'P``````````````````
M.1\````````Q'P``````````````````.A\````````R'P``````````````
M````.Q\````````S'P``````````````````/!\````````T'P``````````
M````````/1\````````U'P``````````````````/A\````````V'P``````
M````````````/Q\````````W'P``````````````````2!\```````!`'P``
M````````````````21\```````!!'P``````````````````2A\```````!"
M'P``````````````````2Q\```````!#'P``````````````````3!\`````
M``!$'P``````````````````31\```````!%'P``````````````````4!\`
M``````#%`P``$P,`````````````4A\```````#%`P``$P,````#````````
M5!\```````#%`P``$P,```$#````````5A\```````#%`P``$P,``$(#````
M````61\```````!1'P``````````````````6Q\```````!3'P``````````
M````````71\```````!5'P``````````````````7Q\```````!7'P``````
M````````````:!\```````!@'P``````````````````:1\```````!A'P``
M````````````````:A\```````!B'P``````````````````:Q\```````!C
M'P``````````````````;!\```````!D'P``````````````````;1\`````
M``!E'P``````````````````;A\```````!F'P``````````````````;Q\`
M``````!G'P``````````````````@!\`````````'P``N0,`````````````
M@1\````````!'P``N0,`````````````@A\````````"'P``N0,`````````
M````@Q\````````#'P``N0,`````````````A!\````````$'P``N0,`````
M````````A1\````````%'P``N0,`````````````AA\````````&'P``N0,`
M````````````AQ\````````''P``N0,`````````````B!\`````````'P``
MN0,`````````````B1\````````!'P``N0,`````````````BA\````````"
M'P``N0,`````````````BQ\````````#'P``N0,`````````````C!\`````
M```$'P``N0,`````````````C1\````````%'P``N0,`````````````CA\`
M```````&'P``N0,`````````````CQ\````````''P``N0,`````````````
MD!\````````@'P``N0,`````````````D1\````````A'P``N0,`````````
M````DA\````````B'P``N0,`````````````DQ\````````C'P``N0,`````
M````````E!\````````D'P``N0,`````````````E1\````````E'P``N0,`
M````````````EA\````````F'P``N0,`````````````EQ\````````G'P``
MN0,`````````````F!\````````@'P``N0,`````````````F1\````````A
M'P``N0,`````````````FA\````````B'P``N0,`````````````FQ\`````
M```C'P``N0,`````````````G!\````````D'P``N0,`````````````G1\`
M```````E'P``N0,`````````````GA\````````F'P``N0,`````````````
MGQ\````````G'P``N0,`````````````H!\```````!@'P``N0,`````````
M````H1\```````!A'P``N0,`````````````HA\```````!B'P``N0,`````
M````````HQ\```````!C'P``N0,`````````````I!\```````!D'P``N0,`
M````````````I1\```````!E'P``N0,`````````````IA\```````!F'P``
MN0,`````````````IQ\```````!G'P``N0,`````````````J!\```````!@
M'P``N0,`````````````J1\```````!A'P``N0,`````````````JA\`````
M``!B'P``N0,`````````````JQ\```````!C'P``N0,`````````````K!\`
M``````!D'P``N0,`````````````K1\```````!E'P``N0,`````````````
MKA\```````!F'P``N0,`````````````KQ\```````!G'P``N0,`````````
M````LA\```````!P'P``N0,`````````````LQ\```````"Q`P``N0,`````
M````````M!\```````"L`P``N0,`````````````MA\```````"Q`P``0@,`
M````````````MQ\```````"Q`P``0@,``+D#````````N!\```````"P'P``
M````````````````N1\```````"Q'P``````````````````NA\```````!P
M'P``````````````````NQ\```````!Q'P``````````````````O!\`````
M``"Q`P``N0,`````````````OA\```````"Y`P``````````````````PA\`
M``````!T'P``N0,`````````````PQ\```````"W`P``N0,`````````````
MQ!\```````"N`P``N0,`````````````QA\```````"W`P``0@,`````````
M````QQ\```````"W`P``0@,``+D#````````R!\```````!R'P``````````
M````````R1\```````!S'P``````````````````RA\```````!T'P``````
M````````````RQ\```````!U'P``````````````````S!\```````"W`P``
MN0,`````````````TA\```````"Y`P``"`,````#````````TQ\```````"Y
M`P``"`,```$#````````UA\```````"Y`P``0@,`````````````UQ\`````
M``"Y`P``"`,``$(#````````V!\```````#0'P``````````````````V1\`
M``````#1'P``````````````````VA\```````!V'P``````````````````
MVQ\```````!W'P``````````````````XA\```````#%`P``"`,````#````
M````XQ\```````#%`P``"`,```$#````````Y!\```````#!`P``$P,`````
M````````YA\```````#%`P``0@,`````````````YQ\```````#%`P``"`,`
M`$(#````````Z!\```````#@'P``````````````````Z1\```````#A'P``
M````````````````ZA\```````!Z'P``````````````````ZQ\```````![
M'P``````````````````[!\```````#E'P``````````````````\A\`````
M``!\'P``N0,`````````````\Q\```````#)`P``N0,`````````````]!\`
M``````#.`P``N0,`````````````]A\```````#)`P``0@,`````````````
M]Q\```````#)`P``0@,``+D#````````^!\```````!X'P``````````````
M````^1\```````!Y'P``````````````````^A\```````!\'P``````````
M````````^Q\```````!]'P``````````````````_!\```````#)`P``N0,`
M````````````)B$```````#)`P``````````````````*B$```````!K````
M````````````````*R$```````#E````````````````````8"$```````!P
M(0``````````````````82$```````!Q(0``````````````````8B$`````
M``!R(0``````````````````8R$```````!S(0``````````````````9"$`
M``````!T(0``````````````````92$```````!U(0``````````````````
M9B$```````!V(0``````````````````9R$```````!W(0``````````````
M````:"$```````!X(0``````````````````:2$```````!Y(0``````````
M````````:B$```````!Z(0``````````````````:R$```````![(0``````
M````````````;"$```````!\(0``````````````````;2$```````!](0``
M````````````````;B$```````!^(0``````````````````;R$```````!_
M(0``````````````````MB0```````#0)```````````````````MR0`````
M``#1)```````````````````N"0```````#2)```````````````````N20`
M``````#3)```````````````````NB0```````#4)```````````````````
MNR0```````#5)```````````````````O"0```````#6)```````````````
M````O20```````#7)```````````````````OB0```````#8)```````````
M````````OR0```````#9)```````````````````P"0```````#:)```````
M````````````P20```````#;)```````````````````PB0```````#<)```
M````````````````PR0```````#=)```````````````````Q"0```````#>
M)```````````````````Q20```````#?)```````````````````QB0`````
M``#@)```````````````````QR0```````#A)```````````````````R"0`
M``````#B)```````````````````R20```````#C)```````````````````
MRB0```````#D)```````````````````RR0```````#E)```````````````
M````S"0```````#F)```````````````````S20```````#G)```````````
M````````SB0```````#H)```````````````````SR0```````#I)```````
M`````````````/L```````!F````9@```````````````?L```````!F````
M:0```````````````OL```````!F````;````````````````_L```````!F
M````9@```&D`````````!/L```````!F````9@```&P`````````!?L`````
M``!S````=```````````````!OL```````!S````=```````````````$_L`
M``````!T!0``=@4`````````````%/L```````!T!0``904`````````````
M%?L```````!T!0``:P4`````````````%OL```````!^!0``=@4`````````
M````%_L```````!T!0``;04`````````````(?\```````!!_P``````````
M````````(O\```````!"_P``````````````````(_\```````!#_P``````
M````````````)/\```````!$_P``````````````````)?\```````!%_P``
M````````````````)O\```````!&_P``````````````````)_\```````!'
M_P``````````````````*/\```````!(_P``````````````````*?\`````
M``!)_P``````````````````*O\```````!*_P``````````````````*_\`
M``````!+_P``````````````````+/\```````!,_P``````````````````
M+?\```````!-_P``````````````````+O\```````!._P``````````````
M````+_\```````!/_P``````````````````,/\```````!0_P``````````
M````````,?\```````!1_P``````````````````,O\```````!2_P``````
M````````````,_\```````!3_P``````````````````-/\```````!4_P``
M````````````````-?\```````!5_P``````````````````-O\```````!6
M_P``````````````````-_\```````!7_P``````````````````./\`````
M``!8_P``````````````````.?\```````!9_P``````````````````.O\`
M``````!:_P````````````````````0!```````H!`$`````````````````
M`00!```````I!`$``````````````````@0!```````J!`$`````````````
M`````P0!```````K!`$`````````````````!`0!```````L!`$`````````
M````````!00!```````M!`$`````````````````!@0!```````N!`$`````
M````````````!P0!```````O!`$`````````````````"`0!```````P!`$`
M````````````````"00!```````Q!`$`````````````````"@0!```````R
M!`$`````````````````"P0!```````S!`$`````````````````#`0!````
M```T!`$`````````````````#00!```````U!`$`````````````````#@0!
M```````V!`$`````````````````#P0!```````W!`$`````````````````
M$`0!```````X!`$`````````````````$00!```````Y!`$`````````````
M````$@0!```````Z!`$`````````````````$P0!```````[!`$`````````
M````````%`0!```````\!`$`````````````````%00!```````]!`$`````
M````````````%@0!```````^!`$`````````````````%P0!```````_!`$`
M````````````````&`0!``````!`!`$`````````````````&00!``````!!
M!`$`````````````````&@0!``````!"!`$`````````````````&P0!````
M``!#!`$`````````````````'`0!``````!$!`$`````````````````'00!
M``````!%!`$`````````````````'@0!``````!&!`$`````````````````
M'P0!``````!'!`$`````````````````(`0!``````!(!`$`````````````
M````(00!``````!)!`$`````````````````(@0!``````!*!`$`````````
M````````(P0!``````!+!`$`````````````````)`0!``````!,!`$`````
M````````````)00!``````!-!`$`````````````````````````````````
M````````````````````````````````````````````````00````````!A
M````````````````````0@````````!B````````````````````0P``````
M``!C````````````````````1`````````!D````````````````````10``
M``````!E````````````````````1@````````!F````````````````````
M1P````````!G````````````````````2`````````!H````````````````
M````20````````!I````````````````````2@````````!J````````````
M````````2P````````!K````````````````````3`````````!L````````
M````````````30````````!M````````````````````3@````````!N````
M````````````````3P````````!O````````````````````4`````````!P
M````````````````````40````````!Q````````````````````4@``````
M``!R````````````````````4P````````!S````````````````````5```
M``````!T````````````````````50````````!U````````````````````
M5@````````!V````````````````````5P````````!W````````````````
M````6`````````!X````````````````````60````````!Y````````````
M````````6@````````!Z````````````````````M0````````"\`P``````
M````````````P`````````#@````````````````````P0````````#A````
M````````````````P@````````#B````````````````````PP````````#C
M````````````````````Q`````````#D````````````````````Q0``````
M``#E````````````````````Q@````````#F````````````````````QP``
M``````#G````````````````````R`````````#H````````````````````
MR0````````#I````````````````````R@````````#J````````````````
M````RP````````#K````````````````````S`````````#L````````````
M````````S0````````#M````````````````````S@````````#N````````
M````````````SP````````#O````````````````````T`````````#P````
M````````````````T0````````#Q````````````````````T@````````#R
M````````````````````TP````````#S````````````````````U```````
M``#T````````````````````U0````````#U````````````````````U@``
M``````#V````````````````````V`````````#X````````````````````
MV0````````#Y````````````````````V@````````#Z````````````````
M````VP````````#[````````````````````W`````````#\````````````
M````````W0````````#]````````````````````W@````````#^````````
M````````````WP````````!S````<P````````````````$````````!`0``
M`````````````````@$````````#`0``````````````````!`$````````%
M`0``````````````````!@$````````'`0``````````````````"`$`````
M```)`0``````````````````"@$````````+`0``````````````````#`$`
M```````-`0``````````````````#@$````````/`0``````````````````
M$`$````````1`0``````````````````$@$````````3`0``````````````
M````%`$````````5`0``````````````````%@$````````7`0``````````
M````````&`$````````9`0``````````````````&@$````````;`0``````
M````````````'`$````````=`0``````````````````'@$````````?`0``
M````````````````(`$````````A`0``````````````````(@$````````C
M`0``````````````````)`$````````E`0``````````````````)@$`````
M```G`0``````````````````*`$````````I`0``````````````````*@$`
M```````K`0``````````````````+`$````````M`0``````````````````
M+@$````````O`0``````````````````,`$```````!I````!P,`````````
M````,@$````````S`0``````````````````-`$````````U`0``````````
M````````-@$````````W`0``````````````````.0$````````Z`0``````
M````````````.P$````````\`0``````````````````/0$````````^`0``
M````````````````/P$```````!``0``````````````````00$```````!"
M`0``````````````````0P$```````!$`0``````````````````10$`````
M``!&`0``````````````````1P$```````!(`0``````````````````20$`
M``````"\`@``;@``````````````2@$```````!+`0``````````````````
M3`$```````!-`0``````````````````3@$```````!/`0``````````````
M````4`$```````!1`0``````````````````4@$```````!3`0``````````
M````````5`$```````!5`0``````````````````5@$```````!7`0``````
M````````````6`$```````!9`0``````````````````6@$```````!;`0``
M````````````````7`$```````!=`0``````````````````7@$```````!?
M`0``````````````````8`$```````!A`0``````````````````8@$`````
M``!C`0``````````````````9`$```````!E`0``````````````````9@$`
M``````!G`0``````````````````:`$```````!I`0``````````````````
M:@$```````!K`0``````````````````;`$```````!M`0``````````````
M````;@$```````!O`0``````````````````<`$```````!Q`0``````````
M````````<@$```````!S`0``````````````````=`$```````!U`0``````
M````````````=@$```````!W`0``````````````````>`$```````#_````
M````````````````>0$```````!Z`0``````````````````>P$```````!\
M`0``````````````````?0$```````!^`0``````````````````?P$`````
M``!S````````````````````@0$```````!3`@``````````````````@@$`
M``````"#`0``````````````````A`$```````"%`0``````````````````
MA@$```````!4`@``````````````````AP$```````"(`0``````````````
M````B0$```````!6`@``````````````````B@$```````!7`@``````````
M````````BP$```````",`0``````````````````C@$```````#=`0``````
M````````````CP$```````!9`@``````````````````D`$```````!;`@``
M````````````````D0$```````"2`0``````````````````DP$```````!@
M`@``````````````````E`$```````!C`@``````````````````E@$`````
M``!I`@``````````````````EP$```````!H`@``````````````````F`$`
M``````"9`0``````````````````G`$```````!O`@``````````````````
MG0$```````!R`@``````````````````GP$```````!U`@``````````````
M````H`$```````"A`0``````````````````H@$```````"C`0``````````
M````````I`$```````"E`0``````````````````I@$```````"``@``````
M````````````IP$```````"H`0``````````````````J0$```````"#`@``
M````````````````K`$```````"M`0``````````````````K@$```````"(
M`@``````````````````KP$```````"P`0``````````````````L0$`````
M``"*`@``````````````````L@$```````"+`@``````````````````LP$`
M``````"T`0``````````````````M0$```````"V`0``````````````````
MMP$```````"2`@``````````````````N`$```````"Y`0``````````````
M````O`$```````"]`0``````````````````Q`$```````#&`0``````````
M````````Q0$```````#&`0``````````````````QP$```````#)`0``````
M````````````R`$```````#)`0``````````````````R@$```````#,`0``
M````````````````RP$```````#,`0``````````````````S0$```````#.
M`0``````````````````SP$```````#0`0``````````````````T0$`````
M``#2`0``````````````````TP$```````#4`0``````````````````U0$`
M``````#6`0``````````````````UP$```````#8`0``````````````````
MV0$```````#:`0``````````````````VP$```````#<`0``````````````
M````W@$```````#?`0``````````````````X`$```````#A`0``````````
M````````X@$```````#C`0``````````````````Y`$```````#E`0``````
M````````````Y@$```````#G`0``````````````````Z`$```````#I`0``
M````````````````Z@$```````#K`0``````````````````[`$```````#M
M`0``````````````````[@$```````#O`0``````````````````\`$`````
M``!J````#`,`````````````\0$```````#S`0``````````````````\@$`
M``````#S`0``````````````````]`$```````#U`0``````````````````
M]@$```````"5`0``````````````````]P$```````"_`0``````````````
M````^`$```````#Y`0``````````````````^@$```````#[`0``````````
M````````_`$```````#]`0``````````````````_@$```````#_`0``````
M``````````````(````````!`@```````````````````@(````````#`@``
M````````````````!`(````````%`@``````````````````!@(````````'
M`@``````````````````"`(````````)`@``````````````````"@(`````
M```+`@``````````````````#`(````````-`@``````````````````#@(`
M```````/`@``````````````````$`(````````1`@``````````````````
M$@(````````3`@``````````````````%`(````````5`@``````````````
M````%@(````````7`@``````````````````&`(````````9`@``````````
M````````&@(````````;`@``````````````````'`(````````=`@``````
M````````````'@(````````?`@``````````````````(`(```````">`0``
M````````````````(@(````````C`@``````````````````)`(````````E
M`@``````````````````)@(````````G`@``````````````````*`(`````
M```I`@``````````````````*@(````````K`@``````````````````+`(`
M```````M`@``````````````````+@(````````O`@``````````````````
M,`(````````Q`@``````````````````,@(````````S`@``````````````
M````10,```````"Y`P``````````````````>@,````````@````N0,`````
M````````A@,```````"L`P``````````````````B`,```````"M`P``````
M````````````B0,```````"N`P``````````````````B@,```````"O`P``
M````````````````C`,```````#,`P``````````````````C@,```````#-
M`P``````````````````CP,```````#.`P``````````````````D`,`````
M``"Y`P``"`,```$#````````D0,```````"Q`P``````````````````D@,`
M``````"R`P``````````````````DP,```````"S`P``````````````````
ME`,```````"T`P``````````````````E0,```````"U`P``````````````
M````E@,```````"V`P``````````````````EP,```````"W`P``````````
M````````F`,```````"X`P``````````````````F0,```````"Y`P``````
M````````````F@,```````"Z`P``````````````````FP,```````"[`P``
M````````````````G`,```````"\`P``````````````````G0,```````"]
M`P``````````````````G@,```````"^`P``````````````````GP,`````
M``"_`P``````````````````H`,```````#``P``````````````````H0,`
M``````#!`P``````````````````HP,```````##`P``````````````````
MI`,```````#$`P``````````````````I0,```````#%`P``````````````
M````I@,```````#&`P``````````````````IP,```````#'`P``````````
M````````J`,```````#(`P``````````````````J0,```````#)`P``````
M````````````J@,```````#*`P``````````````````JP,```````#+`P``
M````````````````L`,```````#%`P``"`,```$#````````P@,```````##
M`P``````````````````T`,```````"R`P``````````````````T0,`````
M``"X`P``````````````````T@,```````#%`P``````````````````TP,`
M``````#-`P``````````````````U`,```````#+`P``````````````````
MU0,```````#&`P``````````````````U@,```````#``P``````````````
M````V`,```````#9`P``````````````````V@,```````#;`P``````````
M````````W`,```````#=`P``````````````````W@,```````#?`P``````
M````````````X`,```````#A`P``````````````````X@,```````#C`P``
M````````````````Y`,```````#E`P``````````````````Y@,```````#G
M`P``````````````````Z`,```````#I`P``````````````````Z@,`````
M``#K`P``````````````````[`,```````#M`P``````````````````[@,`
M``````#O`P``````````````````\`,```````"Z`P``````````````````
M\0,```````#!`P``````````````````\@,```````##`P``````````````
M````]`,```````"X`P``````````````````]0,```````"U`P``````````
M``````````0```````!0!````````````````````00```````!1!```````
M`````````````@0```````!2!````````````````````P0```````!3!```
M````````````````!`0```````!4!```````````````````!00```````!5
M!```````````````````!@0```````!6!```````````````````!P0`````
M``!7!```````````````````"`0```````!8!```````````````````"00`
M``````!9!```````````````````"@0```````!:!```````````````````
M"P0```````!;!```````````````````#`0```````!<!```````````````
M````#00```````!=!```````````````````#@0```````!>!```````````
M````````#P0```````!?!```````````````````$`0````````P!```````
M````````````$00````````Q!```````````````````$@0````````R!```
M````````````````$P0````````S!```````````````````%`0````````T
M!```````````````````%00````````U!```````````````````%@0`````
M```V!```````````````````%P0````````W!```````````````````&`0`
M```````X!```````````````````&00````````Y!```````````````````
M&@0````````Z!```````````````````&P0````````[!```````````````
M````'`0````````\!```````````````````'00````````]!```````````
M````````'@0````````^!```````````````````'P0````````_!```````
M````````````(`0```````!`!```````````````````(00```````!!!```
M````````````````(@0```````!"!```````````````````(P0```````!#
M!```````````````````)`0```````!$!```````````````````)00`````
M``!%!```````````````````)@0```````!&!```````````````````)P0`
M``````!'!```````````````````*`0```````!(!```````````````````
M*00```````!)!```````````````````*@0```````!*!```````````````
M````*P0```````!+!```````````````````+`0```````!,!```````````
M````````+00```````!-!```````````````````+@0```````!.!```````
M````````````+P0```````!/!```````````````````8`0```````!A!```
M````````````````8@0```````!C!```````````````````9`0```````!E
M!```````````````````9@0```````!G!```````````````````:`0`````
M``!I!```````````````````:@0```````!K!```````````````````;`0`
M``````!M!```````````````````;@0```````!O!```````````````````
M<`0```````!Q!```````````````````<@0```````!S!```````````````
M````=`0```````!U!```````````````````=@0```````!W!```````````
M````````>`0```````!Y!```````````````````>@0```````![!```````
M````````````?`0```````!]!```````````````````?@0```````!_!```
M````````````````@`0```````"!!```````````````````B@0```````"+
M!```````````````````C`0```````"-!```````````````````C@0`````
M``"/!```````````````````D`0```````"1!```````````````````D@0`
M``````"3!```````````````````E`0```````"5!```````````````````
ME@0```````"7!```````````````````F`0```````"9!```````````````
M````F@0```````";!```````````````````G`0```````"=!```````````
M````````G@0```````"?!```````````````````H`0```````"A!```````
M````````````H@0```````"C!```````````````````I`0```````"E!```
M````````````````I@0```````"G!```````````````````J`0```````"I
M!```````````````````J@0```````"K!```````````````````K`0`````
M``"M!```````````````````K@0```````"O!```````````````````L`0`
M``````"Q!```````````````````L@0```````"S!```````````````````
MM`0```````"U!```````````````````M@0```````"W!```````````````
M````N`0```````"Y!```````````````````N@0```````"[!```````````
M````````O`0```````"]!```````````````````O@0```````"_!```````
M````````````P00```````#"!```````````````````PP0```````#$!```
M````````````````Q00```````#&!```````````````````QP0```````#(
M!```````````````````R00```````#*!```````````````````RP0`````
M``#,!```````````````````S00```````#.!```````````````````T`0`
M``````#1!```````````````````T@0```````#3!```````````````````
MU`0```````#5!```````````````````U@0```````#7!```````````````
M````V`0```````#9!```````````````````V@0```````#;!```````````
M````````W`0```````#=!```````````````````W@0```````#?!```````
M````````````X`0```````#A!```````````````````X@0```````#C!```
M````````````````Y`0```````#E!```````````````````Y@0```````#G
M!```````````````````Z`0```````#I!```````````````````Z@0`````
M``#K!```````````````````[`0```````#M!```````````````````[@0`
M``````#O!```````````````````\`0```````#Q!```````````````````
M\@0```````#S!```````````````````]`0```````#U!```````````````
M````^`0```````#Y!`````````````````````4````````!!0``````````
M`````````@4````````#!0``````````````````!`4````````%!0``````
M````````````!@4````````'!0``````````````````"`4````````)!0``
M````````````````"@4````````+!0``````````````````#`4````````-
M!0``````````````````#@4````````/!0``````````````````,04`````
M``!A!0``````````````````,@4```````!B!0``````````````````,P4`
M``````!C!0``````````````````-`4```````!D!0``````````````````
M-04```````!E!0``````````````````-@4```````!F!0``````````````
M````-P4```````!G!0``````````````````.`4```````!H!0``````````
M````````.04```````!I!0``````````````````.@4```````!J!0``````
M````````````.P4```````!K!0``````````````````/`4```````!L!0``
M````````````````/04```````!M!0``````````````````/@4```````!N
M!0``````````````````/P4```````!O!0``````````````````0`4`````
M``!P!0``````````````````004```````!Q!0``````````````````0@4`
M``````!R!0``````````````````0P4```````!S!0``````````````````
M1`4```````!T!0``````````````````104```````!U!0``````````````
M````1@4```````!V!0``````````````````1P4```````!W!0``````````
M````````2`4```````!X!0``````````````````204```````!Y!0``````
M````````````2@4```````!Z!0``````````````````2P4```````![!0``
M````````````````3`4```````!\!0``````````````````304```````!]
M!0``````````````````3@4```````!^!0``````````````````3P4`````
M``!_!0``````````````````4`4```````"`!0``````````````````404`
M``````"!!0``````````````````4@4```````""!0``````````````````
M4P4```````"#!0``````````````````5`4```````"$!0``````````````
M````504```````"%!0``````````````````5@4```````"&!0``````````
M````````AP4```````!E!0``@@4``````````````!X````````!'@``````
M`````````````AX````````#'@``````````````````!!X````````%'@``
M````````````````!AX````````''@``````````````````"!X````````)
M'@``````````````````"AX````````+'@``````````````````#!X`````
M```-'@``````````````````#AX````````/'@``````````````````$!X`
M```````1'@``````````````````$AX````````3'@``````````````````
M%!X````````5'@``````````````````%AX````````7'@``````````````
M````&!X````````9'@``````````````````&AX````````;'@``````````
M````````'!X````````='@``````````````````'AX````````?'@``````
M````````````(!X````````A'@``````````````````(AX````````C'@``
M````````````````)!X````````E'@``````````````````)AX````````G
M'@``````````````````*!X````````I'@``````````````````*AX`````
M```K'@``````````````````+!X````````M'@``````````````````+AX`
M```````O'@``````````````````,!X````````Q'@``````````````````
M,AX````````S'@``````````````````-!X````````U'@``````````````
M````-AX````````W'@``````````````````.!X````````Y'@``````````
M````````.AX````````['@``````````````````/!X````````]'@``````
M````````````/AX````````_'@``````````````````0!X```````!!'@``
M````````````````0AX```````!#'@``````````````````1!X```````!%
M'@``````````````````1AX```````!''@``````````````````2!X`````
M``!)'@``````````````````2AX```````!+'@``````````````````3!X`
M``````!-'@``````````````````3AX```````!/'@``````````````````
M4!X```````!1'@``````````````````4AX```````!3'@``````````````
M````5!X```````!5'@``````````````````5AX```````!7'@``````````
M````````6!X```````!9'@``````````````````6AX```````!;'@``````
M````````````7!X```````!='@``````````````````7AX```````!?'@``
M````````````````8!X```````!A'@``````````````````8AX```````!C
M'@``````````````````9!X```````!E'@``````````````````9AX`````
M``!G'@``````````````````:!X```````!I'@``````````````````:AX`
M``````!K'@``````````````````;!X```````!M'@``````````````````
M;AX```````!O'@``````````````````<!X```````!Q'@``````````````
M````<AX```````!S'@``````````````````=!X```````!U'@``````````
M````````=AX```````!W'@``````````````````>!X```````!Y'@``````
M````````````>AX```````!['@``````````````````?!X```````!]'@``
M````````````````?AX```````!_'@``````````````````@!X```````"!
M'@``````````````````@AX```````"#'@``````````````````A!X`````
M``"%'@``````````````````AAX```````"''@``````````````````B!X`
M``````")'@``````````````````BAX```````"+'@``````````````````
MC!X```````"-'@``````````````````CAX```````"/'@``````````````
M````D!X```````"1'@``````````````````DAX```````"3'@``````````
M````````E!X```````"5'@``````````````````EAX```````!H````,0,`
M````````````EQX```````!T````"`,`````````````F!X```````!W````
M"@,`````````````F1X```````!Y````"@,`````````````FAX```````!A
M````O@(`````````````FQX```````!A'@``````````````````H!X`````
M``"A'@``````````````````HAX```````"C'@``````````````````I!X`
M``````"E'@``````````````````IAX```````"G'@``````````````````
MJ!X```````"I'@``````````````````JAX```````"K'@``````````````
M````K!X```````"M'@``````````````````KAX```````"O'@``````````
M````````L!X```````"Q'@``````````````````LAX```````"S'@``````
M````````````M!X```````"U'@``````````````````MAX```````"W'@``
M````````````````N!X```````"Y'@``````````````````NAX```````"[
M'@``````````````````O!X```````"]'@``````````````````OAX`````
M``"_'@``````````````````P!X```````#!'@``````````````````PAX`
M``````##'@``````````````````Q!X```````#%'@``````````````````
MQAX```````#''@``````````````````R!X```````#)'@``````````````
M````RAX```````#+'@``````````````````S!X```````#-'@``````````
M````````SAX```````#/'@``````````````````T!X```````#1'@``````
M````````````TAX```````#3'@``````````````````U!X```````#5'@``
M````````````````UAX```````#7'@``````````````````V!X```````#9
M'@``````````````````VAX```````#;'@``````````````````W!X`````
M``#='@``````````````````WAX```````#?'@``````````````````X!X`
M``````#A'@``````````````````XAX```````#C'@``````````````````
MY!X```````#E'@``````````````````YAX```````#G'@``````````````
M````Z!X```````#I'@``````````````````ZAX```````#K'@``````````
M````````[!X```````#M'@``````````````````[AX```````#O'@``````
M````````````\!X```````#Q'@``````````````````\AX```````#S'@``
M````````````````]!X```````#U'@``````````````````]AX```````#W
M'@``````````````````^!X```````#Y'@``````````````````"!\`````
M````'P``````````````````"1\````````!'P``````````````````"A\`
M```````"'P``````````````````"Q\````````#'P``````````````````
M#!\````````$'P``````````````````#1\````````%'P``````````````
M````#A\````````&'P``````````````````#Q\````````''P``````````
M````````&!\````````0'P``````````````````&1\````````1'P``````
M````````````&A\````````2'P``````````````````&Q\````````3'P``
M````````````````'!\````````4'P``````````````````'1\````````5
M'P``````````````````*!\````````@'P``````````````````*1\`````
M```A'P``````````````````*A\````````B'P``````````````````*Q\`
M```````C'P``````````````````+!\````````D'P``````````````````
M+1\````````E'P``````````````````+A\````````F'P``````````````
M````+Q\````````G'P``````````````````.!\````````P'P``````````
M````````.1\````````Q'P``````````````````.A\````````R'P``````
M````````````.Q\````````S'P``````````````````/!\````````T'P``
M````````````````/1\````````U'P``````````````````/A\````````V
M'P``````````````````/Q\````````W'P``````````````````2!\`````
M``!`'P``````````````````21\```````!!'P``````````````````2A\`
M``````!"'P``````````````````2Q\```````!#'P``````````````````
M3!\```````!$'P``````````````````31\```````!%'P``````````````
M````4!\```````#%`P``$P,`````````````4A\```````#%`P``$P,````#
M````````5!\```````#%`P``$P,```$#````````5A\```````#%`P``$P,`
M`$(#````````61\```````!1'P``````````````````6Q\```````!3'P``
M````````````````71\```````!5'P``````````````````7Q\```````!7
M'P``````````````````:!\```````!@'P``````````````````:1\`````
M``!A'P``````````````````:A\```````!B'P``````````````````:Q\`
M``````!C'P``````````````````;!\```````!D'P``````````````````
M;1\```````!E'P``````````````````;A\```````!F'P``````````````
M````;Q\```````!G'P``````````````````@!\`````````'P``N0,`````
M````````@1\````````!'P``N0,`````````````@A\````````"'P``N0,`
M````````````@Q\````````#'P``N0,`````````````A!\````````$'P``
MN0,`````````````A1\````````%'P``N0,`````````````AA\````````&
M'P``N0,`````````````AQ\````````''P``N0,`````````````B!\`````
M````'P``N0,`````````````B1\````````!'P``N0,`````````````BA\`
M```````"'P``N0,`````````````BQ\````````#'P``N0,`````````````
MC!\````````$'P``N0,`````````````C1\````````%'P``N0,`````````
M````CA\````````&'P``N0,`````````````CQ\````````''P``N0,`````
M````````D!\````````@'P``N0,`````````````D1\````````A'P``N0,`
M````````````DA\````````B'P``N0,`````````````DQ\````````C'P``
MN0,`````````````E!\````````D'P``N0,`````````````E1\````````E
M'P``N0,`````````````EA\````````F'P``N0,`````````````EQ\`````
M```G'P``N0,`````````````F!\````````@'P``N0,`````````````F1\`
M```````A'P``N0,`````````````FA\````````B'P``N0,`````````````
MFQ\````````C'P``N0,`````````````G!\````````D'P``N0,`````````
M````G1\````````E'P``N0,`````````````GA\````````F'P``N0,`````
M````````GQ\````````G'P``N0,`````````````H!\```````!@'P``N0,`
M````````````H1\```````!A'P``N0,`````````````HA\```````!B'P``
MN0,`````````````HQ\```````!C'P``N0,`````````````I!\```````!D
M'P``N0,`````````````I1\```````!E'P``N0,`````````````IA\`````
M``!F'P``N0,`````````````IQ\```````!G'P``N0,`````````````J!\`
M``````!@'P``N0,`````````````J1\```````!A'P``N0,`````````````
MJA\```````!B'P``N0,`````````````JQ\```````!C'P``N0,`````````
M````K!\```````!D'P``N0,`````````````K1\```````!E'P``N0,`````
M````````KA\```````!F'P``N0,`````````````KQ\```````!G'P``N0,`
M````````````LA\```````!P'P``N0,`````````````LQ\```````"Q`P``
MN0,`````````````M!\```````"L`P``N0,`````````````MA\```````"Q
M`P``0@,`````````````MQ\```````"Q`P``0@,``+D#````````N!\`````
M``"P'P``````````````````N1\```````"Q'P``````````````````NA\`
M``````!P'P``````````````````NQ\```````!Q'P``````````````````
MO!\```````"Q`P``N0,`````````````OA\```````"Y`P``````````````
M````PA\```````!T'P``N0,`````````````PQ\```````"W`P``N0,`````
M````````Q!\```````"N`P``N0,`````````````QA\```````"W`P``0@,`
M````````````QQ\```````"W`P``0@,``+D#````````R!\```````!R'P``
M````````````````R1\```````!S'P``````````````````RA\```````!T
M'P``````````````````RQ\```````!U'P``````````````````S!\`````
M``"W`P``N0,`````````````TA\```````"Y`P``"`,````#````````TQ\`
M``````"Y`P``"`,```$#````````UA\```````"Y`P``0@,`````````````
MUQ\```````"Y`P``"`,``$(#````````V!\```````#0'P``````````````
M````V1\```````#1'P``````````````````VA\```````!V'P``````````
M````````VQ\```````!W'P``````````````````XA\```````#%`P``"`,`
M```#````````XQ\```````#%`P``"`,```$#````````Y!\```````#!`P``
M$P,`````````````YA\```````#%`P``0@,`````````````YQ\```````#%
M`P``"`,``$(#````````Z!\```````#@'P``````````````````Z1\`````
M``#A'P``````````````````ZA\```````!Z'P``````````````````ZQ\`
M``````!['P``````````````````[!\```````#E'P``````````````````
M\A\```````!\'P``N0,`````````````\Q\```````#)`P``N0,`````````
M````]!\```````#.`P``N0,`````````````]A\```````#)`P``0@,`````
M````````]Q\```````#)`P``0@,``+D#````````^!\```````!X'P``````
M````````````^1\```````!Y'P``````````````````^A\```````!\'P``
M````````````````^Q\```````!]'P``````````````````_!\```````#)
M`P``N0,`````````````J"````````!R````<P```````````````B$`````
M``!C`````````````````````R$```````"P````8P``````````````!R$`
M``````!;`@``````````````````"2$```````"P````9@``````````````
M"R$```````!H````````````````````#"$```````!H````````````````
M````#2$```````!H````````````````````$"$```````!I````````````
M````````$2$```````!I````````````````````$B$```````!L````````
M````````````%2$```````!N````````````````````%B$```````!N````
M;P``````````````&2$```````!P````````````````````&B$```````!Q
M````````````````````&R$```````!R````````````````````'"$`````
M``!R````````````````````'2$```````!R````````````````````("$`
M``````!S````;0``````````````(2$```````!T````90```&P`````````
M(B$```````!T````;0``````````````)"$```````!Z````````````````
M````)B$```````#)`P``````````````````*"$```````!Z````````````
M````````*B$```````!K````````````````````*R$```````#E````````
M````````````+"$```````!B````````````````````+2$```````!C````
M````````````````,"$```````!E````````````````````,2$```````!F
M````````````````````,R$```````!M````````````````````/B$`````
M``"S`P``````````````````/R$```````#``P``````````````````12$`
M``````!D````````````````````8"$```````!P(0``````````````````
M82$```````!Q(0``````````````````8B$```````!R(0``````````````
M````8R$```````!S(0``````````````````9"$```````!T(0``````````
M````````92$```````!U(0``````````````````9B$```````!V(0``````
M````````````9R$```````!W(0``````````````````:"$```````!X(0``
M````````````````:2$```````!Y(0``````````````````:B$```````!Z
M(0``````````````````:R$```````![(0``````````````````;"$`````
M``!\(0``````````````````;2$```````!](0``````````````````;B$`
M``````!^(0``````````````````;R$```````!_(0``````````````````
MMB0```````#0)```````````````````MR0```````#1)```````````````
M````N"0```````#2)```````````````````N20```````#3)```````````
M````````NB0```````#4)```````````````````NR0```````#5)```````
M````````````O"0```````#6)```````````````````O20```````#7)```
M````````````````OB0```````#8)```````````````````OR0```````#9
M)```````````````````P"0```````#:)```````````````````P20`````
M``#;)```````````````````PB0```````#<)```````````````````PR0`
M``````#=)```````````````````Q"0```````#>)```````````````````
MQ20```````#?)```````````````````QB0```````#@)```````````````
M````QR0```````#A)```````````````````R"0```````#B)```````````
M````````R20```````#C)```````````````````RB0```````#D)```````
M````````````RR0```````#E)```````````````````S"0```````#F)```
M````````````````S20```````#G)```````````````````SB0```````#H
M)```````````````````SR0```````#I)```````````````````<3,`````
M``!H````<````&$`````````<S,```````!A````=0``````````````=3,`
M``````!O````=@``````````````@#,```````!P````80``````````````
M@3,```````!N````80``````````````@C,```````"\`P``80``````````
M````@S,```````!M````80``````````````A#,```````!K````80``````
M````````A3,```````!K````8@``````````````AC,```````!M````8@``
M````````````AS,```````!G````8@``````````````BC,```````!P````
M9@``````````````BS,```````!N````9@``````````````C#,```````"\
M`P``9@``````````````D#,```````!H````>@``````````````D3,`````
M``!K````:````'H`````````DC,```````!M````:````'H`````````DS,`
M``````!G````:````'H`````````E#,```````!T````:````'H`````````
MJ3,```````!P````80``````````````JC,```````!K````<````&$`````
M````JS,```````!M````<````&$`````````K#,```````!G````<````&$`
M````````M#,```````!P````=@``````````````M3,```````!N````=@``
M````````````MC,```````"\`P``=@``````````````MS,```````!M````
M=@``````````````N#,```````!K````=@``````````````N3,```````!M
M````=@``````````````NC,```````!P````=P``````````````NS,`````
M``!N````=P``````````````O#,```````"\`P``=P``````````````O3,`
M``````!M````=P``````````````OC,```````!K````=P``````````````
MOS,```````!M````=P``````````````P#,```````!K````R0,`````````
M````P3,```````!M````R0,`````````````PS,```````!B````<0``````
M````````QC,```````!C````%2(``&L```!G````QS,```````!C````;P``
M`"X`````````R#,```````!D````8@``````````````R3,```````!G````
M>0``````````````RS,```````!H````<```````````````S3,```````!K
M````:P``````````````SC,```````!K````;0``````````````US,`````
M``!P````:```````````````V3,```````!P````<````&T`````````VC,`
M``````!P````<@``````````````W#,```````!S````=@``````````````
MW3,```````!W````8@```````````````/L```````!F````9@``````````
M`````?L```````!F````:0```````````````OL```````!F````;```````
M`````````_L```````!F````9@```&D`````````!/L```````!F````9@``
M`&P`````````!?L```````!S````=```````````````!OL```````!S````
M=```````````````$_L```````!T!0``=@4`````````````%/L```````!T
M!0``904`````````````%?L```````!T!0``:P4`````````````%OL`````
M``!^!0``=@4`````````````%_L```````!T!0``;04`````````````(?\`
M``````!!_P``````````````````(O\```````!"_P``````````````````
M(_\```````!#_P``````````````````)/\```````!$_P``````````````
M````)?\```````!%_P``````````````````)O\```````!&_P``````````
M````````)_\```````!'_P``````````````````*/\```````!(_P``````
M````````````*?\```````!)_P``````````````````*O\```````!*_P``
M````````````````*_\```````!+_P``````````````````+/\```````!,
M_P``````````````````+?\```````!-_P``````````````````+O\`````
M``!._P``````````````````+_\```````!/_P``````````````````,/\`
M``````!0_P``````````````````,?\```````!1_P``````````````````
M,O\```````!2_P``````````````````,_\```````!3_P``````````````
M````-/\```````!4_P``````````````````-?\```````!5_P``````````
M````````-O\```````!6_P``````````````````-_\```````!7_P``````
M````````````./\```````!8_P``````````````````.?\```````!9_P``
M````````````````.O\```````!:_P````````````````````0!```````H
M!`$``````````````````00!```````I!`$``````````````````@0!````
M```J!`$``````````````````P0!```````K!`$`````````````````!`0!
M```````L!`$`````````````````!00!```````M!`$`````````````````
M!@0!```````N!`$`````````````````!P0!```````O!`$`````````````
M````"`0!```````P!`$`````````````````"00!```````Q!`$`````````
M````````"@0!```````R!`$`````````````````"P0!```````S!`$`````
M````````````#`0!```````T!`$`````````````````#00!```````U!`$`
M````````````````#@0!```````V!`$`````````````````#P0!```````W
M!`$`````````````````$`0!```````X!`$`````````````````$00!````
M```Y!`$`````````````````$@0!```````Z!`$`````````````````$P0!
M```````[!`$`````````````````%`0!```````\!`$`````````````````
M%00!```````]!`$`````````````````%@0!```````^!`$`````````````
M````%P0!```````_!`$`````````````````&`0!``````!`!`$`````````
M````````&00!``````!!!`$`````````````````&@0!``````!"!`$`````
M````````````&P0!``````!#!`$`````````````````'`0!``````!$!`$`
M````````````````'00!``````!%!`$`````````````````'@0!``````!&
M!`$`````````````````'P0!``````!'!`$`````````````````(`0!````
M``!(!`$`````````````````(00!``````!)!`$`````````````````(@0!
M``````!*!`$`````````````````(P0!``````!+!`$`````````````````
M)`0!``````!,!`$`````````````````)00!``````!-!`$`````````````
M`````-0!``````!A`````````````````````=0!``````!B````````````
M`````````M0!``````!C`````````````````````]0!``````!D````````
M````````````!-0!``````!E````````````````````!=0!``````!F````
M````````````````!M0!``````!G````````````````````!]0!``````!H
M````````````````````"-0!``````!I````````````````````"=0!````
M``!J````````````````````"M0!``````!K````````````````````"]0!
M``````!L````````````````````#-0!``````!M````````````````````
M#=0!``````!N````````````````````#M0!``````!O````````````````
M````#]0!``````!P````````````````````$-0!``````!Q````````````
M````````$=0!``````!R````````````````````$M0!``````!S````````
M````````````$]0!``````!T````````````````````%-0!``````!U````
M````````````````%=0!``````!V````````````````````%M0!``````!W
M````````````````````%]0!``````!X````````````````````&-0!````
M``!Y````````````````````&=0!``````!Z````````````````````--0!
M``````!A````````````````````-=0!``````!B````````````````````
M-M0!``````!C````````````````````-]0!``````!D````````````````
M````.-0!``````!E````````````````````.=0!``````!F````````````
M````````.M0!``````!G````````````````````.]0!``````!H````````
M````````````/-0!``````!I````````````````````/=0!``````!J````
M````````````````/M0!``````!K````````````````````/]0!``````!L
M````````````````````0-0!``````!M````````````````````0=0!````
M``!N````````````````````0M0!``````!O````````````````````0]0!
M``````!P````````````````````1-0!``````!Q````````````````````
M1=0!``````!R````````````````````1M0!``````!S````````````````
M````1]0!``````!T````````````````````2-0!``````!U````````````
M````````2=0!``````!V````````````````````2M0!``````!W````````
M````````````2]0!``````!X````````````````````3-0!``````!Y````
M````````````````3=0!``````!Z````````````````````:-0!``````!A
M````````````````````:=0!``````!B````````````````````:M0!````
M``!C````````````````````:]0!``````!D````````````````````;-0!
M``````!E````````````````````;=0!``````!F````````````````````
M;M0!``````!G````````````````````;]0!``````!H````````````````
M````<-0!``````!I````````````````````<=0!``````!J````````````
M````````<M0!``````!K````````````````````<]0!``````!L````````
M````````````=-0!``````!M````````````````````==0!``````!N````
M````````````````=M0!``````!O````````````````````=]0!``````!P
M````````````````````>-0!``````!Q````````````````````>=0!````
M``!R````````````````````>M0!``````!S````````````````````>]0!
M``````!T````````````````````?-0!``````!U````````````````````
M?=0!``````!V````````````````````?M0!``````!W````````````````
M````?]0!``````!X````````````````````@-0!``````!Y````````````
M````````@=0!``````!Z````````````````````G-0!``````!A````````
M````````````GM0!``````!C````````````````````G]0!``````!D````
M````````````````HM0!``````!G````````````````````I=0!``````!J
M````````````````````IM0!``````!K````````````````````J=0!````
M``!N````````````````````JM0!``````!O````````````````````J]0!
M``````!P````````````````````K-0!``````!Q````````````````````
MKM0!``````!S````````````````````K]0!``````!T````````````````
M````L-0!``````!U````````````````````L=0!``````!V````````````
M````````LM0!``````!W````````````````````L]0!``````!X````````
M````````````M-0!``````!Y````````````````````M=0!``````!Z````
M````````````````T-0!``````!A````````````````````T=0!``````!B
M````````````````````TM0!``````!C````````````````````T]0!````
M``!D````````````````````U-0!``````!E````````````````````U=0!
M``````!F````````````````````UM0!``````!G````````````````````
MU]0!``````!H````````````````````V-0!``````!I````````````````
M````V=0!``````!J````````````````````VM0!``````!K````````````
M````````V]0!``````!L````````````````````W-0!``````!M````````
M````````````W=0!``````!N````````````````````WM0!``````!O````
M````````````````W]0!``````!P````````````````````X-0!``````!Q
M````````````````````X=0!``````!R````````````````````XM0!````
M``!S````````````````````X]0!``````!T````````````````````Y-0!
M``````!U````````````````````Y=0!``````!V````````````````````
MYM0!``````!W````````````````````Y]0!``````!X````````````````
M````Z-0!``````!Y````````````````````Z=0!``````!Z````````````
M````````!-4!``````!A````````````````````!=4!``````!B````````
M````````````!]4!``````!D````````````````````"-4!``````!E````
M````````````````"=4!``````!F````````````````````"M4!``````!G
M````````````````````#=4!``````!J````````````````````#M4!````
M``!K````````````````````#]4!``````!L````````````````````$-4!
M``````!M````````````````````$=4!``````!N````````````````````
M$M4!``````!O````````````````````$]4!``````!P````````````````
M````%-4!``````!Q````````````````````%M4!``````!S````````````
M````````%]4!``````!T````````````````````&-4!``````!U````````
M````````````&=4!``````!V````````````````````&M4!``````!W````
M````````````````&]4!``````!X````````````````````'-4!``````!Y
M````````````````````.-4!``````!A````````````````````.=4!````
M``!B````````````````````.]4!``````!D````````````````````/-4!
M``````!E````````````````````/=4!``````!F````````````````````
M/M4!``````!G````````````````````0-4!``````!I````````````````
M````0=4!``````!J````````````````````0M4!``````!K````````````
M````````0]4!``````!L````````````````````1-4!``````!M````````
M````````````1M4!``````!O````````````````````2M4!``````!S````
M````````````````2]4!``````!T````````````````````3-4!``````!U
M````````````````````3=4!``````!V````````````````````3M4!````
M``!W````````````````````3]4!``````!X````````````````````4-4!
M``````!Y````````````````````;-4!``````!A````````````````````
M;=4!``````!B````````````````````;M4!``````!C````````````````
M````;]4!``````!D````````````````````<-4!``````!E````````````
M````````<=4!``````!F````````````````````<M4!``````!G````````
M````````````<]4!``````!H````````````````````=-4!``````!I````
M````````````````==4!``````!J````````````````````=M4!``````!K
M````````````````````=]4!``````!L````````````````````>-4!````
M``!M````````````````````>=4!``````!N````````````````````>M4!
M``````!O````````````````````>]4!``````!P````````````````````
M?-4!``````!Q````````````````````?=4!``````!R````````````````
M````?M4!``````!S````````````````````?]4!``````!T````````````
M````````@-4!``````!U````````````````````@=4!``````!V````````
M````````````@M4!``````!W````````````````````@]4!``````!X````
M````````````````A-4!``````!Y````````````````````A=4!``````!Z
M````````````````````H-4!``````!A````````````````````H=4!````
M``!B````````````````````HM4!``````!C````````````````````H]4!
M``````!D````````````````````I-4!``````!E````````````````````
MI=4!``````!F````````````````````IM4!``````!G````````````````
M````I]4!``````!H````````````````````J-4!``````!I````````````
M````````J=4!``````!J````````````````````JM4!``````!K````````
M````````````J]4!``````!L````````````````````K-4!``````!M````
M````````````````K=4!``````!N````````````````````KM4!``````!O
M````````````````````K]4!``````!P````````````````````L-4!````
M``!Q````````````````````L=4!``````!R````````````````````LM4!
M``````!S````````````````````L]4!``````!T````````````````````
MM-4!``````!U````````````````````M=4!``````!V````````````````
M````MM4!``````!W````````````````````M]4!``````!X````````````
M````````N-4!``````!Y````````````````````N=4!``````!Z````````
M````````````U-4!``````!A````````````````````U=4!``````!B````
M````````````````UM4!``````!C````````````````````U]4!``````!D
M````````````````````V-4!``````!E````````````````````V=4!````
M``!F````````````````````VM4!``````!G````````````````````V]4!
M``````!H````````````````````W-4!``````!I````````````````````
MW=4!``````!J````````````````````WM4!``````!K````````````````
M````W]4!``````!L````````````````````X-4!``````!M````````````
M````````X=4!``````!N````````````````````XM4!``````!O````````
M````````````X]4!``````!P````````````````````Y-4!``````!Q````
M````````````````Y=4!``````!R````````````````````YM4!``````!S
M````````````````````Y]4!``````!T````````````````````Z-4!````
M``!U````````````````````Z=4!``````!V````````````````````ZM4!
M``````!W````````````````````Z]4!``````!X````````````````````
M[-4!``````!Y````````````````````[=4!``````!Z````````````````
M````"-8!``````!A````````````````````"=8!``````!B````````````
M````````"M8!``````!C````````````````````"]8!``````!D````````
M````````````#-8!``````!E````````````````````#=8!``````!F````
M````````````````#M8!``````!G````````````````````#]8!``````!H
M````````````````````$-8!``````!I````````````````````$=8!````
M``!J````````````````````$M8!``````!K````````````````````$]8!
M``````!L````````````````````%-8!``````!M````````````````````
M%=8!``````!N````````````````````%M8!``````!O````````````````
M````%]8!``````!P````````````````````&-8!``````!Q````````````
M````````&=8!``````!R````````````````````&M8!``````!S````````
M````````````&]8!``````!T````````````````````'-8!``````!U````
M````````````````'=8!``````!V````````````````````'M8!``````!W
M````````````````````']8!``````!X````````````````````(-8!````
M``!Y````````````````````(=8!``````!Z````````````````````/-8!
M``````!A````````````````````/=8!``````!B````````````````````
M/M8!``````!C````````````````````/]8!``````!D````````````````
M````0-8!``````!E````````````````````0=8!``````!F````````````
M````````0M8!``````!G````````````````````0]8!``````!H````````
M````````````1-8!``````!I````````````````````1=8!``````!J````
M````````````````1M8!``````!K````````````````````1]8!``````!L
M````````````````````2-8!``````!M````````````````````2=8!````
M``!N````````````````````2M8!``````!O````````````````````2]8!
M``````!P````````````````````3-8!``````!Q````````````````````
M3=8!``````!R````````````````````3M8!``````!S````````````````
M````3]8!``````!T````````````````````4-8!``````!U````````````
M````````4=8!``````!V````````````````````4M8!``````!W````````
M````````````4]8!``````!X````````````````````5-8!``````!Y````
M````````````````5=8!``````!Z````````````````````<-8!``````!A
M````````````````````<=8!``````!B````````````````````<M8!````
M``!C````````````````````<]8!``````!D````````````````````=-8!
M``````!E````````````````````==8!``````!F````````````````````
M=M8!``````!G````````````````````=]8!``````!H````````````````
M````>-8!``````!I````````````````````>=8!``````!J````````````
M````````>M8!``````!K````````````````````>]8!``````!L````````
M````````````?-8!``````!M````````````````````?=8!``````!N````
M````````````````?M8!``````!O````````````````````?]8!``````!P
M````````````````````@-8!``````!Q````````````````````@=8!````
M``!R````````````````````@M8!``````!S````````````````````@]8!
M``````!T````````````````````A-8!``````!U````````````````````
MA=8!``````!V````````````````````AM8!``````!W````````````````
M````A]8!``````!X````````````````````B-8!``````!Y````````````
M````````B=8!``````!Z````````````````````J-8!``````"Q`P``````
M````````````J=8!``````"R`P``````````````````JM8!``````"S`P``
M````````````````J]8!``````"T`P``````````````````K-8!``````"U
M`P``````````````````K=8!``````"V`P``````````````````KM8!````
M``"W`P``````````````````K]8!``````"X`P``````````````````L-8!
M``````"Y`P``````````````````L=8!``````"Z`P``````````````````
MLM8!``````"[`P``````````````````L]8!``````"\`P``````````````
M````M-8!``````"]`P``````````````````M=8!``````"^`P``````````
M````````MM8!``````"_`P``````````````````M]8!``````#``P``````
M````````````N-8!``````#!`P``````````````````N=8!``````"X`P``
M````````````````NM8!``````##`P``````````````````N]8!``````#$
M`P``````````````````O-8!``````#%`P``````````````````O=8!````
M``#&`P``````````````````OM8!``````#'`P``````````````````O]8!
M``````#(`P``````````````````P-8!``````#)`P``````````````````
MT]8!``````##`P``````````````````XM8!``````"Q`P``````````````
M````X]8!``````"R`P``````````````````Y-8!``````"S`P``````````
M````````Y=8!``````"T`P``````````````````YM8!``````"U`P``````
M````````````Y]8!``````"V`P``````````````````Z-8!``````"W`P``
M````````````````Z=8!``````"X`P``````````````````ZM8!``````"Y
M`P``````````````````Z]8!``````"Z`P``````````````````[-8!````
M``"[`P``````````````````[=8!``````"\`P``````````````````[M8!
M``````"]`P``````````````````[]8!``````"^`P``````````````````
M\-8!``````"_`P``````````````````\=8!``````#``P``````````````
M````\M8!``````#!`P``````````````````\]8!``````"X`P``````````
M````````]-8!``````##`P``````````````````]=8!``````#$`P``````
M````````````]M8!``````#%`P``````````````````]]8!``````#&`P``
M````````````````^-8!``````#'`P``````````````````^=8!``````#(
M`P``````````````````^M8!``````#)`P``````````````````#=<!````
M``##`P``````````````````'-<!``````"Q`P``````````````````'=<!
M``````"R`P``````````````````'M<!``````"S`P``````````````````
M']<!``````"T`P``````````````````(-<!``````"U`P``````````````
M````(=<!``````"V`P``````````````````(M<!``````"W`P``````````
M````````(]<!``````"X`P``````````````````)-<!``````"Y`P``````
M````````````)=<!``````"Z`P``````````````````)M<!``````"[`P``
M````````````````)]<!``````"\`P``````````````````*-<!``````"]
M`P``````````````````*=<!``````"^`P``````````````````*M<!````
M``"_`P``````````````````*]<!``````#``P``````````````````+-<!
M``````#!`P``````````````````+=<!``````"X`P``````````````````
M+M<!``````##`P``````````````````+]<!``````#$`P``````````````
M````,-<!``````#%`P``````````````````,=<!``````#&`P``````````
M````````,M<!``````#'`P``````````````````,]<!``````#(`P``````
M````````````--<!``````#)`P``````````````````1]<!``````##`P``
M````````````````5M<!``````"Q`P``````````````````5]<!``````"R
M`P``````````````````6-<!``````"S`P``````````````````6=<!````
M``"T`P``````````````````6M<!``````"U`P``````````````````6]<!
M``````"V`P``````````````````7-<!``````"W`P``````````````````
M7=<!``````"X`P``````````````````7M<!``````"Y`P``````````````
M````7]<!``````"Z`P``````````````````8-<!``````"[`P``````````
M````````8=<!``````"\`P``````````````````8M<!``````"]`P``````
M````````````8]<!``````"^`P``````````````````9-<!``````"_`P``
M````````````````9=<!``````#``P``````````````````9M<!``````#!
M`P``````````````````9]<!``````"X`P``````````````````:-<!````
M``##`P``````````````````:=<!``````#$`P``````````````````:M<!
M``````#%`P``````````````````:]<!``````#&`P``````````````````
M;-<!``````#'`P``````````````````;=<!``````#(`P``````````````
M````;M<!``````#)`P``````````````````@=<!``````##`P``````````
M````````D-<!``````"Q`P``````````````````D=<!``````"R`P``````
M````````````DM<!``````"S`P``````````````````D]<!``````"T`P``
M````````````````E-<!``````"U`P``````````````````E=<!``````"V
M`P``````````````````EM<!``````"W`P``````````````````E]<!````
M``"X`P``````````````````F-<!``````"Y`P``````````````````F=<!
M``````"Z`P``````````````````FM<!``````"[`P``````````````````
MF]<!``````"\`P``````````````````G-<!``````"]`P``````````````
M````G=<!``````"^`P``````````````````GM<!``````"_`P``````````
M````````G]<!``````#``P``````````````````H-<!``````#!`P``````
M````````````H=<!``````"X`P``````````````````HM<!``````##`P``
M````````````````H]<!``````#$`P``````````````````I-<!``````#%
M`P``````````````````I=<!``````#&`P``````````````````IM<!````
M``#'`P``````````````````I]<!``````#(`P``````````````````J-<!
M``````#)`P``````````````````N]<!``````##`P``````````````````
M````````````````````````````````K0``````````````````````````
M````3P,`````````````````````````````!A@`````````````````````
M````````"Q@`````````````````````````````#!@`````````````````
M````````````#1@`````````````````````````````"R``````````````
M````````````````#"``````````````````````````````#2``````````
M````````````````````8"```````````````````````````````/X`````
M`````````````````````````?X``````````````````````````````OX`
M`````````````````````````````_X`````````````````````````````
M!/X`````````````````````````````!?X`````````````````````````
M````!OX`````````````````````````````!_X`````````````````````
M````````"/X`````````````````````````````"?X`````````````````
M````````````"OX`````````````````````````````"_X`````````````
M````````````````#/X`````````````````````````````#?X`````````
M````````````````````#OX`````````````````````````````#_X`````
M````````````````````````__X`````````````````````````````````
M````````````````````````````(0(`````````````````````````````
M-`(``$\"````````````````````````K@(``*\"````````````````````
M````[P(``/\"````````````````````````4`,``%\#````````````````
M````````<`,``',#````````````````````````=@,``'D#````````````
M````````````>P,``'T#````````````````````````?P,``(,#````````
M````````````````BP,`````````````````````````````C0,`````````
M````````````````````H@,`````````````````````````````SP,`````
M````````````````````````]P,``/\#````````````````````````AP0`
M````````````````````````````SP0`````````````````````````````
M]@0``/<$````````````````````````^@0``/\$````````````````````
M````$`4``#`%````````````````````````5P4``%@%````````````````
M````````8`4`````````````````````````````B`4`````````````````
M````````````BP4``)`%````````````````````````H@4`````````````
M````````````````N@4`````````````````````````````Q04``,\%````
M````````````````````ZP4``.\%````````````````````````]04```L&
M````````````````````````#08``!H&````````````````````````'`8`
M`!X&````````````````````````(`8`````````````````````````````
M.P8``#\&````````````````````````5@8``%\&````````````````````
M````[@8``.\&````````````````````````_P8`````````````````````
M````````#@<`````````````````````````````+0<``"\'````````````
M````````````2P<``'\'````````````````````````L@<````)````````
M````````````````!`D`````````````````````````````.@D``#L)````
M````````````````````3@D``$\)````````````````````````50D``%<)
M````````````````````````<0D``(`)````````````````````````A`D`
M````````````````````````````C0D``(X)````````````````````````
MD0D``)()````````````````````````J0D`````````````````````````
M````L0D`````````````````````````````LPD``+4)````````````````
M````````N@D``+L)````````````````````````O0D`````````````````
M````````````Q0D``,8)````````````````````````R0D``,H)````````
M````````````````S@D``-8)````````````````````````V`D``-L)````
M````````````````````W@D`````````````````````````````Y`D``.4)
M````````````````````````^PD```$*`````````````````````````PH`
M``0*````````````````````````"PH```X*````````````````````````
M$0H``!(*````````````````````````*0H`````````````````````````
M````,0H`````````````````````````````-`H`````````````````````
M````````-PH`````````````````````````````.@H``#L*````````````
M````````````/0H`````````````````````````````0PH``$8*````````
M````````````````20H``$H*````````````````````````3@H``%@*````
M````````````````````70H`````````````````````````````7PH``&4*
M````````````````````````=0H``(`*````````````````````````A`H`
M````````````````````````````C`H`````````````````````````````
MC@H`````````````````````````````D@H`````````````````````````
M````J0H`````````````````````````````L0H`````````````````````
M````````M`H`````````````````````````````N@H``+L*````````````
M````````````Q@H`````````````````````````````R@H`````````````
M````````````````S@H``,\*````````````````````````T0H``-\*````
M````````````````````X0H``.4*````````````````````````\`H````+
M````````````````````````!`L`````````````````````````````#0L`
M``X+````````````````````````$0L``!(+````````````````````````
M*0L`````````````````````````````,0L`````````````````````````
M````-`L``#4+````````````````````````.@L``#L+````````````````
M````````1`L``$8+````````````````````````20L``$H+````````````
M````````````3@L``%4+````````````````````````6`L``%L+````````
M````````````````7@L`````````````````````````````8@L``&4+````
M````````````````````<0L``($+````````````````````````A`L`````
M````````````````````````BPL``(T+````````````````````````D0L`
M````````````````````````````E@L``)@+````````````````````````
MFPL`````````````````````````````G0L`````````````````````````
M````H`L``*(+````````````````````````I0L``*<+````````````````
M````````JPL``*T+````````````````````````M@L`````````````````
M````````````N@L``+T+````````````````````````PPL``,4+````````
M````````````````R0L`````````````````````````````S@L``-8+````
M````````````````````V`L``.8+````````````````````````\PL````,
M````````````````````````!`P`````````````````````````````#0P`
M````````````````````````````$0P`````````````````````````````
M*0P`````````````````````````````-`P`````````````````````````
M````.@P``#T,````````````````````````10P`````````````````````
M````````20P`````````````````````````````3@P``%0,````````````
M````````````5PP``%\,````````````````````````8@P``&4,````````
M````````````````<`P``($,````````````````````````A`P`````````
M````````````````````C0P`````````````````````````````D0P`````
M````````````````````````J0P`````````````````````````````M`P`
M````````````````````````````N@P``+T,````````````````````````
MQ0P`````````````````````````````R0P`````````````````````````
M````S@P``-0,````````````````````````UPP``-T,````````````````
M````````WPP`````````````````````````````X@P``.4,````````````
M````````````\`P```$-````````````````````````!`T`````````````
M````````````````#0T`````````````````````````````$0T`````````
M````````````````````*0T`````````````````````````````.@T``#T-
M````````````````````````1`T``$4-````````````````````````20T`
M````````````````````````````3@T``%8-````````````````````````
M6`T``%\-````````````````````````8@T``&4-````````````````````
M````<`T``($-````````````````````````A`T`````````````````````
M````````EPT``)D-````````````````````````L@T`````````````````
M````````````O`T`````````````````````````````O@T``+\-````````
M````````````````QPT``,D-````````````````````````RPT``,X-````
M````````````````````U0T`````````````````````````````UPT`````
M````````````````````````X`T``/$-````````````````````````]0T`
M```.````````````````````````.PX``#X.````````````````````````
M7`X``(`.````````````````````````@PX`````````````````````````
M````A0X``(8.````````````````````````B0X`````````````````````
M````````BPX``(P.````````````````````````C@X``),.````````````
M````````````F`X`````````````````````````````H`X`````````````
M````````````````I`X`````````````````````````````I@X`````````
M````````````````````J`X``*D.````````````````````````K`X`````
M````````````````````````N@X`````````````````````````````O@X`
M`+\.````````````````````````Q0X`````````````````````````````
MQPX`````````````````````````````S@X``,\.````````````````````
M````V@X``-L.````````````````````````W@X``/\.````````````````
M````````2`\`````````````````````````````:P\``'`/````````````
M````````````C`\``(\/````````````````````````F`\`````````````
M````````````````O0\`````````````````````````````S0\``,X/````
M````````````````````T`\``/\/````````````````````````(A``````
M````````````````````````*!``````````````````````````````*Q``
M````````````````````````````,Q```#40````````````````````````
M.A```#\0````````````````````````6A```)\0````````````````````
M````QA```,\0````````````````````````^1```/H0````````````````
M````````_!```/\0````````````````````````6A$``%X1````````````
M````````````HQ$``*<1````````````````````````^A$``/\1````````
M````````````````!Q(`````````````````````````````1Q(`````````
M````````````````````21(`````````````````````````````3A(``$\2
M````````````````````````5Q(`````````````````````````````61(`
M````````````````````````````7A(``%\2````````````````````````
MAQ(`````````````````````````````B1(`````````````````````````
M````CA(``(\2````````````````````````KQ(`````````````````````
M````````L1(`````````````````````````````MA(``+<2````````````
M````````````OQ(`````````````````````````````P1(`````````````
M````````````````QA(``,<2````````````````````````SQ(`````````
M````````````````````UQ(`````````````````````````````[Q(`````
M````````````````````````#Q,`````````````````````````````$1,`
M````````````````````````````%A,``!<3````````````````````````
M'Q,`````````````````````````````1Q,`````````````````````````
M````6Q,``&`3````````````````````````?1,``)\3````````````````
M````````]1,````4````````````````````````=Q8``'\6````````````
M````````````G18``)\6````````````````````````\18``/\6````````
M````````````````#1<`````````````````````````````%1<``!\7````
M````````````````````-Q<``#\7````````````````````````5!<``%\7
M````````````````````````;1<`````````````````````````````<1<`
M````````````````````````````=!<``'\7````````````````````````
MW1<``-\7````````````````````````ZA<``/\7````````````````````
M````#Q@`````````````````````````````&A@``!\8````````````````
M````````>!@``'\8````````````````````````JA@``/\=````````````
M````````````G!X``)\>````````````````````````^AX``/\>````````
M````````````````%A\``!<?````````````````````````'A\``!\?````
M````````````````````1A\``$<?````````````````````````3A\``$\?
M````````````````````````6!\`````````````````````````````6A\`
M````````````````````````````7!\`````````````````````````````
M7A\`````````````````````````````?A\``'\?````````````````````
M````M1\`````````````````````````````Q1\`````````````````````
M````````U!\``-4?````````````````````````W!\`````````````````
M````````````\!\``/$?````````````````````````]1\`````````````
M````````````````_Q\`````````````````````````````4R```%8@````
M````````````````````6"```%X@````````````````````````9"```&D@
M````````````````````````<B```',@````````````````````````CR``
M`)\@````````````````````````LB```,\@````````````````````````
MZR```/\@````````````````````````.R$``#PA````````````````````
M````3"$``%(A````````````````````````A"$``(\A````````````````
M````````SR,``/\C````````````````````````)R0``#\D````````````
M````````````2R0``%\D````````````````````````_R0`````````````
M````````````````%"8``!4F````````````````````````&"8`````````
M````````````````````?B8``'\F````````````````````````BB8````G
M````````````````````````!2<`````````````````````````````"B<`
M``LG````````````````````````*"<`````````````````````````````
M3"<`````````````````````````````3B<`````````````````````````
M````4R<``%4G````````````````````````5R<`````````````````````
M````````7R<``&`G````````````````````````E2<``)<G````````````
M````````````L"<`````````````````````````````OR<``,\G````````
M````````````````["<``.\G`````````````````````````"L``'\N````
M````````````````````FBX`````````````````````````````]"X``/\N
M````````````````````````UB\``.\O````````````````````````_"\`
M`/\O````````````````````````0#``````````````````````````````
MES```)@P`````````````````````````#$```0Q````````````````````
M````+3$``#`Q````````````````````````CS$`````````````````````
M````````N#$``.\Q````````````````````````'3(``!\R````````````
M````````````1#(``%`R````````````````````````?#(``'XR````````
M````````````````S#(``,\R````````````````````````_S(`````````
M````````````````````=S,``'HS````````````````````````WC,``-\S
M````````````````````````_S,`````````````````````````````MDT`
M`/]-````````````````````````II\``/^?````````````````````````
MC:0``(^D````````````````````````QZ0``/^K````````````````````
M````I-<``/_7````````````````````````+OH``"_Z````````````````
M````````:_H``/_Z````````````````````````!_L``!+[````````````
M````````````&/L``!S[````````````````````````-_L`````````````
M````````````````/?L`````````````````````````````/_L`````````
M````````````````````0OL`````````````````````````````1?L`````
M````````````````````````LOL``-+[````````````````````````0/T`
M`$_]````````````````````````D/T``)']````````````````````````
MR/T``,_]````````````````````````_?T``/_]````````````````````
M````$/X``!_^````````````````````````)/X``"_^````````````````
M````````1_X``$C^````````````````````````4_X`````````````````
M````````````9_X`````````````````````````````;/X``&_^````````
M````````````````=?X`````````````````````````````_?X``/[^````
M`````````````````````/\`````````````````````````````O_\``,'_
M````````````````````````R/\``,G_````````````````````````T/\`
M`-'_````````````````````````V/\``-G_````````````````````````
MW?\``-__````````````````````````Y_\`````````````````````````
M````[_\``/C_```````````````````````````!`/\"`0``````````````
M````````'P,!````````````````````````````)`,!`"\#`0``````````
M````````````2P,!`/\#`0``````````````````````)@0!`"<$`0``````
M````````````````3@0!`/_/`0``````````````````````]M`!`/_0`0``
M````````````````````)]$!`"G1`0``````````````````````WM$!`/_3
M`0``````````````````````5=0!````````````````````````````G=0!
M````````````````````````````H-0!`*'4`0``````````````````````
MH]0!`*34`0``````````````````````I]0!`*C4`0``````````````````
M````K=0!````````````````````````````NM0!````````````````````
M````````O-0!````````````````````````````P=0!````````````````
M````````````Q-0!````````````````````````````!M4!````````````
M````````````````"]4!``S5`0``````````````````````%=4!````````
M````````````````````'=4!````````````````````````````.M4!````
M````````````````````````/]4!````````````````````````````1=4!
M````````````````````````````1]4!`$G5`0``````````````````````
M4=4!````````````````````````````I-8!`*?6`0``````````````````
M````RM<!`,W7`0```````````````````````-@!`/W_`0``````````````
M````````UZ8"`/_W`@``````````````````````'OH"`/W_`@``````````
M```````````````#`/W_`P`````````````````````````$`/W_!```````
M```````````````````%`/W_!0`````````````````````````&`/W_!@``
M```````````````````````'`/W_!P`````````````````````````(`/W_
M"``````````````````````````)`/W_"0`````````````````````````*
M`/W_"@`````````````````````````+`/W_"P``````````````````````
M```,`/W_#``````````````````````````-`/W_#0``````````````````
M```````.`````````````````````````````@`.`!\`#@``````````````
M````````@``.`/W_#@``````````````````````````````````````````
M``````````````````````!#4#@U-@!#4#DR,@!#4#DT,P!#4#$P-#8`0U`Q
M,3(T`$-0,3$R.0!#4#$Q-C$`24)-,3$V,0!)0DTM,3$V,0!#4TE"33$Q-C$`
M0U`Q,38R`$E"33$Q-C(`24)-+3$Q-C(`0U-)0DTQ,38R`$-0,3$V,P!)0DTQ
M,38S`$E"32TQ,38S`$-324)-,3$V,P!$14,M2T%.2DD`1$5#+4A!3EE5`$-0
M-#,W`$E"330S-P`T,S<`0U-00SA#3T1%4$%'130S-P!#4#<S-P!#4#<W-0!)
M0DTW-S4`0U-00S<W-4)!3%1)0P!#4#@U,@!)0DTX-3(`.#4R`$-34$-0.#4R
M`$-0.#4S`$-0.#4U`$E"33@U-0`X-34`0U-)0DTX-34`0U`X-3<`24)-.#4W
M`#@U-P!#4TE"33@U-P!#4#@U.`!#4#@V,`!)0DTX-C``.#8P`$-324)-.#8P
M`$-0.#8Q`$E"33@V,0`X-C$`0U`M25,`0U-)0DTX-C$`0U`X-C,`24)-.#8S
M`#@V,P!#4TE"33@V,P!#4#@V-`!)0DTX-C0`0U-)0DTX-C0`0U`X-C4`24)-
M.#8U`#@V-0!#4TE"33@V-0!#4#@V.0!)0DTX-CD`.#8Y`$-0+4=2`$-324)-
M.#8Y`$-0,3$R-0!%54,M2DE36#`R,3,`4TA)1E1?2DE36#`R,3,`25-/+3(P
M,C(M2E`M,P!41%,U-C4`25-/+4E2+3(S,`!225-#3U,M3$%424XQ````````
M````````````````9@````8```!G````#````&@````2````:0```!D```!J
M````(````&L````G````;````"X```!L````-@```&P````_````;````$D`
M``!M````4````&T```!8````;0```&$```!M````:P```&X```!R````;@``
M`'H```!N````@P```&X```"-````;P```)<```!P````H0```'$```"G````
M<0```*X```!Q````L@```'$```##````<@```,D```!S````SP```',```#6
M````<P```.0```!T````Z@```'0```#Q````=````/4```!T````_@```'4`
M```$`0``=@````H!``!V````$0$``'8````5`0``=@```!X!``!W````)`$`
M`'<````K`0``=P```"\!``!W````.`$``'@````^`0``>0```$0!``!Y````
M2P$``'D```!/`0``>0```%@!``!Z````7@$``'H```!E`0``>@```&D!``!Z
M````;P$``'H```!X`0``>P```'X!``![````A0$``'L```")`0``>P```)(!
M``!\````F`$``'P```"?`0``?````*@!``!]````K@$``'T```"U`0``?0``
M`+D!``!]````P@$``'X```#(`0``?@```,\!``!^````TP$``'X```#9`0``
M?@```.(!``!_````Z0$``(````#V`0``@0````4"``""````$P(``(,````:
M`@``@P```"4"``"$`````````````````````````$-.`$PQ`$PR`$PV`$PU
M`$PX`#@V,@!,,P`X-C8`0SDY`$550T-.`$-0,3(U,0!#4#$R-3(`0U`X-C(`
M155#+4-.`$-0,3(U-@!#4#@V-@!#4#$R-34`2%H`0U`Q,S8Q`$-0.3,R`$-0
M.#$Y`$-0.3,V`%@P,C$R`$-0,3(U.`!,-P!#4#$R-3,`3#0`0U`Q,3,S`%(X
M`$-(24Y%4T4`25-/.#@U.2TQ`$E33S@X-3DM,@!)4T\X.#4Y+38`25-/+3@X
M-3DM,0!)4T\X.#4Y+34`25-/+3@X-3DM,@!8,#(P,0!)4T\X.#4Y+3$V`$E3
M3RTX.#4Y+38`25-/.#@U.2TQ-0!)4T\M.#@U.2TU`$E33S@X-3DM.0!)4T\X
M.#4Y+3@`25-/+3@X-3DM,38`.#4P`$E33RTX.#4Y+3$U`$E33RTX.#4Y+3D`
M0U`Y-#D`25-/+3@X-3DM.`!)4T\X.#4Y+3,`25-/+4E2+38`6#`R,#@`0UE2
M24Q,24,`25-/+3(P,C(M0TX`25-/.#@U.2TQ,P!)4T\M.#@U.2TS`$-0,3(U
M,`!#4#DU,`!#4#@U,`!)4T\V-#8M0TX`4TI)4P!)4T\M.#@U.2TQ,P!)4T\M
M25(M,3(V`$E33RU)4BTR,C8`25-/+4E2+3$V-@!)4T\M25(M,38U`$-0,3(U
M-P!!4T-)20!)4T\M25(M-3@`0U`S-C<`3$%424XQ`$E33RU)4BTQ-3D`3$%4
M24XR`$E33RU)4BTQ.3D`3$%424XV`$Q!5$E.-0!)4T]?.#@U.2TQ`$-325-/
M,C`R,D-.`$E33U\X.#4Y+3(`25-/+4E2+3$S.`!#4#$R-30`25-/7S@X-3DM
M-@!)4T]?.#@U.2TU`$Q!5$E..`!)4T\M25(M,3`Q`$E33U\X.#4Y+3$V`$="
M,C,Q,@!)4T]?.#@U.2TQ-0!)4T\M0T5,5$E#`$E33U\X.#4Y+3D`3$%424XS
M`$E33U\X.#4Y+3@`54A#`$E33S@X-3DM,3``25-/7S@X-3DM,34Z,3DY.`!-
M04,`25-/7S@X-3DM,P!)4T\M25(M,3`Y`$E33S@X-3DM-P!)4T\M.#@U.2TQ
M,`!#4T%30TE)`$E33U\X.#4Y+3$S`$E33RU)4BTQ-SD`25-/+3@X-3DM-P!)
M4T\M25(M,C`S`$E33RU)4BTQ-#D`35,M144`25-/+4E2+3$T.`!54P!#4#@W
M-`!)4T\X.#4Y+30`25-/+4E2+3$Q,`!)4T]?.#@U.2TQ,#HQ.3DR`$E33U\X
M.#4Y+3$V.C(P,#``25-/.#@U.2TQ-`!)4T\M.#@U.2TT`$E"33@V,@!)4T\M
M25(M-3<`24)-.#8V`$E33RTX.#4Y+3$T`$E33RU)4BTQ,C<`25-/+3(P,C(M
M0TXM15A4`$E33RU)4BTX-P!)4T\M25(M,34W`%5#4RTR`$E"33@Q.0!)4T]?
M.#@U.2TQ-#HQ.3DX`$E33RU)4BTQ-`!%3$]47SDR.`!,051)3C<`551&+3$V
M`$E33U\X.#4Y+3$P`$-354Y)0T]$10!50U,M,DQ%`%541BTX`$E33RU)4BTQ
M,#``25-/7S@X-3DM-P!55$8M,S(`0TA!4@!53DE#3T1%+3$M,0!#4U5.24-/
M1$4Q,0!425,V,C``155#2U(`551&+3$V3$4`3$%424XT`$M30U\U-C`Q`%1)
M4RTV,C``155#+4M2`$E"32U#4#$Q,S,`25-/7S@X-3DM-`!55$8M,S),10!6
M25-#24D`2T])."U2`$E33U\X.#4Y+3$T`$-32T]).%(`1U)%14LX`$U3+4-9
M4DP`0U-625-#24D`24)-.#4P`$E33RU)4BTQ-#0`0DE'-0!50U,M-$Q%`$="
M,3@P,S``34%#0UE224Q,24,`0U-53DE#3T1%,3%55$8W`%5.24-/1$4M,2TQ
M+5541BTW`$))1RTU`$E"33,V-P!425,V,C`M,`!#4T))1S4`3D585%-415``
M0U-+4T,U-C`Q,3DX-P!#4TE33TQ!5$E.,0!+3U)%04X`0U-)4T],051)3C(`
M0TXM0DE'-0!55$8M-P!#4TE33TQ!5$E.-@!#4TE33TQ!5$E.0UE224Q,24,`
M0U-)4T],051)3C4`5$-63@!425,V,C`N,C4R.2TQ`$-31T(R,S$R`$E33RTQ
M,#8T-BU50U,M,@!50U,M-`!-54Q%3$%/+3$`25-/+3(P,C(M2U(`14--02TQ
M,3@`1T)?,C,Q,BTX,`!#4U5#4S0`1T)+`$-325-/3$%424XS`$E33S8T-BU5
M4P!54RU!4T-)20!425,V,C`N,C4S,RTQ`$M/23@M5`!-4RU!3E-)`$M37T-?
M-38P,2TQ.3@Y`$="7S$Y.#@M.#``155#5%<`1U)%14L`155#+517`%=)3D1/
M5U,M,3(U,0!724Y$3U=3+3$R-3(`2E``5TE.1$]74RTQ,C4V`%=)3D1/5U,M
M,3(U-0!625-#24DQ+C$M,0!#4TE33S(P,C)+4@!724Y$3U=3+3$R-3@`5TE.
M1$]74RTQ,C4S`$%235-#24DM.`!#4TE"33@V-@!23TU!3C@`2%HM1T(M,C,Q
M,@!%54-*4`!425,V,C`N,C4S,RTP`$M37T-?-38P,2TQ.3@W`$U!0TE#14Q!
M3D0`25-/+3$P-C0V+55#4RTT`%5#4RTR0D4`155#+4I0`%=)3D1/5U,M,3(U
M,`!!4D%"24,`551&+3$V0D4`5$-63BTU-S$R`%=)3D1/5U,M,3(U-P!#4U!#
M.#8R3$%424Y(14)215<`5$-63C4W,3(M,0!55$8M,S)"10!724Y$3U=3+3$R
M-30`0U-%54-+4@!!4TU/+3<P.`!#4TE33TQ!5$E.05)!0DE#`$U!0TE.5$]3
M2`!50U,M,BU)3E1%4DY!3`!#4TE33TQ!5$E.-`!%0TU!+3$Q-`!#3BU'0BU)
M4T])4C$V-0!!3E-)7U@S+C0M,3DX-@!#4TE33S4W1T(Q.3@X`$-325-/-3A'
M0C(S,3(X,`!(4"U23TU!3C@`04Y325]8,RXT+3$Y-C@`34%#5$A!20!50U,M
M-$)%`$-32%!23TU!3C@`0TXM1T(`54Y)0T]$14Q)5%1,10!)4T]?.#@U.2TU
M.C$Y.#@`25-/7S@X-3DM.3HQ.3@Y`$E33U\X.#4Y+3@Z,3DX.`!+3TDX+54`
M25-/7S@X-3DM,SHQ.3@X`$E33RTR,#(R+4I0`$E33RTR,#(R+4I0+3$`25-/
M+3(P,C(M2E`M,@!#4TE33TQ!5$E.2$5"4D57`$E33S8T-BU*4`!%6%1%3D1%
M1%]53DE87T-/1$5?4$%#2T5$7T9/4DU!5%]&3U)?2D%004Y%4T4`54-3+30M
M24Y415).04P`25-/7S@X-3DM,3HQ.3@W`$E33U\X.#4Y+3(Z,3DX-P!)4T]?
M.#@U.2TV.C$Y.#<`0U-)4T\R,#(R2E``0U-)4T\R,#(R2E`R`$E33U\X.#4Y
M+30Z,3DX.`!-04-#14Y44D%,15523U!%`$A%0E)%5P!-4RU(14)2`$E33U\V
M-#8N25)6.C$Y.3$`0U-%54-45P!+3TDX+5)5`%=)3D1/5U,M.#<T`$I)4S`R
M,#@`1T5/4D=)04XM4%,`25-/7S@X-3DM-SHQ.3@W`$-325-/3$%424Y'4D5%
M2P!*25-?0S8R,C8M,3DX,P!-04-23TU!3@!50U,M,BU35T%04$5$`$-334%#
M24Y43U-(`$))1T9)5D4`0U-)4T\Q-3E*25-8,#(Q,C$Y.3``0U-)4T\Q-$I)
M4T,V,C(P4D\`0U-00S@U,$U53%1)3$E.1U5!3`!"24<M1DE610!*25-?0S8R
M,C`M,3DV.2U23P!*25-?6#`R,3(`0DE'-4A+4T-3`$I)4U@P,C`Q+3$Y-S8`
M1T5/4D=)04XM04-!1$5-60!"24<U+4A+4T-3`$-325-/.#=*25-8,#(P.`!-
M04-'4D5%2P!-4RU'4D5%2P!50U,M-"U35T%04$5$`$U!0T-23T%424%.`$I)
M4U]8,#(P,0!70TA!4E]4`%5.24-/1$5"24<`2DE37U@P,C$R+3$Y.3``2DE3
M7U@P,C`X`$U!0T%204))0P!#4TA!3$9724142$M!5$%+04Y!`$I)4U]8,#(P
M."TQ.3@S`%-(2494+4I)4P!-04-52U)!24Y%`$-3155#4$M$1DU42D%004Y%
M4T4`2DE37U@P,C`X+3$Y.3``0U-32$E&5$I)4P!*25-?6#`R,3(N,3DY,"TP
M`$U!0TA%0E)%5P!32$E&5%]*25,`5$-63C4W,3(M,3HQ.3DS`$U3+5154DL`
M34%#5%522TE32`!-04-23TU!3DE!`$U3+4%204(`2D%600!-4U]+04Y*20!*
M3TA!0@!724Y"04Q44DE-``````````````````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P``````````3@```/____\``````P```!4````&````%@``
M`/____\`````"0```!X````,````'0```/____\`````_____P````#_____
M`````/____\`````#P```"````#_____`````/____\`````$@```#`````6
M````%P```/____\`````_____P`````9````,0```!T````3````_____P``
M``#_____`````/____\`````(0```%@```#_____`````/____\`````)P``
M`"<```#_____`````"X````H````-0```#`````[````6````/____\`````
M0@```"P```!)````,0```$\````K````5@```%T```#_____`````%D```!D
M````8````%0```#_____`````&8````5````_____P````!L````60```'(`
M``!-````>````"X```#_____`````/____\`````?P```!\```#_____````
M`/____\`````_____P````#_____`````((````I````_____P````#_____
M`````/____\`````_____P````")````&````/____\`````_____P````",
M````10```/____\`````DP```#X```#_____`````/____\`````_____P``
M``#_____`````/____\`````_____P````"6````3P```)X````5````____
M_P````"H````%@```/____\`````_____P````#_____`````+(````:````
MO````!4```#'````&0```-$````6````W````$L```#_____`````.(````B
M````[0```!H```#X````(0````,!```9````#@$``!T```#_____`````!@!
M```<````(@$``"(````N`0``+P```#(!```A````_____P`````^`0``'0``
M`$D!``!C````3P$``!P```!:`0``%P```&0!````````;0$``$P```!S`0``
M&0```/____\`````?`$``%L```"(`0``'P```),!```7````G@$``"8```"E
M`0``8````*L!```O````L0$``$X```"[`0``4P```,`!```?````S`$``!L`
M``#7`0``(@```.(!``!&````_____P````#M`0``4````/____\`````^`$`
M`"T```#_`0```````/____\`````!0(``$\```#_____``````\"````````
M%0(``!4````<`@``30```"<"```6````_____P````#_____`````"X"```@
M````.0(``!X```#_____`````$`"```=````1P(``!4```!2`@``6P```%X"
M```6````:0(``!P```#_____`````'0"```J````>P(``!H```#_____````
M`(8"```9````D0(``"````#_____`````)@"```6````HP(``"(```"O`@``
M6````+8"```A````P@(``"````#-`@``'0```-@"```7````WP(``!P```#J
M`@``8P```/____\`````_____P````#_____`````.X"```>````^0(``"$`
M```*`P``,@````X#```7````&0,``!<```#_____`````"0#```;````+@,`
M`!X````Z`P```````$(#```?````3@,``!\```#_____`````/____\`````
M60,``!L```#_____`````&0#```A````_____P````#_____`````/____\`
M````_____P````!O`P``8@```'H#```F````@`,``!T```"+`P```````/__
M__\`````C@,``$<```"4`P``&````)X#```8````J0,``!X```#_____````
M`+H#```B````_____P````#+`P``(````-8#```8````X0,``#````#_____
M`````/____\`````Z`,``$X```#R`P``,0```/D#```@````!00``!H````0
M!```7````"`$``!,````*@0``!X````U!````@```#L$```5````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````0@0`
M`"````!3!```2@```/____\`````_____P````!=!```&P```/____\`````
M9@0``!\```!M!```"````/____\`````=`0``!X```#_____`````(`$```"
M````B@0```0```"2!````0```)@$```5````HP0``!L```"N!```"P```+4$
M``"%````_____P````#_____`````+H$```#````Q@0```,```#_____````
M`-($``!&````V00``&(```#?!```"@```.@$```8````_____P````#_____
M`````.\$``!B````^`0``$8`````!0``8@```/____\`````!P4``$4```#_
M____`````!(%```8````'04```T````F!0``2````"T%```C````_____P``
M``#_____`````#0%```@````_____P````!`!0``(P```/____\`````2`4`
M`!L```!/!0``)P```/____\`````_____P````!7!0``2````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````&`%```O````_____P````#_____`````&<%
M```9````_____P````#_____`````'(%``!?````=P4```<```!_!0``6@``
M`/____\`````AP4``#<```"3!0``#@```*,%```.````M04``%\```#_____
M`````+L%````````P@4``$8```#_____`````,L%``!?````T@4``#\```#_
M____`````-L%``!B````Z04``!4```#U!0``8@```/P%```6````"`8``%\`
M```0!@``#@```/____\`````%@8``!X````B!@``&0```#4&```=````____
M_P````!!!@``20```/____\`````_____P````!&!@``1@```/____\`````
M_____P````!4!@``6````/____\`````708```(```!M!@``!0```',&``!$
M````?08``&4```")!@``&P```)(&``!/````G08```4```"D!@``60```*@&
M```7````M`8```````#_____`````+X&````````QP8``$8```#5!@``0P``
M`-P&```H````Y`8``&(```#S!@``3@```/____\`````_____P````#^!@``
M7@```/____\`````_____P````#_____``````0'```;````_____P````#_
M____``````H'``!>````$0<``"<````>!P``*````"L'``!*````+@<``"P`
M```[!P``*P```/____\`````2`<``$@```!4!P``90```/____\`````8`<`
M`"X```#_____`````/____\`````_____P````!M!P``*0```'H'``!`````
M_____P````#_____`````/____\`````_____P````"$!P``,0```/____\`
M````C0<``#X```"4!P``70```)\'``!2````I0<``$8```"S!P``8@```,('
M```T````S0<```4```#=!P```P```/____\`````Y0<``%(```#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````[`<``"8```#Y!P``&@`````(```)````_____P````#_
M____``````D(``!)````$P@``"T```#_____`````"`(```P````_____P``
M```S"```20```/____\`````_____P`````^"```#````/____\`````____
M_P````!'"```*@```/____\`````5`@``&(```#_____`````%P(```:````
M_____P````#_____`````&4(```:````=@@``#(```"`"```#P```(\(```8
M````_____P````#_____`````/____\`````FP@``!H```#_____`````*0(
M``!0````_____P````"S"````````,((``!.````_____P````#0"```3P``
M`.`(```^````_____P````#J"````````/D(```]````_____P`````!"0``
M!@````D)```^````_____P`````4"0``6````/____\`````&@D```0````H
M"0``&0```/____\`````_____P`````X"0``'0```/____\`````2`D``!P`
M``!8"0``)````/____\`````_____P````!?"0``%P```/____\`````____
M_P````#_____`````&\)``!5````>PD``%8```")"0``5P```)<)```<````
M_____P````#_____`````*@)``!*````_____P````#_____`````+()``!2
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#@"0``$0```/____\`````[PD``!4```#_"0``%@``
M`/____\`````#PH``!H```#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````'PH``%4````K
M"@``5P```/____\`````_____P````#_____`````/____\`````_____P``
M```X"@``&````/____\`````_____P````!("@``,P```/____\`````____
M_P````!9"@``'````/____\`````8`H``"L```#_____`````&@*````````
M_____P````!Y"@``7@```/____\`````_____P````#_____`````/____\`
M````@0H``"4```#_____`````(D*``!'````_____P````#_____`````)4*
M``!,````G0H``$(```#_____`````/____\`````J0H``!L```#_____````
M`+D*```;````R0H``$P```#_____`````/____\`````V`H``#(```#A"@``
M$````/____\`````_____P````#_____`````/____\`````[PH``#(```#_
M____`````/____\`````^PH``%\````#"P``30```!@+``!*````*@L``"\`
M``#_____`````/____\`````_____P`````^"P``7P```/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````$<+``!*````
M_____P````#_____`````/____\`````60L``$T```#_____`````/____\`
M````_____P````!C"P``80```/____\`````_____P````#_____`````&T+
M``!+````>PL``$$```#_____`````(P+``!A````_____P````#_____````
M`/____\`````EPL``$P```#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````"G
M"P``.0```+`+```I````_____P````"Y"P``$@```/____\`````_____P``
M``#_____`````/____\`````QPL``#4```#_____`````/____\`````____
M_P````#3"P``2P```/____\`````_____P````#="P``A@```/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#E"P```P```/____\`````_____P````#_____`````/__
M__\`````\`L``$T```#_"P``3````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````"0P``#P```#_
M____`````/____\`````_____P````#_____`````!,,``!+````)PP``$P`
M```V#```4P```/____\`````_____P````#_____`````/____\`````0`P`
M`#@```#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````2PP``%(```#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````%\,``!,````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````_____P````!N#```4P```'D,``!-````B@P``#L`
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````"4#```4P```/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````)X,``!)````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`*X,```J````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````_____P````#_____`````/____\`````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````"V#```.@```/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````P0P``#8```#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````#,
M#```+````/____\`````_____P````#4#```%````/____\`````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````_____P````#9#```4P```.(,``!D````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````_____P````#_____`````/____\`````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#H#```
M+0````$````@`````0```"$````!````8P````(```!L````8@````,```!Y
M````90```&X````!````?`````(```!3````4P````$````B`````P```"@`
M``!C````*0````$```!A`````@```#P````\`````P```&X```!O````=```
M``$````M`````P```"@```!2````*0````(```!>````,`````,````K````
M+P```"T````"````7@```#(````"````7@```#,````!````)P````$```!U
M`````0```%`````!````+@````$````L`````@```%X````Q`````0```&\`
M```"````/@```#X````%````(````#$```!$(```-````"`````%````(```
M`#$```!$(```,@```"`````%````(````#,```!$(```-````"`````!````
M/P````(```!@````00````(```"T````00````(```!>````00````(```!^
M````00````(````B````00````$```!!`````@```$$```!%`````0```$,`
M```"````8````$4````"````M````$4````"````7@```$4````"````(@``
M`$4````"````8````$D````"````M````$D````"````7@```$D````"````
M(@```$D````!````1`````(```!^````3@````(```!@````3P````(```"T
M````3P````(```!>````3P````(```!^````3P````(````B````3P````$`
M``!X`````0```$\````"````8````%4````"````M````%4````"````7@``
M`%4````"````(@```%4````"````M````%D````"````5````&@````"````
M<P```',````"````8````&$````"````M````&$````"````7@```&$````"
M````?@```&$````"````(@```&$````!````80````(```!A````90````$`
M``!C`````@```&````!E`````@```+0```!E`````@```%X```!E`````@``
M`"(```!E`````@```&````!I`````@```+0```!I`````@```%X```!I````
M`@```"(```!I`````0```&0````"````?@```&X````"````8````&\````"
M````M````&\````"````7@```&\````"````?@```&\````"````(@```&\`
M```!````.@````$```!O`````@```&````!U`````@```+0```!U`````@``
M`%X```!U`````@```"(```!U`````@```+0```!Y`````@```'0```!H````
M`@```"(```!Y`````0```$$````!````80````$```!!`````0```&$````!
M````00````$```!A`````@```+0```!#`````@```+0```!C`````@```%X`
M``!#`````@```%X```!C`````0```$,````!````8P````$```!#`````0``
M`&,````!````1`````$```!D`````0```$0````!````9`````$```!%````
M`0```&4````!````10````$```!E`````0```$4````!````90````$```!%
M`````0```&4````!````10````$```!E`````@```%X```!'`````@```%X`
M``!G`````0```$<````!````9P````$```!'`````0```&<````!````1P``
M``$```!G`````@```%X```!(`````@```%X```!H`````0```$@````!````
M:`````(```!^````20````(```!^````:0````$```!)`````0```&D````!
M````20````$```!I`````0```$D````!````:0````$```!)`````0```&D`
M```"````20```$H````"````:0```&H````"````7@```$H````"````7@``
M`&H````!````2P````$```!K`````0```$P````!````;`````$```!,````
M`0```&P````!````3`````$```!L`````0```$P````!````;`````$```!,
M`````0```&P````"````M````$X````"````M````&X````!````3@````$`
M``!N`````0```$X````!````;@````(````G````;@````$```!/`````0``
M`&\````!````3P````$```!O`````@```"(```!/`````@```"(```!O````
M`@```$\```!%`````@```&\```!E`````@```+0```!2`````@```+0```!R
M`````0```%(````!````<@````$```!2`````0```'(````"````M````%,`
M```"````M````',````"````7@```%,````"````7@```',````!````4P``
M``$```!S`````0```%,````!````<P````$```!4`````0```'0````!````
M5`````$```!T`````0```%0````!````=`````(```!^````50````(```!^
M````=0````$```!5`````0```'4````!````50````$```!U`````0```%4`
M```!````=0````(````B````50````(````B````=0````$```!5`````0``
M`'4````"````7@```%<````"````7@```'<````"````7@```%D````"````
M7@```'D````"````(@```%D````"````M````%H````"````M````'H````!
M````6@````$```!Z`````0```%H````!````>@````$```!S`````0```&8`
M```"````1````'T!```"````1````'X!```"````9````'X!```"````3```
M`$H````"````3````&H````"````;````&H````"````3@```$H````"````
M3@```&H````"````;@```&H````"````1````%H````"````1````'H````"
M````9````'H````!````4P````$```!S`````0```%0````!````=`````$`
M```R(````0```#,@```!````&"````$````9(````0```!L@```!````7@``
M``$````G`````0```*\````!````M`````$```!@`````0```%\````!````
M?@````$````B`````0```+(#```!````N`,```$```"E`P```0```,8#```!
M````P`,```$```"Z`P```0```,$#```!````P@,```$```"8`P```0```+4#
M```!````HP,```(```!E!0``@@4```(```#5!0``U04```(```#5!0``V04`
M``(```#9!0``V04```(````G!@``=`8```(```!(!@``=`8```(```#'!@``
M=`8```(```!*!@``=`8```(```!-#@``,@X```(```#-#@``L@X```(```"K
M#@``F0X```(```"K#@``H0X```(```"R#P``@0\```(```"S#P``@0\```$`
M``!"`````0```&(````!````1`````$```!D`````0```$8````!````9@``
M``$```!-`````0```&T````!````4`````$```!P`````0```%,````!````
M<P````$```!4`````0```'0````"````8````%<````"````8````'<````"
M````M````%<````"````M````'<````"````(@```%<````"````(@```'<`
M```"````80```+X"```"````8````%D````"````8````'D````!````(```
M``$````@`````0```"`````!````(`````$````@`````0```"`````!````
M(`````$````@`````0```"T````!````+0````$````M`````0```"T````!
M````+0````$````M`````0```"<````!````)P````$````L`````0```"<`
M```!````(@````$````B`````0```"(````!````(@````$````K`````0``
M`&\````!````+@````(````N````+@````,````N````+@```"X````$````
M;P```"\```!O````;P````$```"T`````@```+0```"T`````P```+0```"T
M````M`````(````U(```-2````,````U(```-2```#4@```!````/`````$`
M```^`````@```"$````A`````0```"\````"````/P```#\````"````/P``
M`"$````"````(0```#\````$````M````+0```"T````M`````(```!2````
M<P````0````0`0``TQX``&X```!G`````P```$4```!5````4@````,```!A
M````+P```&,````#````80```"\```!S`````0```$,````"````L````$,`
M```#````8P```"\```!O`````P```&,````O````=0````$```"0`0```@``
M`+````!&`````0```&<````!````2`````$```!(`````0```$@````!````
M:`````$````G`0```0```$D````!````20````$```!,`````0```&P````!
M````3@````(```!.````;P````$```!0`````0```%$````!````4@````$`
M``!2`````0```%(````#````5````$4```!,`````@```%0```!-`````0``
M`%H````#````3P```&@```!M`````0```%H````!````0@````$```!#````
M`0```&4````!````90````$```!%`````0```$8````!````30````$```!O
M`````0```-`%```!````T04```$```#2!0```0```-,%```!````:0````,`
M``!&````00```%@````!````LP,```$```"3`P```0```*`#```!````$2(`
M``$```!$`````0```&0````!````90````$```!I`````0```&H````%````
M(````#$```!$(```,P```"`````%````(````#(```!$(```,P```"`````%
M````(````#$```!$(```-0```"`````%````(````#(```!$(```-0```"``
M```%````(````#,```!$(```-0```"`````%````(````#0```!$(```-0``
M`"`````%````(````#$```!$(```-@```"`````%````(````#4```!$(```
M-@```"`````%````(````#$```!$(```.````"`````%````(````#,```!$
M(```.````"`````%````(````#4```!$(```.````"`````%````(````#<`
M``!$(```.````"`````#````(````#$```!$(````0```$D````"````20``
M`$D````#````20```$D```!)`````@```$D```!6`````0```%8````"````
M5@```$D````#````5@```$D```!)````!````%8```!)````20```$D````"
M````20```%@````!````6`````(```!8````20````,```!8````20```$D`
M```!````3`````$```!#`````0```$0````!````30````$```!I`````@``
M`&D```!I`````P```&D```!I````:0````(```!I````=@````$```!V````
M`@```'8```!I`````P```'8```!I````:0````0```!V````:0```&D```!I
M`````@```&D```!X`````0```'@````"````>````&D````#````>````&D`
M``!I`````0```&P````!````8P````$```!D`````0```&T````"````/```
M`"T````!````7@````(````M````/@````$```!6`````P```#P````M````
M/@````(````\````/0````(````]````/@````,````\````/0```#X````!
M````+0````$````O`````0```%P````!````*@````$````B(````0```'P`
M```"````*R(``"LB```#````*R(``"LB```K(@```@```"XB```N(@```P``
M`"XB```N(@``+B(```$````Z`````0```'X````"````+P```#T````"````
M/````#T````"````/@```#T````"````/````#P````"````/@```#X````!
M````MP````,````\````/````#P````#````/@```#X````^`````P```+<`
M``"W````MP````4```!;````3@```%4```!,````70````4```!;````4P``
M`$\```!(````70````4```!;````4P```%0```!8````70````4```!;````
M10```%0```!8````70````4```!;````10```$\```!4````70````4```!;
M````10```$X```!1````70````4```!;````00```$,```!+````70````4`
M``!;````0@```$4```!,````70````0```!;````0@```%,```!=````!```
M`%L```!(````5````%T````$````6P```$P```!&````70````0```!;````
M5@```%0```!=````!````%L```!&````1@```%T````$````6P```$,```!2
M````70````0```!;````4P```$\```!=````!````%L```!3````20```%T`
M```%````6P```$0```!,````10```%T````%````6P```$0```!#````,0``
M`%T````%````6P```$0```!#````,@```%T````%````6P```$0```!#````
M,P```%T````%````6P```$0```!#````-````%T````%````6P```$X```!!
M````2P```%T````%````6P```%,```!9````3@```%T````%````6P```$4`
M``!4````0@```%T````%````6P```$,```!!````3@```%T````$````6P``
M`$4```!-````70````4```!;````4P```%4```!"````70````4```!;````
M10```%,```!#````70````0```!;````1@```%,```!=````!````%L```!'
M````4P```%T````$````6P```%(```!3````70````0```!;````50```%,`
M``!=````!````%L```!3````4````%T````%````6P```$0```!%````3```
M`%T````$````6P```$X```!,````70````,````H````,0```"D````#````
M*````#(````I`````P```"@````S````*0````,````H````-````"D````#
M````*````#4````I`````P```"@````V````*0````,````H````-P```"D`
M```#````*````#@````I`````P```"@````Y````*0````0````H````,0``
M`#`````I````!````"@````Q````,0```"D````$````*````#$````R````
M*0````0````H````,0```#,````I````!````"@````Q````-````"D````$
M````*````#$````U````*0````0````H````,0```#8````I````!````"@`
M```Q````-P```"D````$````*````#$````X````*0````0````H````,0``
M`#D````I````!````"@````R````,````"D````#````*````#$````I````
M`P```"@````R````*0````,````H````,P```"D````#````*````#0````I
M`````P```"@````U````*0````,````H````-@```"D````#````*````#<`
M```I`````P```"@````X````*0````,````H````.0```"D````$````*```
M`#$````P````*0````0````H````,0```#$````I````!````"@````Q````
M,@```"D````$````*````#$````S````*0````0````H````,0```#0````I
M````!````"@````Q````-0```"D````$````*````#$````V````*0````0`
M```H````,0```#<````I````!````"@````Q````.````"D````$````*```
M`#$````Y````*0````0````H````,@```#`````I`````@```#$````N````
M`@```#(````N`````@```#,````N`````@```#0````N`````@```#4````N
M`````@```#8````N`````@```#<````N`````@```#@````N`````@```#D`
M```N`````P```#$````P````+@````,````Q````,0```"X````#````,0``
M`#(````N`````P```#$````S````+@````,````Q````-````"X````#````
M,0```#4````N`````P```#$````V````+@````,````Q````-P```"X````#
M````,0```#@````N`````P```#$````Y````+@````,````R````,````"X`
M```#````*````&$````I`````P```"@```!B````*0````,````H````8P``
M`"D````#````*````&0````I`````P```"@```!E````*0````,````H````
M9@```"D````#````*````&<````I`````P```"@```!H````*0````,````H
M````:0```"D````#````*````&H````I`````P```"@```!K````*0````,`
M```H````;````"D````#````*````&T````I`````P```"@```!N````*0``
M``,````H````;P```"D````#````*````'`````I`````P```"@```!Q````
M*0````,````H````<@```"D````#````*````',````I`````P```"@```!T
M````*0````,````H````=0```"D````#````*````'8````I`````P```"@`
M``!W````*0````,````H````>````"D````#````*````'D````I`````P``
M`"@```!Z````*0````,````H````00```"D````#````*````$(````I````
M`P```"@```!#````*0````,````H````1````"D````#````*````$4````I
M`````P```"@```!&````*0````,````H````1P```"D````#````*````$@`
M```I`````P```"@```!)````*0````,````H````2@```"D````#````*```
M`$L````I`````P```"@```!,````*0````,````H````30```"D````#````
M*````$X````I`````P```"@```!/````*0````,````H````4````"D````#
M````*````%$````I`````P```"@```!2````*0````,````H````4P```"D`
M```#````*````%0````I`````P```"@```!5````*0````,````H````5@``
M`"D````#````*````%<````I`````P```"@```!8````*0````,````H````
M60```"D````#````*````%H````I`````P```"@```!A````*0````,````H
M````8@```"D````#````*````&,````I`````P```"@```!D````*0````,`
M```H````90```"D````#````*````&8````I`````P```"@```!G````*0``
M``,````H````:````"D````#````*````&D````I`````P```"@```!J````
M*0````,````H````:P```"D````#````*````&P````I`````P```"@```!M
M````*0````,````H````;@```"D````#````*````&\````I`````P```"@`
M``!P````*0````,````H````<0```"D````#````*````'(````I`````P``
M`"@```!S````*0````,````H````=````"D````#````*````'4````I````
M`P```"@```!V````*0````,````H````=P```"D````#````*````'@````I
M`````P```"@```!Y````*0````,````H````>@```"D````#````*````#``
M```I`````0```"T````!````?`````$````K`````0```"L````!````*P``
M``$````K`````0```"L````!````*P````$````K`````0```"L````!````
M*P````$```!O````!````"LB```K(@``*R(``"LB```#````.@```#H````]
M`````@```#T````]`````P```#T````]````/0````$```#-:P```0```)^?
M```!`````$X```$````H3@```0```#9.```!````/TX```$```!93@```0``
M`(5.```!````C$X```$```"@3@```0```+I.```!````/U$```$```!E40``
M`0```&M1```!````@E$```$```"640```0```*M1```!````X%$```$```#U
M40```0````!2```!````FU(```$```#Y4@```0```!53```!````&E,```$`
M```X4P```0```$%3```!````7%,```$```!I4P```0```()3```!````ME,`
M``$```#(4P```0```.-3```!````UU8```$````?5P```0```.M8```!````
M`ED```$````*60```0```!59```!````)UD```$```!S60```0```%!;```!
M````@%L```$```#X6P```0````]<```!````(EP```$````X7````0```&Y<
M```!````<5P```$```#;70```0```.5=```!````\5T```$```#^70```0``
M`')>```!````>EX```$```!_7@```0```/1>```!````_EX```$````+7P``
M`0```!-?```!````4%\```$```!A7P```0```'-?```!````PU\```$````(
M8@```0```#9B```!````2V(```$````O90```0```#1E```!````AV4```$`
M``"790```0```*1E```!````N64```$```#@90```0```.5E```!````\&8`
M``$````(9P```0```"AG```!````(&L```$```!B:P```0```'EK```!````
MLVL```$```#+:P```0```-1K```!````VVL```$````/;````0```!1L```!
M````-&P```$```!K<````0```"IR```!````-G(```$````[<@```0```#]R
M```!````1W(```$```!9<@```0```%MR```!````K'(```$```"$<P```0``
M`(ES```!````W'0```$```#F=````0```!AU```!````'W4```$````H=0``
M`0```#!U```!````BW4```$```"2=0```0```'9V```!````?78```$```"N
M=@```0```+]V```!````[G8```$```#;=P```0```.)W```!````\W<```$`
M```Z>0```0```+AY```!````OGD```$```!T>@```0```,MZ```!````^7H`
M``$```!S?````0```/A\```!````-G\```$```!1?P```0```(I_```!````
MO7\```$````!@````0````R````!````$H````$````S@````0```'^````!
M````B8````$```#C@0```0```.J!```!````\X$```$```#\@0```0````R"
M```!````&X(```$````?@@```0```&Z"```!````<H(```$```!X@@```0``
M`$V&```!````:X8```$```!`B````0```$R(```!````8X@```$```!^B0``
M`0```(N)```!````THD```$`````B@```0```#>,```!````1HP```$```!5
MC````0```'B,```!````G8P```$```!DC0```0```'"-```!````LXT```$`
M``"KC@```0```,J.```!````FX\```$```"PCP```0```+6/```!````D9``
M``$```!)D0```0```,:1```!````S)$```$```#1D0```0```'>5```!````
M@)4```$````<E@```0```+:6```!````N98```$```#HE@```0```%&7```!
M````7I<```$```!BEP```0```&F7```!````RY<```$```#MEP```0```/.7
M```!`````9@```$```"HF````0```-N8```!````WY@```$```"6F0```0``
M`)F9```!````K)D```$```"HF@```0```-B:```!````WYH```$````EFP``
M`0```"^;```!````,IL```$````\FP```0```%J;```!````Y9P```$```!U
MG@```0```'^>```!````I9X```$```"[G@```0```,.>```!````S9X```$`
M``#1G@```0```/F>```!````_9X```$````.GP```0```!.?```!````()\`
M``$````[GP```0```$J?```!````4I\```$```"-GP```0```)R?```!````
MH)\```$````@`````0```!(P```!````05,```$```!$4P```0```$53```!
M````0C````$```!$,````0```$8P```!````2#````$```!*,````0```&0P
M```!````A#````$```"&,````0```(@P```!````CS````$```!+,````0``
M`%$P```"````(````)DP```"````(````)HP```!````/0````$```"B,```
M`0```*0P```!````IC````$```"H,````0```*HP```!````Q#````$```#D
M,````0```.8P```!````Z#````$```#O,````0```*LP```!````L3````$`
M````$0```0````$1```!````JA$```$````"$0```0```*P1```!````K1$`
M``$````#$0```0````01```!````!1$```$```"P$0```0```+$1```!````
MLA$```$```"S$0```0```+01```!````M1$```$````:$0```0````81```!
M````!Q$```$````($0```0```"$1```!````"1$```$````*$0```0````L1
M```!````#!$```$````-$0```0````X1```!````#Q$```$````0$0```0``
M`!$1```!````$A$```$```!A$0```0```&(1```!````8Q$```$```!D$0``
M`0```&41```!````9A$```$```!G$0```0```&@1```!````:1$```$```!J
M$0```0```&L1```!````;!$```$```!M$0```0```&X1```!````;Q$```$`
M``!P$0```0```'$1```!````<A$```$```!S$0```0```'01```!````=1$`
M``$```!@$0```0```!01```!````%1$```$```#'$0```0```,@1```!````
MS!$```$```#.$0```0```-,1```!````UQ$```$```#9$0```0```!P1```!
M````W1$```$```#?$0```0```!T1```!````'A$```$````@$0```0```"(1
M```!````(Q$```$````G$0```0```"D1```!````*Q$```$````L$0```0``
M`"T1```!````+A$```$````O$0```0```#(1```!````-A$```$```!`$0``
M`0```$<1```!````3!$```$```#Q$0```0```/(1```!````5Q$```$```!8
M$0```0```%D1```!````A!$```$```"%$0```0```(@1```!````D1$```$`
M``"2$0```0```)01```!````GA$```$```"A$0```0```*\P```!````MS``
M``$```"Y,````0```,@P```!````S#````$```#/,````0```-(P```!````
MU3````$```#8,````0```-LP```!````X#````$```#I,````0```.HP```!
M````ZS````$```#L,````0```.TP```#````*``````1```I`````P```"@`
M```"$0``*0````,````H`````Q$``"D````#````*`````41```I`````P``
M`"@````&$0``*0````,````H````!Q$``"D````#````*`````D1```I````
M`P```"@````+$0``*0````,````H````#!$``"D````#````*`````X1```I
M`````P```"@````/$0``*0````,````H````$!$``"D````#````*````!$1
M```I`````P```"@````2$0``*0````0````H`````!$``&$1```I````!```
M`"@````"$0``81$``"D````$````*`````,1``!A$0``*0````0````H````
M!1$``&$1```I````!````"@````&$0``81$``"D````$````*`````<1``!A
M$0``*0````0````H````"1$``&$1```I````!````"@````+$0``81$``"D`
M```$````*`````P1``!A$0``*0````0````H````#A$``&$1```I````!```
M`"@````/$0``81$``"D````$````*````!`1``!A$0``*0````0````H````
M$1$``&$1```I````!````"@````2$0``81$``"D````$````*`````P1``!N
M$0``*0````<````H````"Q$``&D1```,$0``91$``*L1```I````!@```"@`
M```+$0``:1$``!(1``!N$0``*0````,````H`````$X``"D````#````*```
M`(Q.```I`````P```"@````)3@``*0````,````H````VU8``"D````#````
M*````)1.```I`````P```"@```!M40``*0````,````H`````TX``"D````#
M````*````&M1```I`````P```"@```!=3@``*0````,````H````05,``"D`
M```#````*`````AG```I`````P```"@```!K<```*0````,````H````-&P`
M`"D````#````*````"AG```I`````P```"@```#1D0``*0````,````H````
M'U<``"D````#````*````.5E```I`````P```"@````J:```*0````,````H
M````"6<``"D````#````*````#YY```I`````P```"@````-5```*0````,`
M```H````>7(``"D````#````*````*&,```I`````P```"@```!=>0``*0``
M``,````H````M%(``"D````#````*````.-.```I`````P```"@```!\5```
M*0````,````H````9EL``"D````#````*````.-V```I`````P```"@````!
M3P``*0````,````H````QXP``"D````#````*````%13```I`````P```"@`
M``!M>0``*0````,````H````$4\``"D````#````*````.J!```I`````P``
M`"@```#S@0``*0````,```!0````5````$4````$````*````#(````Q````
M*0````0````H````,@```#(````I````!````"@````R````,P```"D````$
M````*````#(````T````*0````0````H````,@```#4````I````!````"@`
M```R````-@```"D````$````*````#(````W````*0````0````H````,@``
M`#@````I````!````"@````R````.0```"D````$````*````#,````P````
M*0````0````H````,P```#$````I````!````"@````S````,@```"D````$
M````*````#,````S````*0````0````H````,P```#0````I````!````"@`
M```S````-0```"D````#````*``````1```I`````P```"@````"$0``*0``
M``,````H`````Q$``"D````#````*`````41```I`````P```"@````&$0``
M*0````,````H````!Q$``"D````#````*`````D1```I`````P```"@````+
M$0``*0````,````H````#!$``"D````#````*`````X1```I`````P```"@`
M```/$0``*0````,````H````$!$``"D````#````*````!$1```I`````P``
M`"@````2$0``*0````0````H`````!$``&$1```I````!````"@````"$0``
M81$``"D````$````*`````,1``!A$0``*0````0````H````!1$``&$1```I
M````!````"@````&$0``81$``"D````$````*`````<1``!A$0``*0````0`
M```H````"1$``&$1```I````!````"@````+$0``81$``"D````$````*```
M``P1``!A$0``*0````0````H````#A$``&$1```I````!````"@````/$0``
M81$``"D````$````*````!`1``!A$0``*0````0````H````$1$``&$1```I
M````!````"@````2$0``81$``"D````'````*`````X1``!A$0``MQ$````1
M``!I$0``*0````8````H````#!$``&X1```+$0``=!$``"D````#````*```
M``!.```I`````P```"@```",3@``*0````,````H````"4X``"D````#````
M*````-M6```I`````P```"@```"43@``*0````,````H````;5$``"D````#
M````*`````-.```I`````P```"@```!K40``*0````,````H````74X``"D`
M```#````*````$%3```I`````P```"@````(9P``*0````,````H````:W``
M`"D````#````*````#1L```I`````P```"@````H9P``*0````,````H````
MT9$``"D````#````*````!]7```I`````P```"@```#E90``*0````,````H
M````*F@``"D````#````*`````EG```I`````P```"@````^>0``*0````,`
M```H````#50``"D````#````*````'ER```I`````P```"@```"AC```*0``
M``,````H````77D``"D````#````*````+12```I`````P```"@```#8>0``
M*0````,````H````-W4``"D````#````*````'-9```I`````P```"@```!I
MD```*0````,````H````*E$``"D````#````*````'!3```I`````P```"@`
M``#H;```*0````,````H````!9@``"D````#````*````!%/```I`````P``
M`"@```"940``*0````,````H````8VL``"D````#````*`````I.```I````
M`P```"@````M3@``*0````,````H````"TX``"D````#````*````.9=```I
M`````P```"@```#S4P``*0````,````H````.U,``"D````#````*````)=;
M```I`````P```"@```!F6P``*0````,````H````XW8``"D````#````*```
M``%/```I`````P```"@```#'C```*0````,````H````5%,``"D````#````
M*````!Q9```I````!````"@````S````-@```"D````$````*````#,````W
M````*0````0````H````,P```#@````I````!````"@````S````.0```"D`
M```$````*````#0````P````*0````0````H````-````#$````I````!```
M`"@````T````,@```"D````$````*````#0````S````*0````0````H````
M-````#0````I````!````"@````T````-0```"D````$````*````#0````V
M````*0````0````H````-````#<````I````!````"@````T````.````"D`
M```$````*````#0````Y````*0````0````H````-0```#`````I`````@``
M`#$````(9P```@```#(````(9P```@```#,````(9P```@```#0````(9P``
M`@```#4````(9P```@```#8````(9P```@```#<````(9P```@```#@````(
M9P```@```#D````(9P```P```#$````P````"&<```,````Q````,0````AG
M```#````,0```#(````(9P```@```$@```!G`````P```&4```!R````9P``
M``(```!E````5@````,```!,````5````$0````#````*````*(P```I````
M`P```"@```"D,```*0````,````H````IC```"D````#````*````*@P```I
M`````P```"@```"J,```*0````,````H````JS```"D````#````*````*TP
M```I`````P```"@```"O,```*0````,````H````L3```"D````#````*```
M`+,P```I`````P```"@```"U,```*0````,````H````MS```"D````#````
M*````+DP```I`````P```"@```"[,```*0````,````H````O3```"D````#
M````*````+\P```I`````P```"@```#!,```*0````,````H````Q#```"D`
M```#````*````,8P```I`````P```"@```#(,```*0````,````H````RC``
M`"D````#````*````,LP```I`````P```"@```#,,```*0````,````H````
MS3```"D````#````*````,XP```I`````P```"@```#/,```*0````,````H
M````TC```"D````#````*````-4P```I`````P```"@```#8,```*0````,`
M```H````VS```"D````#````*````-XP```I`````P```"@```#?,```*0``
M``,````H````X#```"D````#````*````.$P```I`````P```"@```#B,```
M*0````,````H````Y#```"D````#````*````.8P```I`````P```"@```#H
M,```*0````,````H````Z3```"D````#````*````.HP```I`````P```"@`
M``#K,```*0````,````H````[#```"D````#````*````.TP```I`````P``
M`"@```#O,```*0````,````H````\#```"D````#````*````/$P```I````
M`P```"@```#R,```*0````0```"B,```T3```/PP``#(,```!````*(P``#K
M,```U3```*$P```$````HC```/,P``#:,```HC````,```"B,```_#```.LP
M```$````I#```,LP``#S,```L#````,```"D,```\S```,$P```#````IC``
M`*DP``#S,```!0```*@P``"Y,```KS```/PP``#),```!````*@P``#\,```
MJS```/PP```#````JC```/,P``"Y,````P```*HP``#\,```X#````,```"K
M,```I#```.HP```$````JS```.DP``##,```R#````0```"K,```[3```.HP
M``#\,````P```*PP``#M,```\S````,```"L,```\S```-XP```"````KC``
M`*PP```#````KC```,LP``#\,```!````*TP``#E,```ZC```/PP```$````
MKC```.LP``#`,```_#````(```"M,```[3````4```"M,```[3```+`P``#I
M,```X#````8```"M,```[3```.$P``#\,```R#```.LP```%````K3```.TP
M``#O,```PS```,@P```#````L#```.DP``#@,```!0```+`P``#I,```X#``
M`,@P``#S,```!0```*\P``#K,```O#```*0P``#M,```!````*\P``#M,```
M_#```,TP```#````L3```/PP``"Y,````P```+,P``#K,```RC````,```"S
M,```_#```-TP```$````M3```*0P``"O,```ZS````4```"U,```\S```,$P
M``#\,```X#````0```"W,```ZC```/,P``"P,````P```+LP``#S,```P3``
M``,```"[,```\S```,@P```#````P#```/PP``"Y,````@```,<P``"W,```
M`@```,DP``#K,````@```,@P``#S,````@```,HP``#.,````P```,XP``##
M,```R#````,```#/,```I#```,0P```%````T3```/PP``"[,```\S```,@P
M```#````T3```/PP``#$,```!````-`P``#\,```[#```.LP```%````U#``
M`*(P``"Y,```R#```.LP```#````U#```*\P``#K,````@```-0P``"S,```
M`@```-,P``#K,```!0```-4P``"A,```Z3```,,P``#),```!````-4P``"C
M,```_#```,@P```%````UC```,,P``"W,```IS```.LP```#````U3```.DP
M``#S,```!0```-@P``"O,```OS```/PP``#K,````@```-HP``"],````P``
M`-HP``#+,```TC````,```#8,```ZS```,0P```#````VC```/,P``"Y,```
M`P```-HP``#\,```N#````,```#9,```_#```+\P```$````W3```*0P``#S
M,```R#````,```#<,```ZS```,@P```"````VS```/,P```#````W3```/,P
M``#),````P```-LP``#\,```ZS````,```#;,```_#```/,P```$````WC``
M`*0P``"O,```[3````,```#>,```I#```.LP```#````WC```,,P``#/,```
M`P```-XP``#K,```KS````4```#>,```\S```+<P``#G,```\S````0```#?
M,```KS```.TP``#S,````@```-\P``#J,```!0```-\P``#J,```T#```/PP
M``#K,````@```.$P``"L,```!````.$P``"L,```R#```/,P```$````X3``
M`/PP``#(,```ZS````,```#D,```_#```,DP```#````Y#```/PP``#K,```
M`P```.8P``"B,```\S````0```#J,```PS```,@P``#K,````@```.HP``#I
M,````P```.LP``#4,```_#````0```#K,```_#```-8P``#K,````@```.PP
M``#@,```!0```.PP``#S,```R#```+(P``#S,````P```.\P``##,```R#``
M``(````P````N7````(````Q````N7````(````R````N7````(````S````
MN7````(````T````N7````(````U````N7````(````V````N7````(````W
M````N7````(````X````N7````(````Y````N7````,````Q````,````+EP
M```#````,0```#$```"Y<````P```#$````R````N7````,````Q````,P``
M`+EP```#````,0```#0```"Y<````P```#$````U````N7````,````Q````
M-@```+EP```#````,0```#<```"Y<````P```#$````X````N7````,````Q
M````.0```+EP```#````,@```#````"Y<````P```#(````Q````N7````,`
M```R````,@```+EP```#````,@```#,```"Y<````P```#(````T````N7``
M``,```!H````4````&$````"````9````&$````"````00```%4````#````
M8@```&$```!R`````@```&\```!6`````@```'````!C`````@```&0```!M
M````!````&0```!M````7@```#(````$````9````&T```!>````,P````(`
M``!)````50````(```!S7@``$&(```(````M9@``C%0```(````G60``8VL`
M``(````.9@``NVP```0````J:```#U\``!I/```^>0```@```'````!!````
M`@```&X```!!`````@```+P#``!!`````@```&T```!!`````@```&L```!!
M`````@```$L```!"`````@```$T```!"`````@```$<```!"`````P```&,`
M``!A````;`````0```!K````8P```&$```!L`````@```'````!&`````@``
M`&X```!&`````@```+P#``!&`````@```+P#``!G`````@```&T```!G````
M`@```&L```!G`````@```$@```!Z`````P```&L```!(````>@````,```!-
M````2````'H````#````1P```$@```!Z`````P```%0```!(````>@````(`
M``"\`P``;`````(```!M````;`````(```!D````;`````(```!K````;```
M``(```!F````;0````(```!N````;0````(```"\`P``;0````(```!M````
M;0````(```!C````;0````(```!K````;0````0```!M````;0```%X````R
M````!````&,```!M````7@```#(````#````;0```%X````R````!````&L`
M``!M````7@```#(````$````;0```&T```!>````,P````0```!C````;0``
M`%X````S`````P```&T```!>````,P````0```!K````;0```%X````S````
M`P```&T````O````<P````4```!M````+P```',```!>````,@````(```!0
M````80````,```!K````4````&$````#````30```%````!A`````P```$<`
M``!0````80````,```!R````80```&0````%````<@```&$```!D````+P``
M`',````'````<@```&$```!D````+P```',```!>````,@````(```!P````
M<P````(```!N````<P````(```"\`P``<P````(```!M````<P````(```!P
M````5@````(```!N````5@````(```"\`P``5@````(```!M````5@````(`
M``!K````5@````(```!-````5@````(```!P````5P````(```!N````5P``
M``(```"\`P``5P````(```!M````5P````(```!K````5P````(```!-````
M5P````(```!K````J0,```(```!-````J0,```0```!A````+@```&T````N
M`````@```$(```!Q`````@```&,```!C`````@```&,```!D````!````$,`
M```O````:P```&<````#````0P```&\````N`````@```&0```!"`````@``
M`$<```!Y`````@```&@```!A`````@```$@```!0`````@```&D```!N````
M`@```$L```!+`````@```$L```!-`````@```&L```!T`````@```&P```!M
M`````@```&P```!N`````P```&P```!O````9P````(```!L````>`````(`
M``!M````8@````,```!M````:0```&P````#````;0```&\```!L`````@``
M`%````!(````!````'`````N````;0```"X````#````4````%````!-````
M`@```%````!2`````@```',```!R`````@```%,```!V`````@```%<```!B
M`````P```%8````O````;0````,```!!````+P```&T````#````9P```&$`
M``!L`````@```#$```#E90```@```#(```#E90```@```#,```#E90```@``
M`#0```#E90```@```#4```#E90```@```#8```#E90```@```#<```#E90``
M`@```#@```#E90```@```#D```#E90```P```#$````P````Y64```,````Q
M````,0```.5E```#````,0```#(```#E90```P```#$````S````Y64```,`
M```Q````-````.5E```#````,0```#4```#E90```P```#$````V````Y64`
M``,````Q````-P```.5E```#````,0```#@```#E90```P```#$````Y````
MY64```,````R````,````.5E```#````,@```#$```#E90```P```#(````R
M````Y64```,````R````,P```.5E```#````,@```#0```#E90```P```#(`
M```U````Y64```,````R````-@```.5E```#````,@```#<```#E90```P``
M`#(````X````Y64```,````R````.0```.5E```#````,P```#````#E90``
M`P```#,````Q````Y64```$```!(C````0```/1F```!````RHX```$```#(
MC````0```-%N```!````,DX```$```#E4P```0```)R?```!````G)\```$`
M``!160```0```-&1```!````AU4```$```!(60```0```/9A```!````:78`
M``$```"%?P```0```#^&```!````NH<```$```#XB````0```(^0```!````
M`FH```$````;;0```0```-EP```!````WG,```$````]A````0```&J1```!
M````\9D```$```""3@```0```'53```!````!&L```$````;<@```0```"V&
M```!````'IX```$```!070```0```.MO```!````S84```$```!DB0```0``
M`,EB```!````V($```$````?B````0```,I>```!````%V<```$```!J;0``
M`0```/QR```!````SI````$```"&3P```0```+=1```!````WE(```$```#$
M9````0```--J```!````$'(```$```#G=@```0````&````!````!H8```$`
M``!<A@```0```.^-```!````,I<```$```!OFP```0```/J=```!````C'@`
M``$```!_>0```0```*!]```!````R8,```$````$DP```0```'^>```!````
MUHH```$```#?6````0````1?```!````8'P```$```!^@````0```&)R```!
M````RG@```$```#"C````0```/>6```!````V%@```$```!B7````0```!-J
M```!````VFT```$````/;P```0```"]]```!````-WX```$```!+E@```0``
M`-)2```!````BX````$```#<40```0```,Q1```!````''H```$```"^?0``
M`0```/&#```!````=98```$```"`BP```0```,]B```!`````FH```$```#^
MB@```0```#E.```!````YUL```$````28````0```(=S```!````<'4```$`
M```74P```0```/MX```!````OT\```$```"I7P```0````U.```!````S&P`
M``$```!X90```0```")]```!````PU,```$```!>6````0````%W```!````
M280```$```"JB@```0```+IK```!````L(\```$```"(;````0```/YB```!
M````Y8(```$```"@8P```0```&5U```!````KDX```$```!I40```0```,E1
M```!````@6@```$```#G?````0```&^"```!````THH```$```#/D0```0``
M`/52```!````0E0```$```!S60```0```.Q>```!````Q64```$```#^;P``
M`0```"IY```!````K94```$```!JF@```0```)>>```!````SIX```$```";
M4@```0```,9F```!````=VL```$```!BCP```0```'1>```!````D&$```$`
M````8@```0```)ID```!````(V\```$```!)<0```0```(ET```!````RGD`
M``$```#T?0```0```&^````!````)H\```$```#NA````0```".0```!````
M2I,```$````74@```0```*-2```!````O50```$```#(<````0```,*(```!
M````JHH```$```#)7@```0```/5?```!````>V,```$```"N:P```0```#Y\
M```!````=7,```$```#D3@```0```/E6```!````YUL```$```"Z70```0``
M`!Q@```!````LG,```$```!I=````0```)I_```!````1H````$````TD@``
M`0```/:6```!````2)<```$````8F````0```(M/```!````KGD```$```"T
MD0```0```+B6```!````X6````$```"&3@```0```-I0```!````[EL```$`
M```_7````0```)EE```!`````FH```$```#.<0```0```$)V```!````_(0`
M``$```!\D````0```(V?```!````B&8```$````NE@```0```(E2```!````
M>V<```$```#S9P```0```$%M```!````G&X```$````)=````0```%EU```!
M````:W@```$````0?0```0```%Z8```!````;5$```$````N8@```0```'B6
M```!````*U````$````970```0```.IM```!````*H\```$```"+7P```0``
M`$1A```!````%V@```$```"'<P```0```(:6```!````*5(```$````/5```
M`0```&5<```!````$V8```$```!.9P```0```*AH```!````Y6P```$````&
M=````0```.)U```!````>7\```$```#/B````0```.&(```!````S)$```$`
M``#BE@```0```#]3```!````NFX```$````=5````0```-!Q```!````F'0`
M``$```#ZA0```0```*.6```!````5YP```$```"?G@```0```)=G```!````
MRVT```$```#H@0```0```,MZ```!````('L```$```"2?````0```,!R```!
M````F7````$```!8BP```0```,!.```!````-H,```$````Z4@```0````=2
M```!````IEX```$```#38@```0```-9\```!````A5L```$````>;0```0``
M`+1F```!````.X\```$```!,B````0```$V6```!````BXD```$```#37@``
M`0```$!1```!````P%4```$```!:6````0```'1F```!````WE$```$````J
M<P```0```,IV```!````/'D```$```!>>0```0```&5Y```!````CWD```$`
M``!6EP```0```+Y\```!````O7\```$````2A@```0```/B*```!````.)``
M``$```#]D````0```.^8```!````_)@```$````HF0```0```+2=```!````
MKD\```$```#G4````0```$U1```!````R5(```$```#D4@```0```%%3```!
M````G54```$````&5@```0```&A6```!````0%@```$```"H6````0```&1<
M```!````;EP```$```"48````0```&AA```!````CF$```$```#R80```0``
M`$]E```!````XF4```$```"19@```0```(5H```!````=VT```$````:;@``
M`0```")O```!````;G$```$````K<@```0```")T```!````D7@```$````^
M>0```0```$EY```!````2'D```$```!0>0```0```%9Y```!````77D```$`
M``"->0```0```(YY```!````0'H```$```"!>@```0```,![```!````]'T`
M``$````)?@```0```$%^```!````<G\```$````%@````0```.V!```!````
M>8(```$```!Y@@```0```%>$```!````$(D```$```"6B0```0````&+```!
M````.8L```$```#3C````0````B-```!````MH\```$````XD````0```..6
M```!````_Y<```$````[F````@```&8```!F`````@```&8```!I`````@``
M`&8```!L`````P```&8```!F````:0````,```!F````9@```&P````"````
M?P$``'0````"````<P```'0````"````=`4``'8%```"````=`4``&4%```"
M````=`4``&L%```"````?@4``'8%```"````=`4``&T%```!````X@4```$`
M``#0!0```0```-,%```!````U`4```$```#;!0```0```-P%```!````W04`
M``$```#H!0```0```.H%```!````*P````(```#0!0``W`4```$````^(```
M`0```#X@```!````/B````$````^(````0```%\````!````7P````$```!?
M`````0```"P````!`````3````$````N`````0```#L````!````.@````$`
M```_`````0```"$````!````%"````$````H`````0```"D````!````>P``
M``$```!]`````0```!0P```!````%3````$````C`````0```"8````!````
M*@````$````K`````0```"T````!````/`````$````^`````0```#T````!
M````7`````$````D`````0```"4````!````0`````$````A`````0```"(`
M```!````(P````$````D`````0```"4````!````)@````$````G`````0``
M`"@````!````*0````$````J`````0```"L````!````+`````$````M````
M`0```"X````!````+P````$````P`````0```#$````!````,@````$````S
M`````0```#0````!````-0````$````V`````0```#<````!````.`````$`
M```Y`````0```#H````!````.P````$````\`````0```#T````!````/@``
M``$````_`````0```$`````!````00````$```!"`````0```$,````!````
M1`````$```!%`````0```$8````!````1P````$```!(`````0```$D````!
M````2@````$```!+`````0```$P````!````30````$```!.`````0```$\`
M```!````4`````$```!1`````0```%(````!````4P````$```!4`````0``
M`%4````!````5@````$```!7`````0```%@````!````60````$```!:````
M`0```%L````!````7`````$```!=`````0```%X````!````7P````$```!@
M`````0```&$````!````8@````$```!C`````0```&0````!````90````$`
M``!F`````0```&<````!````:`````$```!I`````0```&H````!````:P``
M``$```!L`````0```&T````!````;@````$```!O`````0```'`````!````
M<0````$```!R`````0```',````!````=`````$```!U`````0```'8````!
M````=P````$```!X`````0```'D````!````>@````$```![`````0```'P`
M```!````?0````$```!^`````0```(4I```!````ABD```$````",````0``
M``PP```!````#3````$````!,````0```/LP```!````\C````$```"A,```
M`0```*,P```!````I3````$```"G,````0```*DP```!````XS````$```#E
M,````0```.<P```!````PS````$```#\,````0```*(P```!````I#````$`
M``"F,````0```*@P```!````JC````$```"K,````0```*TP```!````KS``
M``$```"Q,````0```+,P```!````M3````$```"W,````0```+DP```!````
MNS````$```"],````0```+\P```!````P3````$```#$,````0```,8P```!
M````R#````$```#*,````0```,LP```!````S#````$```#-,````0```,XP
M```!````SS````$```#2,````0```-4P```!````V#````$```#;,````0``
M`-XP```!````WS````$```#@,````0```.$P```!````XC````$```#D,```
M`0```.8P```!````Z#````$```#I,````0```.HP```!````ZS````$```#L
M,````0```.TP```!````[S````$```#S,````0```)DP```!````FC````$`
M``!D,0```0```#$Q```!````,C$```$````S,0```0```#0Q```!````-3$`
M``$````V,0```0```#<Q```!````.#$```$````Y,0```0```#HQ```!````
M.S$```$````\,0```0```#TQ```!````/C$```$````_,0```0```$`Q```!
M````03$```$```!",0```0```$,Q```!````1#$```$```!%,0```0```$8Q
M```!````1S$```$```!(,0```0```$DQ```!````2C$```$```!+,0```0``
M`$PQ```!````33$```$```!.,0```0```$\Q```!````4#$```$```!1,0``
M`0```%(Q```!````4S$```$```!4,0```0```%4Q```!````5C$```$```!7
M,0```0```%@Q```!````63$```$```!:,0```0```%LQ```!````7#$```$`
M``!=,0```0```%XQ```!````7S$```$```!@,0```0```&$Q```!````8C$`
M``$```!C,0```0```*(````!````HP````$```"L`````0```*\````!````
MI@````$```"E`````0```*D@```!`````B4```$```"0(0```0```)$A```!
M````DB$```$```"3(0```0```*`E```!````RR4```$```!!`````0```$(`
M```!````0P````$```!$`````0```$4````!````1@````$```!'`````0``
M`$@````!````20````$```!*`````0```$L````!````3`````$```!-````
M`0```$X````!````3P````$```!0`````0```%$````!````4@````$```!3
M`````0```%0````!````50````$```!6`````0```%<````!````6`````$`
M``!9`````0```%H````!````80````$```!B`````0```&,````!````9```
M``$```!E`````0```&8````!````9P````$```!H`````0```&D````!````
M:@````$```!K`````0```&P````!````;0````$```!N`````0```&\````!
M````<`````$```!Q`````0```'(````!````<P````$```!T`````0```'4`
M```!````=@````$```!W`````0```'@````!````>0````$```!Z`````0``
M`$$````!````0@````$```!#`````0```$0````!````10````$```!&````
M`0```$<````!````2`````$```!)`````0```$H````!````2P````$```!,
M`````0```$T````!````3@````$```!/`````0```%`````!````40````$`
M``!2`````0```%,````!````5`````$```!5`````0```%8````!````5P``
M``$```!8`````0```%D````!````6@````$```!A`````0```&(````!````
M8P````$```!D`````0```&4````!````9@````$```!G`````0```&D````!
M````:@````$```!K`````0```&P````!````;0````$```!N`````0```&\`
M```!````<`````$```!Q`````0```'(````!````<P````$```!T`````0``
M`'4````!````=@````$```!W`````0```'@````!````>0````$```!Z````
M`0```$$````!````0@````$```!#`````0```$0````!````10````$```!&
M`````0```$<````!````2`````$```!)`````0```$H````!````2P````$`
M``!,`````0```$T````!````3@````$```!/`````0```%`````!````40``
M``$```!2`````0```%,````!````5`````$```!5`````0```%8````!````
M5P````$```!8`````0```%D````!````6@````$```!A`````0```&(````!
M````8P````$```!D`````0```&4````!````9@````$```!G`````0```&@`
M```!````:0````$```!J`````0```&L````!````;`````$```!M`````0``
M`&X````!````;P````$```!P`````0```'$````!````<@````$```!S````
M`0```'0````!````=0````$```!V`````0```'<````!````>`````$```!Y
M`````0```'H````!````00````$```!#`````0```$0````!````1P````$`
M``!*`````0```$L````!````3@````$```!/`````0```%`````!````40``
M``$```!3`````0```%0````!````50````$```!6`````0```%<````!````
M6`````$```!9`````0```%H````!````80````$```!B`````0```&,````!
M````9`````$```!F`````0```&@````!````:0````$```!J`````0```&L`
M```!````;`````$```!M`````0```&X````!````<`````$```!Q`````0``
M`'(````!````<P````$```!T`````0```'4````!````=@````$```!W````
M`0```'@````!````>0````$```!Z`````0```$$````!````0@````$```!#
M`````0```$0````!````10````$```!&`````0```$<````!````2`````$`
M``!)`````0```$H````!````2P````$```!,`````0```$T````!````3@``
M``$```!/`````0```%`````!````40````$```!2`````0```%,````!````
M5`````$```!5`````0```%8````!````5P````$```!8`````0```%D````!
M````6@````$```!A`````0```&(````!````8P````$```!D`````0```&4`
M```!````9@````$```!G`````0```&@````!````:0````$```!J`````0``
M`&L````!````;`````$```!M`````0```&X````!````;P````$```!P````
M`0```'$````!````<@````$```!S`````0```'0````!````=0````$```!V
M`````0```'<````!````>`````$```!Y`````0```'H````!````00````$`
M``!"`````0```$0````!````10````$```!&`````0```$<````!````2@``
M``$```!+`````0```$P````!````30````$```!.`````0```$\````!````
M4`````$```!1`````0```%,````!````5`````$```!5`````0```%8````!
M````5P````$```!8`````0```%D````!````80````$```!B`````0```&,`
M```!````9`````$```!E`````0```&8````!````9P````$```!H`````0``
M`&D````!````:@````$```!K`````0```&P````!````;0````$```!N````
M`0```&\````!````<`````$```!Q`````0```'(````!````<P````$```!T
M`````0```'4````!````=@````$```!W`````0```'@````!````>0````$`
M``!Z`````0```$$````!````0@````$```!$`````0```$4````!````1@``
M``$```!'`````0```$D````!````2@````$```!+`````0```$P````!````
M30````$```!/`````0```%,````!````5`````$```!5`````0```%8````!
M````5P````$```!8`````0```%D````!````80````$```!B`````0```&,`
M```!````9`````$```!E`````0```&8````!````9P````$```!H`````0``
M`&D````!````:@````$```!K`````0```&P````!````;0````$```!N````
M`0```&\````!````<`````$```!Q`````0```'(````!````<P````$```!T
M`````0```'4````!````=@````$```!W`````0```'@````!````>0````$`
M``!Z`````0```$$````!````0@````$```!#`````0```$0````!````10``
M``$```!&`````0```$<````!````2`````$```!)`````0```$H````!````
M2P````$```!,`````0```$T````!````3@````$```!/`````0```%`````!
M````40````$```!2`````0```%,````!````5`````$```!5`````0```%8`
M```!````5P````$```!8`````0```%D````!````6@````$```!A`````0``
M`&(````!````8P````$```!D`````0```&4````!````9@````$```!G````
M`0```&@````!````:0````$```!J`````0```&L````!````;`````$```!M
M`````0```&X````!````;P````$```!P`````0```'$````!````<@````$`
M``!S`````0```'0````!````=0````$```!V`````0```'<````!````>```
M``$```!Y`````0```'H````!````00````$```!"`````0```$,````!````
M1`````$```!%`````0```$8````!````1P````$```!(`````0```$D````!
M````2@````$```!+`````0```$P````!````30````$```!.`````0```$\`
M```!````4`````$```!1`````0```%(````!````4P````$```!4`````0``
M`%4````!````5@````$```!7`````0```%@````!````60````$```!:````
M`0```&$````!````8@````$```!C`````0```&0````!````90````$```!F
M`````0```&<````!````:`````$```!I`````0```&H````!````:P````$`
M``!L`````0```&T````!````;@````$```!O`````0```'`````!````<0``
M``$```!R`````0```',````!````=`````$```!U`````0```'8````!````
M=P````$```!X`````0```'D````!````>@````$```!!`````0```$(````!
M````0P````$```!$`````0```$4````!````1@````$```!'`````0```$@`
M```!````20````$```!*`````0```$L````!````3`````$```!-`````0``
M`$X````!````3P````$```!0`````0```%$````!````4@````$```!3````
M`0```%0````!````50````$```!6`````0```%<````!````6`````$```!9
M`````0```%H````!````80````$```!B`````0```&,````!````9`````$`
M``!E`````0```&8````!````9P````$```!H`````0```&D````!````:@``
M``$```!K`````0```&P````!````;0````$```!N`````0```&\````!````
M<`````$```!Q`````0```'(````!````<P````$```!T`````0```'4````!
M````=@````$```!W`````0```'@````!````>0````$```!Z`````0```$$`
M```!````0@````$```!#`````0```$0````!````10````$```!&`````0``
M`$<````!````2`````$```!)`````0```$H````!````2P````$```!,````
M`0```$T````!````3@````$```!/`````0```%`````!````40````$```!2
M`````0```%,````!````5`````$```!5`````0```%8````!````5P````$`
M``!8`````0```%D````!````6@````$```!A`````0```&(````!````8P``
M``$```!D`````0```&4````!````9@````$```!G`````0```&@````!````
M:0````$```!J`````0```&L````!````;`````$```!M`````0```&X````!
M````;P````$```!P`````0```'$````!````<@````$```!S`````0```'0`
M```!````=0````$```!V`````0```'<````!````>`````$```!Y`````0``
M`'H````!````00````$```!"`````0```$,````!````1`````$```!%````
M`0```$8````!````1P````$```!(`````0```$D````!````2@````$```!+
M`````0```$P````!````30````$```!.`````0```$\````!````4`````$`
M``!1`````0```%(````!````4P````$```!4`````0```%4````!````5@``
M``$```!7`````0```%@````!````60````$```!:`````0```&$````!````
M8@````$```!C`````0```&0````!````90````$```!F`````0```&<````!
M````:`````$```!I`````0```&H````!````:P````$```!L`````0```&T`
M```!````;@````$```!O`````0```'`````!````<0````$```!R`````0``
M`',````!````=`````$```!U`````0```'8````!````=P````$```!X````
M`0```'D````!````>@````$```!!`````0```$(````!````0P````$```!$
M`````0```$4````!````1@````$```!'`````0```$@````!````20````$`
M``!*`````0```$L````!````3`````$```!-`````0```$X````!````3P``
M``$```!0`````0```%$````!````4@````$```!3`````0```%0````!````
M50````$```!6`````0```%<````!````6`````$```!9`````0```%H````!
M````80````$```!B`````0```&,````!````9`````$```!E`````0```&8`
M```!````9P````$```!H`````0```&D````!````:@````$```!K`````0``
M`&P````!````;0````$```!N`````0```&\````!````<`````$```!Q````
M`0```'(````!````<P````$```!T`````0```'4````!````=@````$```!W
M`````0```'@````!````>0````$```!Z`````0```)$#```!````D@,```$`
M``"3`P```0```)0#```!````E0,```$```"6`P```0```)<#```!````F`,`
M``$```"9`P```0```)H#```!````FP,```$```"<`P```0```)T#```!````
MG@,```$```"?`P```0```*`#```!````H0,```$```#T`P```0```*,#```!
M````I`,```$```"E`P```0```*8#```!````IP,```$```"H`P```0```*D#
M```!````!R(```$```"Q`P```0```+(#```!````LP,```$```"T`P```0``
M`+4#```!````M@,```$```"W`P```0```+@#```!````N0,```$```"Z`P``
M`0```+L#```!````O`,```$```"]`P```0```+X#```!````OP,```$```#`
M`P```0```,$#```!````P@,```$```##`P```0```,0#```!````Q0,```$`
M``#&`P```0```,<#```!````R`,```$```#)`P```0````(B```!````]0,`
M``$```#1`P```0```/`#```!````U0,```$```#Q`P```0```-8#```!````
MD0,```$```"2`P```0```),#```!````E`,```$```"5`P```0```)8#```!
M````EP,```$```"8`P```0```)D#```!````F@,```$```";`P```0```)P#
M```!````G0,```$```">`P```0```)\#```!````H`,```$```"A`P```0``
M`/0#```!````HP,```$```"D`P```0```*4#```!````I@,```$```"G`P``
M`0```*@#```!````J0,```$````'(@```0```+$#```!````L@,```$```"S
M`P```0```+0#```!````M0,```$```"V`P```0```+<#```!````N`,```$`
M``"Y`P```0```+H#```!````NP,```$```"\`P```0```+T#```!````O@,`
M``$```"_`P```0```,`#```!````P0,```$```#"`P```0```,,#```!````
MQ`,```$```#%`P```0```,8#```!````QP,```$```#(`P```0```,D#```!
M`````B(```$```#U`P```0```-$#```!````\`,```$```#5`P```0```/$#
M```!````U@,```$```"1`P```0```)(#```!````DP,```$```"4`P```0``
M`)4#```!````E@,```$```"7`P```0```)@#```!````F0,```$```":`P``
M`0```)L#```!````G`,```$```"=`P```0```)X#```!````GP,```$```"@
M`P```0```*$#```!````]`,```$```"C`P```0```*0#```!````I0,```$`
M``"F`P```0```*<#```!````J`,```$```"I`P```0````<B```!````L0,`
M``$```"R`P```0```+,#```!````M`,```$```"U`P```0```+8#```!````
MMP,```$```"X`P```0```+D#```!````N@,```$```"[`P```0```+P#```!
M````O0,```$```"^`P```0```+\#```!````P`,```$```#!`P```0```,(#
M```!````PP,```$```#$`P```0```,4#```!````Q@,```$```#'`P```0``
M`,@#```!````R0,```$````"(@```0```/4#```!````T0,```$```#P`P``
M`0```-4#```!````\0,```$```#6`P```0```)$#```!````D@,```$```"3
M`P```0```)0#```!````E0,```$```"6`P```0```)<#```!````F`,```$`
M``"9`P```0```)H#```!````FP,```$```"<`P```0```)T#```!````G@,`
M``$```"?`P```0```*`#```!````H0,```$```#T`P```0```*,#```!````
MI`,```$```"E`P```0```*8#```!````IP,```$```"H`P```0```*D#```!
M````!R(```$```"Q`P```0```+(#```!````LP,```$```"T`P```0```+4#
M```!````M@,```$```"W`P```0```+@#```!````N0,```$```"Z`P```0``
M`+L#```!````O`,```$```"]`P```0```+X#```!````OP,```$```#``P``
M`0```,$#```!````P@,```$```##`P```0```,0#```!````Q0,```$```#&
M`P```0```,<#```!````R`,```$```#)`P```0````(B```!````]0,```$`
M``#1`P```0```/`#```!````U0,```$```#Q`P```0```-8#```!````D0,`
M``$```"2`P```0```),#```!````E`,```$```"5`P```0```)8#```!````
MEP,```$```"8`P```0```)D#```!````F@,```$```";`P```0```)P#```!
M````G0,```$```">`P```0```)\#```!````H`,```$```"A`P```0```/0#
M```!````HP,```$```"D`P```0```*4#```!````I@,```$```"G`P```0``
M`*@#```!````J0,```$````'(@```0```+$#```!````L@,```$```"S`P``
M`0```+0#```!````M0,```$```"V`P```0```+<#```!````N`,```$```"Y
M`P```0```+H#```!````NP,```$```"\`P```0```+T#```!````O@,```$`
M``"_`P```0```,`#```!````P0,```$```#"`P```0```,,#```!````Q`,`
M``$```#%`P```0```,8#```!````QP,```$```#(`P```0```,D#```!````
M`B(```$```#U`P```0```-$#```!````\`,```$```#5`P```0```/$#```!
M````U@,```$````P`````0```#$````!````,@````$````S`````0```#0`
M```!````-0````$````V`````0```#<````!````.`````$````Y`````0``
M`#`````!````,0````$````R`````0```#,````!````-`````$````U````
M`0```#8````!````-P````$````X`````0```#D````!````,`````$````Q
M`````0```#(````!````,P````$````T`````0```#4````!````-@````$`
M```W`````0```#@````!````.0````$````P`````0```#$````!````,@``
M``$````S`````0```#0````!````-0````$````V`````0```#<````!````
M.`````$````Y`````0```#`````!````,0````$````R`````0```#,````!
M````-`````$````U`````0```#8````!````-P````$````X`````0```#D`
M```!````/4X```$````X3@```0```$%.```!````(@$"``$```!@3P```0``
M`*Y/```!````NT\```$````"4````0```'I0```!````F5````$```#G4```
M`0```,]0```!````GC0```$````Z!@(``0```$U1```!````5%$```$```!D
M40```0```'=1```!````'`4"``$```"Y-````0```&=1```!````C5$```$`
M``!+!0(``0```)=1```!````I%$```$```#,3@```0```*Q1```!````M5$`
M``$```#?D0(``0```/51```!`````U(```$```#?-````0```#M2```!````
M1E(```$```!R4@```0```'=2```!````%34```$```#'4@```0```,E2```!
M````Y%(```$```#Z4@```0````53```!````!E,```$````74P```0```$E3
M```!````45,```$```!:4P```0```'-3```!````?5,```$```!_4P```0``
M`']3```!````?U,```$````L"@(``0```'!P```!````RE,```$```#?4P``
M`0```&,+`@`!````ZU,```$```#Q4P```0````94```!````GE0```$````X
M5````0```$A4```!````:%0```$```"B5````0```/94```!````$%4```$`
M``!350```0```&-5```!````A%4```$```"$50```0```)E5```!````JU4`
M``$```"S50```0```,)5```!````%E<```$````&5@```0```!=7```!````
M458```$```!T5@```0````=2```!````[E@```$```#.5P```0```/17```!
M````#5@```$```"+5P```0```#)8```!````,5@```$```"L6````0```.04
M`@`!````\E@```$```#W6````0````99```!````&ED```$````B60```0``
M`&)9```!````J!8"``$```#J%@(``0```.Q9```!````&UH```$````G6@``
M`0```-A9```!````9EH```$```#N-@```0```/PV```!````"%L```$````^
M6P```0```#Y;```!````R!D"``$```##6P```0```-A;```!````YUL```$`
M``#S6P```0```!@;`@`!````_UL```$````&7````0```%-?```!````(EP`
M``$```"!-P```0```&!<```!````;EP```$```#`7````0```(U<```!````
MY!T"``$```!#70```0```.8=`@`!````;ET```$```!K70```0```'Q=```!
M````X5T```$```#B70```0```"\X```!````_5T```$````H7@```0```#U>
M```!````:5X```$```!B.````0```(,A`@`!````?#@```$```"P7@```0``
M`+->```!````MEX```$```#*7@```0```)*C`@`!````_EX```$````Q(P(`
M`0```#$C`@`!`````8(```$````B7P```0```")?```!````QS@```$```"X
M,@(``0```-IA`@`!````8E\```$```!K7P```0```.,X```!````FE\```$`
M``#-7P```0```-=?```!````^5\```$```"!8````0```#HY```!````'#D`
M``$```"48````0```-0F`@`!````QV````$```!(80```0```$QA```!````
M3F$```$```!,80```0```'IA```!````CF$```$```"R80```0```*1A```!
M````KV$```$```#>80```0```/)A```!````]F$```$````08@```0```!MB
M```!````76(```$```"Q8@```0```-1B```!````4&,```$````,*P(``0``
M`#UC```!````_&(```$```!H8P```0```(-C```!````Y&,```$```#Q*P(`
M`0```")D```!````Q6,```$```"I8P```0```"XZ```!````:60```$```!^
M9````0```)UD```!````=V0```$```!L.@```0```$]E```!````;&4```$`
M```*,`(``0```.-E```!````^&8```$```!)9@```0```!D[```!````D68`
M``$````(.P```0```.0Z```!````DE$```$```"540```0````!G```!````
MG&8```$```"M@````0```-E#```!````%V<```$````;9P```0```"%G```!
M````7F<```$```!39P```0```,,S`@`!````23L```$```#Z9P```0```(5G
M```!````4F@```$```"%:````0```&TT`@`!````CF@```$````?:````0``
M`!1I```!````G3L```$```!":0```0```*-I```!````ZFD```$```"H:@``
M`0```*,V`@`!````VVH```$````8/````0```"%K```!````IS@"``$```!4
M:P```0```$X\```!````<FL```$```"?:P```0```+IK```!````NVL```$`
M``"-.@(``0````L=`@`!````^CH"``$```!.;````0```+P\`@`!````OVP`
M``$```#-;````0```&=L```!````%FT```$````^;0```0```'=M```!````
M06T```$```!I;0```0```'AM```!````A6T```$````>/0(``0```#1M```!
M````+VX```$```!N;@```0```#,]```!````RVX```$```#';@```0```-$^
M`@`!````^6T```$```!N;P```0```%X_`@`!````CC\"``$```#&;P```0``
M`#EP```!````'G````$````;<````0```)8]```!````2G````$```!]<```
M`0```'=P```!````K7````$````E!0(``0```$5Q```!````8T("``$```"<
M<0```0```*M#`@`!````*'(```$````U<@```0```%!R```!````"$8"``$`
M``"`<@```0```)5R```!````-4<"``$````42`(``0```'IS```!````BW,`
M``$```"L/@```0```*5S```!````N#X```$```"X/@```0```$=T```!````
M7'0```$```!Q=````0```(5T```!````RG0```$````;/P```0```"1U```!
M````-DP"``$````^=0```0```)),`@`!````<'4```$```"?(0(``0```!!V
M```!````H4\"``$```"X3P(``0```$10`@`!````_#\```$````(0````0``
M`/1V```!````\U`"``$```#R4`(``0```!E1`@`!````,U$"``$````>=P``
M`0```!]W```!````'W<```$```!*=P```0```#E````!````BW<```$```!&
M0````0```)9````!````'50"``$```!.>````0```(QX```!````S'@```$`
M``#C0````0```"96`@`!````5GD```$```":5@(``0```,56`@`!````CWD`
M``$```#K>0```0```"]!```!````0'H```$```!*>@```0```$]Z```!````
M?%D"``$```"G6@(``0```*=:`@`!````[GH```$````"0@```0```*M;`@`!
M````QGL```$```#)>P```0```"="```!````@%P"``$```#2?````0```*!"
M```!````Z'P```$```#C?````0````!]```!````AE\"``$```!C?0```0``
M``%#```!````QWT```$````"?@```0```$5^```!````-$,```$````H8@(`
M`0```$=B`@`!````64,```$```#98@(``0```'I_```!````/F,"``$```"5
M?P```0```/I_```!````!8````$```#:9`(``0```"-E`@`!````8(````$`
M``"H90(``0```'"````!````7S,"``$```#50P```0```+*````!`````X$`
M``$````+1````0```#Z!```!````M5H```$```"G9P(``0```+5G`@`!````
MDS,"``$```"<,P(``0````&"```!````!((```$```">CP```0```&M$```!
M````D8(```$```"+@@```0```)V"```!````LU(```$```"Q@@```0```+."
M```!````O8(```$```#F@@```0```#QK`@`!````Y8(```$````=@P```0``
M`&.#```!````K8,```$````C@P```0```+V#```!````YX,```$```!7A```
M`0```%.#```!````RH,```$```#,@P```0```-R#```!````-FP"``$```!K
M;0(``0```-5L`@`!````*T4```$```#QA````0```/.$```!````%H4```$`
M``#*<P(``0```&2%```!````+&\"``$```!=10```0```&%%```!````L6\"
M``$```#2<`(``0```&M%```!````4(8```$```!<A@```0```&>&```!````
M:88```$```"IA@```0```(B&```!````#H<```$```#BA@```0```'F'```!
M````*(<```$```!KAP```0```(:'```!````UT4```$```#AAP```0````&(
M```!````^44```$```!@B````0```&.(```!````9W8"``$```#7B````0``
M`-Z(```!````-48```$```#ZB````0```+LT```!````KG@"``$```!F>0(`
M`0```+Y&```!````QT8```$```"@B@```0```.V*```!````BHL```$```!5
MC````0```*A\`@`!````JXP```$```#!C````0```!N-```!````=XT```$`
M```O?P(``0````0(`@`!````RXT```$```"\C0```0```/"-```!````W@@"
M``$```#4C@```0```#B/```!````TH4"``$```#MA0(``0```)20```!````
M\9````$````1D0```0```"Z'`@`!````&Y$```$````XD@```0```->2```!
M````V)(```$```!\D@```0```/F3```!````%90```$```#ZBP(``0```(N5
M```!````E4D```$```"WE0```0```'>-`@`!````YDD```$```##E@```0``
M`+)=```!````(Y<```$```!%D0(``0```!J2`@`!````;DH```$```!V2@``
M`0```."7```!````"I0"``$```"R2@```0```):4`@`!````"Y@```$````+
MF````0```"F8```!````MI4"``$```#BF````0```#-+```!````*9D```$`
M``"GF0```0```,*9```!````_ID```$```#.2P```0```#";`@`!````$IL`
M``$```!`G````0```/V<```!````SDP```$```#M3````0```&>=```!````
MSJ`"``$```#X3````0````6A`@`!````#J("``$```"1H@(``0```+N>```!
M````5DT```$```#YG@```0```/Z>```!````!9\```$````/GP```0```!:?
M```!````.Y\```$`````I@(``````````````````````&`?8A]D'V8?:!]J
M'VP?;A]P'W(?=!]V'W@?>A]\'WX?@!^"'X0?AA^('XH?C!^.'Y`?DA^4'Y8?
MF!^:'YP?GA^@'Z(?I!^F'Z@?JA^L'ZX?L!^R'[0?MA^X'[H?O!^^'\`?PA_$
M'\8?R!_*'\P?SA_0'](?U!_6']@?VA_<']X?X!_B'^0?YA_H'^H?[!_N'_`?
M\A_T'_8?^!_Z'_P?_A\`(`(@!"`&(`@@"B`,(`X@$"`2(!0@%B`8(!H@'"`>
M("`@(B`D("8@*"`J("P@+B`P(#(@-"`V(#@@.B`\(#X@0"!"($0@1B!(($H@
M3"!.(%`@4B!4(%8@6"!:(%P@7B!@(&(@9"!F(&@@:B!L(&X@<"!R('0@=B!X
M('H@?"!^((`@@B"$((8@B""*((P@CB"0()(@E""6()@@FB"<()X@H""B(*0@
MIB"H(*H@K""N(+`@LB"T(+8@N""Z(+P@OB#`(,(@Q"#&(,@@RB#,(,X@T"#2
M(-0@UB#8(-H@W"#>(.`@XB#D(.8@Z"#J(.P@[B#P(/(@]"#V(/@@^B#\(/X@
M`"$"(00A!B$((0HA#"$.(1`A$B$4(18A&"$:(1PA'B$@(2(A)"$F(2@A*B$L
M(2XA,"$R(30A-B$X(3HA/"$^(4`A0B%$(48A2"%*(4PA3B%0(5(A5"%6(5@A
M6B%<(5XA8"%B(60A9B%H(6HA;"%N(7`A<B%T(78A>"%Z(7PA?B&`(8(AA"&&
M(8@ABB&,(8XAD"&2(90AEB&8(9HAG"&>(:`AHB&D(:8AJ"&J(:PAKB&P(;(A
MM"&V(;@ANB&\(;XAP"'"(<0AQB'((<HAS"'.(=`ATB'4(=8AV"':(=PAWB'@
M(>(AY"'F(>@AZB'L(>XA\"'R(?0A]B'X(?HA_"'^(0`B`B($(@8B""(*(@PB
M#B(0(A(B%"(6(A@B&B(<(AXB("(B(B0B)B(H(BHB+"(N(C`B,B(T(C8B."(Z
M(CPB/B)`(D(B1")&(D@B2B),(DXB4")2(E0B5B)8(EHB7")>(F`B8B)D(F8B
M:")J(FPB;B)P(G(B=")V(G@B>B)\(GXB@"*"(H0BAB*((HHBC"*.(I`BDB*4
M(I8BF"*:(IPBGB*@(J(BI"*F(J@BJB*L(JXBL"*R(K0BMB*X(KHBO"*^(L`B
MPB+$(L8BR"+*(LPBSB+0(M(BU"+6(M@BVB+<(MXBX"+B(N0BYB+H(NHB["+N
M(O`B\B+T(O8B^"+Z(OPB_B(`(P(C!",&(P@C"B,,(PXC$",2(Q0C%B,8(QHC
M'",>(R`C(B,D(R8C*",J(RPC+B,P(S(C-",V(S@C.B,\(SXC0"-"(T0C1B-(
M(THC3"-.(U`C4B-4(U8C6"-:(UPC7B-@(V(C9"-F(V@C:B-L(VXC<"-R(W0C
M=B-X(WHC?"-^(X`C@B.$(X8CB".*(XPCCB.0(Y(CE".6(Y@CFB/_____H!>B
M%Z07IA>H%ZH7K!>N%[`7LA>T%[87N!>Z%[P7OA?`%\(7Q!?&%\@7RA?,%\X7
MT!?2%]07UA?8%]H7W!?>%^`7XA?D%^87Z!?J%^P7[A?P%_(7]!?V%_@7^A?\
M%_X7`!@"&`08!A@(&`H8#!@.&!`8$A@4&!88&!@:&!P8'A@@&"(8)!@F&"@8
M*A@L&"X8,!@R&#08-A@X&#H8/!@^&$`80AA$&$882!C__TH83!A.&%`84AA4
M&%886!A:&%P87AA@&&(89!AF&&@8:AAL&&X8<!AR&'08=AAX&'H8?!A^&(`8
M@AB$&(88B!B*&(P8CAB0&)(8E!B6&)@8FAB<&)X8H!BB&*08IABH&*H8K!BN
M&+`8LABT&+88N!BZ&+P8OAC`&,(8Q!C&&,@8RAC,&,X8T!C2&-08UAC__]@8
MVAC_____W!C_____WAC@&/_____B&.08YACH&/__ZACL&.X8\!CR&/08]ACX
M&/H8_!C^&``9__\"&?__!!D&&0@9"AD,&0X9$!G__Q(9%!D6&1@9&AD<&1X9
M(!DB&209)ADH&2H9+!DN&3`9,ADT&389.!DZ&3P9/AE`&4(91!E&&4@92AE,
M&4X94!E2&5095AE8&5H97!E>&6`98AED&689:!EJ&6P9;AEP&7(9=!EV&7@9
M>AE\&7X9@!F"&809AAF(&8H9C!F.&9`9DAG__Y09EAF8&9H9_____YP9GAF@
M&:(9I!FF&:@9JAG__ZP9KAFP&;(9M!FV&;@9__^Z&;P9OAG`&<(9Q!G&&<@9
MRAG,&<X9T!G2&=09UAG8&=H9W!G>&>`9XAGD&>89Z!GJ&>P9[AGP&?__\AGT
M&?89^!G___H9_!G^&0`:`AK__P0:________!AH(&@H:#!H.&A`:$AK__Q0:
M%AH8&AH:'!H>&B`:(AHD&B8:*!HJ&BP:+AHP&C(:-!HV&C@:.AH\&CX:0!I"
M&D0:1AI(&DH:3!I.&E`:4AI4&E8:6!I:&EP:7AI@&F(:9!IF&F@::AIL&FX:
M<!IR&G0:=AIX&GH:?!I^&H`:@AJ$&H8:B!J*&HP:CAJ0&I(:E!J6&I@:FAJ<
M&IX:H!JB&J0:IAJH&JH:K!JN&K`:LAJT&K8:N!JZ&KP:OAK`&L(:Q!K&&L@:
MRAK,&LX:T!K2&M0:UAK8&MH:W!K>&N`:XAKD&N8:Z!KJ&NP:[AKP&O(:]!KV
M&O@:^AK\&OX:`!L"&P0;!AL(&PH;#!L.&Q`;$AL4&Q8;&!L:&QP;'AL@&R(;
M)!LF&R@;*ALL&RX;,!LR&S0;-ALX&SH;/!L^&T`;0AM$&T8;2!M*&TP;3AM0
M&U(;5!M6&U@;6AM<&UX;8!MB&V0;9AMH&VH;;!MN&W`;<AMT&W8;>!MZ&WP;
M?AN`&X(;A!N&&X@;BAN,&XX;D!N2&Y0;EAN8&YH;G!N>&Z`;HAND&Z8;J!NJ
M&ZP;KANP&[(;M!NV&[@;NAN\&[X;P!O"&\0;QAO(&\H;S!O.&]`;TAO4&]8;
MV!O:&]P;WAO@&^(;Y!OF&^@;ZAOL&^X;\!OR&_0;]AOX&_H;_!O^&P`<`AP$
M'`8<"!P*'`P<#AP0'!(<%!P6'!@<&AP<'!X<(!PB'"0<)APH'"H<+!PN'#`<
M,APT'#8<.!PZ'#P</AQ`'$(<1!Q&'$@<2AQ,'$X<4!Q2'%0<5AQ8'%H<7!Q>
M'&`<8AQD'&8<:!QJ'&P<;AQP''(<=!QV''@<>AQ\''X<@!R"'(0<AAR('(H<
MC!R.')`<DAR4')8<F!R:')P<GAR@'*(<I!RF'*@<JARL'*X<L!RR'+0<MAS_
M_________[@<NAR\'+X<P!S"',0<QAS(',H<S!S.'-`<TAS4'-8<V!S:'-P<
MWAS@'.(<Y!SF'.@<ZASL'.X<\!SR'/0<]ASX'/H<_!S^'``=`AT$'08="!T*
M'0P=#AT0'1(=%!T6'1@=&AT<'1X=(!TB'20=)ATH'2H=+!TN'3`=,ATT'38=
M.!TZ'3P=/AU`'4(=1!U&'4@=2AU,'4X=4!U2'50=5AU8'5H=7!U>'6`=8AUD
M'68=:!UJ'6P=;AUP'7(==!UV'7@=>AU\'7X=@!V"'80=AAV('8H=C!V.'9`=
MDAV4'98=F!V:'9P=GAV@':(=I!VF':@=JAVL':X=L!VR';0=MAVX';H=O!V^
M'<`=PAW$'<8=R!W*'<P=SAW0'=(=U!W6'=@=VAW<'=X=X!WB'>0=YAWH'>H=
M[!WN'?`=\AWT'?8=^!WZ'?P=_AT`'@(>!!X&'@@>"AX,'@X>$!X2'A0>%AX8
M'AH>'!X>'B`>(AXD'B8>*!XJ'BP>+AXP'C(>-!XV'C@>.AX\'CX>0!Y"'D0>
M1AY('DH>3!Y.'E`>4AY4'E8>6!Y:'EP>7AY@'F(>9!YF'F@>:AYL'FX><!YR
M'G0>=AYX'GH>?!Y^'H`>@AZ$'H8>B!Z*'HP>CAZ0'I(>E!Z6'I@>FAZ<'IX>
MH!ZB'J0>IAZH'JH>K!ZN'K`>LAZT'K8>N!ZZ'KP>OA[`'L(>Q![&'L@>RA[,
M'LX>T![2'M0>UA[8'MH>W![>'N`>XA[D'N8>Z![J'NP>[A[P'O(>]![V'O@>
M^A[___________P>_AX`'P(?!!\&'P@?"A\,'PX?$!\2'Q0?%A\8'QH?'!\>
M'R`?(A\D'R8?*!\J'RP?+A\P'S(?-!\V'S@?.A\\'SX?0!]"'T0?1A]('TH?
M3!].'U`?4A]4'U8?6!]:'UP?7A___]X5X!7B%>05YA7H%>H5[!7N%?`5\A7T
M%?85^!7Z%?P5_A4`%@(6!!8&%@@6"A8,%@X6$!82%A06%A88%AH6'!8>%B`6
M(A8D%B86*!8J%BP6+A8P%C(6-!8V%C@6.A8\%CX60!9"%D061A9(%DH63!9.
M%E`64A94%E866!9:%EP67A9@%F(69!9F%F@6:A9L%FX6<!9R%G06=A9X%GH6
M?!9^%H`6@A:$%H86B!:*%HP6CA:0%I(6E!:6%I@6FA:<%IX6H!:B%J06IA:H
M%JH6K!:N%K`6LA:T%K86N!:Z%KP6OA;`%L(6Q!;&%L@6RA;,%LX6T!;2%M06
MUA;8%MH6W!;>%N`6XA;D%N86Z!;J%NP6[A;P%O(6]!;V%O@6^A;\%OX6`!<"
M%P07!A<(%PH7#!<.%Q`7$A<4%Q87&!<:%QP7'A<@%R(7)!<F%R@7*A<L%RX7
M,!<R%S07-A<X%SH7/!<^%T`70A=$%T872!=*%TP73A=0%U(75!=6%U@7____
M____6A=<%UX78!=B%V07_____V87:!=J%VP7;A=P%_____]R%W07=A=X%WH7
M?!?_____?A>`%X(7________A!>&%X@7BA>,%XX7D!?__Y(7E!>6%Y@7FA><
M%YX7_____YP5GA6@%:(5I!6F%:@5JA6L%:X5__^P%;(5M!6V%;@5NA6\%;X5
MP!7"%<05QA7(%<H5S!7.%=`5TA74%?__UA78%=H5W!7__________P``````
M``````````````!?%6(5915H%6P5<!5S%?__________________________
M_____W85>15\%7\5@A7_____________________A16'%8D5BQ6-%8\5D163
M%945EQ7_____________________________________________________
M_____________________________________________YD5I1*G$JD2JQ*M
M$J\2L1*S$K42MQ*Y$KL2O1*_$L$2PQ+%$L<2R1++$LT2SQ+1$M,2U1+7$MD2
MVQ+=$M\2X1+C$N42YQ+I$NL2[1+O$O$2\Q+U$O<2^1+[$OT2_Q(!$P,3!1,'
M$PD3"Q,-$P\3$1,3$Q43%Q,9$QL3'1,?$R$3(Q,E$R<3*1,K$RT3+Q,Q$S,3
M-1,W$SD3.Q,]$S\301-#$T431Q-)$TL331-/$U$34Q-5$U<361-;$UT37Q-A
M$V,391-G$VD3:Q-M$V\3<1-S$W43=Q-Y$WL3?1-_$X$3@Q.%$X<3B1.+$XT3
MCQ.1$Y,3E1.7$YD3FQ.=$Y\3H1.C$Z43IQ.I$ZL3K1.O$[$3LQ.U$[<3N1.[
M$[T3OQ/!$\,3Q1/'$\D3RQ/-$\\3T1/3$]43UQ/9$]L3W1/?$^$3XQ/E$^<3
MZ1/K$^T3[Q/Q$_,3]1/W$_D3^Q/]$_\3`10#%`44!Q0)%`L4#10/%!$4$Q05
M%!<4&10;%!T4'Q0A%",4)10G%"D4*Q0M%"\4,10S%#44-Q0Y%#L4/10_%$$4
M0Q1%%$<4211+%$T43Q11%%,45117%%D46Q1=%%\4811C%&449Q1I%&L4;11O
M%'$4<Q1U%'<4>11[%'T4?Q2!%(,4A12'%(D4BQ2-%(\4D123%)44EQ29%)L4
MG12?%*$4HQ2E%*<4J12K%*T4KQ2Q%+,4M12W%+D4NQ2]%+\4_____\$4___#
M%/_____%%,<4R13+%,T4SQ31%-,4U137%/__V13__]L4_____]T4WQ3_____
M___A%.,4Y13G%/_____I%.L4[13O%/$4\Q3U%/<4^13[%/T4_Q0!%0,5!14'
M%0D5"Q4-%0\5$143%145%Q49%1L5'14?%2$5(Q4E%2<5*14K%2T5+Q4Q%3,5
M-14W%3D5.Q4]%3\5015#%4451Q5)%4L5315/%5$54Q55%5<5615;%5T5____
M_________ZD*JPJM"J\*L0JS"K4*MPJY"KL*O0J_"L$*PPK%"L<*R0K-"M$*
MU0K9"MT*X0KE"ND*[0KQ"O4*^0K]"@$+!@L+"Q`+%0L:"Q\+)`LI"RX+,PLX
M"ST+0@M'"TP+5`O__UL+7PMC"V<+:PMO"W,+=PM["W\+@PN'"XL+CPN3"Y<+
MFPN?"Z,+IPNK"Z\+LPNW"[L+OPO#"\<+RPO/"],+UPO;"]\+XPOG"_______
M_________________________^L+[POT"_D+_@L##`@,#0P2#!<,'`PA#"8,
M*PPP##4,.@P^#$(,1@Q*#$X,4@Q6#%H,7@QB#&8,:@QN#'(,=PQ\#($,A@R+
M#)`,E0R:#)\,I`RI#*X,LPRX#,`,_____\<,RPS/#-,,UPS;#-\,XPSG#.L,
M[PSS#/<,^PS_#`,-!PT+#0\-$PT7#1L-'PTC#2<-*PTO#3,--PT[#3\-0PU'
M#4L-3PU3#5<-6PU?#6,-9PUK#6\-<PUW#7L-?PV##8<-BPV0#94-F@V?#:0-
MJ0VN#;,-N`V]#<(-QPW,#=$-U@W9#=P-WPWB#>4-Z`WK#>X-\0WU#?D-_0T`
M#@0.!PX+#@\.$PX7#AL.'PXC#B<.*PXO#C,.-PX[#C\.0PY'#DL.3PY3#E<.
M6PY?#F,.9PYK#F\.<PYW#GL.?PZ##H<.BPZ/#I,.EPZ;#I\.HPZG#JL.KPZS
M#K<.NPZ_#L,.___'#LP.T0[6#MH.WP[C#N<.[0[R#O8.^@[^#@,/"`\,#Q`/
M$P\7#QP/(0\D#RH/,0\W#SL/00]'#TP/4`]4#U@/70]C#V@/;`]P#W0/=P]Z
M#WT/@`^$#X@/C@^2#Y</G0^A#Z0/IP^M#[(/N`^\#\(/Q0_)#\T/T0_5#]D/
MW@_B#^4/Z0_M#_$/]@_Z#_X/`A`($`T0$!`6$!D0'A`C$"<0*Q`O$#00-Q`[
M$$`00Q!)$$T04!!3$%8061!<$%\08A!E$&@0:Q!O$',0=Q![$'\0@Q"'$(L0
MCQ"3$)<0FQ"?$*,0IQ"K$*X0L1"U$+@0NQ"^$,,0R!#+$,X0T1#4$-<0W!#?
M$.(0Y1#H$.L0[A#Q$/00^!#]$``1`Q$&$0D1#!$/$1(1%A$:$1X1(A$E$2@1
M*Q$N$3$1-!$W$3H1/1%`$4412A%.$5,16!%=$6$19A%J$7`1<Q%W$7L1?Q&#
M$8D1D1&4$9<1FA&=$:`1HQ&F$:D1K!&O$;(1M1&X$;L1OA'!$<01QQ',$<\1
MTA'5$=H1WA'A$>01YQ'J$>T1\!'S$?81^1'\$0`2`Q(&$@H2#A(1$A82&A(=
M$B`2(Q(F$BH2,A(U$C@2.Q(^$D$21!)'$DH231)1$E4261)=$F$291)I$FT2
M<1)U$GD2?1*!$H42B1*-$I$2E1*9$IT2H1(N$O__[0GO"?$)\PGU"?<)^0G[
M"?T)_PD!"@,*!0H'"@D*"PH-"@\*$0H3"A4*%PH9"AL*'0H?"B$*(PHE"B<*
M*0HK"BT*+PHQ"C,*-0HW"CD*.PH]"C\*00I#"D4*1PI)"DL*30I/"E$*4PI5
M"E<*60I;"ET*7PIA"F,*90IG"FD*:PIM"F\*<0IS"G4*=PIY"GL*?0I_"H$*
M@PJ%"H<*B0J+"HT*CPJ1"I,*E0J7"ID*FPJ="I\*H0JC"J4*IPK__ZL)____
M____________________________________________________________
M____________________________________________________________
M_________________ZT)__^O";$)LPG_______________^U"?__MPG__[D)
M__^["?__O0G_________________________________________________
M_________________[\)________________________________________
M___________________________________________!"?__PPG__\4)____
M____________QPG________________)"<L)___________-"=`)________
MTPG5"?__UPG__]D)___;"?__W0G_________________________________
M_________________________________]\)________________________
M___________________________________________________________A
M"?__XPG__^4)________________YPG________________I">L)__\`````
M````````````````_P<!"`,(!0@'"`D("P@-"`\($0@3"!4(%P@9"!L('0@?
M""$((P@E""<(*0@K""T(+P@Q"#,(-0@W"#D(.P@]"#\(00A#"$4(1PA)"$L(
M30A/"%$(4PA5"%<(60A;"%T(7PAA"&,(90AG"&D(:PAM"&\(<0AS"'4(=PAY
M"'L(?0A_"($(@PB%"(<(B0B+"(T(CPB1"),(E0B7")D(FPB=")\(H0BC"*4(
MIPBI"*L(K0BO"+$(LPBU"+<(N0B["+T(OPC!",,(Q0C'",D(RPC-",\(T0C3
M"-4(UPC9"-L(W0C?".$(XPCE".<(Z0CK".T([PCQ"/,(]0CW"/D(^PC]"/\(
M`0D#"04)!PD)"0L)#0D/"1$)$PD5"1<)&0D;"1T)'PDA"2,))0DG"2D)*PDM
M"2\),0DS"34)-PDY"3L)/0D_"4$)0PE%"4<)20E+"4T)3PE1"5,)50E7"5D)
M6PE="5\)80EC"64)9PEI"6L);0EO"7$)<PEU"7<)>0E["7T)?PF!"8,)A0F'
M"8D)BPF-"8\)D0F3"94)EPF9"9L)G0F?":$)HPFE":<)J0G_____________
M___P!_0']P?__],'___5!________________________]<'________V0?_
M_______;!________]T'________WP?__________________^$'________
M___________C!___________________Y0?__________________^<'____
M____UP3=!.,$Z03O!/4$^P0!!0<%#`41!18%&P4@!24%*@4O!34%.P5!!4<%
M3053!5D%7P5E!6H%<`5V!7L%@`6%!8H%CP7_____E07_________________
M____________________________________________________________
M____________________________________________________________
M____________________F@6>!:(%I@6J!:X%L@6V!;H%O@7#!<@%S072!=<%
MW`7A!>8%ZP7P!?4%^07]!0$&!08)!@T&$085!AD&'@8C!B@&+08R!C<&/`9!
M!D8&2P90!E,&5@99!EP&7P9B!F4&:`9K!F\&<P9W!GL&?P:#!H<&BP:/!I,&
MEP:;!I\&HP:G!JL&KP:S!K<&NP:_!L,&QP;+!L\&TP;7!ML&WP;C!N<&ZP;O
M!O,&]P;[!O\&`P<'!PL'#P<3!Q<'&P<?!R,')P<K!R\',P<W!SL'/P=#!T<'
M2P=/!U,'5P=;!U\'8P=G!VL';P=S!W<'>P=_!X,'AP>+!X\'DP>7!YL'GP>C
M!Z<'JP>O![,'MP>[![\'PP?'!\L'SP?__________________________\D$
M________________________________________________RP3/!/______
M_________________________________________________],$_____YP$
M_____YX$H`2B!/__I`3_______________________^F!/______________
M______^H!*L$__^O!+($_____________[8$_____________[@$________
M____________________________________________________________
M_________________________[H$________O03`!/__________PP3&!/__
M________8`-D`V@#:@/__VT#<0-U`___=P-Z`WP#?@.``X(#A`.&`X@#B@.,
M`___C@.0`_____^3`Y4#EP.9`YL#________G0.A`___I`/__Z8#__^J`___
M_____ZP#K@.P`[(#M`.V`___N`.Z`[P#O@/``\(#Q`/__\8#___*`\P#S@/0
M`___________T@/4`]8#V`/:`________________________]P#X@/H`^X#
M]`/Z`P`$!@0,!!($&`0>!"0$*`0J!"T$,00T!#8$.00]!$($101'!$H$3@10
M!%($5`16!%@$6P1?!&($9`1G!&L$<`1S!'4$>`1\!'X$@`2"!/__________
M________________________________A`2'!(D$C`2.!/______________
M____________________________________________________________
M____________________________________________________________
M______________________^2!/__E03__Y@$________5`/_____5P-<`___
M___________O`O$"\P+U`O<"___Y`OL"_0+______________P(!`P,#!0,'
M`PD#_____PL##0,/`Q$#$P,5`Q<#&0,;`___'0/__Q\#(0,D`___________
M_____________R@#__\M`R\#,@/__S8#.0/__ST#/P/__T$#____________
M______]$`_____]&`TD#3`/__________________________________T\#
M_____^D"[`+_______________^X`KH"________________O`*^`O______
M_________________________________________\`"P@+_____________
M____________________________________________________________
M____________Q`+&`O__________________________________________
M___________(`LH"_____________________\P"S@+_________________
M____T`+2`O__________________________________________________
M___4`M<"V@+=`N`"XP+_________________________________________
M____________Y@+_______________________________^R`O__M0+_____
M__________________^I`O______________________________________
M____________________________________________________________
M________K`*O`O__________________F@*=`J`"HP+_________________
M_Y$"E`*7`O____________\`````````````````````>`)Z`GP"_____WX"
M@`+_________________________________________________________
M_________X("A`*&`O__B`**`O_______XP"__________________]>`F`"
M8@)D`F8"_____________________V@"__]J`FP";@)P`O__<@+_________
M____________________________=`)V`O____]6`E@"6@)<`O__________
M```"``0`!@#__PD`#0`/`!(`%``8`!H`'0`A`",`__\G`"H`+@`Q`#0`-@`X
M`#H`/``^`$$`0P!&`$P`4@!8`%H`70!@`&,`9@!I`&L`;@!P`',`=@!Y`'P`
M?P""`(4`B`"*`(T`D`"3`)8`F0"<`)X`H`"C`*8`J0"L`*\`L@"U`+@`NP"^
M`,$`Q`#&`,D`RP#.`-$`U`#7`-H`W0#@`.,`Y0#H`.L`[@#Q`/0`]P#Y`/L`
M_@`!`00!!P$*`0T!$`$2`10!%@$8`1H!'`$?`2(!)0$H`2H!+`$N`3`!,@$T
M`38!.`$Z`3P!/@%``4(!1`%&`4@!2@%,`4\!4@%4`58!6`%:`5P!7@%A`60!
M9@%H`6L!;@%P`7(!=`%V`7@!>@%\`7X!@0&$`8<!B@&,`?__C@&0`9(!E`&6
M`9@!F@&<`9X!H`&B`:4!J`&J`:P!K@&P`?____^S`;4!MP&Y`;L!O@'!`<0!
MQP'*`<T!SP'1`=,!U0'8`=L!W@'A`>,!Y0'G`>D!ZP'M`>\!\0'S`?4!^`'[
M`?T!_P$!`@,"!0('`@H"#0(/`A$"%`(7`AH"'0(@`B,")@(H`BH"+`(N`O__
M_____________________________________________S`"____________
M____________________________________________________________
M__________________________________________________________\R
M`C4".`([`CX"00)$`D<"2@+_____________________________________
M__________________________________________________________]-
M`E`"4P+__________P````````````````````!$GBH>"R"'RPRO"IX+GBS4
MP2,.KP2>!9YVH0?2`R,$HQ(>G&%7ZQ&>`BP(K!<>2Z,6'DNC(!YUIVVYXB,W
M.@D[PM5QM_A,<LTB'KZC&!YUIR0>::$?'KZC2>$A'FFALR.TIJ$@=B[=RJJE
M]@`+((?+DC=@.`^Y/\)*7%!<.V=*9ZAHSN@SGC*>Z-&Z0#+";RJ7[ADSYS0)
MTLJC""+%TOPN^M\&`)2>1AYYY44>>>4;+'HNA2Z\;KWNJ<_/P'TY`KH7'P`U
M/D=&V*RE3E9=UE@>";E7'@FYD&:@9K'FTL_W8`EA"F$5X?BV6"'+J;?<@A[@
MX7X>@1XGOWD>@1YR+B>_G&^?[WD>?AXGOW$>X.&X-JW':]PMPHL>TZ.*'M.C
M#:^/'I`>O+6.'I`>O#5GUHX>CYX='_+F1)[;IH$L5RUR.W.[F9Z8GIP>GIZ:
M'IZ>B36*-4IO4.^:'IR>#\&^'F:A(D4CQ49%4D5=15[%KYZPGJN>K)X<J:K9
M.]FRIKN>NIZA'F:A!*'.K\T@J"+5HM@>Q:#5H([;WZ"K(;`A-[R3+YZO6Y\>
M'YB@EA\8+1FM^AX)H,6>RB#RH`RD[9YTKT\A=V5X97_E`*$1H-Z>1R#-HZ$?
M^:#3'@F@QY]L+XRU3I\C('<OK"\&1^/JH"!KPA&N41X^1T;8*J$EJ0.WM*`%
MH)$>(!^SH-`>F"!6SDF@'1^SH.6?U)^WH`"@*Z"6H'T@WJ!'']K*JJ(R'V`?
M'J$Q'V`?'J&0G\300)\\GQ2P*Y\#KOZ>*$NP7L9>M6K4ZF"C&&F`Z<\>?R_T
MZEJ@JY\Q'S(?'B&SJ:V@R:"*K]4\2\`"(':NB*]8H+<IZJEEMR5F-&9P9H+F
M2;4UG]&>4%.FU>"?]Q[YH+:?Y:!U($G@=*#1H`BA%:%>GP*A&"$]K.;'HY]`
MK#?%XY_[S/R>`:$4WSS"(Q^3L&JAXLJ@GRO:[I_!GR&?%*$\H0:@-Z$(H#D@
M":'B'RG1-J":($BU>2"9(,,@!ZFE3#OKWC`CNR6?=1]VKGH@L222I1R?Z9_K
MG],>^IYLH/8`*AZ'RT;1$*`/H.R>>*ZYH*,OR=7_'@;'/*"U(LRB)I]:HO&?
M[1\)H;6@)*"^H/'2\-SNGA^?"UT775W=@Y_`H%R?I*\\X`H@KZ"GGZ8?2>!X
MH'>@^Q^9(,,@!ZD#(+$DDJ7"H"H?WJ#HH!^A=4_A:8+JK*]PMR>?T!X>'U;.
M^Q]Y(,,@!ZGR'TBUK:\0'VO")AYV+MW*MJL.H3NA$*$RH3JA8Y]LH!T?()\;
MGSJ@))\>H#Z@6:![H/L?>2"9(`>IL:_%GF6?V9["'J@BU:*HG\:>7K5[QBH?
M?:#)GNV@I9]^H/2@=C"J,.&PXZ#'YMF>Z:#W'J&?ZI[*GZR?OYZIG^T?.:"D
MH*>@YI^JGZT?/:PQ'S(?8)]_H#FA&)^HH.J?)Z&IH*6@Z)]0(5*A*LSVH6Y`
ME\!,(5&A2R+*(@6L2B%1H52AYQYW97AE?^4_(5*A2B%,H3\A4*%.H5>A5J%H
M'LNIZ.Y@H5RA][6A'KZ>A:$A'B2>WI\MUBDI5&==Y[(D$4NB9==EW.4(T@R>
M"E,RTZI/"NEC0WC#@*%^H<6FBZ$]KHFA9Z$&)PXG$Z>AK(2AC"$GRX*ABB$G
MRVXBYZ/GII*AQ-"0H8*KJ2'KJ\W>LM^0*YRK6J@`M\.KO"O'J\RKF2'KJT(N
M@\_,'K`A-[PX-A7OKNG,'JLA-[RTH98\7=AZO+&AP;SOO,VA#+W((>B]?+V"
MO5,PO3#2O;B]UB&6OL"AO+V[H1N^2KZ:QA>XQB&6OMPAG[_;(9^_"$%508A!
MF<%^+CJWXB'CH>$AXZ'A(>*A\^Q%K`0I5=;L(>XAJ&C,:,[HY^SH(>XAJ&C,
M:,[H]"%_,9&QZ"'L(:AHS&C.Z/&A[Z$R+#0L-BPW+%#KR+KM(7\QD;%'H5<G
M2BBDJ(`L8^^#-,JT_J']H7_D`B+6X0`BUN$$H@.B&R)UHD(>Q=(>N+O2@R*0
M(CO%[::)LHFB1Z);H@4B,2)/(EDB=:(JHBNB)R(\(JNB)B(\(JNB2V)D9,?D
M(*(E(D:O5R)W(M]C\N1$HK/H&R)/(EDB=:)!HOW83J(^HB8B)R*KHHJB.J*,
MHG2B-*)D(I&B`.LMHAFB2R'*(@6L@KYLNSFB&R(Q(EDB=:)N(N>C8R)Q(HTB
MCB*2(I0B\&'\X2PB=R+?8_+D&R(Q(D\B=:(SH!JB9:)1(G$BC2*.(I(BE"+P
M8?SA0B*1HEVBN64)YH>B<**.(5`BYZ-IHE$B8R*-(HXBDB*4(O!A_.$MMT"B
M!2(;(C$B3R)9HBPB5R+?8_+D+K+FHA(BD"([Q9K+9Z(8HCVB/Z)1(F,B<2*.
M(I(BE"+P8?SA42)C(G$BC2*2(I0B\&'\X1(B@R([Q4(B9*)1(F,B<2*-(HXB
ME"+P8?SA42)C(G$BC2*.(I(B\&'\X:U<ZMSG(OBBIM_\3/_,V:+QHL(>S2#5
MHBZ?)B(G(CRB]:+!HK0BWB*EL;,BWB*EL28@S*)(M>*BLJ)/M=$B5;7(HL>B
M2R%+(@6LVR+R(O.B)B"UHL4BE2^@+U6UPA[-(*BBUR("M]8B`K>AHNFBRR+R
M(O.BW-"S(K0BI;$NLK^BP[%_HITB^*+:HJ*BRR+;(O.BRR+;(O*BL:*=(N>B
M`*/[HA`>!*,0'@.CK>[I+S$PI+"LLS-19M$XH^DW_K<`+LK?(*,>HRFC+:/+
MRS55S]4AHR:C,:-'/-F^+J,S(T$I::DR(T$I::D:HT"CR3NKX3JCQN=2HP<V
M^S8I9E[FE-(6'A>>4*,++>]34-54(_8CZK5-HT:C3#C5N4\C]B/JM5@CKJ7R
M*./<52.NI3VQA\/44Q355)_GQF4C=RCW/IL_`D!_677N9"-_V>716UA>V/6M
M&"D\L@&N?2.-QGNC^RURLS?/9##)W'2C<R.-QH@CL"/@KCFR\"[SKJ0CKR.F
M-L8V=#MWN]3(@J.RHR<GTZBMHYFC)<B.[Q:MH"/!KN4HVRX]8=#AC:.5I_.N
MH:.5(\&NGZ/"KK2CAB/&MLBNVJ[/+M"NC*/=KH8CIC;&-G0[=[N"(^"NB:,E
M'K2FHZ.0OL')L="[8#!AH^:[H[JC'QXBG@Q'(\X)'@ZOPR/$(\6CPB/$(\6C
MPB/#(\6CPB/#(\2C2>=&Y_FC:+)!GMGF[A[;(XW`-K4LJ:[">D9\1NIJ[NJ*
M'HN>M,T)*8K;3358M<TCC<`)K'-%@D6)18K%X2A_QQL>-SH).\+5CB%0(FZB
MUDEY6+OF3*1N)[$WKSKZ4;'H3R-4(^HU2=1?UL@C!B9.NS"FJ23VI'),I>^K
M)42FI.44K]T>5=B,KZXFS[:'ID*DSJ5AL%&D*R56)B':>*9T4'W0&"53)50E
M7R7L6MGE-"1)I#,D2:10I!?13:1*I!6D@C+"PC,D-*0_I.NC/:0VI!ZD.*;(
MIA2FIJ8$I>$DGUP@W;PDCJ7ZI,:EVJ5&VC'@W*62)$O:3=H1)E96/-OCI(PD
MTC"B[XHDTC"B[V#::B1+VJBF@*:DI%VFG*0`)/:D:>^`)4G8`R!Z()*E<R$1
MRXYA>>Y9)(ZEI::G92CK_^<6)5XEUD4"QF"F-:;VI6:F*29!VW*FC*9EIK*E
M6"2?7"#=A:0VVF`EAB6>)M$GBK``)*FD6J286O';5Z0CT9[3>J4CI=$D7B76
M10+&+R13)50E7R7L6MGE'*;*I2ZFZ:45I9JEGJ4?I*_:]:\*IBK;[N4O)!@E
M5"5?)>Q:V>4O)!@E4R5?)>Q:V>5)IDFFT206)=9%`L8O)!@E4R54)>Q:V>7R
M)(8EGB;1)XJP5%A86)SB%J;'I<"F6R:9)M,F9^\3ILDF5\\]IB^F$*6O)$G8
M)VDUZ7';\B1@)9XFT2>*L%DDO*1^)A;&`R!Z(+&D)*68,9DQ5KLGI;NE)YX#
M)$2F5)Y5(UBCMR5TIM]HX&ACZ=^DWT$EU*\E=*:II0VFLZ9%[UND;*4=I1>D
M7*1II&KA8*LWIB*EP:9OIM2D,-OY(TZ[0*6]I7PD/-MOI56D9Z60)ATL'L53
MIANEMJ8OIM<D0=L@I7@E**;]H]&FTZ3EI5*D=*5VL%#;`R2KI56F5B57I6BF
M&*9%IA\D(=IN)9FFE::=I-*D:]O=I-6D4*9?V_.EV:2O);>E7%A?6%/@**13
MKY&EFZ03I-RDE*87)ATL'L6/IERF;B5;)M,F9^_R)&`EAB71)XJP3[W*IL*F
MO:16I)FD$:2XGKZE)1ZSHR2FPJ9MI>NEHR:[IH&A4Z1P)5?/HJ;/TG'2,:9N
M)9DF9^_R)O0F#:?>)NPF^R[]+O1?)>#@II:>V";L)OLN_2[T7R7@5NC9IN,F
M&"?PS.(F&"?PS/4]"CX5OH^A\:;8)MXF^R[]+O1?)>`3(A(GE]7V)OLF_28`
M)PNG3\?JIM<F]"8-I_XF%B<7I]<F\B8-IP>G[R;[)OTF`"<+I^6U[R;V)OTF
M`"<+I^\F]B;[)@`G"Z?S)A8G%Z?O)O8F^R;])@NG$:>&(0XG$Z?UI@^G[R;V
M)OLF_28`I]<F\B;TIH8A!B<3IPBG`Z?M)I?5AB$&)PZG\R;^)A>G\R;^)A:G
MXB;CICXX$KLAIQ^G.D4\Q5;0BR/3J%>R1[?JPU0GRB>SK=FH-"ARJ'X[?SN!
M.Z&\+^:%+"KF;R?**-XH*^:GKBSFBZ<P)\HGLZWW(4HHI*C@K06HL"BU*,<H
MW"A(3T[/XJB[)^FH8BB6YK,HJ^:<*`C)`J@#J+NQC*A`9D'FY;SP(_K13R<K
MYJ>GAZ<8'B">HJ>BJ,"GWZC@J-JH<Z=3IT$HV*AAQ7OFFJ,&J"\H)RPMK)RG
MFZ>BJ'BGOJAPIXBK"BA6T(JHX:>VJ,NH3Z@6J%TGZ:B"IV[(5N8P)U0GLZWR
M)&`EAB6>)HJPTZ?2IU*H9"C.J!VHQ"C.X20HA.:MIY?(9[(.+5PME<B#LV.G
M9*=:IY:GZ].IIWFHKBBOJ+2G>^;:I]XGA.8V9H[FFB<G+"VLE2B!YJ6R.B=R
MJ$Q%3<62)]BHZJCW(5<GI*@4TWO%LJ=1J%"HV*>6J(*]IZBBH6S4:ZA>I]DG
MSJACYM!&?>YAJ#HG-*@8K&0C=>X1*,VH#D462-K(1<*KIV>G,"B!YE2HGJB[
M*$;"8"<(R9>H>B>AI_<A5R=*J%FH%2BOJ!4HKJA;)[4HW"A(3T[/7R>KYELG
ML"C<*$A/3L^OIX?>F:BFI]PGSN%;IT\GWJBQI^2H>:C9)V2HO<2+(R>GDB=!
MJ#FGAJ=;)[`HM2A(3T[/3R?*J(2GA:?A(W_'7*?,J)@CVRX]X5TGNZ=&J.\H
M]:CN*/6H<M#YJ%8CX]R[.[R[[BCOJ/<H^JCV*/JH_*CQJ/8H]ZA_*E_0^*@`
M*?^K_2C_JPJIYB%5UDWF^Q]Y()D@PZ#8(XK;`JFI+P=9AMD3J0^I0=9O(SRR
M&ZD:J;&>(*D?J2,IIK@B*::X&9]R(51G7>?/HX"[+#=-N?"\+>C4NX?:/JEJ
MJ3FI,B,S(VFI4*G2RO"W;JG>[D*IAT(IX&@I;"E.PPFO6L5G*;2M92FTK58I
M;"E.PS(C,R-!J3JI5BEH*4[#2ZFS*2VKYBGGJ9TI)"JG3-K,9BJ-JKVJV:GX
M*075K*E%R87#N*J&*20JITS:S/6JUZJO*@"KDJE@'W8I+:N$'^JI/RI`JA*J
MRJG)J6@>6*'7J8ZJ,*K-J8JID=4?JG@IYZEX*>:IA!^WJ>RIZZGFJHTI!=5C
MJD&J;:H(JPRK3*O&J2(K0ZLO*C&JXJF&*9TIITS:S"JK":L;*C&JTJD;*B^J
MIZKZ*ONJN"E`JK@I/RI0J@2J0*K[J8<IC:KKO06J/1Z7[O^J,"M&*WZK"ZLX
MJ_LH7]"'*6:JT*DRJKRJ`ZNK*0"KFZFJJHBI)S%MT!TKA=@RJR&K*JNJJ>ZI
M&:NIJ90Q1,8T*ONJ-"KZJG.JJRFOJJVJ!JHMJG6J!ZKQJLLJA=C2JA@J0ZLW
MJR8JU*IV*;.I="I&*WZKT*HDJW:JTK$8*B*K="HP*WZK"*I3JU*K:ZOCI7@K
M:36%-88UB+5_JUFK9BMI-84UAC6(M7VK?*MT*C`K1JMJJ\TKU2O7*]PKYRLO
MQ9>A8$)U5L?6><JHIX'*B="=(9RKG2&0J]HK\ROV*^3#GROFJYXKYJOUJ[<K
MZ:M.K+*QKJNKJXQ;O.&BH*$KZ:O&JZ8AQZO;*^RKTUS4W,?AI*&[JZ8AO*M1
M9U+GNF9-9TYG3V>T;19N9.ZHH8$KU2O7*]PKYRLOQ;VN@2O-*]<KW"OG*R_%
M@2O-*]4KW"OG*R_%G2OS*_8KY,.]*^RK@2O-*]4KUROG*R_%XJMGVJU*MLK=
MJYXKGZN!*\TKU2O7*]PK+\6A*[>KF2&IH;TKVZN=*]HK]BODPZ"KG2O:*_,K
MY,/^*PVL"ZP.K/DK#:S]*`"I$QX(K$LA2R+*H@>L!JP3'@*LWJ/[J_DK_JO\
MJQ,L%"P^PA(L%"P^PA(L$RP^PG6H&JP9K$@>A2Z\;KWN%R:0)A[%SL$@+'M=
MKFM[;)SL'RQ[7:YK>VR<[",L)"PCL"*L(BPCL":L):R:)R\H+:PKK"FL0.N:
M)R\H)ZSR(30L-BPW+%#K\B$R+#8L-RQ0Z_(A,BPT+#<L4.OR(3(L-"PV+%#K
M3:RM'Q@AX<:W'_S=9*Q3K.6A2JQ&K.5L'^XXK*FK6RQ(KD.L3RQ(KFRL8JQA
MK$*L:*QFK%ZLO*WZH9<>5RUR.W.[2-Q")RKF.MR'K1>M]*Q0K?8LBRV,+;DM
M9F:=9J_FB*%2+5,MS"W6+=<MGLBZK;VMAZTLK<NMJ*VGK=VLTJS]K**MH*TB
MK=*MZ:SHK/"L[ZR8K%@MN"W&K9LLBRV,+;DM9F:=9J_FX:R7K0VMKJT(K0>M
M3B/OTP.M_"=<+97(DZ.7K-$>&:W1'ABMY:R]K(,MA*W/RYJLJ2Q3+9[(J2Q2
M+9[(EQZ!+'([<[OU++@MQJV4K?PG#BV5R(&M$SZJOG.M;ZU=K2VM+:V6++2L
MFRSV+(PMN2UF9IUFK^:;+/8LBRVY+69FG6:OYEJM`JWDK..LQ*S#K`2MW^8P
M)U0GRJ=E*6>I]2Q8+<:MFRSV+(LMC"UF9IUFK^:MK'^LLZS3+=2M]2Q8+;BM
MOZRI+-8MUZWFK,6MQ:VI+,PMUZVI+,PMUJW=K=NM6:?CK>*MC^?PK>^M;J-6
MV/VM=R-RL_JMS6?HYQTCRM]P(V,N9*Y(GR6N*ZX9S4.N,ZX6GXO82,T^S)++
M7R[8M06N+RXVKD"N"*[&U$<N6BYKKB8N-JY2+W@[B,9LKA"N)BXOKEBN5ZZ#
MH2>NJB&#SP^N+BY:+FNN3RQ;K"C./*X[KBXN1RYKKAPNV+79M0$N9*X!+F.N
M+BY'+EJN,:Y^'GDNIKG*R28>=1\"(*$@=R[=RG:N%J!R+J:Y2)[@H8,NM2[C
MKO`N\ZY_+N.N6%.*TT@>&RR\;KWN=K%`PNRNX:ZKKMPOR;'?KI#OPR[BKE"G
MDZY_+O132E3MU+NN?C>`-ZDWUS>EN+:NSJ[3J]^NE2.@HZ*CGR[BKJ:CO*ZI
M(]"NJ2//KJBCF"/E*#WAKJ.9+K^N@B.PHY&NGR[#KG\N@Z[JKNFND*Z%(X$N
M\ZZ%(YLC@2[PKNK?V";>)NPF_2[T7R7@0Q[ZW]@FWB;L)OLN]%\EX(OEXT2-
M6:%?IU^H7ZE?K]]PQ<2X"C,ULUBI`)Z,G@D>P:.N7+-<,-T2KQ&O"J0UKTPO
M,,!#S3.O3J\JKR"O.J\^+TBO-Z\\KSNO.2](KRNB.2\^KR6O+Z]1KU"O,"YX
M.XC&>29VQ56O5"\$8S+C\LM:+T>\62]'O%PO72]>KULO72]>KULO7"]>KULO
M7"]=KV"O7R^FU&:O9:]RK[7-U>;]'HRU:*_BGO\>K"_CZKFO6Q_TZH,O[-^P
M+[0OM:^`KY$O\U\5X.7"=Y]JGPZD7^:$+_-?%>#.'IZOT2*@K\X>DZ_1(I6O
MILD?(,G59:`-*8;9_QZ-('>OG*"!K\2@MR]T,+.P@2^UKX$OM*^S+W0PL[![
MK\2OPZ^VL<&>]#'ZL8S:?K"4+LFQG[`EL(*Q!B,Q,*2PM+`XI3ZQT#'WL4NQ
M:[&NL6JQM;`TL4*?D;"0L5:P(BPDK..O8+`&(^DOI+#C,'0SSTWK33W.W[',
ML5*P`+)&L,0AO;`=L"JP'22+L'DCR=P[T!FQA3"FL,>QLR^W+[.PX+#K($$F
MJC#AL%^QZ+$WL?NPJ3#QL/*PV:_E,$*Q$3$YL7$PIK#R)&`EAB6>)M&G8;`"
MPQ:PU)\",9;:[]OBK\JP!B/I+S&P<3"%L'PP\;#K('8PX;!DL?BQ<[&KL;,O
MMR]TL/"O!;#WY<0A4["B,%KJBB2,)*+O_1\CNW6PZR!V,*JP.[!_,$*Q_+%8
ML?*QBK$<L5DQ6K&:L6.Q?#"IL'VP(MA[L`K9EC"6V@E&4L:`,#FQ:K`QPNRP
M3;&!L:2QDK&_*FW0_+$&L'JP@#`1L4ZQ6J/^KUCH?S#EL!>XM[L!L""Q/#$:
M-AC'=#'^L>BP[3!:L>TP6;%X,(6Q[["KL`2P`K"6L5'6K;!1L8:N?3$:LGPQ
M&K(RN^TA]"&1L2&QYZ]?L:FQZ[`<L.TA]"%_L2:Q]BI$QFTQE[&6L9PEF3%6
MNYPEF#%6N^ZP)+&S(K0BWJ*'L:^P`["JJ\:O9J?DHG.PE"[<KS^PU+$`,/>Q
MX[$^*_:QS;'UL9G4/+#1L>>QYK%YL.FPSR__L=RQTK$`,-"QK+#/K^<P,[$B
MNU&Q]+%+L`>R!K(4LB\R,K(+LB>R)C(PLGPQ?;$>LJ%<(MT;LA@R,+(7LBRR
M*;)Y(N"B#S(RLA@R)K(/,B^R-S(XLC8R.+(V,C>RA*,^LF\C&*D[LDRR2[*4
MSN`S+LVR-,BTPK(HIQ=:K-M-LVBRYN'WI\DC8++A,O2T:[.#L]JSIK3^M+RU
M2"3"PA2BJ[3+LM2RU[+I,L>T=K1SM(2S-K1WVS&HX;3>,G1"W=E5LM2TFK2;
MLO^RM#?ZMRBTG++6LM6RG;+=LMRRM;+LM&XSVK1I,@0S]+0/M<"SP;04M?"T
MI31ZQIXRQ[3/LINSX3+TM`0O-;,^'N<T"=)OM".UE[.^M+NT/K.3M,NTG[29
ML^"T[K./M`0O"K,2M!/?'[/2LP4TN30JM;$X=4F1S5ZRT;-YTQRTB+0-M+^T
MV[,7-..T#=)JLN`RVK1W(_NM.[`6./*X_2=KLJ&R'+,CLP*SQ^'1M`JC[;/$
MM%&T\K2CM'NT%+1<M+#(X[)/LS^S;+)BLTZRLK,EL\S0%C1'M"RUL[09M?&T
M7[0]SD$SN30JM82W7[,WL[NS^C-'M&.S7#.0U-.RF+0HM:*RU30<M:BY1#0=
MM4(T';4$M?HT;-GZ,Q:T[[0DM;2SO+,"M,]-ZTT]SO6T&K.@LI^RNK/[(<JT
M%K5>LR:SD;20M""S+;3(LB*SS;2XL^@R>L9OLE5-=DW=SIJR43+(M/^S!K7W
MM/RT03,%-"JU&[4>LQVS8;/ELK.SGC+ILE$RLK3[(8.T(;.AM*6SQ;(Z-!RU
MX#)NL_NT)+.LLF.S++4^'ADS"=+?LDBTY[(!M+>S:3+A,@2S:;2W-&W91K3>
MM+BT"K5PLE&>1;0BM;6T'[7]M.*R(K7FLH2T`+2ZM#HTU;1"-$2T"+4%-1*U
M&[-*M#*T03,%-+FT-,+],^6T-;4TM<ZC`]`G2U9+7DNCR_(?FB"YHHZ?=;79
M(UBU6;7$HL4BT:(!727=V2--M4ZU@C5;N]B@9BMX*X4UAC6(M7BU3+7)M7"U
MQFG(:45J<>I=NULU6[O9NV8K>"MI-88UB+5F*W@K:36%-8BU9BMX*VDUA36&
MM9T>BC5*;U#OG1Z)-4IO4.^.-4OO_1YLK[K9BS5+[Y6UGC6DUY.UV&4E:R9K
M*FLMZY0UI-=9X:RUJ;6WM;6ULK6MM8X>CQYULM*U=[7(M3%,3\P<+E^N82[;
MM=FU(<'XI@K23R-4(_:C^35"MF0A/S;@MIBV]C5"MH"V);9DMCNV1R/[MB:V
M&;<LML>V3K&HQOZU"K8/MJ3`,+8OMJRA`K9=-OBVZ+95:&_H]S7@MO8U^;5$
MMD.V2[9)MNRV@3;)ML2VB+:)MFFV/#;XMF"V7[;_M=^V6K:<MI(V(,67MOJU
M4S;)MJNV:D^@WU6V5K9TME9!5\%[-O-:&5S'98SF^+5NMD7%K3;--J7&AB.O
M(\:VUK;!MH*VI#:EQH8>K<>HME2VAB.D(Z\CIK89ME,V@;:D0&=!\T&^QZ2V
M$:2GMFBV]S4_MCVV4K9`/:Q,KVZT;KGN];;SMF8>/#9=MOJV^;9'(P>V_K;]
MMJ.AUB+7HAJ?Z-@7MQ:W#K8BMQ^W'K<;M^?0,BE-N7.B+[<N-U/80\@X.H^Z
M-K<UM^`A7[JZNTU9T6;<YBDZ"KM_N"RG9C<9.8:ZJ.#3N9VX`[B&GTFW2KFJ
MN6XXP\:1H!R>NBZ`-ZDWUS>E.`;KQN6Z+GXWJ3?7-Z6X=;D&-,NY8+DK'F`X
M#SDPN=M>]EYMW]/3!;I=N!ZZU[CJN@RXF+C6N+HN?C>`-]<WI;C-.9=C4^13
MN9^X\".O.AS0T#+ZMR>X-=(BN%FYNBY^-X`WJ3>EN,.ZN+K[MQLC_K=(J0$X
M>CANN@6X_[?0,K2WY;>)NALCZ;?YMY2X\S=Z.&ZZ9#?4NJXY8]/UMQFZ7SCG
MN-NZWCGSNM^XIC?HNJHZW[H$.Q>[.;I_,_*XTR%$L0JBS[>[MT,Z3\O8.2.Z
MB-D=)Q*[?[E3(]6Y4KA1N`ZY,3K[NJ&W"#CGN"L>DC</N4BZ:+F4NK^YUSE+
MNCJZG+KSN0&Z,[IO-\/&`[KS-P$X;KH&OT:W$3H7S/&Y<SG1N8%&@L8`N*>W
M8;>MM[HN?C>`-ZDWU[<B*2.I1C.1S:ZZ]KCDN1PYHKH>NP.ORSBQ.L`Z@<C*
M.+$ZP#J!R#:YJ+>CMPNX"KH(.%^X',I_,Q:XOKC"NI?(Z+E7'EB>6+@K'I(W
M8+CT1X?(6KE)M\`XHKK=NN>Y]KD/NS^Z8KJ2MV[4U;A:U&BW,BDLMZNW8KK5
MMQBYC[>&N6:Y9;EBN$/"G;H:GH4XT;F!MQ.Z4!X"ND*X%KNRN6&Y[+K:NO@Z
M!;M3PG(N>:X^M&FW!#ACTX6Y2KJ8X62XV;DH4)+CA+>JMX4X<[E@M_DY<+I3
M(TRX93A+NC<X([K'N9^ZNSI_S@JXL[KGNK^X(+D!N82X:+@BN=2Y:;A0'GVY
M>;B>M^6XT[J!.!?,P;I\N0>XHK<W.-BY0S<*NVLZSKJC.F+27#C[NFJX&Q[B
M(PD[PM4T-X^Z$;AFN$?/*[DP.$_+8;BTN64XU[DZMRTY5;DJ.LZZ\S<!.'JX
MU+GENM,Z8U)JTMZZJ;K]NDFW_;<T-SBZ-\QCN)@Z%]:7NF>X:[G:N<`X'+DO
MNH&Z#CC?NKRX\".QM\HXRSC`.H'(W[G@M]NYRCC+.+$Z@<@2NOFXW+?SH3#0
M*CIKNA`Z>;H#N!&[B+D)N!^Y?+H..*JZ<;K@N0RXI;>'N0JXB;D>NUPX,;J#
MN@\X%[N)N1L>XB,W.L+50S<INB2YU;H=)SZXA+D/.`2[P6`P:S'KPCCZNCI/
M/,_],5,[83MIZOT?WC`BVE^[4+M^L3Z[6+NFY#6[#-OY(P:F)[LB.V&[G"68
M,9FQ.[M;-8*U@;4DNR([4[MH.VF[93MINV4[:+M-H@L^@#^!OU)O?^^7'H$L
M5RUSNY<>@2Q7+7*[AB.O(W>[AB.O(W2[,"Y2+XC&>KMYN[$[LKL])W\[@3NA
MO#TG?CN!.Z&\+:D])WX[?SNAO*2[F+N>NZZ[B[NKNY*[K[N'NYJ[D[NANWP[
MLKM\.[&[QKM'L4"W\RB\N_,HN[O!N\`[[$%MVT+?M+L[(ZOAS[O.N[)0K-@V
MJ6+%V+O7NX.U[KL(O`/$W[O_N_6[9D*;P@R\X3L*O`B\![P7/",\@<`4/",\
M@<#PYBN\%#P7/('`++PBO"F\,[PRO#4\.KPT/#J\S!ZK(;"A-#PUO"\C62]:
M+]F^(K_;O%H\8;Q9/&&\63Q:O&^^=+QSO#:]LZ'XOHD\"\"(O*&\LJ'[O9V^
M/2=^.W\[@3N2O/T\I+]#P!J_'<#JO<2^(KY9O^P^!,P[YK*\L;S4OQ'GM:%Q
M'TO`3KROOMB_;:<[VID]VKVZH3.IJ;_=/B?`&,#\OPG`C#Y1/WK&HCRDOX>]
M5+^]H5'`5+]YO*K*\K9YO>B]^KT_OX:_7KZNOL&_++ZNOP@^W[^@)@_`^[X^
MOOB^P[]OO]R_Z#[Q/_6_H[^"/X0_$\"4OT.]PJ'#(5>H?+[^O`F^9[Z%4Y[4
MZCS:O>2_#CX&P(>_]KTCOW^_)KZSOAF^S+YDOY<_`,DROPL^@#^!/\>_!+_%
MH<FAL;]]OO/%Q*'J/)F]#+[`(42]IKQL*MN^>[[F)@H^%;Z>O06^1;V7O/B]
M-+Y./=^_B;WF)O4]%;YN.ZD]@#^!O^6]++^</0;`.+^@OV`MJCX_7$#<`;_F
M)O4]"KX+P/*^H[W/H:B\H;VKODN]![XP8$K@4;W1H4B]C+UDO/.]A;W$O6/`
MO#[5O^$^_[[:OTRB<+_ZOPJ_$;_\/%$_>L:UH]L_F=3&(=:AD;^?O&`M$SX_
M7$#<*;Y)O=T\8>"BO91!E.-_/M6_I[QMP*2]9=-WOR\C1[S^ONN]]SPGP.^^
M3D!40&?`1,"`/O^^!<#^O^N_9,!</?$_];]8P*:_JCP$S-Z^%[YD(YL_`L![
M/%*]4+W:OH`^X;X4OJ^]?+B'OHF^5<"DO$F\G[UY'GX>@9ZSP0V^1+^HO1"^
M1KV-Z#&_3,`@P!_`,L#PO_P\C#YZQ@$]+[VIO%P_\[];/_._IKU4O8.^)L#7
MOJ"];CNI/0L^@;]N.ZD]"SZ`OV<]A#\3P&<]@C\3P$>]G;V<OFF]I[VSOV0C
M]SX"P#[`VR'<H1&^8[VB//V\ZK[VO$V],L#`O9J_2KU3O:F]*$`LP!7`M;Q_
M/KR^WKR!/B_`E3Z9U%6]3CT(OIN]Y;Y-OUP]Z#[UOUL_7+]</>@^\;_*913F
MA;[ZO.2^9"/W/IN_XKZ</0Z^^[R(/!:^3[UG/8(_A+_2O_B\I;Q'OT:_=+_W
M/-V^T3\LP-$_*,#:OR6O2S^POYR_H[S@OG$?U;Q%O]\^5,!=P!*]WSY.P!._
MZ;Y/P'Z^YK[?OL6^22&7P,C!"F<;9TCGPTK(ROY`9-U^0-;`?4#6P.;!;,$4
M/!<\([P00BEB:N3-(]NCC\".P$DA;L!2P9?!+3;,-F=!\T&^QS)('TDNR?'`
M.<_>[CH>,L))02QC2N.^P0W"UT$;0B3"],!LP4R>?4!^P.W!6<%IP3Q!TL'!
M01?"],'9P?S!L<&OP,/`HL%[0&3=M^+>(55!B$&9P;+BGYXP0<3!9<'<P?[!
MS$'3P>"U,\%BP11!Q,$FP>=`TL%;X[Q`+&-*XV[!G,#>(0A!B$&9P9:VEK;?
MP"U!%=,5P<PVI$#S0;['YL"`0,K`4<%^087!=$&%P71!?L'>(0A!54&9P?O!
M9].V/I3CG<#>(0A!54&(P?W`[<".Z"N_NL&YP;W`Z$`7PA1!,,%OP!I!T\$>
MK/=(ILSG0#S!&D',P?#MPD`;0B3"Z\`6P;8E)=1_P,&[V\#,-J1`9T&^Q^G`
MC\'LP!C!`-#!P(G`Z$#!P<)`UT$DPL)`UT$;PHF>&[$Z'KK`*[4ZPC?"SI\2
M+!,L%*PLGHJN:KF)J)FH.LM8PE5"DTJ72KO*G+E.0I-*ETJ[RDW"7,);PH.K
M`CR;PA`?H*"ULGW"H$*GPG7"@L*!PE2IHL)FTP(\9L)Z0J?"BL)Z0J#"K<*L
MPM"C>MQ[7(O<P,)WPT'#-L.VPD@D@K+]PG[<*<-NPW##B=R'KVC#^<)%PVK#
M&<-$PSO##4.-W.W"R,(8PXVP:\-3UH[<^$*-W!]#=<-\P_["\,(.0W7#@,,_
MP\S";-R3W%_7>\.2W&;#<<.YPO+"*$-OU[C"\<+NPN'C5BEH*6RIF-R>[EG#
M6,-](7C#,L/LPN_"`T.!PWK#W<+>PC7#M],.0Q_#M\)](6/#;<,NPQ7#F]PA
MPVO#/%B<W)FI6Z.CQ+7$4L1JQ,]#=,3KSTO$L,3^PW+$1\2]Q`E$8$2BQ,[#
MS<.H0W3$.L3/Q#1$.<2=*]HK\ROVJRVGJ\2.1-3$/\24R+##[+MOQ,M#8$2B
MQ(-$R,2AQ(G$$41CQ!!$8\35YN%#.<3A0S3$T,/*Q/+#L\.NPYK#K\C+0PE$
MHL001!'$=L2AQ+G3F\,%Q,S$L<.H0\_#9,2FQ+C$#43(Q+_$#\3Q0]3$#D1H
MQ,M#"41@Q)'#=\3PPZ_#F<-XQ-`HNL.'Q`U$@\3:Q#S$<,31P]K$\4..Q,E$
MTL0!KSC/%<4,Q0%%/L\&Q?9$/L_WQ._$?"@62-K([L1"3TS/%R:0)AVL=+:G
M'B/%IQXBQ4Q*SU('UH$KS2O5*]<KW"OGJ_OFO9\B)SS%$B*#(I`B:T5UQ2(G
M.L5.Q5W%645QQ:*VJ1Y215U%7L45T#HH3<4Z*$S%/<5@Q:D>1D5=15[%1$5Q
MQ5FIJ1Y"149%4D5>Q:D>1D5215W%4<63I]6[9\5EQ6K%:,4[177%`J]$15G%
MX"."18E%BL6'Q3M%:\53KX7%3:C@(W-%B46*Q7I%AL6%Q73%X"-S18)%BL7@
M(W-%@D6)Q8]%"-Z.10C>9,9"QB?&6,8-QJS09\8RQB'&"\:P1F3G_L5EQG#&
MV<5BQM$D%B5>)0+&R<5&QB;&$\9'QCG1\T6[[LL]\D6[[F'&^L7YQ;3%T206
M)5XEUL5)QB[&"#%2QJ_%H<7JQ9&E'L8[QA?&KL5%QNG%G\5?QG'&!L:MQ3O&
M&$8ZQF[&;<:7Q?8JE+$DQNC%Z\4%Q@@Q"<9P1L/1H,5IQBK&],72Q6S&EL7'
MQ:S%7L9RQF/&/\8^QM[1R$551L/1*\9KQG7&=,;1(^@RI33\/(P^43]\1F9A
MEV&QX=R@T2-ZQHTX@L:-.('&C-PP+E(O>+N0QG,C?:/+W(O&FL;2(9'&H<:>
MQJ0VK;8?MK%%9.>ZQKA&N<83[[)&N<:R1KC&L<83[\C&;S=NN,W&P<8]3V)B
MM>27R,?&WL9I*'WNXT9\VV)4R]3<QN3&(,S7QL_&/:S11GS;V,9BHV%3+];_
M'B.@0L>_(R/.F,>66<;93K$?QQ[')L<EQR_'T\<K1X?'8,=1'A<?1MA7U%S'
M"<?PIE['O,=!QU#'-\=EQV3'J=GA(^&HP<>VQR_'GL?SSPW'DL>JQ]+'VL>@
MQX8>N+;9QX;'4<?,-J1`9T'SP87'F=2BQRS'L,>IQS;+YT<@VJ^?Y$<@VN_'
MZ\<7.8=(^,COR"S)/T@F27%BVV);Y*W(O,C'R([(?"@.1=K(:,AOR+C(CJ.J
MR-;(KD`?22[)*LDQR2O)_T<F27%BVV);Y`[)7,@QMZG(9,C]R-'(!,E!R%;(
M%\@2R<8GNDB[R!K(X,AX;GMN?.[*.,LXL3K`NA<Y],<9R17(]\/\)PXM7*WF
M)P`YS,;GR./(J2Q2+5.MJ.=5R"?(`,A9Q+TS*]YX;GSN',AN2+O(;DBZR`'(
M(,D2R%G(E>:'HRS(?"@.11;(=<B<R)O(]L?0P?3'Q.Y7R*>]6LAI9GIFJN9@
M)YRH0,AJR(W(KD`R2"[)P<C_1S](<6+;8EOD.L@^R/['KD`R2!_).\@[R3K)
MKLFTR:G)H<F6J97)V,FPR8[)1K.QR8W)A,D?RG_)JLEXR6_)3LE#R:&O0,F%
MR3S)8LEWR3_)XN;#R;:CO\D(RGI2N%(?5/I4W=5\S'2NS$E02J9GIV>=[\M)
M4$J=[R[*&-`)2K/,@\SJH^OH5<E-RC%*:LHMRF+*8,H^2C]*P57SU0[*7DIM
MRL;)U$FSS`7*NDRMU3I*2<KQN(#)3,KXR<W)\$EJRCO*3TIIRAI*2<HRR@%*
M/TK!5?/5`4H^2L%5\]733#?<5\J'3.#,&DHZRB9%(TK/4@?6[\DT:);H,TII
MRLM)S$F=[V'*0LH&2FW*_LE1ROW)<,HY:#IH/6B3Z#-*3\KP23'*M],&2E[*
M8\JN2L;*AJLQYHJKRLJSRL7*M<JO2K#*3D)50I=*N\I.0E5"DTJ[RL3*J<JZ
MRL?*G<H\O3#>X"NVRG=*QLJ12K#*D4JORHK*CLK@*ZW*I<I.0E5"DTJ7RG9`
MR,J<RHW*=TJNRJ;*=D##RH/*1ZGJ2D[<*Y^-;Y+O)AZA(':N]DKXRM^?O%H*
MW-9*3MS>2OC*WDKVRNK+Y,M-2[#+<R&RI$;+9\N-RXHAC"%'-59+7DNCRU.?
MQ$L#T^+'2T*+R^U+8,QIS+++%,O4V0M+L,LP.$.Z>LO)RT<U)TM>2Z/+!LR"
MR_/+Z<LYS(_+1S4G2U9+H\L5R^#+3,Q0R]3+/4Q63&3,X,LAS%G+YLOV`"H>
M"Z`ZRQ_+7<L:KEG,A*)'-2=+5DM>RP!,-M7+RUS,;LP>S"O,V\L+2TW+1<N"
MTC5+`].#U%'+)R.GRTRM(\P-S'S+1LRLRW%+?\L2S`/+ALM;2P%,;<S^RCQ+
M8,Q#S%O,;,Q7KUK+IDLVU>E+;<RJ/.R^6,O3RQ1,T=3ARQ%,T=1JS($X$;HK
MS*K+V<:`R]'+0J&K2QC,US5/S)"Z7,M^RQBN4DQ5S%_,[LO7RWG+US4QS%C,
M0,RN5>K50,Q^2V3,4$SDU9/+[\NHRT',/$OMRWY+5LP^RQ;,\<OI2P',J<L!
M)*7O],Q>Z,C)U<E%2N#,N<RD[L_N@U"%T/;,\LRUS/P?.^O0P88IG2DD*MK,
MWLSR-J]NM&ZY[N?,U$D)RJ3,B\P7RLG,W<QB9ZINJVZU;KKN,>F]S"SI0$HW
MW#OIABF=*20JI\S!S*K,14J'S$[IKLSB)N.FG<QTS)S,'1[Y3')-G\[X3)_.
M_LS"'QA.2TYKSI\B_\SZ3*#.GR+\S*K.H\ZFSJ+.H<ZESJC.J\ZYSK/.O<Z^
MSJ_.L,Z\SK'.BTVNS@LNN,ZGSK?.K<Y-3;3.NLZWS2[-RLVB3?C.3C(ES3).
MC4Z=3B?/QL["SL'.Q<Z[SLW.P,[+SM#.S,[(SB:OQ,Z7S<I.?><5KJG.DTW/
MSAW-U\[!SM/.IS1V3=W.BL[JS2=.YL[43K38WL[<SMK.JTW:3;].$,\OT]G.
MTL[6SH)-W\X='OC,V\YJ3MC.IS153=W.-LYM3A+8XL[1SG%-W\[ASN#.Z,[C
MSAC-Y,[ESD8SL;A,3<_.1<U\3N?.C$[M3N'<_,X-S]%-_\XL3?C.^\YD3=I-
MOTX0S_;.],[YSO[.LLY1ST-.]\[5(P#/::\CS;;.^L[NSOW.6T[PSNO.]<[R
MS@'/)\WOSN'-.S!@-.M-/<Y!SJ!-_\[63>K.\<Z#SM)-ZLX#SP3/`L]D3:M-
MOTX0S_7."<\.SQ3/S4T7SP%.&,\3V0S/%L\3SUK-.S!@-,]-/<X%SZS.$<\(
MS\/.#\\'S_31%4X*S^--&,]I3O/.)M09SR+/$L_)SB//_$T*SQ[/^TQ+3FO.
M&L\<SQ_/&\^_(PS',4ZUSEM-YLY,KAW/(<\ISR9.M<XO39U.)\^DSB;/=TV]
MZ17/)<\[,`,T8#3/3>O-Z<[0S;--]\YP3BO/*L]FSHY.EDZDSOM,&$YKSF%.
MX\XOS\?.+L\>'YB@^\\MS[W-U<Y-3N/."\^"SDC.!$[SSG5-V,[[3!A.2\YX
M32=3$M@P3\'G,\]%3BM/,L\TS\[.F4WGSB3/,<_;N63.U<VCZ"S/F$XUSU9-
MJ<Z:3>U.X=POS4I.EDZDSI).(,^/3B#/*,]-LDI.CDZDSHE.-<\&SR]-,DXG
MS_A,^<S^S`;-!<T"S31.2DZ.3I;.!\T$S1K-",U+38K.`,T)S>_-',T8S13-
M%<T7S;'-#<T=S29.,<ZXS1O-&<T+S2'--<T6S1#-$\UD3:M-VDT0SSK-,DU/
MS3'-],U$S3/-,,U4SD+-$,Y&S3S-0,TYS7G.3$V3S3_-@<UHS5#-7<U>3G;@
M<,U.S75-:LYFS6+-<\UAS:<T54UVS5[-<4V"S8;-@\UYS8E-34YASHS-C\U;
M32?.F4U\SHC-/L[23=;-OLV:38S.NLW+S;W-U,W$S01.:<ZMS;]-W,VLS;--
M0\XL3:+-K\VYS:/-G,V[S;#-H$W1S;3-Q\W9S=?-V,WLS9S.^<WRS=W-_$T5
MSF+.YLV>S=[-]LUD3:M-VDV_SO'-"\[IS>#--\[HS>'-XTT!S@G.&\X?SAW.
M*\X7SA[.CTZ2SBW."LX1SGW..<XUSB]-,DZ=SI/.+LY&SD5.<,Z(SEK.5<Y2
MSFY.P>=^SG#.;\YSSHE.F,X[3U!/=>1XH^C$L,`@.SS/-L\@.SK/RT9B8K7D
M]D0!Q19%3,\]NELGL"BU*-PH3L\614+/6R>P*+4HW"A(SS9/=>2R35)/4\]1
M3U//44]2SW`ER2:%SW!/>,]WSX,VH-]:3WC/AL^,(.%I@NJ`SV+/6D]PSW;/
MB$^*V:HA0JY7SW3/B$^)68K9@4^'3XE9BMF(THC2E\^1SY#/C,^ESZC/I,^C
MSY_/H<])GGLA"NFYS[9/N]&T3[O1KL_%3^3/Q$_DS^#/8)[YS_W/[,_&S\1/
MQ<^IP]K/^L^6Q]C/\<]93MSHV<__P3>U"-`'T`O0"M!*Q=#)L;<$Y2[0R=4L
MT,@YDN,GT"+0S+IST&6P0]"MWDQ0=U#$WG;0/-!^T$!0=U#$WGG0:%!OT",G
MJ:?[Y?LH?ZIF4&I0<-!A4&I0<-!44&_0==!A4&90<-!OT+\J)[%OT%10:%!K
M4&[085!F4&K0\*@XT"PD?=!IT$+00%!,4,3>3=`L)'302]";3(70FTR#T(C0
MA]"-JZ_0>%&3T371FM':T*/%K^J.4+O0MZ/3.ZS8&NFOT$[1:]$YT051!U$+
MT3<?D:&[4;W1^;.GT-VB6E@-ZR>W5M':T1M1`=[9T:#1!E$ZT<%0"]$#43K1
MP=`)T0C1P5`%T;[1TU'?4=+JS=$S46;1O]'@T3ND<U$+WNM0`=X'I>Z?,=$K
MT1@C$5%FT:'08=')T>Y%P-`#40;15]$.H,A1V-&#X;[0Z-`^T971H]$VT1@C
M$5$ST;_0=N]+Z!I1"]Z@4)/1J=&#T3#JR.J0T7W1@M'/T:!0>-%8T:30]M!?
MT=7L>]%-Z<1JT^JT3[9/QE"]T<90N]$-T1/1R]%51G#&2E'8T3C1P-$0T9%1
MU>H/4=_12E'(T>W0ZM#BT6_&#U'3T131W-%GHS2>\-'MT?O-\"-NIS_?#IYT
MH3X>&3/GM.>U:#,.T@W2$](0TA=2ZF+ZY!92ZF+ZY"CI9-(YTCM2:])FTEG2
MP;=*TBG2+E)KTC;2,=(ONGDZ:M(CTC#2>3ICTBY2.])QTL\F<-)V4G=24UQ4
MW'-2=U)37%3<<U)V4E-<5-QYTGC2QTFX4A]4^E3=U<#+BD^+SXS2B]))HXS5
M:M4&UK+2L=+'27I2'U2W5/I44U7=U0VB[]1"'@BB9M3VU:?3!]2\U.?2S"8F
M14Q*!U83UE'3XM+ATL[20*"R50O6D]/PTS5+Q,MY(3+3EM,BUB;52ZABP533
M;4X2V&7-.-1Y(0K32M.5TT;3GQ^FU=#2&-.$+HK3F-6BTUC5_=0TU$[5B-45
M5+K5ZD9I52_6!#BNN7?4SKZ6PI+!0=7.U<#4+=52U5+49-1O5*Q5Y=5&W%>S
M$-66/9[4A"Y8T_K21],.TPVE6M/+T@K4[M24U#74W].?U7)#:\I5U6G$+&VO
M;0[NDU3TU+[3O=-8U)RW7",4U;73!ZA.(PLM4-7]T@;5M2Y*5.W41=3,TK'3
M(-3QU&!3NM4`UC_6QTEZ4KA2^E3=U0S4S5:BU[8EW\$(SFW5J=4'GG]5_%40
MUEW3M-,PTUK5^=/VH[4N]%/MU&W30,?1TSFYD]761LO4;M/'THK57Z@TN6_3
M)=5DTQ75QLM&U6+5(]4>U1RTO%/TU+/3WC&5/ML_Q\>6/8738*\SU;C2S=)J
MTRVNUD9BU!%,%,S-U8K5.M9WU:/C0.JU+O132M2RT\'2#=2\4Y/4QTEZ4KA2
M'U3=U5S3C2GXJ?'3>]-*V%PCU-."U(S4B]1QU!'3:].\U3O5J-2[[B@CS]6F
M2P#,E-4>UOK5,M7Y56K;:-.'U$M5`M9*50+67M-.(^_3;-.XTKC36],\U(G4
M8=.<TB?4@-4$UO15"M;CU#%4_%40UG#57]-J5-_4E]+<J6#4-]7M)A*G6=.V
MTY\?4-,HU+!5#=9O4^75%\I43.K5]]6K50W6^5(+UF!3%=0OU0%*/DH_2O/5
M&Q[B(S<Z";L?(*,O)-#=U&G3*",UU1K6QTEZ4KA2'U3ZU#U61M98S&]3K-54
M3*[5`4H^2C]*P=5T50K6R-*OU3Q5:MLZU3%4?U40UAK42E5+U7+5IM(F14Q*
MSU(3UG15]-7Y4K+5JU6PU65JI>HQ5']5_-7/4@?6E[K3U3G5#]-PH>I&8=/@
MU-]51M8=U!2IWU4]UE4>7=9<UFZQ!\/F(02I?*1:5EO65U9;UE=66M9/UE4>
M3M;WHV;69=:/GGI6\M=OUN/7;-9HUX,KQ]9KUG'7UN9FUP;85=?[UY[7`=BA
M5\'7.=<OUT57-E@ZV(C7U-84V+K6C>P&U]36IM:#*W76,=@D5*+7!U@CV/;7
MF%:T5A;7`^\[V*?7Q-?ZUN_7A-<0V/'6%=>=7!W=+=BLUH+7^];4UGC72U<?
MV(S6B]9.ZY56-E@ZV']7!=C(U^S7(5<?V`W8@-8LPQ78?M9QUC_#>]87U[O7
M$=A'5P78O]<+U_/6EM:.UXW7^]<G6#G8@M:*UB14S=:4-9ZU[];.UWS7@->*
MUO#6Q]?&UTC7J-<HV`[8;M9)U_+6:];/UB'8#]B!5IC7@]9'5W_7?];.5B/8
M3M?2U_G7]-9^UWA-;4XGTYW68=<A5TO7^-?WL,Y6!]B95SG8S]<"U\K6E59%
M5SK8F5<GV)5615<VV.[6@T.<W$380MC!X5$>%Q\^QZ\D@*41U2^W8R586)SB
M#*3WK6,E5%B<XN'0:R->V'4F7UA3X+*A:R-;V'4F7%A3X&388]C<V#;C;]F>
MV.JCM=A6V<LJ'2O*V!C9$JYJ6<AGY.=NV-,[LM!RV?GN3]E=3>38?=C,V-W8
M8-D,V878M]CA6,SAX-AEV,78V=C/6,SA,]E=V;18,ME'V1)90]D'MRO9]=CT
MV#:B#:G\L,C8#]D.V>980]GES8;8.-E,V>W8Y-CBV&39&]FUGN98$MGEV!W9
M0K>OV'39A-CCV,;8--F<V$:T][1LV*W855E]V7399"-EHPTIJ:\XYSBXAT^(
M3XK9@4^'3XA/B=G!V0&OP]G$V9I9NEG)V919Q=F36<79#D?&V<?9D%FZ6<G9
MR]G-V<[9O5G(V7G'LI[*V<_9M]G0V<!9PMF\V;!9T=F--9!9FEG)V;;9IUG(
MV<S9LUG"V8O9LUG`V8[9C]F36939#D>6V9C9IUF]V9!9FEFZV:S9H=F_V:79
MIMFOV;+9M]E+R^]9]MFULO39Y]GXV>/9UUGVV=[9UUGOV>;9_5G_V?E9_]GY
M6?W9`5J@VP!:H-NBVZ/;H=NOVZ?;J-NFV[';K=NJVZO;6#*LV[#;OMJYV[;;
MO-OD1^?''R16IB.[P-NWV[O;O]OAG[[;N-MO6]';R=OL),/;RMOHO$E;P=ML
MVL+;9R3+VVHDDJ1MI+7;R-O2V\_;Q-O0V\?;SMO%V\W;B]N/I.G;XMOCV]7;
MWZO7V^?;/5K?V^';X-O8VVY;W=OEV^;;W-O9V];;U-O;V]/;.*E]VP3;UZ^D
MV_/;]MO>VY8P`K$`)?';[MOMV]K;Z]OLV^_;\-OUV_+;K%KTVZI:]-N`6_O;
M,:4!W/[;!]S]V^E*"MP:V@/<!-P&W`C<_]OWV^M:#]SDV_G;_-L%W+K;`MP`
MW`W<'MP=W/Q:%MP:6R7<Z-N-6Q3<&]P0W%S;S%H/W"\D&"53)50E7R79Y17<
M&-RSVY<V&=P,W+U;J.CXVQK<X%H6W/K;"]P2W!/<BMK,VP[<3+L<W"?<$=PA
MW"3<)MSA6B7<LMLBW"%;(]P@6R/<']Q&I8%;*MPLW'Y;*]SYI;3;*-Q\)!&F
M*=S7)"FF/%K!V[G;,MREVT*F6ULNW,;;+]PMW%9;+MSI6C'<:J8\5?G5828U
MW,&[<5K=VS-:T=NNVX2EDUNIVS3<I++JV]%&X\:)VBU;*]RM6OO;*ULJW)I;
M7MT)W-@C":E?VK0KO.'D6A3<QQZ06^#FCEO@YA?<<ENIVS#<-MR#6U[=(-PS
MW`!:`=H(V@+:`]J-VD_;$-H,V@[:<EN3VQ7:%MI8,A?:$]IPVPK:&-H2VAO;
M\=HSVT[:'=HEVC':&UI,V];:*=H?VO=:J.@MVBK:(]H\6DG;0=HVVE7:6]I8
MVU?:4-HTVCK:1MH%VU[:6-I4VE;:,UIOVU+:AMJ$VF;:?]IIVG#:?-J@VH7:
M==IQ6F[;E=ILVF[:;=IBVF/:S=IRVG/::]KBVF':>-NAVJ/:GMJ:VIXPI-JE
MV@`EF-JHVI':JEJLVJ;:DMK+VOC:S]K^VJU:@-O1VKG:LMK)VMO:L-K7VK_:
MPMK2VL3:MMK'VH7;Z4J\V@#;]MK<V@K;S%KKVN?:%-L!VP+;Y%J-V^W:X%K\
MVI+;[MJ7-O/:^MKFV@[;WMK=VBC;G-L6VQW;(%LAVQ?;X5H:VQG;$-LYVS[;
M*UN!VRU;?MLLVUK;5EM;VUG;E=M<VT[;GMMTVVO;EMM`2M/,B*P3/JH^0-P3
M/JH^/]QSTX*L,!Y07#MG2N?62NK*,!Y*7#MG2N=S4G92=U)4W'-2=E)W4E/<
M6MQ8W(?<B)XJPW;<;MRRPK3"E-S)PB;O9-SBPK3"@\;X0@W#"L,OPRO#?-Q/
MPW[#@T,\V/U6'=T>W5@DX20@W1_='3(BW2'=*]TGW2G=*MTOW2/=E2+J7"C=
M$"^S7##=+MTSW4#=$"^N7##=-=TLW7">-]TVW3G=--T[W3C=.MTRW4+=0=T_
MW47=1-T^W7DC9+`\W8[&$UU#W>1<,=U(W4K=OBO4W+XKT]Q'W4K=4MU)W0I=
M7MU0W4_=5-V:38Q.4]T2723=5B/RJ,Y<,=U+W57=E2*M7"C=3=TFW4S=1J!6
M73SH5]U-74[O6MU9W2W=6]U<W5<U)=T]W5C=7]U@W=M<7MU0(!==7=UAW6+=
M1MWB7"3=S5Q#W5'=3MU0(`M=7=UCW4/=_5:=W)[<H-Q8).$DG]RBW!TRH=RL
MW.)<$MU7-0'=[-RHW*U<ZMRIW*K<I]RVW/S<K]RKW!`OKERSW,Y<Y-S!W+#<
MO-RTW+K<N-R_W+O<P-R]W,K<!-W(W,3<LMS#W,+<S5P371S=Q]S%W!#=U=S1
MW-K<TES6W.;<[=SK7/=<3N\6W=[<W-P4W=G<X=S@W.?<]%P\Z/7<!=W[W/K<
M_=S^W%`@"UT7W8-;FEO;7`K=!]T(W0W=#]T;W7M`_L!LW6K=<=UPW9G=E=T?
M+"`LKFM[;)SLW]^"W8'=J-VFW7;===V1W8O=>M[#78W>LMVQW8G>.-ZO78W>
M3-Z2WOG?^MTIWA#>@MYZWE7>FM[EW8O>0*SK4!O1CD6/Q33>&E%ST8K>]=UD
MWO3=9-ZPR)/>D=ZLR@K>N]U/WGE>HM[$W43>H=YCWOC=^=]2WBA>*MZ*7I7>
M2UZBWJQ=]]VEWO;=A-Z#WKBHN-T,7G!>E=[[7:[FKUW#W:K>+][>W2S><%Z*
MWJK>^=VFWE'>2UYYWG_>G-Z/7IG>L]X]T,#>4Q_&7K5JU.JRWK'>K-ZOWD!0
M3%!WT%,?L%ZU:M3J9M]GWVC?FZ%JWVG?:]^9-_9>;=]OWTE?;-]?7W#?=]]X
MWRE?B-]QWYDWVUYMWW3?==]ZWW+?=M\57WO??-]<WX/?@M^!WX#??=]^WQM?
MAM\VWQE?A-\]L\P?A=_]7GO?$E^$WPQ?AM\Z7X[?B=^+WXW?5]^*WX??\%Z(
MWV[?C-]OWY'?C]\/WY/?'%^.WY#?DM^7WP;2L6?<9^SGPKN67XOCE=^8W^)>
M;-^9WW_?FM\AWP#?XUYPWY3?>=]SW\K>R][,WM+>T=[4WN)>2=^9-]M>]MXJ
MW]]>+=_C7E_?\M[[WF3?^-[YWOS>Y-[KWF+?^M[]7A7?_MX)WPK?3M\(WP??
M!=\#WQ)?&=\4WPQ?&]\FW_!>*=\=WR7?'M\LWQ_?'%\ZWS/?.]\OWSS?.-]A
MWT7?1-\^WT;?3=]4WYY?I%^MWYU?I%^MW^+E@S9JSP$OJ5^OWYU?GE^MWYZB
M`2^HWP$OI]\!+Z%?K]^NWYU?GE^DWZO?`2^A7ZG?G*&VW[7?NE^)8(K@N5^)
M8(K@?.`Y8%3@=^##W\+?Y-].X('@'2,`KDO@A.`9X#+@8.!5X"/@?UU%8'+@
MQM\(X(?@^*Z`KP/@A"^1+Q7@V";>)NPF^R[]+B7@X5U?WD,>_*YIX._?Y=]X
MX%S@4N`38%[@$F!>X(0OD2_SW]G?WM_8)MXF[";[+OTN]-^0X%2I.#Y*X&BD
MV]^^7U3@8."/X&J@;^#?7W+@IA]UH#@^,.#0W\??#N!U)EQ87]B^7SG@W=]Z
MX&7@"N`28!/@W%\ZX*^^6>`"X$'@WU]%X-7.P=\)X%?@O=_(W]C?Z=^Y7[I?
MBN"Y7[I?B>`[X";@'>8GX3KAJ^!1MZ;@%.'UX!+A-.&X(S!AH^;,X!T[,&LQ
MZ[W@TF#>X-_@-N$MX<Y@WN`&X<Y@TN#/X$CA%N'VX*[@Z.!A'@EA"F$5X3+A
MT^!A'O=@"F$5X6$>]V`)817AN>"LX&$>]V`)80KAY^"3X-'@N".[8*/F^."Z
MX-#@1N&=X$?AF"/E*-NN1^$WX3QA0N'FX".>E.&)X9^UEF&>X8OA>D:78;'A
M;&&[X>"E9V&[X:1AK.'%X</AN&'`X4S1E>%4X1_I8N&X)'GN2^&'X5UAGN%Z
M1F9AL>&\N1$>5^M=89;A<6&LX3LCR;MQ8:3A>D9F89?A?V'`X6=A;.&T*XS;
M?V&XX478?N%]X<`KH;/*8<OAR&'+X<AARN'/6.'8W"?$J)BCTF&%Y-%AA>3:
M8?MAAN2'Y(SD`"("HHKDB>2+Y--A^^'AX8CD<1Z"GMSA'V*3Y)#D8[*/Y)+D
MZ>)1(F,B<2*-(HXBDB*4(OSAE^2-Y)7DCN338=IAAN11(F,B<2*-(HXBDB*4
M(O#AK^2KY)CDK>2EY%MBQ>2:Y*#DG>1D8JGDI.2CY)'DGN2NY)YBI^3CX9_D
MF>2LY)ODJN2ZXXE`:N0X9,[D:&+,Y,CDMN3#Y+3DN>3-Y+#DN.3`Y+_DON25
M8NAB(60U9,'DG.2[Y,KDRN3)Y"@BQ^3+Y,+DM^2SY,;D!F+%Y+KD2./+1CU/
MM>0.8JGDLN0N8LSDO.2]Y/]'/T@F2=MB6^1S8U%D4F1LY,_D\.32Y.SDZN3V
MY//DW.3:Y./DZ.1$8NAB(60UY.+D[>1#9.ODO6+FY&,E5%A8V![BT>3WY/'D
MW^3UY.7DU>3OY-#D(F.QY'[DWN0*P>UB$.4'00#E".41Y0GEF^+=Y!+E#.6A
MY.3DU^0+Y?OD_T<_2"9)<6);Y`KE;V03Y8%CV.0$Y0/E%.5$8I5B(60U9`?E
M[V'3Y!92%U+ZY+-B$.76Y`;E`N7]Y$1D^.0-Y2_EHN0>Y54O,N,6Y2OE*>4:
M9-3D)>45Y1_E).5_8S'E[N0;Y2SE+>4<Y:UBL>0FY1KE(.4AY;Q`24%*XR+E
M&>55+P3C,.5HV(;D_.3HXQWE*.4JY93D-.5@8C/EO$!)02SC!>5`Y3?EX>26
MY$5!.^7_Y$5D/>4XY3+E&.4YY=-C*N4^Y71B46129&SD+N4VY1?EGV0ZY1GC
MX^)!Y3_E1>51Y43?+F1PY<@Y*-"V/I3!P6,!Y:JW2>4DY4CE0V42[ZCDY=0"
M9$_EX.3IY#SE4.6N8T?EK6-'Y5+E3>53Y4SE*.).Y9;C7N5?Y?[D1N59Y6#E
M7>5OX__D->57Y5CE6^4L(E<B=R+RY$U#7.56Y4+E_6,(Y3[C6N7GY&3E:N7E
M8PCEIF-/Y=GD].1CY?GD9N5AY0_EG^1KY0]CU.2!9&+E:.5$8I5BZ&(U9,'D
M#N4/Y43E3.6,8W#E;^5MY41BE6+H8B%DP>1NY2QBSN3;Y''EFF+KY/-B^.1@
MXVSE5.5T8G-C4F1LY'1B<V-19&SDJK=RY2?E?62[Y/]'/T@F27%BV^():5_I
M=.7$Y'/E**)EY8E`*>)T8G-C4612Y&?EW^*EY'7E=N4V3U#/2N5IY2/E6F2[
MY*[B_Z$=9&+E2^718=+ATV'[83?CU.'=X=CAU^'9X=7A]^'ZX>?AY.$2XNGA
MX^%&X_GA6N/UX0/B(^((XB;B1>(-XA3B(6)^8QAD.N4)XL?B_.(1XA#B!6)P
MY#V['N*BXPYB9.(GX@'B)>($XA7B`.(ZXJUB(N-FXE?B-^++1CU/8N(SXE7B
M/>(XXE[B1F):9'WD;.)MXD#B/^(^XD1B(60UY%'B-.)@Y`9B6^):XB@B2^(P
MXDGB1V)(XDWB+F)HXCGB+&(XY';BK.*@XGKBZ>(/8QKDJN+NXL_BX^(#Y(WB
M.N2%XL'BL>*FXJ?C6..6XI'BS.*IXIOB]>.3XJGC?^*:8D/D>^*8XAKCJ^)X
MXJ7B+")7(G<BW^.#X@ODJ.*`XJ/B\V)$Y!+D%E(74NKBV>(XX_'BR.->8]?C
MM^*6X_#BY>(A4.3B2^/OXNCBN6+E8_WCO.+=XM+BQ>+VXB;D%V0GY+-B[>*[
MXL/BW^+FXA+C!N-ZXVGC+^,HXQOC(>-`XP'C%>,IXROC+N-\Y!ACFN,0XR;C
M5>1!XPCC0V-OXP?C'^,@XW7C^.(SXQGC9>-(XT?CV.-VXU3C9.-LXWYCG^1;
MXZKC8.-PXX3C3>."X^3CH>,HY(?CS..M8Z[CF^.8XW?D@N2X8RODL^._XZ9C
M`N2LXXKCL..UXTSDXN/<X]WCS>/PX][CX>/1X\/CQ^/0XQ3D'62!Y!#D]^-E
MY!/D;>0@Y'GD^>,9Y$KD,^0VY#+DC&,NY#_D5.1CY%[D<>1RY.<>3R%X97_E
MYQY/(7=E?^5%'D:>YQY/(7=E>.7HY>GEZN7KY8EE[>7LY8=E[>4`K_;E\^6@
M9?#EDF7RY9%E\N7TY?7E^.7Y92?KCV7PY0+F<R'79=SE`>8(I`#FQ*3ZY?WE
M`^8&YO[ELF4%YK%E!>;#91+F"N9F(@GF#N8/Y@WF".8,YK1E$N9_MY>V\>7V
M/Q3F%>81Y@?F%^88YO_E%N89YN_E<R&B9=SEES4E:R9K*FLMZR\D&"53)50E
M7R7LVG,AHF77Y1KF$^80YI_?&^;\Y8#E@N6#Y8;EB.6'98GE3Z76Y8]EH.7(
MY9%EDN6.Y9/EE.6,Y;:PF.6992?KJ.5>T.7EJ>6MY=/EI>6CY:'EJ^4NZ[%E
MLN6LY<WEON5F(KGEMN4IZ[_EO>6[Y;SEX>7,Y;1EP^7@Y?8_RN7+Y=3ET.72
MY=7EWF4KZ^3E'>:18!SFBN:,'S1F<&:"YC-F?>8XYD<C7N9")X6L3R=OIU&G
M0*=]RB9F?>:,'R5F<&:"YF/F)BB.YBCFKKQH)T'F:"=`YIOF>.:TYG/F6.8%
MJ5QF769_YLBG2>959G_F5>9'(RGFCZ]F*#7F=^:;+/8LBRV,+;DMG6:OYI7F
M!DEZ9JKFC!\E9C1F@N9(YF7F1N8&26EFJN:4)QFH)F8SYE5F7.8P*)6HC!\E
M9C1F<.;>)R2H'^:7MB8H-N:HYEH>H&:QYM)(:.9>IY_F1>:;+/8LBRV,+;DM
M9F:OYIGF6AZ09K'FN".[8##AC^8&26EF>N9?)[.HB]Z;+/8LBRV,+;DM9F:=
MYEH>D&:@YICJ1^:W9KCFMF:XYK9FM^;)*TUG3F=/9[1M%FYD[NJCR^;CYNML
M".WQ(/CLO>;=YMOF0C?<YFLO,41P[7W6S*,;[L]FM>U"-]'FS>:/;<1M(>ZR
MK8Y;D-N[R;[F&[R1GD+G%^=!YQIG)^<UQ1IG)^<]Y_3N=4`;9TCGOKSVYOIF
M_F8GYW5`"F=(YR+G(>?Z9OYF&N=$YX?9,!Y*7%!<2N<!Y_?F\^8MY\>C=4`*
M9QOGQJ,P'DI<4%P[Y\DKNF9.9T]GM&T6;F3NR2NZ9DUG3V>T;19N9.[)*[IF
M36=.9[1M%FYD[L@K4N?(*U'G6N=R(2DI7>=<YU/G6>=R(2DI5.?&3&-GJFZK
M;K5NNNYBY[%%L,9HYR[H9>=M9W'G:V=Q9^?G:V=M9^?GON=&S8EG%^^`9Q?O
MM>>-YXSGZ:W#Y[WGN>?+2:?GRTFFYY_(R>=!7]SGW>>+YY_GDN=TYVY.,,^1
MYT.CG%CDYZ_GYN?GY_\MZ.?IY^KG05^Q9^SGLN?KYYQ8R.?+YVUG<6?,Y_\M
MS>?3Y]GGWN=!7]SG[N?MY_'G[^=/;U'O^^?UY\VD=>AVZ'?H>>AZZ'CH>^A\
MZ(+H@.B#Z(3H?>B!Z'_HA^B&Z#AHB.B,Z(GH)6B0Z"1HD.B/Z#!HBN@TJ6=G
MDN@L:(KHB^A.2I;HE.@::(CH:$HZ:#UHD^AH2CEH/6B3Z)'H]%Q6W6A*.6@Z
M:)/H[>J7Z&[1F.B=Z)KH5&B<Z)GHF^A/:)SH/C9OZ-^F/[&AZ%MHH.A::*#H
M>\R?Z*+H?NBDZ*7H/C95Z*;HA6C7:A7NGNBGZ`'H`N@#Z`?H!>@&Z`AH&NL*
MZ!'H9^@3Z`[H$N@,Z`_H$.AQ:-?J&.@7Z!IH..@AZ"QH,.@RZ!SH0;^RP2;H
M)&@EZ#OH+NAH2CEH.F@]Z#?H3DHTZ$;H3.A2Z$[H4^A/:%3H3>ASZ&+H6FA;
MZ%GH9>B'SFOH;.APZ'3H,![H(>PA[B'W6KU;S&C.Z-#HMVC&:,AHT>C2Z/"C
M+J+3Z*YHQFC(Z-3HS^C6Z-7HU^C$:-CHPVC8Z*YHMVC':,AHV>C&Z*YHMVC&
M:-KHZ"'L(>XAJ&C.Z#`>Z"'L(>XAJ&C,Z+KHK>BNZ*_HMNBXZ+SHN^C`Z,-H
MQ.C&Z,CHWNC[S]OHL"7@:&/IL"7?:&/I$.EEZ63I9NE7Z6CI:NG726OI"NEL
MZ?)H;NGP:&WI[^CN:&[I=.F=Z7+I<>EPZ7/I>NEXZ2!I?.E<9%]I=^E[(:I/
M[.AUZ5SI>>E[Z>'H?>DG:8'I?^F"Z7[I61^`Z;30A.F#Z6_IBN$%:7SIA>F"
M)1)I-6F!Z1A2ANG*S,?,9^E9Z8(E)^F)Z8?I9^F.Z=7,:>F(Z8_IBNF,Z8WI
MDNF0Z9'ID^F(Z93IL]'FS&7I=NGHZ#3I#>F+Z5QD"6EWZ97IL"7?:.#HX^CB
M:%'IY>@S:3GIZ>@\Z>KHZ^CMZ._H[FCRZ![I_NC]Z/SH_^CTZ`SI4ND):5_I
M!.D.Z0/I#^D%:2#I$>D6Z1/I61\8Z1)I)^D5Z1SI&^DAZ2CI-^D]:4OI-ND_
MZ5[I0>E#Z3KI/NE(Z4GI1>E*Z4SI8NGVZ)_IGNELZFWJKZ'$:6[J7>IPZF_J
M<NHVSF)J=.ISZK%I;NI;:G_J>C7(:45J<>IZ-<9I16IQZGOJ?>IYZG7J?NJ`
MZGCJ=NK>:7SJW6E\ZG?JC"!U3X+JB.J'ZG/J@^J&ZBYJ4>J.ZH_JB^J-ZI/J
MDNJ1ZI#J$VI7:HSJ-VJ:ZA!J5VJ,ZIOJE^J9ZE+JGNJ8ZO5I46J=ZG[1>NH2
M:IKJG^I'ZJ'JYM2<ZI;JH.JBZGHUQFG(:7'J.NJ%ZI7J@>JCZO5I+FJ=ZBCJ
MA.H0:A-JC.K*L,5I?^JRZ:3JOVETZJ?J#E:EZJ;J(KN*ZHGJK.FMZ;%IQ.FT
MZ;/I>C7&:<AI1>JYZ<%I[NF_:6+JU.G;Z=_IV>G2Z3;JT.G=:=[IT>G5Z<5I
M6^K8Z4WJC"!U3^'I\.E5ZDKJ\>GMZ>+I:^IJZ@'J$&H3:E?J`NKXZ?_I#^H.
MZ@WJ!>I,ZD+J&>JR9BWJ).H2:C?J%NI!ZBYJ4>HKZCCJ0^H^ZD3J3^I?Z@Y6
M9>IFZF3JKM!3'[!>QE[4ZJ#LN%'3ZL_J@-'6ZM7JQ>H/T;A1Q.I3'[!>QEZU
MZL]1S.K+ZG%HA6@5[MGJV.K_'G>O^>KOZ@)K(NO1(^[J/NC1(^KJY>I;'W^O
MY.I#HNEJ$VLBZWZWX=`":R+K>^@CZ^EJ`FL3ZQOKES78929K*FLMZY<UV&4E
M:RIK+>N99?GEQ*0+YI<UV&4E:R9K+>L:YI<UV&4E:R9K*NL$YAT[P6`QZQT[
MP6`PZSGK-NO\'Z7,+*Q8ZT[K/5=)Z_(A,BPT+#8L-ZP1'ISA1^M\['WL?NQN
M[+OK@.S_[H'L>&R(["3L@NQ_[(3LA>R&[-MKM^R,[(GLC^R'[/GKD.R-[(OL
MBNR2[)CLUVMV;)[LE>R6[+=K]^N4[)OLD>P?+"`L>UU[;)SLD^RJ[*=K]^N=
M[&;KV.NG[*#L`&RI[*3LRVNH[,KKK.R[[*_LK>R=:W;LONN):[?LM.RQ[+7L
MLNRS[+CLKNRP[+;LNNPZ[*=KMVO`[(_KJ^S*[,=KJ>S([)?LPNPH;+WLQ^P-
M;,7L#&S%[+[L=VS$[,;LP^PN;,'LTNS1[,OLI>QSZUYLS^P(;,[LT.S-[!OL
MHNS,;`?OT^S8[*;LH^SU:[GLU^S;[-3LR>S9[-7LUFP(;Y[OW^S=[-WLW.S>
M[)_LO.PE[([LF>SC[.'LXNR_[)KL8^O@[)UKUVN>[!!LQ.QR:XCLH>P?+"`L
M>UVN:YSL6NM;ZV+K=^MHZV_K=.MZZX'K@^N.ZW)K>.R+ZY/KDNN*ZZM6D>M?
M[(WKD.NMZYKKL^NJZY[KINL"[)SK8.QM[*OK'RP@+'M=KFM[[+KKG6MV[%CL
MOFK!ZWKL,>PY[,GK(^PW[,#KRNO':P#LMNO]Z]+KUNOJZ]7KZ^OAZ^3KY^O=
MZ^+K\.N):]OKZ.LZ[/3KU.M=[`CL#^QH[/?K&^P#[!/L$&QW[`QL#>P2[`GL
M`>Q"[/_K(.PR;`?O+>PH["7L*>P?[!SL,^P^[*112.Q);`CO.^PU[$7L/.Q6
M[%-L5.Q7[%+L;^QD[&?L8^Q,+!_NZR'L["#NP68([>?L).[DH2/N(N['YBGN
M*.[!9NOL=FTF[M=M)>XP[C7N,^X<;C+N+NY$;3'N*NXO[BWNNE.O[3CN.>[#
M[3ON/^[Z[3WN.NX\[A_M0.Y#[D;N0>ZJ[4CN7FU%[EUM1>Y$[DGN3.Y/[E#N
M3N[5YDKN"6TF[E/NI&U-[JMM*^Y1[E+NWF;$;2'N2^Y9[E7N5^Y6[G[M6^Y<
M[EGMAVTK[B?NNE,L[5_NR2NZ9DUG3F=/9Q9N9.[;YF#N8>Y8[F/N6NY:[F+N
M7NXS[=YFCVTA[L_MR>W([5WNQNUG[F7N#FTE[C?N:.XV[FKN5.YI[M7!:^[T
M;4?N\VU'[FSN<.X\;6WN-.X*[F_N_^UQ[KK3<NYQ:-=J+.[)*[IF36=.9T]G
MM&UD[G3N9N[:9G/N'>U"[C[N3"SE[.GLWF:/;<3M]NST[/+L#FW7[0EM=NVL
M[0?M!NTC[8=MJ^T5[BCM'NTF[1+M'^T=[1OM_>T5[>7MV>TO[3#M0NTT[4/M
M/^T>[COM4.U3[1WN4>U@[5UM7NU2[?-M].U<[6'M<NV3[6KM?NUO[6SM;NV)
M[8KM=^WK[9CMH>V:[;OMENV_;<#MI>VI[<KMPNVR[;GMNNW![;SMR2NZ9DUG
M3F=/9[1M%N[6[1KNT^W:[>_MYNWR[?CM^NT'[OGM#.X/[AON&.YD(W>H=TBQ
M2'SNN"2.X7[N=\AW2+%(>.YI*-#&>NZ%[J3N@^Z/[H?N/1YOJE##ETR$[J;N
MI>ZL;KCNQDQB9ZMNM6ZZ[L9,8F>J;K5NNNZI;KCN!:/R-JQ,M&ZY[O(VK$RO
M;KGNQDQB9ZINJVZZ[JENK.[R-JQ,KVZT[L9,8F>J;JMNM>[R1?-%--5('ALL
MA2Z][D@>&RR%+KSNQ.[Z2,/NS.[)[IC,TN[1[MGNV.[Q[DPIN<#V[NWN6J'W
M[O+NY.[;[NKN">?A[NGNKMC^[OWN;6L+[PSOV=8R;,SL26S6;)[O#>__[@+O
M">\1[P[OH>.W1KS&K*&`9XGG(>\@[X+<.>\T[\6EG1Z)-8HU4.^+-8ZU]UQ-
MW?)G4>^='HDUBC5*[_)G3^]O.W_O5.]3;X#O@>^"[X7O<.^'[X/OAN]B;X3O
M86^$[_JAB.]N)9DFTZ:LI'%OBN^)[UKO:N^+[VW1C.]O.U+O5.]5[U?O7^]A
M;V+O6>]@[USO9N]L[VKO<N]W[]Q*DF^9[Y"CGJ[<2HUOF>^:[YOOC6^2[Y3O
ME>^`'I_ORTG,25#*26P([X`>G.^*)(PDTK`!)'+,````````````````````
M```````$`/_______P4`!@#__P<`__\(``H`"P`,`/__#0#__PX`$``3`!0`
M_____Q8`&``:`/__'``=`"$`(@#__R0`)@`H`"H`+``M`"\`,0`T`/____\U
M`#@`.P#_______\\`/__0@!#`$0`_____________T4`_____T<`20#_____
M3`!-`$\`40!3`%4`__]7`%P`_____UT`________7@!@`/____]D`&4`__]G
M`&D`__]K`/____________]N`&\`__________]S`/__=`#_____________
M_____W8`=P#__________________WD`__________]\`/__@`""`(4`____
M____AP#__XD`B@"+`(T`CP#__Y``DP"7`)D`_____YL`__^<`)T`H0"B`*,`
M__^E`*<`JP"M`/__K@#_____________L`#__[(`__^V`+<`_____[@`N0"Z
M`+L`_____[P`_____[T`__^^`+\`_____\``P@#__\,`Q`#_____QP#)`,H`
M___+`/_____,`/__SP#1`-(`U`#__]<`___________9`-H`________W`#=
M`/_______]X`___________?`/_____C`/__Y`#E`.8`________________
M_____^@`_____^H`___L`.T`[P#P`/______________________________
M____________]0#_____________]P#X`/L`_`#]`/X`_P```0,!!@$'`0D!
M__\*`0L!#`$-`0X!_____P\!$0'_____$P'_____%`$7`?____\:`?__&P'_
M_________QP!________'0'__QX!__________\?`2`!_____________R$!
M__________\B`2<!__________\H`?__*@$M`?__+@'__R\!_____S,!__\T
M`?__________-0'_______________\V`?_______S@!__\Z`?__________
M__________________\[`3P!__\^`?____________\_`?__0P'__T0!____
M_________T4!_____________________T8!2`%)`?__2P'__TP!30%/`5`!
M40%2`5,!5`%5`?__5P'_______________]8`5D!_____________UH!____
M____6P%<`?__________70'_____7@'__U\!__]@`?____________]A`?__
M_____________________V,!9`%E`68!9P%H`?__:0%J`?__:P%L`6T!;@'_
M_V\!<0'_____<P%T`?____________________]V`7H!?`'_____?@'__W\!
M@0'__X0!A0'__X8!AP&)`8H!_____XT!C@&/`9`!__________^1`?______
M____________D@&3`?_______Y4!EP'__Y@!__________^:`?__________
M________FP'_____G`'_____G0&?`?__H`'__Z$!__^B`?____________^C
M`:0!__^E`?_______________Z8!__________________^I`:H!JP'_____
M_____________________ZP!__________^M`?__K@'_________________
M_[`!L0'__[,!M`&U`;D!O`'__[T!OP'``?__________________________
M_____\$!Q`'________%`?__________Q@'__\<!R@'.`?__T`'________1
M`=,!U@'__]<!V`'__]D!V@';`?_______]P!___=`?_______]X!X`'A`?__
MX@'__^,!___________D`?__Y0'__^8!YP'K`>P!________[0'N`?_____O
M`?________(!________\P'_____]`'________U`?__]@'X`?________D!
M___Z`?_____[`?P!___]`?__``+_______\!`@("__\#`O__________!`+_
M______________\&`@<""`+__PD"________"@(+`O__________#0+__PX"
M________#P(0`O____\1`O____________\3`A8"__________________\7
M`O____\8`O__________________&0+__________QH"__\;`AP"'0(>`O__
M__\?`O____\A`O__________(@+__R,")0(G`BH"__\L`BT",0(S`C4"__\W
M`O__.`(Y`CH"__\\`O__/0+_______\^`O_______S\"__]``D("__]#`D4"
M_____________T8"__]'`DH"3P+__U`"_____U$"__]3`O__50)7`O__6`)9
M`EH"6P)<`ET"7@+__V$"8@)C`F4"9@+__V@":@)K`FP";0+__________VX"
M__]O`O__<0)R`G,"__________]U`G8"=P+__W@"__]Z`GL"?0)_`H("____
M_X0"A0*(`HD"BP*,`HT"__________^.`H\"__^0`O____^1`O__DP*4`I4"
MF`*9`O__FP*<`O_______YT"__^>`O__GP*@`J$"_____Z("__________^D
M`J8"__^H`O__K`*N`K`"L@*T`K4"M@+__[@"_____[T"O@+#`L8"RP+__\P"
MS0+2`M,"___6`M<"_____]H"W`+__]X"WP+@`N$"___C`N4"Y@+G`O_____I
M`O__ZP+_____[`+__________^T"\`+Q`O________("\P+T`O4"________
M___Z`O__________^P+\`O\"`@/__P4#!@,(`PP##0/_____#@/_____$@/_
M_Q,#_____Q0#%0/__Q8#&0,:`QL#'`,=`QX#(`,A`_____\B`________R,#
M)@,G`R@#*0,M`R\#_____________S<#__\[`S\#0`/__T$#____________
M_T(#2@-,`TT#3P/__U`#__________]1`___5`-5`___70->`U\#__]D`___
M:`/_____________:0/_______]J`VT#_____VX#__]O`W`#__]Q`W(#>@/_
M_X(#A0.'`___CP.7`___________________F0.;`YP#__^>`Y\#________
M_____Z`#__^C`Z0#_____________Z<#J`.I`ZP#KP/_______^Q`_______
M______^R`___LP/_____M`.U`___MP.X`___N0.\`[\#___________!`___
M_____\4#R`/*`___S`/-`\X#___1`](#___5`___U@/__]<#___8`]D#___;
M`___________________W`/=`^`#___C`______D`______F`___________
MYP/_____Z`/J`^P#[0/________P`_______________________________
M____\0/___,#]`/___8#^`/___D#^@/___________L#_`/]`_\#________
M``0!!`($__\$!`4$"`3__________PL$__\,!`T$__________\/!/____\0
M!/____\1!!($__\6!/__%P3__QD$&@0=!"`$__\A!"($)`0G!"D$__\K!/__
M+00N!"\$________,03__S($__\S!#H$__\\!/_______ST$_____S\$0`1"
M!/____]#!$4$_____T8$2`1)!/__2P3__TP$__________].!/__4012!%0$
M6@1;!%P$__]=!%\$8`1A!/__8@3_____8P3__V0$_____V8$:@1K!&P$____
M____;01N!'`$<01R!',$__]U!/__=@1W!/_______WD$>@1[!(`$__^"!(,$
MA02&!(<$B`2)!/__C`2-!/____^.!)`$__^2!)0$EP2:!)T$H`2A!*($HP2D
M!/__I02F!*D$J@2K!*P$__^P!/__L@3_____LP2U!/__MP3_____N03__[H$
MO@3`!/__________Q`3_____QP3*!/__________RP3_____________T`34
M!/__U03________8!/_____9!-L$___=!/__________WP3__^`$___A!/__
MXP3_____Y`3__^8$___G!/__Z`3_____________Z03J!.L$____________
M_________^X$________[P3_____\03________W!/D$___[!/__________
M_`3___T$___^!/______!/____________\`!0(%!`7__P4%!@7_____!P4(
M!0D%"@7__PL%#`4-!0X%$043!10%%07__________________________Q8%
M%P48!1D%_____QL%_____________________________________QP%____
M_________________Q\%__________\@!?__(P7_____)@7_____)P7_____
M__________\I!?__*@4K!2P%________________+07__________RX%____
M_S`%_____S$%__\S!38%_____________S@%________.@4\!?__________
M_____ST%_____________________S\%________0`5$!44%1@5'!?__2`7_
M_TH%_____TL%3`7__TT%__].!?__407_____________________4@7_____
M________4P7_______]8!?_______UH%_____________UL%________707_
M____7@7_____________7P7_____8`7__________V$%8@7__V8%_____VP%
M__]M!?____]N!?__;P5P!7$%_____W(%________<P7_____________=`7_
M______________]U!?__________________=@7_____________=P7_____
M________________>`7_______]Y!7\%__^%!88%________________AP6+
M!9$%_____Y8%________F07__________YH%FP6<!:`%H07_______^C!?__
M_____Z0%__^E!?____________^F!?__J`7__ZH%__^K!?______________
M____L`7_____L@6T!?__________________MP7__[@%__^[!?__________
M________________O`6]!;X%P`7__\$%PP7%!?__R`7________)!<L%____
M____S07__\X%SP7________________0!=$%T@7_____TP7________4!?__
M___________________________5!?__U@7________7!?_____8!?__V07_
M_______:!?__VP7__________________]P%_____]T%_____]X%________
M________________________WP7________A!?_____B!?_______^,%___E
M!>8%___G!>@%ZP7________L!?__________________[07________N!>\%
M___________Q!?(%]`7U!?________8%___W!?@%___________Y!?______
M__H%^P7___P%_@7_________!?_______________P$&_____P(&__\#!@0&
M__________\&!@@&"0;_____"@8+!O_______PP&#0;__PX&__\/!O______
M____$`;_____$0;__Q(&%`;_____%P88!O__________&0;__QH&________
M________&P;__________QP&_____QT&'@;_______\A!B(&________(P;_
M_________R<&__\L!O__+08N!O__+P8P!O__,0;_____________,@;_____
M__\S!C0&-0;__S<&__________\X!O__________.08Z!CL&_____ST&____
M_SX&/P9!!O__0@;_____0P;__T0&__]%!O_______T@&2P91!O__4@;_____
M4P99!EH&__];!EX&_____V$&9`;_____90;__V8&;`;__V\&=`9U!G8&>09\
M!G\&@`;__X4&_____X8&__^+!I`&__^3!O____^8!O____^9!IP&G0;_____
MG@;__Z,&I@:I!O__J@:K!JT&_____[`&LP:V!O__________N`;__[H&__^[
M!KP&O@;_______^_!L$&________P@;#!O_____$!O__________________
M___'!L@&_____\H&_____\X&___/!O______________________________
M_]$&U0;6!O__UP;8!O_____;!O__W@;?!N`&Y@;G!ND&ZP;M!O_____O!O`&
M___Q!O(&\P;___________4&]@;X!OH&______L&___\!O_____^!O___P;_
M_________________P`'__\!!P('`P<$!________P4'________________
M!@<(!PD'"@<+!________PP'#P<0!___________$0<2!________Q,'%`<5
M!Q8'__\8!___&0?__QH'__\;!QP'__\=!________________QX'________
M__\@!_____________\A!___(@?__R,'________________)@<K!RP'____
M______\M!RX',`?__S$'__\S!_____\U!___________-@?_____________
M_____________________________S<'__________\X!SL'__________\\
M!ST'__\^!S\'0`?_____00?_______________]"!________T,'10?_____
M1@?_______]'!________________T@'__]*!_____________________],
M!T\'40?_____4@?_____________5`?_______________]6!___________
M6`?_______]9!UP'__]=!___7@=?!V`'80?__V('_____V,'__]D!V4'____
M______]F!___9P=H!___:0?__VL'_____VP'__]N!________________V\'
M_____W$'__]R!___=`?_____=@?_______________________________]Y
M!WH'__][!_____________________]\!WX'?P?__X`'_____X('__^$!___
M_____X4'__^'!_____^*!________________XL'C0>/!_____^4!___E@>;
M!___G`?_____G0?_____G@?_____________GP?_____H0?_____H@>D!Z4'
MI@>G!___J0?_____J@?__________ZP'K@>O!___L`?__[4'MP>X![D'NP?_
M_[P'O0?________`!\('________PP?%!\<'R`?)!\L'___-!\\'T0?3!]0'
MU0?7!]D'V@?_____W`?__]X'___?!^$'___B!___Y@?H!______I!___[`?_
M_______M!^X'________[P?___$'\@?S!______T!_4'___V!_@'___Z!___
M______L'______X'_P?__________P`(`@@#"/__!`C__P4(!@@'"/______
M_P@(_____PD(#`C__________PT(#@C_____#P@0"/_______Q$(________
M$@C__Q0(__\7"!@(_____________________________QD(__\;"!T((`@C
M"/__)`C__R<(__________________\H"/__*@C_____________________
M_____________RP(,`@R"/__,PC_____-`C__________S8(________-PC_
M____.`C__SD(__\Z"/____________________________\^"#\(0`A""/__
M_____________T,(________1@A("/______________________________
M____2@C_____2PA,"$T(__]/"/____]0"/__40C__________U((__]3"/__
M__]4"/____________]5"/_______U8(6`C_____6@A<"%T(__]>"/______
M_________________U\(_____V$(_____________________V((8PAD"&4(
M9@C_______________________]G"/____________]H"/____]J"/______
M_VP(__________]M"/__<0C_______________]R"/__<PAU"'8(>`C__WD(
M__________________________]["'T(@`C_________________________
M____________@0C_____________________________________________
M__^""/____^#"/____________^%"(8(__^'"/_______XD(B@B-"(X(____
M_________________X\(__________________________________^1"),(
M____________________________________________________________
M____E`C_____E0C_____E@C__Y<(_____________________YD(________
MF@B;"/__G`C_____________________________G@C__________Z`(__^A
M"/__H@C_____HPC_____________________________________I`C_____
M_____________________Z4(________I@BG"/_______ZD(JPC_______^M
M"*X(_____[`(__________^Q"+((__^S"+0(________________________
M________M0C_______^V"/_______[@(N0C__[L(_____________[P(____
M_[X(_____\`(___#"/__________Q`C%"/_____________&"/__________
MQPC_____R0C_____________S`C_____________S0C."/_____________/
M"/_______________]`(_____________]$(________U@C7"/__________
M_____________________]@(________W0C>"-\(X@C__^,(Z0CJ"/_____M
M"/__[@C__^\(______`(______$(______________________________,(
M]0CY"/L(_0C^"/__________________``D!"0()_____P,)____________
M_P0)__\&"0<)________"0D*"0P)#@G__Q`)_____Q$)_____Q()$PD5"1<)
M_____QX)'PG_____________)0G__R8)__\L"?____\R"38).`D^"?__/PE`
M"?__0@G_______]#"44)__]+"?__30E/"?_______________U$)__]5"58)
M_____UH)__]<"5T)__]>"6`)_____V()_____V0)9PEH"6D):PG__VP)__]M
M"6\)________<`ES"78)________>0EZ"7L)?`G__X`)@PF$"8D)__^."9$)
MD@F4"94)E@G__YD)__^:"9L)G`G__________Y\)__^D"?__J0FN";,)____
M______^T"?____^W"?__N0FZ"?__NPF\"?_______[T)__^^"<`)P0G""?__
M_____\0)___________________%"?_____'"?_____("<D)___*"?__RPG_
M_\P)________S0G_____________________________________________
M___."<\)T`G4"?_____5"?_____7"?______________________________
M____V`G9"=H)___;"=P)_____________^,)___________________D"?__
M_____^H)_____________^L)[`G_____________________[0G__^X)____
M____[PGP"?__________________________________\0G_____________
M______________()________\PG___0)]0GV"?<)___X"?D)____________
M__H)^PG________\"?T)``K_______________\'"O__________"`H)"@H*
M_____PL*#`K_____#0K__P\*$`K__________________Q,*%`H5"A<*____
M_________________QD*________________________&@H;"O__________
M____________________________________________________________
M_________QT*________'@K__Q\*(@K_______\E"BD*__\L"O__+0HP"O__
M__\Q"O____________________________________\S"O_______S0*____
M______________________________\U"O__-@HW"O____\X"O_______SH*
M00K__________________T@*_____TD*_____________________TH*__]+
M"O__________3`I-"O____________]."O_______T\*4`I3"O_______U4*
M6`I?"O__8`IA"O__________________8@ID"O__________9PIH"O______
M______]K"FP*;0K__VX*<0K_______]T"O__=0K_____=@K__W<*>`K_____
M________>0K_____________>@I["O__________?`K__WT*_____WX*?PK_
M_X$*__^""H0*A@K__XD*__^*"O____^+"O____^,"O_______XT*C@J/"I`*
M_____Y$*_____Y(*__^3"O__E`K_____________________E@J7"ID*____
M____F@K__YL*G`J?"J$*I`K__Z4*_____Z8*__________^H"JD*J@K_____
MJPK__ZP*K@K_______^O"K(*________M`K_________________________
M_[4*M@K__[<*__________^Z"O__O`K__[T*OPK________________!"L0*
M_____________\4*___("O__R0K/"M`*T0K3"O_______]0*U0K__]@*___:
M"MP*W@KB"O_______^,*_____________^0*Y0K__^8*YPK__________^D*
M___________J"NL*___________________M"O_______^X*____________
M____________[PKS"O________0*^0KZ"OL*___\"O___0K_"@`+________
M__\""_____________\#"P0+!@O_______________________\("PD+__\,
M"___#0L/"Q$+$@L4"_____________\6"Q<+__\8"________QD+_____QP+
M__________\@"_____\A"R<+*0O_____+PLP"S<+.`LY"___________.PO_
M____/`L]"SX+__]`"T,+1`O__T4+_____________________________T8+
M__________]'"TD+________2@O__________TL+________3`O__TT+__].
M"___3PM1"U(+4PO__U0+__________________]6"___5PO_______]9"___
M6@O__UL+7`M="V`+8@MC"___9@O__V<+:0MK"VX+<0MT"W<+>`O_________
M_WH+>PO__WP+?0O__WX+?PO_____________@0O__X(+_____X,+________
MA@O_______^'"XD+BPO__XX+CPO_____D@N3"___E`O__Y4+_____Y8+__^7
M"___F@O__YP+_____________________YX+__^@"Z(+__^C"Z4+________
M__^F"_____^H"ZL+_____ZP+K0O__ZX+L0NS"___M0O__[@+____________
M____________N0NZ"___NPO__________________[P+O0O_____________
M_____[\+___`"______!"______________#"\0+________Q0O__\8+____
M____________R0O__________\H+_____________________\L+___,"\X+
MSPO0"]$+T@O3"___________________________________U`O__]4+____
M_________]8+UPO_____________V`O__]H+___________;"___________
M_____]P+________________________WPOD"______E"_______________
M_^8+___________G"________________^@+Z0O_____ZPO_____________
M___________L"^T+_____^\+\0O___________(+________________\PO_
M__4+]@OY"_H+___^"_\+``P!#`(,!`P%#`8,"`S__________PH,________
M__\,#!$,__\2#/_______Q,,__\4#/____\5#/__________________%PP8
M#/____\9#/__&@S__QT,_____Q\,(0PD#"4,)@S__R<,________*`PK#"P,
M+0S_______________\N#/_______________________________S`,____
M______________\R#/____________________________\U#/__-PPX#/__
M.PS__SP,__\^##\,0`S__T$,0@Q##$4,1@S__T<,20S__________TH,____
M____2PQ,#/____________]-#/____________]/#/__________________
M__]1#/__________________4PS__U0,50S_______]6#%<,_____U@,__]9
M#%H,_____________________________UP,70S_____7@S__U\,_____V$,
M8@QC#&0,_____V4,__]G#/____]H#/_______VD,__]J#&L,_____VX,____
M____________<`QQ#',,__________]U#/_______W<,>`S_____________
M>0QZ#/__>PQ\#/__________?0Q^#/__?PS_____________@`R"#(0,A0S_
M_X@,B0S_____B@S__XL,_____XP,_____________XT,C@R1#/__D@S__Y0,
ME@R7#)H,G0S_______________________^>#)\,________H@S__Z,,____
M_Z0,________I0S_______^F#/__________IPS__________________Z@,
M________J0S__ZH,_____ZP,K0S_____K@RP#+$,__^S#/______________
M____M`S__[4,M@S_______^W#/____^X#+D,N@S_____________________
M__^[#/__O`R^#+\,P`S"#/__PPS__\0,Q@S'#,@,R0S_____________R@S+
M#/_______\P,________S0S__________\\,_____]`,T0S__],,U0S__]8,
MV`S__________________]D,VPS__]P,_____]T,___>#.`,X@S__^0,____
M____Y@SH#.H,[`S__^T,[@S___`,________________________________
M\0SR#/,,]`S_____]@S________X#/__^0SZ#/_____________\#/___0S_
M_____@S_________#``-`@T$#04-!@W_____!PT(#?__________"0W_____
M__________________________\*#?_______________PP-____________
M______________________________\-#0X-#PT0#1$-$PT4#14-%@W__Q<-
M&`W_______________\9#?____________________\:#?______________
M_________________QT-_____QX-_____Q\-_____R`-________(0TB#?__
M__\D#24-)@TG#2@-__________\I#2H-*PTL#2T-+PTR#3,-__\T#34--@TW
M#3D-________________________________________________________
M.PW_____/`W__ST-_____________S\-____________________________
M_________T$-1`U%#48-1PU(#4D-2@U+#4P-30U.#4\-4`W_____________
M________________________40W__U,-_____________U0-50U6#?__5PW_
M_________UH-________________70W__UX-__________________]?#?__
M________8`W__V$-8@W__V,-9`UE#?__________9PW_____:`W_____:0W_
M______]K#?__;0W__________________________VX-________<`UR#?__
M_____________________________________________W,-__]T#?__=0W_
M____________=@W_______]W#?_______________W@-_____________WD-
M>@U[#?____]\#7T-__]^#7\-@`V!#?____^"#?______________________
M____________________@PV$#?__________________A0V&#?__________
MAPW_______________________________^(#8D-____________________
M______^*#8L-_____XT-__^.#8\-D`V1#9(-__^3#98-________________
MEPW__________Y@-__^9#?__F@V<#?__________G0W_________________
M____________GPW__________Z`-__________^A#?_______Z(-________
MHPW_______^E#?_______Z8-__^H#:H-JPVM#:\-__^P#?______________
M_[$-__________________________^R#?____^S#;0-________________
M_____[<-_____________[@-________N0W_____N@W__________[L-____
M______________^\#;X-________OPW________________`#<$-P@W__\,-
M___________$#?__Q0W__________\8-___'#?__R`W__\D-RPW,#?______
M_\\-________________T`W2#?__TPW__]0-U0W6#=D-V@W_____VPW<#?__
MW0W_____W@W_____WPWA#?__XPWE#?__Y@W________G#?_____H#>D-____
M_______K#?_______^T-___N#>\-___P#?__\0W___(-___________U#?__
M___V#?<-^`WY#?__^@W]#?___@W_____``X!#@(.`PX$#O__!0[_______\&
M#@<."`[__PD.__\*#O__________"P[_____#`[__PT.__\.#O____\/#O__
M$`X1#A,.__\5#O____\6#A@.&0[_______\:#O__&PX>#A\.____________
M______\A#B(.(PXD#O_______________________________________R4.
M*0XL#O____\M#BX.,`XQ#O____________\R#O__-`XV#C@.__\Y#O____\[
M#O__________________________/`[_______________]!#O__________
M0@[__T,.1`[__T4.________________20Y*#DP.__]-#E(.__]7#EP.8`YD
M#F8.:`YI#O__________:PYL#FX.__]O#O_______________W0.=@[_____
M__________________]W#O____]X#GD.__________]Z#O____][#O__?`[_
M_________WT._____________________________X`.@0[_____________
M________@@[__________X,.A0Z'#O__B0[__________XH.__________^+
M#O__C`[_____C0[_____________________________D`Z2#I4.E@Z8#O__
M_____YD.F@[_____FP[__________YP._____YX.________GPZ@#O______
M_________________Z$.H@[__________Z,._____________Z0.I0[_____
M________I@ZG#O__J`ZI#O__________________J@[_____JPZL#JX.KPZQ
M#O____^S#K4.M@[__________[<.__^X#O_______________[D.N@Z\#KT.
MO@[_______^_#O_____`#O__P@[##O_______\0.________Q0[&#O______
M____QP[_____________R`[________________*#O__________RP[,#LX.
MSP[__________]$.T@[_____________________TP[________4#M8.VP[_
M_______<#O_____________=#O__W@[__^$.Y`[E#O_____F#O__YP[_____
M_____________________^D._____________________^L._____^P.___M
M#O$.___R#O_____T#O@.___Y#O________________H.________________
M______L._`[___________________X._________P[_____________``\%
M#___!@______!P\*#PL/#`___PX/#P___Q`/__\1#Q,/________%`______
M________________________________%0\6#___%P___Q@/_____QD/&@__
M____&P___________QP/__________\=#Q\/(`\A#___(P______)`\F#R</
M________*`______________*@___RL/+@______,`\Q#___,@__________
M_________S4/_____________________________________S8/-P______
M.`\Y#SH/__\[#SP/_____________ST//P]`#_______________________
M_________T$/1P](#TT/_____TX/__________________________]0#___
M__]1#________________U4/_____U@/__]9#_____]:#UL/7`___UT/7@]?
M#V`/80]F#VD/__]J#________VL/_____VX/________________<`______
M________<0___________________________________W(/____________
M_W,/__]T#___________>0________]Z#___________>P________]\#___
M_____________WX/_____W\/__^"#________X,/A`^&#___AP^(#XH/BP^,
M#___CP^1#Y,/__^4#Y4/EP^8#YH/FP___YT/GP___Z$/__________^B#Z0/
M________________I@________^G#___________J`__________________
M____J0________________^K#ZT/_____________ZX/________L`______
M__________________^Q#___________LP^T#_____________^U#_______
M_[8/N`___[D/NP^^#[\/P`_!#\(/Q`_%#\8/QP_(#________\D/________
M___________________+#\P/___/#______0#___T0______TP_4#_______
M____________U@_________________8#________]D/___________:#___
MVP______________W`_A#___________________________XP__________
M_________________^4/___F#^</Z`___^H/___K#______________L#_`/
M________________________]`_U#_8/___________________W#_______
M_______X#___^0_________________________[#_P/_________@______
M_P________________\`$`$0__________________\"$/__________!!`%
M$/__________________"!`*$`L0_____PP0_____PX0#Q#__Q`0__\1$/__
M_____________Q(0__\3$/____\4$/_______Q40__\6$/____\7$/______
M____________________________________&!#_____&1#_____________
M&Q#__QP0________'1`>$/____________\?$"`0________(1`B$/__(Q#_
M_R00)1#__R80_____________R<0__\I$/_______________RH0*Q#__RT0
M__________\N$"\0,!`Q$#(0,Q#_________________________________
M______________\U$/_______________________S80__\X$/__.1#_____
M__\Z$/_______SP0__\]$/__________________/A#_____/Q#_________
M_________T`001#_____0Q#__T00________11#__T<02!!*$/__3!!.$%`0
M41!2$/____]4$%405A#_______]7$/____]8$%D0____________________
M_UH0__];$/____]<$/____]=$/__________________7A!?$&$0__]B$/__
M________8Q#_____________9!!E$&<0:!#_____________:1#_________
M_VH0__________]K$/____________]M$&\0__________]Q$/__<Q#__W40
M________=A!Z$'P0?1#_____?A#__W\0________@!#__________X(0__^#
M$(00__________________________________________________^&$/__
M__^'$/____________________^)$/____^+$/__CA"/$/______________
M____D!#_____DQ#__________Y00__^5$/____^6$/____^7$/__________
M__^8$)H0________FQ#_____G!">$/_______Y\0H!#__Z$0_____Z(0I!#_
M____________I1"F$/_______Z@0J1#__ZL0__^O$/__________L!#_____
ML1#__________[(0MA"W$+@0__________^Y$/_______[H0__^[$/______
M____O1"_$,`0___________!$,(0___#$,00Q1#_____________QQ#__\@0
MR1#__\H0___+$/_______________\P0___________-$/__SA#/$/__T1#_
M_______________2$-00________U1#9$/__________VQ#__]P0W1#_____
M___?$.`0_____________^(0Y1#__^<0___I$.T0\!#_____\1#_________
M__________________(0______,0______________00___U$/80________
M___________________________W$/__^!#___H0______L0______T0__\`
M$?____\!$?__`Q'__P01__\%$?_______P<1_____PD1"Q'_____#1'__PX1
M$1'_____$Q$7$1L1_____QX1(1$D$241__\F$?__*!$L$3`1,1'_________
M____-1'_______\V$?_______________S<1.!'__________SD1__\Z$?__
M_____SL1_____SP1_____ST1________________/A'_____/Q%`$?__01%#
M$?__11'_____1A'_____1Q%($4H1________3!%-$5`1________41'_____
M4A'__________U0151'_______]6$5@161'__UH16Q%<$?____________]=
M$?__7A'__________________________U\1__]@$?_______________V$1
M________________________8A'_____8Q'__________V419A'__V@1__]I
M$?__________________:A'_____;1'_______]P$?_______________W$1
M<A'_____________=1'__W81=Q'_____________>!%Y$7H1?!'__WX1____
M_X$1________________________________@Q'__X<1__________^($?__
M________________________B1&+$?_______________XT1_____X\1____
M_________________________________Y`1D1'__________Y(1DQ&4$?__
M_____________________________Y41EQ'_____________________F!'_
M______^9$9H1__________________^;$?__G!&A$:,1I!&E$:81IQ&H$:D1
MJA'_______^L$?____^M$:X1_____Z\1_____________________[`1____
M_[$1__________________________________________________^R$?__
M__________^T$?__M1&V$?_______________[<1_____[@1__^Y$?______
M____NQ&\$?____________^]$;X1P!'__\$1PA'#$<81R!'_____R1'_____
M_____________________\H1_____________\L1____________________
M_______________________________________________________,$?__
M_____________\T1_____________\X1________SQ'_____T!'1$=(1TQ'4
M$=41UA'7$=@1___9$=H1W!'>$=\1X!'A$>(1XQ'________________D$?__
M_____________^<1________Z!'__^L1____________________________
M____________[!'_____[1'_____________[A'_____\!'___$1___R$?__
M___S$?________________________01______81___X$?D1^Q'\$?T1_A'_
M$0`2`1("$O__`Q($$@82!Q+_____________"Q+_____________________
M#!+_______\-$O_______PX2________#Q+_______________\0$O______
M_________Q$2__________________\2$O__________________________
M%!+_____%1+__Q<2&!+__________________QH2__\;$AX2__\?$O__(!(A
M$O_______________________R(2__\C$B02)A(G$BH2+A(O$C`2__\R$C,2
M__\T$C@2.1(\$CT2__\^$O__/Q+_______________]`$O_______T$2____
M_T(2_____T,2__________________]$$O_______T42_____________T<2
M_____________________________T@2____________________________
M______________________])$O____________________]*$O__________
M________2Q+_____________________________3!)-$DX23Q)0$E(25!)5
M$E82__]7$O__6!+__UD2_____UH2________71+__________UX28!+_____
M________8A)C$O_______________________________V02:!+_____:1)J
M$O_______VP2_____VT2_____________V\2__________________]Q$G(2
M________________<Q+__W02_____________________W42__]V$G@2>1+_
M_WH2?!)]$H`2@1*#$O__A!*%$H82__^'$HH2BQ+__XP2_____XX2_____X\2
M__________^0$I,2_____Y42_____Y82EQ+__YD2_____YH2__^;$O______
M_YP2________________G1+__YX2________________GQ+_____________
M_____Z`2H1+_______^B$O_______Z42IA+__________Z<2J!+_________
M____J1+_______________^J$O__JQ+_____K!*M$JX2KQ+_______^P$O__
ML1+_______^R$O____^U$O__________MQ+__[@2NA+_________________
M_[P2__________________________^]$KX2________OQ+_____P!+_____
M_____________\$2PA+&$LH2___-$O__T!+1$O______________________
M_](2_____],2_____]02_____]42UA+9$O_____:$MP2_____]T2WA+__^`2
M_____^$2___________B$O__XQ+D$O__Y1+_________________________
M_________^82___G$O_______^@2________________________Z1+K$O__
M[!+M$O_____O$O__\!+R$O02______42___________W$O______________
M__@2___________Y$OH2___]$O___Q("$________P03__\%$___!A/_____
M__\'$_____\*$PL3_____PT3__\.$________Q`3________$1/__Q03____
M_Q43__________\6$___%Q,8$_____________\9$QH3'!/_______\>$___
M__\@$R$3__\B$_____________________________\D$___________)1,F
M$________________R<3*1/__RH3+!/__RT3_____RX3,!/_____,1/_____
M_____S(3_____________S,3-!/_____-1/_____________-A,W$SD3____
M_________SH3/1/__________S\3__]!$T,311-&$T<3________________
M__]*$________TT33Q-0$___________________41/__________U,35!/_
M______________]5$________________________UH371->$___________
M__________]?$V`3__]B$V43________9A-G$VH3________________:Q/_
M_________VP3________________;1/__________V\3________<!/_____
M__________]Q$W(3=!-V$___=Q-X$WD3________>A/_____>Q/_________
M____________?!-]$_____________________]_$X`3__^$$___________
MA1/__________X83B!.)$___BA/__XL3________________C1/_________
M_XX3________________CQ/_____D!/_____DA/_____________________
MDQ/_____________________E1/_______^6$___________________F1.:
M$_____^;$Y\3H!/__Z$3_____________________Z(3_____Z03__^E$___
MJ1/_____JA/__ZP3_____________ZT3________________________KQ/_
M______________^Q$_____^S$________________[<3_____[@3__^Y$___
M__^[$___O!/_____________________P!/_________________________
M____________P1/"$\,3_____________\03Q1/________&$______'$___
M___)$________\L3________S!/__\X3___/$___T1/3$___U1/__]83___9
M$______:$______;$________________]T3_____________]X3WQ/_____
M________X!/D$________________^43YA/__^<3Z!/_________________
M_________________^D3_____^H3________________ZQ/________M$___
M___________________P$______________________S$_________03]1/_
M__<3______@3______D3___Z$___^Q/^$_\3_____P`4__\!%`(4________
M__\#%/__!!0%%/__________"13__PH4_____PX4_____P\4$!3_______\1
M%/____________\2%/__________%!3_____________________%A07%/__
M________&!3_____&A3_______\;%!P4__________\=%/____\>%/______
M______________________\?%/__________(!3__________R(4__\D%/__
M________)13__________R<4*!0I%/_______RH4__\K%/__+10N%"\4,!3_
M______________\Q%/__,A3_____________-!0U%/____\V%/__________
M________________________________-Q0X%/_______SD4_____SH4____
M____________.Q0\%#T4/A0_%$`4013_____________0A1$%/_______T44
M1A3_______]'%$@4________213_____2A3_____2Q1-%/______________
M_T\4_____U`4413_____________4A3__U04________________5116%%<4
M6!19%/__6A1;%/____]<%/____]=%%X4__________]?%/_______V`4__]B
M%/____]C%&04__________________]E%&84:11J%/__________________
M:Q1L%/_______________________VT4_____V\4__]P%/__<11R%/__=!1U
M%/__=A1W%'@4_____WD4__][%'P4__]^%'\4@!3__X$4__^"%(,4__^$%/__
MAA3__X<4________________________B!3__________________XD4BA2+
M%/_______________________________XP4CA3__________X\4D!21%)(4
M__^3%/_______________Y04____________________________________
M______^5%/__F!29%)H4G!2=%/__________________________________
M_____YX4_____Z`4_____________Z04_____________Z44IA2H%/______
M____J13_______________^J%/__________JQ3__ZP4________K13_____
M__^P%+(4LQ2T%+84____________________________________________
M______________________________________^X%/____^Y%/__________
MNQ2]%/__OA3_____OQ3__________________\`4________P13_________
M_______"%/_______________\,4________________Q!3_____QQ3)%/__
M_____\H4RQ3,%/__________S13.%/__SQ3__]`4___2%-,4U!3_________
M_________________]44________UQ3__]@4___________9%/__________
M_____________________________________]L4W13@%/_____A%/______
M____XA3__________^,4___________D%/_____E%/__________YA3__^@4
M_____________________^D4ZQ3L%/__[13_____[A3_____[Q3___`4____
M__________(4______________________04___________U%/__________
M___V%/<4________________^!3Z%/________________________L4____
M_______]%/_____________^%/___Q3_______________\"%0,5________
M__________\%%?__"!7__PD5"Q7_____#17_____________________$!7_
M____________%A7__Q<5_____Q@5&A4?%2$5__________\B%?__(Q4E%285
M________*A7__RL5+14O%?____\P%3$5________________-14W%?____\X
M%3T5__]!%4(50Q7_____1!7__T451A7__T<52!7__________TH52Q7__TT5
M4152%505________5156%?_______________U<5_____UL5715>%?__7Q5C
M%?_______V<5:17_______________]K%6P5__________________]M%6X5
M;Q7__W`5_____________________W$5<A5S%705__]U%?____]W%?______
M_________________________________________W@5>15Z%?__________
M__________][%?_______WP5_____X`5____________________________
M_________X$5@A6#%805_____X45________AA6(%8L5__________^,%8T5
M________CA7_______^/%?____^3%905_____Y45__^7%?__F!7_________
M____F17_____FA6;%9P5_____________YT5_____YX5_____Y\5__^@%:$5
M_____Z(5HQ7_____I!7_______^E%?__________________IA6G%?____^I
M%:H5_____ZL5__^L%:X5KQ6P%?__L17_____________________LA7_____
MM!7_____MA7_____________MQ6X%?__N16Z%;L5O!6]%?__OA7__[\5___`
M%<$5PA7#%<05Q17(%<D5___*%<L5___________,%=85UQ7__________]D5
MVQ7=%?__________WA7_____X17__^(5Y!7__^45YA7_________________
M____YQ7________I%?_____J%?_______^L5_____^T5________________
M___N%?`5\17___________,5]!7V%?@5___Y%?__________^A7___L5____
M_____17^%?______%0(6`Q;__P06!18'%O__________"18+%@P6#1;_____
M#A;__P\6_____Q`6__\1%A,6_____Q06_____Q46____________________
M____________________________________________________%Q;_____
M&1;_____&A8<%AT6________________________'Q;_____________(!8A
M%O____________\B%B,6__________\D%B46_____R86________________
M__\H%O_______________RD6__\L%BT6+A;_________________________
M______\O%C`6,1;__________________________S(6__\S%O__-!;_____
M__\U%C86__________________________________________________\W
M%O____________\X%O____________\Z%CL6/!;_____________________
M_____ST6________/A;__S\6_____________T`6__]!%O__0A;_________
M______]#%D06_____T46_____T<6_____________T@6_____________TD6
M__]*%O____].%O____________]/%O__________________________4!91
M%O____________]2%E,6__________________]4%O__51;__U<66!;_____
M__]:%O_______UL6__________]<%O__7Q;__________________V`6819F
M%F<6__________________________________________]H%O____]I%FH6
M;1;_____;A;__V\6_____________________W`6__]Q%O__________<A;_
M____________<Q;__________________W86=Q;_____>!9Y%GX6?Q;__X`6
M_____________________________________________X$6@A:#%O__A!:%
M%O__AA;__________________X<6________B!;__XD6________BA:-%O__
M__________^.%O__CQ;_______________________^2%O____________^6
M%O____________^8%ID6_____________YH6FQ;__YX6________H1:B%O__
MHQ:F%O_______________________Z<6J!;_____J1;__ZH6JQ:M%O______
M_________Z\6__^P%K(6M!;__________[46_____________[86________
M________________MQ:X%O__N1;__[H6________NQ;_____________OA;_
M____OQ;________`%O__________________P1;__________________\(6
MPQ;__\06_____\46_____\86________QQ;__\@6___+%O_____________-
M%O_______\X6________________SQ;_____________T!;3%O__________
M___4%O_______]D6VA;;%O__W!;_____WQ;_____________________X!;A
M%N(6_____^,6Y!;_____Y1;__^86_____________________^<6________
M________Z!;________________________________I%O______________
M_________________^H6_____________^L6___L%NT6________________
M[A;O%O________`6\1;___________________(6\Q;________________T
M%O_____________________________U%O__________]A;_____]Q;X%O__
M______D6___Z%OL6______P6_________________1;________^%O___Q;_
M_P`7_____P$7`A<'%___"!<)%PX7$1?_____$A?_______\3%Q47%A<7%Q@7
M__________________________________________________________\9
M%QH7__________________\<%___________'1<>%_____\?%________R,7
M)!?__R87)Q?__________RD7_____________________RH7_____RP7__\N
M%_____\O%________S`7________________________,1<R%_____\S%S47
M-A?_______________\X%SH7_____SL7/Q=#%___11?_____1A?_______](
M%_____]*%TX73Q=1%U,75A?_____________5Q?_______________]8%___
M6A=;%UP771?__________UX78A=D%V87__]G%_____]I%_______________
M_VH7__]L%________VT7________;A?__V\7________________<!?_____
M<1=R%_____]S%___=1?_______]Y%___________?1=^%_______________
M____?Q>`%_____^!%X(7__^#%X07AA>(%XH7_____XP7__^-%XX7________
MD!>1%___________________E1>7%Y@7F1>;%YP7__^>%_______________
M____GQ?_______^@%________Z(7__^C%Z47J!?_______^J%___________
M_____ZL7K1?_____________________________KQ?__[$7____________
M_[,7__________^T%___________________M1?_____________MQ?_____
MN1>Z%________________________[L7__________________^\%\(7____
M____________________________PQ?%%________\87___(%___RA?_____
M___________+%\P7___________-%___SA?__]`7TA?3%___________U!?_
M_]@7V1?:%]L7W!?=%]X7_____________________^(7________________
M________XQ?__________________^07Y1?__^87___G%^H7ZQ?__^P7____
M____[1?N%_________$7___R%___\Q?_____]!?U%_________________87
M______________________<7______L7_1?^%_\7`!@!&`(8________`QC_
M_P48__________________________________\&&/_______P<8__\)&/__
M__\*&/__"QC_______\-&/__#AC__P\8$!C_____$1C_______\2&/______
M____$Q@5&/____\6&/__%QC_____&!@;&/____\<&!X8'QC__R`8(1@B&/__
M_____________________________R,8)1C_____)QC__RD8____________
M____*AC_______\K&"T8__\N&/__,!@Q&#,8_____________S08__\U&#88
M__\W&/_______________S@8.1C_____________.QC_____________/1C_
M_SX8________/QA`&/__01A#&/__1!C_____11C_____________1AC_____
M1QA)&/__2AC__TL831A.&/__4!A2&/__4QA4&/____]5&%88________6!C_
M_________UH86QC__UP871A?&/_______V`8__]B&/_______________V,8
M9!C_______________]E&/_______V88________:!C_________________
M____________:1AJ&/____]K&&T8;AC_______________]O&'`8<AAS&/__
M__]W&/__>!C__WP8__________]]&/__?QC_______^`&($8_____X(8____
M____@QC__________X08B1C__XH8BQC_____________________C!C__XX8
M__________^/&/____^3&)08__^5&/____________^7&)@8____________
M_________YD8__^;&/__G!C__YT8__^>&*(8I!BE&*D8__^K&*T8KQC__[`8
M__^Q&+(8LQBT&+48MAC__[<8__^X&/____^Y&/____^Z&+L8O!B]&+X8OQC!
M&,,8Q!C%&,88________R!C__\D8___*&/__RQC__________\P8___.&-`8
MU!C5&-88UQC__]@8________V1C:&/__VQC_____W!C=&/__WAC?&.`8X1CB
M&/__Y!C_____Y1CF&.@8Z1CJ&.L8___________L&.\8________\!CQ&/__
M\QCU&/_____V&/<8___X&/P8_1C___X8____________________&``9`AD$
M&?__!1D'&0H9"QD-&?__________________#AD/&1$9_____Q(9__\3&109
M__\5&189_____Q<9__\8&?__&AG_______\<&?__'1D?&?__(AG__R,9__\D
M&?__)ADH&?__________________*1DM&2X9__\O&3`9,1DR&3,9-1DW&?__
M.!DY&3H9.QD\&?__/1D_&4`9__________]!&?____]"&?____]#&409__]%
M&?__1AE*&4L931G__T\94!E1&5,95!E5&589__]:&5L97!G__UT97AG__V`9
M__]B&6,9__]D&6499AEG&6L9_____VP9__]M&6X9__]O&?__<!G_____<1G_
M_W(9<QG__________W49_____W<9________>1EZ&7L9?!G__________WT9
M?AG_______]_&?__@1F"&?____^%&?__AAF'&8@9________B1G_____BQF-
M&8\9_____Y`9__^1&9(9_____Y,9E1G__Y@9F1F:&9P9__^=&?_______YX9
MHQG_____I!G__Z49__^G&:D9__^J&?__JQFN&?__L1G__________[,9__^T
M&;49MAG_____N!FY&;H9_____[L9_____[P9OAG__[\9___`&?_____!&<,9
MQ1G__\@9RQG-&<X9_____]$9_____________](9_____],9U1G6&=<9____
M_]@9V1G________:&=L9W!G>&?__X!GC&>09YQG_____Z1GK&>P9___M&?__
M\!G________R&?,9___V&?@9^1GZ&?L9_!D`&@$:`AH#&@0:!AH'&@@:"1H*
M&@L:#!H-&@X:#QH0&A$:$QH4&A4:%AH7&A@:&1H:&AL:'!H@&B$:(QHD&B4:
M)AHG&B@:*1HJ&BL:+!HM&BX:+QHP&C(:,QHT&C4:-AHW&CD:.AH[&CT:/AH_
M&D`:01I$&D4:1QI(&DD:2AI-&DX:3QI1&E,:5!I5&E<:__]8&EH:6QI<&ET:
M7AI?&F$:8AID&F4:9QII&FH::QIL&FT:;AIO&G$:<AIS&G0:=1IV&G<:>!IY
M&GH:>QI]&GX:?QJ`&H$:@AJ&&H<:B!J)&HH:BQJ,&HT:CQJ0&I$:DAJ3&I0:
ME1J6&I@:F1J:&IL:G!J=&IX:H1JB&J,:I!JF&J<:J!JI&JH:K!JM&JX:KQJP
M&K(:M1JV&K<:N!JZ&KL:O1K`&O_______\(:___________$&L4:________
MRAK__\P:___1&M,:UAK8&O_______]H:_____]T:___________________?
M&O__________________X!K_____________XAK________D&N4:Z!KI&NH:
M___________________L&NT:___O&O__\1KR&O,:]AK___H:^QK\&O______
M__T:_AK______________QK__________________P`;__\!&___`AL#&P0;
M_____P4;!AL'&________PD;_____________PH;__\,&_____\.&_______
M____________________#QL1&Q,;_____________________________Q0;
M_____________Q4;%AL7&_____________\8&________QD;____________
M____&QL<&___________'1O__QX;_____________Q\;(!LA&___(QO_____
M)!O_____)1O_______\F&R<;__\H&RD;________________________*AO_
M____*QO_______\L&___________+1LN&___+QO_____,!LQ&________S,;
M__\T&___-1O__________________S8;_____S<;.!LY&_____\Z&___/1L^
M&___________________/QM`&T,;________________1!O__T8;________
M__________](&TD;__]+&___________3AO__U$;4QM4&U<;__]8&UH;6QM?
M&___8AMC&V0;9AMG&V@;__]K&________VP;;AO__________V\;__]Q&___
M<QMT&W4;__________]V&_______________________________________
M______]W&WD;_____WH;_____WL;__________]\&___?1M^&___@!N!&___
M@QO_______________^$&_____^%&X8;AQN(&_____^+&___C1O_________
M____CQO__________________________________Y`;__^1&___________
MDAO_____________E!N5&___EAN7&___F1O_____________________FAO_
M______________________________^;&___G1N?&Z$;HANC&___I!O__Z8;
M__^G&ZH;JQO__ZT;KAO_____KQO_____L!NR&___________________M!O_
M____________M1O__[8;_____________[<;__^X&___NQN\&___O1N^&\`;
M________PAO__________________\,;________Q!O__\8;___'&_______
M____________R!O)&\H;________________RQO__\P;___________-&___
M________T!O__]$;TAO__________],;___________5&______7&___V!O9
M&___VAO__]L;W!O________________________________=&]X;___?&___
MX1O__________^(;_____________^,;_____^0;Y1O__________^8;____
M____________________YQO__________^@;_____^H;___N&_`;\1OR&___
M___S&___________]1OW&___^!O___D;___Z&_________P;___________^
M&P`<`1S__P(<__\#'`0<!AS__P<<_____P@<_____PD<__________\*'/__
M__\+'/_______PP<_____________PT<____________________________
M_P\<$!P1'!(<%1S_____%AP8'/__&1S_____&AS_____&QP>'"$<________
M__________________\B'/____________\C'/__________)!S__R8<)QS_
M______\H'"D<_____RH<__\K'/__________________________________
M__\M'/____________________________________\N'/______________
M______\O'#`<,AS__S,<________-!PV'/__________.!PY'/__.QS_____
M/QQ#'$<<2!Q)'/__________________3AS_____________3QS_____41Q2
M'/__________________4QS_____5!S__________U4<________________
M________5AS__________________________U<<6!S_____________61S_
M____8!S_____________81S_______]B'/__9!QE'/____]F'&<<:!QI'&H<
M;QS__________________________________________W`<<1S_________
M_W(<________________________<QS__________________W0<=AS_____
M=QS_____________>!S_______________]Z'/_______WP<?1S__WX<____
M_W\<@!S_____@1S_____________________________________@AS_____
M_____________X0<A1S__X8<____________________________________
M______________^('(D<_____XH<_____________XL<C1S_____CAS_____
M__^/')$<DAR3')0<E1R6')<<F!R:'/__G1R?'*`<H1RB'*,<I!RE'*8<IQRH
M'*D<JAS_______^M'/____________^N'/__KQS_____________________
M__^P'/__________LAS_____________________M!S__[4<MAS_________
M_________[<<________N!S__________[D<________________________
MNAR['+P<O1R^'+\<P!S"',,<Q!S__\<<R1S*'/______________________
M_________________________\L<___,',T<________________________
M___/'/_____________________________0'/_______]$<U!S5'/_____6
M'/__________V1S__________________________________]H<_____]L<
M___<'-T<___________________>'/__________X!S_____X1S__^(<YQS_
M_______H'.H<[!SM'.X<________[QS___________`<______,<]!S_____
M]1S________V'/_____________________W'/________@<^1S_________
M__________P<___________]'/X<____'/____________\`'?__`1W__P,=
M__\$'?_______P4=__\&'?__!QT('?__"1W_____________"AW_________
M_________________PL=#!W_______\-'?__#AW__P\=$!W_______\1'?__
M__\2'10=__________\5'?__________&1W__________________QL=__\<
M'?____________________________________\='?__________'AW_____
M__\?'?____________\@'?__________(1W_____________(QW_________
M____________________)1W__R8=)QW_____*!W__RD=*AW_____________
M__\K'2X=+QW__S`=_____S$=_____________S,=_____S@=____________
M______\Y'3L=________________________/!T]'?____\^'4`=________
M_____________T$=__________]"'?__0QU$'?_______________T4=__]&
M'?____]''4@=21U*'4P=3AW__T\=4!U1'5(=__________]4'?__________
M51W_______]6'5@=_____UH=__];'?__71U>'?__7QW_____8!W__V$=____
M______________]B'?_______________V,=9!W_____91W_____9AW__V<=
M__]H'?____]J'?__________________:QUN'?__________________;QW_
M_W`=__]R'?__________<QW__W0==1W_____=AUX'?_______________WD=
M________________>AW_____?!W__WT=?QV!'8(=A!V%'?__AQW_________
M_________XD=__^+'?__________C!V0'?_______________Y0=________
MEQV8'9D=________FQW_______________________^<'?__H1W_________
M_Z,=I!W__________Z8=_____________________Z@=K!W__ZX=KQW__[`=
MLAW__[,=________MAW__[<=__^Y'?__NAV['?____^_'<$=___#'<4=___'
M'?_____*'?_______\P=_____\T=________SAW________/'?__________
M________________T!W__]$=___________________________3'?_____4
M'?__UAW__]<=___________8'?__________________VAW<'?__W1W__]X=
M___?'>$=XAW_____Y!WF'>@=Z1W__^L=_____________^P=[1WN'?______
M_^\=\1W___(=\QW___0=________]1W___________<=^!W___D=^AW['?P=
M_1W^'?\=________________`!X"'@,>_____________________P0>!Q[_
M_P@>__________\)'O____________________\*'O__________"QX,'O__
M________________#1[_____________#A[_________________________
M______\/'O____\1'O____\2'A0>%A[__________Q<>__________\:'O__
M__________________________________________________\;'AP>'1X>
M'A\>(!XA'O____________\B'B,>__\D'O__________)A[_______\G'O__
M________*![_______________________\I'BH>*Q[_________________
M______\L'O__________________________________+A[_____________
M__________\O'O_______S`>__________________\Q'O__-!XV'C<>__\X
M'O____\Z'O_______________SL>________________________/![__ST>
M__________\^'O__/Q[_______________]`'O__01[_______________]"
M'O_______T,>__]$'D4>1Q[__T@>__])'O_______TH>__________]+'DP>
M________________________31Y.'O__________4![_____41Y2'O__5![_
M____5AY7'O_______________________________________________U@>
M________61[__UH>_____UL>__]<'ET>7A[_____________7QY@'O____]A
M'O__________________________________________8A[_____________
M________8Q[_____9![_____91[_______]F'O__9QYH'O__:1[_________
M____:Q[_______]L'FX>;Q[_____________<1YR'G,>=!YU'G8>__]Y'GH>
M________________________>Q[__WT>?AY_'O_______X$>@Q[_________
M_X0>________A1[__________X8>_____XD>BQZ.'H\>_____________Y$>
M__^2'I,>E![_____EQZ9'O____________________^:'IL>GAZ?'O__H![_
M_Z,>I!ZF'JD>JAZL'O_______Z\>L!ZQ'O____^R'O_______[,>__^T'O__
M________________________M1[_______^V'O_______________[<>N!Z[
M'O__________O![__________________________________________[T>
M___`'O__________________________________P1[#'L0>Q1[_________
M_\8>R![__\D>___________________________________*'LL>___,'O__
MS1[__\X>_____\\>________________________T1[_____TA[3'O_____4
M'M4>UQ[8'MD>VQ[<'O__WA[__________]\>________________X![A'O__
M________________XA[________________________C'O_____D'O__Y1[_
M_^8>YQ[_____Z![J'O__________ZQ[_____[![__^T>________________
M___________________N'O_______________^\>\![Q'O________(>____
M__,>___________________T'O________8>___________W'O@>___Y'O__
M___________Z'OL>_________________![______1[________^'O______
M________'O__`!\!'___`A______`Q___P0?_____________________P8?
M__\''________________PD?"Q\,'PT?$!\4'___%1\6'Q<?&!______&Q\=
M'___'Q___R$?__\B'________________R4?________)A\G'R@?__\J'RL?
M__\L'_____\M'RX?__\O'S`?_____S(?,Q______-1___SD?.A___SP?/1\_
M'T`?0A]#'T0?1A]('TD?2Q].'T\?4!]1'U(?4Q]4'U4?_____U8?_____U<?
M_____________UD?6A___________UL?_____UP?71__________________
M_UX?__________]@'___81___V,?9!________]F'___:!]J'VP?;A]O'___
M________<!___W$?__]R'___<Q___W0?__]U'W8?__]W'W@?>1]['___?!]]
M'___?A___W\?@!^"'X0?A1___X8?________AQ^('XD?__^*'________XL?
M__^,'XX?__^/'________Y$?DA^3'Y4?________EA___________Y<?____
M______^9'___FQ^<'___G1___YX?__^?'Z`?H1^B'Z,?_____Z0?_____Z4?
MIA^G'Z@?J1^J'_____^K'ZP?__^M'___KA^O'[$?LA___[,?M!^V'[<?__^X
M'________________[D?_____[H?__________^['[P?O1^^'___OQ_`'___
MP1_"'________\,?Q!______Q1_&'___R!___\H?________RQ___\P?S1__
M_\X?SQ_0']$?___2'___TQ___]4?UQ___]D?VA___]L?________W!______
MW1______WA___^`?X1______XA___^,?_____^0?___E'___YA_G'^D?___J
M'___ZQ_L'________^T?[A_________O'_`?\1_R'___\Q_U'_<?___X'___
M^A_['____!____T?_Q\%(`8@_____P<@__\((/____\*(`L@#2#__PX@__\/
M(/__$2#__Q(@$R`4(/__%2`6(/__________%R#__Q@@__\9(/__&B#_____
M__\;(/__'"`=(/__'B`?("$@__\B(/____\C("4@________________)R#_
M_R@@*2`K("P@_____RX@_____R\@_____________S`@_____S$@__\S(/__
M__\T(/__________________-B#_____."#__SD@.B`[(/____________\\
M(/__/B`_($`@02!#(/____]%(/__________________________1B!((/__
M2B!+($T@3R!0(%$@__]3(/____]4(%4@________5B!8(%D@__];(%T@__]?
M(/__82#__________V(@9"!E(&<@:2#__VP@__]N(&\@__]Q('(@________
M<R#__W4@__]V(/__=R!Y('H@>R!\('T@?B!_((`@@2"#((0@A2"'((@@B2"*
M((L@C""-((X@CR"0()$@DB"3()4@EB"7()@@FB";()P@G2"?(*`@H2"B(*,@
MI""E(*8@IR"H(*D@JB"K(*P@K2"N(+`@L2"R(+,@M""U(+8@MR"X(+D@NB"[
M(+T@OB"_(,`@P2#"(,,@Q"#%(,8@QR#((,D@RB#+(,P@S2#.(-`@T2#3(-0@
MU2#7(-@@V2#:(-L@W"#=(-\@X"#A(.(@XR#D(.4@YB#G(.@@Z2#J(.L@["#M
M(.\@\"#Q(/(@\R#U(/8@]R#X(/D@^R#\(/X@_R``(0(A`R$$(04A!B$'(0@A
M"2$*(0LA#2$.(1`A$2$2(1,A%"$6(1@A&2$:(1PA'2$>(1\A("$A(2(A(R$D
M(?____\F(?__________)R$J(?____________\M(?__+B'__R\A________
M,R'__S4A_____SDA/2'_______]!(?__0B'_______________________]#
M(?_______________T0A12'__T8A__________________]'(?_______T@A
M22%*(?__2R'_______],(?__________32'__TXA__]/(5`A42%3(?______
M_U0A52%6(?_______U<A_____U@A62%;(5TA7B%A(6(A9"'__________V4A
M9B%G(6@A:2%J(6LA;B%Q(7(A__]S(70A=R'__W@A>2%Z(?__>R%\(7TA?B'_
M_W\A@"&!(8(A@R&$(84A__^&(8<AB"&*(8LA__^,(8XA_____Y`AD2&2(90A
MEB&7(?____^8(9DAFB&<(?__G2'__YXAGR&B(:0AIB'__Z@AJ2'_____JB&M
M(:XAKR'_____L"'_______^Q(;,A__^T(?____^V(;<AN"&Y(;HA_____[LA
M_____[TAOB'__[\AP"'__\$APR'__\8A___'(<@A___)(<LAS2'__\XASR'_
M_______2(=,AU"'6(=<AV"';(=PAWB'?(>$AXR'D(>4AYR'H(>DAZB'K(>PA
M[2'N(?$A\R'T(?4A]B'W(?@A^2'Z(?LA_"'](?XA_R$`(@$B`B(#(@0B!R((
M(@DB"B(+(@PB#2(/(A`B$2(4(A4B%B(7(A@B&2(:(ALB'"(>(A\B("(A(B(B
M(R(D(B<B*R(L(BTB+B(O(C`B_____________S(B__\S(O_______S0B-2+_
M______\V(C<B__________\X(O_______STB__\^(C\B________________
M_____T`B_____________T$B________0B+_______]#(O______________
M_________________T0B__]%(O_______T8B_____T<B__])(DHB________
M_____TLB_____TPB__________________]-(D\B____________________
M______________________________________________]0(O____]1(O__
M_____U(B_____________________________________U,B5")5(E8B5R)8
M(EDB6B);(O__________7"+_______________]>(O__8")A(F,B________
M9"+_________________________________________________________
M____92)F(F<B:")I(O____]J(FLB________;"+_______]M(O__________
M__________________]N(O_______________V\B<2+_____<B+__W,B="+_
M____=2+_______________________]V(O_______W<B>"+_____________
M________________>B+_____________________?")^(O__________@"+_
M____@2*"(H,B_____X0B__^%(H8BB2+__XLB__^-(O__CB*/(I`B__^1(O__
M_____Y,BE"+__Y4B__________^6(I<B_____YDBFB+_______^;(O__G2*>
M(O__GR*@(J0BI2*F(O_______________________________Z<B________
MJ"+__ZLB________KR*P(K$BLB+_______^S(K0B__^U(O______________
M_[8B________N2+_____NB*\(KXB________________OR+__________\`B
M___"(O_______\,B___&(L<BR"+)(LHBRR+-(O__SB+_____SR+__]`B___1
M(M(BTR+4(O__U2+_____UR+_____V"+:(MLBW2+________?(O__X2+C(N4B
MYB+G(O__Z"+________I(NHB_____^LB[2+__^XB[R+___`B________\2+_
M____\B+___,B___T(O8B]R+___@B^2+___HB_2+___XB`",!(_____\"(___
M_____P0C!2/_____________!B/_____!R/__________P@C_____PDC__\+
M(PPC__\-(___#B,/(Q`C$2,2(Q,C%",6(QDC&B,<(QXC'R,@(R$C(B,C(R0C
M)2,F(R<C*",J(RLC+",M(RXC+R,P(S$C,B,T(S4C-R,X(SHC.R,\(STC/B,_
M(T$C0B-#(T0C12-&(T<C2"-)(THC2R-,(_____]-(U`C4R-4(U8C_____UDC
M__]<(UTC7R-A(___9"/__V4C:"-I(_____]L(_____]M(VXC_____V\C<B/_
M____=2-V(_____]X(WDC>B/_____>R-\(WTC__]^(_____________^`(___
M________________@2."(___@R.$(X4CAB.'(___________BB.+(_______
M_XPCC2/__XXC_____X\C________D".3(___________F2.;(___________
M________G2.>(___________GR.@(Z$C________HB/_______^C(Z4C__^G
M(________ZHC________________________JR/__ZPCLB/_____LR/_____
M__________^T([8CMR/_______________^X([HCNR.\(___________O2/_
M______^^(________\`CPB/$(______%(________\8CQR/*(\PC___-(___
MSB/_____SR/__]`C___2(]0C________U2/________6(______________7
M(______8(________]HCVR/<(___W2/__]XC___________?(______@(___
M___A(___XB/E(___________Z"/I(^HC___K(_______________________
M_^PC_____________________^TC___N(______O(_`C___Q(___________
M________________\B/S(_0C___W(_________@C____________________
M_______[(____"/^(_\C`"0!)`,D__________________________\$)`8D
M________________!R0()`DD________________________________"B0+
M)`PD$"3__________________________________Q$D_____Q(D%B3_____
M_____________QHD__\;)!PD("3_________________________________
M_________R$D_____________R(D_____R,D__\F)/__)R3__R@D*23_____
M*B3__RLD+"3__________R\D________,"0Q)#,D-"3__S4D____________
M_________S8D__________\W)/_______S@D__________\Z)/_______SLD
M/B3_____0"3__T$D__________]#)/____________________________]%
M)$8D1R3_______]))/_______THD__]+)$PD323_____3B3_____________
M4"11)%(D5"17)/_______U@D__]:)/____________]<)/______________
M_UXD8"3__________V(D________________923_____9R1I)/_______VLD
M;23__VXD__]O)/__<"1R)/__="1V)'@D__]Z)/__?"1])'\D@22$)(4DAB2(
M)(DDBB2+)/__C22.)/____^/))$D__^2))0D__^5))8D__^7)/__________
M__^8))DD__________^A)/__HB3__Z,DI"2E)*@D________L"2Q)/__LB2S
M)+0DM23__[<DN"3_______^Y)+HD__^\)+TDOB3__[\DP"3_____________
M________P23#)/__Q"3__\4D___&),<DR"3)),HD_____\PD___.)/__T"3_
M____T232)/_____3)-0DU236)/_____7)-@DV23:)/_______]LDX"3A).(D
MXR3D)/__Y23__^<D________Z"3________I)/__ZB3_____ZR3L)/_____N
M)/__[R3___`D___S)/__]23___8D________^"3Y)/________HD______\D
M__\#)?__!"7__P4E!B7_______\')0@E_____PDE__\*)?______________
M____"R7_______\,)?__#27__PXE$B7__Q,E__\4)18E&"7__QLE__\<)?__
M__\=)?__'B4?)?__("4A)2(E(R4D)24E)R7_____*"4I)2HE________+"7_
M_RXE__\O)3`E,27_______\R)?__,R7__S0E__\U)?__________-B7_____
M-R7_____."7_______________\Y)?__.B7__S\E__]`)?_______T(E1"5%
M)48E__]')4PE3B7_____4253)50E5256)?__5R7_____627__UHE________
M6R7__________UPE_____UTE__]?)6`E827_______________]B)60E__]E
M)?____]F)?____]G)6@E:B5K)?_______VPE;25N)6\E________<27__W(E
M<R7__W0E=27__W@E>27_____>B5\)?____]])7XE?R7_____________@"7_
M_X$E@B7__X,E_____X0EA26&)?__B"6+)?__C"7_______________^-)?__
M_____XXE__^/)9`E_____Y(E__^3)?_______Y4EEB7_______^7)?____^8
M)?____^9)9LE_____YPE__^@):$E________HB7_______^C):4E__^F):<E
M__^H)?____^I)?____^J):LEK"7_____________KB7__[`E__^R);0EM27_
M_[8EMR7_____________N"6Z);LE_____[PEOB7__[\EP"7__\$EPB7$)?__
MQB7_____QR7__\@E_____\DE___*)?__________RR7__\PE___-)?______
M_\XESR7________0)=$E_____](ETR7__]0E________U276)?_______]<E
MV"79)=HE___>)>`E___A)>(E_____^0E___________________E)?______
M____YB7__^<E___H)?_______^DE___________K)>TE________________
M___N)?__________[R7___`E\27R)?_____S)?0E]27V)?_____X)?_____Z
M)?LE__________\`)@$F`B;_____`R;_____!";_______\&)@<F__\()@TF
M__\.)O__$";__________Q$F________$B84)A8F__________\7)O__&";_
M_________QDF'28A)B(F(R;__________R0F)B8K)O__+2;__RXF_____R\F
M,"8Q)O__________,B;__S0F.";__SDF.B8[)CPF_____STF__\_)O__0";_
M____029")D0F12;__T8F2";_____229+)DXF3R90)E$F4B93)E0F5296)E<F
M6"99)EHF6R9<)ETF7B9?)F`F829B)F,F9"9E)F8F:B9K)FPF;29N)F\F<29R
M)G,F="9V)G<F>"9Y)GHF>R9\)GTF?R:`)H$F@B:%)H8FAR:()HDFBB:-)HXF
MCR:0)I$FDB:5)I8FER:8)IHFFR:=)IXFGR:A)J(FI":E)J<FJ":I)JHFJR:L
M)JXFKR:P)K$FLB:S)K0FM2:V)K<FN":Y)KHFNR:\)KTFOB:_)L`FP2;")L,F
MQ";&)L<FR";))LHFRR;,)M`FT2;2)M,FU";5)M<FV";;)MPFW2;>)M\FX2;B
M)N,FY";E)N<FZ";I)NHF[2;N)N\F\";Q)O(F\R;U)O<F^";Y)OHF^R;\)OTF
M_B;_)@`G`2<")P,G!"<%)P8G!R<()PDG"B<,)PTG#B</)Q`G$2<3)Q0G%2<6
M)Q<G&"<9)QHG&R<<)QTG'B<?)R`G(2<B)R0G)2<F)R<G*"<I)RHG*R<L)RTG
M+B<O)S`G,B<S)S0G-2<V)S@G.2<Z)SPG/2<^)S\G0"?__T$G0B=#)T0G12=&
M)T<G2"=))THG2R=,)TTG3R=0)U$G4B=3)U0G52=6)U<G6"=9)UHG6R=<)UXG
M7R=@)V$G8B=C)V0G:"=L)_____________]N)W(G__]S)W0G_____W4G=B=X
M)WDG__][)WPG__]])WXG__^`)X(GA">%)________X8GAR?_____________
M__^))XLGC">/)Y`GD2?__Y(GDR>4)___E2>6)Y<G________F">:)___G"?_
M_YXG_____Y\G__^A)Z(GHR>D)Z4G________IB?_____J">I)ZHG__^K)ZTG
MKB>O)_____^P)___L2>R)[,GM">U)[8GN2>^)______$)___QR?__\@GR2?*
M)___RR?,)______-)\XGSR?0)]$GTB?4)]4GUB?8)]DGVR?<)]TGWB??)^`G
MX2?C)^0GY2?F)^<GZ"?I)^HGZR?L)^TG[B?P)_$G\B?S)_4G]B?W)_@G^2?Z
M)_LG_"?])_\G`"@"*`,H!"@%*`8H!R@)*`HH"RC__PTH_____________PXH
M$BC__Q0H%2@7*!DH&RC_____'"C__QTH__\>*"`H)"@E*/__)RC_____*"C_
M_________RDH*RC_______\M*"XH+R@P*#$H________,BC_____________
M_____S,H-BC__S<H________."@Z*#LH/2C_______\^*/__0"A!*/__2"A)
M*/_______________TPH_____U`H________42A2*/__4RA6*/__6"C__UHH
M__]<*%XH__]B*/____________]D*/__92C__V8H:"AI*/__________;"AN
M*/____]O*/__<"C__W$H__]X*'DH_____WPH__________]_*/__@"B#*/__
M__^%*(8H__^-*)`H__^1*/__DBB4*)8H__^8*)\H__^@**$H_____Z(H____
M_________Z0H________IBC__Z<H__^H*/__J2C_______^K**XH_____Z\H
ML"BQ*+,HM2BV*+DHNBC__[PHO2C_______________________________^^
M*/__ORC`*/_____!*,(H_____\,HQ2C_____QBC_____R"C_____________
M_____\DHRBC________________-*/_____________.*/_____/*-(H____
M_________]4HUBC__________]<H_____________]HH________________
M___________;*/_____<*/__X"C________A*.(H___C*/__Y"C__^4HZ"CI
M*/_____M*/0H^RC__P(I!"D&*0<I__________\**0LI__\,*0TI________
M__\0*18I%RD9*?__&BD;*?____\<*?__'BG_______\A*?____\D*?______
M______________\E*?____\F*?____________________\H*?__*BDK*2PI
M__\M*?__+BDO*?_______________________________S`I____________
M____,2DS*34I________________-BG__S<I.2G_____.BG_______\[*?__
M_____SPI/2G_____/BG__T`I_____T$I__]"*40I__]%*48I1RG_________
M____22G_____________2BG_____2RE.*4\I_____________U`I__]2*5,I
M5BE8*5DI6BE;*5TI7BE?*?__8"EA*?____]C*?____________]D*?______
M_V4I__]F*6<I:"G__VDI:BEK*6PI__]M*?__;BG__V\I<"EQ*7(I<RET*?__
M_____W4I=BG__W<I__]Y*?__________>BG_____>RE]*7\I____________
M_X`I@BF#*?__A2G__X<I__^(*?____^**8LIC2F1*94IEBF8*9PI________
M__________^=*?__________GBF?*:`IH2FB*?____^D*:4IIBFH*:HI__^K
M*:PIK2FO*?____^Q*?_______[(I_____[,I__^T*?_______[4IMBG_____
MMRFY*;HI__^]*;XIORG`*<$IPBG#*<0IQ2G'*<@IR2G**<LIS"G-*<XISRG0
M*=(ITRG4*=8IURG9*=HIVRG<*=TIWBG@*>$IXBGF*?__YRGI*>HIZRGL*>TI
M[BGP*?$I\BGS*?4I]BGW*?@I^2GZ*?LI_"G__________P0J!2H)*O__"BK_
M_PLJ_____PPJ#2H0*O__$2H2*A,J________%"K_____%2H7*O__&2H>*A\J
M________(RK__R@J+BHO*C`J,2HR*C,J-"HU*C8J-RHY*CHJ.RH\*O__/2H^
M*D$J1"I%*D8J__]'*O____](*DDJ2BI+*DTJ3BI/*E$J4RK__U0J__]6*O__
M5RK_____________6"I9*EHJ6RK_______]<*ETJ7BK_______]@*F,J__]F
M*F<J:"II*FHJ:RIL*FXJ__]O*G`J__]Q*O__<RIT*G4J__]V*G<J>"IZ*O__
M__________][*G\J________@2K__________X(J__^#*H0JA2J'*H@J__^)
M*HHJBRJ,*HTJCBJ/*O__D"K__Y$J__^2*O____^3*I0JE2J6*I<JF"J9*O__
M__^:*ILJ__________^<*O__G2K_____GBK__Y\JH"K_____HRJD*J<JJ"JJ
M*JLJK2JN*J\JL"JQ*K(JLRJU*K8JMRJX*KDJNBJ[*KPJO2J_*L`JP2K"*L,J
MQ2K&*L<JR"K**LPJS2K.*L\JT"K1*M(JU"K5*M8JURK8*MDJVBK;*MPJW2K>
M*M\JX"K__________________^$JXBKC*O__________________________
M_____^0JY2KF*O_____G*NDJZBKK*O__________["K________M*O__[BK_
M__`J______$J\RKU*O__^2K___________________TJ_BK_*O__`"L!*___
M__\"*P,K__\$*___!2L'*PDK__\**PTK__________________________\.
M*P\K__\0*Q$K________$BO_____%"O_______________\5*___%BL7*___
M__\8*___________________&2L:*QLK'"O__Q\K(2O_____)"O_____)2O_
M_________________________R8K________)RO_____*"O__RDK*BO__RTK
M_____________RXK+RLQ*___,BO_______\S*___-"LU*S8K-RLX*SDK__\]
M*_____\^*___/RM`*___02O__T(K12O_____1BO__T<K_____THK2RO__TTK
M__].*_____]/*___42M2*U0K_____U4K5BM7*U@K62M:*UPK72M>*V(K8RME
M*V<K:"MI*VHK:RML*VTK;BMP*W$K<BMT*W4K=BMY*WHK>RM\*WTK?BM_*X`K
M@2N"*X4KABN'*X@KB2N**XLK__^,*XTKCBN/*Y$KDBN4*Y4KEBN8*YDKFBN;
M*YPKG2N>*Y\KH2NB*___________________HRO_____________I"O_____
M________________J"O_____________J2NK*_____^L*_____^M*ZXK____
M_Z\K_____[`KL2NS*[<KN2NZ*[TKOBO_______________________^_*\$K
MPBO________#*\4K_____\<KR"O**___________RRO__________\TK____
M____________SBO__\\K________TBO________________3*___________
M___4*________________]8KURO________________8*]LK___<*^$KYBOH
M*^DKZBOO*___\"OU*___]BOY*____________"O______2O___XK________
M__\`+/_______________P$L__\"+/__________`RS__P4L____________
M____"BP,+/__#2P.+/_______________P\L$"S_____$2S__Q(L________
M__\3+/__%"S_____%2P7+!@L_____QDL_____QHL________________&RS_
M_QPL_____________QTL'RP@+/__(2PB+",L)"PE+"8L)RS_____________
M__\H+/__*2PJ+"TL__________________\N+"\L_____S$L,BS__S,L-"S_
M_________SDL_____SHL.RS_____/2P^+/____\_+/__0"Q!+/__________
M__]"+/__1"Q%+$<L________________2"S__TDL2BQ++$PL3BS_____3RS_
M_U$L________4BQ3+/__5"S_____52Q6+/__5RQ8+/__________62S_____
M__]:+%LL__]<+/__7RS_______]@+/__82QB+&0L92QF+/__________9RQI
M+/____]J+&PL__]N+&\L__]Q+'(L__________________]S+'4L_____W8L
M=RS_____>"QY+'HL_____WPL?BS_______]_+(`L_____X$L@BR$+/__A2S_
M_X8L__^'+(@LBBR++/__C"S_______^-+/____^.+/____^/+)`L________
M_____________Y,LE"R5+/__EBR7+)@L__________^9+)HLFRR<+/____^=
M+)XL_____Y\LH"S__________Z$LHBRC+/_______________Z0LIRRI+/__
MJRRL++$LLBRS++0LM2RV++<L__^X++DLNBR[++PLOBR_+,`LP2S"+,0LQ2S&
M+,<LR"S)+,HLRRS,+,TLSBS/+-`LT2S2+-<LV"S:+-LLW2S>+-\LX"SA+.(L
MXRSD+.4LYRSH+.DLZBSK+.PL[2SN+.\L\"SQ+/(L\RST+/8L]RSX+/DL^BS[
M+/PL_2S^+/\L`"T!+0(M!"T&+0<M""T)+0HM"RT,+0XM#RT0+1$M$BT3+10M
M%2T6+1@M&BT;+1PM__\=+1XM'RTA+2(M(RTD+24M)BW__R<M__\I+?__*RW_
M_RPM+BW_____________+RTP+3$M__\R+?__,RW_____________________
M_____________S0M-2TV+3@M__________\Z+?_______SPM_____STM____
M_________SXM__\_+4$M0BW_______]$+?____]%+?__1BW_______]'+?__
M__])+4HM_____TLM3"W_______________]-+4XM_____T\M_____U`M42U2
M+?____________________________]3+50M52U6+?____________]7+?__
M__]8+5DM6RW__UTM7BW_____________________7RW__V`M__]A+6(M8RW_
M_V0M________92UG+?_______________V@M_____________________VHM
M__]L+6TM__________]N+?_______W$M_____W(M__]S+?__="W_________
M______]U+?____]V+7<M________>"UY+7HM?"W_____?2W_____?RW__X`M
MARW_______^(+8DMBBV++?____^,+8TMCBV/+9`MD2W__Y0M__^5+98MERW_
M_________Y@M________F2W_____FBV;+?__G2V>+?__________________
M________GRV@+?__________H2W_______^B+:,M__^D+:4MIRW_______^I
M+:HMJRW_____K2W__ZXM__________________^O+?____^P+?__L2W__[(M
MLRW_____________M"VW+?__OBW__[\MP"W"+<,MQ"W%+<<MR"W++<PMS2W.
M+=`MTBW3+=0MU2W6+=@MV2W:+=LMW"W=+=XMWRW@+>$MXBWC+>0MY2WF+><M
MZ"WI+>HMZRWL+>TM[BWO+?`M\2WS+?0M]BWW+?@M^2WZ+?LM_"W]+?XM_RT`
M+@$N`BX#+@0N!2X&+@<N""X*+@LN#"X-+@XN#RX0+A$N$BX3+AHN&RX<+ATN
M'BX?+B`N(2XB+O__(RXD+B4N)BXG+B@N*2[_____*RXN+C`N,2XR+C4N-R[_
M_________S@N.2XZ+O__.R[__________________SPN________________
M__\]+O_______________S\N_____________T`N0BY#+O____]$+D8N2RY0
M+E(N__]3+O__________5RY;+O____]@+F(N9BYK+FXN<B[_____________
M=BYW+O__________>2[_____>B[_____>R[__WPN?2[_____________?BY_
M+O__@"[_____@2[_____@R[_____A"[_______^%+H8NAR[_____B"[_____
M__^)+HHN__^++O__C"Z-+O__CB[_______^/+I`ND2[_____DRZ4+O______
M_Y4NERZ:+O__FRZ<+ITNGB[_____GRZ@+J$N__^C+O__I"[_____________
M________IBZG+O__________J"[_________________________________
M_ZDN__________^J+O____________________________^K+O__________
MK"ZP+O____^R+K0NMBZZ+KPNOBZ_+L$N___"+O__PR[$+O__Q2[_____QB['
M+L@NRB[,+O_____-+LXN___1+M(N___4+O_______]4NUB[7+O_______]@N
MV2[__________________]HNW"[=+MXNWR[@+N(NXR[D+N4NYB[G+N@NZ2[J
M+NTN___N+O__[R[___(N\R[________T+O8N]R[X+OHN_2[_+O____\!+___
M__\$+_______________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______W_`0(#!`4&!PD*"PP-#@\0$?T2%!46%Q@:&QP='OW]_?W_'R`A(B/]
M_20E)B<H*?W]*BLL+2XO_?TP,3(S_?W]_P$"!`<("1$2$Q46%Q@9&AL<'1[]
M_?W]_?W]_?W]_0$"`P0%!@<("0H+#`T.#Q`1$Q05%A<8&1H;'!T#!`4&!PH+
M#`T.#Q(3%!46%QH;'!T"`P0%!@<("0H+#`T.#Q`1$A,4````````````````
M`````````````````````$&(08Q$A$&01H1'A$&409A!G$J$2X1,A$V$3H1/
MA%"$0:!!I$&H5(1!K$&P0;1!N$&\0<!!Q$'(0<Q!T&&$@82AA,&$X81!A6&%
M@86AA<&%X85!AF&&@8:AAL&&X89!AV&'@8>AAP``````````````````````
M````````````]$`%"``````8004(```````````T004(`````-!#!0@`````
M!P```*A$!0@`````0$4%"``````'````C$4%"`````#$104(``````<````(
M1@4(`````$!&!0@`````!P```(!&!0@`````+$<%"``````'````:$<%"```
M``"D1P4(``````<```#<1P4(`````!A(!0@`````!P```$A(!0@`````1$D%
M"``````'````&$H%"`````"X2@4(``````<```!(2P4(`````.A+!0@`````
M!P```'1,!0@`````-$T%"``````'````S$T%"``````D3@4(``````<```!T
M3@4(`````,Q.!0@`````!P```!A/!0@`````Y%$%"/A4!0@'````8%4%"```
M``"4504(``````<```#0504(`````!!6!0@`````!P```%Q6!0@`````?%8%
M"``````'````G%8%"`````#@5@4(``````<````@5P4(`````+!8!0@`````
M!P```#A9!0@`````Q%H%"``````'````E%P%"`````"L7`4(``````$```#,
M7`4(`````/Q<!0@``````0```%1=!0@`````C%T%"``````!````^%T%"```
M```H7@4(``````$```"`7@4(`````+!>!0@``````````!1?!0@`````3%\%
M"```````````I%\%"`````#<7P4(``````(```!(8`4(`````(A@!0@`````
M`0```/1@!0@`````)&$%"``````!````?&$%"`````"L804(``````````#\
M804(`````"QB!0@``````````(1B!0@`````M&(%"```````````2&,%"```
M``!\8P4(``````````#L8P4(`````!QD!0@``````````)1D!0@`````Q&0%
M"```````````5&4%"`````"$904(```````````49@4(`````$1F!0@`````
M`````-1F!0@`````#&<%"``````#````B&<%"`````#`9P4(``````(```!(
M:`4(`````(1H!0@``````P```!AI!0@`````4&D%"``````"````U&D%"```
M```X:@4(``````,````$:P4(X&H%"(AL!0@``````P```$QN!0@`````?&X%
M"``````#````&&\%"`````!0;P4(``````,```#,;P4(X&H%"!QQ!0@`````
M`P````!S!0@`````,',%"``````!````I',%"`````#4<P4(``````````"<
M=`4(`````.1T!0@``````````&QU!0@`````I'4%"``````#````>'8%"```
M``"H=@4(``````(```!`=P4(`````'AW!0@``````P```#!X!0@`````:'@%
M"``````#````"'D%"`````!`>04(``````,```#@>04(`````!!Z!0@`````
M`@```+!Z!0@`````X'H%"``````"````A'L%"`````"\>P4(``````(```!(
M?`4(`````(!\!0@``````P```#A]!0@`````<'T%"``````"````]'T%"```
M```L?@4(``````````"0?@4(`````,A^!0@``````@```%A_!0@`````D'\%
M"``````!````'(`%"`````!4@`4(``````$```#D@`4(`````!R!!0@`````
M`````*"!!0@`````[($%"``````#````F((%"`````#H@@4(``````,```"8
M@P4(`````-"#!0@``````@```$R$!0@`````A(0%"```````````T(0%"```
M```HA04(``````````",A04(`````,B%!0@```````````R&!0@`````1(8%
M"``````"````L(8%"`````#XA@4(``````````!<AP4(X&H%"*R(!0@`````
M`0```"B*!0@`````=(H%"```````````Q(H%"``````HBP4(``````````"4
MBP4(`````"B,!0@``````@```*R-!0@`````A(X%"```````````E(\%"```
M``#@CP4(```````````PD`4(`````,20!0@``````@```.B3!0@`````+)8%
M"``````"````:*(%"``````DHP4(``````8```"HI`4(`````*2G!0@`````
M`P```-"J!0@`````C*P%"``````#````Z*T%"`````!XL`4(``````,```"$
MM`4(`````""V!0BLMP4(`P```."W!0@`````O+H%",B]!0@#````_+T%"```
M```8Q`4(\,T%"`<````@S@4(``````S/!0@``````@```)S0!0@`````]-`%
M"``````"````:-$%"`````!DU`4(``````<```!@V`4(`````.C;!0CPWP4(
M`@```!S@!0@`````W.8%"'SO!0@"````J.\%"`````#8\`4(X/(%"`(````0
M\P4(`````(3X!0@``````@```##Y!0@`````(/H%"``````"````D/H%"```
M``!(_`4(``````(```#8``8(```````#!@@``````@```+@&!@@`````M`<&
M"``````'````+`@&"`````!H"@8(``````<```!H#`8(`````"0/!@@`````
M!P```.`0!@@`````;!(&"+03!@@'````X!,&"``````8%`8(``````$```",
M%`8(`````.@4!@@``````0```.BM!0@`````>+`%"``````#````3!4&"```
M``"$%08(```````````@%@8(`````%`6!@@``````````+@6!@@`````Z!8&
M"```````````3!<&"`````"$%P8(``````````#T%P8(`````$`8!@@`````
M`@```,08!@@`````!!D&"```````````E!D&"`````"`&@8(``````,```#X
M&@8(`````'`=!@@``````@```#P>!@@`````;!X&"```````````'!\&"```
M``!,'P8(``````````#<'P8(``````P@!@@``````````(`@!@@`````L"`&
M"``````!````&"$&"`````!0(08(``````$```#8(08(``````@B!@@`````
M`````'PB!@@`````M"(&"``````!````'",&"`````!4(P8(``````$```#(
M(P8(`````/@C!@@``````````)@D!@@`````R"0&"```````````>"4&"```
M``"H)08(``````$```!8)@8(`````*PF!@@``````````(PG!@@`````O"<&
M"```````````;"@&"`````"D*`8(``````(````@*08(`````&@I!@@`````
M`````.@I!@C@:@4(:"P&"#@O!@@#````:"\&".!J!0AD,08(I#0&"`,```#4
M-`8(<#@&")@X!@AD/@8(`P```/0^!@@`````+#\&"```````````G#\&"```
M``#0/P8(``````,`````````````````````````````````````````````
M``````````````"9`````````(```````````````(B+B8H`````````````
M`````````````````````````)>8````D)$``)25E@"<G8\```",````````
M````C@``````````DI,``````````````````````````````)J;````````
M``````````````````````````````````"!@H6&````````````````````
M````````````&B)T`74!@P!S)78!=P&'`.8AZ"'I(><A)B`B(3`@(B`8(!D@
M.2`Z(!P@'2`>(!,@%"`2(E(!4P$@("$@`?L"^P````````!1<0``````````
M`````````````````%=W``````````````````````````````````````!,
M;```````1@``0P``````````````````4P``````6ET```````!F``!C````
M``````````````!S``````!Z?0``0$%"`$1%1TA)2DM-3D]04E0`559860!;
M`%Q>`````%\`86(`9&5G:&EJ:VUN;W!R=`!U=GAY`'L`?'X`````?T``00!"
M`,<`1`!%`,0`1@!'`$@`20!*`'T!2P!,`$T`3@!'`4\`U@!0`%(`4P!>`50`
M50#<`%<`60#=`%H`7P`6(6$`8@#G`&0`90#D`&8`9P!H`&D`:@!^`6L`;`!M
M`&X`2`%O`/8`<`!R`',`7P%T`'4`_`!W`'D`_0!Z`'\`9"ME*V`K9BM<*40K
M."M(*S<K2BLP*TPK0RM.*S@K22LW*TLK,"M-*T,K3RLK)'<D+21X)"\D>20Q
M)'HD,R1[)"LE=R4M)7@E+R5Y)3$E>B4S)7LE.R5\)40E?25()7XE=29X)@``
M```````````````````````````````````B*2,I<2%R(20I)2EX(2\A)BDG
M*2@I3"(I*2HI*REK(5XA+"DM*2TA>2(N*2\I,"DQ*3(I,RDT*34I-BDW*3@I
M.2DZ*3LI/"D]*3XI/RE`*4$I0BE#*40I12E&*4<I2"E)*4HI2RE,*4TI7R%.
M*4\I4"E1*5(I4RE4*54I5BE7*5@I62E:*5LIW"E=*5XI7RE@*6$I8BEC*60I
M92EF*6<I:"EI*6HI:REL*6`A;2EN*6\I<"EQ*7(I<RET*74I>BDZ*DDJ(2HL
M*CPJ2RI9*E\J/2I,*D`J3RI0*G@I?2D^*DTJ/RI.*EHJ8"I;*F$J?2IV*7LI
M7"IB*CLJ2BHD*B\J(RHN*D$J42I"*E(J>BIY*7XI0RI3*BLK*BLY*D@J1"I4
M*B4J,"I=*F,J)RHS*B8J,BI'*E<J*"HT*G<I?"E>*F0J12I5*D8J5BHI*C4J
M*RHX*BHJ-RHI*R0K;RAP*'$H=BAW*'@H>2AZ*'LH?"AT*'4H12LS*SDK.BLE
M*[@K/RMN*B8K+BNP*\,K,2LR*W4J*"MY*C8K/"LB*T(K+"MJ*G0J:RHT*WLJ
M92IV*F\J+RML*D$K<RIP*F<J?"IQ*F@J)RMM*BTK-2MF*K<K.RMX*G(J0"MI
M*B$K?BHC*W<J/BL]*S$J4RM4*U4K5BLB*E@J+2HV*G$KX"MA*V(K8ROD*UPK
M6BM?*WTK6RM7*VTK62M>*UTK>"MY*WXK:BMV*W<K:RML*W(K9RMO*WHK:"MP
M*W,K=2MI*WLK?"MT*VXK4BLA)B(F(R8D)B4F)B8G)B@F*28J)BLF+"8M)BXF
M+R8P)C$F,B8S)C0F-28V)C<F."9!)D(F0R9$)D4F1B9')D@F229*)DLF3"9-
M)DXF3R90)E$F6292)E,F5"95)E8F5R98)B<G(2<B)R,G)"<E)R8G*"<I)RHG
M*R<L)RTG+B<O)S`G,2<R)S,G-"<U)S8G-R<X)SDG.B<[)SPG/2<^)S\G0"=!
M)U$G4B=3)U0G52=6)U@G62=:)ULG7"==)UXG7R=@)V$G8B=C)V0G92=F)V<G
M:"=I)VHG:R=L)VTG;B=O)W`G<2=7)W(H<RA&*T<K4"M1*SXA?",](4(A1B%'
M(4@A22%W(G@B0"-%(40A<R)L(6TA*")K*%@K?BQL*&TH;BA]+"$I;B%=(U\C
M8BUD+6`C<B)<(W@G>2=Z)S4M-BTW+3@M.2TZ+3LM/"T]+3XM/RU7+34L-BPW
M+#@L.2PZ+#LL/"P]+#XL/RQ`+"LB+"(J(BTB<2(G(R4C)B,H(RDC32).(BLC
M+",J(RTC3R)?(E`B1R)@(CHB1B([(ETA6R-E(F<B9R%X+5PB5")5(DHB2R)!
M(D`B:2)J(G,M:"%H(F8B;")M(FXB8B)B(6$B:R)E(68A8R)D(F\B<"(^(C\B
M0B)#(CPB/2)$(D4B42)2(E,B.B-=(GDM=B=W)T@B22)>(GPG0B=#)T0G12=&
M)T<G2"=))THG2R=,)TTG3B=/)U`G?B=])R$M(BTC+20M)2TF+2<M*"TI+2HM
M*RTL+2TM+BTO+3`M,2TR+3,M-"U!+$(L0RQ$+$4L1BQ'+$@L22Q*+$LL3"Q-
M+$XL3RQ0+%$L4BQ3+%0L52Q6+%<L6"Q9+%HL*RPL+"TL+BPO+#`L,2PR+#,L
M-"Q:)ELF7"9=)EXF7R9@)F$F8B9C)B$H+"@B*"TH(R@N*"0H+R@F*#$H)2@P
M*"<H/"@W*#(H*2@^*#DH-"@H*#@H/2@S*"HH.B@_*#4H*R@[*$`H-B@C(B(B
M;28E(B0B(B,A(R<B)B(D(R,C(2)^(3LC>R%](7PA9RAH*&DH:B@_(WXB:"9I
M)FHF:R9Z(7DA9R9D)F4F?BUJ(6DA.B8])CLF0"8Y)CXF/"8_)FPF?2)V(GLB
M?")U(GHB=")[)WTM(2PB+",L)"PE+"8L)RPH+"DL*BPN(R\C?2-^(R$A(B$C
M(3<A.2$Z(3LA4B%3(50A52%6(5<A6"%9(5HA6R$I(BXB3"%-(5HB6R)8(EDB
M02%@+6$M9B8S(C0B-2(V(C<B/",A)"(D(R0D)"4D)B0G)"@D*20J)*LD+"2M
M)"XDKR0P)+$D,B2S)#0D-20V)#<D."0Y)#HD.R0\)#TD/B0_)$`D021")$,D
M1"1%)$8D1R1()$DD2B1+)$PD321.)$\D4"11)%(D4R14)%4D5B17)%@D621:
M)%LD7"1=)%XD7R1@)&$D8B1C)&0D921F)&<D:"1I)&HD:R1L)&TD;B1O)'`D
M<21R)',D="1U)'8D*R$L(34A-B$Y(GLC(24B)2,E)"4E)28E)R4H)2DE*B6K
M)2PEK24N):\E,"6Q)3(ELR4T)34E-B4W)3@E.24Z);LE/"4])3XE/R5`)4$E
M0B5#)<0E125&)4<ER"5))4HE2R5,)4TE3B5/)5`E4252)5,E5"55)58E5R58
M)5DE6B5;)5PE725>)5\E8"5A)6(E8R5D)64E9B5G)6@E:25J)6LE;"5M)6XE
M;R5P)7$E<B5S)70E=25V)7(G<R=T)W4G)B$\(3,A-"$X(FXF;R9P)G$F<B9S
M)G0F]29V)G<F>29Z)GLF?"9])GXF:BUK+6PM02A"*$,H1"A%*$8H1RA(*$DH
M2BA+*$PH32A.*$\H92UF+6<M:"UI+5`H42A2*%,H5"A5*%8H5RA8*%DH6BA;
M*%PH72A>*%LL7"Q=+%XL7RQ@+&$L8BQC+&0L92QF+&<L:"QI+&HL:RQL+&TL
M;BQQ+'`L<RQR+&\L1BU*+4$M1"U"+4PM2RU%+4TM1RU/+4`M3BU#+4@M22U?
M+6\M;BUM+5,M5"U0+5$M4BU6+54M7B-C+2,N+:$RH3.A7J%6H7ZA4RXKHVCT
M+Z-;+DBC7:->HV&C9Z,CI":D+Z0XI$*D2J1YI#^E0Z5!I5>E(Z@EJ"FH**@L
MJ%]//JAO3U:H6:A<J%ZH;ZAQJ'2H>:A[J#NL1JQ*K&"L6ZU?K7&M-JY\K2ZN
M,JXTKDEU;:YEKBBO*:\LKS2O?G4A=DBO7:\Z=G>O.^Y"[G'N?NY`[U3O<.]W
M[RCP9G<_\$'P0O!)\%#P-/%->$;Q2/%<\6?Q;/$B\BWR.?)D\G3R=_)]\C/S
M-_-'\TOS2/-3\U?S;7DK]#;T._1.]%WT8?0^]4+U2/5*]4SU3_59>EIZ;/5N
M]7?U-?8R]C3V6?94]FWV;O91>T_W;/=@>R3X.OA#^$[X4_AK^"GY/_E)^4M\
M7/DG^EA]:OMP^W7[>/LW_%7\)OTH_2K],?T^?C_]*OXM_DO^8/YL,'I#(J$W
M/'Q+9CXP.V4^/#)423]-(Z$B4"\Q)*%N,R-0)$!"4E8U.DIG/CY.0DHD+B6A
M)%`FH2[P9D,GH24N)BXE4'HV)E!=-#!#9SPG4"A0**$I4#5'5S4IH2JA-T=C
M1D,X,TLLH4EI*E!H/BM0-3(OH64V<#AI3"96,*%P37U&)30U-2Q0+5`[3CU-
M:$$O4'8[<T8G+C)0/C%?.%XX9C!+3TI/,SHA,#&A,U`T4#50-$LV4'(X9S!R
M2WPU?35^-6)$/$XW4#A0.5`TH4T_-:$WH3H]3C\^4#BA/%`]4%@U.:$C.G`R
M.U`Z4"E*.J%&.T4[/D(_4%5)9T`\H3@A0%!"4"@N94)A3DHP.Z%!4#XR1#8]
MH6=#/J%O-T-0)$<I+BHN/Z%K-"LN1%!+,"PN8#AL-'I),DA9-4"A<3)G4$%%
M;$=&4#Q(8DY"H2T_1SMW.T`R0Z%11")#2E`N+B\N3#!C1#L]-#HD34Y"1*$_
M,C`N25!%H3Y-15!'4&XZ2%`D53$N+2Y!H5!0,BXS+E-045!",CM*2U!'H4BA
M2:%/4',X2J$T+D@[2Z$F-$RA5%!,4#4N8TYX.TU04E!-H38N55`W+DY03J$A
M-DTP(C9!,B55>4MN270X4*$O/S=.4:%82C@W)4)D,E*A.2Y3/5.A65!4H5Y0
M7%!5H5=0+T):4%U06U!=2EA0.BXN/W-+7U!@4$^A)#UM4%>A4$<V26A0<$HV
M,FQ06*$[+CPN9E!O4%)!1#A<1STN1V!9H6Y0745:H6-0=C@^+G4X85!;H5RA
M6CQI4%VA;TI-0V50<3<_+F)0:E!D4%%.:U!!3T`N9C9P-T(N02Y#+E^A<%!@
MH7%0=5!.,&&A4$IT4&*A<U!W4&.A=E!D1&2A<C=EH6:A>%!GH44\)D)E1'8V
M>5`V-7I0?%!IH35+9C=JH6NA1"YLH6VA,3MW2'M0;J%HH6^A13I#37&A?E`C
M47U01#I]/7*A<Z$Y-R11=*%/-G6A(5$B444N+T9XH7Q!1RXC-GJA34LE47NA
M/4XF47RA*5$G44@N3D%]H2A1*E%&+G:A+%$K44A*-S4N42]12RXO,DHN(:,M
M44PN=#PR43%1,%$CHU90,U$DHTTN?CTT425-64Q.+C91-5$X43=1.5$Z470P
M-3@[-SP]>T,D-FA`=SA/+FXY/%%(3$9%>3L[43U142Y2+EY%=3,FHSY1?D8T
M04!105$L2'@X.T]"428V**,\2C9"<38U173T<S=#4411*:-B1E\Q1U%].BJC
M1E%&.DA1;F9)44%+2E%+44Q1:3XLHTP\5"XG-$]1+:--43U,3E%:25!145%2
M45]%+J-6451155%346,Z5U%J3&1.,*-8454N*$!945H]6E%6+GQ#/TY@1452
M6U$E=$4V5RY<45Y+6"YH/7Q"7E%D1E]162Y@42XS,Z,THV%1)S9,1GHQ4#TA
M2&)1845:+C6C3S]C42Q*6D`B-"DT9%%F43HW-J-<+F5172XWHW-.:3T]2$Q*
M9U%X36A1:5%^16I1*4!^.G0W:U%).V\Y9D1M42="7BYO.FY1;U$P06Q1<5$Y
MHS9+7RYD.3JC<%%@+G4W7CIM1W11<E$[HWM):CY[460S=5%S44]!/*-W4791
M/J-$,SVC8#=\42U.>%%]47I182YY44"C3TYY.$,R=$Y"HT.C=3U8164Y(E(C
M4D2C94XK3R52>CA%HT:C)%(O,R925DL\1"9-8BY92D>C9"XG4F4N2:-5<#!&
M9BXH4BHT,TQG+B$^*5)G2BU2*D`J4E`V*U(K-&DN+C<N4B]22Z,P4C%26SQJ
M+GLX7DQK+FA,=T9Q2C)2;"XS4DRC3:,U4C=2-E(X4CTR3$M\.CE2;2Y902(^
M*38Z4DZC6T@[4CQ2/5)/HSY2)$EH-F4P4*,_1C]2/3U1HVE`05)`4B,^83A#
M4CY(1%)<2#1";D(H-FY&,4-N1TY+1E)J0&\N<"XU-U2C1U)5HTA2+#%U,&TT
M*$)1-7%-2U(W,E:C2E)Q+BHV3%)Q3'(N35)23GPX<RXV.$Y25Z-04D]27S\Y
M,5XQ45)24G0N-SA8HU-26J-N-5NC,CM44G1+-3I:-2=-4$$_2'T\1SU?HV@\
M=3QV/6"C0$A74D,Q44%].$4X9S9;4B%#?D(K-B0^7%):4D0R9D(X/$L[)C%B
MHV.C<#-F.4H[75)>4DDU1C-G.4@U7T0E,3%&/DPA.7E-1T5^.'4N+S=G4F,V
M2DMEHUU(=BYFHV927C1A4F)29%)E4ELU83\M2F-27U)C.&!2)$]HHW)*:$1B
M.'`Y=RYH4EU&9*-L4FFC:J-^/'8\>2YKHV]2;5(C3'HN:E)S4FY2<5)&.#],
M>RYR4G12=E)\+FRC<#I"3VVC:U)I4G52<%)NHWTN>"YOHWXN>%(C4WI2<*-^
M4B$O(5-[4G&C<J,^4VDZ,3-SHWE2=*,E4W8P)%-UHR4P2DDB4W:C?%(B+W=2
M?5)(.B93=S`O4R=3*%,E/FE+>*,M4RQ3>:-ZHR]%>Z,N4RM3(R]\HWVC-#$V
M.C`_?J,D+RE38D4J4R(P)2\T4R--)SXZ4R8O.5,P4R&D0T(Q4R*D;T(V4R8^
M)*0EI#-39$PG+SPW-U,X4S53.U,H+R>D**0R4RFD05-&4RND0E,]4RDO+*1'
M4S%!*B])4RVD(CD_4WU#*R\NI$-3/%,M-&XT93-$4T!3=C=*4TA34T%*-2PV
M+2]%4W0V1#$SI$Y33%,G5#2D-:0N+S:D,*114TM33U,WI$U3.:1,.U!3.Z13
M4UA35E-54S)#/J0P+T4R,2\_I%)35%,H/C,Q5U,\I%XR8E-`I'P^7E-<4UU3
M0:1?4S(O0Z1$I$6D/3%&I#,O.4%94UI3>C-'I$BD85,U+V\T9%-@4V-32:0W
M+S@O.2\N2C0O548X2&9395-%,TND9U-,I&I3:5--I#HO3J1/I#LO:%,Y1VM3
M4*0\+STO4:1L4U*D/B]N4VU3<%-S4W%3;U-R4U.D=%,_+T`O5*1U4W93=U-X
M4T51?#Q-.W,R5:1X,$1#5J1Y4R0Z3S!>/U>D6*1Z4T<X<3E\4WM38$I]4R%4
M?E-!+R)4(U1W-V`Q)%1:I"94)50H5%I%0R];I"E4-3!?.EVD/3=$+T]#12]&
M+RI4*U0M5"Y49#I?I&"D438W2V&D8J0L5"]403HC.3-4)3HS0V2D,%1:1&6D
M1R]FI&>D:*1(+VFD22\T5&(_,E0U5#\W-E1MI$HO;J1OI#=4)#E`,SE4<*0Z
M5&RD.U0X5$TO,50\5#U43B]/+V1+<Z1K/E`O/U1`5#Y40E1QI#A'=J1H,%9)
M0U11+W>D4B]XI'T^4R]4+SD\>J1=1W`T>Z1K.GRD52]92S)&?:1X-T]"5B]!
M5$141$)%5$94?J0AI4A4:40BI2XT(71A,7-*(Z5L/DA%)*5F.DY4/4I=3B:E
M=#)*5">E.D%-5&-%245D13E(341).E@O2519+RBE=C$V14M41U10/T]46R].
M/2TV4%1<+RFE*J4KI2RE+:5H2BZE?4%&1"^E72]25$]+7R\PI5-46%0QI2]*
M5U115%145E0F.DE*,Z595$5#=3)M/C2E8B];5&$O6E1C+V@Y7%1>5%U49"]@
M5%548E1E+S6E851?5&8O3CM1/U1!8U0\0&TP9$<VI3>E6T1E5&149E1G5&A4
M:50XI3FE44IJ5#JE9R\[I48R:U0\I3Q-,#-)4D@]/T)L5&M,-$P]I6Y49T(W
M14!"5TEO5'!4>S$Z/'%44#!R5$"E<U1B,4*E<31@1G1*=U1507940#=;2W54
M945Y5'A41:5I+T:E>U1Z5'PQ?%0I/GY4)4-]5&HO,TIW/5M%2*5)I2%52J4E
M.2)5(4=>2%%,)4=K+RM5;"\X-45-+TPL5B-52Z4F56TO14(X2TI%3*4G565+
M2CI-I2H^;B\H54ZE4#M/.T^E.3!(.&\O*T!1,"Q5+54J57`O4*51I5*E.#$O
M-%.E*55%3#%)5*4H,'DP43M2,",P,E58I5FE,%5Q+UJE/$PS53%5+U4Q/W(O
M+E5;I5I*7*5D.#=5.%4K/C15+$],1S957:4G.CE57J5827,O.E4U570O=2]?
MI78O.TQW+V"E7D<[53))8:5X+V*E8Z5DI7DO9:5FI6>E:*4\54!5/55II4<R
M/U5Z+SL\/E5Y-TQ5155"56JE:Z5LI61#055MI4-51%5OI6ZE<*5&54=5<:5R
MI7(T255(54I5<Z5\+VX^?2]-55Q$=:5%,4M5=*5.54]54E553U!5455VI5([
M4U5WI28Y5%563WH[.$)555956CLG.5),*#5).%=56#-XI5A5.4)YI5E5(U9:
M55M57%5>57JE5T][I5]5?*5@57VE<$(G,6D\0C!703`T-3PH.5A/9D4AJ"$]
M,31H0VI$.#`Y-75*0CQ2-6M`/#PH36%5(JA<-4LZ,C-C,2P^2#)B549-23TD
MJ&0\8U5S-%)&*4QD565564DFJ&=5*#1W-F95)ZA93S(T,C]K52$[23)J56A5
M;%5I52M'35PS/VU56D]`3FY5*JAP57Y#;U4C0'L[*ZA00G<\=4EL0"VH33QQ
M52T^<E5S55,P.D)2/W15,T8N/B\^6T]U56U`,#Y<3W95=U5=3V!,>%4NJ%Y/
M1C8OJ"(]>55Z55P\+#]T1E0_>$@B1TDV>U5O-7Q5?C9/1C`R4SM]52)6(59]
M-GY5.$4P0C&H2T5(/&!/,JA807I-,Z@TJ#6H)%8E5E9&-J@S.R=6*%9D3SFH
M/*@]J"E694]T-"I6*U9F3T&H+#)"J&=/0ZA$J#M!9#1H3RU6*$Q&J%)"63-'
MJ"]6,59?-&E/+E8P5C-6,E8T5DFH:D]K3VQ/-58]1BXV93(V5CM6.59W2G9*
M;4]G13A65#TW5DRH<C\\5G!/:CI-J$)60U8]5C,S/E9'5D96159!5D^H0%90
MJ$164:A2J'%/>$I.J%.H5*A5J'-/=$]V3TM62%9*5G)-259U3S]65ZAS/UBH
M3%9W3S<Z6JA-5DY6>$]15E!63U9=J&A%.E975E^H8*AAJ&*H4U9Y3U)6>D][
M3U16559CJ&2H9:A85GQ/9ZAF3EE65E9:5GU/8#1;5FBH759<5EY6::AJJ%]6
M;D`C/6NH9#TH=&-!;:@I.3@Z*CEP-6ZH8%8Y.DHX858F3$-'8E8K.2PT)T-2
M-G"H5#M;24%(8U9U-&96<J@I='.H(40J=&569%9G5FM$=:AC/U4[2D!VJ%-"
M(C4B1&A6:59O/CE+=ZAL5FM6:E9]27-6>*A:2VU6;U9K2WJH;E8K="QT<%8H
M2'%6/DIR5GRH?:A^J"&L,S0_2B]'=%9U5BPY-#1V5C@X1$TI378T>%8C1"TY
M,3Y?2#(^>#UL1'E*.44N.5Q)>58CK%E%0CHDK$LX):QM1$,P;CTO.4=-)JPM
M=">L>E9[5E%'**Q\5G=.+4\O='Y6?58IK$<S(5<JK"17)5<C5T!),SXG5R97
M(E<H5RE7*E<M5RM7+%<N5V0Q;D0O5S!T>C=V,C9'+*PP5WM&,71;2C)T,5<N
M3S-T+:PR5T!*-5<A4#%0+JPP/'5&-E==-21$>C`W5R9*,#E00R^L-'0QK&]$
M-71O3#DX3#@X5SE7/U=E/#9T)40W="\V.E<K23AT1D,Y=#M7.G0RK#Q7,#8]
M5SY70%=V13MT05="5SQT0U<T5S-71%=!-S.L/70G23YT3#HW229$2TE%5S0^
M1C$TK$971U=R3&!(/W0UK$I7?3$L0$E72%="-U1"3E=,5T!T2U<G3F4X-JQY
M/4U73$4^/4!&45=05T%T3U=25V8X-ZPXK$)T4U=\25L]5%=Y2$-T048G1$1T
M170YK#!%55<K-30_.JPL23RL1G0]K'<T)D<^K#^L0*Q65U8[.DL[2WXQ6U='
M=&E#2'1!K%A7271W,D*L0ZPM6%I71*PP1UE75U=%K'HY75=*=&-7:5=A5UQ%
M2W1F5UU)1ZQ,=&!795=G3E<[54)>5TBL2:Q>-6A7+4!E,6)7>#)G5S$V9%=-
M=$YT:E=L5W97=%=Q5T]T<%=X3DNL<E<R-C$Y>CUY5VM7;U=?5WHR<U=U5U%#
M*#HX,FU7>%=W5S,V*4)F,T,W;E=,K'I7?5<A6#T\3:PG6'!$>U<E6'DR3JPC
M6"18?E<B6%%T4G1G."I--319,2983ZPZ1RTP4:Q2K&%(7%<L6#!894PI6&E%
M+EA3K'`^+UA71E2L4W1'3RM85'15=#%85:Q[.5:L2T!6=%0P*E@H6%I!?%<T
M.U>L1D(]6%BL6T$X6%FL-5@V6%=T9CPY6#Q8-U@E/3I8-%A\3'M,/E@_6%4P
M6JQ;K%RL,UA=K'(V)C!8=%ZL-C0[6$-80EA9=$=86G1(6%MT7ZQ&6$E805A%
M6&&L2EA+6&*L0%A\.T185D(R.3)8-3]86&E*3EA/6%!85UA66&.L?4LW-%18
M13<T,U%8.$Y36%8P55A,6%)865A$-TU89*Q=32M-7%A@6%UT?D%Y3F%89JQG
MK%Y86UAHK&FL6EA?6#!*:JPT1FNL1C=B6%U8;*QC6'LW,3)@=&M87W0X-&E8
M:E@I.FA89EAE6&Q89%AN6'LR;JQOK'"L<%AO6"A$<UAQK'%89UA\-W)8=EAU
M6'=8=%AX6'E8>EAJ2GQ8>U@_/2Y`9C)\,GU8<ZP_,$Q`?EA#;"%983<B66)T
M=*QO0'6L(UDD63HU)5DF62=95T)-.&%,8W0\2VH]*%ED=':L<$`];F)(:CQW
MK$TZ*5EXK'FL1T(G2F5T<4)F="Q9*EDM67JL*UE[K"Y9?:PQ2F=T-S!^K%Y)
M8TA\K"]9,EDU/CLU,%DW638^:'0Q641'7DTS6319.%EJ1359,SE>0"&M1EDT
M2')"(JUD2"U:>DIQ1'5+.UDA,FI#1%EI=#1#/EE%64!91UE#64)9;T<\67TR
M.EEQ-7-"-EDCK6IT.5DT.5M`-SY!65)'<C5(,V<S(3])64Y92EE]-T]9(CMI
M.6MT):TF/3U9?3M,62:M6#M-640P;'1(62>M**TI1&UT<S4T-DM9)S!#.C8_
M*ZTLK6YT<D0MK2ZM5$A165Y!+ZUO=#"M*D(K.U)9,:U465!984H]1#.M7$%P
M='M*3CQ@65]9-JUX/WXW65DY/FA&,4=Q=%=974$WK7@\7%DX/E996UE31SJM
M55DA-SBM73-=62M.3CHU0UI97$`U.60_9C$\05A9135'-T]$7EE?03NM85EC
M63=":5ED669904ES1&=9/:T^K2Q-2$TY-#^M0*TN,&59<G1B64&M0JUS='@T
M0ZUG,71T:%D\K4E-;%E$K3M"<UEU=&U9=G1J67%94UE%K7=T1JUN67)91ZU"
M2&M%2*UK66]92#=Q.EU`=UEY="9%2:U*K4NM>G1T66!+>W1U64RM=EE.3'AT
M(D!-K6(W3JU]64^M-3MZ67E9,D=0K35&4:TQ17M9?%EO245'(SMQ0%!+23,E
M6GY9?71^=$I-)UHA=2-:)%HB=5*M4ZU@07QT(W4B6C]95*U5K29:(5HK6BQ:
M)T4N6E>M6*TD.RE:/#4O6BA:,UHR6C%:)'4T6B5U-EIQ/EFM-5I:K3E:7*U=
MK5ZM-UHX6G!98*TF=3M:.EHG=7A9/%HP6ED[8:T]6CY:0%H_6D%:?C(V.7Q*
M+T!BK4XX0UI&6E))7S5CK45:1%I41T=:-39)6DA:.C0V.UA&*75DK4DW=#]*
M6C!`*$5?24M:9:UFK4Q:35IGK6BM.$I=549`::U,25@Z94A#2$U%04Y/6E`\
M*G506C8P5#9-0&!)45I".T=#6SLW/VJM:ZU26FRM?4IW,5P[;:U56FZM4UI6
M6CE.5%IOK7M`5UHR0EA:<*UZ-%I:65I;6EQ:>S1\1C9#;#5=.V%!7#TP,%U:
M<JUSK2(R85ITK2QU-SE@6G6M*SHZ/G:M+75?6CL^0$PJ.E<P3D`N=69:+W4Q
M0$<Q=ZTQ=3)U53UF2W(Z>*TS=3P^)T`T=35U-G5E6F-:9%HP=6M#)EMJ6GX[
M.#EH6GFM.'5I6C@_.75[K6=:>JTO.WZM.W4\=2&N;%IK6G!:/75Q6B*N;5H^
M=2(S;EIO6E5():XFKB>N**YA24HW<EH_=3)`/3Y`=4%U4D,IKBJN1S9S6G=:
M2S)T6G9:0G5U6BNN:STLKDA#13!X6BVN>5I$=2I$<4Y#.R^N:THPKD5U/4LQ
MKB);>UI&=7Y:?5HSKGI:(5M'=5Y&2'5\6B-;;#TD6TIU2TUX1R5;)UM+=2A;
M-:XI6THV2#$Y.2I;*UMQ/6)!3'4W=5A2/D$]05A"1SHWKG)0.*YN-RU-?DI^
M22Q;.:Y-=7,Z/T0M6R]/.ZX^2RM$+EM\-"];,%M:3"1,=DM<2R4[,EMK/$]U
M44LT6S=;-EMY-&`U,ULU6SA;4752=7D_/JX_KGM-23!@.CQ"73Q`KG,^.UM.
M14&N.5LK0CI;<CY=3#Q;/5MH35!U0ELZ.55'/UML15Y:8EI%KD\U1JY'1U-U
M05L^/D1(5'5'6WI(/EM$6T-;3T!(KE5U;4M33E9U9TM7=4PR7CM(3T9;=3]%
M6T!;3SA,KDVN3%M*6TTR2%M.6U1;6'5:=4A"3JY!2E9;3ZXB255;<$<_2SLT
M4*YW0$`]6W531%&N+DU2KE%;4%M26T];5UM-6TM;4UM)6U.N;$-X3$8\=#I4
MKEEU.CI<=6]+03-==4Y$2D9),4NN<D`T0"HW6*Y?=5E;6:X[.7PS6UMT,V%;
M8'5:KF%U7EM<KG-`2S,L.EVN2C-/.EZN7%ME-TLW;45?KF"N6EM&,&&N8JY=
M6U];338L-UYU/#1+-6.N9*YB6V)U>3IQ2S<[8ULP26:N9ZYC=6];9'4S,F1;
M:*YIKG5;95M"3FJN;%M?1W1;9UMKKC0P:5MLKCPY;JYOKG"N:UMQKFI;9EMQ
M6S\^9G5G=6U4:#A\37*N<ZYH6W1$(S,M.FAU8%MTKG!;83-N6W);=:YN17JN
M?C1[KC)<:75)3'=;?31\KGY;?:YJ=4!+(5PC7'ZN)UQY6R&O*D-O12M<?%LH
M7"*O(Z\B7&MU)*]L=3D_+%QM=6YU,T`EKRI</31VKF]U4$]V6R:O)EQ8,">O
M>%MP=3I,?5LB/T=$<ULE7'H_+UQQ,R$X,5QZ6S!<*5Q[6RU<+EP_7$Y&<W4D
M7#M<*Z\]7%A$='4MKW%U3$UV23A<2D)U=3Y</T$U7$)<05QO1D!<:D9V=7=U
M>'4NKT1<-UPOKT@V.EQ=/3"O8$<\7$LV-%PV7#-<,:\P3UHS.5PRKWEU0UPU
M,V<Z73%47#.O,4]77#6O-J\Z/U9<55Q[=3>O4EQ\=49<.*]C7$5<6%PYKSJO
M4%P[KTM<2%P\KTE<45PB=$Y</3E(1&1!3%Q]=4=</:]*7#ZO34UJ2T]<65PB
M=D2O85Q:7"-V)'9G7&5<1:]&KV!<1Z])KR5V)G9?7%!$94%*KUU<6UQB7&A<
M=4AN7"=V2Z]I7&Q<9EPH=G1#.$E,KUQ<3:]D7$`^3TQX7&M<(C@C,E\S4UQ!
MKT^O4*]1KT$^<%QW7'D\<C,J=BY#*W92KVU<+'93KW)<=EQ4KS8V5J\M=E>O
M+G9,-71<+W8A-4M&<UQ8KW5<,'9O7#%V<5Q5KUJO8#-)0UNO?%PS=ERO>EQI
M.'E<7J\T=B%=6%LU=C9V7Z][7&"O?5Q^7#=V+%UBKRA=;5LG729=(UUCKVI<
M)5TD762O9J\J729/9:\M77LV9Z]HKRE=*UTX=CEV)T@N76NO;*]MKVZO,ETO
M76^O<TTP75Y<<:]RKW.O=*\S731==J\\=C4Q/78V76<W(3Q5-B0R/G9XKU]-
M/W8X73==.ET]-58V/C0]74!V/%T^77FO3C(W0S]=/S1!74%V>J]`74)=0UU"
M=D1=7SLU0"$Z0W9P241V8DI$3WNO=3M0.G).?*]%=D5=1EU]KV`[1UU(77ZO
M1G9*74E=6$M>/6P\1#M+74U=(S],72'N3EU/74=V4%U174AV(NY2751=4UU5
M724R2D-6728[3#-7723N)>Y"14Q4(S5872;N)^XH[EE=;$IH2TIV1T9:769(
M2W9,=GM(*>Y33%M=*NXK[EU=7%TL[E]=+>Y>74UV+NY.=F%=+^XP[F$[3W8Q
M3&)=8UTD-61=9EUE75!V93\Q[C+N.4E*,3/N14@U[G5$03UA-3;N1D@N/&A=
M0#11=G@Q-^Y2=G)&9UT^.5-#:5U/[G%=:ETX[D%"8C5R751V579H-R4U<%UN
M76M=8$TY[E9V5W9`1#KN649L771=<UTC-SSN/>XM,C[N6'8[.FU=;UU9=E=+
M=$)3=G=+/^Y\77U=3S(H2GU,(5XC/$(^>%U^76@Q-S9`[G5=>EU;=G1`<4=G
M2$'N=UU<=B%+0^YY721>1.XB7D7N>UU==B)+2$=C-25%;4-&[B5>7G9'[DCN
M7W8C7EE"=EU+,5IV2NYA=DON3DTP7F)V+UYV0"Q>;$TV1B9>3.Y%1$WN3NY,
M,3\Y*5YC=E#N9'8G/2Y>9>XM7BA>*UYE=F@S4>XJ7DE'9G8N3G0^=4!G=C9>
M-%Y2[DU)4^Y4[C%>,UYH=CHQ0#DR3STS8DE5[F%-)#,[/S5>5NY7[FIV.EYK
M=D,^;'98[C!-6>XW7EKN,EYM=CA>6^Y>3G-%0D9N=F'N;W9B[C8S53%C[CY>
M05Y#3G!V9$UD[G%V2%Y"7C]>9NY43D5>9^YH[FGN2CU'7DQ><G9Q14I><W9T
M=G5V1%YJ[CA#2UY`7D9>:^Y-7GPP0UY.7CP_7STE2FSN+CH[7DE>.D5V=C9`
M:3-1.D0^/5Y"/4PW/%Y=[E)>;3TZ.&%>;NY;7G0U3T5O[E9>7UXO,#(Q<.XY
M,EA>+$)/7E%>03ER[GAV;>YB7EU><^Y57EQ>>79T[G7N*TQV[G?N6EY>7GCN
M>>YZ[GON4#A\[D4^.4-Z=GMV5%Y][B]-5UY07G)%4UY97E%//CQ^2V->+DAO
M7CLX(>]@/65>+TY".7)>;C!P7B+O9%Y\=FI>?79L7B/O3TUG7BY%:5XD[WYV
M<5XE[VM>1TPA=V9>)N\B/'Y>(G=J,VA>;5YN7B?O;$):0BGO=EY\7GI>*44C
M7W=>*N\K[WA>8%YY-3I)/SQW.2SO+>\S3R-W=%XB7VDQ9D$N[R1W>4=!-'I.
M+^\F=R%,4D0G=WM>?5XH=RCO,.\R03'O(5]Y7G->0S0I=S/O:3<T[R]?*G<U
M[RI?>$`K=V,S-N\L=RUW83TS7S?O+%\L1"E?641,7R9?)5\N7SGO+G<H7R=?
M+5\A0"1?+W<P=S%W,%\Z[S%?,G<[[T(T..\][S-W-E\U7S=?/N\T=SI?/^]#
M131?0>\U=SA?-G<\[V,W>4(R7SM'.5\W=T+O0^\X=SY?/%\_7T3O0E]%[SM?
M:CDH1SE>1N]T33U?05]U0CIW0%\K7SMW:6\Y=T5?2.])7TGO1U\\=SUW2N]#
M7TOO1%](7T9?3DE.7TM?2E]-7U1&3U],[W5#;4(^=R5`4%]27T[O3^]0[U%?
M4>]2[S]W4^]U7D)W4U]5[V=&0'=!=U1?0W=6[U?O4#)8[UGO=$4E,T1W6N]D
M-5X\4CI;[USO17==[R=/9C]J,59?7N]?[U5?8N]&=T=W65\Z0UQ?5U]C[UM?
M2'=:7T!%63!@[W5.9N]>7R@Q9^]H[TEW2G=@7VGO7U]=7TMW9>]87R-+8E]J
M[VOO;.]M[V[O85]O[TQW:S%D7S)*8U].=T]W-4Q'/DUW4'=Q[U%W<N\S048^
M4G=3=WM.=.]J7WE`<^]4=U9W=>]F7VM?;#%7=W;O6'=I7V%'95]H7T@^67=1
M2&Q?43QZ0'GO;U];=UQW9U\G-VU?77=037!?>.\F='KO3SU[[WSO<5]R7WWO
M?N\N1R'P=%]?=W5?7G<S1V!W=45W7R/P>5]53G9?)/!X7VTQ<U\E\";P6U-Z
M7V=!.#M\7WM?)#]94GU?(6!N7WY?87<B8&)W>D<G\"-@)&!C=R5@)F!>1"KP
M*&`G8"E@*F`K\%\\8TDL\"WP;$PK8"Q@5D$D/"U@+F`O\"]@4DI'2#!@5T<M
M1##P9'=E=S'P,6!G,FTU1DPV3#0R-$\R\%)+*DHT\#7P-T`R8#;P0T8C.#-@
M-_!4.C5@-&`V8&=W./`W8#A@:'<^-3E@.F`D.#KP._!(2#SP/?`\8'4^.V!I
M=VIW/O`X-CU@/V`^8$#P0&!1.$%@:39`07TY0V!$8$)@;3Q(1CDV0_!&8"Q#
M16!$\&MW-4]B1T7P26!&\$M@2&!'\$CP5$Q*8$Q@1$Y08&UW;G=/8'9#+4=+
M\"4X3F!,\$WP36`Q33)-2O!.\%%@;C%V.6([4F!38'!W3_!58$,]<7=78%9@
M4?!2\%3P5?!88%;P33-:8%?P66!<8%M@<G=8\#PX6?`H3DPV6O`F,EOP<W=J
M-ESP7?!>\'1W=7=V=U_P=W=@\&$T>'=H3EY@8?!B\&/P8&!D\&7P86!1,F;P
M76!Y=SD[9_!!1%]@>G=[=WQW9&!N/&CP?7=B8&GP?G<^-TE(8V!^8&E@:O!L
M\#TX;?!E-69@?4TA>#!.(GAK\"-X)'AV0F[P:&`F>"=X*'@I>"IX*W@L>"UX
M;_!J8%9.5S9\2$I'</!K8&U@<O!P8'/P+G@O>#!X,7AT\'7P<?!L8#)X;V!J
M.$TQ<6!V\'`_;F!<3C-X=&`D=')@=6`T>#5X9V!S8'?P/#IV8'=@>/!^37GP
M-G@W>'KP.'AX8#UX?/!]\#EX?O`Z>'E@.W@A\2+Q96`\>"/Q/GAZ8#]X0'@D
M\27Q1#1!>";Q*/$G\24\0GA#>$1X>V!\8'U@*?$J\45X.S$K\2%A.TDB820T
M(V$D82WQ)6$L\2=A*&$F85-)*F$I82_Q1GA'>"QA*V$M82YA,&$O87DY,F$Q
M84AX1313/SQ%,V$X0#'Q.CLR\7DQ-&%133/Q8THU84EX1$4S34,Y/3]+0S12
M+D1H,C9A-O$W\3CQ-V$\83GQ.F$Y84):)C,X83KQ6C`[\2I(//%*2#%./6$[
M85Q#)D`K2"U)/V$L3DTW0&$^859(06$]\4)A2GA;,#_Q/O%V/D=A1&%M1D-A
M2WA`\4'Q0O$F-4/Q2F%%849A26%(825)1?%"04%!/S5,>$MA3&%-84?Q3V%.
M858Q2?%786A(46%384KQ56$^/U9A5&%`/$OQ3/%085)A0DE-\4D^66%884YX
M3O%:84_Q)CPO.G=%6V%+1%#Q76%1\5+Q(4Y<84]X4_%I053Q5?%B85;Q9&%E
M851#5_%C86!A7F%?85!X86%1>%CQ6O%2>&AA9F%G85OQ7O%3>%1X6?%5>%_Q
M8/%6>&EA:V%L86UA;F%B\6IA8_%7>'!A9?%O85AX<6%D\6CQ14Y9>'1A<F%S
M86KQ6GAB-'Y,:_%*2G9A=6%W87AA6WA<>'QA>6%Z87MA?6%=>&WQ7GA^85]X
M(6(B8B-B+TA0121B<D<T225B8'@F8BI%)S-$.2=B*&(I8BD[*V)N\2IB+&(M
M8F%X;_%B>&-X<?%P\61X<O%S\65X:4AT\2YB+V)F>&ES,&(Q8C)B+CLS8E9'
M9WA?2TXQ=O%7,6AX-&)I>#9B:G@U8G!%.4`Y73=B04PX8D8T5T@Y8FMX.F)X
M\3MB>?%<3&QX54P^1&I!/6)M>&(]2CY`8C]B/F)]2&YX1S0I.'OQ;WA\\49B
M0V(_/S),0F)$8D5B06)]\7!X?O%Q>$=B2&(O1&,T94-R>$EB<WAT>"7R2F)-
M8G5X=G@F\F<_=WA$1DYB4TM+8B?R3&(I\E%B>'@J\BOR4&)/8GEX4V)28E1B
M>G@N\E9B+_)58C#R,?)-2C+R>WA6/49.5V(W1EAB66)=8EMB7&):8EYB7V)@
M8F%B-TQB8C/R-/)\>'!,8V(U\DY#-O)J1VLV-_(X\CM#9&(Z-CKR4$`[\CSR
M96(].C[R/_)`\F9B0?)G8B8X53I"\FEB0_)6158Z3C5$\GUX)$M+1U=%7#DA
M>6MB1?(B>2-Y)'E+/D;R)7E'\C).13DF>2<X(TAM8F]B:SAN8G9$2?)Q8C<S
M;&)J2#`Q2O)L.E)/<&),\DWR3O)R8DOR2TI90'1B*GEU8BAY<V).,T_R>V)Z
M8B<\?&)W8E#R?6)X8E'R4O)82'9B>6)3\B)C5/)5\BMY5O(A8V%+?F)K,"QY
M)&,N>5?R6/)9\B-C6O(M>4P^)6-#05SR)V,F8RAC7?(O>5_R:&)J8BIC*6,P
M>5[R,7DR>2@\8/)I3E(\*V,W-S5Y-GE`-2<U8SMA\C1-,6,P8T1!+6-B\B]C
M8_(Z>4L]0#\N8RQC*D=-/F7R/$E7.F;R>$4^>3)C,V-)8U@V/4\U031C4C)W
M1"%*9_)H\FGR0GEJ\C5C:_)Z-39C;/(X8SEC*4=#>3IC;?)$>3MC/&-N\EDV
M4S)%1B@]9#MO\G#R17D]8T9Y*3UQ\G+R2C)#24AY/F-S\FM(27E%04%C0F-I
M1T$_/V-A0TIY0&-+>4X^7#`I-4QY0V-X\GA$1&-'0'GR+4QZ\B-)16-&8U5#
M>_)'3GSR2&-'8W[R;SQ*8W`P36,A\TYY2V-4,DXW3&-&.7(Y9DI.8U1+(O-0
M8R/S44!/,3HR+#`D\T]C)?,F\T]Y)_,H\U%C4F-W/BGS4V,J\T\S4'E58VHW
M*_-F-2SS5F-U-E=C?$!-1BWS8$!U.E)Y6&,N\R_S8D-K05IC7&-98UMC(C=3
M>3#S76,F-S'S9S5235]C57E@8S3S+C%6>37S-O-C8W8S8F-A8V5C7F-F8RE.
M./-G8U=Y:&,Y\W14:F-I8VMC;&,U3FUC;W!//FYC;V-7/3A&<&,Z\SOS*$-8
M>7%C/$-R8SSS)38_45U#,SQ9>4@T<V,B9'9C/_-H-75C)&1T8U`^6GEX8WEC
M*T5Z8UXS6C]D24+S?&-#\VA"6WE$\T7S1O-W8WMC?6-[.EQY0?-*\R9D+DE=
M>29(>45:-B5D(V1>>35(?F->0WM%>D5,\W8Z.&1?>4[S*&1/\RID4/,M9&!Y
M+F1A>2MD+&1B>5'S*60G9$WS(61)\T]*53(U9#)D-V14\U7S-F1S1R=,.SLP
M9#ED-&16\S-D+V1C>3%D230]0WU`6/,B2#YD6?,D2%KS84`[9$](6_,_9%-*
M6T-<\SID/&0]9%_S8/-E>69Y8?-`9$0\1D9%9$1D061B\S9/8_-*9$YD2V1'
M9&=Y9/-(9&7S361F\V?S0F154DED0V1,9&EY4F1J>4HT3V1H\U!D46149&AY
M:WEL>5-D=DA59'Q.;4I:9%=D:?-J\U9D4D!99%MD:_-89%]D;/-<9&]Y;?-=
M9$9D;O->9&!D;_-A9'!Y</-Q\W+S1DIB9'%Y8DQ.-BDW8V0T2F@_,$QR>61D
M,TYS>71'1D$T1TT]0#!T>6ED9V1E9"$T=O-1/FID:&1F9&YD;61L9&MD>/-Y
M\V]D=7EP9#I`>O-Q9'-D?/-R9'[S4C@A]#A!=61V>7Q%(_1T9'=Y=F1X>35*
M;$%'.7=D)?1(3B;T>61Z9'MD*/1\9&4[?61/-VHU*C4A92GT<TQ(.7YD>7EZ
M>2KT)&5F3#Q',TDL]'MY8STC95,\23EF.VDU-DHB97QY+?1'04)+=SI]>6<[
M740G95].63I^>2AE0C\J95(^,#HP]#'T*64R]"%Z*CT^.$A!)64K93/T(GHF
M95`W+F4R96LW(WHM93?T./0V921Z2CEM33PP,V5K-3!E.?0Q93KT?44O92QE
M*#-D0"@X)7HX93ST)GH^]#_T-64G>D#T-V4T94'T43<S0CEE;D%#]$9E*'I"
M93QE*7I$]$7T0&5Z/%TP.V5#94=E2SE63%9$/65&]$?T164Z93Y#/V4],$I,
M2/0J>CYE6S9L2"MZ;4%03F\];F4L>DGT2&5*]'Y`1&5)94ME>41.92UZ2F5+
M]%1*2S1+3%XP3/1-97U.3?1,96\Q;$9/93!Z5F5095=E4?0Q>E-E,GI2]'M'
M4_1*/%5E5/1295AE465$/57T+WHE2U;T3#U496!E7&5?95UE865;94%E4T!+
M2%YE5_19931Z(4%2-RL]-7HE/S9!9&5F96=E8V5E939Z6F5B96IE:65Z2RLW
M6/19]&AE;&5K96]E6O1Q93P[;65;]%ST<F5S93=Z=&4X>GIE.T5V95[T=65W
M97AE>65?]&#T>V5\94PT?65^96/T8O1D]&7T9O0A9CEZ(F8C9B1F9_0E9B9F
M:O0H9B=F*68J9BMF;/1M]&[T+F8L9BUF83I3-V_T5D,S2'`]34=M2"]F;5AP
M]''T,&8R9F5-,68T9C-F4TTU9GY(<_0[>C9F=O0\>CEF=_0X9C=F.F8R-R)!
M035X]#YF.V8\9C]F0&8]9BDQ/7HG,GKT0F9#9D1F8DT^>GOT+#U&9D5F/WI`
M>FD_1V9\]'WT2&9)9F4T07I">G[T330A]4IF2V9#>EU+8TU433=/(O5-.4YF
M5#Q-9B3U(_5/9BD\)?510B;U4&9%>DPY)_573%%F4F939E1F*/5&>E5F*?4J
M]2H\1WIM3$AZ5V9)>C]#5F8K]5EF6&9:9CM`6V9<9CE*769O05YF+/5?9GY.
M8F8M]6%F8&8P1"[U8V8F/V1F+_5E9CA/9F9G9FEF:&8E2'E&/D\I2&MF4SXJ
M23#U;&9J9C'U3C14.&@[,O5N2#/U*CA#2V]F;69..4\Y:3!H.C3U64=?,'1F
M-O5`0TIZ6$=;0C?U=F9+>CCU<F9U9G!F<V8F2TQZ53A],'%F.?5X9GEF37HY
M1CSU.S8]]29G/4=I.SPV2$!&3RY,=V940#OU0/5.>E,U>F9!]7QF0_5$]7MF
M1?5]9B9#/D<_]3%$1_4C9R)G3WI^9E4_94DE9R1G4#E33S5G4'HI9RIG47I2
M>DGU<#Q3>BAG>#DG9RMG,D0B2B-!7$(O9TOU,&<L9TWU3O4M9RYG43DV9S)G
M4/5F26Q+*$DQ9S1G,V=$2S=G.&=1]3=!.6<[9S]G5'H\9SIG/T<]9U+U/F=3
M]3(R16=`9U5Z06=6>D)G(4)4]5=Z1&=#9T9G5?5'9TAG0S]7]6DR26=73BL\
M6?4M/6H[5T-*9TMG,3%;]4QG7/5-9TYG7O5/9U!G/38J6E%G94!29TL\4V<P
M4%1G7DI<-&#U)$%8/7%)+CUA]6+U56=2.59G3$AD9V3U6&=E]4E"=4<_.%=G
M)4%F]5EG:?5G]7I$:/5K]6WU;_5;9UIG76=Q]5QG7F=;>F!G<O5?9T\T86=B
M9V-G,3I)3F5G)S]<>G`Q9F=G9W;U>/5H9WGU>O5[]7(P:6=>>FIG?/5G24<\
M;&=?>F!Z87HI,S(P??5^]6)Z:V=N9TY'8WI$/U8R(?8G2R+V9'I=-UPV(_9M
M9R3V:C)E>F9Z(S1G>G$Q<F=J3EU":'I$27YG5S)\9WIG<6=O9R7V<&=C/&PV
M=T,F]E%&43%T9W-G)_9Y9W5G>&=I>FIZ:WIL>E!,=V=8,GTS>V<H]BGV?6<J
M]E0W(V@L:"UH+/8K,"WV;GHT:'$P*VAO>BIH+O8E:"1H(F@A:&-#>T(G:'!Z
M+_8F:'%Z,/8I:')Z<$%5-T$Q*&AS>E,Y*_9T>C'V<4%M>DJN.F@[:%DR+C(X
M:'5Z,_8N:'9Z-F@]:#=H-O8U:'=Z=F<W]CCV,VAX>B]H.?8Z]E`T,6@\:#)H
M>7H^:'IZ,&A\1VE-.6A/:'MZ?'I':'L_?7H[]D8U739":'YZ//8A>ULR/?94
M/D5H6CH^]E%%2F@B>S_V;DHC>T%H6C)6."E)2V@_:$AH0/92:$-H)'M$:#I&
M)7M):"9[1F@H2TQH8#!!]D+V0&A#]D7V3FA-:&M'5&A?:'XS8FA0:$;V56AN
M35YH*'M534?V*DY(]DGV2O9X0TOV3/9K,TWV*7MR261H(49/]C$P76A9:')!
M4VA;:&!H*GLL1RM[*C!0]EAH4?9A:'A)4O93]EQH5V@L>U4^+STL/%;V6$Q'
M22U[9VAP:%?V6F@N>W<S+WMX/F5H,'MJ:'-!6/9F:#%[;6@R>U]#;FA636-H
M.#-I:%KV6_9L:"Q,7/9O:&AH:VA5]E[V7_8I2R%/8/9A]F+V<VAC]GIH9/9R
M:$,\46AE]DY*(DQY:'AH=&AU:#8Q9O8U>W=H<6@V>V?V:/951&GV=FA^,#=[
M-'MJ]B)"0TIO]GMH(6E92'YH5CY)/"-I/C9K]G#V<?8D:7E)?6@X>U9H<O9S
M]G3V?&@Y>T]/(D9S22MI;/8Q:3Q[=O9W]C)I>/8E:7GV=D=Z]B]I)VDI:3U[
M/GLS:2AI>_8L:7(Q948M:3!I?/9]]C][)FDF02II)SM%/S`W=$P[>WE,<CU`
M>R/W-VDU:23W3D\E]S1I)O=!>W5-0GLV:3AI.6DG]RCW/&DZ:2GW*O<C1CMI
M*_=-2"YI0WLL]W,]/6E":71!06E%>RWW(FE&>T=[0VE)03YI0&E(>R[W1'L_
M:3%=(EU*>T5I+_<P]T1I,?<R]TM[=DT\8D9I3'LT]S7W1VDW]V@O2&E7.%0U
M.?=*:5U1.O=->W4U3GLZ3G,V2VE0>TQI;D-2>SOW36E3>SSW>D8]]SHP/O<_
M]V,R4FE3:4#W0?=.:3T[5'M"]T/W3VE"1T3W4&E1:5MI56E8:4;W1_=4:55[
M2/=)]U9I5VE8/%EI04-6-T(S2O=<:4OW3/<_,V%I76E@:4WW.DA.]UYI7VE(
M25I(8FE]0FQI5GMH:5=[6'MK,F9I*DMG:5#W9&E1]V5I:FEM:5E[:VE2]U/W
M:6EC:53W6$-5]W1I*DQ6]U?W6/=R:7-I6?=N:7!I6O=Q:5OW;VE<]UWW9D`Y
M3WAI>6E>]R%J*C][:5_W?FEV:75I(FI@]V'W7#)\:2-J?6E:>V+W>FDS1'=I
M8_=H1R=J6WM<>V?W:/<[36GW)FIJ]R5J9O<N:EU[7GLH:C!J7WMF33-J*FIM
M]RMJ;_<O:C)J,6HI:G#W+&H]:F%[<O<V:G3W=?=V]W?W>/=B>WGW-&HU:G'W
M.FH[:BHS0C4Y:GKW>_<D:F-[9'M\]SAJ/&HW:F5[/FI]]V9[0&H_:F=[0FI!
M:EII1FI^]R'X0VHB^$1J16I':B/X;#=):DAJ,#TE^%0Y)UY*:E$].3,F^$MJ
M4C%7/DQJ)_A5.4UJ83`H^#U)*_A.:BWX:C]5:E)J;T-3:E!J7C9/:E9J-C=>
M0EQJ6&HU0E=J:'M::E%J+OA;:EUJ:7MO2%EJ7FI@:E,X5&I!,"_X,/@Q^%]J
M,OA;.G9.86IB:G5!:GMK>R).-?@S^#;X8VHU361J96HW^&1*9FI`.B-.:VHX
M^#GX;&I8/FIJ;7MG36=J:6H]0'X_._AH:FUJ(TIO:FYJ;#,K2W!J<'MQ>W)[
M;GM\:G)J<VIS>W1J=6IT>W5[>6H]^'IJ=GMX:G=[=FH_^'%J=VI`^$'X>VHW
M<"@R?FI?-GUJ1/@B:R%K)&LC:R5K,3TF:R=K*&L^0$7X5TTI:R1*1D<J:T;X
M*VLK."PU1_@L:WA[:SM!1RUK4#-(^"YK,&MW32]K1C\Q:S)K2?@S:U$T2O@T
M:S5K-FLW:U$S>GM+^$SX.&LY:SIK<C)[>R@_.VM-^$_X4/@\:WQ[/6M1^%+X
M0#A[1#YK5S=6/T%K)$9`:U3X?7LQ-U7X?GL_:W="+35":T-K63Y7^"%\;3=$
M:RQ+7T!V-75,2D%8^$5K(GQ'/W!#6CY9^$9K6OA):R-\2FM;^"1\/CI"0DAK
M6SX^25SX1VLE?&P[4S$F?$YK6#=N.VT[34]-:TQK)T%--4-/.C-</B=\*'Q+
M:U!K46M/:U@X0$UO.R='7OA4:T!`0D,V35=K;#@_0%-K6&MM.%5K5FLI?%)K
M8D!)1EWX+T-=,E_X<$A#-6#X-$1;:UEK3$-!0%(T6FM;/RI\2DY`3V'X7&MG
M:S5$9FLK?&-K:VMD:V!K?$1?:UUK(4UP.V%K7FLL?"U\96MT/4$X8OAZ0D5+
M6C%B,"5&9?AI:V3X:&MF^&9&;6MB:VQK;FLL.&IK5CEG^%4\:/AO:UA-<FMU
M:W-K-4EI^'!K8#9T:W9K:O@Q?'IK=VMY:WAK;/@R?'MK,3PS?'UK?&MH26WX
M(6Q9-S1\?FLB;"-L1#5!9GD^)&QN^&XX)6QO^"9L</@^.TY:<?@G;"AL,CTI
M;"IL<OAS^"ML+&PM;'3X-7QU^"M#=O@N;'CX,&PO;'OX)D9\^#%L-GPM2S)L
M,VQ]^#1L?O@U;"'Y6D9=/C9L-WPB^6LY+E`W;"/Y)/DX;#]).6Q!;#IL/&P[
M;#UL1DL^;#]L)_DF^4!L0FPH^2KY+3-G1&E)8CI7.2OY3TE?,DY(16Q3-%5`
M1&Q);'E#8TQ';$AL+C5*;&-'7T)Q2#U%1FQ'2VPR3&PH3T)$14]Q.TML,4)<
M;"A!>$9022WY+/DN^4]L/SMR.UX^94<Y?"TX3FQ-;&I)03Q213#Y,?DZ?#M\
M46Q2;%@Y4&P\?%-L5&Q6;"-",_E5;&8T6&PT^5=L66P^?%ML76Q>;#]\5D!/
M/%]L4C,U^6!L=D%A;&)L:TDO-6-L-ODV1%LQ-_ED;'$\./EV/T!\+4)G;&9L
M96PZ^3OY;6QK;$%\:&Q"?&IL0WP\^6EL;&QW-7!L5T!Q;%DX;FQO;#WY*4\W
M1"E!<FQ`^75L0?ES;'1L64T^^2=&>&Q#^43Y=FQW;'EL1'Q%^4;Y17Q'^2EM
M?&Q];'ML2OE+^49\>FQ]1"%M)6TB;7YL3/DC;21M3?DK;29M6$`H;4[Y*FTG
M;4_Y4/E1^4=\+6TS/2QM2'PN;2]M,FTQ;3!M-&TS;79,-FTU;3=M4ODX;5/Y
M.FTY;4@_.VU4^6TV/&T^;57Y5OE7^5CY/VU*?$!M/6U!;58\0FTP-3,W6ODN
M.%OY0VUP1CY%1&U';30\7?E,?$9M16U:-TAM7_E3,TIM8/E<.DEM4FU,;4YM
M94I+;6'Y36U1;4]M,35-?%!M4VU:1UA.8OE.?#0]5&U/?")-5FU5;5EM04UC
M^5AM;3-7;5QM6VUD^5IM,D5=;5!\7FUE^5]M;#DE-V!M86UB;4D_8VTM/&1M
M96UG^5)\(5)^469M<&5G;21#*S]`1VCY4WQJ^6AM54I41'XY*4-L^2HQ>$M7
M/VWY;_EP^5XW839Q^59*<OEI;7/Y:VU4?&IM8#)5?'9&;&UW1S-%5GQM;5(]
M=/EO;77Y0DQ^;7%M<FUV^4E$8$)W07?Y*$9P;54U5WQY;7CY=FTE;BE&8$-S
M;7Y$4T5T;7AM8#]G1TQ$0D!W;2Y")$)U;2DP(D]Z;5A\84(U/4H_?&U[;7GY
M;S!];2]))VY;1FL_>_E\^5E#>#8F;C=-/S%72F$R(6XB;B-N)&X[1B-#8S`H
M;BEN(W0]0GWY*FYS,4Q!+SA:32MN+$5X05<\+&XO;F4]+6XK02I!9#!+3C%N
M<D@S;C)N,&YD8U0T(OIN;5I\-6XT;B/Z-FXD^CA-6WQ<?%U\7GPF^E]\848N
M2S=N63PX;BCZ.6Y@?#IN*?HA16%\:C`J^F)\8WQD?"OZ63DZ3V5\/FXM^F9\
M9WPN^C0W.VX\;G1),_I4,VA\,?II?#E-,/H_-E1%-/HU^C+Z/VXV^C?Z0&YK
M?&Q\;7PX^D%N.?HZ^FY\;WQP?")%<7Q#;G)\0FYS?#OZ//H]^G1\/OH_^G5\
M4T9$;C8]8#Q;1W%#<CQL/T5N0/I&;D'Z=GQ"^ET_1VY#^DAN26YO33<]2VY*
M;D3Z6CES.4`[1?I.;G=\1OIF/4UN3&YI0D?Z;SA#0#!(.3UX?$]N7SY(^E)N
M4&YY?$GZ46YZ?$KZ5&Y3;DOZ>CY5;GM\5FY7;DSZ3?I02%,Z83Q8;EEN)$Y%
M/6Y,3$Y:;F(V6VY\?"-%3OI>;G@S2S]<;EUN8$1^?"%]54M\-E'Z(GU2^B-]
M8&YA;GU\7VYC;E/Z)'U4^E]&0S,E?6=N9&YF;E7Z5OIB;D]O96Y8^FM.6C@F
M?2=]*'TI?6]N*GU9^BM]-$5J;EKZ;6YK;EOZ<&Y<^BQ]<6Y=^E[Z:6Y?^G9N
M=#%H;F#Z8?HM2&QN8OI@/F/Z9/I;.2U]9_IH^DA+:?ID-D8]/$8N?6KZ:_HM
M071N;FYS;FSZ0TQM^CA$=6YR;F[Z;_IP^BQ!<_IY;GAN=/IU^B]]=OHP?3%]
M=_IW;GCZ+TLR?7GZ>OHS?7L]>_I\^GIN7TI4,49)<D,B^W@U(_M\;B3[73DT
M?27[-7TL.R;[>VYM/WWZ)_MN/R%O(V\H^RG[-GU[/C=](F\D;SA]4S8J^T5)
M*_MB/"-/?FYX.C]/)F\E;R=O?6XN^SE].GT[?6E&544O^U=$+&\P^S'[0T,H
M;REO/'T]?3Y],OLM-RMO/WTS^S3[,#@J;V$^./LY^WDS.OLP;S\Z>4%*1$!]
M._LU^T%].S,N;R]O0T0M;S%O0GU`^S=O0WU!^SIO.6\M13)O,V\V;T+[.&]$
M?45]0#9#^SMO-6]$^S1O/_L\^TG[1WT_;T9]0&]%^T;[06\^;SUO1_M(^V(^
M*D8\;T5O0V]*^TA]2_M$;T)O>$)&;TS[1V]);TW[27U5-$AO>DQ4;TIO36]+
M;TQO2GU.;TM]4/M1^U!O3'U-?5%O4F]5;U-O5F]8;U=O.412^U/[9TQ9;RY!
M5/M:;T1*6V\K,U7[5OM.?3PQ5S16-%QO76]>;U]O3WU@;U@T53->.39(4'UB
M;V%O47U8^U)]8V]<,5G[4WUF;V5O9&]4?6=O:F]',%O[:&]5?6QO:V]6?5=]
M;F]M;V]O+D99?7!O6GUQ;W-O<F]L227Z=&]U;V4Z7OMV;W=O24M?^V#[2T%B
M^R0P2T)C^WAO;4E[;WEO7SEZ;T(X6WU%2GUO(7!^;R)P9/LA,5@_?#U9-"-P
M9D<E<"(Q)'!$1$U.*T9\;R9.,3A;36;[7'UY-C1.*#=B0B%G)G`L,V\_5C,H
M<"EP)W!D-VC[73IC/EY](S%93E]]8'TK<"YN:_LJ<&S[+G`L<"UP;?LO<#!P
M;$XQ<#)P;OM)0#M(;_M]/V<T.DUM,C@]6S@U<#1P<SLV<#-P*#MA?3IP+6IR
M^U92<_MW/SAP=/MB?25.<48K,61]8T`V/&5]-TI`,6U.:TT[<$5%>SP\<#UP
M3#\^<&Y..7!`<$)P07`_<';[0W!$<'I!8C)W^T5P.$Q&<$=P*D]F?7G[,5M(
M<&=]27!*<'K[3G!+<$QP>_M-<$]P:'UI?6I]1$!\^W=,??M%0&M]?OM0<'-(
M47!3<TQ,4G!3<%1P5S,A_%9P63]L?5=P;7TD-UAP7'!:<%MP<S-9<%UP7G!(
M,%]P8'!N?23\9#XE_&%P)OQ'-2?\9'!C<&)P<6M<2F]]*/PI_&5P9G!P?2K\
M<7UG<&AP:7!R?6IP*_PL_%HT+?PN_"_\='UK<'-],/QL<"-',?QN<#LR=7UQ
M<'!P)#%!-D=*.D0B.C+\8#EG/5P_=WUS<#/\-/QR<$)-:#122%Q&-?PV_'P_
M3DY;-WA]=G`Y_'5P//QY?4M++$9Z?3K\._Q0,7=P='!126I->'!Y<#W\>W!J
M0ELS7#-Z<'Q]?7UI-#(X?GTA?FHT(GXC?C]%8$XE?C[\7#A\<"9^?7!^<"%Q
M(W$B<7=))'$__$#\)7%!_"9Q)W%#_$3\)WY%_$;\1_Q(_"EQ*'$J<4G\*'Y*
M_'1(3&8I/TO\3?PR-4[\3_PI?BMQ4/PL<2Q2.UU32%'\4OQ[,%/\.S!T.S!+
M?CXM<5],5/PN<5Q-0C%!.R]Q;C(P<5?\6/PQ<5K\6_Q<_#-Q-'$V<3)Q-7%;
M-#=Q.'%>_%_\8/QA_&+\8_PY<3IQ9/QE_#MQ/7%F_#QQ/W%"<6?\:/P^<4!Q
M07%#<4(V*GYI_&K\:_QS/$1Q17%A.2M^;/Q&<6W\/C-/1T=Q2'%:0VM&;OQ)
M<6_\</Q]1W'\3$)8,6XV;S9R_'-#3G%P-G/\;S)-<73\2W%,<77\2G%8<4]Q
M4'%W_%%Q4G%4<7C\4W%Y_%D]57$L?BU^5W%Z_#,U5G%[_'M!,SA\_%EQ??Q^
M_"Y^34):<2]^,'XM1B'](OU;<3%^8'%><5UQ7W$C_5QQ,GXD_6)Q,WXT?F%Q
M9'$E_4,V8W%E<69Q:'%G<6EQ:W%J<7PY;'$G_6UQ-7XI_3PS*_UN<6]Q-GXW
M?G$_+?TX?G!Q+OUQ<2_]<G%S<3#].7YB.3+]='%U<3/]=G%W<33]>'$U_3%(
M>G$F27MQ>7%]<7QQ?G$Z?B%R.WXV_2)R/'XW_3C].?TZ_2-R)'([_25R/7XF
M<B=R*'(I<BIR*W(L<CS]/WXM<BYR-5TO<CW]>&0T-3[](3,R.C%R,'(E3$#]
M,W(T<C)R-7)B2S9R>S5`?D']0OU"?D/]1/TE3T-^1?TW<D1^1OU'_4%^.7)%
M?D9^/C!'?CIR*THX<CMR/')(?CUR/G)(_4E^/W)N2RT[2?UZ.B]!2OU-_4!R
M3OU#<D_]07)*?D1R4/UQ.$)R2WY%<D9R1W)+<BH[4OUD0E/]3'))<DAR2G),
M?E3]7S=5_5;]6/U7_5!R3W).<E'],S!<_4U^6OU.?D]^6G)6<E=R4W)9<E5R
M8C-,3UAR5')2<E%R7OU?_6#]8?U<<F+]7W)C_5!^7G)=<F3]9?UF_4E)6W)S
M,&!R:/UB<FG]:OUO,TUR-S%D<E%^:_UC<F%R+4-N_6_]4GY3?G!+5'YQ_5I.
M<OUE<G/];/UT_77]9G)5?E9^9W)V_7?]>/UY_7K]>_U\_7W]:')7?FER?OT[
M1"'^:G(W2&]R:W)L<B+^,4M$3%!&)/YP<G%R/D9N<FUR(_XJ,B;^>7)X<B?^
M*/YU,5A^67YV<G5R<W)[,W)R,CPI,BS^8SE\<GMR>G(N_EI^=W)]<EM^?G(O
M_B5S)'-<?B9S+3$A<R)S,/YT.3E,,?Y=?B-S,_XT_C)+*W->?B=S-OXW_CC^
M+'-??CG^.OXI<RAS8'X[_EPW87X\_BUS/?XN<R]S*G-C?G1R,'-A1#_^-'-`
M_C5S,W-D?D'^/OYB?C)S.'-"_C%S-G-#_D3^-W,Z<T7^97XY<T;^1_Y(_DG^
M/'-G?CUS/G-)3TK^.W-K0FTZ/W--_FA^3/Y._FE^3_Y`<T%S4/Y1_D)S0W,T
M.$1S4OYJ?D5S+SQ4_D9S5?Y'<TAS27-,<TIS/$]+<V].5OY-<VM^6TYL?DYS
M?D=7_D]S47-M?E)S;GYO?G!^4'-M.4U,8TMW5EG^8%U[2W%^*S)4<U`U57-6
M<U=S<GYU.5AS5&!;3&-"67-;<UIS6_Y<<UUS7/Y><UW^7W-@<V%S8G-C<V1S
M97-F<U[^7_YA_F=S:',D17-^73AJ<V+^8_Y-06MS;'-D_F7^='YF_B%)9_YM
M<VC^:?YJ_FYS-V-:;&UP;W-K_G!S;/YU?FW^;_YR<W-S='-P3G%S=7-V<W'^
M>'-W<W/^=/YZ<W7^>W-Y<S9.=GYW?GQS>'Y]<U1C?G-Y?CMV+G1.=4][278D
M?EU]2R]7+W)/>:YZ=5IW;W<\>3UY07DZ>SCW1?<N?&[Y:GPX+DDN4"YC+F@N
M;BXL+R\O-B]:+UXO84]B3U!T7'1>=&%T*'4K=4-U975I=G=V)7=5=RGP)7@G
M>3-Y-'DW>3AY.7D[>3]Y0'E->5%Y9'DN>E#T,WHZ>D1Z6'IT]77U)WMO>WE[
M+WPP?#A\/7QI^5E\8WUV?7M]/B,](RHA,")T(7`A<R%U(2\B2B%+(78A7"$D
M(3$B)2$_(3`C,2,R(S,C-",U(S8C-R,X(SDC)R$H(6,A82%D(2DA=R%!(T(C
M0R-$(T4C1B-'(T@C22-*(TLC3"--(TXC3R-0(U$C4B-3(U0C52-6(U<C6"-9
M(UHC3B%`(4\A,"$R(2XA82-B(V,C9"-E(V8C9R-H(VDC:B-K(VPC;2-N(V\C
M<"-Q(W(C<R-T(W4C=B-W(W@C>2-Z(U`A0R%1(3(B5B)7(C$A;R$B+B&A*Z$N
MH3:A1J%PH7FA=Z$BHR6C)Z,QHS*C.*,_HT&C2J-2HU.C6:-<HW>C*J0ZI#*D
M,:0]I%FD0B]<I&.D7J1KI&JD<J1,+W2D=:0EI3*E8"\^I4>E8T]5I5:E>R]^
MI3"H-Z@XJ#NH.JA%J$"H/ZA(J$JH2ZAN3UNH9JALJ"*L4_XKK#"L4*QEK&VL
M<JPDK3*M*:TJK36M-*TYK5:M)*Y]K3IU(ZXZKD*N/:X\KD2N1ZY)KD.N5:Y7
MKE:N6ZYWKGBN*J]R=4*O/Z]#KT"O6:].KREV,G9AKVJO::]PKW6O(^XT[F!V
M2>YU]%SN8.Y?[E[N,N]'[TWO8>]D[R+P,_`Y\&QW4_![\"[Q,/$U\43Q7?%A
M\6;Q:?%U\7?Q>O$A\B3R(_(H\BSR/?)^>$CR*7E;\D=Y=?)V\E1Y,O,^\SWS
M0/-2\UWS7O-N>7/S=/-W\W7S??-[\R+T)/0G]"_T+O0U]#3T/?1"]$_T:?1K
M]'+T>?0U]3KU1O56]5CU6O5=]5_U8_5J]7#U<_5=>D2E1/9.]C-[7?9U]B'W
M(O=^]DE[,_<V]V7W9/=K]V[W<_<J^"GX+/AL>S3X//@^^$+X5OAC^'?X>?AZ
M^"7Y+_DR^3GY0OE(^4E\6?E>^5%\9OEK^7KY?ODA^BSZ+_I0^D_Z5_IE^F;Z
M<?IR^G[Z(?LM^RS[-OLW^S[[/?M.^T_[5_M:^US[7?MA^V7[9_MI^W'[(OPC
M_#C\0OQ,_%;\6?Q=_';\+/U+_5G]3/U=_5O]9_UP_6W])?XK_BG^-?XR_F9^
M6/Y:_F[^</YR_G;^``````````````````#?_P\`W_\>`/__+@#__SX`__].
M`/__7@#_\VP`#C]U`+`,>@`P9H``GCF)`#__EP`__*,``WZK````JP`(`*P`
M``"L````K``$8*\`5Q6W````MP``([H```"Z`/_7R`#S\=,`+V[=`!Y_Z``W
M(>\`!@#Q````\0"`$?0``VO[`.`#``$````!7YD*`0#W$0$QEA@!$3X?`0``
M'P$``!\!`@`@`0``(`$``"`!_O\O`?L#.`'^_T<!_P-1`0``40$``%$!``!1
M`0(`4@'__V(!__]R`?__@@'__Y(!`@"3`0``DP$``),!``"3`0``DP$``),!
M`,"5`0``E0$``)4!``"5`0\`F0$``)D!:3.A`6<`I@$-F*P!A`.P`0(`L0$`
M`+$!``"Q`0``L0$``+$!`!"R`0``L@$(@+0!2`"V`8((N0$@`+H!``"Z`3@`
MO0'_#\D!_P_5`0``U0'?`]X!``#>`0``W@$0`-\!%`#A`<`#Y0$``.4!K0OM
M`0SD\P'A7_T!,"```B@!`P($``0"QPP+`L``#0+\#!4"X`(9`B``&@(`@!L"
M```;`@`,'0(``!T"```=`F``'P($`2$"```A`@``(0(``"$"```A`@``(0(`
MP","_U\Q`@``,0(``#$"```Q`@``,0(``#$""``R`@``,@(``#("```R`O__
M0@(/`$8"``!&`O__5@+_^V4"_W]T`@^0>@*9.8(".9F*`IF9D@($")0"``"4
M`@``E`(``)0"``"4`@``E`(#`)8"SC"=`L/*I0(/`*D"0("K`@``JP)O0+("
MP$"U`@``M0(``+4"!0"W`@``MP+__\<"``#'`@``QP((`,@"``#(`@``R`(`
M`,@"0`#)`@``R0+`_],"``#3`@``TP(``-,",`#5`@``U0(``-4"``#5`@`,
MUP+O_^8"_[/S`@$`]`(X./H"_O\)`___&0/__RD#__\Y`___20-_^%4#__]E
M`___=0/__X4#__^5`___I0/__[4#``"U`P``M0,``+4#___%`P``Q0,``,4#
M``#%`P8"R`,``,@#_O_7`P``UP,``-<#``#7`P``UP/P`=P#_O_K`P``ZP/_
M__L#+S(#!``$!`0((`8$$`$(!,P(#01`"`\$`"82!((`%`0``!0$`'@8!`#`
M&@0`<!T$`@`>!```'@00*"$$```A!```(00``"$$1``C!```(P0`4"4$```E
M!```)00``"4$``4G!```)P0``"<$!``H!```*`0@$"H$@@`L!``(+00``"T$
M```M!```+00`@"X$```N!```+@0``"X$`&`P!`A`,@0``#($```R!```,@1`
M`30$```T!"``-00`!#8$```V!!``-P0@`#@$```X!```.`0``#@$``0Y!```
M.00``#D$```Y!```.01"`CP$```\!```/`0`@#T$```]!```/00``#T$```]
M!```/00&&$$$(`!"!``@0P0``$,$``!#!```0P0"`$0$``!$!`0!1@00($@$
M`0!)!```200`@$H$0`!+!`$`3`0`$$T$`@!.!```3@0``$X$``!.!```3@0`
M!$\$``!/!(`$400``%$$``!1!```400``%$$`(!2!```4@0``%($``!2!`!`
M4P0(`%0$``!4!,``5@0`!%<$``!7!`!`6`0`%%H$!`!;!```6P0``%L$``!;
M!``@7`2``%T$@"%@!```8`00`&$$0`!B!`@@9`0``&0$``!D!`$`900`@&8$
M``!F!$``9P0``&<$"`!H!`0`:00``&D$``!I!```:00"0&L$``!K!```:P0`
M`&L$``!K!!``;`0``&P$``!L!``$;00``&T$``!M!`$`;@00`&\$``!O!```
M;P0@`'`$``!P!```<`0`@'$$``!Q!```<01!`70$``!T!`@`=000`'8$``!V
M!```=@0``'8$@`!W!```=P2D`'H$``!Z!```>@0`0'L$``![!``"?`2``'T$
M``!]!```?00``'T$``!]!```?00``GX$``!^!``!?P0``'\$``!_!```?P0(
M`(`$``"`!```@`0@`($$``"!!```@00``($$`(&#!```@P0(`(0$``"$!```
MA`0``(0$``"$!!"`A@0``(8$``"&!$!`B`0(`(D$@$"+!```BP0``(L$``"+
M!```BP0``(L$$`",!```C`1``(T$0""/!```CP0``(\$!`"0!```D`0`")$$
M``"1!`@`D@0``)($``"2!```D@0``)($``"2!`!`DP0!`)0$``&5!(`0EP0$
M`)@$``"8!```F`0(")H$``":!$`$G`0``)P$`@"=!```G00(0)\$``"?!!``
MH`0``*`$``"@!``AH@0``*($(`"C!```HP0(`*0$``"D!```I`0``*0$``"D
M!``@I00``*4$``&F!```I@0``*8$(`2H!```J`0`@*D$``"I!```J00``*D$
M`@"J!```J@0@`*L$``"K!```JP0``*L$`H"M!```K00`$*X$``"N!```K@0`
M`*X$``"N!```K@00`*\$``"O!```KP0``*\$``"O!``@L`0``+`$0`"Q!```
ML00``+$$$$"S!```LP0``+,$``"S!```LP0``+,$``"S!"``M`0``+0$``"T
M!```M`0!`+4$``"U!```M02``+8$``2W!!``N`0``+@$``*Y!```N00``+D$
M``"Y!```N00`$+H$``"Z!```N@0``+H$``B[!`0$O00$`+X$``&_!```OP0`
M`+\$@`#`!`$`P00``,$$$`#"!`(`PP0``,,$``##!(``Q`0``,0$``#$!```
MQ`0``,0$``#$!```Q`2``,4$C^_1!/=#VP1"_^4$1YON!*WI^`3BYP(%!`($
M!0I`!P5E?Q(%-OL=!7=Y*`5)'B\%W^T\!?'G1P4Z:$X%YZA7!0ON8`5#-&8%
M`(!G!=%U<`7(XW@%^_^'!1&6C07I_9D%;*VB!=8MJP4#Z+$%9,"V!3S.OP67
MK<D%>\#1!6Q%V`5GZN(%7]?N!?Y__`5`"O\%S\,)!ND4$`9H%!4&=2$<!B$A
M(`9^%RH&"#0N!KY,-P:T]D$&<T9)!NIB408L"E8&7PM?!O3-:08"!&L&I)QR
M!OM_@`:U%(<&)7^1!NH9F09MOJ0&[R.N!GT_N@;_,,0&>#[-!D!XT@;'9ML&
M>V?F!M]-\0;^(/D&L$;_!LD/!P>8OA`'\%@7!SJ6'P>_H"@'G",O!QZ)-@=9
MOD`',EY(!ZHW40?GZUT'W0!C!ZW/;@?GK7D'X3:!!QN$AP<JSY`'[R>;!YY5
MI`?+TJT'NZVX!Q0`N@=(I<`'<6/(!]T(SP<-?]D'\([A!S[_[@?_!?@'&O\#
M"`>H"0C1>Q,(0'L:"$UG(P@B@"8(1!TL"/NX-PA1_4$(91!&"'?[4PB,]5P(
MWP-E"``!9@AF\W`(#J1V"-/"?@A1`($(`,B$""I3BPCSE)0(R7";"!L`GP@`
M>*,(WT^O"`+WMPB`?[\(08#""+!2R`@6M,\('`+3"(!BUPC`0]P(T0GB"`"#
MY0C7J>\(A5+U"`%(^`A1O0$)5@4'"<&5#@DP9A0))7,<"5P0(0DO9RL)BLTS
M"0E!-PG-ID`)&:])"6R14`G*HU@)F0E>">7T:`D#`&H)4H=Q";F8>0D$"WT)
M"'2""1T5B0D)`8P)R=F5"=S0G0E9(*()\;^N"74.M@D@8KH)DX3`"3<FR`D#
M'LX)ED?6"98*W`DE4N()**[I"9GP\0D`3_8)"D_]":IT!0J^UQ$*-=H:"I\^
M)0IDOBX*<1\W"K1^00J&84<*T,-."K.M6`JE=V(*>#%I"AXL<`I,JG<*.%%]
M"@1:@@I(*X@*'W:2"OA-FPI`B)X*"C*C"HJ5J@JIHK$*8!"T"D,"N`H@!+H*
MY#3!"H#$Q0H0",<*!-S-"H4`T`HJ]-@*%AK>"L$4XPIK0NH*(0SN"@$;\PK`
M`O8*)#3["E5```LK$`4+][T2"WB+&@LKM2,+N[LO"^B_.@M\4$$+>8-)"_U2
M4PM=Z5T+]EMH"VOE<@O^[X`+3D2&"QTKC@L#_Y@+8^VB"RO`J`N_T[0+0Q:Z
M"P"5O@L3@,(+SS_."^I=V`N@"MP+!0+?"P.GY@M1+.P+P&CQ"_.O_0O5"@0,
M`@(&#,1<#0P-$!$,`K87#$D`&@R6&2$,E2(G#)50+0R5-S8,`#HZ#,YI0PS_
M2T\,OFA8#$T87@QVKVD,(.AN#,EA=0RY4GT,\,&$#!YXC`Q\_YD,FH2?#.`4
MI`SA/*P,X,.S#$Z/O`Q-KL4,#Q/,#-O_V@R?_^@,^_GU#.BB_`SR<04-HU4-
M#=HS%@W>/B$-C_(K#;^?.`V/4T$-E^=,#;@S5`VX.EP-W'-F#1?*;@TKN7<-
M`.!Z#?4[A0WWCY$-*@25#<X\G@TEAJ0-/;^P#:&`M`T:/KP-].S&#<D'S0U_
M<=@-X`G=#3J_Z`V+0>X-_P_Z#4OC`PXMW@T.@AD2#I'T&@[6?24.**<L#JW)
M-0[[4#X.A&1##M\'30ZP>U8.1%9<#L@_90XAH&D.2`!K#O3U=@X!=WT.=^R(
M#D[&D`X=R9@.RWNC#FY-K`X;X;0.2MJ\#CT&PP[^6\\.0!C2#B(ZV`[TM^,.
M_SOP#@/P]@[J\/\.CC<(#P.##0^`B1$/)/X:#QKR(@^A$B</H%LN#\0<-`\9
MTSP/5(M##Z\?3@\T:%0/68):#W4<8@\K>FL/]`1Q#T"B=0_94'P/9+.$#U!$
MB`\$0(H/`BV/#X&BE`]()YH/B`&=#R[DI0\P:JL/!=JR#[9\O`^U!<,/_Y#-
M#];LUP\Q@-L/4''A#QR>Z0_TR_,/,*'X#_)C`1#,&`<0M04.$+Y7&1"#NB$0
MLK@I$*6S,A!^FCP0E`I!$.<S2Q`&'E$0W===$#C08Q"WK6X0>Y1W$#[;@A"&
M[HL0_O^:$-D-HA";8ZL0QR.S$$5HN1`VV\,0T@/)$$`^SQ!!$]00O?_B$"NK
MZQ#\ZO80P'W^$-JE!Q'"\Q`16_(:$7^D)!'_V#`1HAHV$:T]0!%'@D81W0M/
M$5O%6!&?;V01E-)K$;O:=A$>`'H1R>&"$08^B1$>>Y,1?W.?$;^ZJQ&(2*\1
M]-2X$2Z@OA'9O\H1[:W5$7\>X!%XO^L1]8?U$;OQ`!*''@@2N_T5$@0>&A)N
M!2$2<:HI$D0&+1*X=C82'_]#$KSW3Q('1%02=AE<$N%@8A*7W&P2B_QV$DMC
M?A*,[X@2?.J2$B2<F!*^[J02#DZK$GWON!+P2\`218O'$E8(S!(,Q=(2&6K9
M$I/PX1(O7.H2""GN$DX`\A(;_/P2D!4!$PXL!Q,PC`P3Q^@5$XN0&Q.D9R,3
MR%8J$UF+,A/_ECX3N(]'$U\N41-@2583$.Y=$[[\:1/AZW,3W(U\$\#8@A,*
M@(43),6+$YL(D1,8`),3^,6<$P=@H1.A_JL3A26Q$UUDN1-^,\,3_1_/$P9L
MU1,*_]\3=A;G$_D^\A,O__\3"P@#%!%<"12$R@\4\,X8%'[[)10R`"@4`%\N
M%'E6-Q21`SP4IW='%#H;3Q0`W%04-)%:%/79911G[W$44E]Z%.H>@Q2@#XD4
MJ.Z2%/_ZH!145:<4&/^Q%-K9NQ2(R,`41,#$%`60R!1)L<\4I(S5%-:DW12^
M7N@4.F+O%`"8\A24R_H41I8!%3L%"!4MG!`5;M$9%2(`&Q66WR855^$O%1%U
M-A57<3\5TX%&%;N$3A5J4E45SP=>%3#-9143VFT5:U9V%>..?Q4B[8<5R!&,
M%056DA6(7)@5$F&=%3C:I15A<:P58D:R%:2"MQ40^+T5B@_$%0"-R!4:L]`5
M$!#2%0(BU178D]T5$%;B%4/(Z!5#$.P5P%;R%6]2^Q7U4P46`"`&%K&%#19T
MBA06!=$:%@I&'Q8:2R86O9(O%N%P-A8@VCP6P2!`%B$(0Q8`/4@6=?]5%L49
M7!;LJV86CL)M%A3C=!:'8'H61`A]%H7PA!9'0HH67U"2%H4*EQ8',IT6B#^E
M%H`$IQ;$N[`6H-^Y%MKBPA8PP,86A0#)%DC=T1:G'=H6L@[A%G#1Z!9E"^\6
MK)KW%B7O`1=`0@07JV8-%P)'$A?J!AD7"`P<%W3=)A=_AC`7VR@X%ZS^0Q<=
MKDP72T!1%^H+61>%TV$7[P]L%R&N<Q<`AW<74%5]%\W*AA?'A8X7.G"5%ZK5
MGA=YG:@7CWVS%U'_OA<7/L<7];[3%]_GX!?&WNH7%B3O%RP(\Q>O\_\7[>0)
M&#SK$QB=4AL8']8E&(^K+QAHVS@8MR%`&#D81AC.&T\89!%4&+;W8!A'?6H8
MVTES&&E^?1C#Q848T8>-&&QWEQC4V)\8^E6I&!99L!B2'[@8@,Z^&'$BQ!CP
M%<L8P6#0&`"=U1AO#=X8!/;E&`%(Z!@2Q.T8-3;U&$FZ_1B`(/\8@-P%&?WV
M$AD9&!<99#(=&30"(1GC,"@9%(0L&:C`,1D"(#,9$-TZ&100/1G"=$09NN1-
M&9BF5!DA7%H98EUB&3,$9QG3D6\9E&YW&8-`>QD'&H$98%R'&1-<CAGC!Y89
MZ?VB&:4AJ!F$AJT9,^2U&7`INQG"1L$9&^_,&8<_UAEVP=X9VCKG&0$(Z1D)
M;?`9LM_[&0%@_AF&^P@:S?(2&L&R&1J/+B(:<:<K&CX%,AKM@3H:"=9!&DG>
M2AJX_54:+K9>&N^M:AI1IW(:U(UZ&@9+@!KA]8H::BJ1&N+[G!IW(*,:\?*M
M&C^&MAK`J+L:M__)&@*DS1HR$=(:\Y[=&M`FXQIQ)NH:R0#N&HOH]AJ>P/T:
MRPP$&\KA#!LIM!,;T\,<&S/R)1LI0BH;#JHQ&[6).1OW:40;SO).&S5E5AOD
M\V`;Q8AF&W1-;AO]+WH;O7^'&P_8CQLOYID;_]FF&TE>KAM.1;4;;Z:_&TB;
MQAN(OLX;S?S9&_?MYAN%G.T;YG?X&UN3`1P6"@8<,@\-'*?H%AS/62`<IFXI
M'.HL,1QT9CD<PB8_'"GZ2!S,]U,<7QU='```71P``%T<``!='```71P``%T<
M0%UC'+CP:QPW@7(<FV]]'*5CA1SL58X<TW27'!CCGAQ$HZ0<:M2L'#2(L1QK
MVKL<#1["'']=SASW$]@<4A'='.FXYAQ(!.D<1,7O'$:!]!S_Z@$=\!H('4@_
M$!VVMAH=%@4?'7A4)AW@;R\=<X`U'3HY/1WD)T4=0$U*'9B24!TJ8E8=0$Q:
M'3N`8!WA:VD=$X=P'3^%>1TH-7\=&0.$'2WMCAU/IY@=RH^A';DUJAT8_+(=
MMG>]'<7;QQT&7LX=_!/7'>&*WAV`M^4=7<WO'=;C^1T(;/X=#*(#'OK[$!Z>
M_QT>8``?'K[:*A[N"3(>FFX['O]31Q[`.4T>#*E3'G<771ZYAF4>MP%L'@P`
M;AZHN'4>X&9\'GSMAQZ%#XX>(J"2'J/6FQY;L:0>(XZK'I<JLQ[:_+X>J@#"
M'@46QQXB,\T>0,?3'H:>VQYN^N8>ZQ?P'C8(]1Z1TOP>0J``'Q3?"1]7[A0?
M2Q8;'X#4(!\3M"<?01`J'[K--!]ZN#T?-&!"'PO/2Q^J1U,?'J=<'X#L8A_3
ME6L?F[IU'U3_@!^!%H4?@NZ-'R&SE!]R)IL?P,ZB'_4,JA_/1;,?EJ*Z'P&3
MOQ\#8,,?^=S.'X28TQ^B#MD?@#[?'RHQY1\8C^P?2P'Q']IJ^A^RR@(@6/(*
M(`!_$2#M;QT@#Y<F("H"*B"2S#$@"5HW(*J#/B!Y148@5I%-((0K4R`(@%4@
MA;A<("AL8B#32&D@18!M(&F\=B#D2GT@:NR&('N`C2".09,@1AJ9(%4TH"",
MZZD@'HNQ(*7@N"`&*;T@Q$/#(!5,R2"S\-(@/\3;(#Z[YB`"`>@@/W/S()84
M^2`-=P(AH`P&(<4+#2$_,A8A0,`9(56D("&4P"4ARX\O(=F%-R'"ECXAC:1%
M(0$`1B%4-4TAZ`A2(5JA62$-56`A_ZEL(2XD<B'Z7'PAXF&#(3=IC"%/>I8A
M+Q*=(;0RI"$K1:LA^W&V(872O2&4N,0AQ=S-(==HUB':5=\AMW3I(=&^\R%#
M.?HA"$+](4K2!")2WPXB0)H3(M>@&R(+7"(B?78M(@``+2(``"TB```M(@``
M+2(``"TB@*8R(N+7/"*Q!$$B!C])(@@73B(D=E4B'&M=(I?_:B+=N74BGV5_
M(FI>B")?))`B$WV9(K#OHR)="*DB``"I(@``J2(``*DB``"I(M`XKR*;`+0B
M,@2X(B`"NB)(@;XB"$3!(D39R"+"KM`B"IW7(BBPW")`E^(B4>#H(H\$[B)Q
M(O0BE!_\(C&"`2,=L`@C51@.([(L%2,:0QLC`MPA(VM(*"-A/3`C%H@U(PP(
M.",`?S\C*1=&([SZ42-`KE<C2,M>(W5V:".0D6TC'@!Q(P``<2,``'$C`-AU
M(]CA?2/WG(@C=F20(SH$E2-U[Z$CLR^K(V_YMR/[YL,CCV#*(^93TR.^[M\C
M?W/K(ROC]"/DM?TCOY<))*,*#R1.A18D:T$=)+I%)22`^"LD%JDR)/3@.B15
M`#XD=%-&)(R@2R27)E,DP']<)-0+8R0^%FLDO`-R)*QJ>B2%4'\D%-V')'H5
MCR3;^YPDP[VF)/IPKR1BF+4D@F2Z)/-`P20`$L,DF)?+)+W/UR3#3M\D]P'G
M)`+Q[20I(_,DZI_^)(`H`26$@@4E1=@,)8T"$26Q)A@EC)\A)52@)B4CYR\E
M[]L\)20,0"60+T<ETAQ.)3%<524K4%LE`)E?)=!,926*<&LE`09N)<H!<R7#
M\7PEM@&")2(HAB68@HLEV0>3)0((E25\#9TE,@2A)0Y,IR4-K*XEI_"W)0(`
MN"4``+@E``"X)0``N"4``+@E``"X)0``N"6``[LES?[')5J#SB7].]HE5'KB
M)8@]Z25Y5?(E)@#U)0``]24``/4E`##W)0+5_24<F`,F%[@+)@'Y$B9^%!HF
M[24C)G3M+2:P/S8FN8<_)M\_3";S>E<F9G]B)@R/:2;%"F\FT>5X)EI2?R:8
M!(,F36N,)M;CEB;D7I\F5V^J)AH6L"9RJ+<F856^)DUIQB8>1,PF2AO3)AI;
MVR8"8-XF?HCF)G[U\B;?1?PF.C@#)YTY#"?`^!,G_$\>)^"8)"<;`"@G```H
M)P``*"<`K2TGPYTV)]P)/2<`F$`GK^Y,)Q]P5"<H%UHGW7UF)Q-1;"<.?'0G
M9WI^)Z>1AB<!`(<G``"')P``AR?`0XPG:'&3)QBRF2=Z`Z`G-^NK)P1@KB<'
MF[8G+L2])TX&PR<1:<DGPT'/)SUTV">DC=\G-`[E)P``Y2<``.4G``#E)P"A
MZ"?!$^XG6\#U)W_1`"AM[@LHD@H0*$P1%2A%E1PHK>\H*`XX+B@^Z#<H$D4\
M*&B80BC\`DDH&,1.*,[`52C!?5XH%D-D*,/&;"A6*7,HOLU^**\EARA1-X\H
M?2^:*+[FI2C'3JXHXH>V*)V]P2BI;LHHY071*```T2@``-$HX!K7*%T`W"C,
M2^0HINGM*$@=\R@$R/<HW@7_*`?R!RD?FA`IS508*9"F'BE`!B$I$IHG*32_
M,2G?@CHIR(9`*<F@1BD4)TPIA"10*2!^5RD``%<I``!7*0``5RD``%<I``!7
M*2"[7BDC&60IKNAM*7"W=BDP_X`I&/"&*1?[D2FAP9<IT+J?*8Q!I"FI`JDI
M`Y"M*8!NLREBS+HIO*'"*<\VS"GE`-$I`"#2*;$PV"D%`-HI``#:*0``VBD`
M(-LI``/=*4``WBD``-XI``#>*0``WBD!`-\I``#?*0$0X2D``.$I``#A*0"`
MXBE[CNPI5P#Q*?__`2K__Q$J__\A*O\'+"H``"PJ8``N*@``+BH``"XJ```N
M*O[_/2K__TTJ__]=*O__;2K__WTJ__^-*@$`CBH``(XJ``".*@``CBHH`)`J
M``"0*@`(D2H``)$J``"1*@``D2H``I(J``"2*A0`E"H``)0J``"4*@``E"H$
M`)4J``"5*@``E2H(`)8J``"6*@``EBH``)8J``"6*@`(ERH``)<J``"7*@``
MERH``)<J`@"8*@(`F2H``)DJ``"9*@``F2H``)DJ``"9*@``F2H``IHJ``2;
M*@``FRH``)LJ``";*@`"G"H``)PJ``"<*@``G"H``)PJ0`"=*@``G2H``)TJ
M``"=*@``G2H``9XJ``">*@"`GRH``)\J``"?*@``GRJ``*`J``"@*@``H"H`
M!*$J``"A*@``H2H``*$J``*B*@``HBH``*(J``"B*@`0HRH``*,J`""D*@``
MI"H``*0J``"D*@@`I2H``*4J``"E*@``I2H`(*8J``"F*@``IBH@`*<J``"G
M*@``IRH``*<J``"G*@``IRH"`*@J``"H*@``J"H``*@J$""J*@``JBH``*HJ
M(`"K*@``JRH``*LJ``"K*@"`K"H``*PJ``"L*@(`K2H``*TJ``"M*@`@KBH`
M`*XJ(`"O*@``KRH0"+$J``"Q*H``LBH0`+,J`""T*@``M"H`"+4J``"U*D``
MMBH0`+<J``"W*@``MRH``+<J$`"X*@``N"H``+@J``"X*@``N"H``+@J`&"Z
M*@``NBH``+HJ@`"[*@``NRH``+LJ@`"\*@``O"H``+PJ``"\*@``O"H``+PJ
M``"\*A``O2I``+XJ``"^*@``OBH``+XJ!`"_*@``ORH``+\J``"_*@``ORH`
M`+\J``"_*@`@P"H(`,$J``#!*@``P2H``,$J``#!*D``PBH``,(J``#"*@``
MPBH``,(J`"##*@``PRH@`,0J``#$*@0`Q2H``<8J``#&*@00R"H"`,DJ@`#*
M*@``RBH``,HJ`0#+*@``RRH``,LJ``#+*@``RRH8`,TJ``#-*@!`SBH``,XJ
M``#.*@``SBH``,XJ``#.*D``SRH``,\J``#/*@``SRH`!-`J``#0*@``T"H`
M`-`J``C1*@``T2H``=(J``#2*@``TBH``-(J`$#3*@``TRH``-,J``#3*@``
MTRH`(-0J``#4*@``U"H``-0J``#4*@@`U2H``-4J``C6*@``UBH``-8J``#6
M*@``UBH`"-<J``#7*@"`V"H``-@J``#8*@``V"H``-@J``#8*@``V"H``=DJ
M0(#;*@$`W"H``-PJ``#<*@``W"H``-PJ0`#=*@``W2H``-TJ`"#>*A``WRH`
M`-\J``#?*@``WRH"`.`J``#@*@``X"H``.`J``#@*D``X2H8`.,J``#C*@``
MXRH@`.0J``#D*@``Y"H``.0J!`#E*@``Y2HMA.LJ$`#L*@``["H`#.XJ`@#O
M*B``\"H``/`J``#P*@``\"H0`/$J``#Q*@``\2H`!/(J``#R*@``\BH``/(J
M$`#S*@``\RH``/,J$`#T*@``]"H``/0J``#T*@``]"H``/0J``#T*@`']RJ`
M`/@J``#X*@``^"H``/@J`!#Y*@`0^BH``/HJ`(#[*@``^RH``/LJ&`#]*@``
M_2H``/TJ``#]*H``_BH`@/\J``#_*@``_RH0```K`"`!*P```2L``0(K```"
M*P```BL```(K```"*P```BL`@`,K```#*P```RL```,K`$`$*P%`!BL```8K
M```&*P``!BL!``<K```'*P``!RL```<K```'*P@`""L```@K``8**P``"BL`
M``HK```**P!`"RL```LK0``,*P``#"L```PK"``-*P``#2L```TK```-*T``
M#BL```XK```.*P!`#RL```\K```/*P``#RL`$!`K```0*P``$"L``A$K```1
M*P``$2L``!$K(``2*P``$BL``!(K```2*P``$BL"`!,K```3*T``%"L``!0K
M```4*P`@%2L``!4K```5*P``%2L``!4K0``6*P"`%RL``!<K```7*T``&"L`
M`!@K```8*P``&"L0`!DK```9*P``&2L`0!HK```:*P``&BN``!LK```;*P``
M&RL`!!PK```<*P`('2L``!TK```=*P``'2L`!!XK(``?*P``'RL``!\K```?
M*P``'RL$`"`K```@*P``("L``"`K``(A*P``(2L`("(K```B*R``(RL``",K
M```C*P!`)"L``"0K```D*P`0)2L``"4K```E*P``)2L``"4K```E*P!`)BL`
M`"8K`$`G*P``)RL``"<K```G*P``)RL``B@K```H*P``*"L`0"DK```I*P``
M*2L``"DK```I*P``*2N``"HK```J*P``*BL``"HK```J*P(`*RL``"LK```K
M*P`"+"L0`"TK$``N*Q``+RL``"\K```O*P``+RL``"\K&``Q*P(`,BL``#(K
M```R*P``,BL$`#,K``@T*P``-"L0`#4K```U*P``-2L``#4K`@`V*P``-BL`
M`#8K```V*P!`-RL``#<K```W*T``."LD`#HK```Z*P0`.RL``3PK``$]*P``
M/2L``#TK```]*P@`/BL``#XK```^*P`0/RL``#\K```_*P``/RL0`$`K`0!!
M*P`(0BL`$$,K@`!$*P``1"L``$0K``!$*P``1"L!`$4K``!%*P``12L``$4K
M`"!&*P``1BL``$8K``!&*P``1BL!`$<K0`!(*P``2"L``$@K``!(*P`022L`
M`$DK``!)*P``22L$`$HK``!**P``2BL``$HK``!**P``2BL``$HK`$!+*P``
M2RL``$LK``!+*P$`3"L``$PK`"!-*P``32L``$TK``!-*P`@3BL`!$\K``!/
M*P``3RL"`%`K`(!1*P``42L``%$K`"!2*P``4BL``%(K``!2*P!`4RL``%,K
M``!3*P``4RL``50K``!4*P``5"L`$%4K``!5*P``52N``%8K``!6*P``5BL`
M`%8K`(!7*P``5RL``%<K``)8*P``6"L``%@K``!8*P``6"L(`%DK``!9*P`@
M6BL``%HK``!:*P$`6RL``%LK(`!<*P``7"L``%PK$`!=*P``72L``%TK``!=
M*P``72L``%TKP`%@*P``8"L``&`K``!@*Q``82L`(&(K``!B*P``8BL``F,K
M``!C*P`,92L``&4K`$!F*P``9BL!`&<K``!G*P``9RL``F@K``!H*P``:"L`
M`&@K``!H*S``:BL``&HK`@!K*Q``;"L(`&TK``!M*P``;2L`0&XK``!N*P@`
M;RL``&\K``!O*P0`<"L``'`K``!P*R``<2L``'$K``!Q*P``<2L0`'(K``!R
M*P``<BL``'(K``!R*P``<BL``'(K"$!T*X``=2L``'4K``!U*P``=2L``'4K
M``!U*P``=2L``78K``!V*P``=BL!`'<K``!W*P``=RL!`'@K``!X*P``>"L`
M`'@K``!X*P``>"N``'DK``1Z*P``>BL``'HK``A[*P``>RL``'LK``![*X``
M?"L$`'TK``!]*P``?2L``'TK``!]*P``?2L``'TK"`!^*P`@?RL``'\K``!_
M*P``?RL`$(`K``"`*P``@"L``(`K``"`*R``@2L``($K``"!*P``@2L``($K
M``B"*P``@BL``X0K``"$*P``A"L``(0K``"$*X``A2L``(4K``2&*T`"B"L`
M`(@K``B)*P``B2N``8LK``"+*P``BRL`#(TK``"-*P!`CBL``H\K``"/*P@`
MD"L``)`K``"0*P(`D2L``)$K``*2*P``DBL``)(K`""3*P`@E"L0`)4K``"5
M*P(`EBL``)8K`("7*P``ERL``)<K`0"8*P``F"L``)@K``"8*P``F"L``)@K
M`@"9*P``F2L``)DK``"9*P`(FBL``)HK`(";*P``FRM``)PK``*=*P``G2L`
M`)TK``"=*P``G2L``)TK``B>*P``GBL``)XK``">*P``GBL$`)\K``"?*P``
MGRL``)\K``&@*P``H"L``*`K`0"A*P(`HBL``*(K`0"C*P``HRL``*,K`("D
M*P``I"L``*0K``"D*P``I"L``*0K``"D*P"`I2L``*4K``"E*P``I2L!`*8K
M``"F*P`"IRL``*<K``"G*P``IRL!`*@K``"H*P``J"M``*DK``"I*P``J2L`
M`*DK``"I*P``J2L``*DK!`"J*P``JBL`"*LK``"K*P``JRL``*LK(`"L*P``
MK"L`(*TK``*N*P``KBL``*XK``"N*P`$KRL``*\K``"O*P``KRL0`+`K``BQ
M*P`"LBL``+(K`$"S*P``LRL``+,K``"S*P``LRL`!+0K`("U*P``M2L$`+8K
M``"V*P``MBL``+8K``"V*P``MBL``+8K``*W*P``MRL!`+@K``"X*P``N"L`
M$+DK``"Y*P``N2L``+DK``"Y*P``N2L``+DK@`"Z*P``NBL``+HK``"Z*P(`
MNRL$`+PK``2]*P``O2L``+TK``"]*P``O2L``+TK!`#_____```!``(``P`$
M``4`__\&``<`"``)``H`"P`,``T`#@#_____________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__\/`/__________$`#_____$0`2`!,`__\4`!4`%@`7`!@`&0`:`!L`'`#_
M_QT`'@`?`"``__\A`"(`(P`D`"4`)@`G`/____\H`"D`________________
M*@#_____*P#_________________________________________________
M______________\L`"T`+@`O`/_______S``,0`R`#,`-``U`#8`-P`X`#D`
M.@`[`#P`/0`^`#\`0`!!`$(`0P!$`/__10!&`$<`2`!)`/__2@!+`$P`____
M____30#__TX`3P!0`%$`4@!3`/____]4`%4`5@!7`%@`60!:`%L`_____UP`
M70!>`%\`8`!A`/__8@!C`&0`90!F`&<`__]H`&D`:@#__VL`;`!M`&X`;P!P
M`'$`<@!S`'0`=0!V`/__=P!X`/__>0!Z`'L`?`#_______]]`'X`?P#__X``
M__^!`/____^"`(,`_____X0`A0"&`/____^'`(@`B0"*`(L`C`"-`(X`CP"0
M`)$`D@"3`)0`E0"6`)<`F`"9`)H`FP"<`)T`G@"?`*``H0"B`*,`I`"E`*8`
MIP"H`*D`J@"K`*P`K0"N`*\`L`"Q`+(`LP"T`+4`M@"W`+@`N0"Z`+L`O`"]
M`+X`OP#``,$`P@##`,0`Q0#&`,<`R`#)`,H`RP#,`,T`S@#/`-``T0#2`-,`
MU`#5`-8`UP#8`-D`V@#;`-P`W0#>`-\`X`#A`.(`XP#D`.4`Y@#G`.@`Z0#J
M`.L`[`#M`.X`[P#P`/$`\@#S`/0`]0#V`/<`^`#Y`/H`^P#\`/T`_@#_```!
M`0$"`0,!!`$%`08!!P$(`0D!"@$+`0P!#0$.`0\!$`$1`1(!$P$4`14!%@$7
M`1@!&0$:`1L!'`$=`1X!'P$@`2$!(@$C`20!)0$F`2<!*`$I`2H!*P$L`2T!
M+@$O`3`!,0$R`3,!-`$U`38!-P$X`3D!.@$[`3P!/0$^`3\!0`%!`4(!0P%$
M`44!1@%'`4@!20'__TH!2P%,`4T!3@%/`5`!40%2`5,!5`%5`58!5P%8`5D!
M6@%;`5P!70%>`5\!8`%A`6(!8P%D`64!9@%G`6@!:0%J`6L!;`%M`6X!;P%P
M`7$!<@%S`70!=0%V`7<!>`%Y`7H!>P%\`?__?0%^`7\!@`&!`8(!@P&$`84!
MA@&'`8@!B0&*`8L!C`&-`8X!CP&0`9$!D@&3`90!E0&6`9<!F`&9`9H!FP&<
M`9T!G@&?`?____^@`:$!H@&C`:0!I0&F`:<!J`&I`:H!JP&L`:T!K@&O`;`!
ML0&R`;,!M`&U`;8!MP&X`;D!N@&[`;P!__^]`;X!OP'``<$!P@'#`<0!Q0'&
M`<<!R`'_____________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M___________________________________________________________)
M`<H!___+`<P!S0'________________________________________.`?__
M___/`=`!___1`?______________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________T@'__],!________
MU`'__]4!________U@'7`=@!V0'__]H!_____]L!_____]P!W0'_________
M_]X!_____]\!___@`?_____A`>(!___________C`>0!________________
M_____^4!___F`?__YP'H`?_____I`?__________________________Z@'K
M`?__[`'M`>X!___O`?__\`'_____________\0'___(!\P'___0!]0'_____
M______8!___________W`?________________________@!______D!^@'[
M`?P!_0'________^`?\!__\``O____________\!`O____\"`O_______P,"
M__\$`O_______________________________P4"_____________P8"!P+_
M______\(`O_______PD"_____PH""P+__PP"________________#0+_____
M________________________________#@(/`O____________\0`O__$0+_
M_Q("__\3`O__%`(5`A8"%P(8`O____\9`AH"__\;`AP"________________
M________'0+_______________\>`O__'P(@`B$"__\B`O____________\C
M`O__________)`+__R4"_____R8"________________)P+_____________
M__________\H`O__*0+__________RH"_____RL"________________+`+_
M______\M`O____\N`O_______R\"________,`(Q`C("________________
M,P+_____-`+__S4"-@(W`C@"________________.0+__SH".P(\`O__/0+_
M______________\^`C\"_____________________T`"________00+_____
M0@+_____0P+__________T0"__]%`D8"__]'`D@"20+__TH"2P),`O__30+_
M____________3@)/`O____]0`O____]1`O____________________]2`E,"
M__]4`O_______________U4"__]6`O__5P)8`ED"6@);`O__________7`)=
M`O__7@+_____________7P+__________V`"80+_______]B`F,"________
M__________________]D`F4"9@+_______________]G`O__:`+__VD":@+_
M____________________:P+_______]L`O_______VT";@+_____;P+_____
M__]P`O__<0+_____________<@+_______]S`O_______________W0"=0)V
M`O_______W<">`)Y`O_______WH"__][`O_______WP"________________
M________?0)^`O__?P*``H$"@@+_______^#`O__________A`*%`O__A@*'
M`O__B`*)`HH"_____XL"__________________________^,`O__________
M________C0+__________XX"__^/`O__D`*1`I("_____________Y,"____
M_________Y0"__________________________________^5`I8"EP*8`ID"
M________F@*;`O__G`*=`O____^>`O__________________GP+__Z`"____
M____________H0*B`O__HP(`````````````2S":,$TPFC!/,)HP43":,%,P
MFC"K,)HPK3":,*\PFC"Q,)HPLS":,+LPFC#$,)HPR#":,/<QFC#F```#5`(`
M`U0"`0.,`@`#C`(!`UD"``-9`@$#6@(``UH"`0/I`N4"Y0+I`@``````````
M``````````````````````````````````$````"`````P````0````>````
M'P```"`````A````(@```",````D````)0```"8````G````*0```#`````Q
M````,@```#,````T````-0```#8````W````.````#D````Z````.P```#P`
M```]````/@```#\```!`````00```$(```!#````1````$4```!&````1P``
M`$@```!)````2@```$L```!,````30```$X```!/````4````%$```!2````
M4P```%0```!5````5@```%<```!8````60```%H```!;````7````%T```!>
M````7P```&````!A````8@```&,```!D````90```&8```!G````:````&D`
M``!J````:P```&P```!M````;@```&\```!P````<0```'(```!S````=```
M`'4```!V````=P```'@```!Y````>@```'L```!\````?0```'X```!_````
M@````($```""````@P```(0```"%````A@```(<```"(````B0```(H```"+
M````C````(T```".````CP```)````"1````D@```),```"4````E0```)8`
M``"7````F````)D```":````FP```)P```"=````G@```)\```#Y````^@``
M`/X```#_``````(`@`$"```#`@``!`(```4"```&`@``!P(```@"```)`@"`
M"@(```T"```.`@``#P(``!("```3`@``%`(``!4"```6`@``%P(``!@"```9
M`@``'`(``!T"```>`@``'P(``"$"```B`@``(P(``"8"```H`@``*0(``"H"
M```K`@``+`(``"T"```Q`@``,P(``#0"```U`@``-@(``#<"```X`@``.@(`
M`#P"```]`@``/P(``$`"``!!`@``0P(``$8"``!'`@``2`(``$H"``!+`@``
M3`(``$T"``!.`@``4`(``%$"``!2`@``5`(``%4"``!7`@``60(``%H"`(!;
M`@``70(``%X"``!?`@``8`(``&("``!C`@``9`(``&8"``!G`@``:`(``&D"
M``!J`@``;`(``&X"``!O`@"`<`(`@',"``!V`@``=P(``'D"``!Z`@``>P(`
M`'P"`(!]`@``?P(``(`"``""`@"`@P(``(4"``"&`@``B0(``(H"``"+`@``
MC0(``(X"``"/`@``D@(``)0"``"5`@``E@(``)<"``"8`@``F@(``)T"``">
M`@``GP(``*`"``"A`@"`HP(``*4"``"F`@``````````````````````````
M`````````````!`!$`(0#(,.@_L0&H,;@Q^#`8.;$)P0M`!`@Z@`/H/C@S^#
M_1#^$)T0GA`#$-TN!1`&$`<0_!`5!Q`'#X,\@QP0%@=<@R8')0<8!QD''`<=
M!PB#"8,4$!40.X,]@UN#78,($`D0"A`+$`P0#1`.$`\0$!`1$`N#$@FQ`-<`
M]P`=@V`)'(,>@V8)9PD>"30)0@U`#;``,@<S!P,(Y8,$@Z(`HP`%@P.#!H,*
M@R"#IP`&#04-RPS/#,X,QPS&#*$,H`RS#+(,O0R\##L'$A"2")`(D0B3"!,0
M!X,"@PV#7H,S$#00-1`[$#P0_Q"?$`@)"PF&"8<)@@F#"2H)*0F$"84)B@F+
M"0D)!0D%"@8*)PDH":P`T@C4"``)`PF5"98)EPDE"28)7X-@@Q@0&1`6$!<0
M(`FE"1(*`@D'"6$)4@EJ"6L)&@D]"1T)-0DK"2P)8@E#"44)2`EV"7<)E`@K
M"#`';PUM#6H-(`<A![8`;@UK#6P-:0WO#+<,M@S!#,`,EPB8")8(F0C$".@(
MY@CG".D(-`\U#Q"#$8,2@Q.#%(,5@Q:#%X,8@QF#F0G)##T01H)%@N8,(@<A
M@R*#(X,D@R6#)H,G@RB#*8,J@RN#+(,M@RZ#+X,P@S&#,H,S@S2#-8,V@S>#
M.(,Y@SJ#$PDU"`\(RQ,3""<(08-"@T.#1(-%@T:#1X-(@TF#2H-+@TR#38-.
M@T^#4(-1@U*#4X-4@U6#5H-7@UB#68-:@Z`0$P?Z#_L/01!"$$,01!!%$$80
M1Q!($$D02A!+$$P031!.$$\04!!1$%(04Q!4$%405A!7$%@061!:$%L07!!=
M$%X07Q!@$&$08A!C$&0091!F$&<0:!!I$&H0:Q!L$&T0;A!O$'`0<1!R$',0
M=!!U$'80=Q!X$'D0>A![$'P0?1!^$'\0@!"!$((0@Q"$$(40AA"'$(@0B1"*
M$(L0C!"-$(X0CQ"0$)$0DA"3$)00E1"6$`$``@`#``0`!0````````"A$*(0
MHQ"D$*40IA"G$*@0J1"J$*L0K!"M$*X0KQ"P$+$0LA"S$+00M1"V$+<0N!"Y
M$+H0NQ"\$+T0OA"_$,`0P1#"$,,0Q!#%$,80QQ#($,D0RA#+$,P0S1#.$,\0
MT!#1$-(0TQ#4$-40UA#7$-@0V1#:$-L0W!#=$-X0WQ#@$.$0XA#C$.00Y1#F
M$.<0Z!#I$.H0ZQ#L$.T0[A#O$/`0\1#R$/,0]!#U$/80!@`'``@`"0`*``L`
M#``-`)$#D@.3`Y0#E0.6`Y<#F`.9`YH#FP.<`YT#G@.?`Z`#H0.C`Z0#I0.F
M`Z<#J`.I`V0-8`UB#68-80UE#6<-8PVQ`[(#LP.T`[4#M@.W`[@#N0.Z`[L#
MO`.]`[X#OP/``\$#PP/$`\4#Q@/'`\@#R0/"`_4+]@OW"_@+^0OZ"_L+_`O]
M"_X+%@T7#2`0#@T`#0$-`@T##6@-L0SP$?$1\A'S$?01]1'V$?<1^!'Y$0X`
M^A'[$?P1_1'^$?\1$`01!!($$P04!!4$`006!!<$&`09!!H$&P0<!!T$'@0?
M!"`$(00B!",$)`0E!"8$)P0H!"D$*@0K!"P$+00N!"\$O@J_"L`*P0K""L,*
MQ`K%"L8*QPK("LD*R@K+"LP*,`0Q!#($,P0T!#4$400V!#<$.`0Y!#H$.P0\
M!#T$/@0_!$`$001"!$,$1`1%!$8$1P1(!$D$2@1+!$P$301.!$\$]Q#X$/D0
M^A#:"=L)4PA4"%4($PX8"B,+S@H`#`(,#`P0#!@,%`P<#"P,)`PT##P,`0P#
M#`\,$PP;#!<,(PPS#"L,.PQ+#"`,+PPH##<,/PP=##`,)0PX#$(,41)2$E,2
M5!)5$E825Q)8$ED26A);$EP271)>$E\2L1*R$K,2M!*U$K82MQ*X$KD2NA*[
M$KP2O1*^$K\2`````````````````````-`,T0S2#-,,/`='!T@'20?-`<X!
MT`$^!3\%^`'Y`=$!T@'4`=8!V`':`=P!`````*P'H`"A`*0`I@"I`*H`JP"M
M`*X`KP"R`+,`MP"X`+D`N@"[`+P`O0"^`+\`P`#!`,(`PP#$`,4`Q@#'`,@`
MR0#*`,L`S`#-`,X`SP#0`-$`T@#3`-0`U0#6`-@`V0#:`-L`W`#=`-X`WP#@
M`.$`X@#C`.0`Y0#F`.<`Z`#I`.H`ZP#L`.T`[@#O`/``\0#R`/,`]`#U`/8`
M^`#Y`/H`^P#\`/T`_@#_```!*@%J`1(!3`$!`2L!:P$3`4T!!`'8`D$!/0%:
M`6`!7@%D`7D!?0%[`04!VP)"`3X!6P''`F$!7P%E`7H!W0)^`7P!5`$"`3D!
M!@$,`1@!&@$.`4,!1P%0`5@!;@%P`6(!50$#`3H!!P$-`1D!&P$/`1$!1`%(
M`5$!60%O`7$!8P'9`@@!'`$D`30!7`%L`0D!'0$E`34!70%M`7$"BP)^`H,"
MD@)L`FX">0*(`E8"<P)]`H("D`)[`FT"7P)R`IT"C@)A`DL!<`*!`B<!E0*4
M`F8"F`+"`5,"5P*$`F`"DP%3`5(!:`*)`E@"=0)9`EP"7@)0`F\"B@)D`HP"
M5`)1`E("C0)E`J("H0)5`I$">@)G`EH"#P#]`7`&<080`!$`$@`3`!0`%0`6
M`!<`<@9S!F$#R`+,`M`"T0(&`S\'"P,!`P0#``,/`PP#`@/E`N8"YP+H`ND"
M&``9`"4#+`,Y`QP#'P,@`P@#/0,I`R\#W@(D`S`#/`,T`QT#'@,8`QD#*@,Z
M`SL#`P,:`W8.=PYX#GD.>@Y[#GP.?0Y^#G\.ZPOL"^T+[@OO"_`+\0OR"_,+
M]`MP"'$(<@AS"'0(=0AV"'<(>`AY"'H(>PC0"]$+T@O3"]0+U0O6"]<+V`O9
M"]H+VPO<"]T+W@O?"^`+X0OB"^,+Y`OE"^8+YPOH"^D+T!+1$M(2TQ+4$M42
MUA+7$M@2V1+:$ML2W!+=$MX2WQ+@$N$2XA+C$OH2Z1+E$NT2[!(`````````
M``````````````!1!T('8`MA"V(+8PMD"V4+9@MG"V@+:0MJ"VL+;`MM"VX+
M;PMP"W$+<@MS"V`(80AB"&,(9`AE"&8(9PAH"&D(:@A)$Q03(A--$Q@3)Q,#
M$S8341-7$PT3)A,C$RL32A,[$YP3G1.>$XX3CQ/$$Z$3:P@`````````````
M`````'L3'1`?$!8(S1,A"*02I1*F$J<2J!(Q$C(2.1)^$WT3?!,````````N
M"0``````````'PF_"0```````%8.'@T```N$`A0H+B\N,"Z-+N$N_2[_+@,O
M"R]@+T@O22]6+U\O:B]L+WXOBB^4+Y<O,(')+^`O`3`",`XP&#`G,"XP0#`[
M,$$PE##,,/(PT##F,#&!!C$#,0LQ'C$U,4HQ,H%5,5<QM12=,<,QRC'>,>(Q
M[C$!,ML4$S(5,DDR5S)A,I,RR#(S@<PRT#+6,MLR-('P,OLR`#,',QPS-8%A
M,V,S?3.3,YTSLC,2-"<T332<-&LT=#1_-(@TEC2A-*DTQC3_-`XU*S4U-5`U
M7C6!-88UCC4V@:TUSC4W@0@V#C8[-DDV=C9F-CB!;S9Q-G(VF3:>-JDVK#:S
M-LDVRC8*-SV1(3<O-S,W-#=P-W<W?#><-P^!&Y*X-\<WR#?/-^0W[3?U-_8W
M_S<).!"!83AD.#F!?#B).)XX.H&I.&Z3TCC..-0XVCC@..DX##E!9ETY;3F+
M.9(YI#G#.=(YW3D3.B,Z9SIM.G<Z?CJ$.IXZISK$.KV7&3LE.P``G"X6-0,Z
M/W;`-!M!*$/V.2)P=60<8U!:JD#A0R5.[45F9*9B]7N32"<WH45Q0IL[T#E[
M9O1X8EV^78Y[%D*?7+=HB3NU/@E#ET9(2,=UC7=/1^4N"B]-+YTO23#R-C<Y
MU#D!.@D\WT`/07!!$T8%2;I03U5P5?M9K5WO7<-@#F1C:`)K57!Z<#LSE2ZE
M+M\WLF#!<.]8`"[Q.*)..'`R6BACBV(O?$$Q<#.]-.$TX#;[.14_\GCK3>1@
M+65B=G!VH';[=PLT\S.'.\]0O5_";^AV;S-<?;I:$2Z36/QA)DX8-@0U'4L:
M93M\Y3FI,V9-W%2/=4(VD2Y+</)V3V,,>>$SMC4P.W$_($;S1@1(.$SS3"E-
M6U3(5DY:-'CQ8EMH8&KM<K)-JU7*5L5YID`!:XIMLG6.2:TSAC$2-S`X1#FT
M._8^*$"I0_1#OTP43XY0%%%94=51/U,!7G9BT6*796!P6W(;?6DXO$5:3"55
M^3$N.64Y@#_</[Q"^D4J2B=+M$N+4\%?5FDL?0Y]Q'ZA/)9,>V,$,4L\MD'&
M879(85)9+OHO>#-I0"E.3UKS=PLN%C/N+E4O/2^A+W,OH#+O,PDV#SG!.K8[
MX3O168=&G$>V1TQ+LTQK4,)3C5F^63Q:AUNQ8MMB!&-W8^]CTV-F9[)J*3:H
M;.9O3G`>=XIFQ"_H/!%"65([5>5AO6+^9L!LQ783>=5YRRX:+^-IWC9*.,HX
M^S[K/RI`E$!B0-!!$D+00CE%07MF1K!(=TUP4$Q5AE9U7:5B^6>+=8YVG6SQ
M,;XR%CFS-+,[%CUH08))KTV-6,MD5VAR:J=SN'IL3:AYV6:C-_]'SF8.<H,R
MAS8$--,^X4*Y1#Q(.$B[2W)3NEAK6IIITFEK;0-O[7"C=91V:7=F.[,\?4E-
M>$YXFT,@6RM*?TJV2`U\7T]R,ITU<$#L0CM-!T[13EMD$&E$;Q0N.7SV,QM)
M.DJ$=RI(7#'#6K)DW'&,<ULV*'TB2`5C,62E7`@RQ6+F5'XN@R^@,=(["C+8
M,N<R^SV:-2HXYCF,.Y@[VSMR/GD^HT`?06-!OD';0V)%T4=32/I(/DM32U=,
M(D^73T5/L%085>-6"U?_6J%;(5SI739?\%^=8&9BGF.S:<QJJVR$<%%TDW61
M=:)U97;3=RAY&&(X+BLTN#S,/:E33%8\5ZD\ZU\+;<%V$7A4>%AX`2\.+W$S
MG#5H-OHW1SD).\0[D#P,/GX^S#_N0SI'UT7B11]'RTC$2%]*,#[%2Q=,?4Q_
M54A98SL`6@!=O3^/:1AJM&QW;<QN'6_B>`YZ/'N`+GTP`#&3.9P[+T*`0NQ$
M.DN@4I%51UFI7_MGO&IP:ZQ#RF.@=PDT`S2K-51(6$IP:B=8=4?-?G0SHCL:
M85!F!G`8+D4NQRX1+\HS.#2N.Q,_)4!113U'0DQR3.-,>%`#5'9:KEH(6QI=
M_EQF7>=%6U*[,T4\Z#W20N!"&4,@3EIF,6K=;?AR`4^F65I[J"ZK+JPNFR^@
M+]$P1S'V6G$Q]C%4,R$S?S/K,ZPU@SCA/#<_2C\O0%!`;4`?0UE%2TK!3,)2
M[5+O5_A@!6$(8DYE]W#A<_]W5WE:>O`NW3$M/(%&;4E`//)&=4F)4U!(@5S%
M,.0R1S?^/29SI$4C2SU+-%2!6;U92UO*7;EBS&-_:%]I.6O1;]%Q'S2`<ETN
M-C#E,SHSUU*64^E7YF*O;L9YR'G2>7<Q&D%>9K`U>EIV,-,[1W"%=C(NVTKG
M<5$\2#R80Y]:DTQT=V%OJEJ*48AV@EP72'!>44AL<_(R&S2K91-JI%_-;N%P
M9C.(:$%9PB^^,!$R1#%3-2TWZE.+-U$Y8C^$/W5`=D%G0:E!LD,Z1&Q%;T9"
M2!-.9E4]6OM<3%V974M>:U\.8TICS68(:F-J9FO];AIXCWVX8LYOZ'N',A]"
M@T3`3YEV04B1,"!+>DQ43W1:4%U`:"-J"$?V+CDP)C!E,'PQ.#)C,J<U#S<%
M.,PZ^CZR0?A!\T)R0QQ)*4I]4JQ2+E,46&]8>5T,5ZE@BVD9:^)LTFYC<'5S
M>G95>!-Z>'Y#,9\SLS-[/B8_&TZ03H13_E-#73=B`&KZ:E!V3BX+,.0S?#3Z
M-M$Y9#OQ/:L^)S\X0D5%KT=63M!2RERT:*%@X6#P8TYFAVKH;3=RQW9G>!-_
ME"Z2+@TO2#-)-#XT+SJ,/Z$_GT"G2(Y*6E2!6)YJI&IW:Y!Q7B[)>Z0N?"^O
M+QDP%C!),6PQGS*Y,OXRFC/C,Q$T#C2)-5$WHC=].50[73N/.^4]YSWW/7@^
M@SZ:/K<^&#]20$Q!ET+80J=#.T4"1D-&]$9M1R%(ETC+25],*DUI32].G4XR
M58=6;%@_6N!<!5T875Y=L5T58`-@KV"Q8%1ACV$J8E)C3&AA:!MKHFS\;,IP
M=7%Q<C]8_'*D=4UV!7B9>=AZ.WU;,JLR]S,(--4X]T+@3VIL7V^Y?DLQ.S)*
M-/TV0%IW<6!]TGY$4PE/<&$15?T_VD"H>MM2O&]D2P-XRB[P-F0WOCA:.FA`
MQT$/1@9&.4BQ2/=-U54Z76YB0GN;+E`OR3,&-6\]YCWN/?M'F4QS5`)84&J6
M<]]H4#>G/BM#M3"L,(TQ`$?)-%XXNSFP.VD_34*A0SU(<TL(3GU0QW&`4A58
M)EAM68Y%,%W<8\%H"6^;=F0R*#=01VI?H6RT,4(W*G8Z.(I)M&"R-`X]_#>5
M6/I]7"]*,HLT/D0H1A1']4>$6E9;(ETO<UQ(K7LY6QDSBC$W,M\[]D*N1.9$
M+4>Z2ZEET7:05M9[3$,&<ZM[OU921@DNF##",W$\Z$"21&-%7TCF4<I3(U67
M6X)>E6:#:]ML>'$0>:Q%JT:+2]4NU"XZ+W\O.C+X,_(SXS7;-NLXRSG).?\Y
M4#M-/`(^*S[7/QU`!T,O15P[KT6]1>A%G4=B2WM+#TQ%4TE9P5GX7!E=*UVB
M8`)A\V&6:5YJ:6IF:HQJ[FK';-QLS';\>&]+BRX\+XTO4#%7._H[2$$!0T)&
M(4O+3KM,/E*]5-15P5@Z60Q@,V#J891DGF]03']^#S]8:RM]^EKX;HT[ZW8#
M+O$S]S<Q.<DZI#N)0'].!D^^5>ILGSL`9>!;<C#T1YUB83Q*91Y>#F*9,00\
M:$-F;9Q%;E$^61==!6`=:\IN;G#'9JIP'S#Z,CH\4T=\4#523''(<2MSY6+"
M.S$_^4`[+M8SB#M+0C%'BDOI4N!3+EIK8:-M4G&6>1(QUS-J-/\[B$,Y2JQ=
M`'?:-LXS:#27.S$\WCWN+P%!_D(R3<!9RUE"74U>TE_M81]BD&1&:')ID&MT
M;B]O,7!+<6QQQG:<<<`N3R]%,4$SDS\.0M1'04P+3F-3)E[-<8-RU#,9.;\[
MT4U=62Y>FUQ^.)]1^C%3:/!ORB_[/"5&K%?C6AQB_WG&,:H_[$5O28E+\TV6
M3F1/_E847>$]=7"'<09XYC$=,D!"D4;91AI.MC[277)?^$:O9?=E^&JI,MDS
M<SF//I`_54#D<F1VMS`?,=TR(#-',^PSZ#1&-3$U%S9H.;XY/#JU.P8\#SP1
M/!H\A#Z*/N`^<#]_0H1"VT*,0W=#!T8,1BU&=D9^1Z)('THU2KQ,B$T)3EA.
M/%$F46=1QU4!5UU8`5EE6?!9X%H16Z=<.5V68-9CBV1)95UH\V@?:CQJ5&IS
M:F%LWFRD<69R?G,8=)QVF'<*+@@N'BY7+I<Q<#+.-S0XS#@B.S@^Q4#^1&%'
M5D=$3;92<U5C6KAD<FNX<2!S,3;T-_YX[4(-299+[5%47G=@<F+F:=]X56>Q
M;SL\."_A+[4O!S4@.MT[Z3O#/TY!+T.P14M&[DB;27A-\4TS5;E5'U=>6>99
M,UWC8:]BJF6J:3IJJVZ;;S)PW7$'=[HNP2X#,G4X[#@+/!I5/3Q.80IJQ6]C
M=FUW)5O/:@AX8G'S-J@S%W`Y-((W)3ZH0S1,BE!A5XM<X%]P:$)P5'$0<QAS
MCW9>5,1Z!SUI/7!%HD>H;=MV;D-)1QE)Q6,7>,!V_FB$3WI$^#L6+BQ0754O
M1L0Q-C+B,M,Y@3\G0!!"/T5T11]&=$;R2!9(8TL%3G)2'U7;5KY<5F#P./UH
M?VF@:I-JRVH=<))Q4G=9=XE%#EH&8;MV+3[<0!I"I4441I!'\U=-6DU</EX*
M8:QL9&WA;5]NJ5@',ME"I4-"1)A"+6J#6L!;K&KJ=G9=#&))9]DN2#%#,V`S
MHSL"/!8\W3TF0D="L$032#1(R4Q%31=-TT=<3TY1?5'+17]:K5O:74I>J%]Z
M81MB.6*F96YJSFSU;7AP=W"M<I%R@W6N>TTRA#4X3S91:#&%655>LV'.7$PV
M43BH/*I#_D;]1EI)V5*/58Y5#EE66=]9EUP@741=!V8T:CMV87`@?^<P=3+,
M,^(S"3"J->XX3SD]4HL[9#P=,^-`\T!<0X-#/T.[0\U$Z47Y1N,]S4G]215/
MY5&)+NE5^%:36M]<SUV<76%@26-88VQDO&3[9<5H<&T!<&UPEW,<=Q)ZSS"7
M.(Y!TV$U90AM('##+W0P1S)S,V]`24-?1RQ.LVT?<-<O7CS*;,]%FEU2,Y9H
M=C'#0U@[:SL*/`U$44=<<-8N&CDJ.7!,46H^-14XI3GP0%-"P4<U8E5)0';$
M>2AZ4R\&./X[$&"Q/"\^A3\@0$M!-$+_1O!,WD[.8']AU&*+:+AL`'`N<(IV
MVW[;>^,N\#,G.2Q;C7%,>/E]W4XG4%,S1#6%.UA"GD+30J),[T\B5!=J.'3!
M3_YJ.&/G,?AFZC/I,T8O5'"P;VHY,6']/>I:OV_:2#=L^%)(?#U*L&HY+E@S
M!C9F-\5"HD/F14Y+X4U;3JU0[5?O6JI;NUT]8,9@RV:5:EMSXS;'.#X_K466
M1H!*M4LW5<=J)##E5S`W&S]E0'I&8$ST51I:;E_T81AG17"S><E;7%7Y6E%;
MQ&00<.E9DEHV8^$Z0%<M+O(NF3O@/[U"/$;Q1^A,:V9W:#MJ3G'S<M!Y%THF
M4"I3YV)79*]L`2Y&,<LQBS7U.Q8^,SZ!/A0_-3]K/[0_\D$10Z)&'4=N3U)2
M.E4Z5W1@.6%X879GOVK<:H5M\VV:<G=U`GCE?,4R5T/T5A5'B$S-4\-LKG-S
M=B5-G#@.2<Q)_6^:<]M5&G!:.`)(M$/[24,O+$_81[MO)F6T751S/TEP3VHW
M]S@L.RQ=*E(*-.-QM'VM+DXO7#!U,$,RGFQ(-"0XFCL=/I4^K3[W/A\_C$"U
M0CI#T$.O2$!,AUB.60M:X%U'8@)JYFI$;A-PN'`M<=AQ#G_E3%A$XD1U1?1.
MA%8;6VEPT7.Z3O(TN3^D1$UO[6]$<G@Q:S@I.54\ES[[38]>'%6\;.)N6WBY
M4!TOOTNQ3S!5^W9.,1`T-3A7.*PY8#R2/Y=%7$<A3GM6WV/M;!1P_7!-<R58
M.EBJ,J8^'S=T.1)`$C!:,:PQS3$`,A`U5#A8.%<YE3OV/(L]O$"50BU$<4=#
M2+Q(WTC75MA-;TZ;36]0R%%3/]A5=UE)6U1;4EO67'%=,#)C9&EEY&4.:@1K
M1FP/;@-P#W`9='9V+7@P>MAUS3#5,@PT`C@./*=!GD0>3;-7Y5KT8`1D4W"%
M<N`\!WT_,Y<_LS^<37E28U>_6>1;TDOL4JUJ`TAA2O@Q@5HT24H\]GSK8L4[
M27$>4'@V;SS'0&9%C$Q:;$%P$WA1-,=&#7)(.:-PA3%-+NHQF64.:UA0>D-+
M<V))M'D$7G=55S-@2=]NXW9=3(PN/#P0/^EO`C/1;(E@>6;_/N5%<RYE,8(Y
M/SSN=_LNBCG-/XUJX4^P66)9YSMQ9"M3L5%T/O4_>T.:1,-1F%Q#+OP^2R[<
M-Z(VJ4##3PU=_6`S8;]ALF^7::1F]#V*0JU$AVEW1^),/DTV5#181CIU7ZUB
MK'GS+\,^W4*20U=%;T?#5DQ2S&"Z8"EO37$-,/DWDCJ%2'-)9%']4K=L\CC@
M;&IV&7!_9^19YU<I9"\O93):,\U"ST?*3'U6E%N57#9BA&7K;]U&($\&4AM>
MJV/!>:9^_3&Q6W)8N%N'8$A;Z$IA/HQ@455@56LQ8G*,3GI6EW'J>A`O<%^<
M0D];I77I?'HV63CD9KQV-"\D,DHSS3/;,P8^+$2117]'/DQ.3$A2KU+M4U15
M05XL8NEEJ6S$6\9Q:5$2>.]X/4-I1FI5Y%;06$-E[F8J,U$S)C2#.8<^?#^R
M0$E">4*K0I!%U$O,3+)5KE:16-A9RUUW7Z5@JVBY:KML?W!>=]MX"THX7)DP
M/CRN/X='V$LU5`E7CE\[?\I'%UHY,XM5[7IF/YUA\6.88#P_Q3]B549;/'!G
M2.LYFSH077Y6+&OU+VH_&4HW3`)/XE1H66AH56IY;-\^ST/%5=)9UV(H<_)R
MG&3M9BU\P31L/XQ%7$T54*=LTVP[>$]%]E0-+M@NX#<K.68ZS#NH,0,^G#X6
M0'9"=T6G16Y&;DTV4B9;4&&:89EB7&N@;.9L=&T<=D1VKB^K1&9+'F)A9&IE
MZ'`!/%-)J'AZ9%=E#R]O,JD_13X-1X]9>6$':89I]4T7/U5"N$S/+FE2DGL&
M,CLT=#:S.*1!;D(:46XYB5S>7!M=\':'15Y@&2YU+W4Q0#AC/G,^"C_$1R8N
M/66)=5MV<UP!>/LPP3A65J=8)3*E5Q%EAEM/,`DY1U+'6^A=NF_4;TUPOR_)
M,BDZ`3^M=]TO%V+J<@,W54-I2RM5W&@4;T):WS*3.%5!"D*N1LU+/USI8R,P
M^"\%,T8T,3A).9T[\#SO/"D]ECZQ0F=#/D6Y10M'U4SA3/E0,E@K7MY@LV(,
M9.QD`F<2:2IJ2FRF<-)R_7CS?&Q]3RZA+HTP5C)*-Z@Y/3[8/]D_/T*T1AM'
MT$?22)(Q(5VJ8*AA`&N,;+]L?G(R=B`T+'@7,]4P7#.H.+)$-$=G4F971EKF
M<<,RH4R&2P`X3#Y4.2Q'^U_A,<96:43H6%1[NW[+-[DY)T::1\Y+Z339254^
MG&&51ZI[_D=2?%U(IB[C+\@SN4(K1ZM,Q&^M+VU>OWX'+F)!@$XK3Q-E<S0J
M1T5[\SV56ZP\QCL<9TI.T6046@AAF3F-7!%,(%?9,B(Y(5%?4MM7)W=A?0M)
M?SH8.J4Q#31]-`Y&WU;W;YAR]'SJ.5U2Q4Y-,<E(OUWL76)WNGYX1"%*`F.$
M.5\[VTL;4_)6LET78)ED,C$H1]E^[E9B1_\R!7DD/#M"?ERP;$\UMD`+78!U
M`3-?+K8Q'#DZ4C9@SG$E/^)7A#-Y/P1=K&4S:HUN5G?S1ZYE4W0)00A!N4Q2
M5NUJ.&\O-5$O*C'',LLSI3M]/J!`@D'60PE'VD=G3HQ--E,W4S%54%G5:)AJ
M2G"1</5PQ':-9Q4YB"Y9+PXNB6H_;Q!XK3!\/I8YN3NX/MI#^D/!1-Q&2DG8
M20M-MDZ442A5KUJ*7P!@263)9(%I(6L*;F5P?78*>7Y!D4(R2X-,=$W,7_Q?
MP$V%7[IG^&AE1[%C/'CW=AM-85T]9&IQ<2YU,U`]!$OK3\UE+6:G:2DR#S1E
M/$Y'J$@&5(-4XE7/:.%HS''B=GAVBS^'4\M:3F2@0V55B3)!39Q."51956M8
MDER&=MQ:C7^V+VY!Q45<9H8NKB[:,"$NS#'N.YE%@4B\31]30E:M5QQ:YUQO
M8M)J?'#/<75V&'B;,M%=*S"8,Y='RTW043-4Z&$J;Z-V5WR??F!403B932]=
M7GCD+C8OBR^W,;$RNCT<0+)3/%G38C1RMW;V=@IWEWYB?Z9&=$L7,J,RR%#"
M:,D^2T"002-/25$^7/1=;V#N9"-P+'-"-&][TTJ)4,)L[VTR=[0R03K*/@0_
M%T=\291):DT/3V)2_%+M6P%@?F!+9\YP;3&3?H19BV`R<]9J+3",-'%J:DO$
M;`=AT4"@1_)]F2Z8+A!\:VK!96AE`$E^3I=856$``$$[5CM].Y,[V#OL.Q(\
M'CPC/"L\C1=B/#N!/(&TE7H\CSR?/*,\JCRZ/,L\T#S2//0\-)OB%PT])ST1
M@48]1SU3/4H];3V!/:`]I#VG/;@]RST```P_$"X5+BHN,2XV+CPN/RY"+E8N
M6"Z"+H4N:VR*+A)B#3^.+IXNGRZ@+J(NL"ZS+K8NSB[-+L0NQB["+M<NWB[M
M+M\N]RX)+UHO,"];+UTO5R]'+W8OB"^/+Y@O>R]I+W`OD2]O+X8OEB\8,=0O
MWR_.+]@OVR_1+]HOT"_D+^4O&C`H,!0P*C`E,`4P'"_V+R$P*3`L,/XO[R\1
M,`8P0S!',`-'53!0,$@P6C!6,&PP>#"`,)HPA3"T,+(PR3#*,+,PPC#6,-XP
MY3#M,.,P[C#Y,/4P"3$!,0(Q%C$5,10Q&C$A,3HQ-S$\,3LQ/S%`,5(Q3#%4
M,6(Q^%II,6HQ;C&`,8(QV#:,,8DQCS&1,9,QE3&6,:0QIC&B,:DQJC&K,;,Q
ML3&R,;`QM3&],<4QR3';,>`Q56;I,>TQ\#'U,?XQ!#(+,A0R#C(G,BHR+C(S
M,CDR3S)$,DLR3#)>,E0R:C)T,FDR<S)_,GTRC3*4,I(R<3*(,I$RJ&^G;ZPR
MK3*\,K4RP3+-,M<RWC+C,N8R[7C@,O,R]3+X,ODR!C,(,SA5#3,0,P\S%3,:
M,R,S+S,Q,S,S.#-`,T8S13,7+DDS33/6,5XS:3-N,Q@Y>S-W,X(SEC.@,Z8S
MI3.N,[`SMC/#,Q)<V7;?,_Q&[E'N,^@S[3/Z,P$T/31`-"PT+30\-"XT-C0I
M-!TT3C2/-'4TCC1?-'$T=S1P-)(T>S2`-'8TA#20-(8TQS2B-+@TI32L-,0T
MR#2H-*LTPC2D-+XTO#38-.4TYC0/-10U_33N-.TT^C3B-#DU0#5C-4PU+C5<
M-44U5C57-3@U,S5=-9DU@#6O-(HUGS5[-7XUF#6>-:XU?#6#-:DUAS6H-=HU
MQ37?-<0UW#7D-=0U%#;W-18V_C7]-1LV^35.-E`VWU$T-C8V,C8X-FLV9#8O
M-FPV:C:&-H`VBC:@-I0VCS:E-JXVMC:T-L(VO#;!-L,VP#;(-LXVT3;3-M<V
M[C;Y-@`W_S8$-PDW"#<+-PTW$S<8-Q8WQS4<-R8W-S<X-TXW.S=`-T\W:3?`
M-X@W83=_-XDWDS>@-[,WI#>J-[`WPS?&-]0WTC?3-PHXUC?C-PLX&3@=.'(X
M(3AB.$LX<#C`2U(X/3AY.(4XN3B?.*LXNCC>.+LXN#BN.,4XTSC1.-<XV3C8
M..4XW#CD.-\X[SCZ./DX^SC\./TX`CD*.1`Y&SFF2"4Y+#DM.3(Y.#D^.=):
M53E0.4XY6CE8.6(Y8#EG.6PY:3EX.8$YG3E>+ZLOHSFR.<8YZ#G<.8TYV3G:
M.24Z'SH1.APZ"3H:.D`Z;#I).C4Z-CIB.FHZFCJ\.KXZRSK".KTZXSK7.N8Z
MZ3K6.OHZ^SH,.PL[%CLR.]`Z*CLV.SX[0SM%.T`[43M5.UH[6SME.VD[<#MS
M.W4[>#N(17H[@#N#.Z8[N#O#.\<[R3O4.]`[Y#OF.^([WCOE.^L[\#OV._,[
M!3P'/`@\#3P3/"`\(CPH/#@\.3Q!/$8\3CQ3/%`\3SQQ.VP\;CQB+G8\>3R,
M/)$\E#R;.:L\NSRV/+P\MSS%/+X\QSS9/.D\_3SZ/.T\C#WJ/`L]%3T7/5P]
M'ST;/1$]%#TB/1H]&3T8/4P]4CU./4L];#US/78]ASV$/8(]HCV=/:P]KCV]
M/9`]MSV\/<D]S3W3/=(]UCW;/>L]\CWU/0L^&CX9/A$^&SXV/C<^1#Y#/D`^
M3CY7/E0^7SYB/F0^1SYU/G8^>CZ\?G\^H#[!/L(^R#[0/L\^UC[C/MT^VC[;
M/N(^X3[H/ND^[#[Q/O,^\#[T/O@^_CX#/PD_73]</PL_$3\6/RD_+3\X/T$_
M2#],/TX_+S]1/U8_5S]9/V$_;3]S/W<_@S^"/W\_BC^(/Y$_AS^>/YD_F#^@
M/Z@_K3^\/]8_^S_D/_@_\3_=/[-`_S\A0&!`&4`00"E`#D`Q0!M`%4`K0"9`
M#T`Z0%I`04!J0'=`7T!*0$9`34!C0$-`9$!"0&Q`:T!90(%`C4#G0(-`FD"$
M0)M`ED"70))`IT"+0.%`N$#@0--`M$#P/[U`QD"U0-A`34$5009!]D#W0`!!
M]$#Z0`-!(4'[0/%`#4$.04=!/D$H02=!2D$_03Q!+$$T03U!0D%$07-!=T%8
M05E!6D%K071!;T%E07%!7T%=05-!=4&9099!AT&L091!FD&*09%!JT&N0<Q!
MRD')0?=!R$'#0<9!ND'+07E?S4'F0>-!]D'Z0?1!_T']0?Q!_D$`0@A""4(-
M0@Q"%$(;0AY"(4(J0BY",$(R0C-"04).0EY"8T);0F!":$)\0H)"B4)^0I)"
MDT*60M1"@T*40M="T4*[0L]"_T+&0M1$R$+<0LQ"RD+"0L="FT+)0@Q#[D+Q
M0B=#`D,(0^]"]4)00SY#34,<1$]#ED..0X!#JT-V0Z-#CT.)0Y]#M4-K0VE#
MOD/I0\!#QD/C0\E#TD/V0\1#%D0T1`9$$T0F1#9$'4471"A$#T1G1&]$=D1.
M1"I%E4231*5$J42(1+Q$VD321,5$QT2[1-A$PD3Q1.=$"6+@1.%$K$+C1.]$
M+$7V1/1$\D3Z1`!%_40811Q%!44D12-%*T4T135%-T4V13A%2U5(159%545-
M15A%7D5=17)%>$6"18-%BFN;19]%JT6W1<-%QD7!1<1%S$721=M%V47@1>%%
M\45R1PI&`T;[17-'-48V1C1&'$9/1D1&249!1EY&749D1F=&:$9?1F)&<$:#
M1HA&CD:)1H1&F$:=1L%&N4;)1KY&O$;$1KA&UD;:1N!&/T;F1NE&\$;U1O=&
M#T<61QY')D<G1SAW+D<_1S9'04<X1S='1D=>1V!'64=C1V1'B4=P1ZE'?$=J
M1XQ'BT>F1Z%'A4>W1^]'M$?L1[-'Z4>X1^1'WD?=1^)'[D>Y1\Y'QD?G1YQ*
M'DA&2"E(0$A-2#)(3DBS2"M(64AC2'=(?TB?2(](K4B42)U(FTB#2*Y*N4AT
M2+5(H$BZ2`])C4A^2`%)RD@(2=A((DDF2>%(#$G-2-1(YTC52#9)$DD$2==(
MXT@E2?E(X$CO2"A)*DD:22-)(4G&2'E)=TE<27A):TE427Y);DDY271)/4E9
M23!)84E>25U)@4EJ2;))KDG02;])P4G32;Y)SDGH.\I)W4F[2<-)ITDN2I%)
MH$F<295)M$G>2>A)`DH;2O])"DOY2?))YTD%2K%)'DKM211*ZTD*2A)*P4HC
M2A-*1$H,2G)*-DIX2D=*8DI92F9*2$HX2B)*D$J-2J!*A$JB2J-*ETH79KM*
MPTK"2KA*LTJL2MY*T4K?2JI*VDKJ2OM*!4L69OI*$DL62S%['TLX2S=+W%8Y
M2^YX1TM#2TE+4$M92U1+6TM?2V%+>$MY2W]+@$N$2X-+C4N82Y5+GDND2ZI+
MJTNO2[)+L4NS2[=+O$O&2\M+TTO?2^Q+ZTOS2^]+OGX(3!-,%$P;3"1,(TQ>
M3%5,8DQJ3(),C4R:3(%,FTQ^3&A,<TR23)!,Q$SQ3--,O4S73,5,W4RN3+%,
MODRZ3-M,[TS93.I,'TU-:#9-*TT]33A-&4TU33--$DT,36--DTUD35I->4U9
M38Y-E4WD3X5-^4T53@I.M4W'3>9-N$W&3>Q-WDW,3>A-TDW%3?I-V4WD3=5-
MZDWN32U.;DXN3AE.<DY?3CY.(TYK3BM.=DY-3A].0TXZ3DY.)$[_3AU..$Z"
M3JI.F$[)3K=.TTZ]3J].Q$ZR3M1.U4Z/3J5.PDZ?3D%/$4],4.Q.^$[^3C]/
M\DXQ3^].,D_,3CY/$T_W3H9/>D]X3X%/@$]O3UM/\T]M3X)/?$]83XY/D4_"
M3V9/LT^C3Z%/I$^Y3\9/JD_?3]5/[$_43]A/\4_N3]M/"5`+4/I/$5`!4`]0
M_D\;4!I0=$\=4!A0'U`P4#Y0,E!14&-0F5"24*]0\5"L4+A0LU"N4-]0RU#=
M4-E0"5']4!Q1&5%E4551B%%F46)13%%646Q1CU'[4811E5&H4:Q1UU&Y4;Y1
MTE')4=11SE'@4>Q1YU'U4?Q1^5'_40U2$%(;4BA2+5(L4C!2,E([4CQ2/U)`
M4D922U)84G12?E*"4H%2AU*24I92HE*G4KE2LE+#4L92Q%+.4M)2XE+@4N%2
M^5+W4@\P%U,*4QQ3%E,=4S13+U,I4R53/E-.4T]3V'Y74VI3:%-P4WA3=5-[
M4WI3R%.S4\Y3NU/`4^53[E/>4Z)4!51O5"54^%,R5#I4550_5%]4651!5%Q4
M:51P5&-4:E1V5'Y4BU2>5*=4RE3/5-14\5/@5.-4YU3I5.Y4\E3P5/%4^%3W
M5`15`U4%50Q5#E4-5155$U4>5295+%4\5415355*54E56U5&55I5:55D56=5
M:U5M57A5=E6&58=5=%6*58E5@E6459I5G56E5:-5PE6S5<-5M56]5;A5O%6Q
M5<U5RE725=E5XU7>5?Y5_U7\50%6\%7Z5?)5\U4+5@U6"58?5B=6(%8A5B)6
M)%8T5C!6.U9'5DA61E9<5EA6859B5FA6:59J5F=6;%9P5G)6=E9X5GQ6@%:#
M5HA6BU:.5I96DU:95II6L%:T5KA6N5:Z5L)6S5;65M)6WE;A5N56YU;J5B]F
M^U8(5P=7!%<I5R17'E<E5R97&U<W5SA71U=:5VA7:U=;5V57?U=^5WE7CE>+
M5Y%7H%>>5[!7ME>Y5[]7O%>]5[M7QU?-5]=7VE?<5^-7[E?\5PQ8$E@F62!8
M*EE%6(Y8=%B&6'Q8FEB,6*-8M5BJ6*]8T5C&6,M8U%B^6+Q8Q5C*6.Q8YUC:
M6/U8]%@'61)9$5D962Q9*UE`66!95UE?65I955E367I9?UF*69U9IUE+?ZI9
MKEFS6;E9NEG)6=59YUGL6>%9XUD(6@U:&%H96B!:'UJ`63%:.UH^6C=:0UI7
M6DE:85IB6FE:G7]P6GE:?5J(6I=:E5J86I9:J5K(6K!:MEK%6L1:OUJ#<,=:
MREK-6L]:U5K36ME:VEK=6N%:XEKF6NU:\%H"6P];"EL&6S-;&%L96QY;-5LH
M6S9;4%MZ6P1;35L+6TQ;15MU6V5;=%MG6W!;<5ML6VY;G5N86Y];C5N<6YI;
MBUN26X];75N96\M;P5O,6\];M%O&6]U;Z5L17!1<YEOE6V!<`%P'7!-<\UOW
M6Q=<#5SV6R-<)UPJ7!]<-UPK7#U<3%Q#7%1<3UQ`7%!<6%Q?7&1<5EQE7&Q<
M=5R#7)!<I%RM7*)<JURA7*A<LURR7+%<KERY7+U<P%S%7,)<V%S27-Q<XEP[
M>^]<\EST7/9<^EP&70)='%T570I=15U+72Y=,ET_735=1EUS759=3EUR76A=
M;EU/76-=DUV)75M=CUU]79M=NEVN7:-=M5W'7;U=JUT]7J)=KUW<7;A=GUVP
M7=A=W5WD7=Y=^UWR7>%=!5X*7B->(5X27C%>'UX)7@M>(EY&7F9>.UXU7CE>
M0UXW7C)>.EYG7EU>5EY>7EE>6EYY7FI>:5Y\7GM>@U[577U>KF]_7HA>B5Z,
M7I)>D%Z37I1>EEZ.7IM>G%XX7SI?15],7TU?3E]07U%?55]47UA?7U]@7VA?
M:5]G7WA?@E^&7X-?B%^'7XQ?E%^>7YU?FE^C7Z]?LE^Y7ZY?ME^X7W%KQ5_&
M7\I?U5_47^%?YE_I7_-?^5_<>`9@!&`+8!)@&&`98!Q@(6`H8#]@.V!*8$9@
M4F!88%I@7V!B8&A@<V!R8'!@=F!Y8'U@?V"$8(9@A6";8)-@FF"M8)`QK&#;
M8.5@V6#=8,1@VF#68`EA[V#Q8!MA*6$C82]A2V&+=D9A/F%385%A_&!Q86YA
M96%F871A@V&(88IA@&&"8:!AE6&D8:-A7V&38:EAL&&U8;YAN&&]8<!APF&Z
M8<EAS6'18=EAV&'(8=IAWV'@8>=A^F'[8?YA`6("8@5B!V(*8@UB$&(68BEB
M*V(X8C-B0&)98EAB76):8E]B9&)B8FAB:F)K8BYB<6)W8GAB?F*-8I)BJV*?
M8KMBK&+A8N-BWV+28O1B\V+Z8I-C`V/[8OEBWF(&8]QB"6/98C5C-&,68S)C
M,6-`8SEC4&-%8R]C*V,78QACA6.:8ZICGV.B8Y9C(V..8X=CBF-\8[5C<V-U
M8Z!CB6.H8_1C$V3K8\YC_6,#9-AC"V3!8_=C!V3@8_)C#60B9"!DO6,X9`9E
M^V-M9"ID/&1:981D=V1K9*UD;F2"9&ED1F0L9&]D>60U9,ID8F2Y9+]DGV39
M9,UDNV3:9-!DP63&9-9DH60A9?]D]&0791AE+&4?915E%&7\9$!E8V5894AE
M064"9DME566`9:1EB&6198IEJ&5M991EFV7J98=EG&5W97YED&7)9;IESV6Y
M9=!EU67=9>5EW&7Y90IF$V8+9OYE^F4&9B)F&F8P9C]F3695+E1F7V9G9G%F
MDV:C9JEFJF:+9HQFMF:O9L1FQF:P9LEF(VBK9M1FWF;I9NQFWV;;9N]F$F<&
M9PAG`&<#9_MF$6<)9PUG^68*9S1G/V<W9SMG)6<I9QIG8&=?9WAG3&=.9W1G
M5V=H9VYG66=39V-G:F<%:*)GGV>"9Z]GRV>]9\!GT&?6=JMGQ&>S9\=GQF>[
M9^]G\F?@9P]H#6C^9_9G]V<.:-)G$6@6:!5H(F@A:#%H-F@Y:"=H.VA$:$)H
M4FA9:%YH8FAK:(%H?FB>:'5H?6BU:')H@FB7:))HKFB9:*)HC6BD:+!HOVBQ
M:,-HQ&C4:-AHV6C=:/EH`FG\:/1HZ&CR:`1I#&D*:1-I0VD>:25I*FDK:4%I
M1&D[:39I.&E,:1UI8&E>:69I9&EM:6II;VET:7=I?FF#:8AIBFF3:9AIH6FI
M::9IK&FO:;)INFF]:;]IP&G::=QIW6GG:?1I^&D#:A9J$&H,:AMJ'6HE:C9J
M06I;:E)J1FI(:GQJ;6IL:F)JA6J":H1JJ&JA:I%JI6JF:IIJHVK$:LUJPFK:
M:NMJ\VKG:N1J\6H4:^!JXFKW:MYJVVH,:P=K&FOA:A9K$&L7:R!K,VNK=R9K
M*VL^:RAK06M,:T]K3FM):U9K6VM::VMK7VML:V]K=&M]:X!KC&N.:Y)KDVN6
M:YEKFFLZ;$%L/VQ(;$QL3FQ0;%5L8FQL;'AL>FR";(ELA6R*;(ULCFR4;'QL
MF&P=0JULJFR];+)LLVRN;+9LR&S!;.1LXVS:;/UL^FS[;`1M!6T*;0=M#VT-
M;1!M3G\3;<UL%&T6;6=M;6UQ;7-M@6V9;<)MOFVZ;<]MVFW6;<QMVVW+;>IM
MZVW?;>-M_&T(;@EN_VT=;AYN$&X?;D)N-6XP;C1N2FY';DEN3&Y0;DAN66YD
M;F!N*FYC;E5N=FYR;GQN@6Z';H5NA&Z+;HINDVZ1;I1NF6ZJ;J%NK&ZP;L9N
ML6Z^;L5NR&[+;MMNXV[\;OMNZV[^;@IO!6\5;Q)O&6\3;QQO'V\;;PQO)F\S
M;SMO.6]%;T)O/F],;TEO1F].;U=O7&]B;V-O9&^<;Y]OHV^M;Z]OMV_:;^5O
MXF_J;^]OAW#T;P5P^6_Z;Q%P%7`A<`UP'G`6<`MP)W`V<#5P.7#X;T]P4'!1
M<%)P#G!)<#YP5G!8<%YP:'!O<'9PJ'9R<()P?7"!<(!PBG")<(]PJ'"O<+%P
MM7#B<.1P2$+;<`)Q$G$9<3)Q,'%*<59Q6'%C<65Q:7%S<7)QBW&)<8)QHG&K
M<:]QJG&U<;1QNG'`<<%QR7'+<=!QUG'?<>%QVW'\<?5Q]G$><O]Q%'(L<A5R
M$7)><E=R17))<F1R2'*5<C]R2W)0<IQREG*3<IMR6G+/<KERMW+I<@]S^G)$
M<RYS&7,B<QIS(W,Z<S5S.W-<<V!S?'-N<U9SL'.L<ZUSE'.Y<]9SUW/H<^5S
MV'/#<]UST'/(<^1S&G04=!-T`W0'=!!T-G0K=#5T(70Z=$%T4G1$=%MT8'1B
M=%YT:G0I<G!T=71W='UT6G1\='YT@71_=()UAW6*=91UEG68=9EUH'6H=:=U
MK76\=;MUN76^=<IU]D_#=<UUS'75==1UUG7<=>%UY77B=2%V*'8N=B]V0G9,
M=D]V2W9W=EQV7G9==E]V9G9R=FQVC7:8=I5VEW:J=J=VL7:R=K!VM':V=KAV
MN7;.=LMVR7;-=DUIW'8-=]5V^78$=P9W"'<3=PYW$7</=Q9W&7<D=RIW,'<Y
M=SUW/G=$=T9W2'="=TEW7'=@=V1W9G=H=](R:W=Q=WEWA7=\=X%W>G>&=XMW
MCW>0=YQWJ'>F=Z-WLW>T=\-WQG?(=\MWW'?M=T]_\G??6O9W]7</>`QX.'@D
M>"%X-W@]>$9X3WA+>&MX;WAP>'%X='AS>*IXKWBQ>+9XQ'C#>,9XZ7CK>`-Y
M"7D2>11Y&'DA>1UY'GDD>2!Y+'DN>3UY/GE">4EY17E0>4MY47E2>4QY57F7
M>9AYI7FM>:YYO'G?>=MYW7G8>=%Y[7GN>?%Y\GG[>?AY`7H/>@5ZXGD9>BMZ
M-WI%>D)Z0'I#>CYZ57I->EMZ5WI?>F)Z97ID>FEZ:WIJ>JUZL'J\>L!ZSWK1
M>M-ZU'K>>M]ZXGKC>N9Z[WKK>NYZ]'KQ>O=Z^WH&>QA[&GL?>R)[(WLE>R=[
M*'LI>RI[+GLO>S)[1'M#>T][37M.>U%[6'MT>Y-[@WN1>Y9[EWN?>Z![J'NT
M>\![RGNY>\9[SWO1>])[XWOB>^1[U'OA>SI\\GOQ>_![%7P4?`E\$WP,?`9\
M"'P2?`I\!'PN?!M\)7PD?"%\,'Q'?#)\1GP^?%I\8'QG?'9\>'SG?.Q\\'P)
M?0A]ZWP#?09]*GTF?:]](WT??41]%7T2?4%]/WT^?49]2'U=?5Y]9'U1?5!]
M67UR?8E]AWVK?6]]>GV:?:1]J7VR?<1]P7V[?;A]NGW&?<]]PGW9?=-]^'WF
M?>U][WW]?1I^&WX>?G5^>7Y]?H%^B'Z+?HQ^DGZ5?I%^G7ZE?JE^N'ZJ?JU^
M87?,?LY^SW[0?M1^W'[>?MU^X'[E?NA^[W[T?O9^]W[Y?OM^_'[]?@=_"'^W
M5A5_(7\L?SY_2G]2?U1_8W]??V!_87]F?V=_;']J?W=_<G]V?Y5_G'^@?R\X
MQTE9<&14W#&940``XCT4/A@^6#Y>/KX^*(#+/OD^`#\"/P<_'3\C/S0_-C\]
M/T`_13]4/U@_9#]G/WT_B3^</Z<_KS^U/[<_R3_>/^$_Z3\-0!1`&$`S0#5`
M1T`]@9U`GD#+0-1`U4#=0/A`'$$K03!!-T$^@8U!/X&\0;E!0($B0CY"0T)6
M0EI";T*%0L1"UD+\0@I#&$,Y0T-#94-\0^5#[4/U0Q!$%$0B1'E$441@1&U$
MSD2^1+]$Q$3*1-!$]T3[1")%*45!@6=%G45"@0!&"4851AY&.D8B1B1&*T8P
M1C%&,T;[1DA&3$;$IUE&6D9A1F5&<T9W1GA&C49#@:!&LD:[1L9&R$8B&]M&
MZ$;Z1A-'*8`S1V9'1T=(1WM'@4>31YA'FT>[1_E'P$?71_Q'`4A22!U(+$@Q
M2%M(<DAU2$2!HTBE2+)(R$C02.A([4CP2/%(_$@*24E)Q*HU24))5TEC261)
M:$F`212!I4FM2<])MAO#&^))Z4GJ2?5)]DD/2A5*/ZP[2CY*14I02E9*6TIK
M2G-*8ZR)2I1*G4J>2J5*Y$KG2@\<'8`;2QY++$LU2T9+5DM@2V5+9TMW2X)+
MJ4NM2W"`STO62]=+_TL%3!!,,TQ93%Q,JDQT3'9,A4R&3)A,G$S[3,9,U$S@
M3.M,[DS^KP1-#DTN33%-.4T_35A-94U%@8)-ATV)391-JDVL3;]-Q$W63=I-
MVTW=3?Q-1H$T3D1.7$Y>3JM.L4[!3L=.SDX03QI/1X$J3R]/,T]13UE/7D]A
M3V)/?D^(3XQ/C4^43Z!/IT^V3[Q/QT_*3_E/\$_U3P50!E`H4$I075!>4$Y0
M9%!U4(50I%"K4+=0U%#84.10#U$K41Y1(%$N43!11E%'45%12(%245Q18%%H
M416!A5&'49)1P5&Z4<11_E$`4A5255)64C\>C5*;4KY2P%+[4O&V)U,H4Q:!
M4%-F4WQ3E5.?4Z!3HE.F4ZM3R5//4]93V5/C4^E3!U0*5!I4&U1*@294*%0J
M5"M4+%0N5"]4,%1$5$941U1+5%=48E1K5&U4AE2'5(E4F%2<5)]4HU205*94
MJ%2I5+54OU3(5,E4VE3_5`%5%U4O56]5>56257(?SE7D50!6`E8(5A56%E89
M5AY6+58U5D-62U9D5F56;59O5G%6@5:;5IU6GE:F5JI6ME;%5LQ6SE;45N96
M\5;\5@I7&5<T5S971E=-5TY77%=?5V)7>E>`5Y17JE?@5RU8CL!#6$Y83UA1
M6&A8;EA+@;!8#L&M6.18\E@`6?=8'%DN63%9-%E,@4V!15E&64Z!3X%0@5Q9
M48$9@1J!>5E2@5.!&X&86;%9N%G(6<I9<<+46=Y9ZUGM60-:5($Y6EU:;5I5
M@85:H%K$P[-:NUK.6NM:_5H26RU;.UM'6TY;8%MM6V];<EN>6U:!UUO96P%<
M,5P>7"!<,UPV7&0BH<997&U<>5R/7)1<H%R\7-5<V5S=7`=="%T371U=(UTQ
M74%=2%U375Q=>EV#78M=H%VF7<)=S%W67>-=5X$H7@A>$5X57EF!1UY27F%>
MBEZ-7D=?6H&17Y=?OU_.7]M?WU_L7^Y?^E];@11@)F`U8#=@/&#*8-=@X&#S
M8!AA2F%@86=A:&%M8;MARF'/8==A7(%3)%LD8&)T8O_1CF*A8J-BI&*I8JYB
MMV*^8K]BQF+58OUB_F(`8P%C8F,B8RUC.F-#8T=C46-58WUCAF.28YACIV.I
M8[]CP&/'8\]CT6/A8^IC`60&9`ID7X%(9%]D<&1S9(5DGF2O9+1DNF3`9,)D
M0-,R91YE(V4O95EE9&4?@:UE>F6,98]EHF6P9<MESF7M91)F_V4$9@5F$&9T
MU1AF*68X9E=F6V8V@&)FG25L9G5FF&:X9OIF_&;]9@MG<6>'9XAGK&>M9[5G
MZB769^QG!F@*:!!H%&@?:)AHJFC*:,YHA-?U:!QI8($8:1EI&FDG:3!I,FDY
M:4!IE&EA@=1IY6GV:1)J%6HB:C=J1VI.:EUJ86IU:GEJIVK0:M]J]&KV:B*!
M8H%C@49K5&M9:VEKG6M);&AL9('A;/1L^&S^;&6!$FT;;:]MSFW1;==M(&XC
M;CUN<&Y[;G?@P&Y$*/IN'F\M;S9O5&]-X:9OM6_D;^AO[F\(<"UP9X&(<)5P
MEW"9<)MPHG"S<+YPQ'#%<,=PUW#=<-YP[W#T<":!%'$5<19Q(G$C<2=Q+W$Q
M<31Q/7%(<5MQ@W&><:QQL7&\<==Q^W'D<>5Q[7'Q<0=R$'(X<CER.G(\<D!R
M0W)/<GARB'+"<LMRS'+3<N!R_W($<Q]S(7,E<TAS27-*<V1S97-J<W!SFW.C
M<[ISQG/><]]S!'3]<S-T2G1C=&MT<71R=(YUGW6F=:EUK'6V=;UURW70==-U
ML"G:==YU6':$=MR`G7:D=J5VTG;>=FB!Z7;O=C-W.W=-=TYW3W=:=VYW<W>5
M=ZYWNG?!=\EWWG?;=_1W:8$*>!YX*W@P>&J!4GA3>%9X5WA9>%IXT(!E>&QX
MNGC(>.=X6'F>>0)Z`WHD>BUZ+GHX>DIZ3GI2>K9ZP7K#>LYZUGKY>@)["'L@
M>Q<L+7M>>WE[9GMR>W5[A'N*>X][GGNG>\%[SGOE>_A[_7L`?"-\07Q/?%!\
M4WQC?&5\=WP=?1Y]0WU'?5)]8WUP?7Q]BGV6?<!]K'V\?==]D/7G?0=^%7Y\
M?IY^I'ZL?J]^M'ZU?L-^T7X0?SE_5W^0?Y1_EW^B?P````````````")A`(N
M#RX2+BDN*RXN+D`N1RY(+J*$42X&%*2$6BYI+ITN+!0N%+DNNRXBA;PNPR[(
M+M`NZR[:+O$N]2X`+Q8O9"\W+SXO5"]8+Y.%=R]X+WHO?2^"+X4ODB^:+^8O
MLB^^+\4ORR_/+](O:A3R+P`P$#`3,!PP'C`B,&@40C!&,$XP4S!7,&,P9C!J
M,'`PHS"(,)(PDS"5,)8PG#"J,"N&L3"Z,+LPQ##',/,P@8;.,'&&U##9,.$P
MZ3"2%`@Q^887,1LQ2H=@,0F(<S&#,8LQO!28,:,QK3''%+PQUH@HB?,Q]#$"
M,A(R%C)/BE4R7#)L,G<RA#*",@>+F#(ZBZ0RIC*O,KHRNS+*,A\5T3*YB_<R
M"C,+,R0S-3,^,T(S?(R=C&<S;#-Z,Z0SM#-3C;<SP#.=C5T57A75,]HS8Q7T
M,_4S530D-"@T;A5#-&(T9C1L-(HTC325-*`TIC2M-*XTMS2Z-+\TPS1%CNPT
M[S3Q-/,T`#4!-0DU/#5!-:851S5*-:@58#5A-60UX8Y]-8(UB#61-<45TC65
MCVV/OS7)-<PUT37=-=H5XC5DC^DU*#9?D`<V$#8P-C<V]!4]-C\V0#9'-EXV
M8#9M-@46B#:,-I4VFC:=-J@VK3:R-L4VS3;?-N@V]C;W-@&1%3<C-U61*3=[
MD44W1C=,-TTW=)%H-V\W<S=T-W4W>S?DD=>1K#>:-YTWGC>H-]<W_9',-S:2
M1)+>-^8W\#=*%O@W^S?]-P0X'C@@."<X,C@Y.,2223A,.&<XBCB+.(TXCSB0
M.)0XG3BJ.+$X;9/#.,TXXCCS./0X!3D&.0LY#3D4.20YUY21%CTYF19&.986
M*=);.5\Y1Y5U.78Y?#F?.:XYO#G(.<TYWCGC.>0YYSGN.0:60I;/%@PZ#3H7
M.B<Z+3I5.F4Z>CJ+.IPZGSJ@.J(ZL3JS.K4ZNCJ_.MHZW#K@.N4Z\#KN.O4Z
M`#L(.Q<[-#LM.TP[4CMH.V\[?#M_.X$[A#O#F)8[K#MA%\`[8A?..]8[;!=K
M%_$[_3MU%P,\*3PP/%:97SQC/&<\:#QI/'`\+9I%FGP\>)IBFH@\BCS!%Z&:
MG)J@/*(\ICRG/)*:K3RU/+>:R3S@FC.;!CT0/2L]'3T@/20])CTQ/3D]0CWH
M%V$]:CWT%W`]'IS]%X@]`!B2/90]ESV9/;`]LCVT/7:<N3W1/=<]V#W@/?J<
MY#WI/2\8`#XV&!(^%3Y`&!\^+CX^/DD^7!A6/F$8:SYL/FT^;CY[G:4^JCZL
M/KD^OS[&/M(^V3X>G_T^"#\./QP_K9\>/T<_8S]R/WX_CS^B/Z0_N#_$/_H8
MQS_+/](_TS_4/^(_[C_O/_,__#\7&1=`(D`D0!H93$!_0(I`E4"H0/.@L$"Q
M0+Y`R$#90-M`[D#R0/5`$$$201-!&4$>03I!;QE!049!8$%\05NADD&309=!
MF$&E0:A!K4&KH=5!W4'?0?5!CZ(50B-"*4)&0DQ"44)20F%"9$)[0FU"<T*9
M0J9"U4*XH_U"`T,-0Q!#3Z10I#)#-4,[0SQ#04-$0TY#1J190QVEIJ1L0X1#
MF4,DI91#O4/W0]1#U4/<0^!#ZT/L0_)#"40>1"5$*40O1%I$6T1=1'-$?42'
M1)%$G42?1,M$S$351-=$X:;D1.5$_T0$16X:#T44119%<QH>13)%1$5416M%
M>D6!181%A46*1;)%M46X1;]%PD7)1=1%UAKR1?E%_$4$1@A&(48J1D5&449.
M1NH:PZ=71EM&8T;UI[:G:D9K1FQ&;49[1H!&D$:21IE&#ANM1K%&M48:&[]&
M'!OL1M<:`4<%1Q)'<J@91].HTJA,1TU'5$==1]"HY*C5J'1'=D?:J))'WZAC
M8Q!(L$>R1\-'R$?21]E'VT?P1_='2JE1J4NI&$@?2"U(9:DS2#M(/DA$2$5(
M24A,2%5(5TAW&VM(;DAZ2'Q(@DB02)9(;1N82)E(FDB<2*I(JTBT2+M(^TCD
MJ5JJ$X'#2,5(S$C/2-9(V4CD2.5([$CW2`-)!TF'&X@;E*H[28T;1DEI26Q)
M<DEZ27])DDFD&Y9)F$FF2;!)MTFZ2;Q)P$G12=9).:M'JS!*.*LZJ^-)[DGO
M2?-)S1OT2?Y)$4H:2AU*'*PR2C-*-$H_2D9*24IZ2DY*4DID2@RL?DJ#2HM*
M\!N12I]*H4IDK*M*O4K&2M1*T$K<2MU*_ZSGK.Q*\4KR2O-*_4HDK0M+#TL0
M2Q%+/:T72R8<+TM*2UA+;$MU2WI+@4N;2ZY+F*Z]2[Y+QTO(2\E+VDOF2^=+
M[DOQ2P),"DP.3#5,-DPZ3'^O/TQ-3%M,;4R$3(E,PQR43)5,ETRM3,),T$S2
M'-9,VDS<3.E,[$SM3`"P`$T*321-)DTG36=,+TT\35M-7DU@37!-@$V!38I-
MC4V139A-0+`73OJP^;#3L*M-KDVT3<)--$W(3<Y-STW03=]-Z4WV339.'DXB
M3B=.$1TR3CQ.2$Y)3DM.3$Y/3E%.4TY43E=.8TX>'9-.ITZT3K].PT[*3ME.
M-4_K3OE.^TX*3PQ/&$\E3S9//$]^L5)/5T]:3V!/:$^83WU/D$^63[Y/GT^E
M3Z]/9!VU3\A/R4_:3]Y/Z4^6LOQ/`%`'4`I0(U`#LSE0.E`\4$-01U!+4)H=
M5%!E4&E0;%!N4'90?E"!4(90E5"74+M0QK.?4+%0_K/L4,I0T5#34-Q0`U$$
M4091!U$(40Q1P!TO43%14%%*45-17E'4'991@%&;4:!1HE&N4:]1LU&\M,M1
MTU'94=Q1!U(%'DF!*U(T4CA2.5(L+D)24U)74F-2*;5N4F]2>%)_4HY2I;6M
M4JY2L%*Q4L%28![,4F8>:![S4OI2!U,24QA3&5.#'CE3+%,Q4S-3/5-24Y0>
M:U-L4Y:W;E-O4W%3=U.!4X53BE.44YA3G%.>4Z53J%.U4[=3N5.\4[]3Q5/+
M4^%3YU/Y4Q-4^E,!5"14,50Y5%-40%1#5$U44E1=5'%4@52%5(A43;B25)=4
MF52@5*%4I52J5*M4N52[5+I4UE385-Y4[U3K5%:Y^E1ON2!5)%4J55<?%KH]
M53Y50%5(54Y54%5256Q5<E5Q57I5?55^58%5%+N,574?HE5W'[!5MU6_5<!5
MQE7/5=-5W57?5>!5YU7L5>Y5\57Y50-6&%8'5@]6KA\.O!-6&U8<5C>\)58H
M5CQ6,U9JO,D?05:+O$E655;7'VY6E5:<5J%6H%:G5JA6KU9*O<E65;WH5NQ6
M(KX75QI7+5<U5ZF^.2#EOLV^6%=@5VI7'K]R5WQ7?5=,OU@@FE>?5Z)7I%>I
M5]Y7WU?D5^97ZE?L5Y,@\%?T5_M7+L`%6`98"5@-6!E8(5@L6$=89%AJ6-G`
MBEB46*18G5B>6)]8NUC(6,Q8SEC56.!8X5CF6/E8^EC[6/Y8I\$061M9,%DE
M63M92EE865M9!2%G67)9E%F56999FUFA6:E9M%F[6<)9QUG,6<U9UEE((:G"
MM,)/(0I:$5H56AM:'EIC(2U:.%I'6DQ:5EI96EQ:7UI@6F=::EIU6GA:@EJ*
M6I!:HUJL6M3#M"&Y6KQ:OEJ_(<Q:T5KG6NA:]%KDQ./$!UOQQ#U;)ULJ6RY;
M+ULQ6^8A\R%_6T%;[B%56WE;9%MF6VE;<ULRQ0<BD%N16YM;#B*O6[5;O%O%
M6\I;R\7DQ=1;UEO:6^I;\%L#7`M<#EP/7"9<15Q*7%%<5UQ>7&%<:5QN7&]<
M<%PNQU;'9<>F7&+'MERW7+]<V,?$7,+'R%S-7.C'UUPCR.9<ZUQ<R/5<`UT)
M7<8B$ET>7>#(U,@]73Y=0%U'70S)^\C6(EE=6EUJ77!=W2)_71?)AEV(78Q=
MEUU@R9U=IUVJ7;9=MUW`7===V5WF7?%=^5T"(^W)6($07A=>'5X@7B=>+%Y%
M7G->=5Y^7H9>AUXK(Y%>F%Z:7D,C/%\[7SY?0U]$7T]?P11PRE)?ALIA7V-?
M9%]M7WU??E],RY!?>S$.L)9?G%^M7P+,PU_/7^-?Y5_O7_)?`F`*8`A@#F`1
M8!9@)&`L8#!@0V!F8'%@=6![8)E@G&"D8*=@N&!^S<5@U6#88.9@L,T-8?5@
M^V#N(S5A%F$>8?`C)&$G82QA'<X]80@D:6$7)(%A'"2$885A(B288;)AP6'#
M8=9AVV'=S^1AZL_L85'0_6'_86_0!&+=T!EB(6(B8A[1,F(T8CQB1F))8D5B
M6-%+8G8D3V)Z)%=BC-%<8F-BM]%=@5Z!>6*1)'UB?V*#8HIBDV*G8JABLF*T
M8KIBO&+B8NAB]V('8PAC#&-48QMC'6,P8SQC1&-78[XD?V/4)+,DC6.48Y5C
MFV.=8\ECT&/48]UCY6/Y8P]D$6059'/2%V0Y9$ID3V119%)D661:9%QDW=)E
M9'9D>&1\9(%D#27<9)=DIF2^9`@ESF3/9--D9=/G9.ID[V3P9/%D^F3]9`QE
M&V4D925E*V4T94]E;V4E)4,E/F5195-E7F5A96)EE-1[97UE?V6!989EDV6=
M99]E^-3VU/?4MV6\9<=ERF789=EEWV7A9>9E]F4`9A%F'F8A9B1F)V:-U3EF
M/&:YU4!F((%39E9F;V9W9GIFAV:)9HUFD6:<9IUFJ&8A@;%FLV;!9L-FT6;5
M9M=FXV;F9K@E!6<'9PYG$&<39QEG'V<A9R-G,6<Z9SYG0&=#9U%G6&=D9V5G
M<F=\9UO66M:G9XEGBV>39Z!G?M;E);YGD-;!9\YG]6??9\G6XV?E9^9GZF?K
M9^UG`6@#:`MH$V@H:"YH,F@\:`\F2FA8:%]H9&@5UQ37:6@QUV]HH&B\:+UH
MOFC`:-)HD]?1:--HVVCP:/%H028!:0[8-VDCV$)I16E):5+8929B:8!IB6F0
M:9]IL&FW:=9IV&GK::$F\6GS:?UI_VFO)A%J%&J%V2%J-6H^:D5J36I8:JYJ
MD&JW:KYJUVK\:H3:"FL%:PUK'&L?:RUK0VL,)U%K7FMV:W]K@6N+:Y1KE6N<
M:YYK.6RSVSULOMO'VT5L1VQ/;%1L5VQI;&UL<VRXW)-LDFR9;&0GFVRD;-9L
MU6S9;"#=\&SQ;)#="6T.;6QMA&V5;:9MM][&;<AMV6WL;0QN_2?];09NBM\4
M;A9N(6XB;B=NN]\6*#9N.6Y+;E1N8FYL;FUN;VZ8;IYNKFZS;K5NMFZ[;H+@
MT6[4;DXH^6[SX`!O"&\7;RMO0&]*;UAOC.&D;[1O9H&V;]7AP6_&;R2!RF_-
M;]-OU6_@;_%O]6_[;P)P#'`W<&OB0W!$<%UPR.+)XH5PC'"0<!UVH7"U*+!P
MMG##<,APU^/<<-]P^N/V</)P`''K</YP_W`$<09Q&'$<<1YQ-W$Y<3IQ1G%'
M<5=Q67%A<61Q='%Y<85QCG&H<:YQLW&V<<-QQ'':<4GD1N3L<>YQ`7(*<A9R
M%W)KY#-R0G)'<DIR3G)1<E9R67)@<F%R97)G<FARA^2(Y'QR?7)_<HERC7*7
M<IERGW*G<JMRNN2[Y+)ROW+`<L9RSG+0<M=RV7+E<N=R$7,>Y2GE]W+Y<OMR
M`G,-<Q5S'7,><R=S*7-QY4/E1W-1<U=S6G-K<W%S<W.A<YGES>6(<XMSCW.>
M<_5SY.7=Y?%SP7/'<]QSXG/G<PET#W06=!=T^W,R=#1T.W1%=,'F[^9M=&]T
M>'5Y=89UC'6-=1#GJW6T=7'GR'7[YQ_H+'8S=C1V-N@\=D%V87:)Z()VZ^B:
M=C+IYRFI=J]VLW:Z=KUV^BGXZ=AVVG;==@0J%'<C=RDJ-G=!=T=W57=7=UMW
M:G>@ZK'JEG>:=YYWHG>Q=[)WOG?,=]%WU'?8=]EWX7?Q=P1X#7@.>!1X%GB\
M*I#K(W@R>#-X)7A'>&9XJWBM>+!XS^RW>+AXNWB\>+]XPGC'>,MXX'A_[>%X
MXWCE>.IX\'CQ>/-X"'D[*_#M%GD7>1GN&GD;>1QY4.XQ>3)Y,WDZ>3MY/'E`
M>4%Y1GE->4YY7'E?>6!YHWFF>;EYO7F_><-YR7G4>=EYWGG&[_!Y^7G\>0IZ
M$7H6>AIZ('HQ>C9Z1'I,>EAZPBNO>LHKMWK2*[EZ<O#&>M!ZTGK5>N@KW'K@
M>N5ZZ7H#>PQ[$'L2>Q9[''LK>S-[/7L@+$M[8WME>VM[;'MS>W9[=WNF>ZQ[
ML7O;\3WRLGNX>[Y[QWOS>]A[W7OG>^I[ZWOO>^Y[%?+Z>XKR]WM)\A9\&'P9
M?!I\'7PB?"=\*7PJ?,3R,7PV?#=\17Q<?.GR27Q*?-OR5'Q8?%M\77Q??&E\
M:GQK?&U\;GQP?')\=7QZ?.9\\GP+?0)]SO,1?1=]&'TO],0L&O0R?=$L0GU*
M?5]]8GWY]&E]:WV"]'-]=GUW?7Y]A'V-?9E]H7V_?;5]N7V]?<-]QWW)?=9]
MVGW??>!]XWWT?0<M"GX"?@U^&7X<?AU^>WX8GH!^A7Z;?JA^#/:]?K?VWW[G
M?NY^_WX"?W<M`W\7?QE_+W\W?SI_/7]!?T5_1G]3?U5_6'_Q]UU_`OAI?QKX
M;7]P?W5_LO@`````````````````````A(:%AH"&AH9[A6.&5X9GAE:&:89/
MAFN&8H9MAE>&:(96AFJ&3X9LAF*&;H:I@O6"JX+V@JV"]X*O@OB"L8+Y@DJ#
MEX-,@YB#3H.9@U"#FH-2@YN#6H.<@V.#G8-G@YZ#\X/V@P``````````````
M``````````````````````#DJ^6KX*OFJ]RIQ*NXJ\BKMZO*J["KS*O#J\ZK
MN*O)J[>KRZNPJ\VKPZO/JZND]Z2MI/BDKZ3YI+&D^J2SI/NDJZ7WI:VE^*6O
MI?FEL:7ZI;.E^Z6[I?REQ*7]I<BE_J7UIOBF````````````````````````
M`````````````,0`LP```````````-H```"_````P````-D```##````````
M`+0`````````P@````````#!`````````,4`````````````````````````
MS;K5ULFXM[O4T\B^O;S&Q\RUMKG1TLO/T,K8U\X`````````````````````
M````WP```-P```#;````W0```-ZPL;(```````````````#^````````````
M``````````````````````````````#P``#T`/;X``````````"`@8*#A(6&
MAXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ_@X>+C
MY.7FY^CIZNOL[>[O`/$``/4`]_D`````````````````````````````````
M`````````````````````````````````````````/+S````````_P```/T`
M``````````````````````#Z`````````````````````)$EDB63)0(E)"5A
M)6(E5B55)6,E4257)5TE7"5;)1`E%"4T)2PE'"4`)3PE7B5?)5HE5"5I)68E
M8"50)6PE9R5H)60E9259)5@E4B53)6LE:B48)0PEB"6$)8PED"6`)4`$001"
M!$,$1`1%!$8$1P1(!$D$2@1+!$P$301.!$\$`011!)`$D00$!%0$!@16!`<$
M5P2W`!HB%B&D`*`EH`#$`+,```````````#:````OP```,````#9````PP``
M``````"T`````````,(`````````P0````````#%````````````````````
M`````,VZ``#)``"[``#(``"\``#,``"Y``#+``#*``#.````````````````
M`````````-\```#<````VP``````````L+&R````````````````_@``````
M`````````(X``(N,````````````````````````[_>&`(V/D`"2`)68H:2E
MIJ>HJ:JLK;6VM[B]OL;'`,_0T=+3U-61EIN=GI_\UM?8W=[@X>+CY.7FY^CI
MZNOM[.[R\_3V^J#[HJ/]``````````````````````#_``"<``"*]?F7`*Z)
M\```^/&9F@```(@```"O`*L``/W__?_]__W__?_]_X8#_?^W`*P`I@`8(!D@
MB`,5((D#B@.J`XP#_?_]_XX#JP.I`(\#L@"S`*P#HP"M`ZX#KP/*`Y`#S`/-
M`Y$#D@.3`Y0#E0.6`Y<#O0"8`YD#JP"[`)$EDB63)0(E)"6:`YL#G`.=`V,E
M4257)5TEG@.?`Q`E%"4T)2PE'"4`)3PEH`.A`UHE5"5I)68E8"50)6PEHP.D
M`Z4#I@.G`Z@#J0.Q`[(#LP,8)0PEB"6$);0#M0.`);8#MP.X`[D#N@.[`[P#
MO0.^`[\#P`/!`\,#P@/$`X0#K0"Q`,4#Q@/'`Z<`R`.%`[``J`#)`\L#L`/.
M`Z`EH`#$`+,```````````#:````OP```,````#9````PP````````"T````
M`````,(`````````P0````````#%`````````````````````````,VZU=;)
MN+>[U-/(OKV\QL?,M;:YT=++S]#*V-?.`````````````````````````-\`
M``#<````VP```-T```#>L+&R````````````````_@````````"I````````
M````````````]/4`````````^?L```#L`````````````.\`````````````
M``````````````````````````#W````````````````````````````````
M\```\_(```````````````````````````#B`````.D`````````````Y```
MZ```Z@````````#@``#K[@````````````#C``#EYP#M````````````_ZT`
MG*\``````*:NJ@```/CQ_0``Y@#Z``"G`*RK`*@`````CH^2@`"0````````
M`*4`````F0"=````F@``X86@@P"$AI&'BH*(B8VAC(L`I)6BDP"4]IN7HY:!
M``"8QP#\`.D`X@#D`.``Y0#G`.H`ZP#H`.\`[@#L`,0`Q0#)`.8`Q@#T`/8`
M\@#[`/D`_P#6`-P`^`"C`-@`IR"2`>$`[0#S`/H`\0#1`*H`N@"_`!`CK`"]
M`+P`H0"K`*0`D262)9,E`B4D)6$E8B56)54E8R51)5<E725<)5LE$"44)30E
M+"4<)0`E/"5>)5\E6B54)6DE9B5@)5`E;"5G)6@E9"5E)5DE6"52)5,E:R5J
M)1@E#"6()80EC"60)8`EL0/?`),#P`.C`\,#M0#$`Z8#F`.I`[0#'B+&`[4#
M*2)A(K$`92)D(B`C(2/W`$@BL``9(K<`&B)_(+(`H"6@````````\```P<*B
MPZ7$``````#&`,>HJ0#(`,D`J@#*`*L`RP"M`,P`K@#-`*\`S@#/`-``T0#2
M`+P`TP"]`-0`O@#5`.L`U@#7````V````-_%V>SN[=KWN@#A`/@`X@#\`.,`
M^P#D`.\`Y0#R`.8`\P#G].@`Z?7]]NH`^?J9F@``G9X`````````````````
M``````````````````"%`(8```````````"-````C````(X```"/````B@``
M``````"(`````````(D`````````BP````````"'`````(*#````D0``````
M````````````````````````````````````````````````E@``````````
M``````````````"L``````````````````"[````OP``````````````````
M````````````````````````X`````````````````````#Q````````````
M``````"PL;*SM+6VM[BY)0``````````````````````````````````````
MH`#`HZ0`VP````"7W*$``("3``````"!````F)64````````````````````
M`````````````-X`````````````````````````````````````````W2`A
M(B,D`"8GL`"W`!DB&B*2)0`E`B4\)20E+"4<)30E$"4,)10E&"6R`QXBQ@.Q
M`+T`O`!((JL`NP#W_OC^_?_]__O^_/[]_Z``K0""_J,`I`"$_OW__?^._H_^
ME?Z9_@P&G?ZA_J7^8`9A!F(&8P9D!F4&9@9G!F@&:0;1_AL&L?ZU_KG^'P:B
M`(#^@?Z#_H7^ROZ+_HW^D?Z3_I?^F_Z?_J/^I_ZI_JO^K?ZO_K/^M_Z[_K_^
MP?[%_LO^S_ZF`*P`]P#7`,G^0`;3_M?^V_[?_N/^Y_[K_NW^[_[S_KW^S/[.
M_LW^X?Y]_E$&Y?[I_NS^\/[R_M#^U?[U_O;^W?[9_O'^H"7]_R``(0`B`",`
M)`!J!B8`)P`H`"D`*@`K`"P`+0`N`"\`Q`"S````````````V@```+\```#`
M````V0```,,`````````M`````````#"`````````,$`````````Q0``````
M``````````````````#-NM76R;BWN]33R+Z]O,;'S+6VN='2R\_0RMC7S@``
M``````````````````````#?````W````-L```#=````WK"QL@``````````
M`````/X`````````J0```````````````````/3U`````````/G[````[```
M``````````#O````````````````````````````````````````]P``````
M`````````````````````````/```//R````````````````````````````
MX@````#I`````````````.0``.@``.H`````````X```Z^X`````````````
MXP``Y><`[0```````````/\`FYR8`*"/I```KJH``*?X\?VFH>:&^J4``*^L
MJZT`C@"$`````("1D)*4``"HE0````"9`````)T`GIH``.&%`(,`````AXJ"
MB(D``(R+````HI,``/8`EZ.6@0```,<`_`#I`.(`P@#@`+8`YP#J`.L`Z`#O
M`.X`%R#``*<`R0#(`,H`]`#+`,\`^P#Y`*0`U`#<`*(`HP#9`-L`D@&F`+0`
M\P#Z`*@`N`"S`*\`S@`0(ZP`O0"\`+X`JP"[`)$EDB63)0(E)"5A)6(E5B55
M)6,E4257)5TE7"5;)1`E%"4T)2PE'"4`)3PE7B5?)5HE5"5I)68E8"50)6PE
M9R5H)60E9259)5@E4B53)6LE:B48)0PEB"6$)8PED"6`);$#WP"3`\`#HP/#
M`[4`Q`.F`Y@#J0.T`QXBQ@.U`RDB82*Q`&4B9"(@(R$C]P!((K``&2*W`!HB
M?R"R`*`EH`#$`+,```````````#:````OP```,````#9````PP````````"T
M`````````,(`````````P0````````#%`````````````````````````,VZ
MU=;)N+>[U-/(OKV\QL?,M;:YT=++S]#*V-?.````````````````````````
M`-\```#<````VP```-T```#>L+&R````````````````_@````````"I````
M````````````````]/4`````````^?L```#L`````````````.\`````````
M``````````````````````````````#W````````````````````````````
M````\```\_(```````````````````````````#B`````.D`````````````
MY```Z```Z@````````#@``#K[@````````````#C``#EYP#M````````````
M_ZT`G`````````"NJ@```/CQ_0``Y@#Z````KZRK`*@`I```CH^2@`"0````
MI0``BP``I@``F0"=`*<`FI>-X86@@P"$AI&'BH*(B0"A``",``"BDP"4]IL`
MHY:!F)4`QP#\`.D`X@#D`.``Y0#G`.H`ZP#H`-``\`#>`,0`Q0#)`.8`Q@#T
M`/8`_@#[`-T`_0#6`-P`^`"C`-@`IR"2`>$`[0#S`/H`P0#-`-,`V@"_`!`C
MK`"]`+P`H0"K`+L`D262)9,E`B4D)6$E8B56)54E8R51)5<E725<)5LE$"44
M)30E+"4<)0`E/"5>)5\E6B54)6DE9B5@)5`E;"5G)6@E9"5E)5DE6"52)5,E
M:R5J)1@E#"6()80EC"60)8`EL0/?`),#P`.C`\,#M0#$`Z8#F`.I`[0#'B+&
M`[4#*2)A(K$`92)D(B`C(2/W`$@BL``9(K<`&B)_(+(`H"6@`,0`LP``````
M`````-H```"_````P````-D```##`````````+0`````````P@````````#!
M`````````,4`````````````````````````S;K5ULFXM[O4T\B^O;S&Q\RU
MMKG1TLO/T,K8U\X`````````````````````````WP```-P```#;````W0``
M`-ZPL;(```````````````#^````````````````````````````````````
M``````#Y^P```.P`````````````[P``````````````````````````````
M`````````/<```````````````````````````````#P``#S\@``````````
M`````````````````.(`````Z0````````````#D``#H``#J`````````.``
M`.ON`````````````.,``.7G`.T```````````#_K9N<````````IJZJ````
M^/']``#F`/H``*>OK*L`J)&&CXX```"`DI")`)B+````I:F?C)D```"=E@":
M``#AA:"#A````(>*@H@`C:$```"DE:*3E`#V`)>C`($```#'`/P`Z0#B`.,`
MX`#!`.<`Z@#*`.@`S0#4`.P`PP#"`,D`P`#(`/0`]0#R`-H`^0#,`-4`W`"B
M`*,`V0"G(-,`X0#M`/,`^@#Q`-$`J@"Z`+\`T@"L`+T`O`"A`*L`NP"1)9(E
MDR4")20E825B)58E525C)5$E5R5=)5PE6R40)10E-"4L)1PE`"4\)5XE7R5:
M)50E:25F)6`E4"5L)6<E:"5D)64E6258)5(E4R5K)6HE&"4,)8@EA"6,)9`E
M@"6Q`]\`DP/``Z,#PP.U`,0#I@.8`ZD#M`,>(L8#M0,I(F$BL0!E(F0B(",A
M(_<`2"*P`!DBMP`:(G\@L@"@):``Q`"S````````````V@```+\```#`````
MV0```,,`````````M`````````#"`````````,$`````````Q0``````````
M``````````````#-N@``R0``NP``R```O```S```N0``RP``R@``S@``````
M``````````````````#?````W````-L``````````+"QL@``````````````
M`/X`````````````````````````````````````````_ZV]G,^^W?7YN*:N
MJO"I[OCQ_?SOYO3Z]_NGKZRK\ZBWM;;'CH^2@-20TM/>UM?8T:7CX.+EF9Z=
MZ^GJFNWHX86@@\:$AI&'BH*(B8VAC(O0I)6BD^24]IN7HY:![.>8QP#\`.D`
MX@#D`.``Y0#G`.H`ZP#H`.\`[@#L`,0`Q0#)`.8`Q@#T`/8`\@#[`/D`_P#6
M`-P`^`"C`-@`UP"2`>$`[0#S`/H`\0#1`*H`N@"_`*X`K`"]`+P`H0"K`+L`
MD262)9,E`B4D)<$`P@#``*D`8R51)5<E726B`*4`$"44)30E+"4<)0`E/"7C
M`,,`6B54)6DE9B5@)5`E;"6D`/``T`#*`,L`R``Q`<T`S@#/`!@E#"6()80E
MI@#,`(`ETP#?`-0`T@#U`-4`M0#^`-X`V@#;`-D`_0#=`*\`M`"M`+$`%R"^
M`+8`IP#W`+@`L`"H`+<`N0"S`+(`H"6@`,0`LP```````````-H```"_````
MP````-D```##`````````+0`````````P@````````#!`````````,4`````
M````````````````````S;H``,D``+L``,@``+P``,P``+D``,L``,H``,X`
M````````````````````````WP```-P```#;``````````"PL;(`````````
M``````#^`````````````````````````````````````````````````*:G
M`````````````````````)B-````````````````````````````````````
M``````````````````````">GP```````````````````````````````/^M
MO9S/OMWU^;C1KJKPJ>[X\?W\[^;T^O?[T*^LJ_.HM[6VQXZ/DH#4D-+3WM;7
MV`"EX^#BY9GHG>OIZIH``.&%H(/&A(:1AXJ"B(GLH8R+`*25HI/DE/:;EZ.6
M@0``[<<`_`#I`.(`Y`#@`.4`YP#J`.L`Z`#O`.X`,0'$`,4`R0#F`,8`]`#V
M`/(`^P#Y`#`!U@#<`/@`HP#8`%X!7P'A`.T`\P#Z`/$`T0`>`1\!OP"N`*P`
MO0"\`*$`JP"[`)$EDB63)0(E)"7!`,(`P`"I`&,E4257)5TEH@"E`!`E%"4T
M)2PE'"4`)3PEXP##`%HE5"5I)68E8"50)6PEI`"Z`*H`R@#+`,@`_?_-`,X`
MSP`8)0PEB"6$):8`S`"`)=,`WP#4`-(`]0#5`+4`_?_7`-H`VP#9`.P`_P"O
M`+0`K0"Q`/W_O@"V`*<`]P"X`+``J`"W`+D`LP"R`*`EH`#$`+,`````````
M``#:````OP```,````#9````PP````````"T`````````,(`````````P0``
M``````#%`````````````````````````,VZ``#)``"[``#(``"\``#,``"Y
M``#+``#*``#.`````````````````````````-\```#<````VP``````````
ML+&R````````````````_@``````````````````````````````````````
M````A8&#AXF+C8^1DY67`)F;H:/LK:>IZO2XOL?1T]77W>+DYNBKMJ7\]OJ?
M\N[XG>"@HNNLIJCI\[>]QM#2U-;8X>/EYZJUI/OU^9[Q[?><W@"$@(*&B(J,
MCI"2E)8`F)K_````SP``_0```*X`\`````````````````"O`````%($`@13
M!`,$400!!%0$!`15!`4$5@0&!%<$!P18!`@$600)!%H$"@1;!`L$7`0,!%X$
M#@1?!`\$3@0N!$H$*@0P!!`$,001!$8$)@0T!!0$-005!$0$)`0S!!,$JP"[
M`)$EDB63)0(E)"5%!"4$.`08!&,E4257)5TE.009!!`E%"4T)2PE'"4`)3PE
M.@0:!%HE5"5I)68E8"50)6PEI``[!!L$/`0<!#T$'00^!!X$/P08)0PEB"6$
M)1\$3P2`)2\$0`0@!$$$(01"!"($0P0C!#8$%@0R!!($3`0L!!8AK0!+!"L$
M-P07!$@$*`1-!"T$200I!$<$)P2G`*`EH`#$`+,```````````#:````OP``
M`,````#9````PP````````"T`````````,(`````````P0````````#%````
M`````````````````````,VZ``#)``"[``#(``"\``#,``"Y``#+``#*``#.
M`````````````````````````-\```#<````VP``````````L+&R````````
M````````_@````````#T^@````````````````````````````"/AI*1````
M`````````````````)V;IJ?DY0``J*GGZ```````````F-4``*R?````````
M`````````````````/,```````````````````````#&Q[BM````````````
M````[.T`````````````````O;X``````````````/\``)S/``#U^0``K@#P
M``#X`/W\[^8``/<``*\`JP``M[6V`(X``(#4D-+3WM;7V`"EX^#B`)F>`.OI
MZIH``.&%H(,`A```AXJ"B(F-H8R+`*25HI,`E/8`EZ.6@0```,<`_`#I`.(`
MY`#@``D!YP#J`.L`Z`#O`.X`[`#$``@!R0`+`0H!]`#V`/(`^P#Y`#`!U@#<
M`!T!HP`<`=<`-0'A`.T`\P#Z`/$`T0`>`1\!)`$E`?W_O0`T`5\!JP"[`)$E
MDB63)0(E)"7!`,(`P`!>`6,E4257)5TE>P%\`1`E%"4T)2PE'"4`)3PE7`%=
M`5HE5"5I)68E8"50)6PEI`#]__W_R@#+`,@`,0'-`,X`SP`8)0PEB"6$)?W_
MS`"`)=,`WP#4`-(`(`$A`;4`)@$G`=H`VP#9`&P!;0']_[0`K0#]_Q,A20'8
M`J<`]P"X`+``J`#9`OW_LP"R`*`EH`#$`+,```````````#:````OP```,``
M``#9````PP````````"T`````````,(`````````P0````````#%````````
M`````````````````,VZ``#)``"[``#(``"\``#,``"Y``#+``#*``#.````
M`````````````````````-\```#<````VP``````````L+&R````````````
M````_@``````````````````````````````````````````````````\P``
M``````````````````#T^@#R`/$``/\```#/``#U^0``KJKP``#X````[P``
M`/<``*\``````+6V`(X``(``D`#3`-;7`````.#B`)F>``#I`)KM`.$`H(,`
MA```AP""`(D`H8P`````HI,`E/8``*,`@>P`````QL>DI8^&`````*R?TM31
MT````````*BIM]@``````````````````````````````````````)&2``"5
ME@``G8CCY```U>4`````````BHL``.CJ``#\_9>8``"XK>;GW>Z;G```````
M````WH7K^P````````"-J[V^IJ<`QP#\`.D`X@#D`&\!!P'G`$(!ZP!0`5$!
M[@!Y`<0`!@')`#D!.@'T`/8`/0$^`5H!6P'6`-P`9`%E`4$!UP`-`>$`[0#S
M`/H`!`$%`7T!?@$8`1D!K`!Z`0P!7P&K`+L`D262)9,E`B4D)<$`P@`:`5X!
M8R51)5<E725[`7P!$"44)30E+"4<)0`E/"4"`0,!6B54)6DE9B5@)5`E;"6D
M`!$!$`$.`<L`#P%'`<T`S@`;`1@E#"6()80E8@%N`8`ETP#?`-0`0P%$`4@!
M8`%A`50!V@!5`7`!_0#=`&,!M`"M`-T"VP+'`M@"IP#W`+@`L`"H`-D"<0%8
M`5D!H"6@`,0`LP```````````-H```"_````P````-D```##`````````+0`
M````````P@````````#!`````````,4`````````````````````````S;H`
M`,D``+L``,@``+P``,P``+D``,L``,H``,X`````````````````````````
MWP```-P```#;````W0```-ZPL;(```````````````#^``````````#O``#R
MIO<``````````````````````/\`EIR?`*?U`*@`KJKPJ0#X\?W\`.;T^@#[
M`*^LJ_,``````(Z/D@``D````````````.``Y9F>G0```)H``.$`````A(:1
M``""````````````H@#DE/:;````@0```*"#``"UT("'`````+;1`````.V)
M``"XT[?2``````````"5A0```````*&,``"]U````````.CI````ZNL`````
MK8CCY^[L``````#BDP``````````BHL``)>8`````+[5``````````#'UP``
M`````,;6``````"-I:.DS]@`!@'\`.D``0'D`",!Y0`'`4(!$P%6`5<!*P%Y
M`<0`Q0#)`.8`Q@!-`?8`(@&B`%H!6P'6`-P`^`"C`-@`UP"D```!*@'S`'L!
M?`%Z`1T@I@"I`*X`K`"]`+P`00&K`+L`D262)9,E`B4D)00!#`$8`18!8R51
M)5<E724N`6`!$"44)30E+"4<)0`E/"5R`6H!6B54)6DE9B5@)5`E;"5]`04!
M#0$9`1<!+P%A`7,!:P%^`1@E#"6()80EC"60)8`ETP#?`$P!0P'U`-4`M0!$
M`38!-P$[`3P!1@$2`44!&2"M`+$`'""^`+8`IP#W`!X@L``9(K<`N0"S`+(`
MH"6@`,0`LP```````````-H```"_````P````-D```##`````````+0`````
M````P@````````#!`````````,4`````````````````````````S;K5ULFX
MM[O4T\B^O;S&Q\RUMKG1TLO/T,K8U\X`````````````````````````WP``
M`-P```#;````W0```-ZPL;(```````````````#^````````````````````
M``````````````````````#Y^P``````````````````````````````````
M`````````````````````````/<`````````````````````````````````
M``#S\@```````````````````````````````.H`Z^SM`.X`[_``@(&"@X2%
MAH>(B8J+C(V.CY``D9*3E)66E_3UX>+CY0"8F9J;G)V>GZ"AHJ.DI::GJ*JI
MJZRMKJ_@Y.CFY^D`_P```````````````````/CQ_0````#Z````````````
M````````````````````D0.2`Y,#E`.5`Y8#EP.8`YD#F@.;`YP#G0.>`Y\#
MH`.A`Z,#I`.E`Z8#IP.H`ZD#L0.R`[,#M`.U`[8#MP.X`[D#N@.[`[P#O0.^
M`[\#P`/!`\,#P@/$`\4#Q@/'`\@#D262)9,E`B4D)6$E8B56)54E8R51)5<E
M725<)5LE$"44)30E+"4<)0`E/"5>)5\E6B54)6DE9B5@)5`E;"5G)6@E9"5E
M)5DE6"52)5,E:R5J)1@E#"6()80EC"60)8`ER0.L`ZT#K@/*`Z\#S`/-`\L#
MS@.&`X@#B0.*`XP#C@./`[$`92)D(JH#JP/W`$@BL``9(K<`&B)_(+(`H"6@
M`,0`LP```````````-H```"_````P````-D```##`````````+0`````````
MP@````````#!`````````,4`````````````````````````S;K5ULFXM[O4
MT\B^O;S&Q\RUMKG1TLO/T,K8U\X`````````````````````````WP```-P`
M``#;````W0```-ZPL;(```````````````#^`````````*D`````````````
M``````#T]0````````#Y^P```.P`````````````[P``````````````````
M`````````````````````/<```````````````````````````````#P``#S
M\@```````````````````````````.(`````Z0````````````#D``#H``#J
M`````````.```.ON`````````````.,``.7G`.T```````````#_K9N<`)T`
M````IJZJ````^/']``#F`/H``*>OK*L`J`````".CY*``)``````````I0``
M``"9``````":``#AA:"#`(2&D8>*@HB)C:&,BP"DE:*3`)3V`)>CEH$``)C'
M`/P`Z0#B`.0`X`#E`.<`Z@#K`.@`[P#N`.P`Q`#%`,D`Y@#&`/0`]@#R`/L`
M^0#_`-8`W`"B`*,`I0"G()(!X0#M`/,`^@#Q`-$`J@"Z`+\`$".L`+T`O`"A
M`*L`NP"1)9(EDR4")20E825B)58E525C)5$E5R5=)5PE6R40)10E-"4L)1PE
M`"4\)5XE7R5:)50E:25F)6`E4"5L)6<E:"5D)64E6258)5(E4R5K)6HE&"4,
M)8@EA"6,)9`E@"6Q`]\`DP/``Z,#PP.U`,0#I@.8`ZD#M`,>(L8#M0,I(F$B
ML0!E(F0B(",A(_<`2"*P`!DBMP`:(G\@L@"@):```2%P`2)X`2(T`2$Q`2(R
M`2(S`25O`25M`25N`25P`25L`21U`21V`21W`21X`21Y`21Z`21[`21\`21]
M`21^`24A`24B`24C`24D`24E`24F`24G`24H`24I`24J`24K`24L`24M`24N
M`24O`24P`24Q`24R`24S`24T`24U`24V`24W`24X`24Y`24Z`24[`24\`24]
M`24^`24_`25``25!`25"`25#`25$`25%`25&`2$Y`2$W`2)=`2%D`2%E`2%F
M`2%G`2$M`2$L`2%J`2%K`2%O`2(C`2)J`2(B`2)K`20K`20L`20M`20N`20O
M`20P`20Q`20R`20S`20T`28U`28V`28W`28X`28Y`28Z`28[`28\`28]`28^
M`2)8`2)5`2)7`2)6`2)9`2):`2)<`2);`2)A`2(U`2(\`2))`2)(`2)%`2)&
M`2)-`2).`2)0`2)/`2)$`2(]`2([`2(^`2(Y`2(Z`2)'`2)*`4(A`4(B`4(C
M`4(D`4(E`4(F`4(G`4(H`4(I`4(J`4(K`4(L`4(M`4(N`4(O`4(P`4(Q`4(R
M`4(S`4(T`4(U`4(V`4(W`4(X`4(Y`4(Z`4([`4(\`4(]`4(^`4(_`4)``4)!
M`28A`28B`28C`28D`28E`28F`28G`28H`28I`28J`28K`28L`28M`28N`28O
M`28P`28Q`28R`28S`28T`2,Y`2,Z`2,\`2,]`2,^`2,_`2,W`2,V`2,U`2,T
M`2,S`2-$`2-%`2-'`2-&`2-``2-!`2-#`2-"`2-,`2--`2-.`2,D`2,E`2,F
M`2,G`2,H`2,I`2,J`2,K`2,R`2,Q`2,P`2,O`2,N`2,M`2,L`2,X`2,[`2%\
M`2%[`2%U`2%T`2%^`2%]`2%Z`2%Y`2%R`2%V`2%S`2-(`2-)`2-+`2-*`2%X
M`2%W`2)4`2)1`2)3`2)2`2$A`2$C`2$D`2%Q`2%2`2%3`2%.`2%/`2%6`2%7
M`2%:`2%;`2%*`2%+`2)E`2%&`2%'`2%H`2%I`20U`20V`20W`20X`20Y`20Z
M`20[`20\`20]`2$F`25'`25(`25)`25*`25+`25,`25-`25.`25/`250`251
M`252`253`254`255`256`257`258`259`25:`25;`25<`25=`25>`25?`25@
M`25A`25B`25C`25D`25E`25F`25G`25H`25I`25J`25K`2(A`2)U`2)V`2)P
M`2)Q`2)R`2)T`2)W`2)S`2),`2)+`2)O!B(L!"(D!B$P!B$C#R%L!"%7!",V
M!"@U`S0[`SEM`R=!`RAL`R,C!",W!"4T`T`T!"%9`R%U`R%N`R%Q`R%S#R%$
M!B-.`R)Q!"(Q`R)I`R)J#R%R!2,T`R1*`R1'`R1-!B5Q`R=&!24E!"4Y!"4\
M`R=%!24K!"4[!"4X`R=0#R5*`RLQ!BY:!"@Y`RLP!2@A!"@Z`RLJ!"@W!"@\
M!2ML`S1)`R]2!"ME!C4X!#!%`S0^`S1(!#!*!#8X`SES!#8R!#8W!D95!DE[
M`SET`T`U`T`X`T`[!#PL!#PM!#PH!#PJ!417!$(W!$(S!$(N`T5X!EIS!$(O
M`T5S!$]9`T5R`T5O`T5W!$(R!$A[`TLF`TLE!$A]`TLD`TLH`TLJ`U`R!$]=
M!5-9!$];`U0_`U=3!%IG!%IH!%])!&,O`UPS`UPQ!U)T!U=,!&I!`V$\!"(S
M#R9:!"MI`U=4`R%V`R)Y`R15!2,W!B5[!B5]`R16`RLX!TT]`RI,!#!,!3$F
M!#8]!#PR!&I"`RLZ`SEX!$DB`R%0`R,A`R18!24N`R=7`R=6`R=8!"A#`RL\
M`R]=`R]<!#!-`SE[`SE\!#PT`T5Y!3$I!"%A!B)!`R%^!"(\!2(P!",^!",_
M!"5*!"5,!"5(!"5'`RM!`RM%`RM"!2M\!#!3`R]G`R]I!#!7!#!8!#!2!3$L
M!#!4!#!9`SHD!E!L!#9"!#9%`SHB!3UP`T!"!$)!!$)#!$)"!$(\`T5]`T5[
M!$(_!$(^`T5\!$DC!$]B!$]A!$]C!6$[!%5L!SY]!%]*!&,P!"%D!")`!"-$
M`R1D!"5/!BEO!B\G!"MU`R]K!#!:!#9+`T8B!%5O`U1#!%5P!5-C!%IN!#!<
M!#9-!3UX!BER`S13!7!X!"-+!B8X!"MW`SHE!E!V!#P^!41L!&U3!B8V!#90
M`R%8!B-Q`R,L!E!Z`R=D!"$K!B$[!BAD!"56`R,P!2(\`R,N`R1J`R1I`R1H
M`R=H!BHJ`RM,`R]P!"MZ`R]Q!#91!E$B!4PQ`T8D!$DG`V!P`R%=`R]R!CUA
M`S16!$DI!2%!`R%?`R,R!"5:!"A7`S]X`T8G!$=6!"%K`R(P`R(L`R,X`R,V
M`R1L!"-1`R1K`R1Q!"-4!"-9`R1R!"-3`R1O`R1N`R1Z#R-)`R4E`R=Z`R=M
M!"5=`R=V!25"!BHY`RM2`RM@`RM?`RMB`RM:!"A9!"A<`RM6#RE<!"PE`R]]
M!"M^`R]U`R]\!"PA!"M]!C5]`S`D!2Q#`S1=`S1E!#!J!39P`S1C`S1<!#!P
M`S1:!#!S!#!Q!#!M!#!L#S-#`SA3!#!O!39V`SHR!#9G`SHU`SHL!#9>!#99
M`SHY`SH^`SHM!#9@`SH]!#9?`SHW!D<Y!39Y!39Z`SHP!#98!#9E!#9C`SI!
M!39N`SH_`SHZ!3XY!#Q*!#Q&`T!/!3X]!#Q'!#Q,`T!-`T!0!E$R!$)2`T8R
M`T8O`T8M!$)/!$)*!$)5`T8K`TLZ!$)3!$)6!$)1!44B!$DP!$DL`TM"!$DM
M`TLV!R%.!$]K!$]L`U!!!$]G!$]J!$]O`U`\`U`Z!S<W!%5R`U1&!%5S!$]M
M!6%`!%IP`U=6!6%%!%],!6=9!6MS`UPU`UXG!&8R`V`N`V`M!&QL!V(O`R(R
M`R(A`R,]!253`R=^`RMD`S`F!$)8!&,R`R(S`R4N!"-?`R4Y`R4Z!"->`R4]
M`R4_`R4[`R4T`R@G!"5M`R@K`R@L`RMV!B]E`RMT`RMU`RMS`RMO`S`I!"PO
M!"PQ`S`M`S`L`S`N`S`Q`S1L`S1M`S1S`S1J#S-7!#$A!#9K`SI&!#9N`SI1
M!D=.`SI(`SI-!#Q9!#Q;`T!3`T!5!#Q6!#Q8!$)>!$)=!$);`T8[!$)?`T8Y
M!R%J`TM2`TM(!$DS`TM*`TM.#TXE#TXN!$DJ`U!$!$]X`U!'`U!"`U!#`U!&
M`U!%!%5\`U1-`U1*!%5[!S\P`U==!T9$!6MV`V!R!&QN!3<\`TU!`RMX!"AA
M!258!#9W!$)@`T9'!%IZ`R(Z`R-&`R-(!"-E`R5*!"5Q!259!"5W!"5S!"5X
M`RM]!#$E!CY"`S1Z`SI5!#Q<`U`^`R%T`R-,`R-*!")6!")9!")5`R-)`R52
M`R57`R50`R5/`R5-`R54`R@Q`R@[!"5[`RA"`R@R`R@Z`RA#`RA'`R@T!"8A
M`RA$`R@^`R@V`R@\!25=`R@Y`R@P!"AM!"AI`RM^`RPB#RHJ!"AG`S`_`S!"
M`S`]`S!)`S!'!"P[`S!#`S!0`S!,`S!$!"P_!"PZ`S`Y!"P\`S!1`S!&`S!!
M`S`Z#RYK#RYX!#$I`S4F`S4M`S4A`S4V!#$H`S4L`S4C`S4E`SIQ`SIG`SIT
M`SID`SIV`SIL`SIJ`SIE!3=.`SIN!3=&!#9^`SIO`SI?!#9]`SIP`SI=#SH\
M`SIM`SII`SIH!#Q?`T!B!#QA`T!N`T!M`T!H`T!C!#QD`T!E!#QC`T!P`T!K
M`T!O`T!L`T!I`T9+!$)G!$)L!$)H!$)F`T9)`T92`T91!$)K!$)M`T9-`T9.
M!$)I!$D\!$DZ`TM9`TM7!$E``TM5`U!2`U!5!%`A#U0J!%8B!%8D`U=?`U=@
M!%]4!6=>`UHP`UHR`UPW!&,U`UPX!&8W!&AE`V%B`V%C`R-.!B9X!"-M`RA)
M!"AP!"Q!`S!4`SI]!#QG!RTM`V$]`R(\`R-/!B9Y`R59!"-P`R5;!B9Z`RA/
M!2AN`RPP`RPQ`RPS!"Q"!2Q\!C9=`S5"`S4]`S4^!#$N!CY:`S5``SLA!#<B
M!#QJ!#QL!#QO`T!W!$)T!$)U`TM@!$)W!$E#!$E%!$E&!%I]`UXK!V(U!"-Q
M!"8F!C9H`SLB!"Q,!CYD!$)X!4QC!")=!"-T!"8H!"8G!"AT!"AU!"Q-!3%U
M!#$S!3%S!#$R!#<H!#<I!#QQ!$)Y`R)``R-3!"8J`RA2`RA3!"AY!"AX`RPY
M`RPX`RPV!"Q.!CYK`S5%!#<K!3=F!$)]!$E*`UHW`R%B!"-W`R)"`R)#`R)!
M`R)$`R-6!")A!2)1!"-[!2)0`R-7`R-8!"-X!"-Y`R5@!2-P!2-T`R5D`R5E
M!"-V`RA;!BI[!"8Q!"8R!"8N`RA6!BIV`RA9`RA:!25N`RPZ!"A[!"Q;!"Q3
M!"Q1`S!@!"Q?!"Q5`S!<!"Q:!"Q>!"Q7`S!=!C9\!2TN`S!E!"Q4`S56`S5)
M!#$W`S5,!#$]!CYU`S5-!#$Y!CYX`S50#S0_`S53`SLO`SLR`SLI!#<R!#<T
M`SLU!#QR`SLP`SLL!#QV!#QS!#Q^!3YM!#TA!E(T`T![!#QW!$,B!EQ$!$,M
M!$,J!$,A`T95!$,D`T9;`T98!$,N`T97!$E0!$E,!4QL`TMB!4QH!$E+!$E3
M`TMD!$E/!$E-`TMA!$E4!%`F!%`G!%8H!%`E!50V`U!9!RU,`U1:`U16!5L\
M!%8G`U18!S]$!%]:!6=C!6=D!&8Z`UXL!&AH!7L]`R-;!B%N`SLX!$E5`R)%
M!#%"`R)&!")E!")F`R-=!"0B!"0D`R5I!"0A`R5J#R0E!"8V!"8W!"DE!"0E
M!"DB!"DD!C!C`RQ'!"DC!"DA!"QF!"QH!#%'!#%(!#%%!#%)`S5<!#<[!#<V
M!#<]!#<Z`SL\!#<\`SLY!#<Y!#TH!#TC!#TG!#TF!#TI!$,S!$,R!$,Q!$,O
M`TMN`TMO!%`I!%8M!%8K!&,[!&,Z`U]$!&AK!DA$`T9>!%`K`R-@`R-?`R->
M`R5L!B='!"8X!"8]!"8[!28F!"8\`RAD!"8Z`RAF#R\X`RQ)`RQ*!"DJ!2DF
M!"DI!"DH!"QK!"QM!"QL`S!M`S5>!#%.!#%,!#%/`S5=!3@I!#=`!#=!`SM!
M!3\A!$,V`T9?!$,Y!$,Z!$E;!$E<`TMQ`U!=!%`L!%`N!51"!%]>!&,\!"0I
M`RAJ`T9B!RU;!"DK!#TM!B%Y!")J`R-C`R-D`R5P`RAO!"9`!"9!`RQ.!"DM
M!C!Z!"DN`RQ/!"QQ!3)&!#%1!"QR`SM&`SM#!3\I!#TO!#TN!E)-!$E=!$E?
M`UXN!"9"!%`Q!B1P`RAS!"9#`RAR`S5D`SM(`SM)!$,[!$EA`U!?`R)+!BL^
M`RAT!"DR!"DT`RQ2!2DO!2DS`RQ3!C$E!2U'#R\^!#%4`S5F`S5G!#=)`SM*
M!#=(!#TS!45I!$,]!EQG`U!@!%`T!%8O!B%^`R-E`R-H!"0Q!2)G!")P`RA[
M`RA]`R5Y!"0N`RA\!"0P!"0S`R5S!"0O!"0R`R8D`RAY!"DU!"DW!"9-`RQ9
M`RDD!"9(`RDC!"9.!"9,!"9&#RH^`RQ8!"E!`RQB!"D\!"9)!"DY`S!]!C=4
M!"D]!2DU!"TH!"E(!"DZ!"D[!"E``RQ5!C=:`S!\`RQ>!#%;!2U:`S5S!"TB
M`S5I`S!U!"TC`S5P!"TD`S!W!C=>`S$D!"TK!#%:!#%<!#%B`S5K!DAO!#%C
M`S5U!#%@!3);!#%=`S5L`SM.!#%L!#%G`SM,`S5M`S5W`SM7!#%D!DAU`SM3
M!#%F!#%>!2U7`SM2!3A"!#%J!3A(!#=6!#=0`SM<!#=9`SM?!#=4!#=.!3\R
M`T$E!#=5!#T^`SM@!#TW!3)8`SM;`T$F`T$M!#T[!$-#!3]"!E)I`T9G!#TZ
M!#T\`T$P`T9E!$-"!$-0`T9F`T$O!$-(!$-'!$-)`TM]!$--!$EE`TPB`T9I
M`TM[!$-*!$-,!$-&`TPG`TMX!$-+!%`X`TPJ!$EG!$EI!$EH!$EK!R)\!$EM
M`U!I!$EL`TPF!%`Y!5M,!%LC!%LI!%8V!%LE`U=G!%LD#UHI`U=F!%`Z!6=X
M!&-#!%]D!6=S!T<L`UXP!&-"!&-``U]'!&AL`V%X`R-J`R8F!"94!BM2!"TO
M!"TP!2U=`S5Z`SME!#U"!$-4!4TW`TPK`U1B!B=N!"95!"96!"E-`RQD!"%[
M!"%Z`R)/!")T!")S!")U!"0Z!"0V`R8L`R8M`R8P`R8K!"98`RDM!28Z`RDL
M`RDX!"E5!"TS!"99`RDK#R<N!"E.!"E4`RQF`RDG`RQG`RQI!"T\`RQQ!"E6
M`RQH!"E2!"TR!"TQ`RQJ`RQE`S$T`S$J`S5[`S$Q`S$Z!"T[`S$M`S$K!#%\
M!#(A!#%[`S8L!D`R!#(E`S8O`S8P!#%Y`S5^!#%Q`S8E!#%^!#%Z`SMK`S8J
M!#=N!#=B`S8A!#U%`T$Q!#=D`SMJ!#=K!#=H!#=E`SML`SMI!#=P!#=A`SMN
M!#U0!#U/`T$W!#U,!#U*`T$U`T$[!#U(!#U.`T$\`T%*`T%#`T$_`T%'`T%`
M`T%&`T%!`T$Y!$-8!$-A!ETR`T9Y`T<N`T<M!$-6`T9\`T<G`T<O!$-<`T9W
M!48E`T9]!$EU`TPV!$-D!48C`T<K`T<L!$HD`TPS!R,Z!$EY!$EZ!$EV!$HH
M!$HB!4TZ!$E^!4T^`TP\!$HC`U!T!%8Y!%!%`U!S`U!N`U!X`U!R`U!Q`U1E
M`U1J`U1H`U1C`U1F!%LM`U=I!%LR!%LP!%LN`U=O`U=Q!%LQ`U=H!%LO`U=R
M#UYS`UH]`UH^!&-'`UQ`!&-&!7`D`UXR!&9``V`Q!&I)!&I(!7DJ!"9;!"U`
M!"T_!#(G!#U4!"1``R8Z!"9>!"9?!"E=`RQU`S$^!"U"!C@K`S8S!#(H`S8U
M!#(L!#=Y!#=U!#=X!#=W!#=V!3A\`SMW!#U<!#U9!#U;`T%,!$-F!48P!48N
M!$-I!$HK!$HJ!$HI!%!)!%!,`U=S!%LZ!&-,!&9#`R8[!C@L`T%/`RDZ!"EA
M`S%!`SDK`SMX!$HN!%8^!&I+!"EB!"U)!C@P!DEA!EU1!4U+`R-Q!BMP!C@T
M`S8[`S8^!#UE!$HP!$HQ!")X!")Y!"1#`R8\`R8_`R8^`R9``RD_`RD]!"9C
M!2E/!"EC`RQ[!"ED!"EE`RQX`RTF!C%G!"U,!#([!"U+`S%'!C@W`S%*#R]N
M!"U-!D!1!#(V!#(Z!#(W`S9#!D!/`SPB!#=^`SMZ`SM[!#@E`SPG!#@B!DES
M`SPA!E,]!3]B`T%2`T%7`T%:`T%5`T%3`T%<`T%8!#UH!#UG`T%4`T<X!$-N
M`T<R`T<V!4U3!$HR`TQ"`TQ%!%!2!%!1`U$A!4U0`U![`U!\!%!3!RY:`U1S
M`U1N!%9`!%M`!%M!!%L_!S]V`UI``UI!`UQ$`U],`U]-!75N!75M`R-T!%!6
M`U1T`RE$`S%.!2XE`S9)`SPH!#I#!49%!4U8`U$E`R-V`R9#!"1(`R9&`RE+
M`RE&#R=,`RE0`RE-!291`RTH`RTL!"EO!"EL`RTI!"U7!"U1!"U4!"U8`S%2
M!2XK!"U2!"U;`S%5!"U6`S%1`S99!#)#`S9*`S9/!3)Y!#)"!#)&!#)!!#@T
M`S98`S9=!#@O`SPN!#@L`SP_`SPP!#@J!3DS!#@M`SPL!3DY!#@U`SPU!#@W
M`SPV`SQ#`SPK`SPM!#UX`T%Q`T%F`T%P!#UK!#UN!#UO`T%L`T%I`T%D!#UM
M`T%>!#UU`T%B`T%C`T%Z`T%A`T%?!$0C!#UV`T%@`T):`T%G#TA5!$0D!$-U
M!$0A!$-\`T<_!$-X!$-S`T=!!$-T`T=*!$-]!$-^!$-Z!$0B`T=/`T=`!$0E
M!$-Q!49+`T=)!#UR`T=0#TA2`TQ.!4UM!$HZ`TQ,!4UA`TQ3!$HW!$HV`TQ=
M`TQ8!R-O!$HX!$I"`TQ:`TQ<`TQ(`TQ5`U%#`U%"!%!@!%!:`U$W`U$P!%!9
M!$HY`U$_`U$J`U$]!%9)`U$S`U$Y`TQ+!%!>`U$M!%!D`U$U`U$T`U$V`U4B
M!%9(`U1^`U4E`U1]!%9+!SA5!5MH`U1W`U4F#U\I`U1Y`U4H!%M(!%M$`U=\
M!%M*!%M)!%]O!%]S`UI)!%]P!%]N!%]R!%]U`UI,`UI+#V)3`UI*`UQ,`UQ&
M!&-1!&-/`UQ(`UQ-!&-4`UQ+`UQ%#V4^!7`G`UXV`UQ*`U]0!&AN`V`U`V`S
M`V`T!21(!B@P!"9M!296!"9P!"9L!"U@!"EP!"EQ!C%X!"ET!"ES!2XN!"U=
M!"UA!"UB!"U>`S9A!#)(!#))!D!N!#@[!#@Y`SQ&!3E#!#@\!CAD!#XA!#U\
M!#U[!#U]!#U^!#XB`T=2!EUW!$0J!$I,`TQH!%!F!%!G!%9/!%9.`U4J`U4L
M!%]W!TXB!&AQ!75W!7DO!B4E`RT^`RM[`SQ(!#@_!49?`U@D!")\`RE7!29B
M!"9U`RT_`RU!`RU``S%I`S9C!#)*!#A%!#A$!#A&!#A"`SQ*`T(C!#XC!#XD
M`T(D!$0R!49@!$0S!$0P!$I0!$I/!%!K!%!J!%91!&-5`UQ.!75X!21.!"9X
M!"UD`S%K!#)/!#A)!#A*!#A+`T(E!$0U`U%'`U%(!%!N!%93`U@E!"E[`R-[
M!"9Y`RE;!"9Z#R=;`RU#!"UF!#)2!#)4!#)3!#)5`S9G!"UG!#)1!3E;`SQ,
M!#A/!#A,!#XI`T(G!#XH!#XG!$0_!$0X!$0Y!$0Z!49H!$0\!%!O!%!Q!%!R
M`U%)!%M0!%M/`UI0!&U7!"UJ`RE<`S9H`TQI`U%*!"%/`R)6`R)5`R0B!2%T
M!",B`R94`R9/!"1/`R9=!BA)`R9:!"11`R9+!BA*!BA$`R98`REA`RE?`RE>
M`REB`RE@!"9^`REH`REF#R=F`RU$!2HD!"<B`RU4!2E[!2E\!"E^`RU6`RU,
M#S!)!CAR`S%P`S%Q!"UK!CDS`S%T!"UL`S9I`S(D`S(C`S%^`S%U!#)7`S9Q
M!#)C!#)D`S9N!#)>`S<B`S9M`SQ/`S9^!#)8!#)H!3E>!#):!#)<!D$K!3,]
M`SQ>`S9[`SQ?`S9S!D%!`S9X#S8S!#A1!#A6`SQE!#A2`SQ9!#A9`SQJ`SQG
M`SQ5!#A7!#A:`SQ3`SQ7`SQA`T(K!DIM#SQ##SQ:!#XW`T(L`T(W`T(U`T)(
M`T(X!#XP!#XY!#XM`T)"!#XX`T(T`T(\!#X\`T(O`T)!!4`G!#XO!#XR`T(R
M`T)#`T=5!$1)`T=@!EX[`T=9!E10`T=8!$1&!$1-!$1*!EY``TQN!$I?!$IA
M`TQO`TQ\!$IH!$I=`TQM!$I9`TQR!49X!R1A`TQP!%!T`U%+`TQV!%!W!%!]
M!54V!%!V`U%/`U%.!%!Z!54M`U%3`U%7!%![!%96`U%1`U%,!%!X`U%2!$IB
M!54N`U4R`U4X!%9>!%9@`U4T!%98`U4N!%97!%9<`U4[!%99!%9;`U4S!%M6
M!%M4!%M:!%M7!%M@!%][!%]]!%M;!%]Y`UI1`UQ0!&-:!&->!&-;`UQ2!&9)
M!7`^!&9*!&9,!&AS`UXY`UXX`U]1!&I.`V`X!&MM!&MN`V%F`R0J!"12`R9A
M#R1N`REN!"<G`REX#R=N`RES`RUG`RU9`RUF`RUA`RU@`RU;!"HG`S(N!"US
M`S(R`S<K`S<J`S<T!#)Q!#)V!#)P!#)W#S9(`SQV!#AE!#AA`SQU!#AB!#AD
M!#A@`SLC`SQ^`SQP`SQX`T)4`T)-`T)6!#Y+`T)*`T)5!#Y(!#Y&!#Y)!E14
M`T)+`T)0#T)X#T,\!$19`T=S`T=I!E1G!$16!$1:!$1<`T=Q#TE8`TTF`TTC
M`TTK`TTA`TTG!$IJ!%$E`U%=`U%;!%$K`U%?`U%A!%$D`U%D`U%E`U4]!%9B
M`U4_`U5$!SDF`U=1`U@L!%9D`UQ:`UI9`UQ4`UQ;!&-?!&9.!7-7!&I0`V`Z
M`V%Z!"<L`REZ`S=8`T=T`RUJ!"UV`S<V!#AK`RE[!"HL!#AL`RE]`RE^!2Y3
M!CE`!"UZ!$1?!SDM!%MD!&90`R%J`S(S!",F`R9E!"15!BQQ!"<S!29W!"<R
M!"<O`RUL`RUO!"HN`RUN`S(T`S(U!"U]!"U\!#)Z!3--!#)Y!#)^`S<X!D%F
M`S<W!#AP!#AR!#AS!$1C!E1X!#Y.`T)>!$1B!$1@!$1D!$IO!$IN!$IR!$IQ
M!$IS!%$N!%$P!%$O!%9G`U5&`U5'!%MF!%ME!&`D!U-K!&I1!"<T!"19`R9M
M!"16`R9L!BQU!"<Y!2<N`RHI`RHD`RHE!"<Z!"HR!"HT!"HU`RUR!C)G`S(W
M!2Y<!"XA!"U^!"XB!"XF!D%M!"XG!3-1!#,H!D%U!#,I!#,E!#,K!#,G!#,N
M!#AY!#AW`STL!#A[!DM#!$1E!#Y4!$1F!#Y3`T)@!#Y2!$1J!EYN!$1I!$1H
M!$1G`T=V!#AZ!$I[!$IV!$IZ!$I\!R]T!%$R!%$T`U5(!%9J!%9K!%MG!6@[
M!&-E!&-F!&-G!&-C!&MO`R0N!",I`R0P`R0Q`R9Q`R9O`R9P`RHN`RUV!BTA
M`RHP!"<[`RHQ`RU]`S(Z!"HW!"HX#RPR!#,O`S)#`S)$`S([!#,P`S)%#S$G
M`S)"`S<_`S="`S=!!#,S`S<^`S=#`STT!#A]!3HM`T)C`STQ`STP`T)L#S99
M#ST[!#Y9`T)E`T)I!4!.`T)R#T-)#T-6`T@D!R4W!$LB!$LA`TTW`TT\`TTS
M`TTX`TTT`TTR`U%H!55=!%$W`U%I`U5*!%9O#U5Z#U8B`U5.!%MI`U5,#ULM
M`U@Q!&`J#V)X#V)[`UQA!"HY!"HZ!2YB!"XK!#,U!#,T!#A^!$1P!$1Q!$1O
M!$LC!$LD!%ML!&U:!"1>!2<R`RHT`RXC!"H]`S)*`S)+!"XM`S))!"XL!#,[
M!#DA!#,Z!#,X!#,Y!#,W!#DC!#DF!#,\!#DD!#YB!#YA!#Y=!#Y@`T)V!#YC
M!4=(!$1S!$1V!$1T!$1X!$1W!$1U!$LE!$LG!$LF!%$_`U%O!%%"!%%!!%9R
M!%9S`U51!%9U`U50!%9Q!%MO!%MN!&`L!&`K!&AU!&MP!&I3`S),!#YE`TT_
M!%9X`SU`#U!.!21C!BAB`R9R!"I!`RXI!"I#!"XO!"XQ!3-D`S=(`SU!!#DH
M!#YI`T)Y`T)Z!#YH!$1Y`TU`!$LJ!$LI!%%$!5PO!%MR!%MS!&`N!&-I!&I4
M!#YM!"1A!"1B!2<W`RH\!"I&`RXM!"I)`RXL`RXN`S)6!"XW!"X[!"XU!"XV
M`S)4!"XS!"X_!"XY!CEK`S)3!"XX!"XZ!3-M!#-"`S=,!#-`!"X\!#,_!#-%
M`S=+!#-#!#DR!#DS`SU&`SU+!DM:`SU)!#DV!4!@!#DO!#DP`SU(`SU*!3H[
M!#DU!#DX!#YT!4!D!#YO!#YX!#YN!#YV!#YS!#YZ!$4D!$4H!E\M`T@J`T@L
M!$4C!$4A!R58!$LX`TU"!$LW!$LU!$LS!$LO!R5<!$LN!4=9!$L[!S`V!%%(
M!%%)`U%U!%%.!%%*!%%0!%<F!%<B!%M[!%MW!T!K!%<E!T!G!&`R!&`O!&`P
M!&98!&99`UY`!7-<!&I5!&MR!&MQ`V(M`R9U`RXP`S)8`S=.`T,B`T@M!4=;
M!4Y9!%%6!&`W!&9;!&QS!"=&!"I.`RXQ!"Y&!"Y%!#-'!#-(!#DZ!E52!$4P
M!$4R`T@O`TU#!$L]!%%7!%M^!&-L!"=(!"I1!"I0!"Y'!"Y)`S)9!#-+`S=/
M`SU.`T,C!4!O`T@R!%%:!$4V!%<L!&`X`U\X!&Y(`R9Y!"1E!"=.!"=/!"=-
M!"=,!"=*!"I3!"I6!"I7!"I4!"I8!2IM!"I:!C,X`RXT!"Y2`S)=`S)F`S)@
M!"Y-`S)A!3-V!#-0!#-1`S=6`S=4!#-2!#-.!#--`SU0!#E)`SU4!#E*`SU5
M!#E%!#E(!#D_!#E!!#E+!#E&!#E-!#E'!#E#!#\B!#E,!#E"!#\P!#\M`T,D
M!#\E!#\F!#\G!#\K!#\L!E5A!4=A!$4Y!$5!!$4\!$4W`T@W!$5#!$5&!$4_
M!$5$`T@Z!$4X`TU%!$M%!$M"!$M$!$M'!$M#!$M-`TU'!4Y@!$L_`U%W`U%X
M!%%<!%%@`U%\`U%Z!%%=!%%D!%<R!%<N!%<Q!%<O`U5:!%<P!%<S!%<T!58B
M!6)I!%PG!%PI!%PJ!%PE`U@W!%PF!&-P!&-N!&-Q!&-O!&9=`UY!!&AX!&I7
M!&AZ!&QU!&Y-!"=1!"I?!#-7!$5*`U5=!%<X!&-T!&MU!"Y7!"Y8!#-:!#-9
M!DPK!#\S!$5,`R0R`R9Z!"=3#RAZ!"ID`RXX!"IB`RX\`RT[!"Y?!"Y<!"YB
M!2\T`S=;`S)J`S)K!"Y>!"YA!#->!#-A`S=<!#-?`S=:!#-@`S=>`SU;!3I9
M!DPS!#E8`SU8!#E3!#]`!#\Y!#\_`T,O!#\\`T,R!#\]`T,L!#\^!#\X!#\Z
M!#\[!#]"!$5.`TA#!$51`TA!!$5-!$55!$5/!4=V!$M<!$M8!$M6!$M5!$M>
M!R8D!$M;`U(C`U%]!%%L`U%^!S!9!58S!%%P!%%M!%<[!%=!`TA"!%<Y`U5>
M`U5?!%<_`UA!!%PM`U@]!%PQ!%PO!%PN!&`_!TY<`UQC!&-V!&-U!&9?!&9@
M!&9A!&A\!&A[`V!U`V%G`RX_!"IG!"IF!C-(`S)N!"YD`S)Q`S=D!#-C!#-B
M`SUA`SU@!#E9!#]%!#]$`T,Z`T,[`T,^!#]'`T,\`T,_`TA&!4@D`TA)!4YV
M`TU.!%%V`U(E!%%T!%%U!%="`UA&`UA'`UID!&9C`V(T!21N`R9]!2=&!BU)
M!"=6`RI``RI!`RI#!"IJ!"IO!"IK!"II!"IL#RQM!"YE`S)U`S)Z!D)F!#-G
M!#-F`S=M!#-E!30[!30Y!#-J!#-I!#-K`S=H!#-M!30X`S=N#S<[!#-D!3IE
M!#E>!#EB`SUG!#ED`SUJ!#EC`SUK!#EA!#]/`T-`!#]-`T-%!#],`T-"!#]+
M`T-#!$57!#])!4$Q`TA1`TA*!$5;`TA3`TA.!$5:`TA,!$58!E]K!$59!$ME
M!$MA`TU4!$MB`TU2!R8R`TU8!$MH!$MF!$MD`TU9!%%]!%%\`U(K!%%Y!%%X
M!%%Z`U(M!%=%`U5C!%='`UA(!T$N!%PW!%PU!%PV`UY&!&-Y!&9E!UA,!&9D
M!&A^!&DA`V(Y!"1I!BU.`RY&`RY%!"IQ!"IR`S,A`S)^`S)]!#-O!#-P`S=O
M!31%!#-R!#-Q!D)O`SUL!#EG`SUM!DQ3`SUN!4$Y!#]3!#]2!E8G!$5@!E]X
M!$ML!4\C!50D!%(E!%(B!%(D!S!O`U5E`U5F!%=,!%=-!%=+!%=/`U5G!%PY
M!%PZ!&!(!&!)!&-\!&DB`R0T`RI&!"IV`RY*`S,E!"YM`S,B!31&`SUO!#EJ
M`T-(!#]4!#]5!#]:!$5C!%=2!%P[`UIH!2LA!"YU!"YP`S,H!"YW`S,I!"YS
M!"YR!#-V!#-]`S=T!31(!#-W!#-[`S=U!D)V!#-X!#EM!#ET!#EQ`SUT!#];
M!#ER`SUZ!#EU`SUS!#EO!DQ;!DQ6`T-0!#]F!#]B!#]A`T-2`T-3!#]=`T-.
M!#]@`T-+!#]C!4A&!#EV!$5E`TA;!$5J!$5I`TA?!$5N!$5H`TA9!$5M!$5F
M!4@V!$M[!$MU!$MP`TUA`TU>!$PB`TUG!$M^`TUB!$PN!4\[`TUD!$PP!$PE
M!$PM!$MY!4\R`TU?!4]%!$PL!$PG!$MW`TUF`TUH!$PH!4\V!%(T!%(Z`U(Q
M!%(W!%(K!%(X`U(U!%(Y!%([!%(V!%(O!%(]!%(I`U(R!%=;!5QM!%=>!%=:
M!%=B!5Q]!%=E!%=3`U5L!%=6!%=8!%=9!5Q^!%=5!5TP!%Q$!%Q/!%Q+!%Q0
M!%Q#`UA*!%Q*`UIL!%Q"!%Q,!T$_!%Q&!%Q)!%Q`!6,T!%Q(`UA-`UA+!6-!
M!&!6!6AN`UIJ!&!3!6AF`UIM`UII`UIK!%Q1!&-^!&9I!&9L!&9N`UY*!&9J
M`UY-!&9H!&9M`U]6!7!A!&DF!&DH!&I=!&IA!&I<`V!?!&MV!&U<!&UV!V5=
M!"IW`S,O`S,S!D,B!#0E!319`S=\!DQ@!#E[!#E\`SU]`SU\!#E]`T-:`T-6
M`T-7`T-9`T-;`TAC!$5R`TAD`TAE!F`L`TAF`TUK`TUL`TUI`TUJ!$PW!R97
M!$PU`U(V!%=M`U5S`U5R!%=I!%=J`TUT!%=K!6-.!%Q6`UA2!%Q5!%Q4!6-4
M`UA3`UIP!&!;!&!=!&0C`UQH!U0Z!7!P!&IE!78Y!&QZ`V%%!"=<!C-D`RY7
M`RY5`RY8!"YX!"Y^`S,U`S,T!"Y\`S,Y!"\A`S,X!"Y]`S,V`S,Z!#0N!#0F
M`S@C`S@J!#0G!#0P`S@L!#0M!#0K!#0I`S@H`S@M`S@E`SXV!3LL`SXM`SXR
M`SXG`SXP`SXE!DQQ`SXQ!#]J`T-E`T-K!#]N!#]S!#]O`T-A`T-=`TAL!$5U
M!$5^!$5Y!$8A`TAG`T-?`TAR`TAU!$8C!4A4`TAO`TXJ!4]3!$P^!$P\!$Q`
M`TU[`TXA`TXM`TUV`TUY!$PZ!$P]!$P_`TUZ!$Q$!4]4`TXF`TXC`U(Z!%))
M`U(\!%)'`U(]`U(^!%=S`U5X!5T_`U5V!5U&`U5W!%=N`U5\`U5[!SHY!%QB
M!%Q@!%=R`UA7`UA6`UDI!&!F!&!C!&!H!&!B!T=*`UIS`UIQ!6TB`UQI!&0D
M`UQJ`UQK`UY/`UY.!&DJ!UA8`U]9!&DK!&IF!&MY!&MX!U\S`V!X!&Q\!&Q[
M!&UW!"IY!"\I`S@O`S@R!31@!#0T`S@P!#0S!#HH!$8E`TAV!%).!&IK#R%'
M`RI-`RY<`RY;`RY9!"I[!"\J!CIK!"\M!#0U!#]U!#HJ`T-L`T-M!4%E`TAZ
M`TA[!%)/!%=U!%QE!&!M!&9[!&M[!CIT!"\N`S$_!#0X!#0V!#0W!D,\!#HM
M!#HQ!#HP!#]V`TA^!$8G`TA]!$8H`TA\!$Q)!%)3`U)!!%=W!%QJ!%QK!&DL
M`S-``S-!!#0Z`S@S!#0[!#0^!#0\`S@U`S@T!#HT!#HU!3LZ!#HS`T-P!#]X
M`T-Q!#]W`T-O`TDA!$8J!$8I!$8K!%)5!%)6`UA>`UA@`UA?`UQN!&9]`SXY
M`SXZ!"LG!"LH!"\X!"LI`S@X!#]Z!$8N!$8M!$8O!$8R!$8P!$Q/!%=]!%=Z
M!%=[!%QP!&<A!"1M`S-&`S-%`S@Z!#1!!#HY!4%P`T-T!$8V!$8T!$8U!$8W
M`TDD`TXS!$Q2!%):`U)"!%);!%@A!%@D!%@C!%@B`UAD!&0H`U]<!E9M!",M
M!B5)!"1O!"1N`RI1!CLH`RI5`RI0!"=F#RA2!"=B!"=G!"=C!"=E!2=8`RI:
M`RI3!2LS!"LO!"LJ!"LL`RYB`RY?!C-]!2LY`S-1!"]!!"]&!"]'!"\_!CLQ
M!2]M`SA&!#1,!#1(`SA$!#1+!#12!#11!#1*!#13!D-8`SA``S@_`SA#!#I)
M!#HZ`SX_!#I%!3M-!#I*!#I!!#I`!#I"!#H]`SY&!#H_!#I$!#I+!DE^!DU4
M!E9V!$`G`T-X!$`J!$`C!$`F`T-Z!#]]!$`H`T0A!$`L`T-]`T-Y!31J!$`E
M!$9%!$8^!$8\!$8]!$8_`U)(!$9"!$9`!$8[`TDI`TDH!$8X!$9'!$9!!$Q=
M!$Q8!$Q>!$Q5!$Q<!F!O!$Q4!$Q;!$Q?!4(H!%)C!%)D`U)&`U)%!%)>!%)A
M!%)B!%)F#U%5!5U;!%@K!%@H!%@L!%QT`UAF!%QV`UAG`UIV!&!T!&!S!6TL
M!&0J!&<B!&<D!&<C!&<E!&DP!D-D!T(D`RM$`T0D!"]*!#18!$QC!%)K`S-3
M`S-4`SA*!$QD!F$A`U)+`UY4!"=O!"LS!"LR`RYG`S-6!"]0`SA+!D-Q!D-P
M`SY*!#I.!#I/!DUC!4(M!$`O!$9/!$91!$90`TDL!F$D!4DL`TX^!$QH!$QE
M!%)L!%)M!%@P!%@T!%@S`U8E`U8F!5UG!5Q-!%@R!%Q\!&0M!"]3!#1<!%)O
M!%)N!%@U!%Q]!&DS!B5/`R0W`R0Y`R<G!"1V!"1]`R<L`RIC`RIG`RID`RIJ
M!"=R`RIB!"@A!"=S`RIE`RII!2=C`RIA`RYM!"LV`RYP`RYQ`RYL`RYS`RYU
M!C0Z!"]5`S-A!"]A`S-D`S-;`S->!CM6`S-=!"]>`S-<`S-E!3`A!"]9!"]D
M`S-@!#1>!#1L!#1Q`SA:!#1I!#1E`SA6!#1F!#1B!#1=!#1C!D0L`SA,!D0H
M!34J`SA9`SA<!34D!#IL!#I@!#I?!#ID!#I9!3M6!#I;!#I6`SY3!#I>`SY4
M`SY1!#I<!#IA`SY5!DXG`SY,#SYK!$`P!$`R!#IE`T0W!$9I!$!'!$!)!$`Z
M`T0K`T0I`T0T!$!(`T0]!$!,!$9E`TDO!$97!F%$!$9D`TDQ!$93!4D\!$9A
M`TDP!$9M!$9@!$9<`TDT!4D[!F%8`TDW`TE``TY#!$QR`TX_!$QP!$TD!$QK
M`TY!!$QQ`TY3!$QM!$QS`TY'`TY%`TY6!$Q]`U)1!$QL`TY*!$QN`TY(`TY5
M`TY)!5!&`TY0#U%E#U%S#U%V!$TA!$QO`TY1!$QW!%)W!%)[!%)Y!%,L!%,A
M!%)V`U)3!%,E`U)7!%)^`U)-!%,C!%)Z!%)\!%)R!60M`U),!%,B!%)S`U).
M!%,G!%,Q!$9G!%A$!%@\!%@X!%A"!5UY!%@V!%@[`U8N`U8G!%@]`U8J`U8O
M`UAI!%Q^!%TK`UAM`UAP`UAJ`UAQ!%TC!T(X!%TA#V!.!SLR!&!W`UQS`ULC
M!&!X`ULA`ULD!TE3!&0O!&0T`UQ]!&0S`UQT!U1H`UQY!&0R!&0X`UQZ!&0P
M`UQU!&0V!&<G`UY9!&<H#V@Y`U]=!&DW!UAR`V!!`V!"!7@E!&M]!&U>!&Q]
M`V%J!&UY!&U[#VQL!&XW!&XV!7P^`RIM!"L^!"]G`S-G`S-F`S-H!34U`SAB
M!3MP`SY@`T1!!4)4!4)3`T1"`T1#!$TF!%,V!%TR!60[!60Z!&0Z`R<N`RY]
M`R\A`R\B!"]I!"]K!CMI`SAH`SAG!#1\`SAE!#1[!#1Y!3PF!D1(!#IR`SYG
M!#IT`SYE!3MT!#IP!#IM`SYD`SYF!$!6!$!7`T1+`T1'!$!;!#IN!$!=`T1*
M!$9X`TE&!$9R!$9S!$9Q!$9U`TE'!$9P!$9V!F%I`TE(!$9[`TY:`TY<!RA"
M`TY7`TY8!$TP`TY;!$9Y!$TV!$TO`TE-!%,^`U)<!S)S!%,]!%A-`U)@!S)U
M`U)A!5XR!%A7!%A2`U8W!%A8!%A/!%A6`U8X!%A.`U8R!%A4!%A?`U8U`U8\
M`U8Q!%T[!5XU!%TY`UAR!&$D!6E!`ULJ!&$A!&$E#V-N!6U+!&0[!&0\!&1`
M!&0^!&1!`UTF`UY>!&<P!&0]!&D^`U]>`U]@`V!$!UDE!UQ>!&IX!UQC`V%(
M!&XY`R\E!CMS`SAI`T1,!$<C!$TW!"]O!#IX`TY>!%-*`ULN`RIN`R\H!"M&
M!3`]!"]R!3`Y!#4J!#IZ!#4M!#4N!#4L#S)1!#IY`SYQ!#4P`SYN`SYL`SYK
M`R]*!$!B!$<E!E@K`TE3!$<M!4EL!4EM!$!F!$<Q!$<G`TE5!$!@!$<J!$<N
M!$<F!$<K`TE:`TE0`TE;!$T\!$T_!$TZ!$TY!$U"!$U`!$U'!%-2!%-5!%-6
M`TYC!%-/!%AC!%AG`U9%`U9#!%AD`U8^!SM9`U9$!%AE`U9!!616!%U*!%U(
M!%U)!%U$!%U&!&$J!T,B!&1#!U`E`UTG!&1$`UY?!&I[!UDR`V!Z!&PF`V!Y
M!&U]!2M'!"]S!#4Q!#LA`S-Y`S-X!#4S!#4U!#LC!3PU!#LB`SYS`T10`T11
M!$<V!$<X!$U*!$U(!%-:!%-;!5@R!%-<!5Y#!%AH!%AI!%U.!%U0!&$M!&$N
M`ULP!&$L!&$P`UY@`V(\!#4Z`T13!$!G`T12!$<Z!$U1!$U,!$U.!$U3!$U/
M!%-D!%-A!%-B!%AK!%AJ!61C!&$Q!&$T!&1&!&1'!&TB`R\K!2M)`R\M!"]^
M`S-]!#5!`SA\`SAX!357!#5$!35>`SDD`SDH`SDA!#4_`SA]`SDG!#5#!35=
M!D1M`SDF!356!#LS`SYY`SYZ!#LV!#LU`SYV`SY[`SYW!#LT!#LJ!#LI!#LK
M`S\F!DYK`S\E`T17!EA!`T1>!$!N!$!M!$!L`T1:`T1?`T1B!$<]!$=`!$=*
M!$<\`TEJ!$=&!$="`TEA!$=#`TEI`TEG`TE=!$U9!$U6!$U<!$U>`TYH!$UA
M!$U8!$U;`TYM!$U?!$U:`TYK!$U@!RAY!$U5`TYQ!%-J`U)L`U)M!S--!%-K
M`U9'!%AP`U9+`U9,!5Y5!%U:!THE!%U7!%U;`UDB`UDE!%U4`UDG!&%`!6E2
M`ULS!&$[!&$]!&%%!6E1!&1.`UTM!U`Q!&1,`UTO!&1(`UTQ!&<]!&<_!U4R
M!&<^!&=`!&<Y!UDX`U]C!&E(!79,!"M)!#`C!DYZ`S\G!$=,`TYW!%AU!%UA
M!&E,!#5*`S\H!$!T!$=.!$=/`TEL!$UD`U)P!%-S`U)O!%-R`U)Q!%AV!%AW
M`U9.!&=$!&TD!#`E!#5+!D4B!#5,#T1T!$UG!$UE!$UH!%-U!%-W!%UD!&%(
M!&%&!&=%`U]E`V%,!&TE!#50!D4D`SDO!#L^`TEN`TYY`TYX`U)R`U90`UDL
M`UDM!&%*!TI!`ULW!%UH!#51!#54!3Q,!#L_!#M!`S\N!#M"!D\I!#M#!$$A
M`T1F`T1H!4HI!F)J`TEO`TY[`TY\!$UN!$UL!RDV!$UM!5$Y`T\A`U)T!%-]
M!%-Y!%-[!%-Z`U)V!SPS!%AZ#V!Z!%-^`UTU`UYD!&LA!3!+!4,T!$=9!$=8
M!&=(!3!,!#`G!#`H!#55!#56`SDT`SDV`S\Q!#M%`S\V`S\R!3Q2`S\U!#M(
M!#M'!$$F!$$G!4,\`T1J!$$H!4,X!$=:!F)U!$=;`TEV!4HT`TEW!4HR`T\G
M!$US!$UQ`T\D!$UT!RD]!%0F!5A<!5A5`U)X!%A]!%DE!%A\!5YM!%UM`UDO
M!%UL!%UJ!%UN`UDP!&%-`UTV!&15!&13!&16!&=*!&E.`U]F!&E/!&LC!&PH
M!&TG!"M,`R\O!#`J`S-^!#5>!#59!35R`SD[!#5;!#5<!#5=`SD\!3QC!#M,
M!#M0`S\]!#M-!#M)!D\V!D\\!3Q<!#M*!#M+!#M/`S\\!3Q?!#M1!$$I!4-+
M`T1L`T1N#T58!4H^!$=>!$=A!$=?!$=B!$=E`TEX!$=D`T\H`T1O!$UW!$XB
M`T\J!RE.`T\N`T\I!$U^!$XA!$U]!$UY!$UX!$UV`T\M!$XC!%0N`U)]`U)Z
M!%0O!%0M!5AB!%0P`U)Y!5Y[!%DK!%DL!%DF#UQX!%DJ!%DH`U93`UDS!%UT
M!%UX!%UR!%UU!TI7!&%0`UDT!&%1!%UW!&1;!&1:!&=0!&=,!71+!&LD!UQW
M!&PI`V%/`V(N`S]"!3QG!#M2!#M3`S]!`T1Q`T1P`T1R!$XF!%0R!%DP`U96
M`UL^!&1?`V!,!"M-!"M.#RU3`S0B`SE#`SE$`SE(!#5A!#5B`SE%`SE&`SE"
M!D5%`S](`S]#!#M4`S]*`T1U!$$J`T1T!EDD!$$L!$=F!$=I!$=G`TE^!$XH
M!$XG!$XJ!$XI`U,C!5AR!%0S!%0T!5%A`U98!%DR!%DU!%DW`U97!%DQ!%U\
M!%U[!%UZ!64U!%U]!%U^!&%9!&%8!&%7!&1@!&1A!&=2#VA3`U]H`U]G`V!]
M!&UA!&XA`V(]!$XN`UTY!$=K#TQG`T\X!&1C!U!6`R<R!"4B#RAR`RIO!2=I
M!"M3!"M0`S0C!#`M!#`P`S0D!#`N`SE)!#5I`SE-`S]3!#M7`S].!D](`S]2
M!$$O`THE!$=L`THC`T\Z!$XQ!$XU`T\]`U,J`U,H`U,I!%DX!%DY!T-W`UDY
M!&%>!&PL`R)?!",R`R<V`R<W`R<X`RIV!"@I`R\V!"M6`T4B`R\]!"M4!"M8
M`R\Y`R\Z!C1M!#`X!#`T`S0H!#`S!$=Q!#5L!#5N!#5S!#5K`SE0!#5P!#M>
M`S]8!$$T!$$V`T4A!%D\!$$X!$=M!$=N`THI`THH!4I@!$=P`T\^!$X]!$X\
M!5A^!5\\`V!-!&LF`R\_`S0K`S0L!#5X!#5T`SE3!38V!#5U!#M@`S]:`S];
M`S]<!#MD!EE,`T4F!$$]!$$\!$$_!$$^!$=S!$=T!$X_!$Y!!$X^!$Y`!%0]
M!%0\!%0Z`U,N!%1`!%0[!S14`U,P!%D]!%E"!SQP!%E!!65%!&%A!&%D!&%C
M!&%B!&%E!&=:!&=;!&E4!&E3!&PN!&PM!&X]!#5Z!CQC`SE:`S]?`S]D`S]A
M`S]G`T4L!4-M`THN!$=Y`THV!$=V!$=[!$=X`T]/!$Y#`T]'`T]&!RHX`T]*
M!RH^`U,S`U,T!%1(!%1&!SQ[`U9I!SQW!%E%!%E$#UU,`UD_`UE!!%XO!%XL
M!T0Y!%XG!65/!%XK`UE(`UE'`UM&!&%F`UM+`UM``UM2!&%I!6HS!&%H`UM1
M`UM,`UM)#V0T`UT[!&%L`UU`!&1F!&1L!6XU`UU(!&1M!&=?`UYK!&1I!&=A
M`UYL!&=C!U5H`UYI`UYN`UYO`U]O`V!1!7%5!UEG`U]M!UEH`U]P!715!&LJ
M!79?!&LG`V!.`V!0`V$C`V$A!&PP`V$D`V%N!CQE!#MG#S]V!$%)!%XR`SE;
M!#5\`S]J!#MK`S]N`S]K`T4[!$%0!$%.!$@C`TH[`TH_`THZ!4IN`TH\!RI&
M!$Y(`T]4`T]7!%1/!%1+`U,_!%1,`U-!`U-#`U-&`U-%!S1S!%E.!%E/!%E4
M`U9N`U9L!%E-!%E2!&=F!&1Q!7%;!&E5!2%]`R)@`R0^!21[!BDU!"@Q!"@R
M`RIZ!2MD!"M:`R]!!"M9!#!`!#`]`S0U!#`^`S0W!#`\`SEC`SE=!#5]`SE@
M`SEB`SED`SE?`S]O!#MM`S]T`T4_`T4^!$%5!$%4`T4]`T5!`TI!`TI``TI#
M`TI"`T]9`T]8!RI4`U-'!%13!%11!%E5`UM4!&1S!&=G`S0X!#8D`S]Z`S]V
M`S]Y`S]W!$%6`T5$`T5#`T5%`TI(`T]=`T]<`U-+`U-*`U(X!%E8`U9R`UE,
M`UM5`UU*`UM6`UU+!&E6`V%1`V)``SEF`S]]!E`Q`T5(!$@M!$@Q!$@N`TI*
M!$@T`TI+!$@S!F-[`T]>`T]A`T]?!%19`U-/`U-.!%E@`U9S`U9W!%18`U9V
M!%E=!%E?!%XU`UE-`UE.!%XV!T18!T1@!&%T!&%S`UM7`UM8`UM9!&1U`UU-
M!&E8!&E:!&E;`V!8`V%3`V$G`V%2`V(D`V)$`V)&!&E<!#8H!#8J!#MT!$Y,
M!&1[!$%:`T5*`TI-!$@X!$@W!%1=!%1<!%EB!&1\!&=N!7%C!&PS!#MY`T`C
M!#MV`T5-!$%=!$%?`T5,#T8R!EHH!$@Z!$A`!$@[`TI/`TI0!$@]!$Y/!%1C
M!%1A!%1@!%1D!%1B!%EC!%1H`U-2`U9\!%EH!%ED!SU6`U9Y`U9]`U9^!%X^
M!65^!%Y"!%X\!65S!65[!%X[!%Y!`UM<`UM;!&%W!&%[`UM:!&4C!&1^!6Y)
M!U8G!U8E!&=R!&=P!7%I!U8F`U]T!71B!&LL`V!:!&PT!&TM`V%4!&UE`V%P
M!&XB!$%A!$A#!$A!!$A"!$A$`U-4!%EK!T1W!%Y%`UE2!&%]!&%^!&=S!&E@
M`V!;`T5.`U<A`UMC`UMB`UU2!&=U!&LM`T`E`T`F`T`G`T51!%1J!%1I`UE3
M!&(B!&(C`U]U!#M[#T`M!$%E!$%D!40T!4L^!$A-`TI1!$A.`TI3!$A,!$A+
M!4L_!$A'`T]H!$Y9!$Y<!5)@!%1M!%1O`U-6!$Y=`U-@`U-7`U->!S51`U<E
M!%ES!SUI`U<B!%EW`U<C`U<D`U<G`U<I!%Y.`UE4!%Y)!%Y'!%Y+`UE7`UE5
M!%Y-!%Y,`UE:!&(G!&(I!&(M!&(F!&(L`UMD!&(E!&(O!&(H!&(K!&4O!&4Q
M!&4P`UU4!&=W!&=Y!&=V!&=\!&=[!U8R!&EC`U]V!&EB!&PY!7A(`V%5!#8K
M!#M^`T53!$%M!$%R!$%N!$A1!$A6!$A9!$A0!$A4`TI7!$Y@!$YA!%1V!%1W
M!%1S!%1T!%1U!%E]!%HB!%HA!%E\!%EZ!%E^!%Y1!T1^!%Y0!%Y2`UE=`UE>
M`UE?!&(R`UMG`UMF!&4V`UU5!&=^!&LP!&PZ`U<K`UE@`S0Z!#8L`T`I`T`J
M!#PD`T`H!#PE`T5=`T`L!$%W!$%T`TI<`T5>!$%U`T56`T55`T5:!$%Y!$%Z
M`TI8`TI9!$A;!RLX`TI:!$A<!F1``T]J!$YE!$YD!$YG!$YF!%1X!$YI!%1\
M!%1]!%1Z!%HG!%4B!%HH!%HJ!6`Q`U<M`UED!6`L`U<L!%Y8!%Y7!%Y;!%Y9
M!%Y:!&4Y!&(V`UMH!&4\!&4[`UU7`UU9!&@D!&@C`UY]!&@B!&EG!&EE`U]W
M!&EH!&LQ`V%6!&TP!&UG!&XE`T]L`U-G!%Y?!&(\!$A=`U<O!%4F`U<N`V%Q
M`T`M!41*`T5@!$A>`TIE!$A?`TI?`TIG`TIH`TIK`TII!$YO`T]Q`T]P!$YN
M`T]O!$YM!$YP`U-O`U-N`U-M!5HL`U-I!%4M!5HN!S8H!%HN`U<R`U<U!%HM
M`U<Q!%YG!6IN!%YB`UEH!%YH`UEI!%YC!%YE`UEL!&)!!&(_`UMJ!&)&!&)`
M!&)$!&)%!&5!!&5``UU=`UU;!&5'!6YF!6YM`UU<!&@I!&@J!&@K!&@M`U\C
M!7(M!&@H!UH^!71V!&EK!&EI`U]Z!&LS!&LT!&LR`V$K!V`N!V`M`V%7!&UH
M`V(G!&X_`V(W!&Y7`SEI`T`N!$AB`TIM`T]U!$YU!$YS!$YV`T]X`U-R`U-S
M!%4P!%4R!%4O!%4N`U<Y!%HQ!%HU!%HP`U<X!%HS!691!%YN`UMP!&)(!&)'
M!&5)`UU?!&@P!&EN!&LU!&P^!&TS`T`P!$(B!&)*!71Z!V1U`T`Q!3U2!F1>
M!$AJ!$AI!$AG`TIT!4M9!$Y[`T]Z!%4U!%4V!%HX`U<]!%H[!%YP!%YS`UEN
M!%YT!%YV!%YU!%YW!&).`UMR!&),!&5-!&5/!&5.!U%Y!7(_`U\F!&ER!&Q#
M!&Q!`V$M!7A2!&TU!V%J!&UI!&Y)!U%]!7)!`TIW`TIV`TT^`U-V!UI+`V%8
M`TIY!$\D!$\E!%4_`U-W!%Y^`UEP!%Y]!%Y\`UMS!69H`UUE!&EW!&EV!UI/
M!&Q(!&Q)!&Y8!3U4!$AM!4MD!$\H!$\T`U`A!RMJ!$\Y!$\R!$\K!$\I`U0G
M!%5$!%5"!%5(`U-^`U0H!%5!`U0F`U0D`U0B`U-[!%I``U=!!%\A!SY)!%I"
M`UER!%\C!69N!%\G!%\E`UEX!%\D`UEW!%\I!%\K!&)=!6LU!&)G!&)7!&)A
M!&)9!&)4`UMV!6LQ!&)B!6LK!&)@!&)D`UMX`UM[`UM\#V1R`UUW!&55!U(Q
M!&5;`UUL!U(S!&53`UUK`UUM!&@]`U\M`U\P!&@\`U\N`U\K!&@Z`U\I`U\O
M!&E]`U]]!&HA!&E\`U]\!&E^`V`D!&E[`V`A#VH_!&L\!&L]!&M`!&L[!UXC
M`V!G`V!D!7A;!7A6`V$P!&Q-!&Q.!7<D`V%:!&TY`V$Q!&XL!&XM!&Y;`T5E
M`TIZ`TI[`TI\`TI^!4MK`TI]!5,X!$\_`U`C!$]$!$\[!RMM!$]``U`H`U`I
M`U`F`TQC!$]!!%5.`U0O!%5-`U0P!%5/`U0K!%54!S9*!%5*`U0N!%57`U=+
M!%5+`U0Q!%55`U0T!%50!S91`U8S`U=,!%I1`U='`U=)`U=&!%I2`U=.!%I0
M!%\O!%\U!%\L`UHA`UE\!%\R!%\Q!6<F!%\X!&)J`UPA!&)L!&5A`UPH!&)O
M!6L\!%\V#V1U`UUX!&5L`UU]`UU[!&5J!&5D`UU\!U)"!&5B!&5K`UU^`U\T
M!&A`!&A"!&A!!7)C`U\S!&HG!&HL`V`H!&HF`V`F`V`G!&M%`V!K!7<L!&M$
M!7<T!&M'`V!J`V!I!&M(!&Q0!&Q2!&Q1`V$V!&Q4!&T]`V%<!V,W`V(J`V(^
M!&Y9`V)#!$]'!%\Y!U<I!&M-!7ES!4MM!$])!$]*`U`M`U0X!%58!S9<`UHC
M!&)R`U\Y`V$W`V$X!$AS!$AT`TLA!$]-!$]+!%59!%5<!%5:!%5=`U=/!%\\
M!%\[`UHG!&)Y!&)V!&)]!&)W!&)\!&A)!&A(!&A*!75-!75(!&M.`V$Y!UI]
M!&U!!RPQ!&5Q!&5R!S9E!%\]!&,A!&5V!&A+!&M2!&Q:!RPS!%5>!S9G!6]2
M!&5Y!6]4!&A,!&A.!&A-!&HQ!&M5!&U"!$(L`TLC!$]2!$]3!%5?!%I?!6$C
M!6=`!6<]!%\_!6=!!&,C`UPK!&5\!&8A!&5]!6]8!&A2`U\[!&M6!&Q;!&U$
M`V%>!&U#!&UO!%]``UPL!&HW`V$Z!%5A!&QA!&QB!%]#!%]"!%]$!&,F!&A9
M!%5B!%IC!%]%!&,G!&A:`V`J!&M8!&M;`UHL!%]&`UXC!U)G!6]A!&A<!&XQ
M!7MZ!%IF!6$M!%](!&,I!&,K!&8G!&8E!&8F`U\]!&AA!&H]!&H\`V!N!7=-
M!&QI!&QF!&QJ!&U,!&U+!&UP`V%V`V(K`V(R!&Y+!&Y,!&Y:!75A!6MI!6Q$
M!&AB!&AC!&U1`V(L`40A`40C!"$F`40D`R$F`R$E`B$F`40W`40U`40X`40V
M`B$G`41B`B$O`B$M`41A`41@!"$Y`45B`45A`45@!"%5`45C`45?`4<B`4<C
M`R)B`R)A`R)C!",U`R0_`4MD`R$A!"$G`R$L`40Y`41C`B$P!"$Z`41D`B%#
M`4AK`B4Q!"M>`R$B`40Z`41E`45D`B%$`R=``R$C!"$B!"$C`B$A`40E`40\
M`R$P`B$H`40]`R$N`41F`45E`45G`45F!"(G`4<D`4<E`R-%`4ME`RLB`5-]
M`40B!"$D`B$B`40F`40_`40^`R%&`R%%`R)D`4<F!"(H`R1``4MF!"4Q!"4P
M`RLC`5AQ`C-.`SEL`SEN`6,J`D%6`D%7`R$D`40G`R$M`41H`R)E`4MG`40H
M`B$I`41``R$Q`41I`41K`B$Q`41L`41J!"$[`R%L`R)F`4<G`4MH`R1"`R="
M`4MI`4]G`2<H`41!`41M`R%'`4<H`4<J`4<I`4AL`4MJ`4MK`4]H`4]I`RLF
M`RLE`RLG`RLD`5-^!#8N`D%8`T`S`FU$`40I`R$R`R$S`41O`41N`B$R`41P
M`41V`R%)`41Q`41R`B$T`B$S`41T`41U`R%,`41S`R%+`R%*!"$\`45J`45K
M`45L`45M`45I`45P`B%*!"%;`B%&`B%)`45Q`48C`R%M`B%(!"%:`45N`45O
M`45H`R%R`R%P`B%%`B%'`R)O`R)H`4<W`B%O`4<T`4<X`B%Y`B%M`4<U`B%Q
M`R)K`R)G`R)V`4<V`R)N`4<Y!"(M`4<K`B%P`4<Z`B%T`R)M`B%X`B%U`R)L
M`R)T`B%R`4<L`4<N`4<[!"(J`4<P`B%J`4<S`4<Q`4<R`B%Z`B%W`B%N`4<O
M`R)P`R)W`B%K`4<M`R)U!"(N`R)S`B%S`B%V`R)R#R%Q`B%L`B,H!",Y`4DD
M`4AU`R10`R1(`B,I`4AR`R1/`4DF`R1&`4AZ`R1%`4AY`B)[`4A]`4AX`B,B
M`B,J`R1.`B,F`R1)`4A[`R1+`R1#`4A^`4AO`4DI`B)]`R1$`R1,`B4]`4AM
M`4DE`4AN`4AV`4AW`B,D`B)^`4A\`4AT`B)Z`4AP`B,G`4DG`4DJ`4AS`4DB
M`4DH`4AQ`B,E`4DC`B,K`B)\`4DA`B,A`V1(`B,C`V1)`4MY`B4_`B5+`4MQ
M`R='`B5,`4ML`4MV!"4^`R=/`4MO`B4Y`4MW`B4X`B4\`B5#`B5!`4PA`4MZ
M`B4S`B4U`4M\`4MP`B4V`B5"`B5)`4MU`B4[`B4T`4MT`B4W`4MX`B4Z`R=$
M`4MS`R=1`4MN`R=(`4M]`B5$`4M^`B5(`R=#`B5&`B5*`4M[`B4^`B4R!"4V
M`B5``4MR`B5%`4MM`B5'`R=,`R=)`R=+`R=*`R=-#R5$`4]X`4]L`RLM`RLN
M`BDB`BDJ`RLV`4]K`4]S`5`A`RLL`BDP`BDN`BDI!"@X!"@^`RLK`4]M`BDO
M`BDE`4][`4]R`4]Z`BA^`RLR`BDL`RLO`BDC`4]V`BDD`RLS`BA]`4]]`4]P
M`4]Y`4]O`RLH`BDA`BDF`RLI`BDM`4]W`4]T`BDH`4]\`BDK`BDG`4]Q`4]^
M`4]U`4]N`4]J!"@_`RLU#RDM`RLT`V1*!"@]`BDQ`50Z`50D`R](`50T`R]-
M`50Y`BUQ`BUP`BUU`BUV`50G`R]$`50P`R]8`R],`R]6`50]`R]&`50Q!"MB
M`R]+`R])`R]'`BUJ`50J`BUK`R]/`50_!"MD`50V`50A`50B`BU^`5DD`R]3
M`50O`50N`BUL`50R`C->`50I`BUW`50X`50W`50M`BUO`BUX`R]%`BUI`50L
M`BUY`50U`BUM`50C`R].`50F`50E`BUZ`50S`50H`50\`50^`BUT`50[`R]1
M`BU\`BUN`BU]`R]#`BUR!"MA`BU[`R]0`BUS`R]4`R]5`50K`V1+`C-F`C-:
M`S0\`5AV`S0_`C-?`C-E`5AU`C-8`5AY`C-<`C-5`5AW`C-9`5A\`5DC`S1$
M`C-J`S1!`C-4`S1"`5A]`R]7`C-I`S1'`S0]`5AX`C-;`5AT`C-6`C-2`C-@
M`C-3`C-1`C-=`C-C`C-D`5AZ`S1`!#!'`CH_`C-A`C-0`C-B`S1+`5DF`C-G
M`5DE`C-/`S1#`C-7`C-H`5DA`5A^`5A[`5DB`S1,`S1*`5AR`S1%`S1&`5AS
M`5XN`SEU`CI"`CH[!#8T`5XK!#8S`CI#`SEQ`SER!#8V`CHY`CH\`5XJ`CH]
M`SEO!#8Q`5XM`CI!!#8\`CHW`CHV`5XO`SEP`5XP`5XL`5XQ`CHU`CI``CH^
M`CHX!#8Y!#8P!#8Z`5XI`CHZ`V1-`T`Y`T`\`6,Q`6,K`D%<`6,T`D%B`D%E
M`6,M`6,N`D%?`6,L`D%H`6,R`D%I`T`Z`D%D`6,S`T`W`D%9`6,P`D%:!#PI
M`D%C`D%A`T`]`D%=`6,O`D%;`6,U`D%@`D%G`D%>`D%F`T`V`T`^`6=\`6=Y
M`T5K`6=Z!$(M`DDA`DAW`6=X`6=U`DAX`T5N`T5L`6=W`DA[`T5M`DA]`T5V
M!$(U`DDF`T5P`T5U`DDE`DA^`6=T`DAV`6=R`DAY`6=]`DA\`T5Q`DDB`6=V
M`6=S`DDD`DDC`6=[`DAZ`T5T`6PC`D]4`TLI`D]1`6PD!$AY`6PB`TLK`D]8
M`D]5`D].`6PA`TLM`6PE`D]/`6M^`6PH`D]2`D]3`6PF`6PG`D]9`D]6`D]7
M`TLL`TLG`V1.`7`S`E9#`7`P`E9``7`R`7`T`U`Q`E9!`7`Q!$]:`E9"`U`U
M`E8_`U`P`U`T`7-!`EQ)`7-"`EQ'!%5E`EQ(`EQ&`EQ%`U1!`U1``EQ*`7-`
M`U`S!%5I`F%$`F%%`U=2`D]0`F%#`7-#`7@K`F4W`F4X`UPR`7IB`7IC`FM/
M`FM.`7M8`7M7`FY]`V!O`40J`41"`41X!"$]`41W`45S`45R`4<^`4<]`4<_
M`4<\`R)X`4DL`4DK`4DM`R14!",[`R13`R11`4PC!"4_`4PB`4PD`R=2`5`B
M!"A``2)Y`BXA`2)Z`5DG`2)\`2)[`CI$`SEV`2)]`6=^`2)^`UXE`40K`R$T
M`41Y`4=``4PE`RLW`40L`41\`41Z`41[`4=!`R)Z!"(T`4DN`4PG`4PF`4PH
M`RY[`51``T`_`V13`7`U`R$G!"$^`R%-`R%(`R%.`B$N!"%2`45T`45U`R%X
M`R%Y`4="!"(V`B,L`R=5`5`D`5`C`BXC`BXB`5DH`R$H`41]`B$U`R%Z`R17
M`B5-`RLY`5`E`R];`51#`R]9`51!`51"`R]:`S1-#T9<`7`V`2<O`45V!"%>
M`4=#`B%[`R)^`R)]`R)\`R19`4DO`4DP`R1:`B,M!",]`B5.`4PI`B5/!"5`
M!"5#`RL[`RL]`RL^`BXE`BXF`51&`R]>`BXG`R]?`BXD`51'`51%`51$`BXH
M`S1/`C-K`S1.`SE]`SEZ`CI%!#8_`SE^`D%J`DDG`TLO`TLN`TLP`6PI`7`W
M`E9$`U1"`40M`40[`R$O`R$U`R%1`R%[`R,B#R)9`R1;`R=9!"5%`5DI`5XS
M!D9E`6@A`T5Z`B$C`41^!"%@`45Y`45W`45X`4PJ`R=:`40N`40O!"$J`41#
M`R$V`R%2`44A`44B`44C`B%,`45Z`R%]`B%+`4='`R,E`B%]`4=%`4=&`B%\
M`R,D`R,F`4=(`4=$`R,G`B,N`4]/`B,O`R1?`R1A`B,P!"-``R1<`4DR`4DQ
M`R1>`R1=`4DU`4DS`4DT`R1@`4PP`R=;`4PO`B54`B51`B52`R=>`B50`4PQ
M`4PM`4PL`R=?`4PN`4PK`R==!"5.`V1/`4PR`5`G`BDR`RL_`B53`5`L`RM`
M`BDS`5`H`5`K`5`J`5`I`5`F`RM#`BXK`R]H`51*`BXN`51(`R]E!"MN`R]B
M`BXJ`51+`51)`51,`BXL`BXM`R]@`BXI`BXO`R]F`R]A`R]C#RXM`R]D`S10
M`5XW`5DJ`C-L`C-N`C-M`C-O`5DK`SHC`5XT`SHA`5XU`5XV`S11`6,W`D%L
M`T!!`D%K`D%M`D%N`6,X`T!``6,V`DDH`DDI`6@C`6@B`DQA!$DE`TLQ`6PJ
M`6PK`6PL`6PN`D]:`D];`6PM`TLR`U`V`7`X!$]D`7`Y`U`W!%5M`F4Y`FM1
M`FM0`FY^`V`L`40P`R$W`R%4`R%3`45\`45[`4=)!")"!"(_`B%^!")!`R,H
M`4DW`4DX`4DV`4DY`B,Q`B,R!"-&!"-'!"-(`R1C`R1B`R=A!24Z!24W!24X
M`R=@!24[`4PT`B55!"50`4PS`R=B`BDT`5`P`BDU`5`O`RM(`RM&!"A)`5`M
M!"A+`5`N`RM'`R]O`BXP`R]L`R]J`R]M`R]N`5DL`C-Q`S12`5DO`C-P`5LK
M`5DN`5DM`5XZ!39J`5XY`5XX`6,Y`T!%`T!$`6,\`6,]`6,[!#P\`6,Z`T!&
M!41G`DDJ`T8A`DDK!41C`T5^`TLS`D]=`6PO`D]<`TTL`7`Z`EQ+`7-$!5-B
M`F4Z`7EA`2<T`41$`44D`B$V`R%5`44E`44F`R%6#R$P`R(C`R(B`45]`45^
M`R(D`4=*`B,S`B56`B57!"51`5`Q`BXQ`5DQ`5DP`CI'`CI&!E!T`U`X`40Q
M`44G`48A!#!>`5DR`B$D!"%E`B%-`48B`R(F`B(B`4=,`4=+`B(A`4DZ`V10
M`R1E`RM)!"A.!"A0`51-!"MX!#!?`C-R`6,^`DDL`6@D`T8C`TLT`E9%`U1$
M`UPT`FAJ`R$I`44H`R%7`R1F`B58`BDV`5DU`5DS`5DT`40R!"$P`41%`20_
M`44K`R%9`44J`44I`48E`48D`R,J`B%.`B(C#R(L`R,K`R,M`4PX`4PU`4PW
M`4PV`R=C`5`R`RM*!#!@`5X[!&8P`40S`R%:`44L`R(G`48G`48F`B,T!"--
M`V11`4PY`RI<!#!D`R$J!"$Q`B$W`R(H`48I`48H`4=-`4=.`B,U`4D[`R1G
M`4D\`R=E`4PZ`4P[`4P\`R=F`5`S`BDW`RM+!#!E`51.`T!'`B$E!"%$`44M
M`R%;!"%G!"%F`R(I`B(D`R,O`B,V`B,W`B59`R=G`B5:`BDY`BDX`BD[`BDZ
M`5`T`V12`C-S`510`BXR`51/`S14!#!H`CI(`5X\`SHH`CI)`SHG`T!*`T!)
M`T!(`DDM`6@E`T8E!#Q``T8F`TLU`6PP`U1%`F4[#VTN`R$K`R%<!"%%`B$X
M`R(J`48J!")(`R,Q!"59`R=I`R=J`5DV`S15`SHI`40T`41&`44O`44N`R%>
M`44P`R%@!"%I`R(K`R,S!"-/`4P^`R=K`4P]`4P_`RM0`RM/`5`U`RM.`RM-
M!C5X`511`T!+`E9&`78[`41'`48L`48[`48V!"%L`48Q`48P`48W`48U`48N
M`48\`48O`48K`48Z`48Y`48X`48M`R(Q`48T`R(M`R(N`48S`R(O#R%0`48]
M`48R!"%J`R,U`R,W`4=4!"),`4=:`4=6`R,Y`4=<`B(E`4=9`4=/`4=2`4=5
M`4=1`4=8`4=;`4=0`4=3`4=7`4==`R,Z`R,[`R,T`B-``B,]`R1V`4E)`B,^
M`4D]`4D_`4E7`4E2`R1Y`R1^`R1U`B-%`B,_`4E!`4E#`B-$`4E*`B,Z`4E6
M`4E8`4D^`4E/`R4D`B,X`4E5`R1W`4E&`R1[`4E0`4E1`B,Y`4E.`4E,`R1P
M`4E-`4E3`B-!`4E``R4A`4E4`B-#`4E(`4E%`R1S`B,\`4E$`B-&`4E'`R1\
M`4E+`R1X`R1T`R1M`4E"`B-"`R1]`R4B`B,[`R4C!"5D!"5C`R=N`B5K`B5J
M`4Q1`B5M`B5O`B5D`B5G`B5N`4Q2`R=T`R=X`B5A`B5E`R=U!"5?`B5I`BE*
M`4Q-`BE.`4Q``B5F`4Q!`4Q.`4Q'`4Q#`R=Q`B5B`4Q&`4Q+`4Q4`B5C`B5<
M`4Q%`B5=`B5?!"5@`4Q(`R=L`4Q*`B5;`B5@`R=P`R=Y`4Q3`4Q/`B5H`4Q5
M`R=S`4Q,`B5>`4Q)`R=O`R=W`4Q$`4Q"`B5L`4Q0#R5Q`RM<`RM=`BE)`BD]
M`BE,`RM7`RM9`BD_`5`\`5!*`5`X`5!)`5!!`5!&`5`V`BD^`BE$`5!%`BE0
M`5!'`RM;`5`]`RM4`RM>`BE&`BE#`5`[`RM1`BD\`5!(`BE+`5!``BE-`5!+
M`5`W`5!"`5`_`BE!`5!#`BE'`BE(`5`^`5!$`5`Z`RM5`V14`RMC`RMA`5`Y
M`BE``RM3`BE%`RM8`BE/`BY&`51>`BXT!"PM`BXY`517`51B`BXW`512`51<
M`51A`BX^!"PF`51=`51@`R]W`S`A`BY!`518`BXX`R]T`R]X`S`B`BY$`BY%
M`R]Y`51:`BY#`516`51E!"PI`BX[`R][`514`R]Z`BY(`BX\`BY``519`51D
M`BX]`51?`BY"`BY)`C0D`R]S`BY'`51F`513`BX_`BXV`R]V`51;!"PH!"PN
M`BXU`R]^`S`E`BXZ#RE4#RY"#RY*`BXS`51C`V<A`S1?`C-Z`S1H`5E)`C0J
M`5E'`5E$`C0A`5E``C0E`5E+`C-Y`C-^`C-]`515`5E&`C0H`S1F`C0K`C-V
M!#!W`5Y.`S1G`C0L`5E,!#!R`5D^`5D[`C0C`5DX!#!T`C0I`S1;`5D_`C0M
M`S18`C-W`C0G`5E"`C-X`C-[`C0B`S1B`S1A`5E#`5E!`5E-`S17`SHV`S1D
M!#!K`5E(`S1>`5D\`5IV!#!Z`5D]`C-\`5E*`5E%`C0F`5DZ`S19`5DY`V17
M`V16`V<B`V15`C-T`C-U`CI.`SH\`5X]`5Y``CI9`5Y4`CI<`5X^`CI5`5Y$
M`5Y*`6%#`SHQ`SHX`5Y(`CI2`5Y5`5Y!`5Y)`CI:`D%\`CI?`CI3!#9<`CI*
M`CI7`CI1`5Y'`CI=`SHN`SHJ`5Y#`5Y7`5Y0`SHS`5Y%`5Y"`SI``5Y-`SHT
M`CI>`CI0`CI6`CI8`CI,`CI;`5X_`CI+`SI"`5Y&`5Y6`5Y2`CI-`5Y,`SH[
M#SEQ`5Y3`5Y/`5Y+`SHO`CI4!D<I`V<C`5Y1`D%Z`D%V`T!1`D(G`D%O`D%X
M`6-,`6--`6-%`D(C`6-/`D%T`D%S`D%Q`D(E`6-#`D%]`D%R`6-&`D%[`6-!
M`D%W`D%^`D(B`T!.!#Q+`D(F`6-*`D%P`6-$`D%U`SHK`6,_!E%#`6-+`D(A
M`6-'`6-(`6-.`6-"`2,A`6-``D%Y`T!,`V<E`6-)`V<D#T!B`D(D`V18`6@U
M`6@P`T8N`DD\`DDX`T8H`DDR`6@J`6@F`DD[`6@G`DDU`DDW`T8I`DDZ`T8V
M`6@L`T8L`6@S`6@M!$)7`T8J`DDP`6@N`6@O`DDS`6@T`T8T`DDQ`DDV`6@K
M`DDO`6@Q`6@I`T8S!$)+`6@H`DDT`DDY`T8Q`6@R`V1:`V19`T90`DDN`T8P
M`6PW`D]N`TM!`D]K`TLX`6PQ`6P]`6P^`TL]`6PT`D]I`6PV`D]A`6P\`TM$
M`D]M`6PS`D]O`6PR!$DQ`D]J`D]L`6PU`D]H`D]B`D]?!$DN`TL^`CI/`D]E
M`TLW`D]>`D]D`D]C`TL[`D]@`TM#`6PY`TM%`TM``T8U`TL\`6PX`TLY!R%C
M`TL_`6PZ`D]F`7`[`D]G`E9/`U`_`E9(`U!``7!'`E9,`7`_`7!#`E9+`U`[
M`7!"`7`^`7!!`7`\`7!&`E9-`E9)`7!%`E9'`7!$`E9.`E9*`6P[!$]Q`7!(
M`E90`7!``7`]#U-=`U`]`U1(`EQ2`EQ4`7-&`EQ5`EQ3`EQ1`EQ0`7-(`EQ/
M`7-)!%5T`U1)`U1'!%5X`EQ-`EQ.`7-%`7-*`7-'`V1=`V1;`EQ,`U=;`78\
M`U=:`F%(`F%&`F%+`F%)`U=8`F%'`F%*`U=9`U=7`U=<`7@L`F4^`F4_`7@M
M!%]-`F5``F4\`F5!`F4]`78]`UHM`V1>!&,Q`FAK`FAM`7ED`FAL`7EC`7EB
M`V<F`V<G`V1<`UXF`7EE`FM3`FM4!&8T`7IE`7ID`7IF`FM2`V<H`FU&`FU%
M`U]``7M9`7M;`7M:`FU'`7PT`G`T!&I$!&I#`7Q=`V!Q`G`S`G!\`B$J`R%W
M!"%O`48_`48^!"%M`4=@`4=?`B(G`4=>`B(F`R,^`4E;`B-)`R4L`B-(#R-0
M`R4F`4E9`4E<`R4K`R4J`B-'`R4I`4E:`R5(`R4G`R4H`R@B`B5P`R=]`B5Q
M`4Q6`R=\`R@A`R=[`5!,`RME`BY*`BY+`51G`51H`S`G`C0O`5E.`5E0`C0N
M`5E/`CI@`5Y8`SI$`SI#!#9H!#Q2`6-0`6-1`D(H`T!2`6@W`T8W`6@V`D]P
M`E92`E91`U]!`G%:`41(`B$Y`R%A`B%/`B%0`R(T!"%P!"%Q`4=C`4=G`B(I
M!")1`4=E`4=D`B(H`4=F`4=B`R-!`R-"`4=A`B(J`R,_`R-``4EF`R4Q`R4^
M`4EC`R4P`4E?`B-*`R5``R4V`R4O`B-+`R4\`4EA`R4M`B--`4E=`B-.`B-,
M`4E@`4EB`4EE`4ED`4E>`B-/`R4R`R5!`R5"`R4S`R4X`R4W`V1?#R-2`R4U
M`4Q;`B5^`R@E`4Q=`R@C`4Q<`R@F`B8A`4Q:`4Q9`B5U!"5I`B5T`R@H`B5R
M`B5W`B5V`B5S`B5\`B5]`B5Z`B5X`4Q8`R@I!"5F!"5H`B5[`4Q>`B8B!"5E
M`R@J`B5Y`R@D`5!-`4Q7!"5N#R8S`V1@`5!.`BE5`RMI`RMH`BE;`RML`RMG
M`RMJ`5!4`BE9`BE?`RMQ`BE6`BE:`BE<`BE>`BE8`RMP`BE7`BE2`BE3`5!/
M`RMK`5!1`5!0`BE4`BE=`RMM`RMR`RMN!"A@#REJ#REQ`RMF`5!3!"A>`BE1
M`BY5`S`J`BY4`BY9`BY0`S`P`BY3`BY2`S`O`BY6`S`X`BY:`51I`51L`S`T
M`S`U`BY1`BY7`S`S`S`H`S`W`51K`BY,`S`K`5!2`C0]`BY8`S`V`BY/!"PS
M`51J`BY.#RY<`S`R`C0T`S1N`S1Q`5E1`5E5`C1$`C0R`C1``5E6`C1"`S1R
M`C1(`S1T`C1,`S1I!#![`C1#`C0W`C0_`S1K`C1-`C1+`C1!`C0\`C0U`CIH
M`C0S`5E:`C0Z`5E;`5E7`C0P`C1&`C0X`S1O`S1U`C0V`C1)`5E8`S1V`C1/
M`5E2`5E4`C0^`C0Y`51M`5E3`C0[`C1*`C1.`C1%`V1A`C1'`V1B`V1C`C0Q
M!#9I`SI*`CIC`SI%`CIL`CIK`5Y@`CID`SI'`5YA`5Y?`SI0`CIF`5Y<`CIJ
M`SI,`CIE`CIG`CIA`5Y:!#9O`CIT`CIS`CIP`5Y9`5Y=`5Y>`BY-`CIM`5Y;
M`5E9`CIO`CIB`CIR`CIQ`SI.`CIU`SI)`D(V`SI+`CIN#SE]#SE^!#Q7!#9M
M!#9Q`V1D`CII`D(N`6-;`6->`6-9`D(M`D(Q`D(L`T!7`6-3`6-=`D(I`6-7
M`D(P`T!;`6-5`6-4`D(S`6-6`D(U`T!6`D(R`6-2`T!>`T!<`T!8`6-<`D(W
M`D(K`D(T`T!=!#Q3`D(J`T!:`T!9`6-8`T!4`6-:`D(O`D(X`T9#`T8^`DE$
M`6@X`DE*`T9"`T8\`6@]`DE&`DE-`DD^`6@_`6@Y`DE#`6P_`DE"`DE+`6@Z
M`T8]`6@^`DE!`DE'`DE,`DD]`6@\`DE%`T8Z`T9%`DE)`DE/`DD_`DE(`T8X
M`6@[`DE.`T9!`T9$`T9``DE`!$)9`V1E`6Q#`D]R`6Q!`6Q``D]T`D]Y`TM&
M`D]U`TM0`D]X`6Q&`TM1`7`N`6Q%`TM+`D]Q`D]W`T8_`6Q$`D]V`TM-`D]S
M`TM)`6Q"`TM/`TM,`TM'`E97`U!*`E99`E94`7!*`E96`U!+`7!)`E98`U!(
M`U!,`7!,`E9:`7!+`E93`E95`U!)`U1+`7-.`EQ8`U1,`7--`EQ9`7-,`EQ7
M`7-+`EQ6`78_`78^`F5"`F5$`UHO`F5#`7@N`7@O`UHN!T9%`7@P`FAN`7EF
M`UXH`F\B`F\A`7Q>`41)`44Q`R-#`4EG`R5%`R5#`R5$`R@M`BE@`RMW`S1W
M`5YB`5YC`SI2`D(Y`6A``DE0`D]Z`V1F`U!-`R$Y`B$Z`R(U`R-$`B-0`RMZ
M`RMY`R$Z`R5&`B8C`BEA`BY;`51N`T9&`V5@`F5%!%]2`7IG`41*`49``B%1
M`R(V`4=H`4=I!")2`4Q?!"5P`S1Y`5E<!3<]`6A"`T!?`6A#`6A!`TM3`41+
M!"%)`44R`44T`44S`B$[`44U`49!`B%2`R(X`49"`R(W!"%R`R(Y!")3`R-'
M`4=J`4=K`B(K`R5)`4EH!"-B`B-1!"5U`4QC`B8D!"5R`4QA`4QB`4Q@`BY<
M`R@N`R@O`V1G`5!8`5!7`5!9`5!6`RM\`BEB`4QD`5!5`51O`51P!"PX`51Q
M`S1[`C10`S1\`S1]!#$F`5YD`CIV`5E=`SI3`SI4!#9Y`T!@`6-?`T!A`6A%
M`6A$`DE1`T9(`6Q'`7!-!$][`F%,`FU(`F\C`41,`49#`R([`49$`B(Q`4=M
M`4=P`R-+`B(O`B(M`4=O`B(P`B(R`B(L`4=R`4=Q`4=N`4=L`B(N`R--`R55
M`4ES!"-G`R5,`4EP`B-6`B-9`B-8!"-I`4EJ`4ER`R5+!"-J`4EO`B-5`B-3
M`4EN`R56`R53`R5.`4EI`4EL`R51`B-4`B-;`B-7`4EM`4EQ`4ET`B-2`B-:
M`4EK`RA!`R@S`4QI`4QQ`R@X`B8P`B8I`4QR`B8T`B8E`B8L`RA%`RA``4QH
M`B8F`4QF`B8M`B8Q`4QE`R@]`B8R`B8K`R@W`B8N`R@U`4QT`4QK`B8U`B8S
M`R@_`4QP`4QN`B8J`4QM`B8H`B8G`4QL`4QJ`4QS`4QO`4QG`RPF`B8O`RA&
M`5!;`RPM`5!B`BEP`5!:`BEH`BED`RPA`BET`BEC`RPL`5!=`BEM`5!@`5!C
M`RPN`5!>`BEQ`5!A`RPC`51X`BEW`BEE`RPD`RPE`BEG`BEN`BER`BEV`BES
M`BEL`BEO`RPK`RPI`BEI`5!E`BEK`BEJ`BEU`5!<`BEF`5!D`RPJ`5!?`RPH
M`51^`BYD`S!``51]`RPG!"Q``BYB!"P^`51R`S!/`51W`S!*`BYA`BY>`BYC
M`51S`BY=`S!.`51V`51T`S`^`BYE`51U`51Y`S`[`S!%`51Z`S!(`51\`S!2
M!"PY!"P]`51[`S`\`S4B`S4X`BY?`BY@`S!-!C97`S!+`BYF`C17`5E>`CLF
M`C16`C1I`S4H`S4D`5ED`S4Q`C1G`S4S`5EC`5E?`C1P`C1@`C1C`S4N`5EG
M`C1M`C1E`5E@`5EH`S4J`C1J`C1H`S4O`S4[`C19`C1N`C1B`C1=`S4Z`C13
M`C1O`C1?`C12`S4Y`5EF`C1D`C1Q`C1A`C15`C1:`C11`S4G`5EE`S4\`C1>
M`C1;`5EA`C14`S4P`C1L`5EB`S4K`C1<`C18`S4I`S4T`C1K`S4R#S-S`S4W
M`S4U`5YE`CI]`SIU`CIZ`CLM`CLA`CLN`SI\`5YG`SIC`SIA`SI8`CLJ`CLG
M`SI;`SIW`SIR`SI9`SI@`CLH`CLK`CLO`SI[`C1F`CLQ`D)-`SIF`5YH`CLR
M`CIX`CLD`SIB`CLI`SI<`SI>`5YF`5YI`CLP`CLS`CI\`CIY`SIS`SI:`CI[
M`SI7`SIZ`CLB`CI^`5YJ`SI6`CLL`SIY`SIX`CLC`CLE`CIW`D)!`D(_`6-H
M`6-F`D))`D)``D)*`D)&`D(^`D),`D(]`D)$`6-E`6-D`6-C`D)"`D)'`6-@
M`6-G`T!G`D([`T!F`D)%`D(Z`D)#`6-A`D)(`D(\`6-B`D)+`T!D`SIK`T!J
M`V1H`V1I`DE5`6A*`6A)`6A+`DEA`DE7`DE=`DE2`DE@`DE?`DEC`DE<`6A&
M`DE;`6A,`T9,`DE4`6A'`T9*`DEB`6A(`DE6`DE9`DE>`DE8`DE3`T9/`T93
M`DE:`D]\`6Q+`E`A`D]^`E`C`E`E`TM<`6Q)`TM8`D]]`TM4`D][`TM>`E`F
M`E`D`E`B`TM6`E`H`TM:`E`G`6Q-`6Q(`TM;`6Q*`6Q,`TM=`TM?`E`I`E9A
M`U!0`U!3`E9@`E9?`U!1`E9B`E9;`U!/`E9<`E9D`E9=`U!4`7!.`E9F`U!.
M`E9E`E9>`U!6`EQ=`7-1`EQ;`EQ@`EQ?`E9C`U10`7-0`U1.`EQ>`EQ:`EQB
M`EQA`7-/`U12`EQ<`U1/`7!/`U11`U13`79``UHQ`U=A`U=>`F%-`F5&`F5'
M`F5(`7EG!&,T`UPV`7EH`UPY`FAO`UPZ`FM6`FM5`UXI`U]"`FU)`FU*`F\D
M`G`U`V!S`41-`41.!"$R`41/`44V`49%`B(S`4=S`4=T`4EW`4EX`4EV`4EU
M`4QU`RA(!"8B`B8V`4QW`4QV`B8W!"8C`V1J!"AN`5!F`RPO`54A`BYG`C1S
M!#$L`5EI`5YL`C1R`5YK`T!Q`6A-`T!R`DED`7!0`U!7`7-2`EQC`UHT`7EI
M`UP[`7M<`R$[`B%3`R(]`49&`B%4`4=W`R-0`4=U`4=V`4=X!"-O`4EZ`4EY
M`R5:`B-<`4E[!"8E`B-=`B8X`RA,`B8Y`RA*`4QX`4QZ`4Q\`4QY`4Q]`4Q[
M`RA.`RA+`RA-`5!J`5!G`5!I`5!K`5!H`BYH`BEX#RHY`RPR`BYJ`BYI`54G
M!"Q&`54C!"Q)!C9F`54D`54F`54H`54E`S!7`54J`54I!"Q(`S!6`S!5#RY^
M`5EN`C1U`C1T`5EM`S5!`5EL`5EK`5EO`5EJ`S4_`CLY`CLV`5YN`CLU`CLZ
M!#<D`5YP`CLX`5YM`5YO`CLW`SI^`D).`T!T`D)/`D)0`T!U`T!V`T!S!#QN
M`6A.`6A6`DEE`6A0`6A4`DEF`6A5`6A1`6A2`6A/`6A3`6Q0`CLT`6Q1`6Q/
M!$E$`6Q.`E9G`7!1`EQD`EQE`UHU!%]5`7@Q`7EJ`UXJ`410`R(^`4=Y`R5>
M`R5<`R5=`RA0`5!L`BYK`54K`S!8`S!9`5ER`5EQ`5EP`5YQ`5YR`CL[`6A7
M`7!2`411`B$\`44W`B%5!"%S`R(_`B(T`4=Z!")<`R-2`RA1`4Q^`RPT`SLD
M`D)1`T!X`V4E`412!"%+`44X`B(U`B->!"8I`B-?`R5?`4E\#R54`RPU`CL\
M`5YS`D)2!$E)`U14`7-3`413`41G`44Y`B%6`49'`R-4`4HB`4HA`4E]`4E^
M`B8Z`4TB`4TC`B8[`4TA`RA4`RA5`5!P`BEY`5!O`5!M`5!N`54N`54L`S!:
M`S!;`BYM`54M`BYL`V1K`54B`C1V!#$U`S5#`5ET`5EU`SLF`SLE`5ES`S5$
M`6A8`DEG`6Q2`6Q3`E`J`7-4`F%.`F%/`UHX`7IH`G`V`B$K`44Z!")?`414
M`B%8`B%7!"%V`V1L`R-5`4=[`B(W`B(X`B(V!")@`B(Y`R-:#R)'`R5A`R5F
M`B-G!"-Z`B-B`B-D`B-F`B-C`4HF`B-@`R5B`B-A`4HC`4HD`B-E`B-H`4HE
M`B-I#R-\#R-X`R5C`B9)`RA=`B9#`B8^`4TE`B9&`B9$`B8]`B9*`B9-`B9(
M`B9!`4TG`B9'`4TH`B9"`B9%`B8\`B9``B9,`4TI!"8O`4TJ`RA>`B8_`B9+
M`4TD`4TF`RA<`RA?`RA7!"8T`RA8`BHL`BHE`BHK`BHD`BHF`BE^`BE\`RP_
M`BHM`BHJ`BEZ`RP[`5!R`BHH`BHI`V1M`BHG`BE]`BE[`5!Q`BHC`BHA`RP\
M`RQ"`BHB`BHN`RP^`RQ!`RQ#`RP]`54S`S!C`54R`S!?`BYN`54O`BYP`S!D
M`54T`BYQ!"Q@`S!A`54W`S!B`54U`BYR`BHO`BYT`S!>`54Q!"Q<`54P!"QA
M`BYO`BYS`54V`5EW`5EV`S5+`S5(`S5'`C1X`C1\`C1^`5EX`C4C`S51`5E\
M`C4E`S52`5E^`S5/`5EZ`5HD`S55`5HA`C1Z`5EY`SLK`C1Y`C1W`C4G`C1[
M`S5&`5E[`C4F`5HB`C4B`C4A`5HC`C1]`5E]`S5.!CYV`S5*`C4H`S54`C4D
M`CM+`CM2`CM'`5YV`CM#`CM3`CL]`CM0`CM.`CM(`SLV`CM1`CM*`SLH`CM"
M`CM4`CM``CM-`CL^`SLG`CM5`SLW`5YW`SLJ`CM/`D)5`CM!`5YT`SLN`CM%
M`SLT`5YU`CM$`CM)`SLS!#<U`CM&!#<O`SLQ`CM,`SLM`D)9!#QY`T$A!#Q[
M`D)<`D)4`T!\`D)6`T!Z`D);`D):`6-I!#QU`CL_`D)8`T!Y`T!]`6-J!#QT
M`D)3`D)7!#Q\!#QX`V1N`DEN`T9<`DEU`DEL`T94`DES`DEJ`DER`DEV`DEI
M`DEM`DEH`T96`6A9!$,L`DEK`6A:`DEQ`DEP`DEO`T99`T9:`DET`V1O`TME
M`TMF`TMC`E`N`E`P`6Q5`E`Q`TMK`E`L`TMG`E`K`E`U`TMI`E`S`6Q4`E`V
M`E`M`E`R`E`T`E`O`TMJ`TMH`V1P`U!8`E9K`E9P`E9J`E9O`U!;`E9H`E9R
M`E9N`E9S`E9M`E9I`E9Q`U!:`E9T`E9L`V1Q`EQF`7-8`U17`7-6`U19`7-5
M`7-7`U15`V1R`F%0`U=B`F0^`F5)`UHY`FAP`FAQ`UP]`7EK`UP\`FM7`UP^
M`7II!&8[`FM8`UXM`FU,`7M>`U]#`7M=`FU+`7PU`V`P`F\E!&MH!&I&`R$\
M!"$L`415`4=\`B(Z`B-J`4M6`5HE`S57`TML`416`49*`49)`49(!")C`4HG
M`54X`D)=`417`418`419`44[`R5G`RA@`5!S!"QD`BHP`RQ%`RQ$`5YX`41:
M`B$]`R%C!"%,`49+`49,`B%9`4=]!2)<`R-<`R5H`B-K`R5K`4HH!"0C`B-L
M`4TP`RAB`RAA`B9/`4TN`4TM`B9.`4TK`B90`4TL`4TO`5!T`RQ&`5!V`BHT
M`BHQ`BHR`BHS`BHU`5!U`BYV`BYU`S!F`54Z`S!I`54Y`S!H`S!J`S!G`S5;
M`5HH`C4J`S59`5HG`5HI`5HF`S58`S5:`5YZ`C4I!3=\`5Y[`CM7`SEY`5Y\
M`CM6`5YY`SLZ`SL[`SL]`D)@`D)B`6-K`D)A`D)?`D)>!#TJ!$,U`T9=`DEY
M`6A?`6A=!$,P`6A>`DEW`DEX`TMM`6A;`E`Z`E`X`TMP`6Q7`E`Y`6Q8`6Q6
M`6A<#TY>`V1S`E9W`E9U`E9V`E`W`EQH`7-9`EQG`F%1`F%2`E9X`F5*`V9W
M`41;`49-`4@A`B([`4=^`RAC`4TQ`6-L`R$]`44\`49.`5!W`5Y]`R$^`B%:
M`R)'`B%;`R)(`B(\`V9X`4HJ`B-P`B-N`4HK`B-M`B-O`B-Q!"0H`4HI`R5N
M`R5M`4TU`4TV`4TS`RAE`RAG`4TR`BHY`4TT`RAH`5!X`RQ(`BHX`BHZ`BHW
M`BH[`5!Y`54]`BYW`S!L`BYY`54[`BYZ`54\`BYX`S!K`BHV`C4K`C4N`C4O
M`C4L`5HM`5HL`5HJ`5HK`C4M`S5A`S5@`SL_`5HN`SM``SL^`5\A`5\B!DA%
M`5\C`D)C`D)E`D)G`6-N`6-M`5Y^`D)F`D)D`V1T`DE]`T9A`T9@`DE[`DHC
M`6A@`DHD`DHA`6AA`DE\`DEZ`DHB`6Q:`E`\`DE^`6Q<`E`]`6Q;`6Q>`E`^
M`6Q9`6Q=`E9]`E9[`E9Z`E9\`E9Y`U!<!%LA`7@S`V1U`FAR`FAS`UP_`FM9
M`FU-`7TB`R$_`R-A`4TW`4HL`RAI`RAK`5!Z`RQ,`RQ+`S!N`41<`44]!"%-
M`49/`B(]`R5O`4HM`B-R`RAM`BH\`5![`6AB`41=`R%D`R))`R-B`4@B#R).
M`SM"`6-O`41>`44^`44_`491`490!")K`B(^`4@C!")L`B-S`R5Q`4HN`RAN
M`B92`B93`B94`RAP`4TX`4TY`B91`4TZ!"DL!"QP`5!\`BH]`RQ-`BY\`54^
M`S!O`BY[`S5B`5HO`C4P`5HP`C4Q`S5C`SM'`SM%`5\D!#=%`SM$!#TP`D)H
M#T$_`T$B`DHF`DHE`6AC!$E>`6Q?`E`_`7!3`E9^`7-:`U=C`7M?`F\G`R%`
M`R%!`R)*`R-1`B95`RAQ`BH^`5HQ`CM8`6-P`T$C`U!>#U1#`U=D`79!`V%D
M`R%"`4HP`R5R`4HO`5!]`RQ0`BY]`5HS`5TI`5HT`5HR`5\E`T$D`DHG`6AD
M`6Q@`U]%`B$L`B(_!")M`B-U`4HQ`B-T`4HR!"0L`4T^`B98`B97`4T]`4T[
M`4T\`B96`RAV`RAU`5$A`BH_`5$D`5!^`5$F`5$B`5$C`5$E!"DQ`S!P`S!R
M`55!`55``54_`S!Q`V1V`C4S`5HU`5HX`5HV`V1W`C4R`5H[!#%3`5HW`C4T
M`5HZ`5HY!#%2!#%7!#=*`CM:`CM9`SM+`5\H`5\F`5\G`CM;`6-Q`D)J`6-R
M`D)I!#TT!$,_`E!``T9C`T9D`6QB`DHH`6QA`TMR`6AE`V1X`E<B`E<A`7-;
M`EQI`F5+`FAT`FAU`UXO`45`!"$V`492`R)-!")Q`B%<`R),!2)F`4HT`4HV
M`R5X`B)"`B-X`B-W`B-V`R-F`B)!`B)``4@E`4HU`4HS`4@D`R-G`R-I`R5W
M`4T_`B99`R5[`4U``B-]!"90`B0A`B-^`B9:`R5V`R5T`B-Z`RA^`4HZ`4HX
M`R5\`B-Y`B-[`B0C`R8B`4HW`R8A`B-\`B0G`4U"`R5]`B0D`4HY`R8C`B0B
M`B0E`R5Z`4U!`R5U`4U#`B0F`RAX`RDB`B9N`B9A`B9?`B9M`B9H`5$K`4U$
M`B9I`B9L`5$G`B9K`4U%`4U*`4U(`B9B!"DV`B9=`B9D`4U/`B9O`5$H`B9E
M!"9/`5$I`4U+`B9G`RQ:`BI.`5$J`B9<`4U,`5$L`4U-`4U)`4U.`B9F`B9;
M`B9J`4U&`RAW`RQ;`B9>`B9C`B9@`4U'`RAZ`BI`!"E%`BI!`RDA`BI+`B\C
M`BI,`5$R`BI/`BI%`5$Q`BI'!"D_`BI(`RQ@`S!Y`BI*`5$M`RQ6`S!S`55%
M`RQ7`RQ=`BI&`BI"`55&`S!^!"D^`BI0`55"`B\A`BI)`RQ4`BY^`BI$`BI-
M`RQ?`RQA`5$P`55#`5$V`55$`BI1`B\B`5$O`55(`5$U`5$T`5$S`55'`BI2
M`55)`5$N!"E+`BI#`S!Z`S!X`S![`RQ<`S!V`5H\`B\F`B\H!"TE`B\J`55*
M`550`C4W`B\N`B\E`5H^`C4U`S$B`55/`55-`B\P!"TM`C4V!"TL`B\G`S$E
M`55.`B\K`551`B\M`S5H`S!T`55,`B\L`B\O`B\I`S$G`55+`5H_`S5Q`B\D
M`5H]`S5R!#%K`S$C`S$H`5I``S$A`S5O`S$F`C4Y`C5"`5\K`SM4`5I"`5I'
M`5\L`C5$`5I.`CM=`C4Z`5I&`5I)`5I$`C4X`C5&`C5)`CML!#%H`C5'`CMA
M`5I%`5I,`5I0`C5!`CM<`C5%`5I!`CM>`C5(`CM@`C4]`S5J`5\I`SM6`C4[
M`C4\`5I+`SM5`S5N`5I*`C4_`5I/`C5#`5I(`C5``S5Y`5I-`5\M`5\J`CM?
M`SM8`C4^`SM9`5I#`S5V`S5X`SM:`SM-`S5T`5\R`5\V`CMC`6-W`5\T`CMG
M`5\X`D)K`CMI`6-Y`5\P`5\S`CMJ`SM>`CMK`CMQ`5\Z`6-Z!#T]`CMM`CMR
M`CMF`60F`SM/`6-[`5\Y`CMD`CMS`SM1`60E`5\W`6-T`CMP`SM=`5\[`CMH
M`CMB`5\Q`CME!3\P`CMN`T$K`6-S`6-X`5\N`CMO`SMA`6-V`SMB`SMC`SM0
M`5\O`V1Y`60D`DHJ`D)V`T$I`D)N`DHI!#TY`D)R`D)T`T$G`T$L`D)Q`T9O
M`60C!#TX`D)P`60G`T9N!E)D`T$H`DHY`T9L`T$N`60B`6AG`D)W`DHK`T9M
M`T$J`6-^`D)O`D)S`6AF`6-U`D)L`D)M`6AH`6-]`60A`6-\`D)U`V1Z`DHO
M`DHP`DHU`6QG`DH\`TMS`6AN`TM^`6AM`DHW`TMT`6QF`DHL`6AL`T9Q`DH[
M`6AJ`6AK`TM\`DHX`E!1`6QD`5\U`T9R`DHZ`6QK`DHR!$EO`6QE`T9J`6QJ
M`DHM`DHQ`DHN`DHT`6AO`6QC`6AI`TPA`E!#`DHV`T9H`6QI`T9S`6QL!R)Q
M`DHS`T9K`6QH`E!"!4TJ`TPC`T9T`TPD`TMW`E!'`7!7`E!!`E<N`E!0`6QP
M`TMZ`6QN`7!5`E!-`E!)`6QT`TMV`E<E`U!H`TPH`U!G`6QR`E!(`TPI`E<C
M`TPE`E!,!%`[`E!/`E!&`TMY`6QS!%`W`TMU`6QM`E<D`7!6`E!.`6QO`6QQ
M`E!+`6QU`E!*`E!%`E!$`7!4`E!2`E<G`EQK`7!9`U!A`E<M`U!C`E<K`U!J
M`EQL`U!D`7!:`E<L`U!F`E<I`7-=`EQJ`U!L`E<F`E<H`7->`7!<`7-<`7!;
M`7-@`E<J`7!8`U!B`U!E`U!K`V9Y!%LK`F%;!%8S`F%3`U1A`U1?`U1<`U1>
M`U1=`EQR`F%4`EQN!%8R`U1;`79"`EQP`EQO`7-?`EQM`EQQ`F%<`F%8`F%:
M!%]@`F%5`F%6!%]A`F%9`F%7`7@T`U=E`7@W`7@V`7@U`7EL`FAV`7EM`F5,
M`7IJ`FM:`7IK`7M@`7PV`F\H`U]&`F\I`F\J`V$^`G(J`45!`B%=`493`4@G
M`4@H`4@F`R-K`4@I`4H\`4H[`R8E`B9P`4U1`4U0`RQC`B\Q`5I1`5I2!#%N
M!#%P`SMD`5\\`D)X`60H`60I`D)Z`D)\`D)[!#U#`DH^`T9V`DH]`6AP`DH_
M`T9U`E!3`6QV`TPL`7!=`U!M`7-A`79#`7-B`U](`45"`R%E`R%F`R).`B0H
M`R8H`R8I`B9Q`4U3`4U2`4U4`5$W`BI3`BI4`S$I`B\R`552`5I3`5\]`CMT
M`45#!"$W`41?`45$`R)0`B%>`497`496`494`495`R-O`4@L`B))`B)+`4@K
M`B)#`R-L`B)$`R-M`B)*`B)&`B)(`4@J`B)%`B),`B)'`R-N#R)1`4I#`4I,
M`4I*`B0R`B0O`B0W`4I(`B0X`R8Y`4I!`B0U`R8N`4I'`B0Q`B0P`4I%`B0V
M`4I&`4U5`4I``B0S`R8J`B0I`4H]`R8W`4I0`B0N`B0T`4I"`4I$`R8O`B0J
M`R8V`B0K`B0L!"0Y`4I/`4I)`4I.`B0M`4I-`4H_`4H^`4I+`R8U!"0\`R8S
M`R8T`R8X`R8Q`V1[#R0Y`R8R`RDQ`RDJ`4UC`B9]`B9V`4U>`4UQ`B9R`B9Y
M`B9[`B9^`4UL`RDF`B9Z`B9S`4UJ`B9W`RDH`B<A`4U;`RDE`B9\`4UE`4UD
M`B9U`4U9`RDT`RDR`4U:#R<P`4U8`RDS`4UP`4UH`4UB`4U6`B9X`4UA`4U7
M`4UI`4UR`BI5`4UF`B9T`4U<`4U?`4U@`RDN`4UN`4UO`4UM`4UG`4UK`4U=
M`5$X`RDP`RDW`RDU`RDV`RDO`RDI`RQM`BI;`5%$`5$\`5$^`5%#`BIG`5%!
M`B\S`553`5%&`BI8`BI@`5%"`BI?`BI<`BID`BIF`5$[`5$_`5%%`555`BIA
M`5$]`5%(`BI:`RQO`RQP!2E%`5%``554`5$Z!"E9`BI7`BI>`BI6`BI9`BI=
M`B\T`5%'!"E1`BIB`BIC`BIE`5$Y`RQL`S$R`S$S`RQK`RQN!"E;`55C`B]`
M`55A`55B`B\V`B]&`S$L`558`S$O`S$U`C5*`B](`B]"`S$X`B\Y`S$W`B]+
M`B\\`55>`C5A`B\_`55@`557`S$\`B]-`B]!`55:`B\Z`B\W`B\X`55;`B]'
M`B].`55=`B\^`B\]`55E`55D`556`55<`55?`B]*`S$N`S$Y`B]$`559`B\U
M`B],`B]#`B]%`B])`S$P`S$[`S$V`V1\`V1]`C5+`S8Q`5I;`5IO`5IN`S8G
M`5IC`S8I`C5=`C59`C56`C5H`5I>`5I6`S8F`S8R`C5;`5]-`5I:`C5C`S8B
M`5IP`5IM`C5?`C5.`S5\`S8K`5IL`C5E`C5-`5IA`5IE`C5D`S8C`C57`5IF
M`5I@`C5,`S5]`5\_`C5G`C55`5IK`C58`C5F`5IJ`S8D`CMU!#%W`5I7`C53
M`5I<`5IG!#%X`5IB`C5<`C52`C50`C5B`5I4`5IH`5I8`5\^`C5@`5I9!#(C
M`5I5`5ID`5I?`5I=`C54`5II`C51`C5>`C5:`CMW`CMV`S8M`V1^`S8N`C5/
M`CPI`SMQ`5]!`SMP`CPO`CM\`CPL`D)]`5]$`CPP`CPS`5]#`CPA`CPR`CPQ
M`5]%`CMX`5]``5](`SMS`5]&`CPN!#=Q`CPD`5]*`CPU`CPM`CPV`5]2`5]0
M`CPK`CPJ`SMG`CPH`CPB`5])`SMF`5]'`B\[`CMY`SMH`D,]`CMZ`5]"`5]/
M`D,A!#=@`5]+`5],`CM[`CPT`D)^`CPE`CM^`5].`CPF`CPC`SMR`SMM`5]3
M!#=O`SMO`V4A`60X`T%)`T$R`D,D`D,W`D,\`D,P`60T`D-!`60Q`D,B`T$Z
M`D,C`60J`60S`D,J`60V`60W`D,K`T$X`D,X`D,^`60R`T$^`60L`D,I`D,E
M`D-``D,N`D,O`D,F`D,Z`D,Q`D,[`D,S`T$]`60M`DI``60P`60N`D,_`D,V
M`D,R`T$V`T$S`D,G`6AZ`D,U`60U`D,M`T$T`D,L`T%(`T<E`T%"`60O`60K
M`DI5`D,Y`D,T`D,H`T%$`T%%`V9V`DI0`T9X`DI!`DI,`T<H`DI3`6AX`5]1
M`DI1`6AS`T9^`T<D`T9Z`6AR`DI8!$-=`DI"`DI/`DI#`DI.`6AV`DI2`CPG
M`T<A!$->`T<J`DI9`DI*`6AY`E!A`6QW`T<C`DI7`DI6`6A[`E!4`6QX`E!5
M`T<B`DI&`DI'`DI$`DI)`DI%`DI:`6AU`6QY`6AW`6A\`T9[`DI(`T<I`DI4
M`TPM`T<F`DI-`TPU`E!8`TPX`6AQ`6Q\`E<U`E!=`E!<`E!>`TPP`TPO`E!;
M`6Q]`TP[`6TE`6TB`TPQ`6TC`E!6`E!9`E!C`6TK`6TI`TPN`E!:`CM]`6QZ
M`E!@`E!7`TP^`6TL`E!?`6AT`6TA`DI+`TP_`TPT`6TD`TP]`6TH`6TJ`6TG
M`6TF`TPZ`6Q^`E!B`6Q[`6TM`TPY`V4B`TPW`7!A`7!B`E<T`7!K`7!H`U!P
M`7!?`7!F`E<V`7!D`7!>`TPR`7!E`U!W`E<S`7-D`7!@!51>`7!G`7-C`E<R
M`E<Q`U!V`7!I`U!O`7!J`U!Y`E<P`E<O`7-E`E<Y`7!C`E<W`U!U`U1D`7-F
M`U1G`7-K`EQU`EQW`U=K`7-H`U=M`EQX`EQT`U=L`EQV`7-I`7-L`U1I`EQS
M`7-G`7-J`79%`E<X`79$!S]B`U=J`79*`F%@`U=P`79(`79)`F%C`F%?`79&
M`F%=`7@X`F%A!%LV`F%B`F%>`U=N`79'`F5-`UH[`F50`UH\`UHZ`F51`F5/
M`F52`7@Y`F5.`UXQ`FAZ`7EO`FAY`FAX`FAW`7EN`7EP`V4C`FM;`7IM`7IL
M`U]*`U]+`FU/`FU.`FU1`7PW`7MA`F\L`FU0`U])`V`R`F\K`7PY`7PX`7Q?
M`G`W`G!]`45%!B-L`RQR`CPW`E<Z`R%G`R%H`4@M`B)-`4I3`4I1!"0_`4I2
M!"0^`B<B`4US`5%)`RQT`BIH`RQV`BII`RQS`5%*`B]0!"U#`55F`55G`B]/
M`S$]!"U$`S8W`S8V`5IW!#(K`5IS!#(O`C5I`5IZ`5IY`5IR`5IU`5IX`5IT
M`S8T`CP[`5IQ`5]4`SMT`SMU`SMV`5]6`5]7`CPZ`CP]`5]5`CPX`CP\`CPY
M`T%+`60Y`T%.!#U=`D-"`T%-`T<P`6A]`DI;`7!L`6TN`E!D`6TO`6TP`E!F
M`E!E`E!G`E<\`E<[`EQZ`EQY`7-M`7-N`F53`UQ!`45&`R58`RDY!"U'`S%`
M`CP^`S8X`S8Y`5]9`5]8`D-#`F%D`7IN`F\M`45'!"1!`55H`S%"`5I\`5I[
M`CP_`CQ``60Z`DI<`6A^`E<]!%8_`45(`498`RD[`4UT`B<C`BIJ`5%+`5I]
M`S8Z`CQ!`5]:`60[!#UC`E!H`E!I!%!.`U1K`EQ[`79+`G!^`45)`RD\`B<D
M`4UU`5%,`RQW`BIK`55I`B]4`B]2`B]3`55J`B]1`S8\!#(T`S8_`S8]`5LA
M`5LB`C5J`5LC`5I^`CQ"`SMY`CQ#`D-$!#UD`6DB`6DA!%!/#U1D`EQ\`F%E
M`UH_`F55`F54`FA[`R%I`B$^`5%-`S9!`T%0`45*`499`R)1`4@O`4@N`R-S
M`R-R`4@P`4@Q`B)/`B).`B0Y`4I4`B0\`B0[`B0Z`B0]`R8]!"9B`4UV`B<J
M`B<F`B<O`RE#`RD^`4U]`RE"`4U[`B<K`B<G`B<N`4UZ`4XC`B<I`B<E`4XB
M`B<L`4UY`B<M`4U\`4U^`B<Q`B<P`B<H`4UX`4UW`4XA!"9A`RE``RE!#R<^
M`RQ^`RQZ`BIP`BIV`RTC`5%3`5%0`BIM`BIR`RQ\`5%6`5%.`BIQ`5%1`5%4
M`RQY!"EG`BIT`RQ]`5%/`BIY`5%2`RTA`5%5`BIN`BIS`BIW`BIO`BIL`RTD
M`RTE`BIX`BIU`RTB`RPW`S%&`55R`55K`55N`S%,`55Q`S%$`B]7`S%)`55L
M`B]5`S%(`55P`S%-`S%%`55M`S%#`B]8`55O`S9"!#(Y`C5N`5LE`C5M`C5O
M`5LD`5LI`B]6`S%+`C5L`C5P`S9$`5LF`C5K`5LH`S9%`5LG`SPF`CQ*`SM]
M`CQ%`SPE`5];`5]?`5]<`CQ(`CQ+`SPC`5]=!#@D`5]>`5]C`D--`CQ)`5]A
M`CQ&`CQ$`SM\`5]B`SM^`CQ'`SPD`61!!#UI`D-%`60^`60_`60]`D-*`D-)
M`D-&`61#`T%;`T%6`D-(`5]@`T%9`T%1`D-,`D-'`61``60\`61"`D-+`T<T
M!$-K`T<U`6DE!$-O`DI?`DI>`DI=`6DC!$-M`T<Y`T<S`T<W`6DD`E!L`E!O
M`6TR`TQ$`TQ&`6TQ`E!P`E!K`6TT`E!M`TQ!`6TS`E!J`TQ``E!N`7!R`7!O
M`E=&`E=%`TQ#`E=$`E<_`U!]`E=``U$C!%!0`U!Z`7!P`U!^`7!M`7!Q`E<^
M`7!N`E=!`E="`E='`U$B`U1Q`E=#`U1O`U1P`EQ]!%9!`U1L`U1M`7-P`U1R
M`F%H`7-O`F%F`F%G`79,`7@[`F56`UI#`7@Z`UI"`V4F`FA]`FA^`UQ"`7EQ
M`UQ#`FA\`7IO!&I,`F\N`7PZ`G`X`G`Y`V$_`45+!"%\`4@R`4@S`4I5`R9!
M`B<R`5%7`55S`5LJ#S)S`5DW`5]D`5]E`5XR`CQ,`V4G`61$`DIA`DI@`U$D
M!U-'`45,`4@T`B<S`4XE`RE%`4XD`RTG`BIZ`BI[`V8R`B]9`B]:`55T`55U
M`S9(`55V`C5Q`S9'`S9&`5LL!#@I`5]G`SPI`5]F`D-.`D9!`DIB`E=(`U$F
M`V8S`79-`7ER`45-`49<`49=`49;`49>`49:`R)2`4@W`R-W`B)7`4@V`4@X
M`R-X`R-U`B)2`B)1`B)4`B)3`B)6`4@U`B)0`B)5#R)8#R)7`R9(`B0^`4I?
M`B0_`B1#`4I>`R9)`B1'`B1"`B1%`4I7`4I8`4I9`4I:`R9%`4IA`R9$`B1!
M`4I<`4IB`R9'`B1``B1&`R9"`4I;`B1$`4I=`4I6`4I@`R9*#R0B!"1&#R13
M`4XZ`RE'`B<U`4XF!"9I`4XP`4XQ`4XI`4X[`4XK`B<]`4XV`B<X`4XL`B='
M`B=(`B=``B<Y`4XY`B=%`4XT`4XR`RE2`B=&`RE)`B=$`B<\`B<T`B<[`4XM
M!"9E`4XS`RE*`4XG`B<_`B<^`B<V`RE/`4XU`B="`B<W`4XX`B=)`4XH`RE(
M`4XO`B<Z`B=#`4XW!"9G`4XJ`4XN!"9J`B=!#R=.`RE.`RE,`V4H#R=0`V4I
M`BL]`5%?`5%L`RTV`BLX`BLN`5%E`BLL`5%>`BLG`5%H`BLT`BLA`BLC`RTN
M!"U9!"EN`RTP`BLF`BI\`BLS`BM#`5%C`BLH`BLZ`RTM`BI^`BM!`BM"`BM%
M`BL\`BLM`BLU`5%I`5%<`5%D`5%P`5%9`5%;`RTQ`RTK`RTZ`BLE`5%M`5%F
M`BL_`BLB`5%O`5%J`BLK!"EM!"U.`5%N`BLR`BLJ`5%G`BL^`BLV`RTJ`5%A
M`BM$`BLI`5%=`BL[`BLQ`5%B`BLW`5%:`BI]`5%K`58G`5%@`BLP`BLO`BLD
M`RE1`BM``RTT`BLY`RTR`5%8`RTY`RTW!C%R`RTX`V4K`V4J#RM(`B]N`58N
M`B]O`S%=`B]C`58C`58O`S%7`B]<`S%3`B]E`B]M`S%;`B];`B]V`55W`S%>
M`S%D`S%0`B]U`B]P`S%?`B]Q`58A`58L`B]G`S%6`B]H`B]R`B]I`S%C`B]D
M`B]>`B]?`B]L`B]F`S%4`S%/`55X`55\`B]T`B]@`58J`58F`S%:!"U5`58I
M`58P`55]`58K`B]K`58M`55Z`S%9`55Y`B]=!"U/`B]A`58D`B]S`B]J`B]B
M`58H`58E`RTO`55[`55^`S%B`S%8#S`D`S%A`S%@`V4M`V4L`C8H`S95`C5V
M`C5W`C5[`S9@`C8L`C8I`S9.`C8B`C8A`5LS`C8E`C8T`C5R`S9;`C8U`C8G
M`C8Y`C8M`5LR`C8K`5LM`5M"`5LX`S97`5L\`5L[`C5S!#(_`C8R`C8X`C8P
M`C8W`S91`C8D`C5T`C8V`C8F`5LP`5L]`S9:`C8O`5LV`S9-`S9<`S90`C8N
M`C5U`5L^`S9+`5M``C8Q`5M!`5LO`C5\`C8S`S94`S1X`5LU`5L_`C5^`C8J
M`C5Y`C5]`5LZ`C5X`5LN`5LW`5LT`C8C`58B`CQC`5LQ`S9,`S92`S9>`S9?
M#S57`S96`SQ%`5LY`SQ!`CQF`CQ\`CQQ`5][`SPX`5]V`CQ@`5]W`CQP`SP^
M`CQI`CQV`5]S`CQ.`CQX`5]I`CQ6`5]L`5]K!#@R`5]\`S93`CQ0`CQR`CQS
M`5]N`5]J`CQ>`SP]`5]U`CQ9`SPR`CQT`5]Q`CQL`CQY`CQ3`CQ8`CQ2`SPJ
M`5]P`CQE`D-D`CQ4`5]T`CQ=`CQU`5]O`CQ:`CQ7`CQH`5]R`5]H`5]^`CQK
M`CQJ`SPQ`SQ"`SPY`SP[`SPT`SPO`CQ/`5]M`CQW`CQ?`CQA`SPW`CQN`CQM
M`CQ-`5]X`5]Z`CQ5`CQ<`CQD`5]Y`CQ;`CQG`CQZ#SMP`CQO`SP\#SPA`SQ$
M`SPS`CQ[#SPI`V4O`CQ1#SMN`V4N`SQ``D-X`61,`T%E`D-V`D-A`D-F`D-?
M`T%W`D-R`D-1`D-8!#UQ`D-P`D-Z`D-B`T%H`D-5`D-H`D-M`D-9`T%K`D-J
M`D-6`T%=`T%U`D-=`D->`61.`D-Q`D-O`T%S`D-2`D-T`T%T`D-U`D-W`612
M`61*`T%O`C5Z`D-:`D-L`D-;`61'`617`D-S`615`611`D-0`61)`T%Y`D-3
M`616`T%X`D-C`D-/`T%V`61/`D-G`D-7`610`D-@`61&`5]]`D-I`CQB`D-4
M!#UL`T%M`D-N`61+`D-K`61(`D-E`613`D-<`D-Y`T%J`T%[#T))#T)'`61-
M`D4L`T%R`614#T(H#T(\`DIP`DIN`T<Z`DLF`DIL`T<]`DI^`61%`6DH`DIH
M`DLE`T=1`DIM`DI[`6DM`6DF`T=.`DLC`T=&`DIF`DLB`T='`6DX`DIW`DLI
M`6DV`DIO`6DG`DIQ`DLA`6DP`DIJ`6DT`6DJ`DIS`DII`DIC`T<^`DI]`6DQ
M`DLH`DID`6DN!$-W`DIY!$-Y`6DO`DIK`DIV`DIR`DIT`T=#`6DI`DLG`6DW
M`DIU`T<[`DLJ!$0G`T<\`DIE`DIZ`6DL`6DU`6DS`DIG`DI\`6DR`T=%`T=(
M`6DK`DIX`T=-`T=$!$0H`TQ4`DLD`T=,`E!\`T="`E!X`E!T`E$J`E$G`6TW
M`TQD`TQ@`E$N`E![`6U"`E$D`TQ/`TQ1`E!W`E$C`6T_`E$W!$H]`E$T`E$F
M`E!U`TQ?`TQ7`E$K`E$M`6T[`E$A`E!Z`E!Q`6TX`6U`!$I(`E$P`6U!`E!R
M`E$V`E$I`E$O`6T^`TQ-`TQ0`E$L`TQ'`E$S`TQ;`6U#`TQ6`6T]`E$E`E!V
M`E$X`E!S`E$Q`6TZ`TQ*`E!]`TQ)`E!^`6TY`6TV`E!Y`6T\`TQ2`6TU`TQB
M`E$R`E$U`E$B`E=5`TQ>`TQ9#T]"`TQA`V4P`E=-`U$L`E=)`7$A`U$\`U$X
M`7!T`7!Y`7!U`E=7`E=B`7!S`E=/`E=8`E$H`E=9`U$H`U$K`7!Z`U%``E=H
M`7!^`7$C`E=+`U$[`7!]`U$Q`E=F`E=G`E==`E=<`E=4`U$I`U$^`E=>`E=E
M`E=D`U$O`7!X`7!V`E=6`E=3`U%$`E=0`E=C`7$B`E=A`7!\`7![`U$G`E=;
M!$I+`E=*`E=,`E=.`E=@`E=:`7!W`U$N`E=1`U$R`E=?`U%!`U$Z#U1[`E=2
M`V4Q#U4I`V4R`U1U`7-X`ETQ`7-Q`ETB`U1[`ETM`7-S`ETT`U4A`ETI`U1\
M`ETD`U1V!%9%`ETU`EQ^`ETK`U4G`7-Z`ETP`ETV`ETJ`7-R`ETL`ETA`7-Y
M`U4C`U1Z`ETS`ETF`7-U`U4D`ETH`ETE`7-[`ETG`7-T`7-W`ETO`ETC`ETR
M`U1X`ETN`U4I`U=T`79/`F%S`794`795`U=W`U@A`U=V`79.`F%R`U=X`F%O
M`F%P`792`F%J`F%N`791`U=^`F%K`U=Y`U@C`U=]`U=Z`793`790`U@B`F%I
M`F%M`F%Q`U=[`V4S`F5<`F59`F5B`UI$`F5A`F5?`F5:`UI/`7@_`UI%`UI.
M!%]Q`UI'`UI-`F5;`7@^`7-V`F5>`7@]`F5C`F5=`F58`F%L`UI(`UI&`7@\
M`V4T`F57`FDD`UQ)`FDC`F5@`7ES`U=U`FDG`FDH`FDB`FDF!&-0`FDA`UQ'
M`V4U!&-.`FM?`FDE`7IR`7IP`FM=`UXU`UXT`UXS`FM@`UXW`FM<`FM>`7IQ
M`U]/`U].`FU3`FU4`7MB`FU2#VE,`V4V`V4W`F\Q`7P[`F\O`F\P`G`Z`V!T
M#VM1`7TC`G$C`G$A`G$B`G$D`V%``V%E`V%!`G(K`45.`4@Y`R-Y`4X\!"9Q
M`B=*`RE3`RE4`BM&!"ER`RT\`S%F`B]W`B]Y`S%E`B]X`S%G`B]Z`5M#`C8[
M`B][`S9B`C8Z`C8\`C8]`CQ]`6`B`CQ^`CTB`6`C`6`A`CTA`T%]`D0B`D-^
M`D-]`T%\`D-\`D-[`618`D0A`6DY`DLK`DLM`6DZ`DLL`6U%`TQF`6U$`E$Y
M`TQE`TQG`E=J`E=I`E=K`U%&`U%%`7$D#U4Y`ETW`7-\`U4K`F%T`796`F5D
M`7MC`45/`49?`4@Z`4IC`4X]`4X^`RE5`RE6`5%Q`RT]`S%H`B]\`SQ)`SQ'
M!$0M`T%^`619`T(A`T=3!$I.`E)9`7$E`797`450`R)3`4@[!"9V`B=,`4X_
M`B=+`RE8`BM'`5%R`BM(!2EI`5%S`B]^`58R`58Q`S%J`C9"`C9``C9!`C8_
M`S9D`C8^`CTC`CTF`6`E`CTD`6`D`CTE`D0C`T(B!$0Q`DLN`DLO`DLP`T=4
M`E$\`E$[`6U&`E$Z`E$]`E=L!%!M!5MR`E=M`E=N!%92`ETX`7-]`798`F5E
M`7IS`B$_`RE9`5%T`BM)`58S!#).!#)0`5M$`S9E`6`F`CTG`SQ+`61;`61:
M`T(F`DLQ`DLR`6U'`6U(`E=P`E=O`F%U`F\R`451`B%``49@`R-Z`4ID`B1(
M`RE:`5%U`61<`452`BM*`5%V`BM+`7-^`453`V4X`V4Y`B=-`BM,`RU"`C`E
M`C`D`C`B`S%N`C`A`C`F`C`C`S%L`S%M`5M%`5M&`S9F`6`G`CTH!#A.`CTI
M`CTJ`SQ-#SP\`V4Z`D0G`D0H`D0F`T(H`D0D`D0E`61=`DLS`E%``E$_`E$^
M`E%!`E=R`E=Q`7$F`E=S`70A`ETY`U4M`F%V`F5F`FU5`454`49B`49A!",A
M`4Y``B%!`B%?`4@\`B)8`B1)`B1*`4Y!`RE=`B=.`V4[`5%W`BM-`BM.`58T
M`58X`C`G`58W`58U`58V`C9#`5M'`6`J`SQ.`6`H`6`I`CTK`T(I`T(J`6D[
M`455`B%@`R)7`49C`R)4`B%C`R0A`49F`B%B`49E`49D`4IE`B%A`R)8`R)9
M`B)9#R%F`B)=`B)?`B)@`4A&`4A'`B)<`4A"`R-]`B):`R0E`B)>`4A#`R95
M`4@^`R-\`4@_`R0C`4A%`B);`4@]`4IF`4A``4A!`4A$#R)=`V4\`B1;`B19
M`B1,`4IR`B13`4IM`B1-`RED`B15`R90`B12`4IP`B11`4IW`B1:`4IY`R93
M`4I[`R-^`B1+`R97`4IN`B1<`R91`4IU`4IX`R9,`B=E`4IH`4LA`4IV`B1.
M`4IK`4IZ`B16`4II`4IJ`B=C`B1/`4IQ`4I\`B1=`B10`4IO`R9-`4IT`B=/
M`4I]`B17`4IS`REC`4I^`4IG`B14`4IL`B18`B=D`R9.`R92`R9<`R99`R96
M#R1H`R9;`4Y-`4Y=`B=6`4Y4`RU.`B=K`4Y%`REK`4Y(`B=B!"<F`B=4`B=8
M`4Y0`4Y2`B=;`4Y9`4Y+`4Y)`4Y*`4Y8`B=G`4Y3`B=:`B=<`4Y1`4Y6`B==
M`B=J`REM`5%X`4Y<!"9]`4Y&`B=I`REL`B=M`B=9`B=O`B=@`4Y/`B=5`4Y.
M`4Y@`4Y5`REJ`B=3`BM7`4Y;`4Y?`B=A`B=F`REE`4YA`4Y:`4Y,`4Y"`REI
M`4Y'!"9[`B=7`4Y#`B=N`REG`B=1`B=0`B=>`B=2`4Y>`58Y`4Y7`B=?`4Y$
M`RU/`5(I`B=L`RU&`BM>`BMA`RU0`BMD`BM9`RU(`RU*`BMG`BMJ`BML`BM6
M`5%Y`5%^`C`L`5(P`BME`BMM`BM=`BM5`RU)`RU'`RU-`C!'`5(C`BMB`BM:
M`BM<`5(H`S%Z`BM?`5(B`BM2`BMH`RU+`BMK`RU%`RU7`5%]`RU3`5(K`BM/
M`5(M`5%[`5(Q`BMI`BM1`5(N`C!!`B=H`5(A`5%Z`BM8`BM0`5(O`5(G`BMC
M`5(L`5(J`BM;`5(D`BM3`5(E`5(F`BM4`BMF`5%\`BM@!"HA`RU5`RU1`S%W
M`S%S`C`O`59!`59&`S%Y`S(F`S%V`C`X`C`^`C`Z`C`M`C`P`C`I`C`J`59-
M`58^`C`Y`C!"`59(`58Z`S%O`59#`C`Q`59%`C`R`C`\`S(B`S(E`S%R`59'
M`C!+`C`K`59``58_`59+`C`H`C!)`C`]`C!*`C!$`C`V`C!%`S(A`C`_`C!(
M`C!&`59,`C`W`58]`58\`59$`59*`C!#`59)`C`T`5M(`S%X`C!,`C`S`C`N
M`59"`59.`58[`S(G`C`[`C!``S%]`S%[`S%\`V4]`5MJ`C9%`C9)`S9O`5M7
M`5M5`S9Z`S<A`5M,`C9'`C9&`5M@`SQ0`C9,`5M:`S9R`C9>`C9J`5M)`C9;
M`C94`5ML`C9$`S9J`C9@`S9K`5MI`5M=`5MH`5M3`C90`C9B`C9:`5M4`5M.
M`C9H`S9L`C9A`C9C`5M6`5M>`C9E`C9.`C9?`C93`C9G`5MC`5M+`5MA`C98
M`C96`C97`5M8`C92`C91`5M-`C9+`C9I`5M/`C95`5MM`S9T`5MG`C9*`5MD
M`5MB`5MK`C9<`5MF`C`U`C9=`5ME`C9D`5M*`C99`5M<`C9-`5M;`S9\`5M9
M`5M1`5M0`CTL`C9F`SQ=`S<H`C9/`S<F`S<C`CU!`S9P`5M2`S9W`S<D`S9V
M`S<E`S9Y!#)M`S9]`V4^`S<I#S8I`S<G`SQ4`6!'`5M?`6`U`CT[`6!#`SQ2
M`CTO`6`R`6`N`CU-`6`T`6`X`6`S`6`\`CU1`CU(`SQK`SQM`CTV`6!!`6`[
M`CU"`6`K`CU.`CU'`6`O`CT\`6`^`CU9`CU:!#A;`6`L`CU,`6!``CU``CTR
M`CTS`6!$`CTW`CT^`CTX`SQ:`6!"`6!*`CTT`CTM`CTN`SQ6`CTP`6`Q`CT]
M`SQN`6`_`6!(`SQ8`SQI`CT_`CU7`CU/`6`M`CU5`6`Y`SQF`6`W`SQD`CU;
M`6`V`CU%`CTY`CU#`6!-`CU)`CU&`CTU`6!)`CU3`CU0`CU8`6`P`CU$`6!,
M`SQ;`CU+`T(Z`SQ@`6`Z`6`]`SQ<`CU*`6!+`CTZ`C9(`SQ1`SQL`CU4`CU2
M`CU6#SQ=`SQB`V5"!#A>`SQC`SQH#SQ'`V5`!#A?`CTQ`6!&`V4_`V5!`D1'
M`D1&`D0L`61C`T(P`D1%`D0O`D0P!#X_`61M`D1.`61H`D1$`T(S`D0I`61N
M`61D`D0X`D0N`D0Q`D1)`61>`D10`D1(`61G`D0]`61R`T(N`T(V`61Q`61K
M`T)`!#XV`D1/`61?`D0[`D0R`D0_`D1+`61S`T(Y`61A`D0Z`T(M`D0S`61J
M`T(Q`61I`D0V`D1``D1*`D0M`D0W`61B`D1!`61O`61F`D0T`61E`D0K`D0Y
M`D1-`6!%`6E7`D0\`DLT`D0^`D1,`61L`D0U`61@`61P`6U:`D0J!E1.`D1#
M`T)$`T(^`T)'`D1"`T(]`T)%`T(_`T([`T)&`DM0`6E4`DM%`DM*`6E)`T=6
M`DLV`6E6`T=7`6E``DLU`DM6`6E8`DLY`DM)`T=E`DL[`DM9`DM5`6D^`6E(
M`E%;`6E5`6E&`DLW`T=C`DM4`6E*`DM1`DM>`DL]`DM&`TQX`T=;`DM<`DM2
M`6E%`TQJ`T=D`DM$`6D_`6D]`6E/!$1#`T=?`DM"`DL_`DM``T=:`DM8`T=<
M`DM=`DM;`6E#`DM?`6E'`6E.!$1$`DLX`E%#`DM!`T=>`6E!`6E3`6E0`6E$
M`DM+`DL\`6E1`DM-`6E+`6E-`6D\`T==`DM/`DM'`DLZ`6E,`DM7`DM:`DM#
M`DM.`TQT`6E"`6U)`DM,`E%"`T=B`DM3`T=A!$12#T]Y`V5$`V5%`T=F`V5#
M`DL^`E%,`E%6`6U,`E%5`E%A`6U.`E%3!$I8`E%7`6U9`TQ]`E%.`6U1`TQS
M`E%:`E=[`6U=`6U<`E%<`E%+`E%F`6U7`TQK`6U-`E%?!$II`E%C`E%H`E%=
M`E%1`6U0`6U3`6U;`6U6`TQU`E%4`DM(`TQ^`TQL`E%0`E%G`6U2`TQY`6U5
M`E%I`6U*`E%>`E%$`E%D`70J`TQZ`E%2!%!U`6U+`E%-`6U/`E%%`6E2`E%)
M!$I7`E%B`E%*`E%(`6U4`TQ[`E%@`TQW`E%'`E%9`E%8`E%E`E%/`6U8!$ID
M`V5'#T]]`V5&`E=^`U%6`7$S`7$I`E@L`E=V`7$K`E@D`7$R`7$M`E@B`ET[
M`E@H`E@N`E@G`E=T`E@E`E@P`E@R`7$H`E@Q`7$N`7$T`U%4`7$Q`U%8`E@K
M`7$P`E@F`U%-`E=X`E=]`U%0`E@J`7$O`7$L`7$G`7$J`E=\!%$B`E%&`E=W
M`E=Z`E@M`E@A`E=U`ETZ`E@O`E=Y`E@I`TQQ`U%5`ET]`70N`U4P`U4O`70B
M`U4U`U4V`70F`ET_`EU%`EU#`70D`70E`70L`EU&`ET^`70G`U4Q`EU"`EU!
M`EU'`70M`U4W`70H`70K`EU``70O`70I`70P`70C`EU$`UI5`ET\`U%9`U4Y
M`F(E`V5(`79=`F(B`F(D`U@H`79;`F%^`F(A`F%Z`U@J`U@G`E@C`F%[`79<
M`F%W`U@F`799`F(F`79:`F%X`F%Y`F%]`79?`U@I`79>!%M>`U@K`F%\`7A%
M`F5J`F5P`7A&`F5G`7A#`7A``F5R`7A$`UI2`7A!`F5I`F5L`F5M`F5N`F5Q
M`UI4`F(C`F5H`7A"`F5O`FDT`F5K`UI3`V5*`V5)`FDK`7EU`FDN`7EV`FDW
M`FDM`FDJ`UQ1`FDL`FDP`FDS`FDR`FDV`FDI`UQ/`7ET`FDQ`FDU`FDX`FDO
M`FMA`FMB`FMF`FMG`UX\`FMD`FME`FMC`UXZ`7IT`UX[`7MD`FU9`V`V`U]2
M`FU6`FU7`FU8`7ME`V`W`F\T`F\S`V5+`G`]`7Q@`G`[`G`^`G`\`G$E`7TD
M`7TR`G%Q`G%;`V%Y`G%P`G(^`G(_`456!"%0`R0H`R0F`4A(`B)A`R0G`R0K
M`B1>`R9B`4LB`R9?`4LE`R9>`B1?`R9C`4LC`4LD`R9@#R1Q`REW`B=X`B=Z
M`B=U`B=R`B=T`RET`REP`REU`4YE`REO`REY`REV`4YC`RER`REQ`B=V`4YD
M`B=S`B=P`4YB`B=W!"<I`B=Q`4YF`B=Y!"<K`BMO`RU>`BMS`RU<`RU:`5(Z
M`RU8!"HF`RUE`RUB`BMV`RU?`5(R`5(U`5(W`5(Y`5(V`BMR`BMQ`RUD`5(T
M`BMT`BMU`RUC`BMN`5(X`RUH`5(S`RU=`BMP`V5-!"HH`S(H`C!:`C!;`C!<
M`593!"UU`59/`C!1`S(J`C!9`C!>`594`S(K`C!/`C!5`C!.`C!8`S(Q`S(O
M`C!4`590`592`C!=`S(I`C!-`C!0`C!6`S(M`C!7`C!?`C!3`S(L`591`V5/
M`V5.`S(P`5MR`C9Q`S<P`S<R`C9S`C9O`S<O`C9[`C9M`C9Z`5MN`C9K`CU?
M`C9U`5MQ`S<U`C9V`C9Y`S<N`C9]`S<L`C9R!#)R`C9W`S<M`S<Q`5MO`5MP
M`C9\`C9P`C9L`C9^`S<S`C9T`V50`V51`C9X`C9N`6!.`6!/`CUI`6!5`SQT
M`CU=`CUF`CU<`6!2`CUD`CUB`SQ]`CUC`6!0`SQ\`CUG#SQ^`SQO`SQZ`SQR
M`STA`CU@`CU>`6!1`CUA`CUE`SQ[`SQY`SQQ`6!3`SQS`SQW`V53`CUH`V54
M`V55`V52`D16`D1=`D1?`D1E`T)7`64B`D11`T),`61X`T).`D1@`61]`D1F
M`61T`T)1`D1C`T)8`D13`D1D`D12`64D`T)2`D1>`61U`D1G`T@\`61Z`D17
M`64A`D1B`D15`D1<`D18`D14`61W`61^`61\`61Y`64C`61V`D1;`T)/`61[
M`T)9`6!4`T))`D1A`V59`D19`T)3`V57`V58`V56`D1:!$17!$1;`DMG`T=O
M`6E;`T=N`T=L`DMC`DMI`DME`T=P`6E=`DMD`DMH`DM@`T=R`DMB`6E<`T=J
M`T=M`T=K`T=H`DMF`DMA`T=G`6E>`V5;`6E9#TE+`V5:`DMJ#TE?`6E:`E%O
M`E%L`E%X`E%R`E%T`6U>`E%N`E%V`TTJ`TTD`E%U`E%S`TTI`E%Y`6UA`E%P
M`E%W`TTH`6U?`TTE`TTB`E%K`E%M`6U@`E%J`E%Z`V5<`E%Q`U%B`U%:`E@V
M`7$[`U%@`U%<`EA!`E@_`7$U`E@U`E@X`E@Y`E@T`7$_`7%``E@S`EA"`E@]
M`7$Y`7$V`E@\`E@Z`U%C!%$C`7$\`E@^`7$W`U%>`7$X`U%F`E@[`7$Z`E@W
M!R]/`EA``7$]`EA#`EA$`7$^`V5=`V5>`70R`70Y`EU(`EU.`U4\`EU,`70U
M`70T`70Q`EU*`U4^`U5#`U5``70W`70V`70S`U5!`EU-`EU)`EU+`U5"`70X
M#UIS`79C`F(I`U@M`79@`79A`F(K`79B`F(H`U@N`F(G`F5V`F(J`UI6`F5W
M`7A'`F5U`UI7!%]^`F5T`UQ9`F5S`7A(`V5?`UQ6`7EW`UQ8`UQ5`FDY`FDZ
M`UI8`UQ3`UQ7`V5A`FMJ`FMI`7IU`U]3`FMH`FU:`FU;`U]4`V`Y`F\U`G`_
M`V%#`V%"`G$F`G(L`7U&`G)``457!"%1`4YG`4YH`RUI!"HJ`5([`STB!$IL
M`70Z`458`4YI`595`64E`459`RUK`5MS`6E?`B%"`RE\`BMW`C!@!#Y,`DMK
M!$IM`70[`45:`4YJ`BMX`BMY`CUJ`6!6`T)=`D1H`T)<`T);`64F`DML!$1>
M`TTN`6UB`TTM`7A)`45;`CUK`45<`4A*`B)B`4A)`4LH`4LG`4LF`B1@`R9D
M`RHA`RHB`4YK`RHC`4YL`B=[!"<Q`BMZ`RUM`BM]`5(]`BM[!"HO`5(\`BM\
M`5(^`C!C`C!B`C!A`596`S(V`C<B`C<C`5MT`C<A`C<D`6!8`5MU`STD`STC
M`6!7`CUO`CUN`STE`CUL`CUM`CUP`D1J`D1I`D1M!#Y/`D1L`D1K`6E@`DMO
M`T=U`DMN`6EA`DMM`E%[`TTO`E%\`6UC!%$M`EA%`EA&!4XW`F5\`7A*`F5[
M`F5Z`F5X`F5Y`7IV`FD[`FU<`G$G`V%[`45=!"$X`B%D`49G`B%E`R0L`R0M
M!",G`B)C`B)D`R9K`R9I`B1F`R9F`R9G`B1B`R9J`B1A`4YM`B1E`4LJ`B1C
M`4LI`B1G`B1D`R9H`B@A`BM^`B=]`B@F`RHF`4YN`RHJ`4YQ`B@G`B@C`RHG
M`B@D!"<V`B=\`4YP`B=^`4YO`B@E`RHH`B@B!BQ^`BPD`5)``5)!`RUU`BPG
M`BPA`RUT`BPF`RUP`BPB`5(_`BPE`BPC`RUS`RUQ`C!I`C!F`S(X`C!H`59;
M`59:`598`C!E`C!J`597`599`C!G`C<L`C!D`C!K`S(Y!#,C!#,J`STF`C<G
M`C<K!3-4`C<J`CUR`CU]!#,M`S<[`C<M`S<Z`C<H`CUQ`5MY!#,B!#,L`5MX
M`C<F`C<I`5MZ`S<Y`5MW`5MV`C<E`C<N`CUT`CU[`STG`6!:`CUZ`CUW`STN
M`6!<`STI`STK`STJ`CUY`T)A`STM`CUS`CUU`CUX`CUV`6!;`CU\`6!9`64G
M`STH`D1Q`D1P`D1N!E1\`64J`64I`D1R`T)?`D1O`DMP`6EB`64H`T)B`V5B
M`V5C`D1T`D1S`TTP`DMS`DMQ`6UD`T=Y`6EC`DMR`E%^`T=X`T=Z`T=W!$IW
M`6UE`E%]`E(H`E(G`E(E!$IU`E(D`E(A`E(B`E(C`E(F`E(I`EA+`EA(`EA)
M`7%!`EA'`EA-`EA,`EA*`EU0`EU1`70\`U5)`70]`EU/!%9L`79E`F(L`79D
M`7A+!&`E`7A,`7EX`FD]`FD\`FMK`FU=`7MF`F\W`F\V`F\X`49H`BPH`59<
M`5M[`C<O`49I`B%F`45>`R):`R%K`B)E`R0O!",J#R)F`B1L`B1J`B1K`B1H
M`4LK`B1I`R9N`RHS`B@O`RHM`4YT`B@M`B@I`B@L`RHL`B@H`4YV`B@K`RHK
M`4YS`4YR`RHR`4YU`B@N`B@J`RHO`5)%`5)(`BPP`BPO`BPN`5)"`BPW`BPM
M!"XJ`5)$`C!P`RUX`BPT`BPR`5)'`RU[`BPJ`BPU`RUW`BPL`BPV`BPS`BPK
M`RUZ`5)#`BPX`BPI`5)&`RU^`RUY`RU\`C!U`C!L`C!W`S(^`C!O`C!Z`C![
M`C!M`C!Y`C!V`C!T`C!X`59B`S)``59@`S)'`S(\`C!R`S)&`C!N`S)!`C!Q
M`C!\`C!S`59A`BPQ`S(]`59=`59?`V5D`S<]`C<]`C<R`C<P`STX`C<Q`S(_
M`C<X`S=``C<Y`C<U`5PB`C<Z`C<W`C<T`S<\`5M^`C<S`5M\`5PA`C<V`C<^
M`59>`5M]`C<\`C<[`5PC`V5E#S97`STV`STZ`CXD`STO`ST[`STR`CXE`6!F
M`STY`CXK`T)M`STU`CXM`CXF`6!@`CXJ`CXI`6!A`6!G`T)D`6!H`CXL`6!>
M`CXC`CXA`CXG`CU^`6!E`CXB`CXH`CXN`6!?`6!D`6!B`6!C`STS`ST\`6!=
M`V5F`STW`T)H`T)U`64Q`D1[`64P`D4A`T)O`D1U`T)T`D4B`T)N`T)F`T)Q
M`D1V`D1W`T)S`D4C`D1^`D1\`D1]`D1Y`D1X`T)G`D4D`64M`T)K`D1Z`T)P
M`64R`64L`64S`64T`T)J`64O`64N`T@E`T=^`DMT`6EE`6ED`T=\`T=]`DMY
M`T@B`6UF`6EF`T@A`T=[`6EH`DMZ`64K`6EG`DMV`DMX`DMU`T@G`DMW`T@C
M#TEV`E(S`TTQ`TT[`E(R`E(O`6UI`EA.`6UJ`E(N`TTY`6UH`TTV`E(P`E(M
M`E(J`E(Q`E(K`E(L`6UG`TTU`V5H!%$Y`EU5!%$Z`EA2`TTZ`EA1`EA3`U%J
M`EU2`7%$!%$X`EA/`U%G`7%"`U%L`7%&`7%%`EA0`EA4`U%K`7%#`V5G`EU9
M`71``79F`71!`70^`EU6`EU4`U5/`EU7`U5+`EU:`70_`EU8`EU3`U5-`V5I
M`F(O`F(R`F8A`F(M`U@O`FD^`F(S`U@P`7A-`F(Q`79G`F(N`F(P`F(T`F8B
M`UI:`F5^!&`G`UI<`UI=`UI;`7A.`F5]`UQ>`UQ<`UQ?`7EY`UQ=`UQ@`UX]
M`7IX`FU?`7IW`FUA`FU>`FU@`7P\`G!``49J`B@P`C!]`C!^`5PD`D4E`7%'
M`7A/`7MG`G!!`49K`B@Q`2,B!"H\`RXB`BPY`RXA`BPZ`RXD`S)(`C$A`C$B
M`5PE`5PF#S9G`ST]!#DE`CXO`D4H`D4G`D4F`DM[`T)W`DM\`DM]`6EI`T@H
M`E(U`E(T`TT]`U%M`EA5`7%(`7%)`U%N`EU>`EU;`EU<`EU=`F(V`F(U`79H
M`F8C`FML`49L`5))`S=$`5PG`D4I`T)X`49M!"I``C$C`5PH`S=%`ST^`6!I
M`6!J!4=)`49N`49O`B)F`4LM`4LL`5)*`BP[`CXP`49P`49Q`49R`49S!",K
M`4LN`4LO`B1N`B1M`RHW`4YW`B@T`B@R`B@S`RHX`RHU!"=``RHV`RXG`BP\
M`BP]`RXE`RXH`5).`5),`RXJ`5)-`5)+`RXF#RMZ#RQ*`59C`S).`S)-`S)0
M`S)/`59G`59F`C$D`59E`59D`S)1`C$E`S=&`5PK`C=``C<_`5PI`5PJ`S=)
M`S='`6!L`6!K`CXR`SU#`SU"`CXQ`5PL`SU$!#DL!#YK`64U`D4K`64V`D4J
M`T)[!$1\!$1[`DM^`E(V`6UK`EA6`U%P`U52`EU?!%MT`7A1`7A0!&-H`UQB
M`7MH`49T`B@U`SU%`5PM`DPA`6EJ`R);`R9S`B1O`B1P`B@V`4YY`4YZ`RHZ
M!"=#`4YX`RH[`5)2`5)3`5)0`5)1`RXK`BP^`RXO!"I*`BP_`5)/`C$F`S)7
M`59K`59L`S)5`5PP`C$L!"Y``59Q`59O`C$M`C$H`59N`59M`59H`C$K`C$J
M`C$G`59P`S)2`C$I`59I!"XT`59J`5PQ`C=$`C=%`5PR`C=!`C=#`C='`C=&
M`C="`S=*`5PN`5PO`CXZ`6!Q`6!P`CXT`6!N!#DT`CXW`6!R`CXX`6!S`CXU
M`6!M`6!O`CXY`SU'`CXV`CXS!#YW`D4X`T)\`D4M`64X`64[`64Z`64_`64^
M`D4Y`D4W`D4P`D4T`D4S`64\`D4V`D4R`D4Z`D4Q`64]`64W`64Y`T)]`D4O
M`T@K`DPC`6EN`DPG`6EM`DPD`6EL`T@I`D4N`D4U`DPF!$1^`6EO`DPH`DPE
M`DPB`E(Y`E(]`E(_`E([`E(Z`E(X`6UN`6UL`6UQ`6UR`E(\`6UO`E(W`6UP
M`6EK`E(^`6UM`U%Q`EA8!%%/`EA7`EA?`EA9`EA>`EA;`7%*`EA=`U%S`U%R
M`7%+!%%-`7%,`U%T`EA<`EA:!%<A!%<D`71#`EU@`U55`U53`71"`EUC`EUA
M`EUB!55I!5PV`71$`U54`U@T`F(Z`U@S`79K`F([!%MU!%MY`79I`F(\`79J
M`F(Y`F(]`U@R`F(W`7A2`F8D`7A3`7EZ`F(X`7E[`UX_`UX^`7IY`FMM`7MJ
M`FUB`7MI`V`[`F\Y`7QA`7QB`V5J!V12`G(Z`R)<`V5K`5)4`BQ``6!T`6!U
M`49U`4A+`B)G`R9T`B1Q`4LP`R9V`4Y[!"I,`5)5`5)6`5)7`C=)`C$N`59R
M!"Y!!"Y#`5PS`C=(`S=-`CX\`6!W`SU,`CX[`6!V`T)^`T,A`D4[`6US`E)#
M`E)``E)!`E)"!%%4!%%5`U%V!5Q#`U56`EUD`U57`F(^!%M\!%M]`UI>`FE`
M`FD_!&9:`FUC`49V`B@W`59S`SU-`6!X`D4\!$4T`T@P`DPI`T@N`6UT`EA@
M`V5L`F(_`FE!`49W`R9W`R9X`4Y\`5):`BQ!`5);`5)9`RXR`5)8`C$O`59T
M`S):`S);`59U`59V`5PU`C=*`5PT`S=0`S=2`S=1#S<C`SU/`CX]`5PV`6!Y
M`D4]`65``65!!$4U`6EP`T@Q`6EQ`6UU`7%.`EAA`7%-!%<M`EUE`71%`U@U
M`F)``FE"`49X`4LQ`B@Z`B@Y`4Y]`B@X`4Y^`B@[!"I5`BQ'`5)>`5)=`BQ)
M`BQ(`5)B`RXU`5)A`RXS!"I9`5)<!"I=`BQ#`BQ$`BQ%!"I2`5)C`BQ"`5)?
M`BQ&`5)@`S)D`S)?`C$R`C$V`C$T`C$S!"Y5`C$W`S)>!"Y/`S)H`C$X`C$Y
M`C$Q!"Y1`C$P`S=9`59X`59Y`S)G`C$Z`C$U`S)E`C=3`S=5`C$[`59Z`59W
M`S)<`S)C`C=-!#-/`C=,`S=3`C=.`C=/`C=1`C=0`C=5`5PZ`5PW`5P[`C=+
M`5P\`C=4`5PY`C=2`5PX`S)B`S=7!#-6`SU6`SU3`CY``CY"`CX^`CX_`SU1
M`SU2`CY#`CY%`CY&`CY!`CY$`6!Z`D5!`T,G`D5&`D4^`D5"!#\I`T,H`D5'
M`D5#`65"`65*`T,E`65%`D4_`D5``6EU`65-`65&`T,F`65+`65$`D5%`65,
M`D5$`65(`65#`65)`D5(`DPN`DPP!$5"`T@Y!$5`!$4]`T@S`T@V`T@U`T@T
M`T@X`65'`T@[`T@]`DPK`6ES`DPQ`6ET`DPO`DPJ`DPM`DPR`6ER`DPL`6UW
M`E)'`E)&`TU$`6UZ`6UX`E)$`6UV`E)%`TU&`6UY!%%?`EAI`U%[`EAK`U%Y
M`EAJ`EAB`EAF`EAE`EAC`7%0`7%1`7%/`EAD`EAG`EAH`U59`7%2`U58`71*
M`EUM`U5;`71'`EUG`71)`71+!%%A`U5<`71(`EUL`EUH`71&`EUK`EUF`EUJ
M`EUI`U@V`U@X`F)"`79N`79O`79L`U@[`79M`U@Z`U@Y`F)!!&`Y`F8G`UI@
M`UI?`7A4`F8E`F8F`FE#`FE&`FE$`FE%`FMN`UY"!&9>`7IZ`F\Z`G!"!&MT
M`7QC`G$H`G$I`7TS`49Y`5)D`S)I`CY'`SU7`D5)!&QV`49Z`4LR!"=2`4\A
M`RXV`BQ*`BQ+`59[!#-;`CY(`6![`65.`71,`EUN`F8H`FE'`49[`R9[`R9\
M#R4C`BA!`B@\`B@^`BA``B@_`B@]`4\B#R@T`5)E`BQ4`RXY`BQ/`BQ,`RX[
M`RX^`BQ3`RXW`RXZ`5)G`5)H`BQ2`BQ1`BQ0`BQ-`BQ.`BQ5`5)F`RX]#RQ<
M`V5M`V5N`5<A`V9\`5<G`5<F`C%$`C$^`C$\`S)L`5<D`C=<`59]`C%!`C%%
M`C%'`C%#`C$]`5<E`C%"`C%``59\`C%(`5<H`C%&`5<B`C$_`S)M`5<C`59^
M`V5O`S=B`5P^!#-=`C==`S=C`S==`C=6`C=8`C=:`S=?`C=;`C=9`5P_`S=A
M`C=>`S=@`C=7`V5P`V5Q`V5R`CY,`6!\`CY4`SU<`CY)!DPO`CY5`SU9`CY*
M`CY+`SU=!#E4`CY3`CY2`CY/`5P]`6!]`CY-`CY0`6!^`CY1`CY.`SU:`T,Q
M`D54`T,M`D58`655`T,N`DPX`658`D56`T,W`T,I`D53`D5.`D50`D51`D5*
M`T,U`654`T,K`T,P`653`T,T`65/`D5-`T,J`656`T,V`657`D5,`D5/`D57
M`651`652`D55`D5+#T0E!$53`DPZ`6EW`DP\`D52`DP^`6E[`DP_`DP[`T@^
M`6EX`DPW`6EZ`DPT`DPY`DP]`DPV`T@_`TA%`650`TA$`DPS`6EY`DPU`V5S
M`TA`#TH_`6U]`E))`6XC!$M9`6XA!$M7`TU*`6EV`TU-`E)0`E)1`6U\`TU(
M`TU,`E)/`E)2`6U^`6U[`E)+`E)(`E)-`E)*`6XD`E),`TU+`TU)`E).`6XB
M`U(A`V5T`7%4`EAR`U(D`EAL`EAP`EAV`EAW`EAS`EAT`EAQ!$M=`EAN!%%N
M`7%6`7%3`EAM`EAO`U(B`7%5`EAU`V5U`710`U5@`U5B`EUU`EUO`71/!%<^
M`71-`U5A`EUW`71.`EUR`EUS`EUP`EUX`EUT!%=``711`EUQ`EUY`EUV`UA#
M`U@^`UA``F)&`U@_`U@\`F)#`UA"`79P!%PR`F)'`F))`F)(`F)$`F)%`UA$
M`F8M`UIA`7A5`UIB`F8J`F8L`F8I`F8N!&!"`UIC`F8K`V5V`FE)`FE,`FE(
M`7E\`FE*`FE+`FE-`7E]`7HA`7E^`FMO`UY%`FMQ`UY#`FMP`UY$`FUD#VIF
M`V`\`G!#`G$J`49\`R0S`B1R`4\C`BA#`4\D`4\E`BA"`BQ:`BQ9`5)I`5)L
M`5)K`5)J`BQ6`BQ8`BQ7`V5W`C%+`5<J`C%/`C%.`C%-`C%)`5<I`5<M`5<P
M`S)O`S)P`5<Q`C%*`C%,`5<O`5<N`5<L`5<K`C=E`S)R`C=C`C=?`5Q``SU>
M`C=@`5Q!`C=A`C=B`C=D`S=F`5Q"`S=E`CY9`SU?`CY8`CY7`CY6`SUD`SUB
M!#E:`D5<`659!#]&`D59`D5;`T,X`65:`T,]`65;`D5:`T,Y`SUC`V5X`TA(
M`DQ(`TA'`DQ!`DQ"!4=^`6E^`6E\`6E]`DQ*!4@B`DQ)`DQ&`DQ%`DQ$`DQ#
M`DQ'`DQ``V5Y`E)3`E)8`E)6`TU0`TU1`TU/`E)5`E)4`E)7`V5Z`EAX`U(F
M`7%7`712`EU[`U(G`713`EUZ`F)+`F)*`79Q`UA%`F8O`7A6`FE.`7MK`FUE
M`V`]`G!%`G!$`B%G`5)M`5)N`C=F`V5[`65=`49]`4LU`4LT`4LS!"1H`RH^
M`RH]`BA$`RH_`RI"`4\G`4\F`RI$`5)Q`V5,`BQ<`BQ?`BQ=`RY"`5)O`5)P
M`RY``RY!`BQ;`BQ>`RY#`5<X`S)T`S)S`S)Y`C%6`C%8`C%7`5<U`C%2`S)V
M`S)[`5<S`5<R`S)W`5<V`5<T`S)X`5<W`C%5`C%0`C%1`C%4`C%3`S)\`S=I
M`S=G`S=K`S=J`C=I`C=J`C=H`S=L`C=G`5Q##S<_`SUE`6$E!DQ(`CY:`CY<
M`CY>`6$D!DQ#`SUF`6$B`SUI`CY;`6$C`CY=`6$A`SUH`T-!`D5F`D5=`D5@
M`D5D`65A`D5B!#]0`D5A`D5>`D5?`65?`D5E`65>`T-$`65C`65B`65@!#]*
M`D5C`V4D`DQ0!$5=`DQ/`TA+`TA-`DQ+`TA0`TA/`6HA`DQ.`DQ-`6HB`TA2
M#TID!$MC!$5>!$MK`6XI`TU5`E):`TU6`6XJ`6XF`6XH`TU:`6XE`6XG`TU3
M`TU7`EAY`U(J`7%:`EA[`EAZ`U5D`DQ,`7%<`7%;`7%8`7%9`U(L#UM9`U(I
M`EXB!%=)`EU^`714`EXA!%=(`EXC`EU]`EU\`F),`79T`79R`79S`UIF!&!%
M`UIE`F8P`F8Q`7A8`UIG`7A7`FE0`FE1`FE/`UQD`FUF`FUG`V!V`V!W`49^
M`B)H`4LV`BA%`4\I`4\H`BA&`RY$`RY'`BQA`5)R`BQ@`5)S`RY)`RY(`5<Y
M`C%;`C%9`C%?`5<Z`C%:`C%>`C%<`C%=`C=K`C=M`S=R`5Q$`S=Q`C=L`5Q%
M`6$H`6$G`6$F`CY?`S=P!#EE`D5I`65D`65E`T-&`D5H`D5G`T-'`V5\`DQ1
M`6HD`6HC`DQ2`DQ3`6XL`6XK`TU;`EDA`E);`E)=`E)<`EA^`EA\`EDB`EA]
M!592`7%=`U(O!%(G`U(N`EXD`715`EXE`EXF`U5H`79U`79V!&!+`7HB`UY)
M`UY(`7P]`4<A`R9^`R<A!"=;`RI'`RY.`BQB`RY/`RY-`RY+`RY,#RQV`C%@
M`5<[`S,C`S,F`S,G`S,D`5U^`5U]`S=S`SUQ`6$J`CYA`6$I`CY@`SUP!#]7
M`T-)`T-*`D5J`TA4`6HE`DQ4`6HF`TA5`U(P`U5I`U5J!%=0`UA)`7HC`FE2
M`U]5`4A,`4\J`BA'`RY1`5)U`RY0`5)T`BQC`BQD`C%B`C%D`5<\`C%F`C%I
M`C%G`S,K!"YQ`S,J`C%H`C%E`C%A`5<]`C%J`C%C`S,L`S=X`S=Y`C=V`5Q+
M`C@A`5Q(`S=W`C=X`5Q,`S=[`5Q&`S=V`C=S`C@B`C=T`C=Q`5Q*!#-\`5Q'
M!#-Z`C=W`C=Z`5Q)`C=[`5Q-`C=\`C=R`C=Y`C=]`C=U`C=P`C=N`S=Z`V5]
M`C=^#S=-`C=O#S9^!3LD`CYH`SU[`SUX`SUU`CYD`CYJ`6$M`CYC`CYE`6$K
M`CYB`6$R`CYF`6$Q`CYG`6$S`6$N`6$T`6$O`SUY`6$P`SUR`6$L`SUV`CYI
M`V5^`T-/!#]G`65H`D5U`T-,`D5X`D5L`D5Q`D5K`65J`T-5`D5O!#]>`T--
M`SUW`D5M`65I`T-4`D5T`D5S`D5P`D5R`D5N`6HJ`D5W`65F`D5V`T-1#T1%
M`TA6`DQD`TA8`6HQ`DQ?`TA@`6HP`DQ5!$5K`DQ7`6HI`DQ<`DQ;`DQ>`6HN
M`DQ9`DQ8`TA:`TA>`6HM`6HH`DQ:`6HK`DQ@`DQB`DQ=`DQ6`6HL`TA7`TA=
M`6XT`6HG!$5D`TA<`DQC!$5P`E)A`6XM`TU<`E)C!$PK`6XN`TUE`TU=`6XP
M`E)F!$MZ`E)>`6HO`E)D!$MS!$PQ!$MT!$PJ`E)@`TU@`65G`6XS!$PA!$MX
M`6XO!$PF`6XQ`6XR!$MV`7%@`E)E`E)?`6XU`TUC`E)B`V8A`EDL`EDG!%(M
M!59I`EDQ`7%>`EDI`7%B`EDO`EDF`EDC`EDR`71;`7%C`EDN`EDD`7%A`EDH
M`7%E`EDE`EDJ`7%D`EDM`EDP`U(S`U(T`EXX`EXY`EXI`EXP`EXN!%=?`U5M
M`719`EXU`EDK`U5K`EXL`U5N`EXV`718`EXK`EXJ`EXT`EXQ`EXS!%=4`EXG
M`EXW`716`U5P`EXR`EX[`EXO`71:`717`EXM`EXH`EXZ`7%?`U5Q#UM?!%=7
M`U5O`F)/`UA0`UA.`F)-`F)3`79Z`F)1`F)0`79\`F)6`79[`UA1`F)7`F)4
M`79X`F)5`F).`79Y`79W`F8U`F)2`UA,`V8B`F)8`V8C`F8R`UIO`UIN!&!.
M`7A=`7A;`F8T!&!,`F8V`F8S`7A<`7A9`7A:`7A>`V8D`7HE`UQF`FE7!6QY
M`FE6`FE4`FE3`FE5`UQE`7HD`7HF`V8E#V5G`7I[`UY,!&9O`FMS`FMR`UQG
M`UY+`FUH`U]8`FUJ`FUL`FUK`FUI`U]7`V`_`7MM`7ML`V`^`7P_`7P^`7Q`
M`F\\`F\[`V8F`G$K`G!&`G$L`7TE`V%$`7TF`G%<!&U;`V(Z`7U+`4A-`RI)
M`BA(`RI(`RY2`BQF`BQG`BQE`RY4`RY3`5)V#RTA`BQH`BQI`BQJ`S,Q`C%K
M`C%Q`S,N`S,P`C%O`5<^`C%M`S,R`C%N`C%P`S,M`C%L`5Q.`S=]`C@C`5Q0
M`C@E`5Q/`C@D`S=^`S@A`S@^`S@B!#0B`CYL`6$U`SXA`CYN`CYK`C@F`SXC
M`6$V`SXB`SU^`CYM`V8G#SXA#SXC`T-8`D5[`T-<`65K`D5Y`65L`D5Z`65M
M!$5T`TAB`TAA`6HR`DQH`DQE`DQG`6HS`6HT`DQF#TLG#TLK`TUO`TUQ`TUM
M`E)G`TUP`TUS`E)H`TUR`6XV`E)J`E)I`TUN`2,C!%)$`EDV`EDW`EDS`U(W
M`EDT`7%F`7%G`EDU`71A`U5U`U5T`71=`71B`71>`71@`71<`U(Y`71?`UA5
M!%Q:!%Q;`UA4`79]`EX\!TA7`F8X!&!:`F8W`V8H`FE8`7HG`7HH`FUN`FMT
M`V%I`FUM`V!``G$M`G%R`4A.`R<B`4LW`RI+`BA)`4\K`RI*`5)Y`BQM`5)W
M`BQK`5)\`5)X`5)]`5)[`BQL`5)Z`5="`5=!`C%\`5=*`C%U`C%[`5=&`C%T
M`C%Z`C%X`5=%`5='`C%W`5=``C%V`5=+`5=(`5=,`5=)`C%S`C%R`C%Y`5=#
M`5<_`5=$!"\E`S,W`S,[`C@U`C@N!#HF`6$[`C@M`S@I`5Q4`5Q;`5Q8`5Q>
M`5Q=`5Q9`S@F`C@G`C@J`S@G`C@I`5Q5`C@K`C@T`5Q6`C@H`C@Q`C@R`5Q7
M`C@O`5Q<`5Q2`5Q:`C@L`5Q1`C@P`S@N`S@D`C@S#S=4`S@K`SXT`C\A`CYV
M`6$X`CY]`CYZ`CYR`CY[`6$Z`CYS`SXI`CYO`SXF`SXN`65S`CYX`SXO`6$W
M`CY^`SXH`6$^`6%``CYQ`SXL!#HG`6$_`CYT`6$Y`CY\`CYU`CYY`SXJ`CYW
M`6$\`CYP`6%!`5Q3`6$]`6%"`SXD`SXU`SXS`T-G`65O`D8D`D8F`D8H`D8L
M`SXK`D8B`D5^`65Q!#]Q`D8G`D8K`D8C`D5]`T-F`D5\`T-I`T-@`T-B`D8I
M`D8A`D8E`65R`T->`65P`D8M`65N`D8J`T-D`DQY`T-H`T-J`T-C`6HW`DQQ
M`6Y#`DQ[`6HZ`DTA`6I``DQL`TAT!$5[`DQ\`DQI`TAM`DQ^`DQM`TAN`6I'
M`6I$`DQ]`DQW`6HV`6H^`6H]`TAP`6H\`6I"`TAI`DQJ`6I#`DQX`6H_`6HU
M`DQZ`6HX`6HY`6I!`DQO`DQN`DQK!$5\`DQS`DQP`DQT`6I&`TAH`DTB`6H[
M`DQU`DQV`TAQ`DQR`TAS`V8I`TAK`6I%`V8K`TXB`E)O`6X[`6Y$`6Y``E)L
M`TU\`6X]`6Y!`E)X`6XW`E)P`TUX`6X_`TXD`TXO`E)S`E)N`6X^`6Y"`E)M
M`TXN`6X\`TUW`E)W`6XY`E)V`E)U`6Y%`E`[`6XX`TXK`E)T`E)K`TUU`6Y&
M`E)R`6XZ`TXH`TXI`TXE`TXL`TXG`TU^`TU]`E)Q!$Q%`V8J`7%J`7%O`7%H
M`EE$`ED[`EE'`ED_`EE%`7%P`7%I`EDX`ED^`EE(`EE!`EE&`EDZ!%),`U([
M`EE"`7%K`EE``7%N`7%M`ED\`ED]`EDY`EE#`7%L`EE*`EE)`U)``U(_`EY'
M`EY#`71I`U5Y`EX]`71C`71S`EY)`71K`71G`EY``71N`71Q`EY+`71F`EY"
M`71O`EY-`EY*`EX^`71J`71D`71R`EY%`71M`EX_`71H`EY,`71L`71E`EY&
M`71P`EY$`EY(`U5Z!%Q?`UA9`F):`F)@`7<E`F)C`79^`7<A`F);`F)B`F)=
M`7<F`7<C`UA;`F)9`UA8`7<B`F)?`F)A`7<D`F)>`F)<`V8L!%Q>`UA:`F9"
M`7AB`7AC`7A?`UIR`7A@`UIT`F8^`F8\`UIU`F9``7AD`F9!`F8Z`F8Y`F8]
M`F8[`7AA`F8_`FE9`7HK`7HJ`FE:`UQL`FE<`FE;`7HL`UY3`UY0`FMY`FMV
M`FMW`UY1`FMU`FMX`7I]`FMZ`UY2`7I\`FUO`U]:`7Q!`7Q#`F\]`7Q"`G!'
M`G$O`G$Q`G$N`G$P`7TY!&UX`V(U`4A/!"57`5)^`C!2`5=-`S@Q#S%X`5Q?
M`C\B`C\C`V8M`TAW`EE+`71T`EY.`U5]`UA<`7<G`F9$`F9#`7HM`FM[`U];
M`FUP`7QD`B)I!"(A`4\L`4LX#RA*`BQN`RI.`C(D`C%]`C(C`C(A`5=.`C(B
M`C%^`S,\`C@V!#HK`C\D`C\E`D8P`D8Q`65U`65V`D8O`D8R`D8N`65T`TAX
M`6I(`TAY`65W`DTC`6Y'`E)Y`6Y(`TXP`7%Q`EE.`EE,`EE-`EY1`EY0`EY/
M!T%A!%QH`F9%!&!O`7AE`F9&`FUQ`7QE`G!(`4A0`4\N`4\M`BQP`5,A`RY=
M!"\P`BQO`C(F`S,]`5=/`C@W`C(E`S,_!"\O`S,^`5QA`C@Z`C@X`C@Y`5Q@
M`C\G`C\H`C\F`T-N`65Z`D8T`D8S`D8U`65Y`65X!$8F`E)Z`E)\`TXQ`6Y)
M`E)[`EE/`7%R`F)E`UA=`F)D`7AF`F9'`7AH`7AG`FE=`FM\`7I^`4A1`BQQ
M`5,B`C(I`5=1`C(H`C(G`S-"`5=0`S-#`CA`!#0]`CA"`C@[`C@\`5QB`C@]
M`5QC`CA!`C@^`C@_`5QD`SXW`6%$`6%%`SXX`C\I`D8V`D8W`T-R`DTG`6I+
M`6I)`6I*`DTD`DTE!F!8`DTF`E,C`TXR`E,D`6Y*`E,A`E)^`E,B`E)]`7%U
M`EE0`7%S`7%T`EY3`71U`EY2`F$T`U5^`F)F`F)G`7<H`UAA`7<I`71V`F9(
M`F9)`FE>`7HN`4A2`V9[`4A3`5=3`4\O`5=2`BQR`S@V!"LE`S-$`6%&`4A4
M`5,D`BQS`BQT`5,C`5,E`4A5!"=A`BQU`5=5`C(J`5=7`5=4`5=6`S@W`CA%
M`5QE`S@Y`CA$`CA#!#HX`D8X`TDB`DTH!$8L`6Y+`7%V`EE2`EE1`U8A`EY4
M!%QQ`UAB`UQO`FM]!&DN!&DM`4A6`B1S`BA*`5,F`BQV!CLA`C(L!"\Z`S-)
M`S-(`5=8`C(K`5=9`S-'`V8O`CA'`S@]`S@\`5QG`CA&`CA(`S@[`5QF`SX\
M`C\K`C\L`C\J`6%'`V<I!#]\`65[`T-S`65\!$8S`6I-`TDC`DTJ`DTI`6I,
M`TDF`SX[`TDE`V8P`E,E`TXT`TXV`E,F`TXW`TXU`TXX`EE3!%)<`U)#`71Z
M`71Y`71W`71X`71[`U8B`F)H`7<K`7<J`F9*`FE?`UQP`UQQ`UQR`7MO`7MN
M`4A7!CLD`B]]`65^`6%(`65]`6I.!F!@`4A8`B%H`4A9`4A:`R0U`R0V`BA+
M`B1V`R<D`B1W`4LZ`R<F`B1T`4LY`R<E`4L\`B1U`4L^`4L]`B1X`4L[!"1P
M`R<C`4\T`4\R`BA-`RI6`4\Q`RI;`RI8`RI/`4\V`4\X`4\U`RI9`BA0`BA,
M`4\Y`RI2`4\S`4L_`RI4`4\W`BA/`RI7!"=D`BA.!"=I`4\P`V8Q`BQ\`5,J
M`5,K`BQ^`RYF`BQX`BQ[`BTF`BTD`RY@`5,L`BTJ`5,O`BTG`BQ]`BQZ`RYA
M`RY>`C\N`BTE`5,G`BTH`BQW`BTB`5,I`5,N`BTC`5,R`5,P`RYE`BQY`5,M
M`RYD`BTA`5,Q`5,H`BTI`5=>`S-,`5=G`5=<`5=:`C(N`5=B`5=?`C(P`S-*
M`S-2`5=A`C(O`C(M`C(R`5=F`5=D`C\M`S-+`C(S`C(Q`5=;`S-.`S--`5==
M`5=@`S-/`5=C`RYC`5=E`SY$`CA2`5QI`SA)`CA)`CA+`SA'`CA,!#1-`CA4
M`CA0`CA.!#H[`CA1`CA5`5QJ`5QN`CA*!#1'`CA3!#10`5QL`SA!`5QK`CA/
M`CA-`SA"`5QH`5QM`SA%`SA(`6%.`C\V`SX^!#H^`C\T`6%0!#I'`SY#`SY%
M`SY!`C\O`D9&`SX]`6%/`C\S`SY``SY"`C\P`6%+`6%1`C\U`6%-`C\R`6I/
M`6%,`C\Q`6%2`6%*`6%)!D-:`D8^`D8\`T-[`D9"`T-^`D8Z`D9'`D8_`T-U
M`D8Y`68D`68J`D9$!$`I`D8]`T-V`68G`T-W`T0C`68E`D9%`68B`68A`D9`
M`68F`6%3`T-\`D9#`D8[`68C`68H`68I`T0B`6I4`6I0`TDG`6I5`DTM`TDJ
M!$8Y`DTL`DTN`6I2`DTK`6I3`DTQ`DTP`DTO!$9&`6I1!%)G`TX[`TX]`TXY
M`E,J`TX\`E,M`6Y1`E,L`6Y0`6Y,`6Y-`6Y.`E,I`E,H`6Y/`TXZ`E,K`E,G
M`EE5`EE?`7%Y`7%X`U))`EE9`EE;`U)'`EE6`U)$`EE:`EE4`EE=`7%W`EE<
M`EE8`EE>`U8C`EE7`71^`EY5`EY;`74D`74F`74C`74B!%@G`74A`71]`EY6
M`EY9`71\`EY:`U8D`74E`EY8!TA\`EY7`7<L`UAE`7<M`F)K`F)I`F)J`UIW
M`F9,`UIX`F9+`7AI`FEA`7HO`FE@`FM^`FUR`7MP`G$R`G$S`7Q$`4A;!"=L
M`4\Z`C\W`6I6`74G`EY<`4A<!"1S`5=I`5=H`C\X`SY'!#I,!$QB`EE@`4A=
M`5,S!#I-`SY(`C\Y`C\Z`C\[`6I7`7%Z`4A>!"=M`4\[`BTK`5=J`C(T`5QO
M`SY)`C\\`68K`6I8`7%[`74H`7<N`F9-`4A?`4\\`RI=!"=N`5=K`CA6`6%4
M`TDK`6I9`DTR`E,N`U)*`UAH`UIY`4A@`6%5`D9(`6I:`4AA`BA1`BTL`5,T
M`RYH`C(V!"]/`S-7`5=N`S-8`5=L`5=M`5=O`S-5`C(U`CA;`CA8`CA:`5QP
M`5QR`5QQ`CA7`5QS`CA9`C\]`C\^`C\_`D9+`T0F`D9,!$`N`D9*`D9-!$`M
M`68L`V8T`D9)`TDM`6I;`TDN`E,S`E,O`E,R`E,T`E,Q`E,P`EEA`EEB`EEC
M`7%\`7%]`EY>`EY=`EY?`F)M`F)L`F9/`UIZ`F90`F9.`UI[`7HP!&0L`FEB
M`FEC`UY5`FUS`F\^`G!)`4AB`4M``74I`4AC#S(R`CA<`C]``UI\`7QL`B)J
M!"%3`R0X`B)K`B)M`4AD`B)N`B)L!",O`B4B`B4C`B1[`R<H!"1[!"1U`B4A
M`4M"`R<I`4M#`B1\`B1Z`B1Y`B1]`4M!`B1^`BTM`R<K!"1Y`BA6`4\_`BA5
M`BA7`RI@`4\^`BA<`4]"`BA2`BA@`BAF`4])`BAC`4]&`RIK`BA9`BA?`BAA
M`RIF`BA4`4]%`4]``BA:`4]'`4]*`4]$`RIL`4\]`BA>`BA8`BAE`4],`4](
M`4]#`BA=`5=P`BA;`4]!`4]+!"=Z`BA3!"=^`BAB`BAD`RI>#RAC`RIH!"=[
M`RYV`5-%`5,_`5-'`5-$`BTT`BTW`5-``RYJ`BTN!"LZ`5,Y`5-#`RYK`5-&
M`5-(`BU#`BTZ`RYX`5,X`BU"`5,\`5,Z`5,U`BTR`RYR`BU!`BTV`BTY`BU&
M`RYT`5-)`BU``5-!`BT[`BU%`BTX`BT\`BT_`RYI`RYN`BTP`BU$`BT^`RYO
M`RYZ`BTO!C0\`BTS`5-"`5,]`5,V`5,[`5,W`5-*`BTQ`C)'`5,^!"L]`RYY
M`BT]`BE"`RYW`V8U`V8W`C)*`5=^`S-B`C(Z!"]=`C)%`C)!`SA-`C)4`S-9
M`C),`S-?`C)"`SA;`C)+`C(\`C)``C)7`5@C`C)/`C)&`5=Q`C)5`C(X!"]:
M`C).!"]C`5@B`5=[`C(W`5=Y`5=X`5=]`C)-`5=U`5=\`BTU`C]!`C)(!"]?
M`RI?`C(^`5@A`C(_`C)#`5@D`C(Y`C)1`SY7`C)0`C)8`5=W`5=T`C)6`C)2
M`C))`C)$`5=Z`5=V`C([`5=R`C)3`5=S!"]<`C(]`S-:`S-C`V8V`RTS!#1G
M`SA.`SA1`CAB`CAD`CAI`CA]`5TC`5QW`SA4`CAA`5TD`5TE`CAL`CAS`CAY
M`SA0`CAF!#1M`CAM`SA/`SA=`5TF`CA[`CAV`5TA`5Q]`CAR`CAN`CA@`5QT
M`CAE`CA=`SA5`5Q\`5Q^`CAJ`CAG`5QY`CAW`5QV`CAH`C]J`CAP`SA>`CAO
M`5QU`SA7`5TB`SA2`5QX`CA>`CAC`CAT`CAZ`5TG`CA?`CAK`CAQ`5Q[!#1O
M`SA8`CA\`CAU`CAX`SA?#S=X`5QZ!#IH`C]1`C]%`6%=`C]B`C]K`C]N`6%;
M`C]-`C]F`C].`C]<`6%H`C]8`6%E`SY>`C]9`C]"!3MO`C]G`SY/`SY9`6%N
M`C]D`C]:`C]P`C]5`D9M`SY-`C]S`6%L`C]3`C]?`6%O`6%:`C]7`C]Q`C]0
M`C])`C]4`SY?`C](`C]&`6%6`C]H`C]/`C]L`SY+`C]M`6%>`6%C`6%?`6%G
M`C]C`6%@`C];`C]+#SYF`6%8`C]#`C]E`C]O`C]*`6%F`C]T`C]6`SY2`C]2
M`SY<`6%7`6%K`SY:`C]A`6%M`SY0`C]=`6%B`6%<`6%D`6%9`6%J`C]>`C],
M`C]@`C]'`C]I`SY8!#IG`SY=`SY6`SY.`C]R`V8Y`SY;`V8X`C]$`D9L`T0M
M`D<D`65<`D9Q`T0Q`D9O`D9:`68P`D9J`D9^`D9F`68X`D9]`D9D`6%I`D9T
M`D9E`D9[`68W`68O`T0Z`D9/`D97`T0U`D9P`D9H`D<C`D9K`68]`D9\`T0L
M`68T`T0^`D9N`D9V`D9;`D9U`T0G`D<H`D96`D9W`T0S`D<F`T0_`D90`6%A
M`T1``D9>`D9=`68V`T0R`D9A`D9C`D9R`D<E`68Y`T0X`68Z`T0P`D95`68R
M`D99`D<A`68[!$!$`68S`68U`68\`D<G`D9X`D9S`T0\`T0O`D9@`D9?`68Q
M`D91`68N`D9I`D92`D9G`T0N!$!!`D9<`D<B`T0J`T0Y!$`V`68M`T0[`T0H
M`D98!$!&`D94`D9Z`D93`6IH`DU:`TDU`TE$`DU)`TDS`TDX`DTS`DU1`6I@
M`DU"`DU,`6IC`DU%`6IA`DTV`DU4`DTU`DU(`TD\`DTT`TDY!$9L`DU&`DU/
M`DU-`DU!`DT\`DTZ`TE"`DT[`DU.`DU9`DU#`6IB`TD[`DT^`TDZ`DU2`TE!
M`6IE`DT]`DTW`DU'`6II`TDR!$98`6I=`6IF`DT_`DTY`TDV`6I?`D9Y`6I>
M`DU*`T0V`6I<`6IK`6ID`DU+`DU``DTX`DU3`DU$`6IJ`DU7`6IG`DU6`TD_
M`DU0`DU5`TD^`TE#`DU8`V8[`V8\`V8Z`TD]`E-<`E-=`E-0`E-/`E-+`6Y=
M`TY/`6Y5`E-?`E->`D9.`E-(`E-,`E-&`TY$`E-9`E-*`TY"`E-@`E-#`E-!
M`E--`E-7`E-2`6Y?`E,X`TY``E-6`TY,`TY&`TY4`6Y@`D9B`E-$`E,[`E,^
M`E-D`E-%`E,\`E,Z`E,W!$QZ`6Y9`E-.`6Y8`6Y<`E-)`E-1`6Y2`E-A`E-E
M`6Y4`TY+`E-``E-4`E-8`E,]`E-B`6Y;!$QJ`6Y:`E,U`6Y>`E-;`E,_`E-3
M`E,Y`E-'`E-"`6Y6`6Y7`E-5`E-F`E-C`E-:!$QX`TY-`TY.`TY2!$QT`E,V
M`6Y3`EET`U):`EEK`EEN`U)2`7(E`EEP`EEE`EEL`EER`7(B`7(F`7%^`U)9
M`U)0`EEG`EEW!$TE!%,S`EEQ!%,D`EEH`EHB`EEZ`EED`EYR`EEJ`7(A`U)8
M`EEU`U)4`EHA`7(I`U)6`EE\`EEI`EEO`EES`EEM`EHC`EE^`EE[`7(C`7(D
M`7(H`EEF`EHD`7(G`EEX`U)/`U)5`EEV`V8]`EEY`E\A`EYL`EYQ`EY^`EYP
M`EYH`EYM!%@^`74L`U8K`EYA`EYY`EY[`EY@`74K`EY]`EYU`74R`EY\`EYN
M`74T`EYF`EE]`EYV`EYS`EYB`E\C`74N`U8H`U8I`74O`EYD`EYT`U8M`E\B
M`EYW`EYJ`74Q`74M`EYX`EYK`E\D`EYE`EYO`EYZ`EYG`EYI!%A``74U`EYC
M`74S`7<P`74J`U8L`U8P`74P`7<T`F)]`UAL`F)S`F)N`F)T`F)^`F,D`F,C
M`7<V`7<U`UAN!%TL`F)U`F,E`F)X`F)P`UAO`F)R`F)Q`F)W`F)\`F)O`F)V
M`F)[`7<S!%TH`F)Y`UAK`7<Q`F)Z`7<O`7<R`F9@`F,A`V8^`7AM`UI^`F98
M`F9<`F94`F97`UI]`F9?`7AK`F9D`F9=!&!Z`F95`F9E`F9>`7AN`7AO`F9B
M`ULB`F96`7AJ`7AL`F91`F99`F93`UQ[`F9C`F9A`F92`F9:!&![`ULE`V8_
M`FEJ`7AP`F9;`7HR`7HT`7HQ`UQV`FEO`FEG`FEE`FEI`FEF`UQX`UQ\`FEK
M`FEM`7HU`7HW`UTB`FEL`7HX`7HV`FEN`UQ^!&0W`UTC`UQW`7HS`UTA`UY;
M`UY:`7LA`FPA`FPG`7LC`FEH`FPF`UY<`FPM`FPD`FPK`FPJ`FED`FPE`F,B
M`FPN`FPC`FPH`UY8`FPL`FPB`UY6`FUW`7LB`FPI`UY7`F]#`FUX`FUV`FUT
M`FUU`FUY`V9``7Q%`F]!`F\_`F]$`F]"`V!#`F]%`7Q&`F]``V`O`V%&`G!*
M`V9!`G$T`G$U`G$V`V%'`V%\`G(U`G(M`B)O`4]-`5-+!"]H`C):`C)9`5@E
M`5TH`CDA`SAC`SA@`CA^`SAA`6%P`68_`SYA`68^`69`!4E.`DU;`E-G`EHE
M`EHG`EHF!S)A`74V`E\E`F,F`G%S`4AE`R<M`BAI`BAJ`BAH`BAG`4].`V9"
M`BU*`BU(`R\C`RY\`BU'`RY^`5-,`5-.`5--`BU)`R\D#RT^`S-I`C)F`C)C
M`C)A!"]M`S-L`5@F`C)D`5@K`C)>`C)M`S-O`C)O`C)?`S-N`5@H`C)P`C)K
M`C)=`C)B`C)L`C)H`C)E`S-K`5@M`C)N`C)@`S-J`S-P`C)I`C);`5@L`5@I
M`C)G`S-M`C)J`C)<`5@J`5@G!#1Z`SAF`5TR`CDH`5TQ`SAD`CDK`CDN`5TN
M`5TL`CDC`CDL`CDJ`CDG`CDO`CDP`CDR`CDS`CDB`5TK`CDE`CDD`CDQ`5TM
M`CDF`5TO`5TJ`CDI`5TS!#4F`5TP`CDM#S@Z`6%W`D`E!#IQ`C]X`6%T`SYB
M`D<N`D`C`C]U`6%R`C]Z`6%U`C]^`C]\`6%X`6%Q!#IV`SYC`C]V`C]Y`6%V
M!#IO`C]W!3M[`D`D`D`B`C][`C]]`D`A`6%S`SYH`D<O`D<U`D<K`D<Q`69!
M`D<M`69'`T1$`T1%`69&`T1)`69%`D<T`69(`69)`D<J`D<W`69*`69$`69#
M`D<S`69+`D<I`D<L`D<V`D<R!$!9!$!2`DU[`DUP`69"!4)=`T1&`T1(`6IR
M`DUD`DUY`DUE`6IM`TE/`DUB!$!5`DUK`DUC`6IO`DU=`DUX`6IP`DUU`DUV
M`DU>`6IU`DUM`TE*`DUG`DUN`DUA!$9^`DUZ`DUR`DUL`DU<`6IQ`DUS`TE%
M`6IT`DUW`TE,`DUQ`6IN`DUO`TE)`DUI`6IL`DU@`DUH`DUT`DUF#TPS`TE.
M`DUJ`TE+`V9#`6YJ`D<P`E-Y`E0D`E-X`E-T`E-Q`6YK`E-O`6IS`E-H`6YI
M`E-N`6YH`E-S`E-P`E0B`E-[`E-U`E-Z`6YD`E-R`E0G`E-I`E-J`E0C`6YE
M`E0H`6YG`E0I`E-W`DU?`E-]`E-V`E0A`E-\!5!5`TY=!$TH`E-M`6YB`E0F
M`6YC`E-K`6YF`EHR`E-^`E0E!$TQ`TY9`EHO`6YA`7(J`EHY`EHU!%,\`EHS
M`EHN`EH]`U);`U)=!%-$`7(N`U)?`EHJ`EHV`EHW`EHM`EHL`EHZ!%-!`EHP
M`EHK`EHQ`U)B`EH\`EHI`EH[`EHX`7(L`7(K!%,Y`U)>`7(M`EHT`EHH`V9%
M`V9$`E\G`74\`E\K`E\H`E\O`E\U`E\J`U8Z`E\^`74Y`E\X`E\M`E\Y`E\T
M`E\[`E\L`74^`74]`E\N`E\\`E\F`E\Z`74W`U8Y`E\R`E\Q`E\V`E\I`74[
M`U8[`74_`E\P`E\W`75``E\S`U8V`U8T`74X`74Z`F,S`F,Q`ULH`UAV`F,W
M`F,U`F,X`UAX`F,J`F,R`F,\`E\]`F,N`7<Z`E-L`F,I`F,V`F,P`F,M`F,H
M`F,G`F,[`UAS`F,L`F,K`7<X`F,T`UAT`7<W`UAU!61(`7<Y`F,O`F,Z`V9&
M`F9I`F9J`ULL`7AT`F9G`7AQ`F9O`ULG`7AU`F9Q`F9F`F,Y`F9S`F9H!6E#
M`7AR`F9N`ULI`F9P`F9K`F9R`F9M`F9L`7AS`UAW`ULK`FEQ`FER`UTE`FET
M`7HY`7HZ`FEU`FES`UTD`FEP`UY=`FPQ`FPT`FPP!&$F`7LG`FPR`7LF`7LE
M`7LD`FPS`FU^`FU\`U]?`FU[`FPO`FU]`FPU`FUZ`V!%`F](`F\F`F]&`7Q'
M`F]'`F])`V9'`G!-`7QF`G!,`G!+`7QG!&PC`7TG`G%=`G%U`G%T`G%V`4AF
M`BU+`R\F`C)Q`C)R`SAJ`SYJ`SYI`D`F!DY/`FPV`G!.`4AG`5-/`BU,`S-Q
M`V9(!#4G`CDT`5TT`D`H`D`G`6%Y`T1-`69,`E0J`6YL`TY?`6YM`U)C`U)D
M!%-+`7(O`7QH`4AH`R\G`BU-`4]0`BU/`BU.`5-0`C)S`S-T`C)Z`5@N`C)X
M`C)V`S-W`C)]`C)T`C)U`5@O`S-R`5@S`S-S`S-U`C)^`5@R`C)\`C)Y`C)W
M`5@P`5@Q`C)[`S-V`V9)`5TV`CDU`SAR`5T[`CE%`5TZ`CE'`SAN`SAT`CD[
M`5TX`CE&`SAL`CDV`5TY`CE"`CD^`CE``CDZ`CE!`SAK!#4O`5TU`CD]`SAS
M`CD\`CDX`SAM`CE#`SAO`SAQ`CD_`CDW`SAP`CDY`5TW`CE$`6%\`D`S!#I[
M`SYP`SYR`D`O`D`Q`D`L`D`K`D`I`SYM`D`P`D`R`D`N`SYO`D`M`6%Z`6%[
M`D`U`694`D<Y`D<_`D<Z`D<[`T1.`D=`!4)L`696!$!A`69.`695`D<X`D`J
M`691`69/`D<^`D<]`690`692`D<\`69-`T1/`693`TY@`DU]`6I\`TE9`TE2
M`DXJ`DXI`TE7`DXD`6I^`DXH`DU^`DXA`6IV`6IX`TE4`DXF`DU\`6IZ`6IY
M`DXB`DXG`DXE`6I[`DXC`TE1`TE6`D`T`6IW`TE8`E0K`E0R`6YO!$U&`E0V
M`6YS`E0N`E0L!$T^`E0U`TYA`6YN`E0T`6YP`6YQ`E0M`6YR`E0S`E0O`E0P
M`E0Q`6I]`TYB`EH^`EI*!%-3`7(T`EI%`EI'`U)E`7(R`EH_`EI#!%-0`EI&
M`7(P`7(S`EI)`EI!`EI"`EI(`EI``EI$`7(Q`E]``E\_`75"`E]%`75$`U9`
M!%AB`75!`E]!`75%`E]"`U8_`U8]`E]#`E]&`U9"`75#`F-!`UAY`F-$`UAZ
M`F,^`F-``UA\`UA[`F,_`F-"`F-#`E]$`F,]`V9*`7AX`F9W`F9Z`F9\`F9U
M`F9V`F9Y`F9[`7AY`7AW`7AV`F9X`F9T`FEV`7H[`UTI`FEW`UTH`FPX`7LH
M`FPZ`7LI`FPW`FPY`7MR!70X`FXA`7MQ`F],`F]+!&PE`F]*#VA*`V%)`G$W
M`G$X`G$Z`G$Y`V%]`B)P`4AI`5-1`CE(`6%]`V9+`D=!`7<[`ULO`F9]`V!&
M`V%*`4M$`R\I!"]V!"]U`5T]!#4T`SAV`SAU`5T\`SAW`D`V`6%^`D`X`D`W
M!DY@`SYT`D="`697`DXK`DXN`DXM!$<U`DXL`E0W`E0Y`E0X`TYE`7(V`U)F
M!%-9`TYD`7(U`U9&`75&`E]'`E])`E](`UA^`UA]`7<\`UDA!&$O`ULQ`F<A
M`F9^#V-W`FEX`7H\`UTJ`UYA`7LJ`FXC`FXB`7TH`4M%`BU0`5-2`CE+`CE)
M!#4Y!#4X`CE*`D`Z`D`[`D=)`D`Y`D=#`D='`D=&`D=(`698`D=%`D=$`D=*
M`T14`DXQ`DXO`TE<`DXP`E0\`E0Z`TYF`E0[`EI+`E]*`E]+`7<]`ULR`F<B
M`FEY`7H]!&$W`FP[`FXD`7MS!&E%`F]-`G$[`4M&`5-4`5-5`BU1`R\J`R\L
M`BU2`5-3!"]\`5@Y`S-[`5@W`S-Z`5@V`5@]`5@U`5@^`C,A`5@[!"]]`5@X
M`5@\`5@Z`5@T`S-\`5U%`SA^`5T_`CE/`5U$`SDC`SDI`5U&`5U`!D1P`5U!
M`SAY`CE-`SA[`SDE`5T^`SDB`CE.`5U#!#4]!35;`CE,`5U"`SAZ`6(K`SY\
M`6(M!#LO`SY]`D`^`6(L`6(A`6(E`S\D`69K`D=/`D!``6(F`SY^`SYU`D!#
M`D!$`6(J!#LP`D!&`S\A`D!(`S\C`D!)`D`]`D`\`D!*`6(I`D!'`D!%!#LL
M`6(G`6(C`6(N`D!!`D!"`D`_`SYX`6(H!#LQ`S\B`6(D`6(B`D=.`69F`69A
M`T1@`T19`69<`T1C`69L`69=`T15`699`69H`69E`69G`T18`69>`69C`69:
M`69;`D=6`D=3`D=+`D=0`T1;`69I`D=7`69J`69@`T1<`T1A`D=-`T16`D=5
M`D=1`D=4`D=2`69D`D=,`69?`T1=`DXT`6LB`6LE`TE?`DXV`TED`6LM`DXU
M`6LG`TEC`6YX`DXW!$=%`6LL`DXS`6LN`TE>`TEB`TEK`6LC`TEH`69B`6LF
M`TE@`6LD`6LH`6LJ`6LA`6LO`6LK`TEE`6LI`DXR`TEF#TQ!`TYT`6\A`TYG
M`6Y[`TYR`TYP`TYN`6\D`TYL`E0_`6\E`E1+`E1$`6YT`E1,`E1&`6Y^`E1'
M`TYS`6Y]`E1*`6YW`E1(`E0^`6YV`EI6`6Y\`TYU`6YY`TYI`6\C`TYJ`E0]
M`TYV`E1!`6YU`E1``E1"`E1#`6\B`E1%`E1)`E1-`6\F`7(\`EI1`EI7`EI4
M`EI,`EI8`EI-`U)J`EI3`U)K`7(W`7(]`EI9`TYO`U)G`7(Y`U)N`7)#`7(^
M`EI;`EI5`7(Z`EI.`7)$`EI/`EI0`7)%`7)"`6YZ`U)I`7(X`EI<`7)&`U)H
M`7(_`EI:`7([`7)``7)!`V9,`75.`E]0`E]9`E]6`E]8`U9)`75+`E]1`U9*
M`E]7`75'`E]3`75/`E]/`E]4`E];`EI2`E]5`E].`75(`E]-`75)`E]<`75*
M`E]:`75-`E],`U9(`75,`E]2`F-'`F-5`F-0`F-2`F-&`7<^`UDJ`F-%`7=!
M`7=``UDF`F-4`F-,`F-)`F-/`UDD`F-(`UDH`F-*`F-3`F-1`UDC`7<_`F-8
M`F-6`F--`F-7`F-.`ULT`F<F`7AZ`F<M`ULU!&$Z`FP^`7DC`F-+`F<D`7A]
M`F<E`F<J`ULV`UTS`7DA`7DB`F<C`F<L`F<N`F<G`F<I`F<K`F<H`F<O`7A\
M`7DD`7A^`7A[`FE\!&1-`7I"`FEZ`UTP`UTL`FE^`UTR`FHA`7I``FHB`FE]
M`UTK`FE[`7I#`7H_`FHC`UTN`7I!`7H^`UQM!&<[`7LK`UYB!&=!`7LL`FP]
M`FP\`FP_`FQ``UYC`7LM`FXE`FXJ`7MT`U]A`FXG`U]B`FXF`FXI`FXH`V!(
M`F]1!&I\`7Q(`F]0`F].`V!'`F]/`V!)`V![`7QJ`7QI`G!/`G!0`7QK`V%+
M`G$\`G$]`7TT`V%K`7TZ`V%^`G%W`G(V`4M'!3!&`CE0`SDJ`CE1`D=8`DXX
M`E1.`751`U9-`750`F-9`F<P`U]D`F]2`4M(`C,B`5@_`5U'`D=:`D=9`6\G
M`E1/`6\H`E]=`7="`UTT`V9-`V(A`7U#`4M)`BAK`C,C`SDM!#5-`5U(`SDL
M`CE2`CE3`S\J`D!+`S\I`6(O`69M`T1D`D=<`D=;`D==`TEM`DXY`DXZ`6LP
M`7)'`6\I`7)(`E]A`E]>`E]@`E]?`752`UDK`F-:`F<R`F<Q`B4D`5A!`5A`
M`C,D`SDN`CE4`S\L`S\K`D!-`D!,`6(P`S\M`D=?`D=@`D=>!$!X`T1E`69O
M`69N!$=4`6LR`6LQ`TYZ`E10`EI?`EI=`EI>`7))`E]C`E]B`U9/`F-=`F-<
M`F-;`F<S`V%-`G%X`4M*`5-6`R\N`5-7`5A"`5A#`C,F`C,E`CE5`SDP`5U.
M`5U,`5U)`5U-`5U+`5U*`SDR`SDQ`6(Q`D!0`S\O`69T`6(S`6(X`D!2`6(Z
M`6(Y`6(\`D!1`D!.`6(V`6(R`6(T`D!/`6([`6(W`6(U`69V`69U`69S`69W
M!$!^`69Q`69R`T1I`69P!4,M`D=A`T1G`DX\`TEP`6LT`6LU`6LS`TER`DX[
M`TEQ`DX]`V9.`E13`E15`TY^`6\R`E16`6\K`E12`6\J`6\T`6\P`6\Q`6\M
M`E11`6\L`E17`E14`TY]`6\S`T\B`6\N`6\O`EIA`U)U`EIC`EIB`U)S`EID
M`7)*`EI@`U91`U92`756`E]D`753`757`755`754`F->!%UI`F-A!T-2`F-@
M`UDN`F-?`7=#`F<T`F<U`7DE`F<V`7DF`ULX`V9/`7I%!&1/`7I$`FQ!`UYE
M`UYF`7LN`FQ"`FXK`7MU`7MV`V90`F]3`V!*`7QM`V%.`4M+`SDS`5U0`5U/
M`D=B`D=C`6LV`EIE`6\U`EIF`E]E`4M,`R0Z`BU3`5-9`5-8`C,G`5A$`C,H
M`CE8`SDY`CE7`SDW`CE6`SDU`SDX`D!4`6(_`S\Y`S\T`D!3`6(^`S\W`S\P
M`S\S`D!5`6(]`S\X`D=E`D=H`D=F`D=G`D=K`D=D`D=L`D=I`D=J`6LX`DX^
M`TEU`TES`6LW`TET`E1;`E19`T\F!$UU`6\V`E18`E1:`T\E`6\W`T\C`EIG
M`U)W`EIH`758`UDQ`F<X`F<Z`F<W`F<Y`FHD`FQ#`V91`G%>`4M-`5-:`C,I
M`C,K`C,J`CE;`5U2`SD^`CE9`SDZ`5U1`CE<`SD]`CE=`CE:!D4X`D!A`6)'
M`D!9`D!?`S\_`S\Z`6)"`6)%`D!8`6)``D!<`D=R`6)$`S\[`D!7`S\^`D!=
M`D!:`D!@`D!6`D!>`6)#`6)&`D!;`6)!`69Y`D=N`69X`D=U`D=T`6<A`6<B
M`D=V`69Z`D=S`69^`D=X`D=O`T1K`D=Q`69[`D=M`D=P`D=W`69\`D=Y`69]
M`6LY`DY#`DY)`DY!`DY*`TE[`DY``DY%`DY+`DY(`DY'`DY&`TEZ`DX_`DY$
M`TEY`DY"`6\\`6\Y`E1D`E1I`E1K`E1H`E1A`E1C`E1M`E1J`E1E`E1N`E1B
M`E1L`6\Z`6]``6\^`E1<`6\_`6\[`E1=`E1?`E1>`E1F`E1G`T\L`6\]`T\K
M`6\X`E1@`EIR`7),`U)^`EII`7)-`7)0`EIN!5%(`EIK`7)/!%0I`U)[`EIO
M`EIP`EIJ`EIS`EIL`EIQ`7).`U)\`7)+`EIM`U94`E]K`75;`759`75<`75:
M`E]J`E]G`E]F`U95`E]I!%DM`E]H`F-O`7=)`F-F`F-E`UDR`7=$`F-K`F-J
M`F-B`F-M`F-G`7=(`F-D`F-L`F-C`7=%`7='`F-H`7=&`F-I`ULZ`F-N`F<^
M`ULY`7DK`F<[!&%2`F<_`UL[!&%/`7DH`F<]`7DM`UL\`7DJ`UL]`F<\!&%4
M`7DL`F=``7DG`7I'`7I)`UTW`FHG`7I(`FHE`7DI`FHF`7I&`7LO`7LQ`FQ%
M`7LP`FQ$`FXP`7MW`FXO`7MX`FXM`FXL`FXQ`FXR`F]4`V!+`FXN`G!4`G!1
M`G!2`G!3`7TI`V%0`G%``G$_`G$^`G%?`V%L`G(N`G%Y`7T[`4M.`5A%`SD_
M#SAL`SE``S]``T1S`6<C`TE]`TE\`T\P`T\R`T\O`T\Q`6]!`V92`EIT#U@S
M`UDU`7=*`UDV`F=!`UL_!&%6`UTX!&=1`G%Z`4M/`4]1`5-<`5-;!3!5`5A(
M`S0A`C,L`5A&`C,M`5A'`V93`SE!`CEB`CE>`SE'!#5C`5U3`CEA`CE@`CE?
M`5U4`CEC`CED`S]%`D!H`D!F`D!J`D!K`D!Q`S]'`D!M`D!O!4-0`D!G`D!B
M!#M5`D!N`S]$`S]&`D!P`D!I`D!L`D!C`6))`D!E`D!D`6)(`6)*`S])`6<F
M`D=[`D=]`D=\`D@C`6<D`T1V`D=^`D=Z`D@A`D@B`6<E`6<G`D@D`DY/`DY.
M!$=J`DY,`DY-`6L[`6L]`6LZ`6L\`E1U`E1V`E1Q`T\V`E1R`6]#`6](`6]"
M`6])`6]$`E1S!$XM`T\S`E1T`E1P`6]*`6]&`T\U!$XK`6]%`6]'`T\T`E1O
M`U,D`EIV`7)2`U,B`U,A`EIX`7)4`EI[`EIW`EIU`EIZ`7)3`EIY!S0R`7)1
M`U,E`U99`75>`75A`E]M`U9:`75?`E]L`75=`75@`F-P`F-Q`F-R`7=+`UDW
M`F-S`7=,`7DO`F=$`F=%`F=#`F="`F=&`7DN`FHK`FHI`FHJ`FHL`FHH`FHM
M`FQ'`UYG`FQ(`FQ&`7LR`FXS`7MY`FXT`F]6`F]5`V(B`4M0`6)+`S]+`T1W
M`6<H`T1X`THA`THB`6L^`T\W`U,G`7)6`U,F`7)5`V94`UDX`7DP`7HI`7LS
M`4M1`5A)`6<I`T\Y`F='`R<O!"%4#R%J!",P`R0[#R)Q#R)R`R<P`B4F!"4A
M`R<S`4M2!"4C`4M5`4M4`4M3`R<Q#R4R`B4E`RIR`BAM`RIP`BAO`4]2`RIT
M!"@F`4]4`BAL`BAN`4]3`BAQ`BAP`BAR`RIS`RIQ#RAQ#RAN`BU7`BU5`5-?
M`BU4`5-D`5-A`5->`R\Q`5-E`R\R`5-@`5-C!C1@`5-B`BU6`R\S`5-=`R\P
M`5A/`C,O`C,U`5A,`5A3`S0E`5A.`C,R`C,T`5A1`C,N`C,Q`5A-`5A*`C,P
M`5A0`C,S`5A2`5A+!#`O`S0G`S0F`CEF`CEI`5U6`SE+`5U@`5U<`CEG`SE*
M`SE.`5UD`5U=`5UB`5U8!#5H`5U5`5U7`5UC`CEH`5U;`5U>`5U:`5U?`CEJ
M`5UA`5U9`CEE`SE,`S]/`S]0`S]-`S],`S]1`D!R`6),`D!T`S]5`6).`6)0
M!#5F`D!S`6)-`6)1`S]6`6)/`S]4`S]7`6<O`D@I`6<W`D@F`T1]`6<X`6<M
M`T1Y`D@G`T1\`T1Z`6<R`T1[`D@H`6<K`6<J`T1^`6<U`6<T`6<S`6<Q`6<V
M`D@E`6<L`6<N`6<P`6M``6M#`THD`6M'`6M!`6M&`6M$`THG`6L_`THF`6M%
M`6M"#TQK!$XR`E1Z`6]-`6]+`T\\`E1[!$XS`6].`6],`E1Y`E1X`T\[`7):
M`E1W`7)8`7)7`EI\`6]/`7)9`EI]`7)<`EI^`7);`75C`E]O`75B`75G`75E
M`75F`7=.`75D`E]N`ELA`7=-`7=/`UDZ`7DQ`7DR!&%?`FHN!&E2`7Q*`7Q)
M`4M7`R)>`R)=`B)U`5A4`R0\`B)R`B)S`B)Q`R0]`B)T`V95`B4J`B4G`B4L
M`B4H`4M8`4M;`R<U`B4I`4M:`B4K`R<Y`R<T`4M9`SE1`RIW!"@K`BAU`BAW
M`4]7`BAS`BAV`BAT`4]5`4]8`RIU`4]6`RIX`R\U`BU9`BU=`BU:`R\X`5-H
M`R\T`5-I`R\^`BU<`R\W`BU>`BU@`R\\`5-F`BU?!$$Y`R\[`5-G#T5M`CEQ
M`BU;`C,V`C,_`C,]`C,X`C,Y`C,^`C-``5A6`S0I`C,[`C,W`5A5`5A7`C,Z
M`C-!`C,\`5UE`CET`CEL`CER`CES`5UF`SE/`CEK`CEM`BU8`CEO`CEP`CEN
M`6)3!$X[`SE2`D![`ELB`D!\`D!Y`5UG`6)5`D!X`D!^`D!]`6)2`D$C`D!W
M`D$B`D!U`D$A`D!Z`6)4`S]9`D@P`T4C`D@K`D@Q`D@L`D@J`D@M`6<Y`T4D
M`D@O`T4E`D@N`6<Z`6M)`6M(`DY6`DY9`DY1`DY5`6M*`DY4`DY2`DY8`DY3
M`DY0`DY7`THJ`E4C`6]2`F-T`E1^`E4A`E1]`D!V`6]1`E4D`E1\`6]0`6]3
M`E4B`ELC`7)=`ELD`ELE`U,K`E]P`75H`F-U`F-V`UD\`UD[`F-W`F=)`F=(
M`FHP`FHO`FQ*`FQ+`FQ)`FXU`7MZ`4M<`5-K`5-J`5A:`5A9`C-#`C-$`C-"
M`S0J`5A8`CEX`SE5`CEY`CEU`5UH`CEV`SE4`CEW`V97`D$F`D$H`D$D`D$G
M`6)6`D$E`6)7`T4H`D)Y`6<]`6<\`T4G`6<[!$$Z`D@R`D@S!$$[`DY;`DY=
M`6M.`6M+`THL`6M-`6M,`DY<`DY:`THK`THM`E4K`E4H`E4I`6]7`E4J`E4E
M`E4F`6]4`T\_`6]5`E4G`6]6`T]``ELI`U,M`ELJ`ELG`ELH`7)>`ELF!%1"
M`U,L`U,O!%D_`E]T`E]Q`E]S`75K`E]W`75J`E]U`E]X`E]V`E]R`75I`F-Y
M!%XD`F-Z`F-X`UD]`F-\`7=0`7=1`F=+`7DT`F-[`F=*`7DS`FHS`FHT`7I*
M`FHR!&1E`FHQ`FQ,`7LT`UYH`F]7`G!6`G!5`V!^`7QN`7TJ`G!7`G%@`V%M
M`7T\`4M=`4]9`6<^`7I+`4M>`5-L`5UI`6)8`7=2`4]:`BUB`BUA`C-%`S0P
M`5A=`5A;`5A?`C-'`S0M`5A>`5A<`S0O`S0N`S0Q`C-&`5UL`CHA`SE8`5UK
M`5UM`CHF`5UO`CHC`CHD`CEZ`5UN`CHG!#5[`SE7`CE\`SE6`CE]`CE[`5UJ
M`SE9`CHE`CE^`CHB`D$T`S]=`D$S`D$Q`D$I`D$X`D$L`D$V`D$]`D$U`6)@
M`S]F`6)<`D$J`S]@`D$P`6)>`S]H`D$O`6)?`6)A`D$R`S]I`6)9`6):`D$^
M`D$\`S]B`D$[`D$M`S]E`D$Y!#MF`6)=!D]O`S]>`V99`S]C`6);`D$Z`D$K
M`D$N`D$W`V98`D\B`D@]`T4N`D@V`DA)`DA2`D@Y`6=)`T4K`DA&`6<_`6=!
M`6=-`D@W`T4W`T4O`6="`6=$`6=.`6=#`T4Y!$%!!$%&`T4X`6=,`D@_!$%(
M`D@T`6=*`D@^`6=&`DA0`6=+`DA.`DA"`DA,`6=(`D@U`DA/`DA*`T4J`DA1
M`6=`!$%``T4M`6=/`6=%`T4Q`T4I`D@[`T4T`DA#`DA'`T4S`DA+`6='`D@Z
M`D@X`DA$!$%"!$%#`T4R`T4U`DA!`DA``T4V`DA%`DA(`DA-`V9:#T5R!$=U
M`DY@#TTB`6M/`DYJ`DYB`6M5`6M9`DYS`DY[`DYL`6M1`THT`DYP`D@\`THU
M`6M2`DYW`DY\`DYT`THO`DYV`D\A`DYX`DYF`DYO`T4P`THX`6M:`THS`6M6
M`DYD`DYQ`6M4`DYK`6M3`DYY`DYH`DYA`6M7`DY^`THY!$=W`DYC`DYU`DYR
M`DYM`DY?`DY>`DYG`DYZ`6M8`DY]`DYE`DYI`6M0`THR`THW#TTG`V<J`THQ
M`6]C`6]>`E5-`E5)`E4Q`6]:`T]"`T]0!$Y%`6]9`6]?!$Y'`T]#`T]!`E4O
M`6]=`E4[`E4M`E4N`6]8`E5,`6]A`E4^`E5#`E4]`EL\`E4Y`E5!`E4_`E4R
M`E4L`E5'`6]@`E5(`T](`E5"`T])`E4W`E4U`E4P`T]+`T].`T]$`E4X`E5%
M`E4T`E5$`E5*`T]1!$Y&`6]<`T]%`E5``E5&`E4\`E4V`6];`T]2!$Y$`T],
M`DYN`E4Z`6]B`E4S#U)K`T]-`V9;`V9<`THP`EM!`7)A`EM``EL^`EM0`7)E
M`U,U`EM-`EM%`EM/`ELW`EM#`U,]`7)G`U,^`ELO`U,X`ELM`EM.`U,R`EM,
M`EM+`EL[`ELZ`ELP`7)I!%1#`ELV`EL_`EM*`7)L`EM1`U,V`75S`7)N`7)H
M`ELT`U,W`EL]`ELL`ELN`7)?`7)K`7)D`ELU`EM$`E5+`7)J`ELK`75N`EM&
M`EM)`7)F`U,[`ELY`7)M`7)C`U,\`U,Y`U,Z`7)B`EM"`EM(`7)@!%1%`ELR
M`EM'#UA9#UA(`ELS!S1C`V9=#UA5`V9>!%1)`U,Q`ELX`E]^`U9E`F`E`75P
M`75R`F`K`75L`F`Y`F`Q`F`F`F`G`F`P`U9F`75Y`F`O`E]]`F`N`F`B`F`Z
M`75X`75V`F`C`U9=`F`V`U9G`F`H`F`U`U9D`F`W`E]\`75Q`U9;`F`X`U9H
M`U9>`F`L`U9K`75U`F`I`U9A!%E)`75W`F`R`U9B`U9C`U9?`75O`F`D`F`S
M`U9<`F`M`ELQ`F`T`F`A`U9@`75T`U9J`F0O!%E'`75M`E]Z!%E&#UU!`V9?
M#UTY`F0L`F0E`7=4`UE#`F-^`F0P`F0G`F`J`UE``F0R`F0A`UE"`7=3`F0K
M`7=5`7==`7=;`F0M`7=<`F0C`UE)`F0D`F0I`F0N`UD^`E]Y`7=6`F0W`F0T
M`F=A`F0J`F0F`F0U`F=6`F0H!%XQ`7=9`UE$`7=8`E][`7=:`F0Q`F0S`7=7
M`F0V`F-]!%XI`F0B`UE&#V$S`UE%`V9A`V9B`V9@#V%#`F=?`UM0`F=/`7DX
M`F==`UM$`UM%`F=-`7DY!&%G`F=8`UM#`F=4`7D^`F=>`F=.`F=1`7DV`F=@
M`UM(`F=9`F=<`7D\`7E!`7D_`F=5`F=0`UM-`7DZ`7D[`F=,`7DW`UM/`7DU
M`7D]`F=;`7E``UM*`F=7`F=B`7E"`UM!`UM"`UM.`F=3`UM'`F=:`V9E`V9C
M`V9D`UU!`UYJ`FI!`FI0`FI#`FI*`F=2`FI(`FHW`FI.`7I.`FH[`FI-`FI"
M!&1G`UU#`7I-`UT\`UT_`FI2`FI$`UT^`FI)`FI,`FHU`FI/`FI``FI%`FHY
M`FH]`FI1`FI'`FHV`FHZ`FH\`FI&`UT]`7I,`FH_`UU$`UU%`UU'!&1K`UU"
M`UTZ`FHX`V9F`V9G`V9H#V97`UU&`FH^`FQ0`FQ4`7L[`FQ6`UYM`7LU!&1O
M`FQ2`FQ8`7LZ`7LV!&=<`7LW`FQ/`FQ5`7LY`FQ3`7LX`FQ.`FI+`FQ1!&=B
M`FQ-`FQ7`U]I`U]N`7M[`FX\`FX_`FX[`FX]`FX^`FXX`FXY`FXV`U]J`U]L
M`FXZ`FXW`7M\`7M]`U]K`F]9`V!2`F];!&LI!79=`V!5`V!4`V!6`F]:`F]<
M`V!/`7Q,`V!3`F]8`7Q+`7Q-`V!7`V9J`V9I`G!9`G!:`7QO`G!8`V$B`G%"
M`G%!`G%#`7TL`G%$`7TK`G%%`G%A`G%D`G%C`7TU`G%B!&UB`V%O`V(C`7T_
M`7T]`7T^`7U$`G(P`G(Q`G(O`G(W`V(V`4];!"4K!#`Z`CHH`D$_`E5.`F=C
M!7%6`4]<`R]``5-M`5A@!#`[`S0R`CHI`SE<`CHJ`5UP`6)D`D%!`D%``6)H
M`6)C`D%"`6)E`6)G`6)F`6)B`S]L#S]^`V9K`6=0`T4\`T4Z`DA6`DA4!$%3
M`DA5`DA3#T5[`6M;`TH]`6M>`6M@`6M?!$@B`TH^`6M<`6M=`E50`E5/`6]D
M`E51`T]3`E52`6]E`T]5`T]6!$Y*`EM9`EM7`F!``U-"`EM5`EM6`7)O`EM2
M`EM:`EM4`EM8`F`\`U-$`U-``F`^`U9M`F`_`75^`F`[`75]`F`]`75Z`75[
M`75\`EM3`V9L`7=@`F0Z`F0X`F0Y`7=>`7=A`7=?`UE+`UE*!TM``F=D`F=E
M`7E#`UM3`FI3`FI5`FI4`7I/`7L\`FQ;`FQ:`FQ9#VAR`V9M#R4Y`4]=`R%#
M`B%I`B)X`4AJ`B)V`B)Y`B)W!"4N`R<[`R<Z`B4N`R<_`4MB`R<\`4MC`B4P
M`4M@`B4O`B4M`4MA`4M?`R<]`R<^`RIY!"@S`BAX`BA[`4]@`BAZ`BAY`RI\
M`4]?`4]>`RI[`4]B`BA\`4]A`BUG`5-O`5-P`5-Q`BUH`BUD`5-N`BUE!"M=
M`BUF`BUC!"M;`S0V!#`_`5AG`S0T`SE>`5AD`C-(`5AE`5AH`C-)`S0S`5AC
M`5AA`5AB`5AF`5UQ`CHM`5UY`CHL`SEA`CHO`5UU`CHN`6)P`5US`5UV`5UR
M`5UW`5UX`5UT`SEE`S]Q`CHK`6)L`D%$`S]R`D%(`S]S`S]U`D%'`6)Q`6)M
M`6)N`D%#`D%%`D%&`6)I`6)K`S]P`6)O`6)J`T5``DA9`DA7`DA8`6=2`6=3
M`T5"`DA:`6=1`6MA!$@D`6MC`6MB`TI%`D\C`TI&`TI$`D\D`E54`T]:`E53
M`T];!%12`7)P`7)Q`EM;`7)R`U-(`F!#`U9P`F!!`U9O`F!"`78A`U9Q`F0[
M`7E$`UU)`RI]`U-)`78B`4]C!#!!`5AI`C-*`S0Y#S)O`CHP`5UZ`6)R`D%)
M`D%+`6)T`6)S`6)U`6)V`D%*`6=6`6=7`6=5`6MD`6=4`DA;!$%7`TI'`TI)
M`6ME`E55`EM<`7)S`78C`F0\`F1``7=D`F0]`7=E`7=C`F1!`7=F`F0_`F=F
M`7=B`7E%`UYP`G!;`V$E`V(O`4]D`5U\`5U[#SDJ`S]^`S]\`S][`6)W`D%-
M`D%,`6)X`T5&`DA?`6=;`6=8`DA>`6=:`DA<`6=9`T5'`DA=`D\E`6MF`E58
M!5([`6]F`E56`6]G`6]H`E57`6]I`T]@`EM=`U-0`7)W`7)T`7)Y`EM?`7)U
M`EM>`7)X`U--`U-,`7)V`U-1`F!&`F!(`U9T`U9U`78D`F!'`78E`F!%`F!$
M!%XX`F1#`F1"`7=G`F1$`F=K`7E'`F=J`F=G`7E&`F=H`F=I`FI6`FI7`7I0
M`UU/`7L_`UU,`UU.`FQ<`UYR`UYQ`7L]`7L^`FQ=`V9N`U]Q`7M^`7PA`FY`
M`U]R`V!9`7QP`G!=`7QR`V$F`G!<`G!>`7QQ`G%&!&UD`G%[`V9O`V)%`RI^
M`4]E`T5)`6=<!$@U`D\F`TI,`E59`7)Z`7)[`UE/`4]F`T`A`6]J`7E(`5-R
M`RLA`TI.`7)\`UYS`7Q.`5-S`CHQ!#MW`D%.`T`D`D%0`T`B`D%/`DAC`DA@
M`6==!EHD`6=>`DAA`DAB`T5+`D\H`D\M`6MG`D\G`D\I`D\P`D\K`D\O`D\L
M`D\J`D\N`6MH`T]B`E5<`T]C`E5:`6]L`T]D`6]K`E5;`6]M`U-3`EMB!%1?
M!%1G`EMA`7)]`EM@`F!)`U9Z`F!+`F!-`F!,`U9[`78F`F!*`F1+`7=H`F1)
M`F1,`7=I!%Y#`F1'`UE0`F1*`F1(`F1%`7=J`F1&!&%\`UM?`UM=`F=L`UM>
M`UM@`F=N`F=M`UU0`FI8`UU1`FI9!&=Q`UYU`UYT`FQ>`U]S`7PC!&E>`7PB
M`F]=`F]>`7QS`G!?`V$H`7TV`V([`5-T`6)Y`D\R`D\Q`E5>`E5=!$Y7`U-5
M`78G`F!/`F!.`F1/`F1-`F10`F1.`UE1!&4I`7E)`F=O`F=P`F=Q!&4G`FQ?
M`UYV`FY!`V$I`G!@`5-U`T5/`T]E`EMC`F!0`UMA`5-V!$%C`T50`6MI!$A&
M`EMD`7=K`F11`7E*`UU3`FI:`FI;`7M``F]?`5-W`5XA`5XB`CHR`6)Z`6)[
M`D%1`6)\!$%H`6=B`T52`6=D`DAE`DAF`DAD`6=?`6=@`6=C`6=A`TI4`TI5
M`D\S`6MJ`6MK`TI2`TI6`E5E`6]P`E5@`E5?`T]I`E5D`6]N`T]G!$Y:`7,F
M!%1P`E5A`E5F`E5C`E5B`T]F`6]O`7,D`U-<`EMF`7)^`U-9`EMG`U-:`U(H
M`EME`U-8`7,C`7,A`7,E`U-=`7,B`U-;`U-?!%Y/`UE;`U<F`F!1!%EP`F!6
M`F!2`F!5`78H`U<H`EY!`F!4`F!3`UE9`7=N`7=L`7=O`7=M`F12`F13`F14
M`7=P`UE6`UE8`UME`F=U`7E,`F=S!&(P`7E-`F=R`F=T`7E+`FI?`FI<!&4L
M`FI=`FI>`FQ@`7M"`UYX`7M!`UYW`FY#`FY"`7PD`V!=`V!>`V!<`7Q/`7QT
M`7TM`G%'`G%\`G%]`5-X`D%2!$%Q`DAG`D\T`D\U`6ML!$A7`6MM`E5G`6]Q
M`U-A`78I`U<J`F15`UE<`7=Q`F=X`7E.`F=W`F=Y`F=V`FQC`FI@`FIA`UU6
M`7I1`FQB`UY[`UYY`FQA`UYZ`FY$`G%^`V(E`5-Y`UY\`V(F`5-Z`SEG`5AJ
M`C-+`V9P`CHS`SEH`6)]`6,B`6)^`D%3`T5;`6,D`6,A`T`K`T5<`6,C`T54
M`6=F`T59`DAH`T57`TI=`DAI`E5I!$%[`6=E`6=G`6=H`T58`D\W`TI>`D\V
M`6MN!4M,`6MO`TI;`D\X`E5H`6MQ`6]R!$YC`6MP`V9Z`7,G`E5J`6]T`6]S
M`E5K`E5N`E5L`E5M`6]U`T]K`7,L`7,J`U-E`U-F`7,I`EMI`U-D`7,K`U-B
M`U-C`EMH`F!7!%1^`EMJ`7,H`EMK`F!:`F!8`F!9`F!>`7=U`F!=`F!@`F!?
M`F!<`F!;!%4A`78J`UEB!%HI`UEA`UEF`F18`UEE`F17`7=T`7=R`7=S`UEC
M`F16`V9Q`F=\`UMI`7E/!&(X`F=[`F=Z`7E0!&4Z`FIF`FIE`UU8`FIC`UY^
M`FIB`7I3`7I2`FIG`FY%`7PE`FQE`7M#`FQD`FID`U]X`FY&`7Q0`V$J`7TN
M`G%(!&XD`G(A`5-[`CHT`F!A`5-\`T5?!4M.`D\Z`D\Y`EML!5HF`U-H`F!C
M`U<P`F!B`UEG`7=V`F=]`F=^`7I4`U\A`V!@`G(B`5AK`6,F`6,E`DAJ`DAL
M`6=J`DAK`6=I`6=K`DAM`TIC`TIB`TIF`D\\`D\^`D\]`TIA`D]``TI@`TIL
M`TID`6MR`D\_`D\[`TIJ!$A@`D]!`T]S`E5U`T]M`E5X`E5Z`E5P`E5T`E5Q
M`6]W`6]Z`6]\`E5R`E5S`6][`E5V`E5Y`E5W`6]]`T]N`6]Y`E5O`6]V`T]R
M`6]X`T]T`U-P`7,N`EMR`EMP`EMO`U-Q`EMU`U-K`EMT`EMS`U-L`EMN`7,M
M`EMM`U-J`EMQ`7,O`U<T`F!F`U<W`F!J`F!G`F!I`F!H`F!E`F!K`F!N`F!L
M`F!M`78L`U<S`78K`F!D`F!O`F1=`F1@`F1B`F1A`UEJ`F1;`F1?`F1:`UEK
M`F1<`7=W`F19`UEM`F1>`F@M`F@B`7E1`UMO`UMM`7E2`F@A`F@F`F@L`F@D
M`F@K`UML`F@H`UMN`F@G`F@J`F@E`F@C`UMK`F@I`FIN`FIL`7I5`FIK`FIQ
M`FIO`UU:`7I6`FIJ`FIH!&5&`FII`7I8`FIM`7I7`FIP`FQF`FQL`U\D`U\B
M`FQG`7M'`FQM`7M&`FQK`FQJ`7M%`FQI`7M$`FQH!U91`FY,`FY.`FY-!&EJ
M`FY*`7PG`FY'`FY+`FY0`U]Y`FY/`FY(`FY)`7PF`F]@`7Q3`V!B`F]A`7Q1
M`7Q2`V!A!&P]`G!A`7QU`G%E`V%R`7TW`V%S`G(C`7TX`G(D`G(E`G(S`G(R
M`7U'`G([`5AL`T`O!$(A`DAO!$%]`DAN!$%^`6MS`6MT`D]"!$YT`E5[`EMX
M`T]W`T]V`6]^`7,P`EMV!%4Q`EMY`7,Q`U<Z`F!P`EMW`F1C`7=X`F@N!&))
M`UUA`FIT`FIR`UU@`UU>`FIS`FQN`U\E`7M(`FY1`7Q6`7PH`7Q4`7Q5`G!B
M`7TO`V%T`5AM!#8M`TIN!$YY`F1D`U][`V!C`C-,`T`R`6=L`T5A`D]#`TIO
M`TIS`6MU`D]$`TIQ`TIP`TIR`E5]`E5\`7,S`7`A`7`B!$\A`E8B`E8A`E5^
M`T]Y`U-U`EMZ`EM]`U-T`EM\`EM[`7,R`F!T`F!R`F!Q!%HW`U<[`F!S`U<\
M`7=Y`F1F`F1G`7=Z`UEO`F1E`UMQ`F@P`F@O`F@R`7E3`F@Q!&)/`FIU`FIW
M`FIV`U\G`FQO`FQR`FQP`FQQ`FY2`7PI!&ET!&EQ`V9R`F]B`F]C`F]D`V$L
M`7QV`7TP`G(F`5AN`TIU`7`C`7,T`F1H`UUB`FY3`V$N!&TW`G%F`C--`V(H
M`7U(`5AO`EM^`U<^`F1I`F@S`UUC!&@V`FQS`FY4`5AP`T5B`D]%`D]&`TIX
M`6MV`6MW`E8D`7`E`7`D`E8C`F!U`U<_`F1J`F1L`F1K`7=]`7=\`7=[`UUD
M`7M*`FQT`U\H`7M)`FY6`FY5`V$O`7QW`G!C`5XC`DAP!$(I`T5C`D])`D]'
M`D](!$AK`T]^`E8M!$\P`E8H`E8E`E8L`T]\!$\U`T][`E8N!$\W!$\L`7`G
M`E8K`E8G`T]]!$\J`E8F`E8J`E8I`7`F#U,^`EPK`EPF`EPD`EPM`EPE!%5'
M`EPA!%5#`EPG`U-X`U-Z`EPB`F!^`EPC`EPN`U0C!%5%`U-\`U0A!5I*`U0E
M`U-]`EPJ`7,U`EPI`EPH`U-Y`EPL#UDX`V9S`U=$`F!V`F!Y!%I)`U=%`F!X
M`U=``F$B`F![`F$A`U="`F!]`F!\`F!Z!%I!`F!W!%H_`78O`78N!%I$`78P
M`78M`F$C!%I%#UUV!%I#`F1R`F1U!%\F`F1S`F1W!69Y`UET!%\B`F1X!%\J
M`F1P`7@D`F1Q`UES`F1O`F1V`UMT`F1N`F1M`7@C`7@A`7=^`UEV`UEU`U=#
M#V%R`UEQ`F1T`F@\`FA"`7E6`F@]!6LS`FA``FA$`7E7`F@_!&)<`F@W`UMU
M`F@V`FA#`F@Z`UMW`F@X`FA!`F@Y`7E5`7E4`UMY`F@T`F@U`F@^!&)F`UMZ
M!&)H`F@[#V1K!&)5`UUO`FIZ`FI]`UUQ!&)6`UUG`UUI`7@B`UUJ`UUT`UUU
M!&5:`UUN!&59`UUH`FI[`FLC`FLA`FIY`FLF`UUF`FIX`UUV`7I:`FLB!&54
M`UUS!&57`FI\`7I9`FLE`UUR!&5=`FLD`UUP`FQW`FQV!7)1`U\L!7)+`FQ]
M!7).`FQY`FQ\`7M,!&@[!&@^`FQZ`FQ[!&@Y`FQU`FQX`7M+`U\J#VDJ`7PK
M`FYA`FY<`FY@`V`E`FYC`FY?`U]^`FY;`V`C`7PM`FY>`FYB`7PL`FY9`FI^
M`FY=!&HC!74M`FY:`V`B`FY7#VH^`FY8`7PJ`F]H`F]J`F]M`F]I`F]N`V!E
M`F]G`V!F`F]E`V!H`7Q7`F]K`7Q9`7Q8`F]F`F]L`V$R`G!H`7QX`G!I`V$S
M`G!G`G!D!&Q*`V$T`G!F`G!E`G%)`V%9`G%+`G%*`V%;`G%I!7I3`G%H`G%G
M`G%J`V%U`7U``7U!`G(X`G(\`V)!`5XD`D%4`DAS`T5D`6=M`DAQ`T5F`R]"
M`DAR`T5H`T5G`D]*`D]+`6MZ`6MX`D],`6MY`E8S`U`G`E8V`E8P`E8W`E8O
M`E8Q`U`J`E8R`E8U`U`D`U`K`7`J`E8Z`E8Y`7`H`E8T`E8X`7`I`U0M!$]"
M`U`E`U`B`U0J`EPX!%52`7,Z`U0L`EPS`7,V`U0V`EPP`EPV`EPY`U0S`7,[
M!%I.`EPU`EPR`EPZ`EPQ`U0W`EPW`7,W`U0I`EPO`7,X`U0U`7,Y`EPT`U0R
M`F$U`F$H`F$I`F$L`F$J!%I5`F$D!%I6`U=-`F$G`F$Q`F$K`U=(!%I/`78Q
M!%I-`F$S`F$P`78R`F$R`F$E`F$N`F$O`U=*`F$M#UXD`V9U`F1\`F1^`F4C
M`UEY`UE[`F1[`UE]`7@E`F4E`F1Z`F4F`UE^`F4B`F4D`F4H`F4A`F4I`F1]
M`F1Y`7@F`UHB`F4G`7@G`7E9!%\T`UEZ#V%W`UM]`F$F`FA>`FA5`7E;`FA1
M`7E<`UPG`UPB`FA:`FA4`FA*`7E:`FA7`FA2`FA3`UPE`FA%`FA,`FA;`UM^
M`FA8!6L_`FA0`UPF`FA<`FA+`FA&`FA9`UPD`FA(`FA6`FA-`FA=`FA)`7E8
M`FA'`FA.`FA/`FLM`UPC`FLK!&5I`FLP`UUY`FL\`FLS`FLL`FLH`FLU`FLN
M`FLQ`FLJ`FLX`FLG`FLO`FLT`FLV`FLY`FLI`UUZ`FL]`FL^`FLW`FL[`FLR
M`FTO`FTR`U\U`7M-`U\Q`FTQ`FTV`FTT`7M.`FTK`FTA`FQ^`7M0`FTM`FTN
M`FTJ`FTB`U\R`FTG`FLZ!&A#`FTC`7M/`FTI`U\V`FTH`FTD`FTP!&A$`FTE
M`FYH`FTS`FTU`FTL`FTF`FYI`FYK`FYE`7PN!&HE`FYR`FYP`7PO`FYO`FYN
M`FYG`FYD`FYJ`FYS`FYF`FYL!75%`F]W`F]\`F]R`F]U`7Q:`F]Y!&M&`G`B
M`FYM!&M*`F]S`F]]`G`C`F]X`F]Q`F][!&M+`F]Z`G`A`F]^`FYQ`F]V`F]P
M`F]T`7QY`7QZ`F]O`V!L`G!T`G!K`G!S`G!P`G!Q`G!J`G!M`G!U`G!O`G!N
M`G!L`V$U`G!R!&Q6`G%,!&TZ`G%-`V%=`G%/`G%.`G%1`G%0`G%L`G%K`G(G
M`V(I`G(H`V(P`G(T`7U%`7U)`V(X`G(]`7U*`5XE!$](!5I;`7I;`FTW`U\W
M`7Q[`7Q\`5XF`DAT`T5I`6=N`E8[`U`L`U0Y`EP\`EP]`EP[`F$W`F$V`78S
M`F4K`F$X`F4J!%\Z`UHD`FA@`7E=`7E?`FA?`UPI!&)U`7E>`UXA`FL_`FM!
M`FM``FTX`7M1`U\Z`7Q;`G!V`G%2`V(Q`V(_`G)!`5XG`R5'`D]-!$],`7`K
M`U`O`U`N`U0Z`EP_`EP^`U=0`F$Y`UHF`UHE!&)^`7E@`7I<`FYT`G(Y`5XH
M`6M[`TLB`7`L#V%\`FAA`UXB`G`D`6,G`SEJ`U0\`U0[!%I=`F$Z`UHH!%\^
M`7TQ`6,H`7`M`78T`G`E`6,I`SEK`E8\`7,]`EQ``EQ!`U0]`7,\!%5@`F$[
M`78X`78V`78W`78U`F4L`7@H!&,D`UPJ`FM#`FM"`FM%`FM$`7I=`FTY!&A6
M`FT[`FTZ`7M2`FYU`V`I`G`F`G`G`7Q<`G%3`G%M`7U"!&Y#`D%5`EQ"`F$\
M`FAB`DAU`R=R`F$]`F4N`F4M`UHI`UPM`UPN`U\\`G`H`7Q]`V%?`G%4`G%N
M`6=O`E8]`E8^!$]6`EQ#`6=P`T5J`7@I`F4O`UPP`FT]`7M3`FT^`FT\`G`I
M`V%@`G!W!&U(`6=Q`F%``F$_`F$^`F4P`UHK`UHJ`F4T`F4S`F4R`F4Q`7@J
M`FAC`FM'`7I>`FM&`FT_`FYX`FYW`7PP`FYV`G`L`G`K`G`J`V!M!&Y$`6M\
M!%5C`EQ$`78Y!%ID`FAD`FAE`FYY`G`M!&M<`V$[`G!X`G%5`G(I`G)#`6M]
M`78Z`F4U`FAF`FU``G`N`R-P`7`O`U0^`F%!`F4V`FAG`FAH`FAI`FM,`UXD
M`FM(`7M4`FM+`FM*`7I?`FM)`7IA`7I@`FU"`FU!`7M5`7M6!&A@`U\^`7PR
M`FYZ`7PQ!&MA`G`Q`G`R`G`P`G`O`7TA!&QD`G!Y`G!Z`G![`7Q^`G%6`G%9
M`G%8`G%7`V(S!&Y%`G)"`7,^`U=5!&,M`7@R`FM-`FU#`V`K`7PS`FY[!&Y5
M`V)"`G)$#R%9`7,_`UY'!&XS`F%"`U\_`FY\`V%A`G%O`V%W#UA,`2$K`2$V
M`2$X`2%``2%!`2%$`2%%`2%(`2%)`2%,`2%-`2%0`2%1`2%4`2%5`2%8`2%9
M`2%<`2%=`2(G`2(H`2(K`2(L`2(I`2(J`2$N`2$O`2$P`2$R`2$S`2$T`2$U
M`2%>`2%?`2%@`2%A`2%B`2%C`2(M`2(N`2(O`2(_`2)``2)!`2)#`2)"`2)B
M`2)L`2)M`2)N`2$J`2%L`2)C`2)H`2%M`2$^`2$_`2%N`2(P`2$B`2(Q`2$E
M`2)?`20A`20B`20C`20D`20E`20F`20G`20H`20I`20J`2$H`2$G`2(V`2(X
M`2(W`2$I`2)I`21!`21"`21#`21$`21%`21&`21'`21(`21)`21*`21+`21,
M`21-`21.`21/`210`211`212`213`214`215`216`217`218`219`21:`2)@
M`2(E`21;`21<`21=`21>`21?`21@`21A`21B`21C`21D`21E`21F`21G`21H
M`21I`21J`21K`21L`21M`21N`21O`21P`21Q`21R`21S`21T`2%"`2)>`2%#
M`2)F`2)G`2)D!2$E#R$A!B$O!B$M!B$N!B%"!B%#!2$S`R%$#R$^#R$_!B(K
M!2%-!B-`!B,^!B,_!B1G!B5?!2,O#R)T!B5G!B5C!BDW!BDZ!BDX#RDB#RDC
M!BYF!3!R!3,C#SDR#SDS!D<M#SMS#T`U#T!U#T="#TU6!R$A#UE'!$]\#UH_
M!B$L!B$B!B)?!"%6!B-!!B5@!BD[!24A!2=Z!BY*#RE0!C4E!C4F!D5]!D8_
M#T9`!41^!B$R!2$M!B(M!B-"#RUA!E!0#U-$!"$A!2$F!B$D#R$B!B$S!B%$
M#R$E#R$F!2%.!B(P#R%%!B).!B(O#R%`#R%!!B%%!B(Q!B(N!"(F!"(E!2(D
M!2(E!B-#!BD^!B1=!B56!B5A!B5B!BQ#!BD\!CIE#RDE!BTM!BD]!BY+!2MG
M!C4J!C4G!CED!C4I!CQ[!D5^!D9`!D9!!3U6!2$C!2$B!B$F!B$E!2$A!2$K
M#R$C!B%&!2$T#R$G#R$H!B(S!B(R!B(J!2%/!B-&!B-$#R%N!B-%#R)U!BD_
M!BTL!"8D!BY-!BY.#R5`!BY,!C4K#RU@!CQ^!3!S!CQ]#SDT!E!1!415#T9!
M!EIC!EIB!S9S!T8G!TTZ!2$D!2$G!"$H!2$H!2$L!B%'!B%(!B%)!B-'!2,P
M!B5D!BE`!3!T!D9"!RP\!B$G!B$H!B$I!B%*!B5E!B-(!B-)!B5H#R)V!"4S
M!24B!"4R!BY0!2=[#RDG!C!\!C4M!C4L#RUB!CTA#TUN!B-*#R%O#R%P#R(K
M!2,Q#R)W#R)X#R)Y!24C!BE!#R5#!BY2!BY1#RDH!C4O!2QF!"M?!C4P#RUC
M!C4Q!D9#!CTC!CTB!#!$!3!U#S)T#S)U#S)R!D9%!D9$!D9&!#8O#SDU#SDV
M#SDW!DPM#T`V#T`W#T`X#T9"!E!2!4MQ!R$B#TU7#TU8#TU9!R9Y!R$D!R$C
M!R%&!RP_!5-3!RP^!RP]!T8C!T8H!B$T!B$U#R$D!B%,#R$I!B%+`R%O#R%#
M!B(U!B(T!B(V!"%8!"(L!"(K!"(I!B-/!"(P!B-0!2(G!B--!B-,!"(O!B-+
M#R%S#R%T#R%U#R%V#R%W#R%X#R%Y!2(H!B-1!2(F#R%Z!2,R!B5J!",Z!B5K
M!B5T!B5P!B5L#R)Z#R)[#R)\#R)]#R,A#R,B#R,C#R,E#R,H#R,I#R,J#R,K
M#R,L!",X!B5M!B5O#R,F!B5N!B5I!2,S!B5S!BE#!BE%!"4Z!24H!BE&!24I
M`R=.!24J!"4W!"4U!BE*!BE$!BE,!BE'!BE.!24F!BE"#R5%#R5&#R5(#R5)
M#R5+#R5,#R5-#R5.#R5/#R50#R51!BE-!BE(!BE)!BE+!24D!24G!2=\!BYD
M!BY9!2MR!"@V!BYC!BY7!BY6!2@C!"@[!BY=!2=^!2=]!2@B!BYB!BY5!BY4
M!BYE!BY<#RDI#RDJ#RDK#RDL#RDN#RDO#RDQ#RDR#RDS#RDT#RDU#RDV#RDW
M#RDX!BY3!BY8!BY;!BY>!BY@#R5'!BY?!2@D!"MC!2MP!"MG!C4V!2MK!C4U
M!2MT!"MF!"MH!2MO!C4R!2MI#RUD#RUN!C4W!2MN#RUF#RUG#RUJ#RUK#RUL
M#RUM#RUO#RUQ#RUR#RUS#RUT#RUU#RUV#RUX#RUY#RUZ#RU[#RU\!C4A!C4Z
M!C4[!C4S!C4T!2MH!C4Y#RUW#RUP!2MJ!2MM!2MU!2MQ!2MS!"M@!CTK!CTM
M!CTL!#!)!#!(!CTP!CTH!3$A!CTS!3!W!CTN!CTG!3$B!3!V!#!&!CTJ!CTQ
M!CTW!CTR!CTI!#!+!CTT#RUI#S)W#S)X#S)Y#S)Z#S)[#S)\#S)^#S,A#S,C
M#S,D#S,E#S,F#S,G!D8W!CTX!CYE!CTY!CTO!3!Z!D-C!3!]!3$C!CTD!CTF
M#S)]!3!Y!3!^!3!X!CTE!CTV!3!\!D9)!D9/!396!391!D9,!39.!392!39C
M!393!D9(!395!390!D96!#8U!394!D92!D90!D9+!D9.!D93#S)V!D98!39/
M!397!D9'#SDX#SDY#SDZ#SD[#SD\#SD]#SD^#SD_!D9-!#8[!D91!D94!39-
M!D9*!30A!E!:!$(X!3U:!3U8!E!3!3![!3U>!3U<!E!8!3U;!E!?!E!=!#PN
M!E!<!E!B!E!5!#PO!3U@!E!4!3U7!E!7!E!>#T`Y#T`Z#T`[#T`\#T`]#T`^
M#T`_#T!`#T!!#T!"#T!##T!$#T!%#T!&!E!A!E9.!E!9!E!6!D97!3U9!3U=
M!3U?!#PK!E!@!EIQ!3UA!R$N!$(T!416!EID!EII!3UB!EIK!$(Y!EIT!$(Q
M!EIU!EIH!EIG!EIV#T9##T9$#T9%#T9&#T9'#T9)#T9*#T9+#T9,#T9-#T9.
M#T9/#T91#T92#T93#T94#T96#T97#T98#U-%!R8M!418!EIW!EY7!EIM!EIO
M!EIE#T90#T9(#T95!$(P!EIF!EIJ!EIN!EIP!$(V!3]&!$A^!$AZ!EIL!R$O
M!R$Q!R$I!R$F!R$E!4MW!$A\!R$K!R$L!4MS!R$J!4MY!4MX!R$G#TU:#TU;
M#TU<#TU=#TU>#TU@#TUA!R$H!4MR!R$M#TUB!$DA!4MU!R$P!4MT!4Q%!5-4
M!5-:!RQ`!$]8!$]?!5-8!$]<!$]>!5-5!5-6#U-&#U-'#U-(#U-)#U-*!5-;
M!5-7!S9X!4MV!5IO!5IP!%5G!%5F!S9V#UE(#UE*#UE+#UE,#UE.!S9U!S9W
M#UE)!%5H!S9T!SYV!%IK!%II!%IJ!SYX!SYW#UXP#UXQ#UXL#UXN#UXO!SYU
M!6$Q!%IL!6$O!6$P!6$R!6=*!6=.!&,N!6=-!6=/#V%^#V(A!T=O!6=,!6=+
M!6E\!U)U!TT\#V1Z!6MK!TT[!TUH!&8O!&8N!6]H!U=.!6ML#V<_#V=^!&8M
M!U=-#VDX#VDZ#VDY!7,Q!&I`!UM%#VI+#VM!!75B!&U2#VQ)!B%-!"%<!"(R
M!B-3!B-4!B5U!B5W!B5X!2,U!B5V!BE1!BE0!BE/!BE3#R53!BE2#R52!BYG
M!BYH!2MV#RU]#RU^#RXA!C4\#S,H!3$D!3$E#S,I#S,J!D99#SE`#SE!#SE"
M!398#SE##T!'!E!C#T!(#T99#T9:!419!R$T!R$R!4M[#TUC#TUD!4MZ!R$S
M!5-<!RQ!#U-+#U-,#U--#U-.!5IQ#UE/#UE0#UE1!SYY!6$S#UXR!T8I!6=0
M#V1[!6=1!6MM#V=!#VD[#VI,!7=3#VM"!B$V!2$V!2$U!B(W!B-6!B-5!2,V
M!B5Y!2,X!2@E!2@F!"MJ!C4]#RXB#RXC!CTZ!D9:!E!D!3UC!#PQ!EIX!5IR
M!B$W!B%.!2$W!B%!!B%9!2%0!B,[!"(U!B-7!B5\!B5^!2,Y#R,M!B5Z!BE4
M!BYK!BYI!2@G!BYJ!BY/!C![!C5`!C4_!C5!!C4^!CT[!D9=!3UD#SE$#SE%
M!D9;!D9<!3UE!E!E#T!)#T!*!$(Z!EIY#U1&#U-/#U-0!6$T#UXS!T8J!T8K
M!"$M!B%/!B%1!B(Y!"%=!B(X!2%2#R%&!B(Z!2%1!B-:!B-8!B5'!B8C!B8A
M!B8B!2,Z!BAZ!24L!BE5!BE6!BYL!C5"!C5#!2MW!2MX!CT]!D9?`SEW!D9>
M!#PS!3UF!EI[!EIZ!R$U!5-=!RQ"#U5V!%IM#V="!U=/!2$X!B([#R%(#R%)
M!B-;!"(W!2(I#R%[#R,N#R,O!24M#R55!BYM!CT^#RXE#RXF#RXG#RXH#RXI
M!3$G!D9@#SE'#SE(!D9A#SI=!E!F!EI\#T9;!4YW!RQ##UE2#U-1!SYZ!T8L
M!TT_!6]I!75C#R%*!B-<#R%]#R%^!"(X!2,[!B8D!",\#R,P#R,Q#R,R#R,S
M#R,D#R)^!"5!!"5"!BE8!BE9!24O#R57!2@I!"A!!"A"!2@L!2@H!2@J!BYO
M#RDZ#RD\#RD]#RD^#RD_!BYN!2MZ!"MK!2MY!2@K!C5%!2M[#RXJ#RXK!C5&
M!3$H!CT_!CU`!#!.#S,K#S,L#S,M#S,O#S,P!D9B!39<!39:!39;!399!#8^
M#S,N!3UL!3UG!3UI!3UJ!3UH!3UK!E!G!EI]!4PA!41:!R$W#T9=#T9>!4M^
M!4M]!4M\!R$V#TUG#U-3!RQ%#TUF#U-2!%5J!RQ&!5IS#UE3#UE4!6$V!6$U
M!6$W#UXT!SY[!6=2!6=3!U)V!7,R!"$I!B%2#R$J#R$K#R$L#R$N!B%<#R$M
M!2%3!B(]!"%?!B->!B-=!B-?!B-@#R%+!B8G!B8E!B8F#R,T#R,U!"5&!BE:
M!"5$!BE;!BE<!BE=#R58#R59!BYR!BYP!BYQ!C5'#RXL!C<G!CU"!CU#!CU!
M#S,Q#S,R#S,S!D9C!D9F#SE)!D9D#SE*#T9?#T9@#T9A#TUH!RQ'#U-4#U-5
M#U-##UE5#UXU#V=#!"$N!2$Y!B%3!B%4!B(_!2%4!B(^#R%,!B-E!B-A!B-B
M!B-C#R(A!2(J!B8H#R,V!BE@!BE?!BYS!BYT!C1Z!C5(!CU$!CU%!39=!EI^
M#T9B!R%P!S9[!5IV!6=4!TX^!B$Y!"%`!B%5!2$Z!2$[!B%6!"%!#R$O!B%7
M!2%5!2%6!"%B!B)$!2%7!B)#!B)`!B)%!"(Z!B-J!2(N!2(L!2(K!"([!"(Y
M!B-H!B-G!2(O!B-K!B-I!2(M!"(]#R(B#R(C!"(^!B-F!"-!!B8K!"-#!2,]
M!"-"!2-&!2-%!2-#!2-`!B8I!2,_!2-"!2-!!B8J!B8L!2,^!2-$!BEI!24S
M!24U!"5)!"5+`R=<!BEF!"5-!BED!BEE!BEL!BYU!BEJ!24P!24V!BEK!24R
M!BEG!24T#R5:#R5;#R5<#R5=!BEH!BEB!BEA!24Q!BE7!"A'!2@M!"A%!B\D
M!BY[!B\B!"A(!B\A!"A$!"A&!BYX!BY^!B\C!BYZ!BY]!BY\#RE`#RE!#RE"
M!BYY!2@N!BYW!C5)!"MP!"MM!2PE!2PC!"MO!"MS!C5.!C52!2PB!C53!"ML
M!2PF!C51!"MQ!C50!C5/!C5,!C5+!"MR!2PD!C5-#RXS!C54#RXN#RXO#RXP
M#RXR#RXQ!C5*!2PG!2M]!2PA!2M^!#!0!3$K!#!1!3$J!CU&!#!6!#9)!#!5
M!CU)!CU'!39>!#!/!2PH#S,T#S,U#S,W!CU(!CU*!CU+!#9#!39?!D9M!D9I
M!#9&!#9'!39@!39D!#9*!#9$!#9!!#9`!D9K!D9H!D9L!39A!39B!D9J#SE+
M#SE,#SE-#SE.!#9(!DQ&!D9N!39E!#PY!E!O!3US!E!M!#PU!3UT!E!N!3UM
M!#PW!#PV!3UN!#PZ!3UO!E!K#T!+!E!J!E!H!E!P!E!I!3UR!3UQ#T!,!41;
M!$([!ELD!41A!ELB!ELA!#PX!$)`!41B!41<!41?!$(]!$)$!ELK!ELI!ELH
M!41>!4PB!ELF!41=!ELJ!41@!ELE#T9C#T9D#T9E!ELC!ELG!4PC!4PG!$DD
M!4PD!4PF!R$\!R$]!R$Z!R$^!R$[!4PE!R$X!R):!R$Y!$]@!RQ)!5IW!RQ*
M!RQ.!RQ-!RQ,!5-?!5-A!5-@!5->!RQ(!RQ+!R$_#U-6!5A1!5IZ!%5K!5IY
M!5IX!S9\#UE6!%5N!SY\!6$X!6$Y!S9]#UXV!6$Z!T8O!T8N!T8M!TU`!TU!
M!6]J!U)W#V=$!75D!&ME!V(M!V(L!B$Z!2$\!B%8!"%C!2%9!2%8!2(Q!2(R
M#R(E#R(F#R(G#R(H!2(S!B8N!"-%!2-'#R,X#R,Z#R,[!B8M!"-)!24]!24Y
M!BEM!24\!BEN#R5@#R5A#R5B#R5C!2@P!"A*!B\F!2@Q!2@O!B\H#RE##RE$
M#RE%!C55!C59!"MT!2PM!2PI!2PK!2PL!2PJ#RXT#RXU!C56!C57!3$M!CU.
M!CU,!CU/!CU0!CU1#S,X#S,Y!CU-!39I!39F!39H!39K!39G#SE/#SE0!D9O
M!D9P!D9Q!3UV!3UU!#P[!E!R!E!Q#T!-!3UW!$)&!41F!41D!41E!41I!$)%
M!41H!ELN#T9F!ELL!ELM!4PK!4PH!$DF!4PI!4PJ!RQ/!5I\#U-7!5I[!5I]
M!S9^!S<B!S<A!6$\!SY^!S\A!6=6!6=5!TU"!6]K!UM&!75E!&QK!V8[!2$]
M!B)'!B)(!2(U!2(T!2(V#R(J!B8O!2-(!2-)!"52!BEQ!BEP#R5D#R5E!B\J
M!"A,!B\K!B\L#RE&!B\I!"MV!C5<!C5;!C5>!C5?!C5:!C5=!2PO!#!=!CU2
M!2PN!3$N!3$O!CU3!#9.#SE1!E!S!#!;!3UY#T!.#T!/!ELO!$)'!41J!41K
M#T9G#TUI!$]E!RQ0!RQ1!S<C!S<D!5I^!TU#!B$J!"%"!B)*!B8P!B8S!2-*
M!B8Q!B8R!"A-!B\O!B\Q!B\M!B\N!B\P!CU4!C5@#RXV#RXW!C4D!D9R#SE2
M!#P]#T9H!S\B!6TR!B$K#R$Q!2(W!B-N!")#!B-M!B8T!"-*!B8U#R,\!BES
M!24^!24_!"A/!B\T!2@S!B\S!2@R!B\R!B\W!B\U#RE'!2PP!C5B!C5A!2PQ
M!CU5#S,Z!#9/!E!U!D9S!C5C!3UZ!$)(!ELQ!ELP!4PL!4PM!4PN#TUJ!5-D
M!S<E#UXW!%]+!S\C!TU$!V!I!V1##R$R!2(X!B-O!2-,!B8W#R,]#R5F!B\V
M!2@T!C5D#T9I!TU%!U=0!B%:!2%:!2%;!B)+!B-P!")$!")%!B-S!B-R!2(Z
M!2(Y!B-T!B8Y!2--!B8Z!B-U!B8[#R,^!25`!BET!BEW!BEX!BEV#R5G#R5I
M#R5J#R5K#R5H!BEU!C5E!C5F#RXX#RXY!#!C!#!A!#!B#S,[#SE3#SE4!E!X
M!E!W!E!Y!E![#T!0#T9J#T9K!4PO#TUK#TUL!R%`!S<F#UXX!T8P!U)X!V!J
M!V(N!B),!B-W!B-V!B-X!"-,!2-/!2-.!B8\!"55!"54!BE\!BE[!BE]!BEZ
M!BE^!BEY#R5L!BHB!"A2!"A1!2@W#RE(#RE)#RE*#RE+!B\Y!C5H!"MY!2PR
M!C5G!C5J!CQZ!C5I!CU7!CU6!C5K!CU8!D9U!D9V!D9W!3<_!E!\!41M!ELR
M!R%!#U-8!V-+!2$^!"%##R$T!B%;!")&!BHD!B-Z!B-Y!"-.!B\[!2@X!B\Z
M!"A3!C5L!B\\!D9X!2PS!3U[!E!]!41N!S\D!2$_!2%<!B-[!B)/!B)-!B)0
M!2%=!")'!2([!B-\!B-]!2(_!2)`!2(]!2(^#R(M!B8^!2-0!B8]!2-1!B5>
M#R,_!BHG!BHF!BHI!BHH!25!!"58#R5M#R5N!BHE!2@Y!"A4!B]&!B]!!B]$
M!B]%!B]`!B\^!B]"!B]##RE-#RE.!"A5!B\_!C5S!C5T!"M[!2PT!"M\!C5O
M!C5M!C5P!C5R!C5Q!C5N!2PU#RXZ#RX[!CU@!CU;!#!G!CU?!CU<!CU=#S,]
M!3$P!CU>!#!F!#92!D9\!D9Z!#93!D9[!D9Y!D9]#SE5!D9^!3U\!3U]!E$D
M!E$C!E!^#T!1!E$A!#P_!$))!ELT!ELW!ELS!ELX!41O#T9M#T9N!ELV!ELY
M!EL[!ELZ!ELU!R%#!$DH!4PP!R%$!R%"#TUM!R5(!5-E!RQ3!RQ2#U-9#U-:
M!SM-#UXY#UXZ#UX[#V1\!TXG!U)Y!7=4!UY0!V4S!V8S!2$N!B$\!B$]!B%=
M!B)2!B)1!")*!B0C!B0A#R(N!"))!B0B!B9`#R-`!2,\!BHL!BHK!BHM!BHN
M!B]'!B](!"A6#RE/!C5V!C5U!C9)!C4N!39L!D<B!D<D!DUB#SE6!D<C!3XA
M!E$E!3U^#T!2!EL\#T9O!F!R!R%%!5-F#UE7!TMJ!B%@!2%`!B%>!2%"!B%B
M!B%?!B)5!"%H!2%>!B)6!2%?!B)3!B)4!B0E!")+!B0D!2)"!B0F!2)!!B0G
M!B9$!B9"!2-2#R-!#R-"#R-##R-$!"-0!BHQ!BHO!BHR!BHP#R5O!B]-!B]*
M!B],!B]+!B])#RE1#RE2!C)R!2@V!C5[!2PV!C5\!C5Y!C5W!C5Z#RX\#RX]
M#RX^#RX_!CQG!CUF!CUH!3$R!3$S!CUE!CUC!CUK!CUD!2PW!CUB!CUI!CUJ
M!CQ\!CUG!#94!39M!D<G!D<E#S,^#SE7#SE8#SE9#SE:!D<F!#Q#!#Q"!E$G
M!E$H!E$F!#Q!!D<H!E%;!E$I!E\A!EL^!EL]!41P!E-[#TU5!4PS!4PT#T9P
M!4PR!RQ5#U-;`U`Y!50N!RQ4!S<I!S<H#UE8!%IO!T8R!T8Q!&8Q#V=%!U=1
M!75F!UY1!UY2!2%#!B%D!"%'!"%&#R$V!B%C!2%A!B)9!B)8!B)>!B):!B)=
M!B)7!B)"#R%.!B)<!2)'!B0M!2)%!B0N!")-!2)&!")0!B0L!")/!").!2)$
M!B0H#R(O#R(P#R(R#R(T!B0J#R(Q#R(S!2)#!B0I!B0K!"-6!B9/!B9&!B9-
M!B9,!2-6!"-:!"-=!2-;!2-4!B9(!"-7!"-2!"-8!2-8!B9)!2-9!"-5!2-5
M!B9'!2-<#R-%#R-&#R-'#R-*#R-+#R-,#R-(!B9+!B9*!B90!B9%!2-3!2-7
M!2-:!"5<!"5>!BHV!25,!25$!"5;!BHT!25-!25%!25'!"5A!250!BHS!252
M!2A'!BH[!25(!25+!25*!251!25)!25.!BH]!25/#R5P#R5R#R5S#R5T#R5U
M#R5V#R5W#R5X#R5Y#R5Z#R5]#R5^#R8A#R8B#R8C!25&!BHU!25#!BHX!BHW
M#R5\!BHZ!2PX!2A&!2A2!2A-!2@\!2A1!B]4!B].!2@_!"A;!"A:!2A/!2A%
M!2A+!2A*!2A.!2A(!2A)!2@]!2A!!2A,!"5B!B]9!B]:!2A3!B]/!2@Z!B]7
M!B]6!2A0!B]0!B]8!B]2!2A`!2A"#RLS#RE3#RE5#RE6#RE7#RE8#RE9#RE:
M#RE;#RE>#RE?#RE@#REA#REB#REC#RED#REF#REG!2A#!2A$!"A=#REE!B]5
M!B]3!"A8!2@[!2@^!B]1!C8I!"PD!"PK!"PL!"PG!C8B!2Q.!2Q!!2P_!2Q,
M!2P]!2Q&!2Q6!2Q)!"PJ!2Q-!2Q4!2Q2!"PB!C8C!C8D!2Q1!"PC!2Q`!C8G
M!C8H!2Q7!C8F!2Q3!2Q8!2Q'!2Q9!2Q$!2Q5#RY`#RY!#RY##RY$#RY(#RY)
M#RY+#RY,#RY-#RY.#RY/#RY0#RY1#RY2#RY3#RY4!CE>!C8A!2Q"!2Q%!2Q(
M!C8E!2Q0!2Q+!2PY!2PZ!2P[#RY%!2Q*!2Q/!2P^!2P\!2Q:!3%&!#!I!CUW
M!CUT!#!X!CUO!#!U!3%1!3%)!3%,!#!N!#!Y!3%$!CUV!3$V!3%*!3%%!3%.
M!3$T!3%-!3%"!3$[!CUQ!CUU!CU]!CUZ!CU^!3$Z!3$\!CUL!3$X!CUR!CU[
M#S,_#S-`#S-!#S-"#S-$#S-%#S-&#S-'#S-(#S-)#S-,#S--!3$W!CUS!3$Y
M!CUM!3%!!3%(!CXA!3%2!CUP!3%`!3$U!3%'!3$^!3%#!3$]!3%0!CUY`S1@
M!3%3!3%/!CUX!CUN!3$_!3%+!#95!#9A!D<R!3<D!D<W!D<^!39W!D<U!39\
M!#96!3<H!39O!39Q!#9:!39X!#97!3<I!39^!#9B!#9;!3<C!3<G!#9F!3<P
M!#9=!3<L!3<N!D<N!D<\!3XB!D<K!D<O!D<X!3<B!D<T!D<_!D<Z!#9D!3<F
M!39S#SE;#SE=#SE>#SEA#SEB#SEC#SED#SEE#SEF#SEG#SEH#SEJ#SEM#SEN
M#SEO#SEP!39T!39U!39[!3<E!3<A!D<[#SEK#SE<#SE?#SEI#SEL!3<K!3<O
M!D<]!3<M!3<J!39]!D<V!E$Y!3XC!#Q)!3XG!#Q.!39R!E%!!#Q(!#Q$!EM"
M!3XM!E$S!E$U!3XJ!3XX!E$Z!E$P!3XN!3XD!3XU!3X_!E$_!E$W!3XT!3XW
M!#Q-!3XZ!#Q%!3XS!3XL!#Q/!3XO!#Q1!3XQ!3XR!E$[!E%`!E$J!E$^!E$]
M!3X[!E$X!3XH!3XP!3XK!E$L!E%$!E$N!E$K!E$M#T<F!3X^!E$Q#T!6#T!7
M#T!8#T!9#T!:#T!;#T!<#T!=#T!>#T!?#T!@#T!A#T!C!E$O!E$T!E$\#T!4
M!E%"!3X\!3XV!3XE!3XI!3XF#T!D!EM&!EM`!EM+!$)-!EM/!EM%!EM1!EM0
M!$).!EM,!41S!41W!41U!41\!EM#!EM'!$),!$)4!41[!$)0!41V!EM!!41Q
M!41R!41Y!EM2!EL_!EM)!EM*!41X!EM-#T9Q#T9R#T9S#T9T#T9V#T9W#T9X
M#T9Y#T9Z#T9[#T9\#T9^#T<A#T<B#T<C#T<G#T<H#T<I#T<J#T<K#T<L#T<M
M#T<D!EM(#T9U!41T!41Z!EM.!44A#T9]!EM$#T<E!4PU!41]#T9L!R%1!4P[
M!R%5!R%2!4PY!R%8!R%*!4Q`!4Q&!4P]!R%/!4P^!R%7!R%0!4PV!R%+!4P_
M!R%6!R%9!4Q!!$DO!R%;!4PZ!R%(!4PX!5LG!R%:!$DK!R%4!44C!R%3!R%)
M!R%'!R%B!R%<#TUZ!R%>!4Q"!R%A!RQA!4PW!$DR!4Q'#TUO#TUP#TUQ#TUR
M#TUS#TUT#TUU#TUV#TUX#TUY!4Q$!R%?!R8K!R%=!R%-!R%,!4P\!4Q#!RQJ
M!$]N!5-T!RQ<!5-R!RQH!$]R!5-J!5-X!RQ@!$]H!$]S!$]F!5-Q!$]P!5-O
M!5-H!RQK!RQ;!RQD!5-N!RQ?!5-L!5-G!5-U!5-P!5-S!RQ9!5-K!5-I!RQG
M!RQ8!RQ7#TUW!$]I!$]T!5-W!RQF#U-<#U->#U-?#U-@#U-A#U-B#U-C#U-D
M#U-E#U-G#U-H#U-I#U-J#U-K#U-L#U-M#U-N#U-O!RQ>!RQ=!RQB!RQI!5-M
M#U5T!5-V!%5Z!5LF!5LA!S<M!S<J!S<T!S<U!5LC!5LK!%5Q!%5V!5LH!%5W
M!S<K!5LI!%5Y!S<Q!S<O!S<N!5LD!%5U!S<R!S<Y#UE9#UE:#UE>#UE?#UE@
M#UEA#UEB!S<X!S<P!S<V!S<S!S<L!5LJ!5LB!%IT!S\I!S\O!%IS!6$^!S\K
M!%IQ!%IV!6%&!%IW!6=8!6$]!6%$!6%#!%IX!S\J!%IU!%IY!%IR!S\N!6%!
M!S\G!S\M!S\H!S\F!S\L!6%"#UE;!S\E#UX\#UX]#UX^#UX_#UY`#UY##UY$
M#UY%!6$_#UY*!T8T!%].!5LE!T8[!T8Y!T8W!6=:!6=;!%]0!6=7!T8\!T8Z
M!T8S!T8U!T8X!%]/#UY&!6=<#V(B#V(C#V(D#V(E#V(F!T8V!T=N!T8]!6MT
M!6MU!6MO!6MQ!6MP!TU'!TU)!TU+!TU(!TU&!TU*#V1]#V1^#V4A!TU,!6MR
M!U)[!6]Q!6]O!&8U!6]N!U)Z!6]M!U)^!6]P!U)]!&8S#V='#V=(!6]L!U)\
M!U=9!U=:!7,S!U=5!U=6!U=7!U=4!U=2!U=3#VD\!&AD!U=8!UM)!UM*#VI-
M!UM(!UM'!7=5!7=6!&MF!UY3!UY5!UY4!UY6#VM#!75G!7DC!&QM#VPB#VPC
M!V!K!V(R!V(Q!V(T!V(P!V(S#VQY#VQZ!B%E!B%F#R$W!"%N!B0R!B0P!2))
M#R(U!B0Q!B0O!2)(!B94!B]<!BH^!B98!B96#R-/#R-1!B97!B99!B9<!B9:
M!B91!B95!B92!B93!B9;!255!BI#!BI`!BI!!BI"!BTT!BH_#R8D!254!2A4
M!2A6!B]@!B]?!2A5!B];!B]>!B]=!2Q<!C8M!C8J!C8L!2Q;!C8K!2Q=!3%6
M!CXE!3%7!CXD!CXC!CXB!3%4!CXF!3<S!D=`!D=!!3<Q!3%5#SER#SES#SET
M!D="!3<R!3Y`!E%%!3Y!!E%'!E%(!3Y"!E%&#T!E!EM4!EM8!44D!EM5!EM:
M!EM6#T<N#T<O#T<P!EM7!R%E!R%F!R%D#TU[!$]U#U-S!S<\!S<Z!S<[!%]1
M!TU-!U,B!U,A!"%(!2%$!B)@#R%1#R%2!B)A!B0U#R(V#R(W!B0T!B9J!"-@
M!B9F!B9B!B9>!B9I!B9=!B9E!B9G#R-3#R-4#R-6#R-8#R-:!B9@!B9C!B9H
M!B9D!B9A!B9?!2->#R-9!2-=!2-?!2-@!2-A!"5J!BI/!BI'!BI,!BI&!"5G
M!BI*!"5L!BI(!256!BI1!B9!!BI)#R8F#R8G#R8H#R8I#R8J#R8P#R8Q#R8L
M#R8K!"5K#R8O#R8N!BI0!BI+!BI-!BI.#R8R#R8E!BI%!BI$!257!2A;!B]B
M!2A7!B]D!B]A!2A8!"A?!B]K!B]C#REZ#REH#REI#REK#REL#REM#REN#REO
M#REP#RER#RES#REU#REV#REW#REX#REY#RE[#RE\#RE]!B]J!B]L!C0Q!B]G
M!B]H!B]F#RET!2A=!2A:!2A>!2A<!2A9!2Q>!"PR!C8T!"PP!"PT!C8R!C8\
M!C8V!C8]!C8^!C8Q!C8N!C8Z!C8O!C9`#RY5#RY6#RY7#RY8#RY9#RY:#RY;
M#RY>#RY?#RY@!C8P!C8_!C8W!C8X!C8Y!2Q@!C8[#RY=#RYA!C8S!2Q?!2QB
M!#!]!CXG!#!\!3%=!CXT!CXM!3%;!CXJ!2QA!CXS!CXP!3%:!#$B!#$C#S-/
M#S-;!CXN!CXO#S-.#S-0#S-1#S-2#S-3#S-4#S-5#S-6#S-8#S-9#S-:#S->
M#S-?#S-@#S-A!3%<!CXQ!CXU!#!^!CXH!CXI!3%8!3%9`SI/!E%.!#9R!D='
M!#9J!D=%!#9P!#9L!D=+!D=0!#9U!D=$!D=&!D=-!3<T!CXR!D=/!#Q:!3<Y
M!#9S!D]M!3<X#SEV#SEX#SEY#SEZ#SE[#SE\#SHA#SHB#SHC#SHD#SHE#SHF
M!D=1!D=*!D=)!#9T!D=,#SEU!3<W!3<Z!D=(!3<U!3<V!3<[!3Y&!E%6!E%+
M!E%5!3Y-!#Q4!EMB!E%2!3Y,!E%1!3Y$!3Y+!3Y#!E%4!E%0!3Y)!3Y*!#Q5
M!3Y'!E%)!E%,#SEW!E%3!E%-#T!F#T!G#T!H#T!J#T!K#T!L#T!M#T!N#T!O
M#T!P#T!Q#T!R#T!S!E%/!3Y.!3Y(!3Y%!44I!44H!44G!EM<!$)<!EMD!EMF
M!EMA!44J!EM@!44F!EMG#T<R#T<S#T<T#T<U#T<V#T<W#T<Y#T<Z#T<[#T<\
M!EM=#T<X!EMK!EMC!EM3#T<Q!$):!EME!EM>!44E!44K!R%R!$DT!$DU!R%O
M!$DV!4Q+!4Q,!R%K!R%X!$DW!R%W!R%T#TXA!4Q-!4Q/!R%G!R%U#TU\#TU]
M#TXF#TXG#TXH#TXI#TXJ#TXK#TXM!R%L!R%M!R%N!4QQ!R%S!R%Q!R%I#TU^
M#TXD#TXC!4Q.!4Q*!4Q(!R%H!4Q)!RQO!RQQ!RQL!$]W!$]Z!$]Y!RQM!RQP
M#TXL#U-T#U-V#U-X!5-Z!RQR!5-[!5-Y!S1O!RQS!RQN#U-W!$]V!S=#!%5]
M!S<]!5LN!S<_!S=$!S="!S=%!5LL!RQT#UED#UEE#UEF#UEG#UEH#UEI#UEJ
M#UEK!SYL!S=`!S=!!%5^!5LO!S\T!6%'!S<^!6%)!S\S#UY'#UY(#UY)#UY+
M#UY-#UY.!S\Q!S\R!5LP!6%(#V(H!6%*!T9"!T8_!6==!T9'!T9!#UY,#V(G
M!T9#!T9&!TH[!T9`!S\U!&,S#V4B#V4C#V4D#V4E!TU.!6MW!U,H!&8V!U,D
M!U,C!U,G!U,E!6]T#V=)#V=*#V=,!U,F#V=+!6]R!6]S!U=;#VD]!7,T!U==
M!7,U!UM+!U=<!UY7!7=7!7M?!V5:!V9"!V9/!B)B!B]M!B9K!BI2#RE^#RHA
M!2QD!C9"!B]N!C9!#RYB!2QC!CXV#S-B!D=2!E%9!E%8!EMJ!F1Z!EMH#T<]
M!EMI!R%Z!R%Y!RQU!S\V!T,_#UY/!S\W!T9(!T9)!T@[!U=>!2$O!B)C!B0W
M!B0V!B9L#R-<!C9#!CXW!CXX!E%:!B0Y!B0X!2-D!2-C!"5O!BI3#R8T#RYC
M!3%>!CXY!CX\!2QE!CX[!CXZ!3Y/!E%<#T!T!EML#T<^!EMM!4Q0#TXO#U-Y
M!RQV!RQW!S=&!T9*!S\Z!S\X!S\Y!T9+!TU/!B)D!B)E!B0Z!B9N!B9M!BI4
M#R5"!2A?!2QH!"PU!2QG!C9&!C9%#RYD#RYE!C9'!2QI!#$D!3%A!CX]!3%?
M!3%@!3%B#S-C!D=4!3<^!3="!3=`!3=!#SHG!3Y0!E%=!3Y2!3Y1!E%?!$)A
M!EMO!EMP!EMN!44L!44N!R%[!4Q1!S\[!5LQ!5LR!T9,!B%G!B%H#R$X!B)F
M#R%3#R%4!2%V!B0\!")4!B0_!B1`!B0^!B0]#R%K!"-C!"-D!"-F#R-=#R->
M#R-?#R-@#R-A#R-B#R-C!B9P!B9O!"5V!25:!"5T!BI5!BI6!"AC!BI<!BI8
M!BI9#R8V#R8W!BI:!BI;!BI=!"5Y!BI7!BDY!"AD!"AB!2AA!2AB!2A@#RHC
M#RHD#RHE#RHF#RHH#RHI#RHG#RHB!2QL!C9(!C9+!2QJ!2QM#RYG#RYH#RYI
M!C9*!"PW!2QK!3%D#RYF!"PV!CY!!CY$`S1^!CX^!CY#!CY`!CY%!CX_#S-D
M#S-E!#$G!3%C!#Q>!D=8!D=;!D==!D=:#SHH!D=5!D=<!3=#!D=9!#9Z!#9X
M!3=$!D=7!E%@!E%A!#Q=#T!V!3Y3!3Y4!3Y5!EMR!$)C!44O!$)B#T<_#T=`
M#T=!!EMQ!44P!$DX!R(B!R%\!R(A!RQ\!R%^!4Q3#TXQ#TXR!R%]!$)D!4Q2
M!RQ]!5-\!RQX!RQY!%8A#U-Z!RQZ!S=(!S='!5LS!%8N!%I[#V(I!6MX!U,I
M#VD^!75H#VM$!UY8#VQ?!2%B#R%5#R%6!B1!!")8!B1"#R(Y#R(Z#R([#R(\
M!")7!2)+!B1#!2)*!B9T!"-H!"-K#R-D#R-F#R-H#R-I#R-K#R-L#R-M#R-N
M#R-O#R-E!B9R!B9S!B9U!B9Q#R-J#R-G!2-F!2-G!2-E!"5\!BIA!BI@!25@
M!"5Z!25>!"5]!25;!25<!"5^#R8Z#R8[#R8^#R8_#R9`#R9!#R9"#R9##R9%
M#R9&#R9'#R9(#R9)!BI?!BI>#R9$#R8\#R8]!25B!25?!25C!25A!"AH!2AD
M!B]V!B]X!B]Y!"AE!"AK!2AF!"AF!2AC!B]P!B][!B]T!2AK!B]^#RHM#RHN
M#RHO#RHP#RHQ#RHR#RHS#RHT!B]S!B]W!"AL!B]U!B]Z!B]O!B]]!2AI!"AJ
M!2AJ!2AG!B]Q!B]\!2AE!2AH!B]R`S!3!2QP!C9/!2QR!2QU!2QO!C95!2QN
M!C96!C90!C91#RYL#RYN#RYP#RYQ#RYS#RYT#RYU#RYV#RYW#RYY!C94!C9.
M!2QQ!C93!C92#RYO#RYR!2QW!2QT!2QS!2QV!2QX!CY,!CY2!CY&!CY'!3%J
M!CY(!CY)!CY/!3%I!3%M!CY-!#$K!CY.!3%K!CY3#S-H#S-I#S-J#S-K#S-L
M#S-M#S-N#S-O#S-Q#S-R#S-T#S-U#S-V#S-W#S-X#S-Y#S-Z#S-[#S-\#S-]
M#S-^#S0A#S0B#S0C#S-P!CY1!#$J!CY+!CY*!3%F!3%G!3%H!3%E!#9[!D=B
M!#9\!3=:!D=?!#<A!3=(!3=9!D=D!D=F!3=/!D=E!D=@!3=0!3=)!3=7!3=4
M!3='!3=+#SHI#SHK#SHL#SHM#SHN#SHO#SHP#SHR#SHS#SHT#SHV#SHW#SHX
M#SHY#SHZ#SH^#SH_#SI!#SI"#SI##SI$#SI%#SH[!3=6!D=C!3=8!D=>#SH]
M#SI`#SHQ#SHJ!3=%!3Y6!3=3!3=,!3=2!3=1!3=*!3=-!3=5!D=G#S-G!3Y?
M!3Y:!3Y=!3Y7!#QE!3Y9!E%C!#QB!#Q@!E%G!E%E!EM\!3Y<!3Y;!E%F#T!X
M#T!Y#T!Z#T!\#T!]#T!^#T$B#T$C!E%B!E%D#T!W!E%H!3Y8!3Y>!3Y@!E%J
M#T$A!$)P!44R!$)J!EM[!$)Q!EMS!44T!R(I!$)S!EMU#T=(!$)O!44W!$)N
M#T='#T=)#T=*#T=+#T=,#T=-#T=.#T=/#T=0#T=1#T=2#T=4!EMT!EMX!$)R
M!$)E!EMV#T=3!44S!44V!44U!R(F!44Q!EMW!4Q;!4Q9!$DY!4Q6!R(O!4Q7
M!$D_!$D[!R(L!$D^!R(E!EMY!R(D#TXZ!S=1#T=%!4Q4!4Q<#TXS#TXT#TXU
M#TXV#TXW#TXX#TXY#TX[#TX]#TX^#TX_#TY`#TY!#TY"#TY$!EMZ!R(G!R(N
M!R(M!R(H!R(C#TY%#TY##TX\!4Q:!4Q5!$D]!R(J!4Q8!R(K#U0E!50H!50C
M!RTE!RQ^!50I!50F!RTA!$]^!RTH!50B!RTK!5-]!RTJ!RTL#U-[#U-\#U-]
M#U-^#U0B#U0C#U0D#U0F#U0G#U0K#U0L!5-^!RTF!RTG!RTC!RTB!RTD#U0A
M#U0H!50G!50A!50E!RTI!S=+!S=4!S=/!$]]!S=-!%8C!S=3!S=*!5LV!5LT
M!S=,!S=.!S=0!5LU!%8E#UEL#UEM#UEN#UEO#UEP#UEQ!S=2!S=5!S=)!6%+
M!%I\!S\_!6%,!6%-!S\^!S]`#UY0#UY1#UY2#UY4!S\]!S]!#UY3!S\\!6=?
M!%]3!T9-!T92!T90#UY5#V(J#V(K!T9.!6=A!6=@#U]S!TU1!6MY#V4F!6MZ
M!6M[!U,J!6]V!U,K!6]U#V=-#V=.!U=B!7,V!U=A!U=C!U=?#VD_!U=@!U=D
M#VE`!75I!UM,!UY:!UY;#VM%!UY9!UY<#VPD!7DD#VQ*!V--!7IE!"$S!B)H
M!2%C!B)I#R%8#R%7!B1%!B1$!B9V!B9W!2-J!"-L#R-P!2-I!"AO!C`D!BIC
M!BIB#R9*#R9+#R9,#R9-#R9/!BID#R9.!C`C!C`A!C`F!C`E#RHU#RHV#RHW
M!C`B!C99!2QY!C98#RYZ#RY[!2QZ#S-F#S0D#S0E#S0F#S0G!3=<!D=I!3=;
M!D=J#SI'!D=H#SI&!#QF!#QH!E%M!3YB#T$E#T$F!E%K!E%L!3YA!#QI!EM]
M#T=5#T=6!44X!$E!!$E"#TY&!4Q=!RTO!RTN!RTQ!RTR!50J!RTP#U0M#U0N
M!S=6!TU2#V(L#V(M!6M\#VQ@!B%I!2%D!B1&!B1)!B1*!"):#R(]#R(^#R(_
M#R)`#R)!!B1'!B9^!B9]!"-N!B9[!B9\#R-R!25E!25D!BIF!25F!BIG!BIH
M#R91#R92#R94#R95!BIE#R93!2AL!C`H!C`J!2AM!"AQ!"AR!"AS!C`K!C`G
M!C`I#RHX#RHZ#RH[#RH\!C`L!C`M!"Q*!C9A!"Q%!"Q$!"Q#!"Q'!C9D!C9E
M!C9?!C9>!2Q]!2TB!C9;!C9B#RY\#RY]!C9@!C9C!C9:!C9<!2TA!2Q^!#$M
M!3%O!CY7!CY9!CY8!CY6!CY;!3%P#S0H#S0I#S0J#S0K#S0L#S0M#S0N#S0O
M!#$O!CY<!3%N!CY5!3=>!#<F!3=A!D=P!D=K!#<C!3==!3=@!D=N!#<E!3=?
M!D=O!D=L#SI(#SI)#SI*#SI+#SI,#SI-#SI.#SI/!D=M!3=B#SUL!E%T!E%P
M!#QK!#QP!3YC!E%W!3YD!E%R!E%Q!E%V!#QM!E%S!E%O!E%U#T$G#T$H#T$I
M#T$J#T$L#T$M#T$N!E%N!EM^!EPG!44\!44Z!EPD!EPL!$)V!EPN!EPK!EPF
M!44Y!R(S#T=7#T=8#T=9#T=:!EPH!EPE!EPI!EPM!EPA!EPC!44[!EPJ#T=$
M!F)G!R(P!4Q>!$E'!R(W!$E(!R(U!R(R#TY'#TY(#TY)#TY*#TY+#TY,#TY.
M#TY/!R(X!R(V#TY-!4QA!4Q?!R(Q!4Q@!RTU!RTW!50L!%`B!50M!50K!RTV
M!RTS!RTT#U0O#U0P#U0Q#U0S#U0T#U0U#U0V#U0W!S=9!S=7!5LX#UER#UES
M#UET#UEU!S=8!S=:!R(T!5LW!T98!6%.#UEV#UY6#UY7!S]"#V(N!%]7!T93
M!T95!%]6!T97!T96#V(O!T94!&,V!TU3!U,L!&8X!U,M#V=/#V=0!U,N!7,X
M!&AF!U=E!7,W!U=F!&I%!&MG#VM&!V!L!V1%!7DE#VPE!&U4!7HG!&UQ!V-.
M!V4T!B%J!BIJ!BII#R96#R97!2AO!C`N#RH]!C`Q!C`O!#$Q!D-G!CY>!CY=
M!#<G!CY?!E%Z!E%X!E%Y!EPP!$0F#T=;!EPQ!44]#TY1!R(Z!R(Y!RTY!5-2
M!RTX!S=;!S=<!6%/!T99!TU4!U,O!B%K#R$Y!B1,!2),!B<D!"-R!B<C!B<B
M#R-S!25G#R98!BIK!C`R!C`P!C`S!2AP!"Q+#R\A!C9I!CYA!3%Q!3=C!CYC
M!CY@!CYB#S0P!D=Q#SI0!D=S!D=R!3YE#T$O!44^!EPS!EPR!4QB!R([!50O
M!RTZ#UEW!6%0!6]W!"%*#R$Z!2%E#R%-#R%:!B)K!B)J!2)-#R)#!2-L!"-S
M!25H!B<E!2-K!2-N!2-M!C`T!25I!BIL!25K#R99!C`U!25J!2AQ!C`W!C`X
M!2AR!C`Y!2TC!C9L!C9J!2TD!C9K!C9M#R\B!CYF!3%R!#$T!3%T!D=V!D=T
M!D=U!#<J!D=W#SI1!E%[!E%]!E%\!4@F!$)Z!EPT!45`!44_!EPU!45!!RT]
M!R(^!R(]!R(\!RT[!50P!RT\!RT^#U0X!S==!&8Y!&AG!7DF!B$^!"%U!"%T
M!B)L!B1-!")>!2).!B1.!B10!B11!B1/#R)$!B<I#R-T!B<G!B<F!B<H!2-O
M!"8L!"8K!BIM!BIN!25L!BIO#R9;!25M!"AW!C`Z!C`_!"AZ!"AV!2AU!C`^
M!C`]!C`\!C`[#RI`#RI!#RI"#RI##RI$#RH_!C!`!2AT!C9R!"Q0!C9O!"Q/
M!CYG!C9P!C9N#R\C#R\D#R\F#R\G#R\H!2TF!2TG!C9Q!C9S!2TE!C9T!CYM
M!CYI!3%X!3%Z!3%W!3%Y!3%V!3%[!CYP!CYJ#S0Q#S0R#S0U#S0V#S0W#S0X
M#S0Y#S0Z!CYH!CYL!CYO!CYN#S0S!D@C!D@D!D@B!#<L!D=^!D=Z!3=D!#<M
M!3=E!D=Y!D=X!D@E!D@A!D@F!D=\#SI2#SI3#SI4!D=]!#<N!E(C!3YI!3YG
M!E(F!3YH!E(E!E(I!E(A!E%^!E(G!E(D#T$P#T$Q#T$R!E(B!E(H!3YF!$)\
M!$)^!$)[!EPX!EPV!EPW#T==!EPY!45"!R)`!4QF#TY2#TY3#TY4#TY5#TY6
M!4QE!4QD!RU`!RT_!R(_#U0Y!S`M!S=>!S]#!%]8!6=B#V4G#V4H!6M]#V=1
M!7,Z!2$P!B%L!B)M!B14!B13!B12!2)/!"-U!B<J!"8M!BIQ!BIP!2AW!C!"
M!C!#!2AV!C!$!C9W!C9X!C9V!C4H!C9U!CYQ!CYR!D@H!3=G!D@I!D@G#SI5
M!E(J!EPZ!R)!!RU!!R)"!R)#!U,P!UY=!2%%!2%&!B)P!B)N!B)R!B)Q#R%<
M#R%=#R%>!B)S!2%F!B)O!B17!B15!B19`R-9#R)%#R)&!B16!2)3!B1:!B18
M!2)2!B<N!2-Q!2-X!2-Y!B<P!2-V!2-U!2-W!2-R!2-S!B<Q!B<L!B<R#R-V
M#R-W#R-Y#R-Z#R-[#R-^#R0A!B<M!B<O!"-]#R-]!B<T!B<S!"-\!B<K!2-Z
M!"8P!25U!BIU!"8S!BIR!25S!25T!BIZ!25Q!BIW!BI\!25O!BIY!25R!25P
M!BIT!B<U#R9<#R9=#R9>#R9?#R9@#R9A#R9C#R9D#R9E#R9F#R9G#R9H!BIX
M!BTK!BIS!25V!C!0!C!*!2AX!C!+!2AY!"A^!2AZ!C!&!C!)!C!2#RI%#RI'
M#RI(#RI+#RI,#RI-#RI.#RI/#RI0#RI1!C!-!C!%!C!'!C!1!C!/!C!,#RI*
M#RI&!C!(!2A[!"A\!2TL!2TI!"Q2!"Q9!2TJ!C<A!"Q8!2TT!2TP!2TK!C9]
M!2TQ!2TM!2TO!C<D!C9^!"QB!C9Y!"QC!"Q6!C<E!C<B!C<C!C9[#R\I#R\J
M#R\K#R\L#R\M#R\N#R\O#R\Q#R\S!2TH#R\P#R\R!2TS!"Q=!2TU!2TV!2TR
M!CM.!#$Z!C\K!C\D!C\F!#$\!#$^!3%^!CYY!C\B!CY[!3(H!#$X!C\G!C\L
M!C\I!CYT!C\J!#%`!#$[!3%\!3(F!CYS!#$V!3%]!3(D!C\H!C\C#S0[#S0\
M#S0]#S0^#S1`#S1!#S1"#S1##S1$#S1&#S1'#S1(!CYW!C(J!CY]!CY\!CY^
M!C\A!C\E!#$_!3(I!3(A!3(G!3(C!3(B!3(E!3(J!3=I!D@S!3=N!D@J!D@T
M!3=O!3=L!3=K!#<P!3=P!3=J!3=Q!3=R!3=T!D@N!CYZ!#<Q!D@O!3=M!#<S
M!3=H!3=S#SI6#SI8#SI9#SI:#SI;!D@M!3=U!D@R!D@L!D@Q!D@P#SI<!3YP
M!E(M!3YL!#QZ!3YQ!E(N!EP[!#Q]!E(U!3YJ!3YS!E(K!3YO!E(L!E(Y!E(P
M!E(X!3YN!E(V!EQ`#T$W!3YR#T$S#T$T#T$V#T$X#T$Y!E(Z!E(R!E(W!3YK
M#T$U!E(O!45#!45+!45)!EQ!!EP\!$,K!$,F!$,E!45$!45(!45'!45*!45.
M!EP^!EQ'!45-!45%!45&!EQ"!$,I!EQ&!$,G!$,C!45,!EQ%!EQ#!EP_!$,H
M#T=>#T=?#T=@#T=A!E(Q!$E.!R))!$E2!R)%!4QI!R)0!R)*!4QN!4QG!R)'
M!R)1!4QO!R)/!R),!R)-!4QP!4QJ!4QM!RU$!R)&#TY7#TY8#TY9#TY;#TY<
M!R)$!R)+!R).!4QK!R)(!$E1!50S!%`C!RU*!%`D!50U!RU"!50X!50T!50Q
M!RU'!RU#!5LY!50R#U0Z#U0[#U0\!RU%!RU)!RU(!RU+!RU&!RU-!50W!%8I
M!5L[!6%5!S=@!5L_!S=F!5LZ!S=B!S=D!S=A!5L]!S=?!S=E#UEY#UEZ#UE[
M!%8J!S=C!S=G!SDG!5M`!T9:!6%4!S]'!%I^!6%1!6%2!S])#UY9!6%3!S]&
M#UY8!S]%!S](!6%6!6%7!T9<!%];!T9>!6=E!%]9!T9=!T9?!T9@#V(P#V(Q
M#V(R!T9A!T9B!T9;!&,X!TU5!&,W!6M^!TU7#V4I!TU6!5L^!6]X!6]Z!6]Y
M!U,R!U,Q!7,[!&AI!&AJ!U=G!U=I!U=H!U=J!7,\!UY>!&MJ!&MI!UY@!7=8
M!UY?!7DG#VPF!7HH!7IF!7L\!V-/!7PT!B%M!"$E!")B!2)4!B1;!B1<!2)5
M!B-^!"-^!2-[!BI]#R9J#R9I!C!5!C!4!C!6!C!3!C<F!3(K!#%!!C\M!3=V
M!EQ(!R)2!50Y#TY=#U0]!S=H!S]*!T9C!6=F!UYA!V4U!B%O!B%Q!B%P#R$[
M!2%H!2%G!2-\!B<W#R9K!C!7!C<H#R\T!C\N#SI>!R)3!T9D!B)T!2)6!BI^
M!C!9!C!8!"QE!C\O!35?!3(M!C\P!3(L!D@V#SI?#SI@#SIA!R)4!S]+!"%W
M!B)U!B)V!2)9!2)8!")D!2);!B1A!B1@!B1>#R)(#R)*!2)7!B1?!2):!B=!
M!B<[!20B!B<X!2-^!2-]!20C!B=`!20D!B<\!B<_!20A#R0D!B<Y!B<Z!B<]
M!20E!B<^!25[!"8U!25Y!25]!25Z!25\!28A!BLC!25^!28B!BLB#R9L!28C
M!BLA!25W!25X!2A^!C!B!2A]!2DB!2A\!2DC!C!?!2DE!2DD!C!;!2DA!C!:
M!C!E!C!G#RI3#RI4#RI5!"DF!C!A!C!@!C!<!C!=!C!F!C!D!C!>!2TX!C<R
M!2TW!C<N!2TY!3(N!C<J!"QI!"QJ!C<O!2TZ!C<M!C<Q!C<P!"QG!C<S!C<T
M#R\V#R\U!C<I!C<K!C\U!3(U!#%&!#%#!#%$!3(S!3(O!C\Z!3(P!3(T!C\\
M!3(Q!3(V!C\V!C\[!C\R!3(R!C\T#S1)#S1*#S1+#S1,!C\Y!C\Q!C\]!C\W
M!C\S!D@Y!#<^!D@^!3=Y!3=Z!#<X!3=X!D@Z!#<W!3@A!3@B!C\X!DA`!D@]
M!D@[!3=]!D@X#SIB#SIC!D@_!3=[!3=W!DA!!3=^#T`K!3YX!#TB!452!#TE
M!3YU!3YT!#TD!3YW!3YZ!E(^!E([!E(]!EQ+!3Y[!E(\!3YV!3YY!EQ,!EQ-
M!458!$,T!45/!455!EQ*!454!457#T=B!459!450!456!451!R)7!R)9!4QT
M!4QS!4QU!$E7!4QV!4QX!$E6!R)6!R)5!R)8!4QW!4QY!4QR!RU0!50^!RU2
M!RU8!50]!%`H!RU7!RU6!50[!RU1!50\!RU4!50_!RU/!%`J!5M!!5M"!%8L
M!S=K#UE\!S=I!S=J!6%:!6%9!6%8!T9F!%]=!6=G!%]<!T9E!T9G!6=H#V(S
M!TU8!6PA!U,S!U=L!6][!7,]!U=K!UYB!UYC!7=9!V-0!V-U!"%X!B="!20F
M!"0F!BLD#R9M#R9N!C!I!C!H#RI6!C<U!3(W!DA"!3@C!E(_!45:#T=D!TU9
M#VI.!B%R!B%S!B)X!2%I!B)W#R%B!")G!"0G!20G#R0F!BE>!BLE!28D!28E
M!C!J!C!!!"\G!C<V!#%*!DA#!3Y\!45;!R);#T=E!EQ.#TY?!R)<!R)=!%8F
M!U=M!")H!2)>!B1D!2)=!B1C!B1B!B1F!")I!B1E!B=%!20J!20L!20K!20H
M!20I!B=$!B=(!BLH!B=#!B=&!20M!28L!28H!28G!28K!28J!"8Y!BLF!BLI
M!BLG!"8^!BLJ#R9P#R9Q#R9R#R9S#R9T!28I!28M!BLK!2DH!2DJ!"DG!C!L
M!2DI!C!M#RI7#RI9#RI8#RI:#RI;#RI<!C!K!2T]!2U`!2T^!2U!!2T[!C<Z
M!C<[!"QN!2U"!2T_!C<\!2T\!C<Y#R\W!C<W!C<X!2Q[!3)$!3([!3(Y!#%-
M!C]#!3)"!C](!C\^!3(]!3(\!3(_!3(^!C\_!C]`!3)!!3(X!#%0!C]$!3)#
M!3@H!C]!#S1-#S1.#S1/#S10#S11#S12#S13!C]'!D8]!3(Z!C]"!3)`!DA*
M!#%+!3@K!3@L!3@M!DA+!DA.!3@G!DA-!#="!3@J!3@F!DA)!#=#!3@E!E)$
M!DA&!DA'!3@D#SIE#SIG#SIH#SII#SIJ!DA(!DA,#SIF!#TK!3\E!#TL!E)!
M!E)"!3\B!3\C!E)'!3Y]!E)%#T$Z#T$[#T$\!E)#!E)(!3\D!3Y^!E)&!$,X
M!45<!$,W!45>!EQ0!45@!45?!EQ/#T=G#T=H#T=I#T=J#T=K#T=L#T=M#T=N
M#T=O!EQ1!F`Q#TI4!R)>!$E:!#<_!$E8!4QZ!$E9!RU9!R)B!4Q\!4Q^#TY@
M#TYB#TYC!R)?!R)A!R)C!R)@!4Q[!51!!4Q]!51#!51`!%`M!51$#U0_#U1`
M#U1!#U1"!S=N!5M$!S=L!S=M#UE^#UHA#UHB#UHC!5M#!S=O!5M%!S]1!S].
M!6%;#UY:#UY<!S]-!S]/!S],#UY;!S]0!T9H!T9I!6%<!6=I#V(T#V(U#V(V
M!6=J!6PD!6PC!TU=!TU;!6PB!TU:!TU<!TU>!&8\!U,T!U-A!7,^!U=N!U=O
M!75J#VI/!UM-!UYD!V(V!7IH!7IG#VQ[#R%C#R)+#R),!BLL#R0G!BLM!BLN
M#R\Y#R\[#R\\#R\Z!3)%#S14!DA/#SIK#SIL!3\F!B$_!B%U!B)Y!B=)!"0J
M!C!P!B=-#R0H!B=+!B=.!"8_!BLP!28N!BLQ`RHY!"=!!C4C!C!R!C!S!C!Q
M!C!O!C!N!C<_!C<^!"QO!C<]!C=`!C])!C]*!C]+!C],!C]-!C].!#=$!DA0
M!DA4!DA3!DA1#SIM!DA2!E))!3\G#T$]!EQ3!EQ4!EQ2!45A!R)D!RU:!RU<
M!%`O!51%!S=Q!S=P!U=P!V-1!V-2!V4V!B%`!B%V#R)-!"0K!B=0!B=/!20N
M!BLR!C!V!C!U!C!W!2YH!C]/!3@N!E)*!EQ5!R)E!RU=!2$J!2%'!B%X!B%\
M!B%W!B%Z!B%[!B,A!B,B!B)\!B)Z!B,C!B)[!B)]!B)^!2%J!2)@!2)?!B1H
M!B1I!B1J!B1K!20O!B=1!20Q!B=3!20P#R0I#R0J#R0K#R0L!B=2!20R!28O
M!BLV!BLS!BLT!BLW!BLU!C!^!2DL!C!]!"DP!C!Y!2DK!C!X!2U$!2U#!2U%
M!C=#!C=!!2U&#R\]!C="!3)*!3)(!3))!C]6!C]0!"DO!DA5!C]2!C]3!3)'
M!C]1#S15#S16#S17!C]4!C]7!C]5!DA6!DA9!3@O!3@R!3@Q!DA:!3@P!DA8
M!DA7!3\H!#TQ!E)+#T%`!E),!45B!EQ6!45C!EQ7!EQ9#T=P!EQ:!EQ8!4TA
M!4TB!$E@!R)F#TYD#TYE!R)G!RU?!51&!%`P!RU@!RU>!S=S!S=R!S=T#UHD
M!%LB!6%>!S]2#UY=!6%=!T9M!T9K!T9O!T9J!T9L!6=K!6PE!TU?!%]?!TUA
M!TU@!6PF!6]\!6]]!&8]!U,U!7,_!V`\!V!O!V1&!B1N!B1L!B1M!20S!C$A
M!BLX!BTR!C$D!C=$!C$B!C$C!C=&!C=%!C]8!D\A!3@S!DA<!DA;!3\J!EQ<
M!EQ?!EQ=!EQ;!EQ>!RUA!RU.!%`R!S=U!S]5!S]4!S]3!T9R!T9P!T9Q!U=Q
M!UM.!V(W!B,E!B,D#R%D!B1Q!B1O#R0M!B=4!28P!BL[!BLZ!C='!"QT!"QS
M!35@!C]=!C]9!C]:#S18#S19#S1:!C]<!C];!3)+!DA=!DA@!DA>!DA?#SIN
M!E)1!E).!E)0!E)/#T%!!$,\!EQ@!R)K!R)L!R)I!R)J!4TC!%`S!51'!RUD
M!S=V!S]6#V=4!TUB!U,V!7-!#VPG!B%]!2%K!"%Y!2)A!")N!2)B!20T!B=8
M!20U!B=7!B=9!B=;!B=6!20V!B=5!B=:!28S!BL]!28Q!BL\!28R!2DM!BL_
M!"DS!C$F!2DP!2DN!C$H!2DR!2DQ#RI>!C$G!C=-!"QY!"QW!"Q\!"QU!2U+
M!2U)!"QX!"QZ!"QV!"Q[!2U*!C=)!C=/!C=,#R\_#R]`!C=+!C=0!C=.!C=*
M!#%6!3)/!C]H!C]A!3),!3)1!3).!C]@!3)0!#%8!C]G!C]E!C]B!#%9!C]F
M!3)-!C]D!C]?!C]C!DAD#S1<!#=&!3@V!3@U!3@[!3@Z!3@W!#='!DAA!3@T
M!DAC!3@X!#%5#SIP!DAB#SIO!3@Y!3\L!3\K!E)2!E)4!E)7!E)3#T%"#T%#
M#T%$#T%%#T%&#T%'!E)5!E)6!E9L!3\M!#TR!EQF!EQC!45F!EQB!$,^!45E
M!$-!!$-`!EQA!45H!45J!45D!EQH!EQI!EQJ!45G!EQD#T=Q#T=R#T=S#T=T
M#T=U!EQE!$ED!4TD!5M(!$EC!$EB!4TE!R)M!R)O#TYF#TYG!R)N!R)P!RUE
M!51(!51*!RUG!RUF#U1$#U1%!RUH!51)!5M'!S=W!%8P#UQ?!5M&!6%@!S]7
M!6%?!S]8#UY>!6%A!T9S!T9U!T9V!TTB!T9T!6PG!&,^!&,]#V4J!TUC!U,W
M!6]^!U=R!&I'!7DH!2$Q!B(A!")O!2%L!B,F#R)/!B1U!2)C!B=@!2)I!B==
M!2)D!B1S!B1T!2)E!B=<!B=>!B=A!B1R!2)H!20W!20Y!"9%!B=F!B=D!BM&
M!B=G!BM`!B=B!B=C!BM$!B=E!B=H`R5^!B=I!20Z#R0N#R0O#R0Q#R0R#R0T
M#R0U#R0V#R9W#R9X#R9Y#R9Z#R9[#R9]#R9^#R<A#R9\!BM%!BM!!BM"!"0M
M#R0P!"9$!28T!BM#!"9'!BM,!"E'!C$O!"9+!BM-!C$I!28U!C$L!BM/!"9*
M!28W!"DX!28V!"E#!BM)!28X!"91!"E$!C$J!C$K!BM0!BM'!C$M#R9U#R<B
M#RIP!"E&!C$N!BM(!BM*!BM.!BM+#RID#RI?#RIB#RIE#RIH#RIL!C=;!C=9
M!C$R!"E)!2DW!"E"!"TI!2U.!2DV!C$Y!C=7!C$S!"Q]!2U,!C$U!C=3!"TA
M!C$X!2DT!"Q^!C$Z!C$Q!C$W!C=6!C=5!"TJ!C$T#RIA#RIF#RII#RIK#RIM
M#RIN#RIO#R]&#R]'#R](#R]*!C=2#R]$!C=8#RIC!2U-!C=1!2U2!2U8!2U;
M!C]M!C=C!C]O!C]K!C]P!C=D!2U5!C]I!"TN!C]S!2U6!"TF!3)=!2U1!2U<
M!C=B!C==!3)4!C=?!C=A!C]L!C=@!C]Q!"TG!2U0!C=<!3)3!C]R!C]T!3)2
M!2U/#R]!#R]"#R]##R])#R]+#S1=#S1?#S1@#S1D#S1E#S1F#S1G#S1H!C]J
M!C=E!C=F!2U4!2U9!#=:!DAQ!#=-!3)9!C]\!#=+!DAS!DAI!3A5!C]^!DAR
M!D`B!#%E!2U3!#%M!C]W!DAN!#%A!3@_!3)7!3):!#=,!C]Y!3)<!C]V!C]N
M!#%I!3@\!DAP!3)>!#%?!C]]!C][!C]Z!DAF!DAL!3@^!3A!!DAT!3)5!DAK
M!DAV!DAG!DAE!C]U!3A`#S1A#S1>#S1B#S1C#S1I#S1J#S1K#S1L#S1M#S1O
M#S1P#S1R#SIR#SIS#SIT#SIU#SIV#SIW#SIY#SIZ#SI\#SI]#SI^#SLA#SLB
M#SLE#SLI#SLJ#SLL#SLN!DAH!3)6!C]X#SLG#S1N!DDD!DAM!D`A#SLD!#T_
M!3A*!3A-!3A2!#=/!#=7!#=1!E)=!DDC!3A0!DDB!#=3!3A6!3A8!3A#!E)A
M!3A:!3\S!#=;!3A3!DDA!3A&!DA[!3\T!3A$!3A4!3)?!E)8!3A'!#TV!#=8
M!3A9!3A1!3A+!3\Q!DAW!3A/!3@]!DA^!E)B!E)C!E):!DA]!3A7!E)>!E)@
M!3\O!#U`!#=2!3A)!DAY#SIQ#SI[#SLC#SLH#SLM#T%(#T%.#T%0#T%1#T%2
M!E)<!E)?!E);!DAZ#SLK!3A.!3\N!3A,#S1Q#T=]!3\\!3\V!3\U!E)K!4TF
M!3]%!EQO!3\Y!3\_!3]$!EQT!E)O!45K!3\[!EQL!E)E!3\X!3\]!3\Z!E)9
M!$EN!EQV!EQY!3]#!E)H!EQR!$-/!EQX!EQW!3]!!45M!3\^!EQQ!EQN!EQM
M!3\W!E)G!E)M#T%*#T%+#T%,#T%-#T%/#T%3#T=V#T=W#T=Y#T=Z#T@E#T@H
M!EQP!EQU!3]`#T%)!EQS!E)N!ETC!ETG!$-%!$-$!4TG!EQ\!45W!45V!45S
M!#TU!EQ[!R)R!R)U!4TI!45P!45O!45L!45Q!45R!45Y!ETE!EQ]!EQ^!E)J
M!ETB!R)T!ETA!R)W!45T!45X!RUJ!$-3#T=X#T=\#T=^#T@A#T@C#T@D#T@F
M#TYI#TYJ#TYK#TYL#TYM#TYN#TYO#TYS#TYU!R)S!R)X!EQK!45N!EQZ!4TH
M!45U!RUQ!$EF!$-2!RUK!$EQ!RUM!4TO!RUS!$EJ!4TN!R)Y!4TS!$ER!RUU
M!3A%!4TR!4TU!%`U!%`V!R,A!4TT!S=\!4TP!51.!%8T!R)Z!R,B!514!4TK
M!4TM!51-!4TL!RXB!RUW!RUV!R)^!%`\!RUP!RUO#T@B#TYP!RUR!4TQ!RUL
M#TYQ#TYR#TYT#TYV#U1'#U1(#U1*#U1+#U11#U13!RUT!51+!S!0!R)]!R5Q
M!$EP!51,!51/#TYH#U1/!510!512!RU[!RUX!515!516!511!RU^!RU\!RU]
M!517!%`]!5M)!RXA!S=[!S=]!S=Z!S@A!5M+!RUZ!S=Y!RUN#U1-!513!S@B
M#U1)#U1.#U12#UHE#UHF#UHN#UHG!5M*!518#UHJ#U1,!S=X!5M1!%8U!%8Q
M!%LJ!5M.!6%D!6%B!S];!S@F!%LF!5M-!5M/!S@C!S@E!5M0!6%C!S]:!6%E
M!S]9!R)V#UHK#UHM#UY?#UY@#UYB#UYC#UYE#UYF#UYG!S]<!S@D#UHH!%LG
M!5M2!T9Y!S]=!6%H!TUD!%]C!%]B!T9\!6%I!TUG!%LH!6%J!T<E!T<A!T9X
M!6%G!T9^!6=M!T9Z!6=P!T9W!T<B!S]>!T9]!6=N#UYD!6=O!T9[!6=L#V(Y
M!T<J!&-$!T<G!6=T!T<D!6PJ!T<I!T<F!S]?!6=U!&,_!6=Q!6PH!T<K!T<C
M!TUE!6=W#V(Z#V(X#V([#V(\#V(]!TUF!6%F!6=R#V4K!6=V!6PI!U,Y!TUJ
M!&-!!TUI!&-%!U,X!TUK#V=5!UM/!&8^!6PK!U=S!U=T!U=U!U,[!U,Z!U,\
M#VE"!U=V!UM0!UM2!UM3!UM1#VI0#VE!#VI1#VI2!UM5!7=:!UM4!UYE#VI3
M#VM'#VM(!7=;!UYF!7DI!UYG#VPH#VPI!&UR#VQ\#VQ]!7L^!7M@#VTT!2)J
M!")R!B1V!B=K!20[!B=J!B=M!B=L!"92!BM1!BM8!BM4!BM6!"93!BM5!BM3
M!BM7#R<D#R<C!C$]!C$[!C$^!C%`!"E,!C%!!C$_#RIQ#RIR!C$\!C=G!2U?
M!C=I!2U>!C=H!3)A!#%O!D`E#S1S#S1T!D`D!3)@!DDH!DDG!DDE!DDF!#=<
M!DDI#SLO!3A;!3A<#S1V!#U$!E)Q!3]'!3])#T%5!#U!!E)P!3](!ETI!ETJ
M!45Z!45\!45[!R,D!45]#T@I#T@J!ETH!4TV!$ES!$ET!R,H!R,G!R,E!ETK
M!R,C#TY[!R,I!R,F#TYW#TYX#TYZ!R,J!RXJ!RXE!RXD!RXG!RXF!RXI!RXH
M!RQC!S%P!RXC!S@G!5M3#UHO!S]@!T<M!%]E!T<N!6PL#V4L!7`A!U,]!B,G
M!2%M!B1W!B1X!"0T#R0W#R0X!28Y!BM9!BM:!C%#!C%"!C%$!2DY#RIS#RIT
M#RIU!C%&!C%%!2DX!C=L!C=J!C=K!2UA!2U@!D`F#S1W!3A=!3A?!3A@!3A>
M!3]*!45^!$-5!R,K!5M4!7`B!B,H!2%N!B,I!B,J!2%O!2)L!")V!B1Y!2)R
M!2)P!2)O!2)K!2)M#R)0#R)2!2)Q!"0W!B=S!B=V!B=U!"97!20]!B=O!"0X
M!"0U!B=W!20^!"0[!B=R!BM=!B=Q!BME!BM;!B=P!20\!BM<!B=T#R0[#R0\
M#R0]#R0^#R0_#R1`#R1!#R1##R1$#R1%#R0Z!BM>!BM?!BMA!28[!2DZ!BMD
M!C%(!28]!C%*!28\!C%)!C%'!BMB#R<F#R<G#R<H#R<I#R<J#R<K#R<L#R<M
M#R<O#R<E!28^!C%2!C%4!"E8!"E/!"E0!C%3!C=M!2D_!2E"!2E!!C%-!2E'
M!"TT!"E<!2D^!2D]!2UC!"E3!C=N!2E(!"E:!C%0!2E`!2E$!C%.!C%6!C%+
M!2E#!2D\!C%5!C%1#RIV#RIW#RIX#RIY#RIZ#RI[#RI\#RI]#RI^#RLA#RLC
M#RLD#RLE#RLF#RLG#RLH#RLI#RLJ#R]3#R]<#R]A!C%,#RLB!2D[!2UB!2UD
M!"T]!C=U!"TX!2UM!2UK!"TY!"E7!"TU!2UJ!C=[!C=P!C=]!C=S!2UI!C=R
M!C=W!"TV!C=X!2UL!2UE!"TW!2UG!2UH!"TZ!C=Z!2UF!C%7!C=V!D`G!C=Y
M!C=T!2E&!C=\!C=^#R],#R]-#R].#R]/#R]0#R]1#R]2#R]5#R]6#R]7#R]:
M#R];#R]=#R]>#R]@#R]B!D`H#R]8!C=O#R]4!#%R!#%S!#=>!3)I!D`Q!2UN
M!D`W!3)C!#%T!#(B!#%V!3)B!#%]!3AA!3)D!D`T!3)G!D`U!D`L!D`I!#(D
M!DDO!DDJ!D`J!3)E!DDM!#==!D`O!DDL!DDK!3)H!D`M!DDN!D`S!D`P!#%U
M!D`N#S1X#S1Y#S1Z#S1[#S1\#S1^#S4B#S4C#S4D#S4E#S4F#S4G#S4H#S4I
M#S4J#S4K#S4L#S4N#S4M#S4O#S4P#SLQ#S1]!3)F!#(F#SM!!3AK!DDT!#=I
M!DD[!DDV!3AM!DE!!3AT!DDQ!#U1!#=G!3AB!3AJ!#=?!3AH!#=C!3AI!#=J
M!3AF!#=M!3AO!#=F!DE"!DE#!DDZ!3AQ!DDS!DE&!DDW!3AP!#=L!DE'!DDR
M!3AL!3AN!DE$!3AD!DD\!DE%!DE`!DE,!DD_!DE-!DE(!DDY!3AR!DD]!3AS
M!3AG!DDX!DE+!3AE!E)S#SLP#SLR#SLT#SLU#SLV#SLW#SLX#SLY#SLZ#SL[
M#SL\#SL]#SL_#SM`#SM"#SM##SM$#SM%#SM&#SM(#SM)#SM*!E)T!DD^!DE)
M!DDU!3AC#SM'!3]2!E)[!#U+!#U)!3]5!#U&!E)X!#U-!#U3!#U'!#U2!E)^
M!3]1!48A!3]+!ETL!E,E!E)U!E,C!E,B!3]-!3]3!3].!E)Y!E,A!3]0!E,D
M!E)\!3],!E)Z!3]/#T%6#T%7#T%8#T%9#T%:#T%;#T%<#T%=#T%>#T%@#T%A
M#T%C#T%D#T%E#T%F#T%G#T%I#T@P!E)W!E)]!E)V#T%H!3]4!ETV!4TY!48G
M!48J!$-B!$-?!ET\!ET]!ETN!$-7!ET_!48F!$-C!4TX!48I!ETU!$-9!R,O
M!$-;!$-:!R,N!R,Q!48D!$-E!ETY!ET^!ETZ!48H!ETW!48K!R,L!ET[!ETS
M!ETQ!48B!$-@!ETO!ETT#T@K#T@L#T@M#T@N#T@O#T@S#T@T#T@U#T@W#T@X
M#T@Z#T@[#T@Y#T@\#T@]#T@^#T@_#TA`#TA!#TA"#TA##TA$#TA%#TA'#TA(
M#TA)#TA&!ETP#T@V!R,S!R,X!4T\!$HE!R,]!R,W!R,Y!$E[!$EX!4T]!4T[
M!R-%!$E]!RXO!$HA!4U!!$HF!$E\!519!RX\!R,U!R,T!RXM!RXK!R-$!RXL
M!R,\!4U`!RXN!4T_!R,[!R-"!R-#!R,^!R-!!$EW#T@Q!R,R!R,_!R-`#TY\
M#TY]#TY^#T\A#T\B#T\C#T\F#T\G#T\H#T\I#T\J#T\K#T\M#T\N#T\O#T\P
M#U1?#T\D!%8X!%!!!RXU!RXP!51:!51;!RX^!RXZ!RXR!R,V!%`^!%!#!%!`
M!51=!%`_!RX]!%!&!RX[!%!(!%!"!%!'!RXY!RXQ!RY`!S@I!RXX!51?!51<
M!RXW!S@H!RXS!RX_#U15#U16#U17#U18#U19#U1:#U1;#U1<#U1=#U1>#U1@
M!RXT!RXV!%!$#U14!5M6!S@Q!5M7!S@V!%8[!S@O!S@U!%8Z!S@T!S@L!5M8
M!%8W!5M5!S@J!S@W!S@P!S@N!S@R!S@X!S@K!S@M#UHP#UHQ#UHR#UHS#UHT
M#UHU!S@S!%LS!%LX!6%N!6%K!6%L!6%M!S]H!S]G!%LU!%LW!6=Z!6PM!S]I
M!S]F!%LT!S]C!S]E!T<O!S]A!S]D#UYH#UYI#UYJ#UYM#UYN#UYO#UYQ#UYR
M#UYT#UYL#UYK!%]F!%]H!%]G!%]I!6PO!T<R!T<T!T<V!6=[!T<P!6PN!T<X
M!%]K!T<U!T<S!T<Q!%]J!6=Y#V(^#V(_#V)`#V)!#V)"#V)##V)$#V)%#V)&
M#V))#V4O!S]J!T<W#V)'!6PR!&8_!TUM!&-(!TUL!&-)!TUP!&-*!TUN!6PS
M!6PP!6PQ!TUO#V4M#V4N#V4P!U-$!U=W!&9!!U,_!U-#!U-"!&9"!7-%!U-!
M!U-`#V=6#V=7#V=8#V=9!U=X!U=Y!7-$!7-'!7`C!U=Z!7-"!7-&!U=\!UM7
M!U,^#VE##VE$!7-#!U=[!UM8#VI4#VI5#VI6!UYJ!7==!UYI!&MK!UYK!7=<
M!UYH#VM)#VM*#VM+#VM,!V(X#VPJ#VPK!&US!V-3#VQA!V8F!")W!"0]!"9:
M#R<Q#R<R#R<S!C%8!C@B!2]<!"T^!C@A!C9$!D`Y!D`X!DE/!DE.#SM,#SM-
M!3AU!E,F#T%J!E,G!48M!EU`!R-&!R-'!51@#U1A!S@[!S@Z!5M9!S@\!TUQ
M!20_!B=Y!21`!B=Z!21!!B=X!BMH!"9@!29"!29`!"9=!BML!BMF!BMJ!BMI
M!BMG!28_!29!!"9<!"E@!C%9!2E,!2E+!C%<!C%>!C%=!2E)!2E*!"E>!"E?
M!C%;!C@C!C@D!C@F!2UR!C%?!"U%!C@H!2UP!C@J!2UO!2UT!C@E!2US!2UQ
M!C@I!C@G!"U!!3)M!D!`!#(N!D`Z!D`[!D`]!3)O!3)P!#(P!D`^!D`\!3)K
M!D!!!#(Q!#(J!#(M!#(I!3)N#S4Q#S4R#S4S#S4T#S4U!3)J!D`_!DE8!3DB
M!DE5!#=Z!#=[!DE9!DE4!DE:!3AV!3A^!3DA!3A]!3AW!DE6!3A[!DE1!DE0
M!DE3!#=R!#=S!#=T!3AX!3AY!3)L!DE2!E,O!3AZ!3]7!3]:!3]<!#U7!#U?
M!E,K!E,N!E,I!3];!E,P!E,M!E,H!#U@!3]6!E,Q!3]9!#U>!#U5!#U6!#U8
M!3]8!E,J#T%K!E,L!3)Q!#U:!E5@!48T!EU)!48R!EU!!$-H!48Q!EU"!48O
M!EU&!48W!48U!EU'!EU%!EU$!EU(!EU#!EU*!48S!$-G!48V!EU+!4@E!4U"
M!4U'!$HL!R-.!R-)!R-(!4U&!R-2!R-/!R--!4U%!R-0!4U#!4U$#T\Q!R-+
M!R-,!R-*!%!+!RY"!RY&!RY(#U1B!51A!RY+!RY'!RY)!RY!!RY%!RY,!51C
M!RY*!%!*!51D!51E!51F#U1C!RY$!51B!R-1!51G!S@^!S@]!5M:!5M>!5M=
M!%8\!%8]!5M;#UHW#UHX!S@_!5M<!6%P!S]L!6%O!%L[!S]M!S]N!%LY!S]K
M!6@A!6=^!6=\!6=]#V)*!6PT!&--!6PU!TUR!&-+!TUU!TUT!6PV!TUV!TUW
M!&9$!7`E!7`F!7-(#VE%!UM9!75K!&I*!UM:!&QO#VQB#R)3#R1&!BMM#RLM
M#RLN#RLO!C@M!C@N#R]E!D!"!D!$#S4W#S4X!D!##SM.!3]=#T%L!E,R#S4V
M!4U(!R-4!R-3!4U)#T\S#T\T!4U*!RY-#UHY#UYU#V)+#V=:!UM;!B(B#R<T
M!C%@!"U(!2UV!2UU!C@O!3)R#S4Y!D!&!D!%!DE=#T`R!DE;!DE<!#UA!EU,
M!3]>#T%M!$-J!$HM!R-5!SA`!%]L!B(C#R1'!BMO!BMN!C%A#R]F!#(R!D!(
M!D!'!DE@!DED!DEC!3DC!DEF!DE?!DE>!DEB!#=\!DP^!DEE!#UB!E,V!E,T
M!E,W!3]?!EU/!EU.!EU0`T<Q!$HO!EU-!4U,!4U-!RY1!RY0!RY/!RY2!RY.
M!%!-!SA!!SA"!S]O!%L\!S]P!S]Q!T<Y#V),!TUX!U=]!"1"!B=[#R<U#R<V
M!2E-!C%D!C%C#RLP!C%B!"U*!2UW!C@Q!C@S!C@U#R]G#R]H#R]I#R]J!C@R
M!#(S!#(U!D!*#S4Z#S4[!D!)!DEI!3DE!3DD!DEH!DEJ!DEG#SM/#SM0!E,X
M!3]@!E,Y#T%N#T%O!48X!48Z!EU2!48Y!R-6#T\U!RY3!51H!SA#!5M?!S]S
M!6%Q!%L]!S]T!S]R!T<Z!U-%!&AM!U=^!UYL!V!P!21"!2E.!2UY!2UX!#=]
M!DEK!E,Z!E,[!#UF#T\V!B,L!B,K!B1[!2)S!B1Z!B1\#R)4#R1+!B=\!B=]
M!B@E!21#!B@B!B=^!B@D!B@C!B@A#R1(#R1*#R1,!"1$!29(!BMT!BMS!29)
M!BM]!29$!BMY!29'!BMZ!BMW!29&!29%!BMU!BMX#R<W#R<X#R<Y#R<Z#R<[
M#R<\#R<]!BMQ!BM[!BM\!BMR!BMV!2E1!C%E!C%F!2E0!"EF!C%H!C%I!"EH
M#RLQ#RLR!C%J#RLU#RLV!C%N!C%L!C%K!2U^!C@Z!2XA!2XB!2U[!2XC!2U\
M!2UZ!C@^!C@X!C@\!2U]!C@Y!C@]#R]K#R]M!C@[#R]L!CA!!C@_!3)S!#(X
M!#@A!D!3!#(]!D!.!D!+!D!,!D!0!D!-!D!5!3)U!CA`!D!4!D!6#S4\#S4]
M#S4^#S4_#S5`#S5!#S5"#S5##S5$#S5%#S5&#S5'!D!2!3)T!DEQ!DET!#(\
M!3]A!3DJ!DEO!3DG!DEP!3DI!3DF!DEL!DEM!#@C!DEV!3DK!#@G!DEN!DEU
M!DEW#SM1#SM3#SM4#SM6#SM7#SM9#SM:#SM<#SM=#SM2#SM8!#@F!#@H!DER
M!3DL!3DH!E-#!3]C!E-!!EU3!E-"!E,_!E-$#T8Y#SM;!E,^#T%P#T%Q#T%S
M#T%T#T%U#T%V#T%W#T%X#T%Y#T%Z#T%[#T%]!3U5!E-%!E-`!3]D!48[!48_
M!48]!48^!EU6!49`!49#!49$!$-L!49"!4U.#TA*#TA+#TA,#TA-#TA.#TA/
M!EU4!48\!EU7!EU9!EU:!EU5!EU8!R-A!R-<!R-;!R->!4U2!4U5!R-:!R-7
M!R-8!R-B#T\W#T\Y#T\Z!4U4!R-@#TXP!R-=!R-?!R-9!4U1!51I!51K!RY7
M!%!5!RY5!RY;!RY9!RY=!%!4!RY<!RY4#U1E#U1F#U1G#U1I#U1J!RY8!4U/
M!RUB#U1H!RY#!51J!RY6#T\X!SA'!5M@!5MA!SA(!5MB!SA%!SA&!SA)#UHZ
M#UH[#UH\!SA$#UH]!%L^!6%R!6%S!S]U#UYV#UYW#UYX#UYY#UY[!S]X!6@C
M!T<]!T<\!6@B!6@D!T<[!T<^#V)-!6PW#V4Q#V4R!6MN!TUY!U-&!U@A#VE&
M!7,Y!7-)!UM<!7=>!UYM#VM-!7DK!V1'#R1-!BM^#R<_#R=`!BPA!2E3!2E2
M!C%P#RLW#RLY!C%O!CA"#R]O#R]P#R]Q#R]R#R]S#S5)#S5*#SM?!DEZ!DEY
M!3]E!$-P!E-&!4U7!4U6!R-C#U1K!5MC!S]Z!6%T!S]Y!S]W!%]M!TUZ!TU[
M!7L_!V8^!B,M!B1]!21$!B@I!B@G!B@H!B@F!BPB!2E4!"EI!"EJ#RLZ!C%Q
M!CA##S5+!3)V!D!9!D!;!DE]!DE\!D!:!3DM#SE&#SMA#SMB!E-'!3]G#SM@
M#T%^#T(A!E-(!EU=!EU>!R-D!$HT!4U9!$HS#T\[#T\\!51N!51L!5MD!51M
M#U1M#U1N!SA+!SA*#UH^!6%U#UY\!S][!6PX!75O!7=?!2%(!"%.!"%]#R%E
M!2)U!B4B!2)T!B1^!B4A#R)6!")[!")Z!B@L!"1)!B@J!B@K#R1.#R1/#R14
M#R10#R12!21&!B@M!21%!"1%!"9K!29,!"9F!29+!BPK!290!292!BPH!BPG
M!BPF!29-!293!29/!29.#R=##R=%#R=&#R='#R=)#R=*#R=+#R=-#R=/#R=1
M#R=4#R=5!BPD!BPI!294!BPL#R=$!BPM!BPJ#R=(#R="!BPE!295!BU<!C%T
M!C%S!"EK!2E6!C%U!C%V!2E5!2E9!C%W!2XF!2E:!2E8#R=3#RL[#RL\#RL]
M#RL_#RM`#RM!#RM"#RM##RM$#RM%#RM&#RM'#RM)#RM*#RM+#RM,#RM-#RM.
M#RM/!2E;!D!<!CA/!CA3!CA+!CA-!CA&!2XG!CA(!CA%!CA1!"U0!D!=!2E7
M!2XI!2XJ!CA$#R]T#R]U#R]V#R]X#R]Y#R]Z#R][#R]\#R]]#R]^#S`A#S`B
M#S`C#S`E#S`F#S`G#S`I#S`J#S`K#S`L#S`N!CA,!CA'!CA)!"U3!CA.#S`P
M#S`H!"U:#S`M!2XL!2XH#R]W!CA2!D!H!D!I!D!?!3)W!3,A!3DV!#)%!#)`
M!3)]!D!G!DHN!D!C#S5,#S5-#S5/#S50#S51#S52#S53#S54#S55#S56#S58
M#S59#S5:#S5;#S5<#S5=#S5>#S5?#S5@#S5A#S5B#S5C#S5E#S5F!D!D!D!F
M!D!E!#)'!D!B!D!@!D!A!#)$!3,B!3)X!3)[!3)Z!3)\!D!J#S5.!D!>!#@V
M!DHT!3DU!E-)!#@N!3DX!DHB!3DR!#@K!3DP!3DT!#@Q!DHM!DHO!3DZ!DHD
M!DHA!3DW!DHS!3D\!3D[!DHF!#@P!DHG!DHJ!DHQ!3E`!E-*!3D]!DHX!DHC
M!DHE!DHU!#@S!#@X!DHV!DHW#SMD#SME#SMG#SMH#SMI#SMK#SML#SMM#SMO
M#SMQ#SMR#SMT#SMU#SMV#SMW#SMX#SMY#SMZ#SM[#SM\#SM]#SM^#SPB#SPC
M#SPD#SPE#SPF#SPG#SPH#SPJ#SPK#SPL#SPM#SPN#SPO!DHI!DHK!DHL!DHR
M!3E"!DHP!DHY!DHH!3D^!3E!!3DN!3DO!3DQ!E-.!E-8!#UW!E-6!#UT!E-7
M!3]O!3]J!3]N!3]K!#UJ!E-;!3]S!E-A!3]H!#UZ!3]T!3]I!E-5!3]P!3]M
M!E-@!#US!E-9!E-:!E-=!E-0!#UP!E-<!3]L!E-C!E-/!E-1!E-,#T(C#T(D
M#T(E#T(F#T(G#T(I#T(J#T(K#T(L#T(M#T(N#T(P#T(Q#T(R#T(S#T(T#T(U
M#T(V#T(X#T(Y#T(Z#T([#T(]#T(^#T(_#T)`#T)!#T)"#T)##T)$#T)%#T)&
M#T)(#T)*#T),!E--!E-2!E-4!#UY!E-B!E-+!E-?#T(B#T(O#T(W!3D_!3]R
M!E-3#T-T!49.#T)+!490!$-[!$-R!49-!49/!EUI!495!492!R-E!E-D!49'
M!EU?!494!49&!498!EUB!49*!493!EUC!$-V!49(!49)!EUE!49,!491#TA7
M#TA8#TA9#TA:#TA;#TA<#TA=#TA>#TA?#TA@#TAA#TAB#TAC#TAD#TAE#TAF
M#TAG#TAH#TAI#TAJ#TAK#TAL#TAM#TAN#TAO#TAQ#TAR#TAS#TAU`T=+!EUJ
M!EUG!EUK!EUL!496!497#TAT!EUD!EUF#TA0#TA1#TA3#TA4!EU@!EUM!EUA
M#TA6!R-H!4UG!4U>!$H[!$I'!4U;!$I`!R-Q!R-L!R-T!4UK!4UE!R-P!$I&
M!4U?!$H_!4UD!$I#!$H^!$HU!R-S!4U<!$I*!4UI!R-N!4UC!4UJ!R-I!$I!
M!4U=!R-U!$H\!$I%!$I)!R-F!R-J#T\]#T\^#T\_#T]##T]$#T]&#T]'#T](
M#T])#T]*#T]+#T],#T]-#T].#T]/#T]0#T]1#T]2#T]3#T]`!R-K!4UL!4UH
M!4UF!R-G!R-M!4U@!4U:!4UB!%!;!51]!RYI!%!E!%!8!5ME!SA,!RY@!RYC
M!51[!RYH!RYR!51Z!RYO!RYB!%!B!%9,!%!7!RY?!%!?!51Y!RYG!RYD!51Q
M!51W!%!<!RYN!RYT!51X!%!=!RYF!RYK!%!C!51P!RYA!6%[!51U!51V!51R
M!$I$!RYS!RYL!RYE!RY>!51\!51O!51S#U1O#U1P#U1Q#U1R#U1S#U1U#U1V
M#U1W#U1X#U1Y#U1Z#U1\#U1]#U1^#U4A#U4B#U4D#U4E#U4F#U4G#U4H#U4K
M#U4L#U4M#U4N#U4O#U4P#U4R#U4S#U4T#U4U#U4V#U4W#U4X!RYP!RYQ!%!A
M#U4C!51T#TAP#T]!!RYM!%9#!SA0!SA.!%9'!SA2!SA6!5MJ!5MK!%9*!%9&
M!5MN!SA3!5ML!SA1!SA7!6%\!5MG!%9-!%9$!SA9!%9"!5MI!SA;!5MF!SA4
M#UI`#UI!#UI##UI$#UI%#UI&#UI'#UI(#UI)#UI*#UI+#UI,#UI.#UI/#UI1
M#UI2#UI4!SA8!5MM!SA:!SA-!SA/!S<G#UI3#UI-!5MO!5MP#U4Q#UI0!%M'
M!6%X!T`G!T`C!%M"!T`K!6(D!6%]!6(F!T`I!%M%!6%Z!6(B!6(G!6%^!SA<
M!6(K!6%Y!%M#!%M,!%M&!T`M!T`H!6(C!T=&!6(I!T`F!%M+!6(H!6(E!6%V
M!S]\!S]]#UY^#U\B#U\C#U\D#U\E#U\F#U\G#U\H#U\J#U\K#U\L#U\N#U\O
M#U\P!T`A!T`E!T`L!T`J!6(A#U\A!6(J!6%W!T`B!T`D#U\M!6@E!T=#!6@H
M!6@K!6@I!T="!T=`!6@M!T=!!%]T!T=(!T=)!6@G!6@F!T=%!6@O!T='!S]^
M#V)2#V)6#V)8#V)9#V):#V);#V)<#V)=#V)?#V)@#V)A!6@N!T=$!T<_#V)4
M!6@L#V)7#V)/#V)>#UY]!&-3!TU\!6P_!TU^!6Q"!6@P!6PZ!6PY!6P]!TU]
M!6P\!6Q!!6P[!6@J!6Q`!6P^#V4S#V4T#V4U#V4V#V4W#V4Y#V4Z#V4[#V4\
M#V4]#V4_!TXA!&-2!U-)!U-(!7`K!7`M!&9&!7`I!U--!7`H!7`J!7`L!U-*
M!&9%!7`O!U-.!7`R#V=;#V=<#V==#V=>#V=?#V=@#V=A#V=B#V=C#V=D!U-,
M!7`Q!7`P!U-+!7`N!U@F!7-.!7-/!7-,!7-*!&AO!7-+!7--!U@E#VE'#VE(
M#VE)#VE+#VE.#VE/#VE0#VE1!U@D!U@B#V=E!75Q!75S!7=@!75T!UM@!75R
M!UMA!75U!UM?!7=A!UM=#VI7#VI9!UM>!75V!75P!&ML!UYN!7=B!V!Q#VM.
M#VM/#VM0#VM3#VM4!UYO!UYP#VI8!V!R!7DM#VPL!V!S!7DL!7DN#VM2!7HI
M!V-4!V!T!&U5#VPM#VQ,#VQC!V-,!V-5!7M`!V1(!V1)!V5;#VTO!V5T!B4D
M!"1+!B@O!BPN!B@R!21'!B@Q!"1*!29<!29;!298!BPO!"9O!BPP!29=!"9N
M!299!29:!297#R=6!2E?!C%Z!CA4!C%\!2EB!"EU!2EA!2E>!C%Y!2E<!2E@
M!C%[!2E=#RQW!CA7!CA8!CA5!2XS!2XM!CA6!D!K!2XR!"U?!2XO!2XT!2XQ
M!2XP#S`Q!3,E!D!L!D!M#S5G#S5H#S5I#S5J#S5K#S5L#S5M#S5N!#@]!3E'
M!3]W!#@Z!3E%!DH\!3,D!3E(!DH]!3E$!3E)!DH^!3E&!DH[#SPP#SPQ!DHZ
M!E-N!3]V!3]U!3]Z!E-K!3]Y!E-G!E-F!E-H!E-I!E-J!E-M!3]X#T).!EA:
M!E-L!E-E#T)-!49<!$0K!49>!EUO!EUN!$0L!49=!$0I!EUU!EUP!49:!EUV
M!EUT!49;!EUR!EUQ!EUS!E-O#TAV#TAX!499!4UN!R-]!4UP!4UQ!$I-!R-Y
M!R-W!R-^!R-V!R-Z!R-[!4UO#T]4!R-\!51^!RYV!%!H!RYU#U4Z#U4[!SA>
M!SA@!5MQ!SA?#UI5!SA=!6(L!6@R!6@Q#V)B!7`V!TXC!7`U!7`T!&AP!7`S
M!7-0!U@I!U@G!U@H!7=C!V!U!&QP!&U6!2$R!2%P!B,N!B4F!21*!B@T!BPQ
M!21)!21+!B@S!BP\!BPT!BP[!BPZ!BPV!BPS!BPX!BPR!BPW!29>!BPY!BPU
M!29?#R=7#R=8#R=9!"9R!"EV!2EC!2@U!CA9!CA<!2XU!CA:!CA>!CA=!CA;
M!C=(!3,F!D!P#S5O!D!O!#A`!#@^!3E*!3E+!DI#!#A!!DI"!DI$!DI`!DI%
M!DI&!DI!!3]\!E-P!3][#T)/!EIA!R0B!R0E!R0C!R0F!R0A!R0D#T]5!RYZ
M!RYY!RYW!RYX!SAA!%90#UI6#UI7!6(M!6(N!T`N!7-1!UMB!UMC!2%Q!2%)
M!2)V!B@U!")]!B4G!21,!"1-!B4H!B@V!B@[!B@W!"1,!B@\!21-!B@Y!B@X
M!B@Z!BP_!29@!29F!29A!29D!"9S!"9T!29C!"9W!BP]!BP^!BQ`!C%]!29E
M!2EH!"EX!"EY!C(F!"EW!C%^!2ED!2EE!2EK!2EF!2EG!C(E!"EZ!C(B!C(C
M!2EJ!C(D!CA?#RM0!C(A!2EL!2XV!"UC!CAB!2X[!CAE!2X\!2XX!2XY!CAC
M!CAF!2X]!2XW!2XZ!2X^!CA@!CAA!3,K!D!T!3,J!D!S!3,G!3,H!3,I!D!Q
M!#)+!3,L!DI)!D!U!D!R#S5Q!E-R!DI*!3E3!#A(!DI+!#A#!3E.!3E-!3E/
M!#A'!3E2!3E4!3E0!3E,!3E1!DI,!E-Q!DI(#SPR!E-T!E-Y!3]]!3]^!E-V
M!E-X!#XE!EUX!E-Z!E-U!E-S#T)0#S5P!$0T!$0N!EU[!EU\!$0O!EUY!EUZ
M!ETM!R0I!$I1!4UR!R0G!4UU!R0H!R0K!4UT!%!I!R0L!R0J#T]6!4US!RY[
M!RY\!54A!%!L!54C!54B!RY^#U4\#U4]!SAD!SAB!5MS!SAE!SAC!5MT!6(P
M!6(O!%M-!T`P!RY]!5MU!T`O!6@S!7`W!7`X!U-/!U@J!75Z!75Y!29H!29G
M!C(G!C(H!2X_!#),!#)-!D!X!D!Y!D!V!D!W#S5S#S5U#S5V#S5W!D![!D!Z
M!3,M!DI/!DI.#SPS#S5R!E0A!E0B!E-]!E-^!E0D#T)1#T)2!E0C!E-\!4`A
M!4![!49A!$0V!EXA!$0W!EU^!EU]#TAZ!4UV!EXB!R0M!$I2!R\E!R\C!R\F
M!R\A!R\D!54D!R\B#U4^#U4_#U5`!SAF!SAG!%M.!T`S!6(R!6(Q!T`Q!T`R
M!%]X!T=,!TXE!T=-!U-0!&I-!75[!UMD!7-2!UYS!7=E!7=D!V!V!V-6!2%R
M!B@]!BQ!!C(I!CAG#SPT!4`B!$I3#T]7#T]8#UI9#U5!#V)C#VI:!21/!B@^
M!BQ%!BQ$!29I!CAH!CAJ!CAI!D!\!D!]!4`C!#XF!49B!49C!EXC!R0N!R\G
M!R\H!54E!T=.!6Q#!7DP!2%*!")^#R):#R);!BA`!B@_!"1.#R15#R16#R17
M#R19#R1:!29M!29J!29L!29K!BQ'!BQ&#R=:#R=<#R==#R=>#R=?!29#!C(L
M!2EN!2EO!2EM!2EP!2EQ!C(M!2ES!C(O!CAM!C(N!2ET!C(K!2ER#RM1#RM2
M#RM3#RM4#RM5#RM6#RM7#RM8#RM9#RM:#RM;#RM<#RM>#RM=!CAO!2Y!!CAN
M!"UI!2Y#!"UH!CAL!2Y"#S`R#S`S#S`T#S`U#S`V#S`W#S`X#S`Y!CAK!2Y`
M!D$F!#)6!D$A!3,Q!D$B!D$C!3,N!D$E!3,R!3,P!3,O!D!^!D$D#S5X#S5Y
M#S5Z#S5[#S5\!3E5!#A-!3E6!#A0!DI1!DI3!3E9!3E8!3E:!DI6!DI0!DI5
M!3E7!DI2#SPZ#SPU#SPW#SPX#SPY#SP[#SP]#SP_#SQ`!DI4#SPV!3E<!E0N
M!E0L!#XK!E0G!E0K!#XJ!E0H!E0E!E0I!E0F!E0M!E0J!E0O!4`D#T)3#T)5
M#T)6#T)7!E0P!EXI!49F!49E!EXJ!EXK!EXM!$0]!EXD!$0^!49G!$0[!EXN
M!EXO!EXF!EXG#TA\#TA]#TA^#TDA!EXH!49I!EXP!EXE!EXL!$I6!R0S!R0W
M!R0U!$I5!$I4!4UY!R0T!4UW!4UX!R0Q!R0R!R0P!R0O!R0V!R0X!R\I!54G
M!R\J!%!P!54F!%!S!R\L#U5"#U5##U5$#U5%!R\K!R0Y!SAJ!%95!%94!SAI
M!5MV!SAH#UI:#UI;#UI<!SAL!SAK!6(U!6(T!6(V!T`W!T=/!T`U!6(W!T`T
M!T`V#U\Q!6(S#U\R!T=2!6@T!T=0!T=1#V5!!TXF!&9'!7`Y!U-1#V=G!U@K
M!7-3#VE2!75\!UME!V1*!BQ(!C(P!2EU!2EV!C-,!D$G#S5]!D$H!E0Q!$1`
M!R\M!SAM!%M1#UI=!B4J!B4I#R1<!BQ+!BQ*!BQ)!C(Q!C(R#RM?!2EW!2Y$
M#S5^!3E=#SQ!!E0R!R0[!R0Z!T`X!U-2#R%G!B(D!B4K!2%S!B4L#R)>#R1I
M!",C!B4M!210!B4O!B4Q`R0D#R)<#R1?#R1@!B4P!BQ-!212!BA"!211!213
M!"10!BA&!BA'!BQ,!BA#!BA!!BA%!BA(#R1A#R1>#R1B#R1C#R1D#R1E#R1F
M#R1G#R=C#R=D#R=E!"<C!29O!C(S!29R!29S!"<A!BQ7!"<E!BQ0!"<D!BQ.
M!29N!29P!BQ8!29Q!BQ:!C(T!BQ6!BQ<!"9\!BQ3#R=@#R=A#R=B#R=G#R=H
M#R=I#R=J#R=K#R=M#RMD#RMG#RML!BQ2!BQ4!BQ5!BQ9!BQ/!2EX!"E\!C(V
M!2HB!C([!C(^!2EY!"HB!"UQ!2HA!2E^!C(Z!C)`!2EZ!C)!!2E]!CAP!C(]
M!C(\!"HC!"E]!C(_#RM@#RMA#RMB#RMC#RME#RMF#RMH#RMI#RMJ#RMK#RMM
M#RMN#S`Z#S`]#S!$!C(X!"HD!C(U!C(W!2HC#S!7!"UN!2Y)!CDP!CDN!2Y(
M!2Y'!CA\!2Y*!CAQ!CA[!"UM!"UO!CDE!CAV!CDF!CDJ!CAW!CDI!CA^!CDH
M!D$J!D$I!#)F!CDD!CDL!2Y%!CDC!CAS!CDK!CAX!CDO!CDR!D%&#S`[#S`^
M#S`_#S!`#S!!#S!"#S!##S!%#S!&#S!'#S!(#S!*#S!+#S!,#S!-#S!.#S!/
M#S!0#S!1#S!2#S!3#S!4#S!5#S!6#S!8#S!9#S!:!CAY!CDB!CDQ!"UR!CDG
M!CA]!CAU!2Y&#S8M!#)=!3-`!#);!#)K!D$T!D$X!D$\!#)J!D%#!#)A!D$V
M!#)E!D$U!D%%!#)I!3,S!D$Q!#)@!#)G!DID!3,_!D%"!3,^!D$_!#)9!#)?
M!D$L!"4O!D$[!D$P!DIF!3,X!3-!!DI8!DI9!D$^!D%$!3,V!#)B!D%`!3,[
M!D$O!D$R!3,Z!3,U!#)L!#)N!3,W!D$]#S8A#S8B#S8C#S8E#S8F#S8G#S8H
M#S8J#S8L#S8N#S8O#S8P#S8Q#S8R#S8V#S8W#S8X#S8Y#S8Z#S8[#S8\#S8]
M#SQ"#SQ+#SQ-#SQ7#T)?!DI7!D$S!D$W!3,Y!D$Z!D$Y!D%'!D$M!D$N!3,T
M!3,\!CAZ!DIB!DIP!#A4!3EC!#A5!DI=!DI?!3EG!3EJ!3EB!E1(!3EL!DI:
M!#A3!3-"!#A8!DIL!DI<!3EH!DIQ!E0U!DIG!DIH!DIN!3E@!E0T!DIO!#XL
M!3E?!3EF!3EE!3ED!DIJ!3EA!E0S!DIR!3EM!DIA#SQ$#SQ%#SQ&#SQ(#SQ)
M#SQ*#SQ.#SQ/#SQ0#SQ1#SQ2#SQ3#SQ4#SQ5#SQ6#SQ8#SQ9#SQ;#SQ<!DII
M!3EI!DIK!#A=!DI;!DI@!DI>!3EK#T)S!E1!!4`E!#Y!!E0X!#XT!E0[!E1#
M!#X[!#Y#!#X^!#XN!E1*!4`I!4`F!#Y`!EXQ!E1"!#XZ!4`O!4`M!#XQ!EXR
M!#Y"!4`L!4`N!E0^!E1,!R0\!E1'!$1+!E0_!E1&!E0W!E0V!4`K!4`H!#X]
M!E0\!E0]!E1`!E1%#T)8#T)9#T):#T);#T)<#T)=#T)>#T)@#T)A#T)B#T)E
M#T)F#T)G#T)H#T)I#T)J#T)L#T)M#T)N#T)O#T)P#T)Q#T)R#T)U#TDB#TD^
M!4`J!E1$!#XU!E1-!E0Z!E1+#TDO#T)K#T]L!E0Y!R0]!$14!$1'!$1(!$1,
M!49K!$1.!49J!49T!49V!$1%!$13!EY$!49O!EY!!EXZ!$11!$10!49U!49R
M!49M!R1`!R0_!49W!EY%!$1/!EXY!EY"!49P!49Q!$1!!EX]!4UZ!R0^!EXT
M!49N!EX_!49S#TDC#TDD#TDE#TDF#TDG#TDH#TDI#TDK#TDL#TDM#TDN#TDP
M#TDQ#TDT#TDV#TDW#TDX#TDY#TDZ#TD\#TD]#TE!#TE"#TE##T]M!R)H!$1"
M!EX\!EY#!EXU!49L!EXS!EXW!EXX#TD[!EXV#TDJ!R1B!R12!R1-!$I@!R1:
M!R14!R1,!$IE!$IG!4XE!R1C!R1.!R10!R16!$I<!R17!R1)!4XA!R1E!R1'
M!R1$!$IF!4U[!4XD!R1D!$I;!R1;!$I:!R19!4U^!R1#!R1G!4XC!4U]!R13
M!R1"!SII!R1%!R1H!4XB!R1!!R1>!R1F!4XF!4XH!4U\!$I>!R1?!R1+!R11
M!4XG!R1<#T]9#T]:#T];#T]<#T]=#T]>#T]?#T]B#T]C#T]D#T]E#T]F#T]G
M#T]H#T]J#T]K#T]O#T]P#T]Q#T]R#T]S#T]T#T]U#T]V#T]W#T]X#T][#T]\
M#U51!R15!R1@!R\P!$IC!R1&!R1=!R1(!R1*#U5*#T]^#TE`!%!\!54U!54T
M!54H!54I!54K!R\S!54P!R]'!R]`!R\Z!%!Y!R\Y!%!^!54S!R\]!R\Q!R\W
M!R]&!R\[!R\X!R]#!R\V!R\R!54Q!54J!5MW!R\\!R])!54L!5MY!54R!R\O
M!R\T!R\^!R]!#U5&#U5(#U5)#U5+#U5,#U5/#U50#U52#U53#U54#U55#U57
M#UIM!54O!R\_!R]%!R](!R]*!R\N!R]$!%$A#T]A#UIF#UI?!50Z!5M\!%9:
M!%9?!5MZ!SAZ!SAN!%M2!5M[!5MX!SAP!SAV!SAO!SAY!SAT!SAS!6(X!SAU
M!SA[!5M]!SAW!54W`U4Z!SAX#UI@#UIA#UIB#UIC#UID#UIE#UIG#UII#UIK
M#UIP!SAR!5M^!SA\!SAQ#U5.#UIL#UIO#U5'#U5-#UI>!R\U!6(_!6)&!6)%
M!%M=!6(]!6(Y!6)"!T!`!T!&!%M9!6)+!6)$!T`\!6)!!6)*!%M8!6)#!T!'
M!6([!T!!!6)`!T!(!T`Z!%M?!%M5!T!%!T!$!T`^!6(Z!%M3!6(\!6(^!6))
M!6),!6)'!T`_!%M<!T!"!T=?!6)-#U\S#U\U#U\V#U\W#U\Y#U\Z#U\[#U\\
M#U\]#U\^#U\_#U]`#U]!#U]"#U]##V)D#V)E#V)L!T=>!T`]!T`Y!T!#!T`[
M#U\T#UIJ#UIN!6)(!T=E!T=<!T=B!%]\!%]Z!T=3!6@V!T=6!T=4!T=;!T=:
M!T=5!6@U!T=9!T==!6Q%!T=A#V)F#V)G#V)H#V)I#V)J#V)M#V)N#V)O#V)P
M#V)Q!T=7!T=@!T=F!T=D!T=C!T=8!6Q'!6Q*!6Q+!TXK!&-9!&-=!TXJ!TXI
M!6Q(!&-<!TXN!&-7!&-8!&-6!TXM!7`[!6Q)!6Q,!TXO#V5"#V5##V5$!TXL
M!&9(!7!`!U-6!7`_!7`]!&9+!U-4!7`\!U-9!U-3!&9-!U-?!7!!!U-5!U-:
M#V=H#V=I#V=J#V=K#V=M#V=N#V=O!U-;!U-<!U-=!U->!7`Z#V=P#VE5!U@N
M!U-7!U@O!7-4!7!"!U@M!7-5!U@Q!&AR!U@R#VE3#VE4!U@S!U@P!U@L!78A
M!78B!UMI!UMH!75^!UMG!75]#VI;#VI<#VI=!UMJ!UMF!UYV!7=G!UYW!&QQ
M!UYT!7=F!UYU!&QR!V!Y!V!X!V!W#VPO!V(Y!&U8!7HK!7HJ!&U9!&UT!7II
M!7IJ!V-7!V1+!7M!#VTF!V5<!7P\!B,O!B4S!",D!",E!B4R#R)?#R)@#R)A
M!B4T!"13!"14!214!BA,!215!217#R1K#R1L#R1M#R1P#R1R!BA+!29T!"<H
M!29U#R=O#R=P#R=Q#R=S#R=T#R=U#R=V#R=W!BQ?#R=R!BQ>!"<J!216!2HE
M!C),!2HF!C)$!2HG!C)+!C)&#RMO#RMP#RMQ#RMR#RMS#RMT#RMU#RMV#RMW
M#RMX#RMY#RM[#RM\#RM]#RM^#RPA#RPC!"HI!C)%!C)#!C)'!CDZ!2HH!C)*
M#RPB!C))!2Y/!2Y.!CDV!CDY#S!J!#)O!CDW!"UT!CDT!2Y+#S!=#S!>#S!?
M#S!@#S!A#S!B#S!C#S!D#S!E#S!F#S!H#S!I#S!K#S!L#S!N#S!O#S!P#S!Q
M#S!R!2Y,!CDU!CD[!CD\#S!G#S!M!CDX!2Y-!D%+!#)T!3-$!D%/!#)S!#)U
M!D%.!D%4!D%1!D%-!D%,!DIS!D%2!D%0!D%3#S8D#S8^#S8_#S9`#S9!#S9#
M#S9$#S9%#S9&#S9'#S9)#S9*#S9,#S9-#S9.#S90!D%)!D%(#S9+!3-#!3-%
M!D%5!#AI!DIX!D%*!3EQ!3EO!DI^!DLA!3EN!DIU!#AF!DIZ!DIT!DI]!#AC
M!3EP!DIW#SQ>#SQ?#SQ@#SQA#SQB#SQC#SQD#SQF#SQG#SQH#SQI#SQK#SQL
M#SQM#SQN#SQO#SQP#SQQ#SQR#SQU#SQW#SQX#SQY#SQZ#SQ[#SQ\#STA!DIY
M!DI\!#AG!DIV!DI[#SQJ!3ER!4`T!E1:!E18!4`P!E16!E1=!#Y'!E17!#Y$
M!E1;!E1>!#Y%!4`R!E13!E1C!E1?!E1D!4`U!E1<!E1B#T)V#T)Y#T)[#T)\
M#T)]#T,A#T,B#T,C#T,E#T,F#T,G#T,H#T,I#T,J#T,K#T,M#T,N#T,P#T,S
M#T,T#T,U#T,V#T,W#T,X#T,Y#T,Z#T,[#T,]#T,^!E11!E12!E15!E1F!#Y*
M!E1A!E1E!EI4#T,L!4`S!4`Q#TE4!EY1!EY0!49^!EY*!4<B!$15!49\!49[
M!49Z!R1P!R1J!EY&!4<A!EY'!EY(!49Y!EY+!EY/#TE$#TE%#TE&#TE'#TE)
M#TE*#TE,#TE-#TE.#TE/#TE0#TE1#TE2#TE3#TE5#TE6#TE7#TE:#TE;#TE=
M#TE>#TE@#TEB#TEC#TED!$1=!49]!EY,!EY2!EY)!EY-#TE<!E1@#T)^#T)Z
M!$IK!4XL!R1T!R1M!R1I!4XJ!R1L!R1Q!R1R!R1U!R1K!4XI#TXB!4XK!R1S
M#U`C#U`D#U`F#U`G#U`H#U`I#U`J#U`K#U`N#U`O#U`Q#U`R#U`S#U`T#U`U
M#U`W#U`X#U`Y#U`Z#U`[#U`\!R1N#U`L!RIQ#U`M#U`P#U`E#U`B!4XN!4XM
M!EY.!%$J!R]2!R]F!R]0!R]@!R]>!54[!%$G!R]A!R]C!R]5!R1O!%$H!R]6
M!R]D!R]E!%$F!R]8!R]4!%$I!R]G!54Z!54\!R]B!R]9!R]=!R]:!R]+!R]3
M!R]<#U59#U5:#U5;#U5<#U5=#U5>#U5?#U5@#U5A#U5B#U5C#U5F#U5G#U5H
M#U5J#U5K#U5M#U5N#U5P#U5Q#U5R#U5E!54X!R]-!R].!R];!R]?!S%Z!R]1
M!RQ[#U5O!54]!54Y!R],!R1V!R]7!SDC!%9A!SDE!54^!SDI!SDH!%9C!R]H
M!5PA!SA]!5PD!5PB#UIQ#UIR#UIV#UIW#UIX#UIY#UIZ#UI[#UI\#UI]#UI^
M#ULA#ULB#ULC!SA^!SDD!SDB!5PC!SDA#U5I!T!/!%MB!T!.!6).!T!+!T!3
M!T!1!T!,!%MC!6)/!6)0!%MA!T!4!T!*!T!2#U]$#U]&#U]%#U]'#U](#U])
M#U]*#U],#U]-!T!0!T(B!T!5!T!-!T!)!SDJ#V%V#UIT#UIU!T=L!6@W!&`A
M!T=M!&`B!T=J#V)T#V)U#V)V#V)W!T=I!T=G!T=K#U]+!T=H#V5%!6Q/!TXP
M!TXS!TX[!6Q.!6Q-!6Q1!&`C!TXR!TXX!&-B!&-@!TX\!TXQ!TXU!TXW#V5(
M!TXT#V5&#V5'#V5*#V5+#V5,#V5-#V5.!TXY!TXV!TXZ!6Q0!U-D!&-A!U-F
M!7!#!&9/!U-G!U-B!U-C!U-E#V=Q#V=R#V=S#V=T#V=U!U@V!7-6!&I/!U@W
M!U@X!U@T#VE6#VE7#VE8!U@U!ULD!UMN!UMP!UMM!UQ$!UMO!UML!UMK!78C
M#VI@!UYX#VI?!7=H!V$A!V!\!V!^!V$X!V![!V!]!V(Z!7IK#VQD#VQE!V1-
M!V1,!V1.!V4W!V8T!2%+!B,P!BA-!BA.!218!BQB!BQA!BQC#R=X#R=Y!C).
M!2HK!2HI!C)/!2HJ!C)1#RPD#RPE#RPF!C)-!C)0!2Y1!2Y0#S!S!D%7!D%6
M!D%8#S91!#AJ!DLB!D=#!DU=!E1H!E1I!EY3!4<C!EY6!EY5!EY4!R1Z!4XO
M!R1W!R1Y!R1X!R]I!R]J!54_!%9E#ULD#ULE#ULF#U5S!T!6!6@X#V5/#V50
M!TX]!U-H!UMQ!UYY!V$B#R1S#R1T!BQD!BQE!D%9!D%:#STB#STC!E1J#TEE
M!4<D!55`#R%H!BMK!2HL!"HK!"UW#S!T!3%L!DLC!E1L!E1K!55!!R1[!R1\
M!55"!B(E!B,Q!B4U!BA/!"<M!BQG!BQF!C)2!"HM!C)3!C)4!CD^!"UX#S!U
M!CD]!D%;!D%>!D%=!#)X!D%<#S92#S93!DLH!DLD!DLF!DLG!DLI!DLE!DU8
M!E1M!E1N#T,_!EY8!EY9#TEF!R1]#U`^!R1^!55#!6)1!%$L!R]K!R4A!55$
M!SDK!SDL!5PE!T=P!6Q2!U@Y!UMR!V-8!7M"!V1/#R%I!BA1!219!BA0!"<N
M!BQK!BQJ!BQI!BQH!C)6!C)5!2HM!C)7!2HN!2Y2!"UY!"U[!CE!!CD_!3-&
M!3-'!D%?!D%B!D%@!DLK!#AM!DLN!DLJ!DLL!DLM!3ES!3EV!3ET!3EU!#AN
M!4`X!E1O!#Y-!4`V!4`W!E1P#STD!4<E!EY;!EY<!EY:#TEG!4XR!R4E!4XQ
M!4XP!4XS!R4D!R4B!4XT!R4C!55&!55'!55(!R]M!55%!R]L!5PF!%9F#ULG
M#ULH!6)3!6)2!6Q3!U-I!2-H!CE#!CE"!#AO!DLO#STE#STF!E1Q!EY=!2%U
M#R)C!B4V#R)B!BA3#R1U!BA2!BA4!29Y!2<B!29X!29[!29V!29]!BQN!"<P
M!2<A!BQL!29^!2<C!29\!BQM#R=[#R=\#R=^#R@A!29Z!BQO!BQP!2HR!2HP
M!2HO!C)?!C)<!2HS!2HQ!"HP!C):!C)9#RPH#RPI!C);!C)>!C)8!C)=!2HT
M#R=]!2Y8!2Y4!2Y6!2Y7!2Y5!CE$!2Y9!#)[!D%G!D%H!3-)!3EW!#)]!#)\
M!3-+!3-,#S94#S95!D%E!D%I!D%D!3-(!#AQ!#AT!3E]!DLT!3EY!3E[!3EX
M!DLR!DLU#STG#STH!DLS!DLP!DLQ!3EZ!3E\!3-*#STI!DLV!4<K!4`^!4`\
M!#Y0!EYD!E1S!4<F!E1R!E1U!E1T#T-`#T-!!4`]!E1W!4`[!$1A!4<M!4<H
M!4<N!4<L!EY?!EYC!4<G!4<J!EYG!EYB!EYA!4`Z!EYF#TEH#TEI#TEJ#TEK
M!4<O!4<I!EY@!E1V!EYE#TEL!4<P!4XV!R4F!$IT!4XY!4XZ!4XX!$IP!4XU
M#U`_!R4H!R4G!R]P!55)!55.!R]Q!55+!55-!55*!55,!R]O!SDP!SDN!5PG
M!%9H!%9I!R]N!SDO!T!7!T!8!6@Z!U-J!T=R!T=S!T=Q!6@Y!TX_!6Q4!6Q5
M!7!%!U-L!7!$!7!&!U@Z!7-9!UMT!7-8!UMU!UMS!7=I!V$C#VPQ!V10#R$]
M!B,R!2%W!2%X!2)X!2)[!2)W!",H!2)Z!B4W!2)Y!21>!21?!"1;!"<W!BA8
M!"1:!21:!BA>!21;!BA;!2<O!BQR!"17!21=!21<!BA:!BA9!BQS#R1W!BA7
M!BA<!BA=!BA6!"18!BQZ!2<H!BQ[!2<L!BQY!BQ\!2<G!2<J!BQX!2<M!2<E
M!2<I!2<D!BQW!"<X!2HV!BA5!C)@!2<K!BQV#R@B!BQ]!BQT!"<U!2HU!2H^
M!C)H!2HY!CE+!2H]!C)A!CE,!D%L!2H\!"HQ!2H[!C)D!2HZ!C)F!"HS!2I`
M!C)C!2<F!2HW!2HX#RPJ#RPL#RPM!C)E#RPK!2H_!CE.!2Y>!#,A!CE)!CE-
M!"XE!2Y;!2Y@!2Y=!"XC!CE%!CE*#S!W#S!X!CE(!2Y:!"XD!CE'!CE/!2Y?
M!CE&!3-.#S!V!#,D!D%N!3-5!3E^!3-2!D%P!D%S!3-/!D%O!DL[!#,F!3-3
M!DLX!DLW!3-0!DLY!D%Q!D%R!D%T!DLZ!3HH!E1[!3HF!4`_!#AU!3HB!DM$
M!4!`!3HG!#AV!3HE!3HD!#AX!DL_!#Y1!3HA!DL\!DL^!#Y7#STJ#STK!E1Y
M!E)R!E1Z!DM`!DM!!DM%!DL]!3HC#T-#!#Y6!4!(!E4B!4!'!#Y5!E4G!4!+
M!E4D!E1^!E1]!E4F!4!&!4!$!4!#!E4A!4!"!E4H!4!*!4!!!#Y8!4!)!E4E
M#T-%#T-&#TEP#U!`!4!%!E4C!4!,!EYM!4<Z!EYI!R4I!4<W!$1K!4<U!4<S
M!EYL!4<[!4<V!4<T!EYP!$1L!4<Q#TEM!R4J#TEO!EYK!EYH!EYJ!EYO!$I]
M!4<]!4<\!4<Y!4<X!EYQ!4<R!R4Q!$IX!$IY!R4P!4X\!R4T!R]S!4Y!!R4O
M!R4K!4X^!4Y%!4X[!4Y$!4Y#!4X]!55/!R]R!4X_!4Y`!4Y&!R4L!R4M#U5U
M!550!R4N!R4S#TEN!%$S!4Y"!557!%$U!555!551!552!R]Y!%$Q!R]X!R]W
M!5PH!%$V!553!556!R]U!SDR!%9M!SDQ!R]V!R4R#U5W!R4U!554!5PJ!SDS
M!5PI!T=W!SDU!SDT#ULI#ULJ#ULK#ULL!T!=!6)5!6)4!T!:!T!9!T!<!%MH
M!T!;#U].#U]/!6)6!&-D!T=X!TY`!T=V!T=T!TY!!6Q6!TY"!7!(!U-M!7!'
M!&AT!7!)!U@[!UMV!UMX!UMW!7=J!UYZ#VM5!V$D!V-9#R@C!DM&!EYR!2%,
M!B4X!B,S!BA?!21A!"1=!"1<!BAA!BA@#R1Y!21@!2<P!BTE!"<\!2I!#R@E
M#R@F#R@G#R@H#R@I!BTC#RQ`#R@D!BTB#RP\!C)I!2I%!2I"!"HV!C)K!B]I
M#RPO#RPP#RPQ#RPS#RPT#RPU#RPV#RPW#RPX#RPZ#RP[#RP]!C)J!C)L#RP^
M#RP_#RPN!2I$!2I#!CE3!3-6!2YA!"XI!CE1!"XH!CE2!CE4#S!Y#S!Z#S![
M#S!\#S!]#S!^#S$A#S$C#S$D#S$E#S$F!CE0#S9C!#,Q!CE5!D%Z!3-7!D%[
M!#,R!D%W!D%X!D%Y#S$B#S96#S98#S9<#S9?#S9@#S9A#S9B#S9D#S9=!D%\
M#S9;#S9:#S9>!3-8!D%V#ST^#STT!DM+!3HK!3HJ!3HL!E4I!#Y:!4!-#STX
M!#A\!DM)!DM,#STL#STM#STN#STO#STP#STR#STU#STV#STW#STY#STZ#ST_
M#T-0!DM.!E4R!DM-#SU`!DM(!DM*!E4J#STS#ST]#STQ!3HI!E4K!E4P!#Y;
M!E4Q!E4O!E4N!4<^#T-'#T-*#T-,#T--#T-.#T-/#T-1#T-2#T-3#T-4#T-5
M#T-7#T-8#T-:#T-;#T-<#T-=#T->#T-?#T-@#T-A#T-B#T-C#T-E!E4L!4!/
M!3HN#T-+#T-(!4<_!E4M#T-9#TEZ#TE[#THF!R4X!EYT!4=!!R4V!$1M!4=`
M!EYU!EYW!EYV!EYS#TEQ#TER#TES#TET#TEU#TEW#TEX#TEY#TE\#TE]#TE^
M#THA#THB#THD#THE#THG#THH#THI!4="`T@F!R4Y#THC!R5`!$I^!4Y'!R][
M!R4Z!R]Z!R4\!R4_!R5!!R5"#U!!#U!"#U!##U!$#U!%#U!&#U!(#U!)#U!*
M#U!+#U!,!R4]!4Y(!R4[!4Y)#U5\#U8N#U!'!S`B!R4^!558!55;!559!%$[
M!S`D!R]]!R]^!R]\!%$\!S`A#U5X#U5Y#U5[#U5]#U8C#U8D#U8E#U8F#U8G
M#U8I#U8M#U8O!S`E!S`C!SDV#U8P#U8A#U8H!55<!55:#U8L!SD[!SD]!5PM
M!5PK!T!>!SDY!%MJ!%9N!%9P!SDX#ULN#ULO#ULP#ULQ#ULR#ULS#ULT#ULU
M!5PL!SDZ!SD\!SDW!T!?!6@\!%MK!6)7!&`F!T!@!&`H#U]1#U]3#U]4#U]5
M#U]7#U]9#U]:#U];#U]<#U]?!T!A!T!B#U]0#U]2#U]8#V,C!T=\!T=[!6@^
M!T=Z!TY#!6@]!T=Y#V)\#V)^#V,A#V,B!&`I#V)Y#V)Z#V)]!U-O!6Q7!&92
M#V52#V53#V54#V55!TY$!U-N#U]>!&91!U5\!&93!U@\#V=V!UMY!&I2#VE9
M#VE:!78D#VIA#VIC#VM6#VIB!7DQ!V$F!V$E#VPR!7HL!&XT!BTF!2I'!2I&
M!C)M#RQ!!C)N!CE6!2YC!2YD!CE7!CE8!#,V!3-9!3-:#S9E!3HO!3HP!DM/
M#SU!!DM0!#Y<!4!0!4!1#T-F!R5%!EYX!4=##THJ!4=$!R5$!S`F!%$]!4Y*
M#U!-!R5#!%$^!SD^!6)8#U]@!%MM!&94!U-P!7!*!78E!UMZ!UY[!V([!V(\
M!21B!2<Q!"<]!BTG!2I(!2I)!C)O!"H[!"H^!2YE!2YG!CE<!2YF#S$I!CE;
M!CE9!CE:!3-=!D(B!D%^!D(D!3->!D(C!3-<#S9F#S9H!#DB!3HQ!E4V!#DG
M!3HT!3HS!3-?!DM2!3HR!3-;!DM1!DM3!#YD!4!2!E4W!#Y>!4!3!E4S!E4U
M!#Y?!E4X#T-G!E4T!4='!EY\!4=%!EYZ!$1R!EYY!EY[!4=&!$LH!R5*!4Y,
M!4Y-!4Y.!R5&!R5'!R5)!S`G!%9T!S`H!55?!55A!%%`!55@!55>!%9V!5PN
M!%9W!SE`!SD_!4Y+!%MP!6);!6):!T!D!6)9!T!E!6@_!TY%!U-Q!U-R!&96
M!7!+!&95!U-S!&AV!U@]!7-:!78H!78G!UM[!78F!UQK!7IL!V4X!B,T!BTH
M!2<S!"<^#R@K!C)P#RQ#!4!4!EY]!S`K!S`I!S`J!%9Y!T!F!7!,!B,U!B4Y
M!BTI!2<T!BTJ#RQ$#RQ%!2I*!"H_!C)Q!C1Y!2YI!D(F!3-@!D(E!D(G#S9I
M!E4Y!DM4#SU##SU"!E4[#T-H!E4Z!EY^!R5+#THK!%9Z#ULV#V,F!T9N#V,E
M!U-T!B4Z#R1Z!2<U!BTN!CE=!3-A#THL#U]A!T=]#VPS!7-;!"1?#R1\#R1[
M!BAC!"="!"53!"<_!2<V!BTQ!BTP!BTS#R@L#R@M!BTO!"I"!2I-!C)T!2I,
M!C)S!2I+!C)V!C)Z!C)W!CEE!2I.!C)X!C)U!2YN#RQ&#RQ'#RQ(#RQ)#RQ+
M#RQ,#RQ-#RQ.#RQ/!2I/!2YJ!"XN!2YK!CEA!CE@!CEB!CE?!CEC#S$J#S$K
M#S$L#S$N!"XP#S$M!2YM!2YL!#,^!D(H!3-C!3-B!#,]!D(L!D(O!D(J!D(M
M!D(N#S9K#S9L!D(K!D(I!D%K!#DK!#DI!#DJ!DM7!DM9#S9J#SU&#SU'#SU(
M!DM8!#DM!DM5#SU$#SU%!E5`!#YJ!#YG!E4^!E4_!#YF!4!6!E4\!E5"!4!5
M!E5#!E5$!E5!#T-I#T-J!4!7!E4]!E\C!$1Z!4=*!E\B!E\E!E\H#THM!E\F
M!E\D!E\G!R50!$LL!R5,!R5.!R5-!R5/!4Y/!R51#U!/!$LK!%%%!%%#!%%&
M!S`L!55B#U8R!RP[!SE!!5PS!SE#!5PQ!%9[!SE"!5PT#ULW!SQV!5PP!5PR
M#U8Q!%MQ!T=^!6A!!T@C!TY&!T@A!T@D!&`M!T@B!TY(!TY'!U-W#V=W!U-U
M!U-V#V=2!U@^!&AW!U-X!UM]#VID!UM\!UY\!V(^!V(]!V-:!V-<!V-;!V8I
M!V8U!V9&!B,V!B4[#R@N!"XR!2I0!#DN!E5&!E5%!E\I!55C!S`N!R52!U@_
M!2)\!21D!21E!"1@!BAF!BAG!BAE!BAH!"=%!BTU!"=$#R@O!2<X!BTV!C)]
M!"I+!C)\!C)[!2I2!2I6!"I'!"I(!2I3!"I%!2I4!2I1!2I5!C,D#RQ0!C)^
M#RQ1!C,B!C,C!C,A!CEI!2YO!2YS!CEO!2YQ!CEP!CEJ!2YV!2YR!2YU!CEM
M!CEQ!CEF!"X]!2YT!CEH!"X^!2YP!CEN#S$O!CEG!CEL!D(Q!D(W!3-H!D(U
M!3-K!#-!!3-J!3-F!D(S!#-$!3-I#S9M#S9N#S9O!D(V!D(Y!D(T!D(X#S9P
M!D(P!3-G!3-L!3HV!3H_!DMA!3HU!DME!3HY!3HZ!3H\!3HW!DMC!DM?!3I`
M!DMB!DM;!DMF!3H^!DM>!#DY!DM=!DM@!DMD#SU)#SU*!#DW!DM<!#DQ!3HX
M!E5,!#YR!#YP!#Y[!4!9!#YQ!#YU!$1]!#YY!E5)!4!:!4!<!4!B!#Y\!E5'
M!4!A!E5-!4!E!4!C!4!;!3H]!4!?!4!>!E5+!E5*!#Y]#T-K#T-L!E5(!E5.
M!4!8!4!F!4!=!4=8!4=0!$4E!$4K!4=+!4=/!$4F!E\O!E\J!$4N!$4J!E\K
M!E\T!4=-!4=.!4=3!$4L!E\W!E\U!4=:!E\N!$4G!$4B!4=1!4=2!E\S!4=,
M!4=6!E\Q!E\P#THN!E\X!E\L!$4M!E\R!E\V!4=5!$LZ!$LV!$LM!$LY!4Y3
M!$LT!R5=!$LR!4Y5!4Y7!4Y4!$LQ!R55!$LP!4Y1!4Y2!R53!4=7!4Y8!R54
M!R5;!R59#U!0#U!1#U!2#U!3#U!4!R56!R5:!R5>!4Y6!4Y0!%%+!55E!S`O
M!S`P!55L!55M!%%,!%%'!55H!S`U!55F!55G!55K!S`Q!S`W!55N#U8T#U8U
M!S`T!S`S!55J!S`R!S`X!S`Y!55D!R57!%9\!5PY!55P!SE0!%%1!$4I!%9^
M!SE'!5PU!SE(!5P\!5PZ!5P]!SE/!T!J!55O!5PW!%9]!5PX!%<C!SE)!SE-
M!SE1!SE+!SE&!SE,#ULX!SE$!SE%!SE.!5P[!6)<!5P^!SE*!%MX!5Q`!6)@
M!T!H!6)E!T!I!6)A!6)D!%MV!5P_!6)=!6)B!6)>!6)?!%MZ!T!M!6)C!T@K
M!&`S!T@G!&`T!6A$!&`U!T@F!6A#!6A"!&`V#V,G!&`Q!T@H!T@I!T@E!T@J
M!T!L!&-J!&-K!TY)!TY-!TY,!6Q8!6Q9!TY.!TY+!TY*!7!1!7!0!7!.!&97
M!U-Z!7!/!U-Y#V=X!7-?!7->!7-=!UPB!UM^!&I6!UPA!78I!7=K!UY]!UY^
M!V%"!V$G!V(_!V)`!V)!!7IM!V11!V4Y!"1C!C,E#RQ2!CES!CER#S$P!D(Z
M#S9Q!DMI!DMG!3I!!DMH!R5?!%%3!%%2!S`Z!B4\!B4]!21F!2<Z!2<[!2<Y
M!2<\!"I-!2I9!2I8!2I7!C,G!C,H!C,F#RQ3#RQ4!C,I!2I:!CET!"Y"!CEU
M!D(\#S$Q#S$R#S$S#S$U#S$V#S9U!#-&!3-N!D([#S9R#S9S#S9V!DMK!DML
M!DMJ#S9T!4!H!4!G!E50!#Y^!E5/!4!I#T-M!$4O!E\Y!E\Z#THP#THQ#THS
M#THT#THR!$L\!R5@!R5A!55R!S`\!55Q!S`[!%<G!%<H!5Q"!5Q$!T!N!5Q!
M!SE2!6)F!T!O!T!P!6A%!6A&!6A'!6A(!T@L!TY0!TY/!6)G!UA`!UA!#V=Y
M!UPC!&MS!U\A!V4Z!21G!21H!BTY!BTW!BTX!2<]!C,K!2I;!"I/!C`V!C,J
M!2YW!2YX!CEV!CEZ!3-O!"Y$!CEW!CEX!CEY!#-)!3-P!D(^#S9Y!D(]!#D\
M!DMM!3I"!DMO!#D[#SU+!DMN#S9X!4!J!4!M!4!K!4!L!4!N!E53#T-N!E51
M!#\A!$4Q!$4S!E\^#THU!E\]!4=<!E\_!E\[!E\\!R5C!4Y:!4Y;!4Y<!R5B
M!55V!55X!55T!%%8!55W!55U#U8V!55S!S`]!S`^!SE3!S`_!%<I!6)H!T!R
M!T!S!T!T!T!Q!6A*!6A)!T@M!&-M!6Q;!6Q:!TY1!U-\!&9<!UA"!7=L!7=M
M!V-$!V58!BAI#R1]!"=)!2<^!"='!BT[!2<_!2I>!2I<!2I=!C,M!C,L#RQ5
M!2YY!CHA!CHC!"Y(!2YZ!CE^!CE[!"Y*!CHB#S$W#S$X!CHD!CE\!CE]!#-,
M!3-R!#-*!D(_#S9Z#S9[#S9\#S9]#S<A#S<B!D)`!D)!!CHE!DMT!DMP!3I#
M!#D]!DMR!DMS#SU,#SU-!DMQ!E54!E56!4!P!E58!E57!E55#T-O#T-P!E]!
M!E]`!E]+#THV!4Y=!R5D!R5E#U!5#U!6#U!7#U!8#U!9#U!:!%%9!S!$!%%;
M!S!`!S!%!55Z!55Y#U8W#U8X#U8Y#U8Z#U8[!S!#!S!!!%<K!%PC!%<J!SE4
M!5Q'!T!U!5Q&#UL[#UL\!SE5!SE6!S9Y!5Q%!S!"!SE7!%PB!%PA!T!V!T!X
M!T!W#U]B!T!Y!T@N!6A+!T@O#V,H#V,I!6Q=!TY3!6Q<!TY5#V56!TY2!TY4
M#V=[!UA$!7-@!UA#!UA%#V=Z!U\B!78J!U\C!V)"!2)]#R)G!BAJ!"1D!21J
M!"1F!21K!21I#R1^!"=0!BT\!2=!!"=+!BU`!BU"!BT^!2="!2=#!BU!!BT_
M!2=`!BU#!BU$!C,Y!C,U!C,N!C,R!"I>!C,V!"I<!C,\!2IE!C,S!2II!"I;
M!C,O!C,[!2I@!2IG!2IK!2IA!2IJ!2IH!2IC!2IL!C,P!2I?!2IF!2IB!2ID
M#RQ6#RQ8!C,W!C,Z!C,T!"Y0!2\D`RY:!"Y,!2Y[!CHF!"Y.!2\B!2Y\!CHH
M!"Y+!CHI!2\C!CHJ!"Y3!CHL!2Y^!2\E!CHK#S$Y#S$Z#S$[#S$\#S$]!CHG
M!2\A!2Y]!"Y4!#-5!D)3!D)&!D)-!3-T!3-S!3-]!#-4!D)'!D)$!D)"!3-Z
M!3-[!3-U!D)*!3-X!D)4!3-Y!D)#!D)/!D)+!D)0#S<E!D)2!D),!D))!D)1
M#S<F!3-^!D)%!D).!3-W!3-\!3I)!3I,!DMY!DPC!#-3!DMX!3I+!DM]!DPA
M!3I&!DPF!DMW!#E/!3I*!3I(!3I$!#E.!4!Q!DPE!4!^!#E`!DM^!3I-!DM[
M!3I.!DPH!3I%!3I'#SU/#SU0#SU1!DM\!DPG!DMV!DPD!DPB!#E$!#E0!3I/
M!#D^!E5;!E5>!E5:!#\J!4!X!E5<!4!W!E5?!4!U!E59!#\C!#\H!#\Q!#\N
M!4!Z!E5B!4!V!#\O!#\D!E5D!4!Y!4!R!4!\!E5F!E5=#T-Q#T-R#T-S!DMU
M!E5C!E,U!4!S!4!]!4!T!E5E!4=@!$5%!E]$!$4^!4=C!E](!4=E!4=F!E])
M!$M/!E].!E]&!E]/!R5L!E]'!4=G!4=D!E]#!E]*!E]%!4=B!E]"!4=?!4=>
M!4==!R5F#THW#THX#THY#THZ#TH[#TH\#TH]!$4Z!E]-!E],!4=I!$4[!$M0
M!$M,!$L^!4YB!4YG!$M.!R5K!4YL!4YE!$M!!R5P!$M`!%%E!S!-!4YD!58A
M!4YF!R5M!4YJ!R5R!$M)!$M+!$M&!4Y?!4YK!R5G!R5H!R5J!$M*!4YC!R5N
M!4Y>!4YA!55[!4YI!4YH!R5I#U!;#U!<#U!=!R5O!$M(!58J!58K!%%>!58E
M!58C!58G!55]!%%C!58I!55^!58F!58D!%%B!S!&!S!.!S!/!S!+!S!'!4YM
M!%%G!55\!S!)#U8]!S!1!S!,!58L!%%F!4=H!58H!%PK!5Q(!5Q+!%<U!%<V
M!S!2!SE>!SE9!5Q*!SE:!5Q,!SED!5Q)!T$B!SE?!SE@!SE=!%<W!SEC!5Q/
M!S!(!5Q.!SEA!SE<!SE;#UL^#UL_#UM`!SEB!SE8!%PH!T$C!T!^!6)N!%PL
M!6)K!T![!T!\!6)P!%PD!6)L!6)O!6)Q!6)J#U]C#U]D!T$D!T$E!T!]!6)M
M!T!Z!T$A!6A/!6A,!6A1!&`^!6A0!&`[!6A4!6A.!T@R!&`Z!T@T!&`\!&`]
M!T@P!6A-!T@Q!6A3!6A2#V,J!TM=!T@U!T@S!6Q@!6QB!6Q>!TY8!6QA!6QC
M!TY7#V57!&-R!6Q?!&-S!TY6!U0B!7!2!7!4!7!3!7!5!U-^!U0C!U-]!&AY
M!7-C!UA&!7-A!7-B!UA'!7-E!&I9!U0A!7-D!UDS!7-F!78K!UPF!&I8!UPE
M!U\D!&QT!V)#!V)%!V)$#VQF!7M#!2=$!"I@!"IA!"Y6!2\H!2\G!CHO!CHP
M!#-8!30B#S<G!3I2!#E1!3I3!3I1!3I5!3I0!DPI!3I4!4$C!4$B!4$A!E]1
M!E]2!$5'!$5(!4=L!4=J!4=K!$5)!E]0!$5+#TT_!4YN!$M2!R5U!4YO!$M1
M!R5T!$M3!%%I!%%H!%%J!58M!6)U!SEE!5IU!5Q0!6)T!6)S!6)R!6A7!6A6
M!6A5!6A8!T@V!T@W!&I:!V8_!V9)!B8_!BAK!BAL!C-!!C,_!C-`!2IN!2\J
M!2\K!CHS#S$_#S%`!CHQ!CHR!2\I!30C!30D!#-<!D)9!D)7!30E!D)5!D);
M!D)6!D):!D)8!#E2!DPL#SU2!DPJ#SU3!4$D!#\R!E5I!#\U!#\T!E5G!3I6
M!#\V#T-U!E5H!4=M!4=N!E]3!4=O!4=P#TH^!R5X!$M4!R5V!R5W#U!A!R5Y
M!S!4!%%K#U8_!S!3!5Q1!5Q2!SEF!SEG!7-G!78L!2)^!B4^!"1G!BAM!21M
M!21L#R4A#R4B!2=%!"=4#R@P#R@Q#R@R#R@S!BU'#R@U!"IE!"IC!C-%!2IP
M#RQ9#RQ:#RQ;#RQ=#RQ>#RQ?#RQA#RQC!C-#!C-$#RQD#RQ@!C-"!2IO!2IQ
M!"Y@!2\S!CHT!C-&!CHU!2\O!CHY!2\L!2\Q!2\P!"Y;!"Y=!2\V!2\R!2\U
M#S$^!"Y9!2\W!CHX#S%"#S%##S%%#S%&!"Y:!2\M!CHW#S%(#S%!!30F!2\N
M!CHV!30L!30H!D)A!D)?!30Q!30P!30J!D)@!30T!30R!2\X!30N!30G!30I
M!30M#S<H#S<I#S<J#S<K#S<N#S<O#S<Q#S<R#S<S!D)>!D)<!DPN#S<P!30K
M#S<L!D)B!30O!30S!D)=!3I8!3I>!3I7!3I;!#E6!DPU!#E7!#E5!3I<!3I=
M!DPQ!3I:!3I?#SU4#SU5#SU6#SU7!DPT!DPP!DPR!3IA!3I@!4$H!E5Q!#\W
M!4$I!E5J!E5L!4$E!E5N!#]!!#]#!E5O!E5R!4$F!4$G!E5M#T-W#T-X#T-Y
M#T-Z#T-[#T-\#T-]#T-^#T0A#T0B#T0C#T0D#T0F!E5P!E5S!E];!4=X!E]4
M!R5^!4=Z!E]6!$52!4=S!4=R!E]7!4=[!E]9!E]:!4=U!E]5!4=Q!4=]!E]8
M#TI!#TI##TI$#TI%#TI&#TI'#TI(#TI)#TI+#TI,#TI-#TI/#TI0#TI1#TI2
M!$54#TI`!4=W!4=\!4=Y!4=T#U!D!$M:!4YR!4YS!R8A!4YP!$50!R8E!4YU
M!R5]#U!B#U!C#U!E#U!F#U!H!R8B!R5Z!R8C!4YQ!4YT!R5\#TI*!S!8!58Q
M!58N!58R!S!5!%%Q!%%S!58T!%%R!S!6!S!:!%%O!S!7#U9!#U9"#U9#!58P
M#U9$!58O#U9%#U9&#U9'#U9)#U9+#U9,#U9-!5Q6!SEH!5Q4!SEO!SEJ!5Q3
M!%<Z!SEI!5Q5!%<]!SEL!%<\!58U!5Q8!5Q7!5Q9#UM!#UM"#UM##UM$#UM%
M#UM&#UM'#UM(#UM)!SEK!SEN#U9*!T$I!6)V!6)X!T$F!T$H!6)W!%PP!6)Z
M!T$G!6)Y!T$J#U]E#U]F#U]G#U]H#U]I!&!`!6A:!6A9#V,K#V,L#V,M#V,N
M!T@Z!T@X!T@Y#V,O!6QE!6QF!TY9!TY:!6QD!6QG!&!!!TY;#V5:#V5;#V5<
M#V5=!TY=!7!6!7!7#V=]!U0D!&9B#V=\!7-H!UA(!7-I#VE;#VE<!UA)!7-J
M!78N!&I;!78M!78O#VIE!UPH!UPG!U\F!U\E!U\G!V)&!7HM!7IN!&UU!V13
M!V4[!7Q#!B(G!B5`!BAN#R)H!BU(#R4D!C-'!C-)#R@V#R@X#R@Y#R@Z#R@[
M#R@]#R@W!C%:!2\Y!CHZ!"YC!2\Z!CH[!C-+#RQE#RQF#RQG#RQH#RQI#S%)
M#S%+#S%.!CH^!CH_!CH]!CI`!CH\#RQJ!"IH!30V!CI!#S%*#S%,#S%-#S%/
M#S%0#S%1#S%2#S%3#S%4#S<W!D)C!30U!DPX!3IB!DPY!DPZ!DP\!3IC!DP]
M!DP[!DPV!DPW#S<T#S<V#S<X#SU;#S<U!E5U!4$K!4$J!4$L!DP_!#](#SU8
M#SU9#SU:#SU<#SU=#SU>#SU?#SUB#SUC#SUD#T0H#T0J#SUA!E5T!4@C!E]?
M!E]@!$56!E]C!E]A#T0G#T0I#T0K#T0L#T0M#T0N#T0O#T0P#T0Q#T0R!E]=
M!E]B!4@A!E]>!$M?!R8F!E]<!E]D#TI3#TI5#TI6#TI7#TI8#TI:!R8H!58X
M!S!<!58V!S!=!%%W!58Y!58W!58Z!R8J!S!;#U!J#U!I#U91!%=#!5Q:!SES
M!%=$!SEV!SET!S!>#U!K#U9.#U9/#U90#U92!SEQ!SEU!SER!SEP#UM-#UM/
M!%PT!6)[!T$L#UM+#UM,#UM.#UM0#UM1#UM2!T$K!%PS!6A;!T@\!T@]#U]J
M#U]K!6QH!&-W#V5>!TY>!U0F!U0E#V5?!&A]!UA*!UA+!UPI#VE=!UPJ!UPK
M!7=N!UPL!7=O#VIG!7DR!V))!V)'!V-=#VQG#R)I!C--!D)D!#E;!DQ`!E5V
M!E]E!R8L!S!?!S!@!T$M!7-K!V$H!"%^!B5!#R)J!BAO#R4E!BAP!"=5!2=(
M!"=7!2='#R@^#R@_#RA`#RA!#RA"!BU*!C-1!C-4!2IT!2IR!"IP!2IU!C-6
M!C-0!C-2!"IM!C-/!2IS!C-7#RQK#RQL#RQN#RQO#RQP!C-5!C-3!C-.!2\\
M!2\[!CI%!2\]!CI&!2\^!2IV!30\!CI'#S%5#S%6!CI"!CI$!30Z!D)I!30_
M!#-H!30]!D)H!30W#S<Z#S<\#S<]#S<^!#-L!D)E!D)J!#E?!3ID!#E@!#E<
M!DQ!!DQ"!DQ%!DQ'!#E=!DQ$!#]1#SUE#SUG#SUI!30^#SUF!4$V!4$O!E5Y
M!E5W!E5Z!4$P!4$M!4$R!4$T!4$X!4$S!#].!E8A!4$N!E5[!E5^!E5\#T0S
M#T0T#T0U#T0V#T0W#T0X#T0Y#T0Z!E5X!E5]!4$W!4$U!4@H!E]I!44M!4@M
M!E]H!E]F!E]J!$5<!4@N!4@I!E]N!E]O!4@K!4@G!4@L!E]P!4@J!E]G#TI@
M#TI;#TI<#TI=#TI>#TI?#TIA#TIB#TIC#TIE!E]M!E]L!4Y[!4YX!4YZ!R8S
M!R8P!4YY!$MI!R8T!R8Q!R8X!4@O!R8O!59%!4Y\!4Y]!$MG!$MJ!R8U#U!L
M#U!N#U!O#U!P#U!Q#U!R!R8N!R8V!R8W!%%[!S!M!58]!59`!S!I!58\!58_
M!58^!%%^!58[!59#!S!C!S!D!59"!S!B!59&!5Q;!59'!S!K!S!J!S!L!S!A
M#U94#U95!S!E!S!G!S!H!59$!59!!5Q>!5QA!5QB!5Q?!5Q<!5Q=!%=*!SEW
M!5QD!%=&!5Q@!SEZ#UM4#UM5#UM6#UM7#UM8#UM:!SEX#UM3!59(!SEY!5QC
M#U93!6)]!6,F!6,D!6,A!6,B!6,E!T$P!6)^!T$O!6,C#U]L#U]M#U]N#U]O
M#U]P#U]Q#U]R!6)\!6A>!&!#!6A<!&!$!&!'!T@_!&!&!6A=!TYB!TA!!T@^
M#V,P!TA`!6QK!&-Z!&-X!6QJ!TY@!%PX!6QI!6QL!TY?!TYA#V5@#V5A#V5C
M!TYC!6QM!U0H!U0G!7!8!U0I!UA-!7-L!UA.!78P!78Q!UA/!7=P!UPM!UPN
M!U\H!UYQ#VM7#VM8!&QW!7DS#VPT!&QX!7HN!7MA!7MB!B,W!21O!21P!"=9
M!"=:!"=8!BU-!BU,!BU/`RI%!BU+#RA#!"IT!C-9!C-;!C-8!2IW!"IS!2IY
M!2IX!C-:!C-<!C-=!2IZ#RQQ#RQR#RQS!2\_!"YF!"YK!"YH!2]#!2]"!2]!
M!CI,!"YI!"YJ!"YG!CI*!CI(!2]`!2]$#S%8#S%9#S%:!CI+!CI)!31$!31#
M!D)L!D)K!D)M!31!!#-N!31"!31`!D)N#S=`#S=!#S="#S=##S=$!3IR!#EF
M!3IT!DQ.!DQ*!#EI!DQ2!3II!3IO!3IQ!DQ0!3IG!DQ1!3IH!DQ+!3IJ!#EH
M!3IS!DQ,!3IP!DQ)!3IF!3IM!DQ/!3IN!3IK!DQ-#SUK!4$Z!E8I!4$\!4$[
M!4$^!E8B!E8D!3IL!4$]!4$_!E8H!E8K!4%`!E8F!E8E#T0[#T0]#T0^#T0_
M#T1`!E8C!E8J!E<F!$5A!E]W!4@R!E]V!E]R!E]T!E]S!4@Q!E]Y#TIF!4@S
M!E]Q#T0\!R8[!4\A!4\G!4\J!4@P!R8Z!4\K!4\F!4\B!4\L!4\E!R8Y!4Y^
M!4\H!4\D!4\I!R<N!$MM!59/!591!%(C!590!%(F!59)!%(H!S!P!59*!59,
M!59+!593!59-!594!S!N!59.!5QE!595#U96#U97#U98#U99#U9:!S!Q!5QJ
M!5QG!SHA!%=.!5QI!SE\!SE]!SE[!5QF!SE^!S!R!5QH#UM;!6,H!6,G#U]T
M!&!*!TA$!TA#!6A?!TA"!TYD!TYF!6A@!&-[!6QN!U0M!TYG!TYE#V5D!7!;
M!U0K!&9G!&9F!7!9!U0L!7!:#V@A#V5E!78R!UPO!7=Q!V$J#VM9!U\I!7DT
M!V)*!7MC!BAR!BAQ!2=)!2=*!"IU#RQT#RQX!"YO!2]'!2](!"YL!2]&!2]%
M!"YN#S%<#S%=#S%>#S%?#S%A#S%B!CI-!CI.!D)R!#-S!D)Q!D)S!D)P!#-T
M#S=%#S='!31'#S=(!#EK!DQ5!3IU!3IW!3IV!3IX!DQ4#SUM#SUN#SUO#SUP
M!#]6!#]8!4%"!#]9!E8L!4%!!E8M!E8N#T1!#T1"#T1#!4%#!4@T!E]Z!4@U
M!$5B#TIG#TIH#TIJ#TII!R8_!$MN!4\M#U!S#U!T#U!U!R8]#U9<#U9;!%=1
M!S!T!596#UM<!5QL!5UC!SHB!5QK!6,J!SHC#U]U!T$Q!6,I!TYH!U0N#V5F
M!TA%!7!<#V@B!UA0#VE>#VIH!V$K#R4F!2=+!BU0!2=-!2=,!2I\!2I]!2I[
M!C-?!C->!2I^#RQY#RQZ#RQ[#RQ\#RQ]#RDD!2].!2])!"YT!2]*!2],!2]-
M!CI0!2]1!2]/!2]+!CI/!CI1!2]0!2]2#S%C#S%D#S%E#S%F#S%G#S%H#S%I
M#S%J!"YV!D)T!D)Z!31*!#-Y!31-!D)W!31,!D)\!#-U!31.!D)U!2]3!31)
M!D)Y!D)[!310!311!D)X#S=)#S=*#S=+#S=,#S=.#S=/!3I\!3LB!3I[!3I^
M!#EL!#EN!DQ:!31+!#ES!3LA!3IZ!#EY!#EW!#EP!DQ=!#EX!DQ7!3LE!DQ9
M!DQ<!31/!3I]#SUQ#SUR#SUS#SUT#SUU#SUV#SUX#SUY#SUZ#SUW!3LC!4%4
M!4%(!4%/!#]<!4%-!4%%!#]D!#]E!4%0!#]?!3IY!E8P!4%&!4%5!4%+!4%2
M!4%$!4%)!4%,!E8T!E8R!E8W!E8Z!E8S!E8V!E8X!E][!4%3!4%1!4%.!4%'
M!E8Q!DQ8!E8U!E8Y#T1$#T1&#T1'#T1(#T1)#T1*#T1+#T1,#T1-#T1.#T1/
M#T10!E8O#T$^!4A%!4%6!$5L!4A#!F`G!$5G!E]\!E]]!4@\!4@[!4A"!$5O
M!F`H!4A`!F`F!4@X!4@Y!F`E!F`A!4@Z!4A!!4@W!4@]!F`B!4%*!4A'!E]^
M!4@^!F`D!4@_!$5Q!4A$#TIK#TIL#TIM#TIN#TIO#TIP#TIS#TIT#TIU#TIV
M#TIW#TIX#TIY#TIZ#TIR#TIQ!4\Z!R9)!R9+!4]$!$PO!4\S!R91!R9*!4\^
M!$MQ!$MO!4]!!4\O!4\T!4]#!R9"!4]`!4\Q!%)`!4\Y!4]"!$MR!$PI!$PC
M!$M]!4\X!4\W!4\\!R9.!4A(!4\U!R90!R9'!R9$!4\_!R9`!R93!$PD!R9/
M!$M\!R9,!4\]!R9%!R9#!4\N!R9(!R9&!4]&#U!X!R92#U!W#U!Z#U![#U!\
M#U!]#U!^#U$B#U$D#U$I#U$E#U$F#U$G#U$J!59D!%)!!%(^!598!59>!59F
M!S$J!59<!%(N!59=!%(L!59H!R9!!S$E!%(R!59G!%(Q!S$I!%(\!S!^!S$F
M!%(P!59@!S![!%(_!59?!599!S!Z!S$H!%(J!597!S$D!%(U!59E!S!]!59B
M!%(S!S$K!S!U!S$G!4\P!59C!59:!S!X!S$C!S!V!59A#U9R!59;!S!\!S!W
M!S$B#U9=#U9>#U9@#U9A#U9B#U9C#U9D#U9E#U9F#U9G#U9H#U9I#U9J#U9K
M#U9L#U9M#U9N#U9O#U9P#U9Q#U9S!S!Y#U!Y!5TD!5TA!%==!5QU!5TM!5QY
M!%=<!%=C!%=G!SHL!5TK!%=@!5TB!5QP!5TC!5QR!5TQ!5Q[!5TJ!5QW!5TT
M!SHD!5QV!5Q\!5TF!%=D!5TG!SHI!6-"!5TL!5QZ!SHO!SHH!5QO!5TR!5TI
M!5QS!SHK!5TN!5QQ!5QN!5TH!%=F!%P\!5TS!5QX!5TO!5TE!S$A!5QT!SHG
M!SHF!SHE!SHM#UM=#UM>#UM@#UMA#UMB#UMC#UMD#UMF#UMG#UMH#UMI!SHJ
M!SHN!%=H#UME!%=A!6-+!6-'!5TU!%Q2!6-%!6,X!6,S!%Q'!6-*!6-``UA/
M!6,N!%Q.!%Q%!6-#!6,Y!6-,!%P]!T$[!6-&!6,P!6,W!%P^!%P_!6-(!T$Y
M!6,U!6,R!6,_!T$U!6,L!T$V!%Q!!T$S!%Q3!6,^!T$X!6,]!T$Z!T$^!T$T
M!6,Q!%Q-!6,V!6,Z!6-$!6-)!6,\!6,M!T%"!T%!!6,[!6,K!6,O!T$R!T$W
M#U]V#U]W#U]X#U]Y#U]Z#U][#U]\#U]]#U]^#V`A#V`C#V`D#V`E!T%`!T$]
M#UMJ#V,V#V,W#V`B!6AJ!6AO!TA.!&!9!TA,!6AC!&!4!&!5!&!1!6AI!&!/
M!&!0!TA(!&!2!6AB!&!8!&!-!TA'!6AM!6AH!6AP!6AL!6AK!6AE!6AD!6AG
M!TA&!TA*!6AA!6AQ!TA)#V,Q#V,S#V,T#V,U#V,X#V,Y#V,Z#V,[#V,\!TA+
M!TA-!6Q\!6Q[!6QV!&!7!6QT!TYL!6QZ!&-]!TYT!&0B!6QX!6QS!&9P!TYJ
M!6QO!6QU!6QQ!TYI!TYU!6QW!TYM!TYN!6QR!TYO!U0X!TYQ!TYP!TYR!TYS
M#V5H#V5I!TYK!7!D!7!H!7!I!&9Q!&9K!7!F!7!K!U0O!7!>!7!C!7!@!&0A
M!7!G!7!?!6QP!U0U!7!J!7!=!U0Q!7!E!&DG!7!L!U0V!U0P!U0T#V@C#V@D
M#V@E#V@F#V@G#V@H#V@I!U0S!U0Y!U0R!UA5!&DD!&DC!7-P!7-N!7!B!7-Q
M!UA2!7!M!UA1!7-T!&DE!7-M!UA4!U0W!7-V!7-S!7-O!7-U!7-R!UA6#VE?
M#VE@#VEA#VEB!UA3!UDT!&I>!78S!UPQ!78T!&I?!&I@!&IB!UPP!78V!UPR
M!78U!UPV!UPU#VII!UPS!UPW!UPT!7=R!U\K!U\N!7=T!7=U!U\M!78W!U\L
M!U\J!7=S!U\Q!&MW#VM:#VM;#VM<!U\O!7DU!V$L!V$N!V$Q!&QY!V$O!U\P
M!V$M!7HQ!7HO!7HP!V$P#VQ/#VQ-!V->!V-?#VQH!V-@!7M$!7MD#VTG!V14
M!&Y.!7M\!7PK!21Q#R4G!2=.!BU1#RA%!C-A!2LB!C-@!2LC#RQ^#RTB!CI2
M!2]4!CI6!2]5!CI4!2]6#S%K#S%L#S%M#S%N!CI3!CI5!#-^!315!#0D!314
M!#0A!318!313!316!317!#0C!31:!312!D)]!DQC!D,A#S=0#S=1!D)^#S=2
M!3LF!#EZ!DQA!DQ>!DQE!3LH!#HA!DQD!DQ?#SU\#SU^#SXB#SU[!DQB!4%7
M!#]H!E8]!4%9!4%:!3LG!4%8!E8_!E8^!#E^!4%;!4%=!4%<!E9!#T12#T13
M#T15#T16!E8[#T14!E9`#T11!F`M!4A*!F`K!F`N!4A,!$5S!E8\!F`S!F`R
M!4A+!F`P!4A)!4A-#TI\#TI]#TI^#TLA#TLB#TLC#TLE#TLF#TLH#TLI#TLJ
M#TLM!F`O#TLL!F`I!F`J#TLD!R98!R94!$PV!4]+!R95!R99!$PS!4]*!4],
M!4]0!4A.!4]/!4]-!R9;!R96!4])!$PT!4].!$PR!R9:!4](!4]'#U$K#U$L
M#U$M#U$O!59N!59L!5T\!%)#!59K!%)"!S$O!S$P!59O!S$L!59J!59M!59P
M#U9T#U9U!S$N!5TV!5TX!SHP!5TY!5TW!5TZ!5T[!SHR!SHT!SHU!SHQ#UMK
M#UML#UMM#UMO#UMP#UMQ#UMR!%=L!6-2!T%%!%Q7!6-3!6-/!TA6!6-1!5T]
M!T%&!6-0!TYX!6--!T%##V`G#V`H#V`I#UMN!6AT!TA/!TA0!&!>!&!<!6AS
M!7!N!TA2!TA3!T%(!&!?!%Q8!6AU!T%'!6AR#V,^!TA1!TA4!TA5#V,_!TYW
M!6Q^!TYV#V5J#V5K!&9S!&9R!7!O!U0]!U0\#V@J#V@K!U0[!7-W!UA7!7-X
M!&IC!&ID!UPX#VIJ!78X!UPY!U\R!7=W!7=V!7DX!V$S!7DW!7DV!V$R!V),
M!&U=!7HR!V)+!7HS!V-B!V-A!7M]!V8V!2=/!BU2!2=0#RA'#RA(!2=1!2LF
M!C-B!C-E!2LD!2LE!C-G!C-C!2LG#RTC!C-H!CI;!CI7!"YY!CIC!"Y[!CI=
M!CI<!CI?!2]:!"YZ!"\D!CID!CI9!"\C!CI>!"\B!CI@!CI8!2]9!CIA!2]8
M!2]7!CI:#S%Q#S%R#S%S#S%T#S%U#S%V#S%W!"\F!CIB!31?!31=!#0R!#0H
M!#0J!D,H!#0O!31>!#0Q!D,I!31;!#0L!D,K!D,J!D,E!D,C!D,D!31<#S=8
M#S=9#S=:#S=;!D,G!D,L#S=5!3LQ!3LP!3LN!3LR!DQM!#HC!DQF!DQL!#HB
M!#HD!DQN!D,F!DQG!DQP!DQH!3LM!DQJ!DQI!DQO!3LJ!3LI!3LK#SXE#SXF
M#SXG#SXH#SXI#SXJ#SXK#SXL#SXM#SXN!DQK!3LO!E9+!E9"!4%?!4%>!#]L
M!E9$!#]M!E9(!E9%!#]I!4%A!4%@!E9#!E9)!#HE!#]K!E9&!4%B!E9,!E9-
M!#]R!E9*#T17#T18#T19#T1:#T1;#T1<#T1=#T1>#T1?#T1@#T1A#T1B!E9'
M!#]P!$5X!4A0!$5V!4A2!F`_!F`^!4A6!$5Z!4A5!$5W!F`Y!F!#!F!"!F`V
M!$5]!4A/!4%C!F!!!4A1!F`\!F`T!4A3!4A7!F!`!F`[!$8B!F`X#TLN#TLO
M#TLP#TLQ#TLR#TLS#TLT#TLU#TLV#TLW!F`U!F`W!F`]!$PX!$Q#!R9@!$Q"
M!$P[!4];!4]9!%)(!4]8!4]=!4]5!$Q&!4]:!R9L!R9>!R9D!4]<!4]2!R9A
M!R9F!4]7!$Q!!$PY!R9=!R9E!R9<!R9G!F`Z!R9M!R9K!4]1!4]6!4]>#U$P
M#U$Q#U$R#U$S#U$T#U$U#U$X#U$Y#U$Z#U$]#U$^#U$_!R9B!R9H!R9?!R9C
M!S%&!%)&!S%#!S%$!%)*!S%`!S$]!59T!59V!S$Q!S%"!S$R!SHV!S$S!S$V
M!59U!59W!59S!5U%!%)%!59Q!59R!%)+!S$Z!S$W!S$X!S%!!%)-!S$U!59Y
M!S$T!S%%!S$[!59X!S$_!S$^!S$Y!S$\#U9V#U9W#U9X#U9Y#U9Z#U9[#U9\
M#U9]#U9^!SI$!SI#!5U#!5U`!%=Q!SHW!5U!!SI"!%=O!SHZ!5U$!5T^!SH^
M!SH[!SH\!SI`!5U"!SI!!SH]!5U'#UMS#UMT#UMU#UMW#UMX#UMY#UMZ#UM[
M#UM\#UM]#UM^#UPA#UPB!SH_!SHX!%QD!%Q<!T%.!%QC!%Q=!T%-!T%4!%QA
M!%=P!T%)!6-5!6-8!6-7!T%+!T%1!6-6!T%*!T%/!T%2!T%,!T%7!T%5!T%0
M!T%;!6-:!T%6#V`J#V`K#V`L#V`M#V`N#V`O#V`P#V`Q#V`R!6-9!T%<!T%:
M!T%8!T%3!&!D!&!E!TA?!&!I!TAG!6AV!TAD!&!G!TAF!&!K!6AY!&!@!6AZ
M!TAA!T=+!&!A!TA=!6AW!TAC!TA;!TAB!6AX!TA9!TA:!TA@!TA>#V-`#V-!
M#V-##V-$#V-%!TIS!TA<!TAE!&!J!TY]!TY\!6TC!6TA!&0E!TY^!T\C!TY[
M!U1"!TA8!6TD!T\D!T\F!TYZ!&9Y!T\B!TYY!T\E#V5L#V5M#V5N#V5P#V5Q
M!T\A!7!R!&9U!U1#!7!S!&9X!&9V!&9W!UA>!T\G!U0_!U0^!U1!#V@L#V@M
M#V@N#V@O!&9T!U1`!7!Q!U1$!7-[!UA9!7-\!7-Y!&DI!78Z!UA=!7-Z!UA;
M#VEC#VED#VEE#VEF!UA:!UA<!&E+!&IG!UA?!UPZ!UP[!&IH!&II!&MZ!7=X
M!U\W!U\U#VM=!U\V!U\X!7DZ!U\T!7DY!V$T!V)/!V).!V-C#VQI!V-E!V-D
M!V15!7ME#VTP!V5U!B5"!"IX!2LH!"\H!CIF!2];!31A!D,M!3LT!D,O!D,N
M!DQT!#HI!DQS!3LS#SXO!E90!E9/!#]T!$8D!F!%!4A8!F!$!R9N#TLY#TLZ
M#TL[!R9P!$Q'#U%`#U%!!R9O!59[!59Z#U<B#U<A!5U)!SI%!5U(#UI8#UPC
M#UPD!T%=!T%>#V`S!TAH!&!L#V-&!7!T!&0G!&9Z!U1%!&IJ!UP\#VIK!U\Z
M!U\Y!7HT!V8J!B(I!B(H!"1J!B5$!B5%!BAS#R%\!B5##R4H#R4J!BU3!C-J
M!"==!C-I!BU4!"=>!BAT!"1K!C-K!"IZ!"I\#R56!2LI#RA)!2=2!CIG!CIH
M!CII!2]?!CIL!CIJ!"\L!"\K!C-N!C-L!C-O!D,U#RDY!2]=!D,P!D,Q!D,R
M!D,T!D,V#S%Y!C-M!C9Z!2LJ!"I]!D,S!DQW!D,W!CIM!DQV!D,X!2]>!31B
M#S=<!DQU!3LV!3LU!#HL!DQX#SXP!E92!4%G!E94!DQZ!4%D!4%F!E93!E95
M!DQY!E96#SXQ!E91#T1C!F!&!F!(!F!)!F!*!F!+!F!,!F!-!F!0!4A;!R9U
M!F!.!4A:!E97!4A9!F!/!F!'#TL\!R9Q!R9R!R9S!R9T!4]B!4]?!F!2!R9V
M!4]@!4]A!F!1#U%"#U%#!R5S!S%'!S%(!S%,!S%)!59\!S%+!%)1!SI.!S%*
M!S%-!4]C!59]!%)0!R9W!R9X!SI'!SI(!SI+!5U*!S%.!%=T!6-;!SI,!SI-
M#UPE#U<C!T%?!T%@!T%B!T%D!%QG!%QF!6-<!T%C!TAI!SI*!6->!6A[!TAL
M!&!N!TAJ!TAK!T\H!T\I!T\J!T\K!6TE!6TG!T\L!6TF!6TH!U1&!T\M!7=Z
M!&M\!U\[!7=[!7=Y!V$U!V)0!V-F!V16!V4\!"1L!",L#R%@!BU6!2=3!BU5
M#RTD!C-Q!C-P!"I^#RA+!CIN!CIO!D,[!CIS!CIR!CIQ!CIP!D,Z#S%Z#S%[
M!D,]!31D!#HN!D,^!#0Y!31E#S==!31C!D,Y#S=>#S=?!D,_!3LY!3LW!DQ]
M!#HO!DTA!3LX!DQ^!DQ\!DTB!D<A!E9:!4%H!E9;!E98!4%I!E99!E9<!4%J
M#SXS#SXT!4A<!F!3!F!5!4A=!F!4!4]D!$Q*!R9[!R9\!$Q+!S%/!R9Z!$Q(
M!5<A!59^!%)2#U<E!S%0!%=X!%=V!5U+!SI0!SI/!SI2#UPF!%)4!SI1!6-=
M!%QI!6-?!T%I!T%J!%QM!T%G!T%H!T%F#U<D#V`T#V`U!%QL!6A\!TAP!78[
M!TAO!T\N!TAN!6TI!T\O!T\P!T\Q!T\R!T%E!7!U!U1'!U1(!7-]!UA@!UP^
M!UP]!V$V!V-G!V5>!BU7!C-U!C-R!C-V!2LK!"LB!"LA!"LD!C-T!"LC#RTE
M#RTF!C-S!"\S!CIV!2]A!2]C!2]@!"\Q!"\V!"\U!CIU!2]B!"\T!"\R!CIW
M#R]C#R]D!"\W#S%\!31F!D-!!D-`!D-"!D-#!D-$!D-&!D-'!#0_!D-%!3L[
M!#HR!DTF!DTG!DTM!3L]!#HV!DTN!DTH!DTE!DTO!DTP!3L\!DTJ!DTL!DTK
M#SXU#SXV!DTI!4%N!4%K!#]Y!E9=!E9>!E9?!4%M!4%L#T1D!DTD!4AE!4A>
M!F!7!4A?!4AC!4A@!4AD!4AA!4AB!F!6!4AF#TL]#TL^#TL_#TM`!4]J!4]K
M!R9^!4]H!$Q,!4]L!4]E!R9]!4]G#U%&!F!9!4]F!R<D!R<E!R<A!$Q.!R<B
M!$Q-!R<C#U%$#U%%!S%1!S%3!5<E!S%6!S%2!S%4!%)7!5<C!5<F!5<D!4]I
M!5<B!S%5!5<G#U<F!%=Y!SI4!5U,!SI5!TAQ!5U-!SI3#UPG#UPH!6-@!%QN
M!T%Q!5U.!%QO!T%M!T%O!T%L!T%P!T%N#V`V#V`W!T%K!&!P!6A^!6A]!TAR
M!T\U!T\V#V5R!T\S!&9\!U1)!U1+!T\T!U1*!UAB!UAC!UAA!B5&!BU8!BAU
M!"=?!"=@!CIX!#1`!2LL#S=@#S=A!D-(!DTQ!R<F!S%8!S%7#VM>!BU9!BU:
M!2%Y#RA,!"\Y!31G!3L^!4%O!F!:!R<G!R<I!4AG!S%:!S%9!SI6!2,A!BU;
M#RA-!C-W#RTG!C-X#S%^!31H#S=B!D-)!#HW!3M!!3M`!#][!E9@!F!<!4AL
M!4AH!4AM!4AJ!4AI!4AK!$8Q#T1E!F!;!4]O!4]P!4]Q!4]M!4]N!R<J!5<I
M!5<H!%)8!%)9!S%<!S%=!S%;#U%'!5U/!%=\!SI:!SI7!SI8#U<I!6-A!%=^
M!T%R!SI9!TAU!6-B!T%T!T%S#UPI#UPJ!TAT!6DA!TAS!&9^!U1,!&IL!7=\
M!7D[!2=5!2=4!BU>#RA.#RA/!BU=!2LO!2LM!2LN!"\\!CI^!"\[!CIZ!2]D
M!CLB#S(A#S(D#S(F#S(G!CI[#S(B!CI]!CI\!CLC!CIY#S(E!2]E!D-+!#1#
M!#1"!#1$!D--!31I!D-/!D-.!D-,!D-*#S=C#S=D#S=E#S=F!3M"!DTS!DTT
M!3M#!DTU#SXW#SXX#SXY#SXZ#SX\#SX]#SX^#SX_#SY`!DTR#SX[!E9B!E9F
M!4%Q!4%R!E9A!E9K!E9I!E9G!4%S!E9H!E9D!E9J!E9C#T1F#T1G!E9E!4AP
M!4AQ!4AN!$Q0!F!>!4AR!4AO!4AS#TM!#TM"#TM##TM$#TM%#TM&#TM'#TM(
M#TM*#TM+#TM,!F!?!4]R!R<L!4]U!R<O!4]T!4]S!$Q1!4]W!R<K!R<P!4]V
M#U%(#U%)#U%*#U%+#U%,#U%-#U%.#U%/!R<M!5<L!5<O!5<K!5<M!5<N!S%A
M!S%?!S%>#U<J#U<K#U<L#U<M#U<N#U<O!S%@!5<J!5U0!5U1!5U2!SI;!%@E
M!%@F!5U4!5U3#UPL!SI=!SI<`UAC!T%W!6-F!6-C!%QR!T%Y!5U5!T%X!6-D
M!6-E!T%U#V`X#V`Y#V`Z!T%V#UPK#V-'!TAV!6DB!6DC!TAX!TAW#V-(#V-)
M!T\Y#V5S#V5T#V5U!T\X!T\W!7!V#V@P#V@Q!U1-!U1.!7-^!UAD!&IM#VIL
M#VM?#VPV#VQ0!2%Z!BU?!2LP!D-0!DTV!DAJ!E9N!F!B!F!A!R<Q#U%0!S%B
M!T\Z!2,E!2,C!BU@!BUA!B5(#R)L#R)M!2,D!2,B!21S!21R!BAY!BAX!BAW
M!BAV!C-[!C-Z!C-Y!2=:!2=>!BUD!"]#!BUM!BUN!BUB!2==!BUF!2=9!2=7
M!BUK!2=;!"=K!BUH!BUO#RA0#RA1#RA3#RA4!BUL!"9D!BUE!BUG!2=<!BUJ
M!BUC!CLG!CLE!"\]!2=6!CLF!C0M!"LM!2LT!C0H!2LQ!2LX!C0I!"LN!D-4
M!C0G!"LK!C0K!"LP!C0E!2LV!C0F!2LW!2LR!"](!2LU!C-\!C0A!C0B!C0D
M#RTJ#RTO#S=G#S=H!C-^!C0O!C0L!C0J!C0P!C0N!D-3!D-2#RTK!D-5!D-6
M!CLP!D-1#RTM!2]G!"\^!#1%!"]%!CLR!2]L!"]$!CLN!2]N!CLJ!2]P!3M$
M!2]O!CLI!2]F!CLK!"]`!DT[!2]I#RTI#S(H#S(I#S(M#SY,!2]H!2XD!CLO
M!CLM!CLL!CLS!DTZ!DTX!DTY!DTW!C0C!2]K!2]Q!2]J!31T!D-;!D-9!31K
M!#1.!31L!"]"!31Q!#1&!#15!4%T!#14!D-7!31N!D-?!#1)!31U!31V!D-@
M!D->!#1/!31R!D-A!D-B#S=I#S=K!D-<!D-=!E9O!E9P!E9Q!31S!31O!31P
M!DU#!3M(!DT]!3M%!DU+!DU"!#H\!3M*!DU/!DT\!F!E!3M'!DU0!E9U!#I(
M!3M,!DU5!DU.!DU,!DU3!3M&!4AU!DT^!DU'!DU*#SY!#SY$#SY&#SY'#SY(
M#SY)#SY*#SY+!DU$!DU)#SMC!DU-!DU!!DU2!DT_!DU`!F!C!F!G!F!D#SY%
M!3M)!DU&!31M!3M+!3M.!3M/!DU1!3M1!DU%!F!H!F!F!4%]!$`A!4(F!4(A
M!4%U!4%Y!4(G!E9]!#]^!E9R!#I&!4(B!4%X!E9W!$`D!E9Y!$`B!E<A!E9S
M!4(I!E9T!E9X!4(C!E9\!4%[!4%Z!4(E!4(D!E9Z!4%V!E9^#T1I#T1J#T1K
M#T1L#T1M#T1O#T1Q!$`K!E<C!E<B#T1P!R<R!R<S!E9[!4%^!4%\!$9$!4A[
M!$9,!$9#!4DC!F!J!4AZ!$9*!4DD!4DA!$9)!4AW!4A]!$8Z!$9+!4AX!F!Q
M!F!L!4AV!F!N!4AY!F!M!4A\!S%C!4DB!$9(!F!K#TM-#TM.#TM/#TM1#TM2
M#TM5#TM3!F!P!EU<!4%W!4A^!$Q3!4][!R<T!$Q7!R<[!4]Z!$Q9!SI@!R<W
M!4]\!R<U!$Q:!SI>!4]X!R<X#U%1#U%2#U%3#U%4!R<V!R<Y!R<Z!SI?!F!I
M!4]Y#UPU!S%L!5<W!5<R!%)H!%)=!5<Q!%)?!S%G!S%N!5<U!5<V!%)E!4]]
M!5<T!S%E!S%M!5<Y!S%J!6DD!%)@!S%O#U<Q#U<S#U<R!R<\!S%H!S%I!S%D
M!S%F!S%K!T%Z!TAY!T%[!5<Z!5<P!5<[!5<X!5<S!T(A!5U:!5U9!SIB!%@N
M!%@J!%@I!5U8!5U6!&!Q!TA[!5U>!SIE#UPN#UPO#UPQ#UPR#UPS#UPT#UPV
M#UPP!S=^!SIC!TAZ!TA]!5U=!SIA!5U<!5U7!SID!TA^!%QU!6-J!6-G!6-I
M!6-L!T%\!6-N!T%^!6-K!T(C!6-H!6TJ!6-O#V`[#V`\#V`]#V!`#V!!!T%]
M!T)M!%QS!&!R!TDC!TDI!6DE!6DF!6-M!TDD#V-*!TDH!TDJ#V-,#V--!TDB
M!TDF!TDE!TDG!TDA#V-+!TDK!T\]!6TN!6TM!&0K!&0I!6TK#V5V!T\\!T\[
M!&<F!U1/!7!W!UQ`!U4Z!UP_!&DQ!&DO!UAE#V@S!UQ!!78]!UQ#!UQ%!UQ&
M!78\!UQ"!&IN!UQ'!UQ(!U\]!7=]!U\^!7D\!V17!7IO!7M%!BA\!"1Q#RI)
M!CLT#S(O!DU6!DU7#TM8#TM9#U%6!F!S#UPW!T(E#V!"!7!Y#V@T#VEG!V4]
M!7PL!B5*!BA^!"1R!BA]!BUP!2LZ!C0R#RTP!2]R!CLV!"])#S(P!CLW!CLU
M!D-F!D-E#S=M#S=N!DU9!DU:!E<D!4DE#TM:!$Q@!$QA!4]^#U%7!R<]!%)I
M!5<\!SIF!5U@!5U?#UPX#V!#!6DG!&!U!6TQ#V-.!TDL!6TO!6TP!V)1!BDA
M!BUQ!BUR!CLZ#RTQ!CLX!CLY!31W!#16!DU;!4(J!4DF#TM;!5`A!R<^#U%8
M!5`B!S%Q!%)J!5<]#U<T!%@O!6-P!6-Q!"1T!B5+!B-D!BUS!BUT#RTR!"]+
M!C0S!CL[!CM!!CL]!CL\!"],!CL_!CM`!D-I!31X!CL^!D-H!D-K!D-J!3M2
M!DU<!3M3!4DG!E<H!E<G!E<E!F!T!F!Z!F!U!F!V!5`C!R<_!F!W!F![!F!X
M!R=`!R=!!R="!F!Y!4DH!5`D!5`E!R=#!R=$!S%R!R=%!R=&#U<U!S%T!S%S
M!5UB!S%W!S%V!S%U!5UA!5UD!SIG!T(H!T(G!5UE!%QW!T(F#V!$#V!%!TDM
M!6-S!6-R!TDN!T\_!6DH!6TS!6TT!6TU!T\^!TDO#V-/!6DI!T]`!T]!!7!Z
M#V5X#V@U#V@W!UAF#V@V!UAG!UQ)!7=^!V$W!7D]!7D_!7D^#VQJ!V4^!V4_
M!V93!7Q0#R4K!C0T!"].!"]-!CM"!CM#!CM$!2]S!2]T!D-L!D-M!D%]!DU@
M!DU?!DUA#SY0!4DI!$9-!453!$9.!E<I#TM<!F!\!F!^!F!]!R='#U%9!R=)
M!R=(!S%X!5<^!S%Y!SIH#V!&!6-T!T(J!T(I!6TV!7![!UQ*!78^!5`F!5`G
M#V!'!T]"!UQ+!U\_!V$Y!7IP!21T!"=Q!"=P!BUW!BUV!BUU!2=?!"LQ!"LU
M!"LT!C0U!C0W!C0V!CM*!2]U!CM)!CM%!2]V!"]2!"]1!CM&!CM'!CM(!31Z
M!#19!#1;!D-R!31[!D-N!D-O#S=Q!31Y#S=P#S=R!3M4!DUE!DUD!#1:!#I2
M!#I0!#I1!#I3!DUF!4(K!E<L!4(L!E<J#T1R!E<K!E<M!E<N!4(N!F$G!4DM
M!4DK!$92!F$B!F$F#TM>#TM?#TM=!F$C!4DJ!5`O!$QG!$QF!5`N!5`K!5`L
M!5`P!5`H!R=/!R=-!5`Q!R=*!R=,!R=.!R=+!5`M!5`I!5`J!5="!5<_!5=#
M!S%\!5=`!S(A!S%]!S(C!5=!!S(B#U<V!S%^!S%[!SIJ!%@Q!5UL!5UF!5UI
M!5UH!5UJ!5UK!%QY!6-[!T(L!6-U!6-Z!6-]!6-Y!%QZ!%Q[!6-V!6-W!6-\
M!%QX!T(M!T(K!6-X!TDP!6DM!6DL!6DK!6DJ!TDQ#V-0!TDR!6TW!T]#!7!]
M!7!\!U12!70A!70B!&DR!UAH!U10!U11!&IO!UQ,!V$[!V$Z!V)2!7IQ!&Y/
M!C0X#S=S!3L_#SY1#U%:#UPY!T]$!31\!31]!D-S!31^#SY2!E<O!E<P!E<Q
M!F$I#TM@!F$J!F$H!R=1!R=0!R=2#U%;#U%<#U%=!5=$!5=%!S(E!S(D!6TY
M!6TX!T]%#VPW!2%[!B,X!",N!B50!B51!BUX!B5.!2,F!B5-#R)O#R)P#R)N
M!B5,!"1W!"1X!"1\!BDB!"1Z!BDE!BDC!BDD!BDF#R4L#R4M#R4N#R4O#R4P
M#R4Q!BU[!"=\!"=W!"=Y!2=B!"=]!"=X!"=U!2=@!BU\!2=A!"=T!CM+!B=,
M!BXA!2=D!"=V!BUZ!BU^!CM-!CM,#RA7#RA8#RA9#RA:#RA;#RA=#RA>#RA?
M#RA@#RAA#RAB#RAD!BUY!"L[!"LW!"LX!"LY!2L_!C1#!C0[!"L\!C1!!C0]
M!2L]!C0Y!C1`!C0^!C1"!C1%!C1&!2L[!2L^!2L\#RTS#RTU#RTW#RTX#RTY
M#RTZ#RT[#RT\#RTV!C,^!C0_#RTT!BU]!DUH#RI2!2]\!"]6!"]7!"]B!2]X
M!2]Z!2]^!"]4!2]W!3`C!"];!3`G!"]8!"]E!3`D!"]@!CM>!CM?!3`E!CMA
M!3`B!"]F!CM9!CM8!DUG!D0B!CM5!2]]!CM4!CM1!CM/!CM:!CM<!2][!CM7
M!3`F!2]Y!CM3!CM;!CM=!CMB#S(S#S(U#S(V#S(W#S(X#S(Y#S([#S(\#S(]
M#S(_#S)`#S)"#S)##S)$#S)%#S)'#S)(#S))#S)*#S)+!CM0#S)&#S),#S(^
M!34K!34N!34G!#1P!34L!#1A!#1N!#1H!D0R!#1R!#1U!D0F!D-[!D0C!34C
M!D-Y!D-U!#1@!34R!D-T!D0A!D0X!#1D!D0V!DXZ!D0T!CM@!DUX!#1?!34A
M!#1K!D-W!D0D!34P!D0O!D0U!D0N!D0I!34O!D0S!D-X!D0G!34Q!4(O!E<R
M!E<S!D0P!D0Q!D-^!34B!34S!D0J!34I!34M!34F!DXW!D0Y!D0Z!D-\!D-Z
M#S=T#S=U#S=V#S=W#S=Y#S=[#S=\#S=]#S=^#S@A#S@B#S@D#S@E#S@F#S@G
M#S@H#S@I#S@J#S@K#S@L#S@M#S@N#S@O#S@P#S@Q#S@R#S@S#S@T#S@U!3M=
M!D-]!34H!D0E#S=Z!D0M!D0W#S@C!34E!3M5!#I5!3MI!3MJ!3MB!3ML!3MM
M!3MC!#I=!DUZ!DUR!DXK!DUP!DUK!3M?!3MG!3MH!DU[!DUY!3M>!3MN!3MK
M!#1J!#I7!#I:!#I8!#IB!3M:!#I4!DUI!DXU!#IC!DUJ!3MD!DU\!DXV!DU]
M!DXO!DXP!#IK!DXF!#II!DXC!3M<!DXH!DUU!DXM!DUT!DXB!DXQ!DXI!3ME
M!F$R!F$M!F$N!3M7!DXD!DUO!DXN!4DN!DUS!DXL!DUW!DXE!DUM!DXJ!#IJ
M!3M@!3M;!DUV!DXX!F$K!3MF!F$O!3MA!DXT!F$Q!F$P!DUL!DU^!DQ[!3M8
M!DUN!DUQ!DXS!DXY#SY3#SY5#SY6#SY8#SY:#SY;#SY<#SY=#SY>#SY?#SY@
M#SYA#SYC#SYD#SYE#SYH#SYI#SYJ#SYM#SYO#SYP#SYQ#SYR#SYT#SYU#SYV
M#SYW#SYX#SYY#SYZ#SY[#SY\#SY]#SY^!F$L!3M9!DXA#SYB#SY4#SYN#SYS
M!$!#!E<T!E=&!4).!E<Z!E<[!4(T!$`]!E=)!E=:!$!`!$!"!4)%!E=>!4(Z
M!$`W!$`T!E=!!E=C!4(S!E=1!E=5!4)#!E=*!$`X!$`[!4(V!E=#!$`\!$!%
M!4)!!$!-!4)/!$`^!4)&!E==!4(_!$`S!$`Q!E=E!$`_!E="!4)(!4)"!4(X
M!4(^!E<X!E=3!E=/!E=`!E=G!4(]!E<Y!E=D!E<W!4)0!E=.!E=%!E<\!4))
M!4)-!4([!4)'!E=2!E=@!E=<!E=(!E=6!4(Y!$`Y!E=7!4(P!4)`!4(R!4)*
M!E<_!$`U!$!+!E=,!4(U!4(Q!E='!E=8!R=3!E=A!4(\!E=$!E=4!E<V!E=B
M!E=F!E=9!$!.!4)$!4)+!E<U!E<^!E=+!E=-!E=;!E=?#T1S#T1U#T1V#T1W
M#T1X#T1Y#T1Z#T1[#T1\#T1]#T1^#T4A#T4B#T4C#T4D#T4E#T4F#T4G#T4H
M#T4I#T4J#T4K#T4L#T4N#T4O#T4P#T4Q!4),!$!*!E<]!DXR#SY7!4(W!$9F
M!F%@!4E%!F$S!F%#!4E+!$9C!F%6!$96!F%%!$99!F$\!4E!!F%*!$95!F%2
M!4D]!F%`!F%9!4E)!4E&!F%,!4DZ!$9:!F$Y!F%5!F%-!F$_!4E$!4DY!4DP
M!$9B!F%!!$9>!F$V!$9=!$9K!$9;!4D_!R=8!F$W!4DR!4DW!4DQ!4E(!5`[
M!$9?!4E#!F$X!$9H!F%0!4DX!F%7!F%&!F$[!4E`!4DV!S(G!4DO!4DT!F%'
M!F%)!F%+!F%.!F%:!F%=!F%>#TMA#TMB#TMC#TMF#TMH#TMI#TMJ#TMK#TML
M#TMM#TMN#TMO#TMP#TMQ#TMR#TMS#TMT#TMU#TMV#TMX#TMY#TMZ#TM\#TM]
M#TM^#TPA#TPB#TPC#TPE#TPF#TPG#TPH#TPI#TPJ!F%(!4E"!F%3!F%1!E=H
M!4E*!F%<!F%?!F%;!F$Z!F$U!F%"!F$]!E=0#TMD#TMG!F%4!$9J!$94!4DU
M!4E-!S(F!4DS!F%A!4E'!4E,!5=&#TM[!4D^!R=L!$Q^!5`R!$QI!$Q\!R@A
M!5`U!R@D!R=W!R=<!5`Y!R=I!R=X!R=Y!R=J!R=S!5`Z!R=O!$QU!5`]!5!"
M!R=@!R@B!5!`!5`_!5='!5!!!5!+!R=K!R=V!R=9!R=R!R=E!5!(!5`W!$Q[
M!R=4!R=;!R=D!R=C!R=G!5`S!R=F!R=]!R=>!5`^!R=6!5`T!5!*!R=\!R=B
M!R==!R=N!$QV!5!)!5!%!R=T!5=8!$TB!5!#!R=5!R=:!R=?!R=P!R=Q!R@C
M#U%>#U%?#U%@#U%B#U%C#U%F#U%G#U%H#U%I#U%J#U%L#U%M#U%N#U%O#U%P
M#U%R#U%U#U%W!$TC!R=Z!5!$!R=^!R=U!R=H#U%Q#U%A#U%K!5`V!R=7!5!'
M!5`\!F$T!T(N#TPD!S)1!%,M!S(R!%,J!%,T!S)3!5=)!%,K!5==!S)#!5=4
M!%)Q!%,P!5=1!5=;!S(\!%)U!5=:!5=+!5=?!S(S!5=A!%,O!S(H!5=-!5=/
M!S),!5=5!5=B!S(]!S([!5!,!%)P!5=(!5=>!S)%!S)+!S)!!5=D!5=@!R@E
M!R=[!S)2!5UZ!%,F!S(N!%,I!S(V!5=3!%,H!%)T!5`X!S(O!5=2!S(X!5=6
M!5=,!S(M!S)7!S).!%,N!5=<!S(J!%)X!S(Y!T(O!S(K!S)5!%,R!S)"!S(U
M!S(_#U<^#U<_#U=`#U=!!5=*!5=0!5=7!S(L!S(T!S(W!S(^!S)`!S)'!S))
M!S)-!S)/!S)4!S)9!S):#U<W#U<X#U<Y#U<Z#U<[#U<\#U<]#U="#U=##U=$
M#U=)#U=,#U=-#U=.#U=/#U=0#U=1#U=2#U=3#U=4#U=6#U=7#U=8#U=9#U=:
M#U=;#U=<!S(Q#U=%!%)]!S(Z!S)8!S)0!5=E!5=.!S(P!S(I!S)(#U=*!S)6
M!5=C!5=9!S)&!SIV!%@Z!%@_!SIN!T([!SIX!%A(!%A)!5=F!5UU!5U]!5US
M!SLK!SLO!5UO!%A*!%@W!SI[!%A%!5XA!SI\!SLC!SLS!5U^!5XE!SLQ!5XB
M!5UN!5UX!SI^!5U\!SIS!SLD!SLJ!5U[!%A+!5UM!5XC!%A!!SLP!5UW!%A&
M!5UQ!5XD!SLE!5UV!SIP!SIU!T(Y!SIK!SIL!SLU!SI]!%A'!SLN!SIR!SIW
M!TDT!SIQ!SLB!SLI!S)*!SIY!SLA!SLW!5UT!5!-!%A#!TDU!5UP!5UR!SIM
M!SLG!SLH!SLL!SLT#UPZ#UP[#UP\#UP]#UP^#UQ`#UQ!#UQ"#UQ##UQ$#UQ%
M#UQ&#UQ'#UQ)#UQ*#UQ+#UQ,#UQ/#UQ0!%@Y!SIZ!SLM!SLV!SIT#UQ(#UP_
M#UQ.#U=5#V-;!60L!T)+!%TD!T),!60B!%TE!5XF!60O!T)(!60E!6-^!T(P
M!60A!60I!60V!60Y!T(V!60S!T)&!%TB!5XG!60X!60F!60P!T(]!60D!60N
M!T)-!%TP!60Q!%TN!%TF!%TJ!60T!60R!T(^!T]&!T(Z!T(W!%TO!TE$!60K
M!T(S!T)%!T))!%TM!SLF!T(R!T(T!T(U!T(_!T)"!T)$!T)*!T).!T)/#V!(
M#V!)#V!*#V!+#V!,#V!/#V!0#V!1#V!2#V!3#V!4#V!5#V!6#V!7#V!8#V!9
M#V!:#V!;#V!<#V!>#V!?!%TG!T)`!60G!T)!!TDS!60U!60J!%TI!T)'!60C
M!60H!60W!T)#!T(Q!6D^!6DO!T]=!6DP!6DZ!6DV!&!]!&!Y!6D_!6DW!TDX
M!TE%!6D[!6DU!&!\!6DN!6U"!TE#!6DX!TE&!6DY!TE!!TE4!TE1!TD\!6DS
M!6D]!TE+!TE.!TD^!TD]!TE"!TE'!T]4!TE-!TDY!TE,!TE*!T]'!6DT!6DR
M!&!V!6D\!TE)!TE`!TD_!TDV!TDW!TDZ!TE(!TE0!TE2#V-1#V-2#V-4#V-5
M#V-6#V-7#V-8#V-9#V-:#V-<#V-=#V->#V-?#V-@#V-A#V-B#V-C#V-D#V-E
M#V-F#V-G#V-H#V-I!TE/!T]>!T]5!T].!6U`!6U'!T]A!6U!!6U$!&0Y!T]8
M!6U&!&0U!6T_!7!^!T]?!6T[!T]1!T]0!T],!6T^!6U%!T]-!&0Q!T]G!6T\
M!T]+!T]3!T]B!T];!TD[!T]E!6U#!&0N!T]9!6T]!T]F!T]:!6DQ!U1G!UAI
M!T])!6TZ!6U(!T]2!T]6!T]7!T]<!T]C!T]D#V5Y#V5Z#V5[#V5\#V5]#V5^
M#V8A#V8B#V8C#V8D#V8E#V8F#V8G#V8H#V8I#V8J#V8K#V8L!T]*!T](!T]@
M!U1C!&DU!7$H!U1F!U1?!7$D!&<L!&<J!U19!&<N!7$B!U1D!7$E!U1E!&<I
M!6U)!7$G!U1;!U13!7$F!U1B!U17!U15!U1@!&<M!7$C!7$I!7$J!U14!U1<
M!T]/!U1:!UAV!7$A!U16!U1=!U1A#V@X#V@Z#V@[#V@\#V@]#V@^#V@_#VA!
M#VA"#VA##VA$#VA`!U18!70D!&DV!70E!70G!70H!UAP!70I!&D[!&DZ!UAW
M!UAU!UAM!UQ3!70C!70F!UAO!&DX!&DY!UAN!&DT!UAS!UAK!UAX!UAJ!UAL
M!UAQ!UAT#VEH#VEK#VEL!UQ/!UQ:!&IU!79`!&IT!78_!&IQ!&IS!&IR!&IP
M!79#!UQ1!UQ;!79"!7E`!UQ5!79$!UQ7!UQ8!UQ-!UQ0!79!!UQ6!UQ4!UQ2
M!UQ9#VIM#VIN#VIO!UQ.#VEJ!7@C!7@B!7@A!U]`!7@D!U]"!U]&!U]#!U]$
M!U])!U]!!U]'!7E"#VM@#VMA#VMC!U]%!U](!7E#!V)5!7E!!V)3!V$^!V$]
M!V$\#VPX#VPY!V$_!7HU!7HV!V)9!V)7!V)6!V)8!V)4#VQ1!V)(!&UZ!V-H
M!7IR!&U?!&U\#VQK#VQM!7M&!&XU!V18!V19!7Q)!V5`!7MF!V5@!V5V!7Q/
M!7P]!V5?#RAE!"L_!C1)!C1(#S).!34V!34T!#1W!#1V!D1!!#1X!D1"!D1`
M!D0_!CMC!DX\!3MQ!DX]#S\B#S\C#S\D!4)5!4)1!4)2!E=K!E=J!E=I!4E/
M!F%B!F%F!$9O!F%E!F%G!F%C!F%D!4E0#TPK#TPL!$9N!R@I!R@G!S)?!5!.
M!R@F!R@H#U%Y!R8I!5=J!5=K!5=H!5=I!%,U!5=G!S)@!S)<!S)=!%,X!%,W
M!5=M!S)>#U==#U=>#U=?!5=L!S);!%A,!SLY#UQ1#UQ2#UQ3!T)1!60]!%TS
M!T)0!%TQ!T)2!60\#V!@!TE6!TE5!&!^!TE7!T]I!6U*!T]J!TPF!7$L!T]H
M!7$K!7!-!U1J!U1I!70J!UPD!&XX!21U!BDI!"@B!BXE#RAF#RAG#RAI#RAJ
M!"M#!C1+!"M`!"M"!C1*!2M`!C1-!C1,!C1.#RT]#RT_#RU"#RU##RU$#RU!
M!"M!!3`P!CMH!3`L!3`S!CMG!3`M!3`R!CMF!"]L!"]J!"]N!3`N!CMP!3`I
M!CMK!3`Q!3`H!CMJ!3`O!3`T!CMN!CMD!3`K!CME#S)/!CML!CMM!3`J!CMO
M!34W!#1]!D1%!34X!34Y!34Z!35`!#4B#S@]!#4C!D1,!34\!#4A!34]!D1&
M!35!!D1)!#4D!#1^!D1'!D1*!D1$!D1+!D1-#S@V#S@W#S@X#S@Y#S@[#S@\
M#S@^#S@_#SA`!34^!D1.!#4E!D1#!34_!34[!3MS!DY`#S\H!#IS!DY(!3PH
M!3MX!3MU!3MW!3MZ!3PC!3M]!DY)!DX^!DY#!3MV!3PG!DY"!DY+!DY*!3M\
M!DX_!3MY!3PA!DY-!DY$!DY%!E=N!3PE!3M^!E=X!3PD!DY,!DY'!3PB!3MR
M!DY!#S\E#S\F#S\G#S\I!#IW!E=P!E=O!$!:!$!<!E=T!$!4!4)8!4);!4)6
M!$!1!$!3!4)<!4)>!4):!4)7!$!>!$!0!E=R!E=S!E=L!E=M!F%H!E=Q!E=U
M!4)9#T4R#T4S#T4T#T4U#T4V#T4W#T4X#T4Y!E=V!TEK!E=W!E=Y!4E1!4E6
M!4E;!4E7!4E<!$<A!4E5!$9]!F(C!4E?!$9W!4E9!$9T!F%V!F%J!F%U!$<B
M!4E>!F%K!F%Q!4E4!F%\!4E=!4E8!F%[!F(A!4E@!F%T!F%]!F%M!4EA!4EB
M!F%R!F(B!4E:!F%L!F%Y!F%Z!F%P!4E2!F%N!4E3!F%S#TPM#TPN#TPP#TPQ
M#TPR!F%X!$!8!F%^!F%O!$TM!RA#!5!3!$TN!$TK!R@X!$TT!5!?!R@W!R@L
M!5!1!R@K!R@U!R@_!5!7!$TR!$TJ!RA`!R@T!5!6!R@[!R@Q!R@^!5=N!$TL
M!$TI!5!<!5!:!5!0!5!9!5!8!R@J!5!;!$9Z!5!2!5!>!5!=!$TU!RA&!R@P
M!R@M!RA$!R@Y!RA%!R@\!R@O!F%W!R@V!R@]!5!4!$TG!5!/#U%Z#U%[#U%^
M#U(A#U(B#U(C#U(E#U(H#U(I#U(J#U(K!R@S!RA!!R@Z#U(G!R@R#TPO!5=P
M!%-%!5=V!5=U!%,Z!5=T!5=Q!S)N!S)]!5=W!%-(!5=[!%-)!%-`!%-"!5=\
M!S)M!%,[!S)G!%,_!S)\!5=Y!5=O!5@A!5=R!SLZ!5=X!S)I!%-&!5=Z!S)P
M!S,B!5=S!S)D!5=^!S)T!%-'!5!@!S)K!S)E!5=]!S)V!%-#!S)[!S,D!S)B
M!S)W!S)C!S)X!S)O!S)^!S)R!S)H!S,C#U=@#U=A#U=C#U=D#U=E#U=F!S)Y
M!S)J!S)Z!S)Q!S)F!S)L!%A9!5XI!5XL!%A5!SM2!SM$!%A@!%A<!SM(!SM"
M!SM5!%A>!SM&!RA'!%A0!5XQ!SM0!SL_!%A=!SM/!5XK!5XO!SM3!%A:!SM'
M!SM!!5XS!%A3!SM`!%A1!SL^!SM4!5XJ!SL\!SL[!SM)!%A;!5XM!5XN!SM%
M#UQ4#UQ5#UQ6#UQ7#UQ8#UQ9#UQ:#UQ<!SM#!SM+!SM.!SM1!SL]!5XH!SM*
M!SM,!5XP!%T]!%TW!T)5!T)A!T)8!T)H!61#!61$!5XT!%TX!610!T)9!%TV
M!61%!%TU!%TZ!60_!61"!61-!%TT!61*!T)6!60^!61!!61+!T)7!T)<!T);
M!61`!T)O!T)K!61/!T)N!61)!61,!T)I!61&!T)L!61'!T)E!T)B!T)=!T)C
M!T)4!T):!T)3!T)>!T)J!T)F#V!B#V!D#V!E#V!F#V!H#V!I#V!J!T)D!%T\
M!T)G#V!G#V!A!61.!&$H!TEJ!TE9!TE@!TEL!TE:!TEI!TEM!&$C!6E"!6E`
M!TEB!TEG!TEE!6E$!TE=!TEH!TED!TEF!T]K!TEA!TEN!TEO!TEC!6E%!TE<
M!TE?!TE8#V-K#V-L#V-M#V-O#V-P#V-Q#V-R#V-S#V-T#V-U!TE;!&$B!&$G
M!TE>!T)P!T]U!T]Z!6U-!T]L!&1"!6U,!6U1!T]X!T]P!6U0!T]T!6U2!6U3
M!T]S!6U.!T]R!T]W!T]Q!T]M!6U/!T]O!U1W!T]N!T][#V8M#V8N#V8O#V8P
M#V8Q!T]V!&<O!&<T!U1K!U1P!7$O!U1U!U1N!U1Q!7$N!U1S!7$M!7$P!U1L
M!&<S!U1O!&<U!&<Q!U1R!7$R!U1X!T]Y!U1T!&<R!U1Y!7$Q!7$S!U1V#VA%
M#VA&#VA'#VA(#VA)!U1M!70N!&D\!70L!70K!UDC!UA\!70M!70Q!70P!UAZ
M!70S!70U!70R!UAY!&D]!UDF!UDH!UDG!UA^!UDA!70T!70V!UDD!UDI!70O
M!UA]!UA[#VEM#VEN!79&!&IV!&IW!UQ=!79'!&IY!UQ?!UQ<!79(!UQB!79%
M!U]*!UQ@!&IZ!UQA!79*!UDB!79)#VIP#VIQ#VIR!7@L!U]+!&M^!7@K!7@I
M!U],!7@F!&PB!U]-!7@J!7@H!&PD!7@M!7@G!7E$!&Q^!7E(!7E*!&PA!V%`
M!7E&!V%$!V%#!V%%!7E'!7E)!V%!!7E%!V)=!V);!V)>!V)<!V)?!V-N!V-L
M!7IS!V-K!V-O!V):!V-I!V-Q!V-J!V-P!V-M!V1<!&XZ!V1=!7M'!7M(!V1:
M!V1;!7MG!V5!!V5"!7MH!&Y0!V5B!V5A#VTQ!V8K!2=E!BXG!BXF!"M$!CMR
M!3`U!CMU!CMT#SA!!DY.!DY0!4)?!E=\!E=Z!E=]!E=[!4EE!4EC!4ED!F(F
M!F(D!RA(!5!A!RA)!RA*!F(E!5@C!5@D!5@B!S,E!S,F!5XW!5XV#UQ=!%T^
M!%T_!T)Q!T)S!%U`!T)R!6E&!6U4!T]\!U1Z!UDK!UDJ!U].!V5C!"@C!BXH
M!"@D!C1/!C10!2M!#RU%!3`V!CMW!CMV!3`W!D1/!3PI!DY3!DY2#S\J#S\K
M!DY1!E@C!E@A!$!?!E@B!E=^#T4Z!$<D!5!B!F(G!F(H!%AA!SM6#UQ>!%U!
M!T)T!TEP!U1[!UQD!2=F!BXI!BXJ!BXK!2M#!C11!"M%!"M'!2M%!C13!2M$
M#RAK!C12!2M"!2M&!CM]!3`\!"]Q!CPA!CPE!3`_!CPF!CPG!"]P!CMY!3!`
M!CM[!3`X!CPB!CM\!CPC!CM^!3`[!CMZ!CMX!3`Z#S)0!CPD!CPH!CPI#RU(
M#RU)#S)2!#4H!3PR!#4K!#I\!35&!#4I!D18!35'!35*!35$!35%!35#!D19
M!D1:!35"!D13!D15!D14!D11!D10!D17!D12#RU&#SA%!35(!D16!35)!3PQ
M!DY;!DY9!3PN!DY7!3PO!3PS!#I^!DY8!DY4!#I]!DY6!3PP!3PM!3PK!4)D
M!3PJ#SA$#S\N!DY5!DY:!DY<!3PL#SA#!4)J!4)B!4)F!$!E!4)K!4)C!4)G
M!$!C!4)E!4)I!E@O!$!D!E@J!E@H!E@P!4)H!4)@!E@D!E@G!E@M#S\L#S\M
M#S\O#S\P#T4[!E@F!E@Q!E@E!E@I!4)A#T4^!$<P!$<L!F(M!F(S!$<I!4EF
M!4EI!$<H!4EH!3PT!F(T!4EJ!F(K!F(I!F(J!F(R!F(Q!4EG!F(O!4EK!F(P
M!F(L!$<S!F(U!F(N#TPT#TPV#TPW!$<O#T4\#T4_!5!F!RA4!$U!!5!I!RA7
M!$<R!RA6!5!E!$TX!RA5!S,H!5!G!RA:!RA+!$U%!$T[!$T]!RA3!$U$!$U#
M!5!C!RA8!RA2!RA,!5!D!RA/!5!H!RA1!RA0!RA-#TPU#U(M!RA.!RA9!5@L
M!5@K!S,K!5@G!5@J!S,G!%-1!S,I!%-4!SMB!5@I!5@H!S,J!%-.!S,L!S,O
M!%--!5@E!S,P!5@F!S,N#U(L!S,M!5X^!5X_!SM7!5X[!SM=!SMD!%AF!5XX
M!5XY!5X]!5X\!SM?!SM;!SMC!T)[!SM<!RA;!SM>!SM@!5Y`!SM8!SM:!5XZ
M#U=G#U=H#U=I#U=J!T)U!%U%!T)\!T)^!61;!617!T)]!%U+!614!615!61?
M!%U-!%U"!T)Z!613!%U'!%U,!61=!T)Y!T)W!611!%U#!5Y"!612!T)X!T,C
M!T)V!619!61:!5Y!!61<!61>!618#UQ@!TEV!6E)!6E*!&$I!TE[!TE\!6E'
M!6E(!TER!TES!TEU!TEY!TEZ!TET!TEX!&$K!TEW!T,A#V!K#V!L#V-V!T]]
M!6U8!U`F!6U;!7$T!6U5!&1%!U`C!6U6!U`B!U1\!T]^!6U9!TEQ!6U:!6U<
M!U`D#V8T!U`A!6U=!U4B!U4D!7$V!&<V!U4F!U4E!7$U!U1^!U4A!&<W!U4C
M!UDQ!U1]#V8S!&E!!UDN!&E`!&D_!70W!UDL!UDM!UDP!UDO!7@N#VEO!U]1
M!U]0!U]/!7E+!V%(!V%'!V%&!V)A!7HW!V)B!V)@!V1?!V-S!V-R!V1>!7M^
M!V5D!V8L!7Q+!V9-!21V!BXL!"M(!3!!!"]T!CPJ!D1;#SA&#S\Q#S\R!E@R
M!$<T!F(V!F(W!F(X#TPX#TPY!RA<#TPZ#U(P!S,Q!S,R#U(O!SME#V!M#V!N
M!6E+!U`G!U4G!2=G!BXM!"]W!3!"#S)3!35-!35.!D1<!D1=!350!35+#SA'
M#SA)#SA+!#4R!#4V!35,!35/!DY?!#LE!DYB!DYA!3PV!DY>!#LD!DY=!E@V
M!4)M!4)O!4)N!E@S!E@W!4)P#T5`#T5!#T5"!E@U!F(Y!4EQ!4EN!4ER!$<W
M!F(Z#TP[#TP\!4EO!F([!4EP!$U)!RA?!5!L!$U+!5!K!RAC!5!M!E@T!RAB
M!5!J!5!N#U(Q!RA@!RA>!RA=!RAA!5@P!5@O!5@N!%-7!S,T!5@T!SMG!%-8
M!%->!%-=!5@Q!5@U!S,S!5@M!5@S#U=K#U=L#U=M!SMF!61@!5Y%!5Y$!SMJ
M!SMI!SMK!SMH#UQA#UQB!61B!%U1!%U/!T,D!61A#V!O#V!P#V!Q!T,E!TE]
M!TE^!6U?!U`I!U`H#V8U!6U>#VA+#VA,!U4H!&E#!70Y!&E"#VEP#VEQ!7@O
M!U]3#VMD!U]2!7E-!7E,!V%)!&TA!7IT!&X[!7Q$!V94!BXN!BXO!C14!2M(
M!"]X!CPL!"]Y!CPK!D1G!#4[!353!352!D1?!D1C!#4W!D1D!351!D1@#SA-
M#SA.#SA/!#4\!D1F!D1>!D1B!D1E!D1A!3PW!#LF!DYD!DYG!3PX!DYC!DYF
M!DYI!DYE!#LG!#LH!DYH#S\S!4)S!4)Q!4)R!E@X!F(^!4EU!$<Y!F)`!4ES
M!4ET!F(]!F)!!F(\!F(_!RAF!5!U!RAG!5!T!5!P!5!O!$U0!$U2!$U-!RAI
M!$U4!5!R!RAH!RAJ!5!Q!RAD!RAE!5!S!S,X!S,W!%-?!5@V!%-C!5@Y!5@[
M!%-@!S,V!S,U!5@W!5@X!5@Z!S,Y!5Y&!SMM!SMS!SML!5Y*!5Y)!SMN!S,Z
M!5Y(!SMO!SMP!SMQ!%AL!SMT!SMR!5Y'!T,G!T,H!%U2!T,F!T,I!&$U!6E,
M!&$R!&$S!THA!THB!THC!THD!&$V!U`J!7$W!U4I!70Z!&E$!UQE!7@P!V)C
M!&U@!V1@!V1A!7MI!V5#!2,G!2,H!BXP!CPS!#`A!"][!"]Z!#`B!3!#!CPP
M!CPQ!CPO!CPR!CPN!#5`!D1J!D1S!#4^!D1O!35<!359!D1Q!#5"!354!#5&
M!D1Y!355!D1W!D1K!D1X!358!D1T!D1U!D1N!D1Z#SA0#SA1#SA3#SA4#SA5
M#SA6!D1R!D1I!D1H!D1V!D1L!35:!DYT!#LR!#LN!3P[!DYO!DYN!DYQ!DYJ
M!#LM!DYX!#LX!#LY!3P\!DYM!DYV!DYP!DYW!#LW!3PY!3PZ#S\T#S\U#S\V
M#S\W#S\X#S\Y#S\Z#S\\!DYR!DYU!DYL!DYY!DYS!4)U!$!H!$!J!EA&!4)V
M!3P]!4)Y!$!Q!$!P!EA`!EA+!E@]!EA)!$!I!$!K!4)\!4)T!$!S!EA#!E@\
M!EA'!EA"!E@_!$!R!4)Z!EA(!4)X!4)W!EA$#T5##T5%#T5&!EA*!4)[!E@Y
M!E@[!$!O!E@Z!EA%!E@^!F).!$<_!4EZ!$<[!4EX!4E[!$<^!$=(!F)"!F),
M!$=!!F)3!$=$!F)/!$='!F)&!4EY!F)1!F)%!$=)!F)0!F)$!4EV!4EW#TP]
M#TP^#TP_#TQ`#TQ"#TQ##TQ$#TQ%!F)(!$=+!F)*!4)]!F)+!F)-!F)#!F)2
M!F))!RDA!5$J!RAK!5!Z!5$B!RAQ!RAT!RDB!RA\!RAP!5$G!$U7!5$I!5$C
M!5![!5!^!RAX!5$D!$U=!5$F!$UB!RDD!RAW!RAO!5!X!5!\!RA]!RAM!5$E
M!5!]!5!W!5!Y!5!V#U(R#U(S#U(T#U(U#U(W#U(Y#U(Z!RAV!RAU!RAL!RAR
M#U(X!5$A!RA[!RAN!5$H!RDC!RA^!RAZ!RAS!S-&!5A`!%-Q!S-2!%-H!%-E
M!%-L!S-)!S-1!S-#!5@]!S-"!5@\!S,\!%-P!%-G!S-%!%-O!S,]!%-N!S-'
M!S-.!%-F!S-0!S,^!%-I!S,[!S-3!S-`!S,_!S-(!S-*!5@_!S-,!%-M!S-$
M!5@^#U=N#U=O#U=P#U=Q#U=R#U=S#U=T#U=U#U=V#U=W#U=X!S-4!S-!!S-+
M!%AN!5Y2!5Y1!SM]!%AO!5Y4!%AQ!SMY!%AM!5Y-!5Y3!5Y.!SMV!SPE!%AR
M!T,J!5Y/!SPA!SMW!5Y6!SPG!SM\!SMX!5Y0!%AT!SM[!SM^!SPB!SPC!%AS
M!5Y+!SPF!5Y,!SPD!SMU#UQC#UQD#UQE#UQF#UQG#UQH#UQI#UQJ#UQK!SPH
M!SPI!SMZ!%U>!%U6!T,W!%U8!T,U!61H!T,Z!T,K!%U@!61F!5A!!%U9!61G
M!T,X!T,R!61D!%U3!T,[!%U5!61E!%U=!T,Y!T,O!T,S!THJ!T,P!%U<!T,T
M!T,Q!T,\!T,L!T,M#V!R#V!U!T,V!%U?!T,N!6E-!6E/!THO!&$^!THL!THN
M!&%#!&$Y!6E0!&%!!THT!&%"!6E.!&$_!THF!THI!T,]!THH!THU!U`S!THS
M!&$\!6U@!THG#V-X#V-Y#V-Z!&%$!THK!U`U!THP!THQ!THM!THR!&$X#V!T
M!&1*!&1+!6UB!6UA!U`M!6UC!U`O!&1)!U`K!6E3!U`R!U`N!U`T!U`V!U`L
M!U`P#V8V#V8W#V8X#V8Y!U`X!U`W!U`Y!U4J!&="!U4T!U4M!U4S!&<X!U4N
M!7$]!U4L!U4O!&<\!7$Z!7$Y!&=#!UD[!UDU!&<Z!7$\!7$[!U4Q!U4K!U4P
M!7$X!U4U!70[!70]!71`!79+!&E'!UDY!&E*!70_!&E)!70^!UDW!UE`!U4V
M!70\!UDV!UDZ!UD_!&E&!UD^#VER#VES#VET!UD\!UD]!&I]!&I^!UQF!79.
M!79-!7@Q!UQH!UQI!UQJ#VIT#VIU!UQG!UE"!U]7!U]8!U]5!&PG!U]6!U]:
M#VME#VMF!U]4!U]9!U];!&TC!V%+!7E.!V%,#VPZ#VP[!V%*!7IU!V)E!V)D
M!7HY!&U^!V-T!V1B!&X\!V1$!V5$!V90!21W!#`D!3!$!3!%!#5(!#5)!#5'
M!D1[!#LZ!4)^!4,A!EA,!$=-!5$L!$UC!5$M!5$K!5A"!S-6!S-5!SPJ!5Y7
M!T,^!THV!THY!6E4!THW!6E5!THX!U`Z!THZ!7$^!7IV!V5W!C15!CPU!CPT
M#SA7!#L[!3P^!DY[#S\]!4,B!$!U!EM?!$=0!F)4!$=1!RDH!RDG!RDE!5$O
M!5$N!RDF#U([!5A#!%-T!S-7!5A$!RQ6!5Y:!SPM!5Y8!SPL!5Y9!SPK!61I
M!%UC!T-`!%UB!5Y;!TH\!6E7!TH]!T-!!T-"!6E6!6UF!6UE!6UG#V8Z!6UD
M#V-[!7$_!71!#VIV#VIW!7@R!7E/!7IW!V5%!B54!2,I!2M*!3!(!3!'!CPW
M!CPV!D1^!D1\!35A!D4A!D1]!#L\!DY\!#L]!3Q`!3P_!DY^!3Q!!D\C!DY]
M#S)5!$!W!4,E!$!V!EA.!EA/!4,G!4,C!4,F!EA-!D\B!4,D!4,H!F)5!F)6
M!$=3!$=2!F)9!4E]!4E\!F);!F):!F)7!F)8!5$R!$UF!RDI!RDK!5$Q!5$S
M!RDM!RDL!4E^!5$P!RDJ!4HA!RDN#U(\!5A'!5A(!5A&!S-9!%-V!S-:!S-<
M!S-;!5A%!S-8!5Y=!5Y>!5Y?!5Y<!SPP!SPN!SPO!%UE!61J!61K!T-#!T-$
M!T-%!&%'!6E8!5A)!TH^!&%)!6UK!6UH!U`[!6UJ!6UI!&=&!7%`!U4W!U4X
M!UE#!UQL!UE$!UE%!UQM!UQN!71"!U]<!V%-!U]=!7E0!7HZ!V5&!V9##RAL
M!2M+!CPX#S)6!35D!35C!#5/!35B!#5.!D4E!D4C!D\E!3Q"!3Q&!3Q$!3Q(
M!3Q%!D\H!D\F!3Q'!3Q#!D\G!D\D#S\^!$!\!$!]!$!Z!EA2!4,K!EA1!4,J
M!$!Y!$![!EA3#T5'!4,I!F)A!F)<!4HE!4HC!4HB!F)?!4HD!F)>!F)@#TQ(
M!F)=!F)B#TQ)!5$U!5$T!$UI!5$W!5$V!5$X!$UJ!RDO!RDP!$UK!RDQ!S-D
M!5A+!S->!S-@!S-A!%-X!5A*!S-B!5A,!S-?#U=Z!S-=!S-C!%AY!5YC!SPQ
M!5YB!%AX!5Y@!5YD!5YA#UQL!T-&!%UG!T-'!%UF!61L!TH_!61M!6E;!TI`
M!6E:!TI#!U`]!TI"!6E9!6UM!6UL!U`\!7%"!6UN!7%!!U4Y!UE&!UQP!UQO
M!7IX!2M,!"M*!C16#RU*!#`F!CPY!3!)!3!*#S)7#S)8!CPZ!D4J!D4L!D4G
M!D4H!D4F!D4K!35E#SA9#SA:#SA;#SA<#SA=#SA>#SA?#SA@!D4M!#53!D4I
M!#52!D\K!#M`!3Q)!3Q+!D\N!D\L!D\M!EA7!3Q*#S\_#S]!#S]"#S]##S]$
M#S]%!D\O!D\J!3Q-!$$B!EA4!EA9!EA6!4,P!4,L!EA>!EA5!4,O!4,Q!4,R
M!EA8!EA@!EAB!4,S!EA?#T5(#T5)#T5*#T5+#T5,#T5-#T5.!EAA#S]`!EA;
M!4,N#T8T!F)E!$=5!4HF!F)D!F)F!F)L!F)C!F)I!4HG!$=7#TQ-#TQ.#TQ/
M#TQ1#TQ0#TQ,!F)K!EA=!RDS!RDU!4HH!$UO!RDT!5$Z!$UP!5$[!RDY!RDX
M!RDR#U(]#U(^#U(_!RDW#TQ+!S-J!5A.!S-G!S-F!5A/!S-K!S-N!%-\!S-H
M!5A-!F)H#U0R#U=[#U=\#U=]#U=^#U@A#U@B!S-M!S-L!S-E!S-I!5A0!SPR
M!5YE!5LM!5YG!5A2!5YF!%A[!SPX!SPT!SPV!SPW!SPU#UQN#UQP#UQO!T-+
M!61S!T-.!61O!T-)!T-*!T-1!61Q!61N!61R!T--!T-,#V!V#V!W#V!X#V!Y
M#V![#V!\!T-(!T-0!61P!TI'!TI+!6E=!61T!TI*!T-/!6E<!&%+!TI(!6E>
M!TI-!TI,!6E@!TI$!TI)!TI&#V-\#V-]#V-^#V0A!TI.!TI%!6E?!&11!6UP
M!&10!6UO!U`^!U!`#V8[#V8\#V8]#V8^#V8_!U`_!7%#!&='!7%$!7%%#VA.
M#VA/!U4[!UE'!71%!71$#VEV#VEW#VEX!UE*!UE(!UE)#VA-!UQQ!&LB!71#
M!UQR#VIX!UQS!U]>!U]@!U]?!V)F!BXQ!C17!C18!35F#SAA!D\P!#M$!EAC
M#T5/!4HJ#TQ2!RDZ!5A4!5A3#U@C!S-O!5YI!5YJ!5YH#UQQ!61U!T-3!TI0
M!TI/!7%&!UQT!BXR!BXS!C19#RU+#RU-#RU.#RU/#RU0!"M+!3!-!CP^!CP]
M!3!.!CP\!#`I#S)9#S):#S);#S)<#S)=!35M!D4P!35G!#57!35J!35O!35N
M!#58!D4N!D4O!35K!35H#SAC#SAD#SAE#SAF#SAH#SAI#SAB!35L!35I#SAG
M!3Q1!3Q0!3Q4!3Q/!D\T!D\Q!4,Y!3Q3!3Q.!D\S!#M&!3Q5!EAD!D\U#S]'
M#S](#S])#S]*#S]+#S],#S]/#S]0#S]1!D\R#S].!EAF!4,V!$$C!EAH!$$E
M!4,[!4,U!4,]!4,W!$$D!EAJ!EAI!4,Z#T50#T51#T52#T53#T54#T55#T56
M#T57!EAE!EAG!F)M#S]-!F)N!$=<!4HL!4HP!F)R!4HK!4HN!4HQ!F)Q!F)O
M!4HS!$==!4HO!F)V!4HM!F)S#TQ3#TQ4#TQ5#TQ6#TQ7#TQ8#TQ9!F)P!5%"
M!5$\!$UR!5$_!5$^!5$]!5%`!RD_!5%&!5%#!RE!!5%!!RD\!RE`!RD^!F)T
M!RE"!S-R!5%%!5%$#U)`#U)!!RE#!RD[#U@M!%0C!%0D!%0H!S-T!5A9!%0A
M!%0B!%0G!S-U!%0E!S-Q!S-P!5A8!5A:!S-V#U@D#U@F#U@G#U@H#U@I#U@J
M#U@K#U@L#U@N!S-X!S-W!5A;!5A6!5A7!5YO!5YQ!%DB!5YP!%DD!%DA!5YR
M!%A^!5YL!%DC!5YN!5YK!SPZ!5YS#U@E#UQR#UQS#UQT#UQU#UQV!SPY!61Y
M!61\!%UK!T-7!T-6!61V!61Z!61X!61W!61]!61^!T-;!T-:!61[#V!]!T-8
M!T-5!T-9!T-4!5A=!6EB!6EF!6EH!&%.!&%,!6EC!6EG!6EE!6EA!TI2!6EI
M!6ED#V0C#V0D#V0E!TI1!TI3!&12!&14!&18!&17!6UQ!U!!!U!#!6UR!U!"
M#V9`#V9!#V9"!&=)!7%(!7%)!U4_!U4]!U4\!U4^!7%'!71&!71)!&E-!71(
M!71'#VEY!79/!790#VIY!UE+!UQU!UQV!7@S!7@T!7@U!&TF!V%.!7IY!7M)
M!BXU!BXT!C1;!2M-#RU1!C1:!CQ!!#`K!CQ"!CQ`!3!0!3!/!CP_!CQ#!#5?
M!D4S!#5:!35S!D4W!35W!D4Z!35Q!35U!D4\!D4]!35T!D4[!D4R!D4V#SAJ
M!D4Q!D4U!D4Y!35V!35P!D4T!3Q@!3Q7!3Q8!3Q;!D\[!3Q6!D\X!#M.!3Q=
M!3Q9!3QA!3Q:!D\Y!EAY!3QB#S]4!D\W#S]2!D\Z!3Q>!4-!!4,_!EAQ!4-`
M!4-"!EAT!EAP!4-'!4-%!EAN!EAM!4,^!EAO!EAR!EAV!4-*!EAL!EAW!4-#
M!4-,!4-(!EAS!4-)!4-&!EAU!4HU#T59!EAX!EAK!F,B!4I#!$=@!4HW!4H_
M!4HV!5%.!4H[!F)W!F)[!4I"!4H\!4HY!4I`!4I!!4H]!4-$!4HX!4I$!F)^
M!4I&!F)Y!4I'#TQ:#TQ;!F)X!F)Z!F)]!F,A!F)\!4HZ!RE&!$UZ!5%,!5%'
M!5%*!5%/!RE%!RE)!$U\!RE-!$U[!5%+!5%-!$XD!5%1!5%2!$=C!RE/!5%)
M!RE+#U)"#U)##U)$#U)%!RE(!RE,!RE'!RE*!5%0!5%4!5%5!4I%!S0A!5A@
M!4I(!5AI!%0J!S-Z!5AC!S-^!S0C!S-\!5A?!S-[!S0E!5%3!S0F!5AG!5AH
M!5A>!5AA!S-]!5AE!5AD!S0D!%0K!5AF!%0L#U@Q#U@R!S0B!5YZ!5Y]!5YU
M!SQ`!5YV!5Y\!5YX!%DI!SP^!T-G!SQ#!5Y^!%DN!SP[!SQ"!SQ$!5YY!%DG
M!SQ!!S0G!SP_!%DO#UQW!SP]#UQY!5YW!5YT!T-B!%UP!T-F!%UO!64A!64B
M!64M!64F!%UQ!64L!64H!T-?!6EP!T-E!T-<!64N!T->!64D!T-A!64C!64I
M!%\S!%UV!64E#V!^#V$A#V$B#V$C#V$D#V$E!T-K!64G!T-@!T-I!T-H!T-J
M!T-=!64K!T-C!SP\!64O!6EJ!TIE!6EO!6EQ!TIH!6ET!TI;!64J!6EN!TI8
M!6EM!6ER!&%5!TI4!%US!TI9!T-D!TI>!6ES!TI:!TIF!TI5!TI<!6EK!6EL
M!TIA!TIB!TIC!TI?!6EV!6EU!TI@!TI=!TIG!TI6!TID!&%3!&19!6U]!6UW
M!U!$!6U[!6UV!6UY!U!(!U!&!&1<!6US!&1=!U!'!6UX!6UU!6UT!U!)#V9#
M#V9$#V9%#V9&#V9'!U!%!U!*!U!+!6U\!6U^!6UZ!&=.!U5"!&=/!7%+!U5!
M!U5$!&=-!&=+!7%,!U5#!U5`!7%*#VA1#VA2!71*!U5%!UE,!71-!71/!71.
M!71,!UE-!711!UE.#VEZ!UE/!710!794!792!795!UQY!UQX!793!791!&PK
M!U]A!7@W!7@V!&PJ!7@X!U]B!V%/!U]C!V%2!&TH!V%4!V)G!V%3!V%1!V%0
M#VMG!7H\!7H[!7H]!V-V!7M*!V1C!7MJ#VTH!V5E#VTS!B,Y!B,Z!B55!3!2
M!CQ$!3!1!35Z!35Y!35X!D4^!D5!!D5`!D5"!D4_!D5#!D5$!#5@#SAK!3QE
M!D\_!3QD!D]!!D\^!3QF#S]5#S]6#S]7#S]8!D\]!D]`!EA]!4--!EAZ!EA^
M!EDA#T5:#T5;#T5<!EA[!EA\!EDB!4I*!F,C!F,D!4I)!F,E!F,F#TQ<#TQ=
M#TQ>!RE1!5%6!$XE#U)&#U)(!RE0!5AJ!%0Q!5AK!S0H!SQ&#U@T#U@V!SQ(
M!SQ'!SQ%!5\A#UQZ#UQ[!64P!T-L#V$F#V$G!TIL!TIM!TIJ#V0F#V0G!TIK
M!TII!&1>!U!-#V9(#V9)!U!.!U5&!7%-!U5'!U5(!U5)!UE0#VE\!796!7E1
M!C1<!2M.!C1>#RU2#RU4!CQ%!3!4!CQ'#S)?#S)@!CQ&!3!3#S)>!35[!D5.
M!D5-!D5&!#5D!38B!38A!D5*!35]!D5'!D5,!D5+!35\!35^#SAM!D5(!D5)
M!#5E!D]&!D]'!3QP!3QN!D]%!D]$!D]"!38C!3QM!3QH!3QK!3QJ!D]#!3QI
M!3QQ!3QL!3QO!EDC!EDH!4-3!EDF!EDI!4-1!$$K!4-2!4-/!EDG!4-.#T5=
M#T5>#T5?!EDE!$$M!4-4!F,M!F,O!4I0!$=H!F,H!F,K!4I-!F,L!F,G!F,P
M!4I+!4I.!F,Q!F,N#TQ?#TQ@#TQA#TQC!4I/!4I,!RE9!F,J!5%@!RE7!RE>
M!REB!RE6!5%9!RE:!RE5!RE<!5%8!5%;!5%>!$XL!F,I!RE8!RE=!RE;!5%=
M!5%?!RE2!5%7!RE4!REC#U))#U)*#U)+#U),!RE3!RE?!RE@!REA!5%<!5%:
M!S0I!5AS!S0O!5AT!S0M!5AP!S0K!S0T!5AN!5AQ!5AM!S0U!S0P!S0V!5AL
M!S0S#U@W#U@Y#U@Z!S0L!S0N!S0J#U@X!%0U!5AO!SQ*!SQ2!5\E!SQ-!SQ,
M!SQ+!SQ3!%DS!SQ0!%DT!SQ1!5\B!5\K!%DV!5\H!5\G!SQ4!5\D!5\J!SQ)
M#UQ\#UQ]!SQ.!SQ/!5\F!5\C!5\I!%UY!T-P!%XA!64R!64T#V$H#V$I#V$J
M!T-O!T-R!T-Q!T-N!T-M!64Q!64S!6EX!TIN!TIQ!TIO!TIP!6EZ!&%:!&%;
M!6EY!6EW!6E[!TIR#V0H!TIT!&1B!6XE!6XC!U!3!6XD!6XB!U!1!6XA#V9*
M!U!2!U!0!U!/!6XF!U!4!&=3!7%.!&=4!U5,!U5+!U5*!UE6!&E0!UE2!UE1
M!&E1!UE7!UE3!UE4!UE5!UQ^!UTA!797!UQ[!UQZ!UQ\!UQ]!799!798!7@\
M!7@[!7@Z!U]G!U]E!U]D!7@Y!U]F!7E3!7E2!7H^!7H_!V)H!7IZ!V1D!V)I
M!V-W!7MK!V5F!BDK!BXV!CQ(!D5/!38E!38D!$$N!EDJ#T5A!4I1#TQE#TQF
M!4I2!RED!REE!REF!5%B!S0W!5AU!S0X#U@[!5\M!5\L#UQ^#UTA#UTB#UTC
M!5\N!64W!64V!T-S!TIU!&%<!TIV#V9+!U!5#VA4!UE8!U]H!V5'!V5G!BDL
M!BXW!EDM!EDL!EDK#U)-!S,A!&%=!U5-!B59!B58!B57!"1^!BDM!"4D!CQ)
M!BDN#R4S#R4T!CQ*!BDO!21X!CQ+!D50!2=J!2=K!2=P!BXX!BX]!2=O!"@E
M!2=Q!2=M!"@H!BX[#RAM#RAO#RAP#RAS#RAT#RAU!BXZ!BX_!2=N!2=H!BX\
M!2=L!BXY!BX^!2M/!2M6!2M2!C1?!2M1!C1B!2M5!2M3!"M/!"M1!2M0!C1D
M!C1C#RU5#RU6#RU7#RU8#RU9!"M2!C1E!C1A!DI'!2M7!2M4!CQ4!CQ8!3!;
M!CQ3!3!6!3!:!#`Q!3!7!3!9!CQ2!CQ,!CQ6!#`R!CQ7!CQ-!4-5!CQ5!3!8
M!CQ0!CQ.!3!<!38G!38F!CQ/!D5;!38L!#5J!D5<!38K!CQ1!38I!D57!D5:
M#SAP#SAQ#SAR!D56!D54!D55!D52!D5=!D58!D53!38J!#5G!D59!38M!38H
M#SAO!D51!3QV!3QR!3QX!3QW!#M6!D]3!#M:!#M8!3QY!D]2!REG!D]-!D],
M!D]0!D]/!#M;!D])!D]+#S]B!D]1!D]4!D]5!D]*#S]9#S]:#S];#S]<#S]=
M#S]?#S]@#S]A!3QU!D].!3QT!3QS!#M9!D]6!EE`!EDT!ED]!EDP!$$Q!$$P
M!EDN!4-9!EDQ!EE!!ED[!ED_!EDW!EDU!EE#!EE"!3QZ!$$R!EDS!ED^#T5B
M#T5C#T5D#T5E#T5F#T5G#T5H#T5I#T5J#T5K#T5L!EDR!EDV!ED\!EDY!EDX
M!EDZ!EDO!4-8!4-7!4-6!F,U!F,T!F,W!F,R!F,Z!4I4!F,V!F,X!F,\!4I3
M!4I6!F,S!F,[!SQ5#TQI#TQJ#TQL#TQM#TQN#TQO#TQP#TQQ#TQR!F,Y!SQ6
M!SQ7!SQ8!4I5!REN!REL!RER!REI!REK!$XO!5%D!$XP!5%H!5%E!$XT!REP
M#U).#U)/#U)0#U)1#U)2!5%M!REJ!REO!RET!REU!REQ!RES!T-T!REH!T-U
M!REM!5%I!5%G!5%L!5%F!5%J!5%K!5%C!S1&!5A\!5A[!5AY!S1!!5AW!S1%
M!S0^!S1'!%0V!S1"!S1$!S0Y!S1*!TIW!S0\!S1`!S1,#U@\#U@]#U@^!S0]
M#U@_!RQ:!S1(!S0[!S0Z!S1#!S1+!5AX!5A]!5AZ!S0_!5AV!5\O!%DZ!SQ@
M!5\S!SQ=!5\T!SQ;!U!7!S1)!SQB!SQ>!5\R!5\U#UTD#UTF#UTG#UTH!SQ9
M!SQ<!SQ?!SQC#UTE!5\V!5\W!5\Q!5\P!SQ:!64]!T-\!%XB!T-Z!64Z!T-X
M#V$K#V$L#V$M!T0A!T-^!64Y!T-]!T-V!T-Y!64\!64[!64X!T-[!TLA!TLB
M!TI^#V0J#V0K#V0M#V0N!TIY!TIZ!TI]!TI[!TI\!TIX!6HA!6E^#V0L!U!:
M!6XI!U!9!6XG#V9,!U!8!6XH!UTB!&=5!U5/!7%1!U50!U5.#VA5#VA6#VA7
M#VA8!7%/!7%0!6E]!U51!7%2!712!&LE!UE;!UE:!UE9!UTC!UTE!UTD!V)J
M!U]J!U]I!7@]!V%5!V)K!V5H!BDP!2%\!2,L!2,K!2,M!2,J!",Q!B5:!B5<
M!",S!"4G!21Y!"4F!"4H!"4E!BDS!"4J!21Z!#5Q!BDR#R4U#R4V#R4W#SAS
M#SAU!D5A!D5?!D5@!BDQ!"4I!"@N!D5>!"@J!"@M!"@L!C1I!"@O!2=R!2=S
M!D]8!BY##RAV#RAX#RAY#RA\!D]:!BY!!BY"!BY`#RAW#RA[!D]7!D]9!2=T
M!2M:!2M9!2M8!"M7!"M5!2M?!$$S!2M;#RU:#T5N!EE%!EE$!EE&!C1L!C1F
M!C1G!C1H!C1K!C1J!2M>!2M<!2M=!3!A!3!=!#`V!CQ;!3!E!3!F!3!>!3!C
M!3!?!#`U!CQ=!#`W!CQ?!F,]!F,_!F-`!CQ<!CQ>!CQ:!3!B!3!D!3!@!3!G
M!F,^!CQ9#S)B#S)C#S)D!5%N!$XV!#5O!38Q!38P!38U!38N!38R!#5M!D5F
M!38T!REZ!REY!D5H#S)A#SAV#U)4!REV!REW!RE[!REX!D5C!D5E!D5D!D5B
M#S,\!D5G!38O!38S!3!H!#M?!3TC!3Q^!3TB!#M=!3TD!D]D!3TA!4-G!3Q]
M!3Q\!D]B!D];!#M<#S]C#S]D#S]E#UA!!S1.!D]=!D]<!D]>!D]?!D]@!D]A
M#S]F!D]C!S1-!3Q[!SQD!4-;!4-@!4-C!4->!4-=!$$U!F-!!4-<!4-B!4-?
M!4-D!4-F!$$W!4-E!EE)!4-:#T5O!EE(!EE+!4-A!$=O!4I=!4I<!4I9!4I8
M!4IC!4I?!4I;!F-&!F-#!F-"!4IA!4IB!T0B!T0D!T0C!T0E!F-%!4I7!$=R
M!F-$!64^!4I:!4I>!4ID!$XX!TLC!5%R!RHA!$XW!5%S!$XY!5DH!5%O!5%P
M!RE^!RHB!$XZ#U)3#U)5#U)6!TLF!TLD!RHC!RHE!RHF!RHD!RE\!RE]!5%T
M!S10!5%Q!TLE!6XJ!5DE!5DF!U!<!%0X!S1/!5DA!5DD!S12!5DB!5DC!%0Y
M!S11#UA`!U!=!U!;!6XK!SQE!SQI!5\X!%D[!5\Y!U52!U53!U54!SQG!SQJ
M!SQF!5\[!5\Z!U55!SQH!65`!T0F!T0G!65!!6HE!65$!T0I!T0H!65"!65#
M!UE<!64_!T0J!TLH!T0K!6HD!TLG!6HC!TLJ!TLI!&%@!5DG!6HB!&1D!6XL
M!U!?!U!A!U!>!U!@!&=6#VA9!U56!U57!UE=!U58#VA:!UTF!U]K!U]L!7M+
M!V-X!#`Y#S)E!CQ@!38X!38W!D5R!D5N!38Y!#5V!D5L!D5S!D5I!#5W!38Z
M!D5P!D5O!D5J!D5K#SAW!D5Q!#5Y!D5M!D5T!D]K!3TE!3TF!#ME!D]I!4-J
M!#MB!#MC!D]J!D]F!D]E!#MA!D]G!D]H#S]H#S]I#S]J#S]K!D]L!4-I!4-L
M!4-H!EE.!EE-!4-K!F-*!4IF!4IE#TQS#TQT#TQU#TQW!F-)!F-(#TQX!F-'
M!RHH!5%X!RHL!5%Y!5%U!RHP!5%V!RHO!RHN!RHM!RHI!RHG!5%W#TQV#U)8
M#U)9!RHJ!RHK!RHR!RHQ!S16!S15!5DI!S18!5DL!S1:!%1!!S1?!%0^!%0_
M!S1>!5DJ!S17!S1=!S1<!5DK#UA"#UA#!S19!S1;!S13!S1@!5]!!5\_!5]`
M!5]#!%E`!SQL!5]"!%D^!SQN!5\^!SQT!5]$!SQM!SQS#UTJ#UTK#UTL!SQO
M!SQQ!SQR!5\]!65&!65'!65)!T0S!T0O!%XC!T0L!65(!%XF!65*!SQU!%XE
M!T0R!65+!T0U!T0V!T0M#V$N!T0Q!T0N!65,!T0P!TLO!TLL!6HN!6HK!6HG
M!6HJ!6HI!6HO!6HL!6HH!6HM!TLM!TLN!TLP!TLK!T0T!6HP!6HF!U!B!6XQ
M!6XN!6XO!6XM!6XP!U!C!U!D#V9.!U!E!U!G!U!F!&=9!&=7!&=8!7%3!U5:
M#VA;!U59!UE>!UE?!UEB!713!UEA!UE@#VE]!UTG!UTI!79:!UTK!UTJ!79;
M!UTH#VIZ!7@_!&PO!U]M!U]N!7@^!V)L!7I[!V-Z!V-Y!V1F!V1E!V5X!V5Y
M!C1N!3TG!38[!F-+!F-,!5%Z!RHT!RHS!5DM!S1A!5]%#UTM!T0W#V9/#VA<
M!714!38\!CQA!D5U!D]N!3TI!3TH#T5P!F--!RHU!5]&#V$O!65-#VA=!7%4
M!U5;!CQD#S)F!CQB!38]!D5V!D5W#SAX!D]S!D]T!D]U!D]Q!D]R!D]X!D]V
M!D]P!D]Y#S]L#S]M#S]N#S]O#S]R#S]T#S]Q!D]W#S]P!$%'!4-N!$%%!$%$
M!EE3!EE/#T5Q#T5U#T5V#T5W#T5X!EE5!EE1!EE2#T5Y!EE4!EE0#T5T!4IG
M!4IH!F-2!4II#TQH#TQY#TQ[#TQ\#TQ]#TTA#TTC#TTD#TTE#TTH#TTI!F-.
M!$=Z!F-0!F-1#TTJ!F-4#TQZ!F-5#TTK#TTF#TQ^!RHZ!$Y"!5%^!RI!!RH[
M!RI`!RHY!5%]!RI#!RI$!RH]!5%[!RHW#U);#U)=#U)?#U)@#U)C#U)D#U)E
M#U)G#U)H#U)I#U)J#U)L#U)M!RI"!RH\!RH_!RI%#U)>!RHV!5%\#U)B#U)F
M#U):!5DT!5DW!5DR!%1'!5DN!5DP!S1E!S1D!S1K!S1I!S1G!5DV!%1$!S1B
M!S1J!S1H!5DO!S1F#U)<!5DS#UA$#UA&#UA'#UA)#UA*#UA+#UA-#UA.#UA/
M#UA1#UA3#UA4#UA6#UA7#UA:#UA<#UA=#UA>#UA@#UAA#UAC#UAD#UA0#UA2
M#UA?#UA%#UA8!5DX!5DQ!5](!5])!SQY!%E#!5],!5]+!SQ\!5DU!5]'!SQZ
M!5]*!5]/!SQ^!STD!STA!STE#UTO#UTP#UTT#UTU#UTV#UTW#UTZ#UT[#UT\
M#UT]#UT_#UU`#UU"#UU##UU$#UU%#UU&#UU'#UU(#UU)#UU+#UU.#UU/!SQ]
M!STB!SQX!STC!%E(#UU*#UTX#UTS#UTQ!5].!5]-#UTN!651!%XM!%XN!652
M!%XH!%XJ!T0X!650!65.!6HQ!T0Z!653!%XP!T1`!T0_!654!655!T1!#V$Q
M#V$R#V$T#V$V#V$W#V$X#V$Z#V$\#V$]#V$^#V%`#V%!#V%"#V%$#V%%#V%&
M!T0[!T0\!T0^!T0]#V$P#V$Y#V$U#U]=!&%K!TLS!TLW!6HR!TLT!6HT!TLR
M!TLZ!TLV!TLY!TL[#V0Q#V0R#V0S#V0U#V0V#V0X#V0Y#V0Z#V0[#V0\#V0]
M#V0_#V1`#V1!#V1"#V1##V1$#V1%!TL\!TLU!TLX!&%J!TLQ!656#V0^!&1H
M!U!M!U!N!6XX!U!R!6XS!&1J!6XV!6XR!U!P!U!H!U!I!6XW!&1N!U!Q!6XT
M#V90#V91#V93#V94#V95#V96#V98#V99#V9:#V9;#V9=#V9?#V9@#V9A#V9B
M#V9C#V9D#V9F#V9H#V9J#V9K#V9L#V9M#V9N#V9O!U!L!U!O#V92#V9<#V9G
M!U!J!U5B!&=>!U5G!U5A!U5<!&=@!&==!U5@!U5C!U5I!U5>#VA>#VA?#VA@
M#VAA#VAB#VAC#VAD#VAE#VAF#VAG#VAH#VAI#VAK#VAL#VAM#VAN#VAO!U5?
M!U5D!U5E!U5F!U5=#VAJ!717!UEK!UEJ!UTP!UEF!UED#VE^#VHA#VHB#VHC
M#VHD#VHE#VHF#VHG#VHH#VHI#VHJ#VHK!UEC!UEE!716!79>!&LH!79<#VLO
M!UTO!UTM!UEI!UTL#VI\#VI]#VLC#VLD#VLE#VLF#VLI#VLJ#VLK#VLL#VLM
M#VLN!UTN!UTQ#VLA#VI^#VLG!7A`!U]P!U]Q!U]R!U]O!U]S#VMH#VMI#VMJ
M#VMK#VML!&UC!V%7!V%8#VMM#VP\#VP]!V%6!V)R!V)M!V)N!V)T!V)P!V)O
M!7I`!V)S!V)Q!V)U#VQ2#VQ3#VQ4#VQ5#VQ6#VQ7#VQ8#VQ`!7I!!7I\!V-]
M!V-[#VQO!V-\#VTC!V1H#VTA!V1G!V1I#VTB#VP^!V5(!V5)#VTI!7PA#VTU
M#VTX#VTY!BY$!BDT!2M@!38_!D5[!38^!39`!D5Z#SAY!D5Y!D5X!3TJ!3TK
M!#MH!D]Z!D][#S]U!EE9!EE8!$%*!EE6!EE7#T5Z!4-P!4-O!4IJ!$=\!F-6
M!F-7!4IK!5(A!5(C!5DY!5(B!5(D!5(E#UAE!5D[!S1N!5DZ!STF!S1M!S1P
M!S1L!STI!%E*!5]0!%E+!STJ!STH!STG!T1#!658!T1"!657!6HX!6HV!6HU
M!6HW!6XY!U!S!U!T!&=D!U5J!UEM!UEN!UEL!79A!79@!7A!!U]T!V)V!V1J
M!2MA!3!J!3!K!3!I#S)G!CQF!39"!39!#SAZ#SA[!D5\!3TS!3TQ!3TO!#MJ
M!3TP!#ML`S]M!3TL!3TM!3TN!D]^!E`A!3TR!D]\#S]X#S]Y#S]Z#S][#S]\
M#S]]#T`A!D]]!#MI!$%,!EE>!$%2!$%-!$%+#T5^!EE=!4-T!4-Q!4-S!4-R
M!EE;!$%1!$%/!EE<!EE:#T5]#T8A!4IS!4IO!4IQ!$=^!4IM!$@A!4IT!F-:
M!4IP!4IU!$=]!4IR!4IV!F-9!F-;!F-<!4IL!RI(!5(M!5(H!RI-!5(J!5(G
M!RI.!$Y)!5(L!5(I!RI,#U)N#U)O#U)Q!RI'!RI)!RI*!RI+!5(F!5(K!5(N
M#U)P!%10!%1-!5D]!5E`!S1R!5D\!5D^!5D_!S1U!S1W!S1Y#UAF#UAG#UAH
M!S1T!S1X!S1V!%1.!%E3!%E1!5]4!STK!5]1!5]3!5]5!5]2!STM!%E0!STL
M!%E,!STN#UU0!STO!STP!STQ!65?!65>!65:!%XS!T1$!65;!65A!65@!T1&
M!65=!659!65<#V%'#V%(#V%)#V%,#V%+!T1%!T1'!6HY!TL^!TL_!&%M!6HZ
M!TL]!&%N#V1&#V1'#V1(#V1)#V1*!&1P!6X_!6XZ!6X]!6X\!6X^!6Y`!&1R
M!U!X!6H[!U!U#V9P#V9Q!U!V!6X[!U!W!7%:!6Y!!&=E!7%9!7%7#VAP#VAQ
M#VAS#VAT#VAU!7%<!7%8!718!U5K#VHO!UEO#VHL#VHM#VHN#VHP#VHQ#VLP
M#VLQ#VLR!UTR!7A"#VMN#VMO!U]V!U]U!7E4!&TI!&TJ!V%9!V)W!V)X!7I]
M#VTJ!BY%!2(B!2%^!"(C!2(C!"(B!2(A!2,N!",T!B5=!21]!"4L!"4M!21^
M!21\#R4Z#R4[#R4\#R4]#R4^#R4_!2=U!BY'!2=V!2=X!2=Y!"@P!2=W!BY&
M!BY(#RA]#RA^!2MB!C1P!C1S!"M<!2ME!C1Q!F-=!C1U!C1V!C1W!C1R!2MC
M!C1X#RU;#RU<#RU=!C1T!C1O!CQI!3!O!2MF!CQH!3!L!3!N!CQN!CQK!CQO
M!3!M!CQJ!CQM!CQL#S)H#S)I#S)J#S)K#S)L#S)M#S)N!39#!D8H!D8A!#5^
M!#8B!#8A!39$!D8C!D8D!D8K!D8J!F->!D8F!D8B!D8I!D8G!S1[!D8E#SA\
M#SA]#SA^#SDA#SDB#SDC#SDD#SDE#SDF#SDG!3TX!3T]!3TY!3TZ!3T\!E`E
M!E`C!3TT!3TU!3TW!E`D!E`I!STT!E`G!3T[!E`H!E`F#T`B#T`C!STR!3TV
M!EEJ!4-[!4-X!EEB!EEI!EEG!4-\!4-Y!4-W!F-?!EEC!EEE!4-]!4-Z!EEF
M!T1)!EED!T1(!4-V!EE?!EEK!EE@!4-U!EEA#T8B#T8C#T8D#T8E#T8F#T8G
M#T8H#T8I!EEH!EEL!STS!F-D!F-B!F-F!$@G!$@F!5(O!$@H!$@I!4IX!F-C
M!F-@!$@E!4IY!4IZ!F-E!F-G!TM!#TTN#TTO#TTP#TTQ#TTR#TTS!F-A!4IW
M!5(V!5(T!5(U!RI5!5(X!5(R!5(Q!RI/!5(S!5(W!5(P!U!Z!RI3!RI1!RI0
M!RI2#U)R#U)S#U)T#U)U#U)V#U)W!RI6!5E!!5E"!%14!S1\!5E$!5E#!S1^
M!U!Y#UAI#UAJ#UAK#UAL!6H\!S1]!5]6!5]7!STV!STW!STU!719#UU1#UU2
M#UU3#UU4!65B!T1,!%XT!T1*!T1+#V%-#V%.#V%/#V%0!6H]!TM#!U5L!TM%
M#V1,!7A#!TM"!TM$!U]W#V9R#V9S!U%R!7%=!U5N!U5M!V)Y!V)Z!UEP!UU)
M!U]X!7I^!7LA!V8W!V8H!EEM!$Y+!RI7#U)Y#U)X!5E%!S4A!%E6!T1-!T1.
M!6H^!U![!CQP!CQQ!CQR!D8L!39%!#8C!D8N!D8M!D8P!D8O!#MP!E`L!#MN
M!E`J!EES!E`P!E`N!E`K!#MQ!#MO!E`O!E`M!EE[!4-^!EEN!EEQ!EEW!EEU
M!EEZ!EER!EEP!EET!EEY!EEX!EEO!EEV!F-T!F-R!4I[!F-K!F-L!F-V!F-H
M!F-W!F-P!$@J!F-U!F-O!4I\!F-Q!F-I!4I]!$@K!F-J#TTT#TTU!F-S!F-X
M!F-M!RI=!RI;!RID!RI?!RI<!5(Z!RI>!RIF!RIB!RI@!RIA!RIC!RI:!RI8
M!5(Y!RIE!RIG!%E7!%15!5E'!S4I!S4D!S4O!S4B!S4M!S4H!S4E!S4L!S4J
M!S4F!5E&!S4P!%16!S4K!S4S!S4G!RI9!S4T!S4Q!S4C!S4R#UAM!S4N#U)Z
M!%E9!ST]!ST[!SU%!ST\!ST^!SU)!STZ!SU"!STY!STX!ST_!5]8!SU'!SU!
M!SU`!SU#!SU(!S4V#UU5#UU7!SU$!SU&!T10!T16!T12!T13!T1/!65C!T17
M!T15!65D!T11!T14!TM*!TM'!TM+!TM(!6H_!TM.!&%O!6I`!TM&!TM,!TM-
M!&%P!TM)!TM/!U$C!U$G!U!]!U$J!U$D!U$K!U$H!U!\!6Y"!U$E!U$F!6Y#
M!U$B#V9T!U!^!U$L!U$I!U5T!&=H!U5R!U5O!U5V!U5P!U5U!U5S!U5W!U$A
M#VAV!U5Q!UEQ!UER!&E7!UEU!UEV!UET#VHR!UES!UTX!UTY!UTZ!&LK!UTW
M!UTS!UTT!UTU!UTV!U]\!U]Z!U][!U]Y!V%:#VQ!!V-^!V1K!V9`#RU>!3!P
M#S)P!D8R!D8S!#8E!D8Q#SDH#SDI!3U`!3T^!3U!!3T_!#MS!E`S!#MR!E`R
M#T`E#T`G#T`F!$%8!40E!40B!40A!40D!40C!EE\#T8K#T8L#T8M!40F!4LB
M!$@P!4LC!4LA!4I^!$@L!$@O!F-]!$@R!F-\!F-^#TTW#TTX!F-Z!F-Y!RIJ
M!RII!5)%!5)`!5)!!5(_!5(^!5)#!5(]!%17!5(\!RIK!RIL#T8J#U)[#U)\
M#U)]#U)^#U,A!RIH!5)$!5)"!5]9!S4[!%1;!5E.!5E+!%1:!S4X!5E-!5E*
M!S4Z!5E)!S4Y!S4W!5E(!S4\#UAN#UAO#UAQ#UAR#UAS#UAT#UAU#UAP#U5D
M!5E,!%E<!%E:!%E;!5]:!%EA!5]<!%E>!SU*!65H!SU+!SU-!5];#UU9!SU,
M!SU.#UU:!5]=!65L!65O!T1?!T1C!65I!T1>!65F!T1E!T1B!%XW!65E!65G
M!T1A!T1:!T1=!65N!T1;#V%1!T1D!T19!T1<!65K!65M#UU8!65J!6I'!6I!
M!6I%!6I"!6I#!&%R!6I&!6I$!6I)!&%Q!TM0!TM5!TM1!6I(!TM3#V1.!TM7
M!TM6!TM4!TM2!TM8!U$N!&1T!U$V!&1V!6Y$!&=M!&1X!U$T!U$S!6Y%!&1Z
M!&1W!&1Y!U$O!U$Q!U$R#V9U!U$U!U$W!U$P!U$M!&=J!&=I!U5X!7%>!7%?
M!&=K!&=L!U5Z!7%@!7%A!U5]!U5Y!U5^!U5[!71<!71?!&E9!UEX!71=!UEY
M!UEZ!71:!71>!71;!UEW!79B!UT[!UT\#VLS!79C!7A$!&PR!&PQ!U]]!U]^
M!V`A#VMP!&TL!7E6!&TK!7E5!V%;!7E7!7I$!V)[!7I#!V)\#VQ9!V,C!7I"
M!V1L!&X^!V5+!V5*!V5,!7ML!V8M!V9.!V91!&Y<!#8F!E`T#T8N#T8O#T8P
M!EE]!$@V!RQ$!S4]!5IT!T1F#V1/!7%B#VMQ!CQT!BY)!CQS!#8G!D8T!#8I
M#SDM!E`U!3U"!#MU!E`W!E`V#T`H#T`I!EHA!EE^#TT[!$Y-!RIN!RIM!S4^
M!U$X!U$Y!E`Y!E`Z!E`X!$%9!$%;!40H!40G!EHC!EHB!F0B!4LE!$@Y!F0A
M!4LD#TT\!F0C!$Y.!5)&!5)(!5)'!RIP!RIO#UAW!5E0!5E/!5E4!5E1!5E2
M!5E3#UAV!S4_!SU/!5]?!5]@!5]B!5]A#UU;!SU1!65R!T1G!65P!65Q!%XY
M!6I+!6I*!6Y'!6Y&!TU0!U$Z!6Q&!7%D!U8B!7%F!7%E#VAY!U8A!U8D!U8C
M!UE[!UE\!UT]!79D#VLT!V`B!7I%!V0A!V1N!V1M#SDN!3U#!#MX!E`[!40L
M!40K!EHF!EHI!40J!EHG!40I!EHE!EHK!EHJ!$%<!$%>#T8Q!4LG!$@\!4LF
M!F0G!F0E!4LH!4LI!$@^!4LL!4LJ!4LM!4LK!F0I!$@_!F0H!F0D!F0F!RIS
M!5))!RIW!RIV!$Y1!RIY!5)*!$Y2!RIU!$Y3!5)-!$Y0!5),!5).!RIT!5)+
M!RIX!RIR!S5$!5E5!5E8!%1F!%1>!%1E!5E6!5E7!S5#!S5'!S5`!S5!!S5%
M!S5&!SU8!SU:!5]C!5]I!%EF!5]E!SU3!%EG!S5"!5]M!SU7!%EE!SU9!5]G
M!5]J!SU5!5]K!SU;!S5(!5]H!SU4!SU<#UU<!SU2!5]L!5]F!%Y$!65\!65T
M!%XZ!65V!68B!T1J!T1H!%X_!65W!%Y`!T1M!T1P!68A!T1O!%X]!68C!T1Q
M!T1R!T1N#V%3#V%4!5]D!T1L!T1K!65X!68D!T1I!65U!65Z!65Y!65]!&%Z
M!6I1!6I4!6I/!&%Y!6I-!TM:!6I5!TMC!6I.!&%X!TMA!&%V!TM>!&%U!TMB
M!6I0!TM@#V10#V12#V13!TM;!TM<!6I3!6I2!TM9!6I,!&4D!6Y.!&1]!6Y/
M!6Y*!U$[!6Y(!U$]!&4A!6Y,!&4B!&4E!6Y-!U%!!U$\#V9X!U$^!U%#!U%`
M!6Y+!U$_!6Y0!&4F!U%"!7%M!U8H!&=O!U8J!U8K!7%J!7%K!7%L!7%G!7%H
M!U8I#V9W!71@!UHF!UE]!&E=!71A!UHE!UHC!UE^!UHD!71C!71D!UHA!UHB
M!71E!79E!79H!79F!UT^!79I!79G!UU!!UT_!UU"!UU`!7A&!7E8!V`C!7A%
M!7A'!V%>!V%<!V%=!7I&!V)^!V,B!7E9!V,A!V)]!7LB!V1P!V1O!7M,!V5I
M!7PU!V8N!V8Y!V8X!7Q,!3U$!$%@!$%B!EHL!40M!F0K!4LO!4LQ!4LN!4LP
M!F0J#TT]!4LR!$Y5!5)0!$Y4!$Y6!RI[!RIZ!RI\!RI]!RI^!5)/!5)1!5E9
M!S5)!S5*!5E<!5E=!5E;!S5+!5E:!%EI!SU>!5]N!SU?!%EL!%EJ!5]O!5]P
M#UU=!SU=!SU@!T1V!T1S!%Y&!T1T!SUA!68E!T1X!T1U!TMD!TMF!TMI!TME
M!TMH!TMG!U%$!6I6!6I7!U%%!U%&!&4H#V9Y!6Y2!6Y1!7%N!7%P!7%R!&=T
M!U8L!7%O!7%Q!UHG!&E?!71F!UHH!UHI!71G!UU#!UU&!UU%!UU$!&PU!V%?
M!7I'!V0D!V0B!V0C!7M-!7MM!7PB!40N!EHM!5)2!S5,!%EM!SUB!TML!U%(
M!&4K!7%S!U%'!U8M!UHJ!UU(!UU'!V%@#T`L!40P!40O!4LS!$A%!4LT!5):
M!RLA!5)4!5)7!RLB!5)5!5)6!5)9!5)3!%1K!5)8#UAY!5E>!S5-!SUC!5]Q
M!5]R!68F!68G!68H!&(A!6I8!6I9!U%)!U%*!6Y4!6Y3!6Y5!U8N!7%T!68I
M!71H!71I!&EA#VHS!UU*!&PV!7LC!7P_!C1[!D8U!39&!3U*!3U(!3U)!3U&
M!#M]!3U%!#M\!E`\!#MZ!$%L!40Z!$%K!40Q!40Y!EHO!$%I!4L[!40W!$%F
M!$%G!$%J!EHR!40V!40R!EHP!EHQ!EHN#T8S!40S!40X!4L]!F0Q!F0R!4LW
M!4M$!4LX!$A)!$A(!4LZ!4LV!$A/!4M"!4LY!RLK!4M#!F0U!F0S!F0N!4L\
M!4M!#TT^!F0M!4M`!F0L!F0V!4LU!F0O!F0T!5)=!$Y;!RLE!RLP!5)<!5);
M!$Y8!RLD!RLJ!$A*!RLN!5)>!$Y>!RLM!RLI!S5/!RLL#U,C#U,D!RLG!RLH
M!RLO!RLQ!RLC!RLF!5)?!%1L!5EA!%1N!5EI!S58!5EH!5EF!S59!S57!5EE
M!5EC!S5;!S50!5EJ!5EB!5EK!5ED!5EG!%1Q!S5.!5E@!S5:!%1R!S56!S5<
M#TU`#UAZ#UA\#UA]#UDA#UDB#UDC!S52!S53!S54!S55!5EL!5E?#UA^!5EM
M!%EU!%EQ!%EN!SUE!5]W!%EY!5]X!%ET!5]V!5]S!5]U!%EO!5][!SUJ!%ER
M!SUL!5]T!SUG!%EX!SUK#UU>#UU?#UU@#UUA#UUB#UUC!SUD!SUF!5]Y!5]Z
M!SUH!SUM!68J!%Y*!68P!68N!&(D!68M!68K!T1[!68L!%Y(!68Q!68O!T1\
M#V%5#V%6#V%7#V%8!T1Y!T1Z!TMV!6I=!TMP!TMM!6I>!&(N!TMR!6I<!6Y6
M!6I;!6I:!TMT!TMO!&(J!TMN!TMU!TMQ#V14#V15!TMW!TMS!&4N!&4M!6Y;
M!6Y9!U%.!6Y:!&4R!U%-!&4S!6Y8!U%+!U%/#V9Z!&4T!U%0!U%,!6Y7!U!,
M!7%U!7%V!U8O!7%X!U8X!UHQ!&=Z!&=X!U8S!U8Q!U8V!7%W!7%Y!7%Z!U8P
M!U8T#VAZ#VA[#VA\!U8W!U8U!UHP!71L!71K!UHM!UHO!71J#VHT!UHK!UHN
M!UHL!UU2!UU1!UU/!79L!79M!&LN!79J!UU-!&LO!UU.#VLU!UU0!UU,!UU+
M!&PX!V`D!79K!&PW#VMR!V`E!&TN!7E:!7I(!V,D!7I)!V,E!V,F!&XC!V0E
M!V5-!D8V!E`_!#PA!E`]!3U+#T`N!E`^!40[!41`!$%O!40]!40^!EHT!EHV
M!40\!$%P!EHU!E,S!40_!EHW!$A8!4M(!$A5!4M'!4M&!4M%!$A3!F0W!$A2
M!F0[!F0Y!F0X!$Y?!5)B!$YB!RLT!RLS!RLR!5)A!RLU#U,E#U,F!5EO!5EW
M!5EP!S5=!S5@!5EN!5ES!5EV!S5?!S5A!5ET!5EU!S5>#UDE!5ER!5EQ!SUQ
M!%HE!6`E!6`F!%E[!5]\!SUP!%HD!68R!6`B!%HC!5]^!6`A!6`D!5]]!6`C
M!SUN#UUD#UUE!SUR!SUO!%Y3!T4B!T4D!68W!T4F!68T!68X!%Y4!68Z!&(Q
M!68U!T4E!68V!68Y!68S#V%9!T4H!T4C!T4A!T4G!T1]!6I?!&(S!&(T!&(U
M!6I@!TMY#V16#V17!TMX!TMZ!TM[!TM\!6Y>!6YA!6Y@!&4U!6Y<!&4W!6Y?
M#V9[!6YB!6Y=!&4X!U9`!&=]!&@A!7%[!U8Y!7%\!U8\!U8Z#VA]!U8_!U9!
M!U9"!U8]!U8^!U8[!UHR#VHU!UHS!UU3!7A)!&P[!V`F!V`G!7E;!V%A!7E<
M!&TO!&UF!7I*!7LD!V0F#VTD!7Q'!V95!CQU!4`Y!RLV!TM]!6IA!U9#!&ED
M!71M!C1\!C1]!C4B!C1^!3!Q!CQV!CQX!3U,!39*!39'!D8Z!D8X!39)!D8Y
M!D8[!E!`!39(!E!!!E!&!#PB!3U-!E!$!E!%!#PF!3U.!EHX!3U/!E!"#T`O
M!E!#!#PC!EI"!EHY!41"!41$!41!!41'!$%V!41#!F1#!41%!EH\!EH[!F0]
M!$%S!EHZ!F0^!EH^!41(!EI!!5)C#T8W!EI`!EH_!F0\!$%X!41&!F0_!RLW
M!F1$!4M-!4M)!F1%!4M*!$A:!F1"!4M+!RLY!F1!#T8V#U,H!RLZ!$YK!RM`
M!$YJ!5)I!5)D!5EY!$YH!5)F!5)K!5)H!$YL!5)J!RL\!5)E!RL[!SUS!5)G
M!RL^!RL]#U,G!5EX!RL_!5HC!%HF!5HD!%1[!S5F!S5J!6`G!5E[!S5I!5E^
M!S5G!5E\!S5O!%1Y!S5K!S5P!5HE!S5H!S5C!5EZ!S5E!S5D!S5L!6`I!S5N
M!SUU!S5B!5HB!S5M!5E]#UDF#UDG#UDH#UDI!5HA!SUT!6`H!6`T!SUW!6`M
M!6`O!6`S!6`K!SUV!6`R!6`U!%HK!6`V!SUX!SU]!T4J!SUZ!6`J!T4K!SXA
M!6`N!SUY!SU^#UUF#UUG!SU[!6`P!SU\!T4O!68_!68[!%Y6!%Y<!6`X!%Y=
M!68]!6`W!68\!T4N!T4M!TM^!%Y>!68^!TPB!U%4!T4L!T4I!T4Q#V%:#V%;
M!TPE!TPA!%Y5!T4R!T4P!6ID!TPC!6IB!&([!&4]!U%3!6II!6IF!6IH!6IJ
M!U%1!&(W!6IG!6`Y!6IC!U%2!&(Y!U%8!TPD!U%7!&(Z#V18#V19!6IE!U%6
M!6IK!&4^!U%5!U%9!U%?!U9$!7%]!U%@!6YE!&4_!7%^!6YD!U%>!U%B!6YC
M!TPG!U%A!U%;!U%<!U%=!U9%!U%C!U%:!7(H!7(B!U9&!&@E!7(D!7(A!U9'
M!7(K!U9(!7(J!7(C!7(G!7(E!U9)!7(F!7(I#VA^!&EF!71N!71O!UHW!UU4
M!UHV!71P!UHU#VHW!UHT!79N!UU6!79O!79P!7A*!UU5!7A+!7A,!&P\!V`H
M!V`J!V`I!7E=!V0G!7LE!CQY!D8\!F1&!RM!!F1(!F1'!5)L!%4D!%4E!SXB
M!SXC!S5Q!S5S!S5R!TPI!TPH!T4S!TUS!U%D!V`K!&XF#S)Q!$%\!EI#!4=4
M!F1)!F1*#TU!#U,I!F1+!RM"#U,J#UDJ!S5T#UUH!SXD!T4V!69!!69`!69"
M!T4U!T4T!6IL!&(]!&(^!TPJ!U%E#V9\!7(L#VDA!U9*!UU7!7I+!39+!39,
M!3U0!E!(#T`Q!E!'!41)!EI%!EI$!EI'!EI&!4M1!F1-!F1.!4M0!$AA!F1,
M!F12!4M/!RM##TU"#TU##TU$#TU%!RM&!F1/!F11!4M2!RM*!5)R!RM.!RM'
M!5HR!5)T!5)W!5)M!5)P!5)N!5)U!RM$!5)V!RM(!5)S!RM+!RM)!5)O!RM%
M!RM,!5)Q#U,K#U,L#U,M!RM-!S5Z!%4L!S5Y!5HO!%4J!%4G!%4K!%4H!S5U
M!5HI!%4I!5HP!5HM!S8D!5HS!5HG!5HQ!5HT!5HK!S5\!S5[!S8F!S8A!S5X
M!S8C!5HJ!S8B#UDL!5HH!S5]!S5^!S8G!S8E#UDK!S5V!S5W!6`Z!SXL!6`[
M!SXF!%HO!SXG!SXE!6`\!%HL!SXJ!SXK!4M3!SXH!6`^!6`]#UUI#UUJ!T4\
M!69,!69+!69'!%YD!69)!69(!%YA!69%!69.!%YM!%YI!%YJ!%YF!69/!69#
M!%YL!T4[!T4Z!T4W!69*#V%=#V%>#V%@!%YK#V%<!T4X!69$!T4Y!69-!6IM
M!6IS!6IO!&)#!TPQ!690!TPL!69&!6IQ!6IP!6IT!TPK!6IR!6IV!&)"!6IW
M!TPR!TPT!6IU!TPS!TPM!TPN!TPO#V1;#V1<#V1=!TPP`U<V!TPU!&5%!U%J
M!U%I!6YN!6YI!6YK!6YH!&5"!6YP#V9]!&5#!&5$!&5(!6YQ!6YR!6YG!U%H
M!&@F!6YJ!6YO!6YL!U%K!U%O!U%P!U%Q!U%M!U%L#V9^#V<A!U%G!U%N!U(G
M!U%F!7(O!7(N!7(Q!&@G!7(R!7(P!&@L!U9-!U9,!U9.!U9+#VDB!U9/!U90
M!71X!UH]!7(T!UI!!UHX!71Q!UH[!7(S!71T!71W!71S!UI`!&EL!71U!UHY
M!UHZ!UH\#VHX#VHY#VHZ!71R!71Y!UH_!UU?!UU=!79Q!7A.!UU<!UU9!79R
M!UU:!UU>!UU;!UU@#VLX#VLY!UU8!7A/!V`Q!V`T!7A-!V`S!V`V!V`U!V`O
M!V`P!V`L!V`R!7EB!V%C!7EC!7E?!&TQ!7E@!V%B!7E>!7EA!&TR!V%D!7I,
M!7I-!&XG!V0I!V0H!&Y`!V1R!V1S!V1Q!V5.!7PC!V5J!V5Z!V5[!V9$!3U1
M!#PG!EI)!EI*!EI(!EI+!$AC!$AE!4M5!F18!4M4!$AD!F16!F13!F14!F15
M!F17!$YR!$YQ!5)Z!5)Y!RM2!S8L!5)X!5)[!$YW!RM0!RM4!RM1!$YX!RM3
M!5HV!5HU!%4S!S8K!RM/!S8J!S8I!SXN!%HT!SXR!%HR!SXS!6`_!SXQ!SXM
M!SXO!SXP!699!T4^!%YO!T4]!697!T4_!692!6IX!695!693!696!698!SXT
M!694!TP[!6IZ!6IY!TPZ!TPW!6I\!6I]!6I[!TP]!TP^!TPY!TPX!TP\!TPV
M!&5*!6YU!6YT!6YS!U%S!U%T!U%U!&@O!7(V!U97!&@N!7(U!7(W!U93!U94
M!7(X!U95#VDC!U96!U92!&EM!UI"!&EP!UI#!&EO!UI$!UUE!UUF!79S!&LV
M!79U!&LW!UUB!79T!UUG!UUA!UUC!UUD!&P_!7A0!&TT!V%E#VLZ!V,G!7I.
M!V,H!V0J!V1T!7MN!$(C!$AF!49D!4M6!F1:#TU&#TU'#TU(!F19!RM6#U,N
M#U,O!S8N!S8M#UDM#UDN!%HV!6!`#UUK#UUL!T5`#V%A#V%B!TP_#V1?!6YV
M#V<B#V<C#V<D#V<E!&@Q!U98!UI%!UUH!UUI!UUJ!V`W#VMS!V%F!V%G!V,I
M!V0K!&XH!V5\!E!)!E!*!EI-!EI,#T8Z#T!I!$AH!4M8!F1@!F1?!F1=!F1A
M!F1;!F1<!4M7!4M:!5)^!RM7!RM:!$Y^!RM8!5,D!$\B!RM;!5,C!$Y\!$Y]
M!5)\!$YZ!5)]!5,B!5,A!RM<!RM9#U,P#U,Q#U,R#U,S!S8O!%4W!S8Q!5HZ
M!S8P!%4Y!%4T!%4[!5HW!5HY!%4Z!%4X!S8S!5HX#UDO#UDP#UDQ#UDS!S8R
M!%HZ!%H\!SXZ!6!!!6!$!6!"!SXX!6!%!6!&!6!#!SXU!%HY!SXV#UUM#UUN
M#UUO!SXW!SXY!SX[!T5"!69>!%YQ!69<!69@!69?!T5$!69A!TQ`!T5#!%YR
M!69:!%YX!69;#V%C#V%E!69=!T5!#V%D!&)-!TQ#!TQ'!6I^!6LA!6LC!&)0
M!TQ(!TQ&!TQ!!6LD!6LB!TQ%!TQ"!&)+!TQ$#V1@#V1A#V1C!6Y\!U%V!6YW
M!6Y[!6YZ!6YY!&50!&5,!6Y^!6YX!&5+!U%W!U%X!U%[!U%\#V<F#V<G#V<H
M!6Y]!7([!7(^!7(Z!U99!&@R!&@T!7(Y!&@S!7(]!U9:!7(\!U9>#VDD!U9;
M!U9<!74A!71\!UI&!74B!71^!71[!74E!74D!74C!71]!74F!U9=!&ES!UI'
M!UI(#VH[#VH\!79W!&LX!&LY!79V!UUL!UUM!UUK#VL[!&Q`!V`X!7A1!&Q$
M!&Q"!7EE!V%H!7ED!&TV#VQ"#VQ#!V%I!7I/!V,J!V,K!V0L!&XI!7LF#VQR
M!V1W!V1V!7M.!&Y4!B,]!B,\!41+!4M;!4M<!F1B!RM=!S8T!SX\!T5%!%YY
M!U%^!U9?!7)`!UI)!V`Z!V`Y!7A3!7M/!RM>!$\C!%4\!T5&!U(A!U9A!U9@
M!UI*!UUN#VQS!7M0!$(D!EI.!F1D!F1C!RM?!S8X!%4^!5H[!S8V!S8U!%4]
M!S8W!6!'!SX]!%YZ!T5(!T5)!T5'!TQ)!6LE!TQ*!&51!U(D!U(C!U(B!U(E
M!U9B!&@U!U9D!7)"!U9C!U9E!U9F!74G!UI,!UUQ!UUR!79X!&EU!&LZ!UUP
M!79Y!UUO!UUS!&Q&!&Q%!UUT!V`[!V%K!V%L!7I0!V,L!V,M!V,N!&XJ!V0M
M!V1Y!V1X!V1Z!V5/!7PD!&Y1!7PM!V5]!V9*!V9+!E!+!3U3!EI2!41.!EI1
M!$(F!41,!EI0!41-!$(E!EI/#SDP#SDO!EI3!4M?!4M@!4MA!4M>!4M=!4MB
M!F1H!F1E!F1I#TU)#TU*#TU+!F1K!F1F!F1N!F1L!F1M!F1J!F1G!$\G!5,I
M!RMA!RM@!5,H!5,K!5I!!5,J!$\F!RMC!5,E#U,T#U,U#U,V!5,G!RMB!5,F
M!5H\!S8Z!5I%!5I#!S8Y!%5`!5I$!S8[#UDT!5H^!5H]!5H_!5I"!S8\!5I`
M!%H]!6!)!6!,!6!0!%H^!SX^!6!(!6!*!6!/!6!-!SY`!SY!!SY##UUP#UUQ
M#UUR!6!.!SX_!SY"!6!+!69C!T5+!%Y[!69I!T5.!69G!69E!T5/!T5,#V%G
M!T5*!T51!69B!T5-!T50!69F!6LF!6LI!TQ+!6LG!TQ,!TQ-#V1D#V1E#V1F
M#V1G!69D!6LH!U(K!&52!U(J!6\A!U(I!U(H!6\B!U(F#V<I!7)$!7)&!7)(
M!&@W!U9G!U9H#VDE!7)%!7)#!U9I!7)'!74J!&)1!UI0!&EX!74H!UI.!&EY
M!74K#VH]!74L!74I!&EZ#V<J!UI-!79[!79Z#VDF!7A4!7A5!&Q'!V`_!V`^
M!V!`!V`]!7EG!7EF#VQ$!V,O!&XK!V0N!V0O!&Y!!7M1!7MO!7PE!7Q`!#!#
M!$(J!$(G!EI5!$(H!EI6!41/#T8[!F1O!4ME!$AL!4MC#TU,#TU-!4MF!$\O
M!$\S!$\Q!$\M!RMH!5,Q!5,P!RME!RMD!5,N!$\X!5,S!5,L!5,M!RML!RMF
M!$\V!5,R#U,W#U,Z#U,]!RMK!RMG!RMI!$\N#U,Y!5,O!5I(!5I&!S8]!5I)
M!%5&!%I&!5I.!5I-!%5)!S9#!S8^!S9!!S9`!5I,!S9$#UDV#UDW#UDY#UDZ
M!5I+!S9"#UDU!5I'!S8_!6!6!%I(!6!7!6!4!6!2!%I'!SY+!6!5!SY&!SY-
M!SY%!%I+!SY,!6!:!6!8!SY$!%I*#T8\#UUS#UUT#UUU#UUW#UUY!SY(!6!;
M!6!3!SY*!6!1!6!9!69W!69T!69P!69K!T53!%\H!69M!T52!69J!69Q!69U
M!69R!69O!69L!T54#V%H#V%I#V%J#V%K#V%L#V%M#V%N#V%O#V%Q#V%S!T55
M!SY'!69V!69S!TQ;!TQ8!&)>!TQ2!6LM!&)2!6LO!TQ/!TQ1!&)?!69X!&)C
M!6LR!&);!TQ.!&):!&)E!TQ:!TQ3!TQ9!&)8!TQ5!6LV!6LN!TQ0!6LT#V1N
M#V1H#V1J#V1L#V1O#V1P#V1Q!6LP!TQ4!TQ7!&)3!6LW!6LJ#V1I!6LL#V%P
M!TQ6!6\G!U(N!6\F!6LX!6\I!U(L!&58!6\K!U(O!U(M!6\H!&56!6\D!U(R
M!&5>!6\E!6\C!&5@!U(P!6\L!U(T#V<K#V<L#V<M#V<O#V<P#V<Q#V<R#V<N
M!6\J#V<T!7)*!&@_!7)/!7)3!7<C!7))!7)2!&@X!U9Q!7),!U9R!7)7!U9M
M!7)4!7)-!U9S!U9U!U9J!U9T!7)6!U9N!U9O#VDH#VDI#VDK#VDL#VDM#VDN
M#VDO#VDP#VDQ#VDR!U9K!U9L!7)5!U9P!7)0!UI4!UI2!74R!&HB!74N!74O
M!UI:!UI7!74P!UI<!UI9!74T!UI6!UI;!UI3!UI5!UI1!UI>#VI!#VI"#VI#
M#VI`!UI?!74S!UI8!UI=!74Q!79^!UUX!7<B!&L^!&L_!79\!UUW!&5<!V!&
M!UUU!UXB!UUV!79]!UXA!UU\!7<A!UUY#VL]#VL_!UUZ!UU]!UU^!UU[#VL\
M!V!#!7A<!7A@!7A:!V!!!&Q/!&Q,!7A9!7AA!&Q+!7A?!7A>!7A7!V!+!V!'
M!7A8#VMU#VMX!V!(!V!"!V!$!V!%!7A=!V!*!V!)!V%S!7EH!&TX!7EI!V%N
M!V!Z!V%Q!V%O!7EK!V%R!V%P#VQ%#VQ&!7EJ!V%M!V,U!V,P!V,R!V,S!V,T
M!7I1!7I2#VQ:#VQ;#VQ<#VQ=!V,Q!7LH!7LG!V0P!7LI#VQT!V0Q!7LJ!V0R
M!V1^!7M3!7M2!7M5!V1\!V4A!V1[!7M4!V1]#VQU!7MS!7MR!7MQ!7MP!V50
M!7PF#VTK#VTL!7PG!V5K!7PN!7PW!V8O!7PV#U,\#UUX#VL^!E!,#T`S!E!-
M!$(K!EI7!411!412!EI<!EI8!EI9!410!EI:!EI;!F1P!4MJ!F1Q!4MI!$AN
M!$AO!F1R!F1S!F1T!$AP!4MH#TU/#TU0#TU1!4MG!$]%!RMR!RM]!RMO!RMS
M!RMY!5,W!5,[!5,]!5,Y!RMV!RM\!5,_!5,T!$\]!5-!!5,^!5,U!$\^!5-"
M!RMZ!$\\!RMU!$]#!$\Z!5-#!$]&!RMP!RM[#U-`!RMN!RMW!RMX!5,V!5,Z
M!5-`!RMQ!RMT!5,\!S9+!5I4!5I6!5I1!5I/!%5,!5I3!5I9!5I2!S97!S92
M!5I7!%56!S94!5I8!S90!5I5!S93!S9,!S9%!S9.#UD]#UD^#UD_#UE`!S9-
M!S9/!S98!S96!S9'!S9(!S95!%53!%51!E!.!S9)!5I0!S9&#U8S!SY1!%I,
M!6!>!6!I!SY4!%I3!6!G!SY5!6!=!6!A!SY.!6!D!6!K!6!@!6!B!%I4!SY7
M!6!<!6!C!%I8!SY/!%I;!6!L!SY8!SY3!6!H!6!J#UUZ#UU[#UU\#UU]#UXA
M#UXB#UXC#UXE!SY0!6!?!%I:!SY6!6!E!6!F!SY2!%I7!T5;!6!M!T5?!69]
M!6<E!6<G!%\N!6<J!69Z!6<A!69^!69[!T5=!T58!%\M!T5>!69\!6<K!%\P
M!T5G!6<B!T5D!T5<!6<H!T5A!T5B!T5F!6<D!T59!6<C!T5H!T56!T5@#V%T
M#V%U!T57!6<I!T5C!6LY!TQ=!6LZ!TQB!6L^!6M*!6M`!TQJ!TQD!6L[!TQH
M!TQK!TQC!6M,!6L]!6M+!&)K!6M"!6M%!TQ@!TQ>!6M(!6M$!TQ<!TQF!TQL
M!6M!!&)M!TQI!6M&#V1T#V1V#V1W!TQA!6M'!TQO!6M)!T5I!TQE!TQG!TQM
M!6M#!TQN!TQ?!&)I!6\X!6\P!U(Z!&5E!6\^!U)#!6\R!6]"!&)P!U(V!6\O
M!&5C!6\Q!&5N!&5H!6\S!6\M!6\W!6]$!6\Y!&5M!&5F!6\Z!6\\!6]`!&5G
M!6\N!6\[!6\V!6\_!U(_!U([!U)`!U(U!U(W!6\]!6\U!6\T!6]#!U(X#V<W
M!U(^!U(]!U(Y!U)$!U)!!U(\#V<X!6]!!T5:!7)>!U9Y!7)F!U9^!7)=!7)@
M!7);!7)E!7)D!U<A!U9]!U9Z!7)H!U<G!U<F!U<D!7)<!7)A!6]%!7):!7)B
M!U<B!U9\!7)I!7)J#VDT!7)?!U<C!U9W!U<H!U9V!U9[#VDS!7)8!U9X!7)9
M#V<V!75"!74]!&HD!&HM!74\!&HH!75#!74Y!6]&!75$!75`!74_!&HK!UIB
M!UIL!UIJ!UIP!&HJ!UIK!UIN!74[!&HI!UII!74W!UIH!74X!75&!7)G!UIQ
M!75!!UIO!UIG!U<E#VI$#VI%#VI&#VI'#VI(!74^!UIF!UID!UIA!UIC!74Z
M!UXK!UXG!UXQ!7<S!UXO!7<N!7<I!&M#!UXR!UXV!7<E!7<P!7<J!7<H!7<O
M!UXL!7<G!7<F!7<X!7<K!&M)!&M"!UXU!7<Q!UXP!UXS!7<M!UIE!7<U!UIM
M!UXT!7<V!UXM#VM`!UXD!UXF!UXN!UXI!UXH!7<R!UXJ!UXE!&M!#VMZ!UXW
M!V!-!7AG!7AI!7AM!7AE!7<W!7AH!V!.!7AJ!7AK!V!/!V!0!V!4!7AL!V!3
M!V!,!V!1!7AC!7AF!7AB#VMY!V!2!&Q5!7AD!&Q3!7EQ!7EM!7EP!V%V!&T[
M!7EN!7EL!&T\!V%T!7EO!V%X!V%U!V%W!&T^!7I8!V,Y!7I6!&UK!7I:!7I9
M!7I5!7I7!&UJ!V,X!7I4!V,[!7I;!V,]#VQ>!V,Z!V,V!V,\!7LN!V0T!V0V
M!7LO!7LL!7LK!7LQ!7LP!7LM!V0W#VQV!&XN!V0S!V0U!7M6!V4B!V53!V4D
M!V4F!V4C!V4G!7M7!V4E!&Y"!7MT!V54!V55!7MU!V52!V56!V51!V5M!V5L
M!7PI!7PH#VTR!7PO!V8A!V5^!7PX!V8P!7PY!V8Z!7Q!#VTW!7Q(!V9%!$AQ
M!$AR!5-$!RPB!RPA!RM^!5I:!5I<!S9:!S9;#UE!!S99!6<L!SY9!&)Q!TQP
M!6M-!TQQ!U)&!6](!6])!U)'!6]'!U))!U)(!&A%!U<K!U<J!7)K!UIS!UIR
M!&M,!UXX!UXY!7<Y!V!5!&Q7!7ER!&T_!V,^!7LR!EI=#T8]!4ML#TU2!RPH
M!5-%!RPG!RPF!RPD!5-&!RPE!5-'!RPI!RPC!S9=!5I=#UE"#UE##UE$!6!O
M!6!R!6!P!%I<!6!S!6!Q!SY;!SY:!SY>!SY=#UXF!6!N!T5N!6<Q!6<N!6<M
M!T5K!T5M!T5J!6<P!T5L#V%X#V%Y#V%Z!6<O!6M/!6M.!6M1!&)S!TQS!6M0
M!TQR!6A`!U)+!&)T!&5O!TQT#V<Y!U)*!U),!6]*!&A'!U<L!U<M!&A&#VDU
M!75'!&HN#VI)!7<Z!7<\!7<[!UXZ!UX[!V!6!&Q8!V!7#VM[!7EU!7ET!7AN
M!&U`!&UL#VQ'!V4H!V57!7Q&!V9'!EI?!EI>!413#T8_!$AU!F1U#TU3!5-+
M!5-*!$]/!5-)!5-(!RPK!RPO!RPJ!$].!RPL!5-,!RPN!RPM!S9A!S9?!S9>
M!S9C!%5;!S9B!D=3#UE%!5I>!S9@!6!T!6!U!SY@!SYA#UXH!SYB!SY?!T5P
M!6<R!T5R!6<S!6<U!T5S!6<T#V%[!T5Q!T5O!&)Z!&)X!TQY!TQ[!TQU!6M4
M!6M2!TQZ!6M5!6M3!TQX!&)[!TQW!TQV!6]+!U)3!U)2!6],!U)0!&5P!U)/
M!6].!6]-!U)1#V<Z!U).!U)-!7)L!U<O!7)O!U<P!7)N!U<Q!U<N!7)M!75+
M!75,!UIT!75)!75.!UI[!UIV!UIW!UI\!UIY!75*!UIU!UIX!UIZ!7<_!&M/
M!7<^!7=`!7<]!7AO!7AQ!7AP!V!9!UX\!&Q9!V!8!&UM!V,_!V0Y!V0X!7M8
M!V4I!&Y2!7PP#RDA#T8^#U-"#UXG!4MP!4MN!4MO!5-.!$]0!5--!RPP!5IA
M!S9D!5I?!5I@#UE&!6!X!6!V#UXI!6!W!6<V!TQ\!6M6!TQ]!&5S!U<R!7)P
M!UI^!&M0!UM6!UX]!&M1!7PQ#TU4!RPR!5IB!5ID!5IC!6!Z!6<X!6!Y!6<Y
M!6<W!6M7!&,B#V1Y!&5U!&5T!6]0!6]/!&5W!U)4!U)5!U)6#V<[!U)7!7)S
M!7)R!7)Q!U<S!U<T!75/!&HO!&HP!ULC!ULB!ULA!UX^!7AR!V!:!7AS!V%Y
M!7EV!V8G!$AV!5-/!$]1!S9H!S9F!5IF!5IE!5IG!6!^!SYD!6!\!SYC!6![
M!%I>!6!]!SYE!SYF!6<[!6<Z!&5X!6]1!6]3!7)T!U<V!U<U#VDV!750!&M4
M!7="!7=!!&M3!V-`!V%Z!&UN!7M:!V4J!7M9!F1V!414!F1X!F1W!RPT!$]5
M!$]4!5-0!RPU!RPV!S9J!5IJ!5IH!5II!S9I!S9K!S9L!%I@!SYH!6$A#UXJ
M!SYG!6<^!6<\!T5T!6M8!6$B!6<_!6M:!6M9!6M;!6M=!6M<!TTA!TQ^!6]6
M!6]7!U);!6];!6]9!6]5!U)8!&5^!&5[!U)<!6]:!&5Z!U):#V<\!U)9!U<X
M!&A3!&A1!7)X!&A0!7)[!U<W!7)U!7)Y!7)W!&A4!7)V!&A5!&HT!U<Y!U<Z
M!7)Z!751!&HS!&HU!ULJ!ULG!ULF!&HR!ULI!ULH!752!ULE!7='!UY!!7=&
M!7=$!7=%!7=#!7=(!UX_!7AV!7AW!V!=!&Q<!&Q@!7AU!V!<!7AT!&Q?!&Q>
M!&Q=!UY`!V!;!7EX!7EY!7EZ!7EW!&U%!V%[!V%\!&U&!7I<!V0Z!V4K!&XP
M!V0[!7LS!&XO!7M;!7M<!V4L!&Y*!7MV!V5N!7Q*!V92!T5U!&8B!7)\!&A7
M!7=)!F1Y!RPX!RPW!6$D!S9M!%IA!SYI!SYJ!T5X!6="!T5Y!T5W!T5V!%]!
M!TTD!TTE!SYK!TTC!U)>!U)?!U)=!7)]!U<[!&HV!ULL!ULQ!ULR!ULN!ULP
M!ULM!ULK!ULO!7=*!UY"!7AX!7E[!7I=!&U'!V-!!7LT!V-"!V4M!E!/!S9N
M!S9O!5IK!T9/!V4N!5IL!6$E!SYM!6=#!T5Z!6=$#V%]!TTG!6M@!TTF!6M>
M!6M?!&,E!&8C!U)@!&HY!&A8!U<\!U<]!753!ULT!ULU!755!&HX!ULS!754
M!UY#!V!>!7AY!V!?!7E\!V-#!7LU!7MW!RPY!5IM!SYN!5IN!6$H!6$J!6$K
M!6$I!6$G!SYP!6$F!SYO!6$L!%IB!T5\!TTL!6='!6=(!6=&!6=%!T5[!TTJ
M!6MA!6MC!6MB!TTM!TTN!TTI!U)B!U)D!U)C!6]=!6]>!TTK!U)E!6]<!U)A
M!7,A!7)^!U<^!757!ULV!758!759!756!&HZ!UY$!7=+!&M9!UY(!&M7!&M:
M!UY'!UY&!UY%!7A]!&QC!7A[!7AZ!V!@!V%^!V%]!&U)!7E]!7LV!7MY!7MX
M!V5O!V8B!$]7!S9P!S9Q!SYR!SYQ!6=)!T5^!T8A!T5]!6MD!6ME!U)F!6]?
M!6]@!U)H!&A;!7,B!U<_!U=`!7,C!7,D!ULW!7=,!UY)!7A\#VM^!V!A!7E^
M!7HA!V-&!7I>!V-%!V0\!&Y3!7PR#T`T!%5D!%IE!T8B!&,H!TTO!6U7!&8D
M!&H[#VDW!7HC!7HB!V(A!V4O!6$N!SYS!T8E!%]'!T8D!TTP!6MF!&,J!TTQ
M!TTT!TTR!TTS!TTU!TTV!6MG!U)K!6]C!6]B!&8H!U)I!&8J!U)M!&8I!U)N
M!U)J!$AX!U)L!U=&!7,J!7,G!U=#!U="!&A>!7,H!&A?!&A=!U=$!7,E!7,K
M!U=%!U='!7,I!U=!!7,F!ULX!&H^!75<!75;!75>!UM`!UL_!75?!ULZ!75@
M!&H_!ULY!75:!UL[!UL]!UL^!UL\!75=!7=/!7=.!&M>!&MB!&MC!&M?!&M@
M!7=0!UY.!UY,!&M=!UY*!UY+!UY/!&MD!&QG!7A^!V!G!&QH!V!E!7DA!V(C
M!&QE!V!C!V!F!V!D!V!B!V!H!7DB!&U.!&U*!V(E!7HF!&U0!&U-!7HD!V(G
M!&U/!V(D!V(F!V(H!V(I!V(B!7HE!V-(!7I@!V-'!7IB!7I?!7IA!V0^!&XR
M!V0]!7LW!7LY!7LX!V1`!V1!!V0_!&Y&!V4R!7M=!V4Q!V4P!V59!V5Q!V5R
M!7PJ!V5P!V5S!7PS!V8D!V8C!7P[!V8R!7PZ!V8Q!V8]!V8\!7Q%!V9!!V9(
M!7Q.!7Q-!6MH!TTW!&,L!U)P!U)O!TXD!6]D!U=(#V<]!UM"!UM!!UM#!UM$
M!7=1!7Q1!S9R!SYT!T8F!U=)!6]E!&8K!6]G!6]F!&8L!U)S!U)Q#V<^!U)R
M!7,L!7,N!U=+!7,O!6MJ!7,M!U0J!U=*!TTY!TTX!7M>!V$I!7LZ!7=2!V1"
M#VTM!7Q"#RDF!7,P!V(K!V(J!7ID!7IC!V-*!V-)!7L[!&Y'!V8E!&Y6!V9,
M!BDV!B$Q!B$A!B5F!B5R!"4]!BYA#RUH!CTU!E!;!#PP!EIR#UE-!B-2`R12
M`R=3#V=``R=4!CT\!TT^!B%0`R)[!B-9`R%/!C5$!"$_!B(\`R1!!S9Z!2$I
M!B$X#R,W!BEC!BYV!D9G`T!##R(I!B\E!C58!#9,!"$O!B)&`R(E!B))`R,I
M!B\X!D9T!BHC!B\]!CU9!CU:`SHF#R$S`R0I!B%A!B9#!3$Q!B);!2%@`R,\
M!"-<!B9.!"-;!BH\`S`C!C5^!#!V!CU\!D<J!D<L!D<P!D<Q!D<S!#Q0!EM;
M!E$V!EM9!R%@!RQE`R%\!B0S!C8U!CXL!CXK`S1P!#9V!E%*!R%V!T8^#R-;
M!E%7!2-B!B0[!E%>!D=6!B)G#RHK!C9,!C9-#RYM!CY4!CY0!D=A!E%I#T=&
M`UHS!T91!B1(!#$P#T$K!EPB`UHV!V!M!B<A!C9G!B1+!"$T!2AS!D=[!"$U
M#R9B`RQ`!C!.!D@K!D@U`T!^!E(S!EP]!B<V!EQ)#R%?!D@W!C<L!D@\!RU3
M!RU5!V!N!2DG!C]&!C]%`S5?!E)`!45=!B%T!B=*!BLO!C!T#RI=!BLY!RUC
M!7-``RQ1!C]>!2U(`S5E!B=?#R0S!20X!C$V!C$P#RIG!"E*!DA\!DAX`T9P
M!E)L!E)F!ETF!ETD!$-1!RUI!RUY!R)[`U1@!%LL!T<H`R8G!D`C!2)N!BMC
M!BM@!C%/#RLK!C=Q`S8H!D`V!D`K!DE*!DDP#T%?!R,P!ETX!48L!R,M#T\E
M!$HG!S@Y#UYP!"U&!DE7#UHV`S9`!C@V#T%R!E,\!49!#RLX!C%M!D!7!DEX
M!EU;!BPC!29*!#(^!D!8!3]F!"1'!B@N#R11!"9H`RTU!CA*`S%<!"U<!CA0
M!3)^`SPZ!E->!3]Q`T%N!EUH!R-R#U1T!RYJ!%]V!U@C!B4C!DH_!R-X!UYR
M#TAY!E-W!"UE#S5T!DI-!BQ"#TA[!B4N#R1=!BQ;!BQ1`RU2!C(Y!C)"!"HE
M!"UP!CDM!CAT!CDA#S!;`S9U!DIE!DIC!#XS!E1)!E1/#T)T!EX^!R1/!R18
M#T]I!R]"#U56!%9=!TXH!U-@!U-8!BQ@!BQ=!C)(!#AH#T,O!E19#U`]#U58
M!7M[`U5%!D%A!D%C!D%J!EY>!C)B!DM"!T=U!B(F#R1X!BTD#RPY#S$H!DM'
M#T-D!$1N!T!C#V,D!D(A`ST_!C)Y!"I$!3-E!DM6!#YL!D(R#THO!U-[!BTZ
M!3-Q#U8\!BU%!BT]!C,]!C,Q!2\F#RQ7!CHM!CHN!D)(!DMZ#U!?!S!*!B4_
M!BU&`T,S!E5K!R5[!SEM#R@\!C-*#SU@!$M@!R8G!CI#!D)G!$5?!%(A!S!F
M!E]U!R8^!R8\!S!S#TI[!F`C#U$C!R9-!T$\!6Q]!S$M!SHS!%Q9!T%$`RY6
M!C-F`TAJ#U$W!R9J!R9I!&0F!V)-!DQR!SI&#SXR!SI)!TAM!U\\!DTC#U<G
M!"LF!R<H#U<H!F!=!4AT#UPM!BA[!"=H!BUI`S-0!3M0!DU(#T1H#TM7#TM6
M!$Q6!%@M!#17!DU>`T0E!F$E`R<J!B52!BDG#RA<!BDH!BXB!BXC!C1$!BXD
M!CM2#S(Z!#1S!D0K!#1T!D-V!D0[!#IF!D0^!D0\!D0]!DX[!F$^!F%/#U%D
M!$QY!R=A!R=M!S)$#U='!SIO#V!=!T(\!U1>!&<K!C1'!$!/!SLX`ULF!CMQ
M!#IU!DY&!$9\!$TS#U(D!R@N#U%]!T)@!T)?`ULM!&0_!%-,!B53!3`^!E@N
M!E@L#T4]!SMA#SA*!7HX!CPM!#5%#S\[!F)'!S-/!UE!!BDJ!EA0!EA<`V!\
M!CP[!S-Y!S-S#S]3`T1M!RE$!C1=!#`L!S0Q!%0W!SQA!B5;!#5R!EE'!EE*
M!SQK#T5S!F-3!F-/!%1*#V9>!U!K#VP_!F-8!S1Z!S1Q#V%*!E`B!F-N!S4U
M`U9X!5]>!SU0#UAX!TM?!&4J!TMK!3U'!40U!EHS!F0P!%EV!F0Z!CQW!EH]
M!%4C!%Y@!F10!SXI!RM5#UDR!U%Z!UI@!%I9!T5E!%\W!&)N!U)%!74V!74U
M#VQW!SY<!D8^!&A/!EI@!"@T`UPO!5-1!TTH!$AW!UY-````````````````
M`'G6__^)UO__F=;__ZG6__^YUO[_R-;__]C6___HUO__^-;__PC7[_\7U___
M)]?__S?7_]]&U___5M?__V;7__]VU___AM?__Y;7__^FU___MM?__\;7___6
MU___YM?___;7__\&V.__%=C__R78^_\TV/__1-CO_U/8__]CV/__<]C__X/8
M_S\```````````````````````````````"88+V+HF`5!ZA@+W*Q8&`(M&#*
M.;Q@[`C"8/;JS6#7X-9@_+'@8+Q?ZV`]T_5@__8#85R*"F%WPQ1A\R0<85]Y
M)V'T_S1A_NY!81]U2V&W`U-AN9]>8?KC:6&__G=A<4!\8?_6B6$$,(QA^+.6
M8?4?H6'\CZQA$?^V8?\/PF&6P,AA^__78>/_Y&&']^]A____8?#_"V)W"1-B
M_G\A8L[_+F+_'3IB5D`_8OU_36+_3UIB_O]I8G\H<F*N_W]B__^/8H'[F&*?
M$:!B`_ZI8O_>MV(1_\%B?\'+8H3?U&+_#^!B_/_N8O]/^V*.T`)CS_\08Y_U
M'&/7!"-CGO\P8]$--V-!?T!CY(U(8_[-5&-O_&!C-_!I8XZ_=&/0[WYCS.Z(
M8WL]DV/YSY]C'R^I8W^_MV-<^\)CK+G+8[/LU6/;(=UCW]_K8^V_^&.GCP)D
M^G,-9%YM%V1?[2-D_?,P9.\N.V0SM$-D_]909,]*6636/V1D_W]S9+Y_@&3F
M]8MD_OR89/%_I&3>^;!DO_J]9._URF3!O]1DC[_@9(?OZV3O[_EDQ^D#9<;O
M#F7J_QMEG_\I99_C-&7_#T!EX?],9??[6F7$$E]E_[]N96\!=67__X5E/S^1
M90;OFF6_YZ=E`N"K9?__NV4?,<-E\/_/98_XV67^_^AE_Y_V9<#_`&8K_`IF
M_^D79HWX(&;/W"MFW_LY9MXQ0F;^PTUF1_]99C?[96;WSW)F_`-Z9O^AA6;?
MGY)F^_^A9M[WKF;_S[QFN__*9KO/UF:_W^1F/_WQ9GO7_68_W@EG3WX49V[^
M(&?_;2UG[3$V9W[_1&=_/$]G\W!89Q?%8&>;WVQG?_][9_P_AV?OZY1G7?^A
M9ZWPJF?W+[9GG_S"9\;_SF?=_]QG'__I9]#_]&=^_P)H=>P,:"G^%FB'4QYH
MO<8H:/4?,V@;GCQH]\5':(O]4FCN_V!H_K]N:+_^?&C__XQHZ_^::'_9IFC^
M[[1H_W_#:/_]TFB_#]UH1O_H:/]_]VCZ60%I:``$:3#_#FG_?QUI_O\L:66!
M,FD!0#1I__]$:?_[4VDO_E]I_]MM:8D`<&D`[G9I__^&:?]_E6D`^)II_\^H
M:9./L6D(`+)I``"R:<[_OVG__\]I#P34:?[_XVDG!.AII0+M:0``[6D``.UI
M@'_U:;_]`VK__Q-J_O\B:H#_*VK_>3AJ$3`\:D`@/FH`8$!J[X],:O__7&K_
MWVMJ_T]X:@"`>6K__XEJ"`"*:A0`C&H``(QJ`/"0:O/_GFK__ZYJ0\"S:O__
MPVI_5<YJ#`+1:@``T6H``-%J`##3:OW_XFI___%J?Q_]:L#_!VOCA`YK`0`/
M:^#_&FO__RIK_T`S:P#\.6O__TEK#0!,:P``3&L`OE)K_OM@:^^`:&L_.W-K
M``!S:P",=FO__X9K_Q.1:\!_FFL``)IK`*"<:___K&N$`*YK?`>V:_Y_Q&L)
M`,9K_H_2:P,`U&N0]]UK"F#A:T?_[6MHSO5K#QC[:X\C`VS]WQ%LVG\=;/\)
M)VP?!"UL__(Z;)W^1FSROU)L/'1:;(K38FP6-&AL!*]O;/\0>&SN$']L__^/
M;/A?FFS[$:-L\'^N;/#_NFQ_><9LB?_1;/\!VFS"_^5L[9?P;/#^^VS?^PEM
M_X<5;3H`&6WS_R=M__PU;?]`/FWA!$-M@-]+;?O_6FVO_VAMOP!O;0#N=6W_
M@7]M_T>+;3OHE&U_+Z!M_U^N;82'M&T6W[YM7SG(;<`'S6W$?]=M3?[B;1N!
MZ&V_/_5M`#;Y;;\.`V[8'@MN?[\9;I:/(FZ@[RMN][$V;N%^0&Y@?$=N;O]4
M;M_?8F[>_W!N4ZUY;K[WAFX\_I%NW>.<;DH1H6X\\ZMN;_^Y;I'_Q&YW^M!N
M]:?;;GT*XV[]O_%NDO?[;N$U`V\%_PUOQ_\:;^.?)6_#62UO.8TU;S__0V_X
M;TYO[?]<;R?^9V^??G-O__^#;_Z[D&_K_YYO?^&I;_^TM6^"_[]O_P_+;^3_
MUV__7^5O&__Q;]__`'#!_PMP_T<7<'+^(G#__S)PG^`[<#])1'"__E)P]?A=
M</\A9W`LOW%P_[Y_<"'_B7#_\I9P_"^A</X_KG#X?[IPML'"<._[T'`W_-MP
M$N[C<+_U\'#'N?IPY#\$<7[?$7'7UAQQ[^<I<?]Y-G%._T)QQVY,<?C:5G&N
MY6!Q/Z)I<2'S<7'\^7UQPO>'<0W^D7'S#9IQ_^>H<1O0KW']_[YQ4_C'<?_#
MTW$_RMUQ__?L<1_\]W%_SP1RV8T-<K]_&W+0]21R_W\S<OS]0'(-]DERC_A3
M<OFT77)>KVARC==R<AON?')F?89R;^:1<B./F7(XXJ!R#\"F<B'BK'+"`*]R
M$XBT<GSFOG)5^\ER[_?7<OP=X7*<?NMR]S/V<GW^`W/!]0QS'_@6<[\O(G/_
M?3!SE_X\<_]?2G/^_UESR_=E<W]/<7/TIWMS^\&%<\,YC7.6P91S=_F@<^[[
MK7/ZN[ES[YG$<\/-S7/Z?]ISV$_C<PM6ZG/\__AS_^\'=!7^$70+^QMT_Y(F
M=/__-G3_YT1T_X%.=`175'3_WV-T_Q=O=&#_>71/K()T%`"$=+S_D73M?YYT
M0/VF=!0FJW02^+)T__[!=/\HRW2B_]9T__?E=/=#[W0`?/1T_S\"=>"'"75!
M]!!U_W<>=3G]*77[\#1U(24Y=>5_174S_U%UW,)9=<=X8G7"GVMU<KET=:__
M@G6/ZXUU_T>9=1^SHW4?@JIUT(JP=?\1NG7]G\=U_/?4=3_^X77/K>QU_^7Y
M=6_>!7;V_Q-V7_@>=O__+G:;_3IV_V](=O+]5';YW6!V_PAI=O_W>'8$[G]V
M_\Z,=D_OF'9G^Z1VN.^O=@^>N'84T+UV_OO+=L/\U7;7?^)V^:_N=OW__7:W
M_PMWA_X6=S\Q'W?\_RUW?_T[=V'_1G?__U9W5Y!==_]>:G?]^WAW?_6%=_\?
MDG?^\)UW_S6I=_ZLM'?G^<!WW:O+=_Y[V'?MO^5W>OWQ=W[D^W?U_PEXW=D4
M>,_/('C;="IX#[<T>/TO0'C'WTQXXP-3>/P'7'C0WV9X_W]U>/^]@WA\XXUX
M_[.:>+W?IWC?/[1X_U_">%ZOS7COX]EXGY?D>//_\GCW_P%Y_>L.>?V/&GG]
M\29Y+?XQ>?]W/WG?_TYY`_56>?\O8WG[^7!YB>%W>?__AWF?_)-YVUZ>>1[G
MJ'F/_[5Y_3[!>?TOS7F*?]=YO_GD>?]?\GDFCOEY__\)>G]D$WK)C1MZ__TJ
M>O]_.7K`_T-Z3T%*>O__6GK__VIZ@_YT>G^`?'H!#']Z_O^.>O__GGK_?ZUZ
M@?^W>O__QWK/C-!ZN/_<>O__['K___QZO^`&>_]G$WL$(!5[@O8=>__W+'O_
M_SQ[S_]*>Q\,47L`,%-[W]]A>___<7L!_'A[_]>&>P-0BGO^_YE[_\^G>_]#
MLGOV_\![&.'&>P"PR7O^_]A[_T#A>_\`Z7L"_O%[?_\`?`?_"WS%^!1\_]\C
M?.\#+'SP_SA\?WQ$?!K\37R?_5I\\OMF?`?_<7SBRWI\>?Z&?-_?E'S`CYM\
MSW^H?'Z9LGSU'[U\^.?(?/!_TWP_SMY\>[;I?)1_\WSR:?Q\;B,$?65[#GU_
M`!5]_/\C??_P+WV?`C9]\/U!?<5_3'T0`$U]]/]:??__:GW)_W9]_T^#?02<
MB'W__YA]_W^G??S_M7U?!;U]``"]?=[_RWW_]]I]G\'C??__\WU?$?M]``#[
M?0C^`W[__Q-^__\C?O\?,'X`_SA^_W]'?JT@37X`@$Y^_]]=?M_?:W[__WM^
M9P&!?@(`@G[Y?X]^_^N=?G\'IW[^_[9^_U_$?@,`QGX``,9^_W_5?O__Y7X;
MY>Y^___^?@D``'\`@`%___\1?_\_'W_`_RE_(P`L?X#[-'__/T)_\"]+?\#_
M57__PV%_?P-J?_C_=W^?_X5_%ZB,?_N'EW\'\)Y_OPZH?_R?M']CQ[U_YW?)
M?_='U'\>Y=U_\VSG?^/V\G_>;OU_X/\(@#/Q$8"O]1V`0*PB@/^/+X"_Z3N`
M\_=(@/V$48#]NUZ`'?YI@+G_=H#Z=X*`P&^*@/_+EX`[?Z.`_..N@$?>N(!W
M9<*`__W1@/HTVH#.W>6`I_?Q@+]:_(#ZO0B!=Y82@3K*&H'_[2B!9K\S@4^]
M/H%;^TJ!QO]6@:C[8($7WVN!D^=U@==-?X'WVXR!UU^8@4_\HX'__[.!GG^_
M@7H.QX'\?]2!R0O;@?S_Z8%!^/"!/P3W@?S?!()/_`^"GZ$8@@"`&8+S1R."
MX'\M@A\%-(+^'T""^#]+@@'\4H)>@%B"<^YC@OO!;8)?)7:",+]_@OG!B((H
M_)""_(69@KCAH8+(DZB"_+^U@H]YOX+8D<:"7OO2@O]8W8+X%^:"-C[O@IV?
M^H([<@.#?K\0@^\/&X/W_RJ#H_\V@T]K0(.+_TR#C_]9@_\'9(/A_W"#'X!V
M@_[_A8,_[9&#!N.8@_^#HX/__[.#_[_"@\"?RH/__]J#___J@X/_]8/__P6$
M__\5A'X`&X0`^""$_O\OA/]_/H0/^DB$__]8A/^?9H2/!&R$*0!OA'C_>X3W
M_XJ$#@"-A/'_FH3__ZJ$N0VRA*'HN83W_\B$___8A`^(WH3^_^V$?PKVA!``
M]X1_^`.%__\3A??_(H5_ARV%__\]A?__385#A5.%`%A6A?^_987_X7&%__^!
MA?B1B84`EHV%_O^<A?]_JX6@_[6%_UK!A<(:QX7__]>%^/_DA>68[(7T__F%
M!_\$A@^1"X9]?QB&_M\FAA'^+X;C?SN&H/]%AGGV4(8?65F&K6]DAMX=;H;_
M_GV&G_^+AL_WF(8_K**&?_^QAN_CO8;_F\J&___:AK__Z8:W=_6&/W+_AO;>
M"X>__QJ'_SLGA^TO,H<\_SZ'O@](A_#W4X?V@5N'YK]GA__^=H=_X("'__^0
MA__[GX?K_ZV'Q_^ZAW^#Q(?^*\^'^/O;A__CZ(<_O_6'W]P!B&WY#(C_FAB(
M^_8EB._[,XCC,#J(3\=$B/Z[48@1]UJ(?_]IB/_<=HC^_X6(+_^2B+?^GX@_
M]*J([W^XB/[_QX@'_]*(O__AB)C_[(@?/O:(Y/\"B>Z[#HGT_QN)A_\GB4=^
M,8E?W#R)'WU'B<;;48FQWUR)?]]JB7O,=(GT`WN)W\N'B3_@D(FC_YR)_?^K
MB3?\MHG_+\.)^/_0B?\`V(G^_^>)=^#PB?__`(K_7PZ*_/\<BO]_*XI4$S&*
MBO\\BO__3(I__UN*?@!ABB#`9(K__W2*_Z^"BM8"B(I@^(^*__^?BO__KXH#
M`+&*_/^_BM]VRXH`[-"*___@BO[_[XH#\/6*__\%B_^7$HM7@!B+`+0<B___
M+(O__SR+!X!`B___4(O_KUZ+#P!BBR"(98OXWW&+__^!B___D8MY()>+\/^C
MB___LXL/?[Z+@0#`B^+_S(O__]R+'P#AB_[_\(OS2?F+`H#[B___"XS_PA:,
M_S<CC('T*HS^_SF,__])C/_$5(S__V2,;H!JC/_O>8P7_(.,OP>-C`B^E(SW
M>Z&,X,*GC/O_MHQ?'\&,^"_+C.Y\UHP&+]V,7V_IC)_[]HQ][P.-]^4/C<"_
M&(T7\""-@_\KC?^O.8T'B#Z-_^!)C?__68UG"6"-[/]MC0?^=XW_!X*-`J*&
MC?[^E(T`_IN-__^KC?\;MXT@@+F-]/_&C=_XTHW__^*-_Y?OC0L$\XV*__Z-
M?_@*CO__&HY_/R>.`.$KCOD_-X[$_T*._]]1CC0058[`Y5R.__]LCK_!=H[_
M_X:.O^^4C@'BF8[Q_Z:.\?^SCJ?`NH[$O\2.C__1CF_,VX[=\.6.A0'ICO_W
M^(Y'_P2/B5`)C]Y8$H_H?1R//X<FC_7V,H_C_3Z/WGE)C__458^_$5Z/_5=J
MCS\#<H\MZWR/Z_^*C__OF8__?J>/[O^UC_M_PX_]_]*/GWS=C[?_ZX^"'_*/
M[_\!D/J]#9`Y\Q>0\_\ED/_X,I`=_SZ0';9'D+_Y5)#7+5Z0OP]ID!S_=)!_
M0WZ0`?^'D'__EI`$_Y^0(XBDD/Z*KI!?[KJ0O;O&D-<^T9!>B=F0___ID$^P
M\9#_WP"1>]$*D?__&I%W@2*1@/XJD2^P,I$%PSB1^_]'D;?V4Y'_/V&1?"UJ
MD8#D;Y'_]WZ1\QN(D2#^D)'_8)J1@_.CD?]_LI%_OK^1*/[(D?]WUI'/A^"1
M_P_LD2MO]I&/NP&2W<\-DK4?%Y)\^2*2#_TMDC^=.)+F'T*2^/]/DO`?6)+P
M/V*2\OMNDBL`<I+__X*2=_F.DA_PEY+__Z>2W\*QDOW\OI(%_,:2_[_5DOD_
MX9(`^.:2/W_SDO\+_I+\_PR3^/\9DS?X(Y/_^#"3@?\ZDWU_1Y/P]U*3?S=>
MD_&=:)-X_W23_WV"DY[[CI/'/YF37_>FD_'>L9-_\+R3O_G)D^\7U),9_MZ3
MX>_IDUD_\Y/&[_Z3+S\)E(M[$Y3Y[R"4W]PLE)QR-)3Y93Z4H^I'E#__591_
M_V24`?AJE.7'=)3X_X&42W"(E/CIDI3_/Z"4B_BIE.?OMI0AO[^4_(W)E!/^
MTY1,WMR4OUGGE._S])3SSP"5G_\.E8\Y%Y62_R*5_R\OE8#_.)5_'D.5^/]0
ME3\_7)7``%Z5__]NE?M_?)4A`'Z5@/N&E?__EI7^XZ*5%?ZLE?__O)5\HL25
M`/C)E?^?UY5;"MZ5\__LE?\_^I7"`_^5@/\(EO\C$Y;@?QV6+L$DEOX'+I;_
M.#F6Q[=$EK^_4I:'=EN6SG=FEE?O<I;SEWV6@;Z%E@C_CI8@>Y66_SVBEEQY
MJY;IS[:6Y[_#EJ=?SI;\AM>6WN_DEO/?\99^N?R6=[8'E__;%9=_WR.7^_\R
ME]N?/I?Y]4J7^]]8E_-S8Y?NUV^7OV]\E_P3A9?R'X^7_#^;E_W_JI?_>[B7
MN`*]E_[_S)<3?M67B/_?E^]_[9=/,O67X/O_E___#YA_'!F8:0`=F/C^*9A_
M_SB8$T]`F##`1)CM_U*8_Q]?F/P':)B`^6^8__]_F/__CYA\`)28\?^AF/='
MK)@A`*Z8@/VVF/__QI@?)\^8`?[7F#^_Y)@!B.>8___WF/'\`ID.YPN99_P6
MF5^>(9FXQBF9O_\XF>__1YG]_E69_1=@F?(?:IE__WF9!\)_F9+WB9D'G)"9
M_WB<F1L`H)GJ?ZR9/QZVF?XUP9GS_\^9GW_<F0S2XIE]__"9U[_]F510`IJ0
M_PR:?SX8FL/\(IK__#":_R`YF@+\0)K_!TN:_?]:F@W_99K_!W":Z/M[FOO%
MAIKC/Y&:__^AFOR?K9J`_[::?]S"FIOZS9I_`M6:3.O>F@[\YYJ6S?":>F/Y
MFF!^`9M0>`>;`_\1FQ3^&IOP/R2;$/DKFX<?-)L(_SV;_Q=)F\`/3YO_`UF;
M[_UGFQ#_<)L?P'>;O[^%F[Z?D9N^S)N;Z9ZEFY__LYNZO;Z;?7W*F_S_V)MX
MWN*;?P/KFX3_]9L'@OJ;_O\)G*#@#IS_7QR<_`,DG(#M*YS__SN<_P%$G`8`
M1IS^]E.<ZQ]>G!"\9)S__W2<>0)ZG(/]A)Q^?Y&<@&"4G/._H9P_`*><R->P
MG.'_O)R_0,2<[US/G/[7W)R<;^:<\__TG([_`)V?3PN=_W\:G<#_))W__3.=
M"_@[G??G2)UG_U6=X(1:G?W_:9TE\'"=_[]_G0_DAYW_!9&=#GR9G?^YIIT/
MW;"=_1N[G?]_RIU^V]:=W__EG3^/\)WS]_V=;_@(G@CG#YY'_QN>Y^$EGOO_
M-)Z_\#^>_^Y-GG[\69[_^VB>_P]TGO__A)[__9.>@_^>GC_PJ)[_?[>>_>_%
MGN#_T)Y'`-2>___DGO__])[_]P.?9/H,G___')___RR?__\\G_?P1Y___U>?
M7P)>G^C_:I_S_WB?Y_^&G__?E9__/Z.?P?^NG___OI___\Z?_X?:G___ZI\8
MX.^?____G_?O#:#P?QB@"?`>H/__+J!_+SJ@P/U#H/__4Z#X#UR@\/]HH/_S
M=J#S_X2@'_^1H/?QG:"ISZ>@TQ.OH.Z[NZ#[?\F@[O_7H&?TX:#7*>J@_/_X
MH/`+_Z"`_PBAG_\6H5\1'J'^_RVA?QXXH?#_1*$/@$FA__-7H0__8Z'W`6NA
MX/]VH>^.@:'C;XRAZ/"4H=__HZ'W][&A7WZ]H?__S:']#=>A^/_DH>^3[Z'"
M__JA__<)HO\"$J+\_R"B__`LHO\`-*)8_S^B_W].HO+_6Z(3`%ZB__MMHK__
M?*+'_XFBLP".HOK_G*+_^ZNB_0&SHO\'OJ(`_L6B_Q_2HOQ_WZ(&\.6B___U
MHC_@_J*_%0BCZ/\4HW__(Z/_^#"C_YX]HW_X2:,_WU:C^M]CHZ\?;J/?_WVC
MZP"#HP``@Z/L^X^C?]^=H[?;J:/O[K:C_?[$H[S;SZ./Z]JC__/HHY_O]:-X
M\/VC]#\(I,?_%:2?^2&DO_LOI&_F.J3_^DBD'W]4I/[=8:3/_6ZD]_U\I.;W
MB*0%_I&DZ2^;I/`GHZ3\BJRDFY^WI.K_Q*3C]]"DCZ_;I/5_Z*3]?_:D^U\#
MI?SW$*7O?QZET?\JI3__.*7_'T6E?_]4I?C]8*5_OFVE??=ZI<Y]A:4;T(RE
MWV>8I7'_I*6S?["E?_J]I;_]RZ5_O]FEK_/EI;_]\Z7_?0&FY_\/IN;_'*8]
M?RBF_Q\UIOR?0:9_\DVF_R=9IO^'9:;_GW.F_D-]IO_OC*8_Z9>F#?^BIOSM
MKJ;_+[NF_YG'IH?_TZ;_G^&F_W/NIA[_^J;_?PFG_"\4IS[`&Z?]_RJG^WXW
MI]@"/*?<_4BG_Y]6I_\78J=H[FNG`H!MI___?:?__XVG__V<I[,*HZ?@_JVG
M_[^\I^<_R*<#`,JG,+O2I_^^X*<9`..G___SI__6`*@Q&P>H@-\/J._Q&ZB_
M&26H`#\KJ/?_.J@O]46H\S]1J/"_7*@`OV.HX[]OJ$_\>J@3>H*H_O^1J'WT
MG*AU[ZBH_A^TJ/R>OZCVW\RHO^O9J.=KY*C\__*H_]<`J>O_#JF__ARI?_\K
MJ??7.*G[I$*I_VU/J7O;6ZG[_VJI_;=WJ=_UA*GW])"IF/^;J1CSHZG_'["I
M]G^]J?!OQZG^/]2IL/[>J<?AYZG_W?6IMWX!JOV_#ZK?_QZJ__LMJOG_.ZK_
M_DJJO_]9JO\+9*KP/VZJ!/MVJO__AJK__Y:J#_^BJO__LJJH_[VJ___-JG[_
MVZI__^JJ'__WJO__!ZO_:Q2K@OP<J___+*N__SNK_]]*J___6JO]'V:K^/]S
MJ___@ZO_EY"KP2"4J___I*O__[2K_W_#J___TZNG_^"K___PJP'X]JO__P:L
M_W\5K`?@&ZS^_RJL__\ZK/?_2:S_#U6L`/]=K/__;:S__WVLO^^+K`L$CZS_
MOYZLW_^MK/__O:S?_\RL_P?7K,#_X:S___&L'D7XK(3@_:S7_PNM__\;K?__
M*ZW__SNM_S])K0#_4:W__V&M__]QK?_\?ZTG`H2M%OZ.K?__GJW_WZVM__^]
MK?]?RZWB_]>M___GK96([:V"]/2M__\$KG__$Z[_`QVN__\MKC_^.J[W($*N
M\"]+KO__6ZZ__VJN_[]YKO+_AJ[__Y:N`?B<KG__JZ[__[NNN@/"KO__TJ[_
MP]ZN___NKO_?_:X!_@6O_^H2K___(J\/?RVOP/\WK___1Z_?_U:OQ\=@K]]]
M;:_J[WFO_W^(K_D?DZ]^_)^O_B^KK[_QMZ__/\6O/OC/K\MKV:_O]>:ON?_S
MK_'_`+#__Q"PX]D:L/__*K#Y^#6P[^%`L/__4+#_^U^PPY]IL`#_<;#_^X"P
M@_^+L`D`C;#Z_YNP_[^JL-\_M[#PK\&P``#!L/[_T+#__^"P___PL!___;"?
MQ0>Q?O\5L?__);'__S6Q/_`_L5\72;$`_U&Q]_]@L?__<+'X[WRQ>@"!L?'_
MCK'_]YVQ__^ML1__NK%>P<*Q__W1L?X/W+'\_^JQ`-_QL?__`;+^&`JR_O\9
MLM_!([(_X2VR_]T[LO\D1;+^_U2R]_EALO_!;++_]WNR]?V(LO[_E[*0OZ"R
M_'^MLM__O++W_\NR[O_9LOZ/Y;)_[_.R3_;^LO__#K/Y?!FS__\ILP?_-+._
M_T.SK,)*L___6K/G?V>S^O]UL__WA+,)X(FS__^9L_\?IK,/_[*S_RV^LR;@
MQ+/_^M*SA^':L_^_Z;/_#_6S#/S]L___#;3'\1>T_?HDM,;_,+3O/SVTC/='
MM/?/5+3*[U^TGO]LM-_:>+3O_X>T#V^1M"_XF[1Y^::T[RFPM/__P+2.[\NT
M?^?8M'QWX[3_Z?"TOO_^M/_C"[7_7QFU+O\EM?-_,K7X^SZU__E,M<_>6+7&
M_&*U%S5JM>H_=;5^[X*UN_^0M<>_G+6$_J6U__^UM?],P+5V_\VU___=M?,-
MYK7___:U_X\#MG]^$+;9_QVV__\MMOW^.[9#_T:V__]6MO[_9;;__W6VU_^#
MMO__D[;_AIZV_XFIMOW_N+;__\BV9>71MOW_X+;OONVVO__\MG_X"+=__Q>W
M?_\FM[__-;>7_T*W_]]1MW_O7[<L^VFW[SUUMT?^@+<YGXJW[^Z7MYO_I+?[
M/K"W?V.[MZO_R+?U_]:W_^?DM___]+<__P*X_]D/N/__'[B__2VX__<\N/_"
M1[C__U>XW_YEN.?_<[CN7W^X_O"*N/'GE;A[/:"X[_^ON+?_O;CC-\>X^?_5
MN/?GXKCL?^ZXC__[N/\%!;G_WQ2YG_XAN?_6+KG_^SVY)?A%N?__5;GR1UZY
M_^EKN?[S>+G)0W^Y`'^&N9OPC[G\(YBYT/^CN=WOL+G__\"Y[/_-N?_?W+G^
MO^JY_]CVN7^_!+K_P@^Z__\?NN__+KK__SZZ=OY*NO__6KK_OVFZV/]UNC_I
M@+K__Y"Z?_^?NG,?J;I_(K*Z_/_`NEW`Q[K^_]:Z20+:NOC_Y[K_?_:ZP@#Y
MNO__";L_7A2[#0`7N^C_([O_^3&["O@XN___2+O_@5*[`P!4N_S_8KO_46V[
M"(!ON^G_?+O_#XB[_C^5NP``E;M@W9V[__^MN_\'N+MV`+V[___-N_,=U[O`
M_>"[/QCHN_Z=]+O09_R[\.\'O!\\$+PXK1B\._\EO!?^,+PW_SV\#?](O+$+
M3[S\P5B\#YYAO%OD:KS]*W6\GYZ`O/[_C[S1T):\_Q^CO,#_K;QW$K6\_N_#
MO$"^RKS__]J\_WGGO.__]KS?AP&]J?\-O=^+&+V_/R6];Q,NO?;_/+W_4TB]
MXL]2O7[C7;U?GVF]?V=UO0:X>[VS_XB]%[^3O6=ZG;W_KZN]'T^UO?^_Q+V_
M\,^]^__>O?@LYKW]__6]#?#\O;]O";[\*Q.^\/\?OO_O+KXIR#2^__Y#OM[_
M4;X'`%2^_J]AOEO\;+[_QWF^?S&#OLK_C[[YXYJ^._REOOO?L[X?^+V^O</'
MON[_U;[#/]^^O_?MO@O^][[/?P2_Y;,.O__'&[^_URB_V>LSO^=_0+_\KDN_
M_O]:OR7]9+]_OG&_VO]^OW_>B[_[_YJ_^_FGOV_]M+__G\*__^7/O_W_WK^;
M_NJ_N^GUO^_]`\#[X0[`O_(:P/[?*,##SS+`Z_]`P#_A2L#SWU?`W]ECP/?_
M<L#G_7_`_WF,P/1`DL#`?YO`)OBCP/L]K\`-_KG`_V'$P/O_T\!W#MS`_[_K
MP&_F]L#_2`#!^[\.P<OO&L'?_RG!I_<UP>]O0L%O-TW!T,=5P1W^8,'_`VK!
M].=UP6]*?L%T_(C!7_*3P0G]G,&?P:7!_O^TP6@:NL'R_\?!?^#1P?]_X,'_
M(.G!(-+NP?]__<$`\`'"__D/PA\2%L(@%AK"_O\IPM^`,<+__T'"P3!&PD#8
M2\)_`U3"P/]>PO\K:L(X\''"WZ]^POC'B,+_?Y?"D$*;PNG_J,*$[['"_U"[
MPAF`O\*\S,C"_XG3PH#[V\+0_^;"E\;OPD_@]\(!7/S"(_X&P_?W%,,5TQS#
M3SDEPP``)<.`_R[#]`LVP_B&/L///TK#N.U4P^?C7\-<76C#/]YTP^O_@L.O
M/X[#_?^=PS?@I</_H['#(?^[P^N!P\/SO]##_Q#9P_3_YL.M`NS#___\PT3T
M`\3_\`_$WT,9Q/X^)<2\^C#$W@TYQ(\90<0`@$+$_WU0Q!_Z6\0O`6'$_M]O
MQ"O_>\2/X(/$[_^2Q'_\G\0/@*3$__^TQ#*`N,3__\C$?_W6Q$.%W,3__^S$
M?_WZQ/_["<5!_!'%>^`:Q?_P)L7_LS/%[UT_Q7Z_3,7OKUG%_C]FQ?_/=,7\
M_X+%?_N0Q?]'G,7__ZS%?^:XQ?__R,6__]?%\__EQ?/_\\7G_P'&__L0QI\[
M&\;E?R?&_#<RQOP=/,;^=TG&K/]5QN\78,;_?V_&RZ]ZQO#WA<8;(HO&P/^5
MQO]JH<:`_ZK&_\ZWQ@W@O<;_/\O&QO#3QO\#W<;^C>C&<.KPQN^E^\:?7P?'
MOO\5Q]O_(\?OUS#'^/<\QTZ^1L?_^53'?WMAQ[]_;\=2[GC'_E^%QP#_C<<_
M"Y;'__^FQV#^K\>-D[?'___'QS_HT<?__^''?_?OQ_G__<?_+`C(Q_\5R,_.
M(,C_SBW(_O\\R/#/1LB^PU#(M_]>R+Y_:\CR_WC([_^'R.O/D\C_SZ'(?_^P
MR/</N\B^OL?(^-_3R/]]X<CWWN[([S_[R/__"\G_7QG)_W\HR?^?-LG__T;)
MU^Q1R?__8<E_?V_)>N-YR?__B<G_?9?)__^GR1G^L<G_L[[)^?_,R67_V,G_
M[^?)?_KTR?[5`,K;_`S*";X4ROY3'\K]?RW*\C\XROCO1,H/_U#*_PU;RNK_
M:,K_]G;*_^"!RO__D<I_1YS*WOZIRA(`J\K6-+/*___#RNQ_S\H9_]K*_Z_H
MRF/_],K/Z/[*__\.RPK^%\O__R?+_?PTRP2P.,O__TC+9P).RX#O5LO_6V/+
M-_-NR___?LO#QH;+_W^5RZ3TG<O_OZS+^"NUR_CEO\O3`<7+``#%R^,>SLM\
M'-;+A=[?R_=W[,L_;??+LF<`S*__#LQ>\QG,__\IS.O@,LS__T+,OW=/S.?_
M7<R?X6?,__]WS-."?LS-_XO,_W^:S(OHHLS__[+,WUV^S!3XQ<P?#,S,___<
MS//:Y\S_,?+,R/_]S/W/"LUQ#Q+-/P`8S0``&,T``!C-YO@BS=_P+<W_Y3K-
M3_Y&S:C_4<U/X%G-?V-DS7_^<LV_'W[-_V^,S<S;ELU_WJ/-H_>NS?__OLV;
MMLC-&X[0S?__X,W'`^?-_[_VS8__`\[OY0_._V\=SH#_)L[_.S/.P/\]SL_#
M1\[_=U7.^/]BSE/X:\[Q(W/./XU]SO[^B\[_\IC.__^HSO[2L\Z[_\'.W[_/
MSO^[W<Z_Y^K.__WYSO-_!L_NWQ//2?H<S_?[*L]_OSC/__='S^?W5,_)[U_/
M?_MMSU_O>L_?K8;/M_V3S_L+G<___ZW/^Q.WS_]_QL]^3,_/_?_>S\._Z<\,
M^/#/__?_SW]0"-"P_Q/0__\CT(6?+-"E(3+0`-8WT/__1]#'7U+0!`%4T/[_
M8]!_X&W0?QYXT`#H?-#_?XO0X"^3T$#_G-#_#:?0=`&LT/Q_N=#'\</0XW_/
MT#[XV=`?\>/0*_WNT,M_^M#K``#1`:($T?_[$]'_'A_1__\OT?^?/='_^$K1
M_W]9T?X18M&#OVS1_N]ZT?\_B-'_M971`?^>T?__KM'_?[W1A?O'T?__U]&[
M[^31*B3IT?#_]='__P72_ST2TM6&&M)(_B/2__XRTI]9/-()_D72__M4TO]_
M8])^E&S2`L!OTO__?]+_/XW2\B24T@+_G=+__ZW27@:TTOXUO](#\,72_Y_3
MTOI^W](-_^K2],_UTK>_`M,!``/3P/\-T]OC&-/OE2/3W_LQT_M;/=/CO4C3
M_O]7T_CK8M/W?W#3KOQ[TYW]A]/N?Y33]SV@TWWQJ],?^;;3__K$TW_]TM/_
M_^+3??_PT]_@^M/]_`?4__T6U'UN(=3>?R[4>G\ZU/+Q1-3?_U/4G?]@U/[[
M;M3S#7?4'(-]U!]_B=3\?Y;4ZO^CU)_`J]0_F;74?__$U(_^T-0QS]G46][D
MU/_]\]2V\_[4__L-U7?M&=7W.235_-\QU>O]/M5?_TS5GO]9U9+_9-7B[V_5
M[_E\U?\-A]7^QY/5^7B=U?;^JM4W_[?5_[_&U>3_TM4S[-O5_YGGU?=W]-75
M_P'6S_\/UL__'=;X5B;6_;LSUE][/];N^TS6X?E6UOO_9=9?[W+6?P``````
M``````Q@```,8```#&````Q@Y_\:8!]^)6#W_C-@?P\^8```/F```#Y@```^
M8```/F```#Y@```^8```/F```#Y@```^8'K_2V#__UM@__]K8/^7>&#^_X=@
M_S^58```E6```)5@``"58```E6```)5@``"58```E6```)5@(P`+8```"V``
M``M@``$```````````````````````````````#K``__]P`W8/X`_@,'`0``
M!P$```<!```'`0``!P$```<!```'`0``!P$```<!```'`0``!P$```<!```'
M`0`("`'@_Q,!__\C`?\#+0$``"T!```M`0``+0$``"T!```M`0``+0$``"T!
M```M`0``+0$``"T!```M`0``+0$``"T!```M`0``+0$``"T!```M`0``+0$`
M`"T!```M`0``+0$``"T!```M`0@`+@$``"X!```N`0``+@$``"X!```N`0``
M+@$``"X!```N`0``+@$``"X!```N`0``+@$``"X!`,`P`0!P,P$"`#0!```T
M`1!`-@$F`#D!```Y`0``.0%S$#\!0!!!`1)[20%?7U4!/OYA`8O_;0'XP'0!
M^_Z"`?]_D0'^_I\!\[^L`?W_NP&\W\<!^_W5`9_SX0'^?^\!__S]`:]W"0+_
M]Q@"__\H`O__.`+WWT8"__Y5`N\?80+_@6L"_X%U`O\/@0+P_XT"_S^;`OD?
MI@+\/[("?_B^`N<_R@)[_M<"_[_F`M^/\@*_[P`#+WX+`[__&@/_7R@#O_XV
M`_WU0P/_?U(#__]B`S[F;`/_?WL#YO^(`_]_EP/^_Z8#[W^T`__?PP/__],#
MO_7@`__[[P/]_OT#]_\,!/^?&@3_GR@$_K\V!/_^102[_U,$W_]B!.6_;@1_
M_WT$]_^,!/\_F@3GYZ8$]O^T!/_?PP3__],$[>_@!/__\`1___\$__\/!>O7
M&P5]?2<%__LV!1__0P5]N$T%Y_Q9!?[_:`7__G<%_]>%!?_/DP7__Z,%?_RP
M!?_[OP7_]\X%__[=!?_][`7___P%]?\*!O]_&0;\1R,&_O\R!O[_00;__U$&
M__Y@!O_G;@;__WX&^7^+!OU_F0;_OZ@&__ZW!K?[Q`9N],X&?_O<!O/?Z08_
M[/0&O_\#!_/>#P?_/QT'_O\L![U_.0?O_D<'?YM3!YX?70<^_VH'!_]U!P?_
M@`?_^8X'__^>!_K_K`?_E[D'___)!_G_UP=__.0'_\_R!___`@CW[Q`(__\@
M"/_^+PC__S\(]-]+"/^]60A__V@(__]X"/[_APC_O94(_W^D"/_]LPC/_\$(
M\'_,"/C_V0C_Q^8(_W_U"./_`@G_^1`)?_P="?_C*@G__SH)_^])"?/Q5`G^
MW6$)^_]P"3W>>PG_[XH)_X^7"7_YI`GYV[`)/_^^"?__S@G__]X)[W_L"?_^
M^PG__PL*__@8"O[_)PJ_WS4*__U$"OM_4@J_IUX*GW]K"O[F=PJ/^8(*Y_^0
M"O;^G0K__ZT*__^]"O__S0K??]L*[__J"O__^@JW[P<+__\7"___)PO__S<+
MP?]""_[_40ON_U\+_O]N"___?@O_[XT+_]^<"Y__J@O__[H+_O_)"[__V`O]
M^^8+___V"__W!0S__Q4,__XD#-__,PR'_S\,_G]-#/]^6PS_[VH,__MY##^_
MA@SW_Y4,S_VB#/_]L0S_?\`,__/.#/__W@P_[^L,___[#/^_"@WO_QD-[_LG
M#?__-PW__T<-YW]4#?__9`W__W0-__R"#?__D@U__Z$-__^Q#>__P`W__]`-
M_^_?#?__[PW[__X-__\.#A__&P[_WRH.__\Z#O__2@[_]UD.__]I#O__>0X_
M`'\._/^-#O__G0[^_ZP.__^\#O__S`[_M]H.W^_H#O__^`[__P@/_]\7#_^?
M)0___S4/O_]$#___5`__^V,/__]S#___@P^__Y(/_[V@#W^^K0]__[P/_?W*
M#_\_V`__/^8/_O_U#X__`A#_Y`X0__<=$/__+1#__ST0__]-$/__71#[_VP0
M_O][$/?_BA"__YD0__^I$/__N1#_[\@0_[_7$/__YQ"___80_]\%$??W$Q'_
M_R,1_[<Q$?__01'[_U`1_\-<$??_:Q'_]WH1O_>($?__F!'?_Z<1[^^U$?__
MQ1'__]41]__D$?__]!'__P02__\4$O__)!('_"T2]_\\$O__3!+_]5H2__]J
M$O_O>1+_#X42_O^4$O__I!+[_[,2___#$O__TQ+__^,2^__R$O_O`1.__Q`3
M__\@$__[+Q/__S\3__]/$___7Q/]]VT3^']Y$W_^AQ/W_Y83__NE$__]M!/[
M_\,3O__2$_?_X1/^__`3__\`%/?]#A3[_QT4?_\L%/_O.Q3__TL4_P%4%(#_
M713_]VP4__U[%#X^A13^?I(4__^B%/_5KQ3__[\4___/%/_[WA3__^X4___^
M%.^_#!7__QP5__\L%?__/!7__TP5_W];%?_[:A7__WH5__^*%?__FA7__ZH5
M__^Z%?__RA7__]H5___J%?__^A7_?PD6_^\8%O_[)Q;__S<6__]'%O__5Q;_
M_V<6__]W%L?_A!;__Y06__VC%O_WLA9__\$6___1%O^_X!:W_^X6___^%O__
M#A?_^QT7[_\L%W__.Q?_'D<7X/]2%[__81?__W$7__^!%___D1?__:`7__^P
M%P?\N1?__L@7___8%___Z!?___@7__\(&/__&!C__R@8__\X&/^?1A@[`$L8
M``!+&```2Q@``$L8``!+&+__6ACWPV487^]R&&^[?ACOZXL8WO>8&`P'G1@Z
MPJ08__NS&/[[P1A_^<X8WU;9&/__Z1CQ__88_\,"&?__$AG__R(9_S\P&03S
M-QG__T<9__]7&?__9QG?_W89__^&&?__EAG__Z89#\BM&?__O1G__\T9___=
M&;_2Z!G___@9__\(&O__&!K__R@:_Y,T&O__1!K__U0:__]D&O\_<AK__X(:
M__^2&D_\G1K__ZT:__^]&O__S1K__]T:^__L&O___!K__PP;__\<&___+!O_
M_SP;__],&_]_6QONTV8;_?]U&__C@AM_/X\;__>>&___KAO__[X;/W7)&_]G
MUAO_W^4;__'R&__/`!S_?P\<^O\='/S_*QS__SL<_?]*'/]_61S__VD<^?]W
M'/O_AAS_]Y4<__ND'/__M!S__\0<^__3'/__XQR_O_$<__\!'?__$1V__R`=
M^_<N'?__/AW=STH=W/]7'?/_91W_;W,=/_^!'?W^CQW__Y\=_[^N'?__OAUO
M_\P=___<'?__[!W___P=$^0#'O__$Q[__R,>__\S'G_5/Q[__T\>__]?'O__
M;QY!1',>__^#'O__DQ[__Z,>_P^O'L/_NQ[__\L>___;'O__ZQY_#?4>[OP!
M'___$1___R$?__\Q'W^,.Q___TL?__];'__':!_7_W8?__^&'__[E1_%_Z$?
M__^Q'___P1__Q\X?___>'__O[1____T?__\-(.'_&2#__RD@_[\X()__1B#[
M_U4@S[]B(+__<2#__8`@O_^/('_XFR#__ZL@_XNW(/[_QB#__]8@C_WB(/__
M\B#_7P`A\/\,(?__'"&_^"@A__\X(?__2"'__U@AG?]E(?__=2'__X4AO?^3
M(?__HR'_O[(A_O_!(?__T2'__>`A___P(;_\_2'_YPLB?_\:(M_;)R*__C4B
M?_]$(O^_4R+__V,B__%P(OG_?B*__XTB__^=(O__K2)__KLB___+(O_QV"+_
M_^@B___X(O__""/__Q@C__\H(Q_^-"/__T0C__]4(^O_8B/__W(C__^"(___
MDB.O_Z`C__^P(___P"/_W\\C___?(___[R/K__TC__\-)/G_&R3__RLD__\[
M)/__2R2__UHD__]J)/^]>"3_WX<D__^7)/__IR3]_[8D_/O#)/_?TB3__>$D
M___Q)/__`27_YP\E^_\>)?_/+"4_OSDEZ_]')?/_527__V4EO_]T);M_@27S
M_X\EO_*;)?__JR7_#[<EP__#)?__TR5F_]\E___O)</_^R7__PLF_]\:)O__
M*B;__SHF_\I&)O__5B:__V4F__]U)O__A2;__Y4F__^E)M__M";__\0F_TO0
M)O_OWR;??^TF_N_[)C__"2?]YQ8G__TE)___-2?__T4G__]5)[__9"?E/V\G
M__]_)__OCB?__YXG__^N)^__O2?__\TG__W<)[__ZR?^^_DG__\)*-__&"C_
M?R<H__XV*/_W12C__U4HW_]D*/__="C__X0HO_^3*/__HRC__[,H___#*('_
MS2C__]TH___M*/\C^"C__P@I__\8*?__*"D_T#$I__]!*?__42G_1UTI__]M
M*?__?2G__XTI_T>9*?__J2G__[DI___)*:__URG__^<I___W*?W_!BK__Q8J
M__\F*O__-BK__T8J__]6*O__9BK__W8JZ?^#*O__DRKO_Z(JO_>P*G__ORK_
M_\\J___?*N__[BJ?__PJ_^$(*___&"O__R@K_W\W*_C_1"O__U0K__]D*___
M="L3_'TK__^-*___G2O_BJ@K"O^R*___PBO__](K_S_@*_'_[2O___TK__\-
M+/__'2S__RTL1^0U+/__12S__U4L__]E+/]'<2S(_WPL__^,+/__G"S__ZPL
MR_JW+/__QRS__]<L___G+.__]BS__P8M__\6+5_Z(BW__S(M_Y]`+?__4"W_
M_V`M__]P+?O_?RW__X\M__^?+?__KRW_][XM__W-+?^?VRV_?^DM]__X+?_]
M!R[__Q<N_O\F+M__-2[__T4N?_Y3+O__8R[__W,N__^#+O\?D"[__Z`NA_^L
M+O__O"[__\PN\__:+O__ZBY___DN__\)+___&2___RDO__\Y+__71R___U<O
M__]G+__]=B_^_X4O]?^3+___HR]G_*XO__^^+___SB___]XO7M#F+___]B__
M_P8P__\6,/__)C#_WS4P<P`Z,/__2C#__UHP__]J,/__>C#_1X8P`/B+,/__
MFS#_WZHP__^Z,/__RC#_(]4P^O_C,/__\S#__P,Q__\3,?__(S'_62\QH-XW
M,?__1S'__U<Q__]G,?__=S'_OX8Q;?20,?__H#'__[`Q___`,?__T#'_`]HQ
M_O_I,?__^3'__PDR__\9,O\_)S+\_S4R__]%,O__53+__V4RQ^5O,O__?S+_
M_X\R__V>,O__KC+__;TR___-,N__W#)__^LRW__Z,O]_"3/__QDS__\I,___
M.3/__TDS__]9,__O:#-__W<S\_N$,___E#/]_Z,S^_^R,]]]OS/_O\XS___>
M,W^_[#-___LS^_T)--_;%C1__B0T__\T-.__0S3__U,T__]C-/__<S0/_'TT
M__^--/__G33__ZTT__^]-#^"Q33__]4T___E-/__]33__P4U/P`+-<#_%37_
M_R4U__\U-?__137_#U$U(/Q8-?__:#7__W@U__^(-?__F#7__Z@U_Y^V-:3_
MP37__]$U___A-?__\37__P$V__\1-O]_(#95[RLV__\[-O__2S;__ULV__]K
M-O\_>39(^X(V__^2-O__HC;__[(V___"-O__TC9_U]\V___O-O___S;__P\W
M__\?-__G+3?__STW__]--___73?Y_VLW__][-__]BC?__YHW__^J-___NC?_
M_\HW_S_8-_[_YS?_W_8W__\&./[_%3C_CR(X__\R./_/0#CQ_TTX__]=.#_$
M9CC__W8X__^&.(_^DCC__Z(X_Z^P./[_OSC?_\XX___>./?_[3C___TX__\-
M.?__'3G__RTY__\].?__33G__UTY/_]K.?__>SG__XLY__^;.77_J#G_W[<Y
M_^_&.?__UCG?_^4Y__OT.?__!#K^_Q,Z?_XA.O_^,#K_OS\Z_S]-.OC_6CKW
M_VDZ_W]X.OS_ACK__94Z__^E.O__M3KGW\(Z___2.O__XCK_\>\Z_[_^.OS_
M##O__QP[_?\K.___.SOX_T@[_S]6._S_9#O__W0[?_^#.___DSO__Z,[__^S
M.W__PCO_O]$[___A.___\3O__P$\__\1//O_(#Q__R\\^.\[/-__2CS__5D\
M__]I/,_O=CS?_X4\^_^4//[]HCSG_[`\^]^^/#]_RSS\#]4\___E//_\\SR_
M_P(]__`./?__'CV/_RL]?_XY/?_S1SW_/U4]_]]D/?^?<CVW]W\]__N./?__
MGCW]_ZT]__^]/?G_RSW_?]H]_/_H/?__^#W__P@^_\\6/O__)C[_[S4^__]%
M/O__53[\_V,^__]S/O__@SZ__Y(^\_^@/O__L#[__\`^__;./O__WC[_]^T^
M_W_\/OS_"C\_ZQ8___\F/_\A,#_\_SX_'_%(/___6#]#_V,___]S/__W@C__
M_Y(_G_^@/___L#]__;X____./]__W3_W_^P_O__[/___"T#G]QA`][\F0/__
M-D#_?T5`__Y40-__8T#__W-`__^#0/__DT#__Z-`__^S0/]_PD#OG\]`___?
M0/__[T#G__U`__\-0??_'$'YGRA!]_\W07__1D'_GU1!_\]B09_?;T'__W]!
M]_^.0;^_G$'__ZQ!__^\07/_R4'?_]A!___H0?^K]4'__P5"_\,10O__(4+_
M"RQ"_O\[0O_[2D(_\%1"__]D0O]_<T+Q_X!"_S^.0O__GD+__ZY"-_^[0O__
MRT+]_]I"_?_I0O__^4+]_PA#__\80_M_)D/^_S5#_]M#0___4T/__V-#__YR
M0___@D/__9%#__^A0___L4,__[]#___/0___WT/__^]#____0W__#D3__QY$
M__,L1/__/$3__TQ$__]<1,__:D3__WI$__^*1)__F$3__ZA$__ZW1/__QT3_
M\]5$___E1'__]$3__P1%]_\31?Y_(44``"%%```A10``(44``"%%```A10``
M(44``"%%```A10``(47`_RM%^_TY1;?[1D7__U9%[_]E1?W_=$7_?X-%__N2
M1?__HD7__[)%__B_1?__ST7__]]%___O1?___T5[_PU&__\=1OO'*4;O_SA&
M^_U&1O__5D;V_V1&__]T1O[_@T;_#X]&_/^=1O__K49_X+=&___'1O\'TD;P
M_]Y&___N1A/^^$;__PA'/_D41___)$?_IS%'__]!1_W_4$?/_UY'O_]M1___
M?4?W[XM'__^;1___JT>__[I'?__)1_>_UT?\M^-'_]_R1^_?`$C^_P](_OL=
M2/O^*TA__SI(__]*2/__6D@_!F)(__]R2/__@DC__Y)(_W^A2,7_K4C__[U(
M___-2/__W4C_`>9(#`#H2/__^$C__PA)__\82?__*$F!XBY)__\^2?__3DG_
M_UY)__]N2?__?DG_R8I)"OZ32?__HTG__[-)___#2?__TTG__^-)7^'M2?__
M_4G__PU*__\=2O__+4K_33E*EO]%2O__54K__V5*__]U2O__A4H_Z9!*__^@
M2O__L$K__\!*Z__.2O__WDK__^Y*_Y_\2O__#$O__QQ+]_\K2___.TO__TM+
M__];2^O_:4O__WE+_O^(2^]_EDO__Z9+__^V2_]_Q4OP_]%+___A2__G[TO_
M__]+_Y\-3/__'4S_?RQ,X/\W3/__1TQ__U9,__]F3/__=DS_](-,__^33/__
MHTS_/[%,_O_`3/__T$P__MU,___M3/]__$S^_PM-__\;3?__*TW__SM-__]+
M3?__6TW__VM-__][3>__BDW/[Y=-__^G39__M4W__\5-_Q_23?[_X4T'_NM-
M___[3</_!T[__Q=.[_\F3O_/-$[__T1.[_]33E__84[?_W!.__Y_3O__CT[^
M_YY.__^N3O__OD[__\Y.`0#/3OR_W$[_?^M.___[3OW_"D__^QE/__\I3_?_
M.$___TA/_W]73___9T___W=/__F%3___E4__OZ1/__^T3___Q$__^]-/___C
M3___\T___P-0__\34/W_(E#__S)0__]"4/_W45#__V%0^_]P4/]_?U#__X]0
M``"/4```CU```(]0``"/4```CU```(]0``"/4```CU```(]0@/^84/__J%#_
M_[A0_[_'4/__UU#__^=0___W4/__!U'__Q=1_[\F4?__-E'__T91__]64?__
M9E'_'W-1``!S40``<U$``'-1``!S4?#[?E'?_XU1__^=4?__K5'__[U1_?[+
M4>__VE'_O^E1W__X41_T`E+_KQ!2__\@4O]/+5+__SU2__]-4OO_7%+__VQ2
M_Q]Y4OY_AU+_YY52__^E4M_WLU+?_L%2___14O/_WU+__^]2_^_^4O__#E/_
M_QY3__\N4__O/5/__TU3/P!34P``4U,``%-3`/A84__U9E/_VW13__^$4_^3
MD%/__Z!3\_^N4__[O5/__\U3/__;4__]ZE/___I3/_\(5-__%U3__R=4__\W
M5/_?1E3_[U54__-C5/]_<E3T_W]4/_^-5/_^G%3__ZQ4__^\5/__S%3__]Q4
M^__K5/^7^%2__P=5_1\35?__(U5__S)5[_]!5?_^4%7_^EY5^_]M5?W_?%7_
MXXE5__^95?__J57_Z+55___%5?__U57__^55___U5?W_!%;__Q16__\D5O__
M-%;__T16__]45O__9%;__W16__^$5O__E%;__Z16__^T5O^_PU;M_]%6___A
M5O__\5;__P%7__\15___(5?__S%7__M`5___4%?__V!7__]P5_[_?U?__X]7
M__^?5[W_K5?__[U7_?_,5_?_VU?__^M7___[5Q\``%@```!8````6````%@`
M``!8````6````%@```!8````6````%@```!8````6````%@```!8````6(!_
M"%C_^Q=8__\G6/_[-EC__T98_W]56/__95C_`&U8(`!N6```;E@`<'%8__^!
M6)__CU@?_)I8__^J6!_\M5C_^\18___46/[_XUC___-8__\#6?__$UG__R-9
M_O\R6?>_0%G]_T]9__]?6?_?;EG__WY9_R^+6>?_F5G?_ZA9_?^W6;__QEGX
M_]-9_W_B6?__\EG__P):__\26C_@&UK__RM:__\[6O__2UK_[UI:__]J6O__
M>EK__XI:__^:6A\`GUH``)]:``"?6@#[IEKO_[5:WS_"6@"XQEK^OM-:___C
M6O]?\5K__P%;__\16___(5O__S%;__]!6P,`0UL``$-;``!#6\#_35O__UU;
M__]M6]__?%O__XQ;__^<6_O_JUO__[M;\__)6__^V%O__^A;___X6___"%S_
M#Q1<```47```%%P``!1<`/\<7/__+%S?YSE<__])7/__65S__VE<__]Y7/?_
MB%S__YA<O_^G7'__MES_O\5<___57/_^Y%S___1<?_\#7?__$UWK_R%=_[\P
M7?S_/EW__TY=V?];7?__:UW_^'A=__^(7?[_EUW__Z==_^.T7?_QP5W^#\Q=
M``#,70``S%T``,Q=``#,70``S%T``,Q=X/_77?[_YEW_O_5=__\%7O_G$U[_
M_R->O_XQ7O__05[?_U!>__]@7O\?;5[__WU>__>,7O__G%Z__ZM>__^[7O__
MRU[__]M>___K7O]_^EX``/I>``#Z7@``^EX``/I>``#Z7N"^`U___Q-?__\C
M7___,U__^$!?__U/7___7U_]^6Q?__]\7__'B5___YE?_?^H7___N%___\A?
M_?_77_O_YE__?_5?`.#X7_]S!6`_````````````````````````````>@#_
M_XH`__^:``(`FP```)L```";````FP#_`Z4`\#^O````KP```*\```"O````
MKP```*\```"O````KP```*\`!1"R`!$1M@`0$+@`$!"Z````N@`!0+P``N3!
M``\`Q0#^_]0`,`#6``,`V``,,-P`P,CA````X0`\`.4```#E`&`"Z````.@`
M``#H````Z``'`````````````````#L````[`%@S0@!@`$0`)$A(````2```
M`$@```!(````2````$@```!(````2````$@```!(````2````$@```!(`"@"
M2P```$L```!+````2P```$L```!+`/\#50#_`U\```!?`,\#9P```&<```!G
M````9P```&<```!G````9P```&<`(,1K``%.<``P$',```!S``0`=`##`'@`
M``!X````>````'@`(`!Y``"```````````````````````8````&````!@``
M``8````&````!@````8````&````!@````8````&````!@````8`@`X*```"
M"P````L````+````"P````L````+````"P````L````+````"P````L````+
M`/[_&@#[`R,`_O\R`/L#````````````````````````````````````````
M````````````````````````````````@``!`(,`!`````0`@``%````!0"`
M`/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL
M_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];&8;:!OG&S\<_6RF
M'`\=/AXD'V4?FQ]_'<L@<R%Q(6LA]"$B(B`BDB*Z(I$BL")9(XHC#R02)!,D
M1R2;)``E3271)M,F9R=7*'<HU2AU*8XII2FV*;\I92K-*NTJE"N:*[HK)2U0
M+:,N8"]D+[8O`S"V,!HQ)48A*.(R`C.D,ZPS$#0&-%XT6C0L-2DU+39W-GHV
MRC;F-O4V#3<.-]PWW3?V-QXX8SBE.0\ZBCJ$.HLZ?#I,.T@[23N=.YD[^#LN
M/"T\7#S,1;\\ZCSE/!$]$CT_/3D].ST]/7<]=3UV/7$]ECV3/;0]W3W>/0X^
M$248/D<_2#_O/Q)`.T"D0(U`M$!S0G="O$(91!M$/4131%1$6$2W1-A$[D0B
M14U%AD691:-%O$6G1C='64?01R](,DA"2$Y(:$BI2.U(T$D'2M-)9$I`2_UL
M04QC3+M,$3,E,TA.$$]B3Q)/(5`>4.)0WE#A4'-1U%'U43=215)R4DI3J5.E
M4_53-%105(=45%6$50-74EC86`Q9&%FP6;Q:U5JJ6YQ<_6Q<72M>(5YS7O1>
M]5X_7T)?AE^^7[Q?O5_Q7_)?[U\B8"-@)&!G8&9@EV'.8>=A.V--8^1D0F4=
M9YAG_6Q):4DP<2J%*M,M#F4"3!Y$_6S];"@A<B&Z(?`A[B&X(KDBQ")33+!>
M`````````````````````````````````#0````U````-@```#<````X````
M.0```#H````[````/````#T````^````/P```$````!!````0@```$,```!$
M````10```$8```!'````2````$D```!*````2P```$P```!-````3@```$\`
M``!0````40```%(```!3````5````%4```!6````5P```%@```!9````6@``
M`%L```!<````70```%X```!?````8````&$```!B````8P```&0```!E````
M9@```&<```!H````:0```&H```!K````;````&T```!N````;P```'````!Q
M````<@```',```!T````=0```'8```!W````>````'D```!Z````>P```'P`
M``!]````?@```'\```"`````@0```((```"#````A````(4```"&````AP``
M`(@```")````B@```(L```",````C0```(X```"/````D````)$```"2````
MDP```)0```"5````E@```)<```"8````F0```)H```";````G````)T```">
M````GP```/\``````@```0(```("```%`@``!@(```L"```-`@``$P(``!8"
M```7`@``'0(``","```E`@``,`(``#4"```\`@``0`(``$H"``!1`@``60(`
M`%P"``!E`@``C`(``)D"``#X`@``^0(``/H"`"@:-AH_&H4:!1H$&H(=EATX
M'VD?MA\J&H<:21KB'48:CQJ\&KX:9AWC'00>G!Y$'P(E"B6`)]LI>BI_*O0J
M4"M1*V$K'6(+;6,:8AJC&H4=Q1K/&LX:S!J$'88=%X7%`.0=!1Z>'IT>_1X`
M'SH?.0%&'UT?AA^W'U4!S!];`<X?(2.B`P`J#"LW+C@N-#$U,>`Q)@J-/Y<:
MX!HR`*ENYQHS`.8:-`"B`C$`L`#8(HL=C!V9'>4=4(4+'MP`'@($'P,?!Q\J
MA1X?7Q]M'XD?NA_0'V4!]A_W'_D?9`'T'QT")@(D(P0E&"4R)3`E-"6.`G4E
M2@.")_DG%"B+`Z8#I`.E`Z<#+P0R!($J@RH-*U(KU`3**\<K.2[%!4\NYS$O
M,WHW.3BZ"+D(-SA$.$4XC#^2079"DUR27+,4NA4A&B`:(AIH&HD:F!KY&N\:
M.P`\`/@:!AL#&_P:[AH6&SD`*!L<&P<;&AOZ&A<;2AVR`'(=%86T';,=LAW'
M`.@=*P`4'@\>%1X8'J@>+(5+'T\?.P%0'T0!BQ]"`;X?7`'2'Q8@_Q]G`0`@
M9@$%(!,@%2`[A1\"XR(U(S8C,2,R(^XD!254&H\"-B60`J@"I`)Z):,"AB4]
M`TP#AB=3*Q@HC`,]*'@HJ`.M`Z\#1G>`*"D$""HV!'$$<`1O!/4J#BNI!*H$
M^P33*]HK_`3;*ZX%#RY=+E\N9RY7+E!KPP;K,>HQ,`<W,T$',C,V,R(WSC>,
M"%@X43AW.#PXNPA:.(9\4SAO/'(\;CPUA:$)<SRQ/K(^J`J//ZH*JPJ6##Q%
MP@V-3(Y,DQ![3I00<5FY6Y9<FER[%20:<1H;A9P:11M*&SD;-QM#`#(;0AM"
M`$0;2QM$`$`;-1LQ&U$=#H50'4X=LP"W`)T=R`"U';@=[!TC'B<>)AX?'BL>
M(!ZT'K,>&`$E'SL?=!]'`48!10%K`6D!32!R`7$!.B!L`6\!1"!,(",@&B`R
M($L@(2!S`30@22!0("(@/R!1(%H@+R!V`>DB\B+S(N\B[2+L(N8B2",G`D0C
M/R,\(U,C5B,P`E\C0R-8(U<C*0(J`B\"1B,L`CTC+0)"(U0C52/Q)/(D\"0+
M):9J\2(])9,"E"6,):T"G"6L`JL"GR6I`ILEK@*))9HEJ@*(,4X#C2=0`_XG
M_R?])RLHL@.$*(XHG"BU`[8#A2CU*0DJ.00[!`LJ<@22*I`J`RNL!!XK8RL(
M!><K_BOF*]PKSBL#!?PKWROL*_8KUWGR*_`K^2L+!1,NKP6RA3LN/"Z"+LX%
MRP7,!7@NBR[-!9XNI2Z;+IPNF2Z-+H4NG2YU+H`&KP;3!O8QU0;4!M<&]3);
M,T('5#-2,T0'6#-$,THS83/&"'\XD3B>.,`(;CA\.)\X=3B^"%8XHCAY.,H(
MH3C$"*HXH#C""'D\=SQ^/*0)=3Q[/&0^*0J[/KP^QSZY/KX^MCY@"EX*F#^M
M"JX*K`I7"Y-!@$+="X-"P$+!0@X,EPST0_5#)PW,1LU&^DB?3)%,ETR43)40
MADZ,3H^&E4Z8$&Q2G1&U6[Y;QUN*%,%;J5RD7+44MA2W%*A<)V(F8BMB,V(T
M8BEB/1HH`)T:DQN*&TT`20!M&XX;H!NB&Z$;GQNC&PEO<AM1`(P;5AT/A1&%
MD!W+`,H`S`#M'?X=+Q[L<3P>-!XY'KD>M1Z_'E4?/0%V'WH?DQ](`<$?PA_5
M'X4@>`%?(),@B2!Y(/YJCR!I(&T@>@&4(&H@BB!W`?TB^R+X(B$"_"+V(F4C
M@2-C(V<C,0)N(W@C?R,S`C0"\R1+)4PEP0*P`K0"K26X`L0EO`+");`EOP*U
M`K$"O0*_);L"R26X):PELP*V`KH"MR77);<"8"=``Y8GGB>4)Y\GG2=2`P`H
M&2B0`Y$#22A**+X#NRC!*,`#P0.Y`[DHGBBT*+HH]BD3*A(J=RIY!)@J>P29
M*ITJ^"J@!/DJ*0`&*R$KK@0E*U4KS03+!-D$A"N#*S`L!RP,!38L`04%!0(%
MZ2L]+`@L$P41!;HNLB[D!;<NY"ZG+MH%U073!=4NX2[=+J8NP2[%+L`NWR[@
M+MXNU@6),;0&IC&Z,=D&_S'8!A<R&#(!,OXQ,P<,,T@':S.6,X(SBC-'!Z,S
M2P>B,X\S2@?Y,X`S)C<G-V@W:3=:"($WM#?1-XX(M`@<.,T(S`C/",L(S@B7
M.&PXWSC2".HXT0CD.-@XLCC..,@XI@F+/(@\D#R//*H)ASR)/(T\@3RH"8P\
M$PH:"D`^'0H>"F4^9CYH/F4*9@K-/M,^VSYD"L\^IS^C/YX_L`JO/[,*M0JJ
M/YP_&0M"041!.T%!03]XFT&>074+Q$7#1<9%*PTL#<=%+0W*12Z`PPW/1G9(
M=$C_2/Q(N@!0#UE+J$S3#]`/L$S<#[-,T@^D3+9,ITRL3-L/IDQG'PY.Q$X^
M3YQ.I1"?$)H0G!"B$*I.FQ#)3J,0G1"F3K).B!$:$HT4S%O96\I;V%O/6[=<
MN!2M7+E<-V+#%4%B/F*V8E%C8V-7&GD:LAJP&J\:L1K2&]4;70"^&[@;L!NQ
M&\@;6@!7`,8;S!OE&^,;M!MJ';@`GQW"`,$=SP#"'<,=11Y('N<`Z0!/'E(0
MZ`#%'LH>Q!XG'U@??1]*`=T?W!_:']D?N2"``=`@M"#*((<!HR#:(*0@A`&R
M()X@GR"U(((!@0'-((,!S"`B`@`CK".1(XXCC2.2(Z$CD".F(Z@C.P*<(Y8C
MIR,Z`C@".0(V`O4DA0())0@E5`A2)9H"Q`+?)<4"ZR7O)?`EU24-)@0F^24"
M)O@EXB79)><E:B=4`U4#JR=6`QLH+RB6`SPRE0.4`\0#T2C<*.8HX2C-*'J%
MXBC=*.4H^RGZ*1XJ1`2A*GT$?@3\*OLJ+RNR!+8$9BN9A=P$WP1<+"@%3BQ1
M+!D%$`4C+#$L?"Q2+"P%8"Q*+&$L&P48+L(%[P7C!>4%Z@7F!>X%'R\7+^HN
M(2\$+P4OZ`4Q,40Q0#&%!D(QOC'@!BDR&S+=!B,R+#(:,C`R.S(>,C<R.#+A
M!@XS40=5!^@SUC-2!\<SO#-2-+\SU3/^,V-/^S/?A;$S`30%-``TUS.>#"HW
M:S=2"%X(8`A?".$WD@C6"",Y_S@4.04Y$SD&.2$YW@@5.:\X]#@".44Y_H4F
M.=D(1#G=""0YI3RL":,\L`FB/+L\H#RJ/*\)K@FH/+8\LCRG/*T)JPFY/"X^
M%@H\/C`*;3XS"C$*YS[M/FX*[#[E/N(^L0K$/[T_SS_)/\$_T#^W"LX_[4#K
M0!H+[T!)05!!1D%*05D+34&F07H+>`M["ZA!W@OL"\="_T(>#/U"YD,*1)L,
M!$0+1`=$G0P51`A$_0S31=1%T$7717Q&E`V3#7U&@T:"1L8-U$;51M-&T$;2
M1OY&_$9W2'Q(>TBX#FJ&MPZY#E,/,W]2#U$/CTO33.,/RTS23.(/"4WB3-],
MQDQC$"1.]T[83MU.JA"F$/A._$ZH$*D0Z4ZK$.Y.K!#03@Y/XDX+3_U.>1UV
M4IX1>%*?$:`1=5)]4@\20E1F5!P2C%4%5JX2!E:P$I]8U!/Q6^=;Z5OO6\)<
MO%R[%,9<P%S!%,(4S5S)7+X4Q%SE%(%AQA7L:#(<^1L='/\;!!SP&P,<+A("
M'/P;\ALD'`@<-APN'&4`$!PX'#D<_1M6'/L;HQVF':$=T0#0`,<=R1U@'F0>
M61YE'F<>5QYC'NX`4Q[O`,\>'@'.'M`>T1[,'DL!30%6`0TA]""2`1,A[R#U
M(/D@`B$`(9,!D`$8(?`@]B!!A9<!&2$C`@4CR2,_`K<CS2-#`D("1`*^([LC
M10+;(\@CQ"/%(]$CRB/`(]D"W@(A)BHFSP(=)LT""R;=`LX"TP+6`B(FW`+1
M`B0FT`(4)C$FU0(O)AHF$B;4`ML")B8N=D,#O">[)[<G!2@&*%(H4RC-`]$#
M^BCK*,H#\RCU*.DH[RC4`RHJ,"HN*BPJ+RJO*JDJA@3]*C(KCBN3*X\K3RR9
M+#,%?BPW!70L2RQS+'4L*@4?!58LJ2R++*8L.063+*XLGBRG+$4N\@7X!2XO
M]P52+S`O6R_T!1DO&R_Q!3$O72\W+S4O4R_U!5PO/R]+,8<&:0^+,;8&FC%0
M,D8R3C)`,ND&2S)(,NL&8#)$,DTR-`<W-"0T8@=<!QLT-C1@!RPT&316-$<T
M/C0>-.&%%30B-"<T6318-%4T,#0C-"XW*S<P-VPW80B+-W\(Z3?J-^4W:SGE
M".8(<SE7.>D(\PA=.58YCSE;.1PYFCF;.9DY[@B!.7$Y[0CL"'(Y7#F6.<0\
MVSS,/-`\XSS?/+,)UCSN/-4\M0DG"C4*-@IZ/G$*]3X"/[@*P@KB/^P_U3_Y
M/]\_YC_("L`*P0K$"N0_X3_S0!\+'`L="TT+5D%505A!5T%>0<-!APN""[1!
M?0NQ0=\+``S+0LQ"*D,@#!9##T,B#"0,/T,K0PY#)$,A#"%#&$/=0Z0,I0PD
M1#9$`0U815E%`PUB1=I%V44W#>%%Y47H1=M%.`WB1?!%F0V8#9<-R0W:1MU&
MQPW;1MQ&V0W;#0U'"T<41XY(ADA[#H=(@TB+2'P.O0Z\#L,.)$G!#K\.Q`XE
M26)+DTN92Y=+?@]_#\1+QDL*3+0/LP]`3#Q,.TSV3/],[DP$30--!TV#AN8/
M]TQ9$%H0+4YD$"=.*4X?3U=/M!"Y$+<0M1`A3\$0L1`83UA/LQ"Z$(P1BQ&-
M$812GU*;4HE2IE*24H]2H%)/5'A4>E1N5'M4A%1S5'@2=Q(-5@M6&5:R$M83
MT%I%%)(4E13Y6PE<"%S&%-Y<45WG%.@4VUW?7=Y=UEW@785A8&)98LL55F+-
M%?$5O6(B%R$`0AQ9'&\`1!QF'%(<5!QQ'%`<>QQ\'%@<<`!D`'D<;!QX'*@=
MT1W/'6@>=A[4'BT!H!_$'U@!6"%,(6@AI@%)(:0!GP%=(2DAKG-4(5,AHP%:
M(:`!.B$_(2LAZB-*`N\C1P)(`MTC_B-5A=XCYB-)`N@C_R,#)/<DIC0?)9X"
M6R5=)5XE-W7H`BLF[`([)NT"Y@)A)CHF;B9+)FLFZP+G`D4F3B9H)CTF<28_
M)F\F=2;I`G,F+"99)E0F3R9C)EP#70/()V`#PR=;`ULH82B9`R$I"BD)*=@#
M+"D(*=H#W0,J*14IX`,0*1,IY0,O*1@IUP/C*3DJ-2HZ*C(J3@2,!(@$C86[
M*KHJ-"LY*\X$G(7E!.8$F"PR!=`L0`5'!4P%URRJ+#4%H2RD+#`%[BQ#!><L
M307H+-XLMP7S!7XOBR\"!@L&>2^&+Y,O!`9S+VHONH5L+P@&?R_\!;(ONB__
M!0`&9B]T+XL&6C&-!DXQ33&-,8XQK3'*!L<QRC'+!LDQRX7C,5<R\P9C,F<R
M&C,9,Q8S-@=J!YXTMC28-',T:P>:-(XTMS3;-*4T;#3!-(0T<0=H!Y4T>C29
M-'('N#2Y-'`T+@@U-V((D#>[-^TWF`BU".L(P3G#.<XY^PCX"*TY!#KU"+DY
M"`GG.0>&"#H&.@H)"CJP.08)^#D,.OT(L3GZ"`(Z!SH).@$Z%SK_.1(ZN@FY
M"0,]!ST!/?4\\3P(/?(\#SV["?X\&`I`"CT*&C\0/PX_`D#S/\T*R0K[/\L*
MR@K."AM!(T%A06A!7@MG0=-!D0N,"Y!"X0L"#-5"UT+60C!#*PPF0RH,0$,4
M"AY#K0RC#*L,1T2O#$M$441/1$)$1D0$#6Y%;$7R140-\47U1?-%^44]#4<-
MG`V:1I-&D4;A1N`-Y`TA1QQ'%D<71S9''T>`#I-(F4B:2)Q(R@Y)2=0.-$DW
M2=(.+4G+#DQ)S@[3#DA)1`](#SM+10^!#X8/A0\(3!I,HP\=3+4/24Q%3$1,
MFTCZ#_D/*DTN3?L/\@\Q3>\/&DTT31=-6Q!F$,X0'4]Q3X1/@$]R3Z%/M`%Y
M3Y%/R!"?3ZU/T1#%$"-/TA"%3YQ/MT]84EI2CQ%74K)2IQ&N4J41I!$1$D54
MG%245*-4CU2E5*E4IE2*5*!4D%2259%5E%6U$B96,E8H5K02O1(<5KL2*U8@
M5KD2*5;"$KX2NA(A5CI8MP9;6%A8?%A8$Z98KEBM6&59FQ-^69P3?%E_67I9
MO5G:$]X3P%F[6:U:KUK66DT41A1'%$L43!396D@4F1027`Y<)5R;%!-<[ES.
M%*M<]USK%%E=5%WR7?!=Y5WV71P5C!6'8=$56F+6%=,5;F+4%=`5U15Y8@L6
MX63F9,87Q&K2:H`:)`"!&H\<EQR('(D<=`!Z`($<8!UD<,,`0BK3'=0`U0#2
M'=8=<Q[[`'`>]P`R`3.%J!^F'\4?ER'>(;H!OP&6(;0AQP&%(;<!FR&@(;D!
M62'#`88AO0'0`:\A>B'!`;X!S0&>(<L!J2$/(PXC&B1/`A\D4P(\)!@D/B0F
M)%4".B1D="(D40+[)&,E9"6?`J@FHR:")H@FH2:%)I@F_@*9)OL"B2:!)I8F
M@";Q`O4"D2;O`@0#`P/T`L\F\P("`_<"^@+]`NX"AR:@)O`">2;R`H8FJR:J
M)J0FC29^)D0#U2=B`W<#R0D>*%\H7BA$*3XIZ`-(*1PI[P-;*4TIY@/M`U<I
MYP-3*4\IZP,[*48I+015!$8J1RI3!$@JP"J]*K\JD`01*[X$/BL[*[T$.BO/
M!-`$[`2G*TL%ZBQ(!0<M(BT,+54%406S+-8LTBQ.!>,LY2SI+&L%7@41+?TL
M8`5G!1XM("TA+1XNN`7B+]XOYB\4!@\&!P83!O@O%P;^+\$OOR_W+]$O7S%@
M,6$QF@:X!M$Q]P;X!GTR:S)_,OT&]09S,H$R;3)I,OH&.`<>,^TTAP>`!X@'
M>0<#-7P'_C3E-!XU`C6#!X4'"37*-``UY84!-1@UXC3/-'L'+C7%-/\TA@<<
M-<,T-`AO-U4(;C=H"+XWG`CT-RTX_`BV.74Z'CH:"1@Z%PE(.AL)3SH3"4(Z
M:CIP.OXY!0D'"6TZ'`E[.GXZ63H1"5<Z%@F`.E`Z%0DI.G8Z*CI,.BH]RPDU
M/2P]-ST=/<4)P@DX/<T)-#TK/3,])STD/<H)+3TR/H,^@CZ'/@8_)#\X/RH_
M+#\K/X,*+S\H/Q=`U@K5"AE`.$#1"A]`%$`\0/<_'$`50!A`.4#Y0"1!-(92
M"U\+;D%M07%!CD&5"^5!G0N8"YX+E@N40K-"`PS90B\,2$-)0T-#,0PS#$)#
MWT.T#&-$=D2P#%]$9D1F17%%"`T'#79%A$5U1?]%!T9.#0Y&"490#5(-H0VC
M#:4-S`WG1N)&54?O#>H-0T=71VQ'0D=31^T-04>%#H0.ITB@2*9(I$AT2=L.
M64G9#F!)5TEL27Y)9$G7#EI)74G:#MX.V`YV24U)=4G5#M-+UDN<#YT/8$Q.
M3$5-.TW^#TA-0DU)34!-%$U!30<0[TWV30-.:A#M3^<0VD\84-)/"%#B$`!0
MWQ#A$.40%U!&3Q10TT\%4!]0`E`64,U/YD^1$5U2U5+A4K01L!&U$:X1[E)'
M5$94+1(L$KM4*Q*_5+14*1*U5'\2FE5#5LD2RQ):5L42QA+*$C56.%9"5DE6
M759+5CU6TA+0$BT3-1-@6%Y8?UA^6(-8;!.Q6(=9G1.@$XA9@UFB$Y\3AEF+
M68)9REG26>L3XA/46<E9L%HV%#(44!3R6N1:\UKJ6D\4_5I2%)U;*UPJ7)X4
M*%PI7"Q<H!2<%#I<,%PW7#M<T10*7>\4\!3Q%/Y=(%X=%0M>'Q487B)>'A4;
M7@A>(!4.7A->CA61%95AW8.0%=<5C&)[8G]B@6+9%8)B]!7V%6`!]17S%>YB
M[6(,%NQB7V-O8U$6;6.F%J<6J!8G%R07)1?P9"H7=!?'%ZEFYQ?M%^!FMQHN
M`'L`S!R\''P`JARY''T`JQS#',T<?AU^'GD>_0`CA>$>X![G'H`?JQ^J'ZD?
MX!_J(=H!UR'6`=L!P2$5(UL";"1<`EPD4"1A)&HD:216)&`D9B1?)",E9B5H
M)08#"P/.)@T#Q2;#)@H#$P/0)A`#$@,)`P@#$0,/`W0G=B?<)]<GVB?;)V<#
M("AM*68I]@-D*6XI?H5@*4(K6BMN*V0%;`4P+3HM*BU#+1DM,2UM!3TM>@5U
M!0T&"#`R,#@P'@8Q,!L&&3`J!A$P'P8B!BDP'3`E!B<&*08\,"0&1C!',"@&
M)@8Z,`<P(P9K,9\&<#%M,;$&Y#&3,@,'!P<,!P8'CS($!PD'DC(%!XXR"`=&
M-98'G`>?!YL'F`>9!Y0',36-!Z,'/C63!WPU0S62!W,UZ(55-8X'C`>%-4TU
M4#5'-6<U-C5D-6$UF@=]-40W0#=Q-W,WG#=J"&T(A`C!-Z`(^C<Q.#(X'0DF
M";@ZJ#HS"9$ZNSHX"9HZ,`DH":DZ)PDJ";4Z;#KH.C$)W3K:.N8ZK#HT"2X)
M.PG9.N,ZZ3K;.BD);SW2"=@)2#W/"4H]:SW9"4\]5SUT/<X)TPG0"44]43UM
M/:$'43Y0/DX^1PI!/XL*+C]&/]0*)T#>"DA`4T`]0-\*74!60-<*'D!'0$-`
M6$!)0.$*3$!%0#Y`+PL!01Y!8@MC"WI![D$"0I="F$+B"P0,0PQ=0V1#4T-8
M0X)$D$2*1+X,>D1]1+H,BT1X1+P,3H:-1(A$DD2!1'Y%@T4-#0X-$0V`10\-
M$@U5#0]&60U;#1U&5PVA1J1&S@WI1NI&_@UB1VM'_`U>1_4->4?Y#?H-;T=H
M1X@.B0ZN2(H.APZ+#K!(Y@Z02>T.BDGE#HM)F4F52>`.ATEX29=)B4F82>$.
M6P]<#Z-+CP^+#XT/W4M73+D/8TUJ36Q-#Q`9$!,074UU31@07TT6$'U-;4U3
M$(V&04Y/4(10]A!_4/402%`J4'M0<E!D4"Y07%!34/<005#(4/`08E"`4#Y0
M@U!Q4/D02E!54%A0DA&5$981_%+]4A53N1$64_]2O1&X$1(26%3/5.!4@!*!
M$IH2F!+G56I6@%;4$F]695;:$GA6?5:(5M82VQ)D5GY6W!)G5F-8B%AQ$\U8
M<A/)6*@3[5GP$]N&\1/]$S@4-Q0Y%+%:5113%`1;GEN@6T-<1EQ(7$5<0%Q,
M7-44O10,71-=%5WU%&M=9UU=7E5>-5XA%5E>+UX\7H]>7%YJ7F)>7UYK7FY>
M.UY$7D%>FF&2%9EAWA7;%=H5CV+?%99B^17X%?H5]&+\8@X656-#%GEC5A93
M%IX6[F/U8ZD6"V3Z%O-D,1<P%_=D_V3U9#(7[&3Q9"D7+A>:9787XF8]9UUG
MZ&BE&.MH[VCN:(%J%&O0'-D<W!S8'(P`X1SK'(L`B0#T'.(<WAR-`(8`UP#T
M'00!!P$#`>T>ZAXB`3(?40&N'[`?80'[(0,B"R+I`0<BY0'X(>0!*"(>(N,!
M&"(1(E$B!2(7(Y(D90*,)&,">"2$)',DK227))4D=R1R))8DC200)8P";"4:
M`^<F%0/D)B`#(0/O)B8B'`,;`_`F>RG^`X,I!`0!!(LIC"D`!'@I4BIM!),$
MT"K/*J$$LRNT*W8%>05R!7LM@P5O+8$M/"U"+3@M,RVFA6`M:2U]+88M+"XH
M+C@&3#`P!E<P?#`T!CH&53!B,'$P:C!6,#LP@3`U!D\P?C!D,#\&0`8R!C$&
M-@9Q,;IZ#P>E,IHRG#(0!Z8R#0>D,H\UQ37(-9(ULC6I![0'K`?C-<`UUC71
M-9\UHC72-;@'K@?S>^$UU36=-;,'N@>8-3\(=#>A-SP)\#KS.D()0`D;.PP[
M'3LT.R@[%SL^"40[0CL$.Q$[^CI*.Y$]CCWA"8L]C3U_/8P]?CU\/8,]Y@F(
M/>`)%0J4/I,*53]3/T\_5#]L0&5`9D!A0&M`:$!V0.<*8$`/?G1`!D$.0JT+
M!T*N"^,+N4+U"[="XD(&#'1#=T-V0W5#3PQX0W%#5`QZ0UL]>T.F1*Y$N$3+
M#.,,R0RQ1*]$$PV)18=%%0UA#2E&9@TJ1F0-+48L1F`-,D9C#>Q&\$:!1YY'
M@T<*#I)'!`ZC1Y]'DT<'#H9'N$BW2(T.CPZ0#I(.[`[(2;9);(;12><.J$FK
M2?(.LTG-2>X.STFD2>\.3`]!2V]+<4M>#U\/=@]T#W(/D`\C3%M,O@]A3%],
M@4TF$"40A$T33G002DY,3OT0!1$!$;U0E5`)$9)0PU`,$990I5"U4+-0HU#D
M4-A0U5`-$;=0K5#:4)-0-E/`$<41R1$]4RM31U,Y4]4115,=4T$2_U3J5#,2
M]50Z$@!5[50#5>E40!)"$NI5Z!*;5HY6HE;D$IQ6E%:05JE6K%;G$I]6YA+A
M$IU6.1-G6%P3=1/06-98U%B869I9EUFN$[`3^A,+6@A:`5JT6K-:6Q2A6Z);
MI11:7*(485Q?7-L4VA0E77M==EU\7205B5[V7K%>K5Z27H%>A%XF%:Y>D%Z>
M7I@5EA6:%:)AIV&7%>$5X!7C%>(5H&*=8I]BT&+[%=%B$A84%EEC119D8UP6
M71:X%AEDNA849!5D&F0#%S47-A<Y%P9E+1?X9`%E>A>^9;QEMV6V9<!E>!>X
M97L7?!=^%\1E?1>_9<D7VF;D9NEFZ&;J9N5F\Q<F9QH8&1A`9Q\8IABG&*@8
MJQBI&"X9O6I>&94`DP"2``X=E@#W')<`_!P-'0$=VAW9'=L=AAZ.'NX>,Q^Q
M'_4!1R(M(E0BZ@%+(E(B,2)$(E8B4"(K(O,!32(W(D\BHB2W)&D"LB1K`JHD
MM22P)&P"M"2D)*<D:`(F)?XF*`,$)R8#_"8E`P8G"B?Z)@TG`"<.)VL##P0(
M!)$I#`2/*9`IF"FD*9LIHRF6*>0I6BI@!&($7BJ8!+@K5RU<+:8ME2V(+8H%
MHRV/+80%9"U_!5DM>"V"!84MARV>+98%B068+9PMC06\!2\N@#";,(XPC3"4
M,,8P1`:H,(,P/`:Y,(8PM#"O,)$P3@:J,*$PIS"V,K,R%`>\,JPR%0>M,@XV
MS@<<-AHVX`?"!PLVOP?O-0PV\#4B-L0'V#7/!Q(V^C7(!RHVS`<0-LT'QP<I
M-ODUZC4L-B0VMQCI-5(W3S=3-T,(M@@0.V4[=3M1"4H)30E6"=`[4PE<.ST[
M<3M9"9$["SMY.X$[CSM."5D[=#ON":X][`FC/:T]ZPGO":L]ICVB/>T)\AY7
M/E4^F3Y+/WI`\@KO"O$*C$"$0.T*\`J"0)-`>T#N"@E!&QA0"V8+A`*X"_8+
MBD-7#)!#7@S&1--$P$321,=$PD09#9]%G46>17`-049N#3A&.D9"1G(-=@T^
M1K!&KD>S1Q(.'PZ_1Q$.%@[-1QD.LD<D#A0.)0Z5#I8.DPZ4#L1(S4C"2,9(
MPTC)2,=(H`[X2?L.[4GB2?P.``_X#MQ)`DH!2OD.UDD$#^1)_DD##P!*_$G]
M2?,.]4G_2?H.ZTGE27A+KDOG2[\/94QJ3&9,:$QK3)1-H4V2399-DTUY$!`1
M`5$4$?A0#A'U4!H1!%$9$2$1(Q$?$1M1`U$S4311[5`E$2L1-5$6$051(A$;
M$<X1SQ%]4\L1T1',$7%3%Q)<5.94#U4;55$2J56E5>Y5L5;M$LQ6SE;T$K=6
M\1*U5NE6M%;X$K-6P5:O5LI6T%8O$UX371..6'83=Q/I6-M8?A/K6*19MA.B
M69U9LQ/\$P,4`!0J6BA:"A0"%+A:MEJY6K=:(ELK6R=;&5ND6X<4LUNF%'%<
M:ERI%-X4B%V,7;]>N%Z^7MQ>Y5XN%2T5U%[67C`5VE[M7O->VUXK%;E>XE[K
M7J]AGA6R8;-AGQ7E%>05HV*E8OT5_!47%AD6"F,8%H=CB6.,8^]C*F0B9+\6
M'V0\%QEE:Q?*9=IE@Q>!%X`7WF7(9>!ERA>V9K5FSA?T9O87:V=I9W)G8V<Y
M&`UIKA@!:0QIM1CX:+,8M!C^:`)IA&HB&:MJJFH='18=F0`K'1X=&QV0'I0>
M%!^)<@("9R(!`GLBH0)?(F$B_0%S`G0"<`)V`G4"<@+#),HDNR3`),0D`24?
M)Q@G$2<5)RD#$B<<)RH#(B=Y)Z8I%@2S*:LIZBJ9!%LKTP3U!+<MSBVY+;TM
MSRW`+9DMERV4!;LMT"W$+3$N5@;3,,`P6098!E4&4@;<,-$PR#!7!M4PPS(;
M!QP'OS+%,AD'S3+!,@8S/P<D,V,V0C92-ML'0S8S-N(';#97-M<'3#9N-MX'
MY0?D!^8'U@<W-M\'<39*-C8VW`=3-MH'139P-M,'T`=<-E@W5S>&"(<(K0BW
M"%@):@F[.V()80F^.VD);`EE";4[TSN?.V8)MSOU.[<]]0F[/?0)T3WW";H]
M^`FV/<P]^PG\"=,]FT#U"O@*ED"B0)U`"D$.03P+@4$L0C="-D([0L4+H4)B
M#&,,F$-G#)9#9@S9#-L,UD3K1-@,W$0;#:5%J44T9%-&149Y#4]&?0V]1KM&
M\48L#C<.[$?M1S`.F@[32``6X4@%#QE*!P\)#PH/)THF2GD/P@]N3*]-.!`W
M$*U-(1"J31A.7A`]$3<10!%O44Q1'1%"43,17%%P45]1-1%:44M1/U&*4]@1
MBU.A4XY3W!'>$9E37E1?5"15IU7J5OU6^5;C5N56^A+[$NQ6/1,[$S\37Q/R
M6'\3[UB$$Z99O!,4%`\4.UI#6@X4,EHQ6S!;8!0M6SQ;IUNE6ZL4K!2J%#==
ME5V.7005EET(%45?"E\S%305_5X77QQ?!U\Q7S)?+%\P7P-?!5^B%<)AI!6X
M8:45P6&G%:85YQ6K8K=B_Q7^%15C%&,=%AP6#&,78V<6DV.4%M)CQ1;(%C9D
M,60S9#QD+F0Z9,D6/63'%K5D(F4C92!E'&4=96P7H&6*%^]EZ&7K98@7AQ>&
M%^%EYF7/%]`7^&;U9AP8(QB#9Y1GA&=)&(MGCV=#&(QG2!B)9T<8CF=&&#\8
M1!@D:0]IOA@3:0IIPABZ&+P8QA@J:1IIR!@G:19I(6DC&85JK&K&:L5JUVI3
M:YT`*!TG'=\=)`$U'[,?!P**(GTBB2)Y`LTDT"1X`BLG,R<I)S4G,2<W)S8H
MOBD9!+DI'`2[*1@$XBW;+=TMW"W:+:^%V2V]!5T&WS!:!EX&X3!<!NXP6P:U
M,=0RU3(A!]`RT3+.,M<R(`<R!WTVBC;R!Z<V]0>9-H(VB#;N!^P'AC;J!Y@V
MG3;M!_,'CS;V!ZHV2`A=-TD("CAU"=<[UCOE.V\)>PES"=D[VCOJ.W`)]CLY
M?7@)XSW^">D]``KK/>\]\SWJ/0$*(895"E8*G0IQ/_D*KD#_"K-`_0JL0$,+
M00N#045"3D)$0J-"I4*F0Z1#;PRI0Z]#B@SE#.8,\$3X1/%$?PU)1K4-M@V[
M#<)&\D;S1OI'0`[V1_Q'&$@(2!)(G0Z<#MM(VD@/#Q$/#0\L2DU*%`\3#T9+
M]DLK3'1,N$W(38(0@Q!-$9)1DU%/$7]1JU&744P141&L4>X1Z!'+&,Y3ZQ'-
M4^(1YA'!4[%3QU/L$4!561(_53E571)#55<26Q)6$JM5_A(?5PE7#%<`$P$3
M0%A"$Y988!/V6/=8'11&6D]:/A1I%&44/5M!6V9?>%]=7VE?=%]]7VY?<E]S
M7V)?2%]37U]?:%\X%7]?:U^N%<1AK16O8JUBLF("%A\6&F,;8R(6(!;UAFP6
MFV.?8V@6;19N%J`6SA;0%M$6RQ9`9-(61V33%K=D(!=.%TL7<A=P%Z)EDA>/
M%P!F\V60%S>$]679%]47O68`9P)G^A<T9TEGGV=+&*-GS6>99YUGT!C.&#EI
MSQA$:<08S!@U:=(8-1FO:@,*+QV>`*\`CFL,`I\BFR*>(I8BE"*@(GP".R<P
M`S$#.B?!*4TK72OS+:$%G@5H!F$&]C#E,.HPYS`%,64&^3!F!FH&JP:K-NTV
MLC:P-K4VOC;!-L@V^0?`-KPVL3;$-K\V6`B*"`@\`SS].Q`\`CP3/`0*^CT`
M/KE`O$`""UM"44)/0NM"N$-Y#+E#P4/`0[Y#"T7K#`=%"D4(1>D,#44&115%
MKT4@#2$-@0WU1DT.60XN2%@.&TC1@1I()$BE#JD.YDCC2!H/&0]=2D]*9DI;
M2D=+M$N6#Y@/EP_Z2RY,WX+(#\Y-0Q!%$!E.4A%7$<Q1LE%5$;M1P5%6$5@1
M\A'I4^Y3\%/64PY4VE-(54I53E5-5;%5L%6S50<3.%<R5P@3+5<*$S17&P\I
M5W1881-B$P-9PA/&$ZE96%H>%"44OUK!6DI;K%NP%(E</5T\7:E=H%\]%9!?
M/A637XM?K5^[7[A?1A5%%9Q?V&'780,6)A8G%EUCJ6/:8Y@6K1;5%MH65&39
M%E5D2V3=%C]DN605%Q87%Q<A%SAE-F5`94P7.V4Y9:1EEA>8%PAF#&:;%Q!F
M_Q<'9R48TF=/&,)GNV?,9\MG5AA4&$UI8VE.:=@84&E5:=<87FDF&9!JLFJQ
M:C@9RFH":R=K)FN*&:\BX"3<)#0#.2<U`VJ%?"?S)W"%H0-K*,0I"S$(,0HQ
M;`9M!MPQ*0<J!^$RWS+.-M0VXS;7-N(V``@("`8(!0C8-M4VTC:Q"(@)'CPL
M/"4\\SL$/@@^%3X)"L1`R4#'0,A`J4+&0\5#&$4:12!%(@UF1F1&:D;5#6$.
M70YB#D\.8`XU2#1(J@XB#VQ*(0]N2G%*1A#43=9-&DYB3F5.=D[;4=918A'G
M46`19!'T4;:&_5/54P=4]A$/5/A3P889$H=5D1*U5?55#1,_5T-73%=E$PM9
M:UIH6G!:=5IW6C\4PUI+%>E?ZE_+7\5?QE](%>U?TU]2%>5?2A51%=M?ZU_@
M7\%?4!5,%=UA[A4$%@86+18N%B\6>Q9X%G<6LF.T8[%CM6/R8Z(6H1;C%E9D
M&A<9%U<71&6>%R9F'V889B%F%V;=%PEG!1@H&,5GWV=@&.-G9ACI9^YG9QAH
M&&9I>FG>&&YID6F#:79I?FEM:>$8E6KC:FD9=QD#:P1K&8<7:Z8`-AVE`#8?
M%`)")S8#.`-$)T8G?B?**<@IS"GP*G`&A3'E,N<R*P<1"`H(]#8-".DV%@@0
M"`D(#@AZ"#T\C`DV/)$)%CX*"A(^#SX7/A$^"SX("@L*S4#00,Q`SD#10`<+
MB4'R#&]&2TA$2%5(K@XD#R8/)P]_2G%7F0\O3'I,>TQ\3%\1:A%Q$?Q1$%("
M4FP1;Q'N40-2:!$-4A-2"%(/4AA4$E0!$F@29U5E5;M5:5=B5Q,3;E<6$V%7
M&!-D5TU745B)$\@3@UK&6H04'V!4%01@%V`(8`5@5A7S7QY@`F`:8!M@)V`<
M8%H5M6(%%@<6,V,Q%C1C,6.X8[ICHQ;\8^L6'!?#9%H7365;%R]FIA>J%Z47
MR6;A%\AFQ&8J9SAG4&<J&`IH^V<$:/QG_F=R&&\8<Q@":/9G&VCY9Q5H$&C_
M9P!H#&AK&.88E6FE:>D8[!CH&/`8F&K!:HP96FMD';LB%0+F)$DG]R=Q`R8$
MT"G&!,(KJ`41,7,&_S;^-OTV%0@!-Y@)EPE+/$T\1SS30&A"9T+7"X`,T4,P
M13)%+D6(#9UKR4;(1FD.5DA12&L.*0\H#X5*B4J.2H1*7Q!J3BM2+U(H4G01
M%E(54AU2&E0"$FH2E!*\5757?%>*$Q%9$EE<6[M=9!7T7UX5814M8&459A7D
M8C=C-F-G8[YCO6/B8VAD9F3(9,IDQV3<9%\73V6I93QFKQ<[9LYF#1@49U-G
M?!@N:'H8'VAV&'D8?1AW&+!IO6GV&/$8KFG$:7MJ"PPI&9YJ;QD%:YH9:6NA
M:\<B'2-*)],I:01R*P(NJP4U+B<Q'C$?,2P'+0<'-P8W%PB:"50\'#X@/OA&
M;@Y=2%A(+`^22DY+R@]X$082)U0'$H%7@U<@$T184Q/.$WH4>11"8$U@5&!.
M8&L50V!G%6T5/&-`8\!CA1:P%O,68Q=:95%FMA?=9H(8?Q@X:(8816@Z:(08
M-6C\&/T8^ACQ:H<9DVN:'AH"&0)!4M<I=08H,1H(&P@9"%,\63R<"2$^$`IO
M0C=%M45B2%Y(]4A[$7P1/5(($BU4B56-5X=7D%<:69E:013C%'(57V!S%6@5
M5F!A8%M@6F!<8&5@-19!8X@6G19N9&QD;61U#JIE7&989MYFCQA/:%%HCAA3
M:`49!!G_&/QI.6N>&3X=5`'2(H$"3R<4-_H,<D9S1C(/<!)N$I%7UH9\%+]=
M=15L8'05=Q7F8D5C-Q;(8^1C766Z%R%G$1@L9U=GDAB9&%UH86AE:`AJ"ADJ
M&2L91!EY&45KJ@!(`P4N[S(;-QTW)3XD/FU(M`Y"4DE2#1)X58I5EU=4$YM8
M'%DP%*):"18X%C86BQ;W%F87O1<>&&QHEAAO:`T9#FIS&0AK'6NC:SL#/`-@
M*QPWH`G[#/UL\TB!$9M7IUK$77@5>F"-%G,7869C9M=F=FBF&:5KK05G/!$*
MJSY*4GU5G5=36&5;>V`Y%LUDW62_%S!G%FH/&:<9M1G<"S$4YV(8:J)JJ!E\
M:R4-GDJ$8,$7'&J0#7%(RF.6$G\4$!FC:@H6>VB7:Q(9.A908SL6````````
M`````````````````````````$Y93@%.`TY#3EU.ADZ,3KI./U%E46M1X%$`
M4@%2FU(54T%37%/(4PE."TX(3@I.*TXX3N%114Y(3E].7DZ.3J%.0%$#4OI2
M0U/)4^-3'U?K6!59)UES65!;45M36_A;#UPB7#A<<5S=7>5=\5WR7?-=_EUR
M7OY>"U\37TUB$4X03@U.+4XP3CE.2TXY7(A.D4Z53I).E$ZB3L%.P$[#3L9.
MQT[-3LI.RT[$3D-105%G46U1;E%L49=1]E$&4@=2"%+[4OY2_U(64SE32%-'
M4T537E.$4\M3RE/-4^Q8*5DK62I9+5E46Q%<)%PZ7&]<]%U[7O]>%%\57\-?
M"&(V8DMB3F(O98=EEV6D9;EEY67P9@AG*&<@:V)K>6O+:]1KVVL/;#1L:W`J
M<C9R.W)'<EER6W*L<HMS&4X63A5.%$X83CM.34Y/3DY.Y4[83M1.U4[63M=.
MXT[D3ME.WDY%4411B5&*4:Q1^5'Z4?A1"E*@4I]2!5,&4Q=3'5/?3DI325-A
M4V!3;U-N4[M3[U/D4_-3[%/N4^E3Z%/\4_A3]5/K4^93ZE/R4_%3\%/E4^U3
M^U/;5MI6%EDN63%9=%EV655;@UL\7.A=YUWF70)>`UYS7GQ>`5\87Q=?Q5\*
M8E-B5&)28E%BI67F92YG+&<J9RMG+6=C:\UK$6P0;#AL06Q`;#YLKW*$<XES
MW'3F=!AU'W4H=2EU,'4Q=3)U,W6+=7UVKG:_=NYVVW?B=_-W.GF^>71ZRWH>
M3A].4DY33FE.F4ZD3J9.I4[_3@E/&4\*3Q5/#4\03Q%/#T_R3O9.^T[P3O-.
M_4X!3PM/25%'44912%%H47%1C5&P41=2$5(24@Y2%E*C4@A3(5,@4W!3<5,)
M5`]4#%0*5!!4`50+5`14$50-5`A4`U0.5`94$E3@5MY6W58S5S!7*%<M5RQ7
M+U<I5QE9&EDW63A9A%EX68-9?5EY68)9@5E76UA;AUN(6X5;B5OZ6Q9<>5S>
M709>=EYT7@]?&U_97]9?#F(,8@UB$&)C8EMB6&(V9>EEZ&7L9>UE\F;S9@EG
M/6<T9S%G-6<A:V1K>VL6;%UL5VQ9;%]L8&Q0;%5L86Q;;$UL3FQP<%]R77)^
M=OEZ<WSX?#9_BG^]?P&``X`,@!*`,X!_@(F`BX",@..!ZH'S@?R!#((;@A^"
M;H)R@GZ":X9`B$R(8XA_B2&6,DZH3DU/3T]'3U=/7D\T3UM/54\P3U!/44\]
M3SI/.$]#3U1//$]&3V-/7$]@3R]/3D\V3UE/74](3UI/3%%+44U1=5&V4;=1
M)5(D4BE2*E(H4JM2J5*J4JQ2(U-S4W53'50M5!Y4/E0F5$Y4)U1&5$-4,U1(
M5$)4&U0I5$I4.50[5#A4+E0U5#94(%0\5$!4,50K5!]4+%3J5O!6Y%;K5DI7
M45=`5TU71U=.5SY74%=/5SM7[U@^69U9DEFH69Y9HUF96999C5FD69-9BEFE
M65U;7%M:6UM;C%N+6X];+%Q`7$%</UP^7)!<D5R47(Q<ZUT,7H]>AUZ*7O=>
M!%\?7V1?8E]W7WE?V%_,7]=?S5_Q7^M?^%_J7Q)B$6*$8I=BEF*`8G9BB6)M
M8HIB?&)^8GEB<V*28F]BF&)N8I5BDV*18H9B.64[93AE\67T9E]G3F=/9U!G
M46=<9U9G7F=)9T9G8&=39U=G96O/:T)L7FR9;(%LB&R);(5LFVQJ;'ILD&QP
M;(QL:&R6;))L?6R#;')L?FQT;(9L=FR-;)1LF&R";'9P?'!]<'AP8G)A<F!R
MQ'+"<I9S+'4K=3=U.'6"=N]VXW?!><!YOWEV>OM\57^6@).`G8"8@)N`FH"R
M@&^"DH*+@HV"BXG2B0"*-XQ&C%6,G8QDC7"-LXVKCLJ.FX^PC\*/QH_%C\2/
MX5V1D**0JI"FD*.029'&D<R1,I8NEC&6*I8LEB9.5DYS3HM.FTZ>3JM.K$YO
M3YU/C4]S3W]/;$^;3XM/AD^#3W!/=4^(3VE/>T^63WY/CT^13WI/5%%24551
M:5%W4791>%&]4?U1.U(X4C=2.E(P4BY2-E)!4KY2NU)24U134U-14V93=U-X
M4WE3UE/44]=3<U1U5)94>%255(!4>U1W5(14DE2&5'Q4D%1Q5'94C%2:5&)4
M:%2+5'U4CE3Z5H-7=U=J5VE785=F5V17?%<<64E91UE(64195%F^6;M9U%FY
M6:Y9T5G&6=!9S5G+6=-9REFO6;-9TEG%65];9%MC6Y=;FEN86YQ;F5N;6QI<
M2%Q%7$9<MURA7+A<J5RK7+%<LUP87AI>%EX57AM>$5YX7II>EUZ<7I5>EE[V
M7B9?)U\I7X!?@5]_7WQ?W5_@7_U?]5__7P]@%&`O8#5@%F`J8!5@(6`G8"E@
M*V`;8!9B%6(_8CYB0&)_8LEBS&+$8K]BPF*Y8M)BVV*K8M-BU&++8LABJ&*]
M8KQBT&+98L=BS6*U8MIBL6+88M9BUV+&8JQBSF(^9:=EO&7Z911F$V8,9@9F
M`F8.9@!F#V859@IF!V8-9PMG;6>+9Y5G<6><9W-G=V>'9YUGEV=O9W!G?V>)
M9WYGD&=U9YIGDV=\9VIG<F<C:V9K9VM_:Q-L&VSC;.AL\VRQ;,QLY6RS;+UL
MOFR\;.)LJVS5;--LN&S$;+ELP6RN;-=LQ6SQ;+]LNVSA;-MLRFRL;.]LW&S6
M;.!LE7".<))PBG"9<"QR+7(X<DAR9W)I<L!RSG+9<M=RT'*I<ZASGW.K<Z5S
M/76==9EUFG6$=L)V\G;T=N5W_7<^>4!Y07G)><AY>GIY>OIZ_GQ4?XQ_BW\%
M@+J`I8"B@+&`H8"K@*F`M("J@*^`Y8'^@0V"LX*=@IF"K8*]@I^"N8*Q@JR"
MI8*O@KB"HX*P@KZ"MX).AG&&'5)HB,N.SH_4C]&/M9"XD+&0MI#'D=&1=Y6`
ME1R60)8_ECN61)9"EKF6Z)92EUZ7GTZM3JY.X4^U3Z]/OT_@3]%/ST_=3\-/
MMD_83]]/RD_73ZY/T$_$3\)/VD_.3]Y/MT]749)1D5&@44Y20U)*4DU23%)+
M4D=2QU+)4L-2P5(-4U=3>U.:4]M3K%3`5*A4SE3)5+A4IE2S5,=4PE2]5*I4
MP53$5,A4KU2K5+%4NU2I5*=4OU3_5H)7BU>@5Z-7HE?.5ZY7DU=565%93UE.
M65!9W%G86?]9XUGH60-:Y5GJ6=I9YED!6OM9:5NC6Z9;I%NB6Z5;`5Q.7$]<
M35Q+7-E<TESW71U>)5X?7GU>H%ZF7OI>"%\M7V5?B%^%7XI?BU^'7XQ?B5\2
M8!U@(&`E8`Y@*&!-8'!@:&!B8$9@0V!L8&M@:F!D8$%BW&(68PEC_&+M8@%C
M[F+]8@=C\6+W8N]B[&+^8O1B$6,"8S]E166K9;UEXF4E9BUF(&8G9B]F'V8H
M9C%F)&;W9O]GTV?Q9]1GT&?L9[9GKV?U9^EG[V?$9]%GM&?:9^5GN&?/9]YG
M\V>P9]EGXF?=9])G:FN#:X9KM6O2:]=K'VS);`MM,FTJ;4%M)6T,;3%M'FT7
M;3MM/6T^;39M&VWU;#EM)VTX;2EM+FTU;0YM*VVK<+IPLW"L<*]PK7"X<*YP
MI'`P<G)R;W)T<NERX'+A<K=SRG.[<[)SS7/`<[-S&G4M=4]U3'5.=4MUJW6D
M=:5UHG6C=7AVAG:'=HAVR';&=L-VQ78!=_EV^'8)=PMW_G;\=@=WW'<">!1X
M#'@->$9Y27E(>4=YN7FZ>=%YTGG+>7]Z@7K_>OUZ?7P"?05]`'T)?0=]!'T&
M?3A_CG^_?Q"`#8`1@#:`UH#E@-J`PX#$@,R`X8#;@,Z`WH#D@-V`]($B@N>"
M`X,%@^."VX+F@@2#Y8("@PF#TH+7@O&"`8/<@M2"T8+>@M."WX+O@@:#4(9Y
MAGN&>H9-B&N(@8G4B0B*`HH#BIZ,H(QTC7.-M(W-CLR.\(_FC^*/ZH_EC^V/
MZX_DC^B/RI#.D,&0PY!+D4J1S9&"E5"62Y9,EDV68I=IE\N7[9?SEP&8J)C;
MF-^8EIF9F5A.LTX,4`U0(U#O3R90)5#X3RE0%E`&4#Q0'U`:4!)0$5#Z3P!0
M%%`H4/%/(5`+4!E0&%#S3^Y/+5`J4/Y/*U`)4'Q1I%&E4:)1S5',4<91RU%6
M4EQ25%);4EU2*E-_4Y]3G5/?4^A4$%4!53=5_%3E5/)4!E7Z5!15Z53M5.%4
M"57N5.I4YE0G50=5_50/50-7!%?"5]17RU?#5PE8#UE765A96ED16AA:'%H?
M6AM:$UKL62!:(UHI6B5:#%H)6FM;6%RP6[-;MENT6ZY;M5NY6[A;!%Q17%5<
M4%SM7/U<^USJ7.A<\%SV7`%=]%SN72U>*UZK7JU>IUXQ7Y)?D5^07UE@8V!E
M8%!@56!M8&E@;V"$8)]@FF"-8)1@C&"%8)9@1V+S8@AC_V).8SYC+V-58T)C
M1F-/8TEC.F-08SUC*F,K8RAC36-,8TAE26699<%EQ65"9DEF3V9#9E)F3&9%
M9D%F^&849Q5G%V<A:#AH2&A&:%-H.6A":%1H*6BS:!=H3&A1:#UH]&=0:$!H
M/&A#:"IH16@3:!AH06B*:XEKMVLC;"=L*&PF;"1L\&QJ;95MB&V';69M>&UW
M;5EMDVUL;8EM;FU:;71M:6V,;8IM>6V%;65ME&W*<-APY'#9<,APSW`Y<GER
M_'+Y<OUR^'+W<H9S[7,)=.YSX'/J<]YS5'5==5QU6G59=;YUQ77'=;)ULW6]
M=;QUN77"=;AUBW:P=LIVS7;.=BEW'W<@=RAWZ7<P>"=X.'@=>#1X-W@E>"UX
M('@?>#)X57E0>6!Y7WE6>5YY77E7>5IYY'GC>>=YWWGF>>EYV'F$>HAZV7H&
M>Q%[B7PA?1=]"WT*?2!](GT4?1!]%7T:?1Q]#7T9?1M].G]??Y1_Q7_!?P:`
M!(`8@!6`&8`7@#V`/X#Q@`*!\(`%@>V`](`&@?B`\X`(@?V`"H'\@.^`[8'L
M@0""$((J@BN"*((L@KN"*X-2@U2#2H,X@U"#28,U@S2#3X,R@SF#-H,7@T"#
M,8,H@T.#5(:*AJJ&DX:DAJF&C(:CAIR&<(AWB(&(@HA]B'F(&(H0B@Z*#(H5
MB@J*%XH3BA:*#XH1BDB,>HQYC*&,HHQWC:R.TH[4CL^.L8\!D`:0]X\`D/J/
M](\#D/V/!9#XCY60X9#=D.*04I%-D4R1V)'=D=>1W)'9D8.58I9CEF&66Y9=
MEF266)9>EKN6XIBLF:B:V)HEFS*;/)M^3GI0?5!<4$=00U!,4%I025!E4'90
M3E!54'50=%!W4$]0#U!O4&U07%&54?!1:E)O4M)2V5+84M52$%,/4QE3/U-`
M4SY3PU/\9D95:E5F54157E5A54-52E4Q55953U5552]59%4X52Y57%4L56-5
M,U5!55=5"%<+5PE7WU<%6`I8!EC@5^17^E<"6#58]U?Y5R!98EDV6D%:25IF
M6FI:0%H\6F):6EI&6DI:<%O'6\5;Q%O"6[];QEL)7`A<!UQ@7%Q<75P'709=
M#ET;719=(ET172E=%%T9721=)UT77>)=.%XV7C->-UZW7KA>MEZU7KY>-5\W
M7U=?;%]I7VM?EU^97YY?F%^A7Z!?G%]_8*-@B6"@8*A@RV"T8.9@O6#%8+M@
MM6#<8+Q@V&#58,9@WV"X8-I@QV`:8AMB2&*@8Z=C<F.68Z)CI6-W8V=CF&.J
M8W%CJ6.)8X-CFV-K8ZACA&.(8YECH6.L8Y)CCV.`8WMC:6-H8WIC765695%E
M665795]53V58955E5&6<99MEK&7/9<MES&7.95UF6F9D9FAF9F9>9OEFUU(;
M9X%HKVBB:)-HM6A_:'9HL6BG:)=HL&B#:,1HK6B&:(5HE&B=:*AHGVBA:()H
M,FNZ:^MK[&LK;(YMO&WS;=EMLFWA;<QMY&W[;?IM!6[';<MMKVW1;:YMWFWY
M;;AM]VWU;<5MTFT:;K5MVFWK;=AMZFWQ;>YMZ&W&;<1MJFWL;;]MYFWY<`EQ
M"G']<.]P/7)]<H%R'',;<Q9S$W,9<X=S!70*=`-T!G3^<PUTX'3V=/=T''4B
M=65U9G5B=7!UCW74==5UM77*=<UUCG;4=M)VVW8W=SYW/'<V=SAW.G=K>$-X
M3GAE>6AY;7G[>9)ZE7H@>RA[&WLL>R9[&7L>>RY[DGR7?)5\1GU#?7%]+GTY
M?3Q]0'TP?3-]1'TO?4)],GTQ?3U_GG^:?\Q_SG_2?QR`2H!&@"^!%H$C@2N!
M*8$P@22!`H(U@C>"-H(Y@HZ#GH.8@WB#HH.6@[V#JX.2@XJ#DX.)@Z"#=X-[
M@WR#AH.G@U6&:E_'AL"&MH;$AK6&QH;+AK&&KX;)AE.(GHB(B*N(DHB6B(V(
MBXB3B8^)*HH=BB.*)8HQBBV*'XH;BB**28Q:C*F,K(RKC*B,JHRGC&>-9HV^
MC;J-VX[?CAF0#9`:D!>0(Y`?D!V0$)`5D!Z0()`/D"*0%I`;D!20Z)#MD/V0
M5Y'.D?61YI'CD>>1[9'ID8F5:I9UEG.6>)9PEG26=I9WEFR6P);JENF6X'K?
M>@*8`YA:F^6<=9Y_GJ6>NYZB4(U0A5"94)%0@%"64)A0FE``9_%1<E)T4G52
M:5+>4MU2VU):4Z53>U6`5:=5?%6*59U5F%6"59Q5JE6458=5BU6#5;-5KE6?
M53Y5LE6:5;M5K%6Q57Y5B56K59E5#5<O6"I8-%@D6#!8,5@A6!U8(%CY6/I8
M8%EW6II:?UJ26IM:IUIS6W%;TEO,6]-;T%L*7`M<,5Q,75!=-%U'7?U=15X]
M7D!>0UY^7LI>P5["7L1>/%]M7ZE?JE^H7]%@X6"R8+9@X&`<82-A^F`58?!@
M^V#T8&AA\6`.8?9@"6$`81)A'V))8J-CC&//8\!CZ6/)8\9CS6/28^-CT&/A
M8]9C[6/N8W9C]&/J8]MC4F3:8_EC7F5F96)E8V6199!EKV5N9G!F=&9V9F]F
MD69Z9GYF=V;^9O]F'V<=9_IHU6C@:-AHUV@%:=]H]6CN:.=H^6C2:/)HXVC+
M:,UH#6D2:0YIR6C::&YI^V@^:SIK/6N8:Y9KO&OO:RYL+VPL;"]N.&Y4;B%N
M,FYG;DIN(&XE;B-N&VY;;EAN)&Y6;FYN+6XF;F]N-&Y-;CIN+&Y#;AUN/F[+
M;HEN&6Y.;F-N1&YR;FEN7VX9<1IQ)G$P<2%Q-G%N<1QQ3'*$<H!R-G,E<S1S
M*7,Z="IT,W0B="5T-70V=#1T+W0;="9T*'0E=29U:W5J=>)UVW7C==EUV'7>
M=>!U>W9\=I9VDW:T=MQV3W?M=UUX;'AO>`UZ"'H+>@5Z`'J8>I=ZEGKE>N-Z
M27M6>T9[4'M2>U1[37M+>T][47N??*5\7GU0?6A]57TK?6Y]<GUA?69]8GUP
M?7-]A%74?]5_"X!2@(6`58%4@4N!48%.@3F!1H$^@4R!4X%T@1*"'(+I@P.$
M^(,-A."#Q8,+A,&#[X/Q@_2#5X0*A/"##(3,@_V#\H/*@SB$#H0$A-R#!X34
M@]^#6X;?AMF&[8;4AMN&Y(;0AMZ&5XC!B,*(L8B#B9:).XI@BE6*7HH\BD&*
M5(I;BE"*1HHTBCJ*-HI6BF&,@HROC+R,LXR]C,&,NXS`C+2,MXRVC+^,N(R*
MC86-@8W.C=V-RXW:C=&-S(W;C<:-^X[XCOR.G(\ND#60,9`XD#*0-I`"D?60
M"9'^D&.199'/D122%9(CD@F2'I(-DA"2!Y(1DI25CY6+E9&5DY62E8Z5BI:.
MEHN6?9:%EH:6C99REH26P9;%EL26QI;'EN^6\I;,EP68!I@(F.>8ZICOF.F8
M\ICMF*Z9K9G#GLV>T9Z"3JU0M5"R4+-0Q5"^4*Q0MU"[4*]0QU!_4G=2?5+?
M4N92Y%+B4N-2+U/?5>A5TU7F5<Y5W%7'5=%5XU7D5>]5VE7A5<55QE7E5<E5
M$E<35UY845A86%=86EA46&M83%AM6$I88EA26$M89UG!6LE:S%J^6KU:O%JS
M6L):LEII76]=3%YY7LE>R%X27UE?K%^N7QIA#V%(81]A\V`;8?E@`6$(84YA
M3&%$84UA/F$T82=A#6$&83=A(6(B8A-D/F0>9"ID+60]9"QD#V0<9!1D#60V
M9!9D%V0&9&QEGV6P99=FB6:'9HAFEF:$9IAFC68#9Y1I;6E::7=I8&E4:75I
M,&F":4II:&EK:5YI4VEY:89I76EC:5MI1VMR:\!KOVO3:_UKHFZO;M-NMF["
M;I!NG6[';L5NI6Z8;KQNNFZK;M%NEFZ<;L1NU&ZJ;J=NM&Y.<5EQ:7%D<4EQ
M9W%<<6QQ9G%,<65Q7G%&<6AQ5G$Z<E)R-W-%<S]S/G-O=%IT571?=%YT070_
M=%ET6W1<='9U>'4`=O!U`7;R=?%U^G7_=?1U\W7>=M]V6W=K=V9W7G=C=WEW
M:G=L=UQW97=H=V)W[G>.>+!XEWB8>(QXB7A\>)%XDWA_>'IY?WF!>2R$O7D<
M>AIZ('H4>A]Z'GJ?>J!Z=WO`>V![;GMG>[%\LWRU?)-]>7V1?8%]CWU;?6Y_
M:7]J?W)_J7^H?Z1_5H!8@(:`A(!Q@7"!>(%E@6Z!<X%K@7F!>H%F@06"1X*"
MA'>$/80QA'6$9H1KA$F$;(1;A#R$-81AA&.$:81MA$:$7H9<AE^&^883APB'
M!X<`A_Z&^X8"AP.'!H<*AUF(WXC4B-F(W(C8B-V(X8C*B-6(THB<B>.):XIR
MBG.*9HIIBG"*AXI\BF.*H(IQBH6*;8IBBFZ*;(IYBGN*/HIHBF*,BHR)C,J,
MQXS(C,2,LHS#C,*,Q8SAC=^-Z(WOC?.-^HWJC>2-YHVRC@./"8_^C@J/GX^R
MCTN02I!3D$*05)`\D%604)!'D$^03I!-D%&0/I!!D!*1%Y%LD6J1:9')D3>2
M5Y(XDCV20)(^DEN22Y)DDE&2-)))DDV219(YDC^26I*8E9B6E):5ELV6RY;)
MELJ6]Y;[EOF6]I96EW27=I<0F!&8$Y@*F!*8#)C\F/28_9C^F+.9L9FTF>&:
MZ9R"G@Z?$Y\@G^=0[E#E4-90[5#:4-50SU#14/%0SE#I4&)1\U&#4H)2,5.M
M4_Y5`%8;5A=6_5445@96"58-5@Y6]U465A]6"%805O95&%<65W58?EB#6)-8
MBEAY6(58?5C]6"59(EDD66I9:5GA6N9:Z5K76M9:V%KC6G5;WEOG6^%;Y5OF
M6^A;XEOD6]];#5QB7(1=AUU;7F->55Y77E1>TU[67@I?1E]P7[E?1V$_84MA
M=V%B86-A7V%:85AA=6$J8H=D6&149*1D>&1?9'ID461G9#1D;61[9')EH677
M9=9EHF:H9IUFG&FH:95IP6FN:=-IRVF;:;=INVFK:;1IT&G-::UIS&FF:<-I
MHVE):TQK,VPS;Q1O_FX3;_1N*6\^;R!O+&\/;P)O(F__;N]N!F\Q;SAO,F\C
M;Q5O*V\O;XAO*F_L;@%O\F[,;O=NE'&9<7UQBG&$<9)Q/G*2<I9R1'-0<V1T
M8W1J='!T;70$=9%U)W8-=@MV"783=N%VXW:$=WUW?W=A=\%XGWBG>+-XJ7BC
M>(YYCWF->2YZ,7JJ>JEZ[7KO>J%[E7N+>W5[EWN=>Y1[CWNX>X=[A'NY?+U\
MOGR[?;!]G'V]?;Y]H'W*?;1]LGVQ?;I]HGV_?;5]N'VM?=)]QWVL?7!_X'_A
M?]]_7H!:@(>`4(&`@8^!B(&*@7^!@H'G@?J!!X(4@AZ"2X+)A+^$QH3$A)F$
MGH2RA)R$RX2XA,"$TX20A+R$T83*A#^''(<[AR*')8<TAQB'58<WARF'\X@"
MB?2(^8CXB/V(Z(@:B>^(IHJ,BIZ*HXJ-BJ&*DXJDBJJ*I8JHBIB*D8J:BJ>*
M:HR-C(R,TXS1C-*,:XV9C96-_(T4CQ*/%8\3CZ./8)!8D%R08Y!9D%Z08I!=
MD%N0&9$8D1Z1=9%XD7>1=)%XDJR2@)*%DIB2EI)[DI.2G)*HDGR2D9*AE:B5
MJ96CE:65I)69EIR6FY;,EM*6`)=\EX67]I<7F!B8KYBQF`.9!9D,F0F9P9FO
MFK":YII!FT*;])SVG/.<O)X[GTJ?!%$`4?M0]5#Y4`)1"%$)4051W%&'4HA2
MB5*-4HI2\%*R4RY6.U8Y5C)6/U8T5BE64U9.5E=6=%8V5B]6,%:`6)]8GEBS
M6)Q8KEBI6*98;5D)6_M:"UOU6@Q;"%ON6^Q;Z5OK6V1<95R=791=8EY?7F%>
MXE[:7M]>W5[C7N!>2%]Q7[=?M5]V86=A;F%=855A@F%\87!A:V%^8:=AD&&K
M88YAK&&:8:1AE&&N82YB:61O9'EDGF2R9(ADD&2P9*5DDV259*EDDF2N9*UD
MJV2:9*QDF62B9+-D=65W97AEKF:K9K1FL68C:A]JZ&D!:AYJ&6K]:2%J$VH*
M:O-I`FH%:NUI$6I0:TYKI&O%:\9K/V]\;X1O46]F;U1OAF]M;UMO>&]N;XYO
M>F]P;V1OEV]8;]5N;V]@;U]OGW&L<;%QJ'%6<IMR3G-7<VETBW2#='YT@'1_
M=2!V*78?=B1V)G8A=B)VFG:Z=N1VCG>'=XQWD7>+=\MXQ7BZ>,IXOGC5>+QX
MT'@_>CQZ0'H]>C=Z.WJO>JYZK7NQ>\1[M'O&>\=[P7N@>\Q[RGS@??1][WW[
M?=A]['W=?>A]XWW:?=Y]Z7V>?=E]\GWY?75_=W^O?^E_)H";@9R!G8&@@9J!
MF($7A3V%&H7NA"R%+843A1&%(X4AA12%[(0EA?^$!H6"AW2'=H=@AV:'>(=H
MAUF'5X=,AU.'6XA=B!")!XD2B1.)%8D*B;R*THK'BL2*E8K+BOB*LHK)BL**
MOXJPBM:*S8JVBKF*VXI,C$Z,;(S@C-Z,YHSDC.R,[8SBC..,W(SJC.&,;8V?
MC:.-*XX0CAV.(HX/CBF.'XXACAZ.NHX=CQN/'X\ICR:/*H\<CQZ/)8]ID&Z0
M:)!MD'>0,)$MD2>1,9&'D8F1BY&#D<62NY*WDNJ2Y)+!DK.2O)+2DL>2\)*R
MDJV5L94$EP:7!Y<)EV"7C9>+EX^7(9@KF!R8LY@*F1.9$ID8F=V9T)G?F=N9
MT9G5F=*9V9FWFNZ:[YHGFT6;1)MWFV^;!IT)G0.=J9Z^GLZ>J%A2GQ)1&%$4
M41!1%5&`4:I1W5&14I-2\U)95FM6>59I5F16>%9J5FA6959Q5F]6;%9B5G96
MP5B^6,=8Q5AN61U;-%MX6_!;#EQ*7[)AD6&I88IAS6&V8;YARF'(83!BQ63!
M9,MDNV2\9-IDQ&3'9,)DS62_9-)DU&2^9'1EQF;)9KEFQ&;'9KAF/6HX:CIJ
M66IK:EAJ.6I$:F)J86I+:D=J-6I?:DAJ66MW:P5LPF^Q;Z%OPV^D;\%OIV^S
M;\!ON6^V;Z9OH&^T;[YQR7'0<=)QR''5<;EQSG'9<=QQPW'$<6ASG'2C=)AT
MGW2>=.)T#'4-=31V.'8Z=N=VY7:@=YYWGW>E=^AXVGCL>.=XIGE->DYZ1GI,
M>DMZNGK9>Q%\R7OD>]M[X7OI>^9[U7S6?`I^$7X(?AM^(WX>?AU^"7X0?GE_
MLG_P?_%_[G\H@+.!J8&H@?N!"()8@EF"2H59A4B%:(5IA4.%285MA6J%7H6#
MAY^'GH>BAXV'88@JB3*))8DKB2&)JHFFB>:*^HKKBO&*`(O<BN>*[HK^B@&+
M`HOWBNV*\XKVBOR*:XQMC).,](Q$CC&.-(Y"CCF.-8X[CR^/.(\SCZB/IH]U
MD'20>)!RD'R0>I`TD9*1(),VD_B2,Y,ODR*3_)(KDP23&I,0DR:3(9,5DRZ3
M&9.[E:>6J):JEM66#I<1EQ:7#9<3EP^76Y=<EV:7F)<PF#B8.Y@WF"V8.9@D
MF!"9*)D>F1N9(9D:F>V9XIGQF;B:O)K[FNV:*)N1FQ6=(YTFG2B=$IT;G=B>
MU)Z-GYR?*E$?42%1,E'U4HY6@%:05H56AU:/5M58TUC16,Y8,%LJ6R1;>ELW
M7&A<O%VZ7;U=N%UK7DQ?O5_)8<)AQV'F8<MA,F(T8LYDRF389.!D\&3F9.QD
M\63B9.UD@F6#9=EFUF:`:I1JA&JB:IQJVVJC:GYJEVJ0:J!J7&NN:]IK"&S8
M;_%OWV_@;]MOY&_K;^]O@&_L;^%OZ6_5;^YO\&_G<=]Q[G'F<>5Q[7'L<?1Q
MX'$U<D9R<'-R<ZETL'2F=*AT1G9"=DQVZG:S=ZIWL'>L=Z=WK7?O=_=X^GCT
M>.]X`7FG>:IY5WJ_>@=\#7S^>_=[#'S@>^!\W'S>?.)\WWS9?-U\+GX^?D9^
M-WXR?D-^*WX]?C%^17Y!?C1^.7Y(?C5^/WXO?D1_\W_\?W&`<H!P@&^`<X#&
M@<.!NH'"@<"!OX&]@<F!OH'H@0F"<8*JA82%?H6<A9&%E(6OA9N%AX6HA8J%
MIH5GAL"'T8>SA]*'QH>KA[N'NH?(A\N'.XDVB42).(D]B:R)#HL7BQF+&XL*
MBR"+'8L$BQ"+08P_C'.,^HS]C/R,^(S[C*B-28Y+CDB.2HY$CSZ/0H]%CS^/
M?Y!]D(20@9""D("0.9&CD9Z1G)%-DX*3*)-UDTJ399-+DQB3?I-LDUN3<)-:
MDU23RI7+E<R5R)7&E;&6N);6EAR7'I>@E].71IBVF#69`9K_F:Z;JYNJFZV;
M.YT_G8N>SY[>GMR>W9[;GCZ?2Y_B4Y56KE;96-A8.%M>7^-A,V+T9/)D_F0&
M9?ID^V3W9+=EW&8F9[-JK&K#:KMJN&K":JYJKVI?:WAKKVL)<`MP_F\&</IO
M$7`/</MQ_''^<?AQ=W-U<Z=TOW05=59V6'92=KUWOW>[=[QW#GFN>6%Z8GI@
M>L1ZQ7HK?"=\*GP>?"-\(7SG?%1^57Y>?EI^87Y2?EE^2'_Y?_M_=X!V@,V!
MSX$*@L^%J87-A="%R86PA;J%N87OA^R'\H?@AX:)LHGTB2B+.8LLBRN+4(P%
MC5F.8XYFCF2.7XY5CL".28]-CX>0@Y"(D*N1K)'0D923BI.6DZ*3LY.NDZR3
ML).8DYJ3EY/4E=:5T)75E>*6W);9EMN6WI8DEZ.7II>ME_F739A/F$R83IA3
MF+J8/ID_F3V9+IFEF0Z:P9H#FP:;3YM.FTV;RIO)F_V;R)O`FU&=79U@G>">
M%9\LGS-1I5:H5MY8WUCB6/5;D)_L7O)A]V'V8?5A`&4/9>!FW6;E:MUJVFK3
M:AMP'W`H<!IP'7`5<!AP!G(-<EARHG)X<WISO73*=.-TAW6&=5]V87;'=QEY
ML7EK>FEZ/GP_?#A\/7PW?$!\:WYM?GE^:7YJ?G-^A7^V?[E_N'_8@>F%W87J
MA=6%Y(7EA?>%^X<%B`V(^8?^AV")7XE6B5Z)08M<BUB+28M:BTZ+3XM&BUF+
M"(T*C7R.<HZ'CG:.;(YZCG2.5(].CZV/BI"+D+&1KI'AD]&3WY/#D\B3W)/=
MD]:3XI/-D]B3Y)/7D^B3W)6TEN.6*I<GEV&7W)?[EUZ86)A;F+R819E)F1::
M&9H-F^B;YYO6F]N;B9UAG7*=:IULG9*>EYZ3GK2>^%*W5K96M%:\5N180%M#
M6WU;]EO)7?AA^F$8911E&67F9B=G[&H^<#!P,G`0<GMSSW1B=F5V)GDJ>2QY
M*WG'>O9Z3'Q#?$U\[WSP?*Z/?7Y\?H)^3'\`@-J!9H+[A?F%$8;ZA0:&"X8'
MA@J&%(@5B&2)NHGXB7"+;(MFBV^+7XMKBP^-#8V)CH&.A8Z"CK21RY$8E`.4
M_9/AE3"7Q)A2F5&9J)DKFC":-YHUFA.<#9QYGK6>Z)XOGU^?8Y]AGS=1.%'!
M5L!6PE8466Q<S5W\8?YA'64<995EZ6;[:@1K^FJR:TQP&W*G<M9TU'1I=M-W
M4'R/?HQ^O'\7ABV&&H8CB"*((8@?B&J);(F]B72+=XM]BQ.-BHZ-CHN.7X^O
MC[J1+I0SE#64.I0XE#*4*Y3BE3B7.9<RE_^79YAEF%>919I#FD":/IK/FE2;
M49LMG"6<KYVTG<*=N)V=GN^>&9]<GV:?9Y\\43M1R%;*5LE6?UO47=)=3E__
M821E"FMA:U%P6'"`<^1TBG5N=FQVLWE@?%]\?H!]@-^!<HEOB?R)@(L6C1>-
MD8Z3CF&/2)%$E%&44I0]ESZ7PY?!EVN859E5FDV:TIH:FTF<,9P^G#N<TYW7
MG32?;)]JGY2?S%;670!B(V4K92IE[&80:]ITRGID?&-\97R3?I9^E'[B@3B&
M/X8QB(J+D)"/D&.48)1DE&B7;YA<F5J:6YI7FM.:U)K1FE2<5YQ6G.6=GY[T
MGM%6Z5@L95YP<79R=M=W4'^(?S:(.8ABB).+DHN6BW>"&XW`D6J40I=(ET27
MQI=PF%^:(IM8FU^<^9WZG7R>?9X'GW>?<I_S7A9K8W!L?&Y\.XC`B:&.P9%R
ME'"4<9A>F=::(YO,GF1PVG>:BW>4R9=BFF6:G'Z<BZJ.Q9%]E'Z4?)1WG'B<
M]YY4C'^4&IXH<FJ:,9L;GAZ><GP````````````````````D`20")`,D!"0%
M)`8D!R0()`DD"B0+)`PD#20.)`\D$"01)!(D$R04)!4D%B07)!@D&20:)!LD
M'"0=)!XD'R0A)``````````````````````````````````````````P#/\!
M,`(P#O_[,!O_&O\?_P'_,/XF("4@4/Y1_E+^MP!4_E7^5OY7_C'^%"`R_A,@
M_?_]__W__?\(_PG_-?XV_EO_7?\W_CC^%#`5,#G^.OX0,!$P._X\_@HP"S`]
M_C[^"#`),#_^0/X,,`TP0?Y"_@XP#S!#_D3^6?Y:_EO^7/Y=_E[^&"`9(!P@
M'2`=,!XP,B`U(`/_!O\*_SL@IP`#,,LESR6S);(ESB4&)@4FQR7&):$EH"6]
M);PEHS(%(3X@_?\___W_2?Y*_DW^3OY+_DS^7_Y@_F'^"_\-_]<`]P"Q`!HB
M'/\>_QW_9B)G(F`B'B)2(F$B8OYC_F3^9OYE_CPB*2(J(J4B("(?(K\BTC/1
M,RLB+B(U(C0B0"9")D$F"2:1(9,ADB&0(98AER&9(9@A%B!<_P__//\5(FC^
M!/_E_Q(PX/_A_P7_(/\#(0DA:?YJ_FO^U3.<,YTSGC/.,Z$SCC./,\0SL`!9
M45M17E%=46%18U'G5>ETSGR!)8(E@R6$)84EAB6')8@ECR6.)8TEC"6+)8HE
MB24\)30E+"4D)1PEE"4`)0(EE24,)1`E%"48)6TE;B5P)6\E4"5>)6HE827B
M)>,EY27D)7$E<B5S)?W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]_Q#_$?\2_Q/_%/\5_Q;_%_\8_QG_8"%A(6(A
M8R%D(64A9B%G(6@A:2$A,"(P(S`D,"4P)C`G,"@P*3#]_T13_?\A_R+_(_\D
M_R7_)O\G_RC_*?\J_RO_+/\M_R[_+_\P_S'_,O\S_S3_-?\V_S?_./\Y_SK_
M0?]"_T/_1/]%_T;_1_](_TG_2O]+_TS_3?]._T__4/]1_U+_4_]4_U7_5O]7
M_UC_6?]:_Y$#D@.3`Y0#E0.6`Y<#F`.9`YH#FP.<`YT#G@.?`Z`#H0.C`Z0#
MI0.F`Z<#J`.I`[$#L@.S`[0#M0.V`[<#N`.Y`[H#NP.\`[T#O@._`\`#P0/#
M`\0#Q0/&`\<#R`/)`P4Q!C$',0@Q"3$*,0LQ##$-,0XQ#S$0,1$Q$C$3,10Q
M%3$6,1<Q&#$9,1HQ&S$<,1TQ'C$?,2`Q(3$B,2,Q)#$E,28Q)S$H,2DQV0+)
M`LH"QP++`OW__?_]__W__?_]__W__?_]__W__?_]__W__?]@)&$D8B1C)&0D
M921F)&<D:"1I)'0D=21V)'<D>"1Y)'HD>R1\)'TD<"%Q(7(A<R%T(74A=B%W
M(7@A>2$```````````````````````````````!"3EQ.]5$:4X)3!TX,3D=.
MC4[75FY<<U\/3H=1#DXN3I-.PD[)3LA.F%'\4FQ3N5,@5P-9+%D07/]=X66S
M:\QK%&P_<C%./$[H3MQ.Z4[A3MU.VDX,4@E2'%-,4R)7(U<762]9@5N$6Q)<
M.UQT7'-<!%Z`7H)>R5\)8E!B%6PV;$-L/VP[;*YRL'**<[AYBH`>E@Y/&$\L
M3_5.%$_Q3@!/]TX(3QU/`D\%3R)/$T\$3_1.$D^Q41-2$%*F4B)3'U--4XI3
M!U3A5M]6+E<J5S17/%F`67Q9A5E[67Y9=UE_659;%5PE7'Q<>EQ[7'Y<WUUU
M7H1>`E\:7W1?U5_47\]?7&)>8F1B86)F8F)B66)@8EIB96(W9>]E[F4^9SEG
M.&<[9SIG/V<\9S-G&&Q&;%)L7&Q/;$IL5&Q+;$QL<7!><K1RM7*.<RIU?W9U
M>E%_>()\@H""?8)_@DV&?HF9D)>0F)";D)20(I8DEB"6(Y963SM/8D])3U-/
M9$\^3V=/4D]?3T%/6$\M3S-//T]A3X]1N5$<4AY2(5*M4JY2"5-C4W)3CE./
M4S!4-U0J5%1415095!Q4)5085#U43U1!5"A4)%1'5.Y6YU;E5D%715=,5TE7
M2U=25P990%FF69A9H%F768Y9HEF068]9IUFA68Y;DELH7"I<C5R/7(A<BUR)
M7))<BER&7)-<E5S@70I>#EZ+7HE>C%Z(7HU>!5\=7WA?=E_27]%?T%_M7^A?
M[E_S7^%?Y%_C7_I?[U_W7_M?`&#T7SIB@V*,8HYBCV*48H=B<6)[8GIB<&*!
M8HAB=V)]8G)B=&+P9?1E\V7R9?5E16='9UEG56=,9TAG76=-9UIG2V?0:QEL
M&FQX;&=L:VR$;(MLCVQQ;&]L:6R:;&ULAVR5;)QL9FQS;&5L>VR.;'1P>G!C
M<K]RO7+#<L9RP7*Z<L5RE7.7<Y-SE'.2<SIU.764=95U@78]>32`E8"9@)"`
MDH"<@)""CX*%@HZ"D8*3@HJ"@X*$@GB,R8^_CY^0H9"ED)Z0IY"@D#"6*)8O
MEBV6,TZ83WQ/A4]]3X!/AT]V3W1/B4^$3W=/3$^73VI/FD]Y3X%/>$^03YQ/
ME$^>3Y)/@D^53VM/;D^>4;Q1OE$U4C)2,U)&4C%2O%(*4PM3/%.24Y13AU1_
M5(%4D52"5(A4:U1Z5'Y4951L5'149E2-5&]4851@5)A48U1G5&14]U;Y5F]7
M<E=M5VM7<5=P5W97@%=U5WM7<U=T5V)7:%=]5PQ915FU6;I9SUG.6;)9S%G!
M6;99O%G#6=99L5F]6<!9R%FT6<=98EME6Y-;E5M$7$=<KERD7*!<M5RO7*A<
MK%R?7*-<K5RB7*I<IUR=7*5<MERP7*9<%UX47AE>*%\B7R-?)%]47X)??E]]
M7]Y?Y5\M8"9@&6`R8`M@-&`*8!=@,V`:8!Y@+&`B8`U@$&`N8!-@$6`,8`E@
M'&`48CUBK6*T8M%BOF*J8K9BRF*N8K-BKV*[8JEBL&*X8CUEJ&6[90EF_&4$
M9A)F"&;[90-F"V8-9@5F_6419A!F]F8*9X5G;&>.9Y)G=F=[9YAGAF>$9W1G
MC6>,9WIGGV>19YEG@V=]9X%G>&=Y9Y1G)6N`:WYKWFL=;)-L[&SK;.YLV6RV
M;-1LK6SG;+=LT&S";+ILPVS&;.UL\FS2;-ULM&R*;)UL@&S>;,!L,&W-;,=L
ML&SY;,]LZ6S1;)1PF'"%<)-PAG"$<)%PEG""<)IP@W!J<M9RRW+8<LERW'+2
M<M1RVG+,<M%RI'.A<ZUSIG.B<Z!SK'.=<]UTZ'0_=4!U/G6,=9AUKW;S=O%V
M\';U=OAW_'?Y=_MW^G?W=T)Y/WG%>7AZ>WK[>G5\_7PU@(^`KH"C@+B`M8"M
M@"""H(+`@JN"FH*8@IN"M8*G@JZ"O(*>@KJ"M(*H@J&"J8+"@J2"PX*V@J*"
M<(9OAFV&;H96C-*/RX_3C\V/UH_5C]>/LI"TD*^0LY"PD#F6/98\ECJ60Y;-
M3\5/TT^R3\E/RT_!3]1/W$_93[M/LT_;3\=/UD^Z3\!/N4_L3T1225+`4L)2
M/5-\4Y=3EE.94YA3NE2A5*U4I53/5,-4#8.W5*Y4UE2V5,54QE2@5'!4O%2B
M5+Y4<E3>5+!4M5>>5Y]7I%>,5Y=7G5>;5Y17F%>/5YE7I5>:5Y57]%@-65-9
MX5G>6>Y9`%KQ6=U9^EG]6?Q9]EGD6?)9]UG;6>E9\UGU6>!9_EGT6>U9J%M,
M7-!<V%S,7-=<RUS;7-Y<VES)7,=<RES67--<U%S/7,A<QES.7-]<^%SY72%>
M(EXC7B!>)%ZP7J1>HEZ;7J->I5X'7RY?5E^&7S=@.6!48')@7F!%8%-@1V!)
M8%M@3&!`8$)@7V`D8$1@6&!F8&Y@0F)#8L]B#6,+8_5B#F,#8^MB^6(/8PQC
M^&+V8@!C$V,48_IB%6/[8O!B065#9:IEOV4V9B%F,F8U9AQF)F8B9C-F*V8Z
M9AUF-&8Y9BYF#V<09\%G\F?(9[IGW&>[9_AGV&?`9[=GQ6?K9^1GWV>U9\UG
MLV?W9_9G[F?C9\)GN6?.9^=G\&>R9_QGQF?M9\QGKF?F9]MG^F?)9\IGPV?J
M9\MG*&N":X1KMFO6:]AKX&L@;"%L*&TT;2UM'VT\;3]M$FT*;=IL,VT$;1EM
M.FT:;1%M`&T=;4)M`6T8;3=M`VT/;4!M!VT@;2QM"&TB;0EM$&VW<)]POG"Q
M<+!PH7"T<+5PJ7!!<DER2G)L<G!R<W)N<LIRY'+H<NMRWW+J<N9RXW*%<\QS
MPG/(<\5SN7.V<[5SM'/K<[]SQW.^<\-SQG.X<\MS['3N="YU1W5(=:=UJG5Y
M=L1V"'<#=P1W!7<*=_=V^W;Z=N=WZ'<&>!%X$G@%>!!X#W@.>`EX`W@3>$IY
M3'E+>45Y1'G5><UYSWG6><YY@'I^>M%Z`'L!>WI\>'QY?']\@'R!?`-]"'T!
M?5A_D7^-?[Y_!X`.@`^`%(`W@-B`QX#@@-&`R(#"@-"`Q8#C@-F`W(#*@-6`
MR8#/@->`YH#-@/^!(8*4@MF"_H+Y@@>#Z((`@]6".H/K@M:"](+L@N&"\H+U
M@@R#^X+V@O""ZH+D@N""^H+S@NV"=X9TAGR&<X9!B$Z(9XAJB&F(TXD$B@>*
M<HWCC^&/[H_@C_&0O9"_D-60Q9"^D,>0RY#(D-21TY%4ED^64993EDJ63I8>
M4`50!U`34")0,%`;4/5/]$\S4#=0+%#V3_=/%U`<4"!0)U`U4"]0,5`.4%I1
ME%&34<I1Q%'%4<A1SE%A4EI24E)>4E]255)B4LU2#E.>4R95XE0751)5YU3S
M5.14&E7_5`15"%7K5!%5!57Q5`I5^U3W5/A4X%0.50-5"U4!5P)7S%<R6-57
MTE>Z5\97O5>\5[A7ME>_5\=7T%>Y5\%7#EE*61E:%EHM6BY:%5H/6A=:"EH>
M6C-:;%NG6ZU;K%L#7%9<5%SL7/]<[ESQ7/=<`%WY7"E>*%ZH7JY>JEZL7C-?
M,%]G7UU@6F!G8$%@HF"(8(!@DF"!8)U@@V"58)M@EV"'8)Q@CF`98D9B\F(0
M8U9C+&-$8T5C-F-#8^1C.6-+8TIC/&,I8T%C-&-88U1C66,M8T=C,V-:8U%C
M.&-78T!C2&-*949EQF7#9<1EPF5*9E]F1V919A)G$V<?:!IH26@R:#-H.VA+
M:$]H%F@Q:!QH-6@K:"UH+VA.:$1H-&@=:!)H%&@F:"AH+FA-:#IH)6@@:"QK
M+VLM:S%K-&MM:X*`B&OF:^1KZ&OC:^)KYVLE;'IM8VUD;79M#6UA;9)M6&UB
M;6UM;VV1;8UM[VU_;89M7FUG;6!MEVUP;7QM7VV";9AM+VUH;8MM?FV`;81M
M%FV#;7MM?6UU;9!MW'#3<-%PW7#+<#E_XG#7<-)PWG#@<-1PS7#%<,9PQW#:
M<,YPX7!"<GAR=W)V<@!S^G+T<OYR]G+S<OMR`7/3<]ESY7/6<[QSYW/C<^ES
MW'/2<]MSU'/=<]ISUW/8<^ASWG3?=/1T]70A=5MU7W6P=<%UNW7$=<!UOW6V
M=;IUBG;)=AUW&W<0=Q-W$G<C=Q%W%7<9=QIW(G<G=R-X+'@B>#5X+W@H>"YX
M*W@A>"EX,W@J>#%X5'E;>4]Y7'E3>5)Y47GK>>QYX'GN>>UYZGG<>=YYW7F&
M>HEZA7J+>HQZBGJ'>MAZ$'L$>Q-[!7L/>PA["GL.>PE[$GN$?)%\BGR,?(A\
MC7R%?!Y]'7T1?0Y]&'T6?1-]'WT2?0]]#'U<?V%_7G]@?UU_6W^6?Y)_PW_"
M?\!_%H`^@#F`^H#R@/F`]8`!@?N``($!@B^")8(S@RV#1(,9@U&#)8-6@S^#
M08,F@QR#(H-"@TZ#&X,J@PB#/(--@Q:#)(,@@S>#+X,I@T>#18-,@U.#'H,L
M@TN#)X-(@U.&4H:BAJB&EH:-AI&&GH:'AI>&AH:+AIJ&A8:EAIF&H8:GAI6&
MF(:.AIV&D(:4AD.(1(AMB'6(=HARB("(<8A_B&^(@XA^B'2(?(@2BD>,5XQ[
MC*2,HXQVC7B-M8VWC;:-T8[3COZ/]8\"D/^/^X\$D/R/]H_6D."0V9#:D..0
MWY#ED-B0VY#7D-R0Y)!0D4Z13Y'5D>*1VI%<EE^6O);CF-^:+YM_3G!0:E!A
M4%Y08%!34$M075!R4$A035!!4%M02E!B4!5015!?4&E0:U!C4&101E!`4&Y0
M<U!74%%0T%%K4FU2;%)N4M92TU(M4YQ3=55V53Q535505315*E5156)5-E4U
M53!54E5%50Q5,E5E54Y5.55(52U5.U5`54M5"E<'5_M7%%CB5_97W%?T5P!8
M[5?]5PA8^%<+6/-7SU<'6.Y7XU?R5^57[%?A5PY8_%<06.=7`5@,6/%7Z5?P
M5PU8!%A<66!:6%I56F=:7EHX6C5:;5I06E]:95IL6E-:9%I76D-:75I26D1:
M6UI(6HY:/EI-6CE:3%IP6FE:1UI16E9:0EI<6G);;EO!6\!;65P>70M='5T:
M72!=#%TH70U=)ETE70]=,%T272-='UTN73Y>-%ZQ7K1>N5ZR7K->-E\X7YM?
MEE^?7XI@D&"&8+Y@L&"Z8--@U&#/8.1@V6#=8,A@L6#;8+=@RF"_8,-@S6#`
M8#)C96.*8X)C?6.]8YYCK6.=8Y=CJV..8V]CAV.08VYCKV-U8YQC;6.N8WQC
MI&,[8Y]C>&.%8X%CD6.-8W!C4V7-965F869;9EEF7&9B9AAG>6B':)!HG&AM
M:&YHKFBK:%9I;VBC:*QHJ6AU:'1HLFB/:'=HDFA\:&MH<FBJ:(!H<6A^:)MH
MEFB+:*!HB6BD:'AH>VB1:(QHBFA]:#9K,VLW:SAKD6N/:XUKCFN,:RILP&VK
M;;1MLVUT;JQMZ6WB;;=M]FW4;0!NR&W@;=]MUFV^;>5MW&W=;=MM]&W*;;UM
M[6WP;;IMU6W";<]MR6W0;?)MTVW];==MS6WC;;MM^G`-<?=P%W'T<`QQ\'`$
M<?-P$''\</]P!G$3<0!Q^'#V<`MQ`G$.<7YR>W)\<G]R'7,7<P=S$7,8<PIS
M"'/_<@]S'G.(<_9S^'/U<P1T`73]<P=T`'3Z<_QS_W,,=`MT]',(=&1U8W7.
M==)USW7+=<QUT770=8]VB7;3=CEW+W<M=S%W,G<T=S-W/7<E=SMW-7=(>%)X
M27A->$IX3'@F>$5X4'AD>6=Y:7EJ>6-Y:WEA>;MY^GGX>?9Y]WF/>I1ZD'HU
M>SM[-'LE>S![(GLD>S-[&'LJ>QU[,7LK>RU[+WLR>SA[&GLC>Y1\F'R6?*-\
M-7T]?3A]-GTZ?45]+'TI?4%]1WT^?3]]2GT[?2A]8W^5?YQ_G7^;?\I_RW_-
M?]!_T7_'?\]_R7\?@!Z`&X!'@$.`2(`8@26!&8$;@2V!'X$L@1Z!(8$5@2>!
M'8$B@1&".((S@CJ"-((R@G2"D(.C@ZB#C8-Z@W.#I(-T@X^#@8.5@YF#=8.4
M@ZF#?8.#@XR#G8.;@ZJ#BX-^@Z6#KX.(@Y>#L(-_@Z:#AX.N@W:#6896AK^&
MMX;"AL&&Q8:ZAK"&R(:YAK.&N(;,AK2&NX:\AL.&O8:^AE*(B8B5B*B(HHBJ
MB)J(D8BAB)^(F(BGB)F(FXB7B*2(K(B,B).(CHB"B=:)V8G5B3"*)XHLBAZ*
M.8P[C%R,78Q]C*6,?8U[C7F-O(W"C;F-OXW!C=B.WH[=CMR.UX[@CN&.))`+
MD!&0')`,D"&0[Y#JD/"0])#RD/.0U)#KD.R0Z9!6D5B16I%3D561[)'TD?&1
M\Y'XD>21^9'JD>N1]Y'HD>Z1>I6&E8B5?)9MEFN6<99OEK^6:I<$F.68EYF;
M4)50E%">4(M0HU"#4(Q0CE"=4&A0G%"24()0AU!?4=11$E,14Z13IU.15:A5
MI56M57=515:B59-5B%6/5;55@56C59)5I%5]58Q5IE5_5955H56.50Q7*5@W
M6!E8'E@G6"-8*%CU5TA8)5@<6!M8,U@_6#98+E@Y6#A8+5@L6#M885FO6I1:
MGUIZ6J):GEIX6J9:?%JE6JQ:E5JN6C=:A%J*6I=:@UJ+6JE:>UI]6HQ:G%J/
M6I-:G5KJ6\U;RUO46]%;REO.6PQ<,%PW74-=:UU!74M=/UTU75%=3EU573-=
M.EU273U=,5U974)=.5U)73A=/%TR739=0%U%741>05Y87Z9?I5^K7\E@N6#,
M8.)@SF#$8!1A\F`*819A!6'U8!-A^&#\8/Y@P6`#81AA'6$08?]@!&$+84IB
ME&.Q8[!CSF/E8^AC[V/#8YUD\V/*8^!C]F/58_)C]6-A9-]COF/=8]QCQ&/8
M8]-CPF/'8\QCRV/(8_!CUV/98S)E9V5J961E7&5H965EC&6=99YEKF709=)E
M?&9L9GMF@&9Q9GEF:F9R9@%G#&G3:`1IW&@J:>QHZFCQ:`]IUFCW:.MHY&CV
M:!-I$&GS:.%H!VG,:`AI<&FT:!%I[VC&:!1I^&C0:/UH_&CH:`MI"FD7:<YH
MR&C=:-YHYFCT:-%H!FG4:.EH%6DE:<=H.6L[:S]K/&N4:Y=KF6N5:[UK\&OR
M:_-K,&S\;49N1VX?;DENB&X\;CUN16YB;BMN/VY!;EUN<VX<;C-N2VY`;E%N
M.VX#;BYN7FYH;EQN86XQ;BAN8&YQ;FMN.6XB;C!N4VYE;B=N>&YD;G=N56YY
M;E)N9FXU;C9N6FX@<1YQ+W'[<"YQ,7$C<25Q(G$R<1]Q*'$Z<1MQ2W):<HAR
MB7*&<H5RBW(2<PMS,',B<S%S,W,G<S)S+7,F<R-S-7,,<RYT+'0P="MT%G0:
M="%T+70Q="1T(W0=="ET('0R=/MT+W5O=6QUYW7:=>%UYG7===]UY'77=95V
MDG;:=D9W1W=$=TUW17=*=TYW2W=,=]YW['=@>&1X97A<>&UX<7AJ>&YX<'AI
M>&AX7GAB>'1Y<WER>7!Y`GH*>@-Z#'H$>IEZYGKD>DI[1WM$>TA[3'M.>T![
M6'M%>Z)\GGRH?*%\6'UO?6-]4WU6?6=]:GU/?6U]7'UK?5)]5'UI?5%]7WU.
M?3Y_/W]E?V9_HG^@?Z%_UW]1@$^`4(#^@-2`0X%*@5*!3X%'@3V!38$Z@>:!
M[H'W@?B!^8$$@CR"/8(_@G6".X//@_F#(X3`@^B#$H3G@^2#_(/V@Q"$QH/(
M@^N#XX._@P&$W8/E@]B#_X/A@\N#SH/6@_6#R8,)A`^$WH,1A`:$PH/S@]6#
M^H/'@]&#ZH,3A)J#PX/L@^Z#Q(/[@]>#XH,;A-N#_H/8AN*&YH;3AN.&VH;J
MAMV&ZX;<ANR&Z8;7ANB&T89(B%:(58BZB->(N8BXB,"(OHBVB+R(MXB]B+*(
M`8G)B)6)F(F7B=V)VHG;B4Z*38HYBEF*0(I7BEB*1(I%BE**2(I1BDJ*3(I/
MBE^,@8R`C+J,OHRPC+F,M8R$C8"-B8W8C=.-S8W'C=:-W(W/C=6-V8W(C=>-
MQ8WOCO>.^H[YCN:.[H[ECO6.YX[HCO:.ZX[QCNR.]([ICBV0-)`OD`:1+)$$
MD?^0_)`(D?F0^Y`!D0"1!Y$%D0.189%DD5^18I%@D0&2"I(ED@.2&I(FD@^2
M#)(`DA*2_Y']D0:2!)(GD@*2')(DDAF2%Y(%DA:2>Y6-E8R5D)6'EGZ6B):)
MEH.6@);"ELB6PY;QEO"6;)=PEVZ7!YBIF.N8YISYGH-.A$ZV3KU0OU#&4*Y0
MQ%#*4+10R%#"4+!0P5"Z4+%0RU#)4+90N%#747I2>%)[4GQ2PU7;5<Q5T%7+
M5<I5W57`5=15Q%7I5;]5TE6-5<]5U57B5=95R%7R5<U5V57"51174UAH6&18
M3UA-6$E8;UA56$Y875A96&586U@]6&-8<5C\6,=:Q%K+6KI:N%JQ6K5:L%J_
M6LA:NUK&6K=:P%K*6K1:MEK-6KE:D%K66]A;V5L?7#-<<5UC74I=95UR76Q=
M7EUH76==8EWP74]>3EY*7DU>2U[%7LQ>QE[+7L=>0%^O7ZU?]V!)84IA*V%%
M839A,F$N849A+V%/82EA0&$@8FB1(V(E8B1BQ6/Q8^MC$&029`ED(&0D9#-D
M0V0?9!5D&&0Y9#=D(F0C9`QD)F0P9"AD060U9"]D"F0:9$!D)60G9`MDYV,;
M9"YD(60.9&]EDF73989FC&:59I!FBV:*9IEFE&9X9B!G9FE?:3AI3FEB:7%I
M/VE%:6II.6E":5=I66EZ:4AI26DU:6QI,VD]:65I\&AX:31I:6E`:6]I1&EV
M:5AI06ET:4QI.VE+:3=I7&E/:5%I,FE2:2]I>VD\:49K16M#:T)K2&M!:YMK
M^VO\:_EK]VOX:YMNUF[(;H]NP&Z?;I-NE&Z@;K%NN6[&;M)NO6[!;IYNR6ZW
M;K!NS6ZF;L]NLFZ^;L-NW&[8;IENDFZ.;HUNI&ZA;K]NLV[0;LINEVZN;J-N
M1W%4<5)Q8W%@<4%Q77%B<7)Q>'%J<6%Q0G%8<4-Q2W%P<5]Q4'%3<41Q37%:
M<4]RC7*,<I%RD'*.<CQS0G,[<SIS0'-*<TES1'1*=$MT4G11=%=T0'1/=%!T
M3G1"=$9T3714=.%T_W3^=/UT'75Y=7=U@VGO=0]V`W;W=?YU_'7Y=?AU$';[
M=?9U[77U=?UUF7:U=MUV57=?=V!W4G=6=UIW:7=G=U1W67=M=^!WAWB:>)1X
MCWB$>)5XA7B&>*%X@WAY>)EX@'B6>'MX?'F">7UY>7D1>AAZ&7H2>A=Z%7HB
M>A-Z&WH0>J-ZHGJ>>NMZ9GMD>VU[='MI>W)[97MS>W%[<'MA>WA[=GMC>[)\
MM'RO?(A]AGV`?8U]?WV%?7I]CGU[?8-]?'V,?91]A'U]?9)];7]K?V=_:']L
M?Z9_I7^G?]M_W'\A@&2!8(%W@5R!:8%;@6*!<H$A9UZ!=H%G@6^!1(%A@1V"
M28)$@D""0H)%@O&$/X16A':$>82/A(V$9811A$"$AH1GA#"$381]A%J$681T
MA'.$780'A5Z$-X0ZA#2$>H1#A'B$,H1%A"F$V8-+A"^$0H0MA%^$<(0YA$Z$
M3(12A&^$Q82.A#N$1X0VA#.$:(1^A$2$*X1@A%2$;H10A`N'!(?WA@R'^H;6
MAO6&38?XA@Z'"8<!A_:&#8<%A]:(RXC-B,Z(WHC;B-J(S(C0B(6)FXG?B>6)
MY(GAB>")XHG<B>:)=HJ&BG^*88H_BG>*@HJ$BG6*@XJ!BG2*>HH\C$N,2HQE
MC&2,9HR&C(2,A8S,C&B-:8V1C8R-CHV/C8V-DXV4C9"-DHWPC>"-[(WQC>Z-
MT(WIC>.-XHWGC?*-ZXWTC0:/_XX!CP"/!8\'CPB/`H\+CU*0/Y!$D$F0/9`0
MD0V1#Y$1D1:1%)$+D0Z1;I%OD4B24I(PDCJ29I(SDF627I*#DBZ22I)&DFV2
M;))/DF"29Y)ODC:289)PDC&25))CDE"2<I).DE.23))6DC*2GY6<E9Z5FY62
MEI.6D9:7ELZ6^I;]EOB6]99SEW>7>)=REP^8#9@.F*R8]ICYF*^9LIFPF;69
MK9JKFEN;ZISMG.><@)[]GN90U%#74.A0\U#;4.I0W5#D4--0[%#P4.]0XU#@
M4-A1@%*!4NE2ZU(P4ZQ3)U855@Q6$E;\50]6'%8!5A-6`E;Z51U6!%;_5?E5
MB5A\6)!8F%B&6(%8?UAT6(M8>EB'6)%8CEAV6()8B%A[6)18CUC^6&M9W%KN
M6N5:U5KJ6MI:[5KK6O-:XEK@6MM:[%K>6MU:V5KH6M]:=UO@6^-;8UR"78!=
M?5V&77I=@5UW78I=B5V(77Y=?%V-77E=?UU87EE>4U[87M%>UU[.7MQ>U5[9
M7M)>U%Y$7T-?;U^V7RQA*&%!85YA<6%S85)A4V%R86QA@&%T851A>F%;865A
M.V%J86%A5F$I8B=B*V(K9$UD6V1=9'1D=F1R9'-D?61U9&9DIF1.9()D7F1<
M9$MD4V1@9%!D?V0_9&QD:V199&5D=V1S9:!EH6:@9I]F!6<$9R)GL6FV:<EI
MH&G.:99IL&FL:;QID6F9:8YIIVF-::EIOFFO:;]IQ&F]::1IU&FY:<IIFFG/
M:;-IDVFJ::%IGFG9:9=ID&G":;5II6G&:4IK36M+:YYKGVN@:\-KQ&O^:\YN
M]6[Q;@-O)6_X;C=O^VXN;PEO3F\9;QIO)V\8;SMO$F_M;@IO-F]S;_EN[FXM
M;T!O,&\\;S5OZVX';PYO0V\%;_UN]FXY;QQO_&XZ;Q]O#6\>;PAO(6^'<9!Q
MB7&`<85Q@G&/<7MQAG&!<9=Q1')3<I=RE7*3<D-S37-1<TQS8G1S='%T=71R
M=&=T;G0`=0)U`W5]=9!U%G8(=@QV%781=@IV%':X=H%W?'>%=X)W;G>`=V]W
M?G>#=[)XJGBT>*UXJ'A^>*MXGGBE>*!XK'BB>*1XF'F*>8MYEGF5>91YDWF7
M>8AYDGF0>2MZ2GHP>B]Z*'HF>JAZJWJL>NYZB'N<>XI[D7N0>Y9[C7N,>YM[
MCGN%>YA[A%*9>Z1[@GN[?+]\O'RZ?*=]MWW"?:-]JGW!?<!]Q7V=?<Y]Q'W&
M?<M]S'VO?;E]EGV\?9]]IGVN?:E]H7W)?7-_XG_C?^5_WG\D@%V`7(")@8:!
M@X&'@8V!C(&+@16"EX2DA*&$GX2ZA,Z$PH2LA*Z$JX2YA+2$P83-A*J$FH2Q
MA-"$G82GA+N$HH24A,>$S(2;A*F$KX2HA-:$F(2VA,^$H(37A-2$TH3;A+"$
MD81AAC.'(X<HAVN'0(<NAQZ'(8<9AQN'0X<LAT&'/H=&AR"',H<JARV'/(<2
MASJ',8<UAT*')H<GASB')(<:AS"'$8?WB.>(\8CRB/J(_HCNB/R(]HC[B/"(
M[(CKB)V)H8F?B9Z)Z8GKB>B)JXJ9BHN*DHJ/BI:*/8QHC&F,U8S/C->,EHT)
MC@*._XT-COV-"HX#C@>.!HX%COZ-`(X$CA"/$8\.CPV/(Y$<D2"1(I$?D1V1
M&I$DD2&1&Y%ZD7*1>9%SD:62I))VDIN2>I*@DI22JI*-DJ:2FI*KDGF2EY)_
MDJ.2[I*.DH*2E9*BDGV2B)*ADHJ2AI*,DIF2IY)^DH>2J9*=DHN2+9*>EJ&6
M_Y98EWV7>I=^EX.7@)>"EWN7A)>!EW^7SI?-EQ:8K9BNF`*9`)D'F9V9G)G#
MF;F9NYFZF<*9O9G'F;&:XYKGFCZ;/YM@FV&;7YOQG/*<]9RGGO]0`U$P4?A0
M!E$'4?90_E`+40Q1_5`*48M2C%+Q4N]22%9"5DQ6-59!5DI6259&5EA66E9`
M5C-6/58L5CY6.%8J5CI6&E>K6)U8L5B@6*-8KUBL6*58H5C_6/]:]%K]6O=:
M]EH#6_A:`EOY6@%;!UL%6P];9UR979==GUV27:)=DUV57:!=G%VA79I=GEUI
M7EU>8%Y<7O-]VU[>7N%>25^R7XMA@V%Y8;%AL&&B88EAFV&38:]AK6&?89)A
MJF&A88UA9F&S82UB;F1P9)9DH&2%9)=DG&2/9(MDBF2,9*-DGV1H9+%DF&1V
M97IE>65[9;)ELV6U9K!FJ6:R9K=FJF:O9@!J!FH7:N5I^&D5:O%IY&D@:O]I
M[&GB:1MJ'6K^:2=J\FGN:11J]VGG:4!J"&KF:?MI#6K\:>MI"6H$:AAJ)6H/
M:O9I)FH':O1I%FI1:Z5KHVNB:Z9K`6P`;/]K`FQ!;R9O?F^';\9ODF^-;XEO
MC&]B;T]OA6]:;Y9O=F]L;X)O56]R;U)O4&]7;Y1ODV]=;P!O86]K;WUO9V^0
M;U-OBV]I;W]OE6]C;W=O:F][;[)QKW&;<;!QH'&:<:EQM7&=<:5QGG&D<:%Q
MJG&<<:=QLW&8<IIR6'-2<UYS7W-@<UUS6W-A<UIS67-B<X=TB72*=(9T@71]
M=(5TB'1\='ET"'4'=7YU)78>=AEV'78<=B-V&G8H=AMVG':==IYVFW:-=X]W
MB7>(=\UXNWC/>,QXT7C.>-1XR'C#>,1XR7B:>:%YH'F<>:)YFWEV:SEZLGJT
M>K-ZMWO+>[Y[K'O.>Z][N7O*>[5[Q7S(?,Q\RWSW?=M]ZGWG?==]X7T#?OI]
MYGWV??%]\'WN?=]]=G^L?[!_K7_M?^M_ZG_L?^9_Z']D@&>`HX&?@9Z!E8&B
M@9F!EX$6@D^"4X)2@E""3H)1@B2%.X4/A0"%*84.A0F%#84?A0J%)X4<A?N$
M*X7ZA`B%#(7TA"J%\H05A?>$ZX3SA/R$$H7JA.F$%H7^A"B%'84NA0*%_80>
MA?:$,84FA>>$Z(3PA.^$^808A2"%,(4+A1F%+X5BAE:'8X=DAW>'X8=SAUB'
M5(=;AU*'88=:AU&'7H=MAVJ'4(=.AU^'78=OAVR'>H=NAUR'98=/AWN'=8=B
MAV>':8=:B`6)#(D4B0N)%XD8B1F)!HD6B1&)#HD)B:*)I(FCB>V)\(GLB<^*
MQHJXBM.*T8K4BM6*NXK7BKZ*P(K%BMB*PXJZBKV*V8H^C$V,CXSEC-^,V8SH
MC-J,W8SGC*"-G(VAC9N-((XCCB6.)(XNCA6.&XX6CA&.&8XFCB>.%(X2CAB.
M$XX<CA>.&HXLCR2/&(\:CR"/(X\6CQ>/<Y!PD&^09Y!KD"^1*Y$ID2J1,I$F
MD2Z1A9&&D8J1@9&"D821@)'0DL.2Q)+`DMF2MI+/DO&2WY+8DNF2UY+=DLR2
M[Y+"DNB2RI+(DLZ2YI+-DM62R9+@DMZ2YY+1DM.2M9+ADB63QI*TDGR5K)6K
ME:Z5L)6DEJ*6TY8%EPB7`I=:EXJ7CI>(E]"7SY<>F!V8)I@IF"B8()@;F">8
MLI@(F?J8$9D4F1:9%YD5F=R9S9G/F=.9U)G.F<F9UIG8F<N9UYG,F;.:[)KK
MFO.:\IKQFD:;0YMGFW2;<9MFFW:;=9MPFVB;9)MLF_R<^IS]G/^<]YP'G0"=
M^9S[G`B=!9T$G8.>TYX/GQ"?'%$341=1&E$14=Y1-%/A4W!68%9N5G-69E9C
M5FU6<E9>5G=6'%<;5\A8O5C)6+]8NEC"6+Q8QE@76QE;&ULA6Q1;$UL06Q9;
M*%L:6R!;'EOO6ZQ=L5VI7:==M5VP7:Y=JEVH7;)=K5VO7;1=9UYH7F9>;U[I
M7N=>YE[H7N5>2U^\7[M?G6&H899AQ6&T8<9AP6',8;IAOV&X88QAUV369-!D
MSV3)9+UDB63#9-MD\V399#-E?V5\9:)ER&:^9L!FRF;+9L]FO6:[9KIFS&8C
M9S1J9FI):F=J,FIH:CYJ76IM:G9J6VI1:BAJ6FH[:C]J06IJ:F1J4&I/:E1J
M;VII:F!J/&I>:E9J56I-:DYJ1FI5:U1K5FNG:ZIKJVO(:\=K!&P#;`9LK6_+
M;Z-OQV^\;\YOR&]>;\1OO6^>;\IOJ&\$<*5OKF^Z;ZQOJF_/;[]ON&^B;\EO
MJV_-;Z]OLF^P;\5QPG&_<;AQUG'`<<%QRW'4<<IQQW'/<;UQV'&\<<9QVG';
M<9URGG)I<V9S9W-L<V5S:W-J<W]TFG2@=)1TDG25=*%T"W6`=2]V+78Q=CUV
M,W8\=C5V,G8P=KMVYG::=YUWH7><=YMWHG>C=Y5WF7>7=]UXZ7CE>.IXWGCC
M>-MXX7CB>.UXWWC@>*1Y1'I(>D=ZMGJX>K5ZL7JW>MY[XWOG>]U[U7OE>]I[
MZ'OY>]1[ZGOB>]Q[ZWO8>]][TGS4?-=\T'S1?!)^(7X7?@Q^'WX@?A-^#GX<
M?A5^&GXB?@M^#WX6?@U^%'XE?B1^0W][?WQ_>G^Q?^]_*H`I@&R`L8&F@:Z!
MN8&U@:N!L(&L@;2!LH&W@:>!\H%5@E:"5X)6A46%:X5-A5.%8858A4"%1H5D
MA4&%8H5$A5&%1X5CA3Z%6X5QA4Z%;H5UA56%9X5@A8R%9H5=A52%985LA6.&
M989DAJ2'FX>/AY>'DX>2AXB'@8>6AYB'>8>'AZ.'A8>0AY&'G8>$AY2'G(>:
MAXF''HDFB3")+8DNB2>),8DBB2F)(XDOB2R)'XGQB>"*XHKRBO2*]8K=BA2+
MY(K?BO"*R(K>BN&*Z(K_BN^*^XJ1C)*,D(SUC.Z,\8SPC/.,;(UNC:6-IXTS
MCCZ..(Y`CD6.-HX\CCV.08XPCC^.O8XVCRZ/-8\RCSF/-X\TCW:0>9![D(:0
M^I`SD361-I&3D9"1D9&-D8^1)Y,>DPB3'Y,&DP^3>I,XDSR3&Y,CDQ*3`9-&
MDRV3#I,-D\N2'9/ZDA.3^9+WDC23`I,DD_^2*9,YDS63*I,4DPR3"Y/^D@F3
M`)/[DA:3O)7-E;Z5N96ZE;:5OY6UE;V5J9;4E@N7$I<0EYF7EY>4E_"7^)<U
MF"^8,I@DF1^9)YDIF9Z9[IGLF>69Y)GPF>.9ZIGIF>>9N9J_FK2:NYKVFOJ:
M^9KWFC.;@)N%FX>;?)M^FWN;@IN3FY*;D)MZFY6;?9N(FR6=%YT@G1Z=%)TI
MG1V=&)TBG1"=&9T?G8B>AIZ'GJZ>K9[5GM:>^IX2GSV?)E$E42)1)%$@42E1
M]%*35HQ6C5:&5H16@U9^5H)6?U:!5M98U%C/6-)8+5LE6S);(ULL6R=;)ELO
M6RY;>UOQ6_);MUUL7FI>OE_#8;5AO&'G8>!AY6'D8>AAWF'O9.EDXV3K9.1D
MZ&2!98!EMF7:9=)FC6J6:H%JI6J):I]JFVJA:IYJAVJ3:HYJE6J#:JAJI&J1
M:G]JIFJ::H5JC&J2:EMKK6L);,QOJ6_T;]1OXV_<;^UOYV_F;]YO\F_=;^)O
MZ&_A<?%QZ''R<>1Q\''B<7-S;G-O<Y=TLG2K=)!TJG2M=+%TI72O=!!U$742
M=0]UA'5#=DAV279'=J1VZ7:U=ZMWLG>W=[9WM'>Q=ZAW\'?S>/UX`GG[>/QX
M_WCR>`5Y^7C^>`1YJWFH>5QZ6WI6>EAZ5'I:>KYZP'K!>@5\#WSR>P!\_WO[
M>PY\]'L+?/-[`GP)?`-\`7SX>_U[!GSP>_%[$'P*?.A\+7X\?D)^,WY(F#A^
M*GY)?D!^1WXI?DQ^,'X[?C9^1'XZ?D5_?W]^?WU_]'_R?RR`NX'$@<R!RH'%
M@<>!O('I@5N"6H)<@H.%@(6/A:>%E86@A8N%HX5[A:2%FH6>A7>%?(6)A:&%
M>H5XA5>%CH66A8:%C869A9V%@86BA8*%B(6%A7F%=H68A9"%GX5HAKZ'JH>M
MA\6'L(>LA[F'M8>\AZZ'R8?#A\*'S(>WAZ^'Q(?*A[2'MH>_A[B'O8?>A[*'
M-8DSB3R)/HE!B5*)-XE"B:V)KXFNB?*)\XD>BQB+%HL1BP6+"XLBBP^+$HL5
MBP>+#8L(BP:+'(L3BQJ+3XQPC'*,<8QOC)6,E(SYC&^-3HY-CE..4(Y,CD>.
M0X]`CX60?I`XD9J1HI&;D9F1GY&AD9V1H)&ADX.3KY-DDU:31Y-\DUB37)-V
MDTF34)-1DV"3;9./DTR3:I-YDU>359-2DT^3<9-WDWN389->DV.39Y-.DUF3
MQY7`E<F5PY7%E;>5KI:PEJR6()<?EQB7'9<9EYJ7H9><EYZ7G9?5E]27\9=!
MF$282IA)F$680Y@EF2N9+)DJF3.9,IDOF2V9,9DPF9B9HYFAF0*:^IGTF?>9
M^9GXF?:9^YG]F?Z9_)D#FKZ:_IK]F@&;_)I(FYJ;J)N>FYN;IINAFZ6;I)N&
MFZ*;H)NOFS.=09UGG3:=+ITOG3&=.)TPG46=0IU#G3Z=-YU`G3V=]7\MG8J>
MB9Z-GK">R)[:GON>_YXDGR.?(I]4GZ"?,5$M42Y1F%:<5I=6FE:=5IE6<%D\
M6VE<:ES`76U>;E[88=]A[6'N8?%AZF'P8>MAUF'I8?]D!&7]9/AD`64#9?QD
ME&7;9=IFVV;89L5JN6J]:N%JQFJZ:K9JMVK':K1JK6I>:\EK"VP'<`QP#7`!
M<`5P%'`.</]O`'#[;R9P_&_W;PIP`7+_<?EQ`W+]<79SN'3`=+5TP72^=+9T
MNW3"=!1U$W5<=F1V6790=E-V5W9:=J9VO7;L=L)WNG<,>1-Y%'D)>1!Y$GD1
M>:UYK'E?>AQ\*7P9?"!\'WPM?!U\)GPH?")\)7PP?%Q^4'Y6?F-^6'YB?E]^
M47Y@?E=^4WZU?[-_]W_X?W6`T8'2@="!7X)>@K2%QH7`A<.%PH6SA;6%O87'
MA<2%OX7+A<Z%R(7%A;&%MH72A22&N(6WA;Z%:8;GA^:'XH?;A^N'ZH?EA]^'
M\X?DA]2'W(?3A^V'V(?CA]>'V8<!B/2'Z(?=AU.)2XE/B4R)1HE0B5&)28DJ
MBR>+(XLSBS"+-8M'BR^+/(L^BS&+)8LWBR:+-HLNBR2+.XL]BSJ+0HQUC)F,
MF(R7C/Z,!(T"C0"-7(YBCF".5XY6CEZ.98YGCEN.6HYACEV.:8Y4CD:/1X](
MCTN/*)$ZD3N1/I&HD:61IY&OD:J1M9.,DY*3MY.;DYV3B9.GDXZ3JI.>DZ:3
ME9.(DYF3GY.`DXV3L9.1D[*3I).HD[23HY/2E=.5T96SEM>6VI;"7=^6V);=
MEB.7(I<EEZR7KI>HEZN7I)>JEZ*7I9?7E]F7UI?8E_J74)A1F%*8N)A!F3R9
M.ID/F@N:"9H-F@2:$9H*F@6:!YH&FL":W)H(FP2;!9LIFS6;2IM,FTN;QYO&
MF\.;OYO!F[6;N)O3F[:;Q)NYF[V;7)U3G4^=2IU;G4N=69U6G4R=5YU2G52=
M7YU8G5J=CIZ,GM^>`9\`GQ:?)9\KGRJ?*9\HGTR?59\T4351EE+W4K13JU:M
M5J96IU:J5JQ6VEC=6-M8$ED]6SY;/UO#77!>OU_[80=E$&4-90EE#&4.981E
MWF7=9=YFYVK@:LQJT6K9:LMJWVK<:M!JZVK/:LUJWFI@:[!K#&P9<"=P('`6
M<"MP(7`B<"-P*7`7<"1P''`,<@IR!W("<@5RI7*F<J1RHW*A<LMTQ72W=,-T
M%G5@=LEWRG?$=_%W'7D;>2%Y''D7>1YYL'EG>FAZ,WP\?#E\+'P[?.Q\ZGQV
M?G5^>'YP?G=^;WYZ?G)^='YH?DM_2G^#?X9_MW_]?_Y_>(#7@=6!"X)D@F&"
M8X+KA?&%[879A>&%Z(7:A=>%[(7RA?B%V(7?A>.%W(71A?"%YH7OA=Z%XH4`
MB/J'`XCVA_>'"8@,B`N(!HC\APB(_X<*B`*(8HE:B5N)5XEAB5R)6(E=B5F)
MB(FWB;:)]HE0BTB+2HM`BU.+5HM4BTN+58M1BT*+4HM7BT.,=XQVC)J,!HT'
MC0F-K(VJC:V-JXUMCGB.<XYJCF^.>X["CE*/48]/CU"/4X^TCT"1/Y&PD:V1
MWI/'D\^3PI/:D]"3^9/LD\R3V9.ID^:3RI/4D^Z3XY/5D\23SI/`D]*3I9/G
MDWV5VI7;E>&6*9<KERR7*)<FE[.7MY>VE]V7WI??EUR869A=F%>8OYB]F+N8
MOIA(F4>90YFFF:>9&IH5FB6:'9HDFAN:(IH@FB>:(YH>FAR:%)K"F@N;"IL.
MFPR;-YOJF^N;X)O>F^2;YIOBF_";U)O7F^R;W)O9F^6;U9OAF]J;=YV!G8J=
MA)V(G7&=@)UXG8:=BYV,G7V=:YUTG76=<)UIG86=<YU[G8*=;YUYG7^=AYUH
MG92>D9[`GOR>+9]`GT&?39]6GU>?6)\W4[)6M5:S5N-815O&7<==[E[O7L!?
MP5_Y81=E%F4591-EWV7H9N-FY&;S:O!JZFKH:OEJ\6KN:N]J/'`U<"]P-W`T
M<#%P0G`X<#]P.G`Y<"IP0'`[<#-P07`3<A1RJ')]<WQSNG2K=JIVOG;M=LQW
MSG?/=\UW\G<E>2-Y)WDH>21Y*7FR>6YZ;'IM>O=Z27Q(?$I\1WQ%?.Y\>WY^
M?H%^@'ZZ?_]_>8#;@=F!:()I@B*&_X4!AOZ%&X8`AO:%!(8)A@6&#(;]A1F(
M$(@1B!>($X@6B&.)9HFYB?>)8(MJBUV+:(MCBV6+9XMMBZZ-AHZ(CH2.68]6
MCU>/58]8CUJ/C9!#D4&1MY&UD;*1LY$+E!.4^Y,@E`^4%)3^DQ64$)0HE!F4
M#93UDP"4]Y,'E`Z4%I02E/J3"93XDSR4"I3_D_R3#)3VDQ&4!I3>E>"5WY4N
MER^7N9>[E_V7_I=@F&*88YA?F,&8PIA0F4Z969E,F4N94YDRFC2:,9HLFBJ:
M-IHIFBZ:.)HMFL>:RIK&FA";$IL1FPN<")SWFP6<$ISXFT"<!YP.G`:<%YP4
MG`F<GYV9G:2=G9V2G9B=D)V;G:"=E)V<G:J=EYVAG9J=HIVHG9Z=HYV_G:F=
MEIVFG:>=F9Z;GIJ>Y9[DGN>>YIXPGRZ?6Y]@GUZ?79]9GY&?.E$Y49A2EU+#
M5KU6OE9(6T=;RUW/7?%>_6$;90)K_&H#:_AJ`&M#<$1P2G!(<$EP17!&<!UR
M&G(9<GYS%W5J=M!W+7DQ>2]Y5'Q3?/)\BGZ'?HA^BWZ&?HU^37^[?S"`W8$8
MABJ&)H8?AB.&'(89AB>&+H8AAB"&*88>AB6&*8@=B!N(((@DB!R(*XA*B&V)
M:8ENB6N)^HEYBWB+18MZBWN+$(T4C:^-CHZ,CEZ/6X]=CT:11)%%D;F1/Y0[
ME#:4*90]E#"4.90JE#>4+)1`E#&4Y97DE>.5-9<ZE[^7X9=DF,F8QIC`F%B9
M5IDYFCV:1II$FD*:09HZFC^:S9H5FQ>;&)L6FSJ;4ILKG!V<')PLG".<*)PI
MG"2<(9RWG;:=O)W!G<>=RIW/G;Z=Q9W#G;N=M9W.G;F=NIVLG<B=L9VMG<R=
MLYW-G;*=>IZ<GNN>[I[MGAN?&)\:GS&?3I]EGV2?DI^Y3L96Q5;+5G%92UM,
M6]5=T5WR7B%E(&4F92)E"VL(:PEK#6Q5<%9P5W!2<!YR'W*I<G]SV'35=-ET
MUW1M=JUV-7FT>7!Z<7I7?%Q\67Q;?%I\]'SQ?)%^3W^'?]Z!:X(TAC6&,X8L
MAC*&-H8LB"B()H@JB"6(<8F_B;Z)^XE^BX2+@HN&BX6+?XL5C96.E(Z:CI*.
MD(Z6CI>.8(]BCT>13)10E$J42Y1/E$>4191(E$F41I0_E^.7:IAIF,N85)E;
MF4Z:4YI4FDR:3YI(FDJ:29I2FE":T)H9FRN;.YM6FU6;1IQ(G#^<1)PYG#.<
M09P\G#><-)PRG#V<-IS;G=*=WIW:G<N=T)W<G=&=WYWIG=F=V)W6G?6=U9W=
MG;:>\)XUGS.?,I]"GVN?E9^BGSU1F5+H6.=8<EE-6]A=+XA/7P%B`V($8BEE
M)6669>MF$6L2:P]KRFM;<%IP(G*"<X%S@W-P=M1W9WQF?)5^;((ZAD"&.88\
MAC&&.X8^AC"(,H@NB#.(=HETB7.)_HF,BXZ+BXN(BT6,&8V8CF2/8X^\D6*4
M591=E%>47I3$E\67`)A6FEF:'IL?FR";4IQ8G%"<2IQ-G$N<59Q9G$R<3IS[
MG?>=[YWCG>N=^)WDG?:=X9WNG>:=\IWPG>*=[)WTG?.=Z)WMG<*>T)[RGO.>
M!I\<GSB?-Y\VGT.?3Y]QGW"?;I]OG]-6S59.6VU<+67M9NYF$VM?<&%P77!@
M<"-RVW3E=-5W.'FW>;9Y:GR7?HE_;8)#ACB(-X@UB$N(E(N5BYZ.GXZ@CIV.
MOI&]D<*1:Y1HE&F4Y99&ET.71Y?'E^677IK5FEF;8YQGG&:<8IQ>G&"<`I[^
MG0>>`YX&G@6>`)X!G@F>_YW]G02>H)X>GT:?=)]UGW:?U%8N9;AE&&L9:Q=K
M&FMB<"9RJG+8=]EW.7EI?&M\]GR:?IA^FWZ9?N"!X8%&AD>&2(9YB7J)?(E[
MB?^)F(N9BZ6.I(ZCCFZ4;91OE'&4<Y1)EW*87YEHG&Z<;9P+G@V>$)X/GA*>
M$9ZAGO6>"9]'GWB?>Y]ZGWF?'E=F<&]\/(BRC::.PY%TE'B4=I1UE&":+IMT
MG'.<<9QUG!2>$Y[VG@J?I)]H<&5P]WQJACZ(/8@_B)Z+G(RICLF.2Y=SF'28
MS)AAF:N99)IFFF>:))L5GA>>2)\'8AYK)W),AJB.@I2`E(&4:9IHFAF>2X:?
MBX.4>9RWGG5V:YIZG!V>:7!J<"ERI)Y^GTF?F)\```#^I```````````````
M````````````````S.P`W@``````T@``````````````````````````````
M``#R``````````````````````````````````````"IJJNLK:ZOL+&RLP"U
MMK<`N;J[O+V^O\#!P@#$Q<;'R,G*RP#-SL\`T0#3U`#6U]C9VMO<``#?X.'B
M`.3EYN?HZ>KK`.WN[P#Q`//T`/;W^/GZ^_P``/\``,/C````````````````
MT/``````````````````````````````````````````````````````````
M````````````````````````````N*@`````````````````````````````
M``````````````````"T````````````````````````````````````````
M````````````U?4`````````````````W?T`````````````````````````
M`````*``H0"B`*,`I`"E`*8`IP!3`:D`J@"K`*P`K0"N`*\`L`"Q`+(`LP!X
M`;4`M@"W`%(!N0"Z`+L`O`"]`+X`OP#``,$`P@`"`<0`Q0#&`,<`R`#)`,H`
MRP```\T`S@#/`!`!T0`)`],`U`"@`=8`UP#8`-D`V@#;`-P`KP$#`]\`X`#A
M`.(``P'D`.4`Y@#G`.@`Z0#J`.L``0/M`.X`[P`1`?$`(P/S`/0`H0'V`/<`
M^`#Y`/H`^P#\`+`!JR#_`````):7````D9(``).4`````)4```"%````````
M`````*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)
MRLO,S<[/T-'2T]35UM?8V=H`````W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V
M]_CY^OL`````K"#]__W__?_]_R8@_?_]__W__?_]__W__?_]__W__?_]_Q@@
M&2`<(!T@(B`3(!0@_?_]__W__?_]__W__?_]_Z```0X"#@,.!`X%#@8.!PX(
M#@D."@X+#@P.#0X.#@\.$`X1#A(.$PX4#A4.%@X7#A@.&0X:#AL.'`X=#AX.
M'PX@#B$.(@XC#B0.)0XF#B<.*`XI#BH.*PXL#BT.+@XO#C`.,0XR#C,.-`XU
M#C8.-PXX#CD..@[]__W__?_]_S\.0`Y!#D(.0PY$#D4.1@Y'#D@.20Y*#DL.
M3`Y-#DX.3PY0#E$.4@Y3#E0.50Y6#E<.6`Y9#EH.6P[]__W__?_]__\`_```
M`/X``````/T`````````````````````````2`X!#@(.`PX$#@4.!@X'#@@.
M"0X*#@L.#`X-#@X.#PX0#A$.$@X3#A0.%0X6#A<.&`X9#AH.&PX<#AT.'@X?
M#B`.(0XB#B,.)`XE#B8.)PXH#BD.*@XK#BP.+0XN#B\.,`XQ#C(.,PXT#C4.
M-@XW#C@..0XZ#DD.2@Y+#JP@/PY`#D$.0@Y##D0.10Y&#D<.2`Y)#DH.2PY,
M#DT.3@Y/#E`.40Y2#E,.5`Y5#E8.5PY8#ED.6@Y;#J(`K`"F`*```*&B`*2E
MIJ>HJ:JKK`"NK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2
MT]35UM?8V=K;W-W>W^#AXN/DY>;GZ.GJZ^SM[N\`\?(`]/7V]_CY^OO\`/[_
M````````````````````````````````````````````````````````````
M````H_,```````"@````````_0``````K0``````````````````````````
M````````H``!!`($D`0$!`4$!@0'!`@$"00*!`L$#`2M``X$#P00!!$$$@03
M!!0$%006!!<$&`09!!H$&P0<!!T$'@0?!"`$(00B!",$)`0E!"8$)P0H!"D$
M*@0K!"P$+00N!"\$,`0Q!#($,P0T!#4$-@0W!#@$.00Z!#L$/`0]!#X$/P1`
M!$$$0@1#!$0$101&!$<$2`1)!$H$2P1,!$T$3@1/!!8A4012!)$$5`15!%8$
M5P18!%D$6@1;!%P$IP!>!%\$`(<``````)0`D`"1`)(`DP``W`#=````@`"5
MI@``W@``IP``````J````*D```"J````JP```*X``````````````*\```"Z
M````O````+T`````````V```OL#;`)F:FP``WP```/,```#T````]0```/L`
M``#\`/X``/T```"6`)B7`/><^)WYGOJ?`````````(6$@X:CHJ&E]@```(L`
MB@```````````(T```",````C@```(\``````````````*P`````````````
M`````+L```"_`,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7`-G:``````#@X>+C
MY.7FY^CIZNOL[>[O\/'R`````````````````+"QLK.TM;:WN+D`````````
M``````````````````````````````"(````````````````````````````
M``"@````I```````````K0``````````````````````````````````````
M````````````````@0````````````````````````````````````````""
M`````````````````````(C^UP#W`/;X]?CT^/?X<?Z(`*`E`B4`)1`E#"44
M)1@E>?Y[_GW^?_YW_HK^\/[S_O+^SO[/_M#^]O[X_OK^_/Z@`/KX^?CX^*0`
M^_B+_I'^E_Z;_I_^H_X,!JT`I_ZS_F`&809B!F,&9`9E!F8&9P9H!FD&M_X;
M!KO^O_[*_A\&R_XA!B(&(P8D!B4&)@8G!B@&*08J!BL&+`8M!BX&+P8P!C$&
M,@8S!C0&-08V!C<&Q_XY!CH&S/Z"_H3^CO[3_D`&009"!D,&1`9%!D8&1P9(
M!DD&2@9+!DP&309.!D\&4`91!E(&U_[;_M_^_/CU_O?^^?[[_N/^Y_[L_NG^
M_?_0\````````````````````````````````````-[^`*BIJJNLK:X`L+&R
ML[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL\`T=+3U-76U]C9VMO<W0#?
MX.'BX^3EYN?HZ>KK[.WN[P#Q\O/T]?;W^/GZ^_S]`/\``````````&$!\0#R
M`/,`]`#U`/8`]P#X`/D`^@#[`/P`_0!^`?\`8`'1`-(`TP#4`-4`U@#7`-@`
MV0#:`-L`W`#=`'T!WP"@`*$`H@"C`*0`I0"F`*<`J`"I`*H`JP"L`*T`K@`^
M(,0`LP```````````-H```"_````P````-D```##`````````+0`````````
MP@````````#!`````````,4`````````````````````````S;H``,D``+L`
M`,@``+P``,P``+D``,L``,H``,X`````````````````````````WP```-P`
M``#;``````````"PL;(```````````````#^````````````````````````
M`````````````````("!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9F@``````
M_P"]G,^^W?7YN`"NJO"I[OCQ_?SOYO3Z]_L`KZRK\P``````````````````
M`````````````)X`````````````````````````````````````````]@``
M````````T`71!=(%TP74!=4%U@77!=@%V07:!=L%W`7=!=X%WP7@!>$%X@7C
M!>0%Y07F!><%Z`7I!>H%_?^C`/W_UP#]__W__?_]__W__?_]__W__?_]_ZX`
MK`"]`+P`_?^K`+L`D262)9,E`B4D)?W__?_]_ZD`8R51)5<E726B`*4`$"44
M)30E+"4<)0`E/"7]__W_6B54)6DE9B5@)5`E;"6D`/W__?_]__W__?_]__W_
M_?_]_Q@E#"6()80EI@#]_X`E_?_]__W__?_]__W_M0#]__W__?_]__W__?_]
M_Z\`M`"M`+$`%R"^`+8`IP#W`+@`L`"H`+<`N0"S`+(`H"6@`/W]_?T#_04&
M_?T*"PP-#@\0_?W]%/W]_?W]_?W]_?W]_P`!`@,$!08'"`D*"PP-#@\0_Q$2
M$Q05%A<8&1H;_____P`!`@,$!?__!@<("0H+__\,#0X/$!'__Q(3%!7___\`
M`0(#!`4&!P@)"@L,#0X/$!$2$_______________``$"`P0%!@<("0H+#`T.
M#Q`1$A,4%187&!D@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.4!!0D-$149'
M2$E*2TQ-3D]045)35%565UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T
M=79W>'EZ>WQ]?G^`@8*#A(6&AXB)BHL``0(#!`4&!P@)"@L,#0X/$!$2$Q05
M%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,71U=G=X>7I[?'U^?X"!@H.$
MA8:'B(F*BXR-E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VTM;:WN+FZN[R]
MOK_`P<+#Q,7&Q\C)RLO,S0`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<
M'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)
M2DM,34Y/4%%24U155E=865I;7%U>7V!A8F.FIZBIJJNLK:ZOL+&RL[2UMK>X
MN;J[O+V^O\;'``$"`P0%!@<("0H+#`T.#Q`1$A,4%187'A\@(2(C)"4F)R@I
M*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%56
M5UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#
MA(4``0(#!`4&!P@)"@L,#0X/$!$2$Q056%E:6UQ=7E]@86)C9&5F9VAI:FML
M;6YO<'%X>7I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9B9FIN<G9Z?H*&BHZ2E
MIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S0`!`@,$
M!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q
M,C,T-38W.#DZ.SP]/C]`04)#1$5&1XJ+C(V.CY"1DI.4E9:7F)F:FYR=GI^@
MH:*CJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/*R\S-``$"`P0%!@<("0H+
M#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X
M.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8&%B8V1E
M9F=H:6IK;&UN;W!Q<G-T=79W>'F\O;Z_P,$``0(#!`4&!P@)"@L,#0X/$!$2
M$QH;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S.CL\/3X_0$%"0T1%1D=(24I+
M3$U.3U!14E-455976%E:6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X
M>7I[?'U^?X"!@H.$A8:'B(F*BP`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9
M&AL<'1X?("$B(R0E)B<H*2HK;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>.
MCY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZZOL+&RL[2UMK>XN;J[O+V^O\#!
MPL/$Q<;'R,G*R\S-``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@
M(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-
M3D]045)35%565UA96EM<7:"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYP,'"
MP\3%QL<``0(#!`4&!P@)"@L,#0X/$!$8&1H;'!T>'R`A(B,D)28G*"DJ*RPM
M+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:
M6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'U^?X"!@H.$A0`!
M`@,$!08'"`D*"PP-#@]24U155E=865I;7%U>7V!A8F-D969G:&EJ:W)S='5V
M=WAY>GM\?7Y_@(&"@X2%AH>(B8J+DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBI
MJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-``$"`P0%!@<(
M"0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U
M-C<X.3H[/#T^/T!!A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)VDI::GJ*FJ
MJZRMKJ^PL;*SM+6VM[BYNKN\O<3%QL?(R<K+S,T``0(#!`4&!P@)"@L,#0X/
M$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\
M/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@86)C9&5F9VAI
M:FML;6YO<'%R<[:WN+FZN[R]OK_`P0`!`@,$!08'"`D*"PP-%!46%Q@9&AL<
M'1X?("$B(R0E)B<H*2HK+"TT-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/
M4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\
M?7Y_@(&"@X2%AH>(B8J+``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP=
M'A\@(2(C)"5H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8B)BHN,C8Z/D)&2
MDY25EI>8F9J;G)V>GZ"AJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%
MQL?(R<K+S,T``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D
M)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!1
M4E-45597FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.ZN[R]OK_`P<+#Q,7&
MQP`!`@,$!08'"`D*"Q(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q
M,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>
M7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%``$"`P0%
M!@<("4Q-3D]045)35%565UA96EM<75Y?8&%B8V1E;&UN;W!Q<G-T=79W>'EZ
M>WQ]?G^`@8*#A(6,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRM
MKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,T``0(#!`4&!P@)"@L,
M#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y
M.CM^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYZ?H*&BHZ2EIJ>HJ:JKK*VN
MK["QLK.TM;:WOK_`P<+#Q,7&Q\C)RLO,S0`!`@,$!08'"`D*"PP-#@\0$1(3
M%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`
M04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ:VQM
ML+&RL[2UMK>XN;J[O+V^O\#!``$"`P0%!@<.#Q`1$A,4%187&!D:&QP='A\@
M(2(C)"4F)RXO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)3
M5%565UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`
M@8*#A(6&AXB)BHL``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'V)C
M9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[@H.$A8:'B(F*BXR-CH^0D9*3E)66
MEYB9FINBHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)
MRLO,S0`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H
M*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%&4E9:7
MF)F:FYR=GI^@H:*CI*6FIZBIJJNLK;2UMK>XN;J[O+V^O\#!PL/$Q<;'``$"
M`P0%#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U
M-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8&%B
M8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#A(4``0(#1D=(24I+
M3$U.3U!14E-455976%E:6UQ=7E]F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'U^
M?X:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["Q
MLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S0`!`@,$!08'"`D*"PP-#@\0
M$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-7AY>GM\?7Y_
M@(&"@X2%AH>(B8J+C(V.CY"1F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&X
MN;J[O+V^O\#!PL/$Q<;'R,G*R\S-``$"`P0%!@<("0H+#`T.#Q`1$A,4%187
M&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$
M149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8&%B8V1E9F>JJZRMKJ^PL;*S
MM+6VM[BYNKN\O;Z_P,$``0@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A*"DJ
M*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-45597
M6%E:6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'U^?X"!@H.$
MA8:'B(F*BP`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@97%U>7V!A8F-D969G
M:&EJ:VQM;F]P<7)S='5\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9R=GI^@
MH:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-
M``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL
M+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2XZ/D)&2DY25EI>8F9J;
MG)V>GZ"AHJ.DI::GKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL<``0(#!`4&
M!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S
M-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@
M86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'W`P0`!`@,$!08'"`D*"PP-
M#@\0$1(3%!46%QX?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W/C]`04)#1$5&
M1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S
M='5V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+``$"`P0%!@<("0H+#`T.#Q`1$A,4
M%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO<G-T=79W>'EZ>WQ]?G^`@8*#
MA(6&AXB)BHN2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJ[*SM+6VM[BYNKN\
MO;Z_P,'"P\3%QL?(R<K+S,T``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;
M'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(
M24I+3$U.3U!14E-455976%E:6UQ=7E]@8:2EIJ>HJ:JKK*VNK["QLK.TM;:W
MN+FZN[R]Q,7&QP`!`@,$!08'"`D*"PP-#@\0$1(3%!4<'1X?("$B(R0E)B<H
M*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U15
M5E=865I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"
M@X2%``$"`P0%!@<("0H+#`T.#Q`1$A-65UA96EM<75Y?8&%B8V1E9F=H:6IK
M;&UN;W9W>'EZ>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/EI>8F9J;G)V>GZ"AHJ.D
MI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,T``0(#
M!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P
M,3(S-#4V-S@Y.CL\/3X_0$%"0T1%B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?
MH*&HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<C)RLO,S0`!`@,$!08'"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W
M.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D
M969G:&EJ:VQM;F]P<7)S='5V=[J[O+V^O\#!``$"`P0%!@<("0H+#`T.#Q`1
M&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$X.3H[/#T^/T!!0D-$149'2$E*
M2TQ-3D]045)35%565UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W
M>'EZ>WQ]?G^`@8*#A(6&AXB)BHL``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8
M&1H;'!T>'R`A(B,D)28G*"EL;6YO<'%R<W1U=G=X>7I[?'U^?X"!@H.$A8R-
MCH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EK*VNK["QLK.TM;:WN+FZN[R]OK_`
MP<+#Q,7&Q\C)RLO,S0`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?
M("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,
M34Y/4%%24U155E=865I;GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>^O\#!
MPL/$Q<;'``$"`P0%!@<("0H+#`T.#Q87&!D:&QP='A\@(2(C)"4F)R@I*BLL
M+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA9
M6EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#A(4`
M`0(#!`4&!P@)"@L,#5!14E-455976%E:6UQ=7E]@86)C9&5F9VAI<'%R<W1U
M=G=X>7I[?'U^?X"!@H.$A8:'B(F0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>H
MJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S0`!`@,$!08'
M"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T
M-38W.#DZ.SP]/C]!@<V!FX)C@^F#MX2%A4>&TX:AAVF([XB]B8N*38O9BZ>,
M;XWUC<..D8]3D-^0K9%UDON2R9.7E%F5Y96SEH&70YC/F)V999KKFKF;AYQ)
MG=6=HYYKG_&?OZ```````````&SX"0``P0P`[D\7`/SL(@#^UR\`[^X\`/__
M3`!L^E8`A.%<`.Y/9P#\:'``_L1Z`.WNA@!?_Y0`;&J<`)3/I0"N3Z\`_>Z\
M`/[-R`#/[M0`3_W@`.[^[0#US_D`AD<``?GL"P'^SQ@![_\G`7__-@'L_D(!
M].].`>[_7`'_;&@!_-1R`>__@0'__Y$!;/J;`92+H@&N3ZP!W.RV`?[$P`'/
M[\T!___=`?__[0'_C_H![D\%`OSL$`+_UAT"[^XJ`G_>-P+^_T8"_\]4`NI/
M7@+Q_&D"_L]V`L__A`+__9,"[OZ@`MSOK`+__[P"_^S)`GZ4T@+O[^`"__SN
M`NS^^@+L[P8#[L\2`__^(0/__S$#SZH[`T?=10/__U4#_\]C`^Y/;@/]:'@#
M^`1^`\7NB`-/_),#[/Z?`][_K0/__[T#_^3)`_+$T0/'[MP#3_SG`^S^\P/,
M[OT#_O\,!/_L&03ZU",$X^XN!/_^/03__TT$_^]<!.Y/9P3_['0$_M6`!,_F
MBP1/_9<$_O^F!._OM`3__\0$_^[2!/[\WP3/[^P$S_WY!.SX`P64ZPP%[O\:
M!?_L)P7ZU#$%BP8W!4=P/@7L_DH%Q.]4!?__9`7__W0%__^$!8\FC`5/M98%
M[/ZB!<3OK`7N_[H%_.[&!?__U@7/IN`%3M7I!>[^]@7_[P4&__\5!O[N(@;^
M]"X&[_\]!O__30;L_ED&U.]D!O__=`;^_H(&_]^1!N_NG@9?_:L&[OZX!M[/
MQ`:F3\T&_?[;!O__ZP;/YO8&3_@`!^S^#`?$QQ0'[D\?!_S_+0?__ST'__]-
M!___70?L\F<'Q,=O!^Y/>@?\_H<'_^^6!___I@?__[8'[/["!]_OT`?O_]\'
M__[N!____@?O_@P(__\<"/__+`C_SSH([N=&"/W_50C__V4([_]T"/__A`CN
M_I$(W/^>"/__K@C_;+H(_O3&"._NTPC/_^$([O[N"-3/^`CN3P,)..P+"?[$
M%0G/_B()?_TP"?__0`G_STX)[D]9"7SL8PG^U&X)S^YZ"4_\A0GN_Y,)]<^?
M">Y/J@G][K<)_]_&"?__U@G__N4)[O[R"=3O_0GN7PD*_>P5"O[4(`KO_R\*
M__X^"O[_30K_SUL*[F]G"OWL<PK^U'X*S^Z*"D^9DPK__Z,*_\^Q"NY/O`K]
M+,8*^)3."L7NV`I/^.(*_/[O"M___@K__PX+_^P;"_J4)`O'[B\+3_PZ"^S^
M1@M'[U$+__]A"__D;0OZU'<+[_Z%"__\DPO__Z,+_^^R"^Y?O@O][LL+_O78
M"X^&X`M/7>H+[O[W"_7O!`S__Q0,_^XB#/[_,0SO[CX,;_],#.[^60SV_V<,
M__]W#/]L@PSZ1(L,#0:0#$_=FPSL_J<,Q,VO#/[?O0S__\T,___=#,^FYPQ/
M^?(,;/[]#,3/!@WN7Q(-W.X=#?__+0V/[C@-3_U$#>[_4@WO[V`-__]P#?[L
M?`W^_(D-[_Z7#?__IPUL^+`-U.FY#>__R`W^_M8-___F#<_N\@W__0$.[OX.
M#M;/&0[N3R0.__\T#O__1`[/KD\.3_%9#NSZ9`[$QVP.[D]W#OS\@P[__I(.
M__^B#O__L@YL_KT.QN_(#O__V`[]_.4._\3P#O__``___Q`/[/X<#]S_*0__
M_SD/__])#___60_O_V@/__]X#_[_AP_?SY0/[F^@#_W_KP___[\/___/#___
MWP___^\/_^_^#___#A#][AL0_OPH$/__.!#__T@0[/Y4$-1/71"&3V40W.QO
M$/[$>1#/[H403_V1$.[^GA#>#Z@0)D^P$+SLNA#^Q,00S^[0$$_\VQ#N_N@0
MWX_T$*Y/_A#=[`D1_M\7$>_N)!%O_C$1[OX^$?3/21'N3U01_6Q?$?Y4:1'I
M_W81__Z%$>S^D1'>SYT1[D^H$?W\M1'^UL$1S\[,$4_]V!'__^@1_\_V$>9'
M_Q&]Y`D2_LP4$L?N'Q+/_"L2__\[$M__2A+__UH2_^QG$OK,<1+O[GX2__^.
M$O__GA+__ZX2_O^]$O]LR1+ZW-02S_[A$O_^\!+^__\2[^\-$^[/&1/__B@3
M__\X$\_N1!//_5$3_O]@$^_O;A/__WX3_^Z,$___G!/__ZP3__V[$^QZQ1/\
M[](3[N_?$__L[!/^U/<3SXC_$T><!Q3L_A,4Q,\<%&Y/)A1=[C$4_OT_%,^$
M1Q0/J$X4[/Y:%-2/8Q0N#VL4'.YT%/[D?Q3/CHD41O62%.S^GA3$SZ<4_F^T
M%/WLP!3^U,L4S^[7%$_]XQ3L^.T4U,_W%.[/`Q7\[`X5_MP:%<_N)A5/_3(5
M[/X^%53/1Q7N2U$5`>Y8%?[V917/CF\51[AW%2SZ@!6$SX@5[D^3%?RLG17^
MWJH5[^ZW%?__QQ7L^M(5E,_;%>Y/YA7][O,5_LS^%>__#1;__QT6[/HH%A3'
M+Q;O7SP6'0`````````````````````````````!`@,$!08'"`D*"PP-#@\0
M$1(3%!46%Q@9("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#E`04)#1$5&1TA)
M2DL``0(#!`4&!P@)"@L,#0X/$!$2$[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*
MR\S-U-76U]C9VMO<W=[?X.'BX^3E``$"`P0%!@<.#Q`1$A,4%187&!D:&QP=
M'A\@(2(C)"4F)R@I*BLL+<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY0`!"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]
M/C]`04)#1$5&1^CIZNL``0(#!`4&!P@)"@L,#0X/$!$2$Q05'!T>'R`A(B,D
M)28G*"DJ*RPM+B\P,3(S-#4\/3X_0$%"0T1%1D=(24I+``$"`P0%!@<("0H+
M#`T.#["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)T-'2T]35UM?8V=K;W-W>
MW^#AXN/DY0`!`@,*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*<K+
MS,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CZNL``0(#!`4&!P@)"@L,#0X/$!$2
M$Q05%A<>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/=[?X.'BX^3E
M``$"`P0%!@<("0H+#`T.#Q`1&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$X
M.3H[/#T^/T!!0D-$149'2$E*2P`!`@,$!08'"`D*"ZRMKJ^PL;*SM+6VM[BY
MNKN\O;Z_P,'"P\3%S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.4``0(#!`4&
M!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'\#!PL/$Q<;'R,G*R\S-SL_0T=+3
MU-76U]C9X.'BX^3E``$"`P0%!@<("0H+#`T.#Q`1$A,:&QP='A\@(2(C)"4F
M)R@I*BLL+2XO,#$R,S0U-C<X.=K;W-W>W^#AXN/DY0`!`@,$!08'"`D*"PP-
M%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TT-38W.#DZ.SP]/C]`04)#1$5&
M1TA)2DL``0(#!`4&!ZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!R,G*R\S-
MSL_0T=+3U-76U]C9VMO<W=[?X.'HZ>KK``$"`P0%!@<("0H+#`T.#Q`1$A,4
M%187&!D:&[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35W-W>W^#AXN/DY0`!
M`@,$!08'"`D*"PP-#@\6%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T
M-=;7V-G:V]S=WM_@X>+CY.4``0(#!`4&!P@)$!$2$Q05%A<8&1H;'!T>'R`A
M(B,D)28G*"DP,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+``$"`Z2EIJ>H
MJ:JKK*VNK["QLK.TM;:WN+FZN[R]Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;
MW-WDY>;GZ.GJZP`!`@,$!08'"`D*"PP-#@\0$1(3%!46%[BYNKN\O;Z_P,'"
MP\3%QL?(R<K+S,W.S]#1V-G:V]S=WM_@X>+CY.4``0(#!`4&!P@)"@L2$Q05
M%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,=+3U-76U]C9VMO<W=[?X.'B
MX^3E``$"`P0%#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4L+2XO,#$R,S0U
M-C<X.3H[/#T^/T!!0D-$149'2$E*2P`!`@,$!08'"`D*"PP-#@\0$1(3%!46
M%Q@9("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#E`04)#1$5&1TA)2DL``0(#
M!`4&!P@)"@L,#0X/$!$2$[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-U-76
MU]C9VMO<W=[?X.'BX^3E``$"`P0%!@<.#Q`1$A,4%187&!D:&QP='A\@(2(C
M)"4F)R@I*BLL+<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY0`!"`D*"PP-#@\0
M$1(3%!46%Q@9&AL<'1X?("$H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#
M1$5&1^CIZNL``0(#!`4&!P@)"@L,#0X/$!$2$Q05'!T>'R`A(B,D)28G*"DJ
M*RPM+B\P,3(S-#4\/3X_0$%"0T1%1D=(24I+``$"`P0%!@<("0H+#`T.#["Q
MLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)T-'2T]35UM?8V=K;W-W>W^#AXN/D
MY0`!`@,*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*<K+S,W.S]#1
MTM/4U=;7V-G:V]S=WM_@X>+CZNL``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<>
M'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/=[?X.'BX^3E``$"`P0%
M!@<("0H+#`T.#Q`1&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$X.3H[/#T^
M/T!!0D-$149'2$E*2P`!`@,$!08'"`D*"ZRMKJ^PL;*SM+6VM[BYNKN\O;Z_
MP,'"P\3%S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.4``0(#!`4&!P@)"@L,
M#0X/$!$2$Q05%A<8&1H;'!T>'\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9
MX.'BX^3E``$"`P0%!@<("0H+#`T.#Q`1$A,:&QP='A\@(2(C)"4F)R@I*BLL
M+2XO,#$R,S0U-C<X.=K;W-W>W^#AXN/DY0`!`@,$!08'"`D*"PP-%!46%Q@9
M&AL<'1X?("$B(R0E)B<H*2HK+"TT-38W.#DZ.SP]/C]`04)#1$5&1TA)2DL`
M`0(#!`4&!ZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!R,G*R\S-SL_0T=+3
MU-76U]C9VMO<W=[?X.'HZ>KK``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:
M&[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35W-W>W^#AXN/DY0`!`@,$!08'
M"`D*"PP-#@\6%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-=;7V-G:
MV]S=WM_@X>+CY.4``0(#!`4&!P@)$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G
M*"DP,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+``$"`Z2EIJ>HJ:JKK*VN
MK["QLK.TM;:WN+FZN[R]Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;W-WDY>;G
MZ.GJZP`!`@,$!08'"`D*"PP-#@\0$1(3%!46%[BYNKN\O;Z_P,'"P\3%QL?(
MR<K+S,W.S]#1V-G:V]S=WM_@X>+CY.4``0(#!`4&!P@)"@L2$Q05%A<8&1H;
M'!T>'R`A(B,D)28G*"DJ*RPM+B\P,=+3U-76U]C9VMO<W=[?X.'BX^3E``$"
M`P0%#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4L+2XO,#$R,S0U-C<X.3H[
M/#T^/T!!0D-$149'2$E*2P`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9("$B
M(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#E`04)#1$5&1TA)2DL``0(#!`4&!P@)
M"@L,#0X/$!$2$[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-U-76U]C9VMO<
MW=[?X.'BX^3E``$"`P0%!@<.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I
M*BLL+<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY0`!"`D*"PP-#@\0$1(3%!46
M%Q@9&AL<'1X?("$H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1^CI
MZNL``0(#!`4&!P@)"@L,#0X/$!$2$Q05'!T>'R`A(B,D)28G*"DJ*RPM+B\P
M,3(S-#4\/3X_0$%"0T1%1D=(24I+``$"`P0%!@<("0H+#`T.#["QLK.TM;:W
MN+FZN[R]OK_`P<+#Q,7&Q\C)T-'2T]35UM?8V=K;W-W>W^#AXN/DY0`!`@,*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*<K+S,W.S]#1TM/4U=;7
MV-G:VP````````````!!H8VA<Z)9HT6DD:1WI6.F2:>5IX&H9ZE-JIFJA:MK
MK%&MG:V)KF^O5;!!L8VQ<[)9LT6TD;1WM6.V2;>5MX&X9[E-NIFZA;MKO%&]
MG;V)OF^_5<!!P8W!<\)9PT7$D<1WQ0``````````````````````````````
M````````````````````````````````````````````````````````````
M`````.#^"@#_SQ@`[^XE`$_],0#L_SX`W\]+`(Y/5`#]_F(`_^]Q`.__@`#_
M_Y``[/Z<`/3OJ`#N[[4`_^S"`/[4S0#__]T`___M`&SZ]P"4R?X`:D\'`?SL
M$@'^Q!P![_XJ`?_].0'__TD!_\]7`>Y/8@'\_F\!_]]^`>__C0'__IP!__^L
M`?_/N@'N3\4!]?S1`?[OWP'O_^X!__[]`>[^"@+\_Q@"__\H`OWL-`+^W$`"
M[_]/`O_\70+__VT"_^]\`O__C`+__IL"__^K`N__N@)O_<<"___7`O_/Y0+N
MS_$">:SZ`OZ$`P//[@\#3_P:`Z[^)@/>_S0#__]$`__L40/^Q%L#S^YG`T_]
M<P/N_X$#[^^/`_[_G@/][*H#_M2U`^_NP@/__=$#___A`__O\`/N3_L#_?X)
M!/_^&`3/[B0$3_TP!/[_/P3O[TT$_O]<!/_N:@3^U'4$[^Z"!._]D`3L_IP$
MU/^H!/__N`3_;,0$_-3.!,_NV@1/_>8$[/[R!,3/^P3__PL%_?\:!?__*@7/
MYC4%3_Q`!>S^3`74[U<%[D]B!?S^;P7__W\%S^Z+!4_]EP7L_J,%WN^P!?__
MP`7]_LX%_O_=!>__[`7___P%[/X(!M3O$P;N_R$&_?XO!O_?/@;/[DH&3_U6
M!N[^8P;^SW`&[L]\!OW_BP;__YL&S^ZG!D_]LP;L_+X&Q,_'!NY/T@;\_M\&
M_]_N!O___@;__PX'[/H9!\3/(@?N3RT'_>XZ!__O20?O_E<'__]G!^S^<P?4
MZWT'_O^,!__^FP?__ZL'[_ZY!W_]QP?^_]8'_\_D!^Y/[P?]_OT'_^\,".__
M&PC__RL([/XW"-SO0PCN[U`(_6Q;"/KT9@CO[G,(S_^!".S^C0C4CY8(KD^@
M"-SLJ@C^Q+0(S__""/__T@C__^((_\_P".Y/^PC\[`8)_M01">_N'@G/_"H)
M_OXX"?7/1`GN3T\)_?Y="?_?;`G__WP)__^,">[_F@G_[ZD)[E^U"?]LP0GZ
MU,L)[__:"?_]Z0G___D)_^\("NYO%`K_[B(*_M8N"N_N.PI/_T@*__]8"O_/
M9@KN3W$*_>Q]"M[4APK/[I,*3_R>"O[_K0K?_[P*___,"O_LV0KZU.,*S^[O
M"D_]^PKL_@<+Q.\1"^[?'@O_["L+WM0U"\WN0`M__4X+[/];"]?/9PON7W,+
M_>Z`"_[UC0O/[ID+;?VE"^[^L@O>S[X+[O_,"_WLV`O^U.,+S^[O"V_]_`LL
M_`4,U.T/#.[/&PS]["<,_M0R#`\``````````````````````````````0,$
M"0H+#`T6'!T?("$C)"4F)R@I+#`Q,C,T-3@Y.SP]/T!!0D-$149'2$I,34Y/
M4%%35%576%E;7%U>7V!A8F-D969G:&EJ:VQM<'%S='=Y>GM\?8"%A@`!`@0%
M!@@)"@L,#0X1%187&!D:'B`A)"4F)R@I*BTQ,C,U-C@Y.CP]/D!!0D-$149'
M24M,34Y/4%%2559865Q>8&%E9VIK;&UN<7)T=79X>GM\?7Z!@X6&``$"`P4&
M!PD*"PT.#Q`1$A,4%A<:&QP='A\B(R4F)RDJ*RPM+B\R-#8W.#DZ.ST^/T%"
M0T5&1TA)2DM,3E!14E-455976EM=7F-D969J;&]P<7)S=G=Y>GL``0(#!`4&
M!P@)"@T.#Q`1$A05%A<8&1H;'!T>'R`A(B,D)2<H*2HK+"TN,3(T-38X.3H[
M/#T^04-$149'2$E*3$U.4%%25%565UA96EM<75Y?8&%B8V1E9@`!`P0("0H+
M#`T0$A05%A<8&1L<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-3@Y.SP_04)#
M1$5(2DU.3U%55UA96UU>7V!A9&AI:FQM<'%S='5W>'EZ>WQ]``0%!@<("0P-
M#@\0$1,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[
M/#T^/T!!14=(24M,34Y/4%%46%E:6UQ=8&%C9&5F9VAI:FL``0,$!@@)"@L,
M#0\0$1,4%1<8&1H;'!T>'R`C)"4F*"DK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`
M04)#1$5(24M-3U!14E-455A:7E]@861E9F=H:6ML;6YO<``!`@,$!P@)"@L,
M#Q`1$A,4%187&!D:&QP='A\@(2,D)28G*"HK+"XO,#(S-#4V-S@[/#T_0$%"
M0T1&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!C9&9G``(#!`4&!PL-$!$2
M$Q06%Q@9&AL<'A\@(2(C)"4F)R@K+"TN+S`S-#8W.#H[/#T^/T!#1$9'2$E*
M2TQ.3U!24U165UA96EM<7V!A8F-D969G:&IK;&UN;W```0(#!`4&!P@)"@L,
M#0X/$!$2$Q87&1L='R`A(B8H*BLL+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%
M1D=(24I+3D]14E-55E=865I;7F!B8V1E9F=K;6YS=``!`@4+#1$2%!46&!D:
M&QP='B$E)B<H*2HM+C`Q,C0U-C<X.3H\/3X_04)#1$5&1TA)2DM,34Y/4%%2
M4U155E=865I;7%U>7V!A8F5H:6IL;W!Q<G5Y>GM\``0%!P@)"PP-#@\0$108
M&1H;'!T@(2,D)2<H*2HK+"TP,30U-S@Y.SP]/T!!0D-$149'2$E*2TQ-3D]0
M45)35%5865M<75]A8F-D96AJ;&UN;W-T=7=X>7L``0(#!`4&!P@)"PP-#@\0
M$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TO,#$S-#4W.#DZ.SP]0$)#
M1$5&1TA)3$U/4%%35%565UA96EQ>8&%B8V1E:``"`P8'"`D*"PP/$1,4%187
M&!H;'!T>'R`A(B,D)28G*"DJ*RPN+S`Q,C,T-C<X.3H[/#T^/T!!0D-$149'
M2$E*2TQ-3D]04E-45E=86EM<75Y?8&-D969G``$"`P0'"`D*"PP.#Q`1$A,4
M%Q@9&QP='A\@(R0F)R@L+2XO,#,U.#DZ/#X_0$)#1$9'2$E*2TQ-3D]045)3
M5%565UA;7%Y?8&)D969G:&MM;W!Q<G1X>GL``0(&#`T.$A,5%A<9&AL<'1X?
M(B8G*"DJ*RTN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%2
M4U155E=865I;7%U>7V!A8F-G:6IM<'%R<P`"!`8'"0P-#Q`1$Q05%A<8&1P@
M(2(C)"4G*"DK+"TO,#$R,S0U-C<X.3P]/C]`04-$14=(24I+3$U.3U!14E-4
M55976%E:6UQ=8&%C9&=I:VQM<')T=GAY``$"!`4&"`D*"PP-#@\0$1(3%!46
M%Q@9&AP='A\@(2(C)"4F)R@I*BLL+2XP,3(S-#4V.#DZ/#T^0$%"0T1%1DE+
M3$U.3U!14E155E=865I;7%U>7V!A8F,``0(#!`4&!P@)"@T.$!$2%!46%Q@9
M&AT?(2(C)"4F*"DJ*RPM+B\P,3(S-#4V-S@Y.CP]/C]`04)$149'2$E*2TQ-
M3D]045)35%565UE:6UQ=7F!A8F1E9@`!`@,$!08'"0L-#@\0$1(4%188&1H<
M'1X?("$B)"4F)RDJ*RPM+C$R-#4X.CL\/3Y!0T5&1TA)2DQ-3D]045)35%56
M5UA96EM<75Y?8&%B8V1E9FEJ;&UP``$"`P0%"`T.#Q`1%!47&!D;'!T>'R`A
M)"@I*BLL,#$S-#4W.#DZ.SP]0$1%1D=(24I+3$U.3U!14E-455976%E:6UQ=
M7E]@86)C9&5F9VAI:FML;6YO<'$``0(#!`4&!P@)"@L,#0X/$A,5%A<9'!T>
M'R(F)R@I*BXO,3(S-38W.#DZ.SY"0T1%1D=)2DM,34Y/4%%24U155E=865I;
M75Y?8&%B8V1E9F=H:6IK;&UN;P`!`@,$!08'"`D*"PP-#@\2$Q46%QD:&QP=
M'A\@(2(C)"8G*"DJ*RTN+S`Q,C,U-C<X.3H[/#T^/T!!0D-$149'24I+3$U.
M3U!14E-455976%E:6UQ=7E]@``$"!`4&"`D*"PP-#@\0$1(3%!46%Q@9&AL<
M'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ/3Y`04)$149'2$E,34Y/
M45)35%565UA96EM<75Y?8&$``0(#!`4&!P@)"@L,#0X/$!(3%!46%Q@9&AL<
M'1X?("$B(R0E)B<H*2HK+"XO,#(S-#8W.#DZ.SP_0$%#1$5&1TA)2DM,34Y/
M4%%24U155E=865I;7%U>7P`!`@,$!P@*"PX/$!$2$Q07&1H;'!T>'R`B(R0F
M)R@J*RPM+B\P,S0U-C<X.3H[/#X_0$)#1$9'2$E*2TQ/45-455976%M<7E]@
M8F-D969G:&MP<7)W>'I[``(#!`4&!P@+#Q`1$A,4%Q@:&QP='A\@(2(C)"4F
M)RDK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,3U!24U165UA9
M6EM<7V-D969G:VQN;W```0(#!`4&"0L-#@\0$1(5%A@9&AP='A\@(2(E*2HK
M+"TN,#$R-#4V-S@Y.CL\/3X_04-$149'2$E*34Y045)455976%E:75]A8F-D
M969H:6IL;6YO<'%R<P`!`@,$!08'"0H+#`T.#Q`1$A,4%187&!D:&QP='A\@
M(2(D)28G*"DJ+"TN,#$R-#4V-S@Y.CT_04)#1$5&2$E*3$U.4%%24U155E=9
M6UU>7V!A8F5F:&EJ``$"`P0%!@D+#0X/$!$2%!46%Q@9&AL<'1X?("$B(R0E
M)B@I*BLL+2XP,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I-3E!14E155E=8
M65I<75]A8F-D968``0,$!0<("0H+#`T0$A05%A<8&1P='R`A(R0E)B<H*2PN
M,3(U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045155UA96UQ=7E]@861F
M:&EJ:VQM<'%S>0`!`@,&"`L,#A(3%187&1H;'!T>'R(G*"DJ*RXO,#$R,S4V
M-S@Y.CL\/3X_0$)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-F
M9VEJ:VUO<'%R``,%"`D*"P\0$A,4%A<8&1H;'!\C)"4F)R@K+"XO,#(S-#4V
M-S@Y.CL_04)#1$9'2$E*2TQ-3D]045)35%565UA96EM<75Y?8&-F9VAJ;&UN
M;W!S=7=X>7H``0,$!0<("0H+#`T.#Q`1$A,4%1@9&AL<'1X?("$B(R0E)B<H
M*2HK+"TN+S`Q,C,T-38W.#D[/#T_0$%#1$5&1TA)2DQ.4%%24U155UA96UQ=
M7V!A8F-D90`"!`4&!P@)"@L/$1(7&!D:&QX@(B,D)BDJ*RTN+S$R,S0U-C<X
M.CP]/C]`04)#149'2$E*2TQ-3D]045)35%565UA96EM<75Y?86)C969G:6IK
M;&UN;W!Q``$"`P0%!@<("0L,#0\0$1,4%187&!D;'!X?("$B(R0E)R@I*RPM
M+S`Q,C,T-3<X.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=
M8&%C9&<``0(#!`<+#0\0%A<='A\@(R4G*"DK+"\P,C,T-C<X.3H[/#]#1$5'
M2$M,3D]045)35%565UA96UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X
M>7I[?``!`@,&!PD*#0\0$1(3%A@;'!T>'R(C)28I*BLL+2XO,C8W.#DZ.SX_
M04)#149'2$E*2TQ.4E-45E=96EM=7E]@86)C9&5F9VAI:FML;6YO<'%R<W=Y
M>GM]``$"`P0%"`H,#0X/$!$3%!47&!D:&QP='A\@(2(C)"4G*"DJ*RPM+S`Q
M,C,T-38W.#DZ.SP]/C]`04-$149'2$E,34]045-455976%E<75Y?8&%B8V1E
M9V@``@,$!08'"`D*"PP-#@\0$1(3%!46%Q@;'!X?)"4F)R@K+2\P,30V-S@Y
M.CL\/C]`04)#1$5&1TA*2TQ-3D]04E-455976%E:6UQ=7E]@86)C9&5F9VAI
M:@`!!`4'"`D+#`T.#Q`1$A,4%188&1H;'!T?("$C)"4G*"DJ*RPM+S`R-#4V
M-S@Y/#T_0$%#1$5&1TA)3$Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ
M``$"`P0%!@D*#`T.$!(3%!46&1L?("$B)28H*2HL+B\P,3(U.3H[/#U!0D1%
M1DA)2DM,34Y155976%E:75Y?8&%B8V1E9F=H:6IL;6YO<'%R<W1U=G=X>7H`
M`0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<:&QT>(2(C)"4F)RDJ+B\P,3(S-38W
M.#DZ.SP]/C]`04)#1$5&1TA*2TQ-3D]24U155E=865I;7%U>7V)F9VAI:@`!
M`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'R`B(R0F)R@I*BLL+S`Q,S0U
M-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?``$"
M`P0%!@<("0H+#`T.#Q`2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPN+S`Q
M,C,T-38W.#DZ.SP]/C]`04-$149'2$M,3D]04E-455976%I;75]@86(``0(#
M!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P
M,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455=860`!`@,$
M!08'"`D*"PP-#@\0$A,4%187&1H;'1X?(2(C)"4F)RHK+"TN+S`Q,C,T-38W
M.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4E-55E=96EM<75Y?8F1F``$"`P0'
M"@L0$1(3%!<;'!T?(",D)B<H*BLL+2XO,#,W.#DZ.SP_0$)#1$9'2$E*2TQ/
M45-455976%I;7%Y?8&)C9&5F9VAJ:VQM;W!Q<G-T>GM^@8*#A(<``0(#!0@)
M"PP-#Q`1$A,4%1@<'1X?("$D)2<H*2LL+2XO,#$T.#DZ.SP]/T!!0T1%1TA)
M2DM,34Y/4%%25%565UA975]@86-E9F=H:6QN<'%R='5X>7M\?0`!`@,$!08'
M"`D*"PT.#Q`1$A05%A@9&AP='A\@(2(D)2@I*BLL+2XP,3(T-38X.3H[/#T^
M04-$149'2$E*34Y045)455976%E:75]A8F-D969I:FQM<'%R``$"`P8("@P/
M$1(3%!46%Q@9&AL<'1X?("$B(R4F)R@I*BLN+S$R,S4V-S@Y.CL]/C]`0D-$
M149'2DM-3D]14E-455976EQ>7V!A8F-F9VAI:FMM;F]P<7(``@,%!P@)"@L,
M#Q`2$Q07&!D:&QP?(2,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"
M0T1'2$I+3D]045)35UE;7%U>8&-F9VAJ:VQM;F]P<W1W>``!`@8'"0H+#0X/
M$!$2$Q87&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-C<X.3H[/#T^/T!!
M0D-$149'2$E*2TQ-3D]045)35%565UI;75Y?86-D969G``$$!08'"`D+#`T/
M$!$3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]
M/C]`04)#1$5'2$E*2TQ-3D]045)35%565UA96EM<76```@,&"`D*"PP/$!$3
M%!46%Q@;'!X?("$B(R0E)B<H*2HK+"XO,#$R,S0V-S@Y.CL\/3X_0$%"0T1%
M1D=(2DM,34Y/4%)35%976%I;7%U>7V!C9&5F9VAI:@`!`P0%!@<("0H+#`T.
M#Q`1$A,4%187&!D:&QP=("$C)"4G*"DJ*RPM,#$R-#4V-S@Y.SP]/C]`04)#
M1$5&1TA)2DM,34]045)35%576%E:6UQ=7E]@86)C``$"`P0%!@<("0H+#`T/
M$!$3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]
M/D!!0D-$14A)2TQ-3U%24U1865I;7%U>7V!A8V0``@,$!@<("0H+#`X/$!$2
M$Q05%A<8&QP>'R`B(R0E)B<H*RTO,#$R,S0W.#Q`04)#1TM,35!35%976%I;
M7%U>7V!C9VAI:FML;W!R<W1V=WEZ>WQ_@8.$A0`#!`4'"`D+#`T.#Q`1$A05
M%A<8&1H;'!T@(20I*BLL+34W.3P]/T!!0T1%1D=(24Q.4%%24U1565M<75]B
M8V1E;&UN<W1U=WAY>WQ]?G^`@82'B(F*BXR-``$#!`4)"PP0$A06%Q@9'!T?
M("$C)"4F)R@I+#`Q,C,T-3@Y.SP]/C]`04)#1$5'2$I,34Y/4%%455=865M<
M75Y?8&%D9FAI:FML;7!Q<W1U=WAY>GM\?8```@,$!08'"@L-#@\3%!46%QH<
M'A\@(2(C)B<I*BLM+B\P,3(S-C<Z.SP]/C]"0T5&1TE*2TQ-3D]24U165UA9
M6EM>7V%B8V5F9VAI:FMN<')S='5V=WI[?0`!`P0%!@<("0P.$!(3%!48&1L<
M'1\@(2(C)2@J,S0U-S@Y.SP]/C]`04-$1D=(24I+3$U045-455E:6UQ@969G
M:6QM;W-U=G=X>7R!@H.$A8B)BXR-CY"1``$"`P8*"PP-#@\2$Q47&1H;'!T>
M'R$B(R0F)R@I*BLM+B\Q,C,U-C<X.3H[/#T^/T!!0D-$149'2DM-3D]14U15
M5E=:7%]@86)C9F=I:FMM;F]P<7)S=G@``0(#!`4'"`D+#`T/$!$2$Q05&!D<
M'1X?("$C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#U`04-$14=)2DM,35!2
M5E=87%U>7V!A8V1E9F=H:6IL;G!Q<@*LC:P4K9&M^JUZKN:N5Z^_KS"PI;`B
ML9ZQ![)OLO"R9K/ALT6TK;0>M9"U`+9AML.V([>?MQ&XA;CQN%JYU+E'NL*Z
M*+N:NP.\@+S^O&>]TKT]OKB^([^#O^:_0,"GP#+!L<$DPI?"$,-ZP]O#1L2J
MQ`_%EL4FQJC&)L>XQS+(``$"!`4&!P@)"@L,#0X/$!$2$Q05%AD:&QP='B`A
M(B0E)B@I*BLL+2XQ``(#!`4&!PH+#0X/$!$2$Q05%A<8&1H;'!X?("$B(R8G
M*2HK+S`Q,C,V``(#!`4&!PD*"PP-#@\0$1(3%!46%Q@9&AL='A\@(2(C)28G
M*"DJ*RPM``$"`P0%!@<("0H+#`T.#Q`1%!47&!D;'!T>'R`A)"8G*"DJ*RPM
M+S`Q``$"!`4&!P@)"@P-#@\0$1(3%!46&1H<'1X@(2(C)"4F*2LM+B\P,3(S
M``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:'1X@(20F)R@I*BTO,C,V``$#
M!0<("@L,#1`4%187&!D<'1\@(2,D)28G*"DL,#$R,S0U-S@Y.SP]``$"`P0%
M!@<("0H+#`X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ``$"`P0'"`H+
M#`X/$!$2$Q07&QP='A\@(B,D)28G*"DJ*RPM+B\P,3(S``$#!`4&!P@*"PP-
M#@\0$1(3%!46%Q@9&AL<'A\@(2(C)"4F)R@I*BLL``$"`P0%!@<("0H+#`T.
M#Q`1$A,6%QD:&QT>'R`A(B,F*"HL+2XO,C,T``$"!`4&!P@)"@L,#0X0$1(3
M%!46&!D:&QP='A\@(2(C)"4F)R@I*BPM``$"`P0&!P@*"PP.#Q`1$A,4%Q@9
M&AL<'1X?("$B(R0E)B<H*2HK+"TN``$"`P0%!@@)"@L,#1`1$Q05%Q@9&AL<
M'2`A(B0E)B<H*2LL+2XO,#$R``$"`P0%!@<("0H-#@\0$1(3%!46%Q@9&AL<
M'1X?("$B(R0E)B<H*2HK``$"!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>
M("$B(R0E)B<H*2HK``$"`P0%!@<("0H+#`T.$!$2$Q05%A<8&1H;'!T>("$C
M)28G*"DJ*RPM``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!L<'A\@(B,D)28G
M*"LL+3`Q``$%!@@*#`T.#Q`1$A4:&QP='B$B)"4F*"DJ*RPM+C$U-C<X.3H\
M/3Y```(#!`4&!P@*"PP-#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL
M``$"`P8'"0H+#0X/$!$2$Q8:&QP='A\B(R4F)RDJ*RPM+B\R-#8W.#DZ``(#
M!`8'"`D*"PP-#@\0$1(3%!87&!D:&QP>'R`B(R0E)B<H*2HK+"TN``$"!`4&
M!P@)#`T/$!$3%!46%Q@9'!X@(2(C)"4G*"DK+"TO,#$R,S0U``$"`P0&!P@)
M"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*2HK``$"!`4&!P@)"@T/
M$1(3%!46&!D:&QP='A\@(2(C)"4F*"DJ*RPM+B\P``$$!0<("0L,#0X/$!$4
M%A@9&AL<'1\@(2(C)"4F)R@I*BLL+2XO,#$S``$"`P0%!P@)"PP-#@\0$1(3
M%!46%Q@9&AL<'1X?("$C)"4G*"DK+"TN``$"!0<)"@L,#0X0$1(4%188&1H;
M'!T>("$B(R4F)R@I*BTN,#$R-#4V``$"`P8("@L,#0X/$!$2$Q05%A<8&1H;
M'!T>'R`A(B,D)28G*"DJ*RXO``$%!@<("0H-#Q$2$Q05%AD:'!T>("$B(R0E
M)BDK+2XO,#$R-38X.3H\``$"`P0%"`P-#@\0$105%A<8&1H;'!T>'R`A(B,D
M)28H*2HK+"TN+S`Q``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&AL='B$B(R0E
M)B<J+B\P,3(S``$#!`4'"`D*"PP-$!(4%187&!D;'!T?("$C)"4F)R@I+#`Q
M,C,T-3<X``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!L<'A\@(B,D)28G*"LM
M+S`Q``$"!08("0H,#0X/$!$2%!46%QD:&QP='B`A(B,D)28G*"DJ*RPM+B\P
M``$"!`4&!P@)"PP-#@\0$1,4%187&!D:&QP='A\@(2(C)"4G*"DJ*RPM``$"
M`P0%!@<("0H+#`T.#Q`1$A,6%QD:&QT>'R`A(B,F*"HK+"TN+S$R``(#!`8'
M"`D*"PP-#@\0$1,4%187&!H;'!T>'R`A(B,D)28G*"DJ*RPM``$"`P0%"`D+
M#`T/$!$2$Q05&!H<'1X?("$C)"4G*"DK+"TN+S`Q,S0U``$"`P0%!@<*"PT.
M#Q$2$Q05%A<:&QP>'R`A(B,D)28G*"DJ*RPM+B\P``$"`P0%!@<("0H+#`T.
M$1(4%188&1H;'!T>(2,E)B<H*2HM+C`Q,C4V``$"`P8*"PP-#@\2$Q46%QD:
M&QP='A\B)B<H*2HK+2XO,#$R,S0U-C<X``$"`P0%!@<)"@L,#0X/$!$2$Q05
M%A<8&1H;'!T>'R`A(B,D)28G*"DJ``$#!`4'"0H+#`T0%!46%Q@9'!T?("$C
M)"4F)R@I+"XP,3(S-#4W.#D[``$"`P0%!@<("0H+#`T/$!$2$Q05%Q@9&QP=
M'A\@(2(C)"4F)R@I*BLL``$"`P0'"`H+#`X/$!$2$Q07&1L<'1X@(B,D)B<H
M*2HK+"TN+S`Q,C,T``$"`P0%!@<)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A
M(B,E)B<I*BLL``$"`P0%!@<("0L-#@\0$1(4%187&!D:&QP='A\@(2(C)"4F
M)R@I*BLL``$$!0<("0L,#0X/$!$4%A@9&AL<'1\@(2(C)"4F)R@I*BLL+2XO
M,#$S``$"`P0%!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A)"4G*"DK+"TN
M``$"!08'"0H+#`T.$!$2%!46&!D:&QP='B`A(B,E)B<H*2HM+C`Q-#8W``$"
M!0<("0H+#`T.$!$2%!46&!D:&QP='B$B(R0E)B<H*2HM+C`Q,C0U``$"`P0'
M"0L,#0X/$!06%Q@:'!T>'R`C)R@I*RPO,#(S-#8W.#DZ.SP_``$"`P0%"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK``$"`P0%!@<("0H+
M#`T.#Q`1%!47&!D;'!T>'R`A)"@I*BLL+3`Q,S0U``$"`P0%!@D+#0X/$!$2
M%!46&!D:'!T>'R`A(B4F*2HK+"TN,#$R,S0U``(#!`4&!P@)"PT.#Q`1$A,4
M%Q@:&QP>'R`A(B,D)RDK+"TN+S`R,S0U``$"`P0%!@<("0H+#`T.#Q$2$Q05
M%A<8&1H;'!T>'R`A(B,D)28G*"DJ``$"`P0%!@<)"@L-#@\0$1(3%!46%Q@9
M&AL<'1X?("$B(R4F)RDJ*RTN``$"`P0%!PD*"PP-#@\0$Q06%QH<'1X?(",E
M)R@I*BLL+B\P,3(S-#4V``$"`P0%!@<("0H,#0X/$!$2$Q05%A<8&1H;'!T>
M'R`A(B,D)28G*"DJ``$"!`4&"`D*#`T.#Q`1$A05%Q@9&AL<'1X@(2(D)28H
M*2HK+"TN,#$S``$"`P0%!P@)"PP-#Q`1$A,4%1@:&QP='A\@(2(C)"4F)R@I
M*BLL+2XO``$"`P0%!@<("0H+#`T0$1,4%1<8&1H;'!T@(B0E)B<H*2PM+S`Q
M,S0U``(#!@@*"PP-#@\2$Q46%QD:&QP='A\B)B<H*2HK+2XO,#$R,S0U-C<X
M``$"`P0%!@<)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ``$#
M!`4'"0H+#`T0$A05%A<8&1P='R`A(R0E)B<H*2PN,#$R,S0U.#D[``$#!`4&
M!P@)#!`1$A,4%1<8&1L<'1\@(2(C)"4F*"DJ*RPM+B\P,30U``$"!`4&!PD*
M#0\1$A,5%AD:'!T>("$B(R0E)B<H*2LM+B\P,3(U-C@Y``$"`P0%!@<("0H+
M#0\0$1(3%!<8&AL<'A\@(2(C)"4G*2LL+2XO,#(S``(#!`8'"`D*"PP-#Q$2
M$Q05%A<8&QP>'R`B(R0E)R@J*RTO,#$R,S0V``$#!`4'"`D*"PP-#Q`1$A05
M%A<8&1P='R`A(R0E)B<H*2HK+"TN,#$R``$"!08("0H,#0X/$!$2%1<9&AL<
M'1XA(B0E)B@I*BLL+2XP,3,U-C<X``$$!0<,#0X/$!$4%A@9&AP='R`A(R0E
M)R@I*BLL+3`Q,C0U-C<X.3P]``$"!`4&!P@)"@T/$1(3%!46````````````
M`*7(V,@0R3[)<<FER=[)',I'RGO*J,K=R@O+.LMMRYG+Q<OSRR7,9\R4S,_,
M_LPTS6'-DLW&S?7-+,Y=SIK.S,X"SSO/;<^>S\S/_\\NT&30E=#,T`71,M%N
MT9O1T-']T2K27M*-TL72^](^TVK3H=/7TPW4.-1GU)[4R=3^U"[59-6=U<K5
M!M8]UG?6J];BUA773M>-U_W_``````````!&HD>B1**QH5BBTZ%0H=&ATJ&^
MH[RCO:._H[NC1*-%HT:C1Z-(HTFC2J-+HTRC3:-.HT^C4*-1HU*C4Z-4HU6C
M5J-7HUBC6:-:HUNC7*-=HUZC7Z-@HV&C8J-CHV2C9:-FHV>C:*-IHVJC:Z-L
MHVVC;J-OHW"C<:-RHW.CL\>QQ[+'M,>UQ[;'M\>XQ[G'NL>[Q[S'O<>^Q[_'
MP,?!Q\+'P\?$Q\7'QL?'Q\C'R<?*Q\O'S,?-Q\_'T,?1Q]+'T\?4Q]7'UL?7
MQ]C'V<?:Q]O'W,?=Q]['W\?@Q^''XL?CQ^3'Y<?FQ^?'Z,?.QU:A6*&EH::A
MIZ&HH46A3*%+H:RAJZ&PH<*A2J+!H4NBN:*ZHKNBO**]HKZBOZ+`HL&BPJ+V
MH?2A]Z'UH?BA^:'[H?JAU*';H>BAYZ']H?RAY*'EH>RA[:'OH>ZAXZ'<H=JA
MW:'8H=FAYJ'IH>G'ZL?KQ^S'[<?NQ^_'\,?QQ_+'\\?TQ_7']L?WQ_C'^<?Z
MQ_O'_,=WHGBB>J)[HGRB?:)UHG2B<Z)RHG&BI**EHJ>BIJ)^HJ&BHZ*BHJRB
MK:*NHF*B8Z)DHF6B9J)GHFBB::)PHF^B;J)MHFRB:Z)JHG:B>:*]H;RAMJ&U
MH;^AOJ&[H;JALZ&WH;2AJ**IHJNBJJ*YH;BA\Z'PH?*A\:%`H4*A0Z&RH:3&
M<:%RH6VA;J%UH7:A>:%ZH6FA:J%%HF6A9J&IH:JAPZ+$HL6BQJ+'HLBBR:+*
MHLNBI<:FQJ?&J,:IQJK&J\:LQJW&KL:OQK#&L<:RQK/&M,:UQK;&M\:XQKG&
MNL:[QKS&O<:^QK_&P,;!QL+&P\;$QL7&QL;'QLC&R<;*QLO&S,;-QL[&S\;0
MQM'&TL;3QM3&U<;6QM?&V,;9QMK&V\;<QMW&WL;?QN#&X<;BQN/&Y,;EQN;&
MY\;HQNG&ZL;KQNS&[<;NQN_&\,;QQO+&\\;TQO7&]L;WQJ+&H\;XQOG&^L;[
MQOS&_<;^QD#'0<="QT/'1,=%QT;'1\=(QTG'2L=+QTS'3<=.QT_'4,=1QU+'
M4\=4QU7'5L=7QUC'6<=:QUO'7,==QU['7\=@QV''8L=CQV3'9<=FQV?':,=I
MQVK':\=LQVW';L=OQW#'<<=RQW/'=,=UQW;'=\=XQWG'>L=[QWS'?<=^QZ''
MHL>CQZ3'I<>FQZ?'J,>IQZK'J\>LQZW'KL>OQ[#'H<9THW6C=J-WHWBC>:-Z
MHWNC?*-]HWZCH:.BHZ.CI*.EHZ:CIZ.HHZFCJJ.KHZRCK:.NHZ^CL*.QH[*C
MLZ.TH[6CMJ.WH[BCN:.ZH\"A5:)6HE"B4:)2HE2B5Z)3HNNAZJ%/HD"D0J1#
MI$7)5J14I%>D5:1&R:.D3\E-R:*DH:1"I4&E0*5#I?ZDX*7AI<.H6*2DI%#)
MI:1CR>JFL<M9I*:D1*5DR4#)1*1;I$?)7*2GI$6E1Z5&I>*EXZ7$J+RM0:1!
MR46D7J1=I.2EQ:BNL$O4P[:QW++<1J2II,:H1Z1(R5^DJJ2LI%')K:2KI.6E
MQZC(J$6K8*2NI.:EZ*7GI>NFR:C*J$:K1ZN]K;/<UO9(I+"DKZ12R;&DMZ2R
MI+.D5,E3R;6DMJ2TI$JE2Z5,I4VE2:50I6K)9LEIR5&E8:5HR4ZE3Z5(I67)
M9\GUI;#)\J7VI;K)KLGSI;+)]*7WI>FEL<GXI;7)N<FVR;/)ZJ7LI?FE[J6K
MR?&E[Z7PI;O)N,FOR>VEK,GKI;3)M\FMR6;*0J?TIF?*\:9$I_FF^*9;RORF
M]Z9@RFC*9,KZIOVF[J9'IUW*O<OLID.G[:;UIO:F8LI>RONF\Z9:RN^F9<I%
MITBG\J9`IT:G\*9CRD&G:<I<ROZF7\IARMBHO\O+R]"HS,O+J-6HSJBYR]:H
MN,N\R\/+P<O>J-FHL\NUR]NHSZBVR\++R<O4J+O+M,O3J+?+UZBZR]*HS:C<
MJ,3+W:C(R\;+RLO:J+[+LLO`R]&HQ<O,J,?+5JM*J^#-Z,U)JU&K7:ONS>S-
MY\U+J^W-X\U9JU"K6*O>S>K-X<U4J^+-W<U;JTZK5ZM-J]_-Y,WKS56K4JOF
MS5JKZ<WES4^K7*M3JTRK2*OOS=>MP:W1K=:MT-#/T-30U=#$K<VMVJW.K<G0
MQZW*T-RMTZV^K;^MW="_L,RMRZW+T,^M6]3&K=;0U:W4K<JMSM#7T,C0R:W8
MT-*MS-#`K<.MPJW9T-"MQ:W9K=NMT]#8K=O0S=#<T-'0VM#2T,BM8]17U+.P
M7-1BU+*P5=2VL%G44M2TL%;4N;"^L&?44=2ZL&;4M;!8U+&P4]1/U%W44-1.
MU%K48-1AU+>P6]A>U$W47]3!L&34P+!,U%349=2\L+NPN+"]L*^PL+#(LU[8
M5]C%LU_85=A8V,2S6=C'LUW84]A2V,FSRK/&L\NS4=A<V%K85-C#LU;8RK;$
MMK?<S;:]W,#<QK;'MKK<Q;;#W,NVQ-R_W,RVM-S)MK7<OMR\W+C<R+:VW,ZV
MN]S"W+G<P=RVN;.YM+GYX/'@LKFON?+@L;GUX/?@_N#]X/C@KKGPX*RY\^"W
MN?;@^N"PN:VY_.#[X+6Y].#XN^SDZ>3YN_>[\.3MY.;D]KOZN^?D];O]N^KD
MZ^3[N_R[\>3NY._DJK[XZ*>^]>BIOJN^]NBHOO?H].AVP+WL=\"[[+SLNNRY
M[+[L=<"X[[GOZ.2W[WC`7\/K\>SQU\38Q,'UP/5LQ6O%T/=)I&&DN:2XI%.E
M4J7\I?NE_:7ZI4JG2:=+I^"HWZCAJ%ZK6:+>T%JBPK!<HENB8-A=HKBY7J)*
MI+JD_J7BJ$NDO:2[I+RD0*9,I^2HXZCEJ-VMK+Y.R52E5:5!IFK*8*M?J^#0
MW]##L+ZD5<G-RV&KX*W>K=^MK;Y6I4*FO,E-ITZG:\K.R^:HS\OBT./0XZWD
MT.'0Y*WBK>&MY=!HU&'8Q=Q`X?Z[KK[YZ$RD6J3$L,VSN;E"R;^D6:57I5BE
MYZA-I$ZD8J3`I,&DPJ2^R5JE:\E&IK_)1*9%IKW)1Z9#IFS*[*IMRF[*4*=/
MIU.G4:=2I^VH[*C4R]'+TLO0R^ZHZJCIJ.NHZ*COJ&.K\,W3RVBK\<UDJV>K
M9JMEJV*KZ-#GK>O0Y:WGT.BMYJWIK>G0ZM#FT.S0T;/%L&G4:]1JU&S4QK#.
ML\^ST+/0ML?<QMS(W,G<T;;/MD'A0N&[N;JY6N-`O$&\0KQ$O/+D\^1#O*^^
ML+[M\</UPO71]T^D7*5;I4BFP,E5IU:G5*=7IV_*<,KQJ-7+\*CRS6RK\\UK
MJVFK:JOMT,>P;M3*L&W4Y;')L,BPU+/3L]*STK;5MM:VU+;3MD/A1.'UY$6\
M].2QOK_L><#N\57$8Z3#I%;)Q*3%I%VE7J5)IG'*ULO7RVVK[M#,L,NP8]AB
MV%"DQJ1?I<VP0\ELR6"EPLE+IDJFP<E8I^JM;]37MD7AO+GZZ/WSQZ38R_3-
MT+#.L,^P4:1DI,VBRJ3)I,BD8Z5BI6W)P\GUJ/*H]*CSJ&ZKU;-2I,ND9:5D
MI7+*]JA7R6>E9J5,IDVF<\I9IUJG]ZCXJ/FH;ZOUS>NM1,G,I,3)=,IURMG+
MVLOWS?;-^<WXS7"K<-3MK>_0[*UDV-:S9=A&X;VY1KSO\5C):*71L%.D9:3.
MI,VDSZ3[J/JH_*AQJ^ZM^^A/PF:D:J5YI72E;Z5NI76E<Z5LI7JE;:5II7BE
M=Z5VI6NE<J5QI7NE<*53IEFF5:9;IL7)6*9.IE&F5*90IE>F6J9/IE*F5J9<
MIG[*>\IGIWS*6Z==IW6G<*>ERGW*7Z=AIZ3*:*=XRG2G=J=<IVVG=LISIV2G
M;J=OIW?*;*=JIVNG<:>AREZG<J>CRF:G8Z=ZRF*GILIEIVFG8*>BRGG*Z\OJ
MRT^I[<OOR^3+Y\ONRU"IX<OER^G+2<Y+J4W._:CFR_ZH3*E%J4&IXLM$J4FI
M4JGCR]S+0ZG=R]_+1JE(J=O+X,M1J4VIZ,M3J4JIWLM'J4*I0*GLRTZI2,[[
MS4O._<UXJZBK=*NGJWVKI*MRJ_S-0\ZCJT_.I:MYJT7.0LYWJ_K-IJM*SGRK
M3,ZIJW.K?JM[JT#.H:M&SD?.>JNBJW:K=:O^S43.3LY$T?NM\=#VT/2M0*[T
MT.^M^:W^K?O0^JW]K?[0]:WUT$+10]'WK4'1\ZU#KOC0\:U&T?G0_=#VK4*N
M^M#\K4#11]&AU$711*[PK?S0\]#XK?+0]]#PT$&N=]3DL*?4XK#?L'S4V["B
MU.:P=M1[U'K4\JWAL*74J-1SU.BSJ=3GL-FPUK!^U-.PIM3:L*K4=-2DU-VP
M==1XU'W4WK#<L.BPX[#7L-*QV+!YU.6PX+"CU-6PU+!QU'+4:MC7L]JS==CN
MLWC8V+-QV-ZSY+.]M>*S;MCOL]NSX[-VV-?<>]AOV&;8<]AMV.&S>=C=L_&S
MZK/?L]RSY[-ZV&S8<MATV&C8=]C9LV?8X+/PL^RS:=CFL^VSZ;/ELW#8Z[/5
MW-'<X-S*W-/<Y;;FMMZVW-SHML_<SMS,W-[<W+;8W,W<W[;6W-JVTMS9W-O<
MW]SCMLO<W;;0W-BVY+;:W."VX;;GMMNV7Z+9MM3<XK;=W,VYR+E5X5'A2^'"
MN;ZY5.&_N4[A4.%3X<2YR[G%N4GAQKG'N4SAS+E*X4_AP[E(X<FYP;G`N4WA
M4N'*N4?A3;Q'Y43E1[Q3O%2\2KQ"Y4R\^>12O$;E2;Q(Y4B\0^5%Y4N\0>7Z
MY/?D:]C]Y/;D_.3[Y/CD3[Q.O%"\_N2ROD#E1>G]Z+Z^0NFVOKJ^0>FYOK6^
MN+ZSOKV^0^G^Z+R^_.B[OD3I0.E1O+^^1NFWOK2^QNS(['O`R>S'[,7LQ.Q]
MP,/L?L#![,+L>L"AP'S`P.Q0PKSONN^_[[WON^^^[V##\O'S\5;$]/'P\?7Q
M\?%1PO[S0?19Q$#T6,17Q%K$Q?7&]=K$V<3;Q,3UV/;7]FW%;\5NQ=GVR,6F
M^/'%I?CN^$G)?:5\I5^F7J;'R5VFQLEYIZG*J,IWIWJGI\IXI_#+\<M4J:JK
M2-%)T46N1JZLU.FPZ["KU.JP?-CRL^FVZK;AW,^YSKE)Y4CI1^EK^6>D6<EN
MR6_)8J9FILG)9*9CILC)9:9AIF"FRLFFIZ.G?:>JRJO*H:>MRGNGKLJLRGZG
MHJ>EIZ2G?*>OREFI_LM;J5JI0,Q8J5>I]<OTR_++]\OVR_/+_,O]R_K+^,M6
MJ?O+7*E!S/G+JZM5J:RK5,Y:SK*K6,Y>SE7.6<Y;SEW.5\Y6SE'.4LZMJZ^K
MKJM3SES.L:M0SE/14M%7T4[14=%0T5316-%'KDJN3]%5T4FN2M&PJ[K45M%-
MT4BN3-&QU.RP\+#!U*_4O=3QL+_4Q=3)U,#4M-2\U,K4R-2^U+G4LM2FV+#4
M];"WU/:P\K"MU,/4M=2SU,;4\[#,U.VP[["[U+;42Z[NL+C4Q]3+U,+4Q-2N
MU*'8JMBIV/JSHMC[L_FSI-CVLZC8H]BEV'W8]+.RV+'8KMCSL_>S^+-+T:O8
M];/TL*W8?MBPV*_8L]COW*S8I]CGW/2V][;RMN;<ZMSEW.RV]K;BW/"VZ=SN
MMNVV[-SOMN[<Z]SKMO6V\-SDW.W<X]SQMO.VZ-SQW%WAT+ECX=6Y7^%FX5?A
MU[G1N5SA5;Q;X63ATKG6N5KA8.%EX5;AU+E>X6+A:.%8X6'AT[EGX5GA6;Q+
MY5>\5KQ-Y5+E3N51Y5R\I;Y;O$KE4.5:O$_E3.58O$WI3^E*Z<&^3.G`OD[I
MP[Y0Z<*^2>E+Z:7`S.RDP,WLH\#+[*+`RNQ3PE+"]O'X\??Q8<-BPV/#0O1;
MQ-/WTO?RQ6BDT*2GIU_._+/]L_+<V+EIX5/E6LFPRD+,8,Y9T4RN^?'<Q&FD
M?J5PR6>F:*9=J?>PVKG;N=FY:J31I-.DTJ1;R=2DH:5QR:*E::9JILO)J*>Q
MRF&I0\Q?J6"I7JE:T;:KM:NWJ[2K8<YBJ;.K3:Y.KD^NS=3^L[38^+#XMMVY
MW+EJX5V\Q+[`[]KVU/=KI*.EI*71R6RF;Z;/R<W);J;0R=+)S,EQIG"F;:9K
MIL[)LZ>PI[;*N<JXRJJGLJ>OI[7*L\JNIZFGK*>TRKO*M\JMI[&GM*>RRKK*
MJZ=GJ6^I3\Q(S'"I4\Q$S$O,9JE%S&2I3,Q0S&.I4<Q*S$W,<JEIJ53,4LQN
MJ6RI2<QKJ4?,1LQJJ6BI<:EMJ66I3LRYJ\"K;\ZXJV?.8\YSSF+.NZMLSKZK
MP:N\JW#.OZM6KG;.9,YFSFW.<<YUSG+.:\YNSFC.PZMJSFG.=,ZZJV7.PJN]
MJURN8M%;KF#14*Y5KE_17-%AT5&N6]%4KE*N8]%3KE>N6*Y:KEFN7=%>T631
MU-3YL,+8T]3FU$"QY-3^L/JP[=3=U.#40['JU.+4^[!$L>?4Y=36U.O4W]3:
MU-#4[-3<U,_40K'AU.[4WM32U-?4SM1!L=O4V-3\L-'4Z=3]L-G4U=3HU$"T
MN]BXV,G8O=C*V$*TQMC#V,38Q]C+V./4S=A'W4.TSMBVV,#8Q=A!M$2TS-C/
MV+K8M]BYV+[8O-A%M,C8O]C!V+78^MSXW$*W0+=#W?G<1-U`W??<1MWVW/W<
M_K;]MORV^]Q!W?FV0;?TW/[<\]S\W/JV0MWUW/NV1=UNX>*YX;GCN7KA<.%V
MX6OA>>%XX7SA=>'>N73AY+EMX=^Y>^'@N6_A<N%WX7'A;.%SX57E8;Q8Y5?E
M6N5<Y5^\5N54Y5WE6^59Y5_E7N5CO%Z\8+QBO&#E5^E6Z57I6.E1Z5+I6NE3
MZ<6^7.E;Z53IT>RHP,_LU.S3[%GII\#2[,[LUNS5[*;`T.S&OE3"P>_Z\?OQ
M_/%<Q%W$0_3(]<?UV_;<]M7WI_ALI&VD;J35I*6ET\ERIG.FMZ>XI[:GM:=S
MJ57,=:ETJ5;,Q*M=KF71\-1%L4>T[]1&M.6Y?>''OJG`U^Q>Q'#%<LFFI7/)
M=J9TIG6F=Z:ZI[FGO,J[I[W*5\Q8S':I>*EZJ7>I>ZEYJ<BKQ:O'J\FKQJMF
MT7?.:-%GT6.N7ZY@KF*N9*YAKF:N9:Y*L?+4\=1)L4BQ1[%+L4:QU=C2V$FT
MT=C6V$NTU-A(M$JTT]A(W4G=2MWFN>ZY?N'HN>RYH>'MN>FYZKGGN>NY9KS0
MV&>\9;QDO%WIR+[8[-GL9,-?Q&^D>*;*JVG19ZY.L4VQ3+%,M$VTU]CON<F^
M<*1<R=:D=,G4R7FF?*E+W7&DUZ35R;[*O\J\I]C83K1,W:K`<J2HI-BD=<FG
MI<"GOZ>]I[ZG6<Q^J:&I6LQ]J<ZK>,[-J\NKS*MJKFBN:]%IKFK17J[SU%"Q
M4;%/L?"YHN%HO&F\8>6KP,+OP^_=Q*CX2\G9I'.D=\EVR7JFU\G8R=;)V<G'
MRL+*Q,K&RL/*Q*?`RL'*P:?"I\7*R,K#I\G*:,QBS%W,HZEES&/,7,QIS&S,
M9\Q@S*6I9LRFJ6',9,Q;S%_,:\RGJ:BI7LQJS**II*FKSJ3.JLZCSJ7.?<Y[
MSJS.J<YYSM"KI\ZHSJ;.?,YZSL^KHLY^SJ'.K<YOKFZN;-%KKF[1<*YOT7.N
M<:YPT:[.<M%MKFRN;=%QT7*N4[%2L?74^=3[U%2Q_M18L4'56K%6L5ZQ6['W
MU%6Q]M3TU$/5^-17L4+57+']U/S47;'ZU%FQ1-5`U>?8[MCCV%&TW]COV-G8
M[-CJV.38[=CFV-[8\-C<V.G8VMCQV%*TZ]A/W=W83[3AV%"TX-CEV.+8Z-A3
MW5;=3MU0W57=5-U#M]O84MU$MTW=4=VIX;#AI^&NX:7AK>&QX:3AJ.&CX?&Y
MIN'RN:SAJ^&JX:_A9>5GY6N\:.5CY6+E;.5JY6J\;>5DY6GE:^5FY6'I9NE@
MZ67I7NEHZ63I:>ECZ5_I9^EJZ6+IVNROP*W`K,"NP,3O<O']\43T1?1@Q,GU
MWL3*]=[V<L5QQ=WVR<76]W2D>Z;:R<K*M:A?L76DJJ6II:BEQ:=TKE?==J1W
MI'BDVJ31JZ_.4[1YI%W)JZ6LI7C)?*;+RL:GS,JNJ6[,K*FKJ6W,J:EOS*JI
MK:G2J]2KL\ZPSK'.LLZTSM.K=-%ST7:N=:YBL4;58;%CL6"Q5;1%U5:T\]A7
MM/+85+1:W5S=1;=;W5G=6-VTX?>Y];GVN;+AL^'SN7'E;^5MO'#E;KQLO/2Y
M;>EKZ6SI;N7<[+#`V^S%[\;O;NG^\7JDK:5^IMO)?::OJ4:WVZ2NI=6K6+1Y
MR7K)W,G(I]#*SLK)I\W*S\K1RL>GLZFTJ;&IL*FXSK*IUJNWSKG.MLZZSM>K
M>:YUT7?1=ZYXT7BN=M&USD?52M5+U4C59[%FL62Q9;%)U6BQ6K1;M%RT7=U?
MW6'=2+='MUFT8-U>W;CAMN&\X?BYO>&ZX?FYM^&UX;OA<+QSY;GA<KQTY7&\
M=+QUY6^\<[QSZ7'I<.ERZ6_I9L-&]$?TR_7?]E7&M:G*I]BK>Z3<I*^EW<G+
MI]+*N\[9J_JY?*2AIDFW?:3=I-ZDL:6PI=[)HJ;3RLRG<<QRS'/,MJFWJ7#,
MN*G:J[S.>M%ZKGG1:;%,U6JQ3=5=M&+=O^&^X?NY=;QVY<J^=.FQP'/%V/=T
MS+W.:['TV$JW5<+.I\VGVZM[T6VQ0[-NL6RQ7K3`X?RY=KQ,R=_)U<K/I]3*
MT*>\J7?,=LR[J;FINJEUS-VKOL[@J]RKXJO>J]^KX:M]KGRN>ZY/U6^Q<K%P
ML4[5=;%QL5#5=+%SL?;8]=AAM%^T8+3WV$NW9-U,MV/==^5XO,'A=[S]N=[L
M=>FRP-WL0/)(]$GTWZ2RI7O)TJ?4I^+)V,K7RM;*X<G@R:2FTZ?1IZ.FO:EX
MS+ZIW<K?RM[*><S:RMBGUJ?9RMO*X<K5I]S*Y<K`J>+*UZ?@RN/*OZG!J>3*
MK\RBS'[,KLRIS.>KPJFJS*W,XZNLS,.IR*G&J:/,?,RES,VIL,SDJZ;,Y:O)
MJ:C,S<[FJWO,RJGHJ\NIQZG,J:?,>LRKS,2I?<RDS*',Q:F_SL#.RLZAT<O.
M[JO.SL3.[:O&SL?.R<[IJZ.NQ<[!SJ2NS\Y^KGW1R,Y\T</.S,[LJZ&N\JNB
MKM#.?M'KJZ:N\:OPJ^^KI:[1SJ>NZJO"SG:QI-&FT:C1J*ZNKE/5K-&CT7BQ
M4=6MKJNNKM%2U:71K*ZIT:^NJ]&JKJK1K=&GT:FN>;&BT7>Q>K%5U5[59+1\
ML:.Q9;1@U:JQ^=A6U:*QI;%^L5358M5EU4G98]7]V*&QJ+&LL5W5^-AAU7NQ
M^MADU?S86=5BM%?56-6GL::Q6]6KL5_5I+%<U:FQ9K1CM/O86M5]L6NT;[1`
MV5&W;;1$V7&T9=U&V5.W:;1LM$?92-E.V7.T5+=*V4_90]E>MU6W<K1!V5#9
M7;=PM$ZW3=ETM$79_MAJM$+92]E-MU*W9[1,V5"W:+1<M\/A<-UHW<+A;-UN
MW6O=6[=JW5^WTN%:MT"Z<=W$X5BW:=UMW?ZY3[=FW6?=0;I7MUFW5K=OW<CA
MR>'.X7V\U>%'ND:ZT.%\O,7A1;K4X4.Z1+K1X:KE>KQNM-/AH[S+X7N\HKS&
MX<KAQ^'-X4BZ>;Q"NGKES^&AO*2\S.%^O'GE?N7.OGCEH^FIY:B\IKS,OJ;E
MHN6LO'CIJKRAY7;II>6HY7WEJ[REO'?IS;ZGY:>\J;RDY:V\H^5\Y7OER[ZK
MY7KIX.S0OJ+I?NGA[-&^H>E\Z;3`W^QYZ7OIM<#3OK/`TKZWP'WIS[[/[\?O
MY^S([^/L5L+E[.3LML#B[.;LT._,[\[OR>_*[\WOR^]GPVK#:<-HPV'$2O1B
MQ$'RW\3,]>#$=,7*Q=GWVO?;][KYX*1\R;.EIJ:GIJ6FJ*;:I]FGL<S/J<ZI
MK]&ML:ZQ=;1RW6"W8;=TW7;===W7X=;A2;K8X:SEKKS4OKC`5\*YP.&DYLJR
MS-&IT*G2J?.KTL[3SK#1L*ZOL7:T4=GBI'ZDXZ1]R;>EMJ6TI;6EJZ;IR>O)
MJJ;CR>3)ZLGFR>C)J:;ER>S)Y\GAI^JGZ*?PRNW*]<KFI_;*WZ?SRN6G[\KN
MRN.G],KDI].IWJ?QRN?*VZ?NI^S*\LK@I^*GZ,KIRNK*[:?GI^RGZ\KKI]VG
MW*?II^&IOLRWS-RI[ZFSS+K,O,R_S.JIN\RTS.BIN,S`S-FIO<SCJ>*IMLS7
MJ=BIUJGNJ>:IX*G4J;G,WZG5J>>I\*G4SN2IM<S:J=VIWJGLJ>VIZZGEJ>FI
MVZGTJ]K.0:SXJ_JK0*SFSOVKL=&QKD.LU\[?SOZKWL[;SN/.Y<[WJ_NK0JRS
MKN#.^:M%K-G._*NRKO:KUL[=SM7.V,[<SK+11*SASN+.Y,[UJ\&NOM&_KL"N
MM-'$T;:N9M7&T<#1M]')T;K1O*Y]U;W1OJZUKLO1O]&XKKC1M=&VT;FNQ=',
MT;NNO-&[T<.NPJZTKKJNO:[(T<+1MZZST<K1P='#T<?19]6WL<NQRK&_L7G5
M==5RU:;5NK&RL7?5J+2VL:'5S+')L7O5:M7(L:/5:=6]L<&QHM5SU<*QO+%H
MU7BTI=5QU<>Q=-6DU<:Q4MFSL6_5N+'#L;ZQ>-5NU6S5?M6PL<2QM+%WM'S5
MM;&QL<"QN[&YL7#5Q;%MU7K5=M54V5/9:]5DV7JT:ME9V6?9=]U]M&O9;ME\
MM%S9;=ELV7ZT5=EYM*.TH;1IV5_9I;1PV6C9<=FMM*NT9MEEV6/97=FDM**T
MN=%6V;?=5]E[M*JT>=VFM*>T6-EOV7C=8-E;V:FT8=E>V:ZT<+=\W;'=MMVJ
MW6RWN]UIMWK=>]UBMVNWI-UNMV^WI=VRW;C=:K=DMZ/=?=VZW:C=J=U^W;3=
MJ]VUW:W=9;?9X6BW9K>YW;#=K-VAW5.ZK]UMMZ?=IMUGMV.W[N&SW:[=HMWI
MX=KAY>'LX5&ZK+3JX4RZ2[KQX=OAZ.'<X>?A3[KKX6+9\N'CX5*ZNN6OO/#A
M[^%4NJWEL+RNY=_AX.'=X>+AWN'SX4ZZL;Q0NE6ZX>'MX>;AL>5*NK2\JNFV
MY;7EM^6TY;6\N[RXO+F\K^6RY;SEP;R_O+/E6MFRO+GEL.7"O+CE3;JWO.3A
MNKR^O,"\O;R\O+:\N^6SO,.\V+[9OJGIXK[?OM:^W;ZKZ=N^U;[<OJCIN\#7
MOMZ^NL"GZ:;IX+[AOJ7II.F\P*[IVKZLZ;W`PL#J[.SLO\#M[.GLZ^S`P,/`
MZ.R^P,'`6<*MZ5C"7L+4[US"7<+7[]/O6L+1[VO#U>_6[]+O6\)"\D7R1O)$
M\D?R;,-#\D[T9,1-]$ST2_1CQ&7$S?7BQ.'$X?;@]N/VR\5UQ=WWXO;<]\W%
MS,7SQ:GX[_CDI'+9K^FLIO?*\:?OI_"GP<SQJ4:LY\[HSD>LSM'$KL6NS='3
ML<^QI]76L=6QSK'1L=2QT+%VV<VQK[2QM+*T==EXV;"T<]EWV739<;>\W5:Z
M].'COL2\O>7%O,:\O^6^Y<#EL>FPZ>_L[NS$P,7`2/+EI'G9M+2SM+W=V._C
MQ-[WYJ3&KMBQU[%ZV7O9<K?UX5>ZLNGGI+BE\JG"S.G.2*S9L7S9M;1SM\'E
MPN7P[%_"\/CHI,/,\ZE)K.K.QZ[2T=#1T='(KL_1V['<L:C5W;':L7W9?MF^
MW5FZ6+KQ[-GO2O))\D_T7LE*K.FDN:6NIJVFKZ:PIN[)[<GXRO*G^\KZROG*
M_,KTJ<G,Q<S.S/NI^:G*S,;,S<SXJ4"JR,S$S/ZIR\SWJ<S,^JG\J=#,S\S'
MS/:I]:G]J>_.]<Y0K$VL[,[QSE.L2ZSPSDZL4:SSSDRL^,Y/K%*L[<[RSO;.
M[L[KSO?.],[0KLFNS*[/KM71RJ[3T<ZNRZ[6T<VNK-7?L:O5K=7>L>.QU-&J
MU:[5X+&IU>*QX;&GV:+9MK2ZM+>TI=FHV;BTN;2^M,?=IMF\M*/9H=F]M*39
M>;>_W7:W=[=UM\3=P]W`W7NWPMV[M,;=P=UXMW2W>K?%W5RZ^.'WX?;A6KI;
MNL7ER.7(O,>\R>7$Y<J\QN7)O,/EQ^7ION:^N^FZZ;GIM.FUZ>>^Y+[HOK/I
MY;ZVZ;?IO.FXZ?+LQ\#<[\;`VN_;[V#";L-+\FW#4?12]&;$4/3DQ-_WSL6J
M^*OXZJ2QIK*F\Z?1S%2LT:[DL=*PO[3`M,RSJ=E\M_KA^>'KI+.FTLQ"JD&J
M^<[ZSM?1V-'2KM.NU*ZOU>:QPK3!M,C=>M_[X;WI8<)GQ.RDO*6]I;NEOJ6Z
MI;:F]LFUIK>F\<GPR?/)\LGUR;2F[\GTR?W*_:?^RD/+_*='RT++1<OUI_:G
M]Z?XIT"H0<OZIT&H0,M&R_FG1,O[I_2G_J=7JM3,0ZI-JDZJ1JI8JDBJW,Q3
MJM?,2:KFS.?,W\S8S%:JY,Q1JD^JY<SCS-O,T\S:S$JJ4*I$JM[,W<S5S%*J
MX<S6S%6JZ,Q%JDRJV<SBS%2J1ZI+JN#,6\]<K&FL5L],SV*L2L];K$7/9:Q2
MS_[.0<]$S_O.4<]ASV"L1L]8S_W.7\]@SV//6L]+SU//9JQ9K&&L;:Q6K%BL
M0\]JK&.L7<]`SVRL9ZQ)SVNL4,](SV2L7,]4SUZL8L]'SUJL6<]/SU^L5<]7
MK/S.:*SCKEVL3L]-ST+/7L]7SU6L[-'JKNW1X='?KNNNVM'CT>O1V='TT=6N
M\]'NT>_1W:[HKN71YM'PT>?1XM'<T=W1ZM'DT=:NVJ[RT=[1YJ[BKN6N[*[;
MKN>NZ='IKMBNUZ[;T=_1X*[QT>C1X-'DKN&NV:[<KL35M-6UU;G5R-7%U;[5
MO=7ML<'5T-6PU='5P]75U<G5[+''U>>Q_+'RL?:Q];&QU<[5U-7,U=/5P-6R
MU=+5PM7JL?>QR]7PL<K5L]7XL?JQS=7[L>FQNM7/U>^Q^;&\U<;5M]6[U?2Q
MMM7HL?&Q[K&_U=ZNP-GKL?.QP]G9V<[9UK31M+W9TK3-V<;9T]G.M*O9U=G$
MM+/9Q[3&M->TK=G/V=#9R;3%M+O9T+2VV='9S+3)V=;9L-FUV:_9R[3"V=[=
ML=G/M+K9TMG*M+?9M-G%V<VTP[39M,C9Q]FLV<BTU-F\V;[9R]G*V:K9T[35
MM++9N=G!V=2TN-G$V=?9S-G8V:[9\MVFM_#=V]W@W=G=[-W+W=+=ZMWTW=S=
MS]WBW>?=T]WDW=#=U]W8W:BWZ]WIW<S=[MWOW?'=K+>DM[C5U-WFW=7=H;>Q
MM^W=K[>KM\K=H[?-W;"WW=W)W:FWX=W1W:JWVMU^M]BTX]V_V<[=Z-VEM^7=
MHK??W:VWUMWSW:>WQMZNMTKB2.)>XD;B6.)]MU^Z0N)=XD?B5>)DNEVZ6^)`
MXEKB;[I1XF'B;;I)XEZZ2^)9XF>Z1.)KNF&Z3>)#XOSA5^)HNF#B_>%ENE/B
M9KI%XE#B3.).XF"Z7^)NND_B8N+^X53B8[ILNFJZ0>)6XFFZ8KI2XESBU>71
MY<WEX>7>Y<V\Y>74Y=B\V^70Y=KEU;SNY>OEW>7.Y>+EY.71O-CET^7*Y<Z\
MUKSGY=>\R^7MY>#EYN74O./EZN79O-.\W.7/Y>_ES.7HY="\UN77Y<^\S+S2
MY=*\R[SIY>SEV>7*Z<+IONGVONN^\+[LOLSIU^GJOL3IS>G?Y<[I\;[=Z?6^
M^+[`Z?2^V^G<Z=+IT>G)Z=/IVNG9Z>^^[;[+Z<CIQ>G8Z?>^UNGSOO*^T.F_
MZ<'IP^G5Z<_I[K[&Z=3IQ^G/P$7MR,#U[$'MRL!([?SL]^Q)[?/L_NS1P$3M
M2NW][,G`0.WT[-#`1^WY[,S`^^SX[-+`^NS+P,[`0^WV[$;M0NUCPN?O:,)I
MPF+"YN_C[^3O9L+>[^+O9<+?[V?"9,+=[^'OY>]1\D[R5_)6\E3R3_)RPU#R
M<</-P%/R<,-8\E+R3?+@[V_#3/)6]%7T5?)HQ%GT6O14]%CT4_31]5?TY\3E
MQ,_UTO7.]=#UYL3E]N;V=L7D]N+WS\7@]^'WK/A6QO/X\?CR^/3XN_GMI+BF
M6:KIS&3/]='WT?;1^-']L=?5^='6U=C5V=7:V=NTV]G=V=RTVK3<V?K=^-WW
MW?;=]=VRM_G=<+ICXF7B<;IDXMN\VKSPY=_IWNG@Z?F^2^W3P.CO:L)9\G?%
M[J2_I;FF0JA:JENJ;JSZT;.WT>;ZOFO"[Z2ZINO,7*KJS&7/;ZQFSW"L_-'N
MKNVNWM7<U=W5V]7:U=[9X=G>M-_9W;3@V?O=9N)GXFCB\^7RY=R\\>7TY>'I
MXNGCZ4SMU,!LPEKRZ,1?R7&L9\_OKOZQW[3BV;6WM+=IXFKBW;S>O.7IY.GI
M[^/W\*1@R<"E0ZA(RW*LMK?QI&C/<ZQIS]7`\J3LS&K/0M)!TO[1_=%#TD#2
M0+)!LN"TX]GDV>790=Y"WD#>_=W^W;>W:^+WY?;E]>7XY>?IYNG[ONCIUL!-
M[>KO6_+G]O.DPJ7!I5VJ8<E^R;NF]\E)RTK+7JKMS'2L:\]LS_"N]*Y$TO.N
M\:[RKM_50K+CM.&TXK3FV7*Z]*2AR<.EI,G&I:/)Q:7$I42HHLGXR?S)_LE`
MRL6FQJ;[R<&F^<G]R<*FO::^IL2F^LF\ID6HOZ;`IL.F6\M9RTS+4:A3RTRH
M3<M5RU++3ZA1RU:H6LM8J%JH2\M-J%S+5*A7J$7-1ZA>J%6H3LM*J%FH5LM(
MJ$FH0\U/RU"H6ZA=RU#+3JA3J.[,7*A7RU*H7:A&J%3+2ZA8RT3-:JIZJO7,
M<:I+S6*J9:I"S?/,]\QMJF^J^LQVJFBJ9JIGJG6J1\UPJOG,^\QNJG.J_,Q*
MS76L>:ICJDG-3<WXS$_-0,ULJO3,:ZI]JG*J\LQUSWBJ?*I!S4;-?JIWJFFJ
M7ZIDJO;,8*I.S?#,[\S]S/',>ZKUKG2J_LQAJJ:L3,U\SZ'/I,]WSZ?/JL^L
MSW3/=JQ[K$G2K:RESZW/>\]SSV32?JRBSWC/>L^EK'W/?:QPSZC/J\]ZK*BL
M;<^JK'BLKJRISV_/JZQ>TDC-?*QWK';/;L^LK*2LH\^IK*>L><^AK''/HJRC
MK'+/IL]YK'[/3-+]KD.O5=);TE?22M)-TD;21])*K_JN5M)?TD6O]JY`KT[2
M0J]/TEG21*]HTDC2_*[[KDBO1=)FTEK29])ATE/28M)<TF728]))KU32^:[X
MKD&O1Z]@TD:O4=)#LFG24-)+TOZN2Z_WKEC27=)ELN'5Y=52LE"R1[+CU>+5
M6[+HU56R^M5'UD2R]]7PU6>RX-7\U62R6+)CLDZR[-7^U?;53[))LD76_=5`
MUE&R6;)"UNK5^]7OU4367K)&LERR]-7RU?/54[+NU>W52++GU4;62K+QU6BR
M8K+FU5^R7;)FLOC58;)2TOG58+)!UD6R]=57LNG55K)4LDRR2[+GV4/6Z]7\
MV4VR0;5:LNZT]MG\M.K9Z[3GM$G:[;3QM.RT];1-VD3:\=GZM/2T_=GDM$K:
M0]KHM/?9][15VE;:Y;1(VOFT^]GMV>[9_;3RV?G9\]G[M$2U[]GHV>G9Z]GJ
MM/C9^+1"M?K94]I+VN:T4=KRM/"T5]KOM$':]-G^V4>U1=I"VO#90[5/VDS:
M5-KIM$#:1K5'VO.T]K1&VD6U]=GDU5#:3MI2VNS90+5AWF#>1MZ]MU_>2=Y*
MWL>W:-["MU[>0][(M[ZW4MY(WDO>8]ZXMVK>8M[!MU?>S+?+M\6W:=ZYMU7>
M3-Y9WF7>S;>[MU3>3=[$M\.W4-Y:WF3>1]Y1WKRW6][)M\"W3MZ_MT7>4]YG
MWOZTL+I6WFSB6-YFWL:W3]ZZM\JW\+Q$WEW>7-ZJXJVZ?>*DXJ*Z;N*ONG>Z
M;>*PXK&Z<>*CXG/BL^*OXG6ZH;I3YJZZ?;IOXJ[BH[JKXKCB=>)^XK;BK.)\
MNGSB=KITNJBZ>N)WXGCBLN*WXK7B>KJYXGZZI[IPXOKE>>)XNJRZJ;I[NJ7B
M=.*JNJ?BI+JFNG.ZJ>*AXG+BI;JQXK3B>^*HXGFZW[RFXOGEK>)VXD3F3N;B
MO$WF6>;DO$OF3^;OO$;FY[Q2YO#I\[SRO%3F0^9>YNV\X[Q7YEOF8.95YDGF
MYKSIO/&\[+Q,YJ+B2.9?YNB\Z[QAYN"\5N;[Y5SFW\!*YN&\1>;EO/SEJ[I!
MYEKF0N9`YNJ\6.;^Y5'F4.9=YD?F[KSSZ4F__KY`ZNOI0;_WZ4B_0[_UZ4_M
M^^E"ZOKIZ>GXZ43J1NK]OD7J1+]*OT>__NE&O_GI[>GRZ?WI1;]"O_R^0+_Q
MZ?WE[.GOZ4'J].GJZ4[M0^KNZ?SI4>WCP-?`V\!3[5GM5^W9P-K`X<!:[5+M
MW,!6[57M6^WBP-W`X,!4[>3`WL#EP-C`6.U0[??O<<+T[_;O;\+R[_/O[N_V
MZ>_O<,+K[VW"^.]NPNSO[>_Q[W/"<L+P[WC#7_)E\GG#7/)VPW/#9_)WPW3#
M7O)A\F+R8_)F\O7O7?)UPV3R:/)@\EWT:L1@]&O$:/1?]%ST7O1B]&7T9/1G
M]%OT:<1C]&;T:?1A]-/UU/78]=GUUO77]=7UZ<1XQ>OVZ/;I]NKV><7E]^3W
MK_CTQ:WXL/BN^/7X5\9EQJ/Y;/FB^=#YT?GUI,>F0<I>RU^H8JA?RV"H8:A8
MS5K-5<U2S53-I*JBJE;-HZI3S5#-H:I7S5'-I:I9S:_/L\^WK+;/KZRRK+2L
MMJRSK++/L<^QK+3/M<^NS[6LL*RPSW?2>-)YTE"O3*]NTG;2>])1KVS2<M)K
MTG72<=)-KT^O>M)JTFW2<])TTGS2<-).KVVR3M90UDS66-9*UE?6:;)(UEO:
M4M9LLE/65M9:UD_65-9JLFNR6=9-UDG66]91UE762]9(M4FU9=I/M5G:8MI8
MVDRU8-I>VE_:2K5CVES:6MI+M5W:8=I-M63:<-YWWGG>H=[:MVO>TK=ZWM>W
MHM[.MWW>;=Y^WFS>W+=XWL^WH][4MW'>V;=\WF_>=MYRWF[>T;?8M]:WT[?;
MM]"W==[5MTZU>]YSWG3>P>*TNKWBP^*_XK:ZON+"XKKBO.*UNL#BN^*WNK*Z
MQ.*SNF?F9.9PYFKF;.;TO&;F;N9MYFOF<>;WO&CF;^;UO&/F9>;VO&+F<N9I
MYDKJ4;]5ZE/J2[])ZDSJ3>I(ZE6_5K]'ZE;J4>I/OTR_4.I.ZE*_4NI-OTZ_
M3^I0OTOJ5.I3OU?J6.I4O^?`[L!<[6+M8.WJP.G`YL!>[>S`Z\#HP&'M7>U?
M[>W`=\+[[W3"=<+][W;"^N_Y[VSR_.]M\GK#:_)J\FGR>\-LQ&KT:_3<]=OU
MZL3:]>SV[?;F]['X]OB\^7G&QOGVI*:JIZJXK._`]Z2HJE*OW;?XI&ZRN+IB
MR;?/?=+%XO#`^:2IJKC/N<]FVE"UI-[>M\;B^+Q\P_JD9]K[I,FF0LK(IF6H
M9*ACJ&#+JJJKJEO-NL^]S[JLN\^YK+S/NZRBTJ'2?M)3KUW67M9OLES67]92
MM7"R4;5KVFK::-IIVFS:IMZEWJG>J-ZGWKFZR>+(XKJZQ^)SYG3F^;Q9ZEKJ
M<O)]PW'R</)N\F_RZ\1L].[V]_C\I*7)QZ6FR4/*1,IFRV++8<NLJF7+9ZAC
MRV:H9\MDRU_-OL]=S63-K:JPJF7-8<UBS5S-KZI>S:ZJ8\U@S<+/O:R^K,7/
MO\_$S\#/O*S#S\'/J-*ETJ?26*]7KU6OI-*ITE2O5J^FTF?6H]*JTF+69M9E
MUF[:>=IHUF/6;=ITLG.R8=9DUG6R<K)QLF#6:=9PVG?:5+5VVG/:5K5UVF_:
M<=ITVG+:5;5XVE.UW[>MWJS>JM[BM^&WKMZKWLKBN[K@M[#>K][-XLOB^KR\
MNLSB=N;[O'7F?N9]YGOF>N9WYGCF>>9\YJ'F7^I<ZEWJ5[];ZF'J8.I>ZF3M
M9>WQP/+`8^UYPO[O>,)^PZ'#;<1N]&WTW?7O]GK%Z/?G]^GWR*7&SUFO=K)J
MULFEI\G]I$7*;,MJRVO+:,MHJ&G+;<VSJFO-9\UJS6;-M:IIS;*JL:JTJFS-
M:,W"K,6LSL_-S\S/OZS5S\O/P:ROTM+/T,_$K,C/T\_*S]3/T<_)S\"LUL_'
MS\.LM-*KTK;2KM*YTKK2K-*XTK72L]*WTE^O7:^QTJW2L-*[TK+27J_/SUJO
M7*]XUFW6:]9LUG/6=-9PUGNR==9RUF_6>;)NUG>R>K)QUGG66Z]XLG?6=M9\
MLG[:H=I@M:?:J=JBVEJUIMJEVENU8;5BM:C:6+5]VGO:H]IZVE^U?-JDVJK:
M6;5>M5RU7;57M>FWM][HM[O>L=Z\WK+>L]Z]WKK>N-ZYWK7>M-Z^WN6WMM[J
MM^2WZ[?LM^>WYK?.XKZZO;K3XOR\O[K!NM3BX[?`NM#BTN+/XM'BJ^:JYJ?F
M0+UBZD&]IN;^O*CFI>:BYJGFH^:DYOV\:>UFZF7J9^IF[5J_8^I8OUR_6[]D
MZFCJ6;]M[?7`>L+VP//`:NUH[6OM;NWTP&SM9^U"\$7P=?)`\&_T1O"BPT3P
M>\)!\$/P1_!V\G3RH\-S\F[$[<3Q]NS$\_;P]O+VT,6R^,JE;LV\TKW2?;*_
MWEV_I,-[Q;/XRZ5OS6"BU\_8S[[2O])^LJ&RJ]K"WL'>P-[5XM;BU^+"NJWF
MK.9IZEZ_7[]R[6_M<.UQ[4GP2/!\PG?RWO7,I<:LHK+#WLVEP-*CLF.U9+7.
MI<^E1LIJJ&FHQZS9SZS:T*71I=*ETZ5KJ&RH;LMMR[:J<LUPS7'-VL_;S\NL
MR:S*K,BL8*]DKV.OP=)BKV&OPM*FLGO6>M:DLJ6R9K5EM:[:K=JGLNVWQ=[N
MM\3>V.*NYD*]:NIS[:;#I<-\Q=2E<\VHLMGBP[IORW#+=,VXJKFJMZK/K-"L
MS:S.K-S/W<_,K,/2:*]IKZNRR=)NKVRORM+%TFNO:J]EK\C2Q]+$TFVOQM)F
MKV>OK+*AUJ+6K;)\UG[6I-:CUGW6J;*JLK;::[5JM;#::+6SVFRUM-IMM;':
M9[5IM;7:LMJOVM+>Q][PM_.W\K?WM_:WT][1WLK>SM[-WO2WT-[,WM3>R][U
MM^^W\;?)WMOBQ[K?XL:ZW.+%NLC>S][>XLBZX.+=XMKBL>:UYK?FL^:RYK#F
M1;U#O4B]2;VTYD:]K^9'O<2ZMN9$O6SJ:^ISZFWJ<NIOZF"_<>IAOV*_<.IN
MZOC`=.WWP'?M=>UV[?G`3?"APD[P?<)/\'["3/!0\$KPI\-X\JC#;\1+\'#$
M[L3?]7[%]/9]Q>KW]<7VQ<SYT:S>SVZU;[75I<JF1\IQRVVHNJK2K-.LU*RF
MULO2;Z^NLJ76N-IQM;?:<+75WDJ]N^:XYKGFNN9X[5'P<?1P]/7VUJ5US7"O
M<K76WN'B2[UTZE+P<O37I;NJUZS?S]BLUJS5K,S2<:]RKW.OL+*GUJ^RN=JQ
MLG.UU][XM_FWR;K*NDR]9+]UZF._>>WZP%/P<_38I6ZH>,UWS;RJ=LV]JGG-
MY<_;K-JLY\_FS]^LWJS9K.'/XL_CS^"LX,_<K.3/W:S/TM/2T=+0TM32U=+6
MTL[2S=)UKW:OU]+2TK#6V-)WKW2OJM:IUJO6K-:NUJW6LM:ULK*RMK*HUK>R
ML=:TLJ_6L[*\VK[:NMJ[VK_:P=K"VKW:P-ITM=O>X-[8WMS>X=[=WOJW0[C]
MM]G>VM[.ND:X_K=$N/RWW]Y%N-[>0;C[MT*XXM[FXNCB0+CCXLRZZ>+-NN?B
MXN+EXNKBR[KDXDZ]O^:^YE&]3[V\YDV]O>90O7WJH>I^ZG;J>NIYZG?J9K]G
MOV6_>.I[ZGSJ:+]`P:/M_,![[?[`0<']P*+M?.W[P*'M>NU^[7WM5?"DPJ7"
MHL*CPE3P>_*IPWGR>O)T]'?T=?1V].#U[\3K][3X]\7X^/GX9L;9I>&LP]KC
MWMJE;ZB^JNC/Z<]XK\3:=;5'N$+!I.U\\GCTVZ6AS7K-?,U^S7W->\V_JN*L
M\L_MS^K/\<_DK.6L\,_OS^[/Z\_LS_//XZQ\KZ2OHZ_ATMO2V=*AK[G6>J_>
MTN+2Y-+@TMK2HJ_?TMW2>:_ETJ6OX])]K]S2?J][K[FRNM:SUK76M]:XUK;6
MNK*[UK36R-IVM=#:Q=K1VL;:Q]K/VL[:R]JXLG>UR=K,VGBUS=K*VN[>\MY.
MN/#B4;CPWNW>Z-[JWNO>Y-Y-N$RX2+CGWD^X4+CFWNG>\=Y*N$NX[][EWO+B
MT+KTXNS>]N+4NO?B\^+1NN_BT[KLXO'B]>+NXDFXZ^+2NNWB5+W!YEB]5KW/
MNLCFR>93O<?FRN95O5*]P^;`YL7FPN99O<3FQN97O6J_J.JBZJ;JK.JMZJGJ
MJNJGZJ3J;+]IOZ/JI>IKOZOJ1L&J[:7M1<%#P:SM1,&H[:GMINVM[5;P1\&G
M[:[MJ^U:\%?PIL);\%WP7/!8\%GPH_*JPW[RHO)]\J3RH?)Z]'WT>?1QQ'OT
M?/1^]'+$=,1SQ.'UX_7B]?;VM?CZ^-RE<LO`JJ/-P:K"JJ+-^,_WS^:LZ:SH
MK.>L],_VS_7/Z-*GK^S2Z]+JTN;2IJ^JKZVOKJ_GTNG2K*^KKZFOJ*_"UL#6
MO-:[LKW6O+*^UK_6P=:]LM7:U-K3VM+:]MY2N//>]=Y3N%2X]-Y!X_GB^N+7
MNM6ZUKI#XT+C_N+]XOSB^^)`X_CBR^;0YL[FS>;,YL_FKNIMOTC!L.U)P:_M
M7_!>\*?"I?*KPZ'TH<7W]K?XMOBHR>JLZZS#UE:XW:5RJ'&H<*BDS<2JPZKN
MK/K/_<_[S^RL[:SYS_S/M:_STO72]-*RK^_2L*^OK[.OL:^TK_+2[=+NTO'2
M\-+&UL?6Q=;$UKZR?;76VMC:VMI\M7JUU]I[M=G:>;5!W_?>^M[^WEJX_-[[
MWOC>^=Y8N$#?5[A<N%NX6;C]WDGC2.-$X]BZ1^-&X]FZ7KW2YE^]6[U=O5J]
M7+VOZG"_L>JPZD7C<K]QOVZ_;[^U[;/M2L&T[;;MLNVQ[6#PJL*HPJG"IO*G
M\JW#K,.C]*3THO3X]OGVWJ5(RG.HI<W&JL6JILU`T.^L_L_PK+:O^-+VTOS2
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MPFS!OO*_\K'TH\31IM*F_JS,JL^O4=#`M=.F0:U2T%/00*U"K=2F5-#1KV;3
MTZ_0K]*O0=?@LD#7_M9QWZ'CHKVNO^;JY>KG[>_UU:9SRZK-0ZU5T&C3U*]G
MT]6O0]?BLD+71-?ALD;;1]M%V\&U=+AUN$6[H^.BXT2[^^;\YN?J<,%OP6W!
M;L%QP7SPO\*^PL#RLO2EQ:3%UJ;[T7>XPK5VN$:[UZ:IR=BFV::KS7;+=\MW
MJ'3+=JAYJ'7+>ZAZJ'C+>*C1JL^JK<W.JM.JU:K2JK#-K,W6JM"J?*C4JJ_-
MKLW-JEO01ZU(K5W05]!:T&/08=!)K6?03*UDT%S06=!)VV+01*UET%;07]!&
MK4NM8-!/K4VM6-!*K5[03JU%K6;0VJ_CK]BOUJ]JT]ZOVZ]LT]VO:]-ITV[3
MXJ_@KTC;;]-MT]>OV:_<K]^OX:].U^2R1=='UTC74-=,UTK73==1U^6RZ;)&
MUT_7Y[+FLDO72=?CLNBRR+51VT_;RK5*VZ'?R;5.VTO;Q;7+M5#;Q[5-VT>[
MQK5,V\RUQ+7#M7??==][WW/?HM]XWW+?>[BCN'W?=M]^N'RX?M]YN'BX>=]]
MN,VU?-]TWWJXH;BBN$R[2+M-NZ;CI>.GXTJ[I.-+NZKCJ>.HXTF[0>=$YZB]
M0^>GO:.]I+VEO4#G_N:FO4+G_>;IZO/JL;^PO^WJ[^KJZN[JZ.KQZJ^_\.KL
MZO+JZ^ITP>CM[NUXP7K!=\%VP77!<\'I[>SM<L'M[7G!Z^WJ[<#"P<*A\'WP
M?O#"\L'ROL.T]*3$L_3P]47WIL5#^43YV,7:IM>J4MM.NWO![^W;IN6OY*]3
MV_3JW*90K53;5=M6VT^[LK_=IMBJ:-#FKW#3ZK)7VZ2X4+NSOWS!PL*U]-ZF
MV:KGKU+7SK51NZOC1>??IL^UH]]2N^"FL<UIT%&M<M/JK^BOZ:_KKW'35]=4
MUU;7Z[+MLNRR4]?NLE776-M9VUK;IM^GWZ7?J-^EN*3?4[M*YT;G2>=+YTCG
M1^?UZO;J]^JTO[6_\>WP[?+MH_"B\,3RQ?+#\J7$MO2W]$;W[_>[^.&F?:A]
MP>*F6-=;VT'&2LI+RDW*XZ9.RDS*HLNCRWO+H<NAJ**H?,MZRWG+?<M^J'[+
M:M"VS=RJM<VWS=NJO,W?JK+-P,W&S>:JP\WCJKG-O\W!S;3-XJK=JKK-Y*KG
MJN&JVJJ^S;C-Q<WIJN6JX*J]S>RON\W>JNBJL\W"S<3-8JU<K62M8:UQT'30
M7:UKT%:M8*UCK66MHM!WT%6MH=!9K5>M4JUOT'[0<]!VT*709JU]T%ZM>-"D
MT'70>=!\T&W0H]![T&S0<-!?K5JM4ZU8K52M9ZUNT*736ZUZT$'.J-/ZKW;3
MH]-]T[+3JM-^TZG3>--\T[73_:^MTZ33[:^STW33K-/\K_>O<]/UK_2O^:^K
MT_&O^*]RT%S;IM-ZT_NO>].AT_ZO==.OTZ[3MM/SK_"OM-.PTZ?3HM/VK_*O
M=]/NK['3[Z]YTU[78-=EUWG7_++RLEW7_;+^LFC7;]=UUV+7:==`LW?7<M?Z
MLOBR;M=JUUS7[[)AUUG7][+YLF;78]?TLG/7\;)DUWK7;-=KU_"R^[+SLEK7
M7]=PUW;70;-;UV?7;=?VLGC7<==TU_6R;-M@V]>U?=NGVZK;U;5HVZ/;:=MW
MV^*U<]O?M73;7=NDV^BUH=MUVZS;<-O(WZ_;YK5NVWK;Z;74M7+;K=MKVV3;
M;]MCVV';T+6EVVK;J-NIV]BUW;79M>&U?MO:M7;;9MO2M5[;HMNKVV7;X+6P
MVW';;=O1M>6U?-OGM7C;W+76M=ZUT[7DM7G;9]M[VV+;IMNNVU_;Q]_=WU6X
MS-_*W[7?J;C%W]G?P=^QN-C?O]_CM<_?P-_6W["XJ+BJW[+?R]_#W]S?QM^V
MN-??K;C)W]'?MM_0W^'?L=_2W]_?J]_;M;G?N-^ON+S?OM_-W][?LKBSN+#?
MJ[BTW]K?M+BLN*ZXM;C@W]/?SM^[W[K?JKBLWZ>XQ-^MW\+?M]_;WZ:XL]^O
MW]7?KM]@N]/CPN.LX\KC6+N[X\7C6[N^XUF[K^/-XZ[CP>.MX[_CR./&X[KC
MM>.SX[3CQ^/2X[SC6KNWX\OC7;NVX[#CP.-ANU6[7KNXX[+C5[O4WU:[P^-4
MNV.[7+O$X[GCL>/,X[WC8KO0XU^[S^/)X\[CT>-SYW3G9^=FYV+GM+VLO7;G
M=>>IWU_G8^==YW#G8>=WYUKG6.=DYV[G:>>VO4_G;>>WO;W?6^=2YU7G>^=<
MYU/G4>=.Y["]9>>OO;.]8.=HYZF]>.=\YZN]5^=KYV_G5.=YY[*]L;U,Y[6]
M<N=6YVKG4.=>YUGGK;VNO6SG?>=ZYW'G3>>JO4GK0.M#Z[N_1>OYZD'K1^NX
MO[R_MK_[ZDSK1NO\ZE7K3^OXZD;N_NJWOTKK5.N_OU'K_>I$ZTCK0NM6ZU/K
M4.NYO[J_OK_ZZE?KO;]-ZTOK3NM3[D#N1>Y2[D3N^^U![J+!].U-[D_N\^VA
MP5'N2>ZHP5#N0NZJP?GM4NM*[D?N]>U5[J3!I<'W[4CN5.Y+[OWMI\&CP4SN
M_NU6[OCM0^Y.[OKM_.W+PO;MJ<'$PG[!IL'(PK/PJ?"D\*KPM/"X\+?PRL+)
MPJOPN?"N\*;PJ/"G\*WPLO"E\*SPL?#'PJ_PQ<*P\,/"QL+5\K7PPL/-\M'R
MR?+,\M3RP,/9\M+RRO+:\M/RP\/$P]?RR_*_P\'#QO+.\LCRV/+6\L?RS_*^
M],7#T/*GQ*G$IL3#]+OTN?2]]+KTO_3!]*K$K,3`]*W$J\3"]*C$],3Q]??U
M]L2\]/;U_?7T]?OU^O6X]/7UMO#^]?/U^/7\]?+U2O?UQ/GU]/=+]TGW1_=(
M]TSWV<7R]_#W]??S]_;WVL7Q][SX1?E&^4?YQ_F]^4_*ZJIHK;C3M]-`L$*S
M?-=[U^JUN+BWN+FXU.-^YUCK6NM9ZZO!5^ZZ\*7YY*;)S<K-R,W'S>NJJ="G
MT*;0::UKK6JMJ-#$T\'3O]-!L,+31K"\T\O3S=.]TT.PSM/)T[O3P-/*T\;3
MP]-(L,S3OM/'T[G31[!$L,73R-.ZTT6P0K!,LZ772[.HUZO72+-&LW[7J=>G
MUZ37K->MUZ_7L-=]UT6SHM>AUZ[71[.CUTFS1+.FUTVS2K.JU_&UO]NTV^ZU
MY]^]V[';[+6VV^^UNMNXV_*UZ[6RV[7;\+6SV[[;O-NWV[G;N]OMM>C?[M_D
MW^K?NKCFW\"XO[B^N.W?P;C"N./?\-_#N+VXO+CLW\2XXM_EW^_?Z]_TX^GC
MN[AJN]WC\N/>XV6[V^/DX]SC9[O6X_'C:+ONX^_CU^-MN^;CX./GX]KC\^/K
MX^7CU>-IN^SC;+OPX^KC9KOHX^+C9+O9X^'C[>/?X^/CP;WIW[+GN^>QYZWG
MJN?"O:CG:[NAY\"]I^>_O:SGJ>>YY[3GKN>SY[N]J^>^YZ+GH^>ZY[R]O^>^
MO<#GL.?8X[;GK^>XY[7GIN>YO;WGNKVDY[V]9.NWY[SG8>NXO<"_:^MGZV7K
M8.MOZ\2_7.MHZVGK7^M>ZVSK8NM=ZV/K;NM;ZVWK:NO"O\&_P[]FZ\OP6>ZQ
MP5WN6NYA[F?N7.YP[J[!:NY?[FON9NYM[E[NL\&RP6#N;NY8[FSNK,%D[F/N
M:.Y;[K#!M,%B[FGNM<%E[JW!K\''\,7PS/#)\,WPOO#&\-'P;^["\,_"I>>]
M\,KPQ/#!\+SPN_#0\,#PO_#-PLCPS,+.PL/PS_#>\M_RR</<\L;#Y/+*P^;R
MV_+.\.CRW?+'P^/RY?+@\N?RXO+A\LC#Q?3&],CTKL2OQ,GTQ_3$]$+V1?9!
M]OK$0_;YQ/C$]\1$]E'W3_=.]T#V4/=&]DWW^??7]_?WV\7X]_KWO_CZQ;[X
MO?C[Q5K&;OFG^:;YJ/GEIJK0S]/0T\#;1_;`^.:F;*VKT+'73K/"V\';\[7%
MN,'GP[W$O<6__,7GIJS0[:JNT*W0;:W1T]C32;#6T]33V]/2T]/32K!.L-S3
M3;#:T]?3U=-+L$RPV=-0L[+75;/"UU2SQ->XUU*SP]>SUU.SO]>[U[W7M]>^
MUT^SNM>YU[77P->\U[37MM=1L\'7]K7-V\G;R]O&V\7;P]O*V\S;R-O'V_2U
M];7/V\VX\M_XW_/?]-_YW\^XQ[C.N/'?Q-O*N,BX]]_VW\FXR[CUW\:XS+CV
MXW2[0N1!Y/OC=KM`Y/?C^.-NNW"[_>/UXW*[<;OYX_[C_.-SN_KCSMMON\+G
MR>?&O<WGRKW%Y\/GS.?%O<OGQ[W(O<3GR;W*Y\;GQ^?(YW6[<.M\Z\J_=^MY
MZ\B_<>MUZWCKQK_)OWOK<^MTZWKK<NMVZ\>_<NYQ[K?!=^ZYP;;!<^ZZP73N
M=>YX[KC!UO#9\-/PU?#4\-?PV/!V[M+PS</L\N_R\?+J\NOR[O+P\L[#S,/+
MP^WRZ?+*]+#$R_1)]OO$2_;\Q$CV2O:HQ5+WI\7]]_SW^_=(^4GY2_E*^5#*
MZ*9NK<77][7ZW]#"\O*CJ%>S5K/0V_BUTMO1V_O?T+A#Y$;D1>1$Y,[GT.?/
MY\R_R[^[P7GN>^YZ[M'"]/+S\LSTL<3]Q%3W4_=;QJ2HK]!OK<C7QM?'U]3;
MU=M#X-/;_-]!X$#@0N#1N/[?_=]$X$GD1^1(Y-/GT>?2YWWK?.Y][M+"]?+-
M]++$3/95]ZG%_O=,^:6H<:URK;#0L=!PK52P4K!1L%BP4+!9L-W35K!3L%>P
M5;!/L%^S6;/,UUZS8+-:LUNSRM=8L\O77;/)UURS1+9&MMC;1;;YM?VUY+A)
MX-K;_K7=V][;0[;@V^+;X]O7V];;Y-M"MN';W]M`MONU1[;;V]S;V=M!MORU
M^K5(X-^XVKC5N.6XUKC2N.&XWKC@N->XW+C3N-2X4.!-X$7@2N#BN%'@X[C9
MN$?@3^!+X$[@3.#=N$;@V+A,Y'B[>[M.Y*6[3>1]N\^]3^2DNTODIKMYN]NX
M?+MZNWZ[HKMWNZ>[H[NANTKDUKW2O=F]UN?:O>+GV^?+O>/GW>?5O=[GU+WA
MY\Z]W^?5Y\V]JNO3O="]V+W4Y]CGS+W7Y]GGVN?7O=SGX.?DY]N]TK^EZZOK
MJ.M^ZZSKH>NGZ\V_T[^MZ\^_V;_4OZ_KJ>O0OZ+KVK^CZZ3KV[_8O]&]SK^P
MZ]R_U;^NZ]&_UK_7O\/!I.ZM[JKNK.[`P:7NJ^Z\P:?NQ,&C[JCNK^ZFZZGN
MHNZ]P:'NOL&P[K_!KN["P7[NP<&F[MSPZO#E\.?PV_#3PMKPUL+5PNGPX?#>
M\.3PW?#?\.CPYO#4PNWPZ_#B\.SPX_#Y\L_#0?-/]M;#X/#W\M+#^/+]\M3#
MU</V\D#S0O/Z\OSR_O+[\D/ST</7P]/#T,/0]+?$SO32]-/TM<34]-'TS_2X
MQ+3$U?2VQ+/$_L1`Q4[V3?90]E'V0<56]UOWJL58]U?W6O=9]T/XW,5"^$#X
M0?C^Q?W%P?C"^$#&3?E.^6?&;<:I^<CYIJC-U\[74N!0Y.7GQL'%P>[P1/-$
M^*>HWM-:L&&S5.!3X-R]YN?=O;'NU\)VQJBHR\W?TV*SS]?0U^7;2+;FN%;@
M5>!7X%'D4N2HN]V_WKW>O[7NLNZT[K/NQ\'O\$;S1?.DRURP6[#@T]'7Y]OF
MVTFV6>!:X%C@Z+CGN*J[J;OGY[/KL>NRZ]^_M^ZV[O+P\?#P\$?SJOFIJ'.M
M=*U=L%ZPXM/AT]+7:+-FLV.S9[-ELV2S2K;JV^VX3+91MNS;4[92ME6VZ]OH
MVT^V2[9-MNG;5+90MDZV[[CNN.RX\+CJN.NXZ;A;X%3DK+NMNZN[4^15Y.KG
M[.?GO>WGX+WIY]^]Z;WEO>:]XKWHY^&][N?KY^B]X[WDO;7KM^NVZ[CKX+^T
MZ\O!N.[(P<S!RL')P?/P]O#U\/3PV,)(\TGSV,-*\]G#NL2YQ%+V0L53]ESW
MJ\6LQ47X0L:JJ&JS:;-<X%W@KKNYZ^J]NNNY[JNHLM!VK76MX]-?L.33U=?4
MU]/7[MM8MNW;5[;OVU:V7^!BX&#@8>!EX%[@9N!CX&3@L+M6Y*^[\N?PY^N]
M[^?QY^R]N^N\Z\W!3/-.\TOS3?/6]%3V;_FLJ'>MY=/GT^;3V-=LL];7:[/9
MU]K7U]?[VV"V\]OYVUNV7K;RVUFV]MMLX%VV\=OWV_3;^MOPV_C;7+9?MO7;
M6K;RN&C@\;AOX&[@^+CYN'#@\[AMX/>X<N!IX&O@]+AGX&K@<>#UN'/@]KBQ
MNUOD8>19Y&+D6.1=Y&/D8.1?Y%[D5^1<Y%KD\;WNO?OG0>A#Z$#H^.?ZYT7H
M0NC\YT;H^>=$Z.^]];WSO?/G]+WPO?3G]N?UY_WG_N?RO>V]]^?&Z^*_O>OC
MO^:_PNN_Z^6_P^O$Z[[KQ^O`Z\7KY+_AO\'KO^[0P<[!T<'/P;[NN^ZZ[KWN
MO.Y%\=["^_#Z\-G"0?%`\??P0_'\\-W"^?!"\?CPVL+<POWPV\+^\$3Q4O/>
MPT_S4_/;PU'SX,/=PU#SW\-4\]K#O,2^Q-GTO<37]-S#V/2[Q$/%1<56]D3%
M5?9A]ZW%8/>NQ5[W7?=B]V/W1OA?]\;XP_C$^,7X7,91^5#Y3_EP^;[YJ_EN
MQJVH8+#ZN/:]R.O?PE7SK/FNJ.ZJ>:UXK6.PZ--AL.G38K#?U]O7;;/>U]W7
MW-=NL^#7X==#W$'<1=Q&W$S<2-Q*W$+<_-M)W$O<1-Q'W/W;8K9`W/[;8;9C
MMOVX=>!WX';@>^#[N'C@=.!YX'K@_+C^N'S@9^1FY&3D9>2SN[6[LKNTNTWH
M3NA)Z$KH^+W]O?>]_KWYO4OH3.A(Z$"^^[WZO?R]1^C*Z^B_S.OJO\_KR^O)
MZ\[KZ;_-Z^>_T\'6P<'NU,'`[M+!U<%&\4?Q2/'@PDGQX<+BPUCS6?-7\U;S
M6O/AP]WTV_3<]-[TVO3?]%CV6?97]D;%9/>OQ67W2/A'^*^H9+9`N;:[[+_K
MO^/#?,1'Q;"H9+!!N5OSILNQJ+2HLZBRJ*7+S<W/S>^J\:K,S<[-\*K1S=#-
MTLVVT+30?*VST*.M?JU[K:2M?:VBK:&MM=!ZK6JPZ]/QTV>P;K!IL.[3\--L
ML.K3[=-HL&6P[--KL._3;;!FL./7YM=PLWJS=K/DUWZS=[-\LW*S;[-QLWVS
MY==ULWBS=+-YL^?7>[-SL^+73=QEMD_<9[9IMD[<9K9JMFBV1[FCX$^Y?N!0
MN46YH>!*N:+@0[E"N4VY3+E+N4FY3KE]X$2Y1KE(N;B[N[N_N[F[OKN\N[>[
MO;NZNU+H0[Y!OE/H1+Y"OE'H4.CPOT_H[K_MO]#K1;[OO]'K\K_2Z_&_V,'#
M[M?!W,':P=O!X\+9P<+NT^OBPN3"Y,/EP^#TWL7=Q;:H5<IOL%+*4\I1RE3*
MJLNGRZS+J,NWJ+JHJ<NYJ*O+N*C5S=?-]*K3S=;-U,WRJO6J\ZJXT+S0N="G
MK:BMN]"]T+_0I:V^T*:M[M>ZT/+3^]/YT_33]=/ZT_S3<;#WT_/3<+!RL/;3
M_=/XTZ&S\=?IU^_7\->BL^C7ZM>WT.S7[=?KUVRV5MS4ZU?<5-RCLVZV4]Q9
MW%C<:[9<W%+<6]Q0W%K<5=QMMJK@I>"KX*;@I."GX%&YJ>"HX%*YP;O`NV[D
M<>1IY&WDPKMLY&KD<.1KY&CD;^19Z$B^2O%6Z%?H5>A1W$>^6NA4Z$:^2;Y8
MZ-7K\[_6Z]?KQ.[=P4OQ3/%-\5WS7//B].'T6_9<]EKV9O>PQ;NHJJVIK76P
M=+!`U$'4_M-SL/77]M?RUZ2S\]?TUU_<8=Q=W&#<;[9>W'"V<]U5N52Y4[FL
MX*W@<^1UY,:[P[O%N\2[=.1RY&'H7NA?Z$V^8.A;Z%SH2KY+OEWH3+[;Z]SK
MV>O:Z_2_V.O([L7NQ^[@P<ONW\')[LSNRN[&[M[!3_%0\4[Q4O'EPN;"7_/G
MPU'Q7O/FP^7TYO2_Q.3TX_1=]DC%2?C(^,?X0\9=QLGX<?EOQKRH]JI6N<#$
MO:BKK:6S<;;GPO>JP=#`T$+4>+!VL'JP1-1YL'>P0]2HL_S7I[.ILT+8J[/^
MUT#8]]>JLT/8^=?ZU_C7IK-!V/O7_==MW&S<:MQBW''<9=QOW';<;MQYMG6V
M8]QIW'>V:-QXMGJV:]QRMG.V=]QUW'3<9MQRW':V=+9SW&3<9]QPW+KDM^"P
MX,/@S."SX&&YP.!7N5FY9;FQX%JY7+EFN5NY9+FYX*[@8KFXX%ZYRN!CN<C@
MO.#&X&"YK^#)X,3@R^!8N6>Y7;FUX+W@P>#%X%^YM."RX+[@N^"ZX+_@PN#'
MX'CDQ[NDY'KDS+O0NZWDM>2FY,B[JN2VX,F[L>2VY*[DL.2YY++D?N2IY-&[
MS;M\Y*ODR[NEY,J[L^2BY'GDSKNXY'ODK^2LY*?D=^1VY*'DM.3/N[?D?>2C
MY%*^6KY5OJ3HH>AGZ%"^3[Y6OF7H5+YQZ&/H9.A.OJ/H6+YTZ'GH<^CNZV_H
M=^AUZ&CH8NA]Z%>^?NAXZ&WH:^AFZ&[H>^AJZ'KHHNA3OG;H?.ARZ&SH4;ZH
MY'#H6;YIZ/3K][_SZ_#K1.S[OT'L^.M#[.GK]NO]O^'KW^M"[$#L_NOMZ^SK
MXNM`P.CK\NO]ZT/`1>SHP47`_K_FZ^_KWNO@Z_6_0L#ZO^?K]^OQZT'`W>OC
MP?GK_.O\O^OK1,#YO_B_]>O[Z_:_Y.OZZ^7KZNO2[M?NY<'GP=WNX<'L[N/N
MV.[9[N+N[L'A[M'NX.[4[NWN[<'KP=7NZ.[:[N?NZ>[0[N;!ZN[>[NK!V^[L
MP>3NY,'6[N7NW^[CZ^;NT^[IP>ONXL'.[F#Q6?'IPE3Q8_%;\=SN9?%5\>C"
M7_'JPO+"\,)A\?'"5_%8\5WQ8O'-[NO":O%G\6OQ7O%:\6CQ:O-<\>["[<+/
M[N_"9/%F\>S":?%3\5;Q<_-C\^O#<?-A\^S#;/-H\_'#<O-B\V7SZ<-T\VWS
M<//OP_3#\L-I\V3S[</NPV#SZL/HP_##;_/SPVOS=?/UPV?S;O/S]$+U]?3\
M]&;S^O3I]$#UP\3M]/[T]/3"Q$3U]O3[]/WTY_1!]?+T]_3K]._T0_7Y].CT
M[/3N]/CTP<3Q].KT\/1A]F;V3\5H]DG%9/9J]D[%2L5+Q6#V9_9-Q67V3,5?
M]F/V8O9>]FGVL<5M]W#W;/=N]V_W:?=J]V?W:_=H][+%L\5+^$WX3/A.^.#%
M2OC?Q>'%R_C,^$3&ROA3^5+Y5/E?QE7Y7L96^7+Y=?ET^6C&<_ERQG#&<<9W
MQL#YP?F_^<GY^*I$V'C<I>AV\_FJK*U[L$781MBLLWVV>MQYW*.V?+9[W'ZV
MHK:AMGNV:+G0X,[@S^#-X-*[U;O7N]:[T[O4NZ?HINA;OJCHJ>A<ODWL2^SS
M[DGL2NQ&P$;L3NQ([$SL[^[Q[O+N\\'N[O+!\.[OP?#!\<%'[/7";O%L\6WQ
M\\+VPO3"=_-X\_;#1?5']4;UQ,10Q6WV;/9K]OJJJLE8RNFF5LI9RE?*KLO!
MJ,*HL,N_J*_+K<O`J+ZHV,W;S?VJVLW9S?RJ^ZI`J]S-_JK&T*ZMKZVPK<?0
MP]"MK<30Q=#"T*2PH;!%U**PI;!&U'ZP?+!]L*.PK;-)V+6S2-A+V+&S2MBK
MMJ^SLK.NL[.SM+.PLT?8I[9]W*/<HMRLMJBVJ;9\W'[<H=RDMJ:VJK:EMM/@
MT>#2X&JY:[G4X&FYV+O:N]F[N^2\Y*OHJNA'P$C`3^Q)P/;N].[U[O3!;_'W
MP_7!0:NFL$?43-BVLZVVI-RFW*^VKK:PMK&VI=QNN6^Y;;G;NVRYU>#<NZSH
M4.Q*P/;!</%T\?G"<?'ZPOC"=?'[PG/Q>?/WPOC#S?A"J[BSM[.RMJC<I]RS
MMMG@<[EPN=C@<KG6X'&YU^"]Y-V[K^A=OJWH7KY?OJ[H8+Y1[$[`2\!0P%/L
M3,!2[$_`3<#Y[OON]\'Z[OC!^.[W[G?Q=O'\PGCQ?O/ZPWWS>O/YPWOS?/-(
M]4GUQ<13Q6[V4<52Q6_VM,6UQ7'W1<;/^$?&SOC0^$;&5_FM^4.K=+F^Y+#H
M4<!2P$2K8;[[P[&M4\#BQ;*M3=BIW*O<JMS=X-K@=;EVN=O@W.#`Y,7DWKN_
MY,'DR.3#Y,?DQ.3"Y,;DW[NSZ+'H8[YBOK+H9+Y6[%7L5,!4[/SN_NY![T#O
M^<'][J'Q_<)]\:+Q_L)[\7[Q?/%Y\4##>O&A\Z/SHO-*]4OU</:WQ;;%3_A0
M^$C&T?AIQK.MM+;*Y,GDM>BTZ/K!0^]"[Z7QH_&F\:3Q_,.D\Z7SIO-Q]G+W
MTOBTK5?L1.^UK>"[6.Q!PZ?Q_<-,]4WU5,51^+:MN[.\LT[8M;:VMJS<M[9Z
MN7RYW^#@X-[@=[EXN7NY>;G+Y.&[XKN\Z&>^M^BVZ+OH9;Y;P+CHO>BZZ+GH
M9KY9P%KL5<!;[%GL6,!6P%K`5\!%[TKO1N])[_O!U.U([T?O1,-"PT7#0\.H
M\:GQJO%&PZKS0,2H\T'$I_.I\_[#4?5.]4_U4/5R]E;%5<5T]W/WN,7CQ4G&
M8,98^:[YK_FWK:W<X>#,Y,WDX[ODN[[H:+[\P:OQ1\.M\T+$K/.N\ZOS=?92
M]5/UQL1T]G/V=?>P^;BMN:VGL$C43]BXMKNVN;:NW+VVNK:\MGZYXN#CX,#H
M?;FAN:*YS^3.Y.6[YKO0Y+_HZ+MION>[7,#!Z&N^:K["Z,7HP^C$Z&R^8<!?
MP%[`7>Q@P%SL2^]>[%W`7^Q.[TSO3>]2[TO#4>]4[U/O4.]/[_W!KO&M\4K#
M2,-)PZSQL?-#Q+#SK_-$Q%CU5_55]53UR,3'Q%GU=O>YQ7?V5\5V]E;U=_?D
MQ6'&6?FQ^;JM4-A5[[NMTN31Y&#L5^]6[TS#LO.S\\G$LOFHL+^VOK;DX.;@
MI+GEX*.YI;GGX-3DUN35Y-CDZ;O7Y-/DV>3,Z,_HT>C'Z,OHR.ANOG&^<[[)
MZ,KH<K[-Z-#HSNATOG"^QNAMOF^^8\!F[&3L8^QI[&CL9^QB[&+`8>QE[&3`
M6N]>[UOO7>]<[UGO7^]B[V#O8>]`PO[!6.]C[[/QMO&X\;?QL?&U\;#QLO%-
MPZ_QM/'`\[7S1<1&Q+3SN?._\[?SOO.[\[KSO?.X\[;SO/-@]5[URL1=]6/U
M8?7+Q%SU6O5;]<W$7_7,Q&+U>/9^]GGV6\6A]EK%??9\]EG%>_98Q7KV??>A
M]W[W>_>[Q7CW?/>C]Z+W>?=Z][K%4OCGQ5/XY<7FQ=/X2L9V^6K&L_EKQK3Y
MM?G#^<+Y>L;-^:FPZ>#HX.J[Z[O:Y-+H;.QUOF7`:NQM[&;`9.]K[+GQ3L/!
M\V;U9/5E]:+V7,6D]^K%O,7HQ>G%U/ABQJJPNO%)U*:YV^3LN]SDU.C3Z&C`
M=KYWOM?HUNC5Z&[L<>QP[&_L9\!H[V;O9>]G[T_#O/&]\5##N_'#\\+SQ?-'
MQ,3S9_5I]6CUH_:F]J3VI?:E][W%5/A5^%;X2\9CQK;YJ[!XOFG`OO&F]\3Y
M2M1[QJRP<NR_\<;SI_:G]ZVPW>3>Y.V[[KO9Z'J^>;[8Z&GOP/'"\<'Q4\-2
MPU'#7L6H]EW%J?>H]TS&U?B]L^K@X>3?Y.#DXNC=Z-KHX>CCZ'R^X.C<Z-OH
MW^C>Z'N^?>QX[';LH>QW['/L>>QT['+O=>RB['SL:L![['KL?NQJ[VWO;.]T
M[V_O<^]Q[W#O;N]K[T/"0L)$PD'"=>_(\<OQR?'-\<[QQO%8P\?QQ?',\<3Q
MP_%7PU7#5,/*\<_SU?-*Q-#ST_/7\TO$TO/*\\GSUO/-\\OSU//,\TG$2,3'
M\\CST?/.\VSU;_56PVWU<_5Q]6OU=O5J]<_$<O5N]<[$=?5T]:OVJO:Q]JWV
ML/9@Q:[VK_:I]JSV7\6_Q;3WK_>S][;WLO>N]\'%L?>U]\#%K/=P];#WK?>J
M]ZOWOL5:^%SX7_A;^&#X6?A7^.O%7?CMQ>S%6/A>^-KX3<;;^-GXUOC8^-?X
M6OE<^5OY>?EX^7?Y>OESQG3&ROG.^;ZSK]SMX*>YZ^#LX.+DX^3QN^^[Y.3P
MN^CHZ^CEZ.SHY.CFZ.?HZNBAON_H[NA]ONGH[>A^OJSL;\"G[&O`I.RJ[*WL
M<,"I[*;LKNRE[*OL;,"C[&W`;L"H[*GO>N][[W[O?.]V[WGOI>]][T7"I^^D
M[T;"IN]W[Z+OH^^A[]+QU/'7\='Q6</9\=#QVO'6\=CQW/'5\=WQT_'/\5K#
MV_%;PTW$>._Q\^CS3\3D\U#$[?/G\]WS3L3J\^7SYO/8\]_S[O/K\^/S[_/>
M\]GS[//;\^GSX//P\]SS3,3:\^'SXO-]]7OUHO6N]:7U?/5X]:?U?O6C]7KU
MJO5W]:'UIO6H]:OU>?6O];#UJ?6M]:3UP?;$]F'%P_;(]L;V8L6]]K/VLO9D
MQ;_VP/:\]K3VN?:L];7V8\6[]KKVMO;"]K?VN_?%]L?VOO:X]KSWOO>X]\+%
MQ??#]\/%PO?!][KWM_>]]\;WN?>_]VGX;OAD^&?X[L5K^'+XP/=E^&_X<_AJ
M^&/X;?AL^''X</C$]VCX8OAF^$[&3\9A^.;XW?CE^.+XX_C<^-_XY_CA^.#X
MWOCD^%WY7OE@^5_Y8OEA^7SY>_FW^;CYQ?EXQGS&S_E]QK^ST,3)]E#&4<;`
ML^[@J+GPZ+#LL>RO[*OOJN]'PM_QK._>\?/S4<13Q/+S4L2Q];/ULO7*]F7%
M[\7H^&/YTOG!L^7DHKZS[++LK>]4Q-'$Q_?+^<*S\KNCOO3S=/C`MJ[O9,;!
MMJ2^2,)U^,*V\>ARP+3LM>QQP*_O3,)*PDO"2<+@\5S#M?6T];?UMO72Q,OV
MS?;,]F;%R/=V^'?X\,5D^7WY=<:PW+;LL._U\^_@L>_B\>'Q>/A2QF7Y?OFI
MN?+H\^BW[*JY7</C\<_V9\70]L[V>?CI^*NYM.^S[[+OY/'H\>?QYO'E\5[#
M]O.Y]=/$N/71]LOWRO?$Q<GW?/A[^'KX\[NX[$W"]_/X\\SW??CJ^&;YN?G4
M^?2[3L+I\?GSTO9^^*:^M>_J\?KS^_/\\[[UNO5HQ;WUO/74Q+OUUL35Q-3V
MT_9IQ6K%QL7-]\7%H_BD^*+XH?A4QNOX[/CM^%/&9_EJ^6GY:/G3^7/`9<._
M]=7VQ\7.]]7Y=,"V[\_WH?E*R?S=2J%7H5FA6Z%?H6"A8Z%DH6>A:*%KH6RA
M;Z%PH7.A=*%WH7BA>Z%\H<:AQZ'*H<NAR*')H5RA3:%/H5&A4J%3H52A?:%^
MH:&AHJ&CH:2AS*'-H<ZAWJ'?H>"AX:'BH4RB3:).HDFAK:%#HDBBKJ%=H5ZA
MKZ'/H4&AT*%$H4&BKZ*PHK&BLJ*SHK2BM:*VHK>BN*)'H4:AU:'7H=:A2*%)
MHL^BT*+1HM*BTZ+4HM6BUJ+7HMBBV:+:HMNBW*+=HMZBWZ+@HN&BXJ+CHN2B
MY:+FHN>BZ*)"HL2AZ:+JHNNB[*+MHNZB[Z+PHO&B\J+SHO2B]:+VHO>B^*+Y
MHOJB^Z+\HOVB_J)`HT&C0J-#HV&A5:%BH4ZA````````````````````````
M_30``/TT``#]-```_33[_PPU'_X8-?7^)35_#B\U```O-0``+S4``"\U```O
M-0``+S4``"\U```O-0``+S4``"\U>O\\-?__3#7__UPU_Y=I-?[_>#7_/X8U
M$`#[-``P]@&+_P("<\,+`D!H#P(/&Q<"K.D@`DSS*0(``BH"",`M`EQY-@(^
MRC\"=GE)`D@&30+?+UD"\/=D`CH#:@+_J'4"-^^!`C\CB@($L(X"6?V9`LKS
MHP+__[,"G]Z_`OG_S0+_J]H"]WWG`@#`Z0+LCO("O^[_`MO_#0,#T!(#^D4;
M`^'Z)0/^WS,#[[]!`ZL01P/K_U4#JOQ?`S_O;`/])'4#K7A^`W9_B@,,\)`#
M_^V>`_;/J@/Z++,#^??``VOKRP/]']<#OY7B`W=F[`._O_H#^SL&!+3^$02N
M>QP$XA$B!(&F*`2^03`$-10V!,-R/@1P?4<$D7%.!`,`4`1K)UD$RU=C!,]P
M;`0R1W,$[PU]!-I^B`1T_)($!OZ;!+2]I02?/[$$RHNY!$E^P@0`6,4$CR+,
M!.SKUP1<BMX$N]WJ!&#O\P3GMOX$#Z0%!9/R#@6[-QD%GE0A!4O0*`6OFS,%
M%,0X!=3W0P6P,$@%%`I,!0@O4@70B%<%?O]E!2\9;07:_WH%!_N$!?%_D`7K
M>YP%[\6G!1``J`7_F;0%__W#!==YS@5G!=4%Y__C!<O][P7_P_L%0$#]!?=O
M"@:.O10&^M\A!I<$)P;`]"X&_UL[!GOM1P;GT%`&?@17!N#X7P:?_VT&/K=X
M!OY]A08NB(L&_?^:!G^^IP;^@[$&Q/:Z!E?SQ0;]N-`&@-;6!GWOXP9G5^T&
MB$?S!GW_`0??PPP'__`8!ZDW(0?@?2H'_'`S!V\_/P>:[$@'LTQ0!X&&50>>
M/V`'7-UJ!PWW=`<92'D'H_Z$!P<`AP=6KY$'_SB<!PV8H@>X[ZT'/4"S!V"W
MNP?.V,0'-9#*![]RU0?_/^,']W_Q!Q%Z^`>[]P4(_ZL2"`#_&@B^;R8(/*DN
M"'+^.0COST8(&_%/"&O;6@@*]&$(YL-J"'[O=PB<FX`($/:'"$CPC0CT%I4(
MM?ZA"()1I@BQQZ\(NQ6X"(=NP0C?^\\(/^39",UCX@C_P>T(?G[Y".O]!@E?
M?1()>W<>"?[\*PD+EC()ZML]"2EB0PGH4TL)WS=7">_]90GU-F\)@;UW"1C<
M?@F]_(H)Y-*2"?__H@G7/ZX)X/^Y"6]_Q@GXJ]`)KIO:"=ENY`G[]?$)%?'Y
M":EY`@K[O0\*/%H7"J^M(@JZVRT*K!\V"OQQ0`IY@T@*]WQ4"E_#7@K_WVT*
M9P5T"IK_@`IGA(<*-!6-"HO?F`KS^:0*<S.M"KWWN@H:7L(*0+_*"C^@T@K_
M_^(*ZP'I"L#?\@K=S_X*`'4#"].K#0O#^!8+UNXA"_U#*PO_MSD+KUY$"R="
M2@NLFU,+AO9<"]<G9@N\]G$+A_=\"[<UA@O-JH\+=N&8"^=)H0N?XJL+7%2R
M"_*OO0L_*\<+V&'."SO\V0NXN^,+S__Q"WU[_0N5OP@,X!P.#/U]&PS_0R8,
M]E\R#/[_00SOTTT,SL15#+:-7@R\K6@,W&-Q#.L1>0Q9WX0,T".*#+2^E`S;
M\Z`,YQ^K#,?;M@QC_\(,Y/K,#"NRU`SW8]\,.^WJ#+JM]`P!_OP,_WX*#??_
M&0V\`A\-_S(J#3GO-0W\_T,-!8!&#?MW4PWUO%X-#0%B#??_<0W[_X`-.K^+
M#5<`D`W_WY\->^^L#7V]N`V(V\`-U,C'#?/_U0U\[>`-[EWK#?]6]PT-?@`.
M7ZP*#I;_%@Y_U2(.[C\N#D#!,@[Y;SX.Y_],#IMW5PYWCF$.OVYM#EWD=@[/
M;X(.'U^-#G_@EP[?_J4.V]>Q#OX!N0X`_\$.>_O.#M3_V@[?'^8.`/CK#O__
M^PZ/^P</>P`-#P"_%`]<?Q\/__\O#_,'.`^@ZT`/YSU+#[_W60_7^V8/O_]U
M#P-@>0_]_X@/[;^5#[OOH@]_`JH/0/ZR#_W=OP___<X/^>+8#PMHW@\?^^H/
MX_OV#_VO`Q"DGPP0[?<9$'UZ)!`/^"T0ONXY$-4/0A!=NTT0G_U:$-OR91#Y
M.W`0?_Y^$,SKB!!JAY`0^G.;$/R5I1#\G[$0GQ"X$/?ZQ1"WW=$0S;O<$'[X
MYQ#-[/$09O/[$#\\!1']_Q01/[`=$??I*1%^!C$1KI8Z$0;^0Q%VU4T1UU]9
M$=$_8Q'SHVT1!\]V$;=O@A'1GXP11'^5$5E[GQ'=TZH1.Z^U$;VIOQ'/?<L1
M.O_7$>#[X1'K]NT1`;3R$?__`A+Z>@T2O[<:$@#`'!+]#R<2?_\V$A__0Q+\
M_E`2_Y5<$@``7!+<M6828^]Q$CX_?!)_^XH2&P".$@#HDA+V^Y\2[YZK$M^X
MMA*?_\02/P#*$M![TQ+_]>$2V]_N$O\__!+P_0<3OP`.$R"$$1.]NQT3-]\I
M$][_-Q-M_T03\P].$TQ@4Q/[7E\3^_]N$_OZ>Q->_H<3&0*+$_1YE1/>^:$3
M]Z>M$_KKN1/K`<`3-/_+$]/KUA-S[^(3UZ_N$T#`\1.[<OL3_]P(%'_Q%!38
M+QT4[+@F%`O^,!2CW3H4"Q]"%!V/2Q3/1U44*[%=%-[_:Q3N?W@4<]J"%/\D
MC!3$RY047?>@%/++JA3][+84[;3`%/F_S13=3=<4W9GA%(W[[!1_N_D4>Z\%
M%?O=$A59R1H53_PE%;7Z,!7CKSL57VU&%?__5A5]/V(5`'AF%=O_=!7_MH$5
M_WZ/%:_[G!4O`J(5F_^O%<?ONQ6E_\<5___7%0<`VA4`Q]\5__?N%?'_^Q7]
M?PD6OP$1%@#<%A:\_2(6];\O%O__/Q9__TX6_SY;%BD`7A8`OF06__ER%G__
M@1;[;HT6?OV:%O_+IQ:>`ZX6`..S%MW[P!;_S,P6W_;9%O__Z19_$?(6`/CW
M%O;[!!?OYQ$7/-<;%^_^*1?OWS<7"\`\%[_M21??_E<7S?UC%_5[;Q?]0'<7
M__^'%U^WDQ??_Z(7,/FJ%]_[N!>7W,(7\_[/%_*_VQ??C^<7O]_U%W\7`!CF
M[0L8?P\6&%,U'AA\1"48?H<O&!+Z-QB[14`8X.U)&)YW5!@7@%D8V;]E&%5^
M;QB)WG@8;\&!&$<$AAC>>I$87?>=&/]7JA@%*:\8]X:Y&)7^Q!BSE\X8+_/9
M&/_/YQAUG_(8]W']&!?["!GN-!$9&>X:&<PW(QEA[RT9UI\X&4SO0AF/UDP9
MW?M9&7-[9!GO;7`9_M=]&3&D@QE_7H\9UY>:&5L/HQG8_Z\9@YVW&<Y[PAGL
M(LD9_]S6&3UVX!F'[^L9Y]_X&>W]!1K_3Q(:_*`:&G<[)1K\VS$:[3T\&MQ_
M2!JI;U(:</5;&OL_:!I`+&P:?_][&G^$A!I7[(X:M]Z:&ISFHQHO\JT:ZP^W
M&K75P1KKK\T:Y^W9&B^,X1KP_^T:?U/X&O#H`!N=N0H;_[47&V;_(QN/YRX;
M@=DU&Q"^/!M\G$4;P>--&]&<51LS)UT;O`QD&VW_<1NW_'T;M^^*&]^@DQO_
M_Z,;"[^M&WO^NAO_H\8;/S70&\P3UQO-E^$;-W;K&R?[]AO6SP$<;'X+'%#L
M$APQ[1L<?&<E'!S\+ASZ]CH<OU]''+H/4!POKEH<K:-C'/Y_<1SP_'L<=-Z%
M'.__E!P`\ID<O_NG'*+^L1RO/;P<_[S)')3VTARY7]T<K?/H'(\_\QQL\OP<
M'Z`#'>__$AV_`1H=*'<B'05P)QTU_S,=`]HZ'?G21!WZQT\=OS]<'1U<9!TZ
M_W`=,^QY':^WA1V<_I`=-E*7'9]ZHAWZOZ\=(N>W'?>?Q!W__-(=NR_='1VV
MYAT&[>X=_1WY'==]!1[?[Q,>(^L<'F;Q)1[9?C`>P`TU'CT]/QZ_WTT>1<E4
M'H.Z7![1?68>T)UN'H=[>!YSSX,>\Y^/'O7#F1X-WZ,>_L6N'K,,M1X"@[D>
M>>C"'L"NR1YSQ],>#V_='GW]ZAX_"?(>\?__'E<!!1_[8@\?_P$8'[3](Q_S
M.RX?$[`T'[)#.Q_37D4?,/]/'_\/6Q^?ZV<?[_YU'P/R?!_O/XD?B?N3'ZDW
MG!^9GJ4?^=ZQ'RRGN1\S-\(?]L'+'RZ!T1\^_MT?(%WC'_?R[Q^%U?<?UVD!
M(/__$2#__R$@!]LJ(&__."#_Q$,@?]E/(,[O6R`/OF4@>_%P(%[P>2#/]H4@
MM_^3(/=>GR"$[Z@@R]>S(-\.O2`(_\8@__S4(#_NX"#___`@_Q/[(/_7"2$/
MKQ,A_7\A(<>]+"'Z'S<A```W(0``-R$``#<A```W(0``-R$``#<A```W(0``
M-R$``#<A0.<^(3B]1R$S^5$AZW]>(>W^:R'H?W8A=GR`(?>SC"'O_YLAK_ZH
M(;?8LB%O_\`AO_O.(?OXVB'WV^<A4A?N(?GB^"'(A?XA1W4'(I"0"R+OXQ<B
M])XA(FT_+"(N[C8B-@4\(KSW2"+S?U4B>Z!=(C]_:B)G!7$B8.MY(KZZA"(!
M9HDBV/R3(C]8G"+WRJ<BWX>R(LV_OB*@_\@BS5O2(K_^X"+]MNPBI^_X(N]W
M!2.<WQ`CMS\<(W?X)R,GG3`C_+<\([7*12/OWU,C6OM>([;Q:",Y['$C'^]]
M([_[BR/[?YDC#0"<(_[:J"/[O;4C?T[`(_\SS"/`6M(C];_?(_Z?[".___LC
M7P`!)````23X_0TDRO\9)/UO)B3]SS,D`:`V)/_?123R^U$DO]]?)'__;B3:
M_GHD#PA_)`BZA23_OY0D_7J@)-?NK"3K^[DD^6?$)$3@R223_]4DE]_A)%>?
M["3W_OHDWP@")8#?"B7?_A@EQ?\D)?[W,B7[_T$E`VA&)?MG4B7Z:UTE_W]L
M)>)?=B7__X8E<_^3)=^'GB7[YZLE_>NX):?WQ"5^O]$EQ^_=)?,>YR6"W_`E
M_W;])7[?"B;)>1,F?=H>)K[O*R:;'C0FX'P\)OMW22:^AU,F^_]B)O\;;B;;
M_WPF7#^&)N!/CB;_?YTF#E^F)O]WM":_W<$F3_#*)O__VB;__^HF^`_S)KZC
M_2;?_0LG'/P4)_W_(R=]'RXGGOLZ)_^]2"?<WE,G;S]?)_NZ:R=_WWDG[_N'
M)QM]D2?L+IHGCJ^D)_?RL"</>[HG[L_&)Y8=SB?&=]@G!W[A)_7_[R>"V?8G
MWW\$*.9>#BC_QQLH[OXH*.]Y-"A6FCPHS_]**%_^5RA>WF(H;HEJ*.CY="A>
M]'XHQ.:&*`$`ARA\OI(H?SN>*-_=JRB=U;4H[^G!**PTR"A3WM(H<_7=*/=+
MZ"A/>_,H_YX`*?ZX"REN1Q0I^PT>*47_*2G]JS4I_OM#*=?I3BG_W5PI]^UI
M*?]_>"G]W84IZWZ1*>?/G2G_MZLIZ;VV*9'OP"EU7<HI?-?5*0``U2D``-4I
M``#5*0``U2D``-4I``#5*0``U2D``-4I``#5*8#ZW"GN_^HI\;3S*7:__RGO
M+PLJ=[86*K]W(RJ_GS`J_?\_*K^52BJN]E4J_W5B*CM_;BKUIWDJ^0J!*@``
M@2H``($J``"!*@``@2K0^XLJW2N5*C/VGRI_FJHJJ_VV*OS6P2KF^<PJZ[_9
M*M_?YRH?]/$J_:;\*O__#"O_2A<K>_,C*[=_,"OY_CTK_[9**UP=4BOV?U\K
M_^5L*WL?=RL$)'HK!;Z"*Y[YC2OCVY@K\M^D*^]OL2O__<`K>=;**_S+U2O]
MZ^(K_^_Q*Q\`]BL``/8K``#V*P"8^2M(X?\K%X`$+'1J#"S^`!,L?VT?+/']
M*RQ_N#8L\_Y#+!_@2RQV\54LENY?+#][:RR-ZW4L_?^$+/^MD2RSRYLL[X2D
M+'_AKRRJ3;<L\+_"+#^_SRP__MPL_^OJ+-?_^"S?_P<M?\\4+?O_(RWMA2PM
M/]<X+;P'0"W_KDTM#_Y8+:_]92V_=G$M[_I^+;LWB2W<?Y4MNJ.>+?^VJRWW
M5K8M^&"]+=_GRBUA_]4MWTS?+?NPZ2U%__0M[7T`+OH_#"[_'QDN_!@A+O__
M,2ZOXSPNT\=&+H/?4"Y7^UPN?>]I+O_O>"YX$W\NP/Z(+O=?E2Z[-)XNXUZH
M+@WWLB[V[[\N_M?,+K\`TRZ=]=XN]_?L+MY1]2[@_P`OR?X++W\#%"\!7QLO
M[[\I+_&?-"^G8#LO'>]&+__Q4R\/`%<O``!7+P``5R\``%<O``!7+P``5R\`
M`%<O``!7+P``5R\``%<O``!7+P``5R\``%<O``!7+P``5R^`/%PO3?MG+Q_9
M<2\Z>WLOX_Z'+^D_DB]_W)XO/P"D+P``I"\``*0O`%"F+Q_UL2\'OKHO'?S$
M+QOYSB\>O-<O_W'C+_EO[R^^6_HOEE<#,!N;###_?QLP_/\I,"Z',3#GKSTP
M]>M),$_S5##]WV(P)>=K,-P+<S!$77HP1U>#,-W]D#`_[9PPD'>D,']]L3#(
MBK<P^OK#,/GSSS`J(-,P2^_>,/_U[##/>?<PTZL!,:4+"#%Z]Q0QC_L@,;V.
M*C$?`"\Q```O,0``+S$`\S4Q3OU`,5<:2#$`B$HQK*Y3,51V6S&M%V0Q_\UQ
M,;+_?3$O](<QJEN0,?_;GC$"`)\Q``"?,0``GS'`<Z8QZOFQ,3\NNS&.^L4Q
M_[O3,;QVW3'3_^HQ_N[W,7)^`3*]?@TR]^<:,G_W*#+]SC0R]0\^,@``/C(`
M`#XR```^,@"I0C*;VTTRQZ15,G^17S+*^&@RSGYS,GI]?C+GQXDRO<N4,J[<
MGC)^_:LR=H^U,M.1O3+S?,@RY0'.,B],UC)W[>(R8*/H,ML'\3+X7OLR]QT&
M,X$A"C/@:Q(SG#`8,SH[(3/>^BTS4W\X,_7#0C/-84HSN@=2,P``4C,``%(S
M``!2,P``4C,``%(S``!2,^`F6#/^OF4S^0-M,[7K>#-MXX(SR^F,,R^<E3/>
MOZ(S@Y^K,[^KMS/W'\,SU?_0,]^WW3/^W^LSKOWW,^__!C1^^Q,T_>\A-/^J
M+32_;CDT```Y-```.30``#DT```Y-```.30@MC\TS7]+-)Z^5C2S8EXT\5AF
M-`WQ;C1[_7LT\>F%-/V^DC3#QIHT;5^E-#W_LC3_:;XTS__,-/3[V#3[W.0T
M]T_P-``@\30W$?@T%0```````````````````````````/P`+_\)`3=@$`'^
M`QD!```9`?[_*`'__S@!__](`?__6`'__V@!#V!N`?[_?0'__XT!__^=`?__
MK0'__[T!?T#%`>#_T`'__^`!_P/J`0``Z@$``.H!``#J`0``Z@$``.H!``#J
M`0``Z@$``.H!``#J`0``Z@$``.H!``#J`0``Z@$``.H!``#J`0``Z@$``.H!
M``#J`0``Z@$``.H!``#J`0``Z@$``.H!"`#K`0``ZP$``.L!``#K`0``ZP$`
M`.L!``#K`0``ZP$``.L!``#K`0``ZP$``.L!``#K`0``ZP$`P.T!`'#P`0(`
M\0$``/$!$$#S`28```````````"L````K````*P```"L````K````*P```"L
M`/\#M@#P/\````#`````P````,````#`````P````,````#`````P``%$,,`
M$1''`!`0R0`0$,L```#+``%`S0`"Y-(`#P#6`/[_Y0`P`.<``P#I``PP[0#`
MR/(```#R`#P`]@```/8`8`+Y````^0```/D```#Y``<`````````````````
M=@```'8`&#-\`&0`?P`D2(,```"#````@P```(,```"#````@P```(,```"#
M````@P```(,```"#````@P```(,`*`*&````A@```(8```"&````A@```(8`
M_P.0````D````)``SP.8````F````)@```"8````F````)@```"8````F```
MQ)L`*4ZB`#`0I0```*4`!`"F`,,`J@```*H```"J````J@`@`*L``(``````
M````````````````"0````D````)````"0````D````)````"0````D````)
M````"0````D````)````"0"`#@T```(.````#@````X````.````#@````X`
M```.````#@````X````.````#@````X`_O\=`/L#)@#^_S4`^P,^````/@``
M`#X````^``(`/P#P'T@`^/]5`/__90#__W4``@``````````````````````
M`````````````````````````````````````````````*P`!`"#``<````'
M`(``"`````@`@`#8QEF(5XA=B%N(9HAAB%^(:HAHB&^(;8BGB'.(<8AWB'6(
M^\A[B'F(HHA6B&>(6HALB%R(;HAPB/S(7HATB/K(>(A8B&F(<HA@B':(>HA\
MB'V(?HBAB/;(:XCXR/?(J(C^R/G(]<C]R-G&^<?SQ_3']<?VQ_?'^,?ZQ_O'
M_,?]Q_['0,A!R$+(0\A$R$7(1LA'R$C(2<A*R$O(3,A-R$[(3\A0R%'(4LA3
MR%3(5<A6R%?(6,A9R%K(7,A=R%[(7\A@R&'(8LACR&3(9<AFR&?(:,AIR&K(
M:\ALR&W(;LAOR'#(<<ARR'/(=,AUR%O(8XBDB&6(IHC2R-/(M<:VQK?&N,:Y
MQKK&N\:\QKW&OL9WR'C(=LBAQJ+&H\:DQJ7&IL:GQJC&J<:JQJO&K,:MQJ[&
MK\:PQK'&LL:SQK3&^?GX^>;Y[_G=^>CY\?G?^>SY]?GC^>[Y]_GE^>GY\OG@
M^>OY]/GB^>?Y\/G>^>WY]OGD^>KY\_GA^?KY^_G]^?SYYL;6R-?(V,C9R-K(
MV\C<R-W(WLC?R.#(X<CBR./(Y,CER.;(Y\CHR.G(ZLCKR.S([<CNR._(\,CQ
MR,W&X,;AQN+&Y\;HQNG&ZL;KQNS&[<;NQN_&\,;QQO+&\\;TQO7&]L;WQOC&
M^<;ZQOO&_,;]QO[&0,=!QT+'0\=$QT7'1L='QTC'2<=*QTO'3,=-QT['3\=0
MQU''4L=3QU3'5<=6QU?'6,=9QUK'6\=<QUW'7L=?QV#'8<=BQV/'9,=EQV;'
M9\=HQVG':L=KQVS';<=NQV_'<,=QQW+'<\=TQW7'=L=WQWC'><=ZQ]3(U<C<
MQMW&>\=\QWW'?L>AQZ+'H\>DQZ7'IL>GQZC'J<>JQZO'K,>MQZ['K\>PQ[''
MLL>SQ[3'M<>VQ[?'N,>YQ[K'N\>\Q[W'OL>_Q\#'P<?"Q\/'Q,?%Q\;'Q\?(
MQ\G'RL?+Q\S'S<?.Q\_'T,?1Q]+'T\?4Q]7'UL?7Q]C'V<?:Q]O'W,?=Q]['
MW\?@Q^''XL?CQ^3'Y<?FQ^?'Z,?IQ^K'Z\?LQ^W'[L?OQ_#'\<?RQ^/&VL;;
MQM'(=Y+?EM6)S9/?FVCZVHE9C]N)78_<B?>6VHK<B]N74YZJG>J;;HK(B^B)
MZHEP^^V)W93NB;2>TXK;DMN4^8EZ^_N)_)[\B;^)_HGFB4:=[IU^H&B@Z9AH
MB_V-OHO9G^N*UY]JBUR<L8M>^_.=T*!F_.F2[)JKCTCZ18YOG-Z>[XGIEKN>
MWI2XGKJ79?O6E;N<VI=%CWW[6)%D_E:839M;D\>5YY=9D_61N)>B_;;[^I)7
MDZ:+N?NPE\3]H9SRD?F1\8]%EU.8>/[!^U&2K9UL_6OZPIM[FF"+2Y.]FK>1
MM)7%_O">9(UIDF>-ZOOO^VB-ZY-"_&:1S?K=D\R+;8UNC:B6IOQOC7"-9/Q@
MD'2-PY?0BG22OIO(G+J<>(VYGEJ5M)%(BGV-?8K"BDK]H8W1BK3\1XNDD]J>
M48JFC<6>Q/QXH+64POQKBJN-Z/JMC4G\P9-OD+"-?I3ZD'F4LHWN_'N9M(VW
MC;.1NXVZC;R-1)!,_>23X)-3_<.-N)OP^^F3]I/%C<J-S(U=_;638?WXG%*2
MZ*"EG-:-P)?>H-*7I?JC_=N-KXZUD4G]T?WKC<:7SOW\D%G\UI;%E^^-UY?P
MC::6O_OSC4F4]8URF&N._?I0C\R=9?QNF:&48X_:H%.2Z?VUG7F879UCC6F6
M<)]J_,>*UXE-_MV>^_Z\F,SZL)5DE&^3N93LE>Z1PYCVE?V/Q9AFEV[^W9?2
MDF&7RYCPE5V7XY',F&F4S9C.F/R5HY1BEK;^8Y30F-&8=93@^G*4UICPBMF8
MVYC=F*B8;8K[BJZ*R?ODF.:8Z)A-BE>2WY6LH.N8[)CTF+B*YYZ\E-'\QIQ^
MGOZ8Z/U`F<F4TY1&F<"0T91SE<*32)E+F56.3IG^CEF.[)3OE'2/59E$E5:9
M69E;F47ZMY!#E\V5R9=0_;F.QI5GF;F*_(UVBE&=<YE/G7J99)6AF:69IYGM
MCJV9;I1PC]#ZLYE3H%R6>OW^E[V2_9=DC_?\8I7-EV2>3)+)CKR9I9U4CWR/
MHHYZCZZ7R);#F=:0OIQVCW"42_O*_<>.^:"IC\>9UY#?GLZ9NH_KC\^9PH_)
MDMR7LY5YG+*5VX_CFWJ>[IO>F?KZY9Y2BN&99XJUBZR*Z9G*^]Z7T97UF4K\
MJ9O<^U;^I)Y)G=N5Q8GXF62659#4EGR739;AETB:29I]_JJ04)I'D]B.R9!5
MFKR06)JXB]60099:FER:PI>[BJJ;]9!@FD618YJVB\_\:Y9NFD^11I?FH->2
M=9;4D[N1>99PFGB6S9%*G&^@:J!?D:6?NHG-GGF:SIUSG;F6O);1G+>)[IY#
M^\F>T_NND7B=>YVSGK*>UIU/F<Z)P(O$G]2+O\;YBT:)P,;E^GO(QHM7G/N:
MT(G/B<'&T8GBB7Z2NIW"QOC[QXMKDM*)SY^IG=.)XIEGDJ223HE/B7B2MI'4
MB=*?IY*BE6Z2ZI9ODJ.24(E7^F:8UHFRF*N2WI:LDFZ?\HYLG]B)6?JHDF.1
M<Y^MDNF;J9*JDMF)5OVHGZ&2XY"FH*N4<OS$EZZ29_JBDFGZ:))1B6_Z<?I2
MB5J4P\;=B:+(Q,92GE.)59ZZDL7&??JH^FB:1_I^^KN2MOVB^J/ZI/JTFZ;Z
MWXG;_:GZ5(FK^GK\X(E/GWW(X8FP^LV?YZ"Q^J:)^IZR^K3ZQ))OG["+K)_C
MB=.;Y(FU^M6?58G%DE:)L_JV^K?ZW)[$^W&?NOK'DL;&3)KEB7V?J:#$^L?&
M5XFJ^EB)XXMAB_&:MY[(QM'ZTOJZGM3ZV?K;^N"<]_OZ^^>)>J#<^MWZZ8G)
MQN+ZZXGC^LB0VI)9B?6<6HGG^J*?ZOKM^JV/6?OO^N^6[)W*G6W][(E$^^*=
MP)Y6GGF?QYKT^J&8^/KPB4>>]YW3G\J:\8GY^EJ.\HGSB5V248O@DO2)U)]Y
MBO6)IY>ZDUB>]HE7GO>)08KXB?'Z^HE"^[_ZH_OW^DZ>W)3:E?B=:I^WBD;[
M1HI'^TB1WI)3B_:=VIM^G?V)Y)E#GNF=4H_UG?"=YYF]B^^=MY_0G>N?J8W/
MG>&8Y9W(G4_[ZYU4^U7[HIK6BE^:]9ZWC]*::I[HGK^+PI%BG6"27I+!D<6*
MHY=LBWZ-5)R]G<6<6XE<^UO[5_O'F%K[[ISBDJ>4U)MD^W;[8/OEF<*:^Y%S
MH'*?S)^EF.B2O)OSEN>29_Q]B_2;]Y[!GF^9\99!CDJ5YI?UEN:20I]G^ZF9
MYOII^^67?99L^Z*9NYIEFDZ4;OO?F>.85))[EJ^*KXN]GN:>;_OACGV;?IS9
M^>J2<OMQ^UR)\)CREG3[P8M=B=Z)7HG*QD+^>_M?B6")S9O3G4R84I?#E;:;
MN9JSEW2?\9+?EZ;[J_MWF%28Q955G;+[?I5"E^:4]9+]DJ+[49SIE%R8\)),
ME&N1>(OBE$^8M?MQDF636YA0F+R7\Y)`DTV8<I7O_<']NOOKDG/\MY>T^Z>0
M09?TDKS[=Y7BGGB/W/EREK6>2Y;ZH'65VI!GDZ3^WY!4DV&)M(O`G4B.Q?O'
M^\O&>?IGGM+[8HECB7W\:Y_,^Z[^T?MU^]3[UOO8^UV+3)/BFLF+V_O)GT2?
M[9C=^_*-9(GR_4V3Y_ORH&B86)]SC=[[W_OC^ZB-Y/MUG'B88(WE^V&-8HVA
MH$"<K9CJGNN<X/M1GV6-\9Q8_&:-5);H^\S&SI_\^^2:=9_Q^VF-3Y-.D_3[
MSL;#^V6):HU3D_N=_?M9D$#\0?Q#_&&31OQBDVN-3/RXE=#&RHMZF-'&4?Q4
M_*_Z;(UA^E?\<)M1H,N+;I/5_*G\8?QFB<OZVOEZD^"@:Y-K_-R@:)1M_'&-
M9/VZF=":89KEH%N@K)9`E_&>?I]RC7;\J99NH*K\S?MT_'2@<:!Y_'S\4)QY
MDWB3W:!UC7:-=)-WC:7\HOS#D'F@>8W\BW:@S8M:G_2?NI]ZC46>L)-UH$:;
MKORP_%'Z>XU\C=:>K)-;GZF3?*"R_,&*M)^L_$R>Q8^MD\.=HHU*G;;\HXU+
MGDV>I(W]BK7\P_RRDZ6-H9/&BEN*38G4_GB*JY.GC46?5HJ__,#\YHZDBD.)
M\Y.K_**>QYW2QLZ+Q?S+_+.3ROS)_*R-QOMGB<W\\YS0_+N5T_S4_*Z-U_S;
MDV/^U9/:_'&;W?ROC?+ZV)/?_-.3X?QVCF+\T9.QC5F84OM3^TW[OYQRFU#[
MOI/QG>O\NZ!^F[.-Z)K<COF<4/KGF//\\OSEDUF:M8U-_5[]?8]'E?;\4))H
MB;:-^_Q]H/R8:8E/_E:2R?KHD_C\XYRI_43\0):XC4J;N8_^_&J)N8U^D?23
M?/OGD^^72OY%_:66X/Y(_4?]\OYJ_KV-H9NWFOR.H9]1_:WZOHVDB=F:3OW`
MC?"7M)-$_:>?PHVVF5+]P8U&CM&@RI_/DO2<Q(U!_4R;5_WO_-Z<0OULF/F7
M6)5>F'O^S93NDUK]]9/OD^J.6X_&C<B-QXWWD\F-\OMPELN-7/UEC\V-J)WY
ME,Z-ZI-?_?"3MI_/C6.7T(WQDV+]9?W;G_B3]XMF_<^+T8W2C7'];_W3C>>?
MO9#0G]"+<OVNG-&+VXKD^LZ5=OUB^]2->/WCCG:0QIC5C=&7MI['^D*@<YC\
MG]>-^Y+8C4^4V8UKB<Z7\_JN_:_[MY+:C5J<K?W<C424W8W6H-672I1-E,N7
MWHW?C>"-^?[`_?G\?ONSDJ_]X8W3E<&):/VWG..-P/KEC63Z1XGDC>>-Z(W'
M_;#]1936E\;\1)CIC>J-4/[,_:>=S?W/_=*5[8VZ_,7]TOW<G,^5[HW4_>R6
MZY:VD,/]JYCNEO2-X/WVC?>-^H_0E]*+^(W9D/#ZX?WYC>/]^HUC^Z:0<)GK
MD7"7;YCB_?*8_)ILB?W]7IF]E>3]YI'E_>;]Y_U4E+B9Z9=&DV.8O)7M_??]
M<)CVEJF.491#CEJ+[OWP_?3]]9M^E]6;PYK(E]N@T)'DG]V/Z9'@F,J25YCK
M_4F;=IVOGLR<ZOWQC?O]4X[/^OF6OYA)GLJ;_OW<DD'^S)'BD43^TXM'_DC^
M591+_DS^OXUXGE'^5I1AG5>49IG5BVF@M)A)H$R@99ZUF%C^=9E3_F6@6?ZW
MF+B8NIB[F+R?2J#'GJZ8UI+A^M21WOI;_E[^U_M:_L64ROK!F%R7=/YSET;Z
M9)=H_DZ699>AB?J5U))I_D7[R)COD,F8RIAME+>4;/YKE/R2ZY5S_FZ77_Z]
M_=62N?YQ_KO[>I3[E7?^>?YU_EV4?/Y$DZ:.TY*XE''\7I>G_FJ4XY//F-F@
MOZ!-H+B@SJ"WH*G^PXFK_O2=;8E[G-*8J9^R_K'^V9?$H':4>)FS_M.8M/[4
MF+F?<935F+C^U,:Z_ER>N_Y$H->8V)B\_OZ?O?[=G>&>VIC?G;_^OO[KGEF>
M7*#`_G>4W)C!_MZ8P_[(_LG^RO[+_L*?Q)BPE+&4T?[!H-+^S:#3_N68UO[D
MD<>/KI1/BK*4U(_JF-C^X)WNF,25Z/SOF-CZW/ZNH$R=\9CSF,&4]9A/^N*6
M4)2BEO:8Y9;WF$:@XY;XF.2>UOG#E,*4X?[I_N26K(G;EN+^Q)3C_N?^^Y_)
MD^B45OO%D*B@Y?[]F/N8Z/Z_CMB+]_YHC\:4ZIUI_-J<\_YRG/#^R8E!F4*9
M]?[7D<R4^/ZHE_S^O_W^_M&6U930E$29LZ#/E/J?Y9%JG$F.3(Y-CG.:1YE0
MCD^.29E1CE*.LIJEB4R9^)]6CDV9RI%7CN&41Y#8CUB.ZY1<CE.5Y9]6GT^5
M7HYJF62<V9Q=CE"949EBCE*9:(YACEF?LXM=GV:.;HYDGU.9N/I4F7".89]R
MCFN@0)_ME.Z4O9][CE>9]Y1?GW..8I_VE%B9=8[;^7*0^)1:F;"@>8YXCO.4
MKYBRH'J.7)E\CGV.V8NBB=>>MJ!"GJ2.IXY"E7V859>HCJJ.HXE@F6*9_)1A
MF?J4KHZRCK".8YFJE_N4NXYVF*&.MXZFG;">N(YPG6Z);XEPB7&)<HESB72)
M=8F\CKV.OH[1G?V4UXO:B^*@Z9^H_>>*PH[$CF2999E.E;.8RX[?B\Z.SXYH
MF6F9:YG1CFR9U([5CFV9OJ#6CKR@M:"TH."+M8G=CEV><9FNB>B=995RF5R+
ML8G`H-^.9I5TF7:9=YEYF=J=X(Y<D^:=7XMCE6>5XYU\F7V9?IE;BZ.9I)FF
MF:B9OHIAGJJ9R*"KF<3^PICHCKJ@=_WNCK^>PHFLF6N5;)6OF4J9=HE(C^[[
MKIG[CE*+L)EWB4&/L9E)CTWZY)WI^U2;LIEHGDJ/0H]1CT:8M)GUCE7]S9QX
MB5./;X]CCE:/=O[&GZSZ6(](F+>9999L^N>=8I[,EF>.=?Q^F+G]_)?YF&:/
M;I5%DF"/T9[-_KF98H],E\>17Y6[F6V.<8_+E+&5\IK#EKV9SZ!MC[Z9](YR
MC^25OYE"DJ7[P)FT_7>/P9FY^D"/1/K"F5R/Q)G%F7N/HX_&F<V6QY:EC[OZ
M<)5HDWZ/JH]0H-.05I6XC\B9KX_)F7F529_*F<N9>I75G;"/>OI?GLV9R:#;
MFL:@M(_7H,>@0Z"UC[*/8:!>GK:/Z)^RG'R5QY^[C[R/[(_`CVJ3Y(M\G*&5
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ME^N7\9?WET&879ATF'N8?)BBF*:8J9BJF*R8L9C`F/J8?)JTFK6:MIJZFKZ:
MOYK`FL&:Q)K%FL::R)K)FLN:S)K.FL^:T9K3FM2:U9K6FM>:V)K<FMZ:WYKA
MFN.:Y9KFFNJ:ZYKMFNZ:[YKPFO2:]9KWFOB:^9KZFOV:_II`FT&;0IM#FT2;
M19M(FTN;3YM0FU&;4IM3FU6;5IM9FUN;79M@FV*;8YMDFV:;9YMHFVF;:IMK
MFVR;;9MNFV^;<YMTFW6;>9MZFZ*;I9NFFZN;K9NNF[";LINSF[J;NYN]F[^;
MP)O!F\>;R)O)F\N;SIO/F]*;UIO7F]B;VYO@F^*;Y)OHF^N;[9OQF_.;]YOZ
MF_V;_IM#G$2<1YQ+G$R<5IQ8G%Z<8YQEG&><:9QNG'"<<9QSG'2<=IQXG'J<
M?9RCG*2<IIRGG*J<K9RPG+2<M9RYG,.<Q)S*G,Z<U)S5G-:<UYS?G.&<YISJ
MG.V<^IS^G$"=09U"G4.=1)U%G4>=2YU.G5"=4IU3G52=5IU8G5F=7)U>G5^=
M8YUEG6:=9YUHG6F=:YULG6Z=;YUQG76==YUZG:*=K)VPG;.=S9W4G>V=^IW^
MG4">3YY1GEN><)Y\GJ6>JIZMGKR>PI[0GM.>X)[LGOF>1I]'GTJ?39]0G[.?
MOI_1G^R?I*"QH.R@]Z#[H/Z@0(A!B$*(0XA$B$6(1HA'B$B(28A*B$N(3(A-
MB$Z(3XA0B%&(4HA3B%2(58ABB&2(HXBEB*F(JHA!B;*)NXF^B<J)S8E`BD2*
M18I,BE"*4XI7BEV*7HI?BF"*98IHBFF*;(IPBG&*<HIZBGN*H8JBBJ.*I8JJ
MBJV*L(JRBK2*M8JVBKR*O8K`BLF*S(K/BM**U(K8BMF*W(K?BN"*X8KBBN6*
MYHKHBNV*\XKTBO>*2(M+BTV+3HM/BUF+JHNKBZV+KHNRB\*+PXO%B]:+VXO>
MB^&+XHOFB^V+\XOZB_Z-><AZR'S(?LBAR*/(I,C0R,_(Y,;EQLW(SLC^^763
M=I-(E<:.]J"M_'*21_S?E*28YY3+D'N2V)1?_%3ZVI9YDG3Z=9+[C4F*WY)\
MFV/Z8/IMDF+Z:Y=J_53]<Y+8E[N?0I-VDF7Z;))N^L"2OY*^DK.*=9=`^G;Z
MT/M[^LR)0OJ\DER4M9NGF*27_9##DM";4)7&DD:5POK#GF:<4Y#!E^GZ8I+A
MDL;Z<OK,DOF=0XJFBLV:[OK,FWR=7YGV^\6?68IKBV2*\HKXBMB=UI3^^J?[
M0XM$BU2>RHJHGF.2W9IEBV^+?HM#C]"2OIW>_/V=9HMPBW6+Y(JDB^^*]HIV
MGN.>L9QWGF2+9XO@FDJ+\8K7BJN@[HK^BEB*HXNGB]>=?9ZGGJN>>8MZBWZ*
M1)[GFGR*<8OIFD[[^8ICGDF+SHINBUJ*>XM\B_J*<HNHBZZ><IY?^[J0]I[M
ME_.:[J!\ED63;IA6^DO\QY?+G$"2Z)S]D>B7:OMTB\C]09*AEO..UOK'G-?Z
MH?O%CJ3[^I';_JN71Y&Q^]*48?[.^NV2\Y'&DUJ3[Y+(^D>89I-5F.:60Y^J
MG]J4[I*O_/O[^8[VD;:<K?M.F$2/_99IE]252YBJ^Z^=Q9WQD;&.J9>L^[C\
ML/O2_,N3K(M5H+Z5Z8[XDKZ7;)&JE,:=M9>XDN^1IOY@EUB3=I6LC^R1M)=*
METG[>)6\D]:159-6DU&8^(_`^_*3T)!CDZ61[:!1DZC^4)-,^O>2K?[5^WF>
MV?NGH%Z3RXE3G^'[XOMTD.;[MYM'FUO\_9SL^ZB;U8IS^EG][?NIG*B*PYM.
MF]"57Y#NET[\QIY0_'/]7OI9H'7ZHIQPDW&3=Y/O_FV37?S\BD'[:Y[CE.*.
M39RCEL.*JI9H_&V+Z8JA_&R3</ZH_.G\ZHJKEJ?\RXI7FZ63HY-"BU"7LX]%
MBT:+>Y.QDT>*?)-EFZ^3HY[L^G>+L?R[_*B3[)?"_6>1S/RVD^20Y9#RGLJ3
MO(O/D]O\W/SF_.>6V/S9_*;]\97IG.3\KY1W^LR36I"_DU'[N9/7_K>3V9.[
MD]J3HYC1D'#Z_/Q`BWN@XI/6_*:37Y/RE_B.1X^TDNV1TI9&_4^/295<^DO]
MTY;UH$.2^I?9G?2739+5GLF<6)+(CK24X9/?D_#\[)/VE\^6:?U2DV[]?/KZ
MDWR0MYWIH$[ZH?UTGK^?RYZYF[F7TIY3EZ26OH_9E%B0>?U[_?J.V9[4E[N0
MO/W&_4B2P9VYDJ:22X^VDMB>7I1?F,Z42I)P_6>4[(U(E,'Z]YR^_7[\^9/K
M^L/ZTY?YE4B<:H[8H-?]2ONOFTN4R?VLCEJ2O?S9DMV2NI;:_=[]T_W6_=S]
MW?W^D*'^V)QMGGS]8?M@_E*83Y9ND6V89)A3E.S]>/M:F-"38IA/EU*4TI'J
MEVO[L9'S_<N2L9OL_&N849=QF/.>Z)%,^VJ2^/UAF.V31)?AD6F88HI5G'>.
MYI.BD[.4?9-FGEF46)14_J64[95^_>O[??UOEV&4P9_7E5+Z:)_GF\[\Z)9)
M^DV5^)Y)_LZ1<9>Q_?*<N)-#D%F7UY1F_GV4;_SWCGR4S9*REV7^?I98EW>;
MSY'5EK/\KI-&G%N5T9'TE.W\^OW(_&+^_)%K_OG]Q_Q.D;B<9Y>BE'68K)?3
MD>N.:I=>EOF?^)6B_N:/I)UHE^R.O91;E/:<I_K9FUWZ5I9BE[J43Z#8DKN4
MSY!EE$R?OIYM^\J5PIWXEW.4=)1+BE6*:8MVB_B@WYBU_ON6^YO.GGN>SO[\
MG<_^I8OLBN#\K935_JR4;XJIB\N=Y_S(D_"1X(_MD-R;QY-)DN&6X8_EF\"4
MPY/%DWF0>Y=^D.;^N)UPDJB5N9A`D;[\5Y'?^N:;1(Y/G/3^W)-*CKF=3H[E
ME/";496[B_"49([JE%N.\IO)G6R.=8]QCF".V/U2E525NYU#E?Z2\I3QE.J@
MTIWXD6*4I)NMCM"65Y=WBK6.;:"VCE:70)7SH+Z4W_V\G?Z4P([#CDF6S)!@
MG$N5S([DCDF<7HM<E=F.M)U?DMN.5)?4GFB5PZ!AG%^<3?QIGL?^QOYED>><
M5(ILG%W^:I5ME?".]H[:^TR+=?W=F_7Z:H].CU7Z09Q<DF;[98Y)F*C[0IC[
ME\J06YQ-ETN?M9_2DZK]0)A&D6>86OJI^_W\J_V]D4R/R995CZ[[;Y7PH&^4
MK/W+EE:@7H]LCZ..L_M3_+/]:X_*EF^>Q:!X_$*.6H_"D*6.89!/DG.3M?W,
M_KW[0YC%EKR)2Y)*F/&@^Y[2G*>/7/Q%F$:0^OY@E4B?1Y+[D'&5K)RNCWV5
MMI>]H+V/OX]IDZ>;ZO[AFT&+MIWKH*.;H8O(CTR)8)C'E%B+JY6JE=:3T8_5
MF<C[UX_2CV20MIB]F-R/]O[9C_.7^)MLGO*/[H]NGN^/](_UC\*5:IC/ET&0
MVYQBBTZ*9HK[G/R<Y9QSBV&*HHORG<J.3I#UGT^0_OMCD%>09I#E_&*19Y"A
MCZ*/2)W3^KF0:Y!7_E7^<Y#OF_"<X)'8D4:68)-3^M.<0/OBC4*45I!EF$KZ
MKY5:ETF31Y?TH'B7SX]@_-R189;LDEV3WH[^ED_]WI6PF$"@O9=]E_67K)O:
M^L*2>Y#^DWN4OOI#_<:0I)"HD*F4J9!]D+K]Q)/M_JN=XZ!(EJF*Q9M=EE^7
M7Y9NEEW[L9VC_K*=KI6C_**@599!DZV5U9%ZE_S]1X[]DZ60K)"ND.*59I2X
MD>R<K9#CBNJ5V9'UE?25<OYZDJS^Q9'-D/Z569',E\Z0_?Y;G6#]SYS@D/.0
M\)"WE4N.6);/GF2=4)'!G*>3[Z!1D<&6I/QJG4Z279%MG5J1P)QJD::>M)9R
MD<B>58MRG<R>=)%WD<"6L8^WEGB1=_MUD:.1>9&DD::14I!%H-V<0(EXE'6>
M1Z!(_%*<_8[PCP````!9$@``61(``%D2``!9$@``61(!`%H2``!:$@``6A(`
M`%H2``!:$A``6Q(``%L2``!;$@`@7!(``%P2``!<$@``7!(``%P2``!<$@``
M7!(``%P2``!<$@``7!(``%P2``!<$@``7!(0`%T2``!=$@``71(``%T2$```
M`````````%<2``!7$@``5Q(``%<2``!7$@``5Q(``%<2``!7$@``5Q(``%<2
M``!7$@``5Q(``%<20`!8$@``6!(``%@2``!8$@``6!(``%@2``!8$@``6!(`
M`%@2``!8$@``6!(``%@2``!8$@``6!(``@``````````````````````````
M.Q(@0#T2```]$@``/1(``#T2```]$@``/1(``#T2```]$@``/1(``#T2```]
M$@``/1(``#T2(``^$@``/A(``#X2```^$@``/A(``#X2```^$@``/A(``#X2
M```^$@``/A(``#X2```^$@`@/Q(``#\2```_$@``/Q(``#\2```_$@``/Q(`
M`#\2```_$@!`0!(``$`2``!`$@``0!(`$$$2``!!$@``01(``$$2``!!$@``
M01(``$$2``!!$@``01(``$$2``!!$@`@0A(``$(2``!"$@``0A(``4,2``!#
M$@``0Q(``$,2`!!$$@``1!((`$42``!%$@``11(``$42``!%$@``11((`$82
M`0!'$@``1Q(``$<2``!'$@``1Q(``$<2``!'$@``1Q*``$@2``!($@``2!(`
M`$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``
M2!(``$@2``!($@``2!(``$@2`@!)$@A!3!(``$P2``!,$@@`31(``$T2``!-
M$@$`3A(``$X2``!.$@``3A(,`%`2``!0$@``4!(``%`2`(!1$@``41(``%$2
M``!1$@``41(!`%(2"`!3$@``4Q(``%,2``!3$@``4Q(``%,2`(!4$@``5!($
M`%42``!5$@"`5A(``%82``!6$@``5A(``%82``!6$@``5A(``%82``!6$@``
M5A(``%82``!6$@``5A(``@``````````````````````````,A(``#(2```R
M$@``,A(``#(2```R$H``,Q(``#,2```S$@``,Q(``#,2$``T$@``-!(``#02
M```T$@`$-1(``#42*``W$@``-Q(`@#@2```X$@``.!(`(#D2``0Z$@``.A(`
M`#H2`"`````````````````````````````````K$@``*Q(`("P2```L$@@`
M+1(``2X2```N$@``+A(``"X2```N$@``+A(``"X2```N$@``+A(`!C`2```P
M$@``,!(``#`2```P$@``,!(``#`2```P$@``,!(``#`2```P$@``,!(`0#$2
M```Q$@``,1(``#$2```Q$@`"`````"`2```@$@``(!(``"`2```@$@``(!(`
M`"`2```@$@``(!(`""$2```A$@"`(A(#`"02```D$@``)!(P`"82```F$@`@
M)Q(!`"@2```H$@``*!(``"@2```H$@``*!(``"@2```H$@`0*1(``2H2```J
M$@``*A(``"H2``@`````P1$0`,(1``#"$0`(PQ$``,,1``##$0``PQ$``,,1
M``##$0``PQ$``,,1``##$0``PQ$``,,1``##$0``PQ$``,,1``##$0``PQ$`
M`,,1"`#$$0`#QA$``,81`!#'$0!`R!$``LD1``#)$0`-S!$`$,T1`0#.$0!0
MT!$2`-(1`![6$0"`UQ%``-@1(`+:$0``VA'P#^(1``;D$0``Y!$``.01#@#G
M$0`<ZA$``.H1``#J$4`8[1$`P.\1+P#T$0``]!$`$/41``#U$0:X^Q$``/L1
M`%#]$0$`_A%X$`,2```#$@"`!!(`,@<2```'$@``!Q(D``D2@`8,$H`?$A(`
M@!,2```3$@`@%!(("!82`0(8$@``&!(``!@2```8$@``&!(``!@2```8$@``
M&!(``!@2`"`9$@``&1(``!D2```9$@``&1(``!D2```9$A``&A(``!H2```:
M$@``&A(``!H2```:$@``&A(``!H2```:$@``&A(``!H2```:$@``&A(``!H2
M```:$@``&A)``!L2```;$@``&Q)@`!T2```=$@``'1(``!T2```=$@P`'Q(`
M`!\2``(``````````*01!`*F$0``IA$``*81``"F$0``IA$``*81``"F$0``
MIA$``*81``"F$0``IA$`8*@1``"H$0``J!$``JD1$`"J$0``JA$``*H1`$"K
M$0``JQ$``*L1``"K$0"`K!$``*P1``"L$0``K!$``*P1``"L$0``K!$``*P1
M``"L$0``K!&``*T1``"M$0``K1$``*T1``"M$4``KA$``*X1``"N$0``KA$`
M`*X1``"N$0``KA$`(*\1``"O$00`L!$``+`1``"P$0``L!$``+`1``2Q$0``
ML1$``+$1(`"R$0`@LQ$``+,1``"S$0``LQ$``+,1``"S$0``LQ$``+,1``"S
M$0``LQ$$`+01``"T$0``M!$``+01``"T$0``M!$``+01!`"U$0``M1$``+41
M``"U$0``M1$``+41``"U$0``M1$``+41``"U$0``M1$`,+<1``"W$0``MQ$`
M$+@1``"X$0``N!$``+@1``"X$0``N!$``+@1``"X$0``N!$0`+D1`0B[$0``
MNQ$@`+P1``B]$0``O1$``+T1``"]$0``O1$``+T1``"]$0`,OQ$``+\1``"_
M$0`!P!%```````#(#P``R`\``,@/``#(#P``R`\``,@/``#(#P``R`\``,@/
M``#(#P``R`\``,@/``#(#P``R`\`",D/`$#*#P``R@\``,H/``#*#P``R@\`
M`,H/``#*#P`$RP\``,L/``#+#P``RP\``,L/``#+#P``RP\``,L/``#+#P``
MRP\``,L/``#+#P``RP\``,L/``#+#P``RP\``,L/``#+#P``RP\``,L/``[.
M#P``S@^``,\/@`/2#P``T@\``-(/`/#6#P``U@\``-8/``#6#P``U@\``-8/
M``C7#P``UP\``-</``#7#P``UP\``-</P#_?#P``WP\``-\/``#?#P`!X`\`
M`.`/``#@#P#PY`\#`.8/``#F#P``Y@\``.8/``#F#P`/Z@\``.H/``#J#P"`
MZP\``.L/``#K#P``ZP^`'_$/``#Q#P``\0\``/$/(`#R#P(`\P\``/,/``#S
M#P"`]`\'`/</``#W#P``]P^``/@/`0#Y#P``^0\`^/X/`0#_#P``_P\"```0
M````$``^!1````40@``&$```!A````80`#@)$```"1````D0```)$``""A``
M``H0```*$```"A`0``L0```+$```"Q``@`P0$0`.$."0$Q```!,0``04$```
M%!```!00.``7$```%Q```!<0```7$`0`&!``$!D0```9$``(&A```!H0```:
M$``(&Q!``AT0```=$,`!(!```"`0```@$"``(1```"$0``8C$```(Q```",0
M``0D$```)!``!"40```E$```)1```280```F$#P`*A```"H0`!`K$$`0+1``
M`"T0`"`N$`(`+Q```"\0``(P$`0!,A```#(0```R$```,A!@`#00```T$``,
M-A```#80```V$(`!.!```#@0```X$``".1``0#H0"``[$```.Q```#L0```[
M$```.Q`"`#P0```\$```/!```#P0```\$``!/1```#T0```]$```/1```#T0
M```]$```/1```#T0```]$```/1```#T0``0^$```/A```#X0```^$"``/Q``
M`#\0```_$(``0!```$`0``!`$```0!`0`$$0``!!$```01!``$(0``!"$"``
M0Q```$,0``!#$```0Q```$,0``!#$`"`1!```$00``!$$```1!```$00``!$
M$```1!```$00``!$$```1!`(`$40``!%$```11```$40``!%$```11```$40
M``!%$```11```$40``!%$```11```$40"(!'$`,02A#``DT0`(!.$`C`41`'
M`%00``!4$`P`5A!P@%H0`/]B$```8A"`.&80@`]K$```:Q``P&T0"`!N$,`#
M<A```'(0``!R$/X'?!``0'T0`,!_$`,`@1#@`(00@`>($```B!!X`(P0\`"0
M$`X<EA"``)<0`H"9$`0`FA```)H0``":$```FA```)H0``":$```FA```)H0
M`$";$```FQ```)L0``";$```FQ```)L0``";$```FQ```)L0(`"<$``"G1``
M`)T0``"=$```G1```)T0``"=$```G1```)T0``"=$`#`GQ```)\0``"?$```
MGQ```J`0``"@$```H!!``*$0``"A$```H1```*$0``"A$```H1```*$0``"A
M$```H1```*$0``"A$``!HA```*(0``"B$``,I!```*00``"D$```I!```*00
M``"D$```I!`!`*40``"E$```I1```*40``"E$```I1```*40``"E$```I1``
M`*40``"E$`!`IA```*80``"F$```IA```*80`!"G$```IQ```*<0!`"H$(`$
MJA```JL0``"K$`0`K!```*P0``"L$```K!```*P0``"L$```K!```*P0``"L
M$```K!```*P0``"L$```K!``(*T0``"M$```K1```*T0``"M$```K1```*T0
M``"M$```K1```*T0``"M$``!KA```*X0``"N$`!@L!```+`0``"P$```L!``
M`+`0``"P$```L!#(`+,0``"S$```LQ```+,0`P"U$```M1```+40``"U$```
MM1```+40``"U$```M1```+40``"U$(``MA```;<0``"W$```MQ```+<0"@"Y
M$```N1```+D0``"Y$```N1```+D0``"Y$```N1```+D0``"Y$```N1```+D0
M``"Y$```N1```+D0``"Y$```N1`@@+L0`0"\$```O!```+P0`%"^$```OA``
M`+X0``"^$```OA```+X0``"^$```OA```+X0``"^$```OA```+X0``"^$```
MOA```+X0`#C!$&``PQ```,,0$H#&$```QA```,80``+'$```QQ`@",D0`0#*
M$```RA```,H0``#*$```RA`@`,L0``#+$`(`S!```,P0``#,$`@`S1```,T0
M``#-$```S1```,T0``#-$```S1!``,X00`#/$``@T!`@`-$0``#1$```T1``
M`-$0``#1$`0`TA```-(0``#2$```TA```-(0@`#3$```TQ`#`-40``#5$```
MU1```-40``#5$```U1```-40@`#6$```UA`$`-<0``#7$```UQ```-<0``#7
M$```UQ```-<0`@#8$```V!```-@0``#8$```V!```-@0``#8$$``V1```-D0
M``#9$```V1```-D0`!#:$```VA```-H0``#:$```VA```-H0``#:$```VA``
M`-H0``#:$```VA```-H0``#:$```VA```-H0`!#;$`!`W!```-P0``#<$```
MW!```MT0``#=$```W1```-T0``#=$```W1```-T0``#=$```W1`0`-X0``#>
M$```WA```-X0&`#@$$``X1```.$0``#A$```X1!"`.,0``#C$```XQ```.,0
M``3D$```Y!`@`.40``#E$```Y1```.40``#E$```Y1`#`.<0``#G$```YQ``
M0.@0``#H$```Z!`!`.D0``#I$`@`ZA```.H0``#J$```ZA```.H0``#J$```
MZA```.H0``#J$```ZA```.H0``#J$`!`ZQ```.L0``#K$```ZQ```.L0``#K
M$```ZQ```.L0#@#N$```[A!``.\0`!#P$```\!"``?(0``#R$```\A```/(0
M``#R$```\A```/(0``CS$```\Q```/,0``#S$```\Q```/,0``#S$```\Q``
M`/,0``#S$`8`]1```/40``#U$```]1```O80``#V$```]A```/80$`#W$```
M]Q```/<0``#W$#``^1```/D0``#Y$```^1```/D0``#Y$```^1```/D0`@#Z
M$```^A```/H0`![^$```_A```/X0``#^$```_A``8``1````$0```!$`(`$1
M```!$0```1$```$1```!$0```1$```$1```!$0`!`A$"``,1```#$0```Q$`
M``,1```#$0```Q$```,1`0`$$0``!!$```01```$$0``!!$```01```$$0``
M!!$"``41```%$0``!1$```41```%$0``!1$`0`81```&$0``!A$```81```&
M$0``!A$'``D1```)$0``"1$```D1```)$0``"1$```D1``(*$0`!"Q$```L1
M```+$0``"Q$```L1```+$0``"Q$```L1!``,$0``#!$```P1```,$0``#!$`
M``P1!``-$0``#1$```T1`"`.$0``#A$```X1```.$0``#A$```X1```.$0``
M#A%```\1```/$0``#Q$```\1```/$0``#Q$```\1```/$0"`$!$"`!$1```1
M$0``$1$``1(1```2$0``$A$``!(1```2$0``$A$"`!,1```3$0``$Q$``!,1
M```3$0``$Q$``!,1&``5$0`0%A$``!81```6$0``%A$``!81```6$0``%A$`
M`!81```6$0!`%Q$`0!@1```8$0`!&1$(`!H1```:$0``&A$``!H1```:$0``
M&A$``!H1`$`;$0(`'!$``!P1```<$0``'!$``!P1```<$0``'!$``!P1```<
M$0`!'1$@`!X1```>$0``'A$``!X1!`0@$0``(!$``"`1`$`A$0``(1$$`"(1
M!@`D$0``)!$``"01```D$0``)!$``"01```D$0``)!$``"01```D$0``)!$`
M!"41```E$0`!)A$``"81```F$0\`*A$``"H1```J$0``*A'``"P1```L$0@`
M+1$``"T1```M$0``+1&``"X1```N$0``+A$"`"\1```O$0``+Q$``"\1```O
M$0#`,1$'`#01```T$0``-!&`(3<1`0`X$0``.!$``#@1```X$0``.!$``#@1
M_`=!$0``01$``$$1``!!$0``01$``$$1``!!$0``01'_`$D1``!)$0``21$`
M$$H1``Q,$0$`31$@`$X1``!.$0``3A$``$X1/`!2$0``4A$`0%,1A`!5$1``
M5A$``%81``!6$0``5A$``%81_P!>$0``7A$``%X1``!>$0``7A%``%\1``!?
M$0``7Q$``%\1``!?$1@`81$``&$1`(!B$0(`8Q$``&,1``!C$0#`91$``&41
M``!E$0!`9A$``&81``!F$0``9A$``&81#`!H$0``:!$``&@1``!H$0``:!$`
MX&L1``!K$0`@;!$``&P1``!L$0`!;1$`$F\1``!O$<``<1$``'$1``!Q$0``
M<1$P`',1(`!T$0``=!$``'01``!T$0``=!$``'01``!T$0``=!$``'01``!T
M$0`(=1$``'41``!U$0``=1$``'41``!U$0``=1$``'41``!U$0``=1$``'41
M``!U$0``=1%``'81``!V$0``=A$``'81``!V$0``=A$``'81``!V$0``=A$`
M`'81``!V$0`$=Q$``'<1``!W$0``=Q$``'<1``!W$0``=Q$``'<1``!W$00`
M>!$``'@1``!X$0``>!$``'@1``!X$5``>A$``'H1``!Z$0``>A$``'H1``!Z
M$0``>A$``'H1``!Z$0``>A$``'H1``!Z$0``>A$``'H1``!Z$0``>A$``'H1
M``!Z$0``>A$``'H1``!Z$0``>A$1`'P1`&!^$0`0?Q$``'\1``!_$00"@1$`
M`($1X`"$$0``A!$``(01``"$$1``A1$``(41``"%$0``A1$``(41``"%$0``
MA1$`@(81``"&$0``AA%@`(@1`@")$0!`BA$``(H1``"*$3``C!$``(P1``",
M$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1
M``",$0$`C1$``(T1``"-$0``C1$``(T1``"-$0``C1$``(T1``"-$0``C1$`
M`(T1$`".$0``CA$``(X1``".$8``CQ$``(\1``"/$0``CQ$``(\1``"/$0``
MCQ$``(\1``"/$0``CQ$`0)`1``"0$0``D!$``)`1``"0$0`"D1$``)$1``"1
M$0``D1$``)$1``"1$0!@DQ$``),1``"3$0``DQ$0`)01``"4$0`!E1$``)41
M``>8$0``F!$``)@1``"8$0``F!$``)@1``"8$0``F!$``)@1``"8$0``F!$`
M`)@1$`"9$0``F1$$`)H1``":$0``FA$``)H1``":$0``FA$``)H1``":$0``
MFA$``)H1``":$0``FA$``)H1``":$0``FA$``)H1``":$0"`FQ$``)L1``";
M$1@`G1$``)T1"`">$0"`GQ$``:`1``"@$0`@H1$``*$1`!"B$0``HA$``*(1
M``"B$0``HA$``*(1``"B$0"@````````````````(`X``"`.```@#@``(`X`
M0"$.0$`C#@``(PX``20.```D#@``)`X``"0.```D#@``)`X``"0.```D#@!`
M)0X``"4.```E#@`!)@X``"8.```F#@``)@X``"8.```F#@``)@X``"8.```F
M#@`()PX``"<.`@`H#A``*0X``"D.```I#@``*0X0`"H.```J#@``*@X``"H.
M``@K#@``*PXP`"T.```M#@!"+PX!`#`.`(`Q#@$`,@X``#(.(``S#@``,PX`
M!#0.```T#B``-0X``#4.X@`Y#@``.0X``#D.`,`[#@$`/`X``#P.@``]#B``
M/@X`"D`.``!`#@``0`X@$$(.``!"#AB`10X``$4.``!%#@``10X``$4.(`!&
M#@``1@Z``$<.!@!)#@@`2@X``$H.``!*#@``2@X``$H.`%!,#@``3`X``$P.
M``!,#@``3`Z``$T.``!-#@``30X``$T.`$!.#@``3@X@`$\."`!0#@``4`X!
M@%(.`0A4#@``5`X``%0.`@97#@``5PX!`%@.``!8#@``6`X``%@.``!8#@``
M6`X``%@.``!8#@``6`X``%@.``!8#@``6`X``%@.`$!9#@``60X``%D.``!9
M#@``60X``%D.``!9#@`"6@X``%H.``!:#@``6@X``%H.``!:#@``6@X``%H.
M``!:#@``6@X``%H.`!!;#@``6PX``%L.``!;#@``6PX(`%P.``!<#@``7`X`
M`%P.``!<#@``7`X``%P.``!<#@``7`X``%P.0`!=#@``70X``%T.``!=#A``
M7@X``%X.``)?#@``7PX``%\.``!?#@``7PX``%\.``!?#@``7PX``%\.``!?
M#@(`8`X``&`.``!@#@``8`X!`&$.``!A#@``80X``&$.``!A#@``80X0`&(.
M``!B#@``8@X``&(.``!B#@``8@X``&(.``!B#@``8@X``&(.``!B#@``8@X`
M`&(.`(!C#@``8PX``60.``!D#D``90X``&4.!`!F#@"`9PX``&<.``!G#@$`
M:`X``&@.#@!K#@@`;`X``&P.@`%N#@``;@X`$&\.``!O#@``;PX`@'`.>`!T
M#@``=`X``'0.``!T#@``=`X``'0.``!T#L!S>PX``'L.``![#@#`?0X``'T.
M``!]#H``?@X``'X.``!^#@``?@X``'X.``!^#@#F@PY#((<.``"'#@``APX`
M`(<.``"'#@`@B`[@#X\.``"/#@``CPX`')(.0`"3#@``DPX``),.``"3#@`/
MEPX``)<.``"7#@!@F0X#")P.``"<#@``G`X``)P.``"<#@`@G0X``)T.`"">
M#G``H0X``*$.``"A#@`\I0X``*4.``"E#@!@IPX``*<.``"G#@``IPX``*<.
M`("H#N`)K0X``*T.``"M#@``K0X0`*X.@P.S#@``LPX``+,.<`"V#@``M@X`
M`+8.``"V#@`@MPX``;@.``"X#@``N`X``+@.@0"Z#@``N@X``+H.``"Z#@``
MN@X``KL.``"[#@``NPX``+L.``"[#@``NPX``+L.`("\#@``O`X``+P.`!"]
M#@``O0X``+T.``*^#@$`OPX``+\.``"_#@@`P`X`0,$./`#%#@``Q0X``,4.
M``3&#@``Q@X``,8.``#&#@``Q@X``,8.`!#'#@``QPX``,<.8`#)#@``R0X`
M(,H.`$#+#@``RPX``,L.``#+#@``RPX``,L.-`#.#@``S@X``,X.``#.#H``
MSPX``,\.0`#0#@``T`X``-`.``'1#@`@T@X``-(.``#2#@``T@X``-(.``#2
M#@``T@X``-(.``#2#@``T@Y``-,.``#3#@``TPX``-,.``#3#@``TPX``-,.
M``34#@@`U0X``-4.`$#6#@``U@X``-8.`@#7#@``UPX``-<.!`#8#@``V`X`
M`-@.!P#;#B@`W0[``>`.`%SD#@``Y`X!`.4.0`#F#@`<Z0X``.D.@`#J#@#P
M[@X;`/(.``#R#@``\@X``/(./@#W#@``]PX`'OL.``#[#F`?`@\```(/```"
M#P`'!0\`#`</(``(#P!`"0\>``T/``@.#S@`$0\`P!,/!P`6#P#`&`\``!@/
MP`,<#P``'`\`!!T/.``@#R<`)`^``"4/``@F#Q``)P\``"</```G#P`0*`\`
M`2D/0``J#P``*@\``"H/```J#P`(*P\``"L/"``L#P``+`\``"P/```L#P``
M+`\`""T/```M#P``+0\``"T/```M#P``+0\``"T/```M#P``+0\``"T/```M
M#P``+0\``"T/```M#P``+0\``"T/$``N#P``+@\``"X/```N#P``+@\``"X/
M```N#P``+@\``"X/```N#P``+@\``"X/```N#P``+@\``"X/```N#P``+@\`
M`"X/```N#P``+@\``"X/```N#R0`,`\``#`/```P#P``,`\``#`/```P#P``
M,`\``#`/```P#P``,`]``#$/```Q#P``,0\``#$/```Q#P``,0\``#$/``0R
M#P`$,P\"`#0/```T#P`"-0\``#4/```U#P``-0^``#8/```V#P``-@\``#8/
M```V#P`"-P\``#</$`$Y#P``.0\``#D/(``Z#P``.@\``#H/```Z#P``.@\`
M`#H/```Z#P``.@\``#H/``0[#P``.P\``#L/```[#P(`/`\``#P/```\#P``
M/`\``#P/```\#P``/`\``#P/```\#P``/`\``CT/```]#P``/0\``#T/```]
M#P`$/@\``#X/```^#X``/P\``#\/```_#P`00`\``$`/``!`#P`$00\``$$/
M``!!#P``00\``$$/"`1##P``0P\``$,/`@!$#P``1`\(`$4/``!%#P``10\`
M`$4/``!%#P``10\``$4/``!%#P``10\``$4/``!%#P`01@\``$8/``!&#P``
M1@\``$8/``!&#P``1@\``$8/``!&#P``1@\``$8/(@!(#P``2`\``$@/``!(
M#P``2`\``$@/``!(#P``2`\``$@/`"!)#P``20\!`$H/``!*#P``2@\``$H/
M``!*#P``2@\``$H/``!*#P``2@\@`$L/`@!,#P`(30\``$T/``!-#P``30\`
M`$T/``!-#P``30\``$T/``!-#P@(3P\``$\/`0!0#P``4`\``%`/``!0#P``
M4`\`(%$/``!1#P"`4@\`0%,/``!3#P``4P\``%,/``!3#P``4P\`&%4/``A6
M#P``5@\``%8/``!6#P`!5P\``%</``!7#T`!60\``%D/``!9#P``60\``%D/
M``!9#W``7`\``%P/`(A>#P``7@\``%X/``!>#P``7@\``%X/(`!?#P(`8`\`
M`&`/``!@#S``8@\``&(/``!B#P``8@\``&(/"`!C#P``8P\``&,/``!C#P``
M8P\`@&0/`0!E#P``90\``&4/``!E#P`@9@\``&8/`@!G#P``9P\``&</@`!H
M#P``:`\``&@/``!H#P`":0\``&D/``!I#P`(:@\``&H/`0!K#P``:P\``&L/
M``!K#P``:P\``&L/``!K#P``:P\``&L/``!K#P``:P\``&L/``!K#P``:P\`
M`&L/``!K#P``:P\``&L/``!K#P``:P\`@&P/(`!M#P``;0\``&T/``!M#P``
M;0\$`&X/``!N#P``;@\``&X/``1O#P``;P\``&\/``!O#P``;P\``&\/`$!P
M#P``<`\``'`/``!P#P``<`\``'`/P`!R#P``<@\``'(/(@!T#P``=`\``'0/
M``!T#P`(=0\"`'8/``!V#T``=P\``'</``!W#P``=P^``7D/``!Y#P``>0\`
M`'D/``!Y#P``>0^``'H/``!Z#P``>@\``'H/&0!]#P``?0\``'T/``!]#P``
M?0\``'T/`"!^#P``?@\``'X/0`!_#P``?P\``'\/``!_#P`!@`\``(`/``"`
M#P``@`\``(`/``"`#P``@`\``(`/``"`#P``@`\``(`/``"`#P``@`\``(`/
M``"`#P``@`\``(`/``"`#P``@`\``(`/``"`#P``@`\``(`/"`"!#P``@0\`
M`($/``"!#P``@0\``($/``B"#P``@@\``((/`&"$#P!`A0\``(4/``"%#X`0
MAP\``(</``2(#P``B`\``(@/"`")#P``B0\``(D/`""*#P``B@\``(H/``"*
M#P``B@\$`(L/``"+#S``C0\``(T/``./#P``CP\``(\/@`.2#P``D@\``)(/
M(("4#QX`F`\``)@/``"8#P0`F0\``)D/``:;#P``FP\`.)X/``">#P``G@\$
M`)\/`P"A#P``H0\!!*,/``"C#P``HP\``*,/``"C#P``HP\``*,/``"C#P``
MHP\``*,/``"C#Q``I`\``*0/``"D#T``I0\P0*@/`0"I#P``J0\``*D/``"I
M#P``J0\!`*H/``"J#P0`JP\``*L/``"K#P``JP\``*L/``"K#P``JP\@`*P/
M``"L#P``K`\``*P/``"L#P$`K0\``*T/``2N#P``K@\``*X/``"N#R`2L0\`
M`+$/``"Q#P#@M`\``+0/``"T#P``M`\!`+4/``"U#P``M0\`$+8/`0"W#P``
MMP\``+</@`"X#P``N`\``+@/0""Z#P`$NP\``+L/`("\#P!`O0\``+T/``"]
M#P``O0\!@+\/`(#`#P``P`\``,`/0`#!#P``P0\"`,(/``#"#P0`PP\`$,0/
M!`#%#^`````````````9#H0`&PX``!L.```;#@`H'0X``!T.```=#@``'0X`
M`!T.```=#@``'0X``!T.```=#@``'0X``!T.%"``````HPWX_[`-_P&Y#:``
MNPT``+L-4`R_#0``OPT``+\-``"_#0``OPT``+\-`@#`#0``P`T``,`-``#`
M#0``P`T!$L,-``G%#0``Q0T``,4-`"#&#08BR@T1/-`-9.+7#8!QW`TAJ>(-
M@PGG#9"D[`V8//,-"\'Y#00`^@VD`_\-"```#@````X````.;`0%#@`L"`X`
M0`D.2$8.#B`($`X$`!$.```1#@``$0X``!$.```1#@``$0X``!$.```1#@``
M$0X``!$.```1#@``$0X``!$.```1#@``$0X``!$.```1#@``$0X``!$.```1
M#@$`$@X``!(.```2#@``$@X``!(.```2#@``$@X``!(.```2#@``$@X``!(.
M```2#@``$@X``!(.```2#@``$@X``!(.```2#@``$@Y@;0````#I"P@`Z@L`
M">P+`"#M"P`![@L`$.\+``3P"P``\`L``/`+``#P"Q`&\PL``/,+``#S"R``
M]`L!`/4+``#U"P0B^`M`!OL+``#["P``^PL!`/P+``#\"Q$@_PL`!0$,(@`#
M#`"`!`P```0,```$#``(!0P`,`<,@``(#`"`"0P$1`P,!`@.#``2$`R``!$,
M```1#"!$%`P``!0,``@5#``$%@P$`!<,`0@9#`(`&@R$`!P,`@(>#!``'PP$
M&"(,`P`D#`$`)0P"`"8,(``G#`$`*`P@`"D,```I#`0`*@P``"H,1@(N#%!`
M,0P!`#(,$`@T#`"@-@P@`#<,@@`Y#!4`/`P``#P,```\#$``/0Q``#X,`"%`
M#`$`00R``T0,$`!%#``$1@P``$8,`@!'#```1PQ"`$D,`"!*#```2@P``$H,
M``!*#`!`2PP0P4\,``!/#```3PP``$\,`"!0#`$D4PP0"%4,`$17#$$$6@P`
M`%H,!`%<#``!70P``%T,`@!>#```7@P`$F`,``!@#```8`Q``&$,$`!B#`$$
M9`P`(&4,`4!G#(!`:0P``&D,``!I#"$`:PP`P&T,``!M#```;0P"`&X,"`!O
M#"``<`P`('$,`@!R#`0@=`P"`78,("1Y#```>0R!`'L,0`!\#!``?0P``'T,
M`"1_#``C@@P"&(4,`1"'#`@`B`P"H8P,``",#``@C0Q@*)$,(`"2#```D@R`
M@)0,`@"5#!(`EPP``)<,#"":#&`&G@PB`*`,`$"A#```H0R`@:0,(`BF#!``
MIPP``*<,`0"H#(#`JPR(++`,!`"Q#`(`L@P``+(,``"R#``(LPP``+,,``"S
M#```LPP``+,,``"S#```LPP``+,,``"S#```LPP``+,,``"S#```LPP``+,,
M``*T#`"`M0PCGKT,V];(#(]6T0QCC]H,/?_G#"2^[PRI=/<,_^,$#1AD"0UH
M#0\-K(,6#<O$'@T)%2,-*8HI#61,+PT,H#,-(%0W#:&M/PT2FT8-)$9+#0"#
M3@T('E,-4(A7#02`60WXBV(-U#5J#8V^=`TM2GL-$$!]#20`?PT`@(`-0`"!
M#0"`@@T`$(,-`P"%#040B`T``(@-`B"*#1`2C0T`"(X-`H"0#02`D@T`"),-
M``&4#3!)F0T``)D-``"9#0``F0T`@)H-``2;#0`@G`T``)P-``&=#0``G0T`
M`)T-``"=#0``G0T`()X-``2?#0``GPT``)\-``"?#2``H`V1````````````
M``````````"1`0``D0$``)$!``"1`2``D@$!$)0!``"4`1``E0$(9)D!``"9
M`4@`FP$@@)T!`!">`0(!H`$`@*$!$`"B`0`(HP%``*0!``"D`0``I`$`0*4!
M``"E`0H`IP$"(*D!A0&M`1``K@&``;`!(B"S`0"`M`&B1+D!1"B]`0``O0$.
M2,(!``+#`0`%Q0$((,<!($+*`8!#S@$`@,\!``#/`0`$T`$"`-$!``32`2`4
MU0$C$MH!N@'@`5@@Y`%F`.@!(`#I`0HE[@$`$.\!+##T`0T$^`$)`/H!``#Z
M`02`_`$``/P!``#\`8``_0$!`/X!`$(``@````(````"`````@0)`P(`@`0"
M``(%`@$@!P)``0D"```)`@``"0((``H"```*`@``"@(```H"`0`+`@``"P((
M$`T"`@`.`@``#@(`!`\"``$0`A``$0*``!("!(`4`@`@%0(``!4""``6`@``
M%@(!!AD"!`H<`A(`'@(``1\"```?`@`0(`(D$","`$DF`DH`*0*``2L"``8M
M`A``+@(`""\"A%`S`L``-0(``#4"```U`H``-@(`"#<"`"`X`@``.`(`0#D"
M`0`Z`@4(/0(`0#X"``(_`@0(00(``D("!`!#`@`!1`(!`$4"!AA)`@$`2@)`
M`DP"`@!-`@!03P(4`%$"@"!3`@`05`(<`%<"`"!8`B(!6P(``%L"``!;`@``
M6P(0`%P"``!<`@``7`(``%P"``!<`@``7`(``%P"`"A>`D(080(`B&,"``!C
M`@``8P(((&4"``!E`@0(9P)`4&H"`H!L`@2&<`(@('("((1U`@(`=@(@('@"
M$(!Z`L`P?@(("(`"@`F#`H@PAP)``(@"``"(`@``B`(``(@""0&+`B``C`(`
M`(P"$`"-`@``C0(``(T"`">1`@*!E`*$%)@"PT2>`H8*HP(9E*D"44"M`@``
MK0(``*T"``"M`@``K0((`[`""`"Q`@`0L@(``+(""`"S`@``LP(``+,"`0"T
M`H`0M@(@(+@"``:Z`A``NP(`(+P"``"\`@`"O0(@`+X"B`#``B2$Q`(``,0"
M``#$`@``Q`(``<4"`(C'`@`!R`(`@<H"``#*`@`$RP(80L\"``#/`@``SP($
M`-`"``#0`@``T`*`4-,"`(#4`@``U`(!`-4"``#5`@0`U@(0A-D"``C:`@"`
MVP(``MP"``#<`@(`W0(``-T"``#=`@$`W@(``-X"`03@`@`$X0(`$.("$`#C
M`@``XP(@$N8"``#F`@``Y@(``.8"$!CI`@``Z0(``.D"``CJ`@``Z@(``.H"
M``#J`@!`ZP(``.L"``#K`H``[`(``.P"``3M`@(`[@(`@O`"`"#Q`@0`\@(&
M`/0""`#U`B`@]P(``/<"``#W`@``]P(``/<"``3X`@"`^0(`@/H"!0#\`H$`
M_@(A0`$#`*`#`Q`>"`,0``D#&`H-`T`@#P.`0!$#"*@5`P@`%@,F$!H#!`0<
M`X``'0,@`!X#```>`P``'@,``!X#```>`P``'@,``A\#```?`T"`(0.@`",#
M```C`P``(P,``",#``@D`P``)`,`!"4#`0`F`P``)@,``"8#```F`P"`)P,!
M`"@#```H`R``*0,``"D#"`$K`P``*P,``"L#`$`L`P``+`,``"P#`!`M`P``
M+0,``2X#0``O`T``,`,``#`#(``Q`P`@,@,0`#,#`0@U`P``-0,``#4#@``V
M`P``-@,`(#<#```W`P(`.`,``#@#``@Y`P!@.P,``#L#```[`P$@/0,`(#X#
M"`1``T``00,"0$,#("1&`R!020,@`$H#"@!,`R`$3@,$`$\#``)0`P``4`."
M`%(#``!2`P``4@,`@%,#H`!5`P``50,`@%8#`"!7`Q``6`,@`%D#``!9`P``
M60,``%D#``!9`P``60-``%H#``!:`Q`!7`,``%P#`@!=`Q``7@,`@%\#``!?
M`P`"8`,`$&$#@`!B`P``8@,``&(#`(!C`P5(9P,`0&@#R2!M`P``;0,`8&\#
M`0!P`P``<`,``'`#``!P`Y!`<P,``',#``!S`P!(=0,``'4#``AV`P`@=P,`
M('@#``!X`P``>`,00'H#@0!\`P`@?0,``'T#`B!_`P``?P,``H`#`0"!`P``
M@0,0`((#``""`P``@@,``((#``""`P``@@,"$(0#``"$`P``A`,``(0#``"$
M`P``A`,``(0#$`"%`P`4AP,2%8P#P*"0`P`"D0,`#),#``24`P`!E0.C`IH#
M``6<`P$`G0.`F*$#`$"B`P``H@,`3*4#``&F`P@`IP,`!*@#``.J`X0"K0,D
M"+`#``"P`P``L`,$`+$#``2R`P``L@,$";4#`2"W`P`1N0,``+D#,`"[`P0B
MO@,(`<`#``#``P!`P0,0`,(#``#"`T`!Q`-`$,8#``#&`P(!R`,!`,D#0`#*
M`P``R@,`(,L#`8+.`P(`SP,0$-$#`F#4`P``U`,`"-4#``#5`P``U0-``-8#
M`038`Q`"V@-$`=T#0!3@`X`)XP,\`>@#B(+L`PZ(\0,4(/0#$%#W`R0(^@,`
M@/L#P0#^`Q`0``0````$@`("!`$!!`0(`@8$`(`'!!$$"@02`0T$(`(/!"`0
M$00#`!,$`P`5!``"%@0"`!<$```7!(`0&00,"1T$!$`?!`"@(020(B4$$&`H
M!```*`0(`"D$14\Q!$$`,P0F$#<$!P<]!`$`/@3`0$$$``!!!%@$100*@$@$
M!`!)!``H2P0``$L$`"9.!```3@0@@%`$F%!5!!@`5P04`EH$`#A=!`$$7P0(
M@&$$``!A!`0@8P0(068$*`EJ!`"`:P2``FT$""!O!``*<00.`G4$0`!V!`$`
M=P0``G@$$19]!`(`?@2`08$$`!2#!",(AP0@`(@$`D"*!"\@D`2``)$$"*"4
M!!4@F`0"`)D$`!R<!``.GP0$P*($$H"E!`*"J`0``*@$0`"I!`2@K`0"(*X$
M`0"O!"`@L00``+$$!("S!$P`M@20B+H$@`"[!`#$O@0`)<$$`1##!(($Q@00
M2,D$$`'+!(!@S@1`@-`$`$#1!`@`T@0$`-,$1`#5!``$U@21`-D$`)#;!``2
MW00,`-\$``#?!``&X02`!.,$80CG!``(Z`0`$.D$`0#J!`T([@2T!/,$`H#U
M!```]004`/<$``#W!```]P0@`/@$(`#Y!``"^@00A/T$`!#^!($!`040`@,%
M``($!0"(!@4!`PD%!"@,!00`#062'!,%`"`4!2``%040`A<%"DD<!0)"'P5&
M`2,%0@(F!0,(*04``"D%",`L!0@`+040`"X%!40R!0`@,P4"@#4%``@V!0``
M-@52A#L%```[!4`A/@50$$$%!0!#!0'@1P4`!$@%``!(!0@`206@`$L%``!+
M!0B`304@`$X%&%!2!0D`5`4``%0%``96!0A`6`4``%@%``!8!2``604`5ET%
M``!=!0`$7@4&`&`%`@!A!2""9`4``&0%``!D!2$!9P4`D&D%`$!J!4`!;`7`
M"&\%``!O!1$`<04@2'0%``!T!1`(=@5``G@%`@!Y!8`(>P4``'L%(`!\!0`*
M?@4$`'\%`$"`!0``@`4$`8(%`$"#!0``@P4`A(4%2`"'!0``AP4``(<%`""(
M!0`@B04!`(H%``"*!1`;CP4`<)(%``"2!2``DP4`!)0%`""5!0,0F`4*`)H%
M!`B<!0@`G04``)T%D`"?!0($H040`*(%`(BD!0``I`4``*0%``"D!0``I`4(
M`*4%`@BG!0`$J`4$`*D%``"I!:!`K`4``*P%`$"M!9``KP4(`+`%``"P!8!`
ML@6(`[8%`""W!8`0N04``KH%``"Z!0$@O`4$`+T%`1+`!1&`PP4`(,0%@@#&
M!2`3R@4``,H%@`+,!0&`S@4)!-$%!`#2!0``T@4``-(%``#2!0`0TP6``M4%
M`!#6!0``U@4``=<%``#7!20`V04!(-L%4`#=!0``W04H`-\%((#A!2``X@4`
M`.(%``#B!0`!XP4`0.0%H@#G!0``YP4``.<%$!#I!0""ZP4`".P%``#L!0``
M[`4``NT%`@#N!0)`\`5$`/(%`%GV!8``]P4``/<%``#W!00-^P4``/L%``3\
M!0``_`4"$/X%`"#_!0(```8`@`$&4``#!@$`!`8((`8&H@0*!@``"@8`!`L&
M`L`.!@``#@8Q`!$&`"`2!@"`$P8`*!4&```5!F`#&08``!D&```9!B!`&P8`
M`!L&$@`=!@D`'P8`@"`&```@!@!!(@8(`",&`0`D!A`))P:(`"D&B`@L!@@@
M+@8@0#`&!`0R!A`@-`9(@#<&`&`Y!@``.08``#D&`@`Z!@10/09`0#\&(`!`
M!D``0080`$(&``!"!H8`108``$4&`(!&!@``1@81$$D&`H!+!@``2P;``$T&
M``!-!@!"3P8?(%4&`4A8!@0`60;`0%P&@`1>!F`@808@`&(&``!B!A`!9`8`
M`64&0`!F!D`B:08H!&P&``!L!@``;`8``&P&#P)Q!@`-=`8`$'4&0$!W!D@`
M>08@`'H&D@!]!@P`?P8A!((&`(&$!@0`A08$`(8&`0"'!F(`B@8"`HP&``:.
M!@@8D08`%),&`#B6!@@`EP8@$)D&C`"<!B``G082!*`&!(2C!@`BI0:`"*<&
M)D"K!@`'K@80`;`&``"P!D``L08@`+(&`""S!@``LP8@`+0&``"T!H0`M@8`
M@+<&$`2Y!@(`N@8``+H&``"Z!@``N@8"`+L&`!"\!@($O@8`!+\&``"_!@`0
MP`8``,`&HB;&!@`"QP8`!<D&`$#*!B""S08``,T&`(#.!@2$T08$`-(&`$C4
M!@"`U08`!-8&``#6!F0`V08``-D&4`#;!@``VP8`0-P&@!C?!@``WP8&`.$&
M`H#C!D``Y`8P`.8&`@+H!@``Z`8``.@&``#H!@``Z`84A.P&(`'N!@`&\`8`
M`/`&`(#Q!@$"\P8``/,&0!#U!D`(]P8`!/@&``#X!B`)^P8``/L&`"[_!@0#
M`@<`!`,'$!@&!\``"`<0``D'$"`+!Q``#`=`$`X'```.!Q`"$`<"!!('`*`4
M!P``%`<@2!<'```7!P@&&@<``!H'0`$<!P@`'0<`0!X'`!`?!P``'P<`""`'
M$1`C!X"0)@<@PBH'`HHN!P``+@?I`#,'`#HW!Q$0.@=A@#X'```^!R)`00<@
M`$('`"!#!P`:1@<X2$L'(81/!P(`4`<`"%$'ZE19!P!17`=``5X'#"!A!Y`$
M9`<``&0'`B!F!P`(9P=@`&D'`,)L!^``;P<02'('``!R!P$`<P>A$'<'0`!X
M!P``>`>$@'L'$(!]!P`@?@<$`'\'`""`!P``@`<$`($'``"!!Q0`@P<!`(0'
M`%V)!P`#BP<"@8X'``".!P``C@<2`)`'`("1!P!1E`>`!)8'``"6!P#"F0<A
M`)L'5H"@!X@*I`<``*0'MM*M!P``K0>`$[$'J`.V!T@@N0<A&;X'4`3!!P0P
MQ`<`"L8'$`#'!Q``R`<`$<H'"0#,!X``S0<'`=$'($#3!P!"U0<``-4',`C8
M!T0DW`<J`-\'@6#C!P0$Y0<(8.@'!$#J!P``Z@<2`.P'"`'N!P`0[P<``.\'
M``#O!X0`\0<``/$'`!#R!P`(\P<!X/<'$@#Y!\"`_`=8!``(````"`$``0@B
M``,(@``$"``0!0A```8(```&"```!@@`T`D(`$`*"%`(#0@```T("0`/"``!
M$`@``!`(A`T5"```%0@(`1<(`(`8"`!"&@@H"!T(```="$``'@@00"`(``$A
M"`!1)`@``"0(`#(G")0(*P@:`"X(0``O"``$,`@"(3,(```S"`"`-`A"`S@(
M@``Y"(P!/0@`0#X((P!!"$``0@@``$((`$!#"%P820@``$D(``-+"`0`3`@"
M0$X(R0!2"`*B5@@@`E@(``!8"%`06P@0`%P(!`!="!(`7PA``&`(``!@"``@
M80@`1&,(*`)F"```9@@@`&<(`"!H"`@`:0@"`&H(``!J"`$8;0@,@W(("#QW
M"(0&>P@`0'P(`!A^"!"`@`B``H((``*#"`P`A0@@`(8(!)")"``(B@@``(H(
M!`"+"`P`C0@$`(X(`("/"`$`D`@``)`(`!22"```D@@D")4(``"5""``E@@4
M`)@(0B";"``@G`@16*$(2$"D"``0I0C`4*D(``&J"(0BK@@(!+`(0""R""@2
MM@@``+8(``"V""``MP@``+<(`""X"``DN@@``+H(``"Z"``"NPB``+P($`F_
M"`@`P`@`H,((&1#&"#``R`@@8,L(@`#,"```S`B``,T(``#-"```S0@``,T(
MH$#0"`"`T0@`0-((!(#4"!`0U@@`!-<(@(#9"`"`V@@``-H(``#:"$``VP@`
M`-L(``#;"(``W`B#0N$(#`#C"```XP@"`>4(`(#F"(@`Z`@(0.H($`#K"```
MZP@`(.P(@`#M"``$[@@$`?`(`"#Q""'`]0@"&/@(``#X"!`(^@A.`/X(``#^
M"`$`_P@`@``)@``!"<`P!0E```8)```&"0`2"`E```D)B%(."90$$@D`!!,)
ME``6"00!&`E`!AL)`"`<"0`0'0D0`!X)"``?"2`$(0E``"()`@$D"0``)`D0
M@"8)0``G"0``)PD`!2D)0"(L"0!`+0D``"T)$``N"20`,`E`#C0)@``U"0``
M-0E`!#<)```W"1"$.@D!`3P)!$`^"8"P0@D`"$,)`"5&"0``1@D`($<)``!'
M"8``2`E,@$P)``!,"2``30D"$$\)`!!0"0!"4@D`(%,)"`!4"0`@50D``%4)
M(`!6"5`16@E30%\)`$!@"0`%8@DH$68)%`!H"0:`:PD!`6T)3`!P"0@@<@D`
M8'0)``!T"0!$=@DV`'H)``%["2@`?0D!`'X)``!^"1@!@0D$&(0)!`2&"0"`
MAPD)`(D)``")"0``B0D``(D)``")"0(`B@D``(H)`4","0`0C0D$((\)40"2
M"0"!E`D``)0))`"6"0``E@D`$)<)!$"9"0``F0D$`)H)`2"<"00`G0D``)T)
M``"="0"`G@D``)X)``">"0``G@D``9\)``"?"0``GPD``)\)``"?"0,@H@E`
M&*4)``"E"2`"IPD"`*@)`D"J"4`$K`D`0*T)(`"N"1"`L`D``;$)@""S"0``
MLPED@+<)`$"X"3%`O`D``+P)D`"^"0`0OPD!0,$),(#$":"`QPD``,<)0`#(
M"2"`R@D!`,L)``#+"1``S`D``,P)B"#/"1``T`D@`-$)@`#2"8$&U@D2`-@)
MH`+;"0`0W`E"`-X)``#>"8``WPD``-\)``#?"0`0X`D`"N()`"'D"0`"Y0D`
M`.4)@`#F"0!`YPD``.<)$1#J"0""[`D0`.T)``#M"0`$[@D`!.\)``#O"0`0
M\`D`@/$)`"#R"0"`\PD(,/8)`$#W"00"^0D``/D)`@#Z"0$(_`D!`/T)`$#^
M"0``_@D``/X)!`#_"0``_PD``/\)``#_"0``_PD``/\)``#_"0(```H````*
M````"@````H`B`(*`"`#"@```PH`(`0*4`@'"@`*"0J$``L*"!@."@8Q$PH`
M`!,*```3"@``$PH``!,*```3"@`$%`H$`!4*```5"D`"%PH``!<*"0`9"A``
M&@H``!H*```:"@)`'`H``!P*`"4?"@`$(`I`@"(*```B"@`!(PJB0"<*`0`H
M"@``*`J`("H*01`M"@A`+PH`!#`*%"`S"@0`-`H``#0*``(U"@`@-@H!`#<*
M`@0Y"@`0.@K`0#T*```]"@``/0H(`#X*(0!`"NA?2@H"%$T*`01/"@``3PH`
M`E`*``%1"@0`4@H``%(*B`!4"@`050I``%8*$A!9"@``60H``%D*``!9"@!!
M6PH`"%P*$`!="@``70H``%T*``!="@``70H``%T*``!="@``70H``%T*`E)A
M"H``8@I!$&4*`%!G"@``9PH``F@*0`AJ"A``:PI`@&T*(`!N"@!$<`H`07(*
M"`!S"@`-=@H@$'@*$@!Z"B"A?@H$2($*@`"""A*"A@H``(8*`$"'"@+&C`H`
M`(P*$`B."B@8D@I<()<*B`"9"@``F0H`$)H*`P"<"C\!HPH`@*0*1$NJ"A@A
MK@KR`+,*`1"U"@$@MPH`J;L*0`B]"@@(OPH!`,`*"P##"A(!Q@J`*,D*\"#.
M"@!`SPH,(-(*$`G5"J`0V`H`"MH*(`#;"@"`W`H$`-T*``#="@H`WPH`$.`*
M``#@"D``X0H``.$*``#A"@`@X@H``.(*@`#C"@``XPH``.,*`('E"B``Y@K`
M`ND*Q03N"@``[@H``.X*``#N"@`![PH0`/`*``#P"@`@\0H``/$*"`'S"B(`
M]0I``/8*``+W"@`(^`H"@/H*0`#["B@`_0I`(/\*``#_"@``_PH``/\*$```
M"P@``0L`"`(+`@`#"T(`!0L#``<+@J`+"P`@#`L"``T+@`(/"P"($0L``!$+
M%F48"P4!&PL$`!P+04`?"R0`(0L``"$+,(`D"PA`)@L8`"@+@`@J"P``*@M`
M$"P+(``M"P``+0L``"T+```M"Y`",`N(134+`%`W"T,0.PLB`#T+`$`^"P`2
M0`L``$`+@`M$"P4D2`L`($D+#`!+"P``2PL``$L+``A,"Q`$3@L`$5`+,`!2
M"P`$4PM"`%4+(`!6"P`05PL!@%D+0H!<"P`87@L``%X+`!%@"P@08@L``&(+
M`(!C"P``8PL``&,+1"1G"P``9PN``&@+!0!J"Q"`;`L$@F\+$`!P"P`D<@L0
M`G0+`0!U"P$`=@L``G<+`(!X"PKH?@N`H($+``"!"P$`@@L`@(,+`""$"P`B
MA@L2@(D+!!2,"R&(D`M!@),+(`25"R"`EPL(()D+``"9"P08G`L``)P+``"<
M"P``G`L``)P+``"<"P``G`L``)P+``"<"P00G@M``)\+`@"@"Q`"H@L00J4+
M`4"G"P!@J0L`4*L+"`"L"P@`K0L@"*\+`""P"Q$"LPL0`+0+``"T"P`0M0L`
M5+@+`)&["P``NPL``+L+``"["P``NPL``+L+``B\"S(`OPMA0<0+1)W+"P*@
MS@O2`-(+``#2"P0`TPL"0=8+!`'8"X``V0O``-L+``+<"S``W@L)!.$+!`+C
M"P"`Y`L`0.4+`)+H"R``D`$``)`!``"0`0``D`$"``````#`````P````,``
M``#`````P````,````#`````P````,``T37(`"`PRP"@5-``0%#3`$"TV`#`
M0-L`"`#<````W````-P```#<````W``(`-T```#=````W0```-T```#=````
MW0```-T```#=````W0```-T```#=````W0```-T`X`#@````X````.````#@
M`/[_[P#___\`__\/`?__'P'__R\!#W@W`?[_1@'__U8!__]F`?__=@'__X8!
M?W"_````OP```+\```"_```@`````````````````````(H```"*````B@``
M`(H```"*````B@```(H`_P.4`/`_G@```)X```">````G@```)X```">````
MG@```)X```">````G@```)X```">````G@```)X`__^N`/__O@`!`'L```![
M`$``?``"`'T```!]````?0```'T```!]`/\#AP```(<```"'````AP```XD`
M``")````B0"```````!W````=P```'<```!W````=P```'<```!W````=P``
M`'<```!W````=P```'<``,!Y``,`-0`"`#8`__]&`/__5@#__V8`__]V``(`
M````````````````````````````````````````````````````````````
M`````````````````````````0$````!``,'!@`,``@``S</``P7%0`#`!<`
M#`P;```('````!P``#@?``@`(```""$````A````(0```"$````A````(0``
M8",`5Q4K````*P```"L````K````*P```"L````K````*P`3""\``@0Q`"``
M,@`(!#0````T````-````#0`0`````````````````!"3EQ.]5$:4X)3!TX,
M3D=.C4[75@SZ;EQS7P].AU$.3BY.DT["3LE.R$Z84?Q2;%.Y4R!7`UDL61!<
M_UWA9;-KS&L4;#]R,4X\3NA.W$[I3N%.W4[:3@Q2'%-,4R)7(U<762]9@5N$
M6Q)<.UQT7'-<!%Z`7H)>R5\)8E!B%6PV;$-L/VP[;*YRL'**<[AYBH`>E@Y/
M&$\L3_5.%$_Q3@!/]TX(3QU/`D\%3R)/$T\$3_1.$D^Q41-2"5(04J92(E,?
M4TU3BE,'5.%6WU8N5RI7-%<\68!9?%F%67M9?EEW67]95EL57"5<?%QZ7'M<
M?ES?775>A%X"7QI?=%_57]1?SU]<8EYB9&)A8F9B8F)98F!B6F)E8N]E[F4^
M9SEG.&<[9SIG/V<\9S-G&&Q&;%)L7&Q/;$IL5&Q+;$QL<7!><K1RM7*.<RIU
M?W9U>E%_>()\@H""?8)_@DV&?HF9D)>0F)";D)20(I8DEB"6(Y963SM/8D])
M3U-/9$\^3V=/4D]?3T%/6$\M3S-//T]A3X]1N5$<4AY2(5*M4JY2"5-C4W)3
MCE./4S!4-U0J5%1415095!Q4)5085#U43U1!5"A4)%1'5.Y6YU;E5D%715=,
M5TE72U=25P990%FF69A9H%F768Y9HEF068]9IUFA68Y;DELH7"I<C5R/7(A<
MBUR)7))<BER&7)-<E5S@70I>#EZ+7HE>C%Z(7HU>!5\=7WA?=E_27]%?T%_M
M7^A?[E_S7^%?Y%_C7_I?[U_W7_M?`&#T7SIB@V*,8HYBCV*48H=B<6)[8GIB
M<&*!8HAB=V)]8G)B=&(W9?!E]&7S9?)E]65%9T=G66=59TQG2&==9TUG6F=+
M9]!K&6P:;'AL9VQK;(1LBVR/;'%L;VQI;)IL;6R';)5LG&QF;'-L96Q[;(YL
M='!Z<&-ROW*]<L-RQG+!<KIRQ7*5<Y=SDW.4<Y)S.G4Y=91UE76!=CUY-("5
M@)F`D("2@)R`D(*/@H6"CH*1@I."BH*#@H2">(S)C[^/GY"AD*60GI"GD*"0
M,)8HEB^6+98S3IA/?$^%3WU/@$^'3W9/=$^)3X1/=T],3Y=/:D^:3WE/@4]X
M3Y!/G$^43YY/DD^"3Y5/:T]N3YY1O%&^4352,E(S4D92,5*\4@I3"U,\4Y)3
ME%.'5']4@5215()4B%1K5'I4?E1E5&Q4=%1F5(U4;U1A5&!4F%1C5&=49%3W
M5OE6;U=R5VU7:U=Q5W!7=E>`5W57>U=S5W178E=H5WU7#%E%6;59NEG/6<Y9
MLEG,6<%9MEF\6<-9UEFQ6;U9P%G(6;19QUEB6V5;DUN56T1<1URN7*1<H%RU
M7*]<J%RL7)]<HURM7*)<JERG7)U<I5RV7+!<IEP77A1>&5XH7R)?(U\D7U1?
M@E]^7WU?WE_E7RU@)F`98#)@"V`T8`I@%V`S8!I@'F`L8")@#6`08"Y@$V`1
M8`Q@"6`<8!1B/6*M8K1BT6*^8JIBMF+*8JYBLV*O8KMBJ6*P8KAB/66H9;ME
M"6;\901F$F8(9OME`V8+9@UF!6;]91%F$&;V9@IGA6=L9XYGDF=V9WMGF&>&
M9X1G=&>-9XQG>F>?9Y%GF6>#9WUG@6=X9WEGE&<E:X!K?FO>:QULDVSL;.ML
M[FS9;+9LU&RM;.=LMVS0;,)LNFS#;,9L[6SR;-)LW6RT;(ILG6R`;-YLP&PP
M;<ULQVRP;/ELSVSI;-%LE'"8<(5PDW"&<(1PD7"6<()PFG"#<&IRUG++<MAR
MR7+<<M)RU'+:<LQRT7*D<Z%SK7.F<Z)SH'.L<YUSW73H=#]U0'4^=8QUF'6O
M=O-V\7;P=O5V^'?\=_EW^W?Z=_=W0GD_><5Y>'I[>OMZ=7S]?#6`CX"N@*.`
MN("U@*V`((*@@L""JX*:@IB"FX*U@J>"KH*\@IZ"NH*T@JB"H8*I@L*"I(+#
M@K:"HH)PAF^&;89NAE:,TH_+C]./S8_6C]6/UX^RD+20KY"SD+"0.98]ECR6
M.I9#ELU/Q4_33[)/R4_+3\%/U$_<3]E/NT^S3]M/QT_63[I/P$^Y3^Q/1%))
M4L!2PE(]4WQ3EU.64YE3F%.Z5*%4K52E5,]4PU0-@[=4KE365+94Q53&5*!4
M<%2\5*)4OE1R5-Y4L%2U5YY7GU>D5XQ7EU>=5YM7E%>85X]7F5>E5YI7E5?T
M6`U94UGA6=Y9[ED`6O%9W5GZ6?U9_%GV6>19\EGW6=M9Z5GS6?59X%G^6?19
M[5FH6TQ<T%S87,Q<UUS+7-M<WES:7,E<QUS*7-9<TUS47,]<R%S&7,Y<WUSX
M7/E=(5XB7B->(%XD7K!>I%ZB7IM>HUZE7@=?+E]67X9?-V`Y8%1@<F!>8$5@
M4V!'8$E@6V!,8$!@0F!?8"1@1&!88&9@;F!"8D-BSV(-8PMC]6(.8P-CZV+Y
M8@]C#&/X8O9B`&,38Q1C^F(58_MB\&)!94-EJF6_939F(68R9C5F'&8F9B)F
M,V8K9CIF'68T9CEF+F8/9Q!GP6?R9\AGNF?<9[MG^&?89\!GMV?%9^MGY&??
M9[5GS6>S9_=G]F?N9^-GPF>Y9\YGYV?P9[)G_&?&9^UGS&>N9^9GVV?Z9\EG
MRF?#9^IGRV<H:X)KA&NV:]9KV&O@:R!L(6PH;31M+6T?;3QM/VT2;0IMVFPS
M;01M&6TZ;1IM$6T`;1UM0FT!;1AM-VT#;0]M0&T';2!M+&T(;2)M"6T0;;=P
MGW"^<+%PL'"A<+1PM7"I<$%R27)*<FQR<')S<FYRRG+D<NARZW+?<NIRYG+C
M<H5SS'/"<\ASQ7.Y<[9SM7.T<^MSOW/'<[YSPW/&<[ASRW/L=.YT+G5'=4AU
MIW6J=7EVQ'8(=P-W!'<%=PIW]W;[=OIVYW?H=P9X$7@2>`5X$'@/>`YX"7@#
M>!-X2GE,>4MY17E$>=5YS7G/>=9YSGF`>GYZT7H`>P%[>GQX?'E\?WR`?(%\
M`WT(?0%]6'^1?XU_OG\'@`Z`#X`4@#>`V(#'@."`T8#(@,*`T(#%@..`V8#<
M@,J`U8#)@,^`UX#F@,V`_X$A@I2"V8+^@OF"!X/H@@"#U8(Z@^N"UH+T@NR"
MX8+R@O6"#(/[@O:"\(+J@N2"X(+Z@O."[8)WAG2&?(9SAD&(3HAGB&J(:8C3
MB02*!XIRC>./X8_NC^"/\9"]D+^0U9#%D+Z0QY#+D,B0U)'3D5263Y91EE.6
M2I9.EAY0!5`'4!-0(E`P4!M0]4_T3S-0-U`L4/9/]T\74!Q0(%`G4#50+U`Q
M4`Y06E&449-1RE'$4<51R%'.46%26E)24EY27U)54F)2S5(.4YY3)E7B5!=5
M$E7G5/-4Y%0:5?]4!%4(5>M4$54%5?%4"E7[5/=4^%3@5`Y5`U4+50%7`E?,
M5S)8U5?25[I7QE>]5[Q7N%>V5[]7QU?05[E7P5<.64I9&5H66BU:+EH56@]:
M%UH*6AY:,UIL6Z=;K5NL6P-<5EQ47.Q<_USN7/%<]UP`7?E<*5XH7JA>KEZJ
M7JQ>,U\P7V=?76!:8&=@06"B8(A@@&"28(%@G6"#8)5@FV"78(=@G&".8!EB
M1F+R8A!C5F,L8T1C16,V8T-CY&,Y8TMC2F,\8REC06,T8UAC5&-98RUC1V,S
M8UIC46,X8U=C0&-(8TIE1F7&9<-EQ&7"94IF7V9'9E%F$F<39Q]H&FA):#)H
M,V@[:$MH3V@6:#%H'&@U:"MH+6@O:$YH1&@T:!UH$F@4:"9H*&@N:$UH.F@E
M:"!H+&LO:RUK,6LT:VUK@H"(:^9KY&OH:^-KXFOG:R5L>FUC;61M=FT-;6%M
MDFU8;6)M;6UO;9%MC6WO;7]MAFU>;6=M8&V7;7!M?&U?;8)MF&TO;6AMBVU^
M;8!MA&T6;8-M>VU];75MD&W<<--PT7#=<,MP.7_B<-=PTG#><.!PU'#-<,5P
MQG#'<-IPSG#A<$)R>')W<G9R`'/Z<O1R_G+V<O-R^W(!<]-SV7/E<]9SO'/G
M<^-SZ7/<<])SVW/4<]USVG/7<]ASZ'/>=-]T]'3U="%U6W5?=;!UP76[=<1U
MP'6_=;9UNG6*=LEV'7<;=Q!W$W<2=R-W$7<5=QEW&G<B=R=W(W@L>")X-7@O
M>"AX+G@K>"%X*7@S>"IX,7A4>5MY3WE<>5-Y4GE1>>MY['G@>>YY[7GJ>=QY
MWGG=>89ZB7J%>HMZC'J*>H=ZV'H0>P1[$WL%>P]["'L*>PY["7L2>X1\D7R*
M?(Q\B'R-?(5\'GT=?1%]#GT8?19]$WT??1)]#WT,?5Q_87]>?V!_77];?Y9_
MDG_#?\)_P'\6@#Z`.8#Z@/*`^8#U@`&!^X``@0&"+X(E@C.#+8-$@QF#48,E
M@U:#/X-!@R:#'(,B@T*#3H,;@RJ#"(,\@TV#%H,D@R"#-X,O@RF#1X-%@TR#
M4X,>@RR#2X,G@TB#4X92AJ*&J(:6AHV&D8:>AH>&EX:&AHN&FH:%AJ6&F8:A
MAJ>&E8:8AHZ&G8:0AI2&0XA$B&V(=8AVB'*(@(AQB'^(;XB#B'Z(=(A\B!**
M1XQ7C'N,I(RCC':->(VUC;>-MHW1CM.._H_UCP*0_X_[CP20_(_VC]:0X)#9
MD-J0XY#?D.60V)#;D->0W)#DD%"13I%/D=61XI':D5R67Y:\EN.8WYHOFW].
M<%!J4&%07E!@4%-02U!=4')02%!-4$%06U!*4&)0%5!%4%]0:5!K4&-09%!&
M4$!0;E!S4%=045#046M2;5)L4FY2UE+34BU3G%-U5795/%5-55!5-%4J55%5
M8E4V5355,%525455#%4R56553E4Y54A5+54[54!52U4*5P=7^U<46.)7]E?<
M5_17`%CM5_U7"%CX5PM8\U?/5P=8[E?C5_)7Y5?L5^%7#EC\5Q!8YU<!6`Q8
M\5?I5_!7#5@$6%Q98%I86E5:9UI>6CA:-5IM6E!:7UIE6FQ:4UID6E=:0UI=
M6E):1%I;6DA:CEH^6DU:.5I,6G!::5I'6E%:5EI"6EQ:<EMN6\%;P%M97!Y=
M"UT=71I=(%T,72A=#5TF725=#UTP71)=(UT?72Y=/EXT7K%>M%ZY7K)>LUXV
M7SA?FU^67Y]?BF"08(9@OF"P8+I@TV#48,]@Y&#98-U@R&"Q8-M@MV#*8+]@
MPV#-8,!@,F-E8XIC@F-]8[UCGF.M8YUCEV.K8XYC;V.'8Y!C;F.O8W5CG&-M
M8ZYC?&.D8SMCGV-X8X5C@6.18XUC<&-39<UE969A9EMF669<9F)F&&=Y:(=H
MD&B<:&UH;FBN:*MH5FEO:*-HK&BI:'5H=&BR:(]H=VB2:'QH:VAR:*IH@&AQ
M:'YHFVB6:(MHH&B):*1H>&A[:)%HC&B*:'UH-FLS:S=K.&N1:X]KC6N.:XQK
M*FS`;:MMM&VS;71NK&WI;>)MMVWV;=1M`&[(;>!MWVW6;;YMY6W<;=UMVVWT
M;<IMO6WM;?!MNFW5;<)MSVW);=!M\FW3;?UMUVW-;>-MNVWZ<`UQ]W`7<?1P
M#''P<`1Q\W`0<?QP_W`&<1-Q`''X</9P"W$"<0YQ?G)[<GQR?W(=<Q=S!W,1
M<QAS"G,(<_]R#W,><XAS]G/X<_5S!'0!=/US!W0`=/IS_'/_<PQT"W3T<PAT
M9'5C=<YUTG7/=<MUS'71==!UCW:)=M-V.7<O=RUW,7<R=S1W,W<]=R5W.W<U
M=TAX4GA)>$UX2GA,>"9X17A0>&1Y9WEI>6IY8WEK>6%YNWGZ>?AY]GGW>8]Z
ME'J0>C5[1WLT>R5[,'LB>R1[,WL8>RI['7LQ>RM[+7LO>S)[.'L:>R-[E'R8
M?)9\HWPU?3U].'TV?3I]17TL?2E]07U'?3Y]/WU*?3M]*'UC?Y5_G'^=?YM_
MRG_+?\U_T'_1?\=_SW_)?Q^`'H`;@$>`0X!(@!B!)8$9@1N!+8$?@2R!'H$A
M@16!)X$=@2*!$8(X@C.".H(T@C*"=(*0@Z.#J(.-@WJ#<X.D@W2#CX.!@Y6#
MF8-U@Y2#J8-]@X.#C(.=@YN#JH.+@WZ#I8.O@XB#EX.P@W^#IH.'@ZZ#=H.:
M@UF&5H:_AK>&PH;!AL6&NH:PALB&N8:SAKB&S(:TAKN&O(;#AKV&OH92B(F(
ME8BHB**(JHB:B)&(H8B?B)B(IXB9B)N(EXBDB*R(C(B3B(Z(@HG6B=F)U8DP
MBB>*+(H>BCF,.XQ<C%V,?8REC'V->XUYC;R-PHVYC;^-P8W8CMZ.W8[<CM>.
MX([ACB20"Y`1D!R0#)`AD.^0ZI#PD/20\I#SD-20ZY#LD.F05I%8D5J14Y%5
MD>R1])'QD?.1^)'DD?F1ZI'KD?>1Z)'ND7J5AI6(E7R6;99KEG&6;Y:_EFJ7
M!)CEF)>9FU"54)10GE"+4*-0@U",4(Y0G5!H4)Q0DE""4(=07U'441)3$5.D
M4Z=3D56H5:55K55W5456HE6358A5CU6U58%5HU625:15?56,5:95?U655:%5
MCE4,5RE8-U@96!Y8)U@C6"A8]5=(6"58'%@;6#-8/U@V6"Y8.5@X6"U8+%@[
M6&%9KUJ46I]:>EJB6IY:>%JF6GQ:I5JL6I5:KEHW6H1:BEJ76H-:BUJI6GM:
M?5J,6IQ:CUJ36IU:ZEO-6\M;U%O16\I;SEL,7#!<-UU#76M=05U+73]=-5U1
M74Y=55TS73I=4ET]73%=65U"73E=25TX73Q=,ETV74!=15U$7D%>6%^F7Z5?
MJU_)8+E@S&#B8,Y@Q&`48?)@"F$6805A]6`38?A@_&#^8,%@`V$881UA$&'_
M8`1A"V%*8I1CL6.P8\YCY6/H8^]CPV.=9/-CRF/@8_9CU6/R8_5C863?8[YC
MW6/<8\1CV&/38\)CQV/,8\MCR&/P8]=CV6,R96=E:F5D95QE:&5E98QEG66>
M9:YET&7297QF;&9[9H!F<69Y9FIF<F8!9PQITV@$:=QH*FGL:.IH\6@/:=9H
M]VCK:.1H]F@3:1!I\VCA:`=IS&@(:7!IM&@1:>]HQF@4:?AHT&C]:/QHZ&@+
M:0II%VG.:,AHW6C>:.9H]&C1:`9IU&CI:!5I)6G':#EK.VL_:SQKE&N7:YEK
ME6N]:_!K\FOS:S!L_&U&;D=N'VY);HAN/&X];D5N8FXK;C]N06Y=;G-N'&XS
M;DMN0&Y1;CMN`VXN;EYN:&Y<;F%N,6XH;F!N<6YK;CEN(FXP;E-N96XG;GAN
M9&YW;E5N>6Y2;F9N-6XV;EIN('$><2]Q^W`N<3%Q(W$E<2)Q,G$?<2AQ.G$;
M<4MR6G*(<HERAG*%<HMR$G,+<S!S(G,Q<S-S)W,R<RUS)G,C<S5S#',N="QT
M,'0K=!9T&G0A="UT,70D="-T'70I="!T,G3[="]U;W5L=>=UVG7A=>9UW77?
M=>1UUW65=I)VVG9&=T=W1'=-=T5W2G=.=TMW3'?>=^QW8'AD>&5X7'AM>'%X
M:GAN>'!X:7AH>%YX8GAT>7-Y<GEP>0)Z"GH#>@QZ!'J9>N9ZY'I*>SM[1'M(
M>TQ[3GM`>UA[17NB?)Y\J'RA?%A];WUC?5-]5GUG?6I]3WUM?5Q]:WU2?51]
M:7U1?5]]3GT^?S]_97]F?Z)_H'^A?]=_48!/@%"`_H#4@$.!2H%2@4^!1X$]
M@4V!.H'F@>Z!]X'X@?F!!((\@CV"/X)U@CN#SX/Y@R.$P(/H@Q*$YX/D@_R#
M]H,0A,:#R(/K@^.#OX,!A-V#Y8/8@_^#X8/+@\Z#UH/U@\F#"80/A-Z#$80&
MA,*#\X/5@_J#QX/1@^J#$X3#@^R#[H/$@_N#UX/B@QN$VX/^@]B&XH;FAM.&
MXX;:ANJ&W8;KAMR&[(;IAM>&Z(;1ADB(5HA5B+J(UXBYB+B(P(B^B+:(O(BW
MB+V(LH@!B<F(E8F8B9>)W8G:B=N)3HI-BCF*68I`BE>*6(I$BD6*4HI(BE&*
M2HI,BD^*7XR!C(",NHR^C+",N8RUC(2-@(V)C=B-TXW-C<>-UHW<C<^-U8W9
MC<B-UXW%C>^.]X[ZCOF.YH[NCN6.]8[GCNB.]H[KCO&.[([TCNF.+9`TD"^0
M!I$LD021_Y#\D`B1^9#[D`&1`)$'D061`Y%AD6217Y%BD6"1`9(*DB62`Y(:
MDB:2#Y(,D@"2$I+_D?V1!I($DB>2`I(<DB22&9(7D@62%I)[E8V5C)60E8>6
M?I:(EHF6@Y:`EL*6R);#EO&6\)9LEW"7;I<'F*F8ZYCFG/F>@TZ$3K9.O5"_
M4,90KE#$4,I0M%#(4,)0L%#!4+I0L5#+4,E0ME"X4-=1>E)X4GM2?%+#5=M5
MS%705<M5RE7=5<!5U%7$5>E5OU7258U5SU755>)5UE7(5?)5S5795<)5%%=3
M6&A89%A/6$U825AO6%583EA=6%E895A;6#U88UAQ6/Q8QUK$6LM:NEJX6K%:
MM5JP6K]:R%J[6L9:MUK`6LI:M%JV6LU:N5J06M9;V%O96Q]<,UQQ76-=2EUE
M77)=;%U>76A=9UUB7?!=3UY.7DI>35Y+7L5>S%[&7LM>QUY`7Z]?K5_W8$EA
M2F$K845A-F$R82YA1F$O84]A*6%`82!B:)$C8B5B)&+%8_%CZV,09!)D"60@
M9"1D,V1#9!]D%6089#ED-V0B9"-D#&0F9#!D*&1!9#5D+V0*9!ID0&0E9"=D
M"V3G8QMD+F0A9`YD;V629=-EAF:,9I5FD&:+9HIFF6:49GAF(&=F:5]I.&E.
M:6)I<6D_:45I:FDY:4)I5VE9:7II2&E):35I;&DS:3UI96GP:'AI-&EI:4!I
M;VE$:79I6&E!:71I3&D[:4MI-VE<:4]I46DR:5)I+VE[:3QI1FM%:T-K0FM(
M:T%KFVL-^OMK_&OY:_=K^&N;;M9NR&Z/;L!NGVZ3;I1NH&ZQ;KENQF[2;KUN
MP6Z>;LENMVZP;LUNIF[/;K)NOF[#;MQNV&Z9;I)NCFZ-;J1NH6Z_;K-NT&[*
M;I=NKFZC;D=Q5'%2<6-Q8'%!<5UQ8G%R<7AQ:G%A<4)Q6'%#<4MQ<'%?<5!Q
M4W%$<4UQ6G%/<HURC'*1<I!RCG(\<T)S.W,Z<T!S2G-)<T1T2G1+=%)T4717
M=$!T3W10=$YT0G1&=$UT5'3A=/]T_G3]=!UU>75W=8-I[W4/=@-V]W7^=?QU
M^77X=1!V^W7V=>UU]77]=9EVM7;==E5W7W=@=U)W5G=:=VEW9W=4=UEW;7?@
M=X=XFGB4>(]XA'B5>(5XAGBA>(-X>7B9>(!XEGA[>'QY@GE]>7EY$7H8>AEZ
M$GH7>A5Z(GH3>AMZ$'JC>J)ZGGKK>F9[9'MM>W1[:7MR>V5[<WMQ>W![87MX
M>W9[8WNR?+1\KWR(?89]@'V-?7]]A7UZ?8Y]>WV#?7Q]C'V4?81]?7V2?6U_
M:W]G?VA_;'^F?Z5_IW_;?]Q_(8!D@6"!=X%<@6F!6X%B@7*!(6=>@7:!9X%O
M@42!88$=@DF"1()`@D*"18+QA#^$5H1VA'F$CX2-A&6$481`A(:$9X0PA$V$
M?81:A%F$=(1SA%V$!X5>A#>$.H0TA'J$0X1XA#*$180IA-F#2X0OA$*$+81?
MA'"$.81.A$R$4H1OA,6$CH0[A$>$-H0SA&B$?H1$A"N$8(14A&Z$4(0+AP2'
M]X8,A_J&UH;UADV'^(8.APF'`8?VA@V'!8?6B,N(S8C.B-Z(VXC:B,R(T(B%
MB9N)WXGEB>2)X8G@B>*)W(GFB7:*AHI_BF&*/XIWBH**A(IUBH.*@8ITBGJ*
M/(Q+C$J,98QDC&:,AHR$C(6,S(QHC6F-D8V,C8Z-CXV-C9.-E(V0C9*-\(W@
MC>R-\8WNC="-Z8WCC>*-YXWRC>N-](T&C_^.`8\`CP6/!X\(CP*/"X]2D#^0
M1)!)D#V0$)$-D0^1$9$6D121"Y$.D6Z1;Y%(DE*2,)(ZDF:2,Y)EDEZ2@Y(N
MDDJ21I)MDFR23Y)@DF>2;Y(VDF&2<)(QDE228Y)0DG*23I)3DDR25I(RDI^5
MG)6>E9N5DI:3EI&6EY;.EOJ6_9;XEO66<Y=WEWB7<I</F`V8#IBLF/:8^9BO
MF;*9L)FUF:V:JYI;F^J<[9SGG(">_9[F4-10UU#H4/-0VU#J4-U0Y%#34.Q0
M\%#O4.-0X%#848!2@5+I4NM2,%.L4R=6%58,5A)6_%4/5AQ6`5835@)6^E4=
M5@16_U7Y58E8?%B06)A8AEB!6']8=%B+6'I8AUB16(Y8=EB"6(A8>UB46(]8
M_EAK6=Q:[EKE6M5:ZEK:6NU:ZUKS6N):X%K;6NQ:WEK=6ME:Z%K?6G=;X%OC
M6V-<@EV`77U=AEUZ78%==UV*78E=B%U^77Q=C5UY77]=6%Y97E->V%[17M=>
MSE[<7M5>V5[27M1>1%]#7V]?ME\L82AA06%>87%A<V%285-A<F%L88!A=&%4
M87IA6V%E83MA:F%A859A*6(G8BMB*V1-9%MD761T9'9D<F1S9'UD=61F9*9D
M3F2"9%YD7&1+9%-D8&109']D/V1L9&MD661E9'=D<V6@9:%FH&:?9@5G!&<B
M9[%IMFG)::!ISFF6:;!IK&F\:9%IF6F.::=IC6FI:;YIKVF_:<1IO6FD:=1I
MN6G*:9IISVFS:9-IJFFA:9YIV6F7:9!IPFFU::5IQFE*:TUK2VN>:Y]KH&O#
M:\1K_FO.;O5N\6X#;R5O^&XW;_MN+F\);TYO&6\:;R=O&&\[;Q)O[6X*;S9O
M<V_Y;NYN+6]`;S!O/&\U;^MN!V\.;T-O!6_];O9N.6\<;_QN.F\?;PUO'F\(
M;R%OAW&0<8EQ@'&%<8)QCW%[<89Q@7&7<41R4W*7<I5RDW)#<TUS47-,<V)T
M<W1Q='5T<G1G=&YT`'4"=0-U?760=19V"'8,=A5V$78*=A1VN':!=WQWA7>"
M=VYW@'=O=WYW@W>R>*IXM'BM>*AX?GBK>)YXI7B@>*QXHGBD>)AYBGF+>99Y
ME7F4>9-YEWF(>9)YD'DK>DIZ,'HO>BAZ)GJH>JMZK'KN>HA[G'N*>Y%[D'N6
M>XU[C'N;>XY[A7N8>X12F7ND>X)[NWR_?+Q\NGRG?;=]PGVC?:I]P7W`?<5]
MG7W.?<1]QGW+?<Q]KWVY?99]O'V??:9]KGVI?:%]R7US?^)_XW_E?]Y_)(!=
M@%R`B8&&@8.!AX&-@8R!BX$5@I>$I(2AA)^$NH3.A,*$K(2NA*N$N82TA,&$
MS82JA)J$L830A)V$IX2[A**$E(3'A,R$FX2IA*^$J(36A)B$MH3/A*"$UX34
MA-*$VX2PA)&$888SAR.'*(=KAT"'+H<>AR&'&8<;AT.'+(=!ASZ'1H<@AS*'
M*H<MASR'$H<ZAS&'-8="AR:')X<XAR2'&H<PAQ&']XCGB/&(\HCZB/Z([HC\
MB/:(^XCPB.R(ZXB=B:&)GXF>B>F)ZXGHB:N*F8J+BI**CXJ6BCV,:(QIC-6,
MSXS7C):-"8X"CO^-#8[]C0J.`XX'C@:.!8[^C0".!(X0CQ&/#H\-CR.1')$@
MD2*1'Y$=D1J1))$AD1N1>I%RD7F1<Y&EDJ22=I*;DGJ2H)*4DJJ2C9*FDIJ2
MJY)YDI>2?Y*CDNZ2CI*"DI62HI)]DHB2H9**DH:2C)*9DJ>2?I*'DJF2G9*+
MDBV2GI:AEO^66)=]EWJ7?I>#EX"7@I=[EX27@9=_E\Z7S9<6F*V8KI@"F0"9
M!YF=F9R9PYFYF;N9NIG"F;V9QYFQFN.:YYH^FS^;8)MAFU^;\9SRG/6<IY[_
M4`-1,%'X4`91!U'V4/Y0"U$,4?U0"E&+4HQ2\5+O4DA60E9,5C56059*5DE6
M1E985EI60%8S5CU6+%8^5CA6*E8Z5AI7JUB=6+%8H%BC6*]8K%BE6*%8_UC_
M6O1:_5KW6O9:`UOX6@);^5H!6P=;!5L/6V=<F5V779]=DEVB79-=E5V@79Q=
MH5V:79Y=:5Y=7F!>7%[S?=M>WE[A7DE?LE^+88-A>6&Q8;!AHF&)89MADV&O
M8:UAGV&28:IAH6&-869ALV$M8FYD<&269*!DA6279)QDCV2+9(IDC&2C9)]D
M:&2Q9)AD=F5Z97EE>V6R9;-EM6:P9JEFLF:W9JIFKV8`:@9J%VKE:?AI%6KQ
M:>1I(&K_:>QIXFD;:AUJ_FDG:O)I[FD4:O=IYVE`:@AJYFG[:0UJ_&GK:0EJ
M!&H8:B5J#VKV:29J!VKT:19J46NE:Z-KHFNF:P%L`&S_:P)L06\F;WYOAV_&
M;Y)OC6^);XQO8F]/;X5O6F^6;W9O;&^";U5O<F]2;U!O5V^4;Y-O76\`;V%O
M:V]];V=OD&]3;XMO:6]_;Y5O8V]W;VIO>V^R<:]QFW&P<:!QFG&I<;5QG7&E
M<9YQI'&A<:IQG'&G<;-QF'*:<EAS4G-><U]S8'-=<UMS87-:<UES8G.'=(ET
MBG2&=(%T?72%=(AT?'1Y=`AU!W5^=25V'G89=AUV''8C=AIV*'8;=IQVG7:>
M=IMVC7>/=XEWB'?->+MXSWC,>-%XSGC4>,AXPWC$>,EXFGFA>:!YG'FB>9MY
M=FLY>K)ZM'JS>K=[RWN^>ZQ[SGNO>[E[RGNU>\5\R'S,?,M\]WW;?>I]YWW7
M?>%]`W[Z?>9]]GWQ??!][GW??79_K'^P?ZU_[7_K?^I_['_F?^A_9(!G@*.!
MGX&>@96!HH&9@9>!%H)/@E."4H)0@DZ"48(DA3N%#X4`A2F%#H4)A0V%'X4*
MA2>%'(7[A"N%^H0(A0R%](0JA?*$%87WA.N$\X3\A!*%ZH3IA!:%_H0HA1V%
M+H4"A?V$'H7VA#&%)H7GA.B$\(3OA/F$&(4@A3"%"X49A2^%8H96AV.'9(=W
MA^&'<X=8AU2'6X=2AV&'6H=1AUZ';8=JAU"'3H=?AUV';X=LAWJ';H=<AV6'
M3X=[AW6'8H=GAVF'6H@%B0R)%(D+B1>)&(D9B0:)%HD1B0Z)"8FBB:2)HXGM
MB?")[(G/BL:*N(K3BM&*U(K5BKN*UXJ^BL"*Q8K8BL.*NHJ]BMF*/HQ-C(^,
MY8S?C-F,Z(S:C-V,YXR@C9R-H8V;C2".(XXECB2.+HX5CAN.%HX1CAF.)HXG
MCA2.$HX8CA..'(X7CAJ.+(\DCQB/&H\@CR./%H\7CW.0<)!OD&>0:Y`OD2N1
M*9$JD3*1)I$ND861AI&*D8&1@I&$D8"1T)+#DL22P)+9DK:2SY+QDM^2V)+I
MDM>2W9+,DN^2PI+HDLJ2R)+.DN:2S9+5DLF2X)+>DN>2T9+3DK62X9+&DK22
M?)6LE:N5KI6PE:26HI;3E@67")<"EUJ7BI>.EXB7T)?/EQZ8'9@FF"F8*)@@
MF!N8)YBRF`B9^I@1F129%ID7F169W)G-F<^9TYG4F<Z9R9G6F=B9RYG7F<R9
MLYKLFNN:\YKRFO&:1IM#FV>;=)MQFV:;=IMUFW";:)MDFVR;_)SZG/V<_YSW
MG`>=`)WYG/N<")T%G02=@Y[3G@^?$)\<41-1%U$:41%1WE$T4^%3<%9@5FY6
M<U9F5F-6;59R5EY6=U8<5QM7R%B]6,E8OUBZ6,)8O%C&6!=;&5L;6R%;%%L3
M6Q!;%ELH6QI;(%L>6^];K%VQ7:E=IUVU7;!=KEVJ7:A=LEVM7:]=M%UG7FA>
M9EYO7NE>YU[F7NA>Y5Y+7[Q?G6&H899AQ6&T8<9AP6',8;IAOV&X88QAUV36
M9-!DSV3)9+UDB63#9-MD\V399#-E?V5\9:)ER&:^9L!FRF;+9L]FO6:[9KIF
MS&8C9S1J9FI):F=J,FIH:CYJ76IM:G9J6VI1:BAJ6FH[:C]J06IJ:F1J4&I/
M:E1J;VII:F!J/&I>:E9J56I-:DYJ1FI5:U1K5FNG:ZIKJVO(:\=K!&P#;`9L
MK6_+;Z-OQV^\;\YOR&]>;\1OO6^>;\IOJ&\$<*5OKF^Z;ZQOJF_/;[]ON&^B
M;\EOJV_-;Z]OLF^P;\5QPG&_<;AQUG'`<<%QRW'4<<IQQW'/<;UQV'&\<<9Q
MVG';<9URGG)I<V9S9W-L<V5S:W-J<W]TFG2@=)1TDG25=*%T"W6`=2]V+78Q
M=CUV,W8\=C5V,G8P=KMVYG::=YUWH7><=YMWHG>C=Y5WF7>7=]UXZ7CE>.IX
MWGCC>-MXX7CB>.UXWWC@>*1Y1'I(>D=ZMGJX>K5ZL7JW>MY[XWOG>]U[U7OE
M>]I[Z'OY>]1[ZGOB>]Q[ZWO8>]][TGS4?-=\T'S1?!)^(7X7?@Q^'WX@?A-^
M#GX<?A5^&GXB?@M^#WX6?@U^%'XE?B1^0W][?WQ_>G^Q?^]_*H`I@&R`L8&F
M@:Z!N8&U@:N!L(&L@;2!LH&W@:>!\H%5@E:"5X)6A46%:X5-A5.%8858A4"%
M1H5DA4&%8H5$A5&%1X5CA3Z%6X5QA4Z%;H5UA56%9X5@A8R%9H5=A52%985L
MA6.&989DAIN'CX>7AY.'DH>(AX&'EH>8AWF'AX>CAX6'D(>1AYV'A(>4AYR'
MFH>)AQZ))HDPB2V)+HDGB3&)(HDIB2.)+XDLB1^)\8G@BN**\HKTBO6*W8H4
MB^2*WXKPBLB*WHKABNB*_XKOBON*D8R2C)",]8SNC/&,\(SSC&R-;HVEC:>-
M,XX^CCB.0(Y%CC:./(X]CD&.,(X_CKV.-H\NCS6/,H\YCS>/-(]VD'F0>Y"&
MD/J0,Y$UD3:1DY&0D9&1C9&/D2>3'I,(DQ^3!I,/DWJ3.),\DQN3(Y,2DP&3
M1I,MDPZ3#9/+DAV3^I(EDQ.3^9+WDC23`I,DD_^2*9,YDS63*I,4DPR3"Y/^
MD@F3`)/[DA:3O)7-E;Z5N96ZE;:5OY6UE;V5J9;4E@N7$I<0EYF7EY>4E_"7
M^)<UF"^8,I@DF1^9)YDIF9Z9[IGLF>69Y)GPF>.9ZIGIF>>9N9J_FK2:NYKV
MFOJ:^9KWFC.;@)N%FX>;?)M^FWN;@IN3FY*;D)MZFY6;?9N(FR6=%YT@G1Z=
M%)TIG1V=&)TBG1"=&9T?G8B>AIZ'GJZ>K9[5GM:>^IX2GSV?)E$E42)1)%$@
M42E1]%*35HQ6C5:&5H16@U9^5H)6?U:!5M98U%C/6-)8+5LE6S);(ULL6R=;
M)ELO6RY;>UOQ6_);MUUL7FI>OE^[7\-AM6&\8>=AX&'E8>1AZ&'>8>]DZ63C
M9.MDY&3H9(%E@&6V9=IETF:-:I9J@6JE:HEJGVJ;:J%JGFJ':I-JCFJ5:H-J
MJ&JD:I%J?VJF:IIJA6J,:I)J6VNM:PELS&^I;_1OU&_C;]QO[6_G;^9OWF_R
M;]UOXF_H;^%Q\7'H<?)QY''P<>)Q<W-N<V]SEW2R=*MTD'2J=*UTL72E=*]T
M$'41=1)U#W6$=4-V2'9)=D=VI';I=K5WJW>R=[=WMG>T=[%WJ'?P=_-X_7@"
M>?MX_'CR>`5Y^7C^>`1YJWFH>5QZ6WI6>EAZ5'I:>KYZP'K!>@5\#WSR>P!\
M_WO[>PY\]'L+?/-[`GP)?`-\`7SX>_U[!GSP>_%[$'P*?.A\+7X\?D)^,WY(
MF#A^*GY)?D!^1WXI?DQ^,'X[?C9^1'XZ?D5_?W]^?WU_]'_R?RR`NX'$@<R!
MRH'%@<>!O('I@5N"6H)<@H.%@(6/A:>%E86@A8N%HX5[A:2%FH6>A7>%?(6)
MA:&%>H5XA5>%CH66A8:%C869A9V%@86BA8*%B(6%A7F%=H68A9"%GX5HAKZ'
MJH>MA\6'L(>LA[F'M8>\AZZ'R8?#A\*'S(>WAZ^'Q(?*A[2'MH>_A[B'O8?>
MA[*'-8DSB3R)/HE!B5*)-XE"B:V)KXFNB?*)\XD>BQB+%HL1BP6+"XLBBP^+
M$HL5BP>+#8L(BP:+'(L3BQJ+3XQPC'*,<8QOC)6,E(SYC&^-3HY-CE..4(Y,
MCD>.0X]`CX60?I`XD9J1HI&;D9F1GY&AD9V1H)&ADX.3KY-DDU:31Y-\DUB3
M7)-VDTF34)-1DV"3;9./DTR3:I-YDU>359-2DT^3<9-WDWN389->DV.39Y.`
MDTZ369/'E<"5R97#E<65MY6NEK"6K)8@EQ^7&)<=EQF7FI>AEYR7GI>=E]67
MU)?QET&81)A*F$F819A#F"69*YDLF2J9,YDRF2^9+9DQF3"9F)FCF:&9`IKZ
MF?29]YGYF?B9]IG[F?V9_IG\F0.:OIK^FOV:`9O\FDB;FINHFYZ;FYNFFZ&;
MI9NDFX:;HIN@FZ^;,YU!G6>=-ITNG2^=,9TXG3"=19U"G4.=/ITWG4"=/9WU
M?RV=BIZ)GHV>L)[(GMJ>^Y[_GB2?(Y\BGU2?H)\Q42U1+E&85IQ6EU::5IU6
MF59P63Q;:5QJ7,!=;5YN7MAAWV'M8>YA\6'J8?!AZV'68>EA_V0$9?UD^&0!
M90-E_&249=MEVF;;9MAFQ6JY:KUJX6K&:KIJMFJW:L=JM&JM:EYKR6L+;`=P
M#'`-<`%P!7`4<`YP_V\`</MO)G#\;_=O"G`!<O]Q^7$#<OUQ=G.X=,!TM73!
M=+YTMG2[=,)T%'43=5QV9'99=E!V4W97=EIVIG:]=NQVPG>Z=_]X#'D3>11Y
M"7D0>1)Y$7FM>:QY7WH<?"E\&7P@?!]\+7P=?"9\*'PB?"5\,'Q<?E!^5GYC
M?EA^8GY??E%^8'Y7?E-^M7^S?_=_^']U@-&!TH'0@5^"7H*TA<:%P(7#A<*%
MLX6UA;V%QX7$A;^%RX7.A<B%Q86QA;:%TH4DAKB%MX6^A6F&YX?FA^*'VX?K
MA^J'Y8??A_.'Y(?4A]R'TX?MA]B'XX>DA]>'V8<!B/2'Z(?=AU.)2XE/B4R)
M1HE0B5&)28DJBR>+(XLSBS"+-8M'BR^+/(L^BS&+)8LWBR:+-HLNBR2+.XL]
MBSJ+0HQUC)F,F(R7C/Z,!(T"C0"-7(YBCF".5XY6CEZ.98YGCEN.6HYACEV.
M:8Y4CD:/1X](CTN/*)$ZD3N1/I&HD:61IY&OD:J1M9.,DY*3MY.;DYV3B9.G
MDXZ3JI.>DZ:3E9.(DYF3GY.-D[&3D9.RDZ23J).TDZ.3I9/2E=.5T96SEM>6
MVI;"7=^6V);=EB.7(I<EEZR7KI>HEZN7I)>JEZ*7I9?7E]F7UI?8E_J74)A1
MF%*8N)A!F3R9.ID/F@N:"9H-F@2:$9H*F@6:!YH&FL":W)H(FP2;!9LIFS6;
M2IM,FTN;QYO&F\.;OYO!F[6;N)O3F[:;Q)NYF[V;7)U3G4^=2IU;G4N=69U6
MG4R=5YU2G52=7YU8G5J=CIZ,GM^>`9\`GQ:?)9\KGRJ?*9\HGTR?59\T4351
MEE+W4K13JU:M5J96IU:J5JQ6VEC=6-M8$ED]6SY;/UO#77!>OU_[80=E$&4-
M90EE#&4.981EWF7=9=YFYVK@:LQJT6K9:LMJWVK<:M!JZVK/:LUJWFI@:[!K
M#&P9<"=P('`6<"MP(7`B<"-P*7`7<"1P''`J<`QR"G('<@)R!7*E<J9RI'*C
M<J%RRW3%=+=TPW06=6!VR7?*=\1W\7<=>1MY(7D<>1=Y'GFP>6=Z:'HS?#Q\
M.7PL?#M\['SJ?'9^=7YX?G!^=WYO?GI^<GYT?FA^2W]*?X-_AG^W?_U__G]X
M@->!U8%D@F&"8X+KA?&%[879A>&%Z(7:A=>%[(7RA?B%V(7?A>.%W(71A?"%
MYH7OA=Z%XH4`B/J'`XCVA_>'"8@,B`N(!HC\APB(_X<*B`*(8HE:B5N)5XEA
MB5R)6(E=B5F)B(FWB;:)]HE0BTB+2HM`BU.+5HM4BTN+58M1BT*+4HM7BT.,
M=XQVC)J,!HT'C0F-K(VJC:V-JXUMCGB.<XYJCF^.>X["CE*/48]/CU"/4X^T
MCT"1/Y&PD:V1WI/'D\^3PI/:D]"3^9/LD\R3V9.ID^:3RI/4D^Z3XY/5D\23
MSI/`D]*3YY-]E=J5VY7AEBF7*Y<LERB7)I>SE[>7MI?=E]Z7WY=<F%F879A7
MF+^8O9B[F+Z82)E'F4.9IIFGF1J:%9HEFAV:))H;FB*:()HGFB.:'IH<FA2:
MPIH+FPJ;#IL,FS>;ZIOKF^";WIODF^:;XIOPF]2;UYOLF]R;V9OEF]6;X9O:
MFW>=@9V*G82=B)UQG8"=>)V&G8N=C)U]G6N==)UUG7"=:9V%G7.=>YV"G6^=
M>9U_G8>=:)V4GI&>P)[\GBV?0)]!GTV?5I]7GUB?-U.R5K56LU;C6$5;QEW'
M7>Y>[U[`7\%?^6$7919E%6439=]EZ&;C9N1F\VKP:NIJZ&KY:O%J[FKO:CQP
M-7`O<#=P-'`Q<$)P.'`_<#IP.7!`<#MP,W!!<!-R%'*H<GUS?'.Z=*MVJG:^
M=NUVS'?.=\]WS7?R=R5Y(WDG>2AY)'DI>;)Y;GIL>FUZ]WI)?$A\2GQ'?$5\
M[GQ[?GY^@7Z`?KI__W]Y@-N!V8$+@FB":8(BAO^%`8;^A1N&`(;VA02&"88%
MA@R&_849B!"($8@7B!.(%HACB6:)N8GWB6"+:HM=BVB+8XMEBV>+;8NNC8:.
MB(Z$CEF/5H]7CU6/6(]:CXV00Y%!D;>1M9&RD;.1"Y03E/N3()0/E!24_I,5
ME!"4*)09E`V4]9,`E/>3!Y0.E!:4$I3ZDPF4^),*E/^3_),,E/:3$90&E-Z5
MX)7?E2Z7+Y>YE[N7_9?^EV"88IACF%^8P9C"F%"93IE9F4R92YE3F3*:-)HQ
MFBR:*IHVFBF:+IHXFBV:QYK*FL::$)L2FQ&;"YP(G/>;!9P2G/B;0)P'G`Z<
M!IP7G!2<"9R?G9F=I)V=G9*=F)V0G9N=H)V4G9R=JIV7G:&=FIVBG:B=GIVC
MG;^=J9V6G::=IYV9GIN>FI[EGN2>YY[FGC"?+I];GV"?7I]=GUF?D9\Z43E1
MF%*74L-6O5:^5DA;1UO+7<]=\5[]81ME`FO\:@-K^&H`:T-P1'!*<$AP27!%
M<$9P'7(:<AER?G,7=6IVT'<M>3%Y+WE4?%-\\GR*?H=^B'Z+?H9^C7Y-?[M_
M,(#=@1B&*H8FAA^&(X8<AAF&)X8NAB&&((8IAAZ&)88IB!V(&X@@B"2('(@K
MB$J(;8EIB6Z):XGZB7F+>(M%BWJ+>XL0C12-KXV.CHR.7H];CUV/1I%$D461
MN9$_E#N4-I0IE#V4/)0PE#F4*I0WE"R40)0QE.65Y)7CE367.I>_E^&79)C)
MF,:8P)A8F5:9.9H]FD::1)I"FD&:.IH_FLV:%9L7FQB;%ILZFU*;*YP=G!R<
M+)PCG"B<*9PDG"&<MYVVG;R=P9W'G<J=SYV^G<6=PYV[G;6=SIVYG;J=K)W(
MG;&=K9W,G;.=S9VRG7J>G)[KGNZ>[9X;GQB?&I\QGTZ?99]DGY*?N4[&5L56
MRU9Q64M;3%O57=%=\EXA92!E)F4B90MK"&L):PUL57!6<%=P4G`><A]RJ7)_
M<]ATU739=-=T;7:M=C5YM'EP>G%Z5WQ<?%E\6WQ:?/1\\7R1?D]_AW_>@6N"
M-(8UAC.&+(8RAC:&+(@HB":(*H@EB'&)OXF^B?N)?HN$BX*+AHN%BW^+%8V5
MCI2.FHZ2CI".EHZ7CF"/8H]'D4R44)1*E$N43Y1'E$642)1)E$:4/Y?CEVJ8
M:9C+F%296YE.FE.:5)I,FD^:2)I*FDF:4II0FM":&9LKFSN;5IM5FT:<2)P_
MG$2<.9PSG$&</)PWG#2<,IP]G#:<VYW2G=Z=VIW+G="=W)W1G=^=Z9W9G=B=
MUIWUG=6=W9VVGO">-9\SGS*?0I]KGY6?HI\]49E2Z%CG6')935O872^(3U\!
M8@-B!&(I925EEF7K9A%K$FL/:\IK6W!:<")R@G.!<X-S<';4=V=\9GR5?FR"
M.H9`ACF&/(8QACN&/H8PB#*(+H@SB':)=(ESB?Z)C(N.BXN+B(M%C!F-F(YD
MCV./O)%BE%647917E%Z4Q)?%EP"85II9FAZ;'YL@FU*<6)Q0G$J<39Q+G%6<
M69Q,G$Z<^YWWG>^=XYWKG?B=Y)WVG>&=[IWFG?*=\)WBG>R=])WSG>B=[9W"
MGM">\I[SG@:?')\XGS>?-I]#GT^?<9]PGVZ?;Y_35LU63EMM7"UE[6;N9A-K
M7W!A<%UP8'`C<MMTY735=SAYMWFV>6I\EWZ)?VV"0X8XB#>(-8A+B)2+E8N>
MCI^.H(Z=CKZ1O9'"D6N4:)1IE.661I=#ET>7QY?EEUZ:U9I9FV.<9YQFG&*<
M7IQ@G`*>_IT'G@.>!IX%G@">`9X)GO^=_9T$GJ">'I]&GW2?=9]VG]16+F6X
M91AK&6L7:QIK8G`F<JIRV'?9=SEY:7QK?/9\FGZ8?IM^F7[@@>&!1H9'ADB&
M>8EZB7R)>XG_B9B+F8NECJ2.HXYNE&V4;Y1QE'.429=RF%^9:)QNG&V<"YX-
MGA">#YX2GA&>H9[UG@F?1Y]XGWN?>I]YGQY79G!O?#R(LHVFCL.1=)1XE':4
M=91@FG2<<YQQG'6<%)X3GO:>"I^DGVAP97#W?&J&/H@]B#^(GHN<C*F.R8Y+
MEW.8=)C,F&&9JYEDFF::9YHDFQ6>%YY(GP=B'FLG<DR&J(Z"E("4@91IFFB:
M+IL9GBER2X:?BX.4>9RWGG5V:YIZG!V>:7!J<*2>?I])GYB?````````````
M`````````````````````#`,_P$P`C`._R(@&_\:_Q__`?\P_B8@)2!0_F3_
M4OZW`%3^5?Y6_E?^7/\3(#'^%"`S_OW_-/Y/_@C_"?\U_C;^6_]=_S?^./X4
M,!4P.?XZ_A`P$3`[_CS^"C`+,#W^/OX(,`DP/_Y`_@PP#3!!_D+^#C`/,$/^
M1/Y9_EK^6_Y<_EW^7OX8(!D@'"`=(!TP'C`U(#(@`_\&_PK_.R"G``,PRR7/
M);,ELB7.)08F!2;')<8EH26@);TEO"6C,@4A/B#]_S___?])_DK^3?Y._DO^
M3/Y?_F#^8?X+_PW_UP#W`+$`&B(<_Q[_'?]F(F<B8"(>(E(B82)B_F/^9/YE
M_F;^/"(I(BHBI2(@(A\BOR+2,]$S*R(N(C4B-")`)D(F028))I$ADR&0(9(A
MEB&7(9DAF"$E(B,B_?_]_P__//\$_Z4`$C"B`*,`!?\@_P,A"2%I_FK^:_[5
M,YPSG3.>,\XSH3..,X\SQ#.P`%E16U%>45U185%C4>=5Z73.?($E@B6#)80E
MA26&)8<EB"6/)8XEC26,)8LEBB6))3PE-"4L)20E'"64)0`E`B65)0PE$"44
M)1@E;25N)7`E;R50)5XE:B5A)>(EXR7E)>0E<25R)7,E$/\1_Q+_$_\4_Q7_
M%O\7_QC_&?]@(6$A8B%C(60A92%F(6<A:"%I(2$P(C`C,"0P)3`F,"<P*#`I
M,/W_1%/]_R'_(O\C_R3_)?\F_R?_*/\I_RK_*_\L_RW_+O\O_S#_,?\R_S/_
M-/\U_S;_-_\X_SG_.O]!_T+_0_]$_T7_1O]'_TC_2?]*_TO_3/]-_T[_3_]0
M_U'_4O]3_U3_5?]6_U?_6/]9_UK_D0.2`Y,#E`.5`Y8#EP.8`YD#F@.;`YP#
MG0.>`Y\#H`.A`Z,#I`.E`Z8#IP.H`ZD#L0.R`[,#M`.U`[8#MP.X`[D#N@.[
M`[P#O0.^`[\#P`/!`\,#Q`/%`\8#QP/(`\D#!3$&,0<Q"#$),0HQ"S$,,0TQ
M#C$/,1`Q$3$2,1,Q%#$5,18Q%S$8,1DQ&C$;,1PQ'3$>,1\Q(#$A,2(Q(S$D
M,24Q)C$G,2@Q*3'9`LD"R@+'`LL"_?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W_`$Y93@%.`TY#3EU.ADZ,3KI./U%E46M1X%$`4@%2FU(5
M4T%37%/(4PE."TX(3@I.*TXX3N%114Y(3E].7DZ.3J%.0%$#4OI20U/)4^-3
M'U?K6!59)UES65!;45M36_A;#UPB7#A<<5S=7>5=\5WR7?-=_EUR7OY>"U\3
M7TUB$4X03@U.+4XP3CE.2TXY7(A.D4Z53I).E$ZB3L%.P$[#3L9.QT[-3LI.
MRT[$3D-105%G46U1;E%L49=1]E$&4@=2"%+[4OY2_U(64SE32%-'4T537E.$
M4\M3RE/-4^Q8*5DK62I9+5E46Q%<)%PZ7&]<]%U[7O]>%%\57\-?"&(V8DMB
M3F(O98=EEV6D9;EEY67P9@AG*&<@:V)K>6O+:]1KVVL/;#1L:W`J<C9R.W)'
M<EER6W*L<HMS&4X63A5.%$X83CM.34Y/3DY.Y4[83M1.U4[63M=.XT[D3ME.
MWDY%4411B5&*4:Q1^5'Z4?A1"E*@4I]2!5,&4Q=3'5/?3DI325-A4V!3;U-N
M4[M3[U/D4_-3[%/N4^E3Z%/\4_A3]5/K4^93ZE/R4_%3\%/E4^U3^U/;5MI6
M%EDN63%9=%EV655;@UL\7.A=YUWF70)>`UYS7GQ>`5\87Q=?Q5\*8E-B5&)2
M8E%BI67F92YG+&<J9RMG+6=C:\UK$6P0;#AL06Q`;#YLKW*$<XESW'3F=!AU
M'W4H=2EU,'4Q=3)U,W6+=7UVKG:_=NYVVW?B=_-W.GF^>71ZRWH>3A].4DY3
M3FE.F4ZD3J9.I4[_3@E/&4\*3Q5/#4\03Q%/#T_R3O9.^T[P3O-._4X!3PM/
M25%'44912%%H47%1C5&P41=2$5(24@Y2%E*C4@A3(5,@4W!3<5,)5`]4#%0*
M5!!4`50+5`14$50-5`A4`U0.5`94$E3@5MY6W58S5S!7*%<M5RQ7+U<I5QE9
M&EDW63A9A%EX68-9?5EY68)9@5E76UA;AUN(6X5;B5OZ6Q9<>5S>709>=EYT
M7@]?&U_97]9?#F(,8@UB$&)C8EMB6&(V9>EEZ&7L9>UE\F;S9@EG/6<T9S%G
M-6<A:V1K>VL6;%UL5VQ9;%]L8&Q0;%5L86Q;;$UL3FQP<%]R77)^=OEZ<WSX
M?#9_BG^]?P&``X`,@!*`,X!_@(F`BX",@..!ZH'S@?R!#((;@A^";H)R@GZ"
M:X9`B$R(8XA_B2&6,DZH3DU/3T]'3U=/7D\T3UM/54\P3U!/44\]3SI/.$]#
M3U1//$]&3V-/7$]@3R]/3D\V3UE/74](3UI/3%%+44U1=5&V4;=1)5(D4BE2
M*E(H4JM2J5*J4JQ2(U-S4W53'50M5!Y4/E0F5$Y4)U1&5$-4,U1(5$)4&U0I
M5$I4.50[5#A4+E0U5#94(%0\5$!4,50K5!]4+%3J5O!6Y%;K5DI745=`5TU7
M1U=.5SY74%=/5SM7[U@^69U9DEFH69Y9HUF96999C5FD69-9BEFE65U;7%M:
M6UM;C%N+6X];+%Q`7$%</UP^7)!<D5R47(Q<ZUT,7H]>AUZ*7O=>!%\?7V1?
M8E]W7WE?V%_,7]=?S5_Q7^M?^%_J7Q)B$6*$8I=BEF*`8G9BB6)M8HIB?&)^
M8GEB<V*28F]BF&)N8I5BDV*18H9B.64[93AE\67T9E]G3F=/9U!G46=<9U9G
M7F=)9T9G8&=39U=G96O/:T)L7FR9;(%LB&R);(5LFVQJ;'ILD&QP;(QL:&R6
M;))L?6R#;')L?FQT;(9L=FR-;)1LF&R";'9P?'!]<'AP8G)A<F!RQ'+"<I9S
M+'4K=3=U.'6"=N]VXW?!><!YOWEV>OM\57^6@).`G8"8@)N`FH"R@&^"DH*+
M@HV"BXG2B0"*-XQ&C%6,G8QDC7"-LXVKCLJ.FX^PC\*/QH_%C\2/X5V1D**0
MJI"FD*.029'&D<R1,I8NEC&6*I8LEB9.5DYS3HM.FTZ>3JM.K$YO3YU/C4]S
M3W]/;$^;3XM/AD^#3W!/=4^(3VE/>T^63WY/CT^13WI/5%%24551:5%W4791
M>%&]4?U1.U(X4C=2.E(P4BY2-E)!4KY2NU)24U134U-14V93=U-X4WE3UE/4
M4]=3<U1U5)94>%255(!4>U1W5(14DE2&5'Q4D%1Q5'94C%2:5&)4:%2+5'U4
MCE3Z5H-7=U=J5VE785=F5V17?%<<64E91UE(64195%F^6;M9U%FY6:Y9T5G&
M6=!9S5G+6=-9REFO6;-9TEG%65];9%MC6Y=;FEN86YQ;F5N;6QI<2%Q%7$9<
MMURA7+A<J5RK7+%<LUP87AI>%EX57AM>$5YX7II>EUZ<7I5>EE[V7B9?)U\I
M7X!?@5]_7WQ?W5_@7_U?]5__7P]@%&`O8#5@%F`J8!5@(6`G8"E@*V`;8!9B
M%6(_8CYB0&)_8LEBS&+$8K]BPF*Y8M)BVV*K8M-BU&++8LABJ&*]8KQBT&+9
M8L=BS6*U8MIBL6+88M9BUV+&8JQBSF(^9:=EO&7Z911F$V8,9@9F`F8.9@!F
M#V859@IF!V8-9PMG;6>+9Y5G<6><9W-G=V>'9YUGEV=O9W!G?V>)9WYGD&=U
M9YIGDV=\9VIG<F<C:V9K9VM_:Q-L&VSC;.AL\VRQ;,QLY6RS;+ULOFR\;.)L
MJVS5;--LN&S$;+ELP6RN;-=LQ6SQ;+]LNVSA;-MLRFRL;.]LW&S6;.!LE7".
M<))PBG"9<"QR+7(X<DAR9W)I<L!RSG+9<M=RT'*I<ZASGW.K<Z5S/76==9EU
MFG6$=L)V\G;T=N5W_7<^>4!Y07G)><AY>GIY>OIZ_GQ4?XQ_BW\%@+J`I8"B
M@+&`H8"K@*F`M("J@*^`Y8'^@0V"LX*=@IF"K8*]@I^"N8*Q@JR"I8*O@KB"
MHX*P@KZ"MX).AG&&'5)HB,N.SH_4C]&/M9"XD+&0MI#'D=&1=Y6`E1R60)8_
MECN61)9"EKF6Z)92EUZ7GTZM3JY.X4^U3Z]/OT_@3]%/ST_=3\-/MD_83]]/
MRD_73ZY/T$_$3\)/VD_.3]Y/MT]749)1D5&@44Y20U)*4DU23%)+4D=2QU+)
M4L-2P5(-4U=3>U.:4]M3K%3`5*A4SE3)5+A4IE2S5,=4PE2]5*I4P53$5,A4
MKU2K5+%4NU2I5*=4OU3_5H)7BU>@5Z-7HE?.5ZY7DU=565%93UE.65!9W%G8
M6?]9XUGH60-:Y5GJ6=I9YED!6OM9:5NC6Z9;I%NB6Z5;`5Q.7$]<35Q+7-E<
MTESW71U>)5X?7GU>H%ZF7OI>"%\M7V5?B%^%7XI?BU^'7XQ?B5\28!U@(&`E
M8`Y@*&!-8'!@:&!B8$9@0V!L8&M@:F!D8$%BW&(68PEC_&+M8@%C[F+]8@=C
M\6+W8N]B[&+^8O1B$6,"8S]E166K9;UEXF4E9BUF(&8G9B]F'V8H9C%F)&;W
M9O]GTV?Q9]1GT&?L9[9GKV?U9^EG[V?$9]%GM&?:9^5GN&?/9]YG\V>P9]EG
MXF?=9])G:FN#:X9KM6O2:]=K'VS);`MM,FTJ;4%M)6T,;3%M'FT7;3MM/6T^
M;39M&VWU;#EM)VTX;2EM+FTU;0YM*VVK<+IPLW"L<*]PK7"X<*YPI'`P<G)R
M;W)T<NERX'+A<K=SRG.[<[)SS7/`<[-S&G4M=4]U3'5.=4MUJW6D=:5UHG6C
M=7AVAG:'=HAVR';&=L-VQ78!=_EV^'8)=PMW_G;\=@=WW'<">!1X#'@->$9Y
M27E(>4=YN7FZ>=%YTGG+>7]Z@7K_>OUZ?7P"?05]`'T)?0=]!'T&?3A_CG^_
M?P2`$(`-@!&`-H#6@.6`VH##@,2`S(#A@-N`SH#>@.2`W8#T@2*"YX(#@P6#
MXX+;@N:"!(/E@@*#"8/2@M>"\8(!@]R"U(+1@MZ"TX+?@N^"!H-0AGF&>X9Z
MADV(:XB!B=2)"(H"B@.*GHR@C'2-<XVTC<V.S([PC^:/XH_JC^6/[8_KC^2/
MZ(_*D,Z0P9##D$N12I'-D8*54)9+EDR6399BEVF7RY?ME_.7`9BHF-N8WYB6
MF9F96$ZS3@Q0#5`C4.]/)E`E4/A/*5`64`90/%`?4!I0$E`14/I/`%`44"A0
M\4\A4`M0&5`84/-/[D\M4"I0_D\K4`E0?%&D4:51HE'-4<Q1QE'+45927%)4
M4EM275(J4W]3GU.=4]]3Z%0050%5-U7\5.54\E0&5?I4%%7I5.U4X50)5>Y4
MZE3F5"=5!U7]5`]5`U<$5\)7U%?+5\-7"5@/65=96%E:61%:&%H<6A]:&UH3
M6NQ9(%HC6BE:)5H,6@E::UM87+!;LUNV6[1;KENU6[E;N%L$7%%<55Q07.U<
M_5S[7.I<Z%SP7/9<`5WT7.Y=+5XK7JM>K5ZG7C%?DE^17Y!?66!C8&5@4&!5
M8&U@:6!O8(1@GV":8(U@E&",8(5@EF!'8O-B"&/_8DYC/F,O8U5C0F-&8T]C
M26,Z8U!C/6,J8RMC*&--8TQC2&5)99EEP67%94)F269/9D-F4F9,9D5F06;X
M9A1G%6<79R%H.&A(:$9H4V@Y:$)H5&@I:+-H%VA,:%%H/6CT9U!H0&@\:$-H
M*FA%:!-H&&A!:(IKB6NW:R-L)VPH;"9L)&SP;&IME6V(;8=M9FUX;7=M66V3
M;6QMB6UN;5IM=&UI;8QMBFUY;85M96V4;<IPV'#D<-EPR'#/<#ER>7+\<OER
M_7+X<O=RAG/M<PET[G/@<^ISWG-4=5UU7'5:=5EUOG7%=<=ULG6S=;UUO'6Y
M=<)UN'6+=K!VRG;-=LYV*7<?=R!W*'?I=S!X)W@X>!UX-'@W>"5X+7@@>!]X
M,GA5>5!Y8'E?>59Y7GE=>5=Y6GGD>>-YYWG?>>9YZ7G8>81ZB'K9>@9[$7N)
M?"%]%WT+?0I]('TB?11]$'T5?1I]''T-?1E]&WTZ?U]_E'_%?\%_!H`8@!6`
M&8`7@#V`/X#Q@`*!\(`%@>V`](`&@?B`\X`(@?V`"H'\@.^`[8'L@0""$((J
M@BN"*((L@KN"*X-2@U2#2H,X@U"#28,U@S2#3X,R@SF#-H,7@T"#,8,H@T.#
M5(:*AJJ&DX:DAJF&C(:CAIR&<(AWB(&(@HA]B'F(&(H0B@Z*#(H5B@J*%XH3
MBA:*#XH1BDB,>HQYC*&,HHQWC:R.TH[4CL^.L8\!D`:0]X\`D/J/](\#D/V/
M!9#XCY60X9#=D.*04I%-D4R1V)'=D=>1W)'9D8.58I9CEF&66Y9=EF266)9>
MEKN6XIBLF:B:V)HEFS*;/)M^3GI0?5!<4$=00U!,4%I025!E4'903E!54'50
M=%!W4$]0#U!O4&U07%&54?!1:E)O4M)2V5+84M52$%,/4QE3/U-`4SY3PU/\
M9D95:E5F54157E5A54-52E4Q55953U5552]59%4X52Y57%4L56-5,U5!55=5
M"%<+5PE7WU<%6`I8!EC@5^17^E<"6#58]U?Y5R!98EDV6D%:25IF6FI:0%H\
M6F):6EI&6DI:<%O'6\5;Q%O"6[];QEL)7`A<!UQ@7%Q<75P'709=#ET;719=
M(ET172E=%%T9721=)UT77>)=.%XV7C->-UZW7KA>MEZU7KY>-5\W7U=?;%]I
M7VM?EU^97YY?F%^A7Z!?G%]_8*-@B6"@8*A@RV"T8.9@O6#%8+M@M6#<8+Q@
MV&#58,9@WV"X8-I@QV`:8AMB2&*@8Z=C<F.68Z)CI6-W8V=CF&.J8W%CJ6.)
M8X-CFV-K8ZACA&.(8YECH6.L8Y)CCV.`8WMC:6-H8WIC765695%E665795]5
M3V58955E5&6<99MEK&7/9<MES&7.95UF6F9D9FAF9F9>9OEFUU(;9X%HKVBB
M:)-HM6A_:'9HL6BG:)=HL&B#:,1HK6B&:(5HE&B=:*AHGVBA:()H,FNZ:^MK
M[&LK;(YMO&WS;=EMLFWA;<QMY&W[;?IM!6[';<MMKVW1;:YMWFWY;;AM]VWU
M;<5MTFT:;K5MVFWK;=AMZFWQ;>YMZ&W&;<1MJFWL;;]MYFWY<`EQ"G']<.]P
M/7)]<H%R'',;<Q9S$W,9<X=S!70*=`-T!G3^<PUTX'3V=/=T''4B=65U9G5B
M=7!UCW74==5UM77*=<UUCG;4=M)VVW8W=SYW/'<V=SAW.G=K>$-X3GAE>6AY
M;7G[>9)ZE7H@>RA[&WLL>R9[&7L>>RY[DGR7?)5\1GU#?7%]+GTY?3Q]0'TP
M?3-]1'TO?4)],GTQ?3U_GG^:?\Q_SG_2?QR`2H!&@"^!%H$C@2N!*8$P@22!
M`H(U@C>"-H(Y@HZ#GH.8@WB#HH.6@[V#JX.2@XJ#DX.)@Z"#=X-[@WR#AH.G
M@U6&:E_'AL"&MH;$AK6&QH;+AK&&KX;)AE.(GHB(B*N(DHB6B(V(BXB3B8^)
M*HH=BB.*)8HQBBV*'XH;BB**28Q:C*F,K(RKC*B,JHRGC&>-9HV^C;J-VX[?
MCAF0#9`:D!>0(Y`?D!V0$)`5D!Z0()`/D"*0%I`;D!20Z)#MD/V05Y'.D?61
MYI'CD>>1[9'ID8F5:I9UEG.6>)9PEG26=I9WEFR6P);JENF6X'K?>@*8`YA:
MF^6<=9Y_GJ6>NYZB4(U0A5"94)%0@%"64)A0FE``9_%1<E)T4G52:5+>4MU2
MVU):4Z53>U6`5:=5?%6*59U5F%6"59Q5JE6458=5BU6#5;-5KE6?53Y5LE6:
M5;M5K%6Q57Y5B56K59E5#5<O6"I8-%@D6#!8,5@A6!U8(%CY6/I88%EW6II:
M?UJ26IM:IUIS6W%;TEO,6]-;T%L*7`M<,5Q,75!=-%U'7?U=15X]7D!>0UY^
M7LI>P5["7L1>/%]M7ZE?JE^H7]%@X6"R8+9@X&`<82-A^F`58?!@^V#T8&AA
M\6`.8?9@"6$`81)A'V))8J-CC&//8\!CZ6/)8\9CS6/28^-CT&/A8]9C[6/N
M8W9C]&/J8]MC4F3:8_EC7F5F96)E8V6199!EKV5N9G!F=&9V9F]FD69Z9GYF
M=V;^9O]F'V<=9_IHU6C@:-AHUV@%:=]H]6CN:.=H^6C2:/)HXVC+:,UH#6D2
M:0YIR6C::&YI^V@^:SIK/6N8:Y9KO&OO:RYL+VPL;"]N.&Y4;B%N,FYG;DIN
M(&XE;B-N&VY;;EAN)&Y6;FYN+6XF;F]N-&Y-;CIN+&Y#;AUN/F[+;HEN&6Y.
M;F-N1&YR;FEN7VX9<1IQ)G$P<2%Q-G%N<1QQ3'*$<H!R-G,E<S1S*7,Z="IT
M,W0B="5T-70V=#1T+W0;="9T*'0E=29U:W5J=>)UVW7C==EUV'7>=>!U>W9\
M=I9VDW:T=MQV3W?M=UUX;'AO>`UZ"'H+>@5Z`'J8>I=ZEGKE>N-Z27M6>T9[
M4'M2>U1[37M+>T][47N??*5\7GU0?6A]57TK?6Y]<GUA?69]8GUP?7-]A%74
M?]5_"X!2@(6`58%4@4N!48%.@3F!1H$^@4R!4X%T@1*"'(+I@P.$^(,-A."#
MQ8,+A,&#[X/Q@_2#5X0*A/"##(3,@_V#\H/*@SB$#H0$A-R#!X34@]^#6X;?
MAMF&[8;4AMN&Y(;0AMZ&5XC!B,*(L8B#B9:).XI@BE6*7HH\BD&*5(I;BE"*
M1HHTBCJ*-HI6BF&,@HROC+R,LXR]C,&,NXS`C+2,MXRVC+^,N(R*C86-@8W.
MC=V-RXW:C=&-S(W;C<:-^X[XCOR.G(\ND#60,9`XD#*0-I`"D?60"9'^D&.1
M99'/D122%9(CD@F2'I(-DA"2!Y(1DI25CY6+E9&5DY62E8Z5BI:.EHN6?9:%
MEH:6C99REH26P9;%EL26QI;'EN^6\I;,EP68!I@(F.>8ZICOF.F8\ICMF*Z9
MK9G#GLV>T9Z"3JU0M5"R4+-0Q5"^4*Q0MU"[4*]0QU!_4G=2?5+?4N92Y%+B
M4N-2+U/?5>A5TU7F5<Y5W%7'5=%5XU7D5>]5VE7A5<55QE7E5<E5$E<35UY8
M45A86%=86EA46&M83%AM6$I88EA26$M89UG!6LE:S%J^6KU:O%JS6L):LEII
M76]=3%YY7LE>R%X27UE?K%^N7QIA#V%(81]A\V`;8?E@`6$(84YA3&%$84UA
M/F$T82=A#6$&83=A(6(B8A-D/F0>9"ID+60]9"QD#V0<9!1D#60V9!9D%V0&
M9&QEGV6P99=FB6:'9HAFEF:$9IAFC68#9Y1I;6E::7=I8&E4:75I,&F":4II
M:&EK:5YI4VEY:89I76EC:5MI1VMR:\!KOVO3:_UKHFZO;M-NMF[";I!NG6['
M;L5NI6Z8;KQNNFZK;M%NEFZ<;L1NU&ZJ;J=NM&Y.<5EQ:7%D<4EQ9W%<<6QQ
M9G%,<65Q7G%&<6AQ5G$Z<E)R-W-%<S]S/G-O=%IT571?=%YT070_=%ET6W1<
M='9U>'4`=O!U`7;R=?%U^G7_=?1U\W7>=M]V6W=K=V9W7G=C=WEW:G=L=UQW
M97=H=V)W[G>.>+!XEWB8>(QXB7A\>)%XDWA_>'IY?WF!>2R$O7D<>AIZ('H4
M>A]Z'GJ?>J!Z=WO`>V![;GMG>[%\LWRU?)-]>7V1?8%]CWU;?6Y_:7]J?W)_
MJ7^H?Z1_5H!8@(:`A(!Q@7"!>(%E@6Z!<X%K@7F!>H%F@06"1X*"A'>$/80Q
MA'6$9H1KA$F$;(1;A#R$-81AA&.$:81MA$:$7H9<AE^&^883APB'!X<`A_Z&
M^X8"AP.'!H<*AUF(WXC4B-F(W(C8B-V(X8C*B-6(THB<B>.):XIRBG.*9HII
MBG"*AXI\BF.*H(IQBH6*;8IBBFZ*;(IYBGN*/HIHBF*,BHR)C,J,QXS(C,2,
MLHS#C,*,Q8SAC=^-Z(WOC?.-^HWJC>2-YHVRC@./"8_^C@J/GX^RCTN02I!3
MD$*05)`\D%604)!'D$^03I!-D%&0/I!!D!*1%Y%LD6J1:9')D3>25Y(XDCV2
M0)(^DEN22Y)DDE&2-)))DDV219(YDC^26I*8E9B6E):5ELV6RY;)ELJ6]Y;[
MEOF6]I96EW27=I<0F!&8$Y@*F!*8#)C\F/28_9C^F+.9L9FTF>&:Z9R"G@Z?
M$Y\@G^=0[E#E4-90[5#:4-50SU#14/%0SE#I4&)1\U&#4H)2,5.M4_Y5`%8;
M5A=6_5445@96"58-5@Y6]U465A]6"%805O95&%<65W58?EB#6)-8BEAY6(58
M?5C]6"59(EDD66I9:5GA6N9:Z5K76M9:V%KC6G5;WEOG6^%;Y5OF6^A;XEOD
M6]];#5QB7(1=AUU;7F->55Y77E1>TU[67@I?1E]P7[E?1V$_84MA=V%B86-A
M7V%:85AA=6$J8H=D6&149*1D>&1?9'ID461G9#1D;61[9')EH6779=9EHF:H
M9IUFG&FH:95IP6FN:=-IRVF;:;=INVFK:;1IT&G-::UIS&FF:<-IHVE):TQK
M,VPS;Q1O_FX3;_1N*6\^;R!O+&\/;P)O(F__;N]N!F\Q;SAO,F\C;Q5O*V\O
M;XAO*F_L;@%O\F[,;O=NE'&9<7UQBG&$<9)Q/G*2<I9R1'-0<V1T8W1J='!T
M;70$=9%U)W8-=@MV"783=N%VXW:$=WUW?W=A=\%XGWBG>+-XJ7BC>(YYCWF-
M>2YZ,7JJ>JEZ[7KO>J%[E7N+>W5[EWN=>Y1[CWNX>X=[A'NY?+U\OGR[?;!]
MG'V]?;Y]H'W*?;1]LGVQ?;I]HGV_?;5]N'VM?=)]QWVL?7!_X'_A?]]_7H!:
M@(>`4(&`@8^!B(&*@7^!@H'G@?J!!X(4@AZ"2X+)A+^$QH3$A)F$GH2RA)R$
MRX2XA,"$TX20A+R$T83*A#^''(<[AR*')8<TAQB'58<WARF'\X@"B?2(^8CX
MB/V(Z(@:B>^(IHJ,BIZ*HXJ-BJ&*DXJDBJJ*I8JHBIB*D8J:BJ>*:HR-C(R,
MTXS1C-*,:XV9C96-_(T4CQ*/%8\3CZ./8)!8D%R08Y!9D%Z08I!=D%N0&9$8
MD1Z1=9%XD7>1=)%XDH"2A9*8DI:2>Y*3DIR2J))\DI&2H96HE:F5HY6EE:25
MF9:<EIN6S);2E@"7?)>%E_:7%Y@8F*^8L9@#F069#)D)F<&9KYJPFN::09M"
MF_2<]ISSG+R>.Y]*GP11`%'[4/50^5`"40A1"5$%4=Q1AU*(4HE2C5**4O!2
MLE,N5CM6.58R5C]6-%8I5E-63E975G16-E8O5C!6@%B?6)Y8LUB<6*Y8J5BF
M6&U9"5O[6@M;]5H,6PA;[EOL6^E;ZUMD7&5<G5V476)>7UYA7N)>VE[?7MU>
MXU[@7DA?<5^W7[5?=F%G86YA76%588)A?&%P86MA?F&G89!AJV&.8:QAFF&D
M891AKF$N8FED;V1Y9)YDLF2(9)!DL&2E9)-DE62I9))DKF2M9*MDFF2L9)ED
MHF2S9'5E=V5X9:YFJV:T9K%F(VH?:NAI`6H>:AEJ_6DA:A-J"FKS:0)J!6KM
M:1%J4&M.:Z1KQ6O&:S]O?&^$;U%O9F]4;X9O;6];;WAO;F^.;WIO<&]D;Y=O
M6&_5;F]O8&]?;Y]QK'&Q<:AQ5G*;<DYS5W-I=(MT@W1^=(!T?W4@=BEV'W8D
M=B9V(78B=IIVNG;D=HYWAW>,=Y%WBW?+>,5XNGC*>+YXU7B\>-!X/WH\>D!Z
M/7HW>CMZKWJN>JU[L7O$>[1[QGO'>\%[H'O,>\I\X'WT?>]]^WW8?>Q]W7WH
M?>-]VGW>?>E]GGW9??)]^7UU?W=_KW_I?R:`FX&<@9V!H(&:@9B!%X4]A1J%
M[H0LA2V%$X41A2.%(844A>R$)87_A`:%@H=TAW:'8(=FAWB':(=9AU>'3(=3
MAUN(78@0B0>)$HD3B16)"HF\BM**QXK$BI6*RXKXBK**R8K"BK^*L(K6BLV*
MMHJYBMN*3(Q.C&R,X(S>C.:,Y(SLC.V,XHSCC-R,ZHSAC&V-GXVCC2N.$(X=
MCB*.#XXICA^.(8X>CKJ.'8\;CQ^/*8\FCRJ/'(\>CR6/:9!ND&B0;9!WD#"1
M+9$GD3&1AY&)D8N1@Y'%DKN2MY+JDJR2Y)+!DK.2O)+2DL>2\)*RDJV5L94$
MEP:7!Y<)EV"7C9>+EX^7(9@KF!R8LY@*F1.9$ID8F=V9T)G?F=N9T9G5F=*9
MV9FWFNZ:[YHGFT6;1)MWFV^;!IT)G0.=J9Z^GLZ>J%A2GQ)1&%$441!1%5&`
M4:I1W5&14I-2\U)95FM6>59I5F16>%9J5FA6959Q5F]6;%9B5G96P5B^6,=8
MQ5AN61U;-%MX6_!;#EQ*7[)AD6&I88IAS6&V8;YARF'(83!BQ63!9,MDNV2\
M9-IDQ&3'9,)DS62_9-)DU&2^9'1EQF;)9KEFQ&;'9KAF/6HX:CIJ66IK:EAJ
M.6I$:F)J86I+:D=J-6I?:DAJ66MW:P5LPF^Q;Z%OPV^D;\%OIV^S;\!ON6^V
M;Z9OH&^T;[YQR7'0<=)QR''5<;EQSG'9<=QQPW'$<6ASG'2C=)ATGW2>=.)T
M#'4-=31V.'8Z=N=VY7:@=YYWGW>E=^AXVGCL>.=XIGE->DYZ1GI,>DMZNGK9
M>Q%\R7OD>]M[X7OI>^9[U7S6?`I^$7X(?AM^(WX>?AU^"7X0?GE_LG_P?_%_
M[G\H@+.!J8&H@?N!"()8@EF"2H59A4B%:(5IA4.%285MA6J%7H6#AY^'GH>B
MAXV'88@JB3*))8DKB2&)JHFFB>:*^HKKBO&*`(O<BN>*[HK^B@&+`HOWBNV*
M\XKVBOR*:XQMC).,](Q$CC&.-(Y"CCF.-8X[CR^/.(\SCZB/IH]UD'20>)!R
MD'R0>I`TD9*1(),VD_B2,Y,ODR*3_)(KDP23&I,0DR:3(9,5DRZ3&9.[E:>6
MJ):JEM66#I<1EQ:7#9<3EP^76Y=<EV:7F)<PF#B8.Y@WF"V8.9@DF!"9*)D>
MF1N9(9D:F>V9XIGQF;B:O)K[FNV:*)N1FQ6=(YTFG2B=$IT;G=B>U)Z-GYR?
M*E$?42%1,E'U4HY6@%:05H56AU:/5M58TUC16,Y8,%LJ6R1;>ELW7&A<O%VZ
M7;U=N%UK7DQ?O5_)8<)AQV'F8<MA,F(T8LYDRF389.!D\&3F9.QD\63B9.UD
M@F6#9=EFUF:`:I1JA&JB:IQJVVJC:GYJEVJ0:J!J7&NN:]IK"&S8;_%OWV_@
M;]MOY&_K;^]O@&_L;^%OZ6_5;^YO\&_G<=]Q[G'F<>5Q[7'L<?1QX'$U<D9R
M<'-R<ZETL'2F=*AT1G9"=DQVZG:S=ZIWL'>L=Z=WK7?O=_=X^GCT>.]X`7FG
M>:IY5WJ_>@=\#7S^>_=[#'S@>^!\W'S>?.)\WWS9?-U\+GX^?D9^-WXR?D-^
M*WX]?C%^17Y!?C1^.7Y(?C5^/WXO?D1_\W_\?W&`<H!P@&^`<X#&@<.!NH'"
M@<"!OX&]@<F!OH'H@0F"<8*JA82%?H6<A9&%E(6OA9N%AX6HA8J%9X;`A]&'
MLX?2A\:'JX>[A[J'R(?+ASN)-HE$B3B)/8FLB0Z+%XL9BQN+"HL@BQV+!(L0
MBT&,/XQSC/J,_8S\C/B,^XRHC4F.2XY(CDJ.1(\^CT*/18\_CW^0?9"$D(&0
M@I"`D#F1HY&>D9R139."DRB3=9-*DV632Y,8DWZ3;)-;DW"36I-4D\J5RY7,
ME<B5QI6QEKB6UI8<EQZ7H)?3ET:8MI@UF0&:_YFNFZN;JINMFSN=/YV+GL^>
MWI[<GMV>VYX^GTN?XE.55JY6V5C86#A;75_C83-B]&3R9/YD!F7Z9/MD]V2W
M9=QF)F>S:JQJPVJ[:KAJPFJN:J]J7VMX:Z]K"7`+</YO!G#Z;Q%P#W#[<?QQ
M_G'X<7=S=7.G=+]T%756=EAV4G:]=[]WNW>\=PYYKGEA>F)Z8'K$>L5Z*WPG
M?"I\'GPC?"%\YWQ4?E5^7GY:?F%^4GY9?DA_^7_[?W>`=H#-@<^!"H+/A:F%
MS870A<F%L(6ZA;F%IH7OA^R'\H?@AX:)LHGTB2B+.8LLBRN+4(P%C5F.8XYF
MCF2.7XY5CL".28]-CX>0@Y"(D*N1K)'0D923BI.6DZ*3LY.NDZR3L).8DYJ3
MEY/4E=:5T)75E>*6W);9EMN6WI8DEZ.7II>ME_F739A/F$R83IA3F+J8/ID_
MF3V9+IFEF0Z:P9H#FP:;3YM.FTV;RIO)F_V;R)O`FU&=79U@G>">%9\LGS-1
MI5;>6-]8XECU6Y"?[%[R8?=A]F'U80!E#V7@9MUFY6K=:MIJTVH;<!]P*'`:
M<!UP%7`8<`9R#7)8<J)R>'-Z<[UTRG3C=(=UAG5?=F%VQW<9>;%Y:WII>CY\
M/WPX?#U\-WQ`?&M^;7YY?FE^:GZ%?W-^MG^Y?[A_V('IA=V%ZH75A>2%Y87W
MA?N'!8@-B/F'_H=@B5^)5HE>B4&+7(M8BTF+6HM.BT^+1HM9BPB-"HU\CG*.
MAXYVCFR.>HYTCE2/3H^MCXJ0BY"QD:Z1X9/1D]^3PY/(D]R3W9/6D^*3S9/8
MD^23UY/HD]R5M);CEBJ7)Y=AE]R7^Y=>F%B86YB\F$6929D6FAF:#9OHF^>;
MUIO;FXF=89URG6J=;)V2GI>>DYZTGOA2J%:W5K96M%:\5N180%M#6WU;]EO)
M7?AA^F$8911E&67F9B=G[&H^<#!P,G`0<GMSSW1B=F5V)GDJ>2QY*WG'>O9Z
M3'Q#?$U\[WSP?*Z/?7Y\?H)^3'\`@-J!9H+[A?F%$8;ZA0:&"X8'A@J&%(@5
MB&2)NHGXB7"+;(MFBV^+7XMKBP^-#8V)CH&.A8Z"CK21RY$8E`.4_9/AE3"7
MQ)A2F5&9J)DKFC":-YHUFA.<#9QYGK6>Z)XOGU^?8Y]AGS=1.%'!5L!6PE84
M66Q<S5W\8?YA'64<995EZ6;[:@1K^FJR:TQP&W*G<M9TU'1I=M-W4'R/?HQ^
MO'\7ABV&&H8CB"*((8@?B&J);(F]B72+=XM]BQ.-BHZ-CHN.7X^OC[J1+I0S
ME#64.I0XE#*4*Y3BE3B7.9<RE_^79YAEF%>919I#FD":/IK/FE2;49LMG"6<
MKYVTG<*=N)V=GN^>&9]<GV:?9Y\\43M1R%;*5LE6?UO47=)=3E__821E"FMA
M:U%P6'"`<^1TBG5N=FQVLWE@?%]\?H!]@-^!<HEOB?R)@(L6C1>-D8Z3CF&/
M2)%$E%&44I0]ESZ7PY?!EVN859E5FDV:TIH:FTF<,9P^G#N<TYW7G32?;)]J
MGY2?S%;670!B(V4K92IE[&80:]ITRGID?&-\97R3?I9^E'[B@3B&/X8QB(J+
MD)"/D&.48)1DE&B7;YA<F5J:6YI7FM.:U)K1FE2<5YQ6G.6=GY[TGM%6Z5@L
M95YP<79R=M=W4'^(?S:(.8ABB).+DHN6BW>"&XW`D6J40I=(ET27QI=PF%^:
M(IM8FU^<^9WZG7R>?9X'GW>?<I_S7A9K8W!L?&Y\.XC`B:&.P9%RE'"4<9A>
MF=::(YO,GF1PVG>:BW>4R9=BFF6:G'Z<BZJ.Q9%]E'Z4?)1WG'B<]YY4C'^4
M&IXH<FJ:,9L;GAZ><GS^,)TPGC`%,$$P0C!#,$0P13!&,$<P2#!),$HP2S!,
M,$TP3C!/,%`P43!2,%,P5#!5,%8P5S!8,%DP6C!;,%PP73!>,%\P8#!A,&(P
M8S!D,&4P9C!G,&@P:3!J,&LP;#!M,&XP;S!P,'$P<C!S,'0P=3!V,'<P>#!Y
M,'HP>S!\,'TP?C!_,(`P@3"",(,PA#"%,(8PAS"(,(DPBC"+,(PPC3".,(\P
MD#"1,)(PDS"A,*(PHS"D,*4PIC"G,*@PJ3"J,*LPK#"M,*XPKS"P,+$PLC"S
M,+0PM3"V,+<PN#"Y,+HPNS"\,+TPOC"_,,`PP3#",,,PQ##%,,8PQS#(,,DP
MRC#+,,PPS3#.,,\PT##1,-(PTS#4,-4PUC#7,-@PV3#:,-LPW##=,-XPWS#@
M,.$PXC#C,.0PY3#F,.<PZ##I,.HPZS#L,.TP[C#O,/`P\3#R,/,P]##U,/8P
M%`05!`$$%@07!!@$&00:!!L$'`0C!"0$)00F!"<$*`0I!"H$*P0L!"T$+@0O
M!#`$,00R!#,$-`0U!%$$-@0W!#@$.00Z!#L$/`0]!#X$/P1`!$$$0@1#!$0$
M101&!$<$2`1)!$H$2P1,!$T$3@1/!&`D821B)&,D9"1E)&8D9R1H)&DD="1U
M)'8D=R1X)'DD>B1[)'PD?20``````````````````+V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8$!2GEC#UI[
M*A(R)TZZ+%0$9@17!&`$;`1C!%H$:01=!%($9`15!%X$:@1A!%@$9P1;!%,$
M9016!%\$:P1B!%D$:`1<!%$$4`1M!&X$<`1O!*V!1X:;8]^&`W#,5C45;T5U
M(PD)@K6DW01DFY5N5`BKO$D$.9\T<[5JW>"#L\L%D&LA&'#((2G-&W!`J/&V
MTYN]@;Z$9#'`A(>$6T!?A;V!P2(Z!\XB+&D#"I95+7#'A2`C-*8J(_^)/)DE
MA/";CH;SI#AP0BV]6+.&V:IR(W@C=&V)(X\CD2-<#Y,CYK9S(Z(C`B6M(TU5
M_CI,<#LQRR/F(_PC=207)%0D>22%))5-PE:@)$U76G"]@9[>"2=90$"ME(BL
MK?,DO8'BB8L^YI+;.55%"C(J$8P+J))=0R(7+24T)2O</B6]@9:1TY%F25,E
M6]Y@)6LE;B4G1;*^V1$<18$EA24)/@D@OBF9)6L-CXF@):NM8Z*V)7>*TR7Y
M0>LF%S@;/RTF4\N4<!TG3R9D)B8:F7":<#00#8M\W=B<!R<M'^\EET5&)VDG
MO8&7E/JMTA?UL7,X](WW)XTX2J5D.&TX#2@/*'%*L2A':+XEP"BO**TH)M_C
M"$^/!BEEKRX^"T("*7$)?LRF*<5PPRG4D".QYBFUMQPJ:BHA"*`JG"K0<+LJ
MORT#*=#H.+"39&$(WRIF.H,)V3_^D>0K$R=2DH56B2L.BX',*LV<DYDKNY-R
MDV;-,3_HDY62N2L%SFLL(RRF"?)PO8'("58LY463+&'/^7`%$-&4\@G]<$,P
MD"0V+4@W/"T.U802W1H&<94M(#,)<0IQI8:S+5TM4!_%+026TRU.1=0M998H
MRPDN71M%+JDNKRY++SF7=Y?0+M@N!B^DEWHNER]\5.T*0;6)F+.9!U3V"H(.
M[B]*/+V!.C`P<=.*9B5W(+V!:"4QD\DOM##"VKDPNS!@"[PP_CG;9,TP`8-4
MZYX-+ALZD/HPB,D0F[V!<9LC,7UH+LXR,0!D4'%G,78OWP]4<2J8N-"HG)9B
MWH/IW?$Q13A=<2,,1Q#Y"%`I])WQ2L`07C*]@7,R:''/M6IQ)$:A(F`L)#.D
M50(S<7&2SD$SM"-U<4<S:BUWK5^>DS-=WQWED#/R"X"?P9[C,1PSWC9+-9B"
MA30PDY4TC:(L-1^VUPSX-;@UCW&\D[V!"D&VHM1H3*Y=OJ$VI38[928-^C47
M#0TWED!HMF.V13<M-Q\W?J-U-X"U=QV1-U@3Z9.@-Z,WGS&`IM@WMZ2XI`0X
M9*1EI`LX]8LG.":[,SB]@;MQ\:2TVXBDT[M%2?>>9&K".%RQ8;;K#;H[`JJ]
M@2<Y(CG,<<UQESEI%^(YT#_\8L$Y9J9@S1TZUW&A.\L[G]XS.X,Z#:C!.L`Z
ML@_!#'RH0`YL.2$["MY\%?8Z6#MA#@F%XU10(KD[[W%JF04\\G%=/+,.<3F(
M/%SBS0[=//IQGC+U/#0]_G$U0%NJ]80"<@`*X26:JJ$]O*R</?<]BYL+<E'+
M&CZF4SD^O*M%%[VK9*],M4"U":NE"6L/&7)#;+FD''(/4?<Y)<UAS:O-5C\<
M/_P_A$"_M2=R,LZS5C3/AR.]@;V!KE7AWKV!+ZS314*M3$O//U$L2Z-X0<T)
M'4$PK'I`%Y']K=47L&3$0-Q`S@_T0$5RNP\?002O4T%*<A6O^:T@PDYR_ZZ?
M(Q:O%Z\`KUW%RT'^02="`4),0E5"5D)?0H03:!`T0Q9#-["K0L5"2"S*0KV!
M7"XEL<]"(F1K<JQ"&K)GMF*V.D.HWSU"CD,"995#T2H#9:1#`61Z<JY#P$.T
MM7TZU4/70]40@G+-.;U``D2]@:M$X[2KW&T;A-RH1*Y$3T4J19!RKLI)1<E%
MHJ^GDF2VXS>%"?>US;6;<G=%E47#.F:VN46A<E<1O8&MGN!%,N''161%]D4Y
M5>Q%\`GT1;%D[#L"1M,;LG(?K[FV3]\&+;=R7I1(1DB5CD:]@9Y&6>'+E9<M
MP7)%9,U&RD;G1NY&`KJ$$<ER#D?=11Y'-$>"1ZQ'T4?/1^]']D?4<A!(;U.X
M"M')SLDA2"5(-TA,2%_/XE6=NOVZXG*>2*9(P$AO-F"[V$ALI2])ZW+L<H&2
M=$F]@?!R\7**.B]*1TI32F5GKDH@O5=*M$HQ2LS2N&#$6>O>`'-<G`9+0%K"
M.@!+%[\=2SG6O$HI2ZH_YM`H$49+#>)42P````"]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8$@!"$$(@0C!"0$)00F!"<$*`0I!#0$-00V
M!#<$.`0Y!#H$.P0\!#T$<`-Q`W(#<P-T`W4#=@-W`W@#>0/V'_\?12!@($(C
M5B-K([DD^"0I)78ERBI`+9LO<P4_,+V!$#$A,?0VO8$21[V!M6"]@2@`Q@%]
M!GX&'08>!KV!O8&%!88%AP5\!GN!?8&]!,$%P@7#!<0%Q07&!<<%R`7)!<H%
MRP7,!<T%S@7/!=`%T072!=,%U`75!=8%UP78!=D%V@7;!=P%W07>!=\%X`7A
M!>(%XP7D!>4%Y@7G!>@%Z07J!>L%[`7M!>X%[P7P!?$%\@7S!?0%]07V!?<%
M^`7Y!?H%^P7\!?T%_@7_!0`&`08"!@,&!`8%!@8&!P8(!@D&"@8+!@P&#08.
M!@\&$`81!A(&$P8A!B(&(P8D!B4&)@8G!B@&*08J!BL&+`8M!BX&+P8P!C$&
M,@8S!C0&-08V!C<&.`8Y!CH&.P8\!CT&/@8_!D`&009"!D,&1`9%!D8&1P9(
M!DD&2@9+!DP&309.!D\&4`91!E(&4P94!E4&5@97!E@&609:!EL&7`9=!EX&
M7P9@!F$&8@9C!F0&909F!F<&:`9I!FH&:P9L!FT&;@9O!G`&<09R!G,&=`9U
M!G8&$`(1`A("$P(4`A4"`0(6`A<"&`(9`AH"&P(<`AT"'@(?`B`"(0(B`B,"
M)`(E`B8")P(H`BD"*@(K`BP"+0(N`B\",`(Q`C(",P(T`C4"40(V`C<".`(Y
M`CH".P(\`CT"/@(_`D`"00)"`D,"1`)%`D8"1P)(`DD"2@)+`DP"30).`D\"
MYP.X`[D#)8$F@1H@*('"(RJ!*X%((RV!+H&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@:*!I(%'@4*!L086`R$#&P8<!L`$Q`3&!,<$R`3*
M!,P$S035!-P$W03E!.<$Z@3L!.X$]@3\!/X$!@4*!0P%#04/!18%%P4>!2,%
MO8&]@;V!@P%0`5L!5`%U`=,`>`#+`(H!:@$```````````````````````"]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!_BX(+Q8O?!#/"F0O>2_@"O@*`C!],.4P0S'(
M"]0+_PL-#)<R_3*E+DD,=S-Y,X\S>`SL,U`TI338-+@,<2C##*(UNS7'-1HV
M"PV`-M4NX2??;U<-1C=]#;\W$SBR#5(XX@W6.`(.9#G`.1@."CI$.C(.,0X[
M#LDZ`SO<0R0[7SM%.WP.ECN=#B4\-#PQ/$(\K`Y9/+(.:SQU/)0\MCQ!/8$]
MJCTU/FH^2P_"/L8^YCY!/V\/9#]Q/Y4_F#^I/P9`@-T[0&)`6D"_;VA`:4"D
M0+1`Q@\!K0%!/D'J#_4/-T-9+@H0K$$1$-!!U$'O0?]!"4)EA$$6L0CP@!%S
M?BF3SKY"X+X."6([J=\T+<E+8;]9X^5+_4OLOSM,,$Q"3$-,44,E<TH46DQ=
M3&I,;Q1R)D'!BTS53*E,,'/^P2)-[TP<5?3`?\Q03:%5$DV]@;"M+1"EP1)6
M>DV]@;5-P<'$30-.17,F3CTX.+-)3D=.9D[T37-.=4Z]@>=/G1<$SMU.ELX-
M1@E/*T^U0C-/O8$7KNG#9$^3#W5/N9-E3V)SO8&AQ-K$[D\24*L5+&6G3\!0
MP5#'4+9*T,6A:A=1$<8C42&2*(+<%Z:I@Q<ZVGI1R<:]@8A1G5&]@:]1@7."
M<[M1O%'A489S"1SFQXES:,CE."=2"-Z'4II2<"HVG3\^V,:4<Z<VEG.84QZ4
M$SREMM6V^A:I4YYSTLJ@<[DA?9%B5N)4"LOGM7"G,Y/XJRI4VSK4ZUL4RU90
M5)I4EHMTDX$)M'.:I_M38E285$NL8\V[<Y?+#J@_$)U4K"<%58L79<TL5;V!
M4U4^!Y3.%SS:5E8'`L[-<]A5SW/Q55,09!=G/,I5U7/82KV!ELLWS@/.7E:]
M@1%5(!<35F16X7/`%,#!PQ>T5K(LYW.G%_-6EA=_.597Y=O[VP%7\'-"5_)S
MC=#T<^H7:%<("6*4MR7:T;Y7L5AXZ"Y9YZ#Q6!I93UDA**Q7%CJ/&(59AEF@
MTKFKI-*>6=Q9VQCT6?59@34%6O=(C]/'6LI:O8&]@>=:_%KEW2=;I-2]U=Q;
M$TF^8M!;6=5I3#K6)G23&3C6_$),7%]<,+REO']<C%R-7.E;NK;07-M<[ULV
M=)48CUF;71373]<4[.4)$]?675C7?=<27@->T)3;7=Q!$5Y(=%`1O8&I7@+8
M373*M3P.4'3,T&=,K5^V7\-?E&,98"U@9=J2VJ5@PV/?Z1")LV"J&Y[=/=N[
MJ[@P(J7Y8&=T:'1I=*6:0`R7SC=A/-N^U6%A;-O+VZAA='3$86;<KF&]@2=B
ML`UI8H1B+$[SW(F7SF)?/@%C(F/YO+V!AM[;JLS>&[V*=.QC*V2AWJO?#T*#
M+*+>I=[E&P1CK-_YW[_?,V0;9;Q?169F9N9D8&9V03D5H718W'R/+JQ?'-P]
M.V=69^P38V>5SIHS=F=U2J#>?6>,)2$<N,RT@Y#&K^'EX1&WU93*I?%G@E?V
M9X\<O1<%&,%T]4$!+=MGO8'&=!=H"BVKXA]HY620(K>CO*-):%]H<6A^:(!H
MDFB@:&R\KFB<1?/BO8&U:-WBW701'?1H\V@+:29IS@TUT=$/,(<<KT:^BFEW
M:8AIAVD_'2?-DY)P)Z%IIFFL:3AD^6EIMK(=%^3%Y+5JS&K[:M!J&&MEOH0)
ML>'5Y:!KHFN%Y;1K3A[4:^UKP-OT(?1K*,J#"WVC$&P`;'[F!2PCE$YL"[#"
M;+]LS&PHYQ1N-^@2Z1YU8>BCZ%_IOFW#;21U3FY(.@1N*'43Z:#I^Y2SZ7EM
M+G4O==!NU6[>;N)N=!_J;N]N)+$!;R`.I0R=#_(@?@KKWT)O2&_6'>1D8LU7
M;[V!>6]?*$HHA6]X:HOALFC_5:)OJ6]<3,YOED/^';6U^[7W0CBV"+&1MAY%
MFM^ZE!]+/MVVX"EDLV0$WJQC062+9"S=>;*70VL1\DC#2U!";76XL?Y"<'4C
M0GZ4V:='$464+[RXD^()NY)Z=:$)-)-]=4O#XPF`DALI9;:^D(1UAI`VD8-6
MYJB]@=55BW4ET3&LG+R[K!+0=!<NJ5WEYLZY.?,)U0YG$"PJFG70.=<2?ZF>
M=4NNH'4AS(LF7B@QR%(HIG6HB8V+AF2J=5QDN"#K(MD*]K%\(*6%OX0+(4HA
MD;TH+.N""X59#$J$5(7U!ND@`(0SX;6#&ES"=5@@C2+-(F(APR#(=4JL`B'N
M(2PB02*,(:4A&"*\(KV!O8&]@;V!]C_5I]AU?ZPR/T242:QH(X,CX(9=%^.%
MTH71A7I>7-Y.AQDD9"0SB*$DO8'Z&`Q#3+$@BNRU\761.YV+O8%>$1E&E$76
M11A%SAW\MDVND"5$"(]#B:YT)X6$C2;&B=TH'6.T9R9DG2E-*3\I_@B+*EDL
M!MZZDB^3T)+L*W@K3V,^+(\LTBL9=K.5(90<=K4)Q3[#1>$KP\)!+)??4X6@
M9`Q&`Y"%0O(;R&2[W7UD8`K>+5XN'C`(,%:5/)5NJHTP#RW#E,24P0E@E)T)
MOI*3":I2!][ZEO*F:-W,,,XPYY1&=BLL^Y($+517O=*@63XR8)YKG)LQ.!$O
MG#Z<5'8SSX`S_H$&@EN<63-8,S4R6Z''H12T8'8Q-J6S:J#I#"*@T*:JY/BB
M]S1J=G8V\321-2.V)Z)D-&&A^S4K-S([M`Z.HVVER;5KI<TFH*69E'UVCCA)
MI8!VH`T0%,2\XM[/O+R2F[PEO&Y*`Z3JD_2D)`>.=D*DB;!.."3-*SC3'?`W
M<-27=B,XDJ6AI=XW,K^1"YYV_*E9#N*I?J901E8.3SEJLW8ZWCF$#GX\(PL5
MJD>R\SL2/(D\Q3S2E-$V6#H,/)<..CP7/8"MVJI@9+)CJM^+WDECP':<W2=E
M93^+0,5VO8$_K0\0A#_\K?TKBC\'*N0^PDF[0MJP-K!Q0M!#!T041(^T9;0Y
M(^2VZX;Z1;BLWG;?=E>UH<.&$3$1'[?CW_6L9S)S$4Q&O$5'9+=%'Q>JS=$7
M`T?C$5FXAKC8$=5&\T>&ZMD-Z$6,WNNUSK6[#4T0CK9_$0%W,[6Z8O(H`F2C
MWB24GR)ANR>[^$CRI(Y(CTC[2->SP:D>#1-WN$4;1C\1^K8'MT@3UK8NQ<=C
MP;R>20U*"$I22E!%V4K!TR5WCA.]@196)4OM.[JLNDMT2^X3II*R$_5B<4L,
MB\RUV8.ZJRZ35P@K)S`(:@D4@SUW8DP9+#6=07<<P,TKFX-P2NHK!L%^3'D4
MW4WM39$4\\#\PN;"34XYME)W#D[\32Y.<CQ<3X=/4T_.4*'%W,1==Q=/PL+J
M%&%W5HB6.0Z"#ZB$*9+&:'>BM5U1ITSLAVG`0\*,3(["IFJ%5R-KW#MU=Z(,
M-[:MQ]]J>G<`5N?0?7=J%[=2@A9&4HE2PE+TR(-IPLKB4^53T<K356?-4%=;
MT48L_Q.0=^LL892D+)B4X%=H6)=W;5DBTL(KKED%(<=9_UDF6J5:C5K#O91:
M!=0$U*9WF=]<W[G=+1$C5G493QFR"GU;7%L(XPTQZV*T=Y0WJ4)$0@64K6V?
M7>E=G-=:*T-)L"ON%90)*E^G7\FW,&!*8'05&#X[0:&:&QOY0`M`FI.I;'4)
M;[6[8;V!,2>&&WMBQ&0+WN(2VG?G9-W?W7=E5FM;669G9E=F5F9TX,5%0A$_
MM>AWZ7=G$>6D3V?M=^;@Y>!,$?%WN+:NK9)%ZT5\$0%HL.$'.IT<^W?\=[V!
M*&1)W0!X[]Y^QGICT2RI7+P;>47;KUMH,6CX:0QX@2^%W_*VWVA:X[9C$WBE
M8D`7$-^GMB3?G&D%WH`1ZF*E&Y15^VD-:B%X?1!;:J\=:FH<:R7?*'A//.%J
MOBSO:BUXT!TO>'QJ_1W7'3UD,BH"D.(I^+5HD<1)7YVXJX4Z_0\89><+$#/!
MG6N?QS(/;1-M.VWU;-!L/VR/;.WF7VQ->'[H86WN'L2N6&[P'DQM57A6>'/H
M[^3E;3U66WB?SUUX/%>S%V3-1,ZPS:!5+E=E>!>J),1B2]RG@*BM&QZVX@^;
M9'YC"&3_@SE*-V,-9:0A``=D89V\O4G4239*RTD7DXFD@;5:"3(A6D%90;V!
MGD'4)8=X>RFS*DHI5FV7*;1";P>/>&M#D7@7NKV!=9,)WLPRCBS+*SP52++L
M";L=O-U[9'ADEI2A>/)5P,RD>+JPYJ"!L50KMZN!R"A/V\1DQ/FUR[6ZW:5C
M8D5I$31&(]]?E&$1\[:8/'-%>T56$7ZVU+:9DZ:VYX3">,-XR$56M25"MK5$
M8V9%'V0^AO%CS7C6W49DI]\5O;4;0M[K0M5XUGAD*!J'V7C:>,(F1$NZDWY/
M@I*0MN%XKA?!9,H)Y7CMM7`K?Y1#E$3282RB"5NK<`D?8SDL0=XBE#1D30]T
MB=8<2@RT(ND/S`]<D/5">Q7^>(\_Y.%K%Q<_S]?G06\^5@^MK2VL@C^,0.\/
M-8711GP)B`<`&5H1\1J$*RYCOAM!8!=Y&'G2*8@IE@G2D'Y"(K$?>2.CL(_]
MFGDZ)SLE>26G=-8?J4/>%JHK>1^XVCOMJ+?,OE5?%TX7)LTT>8+,GL^70,G0
MO53ZDFU5@,P3T)N322M"+'.3(2PQ+,64O*_M":\K_)*'"0Y#4&1:.&6P+BSK
M*U!YZSNYK+;3&[**L)U"&;"AW7`A*,V"+HZRS==]L<P[%K`$D"9"LT*IL240
MGSYG>8^VY4^K*^\N<Q`<,6YY;WDD3Z95129S><"E5(,^*7=Y&8=E$GIY>WF#
M07UY,"\/15-.&=Z">8@A9U%-1)!$]-6X1+E$-K[!1,A$*1$8UFQA=4.1>6%%
M=E-*$8Q(41%B/KTHF46>19]%8A%P$701>A%31HX1TQ'"1NU&\D8-1_P12$=<
M1T`2S4=7$O1'7!+Z1]RY"$/C)\!:*2J=$L-(N1(A.<42FP@82>H2[Q(>+CY)
M2TFR*IA).4*<22@3N4G'2=%)YDG(5<MYLTK#.;)*@Q.)$Q%+&4N[8(9+O&#G
M$Q%,,A0\3/E31!1/3%M,3Q3A'^),[$S[3))-FTW@%/H4^TT<3@P5.$X4%6U.
MDV!`0L^*3T]43U!/?4\N4311'T07%J!1I5&Y3*Y1L5'444P0="D@0C=2:5)M
M%HQ2JD2.4I)2X$:44H$6^0W64ME2VE*3%OHI_%($4Z46$U.M%B53KRE!4V13
MU%,/%R94]E-*5%A4?U0P%]=4*6=*.X55=4+D5:,R"%:$%SY6859X5I!6N%;2
M5KL7[U;P5B!7]Q>R5])7\E<O6`5GRUB&&)<8[ED_6F1:AUK16N?4:5MX6]1;
M]%M17=1=\ET<7A@:'RK#7FT:KB`Z7Y@G%"EQ7[4GL%^W&LY?XE_D7^U?\E^W
M8,%@RF#,8#-AA&HM&Z!ITV*>&^AB&&,K8W%C;F-_8Z-CJV.S8[1CO6,#9$1D
M;63%&]$;_V[79,$DW63M9/YDZAL493EE[65B9B<<M&;S9F4<8#FD'`!HM1QR
M:()H%"@D':@R>6E9';%I!"K.:=EI="/<:?=I`FH=:B)JL!V%:MT=_&K/:P-,
M*6Q!;)ULL6RT;*T>X&PO"BEZB6WZ;#YO$"C3;?UM`&X\;K9EMF"[;NQN\6[]
M;@9OG&4B;S%O.&](3(1O/WI`>D%ZVCJ#96PK17H`*H%E>0I)>DIZ2WI,>A<I
M\T)/>E!Z47HJ)E-Z5'I>)E9Z5WI3BEEZ6GJG,EQZ.BA>>E]Z8'IA>F)Z8WH5
M.^]LY5AG>HZ+:7IJ>JV,;'K@+6YZRR]P>G%ZMHW>.+N-=7IV>@<)>'IY>GIZ
M>WHD)2U6XX]_>H!ZP5R">H-ZA'J%>C@@.T*(>HEZBGJ+>HQZC7J.>H]Z@S35
MEY)Z&$,5.I5ZJ3N("7R:F7J:>IMZG'J=>GU4GWJ@>M6?Y5JC>J!@I7IX:*=Z
M!VE]:ZIZO8&L>JUZKGK(H;!ZL7JR>K-ZM'JU>K9ZMWJX>KEZ<3$(.'\XO7J^
M>K]ZO8'ZM;V!PWK$>KV!AH1U*LXXV#K*>A?3HL/->LYZOM+:F%`;^!S3>EK>
MU7K6>ONMV'I6L=IZVWJ2(Q&'7RNHEWX./ZOB>N-Z2"GE>EL,YWKH>NEZ(@H#
MFIY<#M^]@>]Z\'KQ>HE#\WIXBB4K]GKW>KF'VE_Z>D\D_RCQ0OYZ_WH`>^>V
M?"<#>VZ\4LN]@3,'"'ORT@I[F!D,>Z:\Q[Y_M1![)B*[!Q-[O8$5>_P9"-TN
MP!E[1L$;>V$IT4*]@1][DM9682)[&KJB7"5[)GL;+_?+O8$J>RM[*EPVMBY[
MKZT2QP`>,GLS>UN=)67AOE4SYRN-Z[V!>2CALCU[*B`_>Q9G3S^]S-@(MUI%
M>V[)D<9>R;V!2GO"3$Q[T8A.>[V!4'O%2[V!>LKF:E5['PE7>UA[`TM:>UM[
M["Y=>[V!7WM0&6%[NT:E661[=BK<"0V<:'MI>Q0/:WML>T%CNIEO>_!CIM%R
M>_D]7V5U>WB,9UDU6GE[>GMQDSA`:K9^>V0,>0F]@;V!OQ=V."WF9.2#6HA[
MB7N6*%\3RI%A#&^ICWN%D"U#YE23>VCBO8'W'F_0:]V9>YI[FWN<>SJOPTS^
M2@G8-4$?ZL,[I'MB):9[?V3V.1UH+]FK>S7*K9#OI*][12_PW[)[U2CC:`G=
M:R_(M7XWE3N2)>6V0:W1#O8XOWNTV.[889C#>\1[Q7O&>\=[R'O)>XH(RWLJ
MW'H;IC7/>XA)%6/2>W(6U'M?%M9[UWO8>[@KVGN]@=Q[W7N]@1#BX'MW$.)[
MXWO08`]$2RCG>^GCZ7OJ>^M[['OM>RKE[WOP>X[E\GOS>Q]0]7OCY^0>!V;Y
M>R)#^WN1'Q)A_GN<'YR*OF"!)[I@!'RY8-.VB1?_3]9`<3RJ(*0'[-X.?/H)
M@%^UDQ)\+-]9WQ5\+\AK$!73]ZIUO9:_6B#!PIC%?RCMBPY?+2U(K!ZXGC6]
M@;:3.Y3P-NTGBL':)=&[1A`O?+T>XB?>)\E0&,,U*S9\L%C<'RJ-"8OZJ)=2
MGFT87KM'!6W.1SE)!63R)<A2=U3E)[)2F%4]4JHGXDH#*-8E3WR.",4GL2>Q
M..+9[0BT1K`G>B=7)C(G08I<?)`PR+KVBV!\87SK;MI.GB>UC5TT+6A4)LU=
M=D,V8KPU>36^-2DG<'PR;7)\6B.?!V>+9R,-)MXFTR;F1RU??'PQ1S921%G&
M6`=:-E.<50&.;!>$1$:T4"V+5)/).R@TG>_68Z\SUY#.D7PP8AF/R&(\J^GJ
M+(QYC.9#8I;.&4*ZG7PKC7H3'6W?-F"B<QND?+SF+(V*B[V!J7PMC;V!K'S'
MCB-##E"0;=H?Q!\W",TL<CXG)6P)G`P])64)NWQ:*FZWK5,+)FHIP7RYB+V!
M$@UEF_1$;.=)'ZUL/JOPYYL>*;J>X\]\W%6VJ])\\\A@J>XTI4ZWK"RLZ@P(
M88PD]!`Z"6D8WWS`1[`L-HSZ238:9RH_$SPH2VPT+]1'ZWS%;B$?O8&["MDR
MVJ.RL;V!'2BICV<IH[7X?/0C;M!M"+V!O&W63?EKGBDLDQ,NDS8$?05])-'M
M5PA](LTBMPM]O8&^(PY]3B_#9Q&7P6Y,89],PFN1+B--*#3U-+]K3TWJ:_Y-
MO8'"309.U6Q\3<EKO8';;'ZUFF\S)X,MO2'8;K(A("2&$)$D)RD6(G<KTB^(
M:.MM7&`I)G1H`&IZ:.PD\#+L.IHERFQ";7L>`6=`.V8BQD8MDYIJ,R2]@1EB
M06<<8KV!$6)/?3\U(\V*/-$G3F+Z1D4T/(7/1/!-6GT]J[V!6;562%ULZA_4
MBCY5@EF]@0HN@#N]@3HIWR.U+XX@\3UM??D@7"::)EHD@EZ^"+V!LPB]@1(]
M/&+E;U=L[FAT:7IKZ&[$;OI"E$R]@;H]6%GX4+V!X">(?7=?DV^]@=1>3U]<
M;@%?0C1]VBA?=5]33+>VODM82JH^IUN'1QK>9F^./A990T?RZ=-)`.L,7F)$
M\41M7()$<4;K7?NV;U=Z,>!9-Q>]@?N3Q<V]@;Y;VYN]@;TRYT>7:X1M+F1/
M;#59O8&]@?==K$3A9W!LE@@R1$<>T4T*:MG$&3-$'M9N/3.]@1\I+S-F-/DS
MO8$<#:(S:B5UIB0UPCF2"!<O@M_:8-U]O8&9(H:6ADKR)/AFNXSE$KV!?DF]
M@4).ZGU:3JU+YE'C4<U.A49R1M1:FE/,..)11M+;47!&@U*D2,E:#,G31I'.
MZ5@.64A3S%B)6ZU=@URK2'A&6E;U"'([IEZ]@>E:O8%Y/P%9T:UG1EL0]D)D
M,EPS40^]@3<RO8'Q4.W>O8&I,KX=X"/8#@>K%\,6TR5^!)7^C\/DG,UMT($N
M+<7/W;>H;H(P?HZYXA??+#1^D&_F;C=^````````````````````````````
M````@````,```````0``0`$``,`!``!``@``@`(``,`"````!```0`0``(`>
M``#`'@```"$``$`A``"`(0``P"$``$`D``!`)0```"<``(`N``#`+@```"\`
M```P``!`,```@#```,`P````,@```#0``$`T``"`-```P#0````U``!`-0``
M@#4``,`U````-@``0#8``(`V``#`-@```#<``$`W``"`-P``P#<````X``!`
M.```@#@``,`X````.0``0#D``(`Y``#`.0```#H``$`Z``"`.@``P#H````[
M``!`.P``@#L``,`[````/```0#P``,`\````/0``0#T``(`]``#`/0```#X`
M`$`^``"`/@``P#X````_``!`/P``@#\``,`_````0```0$```(!```#`0```
M`$$``$!!``"`00``P$$```!"``!`0@``@$(``,!"````0P``0$,``(!#``#`
M0P```$0``$!$``"`1```P$0```!%``!`10``@$4``,!%````1@``0$8``(!&
M``#`1@```$<``$!'``"`1P``P$<```!(``!`2```@$@``,!(````20``0$D`
M`(!)``#`20```$H``(!*``#`2@```$L``$!+``"`2P``P$L```!,``!`3```
M@$P``,!,````30``@$T```!.``!`3@``@$X``,!.````3P``0$\``(!/``#`
M3P```%```$!0``"`4```P%````!1``!`40``@%$``,!1````4@``0%(``(!2
M``#`4@```%,``$!3``"`4P``P%,```!4``!`5```@%0``,!4````50``0%4`
M`(!5``#`50```%8``$!6``"`5@``P%8```!7``!`5P``@%<``,!7````6```
M0%@``(!8``#`6````%D``$!9``"`60``P%D```!:``!`6@``@%H``,!:````
M6P``0%L``(!;``#`6P```%P``$!<``"`7```P%P```!=``!`70``@%T``,!=
M````7@``0%X``(!>``#`7@```%\``$!?``"`7P``P%\```!@``!`8```@&``
M`,!@````80``0&$``(!A``#`80```&(``$!B``"`8@``P&(```!C``!`8P``
M@&,``,!C````9```0&0``(!D``#`9````&4``$!E``"`90``P&4```!F``!`
M9@``@&8``,!F````9P``0&<``(!G``#`9P```&@``$!H``"`:```P&@```!I
M``!`:0``@&D``,!I````:@``0&H``(!J``#`:@```&L``$!K``"`:P``P&L`
M``!L``!`;```@&P``,!L````;0``0&T``(!M````;@``0&X``(!N``#`;@``
M`&\``$!O``"`;P``P&\```!P``!`<```@'```,!P````<0``0'$``(!Q``#`
M<0```'(``$!R``"`<@``P'(```!S``!`<P``@',``,!S````=```0'0``(!T
M``#`=````'4``$!U``"`=0``P'4```!V``!`=@``@'8``,!V````=P``0'<`
M`(!W``#`=P```'@``$!X``"`>```P'@```!Y``!`>0``@'D``,!Y````>@``
M0'H``(!Z``#`>@```'L``$![``"`>P``P'L```!\``!`?```@'P``,!\````
M?0``0'T``(!]``#`?0```'X``$!^``"`?@``P'X```!_``!`?P``@'\``,!_
M````@```0(```("```#`@````($``$"!``"`@0``P($```""``!`@@``@((`
M`,""````@P``0(,``("#``#`@P```(0``$"$``"`A```P(0```"%``!`A0``
MP(4```"&``!`A@``@(8``,"&````AP``0(<``("'``#`AP```(@``$"(``"`
MB```P(@```")``!`B0``@(D``,")````B@``0(H``("*``#`B@```(L``$"+
M``"`BP``P(L``$",``"`C```P(P```"-``!`C0``@(T``,"-````C@``0(X`
M`(".``#`C@```(\``$"/``"`CP``P(\```"0``!`D```@)```,"0``!`D0``
M@)$``,"1````D@``0)(``("2``#`D@```),``$"3``"`DP``P),```"4``!`
ME```@)0``,"4````E0``0)4``("5``#`E0```)8``$"6``"`E@``P)8```"7
M``!`EP``@)<``,"7````F```0)@``("8``#`F````)D``$"9``"`F0``P)D`
M``":``!`F@``@)H``,":````FP``0)L``(";``#`FP```)P``$"<````G0``
M0)T``("=``#`G0```)X``$">``"`G@``P)X```"?``!`GP``@)\```#@``!`
MX```@.```,#@````X0``0.$``(#A``#`X0```.(``$#B``"`X@``P.(```#C
M``!`XP``@.,``,#C````Y```0.0``(#D``#`Y````.4``$#E``"`Y0``P.4`
M``#F``!`Y@``@.8``,#F````YP``0.<``(#G``#`YP```.@``$#H``"`Z```
MP.@```#I``!`Z0``@.D``,#I``"`Z@``P.H```#K``!`ZP``@.L``,#K````
M[```0.P``(#L``#`[````.T``$#M``"`[0``P.T```#N``!`[@``@.X```#S
M``!`\P``@/,``,#S````]```0/0``(#T``#`]````/4``$#U``"`]@``P/<`
M``#_``#`_P`````"`$```@#```(```$"`(`!`@#``0(```("`$`"`@"``@(`
MP`("```#`@!``P(`@`,"`,`#`@``!`(`0`0"`(`$`@#`!`(`0`4"`(`%`@#`
M!0(```8"```'`@!`!P(```@"`$`(`@``"0(`0`D"```*`@!`"@(`@`H"`(`+
M`@#`"P(```P"`$`,`@"`#`(`P`P"`$`-`@"`#0(```X"`$`.`@"`#@(`P`X"
M```/`@"`#P(`P`\"```0`@!`$`(`@!`"`,`0`@``$0(`0!$"`(`1`@#`$0(`
M0!("`(`2`@#`$@(``!,"`(`3`@#`$P(`0!0"`(`4`@#`%`(`@!4"```6`@!`
M%@(`@!8"`,`6`@``%P(`0!<"`(`7`@#`%P(``!@"`$`8`@"`&`(`P!@"```9
M`@!`&0(`@!D"`,`9`@!`&@(`0!L"`(`<`@!`'0(`@!T"`,`=`@``'@(`@!X"
M`,`>`@!`'P(`@!\"`$`@`@"`(`(`P"`"```A`@!`(0(`@"$"`,`A`@!`(@(`
M`","`(`C`@#`(P(`0"0"`(`D`@``)0(`@"4"```F`@!`)@(`@"8"`,`F`@``
M)P(`0"<"`(`G`@``*`(`0"@"`(`H`@#`*`(``"D"`$`I`@"`*0(`P"H"```K
M`@!`*P(`P"L"```L`@!`+`(`@"P"`,`L`@``+0(`0"T"`(`M`@``+@(`0"X"
M`,`O`@!`,`(`@#`"`,`P`@``,0(`@#$"`,`Q`@``,@(`0#("`(`R`@#`,@(`
M`#,"`(`S`@#`,P(``#0"`$`T`@#`-`(``#4"`$`U`@"`-0(`P#4"```V`@!`
M-@(`@#8"`,`V`@``-P(`0#<"`(`W`@#`-P(`P#H"`$`[`@"`/`(`P#P"`$`]
M`@"`/0(`P#T"```^`@"`/@(`P#X"```_`@!`/P(`@#\"`,`_`@``0`(`0$`"
M`(!``@#`0`(``$$"`$!!`@"`00(`P$$"``!"`@!`0@(`@$("`,!"`@``0P(`
M0$,"`(!#`@#`0P(``$0"`$!$`@"`1`(`P$0"``!%`@!`10(``$8"`$!&`@"`
M1@(`P$8"``!'`@"`1P(``$@"`,!(`@``20(`0$D"`(!)`@#`20(``$H"`$!*
M`@"`2@(`P$H"`$!+`@#`2P(``$P"`(!,`@#`3`(``$T"`(!-`@#`30(`0$X"
M``!/`@!`3P(`@$\"`,!/`@"`4`(`0%$"`,!1`@``4@(`P%("``!3`@``5`(`
M0%0"`$!5`@"`50(`P%4"``!6`@!`5@(`@%8"`,!6`@``5P(`0%<"`,!7`@!`
M6`(`P%@"`$!9`@"`60(`@%H"`,!:`@!`6P(`@%L"`,!;`@``7`(`0%P"`,!<
M`@``70(`0%T"``!>`@"`7@(`P%X"`$!?`@#`7P(``&`"`$!@`@"`8`(``&$"
M`$!A`@"`80(`P&$"`$!B`@#`8@(`0&,"`(!C`@``9`(`@&0"``!E`@!`90(`
M@&4"``!F`@"`9@(`P&8"`$!G`@"`9P(`P&<"`$!H`@"`:`(``&D"`(!I`@#`
M:0(``&H"`$!J`@``:P(`0&L"`(!K`@#`:P(``&P"`$!L`@"`;`(`P&P"``!M
M`@"`;0(`P&T"``!N`@!`;@(`@&X"`,!N`@``;P(`0&\"`(!O`@#`;P(``'`"
M`$!P`@"`<`(`P'`"``!Q`@!`<0(``'("`,!R`@"`<P(``'0"`(!T`@#`=0(`
M`'8"`$!V`@"`=@(``'<"`$!W`@"`=P(`0'@"``!Y`@!`>0(``'H"`$!Z`@"`
M>@(`P'H"``![`@#`>P(``'P"``!]`@!`?0(`@'T"`,!]`@!`?@(``(`"`("`
M`@#`@`(``($"`$"!`@``@@(`0(("`,""`@``@P(`0(,"``"$`@"`A`(``(4"
M`$"%`@#`A0(``(8"`("&`@#`A@(``(@"``")`@!`B0(`@(D"`,")`@``B@(`
M0(H"`("*`@#`B@(``(L"`$"+`@"`BP(`P(L"``",`@#`C`(``(T"``".`@!`
MC@(`@(X"`,".`@"`D`(`P)`"``"1`@"`D0(`P)$"``"4`@!`E`(`P)0"`("5
M`@#`E0(`0)@"`("8`@#`F`(``)D"`$"9`@"`F0(``)L"`,";`@"`G`(``)T"
M`$"=`@``G@(`0)X"`(">`@#`G@(``)\"`("?`@#`H`(``*$"`$"A`@"`H0(`
MP*$"``"B`@"`H@(`P*("`("C`@#`I0(`@*8"`$#X`@"`^`(`P/@"`(#Y`@#`
M^0(``````````````````````````````````````$-^1'Y%?D9^1WY(?DE^
M2GY+?DQ^37Y.?D]^4'Y1?E)^4WY4?E5^5GY7?EA^@`!!``T!0`"2`$D`F@!(
M`,P`4P`1`5(`97Z^`F=^P`)*`($`80`.`6``40&3`&D`FP!H`*L`;0`0`6P`
MS0!S`!(!<@#K`'H`%`%Y`!8!&`$:`1P!?`"$?K\"AG[!`FH`80&*?HM^O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!:>KA?KV!RC:]@;V!_1]=
M0(YMGV*]@;V!M=-1-MH@Z"!H(18C-"-<(Z0C821H)/LD#B61)9@EHBBP*L0J
MQRKR*O0J)BU>+5\M6BY&,/LQ23>^.<0Y)3H./SQ"M48D4"Q0.E!'4$]07U"&
M4+=0^E-/5.]4!EO^7")=9F!G8&Y@D45\3DU/!CM)3.<CO8&]@;V!O8%,8CA*
M'F(\4KV!"UYV4C!_O8&]@1]2!V\-'PEN3&Y^'CE_SL]*;CQ_@0B]@1I`OE.9
M1KV!D1LL:T]KV6\'2TA_"I?0ADM_Y!]!($`@1R!_(*L@]R`,!WTAR!##(4@B
M/0=3!V4'1B/%*ILCO"/%(TD@.210).<DAPAI)1$(<"43"((EXR4M"#((00E3
M)F,F="9Y)I`FKR;8)N,FZ"98"/\F90A_")<GA0A]?^4FO8%"BH%_@G]0)X:A
MK`R!A$9?^+B)?],2?MCZ2(U_]`Q5&I!_<LHJN9TVE'_TC-6*-(Y--GY?FG^;
M?YQ_G7^6V9.RO8$&BZ)_J=AT&J5_IG]R:R<-J7]M$L8'A[NM?ZY_KW^N;=5H
MO8%9%F7$=#:C)K=_N'^WC;L,KXV\?[U_OG^J-L!_0XIH7^&9#-_%?[V!BQK(
M?WH2,RK+?[V!S7\\AL]_T'_1?SDG.Q,Z%KV!]!S7?]A_*E.U:=M_.36^#+6=
MP%YA*#PVPQ"]@>1_B8O/G^=_O8$(CNI_4@S&#.U_.`CO?P>9$BBQC/-_]']\
M!_T]]W^]@;V!^G_[?_Q__7\-X/J+`(`!@!-1`X`#GCF?NP@CNPB`S8PJC!,2
ML(P'BPZ`#X"]@2N,$H`(BP".?8YY$M:<\C7MC'2F^=*.H#Z+/XL1H16AV`PB
M@`>.KHPE@%#+)X`H@"F`:F:,)D14>2>]@8/GYFQV:][3,X#`0NU2;%+<+7+'
MM%)7"A\E?=AV8GJ,CXOWBWN,G0@KN<D(UHIO*/6="8Z0B_B+N(V(CD?9U9#Y
MBU"Y9*(4+%V-7HTUCC:.7"F1BU33S=GUC/N+_KK#"?:,P(Z8NV*`8X#ZDV6`
M9H!9*B@DV@AJ@#)-*"V`&FP=9V]G'-]L36RTP#VDNR>R"$DHZ!_"*GJ`>X`1
M:'V`&R![(/X'XRT1,80QN@L,-/4V.CWU/?H][$&K0^P?+42.@-)0NTIY3M-0
MDX"!![V!EH""40!2F8":@!TEI%D!6YZ`X%P=7D5E.&8_9JAFI8"F:#5ICFF>
M:2-JJX`\;5]N!&\O/=QO]Q^R@-UF]S-B90``````````````````````````
M````````^?GX^>;Y[_G=^>CY\?G?^>SY]?GC^>[Y]_GE^>GY\OG@^>OY]/GB
M^>?Y\/G>^>WY]OGD^>KY\_GA^?KY^_G]^?SY_OG9^=SYVOG6^=OYV/G7^0``
M````````````````*````"@````H````*````"@````H````*````"@````H
M````*````"@````H```"`````````````````````"<````G````)P```"<`
M```G````)P```"<````G````)P```"<````G````)P```"<``(``````````
M```````F````)@```"8````F````)@```"8````F````)@```"8````F````
M)@"`````````````````````````````)0```"4````E````)0```"4````E
M````)0```"4````E``(`)````"0````D````)````"0````D``0``````",`
M```C````(P```",````C````(P```",````C````(P```",````C````(P``
M`",````C````(P```",```0B````(@```"(````B````(@```"(````B````
M(@```"(````B````(@```"(```@`````````````````````````````````
M`````````````````/__$`#__R```0`A````(0`(````````````````````
M```````````````P#/\!,`(P#O\G(!O_&O\?_P'_,/XF("4@4/Y1_E+^MP!4
M_E7^5OY7_ES_$R`Q_A0@,_YT)33^3_X(_PG_-?XV_EO_7?\W_CC^%#`5,#G^
M.OX0,!$P._X\_@HP"S`]_C[^"#`),#_^0/X,,`TP0?Y"_@XP#S!#_D3^6?Y:
M_EO^7/Y=_E[^&"`9(!P@'2`=,!XP-2`R(`/_!O\*_SL@IP`#,,LESR6S);(E
MSB4&)@4FQR7&):$EH"6]);PEHS(%(:\`X_\__\T"2?Y*_DW^3OY+_DS^7_Y@
M_F'^"_\-_]<`]P"Q`!HB'/\>_QW_9B)G(F`B'B)2(F$B8OYC_F3^9?YF_E[_
M*2(J(J4B("(?(K\BTC/1,RLB+B(U(C0B0"9")I4BF2*1(9,AD"&2(98AER&9
M(9@A)2(C(@__//\5(FC^!/_E_Q(PX/_A_P7_(/\#(0DA:?YJ_FO^U3.<,YTS
MGC/.,Z$SCC./,\0SL`!945M17E%=46%18U'G5>ETSGR!)8(E@R6$)84EAB6'
M)8@ECR6.)8TEC"6+)8HEB24\)30E+"4D)1PEE"4`)0(EE24,)1`E%"48)6TE
M;B5P)6\E4"5>)6HE827B)>,EY27D)7$E<B5S)1#_$?\2_Q/_%/\5_Q;_%_\8
M_QG_8"%A(6(A8R%D(64A9B%G(6@A:2$A,"(P(S`D,"4P)C`G,"@P*3!!4T13
M15,A_R+_(_\D_R7_)O\G_RC_*?\J_RO_+/\M_R[_+_\P_S'_,O\S_S3_-?\V
M_S?_./\Y_SK_0?]"_T/_1/]%_T;_1_](_TG_2O]+_TS_3?]._T__4/]1_U+_
M4_]4_U7_5O\```````````````"!>+F2SXB[6%)@IWSZ6E0E9B57)6`E;"5C
M)5HE:25=)5(E9"55)5XE:B5A)5@E9R5;)5,E9256)5\E:R5B)5DE:"5<)5$E
M4"5M)6XE<"5O)9,E````````````````````-````#4````V````-P```#@`
M```Y````.@```#L````\````/0```#X````_````0````$$```!"````0P``
M`$0```!%````1@```$<```!(````20```$H```!+````3````$T```!0````
M40```%(```!3````5@```%@```!9````6P```%P```!=````7@```%\```!A
M````9````&4```!F````:0```&H```!K````;P```'````!Q````<@```',`
M``!T````=0```'8```!W````>````'D```!Z````>P```'P```!]````?@``
M`'\```"`````@0```((```"$````A0```(8```"'````B````(D```"*````
MBP```(P```"-````C@```(\```"0````D0```)(```"3````E````)4```"6
M````EP```)@```"9````F@```)L```"<````G0```)X```"?````_P`````"
M```#`@``!`(```4"```&`@``!P(```@"```)`@``"@(```L"```.`@``#P(`
M`!`"```1`@``$@(``!,"```4`@``%0(``!8"```8`@``&0(``!H"```;`@``
M'`(``!X"```?`@``(0(``"("```C`@``)`(``"4"```G`@``*`(``"D"```J
M`@``+`(``"T"```N`@``+P(``#`"```Q`@``,@(``#,"```U`@``-@(``#<"
M```X`@``.0(``#H"```[`@``/`(``#X"```_`@``0`(``$$"``!#`@``1`(`
M`$4"``!&`@``2`(``$D"``!*`@``2P(``$P"``!-`@``3@(``$\"``!0`@``
M4@(``%,"``!5`@``5@(``%<"``!8`@``60(``%H"``!;`@``7`(``%T"``!>
M`@``7P(``&`"``!A`@``8@(``&,"``!D`@``90(``&8"``!G`@``:`(``&D"
M``!J`@``;`(``&T"``!N`@``;P(``'`"``!Q`@``<@(``',"``!T`@``=0(`
M`'8"``!W`@``>`(``'D"``!Z`@``>P(``'P"``!]`@``?@(``'\"``"``@``
M@0(``(("``"#`@``A`(``(4"``"&`@``AP(``(@"``")`@``B@(``(L"``",
M`@``C0(``(X"``"/`@``D`(``)$"``"2`@``DP(``)0"``"5`@``E@(``)<"
M``"8`@``F0(``)H"``";`@``G`(``)T"``">`@``GP(``*`"``"A`@``H@(`
M`*,"``"D`@``I0(``*8"``#X`@``^0(``/H"`%NV:K81$&BV&Q`2$`X0%1!H
M/Q`0@;87$$9`0T!P$.T0Y[KN$.:ZT;H1NX%!T+K9N@J[]!#:NMVZR+KBNNFZ
MR[I\0<RZP;IJ0=ZZB$'R$/@0\Q!1NQ*[^A#@NBN[M/;8P-'`$$32P,W`'T2V
M$;<1/<$/1,K`NA'+P+P1U\#TPSL2TT4O$H?$B\2#Q#<2F1+%Q]+'QL?3Q]D2
MV!+7$O#'S<?,Q]S'UL<V$^;)0<H_RH=)Q<K`RL;*OLJ_RL9)<!-CR]/,VLS5
MS*43IA.I$^X35!3NT%<4_-`4TJ$4(],BTS#3M=33%#C5U!0_U=<4S$UM3G!.
M]Q3V%/D4^!183T)/:$]I3VC79]=#3V771T^*%77:]]KSVO;:E!4`VY,5_]KU
MVIU2W17<%?<5SU.2W@;@0A8'X&O@5!9LX%46D^&/%I3A]%2T%K,68N)CX@E5
M7^)DXEOB6>+[%OT6I..LXZM5_!:UY"P7+Q>NY"L7Q>0S%S07^U4[YJQ7KE>J
M5^@7O^@KZH3J@.I-ZT_K7%A,ZY+M71G2&H4`B`"N7WE?C@"$`'%?WQJS7X,`
M+%]W7R]APV,"`<UC!@$%`<EC_@`!`0`!SF.E9*!D_F1999IFYP$9'N1HUVC<
M:.8!YVCM`>(!ZP'E:.@![`$*'B0"FA\4;F("\6UA`F`"9`*+`K9O;G!L<(%P
M0G$9`Q8#&`,B`QIQ'0,7`QX#)W$E<1=Q''$]<2!Q:0-J`X%S;`-Z`XH#"77&
M=<1UG`/%=?T#^0/O=O\#WW;>=NYV]7;L=OP#W7:%(_L#`@1?!%8D7@1=!%P$
M(GA1))($EWF5>90$E031!*E[\013?+$E5GQ5?'<%;P7C?>)]AP5]!7P%?@6%
M!8L%A@6`!?U=J7UX!:OU,WX*?KH%68`S!KR!+0;$@<>!QH$W!EHG8R>X@=J!
M+@:W@<"!/0;-@:`&O(2KA*,&AH6;*5J'HRD.!YXI0XBV!ZR)JP>M!Z8'OHFX
M*JH'NBJQ!ZN)J`>O![`'IP>R!YT'I0>U!SYTQRK7*OF,00CSC/>,<"Q%CDB.
M<@B=+&\(<0A$CH4(KXZQCJ0(I0BF",^/J`C+C\V/HPA0D.R1&I(6+20MV)%#
M"="1T9$]"44)>Y'2D40)U)'GD=^1WI%%+=F1SY$-E>,)>2_]7=\)Y`EZ+^4)
M.)54,"(*2@JIF$D*1`I+"H<*B0J2"I$*D`J."CZ91IGMFC#V$@L0"Q$+;)PR
M"S0+-PLS"S8+-0ME"ZR=?#-[,\F>$C2P"Q*?KPNJ"_V>`9\1GZL+B9\%G_Z>
M"Y\@GP2?B*#S"P*A]`L#H;8TX#0(#$X,50Q+#"FB.Z)-#',U!J)2#'(U3`QP
M-5`,4PP#HE$,>*-YHWVCB0Q_HY4,S`S(#,X,,J3*#`"DG38BI,T,J:5<#6<-
M:0UE#6(-!*<G.#4X6?:J#;BHFZG2#:(Y`PX,#I*J"0X&#@4.B3F/J@L."`Z8
MJJ4YKJJ.#IVMMCKH#DFO4*]&K^H.3J^E.\,[5:_I#NL.9*_P#CBQ2P^K/7,/
M=0^2#Y$/DP\E/J</I@^H#ZH/_K.I#UD^NP^\#[H/O0\G$(4_IK8D$!X0'Q`=
M$"`0(Q`I$"(0G+:9MAP0CC\H$+6VH[:@MJ>VF[;?N.&X<1!S$'(03;D"$?.[
M;[MIN_X0OD%KNWB[A[L($86[@KN0NP<1!!&`NV>[`!'\$&&[1!&3N_$0\KN&
MNZ9!!A'-O\2_QA'#$<$1PA$/P<01QQ$-P;\1TA%SP<H1NO8*P2]$",$3P1,2
M^,,P$CX2.1*KQ*C$/!(_$J7$-!(]$L/$I,0X$M3$NL3QQ:!&@A(_QH,2ZL:;
M$O?'X!+=$OK']<?>$O['XQ+E$@#(ET?B$@+(^\<'R-\2&L@N$[C)-Q,X$^G)
MZ\E0RD_*BTF&RV(!CLN4$Y,3JQ.M$_#,^\SU$_<30L[V$_@3A<[[$_D36!1:
M%`71610/3(44I!38%-D42]7=%,@48]7Z%/L4=4\G%9]/*A4E%9G7*!6!VA?;
M$-L2VZ92E16:4_K<\]SRW/7<]MR[W<+=I]X/%A$6J-ZCWA`6JMX5%A,65U3<
MWT<61A8/X%D66Q9YX%X6?^"%X%H6D1:2%I`6DQ8;XO=4OA9WXG;BF.*\%KL6
MMQ:Y%GKB`1?^%KSCNN,"%[;C_Q:P5;3C`!?/Y#<7.A=O%W<7>1?&5GOFR!<<
MZ"'H'>C`Z/(7_^CQ%_`78EA6ZS08H>VB[:;M5O!7\"P9+1D!\>WQ'/?R\_H:
MN%^1`,!?E`"W7^%?Q``*`>ACA1RR9%(!KF99`6\"?FGR`?0!0QYV:?$!/!Z6
M:6H"(&XA;B-N*6YW<%%Q)`-6<2,#B'%9<55Q)P.7<IAR;0/M(6X#;P.A<Z-S
M-2*?`PH$!@0.!`IW#00%!#UW#'<+!!`$+@0]>#EXL'FR>:YYE@27!,0$1R7%
M!"![T@1N?&U\:GR!!3)^C@60!8\%.7Z1!94%DP6C?6TF?WXU?CU^]'_U?SL&
M2`9(@BB"1@9'!B>",H(L@DP&+H)*!E`&0P8C@C&"Q?5)!J8&I0:D!LF$B86Y
M!KN%S@;/!A,'EXB3B"B*Q@?%!\H'V0?!!QB*.XKU*B>*)(H;BC&*RP<FBJ.*
M/XHBBAF*`RM!BBN*92M""`R-=2QT"',(3HZYCOJ.Z8_HC^2/BBU6+5()7Y)=
MDE*24`ETDDL)1I),"6T)JI*8+4J269)+DD\):"WP"5"5-#!%,$T*3`K0F$\*
M3@I0"LR87#&6"E8Q9)EEF9<*E0J8"ER9%9OL"NL*$PL4"S@+.@LY"WF<:`MG
M"\6=N)TLG[X+O`LWGS6?,9^["R^?N@LKG[D+MPLMGRJ?P0N5H/<+/J)@#$>B
M1:)9#%P,6@Q8#%*B6PQPHE"B6*)1HCVB70Q!H@RB/**&HX.CB:/SH]0,TPR_
M-M(,O38MI-<,T0SD-M4,Q:55]FT-;PTT.'4-;`UT#4.G<PTWIT6G-CBL#>6H
MIJG;JA`.VJKFJKHYO#D/#L@Y(P[#.1T.MCD.#OBJZ:H5#L(Y$P[HJO:J&P[%
M.2(.)@[GJKTYL#DA#AP.%P[5JAH.NSG3K<>MT:V9#L.MEPZ`KYBO_0Z$K_8.
M_@[U#O\.]PZ7KX.O@:\!#P0\C*]"L:NR=P^CLJ:R7+-ILV>SJP^+M*BTP`_8
MMC$0+A")]MRV+!#@MN6V,A`O$"L0+1`S$!BX&;CQ/U<07!![$%^Y7KEZ$`*\
M(D(3$1X1%Q$@$2H1$1$5$0\1&!$X0A*\-KPL$3)"J/800B.\`[P<$0"\*1%&
MO&&\$A%/0I<1A,%R1&O!8L%6P6K!4L%5P=01T!%\1&'!N_98P7?!TQ$4$M?$
M1A)%$M[$0Q+?Q`U&1!)($M'$1Q+BQ.'$W<0(1DD2A1)+QH023L:=$OS&GA*@
M$OK&G!+[QI\2_L;W$NH2,<CO$ND2\Q+P$NL2.,CL$O(2]1+N$CK(N\DZ$TL3
M6<I*$TP3V\K?RN+*>1-[$W@3GLNAR[43$,VT$[<3GDH)%/X3"!0'%';.?\Y]
MS@84!!0%%/\3"Q2"SE?0.Q1=%%P47Q1>%"A,+M$A3(,4B].-TZ<49DUL39#3
MJ!3LU&_5:]5QU7C5]DW@%-\4_A3\%/\4_12MURP5[$^Z3^-/O4^=%2_;M%)X
MW4`6^-\9X%\6F^"4X)?@F>"FX:3AI^'15)7BP!8C59#BP1;&%IOBQ.,$%P47
MQN,+5CX7/1=`%S\7X^1"%]_DW>3GY(07@A=_%X47+>@LZ,P7LE?+%\T7-.@X
MZ-M7'>GU%QKI&^D4Z?!7%^DAZB`8(1BJZJ'J-Q@^&'-8/1AN6&/K>>M@ZV58
M8NL\&&'K.!AJ6'#K;5AJZSL8R.VP&,7MONW"[:T8LABX&`M:Q^VO&+#MRNT:
M&79;(!DA&3`9J%LO&0WQ!_&6\>_Q7QE@&1[R'?(17)#SZU^*`!D;G`#N7YH`
M[U_L7_IC#`$+`0T!DAP$9=-I_@'1:?II_P'[`?P!"0+(:0`"U6EU'LUITFG[
M:2ILB&YA;G$"8VYB;F\@5U[(<9AQ*P/!<S]W07<4!!$$$@12>&,$7GAN!)H$
MQWF;!'!Z)WO(!'%[L'OV!$)^0WZE)HP%EP6B!:`F5WZ=?HF"C8*+@H""DH**
M@LB"5`:/@I."D8*H!O*$WH2I!LB%M"C8*,(I&`<7!QT'IX>AAS$'C(I_BM@'
MU0=[BI6*F8KA!XZ*U`?:BHJ*G(KC!WZ*1`A%"!J-58YV"'4(8(ZH+(@(J@C[
MCZL(K`C]CU<)@RU@"5T):PG0DF,)9PG%DEX)TI(1D\4MS2_Y"?,)K96DE:F5
ML)6=E?8)F)><,%$*4PI2"I*9FPJ*F9P*C9F6F?<*F3*/,I$R19M+FP^<%IP[
M"XJ</@L]"\F=:0O(G<J=9)_#"\0+QPM=GV.?.33&"RXTR`N(GSJ@.:"?-*`T
MY@OX"Q>ADZ$'#)6A9`QH#':BE#5E#*XU@*)[HFD,2**HHHBBBZ.*HXRC_*/:
M#.`,YC98I-X,4:15I%.D'`T=#1H-W*5[#7H-?`U<IW@-=PUEIUKVL0WNJ+(-
ML`WPJ+PX\J@V#C6K+@XBJ]8Y(*LT#BVK**LFJSRK*@XXJS,.+0XO#C$.*PXR
M#BJK-0X:JS"KXZH9J^FMYZW/.M:OQ*\(#X>O!@_'K]FO&#S?KTT/80\*L@&R
ML;)X#\&RE`^5#W:S#;0.M,$/PP]M/@>W.1`)MQ:W.A`[$#40-A`.MSP0D#\&
MMQZX2KA8$'P0?1"-$(P0IKR1O#L1/Q&XO):\,A$M$<6\+Q$Y$2X1.A$*O381
M,1$^$3@14D(T$;*\01&WO+2\B;R-O#`1A[S"O)R\DKQ#$<J\4$**O."_F!'F
MO^6_H$2EP;/!AD3:$=<1M<&OP95$L,',P8Q$HL&^P<;!K,&NP1@28$7#]@C%
M!<52$BA&_L1.$B!&`,5/$E`29,9HQJA&AA*'$HD2:L9IQ@W'$L>B$J,2#\>A
M$F?(><ARR&;(?,CY$OT2:,B%R';(=,AQR&3(/A,\$_C)31-LRDX3Z\J!$X,3
M@A.XRX`3B!,MS2[-*,TIS3'-N1,OS2K-.DNDSK?.O\X1%`T4$!03%&/0/!1B
M%&,49]&^T^#VE=6<U0,5!A4"%0$5<=9RU@45;]:43A%0\=<W4#85Z-<U%4-0
MZO:A%:,52=MDVZ`52-OJ%:93Z!4LW>'=[]W`WB$6&Q;7WM3>219(%JW@E51B
M%F$69!9@%F,6KN"LX)949A:L%JL6)^*NXL,6L.+$%B55P.+$X@@7"1<*%P87
M!Q=!%P?E11?]Y$,71!<F5C161Q<$]QOF'.9Q%[+FM.:WYK'FL^:NYHL7U!?3
M%]$7NE?2%S_H-NGW%_@7,>D[Z37I.NDWZ2+J-NHRZB(8P.I%&$$8@5A`&(I8
MA>M_6$(8B>O!&,48X>V[&+D8O1C)&`KN$5H)[K\8QQCH[<,8)!DQ&3,9&/$R
M&3094AEA&=E;>AF"&3Q<Q?,C&PU@#&`A8"P;%F(.9`\!E1P79",!)0%(:@8"
M"`*('E5J26I,:HL>3VH]:GH"=P**;JANBG`N`\MQ+P/5<=1X&P03!%QW=7=F
M!&%X9026</<$BGS0?N$FUR9)?L]^G`76@G^"4P;2@L^"!H4)A;H&HR@B!],I
M!HOQB@2+BROZBO2*ZP?=!_F*[P>+B@.+1PA&"**->`BL+(D(#)`+D&@)=@ET
M"7D)))-Z"7<)%/9Q"263<@GVE?\)^Y4%"C*7^Y=4"O*8\YB>"I\*=#&<F7*;
M^@ITFT0+/PM`"X:<0@N.G)"<40O-G/><UIV$GY6?BI]`-,H+EY]!-,X+R0N@
MH*&@(J&FH:2A"0SH-&P,;@QP#&T,:PQQ#'(,KZ*PHKVBC`SD#':DX0Q[I'FD
M]C;G#``WX@P?#>ZE\:5^#92G@`U9.%4XD:>Y#;<-N`T0J;H-]#BOJ=,-/PX$
M.D4.00X5.D(.0PX[#C@.>ZMWJSH.]3F`J\:K/`Y\JY"K/@ZCJWVKO:N>#I\.
MH0X3KIL.$@\1L$2P#;`8#PP/%+)B#[BR>@^WLH.SK@^O#Q2TK0\<M,0/QP_&
M#\4/U+35M,$_0!!#MT*W/Q!!$(KV0;=.N'\0A[F&$($0@!".$$H1.;U'$8^]
M*KU+$4813A%]0BN]I4)0O4@1;KU%$3N]4[U?O2^],+TXO4R]\;_;$><1Y!$'
MPA;"X1$4PND1^\'E$>`1XQ'XP1#"'<+_P0O"!,+J$?[!_\,Z1E026!)<$B/%
M51*+$HP2IA*E$BK'H,B8R)S(_Q*>R*;(M<BPR#`30!-!$_G*]<J&$]++OQ.]
M$U#-3LU+S5+-3<V^$QD4Y,X<%-K.&Q07%!@444O?SNC./11J%&84<-%RT6<4
M=]%H%*T4KA3FTZK5UA0)%8S6F$Z)U@P5"A4RV#L5.A6$4(%0>MAO4)[:H-IP
MVZ\5JA6K%6[;9MNQ%67;K!7L%7_=X-T!%O_=]M[WWO7>(Q;\WB06'A;YWDH6
M919J%LK@P^#&X&D6N.&]X946O.$%XN#BZ>)"5=_B[.+,%N7BWN(`]\\6\.+C
MX@\7[.,.%PL7$!<-%PP7\N/OX^GC^^1&%T@7-U9)%S?EWN:1%XX7VN;8%]87
M2^C:%TGHUQ?5Z/]7^1=2Z4?I_!=(Z<SJT.JI6$H8IUA.&+-8K%BP6(;KI^NC
MZYQ8MNNMZQ/N/%H<6CI:TQC-&-$8%^XB[C):-%I)[B;N#/<\[BCNJ/#'6_OQ
M8ADR\M;R2/.#&3]<QO.2&9\`H``E8"9@)&`S8'!A)P&09PL"E6JA:I)JCVJ?
M:I9JF&J=:J!JC0*7<.MQ<`.'=^LD,GN:!9\%G078?OM^!G^;!=%^U2:P]6`&
M9`9I!F,&9P9B!O:"!(/^@@(H_X+W@AB%K`84A<V%((;>AR8'(P<E!T6+4XOX
M!TN+58M!B_<'^P?Z!UR+5(MQCM".L`BO"%.0*9-^DWX)>9-]"8`)<)-JDW\)
MA@F%DV23$BYXDX$),I8GEB^6)`I8"E<*H`JZF?X*<9N,FQ4+&IQ'"T8+F)SD
MG6L+;`N%,U0TPI_,"[J?533(G\L+IS2H-/D+N:&XH:6AXJ)X#'H,=0S9HG8,
M=PRLHMVBZ@SN#.T,G:3L#`\W$:8#IH0-A0V##>ZGO`V]#=0-I*O8J]VKWJM5
M#N>K4`Y,#D@.U*M3#LZK5PY4#DX.2@Y1#O&KTZM)#DL.8P[*J^FKIPZF#J0.
M&JY!KFCVY#KE.CVP0+!E/$X\%P]#L!8//[`\L&,/(;(@LH(]QK)[#WP/T;+*
MLHZSD;.P#RT^X[2(MT(0<+=$$)VXG;F1N9BYF;F($(\04Q%;$;^]61&NO;&]
MS+T$OLI"%K[-O501O$+@O<N]U+W)O?^_F1']OU?"4L)0PD7"3<+Q$5/"[Q&"
MPD3"SL//P]+#`L1/Q5C%8A)#Q6,24L5@$F$27Q))Q5/%3<6-$H3&CA*#QC+'
MXL@)$^3(T\@%$]7(W<@#$P83[,CFR-+(^LC:R#$3!LH$RD\3>\H$RP++9A/_
M2<038,W#$\$3Q1,'SP7/#,\A%%K/'Q0B%!K/)Q0@%(K1;11L%&L4;Q1P%(S1
M"=2FUJ9.K-:IUD(5B]BV4(S81!5`%8C8B=@_%9/8JU"+%8/;3]TE%B@6(-\A
M5#;@XN!U%G(6[N!O%N?@Z>!V%G$6IU3?X)<6Q^'7%@GCUA8!X]@6W!;;%M06
M/E43%Q$7%!<%Y`SD>.5=Y5$74!=3%U074A=>Y6#E9^5M%P7W].:5%YD7\>::
M%_KFDQ>7%_CF^>8)Y_WF]^;<%UGH_1=@Z6CI_A<`&`(8`1@#&&KI%.H^ZN3J
M)Q@F&"083!B\6%`851A3&+=84AC2ZU<8OEA8&-886.Y0[M087.[:&-D8&<]B
M6M48Y!@.]]P8&QF/6S<9-AE+&<M;9AEV&=_R?AE]&7\9A!F+&=GSE!FA`!$!
M9F40`JD>X6KO:NAJ,VP3(/YQ,@/T(>]S['/L=9QW(`29=W!X;GB=!$%[[";O
M)@)_`7^E!1N`(X,E@R2#)H,S@R^#CX56B`((_@<!"-8K`PC_!YF+!`CM]4H(
MV8Z'";>3A`FVDX4)"3!4EE>6>I99"GDQCIO&,I";N9L$"TD+2`OOG6T+T@O3
M"^*?T0O6G]B?VI_>G^<+"@S#-0BC!*,*HPNC`J/P#*JDP:0?-]>GV:=E.-ZG
MVJ>^#;\-*JG&.#HZ,:PV.BNL+*PIK"ZL7@XGK"BL6PY?K#"L)*SK.JL..JZL
M#CFN0*Z`L(2P'P\=#W6P=K`<#WRP'@]XL)NP?K!:L60/++*$/9RS1[>*MT@0
M1Q`GN$J^7A%A$2>^X$+S0BZ^)KX(P/<1O<*6PO01^!$>1;["CL)TQ602@,62
M$H\2D!*T1I,2J!(\QSW'J1(ZQT+'^48DR0;)1$@.$Q7)#Q,"R0S)"Q,(R0K)
M!<D<R1`341."RE`3ALIC$P/,>\W'$WK-<4LD%"84;DN`SWE+6,_$2W04<Q1R
M%*K1J]$VTDK2L12,3=;5#A41%1`5#Q42%4D5R5!/%4T5`]G/V%45G]NBVRK>
M+]Y$WT#?+!8K%A'A#^%Y%@WA!^$#X7H6L%29%IH6->*N%J\6!./D%N$6WA;F
M%M\6)N/G%N(6X!8>X^466E4.Y!@7'>0>Y!_D5A>(Y496C>61Y8#E;A=4YE7F
MG1>@%YP7)><:YZ$7HA>?%]\7WA?#5^H7B.D&&'KI!!@/6(#I'NO\ZR7L7QCT
M6/I87!@+[%X8!NP$[-U861CYZP#L9!A=&&(8`NQE&`?L[5A;&.]8M>[=&(?N
MWQB3[@_WXAB^[F;P)QG'\,_PEELZ&3P9/?$Y&3SQ1_$]&3L9LUM,&</Q:!GB
M6QOS@!F%&<GSE1G=\Y89D_2/7#U@I``2`;$>)0+F;D$A-P/W<[!WKG?]76@$
M9P2>!)]\GGPP?ZH%3W^I!:0%)W]1?W$&;P91@U2#5H,GA:T&)(7V*PP(\BL+
M".R+Q(L/"'D(^)/VD_>3[9.-"8\)])/ODXX)#`I_EJ*6?I:F"L69HPJD"J4*
MB#-N"_&?\I_Z"R^A?`Q^#'L,?0PCHRFCC0ST#/,,&Z;KIXD-ZJ<SJ<`-8ZQE
M#I*L9:RM#B4/H+!P]EZQR0^JMTH0J;=G0(D0G+YF$7`1DKYM$6D19Q&&OG(1
M#D-N$8.^G!'\$?T1!!+_$<+V_A$`$L["9A)I$I/%JA*K$A<3+LDGR2C)%1->
M2!(3#DH8S!;,C<W*$X[-R1/+$Y#-C\V!SRD4*!2*SXS/C=!`%'44=A2RT8@4
MV=6V3E<5`5$-V5\5$]D=45@56Q4;V2]1K-NS%;/;[Q5>WS`68-]HWV/?:=]G
MWT$62Q8HX7T6+N$PX7P6)N$QX4'AX%3:X=M4^O8+XF%5-.,SX^@6ZA;I%CGC
M.^-`XS#D&Q<RY#?D51=*5ED76!>!Y9_EI^6D%Z,71.='YTCG/><S5Z<72>?@
M%X#HH.F=Z0@8"A@)&)SI1^H'ZW$8#UEL&$GL$5E$[`-9`5EN&-_L%EE,[/U=
M3^S@&.X8P>[K&+GNR^[/[L3NDUKJ&.\8YQC*[L/NT/!1\4@921FH\<?QQO%-
M&<KQ`O)5&5WR6O)J&6P96?)K&<SR'//,\Y@9F1F7&>CS[//J\ZWTL/1?8%A@
M5V!;'9-G%@([:[\>-&OR;CD#_7,==24$SB,$>DA[6']/@W0&;H-R@ZX&+H7\
MB_2+-I`.E)()E`D4E)4)&90-"J:6)0K)F\";S)L;G*J<J)P#H-4+U@NL-.@+
M-:%_#-(U]0SV#/<,V:0D#8T-B@T_J3VI;`YF#FH.BZQG#FT.:`Y2.FBLBJQ8
MKE>NSK"\L,"PP;"_L*NP7[%E#Z:SF@\IM+$/2Q!-$$P03A"XMW,1=1'=OM:^
ML?;5ON>^V+[LP@,2`,,'P_W"\<+_PJK%L,5(R1X34\ES2$W)&1,<$QH3'1-V
M2$/)4,E#$U(3C,HGS)43F<W,$['/*Q2PSZK/K,\J%,=+=Q3(T<K10M3@U>?6
MZ-;FUA,5%!4T45O95ME=%5K98!4^46(5N-K%V[(5\!5(WGW??-^!WX+?8M],
M%D7A@A:\5($6FQ;CX:06[A;L%E#C[19/X_`6[Q8YY!T7.N1@%UX771?!Y4[G
M;N>Q%ZL7K!>M%W'GKA>,Z(GHXA?EZ+/IMNFTZ4WJ.5@3ZWCL*EE[&"99>!AU
M&"=9<NSR&/08\QC`6LE:=?#:\-?P/QD^&4`93AE7&5D96!D6]VGR9_)N&6;R
M;_)Q\NQ;S_(C\X$9AAFE\X\9_O/[\_WS:%R;&;$9LQEM:SH#!70@=2<$R'?)
M=VH$K`4GAA@('HPVC4P(/926"=>92@NMG`">@0PZHX,,^0SX#":FC@V/#<$-
MMZRVK,"L<`Z;K'$.V+`J#RT/?0\R/C$^P+=/$+^WO[F0$""_T+X.OWD1';\>
MOQ6_%+\>PRS#!1*YQ;C%ML6>QIS&3<?]1F[)8,DA$V3)8LGEL#(3H\W-$\\3
MTM'5T8Y-%A45%;45"!95WC(6D]\S%C06/!96X<)4Z>&<%D7B]!;R%GSD8A?3
MY6$79!>U%TM7M!>.YY?HXQ>;Z)GH'%@.&,_I&UA9ZBP8*Q@@ZR/K*NN%&($8
M?AB#&(`8L.Q"62_OU%K[&/<8,N]#[S_O.>_X&##OW?#:\=OQ6AF$\G_R<O*`
M\N[R>!DJ\R+S<?/-\YT9G!D/]!CT:F"I`+\`T![/'@QTVB.F?'<&=@8WA;L&
MZBGBCIL)O)8/"EL*U9M,"V\+V0L2H((,2Z-!HZ&C[*1T#G(.U*S8K-FL<P[:
MK&RN;:ZQ#BX/Y[#KL.RP8K%.#RNT#;7-M\.Y/[\\OSZ_/;\ZOSB_1,-%PPL2
M2,-0PVP2B4AXR7G)BQ,^S-`3+114U.04<16YV5A1;Q5?WH<6I19RXW7C'A=E
M%[D7MQ>X%^07H^BEZ-SIW>E:ZHP8B1B*&-OLW.R+&*OOA.]V[P$9_ACG6@,9
M!AF#[^I:\5I_\!T90QES\:WQL/%/&0_R#/);&7`9>?.(&7?S>O.)&41<,O0G
M]"KT+/1M7"CT*?0X]"]D>VL-=-DCUG?5=Z&#3(R>"9\)IPI+"]L+V@O`H-8U
MC@QV#O2L,`\O#_"P9@\_LGX17<-RPV+#.D5FPW5&;Q*(R=$3+Q3HS^3/LA08
M%1<5_]9V%:_?KM]/%HD6\N%(XH'C?N/U%A\74N3OY5U7Y1>MZ.;I$!CMZ0\8
MZ>EAZF#J,^LO&#`89%D+[0CMDQB4&`?M!QD)&0@9RN\+&<;O"EN$\.OP??%0
M&7$9F_*B\J'RH/*<\GL9?!F`\W-<0/2A&3GT//2@&:(9RF0;`HEK@@(\A4"-
M8Y1IE.D+4Z.$#.$U%Z@:J`"MLPXT#S,/@!%OPZO&K1*1R40351.QS=(3[\_Q
MV_+;M]^UWXH6AN-:Y&<7QN?+Y^87LN@3&//I+5@G[9<8#%O5[]CO#!GL[X?P
M\O!&&5P9=!ER&:WRL/+]\A]<A_-*]*09HQE.]$GT4?1-]+09<F`V`19T;8Q!
MC;((<91TE!8+<#IW#GRN?Q&*OU;'?11Y4?K92E2,%EOD:!>^%Q48]>_P[_/P
M?_$3\G49I1D9=(5_L(-WE/^D>`XU#YT\@A&'OX,1B[]Q$I[)?A2.%H_C8%9I
M%SGFU.?QZ`+J:^I`ZYH8FQ@0\+[RN?*0&63TGESIFY"_AA&%$1S`#A*2PZ[&
MH\D9%<G?P!?8YT3K)/#X6SI<?5QP]-/T#0P6&,/RJ1FJ&84,(:W*N9S#<^J&
M\<'S">J67-7TPA<Q&!$9JQF<&-3?`#0````U````-@```#<````X````.0``
M`#H````[````/````#T````^````/P```$````!!````0@```$,```!$````
M10```$8```!'````2````$D```!*````2P```$X```!/````4````%$```!2
M````4P```%0```!5````5@```%<```!8````60```%H```!;````7````%T`
M``!>````7P```&````!A````8@```&,```!E````9@```&<```!H````:0``
M`&L```!L````;0```&X```!P````<0```'(```!S````=````'4```!V````
M=P```'@```!Y````>@```'L```!\````?0```'\```"`````@0```((```"#
M````A````(8```"(````B0```(H```",````C@```(\```"0````D0```)(`
M``"5````E@```)<```":````_P`````"```!`@```@(```,"```$`@``!0(`
M``8"```'`@``"`(```D"```*`@``"P(```P"```-`@``#@(``!$"```2`@``
M$P(``!4"```6`@``%P(``!D"```:`@``&P(``!P"```=`@``'@(``!\"```@
M`@``(0(``"("```C`@``)`(``"4"```F`@``)P(``"D"```J`@``*P(``"P"
M```N`@``+P(``#`"```Q`@``,@(``#,"```T`@``-0(``#@"```Y`@``.@(`
M`#L"```\`@``/0(``#X"``!!`@``0@(``$4"``!&`@``1P(``$@"``!)`@``
M2@(``$L"``!,`@``30(``$\"``!0`@``40(``%,"``!4`@``5@(``%<"``!9
M`@``6@(``%L"``!>`@``7P(``&`"``!B`@``8P(``&0"``!E`@``9@(``&<"
M``!H`@``:0(``&H"``!K`@``;`(``'$"``!R`@``=0(``'8"``!W`@``>`(`
M`'D"``![`@``?`(``'T"``!^`@``?P(``(("``"$`@``A0(``(8"``"'`@``
MB`(``(P"``".`@``CP(``)`"``"1`@``D@(``)0"``"5`@``E@(``)H"``"=
M`@``^`(``/D"``#Z`@``````````````````````AEI`&$$86ACH=0(8*1@.
M6R=@`AP^`=PG/%]U8"C10AUJ'5(E/&]UT7C1Q"E,+*TY$A@O&)88T!A"&X,;
M&=&E8*I@#V,.9(,=N!V<99ME/&HH(\)Q(R8!*``IM(>X"&PW*SF(&WE(ME$7
M&&5:#`"R6S``XAC;&'=>0E^M&S-@]QO:`*]@-F(3`1L=B!V''2)ESQW]'6,!
MYQW<(*-IV2`E(2<A,R,3)B5R)')U)E)VB7>_>L0%PP7Q+[6'3*)2113'$L<!
M`*-:HEI1&&H8MEL,&;5;M%O^&!L9PENX6SH`>5ZK`',;"%^.&WI?ME^]8+=@
MO&#=`,1@R6"E'!4!IQRD'#!C@V.%8Q)D-&2]'>1DWF0J90(>KV6T9;-EL64K
M(1LC-2/>;*<"I0*X;;!MI@+";_U9%R9\`RIR<"9])JD#Z77I)U=V-`0U!+9W
MUW?>=Z@$&2D<*74IPGJK>_\$R"F/?L<%Q@7(!6U_M8+0!M$&P(>_AUD(N8L<
MC1(TO0B`CH21A9$H"K,Y))6I"I`Z-CQ,JLP/]K&!2+A1<,.T%'7#%\<C&!8`
M+`#Q6RX9VEM/&[E?NAO?`.``(AS.8-)@T&`7`4-BKQRP'+$<36(T8R\!V6-D
M'1ADTQTX96H!UV5P`6T!W&7+9=9EV&5N`=%E/M$\T=)E*P(H`EEJ_5D_(^5L
MYFR2`NALBR.];9$CE2.^;4EO/P/-;XHE3P-T`UYQT'%]`P9SMP.C`[`#L0.'
M)JL#?'-Q<^]U.@0W!`TH.`1`!(UWMW>.*)\$,WE_>7HI\GL$!0D%!@7]!`H%
M!P4J?XM_R@6#?XI_D"S)!8Y_FBRV@CPN.BY_!I@NV(32!E:%TH=E,-O10P?"
MAX>*@8K"B[R+(XW!")..Q0BC"8V1CI$J"E\*.Y5-E5T*-)4QE?*6\)87"Q6:
M*)MQ"W(+)9SGG0\,Z9T7H,)`D0ULJ8"I2ZJR#\\/S@^>1MZO^Z_K1U&PB4B6
M$`&R`K*62`6RAT@#LI<04<'`48L4PU%3P7K#>,-VPWG#C\-\PWA5&\<<QR56
MDH]U&'08+ELL6RT`#%R9&0M<4`!+``5<3P!,``71<1E3&[\;PE_#7\`;2&#N
M&T9@Y`#C`.I@X0#K8.(`[F`]'!D!O1P,'=AB'IK?8]YC00$W14]DP!U>`0UF
M"&9Y`0EF;AZ#'A)F969>'ET>?B%Y(8EJ>B%L(81JGFJ+:C("AR%B;!TCE`)&
M(Y<"^6Q#(_=LE@*8`@9MW6VR`MEMWVWB;;D"825F)?%:D"5U`W\#?@,I)H\#
M/W(^<@MSO0.R)H-SNP.\`X9SP"9\=CT$/@1T!/=W>@1V!'@$=03[=SMYKP2P
M!,<$S`3Y>\I[%@7_>Q(%'04)?`-\%04/!10%'RKB*1!\FGZ??K`%OP7`!8=_
MT@79!;>">@8(@_F"@0:"!O2"%B_Y+MH&5ZV(,-:'FS#>T6XPGC#4AR(('PB0
MBHV*(0@D,V"+SHO/BUP(?3/1BWT(C0B/".8TRH[+--`(MX[8"+*.NXZYCK4T
MIPF>D9<WLI&;-Q(*;Y.LDR\*(Y1K.2X*+`I<"FR5U3DRE5Z58@IG"K0*^Y8I
MF;V9'YI#/$%Y'9J</#&;+YOJ"T.=^PM!G10,]9T3#!(,$`P1#/*=A@SD/I@,
M'J!4HBH-5J(IHR>C**/.0;4.>:E^J;:KMZL31M8/V`^W1MD/U`_7#X'2N4;]
M64VMY$?]1P](8!`)L0BQGA"A$!ZR&K(CLA6R&;(6LK](RD@4LABRP4B@$!^U
MW;;?MFG!T%']66S!N123PZY2E<.4PY'#E\,PQ\$5PA4X5AC3'``Q7%X`O!E9
M`%P`-EQ?`.D9O1GB&5@;R5_*7\X`&&$281EA$&$68<8<7V+('-]B%V,H'3QC
M*1WJ8^EC'&189&1D\V1?`9=FA0%:9EEFA@&.9K0AO&JI(8<"#6W\;`QM!VX*
M;LH"`F[#`B9N"&X=;L(":"5.;T$#[6_N;^]O@`.!`U!R3'*3`Y(#3W+%`]1S
M_5FP<T8$001%!$($/P2E=@EX@@2!!'\$I00K*;,$M03S>==YC2G:!-QZVP0-
M!1@J#@4+?!X%)04F!1P%(057*D@J)P4:!3I\#7P1?#@J('P!?"0%-WRCT7$J
MJG[!!>$%YW_H?Q(MZP7U?^(%UP7I!36`YG\*+?A_(RWQ?X0&%(,5@PF#M0:\
M!MP&W@;?!GN%*B]^A6:'9X<*B%0'X#"^,%,')`@E""DS*`@G")R*8HOAB]Z+
MWXOIBXL(Y([WCMP(0S7JCO:.$H\!TJ8WL@G`-]F1+SE?DQL*<Y,R"G$Y/Y1X
ME6L*?95L"FT*$I>Y"KH*"0L*"R^9ZCL;"S"9VYD@/%@+*9I:"S;20)MW"SV;
M/IMY"ZD\.)N%/4B<ZPO0G/T+_`L&/A4,&`SV/18,%PP9#``^&PP.G@F>`CX'
MGH<,7Y]@GYP,*J":#"F@_PS^#$VA,0TN#3`-,@ULHOU9+PUGHI4-E@TYHS2C
M6:3%#7H.(ZE"#X*I5`^#J:BI5:KYJOBJ_*KZJ@E&>M*?#Z`/H@_@#W2MX0]K
MK7&MWP]VK0ZQ8A!A$!"Q#[&G$#BR.;(ZLMI(-[(^L@I)B1&<M"JU.K4KM2BU
MJK8/MQT2$+?FN"H3);V.OM,30A1#%(O!D12,P9K!D!2_%+/#O!2RP\`4QQ7%
M%5561,=25C486%NG7#0:`1IC7`H:9@!J7&5<:URM`.U>V5\[83)A6!PU83%A
M/F%#839A;6(=`>1B,0$K'?1C3`%I9&MDE0&1`90!OV;#9JYFCP'L'K%F%1_^
M'KMFKV:P9N,>%A]``N]J00+M:M,A\&J3;#1M*VU9(R<DV`+2`MH"*"00)-<"
M#B1"`U<#!'`#<`)PKR4%<+HEL24`<'1Q>`."`Y<#97)C<LD#UW/(`]8#S`/H
M<]`#VW/8<\X#QP/\)@ETSP/+`_(F_B;E<^=S^"<_=D<$P'9(!+EVNG:#!(4$
MA`0@>$]Y+"FX!+P$D7J0>NYZ\WKL>O%ZZWKR>O1Z[7I!?$A\17PQ!30%-@6"
M*G]\BWPC!3M\3GPZ!9$JCRI\?+0%M07M!>P%V`7P?S:`/X!#@#&`-(!&@/8%
MYP4O@,."?`9[!C:#B`9'+DPN(8/(T8HN<X2^!N:$YP;E!NX&X3!*,3^(60=>
M!VN(6@<_,6$'6`=;![TP<8A?!^+1*@@M"+"*(P@K""P(\XM^"/71DPB9"&&-
M7XVS".<(Z@@HCQZ/*8\"TNN.9H^T"?:1R3<7"F"3=Y.[DR$*O),X"C<*=`IS
M"G4*HI6RE9Z5=@IX"CJ7.)>Z.@P+(`L>"TV:6PM>FEP+%YN#"\8\@`N!"WX+
MB`N%"XD+?PN."V2;9YN$"[<\C#U9G(T]VISN"^T+_@M1G?\+59T[GC2>(PPW
MGA<^,9X</A\,/YY9GA0^89^/#)`,6*!BH%"@H`Q1H*8,GPQ&H*<,H0PMH0(-
M-@U(HU&C2J-/HU"C2:-CI,@-9J1@I-@-#$+=#=P-\:37#0>EV@VZ#INGHZ>=
MI[X.P@Z[#L`.J:>GIZ2G(T2ZI\%W)JE##U4/E*F3J5</:`^819!%!ZL-JP*K
M#*L)JPBK$ZNA#]*K.D8^K#RL9ZV>K>H/K:WG#]FM0JVCK:"MZ`_I#WRM!+!4
M$%BP8+#)L,BP)DAE$!RQ&K&*$'2RL!!NLF^R>;*\$"Y)=[)521I)N!`]27RR
MLA!PLC!)O1!ZLH*RBA%12Z$11+6B$4.UB$M%M142);<?MR`2<Q+HN(Y-C4T)
MN;>YN;EDNF.Z"4X43K$28KIENBL3K+M%$RJ]EQ.8$Y:^U1/"O][2DQ26%`=2
ME!2JP;#!QQ3%%-3#S</6P\04\,1Y5815SA7*%<P55U;)%;I6_5E+T&);;@"W
M7&<:K%RK7'$`P5R[`-,`Z%]I85UA7V'S`.T`]0!D86)A\0#R`/8`(`'Y8B@!
M[F(8'2P=61VK8ZQCJF-H'7X=AF1Z9*$=*&>A`5L?J@&I`3%GM0&E`:@!0A^G
M`4<?+6=#T3T?*V<R9V`?ZR$I:R9K4VM-`C-K-&N=;)P"7R-!;>H"Y0*1;FEN
M;R4B<%X#-'!MT2YQA@.$`_1Q6B8H=-D#''3>`Q%T)'05=-L#%G14="-T_W4Q
M!,]VT'9+!,YV201*!$P$QW=<>(H$-GB)!(L$0WB[!*(IG2GD!"I[`7NC*0M[
M#WL[!2X%/@5&!5,%WWQ$!=)\/P5"!4\%S7Q2!4H%PBK;?%H%I2I)!<]\'"S`
M?ATL`P:!@(*`BH"H@(R`E2V:+0$&!@;[!?D%CH`%!OH%BX"F+9:`_@7,@'T&
MC`9/@TJ#4"Z.!DN#/8-2+D2#28.>A/.$R"[UA/`&\@:SA5@O\0;F!N6%MH78
MT8@QAHAO!VT':0>VB(6(;@>KB"\(,`AC"`V,BXR,C+@S@`BY,YH(E`B6")4(
MEPARC?0(_@B/CP$)>8\""7>/^0B0CXB/@(^>C_8(]PB"CS2/B8__"(6/?H]Z
MCZ:/"S:UC_21OPF\"04X*9(FDBJ2O@G`"7Z3.PHY"EN4891@E#P*FY44.@0Z
MPY5]"LV5?PIZ"GP*!3I^"A4Z#3J`"K\*PPI4EUF7S`H."PT+]9@F"R0+)0LC
M"R$+*0MIFF6:CPN-"WR;BPN2"X";D`MEG.\+\`O?G&"=`0Q>G2X,+0PN/B@,
M*0PL#(^>89Y:GD$^B`QGGY(,D0SJ/KN?1#^I#*P,K@RJ#`8-!0U*#3X-/`T[
M#9NB0@U!#4,-J:)%#6:CF@V;#9\-G@URI':D%*7>#>(-Y@T/I2E"XPTG0M\-
M0:9&IIU#2Z9#IGX.R0[,#L:GT0['I]`.SJ?/#L@.R:?-#LNGQ:=)#T</6`]K
M#VP/:@]IJH`/@@^$#\A%@P\>J[JKM@]2K%&L4ZR?K=NM)D?Q#^.M]@_S#_`/
M'$?7K>FM*$?U#_0/]P_>K=RM/+"+TE40(K$RL2.QBQ#+$,(0U++(LKRRRA#,
M$,VRQQ#)$'!)OK+&$$"SUK+#$())O;*L2;JRQ!#`LIO2G=+!LJ:TI;2HM*D1
MK4NH$:817[5PM6JU9;5GM6^UA[7*2U%,/;=#MR(20+<F$B02)1*=3"H2=!(8
MN7D2D$UZ$AFYP;G83==-EQ*\N<BY+DYQNKP2;KJS$GBZOQ*W$LW2>KJQNZ^[
ML+LT$T832!-93ZB\IKQ6$V<32+U%O6@3F1.:$Z"^I+[8$]2_VQ/<$]T3UQ/2
MOR+`211*%-I0M\#,P#-2YL$84IH4R,'-%,H4],/+%.W#SQ1^P^/2S!3J%.T4
M^<3]Q.D4!\4:%>]3C172%7C'>L=YQXK(\A5[R=7*Z<H]%NO*/A;X%B,7V5BT
M&&Q;H!J0&G4`AAJ$&OI<BAIV`',`GQJA&AA=DQJ]`/9?U1N*88EA^0!_88AA
M^@"#881AF&%C88=A(0$GT2D!]6)08S@!3@&'9(ID966W9\%GQV?(`;P!Q6?+
M9Y`?T6>[`<(!P`&X9\IGR@'>9\D!SF>X`1`A%R)H:TX":VM$(E`"*R)J:T4B
M9FMW:Y9K;FM6T8H"5VUE(U9MG&Z>;OP"^0*A;F,#0G#/)49P/G`S<8<#B`/Z
M<9H#EW*;<JIR5B=S='QTZ0.&=.H#5"=0!/-V\'96!%($3P14!%$$[':O>(X$
MCP1D>&AX6GD]*1][)7OM!.L$I"G&?-9\PWQB!2Q]704N?5Y],WUA!64%7`4M
M?49]7P7!?#I]S'Z=@(.`]H#L+18&"@;X@`X&$@;^@/.`$0;K@/J`$`8'@?R`
M"0;Z+14&U"UR@W.#=(.1!I4&DP:2!H\&7X-@@ZJ$-(7V!K2%^P;PA74O^08-
MAO.%#X8<,'T'R8AZ!W\'Q8AX!]>(S(C9,>>(<`>"!\&(A`?HB#,(RXHR"#8(
MR(IZBU8(>8M^BV<(&XQE"&0(9@@?C!F,@0B""(,(G@B)C?$SG0B+C0\)$@D)
MD/Z/`)`0"1@)"Y`4"1D)-S;]64J0?3:&-L@)Q`G&"7F2QPG#"6R2F9(;TF*2
M%),9"AP*R)/7DPR400IPE$(*0PIQE-^5Y)6""N>5@0J4"H0*D)?2"@\+(@M,
MF2<+*@OZ.R@+3YE@"WV:?II\FG(\C9H9FYL+G`O`FY,+E`O</*`+F0NVFZ$+
MJ)OQ"^N<YYQOG<>>-@R?GC<,/PP\#,2>-`PY##L,-0PP##(,.`P^##H,FYZ7
MGL6>:Y_.G[8,9S^QH*Z@L*"S#`D-=T`^HK6BNJ),#;*BM*)3#4T-40U/#9M!
M=Z.B#8:C>Z/-#7ZD+J7G#2^E\`TWI>D-[`TRI>@-[@T"#C:E.:4UI5RF@@Z#
M#H8.>Z9AINZGZZ?OIR"H*D1E1$H/,*E:#V1%OJEN#V>J?*IP#V\/)*N*#X</
MB`\IJ^^K($:W#_T/($<-K@40/$<($`,0`A`$$#D'"1#_#V2N/T<5KOP/`1`*
M$/!']4=K$&P0-;$VL32Q-[%'LRNSWA!!LT.SVQ!"L]T0XQ`RL^`0V1#8$.00
M1+-*L]H0[Q"@TA5*ODE4LVZS4K/7$+,1NQ'E2[(1TDNM$9*UKQ&XTN!+O[46
M$B@2(Q*S3$&W:;=EMW42?A)\$B*Y';G2N=JYV[G.$LT2SQ)33J2ZGKHW3D=.
M7$Z=NL02S!+($L<2K;JFNJ>ZL[O@NS6\-[Q:$VH32KUK$VT3;Q->OIX3P+ZD
M$Z,3Y!/H$^D3X!/C$_F_ZA/A$^T3-!0U%%$4\%#PP9T4\\$;PO+!^\$<Q!/$
MT!0/Q.X4%L41Q1+%\A0.Q1U4B!5GQO+&VL:/%=S&V!64R)O(DLB:R(C)ALD_
M%N_*4A9K5U[+4!98S+$65LQ4S/D6F\V6SJ3.)A<H%YK.$L^``,`:@0!K77X`
M?P`W73Q="M'W7KX`9E_6`*EAKF&M8<AAI6&P895BY1PE8S0!F62O'71E<&5O
M94%H5&C5`=@!0&@X:-0!V!_9`5)H.FA7:$K166@1(6<BM&O`:UT"0R)>`ED"
M=6M:`J`"8&U';04#\&X'`^]N#@,,`^QN@V]%`X1OCV]D`V%P90-I<-TE9@-B
M<(D#[`/Q`W`G:B?P`_@#="=?)ZYT82=S)[)T\@/T`PMW6`00=PUW6@19!%<$
M6P10*']X@7BF!,($P00_*0MZ3GOO!+`IZGU%?6@%-2LM*W,%;@5T!0(K9@4H
M?5U]W'ZY!28LU'X,!F2!:($@!F*!'09A@1P&9H$A!AH&&0;R@&F!9X%^!IJ#
MFX.%@YR#G0:D@YX&G`9N+IF#AH.0@X&$KH2Q+M0NS08XA0L'"@>%+SN)CP=R
M,I4'D`>1!TR).C*Y!T>)-8F7!YX',XF+!X*)0(D["#H(/`@]"#D(/@AK"&P(
M-HP.C:((H0B?"*V-JHT7D"T)9Y`V"2L)<I`W"0K289"PD*TV)0DO"2P);I!D
MD#()C)!FD)4V:Y!?D'2099"[DKZ2U0FYDM0)U@GODM$)0SG:DT8*CSF0E.F5
MC`J*"H@*$98-ENV5(9;="H&7L9<!F2T+7IEBF2X++`LK"S`+6YE."Y::DYID
M"V$+DIIU/#G2<`NF"Z0+Q)O'F\.;J`NB"\B;IPOL/*4+RINI"\6;SYO<FWR<
M`9T]#-.>W)Y$#$4,1@S4GE<^S)Y'#$@,0@S6GMN>00S5GMF?E`S=G]R?X)_,
MH,`,N`S!#,(,NPR]#+\,N0RW#-*@QPS3H`P-"PU[0!`-C:%=#2%!6@U8#58-
MV*)4#19!O**H#:<-SPW0#8JDZ$&+I(VDT0WK#5.E^PUJ0EFE_0WX#?<-``Y6
MI5>E]@U?0G.F&ZC?#B&H%J@8J.(.Y`Y$J()$)JCC#C:I60]Q#XX/C`\ZJZ0/
M]*M51A008JX``````````````````````````````````````#0````U````
M-@```#<````X````.0```#H````[````/````#T````^````/P```$````!!
M````0@```$,```!$````10```$8```!'````2````$D```!*````2P```$P`
M``!-````4@```%D```!>````7P```&$```!C````9````&L```!R````<P``
M`'4```!V````>0```'H```![````?````(,```"&````AP```(@```")````
MB@```(P```".````E````)4```"7````F0```)L```"<````G0```)X```#_
M``````(```$"```"`@```P(```0"```%`@``!@(```<"```(`@``"0(```H"
M```+`@``#`(```T"```.`@``#P(``!`"```1`@``$@(``!,"```4`@``%0(`
M`!8"```7`@``&`(``!D"```:`@``&P(``!P"```=`@``'@(``!\"```@`@``
M(0(``"("```C`@``)`(``"4"```F`@``)P(``"@"```I`@``*@(``"L"```L
M`@``+0(``"X"```O`@``,`(``#$"```R`@``,P(``#0"```U`@``-@(``#<"
M```X`@``.0(``#H"```[`@``/`(``#T"```^`@``/P(``$`"``!!`@``0@(`
M`$,"``!$`@``10(``$8"``!'`@``2`(``$D"``!*`@``2P(``$P"``!-`@``
M3@(``$\"``!0`@``40(``%("``!3`@``5`(``%4"``!6`@``5P(``%@"``!9
M`@``6@(``%L"``!<`@``70(``%X"``!?`@``8`(``&$"``!B`@``8P(``&0"
M``!E`@``9@(``&<"``!H`@``:0(``&H"``!K`@``;`(``&T"``!N`@``;P(`
M`'`"``!Q`@``<@(``',"``!T`@``=0(``'8"``!W`@``>`(``'D"``!Z`@``
M>P(``'P"``!]`@``?@(``'\"``"``@``@0(``(("``"#`@``A`(``(4"``"&
M`@``AP(``(@"``")`@``B@(``(L"``",`@``C0(``(X"``"/`@``D`(``)$"
M``"2`@``DP(``)0"``"5`@``E@(``)<"``"8`@``F0(``)H"``";`@``G`(`
M`)T"``">`@``GP(``*`"``"A`@``H@(``*,"``"D`@``I0(``*8"``#X`@``
M^0(``/H"`````````````````-$[RSO).PP\`#N'.PT\#SP=XIA>TCL1/'X[
MTT524/Y7J6!"=`D[UCO=/]P_`D!S0'9!IT&H03-#S$,-12Q%&T9:`1U&F48^
M32U8+UB97K-NMG0;=N]_Z8,4.Y0[X3L&0$I`1$`Q07I!K4&N0;%!.$,W0WU$
M?D0M13)%(T8F1CKBH$:H43]4O%3$5CM8&5L86[-<JEZ^7ZQ@)65F96ME0W2U
M=.QU=G>\"!2!W%`<@AV"T)\2H?.E:<&Y%1')%<D0R1/)I#NE.]`\NCS+/'M`
MAD&[0;I!PT&Y0<!!W@`Y0SM#04/10\]#TD,N1&Y$C$2(1#5%0P$Z13M%.$4Y
M12Y&+$;(1K5&K4:P1JM&LTRI3+M1N5%:5LU6*U<%6*P#J@-16$M8ZEKM6C9;
M8EM66U5;9%M86P<<VES87*U>JU[`7\-?LV"W8+I@RQW^!,=@M6".9'-E;&5T
M9;3B<F5Q98)E<&4_;+INN&ZW="."(8(K@B:"(H(EB.2+%8_DGS.A*J$RH2FA
M^Z5;M%RT*+=OP6W!:\%NP1;)(CL6/$@\V#P`/4$`@#_D/[0`YS\,0%-`MT#H
M1=%!Y4'80=9!VD'90=5!YD'40=-!1$/60]=#$T3].G!$DD3;1-I$045#13-&
M]D;41MU&T$8$1]E&VT8%1]-&X4:`37=-@4V"38--7.)A4&!0V%'64==1!8%-
M5$A4UE;/5ME6V%8]5[,#5%A;6%Q8M`-96%A86EA56%98@ECP6AQ;:EMI6W%;
M9UML6VY;>5N+7+A<YUSH7.1<YESE7/!<@UZW7KM>N5[%7E-?Q%_&7\M?R&"?
MXLE@VV"49)5EB&6-9>QI[FGQ:2YL26Q?;M%NRVZ%<QT(2G1'=$MTNW3$='P(
M`G:"=Y%WCW>2=X]\D7RT?))\]'^J@#6"-X(]@CR"+X(P@OB#[X,FAE4+)H@G
MB$&*QHK'BNN+Z(OJBQJ/&8\F#2.4))0EF36A-*$'I1VMX;*KMF"_=\%]P;P5
M'LD:R1W):SLM/$P\*CU*`!4]+#T&/0@]"CU.`%9`A$#)`,9`]4$)0OA!Z$'[
M0>E!]D&W&K@:4D.V&KH:5$-10SE$.D281$Y%>P$V1PQ'$$<R1Q%'&$<<1QI'
M&4<+1P]''4<A1Q-'&T<51R`"T4S(3(U-M4V)`I4"^%#@4>%1O@+>4?Y1W%$!
M4OU1`%+75-94V51E5M)6W%;A5MY60E=+5\,#CEB16(M8D%B(6(E8A%BJ6(U;
MCUM]6W];>UN`6WY;@UN!6X9;BEN]7+Y<=P3T7/-<`EWV7/5<\EP$73U>QEZ)
M7]1?UE_27_I@!F$,80IA#V$O9=0%MV6^9;QEXF4&:O=I!VKV:35V7VQE;&1L
M86Q:;%ULU^+7;M5NWF[A;N!NV6Y,!]INWV[V;@-O(`B3<XMSD7.2<XISB7./
M<U9T673*=,QT6PC0=,UTUG3+=(-U@G4&=BIV+'8K=BEVO7>S=[YWP'>U=[9W
MG7R??""!+0H>@1R!,H$?@2N!(8$F@22!'8$G@5N"68*`@E6"4():@E:"8X)2
M@EB"8PHY@OF#*(88"[R&UH8%AR"'=`LSB$:*0HI#BD>*RXI"BT6+_8OTB_F+
M^HM>CAV/*`U8DE625Y58E=F5W)7;E2>9A9J'FHJ:BYU/GC"@+Z!HH4FAV@](
MH3^A2Z%<H4:A0*$-I1NF':87IJ00(J:GL`BQ!K-]OXX48[]DOW^_:[]\OVB_
M9;]JOYC!F<&NP2O)+<DQR2[)+\EM.S$\+3TY/3@]6P`Z/34]8CWJ/^L_%4#,
M0,A`S4#;0,M`$4(F0F)#7D-A0T%$/T1U1&5T24;K1!I%5T5K1ZE'5$=B1ZI'
M6$=R1V-'<T>+1XQ'7$=11Q9'8$=A1UY'74=D1U-'7T=;1VY'54=21VA'TDS6
M3--,N$V[3>M-Z$VV3>I-YTWI39%0$%$.40]1"U(#4BM2"5(H4BQ2)5(G4@]2
MZ53L5%,#)U9S5N)6YE9VXF%745<26`Y8K5BO6+%8TUB46Y);D%N=6Y-;E5N8
M6Y=;@`2*X@=="UT(7=E>U5[77]]?W03>7^-?XE_>!$=A(@4]83AA1&4Z9;AE
M*F8`9O-E\F7K9?IE[67L9?]E^V4&'TYF[V7W91!J$6H,:@MJW6LP;-L&>FQW
M;"AN)VYE;@YO"V]!;Q-O#V\2;S!OH'.C<YYSEW.A<YUSFW-C=.-TY'3F=.=T
MW72%(>QTY73Q=#MV.78Z=CQV/79'=C]V1'9(=TEW8'?C=^EW\'?:"-L(\G?M
M=^QWYG<6>-<(O'R^?,!\X'P`@`*`_G]>@+.`MX`Z@3F!/H$X@3V!3X%N@E^"
M@8*"@G&">X)Y@G>"<X)O@I>"?H+\@Q&$,H0QA!"$[(7KA2R&+8;:ABZ'+(<J
MAS.'2X<8B$*(.X@_B$&(0X@\B$R*2HI)BE:*SXI'BTB+1HL;C!&,%(P=C!>,
M'HP+C!R,$HP6C`V,%8P3C!B,&@RLCD2/+(]%CV:2;I)EDFB2A)(XE#N4.I0_
ME-^5W97>E>*5U@TLF2^9CYJ0FHR:DYHEG8B=IYWWGKN?.*`YH#>@%*%NH7NA
MW@]LH7^A>*%ZH6^AY0_^HTBF2Z9!IDFF.Z8MK>.P&K$-L1.Q$;$<L7(2M;.O
M$BFWH;<DN+NZH;V#OXV_A[^%OXJ_H[^)OX2_HK^QP;#!K\&VP<G!RL'(P;3!
M6<?)QT')3,G$%47)6LFY.Y0];CVB/6<]8P"C/78];#UD/:4],#VF/6D]I#V0
M/U]`8$#:0-A`W4#L`%E"6T):0CE"-$)$0C-"/$)80FI";T-R0W!#<4-N0_!#
MZT-)1$Q$]40@16I%<D5+1EU&4$?Y1_I'^T<C2+='(DBU1\1'M$?O1Y@!S4?P
M1[A'RT?Q1[I'`TCX1[9'O$>S1R%(]T?"1[Y'R4>]1\Y'N4?'1\I'S$<F2.1,
MX$SP3.Q-)$X83B].)4XH4")0:E!7/)10DE"<4")1,%$=42-1-5(S4B]235(Q
M4EM26E(R4EQ265)=4FE4;50R75@#"E4@51]5#57H5NQ6=U=P5W%7^%C66-E8
MWEC56.%8TP/B6-U8X%@.60A9W%@*60Q9M%NQ6[9;O%L=721=&5T;72)=&ET<
M72%=YE[D7N=>ZE[B!)OB\%_U7^]?0F%N83QAEV&,88%A<6'.8;IA>F%^850%
M<F&[82\%<V&"8;8%NF2X9$ME2&4K9O1E+&9"9DAF1&9%9CQF-V8S9D%F,F:'
M9B=J(VHM:A]J+&HH:G5K=&OG:S)L,6R9;)9LF&R=;))LE&R5;)=LN:$U!Q%O
M.V]Y;T)O0V]=!WAOK',I"+%SM'.S<Z]SJG.R<VAT\G3^=/AT^73_=/5T]W3]
M=`!UB'5N=EUV8W9@=F%W-WAQ>"-X(G@?>"5X_7P1?2-]\'SO?`Z`#("Z@!\*
M4H%5@5.!5(%1@5B!L(*?@G(*H8*:@KZ"H((WA`L+\87RA32&-X8UAHQ>WX9,
MATZ'9(=CAS:'6(AHB%N(7XA9B&6(8(A>B-6*UHI.BU*+-8PYC%B,08Q7C#B,
M/8PRC$2,1.-CCF*.N(ZPCK&.38]CCW"/2X]/CTZ/4X]'CZ(,5(]2CUF/?H\K
MD2Z1?Y)^DH&2@Y)'E%24391,E$N45Y1EE625895BE?"5\Y7YE?25]97OE?B5
M_)7WE?V5%Y8TF3:9.)FOFJZ:K)JBFBB=PFF<G;.=D)T&GP2?"Y\%GT"@3Z"K
MH9VAN*&RH=*ASZ&BH>P/I:&IH:>AT*$"I,^DT*06I1FE=:9QII&F<J:.IFVF
MB*9SIKL0@:9VIGNF?Z:0IGBF2ZU(K5NM4:T]K4"M1JU-K3NM2JU!K3ZM3JVL
ML.:PZ;`IL2$2,[$NL1ZQ'Q+%XR*Q)['GL@NS9K2MMJZV.#`KMRJW++@MN)$3
MEA./N9.YQKK%NA6]$[VQO:F]SC&HOZN_OK^LOZF_IK_!O\S!T<'3P>3!R\'A
MP=+!X\'/P=#!Y<$.PLS'RL?+QUS)8<E=R5G)=\N$T4$[_3L:/&,\MCVR/>D]
MYSW6/3`^[#W=/>@]L#VU/>$]F#^9/[P`DT#E0-@`8$)>0O0`>T/Q0_-#?T4X
MXE=&6$8Y2*=(-4A@2%%(8DA"2#Q(0TBK2*E(M$AY2&I(.TBJ2#-(-T@G2*A(
M<$@O2#9(M4@P2#I(.$BQ2*Q(+DAU2+!(]TP`3?%,\TQ@3F%.,DXM3DI.*DYG
M4*)0HU">4*101%$R49M2F%*94II29E)B4FM28H!G4CM5(U4I57Y6\U:%`_56
M@P.`5WY7?%=_5WU7@5<E62E9%UEC66=995DJ66A9)EED61M98EEI6?Y:1%M"
M6[=;TEO46]=;W%O16]5;S5O86YI<0ETU75A=-%T\73M=/ET]75I=05TX745=
M,UTF7KH$]U[O7O!>[EZ=7P9@$6`(8`)@"F`'8)%ACF&%8>AA%V+486D%Q&'5
M844%V&&`8=YA0F+'9+]DC6:)9I!FFF;(9I)FH6:$9E=J1VIW:CIJ4&I":D-J
MHVIW:[)LXFR];'1N@F^X;VP'NF^Y;[MOAV_DXH-OMV]#.\YSNG-S=`EU"G4+
M=0=U!74.=9=U=W9[=GIV='9Y=H9X]7BE>)UXOGB6>.%XI'BA>/9X!`F->(MX
M>'B8>`IY77TG?5]]P(#!@&V!7H&*@6*!9($Z"L""RH+1@GD*QX+.@@DCQ8(V
MA%>$=X3VA?>%589$ACZ&0H92AN&&"(=HAV>'70LWXWZ(DXAYB(&(?8A[B)2(
MB@MFBMF*X(H^XU^+7XQ>C&B,)PR(C&J,;(QFC&>,B8Q@C(6,*CYHCKF.NHZ^
MCF^/@(]TCX&/>H^<CW./@H]_CZ>/>8]XCWV/J(]\CVB13I&>DD8-0`V8DC\-
MA9*<DL62FI)HE&649Y1AE&"4G0W+#7N5X0T9E@Z6,982EA"6%98_EAV6'I9-
MF4B919E"F4F92IE'F7\.3)G-FM6:Q)K*FL.:1@\IG;2=;9YFGFJ>%9_3G^R?
M5:`:$-:AV*%1HN"A`Z($HMJAZJ$"HM.AY*'EH3ND9J0LI2&E)J74I=6EV:75
MINNFQ:;3$">G\*:YIABG[J;0$+>FNZ;OIKBFWZ;:IN.FR:;LIJ2LCA&CK%ZM
M8:UBK6.MCJUIK6NMA:V-K62M;:U,L4FQ1[%(L4*Q1;%;L5VQ1K$3LQJS#K,/
MLQNS$K/#L[ZSO;-YM'RTPQ*V$H"T=;2;M"\O=+3`$K@205N47S"WI[>EMZ2W
M.KA;N9^YJ+FSN:&YI[FRN9VYH[FBN>^ZV;K9$]6ZW;K:NNZZU[H:O1F]&+VS
MO;^]N[W`O;F]N+W5O1&_$+_#O\*_Z;_-O^6_RK_'O^B_\<$,PN_![L'SP0W"
M]L'PP>P4]<+TPOC"_L(1Q"+$0L1<QUK'7<?1Q]#'=<E[R8G*3<^)T9+1C-&(
MT6?3:-,A/O(]"3[X/?`]\SWU/?L]]SWO/0L^HC_U0/-`]$#R0)A!:$*`0H5"
MCD*/0O0]AD*D0H9#B4.'0X5#W!J(0_]%9D;,`<-(H@'$2#M)YTCX2/M(M@&^
M2,9(Q0'&`?Q(P$@S2<E(_DC:2,Q(NTC]2-](S4C"2,A(,DDM2=)(,4G32"Y)
MSTC_3`E-_$QR3JI.JTZG3GM.=DZH3JQ.@P(A&ZI0`T6L4*U0JU!045A1W5+X
M`JY2HE*K4N-2KU+@4N12]@*G4JI2XE+A4M]2K5+E4M%2K%+54J-2GU)Y5'94
M0U4]54=51%4_55M5?U::5YQ7FP,>6(A9:EEV67)9<%E^66Q9;UEU67=9>%F*
M67E9E%D!6P5<\5ON6^];!%P_'/I;!UST6_5;G%QM76E=9EUB749=C01E75U=
M7EU?78Y>`E\&7P1?`U]B7R=@(6`@8"1@*6`Q8"-@(F#<84UBY6'38>YAYF%6
M!39B0&(_8SUB1&);!5]B*6))8HIB*F*'8DQB,6)(8BMB.V)!8LEA-&)38C5B
M1V(X8M%DTF11955E4F5398]F]&9'9PUG'&?[9AEG]V;Y9O5FZ68*9^YF"V?]
M9@9G`F<69QAG\&;4:69J:FIU:G9J@&IM:I8&:6IG:FAJ76JD:_YK_6OL;.EL
M(6WK;.=L\FP@;7IN+7`N<,IO+W#(;WX'RV_#;X1OTF_&;X$'SV_5;]1OW6\K
M<*-PVV\L<!-P-0C1<\QSU7/)<\]STG-[='QT(W4==1QU'G4B=21U('48=2%U
MB':*=I1VCW:.=I!VFPBG=F1W``D8>11Y'7D%>?]X&WD:>1EY`WD.>4=Y!'E:
M>0=Y('EJ?69]>GUE?:]]S8#/@-&`SH!?@7>!=(&(@76!B8%R@<:"ZH+@@@>#
MYH+E@MV"XX+:@JZ$?H1]A'^$TPK9A/J%^X5-AE2&4890AIB(E8B=B,&(FHB;
MB)\+G(C7B*2(EHB@B#&*Z8INBYJ,I8R4C*:,F8R+C)B,D8R,C*&,HXS&C&^.
M;8YJCFR.<8YNCM^.K(^JC[$,M8^MC[*/LX^KC[:/QX_&CVR1<)&SDDL-C)2!
ME(.4?92%E)"4HI2-E(^4?I2*E'^4=I2'E'B4@)6"E8&5@Y5:EC26+)8JED"6
M+98SEBN62Y8_*#R66IEWF6"9^IKYFOR:U@[UFNB:"9OGFN::Z9HRG2R=O9V\
MG7J>?IYYGHD/(Y\PGRB?U)_.I?&?\)]@H&6@J*$*HANB$J('HD^B#J)2HA:B
M`!!3HE2BA.-6HFVD<J0OI2JGW!!CIX2GKZ=%IW"G5J<6ISVG.*=OIW>G+J<Q
MITRG7Z=UISFG.J<LIRVG/Z<OIS"G/J?0*I`1LJRWK8^ML1&6K9ZMEZV5K:6M
MF*WG*Z.MFJVMK::MMJV9K:^MK*VJ$9^ME*WKL&^Q;;%^L6RQ8;%CL6NQ7K$^
ML62QK;%]$B"ST;/5LZZTK[2?M*BTRK3AMCFW.+<[MZVWM;>OM[&WKK>TM["W
M2[A1N$RX:1-@N+ZYN;FWN;:YH1.]N;BYP;GWNO.Z]+K[NOVZ];KG$_JZ%+OL
M$_*Z_+H`N]\3*[TIO2Z],Q37O=N]V;W8O>:]UKW1O>>]T+W<O>V_&L`9P!;`
M[+_OO^Z_]+\OP##"&<(8PA'"%L(2PA#"%,(,PPW#$,0IQ"C$9<=FQ]['W\?@
MQ]G'V\?8Q^/'U\>FR:?)O\FHR9_)H<FBR:W)H\F@R8/+A<N"RX3+[LQ=S9+.
M5<]3S_SC4<]2SU#/G="'T9?1F]&=T6G3$=7N%WK7,AA$;<8[0#XN/F@^+3XT
M/C(^:3XQ/FH^/CYO/G4^]C\@0"A`9T#[0/Y`_$#]0/]`^D"L0J]"L4+\`+]"
MOD*G0JI"E$.30YE#*@'Z0U9$(D6119)%"$8&1M9(-TE+2<Y)T$DY261)STE&
M269)5DE#24I)6$EE25I)6TE525!)3$G-25%)1TG3`5-)8DG,2=<!?TE-20I-
M#$T/3;M.N4[K3JY.P4[J3KY.OTZZ3K=.LT[I3FY0KU"S4+)0:%%I46I1WE+K
M4A%3[5+I4O=2]%+J4A)3Z%(34XY4AE1C5655F5;"5ZY7L%>M5[19T5FM6?,#
MO5FW6:M9KUG!6;59#UP.7!Q<$UP*7!Y<%%P:7,M<AUV379$$A%V%79)=@%TK
M7F->"E_`!&9?-&`S8$U@B6)78A<>2F)C!3EB/V*08H]BLF*?8I5BH6*<8HYB
MH&*N8I9BRF*L8G`%IF*78I-BMC[69.!DV&1696YG?F=T9W=G@&=Z9VMG7V=V
M9[!G8V>2:H)JG6J4:H-JBVJ$:E=KA&NU:PELYFP"!R5M46T^;MKBA6X_<$)P
M.'`Z<$YP17`Y<#=P1'#GXJ1P/7!!<-]SWG/*<^ESXG/@<XETAW0R=3-UK'7Y
M=0UVN79>>6IY-0F!>6EYK'F`>75Y<7EV>6]YMGT#?K]]`7ZR?<1]VX#<@-B`
M<M&U@:B!CX&>@8Z!WH+B@B"#'8,:@QF#*X,8@Q"##H,D@Q^#$X,U@X.$X`K7
MA`*&`X9<AE^&QX::AY>'HX?WB,:(S(C6B,V(^8C9B-B(F@O1B,Z(U8BC"]2(
M^(AZBGF*?XKSBO6*]HKTBO>*!0QYBYR,WXSUC/^,T8S:C,^,S8S>C-B,K77@
MC/Z,GHQUCG..<H[8CM"/UH_7C\J/S8^*D8F1BY'3DMJ2SI+2DEX-U)+7DM62
M^Y+-DOJ2UI*F#9N4GI2=E*24GY2EE*B4CY6,E9658)95EER6;Y91EF&6IY9>
MEF*65)9NEE*66)9MEE^6;)90EEV6CI9RF7B9=9EVF7R9?IE]F16;%)L=FQR;
M(YM7F\B=70_)G<6=AYZ*GI2>.9]`GSZ?.)_6G[@/=Z!XH'V@W:%>HG>BU*)F
MHE^B<Z)RHI>B6J*6HEVB9:)PHG6B=*)<HF"B-!!MHD&D/*4^I6\02:7DI@RH
M%:@.J-2GQZ<4J-NG7ZCMIPFHSZ?_IQJH]:?NI^6G#:C?I^RGUZ<LJ,VGXZ<`
MJ.NG_:</J"VH4*C^I\2GX:?YI[NLO*R4$9,1NJS0K=:MSJWAK=6MSZW3K10L
MU*VUL)"QH;&!L86Q;K&(L8*QAK&/L8FQ@+&$L=$M*;,KLRJS,+/BL^.SX;/5
MM,2TR;3@M-^TR[3=M.BTU+0<M;6VMK;EMD6W2;=`MT:W1+=*M\FWQ+?"MVBX
MRS""N&NX9[ALN&VX<;B2$]>YTKG9N:H3O+G=N=:YIQ/8N2"[%KL8NQ6[&;LG
MNU"[';LLNQR[*;LKNR2[[Q,HNSF]\KWPO>TQ[;WOO>J]`;Z\OUS`6\!:P";`
M0\(SPCK"-\(VPCS"-,)*PCO"-<(]PD#"/L(7PB;#),,0PS;#)<,B%6;$?\=Z
MQ_O'_<?\Q_K'ULG2R<C)PLG'R<W)P<G&R<S)H<J5RY3+E\N6RY/+H<L)S0C-
M9\UES6+-8<V7S@'/&<\8SUS/9\]LS[46_>-FSV'/;L]=SUK/HM"IT*70IM"R
MT*/0K-&JT:_1J]&QT<;1K=&YT7#3=1<,UX'7@]=^UU'8F=J4VI7:_MT8WP4\
M<CZ"`)D^K3\&0<)"RT+50M)"S$+70L5"RD+L&J)#HT.A0^@:ID.D0_]#`$0U
M`09%)46?17]&ZDGK2=Y)&$K@2>A)WTGQ2>Q)&DKF2>%)74IW.QY*\`&`2A=-
M'4_W3N].[D[M3O5.'D^]4/^2OE!M47913%,94TA3'E-*4TE3)E.55(55?E67
M57U50E:>5@Q7"U<.5\]7V%G@6>A9Z5GB6>%9VEGC6=E9\%GG6>19(UPQ7#-<
M#%S@I"9<)%PR7"=<(5PP7*)<S%R678_BF%V<79M=:UX27Q1?6F!48%%@7F!8
M8/`$66":8O)BK6(@8_%B\&+S8O1BZ6+^8BYCZ&+G8O]B]6+E9.=DYF3I9%AE
M;&?99SX&RV<Y!KYGM6?19\)GMF?39\+BVFFB!JYJH0:L:JEJNFJG:K-JO6JQ
M:@YL$6P/;%)M:FU4;55M4VU7;=#B6VU8;5EM.P>X<+5POW#!<+MPMP?#<*UP
MJ'"N<*IPT'"Q<+QPMW"P</IP^W"Y<`=T_'/_<_)S^'/T<U<(<`BN=0]V$';!
MU<=VQG;.=J<(W';5>=-Y('KB>?%YVWGJ>>MYX7G_>=9YX'G7>>5Y5`D;?A!^
M#WX.?CE^"GX4?@Q^(X!:@.*`DX&P@:N!O8&Q@8V!K8&J@:R!O(')@4>#8H-`
M@T2#/X-#@SV#8(-?@SJ#0H->@UV#O(3@A.Z$ZX0-A0F&#(9IAG2&9X8Q"R<D
MK8?_B!:)"(D)B0")_(@3B12)"HD^TRF)%XD[B?N(OPL.B>0+"(L;C1J-&8T"
MC4H,%XT'C1.-"8T*C1*-JHTXC7N.?(YZCNJ.ZX[OCO"."9`"D`&0*Y`'D,\,
M*)#[CRJ0_H\$D"F0"I",)L*1D2:FD10-QFH'5PJ3_9(&DPV3"9,+DP"3!9,]
MD]64OY2ZE,>4F)6:E0T.I):<EIV6HI:6EI66I9:JEJV6FI:CEI>6D):OEHV6
M`0ZHENZ6HYF9F:&9G)FDF<N95IM(FUF;2IM<F_$.3YM-FUV;.IWCG>&=WIV7
MGIJ>2)]*GTR?3I]/GTN?39]'GU&?VI_YG_R?^Y_]G_B?^I^*H(Z@B*")H(V@
MD*!^XQRBJZ*DHJBBK:*?HIJBL**EHM6BHJ*RHIVBH:(5I$*D<Z2$I-VD7*5,
MI7802Z5GIZBH?ZB-J(NH]ZBIJ/2HFJB,J)6H?JAWJ`H1`Q%QJ/VHB*B9J&VH
MU*B1J'VH8ZAUJ/FHCJATJ-FH9JCZJ/6H8"O!K,FL`ZXLKC2N%ZX)K@2N!JX:
MK@ZN)ZX%K@>N&:X4K@RN':XBKB.NN["\L+JPJ;&UL:RQJK&OL;>Q-1(V$CVS
M1;-(LSRS/K/LL^VSZ;,*M0NU^+0$M?:T^;13MU*W8+=CM\ZWS;?0M\RWA[B-
MN)VX<Q-CN?2Y\;G_N?6Y_+GRN?:YL1/ZN:\3+KM%NT.[4;M,NW.[1[M+NT^[
M]!-$NTV[3KM*NT&[4KN?NU2[6;NBNTN]2+T-OA^^"+X.OAV^!+X8OQN_9L!B
MP(/`9\!BPD_"3L)GPE/"3<),PFC"4<+<%%C"6\)0PFK".<,XPX+$A,2&Q(#'
MAL<ER!'(F14.R!7(#\@8R`W($\@6R!G(",KWR?O)_,FTRK[*P<JFRZ7+HLND
MRQ+-#LUZS7C-?<U^S8'-@\V`S8+-F\Z9SIS.FLZASAK/',^*SWG/<\]USWS/
M>,]@SX//<,^V%KT6A\^$SWO/?L]TS[G0N-"WT+70S-'.T='1!#7+T9LU?M-Z
MTW?3C-/ATR#5'M7"U0_6`-;T%Q#6#=<.UX[7C=>*UXO7C->/UU?8-1A5V%O8
MK-JGVJ#:GMJJ&(W='QF3WI3>DMZ!/-8^PS[D/N(^"3^_/L@^QSZU/[(_#$$+
M00I!!4'30N9"Z4+P0NI"YT*Q0[-#M$.P0UQ$741>1,!$KT50`89&@T:$1EQ*
M<$J,2GM*9DIY2F-*Q4IK2FU*<DII2G5*B4K&2J5*YSYJ2I=*6D]<3UE/)$\E
M3S!/6$\Q3W90P5"%47U195.'4U)35%.*4U!3AE-/4VA3G52@5;I5O56X5:96
M>P/>5]A7T5<36@D$#EH;6CI:!P0<6A):%EH:6DA/2UPW7#9<.%PZ7$E</%Q*
M7+%=PEVU7<1=MET>7Q]?KU]K8&]@DF+D8BQC[V*$'D]C4F-08SIC-V-'8V1C
M0&,\8T5C06/S9+L%P6>T9TL&*F@B:"EH308^:#QH,&C':M5JUFK3:LYJR&I<
M:U]K8FO"!KUKOVM<;;9M&@>=;7]M$@>4;8%M1VY&;CP'E&YU<1IQ*G$R<1=Q
M(W%T<<,'=G$N<25Q('%Q<19Q<'$L<2]Q'W%D<<`'"'04=`IT"W1/=5EU5'51
M=;9U[';M=NIV[GE:>G-Z97IA>E5Z:WID>EMZ3'IO>H1Z<'I=?E=^9GY3?IA^
MEWXH@.N`ZH#H@.R`[X#1@<J!GR+/@<V!SH%P@V>#<X-M@W:#>8-J@XN#<H-Q
M@VZ#>H,6A3F%.X40AI:&>X9\AGV&OH=<B3B).8DNB32),HE;B3.)/(GE"PZ+
M#XL0BX>+6XU3C5\,7(T_C5F-2HU$C4R-0(U?C5Z-3HU4C4.-AXV"CH6.,9!'
MD"Z0+Y!(D#20&`V?0#*3-I,SDS&30)-!D]V4TI39E*T-WY3;E-B4TY3>E."4
MU)37E-J4IY7^EMV60)?BEAX.UI;>EN^6)P[KENJ6Y);1EA@.[);ZEMF6\Y;A
MEMR6Y9;?EM26(`X%E]:9U9G0F<B9Q)G)F<V9TIG,F<J9H)N2F_0.`@^+FZ&;
ME9N(FX:;C9N%FY&;B9NBF_"=\YWTG>^=!IZBGEZ?8Y]@GUN?>Y]8GUF?79\%
MH`:@`J`#H`2@HJ"GH*:@I*"LH*F@YZ(!H]^BV:+CH@^C&J1%I$BD>Z2%I(:D
M_J3_I&2E<:5RI6&E8J5LI6"E7:5CI6>E`:DJJ3"I!JE]J2*IN:D*J1"ICZB`
MJ1.I+JD8J1>I&JD4J4>I8ZDXJ201?ZDAJ3>I,:D;J:6I;*K3K(BN;JY<KG2N
M5*Z#KG`L9:Y@KG"N;ZYMKG*N;*YVKG6N6:['KL&P^;#CL>>QUK'/L=JQZ;'2
ML56S3[--LU&S5K/YL_BS!K0#M`FT][/ULT>U1;4^M4:U*;4TM3^U1+4UM5JU
M*K4SM3>U0[4YM3"U7;4RM2>UO;:ZMKRV\;;PMF&W7+=8MUVWVK?9M]VWW+?>
MMWT3H+BBN`^Z$[H2NA&Z%+H9N@ZZ%[HANB"Z%KIXNS<QA[MYNX"[=[N!NT:[
M>KN<NX.[A+NMNYV[GKM5O3:^*[XGOD:^++Y%OC.^+;XTOB*^9!0?O[/`C,"/
MP*_`K<".P*S`L,"QP*[`F<#KP73"=<*.PFW"<,*,PD_#4<-8PTS#3L,5Q+[$
MV\2SQ*[$A\>*QXC'B\>,QT3(+<@JR#'(+,A%R##(*<A&R/3)%,H0R@_*$LH+
MR@S*"LH3R@[*V<K0R@,TP<N_R[W+O,NZR[O+T<N^R]#+N<L:S1S-&\V1S9;-
MG\V<S9K-G<VMSJ7.KLX#SR;/(,\CSR3/(<\HSR7/'L^4SY//C\^:SZW/PA;*
MT,70N]'AT>K1Y-'MT>;1X-'HT>71&M.4TY;3GM.5TZ'3CM.;TY+3E].9TY/3
M,M4OU2[5,]4<UA[6$=8@UA_6&=86UJS7N=>SUZ;7HM>IUZ?7;-AMV&G8@-AF
MV&78<=AKV+W:P=K3VK;:K!BYVM3:M]K;VKC:P-J\VM7:O]K#VLG:6-V0W97=
ME]T)W@C>!MX%WA#>E]Z5WN[>']\:Y$M6CCSH/O`^]#X&/^T^FP#I/@`_N#]M
M0`1#`4,#0P)#]AHF`6)$ND431MY*UTKD2LY*XTK=2CI+VTK62N!*U$K+2N%*
MR4K?2CQ+_$K/2GE/=D]X3X=1G%.Q4\%3FE.24Z\-PE.64\!3D5.54Z)4PU7`
M5<)5BD:P5A971EI*6CY:15I"6A4$6UI$6@1;(GM57%=<45Q.7%I<QEW#79P$
MQ5W,77%>)E^R7WI@A&![8'1CC&-18TACC6.28YACDV.P8TYCEF.78YQCRF,S
M:(-HA&B::(QHS""9:.!IY&KX:NUJ\VKT:O5J_6H9;)YMQ&V?;9MNGVZ:;JIQ
MG7&2<:)QKW'K<:!QH7&4<9AQCW&'<81QJ7%\<1AT7W5B=6%UP'45=OQV^7;(
M>LEZWGK*>N)Z9`EN"01[S'K=>N1ZTWK'>L9Z7PDW>]A^[GZR?J-^LW[M?OA^
M,8!;@&:`:8"6@)N`]X#S@/2`]8#B@>>!Y8'I@>:!XX%T@W^#CX.0@Y>#HX..
M@YB#C(-"A42%:85#A6B%]@J-AHB&BX:)ALR''XB`B5Z)9XEHB66)2B5TB6F)
M88EBB6R)DXF&B9V*FXH;BQ:+&8L4BQB+%8N9BYB+78V)C7J-?8U+C7,,>(U_
MC7>-?HUYC:N-?(UTC76-IXV-CDZ09I!AD$V03Y#=#%20?)#:D=Z1V)'=D=^1
M9I-BDU^39)-CDV"3B)-JDV>3AY,_DVR3;I.MD_&4])3VE/64^)3[E.R4[Y3M
ME+DG]Y3YE/V4L94VEQN7,I="ETV7'Y<AEQR7,9<NET>7.Y=!EQB7.9<=ER>7
M(Y?7*.Z9Z)GEF>^9Y)GLF?"9UYO8F]2;RIO2F\N;TYOFF^*;29U(G?^="9ZP
MGJ^>?)]XGWJ?<I]YGWZ?#*`+H,V@OJ"\H+^@P*"]H#BC"*,%HSNC$*,,HPVC
M!*,ZHQ.C-Z,YHQ^D2Z3NI'6E>*5\I72E=J7JI>NE^Z@9J:>IC*G<J9BIOJF>
MJ0^JGZG=J9.INZFVJ9"IH:F]J=ZI.JDBJI>IE*G#J8ZIJ*F9J:VIFZFBJ2&J
MK*D.JC&JX:S>K-^LW*S=K.RLYZQIKKBNH:ZHKKJNPJZFKJ2NHZZKKKRNMZZ_
MKJVNL:[*KL2NN:[(L,:PQ[`*L@VR^[$#L@*R_+'YL?BQ;K-CLV*S8;-KLX@2
M;[-FLVRS#K05M!:T$+07M!&T;K5LM8>U@[5CM=RUP+;WMOJV<+=JMVBW:;>$
MM^RWY[?NM[JXLKBUN,NX"T/0N&VY;+F[$T6Z1KHTNBRZ-;I$NKH3=KJQNZJ[
MH;NRNQ(4IKNUN[2[N+NON["[H[MBO62]5KY1OD^^:+Y,OE"^811(ODJ^(;_C
MP+G`WL"WP.'`ML"UP-_`X127PIK"F\*8PI+"D\+7PG/":\-TPWC#;<,8Q.G$
M]<3JQ"[%Y\3^Q.7$-L7PQ.;$+,6)QY7'D\=-R$K(3\A0R$O(*LHKRB_*+LI\
MRNW*XLK@R]S+VLO6R_3+V<O5RR+-(<TDS27-)LTCS:K-K\VPS:O-K\ZWSK7.
MLLZSSBO/V,_"SZ_/O,^XS[[/M\^TS[_/L\^QS[O/O<_6S]W/V-#3T-70X]#B
MT-G0WM#?T-K0U-#ST>+1#=(!T@72&M(#TA_2%M+ZT?S1"M*?-;S3RM.VT\?3
MO].)%[G3C!>PT[C3O=.1T[O3OM,^U3W5.-8]UCG6,]8SU[O7QM?%U\?7R]>H
MU\C7OM?!U[W7@MB>V('8A-B--I;8CMB(V(?8X-H-V]_:Y-KBVMW:[-K>VN?:
MZMKCVES==SE=W9S='=Z=WI[>F]ZUWKG>MM[SWO+>]-XFWR??)=\&X`O@.N`\
MX`H_"S^_/_T_&$'?S)".GD'\0A!##T,-0[E#MT.Z0PI$04N+2T9+4TOB2S]+
M?$I+2TY+BDM'2Y-/SKB,3Z]/R4_&4,A0D5'/4]13SE/=5=1525IC6EU:&@1G
M6KM:8%J`6E]<8%S:7=)=W5V.8(A@;&">8\ECI&.8!=ECTF/:8]UCSF/\8Q1E
M8&77:,MHS6C5:.=I`&L*:P]K`FL!:QULRFW+;<UM3VZ<;H!Q#7("<O$'!W+W
M<?AQ_7$D<OMQ.7(Z<B)TJ2%J=6UU='4.=]]Z*WOC>B9[*GLC>S5[2GO]?@!_
M'G__?IZ`^H#Q@96#J(.F@VZ%@X5MA8^&:@O?A]6'X(?3A]B'C(E+)92)EHF%
MB8^)J8F.B9")N(G#B;N)I8JBBJ(EHXJUBZR+J(NMC;B-M(VNC;:-A1#!C;^-
MDHX`CP&/=9!RD'B0<)!^D'V0?Y#OD6V3CI./DXJ3C9.5DXN3C).PDY.3_)05
ME0Z5&)41E0V5NY6SE3D.H9>:EX27H)>&EYV7JI=XEXV7BI>FEWJ7EY>(EXZ7
M/0Y$#G:7@9>%EW67J)>/EY&7HI><EXF7?Y>6EWF7GY>GET8.AY>;EZ67BY?)
ME_^9`YH`F@*:!)H%FN:9'YH4G`X/#)P/G!F<"YP3G-6;$`\<G%"=3IT2GKF>
MA9^(GY"?$Z#0H-&@TJ#7H-:@Y:!&HVNC1:,_HSZC/A!JHVBC3*,CI"*DEZ21
MI+65F*2<I(FEA!"+I8JEC:6.I8BE3JI$JC>J=:I4JG:J-*IKJC*J5ZI2JD6J
M21&QJ4NJ1ZHSJD"J/*I#JD^J5:I!JK*JP*HTK_FN&:\-K_JN'J\?KPZO0*\(
MK]\1$Z],K_`1S+#+L"2R);(]LB"R)[(FLAVR'K(RLFRR6;**$GJS>;,;M"ZT
M([0@M!^TMK6YM:&UH[6HM:^UFK69M:*UG;4"$ZNUR;;^M@"W_+8'MW6W<K=S
MMW2W^K?\M_BW]K?[M\VXT;C/N'2Y<KESN52Z4;K`$U.Z2;I,NDJZ3[I6N@"\
MU;O7N_^[V;OCN].[%138N]2[WKMQO72^B+Y_OFN^A[YYOGB^B;Z`OG:^*;\H
MOR^_Y<`$P0/!\,#HP.K`\<`!P0+!J<*KPK?"ML+B%*##CL.&PX?#A<.+PXC#
MD,,:Q#3$-\4OQ3#%.<4TQ3/%A<6$Q3K%G\=IR&S(:LAGR&O(/\I`R@O+TLOX
MRP',^LL6S/;C+,TMS2_-+LW!S?7-Q,W>S<S-TLW"S<W-S\W=S<C-NLZ^SK_.
M+L\PS^?/[L_HS^;/XL_DS_O/_,_JS^W0]M#ST/30\=#WT/70ZM#KT`#2+-(2
MTCW2,])-%S#20-(QTE?22A<UTC+2+=(VTCC28M)?THK2UM/8T]W3Y-/CTTW5
MU]5*UDS64-9+UD[63]8YU]+7S=?3U^'7SM?5U]W7U-?/U\O8IMC"V*78J=BB
MV*38L-C,V*_8O]@DVQK;%-LZVR#;&]LAVR7;'ML_VT#;&-LLVQ7;+=L?VRG;
M2]NSW:7=I]VKW:;=JMTBWB/>H=ZCWJ#>O=ZZWOK>^-[\WO;>--]#WV,9U-\-
MX$/@0>`]X$#@/N`_X$;@DQG4X#4_-C\R/SH_R#\V0!Y!'4$?01Q#'4,@0PX!
MP$.:2Y-+W4L*`J-+J4N<2YM+#0*72[%/RD^S3\U/ZE/N4^]3WU505KM6B%J)
M6HQ:A5I>6I1:E5IK7&I<:5SC7?%=-U\S7Y%@CV"78-1CWF/38^!C0V0+9/]C
M!&0'9/EH^FC[:/AH$FL0:Q]LWVWC;5)NJ6YE<H=R0G)2<DQRGW$!<DAR3W)^
M<DUR6')'<EYR27).<EUR6G*&<E%R*72F=*=T<'5O==-UTG4H=QMW&G<<=R%W
M,GMF>WU[<WM_>V5[@'MA>W5[;GMG>W%[;'MC>V)[@WNR>X%[;WMK>X)[BGLI
M?S!_,7^7@`"!_X"V@[6#PX.-A1B&G(::AIF&MXG$B<:)QXF\B<")Q8G-B<&)
MOHFGBKB*(XMT#.B-WHWCC>^-W(WDC>&-Y8V5CI2.DXZ.CIB0G)"9D*"0GI`$
MDM.3M).[D[>3N).]D[:3N9.UDR*5(97#E;R5_Y?EE_>7TI<`F-N7\)?BE\V7
M5@[AE_*7W)?,E]:7\Y?ZE_:7[)?JE^.7T)=:#I67U9?TE\N7VI?(E]^7]9?/
ME\>7UY<DFJ,.')HAFAZ:&)H;FJ@.1IQ+G$B<1YQGG%2<%9XBGL6>*9['GHV?
M&Z`@H.*@YZ#HH.&@<J-[HW2C<:-YHW6CD*-WHWVC3Z10I*.DHJ3TI)2EFJ6;
MI:>EEZ65I9*EG*66I;:JN*JPJABKQ:JUJL*J!JL9J[FJ%:O6JJRJ/!'&JK.J
MPZK*JL^JO:K.JA2KNJH:J\&JNZJ;$9H1`:W\K%JO5*]AKURO5:]*KTNO4:]I
MKVNO\2QFKUBO7:]GKU:OB*]DKTZO5[):LE&R2K)+LEX21[)OLFJR:[)&LFVR
M5+)NLDRR>+.&LX*SIQ+AM>6UV[7>M=>U`[=\MWZW!;@'N.:XX;C[N.6XY[C?
MN/^X=KECNF:Z9;I>NF2Z:[I?NF>Z:+H(O`F\%[P5O!N\"[PHO`Z\&+Q3O$6\
M#;P*O!.\2KQYO:&^C;ZBOI"^;A0QOS"_'\$9P0S!'L$=P0?!9L+%PKK"O<+"
MPL/"O\(-%:'#HL.HPZ/#JL.OP[G#-\2/Q4,5CL6'Q8K%DL67Q9_%!<:IQZ?'
MBLB"R(7(B\B)R('(@,B'R(;(3<H<RQ_+(<P=S"+,_LL;S#K,-\P7S#C,)LP8
MS#3--<TRS7,6X<W]S>/-Z,WYS?_-_LUT%N#-`,YP%NS-Y,WOS?K-RLXQSS+/
M-,]!SP#0!M`(T`70`]`+T`+0"M#PT!/1"M$/T1'1"-$+T1+1#=%;TF/28=)H
MTEK23M--TU#3_-,2U/73'M3PT_/3\M,!U._3[M,6U/;3^],<U-L77=5@U6;5
M7]5AU5O58M57U6G6:]9AUG?67]9CUF+69=;OU^+7`-CHU_+7Y]<I&.77U=C0
MV-K8T]A1&-G8S]C6V-C8]=C.V-?8]-C-V`'9NC92VU7;6MM-VU3;4]M>VV?;
M9=M.V]L83]MAVV[;4=M;VV/=M]VVW</=N]VUW2[>,-XSWC'>I-[!WKO>OMX`
MW__>0-]E&3_?1-]D&6<9V]\/X!'@3N!-X$O@3."5X#L_13]$/SX_/#\_/\P_
MSC\B02-!GT'%0\1#Z4N92Q$"YDOG2_=+TD\S`_U3#%0+5.U7(00B!)M:"EMO
M7'5<\EWX73Y?)&0.9!9D&&009#%D1&2F!2ED+V1+9#9DHP4T:0!I*VD@:R%K
M'FL=:_5M\FWV;9!RG7*<<I)RE'+1<I-RMW*7<K!RGW+)<BUT+'1W=2QWP'NY
M>U-_0(`"@ON!H0J+A:Z%JX6AALW=ZH?=B=R)V8FKBJR*K8JRBBR+*XO"BP".
M#8X&CO^-`XX!CA".#XX%CIB.EXZ6CIF.K)"KD!*2V)/?D]:3+94RE3^8+Y@F
MF#J8.9A?#CN8-9@JF"&8.)@WF#287`XBF#:81)A%FCN:-II"FGJ<AIR+G'^<
M@9PJGM6>GY^=GR:@]*#UH!6CCJ./HR:DIZ2OI*VEK*6KI:JE+ZLAJR.KHZM)
MJSJK2*LMJR6K*:LRJS2K)*LLJTNK.ZL@JRBKF*_U$9>O!"V=KZBOU;!WLGBR
M<K)SL@*S.[3^M0NV_[4'MA$3#!,PMLVVS[80MPJW@[<5N`ZX#+@"N?ZX!;D5
MN0BY?[IWNGRZ@KI^NGBZ?;IYNH&Z2[QCO&2\5KQ4O$Z\$+Q/O%>\7KQ1O&J\
M:;RMOJ2^K+ZIOJZ^3#]0P37!,L'8PM'"S\*^PM7#P</&P\/#PL/`P\7#Q\._
MP\3#U,.0Q=+%3A74Q:_'KL>RQZW'G,B@R+;(/<I6RH+**,LKRSS,/LP_S$+,
M/<Q!S#O,2<Q#S#G-.,TBS@C.#,X&SA/.!,X@SAW.!<X*SM;.U\XVSS?/(]`B
MT"#0&M`=T!S1(-%WT7_2B])]TIG2A-*)TH72@]*&TI[24],7U)07&=0@U!_4
M(]08U"'4*=0DU";47M5OU6[5=-5RU7/5?=9^UH76?]:$UD37]=?XUP/8]M<H
MV6,8.=G[V`[9_=@?V6$8`]G8-A#96A@-V2?90=ERVWC;@-OC&(7;>]M\.'W;
MD=N(VZK;C=N)VY7;F]N,VY[;?-N&VX3;:-W%W<3=R=W&W4+>1=Y!WD3>IM["
MWD+?2=](WTK?3-]+WQ?@&.`5X%+@5.!3X)K@F^#<X.3@D>&O&;KA43];/\\_
M!6X33!5,%$PC3!,"$4P23(`"\$^;41)4%E075+54]%>Q6GE<_UW\7?M=/U]$
M7YU@,F1,9"MD6F0?90%I+6DG:5EI6FE-:5AI(VLE:RMK_VVN;LMRRG+0<LYR
MS'+8<L9RTG+/<LAR%W:P&<1[0,WI>_)[_'OJ>^M[_7MX?W=_<W^>?WE_HH`#
M@02"!8+.@[^%]HGWB3&+,(O)B\>+'(XHCAJ.'HX;CA^.OY"[D+R0P)`:DN^3
M[)/ID_"3_I,TE6J8E9ALF'*89YA@F&N87IAOF&:81BEBF%V87)AEXU":GYPC
M#YZ<IIPUGCB>-IXZGMR>?*.KHTD0J*.GHRND+*0HI"M$J:2JI*ND^*2QI?"E
M[Z6HJXNKE*N>JX^KB*M^JX&K,*N;JX*KD*N%JW^KJ:O>JPVM^A'/K\NOV*_=
MK].OT*_5K]:OUK"2LI6RR^"-LINRG;*/LIZRIK*6LY*S%K8JMBFV++85MQ*W
M$;<3MXBWB[>*MX>W%[@6N!JX&;D7N9&ZE+J+O)"\C[R&O(.\CKR'O*B\A;RF
MO(*\I[RYOK>^M+ZVOK.^QKX\P4#!.,&1PJ;"VL+:P]C#V</;P]?#%L82QA_&
M6144QAK&$,:SQZ[(P<BPR*_(L<BMR++(Q,@\RS_+8<QFS#S-.\TLSGX6*LX^
MSB_.,LXGSBG.0,[?SM[./,\[SS[/(=!&T#S0-M`XT#70,=$VT2W1,]$OT2[1
M-=&LTJG2IM*H%TS40]1!U$_40M11U*D70-10U$742M1+U(/5@M6!U>#5F-:?
MUIO6FM:9UI;6KM:>U@G8#=A.V4K93=E`V3[92-E"V6+91=E1V<;;T-O`V[?;
MPMN\V\7;W-O;V]+;Q]NVV\G;S-O1V\W;VMNZV]/;SMOVV[W;W=O(VPW<-=QQ
MW6[=;]W6W4S>3]Y4WE/>R=[(W@/?5!D$WU895]]2WU/?;1E6WUS?5=]DX%W@
M7N"BX*/@CAGGX.;@F.&LX:_AKN%9/ZE`*D/'0T%,-TPU3#-,.4PR3/]/`5#X
M3QM4&52_5KQ:OEJ]6GU<1E]'7Z1@(65B989I<@8O:S%K%`CX<O5R^7+R<OIR
M\W(4<_UR#W,.<P%S-W0U=#1T,71Z=7MU-W<K?/M[%GP3?),)$7P/?!M\.'RD
M?PF"!X(+@M.#T8/8@QV&J8;0AA6M`HH%B@&*`(HNCC".+XXQCM*0TY`"E$"5
M0I4[E<Z5F)B/F)28D9AO#KJ8D)B&F)J8C)B3F(>8B)B7F(V8G)B]F#R:69JP
M#M&<NYR^G%V=XIX%H;JC+@'TH[*D^:2WI;:EB:OYJ]FKZ*O4J]NKXJO?J]&K
MZ:OJJQ.M$:WZK_BO]*_[KPZP`K`/L)"RK;*ILDBT6K9/MDZV5;94MDJVU;88
MMXVW';@9N":Y*+DKN7VYH+J:NINZM;RMO+*\E+W)OD[!3\%$P5+!Z<,YQ&D5
M?C/'R-/(QLC#R+05TLAFRG_,@,R$S(7,X\Q-%D'-1,U#S4[.3\Z#%DG.2LY+
MSD/.X,[ESN'.YL[BS@S/0,])T$K05-!,T%705M`[T3W1I-*HTL/2O]+(TL+2
MRM+,TLG2OM+-TL?2Q=)=T[`7;-1KU'#4;=1OU(G4A-2-U8K5CM61U;76L=:O
MUKG6M]:PU@P8%]<8&$_7&=@0V!C8$=@<V!+8=MEQV2`W>ME_V2(W<]FKV1XW
M=]ETV7[9F]F$V7S9*=PKW`[<`-P+W/[;^ML7W/_;#-P/W/48`MP!W/S;2=P&
MW!+<$]QXW5O>8MY?WEW>J][5WM3>T]X'WVS?<-]NWVC?;=]WWVK?SM_LWVG@
M:."FX*G@JN``X0WA^.#\X`KA]^`!X;;AN^&WX;GARN%I/R5!64P'4`E0(E0'
M5@16#V[X5\=:T5I^7`A>2E^8XKE?B&F1:81I<VF):85I,VL3;AUS'W,<<R!S
M&G,;<SETKW3E=3QW-WPZ?+M_#@H0@@V"KX81A]@+#8H,B@N*U(L]CCZ..XY#
MCD".1HX1C]V0WY#JD$J2!I3!F+F8QIBXF+N8R)C%F+^8QYC$F&6:9YK7G-N<
MU)S6G.B>"J&]I;ZE&JP-K`^L&ZP0K!&L$ZP8K2"P'[`CL!VP-[`EL"2P*K`G
ML#.P*+`TL+JR<"Z=LTRT7+9JMEVV9;9CMEZV&;>7MS^Y,[DRN:&ZI;JDNJ*Z
MP;PL%,>\Q+S&O,6\U+S*O%/!\<,AQ&X5M\:2QM3(1,J8S)O,D<R5S)K,DLQ3
MSE?.AA9<SEW.9,[JSNW.0L]#SV308=!@T'W1U-+5TMG2A]29U(S4BM2/U+,7
MB]2"U)O4ZQ?(UL36S-;'UL/6QM;+ULK6R=;-UE/7(=@IV!W8)-@HV$,WL=FR
MV;79UMFOV<K9N-D2Y!'D1=Q'W#3<;MQ"W#'<+MQ6W#C<-]Q+W"W<,]PVW.`X
M2-S<W4(99MYMWF/>9-Y!&6?>V=X+WW[?B]\FX"S@*>!OX&O@;>!NX!SA$>$0
MX23A$N$5X1?AK!EO/ZM`+D/)0Y9&A4R@42M4#5XV:_TZ+P<N![%N2G,W<SQS
M.',Z<SYS27--"'L(@'5_=>-U/W=2?$Y\2GQ+?-5_V(4@AK.&L8:PAA>*V8M)
MCA./[9#KD.Z0"I0+E$J5U9C7F-Z8W)CNF'":L@[9G->>RZ/'H_RD.ZPYK$NL
M0ZQ`K$:L3;!#L$>P2[!5L%*P7[8B$WRV>[:HNJFZWKS7O-V\UKS8O)N]X+[H
MON:^^,/[P[O&63*XQG`5P<?`QZ3,J\Q-S67.9\YJSF;.:<YST(#0;]!QT.32
MYM+GTJ#4I-2BU:?5I-7>UMO66-=<UR_8+MC=V>39V-GGV=K9==F5&'G<@-Q_
MW'S<==Q[W(+<`!F)W'3<?=QZW(;<J-QRW`(9B]R1W+/<@=R"W>'=X]WBW7;>
M=-YRWG7>#M\-WY3?DM^3WY'?C]^5W]#?]]]VX*_@GQDFX27A+>&@X</AUS_,
M17E,>DP54-M:A5QP9'MDI6F?:1=NLFXY<T!S3G,^=.AUYW5F?&%\VG\4@M^#
M&(HYBSJ+,)(RD@Z43)7HF/&8ZYCLF'2:<YKQG$*>/IY!GBR@TJ.[I%BL5ZQ6
MK%JL?1%AL&BP9;!?L&2P7K!;L&>PP[*BLU.T?;8@MZZZK[JPNN>\YKSIO/&^
MZ[[JONF^8\$"Q/[#WL;"Q^;(7<JMS'7.<LYWSO864='HTNW2[M*YU*'4MM2N
MU>C6$A@>US'8,MB1&`[:$MH)V@7:D!@#VA_:#=H,V@3:"MK"W+_<R=RRW,'<
MK]RTW+#<MMRWW+O<L=SPW7C>>MYYWN3>YMZ?WYW?F-^9W_G?,.""X('@L^!_
MX#KA/N%(X89,-E035B)7W5JG8'UD>08<;F5S8'-G<TX(&G;CA322&)12E?R8
M>9IXFG::^ISXG"V@UJ.]I+^DOJ1$K'"L8JQNK&ZP?+!TL'BP<+!YL'&PS+*G
MLZ:SD[8AMYRWG;WTOO.^\,BXS+;,O<QSSH+.A]!6T5G1]M+)U,74Q]3*U,+4
MQ-3RUO#6.]@ZV";:*-HTVBW:U]S2W-;<W-S3W-'<AMT>&>_=[MWHWJS?J=^J
MWZO?^]\SX(C@MN"WX-#@S^!/X5GA3.$85N!::7-S?')\Z(7[D!R4"9D*F0B9
M?9I_FF>=>JQ[K-&RR^.=MIVW_+S[O/V\];[VO@_''<?'S,',O\Q4S7_.]<Z*
MT(S07-%ET\_4T-2XU?K69M=`VD':<C?WW//<[]STW.W<\MSQW/G<M-_\W[S@
M7N%;X5_A7>'/X<[A.E3A6A5>%%YX?'E\YG^XAB**_I#;HP:ER*6)K(:PK;.9
MMMBV([<CN+6Z^;X'Q!['^\ARRG/*A\Y)SUW1^-(#UT[:3=I0VE7:"=T'W0S=
M`]T&W0O="MV)W;O?_]\VX(O@9N%IX6?APN'2X>):*`2(9%MN=G-]?*:`6HX7
MF=RCCZR4L)6PMKH$O>["BL[YS@?7']<JUT787-I;VF':7=H8W1_=@]X6WQ3?
MO]_`WW/AP.$74(ED'I0?E%25&)D%G96LF+";L%FT"+T!O\[,^LZ^U4?8:MII
MVFC:9]HEW2C=Q-\WX(W@C."1&2#C(IF"FMFR.,?[SN'4<M=(V&S:<-HQW3#=
M>>$CF?BC=-=SVC3=A]ZRWL+@?>'E6HS.=]IUVCC=.MV#X8'A@'R9K(<12L]*
MV#S=R.$$D:^SB>'ZW6'1/]V3K,G?WK*1SH[AC>&8K,6DI>$`````````````
M`#0````U````-@```#<````X````.0```#H````[````/````#T````^````
M/P```$````!!````0@```$,```!$````10```$8```!'````2````$D```!*
M````2P```%$```!3````50```%H```!;````70```%X```!A````90```&@`
M``!N````<@```',```!X````>@```'\```"`````@0```((```"(````B0``
M`(H```"-````CP```)(```"7````_P`````"```!`@```@(```,"```$`@``
M!0(```8"```'`@``"`(```D"```*`@``"P(```P"```-`@``#@(```\"```1
M`@``$@(``!,"```4`@``%0(``!8"```7`@``&`(``!D"```:`@``&P(``!P"
M```=`@``'@(``!\"```@`@``(0(``"("```C`@``)`(``"4"```F`@``)P(`
M`"@"```I`@``*@(``"L"```L`@``+0(``"X"```O`@``,`(``#$"```R`@``
M,P(``#0"```U`@``-@(``#@"```Y`@``.@(``#L"```\`@``/0(``#X"```_
M`@``00(``$("``!#`@``1`(``$4"``!&`@``1P(``$@"``!)`@``2@(``$L"
M``!,`@``30(``$X"``!/`@``4`(``%$"``!2`@``4P(``%0"``!5`@``5@(`
M`%<"``!8`@``60(``%H"``!;`@``7@(``%\"``!@`@``8@(``&,"``!D`@``
M90(``&8"``!G`@``:`(``&D"``!J`@``:P(``&P"``!M`@``;@(``'$"``!R
M`@``<P(``'4"``!V`@``=P(``'@"``!Y`@``>@(``'L"``!\`@``?0(``'X"
M``!_`@``@`(``(("``"#`@``A`(``(4"``"&`@``AP(``(@"``")`@``C`(`
M`(T"``".`@``CP(``)`"``"1`@``D@(``),"``"4`@``E0(``)8"``"8`@``
MF@(``)L"``"<`@``G0(``)\"``"@`@``H@(``*,"``"D`@``I0(``/@"``#Y
M`@``^@(```````````````````````+)8C,%`(@ST#//,QXT'S0@-`X\+#QA
M,P0S!3,#,P0``<E],XTSHS2D--LW`#@>R:,Y,CL_`=0]U3TC3BQ5>E4#.`<S
M"#./,YPSU3,2-!,T%#0A-*@TIC1V-P$X/3@4R3XX*3EW.7@YICFI.:PY-#L$
M.'L\$#TO.=<]'#X?/AH^-LD>/IX^FCZ@0Z%#TD?31[E+'4U53?].YU$J!!%2
M$U(24J]3L5.0R2U5>U6=59I5IP2?5:!5G%6]5OH$JE=L8I%B=&UJ=2G*!89K
MCVJ/X#,2,P``?S.@,YDSE3.>,]\SWC.O-*TTL#3?-T,X03A(.'4X&LDR.7LY
M>3FS.=L`ISZR.;`YM#DIR<T[SCLKR1`\@#S3/#`]F#,O/3$]VCW9/2<^*#XA
M/B4^ICZB/J$^I#XYR:H^I3ZC/F0S/T1$1!M'4T>$1X9'U4=@R3Y+0$O*3<E-
M)DX`3S%//$\P3S-/,D\X3S124U)44K13LE,O5:55IU6D5:A5J56B5:-5IE6!
M5H!6K5<D7&5<:%QI7#QC.V-=941J@G'Q=&MU&W?K>+I[TWL3?2*)])</JQ"K
M!S@+P0K!&3,:,Q@S9C.",Z@SY3/G,^0S%30C-"0T0S3#-+PTNS0X`+<TN33/
M-`W)>C=[-^$WX#<).$TX%LE+.'DXL3@V.34Y-SDX.7\Y@#F!.5.6?CG-.;\Y
MOCG".;@YP3DP(#$\+SQO/((\.@&'/(8\C3R4/-<\U#S8/!8]%#TN/38]-SWN
M4>`]Y3W?/2L^*3XM/B\^MS[)/L$^RCZR/JP^KCZR0ZA#L$.G0U')4D1*1%9'
M54=?1UY'B$==R=U'XD?A1]]'X$>O2+%(NDA%2T-+O4O(2VS)ODN_2W3)64TI
M3BQ.+TXM3BY.!$\"3P%/0$]*3S]/3T]!3TY/ZU'L4:PS6U)C4EI265+<4]M3
MV5/@4]U3(#.P5;%5LE6V55%64E905H16R02#5L-7N%>Y5[)7D%LF7"E<;EQ`
M8SYC06->9;MEO&6Y9>_)@&E/"$5JNFJ]:E9M56UU;7=M@6WZR8-MBVV$;89Q
M@W&+<6UU%G8H=^IXU'L#?!5]/7\^?Q:$3,H&ADV'(H]SCVV/;H^QD4XX+9/-
M#_F54I8`F/R7^I>2$/>7^)>0RL3*)Z81JZXS4*U/K4VM<:_BRG*O&+5$/2$S
M9S.O,[`S*3,7-"(T`\DE,R@T_S39--LTWC3R-/XT]#3=-$4`!,D!-=PT?3>!
M-WXW?S?E-P\XM0`*.+8`"SA1.%(X4#BX.#TY/CD\.8<YUSG;.<\YX#E,.T([
MU#L1/!0\%3P2/#,\-3PW`7$\,`&1/),\E3S</$(]0#VF@^8]CT0R/C?),3[U
M/LT^WC[5/MH^[C[L/L\^SCX]R<P^\S[!0\1#QD.T0\-#N$.[0[=#O$._0\=#
MOD-@1%U$=D1L1'5$6T1Q1'-$841:1&)$<D1?1%A$'D=81XM'BD?T1_!'TDC-
M2,Y(O$C02$9+1TL^`TT#40/.2\]+S$O+2W+)8$U?35U-U$TZ3CA./$XV3@A/
M?D]>3VY/4T]P3U=/74]C3WI/>4^33X')'5)H4G-2=%)F4F]2=5)Z4G!2;5)E
M4HI3[5/I4^-3[U-S!.I3,561R3A5()@U53I5@56`5;A5P56Z58A6SU;*5L=6
MQ5;(5M!6R5:[5[97O5>=R;17P5?15])7S%?45\M7SE?55]A7E5N36YE;EEN^
M!8E<E%R17(]<A%R77(9<A5R,7/)@[6#O8-EB1F-'8TMC4&-*8TYC3&-(8V-E
M865B96!EPV7%9<%ET&7<R8)I'@B&:81I3&I(:KAJOVK!:L9JQ6K':L!JPVKM
M:P-L(FPA;)]MD&V>;<@(H&V4;95MH6W#",<(FG&0<?)T\W1N=:MUJ74:=AAV
M&W9@=TQW0G<S=S]W/G<X=T-W1G<V=^YX]7CT>%8+&WQ``2M]*7TJ?2Y]/X#F
M@*>#J(,8A`B&4(=3AU:*58IOCW^/LY$ZDSB3-Y,VDU0X@,K=E?R5^I4SE@28
M!Y@(F`:8"9B1RI/*'IW2R@NM0ZU2K5BM7JUHKXVO@J][KUBSO14`R2PS+C,+
M2"TS:3.R,[8SJ3/M,QDT3S06-0,U#C4$-0<U$#4G-2@U#34I-0\U(C41-84W
MA#>#-XHWAC<0.%@X6C@,.L0XQ3A'.4DY2CE+.;M3C3F+.0<Z!CH@R>\Y\#GM
M.?DY`CKG.?0Y]SGQ.5,[53L:`=H[V3LL`3@\F3RB/)P\FCR;/.4\XSSA/.`\
MXCSD//TRZ#POR1,]5CU+/4H]33U,/4D!ZCWI/>L][#TZ/CP^.3X[/A0_#C\U
M/PH_/S\X/WP!3C\7/S_)'C^V0\Y#RD/+0\Q#R4.T1*Q$B$2&1(Q$DT2*1*1$
MAT2E1*9$A42C1(Y$'T=C1XU'^D?[1PE(_D?_1P)(!$C]1P5(^4CW2-M(VDA1
M2U!+5TOB2]A+VDO<2R!-'TUI3=U-0$Y!3D-.#4\,3X=/J4^23X5/OP.,3Z)/
MCT^*3[H#C4_Q43=2BU*'4H)2CE.\4_A3^E/K4_E3_%,%5!M5'54>59+)/%4^
M5815R%7)5=-5QU725556ELF,5HI6U5;35M@$V%;05^Y7\5?[5]-7[%?-5Q58
M)E@.6"=8*E@`6`18*%@(6!18FUNR!:%;G5N@6YY;HEN<6S)<-%R37)9<D%RT
M7+5<MLFV7,)<M<FZ7))<^V`%8?-@_F#]8%UU^F!#8I5BE&+$!F]C<V-<8UMC
M9F-T8V-C9V-@8V)C<6-R8UYC(V4F961EULGR90%FW67<9=ME\V7]9=AE^&7[
M98-IC&F.:4EJ5&I2:DYJ6&I1:E5J4VI7:E!J3VI-:M)JTVK):M1J[VOXR;$S
M!6P$;"YL+6Q%;5MM6FU9;9UMCFV\;=UMNFW]R=AMRVW9;=IMQ&VX;;]MVVW!
M;?S)Q6T9RK%QKW$8RO=T]G3X=%!U475Q=7!UL'6O=:YUK74E=BQV(G8S=C1V
M*PHZ=T!W:'=A"F1W7'=7=U-W3W=1=U1W9G?=([(*#7D(>2O*^GCJ>BI[NWO5
M>]=[I$_P,[4S!GPH?")\(7Q65B-\S4,P?31]R7_*?\A_/<I$@/.`0<KX@/R`
M]H#[@/>``($"@4#*3<HDA`V&*0UBAS")*XDJB9(-+8G:BBB,AHUWCWR/4)!.
MD/*0LI'.D<^1Y9$'9C62,9(3DRN3+)-%DV"309-8DT>36Y-0DX+*7Y-*DU:3
M0Y-$DU&3_94TEC665)95E@R7"Y<*E_F7-9@DF!.8')AIF"68(9B5RI;*F,H@
MG:F?J)_>GPF@"J`+H..A!Z*RHK.B7:-8J(:HAZBYJ;BI#*U$K6:M@*UUK6VM
M?JUGK8&M=ZVHKZ*OI:^;KU>S#[4RM2RU,[7GN&XSMS/V,_(S\S,7.#`T5#13
M-%(U/34\-30U,S54-2\U6`!5-3\U-S56-6$U6#4&R3LU,C4N-3XU.S.,-XTW
M$S@6.!(X6SB*.-<XSCA0.5$Y3SF..8\Y\CDAR2@Z&CHE.ATZ%#H@.A\Z&SH7
M.A4Z'#H3.B7)8#L<`68[XSO>.^`[X3L:/!L\&#P</!D\0CQ`/#X\1#QT/$,\
M+<GR/!L]&3T>/3#)7CUF/5T]6CU?/6`]6SU</5D]\#WQ/4,^0#Y"/D$^/SY7
M/VD_;S^K/W$_DS]6/Y`_;3]L/W`_9C]G/]=#M4/;0]A#U4/40[I$MT2^1+E$
M-P+@1-U$WD08>=A$O43;1!U')4<A20Q)*4DM21M)#DD?201)'$D%209)($D-
M22I)(TD125Q+9DM;2T]+7DM=2_%+ZDOT2^M+\$OZ2_M+*$TL36M-*DUJ36]-
MVTW@3=%_XTWE3>=-34Y53E1.4TY23DY.8$[`4P]/$4\33\9/LT_'3])/N$^L
M3ZY/ST_%3WO)S$^K3\E/N4_[4?A1]U'Y42!2.U(Y4IY2FE*J4JM2KU*64JE2
MIE*14D,$KE*?4JQ2H%*24Y%3OU,75`I4#%1*5495-%5%54-51%63R8=5AE6*
M5=I5V%6T!!@X-#365=155%995EI65U;@!-U6Z5;@5@58$E@36`=8%E@C6`)8
MH<E*6#980%A66$-8H,E+6$98/EA)6*=;MENF6ZA;K%NI6ZM;.%PW7#E<05P^
M7,!<NUR_7+U<_EP>7>Y<_%RWR?E<!EWD7.E<Y5P#7?U<25V^8`IA)H8880UA
M#V$.82!A<6*98N)BWV+>8GAC>6/D!GQC?6.$8XMCBF/2R8EC+&4I96QE!"$)
M9@AF#&8-9A!F)@B?:9AIHFF::=5JXFKP:NIJZVKM:NAJX&J%:X9K\&M&4$5L
M.&P^;$)L0&Q';5QM7FVT;<)M%&[E;15N$6[_R>YMYVWU;?1MZ&T!;N]M\6T`
MRMMQOW':<<=QW7$:RNMQX7'!<;UQ!W7]=`%U"G4#=7)U='5U=;)UL76T=4QV
M0G9`=DEV/'9-=DIV.W9A=W1W)LI_=WIWB'=\=V\*<'</>2AY$WDJ>>UZ[WHN
M>\%[W7M'/BU\*WPU?"]\,7PT?#7*,'PZ?3E]-WU+?51]37U1?4=])W]0?TU_
M3G]4?])_SG]+@$F`!8$/@1F!0\H&@0R!*8$$@0B!)8$<#`.!)X$0@0J!0LI=
MF*J#JX.I@T&$.H0\A"N$2805A@`-%H93RC&&2FT\AWR';8=JAV.':X=[AV2'
M>H=IAV^'-XDUB3R)-HD]B3Z)X8K@BBV,*XR-C9*-M@Z.C6O*D8V6C7N/>(^!
MCY:/HX^5CY>/5)!2D/60`)'[D/20]I#HD>J1/I,]DSN3@)/D#XB3@9."D\Z3
M@Y-WDWF3<Y-MDW"3C9-UDXR3:I.1DXF3CI/<1/^569;'EA*7%)<3E\N70IBM
M$#V8_RI`F$288IA#F#^819@\F)?*1IA'F+/*GIR=G"R=*9TOG2Z=,)WAG^*?
M#J`9H!*@M*+:I2:G6:A:J(BHP*FZJ:"KW<JBJX:M["^=K8BMCZV.K9NMP:_#
MK\2OEJ_'K\:OOZ_#%`^R5;5"M4:U2[5#M5.U2+5)M4JU3K7>>Y$Y2[N`O8&]
M@[V*-8*]0E4B/'`S<3.\,QA/OC.Z,_@S-S0U-/P]5C19-%XT;361-9(U:#5F
M-7,U9P"6-8LUC#66-^XW'#@:.!DX&SA=.%XX&,G<..(X4CF2.3`Z4CI".D$Z
M13HW.D`Z/SH].C@Z.CI).FL[>#MY.R;);#OI.^8[Y3OJ.^<[Z#L?/$L\2CQ3
M/'8\HSRD//8\\SSY//<\_#P=/6T]<3UL/6X]<#UO/6<]:#WZ/?D]3C[>&4T^
M3SY*/DP^E@%"R>X_LC_`/\$_]#_(/\4_QC^M/^)#ZD/C0^%#]T0!11)%]D3Q
M1!]%[D12R?-$%44611=%^$091?)$]$3U1!-%!D4F1R1'6D?(8)='E4>:1Q](
M^STI2"!(8LECR4Q),$DX23U)44E/24I)-$DV23`;:DMH2QQ,#DP>3%D#"4P(
M3!-,`4P/3!1,!DP'3+(<<\EV`WE-ZDWM3>E-[DUH3F1.9TYR3F).=$YY3AE/
M%T\53Q9/YD^DC^Y/T@/?3^1/VD_J3^U/XT_I3_U15SDA4L92N%++4H7)O5*U
M4KM2OU*^4K)2P5+"4IE3QE,L5"U4)50>5!]4(U1054Y535525>E5[%7H55A6
M7%9;5H]6<FKV5@!7_%;X5NI6_E;W5OU6<%AB6$18(`5-6$Q8/UAF6#58*04T
M6(U8A%@X!898B5B'6(-8=5AY6*]8L%BW6[M;N5M&7$=<15SJ7/9<:%TY7;G)
M/5T[74U=,%U*73Y=0%U,74==.%U273I=4UW$8,%@'&$=82IA'F$O82)A+F$E
M88D&L`9*8DMB=F*_!NAB[V+I8L4&ZF+,R>H&FV.>8Y-CIV.<8Z!CFF.K8[YC
MJ6,M96YE1&8]9CIF:&8\9FIFX,DX9F5F.69M9C9FX\D^9GYF-V:9::EIK6FG
M::AI9FII:FUJ9VIK:FIJ[FH!:P-K]&K[:C<(]FK\:O1K"&P*;`EL;6QB;$%L
M7FQ<;/-M)F[D"#EN!,IL;BMN+FX[;EYN^VXG;B1N:6XP;@7*8FXX;C5N*FXL
M;FAN,6XO;BUN.FXV;@/*(6X\;B!N9&X^;N@(]W$2<O%Q]7$B<O)QWW$5<A9R
M>G5V=;YU(`J]=0EV"'97=J-WOW>X=Z]WG'>E=W)W=7>==YEWN7=.>3EY.WDU
M>3QY57GP>O-Z]'H[>SQ[.GLV>P=\ZS]5?%!\3WQ2?%9\O3,R?&-]:WUF?5=]
M77V&"VU]87UI?5I]7'UB?2I_*7]8?UI_UW_;?]Q_W7_8?U2`6X!<@%.`3X!6
M@%"`6H!K@#:!4X$Z@3R!/H%)@4"!1LI'RF2#98.U@[:#LH-(A$J$<H1IA%J$
M3(0LAC"&2X9)AD*&1(9*AD^&DH=7RI>'@(>"AX:'4XE>B5*)6XE.B6V*;HKZ
MBO:*^XHSC#V,-XP^C#6,FHVKC::-L(V9C:"-GHVHC:&-JHVMC;N-G(VEC;,S
M)X^-CXZ/CX^2CU8/D8^MCU>06)!>D%V07)!;D&</"I$#D0Z1N)%-DC^21Y)+
MDDJ2/9(X*$&23)*!*&*3:9-AD]$/JI.FDZR3O9.[DZ23NI.:D^L/H9/!D^"5
M"I8#E@:6.98ZEC:66Y9?EEZ69Y9AEF*679;*ELR6SI88EQV7'Y<@EQ>7%9<?
MF">8)I@04(N8KIB*F)G*DIB)F(>8MA"/F(28@YB,F).8C9B8F'V8?IC2F("8
MF9BLG%"=59U"G3^=/)VC$4R=29U7G5B=3YU<G4>=M\JKGQ`2KY^MG^B?YY\P
MH":@+Z`HH"N@':`MH""@*J`LH#6@(:`CH"2@-J`WH.FANJ*XHLS*;:-JHVBC
M::-KHV&CW*7;I2VF+*:BIBNG,J?7RI2HDJB0J,FIQ*G!J<.IS:D4JZ>KKZNJ
MJPVM5*U;K6&MKJVSK<"MQ*V_K<NMK:VGK:2MO:VOK;*MI:WGK^"OSJ_>K]6O
MWZ_9K_*P([)`LAL5/K*'%<^S5#Y;M5BU8K5?M6>U8[5>M6"UA;:&MH>VZ+CF
MN'&]A;T"RX:]$+[X/+\S83[^,_PS.31A-&`TXC7J->,UM#6N-;XUN#6H-:HU
MJ36S-=4UK36Y-;LUL37"-0C)ZS6Z-=(UU#7Q-QTX$LEB.(PXYCCG.%HY6#E9
M.98YESEA.F<Z<3IE.GTZ?CI].X0[?#M^.W\[@#OO._0['CQ.//L\^CS]/#')
M,LEY/7P]?3V$/7L]>#U7`5X^6CY</ED^53YC/E8^7SY@/EL^2D!E0+-`+$!W
M0#U`4D!A0"I`/D`T0"E`LD"M0$!`4T!$R3]`04!R0/9#]4/T0_)#^4,G151%
M544N153)4\DL13A%.44Q14]%<T4P12M%444L1UM'7$=H1VQ':T=I1Y]'.$@\
M2#I(-4B=`CE(-D@[2&!)84EC261)E$F325Y):$EJ265)9LF025])<DEER3Q,
M)TPD3"9,)4Q?`RA,-DPQ33!--$V!37U-@DV`37D#TS7R369.C$Y[3H-.F`..
M3GI.DDZ13H).&T\<3R=0(5#<`RL=0U#?`QA0>U`:4$M02E!-4$]0&5`U4!-0
M4E`44!Y0+%`@4")0$E`?4`!2(U)`4D-2Y%+;4NI2W5+,4ME2Z%+V4N-2TU+:
M4M92YU(Z5#]40%1(5%E4-U1$5(S)B\E55#E45%5555955U5855E5C57R5?A5
M]57V5?Q5_E7Q5?U57E:65I=6G%:;5I56FLD:5PE7!%<.5QQ7&%<-5Q!7#%<#
M5WM8IEAW6(A8=%C:6'98>%B*6(]8?5B06.U8V5C06!I9UUCB6.%8Q5C@6,I8
M)5G,6+/)QEO!6TU<2UUD795=F5V\R91=HEVN79Y=IUV&7?T%I%V179-=N\F(
M7<U@RF`_84!A1F%!845A6&$[84AA3F)28D]B>V)Z8J!BGV+[8O=BN&.Y8[MC
MMV/T!KIC[P;:8[5COV.\8\!CT\G9R75E>65V935F0&;`9H%FK6:O9JQFCV:H
M9JIFJ6:(9G]F@&:\9JYINVF]:3$(>&IT:@QK$6L(:P9K$&N/:Y!KC6N.:Y9K
ME6L+;`QL?&QS;'5L=FQ];'AL<6Q+;4YM,VXR;@,)D6[G;NENHFZ4;H=NHV[=
M;GMN@VZ!;M]N?&[D;N)NDVY];K]NFVZ.;I]N"0F,;G]NG&Z$;D)NYFY1<DIR
M9'(E<B]R+G(K<BAR,G(M<C%R.7(L<F%R$740=1)U4W55=7MU@75]=7QUPG7%
M=2+*Q'4CRFMV:'8^"EQV779J=B3*=GQV=W<*Q'?+=\AWU'?5=\EWUW=["GAY
M6GE;>5QY5GE8>7%YU)9`>S/*/WM#>T%[XGO@>^-[9GQS?&Q\<7QJ?&U\;GQK
M?(Q]=WTZRG]]B7UZ?85]>'V*?89]+']G?UM_Y7_A?V&`:8!J@&6!;8%C@8:!
M7(%B@4C*>8%I@7"!=H%=@8>!;H%Q@7R!<X%;@6N!OX/!@[V#R8.\@\*#P(.2
MA*F$CX1VA'N$=82DA&2&/8>OASH-6,J=AYF'L8=CB6*)9(EIB:`-=8ISBG&*
M=(H,BQ:+Y0T1BQ^+&HL-BQN+$XM.C%6,4(Q]#M*-TXW1C?&-W(W(C<R-T(W/
MC=^-*X\NCRV/G8^>CY^/J8^@CYB/H8^KCZ^/;I!?D%J0;0]ED&B0<I`7D1:1
M&)$9D1J1(I$;D1R1OI'ND5J24))8DE225Y)6DA63FY.3DY*3<I.8DYF3WY/X
M#]636"G4D_.3])/GD^&3YI/KD^R3VS50$`V6#)8O36B6999KEFF6T9;3EB>7
M*)=H$&<0))?7E\J8QYB>RMB8X9C&F/B8PYCTF!>9ZIC+F(:8Q)C9F!F9PICB
MF,\0WICMF)S*S1`=F=V8VYCHF.F8OYC@F-&8W)C.F!Z9S)CRF/.8G\JBRJ/*
MH<JKG*J<IYRIG(B==9U@G6R=<YVK$6Z==)UVG6B==YV&G>J?4:!0H%B@3:!/
MH$Z@7*!2H$2@2J!+H.JA$*(1HLVBOZ+$HM"BSJ+`HL*BSZ+)HKNBEZ.2HV^C
M?J.:H\$2AJ-SHR0M=Z./HW"C@:."HYFC?:-_HWNCAZ.RI2^F-*8NIC*F1Q.J
MIE<3J:8XIS:G-Z='IS.G.:<UIT2GI:BFJ)ZHXZG?J=.I\:GDJ>"IUJG#+N:I
MV*G>J=NIW*D;JQ^K':L<JQZK(*LAJTX4MJN\J\:KQZNZJ[ZKO:NUJ[2K#ZUB
MK>NMV:WDK=>MV*W6K<ZMW:WGK=*MQ:W)K=NMDJ^*KXNOB:\(L`.P!K`%L/6O
M"[#[K_RP`;$"L?JP"+'WL`"Q_[`&L?:P^[`*L26R0[)$LF2S8K->LUNSUK-R
M,\(S=[6"M7RU?;6&M8&UA+5VM8.U?[5^M8BVC;:+MI&VC[9\MWFW>K?JN$R[
MF;S1-8N]C;V*O8Z]$;Y65!7+=#/#,\0S&S1?-&HT:31K-`PV]C7M-2DV_C7Q
M-1<V_S7N-?TU'#;\-0`V(#9W`/DU9S8(-IXW\S<E."<X'SAE.&,XE#B7./$X
M7SEB.?(88#DBR8PZ@CJ0.HLZC3J!.ITZCCN/.Y([(SQ2/"[)`#T!/0(]'SV,
M/8D]BSV(/8T]CSV%D``^!3X!/F@^;CYG/G4^MAI%R==`1LE(,]1`V$!'R4C)
MND!)R=M`OT`U0;Q`V4#$`=U``$'50#!!O4#<0/U#_D,'1!=U;T5I17!%9T6I
M195%D$5L19=%<452`G1%;46.12]'&\:I1TY(7\E:2$A(54A,2$E(3TA*2-9)
MH$FI26?)G4G42:1)J$FF2>9)?4MW2WI+04Q)3%E,14Q(3$!,CDV539!-]TWX
M3?9-^TV>3IU.F4YWR:-.J4Z83J!.EDZ43I5.GTZA3B%/'4\?3VU0?,F:4))0
M>E!]4*%0G5"94&M0;E!]R452A,G[4NM2\E+Y4H;)^%+M4@%3]U(&4YM3RE-K
M!,,>:U1L5'149U1;5&!4=E1C5&%4*%5;55Y58%5=55Q5]%4`5@A6!U8!5@56
M9%9C5IY6H%:A5I]6)E<M5RA7'5?L6.-8ZU@66<A8&Y/I6.18)%G16$$%W5C"
M6,M8QUCG6%`%ZEA+6:7)8%E]63Y9I,E264Y9/%DR63!9(UG*6\M;R5O(6\U;
MF%V@79]=G%VC79==OLGQ70E>`U[J745>[5T%7AI>%5X!7NQ=#EX77D)>$EX0
M7N]=_UT`7@Q>#UX$7@A>%%Y#7KW)&UX17A->SV#.8&]A;F%Z87!A9&%>86QA
MR<E;86%A96%_8H!B?&*G8J9BH6+`!JABHV*B8JUBI6(!8_]B_&(`8S5C[F/O
M8_9CZ&/J8^-C'V3\!N1C^F/Q8_MCU,D]93QE>0!X97=E"Q#19L=FWV;09N!F
MUF;89A9G#F?99@]G$6?-9HEFSF849]IF$F?39L)FX6;I9NIFWF859]EIUFG-
M:=!ITVGPR8)JA6I_:GUJ@6J#:H1JH*TH:P]K%VL::R5K]\F;:YEKDFR,;)5L
MC6RC;)-LD6S;;IENFFX(;TQO#6\!;TYO`F]-;R%O_&X)RHIN",J5;A%O$F]&
M;QQO26\,;QX)$V\6;_UN#V\?;S!R;G)K<IMR>W)C<I=R;7*<<IAR;W)G<FER
M%75C=89UBG6'=8AUA76)=<IUQW7+=<QUR74-=H-VA'9X=H)V<W9Y=HQVT'?/
M=])WV7?,=^MW_7?L=^AW^'?Z=R?*A0KA=_MWYW@NRJ5YD7FF>7QYDGFB>:!Y
M_'K^>E=[4WM8>^=[CGPXRH-\BWR$?)<+HGVW?:E]I7V??:I]EWVA?9Y]JWV9
M?:-],'\R?R]_<']L?V]_Z'_N?^I_;8!V@'"`<8!L@.N!M8&6@9"!C8%)RJ*!
ML(&2@:"!DX'#@8Z!MH&=@96!LX&D@7"#U(.3#,^#<#24A&$EP(2TA,&$L@R]
MA*^$=X9XAFN&;89NAG*&;X9QAJMBC(8_A[:'MX<&)KN'N(><.KF'`2:+B7J)
MA(F(B9&)>8F.B8")@HE\B:0-A(I_BO(-.XMQBSV+,(OQ#3Z+.(M>C&2,@0Y=
MC&V,3XQBC%^,[(WRC?2-]XWVC0>.[8WJC?"-^(WSC=P.<LHQCR^/MH^NCZJ/
MOX_,C\>/@YF`D'N0?Y!]D(.0>,I&D2V1)9$FD2R1-Y$QD3.1,I$GD2J1+I$O
MD<"1<9)ADF*29I(8D\63PY/$D\*3KI,0E`B4'Y0ZE#N4-I0,E`:4*I17E%"4
M()2%RBR4(90+E!F4-908E`^4$Y15E#F4&I0,$!>4Y)7IE8MU$)82EC^6;I88
M=8S*UI;5EM>6`CYM$#&7,)<ZEX68:YA(F4N9-YE[F6R9A9EEF3:9AIDTF6B9
M6IE8F7*9:IG3F#R9,YD[F4V93YE\F;"96YE5F629:YE3F>805YE>F6V9-9EI
MF5F99IE0F5&97)E=FH>9>)E)F4Z9\9ASF8B9SYBDRK&<LYR<G:2=D)VXG:"=
MG9VHG:F=N<JQG9.=FYVBG:&=L)VGG;.?22NTG_&?[9_LGVB@=:!JH&*@9Z!@
MH'>@7Z!YH".B(:(<HIDL'Z(>HM:BTZ+9HM>BU*+<HMBBHZ/1$KZCJ:.AHZ"C
MJZ.BH[JCPJ.<H[NCJJ.LHZ6CP:,L$^*E-J8]ICJF859(ICRFMZ:LIK.FMJ:R
MIFX37:=)ITZG3Z=-IURG7:B[J,ZHOZBZJ,.HY1,&JOBI_JD3JO:IYA,TJRVK
M*JLUJRRKU*O:J].KTJO.J\^KGQ3]K0NN_JWXK?>M%Z[ZK?FM`*[UK?&M`ZX%
MKARNK*^:KZVOH*\;L"6P)+`FL">P*+`JL!JP+K`5L!6Q%+$7L1BQ#[$3L0NQ
M(K%Z12:R'S!1LDVR3K)*LDNR3+)0LF*R3[)2LFBS:;/EL_"SX;/BL_+*I;6I
MM:2UK[6LM:ZUJK65MIFVD[:=MIBVG+:7M@T6B;>'M]>X[;CQN/"X!;D#N02Y
M7[E7NYR\H;R:O(^]D[V>O:.]F+V9O96];KYJOO2_][]YP8_#D<,+Q`+(A#,$
M-(`T+S8_-CLV8C9$-C,V7S8K-@G).38V-D@V-39L-E@V.C:H-_0W*3B:.``Y
MNSJ].K<ZLCKX`*@ZJSJF.KPZESN6._@[$QE1/#,!M3RT/+8\/`&W/`4](SV5
M/9@]3P&4/9,]!SYS/G$^<CYX/E]!:D%G06M!:4&.04E!@$'<`41!CT%%04S)
M3T%C039!2$%<09-!84%@04Y!7D$_0:1!X!IH00M$$40-1`Y$PD57R;!%PT7(
M165%UT6]1;A%MD7'1;Q%L46O15O)-4<P1UU'=CYO1[!'7LFT1UQ(74@(2NY)
M"TKR2?U)\4D02FC)%$J+2XQ+A4MZ3&Q,8$QG3&9,:DQ?3&U,:$QD3#I-.TTY
M30).!$X#3K1.LTZ[3JQ.MDZQ3J].M4Z^3K).)$^V4+E0K%"P4-=0NU#^4,M0
M?\GU`[-0OE#-4+Q0NE#'4!93&U,74Q53GU..R8)4@U2.5&I4B5245(94D%1B
M59!5#%8/5L,$I5:G5J96I%8U5SA7-E=#5T=7-U=#6:)945ER66U9+UE466Y9
M55DW64]94%DY'YY9J,FS6:=9<07Y69%9I\FV6=U9F5G?6]5;]7<H7D!><5Z8
M7I5>95YX7G]>8%Y\7I9>:EYY7G-><EY[7G!>U6#78(]AB6&>88=AH&&-88AA
M?V&,89-A66*PO+%B](&O8K)B"&,*8S9C-V//R0$'-F0I9$ID)F0H9"1D*F1(
M9$1EA&6,9<1FW&:'9U-G?V<Q9U%G2V=29X!GI6>!9T-G-&<V9S)G2&=)9SQG
M36=*9^;)BF=&9SYG@V=09[1G\&GD:>-IY6GF:>=IX6GO:>AIW6D#:HAJ)FL6
M:SMK+VLY:S1K],DU:S%K.&N!/JIKHVND:Z!KH6NI:Z5KKVRQ;*MLKFRP;+-L
MK&RI;+)LJ&RT;,)L3VUF;1YO%6\0;W]O?F]@;\QOLF]B;XUOCF]W;WQOCV]=
M;VUO8V^O;Y!O?6]Z;P9O"\IH;[1O>&^Q;]<B#,I!">ARZ7+`<M<)ZG*W<KIR
MM7(=RK1RO'+&<KARO7+"<DUS\'+'<L%RPW+Q<NQRX@D<=2!U6'5E=61UC'6-
M==EUX'40=I1VDG:6=I5VOW:@=D4*]'?V=]QW/206>!5X''@/>"QX%'@E>!=X
M$G@>>(!YJ'FO>=9YXGFT>;-YL'FR>:%Y8'MF>V%[3GM=>V-[YGOO>^Q[F'RG
M?)1\E7R1?)U\F7R;?)Q\'7T<?=!]X'W+?=M]VGW"?=-]Y7U]?WM__W_R"_E_
M=X!\@'B`>X!Z@-*!RX')@<Z!Y('*@="!I6%)#-F![H'=@0""X8'>@^*#VH/.
MA$_*SX3:A-&$U(3MA,N$U83QA)R&B(9!A]"']X?/A]&'VX?>A_B'W(?9AZ")
MLHFAB:J)J8FI#::)G(FUB:>)CHJ0BI&*A8M;BW"+9(MGBV.+=XMHBV6+:HMX
MBV:+B(R>C'2,>HQYC(N,?XP3CAZ.%XX:CB*.0XX9CA^.)XX2CB2.)8Y>-C6/
M-(_1C\2/RH_&C\N/S8_BCXF0BY"&D(B0C9`[D3R1/9'UD7F2=9*"DG^2A9)V
MDGR2?I)[DH"2>I)(5\L/'9/VD_>3^9-CE&R4;I04E`T09Y1OE&F4=I25E'&4
M891XE&N4A92$E!26=I:VB766=);BEC^71)<]ET>72)?;E]R7W9?EF.:8PIDN
MFAV:^)GPF?:9Q9G&F?R94IHOFA":\YG2F>J9W)D;FON9PYD6F@>:R9G8F3":
M$YHQFOJ9\IGCFM69`9KQF1R:UID(F@N:%YH@FLJ9,IH%FN29SIDSF@*:&9H>
MFM.9]YGHF1^:])G8FK^<OIR]G-R=W9VKG<F=R)W?G=F=VYW,G>"=[YWSG:Z=
M`9ZWG[F?MI^XG_:?\Y_UG_*?D:"=H)N@DJ"-H)Z@C*`Q$L?*E:#&RHJ@CJ"<
MH.^A+:)2HC6B**(NHN6BZJ/QH^NCV*/0H_.CVZ/.H]42VJ/7H^&C\J/(H]FC
MWJ/1H^>CSZ.WI4>F0J9#IM/*PZ;!IL>F9*=JIV:G4*=NIV6G[&E_I]7*FJ=I
MIW*G;Z=]IW"G8*C"J.>HT:CKJ-2HW*C;J#>J):H?JAZJ(:H;JA>J(JHJJAJJ
M+:HCJB:J-JK_J3JK0*M"JSBK.ZL\JT.KZ*M6%/FKZZOQJ^FK[*L5K4>M1JU%
MK22N5JXAKB>N3:XQKAZN+*Y/KBNN4ZY1KE2N*:Y0KA^N,JXJKAVN**XNKBVN
MO*^[K[VOY,I'L$&PY<I)L/04+K$GL6JR>[)SLG6R:;)YLG*R=K-WLW2S<[,"
MM/ZS`;3YL_2ST[75M=BUP[7*M="UR[7.M<6UYK7$M<"UU+7HM7:VHK:NMJBV
MH[:GMI:VJ;:EMJ^VI+:KMJJVIK:@MIBWV[CVN/6X#+D*N74Q:+ECN6:Y6!9D
MN6JY:;F5N@*[:KM>NVB[:;MEN_[*I[RNO*B\L[R<O:F]MKVSO;*]`\NXO<"]
MO[VZO:B]/+YROG&^=;YSOA>_%;\6OQN_^K_YORS!A<&"P7_!?<&(P?-R3L)0
MPI/#E\.8PYO#G,.6PXO%_<7\Q1?+BVH(-`<T<S:B-J\V@C9[-G0VL#9V-KDV
MGC:Q-J$VLC9N-@O)AP!X-GHV@S::-O@W,3AI.&@XG#@$.9DYQSK&.MPZQ#K8
M.M0ZWSK1.M`ZUCK/.JT[KSNG._T[6SQ:/`<]G3V;/:L]I#V</9X]I3VJ/:8]
M#CY^/GP^[D'50>E!0D'B02-"V4'40>-!%4+O0?!!UD'=0?9!'$+80=M!VD'M
M01%&%4081!I$'T061$W)&41+R?!%"48;1N>E]D7T1;5%$$;R115&\T7X13E'
M.T<V1PY&<D=T1[E'MT>X1W)(:T@=2C=*(DI#2DU*.$I;2GE*&TKS29%+>TR4
M3&_)EDQ_3(],A$Q\3(Y,D$R83(-,@$R33(),_3(]34%-H4V?30I.#4[(3LE.
MQT[-3B5/L5#<4(#)Y5#T4+]0VU#J4/)0^@/Q4.U0YE`"4H+))5,84Q]3(%//
M4YU4F52H5&A59E5G59%5$U855AU6%E895FM6:%9J5FU6:5:J5E=74E=05U]7
M9U=/5_($6U=<5UU7'UJ=6;%9L%F46<-9KUFH6=Q9F%G$6:19JUFJ6:59(5KK
M6>99]UGX6?Q9^EG@6:K)]EFIR>%9[%OB6^1;^5MO7DQKNU[A7@!?V%XO!M9>
MXE[#7K->TE[!R<Y>T%[57KE>NE[/7KU>VV"J8:UAN&&V8;5AKV&T8;=AJ&&Y
M8;YA@F*\8KABMF*Y8L$&$&,G9&ED<&169&MD>F1L9&UDU<G!E(UED&6V9Q!H
M$FBZ9[UG!6C"9P=H]6?IR:]G]&?W9_AG$6CV:?5I^VD!:@!J`FK^:?II_6E`
M"#=K26M+:T9K1VNS:[)KL&NW:Q%LS&S?;--LU6S;;,5LR&S);.)LRFS1;-)L
MW6QL;W-O(7#P;Q]P.W`B<"-PZ&_=;S\)&W#M;P[*\F]&"=QOZ6\=<-IOYF\3
M<Q5S%G,\<PMS'',Z<SUSFG,=<PES"',[<R)U)G4E=21UFS:/=9!UYG7C=>5U
M$78ERJYVOG:T=K-VKW:1=L)VMG:R=E=X.WA8>%%X07@Y>(\*67A%>&%XZ'CZ
M>>IY[WGR>?!Y"'MP>VI[<WMH>\A[\GM[/JY\JWRU?*]\LGRV?+!\'GT#?@9^
M'WZL"P]^`GX9?AA^(GX5?@=^#7XD?@Q^'GZ)?XI_"H`+@`>`!(`)@(2`@X`8
M@A2"!8(6@@Z"$8((@@N"%8*%@#>"*H(-@@^"?H-V@W>#[(/\A`B%_X0#A1"%
M!84&A?J$QX;`AL.&IX:HAJN&P8:JALB&0X<"B`Z(`8C^AP.(:`TBB"&(!X@(
MB`R(RHF\B;Z)O8E<RKN)N8FK#<6)F8IKBY.+E(NIBZ"+IHMARJN+GHN;BY&+
MF8NVC+B,FHR1#IB,FXRSC**,JE2@C)^,6XYPCE2.<8YECE&.G8YACEJ.=(Y,
MCDN.7HY8CE..4HX[CSF/UH_GC]>/V(_9C]J/VX_<C^"/Y(_=C_6/\8^8D)V0
MF9!0D4F1Y"=BD=>1`9+WD7W*C)*<DH@H'Y,>DSV4/Y01E%F4/I18E`"5GI2V
ME*J4KY2LE#`0P)2IE!`^[I5WEGF6>I9]EG^6@Y9XEGZ6Y);FEN6671!.EUF7
M=1".RD^72I?CE]Z7XI=TF:R989EBF7:9>IEYF6"99)J!F]^:A)J*FI*:>9K>
MFIB:;)KAFJ7*?)IRFH&:X)IEFO\0:IJ7FJJ:TYJKFFZ:K)IVFGN:K9JFRI2:
MUYIPFM6:\9IZFFB:EIH+$7.:KIK=FMJ:KYJPFMN:8IKXFL*<QYS(G,6<PYS&
MG-Z=R!$1GA6>*)XAGBV>49XKGA:>))XUGA^>$IX0GH">.YXIGBJ>&YX8GB">
M/YX<GB:>"YZ^G\2?O9_ZG_N?L:"RH+"@N:"FH+V@MJ"XH+2@LZ"GH*Z@O*#R
MH?.A]*$[HD"B1J+PHNZBZ*+QHNNB[Z+\HR"D":0&I`.DS\H9I"2D&Z0=I/VC
M'J3THP&D"*0%I".D_Z/JI4VF3J96IE>F4:95IE2FRZ;4IM&FSZ;2ILJFUJ:+
MIXBGA:>)IYM,NZ>,IW03F:>*I^RH[ZCYJ`FI^*CSJ`"I':FL$_VH2*I<JE6J
M7JI)JF.J8*I3JF*J0*I)JTJK3*M-JPJL!JPOK"&L!ZP)K`*L%JP#K`NL#ZQ@
MKFBN7JY=KF.N7ZYDKGBN8:YIKF6NVJ_FK]NOW*\YL%>P5;!EL&&P5+!%L4&Q
M/K$WL1*R$[(LLI:RZ<J<LIVRA;+HRI^RH[*"LX.S[LH=M!2T'[0@M$>U@+7)
MM?FU!K;PM?BU[[7]M?&U_K6XML"VP[:UMK:VR;;SRKVVNK:_MK.VQK:RMKRV
MM[:YMLBVM;>SMQ86K+>IMZVW$;D-N1:YB;E\N8NY>[F(N82YG;J8NHB[AKN"
MNXN[_\IQNW*[@;N,NX"[B;N[O,&\OKP!R[V\P;VTO;>]R+T[%].]T+VPO<J]
MS;T5OAF^%[X_OD"^1+Y\OGB^>;Z(O@;+B;Y]OB._)+\FOR*_)[\?O\F_P[\*
MP`O`!,#O%P/``<`)P`_!+L$MP9'!F<&>P9#!E,&=P9C!F\&<P9K!5,*=PY_#
MH\.DPZ7#`L87QQO'&<?1QS='`````````````````````````````````#0`
M```U````-@```#<````X````.0```#H````[````/````#T````^````/P``
M`$````!!````0@```$,```!$````10```$8```!'````2````$D```!*````
M2P```$P```!-````5@```%@```!A````9````&<```!Q````=@```'P```!_
M````@0```(8```"-````CP```),```"5````F@```/\``````@```0(```,"
M```$`@``!0(```8"```'`@``"`(```D"```*`@``"P(```\"```0`@``$0(`
M`!("```4`@``%0(``!8"```8`@``&0(``!H"```;`@``'`(``!T"```?`@``
M(`(``"$"```B`@``(P(``"0"```E`@``)P(``"@"```I`@``*@(``"P"```M
M`@``+@(``"\"```P`@``,0(``#("```S`@``-0(``#8"```W`@``.`(``#D"
M```Z`@``.P(``#P"```^`@``/P(``$`"``!!`@``0P(``$0"``!%`@``1@(`
M`$<"``!(`@``20(``$H"``!+`@``3`(``$T"``!.`@``3P(``%`"``!2`@``
M4P(``%0"``!5`@``5@(``%<"``!8`@``60(``%H"``!;`@``7`(``%T"``!>
M`@``7P(``&`"``!A`@``8@(``&,"``!D`@``90(``&8"``!G`@``:`(``&D"
M``!J`@``;0(``&X"``!O`@``<`(``'$"``!R`@``<P(``'0"``!U`@``=@(`
M`'<"``!X`@``>0(``'H"``![`@``?`(``'T"``!^`@``?P(``(`"``"!`@``
M@@(``(,"``"$`@``A0(``(8"``"'`@``B`(``(D"``"*`@``BP(``(P"``"-
M`@``C@(``(\"``"0`@``D0(``)("``"3`@``E`(``)4"``"6`@``EP(``)@"
M``"9`@``F@(``)L"``"<`@``G0(``)X"``"?`@``H`(``*$"``"B`@``HP(`
M`*0"``"E`@``I@(``/@"``#Y`@``^@(```````````!5*X(LB2R'++XMO2W*
M+=0MO"W$+<$MPBW7+7`MNBWC+;LML2ZV+K`N;"\-,`<P\3'U,>TQ[S'K,>PQ
M[C$',L0S"#2S-*TTL#01-8HL@S9Z-H(V:#9Q-K`VKS;V`6PV;S9B-F4V@39_
M-F0V<S9N-F<V=#9]-G@VA3:J-H@VIC9.PXHVA#95&B0Y(CDC.3(Z6SI/.F<"
M)CH^.D(Z1SHB.ILP2CH?.DDZ*SHS.EC#*CHH.CT[/#N_.WD\@#Q\/'H\>#R"
M/5P]6CU+/7P]?ST?/8D]BSU7/7X]?3U3/9\_O#^E/X8_W#^D/[8_HC^T/TA`
M1D"G0!1!$D$10>%!T$$F0BA"*4(O0PU#)4,40SQ#"T,10S!#&$,90S9#%T,0
M0Q5#`T0I1$Q$/T4^131%0D4U1?,QS4711=)%K4:Z1L%&NT:T1KQ&;$>21R%(
M)$@97ZU(KDBK2*Q(<$EV27%)=TE_'.Q*'$O[2NY*XDO]2AY+.TM*2Z[#D@5]
M2U9+1$M+2_I,Z$SX3/],]TSV3/Y,!TU=3=1.P\/(3L5.P,/)3DU/($\V3S5/
MB$\E3R%/)D]%!C]/.T\D3T-/3D]/3T1/0$]!3SE/*T_=4-Y0S5'+4=M1V%'9
M4=)1RE'14=11^5'045Y275**4A13@U2$5)M4@E1]5'Q4F51^5)I4E51[5(94
M2%625;)60E=R5Q57,%=#5UM7'5=S5RU7R0<A5QQ7ZL,I5QY7,U<06@Y:\<,-
M6A%:$EH76@E:#UJ86I1:EEJ96I5:EUI06U);35M76U-;5ENX6Q)<\5SP7.Y<
M[USE7.M<YUSR7.9<]UP)76M=:EUY7LU>[U[D7N->;%]G7V)?6%]I7ZM?5U^M
M7U1?KE]V7TE?15]/7P_$4%]]7T1?9E](7Z-?45]37Q#$8%]'7UY?A5^L7VU?
M=5^H7U4)0U].7UQ?5E]N7V-?:E]68A)B7&)88E5B?F*H8A%B66):8F=B5&);
M8O!B*60L9"ID)V1G9&ADDV259)ID[F3Q9.UDZ63+9=]EVV4\9TYG;&=[9WQG
M@V=K9V9G8V>@9X5G:&>B9^QHZ`KG:!!I&&DZ:1II.&E!:1MI%&D<:1UI$FH-
M:@=J?FI_:KDT@&IZ:O-JN6N[:[IKO6NW:[]K(6PZ;3UM-FU);8%MM@L_;4UM
M/FV]"S!M3VTW;IANF6X1;PUOB&^*;QQP57!6<&)P5W!"<!!P37!:<&9P1G!^
M2T]P^8"'<81Q]''U<?)Q]W%%<U#$27,U<_UR,'-#<T9SU@PS<\9T5L34=-B-
MX'2G-D1UF"U4=CYV-78Z=G$--'8Y=D9V6G9;=CQVW'?6=]!W7L2L>%W$I7CT
M>21ZX'G]>?)Y_'D">O%Y_WG2>=AYTWGY>6/$[7GW>?!YUWD)>O5YPGS%?,]\
MF`[!?,9\U'S.?)M^F7Z/?K=^@GZ3?K1^P7Z0?II^E'Z<?K5^;\1NQ)]^CGZ>
M?CR`1X!!@.N`[(#M@.Z`WX#R@`V!#H&&+*F!I(&E@5^"6H)F@FB":H)D@F6"
MP8+8@GO$V8()@ZJ#HX.Y@^)WI8.K@R"$B86+A=N%Y(7OA>*%Z87PA?.%W84>
MAAV'1H=\AX"'@8>"AX>'B(>*AXR'YX?KA^J':(AKB&F(9HAJB&6(Y8CDB.:(
M&(DDBDB*+XI^BHF)'HI)BB:*"8HTBBV*2HH5BJG$,XHHBB>*((HKBBF*:HH+
MB@Z*'(K_B:K$-8H1BDN*3(H?B@^*.8IHBAV*"(H,B@V*8HJOBC**+(IDB@2*
M%HI-B@>*KHK4C=&-U8W0C7&/78];CWJ/O<1_CWF/9X^>CY2/9(]>CX&/6H]7
MCWR/F(]FCWZ/@H]HCU^/8X^7C\T14X][CWV/>(\&D,"1PI'#D=R2YI+LDO*2
MZ)+KDNJ2Y9+@DM"2V)+5DM.2Y)+SDMN2+Y/YDUV46Y1,E%B48)13E%"4!Y4(
ME?24]I0$E?V4!94HEE:60I9<ECV6+Y8KEEB6898LEE&64)8\EC:6]A)@EEN6
M+I9`EE^6)I8MEEZ6.Y;OE_.7[I?MEUJ88IA;F%^87IADF."8X9CEF*69FYF?
MF9R9>A.JF:29HYEGFB:;&INX$QR;%9L;FQB;'ILEF]S$>YQUG).<CYQ\G)N<
MB)R1G'Z<`12&G%N>5)XUGT"?-Y\IGR:?(Y\PGR"?*)\RGRJ?,9\DGT&?0I]#
MGR6?.)\<H!V@'J#VH*6AB:&=H8JAAZ&KH8:AGJ&3H:&AB*&CH9^AH*'_H@"C
M`J/XHO>B`:.'HXFC=J-NHW>C@J.%HX.CA*-7I$ND5J1=I&"D3:15I%2D4Z10
MI&.D8J07I1:E+:79I;^E+Q6RI:REL*7/I;BE,173I;&EKZ7.I;2EMZ75I9P5
M.*DHJ3^I0*E!J3.I*ZDNJ1&K&*L7JQFK%JOF%0VK)JMYJ]BK\ZO7J\RKSZO+
MJ]&KSJO4J]6KTZO6J\VKVJO2J]ZKS*RXK+>LPJS#K/JM^:T?KAVN@F*FKI"N
MGJZ8KI.NDJZEKI6NJ:^HKZJOJZ^LKQ^P(K"JL):PD;"KL**PI+"=L)>P?;"?
ML)RPF;"FL)*PI[#)L<BQQ['+L72RR;(X%]*RV[+KLNFR[[+NLOFRWK(6M$6T
M?[28M)^TAK20M)JTG;2-M)RTH+2GM(^T0;8UMC>V,+8ZMC:V",7*MA*W%;<B
MMQ.W&+<AMQ"X(+@ON*6XH[BVN*NX:+EGN6^Y=[EDN7BY.AAVN6ZYL1C0N[.[
MR[O6N[&[M+O7N\:[NKO1N]*[M;O$N\R[N[NRNUN^6KY9OIF^E+Z6OI.^D;Z/
MOIB^#+\*OPZ_$K\1OPN_FK]'&;2_41D<P"#`(<#3P-+`.,']*L]K'2R2+(\L
MC"SJ+;DN;B^@+]VM$C`7,&TP!3+[,?TQ!C(`,O\Q_C&V,@4S!S.\-+LTBS6'
M-?N7YS;F-N(VTZ'9-LHV$C<0-]PVT#:+-A,W$$W:-D_#_3;E-LPV.3?'-M@V
M8#ID.H8Z7CIF.E\Z=SJ".I8Z/CMY.WH[B#R)/(P\X&)[/(8\E#V7/;<]M3VX
M/9,]LCVT/9D]PSV=/9L]HSU'`Y\^GCZC/J`^H3[%/\8_OC_$/[\_3$!*0+%`
M%4$701!!&$'@0=]!)T)#0TA#'4-00UA#1T-40U-#0$-50Q<$6D-P2%M%3456
M14]%A\-918C#5$5315!%LT9N1Z,$;T>31RE()4@H2&](N%27P[-(>4E^27Q)
M@TFLPP!+-$ME2S9+ITM92UA+,4MB2SA+<TL^2U5+5$N52ZW#I4N42YI+FTN9
M2Y]+4TL230I-"4T,30M-#DT-30A-.$\Z3S=//4\M3X)/E4^'3YU/M4^!3\=/
MFT^83Y1/AD^03S1/CD^%3Z9/ED_J4=]1O53W4>M1X%'H4>%1Z5'N4>51[%%C
M4L92PE+!4L!2PU(84ZY4HU3%5*!4M%2E5!X'I%2H5*94J%>-5X)7GE>)5X-7
MD5>F5YI7D%>%5WU7[,.;5Z57\%>65XA7UE?85X97I%>75QQ:&5J>6I]:G5J<
M6EU;7EMS6V-;OEO!6[Q;OUN[6[U;$UP47/A<^EP&7?Y<45T+8/%?J5_57]Q?
MRU_R7U]@VU_67]E?T5_/7]A?X%_47_-?!6#.7_1?$L3:7PY@!F#77\U?!V#A
M7PA@OF+O8MEBVF+7'Z!BWV*>8K]BKV*G8JIB]&*N8K5BN&+;8L!BMV*B8MUB
MH6*E8K1BIF*K8JQBGV*Q8OQB+F0P9)ED^&3V9/1EZV7A9>1E=6=I9YH*F6>>
M9Y1GDV>19QEI%VE):4=I2&E2:4!I8VE&:5]I#FJ%:H=JRVK,:LEJRVOG02!L
M7VU@;6IM=FUS;7%M9FW""VMM>6U[;3QNGFZ<;AQO'F\A;Y9OH6^V;Z!OE&^7
M;X%PAG#`<(IP2\2%<)5P27""<(1P>$N0<+%P_G'[<5!S5G-:<TQSW`Q7<^%T
MV73;=/1T175'=71V:W9H=FEV>79;Q(!V@79A=G!V;W9S=EUV^G>S#?-W"G@7
M>%_$L'@^>D9Z3WI$>FEZ,WHO>DYZ.GHK>JEZ4'I%>C=Z)7HL>C]Z-'HI>AYZ
M/7KM?&;$\WSJ?.M\S'[.?M!^XW[@?M%^W'[=?O!^VW[E?O%^R7[H?N=^R'[>
M?LU^Q7[&?N1^PW[[@/R`_H`#@0"!_8`%@1.!IX&T@7""=()Q@G6"?8)S@L2"
MPX+>@MV"$8,/@Q"#PX/"@\J#P8,CA+&%)(81AB6&"H8?AB"&%(8HA@.&$H8+
MAA>&$4U)AXF'D(>/AY:'E8>3A^V'\(?>8H6(=XAZB(2(>8A]B'N([8CLB/:)
MFXF=BA&+Q(K(BM^*OXJSBKJ*$(L&BXB*FHK@BLR*M8KABKR*QHH+BZ2*E8JC
MBN**S8KCBJN*RXJ/BJO$J8HDB^2*$HOEBF>+JHJ@BN:*P8KGB@V+AHJPBHN*
MZ(K)BAF+P(H,B^F*ZHKMC>.-Y(WHC=*-XHUF),^/T8_#C\F/ZH^TC]R/O8_F
MC\B/[(^RCZF/TX_`C^F/U8_9$<6/W1'+C]"/TH_DC^B/S8^VCZJ/U(])H,&/
MW8_.C\F1RI']DMF2_Y($D_J2!I,5DQ&3!Y,+D_R3_9-ME&64%)43E0R5"Y48
ME2*5?99OEG66>Y:`EG^6EI9MEFN6AI9SEF*6=Y:!EFF6@I:7EH26_!)XEM#$
M>I9JEF66?I:4EL*7P9?YEW&8:YAMF&^8;ICRF.B8[YCIF.J8[9CSF.:8R9FT
MF;.9N9G*F;&9MIG'F<29MYEOFC.;,IL?F]G$*YLPFS:;0IM!F]C$I9RKG*F<
MLYRGG*"<TIRHG+:<K)RNG.:<99Y'GV.?39]?GTN?8)])GU.?W\0Z)E>?3I]2
MGU2?(*`BH,&AUZ'5H<2AT*&[H>*ARZ&XH;^AV*'`H;JAM*&\H=2A[:'"H=FA
MS*$OHR.CEJ.-HYZCF:.#I`<5:J1II'6D;*2`I&ZD@:1WI':D<Z1PI(2D&:7R
MI3TG[*7KI?:E[Z7TI>ZE\Z7MI9NHF*B4J'HZFJCPQ$RIJ!57J5&I8JE2J5RI
M4ZGOQ(6J+:L^JS"K?:OFJ_:KY*OIJ^RK\JOHJ^.KZZOPJ^JKYZO]J^6K[JOU
MJ_FK\:OTJ_3$$:S>K-BLW:S;K-.LX:S>K?RM**ZWKKBNQZZRKJFNN:Z\KK.N
MT:ZPK[&OMJ\$L"RPP;">L+JPRA;1L-.PU+#5L,6PMK"RL+6PP["YL,:PUK'@
ML=NQU['=L16S#+,/LPZS_K($LPNS`K/_L@BS$+,7LQ.S!K,)LR2T)K0EM$BT
MM;32M-6TQ+2OM*VTP;3`M,RTS;3#M,BTQ;2ZM-"TPK3.M(T70[9"MD"V,;;/
MMLZV,+<TMS*W0[<\MQ&X-;@TN#>X,;B_N+RXPKC)N(.YB[F@N8VYC+F:N8JY
MD;GQNP^\`;P'O`R\P!C<N^Z[][ORN_B[Z[O*&.:[[;OINPB\`+SEN_R[8;Y>
MOE^^)1F;OA:_%;\@OQ2_&K\7OYR_2AGQOU,9\+\HP"3`*L`KP-7`!,$%P9'!
MDL&FP@DL(BX:+@XN&RX(+K-O',.=,!(R'C*[,K\RO#((,PDS8S/(,RA8CC6-
M-4,W33=M-T(W4C=1-VDW4#=6-VPW1#=%-VLW!0)H-U<W+CDQ.2TYBSJR.HTZ
MHSJD.I`ZB3J..I(Z>SN0/(\\Z3W-/<4]T#W)/=$]QSW2/5\]X3W,/<8]Y#VI
M/M,_VC_2/]L_34!.0!Q!Z$%L0U]#9D-D0WA#94-M0V%#>D,'1&9%:$5B1=-&
MU$;11MQ&<T=R1RU(+$@O2')(M$B)2<U+IDNB2Z!+1DNA2U>&HTNQ2]M+]DO<
M2]9+$TV<3Y=/V$_D3]1/Y4_;3]!/VD_,3]Q/[4_33]%/SD_93]U/QL/F4.50
MZ5#_4?Y1#E*,4LI2RU(:4]=4SU305,E4S%335*15HU6!5R98\U<G6/)7_U?U
M5_Q7#ECP!_97`%@C6`58)5@(6%!8)5H@6B-:(5JA6FE;;%MH6VM;S%O-6Q!=
M#5T*719=%%U272A@+F`L8$U@26`Q8#!@,V`M8#9@/F`O8"=@-&!,8/YB$F,?
M8Q=C]6(58_=B`@I]0_IB^6)+8YQDG60C"O!E]F7O99UGFF>G9Z]GJF=D:89I
M=6EP:81I:VF%:6QI%VJ4:I-JTFO7:]1KIFVG;9QMBVV-;9AMN6V;;9UMF6VH
M;9%MAVV:;:9N'V^G;[%OLF^W;]!PLW"U<,1PPW"\<+)PNG"[<,)PS7"^<+=P
MCW$#<@1R<7-W<W1SBW-Z<U'$C'-S<_]T^W3]=/!T\W3\=/)TDG:>=JYVEG84
M>!)X$W@6>`]XMGB]>(QZKGJL>JMZF7J2>KMZGGI^>J]ZO'J8>@%]"7T&?6?$
M!WT(?<]^#G\R?Q4/$G\6?Q=_&W\5?S%_&'\:?Q!_"G\)?T^`<\0/@1"!=<0H
M@1&!%H$7@0*!NX&Z@<.!O(&*@H2"AH+@@A>#&(,>@Q6#TX/:@]F#YH7TA>&%
M:89`AEB&;(9-AB&'F8?QAVA?AHA;BUR+=XLLBZW$6(MDBV&+2(N7BUF+*8MB
MBRZ+:(N0BSJ+/8M>BT:+:8MEBSZ+28M6B^&+>(MYBV:+2HLUBWJ+DHM@BS:+
M48M"BUT1/XM[BUV+E(MJB[7$\HV[CQN0&I`SD!>0"I`5D!*0`9`MD/V/(Y`%
MD!&0`)`<D#60+I`VD+\T+Y`,D`F0,9#\CP^0&)`"D`"2'Y,WDUH2.),KDRZ3
M(9,PDRF3,9/)Q`&3+),BD_^3=Y1GE'^4?91[E'Z4'I4<E2&5)I4GE2F5+)4=
ME2N5OY:DEJJ6KI:?EM"6L9:MEIN6LI:IEK.6M):ZEJ66MY:LELN6SY;&EP&8
M_Y?]EW>8>)AVF/>8S)F%$]29UYG5F=:9TYE=FU6;X)Q(G>Z<VYSGG-:<Y9SA
MG-V<XIQPGF:>;YYNGH&?:9]NGVV?;)^$GX6?<9]SGVJ?;Y][GVJA?*%]H8&A
M^J$%HNNA^Z'IH>^A_*'GH>'$[J']H3*CIZ.UH[&CN:.HH[.CYL2*I)&DC:29
MI`L5FJ2;I)*DCZ2KI-MK.15UIC&F.*8W%36F::8[ICVF;*9YICRF/J:7J*6H
MHJB=J*&H:*EOJ6VI<JEUJ7>I>:FUJNJJJZI#JT&K0JL)K`BL!JP!K`.L`*P$
MK`JL#JP-K`>L#ZP4K`*L%:P,K!"L!:S]K/^L!*T`K0FM*Z[WQ#&NVZ[%KM.N
MSJYK%LFNOZ[+KL"NT*[4KL&ON:^[K\.OR:\'L"VP^+#AL/JP[[#]L,T6Z[#Q
ML.VP_K#XL0.R[K'HL0&R[+(BLQ2S-+,OLSFS0;,\LTFS6+,ZLT*S/[,BM".T
M2K3<M-FTV[3BM`?%W[3@M->T3[9&ME.V5;9.MDJV3+9CME&W4[=8MTVW6K=)
MMUVW$K@\N-&XW[C6N-BXX+C9N+&YK+FJN>ZYO;E-&,.YJ+FNN:NY';PGO#B\
M$KQ(O"N\%KP9O#V\([PJO&2^K;ZLOA3%L;ZOOBR_)+\EORB_^;_WO_V__K\Y
MP#/`U\#8P.3`H3H.P3O!1,%"P93!D\'5P:?",2XC+B@N)R[&+J,O(3`;,A`!
MP3+#,BHS:3,G-+8WIS>D-Z8WD#>>-Y0WJ#>E-Z(WD3=[`KPZO3JT.K`ZY#I%
M.TL[?CM_.WT[PSO\/?<]\#WM/?$]^#WI/^M!'0200XU#AD.10XI#"$101.I&
MYD;B1N=&[4;A1C1(=DAU2'-(M4B029))X4O?2]5+\DO^2Q-,+DP930A0]1T%
M4`E0!E`#4/U/_$\"4$)0&E(14A52%E+,4L]2T%(B4QY3(5/E5"<'5%7O5%-5
M456M56=8:%BD6'=8B5A$6(M8>5A;6$-85UA*6'Q81EA[6%98J%IV6W);UEO8
M6]%;(ET@72-='EUN7:-@=V"F8&U@HF!\8(1@:&!T8(9@I6![8'I@:6!R8'9@
M2F,W8RIC+6-&8RAC)F-"8RQC.&,K8S-C16,Y9/EE^F6X9[=GNV>Y9[1G;VF'
M:8]IHFFC:3'$FVJ=:LYJSPN];;]MDFW-"^]MR6VD;JANJFXH;R1O)6\F;ZEO
MNF^^;[QOP&_P<-]PX'#M<-MP^W"Y<-IPZW#L<)ISGW.;<Y=SH7,/=05U2'6"
M#;QVNG:_>`%[Z'KO>N1ZYGH">^MZX'KM>MEZ9,04>^YZ4@X3>_EZ^'HE?6G$
M&7T@?4-]/WU%?TQ_27]/?T%_/G]-?U)_2G].?W-_0G]1?U5_4']L?_TJ:G]3
M?VA_58!6@!R!'8&`(AZ!(X$?@>&!S8'+@<R!R(')@9N"E(*2@I:"DX*5@H^"
M'8,B@R&#Z8/O@^"#YH/D@RF&+(9VAH.&>(8\AD-C>H91$/*&GH>;AYJ']H?U
MAZ6(DXBDB(**QXJWBQV,XHO7B^.+Y(N\B].+6A%:B]*++8NOQ,2+T(OEBP6,
M!XSFBQN,YXO8B[Z+%XRTB]F+Z(NMBZ^+R(OIB^J+_HW[C0".<I!PD$:069!>
MD$B03Y!QD&"07Y!ND'.0P,2_Q$>0;9!OD(&0;)!XD(.029!HD'208Y!JD(6&
M99!BD,B0T)'4D=&1`Y)"DV.35I-;DU634),MDT232)-%DX*391)BDX64C90V
ME2^5,94WE:>6V9;PEO*6_9;HENN6[I;@ENF6[9;6EOB6U);?EN>6V);CEN^6
M#Y?*ET8[!9@,F`V8?YB`F(&8`9D#F?*9XIGCF=Z9Z9GHF>"9`9KUF>29`25W
MFG2;;YMBFV&;;9MSFVJ;:9L2G2V=%)T/G2F=%IT#G4:=7)T1G0:=W)PKG2J=
M+)TGG7J>G)^9GY6?BY^8GY:?,J"DH:JA&Z*O%`VB'*(*HB"B"*(:HA.B$:)=
MHU^C7J-@H[NCO*/!H\"CR*/.HZ>DLJ2VI*6DNJ2UI*VDI*33I+"DL:0=I8VF
M0161IK:FMZ:]IKRFEJ:4IJ"FJ*BFJ(2IEJF(J9JIT:K/JE"K4:M.JX"K@:L;
MK!>L(*P9K!JL(:P>K!BL':PI%BVM)*TGK2ZM):T<K1FM*A8CK1^M&JTKK1ZM
MX*TSKN:N_*[EKOBN]J[JKO*N[:[KKO"N\:[&K\BOSJ_%KY86RZ\3L12Q![$,
ML1JR$A<7L@:R%K('LA"R";(9LA6R;K,[LSZS;+-ELV2S6;-\LW"S>;,LM%*T
M4;1,M`"U$+43M?^T_K3MM%JV6+9<MMJV>+=>MV>W9+<3N".X0;@_N$"X[;CC
MN.JX\+CFN.FX\;CNN-2YT;G<N>RY:;QMO%>\9KSYO$J\8+Q6O%F\3+QJO&*\
M8[QPO%^\#<5DO%V\:+R?O+J^N+Z\OKF^M+X[ORV_.+\OOS*_0<#+P-[`W<#:
MP-S`$,%/P4G!F,&6P9?!Q\&<+-K!V,&HP@HLG2S++C@O.2^F+R,R(C(A,LXS
MDC61->PWX#?M-P@XY3?N-^0WZS?C-^HW"CA9P]$ZXSK4.M`ZV3I^`N$;VCK3
M.DP[33M\.X`[S#O_/0@^",$!/FO#`#[M/_,_[C_Q/_`_WC]10()#J4.80YU#
MFD.>0Y]#ID.G0PE$+T1Q16U%<D7O1O!&.T@Y2#Q(.$C]:CI(>$AY2'=(F$F<
M29E)FDD13`I,_4L/3!E,`TP53`Q,"4P23#1,*DP(3"U,*$RQPRQ,)DPS3*<%
M&DT>30=0+%`R4"A0,5`I4#!0*E!$4"Y0T5(D4_=4]%3S5/A4M5B66)A8E5B1
M6+)8GEA96*-8FEB;6"`/@W_:6]];%EP?72U=+ETK7;A@NV"_8+I@U6#C8,%@
MOF"]8+1@PF"A8(=@UV#*8+5@VF#98+-@V&!G8W%C8F-<8VAC4F-68PDX0BZ@
M9`!F_F7_9<MG*,3*9ZEGR&>T::QIJFFI:0YKZ6OM:_)KZVON:^AMVVW7;>-M
MY6WN;=5MLVXM;\%OPV\,<0YQ!W$7<0EQ%G&:<9QQM'.W<[-S3CL3=11UYG;<
M=NAVY78N>"QX*WC->#U[,GLM>T5[/GM0>R5[4WLC>S=].'U'?3U]/GU)?4I]
M'7WI(:5_C'^-?XE_EG^%?X]_=W^.?X)_BG^(?WM_EW]]?WE_68`D@2V!+H$K
M@7;$VH'8@=:!AX*@@BB#)8,?@_.#]X/V@RN&6X9(ALLC7(9MAIV&F8:,AI&&
MFX::AIR&E8:-AI:&I88JAZ&'I(>MAZF(KHBPB`V,8XMQBU&,5(PJC$2,58R9
MC#F,/XP^C$^,38PUC$",,8S5BRN,,XQ!C%:,3(Q&C#R,18Q#C#V,<(Q7C#B,
M6(QE$3>,!XX&C@F.JY"0D).0O)"ID)Z0OY"JD)&0I)":D*>0H9"<D**0FY"?
MD)20CY#PCI*0E9"ED*:0!)*<DWF3>I-^DWN3<9.!DW^3?)-]DW63=I..E(^4
M/I4_E4"5094$$PV7%Y<0EPZ7ZI8=EP.7(I<$EP"7()<AER.7$Y<)EQ&7RY?.
ME]"7S)?4E]LZ"9@+F(68!ID-F603%)D/F0F:%)H+FOR9!)H*F@":_9D'F@::
M$9IYFGB:B)N`FXN;69UAG76=(Q15G5N=7YU2G6*=<IU=G6B=<9UEG6:=9YUV
MG4R=8)UTG5"=BIZ!GH:>?YZ`GJ6?IY^HGZ:?KY^5?[&?-:`YH,.A,*(JHBNB
M+:(NHBRB(Z(AHB*B;*.!HX^C@*/0H\VCU:/4H]&DOJ3+I,ZDO:30I`2GU:;0
MIM.F^Z;8IM&F_:;9IM:FYJ;YIJ&IG:F>J=DH_ZI?JU>K8*M9JRRL):PGK#"L
M)*PFK"VL+JPIK#&L1:U'K5*M2JU0K4:M3ZU.K5.M(:\)KQJO&Z\5<1"O^<04
MKPZO$J\+K\^OTJ_0K]2OTZ_1KQ@U^\0)L!RQ)[$EL1NQ*;$?L3"Q)+$HL1FQ
M+[$DLB&R);(FLB>R=K)FLW6S:;-^LX^S=+,0CJVS*[0JM%BT(K4=M2NU++4M
MM3.U&[4GM2JU*+4[M7ZV<;9YMGBV<+9MMGVV=;9VMMZV9K>#MX>W>[>)MX:W
M@K=\MX&W0[A%N/>X^;CZN`6Z_KD/NO^Y^KD)NB"Z#+H\NB*Z^+D*N@BZ][F.
MO'>\B[RTO(J\FKQYO(.\?[RAO(^\H[R!O)2\?KR"O)"\I;RMO)V\9[YIOLN^
MR+[1OD"_2[])OT:_/K]#OS^_I;^GOT[`3<";2>7`X<#BP!;!%,$;Q5G!4<%?
MP4K!5\%8P<K!V\'>P>#!X<'?P>+!X\&2PK_"OL(++%(N3BZY`!/#IR\F,B<R
MQC(+,VHS>#,:.!8X&3@7.!LX&#@@.#<Y[#J!.SVN#SZM/OL_4D"O0[=#LD-X
M1:Q%`$?^1@)'_48#1T!(0TA"2+=(HDD`3#5,04P%3%,N4$Q.3%-,4U!04%=0
M7U!54.I0)E(PM"I2*%(L4BU2U%('55A5657%6,U8QUCH6$L(,EJ7PMY;,EW(
M-!7$\6#P8.Q@"6'Y8/5@_F!T8X%C?&-U8XEC@F.78X9C?6.38YQC=F.`8T5D
MH3`#9LEGS6?09ZUIQ6FB:NQK]FOS:_-M^FWY;?5M]&WX;;9NM&XR;\UOR&_.
M;\IO*G$A<1UQO7.^<\)S\0S)<Q]U\7;M=O)VX';W=C!X-W@Q>#9XR'AM>VE[
M?7MA>W![<7MS>W9[=7MX>WE[9'MN>U%]3WTB?:]_JG^C?YU_G'^A?[9_K'^B
M?Z=_L'^I?\-_,8$R@3.!-($W@3R!V8'=@=Z!WX'@@:6"JH*B@J."!(0#A/Z#
M*(2OAJV&IH:LAZ6'L(>QAP&(LHC2B/&(T8M'C,F,IXS(C)6,CHR1C'V,[HR-
MC(R,L(R6C$*,?(RQC+*,A(R=C*&,F(RSC"*,>XR*C,Z,@(R7C+2,M8R:C)^,
MDXP2C@N.#HZCD,R0W)#AD-Z0TI#;D-F0UY#4D,F0ZY#:D-&0!)'*D.*0UY&,
MDYF3HI.6DY23GY-G$HZ3`Y24E).41)4OES67*Y<RERV7-I<4$S&7$I<SEQ^7
M-)=`ES^709?3EXF8&)D0F1J:)9H>FI*;E9N3FX2=FIV)G8V=B)V1G9N=G)U(
ML8Z>DI[%G\&?N)^^G[6?QY\\H(D4[*$_HCFB-Z*AHY2CH*/>H]NCWZ/<H]:D
MW*3=I."DXZ3AI!BG&:=3I^S$1*<.IP^G1Z<7IQVG$:>TJ+:HMZF^J<*IM*DQ
MJQ6K@ZL[K#:L0JQ0K$"L-*PXK#VL/JPUK#JL1JPWK#FL1:QWK5VM:JUVK6NM
M;*UEK62M<:U?K7*M_JW_K3ZN*Z\VKRVO.:\_KSNO,Z]"KSJOU:_8K]FO#;`*
ML#FP.K`]L46Q.K$WL3ZQ0K&'LXRS@K-KLZ"SFK.0LXZSH;.]L[*SM;.WLZJS
MHK.ELZZSJ[.\LS*T6K1DM5RU3;4_M3ZU4K58M5>U7K53M52U5K5EJX2VA;:&
MMI>WH;>BMPL8"L6CMZ:W%Q@5N"2X2KA)N$BX2[@.N6*U"[D*N0BY!KE#ND>Z
M/[I&NE"Z;1A+NG`84KK7O+^\V+S@O.>\N+S5O.^\YKSDO-2\UKSJO.T8N[SI
MO!#%;;YPOG.^<K[4OLZ^U;Y:OUB_4K]0OU6_3K]-O\N_S+_-O]&_6,!CP%[`
M5,!;P.G`Y\#HP!W!9\%:P5S!6\%AP:'!C1FDP>G![\'EP?7!Z\'MP9;"E<*S
MPK7"L<*G`$TN)#`K,L\SR30V.#$X5#@Z.#@X.3DX.?0Z\SKV.OPZ]3KQ.IP\
M&#X:/OP__C\#0%-`*T+&0\%#>T4&1TE(N$BC25),34Q?3%Y,84PC38Q0;U!U
M4'10<5!P4&Q0)E,(50<>\%CO6/M8$%D,6?98_EA\6^%;.%UO71AA%6$<81!A
M-6$7Q!=A'6$F82AA*6$J81IA%L0'1ZMCK&.A8ZYCHV.G8TAD!&7]95H*"&;2
M9\9IOFD<:J9JIVJK:@!K^VO\:_EK`6P&;@1N/,0T;S9Q,G%"<2UQ-7'8<R-U
M('4!=P!W`W>\PCQX07@U>,EXCGN>>YE[M'NJ>Y][EGN=>\-[='NK>Z\.8WU;
M?5I]Q7_$?\]_R'^D?[U_TW]@@#N!XX'G@:B"K(*I@BJ#"(0)A+F&P8C"B+B(
MX8SKC.6,^HSDC`N-UXSOC.",[(S[C+#$TXSFC/R,XXS/C-J,W(S2C*2,:Q$7
MCA:.\I#\D!B1]I#^D/.0]Y`!D?F0!I'UD!"1WY`#D0B1V)$%DI>3LY.NDZ^3
MIY.QDZB3K).KDP24FI1*E4*76)=+ET6729=,EUF75I<;$T:71)=;EVF7CIB/
MF!Z9O(8OFIZ;G9N?FYR;M)VNG:N=LYVOG<*=DYZ5GI:>EY[/G\Z?RY]+H$:B
M0Z)%HE&BKJ.OH["CN*/BH^.CYJ/MI.JD.J59IX2G7Z=\IURG6*=5IUVG?J>`
MIX.G5Z=C%5ZGNJC5J5BK:*MGJTJL3*Q2K$FL3JQ'K$VL2ZQ/K'ZMAZV#K8FM
MRFF&K8BM1ZY"KDFN2*Z`%H06?Q9$KU&O1J]'K^2O#[`_L$NQ5[%2L?$64;%8
ML5ZQ4[%=L4VQ/+(_LD:R/K)$LD6R0;(XLD*R0[)ZLJ.SNK/`L\2SQK/+LV&T
M>K5SM7*U=+6`M8&U1RF5MH^VD+:2MI2VB[;FMK*WN+>]M[ZWSK>ZMQ:X)K@E
MN$RX4+A.N%&X4K@4N16Y&[F"NIFZFKI]NH6ZAKJ<NGFZ>[J`NH.Z@;H>O1N]
M*KW[O`6](+T1O02]_;P#O1"]&+T*O4Z]";T'O1R]'!EWOG:^V+[9OF&_7+]>
MOV"_JK_6O]B_"<`(P&O`9<!SP'3`[<`DP27!:L&GP:C!"\+ZP?G!_\$$PO;!
M!<*9PJO"O<*XPJ@`9"Y:+G(O>C.5-5\X83A>.%HX7#A=.&XX5SA8.`(["SL(
M.U$[)3XH/B,^(3XD/BD^!D`*0,I#S$/+0\]#?T5\1=9%"4<+1W9'?4BE25M,
M7$Q=3&5,;5""4(-0AU"54(I0UE(H4PU5+EGNPRU9(5D963M:/%HZ6GY;.UU'
M83EA-&$V849A.V%!845AP&/$8[ICO6.^8Z-D#&;99\UIKFK_:R1LNVZ\;C9O
MU6_3;]9O/'$_<=YSXW,G=2EUBPT%=P=W#'?0>+Y[O'O0>\)[M7O)>V9]*P_5
M?^)_W'_C?]I_PG_H?^F!KX*M@JZ""X3!AK:'N8?`B*6,*(TBC2F-&(T?C1R-
M$HTJC7H1(8TKC1>-\(P6C2.-*Y$FD3V1(I$ZD3&1,I%4D2&1-9$)$BZ1,)$O
MD3:1VI'9D;N3O).WD\*3O9.RDVT21''1>U*7:Y=GEQ\389=LEU&7=)=WEV^7
M;9=HE]'$A)>0F)*8DY@?F3&:.)HYFC>:JYO#G<B=RYW/G9B>U)_3G]B?V9_=
MG]&?UI\^H%BB5Z)5HL2CY*/NI.^D\Z3RI/"DJZ>:IZ^GEZ=J%6P5OZ>4IY.G
MOJB[J+RHV:ELJU.L5*Q;K%BL5JQ7K)^ME*V6K9>M2JY+KE6O6J]>KU^O6:];
MKUBO5*_HK^NO[*\3L&:Q:[%BL6FQ8[%?L4ZQ2+)*LN.SV[/8L]:SAK60M9&U
MB+64M8.ULA><M8VUA;68MIJVG+;GML6WT+?1MQFX)[@=&%2X+;DBN2T8'[F]
MNJZZN[JMNKRZN;JTNLNZM[JSNKJZMKK-NKZZR;H+Q5^].[UAO5R]BKU:O4V]
M1KU$O3V]0+T\O8R]0;U,O3Z]2KU\OGJ^9;]NOVF_:K]OOVR_<+]HOVN_11FL
MO]Z_W;_<O\5CC,"#P(+`B,"%P('`]<#OP/3`\L#VP//`\,#QP"O!)\$HP6S!
MKL$.PAO"%L(?PB+"(,(APA3"$\*=PIS"GL*?PFLNR#)X.'8X<#AQ.`H[+#X1
M1WY(5TQF3&E,9TQH3'%,;TRNOXM0EE`U4CI2:U(654-91ED_63M9/5FQ6K):
MY%M`75UA46%-84QA6V'48])CRF/(8]!CR6-)9*1D$F8/9A%FVV?=9]QGU&DA
M:K)J!&P";!%N%FX0;KYN&HY,<4IQ\G/Q<RIU+'4O=3%U$7<2=TMXVWO6>]U[
MXGOD>^![WWOC>VY]<7WI?^I_8X#K@>J!O8:[AL:&S(;(AL]CR8;*AL^&T(:Z
MA_N'`XC$B$F-4XTVC4J-08U.C1F-38U%C4R-1XU(C4^--XU"C4J11I$*$DF1
M3Y%1D4R1#!(&DE&5>I>#EWZ7?Y>`E[5JD9B4F)68(9D@F3V:0)I&FH2:K)NM
MFRX4VIW9G>*?X9_CG^2?WI_?GT&B6:)<HEJBZ*/VI/RD]Z3ZI/FDQ*>^I]*G
MO:>5I]2GY*EAK&*L8ZQDK&"L7*Q=K%ZLI:VFK4RN:*]NKW&O:Z]OK^ZO\:_P
MK^^O%;`4L&ZK1[!\L7JQ=+%VL6ZQ>+%ML6RQ3K+7L^JSY;-DM+.UH[6EM:>U
MHK6?M::UGK6HM:FVIK:JMJNVH+:AMJBVZ+;IMNJVY+??M^"W*+A=N%NX5KA7
MN%^X8KCANN.ZWKK9NNBZ\KKVNN:Z]+KUNN6ZXKJ-&):]JKV7O7"]H;V=O:F]
M;[U^O92]FKUSO8>]<;UWO8B]C;V%O7B]K;V`OH&^Y;[GOGR_K[_AOY;`H\"0
MP/C`+L%UP7[!?<%[P7C!L,$TPC;",,(=Q2["-\+.-)<UF#5\.'XX?3A_.`\[
MI#PQ/BX^+SXR/BQ"U$/<0]A##D2#181%$D=R3'Q,?DRF4*!0GE"B4"I3&%5-
M65A96UD4=_+#YEMD86AA8&%B8==C2V3@9R)J!6P9;AINPV[8;]QO3W'W<_1S
M^',3=U!X\'OI>^][[7OJ>_A[!7SR>W)],0_Y?_-_]G_R?_=_9H!E@$"!=\31
MAM.&!(A9C6"-6XU=C5Z-:8U<C6&-:HU?C4Z17)%@D6.1VY'*D\F3R).EE*.4
MCI>'EXF7A9>&EX^7BI>0EYB8FYA'FDF:2)KEG>J=[9WPG^^?\I_LGT"@8*)?
MHNNC[*,`I0&EXJ??I^"GX:?CI\.HZZGJJ6&K<:MKK&BL::QGK+"ML:VRK5&N
M=*]_L82Q4[)4LO"S]+/QLS>TO[6\%[L7O;6^M;>UP+6ZM;BUO+6[M>NVY[<=
MN!RX8[A+2#BY-KDTN3>Y!KL<NP*[';L>N^"Z$;L8NR&[(+L0N[V]KKVUO;B]
MN;V^O<2]O+VZO8.^ZK[LOGZ_>[_EOZ?`GL":P"_!,<&#P;7!1L)!PD/"/<)"
MPCO"1\)K,]`SCC@10''#B<-,2"M33UE>66-9:UD_6NE;;6%K86IA*KO@8]UC
MX6/>8]QC36069N-GY6GD:1UN2W7!PDYXUGC]>P=\_GL#?`M\_WMZ?7=]^W]#
M@>V!O(??8P6(QHC%B'2-<XURC7B-<Y%ZD1QN=I%UD7>1SY/.D\V3J)28EY*7
ME)>:F+2;ZYWTG?.=[IWRG?"=9*(%J/NG_*?SJ6RLNJUYKWZO>*_TKQ:P5[+(
MM<.USK6SMNVV[K;QM_BW%!ADN&6X-;LINRR[,;LKNRZ[);O:O>"]U+WAO=V]
MY[\2P*[`K\"&P87!T<%8PC_"4L)+PE/"4,)6PE?"S<++PC$R,#+1,QP"DCB0
M.(\XDSB1.'(#$T=_2*Q0<&'E8R-J)&H(;`=L'VX@;B%NX6]4<5=Q57'Z<SAU
MAHTW=5-X?GU[?7'$_7_\?T:!,H?'B'&-@XUOC7Z-?8V!C7R-BI%^D8"1?9%_
MD8*1U)/0D]*3596;EYJ73IKQG?B?_9]>HF:B!:4*J`NH#J@-J!&H":@0J`RH
M$JC$J/>I^*EJJVNKP*W"K86O@*^$KX&OQ*V+L8VQCK&WMKFV[[;[M_^W9[AH
MN&FX/[D\NTR[/;L^NS^[.[O_O0X9]KWNO?R]^+T!OOJ]B+Z`OQ'`_L``P37!
M/&^]P;O!7,):PM'"T,(+-'-9.3X:0.-#AT5W1WA'L5!J6719ZUM[8:5DY&<+
M;`YL#&PY=1!\$7P6?(%]@'W^?P&``(!'@>^!B(V+D8V1AY&%D8^1A)&(D8Z1
MC)'7D]:3GY>(10.>_I_OHPFE"*4@J"2H'ZAPK%:N]Z_XK_:OD+%>LO>SUK75
MM;NV\+8!N&RX0;E"N4^[4[M8NQ*^!+X3O@6^#;Z"OX&_M<"ZP+[!9<)CPF["
M:L)LPL3";#.EEQ)`34@?57=9>%E$77QAZV/J8^QCIV099B-N="`!=!Q\`X!(
M@=J&D8V2C9:1EY&1D9.1V)/5DU>56)6BEP6>^I\,I0JE+J@IJ"^HQ:ARK,BM
M6JY9KHFOB*_;M=FUVK6\MNP7!K@%N&^X;;APN&"[7KMCNUJ[7[L9OAV^&[XB
MOAR^'K[WOH2_%<"XP,'``<$*P=+!=<)TPG+"T#0;0!!$>4?M8[EJ)&[%;@-T
M2H'WAL&'PH>4C9F1FI%:E:B7)9B>F$&@,J@SJ,NMRJW,K9.QX+5QN&N[*[XI
MOAJ^)KXGOBJ^^+X];W;"&#MZ67]A>0[P@9J-EHV>D9V1W)':DPN>`J!"H&>B
MBZ_BM7&[+[XNOL;`CL%[PG?">,)\PGQ9!X"7C=F7#:4.I>.UY+7SMG6X-[XU
MOH_!@,)_PM3"M%#LOW6K$&QI@*21VY/1K8VO=KLYOH3"@L+2-.YC$6R$?72K
MCZ^.KSN^RS*(PH;"7%6D<76LB\(9.Y^8Y;5`OA)L^[Z,PJ5Q=[AXN-;"WY/2
MK1H[J9?3K<K`Q(>QE&2R```````````````T````-0```#8````W````.```
M`#D````Z````.P```#P````]````/@```#\```!`````00```$,```!$````
M10```$8```!'````2````$D```!*````3````$\```!1````4@```%,```!4
M````50```%8```!7````6````%H```!;````7````%X```!?````8@```&4`
M``!F````9P```&@```!I````:@```&L```!L````;@```&\```!P````<0``
M`',```!T````=0```'8```!W````>````'D```!Z````>P```'P```!]````
M?P```((```"#````A@```(<```")````B@```(X```"/````D````)(```"3
M````E````)4```"6````FP```)P```"=````G@```)\```#Z````_P`````"
M```!`@```@(```,"```$`@``!0(```8"```'`@``"`(```D"```*`@``"P(`
M``P"```-`@``#@(```\"```0`@``$0(``!("```3`@``%`(``!4"```6`@``
M%P(``!@"```9`@``&@(``!L"```<`@``'0(``!X"```?`@``(`(``"$"```B
M`@``(P(``"0"```E`@``)@(``"<"```H`@``*0(``"H"```K`@``+`(``"T"
M```N`@``+P(``#`"```Q`@``,@(``#,"```T`@``-0(``#8"```W`@``.`(`
M`#D"```Z`@``.P(``#P"```]`@``/@(``#\"``!``@``00(``$("``!#`@``
M1`(``$4"``!&`@``1P(``$@"``!)`@``2@(``$L"``!,`@``30(``$X"``!/
M`@``4`(``%$"``!2`@``4P(``%0"``!5`@``5@(``%<"``!8`@``60(``%H"
M``!;`@``7`(``%T"``!>`@``7P(``&`"``!A`@``8@(``&,"``!D`@``90(`
M`&8"``!G`@``:`(``&D"``!J`@``:P(``&P"``!M`@``;@(``&\"``!P`@``
M<0(``'("``!S`@``=`(``'4"``!V`@``=P(``'@"``!Y`@``>@(``'L"``!\
M`@``?0(``'X"``!_`@``@`(``($"``""`@``@P(``(0"``"%`@``A@(``(<"
M``"(`@``B0(``(H"``"+`@``C`(``(T"``".`@``CP(``)`"``"1`@``D@(`
M`),"``"4`@``E0(``)8"``"7`@``F`(``)D"``":`@``FP(``)P"``"=`@``
MG@(``)\"``"@`@``H0(``*("``"C`@``I`(``*4"``"F`@``^`(``/D"``#Z
M`@`````````````````"4XQ3U%.E5))3DU/84]E3IU0K62Q9+5DP62Y9JUD!
M&BU<;5PT^@]=_5*=7J)DU&A6;L-N%'/]4AJ:#U,04YI3FU/]4JQ4-@"74T98
M3PYV6'=8KE@Z67U9Q6ZH7OU2^AI!94)EV&C9:*IIJVE";$%LF5#&;OU2-7`V
M<#=P@_I-MOU2M707=H)WMH9)+7*/7)BHF+=%XV@&`/U2YE-$5$54*1<^`,14
MQ53&5,=4R%3)5,I4U%1]6'*ULEBT6()9QUG(6?U2/%L]6SY;/ULD^M-;1U1.
M&CU=XEVX7KE>PEZZ7L9>NUZM9$QE367]4K)ILVFT:;5IPVS$;,5LQFS';/U2
MSFXP;T=P2'"!(EQS_5)?<QAV&79^=A`DL'AU?6@E=GU!@T*$_5*]AD(H0"CJ
M&!Z.'XZ'CV(M>(^(E(F4BI07F169_5+]4I$RY:,)J3NJ3ZK]4BZY+[G_O?V]
M_KV[1;Q%_5(C4^I3*E1)5$I42U3?5.!4X53B5,%8XU3D5.54P%CF5/=4_5+G
M5.A4Z53J5.M4#EB`6(%8NEB[6+Q8O5@_64!9B%D?^D9;_5)'6TA;-EQR7)9<
M1UWG731>-5XV7C=>XU[D7N5>ZUYU`>9>YU[H7OU2_5*Y9.@=NF1;'F-E9&7]
M4F5E_5)F97QE9V5:^EEHZ6CJ:.MH[&CM:.YH[VB_:<MIPVG5:<1IQ6G3:<9I
MQVG(:<EIRFE*;/U2T6QA;C=O_5)D<&9PF2)G<&AP:7"7(G-P:G!K<&(H_5)R
M<SP$N70<=C9VO':^=K]VP':'=]QXW7CU>-YXWWB>^N!XX7CB>"Q]+7VD):E]
MG'V=?9Y]GWV@?:%]HGW]4J-]I'VG?4*#DX-1A/U24H1$A%.$(H;&AL>&R8;=
M^LJ&9BC(AB2.)8XFCOU2)XXHCOU26(_[^J>/B(^)CZ6/J(^ICZJ/JX^LCZV/
MHRUYC_U2E)25E):4I0G]4I>4?S"8E$Z83Y@9F?U209HJ^_>;!)\9GQ>?0*/L
MHQNG'*?V-@ZI4JK8K2:Q=+7]4G6UQKP+O@R^#;X.O@^^$+[(15G76M>#V839
MA=G]4O5*(.$AX2+A(^$DX2GA]%/]4H]H452K%Q=5&%5;51E5&E53`!M5'%4=
M51Y5'U4@52%5BU>(5RTBA5B'M<=83%E-6?Q9_5G^6?]9_5+]4E9;5UM86UE;
MW%O=6W-<G5RA7)Y<GUR@7.9<45U273U>(E^<&R-?)%\E7R9?)U\H7RE?*E\K
M7_U20%\L7RU?+E\O7S!?T&2H991EE66699=EF&6<99ME_5*A9:!EF66:9:=E
MB!YD:/U2`&D!:?U2_5+E:>EI^VG\:>IIZVGL:>UI[FGO:?II\&GQ:?)I\VGT
M:5)L4VQ4;%5L6&Q6;/U2W6S>;.-LWVS@;")N(VYH;M]NK`!$;Y1PE7"6<)=P
MF'"9<'GZFG";<)UPGG"?<*!P\W+R<A]SB'./=)!T_5+]=/YT_W0`=0%U&GG]
M4N-XY'CE>.9XYWCK>.AXZ7CJ>!UYI'RC?-1]QGW'?<A]R7W*?<M]S'W-?=X%
MSGW#);B!N8&Z@6Z#VX/<@VB$:81JA&N$;(1MA&Z$&2<DAB6&_5(`A^6&^8;G
MANB&Z8;^ANJ&ZX;LADD'[8:A*.Z&IBCOAOU2%X?PAO&&E(M;C%R,78POCI$(
M,(XQCC*.,X[,C\V/SH^NCZ^/L(_3",^/T(_1C]*/TX_]4M2/J0FFE*>4J)2P
ME*F4JI2KE*R4K93[E_R7_5(MF2Z94)DOF3"999KFFPR<`IP#G`2<!9P&G/U2
MP)XDGR6?%J`RH""G(:<BIR.G_C8EIQFI)*D:J1NI'*D=J5+['JE:JENJ7*I=
MJEZJ,:S]4BFQ_5*(LHFRB;57/5:VT;?FMS*X,[A2N5.YU0Y4N56Y_5+]4BF^
M*KXKOBR^+;Z2^RZ^+[XPOC&^,KXSOL4^-+Z;Q"/%),7]4B7%)\46R:#/;]??
M17#7<=?<18P3<M=SUW37G-FJV9W9GMF9#*O9G]DUX3CAC?8U4S93[JVT4\GY
M,E155$15155&54=5Y!=(54E5_5)*54M53%5-54Y53U5055%5F;716/U2TEC3
M6-18U5@A6B):(UIH6VE;:EOB6T5<[%SM7.Y<[US]4F)=8UWT76]31%Y%7GE?
M&QQZ7WM??%]]7WY??U^`7X@!_5*!7X)?@U^$7X5?AE^'7X]?B%^)7\5EQF6J
M'L=ER&7)9<IERV7,9:L>S67.9>-ESV709=%ETF739<1EU&759=9E(&@A:!II
M$FD4:15I%FD9:1=I&&G)`F'Z_5(2:A-J%&H5:A9J%VH8:AEJ86QB;&-L]6RI
M(?9L]VSX;"EN%P5=;U=O6&]9;UIO6V^[<-%PO'"]<-^[T'"^<+]PP'#!<,)P
MPW#$<&R^H7.B<Z-SDW0-=0]U#G40=1%U$G65^N5W+WG]4E=Y,'EH>2MY,7E8
M>:+Z,GE9>?U26GDS>5MY7'E=>1YYKGRO?#M]/'T]?0=^"'X)?@I^"WX,?@U^
M#GX/?A!^(GX1?A)^$WX4?A5^%GX7?AA^N/K]4D:#1X-(@^&#@82#A'5?_5*%
MA(:$*H;1^BN&:X88AQF'&H?]4AN''(<=AQZ''X<@AR&'(H<CAQ$I)(<EAR:'
M)X<HARF'*H?OC$F.2HY+CDR.38Y.CD^.4(Y1CE*.4XY4CEJ.58Y?CP*0`Y`$
MD`60U8\&D`>0UH\(D`F0"I`+D->/#)`-D,B4R93*E,N4S)3-E,Z4SY30E-&4
MTI11--.4U)35E-:4UY3BE-B4!)@%F`:8_5)#F429A)J/FH6:AIHOG!J<&YP<
MG+T*'9P>G!^<()PAG"*<+/LCG"2<#IPEG"N<+)P+G.Z=_5+#GMB>V9XXGSF?
M.I\[GU,T/)\]GSZ?/Y]`GTB@3*`HHE&B4J),HR.D1?LDI#&G,J<SIQ@W-*<U
MIS:G0*<WI_U2.*<]ISBI.:DZJ3NI/*E,J7.J=*HS#76J=JIYJD&L0JQ#K%NM
M_5+7.::+7*WEK>:MYZWHK>VM,+%^.S&QE+)1MOVV_K;IM_U2L[F$N92Y_5*<
MN?U2A;D`O#>\5[Q4OFB^5;Y<OE:^5[Y8OEF^6KY;OC3%?D`UQ?U2.<4VQ3?%
M.,7ER%G)_5(ZR3O)*-")T?U2BM&+T8S1C=&\TJ/51!.DU9/7E->5UY;7E]>Y
MV4_A4.%1X7;C_5+[4X-3.%1=5'%5_5)W57A5!_K#57E5>E5[57Q5<E5]5:!5
M?E5_58!5@56"58-5GE6$5855AE6'58A5DU>45Y57[U?P5_U2C5B/6)!8D5B2
M6-Y8X5A366892EI+6DQ:45I-6DA:=%MU6R!<(5RE7*9<<UUT75!>45Y27E->
MVU_<7R`<W5_>7_]?_5+]4M]?X%\A'.%?XE_C7^1?Y5_F7^=?Z%_I7^I?!V8(
M9@EF"F8+9@QF#6;7'AIF#F8/9A!F'&8G:&9HF&B9:#-I)&DE:29I_5+A`CYJ
M9/H_:E=J0&I!:EAJ0FI#:D1J16I&:N("1VIK;&QL$&T1;;XA=6[O;FIO:V_]
M4FQO;6]N;^]P\'#Q</)P\W#T</5P_W#V<`)Q]W`B<\1SPW,H=7P$('8E=B)V
M(W;K=N,$^7?Z=YEYFGF;>6-Y_5)>>5]Y8'F<>6%YG7E4?E5^5GY7?EA^67Y:
M?AE^:GY;?EQ^77YF?OU27GY??AI^8'YA?OU28GX;?F-^$+<1MTR#FX/K@^R#
M[8/N@Z.$J(2FA.P&+X8PAC&&,H8SAD^'48=2AWV'4X=4AU6'5H=7AUB'68=:
MAUN'7(=7*5V'7H=?AV^'8(=AAV*'8X=RAV2'_5)NA[6+98YFCF>.:(YICFJ.
M:XYLC@Z00Y#]4@^01)!%D$:01Y!(D$F0$)!*D$N03)!-D-\(3I!/D%"049!2
MD%.05)!5D%:05Y!8D%F06I`=D%N07)!=D`;[_5+^E/^4`)4!E0*5`Y4$E065
M!I4'E1B5")4)E?.4"I4+E1N5#)4-E0Z5#Y40E0^889AYF,&:K)JMFD.<1)Q%
MG$:<1YQ(G$F<9)Q*G$N<3)Q-G,<*+?LYGE>?6)]9GU^?6I]JH"NB7:)>HE^B
M_5)@HF&B6*-9HTJD2Z1,I$VD3J17I[.FM*9NIUNG7*?]4EVG7J?]4FRG/:E4
MJ3ZI5:E6J3^I5ZE8J5FI6JE;J5RIB*J)JOU26*Q9K%JL_5)GK6BM::UJK?U2
M:ZULK?ZM_ZT`K@&N`JX#K@2N!:XYL3JQ.[$\L?U2_5*RLK.RM+*ULK:RM[*X
MLCP]HK5AMF*V%+?]4NNW0KA(N/U20[A.N$2X1;BTN;6Y_5+]4OU2MKG]4N&[
M!;S]4G,^FK[]4IN^G+Z=OIZ^G[Z:^Z"^H;ZBOK6^H[ZDOOU2I;ZFOJ>^J+ZO
MOJF^JKZKOJR^K;ZSOOU2H,16Q33))Q$\R0S+_5(^SZ//,-`QT)?1F-&9T9K1
MF]&RU:O5K-7\V>C9Z=GJV?':/]S.WVWA;N%OX7#A<>%RX7/AODMXXSKK9U3Z
M)V14950'5L15Q57&5<=5R%7)5>55RE7+5?U2S%7-5<Y5SU7059=7FE>;5^I8
M[%CM6/=8[ECO6%M97%E=66U:;EK]4F]:@5N"6T]<K5P*VGY=:5Y48%5@5F!7
M8*L!6&!98%I@6V!<8%U@_5+]4EY@7V`[9C9F/&8]9CYF/V9`9D%F0F9+`D-F
M1&9%9C=F_5+]4D9F1V9(9DEF+6BE:#UI/VEN;.=J=6IV:G=J>&IY:GIJ>VI\
M:HYJ?6I^:G(@?VJ`:H%J@FJ#:H1JA6J&:H=JB&J):HIJBVJ,:F]L<&QQ;')L
M*FTK;2QM+6TN;2]M,&TQ;8-NA&^%;Y-O_5*&;X=OB&^);XIOBV\V<3AQ.7$Z
M<>(#.W$\<3UQ/G$_<?U20'%!<4)QWG/?<^!SX7-*=4MU3'5-=4YU3W50=2=V
M^7;Z=OMVF'>9=YIW_5(>>)YY]WF?>:!Y\'GX>?EYH7FB>:-YI'FE>?IY^WG\
M>?UY_GD?>O]Y`'J,>@%ZPGS#?/U2TWQ.?:]^L'ZQ?K)^LW[&?K1^_5*U?K9^
MMWZX?KE^NGZ[?KQ^O7Z^?K]^P7[`?L)^PWY1@E*"4X)4@E6"6H-0@U&#>(/X
M@_F#QH3+A,R$S83.A,^$T(31A-*$TX34A-6$_5(WACB&<X:0AY&'OX>2AY.'
ME(>5AY:'EX>8AYF'O2F:AYN'G(>=AYZ'GX>@AZ&'HH>CAZ2'I8?]4J:'IX>_
MB\"+P8O"B\.+Q(O%B\:+=8Q#C1*-GXV1C?;ZDHV3C92-?HY_CH".@8Z"CDR/
M8X_`D,&0PI`ZE<.0Q)#%D,:0%2['D/U2R)!SD,F0RI#+D,R0S9`."?U2_5+.
MD,^0T)#1D-*0TY#4D-60.Y4\E3V5/I7]4C^50)5!E4*50Y7!"4251959E4:5
M1Y5(E?U22943F(*8@YAFF6>999P3,V:<V0IUG'2<9YQMG':<:)QIG&J<:YQ/
MG&R<^)U%GO@S1I[DGH6?;Y]PGX*@@Z"$H(N@+:)HHFFB=Z)DHFJB_5+RHN*B
M8Z-DHV6C9J,].F>C:*/8-?U2<J1]I&FFA*>&IX>GB*>>I_U2B:>*IY:GBZ>,
MIXVG>:F#J7JI7:E[J?U2GZI(#:"JH:JBJOPX:JQKK&RL;:QNK'BM_5)YK7RM
M(:XBKB.N)*XY.B6N)JY1L5*Q5K']4DL\X;+]4OU2UK+7LMBRV;*UM6RV;[9P
MMKRWO;?MMUNX7+A=N%ZXAKF'N>VY_5+NN?U2#KP/O/U2+;TJO2Z]S+WYOOJ^
M^[[\OKD__;X;O_Z^_[X`OP&_`K\#OR&_!+\%OP:_![\(OPF_"K\+OPR_#;\.
MOP^_$+\1OQ*_$[\4OQ6_>\5\Q7W%?L7/0'_%@,5FQ8'%@L6#Q;+(_5)_R7+)
M6LGKRA7+_5(6R\K[%\O]4L7+QLO'RXC,B<S]4HK,B\R,S(W,W\[]4CO0/-`]
MT#[0/]!`T$'00M!<T:_1J=&JT:O1K-&UT:W1KM'BTB35KD3$U?U2ZM?3U]37
MU=>&V?U2A]G]V07;2=Q?W]/?U=^*X8OAC.&-X8[AC^&0X9'ADN&3X7WC?N/K
M2_U2_5+LY%OEA^^&[_U21E-'4P)4;51N5&]4#58.5@]6$%815A)6$U845I]7
MH%>A5Z-7(5@B6'R&E5B66&%99UF16I):DUJ46HI;BUOW6R1<L%RQ7(Y=!%YJ
M7FM>;%YM7NA@#&'I8.I@#6']4NM@[&#M8.Y@[V#P8/%@\F`68?-@!&$=8?1@
M]6#V8/=@L!P"90-E!&6:9GQFQ69]9GYF?V:`9H%F0!]"'X)F@V:$9H5FAF:'
M9JYH36FP:MQJMFJW:KAJN6JZ:KMJVVJ\:KUJOFK]4K]JP&K!:L)JPVK.:@$#
MV6K$:L5JVFK&:L=JR&K):LIJ?FQ[;$YM3VU0;5%M4FU3;51M56V/;OQNIF^G
M;ZAO(W"+<?U2C'&-<8YQCW&D<9E8)'-&<T=S2'/]<_YS_5)N=7QU;W5P=7%U
M<G4I=BIV7W:B=S!X*WAA>@)Z`WH$>@5Z!GH'>OU2"'H)>F)Z"GH+>@QZ#7H.
M>F-Z)WH/>OU2&WID>A!Z$7J!>A)Z97H3>LY\*7_$?BI__5(K?RQ_+7\N?R]_
M,'\Q?S)_,W\T?_U2-7\V?^-^-W\X?SE_.G\[?TU_/'\]?SY__5+0@=&!58,"
MA`2$_(0'A?V$_H3]4O^$`(4(A0&%`H4UA0.%!(7]4CN&B8:!AH*&,[KKA^R'
M_5+MA^Z'[X?]4O"'\8?RARLJ\X<6*O2']8=+4_:']X?XA_F'^H?[A_R'_8?^
MA_^'`(@;*@&(`H@#B`2(!8@&B`>()RH(B`F("H@+B`R(#8C7B]B+*8V<C?B-
MF(ZDCIF.FHZ;CI>.G([U+)V._5*>CI^.98_6D"`),I$SD321@BXUD3:1-Y'7
MD/U2V)`XD3F1.I$[D3R1/9$^D3^10)'9D$&10I$A"4.11)%Z+GR5?95^E7^5
M@)6!E8*5_5*#E825A96&E:65AY6(E8F5BI6+E8R5C96.E?U2_5*/E?U2D)61
ME9*5DY64E965_5(I,9:55IA7F.&8#ID/F7J9>YF+F?*:\YJ3G)2<E9R6G)><
MK9R8G*N<>YR9G)J<FYR%G)R<G9S:"OU2K)QYG)Z<I)S]G>N>ZIZ/GY"?AI^'
MGXB?K*"MH.RB<Z-TH_U2JJ2KI*RDT:;7IKFGNJ>[I[RGCJF/J9"I?*F1J9*I
MDZF4J53[FJF5J9:IEZF]JL>JOJK]4K^J_5*3K%YMAJV'K8BMB:U!KD*N0ZY$
MKD6N1JY*KD>N2*Y)KFNQ9K']4F>QJSMHL:P[_5+]LOZR_[(`LP&S`K,#LP2S
M!;,&LS.UPK70M73[E;:6MC6W-K=GN&BX:;AJN'*X:[ALN&VX;KAON"*Z_5+]
M4B.Z0;HDNB6Z)KHGNBBZ*;JWN?U2_5+]4MJ\S[W:O8F_M[^*OXN_7L",O_U2
MC;^.OX^_D+^1OY*_D[^4O[:_E;^6OY>_]S_]4IB_F;^:O^H/_5*;O[V_G+^=
MOYZ_G[_`OZ"_H;^BOZ._I+^EOZ:_I[^HOZF_JK_]4K3$M<2VQ+G%NL6[Q9'%
MO,7NR._(ELF7R7/)F,F9R>W*[LK>R[#,L<RRS+/,M,RUS+;,SONWS./.N<]5
MT'[05M!7T%C06=!:T/U2Q-'%T<;1Q]'(T<G1[M'/T<K1R]',T0G3VOL#TR_5
M,-4QU3+5#M@/V!#8$=@2V/U2$]@4V!78_]<?VB#:(=HMVOU2&]L<VQW;'MM3
MW%3<5=Q6W&3<6=Q7W/U26-QKWXD4_5+GW^C?Z=_JW^O?[-^62NW?L>&TX?U2
MBN.-XXSC\N3SY/U2"'07Y[(5G^B@Z?U2;>M]@Y#RQ/A,4W14=51V5$E62E9+
M5DQ6359.5D]64%915E)64U945E565E:D5ZE7*E@K6+-:P5J86_M;_%N\7)9=
M"E[]4J)A_5*!88)A@V&$885AAF&'88AAB6&*88MAC&'Q'(UAT6$49<EFRF;+
M9OWMS&;-9LYFSV;09M%FTF;39M1FU69Q:$U38FD.:_YJ_VH`:_U2`6L":P-K
M%6L$:P5K_5*';(EL;FUO;7!M<6UN^G)M<VUT;9UNN&^Y;[IOPG'#<=5QQ''`
M<<5QQG&*=8MUC'5D=HRN020-=ZAW.W@\>#UX/G@_>$!X9GK+>K=ZN'JY>KIZ
M9WJ[>FAZ:7IJ>KQZ_5+;?(%_@G^#?X1_A7^&?X=_B'^)?[_ZBG^+?_U2C'^-
M?XY_CW^0?Z%_D7_6@9^"6(.%@PN$#(0WA3B%SOHYA3J%.X4\A3V%/H5`A4&%
M0H7]4D.%BH:+AI"(68A;B%R(78A>B(HJ7XA@B&&(8HACB&2(DXAEB&:(9XAH
MB&F(:HAKB)6(;(AMB&Z(;XB,*G"(<8ARB'.(=(AUB':(=XAXB'F(@"IZB'\J
M>XBIB'R(\8OKBXJ,/8VFC:>-NH[]4KN.O(Z]CI&1DI&3D921E9&6D9>1VI"8
MD9F1FI']4OU2FY&<D9V1GI&?D:"1OY&AD:*1HY&DD:61II&GD5N1#?NHD<N5
M_5+:"<R53Y;-E<Z5SY5.EM"5T972E?U2TY74E=65UI77E=B5V97ZE=J5VY4<
M^]R5_5+]4MV5WI7?E>"5X97BE>.5Y)7EE=L)YI7GE8Z8F)F9F?U2"IO]4B:;
M)YN]G-^<X@J^G-Z<OYS`G,&<PIR?G,.<Q)S%G,:<QYSC"LB<R9SCG,J<RYS,
MG,V<SIS/G-"<T9S2G-.<+_O4G`2>99[NGJ"?H9_=H-Z@@Z+ZHG^C@*/HI.FD
MZJ2FB.&F_5+;I]RGW:?>I]^GX*?AI^*GXZ?DI^6GYJ><-^>GL*F8J;&IF:FR
MJ;.IM*FUJ;:IMZFXJ;FIXJKCJN2JY:KFJN>JZ*KIJJVLSZRNK*^LL*RQK)*M
MDZV4K7FN>SIZKGNN?*Y]KGZN?ZZ`KH&N@JZ#KH2NE[&$L86QB;&&L8>Q++,M
MLRZS+[,PLS&S,K,SLS2S-;,VLS>STK5$MP"X@[B$N(;[>KI[NGRZ?;I^NOU2
M?[J'NH"Z0[TTP$D2-<`VP#?`.,`YP#K`.\`\P#W`/L`_P$#`0<!"P$/`1,!%
MP$;`1\!(P$G`2L#]4DO`3,!-P$[`Y\7HQ>G%ZL7KQ>S%[<7NQ??(FLG-R<C[
MH\G.R3'+,LLSR^3,_5+ES.;,R,]TT'70=M!WT'C0>=!ZT&'1W]'@T>'1XM'C
MT>31Y='FT?,2,=,]U3[5/]7TU?75]M7]4A?70=A"V$/81-A%V$;81]A(V$G8
M2MA+V-)&NME$VBK<;=QT1^?[?MQNW&_<<-QQW';<>=^@2OU2!.#XWP7@VN';
MX=SAW>'>X=_AX.'AX<7CFN.;XYSCV.39Y-KD;N57%6OG@]#]4M;IO>G]4BZ%
M_.U3\+?PC/6.]O_U=E,&5'Y4A%:%5H96AU:(5J=6B5:*5HM6C%:-5HY6CU:C
M5I!6D5:25I-6K%:45I56EE:J5ZM7GEBI&`A9"5EH66E9:EF:6=E:VEK;6JA;
M`5PH7'=<O5R^7&!BH%VB70]>A5[^8?]A`&(!8A9B`F(#8@1B!6(&8@=B"&(B
M8@EB"F(+8@QB%&(I8FYA#6(.8@]B$&(18A)B$V(;91QE'6439_]F`&<!9P)G
M`V<$9PIG!6<&9P=G"&<Z:'-H;VEP:7%I4E/]4IIM8&MI^BMK)&LL:RUK+FLO
M:S!K,6LR:S-K-&LU:T5K-FN2;)-LB&V);8IMBVT_;OU2RF_V<?=Q^''Y<2MT
M_5*D=,YT_5*>=9]UH'6A=:)UHW6D=:5UIG48=V!X87AB>&-X9'B]>KYZ"WN_
M>L!Z_5(,>XUZ#7L.>UY[#WL0>\%Z$7O]4L)ZZGSK?.-_Y'_E?^9_YW^2?TJ`
M_5+H?^E_ZG\!@.M_['_O?^U_[G_P?_%_\G_S?_1_]7_V?_=_^'_Y?_Y_^G_[
M?_Q_8X5DA66%9H5GA6B%"XD-B;P'#HD/B:0'%(G4B-6(UHC7B-B(V8C:B-N(
MW(C=B-Z(WXC@B.&(XHCCB.2(Y8CFB.>(Z(CIB.J(ZXCLB.R)[8CNB.^(`(GP
MB`2,_5(%C//ZM8WY^M:.UX[8CMF.J9$`D@&2`I(#D@22!9(&DC^2!Y((D@F2
M"I*VD0N2#)+]4OU2#9+]4@Z2#Y(0DA&2$I(UDA.2%)*JD?U2P9(5DA:2%Y(>
MEA^6()8AEOU2(I8CEI4Q))8EEB:6)Y8HEBF6*I8KE@>6+)8MEBZ6Z`G]4B^6
M,)9(EC&6,I:8,3.6_5(TEC66-I99F)&8YYBXF;F9NIF[F<B939N)FU";*)O[
MG/R<_9S^G/^<>#,`G0&=`IWDG.6<`YT$G06=!IT'G1.=")T)G>:<"IT+G0R=
M"Y[TG@J?L9\=H3O[BZ*,HH^BC:*.H@:CAJ,BI2.E)*4EI2:E)Z4HI?&FN3<C
MJ!*H_5(3J!2H%:@6J!>H&*@9J$NH&J@;J!RH_5(=J!ZH'Z@@J,JIK'7+J<RI
MS:G.J?U2SZD0JQ&K$JL3JQ2K#ZL5JQ:K%ZLS.1BKQJR?K:"MI*VAK;6NMJZW
MKKBNN:ZZKM"NQJZ[KKRNO:Z^KK^NP*[!KL*N8/NGL:BQJ;&JL:NQK+&\L:VQ
MKK'`.Z^QL+&QL<$[M+&RL6:S9[-HLVFS:K-KLVRS;;-NLV^S_5(^M3^U0+7H
MM5*W4[=4MU6WD;B2N).XE+B5N):XE[B8N/U2F;B:N)NXM[JXNKFZ_5*ZNKNZ
MO;K]4KRZB/N'^^N[[+L6O$2\X[Q8O5.]5+W@O;'`LL"SP.K`_5*TP/#`M<"V
MP+?`N,"YP+K`N\"\P+W`OL"_P,#`P<#"P,/`_5+$P,7`QL#\P,?`R,#)P,K`
MR\#,P(3!S<#.P,_`T,#1P-+`RL3+Q#;&-\:?QCC&.<8ZQD1!OLGPR;_)P,GW
MROC*^LI#RT3+#\T0S1'-$LVM0Q/-%,T5S1;-_5+]4M//U\_]4K#0F-"0T)'0
MDM"7T)/09-$!T@+2`]($T@72!M('TEK36]-.U4_54-49UAK6&];]4AS6_5(9
MUQK7AA.*W&[8;]AD1G#8<=ARV'/8=-AUV';8.ML[VSS;6ML]VT+;B]R@W(S<
MC=R.W*O<C]QW1Y#<D=R2W*K<KT>3W)3<GMRHW/U2_5(`X@'B`N(#X@3B!>+$
MXL7B_5*NX[+C_5+]4O?D$^6>YH7G@*;(YT'K@>N"ZX/KA.O$[<7MQNV5[Y;O
ME^]8\%GP_5*I\JKRJ_*.]0/VL_:"7E-3@U2$5(54S%;-5LY6SU;05OU2T5;2
M5MI6LU>T5_U2$UD.66M9`UQA7,%<PERU74!4F&*98IIBFV*<8IUBGF*?8NYB
MH&*A8H9B)64T9S5G46<M9V*65&=29VT"-F<W9SAG.6<Z9SMG:&<\9VX"=VB6
MA7YI?VEI:VIK:VML:VUK;FMO:UUK<&N%:W%K<FMS:W1K=6MV:X1K=VN#:YIL
MIVVH;:EMJFVK;:QMMVVM;:YM_5)%;M-OU&_5;]9OUV\F<B=R*'+]4BER*G(%
M<V0CT'2W=?U2N'6Y=2)W(W=S>'1XCWL2>Q-[%'L5>Q9[%WL8>V%[9GMG>QE[
M:'L:>VE[!'T%??U2!GW]?%"`48!2@%.`5(!5@&.`Q/I6@%>`6(!9@%J`6X#]
M4ER`78!>@%^`UX+]4F"#88,7A#F$CX7(A9"%D868AIF&1(E%B4:)68GNB2LK
M1XE(B?U228E*B4N)3(E-B4Z)3XE0B5&)4HE3B52)58E6B16,FHQ8C?R-_8V&
MDH>2B)*)DHJ2BY*,DOU2'Y.-DHZ2CY*0DI&2DI*3DA'[E)*5DLJ1&)+]4I:2
MEY*8DIF2FI*;DIR2G9*>DI^21B_]4J"2H9*:+[>2_5*6EFB6:9:,EFJ6:Y9L
MEFV6;I9OEG^6A)9PEG&6A99REG.6=)9UEG:6_5)WEGB6>99ZEGN6?)8>^Y28
MU9DIFRN=+)TMG2Z=+YTPG3Z=,9TRG3.=-)TUG1&>4PO`GT*A0Z%$H46A1J&,
MHXVCCJ./HY"CD:-CI62E9:7]4DK[_5+VIC:H-Z@LJ#BH.:C]4CJHXZGBJ?6I
M1ZO]4DBK2:M*JTNK3*NHK:FMJJW]4@NO!J]SKPRO#:\.KP^O$*_]4A&O8OL2
MKQ2O%:\6K_U2$Z\7K]FQVK';L?U2W+&FLZ>SJ+.ILZJSJ[/]4FW[K+.MLZZS
M_5+]4J^SL+.QLT2U1;7WM?BU:[=LMV&W$KBON+"XL;BRN+.XM+BUN+:X(KGJ
MNNNZ[+KMNCT/[;L;O$>\Z+S0O>>]Z+WIO4[!3\%0P7+!4<%2P:?[)A!3P53!
M5<%6P5?!=\%8P5G!6L%;P5S!;L%=P2<0_5)>P2@07\']4M?$B<:*QOU2OON+
MQHS&C<:.QKS[C\;]4IK&D,:1QI+&D\82RO')_5+^ROO*5\M)S4K-2\U,S?U2
M3<U9S4[-3\WTSF7/IM"GT*C0(M(CTHO3C-.-TX[36-7]4EG5.]8\UCW6/M9(
MUY38E=B6V)?8F-A]VO[9?MI_VOU26]M<V^3<P=S]W,+<UMS#W,3<_5+<W,7<
MQMS'W.'<R-S)W,K<R]SR1\S<S=PUX#;@1^`WX!OB'.(=XA[B'^(@XGOB>N+^
MXL;CQ^/(X\GCRN/]4J#GH>?,Z,WH\>G7Z4+K1NNCZZ7KINO+[<SM)NXG[BCN
M*>ZN[Z_OL.]S\/U2?/!T\/U2@/)U\'E,_5+/\OU2C_9P6853EU;V5O=6^%;Z
M5OM6NE>[5[Q7O5<T6#58HE@461%9;EEO60A;N%L)7;U=OEV(7OYB>AW_8@!C
M`6,"8P-C!&,%8P9C_5('8PAC"6,*8PMC#&,-8PYC#V/]4OU2_5(L96MG_5)L
M9X=G;6=X:(MII&NE:Z9KIVN^:ZAKJ6NJ:XUKJVNL:[]K_5(L`ZUKKFND;*5L
MQVW(;<EMO-#*;<MMS&W-;<YM&6_F;TQR37).<@9S_5+-=<YUSW70=5PD@7B"
M>#-8:GMK>[)[;'MM>\Q[KGNS>Y%[_5)N>[1[;WO)@*>`J("I@*J`JX"L@*V`
MKH"O@+"`8("Q@.&!XX+V@MDFKX6PA;&%NH6RA;.%3(;]4J"&H8:PB;&)LHFS
MB;2)Z_JUB;:)MXFXB;F)NHER*[N)O(F]B;Z)OXG?B<")P8G"B<.)Q(EX*_U2
MQ8G&B<>)R(G)B<J)/(K+B<R)S8G.B<^)T(G1B5HL'8P>C&2-98W%C<:-QXW_
MC?^.`(\!CP*/]9)<D_:2]Y*PDOB2^9)=DU"3^I+[DJ*2_)+]DOZ2_Y(3^P"3
M'_O!EL*6PY;$EL66QI;'ELB6R9;*ELN6[^/7ELR6S9;.EB*7SY;0EOU2T9;2
MENF6TY;4EM66.)@[8WV;;UBAFU.=5)W["E6=/)U6G?U29IW\"E>=6)U9G5J=
M6YUGG5R=_5+]4FJ=79T]G5Z=99WAG\V?$?-OH7"A&J.:HYNCG*.>HY^C/_N.
MI?U2_:;]4EZH7ZA@J&6H9ZAHJ&FH_5)JJ(^H:ZALJ&VH]ZGXJ?FIY*GZJ;&K
M=:MVJ_^L`*T!K0*M`ZVNK:VM4:]2K_U24Z]4KU6O5J]7KUBO6:]:KUNO7*]=
MKUZO7Z]@KV&O8J]CKV2O3*]FK_&Q\K'RL_.S]+/UL_:S][/XL_FS^K-,M4NU
M&[;.MK.V?[=Y^WS[&KC$N,6XQKC'N,BXR;C]4AF['+L:NTR\CKQ^O>O![,'M
MP>[![\'PP?'!V,'9P=K!V\'RP?/!],$'POU2K/O]4O7!%<+]4O;!]\'XP?G!
M^L'[P?S!_<'^P:?"_\$`P@'"`L(#P@3"!<+IQ.K$Z\3>QM_&_5+@QN'&XL;C
MQC[*/\I`RD'*<<MRRW/+B,V)S8K-B\V,S8W-CLV/S9#-D<V2S?U2\<^^T+_0
MP-#!T,+0P]!NT3?25](XTCG2.M([TCS2/=(^TB?2/]+]4OU2P-/!T[Y$9]7]
M4FC56-9EUEG66M8DU\W8SMC/V-+8G]HBVGW;?MO_W"7=`-T!W3M(`MT#W03=
M*%$%W0;=!]T6W0C=%]T)W0K=0$@+W0S=*=TZ2`W=_5(.W1#=$=T=W1+=$]W]
M4A3=%=V-WU3@5>!6X#/B-.(UXC;B^N+CX^;C[>/GX^CCZ>/JX^OC)^4@Y?C[
M*N?)Y_U2RN?+Y]GGS.?-Y\[G_5+AZ!OJ'.H=ZA[J1^O1Z\GKT.W1[3_N0.Y!
M[@G\0N[$[YOPDO"3\)9,E/"5\/U2_5+S\O3R]?+V\F#UGO6@]:'U'/:?]E93
M$E<?5Q57%E<75PSZ&%?"5\-7Q%>A6!M9'%EQ61-;%UZ/7E]C8&.L8_U2_5)A
M8V)C8V-D8V5C_5*99YIGFV><9YUGGF>?9Z!GVFO;:]QKW6O>:]]KU6W6;==M
MV&W@;;1N_5)N<F]R<')C=/U2U776===UV'4P=[5[MGO!>_=[H`7+>^A[_5+I
M>[=[%7WF@.>`Z(#I@.J`ZX#*^@N##(-D@]2%U876A=B%I89;4P^*$(K]4A&*
M$HH3BA2*%8H6BA>*&(H9BAJ*+XH;BAR*/XH=BAZ*+(H?BB2,I(REC%&U_HT1
MCQ*/$X]4CUZ3(9,_DT"309-"DT.31),@DT63_5)&D["31Y-7DP&3L9-:DTB3
M!)<%E_4Q3Y=0EP:7!Y<(EPF7"I<+EPR7#9<.EP^7$)<1ES.8-)@UF/R8_9BP
MF[&;LINSFP$+>YU\G7V=?IU_G8"=@9V"G?F>VI^AH?U2_5*MHZZC_5+(I<FE
MRJ6"J(.HA*B%J(:HAZB(J(FHBJC]4@>J"*H!J@FJ`JH*J@NJ#*JGJYBKF:N:
MJYNKG*M0.9VK&JVRK;"OL:\4.[*OLZ^TK[6OMJ_`K[>ON*^YK[JO';`,L@VR
M#K(UL@^R$+(1LA*R(K0CM"2T_5(EM":T)[0HM"FT*K0KM"RT+;0NM%*U4[49
MMK^VB[>,MR.X)+CQN-BX?_M.NT^[5;M0NU&[4KM3NP*[5+OQNR2\T;U\PGW"
M?L)_PH#"G\*!PH+"@\*$PH7"AL*'PHC"F\*)PHK"B\*,POU2H<*-PH["\\3T
MQ/7$),<EQR;')\<HQRG'*L?]4BO'S<@!R8UX<,J`RX'+P,W!S<+-P\W$S<7-
MQLW'S<C-_L_]4MG0W-#:T'716-)9TEK26])<TNS3&A/STW+5<]6"UH/6*M<K
MURS7+=?VV`#9]]CXV/G8_5*4VY7;EML;W(;=3-U-W8/=_5*"W4[=3]U0W5'=
M@=V'2%+=4]U4W57=_5)6W5?=A4A8W5O=7-U=W5[=7]U@W6'=?-UBW3P4_5)C
MW63=<^!%XD;B1^),XA+C_5(3XSGD`^0-Y##EU>7`YO+G\^?TY_7G]N?WY_KH
M^^A%ZD;J2>OGZ^CKV.W9[57N5NY7[MKOV^_<[[CPN?"Z\+%,N_")\KSP,/,Q
M\S+S,_/]4C3S-?,V\T=.-_.R]9#V)O:B]CCW_5(N5_U2+U<P5RI7*U?)5S=8
M(%ER61];95S*7,!=P5W"7;=CN&.Y8[ICNV/]4OU2O&.]8[YC\F.U9[=GN&??
M8[EGU6>Z9[MG2FCR:_-K]&OZ:_5K`FSB;>-MCG*+<N1UZW7E=35WDWCJ>^M[
M_5+L>^U[%WSN>^][\'L.@0^!$($9@1B!$8$2@1.!Q_H4@16!:P86@66#ZH7K
MA>R%[87]4NZ%K(;"BFF*@8IJBFN*;(IMBFZ*;XIPBO0'<8IRBG.*C(ITBG6*
M=HHDCRJ/CI.ODX^3D).1D_U2DI.3DY23E9.6DY>3F).9DYJ3FY.<DSF7.Y<Z
MESR7/9<^ES^7<)=`ET&7P)O!FZ2=EYVEG9B=F9V:G?U2FYVFG9R=G9V>G9^=
MSMW(G:"=&9X-G[^CZ:7JI:*HHZBDJ*6HIJ@5JA>JOZO`J\&KPJO#J\2KQ:L-
M;".MOJT#L`2P!;`&L`>P"+`)L`JP"[`,L""P#;`.L`^P_5(FLB>R*+)=M%ZT
M7[1@M&&T8K1CM&2T9;17M<^VT+:9MYJWZKCKN.RX?KM_NX"[_5+]4H&[@KOS
MNR6\G[R@O/.\`+WKPNS"[<+NPN_"_5)<$/#"\<+RPO/"],+UPOG"^L+[POS"
M_<+^PO_"`,.N^P'#`L,#Q8;'><?]4GK'>\=\QX3'?<=^QW_'ALJ'R@#+`<N(
MRXG+BLOUS?U2)<[VS>O0[-#MT.[0AQ+OT/#0;-(AU"+4(]0DU"74)M1[U7S5
MD=:2UI/6#MD/V1#9L]LVW,;=H=VBW;E(H]W,W:3=I=VFW<O=I]W]4JC=J=VJ
MW?U2J]VLW:W=OTBNW:_=L-V,X(W@CN#Q^Y+@C^!2XE/B5.)5XBGD_5+SY?3E
M#>@.Z`_H$.@4Z7'J<NH/[`3L!NS]4@?LW.W=[6WN>>YN[OU2[._=\-[PW_#@
M\.'PXO#C\.3P.O'E\,],YO!K\VSS3I=D3KWUOO6_]33VOT\2^$!705<"9`-D
M!&0%9`9DUV?,9YAI!FP';*]LL&SJ;?)MHG*C<J1R=G3U=?9U]W7]4CM\)7PZ
M?#Q\/7P^?#>!.($Y@3J!.X$\@3V!/H$_@4N!_5)`@2*#9X/3@_J%_5*\BOU2
M_5*EB@<(MHK]4J:*NXJGBJB*J8JJBJN*K(J_BJV*KHJOBBZ,`(Z=DYZ3RY/,
MD\V3SI//D_U2GY/0D]&3TI/3D]23_5+]4EV77I=?EV"7!0NZG;R=!@NUG;V=
MMIVWG;B=J)TR^_Z>_)[AH<2CQ:,4IJZHKZBPJ+&HN:CGJT:P_5)'L$BP2;`>
ML!^P2K!+L$RP3;!.L/U21K)+LI"TD;3]4I*TD[24M%NU\KCXN/FXE+NDNY>[
MF+LIO*Z\K[U9PUK#_5);PUS#7<->PU_#8,-APZK"8L-CPV3#9<-FPV?#:,-I
MPVK#:\-LPVW#;L-OP_U2LL>SQ[3'^1"UQ[;'M\>XQ[G'NL>[QXC*N$(9SAK.
M&\X6SPS1#=$.T0_1_5*#TH32A=*#U835L-;]4B;9)]DVV2C9*=G]4OU2Y]WH
MW>G=4Q3JW>O=_5+LW>W=[MWOW?#=\=T,WO+=\]WTW?7=]MWWW?C=H^"DX*7@
MIN"GX/U27.+]4DODX>05YOU2%N87YBSH+>@BZ2/IENJ7ZOU2+NPP[#'L_5+?
M[8ONC.[]4HWN_._][_[O_^\7\2WQ&/'S3!GQ_5(2\1KQ&_$<\6D6_5*7\^46
MF/.9\_U2Q/9/5\U7QUT<9!UD'F3G9^EGZF?K9Q5L\6_R;[9RH'A*?"!]8(%A
M@4&!8H$#A@2&V8K:BMN*W(K=BOU2WHK?BN"*X8KBBA((XXK]4C&/!90&E`>4
M<I>*EXN7B)?]4HR7C9>.EX^7D)="F$.8_5+!G<*=PYW$G<NC(J;]4OU2PZC$
MJ,6HQJ@>JB6J\ZOTJ_U2]:LXK4BMRJU/.WJP>[!5LE:RL;2RM+.T_5*TM+6T
MI+<`N0&Y`KFLN_U2L[RVP[?#N,.YP[K#N\.\P[W#OL._P\##P</"P\/#Q,/%
MP\;#Q\/CQ^3'Y<?FQ^?'_5*URJ'*E<L[SCS./<X^SA3/(-$AT2+1(]$DT9;2
ME]*8TI34E=26U)?4F-2/U9#5O-8[USW9_5+?VQ[<(]XDWDG>)=XFWB?>*-XE
M22G>*MXNWB_>3MXPWNO[,=XRWC/>--XUWC;>_5(WWE#>.-[]4CG>.MX[WCS>
M/=X^WKC@N>!BXF/B0>-MY/U24N8WYMOF/^@TZ5OK1NQ:[%OLX>WB[>/MY.VG
M[JCNJ>X/\"OP5O%7\5CQ7O%9\5KQ6_%<\?U2:/']4BSTXO/S\]+U5O;.]F'W
MF_FT^5Q7$/K25W%8<UDL6Y1>_5(_9$!D^6?Z9_UG^V<<;!UL_VT`;O=O_I_]
M4K9W5'QW@7F!>H%[@6F#`HL#BP2+!8L&BP>+"(L)BPJ+"XLUB_U2.8\>E!^4
M()0AE/U2(I0CE"24+)2SE[67MI>WE[B7T)WZGP>BO:+7H]*CVZC6J%U70ZW/
MK:.PI+"EL*:PI["HL*FP7;)>LLFTRK3+M,RT!KD'N?U2Q;OUN[2\N+RUO/W#
M=Q#^P__#`,0!Q`+$`\0)Q`3$!<0&Q`?$$<@2R!/(%,@5R'="F,N9RSS1+=$N
MT?U2N]2\U'@3/=='V4C92=E*V>':Y]KKVR#<.-QBWF?>:-YIWFK>:]YMWF[>
M;]YPWG'><MZ/WG/>=-YUWG;>=][)X,K@YDK+X,S@S>!1X_U2_5)%Y5GH6NA;
MZ$#IS^I>ZWOLD^V\[A;P,/#]4HWQCO$O38_QD/&1\9+QD_&4\97QEO$C]!3T
MV_4*]\[X9E=H5V=7TU=C9`1HGFDF;"IL;'QD?(^!D($T@PZ&)8LFBR>+_5(H
MBPPL_5(IBRJ+*XLLBSZ/0I1#E#.4P9?"E\.7UIW7G>&HXJ@KJM&MS+#-L,ZP
MS[#>M-^TX+3AM/:[+,3]4E3$+<0NQ$'(0LC'RJ#+H<MPSG'.<L[]4C31-=$V
MT:;2S-3]4IG5]-N;WI[>G]Z@WJ'>HMZCWJ3>I=ZFWJ?>J-[;X-S@W>#7X-[@
MW^!9XT;G9>A)Z?U2W>J5[);LE^S4[M;N)O!'38@6R/'%\<;QQ_%1]%+T4_14
M]%7TWO7]4FU7U5=R9*YT#W9K?&U\;GQX?)B!F8&:@42+7(M%BP&.6)19E%J4
M_5+9E]:7VIW?G=N=`Z#OJ#8X,ZK2K>&P;[)DM0ZY4,11Q%+$5LA7R%C(_5*!
MSH+.'<\>ST/1JM+]V_U2QM['WMG>U][]4LC>R=[*WLO>VM[]4LS>S=[.WL_>
MT-[1WKS>X>#BX./@J>1.Y7?H_5+]4JSLK>RV[>7N^/'J\8WRZ_&5]&Y7V%>#
M9*-I,&P/;GE\>GRG@:B!J8&J@1F&4(M1BU*+%2QHBU.+5(OBF]R=%:P6K$^M
M];#VL/>P]+3,MP^Y9L1GQ/U2:,2DRXO.C,[ZU.;>[=[NWN_>\-[^WN?@Z."S
MY.3D@^CL[?U2%O+]4OU2%_+#]*ST[?7]4OU2M/C]4HIDBV0T;!1NWW*[=W]\
M@7RM@:Z!8HMNB_U2;I3]4A>:YIT0GQFL_5(0N?*]=L1WQ)7.ELX`WP'?,=_M
M^QS?;>/T[O7N/?`R\C/R]/7]4G-7-VS]4G&+#[']4@ZQ$;F%Q!3?%=\6WQ??
M&-\9WQK?P^1"\D/R1/)(\OOTI6FX;+*!/8-RB^>7Z)=9ICJJ%+'_M,"\C<2$
M$([$_5(BW_U2_5($[RGO4?)F\@[U$_S]4IMDG&06=H9\AWS]4BS?,-\HWU_I
M_5)^E!FQ"M4VW_S@;?)N\L;YM1I[BP:UG\@R]0W5BWP[W_U2/?4\WSW?````
M````````````````````````````````````0*A!J$*H7*E#J$2H1:A&J$>H
M2*A9J4FH2JA+J$RH3:A.J$^H4*A1J%*HDJA3J%2H5:A6J%>H6*A9J%JH6ZA<
MJ%VH7JA?J&"H8:ABJ&.H9*AEJ&:H9ZAHJ&FH:JAKJ&RH;:ANJ&^H<*AQJ'*H
M<ZATJ'6H=JAWJ'BH>:AZJ'NH?*A]J'ZH@*B!J(*H@ZB$J(6HAJB'J(BHB:B*
MJ(NHC*B-J(ZHCZB0J)&H9:F6J9.HE*B5J$"I0:E"J4.I1*E%J4:I1ZE(J6&I
M8JEFJ6>I8*ECJ62I6JE)J4JI2ZE,J4VI3JE/J5"I4:E2J5.I5*E`@4&!0H%#
M@42!18%&@4>!2(%)@4J!2X%,@4V!3H%/@5"!48%2@5.!5(%5@5:!5X%8@5F!
M6H%;@5R!78%>@5^!8(%A@6*!8X%D@66!9H%G@6B!:8%J@6N!;(%M@6Z!;X%P
M@7&!<H%S@72!=8%V@7>!>(%Y@7J!>X%\@7V!?H&`@8&!@H&#@82!A8&&@8>!
MB(&)@8J!BX&,@8V!CH&/@9"!D8&2@9.!E(&5@9:!EX&8@9F!FH&;@9R!G8&>
M@9^!H(&A@:*!HX&D@:6!IH&G@:B!J8&J@:N!K(&M@:Z!KX&P@;&!LH&S@;2!
MM8&V@;>!N(&Y@;J!NX&\@;V!OH&_@<"!P8'"@<.!Q('%@<:!QX'(@<F!RH'+
M@<R!S8'.@<^!T('1@=*!TX'4@=6!UH'7@=B!V8':@=N!W('=@=Z!WX'@@>&!
MXH'C@>2!Y8'F@>>!Z('I@>J!ZX'L@>V![H'O@?"!\8'R@?.!]('U@?:!]X'X
M@?F!^H'[@?R!_8'^@4""08)"@D."1()%@D:"1X)(@DF"2H)+@DR"38).@D^"
M4()1@E*"4X)4@E6"5H)7@EB"68):@EN"7()=@EZ"7X)@@F&"8H)C@F2"98)F
M@F>":()I@FJ":X)L@FV";H)O@G""<8)R@G."=()U@G:"=X)X@GF">H)[@GR"
M?8)^@H""@8*"@H."A(*%@H:"AX*(@HF"BH*+@HR"C8*.@H^"D(*1@I*"DX*4
M@I6"EH*7@IB"F8*:@IN"G(*=@IZ"GX*@@J&"HH*C@J2"I8*F@J>"J(*I@JJ"
MJX*L@JV"KH*O@K""L8*R@K."M(*U@K:"MX*X@KF"NH*[@KR"O8*^@K^"P(+!
M@L*"PX+$@L6"QH+'@LB"R8+*@LN"S(+-@LZ"SX+0@M&"TH+3@M2"U8+6@M>"
MV(+9@MJ"VX+<@MV"WH+?@N""X8+B@N."Y(+E@N:"YX+H@NF"ZH+K@NR"[8+N
M@N^"\(+Q@O*"\X+T@O6"]H+W@OB"^8+Z@ON"_(+]@OZ"0(-!@T*#0X-$@T6#
M1H-'@TB#28-*@TN#3(--@TZ#3X-0@U&#4H-3@U2#58-6@U>#6(-9@UJ#6X-<
M@UV#7H-?@V"#88-B@V.#9(-E@V:#9X-H@VF#:H-K@VR#;8-N@V^#<(-Q@W*#
M<X-T@W6#=H-W@WB#>8-Z@WN#?(-]@WZ#@(.!@X*#@X.$@X6#AH.'@XB#B8.*
M@XN#C(.-@XZ#CX.0@Y&#DH.3@Y2#E8.6@Y>#F(.9@YJ#FX.<@YV#GH.?@Z"#
MH8.B@Z.#I(.E@Z:#IX.H@ZF#JH.K@ZR#K8.N@Z^#L(.Q@[*#LX.T@[6#MH.W
M@[B#N8.Z@[N#O(.]@[Z#OX/`@\&#PH/#@\2#Q8/&@\>#R(/)@\J#RX/,@\V#
MSH//@]"#T8/2@].#U(/5@]:#UX/8@]F#VH/;@]R#W8/>@]^#X(/A@^*#XX/D
M@^6#YH/G@^B#Z8/J@^N#[(/M@^Z#[X/P@_&#\H/S@_2#]8/V@_>#^(/Y@_J#
M^X/\@_V#_H-`A$&$0H1#A$2$181&A$>$2(1)A$J$2X1,A$V$3H1/A%"$4812
MA%.$5(15A%:$5X18A%F$6H1;A%R$781>A%^$8(1AA&*$8X1DA&6$9H1GA&B$
M:81JA&N$;(1MA&Z$;X1PA'&$<H1SA'2$=81VA'>$>(1YA'J$>X1\A'V$?H2`
MA(&$@H2#A(2$A82&A(>$B(2)A(J$BX2,A(V$CH2/A)"$D822A).$E(25A):$
MEX28A)F$FH2;A)R$G82>A)^$H(2AA**$HX2DA*6$IH2GA*B$J82JA*N$K(2M
MA*Z$KX2PA+&$LH2SA+2$M82VA+>$N(2YA+J$NX2\A+V$OH2_A,"$P83"A,.$
MQ(3%A,:$QX3(A,F$RH3+A,R$S83.A,^$T(31A-*$TX34A-6$UH37A-B$V83:
MA-N$W(3=A-Z$WX3@A.&$XH3CA.2$Y83FA.>$Z(3IA.J$ZX3LA.V$[H3OA/"$
M\83RA/.$](3UA/:$]X3XA/F$^H3[A/R$_83^A$"%085"A4.%1(5%A4:%1X5(
MA4F%2H5+A4R%385.A4^%4(51A5*%4X54A56%5H57A5B%685:A5N%7(5=A5Z%
M7X5@A6&%8H5CA62%985FA6>%:(5IA6J%:X5LA6V%;H5OA7"%<85RA7.%=(5U
MA7:%=X5XA7F%>H5[A7R%?85^A8"%@86"A8.%A(6%A8:%AX6(A8F%BH6+A8R%
MC86.A8^%D(61A9*%DX64A96%EH67A9B%F86:A9N%G(6=A9Z%GX6@A:&%HH6C
MA:2%I86FA:>%J(6IA:J%JX6LA:V%KH6OA;"%L86RA;.%M(6UA;:%MX6XA;F%
MNH6[A;R%O86^A;^%P(7!A<*%PX7$A<6%QH7'A<B%R87*A<N%S(7-A<Z%SX70
MA=&%TH73A=2%U876A=>%V(79A=J%VX7<A=V%WH7?A>"%X87BA>.%Y(7EA>:%
MYX7HA>F%ZH7KA>R%[87NA>^%\(7QA?*%\X7TA?6%]H7WA?B%^87ZA?N%_(7]
MA?Z%0(9!AD*&0X9$AD6&1H9'ADB&289*ADN&3(9-ADZ&3X90AE&&4H93AE2&
M5896AE>&6(99AEJ&6X9<AEV&7H9?AF"&889BAF.&9(9EAF:&9X9HAFF&:H9K
MAFR&;89NAF^&<(9QAG*&<X9TAG6&=H9WAGB&>89ZAGN&?(9]AGZ&@(:!AH*&
M@X:$AH6&AH:'AHB&B8:*AHN&C(:-AHZ&CX:0AI&&DH:3AI2&E8:6AI>&F(:9
MAIJ&FX:<AIV&GH:?AJ"&H8:BAJ.&I(:EAJ:&IX:HAJF&JH:KAJR&K8:NAJ^&
ML(:QAK*&LX:TAK6&MH:WAKB&N8:ZAKN&O(:]AKZ&OX;`AL&&PH;#AL2&Q8;&
MAL>&R(;)ALJ&RX;,ALV&SH;/AM"&T8;2AM.&U(;5AM:&UX;8AMF&VH;;AMR&
MW8;>AM^&X(;AAN*&XX;DAN6&YH;GANB&Z8;JANN&[(;MANZ&[X;PAO&&\H;S
MAO2&]8;VAO>&^(;YAOJ&^X;\AOV&_H9`AT&'0H=#AT2'18=&AT>'2(=)ATJ'
M2X=,ATV'3H=/AU"'48=2AU.'5(=5AU:'5X=8AUF'6H=;AUR'78=>AU^'8(=A
MAV*'8X=DAV6'9H=GAVB':8=JAVN';(=MAVZ';X=PAW&'<H=SAW2'=8=VAW>'
M>(=YAWJ'>X=\AWV'?H>`AX&'@H>#AX2'A8>&AX>'B(>)AXJ'BX>,AXV'CH>/
MAY"'D8>2AY.'E(>5AY:'EX>8AYF'FH>;AYR'G8>>AY^'H(>AAZ*'HX>DAZ6'
MIH>GAZB'J8>JAZN'K(>MAZZ'KX>PA[&'LH>SA[2'M8>VA[>'N(>YA[J'NX>\
MA[V'OH>_A\"'P8?"A\.'Q(?%A\:'QX?(A\F'RH?+A\R'S8?.A\^'T(?1A]*'
MTX?4A]6'UH?7A]B'V8?:A]N'W(?=A]Z'WX?@A^&'XH?CA^2'Y8?FA^>'Z(?I
MA^J'ZX?LA^V'[H?OA_"'\8?RA_.'](?UA_:']X?XA_F'^H?[A_R'_8?^AT"(
M08A"B$.(1(A%B$:(1XA(B$F(2HA+B$R(38A.B$^(4(A1B%*(4XA4B%6(5HA7
MB%B(68A:B%N(7(A=B%Z(7XA@B&&(8HACB&2(98AFB&>(:(AIB&J(:XALB&V(
M;HAOB'"(<8ARB'.(=(AUB':(=XAXB'F(>HA[B'R(?8A^B("(@8B"B(.(A(B%
MB(:(AXB(B(F(BHB+B(R(C8B.B(^(D(B1B)*(DXB4B)6(EHB7B)B(F8B:B)N(
MG(B=B)Z(GXB@B*&(HHBCB*2(I8BFB*>(J(BIB*J(JXBLB*V(KHBOB+"(L8BR
MB+.(M(BUB+:(MXBXB+F(NHB[B+R(O8B^B+^(P(C!B,*(PXC$B,6(QHC'B,B(
MR8C*B,N(S(C-B,Z(SXC0B-&(THC3B-2(U8C6B->(V(C9B-J(VXC<B-V(WHC?
MB."(X8CBB..(Y(CEB.:(YXCHB.F(ZHCKB.R([8CNB.^(\(CQB/*(\XCTB/6(
M]HCWB/B(^8CZB/N(_(C]B/Z(0(E!B4*)0XE$B46)1HE'B4B)28E*B4N)3(E-
MB4Z)3XE0B5&)4HE3B52)58E6B5>)6(E9B5J)6XE<B5V)7HE?B6")88EBB6.)
M9(EEB6:)9XEHB6F):HEKB6R);8ENB6^)<(EQB7*)<XETB76)=HEWB7B)>8EZ
MB7N)?(E]B7Z)@(F!B8*)@XF$B86)AHF'B8B)B8F*B8N)C(F-B8Z)CXF0B9&)
MDHF3B92)E8F6B9>)F(F9B9J)FXF<B9V)GHF?B:")H8FBB:.)I(FEB::)IXFH
MB:F)JHFKB:R)K8FNB:^)L(FQB;*)LXFTB;6)MHFWB;B)N8FZB;N)O(F]B;Z)
MOXG`B<&)PHG#B<2)Q8G&B<>)R(G)B<J)RXG,B<V)SHG/B=")T8G2B=.)U(G5
MB=:)UXG8B=F)VHG;B=R)W8G>B=^)X(GAB>*)XXGDB>6)YHGGB>B)Z8GJB>N)
M[(GMB>Z)[XGPB?&)\HGSB?2)]8GVB?>)^(GYB?J)^XG\B?V)_HE`BD&*0HI#
MBD2*18I&BD>*2(I)BDJ*2XI,BDV*3HI/BE"*48I2BE.*5(I5BE:*5XI8BEF*
M6HI;BER*78I>BE^*8(IABF**8XIDBF6*9HIGBFB*:8IJBFN*;(IMBFZ*;XIP
MBG&*<HISBG2*=8IVBG>*>(IYBGJ*>XI\BGV*?HJ`BH&*@HJ#BH2*A8J&BH>*
MB(J)BHJ*BXJ,BHV*CHJ/BI"*D8J2BI.*E(J5BI:*EXJ8BIF*FHJ;BIR*G8J>
MBI^*H(JABJ**HXJDBJ6*IHJGBJB*J8JJBJN*K(JMBJZ*KXJPBK&*LHJSBK2*
MM8JVBK>*N(JYBKJ*NXJ\BKV*OHJ_BL"*P8K"BL.*Q(K%BL:*QXK(BLF*RHK+
MBLR*S8K.BL^*T(K1BM**TXK4BM6*UHK7BMB*V8K:BMN*W(K=BMZ*WXK@BN&*
MXHKCBN2*Y8KFBN>*Z(KIBNJ*ZXKLBNV*[HKOBO"*\8KRBO.*](KUBO:*]XKX
MBOF*^HK[BOR*_8K^BD"+08M"BT.+1(M%BT:+1XM(BTF+2HM+BTR+38M.BT^+
M4(M1BU*+4XM4BU6+5HM7BUB+68M:BUN+7(M=BUZ+7XM@BV&+8HMCBV2+98MF
MBV>+:(MIBVJ+:XMLBVV+;HMOBW"+<8MRBW.+=(MUBW:+=XMXBWF+>HM[BWR+
M?8M^BX"+@8N"BX.+A(N%BX:+AXN(BXF+BHN+BXR+C8N.BX^+D(N1BY*+DXN4
MBY6+EHN7BYB+F8N:BYN+G(N=BYZ+GXN@BZ&+HHNCBZ2+I8NFBZ>+J(NIBZJ+
MJXNLBZV+KHNOB["+L8NRB[.+M(NUB[:+MXNXB[F+NHN[B[R+O8N^B[^+P(O!
MB\*+PXO$B\6+QHO'B\B+R8O*B\N+S(O-B\Z+SXO0B]&+THO3B]2+U8O6B]>+
MV(O9B]J+VXO<B]V+WHO?B^"+X8OBB^.+Y(OEB^:+YXOHB^F+ZHOKB^R+[8ON
MB^^+\(OQB_*+\XOTB_6+]HOWB_B+^8OZB_N+_(O]B_Z+0(Q!C$*,0XQ$C$6,
M1HQ'C$B,28Q*C$N,3(Q-C$Z,3XQ0C%&,4HQ3C%2,58Q6C%>,6(Q9C%J,6XQ<
MC%V,7HQ?C&",88QBC&.,9(QEC&:,9XQHC&F,:HQKC&R,;8QNC&^,<(QQC'*,
M<XQTC'6,=HQWC'B,>8QZC'N,?(Q]C'Z,@(R!C(*,@XR$C(6,AHR'C(B,B8R*
MC(N,C(R-C(Z,CXR0C)&,DHR3C)2,E8R6C)>,F(R9C)J,FXR<C)V,GHR?C*",
MH8RBC*.,I(REC*:,IXRHC*F,JHRKC*R,K8RNC*^,L(RQC+*,LXRTC+6,MHRW
MC+B,N8RZC+N,O(R]C+Z,OXS`C,&,PHS#C,2,Q8S&C,>,R(S)C,J,RXS,C,V,
MSHS/C-",T8S2C-.,U(S5C-:,UXS8C-F,VHS;C-R,W8S>C-^,X(SAC.*,XXSD
MC.6,YHSGC.B,Z8SJC.N,[(SMC.Z,[XSPC/&,\HSSC/2,]8SVC/>,^(SYC/J,
M^XS\C/V,_HQ`C4&-0HU#C42-18U&C4>-2(U)C4J-2XU,C4V-3HU/C5"-48U2
MC5.-5(U5C5:-5XU8C5F-6HU;C5R-78U>C5^-8(UAC6*-8XUDC66-9HUGC6B-
M:8UJC6N-;(UMC6Z-;XUPC7&-<HUSC72-=8UVC7>->(UYC7J->XU\C7V-?HV`
MC8&-@HV#C82-A8V&C8>-B(V)C8J-BXV,C8V-CHV/C9"-D8V2C9.-E(V5C9:-
MEXV8C9F-FHV;C9R-G8V>C9^-H(VAC:*-HXVDC:6-IHVGC:B-J8VJC:N-K(VM
MC:Z-KXVPC;&-LHVSC;2-M8VVC;>-N(VYC;J-NXV\C;V-OHV_C<"-P8W"C<.-
MQ(W%C<:-QXW(C<F-RHW+C<R-S8W.C<^-T(W1C=*-TXW4C=6-UHW7C=B-V8W:
MC=N-W(W=C=Z-WXW@C>&-XHWCC>2-Y8WFC>>-Z(WIC>J-ZXWLC>V-[HWOC?"-
M\8WRC?.-](WUC?:-]XWXC?F-^HW[C?R-_8W^C4".08Y"CD..1(Y%CD:.1XY(
MCDF.2HY+CDR.38Y.CD^.4(Y1CE*.4XY4CE6.5HY7CEB.68Y:CEN.7(Y=CEZ.
M7XY@CF&.8HYCCF2.98YFCF>.:(YICFJ.:XYLCFV.;HYOCG".<8YRCG..=(YU
MCG:.=XYXCGF.>HY[CGR.?8Y^CH".@8Z"CH..A(Z%CH:.AXZ(CHF.BHZ+CHR.
MC8Z.CH^.D(Z1CI*.DXZ4CI6.EHZ7CIB.F8Z:CIN.G(Z=CIZ.GXZ@CJ&.HHZC
MCJ2.I8ZFCJ>.J(ZICJJ.JXZLCJV.KHZOCK".L8ZRCK..M(ZUCK:.MXZXCKF.
MNHZ[CKR.O8Z^CK^.P([!CL*.PX[$CL6.QH['CLB.R8[*CLN.S([-CLZ.SX[0
MCM&.TH[3CM2.U8[6CM>.V([9CMJ.VX[<CMV.WH[?CN".X8[BCN..Y([ECN:.
MYX[HCNF.ZH[KCNR.[8[NCN^.\([QCO*.\X[TCO6.]H[WCOB.^8[ZCON._([]
MCOZ.0(]!CT*/0X]$CT6/1H]'CTB/28]*CTN/3(]-CTZ/3X]0CU&/4H]3CU2/
M58]6CU>/6(]9CUJ/6X]<CUV/7H]?CV"/88]BCV./9(]ECV:/9X]HCVF/:H]K
MCVR/;8]NCV^/<(]QCW*/<X]TCW6/=H]WCWB/>8]ZCWN/?(]]CWZ/@(^!CX*/
M@X^$CX6/AH^'CXB/B8^*CXN/C(^-CXZ/CX^0CY&/DH^3CY2/E8^6CY>/F(^9
MCYJ/FX^<CYV/GH^?CZ"/H8^BCZ./I(^ECZ:/IX^HCZF/JH^KCZR/K8^NCZ^/
ML(^QC[*/LX^TC[6/MH^WC[B/N8^ZC[N/O(^]C[Z/OX_`C\&/PH_#C\2/Q8_&
MC\>/R(_)C\J/RX_,C\V/SH_/C]"/T8_2C]./U(_5C]:/UX_8C]F/VH_;C]R/
MW8_>C]^/X(_AC^*/XX_DC^6/YH_GC^B/Z8_JC^N/[(_MC^Z/[X_PC_&/\H_S
MC_2/]8_VC_>/^(_YC_J/^X_\C_V/_H]`D$&00I!#D$2019!&D$>02)!)D$J0
M2Y!,D$V03I!/D%"049!2D%.05)!5D%:05Y!8D%F06I!;D%R079!>D%^08)!A
MD&*08Y!DD&609I!GD&B0:9!JD&N0;)!MD&Z0;Y!PD'&0<I!SD'20=9!VD'>0
M>)!YD'J0>Y!\D'V0?I"`D(&0@I"#D(20A9"&D(>0B)")D(J0BY",D(V0CI"/
MD)"0D9"2D).0E)"5D):0EY"8D)F0FI";D)R0G9">D)^0H)"AD**0HY"DD*60
MII"GD*B0J9"JD*N0K)"MD*Z0KY"PD+&0LI"SD+20M9"VD+>0N)"YD+J0NY"\
MD+V0OI"_D,"0P9#"D,.0Q)#%D,:0QY#(D,F0RI#+D,R0S9#.D,^0T)#1D-*0
MTY#4D-60UI#7D-B0V9#:D-N0W)#=D-Z0WY#@D.&0XI#CD.20Y9#FD.>0Z)#I
MD.J0ZY#LD.V0[I#OD/"0\9#RD/.0])#UD/:0]Y#XD/F0^I#[D/R0_9#^D$"1
M09%"D4.11)%%D4:11Y%(D4F12I%+D4R139%.D4^14)%1D5*14Y%4D5615I%7
MD5B169%:D5N17)%=D5Z17Y%@D6&18I%CD62199%FD6>1:)%ID6J1:Y%LD6V1
M;I%OD7"1<9%RD7.1=)%UD7:1=Y%XD7F1>I%[D7R1?9%^D8"1@9&"D8.1A)&%
MD8:1AY&(D8F1BI&+D8R1C9&.D8^1D)&1D9*1DY&4D961EI&7D9B1F9&:D9N1
MG)&=D9Z1GY&@D:&1HI&CD:21I9&FD:>1J)&ID:J1JY&LD:V1KI&OD;"1L9&R
MD;.1M)&UD;:1MY&XD;F1NI&[D;R1O9&^D;^1P)'!D<*1PY'$D<61QI''D<B1
MR9'*D<N1S)'-D<Z1SY'0D=&1TI'3D=21U9'6D=>1V)'9D=J1VY'<D=V1WI'?
MD>"1X9'BD>.1Y)'ED>:1YY'HD>F1ZI'KD>R1[9'ND>^1\)'QD?*1\Y'TD?61
M]I'WD?B1^9'ZD?N1_)']D?Z10))!DD*20Y)$DD621I)'DDB229)*DDN23))-
MDDZ23Y)0DE&24I)3DE2259)6DE>26))9DEJ26Y)<DEV27I)?DF"289)BDF.2
M9))EDF:29Y)HDFF2:I)KDFR2;9)NDF^2<))QDG*2<Y)TDG62=I)WDGB2>9)Z
MDGN2?))]DGZ2@)*!DH*2@Y*$DH62AI*'DHB2B9**DHN2C)*-DHZ2CY*0DI&2
MDI*3DI22E9*6DI>2F)*9DIJ2FY*<DIV2GI*?DJ"2H9*BDJ.2I)*EDJ:2IY*H
MDJF2JI*KDJR2K9*NDJ^2L)*QDK*2LY*TDK62MI*WDKB2N9*ZDKN2O)*]DKZ2
MOY+`DL&2PI+#DL22Q9+&DL>2R)+)DLJ2RY+,DLV2SI+/DM"2T9+2DM.2U)+5
MDM:2UY+8DMF2VI+;DMR2W9+>DM^2X)+ADN*2XY+DDN62YI+GDNB2Z9+JDNN2
M[)+MDNZ2[Y+PDO&2\I+SDO22]9+VDO>2^)+YDOJ2^Y+\DOV2_I)`DT&30I-#
MDT2319-&DT>32)-)DTJ32Y-,DTV33I-/DU"349-2DU.35)-5DU:35Y-8DUF3
M6I-;DUR379->DU^38)-ADV*38Y-DDV639I-GDVB3:9-JDVN3;)-MDVZ3;Y-P
MDW&3<I-SDW23=9-VDW>3>)-YDWJ3>Y-\DWV3?I.`DX&3@I.#DX23A9.&DX>3
MB).)DXJ3BY.,DXV3CI./DY"3D9.2DY.3E).5DY:3EY.8DYF3FI.;DYR3G9.>
MDY^3H).ADZ*3HY.DDZ63II.GDZB3J9.JDZN3K).MDZZ3KY.PD[&3LI.SD[23
MM9.VD[>3N).YD[J3NY.\D[V3OI._D\"3P9/"D\.3Q)/%D\:3QY/(D\F3RI/+
MD\R3S9/.D\^3T)/1D]*3TY/4D]63UI/7D]B3V9/:D]N3W)/=D]Z3WY/@D^&3
MXI/CD^23Y9/FD^>3Z)/ID^J3ZY/LD^V3[I/OD_"3\9/RD_.3])/UD_:3]Y/X
MD_F3^I/[D_R3_9/^DT"4091"E$.41)1%E$:41Y1(E$F42I1+E$R4391.E$^4
M4)11E%*44Y14E%645I17E%B4691:E%N47)1=E%Z47Y1@E&&48I1CE&24991F
ME&>4:)1IE&J4:Y1LE&V4;I1OE'"4<91RE'.4=)1UE':4=Y1XE'F4>I1[E'R4
M?91^E("4@92"E(.4A)2%E(:4AY2(E(F4BI2+E(R4C92.E(^4D)21E)*4DY24
ME)64EI27E)B4F92:E)N4G)2=E)Z4GY2@E*&4HI2CE*24I92FE*>4J)2IE*J4
MJY2LE*V4KI2OE+"4L92RE+.4M)2UE+:4MY2XE+F4NI2[E+R4O92^E+^4P)3!
ME,*4PY3$E,64QI3'E,B4R93*E,N4S)3-E,Z4SY30E-&4TI33E-24U936E->4
MV)39E-J4VY3<E-V4WI3?E."4X93BE..4Y)3EE.:4YY3HE.F4ZI3KE.R4[93N
ME.^4\)3QE/*4\Y3TE/64]I3WE/B4^93ZE/N4_)3]E/Z40)5!E4*50Y5$E465
M1I5'E4B5295*E4N53)5-E4Z53Y50E5&54I53E5255956E5>56)59E5J56Y5<
ME5V57I5?E6"5895BE6.59)5EE6:59Y5HE6F5:I5KE6R5;95NE6^5<)5QE7*5
M<Y5TE765=I5WE7B5>95ZE7N5?)5]E7Z5@)6!E8*5@Y6$E865AI6'E8B5B96*
ME8N5C)6-E8Z5CY60E9&5DI63E925E966E9>5F)69E9J5FY6<E9V5GI6?E:"5
MH96BE:.5I)6EE::5IY6HE:F5JI6KE:R5K96NE:^5L)6QE;*5LY6TE;65MI6W
ME;B5N96ZE;N5O)6]E;Z5OY7`E<&5PI7#E<25Q97&E<>5R)7)E<J5RY7,E<V5
MSI7/E="5T972E=.5U)75E=:5UY78E=F5VI7;E=R5W97>E=^5X)7AE>*5XY7D
ME>65YI7GE>B5Z97JE>N5[)7ME>Z5[Y7PE?&5\I7SE?25]97VE?>5^)7YE?J5
M^Y7\E?V5_I5`ED&60I9#ED26199&ED>62)9)EDJ62Y9,EDV63I9/EE"64992
MEE.65)95EE:65Y98EEF66I9;EER6799>EE^68)9AEF*68Y9DEF669I9GEFB6
M:99JEFN6;)9MEFZ6;Y9PEG&6<I9SEG26=99VEG>6>)9YEGJ6>Y9\EGV6?I:`
MEH&6@I:#EH26A9:&EH>6B):)EHJ6BY:,EHV6CI:/EI"6D9:2EI.6E):5EI:6
MEY:8EIF6FI:;EIR6G9:>EI^6H):AEJ*6HY:DEJ66II:GEJB6J9:JEJN6K):M
MEJZ6KY:PEK&6LI:SEK26M9:VEK>6N):YEKJ6NY:\EKV6OI:_EL"6P9;"EL.6
MQ);%EL:6QY;(ELF6RI;+ELR6S9;.EL^6T);1EM*6TY;4EM66UI;7EMB6V9;:
MEMN6W);=EMZ6WY;@EN&6XI;CEN26Y9;FEN>6Z);IENJ6ZY;LENV6[I;OEO"6
M\9;REO.6]);UEO:6]Y;XEOF6^I;[EOR6_9;^ED"709="ET.71)=%ET:71Y=(
METF72I=+ETR739=.ET^74)=1EU*74Y=4EU675I=7EUB769=:EUN77)==EUZ7
M7Y=@EV&78I=CEV2799=FEV>7:)=IEVJ7:Y=LEVV7;I=OEW"7<9=REW.7=)=U
MEW:7=Y=XEWF7>I=[EWR7?9=^EX"7@9>"EX.7A)>%EX:7AY>(EXF7BI>+EXR7
MC9>.EX^7D)>1EY*7DY>4EY67EI>7EYB7F9>:EYN7G)>=EYZ7GY>@EZ&7HI>C
MEZ27I9>FEZ>7J)>IEZJ7JY>LEZV7KI>OE["7L9>RE[.7M)>UE[:7MY>XE[F7
MNI>[E[R7O9>^E[^7P)?!E\*7PY?$E\67QI?'E\B7R9?*E\N7S)?-E\Z7SY?0
ME]&7TI?3E]27U9?6E]>7V)?9E]J7VY?<E]V7WI??E^"7X9?BE^.7Y)?EE^:7
MYY?HE^F7ZI?KE^R7[9?NE^^7\)?QE_*7\Y?TE_67]I?WE_B7^9?ZE_N7_)?]
ME_Z70)A!F$*80YA$F$681IA'F$B829A*F$N83)A-F$Z83YA0F%&84IA3F%28
M59A6F%>86)A9F%J86YA<F%V87IA?F&"889ABF&.89)AEF&:89YAHF&F8:IAK
MF&R8;9ANF&^8<)AQF'*8<YATF'68=IAWF'B8>9AZF'N8?)A]F'Z8@)B!F(*8
M@YB$F(68AIB'F(B8B9B*F(N8C)B-F(Z8CYB0F)&8DIB3F)28E9B6F)>8F)B9
MF)J8FYB<F)V8GIB?F*"8H9BBF*.8I)BEF*:8IYBHF*F8JIBKF*R8K9BNF*^8
ML)BQF+*8LYBTF+68MIBWF+B8N9BZF+N8O)B]F+Z8OYC`F,&8PIC#F,28Q9C&
MF,>8R)C)F,J8RYC,F,V8SIC/F-"8T9C2F-.8U)C5F-:8UYC8F-F8VIC;F-R8
MW9C>F-^8X)CAF.*8XYCDF.68YICGF.B8Z9CJF.N8[)CMF.Z8[YCPF/&8\ICS
MF/28]9CVF/>8^)CYF/J8^YC\F/V8_IA`F4&90IE#F42919E&F4>92)E)F4J9
M2YE,F4V93IE/F5"949E2F5.95)E5F5:95YE8F5F96IE;F5R979E>F5^98)EA
MF6*98YEDF6699IEGF6B9:9EJF6N9;)EMF6Z9;YEPF7&9<IESF729=9EVF7>9
M>)EYF7J9>YE\F7V9?IF`F8&9@IF#F829A9F&F8>9B)F)F8J9BYF,F8V9CIF/
MF9"9D9F2F9.9E)F5F9:9EYF8F9F9FIF;F9R9G9F>F9^9H)FAF:*9HYFDF:69
MIIFGF:B9J9FJF:N9K)FMF:Z9KYFPF;&9LIFSF;29M9FVF;>9N)FYF;J9NYF\
MF;V9OIF_F<"9P9G"F<.9Q)G%F<:9QYG(F<F9RIG+F<R9S9G.F<^9T)G1F=*9
MTYG4F=69UIG7F=B9V9G:F=N9W)G=F=Z9WYG@F>&9XIGCF>29Y9GFF>>9Z)GI
MF>J9ZYGLF>V9[IGOF?"9\9GRF?.9])GUF?:9]YGXF?F9^IG[F?R9_9G^F4":
M09I"FD.:1)I%FD::1YI(FDF:2II+FDR:39I.FD^:4)I1FE*:4YI4FE6:5II7
MFEB:69I:FEN:7)I=FEZ:7YI@FF&:8IICFF2:99IFFF>::)IIFFJ::YILFFV:
M;IIOFG":<9IRFG.:=)IUFG::=YIXFGF:>II[FGR:?9I^FH":@9J"FH.:A)J%
MFH::AYJ(FHF:BIJ+FHR:C9J.FH^:D)J1FI*:DYJ4FI6:EIJ7FIB:F9J:FIN:
MG)J=FIZ:GYJ@FJ&:HIJCFJ2:I9JFFJ>:J)JIFJJ:JYJLFJV:KIJOFK":L9JR
MFK.:M)JUFK::MYJXFKF:NIJ[FKR:O9J^FK^:P)K!FL*:PYK$FL6:QIK'FLB:
MR9K*FLN:S)K-FLZ:SYK0FM&:TIK3FM2:U9K6FM>:V)K9FMJ:VYK<FMV:WIK?
MFN":X9KBFN.:Y)KEFN::YYKHFNF:ZIKKFNR:[9KNFN^:\)KQFO*:\YKTFO6:
M]IKWFOB:^9KZFON:_)K]FOZ:0)M!FT*;0YM$FT6;1IM'FTB;29M*FTN;3)M-
MFTZ;3YM0FU&;4IM3FU2;59M6FU>;6)M9FUJ;6YM<FUV;7IM?FV";89MBFV.;
M9)MEFV:;9YMHFVF;:IMKFVR;;9MNFV^;<)MQFW*;<YMTFW6;=IMWFWB;>9MZ
MFWN;?)M]FWZ;@)N!FX*;@YN$FX6;AIN'FXB;B9N*FXN;C)N-FXZ;CYN0FY&;
MDIN3FY2;E9N6FY>;F)N9FYJ;FYN<FYV;GIN?FZ";H9NBFZ.;I)NEFZ:;IYNH
MFZF;JINKFZR;K9NNFZ^;L)NQF[*;LYNTF[6;MINWF[B;N9NZF[N;O)N]F[Z;
MOYO`F\&;PIO#F\2;Q9O&F\>;R)O)F\J;RYO,F\V;SIO/F]";T9O2F].;U)O5
MF]:;UYO8F]F;VIO;F]R;W9O>F]^;X)OAF^*;XYODF^6;YIOGF^B;Z9OJF^N;
M[)OMF^Z;[YOPF_&;\IOSF_2;]9OVF_>;^)OYF_J;^YO\F_V;_IM`G$&<0IQ#
MG$2<19Q&G$><2)Q)G$J<2YQ,G$V<3IQ/G%"<49Q2G%.<5)Q5G%:<5YQ8G%F<
M6IQ;G%R<79Q>G%^<8)QAG&*<8YQDG&6<9IQGG&B<:9QJG&N<;)QMG&Z<;YQP
MG'&<<IQSG'2<=9QVG'><>)QYG'J<>YQ\G'V<?IR`G(&<@IR#G(2<A9R&G(><
MB)R)G(J<BYR,G(V<CIR/G)"<D9R2G).<E)R5G):<EYR8G)F<FIR;G)R<G9R>
MG)^<H)RAG**<HYRDG*6<IIRGG*B<J9RJG*N<K)RMG*Z<KYRPG+&<LIRSG+2<
MM9RVG+><N)RYG+J<NYR\G+V<OIR_G,"<P9S"G,.<Q)S%G,:<QYS(G,F<RIS+
MG,R<S9S.G,^<T)S1G-*<TYS4G-6<UIS7G-B<V9S:G-N<W)S=G-Z<WYS@G.&<
MXISCG.2<Y9SFG.><Z)SIG.J<ZYSLG.V<[ISOG/"<\9SRG/.<])SUG/:<]YSX
MG/F<^IS[G/R<_9S^G$"=09U"G4.=1)U%G4:=1YU(G4F=2IU+G4R=39U.G4^=
M4)U1G5*=4YU4G56=5IU7G5B=69U:G5N=7)U=G5Z=7YU@G6&=8IUCG62=99UF
MG6>=:)UIG6J=:YULG6V=;IUOG7"=<9URG7.==)UUG7:==YUXG7F=>IU[G7R=
M?9U^G8"=@9V"G8.=A)V%G8:=AYV(G8F=BIV+G8R=C9V.G8^=D)V1G9*=DYV4
MG96=EIV7G9B=F9V:G9N=G)V=G9Z=GYV@G:&=HIVCG:2=I9VFG:>=J)VIG:J=
MJYVLG:V=KIVOG;"=L9VRG;.=M)VUG;:=MYVXG;F=NIV[G;R=O9V^G;^=P)W!
MG<*=PYW$G<6=QIW'G<B=R9W*G<N=S)W-G<Z=SYW0G=&=TIW3G=2=U9W6G=>=
MV)W9G=J=VYW<G=V=WIW?G>"=X9WBG>.=Y)WEG>:=YYWHG>F=ZIWKG>R=[9WN
MG>^=\)WQG?*=\YWTG?6=]IWWG?B=^9WZG?N=_)W]G?Z=0)Y!GD*>0YY$GD6>
M1IY'GDB>29Y*GDN>3)Y-GDZ>3YY0GE&>4IY3GE2>59Y6GE>>6)Y9GEJ>6YY<
MGEV>7IY?GF">89YBGF.>9)YEGF:>9YYHGFF>:IYKGFR>;9YNGF^><)YQGG*>
M<YYTGG6>=IYWGGB>>9YZGGN>?)Y]GGZ>@)Z!GH*>@YZ$GH6>AIZ'GHB>B9Z*
MGHN>C)Z-GHZ>CYZ0GI&>DIZ3GI2>E9Z6GI>>F)Z9GIJ>FYZ<GIV>GIZ?GJ">
MH9ZBGJ.>I)ZEGJ:>IYZHGJF>JIZKGJR>K9ZNGJ^>L)ZQGK*>LYZTGK6>MIZW
MGKB>N9ZZGKN>O)Z]GKZ>OY[`GL&>PI[#GL2>Q9[&GL>>R)[)GLJ>RY[,GLV>
MSI[/GM">T9[2GM.>U)[5GM:>UY[8GMF>VI[;GMR>W9[>GM^>X)[AGN*>XY[D
MGN6>YI[GGNB>Z9[JGNN>[)[MGNZ>[Y[PGO&>\I[SGO2>]9[VGO>>^)[YGOJ>
M^Y[\GOV>_IY`GT&?0I]#GT2?19]&GT>?2)])GTJ?2Y],GTV?3I]/GU"?49]2
MGU.?5)]5GU:?5Y]8GUF?6I];GUR?79]>GU^?8)]AGV*?8Y]DGV6?9I]GGVB?
M:9]JGVN?;)]MGVZ?;Y]PGW&?<I]SGW2?=9]VGW>?>)]YGWJ?>Y]\GWV??I^`
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MP$+`0\!$P$7`1L!'P$C`2<!*P$O`3,!-P$[`3\!0P%'`4L!3P%3`5<!6P%?`
M6,!9P%K`6\!<P%W`7L!?P&#`8<!BP&/`9,!EP&;`9\!HP&G`:L!KP&S`;<!N
MP&_`<,!QP'+`<\!TP'7`=L!WP'C`><!ZP'O`?,!]P'[`@,"!P(+`@\"$P(7`
MAL"'P(C`B<"*P(O`C,"-P([`C\"0P)'`DL"3P)3`E<"6P)?`F,"9P)K`F\"<
MP)W`GL"?P*#`0,%!P4+!0\%$P47!1L%'P4C!2<%*P4O!3,%-P4[!3\%0P5'!
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MJ7JI>ZE\J7VI?JF`J8&I@JF#J82IA:F&J8>IB*E6J5>I````````````````
M``#&-P``QC<``,8W``#&-P$`QS<`_LXW]_[<-W\/YS<``.<W``#G-P``YS<`
M`.<W``#G-P``YS<``.<W``#G-P``YS<``.<W``#G-P``YS<``.<W``#G-P``
MYS<``.<W``#G-P``YS<``.<W``#G-P``YS<``.<W``#G-Q0``````+$W``"Q
M-P``L3<`$+(W``"R-P``LC<``+(W``"R-P`"LS<``+,W(`"T-P``M#<``+0W
M``"T-P``M#>``+4W`@"V-P#PNC<:@;\WFP,`````````````````````````
M`'8`=(![`(2`?@!+PH4`JA"*`%<$D`"B#)4`O/VA`/2_K0"_!+4`P7*\``B$
MOP#3<\D``)',``4<T0#%XMD`$E?@`/T9Z@!\,/$`"G/X`*K*``&W'PL!5``.
M`49M%@&F)QX!YU0G`6W7,@$6*#<!WW]%`<<[3P%\"E8!M1A=`?6Z:`'_3W4!
MZVA^`9V(A0'_JY(!=RZ<`=_KJ0'?[[<!/S?"`=[>S@'__]X!5^SH`?OS]0'_
M?P0"O_L2`C^/'0+7]RH"/_<W`OO_1@+]_U4"_W]D`H34:@*-ZW0"VX9]`@3$
M@0+8S(D"&^62`LIGFP(0QZ$"+F6I`OW7M@+L5\`"ED#%`C":RP(YT-("[I3;
M`C90X0+PR^H"K*_T`EUY_@+[7PL#^?X8`_87(@/PP"@#\3\S`W?U/P.Z?DH#
M[_]9`_XY9`.>7FX#'MEW`[2[@0/_,8P#53B3`Q$KF0,@-9X#1'JE`XO%K0/?
M6K@#D[S!`[]WS@/YP-8#+73>`X8`X0,0Q.4#I0CJ`Q`7[P,T!/,#R:3Z`[;R
M!`0"Y`D$J_X5!!'&&P2J)R,$BM$J!"=`+P3E5C@$*`P\!$`)/P0?F$<$\TM1
M!#U]7`3L]V@$8BMO!'0O>`2E^8($GN^.!`V+E00?IIX$8'"C!.U,K`1__[L$
M597#!,_-S@2A3]8$A6+<!%.?Y@3\+.\$_S;[!&?/!@6I=0\%_X\<!6_L)P7K
MX#`%O><\!9\_2`7W_U<%]W]E!7_O<P7_^X(%;Q.+!>C7E07,&9P%I_BF!?]O
MM`7W"+P%]K'&!7H+S@5\`]4%K%#;!3?GY@6#Y^\%\_?\!2"5`0;K_@X&\S<9
M!LM8(0;N7RT&[]@X!CK70@;=O4X&[/M:!M[_:`;OSW4&[;Z!!M_GC@;_OYT&
MU/VH!O,YL@;__,`&_^_/!MW_W0;=_^L&[Z?W!K;]`P=K7PX'CVD7!T\1'@=M
MZ"<':30N!PWZ-P?:_T0'I]Q.!R':50<SO5\'QS!F!_NU<@>_\W\'8,J%!]?N
MD0?_=9X'!>RE!_5NL`?6_;P'J>_'![[YTP??^^$'>_ON!P][^`?__P@(^_,5
M"/_[)`C3OB\(^>T["*ON1@BT]5`(_?]?"/_];@@__WP(__^,"&O_F0C^_Z@(
M1$"K"(/ILPC4V[T(1&3""%>`R`B`\\\(AAS5"`OOWPCR'^D(S;[T"/Y@_0BM
M>0<)C<H/"4OO&@GM`"`)V#`F"=R],0F4/SH)_7E&"?G.40DLX%<)\\5A"55>
M:@GM]W<)^_V%"8W:C@G^]YP),[^G":^WLPDOG;T)[Y_*"7_CU@G_UN,)_V7O
M">___@G[_PT*_]T;"O__*PI__SH*W]]("O^750H9-%L*89]D"I%N;`J,P'$*
M/Y]]"GW&APK+[Y,*S[>?"OG_K0JC0K,*+G.\"@0IP`H>W\L*%[S4"O_YX@JQ
M]^T*__K["B\[!0O@<@P+5785"QY9'0O]Z2D+_O\X"Q+>0`NIR4@+=.51"TC@
M5@M:[%\+_9IJ"U_/=@N'37X+.-R&"VR3C@O=%I<+@!N<"XO%I`L<<*H+WV>V
M"_'7P0O:V<L+8T#0"[9`U@OGS>$+JU/J"[9&\@OIYOP+G_,(#-U*$0P^!!<,
MIODA#+P<*0S?>S8,)O=`#/]_3PS_JEL,W=]H#'O^=0Q>_X(,_[>0#._?G@Q_
M[*H,?[^X#/ORQ`SI_]$,O__@#-]_[@R_`O8,&'+\#,FK!0UG'P\-=(05#>'V
M'PTW`24-MBTN#>[Y.@T1<D`-R.9(#=U%40T+B%8-(F!:#1,,7PTE#V8->;QP
M#;T3>0W`<G\-^]F+#9,%D0W>/YT-<9VF#3WSL0UZ*+@-NO[$#5*(R0UFJM$-
MKQW;#;J_YPWTV?$-JU[[#=AG!`[FIPX.O,L8#N];)`X-^BT.Z[XY#G_=1@[_
M^%,.2_]?#IF]:0[OC70.7NI^#MJ?B0YZOI0.J_^A#O__L0[^_;\.^_[-#M\W
MV0Z/-.$.WVSL#IV5]0ZSYP`/:O\,#W_G&0]T92$/354I#_[--0^%)SP/._])
M#QH,3@\\^UD/LBMA#\==:P]>7G4/C:]_#_5GB@\#>Y(/K3Z<#RZ[I@]K[[(/
M/=^^#W^^RP_OO=@/___H#__%]`^__0(08BT)$/[0$Q!.5QP0OT(E$,W;,!"R
M+#<0M"]`$-Q82!!2+U`0;?5;$%Z*8Q!34FH0%OYT$.5_@!#@B(40VFV/$.1?
MF1!>()\0-=^J$/WYMQ!SC+\0@*C#$,3_SA``]-,0+__@$)5_ZQ!W__D0.UX#
M$=;_$!'ZU1L1V_HG$?:_-!'<Z3X1W9=)$?I_5A'NWV,1[EUN$?O_?1%OFX@1
MMK>3$7WLGA$JW*81S^:Q$7_6O1%M]\D1_:O5$>YWX1'^W^\1^U_\$?_["Q)_
M?A@2_7HD$MV?,!)O_SX2_O1*$MW_6!+][642[K]R$GS_?Q+^Y8L2__^;$O__
MJQ+__[L2___+$O__VQ+__^L2___[$F#_!1-[N1`3-^T;$__]*A,#^S,3_^5`
M$R'11A.S\U$3_?M?$T=_:A/95W03`_5\$_USB!/7W903'U^?$X1PI!,I.*H3
MRMZT$SCYO1-.!\03[/C.$ZJ=UQ.1;-X3YG7H$P61[1/Q!/,3S^G^$P:W!A30
M,@P4%((0%&VG&A1[L2047[,O%-&%-A05$CL4X:E#%+8Y3!1O[E@4VZQB%,47
M:A0D,&X4VWYZ%`[G@Q2]G(T4K*>6%'7EH!3?BZL4+-NT%,15NQ3K^L<4YY_3
M%*=VW13_M^L4_S_Y%)=]!!7^;A`56WL;%2G3(Q5Y=RX513LV%8C\/A7O_4P5
MNWU8%<?_917N46X5M;]Z%3_7AA7_KI,5NY^?%>OJJA7OC+05_^_#%7W_T16W
M_=X5^OWK%?F_^!7\/P06__\4%O__)!;]\S$6]_]`%M_]3A;_;UP6_[]K%O]'
M=Q:>+H`6WKF+%HO-E!;_!Y\6=<2G%O#ZL1;_=+T6+T3$%G_=T1;_^=\6EOCH
M%K]_]A:\_P,7WZL/%_^O'1<OOB@7\]HS%^][0!?O?$P7_NY9%]?]9A?WOW07
MS_^"%UZ_CA?__9T7O_^L%__?NQ?_ZL@7'%3.%W_.VA>[5>07.3WM%]LY]Q?L
M4P`8^W\.&/]/&Q@N_"48X9XN&'J].1C\#$$88.)'&/6[4Q@7AUL8V:%C&&T\
M;!C_WWL8>O^(&/Y/E!C_OZ,8;[6N&+UWNAC[-<48<O//&/I8V!C\O>087MWO
M&/O__AB7>0@9_O,5&9NJ'AF&[R@9_?\W&5\A/QG_WTX9/K]:&72W9!G^KW$9
M?_Q^&?_[C1G__YT9^Z^J&:(_LQDO?[\9[U_,&?5HU1G?1-X94++D&=XF[1GO
MX?@9G_L%&NM\$!JW=QP:*5DC&L0G*AK`C"\:0]@V&HNV/QHC\D<:[&U1&M3K
M6QI>=&0:BM%K&L8N<QKVSW\:KZ^+&O=WF!K_EJ0:*[:M&K7]N1KOO\<:Z7_3
M&IL:VQHH=N(:WS_O&NFL^!IMU`$;_WD.&[I<%QL?ZB$;=/\M&_SS.1N1YD$;
M_QU-&\Z/5QOY?V0;6NEM&]97=QO_WX8;?^>3&U.%FANW'J0;^,VN&RE*M!L7
MS;T;;J#$&UZOSQL:W]D;_X/D&W_O\AM_C?T;=6(%'%7_$1S@O1H<W?$E',[]
M,1S_[C\<:_M+'-W_61SWOV<<[_]V'.^C@1R\_(P<-P.3'%I>G!Q_^JD<S'NS
M'/_[PAQ__]$<]Y';'+35Y!S9?N\<)U7W'/[6`QVREPP=;[L8'?;_)AUW12\=
MO_\^'7W_3!W__UP=+GAD':3>;1T93G0=GLY^'?=_C!W_]YL=OSVG'99?L1W_
M6;T=IW+&'<VUT!V.HM<=]:KA'5]EZQVHTO(=^K__'5FU"![>WQ4>3L\?'CG`
M)1[M_C(>/>\^'O7921Z=NU0>?:]@'G]G;!Z_?WH>/_N''O]^E1[\WZ(>__^R
M'O__PA[GQ\T>__W<'ED.XQ[+N^X>\8WW'EW*`!\?;0H?_GX7'__V)1__^S0?
M__]$'WIW3Q___U\?__]O'___?Q__OXX??_^='___K1___[T?O[_+'___VQ__
M_^L?___['___"R#__QL@__\K(/__.R#__TL@__=:('W_:"#__W@@__^((/__
MF"#[_Z<@_W>U(`!`MB`0&+D@``"Y($``NB`0$+P@``*](``$OB`!0,`@``#`
M((#ZQR#+_]0@3'K<(/FXYB#IO?$@_:O](.\;""%M?Q0A^DP=(=VK*"'/?C0A
MG+T^(?3G22&$QU`A"NQ7(1KX7R$55F8AL\-O(>OZ>R'_^8DA_7^7(2;EGR&W
M0J<AR!&L(6D+LR&@C[HA/X'"(4U`QR&@RLTANQG6(:"ZW2'_;^LAN;[V(;_B
M`2+$^0HB7IT4(NP!&B+Z>B4B_<8P(K?Z/"+W\TDBL.M2(O__8B)WRVTBYZ=X
M(HC/@"+J)XDB\4*0(@2TE2)O=:`B_WJM(O\^NB+B&<$BZQ+)(GE,T2*-`-4B
M9)S<(FT"XB)!)N<BA'?O(FWU^B(!+/XB3>,'(W]&$2.%Z!@C-GTB(^@C*2,$
M`"HC?\8U(Y^]02/SIDLC_O!6(R#(6B-<:V,CKTYM(]SY>"/XW((CI0>)(_W.
ME2,/_J`C_<ZL([__NR-]X<4C]<7/(Y7ZV2-[I.(C?^WO(_U__2/K6`8D[=D1
M)+1?&R26[R8D_F\S)/_O0B1U>TTD_>=:)'_`8R3W^&\DO[U\)._^BB3KL90D
M3W^@)/_GKB3O.KDD?OW&)/U]TR36[]\D[_WM)/]W^R3?_PHEO?\8)7_])B7_
M[C0E_Q]!)>R[3"7[IU@E_0%@)?C#:277SW4E9VA])8S[AR4N,8XE[#26)>^=
MHB7@O*HE<MBR)5.JNB71O<0E;3?.)7^LV25W_>8EQK_Q):Z'^B73U@0F=W\1
M)O]&'";7VR@FOO,T)O'W0";>NTPF_[U:)O?[:":7]W0F^?^")OOMCR;.SYHF
M;_VG)L&DK29Z'[<FR=;`)KOOS2;KU]DF?>_F)IF]\";+?/HFP_X%)^2L#2?[
M^QLG\O$E)]WS,2>N_SXG[?],)_\_6B>__VDG_W=W)[7_A"?__Y0G__^D)___
MM"<)(+<GN*O`)Y=WRR?W_]HG?O_H)___^"?__P@H_[\7*/_^)BC__S8H__]&
M*/_]52C_^6,H]_]R*/__@BC__Y(H__^B*/__LBC__\(H___2*'__X2C___$H
MO_\`*?__$"G__R`I__\P*;_O/BG__TXI__]>*?__;BD`$&\I`@AQ*8``<BD!
M`',I``1T*0``="D``G4I`$!V*0``=BD`_WXI/>V)*=_[ERGY\Z,I]_BO*=OI
MNBGO_L@I___8*?__Z"G___@I__\(*O__&"K__R@J__\X*O\?12H!`$8J``!&
M*@``1BJ&@$HJ(-=1*@;_6RK-\V8J[7]S*O?_@BK%*HDJIR>2*CT3FBKG8J,J
M5]"K*M]IMBKO'\(J\RG+*MW9UBIH\-TJ^?WJ*K]-]2JJ;_\J77\+*^ZO%RO_
M9R0K^_LR*_^_02O__U$K__]A*___<2O__X$K__^1*___H2O__[$K___!*___
MT2L_!-@K``#8*P$0VBL$(-PK]_3H*[R=\BM)OOLKQ`3_*XN0!2QVW`\L@%$3
M+"@3&"RX'R$LGZ8K+&E?-2QP]CXLTYY(+,]?5"SR]E\L5=5H++$K<"R$L'4L
M33M^+'3'ARPY5H\L[YZ;+.O_J2S_O;<L\W_$+/W]TBRW`=DL>IOC+,$IZ2P(
M'.TL7\7W+/CS`BWS&PPMS_L9+7\)(BW][S`M__]`+?__4"W__V`M__]P+?__
M@"W__Y`M__^@+?__L"W__\`M[__/+?^_WBW__^XM_[_]+?__#2[__APN__\L
M+O__/"[__TPN__]<+O__;"[__WPN_[^++O__FR[__ZLN__NZ+O__RB[_?]DN
M___I+O__^2[__PDO__L8+[__)R___S<O__]'+___5R___V<O__]W+_^_AB__
M_Y8O__^F+__WM2___\4O'P#*+T(!S2\``,TO``#-+X"`SR\8!-(O0`#3+P`(
MU"\``-0O`!#5+X$`UR\((-DO"`G<+R`$WB\!0.`OL'_J+___^B___PHP__\:
M,/__*C#__SHP__]*,/\04S``@%0P@`!5,`A)63#YNV4P@4=K,`K$<##.=WLP
M:>B#,`O_CC"?5I@P;NRB,'__L3"VC;HP#`V_,-O_S3#^>-@P-[WC,"P<Z3"W
MK_4P_]L#,?J\#C'__QXQL[4H,=C],S&G[S\QW]=,,>G^6#'V5V,QZ_]Q,?__
M@3'__Y$Q/\&:,9?_IS'__[<Q___',?__US'__^<Q___W,?__!S+__Q<R'P`<
M,@!('C(D`B$R"/\J,O__.C+_OTDRT3A0,G_^7C+__VXR_]]],O[_C#+_OYLR
M__^K,O__NS+/_\DR5P#.,@A+TS(,4M@R`/S>,M_^[#+___PR__\,,___'#/_
M_RPS__\\,___3#/__UPS__]L,___?#/__XPS__^<,_\/J#,$`*DS"&*M,S`"
ML#-`_K@S/.K!,]CGRS/U?M<SO5?B,__U\#/W?OTS]W\+-/=_&33[YR8T05PL
M-.W_.C3__THT__]:-/__:C3__WHT__^*-/__FC3__ZHT__^Z-/__RC3__]HT
M___J-/__^C3__PHU__\:-?__*C7__SHU__]*-?]O6#49EE\UR"-E-0"4:#4`
MPFLU!P-P-08,=#7[_X,U__^3-?__HS7__[,U___#-?__TS7__^,U___S-?__
M`S;__Q,V__\C-O__,S;__T,V__]3-O__8S;__W,V__^#-O__DS;__Z,V_W^R
M-I!`M381&+DV`2"[-EVBPS8GP,DV]#_4-GOVX#;S7^PVO__[-N^6!C?O'1$W
M[48:-UIY(S?_I2\W_Y<\-W;]2#?Z;U0W?Y5?-^__;C?\_WPW__^,-_]_FS<&
MX*`W_W&L-SX```````````````````````````!I````:0```&D```!I``(`
M:@```&H```!J````:@```&H```!J````:@`(`&L```!K````:P```&L```!K
M````:P```&L```!K````:P```&L```!K````:P```&L```!K``#`;0``<'``
M`@!Q````<0`00',`)@```````````%0`P`!6``1@60#^`V(```!B````8@``
M`&(```!B````8@```&(``'AF````9@```&8```!F````9@```&8``'`7````
M%P```!<````7````%P```!<`__\G`/__-P`/`#L`_O]*`#@`30```$T``#!/
M````3P```$\`/`!3````4P```@``````````````````````````````````
M```#`````P`I``8`(``'`"``"`````@````(````"`````@````(````"```
M``@````(````"`````@````(````"``@`@H````*``(`"P````L````+````
M"P````L````+````"P#``P\````/````#P````\````/````#P````\````/
M`""`$0`(`!(````2````$@`$`!,`P``5````%0```!4`(``6````%@``@```
M````````````````````````````````````````````````````````````
M```````````````````````````,`@```@````````````#RI@``]*;UIN"F
MX:;PIO&FXJ;CINZF[Z;FIN>FY*;EINBFZ:;JINNF````````````````````
M````````````NZ@```````````````````````````````````````#`J```
M`````````````````````````````````````````````+VH````````OJ@`
M`````````````````````````)C^F?Z:_IO^G/Z=_I[^````````````````
M``````````````````"6_@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````)/^E/Z5_I?^DOX`````````````````````````````````````````
M`````````(7^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(;^`````(?^``````````"(_HG^``"*_HO^
M`````````````````````````````````````````````````````(W^````
M````C/X`````````````````````````````````````````````````````
M`````(_^COX```````````````````````````````""_@``````````````
M````````````````````````````@_X`````````````````````````````
M`````(#^`````````````('^``````````````````````````!]_@``````
M``````````````````````````````````````````````!\_@``````````
M````````````````>/X``````````'?^````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!Z_@``````````````````````````````
M``````````````!B_F7^`````````````````````````````````````&/^
M`````````````````````````````````````%S^````````````````````
M`````````%O^````````````````````````````````````````````````
M`````%;^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!5_@```````````````````````````````(JIBZF,J8VICJF/J9"ID:F2
MJ9.IE*F5J0````````````!0_@````!4_@```````%?^`````%C^7?X`````
M`````````````````````%[^````````````````````````````````````
M````:_X`````;OX```````!Q_@``````````<_X`````=/YU_@```````'G^
M`````````````````````````````````````(3^`````````````(``@0"#
M`(4`A@"'`(D`C`".`)``D0"3`)0`E0"6`)<`F`"9`)H`FP"<`)T`G@"?`*``
MH0"B`*,`I`"E`*8`IP"H`*L`K`"]`,0`U0#<`-T`'0$>`1\!(P$E`2<!*0$J
M`2P!+0$N`2\!,`$Q`3(!,P$T`4`!2@%.`5(!4P%4`54!5@%7`5L!7`%=`6(!
M8P%G`6@!:0%J`6L!;0%Q`7,!=`%U`78!=P%X`8(!J@'V`1H"*0(L`BX",`(R
M`C0"-0(W`CL"/0(^`C\"0`)!`D("0P)%`D8"1P)(`DD"2@),`DT"3@):`EX"
M<0)S`GP"?0+0`M0"*@,M`U(#7`-=`UX#8`-C`V0#90-F`V@#:0-J`VL#;`-M
M`VX#;P-P`W(#<P-T`W4#=@-W`W@#>0-Z`WL#?`-]`WX#?P.``X$#@@.#`X0#
MA0.&`X<#B0.+`XP#C0./`Y`#E0.<`YT#0U5795AE665:95ME7&5@96%E8V5D
M96=E:65L96YE@&6*98YEG&6@9?YE!&8`````````````````````````````
M````````@`"C`*4`I@"I`*\`L@"V`+@`U@#8`-\`X@#G`.L`ZP#N`/$`]`#V
M`/@`^`#[`/L`_0```0(!$@$4`1H!'`$J`2P!0P%%`4<!20%,`4X!:@%L`<T!
MSP'/`=$!T0'3`=,!U0'5`=<!UP'9`=D!VP';`=T!^`'Z`5`"4@)@`F("Q@+(
M`L@"S`+8`MH"D`.B`Z(#J@.P`\(#P@/*`P`$`@0/!%`$4`12!`\@$2`2(!<@
M%R`:(!L@'B`D("<@+R`Q(#$@-"`T(#8@.B`\(*L@K2`"(00A!"$&(0@A"B$5
M(1<A("$B(5\A;"%O(7HACR&4(94AFB$'(@DB#B(0(A`B$B(4(A8B&2(;(APB
M(2(B(B0B)"(F(B8B+"(M(B\B,R(X(CPB/B)'(DDB2R)-(E$B4R)?(F(B8R)H
M(FTB<"*4(I8BF"*:(J0BIB*^(L`B$2,3(U\D:B1S))PD_R1,)4\E="6`)9`E
MDB66)9\EHB6Q);0ENR6^)<4ER"7*)<PES270)>$EYB4$)@<F""8*)C\F029!
M)D,F@"Z"+H,NA2Z'+HDNBBZ-+I8NF"ZF+J@NJ2ZK+JTNKRZR+K0NM2ZX+KHN
MO"[)+LLN[R_\+_\O!#`$,!@P'#`?,"`P*C`],#\P0#"4,)HPGS"@,/<P^S#_
M,`0Q*C$?,BHR,#(R,J(RI#*-,Y`SFS.?,Z`SHC/#,\4SS3//,]`STS/4,]8S
M1C1(-'(T=#2=-9\U#38/-ADV&S87.1DY;3EO.<XYT3G>.>`Y<CIT.DT[3SMM
M/&\\WSSA/%5`5T!>06!!-D,X0ZM#K4.P0[)#W$/>0]5$UT1+1DU&8$9B1B)'
M)$<H1RI'>T=]1XQ'CD=&24A)>4E[27Q)?DF!281)A$F'29I)G$F>2:!)M4FX
M279,>$R>3*1,$DT:3:U-KTW_3::?_]=EZ"OY+?EX^7KYE/F6^>;YZ/GP^?+Y
M"_H0^A#Z$OH2^A7Z%_H9^A[Z(OHB^B7Z)OHJ^B_^,OXR_D7^2/Y3_E/^6/Y8
M_F?^9_YL_@#_7__?_^;___]1`OW_1`%(`?W_80(````````````````U_C;^
M.?XZ_C_^0/X]_C[^0?Y"_D/^1/[]__W_._X\_C?^./XQ_OW_,_XT_@``````
M`````````````````````DX$3@5.!DX/3A).%TX?3B!.(4XC3B9.*4XN3B].
M,4XS3C5.-TX\3D!.04Y"3D1.1DY*3E%.54Y73EI.6TYB3F-.9$YE3F=.:$YJ
M3FM.;$YM3FY.;TYR3G1.=4YV3G=.>$YY3GI.>TY\3GU.?TZ`3H%.@DZ#3H1.
MA4Z'3HI.D$Z63I=.F4Z<3IU.GDZC3JI.KTZP3K%.M$ZV3K=.N$ZY3KQ.O4Z^
M3LA.S$[/3M!.TD[:3MM.W$[@3N).YD[G3NE.[4[N3N].\4[T3OA.^4[Z3OQ.
M_DX`3P)/`T\$3P5/!D\'3PA/"T\,3Q)/$T\43Q5/%D\<3QU/(4\C3RA/*4\L
M3RU/+D\Q3S-/-4\W3SE/.T\^3S]/0$]!3T)/1$]%3T=/2$])3TI/2T],3U)/
M5$]63V%/8D]F3VA/:D]K3VU/;D]Q3W)/=4]W3WA/>4]Z3WU/@$^!3X)/A4^&
M3X=/BD^,3XY/D$^23Y-/E4^63YA/F4^:3YQ/GD^?3Z%/HD^D3ZM/K4^P3[%/
MLD^S3[1/MD^W3[A/N4^Z3[M/O$^]3[Y/P$_!3\)/QD_'3\A/R4_+3\Q/S4_2
M3]-/U$_53]9/V4_;3^!/XD_D3^5/YT_K3^Q/\$_R3_1/]4_V3_=/^4_[3_Q/
M_4__3P!0`5`"4`-0!%`%4`90!U`(4`E0"E`+4`Y0$%`14!-0%5`64!=0&U`=
M4!Y0(%`B4"-0)%`G4"M0+U`P4#%0,E`S4#10-5`V4#=0.%`Y4#M0/5`_4$!0
M05!"4$1015!&4$E02E!+4$U04%!14%)04U!44%905U!84%E06U!=4%Y07U!@
M4&%08E!C4&109E!G4&A0:5!J4&M0;5!N4&]0<%!Q4')0<U!T4'50>%!Y4'I0
M?%!]4(%0@E"#4(10AE"'4(E0BE"+4(Q0CE"/4)!0D5"24)-0E%"54)90EU"8
M4)E0FE";4)Q0G5">4)]0H%"A4*)0I%"F4*I0JU"M4*Y0KU"P4+%0LU"T4+50
MME"W4+A0N5"\4+U0OE"_4,!0P5#"4,-0Q%#%4,90QU#(4,E0RE#+4,Q0S5#.
M4-!0T5#24--0U%#54-=0V%#94-M0W%#=4-Y0WU#@4.%0XE#C4.10Y5#H4.E0
MZE#K4.]0\%#Q4/)0]%#V4/=0^%#Y4/I0_%#]4/Y0_U``40%1`E$#4011!5$(
M40E1"E$,40U1#E$/41!1$5$34111%5$641=1&%$941I1&U$<41U1'E$?42!1
M(E$C4211)5$F42=1*%$I42I1*U$L42U1+E$O43!1,5$R43-1-%$U4391-U$X
M43E1.E$[43Q1/5$^44)11U%*44Q13E%/45!14E%345=16%%945M175%>45]1
M8%%A46-19%%F46=1:5%J46]1<E%Z47Y1?U&#4811AE&'48I1BU&.48]1D%&1
M49-1E%&849I1G5&>49]1H5&C4:91IU&H4:E1JE&M4:Y1M%&X4;E1NE&^4;]1
MP5'"4<-1Q5'(4<I1S5'.4=!1TE'34=11U5'64==1V%'94=I1W%'>4=]1XE'C
M4>51YE'G4>A1Z5'J4>Q1[E'Q4?)1]%'W4?Y1!%(%4@E2"U(,4@]2$%(34A12
M%5(<4AY2'U(A4B)2(U(E4B92)U(J4BQ2+U(Q4C)2-%(U4CQ2/E)$4D521E)'
M4DA225)+4DY23U)24E-255)74EA265):4EM275)?4F!28E)C4F129E)H4FM2
M;%)M4FY2<%)Q4G-2=%)U4G92=U)X4GE2>E)[4GQ2?E*`4H-2A%*%4H92AU*)
M4HI2BU*,4HU2CE*/4I%2DE*44I52EE*74IA2F5*:4IQ2I%*E4J92IU*N4J]2
ML%*T4K52ME*W4KA2N5*Z4KM2O%*]4L!2P5+"4L12Q5+&4LA2RE+,4LU2SE+/
M4M%2TU+44M52UU+94MI2VU+<4MU2WE+@4N%2XE+C4N52YE+G4NA2Z5+J4NM2
M[%+M4NY2[U+Q4O)2\U+T4O52]E+W4OA2^U+\4OU2`5,"4P-3!%,'4PE3"E,+
M4PQ3#E,14Q)3$U,44QA3&U,<4QY3'U,B4R13)5,G4RA3*5,K4RQ3+5,O4S!3
M,5,R4S-3-%,U4S93-U,X4SQ3/5-`4T)31%-&4TM33%--4U!35%-84UE36U-=
M4V53:%-J4VQ3;5-R4W93>5-[4WQ3?5-^4X!3@5.#4X=3B%.*4XY3CU.04Y%3
MDE.34Y13EE.74YE3FU.<4YY3H%.A4Z13IU.J4ZM3K%.M4Z]3L%.Q4[)3LU.T
M4[53MU.X4[E3NE.\4[U3OE/`4\-3Q%/%4\93QU/.4\]3T%/24]-3U5/:4]Q3
MW5/>4^%3XE/G4_13^E/^4_]3`%0"5`54!U0+5!14&%095!I4'%0B5"14)50J
M5#!4,U0V5#=4.E0]5#]4051"5$14151'5$E43%1-5$Y43U115%I4751>5%]4
M8%1A5&-4951G5&E4:E1K5&Q4;51N5&]4<%1T5'E4>E1^5']4@52#5(54AU2(
M5(E4BE2-5)%4DU275)A4G%2>5)]4H%2A5*)4I52N5+!4LE2U5+94MU2Y5+I4
MO%2^5,-4Q53*5,M4UE385-M4X%3A5.)4XU3D5.M4[%3O5/!4\53T5/54]E3W
M5/A4^53[5/Y4`%4"50-5!%4%50A5"E4+50Q5#54.51)5$U455195%U4851E5
M&E4<51U5'E4?52%5)54F52A5*54K52U5,E4T5355-E4X53E5.E4[53U50%5"
M54551U5(54M53%5-54Y53U5155)54U5455=56%5955I56U5=55Y57U5@56)5
M8U5H56E5:U5O57!5<55R57-5=%5Y57I5?55_5855AE6,58U5CE6059)5DU65
M5995EU6:59M5GE6@5:%5HE6C5:15I56F5:A5J56J5:M5K%6M5:Y5KU6P5;)5
MM%6V5;A5NE6\5;]5P%7!5<)5PU7&5<=5R%7*5<M5SE7/5=!5U5775=A5V57:
M5=M5WE7@5>)5YU7I5>U5[E7P5?%5]%7V5?A5^57Z5?M5_%7_50)6`U8$5@56
M!E8'5@I6"U8-5A!6$5825A-6%%855A96%U895AI6'%8=5B!6(58B5B56)E8H
M5BE6*E8K5BY6+U8P5C-6-58W5CA6.E8\5CU6/E9`5D%60E9#5D16159&5D=6
M2%9)5DI62U9/5E!645925E-655965EI66U9=5EY67U9@5F%68U9E5F969U9M
M5FY6;U9P5G)6<U9T5G56=U9X5GE6>E9]5GY6?U:`5H%6@E:#5H16AU:(5HE6
MBE:+5HQ6C5:05I%6DE:45I56EE:75IA6F5::5IM6G%:=5IY6GU:@5J%6HE:D
M5J56IE:G5JA6J5:J5JM6K%:M5JY6L%:Q5K)6LU:T5K56ME:X5KE6NE:[5KU6
MOE:_5L!6P5;"5L-6Q%;%5L96QU;(5LE6RU;,5LU6SE;/5M!6T5;25M-6U5;6
M5MA6V5;<5N-6Y5;F5N=6Z%;I5NI6[%;N5N]6\E;S5O96]U;X5OM6_%8`5P%7
M`E<%5P=7"U<,5PU7#E</5Q!7$5<25Q-7%%<55Q97%U<85QE7&E<;5QU7'E<@
M5R%7(E<D5R57)E<G5RM7,5<R5S17-5<V5S=7.%<\5SU7/U=!5T-71%=%5T97
M2%=)5TM74E=35U1755=65UA765=B5V-795=G5VQ7;E=P5W%7<E=T5W57>%=Y
M5WI7?5=^5W]7@%>!5X=7B%>)5XI7C5>.5X]7D%>15Y17E5>65Y=7F%>95YI7
MG%>=5YY7GU>E5ZA7JE>L5Z]7L%>Q5[-7M5>V5[=7N5>Z5[M7O%>]5[Y7OU?`
M5\%7Q%?%5\97QU?(5\E7RE?,5\U7T%?15]-7UE?75]M7W%?>5^%7XE?C5^57
MYE?G5^A7Z5?J5^M7[%?N5_!7\5?R5_-7]5?V5_=7^U?\5_Y7_U<!6`-8!%@%
M6`A8"5@*6`Q8#E@/6!!8$E@36!18%E@76!A8&E@;6!Q8'5@?6")8(U@E6"98
M)U@H6"E8*U@L6"U8+E@O6#%8,E@S6#18-E@W6#A8.5@Z6#M8/%@]6#Y8/UA`
M6$%80EA#6$581EA'6$A825A*6$M83EA/6%!84EA36%585EA76%E86EA;6%Q8
M75A?6&!885AB6&-89%AF6&=8:%AI6&I8;5AN6&]8<%AQ6')8<UAT6'58=EAW
M6'A8>5AZ6'M8?%A]6']8@EB$6(98AUB(6(I8BUB,6(U8CEB/6)!8D5B46)58
MEEB76)A8FUB<6)U8H%BA6*)8HUBD6*58IEBG6*I8JUBL6*U8KEBO6+!8L5BR
M6+-8M%BU6+98MUBX6+E8NEB[6+U8OEB_6,!8PEC#6,18QEC'6,A8R5C*6,M8
MS%C-6,Y8SUC06-)8TUC46-98UUC86-E8VEC;6-Q8W5C>6-]8X%CA6.)8XUCE
M6.98YUCH6.E8ZECM6.]8\5CR6/18]5CW6/A8^EC[6/Q8_5C^6/]8`%D!60-9
M!5D&60A9"5D*60M9#%D.61!9$5D261-9%UD861M9'5D>62!9(5DB62-9)EDH
M62Q9,%DR63-9-5DV63M9/5D^63]90%E#64591EE*64Q935E065)94UE965M9
M7%E=65Y97UEA66-99%EF66=9:%EI66I9:UEL66U9;EEO67!9<5ER6759=UEZ
M67M9?%E^67]9@%F%68E9BUF,68Y9CUF069%9E%F569A9FEF;69Q9G5F?6:!9
MH5FB6:99IUFL6:U9L%FQ6;-9M%FU6;99MUFX6;I9O%F]6;]9P%G!6<)9PUG$
M6<59QUG(6<E9S%G-6<Y9SUG56=99V5G;6=Y9WUG@6>%9XEGD6>99YUGI6>I9
MZUGM6>Y9[UGP6?%9\EGS6?19]5GV6?=9^%GZ6?Q9_5G^60!:`EH*6@M:#5H.
M6@]:$%H26A1:%5H66A=:&5H:6AM:'5H>6B%:(EHD6B9:)UHH6BI:*UHL6BU:
M+EHO6C!:,UHU6C=:.%HY6CI:.UH]6CY:/UI!6D):0UI$6D5:1UI(6DM:3%I-
M6DY:3UI06E%:4EI36E1:5EI76EA:65I;6EQ:75I>6E]:8%IA6F-:9%IE6F9:
M:%II6FM:;%IM6FY:;UIP6G%:<EIS6GA:>5I[6GQ:?5I^6H!:@5J"6H-:A%J%
M6H9:AUJ(6HE:BEJ+6HQ:C5J.6H]:D%J16I-:E%J56I9:EUJ86IE:G%J=6IY:
MGUJ@6J%:HEJC6J1:I5JF6J=:J%JI6JM:K%JM6JY:KUJP6K%:M%JV6K=:N5JZ
M6KM:O%J]6K]:P%K#6L1:Q5K&6L=:R%K*6LM:S5K.6L]:T%K16M-:U5K76ME:
MVEK;6MU:WEK?6N):Y%KE6N=:Z%KJ6NQ:[5KN6N]:\%KR6O-:]%KU6O9:]UKX
M6OE:^EK[6OQ:_5K^6O]:`%L!6P);`UL$6P5;!EL'6PA;"EL+6PQ;#5L.6P];
M$%L16Q);$UL46Q5;&%L96QI;&UL<6QU;'EL?6R!;(5LB6R-;)%LE6R9;)ULH
M6RE;*ELK6RQ;+5LN6R];,%LQ6S-;-5LV6SA;.5LZ6SM;/%L]6SY;/UM!6T);
M0UM$6T5;1EM'6TA;25M*6TM;3%M-6TY;3UM26U9;7EM@6V%;9UMH6VM;;5MN
M6V];<EMT6W9;=UMX6WE;>UM\6WY;?UN"6X9;BEN-6XY;D%N16Y);E%N66Y];
MIUNH6ZE;K%NM6ZY;KUNQ6[);MUNZ6[M;O%O`6\%;PUO(6\E;REO+6\U;SEO/
M6]%;U%O56]9;UUO86]E;VEO;6]Q;X%OB6^-;YEOG6^E;ZEOK6^Q;[5OO6_%;
M\EOS6_1;]5OV6_=;_5O^6P!<`EP#7`5<!UP(7`M<#%P-7`Y<$%P27!-<%UP9
M7!M<'EP?7"!<(5PC7"9<*%PI7"I<*UPM7"Y<+UPP7#)<,UPU7#9<-UQ#7$1<
M1EQ'7$Q<35Q27%-<5%Q67%=<6%Q:7%M<7%Q=7%]<8EQD7&=<:%QI7&I<:UQL
M7&U<<%QR7'-<=%QU7'9<=UQX7'M<?%Q]7'Y<@%R#7(1<A5R&7(=<B5R*7(M<
MCER/7))<DUR57)U<GER?7*!<H5RD7*5<IERG7*A<JERN7*]<L%RR7+1<MERY
M7+I<NUR\7+Y<P%S"7,-<Q5S&7,=<R%S)7,I<S%S-7,Y<SUS07-%<TUS47-5<
MUES77-A<VES;7-Q<W5S>7-]<X%SB7.-<YUSI7.M<[%SN7.]<\5SR7/-<]%SU
M7/9<]USX7/E<^ES\7/U<_ES_7`!=`5T$705="%T)70I="UT,70U=#UT071%=
M$ET3715=%UT871E=&ET<71U='UT@72%=(ETC725=*%TJ72M=+%TO73!=,5TR
M73-=-5TV73==.%TY73I=.UT\73]=0%U!74)=0UU$745=1EU(74E=35U.74]=
M4%U175)=4UU4755=5EU775E=6EU<75Y=7UU@76%=8EUC761=95UF76==:%UJ
M76U=;EUP77%=<EUS775==EUW77A=>5UZ77M=?%U]77Y=?UV`78%=@UV$785=
MAEV'78A=B5V*78M=C%V-78Y=CUV079%=DEV3791=E5V679==F%V:79M=G%V>
M79]=H%VA7:)=HUVD7:5=IEVG7:A=J5VJ7:M=K%VM7:Y=KUVP7;%=LEVS7;1=
MM5VV7;A=N5VZ7;M=O%V]7;Y=OUW`7<%=PEW#7<1=QEW'7<A=R5W*7<M=S%W.
M7<]=T%W17=)=TUW47=5=UEW77=A=V5W:7=Q=WUW@7>-=Y%WJ7>Q=[5WP7?5=
M]EWX7?E=^EW[7?Q=_UT`7@1>!UX)7@I>"UX-7@Y>$EX37A=>'EX?7B!>(5XB
M7B->)%XE7BA>*5XJ7BM>+%XO7C!>,EXS7C1>-5XV7CE>.EX^7C]>0%Y!7D->
M1EY'7DA>25Y*7DM>35Y.7D]>4%Y17E)>4UY67E=>6%Y97EI>7%Y=7E]>8%YC
M7F1>95YF7F=>:%YI7FI>:UYL7FU>;EYO7G!><5YU7G=>>5Y^7H%>@EZ#7H5>
MB%Z)7HQ>C5Z.7I)>F%Z;7IU>H5ZB7J->I%ZH7JE>JEZK7JQ>KEZO7K!>L5ZR
M7K1>NEZ[7KQ>O5Z_7L!>P5["7L->Q%[%7L9>QU[(7LM>S%[-7LY>SU[07M1>
MU5[77MA>V5[:7MQ>W5[>7M]>X%[A7N)>XU[D7N5>YE[G7NE>ZU[L7NU>[E[O
M7O!>\5[R7O->]5[X7OE>^U[\7OU>!5\&7P=?"5\,7PU?#E\07Q)?%%\67QE?
M&E\<7QU?'E\A7R)?(U\D7RA?*U\L7RY?,%\R7S-?-%\U7S9?-U\X7SM?/5\^
M7S]?05]"7T-?1%]%7T9?1U](7TE?2E]+7TQ?35].7T]?45]47UE?6E];7UQ?
M7E]?7V!?8U]E7V=?:%]K7VY?;U]R7W1?=5]V7WA?>E]]7WY??U^#7X9?C5^.
M7X]?D5^37Y1?EE^:7YM?G5^>7Y]?H%^B7Z-?I%^E7Z9?IU^I7ZM?K%^O7[!?
ML5^R7[-?M%^V7[A?N5^Z7[M?OE^_7\!?P5_"7\=?R%_*7\M?SE_37]1?U5_:
M7]M?W%_>7]]?XE_C7^5?YE_H7^E?[%_O7_!?\E_S7_1?]E_W7_E?^E_\7P=@
M"&`)8`M@#&`08!%@$V`78!A@&F`>8!]@(F`C8"1@+&`M8"Y@,&`Q8#)@,V`T
M8#9@-V`X8#E@.F`]8#Y@0&!$8$5@1F!'8$A@26!*8$Q@3F!/8%%@4V!48%9@
M5V!88%M@7&!>8%]@8&!A8&5@9F!N8'%@<F!T8'5@=V!^8(!@@6""8(5@AF"'
M8(A@BF"+8(Y@CV"08)%@DV"58)=@F&"98)Q@GF"A8*)@I&"E8*=@J6"J8*Y@
ML&"S8+5@MF"W8+E@NF"]8+Y@OV#`8,%@PF##8,1@QV#(8,E@S&#-8,Y@SV#0
M8-)@TV#48-9@UV#98-M@WF#A8.)@XV#D8.5@ZF#Q8/)@]6#W8/A@^V#\8/U@
M_F#_8`)A`V$$805A!V$*80MA#&$081%A$F$3811A%F$781AA&6$;81QA'6$>
M82%A(F$E82AA*6$J82QA+6$N82]A,&$Q83)A,V$T835A-F$W83AA.6$Z83MA
M/&$]83YA0&%!84)A0V%$845A1F%'84EA2V%-84]A4&%285-A5&%685=A6&%9
M85IA6V%<85YA7V%@86%A8V%D865A9F%I86IA:V%L86UA;F%O87%A<F%S871A
M=F%X87EA>F%[87QA?6%^87]A@&&!88)A@V&$885AAF&'88AAB6&*88QAC6&/
M89!AD6&289-AE6&689=AF&&989IAFV&<89YAGV&@8:%AHF&C8:1AI6&F8:IA
MJV&M8:YAKV&P8;%ALF&S8;1AM6&V8;AAN6&Z8;MAO&&]8;]AP&'!8<-AQ&'%
M8<9AQV')8<QAS6'.8<]AT&'38=5AUF'78=AAV6':8=MAW&'=8=YAWV'@8>%A
MXF'C8>1AY6'G8>AAZ6'J8>MA[&'M8>YA[V'P8?%A\F'S8?1A]F'W8?AA^6'Z
M8?MA_&']8?YA`&(!8@)B`V($8@5B!V()8A-B%&(98AQB'6(>8B!B(V(F8B=B
M*&(I8BMB+6(O8C!B,6(R8C5B-F(X8CEB.F([8CQB0F)$8D5B1F)*8D]B4&)5
M8E9B5V)98EIB7&)=8EYB7V)@8F%B8F)D8F5B:&)Q8G)B=&)U8G=B>&)Z8GMB
M?6*!8H)B@V*%8H9BAV*(8HMBC&*-8HYBCV*08I1BF6*<8IUBGF*C8J9BIV*I
M8JIBK6*N8J]BL&*R8K-BM&*V8K=BN&*Z8KYBP&+!8L-BRV+/8M%BU6+=8MYB
MX&+A8N1BZF+K8O!B\F+U8OAB^6+Z8OMB`&,#8P1C!6,&8PIC"V,,8PUC#V,0
M8Q)C$V,48Q5C%V,88QEC'&,F8R=C*6,L8RUC+F,P8S%C,V,T8S5C-F,W8SAC
M.V,\8SYC/V-`8T%C1&-'8TAC2F-18U)C4V-48U9C5V-88UEC6F-;8UQC76-@
M8V1C96-F8VAC:F-K8VQC;V-P8W)C<V-T8W5C>&-Y8WQC?6-^8W]C@6.#8X1C
MA6.&8XMCC6.18Y-CE&.58Y=CF6.:8YMCG&.=8YYCGV.A8Z1CIF.K8Z]CL6.R
M8[5CMF.Y8[MCO6._8\!CP6/"8\-CQ6/'8\ACRF/+8\QCT6/38]1CU6/78]AC
MV6/:8]MCW&/=8]]CXF/D8^5CYF/G8^ACZV/L8^YC[V/P8_%C\V/U8_=C^6/Z
M8_MC_&/^8P-D!&0&9`=D"&0)9`ID#60.9!%D$F059!9D%V089!ED&F0=9!]D
M(F0C9"1D)60G9"AD*60K9"YD+V0P9#%D,F0S9#5D-F0W9#AD.60[9#QD/F1`
M9$)D0V1)9$MD3&1-9$YD3V109%%D4V159%9D5V199%ID6V1<9%UD7V1@9&%D
M8F1C9&1D961F9&AD:F1K9&QD;F1O9'!D<61R9'-D=&1U9'9D=V1[9'QD?61^
M9']D@&2!9(-DAF2(9(EDBF2+9(QDC62.9(]DD&239)1DEV289)IDFV2<9)UD
MGV2@9*%DHF2C9*5DIF2G9*ADJF2K9*]DL62R9+-DM&2V9+EDNV2]9+YDOV3!
M9,-DQ&3&9,=DR&3)9,IDRV3,9,]DT6339-1DU6369-EDVF3;9-QDW63?9.!D
MX63C9.5DYV3H9.EDZF3K9.QD[63N9.]D\&3Q9/)D\V3T9/5D]F3W9/AD^63Z
M9/MD_&3]9/YD_V0!90)E`V4$905E!F4'90AE"F4+90QE#64.90]E$&4191-E
M%&45919E%V4991IE&V4<91UE'F4?92!E(64B92-E)&4F92=E*&4I92IE+&4M
M93!E,64R93-E-V4Z93QE/65`94%E0F5#941E1F5'94IE2V5-94YE4&5295-E
M5&5795AE6F5<95]E8&5A961E965G96AE:65J96UE;F5O97%E<V5U979E>&5Y
M97IE>V5\97UE?F5_98!E@66"98-EA&6%989EB&6)98IEC66.98]EDF64995E
MEF6899IEG66>9:!EHF6C9:9EJ&6J9:QEKF6Q9;)ELV6T9;5EMF6W9;AENF6[
M9;YEOV7`9<)EQV7(9<EERF7-9=!ET6739=1EU6789=EEVF7;9=QEW67>9=]E
MX67C9>1EZF7K9?)E\V7T9?5E^&7Y9?ME_&7]9?YE_V4!9@1F!68'9@AF"68+
M9@UF$&819A)F%F879AAF&F8;9AQF'F8A9B)F(V8D9B9F*68J9BMF+&8N9C!F
M,F8S9C=F.&8Y9CIF.V8]9C]F0&9"9D1F169&9D=F2&9)9DIF369.9E!F4698
M9EEF6V9<9EUF7F9@9F)F8V9E9F=F:69J9FMF;&9M9G%F<F9S9G5F>&9Y9GMF
M?&9]9G]F@&:!9H-FA6:&9HAFB6:*9HMFC6:.9H]FD&:29I-FE&:59IAFF6::
M9IMFG&:>9I]FH&:A9J)FHV:D9J5FIF:I9JIFJV:L9JUFKV:P9K%FLF:S9K5F
MMF:W9KAFNF:[9KQFO6:_9L!FP6;"9L-FQ&;%9L9FQV;(9LEFRF;+9LQFS6;.
M9L]FT&;19M)FTV;49M5FUF;79MAFVF;>9M]FX&;A9N)FXV;D9N5FYV;H9NIF
MZV;L9NUF[F;O9O%F]6;V9OAF^F;[9OUF`6<"9P-G!&<%9P9G!V<,9PYG#V<1
M9Q)G$V<69QAG&6<:9QQG'F<@9R%G(F<C9R1G)6<G9REG+F<P9S)G,V<V9S=G
M.&<Y9SMG/&<^9S]G06=$9T5G1V=*9TMG36=29U1G56=79UAG66=:9UMG76=B
M9V-G9&=F9V=G:V=L9VYG<6=T9W9G>&=Y9WIG>V=]9X!G@F>#9X5GAF>(9XIG
MC&>-9XYGCV>19Y)GDV>49Y9GF6>;9Y]GH&>A9Z1GIF>I9ZQGKF>Q9[)GM&>Y
M9[IGNV>\9[UGOF>_9\!GPF?%9\9GQV?(9\EGRF?+9\QGS6?.9]5GUF?79]MG
MWV?A9^-GY&?F9^=GZ&?J9^MG[6?N9_)G]6?V9_=G^&?Y9_IG^V?\9_YG`6@"
M:`-H!&@&:`UH$&@2:!1H%6@8:!EH&F@;:!QH'F@?:"!H(F@C:"1H)6@F:"=H
M*&@K:"QH+6@N:"]H,&@Q:#1H-6@V:#IH.V@_:$=H2VA-:$]H4FA6:%=H6&A9
M:%IH6VA<:%UH7FA?:&IH;&AM:&YH;VAP:'%H<FAS:'5H>&AY:'IH>VA\:'UH
M?FA_:(!H@FB$:(=HB&B):(IHBVB,:(UHCFB0:)%HDFB4:)5HEFB8:)EHFFB;
M:)QHG6B>:)]HH&BA:*-HI&BE:*EHJFBK:*QHKFBQ:+)HM&BV:+=HN&BY:+IH
MNVB\:+UHOFB_:,%HPVC$:,5HQFC':,AHRFC,:,YHSVC0:-%HTVC4:-9HUVC9
M:-MHW&C=:-YHWVCA:.)HY&CE:.9HYVCH:.EHZFCK:.QH[6CO:/)H\VCT:/9H
M]VCX:/MH_6C^:/]H`&D":0-I!&D&:0=I"&D):0II#&D/:1%I$VD4:15I%FD7
M:1AI&6D::1MI'&D=:1YI(6DB:2-I)6DF:2=I*&DI:2II*VDL:2YI+VDQ:3)I
M,VDU:39I-VDX:3II.VD\:3YI0&E!:4-I1&E%:49I1VE(:4EI2FE+:4QI36E.
M:4]I4&E1:5)I4VE5:59I6&E9:5MI7&E?:6%I8FED:65I9VEH:6EI:FEL:6UI
M;VEP:7)I<VET:75I=FEZ:7MI?6E^:7]I@6F#:85IBFF+:8QICFF/:9!ID6F2
M:9-IEFF7:9EIFFF=:9YIGVF@::%IHFFC::1II6FF::EIJFFL::YIKVFP:;)I
MLVFU:;9IN&FY:;IIO&F]:;YIOVG`:<)IPVG$:<5IQFG':<AIR6G+:<UISVG1
M:=)ITVG5:=9IUVG8:=EIVFG<:=UIWFGA:>)IXVGD:>5IYFGG:>AIZ6GJ:>MI
M[&GN:>]I\&GQ:?-I]&GU:?9I]VGX:?EI^FG[:?QI_FD`:@%J`FH#:@1J!6H&
M:@=J"&H):@MJ#&H-:@YJ#VH0:A%J$FH3:A1J%6H6:AEJ&FH;:AQJ'6H>:B!J
M(FHC:B1J)6HF:B=J*6HK:BQJ+6HN:C!J,FHS:C1J-FHW:CAJ.6HZ:CMJ/&H_
M:D!J06I":D-J16I&:DAJ26I*:DMJ3&I-:DYJ3VI1:E)J4VI4:E5J5FI7:EIJ
M7&I=:EYJ7VI@:F)J8VID:F9J9VIH:FEJ:FIK:FQJ;6IN:F]J<&IR:G-J=&IU
M:G9J=VIX:GIJ>VI]:GYJ?VJ!:H)J@VJ%:H9JAVJ(:HEJBFJ+:HQJC6J/:I)J
MDVJ4:I5JEFJ8:IEJFFJ;:IQJG6J>:I]JH6JB:J-JI&JE:J9JIVJH:JIJK6JN
M:J]JL&JQ:K)JLVJT:K5JMFJW:KAJN6JZ:KMJO&J]:KYJOVK`:L%JPFK#:L1J
MQ6K&:L=JR&K):LIJRVK,:LUJSFK/:M!JT6K2:M-JU&K5:M9JUVK8:MEJVFK;
M:MQJW6K>:M]JX&KA:N)JXVKD:N5JYFKG:NAJZ6KJ:NMJ[&KM:NYJ[VKP:O%J
M\FKS:O1J]6KV:O=J^&KY:OIJ^VK\:OUJ_FK_:@!K`6L":P-K!&L%:P9K!VL(
M:PEK"FL+:PQK#6L.:P]K$&L1:Q)K$VL4:Q5K%FL7:QAK&6L::QMK'&L=:QYK
M'VLE:R9K*&LI:RIK*VLL:RUK+FLO:S!K,6LS:S1K-6LV:SAK.VL\:SUK/VM`
M:T%K0FM$:T5K2&M*:TMK36M.:T]K4&M1:U)K4VM4:U5K5FM7:UAK6FM;:UQK
M76M>:U]K8&MA:VAK:6MK:VQK;6MN:V]K<&MQ:W)K<VMT:W5K=FMW:WAK>FM]
M:WYK?VN`:X5KB&N,:XYKCVN0:Y%KE&N5:Y=KF&N9:YQKG6N>:Y]KH&NB:Z-K
MI&NE:Z9KIVNH:ZEKJVNL:ZUKKFNO:[!KL6NR:[9KN&NY:[IKNVN\:[UKOFO`
M:\-KQ&O&:\=KR&O):\IKS&O.:]!KT6O8:]IKW&O=:]YKWVO@:^)KXVOD:^5K
MYFOG:^AKZ6OL:^UK[FOP:_%K\FOT:_9K]VOX:_IK^VO\:_YK_VL`;`%L`FP#
M;`1L"&P);`IL"VP,;`YL$FP7;!QL'6P>;"!L(VPE;"ML+&PM;#%L,VPV;#=L
M.6PZ;#ML/&P^;#]L0VQ$;$5L2&Q+;$QL36Q.;$]L46Q2;%-L5FQ8;%EL6FQB
M;&-L96QF;&=L:VQL;&UL;FQO;'%L<VQU;'=L>&QZ;'ML?&Q_;(!LA&R';(IL
MBVR-;(YLD6R2;)5LEFR7;)ALFFR<;)ULGFR@;*)LJ&RL;*]LL&RT;+5LMFRW
M;+ILP&S!;,)LPVS&;,=LR&S+;,ULSFS/;-%LTFS8;-ELVFS<;-ULWVSD;.9L
MYVSI;.QL[6SR;/1L^6S_;`!M`FT#;05M!FT(;0EM"FT-;0]M$&T1;1-M%&T5
M;19M&&T<;1UM'VT@;2%M(FTC;21M)FTH;2EM+&TM;2]M,&TT;39M-VTX;3IM
M/VU`;4)M1&U);4QM4&U5;59M5VU8;5MM76U?;6%M8FUD;65M9VUH;6MM;&UM
M;7!M<6UR;7-M=6UV;7EM>FU[;7UM?FU_;8!M@6V#;81MAFV';8IMBVV-;8]M
MD&V2;99MEVV8;9EMFFV<;:)MI6VL;:UML&VQ;;-MM&VV;;=MN6VZ;;MMO&V]
M;;YMP6W";<-MR&W);<IMS6W.;<]MT&W2;=-MU&W5;==MVFW;;=QMWVWB;>-M
MY6WG;>AMZ6WJ;>UM[VWP;?)M]&WU;?9M^&WZ;?UM_FW_;0!N`6X";@-N!&X&
M;@=N"&X);@MN#VX2;A-N%6X8;AEN&VX<;AYN'VXB;B9N)VXH;BIN+&XN;C!N
M,6XS;C5N-FXW;CEN.VX\;CUN/FX_;D!N06Y";D5N1FY';DAN26Y*;DMN3&Y/
M;E!N46Y2;E5N5VY9;EIN7&Y=;EYN8&YA;F)N8VYD;F5N9FYG;FAN:6YJ;FQN
M;6YO;G!N<6YR;G-N=&YU;G9N=VYX;GEN>FY[;GQN?6Z`;H%N@FZ$;H=NB&Z*
M;HMNC&Z-;HYND6Z2;I-NE&Z5;I9NEVZ9;IINFVZ=;IYNH&ZA;J-NI&ZF;JAN
MJ6ZK;JQNK6ZN;K!NLVZU;KANN6Z\;KYNOV[`;L-NQ&[%;L9NR&[);LINS&[-
M;LYNT&[2;M9NV&[9;MMNW&[=;N-NYV[J;NMN[&[M;NYN[V[P;O%N\F[S;O5N
M]F[W;OAN^F[[;OQN_6[^;O]N`&\!;P-O!&\%;P=O"&\*;PMO#&\-;PYO$&\1
M;Q)O%F\7;QAO&6\:;QMO'&\=;QYO'V\A;R)O(V\E;R9O)V\H;RQO+F\P;S)O
M-&\U;S=O.&\Y;SIO.V\\;SUO/V]`;T%O0F]#;T1O16](;TEO2F],;TYO3V]0
M;U%O4F]3;U1O56]6;U=O66]:;UMO76]?;V!O86]C;V1O96]G;VAO:6]J;VMO
M;&]O;W!O<6]S;W5O=F]W;WEO>V]];WYO?V^`;X%O@F^#;X5OAF^';XIOBV^/
M;Y!OD6^2;Y-OE&^5;Y9OEV^8;YEOFF^;;YUOGF^?;Z!OHF^C;Z1OI6^F;ZAO
MJ6^J;ZMOK&^M;ZYOKV^P;[%OLF^T;[5OMV^X;[IONV^\;[UOOF^_;\%OPV_$
M;\5OQF_';\AORF_+;\QOS6_.;\]OT&_3;]1OU6_6;]=OV&_9;]IOVV_<;]UO
MWV_B;^-OY&_E;^9OYV_H;^EOZF_K;^QO[6_P;_%O\F_S;_1O]6_V;_=O^&_Y
M;_IO^V_\;_UO_F__;P!P`7`"<`-P!'`%<`9P!W`(<`EP"G`+<`QP#7`.<`]P
M$'`2<!-P%'`5<!9P%W`8<!EP''`=<!YP'W`@<"%P(G`D<"5P)G`G<"AP*7`J
M<"MP+'`M<"YP+W`P<#%P,G`S<#1P-G`W<#AP.G`[<#QP/7`^<#]P0'!!<$)P
M0W!$<$5P1G!'<$AP27!*<$MP37!.<%!P47!2<%-P5'!5<%9P5W!8<%EP6G!;
M<%QP77!?<&!P87!B<&-P9'!E<&9P9W!H<&EP:G!N<'%P<G!S<'1P=W!Y<'IP
M>W!]<(%P@G"#<(1PAG"'<(APBW",<(UPCW"0<)%PDW"7<)APFG";<)YPGW"@
M<*%PHG"C<*1PI7"F<*=PJ'"I<*IPL'"R<+1PM7"V<+IPOG"_<,1PQ7#&<,=P
MR7#+<,QPS7#.<,]PT'#1<-)PTW#4<-5PUG#7<-IPW'#=<-YPX'#A<.)PXW#E
M<.IP[G#P</%P\G#S</1P]7#V</AP^G#[</QP_G#_<`!Q`7$"<0-Q!'$%<09Q
M!W$(<0MQ#'$-<0YQ#W$1<1)Q%'$7<1MQ''$=<1YQ'W$@<2%Q(G$C<21Q)7$G
M<2AQ*7$J<2MQ+'$M<2YQ,G$S<31Q-7$W<3AQ.7$Z<3MQ/'$]<3YQ/W%`<4%Q
M0G%#<41Q1G%'<4AQ27%+<4UQ3W%0<5%Q4G%3<51Q57%6<5=Q6'%9<5IQ6W%=
M<5]Q8'%A<6)Q8W%E<6EQ:G%K<6QQ;7%O<7!Q<7%T<75Q=G%W<7EQ>W%\<7YQ
M?W&`<8%Q@G&#<85QAG&'<8AQB7&+<8QQC7&.<9!QD7&2<9-QE7&6<9=QFG&;
M<9QQG7&><:%QHG&C<:1QI7&F<:=QJ7&J<:MQK7&N<:]QL'&Q<;)QM'&V<;=Q
MN'&Z<;MQO'&]<;YQOW'`<<%QPG'$<<5QQG''<<AQR7'*<<MQS''-<<]QT''1
M<=)QTW'6<==QV''9<=IQVW'<<=UQWG'?<>%QXG'C<>1QYG'H<>EQZG'K<>QQ
M[7'O<?!Q\7'R<?-Q]''U<?9Q]W'X<?IQ^W'\<?UQ_G'_<0!R`7("<@-R!'(%
M<@=R"'()<@IR"W(,<@UR#G(/<A!R$7(2<A-R%'(5<A9R%W(8<AER&G(;<AQR
M'G(?<B!R(7(B<B-R)'(E<B9R)W(I<BMR+7(N<B]R,G(S<C1R.G(\<CYR0')!
M<D)R0W)$<D5R1G))<DIR2W).<D]R4')1<E-R5')5<E=R6'):<EQR7G)@<F-R
M9')E<FAR:G)K<FQR;7)P<G%R<W)T<G9R=W)X<GMR?')]<H)R@W*%<H9RAW*(
M<HERC'*.<I!RD7*3<I1RE7*6<I=RF'*9<IIRFW*<<IURGG*@<J%RHG*C<J1R
MI7*F<J=RJ'*I<JIRJW*N<K%RLG*S<K5RNG*[<KQRO7*^<K]RP'+%<L9RQW+)
M<LIRRW+,<L]RT7+3<M1RU7+6<MARVG+;<LH"RP+9`A,@%2`E(#4@!2$)(98A
MER&8(9DA%2(?(B,B4B)F(F<BOR)0)5$E4B53)50E5256)5<E6"59)5HE6R5<
M)5TE7B5?)6`E825B)6,E9"5E)68E9R5H)6DE:B5K)6PE;25N)6\E<"5Q)7(E
M<R6!)8(E@R6$)84EAB6')8@EB26*)8LEC"6-)8XECR63)90EE26\);TEXB7C
M)>0EY24))I4B$C`=,!XP_?_]__W__?_]__W__?_]__W__?_]_R$P(C`C,"0P
M)3`F,"<P*#`I,*,RCC./,YPSG3.>,Z$SQ#/.,]$STC/5,S#^XO_D__W_(2$Q
M,OW_$"#]__W__?_\,)LPG##],/XP!C"=,)XP2?Y*_DO^3/Y-_D[^3_Y0_E'^
M4OY4_E7^5OY7_EG^6OY;_ES^7?Y>_E_^8/YA_F+^8_YD_F7^9OYH_FG^:OYK
M_OW__?_]__W__?_]__W__?_]__W__?_]__W_!S#]__W__?_]__W__?_]__W_
M_?_]_]QRW7+?<N)RXW+D<N5RYG+G<NIRZW+U<O9R^7+]<OYR_W(`<P)S!',%
M<P9S!W,(<PES"W,,<PUS#W,0<Q%S$G,4<QAS&7,:<Q]S(',C<R1S)G,G<RAS
M+7,O<S!S,G,S<S5S-G,Z<SMS/',]<T!S07-"<T-S1'-%<T9S1W-(<TES2G-+
M<TQS3G-/<U%S4W-4<U5S5G-8<UES6G-;<UQS77-><U]S87-B<V-S9'-E<V9S
M9W-H<VES:G-K<VYS<'-Q<W)S<W-T<W5S=G-W<WAS>7-Z<WMS?'-]<W]S@'.!
M<X)S@W.%<X9SB'.*<XQSC7./<Y!SDG.3<Y1SE7.7<YASF7.:<YQSG7.><Z!S
MH7.C<Z1SI7.F<Z=SJ'.J<ZQSK7.Q<[1SM7.V<[ASN7.\<[USOG._<\%SPW/$
M<\5SQG/'<\MSS'/.<])STW/4<]5SUG/7<]ASVG/;<]QSW7/?<^%SXG/C<^1S
MYG/H<^ISZW/L<^YS[W/P<_%S\W/T<_5S]G/W<_AS^7/Z<_MS_'/]<_YS_W,`
M=`%T`G0$=`=T"'0+=`QT#70.=!%T$G03=!1T%706=!=T&'09=!QT'70>=!]T
M('0A="-T)'0G="ET*W0M="]T,70R=#=T.'0Y=#IT.W0]=#YT/W1`=$)T0W1$
M=$5T1G1'=$AT271*=$MT3'1-=$YT3W10=%%T4G13=%1T5G18=%UT8'1A=&)T
M8W1D=&5T9G1G=&AT:71J=&MT;'1N=&]T<71R='-T='1U='AT>71Z='MT?'1]
M=']T@G2$=(5TAG2(=(ETBG2,=(UTCW21=))TDW24=)5TEG27=)ATF72:=)MT
MG72?=*!TH72B=*-TI'2E=*9TJG2K=*QTK72N=*]TL'2Q=+)TLW2T=+5TMG2W
M=+ATN72[=+QTO72^=+]TP'3!=,)TPW3$=,5TQG3'=,ATR73*=,MTS'3-=,YT
MSW30=-%TTW34=-5TUG37=-ATV73:=-MTW73?=.%TY73G=.ATZ73J=.MT['3M
M=/!T\73R=/-T]73X=/ET^G3[=/QT_73^=`!U`74"=0-U!74&=0=U"'4)=0IU
M"W4,=0YU$'42=11U%746=1=U&W4==1YU('4A=2)U(W4D=29U)W4J=2YU-'4V
M=3EU/'4]=3]U075"=4-U1'5&=4=U275*=4UU4'51=5)U4W55=59U5W58=5UU
M7G5?=6!U875B=6-U9'5G=6AU:75K=6QU;75N=6]U<'5Q=7-U=75V=7=U>G5[
M=7QU?75^=8!U@76"=81UA76'=8AUB76*=8QUC76.=9!UDW65=9AUFW6<=9YU
MHG6F=:=UJ'6I=:IUK76V=;=UNG6[=;]UP'7!=<9URW7,=<YUSW70==%UTW77
M==EUVG7<==UUWW7@=>%UY77I=>QU[77N=>]U\G7S=?5U]G7W=?AU^G7[=?UU
M_G4"=@1V!G8'=@AV"78+=@UV#G8/=A%V$G83=A1V%G8:=AQV'78>=B%V(W8G
M=BAV+'8N=B]V,78R=C9V-W8Y=CIV.W8]=D%V0G9$=D5V1G9'=DAV279*=DMV
M3G9/=E!V4792=E-V5797=EAV679:=EMV779?=F!V879B=F1V979F=F=V:'9I
M=FIV;'9M=FYV<'9Q=G)V<W9T=G5V=G9W=GEV>G9\=G]V@':!=H-VA7:)=HIV
MC':-=H]VD':2=I1VE7:7=IAVFG:;=IQVG7:>=I]VH':A=J)VHW:E=J9VIW:H
M=JEVJG:K=JQVK7:O=K!VLW:U=K9VMW:X=KEVNG:[=KQVO7:^=L!VP7;#=L1V
MQW;)=LMVS';3=M5VV7;:=MQVW7;>=N!VX7;B=N-VY';F=N=VZ';I=NIVZW;L
M=NUV\';S=O5V]G;W=OIV^W;]=O]V`'<"=P-W!7<&=PIW#'<.=P]W$'<1=Q)W
M$W<4=Q5W%G<7=QAW&W<<=QUW'G<A=R-W)'<E=R=W*G<K=RQW+G<P=S%W,G<S
M=S1W.7<[=SUW/G<_=T)W1'=%=T9W2'=)=TIW2W=,=TUW3G=/=U)W4W=4=U5W
M5G=7=UAW67=<=UUW7G=?=V!W9'=G=VEW:G=M=VYW;W=P=W%W<G=S=W1W=7=V
M=W=W>'=Z=WMW?'>!=X)W@W>&=X=WB'>)=XIWBW>/=Y!WDW>4=Y5WEG>7=YAW
MF7>:=YMWG'>==YYWH7>C=Z1WIG>H=ZMWK7>N=Z]WL7>R=[1WMG>W=[AWN7>Z
M=[QWOG?`=\%WPG?#=\1WQ7?&=\=WR'?)=\IWRW?,=\YWSW?0=]%WTG?3=]1W
MU7?6=]AWV7?:=]UWWG??=^!WX7?D=^9WZ'?J=^]W\'?Q=_)W]'?U=_=W^7?Z
M=_MW_'<#>`1X!7@&>`=X"'@*>`MX#G@/>!!X$W@5>!EX&W@>>"!X(7@B>"1X
M*'@J>"MX+G@O>#%X,G@S>#5X-G@]>#]X07A">$-X1'A&>$AX27A*>$MX37A/
M>%%X4WA4>%AX67A:>%MX7'A>>%]X8'AA>&)X8WAD>&5X9GAG>&AX:7AO>'!X
M<7AR>'-X='AU>'9X>'AY>'IX>WA]>'YX?WB`>(%X@GB#>(1XA7B&>(AXBGB+
M>(]XD'B2>)1XE7B6>)EXG7B>>*!XHGBD>*9XJ'BI>*IXJWBL>*UXKGBO>+5X
MMGBW>+AXNGB[>+QXO7B_>,!XPGC#>,1XQGC'>,AXS'C->,YXSWC1>-)XTWC6
M>-=XV'C:>-MXW'C=>-YXWWC@>.%XXGCC>.1XY7CF>.=XZ7CJ>.MX[7CN>.]X
M\'CQ>/-X]7CV>/AX^7C[>/QX_7C^>/]X`'D">0-Y!'D&>0=Y"'D)>0IY"WD,
M>0UY#GD/>1!Y$7D2>11Y%7D6>1=Y&'D9>1IY&WD<>1UY'WD@>2%Y(GDC>25Y
M)GDG>2AY*7DJ>2MY+'DM>2YY+WDP>3%Y,GDS>35Y-GDW>3AY.7D]>3]Y0GE#
M>41Y17E'>4IY2WE,>4UY3GE/>5!Y47E2>51Y57E8>5EY87EC>61Y9GEI>6IY
M:WEL>6YY<'EQ>7)Y<WET>75Y=GEY>7MY?'E]>7YY?WF">8-YAGF'>8AYB7F+
M>8QYC7F.>9!YD7F2>9-YE'F5>99YEWF8>9EYFWF<>9UYGGF?>:!YH7FB>:-Y
MI'FE>:9YJ'FI>:IYJWFL>:UYKGFO>;!YL7FR>;1YM7FV>;=YN'F\>;]YPGG$
M><5YQWG(><IYS'G.><]YT'G3>=1YUGG7>=EYVGG;>=QYW7G>>>!YX7GB>>5Y
MZ'GJ>>QY[GGQ>?)Y\WGT>?5Y]GGW>?EY^GG\>?YY_WD!>@1Z!7H'>@AZ"7H*
M>@QZ#WH0>A%Z$GH3>A5Z%GH8>AEZ&WH<>AUZ'WHA>B)Z)'HE>B9Z)WHH>BEZ
M*GHK>BQZ+7HN>B]Z,'HQ>C)Z-'HU>C9Z.'HZ>CYZ0'I!>D)Z0WI$>D5Z1WI(
M>DEZ2GI+>DQZ37I.>D]Z4'I2>E-Z5'I5>E9Z6'I9>EIZ6WI<>EUZ7GI?>F!Z
M87IB>F-Z9'IE>F9Z9WIH>FEZ:GIK>FQZ;7IN>F]Z<7IR>G-Z=7I[>GQZ?7I^
M>H)ZA7J'>HEZBGJ+>HQZCGJ/>I!ZDWJ4>IEZFGJ;>IYZH7JB>J-ZI'JG>JEZ
MJGJK>JYZKWJP>K%ZLGJT>K5ZMGJW>KAZN7JZ>KMZO'J]>KYZP'K!>L)ZPWK$
M>L5ZQGK'>LAZR7K*>LQZS7K.>L]ZT'K1>M)ZTWK4>M5ZUWK8>MIZVWK<>MUZ
MX7KB>N1ZYWKH>NEZZGKK>NQZ[GKP>O%Z\GKS>O1Z]7KV>O=Z^'K[>OQZ_GH`
M>P%[`GL%>P=["7L,>PU[#GL0>Q)[$WL6>Q=[&'L:>QQ['7L?>R%[(GLC>R=[
M*7LM>R][,'LR>S1[-7LV>S=[.7L[>SU[/WM`>T%[0GM#>T1[1GM(>TI[37M.
M>U-[57M7>UE[7'M>>U][87MC>V1[97MF>V=[:'MI>VI[:WML>VU[;WMP>W-[
M='MV>WA[>GM\>WU[?WN!>X)[@WN$>X9[AWN(>XE[BGN+>XQ[CGN/>Y%[DGN3
M>Y9[F'N9>YI[FWN>>Y][H'NC>Z1[I7NN>Z][L'NR>[-[M7NV>[=[N7NZ>[M[
MO'N]>[Y[OWO`>\)[PWO$>\5[R'O)>\I[RWO->\Y[SWO0>])[U'O5>]9[UWO8
M>]M[W'O>>]][X'OB>^-[Y'OG>^A[Z7OK>^Q[[7OO>_![\GOS>_1[]7OV>_A[
M^7OZ>_M[_7O_>P!\`7P"?`-\!'P%?`9\"'P)?`I\#7P.?!!\$7P2?!-\%'P5
M?!=\&'P9?!I\&WP<?!U\'GP@?"%\(GPC?"1\)7PH?"E\*WPL?"U\+GPO?#!\
M,7PR?#-\-'PU?#9\-WPY?#I\.WP\?#U\/GQ"?$-\1'Q%?$9\1WQ(?$E\2GQ+
M?$Q\3GQ/?%!\47Q2?%-\5'Q5?%9\5WQ8?%E\6GQ;?%Q\77Q>?%]\8'QA?&)\
M8WQD?&5\9GQG?&A\:7QJ?&M\;'QM?&Y\;WQP?'%\<GQU?'9\=WQX?'E\>GQ^
M?']\@'R!?()\@WR$?(5\AGR'?(A\BGR+?(Q\C7R.?(]\D'R3?)1\EGR9?)I\
MFWR@?*%\HWRF?*=\J'RI?*M\K'RM?*]\L'RT?+5\MGRW?+A\NGR[?+]\P'S"
M?,-\Q'S&?,E\RWS.?,]\T'S1?-)\TWS4?-A\VGS;?-U\WGSA?.)\XWSD?.5\
MYGSG?.E\ZGSK?.Q\[7SN?/!\\7SR?/-\]'SU?/9\]WSY?/I\_'S]?/Y\_WP`
M?0%]`GT#?01]!7T&?0=]"'T)?0M]#'T-?0Y]#WT0?1%]$GT3?11]%7T6?1=]
M&'T9?1I]&WT<?1U]'GT??2%](WTD?25])GTH?2E]*GTL?2U]+GTP?3%],GTS
M?31]-7TV?3=].'TY?3I].WT\?3U]/GT_?4!]07U"?4-]1'U%?49]1WU(?4E]
M2GU+?4Q]37U.?4]]4'U1?5)]4WU4?55]5GU7?5A]67U:?5M]7'U=?5Y]7WU@
M?6%]8GUC?61]97UF?6=]:'UI?6I]:WUL?6U];WUP?7%]<GUS?71]=7UV?7A]
M>7UZ?7M]?'U]?7Y]?WV`?8%]@GV#?81]A7V&?8=]B'V)?8I]BWV,?8U]CGV/
M?9!]D7V2?9-]E'V5?99]EWV8?9E]FGV;?9Q]G7V>?9]]H'VA?:)]HWVD?:5]
MIWVH?:E]JGVK?:Q]K7VO?;!]L7VR?;-]M'VU?;9]MWVX?;E]NGV[?;Q]O7V^
M?;]]P'W!?<)]PWW$?<5]QGW'?<A]R7W*?<M]S'W-?<Y]SWW0?=%]TGW3?=1]
MU7W6?==]V'W9?=I]VWW<?=U]WGW??>!]X7WB?>-]Y'WE?>9]YWWH?>E]ZGWK
M?>Q][7WN?>]]\'WQ??)]\WWT??5]]GWW??A]^7WZ??M]_'W]??Y]_WT`?@%^
M`GX#?@1^!7X&?@=^"'X)?@I^"WX,?@U^#GX/?A!^$7X2?A-^%'X5?A9^%WX8
M?AE^&GX;?AQ^'7X>?A]^('XA?B)^(WXD?B5^)GXG?BA^*7XJ?BM^+'XM?BY^
M+WXP?C%^,GXS?C1^-7XV?C=^.'XY?CI^/'X]?CY^/WY`?D)^0WY$?D5^1GY(
M?DE^2GY+?DQ^37Y.?D]^4'Y1?E)^4WY4?E5^5GY7?EA^67Y:?EM^7'Y=?EY^
M7WY@?F%^8GYC?F1^97YF?F=^:'YI?FI^:WYL?FU^;GYO?G!^<7YR?G-^='YU
M?G9^=WYX?GE^>GY[?GQ^?7Y^?G]^@'Z!?H-^A'Z%?H9^AWZ(?HE^BGZ+?HQ^
MC7Z.?H]^D'Z1?I)^DWZ4?I5^EGZ7?IA^F7Z:?IQ^G7Z>?JY^M'Z[?KQ^UG[D
M?NQ^^7X*?Q!_'G\W?SE_.W\\?SU_/G\_?T!_07]#?T9_1W](?TE_2G]+?TQ_
M37].?T]_4G]3?U9_67];?UQ_77]>?V!_8W]D?V5_9G]G?VM_;']M?V]_<']S
M?W5_=G]W?WA_>G][?WQ_?7]_?X!_@G^#?X1_A7^&?X=_B'^)?XM_C7^/?Y!_
MD7^2?Y-_E7^6?Y=_F'^9?YM_G'^@?Z)_HW^E?Z9_J'^I?ZI_JW^L?ZU_KG^Q
M?[-_M'^U?[9_MW^Z?[M_OG_`?\)_PW_$?\9_QW_(?\E_RW_-?\]_T'_1?])_
MTW_6?]=_V7_:?]M_W'_=?]Y_XG_C?^1_YW_H?^I_ZW_L?^U_[W_R?_1_]7_V
M?_=_^'_Y?_I__7_^?_]_`H`'@`B`"8`*@`Z`#X`1@!.`&H`;@!V`'H`?@"&`
M(X`D@"N`+(`M@"Z`+X`P@#*`-(`Y@#J`/(`^@$"`08!$@$6`1X!(@$F`3H!/
M@%"`48!3@%6`5H!7@%F`6X!<@%V`7H!?@&"`88!B@&.`9(!E@&:`9X!H@&N`
M;(!M@&Z`;X!P@'*`<X!T@'6`=H!W@'B`>8!Z@'N`?(!]@'Z`@8""@(6`B("*
M@(V`CH"/@)"`D8"2@)2`E8"7@)F`GH"C@*:`IX"H@*R`L("S@+6`MH"X@+F`
MNX#%@,>`R(#)@,J`RX#/@-"`T8#2@-.`U(#5@-B`WX#@@.*`XX#F@.Z`]8#W
M@/F`^X#^@/^``($!@0.!!($%@0>!"($+@0R!%8$7@1F!&X$<@1V!'X$@@2&!
M(H$C@22!)8$F@2>!*($I@2J!*X$M@2Z!,($S@32!-8$W@3F!.H$[@3R!/8$_
M@4"!08%"@4.!1(%%@4>!28%-@4Z!3X%2@5:!5X%8@5N!7(%=@5Z!7X%A@6*!
M8X%D@6:!:(%J@6N!;(%O@7*!<X%U@7:!=X%X@8&!@X&$@86!AH&'@8F!BX&,
M@8V!CH&0@9*!DX&4@96!EH&7@9F!FH&>@9^!H(&A@:*!I(&E@:>!J8&K@:R!
MK8&N@:^!L(&Q@;*!M(&U@;:!MX&X@;F!O(&]@;Z!OX'$@<6!QX'(@<F!RX'-
M@<Z!SX'0@=&!TH'3@=2!U8'6@=>!V('9@=J!VX'<@=V!WH'?@>"!X8'B@>2!
MY8'F@>B!Z8'K@>Z![X'P@?&!\H'U@?:!]X'X@?F!^H']@?^!`X('@@B""8(*
M@@N"#H(/@A&"$X(5@A:"%X(8@AF"&H(=@B"")((E@B:")X(I@BZ",H(Z@CR"
M/8(_@D""08)"@D."18)&@DB"2H),@DV"3H)0@E&"4H)3@E2"58)6@E>"68);
M@ER"78)>@F""88)B@F."9()E@F:"9X)I@FJ":X)L@FV"<8)U@G:"=X)X@GN"
M?(*`@H&"@X*%@H:"AX*)@HR"D(*3@I2"E8*6@IJ"FX*>@J""HH*C@J>"LH*U
M@K:"NH*[@KR"OX+`@L*"PX+%@L:"R8+0@M:"V8+:@MV"XH+G@NB"Z8+J@NR"
M[8+N@O""\H+S@O6"]H+X@OJ"_(+]@OZ"_X(`@PJ#"X,-@Q"#$H,3@Q:#&(,9
M@QV#'H,?@R"#(8,B@R.#)(,E@R:#*8,J@RZ#,(,R@S>#.X,]@SZ#/X-!@T*#
M1(-%@TB#2H-+@TR#38-.@U.#58-6@U>#6(-9@UV#8H-P@W&#<H-S@W2#=8-V
M@WF#>H-^@W^#@(.!@X*#@X.$@X>#B(.*@XN#C(.-@X^#D(.1@Y2#E8.6@Y>#
MF8.:@YV#GX.A@Z*#HX.D@Z6#IH.G@ZR#K8.N@Z^#M8.[@[Z#OX/"@\.#Q(/&
M@\B#R8/+@\V#SH/0@]&#TH/3@]6#UX/9@]J#VX/>@^*#XX/D@^:#YX/H@^N#
M[(/M@^Z#[X/S@_2#]8/V@_>#^H/[@_R#_H/_@P"$`H0%A`>$"(0)A`J$$(02
MA!.$%(05A!:$%X09A!J$&X0>A!^$((0AA"*$(X0IA"J$*X0LA"V$+H0OA#"$
M,H0SA#2$-80VA#>$.80ZA#N$/H0_A$"$081"A$.$1(1%A$>$2(1)A$J$2X1,
MA$V$3H1/A%"$4H13A%2$5816A%B$781>A%^$8(1BA&2$981FA&>$:(1JA&Z$
M;X1PA'*$=(1WA'F$>X1\A'V$?H1_A("$@82#A(2$A82&A(J$C82/A)"$D822
MA).$E(25A):$F(2:A)N$G82>A)^$H(2BA*.$I(2EA*:$IX2HA*F$JH2KA*R$
MK82NA+"$L82SA+6$MH2WA+N$O(2^A,"$PH3#A,6$QH3'A,B$RX3,A,Z$SX32
MA-2$U837A-B$V83:A-N$W(3>A.&$XH3DA.>$Z(3IA.J$ZX3MA.Z$[X3QA/*$
M\X3TA/6$]H3WA/B$^83ZA/N$_83^A`"%`84"A0.%!(4%A0:%!X4(A0F%"H4+
MA0V%#H4/A1"%$H44A16%%H48A1F%&X4<A1V%'H4@A2*%(X4DA26%)H4GA2B%
M*84JA2V%+H4OA3"%,84RA3.%-(4UA3:%/H4_A4"%085"A42%185&A4>%2X5,
MA4V%3H5/A5"%4852A5.%5(55A5>%6(5:A5N%7(5=A5^%8(5AA6*%8X5EA6:%
M9X5IA6J%:X5LA6V%;H5OA7"%<85SA76%=H5WA7B%?(5]A7^%@(6!A8*%@X6&
MA8B%B86*A8N%C(6-A8Z%D(61A9*%DX64A96%EH67A9B%F86:A9V%GH6?A:"%
MH86BA:.%I86FA:>%J86KA:R%K86QA;*%LX6TA;6%MH6XA;J%NX6\A;V%OH6_
MA<"%PH7#A<2%Q87&A<>%R(7*A<N%S(7-A<Z%T872A=2%UH77A=B%V87:A=N%
MW87>A=^%X(7AA>*%XX7EA>:%YX7HA>J%ZX7LA>V%[H7OA?"%\87RA?.%](7U
MA?:%]X7XA?F%^H7\A?V%_H4`A@&&`H8#A@2&!H8'A@B&"88*A@N&#(8-A@Z&
M#X80AA*&$X84AA6&%X88AAF&&H8;AAR&'88>AA^&((8AAB*&(X8DAB6&)H8H
MABJ&*X8LABV&+H8OAC"&,88RAC.&-(8UAC:&-X8YACJ&.X8]ACZ&/X9`AD&&
M0H9#AD2&189&AD>&2(9)ADJ&2X9,AE*&4X95AE:&5X98AEF&6X9<AEV&7X9@
MAF&&8X9DAF6&9H9GAFB&:89JAFV&;X9PAG*&<X9TAG6&=H9WAGB&@X:$AH6&
MAH:'AHB&B8:.AH^&D(:1AI*&E(:6AI>&F(:9AIJ&FX:>AI^&H(:AAJ*&I8:F
MAJN&K8:NAK*&LX:WAKB&N8:[AKR&O8:^AK^&P8;"AL.&Q8;(ALR&S8;2AM.&
MU8;6AM>&VH;<AMV&X(;AAN*&XX;EAN:&YX;HANJ&ZX;LAN^&]8;VAO>&^H;[
MAOR&_8;_A@&'!(<%AP:'"X<,APZ'#X<0AQ&'%(<6AQF'&X<=AQ^'((<DAR:'
M)X<HARJ'*X<LARV'+X<PAS*',X<UAS:'.(<YASJ'/(<]AT"'08="AT.'1(=%
MAT:'2H=+ATV'3X=0AU&'4H=4AU6'5H=8AUJ'6X=<AUV'7H=?AV&'8H=FAV>'
M:(=IAVJ':X=LAVV';X=QAW*'<X=UAW>'>(=YAWJ'?X>`AX&'A(>&AX>'B8>*
MAXR'CH>/AY"'D8>2AY2'E8>6AYB'F8>:AYN'G(>=AYZ'H(>AAZ*'HX>DAZ6'
MIH>GAZF'JH>NA["'L8>RA[2'MH>WA[B'N8>[A[R'OH>_A\&'PH?#A\2'Q8?'
MA\B'R8?,A\V'SH?/A]"'U(?5A]:'UX?8A]F'VH?<A]V'WH??A^&'XH?CA^2'
MYH?GA^B'Z8?KA^R'[8?OA_"'\8?RA_.'](?UA_:']X?XA_J'^X?\A_V'_X<`
MB`&(`H@$B`6(!H@'B`B("8@+B`R(#8@.B`^($(@1B!*(%(@7B!B(&8@:B!R(
M'8@>B!^(((@CB"2()8@FB">(*(@IB"J(*X@LB"V(+H@OB#"(,8@SB#2(-8@V
MB#>(.(@ZB#N(/8@^B#^(08A"B$.(1HA'B$B(28A*B$N(3HA/B%"(48A2B%.(
M58A6B%B(6HA;B%R(78A>B%^(8(AFB&>(:HAMB&^(<8ASB'2(=8AVB'B(>8AZ
MB'N(?(B`B(.(AHB'B(F(BHB,B(Z(CXB0B)&(DXB4B)6(EXB8B)F(FHB;B)V(
MGHB?B*"(H8BCB*6(IHBGB*B(J8BJB*R(KHBOB+"(LHBSB+2(M8BVB+B(N8BZ
MB+N(O8B^B+^(P(C#B,2(QXC(B,J(RXC,B,V(SXC0B-&(TXC6B->(VHC;B-R(
MW8C>B."(X8CFB.>(Z8CJB.N([(CMB.Z([XCRB/6(]HCWB/J(^XC]B/^(`(D!
MB0.)!(D%B0:)!XD(B0F)"XD,B0V)#HD/B1&)%(D5B1:)%XD8B1R)'8D>B1^)
M((DBB2.))(DFB2>)*(DIB2R)+8DNB2^),8DRB3.)-8DWB3B).8DZB3N)/(D]
MB3Z)/XE`B4*)0XE%B4:)1XE(B4F)2HE+B4R)38E.B4^)4(E1B5*)4XE4B56)
M5HE7B5B)68E:B5N)7(E=B6")88EBB6.)9(EEB6>):(EIB6J):XELB6V);HEO
MB7")<8ERB7.)=(EUB7:)=XEXB7F)>HE\B7V)?HF`B8*)A(F%B8>)B(F)B8J)
MBXF,B8V)CHF/B9")D8F2B9.)E(F5B9:)EXF8B9F)FHF;B9R)G8F>B9^)H(FA
MB:*)HXFDB:6)IHFGB:B)J8FJB:N)K(FMB:Z)KXFPB;&)LHFSB;2)M8FVB;>)
MN(FYB;J)NXF\B;V)OHF_B<")PXG-B=.)U(G5B=>)V(G9B=N)W8G?B>")X8GB
MB>2)YXGHB>F)ZHGLB>V)[HGPB?&)\HGTB?6)]HGWB?B)^8GZB?N)_(G]B?Z)
M_XD!B@**`XH$B@6*!HH(B@F*"HH+B@R*#8H.B@^*$(H1BA**$XH4BA6*%HH7
MBAB*&8H:BAN*'(H=BAZ*'XH@BB&*(HHCBB2*)8HFBB>**(HIBBJ**XHLBBV*
M+HHOBC"*,8HRBC.*-(HUBC:*-XHXBCF*.HH[BCR*/8H_BD"*08I"BD.*1(I%
MBD:*1XI)BDJ*2XI,BDV*3HI/BE"*48I2BE.*5(I5BE:*5XI8BEF*6HI;BER*
M78I>BE^*8(IABF**8XIDBF6*9HIGBFB*:8IJBFN*;(IMBFZ*;XIPBG&*<HIS
MBG2*=8IVBG>*>(IZBGN*?(I]BGZ*?XJ`BH&*@HJ#BH2*A8J&BH>*B(J+BHR*
MC8J.BH^*D(J1BI**E(J5BI:*EXJ8BIF*FHJ;BIR*G8J>BI^*H(JABJ**HXJD
MBJ6*IHJGBJB*J8JJBJN*K(JMBJZ*KXJPBK&*LHJSBK2*M8JVBK>*N(JYBKJ*
MNXJ\BKV*OHJ_BL"*P8K"BL.*Q(K%BL:*QXK(BLF*RHK+BLR*S8K.BL^*T(K1
MBM**TXK4BM6*UHK7BMB*V8K:BMN*W(K=BMZ*WXK@BN&*XHKCBN2*Y8KFBN>*
MZ(KIBNJ*ZXKLBNV*[HKOBO"*\8KRBO.*](KUBO:*]XKXBOF*^HK[BOR*_8K^
MBO^*`(L!BP*+`XL$BP6+!HL(BPF+"HL+BPR+#8L.BP^+$(L1BQ*+$XL4BQ6+
M%HL7BQB+&8L:BQN+'(L=BQZ+'XL@BR&+(HLCBR2+)8LGBRB+*8LJBRN++(LM
MBRZ++XLPBS&+,HLSBS2+-8LVBS>+.(LYBSJ+.XL\BSV+/HL_BT"+08M"BT.+
M1(M%BT:+1XM(BTF+2HM+BTR+38M.BT^+4(M1BU*+4XM4BU6+5HM7BUB+68M:
MBUN+7(M=BUZ+7XM@BV&+8HMCBV2+98MGBVB+:8MJBVN+;8MNBV^+<(MQBW*+
M<XMTBW6+=HMWBWB+>8MZBWN+?(M]BWZ+?XN`BX&+@HN#BX2+A8N&BX>+B(N)
MBXJ+BXN,BXV+CHN/BY"+D8N2BY.+E(N5BY:+EXN8BYF+FHN;BYR+G8N>BY^+
MK(NQB[N+QXO0B^J+"8P>C#B,.8PZC#N,/(P]C#Z,/XQ`C$*,0XQ$C$6,2(Q*
MC$N,38Q.C$^,4(Q1C%*,4XQ4C%:,5XQ8C%F,6XQ<C%V,7HQ?C&",8XQDC&6,
M9HQGC&B,:8QLC&V,;HQOC'",<8QRC'2,=8QVC'>,>XQ\C'V,?HQ_C(",@8R#
MC(2,AHR'C(B,BXR-C(Z,CXR0C)&,DHR3C)6,EHR7C)F,FHR;C)R,G8R>C)^,
MH(RAC**,HXRDC*6,IHRGC*B,J8RJC*N,K(RMC*Z,KXRPC+&,LHRSC+2,M8RV
MC+>,N(RYC+J,NXR\C+V,OHR_C,",P8S"C,.,Q(S%C,:,QXS(C,F,RHS+C,R,
MS8S.C,^,T(S1C-*,TXS4C-6,UHS7C-B,V8S:C-N,W(S=C-Z,WXS@C.&,XHSC
MC.2,Y8SFC.>,Z(SIC.J,ZXSLC.V,[HSOC/",\8SRC/.,](SUC/:,]XSXC/F,
M^HS[C/R,_8S^C/^,`(T!C0*-`XT$C06-!HT'C0B-"8T*C0N-#(T-C0Z-#XT0
MC1&-$HT3C12-%8T6C1>-&(T9C1J-&XT<C2"-48U2C5>-7XUEC6B-:8UJC6R-
M;HUOC7&-<HUXC7F->HU[C7R-?8U^C7^-@(V"C8.-AHV'C8B-B8V,C8V-CHV/
MC9"-DHV3C96-EHV7C9B-F8V:C9N-G(V=C9Z-H(VAC:*-I(VEC::-IXVHC:F-
MJHVKC:R-K8VNC:^-L(VRC;:-MXVYC;N-O8W`C<&-PHW%C<>-R(W)C<J-S8W0
MC=*-TXW4C=6-V(W9C=R-X(WAC>*-Y8WFC>>-Z8WMC>Z-\(WQC?*-](WVC?R-
M_HW_C0".`8X"C@..!(X&C@>."(X+C@V.#HX0CA&.$HX3CA6.%HX7CAB.&8X:
MCAN.'(X@CB&.)(XECB:.)XXHCBN.+8XPCC*.,XXTCC:.-XXXCCN./(X^CC^.
M0XY%CD:.3(Y-CDZ.3XY0CE..5(Y5CE:.5XY8CEJ.6XY<CEV.7HY?CF".88YB
MCF..9(YECF>.:(YJCFN.;HYQCG..=8YWCGB.>8YZCGN.?8Y^CH".@HZ#CH2.
MAHZ(CHF.BHZ+CHR.C8Z.CI&.DHZ3CI6.EHZ7CIB.F8Z:CIN.G8Z?CJ".H8ZB
MCJ..I(ZECJ:.IXZHCJF.JHZMCJZ.L(ZQCK..M(ZUCK:.MXZXCKF.NXZ\CKV.
MOHZ_CL".P8["CL..Q([%CL:.QX[(CLF.RH[+CLR.S8[/CM".T8[2CM..U([5
MCM:.UX[8CMF.VH[;CMR.W8[>CM^.X([ACN*.XX[DCN6.YH[GCNB.Z8[JCNN.
M[([MCNZ.[X[PCO&.\H[SCO2.]8[VCO>.^([YCOJ.^X[\COV._H[_C@"/`8\"
MCP./!(\%CP:/!X\(CPF/"H\+CPR/#8\.CP^/$(\1CQ*/$X\4CQ6/%H\7CQB/
M&8\:CQN/'(\=CQZ/'X\@CR&/(H\CCR2/)8\FCR>/*(\ICRJ/*X\LCRV/+H\O
MCS"/,8\RCS./-(\UCS:/-X\XCSF/.H\[CSR//8\^CS^/0(]!CT*/0X]$CT6/
M1H]'CTB/28]*CTN/3(]-CTZ/3X]0CU&/4H]3CU2/58]6CU>/6(]9CUJ/6X]<
MCUV/7H]?CV"/88]BCV./9(]ECVJ/@(^,CY*/G8^@CZ&/HH^DCZ6/IH^GCZJ/
MK(^MCZZ/KX^RC[./M(^UC[>/N(^ZC[N/O(^_C\"/PX_&C\F/RH_+C\R/S8_/
MC]*/UH_7C]J/X(_AC^./YX_LC^^/\8_RC_2/]8_VC_J/^X_\C_Z/_X\'D`B0
M#)`.D!.0%9`8D!F0')`CD"20)9`GD"B0*9`JD"N0+)`PD#&0,I`SD#20-Y`Y
MD#J0/9`_D$"00Y!%D$:02)!)D$J02Y!,D$Z05)!5D%:069!:D%R079!>D%^0
M8)!AD&209I!GD&F0:I!KD&R0;Y!PD'&0<I!SD':0=Y!XD'F0>I![D'R0?I"!
MD(20A9"&D(>0B9"*D(R0C9".D(^0D)"2D)20EI"8D)J0G)">D)^0H)"DD*60
MIY"HD*F0JY"MD+*0MY"\D+V0OY#`D,*0PY#&D,B0R9#+D,R0S9#2D-20U9#6
MD-B0V9#:D-Z0WY#@D..0Y)#ED.F0ZI#LD.Z0\)#QD/*0\Y#UD/:0]Y#YD/J0
M^Y#\D/^0`)$!D0.1!9$&D0>1")$)D0J1"Y$,D0V1#I$/D1"1$9$2D1.1%)$5
MD1:1%Y$8D1J1&Y$<D1V1'Y$@D2&1))$ED2:1)Y$HD2F1*I$KD2R1+9$ND3"1
M,I$SD321-9$VD3>1.)$ZD3N1/)$]D3Z1/Y%`D4&10I%$D4611Y%(D5&14Y%4
MD5615I%8D5F16Y%<D5^18)%FD6>1:)%KD6V1<Y%ZD7N1?)&`D8&1@I&#D821
MAI&(D8J1CI&/D9.1E)&5D9:1EY&8D9F1G)&=D9Z1GY&@D:&1I)&ED::1IY&H
MD:F1JY&LD;"1L9&RD;.1MI&WD;B1N9&[D;R1O9&^D;^1P)'!D<*1PY'$D<61
MQI'(D<N1T)'2D=.1U)'5D=:1UY'8D=F1VI';D=V1WI'?D>"1X9'BD>.1Y)'E
MD>:1YY'HD>F1ZI'KD>R1[9'ND>^1\)'QD?*1\Y'TD?61]I'WD?B1^9'ZD?N1
M_)']D?Z1_Y$`D@&2`I(#D@22!9(&D@>2")()D@J2"Y(,D@V2#I(/DA"2$9(2
MDA.2%)(5DA:2%Y(8DAF2&I(;DAR2'9(>DA^2()(ADB*2(Y(DDB62)I(GDBB2
M*9(JDBN2+)(MDBZ2+Y(PDC&2,I(SDC22-9(VDC>2.)(YDCJ2.Y(\DCV2/I(_
MDD"209)"DD.21))%DD:21Y)(DDF22I)+DDR239).DD^24))1DE*24Y)4DE62
M5I)7DEB269):DEN27))=DEZ27Y)@DF&28I)CDF2299)FDF>2:))IDFJ2:Y)L
MDFV2;I)ODG"2<9)RDG.2=9)VDG>2>))YDGJ2>Y)\DGV2?I)_DH"2@9*"DH.2
MA)*%DH:2AY*(DHF2BI*+DHR2C9*/DI"2D9*2DI.2E)*5DI:2EY*8DIF2FI*;
MDIR2G9*>DI^2H)*ADJ*2HY*DDJ62II*GDJB2J9*JDJN2K)*MDJ^2L)*QDK*2
MLY*TDK62MI*WDKB2N9*ZDKN2O)*]DKZ2OY+`DL&2PI+#DL22Q9+&DL>2R9+*
MDLN2S)+-DLZ2SY+0DM&2TI+3DM22U9+6DM>2V)+9DMJ2VY+<DMV2WI+?DN"2
MX9+BDN.2Y)+EDN:2YY+HDNF2ZI+KDNR2[9+NDN^2\)+QDO*2\Y+TDO62]I+W
MDOB2^9+ZDON2_)+]DOZ2_Y(`DP&3`I,#DP23!9,&DP>3"),)DPJ3"Y,,DPV3
M#I,/DQ"3$9,2DQ.3%),5DQ:3%Y,8DQF3&I,;DQR3'9,>DQ^3(),ADR*3(Y,D
MDR63)I,GDRB3*9,JDRN3+),MDRZ3+Y,PDS&3,I,SDS23-9,VDS>3.),YDSJ3
M.Y,\DSV3/Y-`DT&30I-#DT2319-&DT>32)-)DTJ32Y-,DTV33I-/DU"349-2
MDU.35)-5DU:35Y-8DUF36I-;DUR379->DU^38)-ADV*38Y-DDV639I-GDVB3
M:9-KDVR3;9-NDV^3<)-QDW*3<Y-TDW63=I-WDWB3>9-ZDWN3?)-]DWZ3?Y.`
MDX&3@I.#DX23A9.&DX>3B).)DXJ3BY.,DXV3CI.0DY&3DI.3DY23E9.6DY>3
MF).9DYJ3FY.<DYV3GI.?DZ"3H9.BDZ.3I).EDZ:3IY.HDZF3JI.KDZR3K9.N
MDZ^3L).QD[*3LY.TD[63MI.WD[B3N9.ZD[N3O).]D[Z3OY/`D\&3PI/#D\23
MQ9/&D\>3R)/)D\N3S)/-D\Z3SY/0D]&3TI/3D]23U9/7D]B3V9/:D]N3W)/=
MD]Z3WY/@D^&3XI/CD^23Y9/FD^>3Z)/ID^J3ZY/LD^V3[I/OD_"3\9/RD_.3
M])/UD_:3]Y/XD_F3^I/[D_R3_9/^D_^3`)0!E`*4`Y0$E`64!I0'E`B4"90*
ME`N4#)0-E`Z4#Y00E!&4$I03E!24%906E!>4&)09E!J4&Y0<E!V4'I0?E""4
M(90BE".4))0EE":4)Y0HE"F4*I0KE"R4+90NE"^4,)0QE#*4,Y0TE#64-I0W
ME#B4.90ZE#N4/)0]E#^40)1!E$*40Y1$E$641I1'E$B4291*E$N43)1-E$Z4
M3Y10E%&44I13E%245916E%>46)19E%J46Y1<E%V47I1?E&"4891BE&.49)1E
ME&:49Y1HE&F4:I1LE&V4;I1OE'"4<91RE'.4=)1UE':4=Y1XE'F4>I1[E'R4
M?91^E'^4@)2!E(*4@Y2$E)&4EI28E,>4SY33E-24VI3FE/N4')4@E2>5,Y4]
ME4.52)5+E5656I5@E6Z5=)5UE7>5>)5YE7J5>Y5\E7V5?I6`E8&5@I6#E825
MA96&E8>5B)6)E8J5BY6,E8V5CI6/E9"5D962E9.5E)65E9:5EY68E9F5FI6;
ME9R5G96>E9^5H)6AE:*5HY6DE:65II6GE:B5J96JE:N5K)6ME:Z5KY6PE;&5
MLI6SE;25M96VE;>5N)6YE;J5NY6\E;V5OI6_E<"5P97"E<.5Q)7%E<:5QY7(
ME<F5RI7+E<R5S97.E<^5T)71E=*5TY74E=65UI77E=B5V97:E=N5W)7=E=Z5
MWY7@E>&5XI7CE>25Y97FE>>5[)7_E0>6$Y88EAN6'I8@EB.6))8EEB:6)Y8H
MEBF6*Y8LEBV6+Y8PEC>6.)8YECJ6/I9!ED.62I9.ED^64992EE.65I97EEB6
M699:EER6799>EF"68Y9EEF:6:Y9MEFZ6;Y9PEG&6<Y9XEGF6>I9[EGR6?99^
MEG^6@):!EH*6@Y:$EH>6B9:*EHR6CI:1EI*6DY:5EI:6FI:;EIV6GI:?EJ"6
MH9:BEJ.6I):EEJ:6J):IEJJ6JY:LEJV6KI:OEK&6LI:TEK66MY:XEKJ6NY:_
MEL*6PY;(ELJ6RY;0EM&6TY;4EM:6UY;8EMF6VI;;EMR6W9;>EM^6X9;BEN.6
MY);EEN:6YY;KENR6[9;NEO"6\9;REO26]9;XEOJ6^Y;\EOV6_Y8"EP.7!9<*
MEPN7#)<0EQ&7$I<4EQ67%Y<8EQF7&I<;EQV7'Y<@ER&7(I<CER27)9<FER>7
M*)<IERN7+)<NER^7,9<SES27-9<VES>7.I<[ESR7/9<_ET"709="ET.71)=%
MET:71Y=(ETF72I=+ETR739=.ET^74)=1EU2759=7EUB76I=<EUV77Y=CEV27
M9I=GEVB7:I=KEVR7;9=NEV^7<)=QEW*7=9=WEWB7>9=ZEWN7?9=^EW^7@)>!
MEX*7@Y>$EX:7AY>(EXF7BI>,EXZ7CY>0EY.7E9>6EY>7F9>:EYN7G)>=EYZ7
MGY>AEZ*7I)>EEZ:7IY>HEZF7JI>LEZZ7L)>QE[.7M9>VE[>7N)>YE[J7NY>\
ME[V7OI>_E\"7P9?"E\.7Q)?%E\:7QY?(E\F7RI?+E\R7S9?.E\^7T)?1E]*7
MTY?4E]67UI?7E]B7V9?:E]N7W)?=E]Z7WY?@E^&7XI?CE^27Y9?HE^Z7[Y?P
ME_&7\I?TE_>7^)?YE_J7^Y?\E_V7_I?_EP"8`9@"F`.8!)@%F`:8!Y@(F`F8
M"I@+F`R8#9@.F`^8$)@1F!*8$Y@4F!68%I@7F!B8&9@:F!N8')@=F!Z8'Y@@
MF"&8(I@CF"28)9@FF">8*)@IF"J8*Y@LF"V8+I@OF#"8,9@RF#.8-)@UF#:8
M-Y@XF#F8.I@[F#R8/9@^F#^80)A!F$*80YA$F$681IA'F$B829A*F$N83)A-
MF$Z83YA0F%&84IA3F%2859A6F%>86)A9F%J86YA<F%V87IA?F&"889ABF&.8
M9)AEF&:89YAHF&F8:IAKF&R8;9ANF&^8<)AQF'*8<YATF(N8CIB2F)68F9BC
MF*B8J9BJF*N8K)BMF*Z8KYBPF+&8LIBSF+28M9BVF+>8N)BYF+J8NYB\F+V8
MOIB_F,"8P9C"F,.8Q)C%F,:8QYC(F,F8RIC+F,R8S9C/F-"8U)C6F->8VYC<
MF-V8X)CAF.*8XYCDF.68YICIF.J8ZYCLF.V8[ICOF/"8\9CRF/.8])CUF/:8
M]YCXF/F8^IC[F/R8_9C^F/^8`)D!F0*9`YD$F069!ID'F0B9"9D*F0N9#)D.
MF0^9$9D2F1.9%)D5F1:9%YD8F1F9&ID;F1R9'9D>F1^9()DAF2*9(YDDF269
M)IDGF2B9*9DJF2N9+)DMF2^9,)DQF3*9,YDTF369-IDWF3B9.9DZF3N9/)D]
MF3Z9/YE`F4&90IE#F42919E&F4>92)E)F4J92YE,F4V93IE/F5"949E2F5.9
M5IE7F5B969E:F5N97)E=F5Z97YE@F6&98IEDF6:9<YEXF7F9>YE^F8*9@YF)
MF8R9CIF:F9N9G)F=F9Z9GYF@F:&9HIFCF:29IIFGF:F9JIFKF:R9K9FNF:^9
ML)FQF;*9LYFTF;69MIFWF;B9N9FZF;N9O)F]F;Z9OYG`F<&9PIG#F<29Q9G&
MF<>9R)G)F<J9RYG,F<V9SIG/F="9T9G2F=.9U)G5F=:9UYG8F=F9VIG;F=R9
MW9G>F=^9X)GAF>*9XYGDF>69YIGGF>B9Z9GJF>N9[)GMF>Z9[YGPF?&9\IGS
MF?29]9GVF?>9^)GYF?J9^YG\F?V9_IG_F0":`9H"F@.:!)H%F@::!YH(F@F:
M"IH+F@R:#9H.F@^:$)H1FA*:$YH4FA6:%IH7FAB:&9H:FAN:')H=FAZ:'YH@
MFB&:(IHCFB2:)9HFFB>:*)HIFBJ:*YHLFBV:+IHOFC":,9HRFC.:-)HUFC::
M-YHXFCF:.IH[FCR:/9H^FC^:0)I!FD*:0YI$FD6:1II'FDB:29I*FDN:3)I-
MFDZ:3YI0FE&:4II3FE2:59I6FE>:6)I9FEJ:6YI<FEV:7II?FF":89IBFF.:
M9)IEFF::9YIHFFF::IIKFG*:@YJ)FHV:CIJ4FI6:F9JFFJF:JIJKFJR:K9JN
MFJ^:LIJSFK2:M9JYFKN:O9J^FK^:PYK$FL::QYK(FLF:RIK-FLZ:SYK0FM*:
MU)K5FM::UYK9FMJ:VYK<FMV:WIK@FN*:XYKDFN6:YYKHFNF:ZIKLFNZ:\)KQ
MFO*:\YKTFO6:]IKWFOB:^IK\FOV:_IK_F@";`9L"FP2;!9L&FP>;"9L*FPN;
M#)L-FPZ;$)L1FQ*;%)L5FQ:;%YL8FQF;&IL;FQR;'9L>FR";(9LBFR2;)9LF
MFR>;*)LIFRJ;*YLLFRV;+ILPFS&;,YLTFS6;-ILWFSB;.9LZFSV;/IL_FT";
M1IM*FTN;3)M.FU";4IM3FU6;5IM7FUB;69M:FUN;7)M=FUZ;7YM@FV&;8IMC
MFV2;99MFFV>;:)MIFVJ;:YMLFVV;;IMOFW";<9MRFW.;=)MUFW:;=YMXFWF;
M>IM[FWR;?9M^FW^;@)N!FX*;@YN$FX6;AIN'FXB;B9N*FXN;C)N-FXZ;CYN0
MFY&;DIN3FY2;E9N6FY>;F)N9FYJ;FYN<FYV;GIN?FZ";H9NBFZ.;I)NEFZ:;
MIYNHFZF;JINKFZR;K9NNFZ^;L)NQF[*;LYNTF[6;MINWF[B;N9NZF[N;O)N]
MF[Z;OYO`F\&;PIO#F\2;Q9O&F\>;R)O)F\J;RYO,F\V;SIO/F]";T9O2F].;
MU)O5F]:;UYO8F]F;VIO;F]R;W9O>F]^;X)OAF^*;XYODF^6;YIOGF^B;Z9OJ
MF^N;[)OMF^Z;[YOPF_&;\IOSF_2;]9OVF_>;^)OYF_J;^YO\F_V;_IO_FP"<
M`9P"G`.<!)P%G`:<!YP(G`F<"IP+G`R<#9P.G`^<$)P1G!*<$YP4G!6<%IP7
MG!B<&9P:G!N<')P=G!Z<'YP@G"&<(IPCG"2<)9PFG"><*)PIG"J<*YPLG"V<
M+IPOG#"<,9PRG#.<-)PUG#:<-YPXG#F<.IP[G#R</9P^G#^<0)Q!G$*<0YQ$
MG$6<1IQ'G$B<29Q*G$N<3)Q-G$Z<3YQ0G%&<4IQ3G%2<59Q6G%><6)Q9G%J<
M6YQ<G%V<7IQ?G&"<89QBG&.<9)QEG&:<9YQHG&F<:IQKG&R<;9QNG&^<<)QQ
MG'*<<YQTG'6<=IQWG'B<>9QZG'N<?9Q^G("<@YR$G(F<BIR,G(^<DYR6G)><
MF)R9G)V<JIRLG*^<N9R^G+^<P)S!G,*<R)S)G-&<TIS:G-N<X)SAG..<Y)SE
MG.:<YYSHG.F<ZISKG.R<[9SNG.^<\)SQG/*<\YSTG/6<]ISWG/B<^9SZG/N<
M_)S]G/Z<_YP`G0&=`IT#G02=!9T&G0>=")T)G0J="YT,G0V=#IT/G1"=$9T2
MG1.=%)T5G1:=%YT8G1F=&IT;G1R='9T>G1^=()TAG2*=(YTDG26=)ITGG2B=
M*9TJG2N=+)TMG2Z=+YTPG3&=,ITSG32=-9TVG3>=.)TYG3J=.YT\G3V=/IT_
MG4"=09U"G4.=1)U%G4:=1YU(G4F=2IU+G4R=39U.G4^=4)U1G5*=4YU4G56=
M5IU7G5B=69U:G5N=7)U=G5Z=7YU@G6&=8IUCG62=99UFG6>=:)UIG6J=:YUL
MG6V=;IUOG7"=<9URG7.==)UUG7:==YUXG7F=>IU[G7R=?9U^G7^=@)V!G8*=
M@YV$G86=AIV'G8B=B9V*G8N=C)V-G8Z=CYV0G9&=DIV3G92=E9V6G9>=F)V9
MG9J=FYV<G9V=GIV?G:"=H9VBG:.=I)VEG::=IYVHG:F=JIVKG:R=K9VNG:^=
ML)VQG;*=LYVTG;6=MIVWG;B=N9VZG;N=O)V]G;Z=OYW`G<&=PIW#G<2=Q9W&
MG<>=R)W)G<J=RYW,G<V=SIW/G="=T9W2G=.=U)W5G=:=UYW8G=F=VIW;G=R=
MW9W>G=^=X)WAG>*=XYWDG>6=YIWGG>B=Z9WJG>N=[)WMG>Z=[YWPG?&=\IWS
MG?2=]9WVG?>=^)WYG?J=^YW\G?V=_IW_G0">`9X"G@.>!)X%G@:>!YX(G@F>
M"IX+G@R>#9X.G@^>$)X1GA*>$YX4GA6>%IX7GAB>&9X:GAN>')X=GAZ>))XG
MGBZ>,)XTGCN>/)Y`GDV>4)Y2GE.>5)Y6GEF>79Y?GF">89YBGF6>;IYOGG*>
M=)YUGG:>=YYXGGF>>IY[GGR>?9Z`GH&>@YZ$GH6>AIZ)GHJ>C)Z-GHZ>CYZ0
MGI&>E)Z5GI:>EYZ8GIF>FIZ;GIR>GIZ@GJ&>HIZCGJ2>I9ZGGJB>J9ZJGJN>
MK)ZMGJZ>KYZPGK&>LIZSGK6>MIZWGKF>NIZ\GK^>P)[!GL*>PY[%GL:>QY[(
MGLJ>RY[,GM">TI[3GM6>UI[7GMF>VI[>GN&>XY[DGN:>Z)[KGNR>[9[NGO">
M\9[RGO.>])[UGO:>]Y[XGOJ>_9[_G@"?`9\"GP.?!)\%GP:?!Y\(GPF?"I\,
MGP^?$9\2GQ2?%9\6GQB?&I\;GQR?'9\>GQ^?(9\CGR2?)9\FGR>?*)\IGRJ?
M*Y\MGRZ?,)\QGS*?,Y\TGS6?-I\XGSJ?/)\_GT"?09]"GT.?19]&GT>?2)])
MGTJ?2Y],GTV?3I]/GU*?4Y]4GU6?5I]7GUB?69]:GUN?7)]=GUZ?7Y]@GV&?
M8I]CGV2?99]FGV>?:)]IGVJ?:Y]LGVV?;I]OGW"?<9]RGW.?=)]UGW:?=Y]X
MGWF?>I][GWR??9]^GX&?@I^-GXZ?CY^0GY&?DI^3GY2?E9^6GY>?F)^<GYV?
MGI^AGZ*?HY^DGZ6?+/EY^97YY_GQ^0SZ#?H.^@_Z$?H3^A3Z&/H?^B#Z(?HC
M^B3Z)_HH^BGZ_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?^!+OW_
M_?_]_X0N<S1'-(@NBR[]_YXU&C8.-HPNERYN.1@Y_?_/.=\Y<SK0.?W__?].
M.VX\X#RG+OW__?^J+E9`7T&N+C=#LRZV+K<N_?^Q0ZQ#NR[=0]9$849,1OW_
M(T<I1WQ'C4?*+D=)>DE]28))@TF%289)GTF;2;=)MDG]__W_HTR?3*!,H4QW
M3*),$TT4315-%DT731A-&4VN33XP\"_Q+_(O\R_T+_4O]B_W+_@O^2_Z+_LO
M`````````````",`)``E`"8`+``M`#$`,@!0`%$`6`!9`%X`7P!?`&``8P!D
M`&8`9P!G`&@`:`!I`&P`;0!]`'X`A`"%`),`E`"K`*P`K@"O`+(`LP#/`-``
M,0$R`3(!,P$S`30!-`$U`34!-@$V`3<!-P$X`3@!.0%4`54!JP&L`;H!NP$?
M`B`"(`(A`BT"+@+D`N4"Y0+F`NP"[0+M`NX")`,E`S(#,P,S`S0#\1[R'O,>
M]![T'O4>]A[W'OT>_AX&'P<?!Q\('P@?"1\-'PX??1]^'],?U!_4']4?UQ_8
M'^,?Y!_M'^X?*R`L("\@,"!%($8@1R!((+4@MB"[(+P@O""](+\@P"##(,0@
MQ2#&(,<@R"#((,D@R2#*(,L@S"#0(-$@U2#6(-\@X"#B(.,@YR#H(/0@]2#V
M(/<@_"#]("$A(B$D(24A+R$P(4@A22&:(9LAYR+H(O$B\B)5(U8C62-:(V8C
M9R-I(VHC<R-T(X,CA".+(XPCDR.4(Y8CER.8(YDCJB.K(\DCRB/+(\PC`20"
M)`(D`R1`+$$L0BQ#+$4L1BQ'+$@L42Q2+&`L82QB+&,L92QF+&DL:BQK+&PL
M;BQO+'PL?2RA+:(MI2VF+:8MIRVK+:PMK2VN+<$MPBW#+<0MRBW++<PMS2W1
M+=(MURW8+<TNSB[4+M4N12]&+R\P,#`[,#PP/3`^,%\P8#!H,&DP:C!K,&PP
M;3#=,-XP"#$),3(R,S*A,J(RK#*M,JDUJC7^-?\U7C9?-FPV;3;_-@`WV3?:
M-_@X^3AI.6HYWCS?/.8]YSV]/[X_,4`R0#5`-D!@0&%`6$%90<U"SD+A0N)"
MHD.C0Z=#J$/Y0_I#"40*1,)%PT7T1?5%]D7W1?I%^T7[1?Q%#T801A)&$T8H
M1BE&YTCH2`Y)#TE]27Y)$4H22F)*8TJ\@@Z#U)/5DR"4(90[E#R4C)2-E)64
MEI2OE+"4L)2QE+&4LI2TE+64NI2[E+N4O)2]E+Z4PYC$F,28Q9C(F,F8R9C*
MF,J8RYC+F,R88)EAF>&9XIG[F0```````````````````````````````%GZ
M6OI*^DOZ3/I-^D[Z3_I0^E'Z4OI3^D#Z0?I"^D/Z1/I%^D;Z1_I(^DGZE(>5
MAYB'EX>;AYR'DH>3AUOZD(>1AY:'F8=`AT&'0H=#AT2'18=&AT>'2(=)ATJ'
M2X=,ATV'3H=/AU"'48=2AU.'@(>!AUCZBX>,AX6'AH>'AXB'B8=EAVF'8(=C
MAV&':X=JAV2';(=FAVZ'7X=MAV*'9X=HAWZ'CX>.AXV'<H=SAV^'<(=QAW6'
M=(>#AVCZ:?IJ^FOZ;/IM^F[Z</IO^G+Z<?IA^G/Z=OIW^G7Z=/IZ^GCZ>?I[
M^GWZ?/I^^H#Z@?J"^H/ZA/J%^H;Z=_N'^HCZB?J*^HOZC/J-^H[ZC_J2^I'Z
MD_J4^I7ZEOJ7^ICZFOJ9^IWZGOJ?^J#ZH?JB^J/ZI/JE^J;ZI_JI^JKZJ_JL
M^JWZKOJO^K+ZL/JS^K3ZM?JV^K?ZN/IG^KGZNOJ[^KSZO?J^^L#ZO_K"^L/Z
MP?K%^L3ZQOK'^LCZR?K*^LOZS/K-^L[ZT?K/^M/ZU/K2^F/ZT/K6^M?ZU?K9
M^MKZV_K<^MWZWOIF^M_ZX?KB^N3ZY?KF^N/Z9/KG^NGZZ_KL^NWZ[_KN^O#Z
M\?KR^O/Z]/KU^O;Z^/KW^OGZ^OK\^OOZ0/M!^T+[1/M#^T7[2/M&^TG[1_M*
M^TO[3/M-^T[[3_M0^U'[4OMB^E3[4_M6^U?[5?M9^UK[6_M<^UW[7_M@^V'[
M9/MB^V/[9OME^V?[:?MH^VK[:_ML^VW[;ONH^F_[</MS^W'[<OMT^W;[>/MY
M^WK[>_M\^X'[@_N$^X7[A_N(^XK[B_N-^XS[CON/^USZD/N1^Y/[E/N5^Y;[
ME_N8^YG[8/J:^YO[G/N>^Z'[HOM=^J/[I/NE^Z;[I_NH^ZK[J_NL^ZW[KONO
M^[#[LONU^[;[N/NY^[O[NON\^[_[P/N]^[[[P?O#^\+[ROO$^\;[Q?O'^\G[
MR/O+^\W[SOM?^LS[TOO6^]3[T/O1^]7[S_ME^MG[W/O>^]W[V_O8^]?[7OK@
M^]_[X?OB^^/[Y/OE^^;[Y_OH^^O[[/OM^^[[[_OP^_'[\OOS^_3[]?OX^_K[
M^_O\^T#\0OQ!_$/\1/Q%_$;\2/Q'_$K\2_S@^NG[D/J;^ISZL?K8^NCZZOI8
M^U[[=?M]^W[[@/N"^X;[B?N2^YW[G_N@^ZG[L?NS^[3[M_O3^]K[ZOOV^_?[
M^?M)_%?Z5OI4^E7Z``````````````````#%`80`QP$``,<!``#'`0``QP$`
M`,<!``#'`0``QP$``,<!``#'`0``QP$``,<!``#'`0``QP$``,<!%```````
MHP$``*,!``"C`0`"I`$``*0!``"D`0``I`$``*0!``"D`0``I`$``*0!``"D
M`0``I`$``*0!`!"E`0``I0$``*4!`,"G`?__MP'_/P``````````````````
M````````50$``%4!``!5`0``50$``%4!``!5`0``50&``%8!``!6`0``5@$`
M`%8!``!6`0``5@$``%8!`$!7`0``5P$``%<!``!7`2``6`&``%D!``!9`0``
M60$``%D!``!9`0``60$``%D!``!9`0``60$``%D!``!9`8!$7`$P8&`!``!@
M`4`$8@$!`&,!``!C`0`69@$!0&@!`@)J`8``:P&``6T!``%N`0``;@&``&\!
M``!O`0``;P&I`G0!@0!V`0"*>0$$`'H!`&!\`2(`?@$``'X!``%_`8``@`$`
M`(`!`0"!`0``@0$``($!$`""`0``@@%``(,!`$"$`0``A`$``84!``"%`0``
MA0$``(4!`@"&`2`!B`$``(@!``"(`0``B`$``(@!``"(`0``B`$``(@!``"(
M`0``B`$``(@!``"(`0``B`$``(@!``"(`0``B`$``(@!``"(`0``B`$``(@!
M``"(`00`B0$``(D!``")`0``B0$``(D!``")`0``B0$``(D!``")`0``B0$`
M`(D!``")`0``B0$``(D!``")`0``B0$`((H!`("+`0``BP$``(L!``"+`0``
MBP$``(L!``"+`0``BP$``(L!"`B-`0B@D`$B`)(!``"2`0``D@$``)(!``"2
M`0``D@$``)(!``"2`0``D@$``)(!``"2`0``D@$``)(!``"2`0``D@$``)(!
M@`"3`2``E`$``)0!``"4`0``E`$``)0!``"4`0``E`$``)0!``"4`0``E`$`
M`)0!``"4`8``E0$``)4!``"5`0``E0$``)4!``"5`0``E0$`0)8!``"6`0``
ME@$``)8!``"6`0``E@$``)8!``"6`0``E@$``)8!``"6`0!`EP$``)<!``"7
M`0``EP$``)<!``"7`0``EP$``)<!``"7`0`2F0$``)D!``"9`0``F0$``)D!
M``"9`0``F0$``)D!``"9`0``F0$D`)L!`("<`0``G`$``)P!`@B>`0``G@$`
M`)X!``">`0``G@$!`)\!``"?`0``GP$``)\!``"?`0``GP$``)\!``"?`0``
MGP$``)\!``"?`0``GP$``)\!``"?`0``GP$``)\!``"?`0``GP$``)\!``"?
M`0``GP$``)\!``B@`0$`H0$``*$!``"A`0``H0$``*$!``"A`0``H0$``*$!
M``"A`0``H0$``J(!``"B`0``H@$``*(!``"B`0``H@$``*(!``"B`0``H@$`
M`*(!``"B`0``H@$"````````````1`&``$4!``!%`0``10$``$4!``!%`0``
M10$``$4!``!%`0``10$``$4!``!%`0``10$``$4!``!%`0``10$@`$8!``!&
M`0`01P$``$<!``!'`0``1P$``$<!``!'`0``1P$``$<!``!'`0``1P$``$<!
M``!'`0``1P$``$<!``!'`0``1P$$`$@!``!(`8``20$``$D!``!)`0``20$`
M`DH!``!*`0``2@&``$L!`$!,`0``3`$`@$T!``!-`4``3@$``$X!``!.`0``
M3@$``$X!``!.`0@`3P$``$\!`(!0`0``4`$``%`!``!0`0``4`$``%`!``!0
M`0``4`$``%`!``!0`0``4`$``%`!``!0`0``4`$``%`!``!0`0``4`$``%`!
M``!0`0``4`$``%`!``!0`0``4`$``%`!$0!2`0``4@$$`%,!``!3`0``4P$`
M`%,!``!3`0``4P%``%0!``!4`0``5`$``%0!``!4`0``5`$``%0!``!4`0``
M5`$``%0!``!4`0``5`$``%0!``!4`0``5`$``%0!``!4`0``5`$``%0!``!4
M`0``5`$`@````````````````#@!`@`Y`0``.0$``#D!```Y`0``.0$``#D!
M!``Z`0"`.P$``#L!```[`0``.P$``#L!@``\`0``/`$``#P!0``]`0``/0$`
M`#T!```]`0``/0$``3X!```^`0``/@$``#X!```^`0``/@$``#X!$``_`0``
M/P$`$$`!``!``0``0`$``$`!``!``0``0`$``$`!``!``0@"0@$`"$,!``!#
M`0``0P$``$,!``!#`0$``````````````````````"\!```O`0``+P$``"\!
M```O`0`!,`$`$#$!```Q`0``,0$``#$!```Q`0$`,@&``#,!```S`4``-`$`
M`#0!```T`0``-`$``#0!```T`0``-`$``#0!!``U`0``-0$``#4!``0V`0``
M-@$``#8!```V`0``-@$``#8!```V`0``-@$``#8!```V`0``-@$``#8!@``W
M`0``-P$``#<!```W`0``-P$``#<!`@```````````````````````````*@`
M``"H````J``"`*D`$`"J`"``JP```*L`@`"L````K````*P```"L````K`"`
M`*T```"M``!`K@```*X```"N````K@```*X```"N````K@```*X``""O````
MKP```*\`(`2Q````L0```+$```"Q````L0`@0+,```"S``0`M````+0``@"U
M``$`M@"!`+@```"X````N````+@```"X````N````;D```"Y````N0```+D`
M``"Y````N0```+D```"Y``@`N@```+H```"Z````N@```+H```"Z````N@``
M`+H```"Z`$``NP```+L```"[````NP```+L```"[````NP```+L```"[````
MNP```+L```"[````NP```+L```"[````NP```+L```"[````NP```+L```"[
M`"``O````+P```"\````O````+P```"\````O``!`+T```"]````O0``(+X`
M``"^````O@``0+\```"_````OP```+\```"_````OP```+\```"_``!`P```
M`,````#`````P````,````#`````P````,````#`````P````,````#```$"
MP@`@0,0`$$#&``((R````,@`@`+*`"``RP`(`,P```#,```"S0`!`,X`!(#0
M````T````-````#0```,T@``0-,```#3````TP```-,```#3````TP!``-0`
M``#4````U````-0```#4```(U0`!`-8```#6````U@```-8``@#7````UP``
M`-<```#7`!``V``$`-D```#9````V0```-D```#9````V0```-D``(';````
MVP```-L```#;````VP```-L```#;````VP```-L```#;```!W````-P```#<
M```!W0```-T```#=````W0```-T`!`#>````W@```-X```#>````W@`!`-\`
M0`#@````X```".$`"$#C````XP```.,```#C````XP```.,```#C`!0`Y0``
M`.4```#E````Y0```.4```#E````Y0```.4```#E````Y0```.4```#E````
MY0```.4```#E`$``Y@```.8```#F````Y@```.8```#F``"`YP```.<``!#H
M``"`Z0```.D`0`#J````Z@```.H```#J````Z@``!.L```#K````ZP`0`.P`
M``#L````[````.P```#L````[```@.T```#M`(``[@!``.\``!#P````\```
M@/$```#Q````\0`$$?0```#T````]`"``/4``!+W````]P``$/@```#X````
M^````/@```#X````^```@/D```#Y````^0```/D```#Y````^0```/D```#Y
M````^0```/D```#Y````^0```/D```'Z````^@```/H`(`#[````^P```/L`
M``#[`"``_`"@`/X```#^```!_P```/\```#_````_P```/\```#_`"````$`
M```!``@!`0`(`@$```(!```"`0```@$```(!$(`$`0``!`$```0!```$`<``
M!@$`$`<!```'`0``!P$```<!```'`0``!P$```<!`@`(`0``"`$```@!`$`)
M`0``"0$```D!```)`0``"0$```D!```)`0``"0$```D!```)`0``"0$```D!
M`D`+`0``"P$```L!```+`0``"P$```L!```+`1``#`$```P!```,`0``#`$`
M``P!@``-`0``#0$```T!```-`0`@#@$``@\!1``1`0@`$@$@`!,!@``4`0``
M%`%`1A@!```8`0``&`$``!@!!``9`0``&0$``AH!`(`;`0``&P$``!L!```;
M`0``&P$``!L!```;`0(`'`$``!P!`(`=`0``'0$``!T!```=`0"`'@$``!X!
M```>`0``'@$``!X!```>`0``'@$``!X!```>`0``'@$``!X!```>`0``'@$`
M`!X!```>`0``'@$``!X!```>`00`'P$`6"(!0``C`0``(P$``",!```C`0``
M(P$``",!```C`0``(P$``",!```C`4``)`$``"0!```D`0``)`$``"0!```D
M`0``)`$``"0!```D`0``)`$``"0!```D`0``)`$``"0!`@`E`0``)0$`0"8!
M```F`1``)P$`!"@!```H`0``*`$``"@!```H`0``*`$``"@!```H`0``*`$`
M`"@!```H`0``*`$!`"D!```I`0``*0$``"D!```I`0``*0$0""L!```K`0``
M*P$``"L!```K`0``*P$``"L!```K`0``*P$``"L!```K`0``*P$``"L!```K
M`0``*P$``"L!```K`0``*P$``"L!```K`0(`+`&`""X!```N`0``+@$``"X!
M```N`0``+@$``"X!```N`0``+@$``"X!```N`0!`````````````````````
M````````````F0```)D```"9````F0```)D```"9`$``F@```)H```":````
MF@```)H```":````F@`!`)L```&<```0G0```)T```"=``!`G@```)X```">
M````G@```)X```">````G@```)X```">`$``GP``!*````"@````H````*``
M(`"A````H0```*$`@`"B````H@`$`*,`"`"D```@I0```*4```"E````I0``
M`*4```.G````IP`!````````````BP```(L```"+````BP```(L```"+```"
MC``@`(T```"-````C0```(T``!".````C@"``9````"0````D````)````"0
M````D````)````"0````D````)````"0````D````)```$"1````D0`$`)(`
M``"2````D@```)(```"2```(DP```),```"3````DP```),`""B6``@`EP``
M`)<```"7````EP`0`)@```0`````````````````````70```%T```!=```!
M7@```%X```!>````7@```%X```!>````7@```%X```!>````7@```%X```!>
M``(`7P``$&``"0!B````8@```&(```)C````8P!``&0```!D````9```!&4`
M%`1H````:````&@``")J````:@```&H``(!K````:P``0&P`!`!M````;0!%
M`'````!P````<``!`'$```!Q`!``<@```'(```!R````<@```7,```!S`!``
M=````'0```!T````=````'0```1U````=0`0`'8```!V````=@``('<```!W
M``!`>````'@```!X```0>0```'D```!Y`"``>@```'H```!Z````>@```'H`
M``!Z````>@```'H``!![`$"`?0```'T``0!^```(?P```'\```!_`($`@0``
M`($`$`""````@@```((```""````@@`$`(,```"#``@`A````(0`!`"%````
MA0``((8```"&````A@```(8```"&````A@```(8```"&````A@```(8```"&
M```$AP``$(@```*)````B0```(D```")````B0``@(H```"*````B@```(H`
M``"*````B@```(H```"*````B@!`````````````````````````````````
M```````Y````.0```#D````Y``8"/````#P````\````/````#P````\````
M/`#P`4$```!!````00```$$```!!````00`(($,`$`%%`,P(2@!`"$P``"9/
M`((`40```%$``'A5``#`5P``<%H``@!;````6P`0(#<````W``"@`````",`
M```C````(P```",````C````(P```",`__\S``\`````````0``!``(``@``
M``(````"`````@#_`PP`_P,6````%@```!8````6````%@```!8````6````
M%@```!8````6``*$&0`!3AX`(``?````'P`$`"```@`A````(0```"$````A
M`"``(@``@`````````````````````!P(7$A<B%S(70A=2%V(7<A>"%Y(6`A
M82%B(6,A9"%E(68A9R%H(6DAXO_D_P?_`O\Q,A8A(2$U(HI^'(E(DXB2W(3)
M3[MP,6;(:/F2^V9%7RA.X4[\3@!/`T\Y3U9/DD^*3YI/E$_-3T!0(E#_3QY0
M1E!P4$)0E%#T4-A02E%D49U1OE'L4152G%*F4L!2VU(`4P=3)%-R4Y-3LE/=
M4P[ZG%2*5*E4_U2&55E795>L5\A7QU</^A#ZGEBR6`M94UE;65U98UFD6;I9
M5EO`6R]UV%OL6QY<IERZ7/5<)UU371'Z0EUM7;A=N5W072%?-%]G7[=?WE]=
M8(5@BF#>8-5@(&'R8!%A-V$P89AA$V*F8O5C8&2=9,YD3F4`9A5F.V8)9BYF
M'F8D9F5F5V999A+Z<V:99J!FLF:_9OIF#F<I^69GNV=2:,!G`6A$:,]H$_IH
M:13ZF&GB:3!J:VI&:G-J?FKB:N1JUFL_;%QLAFQO;-IL!&V';6]MEFVL;<]M
M^&WR;?QM.6Y<;B=N/&Z_;HAOM6_U;P5P!W`H<(5PJW`/<01Q7'%&<4=Q%?K!
M<?YQL7*^<B1S%OIW<[USR7/6<^-STG,'=/5S)G0J="ET+G1B=(ETGW0!=6]U
M@G:<=IYVFW:F=A?Z1G>O4B%X3GAD>'IX,'D8^AGZ&OJ4>1OZFWG1>N=Z'/KK
M>IY['?I(?5Q]MWV@?=9]4GY'?Z%_'OH!@V*#?X/'@_:#2(2TA%.%685KA1_Z
ML(4@^B'Z!XCUB!**-XIYBJ>*OHK?BB+Z]HI3BW^+\(STC!*-=HTC^L^.)/HE
M^F>0WI`F^A61)Y':D=>1WI'MD>Z1Y)'ED0:2$)(*DCJ20)(\DDZ269)1DCF2
M9Y*GDG>2>)+GDM>2V9+0DB?ZU9+@DM.2)9,AD_N2*/H>D_^2'9,"DW"35Y.D
MD\:3WI/XDS&4191(E)*5W/DI^IV6KY8SESN70Y=-ET^749=5EU>899@J^BOZ
M)YDL^IZ93IK9FMR:=9MRFX^;L9N[FP"<<)UKG2WZ&9[1G@``````````````
M`````````````````(I^'(E(DXB2W(3)3[MP,6;(:/F2^V9%7RA.X4[\3@!/
M`T\Y3U9/DD^*3YI/E$_-3T!0(E#_3QY01E!P4$)0E%#T4-A02E%D49U1OE'L
M4152G%*F4L!2VU(`4P=3)%-R4Y-3LE/=4P[ZG%2*5*E4_U2&55E795>L5\A7
MQU</^A#ZGEBR6`M94UE;65U98UFD6;I95EO`6R]UV%OL6QY<IERZ7/5<)UU3
M71'Z0EUM7;A=N5W072%?-%]G7[=?WE]=8(5@BF#>8-5@(&'R8!%A-V$P89AA
M$V*F8O5C8&2=9,YD3F4`9A5F.V8)9BYF'F8D9F5F5V999A+Z<V:99J!FLF:_
M9OIF#F<I^69GNV=2:,!G`6A$:,]H$_IH:13ZF&GB:3!J:VI&:G-J?FKB:N1J
MUFL_;%QLAFQO;-IL!&V';6]MEFVL;<]M^&WR;?QM.6Y<;B=N/&Z_;HAOM6_U
M;P5P!W`H<(5PJW`/<01Q7'%&<4=Q%?K!<?YQL7*^<B1S%OIW<[USR7/6<^-S
MTG,'=/5S)G0J="ET+G1B=(ETGW0!=6]U@G:<=IYVFW:F=A?Z1G>O4B%X3GAD
M>'IX,'D8^AGZ&OJ4>1OZFWG1>N=Z'/KK>IY['?I(?5Q]MWV@?=9]4GY'?Z%_
M'OH!@V*#?X/'@_:#2(2TA%.%685KA1_ZL(4@^B'Z!XCUB!**-XIYBJ>*OHK?
MBB+Z]HI3BW^+\(STC!*-=HTC^L^.)/HE^F>0WI`F^A61)Y':D=>1WI'MD>Z1
MY)'ED0:2$)(*DCJ20)(\DDZ269)1DCF29Y*GDG>2>)+GDM>2V9+0DB?ZU9+@
MDM.2)9,AD_N2*/H>D_^2'9,"DW"35Y.DD\:3WI/XDS&4191(E)*5W/DI^IV6
MKY8SESN70Y=-ET^749=5EU>899@J^BOZ)YDL^IZ93IK9FMR:=9MRFX^;L9N[
MFP"<<)UKG2WZ&9[1GOW__?]P(7$A<B%S(70A=2%V(7<A>"%Y(>+_Y/\'_P+_
M`````````````````````&`D821B)&,D9"1E)&8D9R1H)&DD:B1K)&PD;21N
M)&\D<"1Q)'(D<R1@(6$A8B%C(60A92%F(6<A:"%I(?W_23,4,R(S33,8,R<S
M`S,V,U$S5S,-,R8S(S,K,THS.S.<,YTSGC..,X\SQ#.A,_W__?_]__W__?_]
M__W__?][,QTP'S`6(<TS(2&D,J4RIC*G,J@R,3(R,CDR?C-],WPS4B)A(BLB
M+B(1(AHBI2(@(A\BOR(U(BDB*B(``````````"XB-")7(2<A(R@I(6<B1B$^
M(7<I>"DE(E(B)"$L(G8I+"AY*'8H>B@O(B$H(B@_(2HH+2@L*2$I(RE`(2HI
M+2DB*20H)"DE*28H)BDG*2@H*"DI*"DI,"DO*"\I*R@K*2XH+BDG(C`B*"(K
M(BHB+2(I(D$E0B5#)40E125&)4<E2"5))4HE2R5,)4TE3B5/)5`E4252)5,E
M5"55)58E5R58)6$E8B5C)60E925F)6<E:"5I)6HE:R5L)6TE;B5O)7`E<25R
M)7,E="5U)78E=R5X)2<L(2PB+",L)"PE+"8L*"PI+"HL*RPL+"TL+BPO+#`L
M,2PR+#,L-"PU+#8L-RPX+#DL.BP[+#PL/2P^+#\L0"Q!+%$L4BQ3+%0L52Q6
M+%@L62Q:+%LL7"Q=+%XL7RQ@+&$L8BQC+&0L92QF+&<L:"QI+&HL:RQL+&TL
M;BQO+'`L<2Q7+"HA+B$O(3`A,2%3(E0B)2$F(38B1R%((5@A>2EZ*7LI?"E]
M*7XI9B))(34B)"=@(F4B8B)9)THA=RAX*'LH?"A]*'XH,"4Q)3(E,R4T)34E
M-B4W)3@E.24A)2(E(R4D)24E)B4G)2@E*24J)6<A:"%F(6DA:B%5(E@B5B)9
M(E<B(2(B(B,B4R$D(E0A="%U(3,B,B)N(7`A1"%0(2LA?"%](7LA>B%R(7,A
M,2)%(7$A+2%O(58A02%5(4(A0R%L(6TA>"%Y(78A=R%!(E$A4B%G*&@H:2AJ
M*&LH;"AM*&XH;RAP*'$H<BAS*'0H=2AG*6@I:2EJ*6LI;"EM*6XI;REP*7$I
M<BES*70I=2E-*4XI3RE0*5$I4BE3*50I52E6*5<I6"E9*5HI6RE<*5TI7BE?
M*6`I82EB*6,I9"EE*68I32A.*$\H4"A1*%(H4RA4*%4H5BA7*%@H62A:*%LH
M7"A=*%XH7RA@*&$H8BAC*&0H92AF*"$F+"8B)BTF(R9()D<F+B8D)D(F028O
M)B8F1B9%)C$F)29$)D,F,"8G)CPF229*)C<F2R9,)C(F*28^)DTF3B8Y)D\F
M4"8T)B@F4292)C@F/293)E0F,R8J)E4F5B8Z)C\F5R98)C4F*R99)EHF.R9;
M)EPF0"9=)EXF7R9@)F$F8B9C)F0F-B9&(F$A8"%#(D<B2")+(DHB22),(F,A
M8B$Z(CDB92%D(3@B-R)?(5XA0B);(5TA7"%$(D4B6B%9(4\B3B)0(E$B3R%.
M(3PB/2)`(CLB/B(_(DTB6R)<(ETB6B(A(2(A(R$H(30A-2$V(3<A."$Y(3HA
M.R$\(3TA:R$R(3,A(2HB*B,J)"HE*B8J)RHH*BDJ*BHK*BPJ+2HN*B\J,"HQ
M*C(J,RHT*C4J-BHW*C@J.2HZ*CLJ/"H]*CXJ/RI`*D$J0BI#*D0J12I&*D<J
M2"I)*DHJ2RI,*DTJ3BI/*E`J42I2*E,J5"I5*E8J5RI8*EDJ6BI;*EPJ72I>
M*E\J8"IA*F(J8RID*F4J9BIG*F@J:2IJ*FLJ;"IM*FXJ;RIP*G$J<BIS*B$K
M(BLC*R0K)2LF*R<K*"LI*RHK*RLL*RTK+BLO*S`K,2LR*S,K-"LU*S8K-RLX
M*SDK.BL[*SPK/2L^*S\K0"M!*T(K0RM$*T4K1BM'*T@K22M**TLK3"M-*TXK
M3RM0*U$K4BM3*U0K52M6*U<K6"M9*UHK6RM<*UTK7BM?*V`K82MB*V,K9"ME
M*V8K9RMH*VDK:BMK*VPK;2MN*V\K<"MQ*W(K<RMT*W4K=BLA)"(D(R0D)"4D
M)B0G)"@D*20J)"LD+"0M)"XD+R0P)#$D,B0S)#0D-20V)#<D."0Y)#HD.R0\
M)#TD/B0_)$`D021")$,D1"1%)$8D1R1()$DD2B1+)$PD321.)$\D4"11)%(D
M4R14)%4D5B17)%@D621:)%LD7"1=)%XD7R1@)&$D8B1C)&0D921F)&<D:"1I
M)&HD:R1L)&TD;B1O)'`D<21R)',D="1U)'8D=R1X)'DD>B1[)'PD?21^)#$I
M,BDS*30I-2DV*3<I."DY*3HI.RD\*3TI/BD_*4`I02E"*4,I1"E%*48I1RE(
M*4DI2BE+*4PI7R(Q*#(H,R@T*#4H-B@W*#@H.2@Z*#LH/"@]*#XH/RA`*$$H
M0BA#*$0H12A&*$<H2"A)*$HH2RA,*%XB22=*)TLG3"=-)SHG.R=<)UTG7B<V
M)S<G."=4)U4G5B=7)U@G(2<B)R,G)2<K)RPG+2<N)R\G,"<Q)S(G,R<T)R<G
M*"<I)RHG/2<^)V4G9B=G)V@G82=B)V,G/R=`)T$G0B=#)T0G12=&)T<G2"=.
M)T\G4"=1)U(G4R=:)ULG8R)L)R8G8"=O)V$B/"=M)S4G.2=J)VLG7R=D(F0G
M;B=I)VEL2V]2=C)86VTR7SY?.WET7&1U)G-@729A>$XP7"IC:7%Z32]\(5,K
M<5%G+%)Y3GUQ/UXZ>SEY4DXK8V!K>DYW2R5E84I,5&%J8UPM7VM++U5U5GAE
M0%XC;$UI)VIV:3M[:6=,;V9005XL9$Q8<7E?3B1Z,F9[>CUZ2$Q-;U55(E-1
M;"=D4FPQ=GM.45`_2R1M*&U"7F)V7&UU7#E@3E0U=%M3-58D;&9D:G%L2T!+
M<FQJ4')Y)6Q?4&IG:U!17&E;3'U76V%:-E9?8T->1%XA2FQN(U,W;D]X2&HX
M;BQQ)7%.:3QY>65J;%9=0FTE>#IE6%LB2DU1;6YK;$5>8&-)2FER3E4V=D).
M1U8T8RUQ8FI"5R=S:DUN:S)9)7U5=F)5-7AU3#5U+61K9U5Q.W`U:4E,57I4
M859705Q&7F]Z86-S879<?$Y$6W%X9%QO93%<5E5:<T%+0UMZ66Y3.'HF?6]K
M)G1*3"AS6W,G6S=V9D]R<%I+4F=#5W!V7F@F96=E(THG3$EJ-G@E>BYQ3F]M
M2S!V3V]/:5YW4TYW7"A;>$LA7V%=2G4V:6QG;FYP<S]?2TQ!4%)T.F!`7V!.
M4EQJ?7962FII:"QC4',D2GA;1UYP:U9Q8F5,3'M+8VI!7VU64&DY;F-54U%P
M931H0VLJ:GQZ=G4\<%1].V!#3CI0.G=S6$UW+F1?5&=0?6PN4F]N5U5D:B)X
M:TT_5S%[;$TR7&Q0?4YP;D),;5!W97QS(FXS6718-VDN3B)9<5A/5"=E4E4I
M5B)T5W%853UP4%=05$]7:FMK?6U;17Q"2U5]2'1J:'-U7GEO4U-L0ETW;U1G
M2DI[67UZ*E9X='=W+%Q75R)?/DYP4R1P;&%G3TMS*6T^2F]T3G9[7CM0-U5Q
M;BAT>%PG2TY:9F`E;7)N>5Q<>5QS<GAY='%\/%!Y6S%7?$LE<'U+=%5M325*
M*U9"4#YP/5(D3#9Z34QZ6D]V.&EU6$Y,35=15&UI:TIB63)]+6-,5C19)V%3
M;D-0,WUD56A/0VTR4'Y.*%I0>%9]47A2>%-<8EUY>T%=-6-=;41.(4MC75U\
M+WE[4B%/*&0V='YL+F-M9T%]8EHS6&1=;W!Q=G!Z=5%/6E1<)EP_;T].66!6
M651L2VH_2C!5:4]M<4],>&1M9%A7)WTK:C)V<$\]>71F6TM1<U%I*7-@4%)I
M8UI28B)V=&%D6E5G/W4B3R]-(T\P37YQ(U`O82-X)DH[=VIR2%Y3:4E>7GU`
M2FIY3E%4;E)4(UDH?5E73G<^>E9/<%=A:T5X>EQ#75]Y;V=E?2-V?%DI?6YG
M9550;S%-(G<R<3%Q,DTK6B=*8F,\>R19.FY3>'I[)$][7&-V*FTA<F%.)GI@
M>59L;F0A>6][:WDC;BQJ*$IZ=%9-=GQ)=%1X)GA*7D9R6E=04T589FI=<UID
M9'9R=D)??5EV3#I3+V1A>29P4TL\8$IT>E0J?6)Y-W1"?3!\;'UB2CU]9VI#
M7U)18DXD4RM]8%]'<G!G;E`J<TM>.'9U83-Q(W<I2B5/1%\P83]P)'8V8T9Z
M;U!M?41==WP_9BU>/WIQ941M)5)N?39U=F%,7EY\5VQ=33=6,TU5>%AE:D]0
M3TQJ+FHM:G%3)5-/=R1N)%`B<G!0(W)X=S-0*5L[4VQ*)G%52V=W7DTD=T!X
M75-03"9/<W9W85Q3?GHG>EEK)T\O:F]D.6E8<5A8<F`T9GQ<<7-08WMR1EMQ
M4')07$]14S%,6'<H2SQK/F1<=$)<)W!`9FU*:VAH94-<7FUR4W=,5$XK9T-+
M,6$R=W-34E-`=5U?<VYQ9S1]2')2<W1N4V)13&I?.FE764UU<G%'>GA90E1E
M=D5=<F=?;4M*>ELU:"93-7U)>6)D/7LD5T5.54YF5CUE35YS;&!M;&P^>VM?
M>&$^>7-0*F!B:%1B?5(H95-97E,X=#QW?5QL:&=D=V,H;'%Z<F5T4"]295PE
M4#1Q,7QX3$9=47I?=RAZ=6Y.7G-G+'=$:V%M*V!'73-2/U),2C][?65E74U8
M=&QU4&UH4E!8669V*EM@=UE8(W1==%%O-5DK;3=C.VXT37-@36IU;&YH*4LO
M<4U**6QK<F]]<WE!9EAL+&U.:E]H3UXF4G1G5E%"9F-C,&0T6"5V7G,E5VAW
M1FAF>V9=?EQ:6"Q:,&HX8RI*>6$Q:FQR;GI5;G1Y;%)[>W!]/6!C3D9X+EY%
M7SYE+6UJ>FY-)FTN;6UP(5TO;7A\:UAY3#5-*7I=855B3VTB74IY:&IM96M3
M5&EZ84QD9&%':%M.55PU=W-\<W`O3C5Q4F](:'%K5$L^8'AC:6HR?'1@8$\E
M;BIZ0V8R82M*9&,[:59B<G-6;C)J=E!9;$M:*$\C75M83GE5:5%C/%(L6$QS
M>TU6=G5G;VAY8SM2<W-[8U!>,$YW5EEQ075$7#MU45YF7%)>8FUV;D]J;G!\
M8U]3=%,S831A4W1&7U9I*ULF=CEC16LI=#9->5(M6F-244]<2WI,74\I:#MC
M.F-:8'=N,UQU4R97-79;5U5A:E0C7U]]=U!4;2I+6V1[82)+8%,_9$![/EI-
M9#E60&]\83EV1U\Q9&=<:%Q6>G936G%R>GUB3U5X4%]-2W5P9"M+1%=^8EI=
M+EIN2CE5(6-C:"MS*4]W4W%49$YR:'5E+F<Z5FQ?0&1D:#587&0Y=#9Q7F(U
M86]-)W%E3EU+8UDL<WE0*VQ37FEW=7E>86Y+/&-6>&Y;<7TV=UYT;7)96RAP
M?6%47BQ@8VUA4TA?-EDL?5-O061K>"Q;1GPM6#IV7UM34T=X3DI!>#12-%PY
M>D]*,WQJ:FMJ>E!D;6==25]M7SQN06]23"1=2E]X4RAQ-TU4;UUD;E\L2SQI
M;&I+7S]Y+U9&52I/*4YX5C=Q>&Y965]S2'A&3F959G1%9E5O;TM??"=<9U9)
M>%)C/6-A3T!P6FQ777![+&PI<%=Z07M`4C!E96TM2S!Y)7<N2R]:-E@G4S)[
M1'TM;"%[:65N:71S<WA!<"]>,'A@<R]G+5LU9BAY6%U9:%9O8E-?8F!\2%<M
M?6]?4TQY4W!41UM57G1P4%5994=\5EQ@8C!:(W-L4TMT17U]8S%Y>U!;;#QU
M)').6$]8=W5A=C=2;'M(76AD05)7>#M65EX]=RYL85!U8#-J5DXE3'9L86(^
M8TA\<$UV>7!?/V4_3F%\,&U1?3MV3WE::T%*.%)Q35-C9GUM9GIC*G!0>6)\
M)WAE87EN=F=M:C1\0G5<5W5P:%UM4WQU/UI[3'I3)'17;T-48WMM>RU@;FHS
M>T)D9W9=4DQ?27PI979@,W9^87!+;VIP:D!:-'AR:T-D5VEQ9&]*5TY*?&%S
M1$ME8T5+-&H]:4E76VLQ;4-,/G=+?'1X-UE3<U1S9'=1=S=8,4Y"2C1[1DMV
M<&=54&I43"]+*G0O:4-U6&EI77-Q>U4[7GMT<WUR?29W25U35"A,05I53&19
M2GIC93Q3<$I$4%!**WIK:WAG95E7421S>U1C?%AZ57,K3W-K?%544WQ-9EEY
M8B%B5&MW8#)D?$QD>RMT/5!Q2CAO0%=Z;G1]8U-">VA5+ELV83=X/V!#>VI=
M(F(F;FAV=79*76)0)EUK77ED+V-\4'QT/$QJ=V1E<5]A=W=Y.6]8>"EY67@]
M;D988V1.=5E=9UDY4D-595I06EE16$Y>2RQT>UII=G-H+$]P<'UT2%M`3E1C
M3U%U<7)-:T\X329C6E$E<B9R3F1[4REQ27)8;TEF.%AS>C5S)'AS44AF6GAI
M7%=>7TML3U]T=%$Z4G)?-V$C8GQ39FU)6WID7D]03E-5=7,N=TAO<TU/=7-E
M0G!12G%J)E!:62MP9VM`935\1&0I3$9]-6HJ93I?7V%16CAA=&A]4R1B2G)F
M6C-W37TV<U=N1'4D6"=R.%DY64EO3E9+=RY?=6@U4E533'1\6FA9:W=)=3QS
M4EHU4S9H3U8Z=$EW*DQ#<%9,4U`]4WM;8$MD4W=V.E5-<V%+=&LM="I\;'=V
M:&=:3'=!96Y@?55F3BM\.U4H<B5B.4UR:D=+=$TO6UEO.DUY?'-?9TY"6BU/
M>6<H>&)S<DHD7T145TQ"93M-6F]8;B==)F)`8#!62GAZ?'Y9,%YL76A:8%1Y
M5E=-6%YX<E9D15`N="A=16U6<UE>9F,H4S!;6F4_8S%;:55!8%MO:7`R5WU0
M:5E^4&UL*5,I<D1P8F)O:5%Y66E::$-:1%I%5'IG8$TP8S);1'MC<R599WM+
M7510-F8N8%I]-5QX8#%G<'5<6$9M.6%`8T!Y<&E;661S-EQI9$5P06-,?$U\
M2W),<D]D6W%9>CAQ=7UY8'MG-WQD?$5[9V,Y6'AV15Q83"]@9W1<;WQ/76\J
M<CY]+$H[?4=],F=1:G1?;%%>9$-E)ED\365S56TZ66=M-7ML>&=@64Q&5"5G
M=54^4WM\<F1U7WAH;7A'3G9]6&A8359G6DQC2G9?1W!&<#I8='%P=$QU97Q%
M:G-J6UU77'U>>7)'55!82'`A42)15%EH5DI9,5I'6&)<3G-T=3EQ4UIJ=G5/
M+GU22C1?75<Z>B=N/75U>&AM850C459A>'E*6WE+5%1<63YN;7=N4F9A>7=M
M75MH,UMW43!@8E17=GE775A]32MR/4U">"QR+4HN2BY/0F,W7%I;.UES2E-V
M>&9U:G9J>78O3U-*+THP4CIQ,U=#8WUS6EY;7EYO8V)[;G=?2E=H3EM;.W%Q
M:3=Z1E`K3"AN>DMY>7U,?E-09&YR551-7SA\4%%-<E)W5$I955Y864TI;CQV
M6TQ)<'Q\26A^='QG7E=<7BQP?DQA33IA;ULR6B51.%QV6"118DUJ7'=P2G`^
M4%Q=5E164U!M(4TU7WA?(50R3DIH=6M58U!U(74G62ME2V9Q=45E(WE;8&MV
M<4MJ62)U45=X47AJ>6HS6E]O;W%V93]N9&(_4"QZ474S9SYI3G(T6TY\;ETT
M9S17-'<^36E:,$]9=V9S64XJ3DA+)U!+<$=0161@6UI5)U=`;G9X4G5I;3Q9
M1F4C=51:)V)\>UQQ=$IZ:&E.>&EE8CE0<E0F44Y?='PJ4RQ,8&]E9550?%MF
M?'Y+:FTQ7F-Y(E1V3U!6:E5N<4MZ(64Q56U/:VTR53Q58GTM<UM],&DG46-]
M,TYD?4YZ,$HG=S%/(F8V?"UR86\N<T9<:UE@:"AA=E5]3UU>45EJ9$]R/W=F
M8BAB5F-1;7EI,58R7FA@*U-<:R]?0TI\;D-]=FLR3VQ9/5E?6#A4/FMO77!=
M<5UR73Y91GLS3WUN*V1%6FQ8*%$I8CQ>-6=P6V)O<'$T3W%;,6`E7U)Y?6<C
M9G%[,$LN<F=-7&A79T!W8U`A6CU,*5%,77YC*E$J:#9J>GE,9EAV1U1+65)9
M2U-W6"E:>'5>7B]R*7A(6$%N07ES77IJ/78[83]-5'1-9D]\(GM<8#MT55HR
M>7)[=EM?7G);7'AN=VAK>E(\<5IZ:EI&6D%W-F='92Q61UPI82IB)E575%!R
M>VI=8'-[/7%G8E=]2$XW:D!\9WUO=S57.F]=<3->2VA=>$=[2%5?5RE=,6DM
M>EEV='HJ>&YF7$P\86]@/VE]?$YF5V%/9G%T<V1[9&1Y8V]N3SYV,F!^?"M1
M>E=(>U=B(U1X<"A79V$_4V1O15=B:V=\(F1H8E!F:'MH='1E/'15=#9?.7Q"
M;G5*96]B2R148%Y]6D9D/FA>8#1V4FI[>4)@9$HW9WUJ75DT6BIN:7M+6S5:
M/G$L4TE[3U]`4U=C9F]0?$!I4W5<;#=W.&IY44A<.6I><397-4\H66YL*ETB
M32YH/6%1<D%I?%(U6V=S?EA1?#)M+W0C>T%\*VXE5')T66Y*>V--.UA;97=X
M5'8I5TE+469,<"Y84WE^53Q8,'(K8FAS0F]L;3AG?EH^3'QR:UI88E9M458S
M8%)\2&M!4TUP=T]2;5A425QQ5SM?)7--=#]Q,7AZ:4M[54I4>4IW2%9H?#US
M?FY^9T)3-E,M3'IV,E984EAG)6,Y9RUP3'LA:R9437L]55]Q>W8T7FM52&4D
M>SE485XC9#=7;G@U7E)657DZ9U5K=U5G;SYA+GII5FY6.V=+;#-5-$XE>VYA
M*'=.>SU8?7MI?#9/1VTL;EU,)W9Z9B1U7'TS;4E.:&\_85MZ8TLI=R9[.5Q`
M<4AM0V\M5DY](6AT>R=5=G%39EY,,GAK7#9]:F5@<4Q;35U(5&U9)75[9E1F
M2'TA5C]]4WPA;SQG;E%59G)I,%]@6#I\+WU.<&%;264T;4-@6&-[:2AJ-WTG
M>T)I=WU98FQ<(FAP9GA]>7T_=B=G5V9S5$E4>E9R5T!A8EM89CUG3W`^<RQB
M-W5P8#A]:&,G5'QH4GIO>%-6-%50<'!W,VXZ:E-J26TK72QE(7U07S-L45]M
M;3AX>G<K>&!T.E0S9%II-EX_64!9;U9,62I:95]E=S),>5]@5SM4>GTS3'-;
M4E]*3EIN9&1/>S=/0VYJ3BUB85=U>DE5+'A99VES;5A$8W%P96AZ8$1N7EDB
M:R-K0GP[:BMH8EYO;2-H<4\\5&I\/F=R?#16+F(W4TQZ7'HU;6-A+&A=:&EO
M/70X3UMI+%%'6DEK3&@W7CQ695-=>E9:,4I(6B9?,WE2<D1*2TYU33!]*%5!
M<6EB2EPT;$!Z*'LH4&Q:;EE[8&IO7GI$8#E/2E5B5R]B.%=-:%IV(F]:8GQV
M4'LM461-+E%M7$YH>7`U3GQF>U=64'5=<7=]=G=;:GM<:4%9<G5%8%1J0GD\
M:D5247M`9R5K>E\B8SE70VE]:"]H4W(I>R582U5(4"]18U=&8")6<&US5U1\
M5UI?3%1R,%%@3'U;/W-1<#M\,&(E9EMB7E]'8&]R84QJ5D)G-DY`<WY-4GMX
M>'MW/V@W:#9M.EPT3'=Q.&AV2B1D5G1F7R=?9U]!841I2UQ%:2-O)FLC2VEC
M>U$D;VMO-%`C369H)6],4VU:.E=5<F5U;UDT>5153WUC6V%Q-FQ^>U=3,5$Q
M2S)1,DM"<6%T-7E#84)A=VLH7TI+.69>>"IY=THW;3A35G)95$5N<'(R2CM<
M>'$W;$IE0'9=?6-48DQ4=V570U,F6$%V=EU`35QE2V5$83!H,'1J<VY:.U<Q
M8BI7>U9?9%9**&M^6T)V.V]]5$A@.6@F;R1-=%0A6UQ;75M<;DM+57QK3D%-
M4WLK>51U*5E=:4U;3EU#9TQL;'E,2WQ@*%13;6]85W)X2F]:5%9-66Y807)3
M7W!::F)]8'A8+W<V6E=*6')Y6%]Z;T]"65)P460W<V!Z;&\R8CU43EEB="E4
M0DU:9UER*ED^6"U<:V)\5GE*6E17="%,.D\X=4-9:%!%8WAK,7([3RU386AL
M3C1@8UYW73)R=G-;=GY77WAR=RE06F8F=3Q78TQ;9EU=,U%M;UY6=&1O87A=
M3VAE2B%<-6`L?"U\)U@X;39;<%8O<R5-<5HH6&1,-%%82G):)W4H=29F;%5X
M57-:1F-D7F5>-5$V43=1,W)>:5-P-')4<&1+5'MF=6IC9EY47WEX+G`X45]6
M5U`A?&YO6%Q?:5UE>WU)8$E6*E1,96!I6%`B?#Y4,V)G7CQ<-E)5=2%.*75Y
M77I=57!?=EIR:V1Q<CEL?'TJ85E*;V\J=7EL+7A"<D-V4E<B>59P>G!@=G-I
M0W(K5#-*)DU#35I-3UE$=EUN1&<T8F)?6V<Q:"Y\365K>CQ/8D]V37!O/G1-
M5#AS(6ER<FMS5W!73U]/0&A!:&-/(FDJ4$%S*U!D5#QO(5A?65=S/5QE3'%M
M8G%;5#5B9DHN4V9,4W%G=5I*;GM%86E?7FY"=R)8+%TO<#U6*V$V>75425`G
M;VQB:EM,3FAU57=-4WYS-5!^8'M?768D:$U+*&\T;EA:.5$I7S!S1$PW3BEO
M55]7;49N/6]6?'1;*F\Y>&EU66-&83]4:%YJ<$)S+U-;2E=\6&U'85AT,U8M
M73Y50W%?;FM6671F5S=:>UU/72-865I8<$1O6&%4<7)M6U5<541S5TLV8G%O
M57M84U!=67`S2UU5)TTL4#I11'$S975[86E@?3Q\(EHC6B%2;U)M8FE>7$XU
M<F1045U(83=;8U\Y;45Q3W,K5RQA:V-';DEA>DI[<&%Z6G!G3'1:/TQM3BE5
M8GIE4%9K7VQ\7U9W:EXT2SYO-4P]3W)O-V)H3'QP8%9&<3AB*VLU2U%83G1W
M<T97.U$J=TIM4U=Z6$5V3%%\77U?97E*8'UR,%-S=$E:7F8Z>%!H>UA5:B-6
M1G9;<GQD,FA:6EQR5GLR:2UN8WIN7&IU8&9]<"Q7175@;F5;7EUP62-I>7%$
M<DM@)&DY8C%C:WPH339,6W`Z9BE-0W-982MO16=I8$5S0%0_52Y=?'E`3")E
M.$Y26%9Y*G%13D=V:UM^7V%8<W=G5WY4/%%/939+.%I$33Y6.F)83TQ@>6M]
M?6A76$MB:3IH1V--;$YL/U8G8U9?:'UA;BAV?5T[>%%H5WEN3D]L)6E55D5-
M.FT]43Y/.VPQ4FE,1%E\:3Y1/&PM93!W:DQ$4T!6?58A83U>*78D6B161G4B
M849I17)I=&Q64VL];%QB:UY<<#]K3E<_42MU?7E<2D9--G)^73=,.%MI4%U.
M0&LB?4MX5FHP<4Y;0W=/6R1+8'A7>TIK(6!-3EQ46'UV4C=R=GHJ=G=Z9E@Q
M=%)H14IK3&YB.V(M=V%X;',A7GUD;&,O73!=-TM3:"-A8%)^<"9I<DMS;5E<
M36!:=SE;+DQ;6D=-,5TO6"-C;TYS<C-X3F!]=6QK15-L?%M2:U0B7F9E,'!$
M571M;6-":'5M?%<[;2MV.')(=F9377(_3RQK0$\H9FE]04]?8&Q>(F`_=&]B
M<5E'<3A+?GDZ6W5:;'9<6F1Z3V`R72EF<V]M<WIK9GE=2EY57DID7WUF+'5U
M9&-I2VUD3U-8,UUL5#ER-U].2UA[65!2771W7&<E9"-\.ULZ<GUI2E!6=459
M-&0G;3UJ?F9$=RUU8%DT2F)X0D\^;#1E2$U(;DAG24TW>6AQ<EEU6S5*1EE)
M6"M9/&U46%I</&)M?&!L?E)':2IF<&([>BYU*GM[;#]L6'QE5$-Y8FYI5W9M
M;5YL3&YC5&AX>C1=-60P6%58:G0Y3F%64D\V4").;G-X<TQ<2U`D?$I-5%<C
M7F!D26Y=8GYU+%1157!80WA7:E=U/UA`?2UK*E4H9TIN9TIC>%U46&I9>W=M
M-64M4'%Q/6)(8U59*E\\6V1X>G$V96]S6GM@82Q9:W4V8$AI3TM)8VY>/F)O
M7"56<6)^5B%90%A;7#UM.%\E:BU7>7-X;4=U2F%C:UYR3'A9:D939ELO=7!.
M?FDV>W)B<D\Y=W-92V%=6CE:>VLY2WEM8&!`=#Q],5]O8R-@.7TQ<$M-/FU`
M57!C>FUD:6U576=V5#=E9UL_8DMN=%==<"M.7F=65DQA,VAN92)<4&`U52%5
M6WM+>7-+)71(>E=696E<>U!]=GLE6CU;8FQW35YP279O7C%3;GQ#:$AQ<4YM
M>71R-F0Y=7!<<6,E:#MR)%Y,6FE*6F-9?%IJ1'DD8UU[2F]$:$Q55VLM62M[
M65,B55YV=EI18"AI>74O>GQK:F`R8T558W%N54Q-66U!6&QZ:W$\>F)F97IZ
M8C9*-V1;:GIU+'M#3WUK>G@Y7W%A)%)[=5I06U`^:C%9-TIG4V5X,E-`8E]R
M94TL>4U-+FXN5FI78&<N:UE/35Q[;7!>:U<E7E=?4%M16R-5,G!<7&A*9GA.
M7%QJ4ELS:5MW*&,N5V%@.DM195Q0055*6"EC)&`I:4=375PN>#A,+E!R6$IC
M+TPM5%%V3%!&2D)5.DY'2C!Z6%\Z=6ME=&\U72I-<F-W>U!W.GUA?7YV0%%%
M:#AD:&%!3&U2/EMB8$EZ36$X2F!R27%Q7E]P1'A,;G)>26=S8F%G2V-,8WA/
M+&]^?25\,7I97U)@6G1*<2-./')C;"5@*W<O:UYE)&$K3719)FA.36EA;WQC
M8$%B)$XF7GYK76M@<%MT=&)(4VMT-6Y8=5]5958P:V-T36-T=#)Z=6]?2C%K
M/VU)?29D)'DS<&QE9U%'65=D76IW5#I:35I,>5IA/UM%3%!L.TMS7BII2%EC
M;CU71$]-4"9\>W%2?4%16V-)4T]<;4PG7CMF(6PY3%Y[8F=!5"A<0F)8<U-E
M67-&<UM-+$U#?&=40E$E>55H3F-*5%I?7WMC9WMX3V,P=6=825DO>'9O-ETO
M;GA-.%XG?'QW,7<[3B%T36XN84-L?D\_>&)8:%,H7F1T0FQU645Y4UUQ5GQL
M<'Q`;3E*9&YA<CE><E9T7EM?4UMG>F-8070W775R+E1S5CA=14]?7SYR(79+
M:WQQ1W-K8'QM6V%E;G5>4WI+<2]0.5U#43%U1FIA<"QV675K<#I=/W)%=R);
M=G(Z2G5W94MF;E-@)4Y85B]426E.4T)T9DLA<3)K(G$S:S1P=$LP5#)S-WML
M=6=N,G1M=7-/8G!.;DQQ.&5U5W-C94]&3S-S6&1Y3UI/37IC9F)R;G4[2EQC
M<DY95C!N971"6%!<;DQ@54IV2GU66$]T)E8^7%1;1U=^<DUQ0V)>7%]<+6\K
M9EUY/VHN;U!T<TXL9EY.>55T8U!-.%5]=RE<=EXJ7&-R-&E<4F9I=F-*9TY0
M=UH\2FAN7EIW<GMB)DP[6FEN6G5<=VIA04XQ5#%]/68M>V=X3F%B=V]U1T\R
M5&],:%1/;E=W)F!!5EQA8W!D<7%<)U9U=$YQ9'(P4&]L.GDU:VU41&)G:31K
M(6H\>"9.1GE:?#-4.5->:BMI86%/4W9T0&I/83I,:FYD<#1S;E1`<F5Q0W14
M8#9K(5=H2RUY+6ED6#-Z16(]?$1L,5@K7"15:6L[:%=8+GMA44!;/G5W7GM*
M1G=(3U!A4&YT:71.355;3SM=+$YH:3141V1;=4%Z*5YX5'=O,U,W:WAO7'5,
M;55;3W%0<3)U+EDL549B(WUE>RM?=6(M=C-U-7`E85UU(FQ];31U.'LC6TI6
M64M497IS.&LW8&Q7;'$O96%5;5=147)A>6\\75QV97!$=&EI>W-O5"),?G<\
M7TUK-U!"5BUH+V\E2VE+:'I&3&=F1VHD6TE/?&)Z;UYK2'5>5%5@,&]'8B]9
M9WEE9TI/46%(8GMO>7IR7"=@:'AJ2SQ+8E9>=5]U-FYV8DI3?&]$43%O15%>
M4&%9.&!133ES3&<H5B=.-51(9#13.6MU2UUV(W%'3$II<&%@=2][44M@>V5R
M<&QL<&MN2VEP3"]7(7-U?"1Q5F`R;U%T(7=1<7Q*?4I.3DAS.G-^;29:;&!-
M>%)+3FM8>5EY8$I*6B9+2$IN>6Q;,5!O57-F(F=99&%D1'QO>71/9G<\3D5T
M(UP]749T(7A6:$%;9G`Y9&UV+GD^73!7:%@]2UIY3GAP>6U@,V,S=$)J9G(V
M<%9;9&MG<E57-E1H>4%7565J:4Q7:5-)8EM\+4TP3")J=F1`4#=P(6YV5TIB
M2V)/>E]K2U8T=$UM4F0I:CID(G-234MV9G%!;3QH46YG<$QB*F1A=5IM;E=Q
M46MI;&ED8"=:5%TC:D-6=%9?6C-O36)];VAR16]G9WU73F=<7T=Y=EDL7UI6
M)%PX<'I5=V1$5FQT?F\A<"I>/%I\6%1Z96PH?&9L2U@Y>U-D>4U33VI*5$\]
M>$=T7VI;>3=496M2821J0GIA>VUZ(G!Q3"-Z=V).8G5I:V%H9U=H>%I+5'9W
M159I5'IZ<DQ==SI>*$XY<'YD26149$-J-&\^5V)[4TTU;VEZ)GD]7T=W?7A\
M>"M>:%M=8V)A1E%0=F9K>5I';'A>:7A>8W5.0WI794AL27,[9"YF-F\_7#U.
M0UA/4'I/2G-78$=1+FD]:$1Z3V)%>CAY8%PP>RE87V4G>6YV3'9X8G%L8%I2
M<4Q22T\]2C]=;W9Y7C1Z+55G<3Y>0%Q(44E1/GAV2WE48G5386E8?GA,3R1]
M=DY0>G-,/F8N=G!52E$^?'%5:4TU>E!B=W1432-G)5M18B)78W<F:B%06DYK
M>R9;7EME6&!J*EA@95M61F]J>%5D=TY88&]7;71F371,8W5*9&%<2'D_?"=H
M1%@^2RY<=U=H<$!=34]S7#!9:68\9$1J;&1E9'A[.TP]9%Q-=UE?74YM4%DC
M94UY+DU.3R]V4WUM:UQ6)&4V55U6:7DD9V-62U%D5G)5>EYX5VI854]]6"M8
M2WU<?"A@<U59?2-,>5EJ4W5U1V]:4SU:*&@O7"-P54TI8"Q>.G`Q;C)N3792
M;D9696`[<V%E2V0C5T);?DI/3R$P(C`C,"0P)3`F,"<P*#`I,"HP*S`L,"TP
M+C`O,#`P,3`R,#,P-#`U,#8P-S`X,#DP.C`[,#PP/3`^,#\P0#!!,$(P0S!$
M,$4P1C!',$@P23!*,$LP3#!-,$XP3S!0,%$P4C!3,%0P53!6,%<P6#!9,%HP
M6S!<,%TP7C!?,&`P83!B,&,P9#!E,&8P9S!H,&DP:C!K,&PP;3!N,&\P<#!Q
M,'(P<S!T,'4P=C!W,'@P>3!Z,'LP?#!],'XP(3$B,2,Q)#$E,28Q)S$H,2DQ
M*C$K,2PQ+3$N,2\Q,#$Q,3(Q,S$T,34Q-C$W,3@Q.3$Z,3LQ/#$],3XQ/S%`
M,4$Q0C%#,40Q13%&,4<Q2#%),4HQ2S%,,4TQ3C%/,5`Q43%2,5,Q5#%5,58Q
M5S%8,5DQ6C%;,5PQ73%>,5\Q8#%A,6(Q8S%D,64Q9C%G,6@Q:3%J,6LQ;#%M
M,6XQ;S%P,7$Q<C%S,70Q=3%V,7<Q>#%Y,7HQ>S%\,7TQ?C$A,B(R(S(D,B4R
M)C(G,B@R*3(J,BLR+#(M,BXR+S(P,C$R,C(S,C0R-3(V,C<R.#(Y,CHR.S(\
M,CTR/C(_,D`R03)",D,R1#)%,D8R1S)(,DDR2C)+,DPR33).,D\R4#)1,E(R
M4S)4,E4R5C)7,E@R63):,ELR7#)=,EXR7S)@,F$R8C)C,F0R93)F,F<R:#)I
M,FHR:S)L,FTR;C)O,G`R<3)R,G,R=#)U,G8R=S)X,GDR>C)[,GPR?3)^,B$S
M(C,C,R0S)3,F,R<S*#,I,RHS*S,L,RTS+C,O,S`S,3,R,S,S-#,U,S8S-S,X
M,SDS.C,[,SPS/3,^,S\S0#-!,T(S0S-$,T4S1C-',T@S23-*,TLS3#--,TXS
M3S-0,U$S4C-3,U0S53-6,U<S6#-9,UHS6S-<,UTS7C-?,V`S83-B,V,S9#-E
M,V8S9S-H,VDS:C-K,VPS;3-N,V\S<#-Q,W(S<S-T,W4S=C-W,W@S>3-Z,WLS
M?#-],WXS(30B-",T)#0E-"8T)S0H-"DT*C0K-"PT+30N-"\T,#0Q-#(T,S0T
M-#4T-C0W-#@T.30Z-#LT/#0]-#XT/S1`-$$T0C1#-$0T131&-$<T2#1)-$HT
M2S1,-$TT3C1/-%`T4312-%,T5#15-%8T5S18-%DT6C1;-%PT731>-%\T8#1A
M-&(T8S1D-&4T9C1G-&@T:31J-&LT;#1M-&XT;S1P-'$T<C1S-'0T=31V-'<T
M>#1Y-'HT>S1\-'TT?C0A-2(U(S4D-24U)C4G-2@U*34J-2LU+#4M-2XU+S4P
M-3$U,C4S-30U-34V-3<U.#4Y-3HU.S4\-3TU/C4_-4`U035"-4,U1#5%-48U
M1S5(-4DU2C5+-4PU335.-4\U4#51-5(U4S54-54U5C57-5@U635:-5LU7#5=
M-5XU7S5@-6$U8C5C-60U935F-6<U:#5I-6HU:S5L-6TU;C5O-7`U<35R-7,U
M=#5U-78U=S5X-7DU>C5[-7PU?35^-2$V(C8C-B0V)38F-B<V*#8I-BHV*S8L
M-BTV+C8O-C`V,38R-C,V-#8U-C8V-S8X-CDV.C8[-CPV/38^-C\V0#9!-D(V
M0S9$-D4V1C9'-D@V239*-DLV3#9--DXV3S90-E$V4C93-E0V5396-E<V6#99
M-EHV6S9<-ETV7C9?-F`V839B-F,V9#9E-F8V9S9H-FDV:C9K-FPV;39N-F\V
M<#9Q-G(V<S9T-G4V=C9W-G@V>39Z-GLV?#9]-GXV(3<B-R,W)#<E-R8W)S<H
M-RDW*C<K-RPW+3<N-R\W,#<Q-S(W,S<T-S4W-C<W-S@W.3<Z-SLW/#<]-SXW
M/S=`-T$W0C=#-T0W13=&-T<W2#=)-THW2S=,-TTW3C=/-U`W43=2-U,W5#=5
M-U8W5S=8-UDW6C=;-UPW73=>-U\W8#=A-V(W8S=D-V4W9C=G-V@W:3=J-VLW
M;#=M-VXW;S=P-W$W<C=S-W0W=3=V-W<W>#=Y-WHW>S=\-WTW?C<A."(X(S@D
M."4X)C@G."@X*3@J."LX+#@M."XX+S@P.#$X,C@S.#0X-3@V.#<X.#@Y.#HX
M.S@\.#TX/C@_.$`X03A".$,X1#A%.$8X1SA(.$DX2CA+.$PX33A..$\X4#A1
M.%(X4SA4.%4X5CA7.%@X63A:.%LX7#A=.%XX7SA@.&$X8CAC.&0X93AF.&<X
M:#AI.&HX:SAL.&TX;CAO.'`X<3AR.',X=#AU.'8X=SAX.'DX>CA[.'PX?3A^
M."$Y(CDC.20Y)3DF.2<Y*#DI.2HY*SDL.2TY+CDO.3`Y,3DR.3,Y-#DU.38Y
M-SDX.3DY.CD[.3PY/3D^.3\Y0#E!.4(Y0SE$.44Y1CE'.4@Y23E*.4LY3#E-
M.4XY3SE0.5$Y4CE3.50Y53E6.5<Y6#E9.5HY6SE<.5TY7CE?.6`Y83EB.6,Y
M9#EE.68Y9SEH.6DY:CEK.6PY;3EN.6\Y<#EQ.7(Y<SET.74Y=CEW.7@Y>3EZ
M.7LY?#E].7XY(3HB.B,Z)#HE.B8Z)SHH.BDZ*CHK.BPZ+3HN.B\Z,#HQ.C(Z
M,SHT.C4Z-CHW.C@Z.3HZ.CLZ/#H].CXZ/SI`.D$Z0CI#.D0Z13I&.D<Z2#I)
M.DHZ2SI,.DTZ3CI/.E`Z43I2.E,Z5#I5.E8Z5SI8.EDZ6CI;.EPZ73I>.E\Z
M8#IA.F(Z8SID.F4Z9CIG.F@Z:3IJ.FLZ;#IM.FXZ;SIP.G$Z<CIS.G0Z=3IV
M.G<Z>#IY.GHZ>SI\.GTZ?CHA.R([(SLD.R4[)CLG.R@[*3LJ.RL[+#LM.RX[
M+SLP.S$[,CLS.S0[-3LV.S<[.#LY.SH[.SL\.ST[/CL_.T`[03M".T,[1#M%
M.T8[1SM(.TD[2CM+.TP[33M..T\[4#M1.U([4SM4.U4[5CM7.U@[63M:.UL[
M7#M=.UX[7SM@.V$[8CMC.V0[93MF.V<[:#MI.VH[:SML.VT[;CMO.W`[<3MR
M.W,[=#MU.W8[=SMX.WD[>CM[.WP[?3M^.R$\(CPC/"0\)3PF/"<\*#PI/"H\
M*SPL/"T\+CPO/#`\,3PR/#,\-#PU/#8\-SPX/#D\.CP[/#P\/3P^/#\\0#Q!
M/$(\0SQ$/$4\1CQ'/$@\23Q*/$L\3#Q-/$X\3SQ0/%$\4CQ3/%0\53Q6/%<\
M6#Q9/%H\6SQ</%T\7CQ?/&`\83QB/&,\9#QE/&8\9SQH/&D\:CQK/&P\;3QN
M/&\\<#QQ/'(\<SQT/'4\=CQW/'@\>3QZ/'L\?#Q]/'X\(3TB/2,])#TE/28]
M)STH/2D]*CTK/2P]+3TN/2\],#TQ/3(],STT/34]-CTW/3@].3TZ/3L]/#T]
M/3X]/SU`/4$]0CU#/40]13U&/4<]2#U)/4H]2SU,/4T]3CU//5`]43U2/5,]
M5#U5/58]5SU8/5D]6CU;/5P]73U>/5\]8#UA/6(]8SUD/64]9CUG/6@]:3UJ
M/6L];#UM/6X];SUP/7$]<CUS/70]=3UV/7<]>#UY/7H]>SU\/7T]?CTA/B(^
M(SXD/B4^)CXG/B@^*3XJ/BL^+#XM/BX^+SXP/C$^,CXS/C0^-3XV/C<^.#XY
M/CH^.SX\/CT^/CX_/D`^03Y"/D,^1#Y%/D8^1SY(/DD^2CY+/DP^33Y./D\^
M4#Y1/E(^4SY4/E4^5CY7/E@^63Y:/EL^7#Y=/EX^7SY@/F$^8CYC/F0^93YF
M/F<^:#YI/FH^:SYL/FT^;CYO/G`^<3YR/G,^=#YU/G8^=SYX/GD^>CY[/GP^
M?3Y^/B$_(C\C/R0_)3\F/R<_*#\I/RH_*S\L/RT_+C\O/S`_,3\R/S,_-#\U
M/S8_-S\X/SD_.C\[/SP_/3\^/S\_0#]!/T(_0S]$/T4_1C]'/T@_23]*/TL_
M3#]-/TX_3S]0/U$_4C]3/U0_53]6/U<_6#]9/UH_6S]</UT_7C]?/V`_83]B
M/V,_9#]E/V8_9S]H/VD_:C]K/VP_;3]N/V\_<#]Q/W(_<S]T/W4_=C]W/W@_
M>3]Z/WL_?#]]/WX_(4`B0"-`)$`E0"9`)T`H0"E`*D`K0"Q`+4`N0"]`,$`Q
M0#)`,T`T0#5`-D`W0#A`.4`Z0#M`/$`]0#Y`/T!`0$%`0D!#0$1`14!&0$=`
M2$!)0$I`2T!,0$U`3D!/0%!`44!20%-`5$!50%9`5T!80%E`6D!;0%Q`74!>
M0%]`8$!A0&)`8T!D0&5`9D!G0&A`:4!J0&M`;$!M0&Y`;T!P0'%`<D!S0'1`
M=4!V0'=`>$!Y0'I`>T!\0'U`?D`A02)!(T$D025!)D$G02A!*4$J02M!+$$M
M02Y!+T$P03%!,D$S031!-4$V03=!.$$Y03I!.T$\03U!/D$_04!!04%"04-!
M1$%%049!1T%(04E!2D%+04Q!34%.04]!4$%105)!4T%4055!5D%705A!64%:
M05M!7$%=05Y!7T%@06%!8D%C061!94%F06=!:$%I06I!:T%L06U!;D%O07!!
M<4%R07-!=$%U079!=T%X07E!>D%[07Q!?4%^02%"(D(C0B1")4(F0B="*$(I
M0BI"*T(L0BU"+D(O0C!",4(R0C-"-$(U0C9"-T(X0CE".D([0CQ"/4(^0C]"
M0$)!0D)"0T)$0D5"1D)'0DA"24)*0DM"3$)-0DY"3T)00E%"4D)30E1"54)6
M0E="6$)90EI"6T)<0EU"7D)?0F!"84)B0F-"9$)E0F9"9T)H0FE":D)K0FQ"
M;4)N0F]"<$)Q0G)"<T)T0G5"=D)W0GA">4)Z0GM"?$)]0GY"(4,B0R-#)$,E
M0R9#)T,H0RE#*D,K0RQ#+4,N0R]#,$,Q0S)#,T,T0S5#-D,W0SA#.4,Z0SM#
M/$,]0SY#/T-`0T%#0D-#0T1#14-&0T=#2$-)0TI#2T-,0TU#3D-/0U!#44-2
M0U-#5$-50U9#5T-80UE#6D-;0UQ#74->0U]#8$-A0V)#8T-D0V5#9D-G0VA#
M:4-J0VM#;$-M0VY#;T-P0W%#<D-S0W1#=4-V0W=#>$-Y0WI#>T-\0WU#?D,A
M1")$(T0D1"5$)D0G1"A$*40J1"M$+$0M1"Y$+T0P1#%$,D0S1#1$-40V1#=$
M.$0Y1#I$.T0\1#U$/D0_1$!$041"1$-$1$1%1$9$1T1(1$E$2D1+1$Q$341.
M1$]$4$111%)$4T141%5$5D171%A$641:1%M$7$1=1%Y$7T1@1&%$8D1C1&1$
M941F1&=$:$1I1&I$:T1L1&U$;D1O1'!$<41R1'-$=$1U1'9$=T1X1'E$>D1[
M1'Q$?41^1"%%(D4C121%)44F12=%*$4I12I%*T4L12U%+D4O13!%,44R13-%
M-$4U139%-T4X13E%.D4[13Q%/44^13]%0$5!14)%0T5$145%1D5'14A%245*
M14M%3$5-14Y%3T5015%%4D53151%545615=%6$5915I%6T5<15U%7D5?16!%
M845B16-%9$5E169%9T5H16E%:D5K16Q%;45N16]%<$5Q17)%<T5T175%=D5W
M17A%>45Z17M%?$5]17Y%(48B1B-&)$8E1B9&)T8H1BE&*D8K1BQ&+48N1B]&
M,$8Q1C)&,T8T1C5&-D8W1CA&.48Z1CM&/$8]1CY&/T9`1D%&0D9#1D1&149&
M1D=&2$9)1DI&2T9,1DU&3D9/1E!&44921E-&5$951E9&5T981EE&6D9;1EQ&
M749>1E]&8$9A1F)&8T9D1F5&9D9G1FA&:49J1FM&;$9M1FY&;T9P1G%&<D9S
M1G1&=49V1G=&>$9Y1GI&>T9\1GU&?D8A1R)'(T<D1R5')D<G1RA'*4<J1RM'
M+$<M1RY'+T<P1S%',D<S1S1'-4<V1S='.$<Y1SI'.T<\1SU'/D<_1T!'04="
M1T-'1$=%1T9'1T=(1TE'2D=+1TQ'34=.1T]'4$=11U)'4T=41U5'5D=71UA'
M64=:1UM'7$==1UY'7T=@1V%'8D=C1V1'94=F1V=':$=I1VI':T=L1VU';D=O
M1W!'<4=R1W-'=$=U1W9'=T=X1WE'>D=[1WQ'?4=^1R%((D@C2"1()4@F2"=(
M*$@I2"I(*T@L2"U(+D@O2#!(,4@R2#-(-$@U2#9(-T@X2#E(.D@[2#Q(/4@^
M2#](0$A!2$)(0TA$2$5(1DA'2$A(24A*2$M(3$A-2$Y(3TA02%%(4DA32%1(
M54A62%=(6$A92%I(6TA<2%U(7DA?2&!(84AB2&-(9$AE2&9(9TAH2&E(:DAK
M2&Q(;4AN2&](<$AQ2')(<TAT2'5(=DAW2'A(>4AZ2'M(?$A]2'Y(4$M62V=+
M3TUH32U.>T\B4#A04%!=4%1155%845M17%%=45Y17U%@46)18U%D46519E%H
M46E1:E%K46U1;U%P47)1=E%Z47Q1?5%^42)2(U(G4BA2*5(J4BM2+5(R4CY2
M0E)#4D121E)'4DA225)*4DM235).4D]24%)14E)24U)44E525E)74EE26E)>
M4E]285)B4F1295)F4F=2:%)I4FI2:U)P4G%2<E)S4G12=5)W4GA29E1\5"55
M*U4N53A6359+5V1715MD6R5<)5U5771=?%Y^7C-?85]H7W%@+6%M875C(60I
M9"YE,64R93EE.V4\941E3F5095)E5F5Z97ME?&5^92%F)&8G9BUF+V8P9C%F
M,V8W9CAF/&9$9D9F1V9*9E)F5F999EQF7V9A9F1F969F9FAF:F9K9FQF;V9Q
M9G)F=69V9G=F>68A9R9G*6<J9RQG+6<P9S]G06=&9T=G2V=-9T]G4&=39U]G
M9&=F9W=G9VAH:'!H<6AW:'EH>VA^:"=I+&E,:7=I06IE:G1J=VI\:GYJ)&LG
M:REK*FLZ:SMK/6M!:T)K1FM':TQK3VM0:U%K4FM8:R9L)VPJ;"]L,&PQ;#)L
M-6PX;#IL0&Q!;$5L1FQ);$IL56Q=;%YL86QD;&=L:&QW;'AL>FPA;2)M(VUN
M;5MN/7)Z<C%S)W1N='1V=G8X=TAW4W=;>'!X(7HB>F9Z*7PA(R(C(R,D(R4C
M)B,G(R@C*2,J(RLC+",M(RXC+R,P(S$C,B,S(S0C-2,V(S<C.",Y(SHC.R,\
M(STC/B,_(T`C02-"(T,C1"-%(T8C1R-((TDC2B-+(TPC32-.(T\C4"-1(U(C
M4R-4(U4C5B-7(U@C62-:(ULC+"%=(UXC7R-@(V$C8B-C(V0C92-F(V<C:"-I
M(VHC:R-L(VTC;B-O(W`C<2-R(W,C="-U(W8C=R-X(WDC>B-[(WPC?2,F(DLA
M3"%^(7XC32%<(P````````````````````````````````````"^'_[_S1__
M_]T?___M'____1___PT@_W\<(```'"```!P@```<(```'"```!P@```<(```
M'"```!P@;P``````LA[__\(>___2'O__XA[___(>__\"'___$A___R(?__\R
M'___0A___U(?__]B'___<A___X(?__^2'___HA___[(?_P\`````````````
M````````````````````````A!63!XL5_SZ8%1&PG14#$Z(5`2BE%1`1J!4`
M`*@5DP6N%7L>N!41L+T5`Y?$%0$[RA42$<X5H`#0%9.5V!5K,-\54;#E%0(1
MZ!4!,NP5,!'P%;`"]!41`?<5"C#[%7FX!!8&$PD6`3`,%A``#1:```X6$P$2
M%@L0%A81`!@6`),<%@,K(A80`",6```C%I,%*19K=#(64;`X%B,3/A8!.T06
M,!!'%@``1Q8``$<6`'!*%A&P3Q8#$U06`"E7%A`16A:`(5T6`0!>%@`P8!85
ML&86#@-K%@$P;A8P`'`6``)Q%A$!=!8C$'@6``!X%@`3>Q:!:X(6$!"$%@`#
MAA83`8H6$Q".%A$PDA8``9,6``"3%C!5F1:X(I\6``"?%@`PH181L*86`I>L
M%@?[MA8Z$;P6L`/!%A,!Q18A`,<6``#'%@`;RQ8-.],6.!'8%K`#W183`>$6
M,Q'G%@$`Z!8`$^L6!2OQ%AP1]A8``?<6``#W%@`0^!81L/T6`!,`%P$J!!<P
M&0D7L`(-%P$`#A<0$!`7```0%P`1$A<!`Q47,!`8%S`"&Q<3!R$7:Q0H%Q$`
M*A<`$RT7!2LS%W3Y/1>XCT87$P%*%SL04!<``%`7``!0%P``4!=PV5@7L$I>
M%Q,!8A<[$&@7$0!J%P,1;A<``&X7,%ET%[$J>Q<1`7X7`!!_%P``?Q<!$8(7
M`0N&%Q``AQ<``(<7$P&+%RL0D!<``)`7`0&2%P`@DQ<0$987H`*9%Q$!G!<A
M,*`76;"G%P(!J1<``*D7,!FN%[`'M!<3`;@7.SC`%Q&PQ1<#`,<7``#'%P``
MQQ<``,<7$PW-%SLXU1<1L-H7`P'=%P`0WA<``-X7``#>%Q,!XA<@$.07$`#E
M%P`!YA<``.87$`'H%P``Z!<``.@7`##J%Q$8[A<"`.\7``#O%Q``\!<``/`7
M$0'S%R,`]A<``/87`)/Z%P$+_A<0$0$8,``#&!$!!A@K,`P8$;`1&,<3&1@!
M.Q\8,`$B&(`")!@``"08`#`F&!&P*QB#$S$8`2LV&#`1.ABP`S\8$0!!&`HP
M11@1L$H8`A%-&``@3A@``$X8``%/&!$!4A@K$%<8$:!;&`(37Q@!*V08$`!E
M&``!9A@!`&<8`#!I&!&0;1@"$W$8`2MV&#`1>ABP9H$8``"!&``P@Q@1L(@8
M`M..&`=KEA@Z$9P8L`>B&`,!I1@@`*88``"F&``3J1@%:[`8.!&U&+`#NA@3
M`;X8N!##&```PQ@`&\<8!2O-&!`!SQ@``]$8``#1&``0TA@1H-88`A'9&`$*
MW!AP>>08L*+J&!$![1@*$/`8``#P&``1\A@!`/,8$!'V&)``^!@1`?L8"0#]
M&```_1@`DP$9!;L)&?+Y%!FP(AD9$P$=&3LR)1D!("<9```G&0``)QDP62T9
ML`8R&9,!-QD[,#X9$:!"&2,11QD``$<9<!%,&;`"4!D1`%(9$!!4&0``5!D!
M$U@9`0-;&1`!71D``%T9DP=D&2L6:QD0`&P9`0%N&0``;ADP$7(9``)S&1$!
M=ADI,'L9$;"`&0``@!D``(`9,%&%&;`.BQD3!9`9.SB8&1&PG1D#`Z$9``&B
M&0``HAD``*(9DP&G&3D0K!D``*P9`@.O&0`[M!D``+09``"T&1,!N!DC`+L9
M``"[&0``NQD``+L9$`"\&0``O!D!`+T9(##`&1&0Q!D"`,49``#%&0``Q1D`
M`,49``#%&0`0QAD``,89`A')&0$#S!D``,P9``#,&1,!T!DKL-<9>;#?&2,3
MY1D!.^L9,!'O&;`"\QD1`?89(?#\&=FP!!I#$PH:`3L0&C`1%!JP`QD:$0$<
M&B!P(!I1L"8:(A,K&@$@+1H0$3`:D`$S&A$!-AH+,#L:$;!`&@*311H!JTL:
M%@!.&@`!3QH3`5,:(3!7&A&P7!H"`U\:`2EC&C`Q:!JP`FP:``!L&@`P;AH9
MN'4:0AM[&@$S@!HX$84:,`.)&@``B1H@`(H:``"*&@`3C1H%,Y,:$!&6&@``
MEAH``)8:``"6&@$`EQH`DYL:!2.@&C`!HQH``:0:`0"E&A`0IQH1,*L:``&L
M&@``K!HP$;`:,`*S&@$`M!H0$+8:``"V&@`1N!H``+@:``"X&@`"N1H3A;\:
M`Q#"&A$0Q1H`$\@:`2O-&C!WU1JX8]T:$P'A&CLPZ!J1L.X:HA'S&@$"]1HP
M>_T:\%<&&Q,!"ALK<!$;T?`9&^,1(!L!&R4;,'$K&[D*,AL3`38;.S`]&P&0
M0!L"$T0;`2M)&S`131NP`E$;$P=7&RLP71L1,&$;`Q-F&P$C:ALP$6X;L`)R
M&Q,!=ANK,'T;$;2#&_X1C!L!"8\;,'&5&[A'G1O3!:0;>S"L&Q&PL1L#4[<;
M`2&Z&Q`1O1L``+T;$P7"&VLPR1L1L,X;`A'1&P$SUAL0`-<;``#7&Q,%W!OK
M..4;$*#H&P(!ZAL`,.P;$!'O&[`"\QL3`/8;(##Y&W&P`!P"`0(<`!`#'!``
M!!P```0<$P$('`L0#!P1$`\<`!,2'`$K%QP``!<<```7'),%'1QK-B8<E;`M
M'`,3,AP!.S@<$`$Z'``".QP``#L<`#`]'!&P0AP#`44<`"!&'!``1QP``4@<
M``!('``P2AP1L$\<"@-3'`$051P0`%8<``%7'!$!6AP#`%P<``!<'`(38!P!
M(V0<$`!E'``#9QP``&<<`!!H'```:!P``6D<``!I'!``:AR0`FT<``!M'``P
M;QP1,',<AE-Z'`%[@1PP$84<L`.*'%$!CAPA`)`<``"0'``3DQP!.YD<,!&=
M'+`"H1P1`*,<$!"E'`$`IAP"$ZH<`2NO'!`1LAP``K,<``"S'``0M!P1L+D<
M`@&['``!O!PP$<`<L`+$'`$`Q1P0$,<<`0#('``1RAP!*\\<$!'2'!`"U!P3
M`=@<*P#<'```W!P`D^`<`ROF'#`1ZARP`NX<$P'R'#LP^1P``/D<`@#Z'```
M^APP&?\<L`,$'1,!"!TK$`T=$;`2'0,!%1T``!4=,!$9';`"'1T3`2$=(1`D
M'0``)!T"`28=`0`G'1``*!T``"@=$P$L'2L0,1T1`#,=`@$U'0`@-ATP$3H=
ML`(^'1$!01T!,$0=$3!('0(`21T``$D=,!%-';`"41T3`U8=.S!='1&P8AT#
M`64=`"!F'0``9AT``&8=$P5K'3LP<AT1L'<=`A%Z'0`0>QT0`7T=``!]'1,!
M@1TK%(<=`0"('0`!B1T``(D=$`&+'8`"C1T!`(X=`#"0'1&PE1T"`9<=`!"8
M'1``F1T``)D=$P&='2,0H1T1$*0=`I.I'04+KAT0$;$=,`"S'1,!MQTK<+X=
M4;#$'2,3RAT!.]`=,`#2'0``TAT``-(=`##4'1&PV1T#$]X=`2OC'1`1YATP
M`^H=`0'L'0HP\!T1L/4=`@'W'0`@^!T``/@=``#X'1$`^AT`$/L=$:#_'0"3
M`QX%*PD>$``*'@`""QX```L>`!`,'A&0$!X`$1(>`2D6'A`1&1ZP`!P>```<
M'@`P'AX1L",>`A,G'B$K+1XP$3$>L`,V'@$`-QX@`#@>```X'@`3.QX%*T$>
M,!%%'K`"21X3`4T>.Q!3'A$@5AX`$UD>(2M?'C(19!Z``F8>$P!I'B@P;1X1
MH'$>`A%T'@$*=QXP$7L>D@)_'A$!@AXA,(8>$0"('@(3C!X!*Y$>,!&5'I`"
MF![3`Y\>*Q*E'A$PJ1X"$ZT>`2L```````````````````````````````!X
M`XLO@0-R0X@#`"")`P0+C0,LZ)0#0..:`P`HG`/(0*`#1%FF`S=)K@-V>;@#
M0`2Z`Y,LP0/PH\D#.`#,`\4(T0,"[M@#`P#:`P"`VP-0->$#R.'H`R,>[P,`
M@O$#2<3W`UJM``1"*04$`,`'!&"`"@0<1A`$FJ07!`/`&P0J!2`$1"HE!$;6
M+03:/3<$``@X!(B#/00@%$`$(`!!!'`!100A($@$`@-+!``P302L0%($((96
M!&)$6P2@(%X$`(IA!%,"9@0$@&@$`@1J!(04;@3[>WL$!!!]!*1_AP3B$8T$
M0221!*0`E`0A%)@$P"";!%`ZH00`<*0$`@"E!$,GK`3)1;,$@B"V!#!&NP3!
M#\($B#S(!%`HS`0"AM`$)*#4!(@CV00&B-T$&0[C!`!`Y`2J(NH$9.OS!!P`
M]@0HS?T$(*$!!>$"!@4+A`L%`((-!9LG%@6>5!X%08$B!;.@*040`"H%"(4N
M!6$@,@4`"#,%""\Y!=`(/04^OD@%#P%-!1CW5@4#J%L%00I?!0A;904$!6@%
M`@!I!0`%:P4J.'$%05!U!0$`=@40&7H%""%]!1,#@@4``((%(F&'!00$B070
M0(T%`1"/!0"`D`4B0),%4("6!4A`F04(`)H%`!";!=$&H04`-Z8%@%ZL!0``
MK`6@`*X%$)2R!1@`M`4`8+8%0`*X!9``N@4`@+L%5`"^!0``O@4(`+\%``G!
M!1``P@5``,,%``##!2!0Q@40$,@%`"3*!0),S@4!`,\%`0;2!1@IUP5,@=P%
M`"'>!0$(X`6%9.8%`P#H!5)$[04A$/`%!`GS!0@`]`4-`/<%``#W!8A)_`4`
M@/T%`0#^!9$6!`9E!PL&`$`,!I*$$08S!!8&`(P9!I)%'P86`"(&(%(F!B@"
M*08(T"T&`$,P!@A,-`:B0#@&*L,_!A"80P8`+D<&`(!(!G`63@:$;E4&@D!8
M!I##7@:S!&0&A7QL!A@A<`8<!'0&R`)X!B`1>P8`2GX&2`J"!ALVB@9`58\&
M`(F2!@H`E`8"F9D&(0*<!D`0G@9"`J$&``2B!D0`I`8``*0&``"D!@0,IP80
M`*@&``"H!A82K08``*T&0@*P!@``L`8@&K0&0`"U!@`$M@8``+8&"0"X!K.U
MP@88"L8&(Q7,!J";TP;H']P&?%#C!GF#ZP;]$/,&G<#Z!O;;!@=@!0H'DN\4
M!T("%P<0`1D'`M\A!V%I*`<B""L'-9`Q!P(",P<``#,'`P`U!P(:.0>J14`'
M`0!!!P`"0@<!@44'42A*!X!@30?2`E('@`)4!P``5`<`&%8'`0!7!P"26@<`
M`%H'@`A<!P`@70<%!&`'`#5D!P`@90=$8&D'YDEQ!YY@>`=,$'P'0BJ!!R`H
MA`=(H8D'L1".!R"`D`<.`),'G'N=!Y"$H0>@%*4'P2BJ!^!!KP<$![,'28RY
M!PT0O0?(#,('$H3&![J)S@?``M$'(A35!P!5V0?`"MT'Q#[E!X.2ZP>C'/('
MAT/Y!P-'_P>@(@,(*#`'",`#"P@!"`T((*`0"`"`$0A$,!4(HX4<"```'`@.
M("`()2(E"#RW+P@!`#`((#(T"%",.0B9`#T(73%%"*``1P@"E$L(`P!-"$L.
M5`A"XUL(((Q?"(``8`B1T&8(E!UM""BC<PB<27H(P6!_"`9$@P@3!XD(D%J/
M"$1$DPB(#YD(``"9"$``F@C$E:$(@76H"$>$K@@"1+$(4\"W"(,KO@@(`<`(
M`$#!"$*2Q@@1!LH(I@G0"``(T0@B,M8(A+/="-T;YP@`\.L(BL#P"(("\P@"
M`/0(`(CV"`!L^@@`DOT((0#_"(!!`@F$C`<)"!,+"40)#PFG!Q<)```7"5&`
M&PE!#!\)`F`B"=``)0D`H"<)T!`K"00P+@D`1#`)```P"0`!,0D!@C0)``<W
M"0`!.`D.1#T),&A""04(10FR9$P)%`50">805@D41%H)$0!<"0`A7@D(G&,)
MP,MJ"2#A;PG"0',)3#!X";1!?@FL$(,)@YJ*";*8D0F!,I8)(IB;"80`G0EI
M,Z4)$KRL"<#6LPD[P+H)H:'`"5,,Q@D>BLT)`.K2"?#+VPG8!>$)D$/F"<,A
M[`D%2/`)'$KV"=`"^@E`,OX)00``"IW7"PH)*Q$*L.@8"L!](`I2)"4*0,(I
M"DO0,`H`H#(*J\@Z"H"*/@JI-$4*`(!&"LE!3`H0@$X*'R15"@"26`I[2&`*
M``!@"LP`9`H&A&@*`#-L"@]!<@H;`'8*`"!W"D"`>0HB@'P*F*"!"H:AAPIK
M`(P*,"J1"J2%EPJ!09L*!`:>"B%@H@H$`*,*@`"D"@&@IPH`!*@*N$:O"@_I
MN`J@`[P*``"\"B`8OPJ@0,(*$`C$"@HXR0H!`,H*``7,"@"HSPH$!-$*BL+7
M"@H`V0H@)]X*$`GA"@R#Y@H"".@*``#H"A%B[0J`$.\*#`#Q"@@(\PH,`/4*
M"`SX"@``^`I`"/H*$!3]"D0`_PH+``(+!&0&"\!0"@L!@`P+?@03"X2)&`M8
M!AT+0$$@"P#`(@NDE"@+8J@N"]P)-0L`&#<+```W"P"!.0L*`#L+"``\"Y!!
M0`L'0$0+H>1+"P$E3PM%9%4+[A%="WT.9@L`2&@+"/MP"Q86=@NH"'H++LF"
M"PD`A`L`&(8+@DJ+"Z`&CPMD:Y<+`@"8"P`6FPM(5J$+D(.F"Z!SK0LJ`+`+
M`("Q"R0`LPOYB+L+`D?`"P)-Q0NJ#\T+``#-"X".T@M[N-P+5'7D"Q@DZ`M`
MV>X+@,CR"PP$]0L``/4+0;#Z"R2,_PM"!`(,-%H)#!H`#`P`@`T,$,$1#$:`
M%0PR`!@,#1@=#`:!(0P"`"(,DLTJ#!1@+@P!=#,,$F$X#)$`.PR8P$`,"D)$
M#`\$20P@A$P,$YI3#`)`50QBBEL,(OUD#(B!:`R`0&H,`!!K#`,A;PP("'$,
M`3%U#"!$>`P$!WP,$KB"#(@#A@P`B8D,`*.-#```C0P"(I`,$!*3#`!&E@Q"
M`)@,00":#(!6GPQ!4J0,\%*K#``@K`P0AK`,%(*T#`00M@P"1KH,"D._##6`
MQ`S@8,D,`-C-#$$`SPP!"-$,`#34#&5LW`S!$>$,!*OG#(8"ZPP$(NX,`P#P
M#```\`R$D/0,``#T#!5`^`R!`OL,`@+]#``S`0T`!`(-0#@&#2`."@W`P`X-
M,``0#84`$PT`!14-)0T;#=!*(0W0@28-@"(I#0P"+`T%MC,-0&(W#7DF/PV`
M8D,-Z@))#0@(2PUGW58->85>#1L(8PV@WFL--8=S#0!`=`V,"GD-`-%]#:H%
M@PTEHHD-0(2,#1`5D`U-0)4-@`"6#1(`F`TBC9X-:!FD#8\%JPV`D*X-&CJU
M#62$N@UAA<`-P,S&#0(@R`T@",H-+G/3#:0@UPTT"]T-!`#>#144XPT!(.4-
M`(+G#5<`[`T`".T-!%#P#40`\@T2$O8-!7G]#=!``0X)``,.`$`$#@"$!@Y,
M!0L.1-@1#II`%@X441L.$@L@#@!`(0X!`B,.@!4G#@$@*0X`""H.2@@N#@#"
M,0X`"#(.`D`T#B`P-PX)F#P.```\#H`8/PXLXD8."`!'#@0`2`X$`$D.X!!-
M#A0`3PX@@%$.`"!2#@"850X`$%8.@G!;#H(`70Z(`F`.`!QC#B),:`X!`&D.
M`)%L#B`(;@X"0'`.0`!Q#@`<=`X`1'8.@P-[#L%\@PXA(8<.`(2)#@+@C0X"
M`(X.P$22#@KBF`X##IT.)H&B#M`"I@X`"*<.(2FL#I"6L@X!0+0.PKB[#D%B
MP`Z``,$.!@K%#E&FS`X2`<\.+('4#@#&V`X`!-D.L`S>#H"BX@XII.@.0(;L
M#@"`[0X"2O$.03#U#@`"]@Y`NOP.5P`!#P%0!`\@(`8/@(@)#[`D#@\"(!`/
M$@$3#],"&0\$`!H/$0(=#P``'0^``!X/!$`@#X(,)`\`X"</"#`J#P``*@\1
M$"T/"``N#P@",`^D@34/H$`X#PY"/0\`!#X/0,!!#X$`0P\`2$4/]2U/#Y$/
M5@\'V%T/*09B#WP`9P\!0&D/1D5O#TZ"=0\`P'</"!!Y#P4P?0\V[8</@`R*
M#T!ECP\+DY8/$`B8#P`&F@\@Z)\/"LBD#X)@J`_*`*P/-$"P#P(NM0\!$K@/
M!)"[#T@9P`\``,`/``#`#P``P`\``,`/``#`#P``P`\``,`/``#`#P``P`]`
M!<,/`!#$#S$`QP\`3,H/I0+/#R!5U`\01-</$`/:#P0CW@\B5.,/-(#G#P,*
MZP\!$NX/:Q+U#Z$!^0\`(/H/2*#^#T@$`1!`1040`(`&$(W@#1#P&A000"@7
M$":&'1`6!"$0&%`E$`!,*!`R`"L0$B$O$.0%-1``#3@0"(H\$`!"/A``2$`0
M,P!$$&`(1Q`#ATT0`851$``T5!`)`5<0*.1=$$4@81``@6,0J"5I$!A<;Q"@
M-740!-AZ$`(<?A#@`H(0H0"%$``"AA!0P(H01D&/$`!HDA`$II<08/*>$(J[
MIQ```*<0MLBO$.(`LQ`"8+80/@*\$(``O1``B<`0<@/&$(&&RQ`&`,T0``#-
M$(@(T!``1M,00$'6$`0.VA``(-L0(A;@$$@0XQ``BN80%R+L$!AT\A```/(0
M`!+T$`(A]Q```O@0@`CZ$$J8`!$@!`(1```"$1$2!A$"``<1!)D,$54J$Q$"
M!!41`%`7$1`0&1$``!D1FD4@$2JP)A$`H"@1"D(L$0@"+A$()S,1```S$9"`
M-A$2"#D10(<^$0$$0!$"XD41(#!($3`&3!&`C%`1Q`14$<`$5Q$`(%@1`(!9
M$0!`6A$QV&$1@`!B$0`"8Q$`%&41"`!F$1@":1$``&D1@`AK$1"*;Q$0('$1
M`$!R$0T!=A$`%7D1``!Y$0``>1$`0'H1H(!]$4`!?Q%0`8(1!""$$0"`A1$$
M`(81"`2($1``B1$``(D1`9",$01*D!$@`)$1`("2$0P`E!%"")<103";$8PJ
MH1$.":81A<"K$08IL!'$0+01``BU$1``MA$&@+D1,+*_$0(!P1$X(<81@`#'
M$0T#S!$@!,X10`G1$1(`TQ$`@-01$`36$02`V!'*B-X12`#@$0(&XQ$$).81
M`0#G$00`Z!$(`.D1$`'K$0U5\A'(J?D1*"3]$5(,`A(```(2,4@'$DUB#A(O
M`A02H#`8$BA!'!)[!202!=(J$I2H,!)$&#02PFP[$L)%01(70$82T2Y.$@$9
M4A((`E02`L)8$@`56Q)`D%X2D2!B$@$$9!)-!&D2``!I$@``:1(``&D2``!I
M$@``:1(``&D2``!I$@``:1(``&D2@(!K$D(5<!(@!'(2`@QU$@`&=Q($%'H2
M`&!\$H>?AA+9N9`2GP68$@I4G1)=)*02$#BH$K`EKA)(`+`2``"P$@``L!(`
M`+`2``"P$E`(LQ*9`+<2(`2Y$@`"NA((`;P2"$2_$D"8PQ(`*,42"H')$@@`
MRA(`A,P2`4#.$@`$SQ(A`-$2E`?7$@""V1(!`-H24`#<$H(DX!(``.`2`!SC
M$@``XQ(!/.@2!(#J$@`(ZQ(`2>X2*`+Q$CSX^A+`AO\2",L%$S!B"A,`H`P3
M!``-$P``#1,```T3`!@/$TBA%!,'`!<3)$`:$Q(`'!-`+"`3A2(E$V^I+Q.S
MYCD3#T`^$R911!.&;$L3.W)4$POB6Q.DM6,3GX5L$R(";Q-,A743(P%Y$P($
M>Q,`0'P3`B%_$R`@@1,$`((3)`*%$X`@AQ,$`(@3`'Z.$P0`CQ,$%I,3H`&6
M$X`JFA,$$)P3`-B@$S(`HQ.!^JL3@S&Q$X@$M!,@`+43`""V$X=`NQ,``+L3
M$(2^$R$"P1.`2,03=`#($P``R!,I`,L32A'0$P``T!/(`M03`)#6$P0`UQ,0
M!-D3`!';$Q``W!,!Q>$35\GJ$P``ZA,`+>X3$`CP$P!`\1,@4/03`!#U$U`$
M^!.(,/P3`0#]$P@`_A,"0``4$@`"%$```Q00``04``$%%"`(!Q0@`0D4$``*
M%`8(#10```T4`*`/%```#Q0```\4```/%```#Q0```\4```/%```#Q0```\4
M```/%```#Q0```\4```/%```#Q0```\4```/%(``$!0)BA44'@$:%#@A'Q0"
M&"(4@`0D%'`0*!0&`"H4```J%```*A0`$"L4`D0N%`2(,105.#<4`?@]%!P$
M013I(4@48&Q.%#`;5!2(!5@4@@A;%/-Z9A1@&FL4#(=Q%,4*=Q3!`'H42E*`
M%(``@10%(H44%`&(%$)0C!0&(I`4D`23%`"HEA0``)84`2F:%```FA1`")P4
M"!">%```GA1(B*(4;Q6K%(\!L10`(+(4`0NV%$!PNA001;X4H(C"%```PA0`
M`,(4``#"%`"!Q!0"`,44D`#'%`"8RA0&X,\4$'#3%`@6UQ0)0=L4`0'=%```
MW10@.N(4E@#F%```YA0``.84``#F%$`BZ10@<>X4&@+R%`(`\Q0GHOH4`"#[
M%`*`_10"P0$5``("%0`(`Q7!``85*2`*%:",#Q4D!A,5```3%0``$Q4``!,5
M``$4%0`!%14``!45&`$8%2!`&A4``!H5```:%0`$&Q6`!!T5`A`?%3Z`)140
M!"<5`(`H%0``*!4`0"D5`H`K%0!(+14``"T5``(N%4``+Q40`3$5```Q%0`@
M,A4E`#45(``V%00(.!6``CH5@``[%0``.Q4``#L5```[%0``.Q4``#L5```[
M%0``.Q4``#L5H`(^%5@`014``D(5``A#%4`!114`"$85``!&%0(@2!4#$$L5
M!`!,%0``3!4``$P5`().%1``3Q40`%`5@`!1%0``414$!U45``!5%0!$5Q4`
M`%<5``!7%0``5Q4``%<5``!7%2"B6Q4``%L5C*!@%2``814P2&45"&!H%1)9
M;A4``6\5$`!P%8!!<Q4(`'05`0!U%0`(=A4`3'D5!(![%8(4?Q6``(`5`""!
M%2$0````````````````````````````````U@$/_^(!.P#G`0``YP$``.<!
M_O_V`?__!@+__Q8"__\F`O__-@(/`#H"_O])`O__60+__VD"__]Y`O__B0)_
M`)`"``"0`@``D`(``)`"_O^?`O__KP+__[\"___/`O__WP+_?^X"``#N`@``
M[@(``.X"``#N`@``[@(``.X"``#N`O___@+_'PL#```+`P``"P,```L#```+
M`___&P/_CR@#```H`P``*`,``"@#```H`P``*`,``"@#```H`P``*`,``"@#
M```H`P``*`,``"@#```H`P``*`,``"@#```H`Q__-0/__T4#__]5`___90/_
MAW$#23D``````````*L```"K`"`SL`!C`+0`#0BX````N````+@```"X`!"`
MN@`>`+X```"^```0OP```+\```"_````OP```+\```"_``@"P0!(`,,`1@C'
M````QP```,<`&'C-`/\#UP#_`^$```#A`/\#ZP```.L```#K````ZP`4`.T`
M``#M````[0"-B?0``F3X`*%?`0$P,`4!```%`00`!@$S#`P!```,`<P`$`$`
M`A$!(``2`0``$@$``!(!```2`0``$@$``!(!```2`00`$P$``!,!```3`0``
M$P$``!,!```3`0``$P$``!,!```3`0``$P$``!,!```3`0``$P$``!,!```3
M`0``$P$``!,!```3`0``$P$``!,!```3`?]_(@'P_RX!!P`Q`0#P-0'__T4!
M/P!+`0``2P'__UL!_P-E`0``90$/\&T!__]]`?__C0'__YT!_P^I`0``J0$`
M`*D!``"I`0``J0$$`*H!^P.S`<PPN0'#R<$!`P##`0``PP$``,,!8,#'`0!0
MR0$``,D!``#)`04`RP$``,L!NS<`````````````````````````````````
M````````````````````````````DF4'`-_W%0!``!8`@<$;`$``'`"!02``
M```@``(`(0#``",`#H$H``<.+@`,`#``P``R````,@```#(````R````,@``
M`#(````R````,@```#(````R````,@```#(````R````,@```#(````R````
M,@```#(````R````,@```#(````R`(``,P`!+SD````Y````.0```#D````Y
M````.0```#D````Y````.0```#D````Y````.0#^_T@`^P-1`/[_8`#[`VD`
M``!I````:0```&D``@!J`/__>@#__XH`__^:`/__J@`"````````````/4]S
M3T=0^5"@4N]3=53E5`E6P5JV6X=FMF>W9^]G3&O"<\)U/'K;@@2#5XB(B#:*
MR(S/C?N.YH_5F3M2=%,$5&I@9&&\:\]S&H&ZB=*)HY6#3PI2OEAX6>99<EYY
M7L=AP&-&9^QG?VB7;TYV"W?U>`AZ_WHA?)V`;H)Q@NN*DY5K3IU5]V8T;J-X
M[7I;A!")3H>HE]A23E<J6$Q='V&^82%B8F719T1J&VX8=;-UXW:P=SI]KY!1
ME%*4E9\C4ZQ<,G7;@$"2F)5;4@A8W%FA7!==MUXZ7TI?=V%?;'IUAG7@?'-]
ML7V,?U2!(8*1A4&)&XO\DDV61YS+3O=."U#Q44]8-V$^86AA.67J:1%OI76&
M=M9VAWNE@LN$`/FGDXN5@%6B6U%7`?FS?+E_M9$H4+M315SH7=)B;F/:9.=D
M(&ZL<%MYW8T>C@+Y?9!%DOB2?D[V3F50_EWZ7@9A5VEQ@52&1XYUDRN:7DZ1
M4'!G0&@)48U2DE*B:KQW$)+4GJM2+V#RCTA0J6'M8\ID/&B$:L!OB(&AB926
M!5A]<JQR!'5Y?6U^J8"+B72+8Y!1G8EB>FQ4;U!].G\CBGQ12F&=>QF+5Y*,
MDZQ.TT\>4+Y0!E'!4LU2?U-P5X-8FEZ17W9AK&'.9&QE;V:[9O1FEVB';85P
M\7"?=*5TRG39=6QX['C?>O9Z17V3?16`/X`;@9:#9HL5CQ60X9,#F#B86IKH
MF\)/4U4Z6%%98UM&7+A@$F)":+!HZ&BJ;DQU>';.>#UZ^WQK?GQ^"(JABC^,
MCI;$G>13Z5-*5'%4^E;1661;.URK7O=B-V5%97)EH&:O9\%IO6S\=9!V?G<_
M>I1_`X"A@(^!YH+]@O"#P84QB+2(I8H#^9R/+I/'EF>8V)H3G^U4FV7R9H]H
M0'HWC&"=\%9D5Q%=!F:Q:,UH_FXH=)Z(Y)MH;`3YJ)J;3VQ1<5&?4E1;Y5U0
M8&U@\6*G8SMEV7-Z>J.&HHR/ES).X5L(8IQGW'31>=.#AXJRBNB-3I!+DT:8
MTU[H:?^%[9`%^:!1F%OL6V-A^F@^:TQP+W38=*%[4'_%@\")JXS<E2B9+E)=
M8.QB`I"*3TE1(5/96.->X&8X;9IPPG+6<U![\8!;E&93FV-K?U9.@%!*6-Y8
M*F`G8=!BT&E!FX];&'VQ@%^/I$[14*Q4K%4,6Z!=YUTJ94YE(6A+:N%RCG;O
M=UY]^7^@@4Z%WX8#CTZ/RI`#F56:JYL83D5.74['3O%/=U'^4D!3XU/E4XY4
M%%9U5Z)7QUN'7=!>_&'88E%EN&?I9\MI4&O&:^QK0FR=;GAPUW*6<P-TOW?I
M=W9Z?WT)@/R!!8(*@M^"8H@SB_R,P(X1D+&09)*VDM*919KIG->=G)\+5T!<
MRH.@EZN7M)X;5)AZI'_9B,V.X9``6$A<F&.?>JY;$U]Y>JYZCH*LCB90.%+X
M4G=3"%?S8G)C"FO#;3=WI5-7<VB%=H[5E3IGPVIP;VV*S(Y+F0;Y=V9X:[2,
M/)L'^>M3+5=.6<9C^VGJ<T5XNGK%>OY\=82/B7.--9"HE?M21U='=6![S(,>
MD@CY6&I+44M2AU(?8MAH=6F9EL50I%+D4L-AI&4Y:/]I?G1+>[F"ZX.RB3F+
MT8])F0GYRDZ76=)D$6:.:C1T@7F]>:F"?HA_B%^)"ODFDPM/RE,E8'%B<FP:
M?69]F$YB4=QWKX`!3PY/=E&`4=Q5:%8[5_I7_%<464=9DUG$6Y!<#EWQ77Y>
MS%^`8M=EXV4>9Q]G7F?+:,1H7VHZ:R-L?6R";,=MF',F="IT@G2C='AU?W6!
M>.]X07E'>4AY>GF5>P!]NGV(?P:`+8",@!B*3XM(C'>-(9,DD^*849D.F@^:
M99J2GLI]=D\)5.YB5&C1D:M5.E$+^0SY'%KF80WYSV+_8@[Y#_D0^1'Y$OD3
M^:.0%/D5^1;Y%_D8^?Z*&?D:^1OY'/F69AWY5G$>^1_YXY8@^4]C>F-74R'Y
MCV=@:7-N(ODW=2/Y)/DE^0U])ODG^7*(RE886BCY*?DJ^2OY+/E#3BWY9U%(
M6?!G$(`N^7-9=%Z:9,IY]5]L8,AB>V/G6]=;JE(O^719*5\28##Y,?DR^5ET
M,_DT^37Y-ODW^3CYT9DY^3KY._D\^3WY/OD_^4#Y0?E"^4/YPV]$^47YOX&R
MC_%@1OE'^6:!2/E)^3]<2OE+^4SY3?E.^4_Y4/E1^>E:)8I[9Q!]4OE3^53Y
M5?E6^5?Y_8!8^5GY/%SE;#]3NFX:63:#.4ZV3D9/KE485\=85E^W9>9E@&JU
M:TUN[7?O>AY\WGW+AI*(,I%;D[MDOF]Z<[AU5)!654U7NF'49,=FX6U;;FUO
MN6_P=4.`O8%!A8.)QXI:BQ^3DVQ3=51[#XY=D!!5`EA86&)>!V*>9.!H=G76
M?+.'Z)[C3HA7;E<G60U<L5PV7H5?-&+A9+-S^H&+B+B,BI;;GH5;MU^S8!)0
M`%(P4A97-5A76`Y<8%SV7(M=IEZ27[Q@$6.)8Q=D0VCY:,)JV&TA;M1NY&_^
M<=QV>7>Q>3MZ!(2IB>V,\XU(C@.0%)!3D/V039-VEMR7TFL&<%ARHG)H<V-W
MOWGD>YM^@(NI6,=@9F7]9;YFC&P><<EQ6HP3F&U.@7K=3JQ1S5'54@Q4IV%Q
M9U!HWV@>;7QOO'6S=^5Z](!CA(627%&795QGDV?8=<=Z<X-:^4:,%Y`MF&]<
MP(&:@D&0;Y`-DI=?G5U9:LAQ>W9)>^2%!(LGD3":AU7V85OY:7:%?S^&NH?X
MB(^07/D;;=EPWG-A?3V$7?EJD?&97OF"3G53!&L2:SYP&W(MAAZ>3%*CCU!=
MY60L919KZV]#?)Q^S85DB;V)R6+8@1^(REX79VIM_'(%=&]T@H?>D(9/#5V@
M7PJ$MU&@8V5UKDX&4&E1R5&!:!%JKGRQ?.=\;X+2BAN/SY&V3S=1]5)"5.Q>
M;F$^8L5EVFK^;RIYW(4CB*V58IIJFI>>SIZ;4L9F=VL=<"MY8H]"EY!A`&(C
M92-O27&)=/1];X#NA":/(Y!*D[U1%U*C4@QMR'#"B,E>@F6N:\)O/GQU<^1.
M-D_Y5E_YNERZ71Q@LG,M>YI_SG]&@!Z0-)+VEDB7&)AAGXM/IV^N>;21MY;>
M4F#YB&3$9--J7F\8<!!RYW8!@`:&7(;OC06/,I=OF_J==9Z,>']YH'W)@P23
M?YZ3GM:*WU@$7R=G)W#/=&!\?H`A42AP8G+*>,*,VHSTC/>6AD[:4.Y;UEZ9
M9<YQ0G:M=TJ`_(1\D">;C9_86$%:8EP3:MIM#V\[=B]]-WX>A3B)Y)-+EHE2
MTF7S9[1I06V<;@]P"71@=%EU)'9K>"R+7IAM42YB>):63RM0&5WJ;;A]*H^+
M7T1A%VAA^8:6TE*+@-Q1S%%>:1QZOGWQ@W66VD\I4IA3#U0.565<IV!.9ZAH
M;&V!<OAR!G2#=&+YXG5L?'E_N'^)@\^(X8C,D="1XI;)FQU4?F_0<9AT^H6J
MCJ.65YR?GI=GRVTS=.B!%I<L>,MZ('N2?&ED:G3R=;QXZ'BLF52;NY[>6U5>
M(&^<@:N#B)`'3DU3*5K274Y?8F$]8VEF_&;_;BMO8W">=RR$$X4[B!./19D[
MG!Q5N6(K9ZML"8-JB7J7H4Z$6=A?V5\;9[)]5'^2@BN#O8,>CYF0RU>Y69):
MT%LG9IIGA6C/:V1Q=7^WC..,@9!%FPB!BHQ,ED":I9Y?6Q-L&W/R=M]V#(2J
M49.)35&54<E2R6B4;`1W('>_?>Q]8I>UGL5N$86E40U4?50.9IUF)VF?;K]V
MD7<7@\*$GX=ID9B2])R"B*Y/DE'?4L99/5Y587AD>62N9M!G(6K-:]MK7W)A
M<D%T.'?;=Q>`O((%@P"+*(N,C"AGD&QG<NYV9G=&>JF=?VN2;")9)F>9A&]3
MDUB96=]>SV,T9G-G.FXK<]=ZUX(HD]E2ZUVN8<MA"F+'8JMDX&59:69KRVLA
M<?=S775&?AZ"`H-JA:.*OXPGEV&=J%C8GA%0#E([5$]5AV5V;`I]"WU>@(J&
M@)7OEO]2E6QI<G-4FEH^7$M=3%^N7RIGMFAC:3QN1&X)=W-\CG^'A0Z+]X]A
ME_2>MURV8`UAJV%/9?ME_&41;.]LGW/)<^%]E)7&6QR'$(M=4EI3S6(/9+)D
M-&<X:LILP'.>=)1[E7P;?HJ!-H*$A>N/^9;!F31/2E/-4]M3S&(L9`!ED67#
M:>YL6&_M<U1U(G;D=OQVT'C[>"QY1GTL@N"'U(\2F.^8PU+48J5D)&Y1;WQV
MRXVQD6*2[II#FR-0C5!*5ZA9*%Q'7G=?/V(^9;EEP64)9HMGG&G";L5X(7VJ
M@("!*X*S@J&$C(8JBA>+II`REI"?#5#S3V/Y^5>87]QBDF-O9T-N&7'#=LR`
MVH#TB/6(&8G@C"F/39%JEB]/<$\;7L]G(FA]=GYV1)MA7@IJ:7'4<6IU9/E!
M?D.%Z87<F!!/3WMP?Z65X5$&7K5H/FQ.;-MLKW+$>P.#U6PZ=/M0B%+!6-AD
MEVJG=%9VIW@7AN*5.9=E^5Y3`5^*BZB/KX^*D"52I7=)G`B?&4X"4'516UQW
M7AYF.F;$9\5HLW`!=<5UR7G=>B>/()D(FMU/(5@Q6/9;;F9E:Q%M>FY];^1S
M*W7I@]R($XE<BQ2/#T_54!!37%.36ZE?#6>/>7F!+X,4A0>)AHDYCSN/I9D2
MG"QG=D[X3TE9`5SO7/!<9V/2:/UPHG$K="M^[(0"AR*0TI+SG`U.V$[O3X50
M5E)O4B94D%3@5RM99EI:6W5;S%N<7F;Y=F)W9:=E;FVE;C9R)GL_?#9_4(%1
M@9J!0(*9@JF#`XJ@C.:,^XQTC;J-Z)#<D1R61);9F>><%U,&4BE4=%:S6%19
M;EG_7Z1A;F(09GYL&G'&=HE\WGP;?:R"P8SPEF?Y6T\77W]?PF(I70MGVFA\
M>$-^;)T53IE0%5,J4U%3@UEB6H=>LF"*84EB>6*098=GIVG4:]9KUVO8:[AL
M:/DU=/IU$GB1>-5YV'F#?,M]X7^E@#Z!PH'R@QJ'Z(BYBFR+NXP9D5Z7VY@[
MGZQ6*EML7XQELVJO:UQM\6\5<%URK7.GC-.,.YB183=L6(`!FDU.BTZ;3M5.
M.D\\3W]/WT__4/)3^%,&5>-5VU;K6&)9$5KK6_I;!%SS72M>F5\=8&ACG&6O
M9?9G^V>M:'MKF6S7;"-N"7!%<P)X/GE`>6!YP7GI>Q=]<GV&@`V"CH/1A,>&
MWXA0BEZ*'8O<C&:-K8^JD/R8WYF=GDI2:?D49VKYF%`J4G%<8V55;,IS(W6=
M=9=[G(1XD3"7=TZ29+IK7G&IA0E.:_E)9^YH%VZ?@AB%:XCW8X%O$I*OF`I.
MMU#/4!]11E6J51=60%L97.!<.%Z*7J!>PE[S8%%H86I8;CUR0'+`<OAV97FQ
M>]1_\XCTB7.*88S>C!R77EB]=/V,QU5L^6%Z(GUR@G)R'W4E=6WY&7N%6/M8
MO%V/7K9>D%]58))B?V--99%FV6;X9A9H\FB`<EYT;GMN?=9]<G_E@!*"KX5_
MB9.*'9#DDLV>()\566U9+5[<8!1F<V:09U!LQ6U?;_-WJ7C&A,N1*Y/93LI0
M2%&$50M;HUM'8GYERV4R;GUQ`71$=(=TOW1L=JIYVGU5?JA_>H&S@3F"&H;L
MAW6*XXUXD)&2)91-F:Z;:%-17%1IQ&PI;2MN#(*;A3N)+8JJBNJ69Y]A4KEF
MLFN6?OZ'#8V#E5V6'66);>YQ;OG.5]-9K%LG8/I@$&(?9E]F*7/Y<]MV`7=L
M>U:`<H!E@:"*DI$63N)2<FL7;05Z.7LP?6_YL(SL4R]645BU6P]<$5SB74!B
M@V,49"UFLVB\;(AMKVX?<*1PTG$F=8]UCG49=A%[X'LK?"!].7TLA6V%!X8T
MB@V089"UD+>2]I<WFM=/;%Q?9Y%MGWR,?A:+%HT?D&M;_5T-9,"$7)#AF(=S
MBUN:8'YGWFT?BJ:*`9`,F#=2</E1<(YXEI-PB->1[D_74_U5VE:"5_U8PEJ(
M6ZM<P%PE7@%A#6)+8HAC'&0V97AE.6J*:S1L&6TQ;^=QZ7)X<P=TLG0F=F%W
MP'E7>NIZN7R/?:Q]87Z>?RF!,8.0A-J$ZH66B+"*D(LXCT*0@Y!LD9:2N9*+
MEJ>6J);6E@"7")B6F=.:&IO44WY8&5EP6[];T6U:;Y]Q(72Y=(6`_8/A78=?
MJE]"8.QE$FAO:5-JB6LU;?-MXW/^=JQW37L4?2.!'()`@_2$8X5BBL2*AY$>
MDP:8M)D,8E.(\(]ED@==)UUI75]TG8%HA]5O_F+2?S:)<HD>3EA.YU#=4D=3
M?V('9FE^!8A>EHU/&5,V5LM9I%HX7$Y<35P"7A%?0V"]92]F0F:^9_1G''/B
M=SIYQ7^4A,V$EHEFBFF*X8I5C'J,]%?46P]?;V#M8@UIEFM<;H1QTGM5AUB+
M_H[?F/Z8.$^!3^%/>U0@6KA;/&&P96AF_'$S=5YY,WU.@>.!F(.JA<Z%`X<*
MBJN.FX]Q^<6/,5FD6^9;B6#I6PM<PU^!;'+Y\6T+<!IUKX+VBL!.05-S^=F6
M#VR>3L1/4E%>525:Z%P18EERO8*J@_Z&68@=BC^6Q983F0F=79T*6+-<O5U$
M7N%@%6'A8P)J)6X"D5233I@0G'>?B5NX7`EC3V9(:#QWP9:-EU28GYNA90&+
MRXZ\E355J5S67;5>EV9,=O2#QY736+QBSG(HG?!.+ED/8#MF@VOG>2:=DU/`
M5,-7%ET;8=9FKVV->'Z"F)9$EX13?&*68[)M"GY+@4V8^VI,?Z^=&IY?3CM0
MME$<6?E@]F,P:3IR-H!T^<Z1,5]U^7;Y!'WE@F^$NX3EA8V.=_EO3WCY>?GD
M6$-;66#:8QAE;6689GKY2FDC:@MM`7!L<=)U#7:S>7!Z>_F*?WSY1(E]^9.+
MP)%]EG[Y"ID$5Z%?O&4!;P!VIGF>BJV96IMLGP11MF&18HUJQH%#4#!89E\)
M<0"*^HI\6Q:&^D\\4;161%FI8_EMJEUM:891B$Y93W_Y@/F!^8)9@OF#^5]K
M76R$^;5T%GF%^0>"18(Y@S^/78^&^1B9A_F(^8GYIDZ*^=]7>5\39HOYC/FK
M=7E^;XN-^0:06YJE5B=8^%D?6K1;COGV7H_YD/E08SMCD?D]:8=LOVR.;9-M
M]6T4;Y+YWW`V<5EQD_G#<=5QE/E/>&]XE?EU>^-]EODO?I?Y38C?CICYF?F:
M^5N2F_GVG)SYG?F>^85@A6V?^;%QH/FA^;&5K5.B^:/YI/G39Z7YCG`P<3!T
M=H+2@J;YNY7EFGV>Q&:G^<%Q282H^:GY2UBJ^:OYN%UQ7ZSY(&:.9GEIKFDX
M;/-L-FY!;]IO&W`O<%!QWW%P<ZWY6W2N^=1TR'9.>I-^K_FP^?&"8(K.C['Y
M2).R^1F7L_FT^4).*E"U^0A2X5/S9FULRF\*<W]W8GJN@MV%`H:V^=2(8XI]
MBVN,M_FSDKCY$Y<0F)1.#4_)3[)02%,^5#-4VE5B6+I89UD;6N1;GV"Y^<IA
M5F7_961FIVA:;+-OSW"L<5)S?7L(AZ2*,IP'GTM<@VQ$<XES.I*K;F5T'W9I
M>A5^"H9`4<58P63N=!5U<';!?Y60S994F29NYG2I>JIZY8'9AGB'&XI)6HQ;
MFUNA:`!I8VVI<Q-T+'27>.E]ZW\8@56!GH-,C"Z6$9CP9H!?^F6)9VILBW,M
M4`-::FON=Q99;%W-725S3W6Z^;OYY5#Y42]8+5F66=I9Y5N\^;WYHEW78A9D
MDV3^9+[YW&:_^4AJP/G_<61TP?F(>J]Z1WY>?@"`<('"^>^'@8D@BUF0P_F`
MD%*9?F$R:W1M'WXEB;&/T4^M4)=1QU+'5XE8N5NX7D)AE6F,;6=NMFZ4<6)T
M*'4L=7.`.(/)A`J.E)/>D\3YCDY13W90*E'(4\M3\U.'6]-;)%P:88)A]&5;
M<I=S0'3"=E!YD7FY>09]O7^+@M6%7H;"CT>0]9#JD866Z);IEM929U_M93%F
M+VA<<39ZP9`*F)%.Q?E2:IYKD&^)<1B`N()3A4N0E9;REON7&H4QFY!.BG'$
MED-1GU/A5!-7$E>C5YM:Q%K#6RA@/V'T8X5L.6UR;I!N,'(_<U=TT8*!B$6/
M8)#&^6*66)@;G0AGBHU>DDU/25#>4'%3#5?460%:"5QP89!F+6XR<DMT[WW#
M@`Z$9H0_A5^'6X@8B0*+59#+ET^;<TZ13Q)1:E''^2]5J55Z6Z5;?%Y]7KY>
MH&#?8`AA"6'$8SAE"6?(^=1GVF?)^6%I8FFY;"=MRODX;LOYX6\V<S=SS/E<
M=#%US?E2=L[YS_FM??Z!.(35B)B*VXKMBC".0HY*D#Z0>I!)D<F1;I/0^='Y
M"5C2^=-KB8"R@-/YU/E!46M9.5S5^=;Y9&^G<^2`!XW7^1>2CY78^=GYVOG;
M^7^`#F(<<&A]C8?<^:!7:6!'8;=KOHJ`DK&664X?5.MM+85PEO.7[IC68^-L
MD9#=4<EANH'YG9U/&E``49Q;#V'_8>QD!6G%:Y%UXW>I?V2"CX7[AV.(O(IP
MBZN1C$[E3@I/W?G>^3=9Z%G?^?)=&U];7R%@X/GA^>+YX_D^<N5SY/EP=<UU
MY?G[>>;Y#(`S@(2`X8)1@^?YZ/F]C+.,AY#I^>KY])@,F>OY[/DW<,IVRG_,
M?_Q_&HNZ3L%.`U)P4^WYO53@5OM9Q5L57\U?;F[N^>_Y:GTU@_#YDX:-BO'Y
M;9=WE_+Y\_D`3EI/?D_Y6.5EHFXXD+"3N9G[3NQ8BEG964%@]/GU^11Z]OE/
M@\.,95%$4_?Y^/GY^<U.:5)56[^"U$XZ4JA4R5G_65!;5UM<6V-@2&'+;IEP
M;G&&<_=TM77!>"M]!8#J@2B#%X7)A>Z*QXS,EEQ/^E*\5JME*&9\<+AP-7*]
M?8V"3)'`EG*=<5OG:)AK>F_>=I%<JV9;;[1[*GPVB-R6"$[73B!3-%B[6.]8
M;%D'7#->A%XU7XQCLF969Q]JHVH,:S]O1G+Z^5!SBW3@>J=\>('?@>>!BH-L
MA".%E(7/A=V($XVLD7>5G):-4<E4*%>P6TUB4&<]:)-H/6[3;GUP(7[!B*&,
M"8]+GTZ?+7*/>\V*&I-'3TY/,E&`5-!9E5ZU8G5G;FD7:JYL&F[9<BISO76X
M>S5]YX+Y@U>$]X5;BJ^,AXX9D+B0SI9?G^-2"E3A6L);6&1U9?1NQ'+[^81V
M37H;>TU\/G[??WN#*XO*C&2-X8U?CNJ/^8]ID-&30T]Z3[-0:%%X44U2:E)A
M6'Q88%D(7%5<VUZ;8#!B$VB_:PALL6].<2!T,'4X=5%U<G9,>XM[K7O&>X]^
M;HH^CTF//Y*3DB*3*Y3[EEJ8:Y@>F0=2*F*88EEM9';*>L![=GU@4[Y<EUXX
M;[EPF'P1EXZ;WIZE8WID=H<!3I5.K4Y<4'502%3#69I;0%ZM7O=>@5_%8#IC
M/V5T9<QE=F9X9OYG:&F):F-K0&S`;>AM'VY>;AYPH7".<_US.G5;=X=XCGD+
M>GUZOGR.?4>"`HKJBIZ,+9%*D=B19I+,DB"3!I=6EUR7`I@.GS92D5)\5218
M'5X?7XQ@T&.O:-]O;7DL>\V!NH7]B/B*1(Z-D626FY8]ETR82I_.3T91RU&I
M4C)6%%]K7ZICS63I94%F^F;Y9AUGG6C7:/UI%6]N;V=QY7$J<JIT.G=6>5IY
MWWD@>I5ZEWS??$1]<'Z'@/N%I(94BK^*F8V!CB"0;9#CD3N6U9;EG,]E!WRS
MC<.36%L*7%)3V6(=<R=0EUN>7[!@:V'5:-EM+G0N>D)]G'TQ?FN!*HXUCGZ3
M&)103U!7YEVG7BMC:G\[3D]/CT]:4-U9Q(!J5&A4_E5/69E;WEW:7EUF,6?Q
M9RIHZ&PR;4INC6^W<.!SAW5,?`)]+'VB?1^"VX8[BH6*<(V*CC./,9!.D5*1
M1)30F?EZI7S*3P%1QE'(5^];^UQ99CUJ6FV6;NQO#'%O=>-Z(H@AD'60RY;_
MF0&#+4[R3D:(S9%]4]MJ:VE!;'J$GEB.8?YF[V+=<!%UQW52?KB$28L(C4M.
MZE.K5#!70%?77P%C!V-O9"]EZ&5Z9IUGLV=B:V!LFFPL;^5W)7A)>5=Y&7VB
M@`*!\X&=@K>"&(>,BOSY!(V^C7*0]'89>C=Z5'YW@`=5U%5U6"]C(F1)9DMF
M;6B;:81K)6VQ;LUS:'2A=%MUN77A=AYWBW?F>0E^'7[[@2^%EX@ZBM&,ZXZP
MCS*0K9-CEG.6!Y>$3_%3ZEG)6AE>3FC&=+YUZ7F2>J.![8;JC,R-[8^?915G
M_?GW5U=OW7TOC_:3QI:U7_)AA&\43IA/'U#)4]]5;UWN72%K9&O+>)I[_OE)
MCLJ.;I!)8SYD0'>$>B^3?Y1JG[!DKV_F<:ATVG3$>A)\@GZR?)A^FHL*C7V4
M$)E,F3E2WUOF9"UG+GWM4,-3>5A885EA^F&L9=EZDHN6BPE0(5!U4C%5/%K@
M7G!?-&%>90QF-F:B9LUIQ&XR;Q9S(7:3>CF!68+6@[R$M5#P5\!;Z%MI7Z%C
M)GBU?=R#(87'D?61BE'U9U9[K(S$4;M9O6!5AAQ0__E44CI<?6$:8M-B\F2E
M9<QN('8*@6".7Y:[EM].0U.852E9W5W%9,EL^FV4<W]Z&X*FA>2,$(YWD.>1
MX94AEL:7^%'R5(95N5^D9(AOM'T?CTV/-93)4!9<OFS[;1MUNW<]?&1\>8K"
MBAY8OED67G=C4G**=6MWW(J\C!*/\UYT9OAM?8#!@\N*49?6FP#Z0U+_9I5M
M[V[@?>:*+I!>D-2:'5)_4NA4E&&$8MMBHF@2:5II-6J2<"9Q77@!>0YYTGD-
M>I:`>(+5@DF#286"C(6-8I&+D:Z1PT_15NUQUW<`A_B)^%O67U%GJ)#B4UI8
M]5ND8(%A8&0]?G"`)86#DJYDK%`470!GG%B]8JAC#FEX:1YJ:VZZ=LMYNX(I
MA,^*J(W]CQ*12Y&<D1"3&).:D]N6-IH-G!%.7'5=>?IZ47O)>RY^Q(19CG2.
M^(X0D"5F/VE#=/I1+F?<GD51X%^6;/*'78AWB+1@M8$#A`6-UE,Y5#16-EHQ
M7(IPX']:@`:![8&CC8F17YKRG710Q$Z@4_M@+&YD7(A/)%#D5=E<7UYE8)1H
MNVS$;;YQU'7T=6%V&GI)>L=]^WUN?_2!J88<C\F6LYE2GT=2Q5+MF*J)`T[2
M9P9OM4_B6Y5GB&QX;1MT)WC=D7R3Q(?D>3%ZZU_63J14/E6N6*59\&!38M9B
M-F=5:36"0):QF=V9+%!34T15?%<!^EAB`OKB9&MFW6?!;^]O(G0X=!>*.)11
M5`969E=(7YIA3FM8<*UPNWV5BFI9*X&B8PAW/8"JC%18+62[:95;$5YO;@/Z
M:85,4?!3*ED@8$MAAFMP;/!L'GO.@-2"QHVPD+&8!/K'9*1OD60$94Y1$%0?
M5PZ*7V%V:`7ZVW52>W%]&I`&6,QI?X$JB0"0.9AX4%=9K%F58@^0*IM=87ER
MUI5A5T9:]%V*8JUD^F1W9^)L/FTL<C9T-'AW?ZV"VXT7F"120E=_9TARXW2I
MC*:/$9(JEFM1[5-,8VE/!%668%=EFVQ_;4QR_7(7>H>)G8QM7XYO^7"H@0YA
MOT]/4$%B1W+'>^A]Z7]-D*V7&9JVC&I7<UZP9PV$58H@5!9;8U[B7@I?@V6Z
M@#V%B95;EDA/!5,-4P]3AE3Z5`-7`UX68)MBL6)58P;ZX6QF;;%U,GC>@"^!
MWH)AA+*$C8@2B0N0ZI+]F)&;15ZT9MUF$7`&<@?Z]4]]4FI?4V%39QEJ`F_B
M=&AY:(AYC,>8Q)A#FL%4'WI3:?>*2HRHF*Z9?%^K8K)UKG:KB'^00I8Y4SQ?
MQ5_,;,QS8G6+=49[_H*=F4]./)`+3E5/IE,/6<A>,&:S;%5T=X-FA\",4)`>
MEQ6<T5AX6U"&%(NTG=);:&"-8/%E5VPB;Z-O&G!5?_!_D962E5"6TY=R4D2/
M_5$K5+A48U6*5;MJM6W8?6:"G))WEGF>"%3(5-)VY(:DE=257):B3@E/[EGF
M6O==4F"78FUG06B&;"]N.'^;@"J""/H)^@68I4Y54+-4DU=:66E;LUO(87=I
M=VTC</F'XXERBN>*@I#MF;B:OE(X:!90>%Y/9T>#3(BK3A%4KE;F<Q61_Y<)
MF5>9F9E35I]86X8QBK)A]FI[<]*.1VNJEE>:55D`<FN-:9?43_1<)E_X85MF
MZVRK<(1SN7/^<REW37=#?6)](WXW@E*("OKBC$F2;YA16W1Z0(@!F,Q:X$]4
M4SY9_5P^8WEM^7(%@0>!HH//DC"8J$Y$41%2BU=B7\)LSFX%<%!PKW"2<>ES
M:71*@Z*'88@(D**0HY.HF6Y15U_@8&=ALV99A4J.KY&+ETY.DDY\5-58^EA]
M6;5<)U\V8DAB"F9G9NMK:6W/;59N^&Z4;^!OZ6]=<-!R)71:=.!TDW9<><I\
M'G[A@*:":X2_A$Z&7X9TAW>+:HRLDP"899C18!9B=Y%:6@]F]VT^;C]T0IO]
M7]I@#WO$5!A?7FS3;"IMV'`%?7F&#(H[G193C%0%6SIJ:W!U=8UYOGFQ@N^#
M<8I!BZB,=)<+^O1D*V6Z>+MX:WHX3II54%FF6WM>HV#;8V%K9693:!EN97&P
M=`A]A)!IFB6<.VW1;CYS08S*E?!13%ZH7TU@]F`P84QA0V9$9J5IP6Q?;LEN
M8F],<9QTAW;!>R=\4H-7AU&0C9;#GB]3WE;[7HI?8F"48/=A9F8#9YQJ[FVN
M;W!P:G-J?KZ!-(/4AJB*Q(R#4G)SEEMK:@24[E2&5EU;2&6%9<EFGVB-;<9M
M.W*T@'6139JO3QE0FE,.5#Q4B57%53]>C%\]9V9QW7,%D-M2\U)D6,Y8!'&/
M<?MQL(43BHAFJ(6G581F2G$QA$E3F57!:UE?O5_N8XEF1W'QBAV/OIX13SID
MRW!F=6>&9&!.B_B=1U'V40A3-FWX@-&>%68C:YAPU74#5'E<!WT6BB!K/6M&
M:SA4<&`];=5_"(+64-Y1G%5K5LU6[%D)6PQ>F6&883%B7F;F9IEQN7&Z<:=R
MIWD`>K)_<(H``````````````````````*P!K`2L!ZP(K`FL"JP0K!&L$JP3
MK!2L%:P6K!>L&:P:K!NL'*P=K""L)*PLK"VL+ZPPK#&L.*PYK#RL0*Q+K$VL
M5*Q8K%RL<*QQK'2L=ZQXK'JL@*R!K(.LA*R%K(:LB:R*K(NLC*R0K)2LG*R=
MK)^LH*RAK*BLJ:RJK*RLKZRPK+BLN:R[K+RLO:S!K,2LR*S,K-6LUZS@K.&L
MY*SGK.BLZJSLK.^L\*SQK/.L]:SVK/RL_:P`K02M!JT,K0VM#ZT1K1BM'*T@
MK2FM+*TMK32M-:TXK3RM1*U%K4>M2:U0K52M6*UAK6.M;*UMK7"M<ZUTK76M
M=JU[K7RM?:U_K8&M@JV(K8FMC*V0K9RMG:VDK;>MP*W!K<2MR*W0K=&MTZW<
MK>"MY*WXK?FM_*W_K0"N`:X(K@FN"ZX-KA2N,*XQKC2N-ZXXKCJN0*Y!KD.N
M1:Y&KDJN3*Y-KDZN4*Y4KE:N7*Y=KE^N8*YAKF6N:*YIKFRN<*YXKGFN>ZY\
MKGVNA*Z%KHRNO*Z]KKZNP*[$KLRNS:[/KM"NT:[8KMFNW*[HKNNN[:[TKOBN
M_*X'KPBO#:\0KRRO+:\PKS*O-*\\KSVO/Z]!KT*O0Z](KTFO4*]<KUVO9*]E
MKWFO@*^$KXBOD*^1KY6OG*^XK[FOO*_`K\>OR*_)K\NOS:_.K]2OW*_HK^FO
M\*_QK_2O^*\`L`&P!+`,L!"P%+`<L!VP*+!$L$6P2+!*L$RP3K!3L%2P5;!7
ML%FP7;!\L'VP@+"$L(RPC;"/L)&PF+"9L)JPG+"?L*"PH;"BL*BPJ;"KL*RP
MK;"NL*^PL;"SL+2PM;"XL+RPQ+#%L,>PR+#)L-"PT;#4L-BPX+#EL`BQ";$+
ML0RQ$+$2L1.Q&+$9L1NQ'+$=L2.Q)+$EL2BQ++$TL36Q-[$XL3FQ0+%!L42Q
M2+%0L5&Q5+%5L5BQ7+%@L7BQ>;%\L8"Q@K&(L8FQB[&-L9*QD[&4L9BQG+&H
ML<RQT+'4L=RQW;'?L>BQZ;'LL?"Q^;'[L?VQ!+(%L@BR"[(,LA2R%;(7LAFR
M(+(TLCRR6+)<LF"R:+)ILG2R=;)\LH2RA;*)LI"RD;*4LIBRF;*:LJ"RH;*C
MLJ6RIK*JLJRRL+*TLLBRR;+,LM"RTK+8LMFRV[+=LN*RY++ELN:RZ++KLNRR
M[;+NLN^R\[+TLO6R][+XLOFR^K+[LO^R`+,!LP2S"+,0LQ&S$[,4LQ6S'+-4
MLU6S5K-8LUNS7+->LU^S9+-ELV>S:;-KLVZS<+-QLW2S>+.`LX&S@[.$LX6S
MC+.0LY2SH+.ALZBSK+/$L\6SR+/+L\RSSK/0L]2SU;/7L]FSV[/=L^"SY+/H
ML_RS$+08M!RT(+0HM"FT*[0TM%"T4;14M%BT8+1AM&.T9;1LM("TB+2=M*2T
MJ+2LM+6TM[2YM,"TQ+3(M-"TU;3<M-VTX+3CM.2TYK3LM.VT[[3QM/BT%+45
MM1BU&[4<M22U);4GM2BU*;4JM3"U,;4TM3BU0+5!M4.U1+5%M4NU3+5-M5"U
M5+5<M5VU7[5@M6&UH+6AM:2UJ+6JM:NUL+6QM;.UM+6UM;NUO+6]M<"UQ+7,
MM<VUS[70M=&UV+7LM1"V$;84MABV);8LMC2V2+9DMFBVG+:=MJ"VI+:KMJRV
ML;;4MO"V]+;XM@"W`;<%MRBW*;<LMR^W,+<XMSFW.[=$MTBW3+=4MU6W8+=D
MMVBW<+=QMW.W=;=\MWVW@+>$MXRWC;>/MY"WD;>2MY:WE[>8MYFWG+>@MZBW
MJ;>KMZRWK;>TM[6WN+?'M\FW[+?MM_"W]+?\M_VW_[<`N`&X![@(N`FX#+@0
MN!BX&;@;N!VX)+@EN"BX++@TN#6X-[@XN#FX0+A$N%&X4[A<N%VX8+ADN&RX
M;;AON'&X>+A\N(VXJ+BPN+2XN+C`N,&XP[C%N,RXT+C4N-VXW[CAN.BXZ;CL
MN/"X^+CYN/NX_;@$N1BY(+D\N3VY0+E$N4RY3[E1N5BY6;E<N6"Y:+EIN6NY
M;;ETN76Y>+E\N82YA;F'N8FYBKF-N8ZYK+FMN;"YM+F\N;VYO[G!N<BYR;G,
MN<ZYS[G0N=&YTKG8N=FYV[G=N=ZYX;GCN>2YY;GHN>RY]+GUN?>Y^+GYN?JY
M`+H!N@BZ%;HXNCFZ/+I`ND*Z2+I)NDNZ3;I.NE.Z5+I5NEBZ7+IDNF6Z9[IH
MNFFZ<+IQNG2Z>+J#NH2ZA;J'NHRZJ+JINJNZK+JPNK*ZN+JYNKNZO;K$NLBZ
MV+K9NORZ`+L$NPV[#[L1NQB['+L@NRF[*[LTNS6[-KLXNSN[/+L]NSZ[1+M%
MNT>[2;M-NT^[4+M4NUB[8;MCNVR[B+N,NY"[I+NHNZR[M+NWN\"[Q+O(N]"[
MT[OXN_F[_+O_NP"\`KP(O`F\"[P,O`V\#[P1O!2\%;P6O!>\&+P;O!R\';P>
MO!^\)+PEO">\*;PMO#"\,;PTO#B\0+Q!O$.\1+Q%O$F\3+Q-O%"\7;R$O(6\
MB+R+O(R\CKR4O)6\E[R9O)J\H+RAO*2\I[RHO+"\L;RSO+2\M;R\O+V\P+S$
MO,V\S[S0O-&\U;S8O-R\]+SUO/:\^+S\O`2]!;T'O0F]$+T4O22]++U`O4B]
M2;U,O5"]6+U9O62]:+V`O8&]A+V'O8B]B;V*O9"]D;V3O96]F;V:O9R]I+VP
MO;B]U+W5O=B]W+WIO?"]]+WXO0"^`[X%O@R^#;X0OA2^'+X=OA^^1+Y%ODB^
M3+Y.OE2^5;Y7OEF^6KY;OF"^8;YDOFB^:KYPOG&^<[YTOG6^>[Y\OGV^@+Z$
MOHR^C;Z/OI"^D;Z8OIF^J+[0OM&^U+[7OMB^X+[CON2^Y;[LO@&_"+\)OQB_
M&;\;OQR_';]`OT&_1+](OU"_4;]5OY2_L+_%O\R_S;_0O]2_W+_?O^&_/,!1
MP%C`7,!@P&C`:<"0P)'`E,"8P*#`H<"CP*7`K,"MP*_`L,"SP+3`M<"VP+S`
MO<"_P,#`P<#%P,C`R<#,P-#`V,#9P-O`W,#=P.3`Y<#HP.S`],#UP/?`^<``
MP03!",$0P17!',$=P1[!'\$@P2/!),$FP2?!+,$MP2_!,,$QP3;!.,$YP3S!
M0,%(P4G!2\%,P4W!5,%5P5C!7,%DP67!9\%HP6G!<,%TP7C!A<&,P8W!CL&0
MP93!EL&<P9W!G\&AP:7!J,&IP:S!L,&]P<3!R,',P=3!U\'8P>#!Y,'HP?#!
M\<'SP?S!_<$`P@3"#,(-P@_"$<(8PAG"',(?PB#"*,(IPBO"+<(OPC'",L(T
MPDC"4,)1PE3"6,)@PF7";,)MPG#"=,)\PGW"?\*!PHC"B<*0PIC"F\*=PJ3"
MI<*HPJS"K<*TPK7"M\*YPMS"W<+@PN/"Y,+KPNS"[<+OPO'"]L+XPOG"^\+\
MP@##",,)PPS##<,3PQ3#%<,8PQS#),,EPRC#*<-%PVC#:<-LPW##<L-XPWG#
M?,-]PX3#B,.,P\##V,/9P]S#W\/@P^+#Z,/IP^W#],/UP_C#",00Q"3$+,0P
MQ#3$/,0]Q$C$9,1EQ&C$;,1TQ'7$><2`Q)3$G,2XQ+S$Z<3PQ/'$],3XQ/K$
M_\0`Q0'%#,40Q13%',4HQ2G%+,4PQ3C%.<4[Q3W%1,5%Q4C%2<5*Q4S%3<5.
MQ5/%5,55Q5?%6,59Q5W%7L5@Q6'%9,5HQ7#%<<5SQ73%=<5\Q7W%@,6$Q8?%
MC,6-Q8_%D<65Q9?%F,6<Q:#%J<6TQ;7%N,6YQ;O%O,6]Q;[%Q,7%Q<;%Q\7(
MQ<G%RL7,Q<[%T,71Q=3%V,7@Q>'%X\7EQ>S%[<7NQ?#%],7VQ??%_,7]Q?[%
M_\4`Q@'&!<8&Q@?&",8,QA#&&,89QAO&',8DQB7&*,8LQBW&+L8PQC/&-,8U
MQC?&.<8[QD#&0<9$QDC&4,91QE/&5,95QES&7<9@QFS&;\9QQGC&><9\QH#&
MB,:)QHO&C<:4QI7&F,:<QJ3&I<:GQJG&L,:QQK3&N,:YQKK&P,;!QL/&Q<;,
MQLW&T,;4QMS&W<;@QN'&Z,;IQNS&\,;XQOG&_<8$QP7'",<,QQ3'%<<7QQG'
M(,<AQR3'*,<PQS'',\<UQS?'/,<]QT#'1,=*QTS'3<=/QU''4L=3QU3'5<=6
MQU?'6,=<QV#':,=KQW3'=<=XQWS'?<=^QX/'A,>%QX?'B,>)QXK'CL>0QY''
ME,>6QY?'F,>:QZ#'H<>CQZ3'I<>FQZS'K<>PQ[3'O,>]Q[_'P,?!Q\C'R<?,
MQ\['T,?8Q]W'Y,?HQ^S'`,@!R`3(",@*R!#($<@3R!7(%L@<R!W((,@DR"S(
M+<@OR#'(.,@\R$#(2,A)R$S(3<A4R'#(<<ATR'C(>LB`R('(@\B%R(;(A\B+
MR(S(C<B4R)W(G\BAR*C(O,B]R,3(R,C,R-3(U<C7R-G(X,CAR.3(]<C\R/W(
M`,D$R07)!LD,R0W)#\D1R1C)+,DTR5#)4<E4R5C)8,EAR6/);,EPR73)?,F(
MR8G)C,F0R9C)F<F;R9W)P,G!R<3)Q\G(R<K)T,G1R=/)U<G6R=G)VLG<R=W)
MX,GBR>3)Y\GLR>W)[\GPR?')^,GYR?S)`,H(R@G*"\H,R@W*%,H8RBG*3,I-
MRE#*5,I<REW*7\I@RF'*:,I]RH3*F,J\RKW*P,K$RLS*S<K/RM'*T\K8RMG*
MX,KLRO3*",L0RQ3+&,L@RR'+0<M(RTG+3,M0RUC+6<M=RV3+>,MYRYS+N,O4
MR^3+Y\OIRPS,#<P0S!3,',P=S"',(LPGS"C,*<PLS"[,,,PXS#G,.\P\S#W,
M/LQ$S$7,2,Q,S%3,5<Q7S%C,6<Q@S&3,9LQHS'#,=<R8S)G,G,R@S*C,J<RK
MS*S,K<RTS+7,N,R\S,3,Q<S'S,G,T,S4S.3,[,SPS`'-",T)S0S-$,T8S1G-
M&\T=S23-*,TLS3G-7,U@S63-;,UMS6_-<<UXS8C-E,V5S9C-G,VDS:7-I\VI
MS;#-Q,W,S=#-Z,WLS?#-^,WYS?O-_<T$S@C.#,X4SAG.(,XASB3.*,XPSC'.
M,\XUSEC.6<Y<SE_.8,YASFC.:<YKSFW.=,YUSGC.?,Z$SH7.A\Z)SI#.D<Z4
MSIC.H,ZASJ/.I,ZESJS.K<[!SN3.Y<[HSNO.[,[TSO7.]\[XSOG.`,\!SP3/
M",\0SQ'/$\\5SQS/(,\DSRS/+<\OSS#/,<\XSU3/5<]8SUS/9,]ESV?/:<]P
MSW'/=,]XSX#/A<^,SZ'/J,^PS\3/X,_AS^3/Z,_PS_'/\\_US_S/`-`$T!'0
M&-`MT#30-=`XT#S01-!%T$?02=!0T%306-!@T&S0;=!PT'30?-!]T('0I-"E
MT*C0K-"TT+70M]"YT,#0P=#$T,C0R=#0T-'0T]#4T-70W-#=T.#0Y-#LT.W0
M[]#PT/'0^-`-T3#1,=$TT3C1.M%`T4'10]%$T4713-%-T5#15-%<T5W17]%A
MT6C1;-%\T831B-&@T:'1I-&HT;#1L=&ST;71NM&\T<#1V-'TT?C1!]()TA#2
M+-(MTC#2--(\TCW2/])!TDC27-)DTH#2@=*$THC2D-*1TI72G-*@TJ32K-*Q
MTKC2N=*\TK_2P-+"TLC2R=++TM32V-+<TN32Y=+PTO'2]-+XT@#3`=,#TP73
M#-,-TP[3$-,4TQ;3'-,=TQ_3(-,ATR73*-,ITRS3,-,XTSG3.],\TSW31--%
MTWS3?=.`TX33C-.-TX_3D-.1TYC3F=.<TZ#3J-.ITZO3K=.TT[C3O-/$T\73
MR-/)T]#3V-/AT^/3[-/MT_#3]-/\T_W3_],!U`C4'=1`U$347-1@U&34;=1O
MU'C4>=1\U'_4@-2"U(C4B=2+U(W4E-2IU,S4T-34U-S4W]3HU.S4\-3XU/O4
M_=0$U0C5#-44U175%]4\U3W50-5$U4S53=5/U5'56-59U5S58-5EU6C5:=5K
MU6W5=-5UU7C5?-6$U875A]6(U8G5D-6EU<C5R=7,U=#5TM78U=G5V]7=U>35
MY=7HU>S5]-7UU??5^=4`U@'6!-8(UA#6$=83UA36%=8<UB#6)-8MUCC6.=8\
MUD#61=9(UDG62]9-UE'65-95UEC67-9GUFG6<-9QUG36@]:%UHS6C=:0UI36
MG=:?UJ'6J-:LUK#6N=:[UL36Q=;(ULS6T=;4UM?6V=;@UN36Z-;PUO76_-;]
MU@#7!-<1UQC7&=<<UR#7*-<IURO7+=<TUS77.-<\UT371]=)UU#74==4UU;7
M5]=8UUG78-=AUV/79==IUVS7<-=TUWS7?=>!UXC7B=>,UY#7F->9UYO7G=<`
M`````#`!,`(PMP`E("8@J``#,*T`%2`E(CS_/"(8(!D@'"`=(!0P%3`(,`DP
M"C`+,`PP#3`.,`\P$#`1,+$`UP#W`&`B9")E(AXB-"*P`#(@,R`#(2LAX/_A
M_^7_0B9`)B`BI2(2(P(B!R)A(E(BIP`[(`8F!2;+)<\ESB7')<8EH26@);,E
MLB6]);PEDB&0(9$ADR&4(1,P:B)K(AHB/2(=(C4B*R(L(@@B"R*&(H<B@B*#
M(BHB*2(G(B@BXO_2(=0A`"(#(K0`7O_'`M@"W0+:`MD"N`#;`J$`OP#0`BXB
M$2(/(J0`"2$P(,$EP"6W);8E9"9@)F$F929G)F,FF2+():,ET"71)9(EI"6E
M):@EIR6F):DE:"8/)@XF'"8>)K8`("`A()4AER&9(98AF"%M)FDF:B9L)G\R
M'#(6(<<S(B'",]@S(2&L(*X`_?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]_P'_`O\#_P3_!?\&_P?_"/\)_PK_"_\,_PW_
M#O\/_Q#_$?\2_Q/_%/\5_Q;_%_\8_QG_&O\;_QS_'?\>_Q__(/\A_R+_(_\D
M_R7_)O\G_RC_*?\J_RO_+/\M_R[_+_\P_S'_,O\S_S3_-?\V_S?_./\Y_SK_
M.__F_SW_/O\__T#_0?]"_T/_1/]%_T;_1_](_TG_2O]+_TS_3?]._T__4/]1
M_U+_4_]4_U7_5O]7_UC_6?]:_UO_7/]=_^/_,3$R,3,Q-#$U,38Q-S$X,3DQ
M.C$[,3PQ/3$^,3\Q0#%!,4(Q0S%$,44Q1C%',4@Q23%*,4LQ3#%-,4XQ3S%0
M,5$Q4C%3,50Q53%6,5<Q6#%9,5HQ6S%<,5TQ7C%?,6`Q83%B,6,Q9#%E,68Q
M9S%H,6DQ:C%K,6PQ;3%N,6\Q<#%Q,7(Q<S%T,74Q=C%W,7@Q>3%Z,7LQ?#%]
M,7XQ?S&`,8$Q@C&#,80QA3&&,8<QB#&),8HQBS&,,8TQCC%P(7$A<B%S(70A
M=2%V(7<A>"%Y(?W__?_]__W__?]@(6$A8B%C(60A92%F(6<A:"%I(?W__?_]
M__W__?_]__W_D0.2`Y,#E`.5`Y8#EP.8`YD#F@.;`YP#G0.>`Y\#H`.A`Z,#
MI`.E`Z8#IP.H`ZD#_?_]__W__?_]__W__?_]_[$#L@.S`[0#M0.V`[<#N`.Y
M`[H#NP.\`[T#O@._`\`#P0/#`\0#Q0/&`\<#R`/)`_W__?_]__W__?_]_P`E
M`B4,)1`E&"44)1PE+"4D)30E/"4!)0,E#R43)1LE%R4C)3,E*R4[)4LE("4O
M)2@E-R4_)1TE,"4E)3@E0B42)1$E&B49)18E%24.)0TE'B4?)2$E(B4F)2<E
M*24J)2TE+B4Q)3(E-24V)3DE.B4])3XE0"5!)4,E1"5%)48E1R5()4DE2B7]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W_E3.6,Y<S$R&8,\0SHS.D,Z4SIC.9,YHSFS.<,YTSGC.?,Z`SH3.B
M,\HSC3..,X\SSS.(,XDSR#.G,Z@SL#.Q,[(SLS.T,[4SMC.W,[@SN3.`,X$S
M@C.#,X0SNC.[,[PSO3.^,[\SD#.1,Y(SDS.4,R8AP#/!,XHSBS.,,]8SQ3.M
M,ZXSKS/;,ZDSJC.K,ZPSW3/0,],SPS/),]PSQC/]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_&`-``J@`F`?W_,@']_S\!00'8`%(!N@#>`&8!2@']
M_V`R83)B,F,R9#)E,F8R9S)H,FDR:C)K,FPR;3)N,F\R<#)Q,G(R<S)T,G4R
M=C)W,G@R>3)Z,GLRT"31)-(DTR34)-4DUB37)-@DV23:)-LDW"3=)-XDWR3@
M).$DXB3C).0DY23F).<DZ"3I)&`D821B)&,D9"1E)&8D9R1H)&DD:B1K)&PD
M;21N)+T`4R%4(;P`O@!;(5PA72%>(>8`$0'P`"<!,0$S`3@!0`%"`?@`4P'?
M`/X`9P%+`4D!`#(!,@(R`S($,@4R!C(',@@R"3(*,@LR##(-,@XR#S(0,A$R
M$C(3,A0R%3(6,A<R&#(9,AHR&S*<))TDGB2?)*`DH22B)*,DI"2E)*8DIR2H
M)*DDJB2K)*PDK22N)*\DL"2Q)+(DLR2T)+4D="1U)'8D=R1X)'DD>B1[)'PD
M?21^)'\D@"2!)((DN0"R`+,`="!_(($@@B"#((0@03!",$,P1#!%,$8P1S!(
M,$DP2C!+,$PP33!.,$\P4#!1,%(P4S!4,%4P5C!7,%@P63!:,%LP7#!=,%XP
M7S!@,&$P8C!C,&0P93!F,&<P:#!I,&HP:S!L,&TP;C!O,'`P<3!R,',P=#!U
M,'8P=S!X,'DP>C![,'PP?3!^,'\P@#"!,((P@S"$,(4PAC"',(@PB3"*,(LP
MC#"-,(XPCS"0,)$PDC"3,/W__?_]__W__?_]__W__?_]__W__?^A,*(PHS"D
M,*4PIC"G,*@PJ3"J,*LPK#"M,*XPKS"P,+$PLC"S,+0PM3"V,+<PN#"Y,+HP
MNS"\,+TPOC"_,,`PP3#",,,PQ##%,,8PQS#(,,DPRC#+,,PPS3#.,,\PT##1
M,-(PTS#4,-4PUC#7,-@PV3#:,-LPW##=,-XPWS#@,.$PXC#C,.0PY3#F,.<P
MZ##I,.HPZS#L,.TP[C#O,/`P\3#R,/,P]##U,/8P_?_]__W__?_]__W__?_]
M_Q`$$002!!,$%`05!`$$%@07!!@$&00:!!L$'`0=!!X$'P0@!"$$(@0C!"0$
M)00F!"<$*`0I!"H$*P0L!"T$+@0O!/W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]_S`$,00R!#,$-`0U!%$$-@0W!#@$.00Z!#L$/`0]!#X$/P1`!$$$
M0@1#!$0$101&!$<$2`1)!$H$2P1,!$T$3@1/!``````````````H*R8K.BLL
M*RHK,"LN*S0K,BLY*R4K)RLI*STK/BLM*S$K*RLO*S,K-2LV*S<K."L_*R(K
M.RL\*R0K(RLA*V4O(2\B+R,O)"\E+R8O)R\H+RDO*B\K+RPO3"]-+TXO3R]0
M+U$O4B]3+U0O52]6+U<O6"]9+UHO6R]<+UTO7B]?+V`O82]B+V,O9"\M+RXO
M+R\P+S$O,B\S+S0O-2\V+S<O."\Y+SHO.R\\+STO/B\_+T`O02]"+T,O1"]%
M+T8O1R](+TDO2B]++R%Z=BPC>GPO.'HB+"YZ+'HC+B0N+7HE+B,L+WHQ>C!Z
M)BX^>C)Z,WHV>B0L-7HT>C=Z>2PH+B<N)2QZ+"MZ*7HJ>BLN.7HJ+CQZ/7I;
M?C]Z>RQ`>D%Z0GI#>E,M1'HI+BAZ(2XA+$5Z1GI@>F%Z8GID>GTL8WI]+S@L
M7BTY+#HL.RQE>F9Z6WIG>FAZ:7I(>D=Z72TM+B\N+BY+>DIZ27I,>DUZ,"Y0
M>FDO47I/>DYZ4GI6>F@O4WI4>E5Z,2Q7>C(N,2XS+EEZ6'HT+EIZ)GLZ>B5Z
M7'I=>EYZ9BT_+#9[0"P^+D$L/RXY>S=[0"XX>SI[.WMG+4$N/'L]>SY[67X_
M>S-[,GMA+5]Z-2XT>SDN;GIO>G%Z<'IR>CHN<WIT>G5Z+GQV>GAZ=WIP+WIZ
M8RUD+7EZ/"Q[>GQZ?7HA>WYZ(GLC>V4M8BUJ>FMZ;'IM>B\L*GM;+2M[-"PV
M+C<N."XU>STN,GP\+CLN)7ME?%HM:'QF?&=\:7QJ?%HN+BQ'+&1\2"Q(?$=\
M27PU+$M\2GQ,?$U\;R].?$9\3WQ1?%!\42Y2+C8L4GPV?#=\:2UC?$XM)WM^
M+3E\.GQP+3M\/'P^?#U\32X_?'(M07Q`?'$M4WQ4?")Z8WM/+&5[2"YD>V9[
M9WMJ>VM[:'ML>TDN;WMI>W![;7MO+7%[>7YT>W9[>7MR>W=[2BYN>W5[<WMM
M+7A[(GQ\>R-\?GLA?'M[?7M2?5I\)'QZ>R5\)GPG?"E\2RXH?&XM*GPK?"Q\
M4"Q:+%4N,7Q2+#MZ4RYS+6HO:WQL?&]\;7Q;+E0M)RQN?'!\<GPI+'%\*"QU
M?'=\:R]Y?'1\=GQ5+7-\>'QZ?'Y\>WPA?7U\?'Q<+B)]5BTD?2HL5RTE?5TN
M)WTH?2-])GTK+%XN*GTI?2Q];"\M?2PL.'PK?2Y],'TO?5@M7RY@+BTL,7TR
M?5DM-7TT?3-]-GU7+EM\:BU<?&)\6"Y=?%Y\7WQ9+G0O42Q@?$8L;"UA?"A[
M*7LW+$1\17QS+U<L/2PM?$PN>GXO?#!\0BY'>TA[2BQ)>TM[3'M*>TU[4'M#
M+D0N3GM4>U5[3WM3>U)[1BY1>TLL5WM6>T4N67M8>T<N7'M:>UM[77M,+&![
M7GM?>TTL87M.+#1\-7Q7?74L)'IK+5!]=R]1?6M]:BYX+VQ];7UN?70M;"Y:
M?5M]5'U5?78M5GU*?5\L2WU,?4U]=2U.?4]]=7U`?3]]8RY"?4%]0WUD+D1]
M17UE+D9]9BY'?6<N2'UA+C=].'TY?6(N.GT[?4DL/'T]?3Y](BY8?6@N67UI
M+G!]<7UR?7-]='UO?6LN)7XF?FDL)WYZ+2A^*7XK?FXN+7XJ?BQ^+GYO+GLM
M<"Y[+W(N,RQL+%1^57Y"+%9^5WY#+'(O1"Q8?G$O=RXD?E-]-GYV+FHL4WYK
M+'9](WXS?'@L5"Y9+%5\5GQV+W4O+WYS+C=^.7XX?CM^/'XZ?D!^/WX^?CU^
M0GY!?G0N17Y#?D1^1GY'?C(L8"U?+4I^2'Y+?FXO27YU+DQ^;2]-?D]^3GY1
M?E)^)WI[?7Q]:"Q]?7@M6"Q^?2%^(GYY+21[,'Y<+#%^72PR?C-^-'Y>+#5^
M>B]/+E`N?"QQ?BY[27UW+')^<WYT?G5^=GYW?EQ^7GY=?G!^+"Y"?$XN0WQ5
M+%I^7WYX+F!^87YN+&TL8GYY+G`L;RQ\+5,L5"QN?EPM8WYD?F8O97YG?F9^
M:'YO?FE^:WXF+&I^4"UL?FU^?B]]?GY^(2TB+7XL(RTD+24M8"PF+7PN*"TI
M+2HM)RTK+2PM82QB+"TM+BU]+2Q[+7LO>S![,"PQ>V<O4'YX?GHN/BUQ+#\M
M0"U"+4$M8GMW?7A];2YW+7E]>GU7?%LL6'Q6+EE\0RU$+44M1BU'+4@M22U*
M+3XL2RU`>T%[0GM#>T1[:"U%>T4L1GM,+4TM>2]6+'(L+RTP+3$M,BTS+30M
M-2TV+7$N-RTX+3DM.BT[+3PM/2UC+%Q]77U>?5]]9"Q@?64L87UB?6-]9'UE
M?68L9RQF?6=]:'UI?6I]3RU1+29Z>RY2+7,L="Q[?GQ^0"MK`P``:P,``&L#
M``!K`P``:P.`````````````````````````````3@,``$X#``!.`Y!`40,1
M`%,#`2!5`UTB7`,G@&$#$`!B`P$`8P,"`&0#``!D`P``9`,``&0#``!D`P(`
M90,``&4#`!!F`P0`9P,`"&@#``!H`P(`:0,``&D#``!I`P``:0,&````````
M``````````````````````````````#U`@``]0(``/4"``#U`@``]0(``/4"
M``#U`@``]0(``/4"``#U`D(!^`(``/@"``#X`H"`^@(8!/T"0`#^`@`(_P(`
M`/\"`!```X$``@,((`0#"``%`P`$!@,!0`@#,``*`P``"@,```H#```*`P``
M"@,```H#```*`P`0"P,`@`P#@``-`P@)$`,``!`#```0`P``$`,`0!$#```1
M`P``$0,``!$#```1`P``$0,``!$#```1`P`!$@,``!(#```2`P0`$P,``!,#
M```3`P``$P,``!,#$``4`P``%`,!!1<#```7`P``%P,"01H#```:`P``&@,`
M`!H#``$;`P``&P,``!L#```;`P``&P,``!L#```;`P``&P,``!L#```;`P!(
M'0,D`B`#"``A`P``(0,`@"(#T0`F`P``)@,``"8#```F`P``)@,``"8#```F
M`P``)@,``"8#4``H`P!++`,,4#`#```P`P``,`,``#`#```P`P``,`,``#`#
M```P`P``,`,``#`#```P`P``,`,``#`#```P`P``,`,$`#$#"&(U`S`".`-`
M`#D#```Y`P``.0,``#D#```Y`P``.0,``#D#`0$[`R``/`-``#T#0``^`P``
M/@,``#X#```^`P``/@,``#X#```^`P``/@,``#X#```^`P``/@,``#X#```^
M`P``/@,``#X#```^`P``/@,``#X#```^`P``/@,1!$$#R"-'`P``1P,`@$@#
M`P!*`P0(3`,)``````!G`@``9P(``&<"``!G`@``9P(0`&@"``!H`@``:`(`
M`&@"``!H`@``:`(`0&D"$!AL`@``;`)``&T"$!!O`@`"<`(`!'$"`4!S`@``
M<P(``',"`"!T`@``=`(``'0"`"!U`@``=0("`'8"``!V`@``=@(!`'<"``9Y
M`@"`>@(``'H"``!Z`@``>@(``'H"`0![`@``>P(``'L"``![`@``>P(``'L"
M``![`@``>P(``'L"``![`A``?`(``'P"`$!]`@``?0(``'T"``)^`@"`?P(`
M`'\"!`&!`@``@0(``($"``"!`@``@0(``($"``"!`@``@0("`(("``""`@``
M@@(``(("0`&$`@``A`(`!(4"``"%`@``A0(``(4"``&&`@@`AP(``(<"@`"(
M`@`0B0(``(D"``")`@``B0(`0(H"`0"+`@@@C0(``(T"``"-`C``CP(`()`"
M``"0`@``D`(``)`"``*1`D``D@(``)("``"2`@(`DP(``),"`%"5`@``E0(`
M!)8"``*7`@`"F`(``)@""`"9`@$`F@(``)H"``":`@#`G`(``9T"``"=`D2`
MH`(``*`"``2A`H``H@(``*("``"B`@``H@(0`*,"``"C`@``HP(``*,"`0"D
M`@``I`(``*0"!`"E`@@!IP(``*<"``"G`@$`J`(``*@"``"H`@``J`(``*@"
M``"H`@``J`($`*D"``"I`@``J0((`*H"``"J`@``J@(``*H"``"J`@``J@(`
M`*H"``"J`B!`K`(``*P"``"L`@``K`(``*P"``&M`@``K0(``*T"`0"N`@``
MK@((`*\"``"O`@"`L`(``+`"!`"Q`@``L0(`"+("``"R`@`@LP(``+,"``"S
M`@0`M`(``+0"``"T`D``M0*``+8"`(2X`@``N`(!`;H"``"Z`@``N@(``+H"
M``"Z`@``N@)``+L"``"[`@``NP(@`+P"``"\`D``O0(!`+X"``"^`@``O@(`
M`+X"""#``A``P0(``,$"`@#"`@``P@(`!,,"``##`@``PP(``,,"`(#$`@``
MQ`(``,0"``#$`@``Q`(``,0"``#$`@``Q`(``,0"``#$`@``Q`(``,0"``#$
M`@``Q`(``,0"``#$`@``Q`(``,0"``#$`@``Q`(``,0"`!#%`@((QP*``,@"
M``#(`@`$R0(``,D"``+*`@!`RP(``,L"``#+`@``RP(``,L"`&'.`@``S@)`
M`,\"``#/`@``SP(``,\"``#/`@``SP(``,\"``#/`@``SP(``,\"`0#0`@``
MT`(``-`"AH#4`@`$U0(``-4"``#5`@``U0(``-4"``#5`@``U0(``-4"``#5
M`@``U0(``-4"0`#6`L(`V0)``-H"(`#;`@D0W@($`-\"``#?`@``WP(``-\"
M`"#@`@``X`(``.`"``#@`@``X`(``.`"``#@`@``X`(``.`"``#@`@``X`(`
M`.`"``#@`@``X`(!`.$"!`#B`@``X@(@`.,"``#C`@``XP(``.,"``3D`@``
MY`(``.0"``#D`@``Y`(``.0"``#D`@``Y`(``.0"``#D`@`!Y0(!`><"`"#H
M`@@!Z@(`!.L"$`#L`@"`[0(`$.X"`!7Q`@$`\@(``/("!`#S`@``\P(``/,"
M``#S`@``\P(``/,"``#S`@``\P)``/0"``#T`@``]`(``/0"``#T`@``]`(`
M`/0"``#T`@``]`(``/0"``#T`@``]`(``/0"``#T`@``]`(``/0"0```````
M``````````!D``"`90```&4`0`!F````9@`$`&<```!G````9P```&<`(`!H
M````:````&@`0`%J````:@```&H```!J````:@`("&P`(`!M``H`;P``2'$`
M``!Q````<0`""',```1T````=````'0`!`!U`!``=@```'8```!V```(=P!@
M`'D```!Y``!`>@`$`'L`$`!\````?````'P```!\``0`?0```'T`!@!_`!``
M@````(``@"""````@@```((``0"#````@P```(,```"#````@P```(,```"#
M````@P```(,`@("%````A0``08<```"'``@`B````(@```"(````B````(@`
M``"(```0B0`$`(H`(`"+````BP```(L```"+````BP```8P```",```:CP``
M()````21````D0"(`),```24```0E0```)4```"5````E0```)4```"5````
ME0```)4``0"6````E@``0)<`P`"9````F0```)D```"9````F0```)D```"9
M````F0```)D```"9````F0```)D```"9````F0`@`)H```":````F@```)H`
M``":````F@```)H``"";````FP!``)P``""=`(``G@``@)\`$0"A`$``H@``
M`*(`$`"C````HP```*,```"C````HP```*,```"C````HP```*,```"C``$`
MI````*0```"D````I``0`*4``!2G```@J````*@```"H````J````*@`@`"I
M````J0`!`JL```"K````JP```*L```"K```0K``!@*X`@`"O`"#$LP```+,`
M`D"U```0M@```+8```BW`"``N``(4KP```"\````O```,+X`;`'#``@DQ@``
M`,8``@#'`!`!R0`@`,H```#*````R@```,H```#*````R@```<L`0`#,``$`
MS0``$,X```#.``$`SP`(`-```"#1````T0```-$```#1````T0`(`-(```#2
M``!`TP``0-0``"#5````U0`$`-8```#6````U@```-8``$#7`"``V``($-H`
M$`#;`$!`W0``8-\```#?`!``X```!.$```3B````X@```.(```CC````XP``
M`.,`"`#D`$``Y0```.4```#E````Y0```.4`@!#G````YP```.<```#G````
MYP```.<`(`#H````Z```!.D``0#J````Z@``(.L```#K`!00[@```.X``$#O
M```!\````/``B`#R``@`\P"(`/4``H#W`#$0^P`"AO\```#_````_P``0``!
M``0!`0```0$```$!(``"`0P`!`$```0!```$`00"!@%```<!```'`0``!P$`
M"`@!@``)`0(!"P$```L!```+`0``"P$`!`P!```,`0``#`$```P!$``-`0`0
M#@$`"1`!```0`0``$`$``!`!@'`4`0``%`$$`!4!```5`0``%0$`@!8!@`$8
M`0``&`$``!@!```8`0"0&@$``!H!```:`0``&@$``!H!```:`0``&@&``!L!
M```;`0``&P$``!L!```;`0``&P$``!L!```;`0``&P$`0!P!`0`=`8``'@$(
M`B`!```@`0``(`$``"`!$``A`0``(0$``"$!```A`0@`(@$@`",!```C`0``
M(P$``",!```C`0``(P$``",!```C`0``(P$``",!```C`0``(P$``",!```C
M`6`$)@$``"8!`P`H`0``*`$(`"D!$``J`0``*@$``"H!"``K`0``*P$0`"P!
M```L`0``+`$`$"T!0``N`0`0+P$``"\!```O`0``+P$``"\!```O`0``+P$`
M@#`!`@`Q`0``,0$``#$!```Q`0!`,@$``#(!!``S`80`-0$``#4!```U`0``
M-0$``#4!@"`W`0``-P$``#<!```W`0``-P$``#<!```W`0`@.`$``#@!```X
M`0``.`$``#@!```X`0``.`$`$#D!``(Z`0``.@$`@#L!`"`\`00!/@$``#X!
M!``_`0``/P$``#\!``E!`8`"0P$``$,!``!#`0`@1`$``$0!`$!%`8002`$(
M`$D!`&A,`0``3`$``$P!``!,`0``3`$``$P!``!,`0``3`$``$P!"`%.`0``
M3@$`@$\!(`!0`0``4`&``%$!``A2`0``4@$`@E0!``!4`0``5`$``54!``!5
M`0!`5@$``%8!``!6`02`6`$``%@!``!8`0`(60$``%D!`)1<`0``7`$``%P!
M``!<`0$`70$"D&`!`@!A`0L`9`$`&6<!``EI`0``:0$*(&P!``AM`2``;@$!
M`&\!`()Q`02"=`$``'0!"`!U`4``=@$``'8!`%!X`2``>0$`%'L!(`!\`0!`
M?0$`"'X!`@!_`0``?P$``'\!``!_`0``?P%``(`!``"``0``@`%``($!``"!
M`3``@P$``(,!``"#`0``@P$``(,!``"#`0``@P$``(,!``&$`0``A`$0`(4!
M``"%`0``A0$``(4!(`"&`0@`AP$``(<!``"'`0`$B`$``(@!``"(`0``B`$`
M((D!(`"*`0#`C`$``(P!``",`8`@C@$``(X!D`"0`4`%DP$``90!(`"5`4@`
MEP$`$)@!``"8`0``F`$``)@!`@"9`0`#FP$0!9X!$`*@`2$(HP$R`*8!``"F
M`0``I@$``*8!!""H`1``J0$``*D!``"I`0``J0$``*D!``"I`0`(J@$``*H!
M``"J`0``J@$`,*P!@`"M`00`K@&"0+$!``2R`4$`M`$@`+4!"`*W`0`!N`&`
M#+L!``"[`0``NP$``+L!0`"\`8``O0$``+T!0("_`0``OP$@`,`!!`#!`1`(
MPP$@`,0!$!#&`0``Q@$``,8!`!#'`0``QP$`,,D!$`#*`0``R@$`$,L!``#+
M`0``RP$``,L!``3,`0``S`$`0<X!``#.`0``S@$``,X!`##0`0``T`$"!-(!
M`!#3`0`0U`$!0-8!``#6`0``U@$``-8!``#6`0``U@$``-8!``#6`0``U@$`
M`-8!`(S9`0``V0$``-D!`(#:`0``V@$`@-L!``#;`0``VP$&`-T!``3>`0@`
MWP&``.`!@`#A`0``X0$``>(!``#B`0`"XP$`(.0!!`#E`0``Y0%``.8!$`#G
M`0``YP$`!.@!``#H`0``Z`$``.@!``#H`0``Z`$P!NP!80#O`0(`\`$``/`!
M0`#Q`0A$]`%!)/@!@$#Z`2``^P$0B/X!A````A0``@(0``,"!``$`@(!!@)`
M`0@"`($*`@$$#`($``T"```-`@`!#@(```X"``@/`@@`$`(``!`"0@03`@``
M$P(``!,"`@`4`A"0%P(``!<"```7`@``%P($`!@"```8`@``&`(``!@"`0`9
M`@@`&@(0`1P"`"`=`@``'0(``!T"```=`@0`'@(``!X"0(`@`@``(`(`0"$"
M```A`@``(0(``"$"`"`B`D`4)0(`""8"``0G`@`(*`(`$"D"```I`@``*0(`
M`"D"```I`@``*0)`""L"```K`@`H+0(``"T"```M`@!`+@(``"X"`!@P`D``
M,0(``#$"!0`S`@``,P("`#0"``8V`@``-@(@`#<"```W`A``.`(``#@"0``Y
M`@``.0(`$#H"`@`[`@``.P((`#P"```\`@``/`(((#X"B$1"`@$`0P(``$,"
M!!!%`@``10(``48"$0!(`@`!20(``$D"``!)`@``20(`0$H"``!*`D``2P(`
M`$L"``!+`A``3`(`0$T"``!-`@``30(@0$\"``!/`@@`4`(`05("``!2`@(0
M5`(``%0"``!4`@``5`(``%0"``!4`@``5`(`1%8"`!!7`@``5P(`@%@"@`!9
M`@@`6@(``%H"``!:`@``6@(``%H"`(!;`@4`70((`E\"(`!@`@$`80(!`&("
M``!B`@$@9`(``&0"``!D`@``9`(``&0"0!!F`@``9@(``&8"``!F`@``9@(@
M`"`````@````(````"`````@````(````"`````@````(````"`````@````
M(````"``_P\L````+````"P````L````+````"P````L````+````"P``/\T
M`/__1``!`$4```!%````10```$4```!%````10```$4`__]5`/]_'P```!\`
M```?````'P"````````````````````````;````&P```!L````;``"`'```
M`!P````<````'````!P````<````'````!P````<````'````!P````<````
M'````!P````<````'````!P````<````'````!P``0`=````'0```!T````=
M``,``````````````````````!D````9````&0```!D````9````&0```!D`
M```9````&0```!D````9```0&@`"````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#<%``P6"@````H`"`@,```(#0````T`$"$0````$```"!$````1
M````$0```!$````1````$0```!$`5148````&````@]./V="3BIU+%GAGE*&
M'%.'48]1\%`+3R-/`T]A3WI/:T_K3_5/-%`B4/9/<E"V3JY1$%G::RQ2,E*T
M3YA2NU*\4LU2VE+W4L93QU-P5VQ7L5>?5YY7OE?,5PY8#%CU5PE8/%A#6$58
M1E@]6%-8B%B$6/A8K59`65-9;5DJ7*54'54V56]5356:5IQ6]U805QE7%UXA
M7BA>:EYT7'Q<J%R>7,-<TUSC7.=<_UP$70!=&ET,74Y=6EV%79-=DEW"7<E=
M4HBO7P99J&5!<D)RO%[+7NR5_Y4:B@>6$Y8;EJQ;IUM=7")?[EE\6I9:<UJ>
M6JU:VEKJ6AM;5EMRFH.:B9J-FHZ:E9JFFI5SF7.@<[%SI7.F<]9S\'/]<^-S
M)'0.=`=T]G/Z<S)T+W1$=$)T<71X=&)TAG2?=*!TF'2R=.B716>?9WMGR&?N
M9TMHH&@2:!]H:FB\:/MH;VBQ:,%HZV@3:=%H$6G3:.QH*VGH:+YI:6E`:6]I
M7VEB:35I66F\:<5IVFG<:0MJY6EF:I9JM&K=<O%<%',Z<Y5K9U_^@/MT`W5<
M96EE)F_X9?ME"68]9F)F7F9L9HUFBV91C5>-8W)W<K%C86)@8H-BY&+#8AQC
M)F.O8_YC(F029.UD$V<89UB!T8'/F-28UYB6:9APW'#Z<`QQ'''+<1]RW7"=
M949B%V#'8--@L&#98!1A/VQG;(1LFFQM;*ALQFRU;$EM.&T1;3IM*&U0;31M
M56UA;:)M96U;;61MM&V:;EQN<FZ@;H=NCF[);L-N-V_8;NIN5F]U;U]OM&^\
M;Q1P#7`,<#QP0WE'>4IY4'ER>9AYH'FD>?QW^W<B>"!X07A:>'5XMGCA>#-Y
M7XK[=AMW+'>&=ZMWK7=D=6]U@VE]?]UVYG;L=B%U_GE$>G]VGG8GGBZ>,)XT
MGDV>4IY3GE2>5IY9GF&>8IYEGF^>=)ZB=01V"'8==M%ZA7J.>J-ZN'J^>MYW
M,("+F(Z8F9BCF(.&!8=8A\^'XH<+B-2`37]*>TY[?WN3>^]["7SP>Q5\`WP@
M?#J"AHBJB,"(R(@FB7:)D7^#@KR"IX(3@_Z"`(-=@T6#1(,=@Z:#F8/^@QJ$
M_(,IA#F$J(3/A)^$PH3WA'"%LX6BA=B6N(7@A=I_KGZT?KQ^UGX*?T-;:HU%
M4FB,;HQMC!:.)HXGCE".F)"@D+V0R)##D-J0_Y`:D0R1()%"D;6/Y)"&C/&)
ML8N[B\>+ZHL)C!Z,`I?0:`9S@9^"G\:2D90`````````````````````````
M`+$?K`.P'W`?$P'I`!L!Z``K`>T`T`'L`$T!\P#2`?(`:P'Z`-0!^0#6`=@!
MV@'<`?P`Z@"Q`S\>1`%(`?D!1__]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W_OE.X3CY/'E#'4!B1F&S<;,-L76ZF;NMNI6]E8:1>&)9(6%.$
M]7P'7Y1B?61:<G15I%5`5H16'UW)<HR9WEG]65Y:NW[D?OE^F9K/<45B2F)\
M>9IS*W2(=*ITV'1G9[5JRG&C:X"/DH]?C3:;J'*CAU*!.&O0F)>(KXA5B0IW
MVI1:E6"5))Y`GE">79Y@G@Z'7'O9?^]_1'Y%CC:.8HY<CGB71ILKGT&?)G4F
M3JR+*8&14,U0N5+4B5=5QY26E)B4SY33E-24YI0SE1R5()4GE3V50Y5NE725
M@)R$G(J<DYR6G)><F)R9G+^<P)S!G-*<VYS@G..<<)=ZEZ&7KI>HEV299IEX
MF7F9>YE^F8*9@YF.F1";&)NB98">')&1GA*?\U*6;$1M&VYG;H)O[&^N8,A>
M^H]_5X95GH1@A`5<"UX171E=UEVS6:Y:E)J/99YP477_<1UI$6J_:`=FCF9S
M9B5L4G:+=^IVE9B`ARV(AWM0?*V.=97"99!3N'D53R%/.T^B3Z10DE`*4\-1
MJ%$@C8=7FE>55^M775A:6'%8E5@P7`Q?#5\.7W)<QURL7VA?7U\26F5:A%K$
M6I1SZG/N<S=T%714=)EG;&CX:/YIXG)G9E*-PXG-B2=D=V0=;#^!5&O6F'IP
M\7`@<5-AAVRM;8%NM6Z4;YMO/7E.>09X67B4>-QX`WD6>EYZX'7<>G9VDICR
M>S!\77R=G*Q\>(+1@^J$P'\>?R&.4XY4EPR?^Y3]__W_P#+!,L(RPS+$,L4R
MQC+',L@RR3+*,LLRX#/A,^(SXS/D,^4SYC/G,^@SZ3/J,^LS[#/M,^XS[S/P
M,_$S\C/S,_0S]3/V,_<S^#/Y,_HS^S/\,_TS_C-8,UDS6C-;,UPS73->,U\S
M8#-A,V(S8S-D,V4S9C-G,V@S:3-J,VLS;#-M,VXS;S-P,S<PJ)!>ED)8`U@^
M;"EMYVXTA<:$/&,%71!_['Z'<BYQ&((6@FQU\W4EFX")IGR%3G!5QI$`````
M`````````````````````&@A;"$G(6,A0"%!(20H(B@H*"8H.B@L*"HH,"@N
M*$(A-"@R*#DH(2@E*"<H*2@M*#$H(R@K*"\H,R@U*#8H-R@X*"8A)2$A)B(F
M(R8D)B4F)B8G)B@F*28J)BLF+"8M)BXF+R8P)C$F,B8S)C0F-28V)C<F."9!
M)D(F0R9$)D4F1B9')D@F229*)DLF3"9-)DXF3R90)E$F4B93)E0F5296)E<F
M6"8G)R$G(B<C)R0G)2<F)R@G*2<J)RLG+"<M)RXG+R<P)S$G,B<S)S0G-2<V
M)S<G."<Y)SHG.R<\)STG/B<_)T`G02=1)U(G4R=4)U4G5B=8)UDG6B=;)UPG
M72=>)U\G8"=A)V(G8R=D)V4G9B=G)V@G:2=J)VLG;"=M)VXG;R=P)W$G5R<J
M(2PA+B$O(3`A,2$M(6LA9"%E(7DA9B%M(7$B<B)S(G0B=2)V(G<B>")Y(GHB
M>R)\(GLA?"%Z(7TA2B%'(48A3"%8(5XA3R%.(40A12%)(4@A4B%3(6`A7R%#
M(4LA5R%6(54A62%4(5PA72%:(5LA42%-(5`A62):(ELB7")=(EXB7R)@(F$B
M8B)%(D8B1R)((DDB2B)+(DPB32).(D\B4")1(E(B4R)4(E4B5B)7(E@B,2(R
M(C,B-"(U(C8B-R(X(CDB.B([(CPB/2(^(C\B0")!(D(B0R)$(B0I)2DF*2<I
M*"DI*2HI*RDL*2TI+BDO*3`I,2DR*3,I-"DU*38I-RDX*3DI.BD[*3PI/2D^
M*3\I0"E!*4(I0RE$*44I1BE'*4@I22E**4LI3"E-*4XI3RE0*5$I4BE3*50I
M52E6*5<I6"E9*5HI6RE<*5TI7BE?*6`I82EB*6,I9"EE*68I9REH*6DI:BEK
M*6PI;2EN*6\I=B%U(7@A=R%T(7,A<"%R(7$A;R%N(6(A82$A(2(A(R$H(2DA
M-"$U(38A-R$X(3DA.B$[(3XA/R%^(3(A,R$\(3TA(20B)",D)"0E)"8D)R0H
M)"DD*B0K)"PD+20N)"\D,"0Q)#(D,R0T)#4D-B0W)#@D.20Z)#LD/"0])#XD
M/R1`)$$D0B1#)$0D121&)$<D2"1))$HD2R1,)$TD3B1/)%`D4212)%,D5"15
M)%8D5R18)%DD6B1;)%PD721>)%\D8"1A)&(D8R1D)&4D9B1G)&@D:21J)&LD
M;"1M)&XD;R1P)'$D<B1S)"$E(B4C)20E)24F)2<E*"4I)2HE*R4L)2TE+B4O
M)3`E,24R)3,E-"4U)38E-R4X)3DE.B4[)3PE/24^)3\E0"5!)4(E0R5$)44E
M1B5')4@E225*)4LE3"5-)4XE3R50)5$E4B53)50E5256)5<E6"59)5HE6R5<
M)5TE7B5?)6`E825B)6,E9"5E)68E9R5H)6DE:B5K)6PE;25N)6\E<"5Q)7(E
M<R5T)74E=B4D(44H1BA'*$@H22A**$LH3"A-*$XH3RA0*%$H4BA3*%0H52A6
M*%<H6"A9*%HH6RA<*%TH7BA?*&`H82AB*&,H9"AE*&8H9RAH*&DH92)F(F<B
M:")I(FHB:R)L(FTB;B([4B$V7T9R34E5?4A/24)/(E@[,FM3)%AS,RA74D<G
M6$!*<$=[,3525#0K-C]+*5@J-CU!3U$E22U8=C@^45QC4%9A-RXT64$\6&A-
M)#4J3G=6=D!9/B]82T1#/C%8-$-E4BY66DXG574Z)C=60#E&4D5'1U0Y2S-2
M4C]813YR1C)2,$]G3VE*0%AR0E)":4@L1TM!:%-Y54)*?C8A6%I3=S]&5"4[
M05AE3BX^*%A'42E0/5AO679-.C\[/24Z8%)Z,F`Z-D1M3RD^)$U!05='<5ET
M64M(:5A:4C)*2DAL6&I81EAV/4U&<#-K6'$]:3U42%,T6$)6,E!72TI[2TQ5
M-CA)3UI9<%@J1VY8>C1N0512;5A'4F]81T-V45E6<EAU6'X\6SQ.2%TW0C=S
M1GA805)I3C\\?#<E-UU06E9%4V\[83MQ6"%),$XK-'-82TEV6%="=U@Q3GE8
M+C)`.2-9:3!F06Q)14M&2R19:#4K-3M.334A5W174U-E3$XZ(EE<66!3?5AP
M-W=7?EAZ6"%98T0V4W1875E[6&5%4$!P45LP43PF6259+%DN62M9.4HI6396
M7C,H67U`3$HJ62=9,%DQ-BDY0%)`3T)"1#UL56`R2$=K/RU9+UEJ3FXZ5D=C
M,5DT;38T62$_7EE.1WY`.%E72WTW-5DW62,Q85,Y6450-EDQ63)9*4$S67,\
M7E`I.&,^/5DZ63,P0EE$638Q/UDY-7,^2$QR.E!20UEH/2LS15EK/D99.UE?
M1#Y905E`62Y5-59C1TA963Q*63Q92UDK1DE9=E<C32$]3%D\135-35E'624S
M?C\U.'Q`>#!V-$Y93UDB-%!97S1!,%%9-4EQ3U)914%662Y)55E465=96TLI
M/2=&4UE865E994A<0'DV(UA*5"I45E!D,U=52$]B.4L_8D-2-D--;EEP63,U
M-38D/FM(*TA+,"LY>4%B63Q`,CE8.4M0>#%D1E\^9#5(5WA19CQ>2CT\9EEG
M6%I$5#@]2&$R650P0V%#(EI?2#10?#XI15HY(UHI5"1:>UDL-FLW>3%\664S
M=CYV/S%29$`S-GY9?5D[/F!&/%<A6CE!<C5H074\531=07U$.#PR-V\W;%D^
M1BT_2SM*-4E;5U`Y33PP=C-W.TI;+SID5#8U<S566%!(5C=01U=8+S\[6UA8
M3%`N.SYK4$%U07)453@T-'4S/DE015E%>T!P,5E83CD]-5I81E8B2R](,DE,
M-$P_=#E;6%Q89S9!/&I,=T]=6#!'4#DC/5Y,2D9@6%Y87UA^,&<^(TIT/#$X
M;CAB6$L]9%AC6'Q%95AF6"9!,$AL,"8Y4SQQ3CU;4T$O-GI6+$59/3Y;/UMX
M0"(^34!`6T9**C)"4V-#*U%"6U5`0ULQ/SQ$6D=$6VA95TDT.7!.2%1\,%(T
M65!I64M>:UDP6"\[,3%7,TY8450S/6\_.T]06$LW45@E1GA'/5)26&1$+DHG
M1R98?4EG3EP[:S`J.RU0,#%D5S]7)35T0D]$*3(W,F4Q,E\\52@_+$)56#%"
M5%A43F!:0$XT6"Y#(5,C3C0\-$A10FT^-E!A6F1')S-R-GQ,>D!W0#E185%'
M6%XR94!Q.DA8+51A3TE82EA#3W@S1SY+6$Q;)4A83WY(3C)64V8R,#Q14RM+
M-#<B-V5*(4A<2F0Q<%!1145;?C5:/T4Y9#YM039?-5\[5E`]655(,",V23\H
M3#-?-TI24T]8-E)%.CY+/DPW7W`U-%]U4U0S=S@Z7T\Z*CQU-2Q->T-S.G1`
M0DUR3SA?14]`0CE?<$)]/E]!3$UW4DTW05]$7W$W23!6-E0W+#I]3%0_,4MT
M1BA615]B3C,S?$XU-$=.<#IA3CU10%]T-$HS9C@[7T5$/%\]7SY?.T4_7T)?
M,51#7SI'6$Y81$I?3U]<5DE?6E\V3D<Z3E](7UY%:TET.GQ#5SY&7TU?6$4F
M54TZ3#X]4T`X9%9'7SXY)S]\04M?3%]07UM?95]77U9?25=C7V1?:V4G4E)?
M*3];5$@_5%],3UU?2E%>7R<P-T937V4Z7S9;37XY551?7VQ/)3!G7U%?1E%5
M7UA?65]<7RD[8%]A7V)?9E]H7S139S@V16I?6DDH041$7C]X3UQ5;E\X,E\Z
M;%]!6V11=$L]-"8P<5]&3')?;5]I7VM?;U]P7ST[<U]T7R,[6THH3B=@*C,F
M8"%@?E]937Q?>E]0/T173$EX7R$P?5][7R)@*&!(-R%&-DDR0'5?/D5$6'E?
M=D0C8"1@)6`E4#1@9$PQ8"8_+V`Y3BM@1DDN0"Y@;3HP.BE@=E\S8#A@+30Y
M8#)/2#HP8'I0+&![5'=?9T4M8'=3-F`W8$1@85`\8$E@2F`^8"I@)$E!8#)@
M2$I#8#5@2TY#2TU@1F!"8$M@.F`_8$!@16!'8$A@3&`[8%1+56!68%)@4&!.
M/%%@0CA%6&I0;T)/8#U@5&!38%=@7&!88'96,#-L5SM+6F![3EDZ86!=8"U2
M8F!;8%E@7V!@8%Y@9&!W1BQ8:U1F8$E*96!!.&=@:&!I8&-@/SIG3&I@>4]K
M8$)(0#U21&Q@;6!T1T1+;F!8.S98<E)O8$5-6C9Q8#!4)T!1-"=.<&!R8$PY
M>CD\37-@5$9T8#)4)DAV8'5@=V!!325*6E176UE;6%MG.5Q;75M8-5I;6ULA
M,U];>#LW5F!;>3X[-U!;+DPR/S4[>%=3/VD_83PS3%Y;4S!K3E@W.5="1B1`
M.4QG6V%;.D9C6VA;=T5J6VE;0#]F6V5;.30L0")"8EMD6TU0;5M=0');8C9S
M6U);.#DK5&Q;43]P6U%;9C5K6V4_;EMQ6WE;(3DC,'%"1S-O6WA;4D9T6W5;
M=UMV6WY;<E,Z,GU;)%Q[6WI;?%M@17D[(UPE7$-,439`72%<(EPU1VDV)UPF
M7"E<)#%,-3`_7U%"-BA<>DMS:UQ+?DM!3'M(*EQN3"M<4ULO7"Q<,SY[2BU<
M2DDY1#U'+EQV5&90*T15-E1;6C%56U9;/CI`2#]*24@S5WE)1S]X.CQ2.F(F
M-#@Q-#A$3V=9)D]B36U98#8Y4CLY.6(W8G,T;$PK3'(W,EAK43LZ)THW3412
M9#]0/&$V15Y&7CQ;65%F1DY$;C=<-WP_8%=U1CPQ2%XQ/5=,2EY)7FPU74E"
M,"Y%*T5,1&D\?4M#.GEE9TAZ97U-,5<^.&A"44A[94HV2SQ]42%F;D,D9GYE
M)69734$W?&5]92-F740H9B=F0T->1BIF-T0B9CQ*8SU#.29F55`O3BEF,&8F
M4BH]+68O9E%`3%(G/#%F=E)+5WY-7DTF0BMF+&8_/2YF,V8R9C9F.&9O1$A$
M:CYO23=F<#9D0VE3-&8U9B)(/68Y9D5&<4T[9CQF:3L^9CIF-T`D4S]F=$E#
M9D1F=E`]0T1#0F9!9D=F,4]T:TIF169>/"E)-3Q33TAF269.9E!F469+9E4U
M3&9/9EM$1F9-9E)F5&939E5F>%E69E=F4U==9EYF5S]05%979C1O2UIF0UA.
M5R)03T-?9CX\0CE;9B=1(CI/0BM8:TIN95QF=3=F2'5$,F5^1'Q+,V4L56Y3
M6$HR,$Y+:DUJ.C5E-&5:5UDY9E8H-G!-2U(F,35*:#-S24T_>U!22C9E0CM<
M3RPY5U0F.F=1?$]2/#=E74AM/W8Q7DM%/$0\>E)<0UP_.SA"0RXZ(E1>1R]$
M;#)1.3ME2$$O53QE/F5G-%0V0DLP43PU64IB-V1)*ST^3G!7(5!927LV6&9B
M/#XS4$E99B(S3%Y(4TU>(E).7DT^3UXL2GQ27S-J96%$(3XR3G)$5CXH1F,R
M4SY\1VM,;#U=3CI*049L93Q0.55M971*0$U%0F]E1$)P97AE34T]25E2*&%L
M4VI+<48L82=A*6$J82]A;3(K85HX+6$N83!A.C4Q83-A.&%2439A-6%K03=A
M0%0R83IA-C`T87D_.6$[83YA/&%%5C]//6$_84U":S9X4TU'93=^/D!A06%'
M86<S:49>-$)12&%&845A0V%"84`Q.%5$84MA3&%*87IO4V%2839'26%.85!A
M5&%184UA3V%5859A5V%885IA6V$A3EUG*#1=5C)1,C,D.7-724=>/BXY5TYN
M,D];.CQ14DA+33!O3V-9;3U2,5!*/#(G2RLW)DHC3WA@2E5[8'I@045[3#%!
M>6!C5B\R1%9;-7@T(58O3V\P?&`A82,S?6!^8#%#74,B87DW3SLC83M$)&$E
M829A,31).#U&:D0B,E)06V=#.U=31%-C.4]B+U=L1U,Q,C118G)0+D)08F(_
M)E-7-5)B:C5M0WTX+CA314\W5&)38D@V>5<E35AB5F)\2C4_.5-58E=B+D%(
M0%MB6F(J0$Y!7&)=8EYB2%M342)-*#U#7B58*C]-6VQ2>D8J141>5S$N7SU*
M,5\M.7U2)3AK.EHS7#5%559#4D\A.W-E<F5T961-=4@O-3]'=F4P;&9E:3DQ
M-3Q":&5G96EE35)J84Y0+DUE44HR:S%R,6U%0U4P4UQA76%;4CDS2S%Y37=5
M7F$V/GTT7V%<.F!A,CM)0F%A;%`]36)A0S5'16-A9&%Y4V5A+5%F82).9V%"
M-6AA53M$4&!B6#%D4F%B23Q,2&-B?FQ];"]?8F(^5GQ-)D-#8U)69V)H8D=3
M;&)L/VUB96)`,VY$;F)#4'8Z:6)>-S,[+$Q+2V1B9F)J8FMB=V)T8G54<V(M
M17I50D5`,F]B<F(O03Q+(35Y8C$\<6)44#E4=6)6.79B4T=P8EQ7(6UX8B5M
M?F)12C5!4#M6/V,Z(4LF;2-M(FU6.R=M=%`D;5XZ=S8A8S(V<4PG.2)/(4=2
M/W$V>F)[8GUB?&)51")C05,G8T1')$\I8S<Z*&-:.R-C)&,J8R9C<DY&4SP[
M0U1Z1"AM?%`E8W5#+6,O,3)C0CPL8S\U:4<P8RH^;TUS.VA,+V,Q8R=/+F,I
M3ET[:S5E/E(R33,Y,2MC43(L-5\Y:#9K3S=C3#M'2$I0.&-N,REM>E-D4RIM
M.6-B4C5C7E-0.#-C-F-?-S1C(D`Z8SA42#0[8T4[=TEE23U$*VU]0EL[+C\_
M3CQC-C]O,7=4/F,M;3]C*3HL;3UC0&,V.BXV.%!#,"YM+VU!0$%C,T5"8S)<
M,&UJ.&Q.)VIG4'E*5D@W3TDS4DYD/5YC<CLH:CU5748I:BIJ+&HK:BYJ+6I8
M/2]J/D)!-'<T)SMF;&5L/S=Y2V(Q9VQ(26AL:6Q62E!>13)Z5$M&1S!R-%-(
M4$TX/UL_)$<T5BE`45XH26]1)$5G,#8S14AB,'8W>D5S-E)54#,\/"TS<3Y1
M,%928THE5S9--C8Y/UM5)SA715)>63]50D!')#LH,6I%>T4G3"<Q5C4H1%->
M.E%I,W)#=S=T5B,U<#(T1&E$+4!47F@P1$5@054Y7#Y834XP3TU67E`^/E=5
M7E!573!B1"-"<#PU4SE`(44F,G%4*$!#2E=>?%4P.2U(*4M97CT_-$8G5S!*
M0T16,U(Y.%9\:C0P9C]T3%I-/U9.0DY.(DPN4%-$,C587G55-SQ3.R0P,D5L
M-'%5?6I:7B9-;$UF3EQ>,4TF0#U76UY&,#0Z4TES1&@^-C),0'!+<3P[.S<U
M=45F7F->73Y?7C<T73U@7FU$1D]@-5XV6DIT-65>1E5A7DU,?D9%1312<CY3
M0CU,.#-3/5@_1DU:46LT9%Y=7F=>?FHP0F)>0%8G-70R:%YR7FU><5Y@2&%7
M;UYH0V%,93(^4FY>:UY53B<T*S\^/E(]:5XN5%Y>:EX_0&Q><S)I."="03UU
M7GA>*S(D-&HT)DEV7E%+8SAW7GI>>5Y"3&$P;C0Z92]0:S(A:W1>8TES7EHP
M(5)W,2],<%XD2RI5>UY=-"9$?5Y^0R%$(5],07Q>;SXR1D4S=D@Z2WY>)%\R
M5S<S0T%+1R4R:30K5VQ$(E\C7R5?,SHF7UY`0TE9,F9')U]<1RA?(FM32RI?
M*5]!,DI%*U]<5$%(+%]P/BU?)U8W:C9K54I\6$0X)3E%-WY52CDG4$UT4#5T
M0T@^-VL],$P],D%6,2@S4C@B25@V.&LT/GU*0T=[57,W1$XK57,Q,VQ?,#5L
M-S9/07IU,5!E55-.;SUB,RLX-E4];4\V.4M"4#TW-FPI2E1%.6PX;$-"-VQ]
M4#IL.VQE5SQL/6QL1EY.2#Q52"DU23X\5F=4+E%Q4#AJ.6HZ:C4Z,4IU/WI-
M0&HZ,#YJ)4`[:GTR=T-H.U=2=$X_:CQJ0VI'4#-3.C1!0W)7455'2D5J1&I'
M:D9J9U943TMJ3CMZ/4Y)3&HY27Y/2FI.5$UJ3VIM34EJ3FIN3EX[/S-51C`^
M>DYG1R<^4&I'5D!!7511:CY/4FIN2B]%-3!4:E-J7W0Z1"DQ7V55:F]*5FI7
M:EA&6&I9:CM4>D<W4GPX0FI<,GQ">%1F3&Y70E104T-K<T5^-U1K-TM>:TI`
M>TTO,UI&?&L^1#1.*40^,7U4=4IL5E-&9#9Z.V!0,4E35"A(2S@^:#Q).VAN
M0%-01#)E-#QH2%5%-CUH>$I<.'5,-$!N43]H0F@\.BTQ7#T]:D-H1FA+:$QH
M24ME,"L\.3E!:'=-2FAV3FU55D%$:#9#>SDF5DAH8$IF5$!H16A':#E'8S=)
M:%T_4FA7:%5H7#Q//%MH7FA::'HQ6#`S1$PX8D8^2&%(3VA4:%9H<3E8:'57
M>T1<:&DR46AM/$(_36AY5GA!<3)?:$%*66@D56HQ.U5.:%!H,#93:%UH.$!W
M2BA+7$9U0&EH(U!R:&I68&AA:'E12SIY.'$X5%1O:&YH;&AP.5),9F@F3G(_
M.#!Q:'!H0%=D:"E-(TDX.UL]:FAB:&-H96@U-6=H14=K:&UH,#TN5WAH=6@P
M379H.D%H:#=#<#!T:'=H(SE224Y#8$YF0'-+74PU4&%*<VAL/'EH7D-E1G<Y
M=#!85RP\;T5$3"9I+4DB:6)`0S]^:%<Y>V@D:4Y2(VDR5C57)VDW/7QH?6@A
M:59-+%(R:2EI*C0[-"MI*%`E:7XS+&EC0"II.6DX:2YI>F@H:2P_,6DZ:25"
M+VE%."UI7%,T:35I-VE':49`16DP:3MI<3`\:255/FD_:4%I<4$V2#UI0FE#
M:3-I-FDQ.T!I=SQ$:49I2FE.:5LR2&DN-TMI3&E!52-$6&EA.DEI(U-4:5=I
M4&E/:4%'4FE9:4@S4VEP3TUI=S-6:5II-$PM3U5I7&E;:5YI46E=:5]I2D,W
M1TXT-CM`4"-L-T5[4R1L)6Q;1FX_)FPG;"I0.$=H."AL.59]54LT/3)D3F=&
M84UU-$!+7SQB:6-I:E%E:7DT9&DS46)*4#)H:69I9VDS5FEI:FEK:6QI+VPY
M14XV<U)N-5D[,6QC4F-..$0_0SXV.5A(,4\Q43%^15`Q*T,Q521K03HZ3"5K
M)VLH:R9K*6LK:RIK+&M/2C58<4,E0WA&+6M*1"YK+VLP:U4W>C<Q:V)',VLD
M.G51,3`R:S1K*C5(0FA'-6LN2U]C0%-;62%-+59S1V!98SLZ.F)C*T]@8T=)
M.3HT46%C:D@O.2T]6#-;3D!,:&-I8W1-+4PS/&IC:V-:4'M&6C=?1TI25DYD
M8VQC<DE!,V=C8T9E8S-M9F,S269%-3D[0V-C/44D05E"5S)M8R8[+41P8UH^
M>V-U8U,Z4#=-4TY64U5!.3156%$Y4'9'*D@T,EI#;F-\8V]C*#=W8W1C.C<B
M179C744H,GQ&8$0B5V%`>6-Z8WUC*4QS8SY30S$T;7%C<F-X8SI00T9S5'YC
M8#TG9"9D<U$C9"ED=T@T3RAD+F1E0C0V<CTB9&DZ*F0L9'TV7E8R9"UD(61N
M.UU-(D=)17=!)&0S1RP]/3TE9$=78C(K9$,\+V1K.S!D*$4Q9&-5(S\Z9#=D
M.V0]9%9&1CI+0"$X-&0A5",Z?CT\9#]->41[3V9)/U-13S-D.&0Y9&E,3DQ4
M0#5D,$$V9%!.03M3-7-()SU'52Q)(CA*9$QD1%$Z4BTZ5#I#9&TU35=`9'U/
M/V1<04I,9TI71%1,2&1'9$%D1&0M-5E31F1Y4F,T-#MN23XT;#M-46U,-6UE
M1RA42V155T)D)3U%9&93261X23YD95-^1TDV?%0S,E=D0DY-9#Q.6SA69$H_
M3E-L0TA%6&1$34]D5&159'XZ9D\_55)D4&1.9&5-*DHC0"8]4V1(.&=D-%1;
M9&]!:61G4E]D8&0J3UU+6F119&5D7$AC9&=$8F1A9'PS:&1A-4Q79F0L.U)7
M3TQX:V1D=CE-5EED7&1Z0EYD2T)$0%!"=3$R3$XU;V0O1F%&=60I0FQ`75%N
M9"Y$;61V9'1D?D)=9'!D?DI$57%D>E%K9&QD<F0K3DM%,4<Z0FID2D$V3#$S
M>V1S9'ID?61\9$XS.C-W9'ED>&1L13U`:%0B940P)&4C920\)64A97YD=#$H
M92EE)F4G92IE648K92UE+&4O92YE8#DP93%E<#MA;'!#1C52.VE!;E1$/D97
M5E13,CYL06HO0C8T5U$T,S)(.S]`;$M6/VQ!;$5L9CX_3%I%/#Y&;'XQ1&PH
M56,U0FPV06,S0VPX2T-`?DQ204AL9CI30')63%$^/S,W54E';&([3$Q]/4A(
M*4]I36M%:3=)43@Z26Q*;$`[2VQB;#HQ63<Y/4QL9E%-;#M(46Q3;$T[93Q/
M;#=).D-C;%554&QS5E)L3FQ4;%5L/TDH3UQ0+%%;2%9L=4YL2EIL66P^,%=L
M6&QD;#Q(1T%<;&!16VQO5%UL1EM>;"PQ7VQ@;"970$4\:RXP=#XX."]25C!Y
M-3-8+$M=8RQ&9C!&13EK.FL[:T!1(T5R:C)$-41.0'-J041O3G!J=&I\22-'
M6$Q^3G5J=FHL3V=`=VH_-GAJ>6IZ:GMJ<6HN2&MA.#=L86UA-%=N86]A3%-Q
M87$_<&%2-3<Q<V%R87PZ=&$W.5$^?$1=.D8]=6%W84`V04\H2G9A>%5\4WAA
M?&%Y87IA:D!^82%B1T![87UA)6)402-B*&)^,B)B34-",B=B)F(D8BEB*V))
M4&U6*$,L8E=/+F)O.F!I+6(J8BL[,U0P8B]B86DQ8C)B,V(A3#1B-6)^4$I"
M<5-U36!G86=!/FI"9&=C9V9--4-B9S<[5D]A06EG:&=T9R,R:F=F9VQG:V<Z
M261596<I-V=G;F=S9VE6;6=R9W%G8#!U9W)'14!M0'!!<&=V9W9+(F@A:$%7
M>F=Y9WMG=V=^9WUG?&=505E'?45#16U'(V@F:"5H)VAW.GAG)&AP2"I)*6AE
M.7Y1*&@J:"UH+F@G02]H,&@L:#1H*V@Q:#5H,F@S:#=H-FA/.2QP+7`P1FHP
M/TA?34U.,6HR:C]&230S:F=5>5TT:C5J-FI*.#!?=4EP3'I)>TE#4R9+)C@N
M<$(Q.&5O3$E35SQJ26<U4$1I-2YN+3M>9R]N*3,R;C%N9STP;C=.3T5T04Y;
M,VYS4%1":$8L-S1N:S-[.S5N7&<V;BX]8G%H2DE26G!;<%QP1D%M.$X^7G`Q
M15UP<5%@<$PP:CU?4E]P+S1H-V9P97`C1F%P8G!#-&-P;E5;3%(^,CQH<&=P
M9'`A,B)6.%,W/BQ(:G!W44Q66SII<#LV-$TF1B%!:W!N<&UP<'!L<#X[;W`U
M3')P53-4,7-P='!V<&$T<7!W<'IP>'!U<'UP>7!\<'YP(7%!3B1Q(W%V07MP
M74IQ-'$Q,4PF<2=Q+'%.52EQ,T@B<2MQ*'$E<2IQ*3`M<2]Q,7$P<2YQ(E$R
M<3-Q;SE'-5<P63!M5$0U5#U*.R=P7C@H<"@P*7!N32IP*W`D1F569'%E<7-#
M6U-15FA%+U-F4D%N.S`U54Y18#Q0.G@_1SA!-4Q%(DI+0T)N/T0B-FQM)$,Q
M5F!/;VU.15PV(4IM;7!M<6T\0S0_;FUT;7)M9E5?0W-M=FTC52-1=6U00W=M
M=#]L/GAM=TQ;4457=E5\;7MM>6UZ;7UM)CXO2R%N/38B;D!$?FU>/4<R0S8E
M;CI8(VXF;FE#<C,G;B1N.4\H;G="*6XJ;BM>,T9&1W56234R2RMN*TTL;C!5
M+6Y$=D=;(S0L0V9Q.$I34BI6<F]8/D,]<V],-BLP+THV;3=M>4XO-W,_.&UK
M0C!).6UV1C,_/&UX15!1*5<Z;3MM8E$_;4!M1&U(;49M3FUH54EM1VT^;6E%
M1D9I25)406U";4-M16UY0"$T:#E0;5%M2FU/;7A.-DM,;4UM=4]2;7)!,E-+
M;3=(;SQP159M;S4U0BTP:4LN,51M:TUB-55M4VU7;7HU6&U9;5QM3#%V16X\
M6FT\3&HR6VUK1$4T=3!?;5I`:#1-15UM1#]>;25$8&UA;6-M5T%'.S@]8FUD
M;69M96UG;3Y*:FQQ0&=):VQN1FQL;49M;'!L9E=S;'%L;FQO;"-7<4EN2W1L
M<FQI3W9L,49`/'5L.S5V.W=L=UE[/3M">&QY;",X>FQ[;'QL;5,N6&M`74=,
M.F-0/4LZ35$X?#%O1U961C]K0W5O6$-B5W=O4S-81VU12%9X;W9O?3M&,U4]
M1E)@.R%/?&][;WEO3#-423!+?F]>,$E6?6]M,U5V2$XB<"%P/C5:/'P[93A"
M1"-P:TLF<"A1/SYN1S9Q-W%5/RDT.'$[351'+54Y<3IQ3T<D4D]6.W%1/3`T
M/3Y<-%%.7S\]<7H_/'$_<3YQ0'%!<7Y!(D%Z2CY5.CXY/D)5(C\O335Q7SU+
M-G%60W-$<TTX1G-'<THP17-)<W%+2W,F4$HQ2'-/<U$U5W-2<U1S4W-[-S\Q
M3G-*<UHU4'-1<U5S37-C/'U!5G-:<TQS2#5N/5QS)#=P/WY6,DUP-%\R6'-9
M<SA)77-><V%S7W-C<V)S6W-J/V\S8',I1W(\:W,_.61S+3)^.V-+;7-I<UPY
M;G-E<V9S:G-A0FQS;W-H<WT\9$]P<V=S<G,M5RI&<W-Q<RA"73AU<W1S6S1V
M<W=S>',Z0&E`<45[<WIS6#1^<WES?'-]<R%T(W1).R)T)'0^,B9T)70N/%=#
M85E@0$QT45=;-TYT(T%)1E8T,U50=$]T471:2U)T051@5F`W.$$[05-T+#YB
M-%1T570K/E9T6W17=%IT?3I8=%ET8CA'3%QT6C)30V-4-S]==#1%:70U3TE.
M6$MW2W0]3U=;0'50:G1K=&QT8W<Q-VUT:U=N='EF0#YZ9FPZ>V9+3WQF/%0V
M/'UF?F9-/%)(,TXA9S\T(F<T25DX241=5UI"5S<]5D9.1#<F12-G7T\D9R5G
M)F<W06E7<$DX3R]6558G9VTP*&<I9UQ);U(M/BIG<S!>2&$]*V=&2"QG9CMX
M."11+6=G0G@^2CTS32YG+V=N/F509TM03$P\,&<H/'=0,6=X4#)G,V="-#1G
M-6=^22Q.8$,W9T$Q<3,X9SEG6U=`53IG3$(Z5SMG/&<]9VH\94-"0#YG/V<I
M/$!G06<V9U`V0F=#9T1G.CM>-49"8#%%9S541F<_.$AG1V=L-TEG>#)*9TMG
M3&=-9TYG3V=09R=3=4M19U)G4V=49TE)56=69U=G6&=99TD]6F<^<U<X,4@_
M<T!S07->.7A-:%@Q.EY"-VXC-SEN.&Y5,#MN5E5O5T-6/6YP2CQN/FY`;C]N
M<E$\1T!#83AG049T7U!'=%M/.DA(=$ET2G1+='I9?CAQ97!38'1,3F$S-'%N
M4F%T:$]B=$Q'5#5D-&1T8W1E=&9T9W0R.C\P:'0M-VU2*U)/0#P_(VM?54AJ
M<W%X-B-+341G<6AQ>SAI<40Z1512,&IQ:W%L<6UQ;G%O<7%Q<'%517)Q>C9T
M<2Y21UY*2UPS(C4B.71$=7%V<41!>T$P5G=Q>'$J03A&6SYY<4\T>G$R;3%M
M8$M>4D%+6%5B2%]`(3Q!:R108E9'-E@X0&M..#]K)C-).2M6=#=*-V<\/C=&
M:T=K.3!//T5K?5-(:TEK3C=":T1K=DE75DU5,E!/:SA.4&LH-3,Q4FLE3%9%
M4VM1:U]%3FLD2E5K>S!Z.C=88W%*:TMK3&M-:U9K0&99:V@_2%)7:UQK;#A8
M:SH]6%`W,%UK7$0L5F`T=D(Y/%IK6VM@5&I&5$1?:R=%=5DQ,F1K13UB:V-K
M+#A1365K86LS02)&<TQF:S!`.%)G:R\X+3AH:SM'<TUJ:VMK;6M(4')K;FMQ
M:WE(?%%L:VEK.3A93V5$;VMP:UI,2$UR,'9K=6LR,F`X=VML,45,)$0E3WEK
M(FQR17IK14E?8GYK3DTA;%LQ-U-<4GUK>VL\,S!J5%<K='0S059"5FE52CXG
M="A2*'0I="IT2SY?4V!)84E"<V9*<DPV8C1+:$Y;5BUT+G0O=#)T/3HS=&,P
M,'0Q="(]53(V=#=T9C8P,D]/-'0L-#5T.'0Y="=-.G0[=#QT4DL]=#YT/W1>
M=#Q!:#PK25Y1=64S7%52-%PL,#5<6CTY7$)8-UQS4U9).EPV7#M<(D,\7$5<
M/5Q?3B563UQ-7%)<9CTK0CA<2UQ.7#Y<4C=%,$=</E!!7"@[/#=,7$9</UQ;
M1S]10%Q*7%!<+4Y"7$-<2%Q)7%0R45Q52S=46UQ?7"9,9EQG0UQ<03]97'HP
M-CEE7%-<1%Q67'1(8#\[23TQ(E-:7%5<.T9>7$)7+T,V-U%'*4-B7%A<:UQ4
M7%U<)3Y77&!<8UQD7'A<85PB76=<:SQ$-"-#9S)Z7')<;UQ\7&Y<<%)H,E=(
M8TA[7&U<=UQU7",^=%Q=,G-<=CQH7$0[<T!4/&E<:EQQ7'9<>5PT-5E(9SM^
M7'U<*U,A72-=)5UQ4B1=)ETG72E223HI739=,5TT73!=3D9R0"]);%PN73==
M<%PO73A=+%TY73-=+5TJ1"A=,T`K02I=*UTR77$[-5TH4SI=.UTG0U)=/%U1
M73TY53YZ/DHZ2EU%73]=2S)#74M=)#)573Y=4$90751=8D%&-TY=3UU$73U=
M35U13$E=0EU(0SQ&+DY,74A=05U&75Q"*5,J4U-==$]X2&9=1UU@761"85U7
M77A665U877`X5EU/1BTV8EUY.F%49UU0-%I=>S]C75]=75U9-5M=7%U>72\]
M9%UE775=24-B2W)=85A11G1==%5S77!=;%UO76A=;E!82&Y=:5UJ77)+;5U-
M,39`.SQQ77===EUK76Y%>UTD7B->>%UO0WM"854U3GU=3#)H1%]*/D=Z77Q=
M?ETB7BHP3C$L7B9>-CUO2"%>)5XI7BA>)UXM7DQ4,UXJ7BY>64`A,39>,5XR
M7B91-5XO7C!>/5`T7FU*.5XX7C=>.UYE/5@R:D,Z7CI%/%Y93"HW950]7C]>
M(D1!7CY>0%XZ54)>+G(B.S)",$5'0B]R:5!=4SUK9C,P<C%R+4IG.C-R-7(T
M<F1+.D\R<C1*3U)L0D-..')V,#=R/G)/,D%1.G(\<FE4.W(V<C]R/7(Y<D=R
M1')&<DIR0G)`<D5R>U9!<GE'7TE(<D8Y,#5#<DER4')6<E<[57)<36M64G)4
M<G(X2W).<GE"755,<DUR3W)3<EER/%-J-G%*9#=7<EAR6G)=<EMR7')145%R
M24U/3BE68W);0V!R+T!L<EYR87)H<F)R9W)F<FER7W)D<FIR+%-E<G4R<G(K
M4'5R2#MY<G!R=G)X<GIR<W)Q<GLZ>S5O<G=R;7)N<FMR)G,C<R)S='):2'MR
M)7-X0WUR)W,I<R1S?'(K<RIS74(N<S!S(7,Q<RQS+W-^<BUS,G,T<RAS,W,U
M<S=0.'-Y63ES-W-D2#9S.G,[<T`T0VX\<SUS*E$L=$904%!<44Y/5CU#46(Z
M:6%"4D)Q.3)M,4-Q0$E$,W)9)4M$<51617%`=$9Q+%1'<4`P071"='PT6T4[
M3&108$U(<7-9.S$N3R0X2G%+<4,R44$P5TEQ3'%.<79985(C5$-T.4A$=$UQ
M3W%C/U!Q5'%6<5%Q44EA16-"?#E3<55Q4SE;<58Z?3!9<5AQ4G%:<5=Q;$A*
M35UQ/65<<5YQ7W%E3T5T<SU@<6%Q=TXJ4GMQ,CA[/%LY9CE90U-*:&I`0'4^
M:6IJ:FMJ;&IM:FYJ;VI'/7MU?75^=7QU8CTA=B4T(G8C=C)L5%%J621V.FXR
M57Y37$Q$2D!E)78O/BE&)5I&/"DV/#A/2"4\)EHG6E9,0T@H6GU&-5%I4C91
M1SPR/60[*5HJ6DA1*UIM4&\V6T)/2VTW:$E#-W<^)%8L6BU:0$9G5S9**55?
M2V]5+EI?5DHT,%HO6FM2,5HR6C-:5$HT6BM*-5HV6D\S;U8W6C`[+C4X6CE:
M;CDO46A2.EI#.&I/;S([6CQ::SU<3F]3/5IS3CY:55-E.S]:-4M02T!::T=N
M5D%:-45!-D):3#=./T-:1%HM2T5:=S5&6D)!.U='6CA,:E(Q1$A:?351.TE:
M,U!*6DM:/4Y,6DU:3EIW,E%:3UIH45!:54-26E-:5%I56CM0)5)Y,%9:*T=7
M6G<](4-86EE:?4,W3%I:6UH^0%=&7%I=6C1'7EI?6D@Y;3LY-GAT>71C33EU
M8&MS3S\[0#HE5%EA='4J,7(R=75W=5$Z=G4R0WEU>'4T,6I5.C@Q.48R<%1-
M3UPP2U5U.TI6-S<P3#9&83$Z.7Q683DA-WH\6FI;:GE,<SE<:GLT,T-1-U@Z
M76IT5%YJ5CQ?.U]J7D$X0E]42E=@:F%J9&IB:F-J7DDS.$0V96IJ2DU)3319
M8F)%9FHU0#A79VHL5WQ(4UA-6%Y4>51$22Y34SA@,V))=G15.G=T7U=Q=#`X
M5%5/.'!&0S-R="PS/51W1W1T<W1+3"1(=71C5S]%0'4[=4-U0G4Z5D%U/E1$
M=4QU3S!X-4EU2G5<145U1G5'=4MU8#Y(=7HX4'53=6<_<CD\=4UU-T)X3'D\
M3G5/=5%U9392=55U/754=3M3;#,D3%9U5W5A/EAU7TQ;=4@R65=9=5IU7'5B
M=6!U7W5==6%U7G5D=65U8TP_93@U8W5H=2-,9G5G=3YU1#$_=44U9#)L=6EU
M5S9M=6IU:W5:-&I4;G5Y,V]U<75P=7)U<W5M22HY>T=C-DE,)FHU,WY4;#EY
M4&UI*E=N:59";4AD.F]I<&EQ:6%6<FES:75I=&EV:7=I84=X:5A4>6E./7II
M>VE//7QI*#@^07UI,C%4.W4Y?FDA:B)J(VIX-RT\9$I.8"]4/4\W521J7E4E
M:D%0/#E'-%DQ,4!F,6<Q:#$],VA(065?,4E!;S0H1UA3>48X47TY=4(M4TM4
M?#U"934W0V4Y.V)5>#TV5"5.+$%9,W9,1F5$94AE2F5'94\U2$9\-45E=DI)
M951#13$C/#=72TU-2TI*4TQ,94ME9D0A43=1365093A-<%9/95TU/DU193HV
M*$UD.45*43-92VQ44F5J-TYE565^-%9E4V5495U27T)&,6)3739L2U=E=E-I
M,70V6F5895EE0#5%4EQE7F5=93)'(U);96)46E5@97%7865<,7M18F5D96-E
M96584DLU7V=U6GA:=EIW6GI:3U!'1&XP,%!Y6DI3*CHB6W%'?%I[6EM)?5HA
M6UY7?EI:025;=%,G6R1;*%L\/4E`(ULF6R-6*5LM6RY;+%M".B0_*ULJ6T=4
M/S(O6WDY,%L[,R8U/#8Q6W4V,EM),31;,ULU6S=;-ELX6SE;.EM/4WIT=4=#
M5V1%?'1]='MT1CYO4%,W350J3")U(74H.GYT5DLD=5)`:C,J325U(W4T/2AU
M*75-/3A#83]A2RIU)G4G=7!$+'4\-&U75S0K=2YU+74O=5%044,I2#!U,74R
M=3-U-'4U=3=U-G4X=4DR5%--2F]`6%8P4C]!<#TJ.'@\1G9'=DAV279*=DQV
M2W9I=TUV3G9$;D5N1FYK520V2&Y';DEN2FXE1TMN3&XP-W8U36Y/;DYN1CA0
M;E%N4FY;-BXS4U9&1#4Q5CA3;E1N/U151WL^64XS.59N56Y8;E=N)459;EIN
M+D=;;B]'7&XG,EUN7FY?;F!N86YJ5V)N8VY8/&1N2U-Z3"PR94%E;B9'+4-F
M;F=N:&YI;FIN:VYL;FUN;FYO;G!N<6YR;G1N<VYU;BU-04)V;G=N>&XA57EN
M,T]Z;GMN?&Y];B%O?FXB;W4X>D,C;R1O0CT_4GDR)6\F;R=O>%(H;WU6*6],
M1BIO*V\T02QO>D]X2RYO+6]Z,W@Y+V\P;V)0,6\R;V8W/U`S;S1O-6]Q2&!,
M-F\W;SAO.6\Z;V!5.V]M-"I#/&\];SYO/V]]3D!O8$(X-#97=3U'3T-O06]"
M;T1O)S9\/&(^3$-%;T9O1V]/;TAO26]*;T)'<6]--DMO3&]-;T8V/D-.;U!O
M46]2;W)54V]W1%1O>$15;U9O9#AW,%=O6&]9;UIO6V]<;UUO7F\U/F%O7V]@
M;V)O8V]-061O96]F;V=O:&]I;VIO:V]L;UA`;6\M06YO;V]P;V)/)#-%0T5C
M04E&8U4Q2DXS-')(1V-03TAC9#Q)8TIC1D,B559$:SE%3DMC=D-,8R<W<SA2
M.DUC3F-$5$]C4&-+45%C4F-38U1C5E%58WLR.T!68RM`5V-88UEC6F-;8S<X
M8EI3-F1:8UIF6FY(95I`-W11=5)S55<]:%=H6F=:(C!336E:/3A*/#U")$)"
M,VI:*D(P1#4]7D]K6D))73%L6C@V.E1],VU:25153V-%;EIO6G!::D%53%U/
M9U,A0G%:94MR6F9+?E)T.'-:+S`V3T]5;4MT6D1C)4$_=D!V07911#A(8U%;
M4$51+SQ-.71O1C0Z4T)V>S-#=G$U179J4R=V*5$I=BAV8T%70"(Q;4YH4"MV
M=D\J=G!5+'8Y0W0[+G8M=EY$6$$J2SQ/+W8P=C%V-D)4,'E%,G9@1R9V.#XR
M/F4U1S<_/U)#9D-,6&\X>3TE45`P,'<Q=RQ0,#`R=S-W-'=*1T\^-W<V=UXQ
M-7<X=SEW)$Y-2"LZ.&@Y:#IH0CYT4D]46$DS4B4V:D=\<6Y/,TMK4&]G9TU+
M.5DV?7%D,$Q+?G$D5"U";$%$1C$^(7)5/")R(W(D<D-2-49'325R,5-%/V),
M)G(G<E51;C8H<BER7S4J<BMR?#(L<BUR)TAG-REL*FPK;"QL+D8M;"YL23<S
M2CAB3W=0=TTR47=3=U)W.V(B/#QB/6(^8C]B0&)!8CDW>U(D/4Y*)3%'2T)B
M?#9$2$-B2#U],41B=C9%8EE$1F):3UTY1V(A0$AB=C))8G-!2F)+8GA"3&)-
M8DYB5THX6&598T\E<#!<;4(F5%1-,5%;,WU'-3(_0F!F.TIA9F)F5#YC9B17
M54UE9ET\9&9F9F=F;D(^/6AF9D(G.FEF:F92,VE1)3]K9F]&;&9M9FYF+49O
M9B=)<&9Q9G)F.65S9G1F8D)U9G9F:%9W9GAF1SD[=SIW/G<\=R$Z/W=`=T)W
M07=$=T-W17=&=T=W:$M?.%1W57=6=UAW6G=7=UMW67=75UQW77=>=U]W8'=+
M6RI8=V5M.7T_:CM)=T=&2'=*=TQW2W=-=SI.3G<G1&-33W8S0E!V4792=E-V
M5'96=BLQ5W98=EEV6G9;=EQV779>=DI/7W9@=F%V8G9C=F1V<$!E=F9V9W9H
M=FEV:G9K=FQV;79N=F]V<'9Q=G)V<W9T=B@^=79V=G=V>'9Z2'EV>G9[=GQV
M?79^=B%W(G<C=R1W)7<F=R=W*'=N,2EW*G<K=RQW+7=;02YW+W=Q1"]P)CPP
M<'E#.$4[43%P,G`S<#1P-7`\46Q1-W`V<"=44DTX<#IP.7`[<#QP:S@]<&@Z
M/G`_<&D^0'!L-D%P0G!#<$1P-4A%<$9P1W!T14AP27!*<#UW2W!,<$UP3G!/
M<%<Z4'!1<%)P4W!4<%5P5G!8<"535W!9<#IU.4)D=V5W9G=G=VAW-$)J=VMW
M<T)P=&]T:4)A=V)W1CMD67)*:$`D<%HZ+4<L1&QW;7=N=W!W;W=Q=W1W<W=R
M=W5W=G=I;6IM:VT\=CUV/G8F-CY81#D[6#%<<TIW=WAW>7=[=WIW1S%\=WUW
M?G=K1C1L73,S=C1V9$$U=C9V-W8X=CEV.G8C2#MV>D$H.6AM:CE?62$C(B,C
M(V<A)2,F(R<C*",I(RHC*R,L(RTC+B,O(S`C,2,R(S,C-",U(S8C-R,X(SDC
M.B,[(SPC/2,^(S\C0"-!(T(C0R-$(T4C1B-'(T@C22-*(TLC3"--(TXC3R-0
M(U$C4B-3(U0C52-6(U<C6"-9(UHC6R-<(UTC7B-?(V`C82-B(V,C9"-E(V8C
M9R-H(VDC:B-K(VPC;2-N(V\C<"-Q(W(C<R-T(W4C=B-W(W@C>2-Z(WLC?"-]
M(RLA:2%J(7XC)",`````````````````````````````LQS^_\(<___2'/__
MXAS___(<__\"'?]_$1T``!$=```1'0``$1T``!$=```1'0``$1T``!$=```1
M'2L``````"L<```K'`"`+!QOOSD<[N=%'/[?4QRB75L<V#]E'`O`:AR$"6X<
M#*!R'$``<QP0:7@<$.)]'!*YA!REAHL<`%J/'`!HDAR)`I8<!9":'(!JGQP0
M`*`<`P"B'```HAP`@*,<^1^N'`".LAP!````````````````````````````
M2`*+?U,">W]@`K0]:0)5[W0"J/M^`EWSB0)#`HT""T"1`D#[F0(^C:("]WNO
M`BR,M0+_;L("^N/-`CH=U0+MJ-X"`N;D`H//[0+UC/8"537^`DC@`P.K_Q`#
MN9(8`UG8(`,8JR<#DB@L`^G7-P,@@#D#.,0_`X/U2`-*YU$#"D56`P"P60,4
MEV`#8G=I`P!4;`.(T7(#(!1U`R`0=P/`R'P#(2&``P``@`.H$X8#!`R)`P"`
MB@-`!(P#P'"1`R@(E`/`")<#!`"8`P(`F0,`@)H#>RND`W(4J@,D>;$#^SN]
M`R<SQ0/D&LP#-9C3`^\XW0/1FN4#`BCH`Q.H[@-IO_D#SV4#!,8O#`01:Q,$
MR:\=!`\T)`134"H$HH8P!`2@,P0&`38$">@\!`\_1@0.P$L$B`I/!$6!5`00
M`%4$`<9:!&&A8`3A)F<$2T1M!`#.<@2JQWL$[M2%!-_*D`2[A9D$=#JA!""E
MI@1L0ZT$0(BP!`8_N`32B\`$>?_-!.\[V01:]^0$[^CO!,O[^P0V6P0%20T*
M!?T;%054`1D%[CDC!578*P5U+C0%V+\_!1JI1@77\U(%O_9?!>!G9P4,M&T%
MPH)R!1,(=@6=U'\%B]"&!5H&C`5A$)`%\G29!>!9H`6?CZL%$K.R!8``LP6J
M:KL%,#+`!5ZPR`5ZG=(%K&#8!0/3WP4`R>,%F##H!5:*[P4`</(%D!/W!10?
M_@5"&`(&8,`&!@@`!P8(@`D&@!`+!@`$#`:0[!,&%R@9!C/F(@98!R@&`)`J
M!@CW,@8)3C@&A?1`!H/\2093KU,&R!A8!GP87P8,"&(&WVIM!A0!<`8,R'4&
M-*=]!A&@@080)X8&Q2B,!B)"D`83!)0&(0"6!A`PF08209T&(!B@!@!`H08K
M`J8&#,:L!@`#K@8`$*\&(@"Q!B(`LP806+<&20*[!I2@P`9PEL<&L.[0!I(7
MUP:6R^`&\@7G!B4`Z@98(_`&WB7Y!LQ"_P8XSP@'!$H,!T`,#P>?-1D'*!$=
M!P"*(`?Z$RD'"I$N!RD",@=6$#<'008[!R`$/0>$!$`'\(1&!P``1@<$#$D'
M``1*!RQ!3P<&$E,'5!%8!TL*7@<"`%\'``)@!\``8@<``&('E`!E!P$`9@>[
MOW,'?!9[!RLD@0>[FXP'J'^6!W\,GP=YXZD']!"O!PW@M0<R0;H'`9_!!U*&
MQP=R-<\'M!#4!Q+_W@<GS^@'(T+M!VO`]`<"AO@'!C']!],?!P@,.@T(JJ$4
M"!((%P@$`AD(<B4@"`$((@C,0"<(4$@K"-!B,0@08#0(@!PX"``I.P@`FC\(
M$`!`"`0`00@`(D,(``!#"(``1`@@($8(`&A)".;+4PB>8%H(;I%B"',_;0C`
M8'$(@CEW"#00>P@P2'\(!@"!"%R]BPC1C)((^]:>".$@HPCH0ZH(``:L"$X(
ML0@`!;,(T,2Y"!^-P@BJB<D(X:;1"`(6U0@!`-8([2'>"%8VY@B+&NT(MQ_X
M"*43_P@"900)H#`("7BR$`G'(Q@)DVP@"2+I)PE_Y#()=#HZ">./1`D@F$@)
M#BA-"24F4PF<OUX)2;]H"1@R;0E4K'0)2;E\"189@@E@#(8)(K6-"<'[EPE9
M!IT)0^.E"2"$J`G9"*X)`("O"0!5LPDB(+8)A`&Y":$`O`D`2+X)$"#`"8`3
MQ`F`0,8)!`W*"18`S0E``,X)((#0"4#]V`GGC>()-E3I"9C@[PF+>_D)'@G_
M"<C^"0I)TA`*$084"NZ-'@HW&28*(KHM"O1W.`K=GT0*[/-/"MKP6`J&0UX*
M0NQE"C^-;PH$)G,*;/I]"B'`@0J.8H@*P@R-"H77E@I%`9H*K7>E"IE5K0I0
MXK,*14"W"@LFO0I4H<,*)YC*"AE8T`I#--8*$*3:"O(%X0H40>4*@"+H"@`'
MZPJT`.\*9D+U"A!R^@JA%0`+)6`%"X5!"@M4``T+```-"P$"#PL$`1$+(,@5
M"W#+'0L@DR(+8FHI"TP8+@N5`#(+@!@U"XN:/0NRJD4+`3))"WK84@O$`%4+
MY?-@"\,$90M-U&T+.*)S"Z&A>0MR4'\+"IB$"_R$C`M2P9(+T428"Y00G`O"
M(*`+@$&C"Q!"I@L``*8+`#JJ"T`"K`N=TK4+`2^["[&HP@M`O<D+,B3."TW3
MUPM+T-X+(Z?F"ZW0[@N2"O,+H77["ZRM!`SI`0H,&H`.#!]W&0PEDA\,&Z`E
M#*'?+PS*(#0,`@8W#(QS/PQ_5TL,.P!0#/\+6PS0`%X,:H!C#(@`90S$H6L,
M*0!N#`4J<PPD!7<,"4!Z#",6@`PB:(4,!8"(#!$@BPP1HI`,!`"1#)!DE@Q)
M2)L,@A.@#-4CJ`PP&:T,@"FQ#)((M0P"5+D,$8B]#`$@OPP$H,(,``3##("!
MQ@P"A<H,(F#.#)``T`P!"]0,(@#6#`(2V0P10-P,@P#?#`$:XPP``.,,``#C
M#```XPP``.,,``#C#```XPP``.,,GP#I#(1&[@S($O,,``+T#/P$^PP`&OX,
MWBX(#4P,#0T"!`\-N(`4#2:H&@W\"B(-`HPF#2@B*@W@H"\->X\Z#=;'1`TU
M(4H-QP91#;'X6@T3!V`-56)G#6Z3<`T9BG8-^FZ!#0[[BPTP%I`-^4B8#2_-
MH@WK?:X-DEBT#81.N@V@3+\-+GK(#>KMTPT>5ML-2<;B#9`1Y@TD4^P-.NCT
M#=O/``XD@00.\1@+#D)C$0Y36!@.BAH>#B!T(P[3)"H..ZHS#A0%-PX88#L.
M6(E!#@!(0PX`P$4.:()*#@&13@ZDA%,.UBQ;#H:(8`ZZQ&@.=P-P#A`"<@Y$
M@G8..`!Y#A&N@`Y*0(0.P"B(#@!1BPY$8(\.%!64#A!SF@X`$)L.@@"=#D@"
MH`X%`J,.!D"F#@/`J@X``*H.``"J#@(,K0X(`*X.(`*P#@"0L@X`0+,.`+BW
M#F'1O@XA1L,.=#+*#@#XSPZ*.]<.#P7=#@"+X0[0N^H.@"+M#@`&[PYI!_8.
M0(#X#D,`^PX@5/\.`%`!#]!!!@\,)0L/$(0.#Q"#$@\!$14/*`(8#PA`&@\P
M`!P/H4`@#P`"(0]``"(/`"`C#P`5)@_CJS`/@#$T#T2J.@_&PD$/),9'#Q.L
M3@\$@%`/`+!3#]$#60\>86`/A4)E#P/S;0^?'7</"D1[#^AX@P\F7HL/DL.2
M#P`@DP^%`)8/`;":#P!`FP^02J`/0HBD#P3*J0^-#*\/!:>V#P-"N@^A(K\/
M!`#`#VB&Q@\!#,D/9%70#WD0U@\"`-</H-[?#P`@X`_!0.0/BTCJ#P%0[0^`
M`_`/``3Q#P``\0\$4/0/7<#[#]"`_P\0H`(0"I<)$""[$!"O31H0(=DA$!`>
M)A!@!"D0%(,N$$B(,A#6ICL0.]A$$#]S3Q"\)U@0=$E?$-P-9Q`3DFT0*Q1S
M$*&+>A!U+H,0.=&+$`DPCQ!04),0"(B6$`!IFA#42:$02@*E$!!`IQ`6@*L0
M9.6S$->)O!`@P+\0%E/&$)(KS1``AM`01:/7$.`5W1"+`.$0`PSE$&X9[1``
MXO$0,7#W$`:`^A"E%@$1*:@'$0`@"!&`&`L1K'H4$4CA&A$',B`1UK4J$>@R
M,1&17SH1H5`_$>4@11$`?$H1@!!,$8!R41&*G5D1J@!=$1]"9!$B#FD1,0)M
M$0`1;Q&4!',1(@!U$0A`=Q$0`'@1$%Q]$4,#@A'(_(L1I:&2$8`%E1$SA)L1
M``2<$8``G1$(;J,12RJJ$2:!KQ'8JK<1`2F[$4UHPA&01,81"0#($8BZSQ%`
M`-`1@@#2$0``TA'1A]H16R'A$>:QZA%A,?`1"(#R$0`(\Q%`PO<1::#]$0"F
M`1)8C0@2,DH.$G%=%Q(*51T2H)HC$E<M+!(%0"\2IDHV$B$@.1*Q,#\2QC])
M$A(!3!+"$%`2"B95$F)$6A*"4%X2@)AB$D"`9!+`!&<2`(%I$@,@;!(``&P2
M``!L$A@X<1(``G(2IO%[$C1$@!(.<H<2HC6.$N"2E!(!@9<2``F9$@`$FA(`
M`)H2A8B?$@``GQ(``)\2``"?$@!`H!*``*$2``"A$@``H1)`0*,2``"C$@``
MHQ(``*,2``"C$@``HQ(``*,2``"C$@``HQ(`"*02@@"F$@``IA(``*82``"F
M$@0`IQ(`B*D2_[^X$N_GQ1+__]42O__D$N_O\A+__0$3__L0$_Z_'A/__RX3
M?P4W$S0`.A.SA4(3!D=($Q9"31,"5%$3$.16$Y*`6A,%LV$3(E1F$S"!:A-C
M0G`3"QAU$WLX?A/U$X<3Y0>/$^JIF!-,/)\3%`6C$P`&I1,"@*<3V1JO$TB]
MMQ,W[L(3EO3+$U]PU!/`?MP3LK_G$U\U\1-$YO@37T4!%`"0`Q1&00@40!T-
M%#L&%!2A8AH4$_XD%`6%*10".2X42`4R%`@,-11/%#P4```\%(@T01086$84
M=S!.%!78510.O5X4^TMI%)"*;A0`A7$4`,%T%!WF?104[844AK.-%'+_F12;
M8Z(4DOVL%+[9MQ1[B+\4D@K$%/[3T!2R'-<4@+G=%'H7YA3)@NP4%]SU%/O_
M!!6`.0D58$(-%0Q9$Q4!#Q@5WS<D%:.4*Q50L3$5(P8V%0<C/!5:^$45`C%)
M%?`!3A4",5(50`!3%8(>614*.E\5:@5E%81;;!6`$F\5`H!Q%12G>!42)GT5
M2Z"#%6D0B!4!D(L5`!",%8J$D14"&)05@#^;%0@'GQ5`0J(5$`&D%11.JA6P
M@*X5`!BP%1#%M16!`K@5`H*[%2D0OQ40`L$5`(C#%2``Q!5"`,85@`+(%0`1
MRA4`X,T5$T32%018UA4"_MX5!SSE%2@PZ168E_$5<P3W%='.`!83RP@6$&(,
M%A]#%!:-)QP6K%4D%BY"*A:2R#`6@%,U%H@".!8Y0#T647A$%BPI2A:(@$T6
M`+E2%B@D5A9!#%H6#@A>%B%$8A8`0F06"`1F%F@(:A8&`&P6!!)O%C$P=!:0
M`G<6/EN!%H7@AQ8V*8X61!"1%A0HE1:"$)@69D*>%C2#I!8\`:D6&U.Q%@0$
MLQ8-#KD6(@R]%E$`P!82`,(6`,#$%D``Q18`B,<62@#*%@``RA8``,H6``#*
M%O;?UQ9'5-X6:(CC%@@`Y!:!`.86``#F%@``YA8`0.<6``'H%@``Z!8``.@6
M``+I%@`&ZQ8(`.P6``#L%@``[!8``.P6``#L%@``[!8``.P6@`#M%@``[19`
M`.X6``#N%@``[A8``.X60!#P%@``\!8``/`6``#P%O_O_Q;]]PT7?_\<%_[_
M*Q?_^SH7__]*%__]61?_OV@7__]X%_\`@!?"$H47(`2'%P8,BQ<(!X\7)!:4
M%Q`!EA<``)87``"6%P``EA<``)87``"6%P``EA<``)87`."9%_[_J!?__[@7
M___(%WE_U!??*-T7^0#C%S(,Z!<2@.L7"`#L%SK5]1=8V/P7PNP$&!B="QBH
M+Q,8()88&!#@'!@,UB,8(B8H&)</,1@&`C080+(Y&%60/QBB@$,8$5!'&`"8
M2A@$!$P8`$!-&```31@``$T8``!-&```31@``$T8``!-&```31@``$T8``!-
M&,#[5AC__V88_N]T&/O?@A@("X880V*,&+9!DQ@[^Y\8=&^I&(DCKQA_KKL8
MU^S&&$?@S1A@6=,8EJ#9&(\)X!@L8>88,*#J&`T)[QBJ*O883M3^&'M/"1FR
MQ!`9BS@7&<:I'QD082,9%``E&0!")QD,@"H9`@(L&4C^-1F%9#L9/M9%&??C
M41F@.E<9!PQ<&0SD8ADP!&49@/9L&0(0;AD``&X9``!N&0``;AD``&X9``!N
M&0``;AD``&X9``!N&0``;AD0`&\9`$!P&0``<!D`0'$9``!Q&0`!<AD``'(9
M``!R&0``<AD``'(9``!R&0``<AD`0',9``!S&0``<QD`!'09``!T&0"`=1D`
M`'49``!U&0``=1D`!'890`!W&0``=QD``'<9``!W&0``=QD``'<9`$!X&0``
M>!D``'@9``AY&0``>1G@_X09O?Z1&?__H1G__[$9?W^_&>?[S!F__]L9__?J
M&?__^AG_[PD:?O\7&O??)1KW]C(:W_M`&OZ_3AI/@%0:``!4&@``5!H``%0:
M``!4&@``5!H``%0:`.];&O]_:AI__WD:][:%&@9$B1I^N),:]3N>&C&(HQJ6
M%ZL:]`"P&F"IMAJ1$[P:@`"]&DERQ!KS\L\:)`#1&@&'UAK(0ML:T^/E&DA0
MZ1H`).L:!4/P&@``\!I,2O8:)P+[&E@0_QH@*`(;%@$&&PFH"QL4``T;```-
M&P``#1O`/A0;:``7&P``%QL``!<;```7&P``%QL``!<;```7&P``%QO@_R(;
M_[<P&]O]/1OW`$0;``!$&P!`11LNQTX;@`%0&P``4!L`(%$;`0!2&P!`4QL`
M`%,;``!3&S``51NH_V`;][1K&_.M=AO_`X`;(`&"&P``@AL``((;``""&P``
M@AL``((;``""&P``@AL``((;``""&P``@AL``((;`/"&&_O_E1OWG:$;S_VN
M&[\!MAO#%;T;)QC#&PJ!QQM"J,P;``K.&PB!T1L(@-,;"(#5&P08V!N^H^(;
M$@#D&P``Y!L``.0;``#D&P``Y!L``.0;``#D&P``Y!L``.0;``#D&P``Y!L`
M`.0;``#D&P``Y!L``.0;``#D&P``Y!L``.0;`)#F&^9I[QLWW/D;_VL&'/\]
M$QSX_!X<^?,J'`0``````%L!+_]H`?L`;P$``&\!``!O`?[_?@'__XX!__^>
M`?__K@'__[X!#P#"`?[_T0'__^$!___Q`?__`0+__Q$"?P@9`N#_)`+__S0"
M_P,^`@``/@(``#X"```^`@``/@(``#X"```^`@``/@(``#X"```^`@``/@(`
M`#X"```^`@``/@(``#X"```^`O\#``````````````````````````"5````
ME0!@,YL`0`"<``T(H````*````"@````H````*````"@````H````*````"@
M````H````*````"@````H``(`*$`0`"B````H@```*(```"B````H@#_#ZX`
M``"N````K@`/`+(```"R````L@```+(```"R````L@```+(``(&T``)DN`"A
M3\``\"#%```1QP```,<`,\#-````S0```,T```+.`"``SP```,\```#/````
MSP```,\```#/````SP`$`-````#0````T````-````#0````T````-````#0
M````T````-````#0````T````-````#0````T````-````#0````T````-``
M``#0````T`#_`]H`\/_F`/__]@#_#P(!```"`0```@$```(!```"`0```@$`
M``(!__\2`?__(@'__S(!__]"`?\/3@$``$X!``!.`0``3@$``$X!``!.`0,`
M4`$,`%(!P,A7`0``5P$``%<!``!7`6``60$``%D!``!9`0``60$%````````
M````````````````````````````````````````````````````````````
M`````)`!`P`#``4````%`(``!@`#-PT`C!83``(`%``("!8```@7````%P``
M(!@````8```(&0```!D````9````&0```!D````9``!`&@!5%2$````A````
M(0```"$````A````(0```"$````A````(0```"$````A````(0```"$````A
M````(0"``B,````C````(P```",````C````(P```",````C````(P```",`
M```C````(P```",`_O\R`/L#.P#^_TH`^P-3````4P```%,```!3``(`5`#_
M_V0`__]T`/__A`#__Y0``@```````````$I5/Y;#5RACSE0)5<!4D79,=CR%
M[G=^@HUX,7*8EHV7*&R)6_I/"6.79KA<^H!(:*Z``F;.=OE15F6L<?%_A(BR
M4&59RF&S;ZV"3&-28NU3)U0&>VM1I'7T7=1BRXUVEXIB&8!=5SB78G\X<GUV
MSV=^=D9D<$\EC=QB%WJ19>US+&1S8BR"@9A_9TAR;F+,8C1/XW1*4YY2RGZF
MD"Y>AFB<:8"!T7[2:,5XC(91E8U0)(S>@MZ`!5,2B652A(7YEMU/(5AQF9U;
ML6*E8K1F>8R-G`9R;V>1>+)@45,74XB/S(`=C:&4#5#(<@=9ZV`9<:N(5%GO
M@BQG*'LI7?=^+77U;&:.^(\\D#N?U&L9D11[?%^G>-:$/875:]EKUFL!7H=>
M^77ME5UE"E_%7Y^/P5C"@7^06Y:ME[F/%G\LC4%BOT_84UY3J(^ICZN/39`'
M:&I?F(%HB-:<BV$K4BIV;%^,9=)OZ&Z^6TAD=5&P4<1G&4[)>7R9LW#%=79>
MNW/@@ZUDZ&*UE.)L6E/#4@]DPI24>R]/&UXV@A:!BH$D;LIL<YI58UQ3^E1E
MB.!7#4X#7F5K/WSHD!9@YF0<<\&(4&=-8B*-;'<ICL>1:5_<@R&%$)G"4Y6&
MBVOM8.A@?W#-@C&"TTZG;,^%S639?/UI^69)@Y535GNG3XQ12VU"7&V.TF/)
M4RR#-H/E9[1X/63?6Y1<[EWGB\9B]&=ZC`!DNF-)AXN9%XP@?_*4ITX0EJ28
M#&86<SI7'5PX7G^5?U"@@()37F5%=3%5(5"%C81BGI0=9S)6;F_B7354DG!F
MCV]BI&2C8WM?B&_TD..!L(\87&AF\5^);$B6@8ULB)%D\'G.5UEJ$&)(5%A.
M"WKI8(1OVHM_8AZ0BYKD>0-4]'4!8QE38&S?CQM?<)H[@'^?B$\Z7&2-Q7^E
M9;UP15&R46N&!UV@6[UB;)%T=0R.('H!87E[QT[X?H5W$4[M@1U2^E%Q:JA3
MAXX$E<^6P6YDEEII0'BH4-=W$&3FB019XV/=77]Z/6D@3SF"F%4R3JYUEWIB
M7HI>[Y4;4CE4BG!V8R25@E<E9C]IAY$'5?-MKWXBB#-B\'ZU=2B#P7C,EIZ/
M2&'W=,V+9&LZ4E"-(6MJ@'&$\58&4\Y.&T[149=\BY$'?,-/?X[A>YQZ9V04
M7:Q0!H$!=KE\[&W@?U%G6%OX6\MXKF039*IC*V,9E2UDOH]4>REV4V(G6494
M>6NC4#1B)EZ&:^-.-XV+B(5?+I`@8#V`Q6(Y3E53^)"X8\:`YF4N;$9/[F#A
M;=Z+.5_+AE-?(6-:46&#8V@`4F-C2(X24)M<=WG\6S!2.WJ\8%.0UW:W7Y=?
MA'9LCF]P>W9)>ZIW\U&3D"183D_T;NJ/3&4;>\1RI&W??^%:M6*57C!7@H0L
M>QU>'U\2D!1_H)B"8\=NF'BY<'A16Y>K5S5U0T\X=9=>YF!@6<!MOVN)>/Q3
MU9;+40%2B6,*5).4`XS,C3ERGWAVA^V/#8S@4P%.[W;N4XF4=I@.GRV5FENB
MBR).'$ZL46.$PF&H4@MHET]K8+M1'FU<499BEV5AED:,%Y#8=?V08W?2:XIR
M['+[BS58>7=,C5QG0)6:@*9>(6Z26>]Z[7<[E;5KK64.?P9845$?EOE;J5@H
M5'*.9F5_F.16G93^=D&0AV/&5!I9.EF;5[*.-6?ZC36"05+P8!58_H;H7$6>
MQ$^=F+F+)5IV8(13?&)/D`*1?YEI8`R`/U$S@!1<=9DQ;8Q.,(W14UI_3WL0
M3T].`);5;-!SZ84&7FIU^W\*:OYWDI1!?N%1YG#-4]2/`X,IC:]R;9G;;$I7
MLX*Y9:J`/V(REJA9_TZ_B[I^/F7R@UZ7857>F*6`*E/]BR!4NH"?7KAL.8VL
M@EJ1*50;;`92MWY?5QIQ?FR)?$M9_4[_7R1AJGPP3@%<JV<"A_!<"Y7.F*]U
M_7`BD*]1'7^]BTE9Y%%;3R94*UEW9:2`=5MV8L)BD(]%7A]L)GL/3]A/#6=N
M;:IMCWFQB!=?*W6:8H6/[T_<D:=E+X%1@9Q>4(%TC6]2AHE+C0U9A5#83AR6
M-G)Y@1^-S%NCBT26AUD:?Y!4=E8.5N6+.66":9F4UG:);G)>&'5&9]%G_WJ=
M@':-'V'&>6)E8XV(41I2HI0X?YN`LGZ77"]N8&?9>XMVV)J/@91_U7P>9%"5
M/WI*5.543&L!9`AB/9[S@)EU<E)IEUN$/&CDA@&6E);LE"I.!%39?CEHWXT5
M@/1FFEZY?\)7/X"7:.5=.V6?4FU@FI^;3ZR.;%&K6Q-?Z5U>;/%B(8UQ4:F4
M_E*?;-^"UW*B5X1G+8T?69R/QX.55(U[,$^];&1;T5D3G^13RH:HFC>,H8!%
M97Z8^E;'EBY2W'104N%;`F,"B59.T&(J8/IH<U&86Z!1PHFA>X:94'_O8$QP
M+XU)47]>&Y!P=,2)+5=%>%)?GY_ZE6B//)OABWAV0FC<9^J--8T]4HJ/VF[-
M:`65[9#]5IQG^8C'C\A4N)II6W=M)FRE3K-;AYICD:AAKY#IERM4M6W26_U1
MBE55?_!_O&1-8_%EOF&-8`IQ5VQ);"]9;6<J@M58CE9JC.MKW9!]61>`]U-I
M;754G55W@\^#.&B^>8Q454\(5-)VB8P"EK-LN&UKC1")9)XZC3]6T9[5=8A?
MX')H8/Q4J$XJ:F&(4F!PC\14V'!YAC^>*FV/6QA?HGZ)5:]/-',\5)I3&5`.
M5'Q43D[]7UIT]EAKA.&`=(?0<LI\5FXG7TZ&+%6D8I).JFPW8K&"UU1.4SYS
MT6X[=1)2%E/=B]!IBE\`8.YM3U<B:Z]S4VC8CQ-_8F.C8"15ZG5BC!5QHVVF
M6WM>4H-,8<2>^GA7AR=\AW;P4?9@3'%#9DQ>36`.C'!P)6.)C[U?8F#4AMY6
MP6N48&=A25/@8&9F/XW]>1I/Z7!';+.+\HO8?F2##V9:6D*;46WW;4&,.VT9
M3VMPMX,68M%@#9<GC7AY^U$^5_I7.F=X=3UZ[WF5>XR`99GYC\!OI8LAGNQ9
MZ7X)?PE4@6?8:)&/37S&ELI3)6"^=7)L<U/)6J=^)&/@40J!\5W?A(!B@%%C
M6PY/;7E"4KA@3FW$6\);H8NPB^)ES%]%EI-9YWZJ?@E6MV<Y67-/MEN@4EJ#
MBI@^C3)UOI1'4#QZ]TZV9WZ:P5I\:]%V6E<67#I[])5.<7Q1J8!P@GA9!'\G
M@\!H[&>Q>'=XXV)A8X![[4]J4L]14(/;:722]8TQC<&)+I6M>_9.95`P@E%2
M;YD0;H5NIVWZ7O50W%D&7$9M7VR&=8N$:&A66;*+(%-QD4V62842:0%Y)G'V
M@*1.RI!';82:!UJ\5@5D\)3K=Z5/&H'A<M*)>IDT?]Y^?U)99761?X^#C^M3
MEGKM8Z5CAG;X>5>(-I8J8JM2@H)4:'!G=V-K=^UZ`6W3?N.)T%D28LF%I8),
M=1]0RTZE=>N+2ES^74M[I&71D<I.)6U?B2=])I7%3BB,VX]SETMF@7G1C^QP
M>&T]7+)21H-B40Z#6W=V9KB<K$[*8+Y\LWS/?I5.9HMO9HB869>#6&QE7)6$
M7\EU5I??>MYZP%&O<)AZZF-V>J!^EG/MET5.>'!=3E*1J5-19>=E_($%@HY4
M,5R:=:"7V&+9<KUU15QYFLJ#0%R`5.EW/DZN;%J`TF)N8^A==U'=C1Z.+Y7Q
M3^53YV"L<&=24&-#GA]:)E`W=W=3XGZ%9"MEB6*88Q10-7+)B;-1P(O=?D=7
MS(.GE)M1&U3[7,I/XWI:;>&0CYJ`599485.O5`!?Z6-W:>]1:&$*4BI8V%).
M5PUX"W>W7G=AX'Q;8I=BHDZ5<`.`]V+D<&"7=U?;@N]G]6C5>)>8T7GS6+-4
M[U,T;DM1.U*B6_Z+KX!#5:97<V!15RU4>GI08%1;IV.@8N-38V+'6Z]G[52?
M>N:"=Y&37N2(.%FN5PYCZ(WO@%=7=WNI3^M?O5L^:R%34'O"<D9H_W<V=_=E
MM5&/3M1VOURE>G6$3EE!FX!0B)DG88-N9%<&9D9C\%;L8FEBTUX4EH-7R6*'
M52&'2H&CCV95L8-E9U:-W81J6@]HYF+N>Q&6<%&<;S",_6/(B=)A!G_"<.5N
M!724:?QRRE[.D!=G:FU>8[-28G(!@&Q/Y5EJD=EPG6W24E!.]Y9ME7Z%RG@O
M?2%1DE?"9(N`>WSJ;/%H7FFW49A3J&B!<LZ>\7OX<KMY$V\&=$YGS)&DG#QY
MB8-4@P]4%V@]3HE3L5(^>(93*5*(4(M/T$_B=<MZDGRE;+:6FU*#=.E4Z4]4
M@+*#WH]PE<E>'&"?;1A>6V4X@?Z42V"\<,-^KGS)48%HL7QO@B1.AH_/D7YF
MKDX%C*ED2H#:4)=USG'E6[V/9F^&3H)D8Y767IEE%U+"B,APHU(.<S-TEV?W
M>!:7-$Z[D-Z<RVW;44&-'53.8K)S\8/VEH2?PY0V3YI_S%%U<'66K5R&F.93
MY$Z<;@ETM&EK>(^967484B1V06WS9VU1F9]+@)E4/'N_>H:6A%?B8D>6?&D$
M6@)DTWL/;TN6IH)B4X68D%Z)<+-C9%-/AH&<DYZ,>#*7[XU"C7^>7F^$>55?
M1I8N8G2:%53=E*-/Q65E7&%<%7]1AB]LBU^'<^1N_W[F7!MC:EOF;G53<4Z@
M8V5UH6)NCR9/T4ZF;+9^NHL=A+J'5W\[D".5J7NAFOB(/80;;8::W'Z(6;N>
MFW,!>(*&;)J"FAM6%U3+5W!.IIY64\B/"8&2=Y*9[H;A;A.%_&9B82MO*8R2
M@BN#\G83;-E?O8,K<P6#&I7;:]MWQI1O4P*#DE$]7HR,.(U(3JMSFF>%:':1
M"9=D<:%L"7>26D&5SVN.?R=FT%NY69I:Z)7WE>Q.#(29A*QJWW8PE1MSIFA?
M6R]WFI%AE]Q\]X\<C"5?<WS8><6)S&P<A\9;0E[):"!W]7Z544U1R5(I6@5_
M8I?7@L]CA'?0A=)Y.FZ97IE9$85M<!%LOV*_=D]EKV#]E0YFGX<CGNV4#51]
M5"R,>&1Y9!&&(6J<@>AX:614F[EB*V>K@ZA8V)ZK;"!OWEM,E@N,7W+09\=B
M87*I3L99S6N36*YF55[?4E5A*&?N=F9W9W)&>O]BZE105*"4HY`<6K-^%FQ#
M3G99$(!(65=3-W6^ELI6(&,1@7Q@^976;6)4@9F%4>E:_8"N61.7*E#E;#Q<
MWV)@3S]3>X$&D+IN*X7(8G1>OGBU9'MC]5\86G^1'YX_7$]C0H!]6VY52I5-
ME85MJ&#@9]YRW5&!6^=BWFQ;<FUBKI2]?A.!4VV<401?=%FJ4A)@<UF69E"&
MGW4J8^9A[WSZB^94)VLEGK1KU8555'90I&QJ5;2-+'(57A5@-G3-8I)C3'*8
M7T-N/FT`95AOV';0>/QV5'4D4MM34TZ>7L%E*H#6@)MBAE0H4JYPC8C1C>%L
M>%3:@/E7](A4C6J639%I3YMLMU7&=C!XJ&+Y<(YO;5_LA-IH?'CW>ZB!"V=/
MGF=CL'AO5Q)X.9=Y8JMBB%(U=-=K9%4^@;)UKG8Y4]YU^U!!7&R+QWM/4$=R
MEYK8F`)OXG1H>8=DI7?\8I&8*XW!5%B`4DYJ5_F"#81S7NU1]G3$BT]<85?\
M;(>81EHT>$2;ZX^5?%9246+ZE,9.AH-AA.F#LH345S1G`U=N9F9M,8S=9A%P
M'V<Z:Q9H&F*[60-.Q%$&;])GCVQV4<MH1UEG:V9U#ET0@5"?UV5(>4%YD9IW
MC8)<7DX!3R]445D,>&A6%&S$CP-??6SC;*N+D&-P8#UM=7)F8HZ4Q91#4\&/
M?GO?3B:,?D[4GK&4LY1-4EQO8Y!%;32,$5A,72!K26NJ9UM45(&,?YE8-X4Z
M7Z)B1VHYE7)EA&!E:*=W5$ZH3^==F)>L9-A_[5S/3XUZ!U($@Q1.+V"#>J:4
MM4^R3N9Y-'3D4KF"TF2]>=U;@6Q2EWN/(FP^4']3!6[.9'1F,&S%8'>8]XN&
M7CQT=WK+>1A.L9`#=$)LVE9+D<5LBXTZ4\:&\F:OCDA<<9H@;M93-EJ+GZ.-
MNU,(5Z>80V>;D<EL:%'*=?-BK'(X4IU2.G^4<#AV=%-*GK=I;GC`EMF(I'\V
M<<-QB5'39^1TY%@89;=6J8MVF7!BU7[Y8.UP[%C!3KI.S5_GE_M.I(L#4HI9
MJWY48LU.Y64.8CB#R81C@XV'E'&V;KE;TGZ74<ECU&>)@#F#%8@247I;@EFQ
MCW-.76QE426);X\NEDJ%7G00E?"5IFWE@C%?DF02;2B$;H'#G%Y86XT)3L%3
M'D]C95%HTU4G3A1DFIIK8L):7W1R@JEM[FCG4(Z#`GA`9SE2F6RQ?KM0955>
M<5M[4F;*<^N"26=Q7"!2?7%KB.J559;%9&&-LX&$555L1V(N?Y)8)$]&54^-
M3&8*3AI<\XBB:$YC#7KG<(V"^E+VEQ%<Z%2UD,U^8EE*C<>&#((-@F:-1&0$
M7%%AB6T^>;Z+-W@S=7M4.$^KCO%M(%K%?EYYB&RA6W9:&G6^@$YA%V[P6!]U
M)75R<D=3\WX!=]MV:5+<@"-7"%XQ6>YRO65_;M>+.%QQAD%3\W?^8O9EP$[?
MF("&GEO&B_)3XG=_3TY<=IK+60]?.GGK6!9._V>+3NUBDXH=D+]2+V;<56Q6
M`I#53HU/RI%PF0]L`EY#8*1;QHG5BS9E2V*6F8A;_UN(8RY5UU,F=GU1+(6B
M9[-HBFN28I./U%,2@M%MCW5F3DZ-<%N?<:^%D6;99G)_`(?-GB"?7EPO9_"/
M$6A?9PUBUGJ%6+9><&4Q;U5@-U(-@%1D<(@I=05>$VCT8AR7S%,]<@&,-&QA
M=PYZ+E2L=WJ8'(+TBU5X%&?!<*]EE60V5AU@P7GX4QU.>VN&@/I;XU7;5CI/
M/$]RF?-=?F<X@`)@@I@!D(M;O(OUBQQD6(+>9/U5SX)ED==/('T?D)]\\U!1
M6*]NOUO)BX.`>)&<A)=[?8:+EH^6Y7[3FHYX@5Q7>D*0IY9?>5E;7V,+>]&$
MK6@&52E_$'0B?0&50&),6-9.@UMY6518;7,>8TN.#X[.@-2"K&+P4_!L7I$J
M60%@<&Q-5TID*HTK=NEN6U>`:O!U;6\MC`B,9E?O:Y*(LWBB8_E3K7!D;%A8
M*F0"6.!HFX$05=9\&%"ZCLQMGXWK<(]CFVW4;N9^!(1#:`.0V&UVEJB+5UEY
M<N2%?H&\=8J*KVA44B*.$9708YB81(Y\55-/_V:/5M5@E6U#4DE<*5G[;6M8
M,'4<=6Q@%()&@1%C86?BCSIW\XTTC<&4%EZ%4RQ4PW!`;/=>7%"M3JU>.F-'
M@AJ04&AND;-W#%3<E&1?Y7IV:$5C4GO??MMU=U"58C19#Y#X4<-Y@7K^5I)?
M%)"";6!<'U<05%1136[B5JACDYA_@16'*HD`D!Y4;US`@=9B6&(Q@36>0)9N
MFGR:+6FE6=-B/E468\=4V88\;0-:YG2<B&IK%EE,C"]??FZI<WV8.$[W<(Q;
MEW@]8UIFEG;+8)M;25H'3E6!:FR+<Z%.B6=1?X!?^F4;9]A?A%D!6LU=KE]Q
M4^:7W8]%:/16+U7?8#I.36_T?L>"#H3461]/*D\^7*Q^*F<:A7-43W7#@()5
M3YM-3RUN$XP)7'!A:U,?=BENBH:'9?N5N7X[5#-Z"GWNE>%5P7_N=!UC%X>A
M;9UZ$6*A96=3X6.#;.M=7%2HE$Q.86SLBTM<X&6<@J=H/E0T5,MK9FN43D)C
M2%,>@@U/KD]>5PIB_I9D9FER_U*A4I]@[XL49IEQD&=_B5)X_7=P9CM6.%0A
ME7IR`'IO8`Q>B6"=@159W&"$<>]PJFY0;(!RA&JMB"U>8$ZS6IQ5XY07;?M\
MF98/8L9^CG=^AB-3'I>6CX=FX5R@3^UR"TZF4P]9$U2`8RB52%'93IR<I'ZX
M5"2-5(@W@O*5CFTF7\Q:/F9IEK!S+G._4WJ!A9FA?ZI;=Y90EK]^^':B4W:5
MF9FQ>T2)6&YA3M1_97GFB_-@S52K3GF8]UUA:L]0$51AC">$77@$ETI2[E2C
M5@"5B&VU6\9M4V8/7%U;(6B6@'A5$7M(951IFTY':TZ'BY=/4Q]C.F2JD)QE
MP8`0C)E1L&AX4_F'R&'$;/ML(HQ17*J%KX(,E2-KFX^P9?M?PU_A3T6('V9E
M@2ES^F!T41%2BU=B7Z*03(B2D7A>3V<G8--91%'V4?B`"%-Y;,26BG$13^Y/
MGG\]9\55")7`>9:(XWZ?6`QB`)=:AAA6>YB07[B+Q(17D=E3[66/7EQU9&!N
M?7]:ZG[M?FF/IU6C6ZQ@RV6$<PF08W8I=]I^=)>;A69;='KJED"(RU*/<:I?
M[&7BB_M;;YKA78EK6VRMBZ^+"I#%CXM3O&(FGBV>0%0K3KV"67*<AA9=68BO
M;<66T52:3K:+"7&]5`F6WW#Y;=!V)4X4>!*'J5SV7@"*G)@.EHYPOVQ$6:EC
M/'=-B!1O<X(P6-5QC%,:>,&6`55F7S!QM%L:C(R:@VLN62^>YWEH9VQB;T^A
M=8I_"VTSEB=L\$[2=7M1-V@^;X"0<(&6679T1V0G7&60D7HCC-I9K%0`@F^#
M@8D`@#!I3E8V@#=RSI&V45].=9B68QI.]E/S9DN!'%FR;0!.^5@[4]9C\92=
M3PI/8XB0F#=95Y#[>>I.\("1=8)LG%OH65U?!6F!AAI0\EU93N-WY4YZ@I%B
M$V:1D'E<OTYY7\:!.)"$@*MUID[4B`]AQ6O&7TE.RG:B;N.+KHL*C-&+`E_\
M?\Q_SGXU@VN#X%:W:_.7-);[61]4]I3K;<5;;IDY7!5?D)9P4_&",6IT6G">
ME%XH?[F#)(0EA&>#1X?.CV*-R'9Q7Y:8;'@@9M]4Y6)C3\.!R'6X7LV6"H[Y
MAH]4\VR,;3AL?V#'4BAU?5X83Z!@YU\D7#%UKI#`E+ERN6PX;DF1"6?+4_-3
M44_)D?&+R%-\7L*/Y&V.3L)VAFE>AAIA!H)93]Y//I!\G`EA'6X4;H66B$XQ
M6NB6#DY_7+EYAUOMB[U_B7/?5XN"P9`!5$>0NU7J7*%?"&$R:_%RLH")BG1M
MTUO5B(28:XQMFC.>"FZD44-1HU>!B)]3]&.5C^U66%0&5S]SD&X8?]R/T8(_
M82A@8I;P9J9^BHW#C:64LURD?`AGIF`%EAB`D4[GD`!3:)9!4="/=(5=D55F
M]9=56QU3.'A"9SUHR51^<+!;?8^-42A7L50298)F7HU#C0^!;(1MD-]\_U'[
MA:-GZ66A;Z2&@8YJ5B"0@G9V<.5Q(XWI8AE2_6P\C0Y@GEB.8?YF8(U.8K-5
M(VXM9V>/X93XE2AW!6BH:8M434ZX<,B+6&2+985;A'HZ4.A;NW?A:WF*F'R^
M;,]VJ667CRU=55PXA@AH8%,88MEZ6V[]?A]JX'IP7S-O(%^,8ZAM5F<(3A!>
M)HW73L"`-':<EMMB+69^8KQL=8UG<6E_1E&'@.Q3;I"88O)4\(:9CP6`%Y47
MA=F/66W-<Y]E'W<$=2=X^X$>C8B4ID^59[EURHL'ER]C1Y4UEKB$(V-!=X%?
M\'*)3A1@=&7O8F-K/V4G7L=UT9#!BYV"G6<O93%4&(?E=Z*``H%!;$M.QWY,
M@/1V#6F6:V=B/%"$3T!7!V-B:[Z-ZE/H9;A^UU\:8[=C\X'T@6Y_'%[97#92
M>F;I>1IZ*(V9<-1UWFZ[;))Z+4[%=N!?GY1WB,A^S7F_@,V1\DX73Q^":%3>
M73)MS(NE?'2/F(`:7I)4L7:96SQFI)K@<RIHVX8Q9RIS^(O;BQ"0^7K;<&YQ
MQ&*I=S%6.TY7A/%GJ5+`ABZ-^)11>T]/Z&Q=>7N:DV(J<OUB$TX6>&R/L&1:
MC<9[:6B$7L6(AEF>9.Y8MG(.:265_8]8C6!7`'\&C,9126/98E-33&@B=`&#
M3)%$54!W?'!*;7E1J%1$C?]9RV[$;5Q;*WW43GU\TVY06^J!#6Y76P.;U6@J
MCI=;_'X[8+5^N9!PC4]9S6/?>;.-4E//959YQ8L[EL1^NY2"?C16B9$`9VI_
M"EQUD"AFYEU03]YG6E!<3U!7IU[]__W__?_]__W_C4X,3D!1$$[_7D53%4Z8
M3AY.,IML6VE6*$ZZ>3].%5-'3BU9.W)N4Q!LWU;D@)>9TVM^=Q>?-DZ?3A"?
M7$YI3I-.B();6VQ5#U;$3HU3G5.C4Z53KE-EEUV-&E/U4R93+E,^4UR-9E-C
M4P)2"%(.4BU2,U(_4D!23%)>4F%27%*OA'U2@E*!4I!2DU*"451_NT[#3LE.
MPD[H3N%.ZT[>3AM/\TXB3V1/]4XE3R=/"4\K3UY/9T\X95I/74]?3U=/,D\]
M3W9/=$^13XE/@T^/3WY/>T^J3WQ/K$^43^9/Z$_J3\5/VD_C3]Q/T4_?3_A/
M*5!,4/-/+%`/4"Y0+5#^3QQ0#%`E4"A0?E!#4%502%!.4&Q0>U"E4*=0J5"Z
M4-90!E'M4.Q0YE#N4`=1"U'=3CUL6$]E3\Y/H)]&;'1\;E']7<F>F)F!4119
M^5(-4P>*$%/K41E955&@3E91LTYNB*2(M4X4@=*(@'DT6P.(N'^K4;%1O5&\
M4<=1EE&B4:51H(NFBZ>+JHNTB[6+MXO"B\.+RXO/B\Z+THO3B]2+UHO8B]F+
MW(O?B^"+Y(OHB^F+[HOPB_.+]HOYB_R+_XL`C`*,!(P'C`R,#XP1C!*,%(P5
MC!:,&8P;C!B,'8P?C"",(8PEC">,*HPKC"Z,+XPRC#.,-8PVC&E3>E,=EB*6
M(98QEBJ6/98\ED*62994EE^69Y9LEG*6=):(EHV6EY:PEI>0FY"=D)F0K)"A
MD+20LY"VD+J0N)"PD,^0Q9"^D-"0Q)#'D-.0YI#BD-R0UY#;D.N0[Y#^D`21
M(I$>D2.1,9$OD3F10Y%&D0U20EFB4JQ2K5*^4O]4T%+64O!2WU/N<<UW]%[U
M4?Q1+YNV4P%?6G7O74Q7J5>A5WY8O%C%6-%8*5<L5RI7,U<Y5RY7+U=<5SM7
M0E=I5X57:U>&5WQ7>U=H5VU7=E=S5ZU7I%>,5[)7SU>G5[17DU>@5]57V%?:
M5]E7TE>X5_17[U?X5^17W5<+6`U8_5?M5P!8'E@96$18(%AE6&Q8@5B)6)I8
M@%BHF1F?_V%Y@GV"?X*/@HJ"J(*$@HZ"D8*7@IF"JX*X@KZ"L(+(@LJ"XX*8
M@K>"KH++@LR"P8*I@K2"H8*J@I^"Q(+.@J2"X8()@_>"Y((/@P>#W(+T@M*"
MV((,@_N"TX(1@QJ#!H,4@Q6#X(+5@AR#48-;@UR#"(.2@SR#-(,Q@YN#7H,O
M@T^#1X-#@U^#0(,7@V"#+8,Z@S.#9H-E@VB#&X-I@VR#:H-M@VZ#L(-X@[.#
MM(.@@ZJ#DX.<@X6#?(.V@ZF#?8.X@WN#F(.>@ZB#NH.\@\&#`83E@]B#!U@8
MA`N$W8/]@]:#'(0XA!&$!H34@]^##X0#A/B#^8/J@\6#P(,FA/"#X8-<A%&$
M6H19A'.$AX2(A'J$B81XA#R$1H1IA':$C(2.A#&$;83!A,V$T(3FA+V$TX3*
MA+^$NH3@A*&$N82TA)>$Y83CA`R%#74XA?"$.84?A3J%5H4[A?^$_(19A4B%
M:(5DA5Z%>H6B=T.%<H5[A:2%J(6'A8^%>86NA9R%A86YA;>%L(73A<&%W(7_
MA2>&!88IAA:&/(;^7@A?/%E!63>`55E:65A9#U,B7"5<+%PT7$QB:F*?8KMB
MRF+:8M=B[F(B8_9B.6-+8T-CK6/V8W%C>F..8[1C;6.L8XIC:6.N8[QC\F/X
M8^!C_V/$8]YCSF-29,9COF-%9$%D"V0;9"!D#&0F9"%D7F2$9&UDEF1Z9+=D
MN&299+IDP&309-=DY&3B9`EE)64N90M?TE\9=1%?7U/Q4_U3Z5/H4_M3$E06
M5`942U125%-45%165$-4(5175%E4(U0R5()4E%1W5'%49%2:5)M4A%1V5&94
MG5305*U4PE2T5-)4IU2F5--4U%1R5*-4U52[5+]4S%395-I4W%2I5*I4I%3=
M5,]4WE0;5>=4(%7]5!15\U0B52-5#U4152=5*E5G58]5M55)56U5055553]5
M4%4\53=55E5U5795=U4S53!57%6+5=)5@U6Q5;E5B%6!59]5?E7659%5>U7?
M5;U5OE6459E5ZE7W5<E5'U;15>M5[%745>95W57$5>]5Y57R5?-5S%7-5>A5
M]57D592/'E8(5@Q6`58D5B-6_E4`5B=6+5985CE65U8L5DU68E995EQ63%94
M5H969%9Q5FM6>U9\5H56DU:O5M16UU;=5N%6]5;K5OE6_U8$5PI7"5<<5P]>
M&5X47A%>,5X[7CQ>-UY$7E1>6UY>7F%>C%QZ7(U<D%R67(A<F%R97)%<FER<
M7+5<HER]7*Q<JURQ7*-<P5RW7,1<TESD7,M<Y5P"70-=)UTF72Y=)%T>709=
M&UU873Y=-%T]76Q=6UUO75U=:UU+74I=:5UT78)=F5V=77.,MUW%77-?=U^"
M7X=?B5^,7Y5?F5^<7ZA?K5^U7[Q?8HAA7ZURL'*T<K=RN'+#<L%RSG+-<M)R
MZ'+O<NER\G+T<O=R`7/S<@-S^G+[<A=S$W,A<PIS'G,=<Q5S(G,Y<R5S+',X
M<S%S4'--<U=S8'-L<V]S?G,;@B59YY@D60)98YEGF6B9:9EJF6N9;)ETF7>9
M?9F`F829AYF*F8V9D)F1F9.9E)F5F8!>D5Z+7I9>I5Z@7KE>M5Z^7K->4XW2
M7M%>VU[H7NI>NH'$7\E?UE_/7P-@[E\$8.%?Y%_^7P5@!F#J7^U?^%\98#5@
M)F`;8`]@#6`I8"M@"F`_8"%@>&!Y8'M@>F!"8&I@?6"68)I@K6"=8(-@DF",
M8)M@[&"[8+%@W6#88,9@VF"T8"!A)F$582-A]&``80YA*V%*875AK&&48:=A
MMV'48?5AW5^SENF5ZY7QE?.5]97VE?R5_I4#E@26!I8(E@J6"Y8,E@V6#Y82
MEA66%I87EAF6&I8L3C]R%6(U;%1L7&Q*;*-LA6R0;)1LC&QH;&EL=&QV;(9L
MJ6S0;-1LK6SW;/AL\6S7;+)LX&S6;/ILZVSN;+%LTVSO;/YL.6TG;0QM0VU(
M;0=M!&T9;0YM*VU-;2YM-6T:;4]M4FU4;3-MD6UO;9YMH&U>;9-ME&U<;6!M
M?&UC;1INQVW%;=YM#FZ_;>!M$6[F;=UMV6T6;JMM#&ZN;2MN;FY.;FMNLFY?
M;H9N4VY4;C)N)6Y$;M]NL6Z8;N!N+6_B;J5NIVZ];KMNMV[7;K1NSVZ/;L)N
MGVYB;T9O1V\D;Q5O^6XO;S9O2V]T;RIO"6\I;XEOC6^,;WAO<F]\;WIOT6_)
M;Z=ON6^V;\)OX6_N;]YOX&_O;QIP(W`;<#EP-7!/<%YP@%N$6Y5;DUNE6[A;
M+W6>FC1DY%ON6S")\%M'C@>+MH_3C]6/Y8_NC^2/Z8_FC_./Z(\%D`20"Y`F
MD!&0#9`6D"&0-9`VD"V0+Y!$D%&04I!0D&B06)!BD%N0N69TD'V0@I"(D(.0
MBY!07U=?5E]87SM<JU107%E<<5MC7&9<O'\J7RE?+5]T@CQ?.YMN7(%9@UF-
M6:E9JEFC69=9REFK69Y9I%G26;)9KUG76;Y9!5H&6MU9"%KC6=A9^5D,6@E:
M,EHT6A%:(UH36D!:9UI*6E5:/%IB6G5:[("J6IM:=UIZ6KY:ZUJR6M):U%JX
M6N!:XUKQ6M9:YEK86MQ:"5L76Q9;,ELW6T!;%5P<7%I;95MS6U%;4UMB6W6:
M=YIXFGJ:?YI]FH":@9J%FHB:BIJ0FI*:DYJ6FIB:FYJ<FIV:GYJ@FJ*:HYJE
MFJ>:GWZA?J-^I7ZH?JE^K7ZP?KY^P'[!?L)^R7[+?LQ^T'[4?M=^VW[@?N%^
MZ'[K?NY^[W[Q?O)^#7_V?OI^^W[^?@%_`G\#?P=_"'\+?PQ_#W\1?Q)_%W\9
M?QQ_&W\??R%_(G\C?R1_)7\F?R=_*G\K?RQ_+7\O?S!_,7\R?S-_-7]Z7G]U
MVUT^=960CG.1<ZYSHG.?<\]SPG/1<[=SLW/`<\ESR'/E<]ES?)@*=.ESYW/>
M<[IS\G,/="IT6W0F="5T*'0P="YT+'0;=!IT071<=%=T5719='=T;71^=)QT
MCG2`=(%TAW2+=)YTJ'2I=)!TIW32=+ITZI?KE^R73&=39UYG2&=I9Z5GAV=J
M9W-GF&>G9W5GJ&>>9ZUGBV=W9WQG\&<):-AG"FCI9[!G#&C99[5GVF>S9]UG
M`&C#9[AGXF<.:,%G_6<R:#-H8&AA:$YH8FA$:&1H@V@=:%5H9FA!:&=H0&@^
M:$IH26@I:+5HCVAT:'=HDVAK:,)H;FG\:!]I(&GY:"1I\&@+:0%I5VGC:!!I
M<6DY:6!I0FE=:81I:VF`:9AI>&DT:<QIAVF(:<YIB6EF:6-I>6F;::=INVFK
M::UIU&FQ:<%IRFG?:95IX&F-:?]I+VKM:1=J&&IE:O)I1&H^:J!J4&I;:C5J
MCFIY:CUJ*&I8:GQJD6J0:JEJEVJK:C=S4G.!:X)KAVN$:Y)KDVN-:YIKFVNA
M:ZIK:X]MCW&/<H]SCW6/=H]XCW>/>8]ZCWR/?H^!CX*/A(^'CXN/C8^.CX^/
MF(^:C\Z."V(78AMB'V(B8B%B)6(D8BQBYX'O=/1T_W0/=1%U$W4T9>YE[V7P
M90IF&69R9P-F%68`9H5P]V8=9C1F,68V9C5F!H!?9E1F069/9E9F86979G=F
MA&:,9J=FG6:^9MMFW&;F9NEF,HTSC3:-.XT]C4"-18U&C4B-28U'C4V-58U9
MC<>)RHG+B<R)SHG/B=")T8EN<I]R77)F<F]R?G)_<H1RBW*-<H]RDG((8S)C
ML&,_9-AD!(#J:_-K_6OU:_EK!6P';`9L#6P5;!AL&6P:;"%L*6PD;"IL,FPU
M955E:V5-<E)R5G(P<F*&%E*?@)R`DX"\@`IGO8"Q@*N`K8"T@+>`YX#H@.F`
MZH#;@,*`Q(#9@,V`UX`09]V`ZX#Q@/2`[8`-@0Z!\H#\@!5G$H%:C#:!'H$L
M@1B!,H%(@4R!4X%T@5F!6H%Q@6"!:8%\@7V!;8%G@4U8M5J(@8*!D8'5;J.!
MJH',@29GRH&[@<&!IH$D:S=K.6M#:T9K66O1F-*8TYC5F-F8VIBS:T!?PFOS
MB9!E49^39;QEQF7$9<-ES&7.9=)EUF6`<)QPEG"=<+MPP'"W<*MPL7#H<,IP
M$'$3<19Q+W$Q<7-Q7'%H<45Q<G%*<7AQ>G&8<;-QM7&H<:!QX''4<>=Q^7$=
M<BAR;'`8<69QN7$^8CUB0V)(8DEB.WE`>49Y27E;>5QY4WE:>6)Y5WE@>6]Y
M9WEZ>85YBGF:>:=YLWG17]!?/&!=8%I@9V!!8%E@8V"K8`9A#6%=8:EAG6'+
M8=%A!F*`@'^`DVSV;/QM]G?X=P!X"7@7>!AX$7BK92UX''@=>#EX.G@[>!]X
M/'@E>"QX(W@I>$YX;7A6>%=X)GA0>$=X3'AJ>)MXDWB:>(=XG'BA>*-XLGBY
M>*5XU'C9>,EX['CR>`5Y]'@3>21Y'GDT>9N?^9[[GOR>\78$=PUW^78'=PAW
M&G<B=QEW+7<F=S5W.'=0=U%W1W=#=UIW:'=B=V5W?W>-=WUW@'>,=Y%WGW>@
M=[!WM7>]=SIU0'5.=4MU2'5;=7)U>76#=5A_87]??TB*:']T?W%_>7^!?WY_
MS7;E=C*(A92&E(>4BY2*E(R4C92/E)"4E)27E)64FI2;E)R4HY2DE*N4JI2M
ME*R4KY2PE+*4M)2VE+>4N)2YE+J4O)2]E+^4Q)3(E,F4RI3+E,R4S93.E-"4
MT932E-64UI37E-F4V)3;E-Z4WY3@E.*4Y)3EE.>4Z)3JE.F4ZY3NE.^4\Y3T
ME/64]Y3YE/R4_93_E`.5`I4&E0>5"94*E0V5#I4/E1*5$Y44E165%I48E1N5
M'94>E1^5(I4JE2N5*94LE3&5,I4TE3:5-Y4XE3R5/I4_E4*5-95$E4651I5)
ME4R53I5/E5*54Y54E5:55Y58E5F56Y5>E5^5795AE6*59)5EE6:59Y5HE6F5
M:I5KE6R5;Y5QE7*5<Y4ZE>=W['?)EM5Y[7GC>>MY!GI'70-Z`GH>>A1Z.7HW
M>E%ZSYZEF7!ZB':.=I-VF7:D=MYTX'0L=2">(IXHGBF>*IXKGBR>,IXQGC:>
M.)XWGCF>.IX^GD&>0IY$GD:>1YY(GDF>2YY,GDZ>49Y5GE>>6IY;GER>7IYC
MGF:>9YYHGFF>:IYKGFR><9YMGG.>DG64=99UH'6==:QUHW6S=;1UN'7$=;%U
ML'7#=<)UUG7-=>-UZ'7F=>1UZW7G=0-V\77\=?]U$'8`=@5V#'87=@IV)788
M=A5V&78;=CQV(G8@=D!V+78P=C]V-79#=CYV,W9-=EYV5'9<=E9V:W9O=LI_
MYGIX>GEZ@'J&>HAZE7JF>J!ZK'JH>JUZLWIDB&F(<HA]B'^(@HBBB,:(MXB\
MB,F(XHC.B..(Y8CQB!J)_(CHB/Z(\(@AB1F)$XD;B0J)-(DKB3:)08EFB7N)
MBW7E@+)VM';<=Q*`%(`6@!R`((`B@"6`)H`G@"F`*(`Q@`N`-8!#@$:`38!2
M@&F`<8"#B7B8@)B#F(F8C)B-F(^8E)B:F)N8GIB?F*&8HIBEF*:83894AFR&
M;H9_AGJ&?(9[AJB&C8:+AJR&G8:GAJ.&JH:3AJF&MH;$AK6&SH:PAKJ&L8:O
MALF&SX:TANF&\8;RANV&\X;0AA.'WH;TAM^&V(;1A@.'!X?XA@B'"H<-APF'
M(X<[AQZ')8<NAQJ'/H=(AS2',8<IAS>'/X>"AR*'?8=^AWN'8(=PATR';H>+
MAU.'8X=\AV2'68=EAY.'KX>HA]*'QH>(AX6'K8>7AX.'JX?EAZR'M8>SA\N'
MTX>]A]&'P(?*A]N'ZH?@A^Z'%H@3B/Z'"H@;B"&(.8@\B#9_0G]$?T5_$(+Z
M>OUZ"'L#>P1[%7L*>RM[#WM'>SA[*GL9>RY[,7L@>R5[)'LS>SY['GM8>UI[
M17MU>TQ[77M@>VY[>WMB>W)[<7N0>Z9[IWNX>ZQ[G7NH>X5[JGN<>Z)[JWNT
M>]%[P7O,>]U[VGOE>^9[ZGL,?/Y[_'L/?!9\"WP??"I\)GPX?$%\0'S^@0&"
M`H($@NR!1(@A@B*"(X(M@B^"*((K@CB".X(S@C2"/H)$@DF"2X)/@EJ"7X)H
M@GZ(A8B(B-B(WXA>B9U_GW^G?Z]_L'^R?WQ\2661?)U\G'R>?*)\LGR\?+U\
MP7S'?,Q\S7S(?,5\UWSH?&Z"J&:_?\Y_U7_E?^%_YG_I?^Y_\W_X?'=]IGVN
M?4=^FWZXGK2><XV$C92-D8VQC6>-;8U'C$F,2I%0D4Z13Y%DD6*189%PD6F1
M;Y%]D7Z1<I%TD7F1C)&%D9"1C9&1D:*1HY&JD:V1KI&OD;61M)&ZD56,?IZX
MC>N-!8Y9CFF.M8V_C;R-NHW$C=:-UXW:C=Z-SHW/C=N-QHWLC?>-^(WCC?F-
M^XWDC0F._8T4CAV.'XXLCBZ.(XXOCCJ.0(XYCC6./8XQCDF.08Y"CE&.4HY*
MCG".=HY\CF^.=(Z%CH^.E(Z0CIR.GHYXC(*,BHR%C)B,E(R;9=:)WHG:B=R)
MY8GKB>^)/HHFBU.7Z9;SEN^6!I<!EPB7#Y<.ERJ7+9<PESZ7@)^#GX6?AI^'
MGXB?B9^*GXR?_IX+GPV?N9:\EKV6SI;2EK]WX):.DJZ2R)(^DVJ3RI./DSZ4
M:Y1_G(*<A9R&G(><B)PC>HN<CIR0G)&<DIR4G)6<FIR;G)Z<GYR@G*&<HIRC
MG*6<IIRGG*B<J9RKG*V<KIRPG+&<LIRSG+2<M9RVG+><NIR[G+R<O9S$G,6<
MQIS'G,J<RYS,G,V<SIS/G-"<TYS4G-6<UYS8G-F<W)S=G-^<XIQ\EX67D9>2
MEY27KY>KEZ.7LI>TE[&:L)JWFEB>MIJZFKR:P9K`FL6:PIK+FLR:T9I%FT.;
M1YM)FTB;39M1F^B8#9DNF5695)G?FN&:YIKOFNN:^YKMFOF:")L/FQ.;'YLC
MF[V>OIX[?H*>AYZ(GHN>DI[6DYV>GY[;GMR>W9[@GM^>XI[IGN>>Y9[JGN^>
M(I\LGR^?.9\WGSV?/I]$GP`P`3`",/LPR0+'`J@``S`%,!4@7O\6("8@&"`9
M(!P@'2`4,!4P"#`),`HP"S`,,`TP#C`/,!8P%S`0,!$PL0#7`/<`-B(G(B@B
M$2(/(BHB*2(((C<B&B*E(B4B("(2(YDB*R(N(F$B3")((CTB'2)@(FXB;R)D
M(F4B'B(U(C0B0B9`)K``,B`S(`,A!/^D`.#_X?\P(*<`%B$&)@4FRR7/)<XE
MQR7&):$EH"6S);(E.R"2(9`AD2&3(1,P_?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?^()(DDBB2+)(PDC22.)(\DD"21))(DDR24))4DEB27))@D
MF22:))LD="1U)'8D=R1X)'DD>B1[)'PD?21^)'\D@"2!)((D@R2$)(4DAB2'
M)&`D821B)&,D9"1E)&8D9R1H)&DD_?_]_R`R(3(B,B,R)#(E,B8R)S(H,BDR
M_?_]_V`A82%B(6,A9"%E(68A9R%H(6DA:B%K(?W__?\!_P+_`__E_P7_!O\'
M_PC_"?\*_PO_#/\-_P[_#_\0_Q'_$O\3_Q3_%?\6_Q?_&/\9_QK_&_\<_QW_
M'O\?_R#_(?\B_R/_)/\E_R;_)_\H_RG_*O\K_RS_+?\N_R__,/\Q_S+_,_\T
M_S7_-O\W_SC_.?\Z_SO_//\]_S[_/_]`_T'_0O]#_T3_1?]&_T?_2/])_TK_
M2_],_TW_3O]/_U#_4?]2_U/_5/]5_U;_5_]8_UG_6O];_US_7?_C_T$P0C!#
M,$0P13!&,$<P2#!),$HP2S!,,$TP3C!/,%`P43!2,%,P5#!5,%8P5S!8,%DP
M6C!;,%PP73!>,%\P8#!A,&(P8S!D,&4P9C!G,&@P:3!J,&LP;#!M,&XP;S!P
M,'$P<C!S,'0P=3!V,'<P>#!Y,'HP>S!\,'TP?C!_,(`P@3"",(,PA#"%,(8P
MAS"(,(DPBC"+,(PPC3".,(\PD#"1,)(PDS#]__W__?_]__W__?_]__W__?_]
M__W_H3"B,*,PI#"E,*8PIS"H,*DPJC"K,*PPK3"N,*\PL#"Q,+(PLS"T,+4P
MMC"W,+@PN3"Z,+LPO#"],+XPOS#`,,$PPC##,,0PQ3#&,,<PR##),,HPRS#,
M,,TPSC#/,-`PT3#2,-,PU##5,-8PUS#8,-DPVC#;,-PPW3#>,-\PX##A,.(P
MXS#D,.4PYC#G,.@PZ3#J,.LP[##M,.XP[S#P,/$P\C#S,/0P]3#V,/W__?_]
M__W__?_]__W__?^1`Y(#DP.4`Y4#E@.7`Y@#F0.:`YL#G`.=`YX#GP.@`Z$#
MHP.D`Z4#I@.G`Z@#J0/]__W__?_]__W__?_]__W_L0.R`[,#M`.U`[8#MP.X
M`[D#N@.[`[P#O0.^`[\#P`/!`\,#Q`/%`\8#QP/(`\D#_?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]_Q`$$002!!,$%`05!`$$%@07!!@$&00:!!L$
M'`0=!!X$'P0@!"$$(@0C!"0$)00F!"<$*`0I!"H$*P0L!"T$+@0O!/W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]_S`$,00R!#,$-`0U!%$$-@0W!#@$
M.00Z!#L$/`0]!#X$/P1`!$$$0@1#!$0$101&!$<$2`1)!$H$2P1,!$T$3@1/
M!/W__?_]__W__?_]__W__?_]__W__?_]__W_`0'A`,X!X``3`>D`&P'H`"L!
M[0#0`>P`30'S`-(!\@!K`?H`U`'Y`-8!V`':`=P!_`#J`/W__?_]__W__?_]
M__W__?_]__W_!3$&,0<Q"#$),0HQ"S$,,0TQ#C$/,1`Q$3$2,1,Q%#$5,18Q
M%S$8,1DQ&C$;,1PQ'3$>,1\Q(#$A,2(Q(S$D,24Q)C$G,2@Q*3']__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?\`)0$E
M`B4#)00E!24&)0<E""4))0HE"R4,)0TE#B4/)1`E$242)1,E%"45)18E%R48
M)1DE&B4;)1PE'24>)1\E("4A)2(E(R4D)24E)B4G)2@E*24J)2LE+"4M)2XE
M+R4P)3$E,B4S)30E-24V)3<E."4Y)3HE.R4\)3TE/B4_)4`E025")4,E1"5%
M)48E1R5()4DE2B5+)0``0B)P(D,B;2)L(FXB-"(Q(FLB1"(B*B$J)"HJ*B,J
M*2HA*2XJ,BHQ*C0J,RI`*C\J0BI!*E`J4BI1*E0J6"I3*BPI8RIB*F4J9"IR
M*C`I3BDB*R$K)"LJ*R,K*2M!*2XK,BLQ*S0K,RM`*S\K0BM!*T,I4"M2*U$K
M5"M8*U,K3"EC*V(K92MD*W(K4"ES*R<J)RLE*B4K*"HH*RLJ*RLL*BPK+RHO
M*RTJ+2LP*C`K(BE"*3<J-RLV*C8K."HX*S4J-2LZ*CHK.RH[*STJ/2L\*CXJ
M/BLD*40I1RI'*T4J12M&*D8K1"I%*28I1BE(*D@K22I)*T<I2BI**TPJ3"M+
M*DLK*2E)*2@I2"E-*DTK3RI/*TXJ3BM**2LI2RE7*E<K5BI6*RTI32E9*EDK
M6RI;*UHJ6BM<*EPK72I=*U\J7RM>*EXK82IA*V`J8"LO*4\I;"IL*VDJ:2MF
M*F8K:RIK*V@J:"MJ*FHK<2IQ*W0J="MS*G4J=2MW*G<K=BIV*R8J)BM#*D,K
M52I5*V<J9RMP*G`K;2IM*V\J;RMN*FXK.2LP(B\B,B(V(C4B,R(X(CDB829B
M)F,F9"9G)FDF;"9V)F4F:B9Q)G(F<R9T)GLF>"9U)GHF=R9Y)GPF0B=#)T0G
M12=&)T<G2"=))THG2R=,)TTG3B=R)W,G="=U)W8G=R=X)WDG>B=[)WPG?2=^
M)W$B;R(A,"(P(S`D,"4P)C`G,"@P*3`J,"LP+#`M,"XP+S`P,#$P,C`S,#0P
M-3`V,#<P.#`Y,#HP.S`\,#TP/C`_,$`P03!",$,P1#!%,$8P1S!(,$DP2C!+
M,$PP33!.,$\P4#!1,%(P4S!4,%4P5C!7,%@P63!:,%LP7#!=,%XP8#!A,&(P
M8S!D,&4P9C!G,&@P:3!J,&LP;#!M,&XP;S!P,%\P<3!R,',P=#!U,'8P=S!X
M,'DP>C![,'PP?3!^,"$Q(C$C,20Q)3$F,2<Q*#$I,2HQ*S$L,2TQ+C$O,3`Q
M,3$R,3,Q-#$U,38Q-S$X,3DQ.C$[,3PQ/3$^,3\Q0#%!,4(Q0S%$,44Q1C%'
M,4@Q23%*,4LQ3#%-,4XQ3S%0,5$Q4C%3,50Q53%6,5<Q6#%9,5HQ6S%<,5TQ
M7C%V,5\Q8#%A,6(Q8S%D,64Q9C%G,6@Q:3%J,6LQ;#%M,6XQ;S%P,7$Q<C%S
M,70Q=3%W,7@Q>3%Z,7LQ?#%],7XQ(3(B,B,R)#(E,B8R)S(H,BDR*C(K,BPR
M+3(N,B\R,#(Q,C(R,S(T,C4R-C(W,C@R.3(Z,CLR/#(],CXR/S)`,D$R0C)#
M,D0R13)1,D8R1S)(,DDR2C)+,DPR33).,D\R4#)2,E,R5#)5,E8R5S)8,EDR
M6C);,EPR73)>,E\R8#)A,F(R8S)D,F4R9C)G,F@R:3)J,FLR;#)M,FXR;S)P
M,G$R<C)S,G0R=3)V,G<R>#)Y,GHR>S)\,GTR?C(A,R(S(S,D,R4S)C,G,R@S
M*3,J,RLS+#,M,RXS+S,P,S$S,C,S,S0S-3,V,S<S.#,Y,SHS.S,\,STS/C,_
M,T`S03-",T,S1#-%,T8S1S-(,TDS2C-+,TPS33-.,T\S4#-1,U(S4S-4,U4S
M5C-7,U@S63-:,ULS7#-=,UXS7S-@,V$S8C-C,V0S93-F,V<S:#-I,VHS:S-L
M,VTS;C-O,W`S<3-R,W,S=#-U,W8S=S-X,WDS>C-[,WPS?3-^,R$T(C0C-"0T
M)30F-"<T*#0I-"HT*S0L-"TT+C0O-#`T,30R-#,T-#0U-#8T.#0W-#DT.C0[
M-#PT/30^-#\T0#1!-$(T0S1$-$4T1C1'-$@T231*-$LT3#1--$XT3S10-%$T
M4C13-%0T5316-%<T6#19-%HT6S1<-%TT7C1?-&`T831B-&,T9#1E-&8T9S1H
M-&DT:C1K-&PT;31N-&\T<#1Q-'(T<S1T-'4T=C1W-'@T>31Z-'LT?#1]-'XT
M(34B-2,U)#4E-28U)S4H-2DU*C4K-2PU+34N-2\U,#4Q-3(U,S4T-34U-C4W
M-3@U.34Z-3LU/#4]-3XU/S5`-4$U0C5#-40U135&-4<U2#5)-4HU2S5,-4TU
M3C5/-5`U4352-5,U5#55-58U5S58-5DU6C5;-5PU735>-5\U8#5A-6(U8S5D
M-64U9C5G-6@U:35J-6LU;#5M-6XU;S5P-7$U<C5S-70U=35V-7<U>#5Y-7HU
M>S5\-7TU?C4A-B(V(S8D-B4V)C8G-B@V*38J-BLV+#8M-BXV+S8P-C$V,C8S
M-C0V-38V-C<V.#8Y-CHV.S8\-CTV/C8_-D`V039"-D,V1#9%-D8V1S9(-DDV
M2C9+-DPV339.-D\V4#91-E(V4S94-E4V5C97-E@V639:-ELV7#9=-EXV7S9@
M-F$V8C9C-F0V939F-F<V:#9I-FHV:S9L-FTV<#9Q-FXV;S9R-G,V=#9U-G8V
M=S9X-GDV>C9[-GTV?C9\-B$W(C<C-R0W)3<F-R<W*#<I-RHW*S<L-RTW+C<O
M-S`W,3<R-S,W-#<U-S8W-S<X-SDW.C<[-SPW/3<^-S\W0#=!-T(W0S=$-T4W
M1C='-T@W23=*-TLW3#=--TXW3S=0-U$W4C=3-U0W53=6-U<W8#=8-UDW6C=;
M-UPW73=>-U\W83=B-V,W9#=E-V8W9S=H-VDW:C=K-VPW;3=^-VXW;S=P-W$W
M<C=S-W0W=3=V-W<W>#=Y-WHW>S=\-WTW(3@B.",X)#@E."8X)S@H."DX*C@K
M."PX+3@N."\X,#@Q.#(X,S@T.#4X-C@W.#@X.3@Z.#LX/#@].#XX/SA`.$$X
M0CA#.$0X13A&.$<X2#A).$HX2SA,.$TX3CA0.%$X3SA2.%,X5#A5.%8X5SA8
M.%DX6CA;.%PX73A>.%\X8#AA.&(X8SAD.&4X9SAH.&DX:CAK.&PX;3AN.&\X
M<#AQ.'(X<SAT.'4X=CAW.'@X>3AZ.'LX?#A].'XX(3DB.2,Y)#DE.28Y)SDH
M.2DY*CDK.2PY+3DN.2\Y,#DQ.3(Y,SDT.34Y-CDW.3@Y.3DZ.3LY/#D].3XY
M/SE`.4$Y0CE#.40Y13E&.4<Y2#E).4HY2SE,.4TY3CE/.5`Y43E2.5,Y5#E5
M.58Y5SE8.5DY6CE;.5PY73E>.5\Y8#EA.6(Y8SED.64Y9CEG.6@Y:3EJ.6LY
M;#EM.6XY;SEP.7$Y<CES.70Y=3EV.7<Y>#EY.7HY>SE\.7TY?CDA.B(Z(SHD
M.B4Z)CHG.B@Z*3HJ.BLZ+#HM.BXZ+SHP.C$Z,SHT.C4Z-CHW.C@Z,CHY.CHZ
M.SH\.CTZ/CH_.D`Z03I".D,Z1#I%.D8Z1SI(.DDZ2CI+.DPZ33I..D\Z4#I1
M.E(Z4SI4.E4Z5CI7.E@Z63I:.ELZ7#I=.EXZ7SI@.F$Z8CIC.F0Z93IF.F<Z
M:#II.FHZ:SIL.FTZ;CIO.G`Z<3IR.G,Z=#IU.G8Z=SIX.GDZ>CI[.GPZ?3I^
M.B$[(CLC.R0[)3LF.R<[*#LI.RH[*SLL.RT[+CLO.S`[,3LR.S,[-#LU.S8[
M-SLX.SD[.CL[.ST[/#L^.S\[0#M!.T([0SM$.T4[1SM(.TD[2CM&.TL[3#M-
M.TX[3SM0.U$[4CM3.U<[53M4.U8[6#M9.UH[6SM<.UT[7CM?.V`[83MB.V,[
M9#ME.V8[9SMH.VD[:CMK.VP[;3MN.V\[<#MQ.W([=&9S.W0[=3MV.W<[>#MZ
M.WD[>SM\.WT[?CLA/"(\(SPD/"4\)CPG/"@\*3PJ/"L\+#PN/"T\+SPP/#$\
M-#PR/#,\-3PV/#<\.#PY/#H\.SP\/#T\/CP_/$`\03Q"/$,\1#Q%/$8\1SQ(
M/$D\2CQ+/$P\33Q./$\\4#Q2/%$\4SQ4/%4\5CQ7/%@\63Q:/%L\7#Q=/%X\
M7SQ@/&$\8CQC/&0\93QF/&<\:#QI/&H\:SQL/&T\;CQO/'`\<3QR/',\=#QU
M/'8\=SQX/'D\>CQ[/'P\?3Q^/"$](CTC/20])3TF/2<]*#TI/2H]*STL/2T]
M+CTO/3(],#TQ/3,]-#TU/38]-STX/3D].CT[/3P]/3T^/3\]0#U!/4(]0SU$
M/44]1CU'/4@]23U*/4L]3#U-/4X]3SU0/5$]4CU3/50]53U6/5<]6#U9/5H]
M6SU</5T]7CU?/6`]83UB/6,]9#UE/68]9SUH/6D]:CUK/6P];3UN/6\]<#UQ
M/7(]<SUT/74]=CUW/7@]>3UZ/7L]?#U]/7X](3XB/B,^)#XE/B8^)SXH/BD^
M*CXK/BP^+3XN/B\^,#XQ/C(^,SXT/C4^-CXW/C@^.3XZ/CL^/#X]/CX^/SY`
M/D$^0CY#/D0^13Y&/D<^2#Y)/DH^2SY,/DT^3CY//E`^43Y2/E,^5#Y5/E8^
M5SY8/ED^6CY;/EP^73Y>/E\^8#YA/F(^8SYD/F4^9CYG/F@^:3YJ/FL^;#YM
M/FX^;SYP/G$^<CYS/G0^=3YV/G<^>#YY/GH^>SY^/GP^?3XA/R(_(S\D/R4_
M)C\G/R@_*3\J/RL_+#\M/RX_+S\P/S$_,C\S/S0_-3\V/S<_.#\Y/SH_.S\\
M/ST_/C\_/T`_03]"/T,_1#]%/T8_1S](/TD_2C]+/TP_33]./T\_4#]1/U(_
M4S]4/U4_5C]7/U@_63]:/UL_7#]=/UX_7S]@/V$_8C]C/V0_93]F/V<_:#]I
M/VH_:S]L/VT_;C]O/W`_<3]R/W,_=#]U/W8_=S]X/WD_>C][/WP_?3]^/R%`
M(D`C0"1`)4`F0"=`*$`I0"I`*T`L0"U`+D`O0#!`,4`R0#-`-$`U0#9`-T`X
M0#E`.D`[0#Q`/4`^0#]`0$!!0$)`0T!$0$5`1D!'0$A`24!*0$M`3$!-0$Y`
M3T!00%%`4D!30%1`54!60%=`6$!90%I`6T!<0%U`7D!?0&!`84!B0&-`9$!E
M0&9`9T!H0&E`:D!K0&Q`;4!N0&]`<$!Q0')`<T!T0'5`=D!W0'A`>4!Z0'M`
M?$!]0'Y`(4$B02-!)$$E029!)T$H02E!*D$K02Q!+4$N02]!,$$Q03)!,T$T
M035!-D$W03A!.4$Z03M!/$$]03Y!/T%`04%!0D%#041!14%&04=!2$%)04I!
M2T%,04U!3D%/05!!44%205-!5$%5059!5T%805E!6D%;05Q!74%>05]!8$%A
M06)!8T%D065!9D%G06A!:4%J06M!;$%M06Y!;T%P07%!<D%S071!=4%V07=!
M>$%Y07I!>T%\07U!?D$A0B)"(T(D0B5")D(G0BA"*4(J0BM"+$(M0BY",$(O
M0C%",D(S0C1"-4(W0C9".$(Y0CI".T(\0CU"/D)`0D%"0D)$0D5"1T)(0DE"
M2D),0D-"1D)+0DU"3D)/0E!"44)20E-"5$)50E9"5T)80EE"6D);0EQ"74)>
M0E]"8$)A0F)"8T)D0F5"9D)G0FA":4)J0FM";$)M0C]";D)O0G!"<4)R0G-"
M=$)U0G9"=T)X0GE">D)[0GQ"?4)^0B%#(D,C0R1#)4,F0R=#*$,I0RI#*T,L
M0RU#+D,O0S!#,4,R0S-#-$,U0S9#-T,Y0SI#.T,\0SU#/D,_0T!#04-"0T-#
M1$-%0T9#1T-(0SA#2D-+0TQ#34-/0TY#4$-10U)#4T-40U5#5D-70UA#64-:
M0UM#24-<0UU#7D-?0V!#84-B0V-#9$-E0V9#9T-H0VE#:D-K0VQ#;4-N0V]#
M<$-Q0W)#<T-T0W5#=D-W0WA#>4-Z0WM#?$-]0WY#(40B1"-$)$0E1"9$)T0H
M1"E$*D0K1"Q$+40N1"]$,$0Q1#)$,T0T1#5$-D0W1#A$.40Z1#M$/$0]1#Y$
M/T1`1$%$0D1#1$1$141&1$=$2$1)1$I$2T1,1$U$3D1/1%!$44121%-$5$15
M1%9$5T181%E$6D1;1%Q$741>1%]$8$1A1&)$8T1D1&5$9D1G1&A$:41J1&M$
M;$1M1&Y$;T1P1'%$<D1S1'1$=41V1'=$>$1Y1'I$>T1\1'U$?D0A12)%(T4D
M125%)D4G12A%*44J12M%+$4M12Y%+T4P13%%,D4S131%-44V13=%.$4Y13I%
M.T4\13U%/D4_14!%045"14-%1$5%149%1T5(14E%2D5+14U%3$5.14]%4$51
M15)%4T54155%5D5715A%645:15M%7$5=15Y%7T5@16%%8D5C161%945F16=%
M:$5I16I%:T5L16U%;D5O17!%<45R17-%=$5U179%=T5X17E%>D5[17Q%?45^
M12%&(D8C1B1&)48F1B=&*$8I1BI&*T8L1BU&+D8O1C!&,48R1C-&-$8U1C9&
M-T8X1CE&.D8[1CQ&/48^1C]&0$9!1D)&0T9$1D5&1D9'1DA&249*1DM&3$9-
M1DY&3T901E%&4D931E1&54961E=&6$991EI&6T9<1EU&7D9?1F!&-D=A1F)&
M8T9D1F5&9D9G1FA&:49J1FM&;$9M1FY&;T9P1G%&<D9S1G1&=49V1G=&>$9Y
M1GI&>T9\1GU&?D8A1R)'(T<D1R5')D<G1RA'*4<J1RM'+$<M1RY'+T<P1S%'
M,D<S1S1'-4<W1SA'.4<Z1SM'/$<]1SY'/T=`1T%'0D=#1T1'14=&1T='2$=)
M1TI'2T=,1TU'3D=/1U!'44=21U-'5$=51U9'5T=81UE'6D=;1UQ'74=>1U]'
M8$=A1V)'8T=D1V5'9D=G1VA':4=J1VM';$=M1VY';T=P1W%'<D=S1W1'=4=V
M1W='>$=Y1WI'>T=\1WU'?D<A2")((T@D2"5()D@G2"A(*4@J2"M(+$@M2"Y(
M+T@P2#%(,D@S2#1(-4@V2#=(.$@Y2#I(.T@\2#U(/D@_2$!(04A"2$-(1$A%
M2$9(1TA(2$E(2DA+2$Q(4TA-2$Y(3TA02%%(4DA42%5(5DA72%A(64A:2%M(
M7$A=2%Y(7TA@2&%(8DAC2&1(94AF2&=(:$AI2&I(:TAL2&U(;DAO2'!(<4AR
M2'-(=$AU2'9(=TAX2'E(>DA[2'Q(?4A^2"%)(DDC221))4DF22=)*$DI22I)
M*TDL22U)+DDO23!),4DR23-)-$DU239)-TDX23E).DD[23Q)04D]23Y)/TE`
M24))0TE$245)1DE'24A)24E*24M)3$E-24Y)3TE025%)4DE3251)54E625=)
M6$E925I)6TE<25U)7DE?26!)84EB26-)9$EE269)9TEH26E):DEK26Q);4EN
M26])<$EQ27))<TET275)=DEW27A)>4EZ27M)?$E]27Y)(4HB2B-*)$HE2B9*
M)THH2BE**DHK2BQ*+4HN2B]*,$HQ2C)*,THT2C5*-DHW2CA*.4HZ2CM*/$H]
M2CY*/TI`2D%*0DI#2D1*14I&2D=*2$I)2DI*2TI,2DU*3DI/2E!*44I22E-*
M5$I52E9*5TI82EE*6DI;2EQ*74I>2E]*8$IA2F)*8TID2F5*9DIG2FA*:4IJ
M2FM*;$IM2FY*;TIP2G%*<DIS2G1*=4IV2G=*>$IY2GI*>TI\2GU*?DHA2R)+
M(TLD2R5+)DLG2RA+*4LJ2RM++$LM2RY++TLP2S%+,DLS2S1+-4LV2S=+.$LY
M2SI+.TL\2SU+/DL_2T!+04M"2T-+1$M%2T9+1TM(2TE+2DM+2TQ+34M.2T]+
M4$M12U)+4TM42U5+5DM72UA+64M:2UM+7$M=2UY+7TM@2V%+8DMC2V1+94MF
M2V=+:$MI2VI+:TML2VU+;DMO2W!+<4MR2W-+=$MU2W9+=TMX2WE+>DM[2WQ+
M?4M^2R%,(DPC3"1,)4PF3"=,*$PI3"I,*TPL3"U,+DPO3#!,,4PR3#-,-$PU
M3#9,-TPX3#E,.DP[3#Q,/4P^3#],0$Q!3$),0TQ$3$5,1DQ'3$A,24Q*3$M,
M3$Q-3$Y,3TQ03%%,4DQ33%1,54Q63%=,6$Q93%I,6TQ<3%U,7DQ?3&!,84QB
M3&-,9$QE3&9,9TQH3&E,:DQK3&Q,;4QN3&],<$QQ3'),<TQT3'5,=DQW3'A,
M>4QZ3'M,?$Q]3'Y,(4TB32--)$TE329-)TTH32E-*DTK32Q-+4TN32]-,$TQ
M33)-,TTT335--DTW33A-.4TZ33M-/$T]33Y-/TU`34%-0DU#341-14U&34=-
M2$U)34I-2TU,34U-3DU/35!-44U235--5$U5359-5TU835E-6DU;35Q-74U>
M35]-8$UA36)-8TUD365-9DUG36A-:4UJ36M-;$UM36Y-;TUP37%-<DUS371-
M=4UV37=->$UY37I->TU\37U-?DTA3B).)$XE3B9.)TXH3BE.(TXJ3BM.+$XM
M3BY.+TXP3C%.,DXS3C1.-4XV3C=..$XY3CI..TX\3CU./DX_3D!.04Y"3D-.
M1$Y%3D9.1TY(3DE.2DY+3DQ.34Y.3D].4$Y13E).4TY43E5.5DY73EA.64Y:
M3EM.7$Y=3EY.7TY@3F%.8DYC3F1.94YF3F=.:$YI3FI.:TYL3FU.;DYO3G!.
M<4YR3G-.=$YU3G9.=TYX3GE.>DY[3GQ.?4Y^3B%/(D\C3R1/)4\F3R=/*$\I
M3RI/*T\L3RU/+D\O3S!/,4\R3S-/-$\U3S9/-T\X3SE/.D\[3SQ//4\^3S]/
M0$]!3T)/0T]$3T5/1D]'3TA/24]*3TM/3$]-3TY/3T]03U%/4D]33U1/54]6
M3U=/6$]93UI/6T]<3UU/7D]?3V!/84]B3V-/9$]E3V9/9T]H3VE/:D]K3VQ/
M;4]N3V]/<$]Q3W)/=$]U3W9/<T]W3WA/>4]Z3WM/?$]]3WY/(5`B4"-0)%`E
M4"90)U`H4"E0*E`K4"Q0+E`O4#!0,5`M4#)0,U`T4#50-U`X4#E0.E`[4#90
M/%`]4#Y0/U!`4$%00E!#4$1015!&4$=02%!)4$I02U!,4$U03E!/4%!045!2
M4%-05%!54%905U!84%E06E!;4%Q075!>4%]08%!A4&)08U!D4&509E!G4&A0
M:5!J4&M0;%!M4&Y0;U!P4'%0<E!S4'10=5!V4'=0>%!Y4'I0>U!\4'U0?E`A
M42)1(U$D4251)E$G42A1*5$J42M1+%$M42Y1+U$P43%1,E$S4311-5$V43=1
M.%$Y43I1.U$\43U1/E$_44!105%"44-11%%%44911U%(44E12E%+44Q135%.
M44]14%%145)14U%445515E%745A165%:45M17%%=45Y17U%@46%18E%C4611
M95%F46=1:%%I46I1:U%L46U1;E%O47!1<5%R47-1=%%U4791=U%X47E1>E%[
M47Q1?5%^42%2(E(C4B12)5(F4B=2*%(I4BI2*U(L4BU2+E(O4C!2,5(R4C-2
M-%(U4C92-U(X4CE2.E([4CQ2/5(^4C]20%)!4D)20U)$4D521E)'4DA225)*
M4DM23%)-4DY23U)04E%24E)34E1255)64E=26%)94EI26U)<4EU27E)?4F!2
M85)B4F-29%)E4F929U)H4FE2:E)K4FQ2;5)N4F]2<%)Q4G)2<U)T4G92=U)X
M4G52>5)Z4GM2?%)]4GY2(5,B4R-3)%,E4R93)U,H4RE3*E,K4RQ3+5,N4R]3
M,%,Q4S)3,U,T4S53-E,W4SA3.5,Z4SM3/%,]4SY3/U-`4T%30E-#4T1315-&
M4T=32%-)4TI32U-,4TU33E-/4U!345-24U-35%-54U935U-84UE36E-;4UQ3
M75->4U]38%-A4V)38U-D4V539E-G4VA3:5-J4VM3;%-M4VY3;U-P4W%3<E-S
M4W13=5-V4W=3>%-Y4WI3>U-\4WU3?E,A5")4(U0D5"54)E0G5"A4*50J5"M4
M+%0M5"Y4+U0P5#%4,E0T5#54-E0W5#A4.50Z5#M4/%0]5#Y4,U0_5$!4051"
M5$-41%1%5$941U1(5$E42E1+5$Q4351.5$]44%115%)44U145%545E175%A4
M651:5%M47%1=5%Y47U1@5&%48E1C5&14951F5&=4:%1I5&I4;%1K5&U4;E1O
M5'!4<51R5'-4=%1U5'94=U1X5'E4>E1[5'Q4?51^5"%5(E4C5215)54F52=5
M*%4I52I5*U4L52U5+E4O53!5,54R53-5-%4U5395-U4X53E5.E4[53Q5/54^
M53]50%5!54)50U5$54551E5'54A5255*54M53%5-54Y53U5055%54E535515
M555655=56%5955I56U5<55U57E5?56!5855B56-59%5E56959U5H56E5:E5K
M56Q5;55N56]5<%5Q57)5<U5T5755=E5W57A5>55Z57M5?%5]57Y5(58B5B-6
M)%8E5B96)U8H5BE6*E8K5BQ6+58N5B]6,%8Q5C)6,U8T5C56-E8W5CA6.58Z
M5CM6/%8]5CY6/U9`5D%60E9#5D16159'5DA6259*5DM61E9,5DU63E9/5E!6
M45925E-65%965E=66%955EE66E9;5EQ6759>5E]68%9A5F)68U9D5F569E9G
M5FA6:59J5FM6;%9M5FY6;U9P5G%6<E9S5G16=59V5G=6>%9Y5GI6>U9\5GU6
M?E8A5R)7(U<D5R57)E<G5RA7*5<J5RM7+%<M5RY7+U<P5S%7,E<S5S17-5<V
M5S=7.%<Y5SI7.U<\5SU7/E<_5T!705="5T-71%=%5T971U=(5TE72E=+5TQ7
M35=.5T]74%=15U)74U=45U575E=75UA765=:5UM77%==5UY77U=@5V%78E=D
M5V579E=G5VA7:5=J5VM7;%=M5VY7;U=P5W%7<E=S5W17=5=V5W=7>%=Y5SY8
M8U=Z5WM7?%=]5WY7(5@B6"-8)%@E6"98)U@H6"E8*E@K6"Q8+5@N6"]8,%@Q
M6#)8,UA,6#18-5@V6#=8.%@Y6#I8.U@\6#U8/UA`6$%80EA#6$1815A&6$=8
M2%A)6$I82UA-6$Y83UA06%%84EA36%1855A66%=86%A96%I86UA<6%U87EA?
M6&!885AB6&-89%AE6&989UAH6&E8:EAK6&Q8;5AN6&]8<%AQ6')8<UAT6'58
M=EAW6'A8>5AZ6'M8?%A]6'Y8(5DB62-9)%DE6299)UDH62I9*UDL62U9+EDO
M63!9,5DR63-9-%DU6399-UDX63E9.ED[63Q9*5D]63Y9/UE`64%90EE#6419
M15E&64=92%E)64I92UE,64U93EE/65!945E265-95%E565995UE865E96EE;
M65Q975E>65]98%EA66)98UED66599EET66=9:%EI66I9:UEL66U9;EEO67!9
M<5ER67-9=5EV67=9>%EY67I9>UE\67U9?EDA6B):(UHD6B5:)EHG6BA:*5HJ
M6BM:+%HM6BY:+UHP6C%:,EHS6C1:-5HV6F8X-UHX6CE:.EH[6CQ:/5H^6C]:
M0%I!6D):0UI$6D5:1EI'6DA:25I*6DM:;5I,6DU:3EI/6E!:45I26E-:5%I5
M6E9:5UI86EE:6EI;6EQ:75I>6E]:8%IA6F):8UID6F5:9EIG6FA::5IJ6FM:
M;%IN6F]:<%IQ6G):<UIT6G5:=EIW6GA:>5IZ6GM:?%I]6GY:(5LB6R-;)%LE
M6R9;)ULH6RE;*ELK6RQ;+5LN6R];,%LQ6S);,ULT6S5;-ELW6SA;.5LZ6SM;
M/%L]6SY;/UM`6T%;0EM#6T1;15M&6T=;2%M)6TI;2UM,6TU;3EM/6U!;45M2
M6U-;5%M56U9;5UM86UE;6EM;6UQ;75M>6U];8%MA6V);8UMD6V5;9EMG6VA;
M:5MJ6VM;;%MM6VY;<%MQ6W);<UMO6W1;=5MV6W=;>%MY6WI;>UM\6WU;?ELA
M7")<(UPD7"5<)EPG7"A<*5PJ7"M<+%PM7"Y<+UPP7#%<,EPS7#1<-5PV7#=<
M.%PY7#I<.UP\7#U</EP_7$!<05Q"7$-<1%Q%7$9<1UQ(7$E<2EQ+7$Q<35Q.
M7$]<4%Q17%)<4UQ47%5<5EQ77%A<65Q:7%M<7%Q=7%Y<7UQ@7&%<8EQC7&1<
M95QF7&=<:%QI7&I<:UQL7&U<;EQO7'!<<5QR7'-<=%QU7'9<=UQX7'E<>EQ[
M7'Q<?5Q^7"%=(ETC721=)5TF72==*%TI72I=*UTL72U=+ETO73!=,5TR73-=
M-%TU739=-UTX73E=.ET[73Q=/5T^73]=0%U!74)=0UU$745=1EU'74A=25U*
M74M=3%U-74Y=3UU075%=4EU3751=55U675==6%U975I=6UU<75U=7EU?76!=
M85UB76-=9%UE769=9UUH76E=:EUK76Q=;5UN76]=<%UQ77)=<UUT775==EUW
M77A=>5UZ77M=?%U]77Y=(5XB7B->)%XE7B9>)UXH7BE>*EXK7BQ>+5XN7B]>
M,%XQ7C)>,UXT7C5>-EXW7CA>.5X_7CI>.UX\7CU>/EY`7D%>0EY#7D1>15Y&
M7D=>2%Y)7DY>2EY+7DQ>35Y/7E!>45Y27E->5%Y57E9>5UY87EE>6EY;7EQ>
M75Y>7E]>8%YA7F)>8UYD7F5>9EYG7FA>:5YJ7FM>;%YM7FY>;UYR7G!><5YS
M7G1>=5YV7G=>>%YY7GI>>UY\7GU>?EXA7R)?(U\D7R5?)E\G7RA?*5\J7RM?
M+%\M7RY?+U\P7S)?,5\S7S1?-5\V7S=?.%\Y7SI?.U\\7SU?/E\_7T!?05]"
M7T-?1%]%7T9?1U](7TE?2E]+7TQ?35].7T]?4%]17U)?4U]47U5?5E]77UA?
M65]:7UM?7%]=7V]?7E]?7V!?85]B7V-?9%]E7V9?9U]H7VE?:E]K7VQ?;5]N
M7W!?<5]R7W-?=%]U7W9?=U]X7WE?>E][7WQ??5]^7R%@(F`C8"1@)6`F8"=@
M*&`I8"I@*V`L8"U@+F`O8#!@,6`R8#-@-&`U8#9@-V`X8#E@.F`[8#Q@/6`^
M8#]@0&!!8$)@0V!$8$5@1F!'8$A@26!*8$M@3&!-8$Y@3V!08%%@4F!38%1@
M56!68%=@6&!98%I@6V!<8%U@9&!>8%]@8&!A8&)@8V!E8&9@9V!H8&E@:F!K
M8&Q@;6!N8&]@<&!Q8')@<V!T8'5@=F!W8'A@>6!Z8'M@?&!]8'Y@(6$B82-A
M)&$E829A)V$H82EA*F$K82QA+6$N82]A,&$Q83)A,V$T835A-F$W83AA.6$Z
M83MA/&$]83YA/V%`84%A0F%#841A16%&84=A2&%)84IA2V%,84UA3F%/85!A
M46%2851A56%685-A5V%885EA6F%;85QA76%>85]A8&%A86)A8V%D865A9F%G
M86AA:6%J86MA;&%M86YA;V%P87%A<F%S871A=6%V87=A>&%Y87IA>V%]87YA
M(6(B8B-B)&)\82UB)6(F8B=B*&(I8BIB*V(L8B]B,&(Q8C)B+F(S8C1B-6(V
M8C=B.&(Y8CIB.V(\8CUB/F(_8D!B06)"8D-B16)&8D1B1V)(8DEB2F)+8DQB
M36).8D]B4&)18E)B4V)48E5B5F)78EAB66):8EMB7&)=8EYB7V)@8F%B8F)C
M8F1B96)F8F=B:&)I8FIB:V)L8FUB;F)O8G!B<6)R8G-B=&)U8G9B=V)X8GEB
M>F)[8GQB?6)^8B%C(F,C8R1C)6,F8R=C*&,I8RIC*V,L8RUC+F,O8S!C,6,R
M8S-C-&,U8S9C-V,X8SEC.F,[8SQC/6,^8S]C0&-!8T)C0V-$8T5C1F-'8TAC
M26-*8TMC3&--8TYC3V-08U%C4F-38U1C56-68U=C6&-98UIC6V-<8UUC7F-?
M8V!C86-B8V-C9&-E8V9C9V-H8VEC:F-K8VQC;6-N8V]C<&-Q8W)C<V-T8W5C
M=F-W8WAC>6-Z8WMC?&-]8WYC(60B9"-D)&0E9"9D)V0H9"ED*F0K9"QD+60N
M9"]D,&0Q9#)D,V0T9#5D-F0W9#AD.60Z9#MD/&0]9#YD/V1`9$%D0F1#9$1D
M161&9$=D2&1)9$ID2V1,9$UD3F1/9%!D46129%-D5&159%9D5V189%ED6F1;
M9%QD761>9%]D8&1A9&)D8V1D9&5D9F1G9&AD:61J9&MD;&1M9&YD;V1P9'%D
M<F1S9'1D=61V9'=D>&1Y9'ID>V1\9'UD?F0A92)E(V4D925E)F4G92AE*64J
M92ME+&4M92YE+V4P93%E,F4S931E-64[939E-V4X93EE.F4\93UE/F4_94!E
M065"94-E1&5%949E1V5(94EE2F5+94QE365/95!E3F5195)E4V54955E5F57
M95AE665:95ME7&5=95YE7V5@96%E8F5C961E965F96AE9V5I96IE:V5L96UE
M;F5O97!E<65R97-E=&5U979E=V5X97EE>F5\97ME?65^92%F(F8C9B1F)68F
M9B=F*&8I9BIF*V8L9BUF+F8O9C!F,68R9C-F-&8U9C9F-V8X9CEF.F8[9CQF
M/68^9C]F0&9!9D)F0V9$9D5F1F9'9DAF269*9DMF3&9-9DYF3V909E%F4F93
M9E1F56969E=F6&999EIF6V9<9EUF7F9?9F!F869B9F-F9&9E9F9F9V9H9FEF
M:F9K9FQF;69N9F]F<&9Q9G)F<V9U9G9F=V9X9GEF>F9[9GQF?69^9B%G(F<C
M9R1G)6<F9R=G*&<I9RIG*V<L9RUG+F<O9S!G,6<R9S-G-&<U9S9G-V<X9SEG
M.F<[9SQG/6<^9S]G0&=!9T)G0V=$9T5G1F='9TAG26=*9TMG3&=-9TYG3V=0
M9U%G4F=39U1G56=69U=G6&=99UIG6V=<9UUG7F=?9V!G86=B9V-G9&=E9V9G
M:F=G9VAG:6=K9VQG;6=N9V]G<&=Q9W)G<V=T9W9G=V=X9WEG=6=Z9WMG?&=]
M9RAH?F<A:")H(V@D:"5H)F@G:"EH*F@K:"QH+6@N:"]H,&@Q:#)H,V@T:#5H
M-F@W:#AH.6@Z:#MH/&@]:#YH/VA`:$%H0FA#:$1H16A&:$=H2&A):$IH2VA,
M:$UH3FA/:%!H46A2:%-H5&A5:%9H5VA8:%EH6FA;:%QH76A>:%]H8&AA:&)H
M8VAD:&5H9FAG:&AH:6AJ:&MH;&AM:&YH;VAP:'%H<FAS:'1H=6AV:'=H>&AY
M:'IH>VA\:'UH?F@A:2)I(VDD:25I)FDG:2AI*6DJ:2MI+&DM:2YI+VDP:3%I
M,FDS:31I-6DV:3=I.&DY:3II.VD\:3UI/FD_:4!I06E":4-I1&E%:49I1VE(
M:4EI2FE,:4UI2VE.:4]I4&E1:5)I4VE4:55I5FE7:5AI66E::5MI7&E=:5YI
M7VE@:6%I8FEC:61I96EF:6=I:&EI:6II:VEL:6UI;FEO:7!I<6ER:7-I=&EU
M:79I=VEX:7EI>FE[:7QI?6E^:2%J(FHC:B1J)6HF:B=J*&HI:BIJ*VHL:BUJ
M+FHO:C!J,6HR:C-J-&HU:C9J-VHX:CEJ.FH[:CQJ/6H^:C]J0&I!:D)J0VI$
M:D5J1FI':DAJ26I*:DMJ3&I-:DYJ3VI0:E%J4FI3:E1J56I6:E=J6&I9:EIJ
M6VI<:EUJ7FI?:F!J86IB:F-J9&IE:F9J9VIH:FEJ:FIK:FQJ;6IN:F]J<&IQ
M:G)J<VIT:G5J=FIW:GAJ>6IZ:GMJ?&I]:GYJ(6LB:R-K)&LE:R9K)VLH:REK
M*FLK:RQK+6LN:R]K,&LQ:S)K,VLT:S5K-FLW:SAK.6LZ:SMK/&L]:SYK/VM`
M:T%K0FM#:T1K16M&:T=K2&M):U!K2FM+:TQK36M2:TYK3VM1:U-K5&M5:U9K
M5VM8:UEK6FM;:UQK7FM=:U]K8&MA:V)K8VMD:V5K9FMG:VAK:6MJ:VMK;6MN
M:V]K;&MP:W%K<FMS:W1K=FMU:W=K>&MY:WIK>VM\:WUK?FLA;")L(VPD;"5L
M)FPG;"AL*6PJ;"ML+&PM;"YL+VPP;#%L,FPS;#1L-6PV;#=L.&PY;#IL.VP\
M;#UL/FP_;$!L06Q";$-L1&Q%;$9L1VQ(;$EL2FQ+;$QL3FQ/;$UL4&Q1;%)L
M4VQ4;%5L5FQ7;%AL66Q:;%ML7&Q=;%YL7VQ@;&%L8FQC;&1L96QF;&=L:&QI
M;&IL:VQL;&UL;FQO;'!L<6QR;'-L=&QU;'9L=VQX;'EL>FQ[;'QL?6Q^;"%M
M(FTC;21M)6TF;2=M*&TI;2IM*VTL;2UM+FTO;3!M,6TR;3-M-&TU;39M-VTX
M;3EM.FT[;3QM/6T^;3]M0&U!;4)M0VU$;45M1FU';4AM26U*;4MM3&U-;4YM
M3VU0;5%M4FU3;51M56U6;5=M6&U9;5IM6VU<;5UM7FU?;6!M86UB;6-M-R*R
M%P``LA<``+(7``"R%P``LA<``+(7`$````D!-!`-`02`#P$8R14!(0`7`9,`
M&P$"%!X!"`,A`3"")0$`("8!P"`I`0"`*@$``BL!"``L`0$,+P$'@30!*N`Z
M`0T90`'D`D4!`$!&`:I*30$%&U,!5(%8`0E470&"9V0!-E9L`9W&=0$``'4!
MA'I\`6.[A@$$$(@!!0"*`06PCP&35)8!B7F>`81`H0$M"*8!9U2N`8Z"M`'-
M)+L!`P"]`5K$Q`%=V,T!!X32`0$FU@&94-P!&;'C`52#Z0%&1.X!R'GV`8%Z
M_0&(L0,".@,)`@2$#`*H@1$"4``3`@!`%`(82!@"`"$:`@H@'0(`U2("!($E
M`BY!*P(D0"X"G``R`B8`-0)L`3H"!`$\`B800`(@`D("H)5(`D-`3`*``T\"
M)114`N@56P+P@&`"P2UG`E&1;0)2&'("(A=X`M,`?0()'((""MF)`J`[D`(E
M<)8"!!B9`@`*FP(J,*`"!$*C`HA!IP(8(JL"$HRP`K0EMP(A@+H"+&3``L$`
MPP(@`,0"!`#%`@@$QP*"A<P",@#/`IB@U`(`0-4"U&K=`A"`WP(J(^4"8I#J
M`L)F\0*"CO<"0&3[`@``^P(!E/\"0-`#`R-S"P,@``P#``P.`V0X%`.")AD#
M`TT?`U,`(P,`@"0#1L$J`YX`+P,8(#(#!(`T`TI:.P..24(#!`)$`T"`1@,@
MY4P#!P)0`P`040.INEH#6ZIC`Q!`90-/HFT#)@!P`S`9=0,@YGL#P#N"`XI`
MA@,@OHT#`;*2`_(IF@/"`)T#AA2B`R(LIP,]UK$#&."V`V`PN@,$`+L#I.G#
M`[M>S@,*$-$#L/;:`X(3WP,`(>$#@)'E`R!@Z`/2(NX#8>'U`Q@S^P,`R/X#
MP2`"!`2"!00`L@D$(8`,!)(!$`0`D1,$@[<<!%$@(`1'`B4$!A`H!!1A+015
M)#,$!@(V!`@`-P1@&#L$'"`_!!J!1`1I@$D$2`!+!`SJ4@0*J%<$9!I=!`!8
M8`2D@&0$D.!I!(D4;@0:)70$!.!X!)C`?026`($$$7"&!`Q`B028)8\$`0"0
M!+`1E00A0)@$J""<!(!,H`0`"*$$2=*H!(40K`0NC;0$4(&X!``4N@0A1+X$
M8"#!!`,!Q`2`*L@$(B#+!!`!S00"&-`$1$#3!`#!U@0`\-H$4D3?!%L`Y`0`
ML^D$AA3N!`.@\@3`!_<$`8#Y!!(@_`0`$/T$@,``!4A:!@5E``H%```*!0`6
M#06,(Q,%,3P:!8"%'@4$H"$%300F!30$*@4`"BP%A"`O!0!`,`46`#,%0B`V
M!00`-P78"#P%$J)!!4P%1@4B@DH%%R10!0'&504*!5D%/(I@!8$(8P45`V@%
MB$AL!0$#;P41`G(%``-T!8$@=P4T@7P%`4%_!21`@@4`"H0%0UF+!0!]D04!
M`)(%`4B5!0``E04T%9L%"N"@!4!8I`4V4*H%(`BL!0``K`7$0;$%`#*T!1Y9
MO`51J,(%L2#'!1$)RP69@-`%-&77!0"BV@5`,-T%E)CC!0,!Y@60"^L%'T#Q
M!0;W^@5,%/\%@"0"!IB%"`80(`H&*``,!H$3$0;2(!8&@@`8!@+`&P9$12`&
M*F$F!C0!*@:#2"\&%,\W!C!J/08D`#\&)#%$!H042`;?4E(&!`Q5!N,"6P9B
M`E\&`$!@!@$08@8$F6<&&RAM!HRQ=`8A)7D&`!-\!@?`@08@\(8&IK*.!@``
MC@::`)(&*!"5!HT*FP8`(IT&7!"B!E<4J080H*P&""2O!@#@L@8!`+,&0`&U
M!LC$NP800+T&8`3`!@`$P084,,4&&"S*!DD!S@8`)M$&8!+5!EY,W08<">(&
M8##F!C*Q[0:4!/$&,4;W!E#@_`8`(/T&(D$!!SH0!@<A%`H'+`,/!P`&$0<5
M018'-88=!R&@(0<`B",''KPL!PL@,`<8*#0'H(`W!P.K/@=*$4,'".!'!Q!>
M30>C`%$',"96!Z&(6P<2AV$'6,IH!T1";`<"-'`'B`)S!Q6`=P>!"'H'`"1\
M!R($?P<D(8,'24"'!QR`BP<$0X\'48&4!P``E`<UPIL'$2.@!V9@I@=>7K`'
MBP*U!V%4NP>"&\$'`QS&!ZC;SP<!.-,'!9[:!Q$@W0<FB.('#='I!Q"([`<`
M6?`'``SR!Z!`]0<($O@'!0#Z!PA`_`>@$0`(,"`#"$!0!@A0"`D($L`-"$H+
M$P@``!,()S@:""T#(`B$$B0(0@`F",4"*P@``"L($*(O"("Q-`@+B#D(,!0]
M"*0)0@@`R$4()QY-"%0!40A`%54(*D9;"`0(70@@D6$(2S)H""`];@AC.'4(
M0`9X",L`?0@``'T(*@F"""1"A@B`"(@(>!./"`>,E0@!()<(1`&:"&*IH0B`
M%:4((`&G",(`J@@DP*X(*D"R"`N`M@@B)+H($0&]")7(Q`A@1LD(9PC/")`$
MT@@*0-4(R@K;"`+HX`@@B.,($^#I"$`3[0AQ,/,(D!#V"`<P^PC,@@$)@T@&
M"1"9"PE@B`\)0"02"40A%@F!2!H)(6`>"20`(`F`B",)#7,K"0%C,`D8$C0)
M0`0V"<I`.PF"@C\)-&)%"06"20G`44X):(Q4"0"L6`D4&ET)@*AA"5`+9@G@
M`FH)L)%P"0``<`D5`',)1*!W"5<4?@F!6H0)%`"&"9#$BPD*!(X)P,&3"0*2
MEPD``)<)@,":":*`G@D!$*`)A`"B"=8!J`D`%*H)D**O"1#%M`E`J+@))8*]
M"5$0P0D1`,,)`$#$"80`Q@E$&LL),(O1"9YPV0D,`=P)""C?"0`@X`D(`N()
M@6#F"0J(Z@F+Y?,)``#S"0!H]@D`*OD)$#7^"4`-`@I`I@<*21@,"@"`#0J.
M9A4*!A$9"@!@&PJ(.2$*780H"N'!+PIA$#,*H`4W"@!$.0H``SL*(3)`"N$@
M10J``$8*"8!)"I`230H83U0*,&!8"C!07`I@0%\*8@!B"O`):`H0"&H*DP!N
M"@`$;PIZ$78*$`!W"@`$>`KXF(`*`$"!"@&HA0H#`8@*X@R."H54E`H!`98*
M``*7"J$0FPH$#)X*!8"A"@V$I@H3&*L*2!:P"@``L`H`0;(*@0.V"HBDNPH0
MB+X*$`/!"B[`QPII5,X*"<G4"H*9V@H08MX*"`C@"@!AXPH20.8*@A+J"F"!
M[@H@`.\*&$ST"K0H^@H,0_\*E!$$"R8L"@L((`P+1>$3"\':&PN"$A\+:T`E
M"ZG1+0ME+#0+H+(Z"V":0`M,(D4+R@)*"["N4@N3!%<+`@Q:"U#_9`L#`F<+
MV2AN"X8@<@O$:7D+!@!["^."@@L'EXH+2\^4"R:*F@L`$YT+"<VD"Q"-J0L0
MG*X+0`"O"\0`L@N3AKD+0.*^"XE!PPN%P,@+`H#*"P)^T0LB`-,++1+9"Q0`
MVPL0A-X+4]#E"X"0Z`N3T.\+`@+Q"YV5^@ML>@,,:"((#"P7#PP[#A<,(((:
M###@'PP2`"$,(C`E#""X*@S])30,`"`U#"):.PP0`CT,01%!#$,21@Q!1$H,
MM!91#`3A5@QP8EP,9.1C#,30:0R5%&\,'21U#!$P>0QPA'X,A,2##")`A@P(
M`H@,)L*.#%$4DPP3"9@,8&*=#`(@GPP.8*0,H0"G#)A1K0P$4+`,&T6W#`!$
MN0P`A+L,$.'`#!(QQ0P/J,P,@%/1#&R(UPQ3!-P,S(SC#$$0Y@P!U.L,H2+P
M##*H]@QPC/P,$AD!#8`*!`T$6@D-`!@+#7H9$PT"BQ@-$@D<#92%(@U09"<-
M)2PM#0(1,`V,%C8-(D@Z#8*H/PTQ!T4-L!%*#6"R4`VA)%4-($%8#64,7@T3
M0&(-"1!E#2@::@U`4FX-`@AP#0`;=`T2:'D-@`!Z#1"`?`V([H0-$Z")#8-`
MC0T@`(X-4::5#8P`F`T00IL-0TB@#2&0I`UE/*P-)`6P#=`.M@T`!;@--%?`
M#5[:R@T`"LP-81'1#5H&UPU`!-D-+G[C#8IBZ0T%,NX-P(#Q#1!`\PU!`/4-
MP9S\#9"C`@ZX)@D.0`H,#B``#0Z(@Q(.3F`8#D@D'`X"<"`.@R$E#HHV+`Z@
M!"\.`8TT#FXY/0["8$(.P`1%#L@"20Y\<%$.@`)3#F0L60YB!EX.`0%@#J,P
M9@Z!L6P.2(!O#K!`<PX%@7<.)LA]#@A!@`[")(4.(F6+#@``BPX``(L.``"+
M#@``BPX``(L.``"+#@``BPX``(L.``"+#@#XD`Z8@)0.##B9#GH@GPX"X*,.
M`:BG#L,0K`Y&)+$.$)"T#@G!N0X`B+L.*-'!#@3DQ@Z`Y<P.6N#3#E%0V`ZQ
M5N`.$0#B#@``X@Y1(.8.(@#H#@)!ZPX`4.T.P`CP#@`#\@X`H?4.M`'Z#@%@
M_0Y-1@0/"`@&#\!1"P^1$`\/(103#Z`4%P^$`!D/@Z,@#X``(0]R2"</04DL
M#P1`+@\4"#$/*,PW#Z!H/`\2&$`/9Z-)#PF`3`\8)E$/!@%4#Q0$5P]XR%X/
M0A!A#XD@90\0J&D/FT9Q#U(-=P^;1X`/E=2(#T``B0\A!(P/%:63#\!@EP^#
M#9T/`.BA#P9PI@^)-*P/G&"R#_H`N`\``+@/`:&\#U4@P0\T.\D/P#+.#P#`
MT`^!@M0/$R#8#P`%V@]`$]X/0H3B#R("Y0\`@.8/``+G#Z"E[0]&%_0/L03Y
M#UDQ`!`B``(0+$`&$$"'"Q`29!`0A9$6$`@0&!"`A!L0ARPB$(Q0)Q`!4"H0
MO(PR$%R`-Q!`@#D03_)#$!>(21``KDX08II5$`BA61"E(%X0T/%F$(1,:Q``
MA6X002%R$$B0=A`Q8'L0!TN"$(("A1!`-8H01P".$,PCE1`?DIT0X`2A$``A
MHQ!"%:@0PB&M$+J#M1`K`+D0IA2_$*D`PQ``-,80L,C,$!G"TA`*P=<0!G;>
M$"D@XA``(>00,H#H$`8(ZQ#X&_00J4/[$(EP`1$BP`41`D<*$6"6$!$<+!81
M"H4;$4H.(1$=WRP1`&$O$244-!$J3SP18I5#$1$"1A$""DD1`0!*$0"=3Q$!
M!5(1`&15$0%\6Q$.2&`1@(!B$:,`9A%"X&L18!=Q$<$!=1$G1GP198*"$80<
MAQ$.2(P1*3R3$0`BE1$QF)L1(0"=$?$0HQ$``*,1\`&H$2`JK!%*HK(1L("V
M$39`NQ%5F,(1H&#&$:EBS1'(,=,1H@#6$>#.WA%)B.,1Q8+I$8#"[1'(2/(1
M2`?W$;J@_A$`$/\1<9`%$F`,"1("T`T2`"`.$H$0$1)\(1@2'$(=$@@@'Q)`
M4R02,J@J$C#0+Q(``"\2```O$@``+Q(``"\2```O$@``+Q(``"\2```O$@``
M+Q(`8S,2H(HX$IHK0!)8(T82:$A+$L`(3A(-&E02$`!5$@`&5Q)@BEP28")@
M$@*19!*EP6L2"@)N$H0(<1(``'$2``!Q$@``<1(``'$2(%)U$@"`=A(4(7H2
M(\!_$D&8A!*D&HH2X461$K("EA*P$)H2%R"?$G((I!)2`*<2SP"M$LHCM!(#
MZ+H2$'B_$@:RQ1(##LH2#`+-$B5LU!*$8MD2*`S=$IN`XQ(2$.82`&'I$H,&
M[A*%@?,2P4'X$JMQ`1/P!`83BX`+$SYA$Q,@`!03```4$P``%!,`(!43<P`:
M$V!!'A-#+"03+0`H$QE!+1-B2#(3%!$V$P`).!,`MSX3F(!"$Q@011,`*$<3
MQ!!+$Q$"3A,@65,3H0M9$R<`71-=8&03N!%J$Z2S<A,@B'434<!Z$W$A@!/1
M58@3K<*0$](VF!.(@9P3B`ZA$Y(@I1,0#JD3:D2O$SI!M1-"<;L33[C$$RP`
MQQ.81LT3,/;5$X,JVQ/S%N0333'K$WC!\A-I5_L3S>0$%`(S"12CPQ$4X;L;
M%`!G(!2$@B04L8DK%$2],Q3O>3\4J;-(%*M14!0!BE04!2%8%#+P7Q2R!F44
MV`!I%(`#;!2G1704L*9[%%ND@Q0'K8L4)$F0%%H+EQ1P!)L4\CZE%`C2JA3$
M`*T4@"^S%!;CNQ3@@+\4`,#!%!ZHR!0H%<T4()+1%`KIV!0&`-H4&`#<%```
MW!0``-P4``#<%```W!0``-P4``#<%```W!0``-P4``#<%```W!0``-P4``#<
M%```W!0``-P4`$/?%!!QY!0`X.<40AKL%%"D\11`"_44#^;^%%$``14```$5
M```!%0!@`Q5T$`@5BC<0%0(`$174`185`D`8%1#8'14>`B(50J0G%7#"+14(
M!"\5``0P%03E-A4`@C@5`@0Z%2P"/A4`+$$5#@%%%0H`1Q4*Q$P5H`U1%8A$
M517(J5P5`0)>%>#&914$4&@59M=R%;)V>Q63:X05$X"(%9(%C16`9)$54%*6
M%6G(G14M0*(5D`2E%<X&K!5L%+(5``"R%0``LA4``+(5`&BU%9&-O!4D$<`5
M``#`%>H$QA5(`,@5A`'+%>*<TQ7$"-<5/A[@%<-AYQ40V^X5`0#O%0``[Q4`
M`.\5`*CR%4``\Q4GIOL5"`+]%1A6`Q:`'`<6,6(-%AP8$A9#0!86G6`=%F@!
M(1:27"@64B`L%@``+!8``"P6```L%@``+!8`U#`6=,HX%DI!/1;E&$06L1)*
M%BRF418_>UT611IC%D$H9Q:X)FX6`!EQ%N!(=A9J?8`6J(.&%O&ND!819)46
MP!*9%H?9HA:"0:86@:&K%J",L!:(I[<6!8B[%D)7PA;,!\D6XB#.%CK&UA99
M^>`6"$_F%J4(ZQ8``.L6``#K%@``ZQ8``.L6``#K%@``ZQ9``.P6A`+O%@0(
M\1:"<?<6`(#X%ATT_Q:L!`07&(`'%RP.#1?!6!,76&09%^P!'Q<"5",7(I(H
M%X@&+!?PQ#,7H4HY%QE`/1>$1$$79S))%P``21<``$D7``!)%P``21<``$D7
M`!Q,%[W`5!=`25@7$-%=%SD`81=`"607((!F%Y!P:Q<G@7$7#()U%]>.?Q=$
MC(07EK:-%_H`DQ?H99L7`..@%RLDIA<`@*<7UT"N%RX`!P$```<!0``(`00`
M````````````````````````````````````````````````````````````
M``````!2Q@<``(4*`/__&@!^_R@`__\X`'__1P#__U<`S_]E`/?/<@#__X(`
M_S^0`/__H`#__[``_W^_````OP```+\```"_````OP``X,(`_Q_/````SP`@
M`-````#0````T````-````#0````T````-````#0````T````-````#0````
MT````-``@`#1```OU@```-8```#6````U@```-8```#6````U@```-8```#6
M````U@```-8`<-??``$`X```_.8``0#G``1\[0```.T```#M````[0#\W_H`
M``#Z````^@```/H```#Z`/S?```````````"3@1.!4X,3A).'TXC3B1.*$XK
M3BY.+TXP3C5.0$Y!3D1.1TY13EI.7$YC3FA.:4YT3G5.>4Y_3HU.EDZ73IU.
MKTZY3L-.T$[:3MM.X$[A3N).Z$[O3O%.\T[U3OU._D[_3@!/`D\#3PA/"T\,
M3Q)/%4\63Q=/&4\N3S%/8$\S3S5/-T\Y3SM//D]`3T)/2$])3TM/3$]23U1/
M5D]83U]/8T]J3VQ/;D]Q3W=/>$]Y3WI/?4]^3X%/@D^$3X5/B4^*3XQ/CD^0
M3Y)/DT^43Y=/F4^:3YY/GT^R3[=/N4^[3[Q/O4^^3\!/P4_%3\9/R$_)3\M/
MS$_-3\]/TD_<3^!/XD_P3_)/_$_]3_]/`%`!4`10!U`*4`Q0#E`04!-0%U`8
M4!M0'%`=4!Y0(E`G4"Y0,%`R4#-0-5!`4$%00E!%4$902E!,4$Y045!24%-0
M5U!94%]08%!B4&-09E!G4&I0;5!P4'%0.U"!4(-0A%"&4(I0CE"/4)!0DE"3
M4)10EE";4)Q0GE"?4*!0H5"B4*I0KU"P4+E0NE"]4,!0PU#$4,=0S%#.4-!0
MTU#44-A0W%#=4-]0XE#D4.90Z%#I4.]0\5#V4/I0_E`#4091!U$(40M1#%$-
M40Y1\E`041=1&5$;41Q1'5$>42-1)U$H42Q1+5$O43%1,U$T4351.%$Y44)1
M2E%/45-155%745A17U%D4691?E&#4811BU&.49A1G5&A4:-1K5&X4;I1O%&^
M4;]1PE'(4<]1T5'24=-1U5'84=Y1XE'E4>Y1\E'S4?11]U$!4@)2!5(24A-2
M%5(64AA2(E(H4C%2,E(U4CQ215))4E525U)84EI27%)?4F!285)F4FY2=U)X
M4GE2@%*"4H52BE*,4I-2E5*64I=2F%*:4IQ2I%*E4J92IU*O4K!2ME*W4KA2
MNE*[4KU2P%+$4L92R%+,4L]2T5+44M92VU+<4N%2Y5+H4NE2ZE+L4O!2\5+T
M4O92]U(`4P-3"E,+4PQ3$5,34QA3&U,<4QY3'U,E4R=3*%,I4RM3+%,M4S!3
M,E,U4SQ3/5,^4T)33%-+4UE36U-A4V-395-L4VU3<E-Y4WY3@U.'4XA3CE.3
M4Y13F5.=4Z%3I%.J4ZM3KU.R4[13M5.W4[A3NE.]4\!3Q5//4])3TU/54]I3
MW5/>4^!3YE/G4_53`E035!I4(50G5"A4*E0O5#%4-%0U5$-41%1'5$U43U1>
M5&)49%1F5&=4:51K5&U4;E1T5']4@52#5(54B%2)5(U4D5255)94G%2?5*%4
MIE2G5*E4JE2M5*Y4L52W5+E4NE2[5+]4QE3*5,U4SE3@5.I4[%3O5/94_%3^
M5/]4`%4!5055"%4)50Q5#54.5155*E4K53)5-54V53M5/%4]54%51U5)54I5
M355055%56%5:55M57E5@56%59%5F57]5@56"5895B%6.58]5D56259-5E%67
M5:-5I%6M5;)5OU7!5<-5QE7)5<M5S%7.5=%5TE735==5V%7;5=Y5XE7I5?95
M_U4%5@A6"E8-5@Y6#U805A%6$E895BQ6,%8S5C56-U8Y5CM6/%8]5C]60%9!
M5D-61%9&5DE62U9-5D]65%9>5F!6859B5F-69E9I5FU6;U9Q5G)6=5:$5H56
MB%:+5HQ6E5:95II6G5:>5I]6IE:G5JA6J5:K5JQ6K5:Q5K-6MU:^5L56R5;*
M5LM6SU;05LQ6S5;95MQ6W5;?5N%6Y%;E5N96YU;H5O%6ZU;M5O96]U8!5P)7
M!U<*5PQ7$5<55QI7&U<=5R!7(E<C5R17)5<I5RI7+%<N5R]7,U<T5SU7/E<_
M5T571E=,5TU74E=B5V579U=H5VM7;5=N5V]7<%=Q5W-7=%=U5W=7>5=Z5WM7
M?%=^5X%7@U>,5Y17EU>95YI7G%>=5YY7GU>A5Y57IU>H5ZE7K%>X5[U7QU?(
M5\Q7SU?55]U7WE?D5^97YU?I5^U7\%?U5_97^%?]5_Y7_U<#6`18"%@)6.%7
M#%@-6!M8'E@?6"!8)E@G6"U8,E@Y6#]825A,6$U83UA06%587UAA6&189UAH
M6'A8?%A_6(!8@5B'6(A8B5B*6(Q8C5B/6)!8E%B66)U8H%BA6*)8IEBI6+%8
MLEC$6+Q8PEC(6,U8SEC06-)8U%C66-I8W5CA6.)8Z5CS6`59!ED+60Q9$ED3
M6119088=62%9(UDD62A9+UDP63-9-5DV63]90UE&65)94UE965M975E>65]9
M85EC66M9;5EO67)9=5EV67E9>UE\68M9C%F.69)9E5F769]9I%FG6:U9KEFO
M6;!9LUFW6;I9O%G!6<-9Q%G(6<I9S5G26=U9WEG?6>-9Y%GG6>Y9[UGQ6?)9
M]%GW60!:!%H,6@U:#EH26A-:'EHC6B1:)UHH6BI:+5HP6D1:15I'6DA:3%I0
M6E5:7EIC6F5:9UIM6G=:>EI[6GY:BUJ06I-:EEJ96IQ:GEJ?6J!:HEJG6JQ:
ML5JR6K-:M5JX6KI:NUJ_6L1:QEK(6L]:VEK<6N!:Y5KJ6NY:]5KV6OU:`%L!
M6PA;%ULT6QE;&UL=6R%;)5LM6SA;05M+6TQ;4EM66UY;:%MN6V];?%M]6WY;
M?UN!6X1;AEN*6XY;D%N16Y-;E%N66ZA;J5NL6ZU;KUNQ6[);MUNZ6[Q;P%O!
M6\U;SUO66]=;V%O96]I;X%OO6_%;]%O]6PQ<%UP>7!]<(UPF7"E<*UPL7"Y<
M,%PR7#5<-EQ97%I<7%QB7&-<9UQH7&E<;5QP7'1<=5QZ7'M<?%Q]7(=<B%R*
M7(]<DER=7)]<H%RB7*-<IERJ7+)<M%RU7+I<R5S+7-)<W5S77.Y<\5SR7/1<
M`5T&70U=$ETK72-=)%TF72==,5TT73E=/5T_74)=0UU&74A=55U175E=2EU?
M76!=85UB761=:EUM77!=>5UZ77Y=?UV!78-=B%V*79)=DUV4795=F5V;79]=
MH%VG7:M=L%VT7;A=N5W#7<==RUW07<Y=V%W97>!=Y%WI7?A=^5T`7@=>#5X2
M7A1>%5X87A]>(%XN7BA>,EXU7CY>2UY07DE>45Y67EA>6UY<7EY>:%YJ7FM>
M;%YM7FY><%Z`7HM>CEZB7J1>I5ZH7JI>K%ZQ7K->O5Z^7K]>QE[,7LM>SE[1
M7M)>U%[57MQ>WE[E7NM>`E\&7P=?"%\.7QE?'%\=7R%?(E\C7R1?*%\K7RQ?
M+E\P7S1?-E\[7SU?/U]`7T1?15]'7TU?4%]47UA?6U]@7V-?9%]G7V]?<E]T
M7W5?>%]Z7WU??E^)7XU?CU^67YQ?G5^B7Z=?JU^D7ZQ?KU^P7[%?N%_$7\=?
MR%_)7\M?T%_17])?TU_47]Y?X5_B7^A?Z5_J7^Q?[5_N7^]?\E_S7_9?^E_\
M7P=@"F`-8!-@%&`78!A@&F`?8"1@+6`S8#5@0&!'8$A@26!,8%%@5&!68%=@
M76!A8&=@<6!^8']@@F"&8(A@BF".8)%@DV"58)A@G6">8*)@I&"E8*A@L&"Q
M8+=@NV"^8,)@Q&#(8,E@RF#+8,Y@SV#48-5@V6#;8-U@WF#B8.5@\F#U8/A@
M_&#]8`)A!V$*80QA$&$181)A$V$4819A%V$981QA'F$B82IA*V$P83%A-6$V
M83=A.6%!845A1F%)85YA8&%L87)A>&%[87QA?V&`88%A@V&$88MAC6&289-A
MEV&889QAG6&?8:!AI6&H8:IAK6&X8;EAO&'`8<%APF'.8<]AU6'<8=UAWF'?
M8>%AXF'G8>EAY6'L8>UA[V$!8@-B!&('8A-B%6(<8B!B(F(C8B=B*6(K8CEB
M/6)"8D-B1&)&8DQB4&)18E)B5&)68EIB7&)D8FUB;V)S8GIB?6*-8HYBCV*0
M8J9BJ&*S8K9BMV*Z8KYBOV+$8LYBU6+68MIBZF+R8O1B_&+]8@-C!&,*8PMC
M#6,08Q-C%F,88REC*F,M8S5C-F,Y8SQC06-"8T-C1&-&8TIC2V-.8U)C4V-4
M8UAC6V-E8V9C;&-M8W%C=&-U8WAC?&-]8W]C@F.$8X=CBF.08Y1CE6.98YIC
MGF.D8Z9CK6.N8Z]CO6/!8\5CR&/.8]%CTV/48]5CW&/@8^5CZF/L8_)C\V/U
M8_AC^6,)9`ID$&029!1D&&0>9"!D(F0D9"5D*60J9"]D,&0U9#UD/V1+9$]D
M46129%-D5&1:9%MD7&1=9%]D8&1A9&-D;61S9'1D>V1]9(5DAV2/9)!DD628
M9)EDFV2=9)]DH62C9*9DJ&2L9+-DO62^9+]DQ&3)9,IDRV3,9,YDT&319-5D
MUV3D9.5DZ63J9.UD\&3U9/=D^V3_9`%E!&4(90EE"F4/91-E%&4691EE&V4>
M91]E(F4F92EE+F4Q93IE/&4]94-E1V5)95!E4F5495]E8&5G96ME>F5]98%E
MA66*99)EE66899UEH&6C9:9EKF6R9;-EM&6_9<)ER&7)9<YET&749=9EV&7?
M9?!E\F7T9?5E^67^9?]E`&8$9@AF"68-9A%F$F859A9F'68>9B%F(F8C9B1F
M)F8I9BIF*V8L9BYF,&8Q9C-F.68W9D!F169&9DIF3&919DYF5V989EEF6V9<
M9F!F86;[9FIF:V9L9GYF<V9U9G]F=V9X9GEF>V:`9GQFBV:,9HUFD&:29IEF
MFF:;9IQFGV:@9J1FK6:Q9K)FM6:[9K]FP&;"9L-FR&;,9LYFSV;49MMFWV;H
M9NMF[&;N9OIF!6<'9PYG$V<99QQG(&<B9S-G/F=%9T=G2&=,9U1G56==9V9G
M;&=N9W1G=F=[9X%GA&>.9X]GD6>39Y9GF&>99YMGL&>Q9[)GM6>[9[QGO6?Y
M9\!GPF?#9\5GR&?)9])GUV?99]QGX6?F9_!G\F?V9_=G4F@4:!EH'6@?:"AH
M)V@L:"UH+V@P:#%H,V@[:#]H1&A%:$IH3&A5:%=H6&A;:&MH;FAO:'!H<6AR
M:'5H>6AZ:'MH?&B":(1HAFB(:)9HF&B::)QHH6BC:*5HJ6BJ:*YHLFB[:,5H
MR&C,:,]HT&C1:--HUFC9:-QHW6CE:.AHZFCK:.QH[6CP:/%H]6CV:/MH_&C]
M:`9I"6D*:1!I$6D3:19I%VDQ:3-I-6DX:3MI0FE%:4EI3FE7:5MI8VED:65I
M9FEH:6EI;&EP:7%I<FEZ:7MI?VF`:8UIDFF6:9AIH6FE::9IJ&FK::UIKVFW
M:;AINFF\:<5IR&G1:=9IUVGB:>5I[FGO:?%I\VGU:?YI`&H!:@-J#VH1:A5J
M&FH=:B!J)&HH:C!J,FHT:C=J.VH^:C]J16I&:DEJ2FI.:E!J46I2:E5J5FI;
M:F1J9VIJ:G%J<VI^:H%J@VJ&:H=JB6J+:I%JFVJ=:IYJGVJE:JMJKVJP:K%J
MM&J]:KYJOVK&:LEJR&K,:M!JU&K5:M9JW&K=:N1JYVKL:O!J\6KR:OQJ_6H"
M:P-K!FL':PEK#VL0:Q%K%VL;:QYK)&LH:RMK+&LO:S5K-FL[:S]K1FM*:TUK
M4FM6:UAK76M@:V=K:VMN:W!K=6M]:WYK@FN%:Y=KFVN?:Z!KHFNC:ZAKJ6NL
M:ZUKKFNP:[AKN6N]:[YKPVO$:\EKS&O6:]IKX6OC:^9KYVON:_%K]VOY:_]K
M`FP$;`5L"6P-;`YL$&P2;!EL'VPF;"=L*&PL;"YL,VPU;#9L.FP[;#]L2FQ+
M;$UL3VQ2;%1L66Q;;%QL:VQM;&]L=&QV;'AL>6Q[;(5LAFR';(ELE&R5;)=L
MF&R<;)]LL&RR;+1LPFS&;,ULSVS0;-%LTFS4;-9LVFS<;.!LYVSI;.ML[&SN
M;/)L]&P$;0=M"FT.;0]M$6T3;1IM)FTG;2AM9VPN;2]M,6TY;3QM/VU7;5YM
M7VUA;65M9VUO;7!M?&V";8=MD6V2;91MEFV7;9AMJFVL;;1MMVVY;;UMOVW$
M;<AMRFW.;<]MUFW;;=UMWVW@;>)MY6WI;>]M\&WT;?9M_&T`;@1N'FXB;B=N
M,FXV;CEN.VX\;D1N16Y(;DEN2VY/;E%N4FY3;E1N5VY<;EUN7FYB;F-N:&YS
M;GMN?6Z-;I-NF6Z@;J=NK6ZN;K%NLVZ[;K]NP&[!;L-NQV[(;LINS6[.;L]N
MZV[M;NYN^6[[;OUN!&\(;PIO#&\-;Q9O&&\:;QMO)F\I;RIO+V\P;S-O-F\[
M;SQO+6]/;U%O4F]3;U=O66]:;UUO7F]A;V)O:&]L;WUO?F^#;X=OB&^+;XQO
MC6^0;Y)ODV^4;Y9OFF^?;Z!OI6^F;Z=OJ&^N;Z]OL&^U;[9OO&_%;\=OR&_*
M;]IOWF_H;^EO\&_U;_EO_&_];P!P!7`&<`=P#7`7<"!P(W`O<#1P-W`Y<#QP
M0W!$<$AP27!*<$MP5'!5<%UP7G!.<&1P97!L<&YP=7!V<'YP@7"%<(9PE'"5
M<)9PEW"8<)MPI'"K<+!PL7"T<+=PRG#1<--PU'#5<-9PV'#<<.1P^G`#<01Q
M!7$&<0=Q"W$,<0]Q'G$@<2MQ+7$O<3!Q,7$X<4%Q17%&<4=Q2G%+<5!Q4G%7
M<5IQ7'%><6!Q:'%Y<8!QA7&'<8QQDG&:<9MQH'&B<:]QL'&R<;-QNG&_<<!Q
MP7'$<<MQS''3<=9QV7':<=QQ^''^<0!R!W((<@ER$W(7<AIR'7(?<B1R*W(O
M<C1R.'(Y<D%R0G)#<D5R3G)/<E!R4W)5<E9R6G)<<EYR8')C<FAR:W)N<F]R
M<7)W<GAR>W)\<G]RA'*)<HURCG*3<IMRJ'*M<JYRL7*T<KYRP7+'<LERS'+5
M<M9RV'+?<N5R\W+T<OIR^W+^<@)S!',%<P=S"W,-<Q)S$W,8<QES'G,B<R1S
M)W,H<RQS,7,R<S5S.G,[<SUS0W--<U!S4G-6<UAS77-><U]S8'-F<V=S:7-K
M<VQS;G-O<W%S=W-Y<WQS@'.!<X-SA7.&<XYSD'.3<Y5SEW.8<YQSGG.?<Z!S
MHG.E<Z9SJG.K<ZUSM7.W<[ESO'.]<[]SQ7/&<\ESRW/,<\]STG/3<]9SV7/=
M<^%SXW/F<^=SZ7/T<_5S]W/Y<_IS^W/]<_]S`'0!=`1T!W0*=!%T&G0;="1T
M)G0H="ET*G0K="QT+70N="]T,'0Q=#ET0'1#=$1T1G1'=$MT3711=%)T5W1=
M=&)T9G1G=&AT:W1M=&YT<71R=(!T@72%=(9TAW2)=(]TD'21=))TF'29=)IT
MG'2?=*!TH72C=*9TJ'2I=*ITJW2N=*]TL72R=+5TN72[=+]TR'3)=,QTT'33
M=-ATVG3;=-YTWW3D=.ATZG3K=.]T]'3Z=/MT_'3_=`9U$G46=1=U('4A=21U
M)W4I=2IU+W4V=3EU/74^=3]U0'5#=4=U2'5.=5!U4G57=5YU7W5A=6]U<75Y
M=7IU>W5\=7UU?G6!=85UD'62=9-UE769=9QUHG6D=;1UNG6_=<!UP77$=<9U
MS'7.=<]UUW7<==]UX'7A=>1UYW7L=>YU[W7Q=?EU`'8"=@-V!'8'=@AV"G8,
M=@]V$G83=A5V%G89=AMV''8==AYV(W8E=B9V*78M=C)V,W8U=CAV.78Z=CQV
M2G9`=D%V0W9$=D5V279+=E5V679?=F1V979M=FYV;W9Q=G1V@7:%=HQVC7:5
M=IMVG':==I]VH':B=J-VI':E=J9VIW:H=JIVK7:]=L%VQ7;)=LMVS';.=M1V
MV7;@=N9VZ';L=O!V\7;V=OEV_'8`=P9W"G<.=Q)W%'<5=Q=W&7<:=QQW(G<H
M=RUW+G<O=S1W-7<V=SEW/7<^=T)W17=&=TIW37=.=T]W4G=6=U=W7'=>=U]W
M8'=B=V1W9W=J=VQW<'=R=W-W='=Z=WUW@'>$=XQWC7>4=Y5WEG>:=Y]WHG>G
M=ZIWKG>O=[%WM7>^=\-WR7?1=])WU7?9=]YWWW?@=^1WYG?J=^QW\'?Q=_1W
M^'?[=P5X!G@)>`UX#G@1>!UX(7@B>"-X+7@N>#!X-7@W>$-X1'A'>$AX3'A.
M>%)X7'A>>&!X87AC>&1X:'AJ>&YX>GA^>(IXCWB4>)AXH7B=>)YXGWBD>*AX
MK'BM>+!XL7BR>+-XNWB]>+]XQWC(>,EXS'C.>-)XTWC5>-9XY'C;>-]XX'CA
M>.9XZGCR>/-X`'GV>/=X^GC[>/]X!GD,>1!Y&GD<>1YY'WD@>25Y)WDI>2UY
M,7DT>35Y.WD]>3]Y1'E%>49Y2GE+>4]Y47E4>5AY6WE<>6=Y:7EK>7)Y>7E[
M>7QY?GF+>8QYD7F3>91YE7F6>9AYFWF<>:%YJ'FI>:MYKWFQ>;1YN'F[><)Y
MQ'G'><AYRGG/>=1YUGG:>=UYWGG@>>)YY7GJ>>MY[7GQ>?AY_'D">@-Z!WH)
M>@IZ#'H1>A5Z&WH>>B%Z)WHK>BUZ+WHP>C1Z-7HX>CEZ.GI$>D5Z1WI(>DQZ
M57I6>EEZ7'I=>E]Z8'IE>F=Z:GIM>G5Z>'I^>H!Z@GJ%>H9ZBGJ+>I!ZD7J4
M>IYZH'JC>JQZLWJU>KEZNWJ\>L9ZR7K,>LYZT7K;>NAZZ7KK>NQZ\7KT>OMZ
M_7K^>@=[%'L?>R-[)WLI>RI[*WLM>RY[+WLP>S%[-'L]>S][0'M!>T=[3GM5
M>V![9'MF>VE[:GMM>V][<GMS>W=[A'N)>XY[D'N1>Y9[FWN>>Z![I7NL>Z][
ML'NR>[5[MGNZ>[M[O'N]>\)[Q7O(>\I[U'O6>]=[V7O:>]M[Z'OJ>_)[]'OU
M>_A[^7OZ>_Q[_GL!?`)\`WP$?`9\"7P+?`Q\#GP/?!E\&WP@?"5\)GPH?"Q\
M,7PS?#1\-GPY?#I\1GQ*?%5\47Q2?%-\67Q:?%M\7'Q=?%Y\87QC?&=\:7QM
M?&Y\<'QR?'E\?'Q]?(9\AWR/?)1\GGR@?*9\L'RV?+=\NGR[?+Q\OWS$?,=\
MR'S)?,U\SWS3?-1\U7S7?-E\VGS=?.9\Z7SK?/5\`WT'?0A]"7T/?1%]$GT3
M?19]'7T>?2-])GTJ?2U],7T\?3U]/GU`?4%]1WU(?4U]47U3?5=]67U:?5Q]
M77UE?6=]:GUP?7A]>GU[?7]]@7V"?8-]A7V&?8A]BWV,?8U]D7V6?9=]G7V>
M?:9]IWVJ?;-]MGVW?;E]PGW#?<1]Q7W&?<Q]S7W.?==]V7T`?N)]Y7WF?>I]
MZWWM??%]]7WV??E]^GT(?A!^$7X5?A=^''X=?B!^)WXH?BQ^+7XO?C-^-GX_
M?D1^17Y'?DY^4'Y2?EA^7WYA?F)^97YK?FY^;WYS?GA^?GZ!?H9^AWZ*?HU^
MD7Z5?IA^FGZ=?IY^/'\[?SU_/G\_?T-_1']'?T]_4G]3?UM_7']=?V%_8W]D
M?V5_9G]M?W%_?7]^?W]_@'^+?XU_CW^0?Y%_EG^7?YQ_H7^B?Z9_JG^M?[1_
MO'^_?\!_PW_(?\Y_SW_;?]]_XW_E?^A_['_N?^]_\G_Z?_U__G__?P>`"(`*
M@`V`#H`/@!&`$X`4@!:`'8`>@!^`((`D@":`+(`N@#"`-(`U@#>`.8`Z@#R`
M/H!`@$2`8(!D@&:`;8!Q@'6`@8"(@(Z`G(">@*:`IX"K@+B`N8#(@,V`SX#2
M@-2`U8#7@-B`X(#M@.Z`\(#R@/.`]H#Y@/J`_H`#@0N!%H$7@1B!'($>@2"!
M)($G@2R!,($U@3J!/(%%@4>!2H%,@5*!5X%@@6&!9X%H@6F!;8%O@7>!@8&0
M@82!A8&&@8N!CH&6@9B!FX&>@:*!KH&R@;2!NX'+@<.!Q8'*@<Z!SX'5@=>!
MVX'=@=Z!X8'D@>N![('P@?&!\H'U@?:!^('Y@?V!_X$`@@."#X(3@A2"&8(:
M@AV"(8(B@BB",H(T@CJ"0X)$@D6"1H)+@DZ"3X)1@E:"7()@@F."9X)M@G2"
M>X)]@G^"@(*!@H."A(*'@HF"BH*.@I&"E(*6@IB"FH*;@J""H8*C@J2"IX*H
M@JF"JH*N@K""LH*T@K>"NH*\@KZ"OX+&@M""U8+:@N""XH+D@NB"ZH+M@N^"
M]H+W@OV"_H(`@P&#!X,(@PJ#"X-4@QN#'8,>@Q^#(8,B@RR#+8,N@S"#,X,W
M@SJ#/(,]@T*#0X-$@T>#38-.@U&#58-6@U>#<(-X@WV#?X.`@X*#A(.&@XV#
MDH.4@Y6#F(.9@YN#G(.=@Z:#IX.I@ZR#OH._@\"#QX/)@\^#T(/1@]2#W8-3
M@^B#ZH/V@_B#^8/\@P&$!H0*A`^$$805A!F$K8,OA#F$181'A$B$2H1-A$^$
M4812A%:$6(19A%J$7(1@A&2$981GA&J$<(1SA'2$=H1XA'R$?82!A(6$DH23
MA)6$GH2FA*B$J82JA*^$L82TA+J$O82^A,"$PH3'A,B$S(3/A-.$W(3GA.J$
M[X3PA/&$\H3WA#*%^H3[A/V$`H4#A0>%#(4.A1"%'(4>A2*%(X4DA26%)X4J
MA2N%+X4SA32%-H4_A4:%3X50A5&%4H53A5:%685<A5V%7H5?A6"%885BA62%
M:X5OA7F%>H5[A7V%?X6!A86%AH6)A8N%C(6/A9.%F(6=A9^%H(6BA:6%IX6T
MA;:%MX6XA;R%O86^A;^%PH7'A<J%RX7.A:V%V(7:A=^%X(7FA>B%[87SA?:%
M_(7_A0"&!(8%A@V&#H80AA&&$H88AAF&&X8>AB&&)X8IAC:&.(8ZACR&/89`
MAD*&1H92AE.&5H97AEB&689=AF"&889BAF.&9(9IAFR&;X9UAG:&=X9ZAHV&
MD8:6AIB&FH:<AJ&&IH:GAJB&K8:QAK.&M(:UAK>&N(:YAK^&P(;!AL.&Q8;1
MAM*&U8;7AMJ&W(;@AN.&Y8;GAHB&^H;\AOV&!(<%AP>'"X<.AP^'$(<3AQ2'
M&8<>AQ^'(8<CARB'+H<OAS&',H<YASJ'/(<]ASZ'0(=#AT6'38=8AUV'88=D
MAV6';X=QAW*'>X>#AX2'A8>&AX>'B(>)AXN'C(>0AY.'E8>7AYB'F8>>AZ"'
MHX>GAZR'K8>NA[&'M8>^A[^'P8?(A\F'RH?.A]6'UH?9A]J'W(??A^*'XX?D
MA^J'ZX?MA_&'\X?XA_J'_X<!B`.(!H@)B`J("X@0B!F($H@3B!2(&(@:B!N(
M'(@>B!^(*(@MB"Z(,(@RB#6(.H@\B$&(0XA%B$B(28A*B$N(3HA1B%6(5HA8
MB%J(7(A?B&"(9(AIB'&(>8A[B("(F(B:B)N(G(B?B*"(J(BJB+J(O8B^B,"(
MRHC+B,R(S8C.B-&(THC3B-N(WHCGB.^(\(CQB/6(]X@!B0:)#8D.B0^)%8D6
MB1B)&8D:B1R)((DFB2>)*(DPB3&),HDUB3F).HD^B4")0HE%B4:)28E/B5*)
M5XE:B5N)7(EAB6*)8XEKB6Z)<(ESB76)>HE[B7R)?8F)B8V)D(F4B96)FXF<
MB9^)H(FEB;")M(FUB;:)MXF\B=2)U8G6B=>)V(GEB>F)ZXGMB?&)\XGVB?F)
M_8G_B02*!8H'B@^*$8H2BA2*%8H>BB"*(HHDBB:**XHLBB^*-8HWBCV*/HI`
MBD.*18I'BDF*38I.BE.*5HI7BEB*7(I=BF&*98IGBG6*=HIWBGF*>HI[BGZ*
M?XJ`BH.*AHJ+BH^*D(J2BI:*EXJ9BI^*IXJIBJZ*KXJSBK:*MXJ[BKZ*PXK&
MBLB*R8K*BM&*TXK4BM6*UXK=BM^*[(KPBO2*]8KVBOR*_XH%BP:+"XL1BQR+
M'HL?BPJ++8LPBS>+/(M"BT.+1(M%BT:+2(M2BU.+5(M9BTV+7HMCBVV+=HMX
MBWF+?(M^BX&+A(N%BXN+C8N/BY2+E8N<BYZ+GXLXC#F,/8P^C$6,1XQ)C$N,
M3XQ1C%.,5(Q7C%B,6XQ=C%F,8XQDC&:,:(QIC&V,<XQUC':,>XQ^C(:,AXR+
MC)",DHR3C)F,FXR<C*2,N8RZC,6,QHS)C,N,SXS6C-6,V8S=C.&,Z(SLC.^,
M\(SRC/6,]XSXC/Z,_XP!C0.-"8T2C1>-&XUEC6F-;(UNC7^-@HV$C8B-C8V0
MC9&-E8V>C9^-H(VFC:N-K(VOC;*-M8VWC;F-NXW`C<6-QHW'C<B-RHW.C=&-
MU(W5C=>-V8WDC>6-YXWLC?"-O(WQC?*-](W]C0&.!(X%C@:."XX1CA2.%HX@
MCB&.(HXCCB:.)XXQCC..-HXWCCB..8X]CD".08Y+CDV.3HY/CE2.6XY<CEV.
M7HYACF*.:8YLCFV.;XYPCG&.>8YZCGN.@HZ#CHF.D(Z2CI6.FHZ;CIV.GHZB
MCJ>.J8ZMCJZ.LXZUCKJ.NX[`CL&.PX[$CL>.SX[1CM2.W([HCNZ.\([QCO>.
M^8[ZCNV.`(\"CP>/"(\/CQ"/%H\7CQB/'H\@CR&/(X\ECR>/*(\LCRV/+H\T
MCS6/-H\WCSJ/0(]!CT./1X]/CU&/4H]3CU2/58]8CUV/7H]ECYV/H(^ACZ2/
MI8^FC[6/MH^XC[Z/P(_!C\:/RH_+C\V/T(_2C]./U8_@C^./Y(_HC^Z/\8_U
MC_:/^X_^CP*0!)`(D`R0&)`;D"B0*9`OD"J0+)`MD#.0-)`WD#^00Y!$D$R0
M6Y!=D&*09I!GD&R0<)!TD'F0A9"(D(N0C)".D)"0E9"7D)B0F9";D*"0H9"B
MD*60L)"RD+.0M)"VD+V0S)"^D,.0Q)#%D,>0R)#5D->0V)#9D-R0W9#?D.60
MTI#VD.N0[Y#PD/20_I#_D`"1!)$%D0:1")$-D1"1%)$6D1>1&)$:D1R1'I$@
MD261(I$CD2>1*9$ND2^1,9$TD3:1-Y$YD3J1/)$]D4.11Y%(D4^14Y%7D5F1
M6I%;D6&19)%GD6V1=)%YD7J1>Y&!D8.1A9&&D8J1CI&1D9.1E)&5D9B1GI&A
MD::1J)&LD:V1KI&PD;&1LI&SD;:1NY&\D;V1OY'"D<.1Q9'3D=21UY'9D=J1
MWI'DD>61Z9'JD>R1[9'ND>^1\)'QD?>1^9'[D?V1`)(!D@22!9(&D@>2"9(*
MD@R2$)(2DA.2%I(8DAR2'9(CDB22)9(FDBB2+I(ODC"2,Y(UDC:2.)(YDCJ2
M/)(^DD"20I)#DD:21Y)*DDV23I)/DE&26))9DER279)@DF&299)GDFB2:9)N
MDF^2<))UDG:2=Y)XDGF2>Y)\DGV2?Y*(DHF2BI*-DHZ2DI*7DIF2GY*@DJ22
MI9*GDJB2JY*ODK*2MI*XDKJ2NY*\DKV2OY+`DL&2PI+#DL62QI+'DLB2RY+,
MDLV2SI+0DM.2U9+7DMB2V9+<DMV2WY+@DN&2XY+EDN>2Z)+LDNZ2\)+YDON2
M_Y(`DP*3"),-DQ&3%),5DQR3'9,>DQ^3(9,DDR63)Y,IDRJ3,Y,TDS:3-Y-'
MDTB329-0DU&34I-5DU>36)-:DUZ39)-EDV>3:9-JDVV3;Y-PDW&3<Y-TDW:3
M>I-]DW^3@).!DX*3B).*DXN3C9./DY*3E9.8DYN3GI.ADZ.3I).FDZB3JY.T
MD[63MI.ZDZF3P9/$D\63QI/'D\F3RI/+D\R3S9/3D]F3W)/>D]^3XI/FD^>3
M^9/WD_B3^I/[D_V3`90"E`24")0)E`V4#I0/E!64%I07E!^4+I0OE#&4,I0S
ME#24.Y0_E#V40Y1%E$B42I1,E%64691<E%^4891CE&B4:Y1ME&Z4;Y1QE'*4
MA)2#E'B5>95^E825B)6,E8V5CI6=E9Z5GY6AE::5J96KE:R5M)6VE;J5O96_
ME<:5R)7)E<N5T)71E=*5TY79E=J5W97>E=^5X)7DE>:5'98>EB*6))8EEB:6
M+)8QEC.6-Y8XECF6.I8\ECV60992EE265I97EEB6899NEG26>Y9\EGZ6?Y:!
MEH*6@Y:$EHF6D9:6EIJ6G9:?EJ26I9:FEJF6KI:OEK.6NI;*EM*6LEW8EMJ6
MW9;>EM^6Z9;OEO&6^I8"EP.7!9<)EQJ7&Y<=ER&7(I<CERB7,9<SET&70Y=*
METZ73Y=5EU>76)=:EUN78Y=GEVJ7;I=SEW:7=Y=XEWN7?9=_EX"7B9>5EY:7
MEY>9EYJ7GI>?EZ*7K)>NE[&7LI>UE[:7N)>YE[J7O)>^E[^7P9?$E\67QY?)
ME\J7S)?-E\Z7T)?1E]27UY?8E]F7W9?>E^"7VY?AE^27[Y?QE_27]Y?XE_J7
M!Y@*F!F8#9@.F!28%I@<F!Z8()@CF":8*Y@NF"^8,)@RF#.8-9@EF#Z81)A'
MF$J849A2F%.85IA7F%F86IABF&.899AFF&J8;)BKF*V8KIBPF+28MYBXF+J8
MNYB_F,*8Q9C(F,R8X9CCF.68YICGF.J8\YCVF`*9!YD(F1&9%9D6F1>9&ID;
MF1R9'YDBF2:9)YDKF3&9,IDSF329-9DYF3J9.YD\F4"909E&F4>92)E-F4Z9
M5)E8F5F96YE<F5Z97YE@F9N9G9F?F::9L)FQF;*9M9FYF;J9O9F_F<.9R9G3
MF=29V9G:F=R9WIGGF>J9ZYGLF?"9])GUF?F9_9G^F0*:`YH$F@N:#)H0FA&:
M%IH>FB":(IHCFB2:)YHMFBZ:,YHUFC::.)I'FD&:1)I*FDN:3)I.FE&:5)I6
MFEV:JIJLFJZ:KYJRFK2:M9JVFKF:NYJ^FK^:P9K#FL::R)K.FM":TIK5FM::
MUYK;FMR:X)KDFN6:YYKIFNR:\IKSFO6:^9KZFOV:_YH`FP&;`IL#FP2;!9L(
MFPF;"YL,FPV;#IL0FQ*;%IL9FQN;')L@FR:;*YLMFS.;-)LUFS>;.9LZFSV;
M2)M+FTR;59M6FU>;6YM>FV&;8YMEFV:;:)MJFVN;;)MMFVZ;<YMUFW>;>)MY
MFW^;@)N$FX6;AIN'FXF;BIN+FXV;CYN0FY2;FIN=FYZ;IINGFZF;K)NPF[&;
MLINWF[B;NYN\F[Z;OYO!F\>;R)O.F]";UYO8F]V;WYOEF^>;ZIOKF^^;\YOW
MF_B;^9OZF_V;_YL`G`*<"YP/G!&<%IP8G!F<&IP<G!Z<(IPCG":<)YPHG"F<
M*IPQG#6<-IPWG#V<09Q#G$2<19Q)G$J<3IQ/G%"<4YQ4G%:<6)Q;G%V<7IQ?
MG&.<:9QJG%R<:YQHG&Z<<)QRG'6<=YQ[G.:<\ISWG/F<"YT"G1&=%YT8G1R=
M'9T>G2^=,)TRG3.=-)TZG3R=19T]G4*=0YU'G4J=4YU4G5^=8YUBG66=:9UJ
MG6N=<)UVG7>=>YU\G7Z=@YV$G8:=BIV-G8Z=DIV3G96=EIV7G9B=H9VJG:R=
MKIVQG;6=N9V\G;^=PYW'G<F=RIW4G=6=UIW7G=J=WIW?G>"=Y9WGG>F=ZYWN
MG?"=\YWTG?Z="IX"G@>>#IX0GA&>$IX5GA:>&9X<GAV>>IY[GGR>@)Z"GH.>
MA)Z%GH>>CIZ/GI:>F)Z;GIZ>I)ZHGJR>KIZOGK">LYZTGK6>QI[(GLN>U9[?
MGN2>YY[LGNV>[I[PGO&>\I[UGOB>_YX"GP.?"9\/GQ"?$9\2GQ2?%I\7GQF?
M&I\;GQ^?(I\FGRJ?*Y\OGS&?,I\TGS>?.9\ZGSR?/9\_GT&?0Y]$GT6?1I]'
MGU.?59]6GU>?6)]:GUV?7I]HGVF?;9]NGV^?<)]QGW.?=9]ZGWV?CY^0GY&?
MDI^4GY:?EY^>GZ&?HI^CGZ6?``````````````````#&`!`!_?\F`?W_,@']
M_T$!/P']_TH!V`!2`?W_9@'>`/W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W_Y@`1`?``)P$Q`3,!.`%"`4`!20%+`?@`4P'?`&<!_@#]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]_\$`P`#$
M`,(``@'-`0`!!`'%`,,`!@$(`0P!QP`*`0X!R0#(`,L`R@`:`18!$@$8`?W_
M'`$>`2(!(`$D`<T`S`#/`,X`SP$P`2H!+@$H`30!-@$Y`3T!.P%#`4<!10'1
M`-,`T@#6`-0`T0%0`4P!U0!4`5@!5@%:`5P!8`%>`60!8@':`-D`W`#;`&P!
MTP%P`6H!<@%N`6@!UP';`=D!U0%T`=T`>`%V`7D!?0%[`?W__?_]__W__?_]
M__W_X0#@`.0`X@`#`<X!`0$%`>4`XP`'`0D!#0'G``L!#P'I`.@`ZP#J`!L!
M%P$3`1D!]0$=`1\!_?\A`24![0#L`.\`[@#0`?W_*P$O`2D!-0$W`3H!/@$\
M`40!2`%&`?$`\P#R`/8`]`#2`5$!30'U`%4!60%7`5L!70%A`5\!90%C`?H`
M^0#\`/L`;0'4`7$!:P%S`6\!:0'8`=P!V@'6`74!_0#_`'<!>@%^`7P!````
M``````````````````````````````#]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]_X8#B`.)`XH#J@/]_XP#_?^.`ZL#_?^/`_W__?_]
M__W_K`.M`ZX#KP/*`Y`#S`/"`\T#RP.P`\X#_?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]_P($`P0$!`4$!@0'!`@$"00*!`L$#`0.!`\$_?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]_U($4P14!%4$5@17!%@$601:!%L$7`1>!%\$````````
M``#]__W__?_]__W__?_]__W__?_]__W__?_]__W_V`+'`K@`V0+=`J\`VP+:
M`E[_A`.%`_W__?_]__W__?_]__W__?^A`*8`OP#]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W_N@"J`*D`K@`B(:0`%B$`````````````````````
M``````````````````!Q(7(A>"$O(4PB:R%>(2TA>2)?(6`A(28B)B,F)"8E
M)B8F)R8H)BDF*B8K)BPF+28N)B\F,"8Q)C(F,R8T)C4F-B8W)C@F029")D,F
M1"9%)D8F1R9()DDF2B9+)DPF329.)D\F4"91)E(F4R94)E4F5B97)E@F)R<A
M)R(G(R<D)R4G)B<H)RDG*B<K)RPG+2<N)R\G,"<Q)S(G,R<T)S4G-B<W)S@G
M.2<Z)SLG/"<])SXG/R=`)T$G42=2)U,G5"=5)U8G6"=9)UHG6R=<)UTG7B=?
M)V`G82=B)V,G9"=E)V8G9R=H)VDG:B=K)VPG;2=N)V\G<"=Q)U<G/B$](4(A
M1B%'(4@A22%W(G@B12%$(7,B;"%M(2@B;B%R(BLB+"(J(BTB32).(D\B7R)0
M(F`B.B([(ETA92)G(F<A7")*(DLB02)`(FDB:B)H(6@B9B)B(F(A82)E(68A
M8R)D(CXB/R(\(CTB72)>(B$H+"@B*"TH(R@N*"0H+R@F*#$H)2@P*"<H/"@W
M*#(H*2@^*#DH-"@H*#@H/2@S*"HH.B@_*#4H*R@[*$`H-B@C(B(B)2(D(B<B
M)B(A(GXA>R%](7PA?B)Z(7DA:B%I(78B=2)T(B$A(B$C(3<A.2$Z(3LA4B%3
M(50A52%6(5<A6"%9(5HA6R$I(BXB3"%-(4$A(20B)",D)"0E)"8D)R0H)"DD
M*B0K)"PD+20N)"\D,"0Q)#(D,R0T)#4D-B0W)#@D.20Z)#LD/"0])#XD/R1`
M)$$D0B1#)$0D121&)$<D2"1))$HD2R1,)$TD3B1/)%`D4212)%,D5"15)%8D
M5R18)%DD6B1;)%PD721>)%\D8"1A)&(D8R1D)&4D9B1G)&@D:21J)&LD;"1M
M)&XD;R1P)'$D<B1S)"LA+"$U(38A(24B)2,E)"4E)28E)R4H)2DE*B4K)2PE
M+24N)2\E,"4Q)3(E,R4T)34E-B4W)3@E.24Z)3LE/"4])3XE/R5`)4$E0B5#
M)40E125&)4<E2"5))4HE2R5,)4TE3B5/)5`E4252)5,E5"55)58E5R58)5DE
M6B5;)5PE725>)5\E8"5A)6(E8R5D)64E9B5G)6@E:25J)6LE;"5M)6XE;R5P
M)7$E<B5S)70E=25V)28A/"$S(30A;#!Z0S<\?$MF/C`[93X\,E1)/TTB4"\Q
M;C,C4"1`0E)6-3I*9SX^3D)*)%!F0R50>C8F4%TT,$-G/"=0*%`I4#5'5S4W
M1V-&0S@S2TEI*E!H/BM0-3)E-G`X:4PF5G!-?48E-#4U+%`M4#M./4UH02]0
M=CMS1C)0/C%?.%XX9C!+3TI/,SHA,#-0-%`U4#1+-E!R.&<P<DM\-7TU?C5B
M1#Q.-U`X4#E033\Z/4X_/E`\4#U06#4C.G`R.U`Z4"E*1CM%.SY"/U!526=`
M."%`4$)094)A3DHP05`^,D0V9T-O-T-0)$=K-$102S!@.&PT>DDR2%DU<3)G
M4$%%;$=&4#Q(8DXM/T<[=SM`,E%$(D-*4$PP8T0[/30Z)$U.0C\R25`^3450
M1U!N.DA0)%504%-045!",CM*2U!/4',X2#LF-%103%!C3G@[35!24%503E`A
M-DTP(C9!,B55>4MN270X+S\W3EA*.#<E0F0R4SU94%Y07%!74"]"6E!=4%M0
M74I84"X_<TM?4&!0)#UM4%!'-DEH4'!*-C)L4&90;U!2040X7$='8&Y0745C
M4'8X=3AA4%H\:5!O2DU#95!Q-V)0:E!D4%%.:U!!3V8V<#=P4'%0=5!.,%!*
M=%!S4'=0=E!D1'(W>%!%/"9"941V-GE0-C5Z4'Q0-4MF-S$[=TA[4$4Z0TU^
M4"-1?5!$.GT].3<D44\V(5$B42]&?$$C-DU+)5$]3B91*5$G44Y!*%$J42Q1
M*U%(2C<U+E$O42\R+5%T/#)1,5$P4590,U%^/311)4U93#91-5$X43=1.5$Z
M470P-3@[-SP]>T,D-FA`=SAN.3Q12$Q&17D[.U$]45Y%=3,^47Y&-$%`44%1
M+$AX.#M/0E$F-CQ*-D)Q-C5%<S=#44118D9?,4=1?3I&448Z2%%N9DE104M*
M44M13%%I/DP\)S1/44U1/4Q.45I)4%%145)17T56451155%346,Z5U%J3&1.
M6%$H0%E16CU:47Q#/TY@14526U$E=$4V7%%>2V@]?$)>461&7U%@42XS85$G
M-DQ&>C%0/2%(8E%A14\_8U$L2EI`(C0I-&119E$Z-V51<TYI/3U(3$IG47A-
M:%%I47Y%:E$I0'XZ=#=K44D[;SEF1&U1)T)O.FY1;U$P06Q1<5$V2V0Y<%%U
M-UXZ;4=T47)1>TEJ/GM19#-U47-13T%W47911#-@-WQ1+4YX47U1>E%Y44].
M>3A#,G1.=3U8164Y(E(C4F5.*T\E4GHX)%(O,R925DL\1"9-64HG4E5P,$8H
M4BHT,TPA/BE29THM4BI`*E)0-BM2*S0N-RY2+U(P4C%26SQ[.%Y,:$QW1G%*
M,E(S4C52-U(V4CA2/3),2WPZ.5)902(^*38Z4EM(.U(\4CU2/E(D26@V93`_
M1C]2/3UI0$%20%(C/F$X0U(^2$127$@T0FY"*#9N1C%#;D=.2T92:D`U-T=2
M2%(L,74P;30H0E$U<4U+4C<R2E(J-DQ2<4Q-4E).?#@V.$Y24%)/4E\_.3%>
M,5%24E(W.%-2;C4R.U12=$LU.EHU)TU003](?3Q'/6@\=3QV/4!(5U)#,5%!
M?3A%.&<V6U(A0WY"*S8D/EQ26E)$,F9".#Q+.R8Q<#-F.4H[75)>4DDU1C-G
M.4@U7T0E,3%&/DPA.7E-1T5^."\W9U)C-DI+74AF4EXT85)B4F1295);-6$_
M+4IC4E]28SA@4B1/<DIH1&(X<#EH4EU&;%)^/'8\;U)M4B-,:E)S4FY2<5)&
M.#],<E)T4G92<#I"3VM2:5)U4G!2>%(C4WI2?E(A4WM2/E-I.C$S>5(E4W8P
M)%,E,$I)(E-\4G=2?5)(.B93=S`O4R=3*%,E/FE++5,L4R]%+E,K4S0Q-CHP
M/RE38D4J4R(P-%,C32<^.E,Y4S!30T(Q4V]"-E,F/C-39$P\-S=3.%,U4SM3
M,E-!4T930E,]4T=3,4%)4R(Y/U-]0T-3/%,M-&XT93-$4T!3=C=*4TA34T%*
M-2PV15-T-D0Q3E-,4R=445-+4T]335-,.U!34U-84U9355,R0T4R4E-44R@^
M,S%74UXR8E-\/EY37%-=4U]3/3$Y05E36E-Z,V%3;S1D4V!38U,N2E5&.$AF
M4V5313-G4VI3:5-H4SE':U-L4VY3;5-P4W-3<5-O4W)3=%-U4W93=U-X4T51
M?#Q-.W,R>#!$0WE3)#I/,%X_>E-'.'$Y?%-[4V!*?5,A5'Y3(E0C5'<W8#$D
M5"94)50H5%I%*50U,%\Z/3=/0RI4*U0M5"Y49#I1-C=++%0O5$$Z(SDS5"4Z
M,T,P5%I$-%1B/S)4-50_-S94-U0D.4`S.50Z5#M4.%0Q5#Q4/51D2VL^/U1`
M5#Y40E0X1V@P5DE#5'T^.3Q=1W`T:SI92S)&>#=/0D%41%1$0D541E1(5&E$
M+C0A=&$Q<TIL/DA%9CI.5#U*74YT,DI4.D%-5&-%245D13E(341).DE4=C$V
M14M41U10/T]43CTM-E!4:$I]049$4E1/2U-46%0O2E=445145%94)CI)2EE4
M14-U,FT^6U1:5&@Y7%1>5%U48%155&)4851?5$X[43]406-4/$!M,&1'6T1E
M5&149E1G5&A4:5112FI41C)K5#Q-,#-)4D@]/T)L5&M,-$QN5&="-T5`0E=)
M;U1P5'LQ.CQQ5%`P<E1S5&(Q<31@1G1*=U1507940#=;2W54945Y5'A4>U1Z
M5'PQ?%0I/GY4)4-]5#-*=SU;12%5)3DB52%'7DA13"5'*U4X-45-+TPL5B-5
M)E5%0CA+2D4G565+2CHJ/BA54#M/.SDP2#@K0%$P+%4M52I5.#$O-"E514PQ
M22@P>3!1.U(P(S`R53!5/$PS53%5+U4Q/RY56DID.#=5.%4K/C15+$],1S95
M)SHY55A).E4U53M,7D<[53))/%5`53U51S(_53L\/E5Y-TQ5155"561#055#
M54151E5'57(T255(54I5;CY-55Q$13%+54Y53U5255!54552.U-5)CE457H[
M.$)555956CLG.5),*#5).%=56#-853E"654C5EI56U5<55Y57U5@57!")S%I
M/$(P5T$P-#4\*#EF12$],31H0VI$.#`Y-75*0CQ2-6M`/#PH36%57#5+.C(S
M8S$L/D@R8E5&34D]9#QC57,T4D8I3&15955926=5*#1W-F95,C0R/VM5(3M)
M,FI5:%5L56E5*T=-7#,_;55`3FY5<%5^0V]5(T![.U!"=SQU26Q`33QQ52T^
M<E5S55,P.D)2/W15,T8N/B\^=55M0#`^=E5W56!,>%5&-B(]>55Z55P\+#]T
M1E0_>$@B1TDV>U5O-7Q5?C9/1C`R4SM]52)6(59]-GY5.$4P0DM%2#Q807I-
M)%8E5E9&,SLG5BA6*59T-"I6*U8L,CM!9#0M5BA,4D)9,R]6,59?-"Y6,%8S
M5C)6-%8U5CU&+C9E,C96.U8Y5G=*=DIG13A65#TW5G(_/%9J.D)60U8]5C,S
M/E9'5D96159!5D!61%9X2DM62%9*5G)-258_5G,_3%8W.DU63E915E!63U9H
M13I65U935E)65%955EA69DY95E966E9@-%M6759<5EY67U9N0",]9#UC02DY
M.#HJ.7`U8%8Y.DHX858F3$-'8E8K.2PT)T-2-E0[6TE!2&-6=31F5B%$959D
M5F=6:T1C/U4[2D!30B(U(D1H5FE6;SXY2VQ6:U9J5GU)<U9:2VU6;U9K2VY6
M<%8H2'%6/DIR5C,T/THO1W16=58L.30T=E8X.$1-*4UV-'A6(T0M.3$^7T@R
M/G@];$1Y2CE%+CE<27E6645".DLX;41#,&X]+SE'37I6>U911WQ6=TXM3WY6
M?59',R%7)%<E5R-70$DS/B=7)E<B5RA7*5<J5RU7*U<L5RY79#%N1"]7>C=V
M,C9',%=[1EM*,5<N3S)70$HU5R%0,5`P/'5&-E==-21$>C`W5R9*,#E00V]$
M;TPY.$PX.%<Y5S]793PE1"\V.E<K249#.U<\5S`V/5<^5T!7=D5!5T)70U<T
M5S-71%=!-R=)3#HW229$2TE%5S0^1C%&5T=7<DQ@2$I7?3$L0$E72%="-U1"
M3E=,5TM7)TYE.'D]35=,13X]0$915U!73U=25V8X4U=\25L]5%=Y2$%&)T0P
M1557*S4T/RQ)=S0F1U975CLZ2SM+?C%;5VE#6%=W,BU86E<P1UE75U=Z.5U7
M8U=I5V%77$5F5UU)8%=E5V=.5SM50EY77C5H5RU`93%B5W@R9U<Q-F17:E=L
M5W97=%=Q5W!7>$YR5S(V,3EZ/7E7:U=O5U]7>C)S5W5744,H.C@R;5=X5W=7
M,S8I0F8S0S=N5WI7?5<A6#T\)UAP1'M7)5AY,B-8)%A^5R)89S@J334T63$F
M6#I'+3!A2%Q7+%@P6&5,*5AI12Y8<#XO6%=&1T\K6#%8>SE+0%0P*E@H6%I!
M?%<T.T9"/5A;03A8-5@V6&8\.5@\6#=8)3TZ6#18?$Q[3#Y8/UA5,#-8<C8F
M,#8T.UA#6$)81UA(6$9825A!6$582EA+6$!8?#M$6%9",CDR6#4_6%AI2DY8
M3UA06%=85EA]2S<T5%A%-S0S45@X3E-85C!56$Q84EA96$0W35A=32M-7%A@
M6'Y!>4YA6%Y86UA:6%]8,$HT1D8W8EA=6&-8>S<Q,FM8.#1I6&I8*3IH6&98
M95AL6&18;EA[,G!8;U@H1'-8<5AG6'PW<EAV6'58=UAT6'A8>5AZ6&I*?%A[
M6#\]+D!F,GPR?5@_,$Q`?EA#;"%983<B66]`(UDD63HU)5DF62=95T)-.&%,
M/$MJ/2A9<$`];F)(:CQ-.BE91T(G2G%"+%DJ62U9*UDN63%*-S!>26-(+UDR
M634^.S4P63=9-CXQ641'7DTS6319.%EJ1359,SE>0$99-$AR0F1(+5IZ2G%$
M=4L[62$R:D-$631#/EE%64!91UE#64)9;T<\67TR.EEQ-7-"-EDY630Y6T`W
M/D%94D=R-4@S9S,A/TE93EE*67TW3UDB.VDY)CT]67T[3%E8.TU91#!(62E$
M<S4T-DM9)S!#.C8_<D142%%97D$J0BL[4EE465!984H]1%Q!>TI./&!97UEX
M/WXW65DY/FA&,4=765U!>#Q<63@^5EE;65-'55DA-UTS75DK3DXZ-4-:65Q`
M-3ED/V8Q/$%8644U1S=/1%Y97T%A66-9-T)I66199EE!27-$9UDL34A-.30N
M,&598EEX-&<Q:%E)36Q9.T)S66U9:EEQ65-9;EER64)(:T5K66]92#=Q.EU`
M=UDF17198$MU67993DPB0&(W?5DU.WI9>5DR1S5&,45[67Q9;TE%1R,[<4!0
M2TDS)5I^64I-)UHC6B1:8$$B6C]9)EHA6BM:+%HG12Y:)#LI6CPU+UHH6C-:
M,EHQ6C1:-EIQ/C5:.5HW6CA:<%D[6CI:>%D\6C!:63L]6CY:0%H_6D%:?C(V
M.7Q*+T!..$-:1EI225\U15I$6E1'1UHU-DE:2%HZ-#8[6$9)-W0_2EHP0"A%
M7TE+6DQ:35HX2EU51D!,25@Z94A#2$U%04Y/6E`\4%HV,%0V34!@25%:0CM'
M0UL[-S]26GU*=S%<.U5:4UI66CE.5%I[0%=:,D)86GHT6EI96EM:7%I[-'Q&
M-D-L-5T[84%</3`P75HB,F%:-SE@6BLZ.CY?6CL^0$PJ.E<P3D!F6C%`1S%5
M/69+<CH\/B=`95IC6F1::T,F6VI:?CLX.6A::5HX/V=:+SML6FM:<%IQ6FU:
M(C-N6F]:54AA24HW<EHR0#T^4D-'-G-:=UI+,G1:=EIU6FL]2$-%,'A:>5HJ
M1'%.0SMK2CU+(EM[6GY:?5IZ6B%;7D9\6B-;;#TD6TM->$<E6R=;*%LI6THV
M2#$Y.2I;*UMQ/6)!6%(^03U!6$)'.G)0;C<M37Y*?DDL6W,Z/T0M6R]//DLK
M1"Y;?#0O6S!;6DPD3'9+7$LE.S);:SQ12S1;-ULV6WDT8#4S6S5;.%MY/WM-
M23!@.CQ"73QS/CM;3D4Y6RM".EMR/EU,/%L]6VA-0ELZ.55'/UML15Y:8EI/
M-4='05L^/D1(1UMZ2#Y;1%M#6T]`;4M33F=+3#)>.TA/1EMU/T5;0%M/.$Q;
M2EM-,DA;3EM46TA"04I66R))55MP1S]+.S1W0$`]4T0N35%;4%M26T];5UM-
M6TM;4UM)6VQ#>$Q&/'0Z.CIO2T$S3D1*1DDQ<D`T0"HW65L[.7PS6UMT,V%;
M7EMS0$LS+#I*,T\Z7%ME-TLW;45:6T8P75M?6TTV+#<\-$LU8EMY.G%+-SMC
M6S!);ULS,F1;=5ME6T).;%M?1W1;9ULT,&E;/#EK6VI;9EMQ6S\^;51H.'Q-
M:%MT1",S+3I@6W!;83-N6W);;D5^-#)<24QW6WTT?EM`2R%<(UPG7'E;*D-O
M12M<?%LH7")<.3\L7#-`*EP]-%!/=ELF7%@P>%LZ3'U;(C]'1'-;)5QZ/R]<
M<3,A.#%<>ELP7"E<>ULM7"Y</UQ.1B1<.UP]7%A$3$UV23A<2D(^7#]!-5Q"
M7$%<;T9`7&I&1%PW7$@V.EQ=/6!'/%Q+-C1<-EPS7#!/6C,Y7$-<-3-G.ETQ
M5%PQ3U=<.C]67%5<4EQ&7&-<15Q87%!<2UQ(7$E<45PB=$Y</3E(1&1!3%Q'
M7$I<34UJ2T]<65QA7%I<9UQE7&!<7UQ01&5!75Q;7&)<:%QU2&Y<:5QL7&9<
M=$,X25Q<9%Q`/D],>%QK7"(X(S)?,U-<03YP7'=<>3QR,RY#;5QR7'9<-C9,
M-71<(35+1G-<=5QO7'%<8#-)0WQ<>EQI.'E<(5U86WM<?5Q^7"Q=*%UM6R==
M)ETC76I<)5TD72I=)D\M77LV*5TK72=(+ETR72]=<TTP75Y<,UTT734Q-EUG
M-R$\538D,E]-.%TW73I=/356-CXT/5T\73Y=3C(W0S]=/S1!74!=0EU#741=
M7SLU0"$Z<$EB2D1/=3M0.G).15U&76`[1UU(74I=25U82UX];#Q$.TM=35TC
M/TQ=3EU/75!=45U2751=4UU5724R2D-6728[3#-774)%3%0C-5A=65UL2FA+
M1T9:769(>TA33%M=75U<75]=7EUA76$[,4QB76-=)#5D769=95UE/SE)2C%%
M2'5$03UA-49(+CQH74`T>#%R1F==/CE30VE=<5UJ74%"8C5R76@W)35P76Y=
M:UU@34!$649L771=<UTC-RTR.SIM76]=5TMT0G=+?%U]74\R*$I]3"%>(SQ"
M/GA=?EUH,3<V=5UZ771`<4=G2'==(4MY721>(EY[72)+2$=C-25%;4,E7B->
M64)V74LQ3DTP7B]>=D`L7FQ--D8F7D5$3#$_.2E>)STN7BU>*%XK7F@S*EY)
M1RY.=#YU0#9>-%Y-23%>,UXZ,4`Y,D\],V))84TD,SL_-5XZ7D,^,$TW7C)>
M.%Y>3G-%0D8V,U4Q/EY!7D-.9$U(7D)>/UY43D5>2CU'7DQ><45*7D1>.$-+
M7D!>1EY-7GPP0UY.7CP_7STE2BXZ.UY)7CI%-D!I,U$Z1#X]7D(]3#<\7E)>
M;3TZ.&%>6UYT-4]%5EY?7B\P,C$Y,EA>+$)/7E%>03EB7EU>55Y<7BM,6EY>
M7E`X13XY0U1>+TU77E!><D537EE>44\^/'Y+8UXN2&]>.SA@/65>+TY".7)>
M;C!P7F1>:EYL7D]-9UXN16E><5YK7D=,9EXB/'Y>:C-H7FU>;EYL0EI"=EY\
M7GI>*44C7W=>>%Y@7GDU.DD_/'<Y,T]T7B)?:3%F07E'031Z3B%,4D1[7GU>
M,D$A7WE><UY#-&DW+U\J7WA`8S-A/3-?+%\L1"E?641,7R9?)5\N7RA?)U\M
M7R%`)%\P7S%?0C0V7S5?-U\Z7T-%-%\X7V,W>4(R7SM'.5\^7SQ?/U]"7SM?
M:CDH1SE>=$T]7T%?=4)`7RM?:6]%7TE?1U]#7T1?2%]&7TY)3E]+7TI?35]4
M1D]?=4-M0B5`4%]27U%?=5Y37V=&5%]0,G1%)3-D-5X\4CHG3V8_:C%67U5?
M65\Z0UQ?5U];7UI?0$59,'5.7E\H,6!?7U]=7UA?(TMB7V%?:S%D7S)*8U\U
M3$<^,T%&/GM.:E]Y0&9?:U]L,6E?84=E7VA?2#Y12&Q?43QZ0&]?9U\G-VU?
M4$UP7R9T3SUQ7W)?+D=T7W5?,T=U17=?>5]53G9?>%]M,7-?6U-Z7V=!.#M\
M7WM?)#]94GU?(6!N7WY?(F!Z1R-@)&`E8"9@7D0H8"=@*6`J8%\\8TEL3"M@
M+&!6020\+6`N8"]@4DI'2#!@5T<M1#%@9S)M-49,-DPT,C1/4DLJ2C=`,F!#
M1B,X,V!4.C5@-&`V8#=@.&`^-3E@.F`D.$A(/&!U/CM@.#8]8#]@/F!`8%$X
M06!I-D!!?3E#8$1@0F!M/$A&.39&8"Q#16`U3V)'26!+8$A@5$Q*8$Q@1$Y0
M8$]@=D,M1R4X3F!-8#%-,DU18&XQ=CEB.U)@4V!58$,]5V!68%A@33-:8%E@
M7&!;8#PX*$Y,-B8R:C9A-&A.7F!@8&%@43)=8#D[041?8&1@;CQB8#XW24AC
M8'Y@:6`].&4U9F!]33!.=D)H8&I@5DY7-GQ(2D=K8&U@<&!L8&]@:CA-,7%@
M<#]N8%Q.=&`D=')@=6!G8'-@/#IV8'=@?DUX8'E@96!Z8$0T)3Q[8'Q@?6`[
M,2%A.TDB820T(V$D825A)V$H829A4TDJ82EA+&$K82UA+F$P82]A>3DR83%A
M1313/SQ%,V$X0#H[>3$T85%-8THU841%,TU#.3T_2T,T4BY$:#(V83=A/&$Z
M83EA0EHF,SAA6C`J2$I(,4X]83MA7$,F0"M(+4D_82Q.33=`83YA5DA!84)A
M6S!V/D=A1&%M1D-A)C5*845A1F%)84AA)4E"04%!/S5+84QA36%/84YA5C%7
M86A(46%3855A/C]6851A0#Q085)A0DE)/EEA6&%:828\+SIW15MA2T1=82%.
M7&%I06)A9&%E851#8V%@85YA7V%A86AA9F%G86EA:V%L86UA;F%J87!A;V%Q
M845.=&%R87-A8C1^3$I*=F%U87=A>&%\87EA>F%[87UA?F$A8B)B(V(O2%!%
M)&)R1S1))6(F8BI%)S-$.2=B*&(I8BD[*V(J8BQB+6)I2"YB+V)I<S!B,6(R
M8BX[,V)61U]+3C%7,31B-F(U8G!%.4`Y73=B04PX8D8T5T@Y8CIB.V)<3%5,
M/D1J03UB8CU*/D!B/V(^8GU(1S0I.$9B0V(_/S),0F)$8D5B06)'8DAB+T1C
M-&5#26)*8DUB9S]$1DYB4TM+8DQB46)08D]B4V)28E1B5F)58DU*5CU&3E=B
M-T988EEB76);8EQB6F)>8E]B8&)A8C=,8F)P3&-B3D-J1VLV.T-D8CHV4$!E
M8CTZ9F)G8B8X53II8E9%5CI.-21+2T=715PY:V)+/C).13DG."-(;6)O8FLX
M;F)V1'%B-S-L8FI(,#%L.E)/<&)R8DM*64!T8G5B<V).,WMB>F(G/'QB=V)]
M8GAB6$AV8GEB(F,A8V%+?F)K,"1C(V-,/B5C0T$G8R9C*&-H8FIB*F,I8R@\
M:4Y2/"MC-S=`-2<U8SLT33%C,&-$02UC+V-+/4`_+F,L8RI'33X\25<Z>$4R
M8S-C26-8-CU/-4$T8U(R=T0A2C5C>C4V8SAC.6,I1SIC.V,\8UDV4S)%1B@]
M9#L]8RD]2C)#23YC:TA%04%C0F-I1T$_/V-A0T!C3CY<,"DU0V-X1$1C1T`M
M3"-)16-&8U5#1TY(8T=C;SQ*8W`P36-+8U0R3C=,8T8Y<CEF2DYC5$M08U%`
M3S$Z,BPP3V-18U)C=SY38T\S56-J-V8U5F-U-E=C?$!-1F!`=3I88V)#:T%:
M8UQC66-;8R(W76,F-V<U4DU?8V!C+C%C8W8S8F-A8V5C7F-F8RE.9V-H8W14
M:F-I8VMC;&,U3FUC;W!//FYC;V-7/3A&<&,H0W%C/$-R8R4V/U%=0S,\2#1S
M8R)D=F-H-75C)&1T8U`^>&-Y8RM%>F->,UH_9$E\8VA"=V-[8WUC>SHF9"Y)
M)DAY15HV)60C9#5(?F->0WM%>D5V.CAD*&0J9"UD+F0K9"QD*60G9"%D3TI5
M,C5D,F0W9#9D<T<G3#L[,&0Y9#1D,V0O9#%D230]0WU`(D@^9"1(84`[9$](
M/V132EM#.F0\9#UD0&1$/$9&161$9$%D-D]*9$YD2V1'9$AD361"9%52261#
M9$QD4F1*-$]D4&119%1D4V1V2%5D?$YM2EID5V169%)`661;9%AD7V1<9%UD
M1F1>9&!D861&2F)D8DQ.-BDW8V0T2F@_,$QD9#-.=$=&031'33U`,&ED9V1E
M9"$T43YJ9&AD9F1N9&UD;&1K9&]D<&0Z0'%D<V1R9%(X.$%U9'Q%=&1V9#5*
M;$%'.7=D2$YY9'ID>V1\9&4[?61/-VHU*C4A97-,2#E^9"1E9DP\1S-)8STC
M95,\23EF.VDU-DHB94=!0DMW.F<[740G95].63HH94(_*F52/C`Z*64J/3XX
M2$$E92ME)F50-RYE,F5K-RUE-F5*.6U-/#`S96LU,&4Q97U%+V4L92@S9$`H
M.#AE-64W931E43<S0CEE;D%&94)E/&5`97H\73`[94-E1V5+.59,5D0]945E
M.F4^0S]E/3!*3#YE6S9L2&U!4$YO/6YE2&5^0$1E265+97E$3F5*951*2S1+
M3%XP365]3DQE;S%L1D]E5F5095=E4V5[1TH\565295AE465$/25+3#U496!E
M7&5?95UE865;94%E4T!+2%YE664A05(W*STE/S9!9&5F96=E8V5E95IE8F5J
M96EE>DLK-VAE;&5K96]E<64\.VUE<F5S971E>F4[179E=65W97AE>65[97QE
M3#1]97YE(68B9B-F)&8E9B9F*&8G9BEF*F8K9BYF+&8M9F$Z4S=60S-(<#U-
M1VU(+V9M6#!F,F9E33%F-&8S9E---69^2#9F.68X9C=F.F8R-R)!034^9CMF
M/&8_9D!F/68I,2<R0F9#9D1F8DTL/49F169I/T=F2&9)9F4T331*9DMF74MC
M351--T]-.4YF5#Q-9D]F*3Q10E!F3#E73%%F4F939E1F568J/&U,5V8_0U9F
M66989EIF.T!;9EQF.4I=9F]!7F9?9GY.8F9A9F!F,$1C9B8_9&9E9CA/9F9G
M9FEF:&8E2'E&/D\I2&MF4SXJ26QF:F9.-%0X:#MN2"HX0TMO9FUF3CE/.6DP
M:#I91U\P=&9`0UA'6T)V9G)F=69P9G-F)DM5.'TP<69X9GEF.48[-B9G/4=I
M.SPV2$!&3RY,=V940%,U>F9\9GMF?68F0SY',40C9R)G?F95/V5))6<D9U`Y
M4T\U9REG*F=P/"AG>#DG9RMG,D0B2B-!7$(O9S!G+&<M9RYG43DV9S)G9DEL
M2RA),6<T9S-G1$LW9SAG-T$Y9SMG/V<\9SIG/T<]9SYG,C)%9T!G06="9R%"
M1&=#9T9G1V=(9T,_:3))9U=.*SPM/6H[5T-*9TMG,3%,9TUG3F=/9U!G/38J
M6E%G94!29TL\4V<P4%1G7DI<-"1!6#UQ22X]56=2.59G3$AD9UAG24)U1S\X
M5V<E05EG>D1;9UIG76=<9UYG8&=?9T\T86=B9V-G,3I)3F5G)S]P,69G9V=H
M9W(P:6=J9V=)1SQL9RDS,C!K9VYG3D=$/U8R)TM=-UPV;6=J,B,T<3%R9VI.
M74)$27YG5S)\9WIG<6=O9W!G8SQL-G=#4491,71G<V=Y9W5G>&=03'=G6#)]
M,WMG?6=4-R-H+&@M:"LP-&AQ,"MH*F@E:"1H(F@A:&-#>T(G:"9H*6AP054W
M03$H:%,Y<4$Z:#MH63(N,CAH+F@V:#UH-V@U:'9G,V@O:%`T,6@\:#)H/F@P
M:'Q':4TY:$]H1VA[/T8U739":%LR5#Y%:%HZ445*:&Y*06A:,E8X*4E+:#]H
M2&A2:$-H1&@Z1DEH1F@H2TQH8#!`:$YH36AK1U1H7VA^,V)H4&A5:&Y-7FA5
M32I.>$-K,W))9&@A1C$P76A9:')!4VA;:&!H+$<J,%AH86AX25QH5VA5/B\]
M+#Q83$=)9VAP:%IH=S-X/F5H:FAS069H;6A?0VYH5DUC:#@S:6AL:"Q,;VAH
M:&MH*4LA3W-H>FAR:$,\46A.2B),>6AX:'1H=6@V,7=H<6A51'9H?C`B0D-*
M>V@A:5E(?FA6/DD\(VD^-B1I>4E]:%9H?&A/3R)&<TDK:3%I,FDE:79'+VDG
M:2EI,VDH:2QI<C%E1BUI,&DF:29!*FDG.T4_,#=T3'E,<CTW:35I3D\T:75-
M-FDX:3EI/&DZ:2-&.VE-2"YI<ST]:4)I=$%!:2)I0VE)03YI0&D_:3%=(EU%
M:41I=DT\8D9I1VE(:5<X5#5*:5U1=34Z3G,V2VE,:6Y#36EZ1CHP8S)2:5-I
M3FD].T]I0D=0:5%I6VE5:5AI5&E6:5=I6#Q9:4%#5C=",UQI/S-A:5UI8&DZ
M2%YI7VE(25I(8FE]0FQI:&EK,F9I*DMG:61I96EJ:6UI:VEI:6-I6$-T:2I,
M<FES:6YI<&EQ:6]I9D`Y3WAI>6DA:BH_>VE^:79I=6DB:EPR?&DC:GUI>FDS
M1'=I:$<G:CM-)FHE:BYJ*&HP:F9-,VHJ:BMJ+VHR:C%J*6HL:CUJ-FHT:C5J
M.FH[:BHS0C4Y:B1J.&H\:C=J/FI`:C]J0FI!:EII1FI#:D1J16I':FPW26I(
M:C`]5#DG7DIJ43TY,TMJ4C%7/DQJ53E-:F$P/4E.:FH_56I2:F]#4VI0:EXV
M3VI6:C8W7D)<:EAJ-4)7:EIJ46I;:EUJ;TA9:EYJ8&I3.%1J03!?:ELZ=DYA
M:F)J=4$B3F-J-4UD:F5J9$IF:D`Z(TYK:FQJ6#YJ:F=-9VII:CU`?C]H:FUJ
M(TIO:FYJ;#,K2W!J?&IR:G-J=&IU:GEJ>FIX:G9J<6IW:GMJ-W`H,GYJ7S9]
M:B)K(6LD:R-K)6LQ/29K)VLH:SY`5TTI:R1*1D<J:RMK*S@L-2QK:SM!1RUK
M4#,N:S!K=TTO:T8_,6LR:S-K430T:S5K-FLW:U$S.&LY:SIK<C(H/SMK/&L]
M:T`X>T0^:U<W5C]!:R1&0&LQ-S]K=T(M-4)K0VM9/FTW1&LL2U]`=C5U3$I!
M16M'/W!#6CY&:TEK2FL^.D)"2&M;/CY)1VML.U,Q3FM8-VX[;3M-3TUK3&LG
M04TU0T\Z,UP^2VM0:U%K3VM8.$!-;SLG1U1K0$!"0S9-5VML.#]`4VM8:VTX
M56M6:U)K8D!)1B]#73)P2$,U-$1;:UEK3$-!0%(T6FM;/TI.0$]<:V=K-41F
M:V-K:VMD:V!K?$1?:UUK(4UP.V%K7FME:W0]03AZ0D5+6C%B,"5&:6MH:V9&
M;6MB:VQK;FLL.&IK5CE5/&]K6$UR:W5K<VLU27!K8#9T:W9K>FMW:WEK>&M[
M:S$\?6M\:VA)(6Q9-WYK(FPC;$0U069Y/B1L;C@E;"9L/CM.6B=L*&PR/2EL
M*FPK;"QL+6PK0RYL,&PO;"9&,6PM2S)L,VPT;#5L6D9=/C9L:SDN4#=L.&P_
M23EL06PZ;#QL.VP];$9+/FP_;$!L0FPM,V=$:4EB.E<Y3TE?,DY(16Q3-%5`
M1&Q);'E#8TQ';$AL+C5*;&-'7T)Q2#U%1FQ'2VPR3&PH3T)$14]Q.TML,4)<
M;"A!>$9024]L/SMR.UX^94<M.$YL36QJ24$\4D51;%)L6#E0;%-L5&Q6;"-"
M56QF-%AL5VQ9;%ML76Q>;%9`3SQ?;%(S8&QV06%L8FQK22\U8VPV1%LQ9&QQ
M/'8_+4)G;&9L96QM;&ML:&QJ;&EL;&QW-7!L5T!Q;%DX;FQO;"E/-T0I07)L
M=6QS;'1L64TG1GAL=FQW;'EL*6U\;'UL>VQZ;'U$(6TE;2)M?FPC;21M*VTF
M;5A`*&TJ;2=M+6TS/2QM+FTO;3)M,6TP;31M,VUV3#9M-6TW;3AM.FTY;4@_
M.VUM-CQM/FT_;4!M/6U!;58\0FTP-3,W+CA#;7!&/D5$;4=M-#Q&;45M6C=(
M;5,S2FU<.DEM4FU,;4YM94I+;4UM46U/;3$U4&U3;5I'6$XT/51M(DU6;55M
M66U!35AM;3-7;5QM6VU:;3)%76U>;5]M;#DE-V!M86UB;4D_8VTM/&1M96TA
M4GY19FUP96=M)$,K/T!':&U52E1$?CDI0RHQ>$M7/UXW83962FEM:VUJ;6`R
M=D9L;7=',T5M;5(];VU"3'YM<6UR;4E$8$)W02A&<&U5-7EM=FTE;BE&8$-S
M;7Y$4T5T;7AM8#]G1TQ$0D!W;2Y")$)U;2DP(D]Z;6%"-3U*/WQM>VUO,'UM
M+TDG;EM&:S]90W@V)FXW33\Q5TIA,B%N(FXC;B1N.T8C0V,P*&XI;B-T/4(J
M;G,Q3$$O.%I-*VXL17A!5SPL;B]N93TM;BM!*D%D,$M.,6YR2#-N,FXP;F1C
M5#1N;35N-&XV;CA-848N2S=N63PX;CEN.FXA16HP63DZ3SYN-#<[;CQN=$E4
M,SE-/S9413]N0&Y!;B)%0VY";E-&1&XV/6`\6T=Q0W(\;#]%;D9N73]';DAN
M26YO33<]2VY*;EHY<SE`.TYN9CU-;DQN:4)O.$-`,$@Y/4]N7SY2;E!N46Y4
M;E-N>CY5;E9N5VY02%,Z83Q8;EEN)$Y%/6Y,3$Y:;F(V6VXC15YN>#-+/UQN
M76Y@1%5+?#9@;F%N7VYC;E]&0S-G;F1N9FYB;D]O96YK3EHX;VXT16IN;6YK
M;G!N<6YI;G9N=#%H;BU(;&Y@/ELY2$MD-D8]/$8M071N;FYS;D-,.$1U;G)N
M+$%Y;GAN=VXO2WL]>FY?2E0Q1DER0W@U?&Y=.2P[>VYM/VX_(6\C;WL^(F\D
M;U,V14EB/"-/?FYX.C]/)F\E;R=O?6YI1E5%5T0L;T-#*&\I;RTW*V\P."IO
M83YY,S!O/SIY04I$.S,N;R]O0T0M;S%O-V\Z;SEO+44R;S-O-F\X;T`V.V\U
M;S1O/V]`;T%O/F\];V(^*D8\;T5O0V]$;T)O>$)&;T=O26]5-$AO>DQ4;TIO
M36]+;TQO3F]0;U%O4F]5;U-O5F]8;U=O.41G3%EO+D%:;T1*6V\K,SPQ5S16
M-%QO76]>;U]O8&]8-%4S7CDV2&)O86]C;UPQ9F]E;V1O9V]J;T<P:&]L;VMO
M;F]M;V]O+D9P;W%O<V]R;VQ)=&]U;V4Z=F]W;TE+2T$D,$M">&]M27MO>6]?
M.7IO0CA%2GUO(7!^;R)P(3%8/WP]630C<&9')7`B,21P1$1-3BM&?&\F3C$X
M6TUY-C1.*#=B0B%G)G`L,V\_5C,H<"EP)W!D-UTZ8SXC,5E.*W`N;BIP+G`L
M<"UP+W`P<&Q.,7`R<$E`.TA]/V<T.DUM,C@]6S@U<#1P<SLV<#-P*#LZ<"UJ
M5E)W/SAP)4YQ1BLQ8T`V/#=*0#%M3FM-.W!%17L\/'`]<$P_/G!N3CEP0'!"
M<$%P/W!#<$1P>D%B,D5P.$Q&<$=P*D\Q6TAP27!*<$YP2W!,<$UP3W!$0'=,
M14!0<'-(47!3<TQ,4G!3<%1P5S-6<%D_5W`D-UAP7'!:<%MP<S-9<%UP7G!(
M,%]P8'!D/F%P1S5D<&-P8G!Q:UQ*97!F<&=P:'!I<&IP6C1K<&QP(T=N<#LR
M<7!P<"0Q039'2CI$(CI@.6<]7#]S<')P0DUH-%)(7$9\/TY.6S=V<'5P2TLL
M1E`Q=W!T<%%):DUX<'EP>W!J0ELS7#-Z<&DT,CAJ-#]%8$Y<.'QP?7!^<"%Q
M(W$B<7=))'$E<29Q)W$I<2AQ*G%T2$QF*3\R-2MQ+'$L4CM=4TA[,#LP=#LP
M2WX^+7%?3"YQ7$U",4$[+W%N,C!Q,7$S<31Q-G$R<35Q6S0W<3AQ.7$Z<3MQ
M/7$\<3]Q0G$^<4!Q07%#<4(V<SQ$<45Q83E&<3XS3T='<4AQ6D-K1DEQ?4=,
M0E@Q;C9O-G-#3G%P-F\R37%+<4QQ2G%8<4]Q4'%1<5)Q5'%3<5D]57%7<3,U
M5G%[03,X67%-0EIQ+49;<6!Q7G%=<5]Q7'%B<6%Q9'%#-F-Q97%F<6AQ9W%I
M<6MQ:G%\.6QQ;7$\,VYQ;W%Q/W!Q<7%R<7-Q8CET<75Q=G%W<7AQ,4AZ<29)
M>W%Y<7UQ?'%^<2%R(G(C<B1R)7(F<B=R*'(I<BIR*W(L<BUR+G(U72]R>&0T
M-2$S,CHQ<C!R)4PS<C1R,G(U<F)+-G)[-25/-W(Y<CXP.G(K2CAR.W(\<CUR
M/G(_<FY++3MZ.B]!0')#<D%R1')Q.$)R17)&<D=R2W(J.V1"3'))<DAR2G)?
M-U!R3W).<C,P6G)6<E=R4W)9<E5R8C-,3UAR5')2<E%R7')?<EYR77))25MR
M<S!@<F)R;S--<C<Q9')C<F%R+4-P2UI.97)F<F=R:')I<CM$:G(W2&]R:W)L
M<C%+1$Q01G!R<7(^1FYR;7(J,GER>')U,79R=7)S<GLS<G(R/"DR8SE\<GMR
M>G)W<GUR?G(E<R1S)G,M,2%S(G-T.3E,(W,R2RMS)W,L<RES*'-<-RUS+G,O
M<RIS='(P<V%$-',U<S-S,G,X<S%S-G,W<SIS.7,\<SUS/G-)3SMS:T)M.C]S
M0'-!<T)S0W,T.$1S17,O/$9S1W-(<TES3'-*<SQ/2W-O3DUS6TY.<WY'3W-1
M<U)S4'-M.4U,8TMW5F!=>TLK,E1S4#55<U9S5W-U.5AS5&!;3&-"67-;<UIS
M7'-=<UYS7W-@<V%S8G-C<V1S97-F<V=S:',D15TX:G--06MS;',A26US;G,W
M8UIL;7!O<W!S<G-S<W1S<$YQ<W5S=G-X<W=S>G-[<WES-DY\<WUS5&-^<RHA
M="%P(7,A=2%*(4LA=B%<(20A)2$_(3`C,2,R(S,C-",U(S8C-R,X(SDC)R$H
M(6,A82%D(2DA=R%!(T(C0R-$(T4C1B-'(T@C22-*(TLC3"--(TXC3R-0(U$C
M4B-3(U0C52-6(U<C6"-9(UHC3B%`(4\A,"$R(2XA82-B(V,C9"-E(V8C9R-H
M(VDC:B-K(VPC;2-N(V\C<"-Q(W(C<R-T(W4C=B-W(W@C>2-Z(U`A0R%1(3$A
M;R$``(,:>M^/&O__GQK__Z\:__^_&O__SQK_/]T:``#=&@``W1H``-T:``#=
M&@``W1H``-T:``#=&@``W1HH``````"O`8MON0'S0\(!0B3&`4:;S@$LZ-4!
MX./=`00`W@$*0.$!95_K`3;;]0%W>0`"200$`M?L#P+PXQ@".&`=`L4((@("
MYB@"`S0M`@"`+@)1-34"R.`[`JM^1@(`@D@":9A/`DBI50)"*5H"`^A@`F"`
M8P(<1&@"DZUQ`CK`=P)H17T"8*J#`E:&B@)Z/Y4"0`*7`HB#G`)A%*$"(!"C
M`G0AJ0(A(*P"`@>P`@`PL@*\0+@")*:^`F)$PP*H8,@"(`K+`A<"T`)TA=<"
M`@39`H2<WP+[>^P"%13Q`B1_^@+B$0`#9;8)`^\"$0-U'QL#_R`D`W`Z*P-`
M."\#PR8V`V-G/P/934@#DB!,`[!&4@/)#UH#F+QB`U!(9@,XAFP#/Z!T`X@C
M>0,6B'X#"3Z%`S)2BP.J(I$#I..9`]T`GP,LQZ<#9J&N`^$FM0,+A+H#"H_!
M`^LGRP.>5=0#0<+9`[N)X@,4`.0#0(7H`V%C[P-)"/,##'_\`]"*`@0^_P\$
MSP47!!K_(@0#J"<$07HN!$![-01%1SP$`H`^!``%0`3K.$D$4=A0!`4`4@0T
MF5D$#'%?!)<#9@0``6<$9F-O!`0D<@30@'8$40!Y!`#`>P0*0X`$<9"&!,@P
MBP0(`(P$`%B/!)D.E@0`]YT$@%^D!$$`I@2P`*D$$)2M!!@`KP2`8K,$0`*U
M!-`)N@0`@KP$5@'!!`10Q`0!",8$$!W+!!`%S@3!A-,$$`#4!"5`V`10$-L$
M#T'A!(I-Z`0)0.L$#:;R!!FK^@1,D0`%P"$$!8$)"`6%Q`X%`P`0!5(&%04`
M@!8%!`L:!0@`&P4=!"`%"0`B!4E()P5<D"T%"0`O!9`6-`5E##H%("(]!1*$
M004S)$<%`PQ+!99'4P4$"E8%)4);!2@`706(D&$%`$ED!0A/:@6B%&\%JM-X
M!3#8?@6'/H<%!(:+!6$?DP6D?IP%AD&A!9##IP6S!:X%I5>W!1@ANP4>),$%
M2"K&!2@1R@4$2LX%0`K1!1L6V`5@#=T%0(C@!0H"XP4"E>@%(8+L!6`0[P5#
M`O,%``3T!404^`4`@/D%``#Y!00,_`4``/P%`'#_!08:!`;!``<&2@(+!@`,
M#08`&A`&0``1!@04%`9%0!@&*0`;!K.])@9X"BP&*P4R!JF[/`:@OT4&?$!+
M!GF#4P;\$EL&'>AC!O9+;09IQ74&]N^"!DH$A@85(8L&`O^4!F/MG@8K0*,&
M,]"J!D("K08`$*X&$P"Q!@(;M@;*6;X&H`#`!@`"P08#I\@&02S-!H!(T`;R
MC]H&!`+<!@``W`8`6-\&!1#B!@"2Y09(`.<&E!CL!@$@[@8$4/$&@#3U!@`R
M^`9,:/X&ZDD&![YH#P=,&!0'0BX:!R"H'@?)(20'N5`K!["`+P<>`#,'?/]`
M!YJ$1@?@%$L'P2A0!^`!5`<.AUL'2:QB!P\3:0?;W74'&KY^!_N)B`?@HHX'
MHE&4!P)5F0?*,J`'1CZH!XN2KP>_';H'CT/"!P-GR0<8,LX'*##2!\`SV`<1
M"-L'(ZGB!P#`Y`=E.NP'XX_V!P($^`=.+/\')88%"#V_$0BA`!0(&CH;"-2,
M(@C)!B@(?#$P".``,P@*E3D(BP$^"-L.1PA+XU`(((Q4"((16`@0\%T(E'UF
M""BG;0BLR74(^T!]"(1$@0A3!H<(D%J-"$1$D0C(/YH(`0";"$@`G0C4]:<(
M`7>N"%?LN`A"Q+T('8G$"(-KS`@H2=$("4'5"$+2VP@=!N$(_EGL"``8[@@B
M.O0(Y+?^")\["0D#\`\)ZL`6"883'`D"@A\)@(DC"0#D)PD`LBL)H1`O"8!+
M-`G$##D)"=-`"42)10FO'U`)-$A5"5F"6PE%#&`)"D)D"5`$9PE`H&H)R!!N
M"4`Q<@E01'8)!$!X"0`!>0F`@GP)0`5_"0@!@0DL1(8),&J,"04:D0FF()8)
M%`6:"<^0H@E69*D)(0"K"0`QK@D8G+0)\,N]"2"AP0GB8\D)3!#-";4!TPF,
M4]H)@YKA";*XZ0F!,NX)>ICV"80*^@GG,P0*`@P'"LS4#PH8D!,*H:$9"G"0
M'@H>BB4*!.`I"M3#,0I1!#4*FD,\"L(A00I$2$4*$%-*"I("3@I`-E,*00)6
M"KWS8@H)JVD*\.AQ"L!]>0K2I8$*0L*&"DO2C@H_I)<*K]"@"J`:I0JA-*L*
M1X*Q"M@#MPI2Q+T*&V7%"I32S`HZR-,*'`#6"LA`V@H&#M\*%#/E"D]A[0H;
MLO4*B`#W"M#`_`HJH`$+F*@'"\6A#@MK%A8+4"X<"[2%(PN+P"D+!`8L"S/Y
M-@L$'CL+;@5""U&B2`L`!$D+.'91"P?L60NX<V(+!D1F"S(8:PN!0&X+%LAT
M"XI\?`L)8X(+@"F&"P2JBPLD')`+G,J8"PY.GPM@)Z4+D`FI"P"#K`M&`*\+
M!(&R"Q%@M@N!$+D+#52_"P@)P@L.`,4+"LS+"P`%S0L`#,\+,`32"T2@U@N+
M`-H+A&?A"XA2Y@L9BNP+7H;T"QB+^@M9+@(,8$$&#!","@R^G!0,86@:#!R)
M(`P`F",,"``D#`"!)@R:""L,&``M#)!!,0P'0#4,H>0\#`4%0`P-9$8,#C%,
M#$T.4PP&2%<,"O]A##(69PRH*FT,+H5T#`L`=PP`&'D,A,I_#"`.@PQL:8L,
M,@".#``6D0Q85I@,D`.<#"!1H`PH&J4,`("F#"01J@SA&+`,)D.V#%)=O@RJ
M#L4,H`_+#"BNT@Q[^MX,`$7A#`ADY0Q`B>D,@,CM#$3`\0P%D/4,0;'[#"2$
M_PS$)`0--!H*#3I@$`T`D!(-E,$8#4:"'0TZ`"$-#1@F#0;!*PTB`"T-$)DR
M#5#@-PT1%3P-5T!"#8(`1`T:!$@-"@)+#4\`4`TPB54-$]A<#4I$80T"BF4-
M(NUM#<`0<`T%0',-`!!T#0(!=@T(B'D-`3%]#0!&@`T$`H(-`/"&#0@'B@T`
MB8T-`**0#0``D`T"(I,-``*4#1`6F`U"`)H-0!"<#0!2GPU@`J(-]%*J#0`@
MJPT0A:\-,(*S#0`1M0T"0K@-"$.\#;6`P@WA<,D-()K.#4`@T`T!"-(-`#76
M#67\X`W!&>8-!*OL#88"\`T48O4-AP#Y#40`^PV%D``.1`(##EQ`"`Z%"@T.
M!S(3#H`S&`X`!!D.P+@?#B#.)0[0P"H.,,`N#H``+PX(!3(.)0TX#I`*/`Y`
M`#T.``(^#@P(00X%94<.`$!(#B%D30X"05`.:`)4#@``5`XD`%8.?(1=#@(`
M7@X@WF4.&89K#DE`;PX("'$.`$!R#H0`=`X!('8.`(1X#A`0>@[-0H$.QP&'
M#CAPC0XJU94.:!F;#H\=I`Y0OJP.$CZS#O4NO0[9@<0.Q,[,#A(DT`XH"-,.
M+G/<#JPDX@XT2^D.#`+L#AW4]`X"*O@.`(#Y#I<`_@X1"`$/Q!$&#T01"@^&
M%Q$/17T:#]E)(@])!B</`$`H#Y&'+P],)34/Q-@\#[I$0P\424@/DAM/#P#(
M4@]Q`E</@!5;#X$`70\`#%\/:@EE#P#":`\`2&H/`D!L#R$P<`])NG@/@"!Z
M#X`<?@^LXH8/"!"(#P00B@\T`(T/X0"1#Q2$E0\@`)8/`""7#P"8F@\4$)T/
MPG"C#ZH$J`^(AJT/(%2Q#V(,M@\3!+H/@)&^#Q`@P`^"0,,/!@+&#T`<R@\`
M5,T/@P/2#^GDVP\E(>`/@(3C#S/DZP\`(.P/P$3P#PGF]P\#"OL/)H$`$-H2
M!Q`!"`D0`6D.$)"7%1`!0!<0AO@?$$WB)Q"!`"D0#@HN$%&F-1`:`3D0[(%`
M$`#&1!!!A$@0N*U1$"RV61!OI&(008=H$%2-;Q`"2W0081%Y$&@"?1!@NX40
M5R"+$*!0CQ`S!)00P*B9$+2WHQ`")*80$@&I$-.:LA``(+,0<2*Y$,@`O!"!
M(+\0GH#%$(H,RA"`X<\0";#4$%&!V1`Q$-T0*$#@$`XJYA"EB>T0MFGV$`YB
M_!`E1`$11-$'$86`"Q%431(1=2P:$;$?(Q$'V"H1+88Q$7S8.A%!2#X13D%$
M$6XB2Q$`@DT1")Y3$0SX6A$W[641@(QI$29U<1$3DW@1%`A[$3(.@1$$R(41
M3DB+$:9NE!%*+)H1<&:A$<`FIA$!NJP1#-.S$5T8NA$``+H1``"Z$0``NA$`
M`+H1``"Z$0``NA$``+H1``"Z$0``NA%`!;T1('#!$3.!QQ&!3\X1I0/4$>Q5
MW1$09.$1&,/G$40C[!%B%/$1-`#T$4,*^1$)&OX1>Q@&$J43#1("`0\22*@4
M$D`$%A)$Q1P2!H$@$MWB*A+P&C$22"TW$B:V/Q(6!$,26%!($D!N3A(R@%(2
M$C%7$N0'7A(`#&`2"()C$@I"9Q)`2&H2.X!P$F!(=!(3AWL2#86!$B@TAA(9
M`XL2*>63$D4CF1(*AY\2J26F$AA<K!*F=[82Q=F_$@!>Q!+H`\H2@0#,$@"G
MT1)4S=D2QD'?$@`HX1($HN428+CK$@HK\1(@`/(2GMK\$NH(`A,:#@@3?$(/
M$\`1$Q,(B1<3=@,>$R&&(Q,%`283```F$Z@8*Q.@1C`32,0U$P4-.A,B(#T3
M(E1"$TB11Q,!BDL3ERA2$YAX61,(`%H3!19?$R(Q9!-`0F<3@`AI$T[Z<Q.B
M!G@3%`A[$Q&2@!,"(((3!)N($U(NCQ-#!I03`%"6$Q"0F1-!`)L3NH6C$T(P
MIQ,@(*D3"T^Q$Z`%M1,()[H3@$"\$Y$%P1.3&L@34-_1$P`&TQ,"HM<3(3#;
M$S`&WQ.`3N03Q`SI$\@$[1,$H/`3`8#R$P!@]!,QU/L3@`C]$P(*`!0`'`,4
M*``%%!B."Q1!``T4T&H4%!#*&100\A\4`$LC%$TG*Q0&%3`4(`(R%)"(-A0`
M6CH4J((_%$E%1110@4D4!"!+%`"`3!0$B$\4""Q3%-$(6!0%`%H4`8!<%,1*
M8A0@X&848@!I%(X`;11""G$453!W%(QJ?A0."8,4I>"*%`8ICQ3$0I04%$B8
M%+.`GA0^@*04,+.K%`(!K10<<[44E!2Z%`U@OQ0@#,(40`G%%!HPRA1`P,T4
M4:33%)3`V!3*C>`4R`7E%,*6[!0,I/$4`0#R%`0T]A3(`/D4$`'[%`U5`A7)
MJ0H5*"0.%5H<%15"`1@5-T@?%4UZ*!4/$"T5M#(T%2I%.A5[,4,5!9)(%92X
M3Q5$7%45UVA>%8I%9!674&L5T2YS%4,9>14(0GP5`M*!%4"=AQ5`F(L5ER"1
M%0E4EA5-!IP5``"<%0``G!4``)P5``"<%0``G!4``)P5``"<%0``G!4``)P5
M@(2?%4)5I14A!*@5!ARM%0`7L14D=K@5$&&\%8?_R!7=N=,5GV7=%0I<XQ5=
M).H5`#SN%;"M]A59`/H5``#Z%0``^A4``/H5``#Z%=`H_Q6;``06(@0'%@`"
M"!8(`0H6"$0-%@28$19`K!86"HT<%BB0(!8`AR06`>`H%@`$*18Q`"P6E!<S
M%B&"-Q89`#H65!`^%K(L118:`DD6`IQ.%@-`419@/5@6!(A;%@P(7A8`>6,6
M*!9H%CRZ<19`AG46",M[%G1R@Q:`D(86'@"*%@``BA8``(H6`-B.%HCAE!:'
MG)P6-$"@%A($HQ9DKJL6D2>R%FOHNQ;[YL<6CT#-%F93U1:F[M\6?U/J%BOC
M\Q;DM?P6GX8%%P(`!A=(A0L7(@$.%P)$$1<`"!(7%B$7%Z`@&A<$`!L7!`(=
M%P`@'A<%`"`7`'XF%U0!*A<L%C`7K`$U%X0J.A>%$#X7%(Q#%S`%1Q?#^U(7
M0[E:%\H`7A=@D&(7`&!D%S)`:!<`$FH7D(!M%S`+<A>!3'<75`!Z%P)`?!<I
M`'\7:AV'%P`@B!>``HH7`("+%P0`C!<0)I`7#!65%T"`EQ<!!YL73=FD%R0,
MJ!<0**L74!BO%P%0LA<@4+47`!"V%]`$NA>`<+X7`0+`%P@!PA?#(<@7,@',
M%P``S!>(`,X7&0?4%P((UA=@!=H7$@#<%PY,XA<%!.47H?#L%P(`[1<``.T7
M``#M%P``[1<``.T7``#M%P``[1<``.T7``#M%P``[1<``.T7``#M%P``[1<`
M`.T7``#M%X``[A>-CO876@/\%[TA!!@$6@D8B#0.&'`1$Q@F`!88```6&```
M%A@`$!<8`L4<&`2('Q@5N"88`?@L&'P4,QCM)3P88.U$&+`;2QB)!5`8UQM:
M&/-Z91AB&FL8#`UP&,4*=AC1Y7\82E*%&)`$B!@%8XX85`.3&$12F!A7*Z$8
M$A:F&'*HK1@!$;`822FV&!@`N!A(";P8"!"^&`!@P!ALB,88;I'.&(\%U1@2
M,-D8D#G?&$#XY1@P2>H8@(CM&!L`\1@``/$8``#Q&`"%]!A"`/886`#Y&`"8
M_!@$Z@(9%'`'&2@6#!D=81,9$U$9&0!@&QDD&B`9IP`E&0``)1D``"49```E
M&<`#*1D@<2X9&!`Q&7(!-ADGJ3X9!&!!&0:)1ADBP$H9#`)-&0`)3QF!0%(9
M+2!7&:",7!DT#F(9``!B&0``8AD``&(9`"%D&0$19QD1@&H9&L%P&4SL>!F2
M"'P90`!]&0"%@!FLQXD9!AB-&3[@E1D2!9D9`(":&1``FQD(0)T9SH"C&0%M
MJ1D0`JL908:P&58(M1D>`;H9)P"^&5`WQ1D]",L9,N#1&05.UQG``=H9A`3=
M&8$`WQE``>$9``#A&0``X1D``.$9``#A&0``X1D``.$9H!KF&5D`ZAG(0_`9
M)(CT&4@=^AD`R/T94@$!&@-R!QH3D`P:!`0.&H""$1H`!!(:$(H6&A0-&QI6
M@"`:"`(B&D"@)1H$)RH:```J&@!,+1H``"T:```M&@``+1H``"T:```M&B"C
M,AH"&38:KJ`]&F`F0AH`WTD:$/!.&A5[5QHA@5L:T#IB&H!!91HH`&<:`Q!J
M&@!(;!H`S'`:%(!S&L\4>QK$`'X:`"!_&B`P@AH!````````````````````
M````````Z`#O__<`/Q#^````_@```/X`_O\-`?__'0'__RT!__\]`?__30$/
M>%4!_O]D`?__=`'__X0!__^4`?__I`%_>+4`#Y"[`)DYPP`YF<L`F9G3``0(
MU0```-4```#5````U0```-4```#5``,`UP`,,-L`P,C@````X```@.$```#A
M`&``XP```.,```#C````XP`%`.4```#E``"D`````'T```!]`&$SA`!C`(@`
M#0B,````C````(P```",````C````(P```",````C````(P```",````C```
M`(P```",``@`C0```(T```B.````C@```(X```".````C@```(X```".``\`
MD@```)(```"2````D@`4`)0```"4````E`"-"9H`!&2>`($?I0`P(*@```"H
M``0`J0###*\```"O`,P`LP```+,`(`"T````M````+0```"T````M````+0`
M``"T``0`````````````````````````````````"P````L````+````"P``
M``L````+````"P````L````+````"P#^_QH`^P,C`/[_,@#[`SL````[````
M.P```#L``@`\`/__3`#__UP`__]L`/__?``"````````````````````````
M````````````````````````````````````````````C!$%`%,`"0````D`
M@``*````"@"``)Q.%E4#6C^6P%0;82AC]EDBD'6$'(-0>JI@X6,E;NUE9H2F
M@O6;DV@G5Z%E<6*;6]!9>X;TF&)]OGV.FQ9BGWRWB(E;M5X)8Y=F2&C'E8V7
M3V?E3@I/34^=3TE0\E8W6=19`5H)7-]@#V%P81-F!6FZ<$]U<'7[>:U][WW#
M@`Z$8X@"BU60>I`[4Y5.I4[?5[*`P9#O>`!.\5BB;CB0,GHH@XN"+YQ!47!3
MO53A5.!6^UD57_*8ZVWD@"V%8I9PEJ"6^Y<+5/-3AUO/<+U_PH_HEF]37)VZ
M>A%.DWC\@29N&%8$51UK&H4[G.59J5-F;=QTCY5"5I%.2Y#RED^##)GA4[95
M,%MQ7R!F\V8$:#AL\VPI;5MTR'9.>C28\8);B&"*[9*R;:MURG;%F:9@`8N*
MC;*5CFFM4X91$E<P6$19M%OV7BA@J6/T8[]L%&^.<!1Q67'5<3]S`7YV@M&"
MEX5@D%N2&YUI6+QE6FPE=?E1+EEE68!?W%^\8OIE*FHG:[1KBW/!?U:)+)T.
MG<2>H5R6;'N#!%%+7+9AQH%V:&%R64[Z3WA3:6`I;D]Z\Y<+3A93[DY53SU/
MH4]S3Z!2[U,)5@]9P5JV6^%;T7F'9IQGMF=,:[-L:W#"<XUYOGD\>H=[L8+;
M@@2#=X/O@].#9H>RBBE6J(SFCTZ0'I>*AL1/Z%P18EER.W7E@;V"_H;`C,66
M$YG5F<M.&D_CB=Y62EC*6/M>ZU\J8)1@8F#081)BT&(Y94&;9F:P:'=M<'!,
M=89V=7VE@OF'BY6.EIV,\5&^4A99LU2S6Q9=:&&"::]MC7C+A%>(<HJGD[B:
M;&VHF=F&HU?_9\Z&#I*#4H=6!%337N%BN60\:#AHNVMR<[IX:WJ:B=*):XT#
MC^V0HY64EFF79ENS7'UI39A.F)MC('LK:G]JMF@-G%]O<E*=57!@[&([;0=N
MT6Y;A!")1(\43CF<]E,;:3IJA)<J:%Q1PWJRA-R1C)-;5BB=(F@%@S&$I7P(
M4L6"YG1^3H-/H%'26PI2V%+G4OM=FE4J6.99C%N86]M;<EYY7J-@'V%C8;YA
MVV-B9=%G4VCZ:#YK4VM7;")OEV]%;[!T&'7C=@MW_WJA>R%\Z7TV?_!_G8!F
M@IZ#LXG,BJN,A)!1E).5D96BE666TY<HF1B".$XK5+A<S%VI<TQV/'>I7.M_
M"XW!EA&85)A8F`%/#D]Q4YQ5:%;Z5T=9"5O$6Y!<#%Y^7LQ?[F,Z9]=EXF4?
M9\MHQ&A?:C!>Q6L7;'UL?W5(>6-;`'H`?;U?CXD8BK2,=XW,CAV/XI@.FCR;
M@$Y]4`!1DUF<6R]B@&+L9#IKH'*1=4=YJ7_[A[R*<(NL8\J#H)<)5`-4JU54
M:%AJ<(HG>'5GS9YT4Z);&H%0A@:0&$Y%3L=.$4_*4SA4KEL37R5@464]9T)L
M<FSC;'AP`W1V>JYZ"'L:??Y\9GWG95MRNU-%7.A=TF+@8AEC(&Y:AC&*W8WX
MD@%OIGE:FZA.JTZL3IM/H$_14$=1]GIQ4?915%,A4W]3ZU.L58-8X5PW7TI?
M+V!08&U@'V-994MJP6S"<NUR[W?X@`6!"().A?>0X9/_EU>96IKP3MU1+5R!
M9FUI0%SR9G5IB7-0:(%\Q5#D4D=7_ETFDZ1E(VL]:S1T@7F]>4M[RGVY@LR#
M?XA?B3F+T8_1D1]4@))=3C90Y5,Z4]=REG/I=^:"KX[&F<B9TIEW41IA7H:P
M57IZ=E#36T>0A98R3MMJYY%17$A<F&.?>I-L=)=ACZIZBG&(EH)\%VAP?E%H
M;)/R4AM4JX43BJ1_S8[AD&93B(A!><)/OE`14D114U4M5^ISBU=166)?A%]U
M8'9A9V&I8;)C.F1L96]F0F@3;F9U/7K[?$Q]F7U+?FM_#H-*@\V&"(ICBF:+
M_8X:F(^=N(+.C^B;AU(?8H-DP&^9ED%HD5`@:WIL5&]T>E!]0(@CB@AG]DXY
M4"9095!\43A28U*G50]7!5C,6OI>LF'X8?-B<F,<:2EJ?7*L<BYS%'AO>'E]
M#'>I@(N)&8OBC-*.8Y!UDWJ659@3FGB>0U&?4[-3>UXF7QMND&Z$<_YS0WTW
M@@"*^HI0EDY."U#D4WQ4^E;1661;\5VK7B=?.&)%9:]G5F[0<LI\M(BA@.&`
M\(-.AH>*Z(TWDL>69Y@3GY1.DDX-3TA3250^5"]:C%^A7Y]@IVB.:EIT@7B>
MBJ2*=XN0D5Y.R9ND3GQ/KT\94!9025%L49]2N5+^4II3XU,15`Y4B5515Z)7
M?5E46UU;CUOE7>==]UUX7H->FEZW7AA?4F!,89=BV&*G8SME`F9#9O1F;6<A
M:)=HRVE?;"IM:6TO;IUN,G6'=FQX/WK@?`5]&'U>?;%]%8`#@*^`L8!4@8^!
M*H)2@TR(88@;BZ*,_(S*D'61<9(_>/R2I)5-E@68F9G8FCN=6U*K4O=3"%35
M6/=BX&]JC%^/N9Y+43M22E3]5D!Z=Y%@G=*>1',);W"!$77]7]I@J)K;<KR/
M9&L#F,I.\%9D5[Y86EIH8,=A#V8&9CEHL6CW;=5U.GUN@D*;FTY03\E3!E5O
M7>9=[EW[9YEL<W0">%"*EI/?B%!7IUXK8[50K%"-40!GR51>6+M9L%MI7TUB
MH6,]:'-K"&Y]<,>1@'(5>"9X;7F.93!]W(/!B`F/FY9D4BA74&=J?Z&,M%%"
M5RJ6.EB*:;2`LE0.7?Q7E7CZG5Q/2E*+5#YD*&849_5GA'I6>R)]+Y-<:*V;
M.7L94XI1-U+?6_9BKF3F9"UGNFNIA=&6D';6FTQC!I.KF[]V4F8)3IA0PE-Q
M7.A@DF1C95]HYG'*<R-UEWN"?I6&@XO;C'B1$)FL9:MFBVO53M1..D]_3SI2
M^%/R4^-5VU;K6,M9R5G_65!;35P"7BM>UU\=8`=C+V5<6Z]EO67H99UG8FM[
M:P]L17-)><%Y^'P9?2M]HH`"@?.!EHE>BFF*9HJ,BNZ*QXS<C,R6_)AO:XM.
M/$^-3U!15UOZ6TAA`6-"9B%KRVZ[;#YRO734=<%X.GD,@#.`ZH&4A)Z/4&Q_
MG@]?6(LKG?IZ^(Z-6^N6`T[Q4_=7,5G)6J1;B6!_;@9OOG7JC)];`(7@>W)0
M]&>=@F%<2H4>?@Z"F5$$7&AC9HV<96YQ/GD7?06`'8O*CFZ0QX:JD!]0^E(Z
M7%-G?'`U<DR1R)$KD^6"PELQ7_E@.T[64XA;2V(Q9XIKZ7+@<RYZ:X&CC5*1
MEID24==3:E3_6XAC.6JL?0"7VE;.4VA4EULQ7-Y=[D\!8?YB,FW`><MY0GU-
M?M)_[8$?@I"$1HARB9"+=(XOCS&02Y%LD<:6G)'`3D]/15%!4Y-?#F+49T%L
M"VYC<R9^S9&#DM13&5F_6]%M77DN?IM\?EB?<?I14XCPC\I/^UPE9JQWXWH<
M@O^9QE&J7^QE;VF):_-MEFYD;_YV%'WA7760AY$&F.91'5)`8I%FV68:;K9>
MTGUR?_AFKX7WA?B*J5+94W-9CUZ07U5@Y))DEK=0'U'=4B!31U/L4^A41E4Q
M51=6:%F^63Q:M5L&7`]<$5P:7(1>BE[@7G!??V*$8MMBC&-W8P=F#&8M9G9F
M?F>B:!]J-6J\;(AM"6Y8;CQQ)G%G<<=U`7==>`%Y97GP>>!Z$7NG?#E]EH#6
M@XN$285=B/.('XH\BE2*<XIAC-Z,I)%FDGZ3&)2<EIB7"DX(3AY.5TZ747!2
MSE<T6,Q8(ELX7L5@_F1A9U9G1&VV<G-U8WJXA'*+N)$@DS%6]%?^F.UB#6F6
M:^UQ5'YW@'*"YHG?F%6'L8\[7#A/X4^U3P=5(%K=6^E;PU].82]CL&5+9NYH
MFVEX;?%M,W6Y=1]W7GGF>3-]XX&O@JJ%JHDZBJN.FX\RD-V1!Y>Z3L%.`U)U
M6.Q8"UP:=3U<3H$*BL6/8Y9MER5[SXH(F&*1\U:H4Q>0.52"5R5>J&,T;(IP
M87>+?.!_<(A"D%21$),8DX^67G3$F@==:5UP9:)GJ(W;EFYC26<9:<6#%YC`
MEOZ(A&]Z9/A;%DXL<%UU+V;$4392XE+368%?)V`08C]E=&4?9G1F\F@6:&-K
M!6YR<A]UVW:^?%:`\%C]B'^)H(J3BLN*'9"2D5*769>)90YZ!H&[EBU>W&`:
M8J5E%&:09_-W37I-?#Y^"H&LC&2-X8U?CJEX!U+98J5C0F288BV*@WK`>ZR*
MZI9V?0R"28?93DA10U-@4Z-;`EP67-U=)F)'8K!D$V@T:,EL16T7;=-G7&].
M<7UQRV5_>JU[VGU*?JA_>H$;@CF"IH5NBLZ,]8UXD'>0K9*1DH.5KIM-4H15
M.&\V<6A1A7E5?K.!SGQ,5E%8J%RJ8_YF_69::=ERCW6.=0YY5GG?>9=\('U$
M?0>&-(H[EF&0()_G4'52S%/B4PE0JE7N6$]9/7*+6V1<'5/C8/-@7&.#8S]C
MNV/-9.EE^6;C7<UI_6D5;^5QB4[I=?AVDWK??,]]G'UA@$F#6(-LA+R$^X7%
MB'"-`9!MD)>3')<2FL]0EUB.8=.!-84(C2"0PT]T4$=2<U-O8$EC7V<L;K.-
M'Y#73UY<RHS/99I]4E.6B'91PV-86VM;"EP-9%%G7)#63AI9*EEP;%&*/E45
M6*59\&!38L%G-8)5:4"6Q)DHFE-/!EC^6Q"`L5PO7H5?(&!+831B_V;P;-YN
MSH!_@=2"BXBXC`"0+I"*EMN>VYOC3O!3)UDL>XV13)CYG=UN)W!34T15A5M8
M8IYBTV*B;.]O(G07BCB4P6_^BCB#YU'XANI3Z5-&3U20L(]J63&!_5WJ>K^/
MVF@WC/AR2)P]:K"*.4Y84P969E?%8J)CYF5.:^%M6VZM<.UW[WJJ>[M]/8#&
M@,N&E8I;D^-6QU@^7ZUEEF:`:K5K-W7'BB10Y7<P5QM?96!Z9F!L]'4:>FY_
M]($8AT60LYG)>UQU^7I1>\2$$)#I>9)Z-H/A6D!W+4[R3IE;X%^]8CQF\6?H
M;&N&=X@[BDZ1\Y+0F1=J)G`J<^>"5X2OC`%.1E'+48M5]5L67C->@5X47S5?
M:U^T7_)A$6.B9AUG;F]2<CIU.G=T@#F!>(%VA[^*W(J%C?.-FI)WE0*8Y9S%
M4E=C]'859XALS7/#C*Z3<Y8E;9Q8#FG,:?V/FI/;=1J06E@":+1C^VE#3RQO
MV&>[CR:%M'U4DS]I<&]J5_=8+%LL?2IR"E3CD;2=K4Y.3UQ0=5!#4IZ,2%0D
M6)I;'5Z57JU>]UX?7XQ@M6(Z8]!CKVA`;(=XCGD+>N!]1X("BN:*1(X3D+B0
M+9'8D0Z?Y6Q89.)D=67T;H1V&WMID-&3NF[R5+E?I&1-C^V/1))X46M8*5E5
M7)=>^VV/?AQUO(SBCEN8N7`=3[]KL6\P=?N63E$05#585UBL66!<DE^795QG
M(6Y[=M^#[8P4D/V039,E>#IXJE*F7A]7=%D28!)06E&L4<U1`%(055186%A7
M695;]ER+7;Q@E6(M9'%G0VB\:-]HUW;8;6]NFVUO<,AQ4U_8=7=Y27M4>U)[
MUGQQ?3!28X1IA>2%#HH$BT:,#XX#D`^0&91VEBV8,)K8E<U0U5(,5`)8#ERG
M89YD'FVS=^5Z](`$A%.0A9+@7`>=/U.77[-?G&UY<F-WOWGD>])K['*MB@-H
M86KX48%Z-&E*7/:<ZX+%6TF1'G!X5F]<QV!F98QL6HQ!D!.8453'9@V22%FC
MD(5134[J49F%#HM8<'IC2Y-B:;29!'YW=5=38&G?CN.676R,3CQ<$%_ICP)3
MT8R)@'F&_U[E97-.95&"63]<[I?[3HI9S5^-BN%OL'EB>>=;<80K<[%Q=%[U
M7WMCFF3#<9A\0T[\7DM.W%>B5JE@PV\-??V`,X&_@;*/EXFDAO1=BF*M9(>)
M=V?B;#YM-G0T>$9:=7^M@JR9\T_#7MUBDF-796]GPW9,<LR`NH`ICTV1#5#Y
M5Y):A6AS:61Q_7*WC/)8X(QJEAF0?X?D>>=W*80O3V526E/-8L]GRFQ]=I1[
ME7PV@H2%ZX_=9B!O!G(;?JN#P9FFGOU1L7MR>+A[AX!(>^AJ85Z,@%%U8'5K
M46*2C&YZ=I>1ZIH03W!_G&)/>Z65Z9QZ5EE8Y(:\EC1/)%)*4\U3VU,&7BQD
MD65_9SYL3FQ(<J]R[7-4=4%^+(+IA:F,Q'O&D6EQ$ICOF#UC:69J=>1VT'A#
MA>Z&*E-14R94@UF'7GQ?LF!)8GEBJV*09=1KS&RR=:YVD7C8><M]=W^E@*N(
MN8J[C'^07I?;F`MJ.'R94#Y<KE^'9]AK-70)=XY_.Y_*9Q=Z.5.+=>V:9E^=
M@?&#F(`\7\5?8G5&>SR09VCK69M:$'U^=BR+]4]J7QEJ-VP";^)T:'EHB%6*
M>8S?7L]CQ772>=>"*)/RDIR$[88MG,%4;%^,95QM%7"GC-.,.YA/9?9T#4[8
M3N!7*UEF6LQ;J%$#7IQ>%F!V8G=EIV5N9FYM-G(F>U"!FH&9@ER+H(SFC'2-
M')9$EJY/JV1F:QZ"881JA>B0`5Q3::B8>H17A0]/;U*I7T5>#6>/>7F!!XF&
MB?5M%U]58KALSTYI<I*;!E([5'16LUBD86YB&G%N68E\WGP;??"6AV5>@!E.
M=4]U44!88UYS7@I?Q&<F3CV%B95;EG-\`9C[4,%85G:G>"52I7<1A89[3U`)
M64=RQWOH?;J/U(]-D+]/R5(I6@%?K9?=3Q>"ZI(#5U5C:6LK==R(%(]">M]2
MDUA580IBKF;-:S]\Z8,C4/A/!5-&5#%825F=6_!<[UPI799>L6)G8SYEN64+
M9]5LX6SY<#)X*W[>@+."#(3LA`*'$HDJBDJ,II#2DOV8\YQLG4].H4Z-4%92
M2E>H63U>V%_97S]BM&8;9]!GTFB242%]JH"H@0"+C(R_C'Z2,I8@5"R8%U/5
M4%Q3J%BR9#1G9W)F=T9ZYI'#4J%LAFL`6$Q>5%DL9_M_X5'&=FEDZ'A4F[N>
MRU>Y62=FFF?.:^E4V6E57IR!E6>JF_YG4IQ=:*9.XT_(4[EB*V>K;,2/K4]M
M?K^>!TYB88!N*V\3A7-4*F=%F_-=E7NL7,9;'(=*;M&$%'H(@9E9C7P1;"!W
MV5(B62%Q7W+;=R>789T+:7]:&%JE40U4?50.9M]V]X^8DO2<ZEE=<L5N35')
M:+]]['UBE[J>>&0A:@*#A%E?6]MK&W/R=K)]%X"9A#)1*&?9GNYV8F?_4@69
M)%P[8GY\L(Q/5;9@"WV`E0%37TZV41Q9.G(V@,Z1)5_B=X13>5\$?:R%,XJ-
MCE:7\V>NA5.4"6$(8;EL4G;MBCB/+U513RI1QU++4Z5;?5Z@8()AUF,)9]IG
M9VZ,;39S-W,Q=5!YU8B8BDJ0D9#UD,26C8<568A.64\.3HF*/X\0F*U0?%Z6
M6;E;N%[:8_ICP63<9DIIV&D+;;9NE'$H=:]ZBG\`@$F$R82!B2&+"HYED'V6
M"IE^89%B,FN#;'1MS'_\?\!MA7^ZA_B(96>Q@SR8]Y8;;6%]/81JD7%.=5-0
M701KZV_-A2V&IXDI4@]495Q.9ZAH!G2#=.)USXCAB,R1XI9XEHM?AW/+>DZ$
MH&-E=8E206V<;@ET675K>))\AI;<>HV?MD]N8<5E7(:&3JY.VE`A3LQ1[EN9
M98%HO&T?<T)VK7<<>N=\;X+2BGR0SY%UEAB8FU+1?2M0F%.79\MMT'$S=.B!
M*H^CEE><GYY@=$%8F6TO?5Z8Y$XV3XM/MU&Q4KI='&"R<SQYTX(TDK>6]I8*
MEY>>8I^F9G1K%U*C4LAPPHC)7DM@D&$C;TEQ/GST?6^`[H0CD"R30E1OF]-J
MB7#"C.^-,I>T4D%:REX$7Q=G?&F4:6IM#V]B<OQR[7L!@'Z`2X?.D&U1DYZ$
M>8N`,I/6BBU0C%1QBFIKQ(P'@=%@H&?RG9E.F$X0G&N*P85HA0!I?FZ7>%6!
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?\,7Q!.
M%4XJ3C%.-DX\3C].0DY63EA.@DZ%3FN,BDX2@@U?CDZ>3I].H$ZB3K!.LTZV
M3LY.S4[$3L9.PD[73MY.[4[?3O=."4]:3S!/6T]=3U=/1T]V3XA/CT^83WM/
M:4]P3Y%/;T^&3Y9/&%'43]]/SD_83]M/T4_:3]!/Y$_E3QI0*%`44"I0)5`%
M4!Q/]D\A4"E0+%#^3^]/$5`&4$-01U`#9U504%!(4%I05E!L4'A0@%":4(50
MM%"R4,E0RE"S4,)0UE#>4.50[5#C4.Y0^5#U4`E1`5$"4191%5$441I1(5$Z
M43=1/%$[43]10%%244Q15%%B4?AZ:5%J46Y1@%&"4=A6C%&)48]1D5&34951
MEE&D4:91HE&I4:I1JU&S4;%1LE&P4;51O5'%4<E1VU'@456&Z5'M4?!1]5'^
M4012"U(44@Y2)U(J4BY2,U(Y4D]21%)+4DQ27E)44FI2=%)I4G-2?U)]4HU2
ME%*24G%2B%*14JB/IX^L4JU2O%*U4L%2S5+74MY2XU+F4NV8X%+S4O52^%+Y
M4@93"%,X=0U3$%,/4Q53&E,C4R]3,5,S4SA30%-&4T53%TY)4TU3UE%>4VE3
M;E,867M3=U."4Y93H%.F4Z53KE.P4[93PU,2?-F6WU/\9NYQ[E/H4^U3^E,!
M5#U40%0L5"U4/%0N5#94*50=5$Y4CU1U5(Y47U1Q5'=4<%225'M4@%1V5(14
MD%2&5,=4HE2X5*54K%3$5,A4J%2K5,)4I%2^5+Q4V%3E5.94#U445?U4[E3M
M5/I4XE0Y54!58U5,52Y57%5%55955U4X53-5756958!5KU2*59]5>U5^59A5
MGE6N57Q5@U6I58=5J%7:5<55WU7$5=Q5Y%745116]U465OY5_54;5OE53E90
M5M]Q-%8V5C)6.%9K5F16+U9L5FI6AE:`5HI6H%:45H]6I5:N5K96M%;"5KQ6
MP5;#5L!6R%;.5M%6TU;75NY6^58`5_]6!%<)5PA7"U<-5Q-7&%<65\=5'%<F
M5S=7.%=.5SM70%=/5VE7P%>(5V%7?U>)5Y-7H%>S5Z17JE>P5\-7QE?45])7
MTU<*6-97XU<+6!E8'5AR6"%88EA+6'!8P&M26#U8>5B%6+E8GUBK6+I8WEB[
M6+A8KEC%6--8T5C76-E8V%CE6-Q8Y%C?6.]8^ECY6/M8_%C]6`)9"ED061M9
MIF@E62Q9+5DR63A9/EG2>E594%E.65I96%EB66!99UEL66E9>%F!69U97D^K
M3Z-9LEG&6>A9W%F-6=E9VEDE6A]:$5H<6@E:&EI`6FQ:25HU6C9:8EIJ6II:
MO%J^6LM:PEJ]6N-:UUKF6NE:UEKZ6OM:#%L+6Q9;,EO06BI;-EL^6T-;15M`
M6U%;55M:6UM;95MI6W!;<UMU6WA;B&5Z6X!;@UNF6[A;PUO'6\E;U%O06^1;
MYEOB6]Y;Y5OK6_!;]EOS6P5<!UP(7`U<$UP@7")<*%PX7#E<05Q&7$Y<4UQ0
M7$]<<5ML7&Y<8DYV7'E<C%R17)1<FUFK7+M<MER\7+=<Q5R^7,=<V5SI7/U<
M^ESM7(Q=ZEP+715=%UU<71]=&UT1711=(ET:71E=&%U,75)=3EU+76Q=<UUV
M78==A%V"7:)=G5VL7:Y=O5V07;==O%W)7<U=TUW27=9=VUWK7?)=]5T+7AI>
M&5X17AM>-EXW7D1>0UY`7DY>5UY47E]>8EYD7D=>=5YV7GI>O)Y_7J!>P5["
M7LA>T%[/7M9>XU[=7MI>VU[B7N%>Z%[I7NQ>\5[S7O!>]%[X7OY>`U\)7UU?
M7%\+7Q%?%E\I7RU?.%]!7TA?3%].7R]?45]67U=?65]A7VU?<U]W7X-?@E]_
M7XI?B%^17X=?GE^97YA?H%^H7ZU?O%_67_M?Y%_X7_%?W5^S8/]?(6!@8!E@
M$&`I8`Y@,6`;8!5@*V`F8`]@.F!:8$%@:F!W8%]@2F!&8$U@8V!#8&1@0F!L
M8&M@66"!8(U@YV"#8)I@A&";8)9@EV"28*=@BV#A8+A@X&#38+1@\%^]8,9@
MM6#88$UA%6$&8?9@]V``8?1@^F`#82%A^V#Q8`UA#F%'83YA*&$G84IA/V$\
M82QA-&$]84)A1&%S87=A6&%985IA:V%T86]A96%Q85]A76%3875AF6&688=A
MK&&489IABF&18:MAKF',8<IAR6'W8<AAPV'&8;IARV%Y?\UAYF'C8?9A^F'T
M8?]A_6'\8?YA`&((8@EB#6(,8A1B&V(>8B%B*F(N8C!B,F(S8D%B3F)>8F-B
M6V)@8FAB?&*"8HEB?F*28I-BEF+48H-BE&+78M%BNV+/8O]BQF+49,ABW&+,
M8LIBPF+'8IMBR6(,8^YB\6(G8P)C"&/O8O5B4&,^8TUC'&1/8Y9CCF.`8ZMC
M=F.C8X]CB6.?8[5C:V-I8[YCZ6/`8\9CXV/)8])C]F/$8Q9D-&0&9!-D)F0V
M9!UE%V0H9`]D9V1O9'9D3F0J995DDV2E9*EDB&2\9-IDTF3%9,=DNV389,)D
M\63G9`F"X&3A9*QBXV3O9"QE]F3T9/)D^F0`9?UD&&4<905E)&4C92ME-&4U
M93=E-F4X94MU2&56955E365895YE765R97AE@F6#98J+FV6?9:MEMV7#9<9E
MP67$9<QETF7;9=EEX&7A9?%E<F<*9@-F^V5S9S5F-F8T9AQF3V9$9DEF069>
M9EUF9&9G9FAF7V9B9G!F@V:(9HYFB6:$9IAFG6;!9KEFR6:^9KQFQ&:X9M9F
MVF;@9C]FYF;I9O!F]6;W9@]G%F<>9R9G)V<XERYG/V<V9T%G.&<W9T9G7F=@
M9UEG8V=D9XEG<&>I9WQG:F>,9XMGIF>A9X5GMV?O9[1G[&>S9^EGN&?D9]YG
MW6?B9^YGN6?.9\9GYV><:AYH1F@I:$!H36@R:$YHLV@K:%EH8VAW:']HGVB/
M:*UHE&B=:)MH@VBN:KEH=&BU:*!HNF@/:8UH?F@!:<IH"&G8:")I)FGA:`QI
MS6C4:.=HU6@V:1)I!&G7:.-H)6GY:.!H[V@H:2II&FDC:2%IQFAY:7=I7&EX
M:6MI5&E^:6YI.6ET:3UI66DP:6%I7FE=:8%I:FFR::YIT&F_:<%ITVF^:<YI
MZ%O*:=UINVG#::=I+FJ1::!IG&F5:;1IWFGH:0)J&VK_:0IK^6GR:>=I!6JQ
M:1YJ[6D4:NMI"FH2:L%J(VH3:D1J#&IR:C9J>&I':F)J66IF:DAJ.&HB:I!J
MC6J@:H1JHFJC:I=J%X:[:L-JPFJX:K-JK&K>:M%JWVJJ:MIJZFK[:@5K%H;Z
M:A)K%FLQFQ]K.&LW:]QV.6ONF$=K0VM):U!K66M4:UMK7VMA:WAK>6M_:X!K
MA&N#:XUKF&N5:YYKI&NJ:ZMKKVNR:[%KLVNW:[QKQFO+:]-KWVOL:^MK\VOO
M:[Z>"&P3;!1L&VPD;"-L7FQ5;&)L:FR";(ULFFR!;)ML?FQH;'-LDFR0;,1L
M\6S3;+ULUVS%;-ULKFRQ;+YLNFS;;.]LV6SJ;!]M38@V;2MM/6TX;1EM-6TS
M;1)M#&UC;9-M9&U:;7EM66V.;95MY&^%;?EM%6X*;K5MQVWF;;AMQFWL;=YM
MS&WH;=)MQ6WZ;=EMY&W5;>IM[FTM;FYN+FX9;G)N7VX^;B-N:VXK;G9N36X?
M;D-N.FY.;B1N_VX=;CAN@FZJ;IANR6ZW;M-NO6ZO;L1NLF[4;M5NCVZE;L)N
MGVY!;Q%O3'#L;OAN_FX_;_)N,6_O;C)OS&X^;Q-O]VZ&;WIO>&^!;X!O;V];
M;_-O;6^";WQO6&^.;Y%OPF]F;[-OHV^A;Z1ON6_&;ZIOWV_5;^QOU&_8;_%O
M[F_;;PEP"W#Z;Q%P`7`/</YO&W`:<'1O'7`8<!]P,'`^<#)P47!C<)EPDG"O
M</%PK'"X<+-PKG#?<,MPW7#9<`EQ_7`<<1EQ97%5<8AQ9G%B<4QQ5G%L<8]Q
M^W&$<95QJ'&L<==QN7&^<=)QR7'4<<YQX''L<>=Q]7'\<?EQ_W$-<A!R&W(H
M<BUR+'(P<C)R.W(\<C]R0')&<DMR6')T<GYR@G*!<H=RDG*6<J)RIW*Y<K)R
MPW+&<L1RSG+2<N)RX'+A<OER]W(/4!=S"G,<<Q9S'7,T<R]S*7,E<SYS3G-/
M<]B>5W-J<VAS<'-X<W5S>W-Z<\ASLW/.<[MSP'/E<^YSWG.B=`5T;W0E=/AS
M,G0Z=%5T/W1?=%ET071<=&ET<'1C=&IT=G1^=(MTGG2G=,ITSW34=/%SX'3C
M=.=TZ73N=/)T\'3Q=/AT]W0$=0-U!74,=0YU#745=1-U'G4F=2QU/'5$=4UU
M2G5)=5MU1G5:=6EU9'5G=6MU;75X=79UAG6'=71UBG6)=8)UE'6:=9UUI76C
M=<)ULW7#=;5UO76X=;QUL77-=<IUTG79=>-UWG7^=?]U_'4!=O!U^G7R=?-U
M"W8-=@EV'W8G=B!V(78B=B1V-'8P=CMV1W9(=D9V7'98=F%V8G9H=FEV:G9G
M=FQV<'9R=G9V>'9\=H!V@W:(=HMVCG:6=I-VF7::=K!VM':X=KEVNG;"=LUV
MUG;2=MYVX7;E=N=VZG8OAOMV"'<'=P1W*7<D=QYW)7<F=QMW-W<X=T=W6G=H
M=VMW6W=E=W]W?G=Y=XYWBW>1=Z!WGG>P=[9WN7>_=[QWO7>[=\=WS7?7=]IW
MW'?C=^YW_'<,>!)X)GD@>"IY17B.>'1XAGA\>)IXC'BC>+5XJGBO>-%XQGC+
M>-1XOGB\>,5XRGCL>.=XVGC]>/1X!WD2>1%Y&7DL>2MY0'E@>5=Y7WE:>55Y
M4WEZ>7]YBGF=>:=Y2Y^J>:YYLWFY>;IYR7G5>>=Y['GA>>-Y"'H->AAZ&7H@
M>A]Z@'DQ>CMZ/GHW>D-Z5WI)>F%Z8GII>IV?<'IY>GUZB'J7>I5ZF'J6>JEZ
MR'JP>K9ZQ7K$>K]Z@Y#'>LIZS7K/>M5ZTWK9>MIZW7KA>N)ZYGKM>O!Z`GL/
M>PI[!GLS>QA[&7L>>S5[*'LV>U![>GL$>TU["WM,>T5[=7ME>W1[9WMP>W%[
M;'MN>YU[F'N?>XU[G'N:>XM[DGN/>UU[F7O+>\%[S'O/>[1[QGO=>^E[$7P4
M?.9[Y7M@?`!\!WP3?/-[]WL7?`U\]GLC?"=\*GP??#=\*WP]?$Q\0WQ4?$]\
M0'Q0?%A\7WQD?%9\97QL?'5\@WR0?*1\K7RB?*M\H7RH?+-\LGRQ?*Y\N7R]
M?,!\Q7S"?-A\TGS<?.)\.YOO?/)\]'SV?/I\!GT"?1Q]%7T*?45]2WTN?3)]
M/WTU?49]<WU6?4Y]<GUH?6Y]3WUC?9-]B7U;?8]]?7V;?;I]KGVC?;5]QWV]
M?:M]/7ZB?:]]W'VX?9]]L'W8?=U]Y'W>??M]\GWA?05^"GXC?B%^$GXQ?A]^
M"7X+?B)^1GYF?CM^-7XY?D-^-WXR?CI^9WY=?E9^7GY9?EI^>7YJ?FE^?'Y[
M?H-^U7U]?JZ/?WZ(?HE^C'Z2?I!^DWZ4?I9^CGZ;?IQ^.'\Z?T5_3']-?TY_
M4']1?U5_5']8?U]_8']H?VE_9W]X?X)_AG^#?XA_AW^,?Y1_GG^=?YI_HW^O
M?[)_N7^N?[9_N']QB\5_QG_*?]5_U'_A?^9_Z7_S?_E_W)@&@`2`"X`2@!B`
M&8`<@"&`*(`_@#N`2H!&@%*`6(!:@%^`8H!H@'.`<H!P@':`>8!]@'^`A("&
M@(6`FX"3@)J`K8"04:R`VX#E@-F`W8#$@-J`UH`)@>^`\8`;@2F!(X$O@4N!
MBY9&@3Z!4X%1@?R`<8%N@66!9H%T@8.!B(&*@8"!@H&@@96!I(&C@5^!DX&I
M@;"!M8&^@;B!O8'`@<*!NH')@<V!T8'9@=B!R(':@=^!X('G@?J!^X'^@0&"
M`H(%@@>""H(-@A""%H(I@BN".((S@D""68)8@EV"6H)?@F2"8H)H@FJ":X(N
M@G&"=X)X@GZ"C8*2@JN"GX*[@JR"X8+C@M^"TH+T@O."^H*3@P.#^X+Y@MZ"
M!H/<@@F#V8(U@S2#%H,R@S&#0(,Y@U"#18,O@RN#%X,8@X6#FH.J@Y^#HH.6
M@R.#CH.'@XJ#?(.U@W.#=8.@@XF#J(/T@Q.$ZX/.@_V#`X38@PN$P8/W@P>$
MX(/R@PV$(H0@A+V#.(0&A?N#;80JA#R$6H6$A'>$:X2MA&Z$@H1IA$:$+(1O
MA'F$-83*A&*$N82_A)^$V83-A+N$VH30A,&$QH36A*&$(87_A/2$%X48A2R%
M'X45A12%_(1`A6.%6(5(A4&%`H9+A56%@(6DA8B%D86*A:B%;864A9N%ZH6'
MA9R%=X5^A9"%R86ZA<^%N870A=6%W87EA=R%^84*AA.&"X;^A?J%!H8BAAJ&
M,(8_ADV&54Y4AE^&9X9QAI.&HX:IAJJ&BX:,AK:&KX;$AL:&L(;)AB.(JX;4
MAMZ&Z8;LAM^&VX;OAA*'!H<(AP"'`X?[AA&'"8<-A_F&"H<TAS^'-X<[AR6'
M*8<:AV"'7X=XATR'3H=TAU>':(=NAUF'4X=CAVJ'!8BBAY^'@H>OA\N'O8?`
MA]"'UI:KA\2'LX?'A\:'NX?OA_*'X(</B`V(_H?VA_>'#HC2AQ&(%H@5B"*(
M(8@QB#:(.8@GB#N(1(A"B%*(68A>B&*(:XB!B'Z(GHAUB'V(M8ARB(*(EXB2
MB*Z(F8BBB(V(I(BPB+^(L8C#B,2(U(C8B-F(W8CYB`*)_(CTB.B(\H@$B0R)
M"HD3B4.)'HDEB2J)*XE!B42).XDVB3B)3(D=B6")7HEFB62);8EJB6^)=(EW
MB7Z)@XF(B8J)DXF8B:&)J8FFB:R)KXFRB;J)O8F_B<")VHG<B=V)YXGTB?B)
M`XH6BA"*#(H;BAV*)8HVBD&*6XI2BD:*2(I\BFV*;(IBBH6*@HJ$BJB*H8J1
MBJ6*IHJ:BJ.*Q(K-BL**VHKKBO.*YXKDBO&*%(O@BN**]XK>BMN*#(L'BQJ+
MX8H6BQ"+%XL@BS.+JY<FBRN+/HLHBT&+3(M/BTZ+28M6BUN+6HMKBU^+;(MO
MBW2+?8N`BXR+CHN2BY.+EHN9BYJ+.HQ!C#^,2(Q,C$Z,4(Q5C&*,;(QXC'J,
M@HR)C(6,BHR-C(Z,E(Q\C)B,'6*MC*J,O8RRC+.,KHRVC,B,P8SDC..,VHS]
MC/J,^XP$C06-"HT'C0^-#8T0C4Z?$XW-C!2-%HUGC6V-<8USC8&-F8W"C;Z-
MNHW/C=J-UHW,C=N-RXWJC>N-WXWCC?R-"(X)CO^-'8X>CA".'XY"CC6.,(XT
MCDJ.1XY)CDR.4(Y(CEF.9(Y@CBJ.8XY5CG:.<HY\CH&.AXZ%CH2.BXZ*CI..
MD8Z4CIF.JHZACJR.L([&CK&.OH[%CLB.RX[;CN.._([[CNN._HX*CP6/%8\2
MCQF/$X\<CQ^/&X\,CR:/,X\[CSF/18]"CSZ/3(])CT:/3H]7CUR/8H]CCV2/
MG(^?CZ./K8^OC[>/VH_EC^*/ZH_OCX>0](\%D/F/^H\1D!60(9`-D!Z0%I`+
MD">0-I`UD#F0^(]/D%"049!2D`Z029`^D%:06)!>D&B0;Y!VD*B6<I""D'V0
M@9"`D(J0B9"/D*B0KY"QD+60XI#DD$ABVY`"D1*1&9$RD3"12I%6D5B18Y%E
MD6F1<Y%RD8N1B9&"D:*1JY&OD:J1M9&TD;J1P)'!D<F1RY'0D=:1WY'AD=N1
M_)'UD?:1'I+_D122+)(5DA&27I)7DD6229)DDDB2E9(_DDN24)*<DI:2DY*;
MDEJ2SY*YDK>2Z9(/D_J21),NDQF3(I,:DR.3.I,UDSN37)-@DWR3;I-6D["3
MK).MDY23N9/6D]>3Z)/ED]B3PY/=D]"3R)/DDQJ4%)03E`.4!Y00E#:4*Y0U
ME"&4.I1!E%*41)1;E&"48I1>E&J4*9)PE'64=Y1]E%J4?)1^E(&4?Y2"E8>5
MBI64E9:5F)69E:"5J)6GE:V5O)6[E;F5OI7*E?9OPY7-E<R5U974E=:5W)7A
ME>65XI4AEBB6+I8OED*63)9/EDN6=Y9<EEZ6799?EF:6<I9LEHV6F):5EI>6
MJI:GEK&6LI:PEK26MI:XEKF6SI;+ELF6S99-B=R6#9?5EOF6!)<&EPB7$Y<.
MEQ&7#Y<6EQF7))<JES"7.9<]ESZ71)=&ETB70I=)EUR78)=DEV:7:)?24FN7
M<9=YEX67?)>!EWJ7AI>+EX^7D)><EZB7II>CE[.7M)?#E\:7R)?+E]R7[9=/
MG_*7WWKVE_67#Y@,F#B8))@AF#>8/9A&F$^82YAKF&^8<)AQF'28<YBJF*^8
ML9BVF,28PYC&F.F8ZY@#F0F9$ID4F1B9(9D=F1Z9))D@F2R9+ID]F3Z90IE)
MF4694)E+F5&94IE,F569EYF8F:69K9FNF;R9WYG;F=V9V)G1F>V9[IGQF?*9
M^YGXF0&:#YH%FN*9&9HKFC>:19I"FD":0YH^FE6:39I;FE>:7YIBFF6:9)II
MFFN::IJMFK":O)K`FL^:T9K3FM2:WIK?FN*:XYKFFN^:ZYKNFO2:\9KWFON:
M!IL8FQJ;'YLBFR.;)9LGFRB;*9LJFRZ;+YLRFT2;0YM/FTV;3IM1FUB;=)N3
MFX.;D9N6FY>;GYN@FZB;M)O`F\J;N9O&F\^;T9O2F^.;XIODF]2;X9LZG/*;
M\9OPFQ6<%)P)G!.<#)P&G`B<$IP*G`2<+IP;G"6<))PAG#"<1YPRG$:</IQ:
MG&"<9YQVG'B<YYSLG/"<"9T(G>N<`YT&G2J=)IVOG2.='YU$G16=$IU!G3^=
M/IU&G4B=79U>G62=49U0G5F=<IV)G8>=JYUOG7J=FIVDG:F=LIW$G<&=NYVX
MG;J=QIW/G<*=V9W3G?B=YIWMG>^=_9T:GAN>'IYUGGF>?9Z!GHB>BYZ,GI*>
ME9Z1GIV>I9ZIGKB>JIZMGF&7S)[.GL^>T)[4GMR>WI[=GN">Y9[HGN^>])[V
MGO>>^9[[GOR>_9X'GPB?MW85GR&?+)\^GTJ?4I]4GV.?7Y]@GV&?9I]GGVR?
M:I]WGW*?=I^5GYR?H)\O6,=I69!D=-Q1F7$``````#`!,`(P#/\.__LP&O\;
M_Q__`?^;,)PPM`!`_Z@`/O_C_S___3#^,)TPGC`#,-U.!3`&,`<P_#`5(!`@
M#_\\_QPP%B!<_R8@)2`8(!D@'"`=(`C_"?\4,!4P._\]_UO_7?\(,`DP"C`+
M,`PP#3`.,`\P$#`1,`O_$B*Q`-<`]P`=_V`B'/\>_V8B9R(>(C0B0B9`)K``
M,B`S(`,AY?\$_Z(`HP`%_P/_!O\*_R#_IP`&)@4FRR7/)<XEQR7&):$EH"6S
M);(EO26\)3L@$C"2(9`AD2&3(1,P_?_]__W__?_]__W__?_]__W__?_]_P@B
M"R*&(H<B@B*#(BHB*2+]__W__?_]__W__?_]__W_)R(H(JP`TB'4(0`B`R+]
M__W__?_]__W__?_]__W__?_]__W_("*E(A(C`B('(F$B4B)J(FLB&B(](ATB
M-2(K(BPB_?_]__W__?_]__W__?\K(3`@;R9M)FHF("`A(+8`_?_]__W__?_O
M)?W__?_]__W__?_]__W__?_]__W__?_]__W__?_]_Q#_$?\2_Q/_%/\5_Q;_
M%_\8_QG__?_]__W__?_]__W__?\A_R+_(_\D_R7_)O\G_RC_*?\J_RO_+/\M
M_R[_+_\P_S'_,O\S_S3_-?\V_S?_./\Y_SK__?_]__W__?_]__W_0?]"_T/_
M1/]%_T;_1_](_TG_2O]+_TS_3?]._T__4/]1_U+_4_]4_U7_5O]7_UC_6?]:
M__W__?_]__W_03!",$,P1#!%,$8P1S!(,$DP2C!+,$PP33!.,$\P4#!1,%(P
M4S!4,%4P5C!7,%@P63!:,%LP7#!=,%XP7S!@,&$P8C!C,&0P93!F,&<P:#!I
M,&HP:S!L,&TP;C!O,'`P<3!R,',P=#!U,'8P=S!X,'DP>C![,'PP?3!^,'\P
M@#"!,((P@S"$,(4PAC"',(@PB3"*,(LPC#"-,(XPCS"0,)$PDC"3,/W__?_]
M__W__?_]__W__?_]__W__?^A,*(PHS"D,*4PIC"G,*@PJ3"J,*LPK#"M,*XP
MKS"P,+$PLC"S,+0PM3"V,+<PN#"Y,+HPNS"\,+TPOC"_,,`PP3#",,,PQ##%
M,,8PQS#(,,DPRC#+,,PPS3#.,,\PT##1,-(PTS#4,-4PUC#7,-@PV3#:,-LP
MW##=,-XPWS#@,.$PXC#C,.0PY3#F,.<PZ##I,.HPZS#L,.TP[C#O,/`P\3#R
M,/,P]##U,/8P_?_]__W__?_]__W__?_]_Y$#D@.3`Y0#E0.6`Y<#F`.9`YH#
MFP.<`YT#G@.?`Z`#H0.C`Z0#I0.F`Z<#J`.I`_W__?_]__W__?_]__W__?^Q
M`[(#LP.T`[4#M@.W`[@#N0.Z`[L#O`.]`[X#OP/``\$#PP/$`\4#Q@/'`\@#
MR0/]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_$`01!!($$P04!!4$
M`006!!<$&`09!!H$&P0<!!T$'@0?!"`$(00B!",$)`0E!"8$)P0H!"D$*@0K
M!"P$+00N!"\$_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_,`0Q!#($
M,P0T!#4$400V!#<$.`0Y!#H$.P0\!#T$/@0_!$`$001"!$,$1`1%!$8$1P1(
M!$D$2@1+!$P$301.!$\$_?_]__W__?_]__W__?_]__W__?_]__W__?\`)0(E
M#"40)1@E%"4<)2PE)"4T)3PE`24#)0\E$R4;)1<E(R4S)2LE.R5+)2`E+R4H
M)3<E/R4=)3`E)24X)4(EL+.RL;0``````````````````````````````+0`
M(!#``$$`P0!!$,,`02#(`$4`R0!%$,P`20#-`$D0T0!.(-(`3P#3`$\0U0!/
M(-D`50#:`%40W0!9$.``80#A`&$0XP!A(.@`90#I`&40[`!I`.T`:1#Q`&X@
M\@!O`/,`;Q#U`&\@^0!U`/H`=1#]`'D0!@%#$`<!8Q`H`4D@*0%I(#D!3!`Z
M`6P00P%.$$0!;A!4`5(050%R$%H!4Q!;`7,0:`%5(&D!=2!Y`5H0>@%Z$-<!
MW!#8`?P0VP'<`-P!_`#T`4<0]0%G$/@!3@#Y`6X`^@'%$/L!Y1#\`<80_0'F
M$/X!V!#_`?@0W`(@((4#I1`$'D)`!1YB0`@>QQ`)'N<0#!Y$0`T>9$`D'DA`
M)1YH0"X>SQ`O'N\0,!Y+$#$>:Q`R'DM`,QYK0#8>3$`W'FQ`/AY-$#\>;1!"
M'DU`0QYM0$8>3D!''FY`3![3($T>\R!.'M8@3Q[V(%0>4!!5'G`06AY20%L>
M<D!B'E-`8QYS0&P>5$!M'G1`>![:('D>^B!\'E8@?1YV('X>5D!_'G9`@!Y7
M`($>=P""'E<0@QYW$(@>5T")'G=`DAY:0),>>D"@'D%`H1YA0*(>03"C'F$P
MI!["$*4>XA"F'L(`IQ[B`*@>PC"I'N(PJA["(*L>XB"L'L)`K1[B0*X>`A&O
M'@,1L!X"`;$>`P&R'@(QLQX#,;0>`B&U'@,AMAX"0;<>`T&X'D5`N1YE0+H>
M13"['F4PO!Y%(+T>92"^'LH0OQ[J$,`>R@#!'NH`PA[*,,,>ZC#$'LH@Q1[J
M(,8>RD#''NI`R!Y),,D>:3#*'DE`RQYI0,P>3T#-'F]`SAY/,,\>;S#0'M00
MT1[T$-(>U`#3'O0`U![4,-4>]##6'M0@UQ[T(-@>U$#9'O1`VAZ@$=L>H1'<
M'J`!W1ZA`=X>H#'?'J$QX!Z@(>$>H2'B'J!!XQZA0>0>54#E'G5`YAY5,.<>
M=3#H'J\1Z1ZP$>H>KP'K'K`![!ZO,>T>L#'N'J\A[QZP(?`>KT'Q'K!!\AY9
M`/,>>0#T'EE`]1YY0/8>63#W'GDP^!Y9(/D>>2#M'Z@`[A^H$```````````
M``````````````````````````"$N8&VQ,K!Q\+(P\F&R\"^K[NZO+^]A<:+
MT8C.B<_:U<72S=/9U(S6CMB1WI;DD^'_Z-OEX.;PYY?IF^V8ZIGKFNR<[@+T
MGO$1^`3U!?8&]Q+Y$_H7_A3[%?P```````"PLP"R``````"Q````````````
M`````````````````````+0`````````````````````````````````````
MH`````````````````````````````````````````"`@Z*"`````(>*HP"-
MD`````"2E:24````G0$``!8``+6XJ;<`````S-"J`-?=`````-_CJ^(```#O
M\P``_0````"AJ````````````````*>N````````````````````````````
M`(_<````````````````````````````````````````````````````````
M``````````````````````````"?\@``````````````````````````````
M`````````````````````````````````````````*6L````````````````
M`*:M````````````````````00#``$4`R`!)`,P`3@#X`4\`T@!5`-D`5P"`
M'ED`\AYA`.``90#H`&D`[`!N`/D!;P#R`'4`^0!W`($>>0#S'J@`[1_"`*8>
MR@#`'M0`TA[<`-L!X@"G'NH`P1[T`-,>_`#<`0(!L!X#`;$>H`'<'J$!W1ZO
M`>H>L`'K'D$`P0!#``8!10#)`$<`]`%)`,T`2P`P'DP`.0%-`#X>3@!#`4\`
MTP!0`%0>4@!4`5,`6@%5`-H`5P""'ED`W0!:`'D!80#A`&,`!P%E`.D`9P#U
M`6D`[0!K`#$>;``Z`6T`/QYN`$0!;P#S`'``51YR`%4!<P!;`74`^@!W`(,>
M>0#]`'H`>@&E`(4#J`#N'\(`I![%`/H!Q@#\`<<`"![*`+X>SP`N'M0`T![8
M`/X!W`#7`>(`I1[E`/L!Y@#]`><`"1[J`+\>[P`O'O0`T1[X`/\!_`#8`0(!
MKAX#`:\>H`':'J$!VQZO`>@>L`'I'D$`PP!%`+P>20`H`4X`T0!/`-4`50!H
M`58`?!Y9`/@>80#C`&4`O1YI`"D!;@#Q`&\`]0!U`&D!=@!]'GD`^1["`*H>
MR@#$'M,`3![4`-8>U@!.'MH`>![B`*L>Z@#%'O,`31[T`-<>]@!/'OH`>1X"
M`;0>`P&U'J`!X!ZA`>$>KP'N'K`![QY!`*(>10"Z'DD`R!Y/`,X>50#F'ED`
M]AYA`*,>90"['FD`R1YO`,\>=0#G'GD`]Q["`*@>R@#"'M0`U![B`*D>Z@##
M'O0`U1X"`;(>`P&S'J`!WAZA`=\>KP'L'K`![1Y!`*`>0@`$'D0`#!Y%`+@>
M2``D'DD`RAY+`#(>3``V'DT`0AY.`$8>3P#,'E(`6AY3`&(>5`!L'E4`Y!Y6
M`'X>5P"('ED`]!Y:`)(>80"A'F(`!1YD``T>90"Y'F@`)1YI`,L>:P`S'FP`
M-QYM`$,>;@!''F\`S1YR`%L><P!C'G0`;1YU`.4>=@!_'G<`B1YY`/4>>@"3
M'L(`K![*`,8>U`#8'N(`K1[J`,<>]`#9'@(!MAX#`;<>H`'B'J$!XQZO`?`>
ML`'Q'@`````?`````````#P````?````(@```%L````8````?0```#(```"5
M````````````````````````````````````P`"B'L,`P0"@'K8>K![(`+H>
MO![)`+@>QA[,`,@>*`'-`,H>T@#.'M4`TP#,'M@>W![>'N`>VA[B'MD`YAYH
M`:```@'"`,H`U`"@`:\!$`$#`>(`Z@#T`*$!L`$1`;`>``,)`P,#`0,C`^``
MHQ[C`.$`H1ZR'K$>LQZU'J\>M!ZN'J8>J!ZJ'J0>P!ZW'J<>J1ZK'J4>K1[H
M`,(>NQZ]'ND`N1[!'L,>Q1Z_'L<>[`#)'L0>OA[2'BD![0#+'O(`U![/'O4`
M\P#-'M,>U1[7'M$>V1[='M\>X1[;'N,>^0#6'N<>:0'Z`.4>ZQ[M'N\>Z1[Q
M'O,>]Q[Y'OT`]1[0'@``V@#D'@,`ZA[L'NX>!P`(``D`"@`+``P`#0`.``\`
M$`#H'O`>\A[V'O@>W0#T'@````````````````````"`U<3DA*2%I8:F!N>'
MIX&A@J("Q@7'@Z.)J<OKB*B*JHNKC*R-K8ZNF^^8N)KWF?:/KY"PD;&2LI.U
ME;Z6MI>WL]Z4_I[XG/RZT;O7O-C_YKGQG\\>W!36&=L```````#`P<+#````
M`,C)R@#,S0````#2T]2@````V=H``-T``.#AXN,`````Z.GJ`.SM`````/+S
M]/4```#Y^@``_0````#%Y0```````````````-#P````````````````````
M`````````,[N````````````````````````````````````````````````
M``````````````````````````````````"=^P``````````````````````
M`````````````````````````````````````````````````+2]````````
M`````````+_?````````````````````H!ZN'K`>MAZD'J8>J!ZL'KP>N!Z^
M'L`>PA[$'L8>T![2'M0>UA[8'N(>VA[<'MX>RA[.'LP>R![F'F@!Y![R'M4`
MKQZQ'K<>I1ZG'JD>K1Z]'KD>OQ[!'L,>Q1[''M$>TQ[5'M<>X!Z@`=D>W1[?
M'LL>\![H'NH>[!ZA`=L>KP'``,$`P@##`*(>`@&S'K4>R`#)`,H`NA[,`,T`
M*`'S'A`!Z1[2`-,`U`"A'O<>ZQ[M'MD`V@#Y'O4>W0#A'K`!X`#A`.(`XP"C
M'@,![QZK'N@`Z0#J`+L>[`#M`"D!R1X1`?$>\@#S`/0`]0#/'LT>Y1[Y`/H`
M:0'G'OT`XQ[N'@```0"R'@,`!`"T'JH>!P`(``D`"@`+``P`#0`.``\`$``1
M`!(`$P#V'A4`%@`7`!@`^!X:`!L`'``=`/0>'P``H:(`HP``I*4`IP``J```
M`````*FJJZP`K:ZOL+&RLP"TM;8`MP"X``"FN0"ZN[_`RL'"P\3%QL?(`,O)
MS```T-'2T]0`VP#5UM?8V=H``/#Q\O/T]?;W^/D``-W>``"@`/P```#^````
M``#]`````````````````````````-`.T0[2#M,.U`[5#M8.UP[8#MD._?_]
M_Z(`K`"F`/W_H`"!#H(.A`Z'#H@.J@Z*#HT.E`Z5#I8.EPZ9#IH.FPZ<#IT.
MG@Z?#J$.H@ZC#J4.IPZK#JT.K@[]__W__?^O#K`.L@ZS#K0.M0ZV#K<.N`ZY
M#KP.L0Z[#KT._?_]__W_P`[!#L(.PP[$#L@.R0[*#LL.S`[-#L8._?_<#MT.
MK2``H:(`I```IZ@`J@``K0```````+2UMK<`N;J[O+V^OP#!PL,`Q0#'``#*
MRP#-SL_0T=+3U-76U]C9`-O<W0``X.'BX^0`Y@#HZ>KK[.T``/#Q\O/T]?;W
M^/D``/S]``"@`($.@@[]_X0._?_]_X<.B`[]_XH._?_]_XT._?_]__W__?_]
M__W_E`Z5#I8.EP[]_YD.F@Z;#IP.G0Z>#I\._?^A#J(.HP[]_Z4._?^G#OW_
M_?^J#JL._?^M#JX.KPZP#K$.L@ZS#K0.M0ZV#K<.N`ZY#OW_NPZ\#KT._?_]
M_\`.P0["#L,.Q`[]_\8._?_(#LD.R@[+#LP.S0[]__W_T`[1#M(.TP[4#M4.
MU@[7#M@.V0[]__W_W`[=#OW__?\```````"Y``````````````"9````````
M`````````````):7````D9*"`).4A`"&AY4```"%````````````B0``````
M````BYL`````````````````````````````LP``````````````````X>+W
MY^3E]OKIZNOL[>[O\/+S]/7FZ./^^_W_^?C\X/'!PM?'Q,76VLG*R\S-SL_0
MTM/4U<;(P][;W=_9V-S`T0"C````````````````````````````````````
M`````````````````````````````````````````````````(.!````````
MD(``````````````````````````````C(H``(Z-````````````````````
M````````````````````````````````````M:4`````````````HJ$`````
M`````````````````````*0`IJ<`OP"KK*VN`+"QL@```+:W````NP````";
M!),$&B"2!!X@)B`@("$@_?\P(+,$.2"R!+<$M@3]_YH$&"`9(!P@'2`B(!,@
M%"#]_R(A_?\Z(/W__?_]__W__?_O!.X$402D`.,$I@"G`/W__?_]_ZL`K`"M
M`*X`_?^P`+$`L@`!!/W_X@2V`+<`_?\6(?W_NP#]__W__?^I`$X$,`0Q!$8$
M-`0U!$0$,P1%!#@$.00Z!#L$/`0]!#X$/P1/!$`$001"!$,$-@0R!$P$2P0W
M!$@$301)!$<$2@0N!!`$$00F!!0$%00D!!,$)008!!D$&@0;!!P$'00>!!\$
M+P0@!"$$(@0C!!8$$@0L!"L$%P0H!"T$*00G!"H$````EI<```"1DH(`DY2$
M`(:'E0```(4```````````")``````````"+FP``````````````````````
M`````,#!PL/$Q<;(R<K+S,W/T-'2T]36U]C9VMO<W=[?X.'CY,?.U>+E````
M``````````````````````````````````````"(````````````````````
M````````F```````C)P```````````````"*F@``````````````````````
M``````"?`````````````````````````````````(,`````````````````
M`````````````````````("!``````````````"-CH^0````````````````
MG9X`T!#1$-(0TQ#4$-40UA#Q$-<0V!#9$-H0VQ#<$/(0W1#>$-\0X!#A$.(0
M\Q#C$.00Y1#F$.<0Z!#I$.H0ZQ#L$.T0[A#T$.\0\!#U$```````````````
M````````````@`"!`!H@D@$>("8@("`A(,8","!@`3D@4@&-`(X`CP"0`!@@
M&2`<(!T@(B`3(!0@W`(B(6$!.B!3`9T`G@!X`0```):7````D9*"`).4A`"&
MAY4```"%````````````B0``````````BYL`````````````````````````
M``````````"(````````````````````````````F```````C)P`````````
M``````"*F@````````````````````````````"?````````````````````
M`````````````(,``````````````````````````````````````("!````
M``````````"-CH^0````````````````G9X`@`"!`!H@D@$>("8@("`A(,8"
M,"!@`3D@4@&-`(X`CP"0`!@@&2`<(!T@(B`3(!0@W`(B(6$!.B!3`9T`G@!X
M`0````"H``````````````````````"N`````````````+*TMKBZO+[`PL3&
MR,K,SM#2U-;8VMS>X.+DYNCJ[.[P\O3V^/K\````_K"OJK$``+.UM[F[O;_!
MP\7'R<O-S]'3U=?9V]W?X>/EY^GK[>_Q\_7W^?O]H@"CK0``````H```````
M``````"G````````````````````I@````"EI"HKJZRI+P``````````````
M`````````````````*``_?^'!8D%*0`H`+L`JP`4("X`704L`"T`B@4F(%P%
M6P5>!3$%804R!6(%,P5C!30%9`4U!64%-@5F!3<%9P4X!6@%.05I!3H%:@4[
M!6L%/`5L!3T%;04^!6X%/P5O!4`%<`5!!7$%0@5R!4,%<P5$!70%105U!48%
M=@5'!7<%2`5X!4D%>05*!7H%2P5[!4P%?`5-!7T%3@5^!4\%?P50!8`%406!
M!5(%@@53!8,%5`6$!54%A056!88%6@7]_P"NKP``````````````````````
M````````````````````L=``````J;@`JKJY`+*SMP```+P```````````"]
M``````````"LK0```````````*0``````````````````````,//````P0``
M`````````````,;'RL[$S0```/4```````````````````#H^```````````
M`````````.KZ````````````````````````````````````````````````
M``````````````````````````````````"F````````````````````````
M``````````````"`H:*CJ*6UI\B@XZN^`+#%`-')S,*=MK3+P.N[TM/4OX&"
M@X2%AN&'B(F*BXR-CH^0D9*3E)66GNF7F)F:FYS[U=;7V-G:\=O<W=[?X.+D
MY>;G[.WN[_"?^?+S]/;W_/V@`,``P0#"`,,`Q`#%`,<`R`#)`,H`RP#,`,T`
MS@#/`-``T0#2`-,`U`#5`-8`V0#:`-L`W`#=`-X`M0#7`/<`J0"A`*(`HP!$
M(*4`D@&G`*0`&2`<(*L`.2`Z(`'[`ONN`!,@("`A(+<`I@"V`"(@&B`>(!T@
MNP`F(#`@K`"_`+D`RP*T`,8"W`*O`-@"V0*H`+(`V@*X`+,`W0+;`L<"%""Q
M`+P`O0"^`.``X0#B`.,`Y`#E`.<`Z`#I`.H`ZP#L`,8`[0"J`.X`[P#P`/$`
M00'8`%(!N@#R`/,`]`#U`/8`Y@#Y`/H`^P`Q`?P`_0!"`?@`4P'?`/X`_P#]
M__W_````````J@````"I`````````````````````*P```#K[```````````
M``````````````````#N`````````````````````````````````+X`````
M````````````H+B_N[J\`+VK`/G[````L+/^``"H\_3R``#Z_??X];FAX*+A
MV-#3M*/<I*7FY::GX[;HY]_IV@#2K>VNV['PWLC$P.+,U->UR<7!S=G5T=WD
MM\K&PNK.`-;+Q\//LO'OH`#``,(`R`#*`,L`S@#/`+0`RP+&`J@`W`+9`-L`
MI""O`-T`_0"P`,<`YP#1`/$`H0"_`*0`HP"E`*<`D@&B`.(`Z@#T`/L`X0#I
M`/,`^@#@`.@`\@#Y`.0`ZP#V`/P`Q0#N`-@`Q@#E`.T`^`#F`,0`[`#6`-P`
MR0#O`-\`U`#!`,,`XP#0`/``S0#,`-,`T@#5`/4`8`%A`=H`>`'_`-X`_@"W
M`+4`M@"^`!0@O`"]`*H`N@"K`*`ENP"Q`/W_`````)*4E9:7DYB(@YF)A)J*
MA9N+AIR,AX\```````````#<`````````-W>````G9X``(V.`````)$```""
M``"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+
MS,W.S]#1TM/4U=;7V-G:`````-_@X>+CY.7FY^CIZNOL[0#O\/'R\_3U]O?X
M^0```````*```````````/L`@```^@```````````````($`````JP"[`"8@
MC/B/^)+XE?B8^(OXCOB1^)3XE_@<(!T@F?C]_R(@A/B)^(7XAOB'^(CXBOB-
M^)#XD_B6^!@@&2#]_Z```0X"#@,.!`X%#@8.!PX(#@D."@X+#@P.#0X.#@\.
M$`X1#A(.$PX4#A4.%@X7#A@.&0X:#AL.'`X=#AX.'PX@#B$.(@XC#B0.)0XF
M#B<.*`XI#BH.*PXL#BT.+@XO#C`.,0XR#C,.-`XU#C8.-PXX#CD..@[__@L@
M$R`4(#\.0`Y!#D(.0PY$#D4.1@Y'#D@.20Y*#DL.3`Y-#B(A3PY0#E$.4@Y3
M#E0.50Y6#E<.6`Y9#JX`J0#]__W__?_]_P````"L``````````````````"[
M````OP#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9V@``````X.'BX^3EYN?H
MZ>KK[.WN[_#Q\@````````````````"PL;*SM+6VM[BYI0``P```````````
M````]`````#S`````````/4`^0``````````^@```````/X`````````````
M`/<`````````````^`````````````"+````````````````````````````
M``#_``#V````````````````````````@0````````````",````````````
M````````F```````````@```@@"#`````````(0`````A0``````A@```(B'
MB0"*``"-CXZ0D0"2E)4`E@"7F0":FP"=G)Z?````Q`"@`,<`R0#1`-8`W`#A
M`.``X@#D`+H&JP#G`.D`Z`#J`.L`[0`F(.X`[P#Q`/,`NP#T`/8`]P#Z`/D`
M^P#\`/W__?_]__W__?]J!OW__?_]__W__?_]_PP&_?_]__W_8`9A!F(&8P9D
M!F4&9@9G!F@&:0;]_QL&_?_]__W_'P9M!B$&(@8C!B0&)08F!B<&*`8I!BH&
M*P8L!BT&+@8O!C`&,08R!C,&-`8U!C8&-P8X!CD&.@;]__W__?_]__W_0`9!
M!D(&0P9$!D4&1@9'!D@&209*!DL&3`9-!DX&3P90!E$&4@9^!GD&A@;5!J0&
MKP:(!I$&_?_]__W_F`;2!@````````"!`````````````-;7````````````
MR````````````````````````````,<`````````T-$```#4U0``TM/!````
M`````,D``````````````````````-G;VM_/S<[,R]T`W,8``-@`````````
M````````````X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ``````#*````
M``````````````````````````````````````````"```""`(,`````````
MA`````"%``````"&````B(>)BXJ,`(V/CI"1DY*4E0"6F)>9FYH``)V<GI\`
M``#$`!_[QP#)`-$`U@#<`.$`X`#B`.0`XP#E`.<`Z0#H`.H`ZP#M`.P`[@#O
M`/$`\P#R`/0`]@#U`/H`^0#[`/P`_?_]__W__?_]__W_JB#]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_'B#]
M__W__?_]_[P%2_LU^R8@H`"X!;<%M06V!;0%$R`4(!P@'2`8(!D@*OLK^[\%
ML`6R!;$%NP6Y!?W_LP70!=$%T@73!=0%U076!=<%V`79!=H%VP7<!=T%W@7?
M!>`%X07B!>,%Y`7E!>8%YP7H!>D%Z@7]__W__?_]__W_``"V````Q@``````
M````N`"W``````````##````L````````````````+H`````````````````
M````````````````````Q0``````````````````````````````K0```+*S
M`````*H```"]``````````````````````````#0T0```-35X@#2T^,`H."E
M````R0```````````.0`````````````````````````````````````````
M````````]O\`````````````````````^?K[_O?]``````````#:VP``````
M``````````````#<W0``````````````````````````````````````````
MSL\`````````````WM\```````````````````````````````#9````````
M`````````````````````````,0``````,K!HJ,`M`"DK*F[Q\(`J/BAL0``
MJ[6FX?P`O,@```#`R^?ES("!KH+I@^;H[>KK[`"$\>[OS84`K_3R\X8``*>(
MAXF+BHR^C8^.D)&3DI25`):8EYF;FM:_G9R>GP``V,0`Q0#'`,D`T0#6`-P`
MX0#@`.(`Y`#C`.4`YP#I`.@`Z@#K`.T`[`#N`.\`\0#S`/(`]`#V`/4`^@#Y
M`/L`_``@(+``H@"C`*<`(B"V`-\`K@"I`"(AM`"H`&`BQ@#8`!XBL0!D(F4B
MI0"U``(B$2(/(L`#*R*J`+H`)B'F`/@`OP"A`*P`&B*2`4@B!B*K`+L`)B"@
M`,``PP#5`%(!4P$3(!0@'"`=(!@@&2#W`,HE_P!X`1X!'P$P`3$!7@%?`2$@
MMP`:(!X@,"#"`,H`P0#+`,@`S0#.`,\`S`#3`-0`_?_2`-H`VP#9`/W_Q@+<
M`J\`V`+9`MH"N`#=`ML"QP+%``````````````````````````````"M````
MLK,``````-``T0``U-4``-+3``"@`)8```#)````````````F```````````
M````````````````````````````````````BX?-K\[7V`#9`-K?_;"UH:*V
MM[BCN;JDN\&EPZ;$`*K&R[S,OK^KO<#;W-W^X>+GY.7ZZ/7IZ^SM[NKO\/+W
M\_3YYOCC]OO\WN#Q``````````````````````#*``"2`+2;K(RI`,?"G*@`
MKK&"A```````@0#(`)<```````"``````(,```````````````"%``````"&
M``"GB`")`(H``(V/CI"1``"4E0````"9`)K6`)T`GI\```#$`+D`L@#)`+,`
MU@#<`(4#X`#B`.0`A`.H`.<`Z0#H`.H`ZP"C`"(A[@#O`"(@O0`P(/0`]@"F
M`*T`^0#[`/P`(""3`Y0#F`.;`YX#H`/?`*X`J0"C`ZH#IP!@(K``AP.1`[$`
M9")E(J4`D@.5`Y8#EP.9`YH#G`.F`ZL#J`.I`ZP#G0.L`)\#H0-((J0#JP"[
M`"8@H`"E`Z<#A@.(`U,!$R`5(!P@'2`8(!D@]P")`XH#C`..`ZT#K@.O`\P#
MCP/-`[$#L@/(`[0#M0/&`[,#MP.Y`[X#N@.[`[P#O0._`\`#S@/!`\,#Q`.X
M`\D#P@/'`\4#M@/*`\L#D`.P`_W_````````Q@``````````````````````
M``##````L```````````````````````````````````````````````````
M````Q0``````````````````````````````K0```+*S``````````#<````
M``````````"J``````````#0T0```-35``#2T]<`H`"E````R0``````````
M``#=JZZXP:>ZM[R^R\T`V-J`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;
MG)V>G^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[?`-ZLK[G/M+O`
MO;_,S@#9VP``````````````````````````````````````````````````
M`````````````**V``````````````````#*``"C_P``I`"I`,?"`*@`H;$`
M``"UI@````#(`````!`$$002!!,$%`05!!8$%P08!!D$&@0;!!P$'00>!!\$
M(`0A!"($(P0D!"4$)@0G!"@$*00J!"L$+`0M!"X$+P0@(+``D`2C`*<`(B"V
M``8$K@"I`"(A`@12!&`B`P13!!XBL0!D(F4B5@2U`)$$"`0$!%0$!P17!`D$
M600*!%H$6`0%!*P`&B*2`4@B!B*K`+L`)B"@``L$6P0,!%P$5003(!0@'"`=
M(!@@&2#W`!X@#@1>!`\$7P06(0$$401/!#`$,00R!#,$-`0U!#8$-P0X!#D$
M.@0[!#P$/00^!#\$0`1!!$($0P1$!$4$1@1'!$@$201*!$L$3`1-!$X$I```
M`+8```#&`````````````````````````,,```"P````````````````````
M``````````````````````````````````#%````````````````````````
M``````"M````LK,``````````-P``````````````*H``````````-#1````
MU-4``-+3UP"@`*4```#)`````````````-VKKKC!I[JWO+[+S0#8VH"!@H.$
MA8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?X.'BX^3EYN?HZ>KK[.WN[_#Q
M\O/T]?;W^/GZ^_S]_M\`WJRON<^TN\"]O\S.`-G;R@"BH_\``*0`J0#'P@"H
M`*&Q````M:8`````R``````0!!$$$@03!!0$%006!!<$&`09!!H$&P0<!!T$
M'@0?!"`$(00B!",$)`0E!"8$)P0H!"D$*@0K!"P$+00N!"\$(""P`*(`HP"G
M`"(@M@`&!*X`J0`B(0($4@1@(@,$4P0>(K$`9")E(E8$M0`"(@@$!`14!`<$
M5P0)!%D$"@1:!%@$!02L`!HBD@%((@8BJP"[`"8@H``+!%L$#`1<!%4$$R`4
M(!P@'2`8(!D@]P`>(`X$7@0/!%\$%B$!!%$$3P0P!#$$,@0S!#0$-00V!#<$
M.`0Y!#H$.P0\!#T$/@0_!$`$001"!$,$1`1%!$8$1P1(!$D$2@1+!$P$301.
M!*0```"V````Q@``````````N`"W``````````##````L```````````````
M`+H`````````````````````````````````````Q0``````````````````
M````````````K0```+*S`````*H```"]``````````````````````````#0
MT0```-35X@#2T^,`H."E````R0```````````.0``````````-S=````````
M````V@``````````````````````]O\`````````````````````^?K[_O?]
M``#*P:*CV[0`I*RIN\?"`*CXH;$``*NUIN'\`+S(````P,OGY<R`@0""Z8/F
MZ.WJZ^P`A/'N[\V%``#T\O.&``"GB(>)BXJ,`(V/CI"1DY*4E0"6F)>9FYK6
M`)V<GI\``-@``*Z^````````````````````````````````````````````
M````````````````]0``````````````````````````````````````````
MSL\`````````````K[\``-[?``````````````````````````#9````````
M`````````````````````````,0`````````````````Q`#%`,<`R0#1`-8`
MW`#A`.``X@#D`.,`Y0#G`.D`Z`#J`.L`[0#L`.X`[P#Q`/,`\@#T`/8`]0#Z
M`/D`^P#\`"`@L`"B`*,`IP`B(+8`WP"N`*D`(B&T`*@`8"("`5X!'B*Q`&0B
M92*E`+4``B(1(@\BP`,K(JH`N@`F(0,!7P&_`*$`K``:(I(!2"(&(JL`NP`F
M(*``P`##`-4`4@%3`1,@%"`<(!T@&"`9(/<`RB7_`'@!1""D`#D@.B!B`6,!
M(2"W`!H@'B`P(,(`R@#!`,L`R`#-`,X`SP#,`-,`U`#]_](`V@#;`-D`,0'&
M`MP"KP#8`MD"V@*X`-T"VP+'`@``M@```+0``````````+@`MP``````````
MPP```+````````````````"Z````````````````````````````````````
M`,4``````````````````````````````*T```"RLP````"J````O0``````
M````````````````````X-$```#4U>(`TM/C`*``I0```,D```````````#D
M``````````#<W0```````````-H``````````````````````/;_````````
M````````````````^P#W````RL&BH]L``*2LV;O'P@"H^*&Q``"KM:;A_`"\
MWP```,#+Y^7,@('>@NF#_?KMZNOL`(3Q[N_-A0"O]/+SA@``IXB'B8N*C/Z-
MCXZ0D9.2E)4`EIB7F9N:UK^=G)Z?````````````QN8`````R.@``-#P````
M`````````````````````````````````````/4`````````````````````
M`````````````````````,[/````````````````J;D`````````````````
M``````````````````"NO@````````````````````````#$````````````
M`````,0`Q0#'`,D`T0#6`-P`X0#@`.(`Y`#C`.4`YP#I`.@`Z@#K`.T`[`#N
M`.\`\0#S`/(`]`#V`/4`^@#Y`/L`_``@(+``H@"C`*<`(B"V`-\`K@!@`2(A
MM`"H`&`B?0'8`!XBL0!D(F4B!B*U``(B$2(/(F$!*R*J`+H`)B%^`?@`OP"A
M`*P`&B*2`4@B!@&K``P!)B"@`,``PP#5`%(!4P$0`10@'"`=(!@@&2#W`,HE
M_?^I`$0@I``Y(#H@Q@"[`!,@MP`:(!X@,"#"``<!P0`-`<@`S0#.`,\`S`#3
M`-0`$0'2`-H`VP#9`#$!Q@+<`J\`P`/+`-H"N`#*`.8`QP(``+8```#&````
M``````"X`+<``````````,,```"P````````````````N@``````````````
M``````````````````````#%``````````````````````````````"M````
MLK,`````J@```+T``````````````````````````-#1````U-7B`-+3XP``
M`*4```#)````````````Y`````````````````````````#:````````````
M``````````#V_P````````````````````#Y^OO^]_T```#U````````````
M``````````````````````````````#.SP``````````````````````````
M`````````````````````-D`````````````````````````````````Q```
M````````````````````````````````````RL&BH]NT`*2LJ;O'P@"H^*&Q
M``"KM:;A_`"\R````,#+Y^7,@(&N@NF#YNCMZNOLW(3Q[N_-A0"O]/+SAJ#>
MIXB'B8N*C+Z-CXZ0D9.2E)7=EIB7F9N:UK^=G)Z?X-_8Q`#%`,<`R0#1`-8`
MW`#A`.``X@#D`.,`Y0#G`.D`Z`#J`.L`[0#L`.X`[P#Q`/,`\@#T`/8`]0#Z
M`/D`^P#\`-T`L`"B`*,`IP`B(+8`WP"N`*D`(B&T`*@`8"+&`-@`'B*Q`&0B
M92*E`+4``B(1(@\BP`,K(JH`N@`F(>8`^`"_`*$`K``:(I(!2"(&(JL`NP`F
M(*``P`##`-4`4@%3`1,@%"`<(!T@&"`9(/<`RB7_`'@!1""D`-``\`#>`/X`
M_0"W`!H@'B`P(,(`R@#!`,L`R`#-`,X`SP#,`-,`U`#]_](`V@#;`-D`,0'&
M`MP"KP#8`MD"V@*X`-T"VP+'`JT```"RLP``````````````````````````
M``````````"V````Q@````````````"W``````````##``````````#0T0``
M`-35X@#2T^,`H`"E````R0```````````````````````-S=````````````
M````````````````R@``HP```*2LJ0#'P@"H`*$``````*8`````R```````
MYP``@`````"#````Z@``````[N_-A0```/(`AO@`IP"'``"*`````(X```"2
M``````"7F9N:U@``G`"?^0``@8(``(2(C(T`````B8N1DP``E)4``):8HJN=
MG@```````/ZN````````L;0``*^P````````M?H`O;ZYNKN\``#\N,'$O\#%
MRP```,_8``#,S@``V=K?X-O>Y>8`````X>0``.CI`````.WP``#Q\_3U]O<`
M`````(^0^_WK[`#$```!`0')``0!U@#<`.$`!0$,`>0`#0$&`0<!Z0!Y`7H!
M#@'M``\!$@$3`18!\P`7`?0`]@#U`/H`&@$;`?P`(""P`!@!HP"G`"(@M@#?
M`*X`J0`B(1D!J`!@(B,!+@$O`2H!9")E(BL!-@$"(A$B0@$[`3P!/0$^`3D!
M.@%%`48!0P&L`!HB1`%'`08BJP"[`"8@H`!(`5`!U0!1`4P!$R`4(!P@'2`8
M(!D@]P#*)4T!5`%5`5@!.2`Z(%D!5@%7`6`!&B`>(&$!6@%;`<$`9`%E`<T`
M?0%^`6H!TP#4`&L!;@':`&\!<`%Q`7(!<P'=`/T`-P%[`4$!?`$B`<<"`-[?
M`````````````````````````````````````````+8```#&``````````"X
M`+<``````````,,```"P````````````````N@``````````````````````
M``````````````#%``````````````````````````````"M````LK,`````
MJ@```+T``````````````````````````-#1````U-7B`-+3XP"@X*4```#)
M````````````Y```````````W-T```````````#:````````````````````
M``#V_P````````````````````#Y^OO^]_T```#U````````````````````
M``````````````````````#.SP``````````````````````````````````
M`````````````-D`````````````````````````````````Q```````````
M````````````````````````````RL&BH]NT`*2LJ;O'P@"H^*&Q``"KM:;A
M_`"\R````,#+Y^7,@(&N@NF#YNCMZNOL`(3Q[N_-A0"O]/+SA@``IXB'B8N*
MC+Z-CXZ0D9.2E)4`EIB7F9N:UK^=G)Z?``#8Q`#%`,<`R0#1`-8`W`#A`.``
MX@#D`.,`Y0#G`.D`Z`#J`.L`[0#L`.X`[P#Q`/,`\@#T`/8`]0#Z`/D`^P#\
M`"`@L`"B`*,`IP`B(+8`WP"N`*D`(B&T`*@`8"+&`-@`'B*Q`&0B92*E`+4`
M`B(1(@\BP`,K(JH`N@`F(>8`^`"_`*$`K``:(I(!2"(&(JL`NP`F(*``P`##
M`-4`4@%3`1,@%"`<(!T@&"`9(/<`RB7_`'@!1""D`#D@.B`!^P+[(2"W`!H@
M'B`P(,(`R@#!`,L`R`#-`,X`SP#,`-,`U`#]_](`V@#;`-D`,0'&`MP"KP#8
M`MD"V@*X`-T"VP+'`L0`LP```````````-H```"_````P````-D```##````
M`````+0`````````P@````````#!`````````,4`````````````````````
M````S;K5ULFXM[O4T\B^O;S&Q\RUMKG1TLO/T,K8U\X`````````````````
M````````WP```-P```#;````W0```-ZPL;(```````````````#^````````
M``#Y^P````````````````````````````#P``#R``#T````````]@"`@8*#
MA(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ_@
MX>+CY.7FY^CIZNOL[>[O`/$``/,``/4```````#W`/\```#]````````````
M``#X````````^@``````````D262)9,E`B4D)6$E8B56)54E8R51)5<E725<
M)5LE$"44)30E+"4<)0`E/"5>)5\E6B54)6DE9B5@)5`E;"5G)6@E9"5E)5DE
M6"52)5,E:R5J)1@E#"6()80EC"60)8`E0`1!!$($0P1$!$4$1@1'!$@$201*
M!$L$3`1-!$X$3P0!!%$$!`14!`<$5P0.!%X$L``9(K<`&B(6(:0`H"6@`,0`
MLP```````````-H```"_````P````-D```##`````````+0`````````P@``
M``````#!`````````,4`````````````````````````S;K5ULFXM[O4T\B^
MO;S&Q\RUMKG1TLO/T,K8U\X`````````````````````````WP```-P```#;
M````W0```-ZPL;(```````````````#^````````````````````````````
M``````````````#Y^P```.P`````````````[P``````````````````````
M`````````````````/<```````````````````````````````#P``#S\@``
M`````````````````````````.(`````Z0````````````#D``#H``#J````
M`````.```.ON`````````````.,``.7G`.T```````````#_K9N<`)T`````
MIJZJ````^/']``#F`/H``*>OK*L`J```````````````````````I0``````
M``````````#A`*```````````````*$```"D`*(```#V``"C``````#0!=$%
MT@73!=0%U076!=<%V`79!=H%VP7<!=T%W@7?!>`%X07B!>,%Y`7E!>8%YP7H
M!>D%Z@6B`*,`I0"G()(!X0#M`/,`^@#Q`-$`J@"Z`+\`$".L`+T`O`"A`*L`
MNP"1)9(EDR4")20E825B)58E525C)5$E5R5=)5PE6R40)10E-"4L)1PE`"4\
M)5XE7R5:)50E:25F)6`E4"5L)6<E:"5D)64E6258)5(E4R5K)6HE&"4,)8@E
MA"6,)9`E@"6Q`]\`DP/``Z,#PP.U`,0#I@.8`ZD#M`,>(L8#M0,I(F$BL0!E
M(F0B(",A(_<`2"*P`!DBMP`:(G\@L@"@):``S.S>TO(`````````````````
M``````````````````````"6EP```)&2@@"3E(0`AH>5````A0``````````
M`(D``````````(N;````````````````````````````S.P`W@``````T@``
M``````````````````````````````#R````````````````````````````
M`````````````````(@```````````````````````````"8``````",G```
M`````````````````````````````````````````````)\`````````````
M````````````````````@P````````````````#5]0````````````````#=
M_0````````````````````````````````````````#`P<(`Q,7&Q\C)RLL`
MS<[/`-$`T]0`UM?8V=K;W```W^#AX@#DY>;GZ.GJZP#M[N\`\0#S]`#V]_CY
M^OO\``#_``##XP```````````````-#P``````````````````"L(/W_&B"2
M`1X@)B`@("$@Q@(P(/W_.2!2`?W__?_]__W_&"`9(!P@'2`B(!,@%"#<`B(A
M_?\Z(%,!_?_]_W@!H`"A`*(`HP"D`*4`I@"G`*@`J0"J`*L`K`"M`*X`KP"P
M`+$`L@"S`+0`M0"V`+<`N`"Y`+H`NP"\`+T`O@"_`,``P0#"``(!Q`#%`,8`
MQP#(`,D`R@#+```#S0#.`,\`$`'1``D#TP#4`*`!U@#7`-@`V0#:`-L`W`"O
M`0,#WP#@`.$`X@`#`>0`Y0#F`.<`Z`#I`.H`ZP`!`^T`[@#O`!$!\0`C`_,`
M]`"A`?8`]P#X`/D`^@#[`/P`L`&K(/\`````EI<```"1DH(`DY2$`(:'E0``
M`(4```````````")``````````"+FP``````````````````````````````
M``````".``````````````````````#_`)X`````H`"BHZ0`IJ>-J0"KK*VN
MG;"QLK.TM;:WC[D`N[R]O@``````Q,6O``#)````````````TP#5UM>H````
MW```WP````#DY;\``.D```````````#S`/7V][@```#\````PN(``,#@P^,`
M````R.@`````Q^<``,OKQN8``````````,SL````````SNX``,'A````````
MS>T```#/[P````#9^='QTO(``````-3T``````````"JN@``VOH`````T/``
M`````````-O[````````V/@``````,KJW?W>_@"L(/W_&B#]_QX@)B`@("$@
M_?\P(/W_.2#]_Z@`QP*X`/W_&"`9(!P@'2`B(!,@%"#]_R(A_?\Z(/W_KP#;
M`OW_H`#]_Z(`HP"D`/W_I@"G`-@`J0!6`:L`K`"M`*X`Q@"P`+$`L@"S`+0`
MM0"V`+<`^`"Y`%<!NP"\`+T`O@#F``0!+@$``08!Q`#%`!@!$@$,`<D`>0$6
M`2(!-@$J`3L!8`%#`44!TP!,`=4`U@#7`'(!00%:`6H!W`![`7T!WP`%`2\!
M`0$'`>0`Y0`9`1,!#0'I`'H!%P$C`3<!*P$\`6$!1`%&`?,`30'U`/8`]P!S
M`4(!6P%K`?P`?`%^`=D"`````)V>_?X```"6EP```)&2@@"3E(0`AH>5````
MA0```````````(D``````````(N;``````````````````````"A````````
M``````````"Z````OP#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76V-G:VP``````
MW-W>W^'CY.7F[.WP\?+S]?;X^@``````````````````````````````````
M````````````````B@````"!`````````(T`CP``````````F@```````(X`
M````````````````````F```````D`````````````"?````J@``P```````
M``````````````#_``````````````````````````````",G```````````
M````````````````````````````````````````````````````````````
M````````````@P``````````````````````````````````````H`"BHZ2E
MIJ>HJ0"KK*VNK["QLK.TM;:WN+D`N[R]O@``````````````````````````
M`````-<``````````.``X@````#GZ.GJZP``[N\`````]```]P#Y`/O\````
MK"!^!AH@D@$>("8@("`A(,8","!Y!CD@4@&&!I@&B`:O!A@@&2`<(!T@(B`3
M(!0@J08B(9$&.B!3`0P@#2"Z!J``#`:B`*,`I`"E`*8`IP"H`*D`O@:K`*P`
MK0"N`*\`L`"Q`+(`LP"T`+4`M@"W`+@`N0`;!KL`O`"]`+X`'P;!!B$&(@8C
M!B0&)08F!B<&*`8I!BH&*P8L!BT&+@8O!C`&,08R!C,&-`8U!C8&UP`W!C@&
M.08Z!D`&009"!D,&X`!$!N(`109&!D<&2`;G`.@`Z0#J`.L`209*!NX`[P!+
M!DP&309.!O0`3P90!O<`40;Y`%(&^P#\``X@#R#2!L3'R,G,S]'2````````
M````````````````````````'?O9!0#_```?^_(%`?\``"K[Z04&_P``*_OI
M!0?_```L^^D%!`8``"W[Z04$!P``+OO0!0'_```O^]`%`O\``##[T`4$_P``
M,?O1!03_```R^](%!/\``#/[TP4$_P``-/O4!03_```U^]4%!/\``#;[U@4$
M_P``./O8!03_```Y^]D%!/\``#K[V@4$_P``._O;!03_```\^]P%!/\``#[[
MW@4$_P``0/O@!03_``!!^^$%!/\``$/[XP4$_P``1/OD!03_``!&^^8%!/\`
M`$?[YP4$_P``2/OH!03_``!)^^D%!/\``$K[Z@4$_P``2_O5!0/_``!,^]$%
M!?\``$W[VP4%_P``3OOD!07_````````````````````````````````_?X`
M``"6EP```)&2@@"3E(0`AH>5````A0```````````(D``````````(N;````
M`````````````,#!PL/$Q<;'R,D`R\S-SL_0T=+3````````````````X.'B
MX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ``````#4U=;7V```````````````
M`````````````````````````````(@```````````````````````````"8
M````H*&BHP"EIJ>HJ0"KK*VNK["QLK.TM;:WN+D`N[R]OK\`````````````
M`````````````````*H`````````````````````````````````````````
MN@``````````V04=^]`%+OOR!1_[T`4O^]4%2_O0!3#[T04Q^](%,OO3!3/[
MU`4T^]4%-?O6!3;[V`4X^]D%.?O:!3K[VP4[^]P%//O>!3[[X`5`^^$%0?OC
M!4/[Y`5$^^8%1OOG!4?[Z`5(^^D%2?OJ!4K[*OLL^RO[+?O1!4S[VP5-^^0%
M3OOI!2K[2?LL^^D%*_M)^RW[``````````````````````$``````````@``
M``$````!`````P````$````$````&`````4````#````'0````(````@````
M`@```"(```"L(/W_&B"2`1X@)B`@("$@Q@(P(/W_.2#]__W__?_]__W_&"`9
M(!P@'2`B(!,@%"#<`B(A_?\Z(/W__?_]__W_H`"A`*(`HP"J(*4`I@"G`*@`
MJ0#7`*L`K`"M`*X`KP"P`+$`L@"S`+0`M0"V`+<`N`"Y`/<`NP"\`+T`O@"_
M`+`%L06R!;,%M`6U!;8%MP6X!;D%_?^[!;P%O06^!;\%P`7!!<(%PP7P!?$%
M\@7S!?0%_?_]__W__?_]__W__?_0!=$%T@73!=0%U076!=<%V`79!=H%VP7<
M!=T%W@7?!>`%X07B!>,%Y`7E!>8%YP7H!>D%Z@7]__W_#B`/(/W_````EI<`
M``"1DH(`DY2$`(:'E0```(4```````````")``````````"+FP``````````
M`````````````````````````(@```````````````````````````"8````
M````````T/``````````````````````W?T`````````````````````````
M`````````````````(R<`````````````-[^BIH`````````````````````
M````````GP````````````````````````````````"#````````T=+3U-76
MU]C9VMO<``#?X.'BX^3EYN?HZ>KK[.WN[P#Q\O/T]?;W^/GZ^_P``/\`````
M````````````````'P'Q`/(`\P#T`/4`]@#W`/@`^0#Z`/L`_``Q`5\!_P`>
M`=$`T@#3`-0`U0#6`-<`V`#9`-H`VP#<`#`!7@'?`*P@_?\:()(!'B`F("`@
M(2#&`C`@8`$Y(%(!_?_]__W__?\8(!D@'"`=("(@$R`4(-P"(B%A`3H@4P']
M__W_>`$```"6EZ\``)&2@@"3E(0`AH>5````A0```````````(D`````````
M`(N;`````````````````````````````````+2AH@"XN;H`O`"^O\#!PL/$
MQ<;'R,G*R\S-SL_0T0#3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q
M\O/T]?;W^/GZ^_S]_@``````````````````````H```HZ2EIJ>HJ0"KK*VN
M`+"QLK,`M;:W````NP"]``"L(/W_&B"2`1X@)B`@("$@_?\P(/W_.2#]__W_
M_?_]__W_&"`9(!P@'2`B(!,@%"#]_R(A_?\Z(/W__?_]__W_H`"%`X8#HP"D
M`*4`I@"G`*@`J0#]_ZL`K`"M`*X`%2"P`+$`L@"S`(0#M0"V`+<`B`.)`XH#
MNP",`[T`C@./`Y`#D0.2`Y,#E`.5`Y8#EP.8`YD#F@.;`YP#G0.>`Y\#H`.A
M`_W_HP.D`Z4#I@.G`Z@#J0.J`ZL#K`.M`ZX#KP.P`[$#L@.S`[0#M0.V`[<#
MN`.Y`[H#NP.\`[T#O@._`\`#P0/"`\,#Q`/%`\8#QP/(`\D#R@/+`\P#S0/.
M`_W_````EI<```"1DH(`DY2$`(:'E0```(4```````````")``````````"+
MFP```````````````````````````````````(@`````````````````````
M``````"8``````",G````````````````(J:````````````````````````
M`````)\`````CIX`````````````````````````@P``````````````````
M````````````````````K"#]_QH@D@$>("8@("`A(,8","!@`3D@4@']_WT!
M_?_]_Q@@&2`<(!T@(B`3(!0@W`(B(6$!.B!3`?W_?@%X`0```):7````D9*"
M`).4A`"&AY4```"%````````````B0``````````BYL`````````````````
M````````````J("!JKVRKZ.*C(Z-`*&/P,'"P\3%QL?(R<K+S,W.S]#1TM/4
MU=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P"X
MD(.ZOK._O)J<GIT`HI\`````````````````````````````````````````
M``````````````````````"EM```````````````````H````*0`IJ<`J0"K
MK*VN`+"Q````M;:W````NP`````"!`,$&B!3!!X@)B`@("$@K"`P(`D$.2`*
M!`P$"P0/!%($&"`9(!P@'2`B(!,@%"#]_R(A600Z(%H$7`1;!%\$H``.!%X$
M"`2D`)`$I@"G``$$J0`$!*L`K`"M`*X`!P2P`+$`!@16!)$$M0"V`+<`4006
M(50$NP!8!`4$5017!!`$$002!!,$%`05!!8$%P08!!D$&@0;!!P$'00>!!\$
M(`0A!"($(P0D!"4$)@0G!"@$*00J!"L$+`0M!"X$+P0P!#$$,@0S!#0$-00V
M!#<$.`0Y!#H$.P0\!#T$/@0_!$`$001"!$,$1`1%!$8$1P1(!$D$2@1+!$P$
M301.!$\$````EI<```"1DH(`DY2$`(:'E0```(4```````````")````````
M``"+FP````````````````````````````````````"A````````````````
M`````*+_`+(`O0``H````*0`IJ>HJ0"KK*VN`+"Q``"TM;:WN```NP``````
MP<(`Q```QP#)`,L`S<X`````T]0`UM<``-H`W-T`WP#AX@#D``#G`.D`ZP#M
M[@````#S]`#V]P``^@#\_0````##XZ6YQN8`````R.C/[]#P````````RNK,
M[```````````````````````````````````````Q>4``+R^``"CL]'Q``#2
M\@````````#5]0``P.```-CXC)P``*JZBIK>_HV=``````````#9^=O[````
M`````(^?K[^.G@"L(/W_&B#]_QX@)B`@("$@_?\P(&`!.2!:`60!?0%Y`?W_
M&"`9(!P@'2`B(!,@%"#]_R(A80$Z(%L!90%^`7H!H`#'`M@"00&D``0!I@"G
M`*@`J0!>`:L`K`"M`*X`>P&P`+$`VP)"`;0`M0"V`+<`N``%`5\!NP`]`=T"
M/@%\`50!P0#"``(!Q``Y`08!QP`,`<D`&`'+`!H!S0#.``X!$`%#`4<!TP#4
M`%`!U@#7`%@!;@':`'`!W`#=`&(!WP!5`>$`X@`#`>0`.@$'`><`#0'I`!D!
MZP`;`>T`[@`/`1$!1`%(`?,`]`!1`?8`]P!9`6\!^@!Q`?P`_0!C`=D"@`"!
M````````````@@```(,```"$````A0```(8`````````AP````````"(````
M`````(D`````````B@````````````````````````"@H:(`I0``J*FJJZP`
M`*^PL;(`M0``N+FZN[P```````````````````````````"+````C````(T`
M``".````CY"1D@```````````````)0`````````DYL`````````````````
M`````````````)66````````````````````````````````````````````
M````````````````EP```````````````````````````````````)B9````
M`````````````````````+,``+0`MK<```````"^`.'B]^?DY?;ZZ>KK[.WN
M[_#R\_3UYNCC_OO]__GX_.#QP<+7Q\3%UMK)RLO,S<[/T-+3U-7&R,/>V]W?
MV=C<P-$`HP``I`"FIP```````*X`````````````````````````````````
M````````````````````````````````O:T``````````````````)H`````
M`````+\```````"<`)T`````G@``````````````````````````````````
M`````````````````````````````````````````````````)\`````````
M```E`B4,)1`E%"48)1PE)"4L)30E/"6`)80EB"6,)9`ED262)9,E(".@)1DB
M&B)((F0B92*@`"$CL`"R`+<`]P!0)5$E4B51!%0$5"56!%<$5R58)5DE6B5;
M)9$$7@1>)5\E8"5A)0$$!`1C)08$!P1F)6<E:"5I)6HED`0.!*D`3@0P!#$$
M1@0T!#4$1`0S!$4$.`0Y!#H$.P0\!#T$/@0_!$\$0`1!!$($0P0V!#($3`1+
M!#<$2`1-!$D$1P1*!"X$$`01!"8$%`05!"0$$P0E!!@$&00:!!L$'`0=!!X$
M'P0O!"`$(00B!",$%@02!"P$*P07!"@$+00I!"<$*@2``($```````````""
M````@P```(0```"%````A@````````"'`````````(@`````````B0``````
M``"*`````````````````````````*"AH@"E``"HJ:JKK`"NK["QL@"U``"X
MN;J[O`"^`````````````````````````(L```",````C0```(X```"/D)&2
M````````````````E`````````"3FP``````````````````````````````
ME98`````````````````````````````````````````````````````````
M``"7````````````````````````````````````F)D`````````````````
M````````LP``M`"VMP``````````X>+WY^3E]OKIZNOL[>[O\/+S]/7FZ./^
M^_W_^?C\X/'!PM?'Q,76VLG*R\S-SL_0TM/4U<;(P][;W=_9V-S`T0"C``"D
M`*:G````````````````````````````````````````````````````````
M``````````````````"]K0``````````````````F@``````````OP``````
M`)P`G0````">````````````````````````````````````````````````
M````````````````````````````````````GP```````````"4")0PE$"44
M)1@E'"4D)2PE-"4\)8`EA"6()8PED"61)9(EDR4@(Z`E&2(:(D@B9")E(J``
M(2.P`+(`MP#W`%`E4252)5$$5`14)58$5P17)5@E625:)5LED01=)5XE7R5@
M)6$E`00$!&,E!@0'!&8E9R5H)6DE:B60!&PEJ0!.!#`$,01&!#0$-01$!#,$
M100X!#D$.@0[!#P$/00^!#\$3P1`!$$$0@1#!#8$,@1,!$L$-P1(!$T$201'
M!$H$+@00!!$$)@04!!4$)`03!"4$&`09!!H$&P0<!!T$'@0?!"\$(`0A!"($
M(P06!!($+`0K!!<$*`0M!"D$)P0J!(``@0```````````((```"#````A```
M`(4```"&`````````(<`````````B`````````")`````````(H`````````
M````````````````H*&BI*6FIZBIJJNLK:ZOL+&RM+6VM[BYNKN\O;X`````
M````````````````````BP```(P```"-````C@```(^0D9(`````````````
M``"4`````````).;``````````````````````````````"5E@``````````
M`````````````````````````````````````````````````)<`````````
M``````````````````````````"8F0````````````````````````"S````
M``````````````#AXO?GY.7V^NGJZ^SM[N_P\O/T]>;HX_[[_?_Y^/S@\<'"
MU\?$Q=;:R<K+S,W.S]#2T]35QLC#WMO=W]G8W,#1`*,`````````````````
M`)H``````````+\```````"<`)T`````G@``````````````````````````
M`````````````````````````````````````````````````````````)\`
M```````````E`B4,)1`E%"48)1PE)"4L)30E/"6`)80EB"6,)9`ED262)9,E
M(".@)1DB&B)((F0B92*@`"$CL`"R`+<`]P!0)5$E4B51!%,E5"55)58E5R58
M)5DE6B5;)5PE725>)5\E8"5A)0$$8B5C)60E925F)6<E:"5I)6HE:R5L):D`
M3@0P!#$$1@0T!#4$1`0S!$4$.`0Y!#H$.P0\!#T$/@0_!$\$0`1!!$($0P0V
M!#($3`1+!#<$2`1-!$D$1P1*!"X$$`01!"8$%`05!"0$$P0E!!@$&00:!!L$
M'`0=!!X$'P0O!"`$(00B!",$%@02!"P$*P07!"@$+00I!"<$*@0``````+6E
M`*JZWOX``````````````````````````*````````"G`*D`JP"M``"PL0``
M``"VMP```+L`````P,'"`,0`QL?(R<K+S,W.SP``TM/4`-8``-G:V]P``-_@
MX>(`Y`#FY^CIZNOL[>[O``#R\_0`]@``^?K[_```_P``P^.AHL7E`````+*Y
M``#0\````````-W]````````````````````````````````````````````
M````````H[/1\0``````````````U?6\O0```````-?W`````*:H````````
M``````````#8^````````+ZLKJ^_M+@`H``$`04!00&L(!X@8`&G`&$!J0`8
M`JL`>0&M`'H!>P&P`+$`#`%"`7T!'2"V`+<`?@$-`1D"NP!2`5,!>`%\`<``
MP0#"``(!Q``&`<8`QP#(`,D`R@#+`,P`S0#.`,\`$`%#`=(`TP#4`%`!U@!:
M`7`!V0#:`-L`W``8`1H"WP#@`.$`X@`#`>0`!P'F`.<`Z`#I`.H`ZP#L`.T`
M[@#O`!$!1`'R`/,`]`!1`?8`6P%Q`?D`^@#[`/P`&0$;`O\```"\O0``````
M`````````*:H`````````````````````````````+X`````M+@`````````
M`````````````*"AHJ,`I0"G`*FJJZRMKJ^PL;*S`+6VMP"YNKL```"_H`"A
M`*(`HP"L(*4`8`&G`&$!J0"J`*L`K`"M`*X`KP"P`+$`L@"S`'T!M0"V`+<`
M?@&Y`+H`NP!2`5,!>`&_````K+P`````````````````````````````````
M``````"AH@```````*:K````````````````````````L+$`````````````
M`````````````````````````````+2U``````````````````````````"W
MN0``````````N[\``````````-?W``````````````````````````"HN*JZ
MO;X```````#0\-[^KP``````````````````````I*4`````````````````
M`````````+*S````````H```HP```*<`J0```*VN`````````+8`````````
M``#`P<+#Q,7&Q\C)RLO,S<[/`-'2T]35U@#8V=K;W-T`W^#AXN/DY>;GZ.GJ
MZ^SM[N\`\?+S]/7V`/CY^OO\_0#_H``"'@,>HP`*`0L!"AZG`(`>J0""'@L>
M\AZM`*X`>`$>'A\>(`$A`4`>01ZV`%8>@1Y7'H,>8![S'H0>A1YA'L``P0#"
M`,,`Q`#%`,8`QP#(`,D`R@#+`,P`S0#.`,\`=`'1`-(`TP#4`-4`U@!J'M@`
MV0#:`-L`W`#=`'8!WP#@`.$`X@#C`.0`Y0#F`.<`Z`#I`.H`ZP#L`.T`[@#O
M`'4!\0#R`/,`]`#U`/8`:Q[X`/D`^@#[`/P`_0!W`?\``/\``+2AI0``````
M``````````````````````````"@`**CI`"FIP"I`*NLK:X`L+&RLP"UMK<`
MN0"[O+V^``````#$Q:\``,D```````````#3`-76UZ@```#<``#?`````.3E
MOP``Z0```````````/,`]?;WN````/P```#"X@``P.##XP````#(Z`````#'
MYP``R^O&Y@``````````S.P```````#.[@``P>$```````#-[0```,_O````
M`-GYT?'2\@``````U/0``````````*JZ``#:^@````#0\```````````V_L`
M``````#8^```````RNK=_=[^`*``'2"B`*,`I``>(*8`IP#8`*D`5@&K`*P`
MK0"N`,8`L`"Q`+(`LP`<(+4`M@"W`/@`N0!7`;L`O`"]`+X`Y@`$`2X!``$&
M`<0`Q0`8`1(!#`')`'D!%@$B`38!*@$[`6`!0P%%`=,`3`'5`-8`UP!R`4$!
M6@%J`=P`>P%]`=\`!0$O`0$!!P'D`.4`&0$3`0T!Z0!Z`1<!(P$W`2L!/`%A
M`40!1@'S`$T!]0#V`/<`<P%"`5L!:P'\`'P!?@$9(*````````"G``````"M
M``"P````````MP```````````,'"P\3%Q@``R0#+`,W.S]```-/4U=8`V`#:
MV]S=WM\`X>+CY.7F``#I`.L`[>[O\```\_3U]@#X`/K[_/W^`,#@``"AL0``
M`````,CH``"IN:*R``#,[,KJ``````````"CLP````"EM:2T``#'YP``````
M`*:V_P``J+@``````````-'Q````K[_2\@```````````````````````*JZ
M`````*N[U_>NO@```````-GY````````````K+P`H``$`1(!(@$J`2@!-@&G
M`#L!$`%@`68!?0&M`&H!2@&P``4!$P$C`2L!*0$W`;<`/`$1`6$!9P%^`14@
M:P%+`0`!P0#"`,,`Q`#%`,8`+@$,`<D`&`'+`!8!S0#.`,\`T`!%`4P!TP#4
M`-4`U@!H`=@`<@':`-L`W`#=`-X`WP`!`>$`X@#C`.0`Y0#F`"\!#0'I`!D!
MZP`7`>T`[@#O`/``1@%-`?,`]`#U`/8`:0'X`',!^@#[`/P`_0#^`#@!````
M````T/``````````````````````W?T`````````````````````````````
M`````````````````````````````-[^````````````````````````````
M`````-'2T]35UM?8V=K;W```W^#AXN/DY>;GZ.GJZ^SM[N\`\?+S]/7V]_CY
M^OO\``#_`````````````````````!X!T0#2`-,`U`#5`-8`UP#8`-D`V@#;
M`-P`,`%>`=\`X`#A`.(`XP#D`.4`Y@#G`.@`Z0#J`.L`[`#M`.X`[P`?`?$`
M\@#S`/0`]0#V`/<`^`#Y`/H`^P#\`#$!7P'_`````````/W^`````````-\`
M````````````````````X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ````
M``"@`**CI*6FIZBI`*NLK:ZOL+&RL[2UMK>XN0"[O+V^````````````````
M````````````````J@````````````````````````````````````````"Z
M``````````"@`/W_H@"C`*0`I0"F`*<`J`"I`-<`JP"L`*T`K@"O`+``L0"R
M`+,`M`"U`+8`MP"X`+D`]P"[`+P`O0"^`/W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?\7
M(-`%T072!=,%U`75!=8%UP78!=D%V@7;!=P%W07>!=\%X`7A!>(%XP7D!>4%
MY@7G!>@%Z07J!?W__?\.(`\@_?\``````*\``*&B````````````````````
M``````````````"TM;8`N+FZ`+P`OK_`P<+#Q,7&Q\C)RLO,S<[/T-$`T]35
MUM?8V=K;W-W>W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?X`````
M`````````````````*```*,``*:GJ*D`JZRM``"PL;*S````MP```+L`O0``
MH``8(!D@HP#]__W_I@"G`*@`J0#]_ZL`K`"M`/W_%2"P`+$`L@"S`(0#A0.&
M`[<`B`.)`XH#NP",`[T`C@./`Y`#D0.2`Y,#E`.5`Y8#EP.8`YD#F@.;`YP#
MG0.>`Y\#H`.A`_W_HP.D`Z4#I@.G`Z@#J0.J`ZL#K`.M`ZX#KP.P`[$#L@.S
M`[0#M0.V`[<#N`.Y`[H#NP.\`[T#O@._`\`#P0/"`\,#Q`/%`\8#QP/(`\D#
MR@/+`\P#S0/.`_W_`````*P``````````````````+L```"_`,'"P\3%QL?(
MR<K+S,W.S]#1TM/4U=;7V-G:``````#@X>+CY.7FY^CIZNOL[>[O\/'R````
M``"@````I```````````K0``H`#]__W__?^D`/W__?_]__W__?_]__W_#`:M
M`/W__?_]__W__?_]__W__?_]__W__?_]__W_&P;]__W__?\?!OW_(08B!B,&
M)`8E!B8&)P8H!BD&*@8K!BP&+08N!B\&,`8Q!C(&,P8T!C4&-@8W!C@&.08Z
M!OW__?_]__W__?]`!D$&0@9#!D0&109&!D<&2`9)!DH&2P9,!DT&3@9/!E`&
M4092!OW__?_]__W__?_]__W__?_]__W__?_]__W_`*&BHZ2EIJ>HJ:JKK`"N
MK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;
MW-W>W^#AXN/DY>;GZ.GJZ^SM[N\`\?+S]/7V]_CY^OO\`/[_H````````/T`
M`````*T```````````````````````"@``$$`@0#!`0$!00&!`<$"`0)!`H$
M"P0,!*T`#@0/!!`$$002!!,$%`05!!8$%P08!!D$&@0;!!P$'00>!!\$(`0A
M!"($(P0D!"4$)@0G!"@$*00J!"L$+`0M!"X$+P0P!#$$,@0S!#0$-00V!#<$
M.`0Y!#H$.P0\!#T$/@0_!$`$001"!$,$1`1%!$8$1P1(!$D$2@1+!$P$301.
M!$\$%B%1!%($4P14!%4$5@17!%@$601:!%L$7`2G`%X$7P0`````````MP``
M````````````````````_P"R`````*````"D``"GJ`````"M`*^P````M```
M`+@``````````,'"P\3%Q@``R0#+`,W.``````#4U=;7V`#:V]P``-\`X>+C
MY.7F``#I`.L`[>X``````/3U]O?X`/K[_````,#@``"AL0```````,CH``#0
M\*JZ``#,[,KJ``````````"KNP````"EM<_O``#'YP```````-/SH@``IK8`
M`````````-'Q````O;_2\@``````````H[,``````````*FY`````*R\W?W>
M_@```````-GY````````````KKX`H``$`3@!5@&D`"@!.P&G`*@`8`$2`2(!
M9@&M`'T!KP"P``4!VP)7`;0`*0$\`<<"N`!A`1,!(P%G`4H!?@%+`0`!P0#"
M`,,`Q`#%`,8`+@$,`<D`&`'+`!8!S0#.`"H!$`%%`4P!-@'4`-4`U@#7`-@`
M<@':`-L`W`!H`6H!WP`!`>$`X@#C`.0`Y0#F`"\!#0'I`!D!ZP`7`>T`[@`K
M`1$!1@%-`3<!]`#U`/8`]P#X`',!^@#[`/P`:0%K`=D"HO\`````````````
M``````````````````````````#&YL7E`````````````````````-CXJ[O5
M]0``IK:AL0``````````J;D``*R\````````````````````````````````
M``````````````````#>_JJZ````````````````W?T`````````````````
MK[\``````````````*```*.D``"GJ`````"M``"P`+*SM+4`M[@`````O0``
MP,'"`,0``,?(R<K+S,W.SP#1TM/4`-;7`-G:V]P``-_@X>(`Y```Y^CIZNOL
M[>[O`/'R\_0`]O<`^?K[_````*``)@'8`J,`I`#]_R0!IP"H`#`!7@$>`30!
MK0#]_WL!L``G`;(`LP"T`+4`)0&W`+@`,0%?`1\!-0&]`/W_?`'``,$`P@#]
M_\0`"@$(`<<`R`#)`,H`RP#,`,T`S@#/`/W_T0#2`-,`U``@`=8`UP`<`=D`
MV@#;`-P`;`%<`=\`X`#A`.(`_?_D``L!"0'G`.@`Z0#J`.L`[`#M`.X`[P#]
M__$`\@#S`/0`(0'V`/<`'0'Y`/H`^P#\`&T!70'9`@````````"W````````
M`````````````*+_`+(`O0``H````*0``*>H`````*T``+````"T````N```
M````````P<(`Q```QP#)`,L`S<X`````T]0`UM<``-H`W-T`WP#AX@#D``#G
M`.D`ZP#M[@````#S]`#V]P``^@#\_0````##XZ&QQN8`````R.C/[]#P````
M````RNK,[```````````````````````````````````````Q>4``*6U``"C
ML]'Q``#2\@````````#5]0``P.```-CXIK8``*JZJ;G>_JN[``````````#9
M^=O[`````````*R\K[^NO@"@``0!V`)!`:0`/0%:`:<`J`!@`5X!9`%Y`:T`
M?0%[`;``!0';`D(!M``^`5L!QP*X`&$!7P%E`7H!W0)^`7P!5`'!`,(``@'$
M`#D!!@''``P!R0`8`<L`&@'-`,X`#@$0`4,!1P'3`-0`4`'6`-<`6`%N`=H`
M<`'<`-T`8@'?`%4!X0#B``,!Y``Z`0<!YP`-`>D`&0'K`!L![0#N``\!$0%$
M`4@!\P#T`%$!]@#W`%D!;P'Z`'$!_`#]`&,!V0(``````*C_`_[__P?^__\'
M`"8``('S_X?^__\'_O__!P`F``#_]_______[____S]F1`4(9$0%"%-$!0A"
M1`4(+D0%"!I$!0@&1`4(2FP%"'AK!0AX:P4(0&P%"#9L!0A;;`4(>&L%"'AK
M!0A1;`4(>&L%"'AK!0@L;`4(>&L%""5L!0BK:P4(?7`%".)P!0AX<`4(Z7`%
M"'AP!0AX<`4(>'`%"'AP!0AX<`4(\'`%"'AP!0AX<`4(>'`%"'AP!0AX<`4(
M>'`%"'AP!0AX<`4(>'`%"'AP!0AX<`4(>'`%"'AP!0AX<`4(>'`%"'AP!0AX
M<`4(>'`%"'AP!0AX<`4(>'`%"'AP!0AX<`4(>'`%"'AP!0CW<`4("X@%"'*(
M!0@&B`4(@(@%"`:(!0@&B`4(!H@%"`:(!0@&B`4(AX@%"`:(!0@&B`4(!H@%
M"`:(!0@&B`4(!H@%"`:(!0@&B`4(!H@%"`:(!0@&B`4(!H@%"`:(!0@&B`4(
M!H@%"`:(!0@&B`4(!H@%"`:(!0@&B`4(!H@%"`:(!0@&B`4(!H@%"`:(!0AY
MB`4($<$%"!'"!0A,P04(@,$%"&S`!0C3OP4(,[\%",I8``#*6```C%8``(M8
M``",Q04(",@%"&C&!0CDR`4((,8%")3%!0A9X04(_.,%")#C!0@DXP4(N.(%
M"!WB!0@X]`4(#_<%"+7V!0A)]@4(\/4%");U!0@]]04(Z/0%"#CT!0@X]`4(
M./0%"#CT!0@X]`4(./0%"#CT!0AE]`4(H3<&"+@W!@A@-P8(S#8&"-`U!@C0
M-08($$H&"!!*!@A&2@8(1DH&"$9*!@@\2@8(/$H&"#Q*!@A&2@8(1DH&"$9*
M!@@\2@8(/$H&"#Q*!@@02@8(1DH&"$9*!@@\2@8(/$H&"```````````````
M`````````````````'`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#
M<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P
M`W`#<`-P`W`#<`-P`P8`10!P`RP`!0`&`!(`/``)``@`,@`.``T`#P%P`W`#
M<`-P`W`#<`-K`)@`!0`=``<`*P!P`"H`!0!5`6H`"@">``@`!0`&`'`#/0`F
M`&(`F`#"`'``'@`*``8`<`-P`W`#<`,\`'`#<`-P`W`#<`-P`W`#<`-P`W`#
M<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P
M3`8([TP&".],!@CA3`8(TTP&",5,!@BW3`8(J4P&")M,!@B-3`8(?TP&"-I.
M!@A93P8(64\&"$M/!@@]3P8(+T\&""%/!@@33P8(!4\&"/=.!@CI3@8([%`&
M"&M1!@AK408(75$&"$]1!@A!408(,U$&""51!@@7408("5$&"/M0!@AD4P8(
M@%,&"(Q3!@B<4P8(4%,&"```````````+R]44D%.4TQ)5``O+TE'3D]210``
M)34P<R`E-3!S```O=7-R+VAO;64O8G5I;&1E<B]P8E]W;W)K7V1I<B]P;&5S
M:S<N-2XT7VAO=&9I>#A?-RXU+C0O<'-A+VQI8B]D:7-T+VQI8@!40U``4T]#
M2T54`%!)4$4`345-3U)9`#`P,#`P`$A9,#`P`&]P=&EO;G,`<&]R=`!C;VUP
M<F5S<P!P:7!E`'5S97(`:6YI="UC;VUM86YD`&1A=&%B87-E`&1E8G5G`')E
M='5R;BUF;W5N9"UR;W=S`'-S;"UK97D`<W-L+6-E<G0`<W-L+6-A`'-S;"UC
M87!A=&@`8VAA<F%C=&5R+7-E=',M9&ER`&1E9F%U;'0M8VAA<F%C=&5R+7-E
M=`!I;G1E<F%C=&EV92UT:6UE;W5T`&-O;FYE8W0M=&EM96]U=`!D:7-A8FQE
M+6QO8V%L+6EN9FEL90!R97!L:6-A=&EO;BUP<F]B90!E;F%B;&4M<F5A9',M
M9G)O;2UM87-T97(`<F5P;"UP87)S92UQ=65R>0!S<VPM8VEP:&5R`&UA>"UA
M;&QO=V5D+7!A8VME=`!S:&%R960M;65M;W)Y+6)A<V4M;F%M90!M=6QT:2UR
M97-U;'1S`&UU;'1I+7-T871E;65N=',`;75L=&DM<75E<FEE<P!S96-U<F4M
M875T:`!C;&EE;G0`9#IT.F\L+W1M<"]C;&EE;G0N=')A8V4`;7D`35E344Q?
M4%=$`&QA=&EN,0!5;FMN;W=N(&]P=&EO;B!T;R!P<F]T;V-O;#H@)7,*`)E@
M!@BG8P8(?V,&"&UC!@A%8P8(&&$&"!]A!@@=8P8(T&(&"*AB!@B`8@8(96(&
M"%=B!@B98`8(F6`&")E@!@B98`8(-V(&"!=B!@@&8@8('V$&"%!A!@@_808(
M@V$&"'5A!@CX808(F6`&"-QA!@BB808(F6`&")%A!@C18P8(T6,&",-C!@BJ
MD`8(E9`&"(20!@@QD`8(#I`&".N/!@C(CP8(HX\&"'2/!@B7CP8(C(\&"/V0
M!@CND`8(:(\&".&0!@CAD`8(X9`&",B0!@BYD`8(5$-0+TE0("@E9"D`,3(W
M+C`N,"XQ`'1C<`!-65-13%]40U!?4$]25`!R;V]T`$Q/1TY!344`54Y+3D]7
M3E]54T52`"]T;7``4TA/5R!33$%612!(3U-44P!32$]7(%-,059%(%-40515
M4P!S:&]W(&1A=&%B87-E<P`@;&EK92`G`'-H;W<@=&%B;&5S`#0N,2XQ,0`E
M+2HN*F<`)2XJ9@!C;VUM:70`<F]L;&)A8VL`<V5T(&%U=&]C;VUM:70],0!S
M970@875T;V-O;6UI=#TP``!_I@8(G:8&"+^F!@A_I@8(G:8&"+>F!@BWI@8(
MG:8&"'^F!@B=I@8(G:8&"'^F!@B=I@8(G:8&")VF!@B=I@8(G:8&"+>F!@BE
MI@8(G:8&"'^F!@C(V08(%-H&"$#:!@AEV@8(B-H&"!7;!@@&V@8(^MH&"*_:
M!@C(V08(^MH&".3:!@CZV@8(;-L&".C;!@COVP8(]]L&"`3<!@@]W`8(J-L&
M"&S;!@@JW`8(K-P&",K=!@@#W@8(GMT&"([=!@@^W08(!MT&"*S<!@A0W08(
M7-X&"+K>!@B,W@8(3]\&".;>!@@,WP8(7-X&"&;@!@@UWP8(3]\&"'/?!@C:
MWP8(9N`&"(S>!@@``(!?)3`X;'@E,#AL>```````````@/___\]!````````
M/T````````!00```^$$``+Q"```$0E5N:VYO=VX@37E344P@97)R;W(`0V%N
M)W0@8W)E871E(%5.25@@<V]C:V5T("@E9"D`37E344P@<V5R=F5R(&AA<R!G
M;VYE(&%W87D`5W)O;F<@:&]S="!I;F9O`$QO8V%L:&]S="!V:6$@54Y)6"!S
M;V-K970`)2TN,3`P<R!V:6$@5$-0+TE0`$5R<F]R(&EN('-E<G9E<B!H86YD
M<VAA:V4`3F%M960@<&EP93H@)2TN,S)S`$5M8F5D9&5D('-E<G9E<@!%<G)O
M<B!O;B!32$]7(%-,059%(%-405154SH`17)R;W(@;VX@4TA/5R!33$%612!(
M3U-44SH`17)R;W(@8V]N;F5C=&EN9R!T;R!S;&%V93H`17)R;W(@8V]N;F5C
M=&EN9R!T;R!M87-T97(Z`%-33"!C;VYN96-T:6]N(&5R<F]R`$UA;&9O<FUE
M9"!P86-K970`26YV86QI9"!U<V4@;V8@;G5L;"!P;VEN=&5R`%-T871E;65N
M="!N;W0@<')E<&%R960`1&%T82!T<G5N8V%T960`26YV86QI9"!P87)A;65T
M97(@;G5M8F5R`%-H87)E9"!M96UO<GDZ("4M+C$P,',`5W)O;F<@;W(@=6YK
M;F]W;B!P<F]T;V-O;`!);G9A;&ED(&-O;FYE8W1I;VX@:&%N9&QE`````$-A
M;B=T(&-O;FYE8W0@=&\@;&]C86P@37E344P@<V5R=F5R('1H<F]U9V@@<V]C
M:V5T("<E+2XQ,#!S)R`H)60I````0V%N)W0@8V]N;F5C="!T;R!->5-13"!S
M97)V97(@;VX@)R4M+C$P,',G("@E9"D`0V%N)W0@8W)E871E(%1#4"])4"!S
M;V-K970@*"5D*0!5;FMN;W=N($UY4U%,('-E<G9E<B!H;W-T("<E+2XQ,#!S
M)R`H)60I`````%!R;W1O8V]L(&UI<VUA=&-H.R!S97)V97(@=F5R<VEO;B`]
M("5D+"!C;&EE;G0@=F5R<VEO;B`]("5D`$UY4U%,(&-L:65N="!R86X@;W5T
M(&]F(&UE;6]R>0``3&]S="!C;VYN96-T:6]N('1O($UY4U%,('-E<G9E<B!D
M=7)I;F<@<75E<GD`````0V]M;6%N9',@;W5T(&]F('-Y;F,[('EO=2!C86XG
M="!R=6X@=&AI<R!C;VUM86YD(&YO=P````!#86XG="!W86ET(&9O<B!N86UE
M9"!P:7!E('1O(&AO<W0Z("4M+C8T<R`@<&EP93H@)2TN,S)S("@E;'4I````
M0V%N)W0@;W!E;B!N86UE9"!P:7!E('1O(&AO<W0Z("4M+C8T<R`@<&EP93H@
M)2TN,S)S("@E;'4I````0V%N)W0@<V5T('-T871E(&]F(&YA;65D('!I<&4@
M=&\@:&]S=#H@)2TN-C1S("!P:7!E.B`E+2XS,G,@*"5L=2D```!#86XG="!I
M;FET:6%L:7IE(&-H87)A8W1E<B!S970@)2TN,S)S("AP871H.B`E+2XQ,#!S
M*0```$=O="!P86-K970@8FEG9V5R('1H86X@)VUA>%]A;&QO=V5D7W!A8VME
M="<@8GET97,```!4:&ES(&-L:65N="!L:6)R87)Y(&ES(&QI8V5N<V5D(&]N
M;'D@9F]R('5S92!W:71H($UY4U%,('-E<G9E<G,@:&%V:6YG("<E<R<@;&EC
M96YS90!.;R!D871A('-U<'!L:65D(&9O<B!P87)A;65T97)S(&EN('!R97!A
M<F5D('-T871E;65N=````$YO('!A<F%M971E<G,@97AI<W0@:6X@=&AE('-T
M871E;65N=`````!#86XG="!S96YD(&QO;F<@9&%T82!F;W(@;F]N+7-T<FEN
M9R]N;VXM8FEN87)Y(&1A=&$@='EP97,@*'!A<F%M971E<CH@)60I````57-I
M;F<@=6YS=7!P;W)T960@8G5F9F5R('1Y<&4Z("5D("`H<&%R86UE=&5R.B`E
M9"D``$-A;B=T(&]P96X@<VAA<F5D(&UE;6]R>3L@8VQI96YT(&-O=6QD(&YO
M="!C<F5A=&4@<F5Q=65S="!E=F5N="`H)6QU*0```$-A;B=T(&]P96X@<VAA
M<F5D(&UE;6]R>3L@;F\@86YS=V5R(&5V96YT(')E8V5I=F5D(&9R;VT@<V5R
M=F5R("@E;'4I`````$-A;B=T(&]P96X@<VAA<F5D(&UE;6]R>3L@<V5R=F5R
M(&-O=6QD(&YO="!A;&QO8V%T92!F:6QE(&UA<'!I;F<@*"5L=2D``$-A;B=T
M(&]P96X@<VAA<F5D(&UE;6]R>3L@<V5R=F5R(&-O=6QD(&YO="!G970@<&]I
M;G1E<B!T;R!F:6QE(&UA<'!I;F<@*"5L=2D`````0V%N)W0@;W!E;B!S:&%R
M960@;65M;W)Y.R!C;&EE;G0@8V]U;&0@;F]T(&%L;&]C871E(&9I;&4@;6%P
M<&EN9R`H)6QU*0``0V%N)W0@;W!E;B!S:&%R960@;65M;W)Y.R!C;&EE;G0@
M8V]U;&0@;F]T(&=E="!P;VEN=&5R('1O(&9I;&4@;6%P<&EN9R`H)6QU*0``
M``!#86XG="!O<&5N('-H87)E9"!M96UO<GD[(&-L:65N="!C;W5L9"!N;W0@
M8W)E871E("5S(&5V96YT("@E;'4I`````$-A;B=T(&]P96X@<VAA<F5D(&UE
M;6]R>3L@;F\@86YS=V5R(&9R;VT@<V5R=F5R("@E;'4I````0V%N)W0@;W!E
M;B!S:&%R960@;65M;W)Y.R!C86YN;W0@<V5N9"!R97%U97-T(&5V96YT('1O
M('-E<G9E<B`H)6QU*0!#;VYN96-T:6]N('5S:6YG(&]L9"`H<')E+30N,2XQ
M*2!A=71H96YT:6-A=&EO;B!P<F]T;V-O;"!R969U<V5D("AC;&EE;G0@;W!T
M:6]N("=S96-U<F5?875T:"<@96YA8FQE9"D``%)O=R!R971R:65V86P@=V%S
M(&-A;F-E;&5D(&)Y(&UY<W%L7W-T;71?8VQO<V4H*2!C86QL````071T96UP
M="!T;R!R96%D(&-O;'5M;B!W:71H;W5T('!R:6]R(')O=R!F971C:```4')E
M<&%R960@<W1A=&5M96YT(&-O;G1A:6YS(&YO(&UE=&%D871A`%5-05-+`%5-
M05-+7T1)4@`*57-E<B!T:6UE("4N,F8L(%-Y<W1E;2!T:6UE("4N,F8*36%X
M:6UU;2!R97-I9&5N="!S970@<VEZ92`E;&0L($EN=&5G<F%L(')E<VED96YT
M('-E="!S:7IE("5L9`I.;VXM<&AY<VEC86P@<&%G969A=6QT<R`E;&0L(%!H
M>7-I8V%L('!A9V5F875L=',@)6QD+"!3=V%P<R`E;&0*0FQO8VMS(&EN("5L
M9"!O=70@)6QD+"!-97-S86=E<R!I;B`E;&0@;W5T("5L9"P@4VEG;F%L<R`E
M;&0*5F]L=6YT87)Y(&-O;G1E>'0@<W=I=&-H97,@)6QD+"!);G9O;'5N=&%R
M>2!C;VYT97AT('-W:71C:&5S("5L9`H``````,A"<W1R:7!E9``P,3(S,#$R
M,#`R,C0U-3`Q,C8R,S`Q,#(P,@``1FEL92`G)7,G(&YO="!F;W5N9"`H17)R
M8V]D93H@)60I````0V%N)W0@8W)E871E+W=R:71E('1O(&9I;&4@)R5S)R`H
M17)R8V]D93H@)60I````17)R;W(@<F5A9&EN9R!F:6QE("<E<R<@*$5R<F-O
M9&4Z("5D*0```$5R<F]R('=R:71I;F<@9FEL92`G)7,G("A%<G)C;V1E.B`E
M9"D```!%<G)O<B!O;B!C;&]S92!O9B`G)7,G("A%<G)C;V1E.B`E9"D`````
M3W5T(&]F(&UE;6]R>2`H3F5E9&5D("5U(&)Y=&5S*0!%<G)O<B!O;B!D96QE
M=&4@;V8@)R5S)R`H17)R8V]D93H@)60I````17)R;W(@;VX@<F5N86UE(&]F
M("<E<R<@=&\@)R5S)R`H17)R8V]D93H@)60I````56YE>'!E8W1E9"!E;V8@
M9F]U;F0@=VAE;B!R96%D:6YG(&9I;&4@)R5S)R`H17)R8V]D93H@)60I````
M0V%N)W0@=6YL;V-K(&9I;&4@*$5R<F-O9&4Z("5D*0!#86XG="!R96%D(&1I
M<B!O9B`G)7,G("A%<G)C;V1E.B`E9"D`````0V%N)W0@9V5T('-T870@;V8@
M)R5S)R`H17)R8V]D93H@)60I`````$-A;B=T(&-H86YG92!S:7IE(&]F(&9I
M;&4@*$5R<F-O9&4Z("5D*0!#86XG="!O<&5N('-T<F5A;2!F<F]M(&AA;F1L
M92`H17)R8V]D93H@)60I`$-A;B=T(&=E="!W;W)K:6YG(&1I<F-T;W)Y("A%
M<G)C;V1E.B`E9"D`````0V%N)W0@8VAA;F=E(&1I<B!T;R`G)7,G("A%<G)C
M;V1E.B`E9"D``"5D(&9I;&5S(&%N9"`E9"!S=')E86US(&ES(&QE9G0@;W!E
M;@H```!$:7-K(&ES(&9U;&P@=W)I=&EN9R`G)7,G("A%<G)C;V1E.B`E9"DN
M(%=A:71I;F<@9F]R('-O;65O;F4@=&\@9G)E92!S<&%C92XN+B!2971R>2!I
M;B`E9"!S96-S``!#86XG="!C<F5A=&4@9&ER96-T;W)Y("<E<R<@*$5R<F-O
M9&4Z("5D*0```$-H87)A8W1E<B!S970@)R5S)R!I<R!N;W0@82!C;VUP:6QE
M9"!C:&%R86-T97(@<V5T(&%N9"!I<R!N;W0@<W!E8VEF:65D(&EN('1H92`G
M)7,G(&9I;&4`````3W5T(&]F(')E<V]U<F-E<R!W:&5N(&]P96YI;F<@9FEL
M92`G)7,G("A%<G)C;V1E.B`E9"D```!#86XG="!R96%D('9A;'5E(&9O<B!S
M>6UL:6YK("<E<R<@*$5R<F]R("5D*0````!#86XG="!C<F5A=&4@<WEM;&EN
M:R`G)7,G('!O:6YT:6YG(&%T("<E<R<@*$5R<F]R("5D*0```$5R<F]R(&]N
M(')E86QP871H*"D@;VX@)R5S)R`H17)R;W(@)60I``!#86XG="!S>6YC(&9I
M;&4@)R5S)R!T;R!D:7-K("A%<G)C;V1E.B`E9"D``$-O;&QA=&EO;B`G)7,G
M(&ES(&YO="!A(&-O;7!I;&5D(&-O;&QA=&EO;B!A;F0@:7,@;F]T('-P96-I
M9FEE9"!I;B!T:&4@)R5S)R!F:6QE`$-A;B=T(&QO8VL@9FEL92`H17)R8V]D
M93H@)60I`%=A<FYI;F<Z("<E<R<@:&%D("5D(&QI;FMS`%5.2TY/5TX`54Y/
M4$5.140`+BX`/P`O971C+P`O=7-R+VQO8V%L+W!S82]M>7-Q;"]V87(`?B\`
M+2UD969A=6QT<RUF:6QE/0`M+61E9F%U;'1S+65X=')A+69I;&4]`"TM;F\M
M9&5F875L=',`+2UP<FEN="UD969A=6QT<P`E<R``:6YC;'5D961I<@!I;F-L
M=61E`'=A<FYI;F<Z(%=O<FQD+7=R:71A8FQE(&-O;F9I9R!F:6QE("5S(&ES
M(&EG;F]R960*``!E<G)O<CH@5W)O;F<@9W)O=7`@9&5F:6YI=&EO;B!I;B!C
M;VYF:6<@9FEL93H@)7,@870@;&EN92`E9`H`````97)R;W(Z($9O=6YD(&]P
M=&EO;B!W:71H;W5T('!R96-E9&EN9R!G<F]U<"!I;B!C;VYF:6<@9FEL93H@
M)7,@870@;&EN93H@)60*`&5R<F]R.B!7<F]N9R`A:6YC;'5D92!D:7)E8W1I
M=F4@:6X@8V]N9FEG(&9I;&4Z("5S(&%T(&QI;F4@)60*``!E<G)O<CH@5W)O
M;F<@(6EN8VQU9&5D:7(@9&ER96-T:79E(&EN(&-O;F9I9R!F:6QE.B`E<R!A
M="!L:6YE("5D"@```$-O=6QD(&YO="!O<&5N(')E<75I<F5D(&1E9F%U;'1S
M(&9I;&4Z("5S"@``1F%T86P@97)R;W(@:6X@9&5F875L=',@:&%N9&QI;F<N
M(%!R;V=R86T@86)O<G1E9`H``"5S('=O=6QD(&AA=F4@8F5E;B!S=&%R=&5D
M('=I=&@@=&AE(&9O;&QO=VEN9R!A<F=U;65N=',Z"@````I$969A=6QT(&]P
M=&EO;G,@87)E(')E860@9G)O;2!T:&4@9F]L;&]W:6YG(&9I;&5S(&EN('1H
M92!G:79E;B!O<F1E<CH``%1H92!F;VQL;W=I;F<@9W)O=7!S(&%R92!R96%D
M.@``"E1H92!F;VQL;W=I;F<@;W!T:6]N<R!M87D@8F4@9VEV96X@87,@=&AE
M(&9I<G-T(&%R9W5M96YT.@HM+7!R:6YT+61E9F%U;'1S"5!R:6YT('1H92!P
M<F]G<F%M(&%R9W5M96YT(&QI<W0@86YD(&5X:70*+2UN;RUD969A=6QT<PD)
M1&]N)W0@<F5A9"!D969A=6QT(&]P=&EO;G,@9G)O;2!A;GD@;W!T:6]N<R!F
M:6QE"BTM9&5F875L=',M9FEL93TC"4]N;'D@<F5A9"!D969A=6QT(&]P=&EO
M;G,@9G)O;2!T:&4@9VEV96X@9FEL92`C"BTM9&5F875L=',M97AT<F$M9FEL
M93TC(%)E860@=&AI<R!F:6QE(&%F=&5R('1H92!G;&]B86P@9FEL97,@87)E
M(')E860````O=7-R+VQO8V%L+W!S82]M>7-Q;"]S:&%R92]M>7-Q;`!C:&%R
M<V5T<R\`+W5S<B]L;V-A;"]P<V$O;7ES<6P`26YD97@N>&UL`'5C<S(```$C
M16>)J\WO_MRZF'94,A#PX=+#F7F"6J'KV6[<O!N/UL%BRFQA=&EN,5]B:6X`
M;&%T:6XQ7V=E<FUA;C)?8VD`;&%T:6XQ7W-W961I<VA?8VD`*&YU;&PI`'AM
M;"YV97)S:6]N`'AM;"YE;F-O9&EN9P!C:&%R<V5T<P!C:&%R<V5T<RYM87@M
M:60`8VAA<G-E=',N8VAA<G-E=`!C:&%R<V5T<RYC:&%R<V5T+G!R:6UA<GDM
M:60`8VAA<G-E=',N8VAA<G-E="YB:6YA<GDM:60`8VAA<G-E=',N8VAA<G-E
M="YN86UE`&-H87)S971S+F-H87)S970N9F%M:6QY`&-H87)S971S+F-H87)S
M970N9&5S8W)I<'1I;VX`8VAA<G-E=',N8VAA<G-E="YA;&EA<P!C:&%R<V5T
M<RYC:&%R<V5T+F-T>7!E`&-H87)S971S+F-H87)S970N8W1Y<&4N;6%P`&-H
M87)S971S+F-H87)S970N=7!P97(`8VAA<G-E=',N8VAA<G-E="YU<'!E<BYM
M87``8VAA<G-E=',N8VAA<G-E="YL;W=E<@!C:&%R<V5T<RYC:&%R<V5T+FQO
M=V5R+FUA<`!C:&%R<V5T<RYC:&%R<V5T+G5N:6-O9&4`8VAA<G-E=',N8VAA
M<G-E="YU;FEC;V1E+FUA<`!C:&%R<V5T<RYC:&%R<V5T+F-O;&QA=&EO;@!C
M:&%R<V5T<RYC:&%R<V5T+F-O;&QA=&EO;BYI9``F`#P\/``@)7,@)7,`<')I
M;6%R>0!B:6YA<GD`8V]M<&EL960`8VAA<G-E=',N8VAA<G-E="YC;VQL871I
M;VXN;F%M90!C:&%R<V5T<RYC:&%R<V5T+F-O;&QA=&EO;BYO<F1E<@````!C
M:&%R<V5T<RYC:&%R<V5T+F-O;&QA=&EO;BYF;&%G`&-H87)S971S+F-H87)S
M970N8V]L;&%T:6]N+FUA<```8VAA<G-E=',N8VAA<G-E="YC;VQL871I;VXN
M<G5L97,N<F5S970``&-H87)S971S+F-H87)S970N8V]L;&%T:6]N+G)U;&5S
M+G```&-H87)S971S+F-H87)S970N8V]L;&%T:6]N+G)U;&5S+G,``&-H87)S
M971S+F-H87)S970N8V]L;&%T:6]N+G)U;&5S+G0``*AL!PBH;`<(0G$'"!-Q
M!PBH;`<(J&P'"-]P!PBO<`<(J&P'"*AL!PBR;`<(&'`'"(!O!P@?;@<(B6T'
M"&YM!PA+;0<(1F\'"+=N!PBW;@<(MVX'"+=N!PAB:6<U`&)I9S5?8FEN`&)I
M9S5?8VAI;F5S95]C:0!L871I;C(`;&%T:6XR7V-Z96-H7V-S`&-H``P9+R\`
M0V@`#!DP,`!#2``,&3$Q``4*$1$`!0H2$@```````````````@``````````
M```````````````````"````````````````````(R0E)B<H*2HK+```````
M```#!/\'"`D*"PT.#Q`2$Q05%A<9&QP='A\@(0````````,$_P<("0H+#0X/
M$!(3%!46%QD;'!T>'R`A````````````````````````````````````````
M```````````#`!$`$!H``!H:&R(`(B(``P`1`!`:```:&ALB`"(B%P,#`P,0
M!@8&"`@("`T-!P<3$Q04%!0`&!P<'!P@&P`7`P,#`Q`&!@8("`@(#0T'!Q,3
M%!04%``8'!P<'"`;```````````````````"````````````````````````
M``````(```````````````````!&1TA)2DM,34Y/``````````,)_PX1%A<8
M&AT>'R,D)RPM+C$U.#T^/T!"`````````PG_#A$6%Q@:'1X?(R0G+"TN,34X
M/3X_0$(```````````````````````````````````````````````````@`
M(@`A,P``,C0V1`!#10`(`"(`(3,``#(T-D0`0T4O!`4'!B`,#0L2%103&QP/
M$"8E*"DK*@`P.CD\.T$W`"\$!0<&(`P-"Q(5%!,;'`\0)B4H*2LJ`#`Z.3P[
M03<```````````````````(``````````````````````````````@``````
M`````````````(J+C(V.CY"1DI,`````````!!#_&B`J+"XS.3L]14=-5UE;
M86EO>7M]?X,````````##_\9'RDK+3(X.CQ$1DQ66%I@:&YX>GQ^@@``````
M````````````````````````````````````````````#@!#`$%E``!C9VN'
M`(6)``T`0@!`9```8F9JA@"$B%T&"`P*/Q88%"(H)B0U-QP>2TE/4553`%]S
M<7=U@6T`7`4'"PD^%1<3(2<E(S0V&QU*2$Y05%(`7G)P=G2`;```````M+6V
MM[BYNKN\`KZ_P,'"P\3%QL?(R<K+S,W.S]#1TM,"F)JKU*JIG*"AL;"5LI2=
MBHN,C8Z/D)&2DYF6I*^EEZ@$$/\:("HL+C,Y.SU%1TU765MA:6]Y>WU_@Z*?
MHZRMFP,/_QD?*2LM,C@Z/$1&3%986F!H;GAZ?'Z"IIZGKM6TM;:WN+FZN[R]
MOK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]8.UT/80679VF-G:X?;A8G<#=U"WD!D
MW^!B9FJ&X82(708(#`H_%A@4(B@F)#4W'!Y+24]155.S7W-Q=W6!;>)<!0<+
M"3X5%Q,A)R4C-#8;'4I(3E!44N-><G!V=(!LY`!E=6-K<@!E=6-K<E]B:6X`
M975C:W)?:V]R96%N7V-I`&-P,3(U,`!C<#$R-3!?8WIE8VA?8W,`=71F.`!U
M=&8X7V)I;@!U=&8X7V=E;F5R86Q?8VD`=6-S,E]B:6X`=6-S,E]G96YE<F%L
M7V-I`&=B,C,Q,@!G8C(S,3)?8FEN`&=B,C,Q,E]C:&EN97-E7V-I`&=B:P!G
M8FM?8FEN`&=B:U]C:&EN97-E7V-I`'-J:7,`<VII<U]B:6X`<VII<U]J87!A
M;F5S95]C:0!T:7,V,C``=&ES-C(P7V)I;@!T:7,V,C!?=&AA:5]C:0!U:FES
M`'5J:7-?8FEN`'5J:7-?:F%P86YE<V5?8VD`=71F.%]P97)S:6%N7V-I`'5T
M9CA?<F]M86Y?8VD`=71F.%]S<&%N:7-H,E]C:0!U=&8X7W-L;W9A:U]C:0!U
M=&8X7VQI=&AU86YI86Y?8VD`=71F.%]D86YI<VA?8VD`=71F.%]C>F5C:%]C
M:0!U=&8X7W1U<FMI<VA?8VD`=71F.%]S=V5D:7-H7V-I`'5T9CA?<W!A;FES
M:%]C:0!U=&8X7V5S=&]N:6%N7V-I`'5T9CA?<&]L:7-H7V-I`'5T9CA?<VQO
M=F5N:6%N7V-I`'5T9CA?<F]M86YI86Y?8VD`=71F.%]L871V:6%N7V-I`'5T
M9CA?:6-E;&%N9&EC7V-I`'5T9CA?=6YI8V]D95]C:0!U8W,R7W!E<G-I86Y?
M8VD`=6-S,E]R;VUA;E]C:0!U8W,R7W-P86YI<V@R7V-I`'5C<S)?<VQO=F%K
M7V-I`'5C<S)?;&ET:'5A;FEA;E]C:0!U8W,R7V1A;FES:%]C:0!U8W,R7V-Z
M96-H7V-I`'5C<S)?='5R:VES:%]C:0!U8W,R7W-W961I<VA?8VD`=6-S,E]S
M<&%N:7-H7V-I`'5C<S)?97-T;VYI86Y?8VD`=6-S,E]P;VQI<VA?8VD`=6-S
M,E]S;&]V96YI86Y?8VD`=6-S,E]R;VUA;FEA;E]C:0!U8W,R7VQA='9I86Y?
M8VD`=6-S,E]I8V5L86YD:6-?8VD`=6-S,E]U;FEC;V1E7V-I`"8@97AP96-T
M960`)7,@870@)R5S)P!5;FMN;W=N(&-H87)A8W1E<@`F(&]R(#P@97AP96-T
M960`8VAA<F%C=&5R(&5X<&5C=&5D`%-H;W5L9"!N979E<B!H87!P96X`5&]O
M(&UA;GD@<G5L97,`````````````````````````````````````)B!<=3`V
M-D0@/"!<=3`V-$4@/"!<=49%-S8@/"!<=49%-S<@/"!<=3`V-3`@/"!<=49%
M-T$@/"!<=49%-T(@/"!<=3`V-$8@/"!<=49%-S@@/"!<=49%-SD@/"!<=3`V
M-$(@/"!<=49%-S`@/"!<=49%-S$@/"!<=3`V-$0@/"!<=49%-S0@/"!<=3`V
M-$,@/"!<=49%-S(F(%QU1D4W1B`\(%QU,#8U,R`\(%QU,#8U-"`\(%QU,#8U
M-2`\(%QU,#8W,"8@7'4P-C8Y(#P@7'4P-C(R(#P@7'4P-C(W(#P@7'4P-C<Q
M(#P@7'4P-C(Q(#P@7'4P-C(S(#P@7'4P-C(U(#P@7'4P-C(T(#P@7'4P-C(V
M)B!<=3`V-#(@/"!<=3`V03D@/"!<=3`V-#,F(%QU,#8T."`\(%QU,#8T-R`\
M(%QU,#8R.2`\(%QU,#9#,"`\(%QU,#9#0R`\(%QU,#8T.2`\(%QU,#8T028@
M7'5&13@P(#P@7'5&13@Q(#P@7'5&13@R(#P@7'5&13A$(#P@7'5&13A%(#P@
M7'5&0C4P(#P@7'5&0C4Q(#P@7'5&13@P(#P@7'5&13@S(#P@7'5&13@T(#P@
M7'5&13@W(#P@7'5&13@X(#P@7'5&13@U(#P@7'5&13@V(#P@7'4P-C@Y(#P@
M7'4P-CA!)B!<=49%044@/"!<=49$1D,F(%QU1D5$."`\(%QU1D(X12`\(%QU
M1D(X1B`\(%QU1D(Y,"`\(%QU1D(Y,2`\(%QU1D5$.2`\(%QU1D5$02`\(%QU
M1D5$0B`\(%QU1D5$0R8@7'5&145%(#P@7'5&144Y(#P@7'5&145!(#P@7'5&
M145"(#P@7'5&145#(#P@7'5&13DS(#P@7'5&13DT(#P@7'5&0D$T(#P@7'5&
M0D$U(#P@7'5&0D9#(#P@7'5&0D9$(#P@7'5&0D9%(#P@7'5&0D9&(#P@7'5&
M145&(#P@7'5&148P(#P@7'5&148Q(#P@7'5&148R(#P@7'5&148S(#P@7'5&
M148T(#P@7'5&148U(#P@7'5&148V(#P@7'5&148W(#P@7'5&148X(#P@7'5&
M148Y(#P@7'5&149!(#P@7'5&149"(#P@7'5&149#```F($D@/#P@:B`\/#P@
M2B`F(%8@/#P@=2`\/#P@52`````````````````````````F0R`\("!C:"`\
M/#P@0V@@/#P\($-()DP@/"`@;&P@/#P\($QL(#P\/"!,3"9.(#P@7'4P,$8Q
M(#P\/"!<=3`P1#$F4B`\/"!R<B`\/#P@4G(@/#P\(%)2```````````F($$@
M/"!<=3`P130@/#P\(%QU,#!#-"8@0R`\(%QU,#$P1"`\/#P@7'4P,3!#)B!(
M(#P@8V@@/#P\($-H(#P\/"!#2"8@3R`\(%QU,#!&-"`\/#P@7'4P,$0T)B!3
M(#P@7'4P,38Q(#P\/"!<=3`Q-C`F(%H@/"!<=3`Q-T4@/#P\(%QU,#$W1```
M````````````````````````````)B!#(#P\(&-H(#P\/"!#:"`\/#P@0T@\
M(%QU,#$P1"`\/#P@7'4P,3!#)B!%(#P\(%QU,#$Q.2`\/#P@7'4P,3$X(#P\
M(%QU,#$Q-R`\/#P@7'4P,3$V)B!)(#P\('D@/#P\(%DF(%,@(#P@7'4P,38Q
M(#P\/"!<=3`Q-C`F(%H@(#P@7'4P,3=%(#P\/"!<=3`Q-T0`````````````
M`"8@62`\/"!<=3`P1D,@/#P\(%QU,#!$0R`\/"!<=3`Q-S$@/#P\(%QU,#$W
M,"8@6B`@/"!<=3`P138@/#P\(%QU,#!#-B`\/"!<=3`P130@/#P\(%QU,#!#
M-"`\(%QU,#!&."`\/#P@7'4P,$0X(#P\(%QU,#!&-B`\/#P@7'4P,$0V(#P\
M(%QU,#$U,2`\/#P@7'4P,34P(#P@7'4P,$4U(#P\/"!<=3`P0S4@/#P@86$@
M/#P\("!!82`\/#P@04$`````````````````````````````````````````
M)B!#(#P@7'4P,3!$(#P\/"!<=3`Q,$,@)B!((#P@("`@("!C:"`\/#P@("`@
M("!#:"`\/#P@0T@F(%(@/"!<=3`Q-3D@/#P\(%QU,#$U."8@4R`\(%QU,#$V
M,2`\/#P@7'4P,38P)B!:(#P@7'4P,3=%(#P\/"!<=3`Q-T0````F($,@/"!<
M=3`P13<@/#P\(%QU,#!#-R`F($<@/"!<=3`Q,48@/#P\(%QU,#$Q12`F($@@
M/"!<=3`Q,S$@/#P\(%QU,#`T.2`F($\@/"!<=3`P1C8@/#P\(%QU,#!$-B`F
M(%,@/"!<=3`Q-48@/#P\(%QU,#$U12`F(%4@/"!<=3`P1D,@/#P\(%QU,#!$
M0R``````````````````````)B!9(#P\7'4P,$9#(#P\/"!<=3`P1$,@)B!:
M(#P@7'4P,$4U(#P\/"!<=3`P0S4@/"!<=3`P130@/#P\(%QU,#!#-"`\/"!<
M=3`P138@/#P\(%QU,#!#-B`\(%QU,#!&-B`\/#P@7'4P,$0V(#P\(%QU,#!&
M."`\/#P@7'4P,$0X(``F($X@/"!<=3`P1C$@/#P\(%QU,#!$,2```````"8@
M4R`\(%QU,#$V,2`\/#P@7'4P,38P("`\(%QU,#`W02`\/#P@7'4P,#5!("`\
M(%QU,#$W12`\/#P@7'4P,3=$("8@5R`\(%QU,#!&-2`\/#P@7'4P,$0U(#P@
M7'4P,$4T(#P\/"!<=3`P0S0@/"!<=3`P1C8@/#P\(%QU,#!$-B`\(%QU,#!&
M0R`\/#P@7'4P,$1#(``````````````F($$@/"!<=3`Q,#4@/#P\(%QU,#$P
M-"`F($,@/"!<=3`Q,#<@/#P\(%QU,#$P-B`F($4@/"!<=3`Q,3D@/#P\(%QU
M,#$Q."`F($P@/"!<=3`Q-#(@/#P\(%QU,#$T,2`F($X@/"!<=3`Q-#0@/#P\
M(%QU,#$T,R`F($\@/"!<=3`P1C,@/#P\(%QU,#!$,R`F(%,@/"!<=3`Q-4(@
M/#P\(%QU,#$U02`F(%H@/"!<=3`Q-T$@/#P\(%QU,#$W.2`\(%QU,#$W0R`\
M/#P@7'4P,3="`````````````````"8@0R`\(%QU,#$P1"`\/#P@7'4P,3!#
M("8@4R`\(%QU,#$V,2`\/#P@7'4P,38P("8@6B`\(%QU,#$W12`\/#P@7'4P
M,3=$(````````````````````````````````"8@02`\(%QU,#$P,R`\/#P@
M7'4P,3`R(#P@7'4P,$4R(#P\/"!<=3`P0S(@)B!)(#P@7'4P,$5%(#P\/"!<
M=3`P0T4@)B!3(#P@7'4P,C$Y(#P\/"!<=3`R,3@@/#P@7'4P,35&(#P\/"!<
M=3`Q-44@)B!4(#P@7'4P,C%"(#P\/"!<=3`R,4$@/#P@7'4P,38S(#P\/"!<
M=3`Q-C(@```F($,@/"!<=3`Q,$0@/#P\(%QU,#$P0R`F($<@/"!<=3`Q,C,@
M/#P\(%QU,#$R,B`F($D@/"!<=3`P-SD@/#P\(%QU,#`U.2`F($L@/"!<=3`Q
M,S<@/#P\(%QU,#$S-B`F($P@/"!<=3`Q,T,@/#P\(%QU,#$S0B`F($X@/"!<
M=3`Q-#8@/#P\(%QU,#$T-2`F(%(@/"!<=3`Q-3<@/#P\(%QU,#$U-B`F(%,@
M/"!<=3`Q-C$@/#P\(%QU,#$V,"`F(%H@/"!<=3`Q-T4@/#P\(%QU,#$W1"``
M`````````"8@02`\(%QU,#!%,2`\/#P@7'4P,$,Q("8@1"`\(%QU,#!&,"`\
M/#P@7'4P,$0P("8@12`\(%QU,#!%.2`\/#P@7'4P,$,Y("8@22`\(%QU,#!%
M1"`\/#P@7'4P,$-$("8@3R`\(%QU,#!&,R`\/#P@7'4P,$0S("8@52`\(%QU
M,#!&02`\/#P@7'4P,$1!("8@62`\(%QU,#!&1"`\/#P@7'4P,$1$("8@6B`\
M(%QU,#!&12`\/#P@7'4P,$1%(#P@7'4P,$4V(#P\/"!<=3`P0S8@/#P@7'4P
M,$4T(#P\/"!<=3`P0S0@/"!<=3`P1C8@/#P\(%QU,#!$-B`\/"!<=3`P1C@@
M/#P\(%QU,#!$."`\(%QU,#!%-2`\/#P@7'4P,$,U(```````````````````
M````````````````/"$M+0`M+3X`/STO/#XA`#\G(CTO/#X@"0T*`%1%6%0`
M-CH@)7,@=6YE>'!E8W1E9"`H)S\G('=A;G1E9"D`4U1224Y'`$E$14Y4`$5/
M1@!#3TU-14Y4`"<_)P`G/B<`)STG`"<\)P`G+R<`)R$G`#4Z("5S('5N97AP
M96-T960@*"<^)R!W86YT960I````)SPO)7,^)R!U;F5X<&5C=&5D("@G/"\E
M<SXG('=A;G1E9"D`-#H@)7,@=6YE>'!E8W1E9"`H:61E;G0@;W(@<W1R:6YG
M('=A;G1E9"D````Q.B`E<R!U;F5X<&5C=&5D("AI9&5N="!W86YT960I`#,Z
M("5S('5N97AP96-T960@*&ED96YT(&]R("<O)R!W86YT960I```K-@@(?S,(
M"'\S"`A_,P@(?S,("'\S"`A_,P@(?S,("'\S"`A_,P@(?S,("'\S"`A_,P@(
M?S,(""$V"`A_,P@(?S,("'\S"`A_,P@(?S,("'\S"`A_,P@(?S,("'\S"`A_
M,P@(?S,("'\S"`@7-@@(#38("`,V"`CY-0@(?S,("'\S"`A_,P@([S4("'\S
M"`CE-0@(?S,("'\S"`A_,P@(VS4("'\S"`A_,P@(?S,("'\S"`A_,P@(?S,(
M"'\S"`A_,P@(?S,("-$U"`C'-0@(=C0("(`T"`B`-`@(@#0("(`T"`B`-`@(
M@#0("(`T"`B`-`@(@#0("(`T"`B`-`@(@#0("(`T"`AL-`@(@#0("(`T"`B`
M-`@(@#0("(`T"`B`-`@(@#0("(`T"`B`-`@(@#0("(`T"`B`-`@(8C0("%@T
M"`A.-`@(1#0("(`T"`B`-`@(@#0("#TT"`B`-`@(-C0("(`T"`B`-`@(@#0(
M""\T"`B`-`@(@#0("(`T"`B`-`@(@#0("(`T"`B`-`@(@#0("(`T"`C-,P@(
MOS,(""$T"`@H-`@(*#0(""@T"`@H-`@(*#0(""@T"`@H-`@(*#0(""@T"`@H
M-`@(*#0(""@T"`@H-`@(&C0(""@T"`@H-`@(*#0(""@T"`@H-`@(*#0(""@T
M"`@H-`@(*#0(""@T"`@H-`@(*#0("!,T"`@,-`@(!30("/XS"`@H-`@(*#0(
M""@T"`CW,P@(*#0("/`S"`@H-`@(*#0(""@T"`CI,P@(*#0(""@T"`@H-`@(
M*#0(""@T"`@H-`@(*#0(""@T"`@H-`@(XC,("-0S"`AD-0@(;C4("&XU"`AN
M-0@(;C4("&XU"`AN-0@(;C4("&XU"`AN-0@(;C4("&XU"`AN-0@(;C4("%HU
M"`AN-0@(;C4("&XU"`AN-0@(;C4("&XU"`AN-0@(;C4("&XU"`AN-0@(;C4(
M"&XU"`A0-0@(ZS0(".0T"`C=-`@(;C4("&XU"`AN-0@(UC0("&XU"`C/-`@(
M;C4("&XU"`AN-0@(R#0("&XU"`AN-0@(;C4("&XU"`AN-0@(;C4("&XU"`AN
M-0@(;C4(",$T"`BP-`@(0C4("$DU"`A)-0@(234("$DU"`A)-0@(234("$DU
M"`A)-0@(234("$DU"`A)-0@(234("$DU"`@[-0@(234("$DU"`A)-0@(234(
M"$DU"`A)-0@(234("$DU"`A)-0@(234("$DU"`A)-0@(-#4(""TU"`@F-0@(
M'S4("$DU"`A)-0@(234("!@U"`A)-0@($34("$DU"`A)-0@(234("`HU"`A)
M-0@(234("$DU"`A)-0@(234("$DU"`A)-0@(234("$DU"`@#-0@(\C0(""5S
M)3`R9#HE,#)D.B4P,F0`)3`T9"TE,#)D+24P,F0`)3`T9"TE,#)D+24P,F0@
M)3`R9#HE,#)D.B4P,F0```#430@(U$T(".!-"`CT30@(I$T("```($%;HV?@
M6</\/WW#E"6M2;)4________[W\```````````````````````````````"`
M:`@(``````A")0@`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````"0$`````````````````````````
M```````````````$````])L8"%#D&`@`````2)P8"$R<&`A3G!@(6)P8"```
M``!?G!@(99P8"```````````````````````````X'`&"`R)!@A(:`8(-&P&
M"!1D!@@07P8(O+D&"%#"!@@LRP8(:.L&"`CI!@@`````M+P&".!P!@C4I@8(
M(0```&N<&`C@Y!@(````````````````````````````````<YP8")2A&`AX
MG!@(06T("(&<&`@1G1@(AIP8"(N<&`C\@0@(F)P8"*&<&`BGG!@(N9P8",&<
M&`C*G!@(T9P8"-R<&`COG!@(!9T8"!F=&`@QG1@(*9T8"#Z=&`A0G1@(:9T8
M"'J=&`B%G1@(`J,8")B=&`BPG1@(OIT8",^=&`C=G1@(````````````````
M`````````````````````(`SX0&`,^$!````0``@```!````B.48"(SE&`@`
M````)*$8"#BA&`@HHQ@(;*,8")RC&`B\HQ@(5J$8".BC&`@DI!@(<:$8"(&A
M&`B;H1@(KJ$8"$2D&`ATI!@(R*$8"*RD&`CLI!@(**48"&RE&`BDI1@(VZ$8
M".NA&`@'HA@((J(8"#VB&`A9HA@(;J(8"-BE&`A_HA@(FZ(8""RF&`BRHA@(
M9*88",&B&`B,IA@(V*88"-JB&`@,IQ@(5*<8")RG&`CDIQ@(-*@8"'RH&`C,
MJ!@($*D8"$BI&`CQHA@("Z,8"(RI&`CTJ1@(+*H8"%RJ&`CTFQ@(````````
M````````````````````````````````````````````````````````\!,'
M"/`3!PB$FP0(AG<("+BK&`@"````````````````````_____P``````````
M`````````````````````/@/````````P*L8"/C_````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!@YQ@(0```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/\!``"T`0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````W*L8"`"L&`@PK!@(6*P8"("L&`BHK!@(R*P8"/"L
M&`CTFQ@((*T8",FP&`A<K1@(?*T8"*2M&`C,K1@(]*T8"""N&`A,KA@(Y[`8
M"'2N&`B<KA@(_*X8""BO&`B$KQ@(O*\8".RO&`@DL!@(3+`8"'BP&`@`````
M`````````````````````````````````````!BQ&`@>L1@(])L8"#>Q&`@`
M`````````"2!"`@`````H/H8"```````````,#$R,S0U-C<X.6%B8V1E9F=H
M:6IK;&UN;W!Q<G-T=79W>'EZ````````````````````````````````````
M`#`Q,C,T-38W.#E!0D-$149'2$E*2TQ-3D]045)35%565UA96@``````````
M```````````````````````````O```````````````1````%9X8")2U&`CT
MFQ@(`````,#U&`C`]!@(P/,8"``````````````````%&0@`````````````
M```!`````0````$``````/\`0/,8"``,&0@``````````*B'!PA,@@<(9(('
M"&R"!PB`@@<(6(('"%!B!PB$8@<(1'0'"&1T!PB$=`<(J'0'",QU!PA\?0<(
M3'X'"#2"!PA0=@<(T'<'""AY!PA4>P<(-'T'"/2%!PC,@0<(````````````
M```````````````````````````!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9
M&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&
M1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$149'2$E*2TQ-3D]045)3
M5%565UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@
MH:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-
MSL_0T=+3U-76U]C9VMO<W=[?P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;WV-G:
MV]S=WO\``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G
M*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0&%B8V1E9F=H:6IK;&UN;W!Q<G-T
M=79W>'EZ6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'U^?X"!
M@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VN
MK["QLK.TM;:WN+FZN[R]OK_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]M?X^?K[
M_/W^W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_`"`@("`@("`@
M("@H*"@H("`@("`@("`@("`@("`@("`@2!`0$!`0$!`0$!`0$!`0$(2$A(2$
MA(2$A(00$!`0$!`0@8&!@8&!`0$!`0$!`0$!`0$!`0$!`0$!`0$0$!`0$!""
M@H*"@H("`@("`@("`@("`@("`@("`@("`A`0$!`@````````````````````
M``````````````````````!($!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$`$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!$`$!`0$!`0$"`@("`@("`@("
M`@("`@("`@("`@("`@(0`@("`@("`@(`````````````````````````````
M````````````'P``````````````00```!6>&`B?M1@(])L8"`````#`]1@(
MP/08",#S&`B`]Q@(````````````!1D(`````````````````@````$````!
M``````#W`$#S&`A`]Q@(`````,1B!PB08P<(D&0'"/2`!PA\?P<(S'0'"*""
M!P@$90<(```````````````````````````````````````!`@,$!08'"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W
M.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$
M149'2$E*2TQ-3D]045)35%565UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1
MDI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^
MOT%!04'$05Q#145%14E)24E$3D]/3T_6U]A5557<6=[?04%!0<1!7$-%145%
M24E)241.3T]/3];WV%555=Q9WED`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````10``````````
M````````````10``````10``4P````!%``````````````````````!%````
M``!%`````````````````````````````````````````````````0(#!`4&
M!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S
M-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@
M04)#1$5&1TA)2DM,34Y/4%%24U155E=865I[?'U^?X"!@H.$A8:'B(F*BXR-
MCH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZ
MN[R]OK]!04%!04%<0T5%145)24E)1$Y/3T]/3]?8555555G>4T%!04%!05Q#
M145%14E)24E$3D]/3T]/]]A555556=Y9"```````````````(0```!6>&`BQ
MM1@(])L8"`````#`]1@(P/08",#S&`@`^Q@(````````````!1D(````````
M`````````0````$````!``````#_`$#S&`@`"!D(``$"`P0%!@<("0H+#`T.
M#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[
M/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8$%"0T1%1D=(
M24I+3$U.3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25
MEI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_04%!
M05Q;7$-%145%24E)241.3T]/3UW7V%5555E9WM]!04%!7%M<0T5%145)24E)
M1$Y/3T]/7??8555565G>_P`$&0@``QD(``(9"```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````$9"```&0@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````F0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````):7````D9*"`).4A`"&AY4```"%````````````B0``````
M````BYL`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(@`````
M``````````````````````"8````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MC)P```````````````"*F@````````````````````````````"?`````(Z>
M`````````````````````````(,`````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````$"`P0%
M!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R
M,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?
M8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G\`````````````````
M`````````````````````````*"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BY
MNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7F
MY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P```0`"``,`!``%``8`!P`(``D`
M"@`+``P`#0`.``\`$``1`!(`$P`4`!4`%@`7`!@`&0`:`!L`'``=`!X`'P`@
M`"$`(@`C`"0`)0`F`"<`*``I`"H`*P`L`"T`+@`O`#``,0`R`#,`-``U`#8`
M-P`X`#D`.@`[`#P`/0`^`#\`0`!!`$(`0P!$`$4`1@!'`$@`20!*`$L`3`!-
M`$X`3P!0`%$`4@!3`%0`50!6`%<`6`!9`%H`6P!<`%T`7@!?`&``80!B`&,`
M9`!E`&8`9P!H`&D`:@!K`&P`;0!N`&\`<`!Q`'(`<P!T`'4`=@!W`'@`>0!Z
M`'L`?`!]`'X`?P"L(```&B"2`1X@)B`@("$@Q@(P(&`!.2!2`0``?0$`````
M&"`9(!P@'2`B(!,@%"#<`B(A80$Z(%,!``!^`7@!H`"A`*(`HP"D`*4`I@"G
M`*@`J0"J`*L`K`"M`*X`KP"P`+$`L@"S`+0`M0"V`+<`N`"Y`+H`NP"\`+T`
MO@"_`,``P0#"`,,`Q`#%`,8`QP#(`,D`R@#+`,P`S0#.`,\`T`#1`-(`TP#4
M`-4`U@#7`-@`V0#:`-L`W`#=`-X`WP#@`.$`X@#C`.0`Y0#F`.<`Z`#I`.H`
MZP#L`.T`[@#O`/``\0#R`/,`]`#U`/8`]P#X`/D`^@#[`/P`_0#^`/\``0``
M`&:U&`@!````RK48"`$```#6M1@(`0```..U&`@!````[+48"`@```#\M1@(
M#P````VV&`@0````*;88"`,```!$MA@(!````%JV&`@1````<K88"`$```"/
MMA@(`0```*:V&`@.````O;88"`$```#8MA@("@```.^V&`@!````"K<8"`L`
M```AMQ@(`0```#RW&`@,````5;<8"`D```!RMQ@(!@```-"W&`@"````C;<8
M"`4```#PMQ@(!P```!2X&`@-````-+@8"!(```!4N!@($P```'RX&`@4````
MH+@8"!4```#$N!@(`````````````````````,"%!P@D<P<(F','"*1R!PCT
M@`<(?'\'",QT!PB@@@<(Z'4'"```````````````````````````````````
M``"X@P<(`````*B'!PA,@@<(9(('"&R"!PB`@@<(6(('"#1U!PAH=0<(1'0'
M"&1T!PB$=`<(J'0'",QU!PA\?0<(3'X'"#2"!PA0=@<(T'<'""AY!PA4>P<(
M-'T'"/2%!PC,@0<(`````````````````````````````````````#\`````
M`````````#$```#`MQ@(P+<8"/2;&`@`````X`H9".`)&0C@"1D(````````
M``````````````````````````````$````!`````0``````_P!@"1D((`D9
M"``````@A@<(;(8'"*2)!PCT@`<(1(@'")"'!PADB@<(^(<'"```````````
M`````````````````````````````````````*B'!PA,@@<(9(('"&R"!PB`
M@@<(6(('"+2'!PC4AP<(@(<'"("'!PB(AP<(B(<'",QU!PA\?0<(3'X'"#2"
M!PA0=@<(T'<'""AY!PA4>P<(-'T'"/2%!PC,@0<(````````````````````
M```````````````````!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?
M("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,
M34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY
M>GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6F
MIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3
MU-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O\`
M("`@("`@("`@*"@H*"@@("`@("`@("`@("`@("`@("!($!`0$!`0$!`0$!`0
M$!`0A(2$A(2$A(2$A!`0$!`0$!"!@8&!@8$!`0$!`0$!`0$!`0$!`0$!`0$!
M`1`0$!`0$(*"@H*"@@("`@("`@("`@("`@("`@("`@("$!`0$"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````0A@<(J(8'"/2&!P@$B@<(](`'"$2(!PB0AP<(
M9(H'"/B'!P@`````````````````````````````````````5```````````
M````$0```$"Y&`A%N1@(])L8"``````@#QD((`X9""`-&0@`````````````
M`````````````````````````0````$````"``````#_`*`,&0B`*B4(````
M`/"4!P@HE0<(<%P("+A<"`@XEP<(@(('"%B"!PBLE@<(/)4'",Q6"`@H5P@(
MA%<("-17"`C,=0<(?'T'"$Q^!P@T@@<(4'8'"-!W!P@H>0<(5'L'"#1]!PCT
MA0<(S($'"````````````````````````````````````````0(#!`4&!P@)
M"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V
M-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@04)#
M1$5&1TA)2DM,34Y/4%%24U155E=865I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0
MD9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]
MOK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;GZ.GJ
MZ^SM[N_P\?+S]/7V]_CY^OO\_?[_``$"`P0%!@<("0H+#`T.#Q`1$A,4%187
M&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!A8F-D
M969G:&EJ:VQM;F]P<7)S='5V=WAY>EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q
M<G-T=79W>'EZ>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>
MGZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+
MS,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X
M^?K[_/W^_P`@("`@("`@("`H*"@H*"`@("`@("`@("`@("`@("`@($@0$!`0
M$!`0$!`0$!`0$!"$A(2$A(2$A(2$$!`0$!`0$(&!@8&!@0$!`0$!`0$!`0$!
M`0$!`0$!`0$!$!`0$!`0@H*"@H*"`@("`@("`@("`@("`@("`@("`@(0$!`0
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````$``````````````&$```!`N1@(
M3KD8"/2;&`@`````(`\9""`.&0@@#1D(X!`9"```````````````````````
M``````````$````!`````@``````_P"@#!D(H!`9"`````!`BP<(9(P'".B-
M!PCDDP<(R%@(""18"`A@70@(Z'4'"```````````````````````````````
M`````````0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G
M*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-4
M55976%E:7%U;7E]%04)#1$5&1TA)2DM,34Y/4%%24U155E=865I[?'U9?X"!
M@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VN
MK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;
MW-W>W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_2J%7H0``6:%;
MH5^A8*%CH62A9Z%HH6NA;*%OH7"A<Z%TH7>A>*%[H7RA``````````#&H<>A
MRJ'+H<BAR:%<H4VA``!/H0``4:%2H5.A5*$``'VA?J&AH:*AHZ&DH<RAS:'.
MH=ZAWZ'@H>&AXJ$`````3*)-HDZB````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$FA``"MH4.B2**NH0``7:%>H:^ASZ%!H="A1*%!HJ^BL**QHK*BLZ*T
MHK6BMJ*WHKBB1Z%&H=6AUZ'6H4BA2:+/HM"BT:+2HM.BU*+5HM:BUZ+8HMFB
MVJ+;HMRBW:+>HM^BX*+AHN*BXZ+DHN6BYJ+GHNBB``!"H@````#$H0``Z:+J
MHNNB[*+MHNZB[Z+PHO&B\J+SHO2B]:+VHO>B^*+YHOJB^Z+\HOVB_J)`HT&C
M0J-#HV&A5:%BH0```````````````$ZA````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````,ZB2LG\W?BJ`````$38>-REZ';S`````/FJ``"LK7NP
M`````$78``!&V*RS``!]MGK<>=RCMGRV>]Q^MJ*VH;9[M@```````&BY````
M`-#@SN```,_@S>```-*[``#5N]>[UKL`````T[O4NP``I^BFZ%N^J.@``*GH
M7+X```````!-[$OL\^X``$GL2NQ&P$;L3NQ([$SL[^X`````\>X``/+N\\'N
M[O+!\.[OP?#!\<%'[`````#UPF[Q;/%M\?/"]L+TP@```````'?S>//VPP``
M1?5']4;UQ,10Q6WV;/9K]@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/JJ``"JR0``6,KI
MIE;*6<I7R@```````*[+``#!J```PJBPR[^HK\NMR\"HOJ@`````````````
M``#8S=O-_:K:S=G-``#\JONJ``!`J]S-_JH`````````````QM"NK:^ML*W'
MT,/0K:W$T```Q=#"T````````*2P`````*&P1=2BL*6P1M0``'ZP?+!]L*.P
M`````````````*VS2=BULTC8``!+V+&S2MBKMJ^SLK.NL[.SM+.PLP``````
M`$?8I[9]W```H]P`````HMRLMJBVJ;9\W'[<H=RDMJ:V``"JMJ6V`````-/@
MT>#2X&JY:[D``-3@:;G8NP``VKO9NP``N^0`````O.2KZ```JN@`````1\!(
MP$_L2<```/;N``#T[@``]>[TP0``;_'WPP```````/7!0:L``*:P1]0`````
M3-BVLZVVI-RFW*^VKK:PMK&VI=QNN6^Y;;G;NVRYU>````````#<NZSH4.Q*
MP/;!</%T\?G"<?'ZPOC"=?'[PG/Q``!Y\_?"^,,``,WX`````$*KN+.WLP``
M````````LK:HW*?<L[8`````V>!SN7"YV.!RN=;@<;D``-?@``"]Y-V[``"O
MZ```7;ZMZ%Z^7[ZNZ&"^``!1[```3L!+P%#`4^Q,P%+L3\``````3<```/GN
M^^X`````]\'Z[OC!^.[W[@``=_%V\?S">/%^\_K#??-Z\_G#>_-\\P``2/5)
M]<7$``!3Q0````!N]@````!1Q5+%;_8`````M,6UQ7'W`````$7&S_A'Q@``
MSOC0^$;&5_D``*WY````````````````0ZL```````!TN0``ON0``+#H4<!2
MP```1*L``&&^^\.QK0```````%/```#BQ;*M3=@``*G<``"KW```JMP``-W@
MVN!UN0``=KG;X-S@``#`Y,7DWKN_Y,'DR.3#Y,?DQ.3"Y,;DW[L`````L^@`
M`+'H8[X``&*^LNADO@``````````5NP`````5>Q4P%3L_.X``/[N0>]`[P``
M^<'][J'Q_<)]\:+Q_L(``'OQ``!^\7SQ>?%`PWKQ``````````"A\P````"C
M\Z+S``!*]0``2_4```````!P]@``M\4``+;%3_A0^$C&T?@``&G&``"SK;2V
MRN3)Y+7HM.@`````^L%#[T+OI?&C\:;QI/$`````_,.D\Z7SIO,``''V``!R
M]P``TO@``````````````````+2M`````%?L1.\``+6M`````."[``!8[$'#
MI_']PP``3/5-]53%4?BVK;NSO+-.V+6VMK:LW+>V``!ZN0``?+G?X.#@WN!W
MN7BY>[EYN0````#+Y.&[XKL`````O.AGOK?HMN@``+OH9;X`````6\```+CH
MO>BZZ+GH``!FO@``6<```%KL5<```%OL`````%GL``!8P%;`6L```%?`````
M`````````$7O``!*[T;O2>_[P0``U.U([T?O``!$PT+#1<-#PZCQJ?&J\4;#
M````````JO-`Q*CS``!!Q*?SJ?/^PU'U3O4``$_U4/5R]E;%``!5Q0``=/=S
M][C%````````X\5)QF#&6/FN^:_Y````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````MZVMW`````#AX,SD
MS>3CNP``Y+N^Z&B^`````/S!``"K\0``1\.M\T+$K/.N\ZOS=?92]5/U``#&
MQ```=/8`````<_8``'7WL/D`````````````````````````````````````
MN*T```````"YK0````"GL$C4``!/V```N+8``+NVN;:NW```O;8``+JV````
M`+RV``!^N0``XN``````X^#`Z```?;FAN:*Y``#/Y```SN3ENP``YKL``-#D
MO^CHNVF^``#GNP```````%S`P>AKOFJ^PNC%Z,/HQ.ALO@``8<!?P`````!>
MP%WL``!@P`````!<[$OO``!>[%W`7^Q.[TSO3>]2[TO#4>]4[U/O4.]/[P``
M_<$``````````*[Q``"M\4K#2,-)PP``K/$``+'S``!#Q```L/.O\T3$``!8
M]5?U``!5]0``5/7(Q,?$6?5V][G%=_97Q7;V5O4``'?WY,4``&'&6?D``+'Y
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"ZK5#85>^[K0````#2Y-'D8.P`````5^\``%;O``!,
MP[+SL_/)Q`````"R^:BPO[:^MN3@YN"DN>7@H[FEN>?@````````U.36Y-7D
M``#8Y````````.F[U^33Y````````-GD``#,Z```S^C1Z,?HR^C(Z&Z^<;YS
MOLGHRNAROLWHT.C.Z'2^``!POL;H;;X``&^^`````&/`9NQD[&/L``!I[```
M:.QG[```8NQBP&'L``!E[&3``````%KO``!>[UOO7>]<[UGO7^]B[V#O8>]`
MP@``_L%8[V/OL_&V\;CQM_$``+'QM?&P\0``LO%-PZ_Q``"T\0````#`\[7S
M1<0`````1L2T\[GSO_.W\[[S``"[\P``NO.]\[CSMO,``+SS``!@]5[URL1=
M]6/U8?4``,O$7/5:]0``6_7-Q%_US,1B]7CV?O8`````>?9;Q:'V6L5]]GSV
M6<5[]EC%>O8``'WWH?=^]P``>_>[Q7CW?/>C]P``HO=Y]WKWNL52^.?%``!3
M^.7%YL4`````T_A*QG;Y``!JQ@``L_EKQK3YM?G#^<+Y>L;-^0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````*FP`````.G@``#HX```ZKOKN]KD``#2
MZ&SL`````'6^9<!J[```;>QFP```9.]K[+GQ3L/!\P```````&;U9/4`````
M9?4`````HO8``%S%I/?JQ;S%Z,7IQ=3X8L8``*JP````````NO$`````2=0`
M`*:Y``#;Y`````#LN]SD````````U.C3Z&C`=KYWO@``U^C6Z-7H`````&[L
M<>P``'#L;^QGP&CO9N]E[P````!G[P``3\.\\;WQ4,,``+OQ``##\\+SQ?-'
MQ,3S``!G]6GU:/4`````H_:F]J3VI?:E][W%````````5/A5^%;X``!+QF/&
MMOFKL```>+YIP+[Q``"F]P````#$^4K4``![QJRP<NP``+_Q``#&\P````"G
M]J?WK;```-WDWN0``.V[[KO9Z'J^>;[8Z```:>\``,#QPO'!\5/#4L-1PP``
M7L6H]@``7<6I]ZCW``!,QM7XO;/JX````````.'DW^3@Y`````#BZ```W>C:
MZ.'H````````X^@`````?+[@Z-SH`````-OHW^C>Z'N^`````'WL>.QV[*'L
M=^P``'/L``!Y[`````!T['+O=>RB[```````````````````?.QJP'OL>NP`
M`'[L``````````!J[VWO`````&SO``!T[V_O<^\``''O<.]N[P``:^\``$/"
M0L(``$3"0<)U[P````````````#(\<OQ``#)\<WQ````````SO$``,;Q6,/'
M\0``Q?',\0``Q/'#\5?#5<-4PP````````````````````#*\<_SU?-*Q-#S
M``#3\]?S2\32\P``RO,``,GSUO/-\P``R_/4\\SS2<1(Q```Q_/(\]'S````
M````SO,```````````````!L]6_U``````````!6PP``````````````````
M;?5S]7'U:_5V]0``:O4``,_$<O4```````!N]<[$=?4`````=/4`````````
M`*OVJO8```````"Q]@``K?:P]F#%`````*[VK_8``*GVK/9?Q0```````+_%
MM/>O][/W``"V][+W``"N]P``P<6Q][7WP,6L]W#UL/<`````K?<``*KW``"K
M][[%6OA<^%_X6_A@^```6?@``%?X``#KQ5WX[<7LQ5CX7O@``````````-KX
M3<;;^```V?C6^`````#8^-?X6OD``````````%SY6_D`````>?D``'CY=_EZ
M^0``<\9TQLKYSOD`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````+ZS
MK]SMX```I[GKX`````#LX````````.+DX^3QN^^[Y.3PN^CH``#KZ.7H[.CD
MZ.;H``#GZ.KH`````*&^[^CNZ'V^Z>CMZ'Z^````````````````K.P``&_`
M``"G[&O```"D[*KLK>P``'#```"I[*;LKNRE[```J^QLP```H^QMP```;L"H
M[````````*GO>N][[W[O?.\``';O`````'GOI>]][P````!%P@``I^^D[T;"
MIN]W[Z+OH^\``*'O``````````#2\=3QU_$`````T?$``%G#V?'0\=KQ``#6
M\=CQW/'5\=WQT_'/\5K#``#;\5O#3<0`````````````>._Q\^CS3\3D\U#$
M`````.WSY_/=\T[$ZO/E\^;S``#8\]_S[O,``.OS``#C\P``[_/>\]GS[/,`
M`-OSZ?/@\_#SW/-,Q-KSX?/B\P```````'WU``![]0``HO4``*[UI?5\]7CU
MI_5^]:/U>O6J]7?UH?6F]:CUJ_5Y]0``K_6P]:GUK?6D]0``P?;$]@``8<4`
M`,/VR/;&]F+%O?:S]K+V9,6_]L#VO/:T]@``N?:L]0``M?9CQ;OV``"Z]@``
MMO;"]@``M_:[]\7VQ_:^]KCVO/>^][CWPL4``,7WP_?#Q<+WP?>Z][?WO??&
M][GWO_<``&GX;OAD^&?X[L5K^```<OC`]P``9?AO^'/X:OAC^&WX``!L^''X
M</C$]VCX8OAF^$[&3\9A^```YOC=^.7XXOCC^-SXW_CG^.'XX/C>^```Y/@`
M`%WY``!>^0``8/E?^6+Y8?E\^7OYM_D``+CY``#%^7C&?,8``,_Y?<8`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````O[,```````#0Q,GV
M``!0QE'&``#`L^[@``"HN?#H`````+#LL>RO[*OOJN]'PM_QK._>\0````#S
M\U'$4\3R\P````!2Q```L?6S];+URO9EQ0``[\7H^&/Y`````-+YP;,``.7D
M``"BO@```````+/LLNP``*WO````````5,31Q,?WR_D```````#"L_*[``"C
MO@``]/,``'3XP+8``````````*[O````````9,;!MJ2^2,)U^,*V``#QZ'+`
MM.RU[```<<```*_O3,)*PDO"2<+@\5S#````````M?6T];?UMO72Q`````#+
M]@``S?;,]F;%R/<``';X=_CPQ63Y??EUQ@``L-RV[+#O]?/OX```L>_B\>'Q
M``````````!X^%+&``!E^7[Y````````J;GRZ//H``"W[*JY``!=P^/Q``#/
M]F?%T/;.]GGX``#I^```J[D``+3OL^^R[^3Q`````.CQY_'F\>7Q7L/V\[GU
MT\2X]='VR_?*]\3%R?=\^'OX>O@`````\[L``+CL3<(``/?S^//,]WWX````
M`.KX9OFY^=3Y]+M.PNGQ^?/2]G[X`````*:^``"U[^KQ^O/[\_SSOO4``+KU
M:,6]];SUU,2[]=;$``#5Q-3VT_9IQ6K%`````,;%S??%Q0``H_BD^*+XH?A4
MQ@``Z_CL^.WX4\9G^6KY:?EH^0````#3^0``````````````````````````
M``````````!SP`````!EP[_UU?8``,?%SO<`````U?D```````!TP```````
M`+;O``#/]P``H?D`````0*1"I```0Z0```````!%R5:D5*17I%6D1LFCI$_)
M3<FBI*&D`````$*E0:5`I0``0Z7^I```````````X*7AI0``````````````
M`,.H``````````!8I```I*10R0``I:1CR>JFL<L``````````%FDIJ0``$2E
M9,D`````````````0,E$I```6Z0``$?)7*0`````IZ0``$6E1Z5&I0````#B
MI>.E`````,2H``"\K4&D`````$')1:1>I%VD````````````````````````
MY*4```````````````````````#%J```````````````````````````KK!+
MU`````##MK'<LMP``$:D``"II`````#&J$>D2,E?I`````"JI*RD4<FMI*ND
M````````Y:4``,>H`````,BH1:L``&"DKJ0``.:EZ*7GI0``ZZ8`````R:C*
MJ$:K1ZL``````````+VM`````+/<`````-;V2*0`````````````L*2OI%+)
ML:2WI```LJ2SI%3)4\FUI+:D``"TI````````````````$JE2Z5,I4VE2:50
MI6K)``!FR6G)4:5AI0``:,D``$ZE3Z5(I0````!ER6?)````````````````
M]:6PR?*E]J6ZR:[)\Z6RR0```````/2E``#WI0``Z:6QR?BEM<D``+G)MLD`
M````L\GJI>RE^:4``.ZEJ\GQI>^E\*6[R;C)K\GMI0````"LR>NE````````
MM,D``````````+?)````````````````````````K<EFR@``0J?TI@````!G
MRO&F``!$IP``^:8``/BF6\K\IO>F8,IHR@``9,H``/JF`````/VF[J9'IUW*
M`````+W+[*9#I^VF]:;VIF+*7LK[IO.F6LKOIF7*1:=(I_*F0*=&I_"F8\I!
MIVG*7,K^IE_*`````&'*``#8J+_+R\O0J```S,O+J-6H`````,ZHN<O6J+C+
MO,O#R\'+WJC9J+/+M<O;J,^HMLO"R\G+U*B[R[3+TZBWR]>HNLL``-*H``#-
MJ```W*C$R]VHR,L``,;+RLO:J+[+LLL``,#+T:C%R\RHQ\L`````````````
M``````````````````````````!6JTJK`````.#-Z,T``$FK4:M=JP``[LWL
MS>?-````````2ZOMS>/-6:M0JUBKWLT``.K-``#AS52KXLT``-W-6ZM.JU>K
M3:L``-_-Y,T``.O-5:M2J^;-6JOIS>7-3ZM<JU.K3*M(JP``````````````
M````````````[\T``->MP:T``-&M``#6K=#0S]#4T-70Q*T``,VM````````
MVJT``,ZM``````````#)T,>MRM```-RM``#3K;ZMOZW=T+^P``#,K<NMR]#/
MK5O4QJW6T-6MU*W*K<[0U]```,C0R:W8T-*MS-#`K0``PZW"K=G0T*W%K=FM
MVZW3T-BM``#;T,W0W-```-'0``#:T```TM```````````,BM````````8]17
MU```L[```%S48M2RL%74MK!9U%+4M+!6U+FPOK```&?4``!1U```NK```&;4
M`````+6P6-2QL%/43]1=U%#43M1:U&#48=2WL`````!;V%[43=1?U```P;!D
MU,"P3-0``%349=2\L+NPN+"]L`````"OL`````"PL`````#(LP``7MA7V```
MQ;,``%_8````````5=A8V,2S6=@`````Q[-=V```4]A2V,FS``#*L\:SR[-1
MV%S86MA4V````````,.S5M@`````````````````````RK;$MK?<S;:]W,#<
MQK;'MKK<Q;;#W,NVQ-P``+_<S+8``+3<R;:UW```OMR\W```N-S(MK;<SK:[
MW,+<N=S!W`````"VN;.Y``"TN0``^>#QX+*YK[GRX`````"QN?7@``#WX```
M``#^X`````#]X/C@KKGPX*RY\^"WN?;@``#ZX+"YK;G\X/O@M;D``/3@``#X
MN^SD``#IY/F[``#WNP``\.3MY.;D]KL``/J[Y^3UN_V[ZN3KY/N[_+OQY.[D
M[^0```````"JOOCHI[[UZ*F^J[X``/;HJ+X``/?H``#TZ`````!VP+WL=\"[
M[```O.RZ[+GL`````+[L=<``````N.^Y[P``Z.2W[WC`7\/K\>SQ``#7Q-C$
MP?7`]6S%:\70]P``2:1AI+FD``"XI%.E4J7\I?NE_:7ZI0``2J=)ITNG````
M``````#@J```WZCAJ```7JL``%FBWM!:HL*P7*);HF#8``!=HKBY7J(``$JD
M``"ZI/ZEXJ@``$NDO:2[I+RD`````$"F````````3*?DJ..HY:@```````#=
MK0```````*R^````````````````3LD``%2E5:4`````0:8``&K*``!@JU^K
MX-#?T,.P``"^I%7)`````````````,W+``!AJP``X*T``-ZMWZT`````````
M`*V^``!6I0```````$*FO,D``````````$VG3J<``&O*`````,[+YJC/RP``
M``````````#BT./0XZT``.30``#AT.2MXJWAK>70``!HU````````&'8````
M`,7<0.$```````#^NZZ^^>@``$RD6J0`````````````````````````````
M````````Q+#-LP``N;D``$+)OZ0``%FE5Z58I0````#GJ`````!-I$ZD``!B
MI`````#`I,&DPJ2^R5JE``!KR0``1J8``+_)1*9%IKW)`````$>F0Z8`````
M`````&S*[*IMR@````!NR@````!0IT^G`````%.G4:=2IP```````.VH``#L
MJ-3+T<O2RP``T,ONJ.JHZ:@``.NHZ*@`````````````[Z@``&.K\,T``-/+
M:*L``/'-9*MGJV:K9:MBJP```````.C0``#GK>O0Y:T```````#GT.BMYJWI
MK>G0ZM```.;0[-````````````````#1L\6P:=1KU&K4;-3&L`````#.LP``
MS[/0LP``T+;'W```QMS(W,G<T;8``,^V0>%"X;NYNKE:XP````!`O$&\0KQ$
MO/+D\^1#O````````*^^``"PO@````#M\</UPO71]P``3Z0```````!<I5NE
M`````$BF`````,#)`````%6G5J=4IU>G;\IPR@``````````````````````
M`````````/&HU<L``/"H``#RS6RK\\UKJP```````&FK``!JJP```````.W0
M``````````#'L&[4``#*L&W4Y;')L,BP``#4LP``T[/2L]*V`````-6VUK;4
MM@``T[8`````0^$``$3A````````]>1%O/3D``"QOK_L><```.[Q5<0``&.D
MPZ16R0``Q*3%I`````````````!=I5ZE``!)IG'*ULO7RP``;:ONT,RPR[!C
MV&+8`````%"DQJ1?I0``S;!#R0``;,E@I0``PLE+IDJFP<E8IP``````````
M`````.JM`````&_4``#7MD7AO+D`````^N@`````_?,``,>D`````-C+],W0
ML,ZPS[!1I```9*3-HLJD``#)I,BD8Z5BI0``;<G#R0```````/6H\JCTJ/.H
M`````&ZK`````-6S``!2I```RZ0``&6E9*4``'+*`````/:H````````````
M`%?)``!GI6:E3*9-IG/*6:<``%JG``#WJ/BH^:@``&^K]<T`````ZZT`````
M1,D``,RD`````````````,3)````````=,IUR@````#9RP``VLL``/?-]LWY
MS?C-<*L``'#4[:WOT.RM``````````!DV-:S``!EV```````````1N&]N0``
M````````1KP``._Q``````````!8R0``:*4``````````````````-&P````
M``````!3I&6DSJ3-I```SZ0```````````````#[J```^JC\J````````'&K
M````````[JT``/OH3\)FI&JE>:5TI0``;Z5NI76E<Z5LI7JE;:5II7BE=Z5V
MI6NE``!RI0````!QI0````![I7"E``````````!3I@``6:95I@``6Z;%R5BF
M3J91IE2F4*97IEJF3Z92IE:F7*8`````````````?LI[R@``9Z=\RENG7:=U
MIW"G````````I<I]RE^G8:>DRFBG>,ITIW:G7*=MIP``=LISIP``9*<``&ZG
M;Z=WRFRG:J<``&NG<:>AREZG``!RIZ/*9J=CIP``>LIBIZ;*9:<``&FG````
M````8*>BR@``````````><H`````````````````````````````Z\OJRT^I
M[<OOR^3+Y\ONRU"I`````.'+Y<L`````Z<M)SDNI3<[]J.;+_JA,J46I0:D`
M`.++1*E)J5*IX\O<RT.IW<O?RP``1JD``$BIV\O@RP````!1J4VIZ,M3J0``
M2JG>RT>I`````$*I0*D``.S+``!.J0````````````!(SOO-2\X`````_<UX
MJZBK=*NGJWVKI*MRJ_S-0\ZCJT_.I:L``'FK`````$7.0LYWJP``^LVFJTK.
M?*M,SJFK<ZM^JWNK0,ZAJT;.1\YZJZ*K=JL``````````'6K_LT`````````
M``````!$S@``````````````````3LX``$31^ZWQT```]M#TK4"N]-#OK?FM
M_JW[T```^JW]K0````#^T/6M]=````````!"T4/1``#WK4'1\ZU#K@``^-``
M`/&M``!&T?G0_=#VK4*N^M#\K4#11]&AU```1=%$KO"M_-#ST```^*T`````
M\M``````]]``````````````````````````````\-!!K@````!WU```Y+"G
MU.*PW[!\U-NPHM3FL';4>]1ZU/*MX;"EU```J-1SU```Z+,``*G4Y[```-FP
MUK!^U-.P``"FU```VK"JU```=-2DU-VP==1XU'W4`````-ZPW+#HL```````
M````X[```->PTK$``-BP>=3EL."PH]35L````````-2P````````````````
M``````````!QU'+4:M@```````#7L]JS==CNLWC8V+-QV-ZSY+.]M0````#B
MLV[8[[/;L^.S=MC7W'O8;]@``&;8<]AMV.&S>=@`````W;/QL^JS``#?L]RS
M``#GLP``>MALV'+8=-AHV'?8V;-GV```X+/PL^RS:=CFLP````#ML^FSY;,`
M`'#8`````````````.NS````````U=S1W```X-S*W-/<Y;;FMMZVW-SHML_<
MSMS,W-[<W+;8W,W<W[;6W-JVTMS9W-O<`````-_<X[;+W-VVT-P``-BV``#D
MMMK<X+;AMN>VV[9?HMFVU-P`````````````XK8`````W=P```````#-N<BY
M``!5X5'A``!+X<*YOKE4X;^Y3N%0X0``4^$``,2Y``#+N<6Y`````$GAQKG'
MN4SAS+D``$KA3^'#N4CAR;G!N0```````,"Y3>%2X0``RKD`````````````
M`````$?A``!-O$?E``!$Y0``1[Q3O%2\``!*O$+E3+SYY%*\``!&Y4F\2.5(
MO```0^5%Y4N\0>7ZY/?D`````&O8_>0``/;D_.3[Y```^.0``$^\````````
M``!.O````````%"\_N2ROD#E````````1>D``/WH``"^OD+IMKZZOD'I``"Y
MOK6^N+ZSOKV^0^G^Z+R^_.B[OD3I0.E1O```O[Y&Z;>^M+X``````````,;L
MR.Q[P,GLQ^S%[,3L?<##['[```````````#![,+L>L"AP'S``````,#L``!0
MP@``O.^Z[[_OO>\``+OOON\``````````````````&##\O'S\5;$``#T\?#Q
M]?'Q\5'"````````_O-!]%G$0/18Q%?$``````````!:Q,7UQO4``-K$V<3;
MQ,3U``#8]M?V``!MQ6_%;L79]LC%IO@```````#QQ0``I?CN^`````!)R0``
M``!]I7RE``!?IEZFQ\E=IL;)`````'FGJ<H``*C*`````'>G>J<`````I\H`
M`'BG````````````````\,L``/'+5*D``````````*JK``!(T4G11:Y&K@``
M``"LU.FPZ["KU.JP?-CRLP``````````Z;;JMN'<``#/N0``SKD``$GE2.E'
MZ0``:_EGI%G)``!NR6_)``````````!BIF:FR<D``&2F8Z;(R66F8:8`````
M8*;*R0```````````````*:G`````*.G``!]IZK*````````J\H``*&G``"M
MRGNGKLJLRGZGHJ>EIZ2G?*>OR@``````````````````````````````````
M``!9J?[+``!;J0``6JD``$#,6*E7J?7+``#TRP``\LOWR_;+\\O\R_W+^LOX
MRU:I````````^\M<J4',`````/G+``"KJU6I``````````````````"LJU3.
M`````%K.````````LJM8SE[.``!5SEG.6\Y=SE?.``!6SE'.4LZMJP``KZNN
MJU/.7,X`````````````````````L:L```````````````!0SE/1``!2T5?1
M3M$``%'14-$``%31``!8T4>N2JX`````3]%5T0```````$FN2M$``+"KNM16
MT0``3=$``$BN3-$```````````````"QU`````#LL/"PP=2OU+W4\;"_U```
MQ=0``,G4`````,#4M-2\U```RM3(U+[4N=2RU*;8L-3UL+?4]K#RL*W4P]2U
MU`````"SU,;4\[```,S4[;#OL+O4MM1+KNZPN-3'U,O4PM0``,34````````
MKM0``````````*'8``"JV*G8^K.BV```^[/YLP``I-CVLZC8``"CV*78?=CT
MLP``LMBQV*[8\[/WL_BS2]&KV/6S]+"MV'[8L-BOV```L]@``._<``"LV```
M``````````````````"GV.?<]+;WMO*VYMSJW.7<``#LMO:VXMSPMNG<``#N
MMNVV[-SOMN[<``#KW.NV````````];;PW.3<[=P`````X]P`````\;8``/.V
M``#HW```\=P`````7>'0N6/A`````-6Y7^%FX5?AU[G1N5SA5;Q;X63ATKD`
M`-:Y6N%@X67A5N'4N5[A`````&+A:.%8X6'A``#3N6?A````````6>$`````
M``!9O$OE5[Q6O$WE4N4``$[E``!1Y5R\``"EOEN\``!*Y5#E``!:O$_E``!,
MY0``6+P```````````````!-Z0``3^E*Z<&^3.D``,"^3ND`````P[Y0Z<*^
M2>E+Z0``````````I<#,[```I,#-[*/`R^RBP,KL``!3PE+"]O'X\0``]_%A
MPV+#`````&/#0O1;Q`````#3]]+W\L4``&BDT*0`````IZ<``````````%_.
M``````````#\L_VS``#RW-BY:>%3Y0```````%K)`````+#*````````````
M`$+,8,Y9T4RN`````/GQ``#<Q&FD?J5PR0``9Z9HI@``7:D```````#WL```
MVKD``-NYV;D``&JD``#1I-.DTJ1;R=2DH:5QR0``HJ4`````````````::9J
MI@```````,O)``"HIP``L<H```````!AJ4/,``!?J6"I7JE:T0```````+:K
MM:NWJ[2K``!ASF*ILZL``$VN3JX``$^N``#-U````````/ZSM-CXL```````
M````^+8``-VYW+EJX0``7;S$O@``P._:]M3W:Z2CI0``I*71R6RF;Z8``,_)
MS<ENIM#)TLG,R7&F<*9MIFNFSLD``````````+.G`````+"GMLJYRKC*``"J
MI[*G`````*^GM<JSRJZG````````J:>LIP``M,J[RK?*K:>QI[2GLLJZRJNG
M`````````````&>I;ZD``$_,2,QPJ5/,1,Q+S`````!FJ47,9*E,S%#,8ZD`
M`%',2LP``$W,``!RJ6FI5,Q2S```;JELJ4G,:ZE'S$;,:JEHJ7&I;:EEJ0``
M3LP``+FK``#`JV_.N*MGSF/.``!SSF+.``"[JVS.OJO!JP``O*MPSK^K``!6
MKG;.9,X`````9LYMSG'.=<YRSFO.;LX`````:,[#JVK.:<YTSKJK9<["JP``
MO:L`````````````7*YBT0``6ZX`````8-$``%"N``!5K@``7]%<T6'14:Y;
MT0``5*Y2K@``8]%3KE>N`````%BN``!:K@```````%FN````````7=%>T0``
M````````9-$``-34^;#"V-/4YM0`````0+$``.34``#^L/JP[=3=U.#4``!#
ML>K4XM3[L$2Q``#GU.74`````-;4Z]3?U-K4``#0U.S4W-3/U```0K'AU.[4
MWM32U-?4SM0``$&Q``#;U-C4_+#1U```Z=3]L```V=35U`````#HU```````
M`````````$"TN]@``+C8R=B]V,K8``!"M````````,;8P]@`````````````
MQ-C'V,O8``#CU,W81]T``$.TSMBVV,#8``#%V`````!!M$2TS-C/V+K8M]@`
M````N=@`````OMB\V$6T``#(V`````"_V```P=BUV/K<^-Q"MT"W0]WYW$3=
M0-WWW$;=]MS]W/ZV_;;\MOO<0=WYMD&W``#TW```_MSSW/S<^K9"W?7<^[9%
MW0``````````````````;N'BN>&YX[EZX7#A=N%KX7GA>.%\X77AWKETX>2Y
M``!MX=^Y``![X>"Y;^%RX7?A<>%LX0``````````<^%5Y6&\6.57Y5KE7.4`
M`%^\``!6Y0``5.4``%WE6^59Y0``7^4``%[E8[Q>O```8+QBO`````!@Y5?I
M`````%;I5>D``%CI4>D``%+I6NE3Z0``Q;Y<Z0``6^E4Z0``T>RHP,_LU.S3
M[%GI``"GP```TNS.[-;LU>RFP```T.P``,:^````````5,(```````#![_KQ
M^_'\\5S$`````%W$``!#]```R/7']0````#;]MSVU?>G^```;*1MI```;J35
MI*6ET\ERIG.F``"WI[BGMJ>UIP``<ZD`````5<QUJ72I5LP```````#$JP``
M7:YET0``\-0``$6Q1[3OU$:T``#EN0``?>''O@``J<#7[```7L0``'#%``!R
MR0``IJ5SR7:F``!TIG6F=Z8``+JGN:<``+S*NZ<`````O<I7S```6,P``':I
M>*EZJ7>I>ZEYJ0````````````#(J\6KQZO)J\:K9M%WS@```````&C19]%C
MK@``7ZX`````8*YBKF2N8:X``&:N9:X`````````````2K'RU/'42;$``$BQ
M1[%+L4:Q`````-78TMA)M-'8UM@``$NTU-A(M$JTT]@``$C=``!)W4K=````
M``````#FN>ZY?N'HN>RYH>'MN>FYZKGGN>NY9KS0V&>\9;P``&2\7>G(OMCL
MV>P`````9,-?Q```;Z0``'BF````````````````RJL``&G19ZX`````3K%-
ML4RQ3+1-M-?8[[G)OG"D7,G6I'3)`````-3)>:8```````!\J0``````````
M2]T`````<:0``->DU<D`````OLH``+_*``"\IP```````-C83K0``$S=````
M````JL!RI*BDV*1UR:>E``#`I[^GO:>^IP````!9S'ZIH:E:S'VI`````,ZK
M>,[-J\NKS*MJKFBN`````&O1::YJT0``7J[SU`````!0L5&Q`````$^Q``#P
MN:+A:+QIO```8>6KP,+OP^\``-W$J/A+R=FD``!SI```=\EVR0``````````
M>J;7R=C)ULD``-G)``````````````````#'R@``PLK$RL;*P\K$I\#*``#!
MRL&GPJ?%RLC*PZ?)R@``````````````````:,P``&+,7<RCJ67,8\Q<S&G,
M;,QGS&#,I:EFS*:I8<QDS%O,7\QKS*>I``"HJ0``7LQJS**II*D`````````
M`````````````````````````*O.I,ZJSJ/.I<Y]SGO.``"LSJG.><X``-"K
MI\ZHS@``ILY\SGK.SZNBSG[.`````*'.K<X`````````````````````;ZX`
M`&ZN``!LT6NN;M$``'"N;]$`````<ZX``'&N<-&NSG+1``!MK@``;*X``&W1
M<=%RK@``````````4[%2L0```````/74^=3[U%2Q_M0``%BQ0=4``%JQ``!6
ML5ZQ``!;L??45;$``/;4]-1#U?C4``!7L4+57+']U/S47;'ZU%FQ````````
M``!$U0``0-7GV.[8X]A1M-_8[]C9V.S8ZMCDV```[=CFV```WMCPV-S8Z=C:
MV```\=@``%*T``#KV$_=W=A/M```X=@``%"TX-CEV`````#BV````````.C8
M``````````!3W0```````%;=3MT``%#=``!5W53=0[<``-O84MT`````1+<`
M`$W=4=T``````````*GA``"PX:?A``"NX:7AK>&QX:3AJ.&CX0``\;D``*;A
M\KFLX:OAJN$`````K^$``````````&7E9^5KO&CE``!CY0``8N5LY0``:N5J
MO&WE9.5IY6OE9N4``````````&'I9NE@Z67I``!>Z6CI9.EIZ6/I7^EGZ0``
M:NEBZ0``VNROP```K<```*S`KL``````Q.\``'+Q_?$`````1/1%]```8,0`
M`,GU``#>Q```RO4``-[V<L4``''%W?;)Q0``UO<``````````'2D>Z;:R<K*
MM:A?L0````!UI*JEJ:6HI0````#%IP````!TK@``5]UVI'>D>*3:I`````#1
MJP``K\X```````!3M'FD7<D`````JZ6LI7C)``!\I@```````,O*``#&IP``
MS,H`````KJD`````;LRLJ:NI;<RIJ6_,JJFMJ0``TJL``-2KL\ZPSK'.LLZT
MSM.K`````'31<]$``':N``!UK@````````````!BL4;5``!AL6.Q8+$`````
M`````%6T1=4``%:T\]@``%>T\MA4M```````````6MU<W46W6]U9W5C=````
M````M.'WN?6Y``#VN;+AL^$``/.Y<>5OY0``;;QPY6Z\;+STN0````!MZ6OI
M;.ENY=SLL,#;[,7OQN]NZ?[Q``!ZI*VE?J;;R7VF``"OJ4:W``#;I*ZEU:M8
MM```><D``'K)``#<R0````#(I]#*SLK)I\W*S\K1R@``QZ<`````````````
MLZFTJ;&I`````+"IN,ZRJ0```````-:K``"WSKG.MLZZSM>K>:YUT0``=]%W
MKGC1>*YVT0``M<Y'U4K52]5(U6>Q9K%DL66Q2=4``````````&BQ`````%JT
M6[0``%RT7=U?W6'=2+='MUFT8-U>W0``N.$`````MN&\X?BYO>&ZX?FYM^&U
MX;OA<+QSY;GA<KQTY7&\=+QUY6^\<[P``'/I<>EPZ7+I;^D`````9L,``$;T
M1_0``,OUW_95Q@````"UJ<JG`````-BK````````>Z3<I```KZ7=R0``RZ?2
MR@``N\[9JP``^KE\I````````*&F`````$FW?:3=I-ZD``"QI;"E``#>R:*F
M``#3R@``S*<`````<<QRS'/,``"VJ;>I<,RXJ0```````-JKO,X``'K1>JX`
M`'G1``!IL4S5:K%-U0```````%VT````````8MT`````O^&^X0``^[D``'6\
M=N7*OG3IL<```'/%V/<``````````'3,``"]SFNQ]-A*MP```````%7"````
M``````#.IP``S:?;JP``>]$``&VQ0[-NL6RQ7K0``,#A_+EVO```3,G?R0``
MU<K/I]3*T*<`````O*EWS';,NZFYJ;JI=<P`````W:N^SN"KW*OBJ]ZKWZOA
MJP```````'VN?*Y[K@```````$_5;[%RL7"Q``!.U76Q``!QL5#5=+%SL0``
M`````/;8]=@``&&T7[1@M/?82[=DW4RW8]T`````=^4`````>+S!X7>\``#]
MN0``WNQUZ;+`W>Q`\DCT2?0``-^D``"RI0```````'O)`````-*GU*<``.+)
MV,K7RM;*``#AR>#)I*;3I]&GHZ8```````"]J7C,``"^J=W*``#?RM[*><P`
M````VLH``-BGUJ<``-G*V\KAR@``U:<``-S*Y<K`J0``XLK7IP``X,KCR@``
MOZD``,&IY,H`````````````````````K\RBS'[,KLRIS.>KPJFJS*W,XZNL
MS,.IR*G&J:/,``!\S*7,S:FPS.2KILP``.6KR:FHS```S<[FJWO,RJGHJ\NI
MQZG,J:?,>LRKS,2I`````'W,I,RAS,6I``"_S@``P,X```````````````#*
MSJ'1R\[NJ\[.Q,[MJ\;.``#'S@````#)SNFK`````*.N`````,7.P<ZDK@``
M``#/SGZN?='(S@``?-'#SLS.`````.RKH:[RJZ*NT,Y^T>NKIJ[QJ_"K[ZNE
MKM'.IZ[JJP``PLX```````````````````````````````!VL:31IM$``*C1
MJ*ZNKE/5K-&CT7BQ4=4``*VNJZZNT0``4M4``*71``"LKJG1KZZKT0````"J
MKJK1K=&GT0``J:YYL0``HM%WL0``````````>K$``````````````````%75
M7M5DM```?+&CL66T8-6JL?G85M6BL:6Q?K%4U6+59=5)V0``8]7]V*&QJ+&L
ML5W5^-AAU7NQ^MADU?S86=4``&*T``!7U5C5I[$`````IK%;U:NQ7]6DL5S5
M``"IL6:T8[3[V```6M4``'VQ````````````````````````:[1OM$#94;=M
MM$39<;1EW4;94[=IM&RT1]D``$C93MESM%2W``!*V4_90]E>MP``5;=RM$'9
M4-D``%VW<+1.MTW9``!TM$79_MAJM$+9``!+V0``3;=2MV>T3-D``%"W````
M````:+0```````!<M\/A<-T``&C=PN$``&S=;MT`````:]T``%NW``!JW5^W
M````````TN$`````6K=`NG'=Q.$`````6+=IW6W=_KE/MV;=9]U!NE>W6;=6
MMV_=`````,CAR>'.X7V\U>$``$>Z``!&NM#A``!\O,7A1;H``-3A0[I$N@``
MT>&JY7J\;K0``-/AH[S+X0``>[P``**\QN'*X<?AS>%(NGF\0KH``'KES^$`
M`*&\``"DO```S.$``'Z\>>4`````````````?N7.OGCEH^FIY:B\``"FO,R^
MIN6BY:R\``!XZ0```````*J\H>4``';I``"EY0``J.5]Y0``J[P`````I;QW
MZ<V^I^6GO*F\I.6MO*/E?.5[Y<N^J^5ZZ>#LT+X``*+I``!^Z0``X>P``-&^
MH>D``'SIM,#?[```>>E[Z;7`T[ZSP-*^M\!]Z<^^````````````````````
M`,_O``#'[P````````````#G[,COX^P`````5L+E[.3LML#B[.;LT._,[\[O
M``#)[\KO``#-[\OO9\,`````:L-IPVC#8<1*]&+$0?+?Q,SUX,1TQ<K%V?<`
M`-KWV_<`````NOG@I'S)LZ4``*:FIZ:EI@``J*;:I]FG``"QS,^ISJD`````
MK]&ML:ZQ````````=;1RW6"W8;=TW7;===T``-?A``#6X4FZV.$``*SEKKP`
M`-2^``"XP%?"N<```.&D````````YLH`````LLS1J="ITJGSJ]+.T\X`````
ML-&PKJ^Q=K11V>*D``!^I..D``!]R;>EMJ6TI;6E````````JZ;IR>O)JJ;C
MR0``Y,D``.K)YLGHR:FFY<GLR>?)````````````````X:?JI^BG\,KMRO7*
MYJ?VR@``WZ?SR@``Y:?ORN[*XZ?TRN2GTZG>I_'*``#GRMNG``#NI^S*\LK@
MI^*G``#HR@``Z<KJR@``[:?GI^RGZ\KKI]VGW*?IIP``````````````````
M`````````````````````.&IOLRWS-RI[ZFSS+K,O,R_S.JI``"[S+3,Z*FX
MS```P,S9J0``O<SCJ>*IMLS7J0````#8J0``UJD``.ZIYJG@J=2IN<S?J=6I
MYZGPJ=3.Y*FUS-JIW:G>J0``[*GMJ>NIY:GIJ=NI]*L`````````````````
M````````````````````VLY!K/BK^JM`K.;._:NQT;&N0ZS7SM_._JO>SMO.
MX\[ESO>K^ZM"K+.NX,[YJT6LV<X```````#\J[*N]JL``-;.W<[5SMC.W,ZR
MT42L``#ASN+.Y,[UJP``````````````````````````````````````````
M``#!KK[1OZ[`KK31Q-$``+:N`````&;5QM'`T0``M]$``,G1NM&\KGW5O=&^
MKK6N``#+T;_1N*ZXT;71MM&YKL71S-&[KKS1N]'#KL*NM*ZZKKVNR-$`````
MPM&WKK/1RM'!T</1Q]$``````````````````````````&?5``"WL<NQRK$`
M`+^Q``!YU775<M6FU;JQLK$`````=]6HM+:QH=4``,RQR;%[U6K5`````,BQ
MH]5IU;VQP;&BU0``<]7"L;RQ:-4``'BTI=5QU<>Q=-6DU<:Q``!2V0``L[%O
MU;BQP[$``+ZQ>-5NU6S5?M6PL<2QM+%WM'S5M;$``+&QP+&[L;FQ<-7%L6W5
M>M5VU5394]D`````````````````````````````:]5DV0``>K0``&K96=EG
MV7?=?;1KV6[9?+1<V6W9;-E^M%79>;2CM```H;1IV0``7]FEM'#9:-EQV:VT
MJ[1FV679``!CV5W9I+0``**TN=%6V0``M]U7V7NTJK1YW0``IK2GM%C9;]EX
MW6#96]FIM&'97MD`````KK0```````````````````````````````!PMP``
M``!\W;'=MMVJW6RWN]UIMWK=``![W6*W:[>DW6ZW;[>EW0``LMVXW6JW``!D
MMZ/=?=VZW:C=J=U^W;3=J]VUW:W=``!EM]GA:+=FM[G=L-VLW0````"AW5.Z
MK]UMMZ?=``"FW0```````&>W8[?NX;/=KMT``*+=``````````````````#I
MX0``VN'EX0``[.%1NJRTZN%,N@```````$NZ\>$``-OAZ.'<X>?A3[KKX6+9
M````````\N'CX5*ZNN6OO```\.'OX52ZK>6PO*[E``#?X>#AW>'BX=[A\^%.
MNK&\4+I5N@``X>$``.WA`````.;A`````+'E``!*NK2\JNFVY;7EM^4`````
MM.6UO```N[RXO```N;ROY;+EO.7!O+^\``"SY5K9LKRYY;#E``#"O+CE3;JW
MO.3A`````+J\``"^O,"\O;R\O```MKR[Y;.\P[P``````````````````-B^
MV;ZIZ>*^W[X``-:^W;ZKZ=N^U;X``-R^``"HZ;O`U[X``-Z^NL"GZ:;I``#@
MO@``X;X``*7II.F\P*[IVKZLZ0``````````O<```,+`ZNSL[```O\```.WL
MZ>P``.OLP,##P```Z.R^P,'`6<*MZ5C"`````%["U.\``%S"7<+7[]/O6L+1
M[VO#U>\``-;OTN\``%O"0O(``$7R`````$;R1/)'\FS#0_(`````3O1DQ$WT
M3/1+]&/$9<0``,WUXL3AQ`````#A]N#VX_;+Q77%W??B]@````#<]\W%S,7S
MQ:GX[_CDI`````!RV:_I`````*RF]\KQI^^G``#PIP``P<SQJ4:L``#GS@``
MZ,X``$>LSM$``,2NQ:[-T0``````````T[$``,^Q``"GU=:QU;'.L=&QU+'0
ML0````!VV<VQK[0```````"QM+*T==EXV;"T<]EWV0``=-D``'&W`````+S=
M`````%:Z].'COL2\O>7%O,:\O^6^Y<#EL>D`````L.GO[.[LQ,#%P$CR````
M`.6D``````````!YV0```````+2TL[2]W0``V._CQ-[WYJ0``,:N``#8L=>Q
M>ME[V7*W]>%7NK+I``#GI+BE``#RJ<+,``#ISDBLV;$``'S9M;1SMP``P>7"
MY0````#P[%_"\/CHI```P\SSJ4FL``#JS@``QZ[2T=#1T='(KL_1````````
M``#;L=RQJ-7=L=JQ?=D``'[9OMT`````6;I8N@````#Q[-GO``!*\DGR3_0`
M`%[)2JP`````Z:2YI0``KJ:MI@````"OIK"F[LGMR?C*\J?[ROK*^<K\R@``
M````````]*G)S,7,SLP`````^ZD``/FIRLS&S,W,^*E`JLC,Q,S^J<O,]ZG,
MS/JI_*G0S,_,Q\SVJ?6I_:D```````````````#OSO7.``!0K$VL[,[QS@``
M4ZQ+K/#.3JQ1K`````#SS@``3*SXSD^L``!2K.W.\L[VSN[.Z\X`````]\[T
MS@```````````````-"NR:[,K@``SZX``-71``#*KM/1``#.K@````#+K@``
MUM'-K@```````````````*S5W[&KU:W5WK'CL=31``"JU:[5``#@L:G5XK$`
M`.&Q``"GV0``HMD``+:TNK2WM*79J-D``+BT``"YM+ZTQ]VFV;RTH]FAV0``
MO;0``*39````````>;<``+_==K=WMW6WQ-W#W<#=>[<`````PMV[M`````#&
MW<'=>+=TMWJWQ=T```````!<N@``^.'WX?;A6KH`````````````6[K%Y<CE
MR+P`````Q[S)Y<3ERKS&Y0``R;S#Y0``Q^7ION:^N^FZZ0``N>FTZ0``M>D`
M``````#GO@``Y+[HOK/IY;ZVZ;?IO.D`````N.D`````\NP```````#'P```
MW._&P-KOV^]@PF[#2_(``&W#`````%'T4O0``&;$``!0].3$``#?]\[%JOBK
M^```ZJ0``+&FLJ;SIP``T<Q4K-&NY+$`````TK```+^TP+3,LZG9``!\M_KA
M^>$`````ZZ2SIM+,0JH``$&J``#YSOK.``#7T=C1TJ[3K@``U*ZOU0````#F
ML0``PK0``,&TR-UZW_OAO>D`````8<)GQ.RD``"\I;VENZ6^I;JE`````+:F
M``#VR;6FMZ8`````\<GPR?/)\LGUR;2F[\GTR0````````````#]ROVG_LI#
MR_RG``!'RT++1<OUI_:G]Z?XIP``0*@``$'+^J=!J```0,M&RP``^:=$R_NG
M]*?^IP```````````````````````%>J``#4S$.J``!-JDZJ1JI8JDBJW,Q3
MJM?,2:KFS.?,W\S8S%:JY,Q1JD^J``#ES```X\S;S-/,VLQ*J@``4*H``$2J
MWLS=S-7,``!2JN',ULQ5JNC,1:H``$RJV<SBS%2J``!'JDNJ``#@S```````
M``````````````````````````````!;SURL::P``%;/3,]BK$K/6ZQ%SV6L
M4L_^SD'/``````````!$S_O.4<]ASV"L1L]8SP``_<Y?SV#/8\]:STO/4\]F
MK%FL8:QMK%:L6*P```````!#SVJL8ZQ=ST#/;*QGK$G/`````&NL4,](SV2L
M7,]4SP``7JQBST?/6JQ9ST_/7ZQ5SU>L_,YHK..N7:Q.STW/0L\``%[/``!7
MSP````!5K````````````````````````````````````````````````.S1
MZJ[MT0``X='?KNNN``#:T0``X]'KT0``V='TT=6N````````\]'NT0``[]'=
MKNBNY=$``.;1\-'GT0``XM'<T=W1ZM'DT0````#6KMJN\M'>T>:NXJX`````
MY:[LKMNNYZ[IT>FNV*X``->NV]$``-_1X*[QT>C1X-'DKN&N``#9KMRN````
M``````````````````````````````````````````````````````#$U0``
MM-6UU;G5``#(U<75``"^U;W5[;'!U=#5L-4``-'5P]75U<G5[+''U>>Q_+'R
ML0``]K'UL;'5``#.U=35S-73U0````#`U;+5TM7"U>JQ][$``,O5\+$`````
M``#*U;/5^+$``/JQS=7[L>FQNM7/U0````#OL?FQO-7&U;?5N]7TL;;5Z+'Q
ML>ZQO]7>KL#9Z[$`````````````````````````````````````\[$``,/9
MV=G.V=:T``#1M+W9TK3-V0``QMG3V<ZTJ]G5V<2TL]G'M,:T``#7M```K=G/
MV=#9R;3%M+O9``#0M+;9``#1V<RTR=G6V;#9M=FOV0``R[3"V=[=L=G/M+K9
MTMG*M+?9M-G%V<VTP[39M,C9Q]D```````````````"LV<BTU-F\V;[9``#+
MV<K9JMG3M-6TLMFYV<'9U+2XV<39U]D``,S9````````````````````````
M``````````#8V0``````````KMD``````````/+=IK<``/#=V]W@W=G=``#L
MW<O=TMT``.K=]-W<W0``S]WBW>?=T]T``.3=T-T`````U]W8W:BWZ]WIW0``
MS-WNW0``[]WQW:RWI+<``+C5U-WFW=7=H;>QM^W=K[>KM\K=H[<``,W=L+<`
M`-W=R=T``*FWX=W1W:JWVMU^M]BTX]V_V<[=`````.C=I;?EW:*WW]VMM];=
M\]T```````````````"GM\;>`````*ZW````````````````2N)(X@``7N)&
MX@``6.)]MU^Z0N)=X@``1^)5XF2Z7;H``%OB``!`XEKB``!ONE'B8>)MNDGB
M7KI+XEGB9[I$XFNZ8;I-XD/B_.$``%?B:+I@XOWA9;H``%/B``!FND7B4.),
MXD[B``!@NE_B;KI/X@``8N(`````_N%4XF.Z;+IJND'B5N)IN@````!BNE+B
M``````````!<X@````````````````````#5Y0``T>7-Y>'EWN7-O`````#E
MY=3EV+S;Y0````#0Y=KEU;SNY0``Z^7=Y<[E`````.+EY.71O-CET^7*Y<Z\
MUKP``.?EU[S+Y>WEX.7FY=2\`````./E``#JY0``V;P``-.\W.7/Y>_ES.7H
MY="\``#6Y0``U^7/O,R\TN72O```R[P``.GE[.79Y<KI````````````````
M````````PND``+[I]KX`````Z[[PONR^S.G7Z>J^Q.G-Z=_ESND`````\;X`
M`-WI];[XOL#I``#TO@``V^G<Z=+IT>G)Z0````#3Z=KIV>D``.^^[;[+Z<CI
M``#%Z=CI][[6Z?.^\KX``-#I``"_Z<'IP^G5Z<_I[KX``,;I``#4Z0``````
M`````````,?I``````````````````#/P$7MR,#U[```0>W*P$CM``#\[```
M]^P`````2>WS[/[L``#1P$3M2NW][,G`0.WT[-#``````$?M^>S,P```^^SX
M[-+`^NS+P,[`0^WV[$;M``!"[0```````&/"Y^]HPFG"````````8L+F[P``
MX^_D[V;"WN_B[V7"``#?[P``````````9\)DP@``W>_A[^7O````````4?).
M\E?R``!6\E3R3_(``'+#`````````````%#R<</-P%/R<,-8\E+R3?+@[P``
M`````&_#``!,\E;T``!5]%7R:,0``%GT6O14]%CT``!3]```````````T?57
M].?$Y<3/]0```````-+U``#.]=#UYL0```````#E]N;V=L7D]@```````.+W
MS\7@]^'WK/@`````5L;S^/'X\OCT^````````+OY``#MI+BF``!9J@``Z<P`
M````9,\```````#UT??1``#VT0``^-']L=?5^=$``-;5V-79U=K9V[3;V=W9
MW+3:M-S9``#ZW?C=]]T``/;=]=VRM_G=<+ICXF7B<;IDXMN\``#:O/#E````
M`-_IWNG@Z0````#YO@``2^W3P```Z.]JPEGR=\7NI+^EN:9"J%JJ6ZH`````
M;JP`````^M$``````````+.W````````T>;ZOFO"[Z0``+JF`````.O,7*KJ
MS```9<]OK&;/``!PK```_-'NKNVN``#>U=S5W=7;U0``VM4`````WMGAV=ZT
MW]G=M.#9``#[W0````!FXF?B:.(``//E\N7<O/'E].7AZ0````#BZ>/I``!,
M[=3`;,):\@``Z,1?R0``<:QGS^^N`````/ZQ``#?M.+9``"UM[2W`````&GB
M:N+=O-Z\Y>GDZ>GOX_?PI&#)P*4``$.H2,L``'*LMK?QI```:,]SK&G/``#5
MP/*D`````.S,``!JSP``0M)!TO[1``#]T4/20-(`````0+)!L@````#@M./9
M``#DV>79````````0=Y"WD#>``#]W?[=M[=KXO?E]N7UY?CEY^GFZ?N^Z.D`
M`-;`3>T``.KO6_+G]@``\Z3"I<&E``!=JF')?LF[I@``]\E)RTK+7JH``.W,
M``!TK&O/;,\``/"N]*Y$TO.N\:[RK@``W]5"LN.T``#AM.*TYMD`````<KKT
MI```H<D``,.E`````*3)`````,:EH\G%I<2E1*BBR0````#XR0```````/S)
M_LE`RL6FQJ;[R<&F``#YR0``_<G"I@``O:8``+ZF``#$IOK)O*9%J+^FP*;#
MI@```````%O+6<M,RU&H4\M,J$W+``!5RP``4LM/J%'+5JA:RUBH``!:J```
M2\L``$VH7,L``%2H5Z@``$7-1ZA>J%6H3LM*J%FH5LM(J$FH0\U/RU"H6ZA=
MRU#+3J@``%.H[LQ<J%?+4J@``%VH1JA4RTNH6,M$S0``````````````````
M````````````````:JIZJO7,<:H``$O-8JH``&6J0LT``//,]\QMJF^J^LQV
MJFBJ9JIGJG6J1\UPJOG,^\QNJG.J_,Q*S0``=:QYJ@``8ZI)S0``3<WXS$_-
M0,ULJO3,:ZI]JG*J``#RS'7/>*I\JD'-1LT``'ZJ=ZIIJE^J``!DJ@``]LQ@
MJD[-``#PS._,_<SQS'NJ]:YTJO[,8:H``*:L````````3,T`````````````
M``!\SZ'/``"DSW?/`````*?/JL^LSW3/=JQ[K$G2K:RESZW/>\]SSP``````
M`&32?JRBSWC/>L^EK```?<]]K'#/J,\``*O/`````'JL``"HK&W/JJQXK*ZL
MJ<]OSZNL7M)(S7RL=ZQVSV[/K*RDK*//J:RGK'G/H:QQSZ*LHZQRSZ;/>:Q^
MSP```````````````````````````````````````````````````````$S2
M_:Y#KP```````%726])7TDK23=)&TD?22J_ZKE;27])%K_:N``!`KT[20J]/
MTEG2````````1*]HTDC2_*[[KDBO1=)FTEK29])ATE/28M(``%S29=)CTDFO
M5-+YKOBN0:]'KV#21J]1TD.R``!ITE#22]+^KDNO]ZX``%C27=(`````````
M````````````````````````````````````9;+AU>75``!2LE"R`````$>R
MX]7BU5NR``#HU56R``#ZU4?61++WU?#59[+@U0``_-4``&2R6+)CLDZR[-7^
MU?;53[))LD76``#]U4#64;)9LD+6ZM7[U>_51-9>LD:R7++TU?+5\]53LN[5
M[=5(LN?51M9*LO'5:+(``&*RYM5?LEVR9K+XU6&R4M+YU6"R0=9%LO755[+I
MU5:R``!4LDRR2[+GV4/6`````.O5`````/S9``!-L@``````````````````
M````````````````````````````````0;5:LNZT]MG\M```ZMGKM.>T2=KM
MM/&T[+3UM$W:1-H`````\=GZM/2T_=GDM$K:0]KHM/?9][15VE;:``#EM$C:
M^;3[V>W9[MG]M/+9^=GSV0``^[1$M>_9Z-GIV0``Z]GJM/C9``#XM$*U````
M`/K94]I+VN:T4=KRM```\+0``%?:[[1!VO39_ME'M47:0MKPV4.U3]I,VE3:
MZ;1`VD:U``!'V@````#SM/:T``!&VD6U]=GDU0````!0VD[:4MH`````````
M````````````````````````````[-E`M0```````&'>8-Y&WKVW``!?WDG>
M2MX``,>W:-["MU[>``!#WLBWOK=2WDC>2]YCWKBW:MYBWL&W5][,MP````#+
MM\6W`````&G>N;=5WDS>6=YEWLVW``"[MU3>``!-WL2W``##MU#>6MYDWD?>
M4=Z\MUO>R;?`MT[>O[=%WE/>9][^M+"Z5MYLXEC>9M[&MT_>NK?*M_"\1-X`
M`%W>````````7-X`````````````````````````````````````JN*MNGWB
MI.*BN@``;N*ON@``=[IMXK#BL;IQXJ/B``!SXK/BK^)UNJ&Z4^:NNGVZ;^(`
M`*[BH[JKXKCB=>)^X@````"VXJSB?+H`````?.)VNG2ZJ+H`````>N)WXGCB
M``"RX@``M^*UXGJZN>)^NJ>Z``!PXOKE>>(``'BZK+JINGNZI>)TXJJZI^*D
MNJ:Z<[H``*GBH>)RXJ6ZL>*TXGOBJ.(``'FZW[RFXOGE``"MX@``````````
M````````````````=N)$YD[FXKQ-YEGFY+Q+Y@``3^;OO```1N;GO```4N;P
MZ?.\\KQ4YD/F7N;MO```X[Q7Y@``6^9@YE7F2>;FO.F\\;SLO```3.:BX@``
M``!(YE_FZ+P``.N\8>;@O%;F^^5<YM_```!*Y@``X;Q%YN6\_.6KND'F``!:
MYD+F0.;JO```6.8``/[E4>90YEWF1^;NO````````````````//I``!)O_Z^
M0.KKZ4&_]^E(OT._]>E/[?OI0NKZZ>GI^.E$ZD;J_;Y%ZD2_2K\``$>_``#^
MZ4:_^>D``.WI\ND``/WI1;]"O_R^0+_QZ0``_>7LZ>_I0>KTZ>KI3NU#ZN[I
M_.D``````````%'MX\``````U\``````V\!3[5GM5^W9P-K`X<!:[5+MW,``
M`%;M5>U;[>+```#=P.#`5.WDP-[`Y<#8P%CM``!0[0````#W[P````!QPO3O
M]N\``&_"\N_S[^[O`````/;I[^]PPNOO``!MPOCO;L+L[^WO\>]SP@``<L(`
M````\.]XPU_R9?)YPUSR=L-SPV?R=\,``'3#7O)A\F+R8_)F\@``]>]=\G7#
M9/)H\F#R````````7?1JQ&#T:\1H]%_T7/0``%[T8O1E]&3T9_1;]```:<1C
M]&;T:?1A]-/UU/78]=GU``#6]=?UU?4``.G$``````````!XQ>OV`````.CV
MZ?;J]GG%``#E]^3W``"O^/3%K?BP^*[X]?A7QF7&H_EL^0``HOG0^='Y]:0`
M`````````,>F0<H`````7LL``%^H``!BJ```7\L``&"H8:@``````````%C-
M6LU5S5+-5,T```````"DJ@```````**J`````%;-HZI3S5#-H:I7S0``4<VE
MJEG-``````````"OSP``L\\`````MZP``````````+;/``"OK+*LM*RVK+.L
MLL^QSP``L:RTS[7/``"NS[6L``"PK````````+#/````````````````=])X
MTGG24*\``$RO;M(``';2>])1KP``;-)RTFO2==(`````<=)-KT^O>M(``&K2
M;=)ST@``=-)\TG#2``!.KP``````````````````````````;;).U@````!0
MUDS6``!8UDK65]9ILDC66]I2UFRR``!3UE;6``!:U@``3]8``%36`````&JR
M:[)9UDW62=9;U@``4=8`````5=8```````!+U@``2+5)M67:3[4``%G:8MI8
MVDRU8-I>V@``7]I*M0``8]H`````````````7-I:VDNU7=IAV@```````$VU
M````````9-H```````````````!PWG?>>=ZAW@``VK=KW@``TK<``'K>U[>B
MWLZW``!]W@``;=Y^WFS>``#<MP``>-[/MZ/>``#4MW'>V;=\WF_>=MYRWF[>
MT;?8M]:WT[?;M]"W==X``-6W``!.M0``>]X``'/>`````````````'3>````
M`,'B``"TN@````"]XL/BO^(``+:ZON+"XKKB``"\XK6Z``````````#`XKOB
M``"WN@``LKH`````Q.(``+.Z9^9DYG#F:N9LYO2\9N9NY@````!MYFOF``!Q
MYO>\:.9OY@``];P`````8^9EYO:\8N9RY@``:>8`````2NI1OP````!5ZE/J
M2[])ZDSJ3>I(ZE6_5K]'ZE;J4>I/OTR_4.I.Z@````!2OU+J3;\``$Z_``!/
MZE"_2^H``%3J4[]7ZECJ5+\`````Y\#NP%SM8NT``&#MZL#IP.;`7NT`````
M``#LP.O`Z,```&'M7>U?[0``[<````````!WPOOO``!TPG7"_>]VPOKO``#Y
M[VSR_.\``&WR>L-K\@````!J\@``:?)[PP````!LQ`````!J]&OT````````
M``#<]=OUZL0``-KU[/;M]@````#F]['X`````/;XO/EYQL;Y]J0``*:JIZH`
M````N*P``````````._`]Z0``*BJ4J_=M_BD``!NLKBZ8LD``+?/?=(``,7B
M``#PP/FDJ:JXS[G/9MI0M0````"DW@````#>M\;B`````/B\``!\P_JD9]K[
MI```R:9"RLBF9:ADJ&.H8,L```````"JJ@``JZI;S0``NL\``+W/NJR[SP``
MN:R\S[NL``"BTJ'2?M)3KP``7=9>UF^R7-9?UE*U<+(`````4;5KVFK:``!H
MVFG:``!LVJ;>I=ZIW@``J-ZGWKFZR>(``,CBNKK'XG/F``!TYOF\``!9ZEKJ
M`````'+R?<-Q\G#R;O)O\NO$;/3N]O?X``#\I```I<G'I:;)````````0\I$
MR@``````````9LL`````8LL``&'+K*IERV>H8\MFJ&?+9,L`````7\V^SUW-
M9,T``*VJ``"PJF7-8<T``&+-``!<S:^J7LVNJF/-``!@S0````#"S[VLOJP`
M`,7/O\\``,3/``#`S[RLP\_!SP``````````````````J-*ET@``I])8KU>O
M5:^DTJG25*]6KZ;29]:CTJK2`````````````&+69M8``&76;MIYV@````!H
MU@``8]9MVG2R`````'.R8=9DUG6R``!RLG&R8-9IU@```````'#:=]H``%2U
M=MISV@``5K4```````!UV@````!OVG':=-IRVE6U>-I3M=^W`````*W>K-ZJ
MW@``XK?AMZ[>``"KWLKBN[K@MP```````+#>K]X``,WBR^+ZO```O+K,XG;F
M``````````#[O'7F?N9]YGOF``!ZYG?F>.9YYGSFH>8`````7^I<ZEWJ5[];
MZF'J8.I>Z@``9.UE[?'```#RP&/M``!YPO[O>,)^PP``H<-MQ&[T;?3=]>_V
M>L7H]^?WZ??(I<;/6:]VLFK6R:6GR?VD`````$7*````````;,MJRVO+:,MH
MJ&G+`````````````&W-``"SJFO-9\UJS0``9LVUJFG-``"RJK&J``"TJFS-
M:,T``````````,*LQ:S.S\W/S,^_K-7/R\\``,&LK](``-+/T,_$K```R,_3
MSP``RL_4S]'/R<\``,"LUL_'S\.L``````````"TTJO2MM(``*[2N=*ZTJS2
MN-*UTK/2M])?KP``7:\`````L=(``*W2``"PTKO2LM)>K\_/``!:KURO````
M`````````'C6;=9KU@``;-8``'/6``!TUG#6>[)UUG+6;]8``'FR;M9WLGJR
M<=9YUENO>+)WUG;6?+(`````````````````````?MH```````"AVF"U``"G
MV@````"IVJ+:6K6FVJ7:6[5AM0``8K6HVEBU?=I[VJ/:>MI?M7S:I-JJVEFU
M7K5<M5VU````````5[4``````````.FWM][HM[O>``"QW@``O-X```````"R
MWK/>``"]WKK>N-ZYWK7>M-X``+[>Y;<``+;>``#JM^2WZ[?LMP``Y[?FMP``
M``#.XKZZO;H`````T^(``/R\O[H`````P;K4XN.WP+K0XM+BS^(``-'B````
M````J^8`````JN:GYD"]8NI!O:;F``#^O```J.:EYJ+FJ>:CYJ3F_;P`````
M`````&GM``!FZ@``9>IGZ@``9NU:OP``8^H``%B_``!<OUN_9.IHZ@``6;\`
M`&WM]<!ZPO;`\\!J[6CM``!K[0``;NWTP&SM9^T`````0O!%\'7R0/```&_T
M1O```*+#1/![PD'P0_!'\';R``!T\@``````````H\-S\@```````&[$````
M``````#MQ/'V[,3S]O#V\O;0Q;+XRJ5NS;S2O=)]LK_>7;^DPWO%L_C+I0``
M;\U@H@````#7SP``V,\`````````````OM*_TGZRH;(```````"KV@``PM[!
MWL#>U>(``-;BU^+"N@````"MYJSF`````&GJ7K]?OP``<NUO[7#M<>U)\$CP
M?,)W\M[US*4``,:L``"BLL/>``#-I0``P-*CL@````!CM62U``#.I<^E1LIJ
MJ&FHQZS9SZS:T*71I=*ETZ4```````!KJ&RH;LMMRP````"VJG+-<,UQS0``
M`````````````-K/V\\`````RZS)K```RJS(K```````````8*\`````````
M`&2O8Z_!TF*O8:\``,+2`````*:R>]9ZUJ2RI;(```````!FM66UKMH`````
MK=JGL@````````````#MM\7>[K?$W@```````-CBKN9"O6KJ````````<^T`
M`*;#I<,`````?,74I7/-`````*BRV>+#N@````!ORW#+`````'3-N*JYJ@``
M``"WJ@``````````SZS0K,VLSJP``-S/`````-W/S*P``````````,/2``!H
MKVFO``"KLLG2``!NKVRORM+%TFNO:J]EK\C2Q]+$TFVO``#&TF:O``!GKP``
M``"LLJ'6HM:MLGS6?M:DUJ/6?=8``*FRJK(``+;::[5JM;#::+4``+/:;+6T
MVFVUL=IGM6FUM=H``++:K]H`````````````TMX``,?>\+?SM_*W][?VM]/>
MT=[*WL[>S=[TM]#>S-[4WLO>];?OM_&W``#)W@``````````V^+'NM_BQKK<
MXL6Z``#(WL_>WN(``,BZX.+=XMKB`````+'FM>:WYK/FLN:PYD6]0[U(O4F]
MM.9&O:_F1[W$NK;F1+T```````!LZ@``:^ISZFWJ<NIOZF"_<>H`````8;\`
M`&*_``!PZF[J``````````#XP'3M`````/?`=^UU[7;M`````/G`````````
M3?```*'"3O``````?<)/\'["3/!0\```2O``````I\-X\JC#;\0``$OP<,0`
M``````#NQ-_U``!^Q?3V?<4``.KW]<7VQ0````#,^0````#1K-[/``!NM6^U
MU:7*ID?*``!QRVVH``"ZJ@``TJS3K-2LIM;+TF^O`````*ZRI=8`````N-IQ
MM0``M]IPM0````#5WDJ]N^:XYKGFNN8`````````````>.T``%'P````````
M<?1P]```]?;6I77-<*\```````!RM=;>`````.'B``!+O73J``!2\'+TUZ4`
M````NZK7K-_/V*S6K```U:S,TG&O`````'*O<Z\```````"PLJ?6K[(`````
M````````N=JQLG.UU][XM_FW``#)N@``RKI,O62_=>ICOP``>>WZP```4_!S
M]-BE;JAXS7?-O*IVS;VJ><T``.7/VZS:K.?/YL_?K```WJP`````V:P``.'/
MXL_CSP``X*S@S]RLY,_=K```````````S]+3TM'2T-(``-32````````U=+6
MTL[2``#-T@``=:]VKP``U]+2T@``L-8``-C2=Z]TKP```````*K6``"IU@``
MJ]:LUJ[6K=:RUK6RLK*VLJC6M[*QUK2RK]:SL@````````````"\VK[:NMJ[
MV@````"_VL':PMJ]VL#:=+4`````V]X``.#>V-[<W@````#AWMW>^K=#N```
M_;?9WMK>SKI&N/ZW``!$N/RWW]Y%N-[>0;C[MT*XXM[FXNCB````````````
M````````````0+@`````X^+,NNGBS;KGXN+BY>+JXLNZY.(``$Z]O^:^Y@``
M4;U/O;SF3;V]Y@``4+T```````!]Z@``H>H``'[J=NIZZGGJ=^IFOV>_9;]X
MZGOJ?.H``&B_``!`P:/M``#\P'OM_L!!P0````#]P*+M?.W[P*'M>NU^[7WM
M`````%7PI,*EPJ+"``"CP@````!4\```>_(`````J<,``'GR>O(``'3T=_1U
M]';TX/4`````[\3K][3X``#WQ?CX^?AFQMFEX:P``,/:``#CW@``VJ5OJ```
MOJH``.C/Z<]XKP````#$VG6U1[A"P:3M?/)X]-NE````````H<UZS7S-?LU]
MS7O-OZH``````````.*L\L\``.W/ZL\`````\<\`````Y*SEK/#/[\_NS^O/
M[,_SS^.L`````````````````````'RO``"DKZ.OX=+;TMG2``"AK[G6>J_>
MTN+2Y-+@TMK2HJ_?TMW2>:_ETJ6OX])]K]S2``!^KWNO````````````````
M``````````"YL@``NM8`````L]:UUK?6``"XUK;6NK(``+O6``"TU@``````
M`````````````````,C:=K70V@``Q=H``-':``#&VL?:`````,_:SMK+VKBR
M=[7)VLS:>+7-VLK:``````````````````#NW@``\MY.N```\.)1N/#>````
M`.W>Z-[JWNO>Y-X``$VX`````$RX``!(N.?>``!/N```4+CFWNG>\=Y*N$NX
M[][EW@```````/+BT+KTXNS>]N+4NO?B\^(``-&Z[^+3NNSB\>+UXN[B````
M`$FX``#KXM*Z[>(`````````````5+W!YEB]``!6O0````#/N@``R.;)YE.]
M`````,?FRN95O5*]P^;`YL7FPN99O<3F`````,;F5[T``````````&J_J.H`
M`*+JINJLZJWJJ>JJZJ?J``"DZ@``;+]IOZ/JI>H``&N_J^H``$;!`````*KM
MI>U%P0````!#P0``K.U$P:CMJ>VF[:WM5O```$?!I^T``*[MJ^T```````!:
M\`````!7\```IL(``%OP7?!<\%CP6?``````H_(``*K#``!^\J+R??*D\@``
M``"A\@``>O1]]'GT<<1[]'ST?O1RQ'3$<\3A]0``X_4``.+U````````]O8`
M````M?CZ^-RE`````'++P*JCS<&JPJJBS0``^,_WS^:LZ:SHK.>L],_VS_7/
M`````.C2IZ_LTNO2ZM+FTJ:OJJ^MKP````"NK^?2Z=*LKZNOJ:^HK\+6``#`
MUKS6N[(``+W6O+*^UK_6P=8``+VR`````-7:``#4VM/:TMH``````````/;>
M4K@``//>]=X``%.X``!4N/3>`````````````$'C``#YXOKB``#7NM6ZUKI#
MXP``0N/^XOWB_.+[XD#C^.(``,OFT.;.Y@```````,WFS.;/Y@``KNH``&V_
M2,&P[0``2<&O[5_P7O"GP@``I?*KPZ'TH<7W]@``M_BV^*C)ZJSKK,/6``!6
MN-VE<JAQJ'"H````````I,T`````Q*K#J@``[JP``/K/_<_[SP``[*SMK```
M``#YS_S/``"UKP```````//2]=+TTK*O[](`````L*^OKP``LZ^QKP``M*_R
MTNW2[M+QTO#2``````````````````#&UL?6Q=8``,36OK(``````````'VU
M``#6VMC:VMI\M0````!ZM0``U]I[M=G:>;4`````0=_WWOK>_MY:N/S>``#[
MWOC>^=Y8N$#?5[@``%RX6[A9N```_=X```````!)XP``2.,`````1.,`````
MV+I'XT;CV;H`````````````7KT``-+F``!?O5N]7;T``%J]7+T```````"O
MZ@``<+^QZK#J``!%XW*_<;]NOV^_`````````````+7M``"S[4K!M.T``+;M
MLNVQ[0````!@\*K"J,*IP@``````````IO*G\JW#``"LPZ/TI/2B]```^/;Y
M]@````#>I4C*<Z@``*7-QJK%JJ;-`````$#0[ZS^S_"L`````+:O^-+VTOS2
MMZ_WTOO2^=+ZT@````#(ULK6``"_L@``R=;`LJ*UH;5^M=O:``````````!$
MWUVX7K@``$/?0M\``````````$KCV[K:NDOC3.,``&&]8+T``+7JT^;5YM3F
MM.JRZK;JL^H``'._````````M^U+P;CMN>T`````J\*LP@``=<0`````T<7?
MI0````````````!!T````````````````/W2N*\`````````````NK.YLP``
M``"DM=W:H[7<V@``````````1=\``-RZ3>/=N@```````````````';$I?0`
M`,NFQZJGS0``\JP``/&L0M!#T`````!`TT+3N:\``$331]-%TP```````$;3
M0]/^TKJO2--!TP``````````T];&LMS6P[(``-76Q[(``,&R``#0UMW6T=;.
MUL6R``#"L@``U-;7UL2RV-;(LMG6S];6UMK6TM;-ULO6`````-O6`````-_:
M``````````#DV@```````.#:YMJGM<S6X=JEM=[:K+7BVJNUX]JMM:BUKK6I
MM0``JK4``*:U``#EV@``````````````````8;A0WP``4]]'WTS?1M]CN```
M2M\```````!(WV*X``!/WT[?2]]-WTG?X;I2WU^X4=\`````````````````
M``````!=XP``Z+I8XP``Y[I.XP``4./@NE7C5.-7X^6Z4N-1XP````#DNM^Z
M4^/BNEGC6^,``%;C3^/CN@````!IO=ZZ`````%SC``````````````````#9
MYF*]``#;Y@``8[T`````9;W>Y@``UN;FNMSF``````````#8Y@``8+AHO0``
M``!DO0``9KUGO0``=K_=YM?F:KT``-KF`````````````,#JN^H`````Q>IT
MO[WJ>+_#ZKKJM^K&ZE'!>;_"ZKCJ=[^\ZGN_N>J^ZGJ_P>K$Z@``````````
MR^W,[;SMP^W![0````!/P<CMO^H``+_M``#)[4[!ONV][<?MQ.W&[0``NNW*
M[4S!``#%[<[MPNU0P4W!P.V[[<WM=;\``````````````````&/P`````&'P
M9_"PPF7P9/"RPFKPL<(``&OP:/"NPFGP8O"OPJW"J_)F\`````!L\`````"H
M\@```````++#L,.J\@``K/*I\K'#KL.OP[/#`````'C$``"J]```J?2G]*;T
MJ/0``'?$><0`````\,0`````Y?7D]0````#Z]@``_/;^]OWV^_8`````H\6B
MQ0````#3Q=+%U,7M]^SW``#[^+CX_/A8Q@``6<9M^0````!^QLRF``"HS0``
M``!%T$;01-``````\ZP``$?02-!)T`````!)TT_3`````$W3NZ]+TP``3--.
MTP```````$K3R;(``-[6R[+@ULJRW]8`````````````Z-JOM0``ZMKGVN'6
M``"PM0````#IV@```````````````%;?``!DN%3?9;A5WV:X````````Z;IA
MXU[C8./JNNNZ7^,`````````````W^8`````X.8``&N]XN;AY@``8:(``,KJ
MR^K'Z@``R.I\OWV_R>H``%?!`````%/!6,%4P5;!4L$``%7!``````````"S
MPL_M``"N\@``K?(``*OT>L1[Q$'WYO4``$#W``#]^*3YS:8`````=*@``*G-
MR*H``/:L3-#TK$K0^:SUK/JL^*Q+T/>LOZ^^KUK3QZ]3TUG3PZ]2TUC35M/"
MK\2O5=.]KU33R*_%K\FOQJ]1TU#35]/`K[ROP:\`````````````\-;IU@``
MM;7HU@``S[+6LM.RV;+8LM2R``#BUN76``#DUM"RYM;OUM&RX];LUNW6TK+J
MUM>RS;+5LN?6S++KU@````#NU@```````/O:\MJRM?G:]MKNVO?:M+7OV@``
MZ]H`````;+CTV@``L;7ZV@``N+6ZM>W:`````+FU\-JSM?C:\=KUV@``\]JV
MM>S:N[7.LK>UO+4`````````````:+A=WU_?8=]EWP``6]]9WVJX``!@WV3?
M7-]8WP``5]\```````!BWUK?7M]KN```:;AFWV>X8]\``'+C````````````
M`.ZZ:N-XO73C\;IXX_>Z9>,`````=>-BXP``=^-FXP``_KK[NG;C<./MNO6Z
M]+H``/.Z^;H``&/C^KIQX_:Z[+ISX^^Z\+KXNFCC9^-DXP``;.-IXVWC_;H`
M`'GC\KINXV_C``!KXP```````/RZ``````````#GYG"]>;UUO>3F``!RO7:]
M\.9LO>CF``!TO0````#KYN;F<[UWO>7F``!QO0``[^9NO>[F[>9ZO7+E;;T`
M`.SFX^8``'N]ZN9OO0``````````````````Z>8``````````**_I[]^O]CJ
MS^K;ZM/JV>JHOZ&_S.K2ZMSJU>K:ZL[J`````-;JH[_4ZJ:_I;_0ZM'JS>K7
MZJ2_WNK=Z@```````-KMUNU?P0``T.U9P6G!W.UAP5W!T^UDP6?!WNU<P=7M
M9<'@[=WMT>U@P5K!:,'8[6/!TNU>P=_M8L%;P=GM9L'7[0````#;[0``````
M`&[P=/"YPG?PM,*UPF_P=O!Q\+K"M\(``&WP``"VPG/P=?"XPG+P</``````
M`````+CRM\.XP[3#``"UPP``M/*R\@``MO*ZP[?RL/*O\K/RL?*VP[7RK/1^
MQ'W$K?0``*_TKO2AQ````````.OUZ/7I]0``Y_7J]?+$[/4``/'$``!"]P``
MU<77Q>[WUL6Y^$#Y0OG^^$'Y;,8`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#.I@``^ZQOTLJO`````-JR_-K]V@```````-_J:L'A[0``
M``"[P@``NO*Y\J+$[?4``$/W^,5)R@````#)JG6H`````$W0`````&#36]-?
MTUW3RZ]>TUS3``#QU@``_MI`VVG?:M]NN&^X:-]KWV??;;@``$"[``!PN'KC
M``!\O?'F?;T``*F_XNK@ZN'JY.WC[>+M````````N_(``+G#O/)$]_G%NOC/
MILNJRJI/T/RL`````$[08M,``,RO\M9ATP```````-RR]=;SUO36V[(``$+;
M0]M!VP``<[AMWVS?;M]RN'&X`````/+F].8``'Z]\^;CZJJ_>?```'CPN\.]
M\KW#O,.P].[U\\30IE#0_:QET\ZO9--CTP``S:\``/O6``#]UO;6]];=LOC6
MWK+\UOG6^M;?L@``OK6_M0``1-L```````!OWW#?``!^XT.[0;M"NWOC?.,`
M`'WC^>8``/KFH;WWYO;F^.;UYJV_Y.JKOZR_YNUKP>7MJ.\``'KP>_"\P@``
MO<)LP;[RO_*Q]*/$T:8``-*F_JS,JL^O4=````````#`M=.F0:U2T%/00*U"
MK=2F``!4T-&O9M/3K]"OTJ\``$'7X+(``$#7_M8``''?`````*'C``"BO0``
MKK_FZN7J``#G[0```````._U`````-6F<\NJS4.M5=```&C3````````U*]G
MT]6O````````0]<`````XK)"UT37``#AL@``````````1MM'VT7;P;4`````
M``!TN```=;@``$6[``"CXZ+C1+L`````````````^^8`````_.8`````````
M`.?J`````'#!;\%MP6[!<<$``'SPO\*^PL#RLO0```````"EQ:3%UJ8`````
M^]$``'>XPK5VN$:[``#7IJG)V*;9I@````"KS7;+``!WRW>H``!TRW:H``!Y
MJ'7+>ZAZJ'C+>*@```````#1JL^JK<T``,ZJ````````TZK5JM*J``"PS:S-
MUJH``-"J?*@``-2JK\T`````KLT``,VJ``````````````````!;T$>M2*U=
MT```5]!:T&/08=```$FM9]!,K6307-!9T`````!)VV+01*UET%;07]!&K4NM
M8-!/K4VM``!8T$JM``!>T$ZM1:UFT````````````````-JO``#CK]BOUJ]J
MT]ZOVZ]LTP````#=KVO3:=-NT^*OX*](VP``;]-MT]>O`````-FOW*\``-^O
M``#AKP``````````````````````````3M?DL@``1=='UP``2-<``%#73-=*
MUP``3==1U^6RZ;)&UP``3]<``.>R``#FLDO72=<``..RZ+(`````````````
M````````R+51VP````!/V\JU``````````!*VZ'?``#)M4[;`````$O;Q;7+
MM5#;Q[5-VT>[QK5,V\RUQ+7#M0````````````!WWW7?``![WP``<]^BWWC?
M``!RWWNXH[A]WP``=M\``'ZX`````'RX?M]YN'BX>=]]N,VU``!\WW3?>KBA
MN**X``````````!,NTB[``!-NZ;C`````*7CI^-*NZ3C2[NJXZGCJ.,``$F[
M`````````````$'G``!$YZB]0^>GO:.]I+VEO4#G_N:FO0``0N?]Y@````#I
MZO/JL;^POP``[>KOZ@``ZNH``.[JZ.KQZJ^_\.KLZ@``\NH``.OJ=,'H[>[M
M>,%ZP7?!=L$``'7!<\'I[>SM<L'M[0``><'K[0``ZNW`P@``P<*A\'WP?O``
M````PO(``,'ROL.T]*3$L_0``/#U1?>FQ4/Y1/G8Q=JF``#7JE+;3KM[P>_M
MVZ8``.6OY*]3VP```````/3JW*90K0````!4VU7;5MM/N[*_W:8``-BJ:-#F
MKW#3ZK(``%?;I+@``%"[L[]\P<+"M?3>IMFJ`````.>O4M?.M0``4;NKXT7G
M``````````#?IL^UH]]2N^"FL<UIT%&M`````'+3`````.JO``#HK^FOZZ\`
M````<=,`````5]=4UU;7Z[+MLNRR4]?NLE77``!8VUG;``!:VZ;?``"GWP``
MI=^HWP``I;@``*3?``!3NP````!*YT;G2>=+YTCG1^<``/7J]NKWZK2_M;_Q
M[?#M\NT``*/PHO```,3R``#%\L/R``"EQ```MO2W]```1O?O][OXX:9]J```
M?<'BI@``6-=;VP``0<9*R@```````$O*3<KCID[*3,H`````HLNCRWO+````
M``````"ARZ&H``"BJ'S+>LMYRWW+?JA^RVK0````````MLW<JK7-M\T``-NJ
MO,W?JK+-P,W&S>:JP\WCJ@``N<V_S<'-``"TS>*JW:JZS>2JYZKAJ@``VJJ^
MS;C-Q<WIJN6JX*J]S>RON\W>JNBJ``"SS0``PLW$S0``````````````````
M````````````````8JU<K62M8:UQT'307:T``&O0``!6K6"M``!CK66MHM!W
MT```5:VAT%FM5ZU2K6_0``!^T'/0=M"ET```9JU]T%ZM>-"DT'70>=!\T```
M``!MT*/0>]``````;-```'#07ZU:K5.M6*U4K6>M;M"ETUNM`````'K00<X`
M````````````````````J-/ZKP``=M,``*/3?=,``++3``"JTP``?M,``*G3
M>--\T[73_:^MTZ33[:^STW33``"LTP``_*_WKW/3]:_TK_FOJ]/QK_BO<M!<
MVZ;3`````'K3^Z][TZ'3_J]UTZ_3``"NT[;3\Z_PK[33L-.GTZ+3]J_RKW?3
M[J^QT^^O``!YTP``````````````````````````````````````````````
M````````````````````````````7M=@UV77>=?\LO*R``!=U_VR_K)HUV_7
M==<``&+7``!IUP````!`LW?7<M?ZLOBR;M=JUUS7[[)AUUG7``#WLOFR9M=C
MU_2R<]?QLF37>M=LUP``:]?PL@``^[(``/.R6M=?UW#7=M=!LUO79]=MU_:R
M`````'C7<==TUP```````````````````````````````/6R``!LVV#;U[5]
MVZ?;JMO5M6C;H]MIVW?;XK5SV]^U``!TVUW;``"DVP````#HM:';==NLVW#;
MR-\``*_;YK5NVWK;Z;74M7+;K=MKVV3;;]L``&/;8=O0M:7;:MNHVP``J=O8
MM=VUV;7AM7[;VK5VVV;;``#2M5[;HMNKVV7;X+6PVW';``!MVP``T;7EM0``
M?-OGM0``>-O<M=:UWK73M>2U>=MGVWO;8MNFVP``````````````````KML`
M`````````````````%_;`````````````,??``#=WU6XS-\``,K?M=^IN,7?
MV=_!W[&XV-^_W^.US]_`W];?L+BHN```JM^RWP``R]_#W]S?QM^VN-??``"M
MN```R=_1W[;?T-\``.'?L=_2WP``W]\``*O?V[4``+G?N-^ON```O-^^W\W?
MWM^RN```L[@``+#?J[BTW]K?M+@``*RXKKBUN.#?T]_.WP````"[W[K?JKBL
MWZ>XQ-^MW\+?`````+??V]\```````"FN````````+/?````````````````
MK]_5WZ[?8+O3XP````#"XP````"LX\KC6+N[X\7C6[N^XUF[K^/-XZ[CP>,`
M`*WC`````+_CR./&X[KCM>.SXP``M./'X]+CO.-:NP``M^,``,OC``!=N[;C
ML./`XV&[`````%6[7KNXX[+C``!7N]3?5KO#XP``5+MCNUR[Q..YX['CS..]
MXV*[T.-?N\_C``#)X\[C````````T>,`````````````````````````````
M<^=TYV?G9N=BY[2]``"LO7;G=>>IWU_G8^==YP``<.=AYP``=^=:YUCG9.=N
MYVGGMKU/YP``;><```````"WO;W?6^=2YU7G>^=<YU/G4>=.YP``L+UEYZ^]
ML[U@YVCGJ;UXYWSGJ[T``%?G:^=OYU3G>>>RO0``L;U,Y[6]<N=6YVKG4.=>
MYUGGK;VNO6SG?>=ZYW'G````````````````````````3><``*J]2>L``$#K
M0^L``+N_1>OYZD'K1^NXO[R_MK\`````^^I,ZP````!&ZP``_.I5ZT_K^.I&
M[O[JM[\``$KK``!4Z[^_``!1Z_WJ1.M(ZT+K5NM3ZU#KN;^ZO[Z_^NI7Z[V_
M3>L`````2^L```````!.ZU/N0.Y%[E+N1.[[[4'N``"BP0``].U-[D_N\^VA
MP5'N2>ZHP5#N0NZJP?GM4NM*[D?N]>U5[J3!`````*7!]^U([@``5.Y+[OWM
MI\&CP4SN_NU6[OCM0^Y.[OKM_.T``,O"]NVIP<3"?L$``````````*;!R,*S
M\```J?"D\*KPM/"X\+?PRL+)P@````"K\+GPKO"F\```J/"G\*WPLO"E\*SP
ML?#'P@``K_```,7"L/##PL;"U?*U\`````#"PP``S?+1\LGRS/(``-3RP,/9
M\M+R``#*\MKRT_+#P\3#U_(``,ORO\/!P\;RSO+(\@``V/+6\L?RS_(`````
M``"^],7#T/*GQ*G$IL0``,/TN_2Y]+WTNO0`````O_3!]*K$K,0``,#TK<2K
MQ,+T``````````"HQ`````````````#TQ/'U]_7VQ+ST]O4``/WU]/7[]?KU
MN/3U];;P_O7S]?CU``#\]?+U``!*]_7$^?4`````]/=+]TGW1_=(]TSW``#9
MQ?+W\/?U]_/W``#V]]K%\?<`````O/@`````1?E&^4?Y`````,?YO?E/RNJJ
M``!HK0``N-.WTT"P0K-\UP````![UP``ZK6XN```M[BYN```U.-^YUCK6NM9
MZP``J\%7[KKPI?GDI@``R<W*S<C-Q\WKJ@``J="GT`````"FT```::UKK6JM
MJ-``````````````````````Q-/!T[_3`````$&PPM-&L+S3R],``,W3O=,`
M`$.PSM/)T[O3P-/*T\;3P],``$BPS-.^TP````#'T[G31[!$L,73``#(T[K3
M1;!"L```````````3+.EUTNS``"HUZO72+-&LW[7J=>GUZ37K->MUZ_7L-=]
MUT6SHM>AUZ[71[.CUTFS1+.FUTVS``!*LZK7````````\;6_VP``M-ONM0``
MY]^]V[';[+6VV^^UNMNXV_*UZ[4`````LMNUV_"U``"SVP``OMN\V[?;N=N[
MV^VU``````````````````#HW^[?Y-_JW[JXYM_`N`````"_N```OKCMW\&X
MPKCCW_#?P[B]N+RX[-_$N.+?Y=_OW^O?`````/3CZ>.[N```````````:KO=
MX_+CWN-ENP``V^,``.3CW.-GN];C\>-HN^[C[^/7XVV[YN,``.#CY^/:XP``
M\^/KX^7CU>-IN^SC``!LN_#C``#JXV:[Z.,``.+C9+O9X^'C[>/?XP````#C
MXP````````````#!O>G?LN>[Y['GK>>JY\*]J.=KNZ'GP+VGY[^]K.>IY[GG
MM.>NY[/GN[VKY[[GHN>CY[KGO+V_Y[Z]P.>PY]CCMN>OY[CGM><```````"F
MY[F]O>>ZO:3GO;UDZ[?GO.<`````````````8>NXO<"_:^MGZP``9>M@ZV_K
M````````Q+\``%SK:.MIZU_K7NMLZP``8NM=ZV/K``!NZUOK;>MJZ\*_P;\`
M````P[]FZ\OP`````````````%GNL<%=[EKN8>YG[ESN``!P[J[!:NY?[FON
M9NYM[E[NL\&RP6#N;NY8[FSNK,$``&3N8^YH[EONL,$``+3!8NYI[K7!9>X`
M`````````*W!K\''\,7P`````,SPR?#-\```OO#&\-'P;^["\,_"I>>]\,KP
MQ/#!\+SPN_#0\```P/"_\,W"R/```,S"`````,["P_#/\```WO+?\@``R</<
M\L;#Y/(``,K#YO+;\L[PZ/+=\@``Q\/C\@``Y?+@\N?RXO+A\LC#`````,7T
MQO0``,CTKL2OQ,GTQ_0``,3T``!"]D7V0?8``/K$0_;YQ/C$]\1$]E'W3_<`
M`$[W0/90]T;V3?<``/GWU_?W]]O%^/?Z]P``O_CZQ;[XO?C[Q0``6L9N^:?Y
MIOFH^>6FJM```,_3T-,```````#`VP``1_;`^.:F;*VKT````````+'73K,`
M`,+;P=OSM0``Q;C!Y\.]``#$O0```````,6__,7GI@```````*S0[:JNT*W0
M;:T``-'3``#8TTFPUM/4TP``V]/2T]/32K```$ZP`````-S33;#:T]?3U=-+
ML$RPV=,``````````%"SLM<``%6SPM=4L\37`````+C74K/#UP``L]=3L[_7
MN]>]U[?7OM<`````3[.ZUP``N=>UUP``P-<`````O->TUP``MM=1L\'7````
M``````#VM<W;````````R=O+V\;;Q=O#VP``RMO,V\C;``#'V_2U];4`````
M``````````#/V\VX\M_XW_/?]-\``/G?``#/N```Q[C.N/'?Q-O*N,BX]]_V
MW\FXR[CUW\:X``#,N`````````````#VXW2[`````$+D0>0``/OC=KM`Y/?C
M^.-NNW"[``#]X_7C<KMQN_GC_N/\XW.[^N,`````SMMONP````#"Y\GGQKT`
M`,WGRKW%Y\/G``#,YP``Q;W+Y\>]R+W$Y\F]RN?&Y\?GR.=UNP```````'#K
M?.L``,J_=^MYZP``R+]QZW7K``!XZ\:_R;][ZW/K=.MZZW+K=NO'OW+N``!Q
M[K?!=^ZYP0````"VP7/NNL%T[@````!U[GCN``"XP0``UO``````V?```-/P
MU?``````U/#7\-CP=N[2\`````#-P^SR[_+Q\NKRZ_+N\O#RSL/,P\O#[?+I
M\LKTL,0``,OT`````$GV^\1+]OS$2/9*]JC%``!2]Z?%_??\]P``^_<`````
M2/E)^4OY2OD``%#*Z*8``&ZMQ=?WM0``^M_0P@``\O(`````HZ@```````!7
MLP```````%:S``#0V_BUTMO1VP````#[W]"X0^1&Y$7D``!$Y,[GT.?/YP``
MS+\```````#+OP``N\%Y[GON>NX`````T<(```````#T\O/R``#,]+'$````
M`/W$5/=3]UO&`````````````````````````````````````````````*2H
MK]!OK<C7QM<`````Q]?4V]7;0^#3VP``_-]!X$#@0N#1N/[?_=]$X```2>1'
MY```2.33Y]'G`````-+G?>M\[GWNTL(``/7RS?2RQ```3/95]ZG%``#^]TSY
MI:@``'&M<JVPT`````"QT'"M``!4L```4K```%&P6+!0L%FPW=-6L```4[!7
ML%6P3[``````7[,``%FSS-=>LP````!@LUJS``!;LP``RM<`````6+,``,O7
M7;,`````R==<LP````!$M@``1K8`````V-M%MOFU_;4``.2X2>#:V_ZU````
M`-W;WMM#M@``X-L``.+;``#CV]?;UMODVT*VX=O?VP``0+;[M4>VV]O<V]G;
M``!!M@````#\M0``^K5(X-^XVK@`````U;@``.6XUK@``-*XX;C>N."X``#7
MN-RXT[C4N%#@3>!%X$K@``#BN%'@X[C9N`````!'X```3^!+X$[@3.#=N$;@
MV+@```````!,Y'B[>[L``$[D``"ENTWD?;L``,^]3^0``*2[2^2FNP``````
M`'F[``#;N'R[``!ZNWZ[HKMWNZ>[H[L``*&[2N0``````````-:]``#2O0``
M`````-F]``#6Y]J]XN?;Y\N]X^?=Y]6]WN<``-2]X>?.O=_GU>?-O:KKT[T`
M`-"]``#8O0``U.<``-CGS+W7Y]GGVN?7O=SGX.?DYP``V[W2OZ7KJ^NHZW[K
MK.NAZP``I^L``,V_T[^MZP````#/OP``V;_4OZ_KJ>O0OZ+KVK^CZZ3KV[_8
MO]&]``#.O[#KW+\``-6_KNO1O]:_U[\``,/!I.ZM[JKNK.X``,#!I>X``*ON
MO,&G[L3!H^ZH[J_NINNI[J+NO<&A[K[!L.Z_P:[NPL%^[@``P<$``*;NW/#J
M\.7PY_#;\-/"``#:\-;"U<(``.GPX?#>\.3P``#=\```W_#H\.;P``#4PNWP
MZ_#B\.SPX_```/GRS\-!\P````!/]M;#X/#W\M+#^/+]\@````#4P]7#]O)`
M\T+S^O+\\O[R^_)#\]'#U\/3PP``T,/0]```M\3.]`````#2]```T_2UQ-3T
MT?0``,_TN,2TQ-7T``"VQ+/$````````_L0`````0,5.]DWV4/91]@``0<56
M]UOWJL4``%CW``!7]UKW6?<``$/X``#<Q4+X0/@``$'X````````_L7]Q<'X
MPOA`Q@``3?E.^6?&``!MQ@``J?G(^0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````IJ@``,W7``#.UU+@4.3EY\;!``#%P>[P1/,``$3XIZC>TUJP
M8;-4X%/@W+WFY]V]L>[7P@```````';&J*C+S=_3`````&*S``#/U]#7``#E
MVP``2+;FN```5N!5X%?@``!1Y%+DJ+O=O]Z]WK\``+7NLNZT[K/NQ\$``._P
M1O-%\Z3+7+!;L.#3``#1UP````#GV^;;2;8``%G@6N!8X`````#HN.>X``"J
MNZF[``#GY[/KL>NRZ]^_M^ZV[@``\O#Q\/#P1_,``*KYJ:ASK0``=*U=L%ZP
MXM/AT]+7``!HLV:S8[-GLV6S9+,`````2K;JVP``[;A,ME&V[-M3ME*V5;;K
MV^C;3[9+MDVVZ=M4ME"V3K;ON.ZX[+CPN```ZKCKN```Z;@``%O@`````%3D
M``"LNZV[J[L``%/D``!5Y```ZN?LYP``Y[WMY^"]Z>??O>F]Y;WFO>*]Z.?A
MO>[GZ^<``.B]``#CO>2]M>L``+?KMNL``+CKX+^TZP````#+P;CNR,',P<K!
MR<'S\```]O```/7P``#T\-C"2/-)\]C#2O/9PP````"ZQ```N<12]@````!"
MQ5/V7/>KQ:S%``!%^```0L8`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"JJ```:K-ILUS@7>```*Z[N>OJ
MO;KKN>ZKJ```LM!VK76M``#CTU^PY-/5UP``U-<``-/7`````.[;6+8`````
M[=M7M@```````._;5K8``%_@8N!@X&'@9>!>X&;@8^!DX+"[5N0`````K[L`
M`/+G\.<`````Z[WOY_'G``#LO0``N^L``+SKS<$``$SS3O-+\TWSUO14]@``
M``!O^:RH=ZWET^?3YM,``-C7;+,``-;7``!KL]G7``#:U]?7`````/O;8+;S
MV_G;`````%NV7K;RVUFV]MMLX%VV``#QVP``]]OTV_K;\-OXVURV7[;UVUJV
M``#RN&C@\;AOX&[@^+@``/FX<.#SN&W@][ARX&G@``!KX/2X9^!JX''@];AS
MX`````````````#VN```L;M;Y&'D6>1BY```6.1=Y&/D8.1?Y%[D``!7Y%SD
M`````%KD``#QO>Z]^^=!Z$/H0.CXY_KG1>A"Z/SG1NCYYT3H[[WUO?.]\^?T
MO?"]].?VY_7G_>?^YP``\KT``.V]`````/?G``#&Z^*_``"]Z^._YK_"ZP``
MO^OEOP````##Z\3KONO'Z\#KQ>ODOP``X;_!ZP``O^[0P<[!T<'/P;[NN^ZZ
M[@``O>X`````O.Y%\=["^_#Z\```V<)!\4#Q]_!#\?SPW<+Y\$+Q^/#:PMS"
M_?#;PO[P``!$\5+S``#>PT_S``!3\P````#;PU'SX,,``-W#``!0\P``W\-4
M\]K#``````````"\Q+[$``#9]+W$U_3<P]CTN\1#Q47%5O9$Q57V``!A]ZW%
M8/>NQ5[W7?=B]V/W1O@``%_W`````,;XP_C$^,7X7,8``%'Y4/E/^7#Y``"^
M^:OY;L:MJ&"P`````````````/JX``````````````````#VO0````#(ZP``
M``#?P@``5?,```````````````"L^:ZH[JIYK7BM``!CL```Z--AL.G38K``
M````W]?;UP````!ML][7W=?<UVZSX-?AUP```````$/<0=Q%W$;<3-P``$C<
M2MP``$+<_-L``$G<`````$O<1-Q'W/W;8K9`W/[;8;9CM@``_;AUX'?@=N![
MX/NX``!XX'3@>>!ZX/RX_KA\X```9^1FY```9.1EY+.[M;NRN[2[3>A.Z$GH
M``!*Z/B]_;WWO?Z]^;U+Z`````!,Z$CH0+[[O0````#ZO?R]``!'Z```RNOH
MOP````#,Z^J_S^O+Z\GKSNOIO\WK``#GOP````#3P=;!P>X``-3!P.[2P=7!
M1O%'\4CQX,(``$GQ``#APN+#6/-9\U?S5O-:\^'#W?3;]-STWO3:]-_T6/8`
M`%GV5_9&Q63WK\5E]TCX1_@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"OJ&2V`````$"Y
M````````MKL`````[+\``.N_``````````#CPWS$1\6PJ&2P0;D``%OS````
M``````````````````````"FRP````"QJ```M*BSJ+*H`````*7+``#-S0``
MS\WOJ@````#QJLS-SLWPJM'-T,W2S0````````````````````"VT+30?*VS
MT*.M?JU[K0``I*T``'VMHJT``*&MM=```'JM````````:K#KT_'39[!NL```
M:;#NT_#3;+#JT^W3:+!EL.S3:[#OTVVP9K```````````./7YM=PLP``>K-V
ML^37`````'ZS=[-\LW*S``!OLW&S?;/EUW6S>+-TLWFSY]=[LW.SXM<`````
M````````````````3=QEMD_<``!GMFFV``!.W&:V:K8``&BV````````1[FC
MX$^Y?N```%"Y1;D``*'@`````$JY``"BX$.Y0KD``$VY3+E+N4FY3KE]X$2Y
M1KE(N0````"XN[N[``"_N[F[OKN\NP``M[L``+V[NKL```````!2Z$.^0;X`
M`%/H``!$OD*^4>A0Z```\+]/Z.Z_[;_0ZT6^[[_1Z_*_TNOQO]C!P^[7P=S!
MVL';P>/"V<'"[M/KXL+DP@``Y,/EPP``X/0``-[%W<6VJ`````!5RF^P``!2
MRE/*4<H``%3*`````*K+I\NLRZC+MZBZJ```J<NYJ*O+`````+BH````````
M``#5S=?-]*K3S=;-U,WRJO6J``#SJ@``````````N-"\T+G0``"GK0``J*T`
M`+O0``"]T+_0``"EK;[0`````*:M`````````````.[7NM#RT_O3^=/TT_73
M^M/\TW&P``#WT_/3<+!RL/;3_=/XTP````"AL_'7Z=?OU_#7HK,``.C7ZM>W
MT.S7[=?KUVRV````````5MS4ZU?<5-RCLVZV4]Q9W%C<:[9<W%+<6]Q0W%K<
M5=QMM@``JN```*7@J^"FX*3@I^!1N0``J>```*C@4KG!N\"[;N1QY&GD;>3"
MNVSD:N1PY&OD:.1OY```6>A(ODKQ5NA7Z%7H4=Q'OEKH5.A&ODF^6.C5Z_._
MUNO7ZP``Q.[=P4OQ3/$`````3?%=\USSXO0``.'T6_9<]EKV9O>PQ;NHJJVI
MK76P=+!`U$'4_M,``'.P]=<``/;7\M>DL_/7``#TUP``````````7]QAW%W<
M8-QOME[<<+8`````<]U5N52Y``!3N0``K."MX`````!SY'7DQKO#NP``Q;O$
MNW3D<N0`````````````8>A>Z%_H3;Y@Z%OH7.A*O@``2[Y=Z$R^``#;ZP``
MW.O9Z]KK]+_8ZP````````````#([L7NQ^[@P<ONW\')[LSNRN[&[M[!``!/
M\0``4/%.\0``4O'EPN;"7_/GPU'Q7O/FP^7TYO2_Q.3T``#C]```7?9(Q0``
M2?C(^,?X``!#QEW&R?AQ^0``;\:\J/:J``!6N0``P,2]J*NMI;-QMN?"]ZH`
M`,'0P-!"U```>+!VL'JP1-0``'FP=[```````````$/4J+/\UP``I[.ILT+8
MJ[/^UT#8]]>JLT/8`````/G7``#ZU_C7IK,``$'8^]?]UP```````&W<``!L
MW&K<8MQQW&7<;]QVW&[<>;8``'6V8]P``&G<=[8``&C<>+9ZMFO<``!RMG.V
M=]QUW```=-QFW```<MP``':V``````````!TMG/<9-QGW'#<````````````
M`+KDM^```+#@P^#,X+/@8;D``,#@5[E9N66YL>``````6KE<N6:Y6[D`````
M`````&2YN>```*[@8KFXX%ZYRN!CN<C@O.#&X&"YK^#)X,3@``#+X%BY````
M`&>Y7;D`````M>```+W@P>```,7@7[FTX++@ON```````````+O@NN```+_@
MPN```,?@````````>.0``,>[I.1ZY,R[T+NMY+7DIN3(NP``JN2VX```R;NQ
MY+;DKN0``+#DN>2RY'[DJ>0`````T;L``,V[?.2KY,N[I>3*N[/DHN1YY,Z[
MN.0`````>^2OY*SDI^1WY';DH>2TY,^[M^1]Y*/D4KX`````````````6KY5
MOJ3HH>AGZ%"^````````3[Y6O@```````&7H5+YQZ&/H9.A.OJ/H6+YTZ'GH
M<^CNZV_H=^AUZ&CH8NA]Z%>^?N@``'CH``!MZ&OH9N@```````!NZ'OH:NAZ
MZ*+H`````%.^``!VZ'SH<NALZ%&^````````J.1PZ%F^:>@`````````````
M].OWO_/K\.M$[/N_``!![/CK0^SIZ_;K``#]OP``X>L``-_K0NP``$#L_NOM
MZ^SKXNM`P```Z.ORZ_WK0\!%[```Z,%%P/Z_YNL``._KWNO@Z_6_0L#ZO^?K
M]^OQZT'`W>OCP?GK_.O\OP``Z^M$P/F_````````^+_UZ_OK]K\``.3K^NL`
M````Y>L```````````````````````#JZ]+N``#7[N7!Y\'=[N'![.[C[MCN
MV>[B[@``[L'A[M'NX.[4[NWN[<'KP=7N``#H[@``VN[G[@``Z>[0[N;!``#J
M[@````#>[@``ZL';[@````#LP>3N````````Y,'6[N7N``#?[N/KYN[3[@``
MZ<$``.ON``#BP<[N``````````!@\5GQZ<(``%3Q8_%;\=SN``!E\57Q``#H
MPE_QZL+RPO#"8?'QPE?Q``!8\5WQ8O$``,WNZ\)J\6?Q:_%>\5KQ:/%J\USQ
M``#NP@``[<+/[N_"9/%F\>S":?%3\0``5O$`````````````````````<_,`
M`&/SZ\-Q\P````!A\^S#``!L\P``://QPW+S8O-E\^G#=/,``&WS<//OP_3#
M\L-I\V3S``#MP^[#8//JPP``Z,/PPV_S\\,``&OS=?/UPP```````&?S``!N
M\P```````````````//T0O7U]/ST9O/Z].GT0/7#Q.WT_O3T]`````#"Q```
M``!$]?;T``#[]/WTY_1!]?+T]_3K]._T0_7Y].CT[/3N]/CT``#!Q/'T````
M````````````ZO0``````````````````/#T8?9F]D_%:/8``$G%``!D]FKV
M3L5*Q0``2\5@]F?V3<5E]DS%7_9C]F+V``!>]FGV````````L<5M]W#W;/=N
M]V_W:?=J]V?W`````&OW:/>RQ;/%`````$OX``!-^`````````````!,^$[X
M``#@Q0``2OC?Q>'%````````R_C,^$3&RO@``%/Y4OE4^5_&5?E>QE;Y<OEU
M^73Y:,9S^0```````'+&<,9QQG?&P/G!^;_YR?D`````````````````````
M``````````!5HE:B````````````````````````````````4*)1HE*B````
M`%2B````````````````````````````````````````````````````````
M``````````````````````````````````!7H@``````````````````````
M`%.B`````.NAZJ$`````3Z+`H0``````````````````0*%"H4.ALJ$``*3&
M`````'&A<J%MH6ZA=:%VH7FA>J%IH6JA1:(``&6A9J$`````````````````
M`*FAJJ$`````PZ+$HL6BQJ+'HLBBR:+*HLNB````````````````````````
M`````````````````````````````````````*7&IL:GQJC&J<:JQJO&K,:M
MQJ[&K\:PQK'&LL:SQK3&M<:VQK?&N,:YQKK&N\:\QKW&OL:_QL#&P<;"QL/&
MQ,;%QL;&Q\;(QLG&RL;+QLS&S<;.QL_&T,;1QM+&T\;4QM7&UL;7QMC&V<;:
MQMO&W,;=QM[&W\;@QN'&XL;CQN3&Y<;FQN?&Z,;IQNK&Z\;LQNW&[L;OQO#&
M\<;RQO/&],;UQO;&]\8```````````````````````"BQJ/&`````/C&^<;Z
MQOO&_,;]QO[&0,=!QT+'0\=$QT7'1L='QTC'2<=*QTO'3,=-QT['3\=0QU''
M4L=3QU3'5<=6QU?'6,=9QUK'6\=<QUW'7L=?QV#'8<=BQV/'9,=EQV;'9\=H
MQVG':L=KQVS';<=NQV_'<,=QQW+'<\=TQW7'=L=WQWC'><=ZQWO'?,=]QW['
MH<>BQZ/'I,>EQZ;'I\>HQZG'JL>KQZS'K<>NQZ_'L,<`````````````````
M`*'&````````````````=*-UHW:C=Z-XHWFC>J-[HWRC?:-^HZ&CHJ.CHZ2C
MI:.FHZ>CJ*.IHZJCJZ.LHZVCKJ.OH["CL:.RH[.CM*.UH[:CMZ.XH[FCNJ,`
M``````````````#IQ^K'Z\?LQ^W'[L?OQ_#'\<?RQP``````````````````
M````````\\?TQ_7']L?WQ_C'^<?ZQ_O'_,<`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'>B``!XH@```````````````````````'JB````
M````>Z(```````!\H@```````'VB````````=:(``````````````````'2B
M``````````````````!SH@``````````````````<J(`````````````````
M`'&B``````````````````````````````````````````````````"DH@``
M````````````````````````````````I:(`````IZ(`````````````````
M````IJ(`````?J*AHJ.BHJ*LHJVBKJ(`````````````````````````````
M`````&*B8Z)DHF6B9J)GHFBB::)PHF^B;J)MHFRB:Z)JH@``````````=J)Y
MH@``````````````````````````O:&\H0``````````````````````````
M````````````````MJ&UH0````````````````````"_H;ZA````````````
M`````````+NANJ$```````"SH0````"WH;2A````````````````````````
M````````````````````````J**IHJNBJJ(`````````````````````````
M`````````````````````````````````````````````````````````+FA
MN*$`````\Z$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#PH?*A\:$`````````````````
M`````````````````%:A6*$```````"EH::A`````*>AJ*$``````````$6A
M`````$RA2Z$`````````````````````````````K*$`````JZ$`````````
M````L*$`````PJ$`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$JB
M``#!H0```````$NB````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````+FBNJ*[HKRBO:*^HK^BP*+!HL*B````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/:A]*'WH?6A`````/BA^:'[H?JA````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-2A````````VZ'HH>>A`````/VA``#\H0``````
M`.2AY:'LH0````#MH0````````````#OH>ZA````````````````XZ$`````
M``````````````````````````````````````````````````#<H0``````
M````````````````````````````VJ'=H0``````````V*'9H0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````YJ$`````````````````````````
M`````````````````````````````````````````.FA````````OJ,``+RC
MO:._HP``````````````````````````````````NZ,`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!$HT6C1J-'
MHTBC2:-*HTNC3*--HTZC3Z-0HU&C4J-3HU2C``!5HU:C5Z-8HUFC6J-;HP``
M````````````````7*-=HUZC7Z-@HV&C8J-CHV2C9:-FHV>C:*-IHVJC:Z-L
MHP``;:-NHV^C<*-QHW*C<Z,`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````+/'````````
M````````````````````````````````````````L<>RQ[3'M<>VQ[?'N,>Y
MQ[K'````````````````N\>\Q[W'OL>_Q\#'P<?"Q\/'Q,?%Q\;'Q\?(Q\G'
MRL?+Q\S'S<?/Q]#'T<?2Q]/'U,?5Q];'U\?8Q]G'VL?;Q]S'W<?>Q]_'X,?A
MQ^+'X\?DQ^7'YL?GQ^C'``#.QP````````````!&HD>B``!$H@``L:$`````
M````````````````6*+3H0````````````!0H0``````````````````````
M````````````````````````````````````````````````````````````
MT:$`````````````````````````````````````````````````````````
M`````````````````````````-*A``````````````````````````!"3EQ.
M]5$:4X)3!TX,3D=.C4[75@SZ;EQS7P].AU$.3BY.DT["3LE.R$Z84?Q2;%.Y
M4R!7`UDL61!<_UWA9;-KS&L4;#]R,4X\3NA.W$[I3N%.W4[:3@Q2'%-,4R)7
M(U<762]9@5N$6Q)<.UQT7'-<!%Z`7H)>R5\)8E!B%6P`````````````````
M````````````````````````````````````````````````````````````
M`````````````#9L0VP_;#MLKG*P<HISN'F*@!Z6#D\83RQ/]4X43_%.`$_W
M3@A/'4\"3P5/(D\33P1/]$X23[%1$U()4A!2IE(B4Q]335.*4P=4X5;?5BY7
M*E<T5SQ9@%E\6859>UE^67=9?UE66Q5<)5Q\7'I<>UQ^7-]==5Z$7@)?&E]T
M7]5?U%_/7UQB7F)D8F%B9F)B8EEB8&):8F5B[V7N93YG.6<X9SMG.F<_9SQG
M,V<8;$9L4FQ<;$]L2FQ4;$ML````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$QL<7!><K1RM7*.<RIU?W9U>E%_>()\@H""?8)_@DV&
M?HF9D)>0F)";D)20(I8DEB"6(Y963SM/8D])3U-/9$\^3V=/4D]?3T%/6$\M
M3S-//T]A3X]1N5$<4AY2(5*M4JY2"5-C4W)3CE./4S!4-U0J5%1415095!Q4
M)5085```````````````````````````````````````````````````````
M````````````````````````````````````/51/5$%4*%0D5$=4[E;G5N56
M05=%5TQ725=+5U)7!EE`6:99F%F@69=9CEFB69!9CUFG6:%9CEN26RA<*ER-
M7(]<B%R+7(E<DER*7(9<DUR57.!="EX.7HM>B5Z,7HA>C5X%7QU?>%]V7])?
MT5_07^U?Z%_N7_-?X5_D7^-?^E_O7_=?^U\`8/1?.F*#8HQBCF*/8I1BAV)Q
M8GMB>F)P8H%BB&)W8GUB<F)T8C=E\&7T9?-E\F7U945G1V<`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````66=59TQG2&==9TUG6F=+
M9]!K&6P:;'AL9VQK;(1LBVR/;'%L;VQI;)IL;6R';)5LG&QF;'-L96Q[;(YL
M='!Z<&-ROW*]<L-RQG+!<KIRQ7*5<Y=SDW.4<Y)S.G4Y=91UE76!=CUY-("5
M@)F`D("2@)R`D(*/@H6"CH*1@I."````````````````````````````````
M``````````````````````````````````````````````````````````"*
M@H."A()XC,F/OX^?D*&0I9">D*>0H)`PEBB6+Y8MEC-.F$]\3X5/?4^`3X=/
M=D]T3XE/A$]W3TQ/ET]J3YI/>4^!3WA/D$^<3Y1/GD^23X)/E4]K3VY/GE&\
M4;Y1-5(R4C-21E(Q4KQ2"E,+4SQ3DE.44X=4?U2!5)%4@E2(5&M4>E1^5&54
M;%1T5&94C51O5&%48%285&-49U1D5/=6^59O5W)7;5=K5W%7<%=V5X!7=5=[
M5W-7=%=B5P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!H5WU7#%E%6;59NEG/6<Y9LEG,6<%9MEF\6<-9UEFQ6;U9P%G(6;19QUEB
M6V5;DUN56T1<1URN7*1<H%RU7*]<J%RL7)]<HURM7*)<JERG7)U<I5RV7+!<
MIEP77A1>&5XH7R)?(U\D7U1?@E]^7WU?WE_E7RU@)F`98#)@"V``````````
M````````````````````````````````````````````````````````````
M`````````````````````#1@"F`78#-@&F`>8"Q@(F`-8!!@+F`38!%@#&`)
M8!Q@%&(]8JUBM&+18KYBJF*V8LIBKF*S8J]BNV*I8K!BN&(]9:AENV4)9OQE
M!&829@AF^V4#9@MF#68%9OUE$6809O9F"F>%9VQGCF>29W9G>V>89X9GA&=T
M9XUGC&=Z9Y]GD6>99X-G?6>!9WAG>6>49R5K@&M^:]YK'6R3;.QLZVSN;-EL
MMFS4;*ULYVRW;-!LPFRZ;,-LQFSM;/)L````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-)LW6RT;(ILG6R`;-YLP&PP;<ULQVRP;/EL
MSVSI;-%LE'"8<(5PDW"&<(1PD7"6<()PFG"#<&IRUG++<MARR7+<<M)RU'+:
M<LQRT7*D<Z%SK7.F<Z)SH'.L<YUSW73H=#]U0'4^=8QUF'6O=O-V\7;P=O5V
M^'?\=_EW^W?Z=P``````````````````````````````````````````````
M````````````````````````````````````````````]W=">3]YQ7EX>GMZ
M^WIU?/U\-8"/@*Z`HX"X@+6`K8`@@J""P(*K@IJ"F(*;@K6"IX*N@KR"GH*Z
M@K2"J(*A@JF"PH*D@L."MH*B@G"&;X9MAFZ&5HS2C\N/TX_-C]:/U8_7C[*0
MM)"OD+.0L)`YECV6/)8ZED.6S4_%3]-/LD_)3\M/P4_43]Q/V4^[3[-/VT_'
M3]9/ND_`3[E/[$]$4DE2P%+"4CU3?%.74Y93F5.84[I4H52M5*54SU0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````PU0-@[=4KE36
M5+94Q53&5*!4<%2\5*)4OE1R5-Y4L%2U5YY7GU>D5XQ7EU>=5YM7E%>85X]7
MF5>E5YI7E5?T6`U94UGA6=Y9[ED`6O%9W5GZ6?U9_%GV6>19\EGW6=M9Z5GS
M6?59X%G^6?19[5FH6TQ<T%S87,Q<UUS+7-M<````````````````````````
M````````````````````````````````````````````````````````````
M``````#>7-I<R5S'7,I<UES37-1<SUS(7,9<SES?7/A<^5TA7B)>(UX@7B1>
ML%ZD7J)>FUZC7J5>!U\N7U9?AE\W8#E@5&!R8%Y@16!38$=@26!;8$Q@0&!"
M8%]@)&!$8%A@9F!N8$)B0V+/8@UC"V/U8@YC`V/K8OEB#V,,8_AB]F(`8Q-C
M%&/Z8A5C^V+P8D%E0V6J9;]E-F8A9C)F-68<9B9F(F8S9BMF.F8=9C1F.68N
M9@]G$&?!9_)GR&>Z9P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#<9[MG^&?89\!GMV?%9^MGY&??9[5GS6>S9_=G]F?N9^-GPF>Y
M9\YGYV?P9[)G_&?&9^UGS&>N9^9GVV?Z9\EGRF?#9^IGRV<H:X)KA&NV:]9K
MV&O@:R!L(6PH;31M+6T?;3QM/VT2;0IMVFPS;01M&6TZ;1IM$6T`;1UM0FT`
M````````````````````````````````````````````````````````````
M``````````````````````````````%M&&TW;0-M#VU`;0=M(&TL;0AM(FT)
M;1!MMW"?<+YPL7"P<*%PM'"U<*EP07))<DIR;')P<G-R;G+*<N1RZ'+K<M]R
MZG+F<N-RA7/,<\)SR'/%<[ESMG.U<[1SZW._<\=SOG/#<\9SN'/+<^QT[G0N
M=4=U2'6G=:IU>7;$=@AW`W<$=P5W"G?W=OMV^G;G=^AW!G@1>!)X!7@0>`]X
M#G@)>`-X$WA*>4QY2WE%>41YU7G-><]YUGG.>8!Z````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'YZT7H`>P%[>GQX?'E\?WR`?(%\
M`WT(?0%]6'^1?XU_OG\'@`Z`#X`4@#>`V(#'@."`T8#(@,*`T(#%@..`V8#<
M@,J`U8#)@,^`UX#F@,V`_X$A@I2"V8+^@OF"!X/H@@"#U8(Z@^N"UH+T@NR"
MX8+R@O6"#(/[@O:"\(+J@@``````````````````````````````````````
M````````````````````````````````````````````````````Y(+@@OJ"
M\X+M@G>&=(9\AG.&08A.B&>(:HAIB-.)!(H'BG*-XX_AC^Z/X(_QD+V0OY#5
MD,60OI#'D,N0R)#4D=.15)9/EE&64Y9*EDZ6'E`%4`=0$U`B4#!0&U#U3_1/
M,U`W4"Q0]D_W3Q=0'%`@4"=0-5`O4#%0#E!:4911DU'*4<11Q5'(4<Y185):
M4E)27E)?4E528E+-4@Y3GE,F5>)4%U425>=4\U3D5!I5_U0$50A5ZU015055
M\50`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````"E7[
M5/=4^%3@5`Y5`U4+50%7`E?,5S)8U5?25[I7QE>]5[Q7N%>V5[]7QU?05[E7
MP5<.64I9&5H66BU:+EH56@]:%UH*6AY:,UIL6Z=;K5NL6P-<5EQ47.Q<_USN
M7/%<]UP`7?E<*5XH7JA>KEZJ7JQ>,U\P7V=?76!:8&=@````````````````
M````````````````````````````````````````````````````````````
M``````````````!!8*)@B&"`8))@@6"=8(-@E6";8)=@AV"<8(Y@&6)&8O)B
M$&-68RQC1&-%8S9C0V/D8SEC2V-*8SQC*6-!8S1C6&-48UEC+6-'8S-C6F-1
M8SAC5V-`8TAC2F5&9<9EPV7$9<)E2F9?9D=F46829Q-G'V@::$EH,F@S:#MH
M2VA/:!9H,6@<:#5H*V@M:"]H3FA$:#1H'6@2:!1H)F@H:"YH36@Z:"5H(&@L
M:R]K+6LQ:S1K;6N"@(AKYFOD:P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#H:^-KXFOG:R5L>FUC;61M=FT-;6%MDFU8;6)M;6UO
M;9%MC6WO;7]MAFU>;6=M8&V7;7!M?&U?;8)MF&TO;6AMBVU^;8!MA&T6;8-M
M>VU];75MD&W<<--PT7#=<,MP.7_B<-=PTG#><.!PU'#-<,5PQG#'<-IPSG#A
M<$)R>'(`````````````````````````````````````````````````````
M`````````````````````````````````````'=R=G(`<_IR]'+^<O9R\W+[
M<@%STW/9<^5SUG.\<^=SXW/I<]QSTG/;<]1SW7/:<]=SV'/H<]YTWW3T=/5T
M(75;=5]UL'7!=;MUQ'7`=;]UMG6Z=8IVR78==QMW$'<3=Q)W(W<1=Q5W&7<:
M=R)W)W<C>"QX(G@U>"]X*'@N>"MX(7@I>#-X*G@Q>%1Y6WE/>5QY4WE2>5%Y
MZWGL>>!Y[GGM>>IYW'G>>=UYAGJ)>H5ZBWJ,>HIZAWK8>A![````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````1[$WL%>P]["'L*>PY[
M"7L2>X1\D7R*?(Q\B'R-?(5\'GT=?1%]#GT8?19]$WT??1)]#WT,?5Q_87]>
M?V!_77];?Y9_DG_#?\)_P'\6@#Z`.8#Z@/*`^8#U@`&!^X``@0&"+X(E@C.#
M+8-$@QF#48,E@U:#/X-!@R:#'(,B@P``````````````````````````````
M````````````````````````````````````````````````````````````
M0H-.@QN#*H,(@SR#38,6@R2#((,W@R^#*8-'@T6#3(-3@QZ#+(-+@R>#2(-3
MAE*&HH:HAI:&C8:1AIZ&AX:7AH:&BX::AH6&I8:9AJ&&IX:5AIB&CH:=AI"&
ME(9#B$2(;8AUB':(<HB`B'&(?XAOB(.(?HATB'R($HI'C%>,>XRDC*.,=HUX
MC;6-MXVVC=&.TX[^C_6/`I#_C_N/!)#\C_:/UI#@D-F0VI#CD-^0Y9#8D-N0
MUY#<D.204)$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````3I%/D=61XI':D5R67Y:\EN.8WYHOFW].<%!J4&%07E!@4%-02U!=4')0
M2%!-4$%06U!*4&)0%5!%4%]0:5!K4&-09%!&4$!0;E!S4%=045#046M2;5)L
M4FY2UE+34BU3G%-U5795/%5-55!5-%4J55%58E4V5355,%525455````````
M````````````````````````````````````````````````````````````
M```````````````````````,53)5955.53E52%4M53M50%5+50I7!U?[5Q18
MXE?V5]Q7]%<`6.U7_5<(6/A7"UCS5\]7!UCN5^-7\E?E5^Q7X5<.6/Q7$%CG
M5P%8#%CQ5^E7\%<-6`187%E@6EA:55IG6EY:.%HU6FU:4%I?6F5:;%I36F1:
M5UI#6EU:4EI$6EM:2%J.6CY:35HY6DQ:<%II6D=:45I66D):7%IR6VY;P5O`
M6UE<'ET+71U=&ET@70Q=*%T-729=)5T/70``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````P71)=(UT?72Y=/EXT7K%>M%ZY7K)>LUXV
M7SA?FU^67Y]?BF"08(9@OF"P8+I@TV#48,]@Y&#98-U@R&"Q8-M@MV#*8+]@
MPV#-8,!@,F-E8XIC@F-]8[UCGF.M8YUCEV.K8XYC;V.'8Y!C;F.O8W5CG&-M
M8ZYC?&.D8SMCGV,`````````````````````````````````````````````
M`````````````````````````````````````````````'ACA6.!8Y%CC6-P
M8U-ES65E9F%F6V999EQF8F889WEHAVB0:)QH;6AN:*YHJVA6:6]HHVBL:*EH
M=6AT:+)HCVAW:))H?&AK:')HJFB`:'%H?FB;:)9HBVB@:(EHI&AX:'MHD6B,
M:(IH?6@V:S-K-VLX:Y%KCVN-:XYKC&LJ;,!MJVVT;;-M=&ZL;>EMXFVW;?9M
MU&T`;LAMX&W?;=9MOFWE;=QMW6W;;?1MRFV];>UM\&VZ;=5MPFW/;<EM````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-!M\FW3;?UM
MUVW-;>-MNVWZ<`UQ]W`7<?1P#''P<`1Q\W`0<?QP_W`&<1-Q`''X</9P"W$"
M<0YQ?G)[<GQR?W(=<Q=S!W,1<QAS"G,(<_]R#W,><XAS]G/X<_5S!'0!=/US
M!W0`=/IS_'/_<PQT"W3T<PAT9'5C=<YUTG7/=0``````````````````````
M````````````````````````````````````````````````````````````
M````````RW7,==%UT'6/=HEVTW8Y=R]W+7<Q=S)W-'<S=SUW)7<[=S5W2'A2
M>$EX37A*>$QX)GA%>%!X9'EG>6EY:GEC>6MY87F[>?IY^'GV>?=YCWJ4>I!Z
M-7M'>S1[)7LP>R)[)'LS>QA[*GL=>S%[*WLM>R][,GLX>QI[(WN4?)A\EGRC
M?#5]/7TX?39].GU%?2Q]*7U!?4=]/GT_?4I].WTH?6-_E7^<?YU_FW_*?\M_
MS7_0?]%_QW_/?\E_'X``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````'H`;@$>`0X!(@!B!)8$9@1N!+8$?@2R!'H$A@16!)X$=@2*!
M$8(X@C.".H(T@C*"=(*0@Z.#J(.-@WJ#<X.D@W2#CX.!@Y6#F8-U@Y2#J8-]
M@X.#C(.=@YN#JH.+@WZ#I8.O@XB#EX.P@W^#IH.'@ZZ#=H.:@UF&5H:_AK>&
M````````````````````````````````````````````````````````````
M``````````````````````````````#"AL&&Q8:ZAK"&R(:YAK.&N(;,AK2&
MNX:\AL.&O8:^AE*(B8B5B*B(HHBJB)J(D8BAB)^(F(BGB)F(FXB7B*2(K(B,
MB).(CHB"B=:)V8G5B3"*)XHLBAZ*.8P[C%R,78Q]C*6,?8U[C7F-O(W"C;F-
MOXW!C=B.WH[=CMR.UX[@CN&.))`+D!&0')`,D"&0[Y#JD/"0])#RD/.0U)#K
MD.R0Z9!6D5B16I%3D561[)'TD?&1\Y'XD>21^9'JD0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#KD?>1Z)'ND7J5AI6(E7R6;99K
MEG&6;Y:_EFJ7!)CEF)>9FU"54)10GE"+4*-0@U",4(Y0G5!H4)Q0DE""4(=0
M7U'441)3$5.D4Z=3D56H5:55K55W5456HE6358A5CU6U58%5HU625:15?56,
M5:95?U655:%5CE4,5RE8-U@`````````````````````````````````````
M`````````````````````````````````````````````````````!E8'E@G
M6"-8*%CU5TA8)5@<6!M8,U@_6#98+E@Y6#A8+5@L6#M885FO6I1:GUIZ6J):
MGEIX6J9:?%JE6JQ:E5JN6C=:A%J*6I=:@UJ+6JE:>UI]6HQ:G%J/6I-:G5KJ
M6\U;RUO46]%;REO.6PQ<,%PW74-=:UU!74M=/UTU75%=3EU573-=.EU273U=
M,5U974)=.5U)73A=/%TR739=0%U%741>05Y87Z9?I5^K7\E@N6#,8.)@SF#$
M8!1A````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/)@
M"F$6805A]6`38?A@_&#^8,%@`V$881UA$&'_8`1A"V%*8I1CL6.P8\YCY6/H
M8^]CPV.=9/-CRF/@8_9CU6/R8_5C863?8[YCW6/<8\1CV&/38\)CQV/,8\MC
MR&/P8]=CV6,R96=E:F5D95QE:&5E98QEG66>9:YET&7290``````````````
M````````````````````````````````````````````````````````````
M````````````````?&9L9GMF@&9Q9GEF:F9R9@%G#&G3:`1IW&@J:>QHZFCQ
M:`]IUFCW:.MHY&CV:!-I$&GS:.%H!VG,:`AI<&FT:!%I[VC&:!1I^&C0:/UH
M_&CH:`MI"FD7:<YHR&C=:-YHYFCT:-%H!FG4:.EH%6DE:<=H.6L[:S]K/&N4
M:Y=KF6N5:[UK\&OR:_-K,&S\;49N1VX?;DENB&X\;CUN16YB;BMN/VY!;EUN
M<VX<;C-N2VY`;E%N.VX#;BYN7FX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````:&Y<;F%N,6XH;F!N<6YK;CEN(FXP;E-N96XG;GAN
M9&YW;E5N>6Y2;F9N-6XV;EIN('$><2]Q^W`N<3%Q(W$E<2)Q,G$?<2AQ.G$;
M<4MR6G*(<HERAG*%<HMR$G,+<S!S(G,Q<S-S)W,R<RUS)G,C<S5S#',N="QT
M,'0K=!9T````````````````````````````````````````````````````
M```````````````````````````````````````:="%T+70Q="1T(W0=="ET
M('0R=/MT+W5O=6QUYW7:=>%UYG7===]UY'77=95VDG;:=D9W1W=$=TUW17=*
M=TYW2W=,=]YW['=@>&1X97A<>&UX<7AJ>&YX<'AI>&AX7GAB>'1Y<WER>7!Y
M`GH*>@-Z#'H$>IEZYGKD>DI[.WM$>TA[3'M.>T![6'M%>Z)\GGRH?*%\6'UO
M?6-]4WU6?6=]:GU/?6U]7'UK?5)]5'UI?5%]7WU.?3Y_/W]E?P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!F?Z)_H'^A?]=_48!/
M@%"`_H#4@$.!2H%2@4^!1X$]@4V!.H'F@>Z!]X'X@?F!!((\@CV"/X)U@CN#
MSX/Y@R.$P(/H@Q*$YX/D@_R#]H,0A,:#R(/K@^.#OX,!A-V#Y8/8@_^#X8/+
M@\Z#UH/U@\F#"80/A-Z#$80&A,*#\X,`````````````````````````````
M````````````````````````````````````````````````````````````
M`-6#^H/'@]&#ZH,3A,.#[(/N@\2#^X/7@^*#&X3;@_Z#V(;BAN:&TX;CAMJ&
MZH;=ANN&W(;LANF&UX;HAM&&2(A6B%6(NHC7B+F(N(C`B+Z(MHB\B+>(O8BR
MB`&)R8B5B9B)EXG=B=J)VXE.BDV*.8I9BD"*5XI8BD2*18I2BDB*48I*BDR*
M3XI?C(&,@(RZC+Z,L(RYC+6,A(V`C8F-V(W3C<V-QXW6C=R-SXW5C=F-R(W7
MC<6-[X[WCOJ.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/F.YH[NCN6.]8[GCNB.]H[KCO&.[([TCNF.+9`TD"^0!I$LD021_Y#\
MD`B1^9#[D`&1`)$'D061`Y%AD6217Y%BD6"1`9(*DB62`Y(:DB:2#Y(,D@"2
M$I+_D?V1!I($DB>2`I(<DB22&9(7D@62%I)[E8V5C)60E8>6?I:(E@``````
M````````````````````````````````````````````````````````````
M````````````````````````B9:#EH"6PI;(EL.6\9;PEFR7<)=NEP>8J9CK
MF.:<^9Z#3H1.MDZ]4+]0QE"N4,10RE"T4,A0PE"P4,%0NE"Q4,M0R5"V4+A0
MUU%Z4GA2>U)\4L-5VU7,5=!5RU7*5=U5P%745<15Z56_5=)5C57/5=55XE76
M5<A5\E7-5=E5PE445U-8:%AD6$]835A)6&]855A.6%U865AE6%M8/5AC6'%8
M_%C'6L1:RUJZ6KA:L5JU6K!:OUK(6KM:QEH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````MUK`6LI:M%JV6LU:N5J06M9;V%O96Q]<
M,UQQ76-=2EUE77)=;%U>76A=9UUB7?!=3UY.7DI>35Y+7L5>S%[&7LM>QUY`
M7Z]?K5_W8$EA2F$K845A-F$R82YA1F$O84]A*6%`82!B:)$C8B5B)&+%8_%C
MZV,09!)D"60@9"1D````````````````````````````````````````````
M```````````````````````````````````````````````S9$-D'V059!AD
M.60W9")D(V0,9"9D,&0H9$%D-60O9`ID&F1`9"5D)V0+9.=C&V0N9"%D#F1O
M99)ETV6&9HQFE6:09HMFBF:99I1F>&8@9V9I7VDX:4YI8FEQ:3]I16EJ:3EI
M0FE7:5EI>FE(:4EI-6EL:3-I/6EE:?!H>&DT:6EI0&EO:41I=FE8:4%I=&E,
M:3MI2VDW:5QI3VE1:3)I4FDO:7MI/&E&:T5K0VM":TAK06N;:PWZ^VO\:P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#Y:_=K^&N;
M;M9NR&Z/;L!NGVZ3;I1NH&ZQ;KENQF[2;KUNP6Z>;LENMVZP;LUNIF[/;K)N
MOF[#;MQNV&Z9;I)NCFZ-;J1NH6Z_;K-NT&[*;I=NKFZC;D=Q5'%2<6-Q8'%!
M<5UQ8G%R<7AQ:G%A<4)Q6'%#<4MQ<'%?<5!Q4W$`````````````````````
M````````````````````````````````````````````````````````````
M`````````$1Q37%:<4]RC7*,<I%RD'*.<CQS0G,[<SIS0'-*<TES1'1*=$MT
M4G11=%=T0'1/=%!T3G1"=$9T3714=.%T_W3^=/UT'75Y=7=U@VGO=0]V`W;W
M=?YU_'7Y=?AU$';[=?9U[77U=?UUF7:U=MUV57=?=V!W4G=6=UIW:7=G=U1W
M67=M=^!WAWB:>)1XCWB$>)5XA7B&>*%X@WAY>)EX@'B6>'MX?'F">7UY>7D1
M>AAZ&7H2>A=Z%7HB>A-Z````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````!MZ$'JC>J)ZGGKK>F9[9'MM>W1[:7MR>V5[<WMQ>W![87MX
M>W9[8WNR?+1\KWR(?89]@'V-?7]]A7UZ?8Y]>WV#?7Q]C'V4?81]?7V2?6U_
M:W]G?VA_;'^F?Z5_IW_;?]Q_(8!D@6"!=X%<@6F!6X%B@7*!(6=>@7:!9X%O
M@0``````````````````````````````````````````````````````````
M````````````````````````````````1(%A@1V"28)$@D""0H)%@O&$/X16
MA':$>82/A(V$9811A$"$AH1GA#"$381]A%J$681TA'.$780'A5Z$-X0ZA#2$
M>H1#A'B$,H1%A"F$V8-+A"^$0H0MA%^$<(0YA$Z$3(12A&^$Q82.A#N$1X0V
MA#.$:(1^A$2$*X1@A%2$;H10A`N'!(?WA@R'^H;6AO6&38?XA@Z'"8<!A_:&
M#8<%A]:(RXC-B,Z(WHC;B-J(S(C0B(6)FXG?B>6)Y(D`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````X8G@B>*)W(GFB7:*AHI_BF&*
M/XIWBH**A(IUBH.*@8ITBGJ*/(Q+C$J,98QDC&:,AHR$C(6,S(QHC6F-D8V,
MC8Z-CXV-C9.-E(V0C9*-\(W@C>R-\8WNC="-Z8WCC>*-YXWRC>N-](T&C_^.
M`8\`CP6/!X\(CP*/"X]2D#^0````````````````````````````````````
M``````````````````````````````````````````````````````!$D$F0
M/9`0D0V1#Y$1D1:1%)$+D0Z1;I%OD4B24I(PDCJ29I(SDF627I*#DBZ22I)&
MDFV2;))/DF"29Y)ODC:289)PDC&25))CDE"2<I).DE.23))6DC*2GY6<E9Z5
MFY62EI.6D9:7ELZ6^I;]EOB6]99SEW>7>)=REP^8#9@.F*R8]ICYF*^9LIFP
MF;69K9JKFEN;ZISMG.><@)[]GN90U%#74.A0\U#;4.I0W5#D4--0[%#P4.]0
MXU#@4```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#8
M48!2@5+I4NM2,%.L4R=6%58,5A)6_%4/5AQ6`5835@)6^E4=5@16_U7Y58E8
M?%B06)A8AEB!6']8=%B+6'I8AUB16(Y8=EB"6(A8>UB46(]8_EAK6=Q:[EKE
M6M5:ZEK:6NU:ZUKS6N):X%K;6NQ:WEK=6ME:Z%K?6G=;X%L`````````````
M````````````````````````````````````````````````````````````
M`````````````````.-;8UR"78!=?5V&77I=@5UW78I=B5V(77Y=?%V-77E=
M?UU87EE>4U[87M%>UU[.7MQ>U5[97M)>U%Y$7T-?;U^V7RQA*&%!85YA<6%S
M85)A4V%R86QA@&%T851A>F%;865A.V%J86%A5F$I8B=B*V(K9$UD6V1=9'1D
M=F1R9'-D?61U9&9DIF1.9()D7F1<9$MD4V1@9%!D?V0_9&QD:V199&5D=V1S
M9:!EH6:@9I]F!6<$9R)GL6FV:<EI````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````*!ISFF6:;!IK&F\:9%IF6F.::=IC6FI:;YIKVF_
M:<1IO6FD:=1IN6G*:9IISVFS:9-IJFFA:9YIV6F7:9!IPFFU::5IQFE*:TUK
M2VN>:Y]KH&O#:\1K_FO.;O5N\6X#;R5O^&XW;_MN+F\);TYO&6\:;R=O&&\[
M;Q)O[6X*;P``````````````````````````````````````````````````
M````````````````````````````````````````-F]S;_EN[FXM;T!O,&\\
M;S5OZVX';PYO0V\%;_UN]FXY;QQO_&XZ;Q]O#6\>;PAO(6^'<9!QB7&`<85Q
M@G&/<7MQAG&!<9=Q1')3<I=RE7*3<D-S37-1<TQS8G1S='%T=71R=&=T;G0`
M=0)U`W5]=9!U%G8(=@QV%781=@IV%':X=H%W?'>%=X)W;G>`=V]W?G>#=[)X
MJGBT>*UXJ'A^>*MXGGBE>*!XK'BB>*1XF'F*>8MYEGF5>91YDWD`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````EWF(>9)YD'DK>DIZ
M,'HO>BAZ)GJH>JMZK'KN>HA[G'N*>Y%[D'N6>XU[C'N;>XY[A7N8>X12F7ND
M>X)[NWR_?+Q\NGRG?;=]PGVC?:I]P7W`?<5]G7W.?<1]QGW+?<Q]KWVY?99]
MO'V??:9]KGVI?:%]R7US?^)_XW_E?]Y_````````````````````````````
M````````````````````````````````````````````````````````````
M```D@%V`7(")@8:!@X&'@8V!C(&+@16"EX2DA*&$GX2ZA,Z$PH2LA*Z$JX2Y
MA+2$P83-A*J$FH2QA-"$G82GA+N$HH24A,>$S(2;A*F$KX2HA-:$F(2VA,^$
MH(37A-2$TH3;A+"$D81AAC.'(X<HAVN'0(<NAQZ'(8<9AQN'0X<LAT&'/H=&
MAR"',H<JARV'/(<2ASJ',8<UAT*')H<GASB')(<:AS"'$8?WB.>(\8CRB/J(
M_HCNB/R(]HC[B```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#PB.R(ZXB=B:&)GXF>B>F)ZXGHB:N*F8J+BI**CXJ6BCV,:(QIC-6,
MSXS7C):-"8X"CO^-#8[]C0J.`XX'C@:.!8[^C0".!(X0CQ&/#H\-CR.1')$@
MD2*1'Y$=D1J1))$AD1N1>I%RD7F1<Y&EDJ22=I*;DGJ2H)*4DJJ2C9(`````
M````````````````````````````````````````````````````````````
M`````````````````````````*:2FI*KDGF2EY)_DJ.2[I*.DH*2E9*BDGV2
MB)*ADHJ2AI*,DIF2IY)^DH>2J9*=DHN2+9*>EJ&6_Y98EWV7>I=^EX.7@)>"
MEWN7A)>!EW^7SI?-EQ:8K9BNF`*9`)D'F9V9G)G#F;F9NYFZF<*9O9G'F;&:
MXYKGFCZ;/YM@FV&;7YOQG/*<]9RGGO]0`U$P4?A0!E$'4?90_E`+40Q1_5`*
M48M2C%+Q4N]22%9"5DQ6-59!5DI6259&5EA6````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````%I60%8S5CU6+%8^5CA6*E8Z5AI7JUB=
M6+%8H%BC6*]8K%BE6*%8_UC_6O1:_5KW6O9:`UOX6@);^5H!6P=;!5L/6V=<
MF5V779]=DEVB79-=E5V@79Q=H5V:79Y=:5Y=7F!>7%[S?=M>WE[A7DE?LE^+
M88-A>6&Q8;!AHF&)80``````````````````````````````````````````
M````````````````````````````````````````````````FV&38:]AK6&?
M89)AJF&A88UA9F&S82UB;F1P9)9DH&2%9)=DG&2/9(MDBF2,9*-DGV1H9+%D
MF&1V97IE>65[9;)ELV6U9K!FJ6:R9K=FJF:O9@!J!FH7:N5I^&D5:O%IY&D@
M:O]I[&GB:1MJ'6K^:2=J\FGN:11J]VGG:4!J"&KF:?MI#6K\:>MI"6H$:AAJ
M)6H/:O9I)FH':O1I%FI1:Z5KHVNB:Z9K`6P`;/]K`FQ!;R9O?F^';\9ODF\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````C6^);XQO
M8F]/;X5O6F^6;W9O;&^";U5O<F]2;U!O5V^4;Y-O76\`;V%O:V]];V=OD&]3
M;XMO:6]_;Y5O8V]W;VIO>V^R<:]QFW&P<:!QFG&I<;5QG7&E<9YQI'&A<:IQ
MG'&G<;-QF'*:<EAS4G-><U]S8'-=<UMS87-:<UES````````````````````
M````````````````````````````````````````````````````````````
M``````````!B<X=TB72*=(9T@71]=(5TB'1\='ET"'4'=7YU)78>=AEV'78<
M=B-V&G8H=AMVG':==IYVFW:-=X]WB7>(=\UXNWC/>,QXT7C.>-1XR'C#>,1X
MR7B:>:%YH'F<>:)YFWEV:SEZLGJT>K-ZMWO+>[Y[K'O.>Z][N7O*>[5[Q7S(
M?,Q\RWSW?=M]ZGWG?==]X7T#?OI]YGWV??%]\'WN?=]]=G^L?[!_K7_M?^M_
MZG_L?^9_Z']D@&>`HX&?@0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````">@96!HH&9@9>!%H)/@E."4H)0@DZ"48(DA3N%#X4`A2F%
M#H4)A0V%'X4*A2>%'(7[A"N%^H0(A0R%](0JA?*$%87WA.N$\X3\A!*%ZH3I
MA!:%_H0HA1V%+H4"A?V$'H7VA#&%)H7GA.B$\(3OA/F$&(4@A3"%"X49A2^%
M8H8`````````````````````````````````````````````````````````
M`````````````````````````````````%:'8X=DAW>'X8=SAUB'5(=;AU*'
M88=:AU&'7H=MAVJ'4(=.AU^'78=OAVR'>H=NAUR'98=/AWN'=8=BAV>':8=:
MB`6)#(D4B0N)%XD8B1F)!HD6B1&)#HD)B:*)I(FCB>V)\(GLB<^*QHJXBM.*
MT8K4BM6*NXK7BKZ*P(K%BMB*PXJZBKV*V8H^C$V,CXSEC-^,V8SHC-J,W8SG
MC*"-G(VAC9N-((XCCB6.)(XNCA6.&XX6CA&.&8XFCB>.````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````!2.$HX8CA..'(X7CAJ.+(\D
MCQB/&H\@CR./%H\7CW.0<)!OD&>0:Y`OD2N1*9$JD3*1)I$ND861AI&*D8&1
M@I&$D8"1T)+#DL22P)+9DK:2SY+QDM^2V)+IDM>2W9+,DN^2PI+HDLJ2R)+.
MDN:2S9+5DLF2X)+>DN>2T9+3D@``````````````````````````````````
M````````````````````````````````````````````````````````M9+A
MDL:2M))\E:R5JY6NE;"5I):BEM.6!9<(EP*76I>*EXZ7B)?0E\^7'I@=F":8
M*9@HF""8&Y@GF+*8")GZF!&9%)D6F1>9%9G<F<V9SYG3F=29SIG)F=:9V)G+
MF=>9S)FSFNR:ZYKSFO*:\9I&FT.;9YMTFW&;9IMVFW6;<)MHFV2;;)O\G/J<
M_9S_G/><!YT`G?F<^YP(G06=!)V#GM.>#Y\0GQQ1$U$741I1$5'>4313X5-P
M5F!6;E8`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M<U9F5F-6;59R5EY6=U8<5QM7R%B]6,E8OUBZ6,)8O%C&6!=;&5L;6R%;%%L3
M6Q!;%ELH6QI;(%L>6^];K%VQ7:E=IUVU7;!=KEVJ7:A=LEVM7:]=M%UG7FA>
M9EYO7NE>YU[F7NA>Y5Y+7[Q?G6&H899AQ6&T8<9AP6',8;IA````````````
M````````````````````````````````````````````````````````````
M``````````````````"_8;AAC&'79-9DT&3/9,EDO62)9,-DVV3S9-ED,V5_
M97QEHF7(9KYFP&;*9LMFSV:]9KMFNF;,9B-G-&IF:DEJ9VHR:FAJ/FI=:FUJ
M=FI;:E%J*&I::CMJ/VI!:FIJ9&I0:D]J5&IO:FEJ8&H\:EYJ5FI5:DUJ3FI&
M:E5K5&M6:Z=KJFNK:\AKQVL$;`-L!FRM;\MOHV_';[QOSF_(;UYOQ&^];YYO
MRF^H;P1PI6^N;[IOK&^J;\]OOV^X;P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"B;\EOJV_-;Z]OLF^P;\5QPG&_<;AQUG'`<<%Q
MRW'4<<IQQW'/<;UQV'&\<<9QVG';<9URGG)I<V9S9W-L<V5S:W-J<W]TFG2@
M=)1TDG25=*%T"W6`=2]V+78Q=CUV,W8\=C5V,G8P=KMVYG::=YUWH7><=YMW
MHG>C=Y5WF7<`````````````````````````````````````````````````
M`````````````````````````````````````````)=WW7CI>.5XZGC>>.-X
MVWCA>.)X[7C?>.!XI'E$>DAZ1WJV>KAZM7JQ>K=ZWGOC>^=[W7O5>^5[VGOH
M>_E[U'OJ>^)[W'OK>]A[WWO2?-1\UWS0?-%\$GXA?A=^#'X??B!^$WX.?AQ^
M%7X:?B)^"WX/?A9^#7X4?B5^)'Y#?WM_?']Z?[%_[W\J@"F`;("Q@::!KH&Y
M@;6!JX&P@:R!M(&R@;>!IX'R@56"5H)7@E:%185KA4V%4X5AA5B%````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$"%1H5DA4&%8H5$
MA5&%1X5CA3Z%6X5QA4Z%;H5UA56%9X5@A8R%9H5=A52%985LA6.&989DAIN'
MCX>7AY.'DH>(AX&'EH>8AWF'AX>CAX6'D(>1AYV'A(>4AYR'FH>)AQZ))HDP
MB2V)+HDGB3&)(HDIB2.)+XDLB1^)\8G@B@``````````````````````````
M````````````````````````````````````````````````````````````
M````XHKRBO2*]8K=BA2+Y(K?BO"*R(K>BN&*Z(K_BN^*^XJ1C)*,D(SUC.Z,
M\8SPC/.,;(UNC:6-IXTSCCZ..(Y`CD6.-HX\CCV.08XPCC^.O8XVCRZ/-8\R
MCSF/-X\TCW:0>9![D(:0^I`SD361-I&3D9"1D9&-D8^1)Y,>DPB3'Y,&DP^3
M>I,XDSR3&Y,CDQ*3`9-&DRV3#I,-D\N2'9/ZDB63$Y/YDO>2-),"DR23_Y(I
MDSF3-9,JDQ23#),`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````"Y/^D@F3`)/[DA:3O)7-E;Z5N96ZE;:5OY6UE;V5J9;4E@N7$I<0
MEYF7EY>4E_"7^)<UF"^8,I@DF1^9)YDIF9Z9[IGLF>69Y)GPF>.9ZIGIF>>9
MN9J_FK2:NYKVFOJ:^9KWFC.;@)N%FX>;?)M^FWN;@IN3FY*;D)MZFY6;````
M````````````````````````````````````````````````````````````
M``````````````````````````!]FXB;)9T7G2"='IT4G2F='9T8G2*=$)T9
MG1^=B)Z&GH>>KIZMGM6>UI[ZGA*?/9\F4251(E$D42!1*5'T4I-6C%:-5H96
MA%:#5GY6@E9_5H%6UEC46,]8TE@M6R5;,ELC6RQ;)ULF6R];+EM[6_%;\ENW
M76Q>:EZ^7[M?PV&U8;QAYV'@8>5AY&'H8=YA[V3I9.-DZV3D9.AD@66`9;9E
MVF729HUJEFJ!:J5JB6J?:IMJH6J>:H=JDVJ.:@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"5:H-JJ&JD:I%J?VJF:IIJA6J,:I)J
M6VNM:PELS&^I;_1OU&_C;]QO[6_G;^9OWF_R;]UOXF_H;^%Q\7'H<?)QY''P
M<>)Q<W-N<V]SEW2R=*MTD'2J=*UTL72E=*]T$'41=1)U#W6$=4-V2'9)=D=V
MI';I=K5WJW>R=[=WMG<`````````````````````````````````````````
M`````````````````````````````````````````````````+1WL7>H=_!W
M\WC]>`)Y^WC\>/)X!7GY>/YX!'FK>:AY7'I;>E9Z6'I4>EIZOGK`>L%Z!7P/
M?/)[`'S_>_M[#GST>PM\\WL"?`E\`WP!?/A[_7L&?/![\7L0?`I\Z'PM?CQ^
M0GXS?DB8.'XJ?DE^0'Y'?BE^3'XP?CM^-GY$?CI^17]_?WY_?7_T?_)_+("[
M@<2!S('*@<6!QX&\@>F!6X):@ER"@X6`A8^%IX65A:"%BX6CA7N%I(6:A9Z%
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'>%?(6)
MA:&%>H5XA5>%CH66A8:%C869A9V%@86BA8*%B(6%A7F%=H68A9"%GX5HAKZ'
MJH>MA\6'L(>LA[F'M8>\AZZ'R8?#A\*'S(>WAZ^'Q(?*A[2'MH>_A[B'O8?>
MA[*'-8DSB3R)/HE!B5*)-XE"B:V)KXFNB?*)\XD>BP``````````````````
M````````````````````````````````````````````````````````````
M````````````&(L6BQ&+!8L+BR*+#XL2BQ6+!XL-BPB+!HL<BQ.+&HM/C'",
M<HQQC&^,E8R4C/F,;XU.CDV.4XY0CDR.1XY#CT"/A9!^D#B1FI&BD9N1F9&?
MD:&1G9&@D:&3@Y.ODV235I-'DWR36)-<DW:329-0DU&38)-MDX^33)-JDWF3
M5Y-5DU*33Y-QDW>3>Y-ADUZ38Y-GDX"33I-9D\>5P)7)E<.5Q96WE:Z6L):L
MEB"7'Y<8EQV7&9>:EZ&7G)<`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````GI>=E]67U)?QET&81)A*F$F819A#F"69*YDLF2J9,YDR
MF2^9+9DQF3"9F)FCF:&9`IKZF?29]YGYF?B9]IG[F?V9_IG\F0.:OIK^FOV:
M`9O\FDB;FINHFYZ;FYNFFZ&;I9NDFX:;HIN@FZ^;,YU!G6>=-ITNG2^=,9TX
MG3"=````````````````````````````````````````````````````````
M``````````````````````````````````!%G4*=0YT^G3>=0)T]G?5_+9V*
MGHF>C9ZPGLB>VI[[GO^>))\CGR*?5)^@GS%1+5$N49A6G%:75II6G5:95G!9
M/%MI7&I<P%UM7FY>V&'?8>UA[F'Q8>IA\&'K8=9AZ6'_9`1E_63X9`%E`V7\
M9)1EVV7:9MMFV&;%:KEJO6KA:L9JNFJV:K=JQVJT:JUJ7FO):PML!W`,<`UP
M`7`%<!1P#G#_;P!P^V\F</QO]V\*<`%R_W'Y<0-R_7%V<P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"X=,!TM73!=+YTMG2[=,)T
M%'43=5QV9'99=E!V4W97=EIVIG:]=NQVPG>Z=_]X#'D3>11Y"7D0>1)Y$7FM
M>:QY7WH<?"E\&7P@?!]\+7P=?"9\*'PB?"5\,'Q<?E!^5GYC?EA^8GY??E%^
M8'Y7?E-^M7^S?_=_^']U@-&!TH$`````````````````````````````````
M`````````````````````````````````````````````````````````-"!
M7X)>@K2%QH7`A<.%PH6SA;6%O87'A<2%OX7+A<Z%R(7%A;&%MH72A22&N(6W
MA;Z%:8;GA^:'XH?;A^N'ZH?EA]^'\X?DA]2'W(?3A^V'V(?CAZ2'UX?9AP&(
M](?HA]V'4XE+B4^)3(E&B5")48E)B2J+)XLCBS.+,(LUBT>++XL\BSZ+,8LE
MBS>+)HLVBRZ+)(L[BSV+.HM"C'6,F8R8C)>,_HP$C0*-`(U<CF*.8(Y7CE:.
M7HYECF>.````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%N.6HYACEV.:8Y4CD:/1X](CTN/*)$ZD3N1/I&HD:61IY&OD:J1M9.,DY*3
MMY.;DYV3B9.GDXZ3JI.>DZ:3E9.(DYF3GY.-D[&3D9.RDZ23J).TDZ.3I9/2
ME=.5T96SEM>6VI;"7=^6V);=EB.7(I<EEZR7KI>HEZN7I)>JEP``````````
M````````````````````````````````````````````````````````````
M````````````````````HI>EE]>7V9?6E]B7^I=0F%&84IBXF$&9/)DZF0^:
M"YH)F@V:!)H1F@J:!9H'F@::P)K<F@B;!)L%FRF;-9M*FTR;2YO'F\:;PYN_
MF\&;M9NXF].;MIO$F[F;O9M<G5.=3YU*G5N=2YU9G5:=3)U7G5*=5)U?G5B=
M6IV.GHR>WYX!GP"?%I\EGRN?*I\IGRB?3)]5GS11-5&64O=2M%.K5JU6IE:G
M5JI6K%;:6-U8VU@263U;/EL_6\-=<%X`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````OU_[80=E$&4-90EE#&4.981EWF7=9=YFYVK@
M:LQJT6K9:LMJWVK<:M!JZVK/:LUJWFI@:[!K#&P9<"=P('`6<"MP(7`B<"-P
M*7`7<"1P''`J<`QR"G('<@)R!7*E<J9RI'*C<J%RRW3%=+=TPW06=6!VR7?*
M=\1W\7<=>1MY````````````````````````````````````````````````
M```````````````````````````````````````````A>1QY%WD>>;!Y9WIH
M>C-\/'PY?"Q\.WSL?.I\=GYU?GA^<'YW?F]^>GYR?G1^:'Y+?TI_@W^&?[=_
M_7_^?WB`UX'5@62"88)C@NN%\87MA=F%X87HA=J%UX7LA?*%^(78A=^%XX7<
MA=&%\(7FA>^%WH7BA0"(^H<#B/:']X<)B`R("X@&B/R'"(C_APJ(`HABB5J)
M6XE7B6&)7(E8B5V)68F(B;>)MHGVB5"+2(M*BT"+4XM6BU2+2XM5BP``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!1BT*+4HM7BT.,
M=XQVC)J,!HT'C0F-K(VJC:V-JXUMCGB.<XYJCF^.>X["CE*/48]/CU"/4X^T
MCT"1/Y&PD:V1WI/'D\^3PI/:D]"3^9/LD\R3V9.ID^:3RI/4D^Z3XY/5D\23
MSI/`D]*3YY-]E=J5VY7AEBF7*Y<LERB7)I<`````````````````````````
M````````````````````````````````````````````````````````````
M`````+.7MY>VE]V7WI??EUR869A=F%>8OYB]F+N8OIA(F4>90YFFF:>9&IH5
MFB6:'9HDFAN:(IH@FB>:(YH>FAR:%)K"F@N;"IL.FPR;-YOJF^N;X)O>F^2;
MYIOBF_";U)O7F^R;W)O9F^6;U9OAF]J;=YV!G8J=A)V(G7&=@)UXG8:=BYV,
MG7V=:YUTG76=<)UIG86=<YU[G8*=;YUYG7^=AYUHG92>D9[`GOR>+9]`GT&?
M39]6GU>?6)\W4[)6````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+56LU;C6$5;QEW'7>Y>[U[`7\%?^6$7919E%6439=]EZ&;C9N1F
M\VKP:NIJZ&KY:O%J[FKO:CQP-7`O<#=P-'`Q<$)P.'`_<#IP.7!`<#MP,W!!
M<!-R%'*H<GUS?'.Z=*MVJG:^=NUVS'?.=\]WS7?R=R5Y(WDG>2AY)'DI>0``
M````````````````````````````````````````````````````````````
M````````````````````````````LGEN>FQZ;7KW>DE\2'Q*?$=\17SN?'M^
M?GZ!?H!^NG__?WF`VX'9@0N":()I@B*&_X4!AOZ%&X8`AO:%!(8)A@6&#(;]
MA1F($(@1B!>($X@6B&.)9HFYB?>)8(MJBUV+:(MCBV6+9XMMBZZ-AHZ(CH2.
M68]6CU>/58]8CUJ/C9!#D4&1MY&UD;*1LY$+E!.4^Y,@E`^4%)3^DQ64$)0H
ME!F4#93UDP"4]Y,'E`Z4%I02E/J3"93XDPJ4_Y,`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````_),,E/:3$90&E-Z5X)7?E2Z7+Y>Y
ME[N7_9?^EV"88IACF%^8P9C"F%"93IE9F4R92YE3F3*:-)HQFBR:*IHVFBF:
M+IHXFBV:QYK*FL::$)L2FQ&;"YP(G/>;!9P2G/B;0)P'G`Z<!IP7G!2<"9R?
MG9F=I)V=G9*=F)V0G9N=````````````````````````````````````````
M``````````````````````````````````````````````````"@G92=G)VJ
MG9>=H9V:G:*=J)V>G:.=OYVIG9:=IIVGG9F>FYZ:GN6>Y)[GGN:>,)\NGUN?
M8)]>GUV?69^1GSI1.5&84I=2PU:]5KY62%M'6\M=SUWQ7OUA&V4":_QJ`VOX
M:@!K0W!$<$IP2'!)<$5P1G`=<AIR&7)^<Q=U:G;0=RUY,7DO>51\4WSR?(I^
MAWZ(?HM^AGZ-?DU_NW\P@-V!&(8JAB:&'X8CAAR&&88GABZ&(88@ABF&'H8E
MA@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````IB!V(
M&X@@B"2('(@KB$J(;8EIB6Z):XGZB7F+>(M%BWJ+>XL0C12-KXV.CHR.7H];
MCUV/1I%$D461N9$_E#N4-I0IE#V4/)0PE#F4*I0WE"R40)0QE.65Y)7CE367
M.I>_E^&79)C)F,:8P)A8F5:9.9H]FD::1)I"FD&:.IH`````````````````
M````````````````````````````````````````````````````````````
M`````````````#^:S9H5FQ>;&)L6FSJ;4ILKG!V<')PLG".<*)PIG"2<(9RW
MG;:=O)W!G<>=RIW/G;Z=Q9W#G;N=M9W.G;F=NIVLG<B=L9VMG<R=LYW-G;*=
M>IZ<GNN>[I[MGAN?&)\:GS&?3I]EGV2?DI^Y3L96Q5;+5G%92UM,6]5=T5WR
M7B%E(&4F92)E"VL(:PEK#6Q5<%9P5W!2<!YR'W*I<G]SV'35=-ETUW1M=JUV
M-7FT>7!Z<7I7?%Q\67Q;?%I\````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/1\\7R1?D]_AW_>@6N"-(8UAC.&+(8RAC:&+(@HB":(
M*H@EB'&)OXF^B?N)?HN$BX*+AHN%BW^+%8V5CI2.FHZ2CI".EHZ7CF"/8H]'
MD4R44)1*E$N43Y1'E$642)1)E$:4/Y?CEVJ8:9C+F%296YE.FE.:5)I,FD^:
M2)I*F@``````````````````````````````````````````````````````
M````````````````````````````````````29I2FE":T)H9FRN;.YM6FU6;
M1IQ(G#^<1)PYG#.<09P\G#><-)PRG#V<-IS;G=*=WIW:G<N=T)W<G=&=WYWI
MG=F=V)W6G?6=U9W=G;:>\)XUGS.?,I]"GVN?E9^BGSU1F5+H6.=8<EE-6]A=
M+XA/7P%B`V($8BEE)6669>MF$6L2:P]KRFM;<%IP(G*"<X%S@W-P=M1W9WQF
M?)5^;((ZAD"&.88\AC&&.X8^AC"(,H@NB#.(=HETB7.)_HD`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````C(N.BXN+B(M%C!F-F(YD
MCV./O)%BE%647917E%Z4Q)?%EP"85II9FAZ;'YL@FU*<6)Q0G$J<39Q+G%6<
M69Q,G$Z<^YWWG>^=XYWKG?B=Y)WVG>&=[IWFG?*=\)WBG>R=])WSG>B=[9W"
MGM">\I[SG@:?')\XGS>?-I]#GT^?````````````````````````````````
M``````````````````````````````````````````````````````````!Q
MGW"?;I]OG]-6S59.6VU<+67M9NYF$VM?<&%P77!@<"-RVW3E=-5W.'FW>;9Y
M:GR7?HE_;8)#ACB(-X@UB$N(E(N5BYZ.GXZ@CIV.OI&]D<*1:Y1HE&F4Y99&
MET.71Y?'E^677IK5FEF;8YQGG&:<8IQ>G&"<`I[^G0>>`YX&G@6>`)X!G@F>
M_YW]G02>H)X>GT:?=)]UGW:?U%8N9;AE&&L9:Q=K&FMB<"9RJG+8=]EW.7EI
M?&M\]GR:?@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"8?IM^F7[@@>&!1H9'ADB&>8EZB7R)>XG_B9B+F8NECJ2.HXYNE&V4;Y1Q
ME'.429=RF%^9:)QNG&V<"YX-GA">#YX2GA&>H9[UG@F?1Y]XGWN?>I]YGQY7
M9G!O?#R(LHVFCL.1=)1XE':4=91@FG2<<YQQG'6<%)X3GO:>"I\`````````
M````````````````````````````````````````````````````````````
M`````````````````````*2?:'!E</=\:H8^B#V(/XB>BYR,J8[)CDN7<YAT
MF,R889FKF62:9IIGFB2;%9X7GDB?!V(>:R=R3(:HCH*4@)2!E&F::)HNFQF>
M*7)+AI^+@Y1YG+>>=79KFGJ<'9YI<&IPI)Y^GTF?F)\`````````````````
M```````````P#/\!,`(P#O\B(!O_&O\?_P'_,/XF("4@4/YD_U+^MP!4_E7^
M5OY7_ES_$R`Q_A0@,_[]_S3^3_X(_PG_-?XV_EO_7?\W_CC^%#`5,#G^.OX0
M,!$P._X\_@HP"S`]_C[^"#`),#_^0/X,,`TP0?Y"_@XP#S!#_D3^6?Y:_@``
M````````````````````````````````````````````````````````````
M````````````````````````````6_Y<_EW^7OX8(!D@'"`=(!TP'C`U(#(@
M`_\&_PK_.R"G``,PRR7/);,ELB7.)08F!2;')<8EH26@);TEO"6C,@4A/B#]
M_S___?])_DK^3?Y._DO^3/Y?_F#^8?X+_PW_UP#W`+$`&B(<_Q[_'?]F(F<B
M8"(>(E(B82)B_F/^9/YE_F;^/"(I(BHBI2(@(A\BOR+2,]$S*R(N(C4B-")`
M)D(F028))I$ADR&0(9(AEB&7(9DAF"$E(B,B_?\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````_?\/_SS_!/^E`!(PH@"C``7_(/\#
M(0DA:?YJ_FO^U3.<,YTSGC/.,Z$SCC./,\0SL`!945M17E%=46%18U'G5>ET
MSGR!)8(E@R6$)84EAB6')8@ECR6.)8TEC"6+)8HEB24\)30E+"4D)1PEE"4`
M)0(EE24,)1`E%"48)6TE````````````````````````````````````````
M``````````````````````````````````````````````````!N)7`E;R50
M)5XE:B5A)>(EXR7E)>0E<25R)7,E$/\1_Q+_$_\4_Q7_%O\7_QC_&?]@(6$A
M8B%C(60A92%F(6<A:"%I(2$P(C`C,"0P)3`F,"<P*#`I,/W_1%/]_R'_(O\C
M_R3_)?\F_R?_*/\I_RK_*_\L_RW_+O\O_S#_,?\R_S/_-/\U_S;_-_\X_SG_
M.O]!_T+_0_]$_T7_1O]'_TC_2?]*_TO_3/]-_T[_3_]0_U'_4O]3_U3_5?]6
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!7_UC_
M6?]:_Y$#D@.3`Y0#E0.6`Y<#F`.9`YH#FP.<`YT#G@.?`Z`#H0.C`Z0#I0.F
M`Z<#J`.I`[$#L@.S`[0#M0.V`[<#N`.Y`[H#NP.\`[T#O@._`\`#P0/#`\0#
MQ0/&`\<#R`/)`P4Q!C$',0@Q"3$*,0LQ##$-,0XQ#S$`````````````````
M````````````````````````````````````````````````````````````
M`````````````!`Q$3$2,1,Q%#$5,18Q%S$8,1DQ&C$;,1PQ'3$>,1\Q(#$A
M,2(Q(S$D,24Q)C$G,2@Q*3'9`LD"R@+'`LL"````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.64X!3@-.0TY=3H9.C$ZZ3C]195%K4>!1`%(!4IM2
M%5-!4UQ3R%,)3@M."$X*3BM..$[A445.2$Y?3EY.CDZA3D!1`U+Z4D-3R5/C
M4Q]7ZU@562=9<UE06U%;4UOX6P]<(EPX7'%<W5WE7?%=\EWS7?Y=<E[^7@M?
M$U]-8@``````````````````````````````````````````````````````
M````````````````````````````````````$4X03@U.+4XP3CE.2TXY7(A.
MD4Z53I).E$ZB3L%.P$[#3L9.QT[-3LI.RT[$3D-105%G46U1;E%L49=1]E$&
M4@=2"%+[4OY2_U(64SE32%-'4T537E.$4\M3RE/-4^Q8*5DK62I9+5E46Q%<
M)%PZ7&]<]%U[7O]>%%\57\-?"&(V8DMB3F(O98=EEV6D9;EEY67P9@AG*&<@
M:V)K>6O+:]1KVVL/;#1L:W`J<C9R.W)'<EER6W*L<HMS&4X`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````%DX53A1.&$X[3DU.3TY.
M3N5.V$[43M5.UD[73N-.Y$[93MY.15%$48E1BE&L4?E1^E'X40I2H%*?4@53
M!E,74QU3WTY*4TE385-@4V]3;E.[4^]3Y%/S4^Q3[E/I4^A3_%/X4_53ZU/F
M4^I3\E/Q4_!3Y5/M4_M3VU;:5A99````````````````````````````````
M```````````````````````````````````````````````````````````N
M63%9=%EV655;@UL\7.A=YUWF70)>`UYS7GQ>`5\87Q=?Q5\*8E-B5&)28E%B
MI67F92YG+&<J9RMG+6=C:\UK$6P0;#AL06Q`;#YLKW*$<XESW'3F=!AU'W4H
M=2EU,'4Q=3)U,W6+=7UVKG:_=NYVVW?B=_-W.GF^>71ZRWH>3A].4DY33FE.
MF4ZD3J9.I4[_3@E/&4\*3Q5/#4\03Q%/#T_R3O9.^T[P3O-._4X!3PM/25%'
M44912%%H40``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!Q48U1L%$74A%2$E(.4A92HU((4R%3(%-P4W%3"50/5`Q4"E005`%4"U0$
M5!%4#50(5`-4#E0&5!)4X%;>5MU6,U<P5RA7+5<L5R]7*5<961I9-UDX6819
M>%F#67U9>5F"68%95UM86X=;B%N%6XE;^EL67'E<WET&7G9>=%X`````````
M````````````````````````````````````````````````````````````
M``````````````````````]?&U_97]9?#F(,8@UB$&)C8EMB6&(V9>EEZ&7L
M9>UE\F;S9@EG/6<T9S%G-6<A:V1K>VL6;%UL5VQ9;%]L8&Q0;%5L86Q;;$UL
M3FQP<%]R77)^=OEZ<WSX?#9_BG^]?P&``X`,@!*`,X!_@(F`BX",@..!ZH'S
M@?R!#((;@A^";H)R@GZ":X9`B$R(8XA_B2&6,DZH3DU/3T]'3U=/7D\T3UM/
M54\P3U!/44\]3SI/.$]#3U1//$]&3V-/````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````%Q/8$\O3TY/-D]93UU/2$]:3TQ12U%-4751
MME&W4252)%(I4BI2*%*K4JE2JE*L4B-3<U-U4QU4+50>5#Y4)E1.5"=41E1#
M5#-42%1"5!M4*51*5#E4.U0X5"Y4-50V5"!4/%1`5#%4*U0?5"Q4ZE;P5N16
MZU9*5U%70%=-5P``````````````````````````````````````````````
M````````````````````````````````````````````1U=.5SY74%=/5SM7
M[U@^69U9DEFH69Y9HUF96999C5FD69-9BEFE65U;7%M:6UM;C%N+6X];+%Q`
M7$%</UP^7)!<D5R47(Q<ZUT,7H]>AUZ*7O=>!%\?7V1?8E]W7WE?V%_,7]=?
MS5_Q7^M?^%_J7Q)B$6*$8I=BEF*`8G9BB6)M8HIB?&)^8GEB<V*28F]BF&)N
M8I5BDV*18H9B.64[93AE\67T9E]G3F=/9U!G46=<9U9G7F=)9T9G8&<`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````4V=79V5KSVM"
M;%YLF6R!;(ALB6R%;)ML:FQZ;)!L<&R,;&ALEFR2;'UL@VQR;'YL=&R&;'9L
MC6R4;)AL@FQV<'QP?7!X<&)R87)@<L1RPG*6<RQU*W4W=3AU@G;O=N-WP7G`
M>;]Y=GK[?%5_EH"3@)V`F(";@)J`LH!O@I*"````````````````````````
M````````````````````````````````````````````````````````````
M``````"+@HV"BXG2B0"*-XQ&C%6,G8QDC7"-LXVKCLJ.FX^PC\*/QH_%C\2/
MX5V1D**0JI"FD*.029'&D<R1,I8NEC&6*I8LEB9.5DYS3HM.FTZ>3JM.K$YO
M3YU/C4]S3W]/;$^;3XM/AD^#3W!/=4^(3VE/>T^63WY/CT^13WI/5%%24551
M:5%W4791>%&]4?U1.U(X4C=2.E(P4BY2-E)!4KY2NU)24U134U-14V93=U-X
M4WE3UE/44]=3<U1U5```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"65'A4E52`5'M4=U2$5))4AE1\5)!4<51V5(Q4FE1B5&A4BU1]
M5(Y4^E:#5W=7:E=I5V%79E=D5WQ7'%E)64=92%E$6519OEF[6=19N5FN6=%9
MQEG06<U9RUG36<I9KUFS6=)9Q5E?6V1;8UN76YI;F%N<6YE;FUL:7$A<15P`
M````````````````````````````````````````````````````````````
M`````````````````````````````$9<MURA7+A<J5RK7+%<LUP87AI>%EX5
M7AM>$5YX7II>EUZ<7I5>EE[V7B9?)U\I7X!?@5]_7WQ?W5_@7_U?]5__7P]@
M%&`O8#5@%F`J8!5@(6`G8"E@*V`;8!9B%6(_8CYB0&)_8LEBS&+$8K]BPF*Y
M8M)BVV*K8M-BU&++8LABJ&*]8KQBT&+98L=BS6*U8MIBL6+88M9BUV+&8JQB
MSF(^9:=EO&7Z911F$V8,9@9F`F8.9@!F#V859@IF````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````=F#6<+9VUGBV>59W%GG&=S9W=G
MAV>=9Y=G;V=P9W]GB6=^9Y!G=6>:9Y-G?&=J9W)G(VMF:V=K?VL3;!MLXVSH
M;/-LL6S,;.5LLVR];+YLO&SB;*MLU6S3;+ALQ&RY;,%LKFS7;,5L\6R_;+ML
MX6S;;,ILK&SO;-QLUFS@;```````````````````````````````````````
M````````````````````````````````````````````````````E7".<))P
MBG"9<"QR+7(X<DAR9W)I<L!RSG+9<M=RT'*I<ZASGW.K<Z5S/76==9EUFG6$
M=L)V\G;T=N5W_7<^>4!Y07G)><AY>GIY>OIZ_GQ4?XQ_BW\%@+J`I8"B@+&`
MH8"K@*F`M("J@*^`Y8'^@0V"LX*=@IF"K8*]@I^"N8*Q@JR"I8*O@KB"HX*P
M@KZ"MX).AG&&'5)HB,N.SH_4C]&/M9"XD+&0MI#'D=&1=Y6`E1R60)8_ECN6
M1)8`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````0I:Y
MENB64I=>EY].K4ZN3N%/M4^O3[]/X$_13\]/W4_#3[9/V$_?3\I/UT^N3]!/
MQ$_"3]I/SD_>3[=/5U&249%1H%%.4D-22E)-4DQ22U)'4L=2R5+#4L%2#5-7
M4WM3FE/;4ZQ4P%2H5,Y4R52X5*94LU3'5,)4O52J5,%4````````````````
M````````````````````````````````````````````````````````````
M``````````````#$5,A4KU2K5+%4NU2I5*=4OU3_5H)7BU>@5Z-7HE?.5ZY7
MDU=565%93UE.65!9W%G86?]9XUGH60-:Y5GJ6=I9YED!6OM9:5NC6Z9;I%NB
M6Z5;`5Q.7$]<35Q+7-E<TESW71U>)5X?7GU>H%ZF7OI>"%\M7V5?B%^%7XI?
MBU^'7XQ?B5\28!U@(&`E8`Y@*&!-8'!@:&!B8$9@0V!L8&M@:F!D8$%BW&(6
M8PEC_&+M8@%C[F+]8@=C\6+W8@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#O8NQB_F+T8A%C`F,_945EJV6]9>)E)68M9B!F)V8O
M9A]F*&8Q9B1F]V;_9]-G\6?49]!G[&>V9Z]G]6?I9^]GQ&?19[1GVF?E9[AG
MSV?>9_-GL&?99^)GW6?29VIK@VN&:[5KTFO7:Q]LR6P+;3)M*FU!;25M#&TQ
M;1YM%VT`````````````````````````````````````````````````````
M`````````````````````````````````````#MM/6T^;39M&VWU;#EM)VTX
M;2EM+FTU;0YM*VVK<+IPLW"L<*]PK7"X<*YPI'`P<G)R;W)T<NERX'+A<K=S
MRG.[<[)SS7/`<[-S&G4M=4]U3'5.=4MUJW6D=:5UHG6C=7AVAG:'=HAVR';&
M=L-VQ78!=_EV^'8)=PMW_G;\=@=WW'<">!1X#'@->$9Y27E(>4=YN7FZ>=%Y
MTGG+>7]Z@7K_>OUZ?7P"?05]`'T)?0=]!'T&?3A_CG^_?P2`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````!"`#8`1@#:`UH#E@-J`
MPX#$@,R`X8#;@,Z`WH#D@-V`]($B@N>"`X,%@^."VX+F@@2#Y8("@PF#TH+7
M@O&"`8/<@M2"T8+>@M."WX+O@@:#4(9YAGN&>H9-B&N(@8G4B0B*`HH#BIZ,
MH(QTC7.-M(W-CLR.\(_FC^*/ZH_ECP``````````````````````````````
M````````````````````````````````````````````````````````````
M[8_KC^2/Z(_*D,Z0P9##D$N12I'-D8*54)9+EDR6399BEVF7RY?ME_.7`9BH
MF-N8WYB6F9F96$ZS3@Q0#5`C4.]/)E`E4/A/*5`64`90/%`?4!I0$E`14/I/
M`%`44"A0\4\A4`M0&5`84/-/[D\M4"I0_D\K4`E0?%&D4:51HE'-4<Q1QE'+
M45927%)44EM275(J4W]3GU.=4]]3Z%0050%5-U7\5.54\E0&5?I4%%7I5.U4
MX50)5>Y4ZE0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````YE0G50=5_50/50-7!%?"5]17RU?#5PE8#UE765A96ED16AA:'%H?6AM:
M$UKL62!:(UHI6B5:#%H)6FM;6%RP6[-;MENT6ZY;M5NY6[A;!%Q17%5<4%SM
M7/U<^USJ7.A<\%SV7`%=]%SN72U>*UZK7JU>IUXQ7Y)?D5^07UE@````````
M````````````````````````````````````````````````````````````
M``````````````````````!C8&5@4&!58&U@:6!O8(1@GV":8(U@E&",8(5@
MEF!'8O-B"&/_8DYC/F,O8U5C0F-&8T]C26,Z8U!C/6,J8RMC*&--8TQC2&5)
M99EEP67%94)F269/9D-F4F9,9D5F06;X9A1G%6<79R%H.&A(:$9H4V@Y:$)H
M5&@I:+-H%VA,:%%H/6CT9U!H0&@\:$-H*FA%:!-H&&A!:(IKB6NW:R-L)VPH
M;"9L)&SP;&IME6V(;8=M9FUX;7=M66V3;0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!L;8EM;FU:;71M:6V,;8IM>6V%;65ME&W*
M<-APY'#9<,APSW`Y<GER_'+Y<OUR^'+W<H9S[7,)=.YSX'/J<]YS5'5==5QU
M6G59=;YUQ77'=;)ULW6]=;QUN77"=;AUBW:P=LIVS7;.=BEW'W<@=RAWZ7<P
M>"=X.'@=>#1X-W@`````````````````````````````````````````````
M`````````````````````````````````````````````"5X+7@@>!]X,GA5
M>5!Y8'E?>59Y7GE=>5=Y6GGD>>-YYWG?>>9YZ7G8>81ZB'K9>@9[$7N)?"%]
M%WT+?0I]('TB?11]$'T5?1I]''T-?1E]&WTZ?U]_E'_%?\%_!H`8@!6`&8`7
M@#V`/X#Q@`*!\(`%@>V`](`&@?B`\X`(@?V`"H'\@.^`[8'L@0""$((J@BN"
M*((L@KN"*X-2@U2#2H,X@U"#28,U@S2#3X,R@SF#-H,7@T"#,8,H@T.#````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````%2&BH:JAI.&
MI(:IAHR&HX:<AG"(=XB!B(*(?8AYB!B*$(H.B@R*%8H*BA>*$XH6B@^*$8I(
MC'J,>8RAC**,=XVLCM*.U([/CK&/`9`&D/>/`)#ZC_2/`Y#]CP60^(^5D.&0
MW9#BD%*139%,D=B1W9'7D=R1V9&#E6*68Y9AE@``````````````````````
M````````````````````````````````````````````````````````````
M````````6Y9=EF266)9>EKN6XIBLF:B:V)HEFS*;/)M^3GI0?5!<4$=00U!,
M4%I025!E4'903E!54'50=%!W4$]0#U!O4&U07%&54?!1:E)O4M)2V5+84M52
M$%,/4QE3/U-`4SY3PU/\9D95:E5F54157E5A54-52E4Q55953U5552]59%4X
M52Y57%4L56-5,U5!55=5"%<+5PE7WU<%6`I8!EC@5^17^E<"6#58]U?Y5R!9
M8EDV6D%:25IF6FI:0%H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/%IB6EI:1EI*6G!;QUO%6\1;PEN_6\9;"5P(7`=<8%Q<7%U<
M!UT&70Y=&UT672)=$5TI711=&5TD72==%UWB73A>-EXS7C=>MUZX7K9>M5Z^
M7C5?-U]77VQ?:5]K7Y=?F5^>7YA?H5^@7YQ??V"C8(E@H&"H8,M@M&#F8+U@
M````````````````````````````````````````````````````````````
M``````````````````````````````#%8+M@M6#<8+Q@V&#58,9@WV"X8-I@
MQV`:8AMB2&*@8Z=C<F.68Z)CI6-W8V=CF&.J8W%CJ6.)8X-CFV-K8ZACA&.(
M8YECH6.L8Y)CCV.`8WMC:6-H8WIC765695%E665795]53V58955E5&6<99ME
MK&7/9<MES&7.95UF6F9D9FAF9F9>9OEFUU(;9X%HKVBB:)-HM6A_:'9HL6BG
M:)=HL&B#:,1HK6B&:(5HE&B=:*AHGVBA:()H,FNZ:P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#K:^QK*VR.;;QM\VW9;;)MX6W,
M;>1M^VWZ;05NQVW+;:]MT6VN;=YM^6VX;?=M]6W%;=)M&FZU;=IMZVW8;>IM
M\6WN;>AMQFW$;:IM[&V_;>9M^7`)<0IQ_7#O<#UR?7*!<AQS&W,6<Q-S&7.'
M<P5T"G0#=`9T_G,-=.!T]G0`````````````````````````````````````
M`````````````````````````````````````````````````````/=T''4B
M=65U9G5B=7!UCW74==5UM77*=<UUCG;4=M)VVW8W=SYW/'<V=SAW.G=K>$-X
M3GAE>6AY;7G[>9)ZE7H@>RA[&WLL>R9[&7L>>RY[DGR7?)5\1GU#?7%]+GTY
M?3Q]0'TP?3-]1'TO?4)],GTQ?3U_GG^:?\Q_SG_2?QR`2H!&@"^!%H$C@2N!
M*8$P@22!`H(U@C>"-H(Y@HZ#GH.8@WB#HH.6@[V#JX.2@XJ#DX.)@Z"#=X-[
M@WR#````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(:#
MIX-5AFI?QX;`AK:&Q(:UAL:&RX:QAJ^&R893B)Z(B(BKB)*(EHB-B(N(DXF/
MB2J*'8HCBB6*,8HMBA^*&XHBBDF,6HRIC*R,JXRHC*J,IXQGC6:-OHVZC=N.
MWXX9D`V0&I`7D".0'Y`=D!"0%9`>D""0#Y`BD!:0&Y`4D```````````````
M````````````````````````````````````````````````````````````
M````````````````Z)#MD/V05Y'.D?61YI'CD>>1[9'ID8F5:I9UEG.6>)9P
MEG26=I9WEFR6P);JENF6X'K?>@*8`YA:F^6<=9Y_GJ6>NYZB4(U0A5"94)%0
M@%"64)A0FE``9_%1<E)T4G52:5+>4MU2VU):4Z53>U6`5:=5?%6*59U5F%6"
M59Q5JE6458=5BU6#5;-5KE6?53Y5LE6:5;M5K%6Q57Y5B56K59E5#5<O6"I8
M-%@D6#!8,5@A6!U8(%CY6/I88%D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=UJ:6G]:DEJ;6J=:<UMQ6]);S%O36]!;"EP+7#%<
M3%U0731=1UW]745>/5Y`7D->?E[*7L%>PE[$7CQ?;5^I7ZI?J%_18.%@LF"V
M8.!@'&$C8?I@%6'P8/M@]&!H8?%@#F'V8`EA`&$281]B26*C8XQCSV/`8^EC
MR6/&8\UC````````````````````````````````````````````````````
M``````````````````````````````````````#28^-CT&/A8]9C[6/N8W9C
M]&/J8]MC4F3:8_EC7F5F96)E8V6199!EKV5N9G!F=&9V9F]FD69Z9GYF=V;^
M9O]F'V<=9_IHU6C@:-AHUV@%:=]H]6CN:.=H^6C2:/)HXVC+:,UH#6D2:0YI
MR6C::&YI^V@^:SIK/6N8:Y9KO&OO:RYL+VPL;"]N.&Y4;B%N,FYG;DIN(&XE
M;B-N&VY;;EAN)&Y6;FYN+6XF;F]N-&Y-;CIN+&Y#;AUN/F[+;@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````");AEN3FYC;D1N<FYI
M;E]N&7$:<29Q,'$A<39Q;G$<<4QRA'*`<C9S)7,T<RES.G0J=#-T(G0E=#5T
M-G0T="]T&W0F="AT)74F=6MU:G7B==MUXW79==AUWG7@=7MV?':6=I-VM';<
M=D]W[7==>&QX;W@->@AZ"WH%>@!ZF'H`````````````````````````````
M````````````````````````````````````````````````````````````
M`)=ZEGKE>N-Z27M6>T9[4'M2>U1[37M+>T][47N??*5\7GU0?6A]57TK?6Y]
M<GUA?69]8GUP?7-]A%74?]5_"X!2@(6`58%4@4N!48%.@3F!1H$^@4R!4X%T
M@1*"'(+I@P.$^(,-A."#Q8,+A,&#[X/Q@_2#5X0*A/"##(3,@_V#\H/*@SB$
M#H0$A-R#!X34@]^#6X;?AMF&[8;4AMN&Y(;0AMZ&5XC!B,*(L8B#B9:).XI@
MBE6*7HH\BD&*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````%2*6XI0BD:*-(HZBC:*5HIAC(*,KXR\C+.,O8S!C+N,P(RTC+>,MHR_
MC+B,BHV%C8&-SHW=C<N-VHW1C<R-VXW&C?N.^([\CIR/+I`UD#&0.)`RD#:0
M`I'UD`F1_I!CD661SY$4DA62(Y()DAZ2#9(0D@>2$9*4E8^5BY61E0``````
M````````````````````````````````````````````````````````````
M````````````````````````DY62E8Z5BI:.EHN6?9:%EH:6C99REH26P9;%
MEL26QI;'EN^6\I;,EP68!I@(F.>8ZICOF.F8\ICMF*Z9K9G#GLV>T9Z"3JU0
MM5"R4+-0Q5"^4*Q0MU"[4*]0QU!_4G=2?5+?4N92Y%+B4N-2+U/?5>A5TU7F
M5<Y5W%7'5=%5XU7D5>]5VE7A5<55QE7E5<E5$E<35UY845A86%=86EA46&M8
M3%AM6$I88EA26$M89UG!6LE:S%J^6KU:O%H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````LUK"6K)::5UO74Q>>5[)7LA>$E]97ZQ?
MKE\:80]A2&$?8?-@&V'Y8`%A"&%.84QA1&%-83YA-&$G80UA!F$W82%B(F(3
M9#YD'F0J9"UD/60L9`]D'&049`UD-F069!=D!F1L99]EL&679HEFAV:(9I9F
MA&:89HUF`V>4:6UI````````````````````````````````````````````
M``````````````````````````````````````````````!::7=I8&E4:75I
M,&F":4II:&EK:5YI4VEY:89I76EC:5MI1VMR:\!KOVO3:_UKHFZO;M-NMF["
M;I!NG6[';L5NI6Z8;KQNNFZK;M%NEFZ<;L1NU&ZJ;J=NM&Y.<5EQ:7%D<4EQ
M9W%<<6QQ9G%,<65Q7G%&<6AQ5G$Z<E)R-W-%<S]S/G-O=%IT571?=%YT070_
M=%ET6W1<='9U>'4`=O!U`7;R=?%U^G7_=?1U\W7>=M]V6W=K=V9W7G=C=P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!Y=VIW;'=<
M=V5W:'=B=^YWCGBP>)=XF'B,>(EX?'B1>)-X?WAZ>7]Y@7DLA+UY''H:>B!Z
M%'H?>AYZGWJ@>G=[P'M@>VY[9WNQ?+-\M7R3?7E]D7V!?8]]6WUN?VE_:G]R
M?ZE_J'^D?U:`6("&@(2`<8%P@7B!98%N@7.!:X$`````````````````````
M````````````````````````````````````````````````````````````
M`````````'F!>H%F@06"1X*"A'>$/80QA'6$9H1KA$F$;(1;A#R$-81AA&.$
M:81MA$:$7H9<AE^&^883APB'!X<`A_Z&^X8"AP.'!H<*AUF(WXC4B-F(W(C8
MB-V(X8C*B-6(THB<B>.):XIRBG.*9HIIBG"*AXI\BF.*H(IQBH6*;8IBBFZ*
M;(IYBGN*/HIHBF*,BHR)C,J,QXS(C,2,LHS#C,*,Q8SAC=^-Z(WOC?.-^HWJ
MC>2-YHVRC@./"8_^C@J/````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````)^/LH]+D$J04Y!"D%20/)!5D%"01Y!/D$Z039!1D#Z009`2
MD1>1;)%JD6F1R9$WDE>2.)(]DD"2/I);DDN29))1DC2229)-DD62.9(_DEJ2
MF)68EI26E9;-ELN6R9;*EO>6^Y;YEO:65I=TEW:7$)@1F!.8"I@2F`R8_)CT
MF```````````````````````````````````````````````````````````
M````````````````````````````````_9C^F+.9L9FTF>&:Z9R"G@Z?$Y\@
MG^=0[E#E4-90[5#:4-50SU#14/%0SE#I4&)1\U&#4H)2,5.M4_Y5`%8;5A=6
M_5445@96"58-5@Y6]U465A]6"%805O95&%<65W58?EB#6)-8BEAY6(58?5C]
M6"59(EDD66I9:5GA6N9:Z5K76M9:V%KC6G5;WEOG6^%;Y5OF6^A;XEOD6]];
M#5QB7(1=AUU;7F->55Y77E1>TU[67@I?1E]P7[E?1V$`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/V%+87=A8F%C85]A6F%8875A
M*F*'9%AD5&2D9'AD7V1Z9%%D9V0T9&UD>V1R9:%EUV769:)FJ&:=9IQIJ&F5
M:<%IKFG3:<MIFVFW:;MIJVFT:=!IS6FM:<QIIFG#::-I26M,:S-L,V\4;_YN
M$V_T;BEO/F\@;RQO#V\";R)O````````````````````````````````````
M``````````````````````````````````````````````````````#_;N]N
M!F\Q;SAO,F\C;Q5O*V\O;XAO*F_L;@%O\F[,;O=NE'&9<7UQBG&$<9)Q/G*2
M<I9R1'-0<V1T8W1J='!T;70$=9%U)W8-=@MV"783=N%VXW:$=WUW?W=A=\%X
MGWBG>+-XJ7BC>(YYCWF->2YZ,7JJ>JEZ[7KO>J%[E7N+>W5[EWN=>Y1[CWNX
M>X=[A'NY?+U\OGR[?;!]G'V]?;Y]H'W*?;1]LGVQ?;I]HGV_?;5]N'VM?=)]
MQWVL?0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!P
M?^!_X7_??UZ`6H"'@%"!@(&/@8B!BH%_@8*!YX'Z@0>"%((>@DN"R82_A,:$
MQ(29A)Z$LH2<A,N$N(3`A-.$D(2\A-&$RH0_AQR'.X<BAR6'-(<8AU6'-X<I
MA_.(`HGTB/F(^(C]B.B(&HGOB*:*C(J>BJ.*C8JABI.*I(H`````````````
M````````````````````````````````````````````````````````````
M`````````````````*J*I8JHBIB*D8J:BJ>*:HR-C(R,TXS1C-*,:XV9C96-
M_(T4CQ*/%8\3CZ./8)!8D%R08Y!9D%Z08I!=D%N0&9$8D1Z1=9%XD7>1=)%X
MDH"2A9*8DI:2>Y*3DIR2J))\DI&2H96HE:F5HY6EE:25F9:<EIN6S);2E@"7
M?)>%E_:7%Y@8F*^8L9@#F069#)D)F<&9KYJPFN::09M"F_2<]ISSG+R>.Y]*
MGP11`%'[4/50^5`"40A1"5$%4=Q1````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(=2B%*)4HU2BE+P4K)3+E8[5CE6,E8_5C16*593
M5DY65U9T5C96+U8P5H!8GUB>6+-8G%BN6*E8IEAM60E;^UH+6_5:#%L(6^Y;
M[%OI6^M;9%QE7)U=E%UB7E]>85[B7MI>WU[=7N->X%Y(7W%?MU^U7W9A9V%N
M85UA56&"80``````````````````````````````````````````````````
M````````````````````````````````````````?&%P86MA?F&G89!AJV&.
M8:QAFF&D891AKF$N8FED;V1Y9)YDLF2(9)!DL&2E9)-DE62I9))DKF2M9*MD
MFF2L9)EDHF2S9'5E=V5X9:YFJV:T9K%F(VH?:NAI`6H>:AEJ_6DA:A-J"FKS
M:0)J!6KM:1%J4&M.:Z1KQ6O&:S]O?&^$;U%O9F]4;X9O;6];;WAO;F^.;WIO
M<&]D;Y=O6&_5;F]O8&]?;Y]QK'&Q<:AQ5G*;<DYS5W-I=(MT@W0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````?G2`=']U('8I=A]V
M)'8F=B%V(G::=KIVY':.=X=WC'>1=XMWRWC%>+IXRGB^>-5XO'C0>#]Z/'I`
M>CUZ-WH[>J]ZKGJM>[%[Q'NT>\9[QWO!>Z![S'O*?.!]]'WO??M]V'WL?=U]
MZ'WC?=I]WGWI?9Y]V7WR??E]=7]W?Z]_````````````````````````````
M````````````````````````````````````````````````````````````
M``#I?R:`FX&<@9V!H(&:@9B!%X4]A1J%[H0LA2V%$X41A2.%(844A>R$)87_
MA`:%@H=TAW:'8(=FAWB':(=9AU>'3(=3AUN(78@0B0>)$HD3B16)"HF\BM**
MQXK$BI6*RXKXBK**R8K"BK^*L(K6BLV*MHJYBMN*3(Q.C&R,X(S>C.:,Y(SL
MC.V,XHSCC-R,ZHSAC&V-GXVCC2N.$(X=CB*.#XXICA^.(8X>CKJ.'8\;CQ^/
M*8\FCRJ/'(\>CP``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````ECVF0;I!HD&V0=Y`PD2V1)Y$QD8>1B9&+D8.1Q9*[DK>2ZI*LDN22
MP9*SDKR2TI+'DO"2LI*ME;&5!)<&EP>7"9=@EXV7BY>/ER&8*Y@<F+.8"ID3
MF1*9&)G=F="9WYG;F=&9U9G2F=F9MYKNFN^:)YM%FT2;=YMOFP:="9T`````
M````````````````````````````````````````````````````````````
M``````````````````````````.=J9Z^GLZ>J%A2GQ)1&%$441!1%5&`4:I1
MW5&14I-2\U)95FM6>59I5F16>%9J5FA6959Q5F]6;%9B5G96P5B^6,=8Q5AN
M61U;-%MX6_!;#EQ*7[)AD6&I88IAS6&V8;YARF'(83!BQ63!9,MDNV2\9-ID
MQ&3'9,)DS62_9-)DU&2^9'1EQF;)9KEFQ&;'9KAF/6HX:CIJ66IK:EAJ.6I$
M:F)J86I+:D=J-6I?:DAJ66MW:P5LPF^Q;Z%O````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````,-OI&_!;Z=OLV_`;[EOMF^F;Z!OM&^^
M<<EQT''2<<AQU7&Y<<YQV7'<<<-QQ'%H<YQTHW28=)]TGG3B=`QU#74T=CAV
M.G;G=N5VH'>>=Y]WI7?H>-IX['CG>*9Y37I.>D9Z3'I+>KIZV7L1?,E[Y'O;
M>^%[Z7OF>]5\UGP*?@``````````````````````````````````````````
M````````````````````````````````````````````````$7X(?AM^(WX>
M?AU^"7X0?GE_LG_P?_%_[G\H@+.!J8&H@?N!"()8@EF"2H59A4B%:(5IA4.%
M285MA6J%7H6#AY^'GH>BAXV'88@JB3*))8DKB2&)JHFFB>:*^HKKBO&*`(O<
MBN>*[HK^B@&+`HOWBNV*\XKVBOR*:XQMC).,](Q$CC&.-(Y"CCF.-8X[CR^/
M.(\SCZB/IH]UD'20>)!RD'R0>I`TD9*1(),VD_B2,Y,ODR*3_)(KDP23&I,`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````$),FDR&3
M%9,NDQF3NY6GEJB6JI;5E@Z7$9<6EPV7$Y</EUN77)=FEYB7,)@XF#N8-Y@M
MF#F8))@0F2B9'ID;F2&9&IGMF>*9\9FXFKR:^YKMFBB;D9L5G2.=)ITHG1*=
M&YW8GM2>C9^<GRI1'U$A43)1]5*.5H!6D%:%5H=6````````````````````
M````````````````````````````````````````````````````````````
M``````````"/5M58TUC16,Y8,%LJ6R1;>ELW7&A<O%VZ7;U=N%UK7DQ?O5_)
M8<)AQV'F8<MA,F(T8LYDRF389.!D\&3F9.QD\63B9.UD@F6#9=EFUF:`:I1J
MA&JB:IQJVVJC:GYJEVJ0:J!J7&NN:]IK"&S8;_%OWV_@;]MOY&_K;^]O@&_L
M;^%OZ6_5;^YO\&_G<=]Q[G'F<>5Q[7'L<?1QX'$U<D9R<'-R<ZETL'2F=*AT
M1G9"=DQVZG:S=ZIWL'>L=P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"G=ZUW[W?W>/IX]'CO>`%YIWFJ>5=ZOWH'?`U\_GOW>PQ\
MX'O@?-Q\WGSB?-]\V7S=?"Y^/GY&?C=^,GY#?BM^/7XQ?D5^07XT?CE^2'XU
M?C]^+WY$?_-__']Q@'*`<(!O@'.`QH'#@;J!PH'`@;^!O8')@;Z!Z($)@G&"
MJH4`````````````````````````````````````````````````````````
M`````````````````````````````````(2%?H6<A9&%E(6OA9N%AX6HA8J%
M9X;`A]&'LX?2A\:'JX>[A[J'R(?+ASN)-HE$B3B)/8FLB0Z+%XL9BQN+"HL@
MBQV+!(L0BT&,/XQSC/J,_8S\C/B,^XRHC4F.2XY(CDJ.1(\^CT*/18\_CW^0
M?9"$D(&0@I"`D#F1HY&>D9R139."DRB3=9-*DV632Y,8DWZ3;)-;DW"36I-4
MD\J5RY7,E<B5QI6QEKB6UI8<EQZ7H)?3ET:8MI@UF0&:````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/^9KINKFZJ;K9L[G3^=BY[/
MGMZ>W)[=GMN>/I]+G^)3E5:N5ME8V%@X6UU?XV$S8O1D\F3^9`9E^F3[9/=D
MMV7<9B9GLVJL:L-JNVJX:L)JKFJO:E]K>&NO:PEP"W#^;P9P^F\1<`]P^W'\
M<?YQ^'%W<W5SIW2_=!5U5G98=@``````````````````````````````````
M````````````````````````````````````````````````````````4G:]
M=[]WNW>\=PYYKGEA>F)Z8'K$>L5Z*WPG?"I\'GPC?"%\YWQ4?E5^7GY:?F%^
M4GY9?DA_^7_[?W>`=H#-@<^!"H+/A:F%S870A<F%L(6ZA;F%IH7OA^R'\H?@
MAX:)LHGTB2B+.8LLBRN+4(P%C5F.8XYFCF2.7XY5CL".28]-CX>0@Y"(D*N1
MK)'0D923BI.6DZ*3LY.NDZR3L).8DYJ3EY/4E=:5T)75E>*6W);9EMN6WI8D
MEZ.7II<`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MK9?YETV83YA,F$Z84YBZF#Z9/YD]F2Z9I9D.FL&:`YL&FT^;3IM-F\J;R9O]
MF\B;P)M1G5V=8)W@GA6?+)\S4:56WEC?6.)8]5N0G^Q>\F'W8?9A]6$`90]E
MX&;=9N5JW6K::M-J&W`?<"AP&G`=<!5P&'`&<@UR6'*B<GAS````````````
M````````````````````````````````````````````````````````````
M``````````````````!Z<[UTRG3C=(=UAG5?=F%VQW<9>;%Y:WII>CY\/WPX
M?#U\-WQ`?&M^;7YY?FE^:GZ%?W-^MG^Y?[A_V('IA=V%ZH75A>2%Y87WA?N'
M!8@-B/F'_H=@B5^)5HE>B4&+7(M8BTF+6HM.BT^+1HM9BPB-"HU\CG*.AXYV
MCFR.>HYTCE2/3H^MCXJ0BY"QD:Z1X9/1D]^3PY/(D]R3W9/6D^*3S9/8D^23
MUY/HD]R5M);CEBJ7)Y=AE]R7^Y=>F```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!8F%N8O)A%F4F9%IH9F@V;Z)OGF]:;VYN)G6&=
M<IUJG6R=DIZ7GI.>M)[X4JA6MU:V5K16O%;D6$!;0UM]6_9;R5WX8?IA&&44
M91EEYF8G9^QJ/G`P<#)P$')[<\]T8G9E=B9Y*GDL>2MYQWKV>DQ\0WQ-?.]\
M\'RNCWU^?'X`````````````````````````````````````````````````
M`````````````````````````````````````````()^3'\`@-J!9H+[A?F%
M$8;ZA0:&"X8'A@J&%(@5B&2)NHGXB7"+;(MFBV^+7XMKBP^-#8V)CH&.A8Z"
MCK21RY$8E`.4_9/AE3"7Q)A2F5&9J)DKFC":-YHUFA.<#9QYGK6>Z)XOGU^?
M8Y]AGS=1.%'!5L!6PE8466Q<S5W\8?YA'64<995EZ6;[:@1K^FJR:TQP&W*G
M<M9TU'1I=M-W4'R/?HQ^O'\7ABV&&H8CB"*((8@?B&J);(F]B72+````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'>+?8L3C8J.C8Z+
MCE^/KX^ZD2Z4,Y0UE#J4.)0RE"N4XI4XESF7,I?_EV>899A7F46:0YI`FCZ:
MSYI4FU&;+9PEG*^=M)W"G;B=G9[OGAF?7)]FGV>?/%$[4<A6RE;)5G];U%W2
M74Y?_V$D90IK86M1<%AP@'/D=(IU;G9L=@``````````````````````````
M````````````````````````````````````````````````````````````
M````LWE@?%]\?H!]@-^!<HEOB?R)@(L6C1>-D8Z3CF&/2)%$E%&44I0]ESZ7
MPY?!EVN859E5FDV:TIH:FTF<,9P^G#N<TYW7G32?;)]JGY2?S%;670!B(V4K
M92IE[&80:]ITRGID?&-\97R3?I9^E'[B@3B&/X8QB(J+D)"/D&.48)1DE&B7
M;YA<F5J:6YI7FM.:U)K1FE2<5YQ6G.6=GY[TGM%6Z5@L95YP<79R=M=W4'^(
M?S:(.8ABB).+DHL`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````EHMW@AN-P)%JE$*72)=$E\:7<)A?FB*;6)M?G/F=^IU\GGV>!Y]W
MGW*?\UX6:V-P;'QN?#N(P(FACL&1<I1PE'&87IG6FB.;S)YD<-IWFHMWE,F7
M8IIEFIQ^G(NJCL61?91^E'R4=YQXG/>>5(Q_E!J>*')JFC&;&YX>GG)\````
M````````````````````````````````````````````````````````````
M``````````````````````````#^,)TPGC`%,$$P0C!#,$0P13!&,$<P2#!)
M,$HP2S!,,$TP3C!/,%`P43!2,%,P5#!5,%8P5S!8,%DP6C!;,%PP73!>,%\P
M8#!A,&(P8S!D,&4P9C!G,&@P:3!J,&LP;#!M,&XP;S!P,'$P<C!S,'0P=3!V
M,'<P>#!Y,'HP>S!\,'TP?C!_,(`P@3"",(,PA#"%,(8PAS"(,(DPBC"+,(PP
MC3".,(\PD#"1,)(PDS"A,*(PHS"D,*4PIC"G,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"H,*DPJC"K,*PPK3"N,*\PL#"Q,+(P
MLS"T,+4PMC"W,+@PN3"Z,+LPO#"],+XPOS#`,,$PPC##,,0PQ3#&,,<PR##)
M,,HPRS#,,,TPSC#/,-`PT3#2,-,PU##5,-8PUS#8,-DPVC#;,-PPW3#>,-\P
MX##A,.(PXS#D,.4PYC``````````````````````````````````````````
M`````````````````````````````````````````````````.<PZ##I,.HP
MZS#L,.TP[C#O,/`P\3#R,/,P]##U,/8P%`05!`$$%@07!!@$&00:!!L$'`0C
M!"0$)00F!"<$*`0I!"H$*P0L!"T$+@0O!#`$,00R!#,$-`0U!%$$-@0W!#@$
M.00Z!#L$/`0]!#X$/P1`!$$$0@1#!$0$101&!$<$2`1)!$H$2P1,!$T$3@1/
M!&`D821B)&,D9"1E)&8D9R1H)&DD="1U)'8D=R1X)'DD>B1[)'PD?20`````
M```"``````````````!!!```7KD8"&6Y&`CTFQ@(`````$!]&@A`?!H(0'L:
M"$!Z&@@``````````$!X&@B`=AH(```````````$`````0````$`````````
M0`@9"$!V&@@`````E)<'"+2:!PCXF@<(O)P'"'Q_!PC,=`<(H(('".AU!P@`
M``````````````````````````````````````#]`$!W&@@"`7X!P'8:",<"
MW0*@=AH(``````````"W`````````````````````*+_`+(`O0``````````
M`,/CH;'&Y@````#(Z,_OT/````````#*ZLSL````````````````````````
M``````````````#%Y0``I;4``*.ST?$``-+R`````````-7U``#`X```V/BF
MM@``JKJIN=[^J[L``````````-GYV_L`````````K+ROOZZ^``````$"`P0%
M!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R
M,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?
M8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?@``````````````````
M`````````````````````````*````"D``"GJ`````"M``"P````M````+@`
M`````````,'"`,0``,<`R0#+`,W.`````-/4`-;7``#:`-S=`-\`X>(`Y```
MYP#I`.L`[>X`````\_0`]O<``/H`_/T``````0`"``,`!``%``8`!P`(``D`
M"@`+``P`#0`.``\`$``1`!(`$P`4`!4`%@`7`!@`&0`:`!L`'``=`!X`'P`@
M`"$`(@`C`"0`)0`F`"<`*``I`"H`*P`L`"T`+@`O`#``,0`R`#,`-``U`#8`
M-P`X`#D`.@`[`#P`/0`^`#\`0`!!`$(`0P!$`$4`1@!'`$@`20!*`$L`3`!-
M`$X`3P!0`%$`4@!3`%0`50!6`%<`6`!9`%H`6P!<`%T`7@!?`&``80!B`&,`
M9`!E`&8`9P!H`&D`:@!K`&P`;0!N`&\`<`!Q`'(`<P!T`'4`=@!W`'@`>0!Z
M`'L`?`!]`'X`````````````````````````````````````````````````
M````````````````````````````````````````H``$`=@"00&D`#T!6@&G
M`*@`8`%>`60!>0&M`'T!>P&P``4!VP)"`;0`/@%;`<<"N`!A`5\!90%Z`=T"
M?@%\`50!P0#"``(!Q``Y`08!QP`,`<D`&`'+`!H!S0#.``X!$`%#`4<!TP#4
M`%`!U@#7`%@!;@':`'`!W`#=`&(!WP!5`>$`X@`#`>0`.@$'`><`#0'I`!D!
MZP`;`>T`[@`/`1$!1`%(`?,`]`!1`?8`]P!9`6\!^@!Q`?P`_0!C`=D"``$"
M`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO
M,#$R,S0U-C<X.3H[/#T^/T!!1TA,3E-4559:6UQ@861I:FMN<G5Z>WQ]?X.$
MA8:'B$%'2$Q.4U155EI;7&!A9&EJ:VYR=7I[?'U_B8J+C``!`@,$!08'"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?_T+_7?]>;____W!Q<X#_@8+_0O]=_UYO
M__]P<7.`_X&";$-$149?24M*3U%24%E73?]B8V5F9VC_;7=V>'E^=/]L0T1%
M1E])2TI/45)065A-_V)C969G:/]M=W9X>7YT_P`!`@,$!08'"`D*"PP-#@\0
M$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]
M/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$149'2$E*
M2TQ-3D]045)35%565UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7
MF)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL*"RHK2DI;>XJ:JKK+VNK\#!PL/$
MQ<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?P,'"P\3%QL?(R<K+S,W.S_#1
MTM/4U=;WV-G:V]S=WO\``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>
M'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0&%B8V1E9F=H:6IK
M;&UN;W!Q<G-T=79W>'EZ6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X
M>7I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?L:&SH[6V
MIJ>HN;J[O*V^O["QLK.TM;:WN+FZN[R]OK_@X>+CY.7FY^CIZNOL[>[OT/'R
M\_3U]M?X^?K[_/W^W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_
M`"`@("`@("`@("@H*"@H("`@("`@("`@("`@("`@("`@2!`0$!`0$!`0$!`0
M$!`0$(2$A(2$A(2$A(00$!`0$!`0@8&!@8&!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$0$!`0$!""@H*"@H("`@("`@("`@("`@("`@("`@("`A`0$!`@("`@("`@
M("`H*"@H*"`@("`@("`@("`@("`@("`@($@!$`$0`0$0```!`0$!$`$!$`(0
M`A`"`A`0`@("`A`"`@$!`0$!`0$!`0$!`0$!`0$0`0$!`0$!$`$!`0$!`0$0
M`@("`@("`@("`@("`@("`@("`@("`@(0`@("`@("`A````"8N1@(G+H8"*"[
M&`BDO!@(````````````````=;D8"'BY&`A]N1@(@+D8"(6Y&`B(N1@()8((
M"(VY&`C$>`@(DKD8"````````````````````````````````%4`````````
M`````!$```"EO1@(J[T8"/2;&`@`````@($:"("`&@B`?QH(````````````
M``````````````````````````$````!`````@``````_P``?QH(@"HE"```
M``!TG0<(L)T'"'!<"`BX7`@('%T("(""!PA8@@<(3)\'"-"=!PC,5@@(*%<(
M"(17"`C45P@(S'4'"'Q]!PA,?@<(-(('"%!V!PC0=P<(*'D'"%1[!P@T?0<(
M](4'",R!!P@```````````````````````````````````````$"`P0%!@<(
M"0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U
M-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8$%"
M0T1%1D=(24I+3$U.3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/
MD)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\
MO;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CI
MZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`!`@,$!08'"`D*"PP-#@\0$1(3%!46
M%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`86)C
M9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I;7%U>7V!A8F-D969G:&EJ:VQM;F]P
M<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=
MGI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*
MR\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W
M^/GZ^_S]_O\`("`@("`@("`@*"@H*"@@("`@("`@("`@("`@("`@("!($!`0
M$!`0$!`0$!`0$!`0A(2$A(2$A(2$A!`0$!`0$!"!@8&!@8$!`0$!`0$!`0$!
M`0$!`0$!`0$!`1`0$!`0$(*"@H*"@@("`@("`@("`@("`@("`@("`@("$!`0
M$"`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0````````
M```````````````````````````````````3```````````````A````I;T8
M"+6]&`CTFQ@(`````("!&@B`@!H(@'\:"$"#&@@`````````````````````
M```````````!`````0````(``````/\``'\:"`"#&@@`````)','")AS!PBD
M<@<(](`'",A8"`@D6`@(8%T(".AU!P@`````````````````````````````
M``````````$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F
M)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)3
M5%565UA96EM<75Y?8$%"0T1%1D=(24I+3$U.3U!14E-455976%E:>WQ]?G^`
M@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRM
MKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:
MV]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_Z&CHJ.CHZ2C
MI:.FHZ>CJ*.IHZJCJZ.LHZVCKJ.OH["CL:.RH[.CM*.UH[:CMZ.XH[FCNJ.[
MH[RCO:.^H[^CP*/!H\*CPZ/$H\6CQJ/'H\BCR:/*H\NCS*/-H\ZCSZ/0H]&C
MTJ/3H]2CU:/6H]>CV*/9H]JCVZ.LH=VCWJ/?H^"CX:/BH^.CY*/EH^:CYZ/H
MH^FCZJ/KH^RC[:/NH^^C\*/QH_*C\Z/TH_6C]J/WH_BC^:/ZH_NC_*/]HZ:B
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````RZ',H?ZA_J,``,VA
MW*,``````````````````````````-#+ULOGR\_-Z,VMSOO/HM"XT-#0W=#4
MT=71V-';T=S1W='>T=_1X-'BT>/1Y-'ET>;1Z-'IT>K1Z]'MT>_1\-'RT?;1
M^M'\T?W1_M&BTJ/2I]*HTJG2JM*KTJW2LM*^TL+2P]+$TL;2Q]+(TLG2RM++
MTLW2SM+/TM#2T=+2TM/2U-+5TM;2U]+9TMK2WM+?TN'2XM+DTN72YM+GTNC2
MZ=+JTNO2\-+QTO+2\]+TTO72]]+XTN;4_-2EU:O5KM6XULW6R]?DU\7;Y-NE
MW*7=U=WTW?S>_MZSW^'?Z-_QX*WA[>'UXZ'DJ>2NY;'ELN6YY;OEO.7$Y<[E
MT.72Y=;E^N7[Y?SE_N6AYJ3FI^:MYJ_FL.:QYK/FM^:XYKSFQ.;&YL?FRN;2
MYM;FV>;<YM_FX>;DYN7FYN;HYNKFZ^;LYN_F\>;RYO7F]N;WYOGFH>>FYZGG
MJN>LYZWGL.>_Y\'GQN?'Y\OGS>?/Y]#GT^??Y^3GYN?WY^?HZ.CPZ/'H]^CY
MZ/OH_NBGZ:SIS.GWZ<'JY>KTZO?J_.K^ZJ3KI^NIZZKKNNN[Z[WKP>O"Z\;K
MQ^O,Z\_KT.O1Z]+KV.NF[*?LJNRO[+#LL>RR[+7LN.RZ[,#LP>S%[,;LR>S*
M[-7LW>S>[.'LY.SG[.CL]^SX[/KLH>VB[:/M[NW;[KWR^O*Q\Z?T[O3T]O;V
MN/?(]]/WV_CP^*'ZHOKF^JG\``````````"AL**P08%"@:.P0X%$@:2PI;"F
ML*>P18%&@4>!2(%)@:BPJ;"JL*NPK+"ML*ZPK[!*@;"PL;"RL+.PM+!+@4R!
MM;!-@4Z!3X&VL%"!48%2@5.!5(%5@5:!M["XL%>!N;"ZL+NP6(%9@5J!88%B
M@6.!O+"]L&2!98&^L&:!9X%H@;^P:8%J@6N!;(%M@6Z!;X%P@7&!<H'`L'.!
MP;!T@76!=H%W@7B!>8'"L'J!@8&"@<.P@X&$@86!Q+"&@8>!B(&)@8J!BX&,
M@8V!CH&/@9"!D8&2@9.!E(&5@9:!EX&8@<6PQK"9@9J!Q[";@9R!R+#)L)V!
MRK">@9^!H(&A@:*!R[#,L*.!S;#.L,^PT+"D@:6!T;#2L-.PU+"F@:>!J('5
ML*F!JH&K@=:PK(&M@:Z!KX&P@;&!LH'7L-BPLX'9L-JPV["T@;6!MH&W@;B!
MN8'<L-VPWK"Z@=^PNX&\@>"PX;"]@;Z!OX'`@<&!PH'#@>*PX[#$@>2PY;#F
ML,6!QH''@>>PR(')@>BPRH'+@<R!Z;#-@<Z!SX'JL-"!T8'2@=.!U('5@=:!
MUX'KL-B![+#9@=J!VX'<@=V!WH'?@>"![;#NL.&!XH'OL..!Y('PL/&PY8'R
ML.:!\[#G@>B!]+#UL/:PZ8'WL.J!^+#YL.N![('M@>Z![X'ZL/NP\('Q@?RP
M\H'S@?2!_;#U@?ZP]H'W@?B!^8'Z@:&QHK'[@:.Q_(&DL?V!_H%!@D*"0X)$
M@J6Q18)&@D>"IK%(@DF"2H*GL4N"3()-@DZ"3X)0@E&"4H*HL5."5(*IL:JQ
M58)6@E>"6()9@EJ"J[&LL6&"8H*ML6."9()E@JZQ9H)G@FB":8)J@FN";(*O
ML;"Q;8*QL6Z"LK%O@G""<8)R@G."=(*SL76"=H)W@K2Q>()Y@GJ"M;&!@H*"
M@X*$@H6"AH*'@HB"MK&)@K>QBH*+@HR"C8*.@H^"D(*1@KBQN;&2@I."NK&4
M@I6"N[&\L;VQOK&6@I>"F(*9@K^QP+'!L9J"PK&;@L.QQ+&<@IV"GH*?@J""
MQ;'&L:&"HH+'L:."I(*E@LBQIH*G@JB"J8*J@JN"K(*M@JZ"KX*P@LFQRK&Q
M@K*"LX*T@K6"MH++L;>"N(*Y@KJ"NX*\@KV"OH*_@L""P8+"@L."Q(+%@L:"
MQX+(@LRQR8+*@LN"S(+-@LZ"SX+0@LVQSK'1@M*"S['3@M2"U8+0L=:"UX+8
M@MF"VH+;@MR"T;'2L=V"T['>@M^"X(+A@N*"XX+D@N6"U+'F@N>"Z(+5L>F"
MZH+K@M:Q[(+M@NZ"[X+P@O&"\H+S@O2"]8+V@O>"^(+Y@OJ"^X+\@OV"_H+7
ML=BQ08-"@]FQ0X-$@]JQV['<L46#1H-'@TB#28-*@]VQWK%+@]^Q3(/@L4V#
M3H-/@U"#48-2@^&Q4X-4@U6#5H-7@UB#68-:@V&#8H-C@V2#98-F@V>#:(-I
M@VJ#:X-L@VV#;H-O@W"#<8-R@W.#XK'CL72#=8/DL7:#=X/EL>:Q>(/GL7F#
M>H.!@X*#@X/HL>FQA(/JL86#Z['LL8:#AX.(@^VQB8/NL>^Q\+&*@_&QBX.,
M@XV#\K&.@_.QCX.0@Y&#DH.3@_2Q];&4@_:Q]['XL96#EH.7@_FQF(.9@_JQ
M^[&:@YN#_+&<@YV#GH/]L9^#H(.A@Z*#HX.D@Z6#_K&ALJ:#HK*CLJ2RIX.H
M@ZF#JH.K@ZR#I;*FLJV#KH.O@["#L8.R@Z>RLX.T@[6#MH.W@[B#N8.Z@[N#
MO(.]@[Z#OX/`@\&#PH/#@\2#Q8/&@\>#R(/)@\J#RX/,@\V#SH//@]"#T8/2
M@].#U(/5@]:#UX/8@]F#VH/;@]R#W8/>@]^#X(/A@ZBRJ;*JLN*#J[+C@^2#
MY8.LLN:#YX/H@^F#ZH/K@^R#K;*NLNV#K[*PLK&R[H/O@_"#\8/R@_.#LK*S
MLO2#]8.TLO:#]X/X@_F#^H/[@_R#_8/^@T&$0H2ULD.$1(2VLD6$M[)&A$>$
M2(1)A$J$2X2XLDR$381.A+FR3X10A%&$NK)2A%.$5(15A%:$5X18A%F$6H1A
MA+NRO+)BA&.$9(1EA+VR9H1GA+ZR:(1IA&J$:X1LA&V$;H1OA'"$<81RA'.$
M=(1UA':$=X1XA'F$>H2!A(*$@X2$A(6$AH2'A(B$O[+`LHF$BH3!LHN$PK*,
MA,.RC82.A(^$D(21A)*$DX3$LL6RE(3&LI6$Q[+(LLFREH27A)B$F83*LLNR
MFH2;A)R$G82>A)^$S+*@A*&$HH2CA*2$I82FA*>$J(2IA*J$S;+.LJN$K(2M
MA*Z$KX2PA,^RT+*QA+*$LX2TA+6$MH2WA+B$N82ZA+N$O(2]A+Z$OX3`A,&$
MPH3#A-&RQ(3%A,:$QX3(A,F$TK+*A,N$S(33LLV$SH3/A-2RT(31A-*$TX34
MA-6$UH35LM:RUX38A-F$U[+:A-N$W(3=A-Z$WX38LN"$X83BA..$Y(3EA.:$
MYX3HA.F$ZH3KA.R$[83NA.^$\(3QA/*$\X3TA/6$]H3WA/B$^83ZA-FRVK+[
MA/R$V[+]A/Z$087<LD*%0X5$A46%1H5'A=VRWK+?LDB%X+))A>&RXK)*A4N%
M3(5-A4Z%X[)/A5"%4852A5.%5(55A>2R5H57A5B%685:A6&%8H5CA62%985F
MA>6RYK)GA6B%:85JA6N%;(7GLNBR;85NA>FR;X5PA7&%ZK)RA7.%=(5UA7:%
M=X5XA>NR[+)YA7J%[;*!A8*%@X6$A86%AH6'A>ZRB(6)A8J%[[*+A8R%C87P
MLHZ%CX60A9&%DH63A92%\;+RLI6%EH67A9B%F86:A9N%G(6=A9Z%\[*?A:"%
MH86BA:.%I(6EA::%IX6HA:F%JH6KA:R%K86NA:^%L(6QA;*%LX6TA;6%MH6W
MA;B%N87TLO6RNH6[A?:RO(7WLKV%^+*^A?FROX7`A<&%PH7ZLONR_++#A?VR
MQ(7^LL6%QH7'A:&SR(7)A<J%RX7,A<V%SH7/A="%T872A=.%U(75A=:%UX78
MA=F%VH7;A=R%W87>A=^%X(7AA>*%XX7DA>6%HK.CL^:%YX6DL^B%Z87JA:6S
MZX7LA>V%[H7OA?"%\86FLZ>S\H6HL_.%J;/TA?6%]H7WA?B%^86JLZNSK+/Z
MA:VS^X7\A:ZSK[.PL[&S_87^A4&&0H9#AK*SL[-$AK2SM;.VL[>SN+-%AKFS
M1H:ZL[NSO+-'ADB&O;-)ADJ&2X:^LTR&389.AD^&4(91AE*&O[/`LU.&P;/"
ML\.S5(95AE:&5X98AEF&Q+/%LUJ&88;&LV*&8X9DAL>S989FAF>&:(9IAFJ&
M:X;(LVR&;89NAF^&R;-PAG&&<H9SAG2&=89VAG>&>(9YAGJ&@8:"AH.&A(:%
MAH:&AX:(AHF&BH:+AHR&C8:.AH^&D(:1AI*&DX:4AI6&EH:7ALJSR[.8ALRS
MS;.9AIJ&FX;.LYR&S[/0LYV&GH:?AJ"&T;/2LZ&&T[/4L]6SHH:CAJ2&I8:F
MAM:SU[/8LZ>&J(;9LZF&JH:KAMJSK(:MAJZ&KX:PAK&&LH;;L]RSLX;=L]ZS
MW[.TAK6&MH:WAKB&N8;@L^&SNH:[AN*SO(:]AKZ&X[._AL"&P8;"AL.&Q(;%
MAN2SY;/&AL>&YK/GL\B&R8;HL\J&RX;,ANFSS8;.AL^&ZK/0AM&&TH;3AM2&
MU8;6AM>&V(;9AMJ&VX;<AMV&WH;?AN"&X8;BAN.&Y(;EAN:&Z[/LL^>&Z(;M
ML^F&ZH;KANZS[(;OL^V&[H;OAO"&\8;PL_&S\H;RL_.&\[/TAO6&]H;WAO2S
M];/VL_B&^8;ZAO>S^X;\AOV&^+/^AD&'0H=#AT2'18=&AT>'2(=)ATJ'^;-+
MATR'38=.AT^'4(=1AU*'4X=4AU6'5H=7AUB'68=:AV&'8H=CAV2'98=FAV>'
M:(=IAVJ':X=LAVV';H=OAW"'<8=RAW.'^K-TAW6'=H?[LW>'>(=YA_RS>H>!
MAX*'@X>$AX6'AH?]L_ZSAX>AM(B'B8>*AXN'C(>-AXZ'CX>BM*.TD(>1AZ2T
MDH>3AY2'I;25AY:'EX>8AYF'FH>;AYR'IK2=AZ>TGH>HM)^'H(>AAZ*'HX>D
MAZFTJK2EAZ:'J[2GAZB'K+2MM*F'JH>KAZR'K8>NAZ^'KK2OM+"'L+2QA[&T
MLH>SA[2'M8>VA[>'LK2XA[F'NH>[A[R'O8>^A[^'P(?!A\*'PX?$A\6'QH?'
MA\B'R8?*A[.TRX?,A\V'SH?/A]"'T8>TM-*'TX?4A]6'UH?7A]B'V8?:A]N'
MW(?=A]Z'WX?@A^&'XH?CA^2'Y8?FA^>'Z(?IA^J'ZX?LA[6T[8?NA^^'MK3P
MA_&'\H>WM/.'](?UA_:']X?XA_F'N+2YM/J'^X?\A_V'_H=!B$*(0XA$B$6(
MNK2[M$:(1XA(B$F(2HA+B+RT3(A-B$Z(3XA0B%&(4HB]M+ZT4XA4B%6(O[16
MB%>(6(A9B%J(88C`M,&T8HACB,*T9(AEB&:(P[3$M,6T9XAHB&F(:HAKB,:T
MQ[1LB,BT;8C)M,JT;HAOB'"(R[1QB,RT<HASB'2(S;1UB':(=XC.M'B(>8AZ
MB(&(@HB#B(2(A8B&B(>(B(B)B(J(BXB,B(V(CHB/B)"(S[30M)&(DHC1M).(
ME(B5B-*TEHC3M)>(F(B9B)J(FXC4M-6TG(C6M)V(U[2>B)^(H(BAB-BTHHC9
MM-JTV[2CB-RTI(BEB-VTWK3?M."TX;2FB*>(J(CBM..TY+2IB.6TYK3GM.BT
MZ;2JB*N(K(CJM.NT[+2MB*Z([;2OB+"(L8CNM+*(LXBTB+6(MHBWB+B([[3P
MM+F(\;3RM/.TNHB[B+R(O8B^B+^(]+3`B,&(PHC#B,2(Q8C&B,>(R(C)B,J(
MRXC,B,V(SHC/B-"(T8C2B-.(U(C5B-:(UXC8B-F(VHC;B-R(W8C>B-^(X(CA
MB.*(XXCDB.6(YHCGB.B(Z8CJB.N([(CMB.Z([XCPB/&(\HCSB/2(]8CVB/6T
M]K3WM/>(^+3XB/F(^;3ZM/J(^[3\M/N(_(C]B/Z(_;3^M$&)H;5"B:*U0XFC
MM42)18FDM4:)I;6FM4>)2(FGM4F)2HE+B:BU3(E-B4Z)3XE0B5&)4HFIM:JU
M4XFKM:RUK;54B56)5HE7B5B)68FNM5J)88EBB:^U8XEDB66)L+5FB6>):(EI
MB6J):XELB6V);HEOB7")L;6RM7&)<HESB72)=8EVB;.U=XEXB7F)M+5ZB8&)
M@HF#B82)A8F&B8>)B(F)B8J)BXF,B8V)CHF/B9")D8F2B9.)E(F5B9:)M;6V
MM9>)F(FWM9F)FHFXM;FUFXFZM9R)N[6=B9Z)GXF\M;VUH(F^M:&)O[6BB<"U
MHXG!M:2)I8G"M::)IXFHB<.UJ8FJB:N)Q+6LB:V)KHFOB;")L8FRB;.)M(FU
MB;:)MXFXB;F)NHF[B;R)O8F^B<6UOXG`B<&)PHG#B<2)Q8G&B<>)R(G)B<J)
MRXG,B<V)SHG/B=")T8G&M=*)TXG4B=6)UHG7B=B)Q[79B=J)VXG(M=R)W8G>
MB<FUWXG@B>&)XHGCB>2)Y8G*M<NUYHG,M>>)Z(GIB>J)ZXGLB>V)[HG-M>^)
M\(GQB?*)\XGTB?6)]HGWB?B)^8GZB?N)_(G]B?Z)08I"BD.*1(I%BD:*1XI(
MBDF*2HI+BLZUS[5,BDV*T+5.BD^*4(K1M5&*4HI3BE2*58I6BE>*TK73M5B*
MU+59BM6U6HIABF**8XIDBF6*UK5FBF>*:(IIBFJ*:XILBFV*;HIOBG"*<8IR
MBG.*=(IUBG:*=XIXBM>U>8IZBH&*@HJ#BH2*A8K8M8:*AXJ(BHF*BHJ+BHR*
MC8J.BH^*D(J1BI**DXJ4BI6*EHJ7BIB*F8K9M9J*FXJ<BIV*GHJ?BMJUH(JA
MBJ**V[6CBJ2*I8K<M::*IXJHBJF*JHJKBJR*K8K=M:Z*WK6OBM^UL(JQBK**
MLXJTBK6*X+6VBK>*N(KAM;F*NHJ[BN*UO(J]BKZ*OXK`BL&*PHKCM<.*Q(K%
MBL:*Y+7'BLB*R8K*BLN*S(KEM>:US8K.BN>USXK0BNBUZ;71BNJUTHK3BM2*
MU8K6BNNU[+77BNVUV(KNM=F*VHK;BMR*W8K>BN^UWXK@BN&*XHKCBN2*Y8KF
MBN>*Z(KIBNJ*ZXKLBNV*[HKOBO"*\8KRBO.*](KUBO:*]XKXBOF*\+7QM?J*
M^XKRM?R*_8KSM?2U_HI!BT*+0XM$BT6+1HOUM?:U1XOWM?BU^;7ZM4B+28M*
MBTN+3(O[M?RU38M.B_VU3XM0BU&+_K52BU.+5(M5BU:+5XM8BZ&VHK99BZ.V
MI+:EMEJ+88MBBV.+9(NFMJ>VJ+9EBV:+J;9GBVB+:8NJMFJ+:XMLBVV+;HMO
MBW"+J[:LMG&+K;:NMJ^V<HMSBW2+=8MVBW>+>(MYBWJ+@8N"BX.+A(N%BX:+
MAXN(BXF+BHN+BXR+C8N.BX^+D(N1BY*+DXN4BY6+EHN7BYB+F8N:BYN+G(N=
MBYZ+GXN@BZ&+HHNCBZ2+I8NFBZ>+J(NIBZJ+JXNLBZV+KHNOB["+L8NRB[.+
MM(NUB["VL;:VB[>+LK:XB[F+NHNSMKN+M+:UMKR+O8N^B[^+MK:WML"+N+:Y
MMKJVP8O"B\.+Q(O%B[NVO+:]ML:+QXN^MLB+R8O*B[^VRXO,B\V+SHO/B]"+
MT8O`ML&VTHO"ML.VQ+;3B]2+U8O6B]>+V(O%MMF+VHO;B]R+W8O>B]^+X(OA
MB^*+XXODB^6+YHOGB^B+Z8OJB^N+QK;LB^V+[HOOB_"+\8ORB_.+](OUB_:+
M]XOXB_F+^HO[B_R+_8O^BT&,0HQ#C$2,18Q&C$>,2(Q)C$J,2XQ,C$V,3HQ/
MC%",Q[;(ME&,4HS)ME.,5(Q5C,JV5HQ7C%B,68Q:C&&,8HQCC&2,98QFC&>,
MR[9HC&F,:HQKC&R,;8S,MFZ,;XQPC'&,<HQSC'2,S;9UC':,=XQXC'F,>HR!
MC(*,@XR$C(6,AHR'C(B,B8R*C(N,C(R-C,ZVCHR/C)",D8R2C).,E(R5C):,
MEXR8C)F,FHR;C)R,G8R>C)^,H(RAC**,HXRDC*6,IHRGC*B,S[:IC*J,JXS0
MMJR,K8RNC*^,L(RQC+*,LXRTC+6,MHRWC+B,N8RZC+N,O(R]C+Z,OXS`C,&,
MPHS#C,2,Q8S&C,>,R(S)C,J,RXS,C,V,SHS/C-",T8S2C-.,U(S5C-:,UXS8
MC-F,VHS;C-R,W8S>C-&VTK;?C.",T[;AC.*,XXS4MN2,Y8SFC.>,Z(SIC-6V
MUK;JC.N,[(SMC->V[HSOC/",\8SRC/.,](SUC/:,]XSXC/F,^HS[C/R,_8S^
MC$&-0HU#C42-18U&C4>-2(U)C4J-2XU,C4V-3HU/C5"-48W8ME*-4XU4C56-
M5HU7C5B-68U:C6&-8HUCC62-98UFC6>-:(UIC6J-:XULC6V-;HUOC7"-<8UR
MC=FV<XUTC76-VK9VC7>->(W;MGF->HV!C8*-@XV$C86-W+;=MH:-AXV(C=ZV
MB8V*C8N-C(V-C8Z-CXV0C9&-DHV3C92-E8V6C9>-F(V9C9J-FXV<C9V-GHV?
MC:"-H8VBC:.-I(VEC::-IXVHC:F-JHW?MN"VJXVLC>&VK8VNC>*VX[:OC;"-
ML8VRC;.-M(VUC>2VY;:VC>:VMXVXC;F-NHV[C;R-O8V^C>>VOXW`C<&-Z+;"
MC<.-Q(WIML6-QHW'C<B-R8W*C<N-ZK;KMLR-S8W.C<^-T(W1C=*-TXW4C=6-
M[+;6C=>-V(WMMMF-VHW;C>ZVW(W=C=Z-WXW@C>&-XHWOMO"VXXWQMN2-\K;E
MC>:-YXWHC>F-ZHWSMO2VZXWLC?6V[8WNC>^-]K;PC?&-\HWSC?2-]8WVC?>V
M^+;WC?FV^K;[MORV^(WYC?J-_;;^MJ&WHK?[C?R-H[?]C?Z-08ZDMT*.0XY$
MCD6.1HY'CDB.I;>FMTF.I[>HMZFW2HY+CDR.38Y.CD^.JK>KMU".48ZLMU*.
M4XY4CE6.5HY7CEB.68Y:CF&.8HYCCF2.98ZMMV:.KK=GCFB.:8YJCFN.;(YM
MCFZ.;XYPCG&.<HYSCG2.=8YVCG>.>(YYCGJ.@8Z"CH..A(Z%CH:.AXZ(CHF.
MBHZ+CHR.C8Z.CJ^WL+>/CI".L;>1CI*.DXZRMY2.E8Z6CI>.F(Z9CIJ.L[>T
MMYN.M;>VM[>WG(Z=CIZ.GXZ@CKBWN;>ZMZ&.HHZ[MZ..I(ZECKRWIHZGCJB.
MJ8ZJCJN.K(Z]M[ZWK8Z_MZZ.P+>OCK".L8ZRCK..M([!M\*WM8ZVCL.WMXZX
MCKF.Q+>ZCKN.O(Z]CKZ.OX[`CL6WQK?!CL>WR+?)M\*.PX[$CL6.QH['CLJW
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MOI.FNJ>ZOY/`D\&3PI/#D\23Q9.HNJFZQI.JNJNZK+K'D\B3R9/*D\N3S).M
MNJZZS9/.DZ^ZSY/0D]&3L+K2D].3U)/5D]:3UY/8D]F3L;K:D[*ZL[JTNMN3
MW)/=D[6ZWI/?D[:ZX)/AD^*3M[KCD^23Y9/FD^>3Z)/ID^J3ZY/LD^V3[I/O
MD_"3\9/RD_.3])/UD_:3]Y/XD_F3N+JYNKJZ^I.[NON3_)/]D[RZ_I-!E$*4
M0Y1$E$641I2]NKZZ1Y2_NDB4P+I)E$J42Y1,E$V43I3!ND^44)11E,*Z4I13
ME%245916E%>46)19E%J4891BE&.49)1EE&:4P[IGE&B4:91JE&N4;)1ME,2Z
M;I1OE'"4<91RE'.4=)1UE':4=Y1XE'F4>I2!E(*4@Y2$E(64AI3%NH>4B)2)
ME(J4BY2,E(V4QKK'NHZ4CY3(NI"4D922E,FZDY24E)64EI27E)B4F93*NLNZ
MFI2;E)R4G92>E)^4H)2AE**4HY3,NJ24I92FE,VZIY2HE*F4JI2KE*R4K92N
ME*^4L)2QE+*4LY2TE+64MI2WE+B4N92ZE+N4O)2]E,ZZS[J^E+^4T+K`E,&4
MT;K2NM.ZU+K"E,.4Q)3%E,:4U;K6NL>4U[K(E-BZR93*E,N4V;K:NLR4V[K-
ME,Z4SY30E-&4TI33E-RZU)35E-:4UY38E-F4VI3;E-R4W93>E-VZWY3@E.&4
MXI3CE.24Y93>NN:4YY3HE.F4ZI3KE.R4[93NE.^4\)3QE/*4\Y3TE/64]I3W
ME/B4^93ZE/N4_)3]E/Z4095"E=^ZX+I#E425X;I%E4:51Y7BNDB5295*E4N5
M3)5-E4Z53Y50E5&54I53E>.Z5)55E5:55Y58E5F5Y+I:E6&58I7ENF.59)5E
ME>:Z9I5GE6B5:95JE6N5;)7GNFV5;I7HNF^5Z;IPE7&5<I5SE725=97JNNNZ
M=I5WE>RZ>)5YE7J5[;J!E8*5@Y6$E865AI6'E>ZZ[[J(E?"ZB96*E8N5C)6-
ME8Z5CY60E9&5DI63E925E966E9>5F)69E9J5FY6<E9V5GI6?E:"5H96BE:.5
MI)6EE::5IY6HE:F5JI6KE:R5\;KRNJV5KI7SNJ^5L)6QE?2ZLI7UNK.5M)6U
ME;:5MY7VNO>ZN)7XNKF5^;KZNONZNI6[E;R5O97\NOVZOI6_E?ZZP)7!E<*5
MH;O#E:*[Q)7%E<:5QY7(E:.[I+O)E:6[IKNGN\J5RY7,E<V5SI6HNZF[JKO/
ME="5J[O1E=*5TY6LN]25U976E=>5V)79E=J5K;NNN]N5K[NPN[&[W)7=E=Z5
MWY7@E>&5LKNSN^*5XY7DE>65YI7GE>B5Z97JE>N5[)7ME>Z5[Y6TN_"5\97R
ME?.5])7UE?:5]Y7XE?F5^I7[E?R5_97^E4&60I9#ED26199&ED>62)9)EDJ6
M2Y9,EDV63I9/EE"64992EE.65)95EE:65Y98EK6[MKM9EEJ6M[MAEF*6N+NY
MNV.69)9EEF:69Y9HEFF6NKMJEFN6N[N\N[V[;)9MEFZ6;Y9PEG&6OKMREG.6
M=)9UEG:6=Y9XEGF6>I:!EH*6@Y:$EH66AI:'EHB6B9:*EHN6O[N,EHV6CI:/
MEI"6D9;`N\&[DI:3EI26E9:6EI>6F):9EIJ6FY:<EIV6GI:?EL*[P[N@EL2[
MQ;O&NZ&6HI:CEJ26I9:FEJ>6J):IEJJ6JY:LEJV6KI:OEK"6L9:REK.6M):U
MEK:6MY:XEKF6NI:[EKR6O9:^EK^6P);!EL*6Q[O(N\.6Q);)N\66QI;'ELJ[
MR);)ELJ6RY;,ELV6SI;+N\R[SY;0EM&6S;O2EM.6U);5EM:6UY;8EMF6VI;;
MEMR6W9;>EM^6X);AEN*6XY;DEN66YI;GENB6Z9;JENN6[);MENZ6[Y;PEO&6
M\I;SEO26]9;VEO>6^);YEOJ6^Y;\EOV6_I9!ET*70Y=$ET671I='ETB729=*
METN73)=-ETZ73Y=0EU&7SKM2EU.75)=5EU:75Y=8EUF76I=AEV*78Y=DEV67
M9I=GEVB7:9=JEVN7;)=MEVZ7;Y=PEW&7<I?/NW.7=)=UEW:7=Y=XEWF7>I>!
MEX*7@Y>$EX67AI>'EXB7B9>*EXN7C)?0NXV7CI>/EY"7D9>2E]&[TKN3EY27
MT[N5EY:7EY?4NYB7F9>:EYN7G)>=EYZ7U;N?EZ"7UKNAE]>[HI>CEZ27I9>F
MEZ>7J)>IEZJ7JY>LEZV7KI>OE["7L9>RE[.7M)>UE[:7MY>XE[F7NI>[E[R7
MO9>^E[^7P)?!E\*7PY?$E\67QI?'E\B7R9?*E\N7S)?-E\Z7SY?0E]&7TI?3
ME]27U9?6E]>7V)?9E]J7VY?<E]V7WI??E^"7X9?BE^.7Y)?EE^:7YY?HE^F7
MZI?KE^R7[9?NE^^7\)?QE_*7\Y?TE_67]I?WE_B7^9?ZE_N7V+O\E_V7_I=!
MF$*80YA$F$681IA'F$B829A*F$N83)A-F$Z83YA0F%&8V;M2F%.85)A5F%:8
M5YC:NUB869A:F-N[89ABF&.8W+MDF&689IAGF&B8:9AJF-V[WKMKF&R8;9AN
MF&^8<)AQF'*8<YATF'68=IAWF'B8>9AZF(&8@IB#F(28A9B&F(>8B)B)F(J8
MBYB,F(V8CIB/F)"8D9B2F).8E)B5F):8W[O@NY>8F)CANYF8FIB;F.*[G)B=
MF)Z8GYB@F*&8HICCN^2[HYCENZ28YKNEF*:8IYBHF*F8JICGN^B[JYCIN^J[
MK)BMF.N[[+OMN^Z[KIBOF+"8L9BRF.^[\+NSF/&[\KOSN[28M9BVF/2[MYBX
MF/6[]KNYF+J8][N[F+R8O9CXN[Z8OYC`F,&8PIC#F,28^;OZN\68^[O\N_V[
MQIC'F,B8R9C*F,N8_KNAO,R8S9BBO,Z8SYC0F*.\T9C2F-.8U)C5F-:8UYBD
MO*6\V)BFO-F8I[S:F-N8W)C=F-Z8WYBHO."8X9CBF*F\XYCDF.68JKSFF.>8
MZ)CIF.J8ZYCLF*N\[9CNF.^8\)BLO/&8\ICSF/28]9CVF*V\KKROO+"\L;SW
MF/B8LKRSO/F8M+RUO/J8^YC\F/V8MKRWO/Z8N+RYO+J\09E"F4.91)F[O$69
MO+R]O$:91YF^O$B929E*F;^\2YE,F4V93IE/F5"949G`O,&\4IG"O,.\Q+Q3
MF52959E6F5>96)G%O,:\69E:F<>\89EBF6.9R+QDF6699IEGF6B9:9EJF<F\
MRKQKF<N\S+S-O&R9;9ENF6^9<)EQF<Z\<IESF729S[QUF7:9=YG0O'B9>9EZ
MF8&9@IF#F829A9F&F8>9B)F)F=&\BIF+F8R9C9F.F8^9TKS3O-2\D)G5O)&9
MDIF3F=:\E)G7O)69EIF7F9B9F9G8O-F\FIG:O)N9V[R<F9V9GIG<O)^9H)G=
MO-Z\H9FBF=^\HYFDF:69X+RFF:>9J)FIF:J9JYFLF:V9KIFOF;"9L9GAO+*9
MLYFTF;69MIFWF>*\N)FYF;J9X[R[F;R9O9GDO+Z9OYG`F<&9PIG#F<29Y;S%
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MJYVLG:V=KIVOG;"=O;ZQG;*=LYVTG;6=MIVWG;B=N9VZG;N=OKZ_OKR=O9W`
MOKZ=OYW`G<&^P9W"G<.=Q)W%G<:=QYW"OL.^R)W$OLF=Q;[*G<N=S)W-G<Z=
MSYW&OL>^T)W1G<B^R;[*OM*=R[[,OLV^TYW4G=6=UIW.OL^^T+[7G=&^TK[3
MOMB=V9W:G=2^U;[;G=:^U[[<G=V=V+[>G=^=X)W9ON&=XIWCG>2=Y9WFG>>=
MVK[;ONB=W+[=OMZ^Z9WJG>N=[)WMG>Z=W[[@ON^=\)WAOO&=\IWSG>*^])WU
MG>.^]IWWG?B=^9WDON6^^IWFOON=Y[[\G?V=_IWHOD&>Z;[JOD*>0YY$GNN^
M19Y&GD>>[+Y(GDF>2IY+GDR>39Y.GD^>[;Y0GE&>4IY3GE2>59Y6GE>>6)Y9
MGNZ^[[Y:GF&>\+[QOF*>\K[SOO2^];YCGF2>99YFGF>>]K[WOOB^^;[ZOON^
M_+YHGOV^:9[^OFJ>H;^BOVN>;)ZCOVV>;IYOGJ2_<)YQGG*><YYTGG6>=IZE
MOZ:_=YZGOWB>J+]YGGJ>@9Z"GH.>A)ZIOZJ_J[^%GJR_AIZ'GHB>K;^)GJZ_
MK[^*GHN>C)Z-GK"_L;^RO[._M+^UOXZ>CYZ0GK:_M[^XO[F_D9Z2GI.>NK^4
MGI6>EIZ[OY>>F)Z9GIJ>FYZ<GIV>O+^]OYZ>OK^_OY^>H)ZAGJ*>HYZDGJ6>
MP+_!OZ:>IY["OZB>J9ZJGL._Q+_%OZN>QK^LGJV>Q[_(O\F_KI[*OZ^>R[^P
MGLR_L9ZRGK.>M)[-O\Z_M9ZVGL^_MYZXGKF>T+^ZGKN>O)Z]GKZ>OY[`GM&_
MTK_!GM._U+_5O\*>PY[$GL6>QI['GM:_U[_(GLF>V+_*GLN>S)[-GLZ>SY[0
MGM&>TI[3GM2>V;_5GM:>VK_7GMN_V)[9GMJ>VY[<GMV>W+_=O]Z>WY[>O^">
MX9[BGM^_XY[DGN6>YI[GGNB>Z9[@O^&_ZI[BO^N>X[_LGNV>[I[OGO">\9[D
MO^6_\I[SGN:_])[UGO:>Y[_WGOB>^9[ZGON>_)[]GNB_Z;_^GNJ_09_KOT*?
M0Y]$GT6?1I]'G^R_[;](GTF?[K]*GTN?3)_OO_"_\;]-GTZ?3Y]0GU&?\K_S
MOU*?]+]3G_6_5)]5GU:?5Y]8GUF?]K_WOUJ?89_XOV*?8Y]DG_F_99]FGV>?
M:)]IGVJ?:Y_ZO_N_;)]MG_R__;]NGV^?<)]QGW*?<Y_^OZ'`=)]UGZ+`=I]W
MGWB?H\!YGWJ?@9^"GX.?A)^%GZ3`I<"&GX>?B)^FP(F?BI^+GXR?C9^.GZ?`
MJ,"/GY"?J<"1GY*?DY^JP)2?E9^6GY>?F)^9GYJ?J\"LP)N?K<"<GZ[`G9^>
MGY^?H)^AGZ*?K\"PP*.?I)^QP*6?II^GG[+`J)^IGZJ?JY^LGZV?KI^SP+3`
MKY^UP+"?ML"QG[?`LI^SG[2?M9^XP+G`MI^WG[K`N)^YG[J?N\"[G[R?O9^^
MG[^?O,#`G[W`OL#!G[_`PI_`P,'`PL##P,3`Q<#&P,?`PY_$G\6?R,#&G\>?
MR)_)P,F?RI_+G\R?S9_.G\^?RL#0G]&?R\#2G].?U)_5G]:?UY_8G]F?S,#-
MP-J?VY_.P-R?W9_>G\_`T,#1P-^?X)_AG^*?TL#3P-3`XY_5P-;`U\#8P.2?
MY9_FG]G`YY_:P-O`Z)_IG]S`ZI_=P-[`W\#KG^#`[)_MG^Z?[Y_PG^'`XL#Q
MG^/`Y,#EP.;`\I_SG_2?]9_VG^?`Z,#WG_B?Z<#YG_J?^Y_JP/R?_9_^GT&@
M0J!#H$2@Z\#LP$6@[<#NP._`1J!'H$B@2:!*H$N@\,#QP$R@3:#RP$Z@\\!/
MH/3`4*!1H%*@4Z!4H%6@5J#UP%>@6*!9H%J@]L!AH&*@8Z!DH&6@9J#WP&>@
M:*!IH/C`:J!KH&R@^<!MH&Z@;Z!PH'&@<J!SH'2@=:!VH'>@>*!YH'J@@:""
MH(.@A*"%H/K`^\"&H(>@_,"(H(F@BJ#]P(N@_L",H(V@CJ"/H)"@H<&BP9&@
MH\&2H*3!I<&3H)2@E:"6H)>@IL&GP9B@F:"HP9J@FZ"<H*G!G:">H)^@H*"A
MH**@HZ"JP:O!I*"LP:6@K<&FH*>@J*"IH*J@JZ"NP:R@K:"NH*_!KZ"PH+&@
ML,&RH+.@M*"UH+:@MZ"XH+'!LL&YH+J@L\&TP;N@O*"]H+Z@OZ#`H+7!P:#"
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MJ[_#8ZMDJV6K9JMGJVBK::O`P\'#:JO"PVNKP\-LJVVK;JMOJW"K<:O$PW*K
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MG[J@ND&[0KM#NT2[1;O`QL'&1KO"QD>[P\9(NTF[2KM+NTR[3;O$QL7&QL9.
MN\?&3[M0NU&[R,92N\G&4[M4NU6[5KM7N\K&R\98N\S&S<;.QEF[6KMAN\_&
M8KMCN]#&T<9DNV6[TL9FNV>[:+O3QFF[:KMKNVR[;;MNNV^[U,;5QG"[UL;7
MQMC&<;MRNW.[=+MUNW:[V<;:QG>[>+MYNWJ[@;N"NX.[A+N%NX:[A[N(NXF[
MBKN+NXR[C;N.NX^[D+N1NY*[D[N4NY6[EKN7NYB[F;N:NYN[G+N=NYZ[G[N@
MNT&\0KQ#O$2\1;Q&O$>\2+Q)O$J\2[Q,O$V\3KQ/O%"\4;Q2O-O&W,93O%2\
MW<95O%:\5[S>QEB\6;Q:O&&\8KQCO&2\W\;@QF6\X<;BQN/&9KQGO&B\:;QJ
MO&N\Y,;EQFR\;;SFQFZ\;[QPO.?&<;QRO'.\=+QUO':\=[SHQNG&>+SJQGF\
MZ\9ZO(&\@KR#O(2\A;SLQH:\A[R(O.W&B;R*O(N\[L:,O(V\CKR/O)"\D;R2
MO._&\,:3O)2\\<;RQI6\EKR7O)B\F;R:O//&F[R<O)V\GKR?O*"\0;WTQD*]
M0[U$O46]1KU'O4B]2;WUQDJ]]L9+O4R]3;U.O4^]4+U1O5*]]\;XQE.]5+WY
MQE6]5KU7O?K&6+U9O5J]8;UBO6.]9+W[QOS&9;W]QF:]_L9GO6B]:;UJO6N]
M;+VAQVV];KUOO7"]<;URO7.]=+UUO7:]=[UXO7F]>KV!O8*]@[V$O86]AKVB
MQX>]B+V)O8J]B[V,O8V]CKV/O9"]D;V2O9.]E+V5O9:]E[V8O9F]FKV;O9R]
MG;V>O9^]H+U!OD*^0[Y$OD6^1KY'ODB^H\=)ODJ^2[ZDQTR^3;Y.OD^^4+Y1
MOE*^4[Y4OE6^5KY7OEB^6;Y:OF&^8KYCOF2^9;YFOF>^:+ZEQVF^:KYKOJ;'
M;+YMOFZ^I\=OOG"^<;YROG.^=+YUOG:^J,=WOJG'>+YYOGJ^@;Z"OH.^A+Z%
MOJK'J\>&OH>^K,>(OHF^K<>NQXJ^K\>+OHR^C;Z.OH^^L,>QQY"^LL>1OK/'
MDKZ3OI2^E;Z6OI>^M,>8OIF^FKZ;OIR^G;Z>OI^^H+Y!OT*_0[]$OT6_1K]'
MOTB_2;]*OTN_M<=,OTV_3K]/OU"_4;]2OU._5+]5OU:_5[]8OUF_6K]AOV*_
M8[]DOV6_9K]GOVB_:;]JOVN_;+]MOVZ_;[]POW&_<K]SO[;'=+]UOW:_M\=W
MOWB_>;^XQWJ_@;^"OX._A+^%OX:_N<>'OXB_NL>)OXJ_B[^,OXV_CK^/OY"_
MN\>1OY*_D[^\QY2_E;^6O[W'E[^8OYF_FK^;OYR_G;^^QYZ_G[^_QZ"_P,=!
MP$+`0\!$P$7`1L#!QT?`2,!)P,+'2L!+P$S`P\=-P$[`3\!0P%'`4L!3P,3'
MQ<=4P,;'5<!6P%?`6,!9P%K`8<!BP&/`9,!EP&;`9\!HP&G`:L!KP&S`;<!N
MP&_`<,!QP'+`<\!TP'7`=L!WP'C`><!ZP('`@L"#P(3`Q\?(QX7`AL#)QX?`
MB,")P,K'BL"+P(S`C<".P(_`D,#+Q\S'D<#-QY+`SL>3P)3`E<"6P)?`F,#/
MQ]#'F<":P-''F\"<P)W`TL>>P)_`H,!!P=/'0L%#P=3'U<=$P=;'1<'7QT;!
M1\%(P4G!2L%+P=C'V<=,P4W!VL=.P4_!4,';QU'!4L%3P53!5<%6P5?!W,?=
MQUC!WL??Q^#'6<%:P6'!8L%CP63!X<=EP6;!9\%HP6G!:L%KP6S!;<%NP6_!
M<,%QP7+!<\%TP77!=L%WP7C!XL=YP7K!@<&"P8/!A,&%P8;!A\&(P8G!BL&+
MP8S!C<&.P8_!D,&1P9+!D\&4P97!EL&7P9C!F<&:P9O!G,&=P9[!G\&@P>/'
MY,=!PD+"Y<=#PD3"1<+FQT;"Y\='PDC"2<)*PDO"Z,?IQTS"ZL=-PNO'3L)/
MPE#"4<)2PE/"[,?MQU3"5<+NQU;"5\)8PN_'6<):PF'"8L)CPF3"9<+PQ_''
M9L+RQV?"\\=HPFG":L)KPFS";<+TQ_7';L)OPO;'<,)QPG+"]\=SPG3"=<)V
MPG?">,)YPOC'^<=ZPOK'^\?\QX'"@L*#PH3"A<*&POW'A\*(PHG"_L>*PHO"
MC,*AR(W"CL*/PI#"D<*2PI/"E,*BR)7"EL*7PIC"F<*:PIO"G,*=PI["H\BD
MR)_"H,*ER$'#0L-#PZ;(1,-%PT;#1\.GR$C#2<.HR*G(2L.JR$O#J\A,PTW#
M3L.LR$_#4,.MR*[(4<-2PZ_(4\-4PU7#L,A6PU?#6,-9PUK#8<-BPV/#9,-E
MP['(9L.RR&?#:,-IPVK#:\-LP[/(M,AMPV[#M<AOPW##<<-RPW/#=,-UPW;#
M=\-XPWG#>L.!PX+#MLB#P[?(A,.%PX;#A\.(PXG#N,BYR(K#B\.ZR(S#C<..
MP[O(C\.0PY'#DL.3PY3#E<.6P[S(E\.]R)C#OLB9PYK#F\.<PYW#GL._R)_#
MH,-!Q,#(0L1#Q$3$P<A%Q$;$1\1(Q$G$2L1+Q$S$PLA-Q,/(3L1/Q%#$4<12
MQ%/$5,15Q,3(Q<A6Q%?$QLA8Q%G$6L3'R&'$8L1CQ&3$R,AEQ&;$R<AGQ&C$
MRLAIQ,O(:L1KQ&S$;<1NQ&_$S,APQ''$<L3-R'/$=,1UQ,[(=L1WQ'C$><1Z
MQ('$@L3/R(/$A,2%Q(;$T,B'Q(C$B<2*Q(O$C,31R-+(C<2.Q-/(C\20Q)'$
MU,B2Q)/$E,25Q);$E\28Q)G$FL2;Q)S$G<35R)[$G\2@Q$'%0L5#Q=;(U\A$
MQ47%V,A&Q4?%2,79R$G%2L5+Q4S%3<5.Q4_%VLC;R%#%W,A1Q=W(4L53Q53%
M5<56Q5?%WLC?R%C%6<7@R%K%8<5BQ>'(8\5DQ67%9L5GQ6C%:<7BR&K%:\7C
MR&S%Y,AMQ6[%;\5PQ7'%<L7ER.;(<\5TQ>?(=<7HR.G(ZLCKR';%=\5XQ7G%
M>L6!Q>S([<B"Q>[(@\7OR(3%A<6&Q?#(A\6(Q?'(B<6*Q8O%\LB,Q8W%CL7S
MR(_%D,61Q9+%D\64Q97%],CUR);%E\68Q?;(F<6:Q9O%G,6=Q9[%]\CXR)_%
MH,7YR$'&0L9#QOK(1,9%QD;&1\9(QDG&2L;[R/S(2\;]R$S&_LA-QD[&3\90
MQE'&4L8```````````````````````````````#^[0``````````````````
M``"FV@````#LX`````````````#-^```TLL```````#.ZP``V/G9^>#*RMH`
M``````"FRP``````````````````````````R,KN^>S;`````+'0````````
M``#OU0```````//F````````````````````````HN?9Y```````````````
M````````````X>0`````Q/P```````````````````````#O^?3/YO<`````
M````````O,X``````````,7TH]P`````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"]
MW0``````````QO0`````````````````````H?@```````#6Z````````,';
M`````````````````````.;P````````N>3M]@``KOD``+[=````````````
M````L-?HV+W+`````-KY``````````````````````````#.^/#Y[>"SX[/T
M`````,+JYO*V\`````````````#6VP````````````#DZP````#G\@``U=>V
MU.CYP=<``````````-7E``````````````````#JZ<S7````````Z=/)X@``
MV_RMS0````````````"PS*+J`````/;DP-```+?PH>X```````````````#V
MUP```````,KBR^(``,_Z````````````````W^L`````````````R]8`````
M``"T]```````````S>W2Y`````"IZKKDHO/2S0``R_8``.;QP>V\Z-'N````
M````````````Y_#,X@````"JY```X?7:[0````````````#NU_'1````````
M``#KZ>SIY.```````````*?:U-T``*/J````````P];TU@``W]H``+/O````
M``````#-X@````````````#][^CR````````````````````````Q>\``.?G
M`````/W7`````,[G`````-S?``#'^0````````````````````#VV0``````
M``````````````"LWP``VM8```````````````"DW````````+CP````````
M``#ZU0``]^0```````#$U@````````````````````#L]```````````_N\`
M````````````H?```*K>`````+S:_-@```````````````#4^@```````.7L
M````````````````J/P`````YNP`````R]@`````````````````````````
M`````````````````+G[``#3Y```^<T`````````````````````````````
M`````````````-//``````````````````#JR@````#4SP``O?@`````````
M``````````````````````````````````````````````````````#']```
M````````W^H``````````````````-OY`````````````````````+?4````
M``````````````````````````````````````````````````````#EZP``
M``#2X0``````````I.H```````#"^N'[[?JB\/',``"C^O?B``#.X@``]>D`
M`.OA````````Z.?7Z/C:R]0```````#V]\76````````````````````````
M`````````````````````````````.G4`````/KZ``````````````````#R
MS-WW``"ZW@``````````````````````````J,X`````````````N?#^Y,GD
M`````````````-3D````````P^H``+3O````````OM<```````````````#B
M^P``T\T```````"U[P```````.GZ````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````*;Y
M````````````````O=\``,?W````````````````````````````````````
M````````````_?@`````_/@`````````````````````````````````````
M`````````````*O>Z-L`````W>,``.+AQM$`````````````````````````
M`-#VYNOYV@``````````Q^P``````````````````/C>Z?C>XP``````````
M]<X`````````````P_K7Y0``R.P```````#)\P````"[Y```````````KN8`
M````````````MN\``+_<``````````````````"]S@``````````````````
M````````````````````````````````````````````````````````P]@`
M``````#/T```^L_*\]?@````````Q]&NZ0``O>@`````Q/H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````S^(`````Q?H```````"X^0``````
M````````````X-P`````L/L```````"IV-_EI_D`````[O8``,SV^.(`````
M`````/'L``````````````````#@V@``````````````````````````````
M``````#2\<S2R\\`````O<H```````"_W0```````._V``#YW@``````````
M````````````````````````M/H```````"MU0``````````````````````
M````````````Y_$``+[>````````````````P-P`````````````R-')T0``
M`````````````````````+[X````````````````````````````````````
M`````````/;+``````````#YU`````````````#B]=/A````````````````
M`````.G8`````/[X``#,SP``````````````````I/T`````````````````
M`/;.``#0^@````#SS+[F````````KO8`````\-4`````RM$```````"^_/'5
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#IS0``````````````
M`````````````````````````+7Z````````````````````````````````
M`````````````````````````````````````-#B]_0```````#4S0``````
M`````````````````````````*/G`````````````````````*7;````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#1X@``````````
M`````````````````````*+7`````./W````````````````INH`````````
M`````````````````*'0``````````#:SNO[IMO>V^78````````````````
M````````X.H``````````*K8`````````````.#E````````````````````
M`````````````````````````````````-O6````````````````````````
M````````````````````````````````````````````````````````QN\`
M````ZO@``````````````````````````````````-7D````````````````
M`````````````/?.`````-C@````````````````````````````````````
M`````````````````````````````````._7````````````````````````
M````````[?0``````````````````````````````````.;-````````],P`
M````````````````````````````````````````````````````````````
M``````````````````````````````````#C]0````#*Y```X=P`````R/D`
M``````````````````````````````````````"__```````````````````
M`````````````*?H`````````````````````,38````````````````````
M`````````+[+``"NW```````````````````````````````````]]<`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#H\```P-T``,W/````````````````````````\]RPV0``Z>8`
M``````````````````````````````````````````````"\Y```````````
M``````````````````````````````````#$Z@``````````````````````
M````[.0``.7D````````````````````````````````````````````````
M^/L```````````````````````````````````````````````````````"[
MS`````````````````````````````"]Y`````#<S??9````````````````
M``````````#?W0````````````#.[0``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-#9````
M`````````*/E``````````#-^0``````````````````````````````````
M`````*[-````````````````````````````````````````````````SL\`
M````````````````````````````````````````````````````````````
M````````K_8`````````````T_WMZ]S6````````````````````````````
M``````````````````````````````````````````````````````"DY0``
M`````+;5````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````-W6
M````````Z?D```````"DYP``X]8`````````````````````````````````
M``````````````#+T>36````````\M4`````````````^MX``/C7````````
M`````.K8`````````````````````````````````````-7/_=@`````````
M````J]@`````R_T``````````-S\````````````````````````J.#SU0``
M``#9_0````"CS````````/G9`````.K3]?4``,?O````````````````````
M````VM,`````````````````````````````O=H`````````````````````
M``````````````````````````"HZ*_<`````````````*/P``````````#5
MS0```````````````````````````````*G@````````````````````````
M`````````````````````````````````````````````*S>````````````
M`````````````````````````+KPL>X`````LNX```````#-]@``````````
M`````````````````````-+N``#&U@````````````#EX`````"[\P``X>4`
M`````````````````````````,OD````````````````````````````````
M````````````````````````H]<`````PML``````````/[*````````````
M````S\\``````````````````````````.GLR^\``-+V````````LMC;[;+?
MOM^[^0``]-P```````#D]0````"F\^#=IN$``/C.L-P``````````*KC````
M`````````````````````````````````.GQ``````````#ZS0``````````
M``"O_*'3``"K\0```````````````-'GK-(``/G.`````````````/WQ``"_
MWKK[N?D```````````````#2S@``J^/@ZP```````/K.]\NEY0``````````
M``````````````````#AR@``S-0`````````````X>H`````X]RMWP``````
M`````````.O+````````K]4```````#UU@``^.4`````P-ZC[```S>D``*?J
M]NF[^P``Z>?,[P````#FT`````#!W@````"LY`````#,V/'Y``#?SJ3ZLN8`
M`/OZ`````+WZR,S-[]75``````````````````"BTP```````-'L````````
M`````*?DTNP`````L?8`````^\X`````T="_RP``I.T```````````````"H
M[<+>XO;<[?7<N>````````#.U```M?0```````#;T[76I.P`````````````
M`````````````.;D``#J\0```````.S+P,L```````#R[`````````````#J
MT```````````````````\OFE[-_0``#JY^O0T=SIV\S]````````````````
M````````````````````````````````````````````````````````````
M`-?;``````````#AV@``MM8``-_C``##W@``Q-ZAR@````````````#L[@``
M``"CT[?NS_@``````````,CJN.ZL\:7QSND```````"\^0```````/GEZNS6
MW<+M````````````````````````````````I?@`````````````NN78VP``
M``"BR@````#-T0```````.WN````````Z^S%W@``X.,``,G*Z?(``,[5``"V
M]@``PL['U@``M.,``*WQ``#BZ@``````````PM<``*?S`````.K-``#NZP``
M````````````````````````````````````````LMFE_0````````````#5
M]N+5`````````````````````+7X`````/7,M?6MY```````````Z^?5\0``
M`````+OP`````+7I``#)S-7Z`````-3A`````-;7`````,'<``#&WN_ZX>,`
M``````````````````````````````#SX?;<``#\S@``Q-L``/'X`````.3<
M``#OY0``````````````````L=P```````#6U0````#:\P``P<L``,/;````
M````^MGNTP```````+CZ`````*;][^L``*;T``#*S*CS``#;\P``I]NW]@``
MYL_R\-K+``#2Y\/7\/;>Z```````````````````````````````````IN4`
M`````````````````.?E````````H\JGS,GJ`````````````+;X````````
M`````*7Z``````````"N\0``SN\`````````````````````[<L`````````
M````````````````````````````L/;/[\_I``#>]P``````````````````
MT\X``````````/?<``````````````````"HVP```````/C+````````````
M````H=_AW0```````````````````````````````````````````````,KU
MMND``````````.SG[NX``/#S``"_WP```````````````,O,````````````
M````P=````````#2]+K@``````````#`WP``X,X```````#2W.K]````````
M]M8```````#*Z@```````````````.GH``"LXP````````````#0\P``````
M``````````````````````"DR@``^-L```````#'WO#KUO$`````XN4``,S,
M`````/O+`````````````````````./J````````````````````````````
M````P=\``.W6`````````````````````-#I``````````````````"Y[@``
M````````X]4`````T]$``/#E````````M.C#ZP``JNK\^O;UO/#4_;O@P\X`
M`+K0NO?SV,WW````````KN0```````````````````````#?U```````````
M``#GT`````#][```KM+O[M?5Y.JB^.O-O]>Q^P````#LS0```````++<[-#]
MSO#N````````PLP```````#MT`````````````#WY0```````/SS`````*+N
M``````````"SV0````#TV```M^D`````````````````````KLX`````````
M`*+9``````````#QV```S]0```````````````````````"GY=+5````````
M`````*G6````````````````HO0``-?Q`````-C5``"]\-#7T-0`````````
M````````````````````````````S]?JZ^O]`````.W;````````````````
M`````````````````````,7\PLL``````````-7]``#(].KH\_4`````WOD`
M````[],`````T^P`````PMVW[]3G``#*R@```````/O9`````/WZ````````
M`````*K6`````````````/CT````````````````]_>LW````````-?7HM\`
M``````"^S@``\-,`````````````I/#LX>?/R_.I[;[*````````````````
M``#O]````````,[V`````/O>N]"WU?'N````````````````J/0``/C<````
M``````"GRP``SMH```````#FX```````````````````I>WR[@``````````
M^=P`````W/D`````W/,``````````````````/+X``#Y]````````/'\````
M````O-#YV['7````````_,L```````"E\/W+`````````````````````/35
M````````[<VER@````"KUL+0``````````"^\+W2I,P`````````````````
M``````````````````````````````"V^@````#-S```^MH``,_V``"XZ0``
M]=@```````#.S```````````S=<`````T=3MZ0``Z\KBV0``LOT``*WCS-:T
MV0````"GX=/NP]``````````````````````````````````````L_T``.35
M`````.C/``##[;+0`````/[.J-H`````````````T/@`````UOT`````````
M`-'X``#2^-/<``````````#BW?G[P=T``+7C````````````````W>W$S@``
MH<L```````````````#CW0``````````W?P```````````````````````"O
M^0````````````#[TJ'/J.0``+;T_NP`````KN/MY\']XMH`````L]@`````
M``#DW>_P\?;P^@````#UT0````#/V@``U-P``*;<``"_[P````````````#/
MS@``V>````````````````#6V=3LR^H`````O\JPU0``Z<\`````````````
M[?$``,_,``````````#XY`````````````````````````````````````#M
MY```````````V-<``*?]``````````"KZK+V``````````#PS[WY````````
M````````].8``````````````````````````````````-O+````````````
M``````#1\P``````````T>FI\^#0TND``./:````````````````TN(``*+V
M].$```````#DV@````````````#5Y[_UHL^OS://````````L,W^\:/0K^&C
M^```ILJ[]^KRR-[3Z0``````````R=X``````````````````````````-[]
MP,H```````#J^<[1U.X``-+4H]FH_=G7SO>^^@``````````````````````
M`-;/``#PUP``X>O%^`````````````#ZW`````##W0``W_D`````````````
M`````._G``````````#E_:/V``#\V:G]``#NYP```````.75````````````
M`-#O``"QS0```````````````*+W````````````````````````````````
M``````````````````````````"R\0``L?$```````````````"RS0``J]H`
M`*?*`````````````.+CO/NDV0````"Z[@````````````#3^```````````
M``#Z^P``I,\``/O<````````````````````````````````````````````
M``````#C]@```````*KM`````*'RX<X```````````````"F^@``````````
MX/D``````````-;L`````.[DH?D`````[_L```````#K^:/N````````````
M`````````````````````````````````````````````````*SJ````````
MJ,H`````^O0``````````-;-]OP```````#)]```````````````````U/@`
M``````````````````````"F^```RM[&\@```````````````-K7``#0TP``
M``````````````````````````#%V```````````````````````````````
M`````````````````.;J``#=\P```````-KD`````````````````````.3V
M`````````````/+V``#"WP````````````````````#]V0```````/;,````
M`+K3``````````````````"OY```````````X?D`````````````````````
M``````````````````````````````````````````"F\````````-/+````
M````O.```,KT^M0``*K]XOD``````````````````````````````````+?T
MPOVP_```[/WBR@```````````````````````+W]``#GZL/?TM'BS@``I-,`
M`````````````````````````````````````````````````````````*O]
M``#@WP```````````````````````````````,?R`````````````/#G``#N
MT`````"J\P```````,O>N/8`````````````````````````````````````
M``````````````````````````#UX;/Q``````````````````"C]P````"I
MR@``````````````````````````I<\`````Q-\`````````````````````
M````````````````````````````````````````L.$`````O_```*3V``"V
MXP``````````````````````````````````````````````````````````
M````````````````QOH`````````````````````````````````````````
M````````````[]``````[?T`````````````````````Q-T`````````````
M````````````````````````````````]_P`````````````````````````
M``````````````````````````````````````````````````````"_Y@``
M`````````````*W>``"_^@````````````#QY0``````````````````Q.T`
M`````````````````````````````````*72`````.[]````````MO4`````
M````````````````]N',W@````#>_```U^P`````````````````````````
M``````````````#=S0````````````````````"WUK/-````````````````
M`````-7XV.4```````#JSP````#0SP``S.H``````````*[JK>H`````\=,`
M`*73````````````````S_<`````````````````````I.X``````````*30
M`````*+R``````````````````````````#PT```````````H_(``/CW````
M``````"ST`````"IVP````"[T^S*``"F\=7+````````````````````````
M````````````````Y_<`````WLT``*3W````````P/@```````#=TP``T,P`
M`````````*;/````````````````\_8`````````````]^$`````````````
MW-,`````_OH``````````````````*?Z````````````````````````````
M````V>L``*?/K^H`````````````````````````````````````````````
M`````````````````````````````````````._D````````N>G8\0````#8
MV`````#RX```````````````````````````````````````````M.;\W```
M`````````````````````````````````````/'S````````T.,`````^_(`
M`,;;\=```/+0````````W,\``-'3`````+',V/<``*C+O.N^Y```````````
M````````````````````````````````````````W/0`````PMP`````I_``
M````P.8`````[<H``````````.OHZ.7#W`````#>[?+3``````````#WS```
M`````````````````````````````````````-3.J^<```````##RP``L>$`
M````LO<`````\]/2TP``P/4```````#=WP````#S[O'G``"T_0``````````
M````````````````````````````````R/(```````#2\P````#T[@``T^(`
M`````````-',``#JWP```````+KI````````````````````````U]D`````
M````````````````S?4``/+QQ_H`````````````````````^-G"U```````
M````Y?8``````````,7=````````````````\N??[0````#+R@````#ZVP``
M`````+7H``"FTP```````````````+7]`````,GY``#BY```O?L`````I-?%
MS@``````````U<[FU@``````````O>4```````````````#-WO/L`````.#M
M````````````````````````[.R^^^O?``#XX0``````````````````````
M``````````````````````"^^0``````````\]"JX.+H`````-3B_=(``*CE
M`````````````-/9``````````#>TP``N/2\]_W<``#LZ.?D`````/?C````
M`````````*CL````````````````\?H`````````````\N4`````]-"OTN7<
M``````````"ET+3QL?SXS`````#&W='Z``#?]P````"H^@````````````#U
M[@``SMX``````````//G`````*SWQ.OA[:O@Q]T``````````+/2O](`````
M``#,R@``````````O_L``````````/WEY=W-V`````````````#T[```````
M``````````````#UT`````#MZ-+0``#8V0``````````````````````````
M``#F]@````"JVP```````.#W````````````````````````````````V=@`
M`*/T`````-WT``````````#1[P````"UV0````"K[0``M^,``````````+ON
MM,T``//@S>H``````````/7L[N@``*G+K_$`````````````````````S<H`
M`*GL``#K\@``[_T``//Y````````````````````````P>8`````V.P`````
M``"L[0``SNH``-_H``````````````````````````````````#/W@``````
M`````````*;2`````/3GUM$`````PN;CXP``````````L.0```````"TV```
M`````````````````````````````*7V`````````````-[S``````````"E
MUP``````````Z/<`````QN@`````````````````````````````````````
M`````.;[``````````````````#FW0```````/[<````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#:V```````````````````K-JP
MZ@````````````````````"XXP``````````````````````````````````
M````````````````````````````````````````JLKYX0``L>H`````````
M`.SR`````.[Z````````````````````````````````````````````````
M`````-7N``````````#T^0````#LT@``````````````````````````````
M`````````````````````````````````````````/O[````````\/T``+W@
MX\X```````````````````````#&^```````````````````````````````
M````````````````````KMX`````````````````````````````````````
M``````````````````#%WP````"^Y0``````````````````````````````
M`*WMZOH`````[LVF[0``KNWM\```H=T``*_M^/P``.O8````````^<RUS0``
M````````J?H``-WA``````````#5XL_M````````HMT`````ROD``.CJ``#M
MY0````````````````````#KTP``U.GZX<SD``#DX<?H`````-O.````````
MU=P``+7W\_SS\*_.M?'2[\CH\>L`````````````U,N^X/CCZ>JR_```````
M``````#TX```X,\``*7N`````*KZP^:RX:O*``#DX[OI`````````````-;B
M\O,``-;NLNKVT-GLR]JHSP``````````H]T```````#;V```SOG5Z='C````
M`+S2````````````````K-C,\P``^\W6]@``]>?OZ/GCN]+S\_OC``#0WK#.
M``#WUMGQ`````````````,'UQ-P``+OU``#1W@```````````````.;<````
M`-+>`````.+M]N[/ZN[P_.,``-_3]-.SX0``M.$``````````-/T`````,;?
M``````````````````````````#6Z0```````*O;````````````````````
M`*;V````````````````N>/%ZZGTMLWYT@``K=KCTM'/``````````#<R_K,
M``#=SP````"IZ```N^.ZXP````#:X````````/?N`````````````+/<````
M``````#UTP``IM<``+7VV]<```````````````#5X0````#JU```H]\`````
M`````````````-_]````````````````````````````````````````````
M``````````````#WT-3M````````````````````````````````````````
MJLL``````````````````-OD``#[X:++``````````#@TP``O^0``,#[``"^
MVLWD``"YU@```````,#O``#\X0``````````````````````````````````
M`````````````````````````````+GV````````````````Q]\`````````
M`````````+'D````````````````Y]SHW````````-;Z``#VTP``````````
MVO$``/+Z````````````````````````_>(`````````````S]7XT`````#?
MS0````#+]0``\.2KRP``Q-<``````````````````````````````````/[B
M``#:W0``````````````````````````````````````````````````````
M`````````````````````````````````*[:[LH```````"YU0``````````
M`````````````````````````````````````````````````````*'C````
M`./H`````*OS````````````````````````````````````````````````
M`````````````*G/````````]],`````````````````````````````````
M````````````\=0`````Y,X``/+H``````````````````#UY0``````````
M````````````````````````KN<``+K6``#LW\#D````````````````````
M````````````````````Y.@``````````+78````````W.0`````````````
M``"Y]+;Q`````-[BM>$`````[\VG\>7.W<L`````X]D`````K/,`````^="K
M[-/>Z?<`````]?D`````````````WN'NRP```````+SCUO@`````[ML`````
M````````\?T``````````+;W``````````#>]`````#M\@``V=L``*CP````
M``````````````#]X0````````````#4W@``K.``````````````X^T`````
MX=,``,C?``````````"VV0``K/W3[P```````,'DZ_@``*S;``````````#&
M_`````````````````````"MV````````````````````````+KV``#?V]/3
MQ_@`````````````````````````````````````SLK!^+32`````+3<N?K/
MR@``L_SJZNOJ^M``````````````Y.T`````Y]T`````R=\``````````.W?
M`````````````+SN``#![P````#2S```I-T```````#*WP````````````#X
MTZCQ````````M\T``-3O``````````````````#=Y.[?K,N\Z0``````````
M``#LZ@```````,O?`````````````+_YK];&U0````````````"JSP````"I
MS@````#XU@```````+?Q^.X```````#9V=_S``#(^,;.````````````````
M`````.;5````````````````YO0`````Q>;5[P````#OR]_\````````````
M`*?<`````.?6`````````````,GX``````````#2XP``O>,``.'/P/#:[```
MU]WP^P````"L[````````*GP````````````````U_K!^P``P-(`````````
M`````````+#E````````Y>T``````````*W+``"P^0``````````````````
M``````````"E]P``KLL``*_:``"VV```````````````````I].R^P``Q/T`
M`*WL````````````````H?L```````#IY>[I``#T\_/XP?"OWK#X`````.#S
MK^<`````````````K=L``+7F`````*CY`````-C=V>C6[P```````.+3``#?
MX@````#@_,C7K?T```````#OW]/,^=,``````````/#4Q]O5W@``````````
M]/```-#5V>4```````````````#'_-;<X.(```````"PV@``````````````
M`*/S``#LTP``R_0```````#%_0````````````#]XP``L?D`````````````
M``#[T-OL`````````````````````+SUI/+.V,_8````````````````]_4`
M`````````````````````````.'V````````````````````````M](`````
M`````````````.S[``#(W0``````````````````````````````````````
M`.CD`````,'2````````U_@`````````````N];6W@````"]]Z[L````````
MX=```/7@L^H``-;.``````````"ES```````````````````````````````
M``````````````#V[.'BON,```````````````````````#(_`````#PS0``
M]OD`````\-\```````"_Y0```````+_.``````````#A_+#MT?V[]@````#/
M^=KKP<H``+C2\<T``-/CYOT`````````````````````````````````````
M````````````````[>8```````#ZXP````"J\-#Y````````````````XOP`
M`*?X````````Y>'Y[@```````/;G[>H`````M/S"]0````#<UP``````````
M``````````#U\```Z-WMT_SU``"_V@``^\P```````#ZTZ3T````````````
M``````#7[P``P]0```````````````````````#C^P``````````````````
M``#M^P``K>``````[NJS^\+D````````````````````````````````````
M`.?VW=(``,S?`````,G\`````*GE]N"S]@````````````#^X0``````````
M\,L``._J\.H```````#`VK3X\NL`````````````P^0``````````-?I\>0`
M``````#OR@``````````````````U\X`````````````````````ROP`````
M``#A\P````#$RP``````````Y>,``,7+M.H`````O>D``,G7`````-OKL>T`
M`,/,OO?+_````````````````/3X``"WV0````#3\]3S````````Y/<``-'W
M`````+?8L<["R@````"T^\;+`````/;P`````.?5``#0Z@````````````#4
MS*_+`````````````*KTK^D`````P_78Z0``````````````````Z=T`````
M``#S\0``^]6[W@````#[]````````//]\OVF]P``````````````````````
M`,G=`````-/4``"HS```P=K5S```Y-D```````#*^@```````./E````````
MO-,```````#PR@``````````Q-````````#0RJOZZ^OXY^79````````````
M`````````````````````````````````````````````````````````-?1
M`````````````````````````````*3S````````^]3C_-CZ``#5\P``J\\`
M````\^O\U0```````````````-33_,T``.;9``#YXJ'BU.L``/?@LN3\S```
M`````.3[````````J_0``````````+W0``#QR@````````````````````"X
M[P```````,#7``#Z[O3]`````./3``#"^P``````````````````Z-6NV[;A
MM_@`````````````O^##^^K=``"BX@``INX`````````````Z/8`````````
M`/7V````````````````````````````````````````````````````````
MRMT`````XM```````````*;=`````.O=`````/GD`````*_C_-````````#\
M]```````````O,SJ]P```````````````.3E\=\`````X?<``/?YN>\`````
MV/@```````````````````````````````````````"I^0````````````#9
M^````````+WN````````QM@`````X^3.]0``````````V=T``````````.?9
MN=+#U0````#EVM#:``#9T=C.``#>RZST^]H``.GV\^BLS_#P``#]],C;````
M````````````````````````````````````P,[4X\_1]?$``/+-``#KSP``
M`````+C-````````````````IN/:T0``I?(`````````````IO(``,[D````
M``````````````#[TP``````````````````````````````````````````
M````````````````````````J?$```````#)\@``````````````````````
M````V._)Y@``N-CS^@``````````````````````````M?,`````I/@`````
M\]'(Y@``````````VO@`````````````````````````````````````````
M````Z=S7W@````````````#?RP```````.S/``````````#?]`````#TT;K2
M````````\M\```````"WX0``````````H^+\TP````#F[0````````````#)
MVP```````/KD``#>SP````#0S@``````````T]7U\Z[W`````,CO``#SS<_U
M\^7"\```````````````````````````````````````````````````````
M`-'*````````\>H``*;0`````````````````````-K9J_``````````````
MY^L```````#`Y;7\`````````````,3D````````````````````````````
M`*G,QOT`````````````M>H``*KENM\`````````````````````````````
M``````````````````````````#?X0``T=H``````````+CA``#TZ/W3````
M``````"DX@````````````#*\@```````````````````````.;:L_<`````
M``````````````````````````#-_0```````+;S````````````````````
M``````````````````````````````````````````````#7[@``````````
M````````Q/4`````````````````````I-@`````````````I_(`````````
M````````````N-FYV<GO``````````````````````````````````#.U@``
M``````````````````#+]Z[?]>@```````````````"UT@```````-73````
M`````````,ST_-H`````````````Z-D``.OWR?4``+SS``#2V@``````````
M``````````"UTP````````````"VZ`````#/UKKT``#)]P````"JS`````##
M\-;,````````T]```+W3````````^]L``.#+````````````````Y-/W]@``
M``"ZU<WSX<L``````````/3K`````````````*WT``"J_`````````````#L
M]P```````/;H``#GV@```````,SW````````````````````````````````
M``````````````````#!Y0``````````[N``````````````_=4`````````
M``````#FSJO\N]4`````J/(```````````````"EXKG-\NK'RP``],T`````
MK]O9[P````````````"ZS0````#Y_```````````\]_GSL+:``"MSP``````
M````^>>H^````````````````.+S````````\LJDWP````#$U```````````
M``#7S,+E``````````"[S0``VN_8[@``I]VFX@````````````#`X```````
M`+#6RO@``/K\``#^V0``````````L-X```````#LW>C:`````````````.#4
M``#YU@``U\W8W@````#X\@``UN0`````Q="N]```J-T```````#%[=;S````
M`-G>YN,```````````````"HTP``L-L`````VN6_XP```````+';````````
MZ=4`````````````P>#;[P````#I\`````"RUP``````````_=``````````
M````````````Z=D`````_M```.WLJ=,``*GRQ/``````XN+OZ0```````-'Y
M`````-GI`````````````-KHP]K$VL74``#ZYP```````````````.#-L.,`
M`++;Q/L``./S``"EV>?[R]W4T```MN:NX-K]`````````````````````+7<
M^."QYP``````````\/4``-S8QNT``````````+GA``#`X\#Y\.D`````V]D`
M`.3S````````MMSIY`````````````#%\,'CS/S-_```````````R_(``,SR
M````````S^0```````````````````````#;\0``V?H``+CQ]?WYX```````
M````^^>W_.3\Q?OGX[G8``#X]@````#%W-C,````````K^#G]```W._\S]WO
M``"J\@```````````````````````+[]`````*S*N_W'_0``````````LN<`
M`-'J]-\``````````.S1WN3#Y0``````````IMD`````O,T``.7S````````
M`````````````-7M`````+K9````````Y^VU^^SX``````````#GX```V<P`
M````QM0`````````````I><``/75OM,``/O\````````````````````````
M````````\N0`````]=\`````^.CM^`````#'S@````````````#V_0``````
M`````````````````-CH``#8S=;GVLP`````X\KVW\?PQO```+K8``#T\?#T
MS/4`````Y?P``````````,7J\^H``-O=``#7W````````````````/W>^?(`
M`,?5````````T-@``,CPH=&BT0```````````````-39Z-;*V0``L=K'V.+<
MSO/T]0````"Y\0````#3V@``ZO8```````#USP````"N_0``````````````
M``````#2R@````"TWP``````````W=>Z^J?NO?4``/7X`````.CM````````
M`````.'4``"CT=;A``````````````````````````````````#X^0``RMOY
MR]34``#<V0``ONX``.WW````````[M(`````YN'Y]P``````````````````
M[=T``-OH``"SVP```````/?1L.``````XM0``-?V``#YUP````#=V```_<VK
M\@````````````````````````````````````````````"]S<+X`````*SR
M`````*W*KLJNSP````````````#"XP````````````"WW```````````````
M````````````VMN[V?/*T_;XYO7J`````````````/;J`````/GV````````
M`````````````````````*_/`````-/*`````*_*L-*Z\0``L]?#X_WSVMX`
M`````````-O>`````-[O````````````````````````````````````````
M``````````#CXOON`````/??RM<```````````````````````#HSMO;````
M``````````````"[\0``````````\>D`````````````````````M_K&T```
M``"KS*CN`````/K+^?G]S/[3``````````#0Y`````````````#N\@``U=3-
MWP``N/S0T0``````````````````````````````````````````````````
M`````````````,WR`````````````````````-+W````````````````````
M`-3*``#9U0```````-[8````````````````````````V<T```````"I[KSV
M`````-O,`````````````,GP``#\_```R>C^]```````````_.?>UP``````
M````W-X``*SP_LSAS0``NN$``._;LMH`````````````````````````````
M`````*71N-P```````#VV```I-$``.+-``````````#JW`````#W\```RO"^
MT```W-T``````````-;4UM,```````````````#0[:'-`````````````+7?
M````````^-\```````````````"AU++.`````````````,KH``````````#U
MZP``````````````````U>/0]0```````*'U````````````````````````
M`````````````````````````````*?9`````````````````````*OE````
M````````````````````````````R^8``/'U````````````````````````
M``#%Y0````````````````````"C^=O@Z_8``/'+``#JV:+U````````T=<`
M`/C1^.KYZK/:``````````#?[P````#O\0``]N6_[N3B`````````````+_0
M``"L^M'UL^<`````````````````````````````````````````````````
M``````````````````````"^Z0````````````#.\K3;````````````````
M`````,[\``#NW0```````````````+3G`````````````+37````````````
M````M/<`````````````OLT``.G:``````````````````"PS]GWYO,`````
MV<X`````````````````````````````````````````````````````````
M````JLX``,C+``````````````````````````````````````````"GT```
MR_```,?0`````,7D``````````````````#@VP```````````````-K5``"G
MUP```````,#N``#V^```````````TO7I[0``O-D``,;E````````````````
M`````````````````````````````*/U`````-3:I^+\^P````#<\0``````
M`````````/3*````````^N@`````Z<X```````````````#XZ>7B````````
M``"YT/+4`````````````*;1``#.WP```````````````````````/3\````
M`````````````````````````````````````````````````*K3````````
MK,P``````````.#O````````Y>75T`````````````````````#\VP``````
M````YOP`````````````_LOJ[0``````````````````````````````````
M`````+'>``````````````````#C^0```````````````*+4]L\`````````
M``````````````````````````````#0U@```````````````.K5[O$`````
M````````````````````````````````````````````````````````````
M````R_H``````````*'E`````````````````````+'5`````````````.W/
M``#K[0````````````"RU0```````+S5````````````````````````XOVM
M\P``V_T`````````````````````````````````````L.D`````````````
M`````*?1`````./]L\X``````````````````.3]SOH``````````+#*``"G
M]P``L<\`````````````````````````````````````HN8``+;\K?+A[Z[S
MQMSKV0```````.#H``````````````````"HX0``````````]M7]SP````#=
MW@```````-'9````````ZN3/\@``O_<`````YN*HX@``````````````````
M``````````#6XP``T>T`````````````^>D`````````````````````````
M``````````````"QUK+>`````.C@`````*O3``#<ZP````"OWP``P\H`````
M_.X``,/]````````]NNRSP``````````[-D``+W9``#?V`````"XU+[K[]T`
M`/#=\=WRW0````"^V0```````````````````````````````````````,;[
ML\\`````````````````````````````````````````````````````````
M``````````````#][@```````````````*OD``#%V@``[-@`````````````
M``````````````````````````"HT0``````````````````````````````
M````````````J>(`````O-ZUYP````````````#PVP``XN_P\;3/````````
M`````````````````````/';``"QX```````````I=\``-+Y`````/WG````
M`*/F\?NPRZ[R``````````````````#GS0``W.@`````U^<`````P/<``./0
M````````H=H```````"]S`````"IT<S=`````/[CJM&JZ```MNKZ^<SFV/8`
M``````#'U````````,O9``#2V<O3]]BIVOCU`````-[>K_*I^```````````
M`````````````````````````````,C8`````,'N``````````#!^0``````
M````\]WZZ@``O?:[X;_-U/3-Y@``S_RB^P``W.```````````+OTU=H``++Y
M````````````````\OL``/;;``#?W@```````/+;`````````````-SX[O?H
MZP``^M(`````O/$`````VOH`````ZMK&VL'W`````+;G````````````````
M`````````````````````````````````````````````,?EK-8`````````
M`,?<`````````````*GA``"JX@``IM4`````U]0```````````````#0\@``
M^^H``-W@\_L``````````````````+WQ`````.?BU_T``,C.M^H``,#\``#G
M_>_W`````+77````````````````````````````````````````````````
M`````````````+KOW?$``+/>````````````````R^@`````W?@`````Q_O(
MU0``W]<``*G=`````````````+'I`````*WZV?;T^@````````````"J^```
M``````````#NY@``W,R\X>_@`````+_I_?S.Y@````#7X0``S^8``/'T````
M````````````````````````````````````````````````````````````
M``#SY`````#[Y`````#D^0``````````````````````````X^\`````[L^^
M]K+@_ORKT0```````/K7````````R/L``-?B````````````````H]3X\*C7
M````````Y^$`````O],```````````````#D[P``Q=?BZP````#G_`````"B
MY```Z.(``-#F``#H^^CT].6\]-7T````````````````````````````````
M````````````````````````````````````````MM\``+G\PN[UR@``````
M`.7OXLNDU```X-[]VL;DON@``````````-[@M/;2Z@``^_D`````PN```.3*
M``"WYP``_>H``-W9``"TVJKNZ?L``````````,O;M=H`````````````OO$`
M````K-,`````````````````````R?L``,_?`````,#3U^,``.;OT/P`````
M`````````````,#I````````T_4`````W.RW]P````"XZOG1````````````
M````R-P`````````````````````````````````````````````````````
M``"YZ@````````````#>\0````````````"VU[7/``"HV0````#N[`````"J
MW0``````````HLVNZ````````+WA``#1\@``````````P>D```````#\T@``
M````````````````M=L``.?S_M@```````#1_```LNVO]```H_L`````P?P`
M`*ONI=0`````````````````````````````````````````````````````
M````````````````\O0``````````-GN````````ROL`````````````X\V[
MV```V^7W^````````-3V`````````````````````*G7``#)RP````#1YLSP
M``````````````````````````"NV```T_G^U0``````````````````O-BP
M\@``````````J^+H\P````````````#"[P```````````````.SM``"XYP``
M`````````````````````````````````````/[:`````+[,`````/SRZ]H`
M`-CBUNT`````T=:SX`````#2_```R.L`````````````````````P=/-\```
M]\\```````````````````````#2[0``V-3)W/'7`````+O?`````*7S````
M````S?0``````````+_QL?@``/KI````````R_L`````U<H`````````````
M````````````````U/G*]P````#(U@```````````````.C\O?,``/[N``#^
MYP````````````#"TP``````````MM,``*W,^O:RUMC2````````````````
MV.<``````````````````````````*7C``````````"YYP``````````K?#,
M^Z'K`````*;4``````````#-^P``O=7?\0````#[]@``M-X`````````````
M``````````````````#KU0````#(Y0```````*3[N=0`````X=X``*/D````
M````M]<``.[X````````M=X`````TM8``-7YNN?5Z_?5Y^^^X0```````*[Z
M````````Z=;NU@```````````````+OG``````````````````#+[```````
M`````````+/5``````````````````````````````````"TS@```````*7[
M[N$```````````````"H]P``````````SOL`````````````O=@`````````
M`````````/W[``````````#I_```````````````````ML\```````#'[:SN
M``````````````````#=S```````````I_8```````#ZY@```````*3U````
M`````````-S]L^W)S@```````````````.CO`````+_A````````````````
MV_KCRZGW``"F^P```````+G<````````P/'([</O````````````````````
M`````````````````*W6`````,[]````````H>@`````````````````````
M]/NGU0```````/;Q``#3Y@``````````````````````````````````````
M``````#>S```````````````````LO@```````#KW````````````````+;]
M``````````#JY0````#@\0```````````````````````````````,S;S=T`
M``````#(U`````#MV0``````````I?4```````````````````````#[Y@``
M``````````#4Y@``````````````````````````````````````````R/T`
M`*'6O_T``-/\``"A[P``O.<`````````````[M$`````U>8`````\ND``+#?
M`````````````.#8NORO_<[P``#AVP````#)Y0``M.T`````````````````
M````````````````````P^````````````````#8XP``````````^^FHZ@``
M````````M_T`````I_L``,+I``````````#W_0````````````#9X@````#L
MW````````````````````````*+H``````````#PY@``````````````````
M^/WY_0```````+_V`````*?G``#7Y@``````````\]3)U```````````^M8`
M`/+7``#`X0``XMO8Y@```````````````````````+WG`````````````,_P
MOO.LX@````````````"W]?#@````````````````````````````````N/WH
MXP``I]3\Z-+Z`````````````._X````````````````````````T]8`````
M`````````````````````+35````````````````````````````````````
M`-#P``#P][/N`````+KJ``#3Z@````#)[:O=````````K.6A_0``T-^S[```
MT=\`````````````[>VX^/KW````````J_@`````````````X/0`````````
M````NM2SY```VND``+;>``"_V0``P-GOU@``````````S-D``*K:````````
M`````````````.7?````````````````Y?<```````"RS`````#YW^#7````
M````````````````````````````````````````````````````````````
M`````````````````````+O4``````````#Z_0``````````L\P`````\]L`
M`````````````````````````````````````````-+?``#*S@``VNX`````
M``````````````````#DY```S_L```````````````"WSP``P^X`````````
M`````````.K.``````````````````"MX@``````````````````````````
M``````````#AU_7Z`````,G5K/@```````````````````````````````#9
MYP````````````````````````````#I\P``````````[=C$X_'P````````
M``````````#EZ````````/K@Q.[>V0``````````````````````````HNNC
MZP```````````````,+\N^H``````````*OHXMX`````````````````````
M`````._M``"CZ```````````\<\`````````````````````````````````
M`````````+S4``#J_`````````````"^YP``\OP`````M-8`````KN(``+?3
MS/H`````````````````````W/H``+7MX^$``*SH``#=Z`````#I[P``````
M``````"]]```N,_;Z:S1````````````````Q]H``````````````````,GK
M``#,Z````````+?>``````````"\UN73`````````````-WZ````````````
M````UMH``+'*````````````````R-JFWP``L_G2\@``Q,H`````````````
M``#+S@````#US0```````+#]J-4``,'Q`````.GBRMRT[,#Z`````*C[J-``
M````[-H```````````````````````#NV0``^^````````#J[][Z`````,3@
M``"YSP``RM7BUZ_B``"XUP```````````````````````,WH````````````
M``````#:]@``````````HN_:XOSV`````-#[K=$``.3-``"NT>W<SN@``/GP
MM<[\Y@````#[U];0]=WQ]P``_?8``/?;``````````#J^]SIP=D``/+UQ>``
M``````````````#4Z@```````````````````````,+Y``"\Z@``Q=+1^\#G
MI>L``/K?HN.YUP``P^D``/WHK^@`````T_*I^Z78``````````#+U0``````
M``````````````````````````````#(T````````*_1X]<```````#&X```
MHM8``/#M````````````````````````````````\]<```````#4_```U]K?
MS```U/(``+#1``#@S```_=N_\P``T?``````````````N_P``+#B`````*7F
M````````V^(```````#>WP``Q^````````````````#O\@```````.',````
M``````#JU@``````````PN<```````"VS@``P/,``/[-````````TOL``/CX
M^_<`````O^@``````````````````+?H`````````````````````+;M````
M````````````````````NMP`````M,P`````````````````````````````
M``#W\0```````+CH`````/;*``"DY-;T````````YM\```````"GWP``Y]_!
MX0``Q.D`````R]S%Z0```````*/OINNCR^GC````````^]&D[P``Z^\`````
M``````````````````````````"TT```````````H\T`````YN@``*7O``#,
MT^W:``````````"ZUP``U?+E]>_9``````````"T^0````#4U<_]````````
MX]L``````````.'QMNP``````````/[[U],``+'1``"QRP``````````LM$`
M``````````````"RR\+Q`````.'TM?D`````P^'"X0``]^L`````````````
M````````````````J-\``````````````````,K+`````````````+GF````
M`````````-[XJOGWR@``M^T`````N-/6\@````#9U,7N\/(```````"RR@``
M``"[W```^/$`````````````M^P``````````,KE``#`]MW]`````./4XLP`
M`-3W````````````````Y=<``````````````````````````````````,/3
M``"FV```P?8`````````````]MT``,#-````````W.4`````````````````
M``````````````#+Y0````````````````````````````#$X0``````````
M``"PZ+#TZO/NV@``N]<``+'B````````````````````````````````````
M`````````````````*K7````````````````^]8`````````````````````
M``#?Y```ULH```````"HZP```````/[;``````````````````````````#"
M]@````"[[P``````````_=0`````R.````````"YZ```IN\`````````````
MI,T`````]-2AV]S;W=L`````````````W.X``,O+U?P```````````````#K
MS@``P<T`````T_L`````````````````````````````````````````````
M````````````````````````J_D`````````````````````````````U/4`
M`````````*G9`````-WIS=L`````SMT``,/G``#,[```````````````````
M[/D```````#,RP``````````_."HU```T^WOV```U_(``/C*[]H`````U-8`
M``````````````#-V0```````.[8``#!\@```````-/?````````\-H``.KB
M`````/W@`````/C8````````K_>VV@``U\H`````````````````````````
M``````````````````````#8\@``^=@`````````````````````W_H`````
M`````````````````````````````._/PMD``-+P``#1Y````````+?S````
M````````````````````````````X/H`````````````````````````````
M`````.SO`````````````++B``"]U`````#.V0``````````XO0`````````
M`````````````````````````*G4``````````#"S=KG````````````````
M`````````````-GR`````````````*K9````````````````````````````
M````OM@```````````````"MW````````````````.OB_-8`````^<H`````
MVM0``````````````````-?TH<P`````NL\`````````````````````````
M````````````````````````````````````N/4```````##V>C0````````
M`````,7C^.L``+'R````````N\\```````"MT^'H[,X```````"TX```````
M``````````````````````````````#CW@``````````````````````````
M`````````````/?=````````````````````````````````````````````
M````LO+V\]OV``````````#^UP````````````#?^```\O<`````````````
M`````````````````````````````*G0````````````````````````VN8`
M`````````````````````````````````*;U````````````````````````
M``````````"\U^/,`````-OF````````````````````````````````W=T`
M`````````+/1`````````````.WO``````````#>UO3D[^$`````^-T`````
M````````S^@`````````````````````````````Y<H```````"AW```M>``
M`````````````````````````````````````````*S\K?RGV```````````
MN.T```````"VVP``````````\-:O\P````"ES0``\=H`````````````````
M````````````````````````````````````````````J-@```````#DS```
M``"TT0````````````#8R@````````````#RV@````````````"G]0``````
M`````````````````````````*CU``````````````````"FY@``````````
M````````````````````````````````````````[-7XU?/:````````````
M``````````````````````#&XP```````.3>``#EWK71`````````````+;1
MM]&S\@```````````````-[I`````````````-/PM/(`````U/#DR]3[YO7J
MXP``YMX``````````-3?`````/GX``````````"N\```````````````````
M`````````````+C1``````````#?U@``U]``````````````````````````
M````H?SN[]C<``#?Z0``````````````````````````````````````````
M``````````#=Y?O]`````,G@````````R=8`````JM0``,SE````````````
M`.#I````````V-"B_+[4L^+GW@``````````````````O-RVTM7U````````
M`````*'.J?4`````^=T`````^MT```````````````#5\```````````W_8`
M`-KRZ^0``/'R`````````````````````````````````````````````+GL
M``````````#\_0``````````JN$`````V<H`````[^\``*KU````````````
M````^>P`````K?@``,+RP_8``-+7`````*+YUO``````````````````````
M`````````````/KP`````.#V``````````#SZ</R````````J]2SRJ;-``##
MS=K-`````````````,_9`````,3V````````W>[$YP``````````````````
M``"TX@```````````````````````.+?V^<```````````````"QZ```KOP`
M`````````,WE````````Z_H``+S/`````.+/]LT`````\.\``+[T``#-U```
M``"X\P```````*'I````````````````````````\O+K\P``U_``````U\\`
M``````````````#?SP```````````````````````,#HP>@```````#CSZ+I
M``````````````````````````"JT````````````````````````,'SJ]``
M`.34`````+SOH=@`````````````````````````````W]D``-?S````````
MO=P``.7,\>T`````XO$``-O4``````````"UX@````#FR@``KM,`````````
M``````#FS`````#3\>?U``````````#:R@``````````````````````````
M`````````````.[[``#%X0``````````````````Z=\``-[N`````,+W``"B
MV`````````````"LW0````````````"O\+W6````````````````````````
M`````*OA````````````````````````````````MOD`````]=0``,G0I^_L
MX@``ZMO,SNCUU?<``,W3``#^\P```````````````````````+70````````
M`````````````````````/[@``#[WP```````````````-WF````````````
M``````"DZ````````````````````````,W+````````J.\```````"T[@``
M````````V-JYT0``J=\`````L/,`````Q,P```````"WS@``````````````
M``````````````"I[P```````-7?`````-?M````````QNX`````````````
M`````+WOUOP`````]-L``*KON?@``.GU`````````````````````-GC````
M``````````````````````````````#&X0```````+_4``````````#HW@``
M````````````````````````````````````````````````````````````
M``````````````#J\```````````````````````````PO,`````````````
M````````````````K],`````V\H`````````````U_P`````V.W'X0``````
M``````````````````````````````````````#8]+/6K=T```````"^U0``
M``````````````````##\=_N````````````````````````````````````
M````````````Z]8```````#9]```````````````````YM<`````````````
M``"WV@```````````````````````````````````````/O=````````````
M`,_=`````````````````````*/8`````-G:``#8\,3O````````````````
MV.$`````````````U/$``/+M````````````````V]4`````W-7$\]?+````
M`````````+;B``````````#Q[P````````````````````````````#5^P``
M``````````````````````````#8TP``````````````````T-W9\+/+````
M````````````W=4`````````````````````````````````````````````
M`````*?-`````*S0``"ZT0``Q/$``+/E]?OAZ>#]O/P``*+:H]H``*'2````
M`._2````````[>(`````Z=[<SK7RY-#1W0``````````R.&WV^/?````````
M`````````````+GMQ?$``,_SJ]>LX0````#KXP``Q^X```````#)X?K*````
M``````````````#[\.'ZVO#GS/3:````````````````````````O\P`````
M`````````````````````````````.W.`````*G5XOH```````#ET```UNL`
M`-_L````````_-\`````UO?JWK3+`````+[O`````+7,`````````````+W/
M`````````````````````````````````````/+OM^(```````#HS```````
M``````````````#\\````````.#6``#&\0```````````````````````+CB
MJ^L```````"UR]'8``#.]/?S`````,;7``"[T:KW``#*[=/7^M@`````````
M`````````,7V`````,S1_-T``````````````````````````/W?``#E^0``
MRN``````_?*PTP``\_3)V@``WN8``````````+KXT.@`````^]@`````U>H`
M`````````*/6````````````````QO8`````````````````````````````
M`````-OR_.0``````````````````````````++H`````````````-K:``#<
M\M;[LND``*WN``#C^@``````````````````[MP`````ZO7@Y@``_?``````
M````````K-<`````````````Q?7@[@````#EVP``WMT`````\-FCZ0``````
M````````````````````^?$``,3RR^``````````````````````I.D`````
MN>(``````````````````+'CZ_RHS0``MLP`````V_``````````````````
M````NN8`````J<T`````````````P_,```````````````````````#9X0``
M``"K[P```````,7G`````.G@``#%\P````#`U+_5````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````KMT``/SY``#`S```````````````````
M``````````````````````````"BY0```````+C.````````TMC6^0``````
M``````````````````````````````````````````````"J\='.`````,?V
M``#KVP``_M\`````X=@``//W``#GUP````````````````````````````#^
MU`````"\T0``S^4``+;+``"XV@````````````#$S0````````````"^U@``
M`````+KB`````````````-C/````````S.#YZP````````````````````#]
M_0````````````#HU]C+````````XND```````"ZZ````````,?C````````
M``#-[```SNP``+_6````````I^,``-;?Z/T```````````````````````#A
M[JCV_=T``````````````````+OX``#1Z```````````U_D`````````````
M````````[LX`````S^P```````"EZ=76``#%S0``NNV]T0````"^SP````"[
M[````````+'2``````````#IS```Q-G\Z0``````````````````````````
M``````````````````````````"^T0````````````"\[`````"MY0``````
M`````````+#W``#JS````````,33`````,#6````````_=8`````````````
M````````````````H>$``+W>``"I]@```````*3:````````````````````
M``````````````````````"DUL;U``"BX<;I````````Q?(`````````````
MZ?3LUM/K``````````"][-SBZ][<\```O^L``,[7O]$`````````````````
M``````"K]0``````````_?D``-S*````````QLVV\@````#^W0```````+?,
MN-L``````````.G0``#=SL#K``"B_0````````````#+^```````````````
M``````#6ZK#Q``````````````````#.VP``P_<`````````````````````
M````````S]NDRP````#@^`````#7^P````#*ZZ'@````````````````````
M`````````,W.`````-S4````````V/T``````````/;2``````````"W\@``
M``#V^JKV]_KFV```L?0``````````````````````````````````-+H``#%
MRNO,``````````````````#NX@````````````"[X@``K?<```````#A^```
M`````````````````````.SS``````````"AW@``````````````````````
M`````````/WD`````.SC``"OW;#=`````+?+T^@`````````````````````
M``````````````````"CX>#2``````````#^\```````````INGRRP``````
M`````````//MV=S-X```````````VO>YVP``````````````````KLP``-O:
M``````````#'S0``````````````````````````L=T``*_8H^,`````[\X`
M````\_(``````````+/X``````````````````````````#.X```_?4`````
M`````.SK`````,73[/S;TNO4``"BW@```````.;E````````````````L/``
M`````````````````````````,35````````````````].T```````#MXP``
MPN@``/7M_-<``+OM`````*OV`````````````+CRR/8`````````````YM/=
M\K_/``"LZP```````````````,#/``"HYNG]``#!SP``W^#LW@``````````
MHN``````````````````````O_3OX@``\=G'\0``N,L`````````````````
M````_OFZV_7:`````````````````````.SVW-KD^@``S^``````````````
M``"RW0``````````J>8``//O````````````````````````````````````
M`````````.WS``````````````````````````#ZZP``YOD`````````````
M`````-W*WM4``-[*Y-\```````#]Y@``K/4`````````````]>0`````````
M``````````````````````#CZ0``R^WDSP```````-/8````````````````
ML]WLU`````"Y\@``M]\`````````````SLO8^P````#9T`````#2W?3WW.>E
MY```H_P``+O;````````NO+]Z<K0``#6]<79M.0``*?M````````````````
M`````````````````````````````+WJ_N8``,3WK?4``.#9````````M,H`
M````XOC"SP``ONP```````"TY<C-R.X```````````````````````#(YP``
M``````````````````````````#)S;?Y`````.CQ\MGUV[7*QMD```````#)
MV```````````````````````````````````J]D`````````````````````
M`````````````````````+SM`````-38````````VMP``+SB`````.W\X.S^
MT@``Q^FJY@```````````````/#B````````````````N_H``*[UJOL`````
M`````/OL``"_[-C\````````````````````````````````````````````
M`````````````````````````````````````````.74````````P_D`````
M``#B[@``````````````````````````````````Z=?V[0```````.W>````
M``````````````#LS```[N,`````````````U.@```````#X^@``````````
M`````+3=M>2PV`````````````````````````````````````````````#5
MV````````.KT````````N<X```````#AUM+/``"VT````````````````*+.
M`````.[S`````````````/CS````````````````````````````````S-P`
M`,O0````````I/S*S=37H]X``.#D``````````#)[@```````-WB````````
M`````/[UK-0`````````````T=4``/#8P_C7Z@``````````````````````
M``````````````````````````````````````````````#7]0````"_V```
M````````P/T```````````````"MZP``````````JM4`````````````````
M````````````J.<``````````````````````````````````,KN````````
MY\H`````````````X_@``-W4`````-CJ``````````#9^_?M`````+7E````
M`````````*W0``````````#Q\0``````````````````````````````````
M`````````````````````+WB````````R.,``````````-79`````*K?````
M``````"\VP``````````````````````````````````````````Y/@`````
M````````^O$`````MN7O\P````#:^^#A``"LV0``Z_4``+;@`````,CI``#/
MRP``R>,```````#NW@````````````````````"^X@``````````````````
M``````````````````````````#OW```I=8`````````````\>(`````````
M`````````/[6````````````````````````````````````````````````
M`````*'9``#`V-O<`````+WMN-\``*7J````````K=<`````^?,``/CM``#'
M]0```````````````,KAX^L``-[R````````````````````````````````
M``#,^```V>H``,;3``#FVP````````````"O]0``````````\,X`````````
M`/[I`````````````+;[````````````````````````\N(``````````/+/
MN??SV0````#+X0``````````````````````````````````````````````
M````````````W=H`````N=H``````````````````/OK``"YRP````#Y[0``
M`````````````.#@``````````````````````````#`]```O/VQW^_C````
M``````"CX+G]````````````````````````L?````````````````#+S0``
M````````````````ONT```````#`U?#C^NT`````````````Y.D`````````
M``````#MU=WG````````````````]M2WY0```````.?;O^(`````````````
M``````````````````#+[@````#TU]WP````````J\X`````WN<```````#6
MULSA`````+/H`````````````````````````````.[EHMP`````T.``````
M``````````````````````````````````````````"UU0``````````````
M``````````````````````````````"AU0``````````````````````````
M``````````#;^P``R_D```````#SRZ7T`````````````,CZU]8``.7IW/L`
M`````````````````-#]````````````````````````````````````````
M`````/;[``````````````````````````````````````````"EV@``O=L`
M``````````````#B[````````````````````````````````````````/?-
MWO```````````,GV````````````````````````````````````````````
M`````````````````````````````````._>````````L=,`````````````
M````````[OP``````````,/H``#(\0```````/'.``````````#M^0``````
M``````````````#T\@``````````````````````````````````````````
MMN0``+GU``#PW/'C``````````"EZ```````````````````````````````
M`````````+OR``"DW@``S-H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````.G*````````````````VN,``-G\
M``````````````````#:Z@```````````````,3Y``"DXP``````````````
M``````````````#=^P``RN\``,3H````````````````````````S-4`````
M`````````````````````-?K````````````````````````````````````
M`````````*W9`````*O[````````````````````````````````````````
M``#9TP```````````````*+5````````````````````````WO8`````````
M````````````````````````````````````````````````````````````
M``#VV@````````````````````````````#1X`````"HZ0````#Y]0``````
M`````````*_Z``#\ZP````#JX````````````````++C````````````````
M``````````````````````````````````````````````````#%U0````#C
M\>[5``````````````````````````````````#,S0``````````V>T`````
M`````,'8``````````#L^@````````````#K\0````````````"\^N+F````
M``````#E^OKB````````MLH``+?D``#;Z@``^O4```````"L^\//_>L`````
M`````/KX`````+G?``````````#QX0``I-(``````````/OU````````````
M````VM#;T```ONJQV0````````````"WR@````#GTP``Y?@``````````++3
M````````P.+?\@```````````````.7-````````````````````````````
M````K/D`````````````````````S<T`````````````````````````````
M``"N[J[6````````````````````````````````ZM<``````````.#GKNL`
M``````#9SP````#-W/OM``#PW@``Z]<```````````````"EW@``````````
M````````````````U]_0V]';`````*/5``````````"R\```````````````
M`````````-S<`````````````````````.C*``#F^,[<``````````#<ZM+;
M`````````````````````````````+/I``````````#;]P``````````````
M``````````````"HXP``KM<`````X>``````````````NLL`````T>4`````
M````````````````````````````````````````````````````````````
M````W-```````````,'5`````````````,K8``````````````````"IXP``
M`````````````````````````````*3@``"IZ0``Q],`````W=RN^```````
M`+C,````````KM````````#RV`````#*XP``````````````````````````
MK\P``````````````````*W4T?8``````````````````,S0````````````
M``````#&R@````#"U0````"ZS@``````````````````````````````````
M``````````#'R@``````````````````````````````````````````L/H`
M`````````````````````````````````````````-C?````````NO4`````
M`````````````.OE``#T[[7=``````````"JS0``\N,``/?[``#0]P``````
M````NOT`````X?W^]L#1`````,7H``"XY```Z.$```````#!S```[=(`````
M`````+[;`````.+@````````R?H`````S>$``+C*````````X/+)\0``````
M``````````````````````````````````````````````#QW@```````-_P
MQ/@`````````````S.X`````\MX``,GG``#SXN'G`````,OC`````,SC````
M````^,^L[P``_OVE_+'ZV=\``-+@````````VO0`````````````````````
M````````RO$``*/.``````````"\\N/L`````````````*7@``"K]P````"O
MZP````````````#>Y0``I.&KS0``]-FFZ,[-Z>$``._\``#CX```````````
M``#!X@``I,X```````````````"FW@````#^ZP``W>O@\`````#;]```].(`
M````R-,```````#K]```M>X``-CU`````-_5````````Y=8``````````+#K
MX_0``````````,WC``````````#T]++Z`````/7OW\H``+'KO^T`````R?T`
M`````````*;DI/FS\```[.4```````#GT0``Q]G7Y-WJ``#WU```````````
M`````````````+K:``#-V@```````,SY``#:X;_;``#%S-#LN\L``//>````
M`*KI``````````````````#(V0````#C[KW7````````````````Q,\`````
M````````S=```````````````````*;\``````````````````#[\0``````
M````TOW!T0````````````````````#;XP``R=,``,_<````````````````
M````````[<P`````````````I]X`````N^:A[````````+G,`````-[[````
M`````````.+G`````,'4````````````````````````J-P`````````````
MPN(``-CST^4`````V?,```````#&\P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-O-``````````````````"LS0``P_P`````
M`````.?4``#"T0``I?D``-7H`````````````````````,[C``````````#*
MU````````````````-K?`````````````````````-_[X^<`````````````
M`````````````````````/OXS^,``````````````````+#U````````````
M``````#GV```R=D``````````````````````````````````````````*_X
M]N\``+;=K^[XS0``````````N-ZG_/SWL?>[SJ'T`````,WNKN$`````P^S^
MSP``O_CBV.C3`````*C>Y/3"[```]=G%^=/=\=;\[/#\`````,#MN<H``.3N
M````````````````X?(``+G>````````````````\M8``/3>``#;WP``T]L`
M`.?ZX]C!]```M]T```````#U\@````"NU````````````````//6````````
M````````N-W%S]_?````````````````OO*A]@``R^O\\0``Q_,`````Z^``
M````````````_.T`````V^$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````Y>X``/7>````
M``````#3^@``````````R_$`````K]"YW0````##T0``````````````````
M````````````````L?4``````````,;J````````````````````````````
M`````````.'P````````````````````````K/8``````````-GU````````
M``````````````````#K\````````````````+K=````````O_(`````````
M`````````,7W``````````"BV_;R`````+K*````````````````````````
M`````/7W``#ERP```````.;N``#3X```````````I<X```````````````#8
MU@```````*_4````````````````````````````````````````````````
M``````````#)Z0``````````SM/"]```````````````````````````````
M````YLL`````````````````````````````H?$`````````````LNL`````
M`````*+Q````````````````````````````````L^L``+3P`````/3+L-2R
M\[?[`````````````````````````````````````.SU`````````````.?N
MLO0``````````````````````````````````````````````````.WU``#S
MSP``````````````````````````XO``````````````SNX`````S/$`````
MN.4`````````````````````````````````````````````````````````
M`````````````````/77\^/ESP``````````````````````````````````
M````````````````QL\```````````````````````"S\]CD^<_:SP``````
M````S?H```````````````````````````````#CY@``````````````````
M``````````#B\@```````````````````````````````.[U`````+O*````
M`-SC``````````#RS@``V=8```````"P[@````````````````````#E],+8
MT-SNS`````````````#@U<KVROW6V,_T````````````````IM:^W```U-O'
MUP``````````_O(```````#-\0``````````P^+>W```W]P`````K>^KY@``
M````````W?F_Z@```````*[O````````T/3SS@``````````````````````
M``````````````"LY@``WLX`````^=4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M]./0S0```````````````+C5`````/WW``"IW```````````]MX``*K<X_*T
MZ=S2````````````````````````````````````````YND`````]N,`````
M````````````````RN<`````SM``````]]H`````````````````````````
M````````````````````O,H```````#H[M[:``#W\@````#[X@``ILP`````
M`````+O:``#I[@```````-KU`````-SWZN'!SK'4``"Q_;WF``"M^P````#G
M^```SN$``.+W[_7'SP````"RU._,``#HU```S^[7]P````"FX,'6W.'C\.3Q
M\=RGU@``````````````````````````]?0`````SO'D\@````"PT`````#O
M[````````+KY``"UZP````#MU,3B``````````#GZ0````"TZZ'J``"\^*;.
M``#&^=K\``"SU+G3WNH```````"KZ0````#AX<_3]O0``,#JS^$``+K,````
M`````````.KN````````Y/"T\^[4`````,#R`````.7Q``##]-3@``"VZP``
MH=?HRP``K?FMZ>38L_K%XKW\`````,3LL=@``*O<``````````"DU0``Z>L`
M``````"[Z````````-?8`````````````````````*[[X=$`````P-L``+[U
M``#WW@``````````^\K&]\C/````````T.$`````T.X`````````````````
M````].D`````````````````````],X`````````````````````````````
M`````````````````````,W5`````-O/````````````````N]T`````````
M`*S.``````````````````#HZ0``````````````````M-0``````````,?D
M````````````````````````````````````````V_4`````P?H```````"I
MW@``````````````````````````````````^-0`````````````]^\`````
M`````+/3````````````````````````````````````````````````````
M``````"WZ_COW/7,[=7;S_$```````#0\0``````````````````````````
M`````````````++U````````````````KMFLU0``QN(`````````````````
M````H_T``.7[J]\`````````````````````````````````````]>(``*WV
M``"S]0``M?```````````*7A````````````````````````W?4`````````
M````````````````````````````HNS][0``M/6X^P``H]L`````RM;9RP``
M````````````````````````U.4```````````````#Z\P``N.L``+?@[-?L
M\:_EX=7MU]'1`````````````/+A^>\```````"\W=SV`````````````.7P
M````````Q/0`````Z>D``````````````````````````/OS````````````
M`````````````````````````````````````````````````._4`````*+,
M_O>\WP``````````S>L```````````````"WT```````````````````````
M`````````````````````````````````,+6`````````````*WH````````
M``"O[Z7+``````````#IRP```````.CZ````````````````````````````
M``````#&S````````.?F`````,?J````````I-L``,G/_.+Z[P``````````
M````````````````````````````````````````````````````````WNL`
M````R/4``-[4`````````````````````````````-7@``"P[P````#'X@``
MK]D```````#G^0``````````````````````````````````````````````
M````````````Y><`````RL_1X0``R.(`````````````````````````````
M``````````````````#[[P````#Y^@````#RW```````````````````````
M``````````````````````"GX`````````````#H^```````````````````
M````````````````ZLL```````"\RP``````````````````XM8`````````
M````````````````````WO4``````````````````-_U``"V[@```````/;B
MRM/\[\31L>\``,71``#>T```X=D`````N.``````T<VY\P``````````````
M`````````````````````````````````````````````````,SG``"HUJ?.
M``"UU````````````````,CD````````````````M-,`````````````````
M``````````````````````````````"YZP```````````````/7+````````
M````````W?8``*/Q``````````````````````````````````#'S```````
M````````````RND``/#A````````X/4`````````````````````K_L`````
M``#1RP``````````X/OE\@````#P[```````````````````````````````
M`````````````````.SP``````````````````````````````````#K[@``
M`````````````````````````````,OI`````/#,`````*_7````````````
M`````````````````````````````````*'S````````````````````````
M``````````#U_```````````````````````````````````````````````
M````I/$```````````````````````````````#6X`````````````"R[P``
M`````````````````````-'T`````*'W````````````````````````````
M`-'Q````````````````````````````````_,K]R@``````````````````
M``#.S@``````````````````````````````````````````````````````
M`````````````````````````````````,CS``"Z\\FGRJ?+I\RGS:<`````
M``"ZI[NGW*?=I]ZGMJ>WI[BGU*?5I]:GUZ?8IZ&GHJ>CIZ6GJZ>LIZVGKJ>O
MI["GL:>RI[.GM*>GIZBGJ:>JI[VGOJ?EI^:GYZ?HI^&GXJ?CI[^GP*?!I\*G
MPZ?$I\6GQJ?'I\BGSJ?/I]"GT:?2I].GVJ?;I^.B[*>FI^"G[Z?AHKRG[:>U
MIP``````````N:?JIP````#KIP````#?IP``Y*(`````Y*?NI^FG`````*&A
MHJ&CH:BA``````````"TH;6AMJ&WH;BAN:&ZH;NAO*&]H0``ZZ&RH;.A````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"AJJ*JHZJD
MJJ6JIJJGJJBJJ:JJJJNJK*JMJJZJKZJPJK&JLJJSJK2JM:JVJK>JN*JYJKJJ
MNZJ\JKVJOJJ_JL"JP:K"JL.JQ*K%JL:JQZK(JLFJRJK+JLRJS:K.JL^JT*K1
MJM*JTZK4JM6JUJK7JMBJV:K:JMNJW*K=JMZJWZK@JN&JXJKCJN2JY:KFJN>J
MZ*KIJNJJZZKLJNVJ[JKOJO"J\:KRJO.J````````````````````````````
M``````"AJZ*KHZNDJZ6KIJNGJZBKJ:NJJZNKK*NMJZZKKZNPJ[&KLJNSJ[2K
MM:NVJ[>KN*NYJ[JKNZN\J[VKOJN_J\"KP:O"J\.KQ*O%J\:KQZO(J\FKRJO+
MJ\RKS:O.J\^KT*O1J]*KTZO4J]6KUJO7J]BKV:O:J]NKW*O=J]ZKWZO@J^&K
MXJOCJ^2KY:OFJ^>KZ*OIJ^JKZZOLJ^VK[JOOJ_"K\:ORJ_.K]*OUJ_:K````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"AI**DHZ2DI*6DIJ2GI*BDJ:2JI*ND
MK*2MI*ZDKZ2PI+&DLJ2SI+2DM:2VI+>DN*2YI+JDNZ2\I+VDOJ2_I,"DP:3"
MI,.DQ*3%I,:DQZ3(I,FDRJ3+I,RDS:3.I,^DT*31I-*DTZ34I-6DUJ37I-BD
MV:3:I-NDW*3=I-ZDWZ3@I.&DXJ3CI.2DY:3FI.>DZ*3II.JDZZ3LI.VD[J3O
MI/"D\:3RI/.D]*3UI/:D]Z3XI/FD^J3[I/RD_:3^I```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"QJ;*ILZFTJ;6IMJFW
MJ;BIN:FZJ;NIO*F]J;ZIOZG`J<&IPJG#J<2IQ:G&J<>IR*G)J<JIRZG,J=^B
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"Q
MJ+*HLZBTJ+6HMJBWJ+BHN:BZJ+NHO*B]J+ZHOZC`J,&HPJC#J,2HQ:C&J,>H
MR*C)J,JHRZC,J````````-ZBYZCHJ.FHZJCKJ.RH[:CNJ.^H\*CQJ/*H\ZCT
MJ/6H`````````````.>IZ*GIJ>JIZZGLJ>VI[JGOJ?"I\:GRJ?.I]*GUJ0``
M````````````````````````````````````````````````````````````
M````S:G.J<^IT*G1J=*ITZG4J=6IUJG7J=BIV:G:J=NIW*G=J=ZIWZG@J>&I
MXJGCJ>2IY:GFJ0``````````````````````````````````````````````
M``````````````````````#-J,ZHSZC0J-&HTJC3J-2HU:C6J->HV*C9J-JH
MVZC<J-VHWJC?J."HX:CBJ..HY*CEJ.:H````````````````````````````
M``````````````````````````````"AIJRFHJ:MI@``````````````````
M``"CILBFQZ:NIJ2FPJ;!IJ^FIJ;&IL6FL::EIL2FPZ:PIJ>FO*;)ILJFMZ;+
MILRFLJ:IIKZFS:;.IKFFSZ;0IK2FJ*;1IM*FN*:]IM.FU*:SIJJFU:;6IKJF
MOZ;7IMBFM::KIMFFVJ:[IMNFW*;`IMVFWJ;?IN"FX:;BIN.FY*:VI@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MQJ(``````````````````````````````````.&AX*$``,.BQZ+(HLNBRJ+)
MHLRB`````````````````````..AXJ$`````NJ*YH@``````````Y:'DH0``
M``"XHK>B``````````#?H=ZAPJ(`````VZ$`````W:'<H<2BQ:(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#:H=FA``````````````````#/HLZB````````````````````````
M````````T*(``-&B````````````````````````````````````````````
M````````````````````````````````````````````SZ$``,ZA````````
M````````````````````````````````````````````````````````````
M`````````+RBO:(``,"BNZ*^H@``OZ+-HMNBW*(``-VBVJ(`````JJ$`````
MKJ&OH0````"PH;&A`````-.BU*(```````"EH::A````````````````````
M````MJ(``,>AR*$``````````````````-BA````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/FI``````````````````````````#ZJ0``^ZG\J?VI_JD`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#)H0````````````"UH@``````````````
M`````````*2G`````."B``````````````````````````#EHN*B````````
MV:<``````````,JA````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M]ZCXJ````````````````/NH_*C]J/ZH``"PI;&ELJ6SI;2EM:6VI;>EN*6Y
MI0```````````````*&EHJ6CI:2EI:6FI:>EJ*6II:JE````````````````
M``````````````````````````````````````````#GH>BAYJ'IH>JAU:+8
MHM:BV:+7H@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"AH@``HJ(`````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````*.B``#3H:2B````````
MU*'TH0````#UH0```````+.B``"RH@````````````````````#NH0````#P
MH<2A``#0H0``````````JZ$``/RA_:'[H?JA\J'SH0``L:(`````````````
MQ:'QH0```````````````*VA[Z$`````````````````````````````````
M````````````````````UJ$``````````````````````````````````,&A
MU:$`````PJ'#H0``````````[*'MH0``````````````````````````````
M````````````````````````````^*'YH0````#VH?>A````````````````
M`````````````````````````````,&B````````````````````````````
M`-&A````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````TJ$`````
MIZ(`````````````````````L*(``````````````````*BBJZ*JHJVB``"I
MH@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#!
MI<*EPZ7$I<6EQJ7'I<BER:7*I<NES*7-I<ZESZ70I=&E``#2I=.EU*75I=:E
MUZ78I0``````````````````X:7BI>.EY*7EI>:EYZ7HI>FEZJ7KI>RE[:7N
MI>^E\*7QI0``\J7SI?2E]:7VI?>E^*4`````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````*>L
M`````````````````````````````````````*&LHJRCK*2LI:RFK*BLJ:RJ
MK*NLK*RMK*ZLKZRPK+&LLJRSK+2LM:RVK+>LN*RYK+JLNZR\K+VLOJR_K,"L
MP:S1K-*LTZS4K-6LUJS8K-FLVJS;K-RLW:S>K-^LX*SAK.*LXZSDK.6LYJSG
MK.BLZ:SJK.NL[*SMK.ZL[ZSPK/&L``#7K`````````````"NH@````"TH@``
M``#7H:>A``"CJ`````"IH0````#&H;ZA]ZGXJ:6B``#2HJ2AK*+VJ:RH``#Y
MJ/:H^JBOH@```````````````*&H````````````````````````HJ@`````
M``````````"_H:JH`````````````*VHK*D```````````````"AJ0``````
M`````````````````*.I````````````````P*&JJ0````````````"MJ0``
M`````````````````````````````````````````````**I````````````
M`````````````````````````````````````````*2HI*D`````````````
M``````````"EJ::HIJD``````````*>I````````````````J*BHJ:FHJ:D`
M``````````````"PJ:^HKZD```````````````"KJ*NI````````````````
M````````````````````````````````KJBNJ0``````````````````````
M`#U/<T]'4/E0H%+O4W54Y50)5L%:MEN'9K9GMV?O9TQKPG/"=3QZVX($@U>(
MB(@VBLB,SXW[CN:/U9D[4G13!%1J8&1AO&O/<QJ!NHG2B:.5@T\*4KY8>%GF
M67)>>5['8<!C1F?L9W]HEV].=@MW]7@(>O]Z(7R=@&Z"<8+KBI.5:TZ=5?=F
M-&ZC>.UZ6X00B4Z'J)?84DY7*EA,71]AOF$A8F)ET6=$:AMN&'6S=>-VL'<Z
M?:^04912E)6?````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(U.L7#)UVX!`DIB56U((6-Q9H5P77;=>.E]*
M7W=A7VQZ=89UX'QS?;%]C']4@2&"D85!B1N+_))-ED><RT[W3@M0\5%/6#=A
M/F%H83EEZFD1;Z5UAG;6=H=[I8++A`#YIY.+E8!5HEM15P'YLWRY?[61*%"[
M4T5<Z%W28FYCVF3G9"!NK'!;>=V-'HX"^7V019+XDGY.]DYE4/Y=^EX&85=I
M<8%4AD>.=9,KFEY.D5!P9T!H"5&-4I)2HFH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"\=Q"2U)ZK4B]@
M\H](4*EA[6/*9#QHA&K`;XB!H8F4E@58?7*L<@1U>7UM?JF`BXETBV.049V)
M8GIL5&]0?3I_(XI\44IAG7L9BU>2C).L3M-/'E"^4`91P5+-4G]3<%>#6)I>
MD5]V8:QASF1L96]FNV;T9I=HAVV%</%PGW2E=,ITV75L>.QXWWKV>D5]DWT5
M@#^`&X&6@V:+%8\5D.&3`Y@XF%J:Z)O"3U-5.EA166-;1ERX8!)B0FBP:```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````.AHJFY,=7AVSG@]>OM\:WY\?@B*H8H_C(Z6Q)WD4^E32E1Q5/I6
MT5ED6SM<JU[W8C=E165R9:!FKV?!:;UL_'60=GYW/WJ4?P.`H8"/@>:"_8+P
M@\&%,8BTB*6*`_F<CRZ3QY9GF-B:$Y_M5)ME\F:/:$!Z-XQ@G?!69%<1709F
ML6C-:/YN*'2>B.2;:&P$^:B:FT]L47%1GU)46^5=4&!M8/%BIV,[9=ES>GJC
MAJ*,CY<R3N%;"&*<9]QT````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````T7G3@X>*LHKHC4Z02Y-&F-->Z&G_
MA>V0!?F@49A;[%MC8?IH/FM,<"]TV'2A>U!_Q8/`B:N,W)4HF2Y276#L8@*0
MBD])42%3V5CC7N!F.&V:<,)RUG-0>_&`6Y1F4YMC:W]63H!02EC>6"I@)V'0
M8M!I09N/6QA]L8!?CZ1.T5"L5*Q5#%N@7>==*F5.92%H2VKA<HYV[W=>??E_
MH(%.A=^&`X].C\J0`YE5FJN;&$Y%3EU.QT[Q3W=1_E(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!`4^-3
MY5..5!16=5>B5\=;AUW07OQAV&)19;AGZ6?+:5!KQFOL:T)LG6YX<-=REG,#
M=+]WZ7=V>G]]"8#\@06""H+?@F*(,XO\C,".$9"QD&22MI+2F46:Z9S7G9R?
M"U=`7,J#H)>KE[2>&U28>J1_V8C-CN&0`%A(7)ACGWJN6Q-?>7JN>HZ"K(XF
M4#A2^%)W4PA7\V)R8PIKPVTW=Z535W-HA7:.U94Z9\-J<&]MBLR.2YD&^7=F
M>&NTC```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#R;!_GK4RU73EG&8_MIZG-%>+IZQ7K^?'6$CXESC360
MJ)7[4D=71W5@>\R#'I((^5AJ2U%+4H=2'V+8:'5IF9;%4*12Y%+#8:1E.6C_
M:7YT2WNY@NN#LHDYB]&/29D)^<I.EUG29!%FCFHT=(%YO7FI@GZ(?XA?B0KY
M)I,+3\I3)6!Q8G)L&GUF?9A.8E'<=Z^``4\.3W91@%'<56A6.U?Z5_Q7%%E'
M69-9Q%N07`Y=\5U^7LQ?@&+79>-E````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````'F<?9UYGRVC$:%]J.FLC
M;'UL@FS';9AS)G0J=()THW1X=7]U@7CO>$%Y1WE(>7IYE7L`?;I]B'\&@"V`
MC(`8BD^+2(QWC2&3))/BF%&9#IH/FF6:DI[*?79/"53N8E1HT9&K53I1"_D,
M^1Q:YF$-^<]B_V(.^0_Y$/D1^1+Y$_FCD!3Y%?D6^1?Y&/G^BAGY&OD;^1SY
MEF8=^59Q'OD?^>.6(/E/8WIC5U,A^8]G8&ES;B+Y-W4C^23Y)?D`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```-?2;Y)_ERB,I6&%HH^2GY*ODK^2SY0TXM^6=12%GP9Q"`+OES671>FF3*
M>?5?;&#(8GMCYUO76ZI2+_ET62E?$F`P^3'Y,OE9=#/Y-/DU^3;Y-_DX^=&9
M.?DZ^3OY//D]^3[Y/_E`^4'Y0OE#^<-O1/E%^;^!LH_Q8$;Y1_EF@4CY2?D_
M7$KY2_E,^4WY3OE/^5#Y4?GI6B6*>V<0?5+Y4_E4^57Y5OE7^?V`6/E9^3Q<
MY6P_4[IN&EDV@P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#E.MDY&3ZY5&%?'6%9?MV7F98!JM6M-;NUW
M[WH>?-Y]RX:2B#*16Y.[9+YO>G.X=5205E5-5[IAU&3'9N%M6VYM;[EO\'5#
M@+V!086#B<>*6HL?DY-L4W54>P^.79`050)86%AB7@=BGF3@:'9UUGRSA^B>
MXTZ(5VY7)UD-7+%<-EZ%7S1BX62S<_J!BXBXC(J6VYZ%6[=?LV`24`!2,%(6
M5S585U@.7&!<]ER+7:9>DE^\8!%CB6,79$-H````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````^6C":MAM(6[4
M;N1O_G'<=GEWL7D[>@2$J8GMC/.-2(X#D!204Y#]D$V3=I;<E])K!G!8<J)R
M:'-C=[]YY'N;?H"+J5C'8&9E_66^9HQL'G')<5J,$YAM3H%ZW4ZL4<U1U5(,
M5*=A<6=0:-]H'FU\;[QULW?E>O2`8X2%DEQ1EV5<9Y-GV'7'>G.#6OE&C!>0
M+9AO7,"!FH)!D&^0#9*77YU=66K(<7MV27ODA02+)Y$PFH=5]F%;^6EVA7\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````_AKJ'^(B/D%SY&VW9<-YS87T]A%WY:I'QF5[Y@DYU4P1K$FL^
M<!MR+88>GDQ2HX]07>5D+&46:^MO0WR<?LV%9(F]B<EBV($?B,I>%V=J;?QR
M!71O=(*'WI"&3PU=H%\*A+=1H&-E=:Y.!E!I4<E1@6@1:JY\L7SG?&^"THH;
MC\^1MD\W4?520E3L7FYA/F+%9=IJ_F\J>=R%(XBME6*::IJ7GLZ>FU+&9G=K
M'7`K>6*/0I>080!B(V4C;P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$EQB73T?6^`[H0FCR.02I.]41=2
MHU(,;<APPHC)7H)EKFO";SY\=7/D3C9/^59?^;I<NET<8+)S+7N:?\Y_1H`>
MD#22]I9(EQB889^+3Z=OKGFTD;>6WE)@^8ADQ&33:EYO&'`0<N=V`8`&AER&
M[XT%CS*7;YOZG76>C'A_>:!]R8,$DW^>DY[6BM]8!%\G9R=PSW1@?'Z`(5$H
M<&)RRGC"C-J,](SWEH9.VE#N6]9>F67.<4)VK7=*@/R$````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````?)`G
MFXV?V%A!6F)<$VK:;0]O.W8O?3=^'H4XB>232Y:)4M)E\V>T:4%MG&X/<`ET
M8'19=21V:W@LBUZ8;5$N8GB6ED\K4!E=ZFVX?2J/BU]$81=H8?F&EM)2BX#<
M4<Q17FD<>KY]\8-UEMI/*5*84P]4#E5E7*=@3F>H:&QM@7+X<@9T@W1B^>)U
M;'QY?[A_B8//B.&(S)'0D>*6R9L=5'YOT'&8=/J%JHZCEE><GYZ79\MM,W3H
M@1:7+'@`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#+>B![DGQI9&IT\G6\>.AXK)E4F[N>WEM57B!OG(&K
M@XB0!TY-4RE:TEU.7V)A/6-I9OQF_VXK;V-PGG<LA!.%.X@3CT69.YP<5;EB
M*V>K;`F#:HEZEZ%.A%G87]E?&V>R?51_DH(K@[V#'H^9D,M7N5F26M!;)V::
M9X5HSVMD<75_MXSCC(&019L(@8J,3)9`FJ6>7UL3;!MS\G;?=@R$JE&3B4U1
ME5')4LEHE&P$=R!WOWWL?6*7M9[%;@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````!&%I5$-5'U4#F:=9B=I
MGVZ_=I%W%X/"A)^':9&8DO2<@HBN3Y)1WU+&63U>56%X9'EDKF;09R%JS6O;
M:U]R87)!=#AWVW<7@+R"!8,`BRB+C(PH9Y!L9W+N=F9W1GJIG7]KDFPB629G
MF81O4Y-8F5G?7L]C-&9S9SIN*W/7>M>"*)/94NM=KF'+80IBQV*K9.!E66EF
M:\MK(7'W<UUU1GX>@@*#:H6CBK^,)Y=AG:A8V)X14`Y2.U1/58=E````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=FP*?0M]7H"*AH"5[Y;_4I5L:7)S5)I:/EQ+74Q?KE\J9[9H8VD\;D1N
M"7=S?(Y_AX4.B_>/89?TGK=<MF`-8:MA3V7[9?QE$6SO;)]SR7/A?925QEL<
MAQ"+75):4\UB#V2R9#1G.&K*;,!SGG24>Y5\&WZ*@3:"A(7KC_F6P9DT3TI3
MS5/;4\QB+&0`99%EPVGN;%AO[7-4=2)VY';\=M!X^W@L>49]+(+@A]2/$ICO
MF,-2U&*E9"1N46\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!\=LN-L9%BDNZ:0YLC4(U02E>H62A<1UYW
M7S]B/F6Y9<%E"6:+9YQIPF[%>"%]JH"`@2N"LX*AA(R&*HH7BZ:0,I:0GPU0
M\T]C^?E7F%_<8I)C;V=#;AEQPW;,@-J`](CUB!F)X(PICTV1:I8O3W!/&U[/
M9R)H?79^=D2;85X*:FEQU'%J=63Y07Y#A>F%W)@03T][<'^EE>%1!EZU:#YL
M3FS;;*]RQ'L#@]5L.G3[4(A2P5C89)=JIW16=@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````*=X%X;BE3F7
M9?E>4P%?BHNHCZ^/BI`E4J5W29P(GQE.`E!U45M<=UX>9CIFQ&?%:+-P`77%
M=<EYW7HGCR"9")K=3R%8,5CV6VYF96L1;7IN?6_D<RMUZ8/<B!.)7(L4CP]/
MU5`04UQ3DUNI7PUGCWEY@2^#%(4'B8:).8\[CZ69$IPL9W9.^$])60%<[USP
M7&=CTFC]<*)Q*W0K?NR$`H<BD-*2\YP-3MA.[T^%4%92;U(F5)!4X%<K669:
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````6EMU6\Q;G%YF^79B=V6G96YMI6XV<B9[/WPV?U"!48&:@4""
MF8*I@P.*H(SFC/N,=(VZC>B0W)$<ED26V9GGG!=3!E(I5'16LUA466Y9_U^D
M86YB$&9^;!IQQG:)?-Y\&WVL@L&,\)9G^5M/%U]_7\)B*5T+9]IH?'A#?FR=
M%4Z94!53*E-14X-98EJ'7K)@BF%)8GEBD&6'9Z=IU&O6:]=KV&NX;&CY-73Z
M=1)XD7C5>=AY@WS+?>%_I8``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````^@<*!\H,:A^B(N8ILB[N,&9%>
ME]N8.Y^L5BI;;%^,9;-JKVM<;?%O%7!=<JUSIXS3C#N8D6$W;%B``9I-3HM.
MFT[53CI//$]_3]]/_U#R4_A3!E7C5=M6ZUAB61%:ZUOZ6P1<\UTK7IE?'6!H
M8YQEKV7V9_MGK6A[:YELUVPC;@EP17,">#YY0'E@><%YZ7L7?7)]AH`-@HZ#
MT83'AM^(4(I>BAV+W(QFC:V/JI#\F-^9G9Y*4FGY%&=J^0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````)A0
M*E)Q7&-E56S*<R-UG767>YR$>)$PEW=.DF2Z:UYQJ84)3FOY26?N:!=NGX(8
MA6N(]V.!;Q*2KY@*3K=0SU`?4495JE475D!;&5S@7#A>BEZ@7L)>\V!1:&%J
M6&X]<D!RP'+X=F5YL7O4?_.(](ESBF&,WHP<EUY8O73]C,=5;/EA>B)]<H)R
M<A]U)75M^1E[A5C[6+Q=CUZV7I!?56"28G]C36619MEF^&86:/)H@')>=&Y[
M;GW6?7)_````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````Y8`2@J^%?XF3BAV0Y)+-GB"?%5EM62U>W&`49G-F
MD&=0;,5M7V_S=ZEXQH3+D2N3V4[*4$A1A%4+6Z-;1V)^9<ME,FY]<0%T1'2'
M=+]T;':J>=I]57ZH?WJ!LX$Y@AJ&[(=UBN.->)"1DB6439FNFVA345Q4:<1L
M*6TK;@R"FX4[B2V*JHKJEF>?85*Y9K)KEG[^APV-@Y5=EAUEB6WN<6[YSE?3
M6:Q;)V#Z8!!B'V9?9BES^7/;=@%W;'L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!6@'*`98&@BI*1%D[B
M4G)K%VT%>CE[,'UO^;",[%,O5E%8M5L/7!%<XEU`8H-C%&0M9K-HO&R(;:]N
M'W"D<-)Q)G6/=8YU&781>^![*WP@?3E]+(5MA0>&-(H-D&&0M9"WDO:7-YK7
M3VQ<7V>1;9]\C'X6BQ:-'Y!K6_U=#63`A%R0X9B'<XM;FF!^9]YM'XJFB@&0
M#)@W4G#Y47".>):3<(C7D>Y/UU/]5=I6@E?]6,):B%NK7,!<)5X!80``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````UB2V*(8QQD-F5X93EJBFLT;!EM,6_G<>ER>','=+)T)G9A=\!Y5WKJ
M>KE\CWVL?6%^GG\I@3&#D(3:A.J%EHBPBI"+.(]"D(.0;)&6DKF2BY:GEJB6
MUI8`EPB8EIG3FAJ;U%-^6!E9<%N_6]%M6F^?<2%TN72%@/V#X5V'7ZI?0F#L
M91)H;VE3:HEK-6WS;>-S_G:L=TU[%'TC@1R"0(/TA&.%8HK$BH>1'I,&F+29
M#&)3B/"/99('72==````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````:5U?=)V!:(?5;_YBTG\VB7*)'DY83N=0
MW5)'4W]B!V9I?@6(7I:-3QE3-E;+6:1:.%Q.7$U<`EX17T-@O64O9D)FOF?T
M9QQSXG<Z><5_E(3-A):)9HIIBN&*58QZC/17U%L/7V]@[6(-:99K7&Z$<=)[
M58=8B_Z.WYC^F#A/@4_A3WM4(%JX6SQAL&5H9OQQ,W5>>3-]3H'C@9B#JH7.
MA0.'"HJKCIN/<?G%CS%9I%OF6XE@Z5L+7,-?@6P`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!R^?%M"W`:
M=:^"]HK`3D%3<_G9E@]LGD[$3U)17E4E6NA<$6)9<KV"JH/^AEF('8H_EL66
M$YD)G5V="EBS7+U=1%[A8!5AX6,":B5N`I%4DTZ8$)QWGXE;N%P)8T]F2&@\
M=\&6C9=4F)^;H64!B\N.O)4U5:E<UEVU7I=F3';T@\>5TUB\8LYR*)WP3BY9
M#V`[9H-KYWDFG9-3P%3#5Q9=&V'69J]MC7A^@IB61)>$4WQBEF.R;0I^2X%-
MF```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/MJ3'^OG1J>7TX[4+91'%GY8/9C,&DZ<C:`=/G.D3%?=?EV
M^01]Y8)OA+N$Y86-CG?Y;T]X^7GYY%A#6UE@VF,896UEF&9Z^4II(VH+;0%P
M;''2=0UVLWEP>GOYBG]\^42)??F3B\"1?99^^0J9!%>A7[QE`6\`=J9YGHJM
MF5J;;)\$4;9AD6*-:L:!0U`P6&9?"7$`BOJ*?%L6AOI//%&T5D19J6/Y;:I=
M;6F&48A.64]_^8#Y@?F"68+Y````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````@_E?:UULA/FU=!9YA?D'@D6"
M.8,_CUV/AOD8F8?YB/F)^:9.BOG?5WE?$V:+^8SYJW5Y?F^+C?D&D%N:I58G
M6/A9'UJT6X[Y]EZ/^9#Y4&,[8Y'Y/6F';+]LCFV3;?5M%&^2^=]P-G%9<9/Y
MPW'5<93Y3WAO>)7Y=7OC?9;Y+WZ7^4V(WXZ8^9GYFOE;DIOY]IR<^9WYGOF%
M8(5MG_FQ<:#YH?FQE:U3HOFC^:3YTV>E^8YP,'$P=':"TH(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"F
M^;N5Y9I]GL1FI_G!<4F$J/FI^4M8JOFK^;A=<5^L^2!FCF9Y::YI.&SS;#9N
M06_:;QMP+W!0<=]Q<'.M^5MTKOG4=,AV3GJ3?J_YL/GQ@F"*SH^Q^4B3LOD9
ME[/YM/E"3BI0M?D(4N%3\V9M;,IO"G-_=V)ZKH+=A0*&MOG4B&.*?8MKC+?Y
MLY*X^1.7$)B43@U/R4^R4$A3/E0S5-I58EBZ6&=9&UKD6Y]@N?G*859E_V5D
M9J=H6FRS;P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````,]PK'%2<WU["(>DBC*<!Y]+7(-L1'.)<SJ2JVYE
M=!]V:7H5?@J&0%'%6,%D[G05=7!VP7^5D,V65)DF;N9TJ7JJ>N6!V89XAQN*
M25J,6YM;H6@`:6-MJ7,3="QTEWCI?>M_&(%5@9Z#3(PNEA&8\&:`7_IEB6=J
M;(MS+5`#6FIK[G<666Q=S5TE<T]UNOF[^>50^5$O6"U9EEG:6>5;O/F]^:)=
MUV(69)-D_F2^^=QFO_E(:L#Y_W%D=,'Y````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B'JO>D=^7GX`@'"!
MPOGOAX&)((M9D,/Y@)!2F7YA,FMT;1]^)8FQC]%/K5"74<=2QU>)6+E;N%Y"
M895IC&UG;K9NE'%B="AU+'5S@#B#R80*CI23WI/$^8Y.44]V4"I1R%/+4_-3
MAUO36R1<&F&"8?1E6W*7<T!TPG90>9%YN7D&?;U_BX+5A5Z&PH]'D/60ZI&%
MENB6Z9;64F=?[64Q9B]H7'$V>L&0"IB13L7Y4FJ>:Y!OB7$8@+B"4X4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!+D)66\I;[EQJ%,9N03HIQQ)9#49]3X5035Q)7HU>;6L1:PULH8#]A
M]&.%;#EM<FZ0;C!R/W-7=-&"@8A%CV"0QOEBEEB8&YT(9XJ-7I)-3TE0WE!Q
M4PU7U%D!6@E<<&&09BUN,G)+=.]]PX`.A&:$/X5?AUN(&(D"BU60RY=/FW-.
MD4\246I1Q_DO5:E5>ENE6WQ>?5Z^7J!@WV`(80EAQ&,X90EGR/G49]IGR?EA
M:6)IN6PG;<KY.&[+^0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````.%O-G,W<\SY7'0Q=<WY4G;.^<_YK7W^
M@3B$U8B8BMN*[8HPCD*.2I`^D'J029')D6Z3T/G1^0E8TOG3:XF`LH#3^=3Y
M05%K63E<U?G6^61OIW/D@`>-U_D7DH^5V/G9^=KYV_E_@`YB''!H?8V'W/F@
M5VE@1V&W:[Z*@)*QEEE.'U3K;2V%<);SE^Z8UF/C;)&0W5')8;J!^9V=3QI0
M`%&<6P]A_V'L9`5IQ6N1=>-WJ7]D@H^%^X=CB+R*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````<(NKD8Q.
MY4X*3]WYWODW6>A9W_GR71M?6U\A8.#YX?GB^>/Y/G+E<^3Y<'7-=>7Y^WGF
M^0R`,X"$@.&"48/G^>CYO8RSC(>0Z?GJ^?28#)GK^>SY-W#*=LI_S'_\?QJ+
MND[!3@-2<%/M^;U4X%;[6<5;%5_-7VYN[OGO^6I]-8/P^9.&C8KQ^6V7=Y?R
M^?/Y`$Y:3WY/^5CE9:)N.)"PD[F9^T[L6(I9V5E!8/3Y]?D4>O;Y3X/#C&51
M1%,`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#W^?CY^?G-3FE255N_@M1..E*H5,E9_UE06U=;7%MC8$AA
MRVZ9<&YQAG/W=+5UP7@K?06`ZH$H@Q>%R87NBL>,S)9<3_I2O%:K92AF?'"X
M<#5RO7V-@DR1P)9RG7%;YVB8:WIOWG:17*MF6V^T>RI\-HC<E@A.UTX@4S18
MNUCO6&Q9!UPS7H1>-5^,8[)F5F<?:J-J#&L_;T9R^OE0<XMTX'JG?'B!WX'G
M@8J#;(0CA92%SX7=B!.-K)%WE0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````)R6C5')5"A7L%M-8E!G/6B3
M:#UNTVY]<"%^P8BAC`F/2Y].GRURCWO-BAJ31T].3S)1@%30695>M6)U9VYI
M%VJN;!INV7(J<[UUN'LU?>>"^8-7A/>%6XJOC(>.&9"XD,Z67Y_C4@I4X5K"
M6UAD=67T;L1R^_F$=DUZ&WM-?#Y^WW][@RN+RHQDC>&-7X[JC_F/:9#1DT-/
M>D^S4&A1>%%-4FI285A\6&!9"%Q57-M>FV`P8A-HOVL(;+%O````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M3G$@=#!U.'51=7)V3'N+>ZU[QGN/?FZ*/H])CS^2DY(BDRN4^Y9:F&N8'ID'
M4BIBF&)9;61VRGK`>W9]8%.^7)=>.&^Y<)A\$9>.F]Z>I6-Z9':'`4Z53JU.
M7%!U4$A4PUF:6T!>K5[W7H%?Q6`Z8S]E=&7,979F>&;^9VAIB6IC:T!LP&WH
M;1]N7FX><*%PCG/]<SIU6W>'>(YY"WI]>KY\CGU'@@**ZHJ>C"V12I'8D6:2
MS)(@DP:75I<`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!<EP*8#I\V4I%2?%4D6!U>'U^,8-!CKVC?;VUY
M+'O-@;J%_8CXBD2.C9%DEIN6/9=,F$J?SD]&4<M1J5(R5A1?:U^J8\UDZ65!
M9OIF^68=9YUHUVC]:15O;F]G<>5Q*G*J=#IW5GE:>=]Y('J5>I=\WWQ$?7!^
MAX#[A:2&5(J_BIF-@8X@D&V0XY$[EM66Y9S/90=\LXW#DUA;"EQ24]EB'7,G
M4)=;GE^P8&MAU6C9;2YT+GI"?9Q],7YK@0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"J.-8Y^DQB44$]0
M5^9=IUXK8VI_.TY/3X]/6E#=6<2`:E1H5/Y53UF96]Y=VEY=9C%G\6<J:.AL
M,FU*;HUOMW#@<X=U3'P"?2Q]HGT?@MN&.XJ%BG"-BHXSCS&03I%2D424T)GY
M>J5\RD\!4<91R%?O6_M<668]:EIMEF[L;PQQ;W7C>B*((9!UD,N6_YD!@RU.
M\DY&B,V1?5/;:FMI06QZA)Y8CF'^9N]BW7`1=<=U4GZXA$F+"(U+3NI3````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````JU0P5T!7UU\!8P=C;V0O9>AE>F:=9[-G8FM@;)IL+&_E=R5X27E7
M>1E]HH`"@?.!G8*W@AB'C(K\^02-OHURD/1V&7HW>E1^=X`'5=15=5@O8R)D
M269+9FUHFVF$:R5ML6[-<VATH71;=;EUX78>=XMWYGD)?AU^^X$OA9>(.HK1
MC.N.L(\RD*V38Y9SE@>7A$_Q4^I9R5H97DYHQG2^=>EYDGJC@>V&ZHS,C>V/
MGV459_WY]U=7;]U]+X\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#VD\:6M5_R881O%$Z83Q]0R5/?56]=
M[ETA:V1KRWB:>_[Y28[*CFZ026,^9$!WA'HODW^4:I^P9*]OYG&H=-ITQ'H2
M?()^LGR8?IJ+"HU]E!"93)DY4M];YF0M9RY][5##4WE86&%98?IAK&79>I*+
MEHL)4"%0=5(Q53Q:X%YP7S1A7F4,9C9FHF;-:<1N,F\6<R%VDWHY@5F"UH.\
MA+50\%?`6^A;:5^A8R9XM7W<@R&%QY'UD8I1]6=6>P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````*R,Q%&[
M6;U@588<4/_Y5%(Z7'UA&F+38O)DI67,;B!V"H%@CE^6NY;?3D-3F%4I6=U=
MQ63);/IME'-_>AN"IH7DC!".=Y#GD>&5(9;&E_A1\E2&5;E?I&2(;[1]'X]-
MCS64R5`67+YL^VT;=;MW/7QD?'F*PHH>6+Y9%EYW8U)RBG5K=]R*O(P2C_->
M=&;X;7V`P8/+BE&7UIL`^D-2_V:5;>]NX'WFBBZ07I#4FAU2?U+H5)1AA&+;
M8J)H````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````$FE::35JDG`F<5UX`7D.>=)Y#7J6@'B"U8))@TF%@HR%
MC6*1BY&ND<-/T5;M<==W`(?XB?A;UE]19ZB0XE-:6/5;I&"!86!D/7YP@"6%
M@Y*N9*Q0%%T`9YQ8O6*H8PYI>&D>:FMNNG;+>;N"*83/BJB-_8\2D4N1G)$0
MDQB3FI/;EC::#9P13EQU77GZ>E%[R7LN?L2$68YTCOB.$)`E9C]I0W3Z42YG
MW)Y%4>!?EFSRAUV(=XBT8+6!`X0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````%C=93.50T5C9:,5R*<.!_
M6H`&@>V!HXV)D5^:\IUT4,1.H%/[8"QN9%R(3R10Y%797%]>96"4:+MLQ&V^
M<=1U]'5A=AIZ27K'??M];G_T@:F&'(_)EK.94I]'4L52[9BJB0-.TF<&;[5/
MXEN59XAL>&T;="=XW9%\D\2'Y'DQ>NM?UDZD5#Y5KEBE6?!@4V+68C9G56DU
M@D"6L9G=F2Q04U-$57Q7`?I88@+ZXF1K9MUGP6_O;R)T.'07B@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#B4450&5F972%^:84YK6'"M<+M]E8IJ62N!HF,(=SV`JHQ46"UDNVF56Q%>
M;VX#^FF%3%'P4RI9(&!+889K<&SP;!Y[SH#4@L:-L)"QF`3ZQV2D;Y%D!&5.
M41!4'U<.BE]A=F@%^MMU4GMQ?1J0!EC,:7^!*HD`D#F8>%!76:Q9E6(/D"J;
M76%Y<M:585=&6O1=BF*M9/ID=V?B;#YM+'(V=#1X=W^M@MN-%Y@D4D)7?V=(
M<N-TJ8RFCQ&2````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````*I9K4>U33&-I3P15EF!799ML?VU,<OUR%WJ'
MB9V,;5^.;_EPJ($.8;]/3U!!8D=RQWOH?>E_39"MEQF:MHQJ5W->L&<-A%6*
M(%066V->XEX*7X-ENH`]A8F56Y9(3P53#5,/4X94^E0#5P->%F";8K%B56,&
M^N%L9FVQ=3)XWH`O@=Z"882RA(V($HD+D.J2_9B1FT5>M&;=9A%P!G('^O5/
M?5)J7U-A4V<9:@)OXG1H>6B(>8S'F,280YH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#!5!]Z4VGWBDJ,
MJ)BNF7Q?JV*R=:YVJXA_D$*6.5,\7\5?S&S,<V)UBW5&>_Z"G9E/3CR0"TY5
M3Z93#UG(7C!FLVQ5='>#9H?`C%"0'I<5G-%8>%M0AA2+M)W26VA@C6#Q95=L
M(F^C;QIP57_P?Y&5DI50EM.7<E)$C_U1*U2X5&-5BE6[:K5MV'UF@IR2=Y9Y
MG@A4R%32=N2&I)74E5R6HDX)3^Y9YEKW75)@EV)M9T%HAFPO;CA_FX`J@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````CZ"?H%F*5.55"S5)-76EEI6[-;R&%W:7=M(W#YA^.)<HKGBH*0
M[9FXFKY2.&@64'A>3V='@TR(JTX15*Y6YG,5D?^7"9E7F9F94U:?6%N&,8JR
M8?9J>W/2CD=KJI97FE59`')KC6F7U$_T7"9?^&%;9NMLJW"$<[ES_G,I=TUW
M0WUB?2-^-X)2B`KZXHQ)DF^845MT>D"(`9C,6N!/5%,^6?U</F-Y;?ER!8$'
M@:*#SY(PF*A.1%$14HM7````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````8E_";,YN!7!0<*]PDG'I<VET2H.B
MAV&(")"BD*.3J)EN45=?X&!G8;-F685*CJ^1BY=.3I).?%356/I8?5FU7"=?
M-F)(8@IF9V;K:VEMSVU6;OANE&_@;^EO77#0<B5T6G3@=)-V7'G*?!Y^X8"F
M@FN$OX1.AE^&=(=WBVJ,K),`F&68T6`68G>16EH/9O=M/FX_=$*;_5_:8`][
MQ%087UYLTVPJ;=AP!7UYA@R*.YT64XQ4!5LZ:FMP=74`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"->;YY
ML8+O@W&*08NHC'27"_KT9"MENGB[>&MZ.$Z:55!9IEM[7J-@VV-A:V5F4V@9
M;F5QL'0(?820:9HEG#MMT6X^<T&,RI7P44Q>J%]-8/9@,&%,84-F1&:E:<%L
M7V[);F)O3'&<=(=VP7LG?%*#5X=1D(V6PYXO4]Y6^UZ*7V)@E&#W869F`V><
M:NYMKF]P<&IS:GZ^@32#U(:HBL2,@U)R<Y9;:VH$E.Y4AE9=6TAEA67)9I]H
MC6W&;0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#MRM(!UD4V:KT\94)I3#E0\5(E5Q54_7HQ?/6=F<=US
M!9#;4O-29%C.6`1QCW'[<;"%$XJ(9JB%IU6$9DIQ,81)4YE5P6M97[U?[F.)
M9D=Q\8H=C[Z>$4\Z9,MP9G5GAF1@3HOXG4=1]E$(4S9M^(#1GA5F(VN8<-5U
M`U1Y7`=]%HH@:SUK1FLX5'!@/6W5?PB"UE#>49Q5:U;-5NQ9"5L,7IEAF&$Q
M8EYFYF:9<;EQNG&G<J=Y`'JR?W"*``````*L`ZP%K`:L"ZP,K`VL#JP/K!BL
M'JP?K"&L(JPCK"6L)JPGK"BL*:PJK"NL+JPRK#.L-*P````````````````U
MK#:L-ZPZK#NL/:P^K#^L0:Q"K$.L1*Q%K$:L1ZQ(K$FL2JQ,K$ZL3ZQ0K%&L
M4JQ3K%6L````````````````5JQ7K%FL6JQ;K%VL7JQ?K&"L8:QBK&.L9*QE
MK&:L9ZQHK&FL:JQKK&RL;:QNK&^L<JQSK'6L=JQYK'NL?*Q]K'ZL?ZR"K(>L
MB*R-K(ZLCZR1K)*LDZR5K):LEZR8K)FLFJR;K)ZLHJRCK*2LI:RFK*>LJZRM
MK*ZLL:RRK+.LM*RUK+:LMZRZK+ZLOZS`K,*LPZS%K,:LQZS)K,JLRZS-K,ZL
MSZS0K-&LTJS3K-2LUJS8K-FLVJS;K-RLW:S>K-^LXJSCK.6LYJSIK.NL[:SN
MK/*L]*SWK/BL^:SZK/NL_JS_K`&M`JT#K06M!ZT(K0FM"JT+K0ZM$*T2K1.M
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````%*T5
MK1:M%ZT9K1JM&ZT=K1ZM'ZTAK2*M(ZTDK26M)JTGK2BM*JTKK2ZM+ZTPK3&M
M,JTSK0```````````````#:M-ZTYK3JM.ZT]K3ZM/ZU`K4&M0JU#K4:M2*U*
MK4NM3*U-K4ZM3ZU1K5*M4ZU5K5:M5ZT```````````````!9K5JM6ZU<K5VM
M7JU?K6"M8JUDK66M9JUGK6BM::UJK6NM;JUOK7&M<JUWK7BM>:UZK7ZM@*V#
MK82MA:V&K8>MBJV+K8VMCJV/K9&MDJV3K92ME:V6K9>MF*V9K9JMFZV>K9^M
MH*VAK:*MHZVEK::MIZVHK:FMJJVKK:RMK:VNK:^ML*VQK;*MLZVTK;6MMJVX
MK;FMNJV[K;RMO:V^K;^MPJW#K<6MQJW'K<FMRJW+K<RMS:W.K<^MTJW4K=6M
MUJW7K=BMV:W:K=NMW:W>K=^MX:WBK>.MY:WFK>>MZ*WIK>JMZZWLK>VM[JWO
MK?"M\:WRK?.M]*WUK?:M]ZT`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#ZK?NM_:W^K0*N`ZX$K@6N!JX'K@JN#*X.K@^N$*X1
MKA*N$ZX5KA:N%ZX8KAFN&JX;KARN````````````````':X>KA^N(*XAKB*N
M(ZXDKB6N)JXGKBBN*:XJKBNN+*XMKBZN+ZXRKC.N-:XVKCFN.ZX\K@``````
M`````````#VN/JX_KD*N1*Y'KDBN2:Y+KD^N4:Y2KE.N5:Y7KEBN6:Y:KENN
M7JYBKF.N9*YFKF>N:JYKKFVN;JYOKG&N<JYSKG2N=:YVKG>N>JY^KG^N@*Z!
MKH*N@ZZ&KH>NB*Z)KHJNBZZ-KHZNCZZ0KI&NDJZ3KI2NE:Z6KI>NF*Z9KIJN
MFZZ<KIVNGJZ?KJ"NH:ZBKJ.NI*ZEKJ:NIZZHKJFNJJZKKJRNK:ZNKJ^NL*ZQ
MKK*NLZZTKK6NMJZWKKBNN:ZZKKNNOZ[!KL*NPZ[%KL:NQZ[(KLFNRJ[+KLZN
MTJ[3KM2NU:[6KM>NVJ[;KMVNWJ[?KN"NX:[BKN.NY*[EK@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````.:NYZ[IKNJN[*[NKN^N
M\*[QKO*N\Z[UKO:N]Z[YKOJN^Z[]KOZN_ZX`KP&O`J\#KP2O!:\`````````
M```````&KPFO"J\+KPRO#J\/KQ&O$J\3KQ2O%:\6KQ>O&*\9KQJO&Z\<KQVO
M'J\?KR"O(:\BKR.O````````````````)*\EKR:O)Z\HKRFO*J\KKRZO+Z\Q
MKS.O-:\VKS>O.*\YKSJO.Z\^KT"O1*]%KT:O1Z]*KTNO3*]-KTZO3Z]1KU*O
M4Z]4KU6O5J]7KUBO6:]:KUNO7J]?KV"O8:]BKV.O9J]GKVBO::]JKVNO;*]M
MKVZO;Z]PKW&O<J]SKW2O=:]VKW>O>*]ZKWNO?*]]KWZO?Z^!KX*O@Z^%KX:O
MAZ^)KXJOBZ^,KXVOCJ^/KY*ODZ^4KY:OEZ^8KYFOFJ^;KYVOGJ^?KZ"OH:^B
MKZ.OI*^EKZ:OIZ^HKZFOJJ^KKZROK:^NKZ^OL*^QK[*OLZ^TK[6OMJ^WK[JO
MNZ^]K[ZO````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````OZ_!K\*OPZ_$K\6OQJ_*K\ROSZ_0K]&OTJ_3K]6OUJ_7K]BOV:_:K]NO
MW:_>K]^OX*_AKP```````````````.*OXZ_DK^6OYJ_GK^JOZZ_LK^VO[J_O
MK_*O\Z_UK_:O]Z_YK_JO^Z_\K_VO_J__KP*P`[`````````````````%L`:P
M![`(L`FP"K`+L`VP#K`/L!&P$K`3L!6P%K`7L!BP&;`:L!NP'K`?L""P(;`B
ML".P)+`EL":P)[`IL"JP*[`LL"VP+K`OL#"P,;`RL#.P-+`UL#:P-[`XL#FP
M.K`[L#RP/;`^L#^P0+!!L$*P0[!&L$>P2;!+L$VP3[!0L%&P4K!6L%BP6K!;
ML%RP7K!?L&"P8;!BL&.P9+!EL&:P9[!HL&FP:K!KL&RP;;!NL&^P<+!QL'*P
M<[!TL'6P=K!WL'BP>;!ZL'NP?K!_L(&P@K"#L(6PAK"'L(BPB;"*L(NPCK"0
ML)*PD["4L)6PEK"7L)NPG;">L*.PI+``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"EL*:PI["JL+"PLK"VL+>PN;"ZL+NPO;"^
ML+^PP+#!L,*PP[#&L,JPR[#,L,VPSK#/L-*P````````````````T[#5L-:P
MU[#9L-JPV[#<L-VPWK#?L.&PXK#CL.2PYK#GL.BPZ;#JL.NP[+#ML.ZP[[#P
ML````````````````/&P\K#SL/2P];#VL/>P^+#YL/JP^[#\L/VP_K#_L`"Q
M`;$"L0.Q!+$%L0:Q![$*L0VQ#K$/L1&Q%+$5L1:Q%[$:L1ZQ'[$@L2&Q(K$F
ML2>Q*;$JL2NQ+;$NL2^Q,+$QL3*Q,[$VL3JQ.[$\L3VQ/K$_L4*Q0[%%L4:Q
M1[%)L4JQ2[%,L4VQ3K%/L5*Q4[%6L5>Q6;%:L5NQ7;%>L5^Q8;%BL6.Q9+%E
ML6:Q9[%HL6FQ:K%KL6RQ;;%NL6^Q<+%QL7*Q<[%TL76Q=K%WL7JQ>[%]L7ZQ
M?[&!L8.QA+&%L8:QA[&*L8RQCK&/L9"QD;&5L9:QE[&9L9JQF[&=L0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````)ZQG[&@L:&Q
MHK&CL:2QI;&FL:>QJ;&JL:NQK+&ML:ZQK[&PL;&QLK&SL;2QM;&VL;>QN+$`
M``````````````"YL;JQN[&\L;VQOK&_L<"QP;'"L<.QQ+'%L<:QQ['(L<FQ
MRK'+L<VQSK'/L=&QTK'3L=6Q````````````````UK'7L=BQV;':L=NQWK'@
ML>&QXK'CL>2QY;'FL>>QZK'KL>VQ[K'OL?&Q\K'SL?2Q];'VL?>Q^+'ZL?RQ
M_K'_L0"R`;("L@.R!K('L@FR"K(-L@ZR#[(0LA&R$K(3LA:R&+(:LANR'+(=
MLAZR'[(ALB*R([(DLB6R)K(GLBBR*;(JLBNR++(MLBZR+[(PLC&R,K(SLC6R
M-K(WLCBR.;(ZLCNR/;(^LC^R0+)!LD*R0[)$LD6R1K)'LDBR2;)*LDNR3+)-
MLDZR3[)0LE&R4K)3LE2R5;)6LE>R6;):LENR7;)>LE^R8;)BLF.R9+)ELF:R
M9[)JLFNR;+)MLFZR````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````;[)PLG&R<K)SLG:R=[)XLGFR>K)[LGVR?K)_LH"R@;*"LH.R
MAK*'LHBRBK*+LHRRC;*.L@```````````````(^RDK*3LI6REK*7LINRG+*=
MLIZRG[*BLJ2RI[*HLJFRJ[*MLJZRK[*QLK*RL[*ULK:RM[(`````````````
M``"XLKFRNK*[LKRRO;*^LK^RP++!LL*RP[+$LL6RQK+'LLJRR[+-LLZRS[+1
MLM.RU++5LM:RU[+:LMRRWK+?LN"RX;+CLN>RZ;+JLO"R\;+RLO:R_++]LOZR
M`K,#LP6S!K,'LPFS"K,+LPRS#;,.LP^S$K,6LQ>S&+,9LQJS&[,=LQZS'[,@
MLR&S(K,CLR2S);,FLR>S*+,ILRJS*[,LLRVS+K,OLS"S,;,RLS.S-+,ULS:S
M-[,XLSFS.K,[LSRS/;,^LS^S0+-!LT*S0[-$LT6S1K-'LTBS2;-*LTNS3+--
MLTZS3[-0LU&S4K-3LU>S6;-:LUVS8+-ALV*S8[,`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!FLVBS:K-LLVVS;[-RLW.S=;-V
MLW>S>;-ZLWNS?+-]LWZS?[."LX:SA[.(LXFSBK.+LXVS````````````````
MCK./LY&SDK.3LY6SEK.7LYBSF;.:LYNSG+.=LYZSG[.BLZ.SI+.ELZ:SI[.I
MLZJSJ[.MLP```````````````*ZSK[.PL[&SLK.SL[2SM;.VL[>SN+.YL[JS
MN[.\L[VSOK._L\"SP;/"L\.SQK/'L\FSRK/-L\^ST;/2L].SUK/8L]JSW+/>
ML]^SX;/BL^.SY;/FL^>SZ;/JL^NS[+/ML^ZS[[/PL_&S\K/SL_2S];/VL_>S
M^+/YL_JS^[/]L_ZS_[,`M`&T`K0#M`2T!;0&M`>T"+0)M`JT"[0,M`VT#K0/
MM!&T$K03M!2T%;06M!>T&;0:M!NT';0>M!^T(;0BM".T)+0EM":T)[0JM"RT
M+;0NM"^T,+0QM#*T,[0UM#:T-[0XM#FT.K0[M#RT/;0^M#^T0+1!M$*T0[1$
MM```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$6T
M1K1'M$BT2;1*M$NT3+1-M$ZT3[12M%.T5;16M%>T6;1:M%NT7+1=M%ZT7[1B
MM&2T9K0```````````````!GM&BT:;1JM&NT;;1NM&^T<+1QM'*T<[1TM'6T
M=K1WM'BT>;1ZM'NT?+1]M'ZT?[2!M(*T````````````````@[2$M(6TAK2'
MM(FTBK2+M(RTC;2.M(^TD+21M)*TD[24M)6TEK27M)BTF;2:M)NTG+2>M)^T
MH+2AM**TH[2EM*:TI[2IM*JTJ[2MM*ZTK[2PM+&TLK2SM+2TMK2XM+JTN[2\
MM+VTOK2_M,&TPK3#M,6TQK3'M,FTRK3+M,RTS;3.M,^TT;32M-.TU+36M->T
MV+39M-JTV[3>M-^TX;3BM.6TY[3HM.FTZK3KM.ZT\+3RM/.T]+3UM/:T][3Y
MM/JT^[3\M/VT_K3_M`"U`;4"M0.U!+4%M0:U![4(M0FU"K4+M0RU#;4.M0^U
M$+41M1*U$[46M1>U&;4:M1VU````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````'K4?M2"U(;4BM2.U)K4KM2RU+;4NM2^U,K4SM36U
M-K4WM3FU.K4[M3RU/;4^M3^U0K5&M0```````````````$>U2+5)M4JU3K5/
MM5&U4K53M56U5K57M5BU6;5:M5NU7K5BM6.U9+5EM6:U9[5HM6FU:K4`````
M``````````!KM6RU;;5NM6^U<+5QM7*U<[5TM76U=K5WM7BU>;5ZM7NU?+5]
MM7ZU?[6`M8&U@K6#M82UA;6&M8>UB+6)M8JUB[6,M8VUCK6/M9"UD;62M9.U
ME+65M9:UE[68M9FUFK6;M9RUG;6>M9^UHK6CM:6UIK6GM:FUK+6MM:ZUK[6R
MM;:UM[6XM;FUNK6^M;^UP;7"M<.UQ;7&M<>UR+7)M<JUR[7.M=*UT[74M=6U
MUK77M=FUVK7;M=RUW;7>M=^UX+7AM>*UX[7DM>6UYK7GM>BUZ;7JM>NU[;7N
MM>^U\+7QM?*U\[7TM?6U]K7WM?BU^;7ZM?NU_+7]M?ZU_[4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````M@&V`K8#M@2V!;8&
MM@>V"+8)M@JV"[8,M@VV#K8/MA*V$[85MA:V%[89MAJV&[8<MAVV````````
M````````'K8?MB"V(;8BMB.V)+8FMB>V*+8IMBJV*[8MMBZV+[8PMC&V,K8S
MMC6V-K8WMCBV.;8ZM@```````````````#NV/+8]MCZV/[9`MD&V0K9#MD2V
M1;9&MD>V2;9*MDNV3+9-MDZV3[90ME&V4K93ME2V5;96ME>V6+99MEJV6[9<
MMEVV7K9?MF"V8;9BMF.V9;9FMF>V:;9JMFNV;+9MMFZV;[9PMG&V<K9SMG2V
M=;9VMG>V>+9YMGJV>[9\MGVV?K9_MH"V@;:"MH.VA+:%MH:VA[:(MHFVBK:+
MMHRVC;:.MH^VD+:1MI*VD[:4MI6VEK:7MIBVF;::MINVGK:?MJ&VHK:CMJ6V
MIK:GMJBVJ;:JMJVVKK:OMK"VLK:SMK2VM;:VMK>VN+:YMKJVN[:\MKVVOK:_
MML"VP;;"M@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````,.VQ+;%ML:VQ[;(MLFVRK;+MLRVS;;.ML^VT+;1MM*VT[;5MM:VU[;8
MMMFVVK;;MMRVW;8```````````````#>MM^VX+;AMN*VX[;DMN6VYK;GMNBV
MZ;;JMNNV[+;MMNZV[[;QMO*V\[;UMO:V][;YMOJV````````````````^[;\
MMOVV_K;_M@*W`[<$MP:W![<(MPFW"K<+MPRW#;<.MP^W$+<1MQ*W$[<4MQ6W
M%K<7MQBW&;<:MQNW'+<=MQZW'[<@MR&W(K<CMR2W);<FMR>W*K<KMRVW+K<Q
MMS*W,[<TMS6W-K<WMSJW/+<]MSZW/[=`MT&W0K=#MT6W1K='MTFW2K=+MTVW
M3K=/MU"W4;=2MU.W5K=7MUBW6;=:MUNW7+==MUZW7[=AMV*W8[=EMV:W9[=I
MMVJW:[=LMVVW;K=OMW*W=+=VMW>W>+=YMWJW>[=^MW^W@;>"MX.WA;>&MX>W
MB+>)MXJWB[>.MY.WE+>5MYJWF[>=MYZW````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````G[>AMZ*WH[>DMZ6WIK>GMZJWKK>OM["W
ML;>RM[.WMK>WM[FWNK>[M[RWO;>^M[^WP+?!MP```````````````,*WP[?$
MM\6WQK?(M\JWR[?,M\VWSK?/M]"WT;?2M].WU+?5M]:WU[?8M]FWVK?;M]RW
MW;<```````````````#>M]^WX+?AM^*WX[?DM^6WYK?GM^BWZ;?JM^NW[K?O
MM_&W\K?SM_6W]K?WM_BW^;?ZM_NW_K<"N`.X!+@%N`:X"K@+N`VX#K@/N!&X
M$K@3N!2X%;@6N!>X&K@<N!ZX'[@@N"&X(K@CN":X)[@IN"JX*[@MN"ZX+[@P
MN#&X,K@SN#:X.K@[N#RX/;@^N#^X0;A"N$.X1;A&N$>X2+A)N$JX2[A,N$VX
M3KA/N%"X4KA4N%6X5KA7N%BX6;A:N%NX7KA?N&&X8KACN&6X9KAGN&BX:;AJ
MN&NX;KAPN'*X<[ATN'6X=KAWN'FX>KA[N'VX?KA_N("X@;B"N(.XA+@`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"%N(:XA[B(
MN(FXBKB+N(RXCKB/N)"XD;B2N).XE+B5N):XE[B8N)FXFKB;N)RXG;B>N)^X
M````````````````H+BAN**XH[BDN*6XIKBGN*FXJKBKN*RXK;BNN*^XL;BR
MN+.XM;BVN+>XN;BZN+NXO+B]N````````````````+ZXO[C"N,2XQKC'N,BX
MR;C*N,NXS;C.N,^XT;C2N-.XU;C6N->XV+C9N-JXV[C<N-ZXX+CBN..XY+CE
MN.:XY[CJN.NX[;CNN.^X\;CRN/.X]+CUN/:X][CZN/RX_KC_N`"Y`;D"N0.Y
M!;D&N0>Y"+D)N0JY"[D,N0VY#KD/N1"Y$;D2N1.Y%+D5N1:Y%[D9N1JY&[D<
MN1VY'KD?N2&Y(KDCN22Y);DFN2>Y*+DIN2JY*[DLN2VY+KDON3"Y,;DRN3.Y
M-+DUN3:Y-[DXN3FY.KD[N3ZY/[E!N4*Y0[E%N4:Y1[E(N4FY2KE+N4VY3KE0
MN5*Y4[E4N56Y5KE7N0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````%JY6[E=N5ZY7[EAN6*Y8[EDN66Y9KEGN6JY;+ENN6^Y<+EQ
MN7*Y<[EVN7>Y>;EZN7NY?;D```````````````!^N7^Y@+F!N8*Y@[F&N8BY
MB[F,N8^YD+F1N9*YD[F4N96YEKF7N9BYF;F:N9NYG+F=N9ZY````````````
M````G[F@N:&YHKFCN:2YI;FFN:>YJ+FIN:JYJ[FNN:^YL;FRN;.YM;FVN;>Y
MN+FYN;JYN[F^N<"YPKG#N<2YQ;G&N<>YRKG+N<VYT[G4N=6YUKG7N=JYW+G?
MN>"YXKGFN>>YZ;GJN>NY[;GNN>^Y\+GQN?*Y\[GVN?NY_+G]N?ZY_[D"N@.Z
M!+H%N@:Z![H)N@JZ"[H,N@VZ#KH/NA"Z$;H2NA.Z%+H6NA>Z&+H9NAJZ&[H<
MNAVZ'KH?NB"Z(;HBNB.Z)+HENB:Z)[HHNBFZ*KHKNBRZ+;HNNB^Z,+HQNC*Z
M,[HTNC6Z-KHWNCJZ.[H]NCZZ/[I!ND.Z1+I%ND:Z````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1[I*NDRZ3[I0NE&Z4KI6NE>Z
M6;I:NENZ7;I>NE^Z8+IANF*Z8[IFNFJZ:[ILNFVZ;KION@``````````````
M`'*Z<[IUNG:Z=[IYNGJZ>[I\NGVZ?KI_NH"Z@;J"NH:ZB+J)NHJZB[J-NHZZ
MC[J0NI&ZDKH```````````````"3NI2ZE;J6NI>ZF+J9NIJZF[J<NIVZGKJ?
MNJ"ZH;JBNJ.ZI+JENJ:ZI[JJNJVZKKJONK&ZL[JTNK6ZMKJWNKJZO+J^NK^Z
MP+K!NL*ZP[K%NL:ZQ[K)NLJZR[K,NLVZSKK/NM"ZT;K2NM.ZU+K5NM:ZU[K:
MNMNZW+K=NMZZW[K@NN&ZXKKCNN2ZY;KFNN>ZZ+KINNJZZ[KLNNVZ[KKONO"Z
M\;KRNO.Z]+KUNO:Z][KXNOFZ^KK[NOVZ_KK_N@&[`KL#NP6[!KL'NPB[";L*
MNPN[#+L.NQ"[$KL3NQ2[%;L6NQ>[&;L:NQN[';L>NQ^[(;LBNR.[)+LENR:[
M)[L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````H
MNRJ[++LMNRZ[+[LPNS&[,KLSNS>[.;LZNS^[0+M!NT*[0[M&NTB[2KM+NTR[
M3KM1NU*[````````````````4[M5NU:[5[M9NUJ[6[M<NUV[7KM?NV"[8KMD
MNV6[9KMGNVB[:;MJNVN[;;MNNV^[<+MQNP```````````````'*[<[MTNW6[
M=KMWNWB[>;MZNWN[?+M]NWZ[?[N`NX&[@KN#NX2[A;N&NX>[B;N*NXN[C;N.
MNX^[D;N2NY.[E+N5NY:[E[N8NYF[FKN;NYR[G;N>NY^[H+NANZ*[H[NENZ:[
MI[NINZJ[J[NMNZZ[K[NPN[&[LKNSN[6[MKNXN[F[NKN[N[R[O;N^N[^[P;O"
MN\.[Q;O&N\>[R;O*N\N[S+O-N\Z[S[O1N]*[U+O5N]:[U[O8N]F[VKO;N]R[
MW;O>N]^[X+OAN^*[X[ODN^6[YKOGN^B[Z;OJN^N[[+OMN^Z[[[OPN_&[\KOS
MN_2[];OVN_>[^KO[N_V[_KL!O```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````.\!+P%O`:\![P*O`Z\$+P2O!.\&;P:O""\(;PB
MO".\)KPHO"J\*[PLO"Z\+[PRO#.\-;P````````````````VO#>\.;PZO#N\
M/+P]O#Z\/[Q"O$:\1[Q(O$J\2[Q.O$^\4;Q2O%.\5+Q5O%:\5[Q8O%F\````
M````````````6KQ;O%R\7KQ?O&"\8;QBO&.\9+QEO&:\9[QHO&F\:KQKO&R\
M;;QNO&^\<+QQO'*\<[QTO'6\=KQWO'B\>;QZO'N\?+Q]O'Z\?[R`O(&\@KR#
MO(:\A[R)O(J\C;R/O)"\D;R2O).\EKR8O)N\G+R=O)Z\G[RBO*.\I;RFO*F\
MJKRKO*R\K;RNO*^\LKRVO+>\N+RYO+J\N[R^O+^\P;S"O,.\Q;S&O,>\R+S)
MO,J\R[S,O,Z\TKS3O-2\UKS7O-F\VKS;O-V\WKS?O."\X;SBO..\Y+SEO.:\
MY[SHO.F\ZKSKO.R\[;SNO.^\\+SQO/*\\[SWO/F\^KS[O/V\````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_KS_O`"]`;T"O0.]
M!KT(O0J]"[T,O0V]#KT/O1&]$KT3O16]%KT7O1B]&;T:O1N]'+T=O0``````
M`````````!Z]'[T@O2&](KTCO26])KTGO2B]*;TJO2N]+;TNO2^],+TQO3*]
M,[TTO36]-KTWO3B].;T````````````````ZO3N]/+T]O3Z]/[U!O4*]0[U$
MO46]1KU'O4J]2[U-O4Z]3[U1O5*]4[U4O56]5KU7O5J]6[U<O5V]7KU?O6"]
M8;UBO6.]9;UFO6>]:;UJO6N];+UMO6Z];[UPO7&]<KUSO72]=;UVO7>]>+UY
MO7J]>[U\O7V]?KU_O8*]@[V%O8:]B[V,O8V]CKV/O9*]E+V6O9>]F+V;O9V]
MGKV?O:"]H;VBO:.]I;VFO:>]J+VIO:J]J[VLO:V]KKVOO;&]LKVSO;2]M;VV
MO;>]N;VZO;N]O+V]O;Z]O[W`O<&]PKW#O<2]Q;W&O<>]R+W)O<J]R[W,O<V]
MSKW/O="]T;T`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#2O=.]UKW7O=F]VKW;O=V]WKW?O>"]X;WBO>.]Y+WEO>:]Y[WHO>J]
MZ[WLO>V][KWOO?&]````````````````\KWSO?6]]KWWO?F]^KW[O?R]_;W^
MO?^]`;X"O@2^!KX'O@B^";X*O@N^#KX/OA&^$KX3O@```````````````!6^
M%KX7OAB^&;X:OAN^'KX@OB&^(KXCOB2^);XFOB>^*+XIOBJ^*[XLOBV^+KXO
MOC"^,;XROC.^-+XUOC:^-[XXOCF^.KX[OCR^/;X^OC^^0+Y!OD*^0[Y&OD>^
M2;Y*ODN^3;Y/OE"^4;Y2OE.^5KY8OER^7;Y>OE^^8KYCOF6^9KYGOFF^:[YL
MOFV^;KYOOG*^=KYWOGB^>;YZOGZ^?[Z!OH*^@[Z%OH:^A[Z(OHF^BKZ+OHZ^
MDKZ3OI2^E;Z6OI>^FKZ;OIR^G;Z>OI^^H+ZAOJ*^H[ZDOJ6^IKZGOJF^JKZK
MOJR^K;ZNOJ^^L+ZQOK*^L[ZTOK6^MKZWO@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````+B^N;ZZOKN^O+Z]OKZ^O[[`OL&^PK[#
MOL2^Q;[&OL>^R+[)OLJ^R[[,OLV^SK[/OM*^T[X```````````````#5OM:^
MV;[:OMN^W+[=OMZ^W[[AON*^YK[GONB^Z;[JONN^[;[NON^^\+[QOO*^\[[T
MOO6^````````````````]K[WOOB^^;[ZOON^_+[]OOZ^_[X`OP*_`[\$OP6_
M!K\'OPJ_"[\,OPV_#K\/OQ"_$;\2OQ._%+\5OQ:_%[\:OQZ_'[\@OR&_(K\C
MOR2_);\FOR>_*+\IORJ_*[\LORV_+K\OOS"_,;\ROS._-+\UOS:_-[\XOSF_
M.K\[OSR_/;\^OS^_0K]#OT6_1K]'OTF_2K]+OTR_3;].OT^_4K]3OU2_5K]7
MOUB_6;]:OUN_7+]=OUZ_7[]@OV&_8K]COV2_9;]FOV>_:+]IOVJ_:[]LOVV_
M;K]OOW"_<;]ROW._=+]UOW:_=[]XOWF_>K][OWR_?;]^OW^_@+^!OX*_````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````@[^$OX6_
MAK^'OXB_B;^*OXN_C+^-OXZ_C[^0OY&_DK^3OY6_EK^7OYB_F;^:OYN_G+^=
MOP```````````````)Z_G[^@OZ&_HK^COZ2_I;^FOZ>_J+^IOZJ_J[^LOZV_
MKK^OO[&_LK^SO[2_M;^VO[>_N+\```````````````"YO[J_N[^\O[V_OK^_
MO\"_P;_"O\._Q+_&O\>_R+_)O\J_R[_.O\^_T;_2O]._U;_6O]>_V+_9O]J_
MV[_=O]Z_X+_BO^._Y+_EO^:_Y[_HO^F_ZK_KO^R_[;_NO^^_\+_QO_*_\[_T
MO_6_]K_WO_B_^;_ZO_N__+_]O_Z__[\`P`'``L`#P`3`!<`&P`?`",`)P`K`
M"\`,P`W`#L`/P!#`$<`2P!/`%,`5P!;`%\`8P!G`&L`;P!S`'<`>P!_`(,`A
MP"+`(\`DP"7`)L`GP"C`*<`JP"O`+,`MP"[`+\`PP#'`,L`SP#3`-<`VP#?`
M.,`YP#K`.\`]P#[`/\``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!`P$'`0L!#P$3`1<!&P$?`2,!)P$K`2\!,P$W`3L!/P%#`
M4L!3P%3`5<!6P%?`6<!:P%O`````````````````7<!>P%_`8<!BP&/`9,!E
MP&;`9\!JP&O`;,!MP&[`;\!PP''`<L!SP'3`=<!VP'?`>,!YP```````````
M`````'K`>\!\P'W`?L!_P(#`@<""P(/`A,"%P(;`A\"(P(G`BL"+P(S`C<".
MP(_`DL"3P)7`EL"7P)G`FL";P)S`G<">P)_`HL"DP*;`I\"HP*G`JL"KP*[`
ML<"RP+?`N,"YP+K`N\"^P,+`P\#$P,;`Q\#*P,O`S<#.P,_`T<#2P-/`U,#5
MP-;`U\#:P-[`W\#@P.'`XL#CP.;`Y\#IP.K`Z\#MP.[`[\#PP/'`\L#SP/;`
M^,#ZP/O`_,#]P/[`_\`!P0+!`\$%P0;!!\$)P0K!"\$,P0W!#L$/P1'!$L$3
MP13!%L$7P1C!&<$:P1O!(<$BP27!*,$IP2K!*\$NP0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#+!,\$TP37!-\$ZP3O!/<$^
MP3_!0<%"P4/!1,%%P4;!1\%*P4[!3\%0P5'!4L%3P5;!5\$`````````````
M``!9P5K!6\%=P5[!7\%@P6'!8L%CP6;!:L%KP6S!;<%NP6_!<<%RP7/!=<%V
MP7?!><%ZP7O!````````````````?,%]P7[!?\&`P8'!@L&#P83!AL&'P8C!
MB<&*P8O!C\&1P9+!D\&5P9?!F,&9P9K!F\&>P:#!HL&CP:3!IL&GP:K!J\&M
MP:[!K\&QP;+!L\&TP;7!ML&WP;C!N<&ZP;O!O,&^P;_!P,'!P<+!P\'%P<;!
MQ\')P<K!R\'-P<[!S\'0P='!TL'3P=7!UL'9P=K!V\'<P=W!WL'?P>'!XL'C
MP>7!YL'GP>G!ZL'KP>S![<'NP>_!\L'TP?7!]L'WP?C!^<'ZP?O!_L'_P0'"
M`L(#P@7"!L('P@C""<(*P@O"#L(0PA+"$\(4PA7"%L(7PAK"&\(=PA["(<(B
MPB/"````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M),(EPB;")\(JPBS"+L(PPC/"-<(VPC?".,(YPCK".\(\PCW"/L(_PD#"0<)"
MPD/"1,)%P@```````````````$;"1\))PDK"2\),PDW"3L)/PE+"4\)5PE;"
M5\)9PEK"6\)<PEW"7L)?PF'"8L)CPF3"9L(```````````````!GPFC":<)J
MPFO";L)OPG'"<L)SPG7"=L)WPGC"><)ZPGO"?L*`PH+"@\*$PH7"AL*'PHK"
MB\*,PHW"CL*/PI'"DL*3PI3"E<*6PI?"F<*:PIS"GL*?PJ#"H<*BPJ/"IL*G
MPJG"JL*KPJ["K\*PPK'"LL*SPK;"N,*ZPKO"O,*]PK["O\+`PL'"PL+#PL3"
MQ<+&PL?"R,+)PLK"R\+,PLW"SL+/PM#"T<+2PM/"U,+5PM;"U\+8PMG"VL+;
MPM["W\+APN+"Y<+FPN?"Z,+IPNK"[L+PPO+"\\+TPO7"]\+ZPOW"_L+_P@'#
M`L,#PP3#!<,&PP?#"L,+PP[##\,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````0PQ'#$L,6PQ?#&<,:PQO#'<,>PQ_#(,,APR+#
M(\,FPR?#*L,KPRS#+<,NPR_#,,,QPS+#````````````````,\,TPS7#-L,W
MPSC#.<,ZPSO#/,,]PS[#/\-`PT'#0L-#PT3#1L-'PTC#2<-*PTO#3,--PP``
M`````````````$[#3\-0PU'#4L-3PU3#5<-6PU?#6,-9PUK#6\-<PUW#7L-?
MPV##8<-BPV/#9,-EPV;#9\-JPVO#;<-NPV_#<<-SPW3#=<-VPW?#>L-[PW[#
M?\.`PX'#@L.#PX7#AL.'PXG#BL.+PXW#CL./PY##D<.2PY/#E,.5PY;#E\.8
MPYG#FL.;PYS#G<.>PY_#H,.APZ+#H\.DPZ7#IL.GPZC#J<.JPZO#K,.MPZ[#
MK\.PP['#LL.SP[3#M<.VP[?#N,.YP[K#N\.\P[W#OL._P\'#PL/#P\3#Q</&
MP\?#R,/)P\K#R\/,P\W#SL//P]##T</2P]/#U,/5P];#U\/:PP``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-O#W</>P^'#X\/D
MP^7#YL/GP^K#Z\/LP^[#[\/PP_'#\L/SP_;#]\/YP_K#^\/\P_W#_L,`````
M``````````#_PP#$`<0"Q`/$!,0%Q`;$!\0)Q`K$"\0,Q`W$#L0/Q!'$$L03
MQ!3$%<06Q!?$&,09Q!K$````````````````&\0<Q!W$'L0?Q"#$(<0BQ"/$
M)<0FQ"?$*,0IQ"K$*\0MQ"[$+\0QQ#+$,\0UQ#;$-\0XQ#G$.L0[Q#[$/\1`
MQ$'$0L1#Q$3$1<1&Q$?$2<1*Q$O$3,1-Q$[$3\10Q%'$4L13Q%3$5<16Q%?$
M6,19Q%K$6\1<Q%W$7L1?Q&#$8<1BQ&/$9L1GQ&G$:L1KQ&W$;L1OQ'#$<<1R
MQ'/$=L1WQ'C$>L1[Q'S$?<1^Q'_$@<2"Q(/$A,2%Q(;$A\2(Q(G$BL2+Q(S$
MC<2.Q(_$D,21Q)+$D\25Q);$E\28Q)G$FL2;Q)W$GL2?Q*#$H<2BQ*/$I,2E
MQ*;$I\2HQ*G$````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````JL2KQ*S$K<2NQ*_$L,2QQ++$L\2TQ+7$ML2WQ+G$NL2[Q+W$OL2_
MQ,#$P<3"Q,/$Q,3%Q````````````````,;$Q\3(Q,G$RL3+Q,S$S<3.Q,_$
MT,31Q-+$T\34Q-7$UL37Q-C$V<3:Q-O$W,3=Q-[$W\0```````````````#@
MQ.'$XL3CQ.3$Y<3FQ.?$Z,3JQ.O$[,3MQ.[$[\3RQ//$]<3VQ/?$^<3[Q/S$
M_<3^Q`+%`\4$Q07%!L4'Q0C%"<4*Q0O%#<4.Q0_%$<42Q1/%%<46Q1?%&,49
MQ1K%&\4=Q1[%'\4@Q2'%(L4CQ23%)<4FQ2?%*L4KQ2W%+L4OQ3'%,L4SQ33%
M-<4VQ3?%.L4\Q3[%/\5`Q4'%0L5#Q4;%1\5+Q4_%4,51Q5+%5L5:Q5O%7,5?
MQ6+%8\5EQ6;%9\5IQ6K%:\5LQ6W%;L5OQ7+%=L5WQ7C%><5ZQ7O%?L5_Q8'%
M@L6#Q87%AL6(Q8G%BL6+Q8[%D,62Q9/%E,4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"6Q9G%FL6;Q9W%GL6?Q:'%HL6CQ:3%
MI<6FQ:?%J,6JQ:O%K,6MQ:[%K\6PQ;'%LL6SQ;;%````````````````M\6Z
MQ;_%P,7!Q<+%P\7+Q<W%S\72Q=/%U<76Q=?%V<7:Q=O%W,7=Q=[%W\7BQ>3%
MYL7GQ0```````````````.C%Z<7JQ>O%[\7QQ?+%\\7UQ?C%^<7ZQ?O%`L8#
MQ@3&"<8*Q@O&#<8.Q@_&$<82QA/&%,85QA;&%\8:QAW&'L8?QB#&(<8BQB/&
M)L8GQBG&*L8KQB_&,<8RQC;&.,8ZQCS&/<8^QC_&0L9#QD7&1L9'QDG&2L9+
MQDS&3<9.QD_&4L96QE?&6,99QEK&6\9>QE_&8<9BQF/&9,9EQF;&9\9HQFG&
M:L9KQFW&;L9PQG+&<\9TQG7&=L9WQGK&>\9]QG[&?\:!QH+&@\:$QH7&AL:'
MQHK&C,:.QH_&D,:1QI+&D\:6QI?&F<::QIO&G<:>QI_&H,:AQJ+&H\:FQ@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````*C&JL:K
MQJS&K<:NQJ_&LL:SQK7&ML:WQKO&O,:]QK[&O\;"QL3&QL;'QLC&R<;*QLO&
MSL8```````````````#/QM'&TL;3QM7&UL;7QMC&V<;:QMO&WL;?QN+&X\;D
MQN7&YL;GQNK&Z\;MQN[&[\;QQO+&````````````````\\;TQO7&]L;WQOK&
M^\;\QO[&_\8`QP''`L<#QP;'!\<)QPK'"\<-QP['#\<0QQ''$L<3QQ;'&,<:
MQQO'',<=QQ[''\<BQR/')<<FQR?'*<<JQRO'+,<MQR['+\<RQS3'-L<XQSG'
M.L<[QS['/\=!QT+'0\=%QT;'1\=(QTG'2\=.QU#'6<=:QUO'7<=>QU_'8<=B
MQV/'9,=EQV;'9\=IQVK';,=MQV[';\=PQW''<L=SQW;'=\=YQWK'>\=_QX#'
M@<>"QX;'B\>,QXW'C\>2QY/'E<>9QYO'G,>=QY['G\>BQZ?'J,>IQZK'J\>N
MQZ_'L<>RQ[/'M<>VQ[?'````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````N,>YQ[K'N\>^Q\+'P\?$Q\7'QL?'Q\K'R\?-Q\_'T<?2
MQ]/'U,?5Q];'U\?9Q]K'V\?<QP```````````````-['W\?@Q^''XL?CQ^7'
MYL?GQ^G'ZL?KQ^W'[L?OQ_#'\<?RQ_/'],?UQ_;']\?XQ_G'^L<`````````
M``````#[Q_S'_<?^Q__'`L@#R`7(!L@'R`G("\@,R`W(#L@/R!+(%,@7R!C(
M&<@:R!O('L@?R"'((L@CR"7()L@GR"C(*<@JR"O(+L@PR#+(,\@TR#7(-L@W
MR#G(.L@[R#W(/L@_R$'(0LA#R$3(1<A&R$?(2LA+R$[(3\A0R%'(4LA3R%7(
M5LA7R%C(6<A:R%O(7,A=R%[(7\A@R&'(8LACR&3(9<AFR&?(:,AIR&K(:\AL
MR&W(;LAOR'+(<\AUR';(=\AYR'O(?,A]R'[(?\B"R(3(B,B)R(K(CLB/R)#(
MD<B2R)/(E<B6R)?(F,B9R)K(F\B<R)[(H,BBR*/(I,@`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"ER*;(I\BIR*K(J\BLR*W(
MKLBOR+#(L<BRR+/(M,BUR+;(M\BXR+G(NLB[R+[(O\C`R,'(````````````
M````PLC#R,7(QLC'R,G(RLC+R,W(SLC/R-#(T<C2R-/(ULC8R-K(V\C<R-W(
MWLC?R.+(X\CER````````````````.;(Y\CHR.G(ZLCKR.S([<CNR._(\,CQ
MR/+(\\CTR/;(]\CXR/G(^LC[R/[(_\@!R0+)`\D'R0C)"<D*R0O)#LD`,`$P
M`C"W`"4@)B"H``,PK0`5("4B//\\(A@@&2`<(!T@%#`5,`@P"3`*,`LP##`-
M,`XP#S`0,!$PL0#7`/<`8")D(F4B'B(T(K``,B`S(`,A*R'@_^'_Y?]")D`F
M("*E(A(C`B('(F$B4B*G`#L@!B8%)LLESR7.)<<EQB6A):`ELR6R);TEO"62
M(9`AD2&3(90A$S!J(FLB&B(](ATB-2(K(BPB""(+(H8BAR*"(H,B*B(I(B<B
M*"+B_P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`!#)$LD3R13)%<D6R1?)&<D:R1O)',D=R1[)'\D@R2')(LDCR23))<DFR2?)
M*,DIR2K)*\D````````````````MR2[)+\DPR3'),LDSR37)-LDWR3C).<DZ
MR3O)/,D]R3[)/\E`R4')0LE#R43)1<E&R4?)````````````````2,E)R4K)
M2\E,R4W)3LE/R5+)4\E5R5;)5\E9R5K)6\E<R5W)7LE?R6+)9,EER6;)9\EH
MR6G):LEKR6W);LEOR=(AU"$`(@,BM`!>_\<"V`+=`MH"V0*X`-L"H0"_`-`"
M+B(1(@\BI``)(3`@P27`);<EMB5D)F`F829E)F<F8R:9(L@EHR70)=$EDB6D
M):4EJ"6G):8EJ25H)@\F#B8<)AXFM@`@("$@E2&7(9DAEB&8(6TF:29J)FPF
M?S(<,A8AQS,B(<(SV#,A(0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````<<ERR7/)=<EVR7?)>,EYR7K)>\E]R7[)?\F`
MR8')@LF#R83)A<F&R8?)BLF+R8W)CLF/R0```````````````)')DLF3R93)
ME<F6R9?)FLF<R9[)G\F@R:')HLFCR:3)I<FFR:?)J,FIR:K)J\FLR:W)KLD`
M``````````````"OR;#)L<FRR;/)M,FUR;;)M\FXR;G)NLF[R;S)O<F^R;_)
MPLG#R<7)QLG)R<O)S,G-R<[)S\G2R=3)U\G8R=O)`?\"_P/_!/\%_P;_!_\(
M_PG_"O\+_PS_#?\._P__$/\1_Q+_$_\4_Q7_%O\7_QC_&?\:_QO_'/\=_Q[_
M'_\@_R'_(O\C_R3_)?\F_R?_*/\I_RK_*_\L_RW_+O\O_S#_,?\R_S/_-/\U
M_S;_-_\X_SG_.O\[_^;_/?\^_S__0/]!_T+_0_]$_T7_1O]'_TC_2?]*_TO_
M3/]-_T[_3_]0_U'_4O]3_U3_5?]6_U?_6/]9_UK_6_]<_UW_X_\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#>R=_)X<GCR>7)
MYLGHR>G)ZLGKR>[)\LGSR?3)]<GVR??)^LG[R?W)_LG_R0'*`LH#R@3*````
M````````````!<H&R@?*"LH.R@_*$,H1RA+*$\H5RA;*%\H9RAK*&\H<RAW*
M'LH?RB#*(<HBRB/*),HER@```````````````";*)\HHRBK**\HLRBW*+LHO
MRC#*,<HRRC/*-,HURC;*-\HXRCG*.LH[RCS*/<H^RC_*0,I!RD+*0\I$RD7*
M1LHQ,3(Q,S$T,34Q-C$W,3@Q.3$Z,3LQ/#$],3XQ/S%`,4$Q0C%#,40Q13%&
M,4<Q2#%),4HQ2S%,,4TQ3C%/,5`Q43%2,5,Q5#%5,58Q5S%8,5DQ6C%;,5PQ
M73%>,5\Q8#%A,6(Q8S%D,64Q9C%G,6@Q:3%J,6LQ;#%M,6XQ;S%P,7$Q<C%S
M,70Q=3%V,7<Q>#%Y,7HQ>S%\,7TQ?C%_,8`Q@3&",8,QA#&%,88QAS&(,8DQ
MBC&+,8PQC3&.,0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$?*2,I)RDK*2\I.RD_*4<I2RE/*5<I6RE?*6,I9REK*6\I>RF+*
M8\IDRF7*9LIGRFG*:LH```````````````!KRFS*;<INRF_*<,IQRG+*<\IT
MRG7*=LIWRGC*><IZRGO*?,I^RG_*@,J!RH+*@\J%RH;*````````````````
MA\J(RHG*BLJ+RHS*C<J.RH_*D,J1RI+*D\J4RI7*ELJ7RIG*FLJ;RIS*G<J>
MRI_*H,JARJ+*H\JDRJ7*ILJGRG`A<2%R(7,A="%U(78A=R%X(7DA````````
M`````&`A82%B(6,A9"%E(68A9R%H(6DA``````````````````"1`Y(#DP.4
M`Y4#E@.7`Y@#F0.:`YL#G`.=`YX#GP.@`Z$#HP.D`Z4#I@.G`Z@#J0,`````
M````````````````L0.R`[,#M`.U`[8#MP.X`[D#N@.[`[P#O0.^`[\#P`/!
M`\,#Q`/%`\8#QP/(`\D#````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````J,JIRJK*J\JLRJW*KLJORK#*L<JR
MRK/*M,JURK;*M\JXRKG*NLJ[RK[*O\K!RL+*P\K%R@```````````````,;*
MQ\K(RLG*RLK+RL[*T,K2RM3*U<K6RM?*VLK;RMS*W<K>RM_*X<KBRN/*Y,KE
MRN;*Y\H```````````````#HRNG*ZLKKRNW*[LKORO#*\<KRRO/*]<KVRO?*
M^,KYROK*^\K\ROW*_LK_R@#+`<L"RP/+!,L%RP;+!\L)RPK+`"4")0PE$"48
M)10E'"4L)20E-"4\)0$E`R4/)1,E&R47)2,E,R4K)3LE2R4@)2\E*"4W)3\E
M'24P)24E."5")1(E$24:)1DE%B45)0XE#24>)1\E(24B)28E)R4I)2HE+24N
M)3$E,B4U)38E.24Z)3TE/B5`)4$E0R5$)44E1B5')4@E225*)0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````+RPS+
M#<L.RP_+$<L2RQ/+%<L6RQ?+&<L:RQO+',L=RQ[+'\LBRR/+),LERR;+)\LH
MRRG+````````````````*LLKRRS++<LNRR_+,,LQRS++,\LTRS7+-LLWRSC+
M.<LZRSO+/,L]RS[+/\M`RT++0\M$RP```````````````$7+1LM'RTK+2\M-
MRT[+3\M1RU++4\M4RU7+5LM7RUK+6\M<RU[+7\M@RV'+8LMCRV7+9LMGRVC+
M:<MJRVO+;,N5,Y8SES,3(9@SQ#.C,Z0SI3.F,YDSFC.;,YPSG3.>,Y\SH#.A
M,Z(SRC.-,XXSCS//,X@SB3/(,Z<SJ#.P,[$SLC.S,[0SM3.V,[<SN#.Y,X`S
M@3.",X,SA#.Z,[LSO#.],[XSOS.0,Y$SDC.3,Y0S)B'`,\$SBC.+,XPSUC/%
M,ZTSKC.O,]LSJ3.J,ZLSK#/=,]`STS/#,\DSW#/&,P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````&W+;LMORW#+<<MRRW/+=,MURW;+=\MZRWO+?,M]RW[+
M?\N`RX'+@LN#RX3+A<N&RX?+B,L```````````````")RXK+B\N,RXW+CLN/
MRY#+D<N2RY/+E,N5RY;+E\N8RYG+FLN;RYW+GLN?RZ#+H<NBRZ/+````````
M````````I,NERZ;+I\NHRZG+JLNKRZS+K<NNRZ_+L,NQR[++L\NTR[7+MLNW
MR[G+NLN[R[S+O<N^R[_+P,O!R\++P\O$R\8`T`"J`"8!```R`0``/P%!`=@`
M4@&Z`-X`9@%*`0``8#)A,F(R8S)D,F4R9C)G,F@R:3)J,FLR;#)M,FXR;S)P
M,G$R<C)S,G0R=3)V,G<R>#)Y,GHR>S+0)-$DTB33)-0DU236)-<DV"39)-HD
MVR3<)-TDWB3?).`DX23B).,DY"3E).8DYR3H).DD8"1A)&(D8R1D)&4D9B1G
M)&@D:21J)&LD;"1M)&XDO0!3(50AO`"^`%LA7"%=(5XA````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````Q<O&R\?+R,O)R\K+R\O,
MR\W+SLO/R]#+T<O2R]/+U<O6R]?+V,O9R]K+V\O<R]W+WLO?RP``````````
M`````.#+X<OBR^/+Y<OFR^C+ZLOKR^S+[<ONR^_+\,OQR_++\\OTR_7+]LOW
MR_C+^<OZR_O+_,L```````````````#]R_[+_\L`S`',`LP#S`3,!<P&S`?,
M",P)S`K,"\P.S`_,$<P2S!/,%<P6S!?,&,P9S!K,&\P>S!_,(,PCS"3,Y@`1
M`?``)P$Q`3,!.`%``4(!^`!3`=\`_@!G`4L!20$`,@$R`C(#,@0R!3(&,@<R
M"#(),@HR"S(,,@TR#C(/,A`R$3(2,A,R%#(5,A8R%S(8,ADR&C(;,IPDG22>
M))\DH"2A)*(DHR2D)*4DIB2G)*@DJ22J)*LDK"2M)*XDKR2P)+$DLB2S)+0D
MM21T)'4D=B1W)'@D>21Z)'LD?"1])'XD?R2`)($D@B2Y`+(`LP!T('\@@2""
M((,@A"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```ES";,*LPKS"W,+\PQS#+,,\PTS#7,-LPWS#K,/\Q`S$',0LQ#S$;,1\Q)
MS$K,2\Q-S$[,````````````````3\Q0S%',4LQ3S%;,6LQ;S%S,7<Q>S%_,
M8<QBS&/,9<QGS&G,:LQKS&S,;<QNS&_,<<QRS````````````````'/,=,QV
MS'?,>,QYS'K,>\Q\S'W,?LQ_S(#,@<R"S(/,A,R%S(;,A\R(S(G,BLR+S(S,
MC<R.S(_,D,R1S)+,D\Q!,$(P0S!$,$4P1C!',$@P23!*,$LP3#!-,$XP3S!0
M,%$P4C!3,%0P53!6,%<P6#!9,%HP6S!<,%TP7C!?,&`P83!B,&,P9#!E,&8P
M9S!H,&DP:C!K,&PP;3!N,&\P<#!Q,'(P<S!T,'4P=C!W,'@P>3!Z,'LP?#!]
M,'XP?S"`,($P@C"#,(0PA3"&,(<PB#"),(HPBS",,(TPCC"/,)`PD3"2,),P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````)3,E<R6S)?,FLR;S)W,GLR?S*',HLRCS*3,
MI<RFS*?,JLRNS*_,L,RQS++,L\RVS+?,N<P```````````````"ZS+O,O<R^
MS+_,P,S!S,+,P\S&S,C,RLS+S,S,S<S.S,_,T<S2S-/,U<S6S-?,V,S9S-K,
M````````````````V\S<S-W,WLS?S.#,X<SBS./,Y<SFS.?,Z,SIS.K,Z\SM
MS.[,[\SQS/+,\\STS/7,]LSWS/C,^<SZS/O,_,S]S*$PHC"C,*0PI3"F,*<P
MJ#"I,*HPJS"L,*TPKC"O,+`PL3"R,+,PM#"U,+8PMS"X,+DPNC"[,+PPO3"^
M,+\PP##!,,(PPS#$,,4PQC#',,@PR3#*,,LPS##-,,XPSS#0,-$PTC#3,-0P
MU3#6,-<PV##9,-HPVS#<,-TPWC#?,.`PX3#B,.,PY##E,.8PYS#H,.DPZC#K
M,.PP[3#N,.\P\##Q,/(P\S#T,/4P]C``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````_LS_S`#-`LT#
MS03-!<T&S0?-"LT+S0W-#LT/S1'-$LT3S13-%<T6S1?-&LT<S1[-'\T@S0``
M`````````````"'-(LTCS27-)LTGS2G-*LTKS2W-+LTOS3#-,<TRS3/--,TU
MS3;--\TXS3K-.\T\S3W-/LT````````````````_S4#-0<U"S4/-1,U%S4;-
M1\U(S4G-2LU+S4S-3<U.S4_-4,U1S5+-4\U4S57-5LU7S5C-6<U:S5O-7<U>
MS5_-$`01!!($$P04!!4$`006!!<$&`09!!H$&P0<!!T$'@0?!"`$(00B!",$
M)`0E!"8$)P0H!"D$*@0K!"P$+00N!"\$````````````````````````````
M````````````,`0Q!#($,P0T!#4$400V!#<$.`0Y!#H$.P0\!#T$/@0_!$`$
M001"!$,$1`1%!$8$1P1(!$D$2@1+!$P$301.!$\$````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!AS6+-8\UES6;-9\UHS6G-:LUKS6[-<,URS7/-=,UUS7;-=\UY
MS7K->\U\S7W-?LU_S8#-````````````````@<V"S8/-A,V%S8;-A\V)S8K-
MB\V,S8W-CLV/S9#-D<V2S9/-ELV7S9G-FLV;S9W-GLV?S0``````````````
M`*#-H<VBS:/-ILVHS:K-J\VLS:W-KLVOS;'-LLVSS;3-M<VVS;?-N,VYS;K-
MN\V\S;W-OLV_S<#-P<W"S</-Q<T`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````,;-Q\W(S<G-RLW+S<W-SLW/S='-
MTLW3S=3-U<W6S=?-V,W9S=K-V\W<S=W-WLW?S>#-X<T```````````````#B
MS>/-Y,WES>;-Y\WIS>K-Z\WMS>[-[\WQS?+-\\WTS?7-]LWWS?K-_,W^S?_-
M`,X!S@+.`````````````````\X%S@;.!\X)S@K."\X-S@[.#\X0SA'.$LX3
MSA7.%LX7SAC.&LX;SAS.'<X>SA_.(LXCSB7.)LXGSBG.*LXKS@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+,XM
MSB[.+\XRSC3.-LXWSCC..<XZSCO./,X]SC[./\Y`SD'.0LY#SD3.1<Y&SD?.
M2,Y)S@```````````````$K.2\Y,SDW.3LY/SE#.4<Y2SE/.5,Y5SE;.5\Y:
MSEO.7<Y>SF+.8\YDSF7.9LYGSFK.;,X```````````````!NSF_.<,YQSG+.
M<\YVSG?.><YZSGO.?<Y^SG_.@,Z!SH+.@\Z&SHC.BLZ+SHS.C<Z.SH_.DLZ3
MSI7.ELZ7SIG.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````":SIO.G,Z=SI[.G\ZBSJ;.I\ZHSJG.JLZKSJ[.K\ZP
MSK'.LLZSSK3.M<ZVSK?.N,ZYSKK.````````````````N\Z\SKW.OLZ_SL#.
MPL[#SL3.Q<[&SL?.R,[)SLK.R\[,SLW.SL[/SM#.T<[2SM/.U,[5S@``````
M`````````-;.U\[8SMG.VL[;SMS.W<[>SM_.X,[ASN+.X\[FSN?.Z<[JSNW.
M[L[OSO#.\<[RSO/.]L[ZSOO._,[]SO[._\X`K`&L!*P'K`BL":P*K!"L$:P2
MK!.L%*P5K!:L%ZP9K!JL&ZP<K!VL(*PDK"RL+:POK#"L,:PXK#FL/*Q`K$NL
M3:Q4K%BL7*QPK'&L=*QWK'BL>JR`K(&L@ZR$K(6LAJR)K(JLBZR,K)"LE*R<
MK)VLGZR@K*&LJ*RIK*JLK*ROK+"LN*RYK+NLO*R]K,&LQ*S(K,RLU:S7K."L
MX:SDK.>LZ*SJK.RL[ZSPK/&L\ZSUK/:L_*S]K`"M!*T&K0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````+/`\\%SP;/!\\)SPK/
M"\\,SPW/#L\/SQ+/%,\6SQ?/&,\9SQK/&\\=SQ[/'\\ASR+/(\\`````````
M```````ESR;/)\\HSRG/*L\KSR[/,L\SSS3/-<\VSS?/.<\ZSSO//,\]SS[/
M/\]`ST'/0L]#ST3/````````````````1<]&ST?/2,])STK/2\],STW/3L]/
MSU#/4<]2SU//5L]7SUG/6L];SUW/7L]?SV#/8<]BSV//9L]HSVK/:\]LSPRM
M#:T/K1&M&*T<K2"M*:TLK2VM-*TUK3BM/*U$K46M1ZU)K5"M5*U8K6&M8ZUL
MK6VM<*USK72M=:UVK7NM?*U]K7^M@:V"K8BMB:V,K9"MG*V=K:2MMZW`K<&M
MQ*W(K="MT:W3K=RMX*WDK?BM^:W\K?^M`*X!K@BN":X+K@VN%*XPKC&N-*XW
MKCBN.JY`KD&N0ZY%KD:N2JY,KDVN3JY0KE2N5JY<KEVN7ZY@KF&N9:YHKFFN
M;*YPKGBN````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````;<]NSV_/<L]SSW7/=L]WSWG/>L][SWS/?<]^SW_/@<^"SX//A,^&SX?/
MB,^)SXK/B\^-SP```````````````([/C\^0SY'/DL^3SY3/E<^6SY?/F,^9
MSYK/F\^<SYW/GL^?SZ#/HL^CSZ3/I<^FSZ?/J<\```````````````"JSZO/
MK,^MSZ[/K\^QS[+/L\^TS[7/ML^WS[C/N<^ZS[O/O,^]S[[/O\_`S\'/PL_#
MS\7/QL_'S\C/R<_*S\O/>:Y[KGRN?:Z$KH6NC*Z\KKVNOJ[`KL2NS*[-KL^N
MT*[1KMBNV:[<KNBNZZ[MKO2N^*[\K@>O"*\-KQ"O+*\MKS"O,J\TKSRO/:\_
MKT&O0J]#KTBO2:]0KURO7:]DKV6O>:^`KX2OB*^0KY&OE:^<K[BON:^\K\"O
MQZ_(K\FORZ_-K\ZOU*_<K^BOZ:_PK_&O]*_XKP"P`;`$L`RP$+`4L!RP';`H
ML$2P1;!(L$JP3+!.L%.P5+!5L%>P6;``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#,S\W/SL_/S]#/T<_2S]//U,_5S];/U\_8
MS]G/VL_;S]S/W<_>S]_/XL_CS^7/YL_GS^G/````````````````ZL_KS^S/
M[<_NS^_/\L_TS_;/]\_XS_G/^L_[S_W/_L__SP'0`M`#T`70!M`'T`C0"=`*
MT`````````````````O0#-`-T`[0#]`0T!+0$]`4T!70%M`7T!G0&M`;T!S0
M'=`>T!_0(-`AT"+0(]`DT"70)M`GT"C0*=`JT"O0+-!=L'RP?;"`L(2PC+"-
ML(^PD;"8L)FPFK"<L)^PH+"AL**PJ+"IL*NPK+"ML*ZPK["QL+.PM+"UL+BP
MO+#$L,6PQ[#(L,FPT+#1L-2PV+#@L.6P"+$)L0NQ#+$0L1*Q$[$8L1FQ&[$<
ML1VQ([$DL26Q*+$LL32Q-;$WL3BQ.;%`L4&Q1+%(L5"Q4;%4L56Q6+%<L6"Q
M>+%YL7RQ@+&"L8BQB;&+L8VQDK&3L92QF+&<L:BQS+'0L=2QW+'=L0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"[0+]`PT#'0
M,M`ST#;0-]`YT#K0.]`]T#[0/]!`T$'00M!#T$;02-!*T$O03-!-T$[03]``
M``````````````!1T%+04]!5T%;05]!9T%K06]!<T%W07M!?T&'08M!CT&30
M9=!FT&?0:-!IT&K0:]!NT&_0````````````````<=!RT'/0==!VT'?0>-!Y
MT'K0>]!^T'_0@-""T(/0A-"%T(;0A]"(T(G0BM"+T(S0C=".T(_0D-"1T)+0
MD]"4T-^QZ+'IL>RQ\+'YL?NQ_;$$L@6R"+(+L@RR%+(5LA>R&;(@LC2R/+)8
MLERR8+)HLFFR=+)ULGRRA+*%LHFRD+*1LI2RF+*9LIJRH+*ALJ.RI;*FLJJR
MK+*PLK2RR++)LLRRT++2LMBRV;+;LMVRXK+DLN6RYK+HLNNR[++MLNZR[[+S
MLO2R];+WLOBR^;+ZLONR_[(`LP&S!+,(LQ"S$;,3LQ2S%;,<LU2S5;-6LUBS
M6[-<LUZS7[-DLV6S````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````E="6T)?0F-"9T)K0F]"<T)W0GM"?T*#0H="BT*/0IM"GT*G0
MJM"KT*W0KM"OT+#0L="RT````````````````+/0MM"XT+K0N]"\T+W0OM"_
MT,+0P]#%T,;0Q]#*T,O0S-#-T,[0S]#2T-;0U]#8T-G0VM``````````````
M``#;T-[0W]#AT.+0X]#ET.;0Y]#HT.G0ZM#KT.[0\M#ST/30]=#VT/?0^=#Z
MT/O0_-#]T/[0_]``T0'1`M$#T0319[-ILVNS;K-PLW&S=+-XLX"S@;.#LX2S
MA;.,LY"SE+.@LZ&SJ+.LL\2SQ;/(L\NSS+/.L]"SU+/5L]>SV;/;L]VSX+/D
ML^BS_+,0M!BT'+0@M"BT*;0KM#2T4+11M%2T6+1@M&&T8[1EM&RT@+2(M)VT
MI+2HM*RTM;2WM+FTP+3$M,BTT+35M-RTW;3@M..TY+3FM.RT[;3OM/&T^+04
MM16U&+4;M1RU)+4EM2>U*+4IM2JU,+4QM32U.+4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````%T0;1!]$(T0G1"M$+T0S1#M$/
MT1#1$=$2T1/1%-$5T1;1%]$8T1G1&M$;T1S1'=$>T1_1````````````````
M(-$AT2+1(]$DT271)M$GT2C1*=$JT2O1+-$MT2[1+]$RT3/1-=$VT3?1.=$[
MT3S1/=$^T0```````````````#_10M%&T4?12-%)T4K12]%.T4_14=%2T5/1
M5=%6T5?16-%9T5K16]%>T6#18M%CT6319=%FT6?1:=%JT6O1;=%`M4&U0[5$
MM46U2[5,M4VU4+54M5RU7;5?M6"U8;6@M:&UI+6HM:JUJ[6PM;&UL[6TM;6U
MN[6\M;VUP+7$M<RUS;7/M="UT;78M>RU$+81MA2V&+8EMBRV-+9(MF2V:+:<
MMIVVH+:DMJNVK+:QMM2V\+;TMOBV`+<!MP6W*+<IMRRW+[<PMSBW.;<[MT2W
M2+=,MU2W5;=@MV2W:+=PMW&W<[=UMWRW?;>`MX2WC+>-MX^WD+>1MY*WEK>7
MMP``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````&[1
M;]%PT7'1<M%ST731==%VT7?1>-%YT7K1>]%]T7[1?]&`T8'1@M&#T871AM&'
MT8G1BM$```````````````"+T8S1C=&.T8_1D-&1T9+1D]&4T971EM&7T9C1
MF=&:T9O1G-&=T9[1G]&BT:/1I=&FT:?1````````````````J=&JT:O1K-&M
MT:[1K]&RT;31MM&WT;C1N=&[T;W1OM&_T<'1PM'#T<31Q='&T<?1R-')T<K1
MR]',T<W1SM'/T9BWF;><MZ"WJ+>IMZNWK+>MM[2WM;>XM\>WR;?LM^VW\+?T
MM_RW_;?_MP"X`;@'N`BX";@,N!"X&+@9N!NX';@DN"6X*+@LN#2X-;@WN#BX
M.;A`N$2X4;A3N%RX7;A@N&2X;+AMN&^X<;AXN'RXC;BHN+"XM+BXN,"XP;C#
MN,6XS+C0N-2XW;C?N.&XZ+CIN.RX\+CXN/FX^[C]N`2Y&+D@N3RY/;E`N42Y
M3+E/N5&Y6+E9N5RY8+EHN6FY````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````T-'1T=+1T]'4T=71UM'7T=G1VM';T=S1W='>T=_1
MX-'AT>+1X]'DT>71YM'GT>C1Z='JT0```````````````.O1[-'MT>[1[]'P
MT?'1\M'ST?71]M'WT?G1^M'[T?S1_='^T?_1`-(!T@+2`]($T@72!M(`````
M```````````(T@K2"](,T@W2#M(/TA'2$M(3TA32%=(6TA?2&-(9TAK2&](<
MTAW2'M(?TB#2(=(BTB/2)-(ETB;2)](HTBG2:[EMN72Y=;EXN7RYA+F%N8>Y
MB;F*N8VYCKFLN:VYL+FTN;RYO;F_N<&YR+G)N<RYSKG/N="YT;G2N=BYV;G;
MN=VYWKGAN>.YY+GEN>BY[+GTN?6Y][GXN?FY^KD`N@&Z"+H5NCBZ.;H\ND"Z
M0KI(NDFZ2[I-NDZZ4[I4NE6Z6+I<NF2Z9;IGNFBZ:;IPNG&Z=+IXNH.ZA+J%
MNH>ZC+JHNJFZJ[JLNK"ZLKJXNKFZN[J]NL2ZR+K8NMFZ_+H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````JTBO2+M(OTC'2,M(S
MTC72-M(WTCC2.=(ZTCO2/M)`TD+20])$TD721M)'TDG22M)+TDS2````````
M````````3=).TD_24-)1TE+24])4TE725M)7TEC26=):TEO27=)>TE_28-)A
MTF+28])ETF;29])HT@```````````````&G2:M)KTFS2;=)NTF_2<-)QTG+2
M<])TTG72=M)WTGC2>=)ZTGO2?-)]TG[2?]*"TH/2A=*&TH?2B=**THO2C-(`
MNP2[#;L/NQ&[&+L<NR"[*;LKNS2[-;LVNSB[.[L\NSV[/KM$NT6[1[M)NTV[
M3[M0NU2[6+MANV.[;+N(NXR[D+NDNZB[K+NTN[>[P+O$N\B[T+O3N_B[^;O\
MN_^[`+P"O`B\";P+O`R\#;P/O!&\%+P5O!:\%[P8O!N\'+P=O!Z\'[PDO"6\
M)[PIO"V\,+PQO#2\.+Q`O$&\0[Q$O$6\2;Q,O$V\4+Q=O(2\A;R(O(N\C+R.
MO)2\E;R7O```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(W2CM*/TI+2D]*4TI;2E]*8TIG2FM*;TIW2GM*?TJ'2HM*CTJ72IM*G
MTJC2J=*JTJO2K=(```````````````"NTJ_2L-*RTK/2M-*UTK;2M]*ZTKO2
MO=*^TL'2P]+$TL72QM+'TLK2S-+-TL[2S]+0TM'2````````````````TM+3
MTM72UM+7TMG2VM+;TMW2WM+?TN#2X=+BTN/2YM+GTNC2Z=+JTNO2[-+MTN[2
M[]+RTO/2]=+VTO?2^=+ZTIF\FKR@O*&\I+RGO*B\L+RQO+.\M+RUO+R\O;S`
MO,2\S;S/O-"\T;S5O-B\W+STO/6\]KSXO/R\!+T%O0>]";T0O12])+TLO4"]
M2+U)O4R]4+U8O5F]9+UHO8"]@;V$O8>]B+V)O8J]D+V1O9.]E;V9O9J]G+VD
MO;"]N+W4O=6]V+W<O>F]\+WTO?B]`+X#O@6^#+X-OA"^%+X<OAV^'[Y$OD6^
M2+Y,ODZ^5+Y5OE>^6;Y:OEN^8+YAOF2^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````^]+\TOW2_M+_T@+3!-,&TP?3"-,)TPK3
M"],/TQ'3$M,3TQ73%],8TQG3&M,;TQ[3(M,CTP```````````````"33)M,G
MTRK3*],MTR[3+],QTS+3,],TTS73-M,WTSK3/M,_TT#30=-"TT/31M-'TTC3
M2=,```````````````!*TTO33---TT[33]-0TU'34M-3TU335=-6TU?36--9
MTUK36]-<TUW37M-?TV#38=-BTV/39--ETV;39]-HTVG3:+YJOG"^<;YSOG2^
M=;Y[OGR^?;Z`OH2^C+Z-OH^^D+Z1OIB^F;ZHOM"^T;[4OM>^V+[@ON.^Y+[E
MONR^`;\(OPF_&+\9OQN_'+\=OT"_0;]$OTB_4+]1OU6_E+^PO\6_S+_-O]"_
MU+_<O]^_X;\\P%'`6,!<P&#`:,!IP)#`D<"4P)C`H,"AP*/`I<"LP*W`K\"P
MP+/`M,"UP+;`O,"]P+_`P,#!P,7`R,#)P,S`T,#8P-G`V\#<P-W`Y,``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!JTVO3;--M
MTV[3;]-PTW'3<M-STW33==-VTW?3>--YTWK3>]-^TW_3@=."TX/3A=.&TX?3
M````````````````B-.)TXK3B]..TY+3D].4TY73EM.7TYK3F].=TY[3G].A
MTZ+3H].DTZ73IM.GTZK3K-.NTP```````````````*_3L-.QT[+3L].UT[;3
MM].YT[K3N].]T[[3O]/`T\'3PM/#T\;3Q]/*T\O3S-/-T\[3S]/1T]+3T]/4
MT]73UM/EP.C`[,#TP/7`]\#YP`#!!,$(P1#!%<$<P1W!'L$?P2#!(\$DP2;!
M)\$LP2W!+\$PP3'!-L$XP3G!/,%`P4C!2<%+P4S!3<%4P57!6,%<P63!9<%G
MP6C!:<%PP73!>,&%P8S!C<&.P9#!E,&6P9S!G<&?P:'!I<&HP:G!K,&PP;W!
MQ,'(P<S!U,'7P=C!X,'DP>C!\,'QP?/!_,']P0#"!,(,P@W"#\(1PAC"&<(<
MPA_"(,(HPBG"*\(MP@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-?3V=/:T]O3W-/=T][3W]/@T^+3Y-/ET^;3Y]/HT^G3ZM/K
MT^[3[]/QT_+3\]/UT_;3]],```````````````#XT_G3^M/[T_[3`-0"U`/4
M!-0%U`;4!]0)U`K4"]0,U`W4#M0/U!#4$=02U!/4%-05U!;4````````````
M````%]08U!G4&M0;U!S4'M0?U"#4(=0BU"/4)-0EU";4)]0HU"G4*M0KU"S4
M+=0NU"_4,-0QU#+4,]0TU#74-M0WU"_",<(RPC3"2,)0PE'"5,)8PF#"9<)L
MPFW"<,)TPGS"?<)_PH'"B,*)PI#"F,*;PIW"I,*EPJC"K,*MPK3"M<*WPKG"
MW,+=PN#"X\+DPNO"[,+MPN_"\<+VPOC"^<+[POS"`,,(PPG##,,-PQ/#%,,5
MPQC#',,DPR7#*,,IPT7#:,-IPVS#<,-RPWC#><-\PWW#A,.(PXS#P,/8P]G#
MW,/?P^##XL/HP^G#[</TP_7#^,,(Q!#$),0LQ##$````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````.-0YU#K4.]0\U#W4/M0_U$'4
M0M1#U$741M1'U$C42=1*U$O43-1-U$[43]10U%'44M13U```````````````
M`%345=16U%?46-19U%K46]1=U%[47]1AU&+48]1EU&;49]1HU&G4:M1KU&S4
M;M1PU''4<M0```````````````!SU'34==1VU'?4>M1[U'W4?M2!U(/4A-2%
MU(;4A]2*U(S4CM2/U)#4D=22U)/4E=26U)?4F-29U)K4F]2<U)W4-,0\Q#W$
M2,1DQ&7$:,1LQ'3$=<1YQ(#$E,2<Q+C$O,3IQ/#$\<3TQ/C$^L3_Q`#%`<4,
MQ1#%%,4<Q2C%*<4LQ3#%.,4YQ3O%/<5$Q47%2,5)Q4K%3,5-Q4[%4\54Q57%
M5\58Q5G%7<5>Q6#%8<5DQ6C%<,5QQ7/%=,5UQ7S%?<6`Q83%A\6,Q8W%C\61
MQ97%E\68Q9S%H,6IQ;3%M<6XQ;G%N\6\Q;W%OL7$Q<7%QL7'Q<C%R<7*Q<S%
MSL4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````">
MU)_4H-2AU*+4H]2DU*74IM2GU*C4JM2KU*S4K=2NU*_4L-2QU++4L]2TU+74
MMM2WU+C4````````````````N=2ZU+O4O-2]U+[4O]3`U,'4PM3#U,34Q=3&
MU,?4R-3)U,K4R]3-U,[4S]31U-+4T]35U````````````````-;4U]38U-G4
MVM3;U-W4WM3@U.'4XM3CU.34Y=3FU.?4Z=3JU.O4[=3NU._4\=3RU//4]-3U
MU/;4]]3YU/K4_-30Q='%U,78Q>#%X<7CQ>7%[,7MQ>[%\,7TQ?;%]\7\Q?W%
M_L7_Q0#&`<8%Q@;&!\8(Q@S&$,88QAG&&\8<QB3&)<8HQBS&+<8NQC#&,\8T
MQC7&-\8YQCO&0,9!QD3&2,90QE'&4\94QE7&7,9=QF#&;,9OQG'&>,9YQGS&
M@,:(QHG&B\:-QI3&E<:8QIS&I,:EQJ?&J<:PQK'&M,:XQKG&NL;`QL'&P\;%
MQLS&S<;0QM3&W,;=QN#&X<;HQ@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/[4_]0`U0'5`M4#U075!M4'U0G5"M4+U0W5#M4/
MU1#5$=42U1/5%M48U1G5&M4;U1S5'=4````````````````>U1_5(-4AU2+5
M(]4DU275)M4GU2C5*=4JU2O5+-4MU2[5+]4PU3'5,M4SU335-=4VU3?5````
M````````````.-4YU3K5.]4^U3_50=5"U4/51=5&U4?52-5)U4K52]5.U5#5
M4M53U5355=56U5?56M5;U5W57M5?U6'58M5CU>G&[,;PQOC&^<;]Q@3'!<<(
MQPS'%,<5QQ?'&<<@QR''),<HQS#',<<SQS7'-\<\QSW'0,=$QTK'3,=-QT_'
M4<=2QU/'5,=5QU;'5\=8QUS'8,=HQVO'=,=UQWC'?,=]QW['@\>$QX7'A\>(
MQXG'BL>.QY#'D<>4QY;'E\>8QYK'H,>AQZ/'I,>EQZ;'K,>MQ[#'M,>\Q[W'
MO\?`Q\''R,?)Q\S'SL?0Q]C'W<?DQ^C'[,<`R`'(!,@(R`K(````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````9-5FU6?5:M5LU6[5
M;]5PU7'5<M5SU7;5=]5YU7K5>]5]U7[5?]6`U8'5@M6#U8;5BM6+U0``````
M`````````(S5C=6.U8_5D=62U9/5E-65U9;5E]68U9G5FM6;U9S5G=6>U9_5
MH-6AU:+5H]6DU:;5I]4```````````````"HU:G5JM6KU:S5K=6NU:_5L-6Q
MU;+5L]6TU;75MM6WU;C5N=6ZU;O5O-6]U;[5O]7`U<'5PM7#U<35Q=7&U<?5
M$,@1R!/(%<@6R!S('<@@R"3(+,@MR"_(,<@XR#S(0,A(R$G(3,A-R%3(<,AQ
MR'3(>,AZR(#(@<B#R(7(ALB'R(O(C,B-R)3(G<B?R*'(J,B\R+W(Q,C(R,S(
MU,C5R-?(V<C@R.'(Y,CUR/S(_<@`R03)!<D&R0S)#<D/R1')&,DLR33)4,E1
MR53)6,E@R6')8\ELR7#)=,E\R8C)B<F,R9#)F,F9R9O)G<G`R<')Q,G'R<C)
MRLG0R=')T\D`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#*U<O5S=7.U<_5T=73U=35U=76U=?5VM7<U=[5W]7@U>'5XM7CU>;5
MY]7IU>K5Z]7MU>[5````````````````[]7PU?'5\M7SU?;5^-7ZU?O5_-7]
MU?[5_]4"U@/6!=8&U@?6"=8*U@O6#-8-U@[6#]82U@```````````````!;6
M%]88UAG6&M8;UAW6'M8?UB'6(M8CUB76)M8GUBC6*=8JUBO6+-8NUB_6,-8Q
MUC+6,]8TUC76-M8WUCK6.];5R=;)V<G:R=S)W<G@R>+)Y,GGR>S)[<GOR?#)
M\<GXR?G)_,D`R@C*"<H+R@S*#<H4RAC**<I,RDW*4,I4RES*7<I?RF#*8<IH
MRGW*A,J8RKS*O<K`RL3*S,K-RL_*T<K3RMC*V<K@RNS*],H(RQ#+%,L8RR#+
M(<M!RTC+2<M,RU#+6,M9RUW+9,MXRWG+G,NXR]3+Y,OGR^G+#,P-S!#,%,P<
MS!W,(<PBS"?,*,PIS"S,+LPPS#C,.<P[S```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#W6/M8_UD'60M9#UD361M9'UDK63-9.
MUD_64-92UE/65M97UEG66M9;UEW67M9?UF#68=8```````````````!BUF/6
M9-9EUF;6:-9JUFO6;-9MUF[6;]9RUG/6==9VUG?6>-9YUGK6>]9\UGW6?M9_
MUH#6````````````````@=:"UH36AM:'UHC6B=:*UHO6CM:/UI'6DM:3UI76
MEM:7UIC6F=::UIO6G-:>UJ#6HM:CUJ36I=:FUJ?6J=:JUCS,/<P^S$3,1<Q(
MS$S,5,Q5S%?,6,Q9S&#,9,QFS&C,<,QUS)C,F<R<S*#,J,RIS*O,K,RMS+3,
MM<RXS+S,Q,S%S,?,R<S0S-3,Y,SLS/#,`<T(S0G-#,T0S1C-&<T;S1W-),TH
MS2S-.<U<S6#-9,ULS6W-;\UQS7C-B,V4S97-F,V<S:3-I<VGS:G-L,W$S<S-
MT,WHS>S-\,WXS?G-^\W]S03.",X,SA3.&<X@SB'.),XHSC#.,<XSSC7.````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````J]:MUJ[6
MK]:QUK+6L]:TUK76MM:WUKC6NM:\UKW6OM:_UL#6P=;"UL/6QM;'ULG6RM;+
MU@```````````````,W6SM;/UM#6TM;3UM76UM;8UMK6V];<UMW6WM;?UN'6
MXM;CUN76YM;GUNG6ZM;KUNS6[=8```````````````#NUN_6\=;RUO/6]-;V
MUO?6^-;YUOK6^];^UO_6`=<"UP/7!=<&UP?7"-<)UPK7"]<,UPW7#M</UQ#7
M$M<3UQ376,Y9SES.7\Y@SF'.:,YISFO.;<YTSG7.>,Y\SH3.A<Z'SHG.D,Z1
MSI3.F,Z@SJ'.H\ZDSJ7.K,ZMSL'.Y,[ESNC.Z\[LSO3.]<[WSOC.^<X`SP'/
M!,\(SQ#/$<\3SQ7/',\@SR3/+,\MSR_/,,\QSSC/5,]5SUC/7,]DSV7/9\]I
MSW#/<<]TSWC/@,^%SXS/H<^HS[#/Q,_@S^'/Y,_HS_#/\<_SS_7/_,\`T`30
M$=`8T"W0--`UT#C0/-``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````5UQ;7%]<:UQO7'=<>UQ_7(=<BUR/7)-<EUR;7)]<JURS7
M+M<OUS#7,=<RUS/7-M<WUSG7````````````````.M<[USW7/M<_UT#70=="
MUT/71==&UTC72M=+UTS73==.UT_74M=3UU776M=;UUS77==>UP``````````
M`````%_78M=DUV;79]=HUVK7:]=MUV[7;]=QUW+7<]=UUW;7=]=XUWG7>M=[
MUW[7?]>`UX+7@]>$UX77AM>'UXK7B]=$T$701]!)T%#05-!8T&#0;-!MT'#0
M=-!\T'W0@="DT*70J-"LT+30M="WT+G0P-#!T,30R-#)T-#0T=#3T-30U=#<
MT-W0X-#DT.S0[=#OT/#0\=#XT`W1,-$QT331.-$ZT4#10=%#T4311=%,T4W1
M4-%4T5S17=%?T6'1:-%LT7S1A-&(T:#1H=&DT:C1L-&QT;/1M=&ZT;S1P-'8
MT?31^-$'T@G2$-(LTBW2,-(TTCS2/=(_TD'22-)<T@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(W7CM>/UY'7DM>3UY37E=>6
MUY?7FM><UY[7G]>@UZ'7HM>CUP``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````&32@-*!
MTH32B-*0TI'2E=*<TJ#2I-*LTK'2N-*YTKS2O]+`TL+2R-+)TLO2U-+8TMS2
MY-+ETO#2\=+TTOC2`-,!TP/3!=,,TPW3#M,0TQ33%M,<TQW3'],@TR'3)=,H
MTRG3+-,PTSC3.=,[TSS3/=-$TT73?--]TX#3A-.,TXW3C].0TY'3F-.9TYS3
MH-.HTZG3J].MT[33N-.\T\33Q=/(T\G3T-/8T^'3X]/LT^W3\-/TT_S3_=/_
MTP'4````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````"-0=U$#41-1<U&#49-1MU&_4>-1YU'S4?]2`U(+4B-2)
MU(O4C=24U*G4S-30U-34W-3?U.C4[-3PU/C4^]3]U`35"-4,U135%=47U3S5
M/=5`U4353-5-U4_54=58U5G57-5@U675:-5IU6O5;=5TU775>-5\U835A=6'
MU8C5B=60U:75R-7)U<S5T-72U=C5V=7;U=W5Y-7EU>C5[-7TU?75]]7YU0#6
M`=8$U@C6$-81UA/6%-85UAS6(-8`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````DUBW6.-8YUCS60-9%UDC6
M2=9+UDW64=94UE766-9<UF?6:=9PUG'6=-:#UH76C-:-UI#6E-:=UI_6H=:H
MUJS6L-:YUKO6Q-;%ULC6S-;1UM36U];9UN#6Y-;HUO#6]=;\UOW6`-<$UQ'7
M&-<9UQS7(-<HURG7*]<MUS37-=<XUSS71-='UTG74-=1UU375M=7UUC76==@
MUV'78]=EUVG7;-=PUW37?-=]UX'7B->)UXS7D->8UYG7F]>=UP`````B````
M``````````!!!```Q;T8",R]&`CTFQ@(``````"4'`@`DQP(`)(<"`"1'`@`
M``````````"/'`B`C!P(```````````"`````0````$`````````0`@9"$",
M'`@`````V)\'"#BB!PA\H@<([*,'"'Q_!PC,=`<(H(('".AU!P@`````````
M``````````````````````````````#]``".'`@"`7X!@(T<"!,@K"#@C!P(
MQP+=`K&,'`@B(2(AL(P<"```````````F:$`````````````````````HO\`
ML@"]````````````````````````````````EI<```"1DH(`DY2$`(:'E0``
M`(4```````````")``````````"+FP``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M@````````,/CI;G&Y@````#(Z,_OT/````````#*ZLSL````````````````
M``````````````````````#%Y0``O+X``*.ST?$``-+R`````````-7U``#`
MX```V/B,G```JKJ*FM[^C9T``````````-GYV_L`````````CY^OOXZ>````
M``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL
M+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA9
M6EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G\`````````
M`````````````````````````````````*````"D`*:GJ*D`JZRMK@"PL0``
MM+6VM[@``+L``````,'"`,0``,<`R0#+`,W.`````-/4`-;7``#:`-S=`-\`
MX>(`Y```YP#I`.L`[>X`````\_0`]O<``/H`_/T``````0`"``,`!``%``8`
M!P`(``D`"@`+``P`#0`.``\`$``1`!(`$P`4`!4`%@`7`!@`&0`:`!L`'``=
M`!X`'P`@`"$`(@`C`"0`)0`F`"<`*``I`"H`*P`L`"T`+@`O`#``,0`R`#,`
M-``U`#8`-P`X`#D`.@`[`#P`/0`^`#\`0`!!`$(`0P!$`$4`1@!'`$@`20!*
M`$L`3`!-`$X`3P!0`%$`4@!3`%0`50!6`%<`6`!9`%H`6P!<`%T`7@!?`&``
M80!B`&,`9`!E`&8`9P!H`&D`:@!K`&P`;0!N`&\`<`!Q`'(`<P!T`'4`=@!W
M`'@`>0!Z`'L`?`!]`'X`?P"L(```&B```!X@)B`@("$@```P(&`!.2!:`60!
M?0%Y`0``&"`9(!P@'2`B(!,@%"```"(A80$Z(%L!90%^`7H!H`#'`M@"00&D
M``0!I@"G`*@`J0!>`:L`K`"M`*X`>P&P`+$`VP)"`;0`M0"V`+<`N``%`5\!
MNP`]`=T"/@%\`50!P0#"``(!Q``Y`08!QP`,`<D`&`'+`!H!S0#.``X!$`%#
M`4<!TP#4`%`!U@#7`%@!;@':`'`!W`#=`&(!WP!5`>$`X@`#`>0`.@$'`><`
M#0'I`!D!ZP`;`>T`[@`/`1$!1`%(`?,`]`!1`?8`]P!9`6\!^@!Q`?P`_0!C
M`=D"``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I
M*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%56
M5UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#
MA(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^P
ML;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=
MWM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`!`@,$!08'"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W
M.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$
M149'2$E*2TQ-3D]045)35%565UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1
MDI.4E9:7F)F*FXR-CH^@H:*CI*6FIZBIJJNLK:ZOL+&RH[2UMK>XI:J[O+V\
MK\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=ZGP,'"P\3%QL?(R<K+
MS,W.S]#1TM/4U=;WV-G:V]S=WO\``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8
M&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0&%B8V1E
M9F=H:6IK;&UN;W!Q<G-T=79W>'EZ6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R
M<W1U=G=X>7I[?'U^?X"!@H.$A8:'B(F:BYR=GI^0D9*3E)66EYB9FIN<G9Z?
MH*&BLZ2YIM^HJ;JKK*VNO["QLK.TM;:WN+FZN[Z]OK_@X>+CY.7FY^CIZNOL
M[>[O\/'R\_3U]M?X^?K[_/W^W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY
M^OO\_?[_`"`@("`@("`@("@H*"@H("`@("`@("`@("`@("`@("`@2!`0$!`0
M$!`0$!`0$!`0$(2$A(2$A(2$A(00$!`0$!`0@8&!@8&!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$0$!`0$!""@H*"@H("`@("`@("`@("`@("`@("`@("`A`0$!`@
M("`0(!`0$!`@$`$0`0$!`2`0$!`0$!`0(!`"$`("`@)($!`!$`$0`1`0`1`0
M$!`!$!`0`A`0$!`0`@(0`1`"`@$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!$`$!
M`0$!`0$"`@("`@("`@("`@("`@("`@("`@("`@(0`@("`@("`A``````````
M````````````````````````````````MK:VMK:VMK:VMK:VMK:VMK:VMK:V
MMK:VMK:VMK:VMK:@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T"Y
M8DGPZF9G:.YJ:[-M\O5P<>"Z_OMV=WC]GUM<75Y?8#9B2?#J9F=H[FIKLVWR
M]7!QX+K^^W9W>/V?I7Q]?K:VMH*VA(6&A[:)FHNZ_IZ?MI&2DY25EI>VF9J;
MNOZ>GR"AHK.DI::GJ+FZJZRMKI^PL;*SM+6VM[BYNKNSO;.?X+FYN;FS[N[(
MZNKJZN[N\/#R\O7U]?77^/O[^_O]_M_@N;FYN;/N[LCJZNKJ[N[P\/+R]?7U
M]??X^_O[^_W^_P``````````````````````````````````````````("$B
M(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/
M4%%24U155E=865I;7%U>7V`V0D-$149'2$E*2TQ-3D]045)35%565UA96J5\
M?7X```""`(2%AH<`B8J+4U2.6@"1DI.4E9:7`)F*FU-4CEH@H:),I*6FIZA!
M4ZNLK:Y:L+&R3+2U`+>X05.[3+U,6E)!04%!3$-#R$5%145)241$3DY/3T]/
MU]A55555653?4D%!04%,0T/(145%14E)1$1.3D]/3T_WV%5555595/]UN1@(
MK0,``"6""`BF`@``?;D8"*T"``"%N1@(K0$``,1X"`BF`0``````````````
M`````````````````````@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?
M("$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?\!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0("_P("`@("`@("`@("`@("`@("`@("
M`@("`0$!`2(C)`$E`0$!`28!`0$#`P$%)P$!`0$!`0$H`0(!!`0"!@(!`0<!
M$0$!`0$%`0$!`0,!`0$(`0$I`0$2!@$%`08$`P,%!PD#`P4!`PD'!0,%`P4#
M!0,%"0<!`04#"0<#!0$$!`8("@0$!@($"@@&!`8$!@0&!`8*"`$"!@0*"`0&
M`8&!@8&!@8&!@8&!@8&!@8&!@8&!@8&!@8&!@8&!@8&!@H.$A8:'B(F*BXR-
MCH^0D9*3E)66EYB9FIN<G9Z?H*&BI*7_J*FJJZRNK["QLK.TM;:WN;R]OK_`
MP<+$Q<;'R,FDI?^HJ:JKK*ZOL+&RL[2UMK>YO+V^O\#!PLK+S,V!@8'.@<_0
MT=*!T[K4N;S#PH'5UM?8V=K;@=RZW;F\P\*"WM^QX*3AXN/DN>7FY^C"Z>KK
ML>WN@>_PI+GQL?*QPK>DI*2DL::FIZFIJ:FNKJBHL[.TM+2T\[B]O;V]P;R[
MMZ2DI*2QIJ:GJ:FIJ:ZNJ*BSL[2TM+3TN+V]O;W!O/53``````````````"1
M````W+T8".&]&`CTFQ@(`````,";'`C`FAP(P)D<"```````````````````
M```````````````````!`````0````,``````/\`@)T<"(`J)0@``0(#!`4&
M!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S
M-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@
M04)#1$5&1TA)2DM,34Y/4%%24U155E=865I[?'U^?X"!@H.$A8:'B(F*BXR-
MCH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZ
MN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;G
MZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_``$"`P0%!@<("0H+#`T.#Q`1$A,4
M%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!A
M8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>EM<75Y?8&%B8V1E9F=H:6IK;&UN
M;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;
MG)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(
MR<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U
M]O?X^?K[_/W^_P`@("`@("`@("`H*"@H*"`@("`@("`@("`@("`@("`@($@0
M$!`0$!`0$!`0$!`0$!"$A(2$A(2$A(2$$!`0$!`0$(&!@8&!@0$!`0$!`0$!
M`0$!`0$!`0$!`0$!$!`0$!`0@H*"@H*"`@("`@("`@("`@("`@("`@("`@(0
M$!`0(`,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,`````
M`````````````````````````````````````"$``````````````.$```#<
MO1@(ZKT8"/2;&`@`````P)L<",":'`C`F1P(P)D<"```````````````````
M``````````````$````!`````P``````__^`G1P(0)T<"``````PL`<(5+,'
M""RY!PCD7P@(`+D'",BV!PA@70@('*H'"```````````````````````````
M````````````````_+H'"+"[!PAP7`@(N%P("!Q="`B`@@<(+&4(""BG!PCT
MIP<(:*L'")2N!PB,J`<(!*T'",QU!PA\?0<(3'X'"#2"!PA0=@<(T'<'""AY
M!PA4>P<(-'T'"/2%!PC,@0<(````````````````````````````````````
M``#>'`@`V!P(`-(<"`#,'`@`QAP(`,`<"```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"Z'`@`M!P(``````"N
M'`@```````````"H'`@`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"B'`@`_P#_`/\!_P'_
M`?\"_P+_`O\#_P/_`_\$_P3_!/\%_P7_!?\&_P;_!O\'_P?_!_\(_PC_"/\)
M_PG_"?\*_PK_"O\+_PO_"_\,_PS_#/\-_PW_#?\._P[_#O\/_P__#_\0_Q#_
M$/\1_Q'_$?\2_Q+_$O\3_Q/_$_\4_Q3_%/\5_Q7_%?\6_Q;_%O\7_Q?_%_\8
M_QC_&/\9_QG_&?\:_QK_&O\;_QO_&_\<_QS_'/\=_QW_'?\>_Q[_'O\?_Q__
M'_\@_R#_(/\A_T'_(?\B_T+_(O\C_T/_(_\D_T3_)/\E_T7_)?\F_T;_)O\G
M_T?_)_\H_TC_*/\I_TG_*?\J_TK_*O\K_TO_*_\L_TS_+/\M_TW_+?\N_T[_
M+O\O_T__+_\P_U#_,/\Q_U'_,?\R_U+_,O\S_U/_,_\T_U3_-/\U_U7_-?\V
M_U;_-O\W_U?_-_\X_UC_./\Y_UG_.?\Z_UK_.O\[_SO_._\\_SS_//\]_SW_
M/?\^_S[_/O\__S__/_]`_T#_0/\A_T'_(?\B_T+_(O\C_T/_(_\D_T3_)/\E
M_T7_)?\F_T;_)O\G_T?_)_\H_TC_*/\I_TG_*?\J_TK_*O\K_TO_*_\L_TS_
M+/\M_TW_+?\N_T[_+O\O_T__+_\P_U#_,/\Q_U'_,?\R_U+_,O\S_U/_,_\T
M_U3_-/\U_U7_-?\V_U;_-O\W_U?_-_\X_UC_./\Y_UG_.?\Z_UK_.O];_UO_
M6_]<_US_7/]=_UW_7?]>_U[_7O]?_U__7_]@_V#_8/]A_V'_8?]B_V+_8O]C
M_V/_8_]D_V3_9/]E_V7_9?]F_V;_9O]G_V?_9_]H_VC_:/]I_VG_:?]J_VK_
M:O]K_VO_:_]L_VS_;/]M_VW_;?]N_V[_;O]O_V__;_]P_W#_</]Q_W'_<?]R
M_W+_<O]S_W/_<_]T_W3_=/]U_W7_=?]V_W;_=O]W_W?_=_]X_WC_>/]Y_WG_
M>?]Z_WK_>O][_WO_>_]\_WS_?/]]_WW_??]^_W[_?O]__W__?_^`_X#_@/^!
M_X'_@?^"_X+_@O^#_X/_@_^$_X3_A/^%_X7_A?^&_X;_AO^'_X?_A_^(_XC_
MB/^)_XG_B?^*_XK_BO^+_XO_B_^,_XS_C/^-_XW_C?^._X[_CO^/_X__C_^0
M_Y#_D/^1_Y'_D?^2_Y+_DO^3_Y/_D_^4_Y3_E/^5_Y7_E?^6_Y;_EO^7_Y?_
ME_^8_YC_F/^9_YG_F?^:_YK_FO^;_YO_F_^<_YS_G/^=_YW_G?^>_Y[_GO^?
M_Y__G_^@_Z#_H/^A_Z'_H?^B_Z+_HO^C_Z/_H_^D_Z3_I/^E_Z7_I?^F_Z;_
MIO^G_Z?_I_^H_ZC_J/^I_ZG_J?^J_ZK_JO^K_ZO_J_^L_ZS_K/^M_ZW_K?^N
M_Z[_KO^O_Z__K_^P_[#_L/^Q_['_L?^R_[+_LO^S_[/_L_^T_[3_M/^U_[7_
MM?^V_[;_MO^W_[?_M_^X_[C_N/^Y_[G_N?^Z_[K_NO^[_[O_N_^\_[S_O/^]
M_[W_O?^^_[[_OO^__[__O__`_\#_P/_!_\'_P?_"_\+_PO_#_\/_P__$_\3_
MQ/_%_\7_Q?_&_\;_QO_'_\?_Q__(_\C_R/_)_\G_R?_*_\K_RO_+_\O_R__,
M_\S_S/_-_\W_S?_._\[_SO_/_\__S__0_]#_T/_1_]'_T?_2_]+_TO_3_]/_
MT__4_]3_U/_5_]7_U?_6_];_UO_7_]?_U__8_]C_V/_9_]G_V?_:_]K_VO_;
M_]O_V__<_]S_W/_=_]W_W?_>_][_WO_?_]__W__@_^#_X/_A_^'_X?_B_^+_
MXO_C_^/_X__D_^3_Y/_E_^7_Y?_F_^;_YO_G_^?_Y__H_^C_Z/_I_^G_Z?_J
M_^K_ZO_K_^O_Z__L_^S_[/_M_^W_[?_N_^[_[O_O_^__[__P__#_\/_Q__'_
M\?_R__+_\O_S__/_\__T__3_]/_U__7_]?_V__;_]O_W__?_]__X__C_^/_Y
M__G_^?_Z__K_^O_[__O_^__\__S__/_]__W__?_^__[__O________\`)``D
M`"0!)`$D`20")`(D`B0#)`,D`R0$)`0D!"0%)`4D!20&)`8D!B0')`<D!R0(
M)`@D""0))`DD"20*)`HD"B0+)`LD"R0,)`PD#"0-)`TD#20.)`XD#B0/)`\D
M#R00)!`D$"01)!$D$202)!(D$B03)!,D$R04)!0D%"05)!4D%206)!8D%B07
M)!<D%R08)!@D&"09)!DD&20:)!HD&B0;)!LD&R0<)!PD'"0=)!TD'20>)!XD
M'B0?)!\D'R0@)"`D("0A)"$D(20B)"(D(B0C)",D(R0D)"0D)"0E)"4D)20F
M)"8D)B0G)"<D)R0H)"@D*"0I)"DD*20J)"HD*B0K)"LD*R0L)"PD+"0M)"TD
M+20N)"XD+B0O)"\D+R0P)#`D,"0Q)#$D,20R)#(D,B0S)#,D,R0T)#0D-"0U
M)#4D-20V)#8D-B0W)#<D-R0X)#@D."0Y)#DD.20Z)#HD.B0[)#LD.R0\)#PD
M/"0])#TD/20^)#XD/B0_)#\D/R1`)$`D0"1!)$$D021")$(D0B1#)$,D0R1$
M)$0D1"1%)$4D121&)$8D1B1')$<D1R1()$@D2"1))$DD221*)$HD2B1+)$LD
M2R1,)$PD3"1-)$TD321.)$XD3B1/)$\D3R10)%`D4"11)%$D4212)%(D4B13
M)%,D4R14)%0D5"15)%4D5216)%8D5B17)%<D5R18)%@D6"19)%DD621:)%HD
M6B1;)%LD6R1<)%PD7"1=)%TD721>)%XD7B1?)%\D7R1@)&`D8"1A)&$D821B
M)&(D8B1C)&,D8R1D)&0D9"1E)&4D921F)&8D9B1G)&<D9R1H)&@D:"1I)&DD
M:21J)&HD:B1K)&LD:R1L)&PD;"1M)&TD;21N)&XD;B1O)&\D;R1P)'`D<"1Q
M)'$D<21R)'(D<B1S)',D<R1T)'0D="1U)'4D=21V)'8D=B1W)'<D=R1X)'@D
M>"1Y)'DD>21Z)'HD>B1[)'LD>R1\)'PD?"1])'TD?21^)'XD?B1_)'\D?R2`
M)(`D@"2!)($D@22")((D@B2#)(,D@R2$)(0DA"2%)(4DA22&)(8DAB2')(<D
MAR2()(@DB"2))(DDB22*)(HDBB2+)(LDBR2,)(PDC"2-)(TDC22.)(XDCB2/
M)(\DCR20))`DD"21))$DD222))(DDB23)),DDR24))0DE"25))4DE226))8D
MEB27))<DER28))@DF"29))DDF22:))HDFB2;))LDFR2<))PDG"2=))TDG22>
M))XDGB2?))\DGR2@)*`DH"2A)*$DH22B)*(DHB2C)*,DHR2D)*0DI"2E)*4D
MI22F)*8DIB2G)*<DIR2H)*@DJ"2I)*DDJ22J)*HDJB2K)*LDJR2L)*PDK"2M
M)*TDK22N)*XDKB2O)*\DKR2P)+`DL"2Q)+$DL22R)+(DLB2S)+,DLR2T)+0D
MM"2U)+4DM22V)-`DMB2W)-$DMR2X)-(DN"2Y)-,DN22Z)-0DNB2[)-4DNR2\
M)-8DO"2])-<DO22^)-@DOB2_)-DDOR3`)-HDP"3!)-LDP23")-PDPB3#)-TD
MPR3$)-XDQ"3%)-\DQ23&).`DQB3').$DQR3().(DR"3)).,DR23*).0DRB3+
M).4DRR3,).8DS"3-).<DS23.).@DSB3/).DDSR2V)-`DMB2W)-$DMR2X)-(D
MN"2Y)-,DN22Z)-0DNB2[)-4DNR2\)-8DO"2])-<DO22^)-@DOB2_)-DDOR3`
M)-HDP"3!)-LDP23")-PDPB3#)-TDPR3$)-XDQ"3%)-\DQ23&).`DQB3').$D
MQR3().(DR"3)).,DR23*).0DRB3+).4DRR3,).8DS"3-).<DS23.).@DSB3/
M).DDSR3J).HDZB3K).LDZR3L).PD["3M).TD[23N).XD[B3O).\D[R3P)/`D
M\"3Q)/$D\23R)/(D\B3S)/,D\R3T)/0D]"3U)/4D]23V)/8D]B3W)/<D]R3X
M)/@D^"3Y)/DD^23Z)/HD^B3[)/LD^R3\)/PD_"3])/TD_23^)/XD_B3_)/\D
M_R0`(0`A`"$!(0$A`2$"(0(A`B$#(0,A`R$$(00A!"$%(04A!2$&(08A!B$'
M(0<A!R$((0@A""$)(0DA"2$*(0HA"B$+(0LA"R$,(0PA#"$-(0TA#2$.(0XA
M#B$/(0\A#R$0(1`A$"$1(1$A$2$2(1(A$B$3(1,A$R$4(10A%"$5(14A%2$6
M(18A%B$7(1<A%R$8(1@A&"$9(1DA&2$:(1HA&B$;(1LA&R$<(1PA'"$=(1TA
M'2$>(1XA'B$?(1\A'R$@(2`A("$A(2$A(2$B(2(A(B$C(2,A(R$D(20A)"$E
M(24A)2$F(<D#)B$G(2<A)R$H(2@A*"$I(2DA*2$J(6L`*B$K(>4`*R$L(2PA
M+"$M(2TA+2$N(2XA+B$O(2\A+R$P(3`A,"$Q(3$A,2$R(3(A,B$S(3,A,R$T
M(30A-"$U(34A-2$V(38A-B$W(3<A-R$X(3@A."$Y(3DA.2$Z(3HA.B$[(3LA
M.R$\(3PA/"$](3TA/2$^(3XA/B$_(3\A/R%`(4`A0"%!(4$A02%"(4(A0B%#
M(4,A0R%$(40A1"%%(44A12%&(48A1B%'(4<A1R%((4@A2"%)(4DA22%*(4HA
M2B%+(4LA2R%,(4PA3"%-(4TA32%.(4XA3B%/(4\A3R%0(5`A4"%1(5$A42%2
M(5(A4B%3(5,A4R%4(50A5"%5(54A52%6(58A5B%7(5<A5R%8(5@A6"%9(5DA
M62%:(5HA6B%;(5LA6R%<(5PA7"%=(5TA72%>(5XA7B%?(5\A7R%@(7`A8"%A
M(7$A82%B(7(A8B%C(7,A8R%D(70A9"%E(74A92%F(78A9B%G(7<A9R%H(7@A
M:"%I(7DA:2%J(7HA:B%K(7LA:R%L(7PA;"%M(7TA;2%N(7XA;B%O(7\A;R%@
M(7`A8"%A(7$A82%B(7(A8B%C(7,A8R%D(70A9"%E(74A92%F(78A9B%G(7<A
M9R%H(7@A:"%I(7DA:2%J(7HA:B%K(7LA:R%L(7PA;"%M(7TA;2%N(7XA;B%O
M(7\A;R&`(8`A@"&!(8$A@2&"(8(A@B&#(8,A@R&$(80AA"&%(84AA2&&(88A
MAB&'(8<AAR&((8@AB"&)(8DAB2&*(8HABB&+(8LABR&,(8PAC"&-(8TAC2&.
M(8XACB&/(8\ACR&0(9`AD"&1(9$AD2&2(9(ADB&3(9,ADR&4(90AE"&5(94A
ME2&6(98AEB&7(9<AER&8(9@AF"&9(9DAF2&:(9HAFB&;(9LAFR&<(9PAG"&=
M(9TAG2&>(9XAGB&?(9\AGR&@(:`AH"&A(:$AH2&B(:(AHB&C(:,AHR&D(:0A
MI"&E(:4AI2&F(:8AIB&G(:<AIR&H(:@AJ"&I(:DAJ2&J(:HAJB&K(:LAJR&L
M(:PAK"&M(:TAK2&N(:XAKB&O(:\AKR&P(;`AL"&Q(;$AL2&R(;(ALB&S(;,A
MLR&T(;0AM"&U(;4AM2&V(;8AMB&W(;<AMR&X(;@AN"&Y(;DAN2&Z(;HANB&[
M(;LANR&\(;PAO"&](;TAO2&^(;XAOB&_(;\AOR'`(<`AP"'!(<$AP2'"(<(A
MPB'#(<,APR'$(<0AQ"'%(<4AQ2'&(<8AQB''(<<AQR'((<@AR"')(<DAR2'*
M(<HARB'+(<LARR',(<PAS"'-(<TAS2'.(<XASB'/(<\ASR'0(=`AT"'1(=$A
MT2'2(=(ATB'3(=,ATR'4(=0AU"'5(=4AU2'6(=8AUB'7(=<AUR'8(=@AV"'9
M(=DAV2':(=HAVB';(=LAVR'<(=PAW"'=(=TAW2'>(=XAWB'?(=\AWR'@(>`A
MX"'A(>$AX2'B(>(AXB'C(>,AXR'D(>0AY"'E(>4AY2'F(>8AYB'G(><AYR'H
M(>@AZ"'I(>DAZ2'J(>HAZB'K(>LAZR'L(>PA["'M(>TA[2'N(>XA[B'O(>\A
M[R'P(?`A\"'Q(?$A\2'R(?(A\B'S(?,A\R'T(?0A]"'U(?4A]2'V(?8A]B'W
M(?<A]R'X(?@A^"'Y(?DA^2'Z(?HA^B'[(?LA^R'\(?PA_"'](?TA_2'^(?XA
M_B'_(?\A_R$('P`?D0,)'P$?D0,*'P(?D0,+'P,?D0,,'P0?D0,-'P4?D0,.
M'P8?D0,/'P<?D0,('P`?D0,)'P$?D0,*'P(?D0,+'P,?D0,,'P0?D0,-'P4?
MD0,.'P8?D0,/'P<?D0,8'Q`?E0,9'Q$?E0,:'Q(?E0,;'Q,?E0,<'Q0?E0,=
M'Q4?E0,6'Q8?%A\7'Q<?%Q\8'Q`?E0,9'Q$?E0,:'Q(?E0,;'Q,?E0,<'Q0?
ME0,='Q4?E0,>'QX?'A\?'Q\?'Q\H'R`?EP,I'R$?EP,J'R(?EP,K'R,?EP,L
M'R0?EP,M'R4?EP,N'R8?EP,O'R<?EP,H'R`?EP,I'R$?EP,J'R(?EP,K'R,?
MEP,L'R0?EP,M'R4?EP,N'R8?EP,O'R<?EP,X'S`?F0,Y'S$?F0,Z'S(?F0,[
M'S,?F0,\'S0?F0,]'S4?F0,^'S8?F0,_'S<?F0,X'S`?F0,Y'S$?F0,Z'S(?
MF0,['S,?F0,\'S0?F0,]'S4?F0,^'S8?F0,_'S<?F0-('T`?GP-)'T$?GP-*
M'T(?GP-+'T,?GP-,'T0?GP--'T4?GP-&'T8?1A]''T<?1Q]('T`?GP-)'T$?
MGP-*'T(?GP-+'T,?GP-,'T0?GP--'T4?GP-.'TX?3A]/'T\?3Q]0'U`?I0-9
M'U$?I0-2'U(?I0-;'U,?I0-4'U0?I0-='U4?I0-6'U8?I0-?'U<?I0-8'U@?
M6!]9'U$?I0-:'UH?6A];'U,?I0-<'UP?7!]='U4?I0->'UX?7A]?'U<?I0-H
M'V`?J0-I'V$?J0-J'V(?J0-K'V,?J0-L'V0?J0-M'V4?J0-N'V8?J0-O'V<?
MJ0-H'V`?J0-I'V$?J0-J'V(?J0-K'V,?J0-L'V0?J0-M'V4?J0-N'V8?J0-O
M'V<?J0.Z'W`?D0.['W$?NQ_('W(?E0/)'W,?R1_*'W0?EP/+'W4?RQ_:'W8?
MF0/;'W<?VQ_X'W@?GP/Y'WD?^1_J'WH?I0/K'WL?ZQ_Z'WP?J0/['WT?^Q]^
M'WX??A]_'W\??Q^('X`?D0.)'X$?D0.*'X(?D0.+'X,?D0.,'X0?D0.-'X4?
MD0..'X8?D0./'X<?D0.('X`?D0.)'X$?D0.*'X(?D0.+'X,?D0.,'X0?D0.-
M'X4?D0..'X8?D0./'X<?D0.8'Y`?EP.9'Y$?EP.:'Y(?EP.;'Y,?EP.<'Y0?
MEP.='Y4?EP.>'Y8?EP.?'Y<?EP.8'Y`?EP.9'Y$?EP.:'Y(?EP.;'Y,?EP.<
M'Y0?EP.='Y4?EP.>'Y8?EP.?'Y<?EP.H'Z`?J0.I'Z$?J0.J'Z(?J0.K'Z,?
MJ0.L'Z0?J0.M'Z4?J0.N'Z8?J0.O'Z<?J0.H'Z`?J0.I'Z$?J0.J'Z(?J0.K
M'Z,?J0.L'Z0?J0.M'Z4?J0.N'Z8?J0.O'Z<?J0.X'[`?D0.Y'[$?D0.R'[(?
MD0.\'[,?D0.T'[0?D0.U'[4?M1^V'[8?D0.W'[<?D0.X'[`?D0.Y'[$?D0.Z
M'W`?D0.['W$?NQ^\'[,?D0.]'[T?O1^9`[X?F0._'[\?OQ_`'\`?P!_!'\$?
MP1_"'\(?EP/,'\,?EP/$'\0?EP/%'\4?Q1_&'\8?EP/''\<?EP/('W(?E0/)
M'W,?R1_*'W0?EP/+'W4?RQ_,'\,?EP/-'\T?S1_.'\X?SA_/'\\?SQ_8']`?
MF0/9']$?F0/2'](?F0/3'],?TQ_4']0?U!_5']4?U1_6']8?F0/7']<?F0/8
M']`?F0/9']$?F0/:'W8?F0/;'W<?VQ_<']P?W!_=']T?W1_>']X?WA_?']\?
MWQ_H'^`?I0/I'^$?I0/B'^(?I0/C'^,?XQ_D'^0?H0/L'^4?H0/F'^8?I0/G
M'^<?I0/H'^`?I0/I'^$?I0/J'WH?I0/K'WL?ZQ_L'^4?H0/M'^T?[1_N'^X?
M[A_O'^\?[Q_P'_`?\!_Q'_$?\1_R'_(?J0/\'_,?J0/T'_0?J0/U'_4?]1_V
M'_8?J0/W'_<?J0/X'W@?GP/Y'WD?^1_Z'WP?J0/['WT?^Q_\'_,?J0/]'_T?
M_1_^'_X?_A__'_\?_Q\`'@$>00``'@$>00`"'@,>0@`"'@,>0@`$'@4>0@`$
M'@4>0@`&'@<>0@`&'@<>0@`('@D>0P`('@D>0P`*'@L>1``*'@L>1``,'@T>
M1``,'@T>1``.'@\>1``.'@\>1``0'A$>1``0'A$>1``2'A,>1``2'A,>1``4
M'A4>10`4'A4>10`6'A<>10`6'A<>10`8'AD>10`8'AD>10`:'AL>10`:'AL>
M10`<'AT>10`<'AT>10`>'A\>1@`>'A\>1@`@'B$>1P`@'B$>1P`B'B,>2``B
M'B,>2``D'B4>2``D'B4>2``F'B<>2``F'B<>2``H'BD>2``H'BD>2``J'BL>
M2``J'BL>2``L'BT>20`L'BT>20`N'B\>20`N'B\>20`P'C$>2P`P'C$>2P`R
M'C,>2P`R'C,>2P`T'C4>2P`T'C4>2P`V'C<>3``V'C<>3``X'CD>3``X'CD>
M3``Z'CL>3``Z'CL>3``\'CT>3``\'CT>3``^'C\>30`^'C\>30!`'D$>30!`
M'D$>30!"'D,>30!"'D,>30!$'D4>3@!$'D4>3@!&'D<>3@!&'D<>3@!('DD>
M3@!('DD>3@!*'DL>3@!*'DL>3@!,'DT>3P!,'DT>3P!.'D\>3P!.'D\>3P!0
M'E$>3P!0'E$>3P!2'E,>3P!2'E,>3P!4'E4>4`!4'E4>4`!6'E<>4`!6'E<>
M4`!8'ED>4@!8'ED>4@!:'EL>4@!:'EL>4@!<'ET>4@!<'ET>4@!>'E\>4@!>
M'E\>4@!@'F$>4P!@'F$>4P!B'F,>4P!B'F,>4P!D'F4>4P!D'F4>4P!F'F<>
M4P!F'F<>4P!H'FD>4P!H'FD>4P!J'FL>5`!J'FL>5`!L'FT>5`!L'FT>5`!N
M'F\>5`!N'F\>5`!P'G$>5`!P'G$>5`!R'G,>50!R'G,>50!T'G4>50!T'G4>
M50!V'G<>50!V'G<>50!X'GD>50!X'GD>50!Z'GL>50!Z'GL>50!\'GT>5@!\
M'GT>5@!^'G\>5@!^'G\>5@"`'H$>5P"`'H$>5P""'H,>5P""'H,>5P"$'H4>
M5P"$'H4>5P"&'H<>5P"&'H<>5P"('HD>5P"('HD>5P"*'HL>6`"*'HL>6`",
M'HT>6`",'HT>6`".'H\>60".'H\>60"0'I$>6@"0'I$>6@"2'I,>6@"2'I,>
M6@"4'I4>6@"4'I4>6@"6'I8>2`"7'I<>5`"8'I@>5P"9'ID>60":'IH>FAY@
M'IL>4P"<'IP>G!Z='IT>G1Z>'IX>GAZ?'I\>GQZ@'J$>00"@'J$>00"B'J,>
M00"B'J,>00"D'J4>00"D'J4>00"F'J<>00"F'J<>00"H'JD>00"H'JD>00"J
M'JL>00"J'JL>00"L'JT>00"L'JT>00"N'J\>00"N'J\>00"P'K$>00"P'K$>
M00"R'K,>00"R'K,>00"T'K4>00"T'K4>00"V'K<>00"V'K<>00"X'KD>10"X
M'KD>10"Z'KL>10"Z'KL>10"\'KT>10"\'KT>10"^'K\>10"^'K\>10#`'L$>
M10#`'L$>10#"'L,>10#"'L,>10#$'L4>10#$'L4>10#&'L<>10#&'L<>10#(
M'LD>20#('LD>20#*'LL>20#*'LL>20#,'LT>3P#,'LT>3P#.'L\>3P#.'L\>
M3P#0'M$>3P#0'M$>3P#2'M,>3P#2'M,>3P#4'M4>3P#4'M4>3P#6'M<>3P#6
M'M<>3P#8'MD>3P#8'MD>3P#:'ML>3P#:'ML>3P#<'MT>3P#<'MT>3P#>'M\>
M3P#>'M\>3P#@'N$>3P#@'N$>3P#B'N,>3P#B'N,>3P#D'N4>50#D'N4>50#F
M'N<>50#F'N<>50#H'ND>50#H'ND>50#J'NL>50#J'NL>50#L'NT>50#L'NT>
M50#N'N\>50#N'N\>50#P'O$>50#P'O$>50#R'O,>60#R'O,>60#T'O4>60#T
M'O4>60#V'O<>60#V'O<>60#X'OD>60#X'OD>60#Z'OH>^A[['OL>^Q[\'OP>
M_![]'OT>_1[^'OX>_A[_'O\>_QX`!0`%``4!!0$%`04"!0(%`@4#!0,%`P4$
M!00%!`4%!04%!04&!08%!@4'!0<%!P4(!0@%"`4)!0D%"04*!0H%"@4+!0L%
M"P4,!0P%#`4-!0T%#04.!0X%#@4/!0\%#P40!1`%$`41!1$%$042!1(%$@43
M!1,%$P44!10%%`45!14%%046!18%%@47!1<%%P48!1@%&`49!1D%&04:!1H%
M&@4;!1L%&P4<!1P%'`4=!1T%'04>!1X%'@4?!1\%'P4@!2`%(`4A!2$%(04B
M!2(%(@4C!2,%(P4D!20%)`4E!24%)04F!28%)@4G!2<%)P4H!2@%*`4I!2D%
M*04J!2H%*@4K!2L%*P4L!2P%+`4M!2T%+04N!2X%+@4O!2\%+P4P!3`%,`4Q
M!6$%,04R!6(%,@4S!6,%,P4T!60%-`4U!64%-04V!68%-@4W!6<%-P4X!6@%
M.`4Y!6D%.04Z!6H%.@4[!6L%.P4\!6P%/`4]!6T%/04^!6X%/@4_!6\%/P5`
M!7`%0`5!!7$%005"!7(%0@5#!7,%0P5$!70%1`5%!74%105&!78%1@5'!7<%
M1P5(!7@%2`5)!7D%205*!7H%2@5+!7L%2P5,!7P%3`5-!7T%305.!7X%3@5/
M!7\%3P50!8`%4`51!8$%4052!8(%4@53!8,%4P54!80%5`55!84%5056!88%
M5@57!5<%5P58!5@%6`59!5D%605:!5H%6@5;!5L%6P5<!5P%7`5=!5T%705>
M!5X%7@5?!5\%7P5@!6`%8`4Q!6$%,04R!6(%,@4S!6,%,P4T!60%-`4U!64%
M-04V!68%-@4W!6<%-P4X!6@%.`4Y!6D%.04Z!6H%.@4[!6L%.P4\!6P%/`4]
M!6T%/04^!6X%/@4_!6\%/P5`!7`%0`5!!7$%005"!7(%0@5#!7,%0P5$!70%
M1`5%!74%105&!78%1@5'!7<%1P5(!7@%2`5)!7D%205*!7H%2@5+!7L%2P5,
M!7P%3`5-!7T%305.!7X%3@5/!7\%3P50!8`%4`51!8$%4052!8(%4@53!8,%
M4P54!80%5`55!84%5056!88%5@6'!8<%AP6(!8@%B`6)!8D%B06*!8H%B@6+
M!8L%BP6,!8P%C`6-!8T%C06.!8X%C@6/!8\%CP60!9`%D`61!9$%D062!9(%
MD@63!9,%DP64!90%E`65!94%E066!98%E@67!9<%EP68!9@%F`69!9D%F06:
M!9H%F@6;!9L%FP6<!9P%G`6=!9T%G06>!9X%G@6?!9\%GP6@!:`%H`6A!:$%
MH06B!:(%H@6C!:,%HP6D!:0%I`6E!:4%I06F!:8%I@6G!:<%IP6H!:@%J`6I
M!:D%J06J!:H%J@6K!:L%JP6L!:P%K`6M!:T%K06N!:X%K@6O!:\%KP6P!;`%
ML`6Q!;$%L06R!;(%L@6S!;,%LP6T!;0%M`6U!;4%M06V!;8%M@6W!;<%MP6X
M!;@%N`6Y!;D%N06Z!;H%N@6[!;L%NP6\!;P%O`6]!;T%O06^!;X%O@6_!;\%
MOP7`!<`%P`7!!<$%P07"!<(%P@7#!<,%PP7$!<0%Q`7%!<4%Q07&!<8%Q@7'
M!<<%QP7(!<@%R`7)!<D%R07*!<H%R@7+!<L%RP7,!<P%S`7-!<T%S07.!<X%
MS@7/!<\%SP70!=`%T`71!=$%T072!=(%T@73!=,%TP74!=0%U`75!=4%U076
M!=8%U@77!=<%UP78!=@%V`79!=D%V07:!=H%V@7;!=L%VP7<!=P%W`7=!=T%
MW07>!=X%W@7?!=\%WP7@!>`%X`7A!>$%X07B!>(%X@7C!>,%XP7D!>0%Y`7E
M!>4%Y07F!>8%Y@7G!><%YP7H!>@%Z`7I!>D%Z07J!>H%Z@7K!>L%ZP7L!>P%
M[`7M!>T%[07N!>X%[@7O!>\%[P7P!?`%\`7Q!?$%\07R!?(%\@7S!?,%\P7T
M!?0%]`7U!?4%]07V!?8%]@7W!?<%]P7X!?@%^`7Y!?D%^07Z!?H%^@7[!?L%
M^P7\!?P%_`7]!?T%_07^!?X%_@7_!?\%_P4`!%`$%00!!%$$%00"!%($`@0#
M!%,$$P0$!%0$!`0%!%4$!00&!%8$!@0'!%<$!@0(!%@$"`0)!%D$"00*!%H$
M"@0+!%L$"P0,!%P$&@0-!%T$&`0.!%X$(P0/!%\$#P00!#`$$`01!#$$$002
M!#($$@03!#,$$P04!#0$%`05!#4$%006!#8$%@07!#<$%P08!#@$&`09!#D$
M&00:!#H$&@0;!#L$&P0<!#P$'`0=!#T$'00>!#X$'@0?!#\$'P0@!$`$(`0A
M!$$$(00B!$($(@0C!$,$(P0D!$0$)`0E!$4$)00F!$8$)@0G!$<$)P0H!$@$
M*`0I!$D$*00J!$H$*@0K!$L$*P0L!$P$+`0M!$T$+00N!$X$+@0O!$\$+P00
M!#`$$`01!#$$$002!#($$@03!#,$$P04!#0$%`05!#4$%006!#8$%@07!#<$
M%P08!#@$&`09!#D$&00:!#H$&@0;!#L$&P0<!#P$'`0=!#T$'00>!#X$'@0?
M!#\$'P0@!$`$(`0A!$$$(00B!$($(@0C!$,$(P0D!$0$)`0E!$4$)00F!$8$
M)@0G!$<$)P0H!$@$*`0I!$D$*00J!$H$*@0K!$L$*P0L!$P$+`0M!$T$+00N
M!$X$+@0O!$\$+P0`!%`$%00!!%$$%00"!%($`@0#!%,$$P0$!%0$!`0%!%4$
M!00&!%8$!@0'!%<$!@0(!%@$"`0)!%D$"00*!%H$"@0+!%L$"P0,!%P$&@0-
M!%T$&`0.!%X$(P0/!%\$#P1@!&$$8`1@!&$$8`1B!&,$8@1B!&,$8@1D!&4$
M9`1D!&4$9`1F!&<$9@1F!&<$9@1H!&D$:`1H!&D$:`1J!&L$:@1J!&L$:@1L
M!&T$;`1L!&T$;`1N!&\$;@1N!&\$;@1P!'$$<`1P!'$$<`1R!',$<@1R!',$
M<@1T!'4$=`1T!'4$=`1V!'<$=`1V!'<$=`1X!'D$>`1X!'D$>`1Z!'L$>@1Z
M!'L$>@1\!'T$?`1\!'T$?`1^!'\$?@1^!'\$?@2`!($$@`2`!($$@`2"!(($
M@@2#!(,$@P2$!(0$A`2%!(4$A02&!(8$A@2'!(<$AP2(!(@$B`2)!(D$B02*
M!(H$B@2+!(L$BP2,!(T$C`2,!(T$C`2.!(\$C@2.!(\$C@20!)$$D`20!)$$
MD`22!),$D@22!),$D@24!)4$E`24!)4$E`26!)<$E@26!)<$E@28!)D$F`28
M!)D$F`2:!)L$F@2:!)L$F@2<!)T$G`2<!)T$G`2>!)\$G@2>!)\$G@2@!*$$
MH`2@!*$$H`2B!*,$H@2B!*,$H@2D!*4$I`2D!*4$I`2F!*<$I@2F!*<$I@2H
M!*D$J`2H!*D$J`2J!*L$J@2J!*L$J@2L!*T$K`2L!*T$K`2N!*\$K@2N!*\$
MK@2P!+$$L`2P!+$$L`2R!+,$L@2R!+,$L@2T!+4$M`2T!+4$M`2V!+<$M@2V
M!+<$M@2X!+D$N`2X!+D$N`2Z!+L$N@2Z!+L$N@2\!+T$O`2\!+T$O`2^!+\$
MO@2^!+\$O@3`!,`$P`3!!,($%@3!!,($%@3#!,0$PP3#!,0$PP3%!,4$Q03&
M!,8$Q@3'!,@$QP3'!,@$QP3)!,D$R03*!,H$R@3+!,P$RP3+!,P$RP3-!,T$
MS03.!,X$S@3/!,\$SP30!-$$$`30!-$$$`32!-,$$`32!-,$$`34!-4$U`34
M!-4$U`36!-<$%036!-<$%038!-D$V`38!-D$V`3:!-L$V`3:!-L$V`3<!-T$
M%@3<!-T$%@3>!-\$%P3>!-\$%P3@!.$$X`3@!.$$X`3B!.,$&`3B!.,$&`3D
M!.4$&`3D!.4$&`3F!.<$'@3F!.<$'@3H!.D$Z`3H!.D$Z`3J!.L$Z`3J!.L$
MZ`3L!.T$+03L!.T$+03N!.\$(P3N!.\$(P3P!/$$(P3P!/$$(P3R!/,$(P3R
M!/,$(P3T!/4$)P3T!/4$)P3V!/8$]@3W!/<$]P3X!/D$*P3X!/D$*P3Z!/H$
M^@3[!/L$^P3\!/P$_`3]!/T$_03^!/X$_@3_!/\$_P0``P`#``,!`P$#`0,"
M`P(#`@,#`P,#`P,$`P0#!`,%`P4#!0,&`P8#!@,'`P<#!P,(`P@#"`,)`PD#
M"0,*`PH#"@,+`PL#"P,,`PP##`,-`PT##0,.`PX##@,/`P\##P,0`Q`#$`,1
M`Q$#$0,2`Q(#$@,3`Q,#$P,4`Q0#%`,5`Q4#%0,6`Q8#%@,7`Q<#%P,8`Q@#
M&`,9`QD#&0,:`QH#&@,;`QL#&P,<`QP#'`,=`QT#'0,>`QX#'@,?`Q\#'P,@
M`R`#(`,A`R$#(0,B`R(#(@,C`R,#(P,D`R0#)`,E`R4#)0,F`R8#)@,G`R<#
M)P,H`R@#*`,I`RD#*0,J`RH#*@,K`RL#*P,L`RP#+`,M`RT#+0,N`RX#+@,O
M`R\#+P,P`S`#,`,Q`S$#,0,R`S(#,@,S`S,#,P,T`S0#-`,U`S4#-0,V`S8#
M-@,W`S<#-P,X`S@#.`,Y`SD#.0,Z`SH#.@,[`SL#.P,\`SP#/`,]`ST#/0,^
M`SX#/@,_`S\#/P-``T`#0`-!`T$#00-"`T(#0@-#`T,#0P-$`T0#1`.9`T4#
MF0-&`T8#1@-'`T<#1P-(`T@#2`-)`TD#20-*`TH#2@-+`TL#2P-,`TP#3`--
M`TT#30-.`TX#3@-/`T\#3P-0`U`#4`-1`U$#40-2`U(#4@-3`U,#4P-4`U0#
M5`-5`U4#50-6`U8#5@-7`U<#5P-8`U@#6`-9`UD#60-:`UH#6@-;`UL#6P-<
M`UP#7`-=`UT#70->`UX#7@-?`U\#7P-@`V`#8`-A`V$#80-B`V(#8@-C`V,#
M8P-D`V0#9`-E`V4#90-F`V8#9@-G`V<#9P-H`V@#:`-I`VD#:0-J`VH#:@-K
M`VL#:P-L`VP#;`-M`VT#;0-N`VX#;@-O`V\#;P-P`W`#<`-Q`W$#<0-R`W(#
M<@-S`W,#<P-T`W0#=`-U`W4#=0-V`W8#=@-W`W<#=P-X`W@#>`-Y`WD#>0-Z
M`WH#>@-[`WL#>P-\`WP#?`-]`WT#?0-^`WX#?@-_`W\#?P.``X`#@`.!`X$#
M@0."`X(#@@.#`X,#@P.$`X0#A`.%`X4#A0.&`ZP#D0.'`X<#AP.(`ZT#E0.)
M`ZX#EP.*`Z\#F0.+`XL#BP.,`\P#GP.-`XT#C0..`\T#I0./`\X#J0.0`Y`#
MF0.1`[$#D0.2`[(#D@.3`[,#DP.4`[0#E`.5`[4#E0.6`[8#E@.7`[<#EP.8
M`[@#F`.9`[D#F0.:`[H#F@.;`[L#FP.<`[P#G`.=`[T#G0.>`[X#G@.?`[\#
MGP.@`\`#H`.A`\$#H0.B`Z(#H@.C`\,#HP.D`\0#I`.E`\4#I0.F`\8#I@.G
M`\<#IP.H`\@#J`.I`\D#J0.J`\H#F0.K`\L#I0.&`ZP#D0.(`ZT#E0.)`ZX#
MEP.*`Z\#F0.P`[`#I0.1`[$#D0.2`[(#D@.3`[,#DP.4`[0#E`.5`[4#E0.6
M`[8#E@.7`[<#EP.8`[@#F`.9`[D#F0.:`[H#F@.;`[L#FP.<`[P#G`.=`[T#
MG0.>`[X#G@.?`[\#GP.@`\`#H`.A`\$#H0.C`\(#HP.C`\,#HP.D`\0#I`.E
M`\4#I0.F`\8#I@.G`\<#IP.H`\@#J`.I`\D#J0.J`\H#F0.K`\L#I0.,`\P#
MGP..`\T#I0./`\X#J0//`\\#SP.2`]`#D@.8`]$#F`/2`](#T@/3`],#T@/4
M`]0#T@.F`]4#I@.@`]8#H`/7`]<#UP/8`]@#V`/9`]D#V0/:`]L#V@/:`]L#
MV@/<`]T#W`/<`]T#W`/>`]\#W@/>`]\#W@/@`^$#X`/@`^$#X`/B`^,#X@/B
M`^,#X@/D`^4#Y`/D`^4#Y`/F`^<#Y@/F`^<#Y@/H`^D#Z`/H`^D#Z`/J`^L#
MZ@/J`^L#Z@/L`^T#[`/L`^T#[`/N`^\#[@/N`^\#[@.:`_`#F@.A`_$#H0.C
M`_(#HP/S`_,#\P/T`_0#]`/U`_4#]0/V`_8#]@/W`_<#]P/X`_@#^`/Y`_D#
M^0/Z`_H#^@/[`_L#^P/\`_P#_`/]`_T#_0/^`_X#_@/_`_\#_P,``@$"00``
M`@$"00`"`@,"00`"`@,"00`$`@4"10`$`@4"10`&`@<"10`&`@<"10`(`@D"
M20`(`@D"20`*`@L"20`*`@L"20`,`@T"3P`,`@T"3P`.`@\"3P`.`@\"3P`0
M`A$"4@`0`A$"4@`2`A,"4@`2`A,"4@`4`A4"50`4`A4"50`6`A<"50`6`A<"
M50`8`AD"4P`8`AD"4P`:`AL"5``:`AL"5``<`AT"'`(<`AT"'`(>`A\"2``>
M`A\"2``@`B`"(`(A`B$"(0(B`B,"(@(B`B,"(@(D`B4")`(D`B4")`(F`B<"
M00`F`B<"00`H`BD"10`H`BD"10`J`BL"3P`J`BL"3P`L`BT"3P`L`BT"3P`N
M`B\"3P`N`B\"3P`P`C$"3P`P`C$"3P`R`C,"60`R`C,"60`T`C0"-`(U`C4"
M-0(V`C8"-@(W`C<"-P(X`C@".`(Y`CD".0(Z`CH".@([`CL".P(\`CP"/`(]
M`CT"/0(^`CX"/@(_`C\"/P)``D`"0`)!`D$"00)"`D("0@)#`D,"0P)$`D0"
M1`)%`D4"10)&`D8"1@)'`D<"1P)(`D@"2`))`DD"20)*`DH"2@)+`DL"2P),
M`DP"3`)-`DT"30).`DX"3@)/`D\"3P)0`E`"4`)1`E$"40)2`E("4@*!`5,"
M@0&&`50"A@%5`E4"50*)`58"B0&*`5<"B@%8`E@"6`*/`5D"CP%:`EH"6@*0
M`5L"D`%<`EP"7`)=`ET"70)>`EX"7@)?`E\"7P*3`6`"DP%A`F$"80)B`F("
M8@*4`6,"E`%D`F0"9`)E`F4"90)F`F8"9@)G`F<"9P*7`6@"EP&6`6D"E@%J
M`FH":@)K`FL":P)L`FP";`)M`FT";0)N`FX";@*<`6\"G`%P`G`"<`)Q`G$"
M<0*=`7("G0%S`G,"<P)T`G0"=`*?`74"GP%V`G8"=@)W`G<"=P)X`G@">`)Y
M`GD">0)Z`GH">@)[`GL">P)\`GP"?`)]`GT"?0)^`GX"?@)_`G\"?P*F`8`"
MI@&!`H$"@0*"`H("@@*I`8,"J0&$`H0"A`*%`H4"A0*&`H8"A@*'`H<"AP*N
M`8@"K@&)`HD"B0*Q`8H"L0&R`8L"L@&,`HP"C`*-`HT"C0*.`HX"C@*/`H\"
MCP*0`I`"D`*1`I$"D0*W`9("MP&3`I,"DP*4`I0"E`*5`I4"E0*6`I8"E@*7
M`I<"EP*8`I@"F`*9`ID"F0*:`IH"F@*;`IL"FP*<`IP"G`*=`IT"G0*>`IX"
MG@*?`I\"GP*@`J`"H`*A`J$"H0*B`J("H@*C`J,"HP*D`J0"I`*E`J4"I0*F
M`J8"I@*G`J<"IP*H`J@"J`*I`JD"J0*J`JH"J@*K`JL"JP*L`JP"K`*M`JT"
MK0*N`JX"K@*O`J\"KP*P`K`"L`*Q`K$"L0*R`K("L@*S`K,"LP*T`K0"M`*U
M`K4"M0*V`K8"M@*W`K<"MP*X`K@"N`*Y`KD"N0*Z`KH"N@*[`KL"NP*\`KP"
MO`*]`KT"O0*^`KX"O@*_`K\"OP+``L`"P`+!`L$"P0+"`L("P@+#`L,"PP+$
M`L0"Q`+%`L4"Q0+&`L8"Q@+'`L<"QP+(`L@"R`+)`LD"R0+*`LH"R@++`LL"
MRP+,`LP"S`+-`LT"S0+.`LX"S@+/`L\"SP+0`M`"T`+1`M$"T0+2`M("T@+3
M`M,"TP+4`M0"U`+5`M4"U0+6`M8"U@+7`M<"UP+8`M@"V`+9`MD"V0+:`MH"
MV@+;`ML"VP+<`MP"W`+=`MT"W0+>`MX"W@+?`M\"WP+@`N`"X`+A`N$"X0+B
M`N("X@+C`N,"XP+D`N0"Y`+E`N4"Y0+F`N8"Y@+G`N<"YP+H`N@"Z`+I`ND"
MZ0+J`NH"Z@+K`NL"ZP+L`NP"[`+M`NT"[0+N`NX"[@+O`N\"[P+P`O`"\`+Q
M`O$"\0+R`O("\@+S`O,"\P+T`O0"]`+U`O4"]0+V`O8"]@+W`O<"]P+X`O@"
M^`+Y`OD"^0+Z`OH"^@+[`OL"^P+\`OP"_`+]`OT"_0+^`OX"_@+_`O\"_P(`
M`0$!00```0$!00`"`0,!00`"`0,!00`$`04!00`$`04!00`&`0<!0P`&`0<!
M0P`(`0D!0P`(`0D!0P`*`0L!0P`*`0L!0P`,`0T!0P`,`0T!0P`.`0\!1``.
M`0\!1``0`1$!$`$0`1$!$`$2`1,!10`2`1,!10`4`14!10`4`14!10`6`1<!
M10`6`1<!10`8`1D!10`8`1D!10`:`1L!10`:`1L!10`<`1T!1P`<`1T!1P`>
M`1\!1P`>`1\!1P`@`2$!1P`@`2$!1P`B`2,!1P`B`2,!1P`D`24!2``D`24!
M2``F`2<!)@$F`2<!)@$H`2D!20`H`2D!20`J`2L!20`J`2L!20`L`2T!20`L
M`2T!20`N`2\!20`N`2\!20`P`6D`20!)`#$!20`R`3,!,@$R`3,!,@$T`34!
M2@`T`34!2@`V`3<!2P`V`3<!2P`X`3@!.`$Y`3H!3``Y`3H!3``[`3P!3``[
M`3P!3``]`3X!3``]`3X!3``_`4`!/P$_`4`!/P%!`4(!00%!`4(!00%#`40!
M3@!#`40!3@!%`48!3@!%`48!3@!'`4@!3@!'`4@!3@!)`4D!20%*`4L!2@%*
M`4L!2@%,`4T!3P!,`4T!3P!.`4\!3P!.`4\!3P!0`5$!3P!0`5$!3P!2`5,!
M4@%2`5,!4@%4`54!4@!4`54!4@!6`5<!4@!6`5<!4@!8`5D!4@!8`5D!4@!:
M`5L!4P!:`5L!4P!<`5T!4P!<`5T!4P!>`5\!4P!>`5\!4P!@`6$!4P!@`6$!
M4P!B`6,!5`!B`6,!5`!D`64!5`!D`64!5`!F`6<!9@%F`6<!9@%H`6D!50!H
M`6D!50!J`6L!50!J`6L!50!L`6T!50!L`6T!50!N`6\!50!N`6\!50!P`7$!
M50!P`7$!50!R`7,!50!R`7,!50!T`74!5P!T`74!5P!V`7<!60!V`7<!60!X
M`?\`60!Y`7H!6@!Y`7H!6@![`7P!6@![`7P!6@!]`7X!6@!]`7X!6@!3`'\!
M4P"``8`!@`&!`5,"@0&"`8,!@@&"`8,!@@&$`84!A`&$`84!A`&&`50"A@&'
M`8@!AP&'`8@!AP&)`58"B0&*`5<"B@&+`8P!BP&+`8P!BP&-`8T!C0&.`=T!
MC@&/`5D"CP&0`5L"D`&1`9(!D0&1`9(!D0&3`6`"DP&4`6,"E`'V`94!]@&6
M`6D"E@&7`6@"EP&8`9D!F`&8`9D!F`&:`9H!F@&;`9L!FP&<`6\"G`&=`7("
MG0&>`9X!G@&?`74"GP&@`:$!3P"@`:$!3P"B`:,!H@&B`:,!H@&D`:4!I`&D
M`:4!I`&F`8`"I@&G`:@!IP&G`:@!IP&I`8,"J0&J`:H!J@&K`:L!JP&L`:T!
MK`&L`:T!K`&N`8@"K@&O`;`!50"O`;`!50"Q`8H"L0&R`8L"L@&S`;0!LP&S
M`;0!LP&U`;8!M0&U`;8!M0&W`9("MP&X`;D!N`&X`;D!N`&Z`;H!N@&[`;L!
MNP&\`;T!O`&\`;T!O`&^`;X!O@'W`;\!]P'``<`!P`'!`<$!P0'"`<(!P@'#
M`<,!PP'$`<8!Q`'$`<8!Q`'$`<8!Q`''`<D!QP''`<D!QP''`<D!QP'*`<P!
MR@'*`<P!R@'*`<P!R@'-`<X!00#-`<X!00#/`=`!20#/`=`!20#1`=(!3P#1
M`=(!3P#3`=0!50#3`=0!50#5`=8!50#5`=8!50#7`=@!50#7`=@!50#9`=H!
M50#9`=H!50#;`=P!50#;`=P!50".`=T!C@'>`=\!00#>`=\!00#@`>$!00#@
M`>$!00#B`>,!Q@#B`>,!Q@#D`>4!Y`'D`>4!Y`'F`><!1P#F`><!1P#H`>D!
M2P#H`>D!2P#J`>L!3P#J`>L!3P#L`>T!3P#L`>T!3P#N`>\!MP'N`>\!MP'P
M`?`!2@#Q`?,!\0'Q`?,!\0'Q`?,!\0'T`?4!1P#T`?4!1P#V`94!]@'W`;\!
M]P'X`?D!3@#X`?D!3@#Z`?L!00#Z`?L!00#\`?T!Q@#\`?T!Q@#^`?\!V`#^
M`?\!V``````````!``$``0`"``(``@`#``,``P`$``0`!``%``4`!0`&``8`
M!@`'``<`!P`(``@`"``)``D`"0`*``H`"@`+``L`"P`,``P`#``-``T`#0`.
M``X`#@`/``\`#P`0`!``$``1`!$`$0`2`!(`$@`3`!,`$P`4`!0`%``5`!4`
M%0`6`!8`%@`7`!<`%P`8`!@`&``9`!D`&0`:`!H`&@`;`!L`&P`<`!P`'``=
M`!T`'0`>`!X`'@`?`!\`'P`@`"``(``A`"$`(0`B`"(`(@`C`",`(P`D`"0`
M)``E`"4`)0`F`"8`)@`G`"<`)P`H`"@`*``I`"D`*0`J`"H`*@`K`"L`*P`L
M`"P`+``M`"T`+0`N`"X`+@`O`"\`+P`P`#``,``Q`#$`,0`R`#(`,@`S`#,`
M,P`T`#0`-``U`#4`-0`V`#8`-@`W`#<`-P`X`#@`.``Y`#D`.0`Z`#H`.@`[
M`#L`.P`\`#P`/``]`#T`/0`^`#X`/@`_`#\`/P!``$``0`!!`&$`00!"`&(`
M0@!#`&,`0P!$`&0`1`!%`&4`10!&`&8`1@!'`&<`1P!(`&@`2`!)`&D`20!*
M`&H`2@!+`&L`2P!,`&P`3`!-`&T`30!.`&X`3@!/`&\`3P!0`'``4`!1`'$`
M40!2`'(`4@!3`',`4P!4`'0`5`!5`'4`50!6`'8`5@!7`'<`5P!8`'@`6`!9
M`'D`60!:`'H`6@!;`%L`6P!<`%P`7`!=`%T`70!>`%X`7@!?`%\`7P!@`&``
M8`!!`&$`00!"`&(`0@!#`&,`0P!$`&0`1`!%`&4`10!&`&8`1@!'`&<`1P!(
M`&@`2`!)`&D`20!*`&H`2@!+`&L`2P!,`&P`3`!-`&T`30!.`&X`3@!/`&\`
M3P!0`'``4`!1`'$`40!2`'(`4@!3`',`4P!4`'0`5`!5`'4`50!6`'8`5@!7
M`'<`5P!8`'@`6`!9`'D`60!:`'H`6@![`'L`>P!\`'P`?`!]`'T`?0!^`'X`
M?@!_`'\`?P"``(``@`"!`($`@0""`((`@@"#`(,`@P"$`(0`A`"%`(4`A0"&
M`(8`A@"'`(<`AP"(`(@`B`")`(D`B0"*`(H`B@"+`(L`BP",`(P`C`"-`(T`
MC0".`(X`C@"/`(\`CP"0`)``D`"1`)$`D0"2`)(`D@"3`),`DP"4`)0`E`"5
M`)4`E0"6`)8`E@"7`)<`EP"8`)@`F`"9`)D`F0":`)H`F@";`)L`FP"<`)P`
MG`"=`)T`G0">`)X`G@"?`)\`GP"@`*``H`"A`*$`H0"B`*(`H@"C`*,`HP"D
M`*0`I`"E`*4`I0"F`*8`I@"G`*<`IP"H`*@`J`"I`*D`J0"J`*H`J@"K`*L`
MJP"L`*P`K`"M`*T`K0"N`*X`K@"O`*\`KP"P`+``L`"Q`+$`L0"R`+(`L@"S
M`+,`LP"T`+0`M`"<`[4`G`.V`+8`M@"W`+<`MP"X`+@`N`"Y`+D`N0"Z`+H`
MN@"[`+L`NP"\`+P`O`"]`+T`O0"^`+X`O@"_`+\`OP#``.``00#!`.$`00#"
M`.(`00##`.,`00#$`.0`00#%`.4`00#&`.8`Q@#'`.<`0P#(`.@`10#)`.D`
M10#*`.H`10#+`.L`10#,`.P`20#-`.T`20#.`.X`20#/`.\`20#0`/``T`#1
M`/$`3@#2`/(`3P#3`/,`3P#4`/0`3P#5`/4`3P#6`/8`3P#7`-<`UP#8`/@`
MV`#9`/D`50#:`/H`50#;`/L`50#<`/P`50#=`/T`60#>`/X`W@#?`-\`WP#`
M`.``00#!`.$`00#"`.(`00##`.,`00#$`.0`00#%`.4`00#&`.8`Q@#'`.<`
M0P#(`.@`10#)`.D`10#*`.H`10#+`.L`10#,`.P`20#-`.T`20#.`.X`20#/
M`.\`20#0`/``T`#1`/$`3@#2`/(`3P#3`/,`3P#4`/0`3P#5`/4`3P#6`/8`
M3P#W`/<`]P#8`/@`V`#9`/D`50#:`/H`50#;`/L`50#<`/P`50#=`/T`60#>
M`/X`W@!X`?\`60``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!:``````````````"1````:K48"/J]&`CTFQ@(
M``````#G'`@`YAP(`.4<"``````````````````````````````````````!
M`````@````(``````/__P.@<",#D'`@`````A-,'"#S4!P@0U@<(](`'"%S3
M!PCLU`<(8%T("'#6!P@```````````````````````````````````````$"
M`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO
M,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<
M75Y?8$%"0T1%1D=(24I+3$U.3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)
MBHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6V
MM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+C
MY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`!`@,$!08'"`D*"PP-#@\0
M$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]
M/C]`86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I;7%U>7V!A8F-D969G:&EJ
M:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7
MF)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$
MQ<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q
M\O/T]?;W^/GZ^_S]_O\`("`@("`@("`@*"@H*"@@("`@("`@("`@("`@("`@
M("!($!`0$!`0$!`0$!`0$!`0A(2$A(2$A(2$A!`0$!`0$!"!@8&!@8$!`0$!
M`0$!`0$!`0$!`0$!`0$!`1`0$!`0$(*"@H*"@@("`@("`@("`@("`@("`@("
M`@("$!`0$"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````C``````````````#A
M````:K48"`.^&`CTFQ@(``````#G'`@`YAP(`.4<"`#E'`@`````````````
M```````````````````!`````@````(``````/__P.@<"(#H'`@`````U+T'
M".B^!P@@P0<(O-8'"##3!PC\OP<(8%T("+"\!P@`````````````````````
M`````````````````````,S!!PC8P0<(G-('"+#2!PB\T@<(_-('""QE"`CD
MNP<(%+P'"%"]!PC,O0<(0+P'"%B]!PCDP0<(9,P'"$C-!PC8T@<(+,,'"`S%
M!PC0Q@<(:,D'",S+!PB`S@<(4-@'"```````````````````````````````
M```````!````"@```&0```#H`P``$"<``*"&`0!`0@\`@):8``#A]04`````
M````````````````````````````````5@``````````````$0```!.^&`@:
MOA@(])L8"`````!@[!P(8.L<"&#J'`@`````````````````````````````
M`````````0````$````"``````#_`.#I'`B`*B4(`````(C8!PBXV`<(<%P(
M"+A<"`@<70@(@(('"%B"!P@LV@<(S-@'",Q6"`@H5P@(A%<("-17"`C,=0<(
M?'T'"$Q^!P@T@@<(4'8'"-!W!P@H>0<(5'L'"#1]!PCTA0<(S($'"```````
M`````````````````````````````````0(#!`4&!P@)"@L,#0X/$!$2$Q05
M%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"
M0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@04)#1$5&1TA)2DM,34Y/
M4%%24U155E=865I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<
MG9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)
MRLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V
M]_CY^OO\_?[_``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C
M)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!A8F-D969G:&EJ:VQM;F]P
M<7)S='5V=WAY>EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]
M?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJ
MJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7
MV-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`@("`@
M("`@("`H*"@H*"`@("`@("`@("`@("`@("`@($@0$!`0$!`0$!`0$!`0$!"$
MA(2$A(2$A(2$$!`0$!`0$(&!@8&!@0$!`0$!`0$!`0$!`0$!`0$!`0$!$!`0
M$!`0@H*"@H*"`@("`@("`@("`@("`@("`@("`@(0$!`0(```````````````
M``````````````````````````````,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,`````````````````````````
M`````````````````!@``````````````"$````3OA@();X8"/2;&`@`````
M8.P<"&#K'`A@ZAP((.X<"`````````````````````````````````$````!
M`````@``````_P#@Z1P(X.T<"``````D<P<(F','"*1R!PCT@`<(R%@(""18
M"`A@70@(Z'4'"````````````````````````````````````````0(#!`4&
M!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S
M-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:7%U;7E]@
M04)#1$5&1TA)2DM,34Y/4%%24U155E=865I[?'U9?X"!@H.$A8:'B(F*BXR-
MCH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZ
MN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;G
MZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_(2,B(R,C9R$E(R8C)R,H(RDC*B,K
M(RPC+2,N(R\C,",Q(S(C,R,T(S4C-B,W(S@C.2,Z(SLC/",](SXC/R-`(T$C
M0B-#(T0C12-&(T<C2"-)(THC2R-,(TTC3B-/(U`C42-2(U,C5"-5(U8C5R-8
M(UDC6B-;(UPC72->(U\C8"-A(V(C8R-D(V4C9B-G(V@C:2-J(VLC;"-M(VXC
M;R-P(W$C<B-S(W0C=2-V(W<C>"-Y(WHC>R-\(WTC*R$`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!I(6HA``!^(P``)",`````````````````
M````````````<40O<"8\,'!Y0P``.$4[40``,7`R<#-P-'`U<#Q1``!L40``
M-W`V<"=4``!233AP.G`Y<#MP/'``````:S@]<&@Z```^<#]P:3Y`<&PV07!"
M<$-P1'`U2$5P1G```$=P=$4``$AP````````27```$IP/7<``$MP3'!-<```
M3G```````````$]P5SH``%!P47!2<%-P5'!5<%9P6'``````)5-7<```67``
M`````````````````````````#IU.4(`````9'<``````````&5W9G<`````
M9W<```````````````!H=S1"````````````````````````:G<``&MW````
M````````````<T(``````````````````````````````````'!T````````
M;W0`````:4(``&%W8G<`````````````1CL``````````&19````````<DIH
M0"1P``!:.@`````M1P```````"Q$`````&QW;7=N=P``<'=O=P``<7<`````
M='<``'-W``!R=W5W``````````!V=P```````````````````````&EM``!J
M;6MM```\=@```````````````````````````````#UV```^=B8V```^6```
M``!$.0```````#M8```Q7````````````````'-*``!W=P``````````````
M`````````'AW`````'EW``````````````````![=P``>G<``$<Q``!\=WUW
M`````````````'YW`````````````````````````````&M&-&P`````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!=,S-V````
M`#1V9$$U=C9V-W8X=CEV.G8C2#MV````````````````````````````````
M>D$H.6AM````````:CE?60````````````````````````````````````!C
M4P````!/=@``,T)0=@````!1=E)V4W94=@````!6=@``*S%7=@``6'99=EIV
M``!;=EQV``````````!==EYV2D\``%]V8'9A=F)V8W9D=G!`979F=F=V:'9I
M=@``:G8``&MV;'8``&UV;G9O=G!V<79R=G-V='8H/@``=79V=G=V>'8`````
M````````>DAY=GIV>W9\=@````!]=GYV(7<B=R-W)'<E=P`````F=R=W*'=N
M,2EW*G<K=P`````L=RUW6T$N=P`````O=P```````````````````````#M2
M(38``%]&````````<DU)57U(3TE"3R)8.S)K4P``)%AS,P``*%=21R=80$H`
M`'!'>S$U4E0T*S8_2RE8````````*C8``#U!3U$``"5)+5@``'8X/E%<8U!6
M`````&$W```N-```64$``#Q8``!H320U*DYW5@``=D!9/B]8````````2T0`
M`$,^```Q6#1#95(``"Y66DXG574Z)C=60```.49214='``!4.0``2S-24@``
M```_6$4^<D8R4C!/9T\``````````&E*`````$!8````````````````<D)2
M0@``:4@``````````````````````````"Q'``````````````````!+00``
M:%-Y50``0DI^-B%86E-W/P``1E0E.T%894XN/@`````H6```1U$I4```````
M`#U8;UEV33H_```[/24Z8%)Z,F`Z-D0``&U/*3XD34%!````````5T=Q60``
M=%D``````````$M(:5@```````!:4C)*2DAL6&I81EAV/4U&<#,``&M8<3UI
M/0``5$A3-`````!80@``5C)05TM*>TM,538X24\```````!:67!8*D<``&Y8
M``!Z-&Y!5%(`````;5@``$=2;UA'0P```````'91``!95G)8``!U6'X\6SP`
M``````!.2```73<``$(W``!S1@``````````````````>%A!4@````!I3C\\
M?#<E-UU0`````````````%I615-O.V$[<5@`````(4DP3BLT``!S6```2TEV
M6%="=U@`````,4YY6````````"XR0#D``"-9``!I,```9D$``&Q)``!%2P``
M1DLD60````````````!H-0`````K-0```````````````#M.334A5W174U,`
M`&5,``!..@``(EE<66!3?5AP-W=7?EAZ6"%98T0`````-E-T6%U9``![6```
M944`````4$``````<%%;,`````!1/"99```E60``````````+%DN60``*UDY
M2@```````"E9-E8```````!>,RA9``!]0```3$H``"I9```G60`````P60``
M```Q-@```````"DY``!`4@````!`3P````!"0@``1#UL56`R2$=K/RU9```O
M60``:DYN.@````````````!61P```````````````````````&,Q````````
M631M-C19```````````A/P```````%Y93D=^0#A9`````````````%=+?3<`
M`#59```W62,Q85,Y60``15```#99`````#%9```R62E!,UD`````<SQ>4"DX
M``!C/@``/5D``````````#I9```S,````````$)9````````````````````
M``````````````!$638Q```_60`````Y-0``<SX```````!(3'(Z4%(``$-9
M`````&@]```K,P```````$59:SX``$99.UE?1```/EE!64!9````````````
M`````````````````"Y5```U5@``8T<``````````$A9````````63Q*60``
M`````#Q9``!+62M&`````````````$E9``````````!V5P``(TT`````````
M````````````(3T```````````````!,60```````````````````````#Q%
M-4T```````!-60````!'624S?C\``````````#4X`````'Q```````````!X
M,````````````````````````````````````````````````````````'8T
M``!.60``3UDB-%!9`````%\T`````````````$$P``````````````````!1
M635)``````````````````````````````````````````````````!Q3P``
M`````````````%)9````````14$`````````````````````````````5EDN
M20``````````55E465=9``````````!;2P``*3T`````````````)T8`````
M`````````````````````%-96%D```````!960```````````````&5(````
M`````````````````````````````````%Q`````````````````````````
M`````````````````````````````````````````````````````'DV(UA*
M5```*E164&0S5U4``$A/8CD``$L_``!B0P```````%(V`````$--;EEP60``
M`````#,U```U-@`````````````D/@````!K2``````K2`````!+,"LY>4%B
M60``/$`R.0``6#E+4'@Q9$9?/F0U2%<``'A19CQ>2@`````]/&999U@`````
M6D0`````5#@]2`````!A,EE4```````````P0P````!A0R):7T@``#10``!\
M/BE%````````6CD``"-:```I5"1:`````````````'M9+#8`````:S=Y,7Q9
M93-V/@``=C\Q4F1`````````,S9^67U9`````#L^````````8$8``#Q7(5H`
M`#E!``!R-6A!`````'4\``!5-````````````````````````%U!``!]1```
M```X/#(W`````&\W````````````````;%D``#Y&```M/TL[`````$HU``!)
M6U=0```Y33PP=C-W.TI;+SH``&14-C5S-5984$@`````5C=01U=8```O/P``
M```[6UA8`````$Q0+CL````````^:U!!=4%R5%4X-#0``'4S`````#Y)````
M````4$4```````!917M```!P,0``65A..0``/34`````6E@`````1E8B2R](
M,DE,-$P_``!T.0``6UA<6&<V03QJ3````````````````'=/``!=6#!'````
M`%`Y(ST`````7DP``$I&`````````````&!8``!>6`````!?6````````'XP
M``!G/@``(TIT/```````````,3@`````;C@`````````````````````````
M`&)8``!+/0``9%AC6`````````````!\10``````````````````95@`````
M9E@``````````````````"9!```P2&PP)CE3/'%./5M300``````````+S9Z
M5BQ%63T^6S];````````>$`B/DU```````````````````````````!`6T9*
M````````*C(```````!"4P``8T,``"M1``````````!"6P``54````````!#
M6P``,3\````````````````\1```````````6D<`````````````````````
M````````1%L`````````````````````:%E720```````#0Y<$Y(5```````
M````?#!2-```65```````````&E9``!+7FM9```````````P6"\[,3$``%<S
M3E@`````450`````,SUO/P``.T\`````4%@```````!+-P```````%%8````
M```````````````````````E1GA'/5(`````4EAD1```+DH``"='```F6```
M?4EG3EP[:S`````````J.RU0```P,617/U<``"4U=$)/1``````I,@``-S(`
M`&4Q,E\\52@_+$)56#%"``!46%1.``!@6@``0$X`````-%@N0R%3(TX``#0\
M-$A10@``;3XV4```85H``````````&1'`````"<S``!R-GQ,>D``````=T``
M`#E185%'6```````````````````7C(`````94```'$Z`````$A8```M5```
M``!A3TE8``!*6$-/``!X,T<^``````````!+6```````````````````3%L`
M`````````"5(````````6$\``'Y(3C(`````````````5E-F,C`\45,K2S0W
M````````(C<`````94H``"%(7$ID,7!0``!110```````$5;?C4`````6C]%
M.60^;4$``#9?-5\[5E`]655(,",V23\H3#-?-TI24P``3U@V4D4Z/DL^3```
M-U]P-31?````````=5,``%0S=S@``#I?``!/.BH\=34``"Q->T-S.G1`0DUR
M3SA?14\``$!".5]P0@```````'T^``!?04Q-=U)--T%?``!$7P````!Q-TDP
M5C94-P``+#I]3%0_,4MT1@``*%9%7P``8DXS,P````!\3C4T``!'3G`Z``!A
M3@``/5$`````0%\`````=#0``$HS``!F.#M?``````````!%1```/%\]7SY?
M.T4_7T)?,51#7P``.D=83@````````````!81```2E\``$]?``!<5@``````
M``````````````!)7UI?-DX``$<Z3E](7UY%`````&M)=#I\0P````!7/@``
M1E\``$U?``!810``````````)E5-.@``3#X]4T`X``!D5@``1U\^.2<_````
M`'Q!2U],7P``4%\`````````````6U]E7P``5U]67TE78U]D7VME)U)27P``
M*3\``%M4``!(/U1?````````3$\`````75\``$I1``!>7R<P-T937P``93H`
M`%\V6TU^.554`````%]?;$\E,&=?45]&455?6%]97UQ?```I.P``8%]A7P``
M8E]F7VA?-%,`````````````9S@V16I?6DDH041$`````%X_>$\```````!<
M56Y?````````````````.#(``%\Z;%\``$%;``!D40``````````=$L]-```
M)C``````````````<5]&3')?`````&U?````````````````:5\`````````
M`&M?``!O7W!?/3L`````<U\`````=%\``",[``!;2BA.)V`J,P``)F``````
M```A8```````````?E\``%E-?%\``'I?``!0/T17``!,20````!X7R$P````
M`````````'U?``````````![7R)@`````````````"A@``````````!(-P``
M```A1C9),D!U7P`````^10``1%AY7W9$````````````````(V`D8"5@)5``
M````-&!D3```,6```"8_+V`Y3BM@1DD`````+D`N8&TZ,#HI8````````'9?
M```S8``````X8````````"TT.6``````,D](.@``,&``````````````````
M`'I0````````````````````````+&```'M4``!W7P``9T4``"U@``!W4P``
M-F`W8`````````````!$8&%0````````/&``````26!*8````````#Y@*F`D
M24%@```R8`````````````!(2D-@```U8```2TX``$-+36!&8$)@``!+8```
M.F`_8$!@`````$5@`````$=@2&```$Q@```[8`````````````!42U5@``!6
M8%)@````````````````4&!./`````!18```0CA%6```````````````````
M``!J4`````!O0@````!/8#U@````````5&!38`````!78```````````7&!8
M8````````'96,#,``&Q7```[2P````!:8```>TX```````!9.@``````````
M`````````````````````&%@76`M4@````````````!B8`````!;8%E@7V``
M````8&``````````````7F```&1@````````=T8L6&M49F!)2@``````````
M96```````````$$X``````````!G8&A@`````````````````````&E@8V``
M`````````````````#\Z9TP```````!J8```````````````````````````
M`````````````'E/`````````````````````````````&M@````````````
M``````!"2```````````0#T``````````````````````````````````%)$
M````````````````````````;&``````;6``````=$=$2P``;F!8.S98<E)O
M8$5-``!:-@```````````````'%@```P5``````G0%$T`````"=.<&``````
M``!R8$PY`````'HY/$US8````````%1&=&```#)4```F2'9@=6``````````
M````````````````````````````````````=V``````04T````````E2@``
M````````6E176UE;``!86V<Y7%M=6U@U`````%I;`````````````%M;(3-?
M6P````!X.P``-U8``&!;``````````!Y/@`````[-P``4%LN3#(_-3MX5U,_
M`````````````&D_`````&$\,TQ>6U,P:TY8-SE70D8`````)$```#E,``!G
M6V%;.D9C6P``:%L``'=%````````:EL`````:5M`/P```````&9;95L`````
M````````.30L0")"8EMD6P``````````35!M6P````````````!=0');````
M``````````````!B-@``````````<UM26S@Y*U1L6P``43]P6P``45L``&8U
M``!K6V4_````````;EL``'%;````````>5L````````````````````````A
M.2,P``````````````````!Q0@````!',V];`````'A;``!21G1;`````'5;
M=UMV6P````!^6P``<E,Z,@```````'U;`````````````````````"1<``![
M6P``````````>EL```````!\6V!%>3L`````(UP`````)5P``$-,````````
M439`70```````"%<```B7````````#5'````````:38````````G7```````
M````)EP``"E<)#$`````3#4`````````````,#\`````````````7U$`````
M`````$(V`````````````````````````````````````"A<````````````
M``````!Z2W-K````````7$L`````?DL```````!!3`````````````![2```
M`````````````"I<`````````````&Y,*UP`````````````````````````
M````````````````````4UL``"]<+%P``#,^``![2@```````"U<````````
M`````````````$I).40`````````````/4<N7````````'949E``````````
M````````````*T15-@``````````````````````````````````````````
M`````%1;``````````!:,0```````%5;````````````````````````````
M`%9;````````/CH`````````````````````````````````````0$@`````
M```````````_2DE(```S5P``>4D`````1S\`````>#H`````/%(`````````
M````````````.F(``"8T`````#@Q`````````````#0X``!$3P``````````
M9UDF3V)-`````&U98#8``#E2`````#LY```````````Y8C=B``!S-```;$PK
M3'(W```R6&M1.SH``"=*`````#=-`````$129#]0/&$V``!%7@``````````
M1EX\6P``65$`````9D9.1&XW``!<-P````!\/V!7``!U1@`````\,4A>,3U7
M3$I>``!)7@````````````!L-0``74D`````0C``````````````````````
M`````````````"Y%*T4``$Q$``!I/'U+````````0SH```````!Y96=(>F5]
M30``,5<^.&A"``!12`````![90``````````2C9+/`````!]42%F``!N0P``
M````````)&8``````````'YE)69730````!!-WQE?64C9@````!=1"AF````
M`"=F````````````````0T,``%Y&`````"IF```````````````````W1```
M`````")F/$H``````````&,]0SDF9E50+TX`````*68P9@``)E(``"H]+68`
M````````````+V8``%%``````$Q2````````)SP`````````````````````
M```````````Q9@``=E(```````!+5P``?DT``%Y-)D(K9BQF/STN9C-F````
M`#)F```````````V9@``.&8``````````&]$````````2$0`````:CYO20``
M```W9@``<#8```````!D0P``````````````````:5,T9@``-68``")(````
M`````````#UF````````.68`````````````148`````<4T[9@``````````
M````````````````/&8``````````&D[```````````````````^9@``````
M````.F8`````-T`````````````````````````D4S]F=$E#9@````!$9@``
M````````=E`````````````````````````````````````````````````]
M0P``````````````````1$-"9@``````````````````````````````````
M``!!9@``````````````````1V8Q3P``=&L`````2F8`````````````168`
M````7CPI20```````````````#4\`````%-/`````````````$AF``!)9@``
M3F8``%!F````````468```````!+9E4U``!,9@````!/9@````!;1```1F8`
M````````````368`````````````````````````````````````````````
M````````````````4F8```````````````````````````````!49E-F````
M````````````````````````````````````````````````````````````
M`````%5F``!X60````!69@````````````````````!79@``````````````
M`````````````````````````%-7768``%YF5S]05```5E=F-&]+6F9#6$Y7
M(E```$]#`````%]F/CQ".5MF)U$`````(CI/0@``*U@```````!K2FYE``!<
M9@``=3<``````````&9(`````'5$`````#)E?D0``'Q+,V4L50``;E-82C(P
M``!.2VI-`````&HZ````````-64``#1E``!:5UDY9E8H-G!-2U(F,35*``!H
M,W-)33][4%)*-F5".P```````%Q/+#D``````````%=4`````"8Z9U%\3U(\
M```W95U(````````;3]V,5Y+`````$4\``!$/'I27$-</P``````````.S@`
M``````!"0P``+CHB5````````````````````````%Y'+T1L,@``43D`````
M.V5(00`````O50`````````````\90``/F4``````````````````&<T5#9"
M2S!1/#4`````64H``&(W`````&1)```K/0`````^3G!7```````````A4```
M64D`````>S989F(\```^,P``4$D``%EF(C,``````````$Q>``!(4TU>```B
M4@``````````3EX``````````$T^`````$]>````````+$I\4E\S:F5A1"$^
M,DYR1%8^*$9C,@````!3/@````!\1VM,;#U=3@`````Z2D%&;&4\4```````
M`#E5````````;64``````````'1*``!`345"``!O90``1$)P90``````````
M````````>&5-30``/4D``````````````````%E2*&$``````````&Q3``!J
M2W%&`````````````"QA````````)V$I80`````J82]A`````&TR```K85HX
M+6$N83!A.C4Q80`````````````S83AA`````````````%)1```V835A:T$`
M```````W80``0%0``#)A```Z838P```````````T80``>3\``#EA`````#MA
M````````````````/F$````````````````\80```````````````$56````
M```````````````_3P`````]83]A34(``&LV``!X4P````!-1P````!E-P``
M````````````````````````?CX```````````````!`84%A`````$=A9S,`
M``````````````!I1@````````````!>-```0E$``````````$AA`````$9A
M`````````````$5A``!#84)A``!`,0```````#A51&$`````````````2V$`
M````````````````````3&%*80````````````````````!Z;P````!385)A
M-D<`````````````````````````````26$`````3F$``%!A````````````
M`````````````````%1A``!184UA`````$]A``````````!580``````````
M````````````````````````5F$`````````````````````````````````
M`````````````````````````%=A````````6&$`````````````````````
M`````````````````````````````````````````````%IA````````````
M``````````````````````!;80``````````````````(4X`````````````
M`````````````````````%UG```H-%U6`````#)1,C,`````)#ES5TE'7CXN
M.0``5TX`````;C)/6P``.CQ14DA+33``````;T\`````````````8UEM/0``
M``!2,5!*/#(``"=+*S<``"9*````````(T\`````>&!*57M@`````'I@045[
M3```,4%Y8&-6+S)$5ELU`````````````````````'@T(58`````````````
M+T]O,`````!\8``````````````A82,S`````'U@?F`Q0P``````````74,`
M`")A>3<```````````````!/.P``````````````````(V$[1```````````
M```D80`````E80`````F83$T````````````````````````````````````
M````23@]1FI$```B,@``4E```%MG0SM74T13``!C.4]B````````+U<``&Q'
M4S$`````,C118@```````')0+D)08@``8C\F4U<U4F)J-0``;4-].```+C@`
M`%-%3S=48@``````````4V)(-GE7`````````````"5-`````````````%AB
M``!68GQ*-3\Y4U5B``````````!78@``````````````````````````+D%(
M0````````````````%MB6F(J0`````!.00``````````7&(`````````````
M``````````````````!=8@``7F(```````````````````````!(6P``4U$B
M30`````H/0```````$->)5@J/TU;;%)Z1BI%````````1%X``%<Q+E\`````
M```]2@``,5\``"TY``!]4@``)3AK.@````!:,P```````%PU154`````````
M`%9#4D\A.P``<V5R90````!T90``9$T``'5(```````````````````O-3]'
M``!V90```````#!L````````````````````````````````````````9F4`
M`&DY,34``#Q":&5G96EE``````````!-4@```````&IA3E```"Y-``!E40``
M``!*,FLQ``!R,6U%`````$-5,%,``%QA````````76$``%M2```Y,TLQ````
M````>4UW55YA```V/GTT``!?85PZ8&$R.TE"86$```````!L4```/4T`````
M8F$``$,U1T5C80````!D80``````````>5,```````````````!E80``+5$`
M````9F$B3@```````````````&=A``!"-0``````````:&%5.P``````````
M``!$4&!B6#%D4@````!A8@````!)/$Q(``!C8GYL?6PO7P```````&)B/E9\
M329#````````0V,`````4E9G8@````!H8@````!'4P````!L8FP_``!M8F5B
M`````$`S````````;D0`````;F(`````0U```'8Z:6)>-S,[+$Q+2V1B9F)J
M8FMB````````=V(`````=&)U5'-B`````"U%``!Z54)%0#(`````;V(``')B
M+T$\2P`````A-7EB````````,3QQ8E10.51U8E8Y=F(```````!31P``````
M``````!P8@````````````!<5R%M`````'AB```E;7YB44H`````````````
M`````#5!``!0.P````!6/P``8SH`````(4L````````F;2-M`````")M````
M``````!6.R=M=%``````)&U>.G<V(6,R-G%,)SD``")/(4<`````4C\`````
M<38``'IB>V)]8GQB540B8P``05,````````G8T1'```````````D3P`````I
M8S<Z```````````H8P``6CL``"-C````````)&,J8P``)F,``').1E,`````
M/#L`````0U0``'I$`````"AM?%`E8P``=4,``"UC+S$``#)C````````0CP`
M````+&,_-0````````````````````!I1S!C````````*CYO30``````````
M``!S.P```````&A,`````"]C```Q8P``)T\N8P``*4Y=.P````````````!K
M-64^4C)-,P``.3$K8U$R+#5?.6@V`````&M/-V,``$P[`````$=(2E``````
M````````.&-N,P``````````*6T``'I39%,````````J;3EC8E(`````````
M````-6,``````````%Y3``````````!0.#-C`````#9C7S<``#1C(D``````
M```Z8P``````````````````````````````````````````````````.%0`
M````````````````````2#0``#MC``!%.P``=TD`````94D````````]1```
M````````````````*VT``````````'U"``````````!;.RX_````````````
M```````_3@``````````/&,``#8_````````````````````````````````
M``````````````````!O,0````!W5``````````````^8P``````````````
M```````M;0```````````````````````#]C*3HL;0`````]8P``````````
M````````````````0&,````````````````V.@```````"XV````````````
M`#A0``!#,"YM`````````````"]M04```$%C````````````````````````
M`````````````````````#-%````````````````````````````````````
M`$)C````````````````````````,EP````````````````P;0``:C@``&Q.
M)VIG4'E*5D@W3TDS4DYD/0````!>8W([*&H]50``748I:@```````"IJ```L
M:BMJ```N:BUJ``````````!8/0``+VH``#Y"``````````!!-'<T`````"<[
M`````````````&9L96P_-WE+8C$``&=L````````2$EH;&EL``!62E!>13)Z
M5`````!+1D<P<C132````````%!-`````#@_``````````````````!;/P``
M```D1S16```I0%%>*$EO421%9S`V,T5(`````&(P`````'8W`````'I%````
M`',V``!255`S/#P````````M,P``````````<3Y1,````````````````%92
M8THE5P``-DTV-CD_6U4``"<X5T4```````!27ED_54)`1P``)#LH,0````!J
M10````![12=,```````````G,0```````%8U````````*$0``%->.E%I,P``
M<D,`````=S<``'16(S5P,C1$:40M0%1>``!H,$1%8$$``%4Y``!</EA-3C``
M`$]-5EY0/CY755Y055TP`````&)$`````"-"<#P``#53.4`A128R<50`````
M*$!#2E=>?%4``#`Y```M2"E+``!97CT_```````````T1B=7,$I#1```5C-2
M.0``````````.%9\:C0P``````````!F/P````!T3```````````6DT`````
M```_5DY"``!.3B),+E!31#(U6%YU53<\4SL`````)#```#)%;#0```````!Q
M50````!]:@```````````````%I>)DT`````;$T``````````&9.7%X``#%-
M)D``````/5<``%M>1C`T.E-)<T1H/@``````````-C(`````````````````
M````3$!P2P``<3P[.S<U````````=44``&9>````````8UY=/@````!?7@``
M````````-S1=/0````!@7FU$``````````!&3P``8#4``````````%XV6DIT
M-65>``!&50``85Y-3'Y&``!%10```````#12``!R/@``````````````````
M4T(``#U,.#,``%,]``!8/T9-6E%K-```9%Y=7F=>``!^:@`````P0F)>````
M`$!6)S4``'0R``!H7@``<EX`````````````;5X``'%>`````&!(````````
M85=O7FA#84P``&4R````````/E(``````````````````&Y>``!K7E5.```G
M-``````````````K/SX^`````%(]``````````!I7@``+E0``%Y>``!J7@``
M````````/T```&Q><S)I."="`````$$]`````````````'5>>%X`````*S(D
M-`````!J-"9)````````````````=EY12P``8S@``'=>>EX``````````'E>
M````````0DP``&$P;C0````````````````Z90`````````````O4`````!K
M,@``(6L``'1>`````&-)<UY:,"%2=S$``"],``````````````````!P7@``
M)$L````````J50````````````![7@````````````````````!=-```)D0`
M``````!]7@``````````````````````````?D,A1"%?````````````````
M``!,00``?%YO/@``,D8```````````````````````!%,W9(`````#I+?EX`
M````)%\``````````#)7`````````````#<S``````````!#00````!+1R4R
M:30``"M7``````````!L1```(E\C7P``)5\``#,Z````````)E\``%Y`````
M`$-)``````````````````!9,F9'```G7P``7$<``````````"A?(FL`````
M````````4TL````````J7P``*5\``$$R````````````````````````````
M``````````````````````````````````````!*10``````````````````
M```K7P````````````````````!<5`````````````!!2```````````````
M`````````````````"Q?`````````````'`^`````"U?)U8``````````#=J
M-FM52@``?%A$.```)3D`````13=^50````````````!*.0`````G4$UT````
M`%`U`````'1#``!(/@```````#=K/3``````3#T``#)!``!6,2@S````````
M4C@B20````!8-@``````````.&LT/@```````'U*``!#1P``>U4`````<S<`
M``````````````````````````````````````!$3@```````"M5<S$`````
M```S;%\P```U;````````#<V``!/00``>G4Q4`````!E50``4TX`````;SUB
M,P``*S@``#95```];0``3S8``#E+0E``````````````````````/3<`````
M-FPI2@```````%1%```Y;#AL0T(W;```````````?5`Z;```.VQE5P`````\
M;````````#UL;$8`````````````````````7DX``$@\`````%5(*35)/CQ6
M9U0`````+E%Q4#AJ.6HZ:C4Z```````````Q2G4_`````'I-````````````
M`$!J```Z,#YJ`````"5`````````.VH``'TR``!W0V@[````````5U)T3C]J
M````````/&H```````!#:@``1U`S4P``````````.C0``$%#<E<`````````
M`%%5``!'2@``16H`````1&I':D9J`````````````&=6``!43P````!+:@``
M3CL``````````````````'H]3DD`````3&H`````.4E^3TIJ3E1-:D]J````
M`&U-``````````!):@``3FH`````;DX``%X[```_,P````````````!51C`^
M>DX```````!G1P``)SY0:@````!'5@```````$!!````````750``%%J````
M`#Y/``````````!2:@``````````;DH``````````"]%-3``````````````
M5&H```````````````````````!3:E]T`````````````#I$````````````
M`"DQ``````````!?90``````````56H`````````````````````````````
M````````````````````````````````````````;TH``%9J5VI81@``````
M``````````````!8:@````!9:@```````````````#M4``!Z1S=2?#@`````
M0FH``%PR`````'Q"``!X5&9,;E<``````````````````$)44%-#:W-%``!^
M-P````!4:P```````#=+7FL``$I`````````>TT``"\S``!:1@``````````
M`````'QK```^1```-$XI1#XQ?50``'5*``!L5@````!31F0V``````````!Z
M.P````!@4``````Q20``4U0H2`````!+.```/F@\20`````[:```;D!34$0R
M930``#QH`````$A5`````````````$4V```]:'A*7#AU3````````#1`````
M`&Y1/VA":``````\.@``+3%</0``/6I#:```1F@``$MH``````````!,:```
M24ME,```*SP`````.3D`````06@``'=-``!*:```````````=DX`````````
M`&U5``!6041H```V0P``>SDF5DAH````````8$IF5```0&@``$5H1V@``#E'
M8S<``$EH``!=/U)H`````%=H``!5:%P\3SQ;:`````````````````````!>
M:```6FAZ,0``````````````````````````6#`S1$PX8D8^2&%(````````
M3VA4:%9H``!Q.5AH=5<``'M$``!<:`````!I,@```````%%H`````&T\````
M`$(_36AY5@``>$%Q,@````````````````````!?:```04I9:```````````
M)%4``&HQ.U5.:%!H,#93:```76@X0```=TH``"A+`````%Q&=4``````````
M````:6@````````C4```````````````````<FAJ5@``````````````````
M8&AA:````````'E12SIY.`````!Q.%14;V@``&YH;&AP.5),9F@F3G(_```X
M,'%H<&@``$!7``!D:```*4TC20``.#M;/6IH````````````````````````
M``!B:&-H96@U-6=H14=K:&UH,#TN5P``>&@`````````````````````=6@`
M`#!-=F@````````````````````````Z00``:&@``#=#<#``````````````
M````````=&@```````!W:````````",Y``````````````````````````!2
M20```````$Y#8$YF0```````````<TL``%U,-5``````84H``'-H````````
M``````````````````!L/```>6@```````````````!>0P``948``'<Y````
M``````!T,`````!85P`````L/```;T4`````````````1$P`````)FD`````
M`````````````````````"U)```B:6)`````````0S\```````!^:%<Y``![
M:```````````)&D```````!.4@`````````````C:0``,E8U5P``)VD``#<]
M````````````````````````````````?&A]:````````"%I````````````
M`````````%9-`````"Q2````````,FD``````````"EI````````*C0``#LT
M`````"MI`````````````````````````````````````````````"A0````
M`"5I`````'XS`````"QI8T```"II`````#EI`````#AI```````````N:0``
M``!Z:``````H:0`````````````L/S%I.FD`````)4(````````O:0``13@`
M`"UI``!<4S1I-6DW:0```````$=I````````````````1D!%:0`````P:0``
M```[:7$P```````````````````````````\:255`````#YI```_:0``````
M`$%I`````'%!`````#9(````````/6D`````````````0FD`````````````
M````````0VD``#-I```V:0``,3L```````!`:0```````````````'<\````
M````1&E&:0```````````````````````````````$II``````````!.:0``
M````````````````````````6S(``$AI```````````````````````````N
M-P```````````````````````````````$MI3&D```````````````!!50``
M(T0```````````````!8:0``83H``````````$EI```C4P```````%1I````
M``````````````!7:5!I`````````````$]I`````$%'````````````````
M`````%)I``````````````````!9:4@S``!3:0````````````!P3P``````
M`$UI`````````````````````````````'<S``````````````````!6:0``
M``!::0```````#1,````````+4\```````````````````````!5:0``7&E;
M:0````````````!>:0````````````````````!1:0``````````````````
M``!=:0``7VE*0P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````-T=.-#8[0%`C;``````W10``````````````````
M````````>U,``````````"1L```E;%M&````````;C\``````````"9L````
M`"=L*E```#A'`````&@X````````````````````````````````*&P`````
M````````````````.59]54LT/3)D3F=&`````&%-````````````````````
M`````````````````'4T``!`2U\\``````````!B:6-I:E%E:0``>31D:0``
M,U%B2E`R``!H:0``````````9FEG:0`````S5@```````&EI:FD`````````
M````:VD`````````````````````;&D`````````````````````+VPY14XV
M``!S4@``````````````````;C4``%D[,6P`````8U(`````````````8TX`
M`#A$```_0P`````^-CE82#%/,5$Q?D4``%`Q```K0P`````````````Q50``
M```````````````````D:T$Z````````.DP````````E:P``)VL````````H
M:P```````"9K```````````````````I:RMK*FL`````````````+&L``$]*
M-5AQ0P``)4-X1BUK2D0``"YK+VLP:U4W````````>C<``#%K8D<``#-K```D
M.G51,3`R:S1K````````*C5(0FA'```U:P``+DM?8P````!`4P``````````
M6UD`````(4TM5G-'````````8%EC.P``.CIB8P`````````````K3P``````
M`&!C1TD``#DZ````````-%%A8VI(+SDM/5@S6TX`````0$P```````!H8VEC
M=$T`````````````+4P``#,\``!J8P``:V,`````6E````````![1EHW````
M`%]'2E)63@``9&-L8P``<DE!,P````!G8P````!C1F5C`````#-M9F,`````
M`````#-)``!F10```````#4Y```[0P``8V,]121!64)7,@``;6,F.RU$``!P
M8UH^`````'MC=6-3.@``````````4#=-4P``3E9354$Y-%5840``````````
M.5!V1P```````"I(-#(``%I#````````;F,`````?&-O8R@W=V-T8P``````
M`#HW`````")%``!V8UU%*#)\1@``8$0`````(E<``&%`>6,`````>F-]8RE,
M<V,``#Y3``!#,31M<6-R8P``>&,Z4$-&<U1^8P````!@/0`````G9``````F
M9````````'-1(V0``"ED````````=T@``````````#1/```H9"YD94(`````
M-#8```````````````!R/0``(F0`````:3HJ9``````L9`````!]-EY6,F0`
M`"UD````````(60``&X[74TB1TE%`````'=!```D9```,T<L/3T])60``$=7
M8C(``"MD0SPO9```:SLP9"A%,60``````````&-5(S\``#ID```W9```.V0`
M````/60`````5D8`````1CI+0````````"$X-&0``````````"%4`````",Z
M?CT````````\9``````````````_30````!Y1`````![3V9)`````#]3``!1
M3P`````S9```.&0Y9&E,`````````````$Y,``!40#5D,$$V9%!.``!!.U,U
M``!S2"<]1U4L22(X2F0`````3&1$40`````Z4@`````M.@````!4.@``````
M`````````$-D;34```````!-5T!D?4\_9````````%Q!2DP``````````&=*
M``````````!71```5$Q(9````````$=D060``$1D+34`````65,``$9D````
M``````!Y4F,T```T.P````!N20``/C0```````!L.P``35$``&U,-6T`````
M````````````````94<``````````"A4``!+9%570F0``"4]160`````9E,`
M`$ED>$D`````/F0`````95,`````?D=)-@``?%0S,E=D````````0DX``$UD
M```\3@``6S@`````5F0``$H_````````3E,``&Q#````````````````````
M`$A%6&0`````````````````````1$U/9```````````5&159```?CH``&9/
M`````#]5````````4F0`````````````````````````````4&0`````3F0`
M``````````````````````````````````````!E32I*````````(T```"8]
M4V0`````2#@`````````````9V0T5```````````````````6V0```````!O
M00````!I9`````!G4@````!?9```8&0`````*D\``````````%U+``!:9%%D
M``!E9```7$AC9`````!G1&)D``!A9````````'PS:&0``````````&$U````
M````3%<```````!F9```+#L``%)73TQX:P``9&0`````=CD```````!-5EED
M7&1Z0EYD``!+0D1`4$(``'4Q,DP``````````````````````````$XU````
M``````!O9``````````````````````O1@```````&%&`````'5D````````
M`````"E"````````;$!=46YD```````````````````````````N1```````
M`&UD``````````!V9'1D?D(``%UD``!P9```?DH``$15`````'%D````````
M``````````!Z40``````````````````:V1L9````````')D```K3@``````
M````````````````````2T4````````Q1P``.D(```````!J9````````$I!
M````````````````-DPQ,P```````'MD``!S9````````'ID``!]9```?&0`
M`````````````````$XS````````.C-W9`````!Y9'AD;$4`````````````
M`````````````````````#U```````````!H5``````````````B90``````
M``````````````````````!$,``````D90`````C90```````````````"0\
M```E90```````````````"%E``````````````````!^9'0Q````````````
M`````````````````"AE```I929E````````````````````````````````
M)V4J90``````````````````````````````````````````````````````
M`````````````````````````````````%E&`````````````````````"ME
M+64``````````````````"QE````````````````````````````````````
M`````````"]E````````+F4`````````````````````````````````````
M``````````!@.0`````P90`````````````````````````````````````Q
M90```````````````````````````````'`[86QP0P``1C52.P``````````
M:4%N5```1#X```````!&5P``5E13,CYL``````````!!:@```````"]"-C0`
M``````!740```````#0S```R2#L_0&P`````2U8`````/VQ!;```````````
M````````````````````````16QF/C],6D4\/@``1FP``'XQ````````1&PH
M56,U``!";#9!8S,`````0VPX2T-`?DP``````````%)!``!(;```````````
M````````````````````````9CI30```<E8```````!,40``````````/C\`
M`#,W54E';&([``!,3'T]2$@``"E/``````````````````!I30``:T4`````
M``!I-P````````````````````````````!)43@Z`````````````$EL````
M`$IL``!`.TML``!B;#HQ63<`````````````````````````````.3T`````
M````````````````3&QF44UL```````````[2```````````````````````
M``````````````!1;```````````4VP``$T[``!E/```````````````````
M````````````````3VP``#=)`````````````#I#``!C;%554&P`````````
M````<U8```````!2;$YL``````````!4;```56P`````/TD`````````````
M```H3P````````````!<4```````````+%$``````````%M(````````5FQU
M3@````````````!L2EIL``````````````````!9;````````#XP````````
M````````5VP``%AL````````9&P````````````````````````\2```````
M````````````````````1T$`````````````7&Q@40``````````````````
M````````6VP``````````&]4``!=;````````````````$9;````````````
M``````````````!>;````````````````````````````````"PQ````````
M``````````````````````````````````````````````````!?;```````
M````````````````````8&P``"97``!`10```````#QK+C````````!T/C@X
M+U)6,'DU```S6```+$L``%UC```````````````````L1F8P````````1D4Y
M:P``````````.FL````````[:P````!`40``(T4``')J```R1```-41.0```
M`````'-J040``&].``````````!P:G1J`````'Q)`````"-'````````6$Q^
M3@```````'5J=FHL3V=``````'=J`````````````#\V>&H``'EJ``!Z:@``
M``![:@```````````````````````````````'%J````````````````````
M````````````+DAK80``.#=L80```````&UA```T5VYA;V%,4P``````````
M````````<6%Q/W!A4C4````````W,0``````````<V%R80``?#H``'1A````
M```````W.0``43X``````````'Q$``!=.D8]````````````````=6%W80``
M``!`-D%/*$IV87A5?%-X87QA>6$`````>F%J0```?F$A8D=```````````![
M80``?6$````````````````E8@```````%1!```````````C8@``*&)^,B)B
M````````34-",B=B)F(`````)&(I8@`````K8@```````$E0;58H0RQB``!7
M3P`````N8@````!O.@````!@:2UB*F(``````````"L[,U0`````````````
M`````````````````````#!B`````"]B``!A:0``````````,6(`````````
M````````````,F(`````````````````````````````,V(A3```-&(`````
M````````````````````````````````-6(`````````````?E``````2D(`
M`'%3``!U30````!@9P````!A9P``````````03X``````````&I"````````
M9&<`````8V<```````````````!F30``-4,`````8F<W.U9/``!A06EG````
M````:&<`````=&<C,@``````````:F<``&9G`````````````&QG:V<Z20``
M``!D50``96<I-V=G``````````````````!N9P``````````<V<``&E6````
M``````!M9P``<F<``'%G````````8#```````````'5G````````````````
M``````````````````````````!R1P``14!M0`````!P07!G``````````!V
M9W9+````````````````````````(F@A:````````````````$%7`````'IG
M>6<``'MG``!W9P``?F<``'UG``!\9P````!505E'?45#10````````````!M
M1P``````````(V@`````````````````````````````````````````````
M`````"9H```E:```)VAW.GAG)&@``'!(*DD`````````````````````````
M`````````"EH`````&4Y`````````````'Y1*&@````````````````J:```
M+6@N:```)T$````````O:````````#!H`````"QH```T:```````````````
M```````````````K:```,6@`````````````````````-6@R:#-H````````
M```````````````````````````````````W:```````````````````````
M```````````````````````````````````````V:```````````````````
M`````$\Y```L<```+7```#!&:C`_2```7TT``````````````````$U.,6H`
M`````````#)J```_1DDT```````````````````S:@``````````9U4`````
M````````````````>5T``#1J```U:@``-FH``````````$HX,%]U20``<$P`
M````>DD`````````````>TD`````0U,F2P``)C@N<$(Q```X96],25-7/&I)
M``!G-0``4$1I-0``+FXM.P````!>9P``+VX``````````"DS`````#)N````
M`#%N9ST``#!N-TX``````````$]%``````````!T04Y;,VYS4```````````
M``````````!40FA&````````+#<``````````````````#1N``!K,P``````
M`'L[-6X`````````````7&<````````V;@`````N/0``````````8G$`````
M``!H2@``25):<```6W```%QP1D$``&TX3CX`````7G```#%%77!Q40``8'!,
M,&H]`````````````%]27W```"\T:#=F<&5P(T9A<&)P0S0`````8W!N50``
M``!;3%(^,CP```````!H<&=P9'`A,@``(E8X4S<^+$@`````:G``````````
M`'=1``!,5ELZ:7```#LV`````#1-`````"9&````````(4%K<&YP``!M<'!P
M;'```#X[;W```````````#5,<G``````53,``````````%0Q`````'-P````
M`'1P=G!A-```<7```'=P``````````!Z<```>'````````!U<```````````
M?7```'EP?'!^<```(7$```````!!3B1Q```C<0``=D%[<%U*`````'$T<3$Q
M3```)G$`````)W$`````+'%.52EQ`````#-(````````(G$``"MQ*'$E<0``
M```J<0`````````````````````I,"UQ````````````````+W$``#%Q````
M`````````#!Q```N<0``````````(E$``````````````````#)Q````````
M,W$`````````````````````;SD`````1S4``%<P63````````!M5```1#4`
M`%0]2CLG<`````!>.``````H<``````H,```*7``````;DT`````*G``````
M`````````````````````"MP````````````````````````)$8`````959D
M<0``97$``````````````````````````'-#`````%M3`````%%6:$4``"]3
M``!F4@````!!;CLP-55.46`\4#H``'@_``!'.$$U3$4`````(DH```````!+
M0P````````````!";@`````````````````````_1"(V``!L;21#```Q5@``
M`````&!/;VT`````3D4``%PV`````"%*`````&UM`````'!M<6T\0P``-#\`
M`&YM`````````````````````````````'1M<FT``````````&957T,``'-M
M````````=FT``"-5(U$```````!U;0``4$,`````````````=VUT/VP^>&T`
M`'=,``!;40```````$57=E4``'QM````````>VT`````````````````````
M>6UZ;0````````````````````!];28^`````````````"]+(6X]-@``(FY`
M1```?FT`````7CU',@```````````````````````````````$,V````````
M)6XZ6"-N)FX```````!I0W(S````````````````)VXD;CE/`````"AN=T(`
M```````````````````````````````I;BIN```K7@`````S1@``1D<``'56
M234``#)+````````*VX`````*TT``"QN`````````````#!5```M;@``1'8`
M`````````````````````````````````$=;````````````````````````
M(S0````````L0V9Q`````````````#A*4U(``"I6``!R;P``6#X``$,]<V],
M-BLP```````````O2@`````V;0``-VT``````````'E.+S=S/SAM:T(P20``
M`````````````#EM`````'9&,S\````````\;7A%``!040``*5<Z;3MM``!B
M40``/VU`;0``1&T```````!(;0``1FU.;6A5``!);0````!';3YM`````&E%
M````````1D8`````:4E25$%M0FU#;45M``!Y0```(30``````````&@Y``!0
M;0``````````46T``$IM``!/;0``>$X`````-DM,;4UM`````````````'5/
M````````````````````````````````4FUR03)32VTW2```````````````
M``````!O/```````````<$4``````````````````````````%9M``!O-0``
M```U0BTP:4L`````+C$``%1M````````:TUB-0``56U3;5=M`````'HU``!8
M;0``66T``%QM``!,,0````````````````````!V16X\6FT\3&HR````````
M``!;;0``````````:T0`````130```````!U,````````%]M6D!H-```````
M````344```````!=;40_````````7FT`````````````````````````````
M````````)40```````!@;0````````````!A;0``8VT`````5T$`````1SL`
M```````````````X/0```````&)M````````````````````````````````
M``!D;0``````````````````````````9FT`````````````96T`````````
M``````````````````````````````!G;0`````````````^2FIL<4```&=)
M``!K;&Y&``````````!L;```;49M;````````````````````````'!L````
M`&97<VP`````<6QN;&]L(U=Q26Y+=&P``')L`````&E/``!V;#%&````````
M``!`/```=6P``````````````````#LU=CL``'=L`````````````'=9>ST`
M````.T)X;```````````>6P``````````",X````````````````````````
M``!Z;````````````````````````````````'ML````````````````````
M`````````'QL`````````````&U3+EAK0```74=,.@``8U`]2P``.DT`````
M43@`````?#$``&]'``!65@```````$8_:T,`````=6\`````6$,`````````
M``````!B5P```````'=O4S,``%A';5$``$A6``!X;P``=F\``'T[1C,`````
M`````````````%4]`````$92``!@.P`````A3P``?&][;P````!Y;P``````
M````3#,``%1),$L`````````````?F\`````7C``````258```````!];P``
M;3,`````578```````````````````````````````````````!(3@``````
M`")P```A<```/C5:/'P[``!E.````````````````$)$````````````````
M```````````C<`````````````!K2P``````````````````````````````
M`````````````````````````````````"9P````````*%$``#\^;D<V<3=Q
M53\``````````"DT.'$[30``5$<M50``.7$``#IQ``````````!/1P``````
M`"123U8`````.W%1/3`T/3X```````!<-%%.``!?/SUQ``````````!Z/SQQ
M```_<0```````#YQ0'$`````````````07$`````````````````````````
M````?D$`````````````````````````````(D$`````````````````````
M`````'I*`````#Y5```````````Z/CD^0E4`````(C\``"]--7$`````````
M``````!?/0``2S8```````````````````````!Q5D-S`````$1S``!-.```
M`````$9S1W,``$HP``!%<P``27-Q2P```````$MS```F4`````!*,4AS````
M````3W,``%$U`````%=S``!2<P```````%1S4W-[-P``/S$``$YS2G-:-0``
M4',`````47,``%5S``````````!-<P``8SP``'U!``!6<P``````````````
M`%IS``!,<P``2#4``&X]7',`````)#=P/WY6,DT``'`T``!?,@``6',``%ES
M.$D``%US`````%YS``!A<P````````````````````````````!?<P````!C
M<V)S`````%MS``!J/P``;S,``&!S`````"E'``!R/```````````:W,`````
M`````````````#\Y`````&1S````````+3)^.P``8TL``````````&US:7,`
M``````!<.6YS````````97-F<VIS84)L<V]S:'-]/````````&1/`````'!S
M````````9W,`````````````````````<G,``````````"U7*D8`````````
M`'-S``````````!Q<P``*$(`````````````73AU<P````!T<P```````%LT
M````````=G-W<P```````'AS````````.D``````:4``````````````<44`
M`````````'MS``!Z<P````````````````````!8-````````'YS>7,`````
M?',```````````````!]<P`````````````````````A=```````````````
M`"-T23L`````(G0``````````````````````````````````"1T````````
M````````/C(F="5T`````````````````````````````"X\````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!70V%9````````````````8$!,=%%7````
M`````````````````````````%LW``````````````````!.="-!`````$E&
M``!6-#-5````````4'1/=%%T6DL`````4G0``$%48%8``````````&`W````
M````.$$`````.T%3="P^`````````````&(T`````%1T570K/@````!6=```
M`````%MT``!7=%IT``!].@``6'19=```````````````````8CA'3%QT``!:
M,@````!30P````!C5#<_``````````````````!==````````````````#1%
M`````````````````````&ET`````#5/````````````````````````````
M`````````$E.````````````````````````````````````````````````
M````````6$L``'=+``````````!T/0```````$]7````````6T``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=5``````````````````````
M:G0`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````&MT``````````````````!L=```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!C=P`````````````Q
M-P````````````!M=```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````:U<`````
M``````````````````````````````````````````````````````````!N
M=````````'EF0#YZ9FPZ>V9+3WQF/%0V/'UF?F9-/%)(,TXA9P``/S0B9S1)
M63A)1```75=:0E<W/59&3D0W`````"9%(V=?3R1G)6<F9S=!:5=P23A/+U95
M5B=G;3`H9REG7$EO4BT^*F=S,%Y(83TK9T9(```L9V8[>#@D42UG9T)X/DH]
M,TTN9R]G;CYE4```9TM03$P\,&<H/'=0,6<``'A0,F<S9T(T-&<U9WY)+$Y@
M0S=G03%Q,P``.&<Y9UM70%4Z9TQ".E<[9SQG/6=J/&5#0D`^9S]G*3P``$!G
M06<V9U`V0F<``$-G1&<Z.UXU1D)@,45G-51&9S\X2&='9VPW``!)9W@R2F=+
M9TQG36=.9T]G4&<G4W5+46=29U-G5&=)255G5F=79UAG66=)/5IG/G,``%<X
M```Q2```````````````````/W,``$!S07,`````````````````````````
M`%XY>$T`````:%@Q.@``7D(W;@``(S<``````````#EN```X;E4P````````
M`````#MN5E5O5P```````$-6`````#UN<$H``#QN```````````^;@``````
M````0&X`````/VX`````````````````````<E$``#Q'``!`0P``````````
M``!A.`````````````!G00````!&=%]01W0``%M/`````#I(`````$AT````
M``````````````!)=$IT``!+=`````````````!Z67XX`````'%E<%,``&!T
M``!,3@```````&$S```````````T<0``;E(``&%T`````````````&A/8G0`
M````3$<```````````````!4-60T9'0```````!C=&5T`````&9T````````
M``!G=```,CH_,```:'0``````````````````"TW;5(````````K4D]````\
M/R-K7U5(:@``````````<W%X-B-+`````$U$``!G<0``:'%[.&EQ1#I%5%(P
M`````&IQ````````:W$``&QQ`````&UQ;G%O<7%Q<'%510``````````````
M`')Q``!Z-@``='$N4D=>2DL`````7#,``"(U```B.0````!T1'5Q`````'9Q
M````````1$%[03!6=W$``````````'AQ```J00```````#A&``!;/@``````
M``````````````````````````````!Y<4\T````````````````>G$`````
M`````````````````````````````#)M,6T`````8$M>4@``04M850``8D@`
M`%]`(3P```````````````!!:P`````D4```8E8``$<V6#A`:TXX```_:R8S
M23DK5@``=#=*-P```````&<\/C=&:P``1VLY,$\_``!%:WU3``!(:P````!)
M:P````!.-P``0FM$:W9)5U9-53)03VLX3E!K```H-0`````````````S,5)K
M)4P``````````````````%9%4VL``%%K7T5.:R1*56M[,`````!Z.@`````W
M6&-Q``!*:TMK3&M-:U9K0&99:P``:#](4E=K7&ML.%AK```Z/0``6%```#<P
M``!=:UQ$```````````L5@```````&`T`````'9".3P`````6FM;:V!4:D94
M1%]K)T5U60``,3(``&1K``!%/0```````&)K````````````````````````
M``````````!C:P`````L.```44UE:P```````&%K```S00`````````````B
M1@``````````````````<TP``&9K```P0#A29VL````````O."TX``!H:SM'
M<TT```````!J:VMK`````````````&UK``````````!(4```<FL``&YK````
M````<6MY2```?%%L:P````!I:P``````````.3A93V5$;VMP:UI,2$UR,```
M=FL`````````````=6L``#(R``````````!@.```=VL```````````````!L
M,0````!%3"1$)4\`````````````>6L`````(FP``')%``!Z:P``````````
M``````````!%20```````````````%]B?FL``````````$Y-(6Q;,3=3````
M`%Q2````````?6L``'MK````````````````````````````````````````
M```````````````````\,P```````#!J`````%17```K='0S````````````
M`$%60E8```````````````!I54H^```G=```*%(H="ET```J=$L^7U,`````
M````````8$EA20````!"<P``9DH``'),````````````````-F(T2P``:$Y;
M5@``+70N="]T```````````R=```/3HS=&,P,'0``#%T(CU5,@``-G0W=&8V
M,#)/3S1T+#0``#5T`````#AT`````````````#ET`````"=-```Z=```.W0`
M```````\=`````````````````````!22P``/70``````````#YT````````
M`````````````#]T`````````````%YT/$%H/```*TE>475E```````````S
M7%52`````#1<+#`U7`````!:/0``.5P```````!"6```-UQS4P``5DDZ7#9<
M```[7")#```````````\7$5</5P`````7TXE5@``3UP``$U<`````%)<9CTK
M0@``.%Q+7$Y</EQ2-T4P1UP^4$%<*#L``#PW3%P`````1EP_7%M'````````
M/U%`7`````!*7`````!07``````M3D)<``!#7$A<25Q4,E%<54L``#=46UQ?
M7"9,9EP``&=#7%P`````03]97```>C`V.65<4UP``$1<5EQT2&`_````````
M```[20```````#TQ```B4P````!:7`````!57```.T8``%Y<````````````
M`$)7+T,V-U%'*4-B7%A<:UQ47`````!=7```)3Y77```8%P`````8UQD7```
M>%P`````85PB76=<``````````````````````````!K/$0T`````"-#9S)Z
M7```<EP``&]<``!\7&Y<<%)H,@``5TAC2'M<``!M7````````'=<`````'5<
M`````",^=%P``%TR`````````````'-<=CQH7$0[``!S0`````````````!4
M/&E<:EP``'%<=EQY7#0U``!92&<[?EQ]7"M3(5TC725=<5(D729=)UTI4@``
M````````````````23HI70`````V73%=-%T``````````````````#!=3D8`
M````<D```````````"])````````;%PN70``````````-UT`````<%PO70``
M.%T``"Q=```````````````````Y73-=+5TJ1```````````*%TS0"M!*ETK
M70``,EUQ.S5=*%,Z70``.UTG0P````!273Q=````````45T``#TY`````%4^
M``!Z/@````!*.@``````````2ET``$5=```_70```````$LR0UT``$M=)#)5
M70```````#Y=````````4$9070````````````!476)!1C<`````````````
M3EU/70```````$1=````````/5T``$U=44P``$E=``````````!"74A#/$8N
M3DQ=``!(70```````````````$%=````````1EU<0@```````````````"E3
M*E-3771/>$@`````````````````````9ET```````````````!'70``````
M`&!=9$(`````````````````````85T``````````````````````````%==
M`````````````'A6``!975A=<#A670``````````3T8``"TV````````````
M`&)=``!Y.F%49UT```````!0-```6ET``'L_8UT``%]=``!=70``````````
M````````634``````````%M=7%U>70``+SUD70``95T`````````````````
M````=5T``$E#`````&)+``````````!R70``````````````````````````
M````````85@`````448``'1=````````=%5S77!=`````&Q=``!O70``:%T`
M````;E```````````%A(;ET`````:5T`````:EUR2P``;5T`````33$`````
M```````````V0```.SQQ70````!W70``=EUK70````````````!N10``````
M`'M=`````````````````````````````"1>`````"->````````````````
M````````````````>%T``````````&]#``![0@```````&%5`````#5.````
M``````!]70``3#(```````````````````````!H1%]*````````````````
M```````````^1WI=?%U^72)>*C!.,0`````````````L7@``````````)EXV
M/6](`````````````````````````````"%>`````"5>```````````I7@``
M```````````H7@```````"=>````````````````````````+5X``$Q4````
M```````S7BI>+EX`````64``````````````(3$V7@``,5X`````````````
M`````#)>`````````````````````````````"91-5X`````````````````
M`"]>````````,%X``#U0````````-%YM2CE>````````````````.%X``#=>
M```````````````````[7@``````````````````93T`````````````6#)J
M0P`````Z7@``.D4````````````````\7@``````````````````64P`````
M`````"HW`````````````````````````````````````````````&54````
M````/5X`````````````/UX`````````````````````````````(D0`````
M`````$%>```````````````````````````````````````````^7@``0%X`
M````````````````````````````````````.E4```````!"7@``````````
M````````````````````````````````+G(B.S)",$5'0@`````O<@``````
M``````!I4````````%U3````````/6L`````````````````````9C,P<@``
M,7(`````+4H``````````````````&<Z,W(U<C1R9$LZ3S)R-$I/4FQ"````
M``````````````!#3CAR=C`W<@`````````````^<@``3S(`````````````
M``!!43IR`````````````#QR:50`````.W(V<C]R/7(``#ER`````$=R1')&
M<@````!*<D)R0'(```````!%<@````````````![5@```````$%R``!Y1U])
M``!(<D8Y,#4`````0W))<E!R5G(`````5SL```````!5<EQ-``!K5@````!2
M<E1R``````````!R.```````````2W(```````!.<GE"``!=54QR37)/<E-R
M````````67(\4P``````````:C8``'%*``!D-U=R````````6'):<EUR6W(`
M````7'(``````````%%147(``$E-``!/3BE6``!C<@``6T,``&!R`````"]`
M;')><@``87(```````!H<@``````````8G(`````9W(`````9G(`````:7(`
M``````!?<@````!D<FIR```````````````````L4V5R=3(`````<G(``"M0
M``````````!U<@```````$@[``!Y<@```````````````'!R`````'9R>')Z
M<@````````````````````!S<@``<7(```````![.@``>S4``````````&]R
M=W)M<FYR````````:W(F<P``(W,`````(G,`````='(``%I(````````````
M`'MR````````)7,``````````````````'A#`````````````````````'UR
M`````"=S*7,D<P``?'(````````K<P``*G,``````````%U"`````"YS````
M`#!S`````````````"%S````````,7,L<P`````````````O<WYR+7,`````
M`````````````#)S```````````T<P``````````*',``````````#-S````
M````-7,``````````````````````````#=0```````````X<P``````````
M>5D````````````````Y<P`````````````````````W<P``9$@V<P``````
M````.G,`````````````.W-`-```````````````````````````````````
M`````$-N````````````````/',`````/7,````````J40```````"QT1E``
M``````````````!04%Q1````````````````3D\`````5CT``$-1````````
M``````````!B.FEA0E)"<3DR`````&TQ0W$``$!)1#,``')9```E2P``1'$`
M`````````%16`````````````$5Q0'1&<0``+%1'<0``0#!!=`````!"=```
M``!\-```6T4``````````#M,````````9%``````````````8$T`````````
M````2'$``'-9````````````````.S$``"Y/````````)#@`````````````
M2G$``````````$MQ``````````!#,E%!`````#!727$`````3'$`````````
M`$YQ````````=ED``&%2(U0`````0W0Y2`````````````!$=`````!-<4]Q
M8S]0<0````!4<0``````````````````5G%1<0``44EA10```````&-"?#D`
M````4W$``%5Q````````4SD``````````````````%MQ`````````````%8Z
M``!],%EQ`````````````%AQ4G%:<0````````````!7<0```````&Q(````
M``````!*35UQ```````````]90```````%QQ``!><0``````````````````
M````````7W$`````94\`````````````````````````````````````````
M`````````````````````````$5T<ST```````````````!@<0``````````
M``````````````````````````````````````````!A<0```````'=.```J
M4@``>W$`````,C@`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'L\6SD``&8Y
M64-32FAJ0$!U/FEJ:FIK:@``;&IM:FYJ;VI'/0```````'MU````````?74`
M`'YU``!\=0``````````8CT``"%V)30``````````")V````````(W8`````
M```R;````````````````````````````````%11````````````````:ED`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````D=@```````````````````````#IN````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M,E4```````````````````````````````````````!^4UQ,````````````
M`````````$1*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!`90``````````````````````````````````````
M`````````````````````````````````````````"5V````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+SX`````````````*48`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````E6D8\*38\.$]()3PF6B=:5DQ#2"A:?48``#51:5(V44<\```R/60[
M*5HJ6DA1*UIM4&\V6T(``$]+;3=H24,W=SXD5BQ:+5I`1F=7-DH``"E57TMO
M52Y:7U9*-#!:+UH``&M2,5HR6C-:5$HT6BM*-5HV6D\S;U8W6C`[+C4X6CE:
M;CDO46A2.EI#.&I/;S([6CQ:``!K/5Q.;U,]6G-./EI54V4[/UHU2U!+0%IK
M1VY605HU14$V0EI,-TX_0UI$6BU+15IW-49:0D$[5T=:.$P``&I2,41(6GTU
M43M)6C-02EI+6CU.3%I-6DY:=S)16D]::%%06E5#4EH``%-:5%I56CM0)5)Y
M,%9:*T=76G<](4-86EE:?4,W3%I:6UH^0%=&7%I=6C1'7EI?6D@Y````````
M````````````````;3L``````````#DV>'0``'ET`````&--````````````
M`````````#EU``````````!@:P```````````````'-//SL`````````````
M`````$`Z)50``````````````````%EA``````````!T=2HQ<C(`````````
M`````````'5U`````'=U````````43IV=0``,D,``````````````````'EU
M````````>'4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```T,6I5.C@``#$Y1C)P5$U/7#!+574[2E8W-S!,-D9A,3HY?%9A.2$W>CQ:
M:EMJ>4QS.5QJ>S0S0U$W6#I=:G147FI6/%\[7VI>03A"7U1*5V!J86ID:F)J
M8VI>23,X1#9E:FI*34E--`````!98F)%9FHU0```.%=G:BQ7?$A36$U87E0`
M`'E41$DN4U,X8#,``&))=G0```````!5.@``=W0`````7U<`````<70P.%15
M3SAP1@```````````````````````$,S`````')T+#,``````````#U4=T<`
M````````````='0`````<W0``````````````````````````$M,````````
M)$@``````````````````````````````````'5T``!C5S]%0'4`````.W4`
M`$-U``!"=0``.E9!=0```````#Y41'4``$QU``````````!/,'@U``!)=4IU
M``!<10``````````175&=0````!'=4MU``!@/DAU>C@```````!0=5-U````
M````9S\``'(Y/'5-=0`````W0@```````'A,``!Y/```3G5/=5%U9392=0``
M574``````````````````#UU````````5'4[4P``;#,`````)$P`````````
M`%9U`````````````````````%=U83Y8=0````!?3%MU`````````````$@R
M65<``%EU``!:=5QU``!B=0```````&!U````````7W5==0````!A=0````!>
M=61U974``&-,`````#]E.#5C=6AU(TP`````````````9G5G=0``````````
M`````#YU````````````````````````````````1#$`````/W4`````135D
M,@``;'5I=0``5S8``&UU``!J=0````````````!K=0````!:-```:E0`````
M``!N=0``>3,``````````````````&]U<74```````!P=0``````````````
M````<G4``'-U````````````````````````````````;4DJ.0````![1P``
M``!C-@``````````````````24P`````````````````````````````````
M`````````````````"9J````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```U,WY4;#EY4```;6DJ5VYI5D)M2&0Z;VEP:7%I859R:7-I=6ET:79I=VEA
M1WAI6%1Y:4X]``!Z:7MI3SU\:2@X/D%]:3(Q5#MU.7YI```A:B)J(VIX-RT\
M``!D2DY@+U0]3S=5)&I>525J05`\.0``1S19,0```````#%```````````!F
M,6<Q``!H,0``````````/3-H2```````````064`````7S$```````!)06\T
M`````"A'6%,``'E&.%$``'TY=4(`````````````+5,``$M4?#T``$)E-3=#
M90`````Y.V)5``!X/394)4XL05DS`````'9,``!&941E2&4``$IE1V5/-4A&
M``!\-45E``!V2@````!)90```````%1#13$C/````````#=7`````$M-34M*
M2E-,3&5+969$`````"%1-U%-90``4&4``#A-<%9/95TU```^30``464Z-@``
M```H360Y``!%2E$S64ML5%)E:C<```````!.90```````````````%5E?C16
M90````````````!3951E``!=4@````!?0D8Q``!B4P````!=-FQ+``!790``
M``!V4P````````````!I,0``=#9:95AE665`-0```````$527&4`````7F4`
M``````````````!=93)'```C4@````!;90``````````8E1:50``````````
M``!@97%7``````````````````!A90``7#%[40``8F5D90``````````8V4`
M````964`````````````6%(``$LU``!?9P``=5H``'A:``!V6@``=UH`````
M``!Z6D]01T0`````;C`````````P4```>5H``$I3*CHB6W%'``!\6GM:6TE]
M6@``(5M>5WY:6D$`````)5L`````=%,`````)ULD6P``*%L`````/#T`````
M``!)0"-;)ELC5@``*5L````````M6P```````"Y;+%M".@```````"0_*UL`
M```````J6T=4/S(`````+UL``'DY```P6P``````````.S,````````F-0``
M````````/#8Q6P```````'4V```R6P``````````````````````````````
M``````````````````````!),0``````````-%L````````S6S5;````````
M`````````````````````#=;```V6P``````````````````.%L`````````
M```````````````Y6P`````Z6P````!/4WIT=4=#5V1%?'1]='MT``!&/@``
M````````;U``````4S<`````350J3``````B=2%U*#I^=%9+````````)'52
M0```:C,``"I-)74C=30]*'4``"EU33TX0V$_84LJ=0```````"9U)W5P1```
M```````````L=0``/#0``&U7``!7-"MU+G4`````+74O=5%0````````````
M``````!10RE(````````````````,'4Q=0```````````````#)U`````#-U
M-'4U=0``````````-W4V=0``````````.'4`````````````````````````
M``````!),@``5%--2@``;T!85C!2/T$``'`]````````````````````````
M```J.```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````>#P`````````
M`````````````````````````````````````````````````````````$9V
M````````````````````````````````````````````````````````````
M``````````````````````!'=@``````````````````````````````````
M````````````````````````````````2'8`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!)=@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````2G8`````````````
M````````````````````````````````````````````````````````````
M``````````````````````!,=@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M2W8`````````````````````````````:7<`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$UV````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$YV````````````````````````````````````````````````
M``````````````````!$;D5N1FYK520V2&Y';DEN2FXE1TMN3&X``#`W=C5-
M;D]N``!.;@``1CA0;E%N4FY;-BXS4U9&1#4Q5CA3;E1N/U151WL^64XS.59N
M56Y8;E=N)459;EIN+D=;;B]'7&XG,EUN7FY?;F!N86YJ5V)N8VY8/&1N2U-Z
M3"PR94%E;B9'+4,``&9N9VYH;FEN:FYK;FQN``!M;FYN;VX`````<&YQ;G)N
M=&YS;@``=6XM34%"=FYW;GAN(55Y;C-/>FY[;@``?&Y];B%O?FXB;W4X>D,C
M;R1O0CT_4GDR)6\F;R=O>%(H;WU6*6],1@``*F\K;S1!+&]Z3WA++F\M;WHS
M>#DO;S!O8E`Q;S)O9C<_4#-O-&\U;W%(8$PV;S=O.&\Y;SIO8%4[;VTT*D,\
M;P``/6\^;S]O``!]3D!O8$(X-#97=3T``$=/0V]!;T)O1&\G-GP\8CY,0T5O
M1F\``$=O3V](;TEO2F]"1W%O339+;P``3&]-;T8V/D-.;P``4&]1;U)O<E4`
M`%-O=T0``%1O>$15;U9O9#AW,%=O6&]9;P``6F];;UQO76\``%YO-3YA;U]O
M8&\``&)O8V]-061O96]F;V=O:&]I;VIO:V]L;UA```!M;RU!;F]O;W!O````
M`&)/`````````````````````"0S````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$5#16-!249C``!5,4I.,S1R2$=C4$](8V0\26-*8T9#(E561&LY14Y+
M8W9#3&,``"<W<SA2.DUC3F-$5$]C``!08TM146-28U-C5&-6455C>S([0%9C
M```K0%=C6&-98P``6F-;8P``-SAB6@``4S8``&1:8UH`````````````````
M`&9:````````;D@`````95I`-W11=5)S55<]``````````!H5VA:9UH``"(P
M4TT``&E:```].$H\/4(D0D(S:EH``"I",$0U/0````!>3P```````&M:0DD`
M````````````73$```````!L6@``.#8Z5```?3,`````;5I)5%5/8T4``&Y:
M`````````````&]:``!P6FI!54Q=3P``````````````````````````````
M````9U,A0@``<5H`````94L``'):``!F2WY2````````=#@`````<UHO,#9/
M`````$]5``````````````````````````!M2P````````````````````!T
M6@````!$8P`````E00`````_=@````!`=D%V440``#A(8U$`````6U!%42\\
M33D``'1O`````$8T.E-"=GLS`````$-V`````'$U````````````````````
M``````!%=@``````````````````:E,G=BE1```````````I=@```````"AV
M`````&-!5T```"(Q``````````!M3@``:%`K=@````!V3P``*G9P52QV.4,`
M``````!T.RYV+78```````!>1`````!800`````````````J2P``/$\`````
M````````````````````````+W8`````,'8`````,78``#9"````````````
M`%0P>44``````````#)V````````````````````````````````````````
M``````````!@1R9V`````#@^`````#(^``!E-0````!'-P``/S]20V9#````
M`$Q8````````;S@```````````````````````!Y/251``!0,```````````
M```P=P`````````````````````Q=P`````````````L4```,#`````````R
M=S-W```T=P```````$I'``````````````````!//@`````W=P``````````
M````````-G<``%XQ```U=P`````X=P``.7<`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"1.34@``"LZ.&@Y
M:#IH0CX`````````````=%(``$]46$D`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````S4B4V:D=\<6Y/,TMK4&]G9TU+.5DV?7%D,$Q+?G$D5"U";$%$1C$^
M(7)5/```(G(C<@``)')#4C5&``!'325R```Q4T4_8DP``"9R)W)546XV*'(I
M<E\U*G(K<@``?#(L<BUR)T@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````9S<`````*6PJ;"ML```L;``````N1BUL+FP```````!)-S-*````````
M```````````X8D]W````````````````````````````````````````````
M````````````````````````````````````````````````````4'<`````
M33(`````````````````````````````````````````````````````````
M````````````````````47<`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%-W4G<``````````````````````````````````#MB```B/```/&(]8CYB
M/V)`8D%B.3=[4B0]3DHE,4=+``!"8GPV1$A#8@````!(/0``?3%$8@``=C9%
M8EE$`````$9B6D]=.4=B(4```$AB=C(``$EB``!S04IB2V)X0DQB36).8E=*
M.%AE66-/`````````````````````````````"5P`````#!<````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````;4(F5%1-,5%;,WU'```U,C]"8&8[2F%F
M8F94/F-F)%=5365F73QD9F9F9V9N0@``/CUH9F9")SII9@``:F92,VE1````
M`"4_:V9O1FQF;68`````;F8M1F]F```G27!F<69R9CEE<V9T9F)"=69V9FA6
M=V8``'AF1SD``````````````````#MW.G<``````````#YW/'<A.@``/W<`
M`$!W````````0G=!=T1W`````$-W`````````````$5W1G<``````````$=W
M``!H2P``````````7S@```````````````!4=P``57<``````````%9W````
M``````!8=P``6G<``%=W````````````````````````6W<``%EW````````
M``````````!75P``````````7'<```````````````!==P```````%YW````
M`````````````````````````%]W````````8'<`````````````````````
M````````2UL`````*E@`````````````````````=V5M.0``````````?3]J
M.TEW1T9(=P``2G=,=TMW````````37<``#I.``!.=P`````G1&4B9B)G(F@B
M:2)J(FLB;")M(FXB```A(2(A(R$H(0``*2$`````-"$U(38A-R$X(3DA.B$[
M(3XA/R$``'XA,B$S(3PA/2$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(20B)",D)"0E)"8D)R0H)"DD*B0K)"PD+20N)"\D,"0Q)#(D
M,R0T)#4D-B0W)#@D.20Z)#LD/"0])#XD/R1`)$$D0B1#)$0D121&)$<D2"1)
M)$HD2R1,)$TD3B1/)%`D4212)%,D5"15)%8D5R18)%DD6B1;)%PD721>)%\D
M8"1A)&(D8R1D)&4D9B1G)&@D:21J)&LD;"1M)&XD;R1P)'$D<B1S)```````
M````````````````````````````(24B)2,E)"4E)28E)R4H)2DE*B4K)2PE
M+24N)2\E,"4Q)3(E,R4T)34E-B4W)3@E.24Z)3LE/"4])3XE/R5`)4$E0B5#
M)40E125&)4<E2"5))4HE2R5,)4TE3B5/)5`E4252)5,E5"55)58E5R58)5DE
M6B5;)5PE725>)5\E8"5A)6(E8R5D)64E9B5G)6@E:25J)6LE;"5M)6XE;R5P
M)7$E<B5S)70E=25V)0``````````)"$```````````````````````!%*$8H
M1RA(*$DH2BA+*$PH32A.*$\H4"A1*%(H4RA4*%4H5BA7*%@H62A:*%LH7"A=
M*%XH7RA@*&$H8BAC*&0H92AF*&<H:"AI*````````````````%DB6B);(EPB
M72)>(E\B8")A(F(B``````````````````````````!%(D8B1R)((DDB2B)+
M(DPB32).(D\B4")1(E(B4R)4(E4B5B)7(E@B,2(R(C,B-"(U(C8B-R(X(CDB
M.B([(CPB/2(^(C\B0")!(D(B0R)$(@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````)"DE
M*28I)RDH*2DI*BDK*2PI+2DN*2\I,"DQ*3(I,RDT*34I-BDW*3@I.2DZ*3LI
M/"D]*3XI/RE`*4$I0BE#*40I12E&*4<I2"E)*4HI2RE,*4TI3BE/*5`I42E2
M*5,I5"E5*58I5RE8*5DI6BE;*5PI72E>*5\I8"EA*6(I8RED*64I9BEG*6@I
M:2EJ*6LI;"EM*6XI;RD`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!V(74A``````````````````````````````````````````!X(7<A````
M````````````````````````````````````````````="%S(0```````'`A
M`````'(A<2$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````;R%N(0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````&(A``!A(0``````````````````````````````````*B$L(0``
M+B$O(0`````P(3$A`````````````````````"TA````````````````````
M````:R$``&0A92$``````````````````'DA````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!F(0``````````````````````````````
M`````````````````&TA````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!Q(G(B<R)T(G4B=B)W(G@B>2)Z
M(GLB?"(`````````````````````````````````````````````````````
M``````````````````````````````````````````![(7PA>B%](0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!*(0```````````````$<A``!&(0````````````````````!,(0````!8
M(5XA``!/(0``````````3B$``$0A12%)(4@A4B$`````4R$`````````````
M8"%?(4,A2R$`````````````5R$``````````````````````````%8A````
M````52$``````````````````````````````````````````````````%DA
M5"$`````7"%=(0````````````````````!:(5LA````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````%$A````````````````````````````
M`$TA````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````4"$`````
M)B$``"4A````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M)B(F(R8D)B4F)B8G)B@F*28J)BLF+"8M)BXF+R8P)C$F```R)C,F-"8U)C8F
M-R8X)@``````````````````029")D,F1"9%)D8F1R9()DDF2B9+)DPF329.
M)D\F4"91)@``4B93)E0F5296)E<F6"8`````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"<G
M`````````````````````````````````````"$G(B<C)R0G)2<F)R@G*2<J
M)RLG+"<M)RXG+R<P)S$G,B<S)S0G-2<V)S<G."<Y)SHG.R<\)STG/B<_)T`G
M02=1)U(G4R=4)U4G5B=8)UDG6B=;)UPG72=>)U\G8"=A)V(G8R=D)V4G9B=G
M)V@G:2=J)VLG;"=M)VXG;R=P)W$G``!7)P````````````!H(0````!L(2<A
M``````````````````!C(4`A````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!!(0`````````````````````D*"(H````````````````*"@F*#HH```L
M*"HH```````````P*"XH````````0B$``#0H,B@``#DH```````````A*```
M```````````````````````````````````````````E*```````````````
M````)R@````````````````````````````````````````I*```````````
M````````````````````````````````````````````````````````````
M`````````````````"TH````````````````````````````````````````
M`````````````````````````````````````#$H````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",H```K*```+R@``#,H```U*```-B@``#<H```X*```````````````````
M2E4_EL-7*&/.5`E5P%21=DQV/(7N=WZ"C7@Q<IB6C9<H;(E;^D\)8Y=FN%SZ
M@$AHKH`"9LYV^5%69:QQ\7^$B+)095G*8;-OK8),8U)B[5,G5`9[:U&D=?1=
MU&++C7:7BF(9@%U7.)=B?SAR?7;/9WYV1F1P3R6-W&(7>I%E[7,L9'-B+(*!
MF']G2')N8LQB-$_C=$I3GE+*?J:0+EZ&:)QI@('1?M)HQ7B,AE&5C5`DC-Z"
MWH`%4Q*)95(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"$A?F6W4\A6'&9G5NQ8J5BM&9YC(V<!G)O9Y%X
MLF!14Q=3B(_,@!V-H90-4,AR!UGK8!EQJXA46>^"+&<H>RE=]WXM=?5L9H[X
MCSR0.Y_4:QF1%'M\7Z=XUH0]A=5KV6O6:P%>AU[Y=>V5764*7\5?GX_!6,*!
M?Y!;EJV7N8\6?RR-06*_3]A37E.HCZF/JX]-D`=H:E^8@6B(UIR+82M2*G9L
M7XQETF_H;KY;2&1U4;!1Q&<93LEY?)FS<```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````,5U=EZ[<^"#K63H
M8K64XFQ:4\-2#V3"E)1[+T\;7C:"%H&*@21NRFQSFE5C7%/Z5&6(X%<-3@->
M96L_?.B0%F#F9!QSP8A09TUB(HUL=RF.QY%I7]R#(840F<)3E8:+:^U@Z&!_
M<,V",8+33J=LSX7-9-E\_6GY9DF#E5-6>Z=/C%%+;4)<;8[28\E3+(,V@^5G
MM'@]9-];E%SN7>>+QF+T9WJ,`&2Z8TF'BYD7C"!_\I2G3A"6I)@,9A9S````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````.E<=7#A>?Y5_4*"`@E->945U,54A4(6-A&*>E!UG,E9N;^)=-522
M<&:/;V*D9*-C>U^(;_20XX&PCQA<:&;Q7XEL2):!C6R(D63P><Y766H08DA4
M6$X+>NE@A&_:BW]B'I"+FN1Y`U3T=0%C&5-@;-^/&U]PFCN`?Y^(3SI<9(W%
M?Z5EO7!%4;)1:X8'7:!;O6)LD71U#(X@>@%A>7O'3OA^A7<13NV!'5+Z47%J
MJ%.'C@25SY;!;F266FD`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!`>*A0UW<09.:)!%GC8]U=?WH]:2!/
M.8*853).KG67>F)>BE[OE1M2.52*<'9C))6"5R5F/VF'D0=5\VVO?B*(,V+P
M?K5U*(/!>,R6GH](8?=TS8MD:SI24(TA:VJ`<83Q5@93SDX;3M%1EWR+D0=\
MPT]_CN%[G'IG9!1=K%`&@0%VN7SL;>!_46=86_A;RWBN9!-DJF,K8QF5+62^
MCU1[*7938B=91E1Y:Z-0-&(F7H9KXTXWC8N(A5\ND```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"!@/8#%
M8CE.55/XD+ACQH#F92YL1D_N8.%MWHLY7\N&4U\A8UI188-C:`!28V-(CA)0
MFUQW>?Q;,%([>KQ@4Y#7=K=?EU^$=FR.;W![=DE[JG?S49.0)%A.3_1NZH],
M91M[Q'*D;=]_X5JU8I5>,%>"A"Q['5X?7Q*0%'^@F()CQVZ8>+EP>%%;EZM7
M-75#3SAUEU[F8&!9P&V_:XEX_%/5ELM1`5*)8PI4DY0#C,R-.7*?>':'[8\-
MC.!3````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````4[O=NY3B91VF`Z?+96:6Z*+(DX<3JQ18X3"8:A2"VB7
M3VM@NU$>;5Q1EF*796&61HP7D-AU_9!C=])KBG+L<ON+-5AY=TR-7&=`E9J`
MIEXA;I)9[WKM=SN5M6NM90Y_!EA141^6^5NI6"A4<HYF97^8Y%:=E/YV09"'
M8\94&EDZ69M7LHXU9_J--8)!4O!@%5C^ANA<19[$3YV8N8LE6G9@A%-\8D^0
M`I%_F6E@#(`_43.`%%QUF3%MC$X`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````PC=%36G]/>Q!/3TX`EM5L
MT'/IA09>:G7[?PIJ_G>2E$%^X5'F<,U3U(\#@RF-KW)MF=ML2E>S@KEEJH`_
M8C*6J%G_3K^+NGX^9?*#7I=A5=Z8I8`J4_V+(%2Z@)]>N&PYC:R"6I$I5!ML
M!E*W?E]7&G%^;(E\2UG]3O]?)&&J?#!.`5RK9P*'\%P+E<Z8KW7]<"*0KU$=
M?[V+25GD45M/)E0K67=EI(!U6W9BPF*0CT5>'VPF>P]/V$\-9P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`&YMJFV/>;&(%U\K=9IBA8_O3]R1IV4O@5&!G%Y0@72-;U*&B4N-#5F%4-A.
M')8V<GF!'XW,6Z.+1):'61I_D%1V5@Y6Y8LY98)IF936=HEN<EX8=49GT6?_
M>IV`=HT?8<9Y8F5CC8A1&E*BE#A_FX"R?I=<+VY@9]E[BW;8FH^!E'_5?!YD
M4)4_>DI4Y51,:P%D"&(]GO.`F75R4FF76X0\:.2&`9:4ENR4*DX$5-E^.6C?
MC16`]&::7KE_````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````PE<_@)=HY5T[99]2;6":GYM/K(YL4:M;$U_I
M75YL\6(AC7%1J93^4I]LWX+7<J)7A&<MC1]9G(_'@Y54C7LP3[UL9%O161.?
MY%/*AJB:-XRA@$5E?ICZ5L>6+E+<=%!2X5L"8P*)5D[08BI@^FAS49A;H%'"
MB:%[AIE0?^]@3'`OC4E1?UX;D'!TQ(DM5T5X4E^?G_J5:(\\F^&+>'9":-QG
MZHTUC3U2BH_:;LUH!97MD/U6G&?YB,>/R%0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"XFFE;=VTF;*5.
MLUN'FF.1J&&OD.F7*U2U;=);_5&*555_\'^\9$UC\66^88U@"G%7;$EL+UEM
M9RJ"U5B.5FJ,ZVO=D'U9%X#W4VEM=52=57>#SX,X:+YYC%153PA4TG:)C`*6
MLVRX;6N-$(EDGCJ-/U;1GM5UB%_@<FA@_%2H3BIJ88A28'"/Q%38<'F&/YXJ
M;8];&%^B?HE5KT\T<SQ4FE,94`Y4?%1.3OU?6G3V6&N$X8!TA]!RRGQ6;@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"=?3H8L5:1BDDZJ;#=BL8+75$Y3/G/1;CMU$E(64]V+T&F*7P!@
M[FU/5R)KKW-3:-B/$W]B8Z-@)%7J=6*,%7&C;:9;>UY2@TQAQ)[Z>%>')WR'
M=O!1]F!,<4-F3%Y-8`Z,<'`E8XF/O5]B8-2&WE;!:Y1@9V%)4^!@9F8_C?UY
M&D_I<$=LLXORB]A^9(,/9EI:0IM1;?=M08P[;1E/:W"W@Q9BT6`-ER>->'G[
M43Y7^E<Z9WAU/7KO>95[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````C(!EF?F/P&^EBR&>[%GI?@E_"52!
M9]AHD8]-?,:6RE,E8+YU<FQS4\E:IWXD8^!1"H'Q7=^$@&*`46-;#D]M>4)2
MN&!.;<1;PENAB["+XF7,7T66DUGG?JI^"5:W9SE9<T^V6Z!26H.*F#Z-,G6^
ME$=0/'KW3K9G?IK!6GQKT79:5Q9<.GOTE4YQ?%&I@'"">%D$?R>#P&CL9[%X
M=WCC8F%C@'OM3VI2SU%0@]MI=)+UC3&-P8DNE:U[]DX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!E4#""
M45)OF1!NA6ZG;?I>]5#<609<1FU?;(9UBX1H:%99LHL@4W&1399)A1)I`7DF
M<?:`I$[*D$=MA)H'6KQ6!63PE.MWI4\:@>%RTHEZF31_WGY_4EEE=9%_CX./
MZU.6>NUCI6.&=OAY5X@VEBIBJU*"@E1H<&=W8VMW[7H!;=-^XXG061)BR86E
M@DQU'U#+3J5UZXM*7/Y=2WND9=&1RDXE;5^))WTFE<5.*(S;CW.72V:!>=&/
M['!X;0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#U<LE)&@V)1#H-;=W9FN)RL3LI@OGRS?,]^E4YFBV]F
MB)A9EX-8;&5<E81?R756E]]ZWGK`4:]PF'KJ8W9ZH'Z6<^V714YX<%U.4I&I
M4U%EYV7\@06"CE0Q7)IUH)?88MERO75%7'F:RH-`7(!4Z7<^3JYL6H#28FYC
MZ%UW4=V-'HXOE?%/Y5/G8*QP9U)08T.>'UHF4#=W=U/B?H5D*V6)8IAC%%`U
M<LF)LU'`B]U^1U?,@Z>4FU$;5/M<````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````RD_C>EIMX9"/FH!5EE1A
M4Z]4`%_I8W=I[U%H80I2*EC84DY7#7@+=[=>=V'@?%MBEV*B3I5P`X#W8N1P
M8)=W5]N"[V?U:-5XEYC1>?-8LU3O4S1N2U$[4J);_HNO@$-5IE=S8%%7+51Z
M>E!@5%NG8Z!BXU-C8L=;KV?M5)]ZYH)WD9->Y(@X6:Y7#F/HC>^`5U=W>ZE/
MZU^]6SYK(5-0>\)R1FC_=S9W]V6U48].U':_7*5Z=81.64&;@%``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"(F2=A@VYD5P9F1F/P5NQB:6+37A26@U?)8H=5(8=*@:./9E6Q@V5G5HW=
MA&I:#VCF8NY[$99P49QO,(S]8\B)TF$&?\)PY6X%=)1I_'+*7LZ0%V=J;5YC
MLU)B<@&`;$_E66J1V7"=;=)24$[WEFV5?H7*>"]](5&25\)DBX![?.IL\6A>
M:;=1F%.H:(%RSI[Q>_ARNWD3;P9T3F?,D:2</'F)@U2##U07:#U.B5.Q4CYX
MAE,I4HA0BT_03P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````.)URWJ2?*5LMI:;4H-TZ53I3U2`LH/>CW"5
MR5X<8)]M&%Y;93B!_I1+8+QPPWZN?,E1@6BQ?&^")$Z&C\^1?F:N3@6,J61*
M@-I0EW7.<>5;O8]F;X9.@F1CE=9>F6474L*(R'"C4@YS,W279_=X%I<T3KN0
MWIS+;=M108T=5,YBLG/Q@_:6A)_#E#9/FG_,475P=9:M7(:8YE/D3IQN"72T
M:6MXCYE9=1A2)'9!;?-G;5&9GTN`F50\>[]Z````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````AI:$5^)B1Y9\
M:01:`F33>P]O2Y:F@F)3A9B07HEPLV-D4T^&@9R3GHQX,I?OC4*-?YY>;X1Y
M55]&EBYB=)H55-V4HT_%965<85P5?U&&+VR+7X=SY&[_?N9<&V-J6^9N=5-Q
M3J!C976A8FZ/)D_13J9LMGZZBQV$NH=7?SN0(Y6I>Z&:^(@]A!MMAIK<?HA9
MNYZ;<P%X@H9LFH*:&U875,M7<$ZFGE93R(\)@9)WDIGNAN%N$X7\9F)A*V\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````IC)*"*X/R=A-LV5^]@RMS!8,:E=MKVW?&E&]3`H.243U>C(PX
MC4A.JW.:9X5H=I$)EV1QH6P)=Y):097/:XY_)V;06[E9FEKHE?>5[$X,A)F$
MK&K?=C"5&W.F:%];+W>:D6&7W'SWCQR,)5]S?-AYQ8G,;!R'QEM"7LEH('?U
M?I5135')4BE:!7]BE]>"SV.$=]"%TGDZ;IE>F5D1A6UP$6R_8K]V3V6O8/V5
M#F:?AR.>[90-5'U4+(QX9```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'ED$88A:IR!Z'AI9%2;N6(K9ZN#
MJ%C8GJML(&_>6TR6"XQ?<M!GQV)A<JE.QEG-:Y-8KF957M]256$H9^YV9G=G
M<D9Z_V+J5%!4H)2CD!Q:LWX6;$-.=ED0@$A95U,W=;Z6RE8@8Q&!?&#YE=9M
M8E2!F851Z5K]@*Y9$Y<J4.5L/%S?8F!//U-[@0:0NFXKA<AB=%Z^>+5D>V/U
M7QA:?Y$?GC]<3V-"@'U;;E5*E4V5A6VH8.!GWG+=48%;````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````YV+>
M;%MR;6*NE+U^$X%3;9Q1!%]T6:I2$F!S699F4(:?=2ICYF'O?/J+YE0G:R6>
MM&O5A554=E"D;&I5M(TL<A5>%6`V=,UBDF-,<IA?0VX^;0!E6&_8=M!X_'94
M=212VU-33IY>P64J@-:`FV*&5"A2KG"-B-&-X6QX5-J`^5?TB%2-:I9-D6E/
MFVRW5<9V,'BH8OEPCF]M7^R$VFA\>/=[J($+9T^>9V.P>&]7$G@YEWEBJV*(
M4C5TUVL`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!D53Z!LG6N=CE3WG7[4$%<;(O'>T]01W*7FMB8`F_B
M=&AYAV2E=_QBD9@KC<%46(!23FI7^8(-A'->[5'V=,2+3UQA5_QLAYA&6C1X
M1)OKCY5\5E)18OJ4QDZ&@V&$Z8.RA-17-&<#5VYF9FTQC-UF$7`?9SIK%F@:
M8KM9`T[$409OTF>/;'91RVA'66=K9G4.71"!4)_794AY07F1FG>-@EQ>3@%/
M+U1160QX:%84;,2/`U]];.-LJXN08P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'!@/6UU<F9BCI3%E$-3
MP8]^>]].)HQ^3M2>L92SE$U27&]CD$5M-(P16$Q=(&M):ZIG6U14@8Q_F5@W
MA3I?HF)':CF5<F6$8&5HIW=43JA/YUV8EZQDV'_M7,]/C7H'4@2#%$XO8(-Z
MII2U3[).YGDT=.12N8+29+UYW5N!;%*7>X\B;#Y0?U,%;LYD=&8P;,5@=YCW
MBX9>/'1W>LMY&$ZQD`-T0FS:5DN1Q6R+C3I3QH;R9J^.2%QQFB!N````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````UE,V6HN?HXV[4PA7IYA#9YN1R6QH4<IU\V*L<CA2G5(Z?Y1P.'9T4TJ>
MMVEN>,"6V8BD?S9QPW&)4=-GY'3D6!AEMU:IBW:9<&+5?OE@[7#L6,%.ND[-
M7^>7^TZDBP-2BEFK?E1BS4[E90YB.(/)A&.#C8>4<;9NN5O2?I=1R6/49XF`
M.8,5B!)1>EN"6;&/<TY=;&51)8EOCRZ62H5>=!"5\)6F;>6",5^29!)M*(1N
M@<.<7EA;C0E.P5,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````>3V-E46C352=.%&2:FFMBPEI?='*"J6WN
M:.=0CH,">$!G.5*9;+%^NU!E55YQ6WM29LISZX))9W%<(%)]<6N(ZI55EL5D
M88VS@81556Q'8BY_DE@D3T953XU,9@I.&ESSB*)H3F,->N=PC8+Z4O:7$5SH
M5+60S7YB64J-QX8,@@V"9HU$9`1<46&);3YYOHLW>#-U>U0X3ZN.\6T@6L5^
M7GF(;*%;=EH:=;Z`3F$7;O!8'W4E=7)R1U/S?@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````%WVW9I4MR`
M(U<(7C%9[G*]97]NUXLX7'&&05/S=_YB]F7`3M^8@(:>6\:+\E/B=W]/3EQV
MFLM9#U\Z>>M8%D[_9XM.[6*3BAV0OU(O9MQ5;%8"D-5.C4_*D7"9#VP"7D-@
MI%O&B=6+-F5+8I:9B%O_6XAC+E774R9V?5$LA:)GLVB*:Y)BDX_44Q*"T6V/
M=69.3HUP6Y]QKX619MEF<G\`A\V>()]>7"]G\(\1:%]G#6+6>H58MEYP93%O
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````56`W4@V`5&1PB"EU!5X3:/1B')?,4SUR`8PT;&%W#GHN5*QW
M>I@<@O2+57@49\%PKV659#96'6#!>?A3'4Y[:X:`^EOC5=M6.D\\3W*9\UU^
M9SB``F""F`&0BUN\B_6+'&18@MYD_57/@F61UT\@?1^0GWSS4%%8KVZ_6\F+
M@X!XD9R$EWM]AHN6CY;E?M.:CGB!7%=Z0I"GEE]Y65M?8PM[T82M:`95*7\0
M=")]`95`8DQ8UDZ#6WE95%@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!M<QYC2XX/CLZ`U(*L8O!3\&Q>
MD2I9`6!P;$U72F0JC2MVZ6Y;5X!J\'5M;RV,"(QF5^]KDHBS>*)C^5.M<&1L
M6%@J9`)8X&B;@1!5UGP84+J.S&V?C>MPCV.;;=1NYGX$A$-H`Y#8;7:6J(M7
M67ERY(5^@;QUBHJO:%12(HX1E=!CF)A$CGQ54T__9H]6U6"5;4-225PI6?MM
M:U@P=1QU;&`4@D:!$6-A9^*/.G?SC32-P9067H53+%3#<```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$!L
M]UY<4*U.K5XZ8T>"&I!0:&Z1LW<,5-R49%_E>G9H16-2>]]^VW5W4)5B-%D/
MD/A1PWF!>OY6DE\4D()M8%P?5Q!45%%-;N)6J&.3F'^!%8<JB0"0'E1O7,"!
MUF)88C&!-9Y`EFZ:?)HM::59TV(^519CQU39ACQM`UKF=)R(:FL664R,+U]^
M;JES?9@X3O=PC%N7>#UC6F:6=LM@FUM)6@=.58%J;(MSH4Z)9U%_@%_Z91MG
MV%^$60%:````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````S5VN7W%3YI?=CT5H]%8O5=]@.DY-;_1^QX(.A-19
M'T\J3SY<K'XJ9QJ%<U1/=<.`@E5/FTU/+6X3C`E<<&%K4Q]V*6Z*AH=E^Y6Y
M?CM4,WH*?>Z5X57!?^YT'6,7AZ%MG7H18J%E9U/A8X-LZUU<5*B43$YA;.R+
M2US@99R"IV@^5#14RVMF:Y1.0F-(4QZ"#4^N3UY7"F+^EF1F:7+_4J%2GV#O
MBQ1FF7&09W^)4GC]=W!F.U8X5"&5>G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````>F]@#%Z)8)V!%5G<
M8(1Q[W"J;E!L@'*$:JV(+5Y@3K-:G%7CE!=M^WR9E@]BQGZ.=WZ&(U,>EY:/
MAV;A7*!/[7(+3J93#UD35(!C*)5(4=E.G)RD?KA4)(U4B#>"\I6.;29?S%H^
M9FF6L',N<[]3>H&%F:%_JEMWEE"6OW[X=J)3=I69F;%[1(E8;F%.U']E>>:+
M\V#-5*M.>9CW76%JSU`15&&,)X1=>`272E+N5*-6`)6(;;5;QFU39@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````]<75LA:):`>%41>TAE5&F;3D=K3H>+ET]3'V,Z9*J0G&7!@!",F5&P
M:'A3^8?(8<1L^VPBC%%<JH6O@@R5(VN;C[!E^U_#7^%/18@?9F6!*7/Z8'11
M$5*+5V)?HI!,B)*1>%Y/9R=@TUE$4?91^(`(4WELQ):*<1%/[D^>?SUGQ54(
ME<!YEHCC?I]8#&(`EUJ&&%9[F)!?N(O$A%>1V5/M98]>7'5D8&Y]?UKJ?NU^
M:8^G5:-;K&#+981S````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````"9!C=BEWVGYTEYN%9EMT>NJ60(C+4H]Q
MJE_L9>*+^UMOFN%=B6M;;*V+KXL*D,6/BU.\8B:>+9Y`5"M.O8)9<IR&%EU9
MB*]MQ9;15)I.MHL)<;U4"9;?</EMT'8E3A1X$H>I7/9>`(J<F`Z6CG"_;$19
MJ6,\=TV(%&]S@C!8U7&,4QIXP98!569?,'&T6QJ,C)J#:RY9+Y[G>6AG;&)O
M3Z%UBG\+;3.6)VSP3M)U>U$W:#YO@)!P@999=G0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'9"=<99"1
M>B.,VEFL5`"";X.!B0"`,&E.5C:`-W+.D;917TYUF)9C&D[V4_-F2X$<6;)M
M`$[Y6#M3UF/QE)U/"D]CB)"8-UE7D/MYZD[P@)%U@FR<6^A975\%:8&&&E#R
M75E.XW?E3GJ"D6(39I&0>5R_3GE?QH$XD(2`JW6F3M2(#V'%:\9?24[*=J)N
MXXNNBPJ,T8L"7_Q_S'_.?C6#:X/@5K=K\Y<TEOM9'U3VE.MMQ5MNF3E<%5^0
ME@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'!3\8(Q:G1:<)Z47BA_N8,DA"6$9X-'A\Z/8HW(=G%?EIAL
M>"!FWU3E8F-/PX'(=;A>S98*COF&CU3S;(QM.&Q_8,=2*'5]7AA/H&#G7R1<
M,76ND,"4N7*Y;#AN29$)9\M3\U-13\F1\8O(4WQ>PH_D;8Y.PG:&:5Z&&F$&
M@EE/WD\^D'R<"6$=;A1NA9:(3C%:Z)8.3G]<N7F'6^V+O7^)<]]7BX+!D`%4
M1Y"[5>I<H5\(83)K\7*R@(F*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=&W36]6(A)AKC&V:,YX*;J11
M0U&C5X&(GU/T8Y6/[5985`97/W.0;AA_W(_1@C]A*&!BEO!FIGZ*C<.-I92S
M7*1\"&>F8`66&("13N>0`%-HED%1T(]TA5V156;UEU5;'5,X>$)G/6C)5'YP
ML%M]CXU1*%>Q5!)E@F9>C4.-#X%LA&V0WWS_4?N%HV?I9:%OI(:!CFI6()""
M=G9PY7$CC>EB&5+];#R-#F">6(YA_F9@C4YBLU4C;BUG9X\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#A
ME/B5*'<%:*AIBU1-3KAPR(M89(MEA5N$>CI0Z%N[=^%K>8J8?+YLSW:I99>/
M+5U57#B&"&A@4QABV7I;;OU^'VK@>G!?,V\@7XQCJ&U69PA.$%XFC==.P(`T
M=IR6VV(M9GYBO&QUC6=Q:7]&48>`[%-ND)AB\E3PAIF/!8`7E1>%V8]9;<US
MGV4?=P1U)WC[@1Z-B)2F3Y5GN77*BP>7+V-'E366N(0C8T%W@5_P<HE.%&!T
M9>]B8VL_90``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"=>QW71D,&+G8*=9R]E,508A^5WHH`"@4%L2T['
M?DR`]'8-:99K9V(\4(1/0%<'8V)KOHWJ4^AEN'[77QICMV/S@?2!;G\<7ME<
M-E)Z9NEY&GHHC9EPU'7>;KMLDGHM3L5VX%^?E'>(R'[->;^`S9'R3A=/'X)H
M5-Y=,FW,BZ5\=(^8@!I>DE2Q=IE;/&:DFN!S*FC;AC%G*G/XB]N+$)#Y>MMP
M;G'$8JEW,58[3E>$\6>I4L"&+HWXE%%[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````3T_H;%UY>YJ38BIR
M_6(33A9X;(^P9%J-QGMI:(1>Q8B&69YD[EBV<@YI)97]CUB-8%<`?P:,QE%)
M8]EB4U-,:")T`8-,D4150'=\<$IM>5&H5$2-_UG+;L1M7%LK?=1.?7S3;E!;
MZH$-;E=;`YO5:"J.EUO\?CM@M7ZYD'"-3UG-8]]YLXU24\]E5GG%BSN6Q'Z[
ME()^-%:)D0!G:G\*7'60*&;F75!/WF=:4%Q/4%>G7@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"-3@Q.0%$03O]>15,53IA.'DXRFVQ;:58H3KIY/TX54T=.+5D[<FY3
M$&S?5N2`EYG3:WYW%Y\V3I].$)]<3FE.DTZ(@EM;;%4/5L1.C5.=4Z-3I5.N
M4V6778T:4_53)E,N4SY37(UF4V-3`E((4@Y2+5(S4C]20%),4EY285)<4J^$
M?5*"4H%2D%*34H)15'^[3L-.R4["3NA.X4[K3MY.&T_S3B)/9$_U3B5/)T\)
M3RM/7D]G3SAE6D]=3P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````%]/5T\R3SU/=D]T3Y%/B4^#3X]/?D][
M3ZI/?$^L3Y1/YD_H3^I/Q4_:3^-/W$_13]]/^$\I4$Q0\T\L4`]0+E`M4/Y/
M'%`,4"50*%!^4$-055!(4$Y0;%![4*50IU"I4+I0UE`&4>U0[%#F4.Y0!U$+
M4=U./6Q83V5/SD^@GT9L='QN4?U=R9Z8F8%1%%GY4@U3!XH04^M1&5E54:!.
M5E&S3FZ(I(BU3A2!THB`>31;`XBX?ZM1L5&]4;Q1````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````QU&64:)1
MI5&@BZ:+IXNJB[2+M8NWB\*+PXO+B\^+SHO2B].+U(O6B]B+V8O<B]^+X(OD
MB^B+Z8ONB_"+\XOVB_F+_(O_BP",`HP$C`>,#(P/C!&,$HP4C!6,%HP9C!N,
M&(P=C!^,((PAC"6,)XPJC"N,+HPOC#*,,XPUC#:,:5-Z4QV6(I8AEC&6*I8]
MECR60I9)EE267Y9GEFR6<I9TEHB6C9:7EK"6EY";D)V0F9"LD*&0M)"SD+:0
MNI``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"XD+"0SY#%D+Z0T)#$D,>0TY#FD.*0W)#7D-N0ZY#OD/Z0
M!)$BD1Z1(Y$QD2^1.9%#D4:1#5)"6:)2K%*M4KY2_U304M92\%+?4^YQS7?T
M7O51_%$OF[93`5]:=>]=3%>I5Z%7?EB\6,58T5@I5RQ7*E<S5SE7+E<O5UQ7
M.U="5VE7A5=K5X97?%=[5VA7;5=V5W-7K5>D5XQ7LE?/5Z=7M%>35Z!7U5?8
M5]I7V5?25[A7]%?O5_A7Y%?=5P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````M8#5C]5^U7`%@>6!E81%@@
M6&58;%B!6(E8FEB`6*B9&9__87F"?8)_@H^"BH*H@H2"CH*1@I>"F8*K@KB"
MOH*P@LB"RH+C@IB"MX*N@LN"S(+!@JF"M(*A@JJ"GX+$@LZ"I(+A@@F#]X+D
M@@^#!X/<@O2"TH+8@@R#^X+3@A&#&H,&@Q2#%8/@@M6"'(-1@UN#7(,(@Y*#
M/(,T@S&#FX->@R^#3X-'@T.#7X-`@Q>#8(,M@SJ#,X-F@V6#````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M:(,;@VF#;(-J@VV#;H.P@WB#LX.T@Z"#JH.3@YR#A8-\@[:#J8-]@[B#>X.8
M@YZ#J(.Z@[R#P8,!A.6#V(,'6!B$"X3=@_V#UH,<A#B$$80&A-2#WX,/A`.$
M^(/Y@^J#Q8/`@R:$\(/A@UR$481:A%F$<X2'A(B$>H2)A'B$/(1&A&F$=H2,
MA(Z$,81MA,&$S830A.:$O833A,J$OX2ZA."$H82YA+2$EX3EA..$#(4-=3B%
M\(0YA1^%.H4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!6A3N%_X3\A%F%2(5HA62%7H5ZA:)W0X5RA7N%
MI(6HA8>%CX5YA:Z%G(6%A;F%MX6PA=.%P87<A?^%)X8%ABF&%H8\AOY>"%\\
M64%9-X!565I96%D/4R)<)5PL7#1<3&)J8I]BNV+*8MIBUV+N8B)C]F(Y8TMC
M0V.M8_9C<6-Z8XYCM&-M8ZQCBF-I8ZYCO&/R8_ACX&/_8\1CWF/.8U)DQF.^
M8T5D060+9!MD(&0,9"9D(61>9(1D;6269```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'IDMV2X9)EDNF3`
M9-!DUV3D9.)D"64E92YE"U_27QEU$5]?4_%3_5/I4^A3^U,25!94!E1+5%)4
M4U145%940U0A5%=4650C5#)4@E245'=4<51D5)I4FU2$5'949E2=5-!4K53"
M5+14TE2G5*94TU345')4HU355+M4OU3,5-E4VE3<5*E4JE2D5-U4SU3>5!M5
MYU0@5?U4%%7S5")5(U4/51%5)U4J56=5CU6U54E5;55!5555/U5053Q5````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````-U565755=E5W53-5,%5<58M5TE6#5;%5N56(58%5GU5^5=95D55[
M5=]5O56^5915F57J5?=5R54?5M%5ZU7L5=15YE7=5<15[U7E5?)5\U7,5<U5
MZ%7U5>15E(\>5@A6#%8!5B16(U;^50!6)U8M5EA6.5975BQ6359B5EE67%9,
M5E16AE9D5G%6:U9[5GQ6A5:35J]6U%;75MU6X5;U5NM6^5;_5@17"E<)5QQ7
M#UX97A1>$5XQ7CM>/%X`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````W7D1>5%Y;7EY>85Z,7'I<C5R07)9<
MB%R87)E<D5R:7)Q<M5RB7+U<K%RK7+%<HUS!7+=<Q%S27.1<RUSE7`)=`UTG
M729=+ETD71Y=!ET;75A=/ETT73U=;%U;76]=75UK74M=2EUI771=@EV979U=
M<XRW7<5=<U]W7X)?AU^)7XQ?E5^97YQ?J%^M7[5?O%]BB&%?K7*P<K1RMW*X
M<L-RP7+.<LURTG+H<N]RZ7+R<O1R]W(!<_-R`W/Z<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/MR%W,3
M<R%S"G,><QUS%7,B<SES)7,L<SAS,7-0<TUS5W-@<VQS;W-^<QN")5GGF"19
M`EECF6>9:)EIF6J9:YELF729=YE]F8"9A)F'F8J9C9F0F9&9DYF4F969@%Z1
M7HM>EEZE7J!>N5ZU7KY>LUY3C=)>T5[;7NA>ZEZZ@<1?R5_67\]?`V#N7P1@
MX5_D7_Y?!6`&8.I?[5_X7QE@-6`F8!M@#V`-8"E@*V`*8#]@(6!X8'E@>V!Z
M8$)@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````:F!]8)9@FF"M8)U@@V"28(Q@FV#L8+M@L6#=8-A@QF#:
M8+1@(&$F815A(V'T8`!A#F$K84IA=6&L891AIV&W8=1A]6'=7[.6Z97KE?&5
M\Y7UE?:5_)7^E0.6!)8&E@B6"I8+E@R6#98/EA*6%986EA>6&98:EBQ./W(5
M8C5L5&Q<;$ILHVR%;)!LE&R,;&AL:6QT;'9LAFRI;-!LU&RM;/=L^&SQ;-=L
MLFS@;-9L^FSK;.YLL6S3;.]L_FP`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````Y;2=M#&U#;4AM!VT$;1EM
M#FTK;4UM+FTU;1IM3VU2;51M,VV1;6]MGFV@;5YMDVV4;5QM8&U\;6-M&F['
M;<5MWFT.;K]MX&T1;N9MW6W9;19NJVT,;JYM*VYN;DYN:VZR;E]NAFY3;E1N
M,FXE;D1NWVZQ;IANX&XM;^)NI6ZG;KUNNVZW;M=NM&[/;H]NPFZ?;F)O1F]'
M;R1O%6_Y;B]O-F]+;W1O*F\);REOB6^-;XQO>&]R;WQO>F_1;P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`,EOIV^Y;[9OPF_A;^YOWF_@;^]O&G`C<!MP.7`U<$]P7G"`6X1;E5N36Z5;
MN%LO=9Z:-&3D6^Y;,(GP6T>.!XNVC]./U8_EC^Z/Y(_IC^:/\X_HCP60!)`+
MD":0$9`-D!:0(9`UD#:0+9`OD$2049!2D%"0:)!8D&*06Y"Y9G20?9""D(B0
M@Y"+D%!?5U]67UA?.URK5%!<65QQ6V-<9ER\?RI?*5\M7W2"/%\[FVY<@5F#
M68U9J5FJ6:-9````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````EUG*6:M9GEFD6=)9LEFO6==9OED%6@9:W5D(
M6N-9V%GY60Q:"5HR6C1:$5HC6A-:0%IG6DI:55H\6F):=5KL@*I:FUIW6GI:
MOEKK6K):TEK46KA:X%KC6O%:UEKF6MA:W%H)6Q=;%ELR6S=;0%L57!Q<6EME
M6W-;45M36V);=9IWFGB:>II_FGV:@)J!FH6:B)J*FI":DIJ3FI::F)J;FIR:
MG9J?FJ":HIJCFJ6:IYJ??J%^HWZE?JA^J7X`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"M?K!^OG[`?L%^
MPG[)?LM^S'[0?M1^UW[;?N!^X7[H?NM^[G[O?O%^\GX-?_9^^G[[?OY^`7\"
M?P-_!W\(?PM_#'\/?Q%_$G\7?QE_''\;?Q]_(7\B?R-_)'\E?R9_)W\J?RM_
M+'\M?R]_,'\Q?S)_,W\U?WI>?W7;73YUE9".<Y%SKG.B<Y]SSW/"<]%SMW.S
M<\!SR7/(<^5SV7-\F`ITZ7/G<]YSNG/R<P]T*G1;="9T)70H=#!T+G0L=```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````!MT&G1!=%QT5W15=%ET=W1M='YTG'2.=(!T@72'=(MTGG2H=*ET
MD'2G=-)TNG3JE^N7[)=,9U-G7F=(9VEGI6>'9VIG<V>89Z=G=6>H9YYGK6>+
M9W=G?&?P9PEHV&<*:.EGL&<,:-EGM6?:9[-GW6<`:,-GN&?B9PYHP6?]9S)H
M,VA@:&%H3FAB:$1H9&B#:!UH56AF:$%H9VA`:#YH2FA):"EHM6B/:'1H=VB3
M:&MHPFAN:?QH'VD@:?EH````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````)&GP:`MI`6E7:>-H$&EQ:3EI8&E"
M:5UIA&EK:8!IF&EX:31IS&F':8AISFF):69I8VEY:9MIIVF[::MIK6G4:;%I
MP6G*:=]IE6G@:8UI_VDO:NUI%VH8:F5J\FE$:CYJH&I0:EMJ-6J.:GEJ/6HH
M:EAJ?&J1:I!JJ6J7:JMJ-W-2<X%K@FN':X1KDFN3:XUKFFN;:Z%KJFMKCVV/
M<8]RCW./=8]VCWB/=X]YCWJ/?(]^CX&/@H^$CX>/BX\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"-CXZ/
MCX^8CYJ/SHX+8A=B&V(?8B)B(6(E8B1B+&+G@>]T]'3_=`]U$743=31E[F7O
M9?!E"F899G)G`V859@!FA7#W9AUF-&8Q9C9F-68&@%]F5&9!9D]F5F9A9E=F
M=V:$9HQFIV:=9KYFVV;<9N9FZ68RC3.--HT[C3V-0(U%C4:-2(U)C4>-38U5
MC5F-QXG*B<N)S(G.B<^)T(G1B6YRGW)=<F9R;W)^<G]RA'*+<HURCW*2<@AC
M,F.P8P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#]DV&0$@.IK\VO]:_5K^6L%;`=L!FP-;!5L&&P9;!IL
M(6PI;"1L*FPR;#5E565K94UR4G)6<C!R8H864I^`G("3@+R`"F>]@+&`JX"M
M@+2`MX#G@.B`Z8#J@-N`PH#$@-F`S8#7@!!GW8#K@/&`](#M@`V!#H'R@/R`
M%6<2@5J,-H$>@2R!&($R@4B!3(%3@72!68%:@7&!8(%I@7R!?8%M@6>!35BU
M6HB!@H&1@=5NHX&J@<R!)F?*@;N!````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````P8&F@21K-VLY:T-K1FM9
M:]&8TIC3F-68V9C:F+-K0%_":_.)D&51GY-EO&7&9<1EPV7,9<YETF7698!P
MG'"6<)UPNW#`<+=PJW"Q<.APRG`0<1-Q%G$O<3%Q<W%<<6AQ17%R<4IQ>'%Z
M<9AQLW&U<:AQH''@<=1QYW'Y<1UR*')L<!AQ9G&Y<3YB/6)#8DAB26([>4!Y
M1GE)>5MY7'E3>5IY8GE7>6!Y;WEG>7IYA7F*>9IYIWFS>=%?T%\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\8%U@6F!G8$%@66!C8*M@!F$-85UAJ6&=8<MAT6$&8H"`?X"3;/9L_&WV
M=_AW`'@)>!=X&'@1>*ME+7@<>!UX.7@Z>#MX'W@\>"5X+'@C>"EX3GAM>%9X
M5W@F>%!X1WA,>&IXFWB3>)IXAWB<>*%XHWBR>+EXI7C4>-EXR7CL>/)X!7GT
M>!-Y)'D>>31YFY_YGON>_)[Q=@1W#7?Y=@=W"'<:=R)W&7<M=R9W-7<X=U!W
M47='=T-W6G=H=P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````&)W97=_=XUW?7>`=XQWD7>?=Z!WL'>U=[UW
M.G5`=4YU2W5(=5MU<G5Y=8-U6']A?U]_2(IH?W1_<7]Y?X%_?G_-=N5V,HB%
ME(:4AY2+E(J4C)2-E(^4D)24E)>4E92:E)N4G)2CE*24JY2JE*V4K)2OE+"4
MLI2TE+:4MY2XE+F4NI2\E+V4OY3$E,B4R93*E,N4S)3-E,Z4T)31E-*4U936
ME->4V938E-N4WI3?E."4XI3DE.64YY3HE.J4````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````Z93KE.Z4[Y3S
ME/24]93WE/F4_)3]E/^4`Y4"E0:5!Y4)E0J5#94.E0^5$I43E125%946E1B5
M&Y4=E1Z5'Y4BE2J5*Y4IE2R5,94RE325-I4WE3B5/)4^E3^50I4UE425195&
ME4F53)5.E4^54I53E5255I57E5B5695;E5Z57Y5=E6&58I5DE6659I5GE6B5
M:95JE6N5;)5OE7&5<I5SE3J5YW?L=\F6U7GM>>-YZWD&>D==`WH">AYZ%'H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````Y>C=Z47K/GJ69<'J(=HYVDW:9=J1VWG3@="QU()XBGBB>*9XJ
MGBN>+)XRGC&>-IXXGC>>.9XZGCZ>09Y"GD2>1IY'GDB>29Y+GDR>3IY1GE6>
M5YY:GEN>7)Y>GF.>9IYGGFB>:9YJGFN>;)YQGFV><YZ2=91UEG6@=9UUK'6C
M=;-UM'6X=<1UL76P=<-UPG76=<UUXW7H=>9UY'7K=>=U`W;Q=?QU_W40=@!V
M!78,=A=V"G8E=AAV%789=@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````!MV/'8B=B!V0'8M=C!V/W8U=D-V
M/G8S=DUV7G94=EQV5G9K=F]VRG_F>GAZ>7J`>H9ZB'J5>J9ZH'JL>JAZK7JS
M>F2(:8ARB'V(?XB"B**(QHBWB+R(R8CBB,Z(XXCEB/&(&HG\B.B(_HCPB"&)
M&8D3B1N)"HDTB2N)-HE!B6:)>XF+=>6`LG:T=MQW$H`4@!:`'(`@@"*`)8`F
M@">`*8`H@#&`"X`U@$.`1H!-@%*`:8!Q@(.)>)B`F(.8````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B9B,
MF(V8CYB4F)J8FYB>F)^8H9BBF*68IIA-AE2&;(9NAG^&>H9\AGN&J(:-AHN&
MK(:=AJ>&HX:JAI.&J8:VAL2&M8;.AK"&NH:QAJ^&R8;/AK2&Z8;QAO*&[8;S
MAM"&$X?>AO2&WX;8AM&&`X<'A_B&"(<*APV'"8<CASN''H<EARZ'&H<^ATB'
M-(<QARF'-X<_AX*'(H=]AWZ'>X=@AW"'3(=NAXN'4X=CAWR'9(=9AV6'DX>O
MAZB'TH<`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#&AXB'A8>MAY>'@X>KA^6'K(>UA[.'RX?3A[V'T8?`
MA\J'VX?JA^"'[H<6B!.(_H<*B!N((8@YB#R(-G]"?T1_17\0@OIZ_7H(>P-[
M!'L5>PI[*WL/>T=[.'LJ>QE[+GLQ>R![)7LD>S-[/GL>>UA[6GM%>W5[3'M=
M>V![;GM[>V)[<GMQ>Y![IGNG>[A[K'N=>ZA[A7NJ>YQ[HGNK>[1[T7O!>\Q[
MW7O:>^5[YGOJ>PQ\_GO\>P]\%GP+?```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````!]\*GPF?#A\07Q`?/Z!
M`8("@@2"[(%$B"&"(H(C@BV"+X(H@BN".(([@C."-((^@D2"28)+@D^"6H)?
M@FB"?HB%B(B(V(C?B%Z)G7^??Z=_KW^P?[)_?'Q)99%\G7R<?)Y\HGRR?+Q\
MO7S!?,=\S'S-?,A\Q7S7?.A\;H*H9K]_SG_5?^5_X7_F?^E_[G_S?_A\=WVF
M?:Y]1WZ;?KB>M)YSC82-E(V1C;&-9XUMC4>,28Q*D5"13I%/D621````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````8I%AD7"1:9%OD7V1?I%RD721>9&,D861D)&-D9&1HI&CD:J1K9&ND:^1
MM9&TD;J158Q^GKB-ZXT%CEF.:8ZUC;^-O(VZC<2-UHW7C=J-WHW.C<^-VXW&
MC>R-]XWXC>.-^8W[C>2-"8[]C12.'8X?CBR.+HXCCB^..HY`CCF.-8X]CC&.
M28Y!CD*.48Y2CDJ.<(YVCGR.;XYTCH6.CXZ4CI".G(Z>CGB,@HR*C(6,F(R4
MC)MEUHG>B=J)W(D`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#EB>N)[XD^BB:+4Y?IEO.6[Y8&EP&7")</
MEPZ7*I<MES"7/I>`GX.?A9^&GX>?B)^)GXJ?C)_^G@N?#9^YEKR6O9;.EM*6
MOW?@EHZ2KI+(DCZ3:I/*DX^3/I1KE'^<@IR%G(:<AYR(G"-ZBYR.G)"<D9R2
MG)2<E9R:G)N<GIR?G*"<H9RBG*.<I9RFG*><J)RIG*N<K9RNG+"<L9RRG+.<
MM)RUG+:<MYRZG+N<O)R]G,2<Q9S&G,><RIS+G```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````,R<S9S.G,^<
MT)S3G-2<U9S7G-B<V9S<G-V<WYSBG'R7A9>1EY*7E)>OEZN7HY>RE[27L9JP
MFK>:6)ZVFKJ:O)K!FL":Q9K"FLN:S)K1FD6;0YM'FTF;2)M-FU&;Z)@-F2Z9
M59E4F=^:X9KFFN^:ZYK[FNV:^9H(FP^;$YL?FR.;O9Z^GCM^@IZ'GHB>BYZ2
MGM:3G9Z?GMN>W)[=GN">WY[BGNF>YY[EGNJ>[YXBGRR?+Y\YGS>?/9\^GT2?
M`````!`$$002!!,$%`05!`$$%@07!!@$&00:!!L$'`0=!!X$'P0@!"$$(@0C
M!"0$)00F!"<$*`0I!"H$*P0L!"T$+@0O!```````````````````````````
M`````````````#`$,00R!#,$-`0U!%$$-@0W!#@$.00Z!#L$/`0]!#X$/P1`
M!$$$0@1#!$0$101&!$<$2`1)!$H$2P1,!$T$3@1/!```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````0'A`,X!X``3`>D`&P'H`"L![0#0`>P`
M30'S`-(!\@!K`?H`U`'Y`-8!V`':`=P!_`#J````````````````````````
M````!3$&,0<Q"#$),0HQ"S$,,0TQ#C$/,1`Q$3$2,1,Q%#$5,18Q%S$8,1DQ
M&C$;,1PQ'3$>,1\Q(#$A,2(Q(S$D,24Q)C$G,2@Q*3$`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M)0$E`B4#)00E!24&)0<E""4))0HE"R4,)0TE#B4/)1`E$242)1,E%"45)18E
M%R48)1DE&B4;)1PE'24>)1\E("4A)2(E(R4D)24E)B4G)2@E*24J)2LE+"4M
M)2XE+R4P)3$E,B4S)30E-24V)3<E."4Y)3HE.R4\)3TE/B4_)4`E025")4,E
M1"5%)48E1R5()4DE2B5+)0```#`!,`(P^S#)`L<"J``#,`4P%2!>_Q8@)B`8
M(!D@'"`=(!0P%3`(,`DP"C`+,`PP#3`.,`\P%C`7,!`P$3"Q`-<`]P`V(B<B
M*"(1(@\B*B(I(@@B-R(:(J4B)2(@(A(CF2(K(BXB82),(D@B/2(=(F`B;B)O
M(F0B92(>(C4B-")")D`FL``R(#,@`R$$_Z0`X/_A_S`@IP`6(08F!2;+)<\E
MSB7')<8EH26@);,ELB4[()(AD"&1(9,A$S``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(@DB22*)(LDC"2-)(XDCR20))$DDB23
M))0DE226))<DF"29))HDFR1T)'4D=B1W)'@D>21Z)'LD?"1])'XD?R2`)($D
M@B2#)(0DA22&)(<D8"1A)&(D8R1D)&4D9B1G)&@D:20`````(#(A,B(R(S(D
M,B4R)C(G,B@R*3(`````8"%A(6(A8R%D(64A9B%G(6@A:2%J(6LA````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````'_`O\#_^7_!?\&_P?_"/\)_PK_"_\,_PW_#O\/_Q#_$?\2_Q/_
M%/\5_Q;_%_\8_QG_&O\;_QS_'?\>_Q__(/\A_R+_(_\D_R7_)O\G_RC_*?\J
M_RO_+/\M_R[_+_\P_S'_,O\S_S3_-?\V_S?_./\Y_SK_._\\_SW_/O\__T#_
M0?]"_T/_1/]%_T;_1_](_TG_2O]+_TS_3?]._T__4/]1_U+_4_]4_U7_5O]7
M_UC_6?]:_UO_7/]=_^/_````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````03!",$,P1#!%,$8P1S!(,$DP2C!+
M,$PP33!.,$\P4#!1,%(P4S!4,%4P5C!7,%@P63!:,%LP7#!=,%XP7S!@,&$P
M8C!C,&0P93!F,&<P:#!I,&HP:S!L,&TP;C!O,'`P<3!R,',P=#!U,'8P=S!X
M,'DP>C![,'PP?3!^,'\P@#"!,((P@S"$,(4PAC"',(@PB3"*,(LPC#"-,(XP
MCS"0,)$PDC"3,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"A,*(P
MHS"D,*4PIC"G,*@PJ3"J,*LPK#"M,*XPKS"P,+$PLC"S,+0PM3"V,+<PN#"Y
M,+HPNS"\,+TPOC"_,,`PP3#",,,PQ##%,,8PQS#(,,DPRC#+,,PPS3#.,,\P
MT##1,-(PTS#4,-4PUC#7,-@PV3#:,-LPW##=,-XPWS#@,.$PXC#C,.0PY3#F
M,.<PZ##I,.HPZS#L,.TP[C#O,/`P\3#R,/,P]##U,/8P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````)$#D@.3`Y0#E0.6`Y<#F`.9`YH#FP.<`YT#G@.?`Z`#
MH0.C`Z0#I0.F`Z<#J`.I`P````````````````````"Q`[(#LP.T`[4#M@.W
M`[@#N0.Z`[L#O`.]`[X#OP/``\$#PP/$`\4#Q@/'`\@#R0,`````````````
M````````5P``````````````$0```#>^&`@[OA@(])L8"`````!@0AX(8$$>
M"&!`'@@``````````````````````````````````````0````$````"````
M``#_`.`_'@B`*B4(`````+3A!PCLX0<(<%P("+A<"`@<70@(@(('"%B"!PA4
MXP<(#.('",Q6"`@H5P@(A%<("-17"`C,=0<(?'T'"$Q^!P@T@@<(4'8'"-!W
M!P@H>0<(5'L'"#1]!PCTA0<(S($'"```````````````````````````````
M`````````0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G
M*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-4
M55976%E:6UQ=7E]@04)#1$5&1TA)2DM,34Y/4%%24U155E=865I[?'U^?X"!
M@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VN
MK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;
MW-W>W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_``$"`P0%!@<(
M"0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U
M-C<X.3H[/#T^/T!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>EM<75Y?8&%B
M8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/
MD)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\
MO;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CI
MZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`@("`@("`@("`H*"@H*"`@("`@("`@
M("`@("`@("`@($@0$!`0$!`0$!`0$!`0$!"$A(2$A(2$A(2$$!`0$!`0$(&!
M@8&!@0$!`0$!`0$!`0$!`0$!`0$!`0$!$!`0$!`0@H*"@H*"`@("`@("`@("
M`@("`@("`@("`@(0$!`0(```````````````````````````````````````
M``````,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,``````````````````````````````````````````!P`````
M`````````&$````WOA@(0[X8"/2;&`@`````8$(>"&!!'@A@0!X(($0>"```
M``````````````````````````````$````!`````@``````_P#@/QX(X$,>
M"`````!$W`<(V-T'",3?!PBHX`<(R%@(""18"`A@70@(Z'4'"```````````
M`````````````````````````````0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8
M&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%
M1D=(24I+3$U.3U!14E-455976%E:7%U;7E]@04)#1$5&1TA)2DM,34Y/4%%2
M4U155E=865I[?'U9?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?
MH*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,
MS<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY
M^OO\_?[_S2'%-]Q"VBR8*[\*%3E)#QDT8R8H3-\&J1^_&YP>!A:O"+E3]A9&
M'_,23DF_25A!P1\X&+U*]1C$"8Q*9#_2$\(?#!<Y&)$/!3DN+8PA02(-/I,L
MO2ZI!UQ&?T?2+R8WXBQO,J<Z#Q%P#"T(R5%.%O030"D))R9*R2#)*1PY9DQZ
M.ED[[Q0-1WHQ$$?N#.-(SD,E'_%(44Q,#?LE?1!F0&\;4#6V/QD$O@:_$JX\
M#A'M0F`02QC^$PP'.`GG",<WK#6?$3D):C(*09Y(<Q+1![D_"@XB4G(O:4S8
M#D$0AD',2?E$<1M\`^T>U2]"#<T2?BYU#")./0FD,L-&_$0#3QY#@RZ7+9I$
MR$6+4F\T4076+]%)@CJ@2?=0#A?F*?E2<@=P-(`%)U#>"S](WD^7!?)"F#3>
M.,4$0!KY%\1#E!1@$3$LX`8<&-8:<!;E-.0+)44@./(^NQ.V(UA))1:12E`K
MRT6=`YLH%!%2*5H(^@G&1E]2)C8E'8<Z^@S).T0N]!Z7'^X)W5`,5<(*^B@:
M(-`Y_3UD./<^%@<7+?9#Q3[+3'Q"M$4^%H$B:$'M25T35";$&F0?IC+6-G$O
MP4&=*[1"7$59#C\)M%&W(T\ZY1I.1"T=?08+"Q,2%D<;!?],Y40C"M8(1U'D
M!M8?<TAX#.\EAC^X(]8'?52_%'\]C3GO*BH\9`L\1:,O3C$5%&<?03MD'M@1
M8U%'5%0IKCK^),4:5@\[5#X%:4'U'P8MFP?J'-%(03==,Q9+I`EX,EPV55*8
M"S9`TTSH!A`]QD>"$IT\#T'5$$8)G#B:(5\.-P@@!?E(U1FL2.-/PPHJ1Q%,
MOD5<3[L+AA-O!<I1H2N)&ZU)J42K1I$']0\+")E03#XA!:I.:1XW0.DZVU$-
M.ZE"U$T'-HDN7DZ0'<\IA0YX/)\7;A[C08\WJS+M(-@'$0O*-B4%54332W=(
M7#R9.TA(61'I!E$<H$Z%%;('S"2E2]Y.<52J+\$Z-PO<3*1/JE2R-U4+>A]2
M%_A/R3,R1VX.MT0G*"8%>3#='D(FL"@1*DPR`D-?/&)+@@]/4Y0W)S.@'\@^
M]%0E,6XD!PDS%F$Q_PV("%!`.1L#!WH:0`O+/6D-^AUI$I%#)R#M$`LG,0>V
M%0-#DD,3+`9)"A^/'$DSD1*=4HD#NC:%250A82Z."#Y*@`VJ(@D=&0L`'C\W
MHD[)!Z,&T`,!/+`*:@CR(Z4M#Q^V,@`K>T$U+@\TIBW["-0F"RG5(OT$3DUD
M!J]."E*C.O-+BA?S,Y<)PR7\/%U`%2C["IH(:C6H.:(:VR6`*;%.I"ZD/*U'
MW20Z+:1.2$49$!H0ES[H"!,1%1'!'H-'"CEG.?XR(A6Q%S4XBP]Q!",5$!JW
M/W`M929W3`T77#T),?T;)TIL*F`U0D=@*@$(BQ_+%9,?;RJ04D45NT6\2I4A
M4TDN*R<Y]2ID(&,B[BN'$Y=$?BL)/",4!QD6+_D2`2PB,IH<T3JY*G`^J!5H
M'^LS>0\6%)U*90.?)=D',RR<4V0,73IL$`L?#2<*0L,/?!%]$>L?`@OU4'02
MO2R$4742>1)U(?43RC">(B`7J35("Q(;HS*7#!8;0PUS/\T@`R7Z$LLTP0X"
M+"TG)%*'!E4>5AY9-ZT(T!1;"_<B@1!`$5H>Y@M.'X</C"D,3W%-L`P-(EP(
M7`NQ#`4E%!*Q"(0Q70L\5"\4R01:$-(SL0\O'>H;)D?J&F,0I3XP0<\5H3@T
M'=8,=B%>"RX+N`BF/K$H%"7*+VXW62+%%5898D_/4P8F?2"?)Y46`1Z6%DP=
M31UJ/!0<5QU8'0M2FPB]5%8L1"7<4@='[AXR(F=$A5'32:A27"QC)*P@7B(<
M2#T_2T27+,$B6QZ])@XB]AYL%`8L5`HU),Q+#R*O(-,SH"AZ!VT(B"&C*WP/
MV46100=*A$;H0*0X:R2R*'HP13DS&Y(=]!TA->I#,TKU(&P1FB`P/GX@.PWN
M*8E&BD8=*;8E5@EK-2,U($ZJ'^P$2"J2!=,3U!/'28\O[A_&/)44T!`$%=<,
MW!\*%54MSA]029P=P2&O&'$T?A%;,^,'Q"*[&-1,?!9Q&C4-,2,")@<F.#O$
M#^<?L31Q0MLAA$=_-,!&URVC5!DY<D*B/Z,_:T0H#8H;^3D$%KI!I410'CU(
M^C/H-SL*S$4I-1\C?AO6$/%!Q#8F0%50-1?^1CH.>D\P+U@#6#/N1JQ1,"H.
M/00XW3W+5!42#`B>3:`EA@[>'N(#@A;71Z\E"`GO([`E:4>F1\=-]Q3>)@HV
MR31#(L8DV0\V4ZL'K`>O!X8#%0UI.>(5+P2'-ATYM%-X'.<Z?QMO0'TV)PS,
M%34T-PH-$#H8S2LH*OY%(E2:#.)(T2[.&BY)P`JP,YX><P><$$\8/T'G+'5&
MA@^=&&H40B'W*),4C"K;,4)!%AXC3C@*>3C3/LM`R!"Q.*,@BR_.0*XI4S4^
M#B(YC%+2/7="WTGX,:TP*52X1>!)]$/-#,PT'A?S/@0QB08`$P9(OA?X%K\,
M4S\8574'P#L?0^0:_#%!$<L0?4*14M$Y3$24(G`9R#S,$`%&NQ9^)!P^3D5%
M3!T/PRTG10HQF!>931LH!3$T*J94RQ=]0V<D\S!P)B0$SRL2*4(['!,0%S(Z
M3DQ=%5X5:`0B%_E)9AQC/B5#AS\")48T00GR3@%'B`_?,2(.M#.%*A45!3U"
M(F8F7B0I-T54^D#,2@,R'1'[,KP##4^K#E],@#W1(]1!8@-U+K]38`XU&`1$
MK$/6/FM!VD#Z#H85XC'C,5P-1C\P5(T%?@S1%P)'Y#%@4&<F,$,:2]`5`D^^
M%G$I>2T/#NXT&SSQ%'D\N`-B#1--95!O4FD(7S\'3:M.94BD*]083$ZX&;D9
M*AM"4@U`1C?@1=H99Q#_+7,F%$WC-@0*)3/+1S$-CB^P!Y]+WC]>2],O#@7R
M%/9.\AH=/7U(`AC-,@0WIDN`&'Y$V2DX"`873#9(/S0;/2\T0:\R^%..)%@_
MDARP._`+N#;S%/8LR3+"!>4#_"7-5(10=RQ1/",>?`K&'8DA8#QP-V@#640I
M*!1$PAA[&L<6U2X$0Q5/]0C@,.@-T2G?&+`3:3SG2+,V)!Y:1#X9X2E<-6\D
M740]&S(C&42(%ZTI*C,:"R$\;`W51KL0]51M$0L*,QK"!U0+0@QJ#3M-@B,$
M0A`RAA<()J9%-!K?2K-&!2YF.J%',4O&#+1/H%)C+H<:O$0K'MU-=`.P2ZTB
MYTR$+]@-[T0V$($-\$0R,+=*TU0W+C,.*R3A._4:YT(625\00#!X4AL<%!_\
M"(U&ARI5/4\HF!I#!_5+$B[B2B09V2I(&')0,B6M)PH7+RT^+.I'RB5D*/4G
M42QW#9@)ES`T,-A#B2JA0H`0C2)M1Y\(/TL@#YTCXSLP1+,+>QD'&UE3&RXQ
M1)`'/27("'$(X26`2F\IPT[\.C<8/T_@'(M.]E())"$N4C7;)ST:C4HH+J,^
MPR%O390?1S`D3O,+/QJ=$,X6#CYN/L\61C74-=`6[3O2%L1*QAHC%U8ITQ8T
M"PY`H$W>-'@B-C&G3:A-($>S/H0^A3ZG/D<I?QI,2BLI-BD(1Y(^_#T=,9@H
MGR+L'_%,+3(N,K!3E`TA,M]"5S?T+5TL8!R)48!&U4FD,SL2-"+J/F$2F`5)
M'U$.'A_8&QL*'Q\5+W4\=C1@4=,5]CN,'T!(P1*<*!LT/A5=1C($,"?_4GD3
MLABM4=T#^PQ(+^,KXAOZ%Q`IP`L]"I)*HA@.$#U0#1,J%F](AQ!T%D0((4AM
M1&XYX@99&-$,9"&7#7`7N@,-17Y#H@3#$DD$^DD'2T(7TD5E"X<S7@7-$2HU
MSDM&(4@<6PY:)*4@RAY=4+DF+AE[!XX?Y4@0#AA'[S1?.\0SC#]J(&HI`U%'
M(I`*6`]:/)P'#0M?!9LA=A`(2FE1FU.-,6L@A2T6(D<CM2VC'#$4"4W7$*H5
M_R3$$?-&2"/,`S(X5RUF/M4)C!FV!3TFOQ9,4]P$BTQ6*D`>53;]2/`42E2,
M3-L9WA!X2/0$Q0N:*@4)%#\',:425U*R'L\>-A@V%'<+G2&_,,HD0472&?T/
M:3\(1H9"EANG(F-+V4MY(1([\SAS*^I`W@E]/C(U1%*G):LON0393A`0<#UO
M01]1A4;G4((#!15@1Y\AG$"X1,XG_Q94)/8(K"]H!7H)NRB&*,0NLC*H*G@L
MJ#X1.CTH5@88".]1(%"I(;4.APEQ400<Q1;U,@<?=`YF#-A'RSM"3X`R>D"'
M4PPSEC>7-T`$)S&K(F8/;A$Z-3(0D0QU#JDXDA"5$#4\`PZH+$P2YQDV/,<,
M`DDB4TX=#P3H,A`S+")-2APPM@Y_'>E(/`<[/!LD@B!Q&:0-=#6[,HY&+"1G
M0HH#YT;)#5<V%1_3).PB92AN1T,\84!R&1<H&"A^-LLE`2>@")9&<T>^)%($
M<#_(-FM3+TGG*093;E/1&&@CU1CA16XC>SE$*C,0?CE#27@5GAVA$I5/.`8^
M.T4U,2>S#%E%S41,+>I"S$UB*E80T#.\+D<5!3+[*B<KB`DM3^$5612O/`H\
M?$=^!0X;14X]'"`$!Q$,#E8OJR!N1)<.04BM&6DAB$]'!08:`A+$#L]&4P4(
M!.E`^#"@00T$DQT#)FL0&4Z4'54Y:Q+V&O<%+"E("2X/+S+#'Y8N5PCP0J41
MP!M-&"4-T!)?'_,6UT`E4MTN:Q=-4B5.QQ+X"=`@75.Y1^@LW40]$G82I#_H
M#S,$M5,I4`,MSDU6/B%#X4F7$%XLG`4B.)@0P!>Y15(1^%#D*Y4$T1(R)R-4
M8C5=-P=(]2GJ4U,@NC5P#X`;P!/A0S@9DR!#%9\<H!S:+6)1P5!Y0R88*Q8K
M(8\BO$<R++XF=B_.$$=,3T<G..8X=1;G-*PZ6AA_0^PWQ@FF1#4JVQ*S+!,B
MHPND"_X]+$4:+7U,US!J+;Y1)!=@4[@PS#Z`0T9!4$=L0<E!5$=^3(TZB27^
M'W]35#$J0\!360^D*&\#F1`C*(HK%PP&,?\?G0=&)P5$KCGE,20:B1,'00A!
M+3SE$>8173V&+?`T;A\K'T0RK`X^11499S^^(Z5*:5)>+8H35RG-`TDCS4H9
M1P`@EB69#BM#+QE0&9L-K4@L+8PV?AQ-/A9-WS]I#@XVO2HR#5XV>C,E&A%!
M?#)X"[4KC1.7'O8/=DE84MP9C"ND`QQ+"49!'N`_"U$A-!,]L$0K/SXF=RIF
M-50Z23!V0$<_/`S6&&\>W02914X^4Q:>5'Y(JDWD-4TVE"?`*@<O`@2P*2HC
MEC/14*M-0A[H-28L(TL4.^@MMCPU+SPD62W3!#HP-$HO32Y&%2H]2;,AJDNW
M+5<6X1X[4Q9/%!>1)%-0&AD;&0H$8C:U*8<P;Q5V02LS+C_63[DK.D,[0X`L
MB";P)5H96Q;T#711J$5!25(9!4(S(XDUW$>%",D=PBJV$6\1"4-.2A@8+!ZX
M$5@Y:3OI,BXF&4;Q1.LM9P]/2K,'BP/>+3@NL2FX/;(*%A_4"[!,E3#^-30V
M""T\1P,\-TN\,@1.DBM[!5\X1$6_+<4/RB>)31\DZT=T)Q`>WRTA)!1#0$L'
M.J8:"S5@*T(E+2ET1]U2(R3*(.53_D2(.NX[0DQ&4X`[T"L8#$4RX4:B+0)4
M'25F1E4'_2P6+D%++BD&-O<S/APB-I](5$E*'Y-3YU)5&.,X:DFQ/0LYQPE*
M-?\4^T.,3[P-4S@#&FLK9"*>!ZU.=TT?-/X7G5`Z'3$NZ@:-&:HS\#@R+@(?
M1R[C4=U,WP2U(C,N>""M,\,8^#@T+EDX54"81+8B@!I5(5]*CDGI!(,SD0KJ
M!)H2#RD<$.<P-U/<$A0BI!TY4ZQ&W#DC$,<-4AXI$2H1K#G(-S\LLR9:0UM#
M5B.P/[`F+"JQ/[(_LS]M2(@0)B-#4O83BQ6]/OL3_!-T0FX%I!YD/=8.MSB]
M4*A$@2W*0<M!!BI%*+HP1#T7$K%$!"DD"+U$B2#'()LFR"#U4MA$K"T\/^Y"
M:R7`$*\-5AK>)Z\UAT$]%QPXS0HE2>M-A02@2-4#B4%8'L(0/A)X/VLR=S&?
M'@E5"E5"2%0@*11?1M4P=R6=/7@T`1,)/P`P!@3<(GDT[3">/30G'0JO,"L(
MH00:/F!&-`;#%Q$BF2G/$'X3\@Z?*`L1%Q'!$]HT8DFN+.<XG@,"0(49:2M0
M)>,;<@\#0$E,?A6_)G%(NAVB$&]$7`='-8`202U3)0A,@4/A-;T-+CC("7$^
MY11O%+I"Q4K13%LDJ"%20RLUAPK4.^,F3AD!(+\C\"M*(TLCIU2K%?1&.Q18
M*5DI1R=;$`11STI]#R87!5$X0`TP:QZH5'<B6@_02O)3,T_=&8U,*DB&$E,T
M*T@4/:Y)W%$^.=\0%U.2(18ICD>^*BP7*QNZ&>\]FT&.3$M4Z2,((EM'7$<_
M0$Q420A@.^<A>S.;,7X^$1#R0>M`V@=]/.DU<QYF`Y4GH4$$,U@%APZ6,MI+
M`BZF#/0XD#;#.E14K!V")K0AN0@-#QP(,@]J/CXHT4_23^8#[P>'--$R9PS1
M5,0-Q0T^0C!-@"_M)^M#)0@$!WXSRATX1W`DZD^*)HLFTAZ3$.I4*1[Y((Y(
MRQV/2/H@M4]02F=&22T121))B$D,+F-#HAO!1`,B7!9^#A`$XE3Q/_\UR@V"
M)XH>Z$P'3OQ*(S:/'KPE9!;V)_<G=TLI0C0@H0B12P$C;T=/+0PU-PE7#"\I
MD0Z2#ATN=4=V1[)''2-W1YTBS1D@'R4)TB9`(A$Q$C%>-#A1*E!K2=D>E#L>
M-=`O]!)W3B0/\RTH$NHNBE$)&50-_0Q?+`(39RSO2?!)LS`C,J0@)S;W.1XZ
M0S.14+LX2S4(#4L6NS`<4/`<:#\+#40WCS'=#X\8+%&:11!`&4JH!,`P_PX&
M%0@OMSQT*XT<\CPP&C12<3=7!M<6%T_-+*D$4Q^\"/E1QAC4!>`%$%"`*Q$S
M>PA-$@<KJP2S"M@KZ0J('FI#_B.6'.$&&Q3(&]<]+D\Y%H8JA#-#$/]&9`2@
M'EY3W$;G"QL^I4FV498]MU']0W(^>A:#(O8J+4Q=!^,&\PG`(XL;LCK8.>0S
M&$W**]4Z$`BO0QD2VQ_G$$!`SR?D0M8ZY%&#!\HSWQ_@'RHH"DL4#;PH-4KD
M"H8^9SKM1,LK"0EW01T2.Q95(JXBZ07J,@\GG"9F*"@<DDL50^4]NTM#)><]
MFD8<#NPP01H$+4(:8A([((5'UTXH23T1P#8^$4<YUPX"&2)!4`Z?'4<$3#CU
M3[`\6A-!#AD)PE!C2:T@S3=S36D?Q0[V3Z4=X#*F+[<%"S@O//X<B!1,$<,%
M6B(%'9(&'T1M#<@6@!UX&#DKS!9O/QPATAN=*'(:<QJ)28I)E$GE3>9-KD"]
M1_I,_`G&#MM+8C`6"K%3)S]T&R92NC\-#C4G`Q/`/\)!0#_O";]1:A\6##Y1
M&0Q80O(;RU'Y"VI2P2.J1+$>-1U`.7\<.P:/$T%`N@3S00Y1?3`A/>D-$E&,
M!GX*4PF02(@:KRH?*+I#``6R-)LDE34W#\T3ES7E$\])&SFS06D1%$OF*\Q`
MC$%U&WA"H1YY/_4+]DQX,78,"SS</FPRNAI,1;X_\T*O(54@XTG6!.<K8"]A
M(I8$/RW"/:856R`!3%8.83X$3-42>4*=!>Q+.T;X"\H&`!IV1MLOTCG#01H\
MR$M@+$0B*3E^0H`D)QC&(I@LE%%P1)<]\PZ9%W863#%-1%$ZN!@<-$,:50ID
M24]%Y!4:)T`*RC?;-/%-DR_B#6(:_D,Q*L]+=$WB+_--"DUT/J\>85`;)YH7
M7C-%/7P'J3+-0?8I"DHC&/`)DD$,)4\D^@L+2HHE4RW8$)1!&@SE#1()Z2J7
M)0X6"195,4DB@3U:*>1!G"&D%K8M+A#A%JY/?$W-'OD;Y"8+3=H7\30N/$D]
M_"VE"[`:YT2Z$*X[;52D'-1+Y@U8+5].``^:"P,T$0@E!K,:3505/2P%"D;A
M/YT40D"Y!0M&NQFE*]5+!C*P-Z9*=0E[*B@R&R*$`V0SCT=?-FY4KC8=2S@U
M!Q4U3AP[HS&`2,(Z"1J8&XP5>2!?"[@M?T1Z(2%1W$OZ!]-&;C@J!XHABT++
M&MY+2TBH)>4VN#RN2NA%%CQC3C0L'Q4=#'XPSBS8%FD*P0>\![H':`P4+/Q/
M23X+!!(Z$!8[-?=.X1_^)=LNQ#H('PQ+&RFT-ZD^^"E2,A`X\3-[#G51*RB_
M(&@Q8S$\3<LPA"8K#/)+?PKZ44H^J@D1,HDTMB\W!1`TS!UE"@DFSC`T(X(:
MY0D.2P]+8$)A0FX--SR4$%$0(SL&(1H(&D1Q$6H2<222)#Q#%2R,)GA!PP?[
M($,,F$-2/)4X^"]12@I#9"YO#5,\5A^X.DD;@T!X&:(SG3.#(/L'+B(X2U)*
M$2<)-U8A:!F,`SY'BB/H0FT*L4P12_0,*"N.`P@K*!"[,5DL]2/M*K0*#%*S
M+N@*4$A$!Q)2[B+6(O9+\A*N)]DK[`F9&LX(("1J&31&>S70""D<D"!\&18X
M4"8K+40KI3P=(7-30A3H37P4FQQZ#_L.EP=L'$Y1#2/H3](RBQ0&'3%-GD>4
M0NU/FD*<0K0T`QD%&<$0'CD\/6,JJ`[`-VQ)JDF01S<TG"2@$4@VGDX64-4.
M5TQO(CX7'3@O".X^>16(0>X-L#4P"&TR81QL3`4$N4&+4:E1[PU]1\PB+P;M
M'\U`RQCL3;(S33@;449.>C]F+?XP_S`Q!/P#!4\F3LL&D%$4+0\QH4B_4%A/
M"$BT%YLM\$A2"MTO/QS(*GHT!@M!',=/1"_<+&XR]#YE!$,.7"!W(QTR/3(9
M&"HN%A65##X*<40&"!L:502X47DC=!!U$&\NWE"6%!@>=`_>+,`F64]_*/0.
MUR"X)D`@%$<F0\U,^#X<!^84-SW-"2HW-B*[*G`N]A^A+^L<8C>%-G-$-0BB
M$N<=]Q_F&G4^`#$R3[XZV4C>('X_?0?X5/5(ET^`*-(Z^3ZD!#)`IC^.,_\W
M\2OA*F(3MPT)0:8@^DUL5((]93Y+!88V_50005<QT`GS-DPI[#,R%$<.QQJ0
M,9$Y2#)()QI'!E%H)M85GRWK&L=''E&@!\,&1SV+5"\BYBXY'C<LU13P*N0V
MRR^H+O4<#%&V'_8<84<F+4$8.##B/Z\V\2U!.6]4Z%"N1N`9/`8L2+P9D4?)
M5)M%`2*&&TH]F2.A(W8)N!][/B8:S123"A)$LD1Z,CH("05Y2.,_[0W=0'!4
MSA1+%;@SZC4S-9<*CCN".^LUK2_M(8%(P@U148HNE2-K-%Q#`Q_3*^@0:@MO
M-]8[?D\*+ZDEN3S7&.512C_'0MY`\S)R/:%0Z1"C+OLTD$]P00TXOB'L-:8V
MN@BA.[H??0I."]D6IQ)V#@PRWCHJ)JL)"`H1%KTH/RAS5-@3'!F13_8RJSQ7
M&?PL>AU8%HM+[`/[408N^2G-"%LBSPH1.*H^^QUY"%0R?@:J'89(4A55,CX;
M@3!A)#<0E4-6-I<6KDX_2CU#K0E(+80801;(#,\M#B<B434:`A[-&^D'8SQ.
M#04'1PG&(!M$3@5M$\M3+S\9,;DS-!`_&0,>W3M+,P-!"QVR2S8MC"C,4QY/
M&S&P"U$;BPT*-]PS3!Z<(CP-AT0+21,$A"`,2?<0\2HZ*\X;!#S+#1XD2R#@
M2%0V&TD72:@M]QJ+'K4&.2Z/%`U2B1Z%(T\L9!V.1-<F)#QA!.XZ4"A**8HU
M#E)12.TDC`>I.54,U"UK0UXAS"6J(ZD9>$MG*!DH73)>,F,R_R,60T)+LBI]
M"'E+4@R21!<XE2FU*D4K%`JR3C`I)3SB)9,.3S^.#1(>)"3H)8<6BQ8M&[5&
MSB&A2>@3=`3O,(,.8B('+(]!S!<)"`P+FA3:11X><`F:4&40UTQI!-M%9A``
M+IH.7!`:2@DBS4<N&U@^5D1H$"Y(JT(0+&D#:@,Q#NM0Y3F.)HHT6D6V204>
MFS<&'M938$HO)O$%."5@1&%$6T9],84QXR"93YI/>P3J3`4D9T![.'L<@!S>
M3"4>6CZK#\%*PC*:-,U/PU/'4\U3FS/T)M=3'@L*$-]2IAYN%W<O!4S9+(8Q
MYR^/)]X2V1$N'T)0KTG5-SL=$!$$4G(19S!S$;Y/L2)W.[Y,TQOT&^\::424
M/?0[4PZ-1:X(&$CD..@KZ2O4/G,+9$$6!88$61Y\.!`9U!&(%@!&*Q*E,[08
M2T<Q3]4193A=("-(S@8]1O`PPU`Y)Y87:"PY!M!%K1I[5"TY$1(>#YM`5`]N
M`\\&UP/B)]\BLCWN.`4:`T8$(Y`BZ!WY'L%1'SY_&,,3TD-%%TDA@D-&(Y92
MSD&@.&)08U!)%YT7CS^$/<13VE2&4H(WH2WF0><Q(%$;2L$#E3_F)MP(Q3]!
M1/H1-T9]261.*AK!1?4KTTB62[4Y2$#;,WPJ("W_'"](>0N'2+$[.#'\'7TA
M=!3N0!0)#3*D%]E'L24/'.HJMDZ^1*47@2P$#+PM`E"#&ED7,$8Z"Y(F5#Q7
M'X(P]29B0E-*%1P3&A8-!TD(2;<E/#PW/D5$'Q)=.$Q0BQ=A2NQ#&T5V-P@>
M_@2#'^5'CP,823DV"RO$)8()[R(7#Q@/RT@(&_,H`S;\)Y8I,2E3-Z8\LT?@
M4N!-V$FU&(XY[`>&.$!/P`?C170:]TIF,S@2)#!U!#HG_A&<-)$NLSU2),Q4
M(BS1&=<^6S$@2U)4UC\X/EDD<B3])YTPRCD&/98U'01Q$+$-;B4Z-*P??P6^
M">(+2C8V,FU,*$&?1G\1)52S-?$^5`XM*OD)V4G5$_H454F@'5LWI3_%'RXJ
M44*430T24@_U0G0+ASE+&>)$4R[!"JHZ[TWU'AX;3RJ>!=@#0!+F2=(2%2T1
M&>]&E`_V1&)(MQ`\4%A.UE1].%<.52BK.A8M^4*..E)"WA4.$VDL\DGR2/=(
M+CGV+88%94F>+9$CQ1<$+X`1+%($#<$+5DC6$HLYXC>M.B@X&2W02[E16D]8
M#5L5$S'>`P\3&`>)$'@%B4^/.@A38B\C.=\51@BG2-4?OB>2*H`EVC7G3JPV
MS4NG1@`RDE!M2<=#XU",)?PVCB'"!J`U6P2A->4&[5.?"OU)Z0LP'==4&Q$P
M$0%-6!$7%:I/C2692OY),SD=$RDV;DEU(O\SV#9Z1HH09@N:+'U.MRX72V8>
MOR?A3ZA&F3:;4`<%WSU[(W`?(@=,!6DVUT$^),$G@Q)8,=%`,2$%%`D[330P
M3!PHEB]O4V$.!49Z/O5.3TRQ!28.*!=-4<$U(@7Q'+49D#^A+DP<H3WU&P9$
M_"BZ(A\(0Q*P.I$ZH0^G,X=+`R!I(\%3=`@Y0'$?#27$!N)"PA+./,U1PB/X
M):=3$24',M8&72G["ZTRG#&F!X$(9E`%$O,NM@2T&M<)Z4ZA)1I-&TVO%;46
M?P\T%,8_N0R)$:()YD_H,7]-DD<<3=\T'$JD-5TQJ5,R$\<CC52.5#(26PG8
M,XHMEC^L*(,71!ZC"D$@(B#8"?Y4RC+C1A`PQ5/[4YH&J2\_#_0*W0C:*C`9
M]QQ4%H="TPV.%IL.3U$@-=LL91/7%,POD3=W238X>!"6$TE`Z3^!'%-4LQQ^
M23M"U$>81[0<WTS>%Q=!43#$!6=(P1:?18\V,$BB(V)'204K&@\CLQX0(UDZ
MC!(M/XP;SRQ]*G\BW!CT/9M,&4S^"TA&24BC4%(P`TET'@1))SJ23.H_HRI,
M/9(;=1X>-N09I"3\-+1##CDQ/)Y`2#C;"A4PA!PV2M-/01.L+G<KEQ5)'<0[
ML4@U-[%--50K+!T[CAR(2'X>$AH<%($RTBFR3?$U^3A44:-`]3WM-8(\G$]?
M.JHX\B'Z09(59#%?%(8["R^[/*D4>PNL4'8NGAM/%=,RF3*I*NU%0!2L4QH_
M*#-;2(D.A1SP4<8-[B?:-D)"/QLK)H0:K4NW,N@6WQ/@$ZL^6!D<-VL,LR\Y
M3)8='QG$&9@6!RY`2D\4MR%=%EX6^REL4&=3IB16)'L)!0P>)6E%W3,3.A0^
M%!8:3R0[L"2)*&`F?RLN*"L))3OU(5P&PRB['X9094^C.?PIU"Q=2*8]M"\E
M4S8W!#6^'`8,0!LY1VY&1Q&V1GA1SE0E##LQZ#E9&3HCLU"<-PQ"?PNW#DX1
M2BQ\08(U(">F)S`SF4.$-HX1V$^))#].+#HX$+`)C#P!*RP[""$]/(D:2ANE
M+C`_02YO-CD^1T]1$A$T:#4O&(<R<17()Y0D4!1C0JPX-E3/-JL;C0\['UD=
M'0OP#*8Y@QT4)STM^4J1&G<WXU0R1K0)'10O(.948DH^,9424AJE#1P<;CO0
M,.D)_`HN4Y(:K!N;'H<<7CD,'>PRVPVX27P&N3KX-[TEXTK</`8\DRN^,:X^
MQ@;[&B(<7#*J+3PN1TEG%&4=$DMY+N@SI$>_,80K3U"<%H$+6!L5(^4P"`[J
M"K,4E"OX2Q12#AI?,M8DM22K-I$HQ256#!\IW"N>&LLN\2@/4E04QP_"3<TE
M(Q+94_`Z%B:R'>X*]C/&4FPH<4?3)<=2F@F0'@`1^SIL&1@N6DW^)ZXCWAUL
M0VH63"`R1'<G1DO8'`!+)$Q^2[U#;"Y-!Z,(!B1.(`DZ&CCH5"D,#C6U-.8'
MZA]A388IY258##(ID`TA(7A')20,).%2PR1G)50$-"UH37HG-Q9U&3DRD$4;
M"0D+!#*&(?])WR"!0M-%M1<H(SDDNR(Y.EX#G$5%"K<SGB&](J`A.0O`%:E*
MG4P51`E)-D%D/`P?Q2['&$\]=AFI188O9$)>1*U%#D(P)A\+8TK^$+5,L@M^
M&7<'>`=>(',R)`H"-T8*!C=%4F,[9#NR)1M/J$RX)646OQ!74&$L8BRC2(`X
MU$7E("8R3C0*.]4S'4I9/OY(N0>U&@D/K5!/3I]`RPI0/0T?N#?@2LP.XA\[
M(UT,/0WP#X0=2R:W!L@/TAS9'`E3[3,,2BLW`")%,WI(T49U&CPU.AO&+E$:
M!Q!(23=$!1:W*FT#EAX%,)4(32I.*@(PMR9%'*TVQ"PI/ZE&,1'B-5-#'2!/
M-*(/NRYJ+R,@71!P!<,V?BJQ-ITY.#_?%]L[Q3;O**DL(R4Z/O@UND_W-KM/
M#BN2*!P/SB#Q,1U(<2VP!BDX`3+/0<4S'4=>#TQ(.DX:4;\&D@T<.ITDK2VC
M$6T6DP8O3YDKP`[J34$+=#^F$?@,[SXJ*CLTGS`Q,B-!)$&4/L0?.5&,43<R
M2Q],'W,V*B%1&!4U,`81%"-2*"_2(/8832[*1<U%)TY^1U4-_DL+&>$:4"Z-
M*F4K=@HI+X,%C5$8+WQ3>4Z*)P9/>!+)*GQ.]CYZ)5$K6TE)$64]3CK=(I4?
M\1_G24(<*5):&CP%"$_,4NU+6A6V&)(OWPL>"@$[G@F%.AD@=T9^.-0@!Q/"
M&P@65@W#2F%2\T@=&I].R0D$0*08*1V2.A@1*441$_LVEU$%2TA!T2&>*<<#
M/SV9+.(D,TE3*^DT\3`Y1*)$`SO'(F`S5R"U,%!%NU$L%AXL*T%[-/-)91^Y
M.,\OL`CW'L4F1S0S0"47-BH)3!T'G`]@&`!*ADL4)#<75"73%#LFAPNC$@%*
M(3YJ)$H<>`J:'T,[HPEY+X-#:#AT(Z4P1A<I'\LM9#Y21``^HQ#5/HXE'SJ3
M.N0D(#JX#R].)!A`17<YI@L-4$HBD3_]/EL/^T`$(`<X6":Q&M4[8C/D#;0@
MAQ7B%DH7:U+(+YX7V`A9,<(1)@JE*!X@Y22#4+PP@ST-38<MIBAN*W(?2B=;
M*:$T#DW-+5,&OAA]3<,CQC.5,II1\$HC!S\%>$W;0(TVYQ%Y30<B]AL(./\V
MDC$W,-I!>TT0-KT9^!R7+E4T\#V'$OQ`%SWD/RPV$@C3%Y-':!A9*U,J'DN4
M1T(8G3B_*I1.O1H-+7X670KA$#\F"#(),IXJ;STN#!%`L0=L&B<'P$64&_,<
MM!(>2@A+\3A%'IY073R33+L%#2R^.&<^BCC62R0@@`^V/O8=5C1H/.PG\!JB
M32<MF@0T3/4T8U-U)H((,4.,"P`8_%,'*E]+GR.($B4H$D#$0F!+VC`$'Y$6
MLCNM3?\EKTC\*IU3WPD5/-H,2S\K%><V8$_U.&LIP"GK/Y5.HD&@0,XR$T_!
M.&<#-TZJ2A<[NCO".%\#(2\5"^Q`VP?4*Z84H1<1&HQ"*@[F42A+=AZ*%$@[
M(1YW&M9*2A0!.HX+5T0F379%'1G&!5@&\5&K'6DB<SBU-W@KZ`.'*/T8\4N[
M"+41K$NK%@HJYC.C3`8<^T8I"5U"!QQ`*.\GXQ[:%AX,=E'A$^8R)A[_"Y$+
MK#[<+O4\Z$@_0GDK@SRV-U<7`"9,/S$*^1.N+T14MB&;+P]0B0KN1=\:2QTV
M1U8+A29Q#"(]?1T?#(U+<ACZ1.0Y$A8@#%<C[T7R43TP_"`J'MPPGPV%&H,>
M>4'I+J,;&D`J.YPRE4*60I4[4A`6+(,V)CNQ4"$,-TK\46T_(CRT1C4CU4B'
M/IXV%QCA!9`(O#DZ,?$F&T`/-P@WY@FC'UL9S1V3))(,A1@R%SQ.T">&&$<3
MIA?J%SY#3QUU-Y="#@2**$@NLDP3)Y8X@@W'&1]/Q$1$35DY:$9E)QXJ$%2S
M2XH:R@=))K@.$TF6&;10'RI/#55*:CL_,(4@WCN?,]-392[)%A$?A2\+-ZT;
MA$#Z"N0[NCH,/@PW\E(0)EXKT#CI.8$K22YP2W%+"2L7'[PQ'1S45!M!P3S]
M2KA*)1#5"_@:]#,M)%DA=0,=0*4&G16-,G)+I@:&(R(2W@>(*F8=7D"J*;M.
MUBB^)?=+4DB0**4Z!5*;2\8/SC\[&LY$$"]@.&8&F`C:*Z\GSQP1-^L)H!6J
M!@(;GT-H*+HS`C;.)88?+$1[2U8[9$!K&7]&Q%+X)]TC*1"Y$>\8WB.J.7$G
M?$M?*S$<3B9H'4-+`B=Y2M8<H@@?#6PU&AT`))@1%CJ+3=Y3FQ(8.-DD`20H
M#+,TO$N/,F01&2']1W]+GS;$3C,I\T<^)6$KJC<F/(\-$Q[)"(%+L!?>4C(D
M"B0Y+7$_-RF_1G%#`$@@%`1(;$TD%O)#\T,7&CL82E.%3YM$3PJ-3OHQ*E)!
M$E0NL4`0,>A)WB^$(1HOA2%!+\$LL28F%O]$)Q8H%A\&T@RW0OY0SE(&(BU0
M$A,V!*-$I$2&)Z-33"_Z.T1(#SY_-P5``AIC4ND=U44J&!@ULQE@16%%5$/&
M2BY!95)T2#0YV3\B/GM&DDZ'(;M"-D8`4?0P1QHO%DT)(1IL"64:QR8F$YL?
M3@DT,>`]NU,"/OX64R1F-]Q%6@KC-=,8W$&4.?\7@T:%(N8@!T3=07!332%B
M#JQ$C1N90?THR$<?(!TG3R/)&M@^YT&##$]!0QAP(&83%4'\"[42P3`$-(XV
MZ$$%-`5%'TK"'1U-/A01,(T5QS^+.,$5TC?3-W(MV!3E/W@)`Q@A(T92K$(L
M&K821"811?<=QP4A2^Y22D"@/H,W]4&9+IHNA@@S1YP?H1_3*GE`=$\`'PHT
M'S:_&8H16C1E.S%(SB9('OA.PA463B(M2#EW)E`5A#PU"0H1,@<+&H-$D4*E
M01A.YA<%&/Q!.T[[+(4W"S2_2'HK!"9H2W%!(!7:1_PRU@5=!@<,Q"B_'"\H
MM2]*.T-*%3[](%A4(!F&2?U1?4#%)UH7QRZ0-:(?6R-;#$A/QAP00A%"1$I?
M1&P*ZQG`"`I)MT;@1[A&$S-8(?4-4Q`_.-`=4A)N.D5-]B:D']LW4Q*Y1BHD
MPRJM/%9*I1_K*E@?61]M2V1*:4;V(Q<\S`<70C\U=E07)E,:V%)M)_,_94J-
M1$U0DQKC#)XNW08Z-@P8DD89'[8*W0W'2`T8+B1I!@`VQB6.+)0V("FK(^`#
MET;P(D4ZHR;4)6TH#R&L)N]'*T+11/\G'$G/!W@U#4XO)"H,C@H:%I(@6`E#
M*Z<\,"3B4B8D>R=N3350^U!-+Z$)$T`P%_X@W$BU5#014PO?(<M."@_4,JY+
M[3(<+R()JQQ-"YY,=4\1!K`$,P=/"SM,R0^G"4PNK1^^.[0U)BK`$2H4NT=^
M%!<%D#I*3(`4KRQ%#A\U[#0^5#@J.")&,A(E"#$U%.D\007V-(T+5AR-$NXA
M)2#B"I)",06E*;<>MRG&-GY`)"4Y$#L^,3,80L<ER@_9)O@N:S!*!RQ"F@HC
M0(4UFPHP!,$;9`BR4WH4Q2$/!YX8#D>_2FH1;5/.(DY2ORS?+QL@7$D+10L_
M-R?@+YPMI$A#3'A&1`T3!]]9X%GA6>)9XUGD6>59YEGG6>A9Z5GJ6>M9[%GM
M6>Y9[UGP6?%9\EGS6?19]5GV6?=9^%GY6?I9^UG\6?U9_EG_60!:`5H"6@-:
M!%H%6@9:!UH(6@E:"EH+6@Q:#5H.6@]:$%H16A):$UH46A5:%EH76AA:&5H:
M6AM:'%H=6AY:'UH@6B%:(EHC6B1:)5HF6B=:*%HI6BI:*UHL6BU:+EHO6C!:
M,5HR6C-:-%HU6C9:-UHX6CE:.EH[6CQ:/5H^6@L`(@`E`$@!1@!(`$0`=@!^
M708`0@!*`$H!2P!,`$T`3@!M`'``6`!:`%P`7@!@`&(`9`!F`'(`<P!H`&H`
M@P"$`(4`EP"/`)``B`"'`)(`D0"&`)@`B0"E`(X`C`"G`'P`DP"4`)X`FP":
M`)D`B@"=`*,`I`"?`*``KP&6`)4`4P%2`4<!3P!0`+L!$@!#`4$!0@%+`44!
MZP%/`5`!L`"R`+$`KP"N`*D`J`"K`*H`3`&Y`+T`MP"[`$X!/UI`6D%:0EI#
M6D1:15I&6D=:2%I)6DI:2UI,6DU:3EI/6E!:45I26E-:5%I56E9:5UI86EE:
M6EI;6EQ:75I>6E]:8%IA6F):8UID6F5:9EIG6FA::5IJ6FM:;%IM6FY:;UIP
M6G%:<EIS6G1:=5IV6G=:>%IY6GI:>UI\6GU:?EI_6H!:@5J"6H-:A%J%6H9:
MAUJ(6HE:BEJ+6HQ:C5J.6H]:D%J16I):DUJ46I5:EEJ76IA:F5J:6IM:G%J=
M6IY:60%@`6<!;@%U`7P!@P&*`9$!EP%_7(!<@5R"7(-<A%Q8`5\!9@%M`70!
M>P&"`8D!D`&6`9H!G0&@`:(!I`&F`:@!J@&L`:X!5P%>`64!;`%S`7H!@0&(
M`8\!E0&9`9P!GP&A`:,!I0&G`:D!JP&M`58!70%D`6L!<@%Y`8`!AP&.`90!
MA5R&7"=)/!&_-GPZ6D',)T@Q&`2_']DXAUR(7%H!80%H`6\!=@%]`80!BP&2
M`9@!FP&>`8E<BER?6J!:H5JB6J-:I%JE6J9:IUJH6JE:JEJK6JQ:K5JN6J]:
ML%JQ6K):LUJT6K5:MEJW6KA:N5JZ6KM:O%J]6KY:OUK`6L%:PEK#6L1:Q5K&
M6L=:R%K)6LI:RUK,6LU:SEK/6M!:T5K26M-:U%K56M9:UUK86ME:VEK;6MQ:
MW5K>6M]:X%KA6N):XUKD6N5:YEKG6NA:Z5KJ6NM:[%KM6NY:[UKP6O%:\EKS
M6O1:]5KV6O=:^%KY6OI:^UK\6OU:_EH-``X`$`!$`10`%@`!`!@`&P`>`'D`
M(``#`"0`)@!4`54!7`%C`6H!<0%X`7\!A@&-`2@`*P!^`(``@@`M`"\`L`&W
M`;D!OP'!`<@!RP'.`=`!U@'8`=T!X0'G`>P!\@'T`?8!^`'Z`?T!"`(*`@P"
M#@(0`C``,@`S`#0`-0`Y`+$!N`&Z`<`!P@')`<P!SP'1`=<!V0'>`>(!Z`'M
M`?,!]0'W`?D!^P'^`0D""P(-`@\"$0(\`#X`0`!%`/]:`%L!6P);`UL$6P5;
M!EL'6PA;"5L*6PM;#%L-6PY;#UL06Q%;$EL36Q1;%5L66Q=;&%L96QI;&UL<
M6QU;'EL?6R!;(5LB6R-;)%LE6R9;)ULH6RE;*ELK6RQ;+5LN6R];,%LQ6S);
M,ULT6S5;-ELW6SA;.5LZ6SM;/%L]6SY;/UM`6T%;0EM#6T1;15M&6T=;2%M)
M6TI;2UM,6TU;3EM/6U!;45M26U-;5%M56U9;5UM86UE;6EM;6UQ;75M>6X4"
MAP*)`HL"C0*/`I("E`*6`I@"FP*=`I\"H0*C`J4"J`*J`JP"K@*P`K("M`*V
M`K@"N@*\`KX"P`+"`L0"Q@+(`LH"S`+.`M`"T@+4`M8"V`+:`MP"W@+@`N("
MY`+F`N@"Z@+L`NX"\`+R`O0"]@+X`OH"_`+^`@`#`@,$`P8#"`,*`PP##@,0
M`Q(#%`,6`Q@#&@,<`QX#(`,B`R0#)@,H`RH#+`.+7(Q<C5R.7(]<D%R17))<
MDUR47)5<7UM@6V%;8EMC6V1;95MF6V=;:%MI6VI;:UML6VU;;EMO6W!;<5MR
M6W-;=%MU6W9;=UMX6WE;>EM[6WQ;?5M^6W];@%N!6X);@UN$6X5;AEN'6XA;
MB5N*6XM;C%N-6XY;CUN06Y%;DEN36Y1;E5N66Y=;F%N96YI;FUN<6YU;GEN?
M6Z!;H5NB6Z-;I%NE6Z9;IUNH6ZE;JENK6ZQ;K5NN6Z];L%NQ6[);LUNT6[5;
MMENW6[A;N5NZ6[M;O%N]6[Y;A`*&`H@"B@*,`HX"D0*3`I4"EP*:`IP"G@*@
M`J("I`*G`JD"JP*M`J\"L0*S`K4"MP*Y`KL"O0*_`L$"PP+%`L<"R0++`LT"
MSP+1`M,"U0+7`MD"VP+=`M\"X0+C`N4"YP+I`NL"[0+O`O$"\P+U`O<"^0+[
M`OT"_P(!`P,#!0,'`PD#"P,-`P\#$0,3`Q4#%P,9`QL#'0,?`R$#(P,E`R<#
M*0,K`Y`"F0*F`I9<EUR87)E<FER;7)Q<G5R_6\!;P5O"6\-;Q%O%6\9;QUO(
M6\E;REO+6\Q;S5O.6\];T%O16]);TUO46]5;UEO76]A;V5O:6]M;W%O=6]Y;
MWUO@6^%;XEOC6^1;Y5OF6^=;Z%OI6^I;ZUOL6^U;[EOO6_!;\5OR6_-;]%OU
M6_9;]UOX6_E;^EO[6_Q;_5O^6_];`%P!7`)<`UP$7`5<!EP'7`A<"5P*7`M<
M#%P-7`Y<#UP07!%<$EP37!1<%5P67!=<&%P97!I<&UP<7!U<'EP2`A0"%@(8
M`AH"'`(>`B`"(@(D`B8"*`(J`BP"+@(P`C("-`(V`C@".@(\`CX"0`*>7)]<
MH%RA7*)<HURD7*5<$P(5`A<"&0(;`AT"'P(A`B,")0(G`BD"*P(M`B\",0(S
M`C4"-P(Y`CL"/0(_`D$"IERG7*A<J5RJ7*M<K%P9`!P`;@!Q`%D`6P!=`%\`
M80!C`&4`9P"M7*Y<:0!K`#T`00`(`*]<4@!7`+!<L5RR7+-<M%RU7+9<MURX
M7!]<(%PA7")<(UPD7"5<)EPG7"A<*5PJ7"M<+%PM7"Y<+UPP7#%<,EPS7#1<
M-5PV7#=<.%PY7#I<.UP\7#U</EP_7$!<05Q"7$-<1%Q%7$9<1UQ(7$E<2EQ+
M7$Q<35Q.7$]<4%Q17%)<4UQ47%5<5EQ77%A<65Q:7%M<7%Q=7%Y<7UQ@7&%<
M8EQC7&1<95QF7&=<:%QI7&I<:UQL7&U<;EQO7'!<<5QR7'-<=%QU7'9<=UQX
M7'E<>EQ[7'Q<?5Q^7$("1`)&`D@"2@),`DX"4`)2`E0"5@)8`EH"7`)>`F`"
M8@)D`F8":`)J`FP";@)P`G("=`)V`G@">@)\`GX"@`*"`KE<NER[7+Q<O5R^
M7+]<P%S!7,)<PUS$7,5<QES'7$,"10)'`DD"2P)-`D\"40)3`E4"5P)9`EL"
M70)?`F$"8P)E`F<":0)K`FT";P)Q`G,"=0)W`GD">P)]`G\"@0*#`LA<R5S*
M7,M<S%S-7,Y<SUS07-%<TES37-1<1P`Z`$D`!0`'`$D!40"^`<H!O@"X`+H`
MO`![`(L`C0"<`*$`H@"F`,4`S`#1`-(`TP#9`-H`VP#A`.(`XP#I`.H`ZP#U
M`/8`]P```0$!`@$+`0P!#0$6`1<!&`$I`2H!*P'4`-P`[`#D`"P!+0$N`2\!
M,P$U`3<!.0$[`3T!/P$^`3P!.@$X`38!-`$P`4`!,0$R`:P`K0"S`+0`M0"V
M`%$!>@!-`70`=0#57-9<UUS87-E<VES;7-Q<W5S>7-]<M0&R`;0!LP''`<,!
MQ@'$`=4!T@'4`=,!\0'N`?`![P$#`O\!`@(``@<"!`(&`@4"`0+%`;8!X%SI
M`>H!X5S-`>)<XUSD7.5<+0,N`R\#,`,Q`S(#,P,T`S4#-@,W`S@#.0,Z`SL#
M/`,]`SX#/P-``T$#0@-#`T0#10-&`T<#2`-)`TH#2P-,`TT#3@-/`U`#40/F
M7.=<Z%SI7.I<ZUSL7.U<[ESO7/!<\5SR7/-<]%SU7/9<]USX7/E<^EQ;`6(!
M:0%P`7<!?@&%`8P!DP$E4>0!V@'F`;T!VP'C`;P!W`'?`>`!Y0$I`$8!0P#[
M7/P!KU+\7`0`_5S^7/]<?UT)``H`@%V!77<`@EV#75,`5`!5`%8`-@`W`#@`
M'P`A`",`*@`G`"P`#``7`!H`.P`_`&P`;P`/`!4`'0!X``(`?0"!`'\`,0`1
M`!,`+@``70%=`ET#701=!5T&70=="%T)70I="UT,70``#5T.70]=$%T171)=
M$UT4715=%ET771A=&5V_`,``Q@#'`,$`P@#(`,D`PP#$`,H`RP#-`,X`SP#0
M`-4`U@#7`-@`W0#>`-\`X`#E`.8`YP#H`.T`[@#O`/``\0#R`/,`]`#X`/D`
M^@#[`/P`_0#^`/\``P$$`04!!@$'`0@!"0$*`0X!#P$0`1$!$@$3`10!%0$9
M`1H!&P$<`1T!'@$?`2`!(0$B`2,!)`$E`28!)P$H`1I=&UT<71U='ET?72!=
M(5TB72-=)%TE729=)UTH77TB3T.'&<87/E""&\A&8S?2.QT^920W*M)!O$(>
M!<-144<L-T<7+Q_R+NL1"$1J!),Q5`8)2\0CI1S&,DPCT$=^5,Y1!U'W1LHF
M+`A/5*T3B1+]0*---0N?/AY'>T12'`T&%DR#2(,[+`<H+-DZP2FO3?,,,TW#
M.(47RS(J2J10W`>)%QDJEQVG+(D(Z@-A%&P,3P7B!=<%Z1EM!_(F]44V/L)(
M0CH<1'\Y-1`M'L04PB#!#XL:KR)D0V5#.BX6!AE5&E4;51Q5'54>51]5(%4A
M52)5(U4D5255)E4G52A5*54J52M5+%4M52Y5+U4P53%5,E4S5315-54V53=5
M.%4Y53I5.U4\53U5/E4_54!5055"54-51%5%54951U5(54E52E5+54Q5355.
M54]54%5155)54U5455555E5755A5655:55M57%5=55Y57U5@56%58E5C5615
M955F56=5:%5I56I5:U5L56U5;E5O57!5<55R57-5=%5U5795^1IX+@HKV"9*
M+3P6@#EI*,\[H4-!*VTU4"V#*6Y#TC$?(<@K[E-=*/XZ.32X$Y\D'@12&%4.
M0POJ$V],W3%P3`T)5QAF0=,2IQX11]TJL@3P3=4@2$[6()P<10V.,,0R]$FW
M`[8P$Q,H1K@+-Q5Y'.,WOPME-8(X*CCP.[94P">D!8]0RQX:'C(=D"4P%OM"
M9E(H1WI%)TB]104[B#/(2JI&V@3D0[U"3!9Y"M9%>B^#)'P-&$NW0*40T0D1
M/6Y!=U5X57E5>E5[57Q5?55^57]5@%6!58)5@U6$5855AE6'58A5B56*58M5
MC%6-58Y5CU6059%5DE635915E56659=5F%6959I5FU6<59U5GE6?5:!5H56B
M5:-5I%6E5:95IU6H5:E5JE6K5:Q5K56N5:]5L%6Q5;)5LU6T5;55ME6W5;A5
MN56Z5;M5O%6]5;Y5OU7`5<%5PE7#5<15Q57&5<=5R%7)5<I5RU7,5<U5SE7/
M5=!5T5725=-5U%5,0<X)3B&7*B,%`SZ&0PX+3!<L1E9'0T9]12<3WD%+)Y@E
MSAZM.X42@3^P#I$PSD\#-_(K'DW((_,KI3@40(4]$@MA!:@)ZA#>"&(%K2CZ
M%<@.*07',JI3D#-F$=`>W@^T'BT:X$RE*GP+$48>/1)%$PT2-O8KMAQ+0&`V
MP!F!1"\+`!U.4Q,)12;]-`(0^$;F&9TGR#CS-;,[B4BA0'1!KE`)'VI+PRF\
M/*`GLR5"))$]U3*=#/8@.%">!J`Y^`C55=95UU785=E5VE7;5=Q5W57>5=]5
MX%7A5>)5XU7D5>55YE7G5>A5Z57J5>M5[%7M5>Y5[U7P5?%5\E7S5?15]57V
M5?=5^%7Y5?I5^U7\5?U5_E7_50!6`58"5@-6!%8%5@96!U8(5@E6"E8+5@Q6
M#58.5@]6$%815A)6$U845A56%E875AA6&58:5AM6'%8=5AY6'U8@5B%6(E8C
M5B16)58F5B=6*%8I5BI6*U8L5BU6+E8O5C!6,58R5EPC/%,(#$1)M#%5'^I.
M833N`RPFXRKA2D`9A4!30?8-@45)3[I&J#2F#?<FE"82-"T[7Q9:'Y`1TQZG
M)TP;C!I;'Y`#[$Z##0D>N!96/)0:F1D0-W`[>3W]"K9,&A]J**D&LSG55/LC
M;$(C'#-&9S8<0>(3MB3+#\\E%5(:-NTEODX4-%8]:!94.Z\C`"AN*-4E,21'
M2T8KOD,7-!L6X`W&3J09%`<>!W!1Z25H.<-#_S*)!(<OUA%&#;T2X2M4/S-6
M-%8U5C96-U8X5CE6.E8[5CQ6/58^5C]60%9!5D)60U9$5D561E9'5DA6259*
M5DM63%9-5DY63U905E%64E935E1655965E=66%995EI66U9<5EU67E9?5F!6
M859B5F-69%9E5F969U9H5FE6:E9K5FQ6;59N5F]6<%9Q5G)6<U9T5G56=E9W
M5GA6>59Z5GM6?%9]5GY6?U:`5H%6@E:#5H16A5:&5H=6B%:)5HI6BU:,5HU6
MCE:/5I!6SAAF27($M2#Q"``*V2><#1LK@E/",!(&G%+:)\H+*4L.,CA#02A\
M#L@N/5,A)WU!=0WS0#M+IT=L/2X7\PC1,R\XLPBT"&HV\SH].)DHLA)N3_@2
MHS`F#Q8U\RJ@!=(?B3N+)[`L*TX4$](4J1X5$V@]L2SC/'<=1#\?$QLMM"RU
M+`H(:SW%$ZL%P@S/44,I`"\U25$9E$R53+<L3R$-2I$G`@]3&7\-A%.H'>()
M%0GI/K$D/PBH)Q,/)">'';@*D5:25I-6E%:55I96EU:85IE6FE:;5IQ6G5:>
M5I]6H%:A5J)6HU:D5J56IE:G5JA6J5:J5JM6K%:M5JY6KU:P5K%6LE:S5K16
MM5:V5K=6N%:Y5KI6NU:\5KU6OE:_5L!6P5;"5L-6Q%;%5L96QU;(5LE6RE;+
M5LQ6S5;.5L]6T%;15M)6TU;45M56UE;75MA6V5;:5MM6W%;=5MY6WU;@5N%6
MXE;C5N16Y5;F5N=6Z%;I5NI6ZU;L5NU6[E9",!H/&P]='ED-F#GS40(MA`4K
M%(12X$*.18X)>4:",:9"=PRE!7Q45$9(4501FU$6$OD?9S>S+?$\$3XZ'CI`
M2AH</%L*T"IW'PI$:#X\*@M$-CL5,6D0>3DK2ED%'E#[%;0IZ2;^&X@]IP-@
M"LD%]RL2$.DA!4<^#'$X2%+T431-CQ(S2'P)?S[&%KM`PQF*(J]*`"$'0O`5
M14I0"WP:E2Z*#B10=3A&#%=*@E3Q.@TWYPY)*$HHH#-/$Y<F,C/O5O!6\5;R
M5O-6]%;U5O96]U;X5OE6^E;[5OQ6_5;^5O]6`%<!5P)7`U<$5P57!E<'5PA7
M"5<*5PM7#%<-5PY7#U<05Q%7$E<35Q17%5<65Q=7&%<95QI7&U<<5QU7'E<?
M5R!7(5<B5R-7)%<E5R97)U<H5RE7*E<K5RQ7+5<N5R]7,%<Q5S)7,U<T5S57
M-E<W5SA7.5<Z5SM7/%<]5SY7/U=`5T%70E=#5T1715=&5T=72%=)5TI72U=,
M5ZHG<R1$0R`2/@T-2PL814/Q%?4_<2Y332%`MTO4)+\EP#EV#18G%R>1!BH<
M$0I32$T>&5&+*MPE"AOA(V$;.D:42P%+P$LG/)0.ERDZ*3LI[P;R!C<$2A%+
M$50S;07P3FTJWB[@"S\G:BR#&\DO1Q2G$%`7O`6G"K`R:P-$1*<7%!JH%R!/
M=`RI%TA$#4FK%PL>E`,>10\:UB5V,/87,Q[_$UDO5S0T-6-/F!4W(3@AGE)G
M3VA/VT_,#]XQ4TL&!50#4P-<`UT#60-;`UH#9`-L`W(#<0-[`X4#?0.``ZT#
MH`.<`[L#Q@/.`\4#R@/)`],#U@/9`]L#X0/M`_$#_P,'!`D$$@01!"($)00<
M!!L$'P0F!!<$(P0:!#0$/`1%!$($Y2Y&!%$$2@1(!%<$6@18!&`$601F!&<$
M:P1Y!'8$>@1S!'<$>`2'!(@$E`27!),$GP22!)$$F`2@!*,$I02O!+$$K02U
M!+X$LP2_!+0$N`3'!,@$Q`3.!/0&+E#'%\X7]0:*/V%,KQ%G$U@TU`VT*-!/
M("7D'O!%O!P,+ZX#8RC&17E2IPVS`Z$5UR42%-0_^S')36D]Y$1_0GT2[2L?
M+#`Y+$[_+M<1<BI[0S4Y#$@!4:A(,#CG&N\,R%#B(OH?:3C-*FLL#5.44#8Y
M^`ZT+4!4-`G3!E4KYB<E/A\/8PYG+2,L1$;E4"A(<2Q64FPLH"HF,U$7I1GT
M":@,N""H$`@JB4/J074CA#>)/;86:S\!)4DY##3/)@]1/0?4!-@$VP37!-4$
M[@3M!/D$[P3V!/\$!04*!0@%!`4/!2L%&041!1H%'`42!14%)P4H!1\%.P5&
M!44%3054!54%705D!6L%905Q!7H%?06/!8D%A078!<L%W065!:D%HP63!9D%
MR`66!;`%U064!=`%YP7S!>\%J`4;!@H&#@8@!B$&-@8W!BP&109&!D@&/@9/
M!DX&7@9V!H(&@0:(!I`&EP:9!J0&FP:6!K$&P0;`!M`&QP;,!M(&T086)=0C
M9CN\(#LPMQJU*$L4AU*D3+@:T"GE0C1%,1JW%I9.FPNW'-0JDQ@31I(]\45;
M$1I!E!8M*^]`;"*A#5\)#32#+%X2(4\F4%A*S0Y<(H0L+3H-##(H#`K^*6`6
MR!DN.AE"*C%>.+4F5PE>'0Y)^46?+)D67QT9294#FAH2'5!0L2K&"O@V0BZ4
M1LI(_AH/*Y4KF#"6*]<D\2(?1I<K"QMP*!0K`2@<%@\J;D*H/*XA]U*),Q]-
M.SH43R(A4#CF!MX&\P;_!@8'\`;Y!O$&)0<7!RL'(0<T!PT'$0<D!_X&-0<F
M!Q('$`=J!V8':0=H!X`'<`=Q!W0'B0=_!W8'BP>2!Y@'E`>3!Y4'H0>D!YH'
MGP>E!Z<'M`>J![<'M@>X![\'QP?4!]<'T`?3!^4'Z@?K!_('[0?Y!P0($P@#
M"`((!P@C""@(.0@N"$<(2`A%"%`(2@A/"%D(7@A;"&$(9@AH"'8(=0B*"(0(
M?PB'"+4(K`BV",\(U0C9"(T8A$ML4@H>2D_D35`$.0_V,294CD%84'$B+!0J
M#=D@@R77$K)`N!"P(9A1JQZ5!LD065!;.U4_QAYM+/L?`TV.*1`_TA"V+.E2
MABZF,$`G6B^B)/8&]C#F2^,B-R+S-+-2,A;9$"<RJ"@[0'\#AT-71Y@OA"1D
M&-8S<D`C,RD(.2(N-<P(0R1$&)9,#43%0K<$'2C72T,)40G11S(W:R..%2H(
M,1F#*(4)G"ZV.LA3.R*91X532R+@":0Q?U3N,P()[0CO".8([@CI"`$)!@D.
M"1$)#PD?"1@)'`DF"2H)+`DD"3(),PD\"44)5`E0"4H)50E:"60)9PEC"7$)
M90EF"6@)D0F-":X)CPG%">@)O0F_"<L)V0G6"><)P@G`"?$)\@GV"?<)"0H@
M"B4*&0H<"A@*&@I!"CP*.@HV"E`*6`I."E8*<PIT"H4*A@J/"I4*K0JD"J\*
MJ`JF"JD*G`JA"L0*O@K("LX*S`KG"M8*[`K:"N$*UPK4"O@*ZB8U(0$'^"NX
M'`08-37Y)-=*<D&E,5\I1RUC-F1'0P\8/R1+'B)10$$ZKU`$$,M"H`T@/5PM
M=#T/,D\0D!(]-0TSQ"D+%2<[K1"B)VHZB3Q!&?$O)"-V/<Y":3$*)G]`4DX3
M$)HC_BZ12$!3DP@4,O`#GB_1)XXHK"%7"XD)L4K0)&8P%3(6,FT,7U2Q"V0I
M4AN>-W0D2T]@'9U"1P^Z#@@'B$X5,Q@.P"5A'1I"$5`T,Q,=3TV/4_`7(B(D
M3^XD\PKU"B,+%`L6"P,+)@LK"RT+.`LP"S,+/PM""TH+3`MQ4U(+C`E9"V`+
M80MH"VX+8PMU"WH+DPN&"XH+A`N>"Z`+IPNY"\0+S0O."\L+R0O&"[X+W0OE
M"^T+XPL,#/T+20OR"_$+%0PM##,,10Q'##H,40Q<#%H,:0QB#&,,?`R$#(4,
M@`R'#(\,E`R9#)\,H`R<#+<,M`R\#,,,R@S;#-\,[`SM#/$,]0SV#!H-`0T%
M#?<,!PT.#0(-$`V,'OX*'4E!-:@-N4GY+_HONDR*,!@REP/](=,<5$UH-ETO
MV`M%!U1(UBE(0_(BN"38)!E2T"78)9D11#5>+TA+W24"*`,HD"P*.AT6!R2.
M!WE'SS7M3;\[RRF>1&-(?S%2!1T03U)04C%)ZCA+3+Q1H#U_$VHK.3O+*F<(
M_BC23$U!#E-[%KY"25%P%'$4(3K^'FLXQA-J(V0.TCRP%0\6W%16)ZXHP`UM
M4;T%]PHN&C9,JTH#5/$:IE#835!!74,##2P-)PTD#28-+0U+#4<-4@UC#5,-
M7@U?#5<-70UA#7L-B`V)#9@-F0VL#;X-S`V[#;D-OPVX#<X-V0W/#=4-T0WJ
M#>,-[`W[#?`-\0W\#04.``[^#1,."PX6#B$.(PXG#AT.)`Z?3RP.0@Y`#D\.
M;0YE#EH.4@Y=#FP.BPZ$#H@.G`Z8#I8.N0ZG#J$.H@ZC#J8.K0ZO#JX.L0[*
M#K\.S@[##KX.W@[9#MH.W0[M#NP.#@\2#_`._`X(#S)(4E$\2:8J6CIO#BX%
ML%#@2P@<=12&/&`ZTRG<.YH3%4:U,5!-31N@.I0(<0V:%G$[8"5G+C\KS0W(
M)0Y.75''3O,D"S:M1%\^F#4G5$,(Z4GW0L(M'C1E$I<7+4Y!428?0E']3(0B
MF03C+X(MDR4*3.0O'P=!)\0M^U1*46`@V!HF/M%1V1K5%YY*]%/24:,UZP\1
M4U\ND!-<%#1/(CIL(P<4,Q\8/7P^(4=G*;<HLQ4`5:!3NP0V&^=1;R/Z)"$/
M*`\C#RD/+P\Q#T(/.@\V#TH/3@]/#V4/:`]L#W4/;@]S#VT/=@^*#Y,/D`^6
M#YH/G@^E#XD/M`^W#[T/V@^Y#]P/X`_?#^8/[@_G#^D/[`_E#_</^@\%$/L/
M_`_^#P\0&Q`7$!@0,1`M$#L0+Q!*$$(021!&$$L09!!8$%4081!S$'L0<!"0
M$(P0@A"-$(L0K!"A$*L0GQ"Q$)L0H!#1$+X0Q1#F$-P0U!`($1(1$1$L$2L1
M+Q$N$3L1L"\*)ZM4*$U%*48I/TF30B<&"1Q"$]D%K2Y)'DE2552C190)U@U'
M)@E4/4WV1?Y18A29%?0U:SL)-A8<N"'$!^0J$%(*',TH]SI.&X]+U$`I-(XC
M64KR&6TSSQLD1"LQTQVM4SX^YU0,*7,[:2X2-YL::36U+E5-BS`K',(^U4"V
M"?\:\R(.*6T&%#>N4T8E60P*1UM,*SA/'[=(9B2I2-($U`9%/])2&Q[;#C%!
M4!9+"[M(#D32"6<B9PW)4Z!%0A%($5416A%1$5`15Q%A$641=1%H$6L1=!&,
M$8$1@Q&3$7L1A1&>$:(1J1&J$:01J!&G$;T1OA&[$<P1RQ')$<H1T!'1$=,1
MWQ'I$>(1Y!'@$?@1`!(!$@L2$!(,$@X2$A(J$C42)Q(L$B82*1(\$D@2/Q)=
M$F,28!)D$F<2:!)Q$GL2>A*.$H$2BQ)R$GP2A!*D$J`2J1*L$K$2L!+`$L82
MS!+K$M02Z1+\$@43/!,Q$Q`3*!/V$@P3!A/V.NX5JU,!04T_(D<.-))(DTBW
M/2T)=SWH#H8@E2820JE!_2)1"S-0OB*_(K4)B@R8)OU.8`Q.,Q4TK0\!3QHH
M<C,$"^`X>A,Z,@H+7!B#,8`7@S@N$LDKP30/4T(GZ"?G!ET$F3II&'@?X@XL
M2M\Y=!_%-*@P(25(4R8(]PV3#&`_B!^D(8D?H22B+R$*,BK/4GP_ZATZ.Z8S
M\49^4YM-<A<A"`<PJTE<#VHWP$+44O$L815C,PLLR@0-"'PO3"<>$R43-Q,P
M$_426!-7$V037Q-@$UP38Q-H$UD3:Q."$X@3JA.5$WT3C!-T$WL3<A.8$W83
MCA-S$W<3=1.7$W@3M1.T$[P3SA/=$]83UQ/9$^,3Y!/I$^\3\!/K$P,4"!0`
M%`04'A0A%"04+A0M%"@4)Q0F%#P4/111%$,41A1.%$044A1=%&048Q1K%((4
MB12'%'@4A12#%'\4AA29%)\4FQ2A%)@4HQ3!%+P4O13%%,<4R!34%,\4T13@
M%($N*1.'$084L!$-.6DJ.SD`-`PLH"F/%H(T*@JG2KQ(C@5\(_$=C3LM-C`;
M=Q=94LDC?@T5".82@#X7)48D0B#\%0$=+Q=%/LI"Z5':"3L['E,!5?$]%@AS
M%/@3R2(X3KHN0T0#,<LCD%3U+ML%PA3^.^`59$R]'$A0_A@344HWB%*_*.LF
M42%#$V1/;A56,E(A;PL9"*Q44P<61A,&D#M@0\PP%D7C&,LXXTU]"QPI.$%I
M#T,ZI1MX'A=%URJW$>04Z!3J%/04^13X%``5`Q7[%`(5]A3^%/44$A43%105
M'!4;%2<5)!4F%345-!5"%3\5015&%6D58A56%6T55159%5@55Q64%7<5B16`
M%7P5?16G%:D5I16Q%;P5NQ7.%=$5U17:%=P5W17C%>P5Y17G%>@5YA7]%?D5
M'Q8*%AD6!Q8C%C@6/Q95%D860Q9/%D(6119*%FX6>19R%G<6C1:)%I,6C!:%
M%J<6J!:T%L06O1;1%N`6[!;P%O<6.PN2$BA3=AAK,R8TPBNX,G`5_#A`3NP7
MC3P&3ID*DS8640TNNC)&1`P5-B_C#]13Y0I/-RE3V#+S)\<<AP>5&NL%,@X.
M##U''C=>#!XP=#!63:T^(D]0-YL6D$DB&<$(;2+1,/M.4QM#*!L(TRVD.U\,
MT0ZE.Z<D4B8E1$8'A2M1-ZD-G29`#6\3%!T7+#XC'0W7'9$[=20M1-PH83FG
M3NTQ]R[`,2$P#12-(-THURAP1X4-O#8P4S`58#(>)F(Y^Q;Z%OP6!1<"%P07
M`Q<2%Q87'!<M%QL7*1<K%QT7.!<V%U\77A=$%T$771=#%TL7/Q<\%VD7;Q=S
M%XT7C!>'%X(7DQ>2%YP7E!>;%[,7MA?0%]87S1>Z%[\7O!>[%]07XA?)%\$7
MTA<'&`88"!C[%Q88%1@:&!T8'A@@&"(8(1@N&#`8*!@\&#T8/QA?&&<86QA0
M&$P83AB.&(P8D!B<&*$8IAB?&+$8KABS&-X8T!C;&,\8Y1C-&.08V!@")$`C
MOTP)3H\7NU`'/%@]&2ZY"I=)RC'_/%I3I5)X$<4YI%*0,N%3`3WE*'$HW1P[
M/X!+9$WC(P8H<S,D)@LD:#(03CY2MS0E)AX&#!#&5$<EUCB(*8-+$D[C4VU-
M@A$C.%I0+#B-+L@7?RV;#!M0/S*63XH%BP2502TWL2$--HL%73O)2EY05BL1
M/!09\Q-F('(LF5(#"@L[:A@I/@X(Z"9D4UX$8"0@$8,TVQ>.0S@3624`3L`H
M*""L,6P$_T_,&/<8^1@*&0$9#!D$&2P9-QDV&3T9/!E,&4H921E-&6498QEB
M&609;QET&8,9B1F"&:89L!FT&:\9OAG!&;89LAFN&:H9SQG3&=D9\1GO&?09
MU!G6&=\9Y1D$&@@:`1H'&A8:'!HH&CD:&AI+&CX:=AI/&H$:51IK&F@:9AII
M&E@:9!I7&ED:8!I=&JX:K!JO&KX:NQK(&M,:UQK;&MH:Z!KB&NX:^AKC&NP:
M$1L7&R@;&!LU&T(;)1L[&^D6,AG--HH\*0:N*X%441TE)<9$[Q*P+C@%FQ5W
M15L<:%.1/-`V;1*N'4PLT3;2-K0N;@IB)K(B6`>>&<,Y+!RB0[`^'B[9)1=5
M-@X?+L$],R1+.J\?_!0<4;$?1$SG&U\(DU*E1N)-71A=3($4?3^[-;1`2#3N
M+.]35SY6+L02ZQN0.8@+Y2_D4"XW81B<484;,!(P3KXU2@W,'MH1>0S*'WY.
M*`3?$M117S&6"F48?TZ#0BH3KD0T./P&$E/#-!H;%!L@&TL;$!L=&R,;*1LQ
M&W(;>1N1&YT;M!N5&W`;@1N'&W8;>!N7&W<;Q!N]&\4;OAL`'-L;$QS@&]8;
M]QO?&_,;YAOQ&_`;U!O5&^0;VAO>&]D;[!O7&UD<1!P\'$`<21P['&0<;AQ\
M''<<?1R+')`<B!R*'(D<C!R8'*(<EQR5'*8<F1RU'*$<G1R>')0<K1SI'/(<
MZ!P('?H<Y1SL'`(=YQSO'.X<*QU*'48=0QTL'2(=1QU0'2,=32<34^XW&!1'
M2"L3$S_*4`P-#PN\.#)2+$.X5(\?FP2C-',LV3G85.4B,!_#-7@7M$1P'K92
MI0K8%5\$[R#F(MH8ZPN.&=D4M#Q\1(@B\AWX-,\3H2E'1E8%BD,S$\84*C[F
M-;P]J$K+)+5$N2#'$P,/1#Y6.J<=R4-M&O`@`QV](`H*WT#I4`(IVPE;-)XY
MK@1&/A-$D!E\,^L4=44?/8!%@D1O&(Y".1/A/5([(A!P(^<2-Q\8&5-17D>?
M'Z@2+ATS'2@=)QTV'3X=,1TF'7P=<QUT'78=<AV)'9$=CQV.'8T=G1VI':$=
MSQW`'=(=P1V_';8=MQV[';X=N1T4(>\=[AWL'>(=[1WD'>`=YAT''N4=\QT?
M'B<>'!X='A4>(!Y#'C@>-QX['D<>-1Y]'E<>4QX<(%P>;!YW'H`>81YB'I@>
ME1ZB'KL>HQZH'JX>G1ZJ'JT>I1Z]'M$>OQ["'KX>Q![6'MH>X![7'M\>\QX&
M'_H>!1_R'OP>^Q[_&^I%IC565%X)?!"T)1DI7B:N"AHU[S>M,9Y3KS&;/[0R
MDT-].1=`U#R</S<4RC];!8A3HP?J%H8,8"G$)^LQZ4_<!:P+8">.*V<Q:#-U
M/5=4K!:15/Y!"E1"16LFY1[N$6LV^BLU3714BQ$:*?)%*DO,-[`Q]T6W0\`<
M'R*60V0VCRM#&P80BPI]#OLK62JT3;]$Y01K.B<T%`:H&=P4"@RJ*X!`G1-6
M0%0^+17#*XA$2"995$$&KQ:R2B,]QA7O'O`>)Q\X'R0?-1\R'SP?(1\L'SD?
M-A\C'T4?7A]1'U`?@!]\'W8?A!]B'VL?>Q]S'VP?8!^8'YT?MQ^N'ZL?QQ_)
M'\`?QA^^'\L?V!_9'\\?T!_=']$?VA_3'Q4@\!_R'_@?[Q_T'R`@&"`Z(#X@
M/2`\('L@5B!M(%$@6B!O((`@=R!B(%`@;"!?(&4@E2"9()0@KB"V(*(@LB#%
M(!XAT2#B(-T@"B'<(,P@SR#:("DA,R$N(2<A*"%'(092:4ZO"9((%PW/0K5-
M=52J190X[C_=%"(W;DL2'UI*BE.]+:H$FA4.+Z%2R!R\"P8U%#IL3M%";@P7
M'/DUOSRC$T%.U5!E%%,VZ!BC3O@\FD,K.]90@U3`/`P:J`?L!:L22`PL):8[
MHT=H0H54LR144[TR(2IZ40TIB"QH,!$F4$9W5%0;>#=T.QXI7`5&2>HV.RSW
M,L`:#D,>'$`WAT5?-5%&>#L8,TU/!55:4:$WTS;])E=-E1&>)B$)[51G'4,A
M4"%*(40A3"%A(6`A8B'<)V@A:B%[(6\A=R&-(9$ACR&6(9@AIB&R(;4AN2&]
M(<0AOR''(<\AT"'3(=@AW"'=(=XAZ"'W(?0AX2'^(?\A!"(*(@LB#"(0(A4B
M)2(I(B<B*"(U(C,B12)2(E$B4R)6(ETB8")E(G,B=")Z(GXBBR*`(HDBCB*5
M(I<BF2*8(J`BJ"*B(J$BM"*\(L`BR"+-(N$BWB+D(MLBVB+V(OHB^"+[(@LC
M`R,1(R`CC37#"'`VB$6<&E\9PE0@0ODR0D[D#)<XGQHM'!,W%1V*'9\9&3,1
M#+P>#A[[!9P(<4IM+GD[<DH]-SPV,ARL!I\R`R0N,9A&RS'!+\U(D2SQ))-$
MQ53T(OE+^T6Y)!A#I`@1'G(HI0A,2YD'>34<0]!4QU2K*6]")R3$)%$F4QBU
M-?Q2W%#U#H)"'TO0/&%.BT-E#*!$R!+)$E(Q_0;#,.9#1%`X%#)+%A;N5$$\
MX0<9,O1`1$NZ)$@\<RA].B(4,",L(RTC1"-%(V8C<R-X(W8C@2.`(X\CD".;
M(Z0CH".G(Y(CO".U(]4C["/H(^<CYB/T(^LCY"/P(^XC%203)!PD%B0H)"DD
M/R1!)#HD/20V)%`D7"1?)&(D9"1\)'TD?R20)(TDC"2C))DDK"2T)-$DSB3F
M)-(DR23K).`DXR3A)/<D^"3])`0E!B4.)2HE*R4')0@E%256)4TE3B5>)4LE
M"B6%)6TEBR5O)6HE<262)6DE<"6>)78E?B51-24X7Q7J4OP?]RKO*]<5&CVZ
M(#03.CC9%<I3*4W"`UP183K4*<8G301>$2X)AD#C!1\<@@K))\,@ABM14'TI
M(C!F&VP;-"E.*],,)4@N3"Q,1!(I!%E(@A7%,LQ.110.2A13>$GG-4TU]#*1
M&8]#+DI-2-8RA3*I3-X4NTV6$7LW5A)\-S0F<R[],AT5>@HQ$F(85PIZ#"P3
MP4*,+Y,CZ"_-)]51I#0W0GU$[D$"(F\:)QH/1$DW<!A['=<-2S>B)6PEFB5T
M)7TE:"4?)5$E[B7Y)?8E\B4=)OTE]"7U)?,E)B8H)D$F.B8Y)C<F6R95)E<F
M7"93)F0F<B9V)G0F;R9Q)HTF?R:`)GXFDR:!)GTFB"2N)K0FF2:#)K(FNB;-
M)L8FNR;))N<FX";[)ODFX2;?)@0GY28,)QPG&2<K)SPG4R=>)U\G0R<L)T\G
M/B<N)T0G,R>`)X0G@R>')Y`GG">2)YHGCB>))Z$GC2>])\LGW2?J)]\GZ2?R
M)V8*%T9K"EI4J3\V&I<8"1AI,!(FK33T`_XFC2]/,_8#H!H@1MX->R0X%3L5
M.17Y#ELV&1'T#]P]Z2\G"L\T3AQG(-P*:"F?&R-/,RA9&Y4D`QOZ2VT9VDF+
M,S).*PUC&&519E'+4$\)"5$Q3%<_FCTA$1]'Q3T:-Z(7J#C0)CH?D`5,#ML6
MO$#S1<0P``Q$#T4/^#U((`L,_"(+)@PF\$`X(Q,F&"8/#(XXQ3KC/3\C$RY[
M44$-/2Y6,VL=Y#WF/>LG$B@4*!$H*"@A*#PH0BA&*$0H4RA1*%\H4BA7*($H
M?2A^*(0HXBBV*$PHN2BA**LHS"BO*)XHFBC"*.HH]B@`*?@H^R@)*0$I`RD3
M*1<I$2D4*;,H%2DC*20I(BDH*3TI/BE!*4(I2RE3*4XI32E0*5$I:2ET*7PI
M<"EU*7@I>2EZ*9`IHBF:*9TIFRFO*;,IO"F]*;XINBG-*=HIV"G;*=XIZ"GI
M*>4IZBG]*?HI]RD)*APJ$"H7*A@J!RA!4)0Z&#M*4,A)/#0D(OT'?10>#JP9
M.0JV-4,VS4TS"!\70A)A+RHO`TQ4-<]`@3$#,+]!P$$F(O8.I@4X!!D'G31J
M/2A4_Q%#4;`ME"]"5-@2*$.R+'TTXB$_"@M(*R_]"5%%'!$L&$-431;/";0]
M>PR4*G1$=43K*79$)R[<0-)`9$5U'S),)1C+)F@W!#Z8*HL+;#AJ'.@\ER".
M&V-%`D7^/M,)QCZC#U8M+#"(%?4D'5!A.T8>:288.E4&$BHK*C,J+RKR*BDJ
M02I)*E$J6"I+*DPJ:"IA*G`J<2IX*H$J<RJ**I`JCRJ6*JHJKBJD*HXJDRJ;
M*L$JN"JZ*LHJSRK'*LXJVRKG*NXJ^2H<*PTK_2H=*QHK)BLE*U@K."M`*SLK
M,2LT*R\K32ML*V@K9RM\*VTK<2N-*XDKBRNB*YHKGBN@*Z<KK2NT*[8KMRO$
M*[XKP"O'*\8KU2O1*^(K!"P`+`HL"2P(+!PL+RP=+"0L&RPV+#DL/2Q>*5`P
M\A;Y-&P+9`UL+?HLQ#5M.*D+!R"!#Q0PUA880:<J839-$&$*=RG4+G`.J`-;
M+?\Y94Y'4A,V@3Y-0/@=5QP#$,H%]`B:,EH_>CF'/!X[AE,Y2H8FH!L8,(1$
M!BG)+OD(Q2C=%BXO)0N9'>P2/E/&*,X=F4OP*&]&'0@\/KXMEB:)#&$6($3N
M/)$1>5'1'<@8B`PD2;A#53ML$B]340VP(F@N"R$@"ZD@J2,Q)N<^P3&-#+@&
MDT9B+1U!W$Y#+%(L1"Q%+$LL2"Q5+%@L6RQP+'\LB2QD+'HL>2QF+)PLE2RD
M+*TLJRRJ+*PLI2S++-,LS"S(+-(LNBR\+-`LPBS7+-TLXRQE+>TLYBSK+.DL
M`2W^+/\L"RT)+1@M$RT=+3`M0"U4+5(M72U?+6DM:RWE+',M="UZ+9$M@"U^
M+7LMFBV9+;(MNRVQ+;DM-T?`+<$MT2W0+<PMV2W=+>`MXRWN+?`M^2T7+OLM
M"BX++O@M*2XO+BXN-BXK+J!#:@9%16`CK",_1V\H"1N"3I0IN#3=3C4IEBV#
M3CLR#D%`%OPF/1;?'?H;213)"I`K#BZ>%$`=!0]0469%_SMW0S0(,#7B3!A%
M22#C'P=%`SC('QT\43EB/$,Q1#'_%6`9DSW,0K,-A!'@+A(\AA$R"ULH4B?"
M0@<T-"^1(CH3^4ZJ$ADEH$Q')`@^-@?<+0T@[AE;5$(&U2P1#X\/P`0^"%M*
MWP<T*!L-<$;(2/D-A@WO,I,HNDFS&VP=!!O,,2TN12Y++D\N52Y2+EXN72Y:
M+FXN?2Z$+H@NBRZ8+I0NDRZ@+K(NMBZF+KDNP"[#+L$NV"[2+M,NVB[A+M\N
MY"[K+NPNYR[N+O$N]"[P+OLN^BX"+P$O!2\-+QTO'B\7+QLO)R\Q+S,O/B]"
M+T,O1R]&+TLO3B]5+U<O7R]C+VDO;2]K+V<O>R]T+W,O@R^(+Y4OD2^7+[<O
MIR^Q+Z@OKR^Y+[HOH"^R+\<OS2_:+^$O_"_7+]PO\"\2,`0PE2AT**@(#3K*
M'*<P[$?\1_@'GB39/9L]M1V?+]!),0B(*^83]$P(&3E47AH_.Z91W3XK0/<Q
ML$"9-?X2_5(M&=,@W1O]`]4*;BK0-6P7P$HJ3-M)4S,K,%@.(`Y\)>5+&`6D
M20)3G2T5!\T&<T6E2/A"6!A[3U,/[P[U+;<8D2I_.+T5H05L0`L3YU.24>@;
M]POE+6%&EQ2$)=TU:PAJ"?Y,>Q<Z5,(F2D%9$$D6Z`M$%2T6O1U[3.Q35A%#
M*E%2"S`3,`8P_2\G,"TP/C`U,$,P2S!(,$8P73!E,&,P;S!X,(`P@S"),),P
MCS";,*$PHC"N,+`PO3"J,*PPN3"K,+(PU##6,-DPWS#U,/LP[C#W,/PP#C$6
M,0LQ'S$B,2`Q)#$R,3`Q,3$U,3,Q.3%&,44Q7#%>,5`Q5C%+,4<Q3S%F,4TQ
M2C%[,9TQ?#%^,90QCC&(,70QJS&`,7,QFC'A,=@QU#'6,=HQ_3'^,1(R[S'S
M,?0Q]3'Y,?`Q&S(X,M!2B!G9$L(3U`P^"R@?&A'(`R`S(@JW,,<>@235.5]3
MU0P("'Q,Z@\T0`DEG0_=$J(URDI^!TI.13O*"6T)2T&*!M-!Z1004V\L8E/\
M5/H^2328.VX)I"_X*CU%*A]""2\A4T>U#$@7M@QH'+L_#$Q7+M$WA$/90&<>
M'"W%+)H^=2U"*NH+9@Z>-%T/C%24(ZDH<T#]+4TC(3&33EL4Y!9<*:(*:0OE
M3^(J#R7R!+4SIR",,T@./![<'B0S^SLD,B4R/C(P,CPR0S(J,C,R3C(K,DDR
M=S*),G4R=C)P,H0RF#*3,ITRJC*L,J(RLS+#,KXRS#*_,N(RY#+A,O$R$C,+
M,PDS`#,B,S,S'C,?,SLS3#-*,T8S0C,_,T0S4C-5,U<S6C-<,W8S=3-T,XHS
MCS.4,X8SFC.1,ZPSLS.],[\SOC/`,\$SQS/>,]<SV3/4,^(SXS/J,P8T_#,=
M-!@T&C10-#TT-C1%-#\TAC1M-(`T;C2!-'<T=32B--84.AEY,Z(#Q#]@!852
MJ!P()TX\;CW2#?H8UQ=V"_((BAD8$L4C13>+1W5)Y#?X&^L5#PC,4#8_M!^S
M!1%*^BH"!5LO/@\B-.HAYT.H/]E,VDR1$T`F#D8H+10(_D"9"Q!$#P;)+*4#
M84M](WXC>1VH*_]4%%6A5!$V64(`2:8#I32N'#43&"FO'(HO:QAL&)$8TD=I
M/O]3VC-:*^(9-SC:$YI201U$0"@'YC_[&_\/O4A'._HTGU"V&L`XZB-15,`T
MPC3'--(TRC3=-!$UY#0'->@TXS3R-.LT%#4=-1PU)34D-2<U*#4W-3DU+S4M
M-4PU3C5:-5XU835D-7`U=C5W-74U>C5_-88UBS6.-8\UE#63-9$UGC6X-:XU
MJC6H-;(UL37,-<TUTC78-=XU[S7?-?HU\C7N->`UW#4%-@\V##8A-B@V/38Q
M-C4V)39%-D0V0C9'-E(V6C98-FTV>#9W-G\V@#:(-HHVFC:;-J0VLC:U-K`V
MN3:^-L$V9DA^3:$J%4[:.4U3[15G-55&+R-%0#5,VCJL2L0XCPOV.!=.IU`N
M-JLE)C6P3:PE12#W0=@*MD6"/I<G\QJ=#K$RHE3Y,*H,@$W="BI-"2\C,?<L
M/$))$CE.D3;=!S4KA#LI+-LZF"<]0F450"3>$[L,@#R/*1)&L$B2%G)4J185
M5:,]%PA]+^TC.SA5)%HGXPZD/6HJ$S[74JH#`28!#,4P)#3F'I(+@1X80+D^
M\0<^33I**2#,!8@HA`<`4*\DR3;+-MDVVS;B-N8VZ#;R-O0V!3?Z-OTV&S<?
M-R\W*#<C-R<W)#<E-SXW0S=(-TXW4C=D-XHW6C=4-U@W<C=?-WTW?C>:-Z`W
MG3>0-X@WC#>8-[,WK3>O-\(WP3?&-\DWOC?/-\XWU#?0-^`WWS?E-^8WZS?I
M-^HW\3?S-_PW^3?^-PHX#C@%.`PX!C@".`$X,3@;."$X'C@?.#,X+3@D.$<X
M3CA/.%8X9CAC.&\X:CAZ.'<XC#B!.'8XDSCG,ALJ94=A)_P;60:M%CD7+0[!
M*!(XMS<N#HA&6P=X#JL,/CA,1N`8[P-<*RPH-5+A,)4=>RL"#.HM?1K`(-I*
M<S>M2MP6>0D>&3,W:B*U,K8IY`<93R8E5T"F&X8RJS@#*]<NO0B>#FXVSR2J
M3"TSXPI"&<$<XBD]3LT$'TS.*($U\1`D/0@2`2$>$C`V3A(Y(RLZ!D>K19X3
MH@U206H/;#HA1)A"\"=J3MHWPAR'.V8G1TW00J(Z9BX:1FU./TV:.*(XHSB$
M.)XXL#BO.+HXN#B_.+0XKCBR.-@XW#CH.-\XVSCL..LXXCCA.`,Y!#D'.0PY
M"3D(.1HY&#D1.10Y+SD?.2LY4SDY.2$Y+#E&.5<Y,CD6.2`Y1#DF.1(Y%SDJ
M.2@Y)#DE.6HY:SEO.6TY<3EV.74Y<CE\.70YI#F(.9(YCSF$.9\YACF:.9,Y
MF3F".;`YKSFR.;XYMCF_.;@YNSFW.;DY[5++.<\YTSG-.<PYU#GB.=<YWCGC
M.41"JA>-`XT:CAH8'-8+M4.K/]8K_"2"'<L'0#CK,A0F\R&\3>$,4CUM/+=/
MB#L+0Y(1-`_'1)P5O3E:'7\7JC:+1L1(;@0F$)8P7$`[+K4*W"EP,!<R[4Z`
M";90.!&I+7-+)@PF1+TQ7Q$-'?A%%B,K!NH.@BOW(Q@?$S1N,V%#1D,O._(H
M;$KZ19E$;4J<(]4D+AXT#J)1#`7)2(LLR1EG!N\Z0CRZ/A8T-3.00+`GEAK,
M+F@4<D[H!-$EP3G%4M8Y[SGQ.?0Y\SGU.?8Y_3G[.0,Z`#H0.A<Z&SHE.B,Z
M)CHO.B@Z*3HQ.CHZ-SHV.E4Z:#IE.E`Z3#I*.DDZ>#J<.GXZFSI[.H`Z@3J*
M.GDZJ3J_.KPZRSK*.L@ZQSK).M<ZX#KL.C\Z\CKT.OTZ!CL'.PX[&SL3.Q8[
M"#L`.P([-SL\.ST[0#M/.U`[3CM8.V<[6CMR.V([:#M<.WT[BCN+.Z`[G#N6
M.Z([K#NK.Z\[J3O#.[P[O3N4'LH[=P,E)R%&NS/@(SH_KD%Q-G(VQ3%K*/DZ
MPSY`*G5.TC#L3)5&+AR2'R)&+S3Z.J@?O!):!VXU>DIM0UQ--2`U)C8F_TKP
M,D5+^2=</C49"TYU)YM(LRIG%P(C!"0S'*H-)2KR)+LD81F<$EM1E4`;(VX9
M/R4U'-LD<QF$*6<;'"/G*.$<O38"/<$D&S4X1(A*."GF*H4&4CH!1!`+OQB6
M1:0,+Q.=184H_!BC%\<==2#[!&='[D_O3_XBIP:>0NXYS#O1.^4[X#OQ._@[
M]SOS.Q`\$SP(/`T\##P8/!\\&3PC/"`\*#P_/#(\.#PT/"L\2SQ//$P\83Q;
M/%@\63QF/'P\?CQW/'H\BSQV/(X\G#RA/)X\K#RJ/+,\L3RZ/+(\T3S+/,H\
MSSS,/.`\X3SF//T\\SSP//0\"#T'/0H]"3T6/28]*#T2/38]2SU3/48]0CT^
M/3T]6SU>/7$]8SUM/68]BCV&/9@]G#V?/;D]OSW#/<@]TSW6/=H]WCW"#D`T
MGPFS.-L@6U#[-UY,(1<L5-!#PQ'3$"H$0@I!,K5`]4WV33`AB3$D/HHQG$W@
M($@:C3.+,512QBR\/T421A)T%X,35S50+XDM#0V^,"@*:""<)8L3<D\\%0XP
M40<N0\<.BP;5!JQ/R3V*%5U+H!3L"TP:/2J2$\PF.TDS0Z,E($K&,'$>_3=Y
M2<@_=2QE,W\6"32&)!1%M1Y<-&\<SCY$"3`%4Q<M1NI0:A->0T@DS06!33=,
M>1YE#;(.31K8/>D][3WJ/>L]_ST&/A`^(#XM/CT^%SXG/AD^*#Y"/D$^0SY`
M/D@^2SY2/E$^73Y>/F`^8CYO/G,^>#YV/GD^D3Z3/ID^GCZB/K@^NS['/L\^
MT#[+/M(^VS[F/O4^[3[_/A(_!C\$/PT_+#\H/S,_-3]!/SX_23]"/S\_4#]6
M/UX_8C]N/V4_:C][/W\_<C^`/W<_FC^(/XD_F#^./X4_C3^A/Z<_M#^X/[4_
MP3^]/[\_TS_5/]$_T#_8/[<Z#B"Q,39-4R%B.F$IM24/#]4\6",Q%U@7O03\
M$5)`,!"%3;L[FS)Y-HTM4T!L)E\/[A".!'D.RS^[!ULKBPBE(YL;^3V#*JQ%
MD2M+'OHX&$:?1Q4V[S^?$[9-V"J!0&4VBD2O0BU+S#B,"FP\O%)<5"4]MTT$
M*Z@CP`\H-$-"!$$:3L8T:TM^'7X$;SKN"Q5"Y4`5)G\$^S6N&SE!AD5@%XM)
M<P5#&;=)[P\0+>X7Z1A0&L4I74K!0&]+^3PW4O8_Z#_7/_L_`$`'0/T_"4`+
M0/H_%D`,0"Q`/$`M0"=`*$`I0"I`:4![0&M`;4!N0'5`CT!J0'=`=$!Q0'Q`
M:$"D0)U`MD"M0+-`KT#*0--`T$#60.-`XD#Q0/9``D'X0`!!!D$900U!$T$+
M02E!)T$M02!!)4$L02I!/4%#04=!04%`03Y!94%906I!6T%U05U!9T%>081!
MHT&708U!@D&#09-!D$&[0?U!O$&U0=]!O4'E00-"MT'X0=%!X`>F.K@QK#VZ
M-X$.U"B,0!%2?@FJ-!\PMTQB'34HKS/^2H4=Q$`G1"(J<5"(4+DIS1:K)Q`,
M+R4-*BA$_0B,+,]4<3HL-.T\?%&^+PP>KC2.!I\FA!9J0M`;0E/]$78D#2$.
M(>1*F0C8'4LM+D2C+(T*O$9R.NL*MPF'#6(EHS>[25T?Y0P:,MD+V4,3.*,S
M?4MP",DE.$\C1ME2*$]F1$<JTT3-,00V&QV0%]]3DAZM!KD7G!':))$>LB,9
M+-HEZT',0;A!U4$(0K%!UD'[0=M!]$&T0>E!1D(X0C9"-$(Z0E="5D)30G5"
MBD)S0GI"KD*G0K%"UD+-0LA"M4*R0KA"W4+C0N%"WD+]0@%#[T+L0@9#\4(D
M0R-#+T,M0R!#)T,B0S9#4$-10W5#C4-R0Y!#B$.,0WI#A4-X0W9#J$.K0[]#
MJ4.V0[E#L$.F0\I#R$/%0]1#ST/-0^-#XD/M0^E#X$/E0PE$#$0>1/=#3T0K
M1!%$_T/\0SQ$0$1I-"`N=2CR#S5$RE((*$$E"2@\+]9()C`Q+:0534O&.3!"
MO0>Z-!`UO@<%*I,>XU*O4]`9CRYD+UI2[2E$$6LAWBND0J<ATTV?-%4G14;;
M.2L^'B@W0^88@D#:#8$*AT#<#9E3`11T3%U)VA(O$EX>+E)(#?=)4E*L'D51
M=T15-491+"%N"!\:5C41/W\G\P2Z2!)5K`7M-VD@_!=C1LE0<4GM+O<&#@Z$
M$Z86QE'645@U`TK[/N\L*!5!1E]0?C0_1$E$441*1%1$4T101&-$8D1D1&5$
MBT1H1')$@$1J1'E$;$1Z1)9$JT2A1-)$PT2<1)U$MD2G1/)$WT3J1.-$X$3K
M1-Y$VT0`10-%#$4311!%#T4*12!%*$4C12)%(44U13E%-T4Z13A%1T5&15)%
M245-155%5D5;15U%8D5T1>=%?D5X17Q%>T6G18Q%I$671:)%DT6U1;=%ZT7?
M1<Y%QT7)1==%ST7E1>)%W47>1?]%!T8"1BI&*T8G1@]-,BOX!@`'1PI#"H8B
MPC6F'3<=="QM'AX1*C:T4E$6GTIF(2Y%&3=.(^DMW3E4'&TC6B68(#@XHA3-
M4),G`1PQ2FL'9E,D.D\U5R6"17@(4B/3/-I-6R=("M\(J@IJ)FXO[1&J%IM'
MO@_U4>DQIC'G%C$B8#%./5(Y1!.*"KM$$`]9(_@/@T6$1=M-FQ.G3+<^G4<R
M&E,O-PU03L<[+A5F&?8UW$T/+:8?40B`!-XV["TS2[D>:1F,(@TF)R7..#5&
M.49`1C]&5D971EY&6D9M1G1&@4:&1JU&G4:@1IM&GD:<1LM&Q$;!1L)&RD;%
M1MI&W4;>1N!&VT;91NU&ZD;R1O5&^D;V1@1'`$<)1PQ'+4<D1R]')T<L1U5'
M14=21U]'2D=#1TA'9D=:1TU'3$>!1XE'BD>&1YQ'PT?,1^%'N$>_1]-'P$>^
M1\Y'P4?)1\5'"D@%2`Y(#4@92!1(&T@>2!5()$@72$5(/DA&2$-(6$A<2&I(
M:$AA2(I("BE>2NX.RT0/0XU`>@;S!QD<'3?0!.0%4!,.'553#QV+#+`;/PV)
M3I0100?N0[M&C0:#-0PJ^",#!"5/G1;_!W4[:BY\"#,FA`W".5<\_07\(U,3
MHU'L.\0Y6S]C.6($D$1.!YL)XB,$*$Y"&D,()'A0(0U/(,A.U3@@'85*#R0+
M1[9!K1*3$[X23P3T%VD;;ALD'>D5.@;$1U(6YR!9,'8J;RMP*](K/#F:.G<(
MSE#Q('4KO3T%)L!(]E$Y(4!"@DAL2(5(=DA[2'!(IDBK2+A(N4C,2-)(U$C8
M2-=(YDCD2.%([4CZ2.I(ZTCL2/]([TC[2"9).$DM23E)-TDP22M)+$F"25))
M?$ET24])<$F$259)64EA29-)L$FG2:E)G$F;2:))G4G%2==)Y4G=2<U)P4G6
M26A*%DHO2O5)RTDP2BA*04K$2<!)`DHI2NM)R4D$2MQ)SDEG2A!*ZDF52I9*
MCDJ:2I=*D$J32KY*TTK12LY*[4KJ2NM*[TJ&-_`_F4*,/;-,'23X$.$/?S,_
M+R`<,"QT2U,5UC3P3QL?\A7Z#6D=?BG7--0<(D`6(=DT@2DB)&$X-P[W%;I'
MASU"-,D>-`S743L)B!MF#4D.5!G^-*<42SF`%ID>S!I?-!5%CBU$&\<H9D_N
M!1Q%NS<.%192:D8B"R1"F$GF*!LA+D+V1S)"24<[#X`30S1$-!D>Z1NL$<Q&
MW`Z"&#8(XCR416@>6@V_-<U&RTJ--P(R_#[N&\Y&VTJF$#,2&T<#2Q5++TL;
M2SU+$TLK2UE+6DM;2UA+:4M42W9+5DN,2XI+ETN52YU+H4N@2[9+HDND2ZA+
MWTO=2\=+R4O12\5+TDO+2^1+[DOH2^]+Z4O\2_U+`$P03/]+`DP53"M,)TPF
M3#Y,0$Q33$Q,/4P_3%E,8$QE3'),G$RA3)I,IDQJ3'9,F$QU3)!,8DR$3(A,
M9TQ_3,I,Q4S(3,Y,QTS/3,E,[DP(3?-,^4SP3"%-%4T`31E-)4T,3?Q,^$PL
M361(S#I8.-)*Z$3I(#U$:"UR"1-,G5%31=P1!$4="0DX6$><-I]3OT422A-*
M#SL%"K<7.3C<%^9%SU`94RU12!4T5*]/CQ64$_P<!@]7)TH.6DA&+2`OFU(9
M%"%*;B"^2(]/%3]Z2<0T15#',+\%6$6%-#L$W`RY5+4\\%+'"VA0V$O"1:]&
M,DH*&N`73#E."%A$QC@?&&`(3!6!%O\T>!IZ'E49R1/+0^T_/#BK"H,/-BLX
M+.P0+QIC1U1%VQ5&$0)-%TT@305-0$WO3'9->DUR38Y-E4V=39A-H4VS39)-
MD4V:3:Y-K$VD3<A-STW93=!-T4W?3>%-_DW\3?)-[DW]3>=-]$WY33%.'TXN
M3B%.24Y#3E=.:TY=3EM.9TY63GA.A4Z$3I%.D$Z.3IA.F4Z<3IU.J4ZP3K5.
MN$[-3MA.VD[?3N!.XT[N3N9.Y4[K3NA.`$_Z3O1.\4[O3OQ."D\'3P1/"4\U
M3SM/1$]%3T%/4T]L3UU/7T]M3V]/[`:V/7])S22X4LHBDB(U00L<]U'*-4`,
M5R2N$-(B`$()/F@-,P6,"%5,/")',WTS\CFK`^-,6T3A";@>E$,W0:9!=A3.
M.F('?AI^'S,Z[%`T.K\/,QD6"1DZA1X@(HLT(@P^1&P[S#\_0PD2#0K?.T9*
MWRS<2N8.+S#04[X(8`F84Q$<:C$Y/(M36$`/(.<S:P\O41Q/DE17,M%3>292
M'1L+YD)L*5HX>09<&50PK$P4#ZY%7#!:.1M&6SG-&ET9<T]Q3WQ/BD^23U=/
MA$^+3X9/FT^83YY/H$^B3Z5/O$^H3[%/JT^G3\M/R$_43\Q/RD_R3^!/W4_?
M3^)/YT_D3P-0]T_[3_U/]$\.4`Q0&%`44!=0&E`54!E0)5`?4"M0+%`V4#=0
M/U!&4$=0.E!)4#E05%!64%Q09U!P4'I0>U"%4']0@5".4*)0E5"E4)90M5"*
M4(M0C%#`4,=0OE#P4.%0[U#;4!!1_5`(4?E0_U#V4/I0(U$=4211*E'Y$%M2
M?PZ,1$L3/3'Z/5L=[#%(31%405-F0H\:M$JO`T%#(RU_":\2OU(T2.)'\QD<
M1K`4KBYL,9XL%$F(0!E%^SQZ4I\WY#`\(PT:_!J0%'5+-RM'1(,K:4+N,F()
M?D8J/3`[P00U"EHR8#F:';Y-S$0I1,(\EDB72%A1NTQH!BP,,"5-+$XLO#=S
M4#PL%ATF3[Q4&R8V*,X'S2ZY%D="VE/U`Q0$ZQYT4)5)R1BS'2,J,0ED%T49
MQ0BO14Y/%S<I42M1*%$F4391.E$S43=155$[43U12U$U43)1/%%J46%1:U%L
M45Y19%%?48A1E5&"49Y1@U&&48Y1IU'`4<Q1I5'%4>I1KU&U4:M1WE'$4>A1
MLE&Q4=!1WU&P4=-1(5(M4BA2+U(Q4BM20%(_4E-22U),4EU28%)<4F)27E)P
M4G]2@E*#4HU2EU*.4I)2HE*P4JY2MU*G4K)2L5*J4M-2RU+14N]2Z%+T4O%2
MYE(54P=3^U(64P-3'5,84R5":4\J$#%132W]([80G$L0(5L;]U0/'ED'H1I7
M4U,L/4]Y3P`Y-C-$/#Y/0#&8."1&_DY'/(P->SL70UX;,AX@)G0N2TEX`[]/
M5!JC&GM*?$JD-WPU?"Z@,BP0ZCLF&7U2D1>8`TE+VAQ=31\=JAK/#W=0)D;%
M3MPD8CB70,H(YB6924L&>5#W1P,1O`J90+T*STBI"'TU`DL-))P)E$0B+H`9
MR4Z*2I$-QD\!2-@/[#ZM-4M%5T6:!61253B81?I2`5,+4P53+5,R4S-3-5,X
M4T5345-04U)385-<4V536U-R4VI3;%-W4WA3=5.)4WU3@%.74YI3I5.B4Z%3
MIE/&4[93O5.^4\)3LU.X4^A3Z5/Q4^M3_5/S4^93,53D4R!4,E0A5#A4/U0W
M5&-43E1>5$942%1J5'I4AE2:5)Q4G52?5*14I52I5+=4L52R5+-4R%3$5-)4
MX53;5-U4Z53K5/I4`U4$50U5$U4&50=5$54I72I=*UTL72U=0C)F&*A"CQMQ
M&!4711@<0AU"H"8Z%]`/"RC@,5LE\@UR!><YG4.6$AI2(%("2`-("`LC&M\^
M%$H52JD<+`2I&.,0V0J['"HBRA-V(.H2`4*?!L!27!Q4$AY"0@>E0)H9-0Y@
M5%@2<TK+`P\P\BSJ+ST5]"Q23'8LG3J2&2LBX1?/`R(ECRV1!>E,71RA/DHJ
M'T)I2HP@T0I%/'\9)"$3!9!0ETV!$Y8''A7G/`5*=A>"/Y`P[1JQ$1X\#182
M3]A1`0L/&X!!T1/8+:`VU"_*%+P)G!0\+?80HA9X3(0P?`7K/E](:T@T43D.
M_40&2P@C,DU-%-\\Y5)Z&PXMS"L5&W(Q3RL.!_XVEA4L3P`XL@R(1^X@7CH0
M2>-'NA'F,'$6)R,C!AU/TA4I3*T-PTG)0$@?<"*&%G`AGB,A&XLW9C^;(F$P
M]"`(,]$:2TJ*'\(_DC4B#PM0ER28-L9)NRRK-<9,*3#K1E$_7$'4"-('P"'X
M4D,N8R'J2])))15#$1I30SG`!05411&0%ELP)`;@*1$-ICCG(AH2QCU[22L*
M>2H!&$(%N"@>)WD:RQ-3,`94@ASL139/^1W,$\Y.11TN2]1&[5#V-Z`&H09@
M-/<W1@O03G12UB.W3N\+80G#-XT];R_?%$!#[RE3'6T[H1-E/",,)`P!4D4;
M(U#B#Q,?_"N<"VY.YP273M@CNQ+H!U8;K3B1`U93IA-4%;LV)T^A)FY*;P2+
M":T_$U*04VL&'DY43W@-OT[M1RTQI3<8/@4_F"VO$WL;/Q%!3),BER&I4MY)
ME3UE".$=6RZ6+)T*@D=_)4$T3R7,3*0PRDN,.K,2J#*)-N\NI%.,.8TI]T"(
M!4`]ZA5&(F,@9A*'1WA$[QO:/VM4(BB?/)@&HBY?"OE!4A]('<4=WA\O/A1&
M.@T6/N@^^C<T,K14"$Y.#!\.LD'01GL8WQ;""!HCPP0>,3X8(Q/W$O\Z@SI0
M/H!'&P>C%G4JKT0G*0(QUP9L2Y,IMR2]!@89O"9.0Z\_@DL<'R$524/13@0&
MT0^T.?1']4=31B`H'Q333H]-P05Q4K<2&T[A02P^CT*I";()TD*3/)E4AB6.
M-P(TJ#-80_=3ZB"I,RD*N@N2"0</%`Z)0K!/\B"<&RT*WPK$%7U&OCUY$`H4
MHSM!#$%"2U`A._A**R!4'3XUK0MS#,@HHPTJ-!)4)SV0-&\*^1DW,QHS+Q[_
M3EH].A&T3B]!Y2'K((0)Q1'[34L$EC$W/R)*0AU8)]$J>2+A"QXR&U,)(*\Z
M8BM!4B$L04=4'H$8AS>_+E(@9"U[%;(7.PX[4',T5TG"(L@DU!5?'A@:)CA`
M%>8T)U'#&KI%0#-M%,\BQ$&(5+Q3-4"!3%0XL@A>.W,).!U\1OQ(VA`0309&
MHP-G#O936C!`+(H-$#M".7(K:5`$'3Q/*3/W(-U'LT^9"4\>V!YQ$X5!+#)'
M'X,$I`X(50,%)$6^$[U1]RV*5&<+"C#=/]<9/4!%0AH7^S/7(B<J)D&\$<@&
MV2\4!>Y(QST&+W(@BRV`20(<CA"/$+E2`#4T4\Q#8@IG!>M1<!RB!]X,*B"A
M.8@^%PM_'P0N&$2%!Y8,N2RB.?T="C,K*U4=MS$%05E`AAZH&P@N$"`)+F(I
MR2C[))X_!36M5&PS:S%$#%U4SB\54;1,5!"="^)+@`Z!3XH)'#^0/$P3KE2O
M+E0(R3[:,ME/C`XK/;$;TR>\3O0%A`K8**(F;SP>#3$[:T(E(R0<?5'<,GY1
M$B]A5!HFX4[5+<0^,B`30SQ2/`[U.V,<LU&K4J,B>T*$&5E.B"6%2VX4Q4$9
M$PDP+#R,1[<@-$?82OE/XC"5-Y-4<B>9$M,*JQGD*9DTYS>]%[H4&2O8185$
MZ#K*1!4AZ4J2,I,-$`E'.BT&2`54-$H%S1!3$;$Y2!NQ2PH8_#\A07D4VE#8
M(BHP44ES)74QA`3L$Q,HI0Y4*$L)/PX(/WPMP"S<`Q)'\0YO#W$A83>_-U$M
MOQ/"2LP)[3B\%H)&Q";236A1O0,)2@PPVRT)!TP,$B$F)\@[&S,<,WPF/!`"
M%N<,`08"!HX@43-`$+H*8AM_00].UBV`4>,E'5+Q"@L0F$`,*"@G&T.:0`XD
M<C771",NZSN\-+H;4PS`5'!"'B,E(2DG+PTT$C@]>A`)%4LDIS61*7,#1ALL
M($TB3B*B1\0JNB&2-#<HEB1^$']1[D<Z/=\-3TMI33X)<$]X%BTA]TT!10D-
M!$:M$<`U:3?0(I8YX3YT"0\-VQ#S+)<Q5"I=-M$B>S)'4T`8P!BE+YL^]38*
M#78B_@ZD2O8DJ!BE%*E-%"JI2UTF,`KS1"4PA$KW![0=`"WD#S(R&QMV/TI%
MV3&G0_T21T<I3O\2W!MU)<806"#_+X]1=#9T0^H(]`N%,XM!I3)Y,5PW,@;^
M4E<BHTEE+.X3A3#A)S4$PRSS'V,UX3,?"@H3."?D+01+9BI52_XSZROA-Z<R
M9TE^-:<%PPL_(!X^11JM4NP](3,8$Y\U.T7J-%\:ID8@+/\QO!UW"G4=G"E7
M2Z8TZ")+#EDG$@W?`]!0LA'+(DI(F2\J!6<5:!51+QQ3"#;D$#T$@%*?47Q(
MZR$C2L@S33G(,"(1&14F("(>-!:Z*'PA`35R4IM.[%'U-W@F.$W9-QU,IQE)
M-6M0G3]L$\PS=5*0+6(G;E#K3WHF#E0W&LT_K@OM%J$AM4FX+[DRL!;2+<TP
M_A4U!6,I]BYA)F8V%S:O&S5(0D,\"S(,@`NQ%"),1QBE.:03$U1-$Z9`4`7:
M3[A,IT"B(705N%#40G$RS!3X'M\I?SM>&)52F2%Y!>\X^4`O3*00E2H+3)0E
M=S[\0B$31#L-3"4.YD2+/SLD&4N)"S$?E3'@0;0ZVQX,+5HQ.@25.=H(Q#V%
M3(L9L@4N$YP^8`V!#"Y'H%2:#:<<E#]<2V,531<<,HH2Q36R0^<_MPAX(0HR
M+B-:0N(0W@3B+O(])BC\+@U&4QRH4,4X4#9[+`D1+P7M0'P7FAL:);P$NAP^
M.ETD9DLK31\[_RJ,#UY"+28_#!\GOTW9*-D=+PE)4Y%`P1IQ1G90,![Q3V0'
MBR19$G81`">V%!4WI2&@&;U)M1N14R@17DUM'4H8O22"+^0EYR5V*"HG^0QG
M4EHFHD#("]Y40`:F(]$+6$:>!$0&1P:"!-H+209*!F`N8B[74*(+*4G.-:$1
MW3A)-G((YQ-:3)Y)23%63](_F#Z44\L,;1?,#)X0)U),":XM4PII"013QSP,
M/\TT1AIX#TU,!2UI26,>PR;)1D@0F1\.3$HT7@YM'ZQ)IS1K(OU%JR:&&M9&
M`B%L-N!4IQL"*XT1MC%Y&,A$1ACR/UQ*\D#M.NT%?A<%/#<VD$9F0V84,R4%
M&[`T,QB:$1HN1RL1%?%)U"+Q)<$,[DG(0=9.3R_[2Z\FN1/W$VPYW"JD/ED)
M6Q,U!OX#8![C'7M._$EM*4@AD#W:2&,#\"S&&]467`0"(`$QR"9Y,@L6`0]>
M3QQ'MC.13,`##$;K!@HCUDV;.0P1)`NR'#TZST^J+MPVHRDG2W)15A>"4)9!
M]R6Y.TD:@Q7&(T`%N`SL(&8%%$QM4O\>$4VH"T@]V0S*3:DNG0U1.Y9'+`H;
M/?(XH%`73&).Y1#Q%MT,%4`?+81(R@K21M<[<0XN"LM-&3O"*1,6`5!4.8\'
M9PHB.U`0>@XM*#,*G@R,-5@R.$9!38=)\A"1)EPY\"F8&;A/]SPY$1<&&@8T
M)<--)4R%*64EZ#W5,58W:$PD-H0_SA+"(90&W$1+.)!-C@S<&J<$62";!5(_
MPR)'%K4X<B)J4(9$3BCV5$\,#!3&&3$P-D754]0:RE0X+<))Y3S^##\Y9P=-
M"A,;7R*N#9HD54]2`V!(SQ)6$]1)\@QR)<00@05C!+H6L3/L2GI.7R&E0LT5
MA2=0#RPN5Q`^+>M+33K%(A\;43@9&L`,MB9@2?A#H@6W"RD66QI>13))^2ZD
M(G(0X1O.*RPKAT]<+LD4E"S.*?L):"3C%$5!6T^J._-.QT$052(;KA(.3Z<N
MLROB)DM3,%#-/+P8?0Q"-[T3PA=\&Z`8)D4U0E86GRY))$Y'PPF;#_DH7A-$
M03@D91SB%!H'@$+.-#I$4S'",VA2B52Q,+TC@RT/3(8'JD,A(+1+`C,V29DJ
MBS8D!9<YV$Q<3J<8!B.M0ZY#TSI[/"4L\$%&-A,+`52/5`%),T&S0S-.`S.G
M2WHJ)PGH$JHF.E,9&08S$RH',\-%`0[Y!;%&W@5#3QE`+E&"*NTF.`T%*P])
M_@>L(I,2!BOK(C(FNDZ6"/1+5QOG1YX(O4YZ&9Y+6PW[!CT/-"25)?`Y)PO]
M#L0,'BT0)0DC/A[!2RDCM1_4.J-*7`H_'B0HAR+_0&H:E3/D`Q$[LP\:(@$N
MN!=="9X[I!17`W8MA!>"#G`#@0,\.OD6$CX&"GXO]"3N!WLP8C$F2UH%ZCH5
M#G8KG"_$((<F&#$H"R@>N"Z9,TTH(@CS#7T7$!\%(4))M#;T+S,VB@<!&RTM
M^3_D'!(M3RG*&"\G1DS03,,SU4RY3?X_KE%U+YL\G@H/3]06+4+"3MXE@DR-
M1]E452HP#:0/G%"?3>$27ST?,MLPK`JA3JL+5$P+2R8QWU0`%QQ`RR@:)#I'
MUSS73SH\C%-#0[4/53QD-)0+;TY/$?HAXCK%"J(,<$[G2]H#E$^O'74PQ`A8
M33$EXDY)2;$=1CS=,&LN?4KP1WY*X2T_-KL*^$=X)TDK2BOB+0E%-![7.$PK
M_D<S!CTY9#DU)<,>LQ.H2:DFM`TO4"P/V#!,-#D$F%!G42L$/REA$P<MWPYK
M-SPS"D`2018J(E!&$W`1<QO7,34R=C%R-.Q&<T,$!!X(Y2,A!`T9!2)1#V(<
M>47\##,59"KE*^))<0\7'J%&_%!I)+DCL3HK1ZP5.T3`%D@BX2#E-:Y(83^:
M3@]`CTRE##LH^E.<*J<XM3K*&R%0\"8$#J@&CTF-#DP*TA$X#,=&(DBC&+HC
M54+P"-X9?T@4400>NS15-Q,U.#3$`SH6NRE1+D=.LT)*+P\2VS6E(G,Y?CNJ
M!;$@CR6`3%5#QTIF(D4++U2($89,,D%.%S,4F#$Z*M4U:`Z8.H1"%TIC"+TX
MEC[B08XN1S)2-#D=ZR_=2/%*1`3&$7<),$69#_]-2C+E$H(']2SI1*D0\R!,
M$"H5\DI],HT$I3::-2`)6"XV$DU.L4F2,^POPQ9M&-1*-"'A#B1*,U);0ML3
MUC7>&A0\R2&E36`H=RVY0&H0"U2,+8,^3CGY*VP5\2%<)]@&S`N3%2T'[2\M
M39XZ`E5A!QM,LPZ#'*E0#SE/.<H]<R`U.S1)XQ9R*8@M\C<[##,KV1A+"$-`
M>$"?*D0M_D]]'_\@CR;%1(]&?1D]"^`:@3O92H%1VCAT/-X^=D*Y-?=,40I?
M2=%#^@:#3+P:.PC<.D(L:$7G'LXV4U,S+2@P8$%O%DDO7T7&0RH_H0/63*\%
MVA3G`^(>CPC"1!`G.4O:1+`-F`S+"&)!J%'9+G4*84&#(0P)6@NH.BX&3BX.
M&04+D"_/#%5("U5]+003&@GD25I)1SXE1P4(<B&B1GXRQSC&.TI&,5#U!.,7
MT06-..`*]S@N!Q]38PJ`3NHP+CY_,CT3H4]K*D\R/A.M)0%.[B\/2)P$`@=[
M'BP5X3D14;@LHRT#+G(.6!S1+%`\23BR25LZZ2)G(1`%,3XQ17,8_AU)"C41
MPQ39!OLXG2SU%MU*.B%S4I0*U4,R/GTLZ"0\&SE-]$6<-?E4^%&2-V@*7T(R
M10,U[R_,/;U2E!@L+)8BBT@%0SE#:D4[(3P(AR2A&RXP+S9=*T!)L$HU%A(B
M6DX=!;TZ0#+Y(F4C^TE!/=PT83,_10,2!`G#/Z`*O1A_#&!.*R/@$``E@5,]
M,[H%%3N7,JM+5!\L,X`*'`L2)R$K?3TZ&OHY1$<!0%08`RS&(=,[ZRAG([,?
M42023=L(A4*X0+(:W1#0-#$UY!=S/38UJB%I4P,OP#(:.O(Q?SI8"'<2DTV^
M+)LK1!!D*WH5,0;80'H7_S^@).T3SCG@)U8H"4B).H,0-B=E*I@I/$89+PH_
M5A@%+"(?PP--#SA,!S?6(8,R8SIX+>0.6Q=[-E8Y/2)C-!U$;U"%1=M."SV]
M#,<5AQBO2ZD/""FM*DPDJC_N1#Y.-@4H.T)-C0@*/CH'7!=R''<8FR"4$GH(
MGS\#4FTZG"!$&>5,J#WJ(M)32"DS1:XS=#@S%TDIWDCF"E%/$2"70Z\0/BH:
M,2@E(R]\-N0)=Q1=)>P\Q08F4^Y0:S[')^14B"`+"8=-R1PY%.D.V3SZ"&4I
M(2)G)_4OSR@N)=DR<"^J(/TKAADP0,$F1AR-4)1*1!JL4N4;T45<&LD\HT:B
M'8PG^!BD1DLV!#M)0;LC"$"Z4Y8@(`BF!-!!O"JQ&>Q2D3'90;,ZN@^H4S8P
MDC@7%/D1&PQ7.`P6IRC^.;-$,$>F*_`=V#KA&>1%B2^J'$9&%$&=*M5'ES,<
M(@\X12IE2S<QJB5.-L4[RAK%!7]%:1-_/"TO)RSH&6=+%D08)/`'Q!BD*<(9
M1B:[4CY)OB@O1@D4YCEI.G0W\#<U/I$(UR/E5+LOT0/V+YM#Y49Y4^PD5@-/
M(N([7B/"#XE`<`L45!=11`4/+H14E0L^/$8/N3&(,HU33QM)3>H>`!9=*N$(
MCCT60DHFVCRW%;X,ZCFW4-`H("O1*#09>P:V$\PC+2+'$7I!$2VL/_\8ZPT,
M0PU#TAI[)F,1Y2I_(1)(&0Y,)LL69T/Q#XL^'D"@/Z<3&#:R&_P0/B&Y4"P]
M>$\C&39("1#50KE,/B*/./897T"H$S100`AO,]$X21@7([$N%C-+.U\E<`VV
M3P\F-C8I,?(%CA?84V87T$1Z2PI.;Q*M%U,$ARML%I4-9BM(3&L)1BY0,E,R
MI$&))EDRE1D1'1`=H0L/1V-!EA\+3UY)+1%#'&,?``VE&#(O7@=5)4LT`D1#
M/4@U!2/;/[<9JB@V"^,9633&0NL#3178.YDG!T/S)H<@R43%*W8[EB/1&V<:
MM3[=4<LADU$D&YH0@`A<0G\@T0AA'X4N4BLM$[@%8TU)"34ZX1%&1U]!]4R"
M!1<SF1A//GA4FQD:2?\K8QWY#UP=<#H8(^T8'49^4(T>NE`8!CI2%U1M1=](
MQ2K]+F$#T!.*,K`J00CF#,($UT(<)K0[BR&82!Y)>B[F0`$VECRU.]TRM!1$
M.G$+1P<3+\D,=07@-CH4&%0[03Q+%1JN/;(G@"&2.SHWXSJN/VD4\E#S4$TD
M;TK!3:,\%"Y(0EX<DA3&*9X@T#J[5+8[MSN7$JE`X2R4*+@[SBZP5*\^<448
M%E)&32:!.0XJC2Q_*?$>)%1$%DHN:TR$.LX,?E)>-UDS$T>'-8HY.":X'8@P
M70A2):`P0S\I0Y<[7`XQ0+D0;Q]W!FH>UPBN!7X(ARX`!-5-[CV:04D502PY
M,(,#DC`'"APE-4?C,GPP]PBM)/I/!D*9-^@%[2VR*04ZMQ.R$_L2?R[Y4U$>
MRR#&!-1.BSI\$X=4[$F`+N\[^D,Y&4XP"R69,1@B=E.N!^)1GT$,!)LGDS=;
M!@,,[$\O'+M#2#I83(I2>Q1U/]DB_@620+4G&P[4-GE4EDG>*#\BWC)O#'`Q
M_PAP/"0JN4O&")@2AQ]L!NLY2RB)11(,^B?`3FH=]@<Y)>M")T*[(14Z;`4'
M4&$RN`GC*$89MALO,:0:WS+>,`,G%C>*1:-#N0E!(W4ZMR=.+?L9AC!Z.YL1
M.#/B-#E(<3SP0Q<AVAWP5*0F<3-X)"L0^$2H3E\;'!T]4@D.Z4:32Q80&"%[
M+ED]0C'./<\]$U`U#Z8W;B$='202?#N6**`@IQI?32(F*$[8+X4Y%!2?1`@3
MCU()$P<+_PR"(G$7HQWG%`!$#SU.)^8QZ!'+-Z46=Q!X.<(G&362/_53&2*Q
M0QD]P2MN&E<Z/08I%8-3]"L!'])03S9>%!@E+4JY')P&9#`:*JXD.BSI-HE$
MD"9&3X$=GC(4,Y<9PU1>2$$;*@N/3J-+)0\9&R]`+1+J*]@@X"'D)ZD.!@WR
M,.PK1QPR$1@5E47P1BL8=4B?*51"(AHG)I\Q(DN>,?L84".51QP,ES_<4QTS
M93+@4[PD!0;0/:(9D41O$.\6NPF1(%H2Z`R!2ID#:5381NL.+%,T&))3:!NK
M+?<7#!O/,ZX&2TM#(SXNLD5N'6\=H3)6"!]2WRM%);\D:AN_5/4BQ#?&+[,C
MU`]&.K4+(2ET!@$%ERA*0[@B#2@$$7<H<!T0)%`'XAS02*H(P4-Q'3-"(!;G
M!R0NWB14#+XT)B^)*<%4.2GD3B8N)B&I/.12$22A-A](*D7Q!"]%.RKB1ME1
M_D+;3*<QX`A<"08@?RJ?3-=-R4):+8@#A3SI'NP9,$MR#`D,,48$4"@QS0>L
M--(H^`7!3N%`3T!F3KT\BD%-!MPQ,@C**7DE`3"\*Z)(=3;F'/(*P0GV"_5#
MOQ'C+@!3"BVZ48!0XR?4'[0P6"BV0OE#!DR6430_/U$[)S851`Z!)0X_H`G2
M(8(DWT:`-<)1DU`N%E$Q`3YZ(]<?3QDI&&,:91XE*;`@GP.\1:X1K14D$^0@
M+E2;.TDG]@I'$KL/KC)#4.U1)4OJ&0Q4.P>B//<U:@6I)YP9L".G".L([`C,
M'P$$#`\)(:TF2"O?*LPI_#F!-^D:X"I91[0%3Q>U!6PW;2'*(5<%;AB!-M<V
M-$-$';`<#BRJ0ATZI@]V3V`MLD^:+]M"72<_!M(%@C;G%^\5JQ2,%%T1&`N#
M&%D6$BPA-W$C6"3M*/8]3#<M(`).`TZ_"-,T(R?B"#DW<B,[1\)`:$?Z$+D:
M2DW#0(@8SP2)&-4TLTC%0)`$L`,?0+E*AR-`-78I:PM9)N86/!UJ#@4@+PQP
M."$M84]#)A<DF1N<,$0@(S0`$&T+DPGL*$T(0R!)1J(J9$NK4`82VCN/.[I$
M3!1J#&`40#J=!O`UNE*Y1.@>Y3)E,=`*B#R^4N(8"Q0%3M\S'S\'(2\SGC.-
M*.Q4"T(N(+I-LB1J1Q4G5P=2"!I,Z0-C+#D,KC=^/4M./"9R,#,-DQNR!E1*
MMS7*$%P5XR%:*)E1^$G%4+H8AR5R2#@YR%'M-*(H9%#.+<D_^B.V#P@UT2]Z
M/14NYSN!(?$70C58"_,5K`_N,?\BF#SU%7$PK2&B0J4:QPC[+ZL-H1GI.\=`
MR$!`%W,AL@]P&MD[E!F8)/M$RDFD48]*%DB2#\,0>#AF+R441$Z'4?XOG0G'
M$'0T/0Y^)P<_R0:$$(DYA1`6$7,67$Q%(4$S*T6%"X43N4*`-X4X%#'?4'Q#
MN@UH+P9*'Q!5*9Q*_1]O":,HASA70Z%*ZU(I2-$UPT*("LI'HDJ'3!(.W#_^
M+2`0J@L`5#$,RBCX)G!`DQS!,FD<R1N0&Y,A_0W<$P<=ST["+CTG@0=I!5)/
M03`,,:X3ER,0%)47*3Q:%#!/X40J3HH6Q!>L3F<J^TP#":\MAS&?./9((PG"
M1R`:8`<G%WT6#T8.(X<#*BS9/I%&QD@J0C<M/04Q.>`B:$G'4?!3Q!/]'N90
MTB-1-#(;7CR<$W,([1LY0B@.HDQ1%0X?T30J':T=GC!0*G\5;4&N%2\;<2"L
M'$HPU2%?,YH[5@2_`ST>R!.71RD:3DZ=08$\`QS##>,#D$+T2J<VB#7N)KP^
M`@X:,%,[.DUB0TL2IRTD$5`;R`W[2@=2%B@H0KHEP27]%TQ1&$J3,TLRCQE.
M%;L@Q1B'3JU,L0I-.V47_1H$.A<6[0J*3KA+6ALA0M4G-B4D+6M&C$Z[&[P;
MY"S*$@$WRBPW$BPO-$YD"A!(N0/^*K0.G@W!&.4.UBQ]"7=/8R=M,792>ABY
M3[5**E/E/F@GA0\T2ZI!;B=O)WP8NDJH%%8'="JF+((,/1W"-IPY"@GI*#PQ
MMC1_,+(-]$(L"U4/%T>;2A<B-DX-,5D*]1V\#PL/.DR63=X6Z4T,0=DUSAE-
M'UDV#CS]%)53ZBQN2)0RY2=W#V4A62AZ'&<XE%(/5;X5Q%";-$119A\Q%GL/
M*4>F(J,V_19/,.)05RO@/G,IKPQ%+Y,_[RTT'S%'^Q&73%!40`\_'3`,*2VI
M*UD_ZQ#@.=T)F$NJ%`4ILP;V//]1DT^>%0PKZS9Y-_$I\BE33M0G*2NK!JQ!
MDT"+(TE"=$IY#00]8$W[)R`-MQLO+SM()$`E0*-"-APJ*Q4KP"3J)0T;>@,E
M$B,-#BAY)YL#G1+L)>L$$!@1&!,8[@:\,V`]JE"L"?`S@A^%'V(][!&L*_<$
MCSVH&B%)+0],"+$<QC4I#NT/GD''-9@S62[U2ITV^"Q^++I4G00\2L%(UCQM
M!$H>=!A2+]H&LTJM%-@\J1NL`QL8&A4@,N(]FDM,.ZD]3D94(F,%YCL24!DF
M(B=N3-A!.DE'-^Q$#4)0!J(V="#=.F(&8P:#.4H5:Q7L&`021QOS(W%,>"]2
M*JE/+1^@+98GM$D:2"Y`11#Z,NDXN1@*4SY&^3OX2"9(F$$J%^@J'@G/1]T8
M)TWL/P$0RP001A`&S3Z()QTJN3=H3D)*1DV/$6\[:$,:(6$,3`;0#>E%#T)X
M)0\9C1\6&>H1$SF&.O9"D5%\-!(9%A,.53`K0%'""Y=0F3V@,8,(C4+.4V5"
M;S7D/$H\]06(([0CST2L!`T1+30N-/(74#/8+,L<&@Z^+L,\Z#N/1!0OMQ3_
M!8PC<CPY*)\6.3-91F,;WAR+'=((Z0PH&6]#:3+5#UP_XQP2)`9`R#5%$]4J
M(C6N%%I`33,T%Q<)B2,@-G-.%#AB0+44<`3$/#(5=$Y5%``&94"I&M(/73_6
M#QH3S1\(0\!$$$-<&X9.I22\+_H9.DMV3L(OM0.[2MQ#*1GT2#`/Y3,'(^A#
M*CH3%YY%@4FA1;45S3HC(Z@Q'A!G'&$:D"Z]-5=(/50L-4TR#RSK/!,R)!"$
M*NPJ013R+?),T`QB1K\K'!L3%)8-D45`"4<0%4>W4PL&?A)B$7X#D27G)WU/
M(SY&#I@C#S\@$RU%.2J_0@$SHT]^#T(MP!0600LR(1`M!4$/A@F!4G\>=PY+
M1B8&;5"N%MTV\C.I-#H0!@Z('8T'$"M/!Y`AH%%2$W`3CT6?*U@B/A"]*RD-
MFSAU36])1CM!5`$*FRS3(_D<:PZ=._E&NBUY%RY-@S]\!$X0+PXY#2(O^C"!
M)U()@1_I).L7#C/S$+`06T"''H,C6SB,28U)^2$4$$,&J3#J),`]<QQ5/I`:
M%"-T'&XI"SZS"9!+'$[K&&$77!^^/K\^E##9(\`^&50:5'(+2`_:(T`\8A=;
M,OLAC`RG'X`SD4FV-B\]LQ#_$&M'X$"C(<-+0U-L1VE#"$6\2=Y-X3:.#H\.
MFQT`(_`D>21W,&,_]"E-#)Q(KA<Z,[H5UT:P1ZL:TPA`-A<KKP9).SPP>C;K
M.A(C@"KV(2XL<S"Q":LA^B:B%=L]GP47-6<]JQ'&4/0WF3^T/A<3,!2!%:0E
MFD<7,!DD+255&TQ/SQ<5%J$@P!ZQ$Y])TS`H4*@FE3Y$"V`WWBIB"(PN>0</
M/&$@B@1R,L$1R"&5#]T:0P0$30)1A!7F(>@P7P<@!_A-QRQ-/*H..#HZ.4)&
MPCNM!80MYB]B$-0AA20S$3-,U`EK'$,MVTBF">`.H$IT(;52!3Y+#SL9]#3T
M%G!#FC!X*!@G)2X2-0<^GA_],(E+PDOO)'\23`_#%3\3K4+53UH&J38^!``\
MTR;(%4]&W#>*(&4&<SIC0#A(FDCE.H(A[39W$;8G2T+6)VPP;3"Y)V\&<`9Q
M!J8F<@88-YX2<D4@2,E/7#J,2)XGXQ%Y$?<1Y3BM!R<;/`^5.@`_K4_B/LDU
M(DV^(%X*]DJS$;01A3OS2B!3@TD65=,%FAZ^/.`$T@O4/9\ZX010.9$0!Q?+
M-8L]_QUQ'-L&C4@S/C`WNST*40`WD@IG/+X#*S9M),HCZCPZ(E!/6"5R%*H0
MN@Q$*<,G;"']'$4DJS,*(%4#T#*K+D,%YPT=(E,CM!70&FPOJ"`S/`A4:3-^
M(60Z[Q`]"-\ZDQE@`T@HUS(<$JLJA2RL%)T@X"RC)T=*6ARB!F$&;CP@*GLI
MM4NO5$U&%PZ7"`PA+#&/*"<0^2,_,5`,VS('#@`;VU-P2E4(;@8V4E(XJ0SN
M48<%*E1N+*TY_R@L&^,21"3O(:4UTPO60TY(P2`V$:LD`D('!VTM]1!C!U<A
MJ@\I.ZY,"4*42+\:[A9=.5T=CE/<!IQ#B`<527(-\A$%4(I``1;[$)LN<4[N
M&/<9EQK,')H8D@.5/#D2CD"?%4((SSJ7/$@'4Q2?0CTCLR?D.MT\'TFJ0%`L
MF3P`*OH%6TUP1>P>U39"(UA3IS=P"GH-?TI@&X0UN@F60-U#P$\Z$@L7%BOY
M1U<LJPC>0XHIRDXU+3@/\#Z&$,H7JB3&09\/2R'E%I`5TU`0'`XWR2VK$W$U
M2!;K':`7]D'C,/<.%QG&2[`?<$W9!.!08!57#UPHH#3_"5,Z'Q':4;\5944F
M*2D'$R61%21--4,</7-!N"NI`PL%D`OA&/`0SPNL*J=!PTC%'#9+AU#2)YHF
MUAWD'U)-)1G;*!X68RTG#S8>>R6)-X(E!TSQ$^0A20V-3U@O#%,I1DL<`T=S
M2>!1;"2<0:<,,D,Q-]92&Q*R%4Q`X4QC3#0-HR,X2I(8;PA'*(8<]C8%22\'
M2A(W!Z0MWP4^!XH^%Q?S$<T<L0.6`Q)#'4Y;$HPP]42_*2--IA)5%W,.&3\!
M/R\*L$8A4U91?R\&1=<UJ#913KU`<U%-#>XH'DPX!^,$^"`;/SU*B#07,8PT
MD!_K,#)0ADV=+Y]2?"`G4X(N$B#R+]5.D1QD)]10\CNB$T]($#GE!1T_'C^A
M.J0GU2E7,-L\"%+\-?H\A`^,1N`T03B1'S<1"!<_!\%2MDJG*7=2<PT)%ZPG
M,"#&.H$S/RIJ"H(L?02D&_`98`:2*8Y+ID_Q)_I*F`J!!-LC:TJ[#C,PD`ZY
M-`]*P#J^0?TSEE,B!JI(M3VG#_`AI4R'1GH@Y$PJ25,(["R\-<@>S"H?+WT-
M4!R$%#`B^B7<"2DF^QQX!OD*33W.!0L@7A#%##(%X@0'*2@&\2-*"GU0^#([
M-B4O_4:213(AD`S%'L<D*U0Z"9<ZSQJ/)*`\UBXP*)@==RZ2+`0/*@\N#5$G
M,"["%C<C\@,P/`\7C#%U%TXD8Q>,/AY&T3Y:(;P0]0D=1:0ZVBAZ4WQ2%3A8
M,&$CWCS-(V)4(R+",<,QZ$?T$>XVZ4>X%+1(KT%?,!,,8#".,O41_!F,,M4:
MP$PR/>$TV4)D5!DC&S9T.LH5(S]G%N8Z9#+M"1=2N"?$+_X\3$+\!\T/\4?$
M39=4[S:H-\\Q&U((.N0H34*"*0A0CRP6!+4'<P84#)4T!@8<4F)-L45'&0H'
M,CLV1`4G\T\]$+PG)3\G"+T.VQW1/?I'BRG"3W(>W1>(2^PA5!?T$#]3$"[S
M*=\VK!<^-IDPL!AT,CXTPQML"!X:OA3T*B(3"#!V-E9#@1>P'@$5EP_N2OX)
M$1=D%=@7G2423%DUCD\@-%0GI0E03`@T;1Q%+>%16#J$-/,]?R.A,<,=+4A7
M*G(X4E#8-U%!&R7>"CL3SS++,[(Q_T$W3>\1ZQ;*%CM*&3"G/0(U;#]*)!\K
M?@OU-2HM2!,3(_@AH!/A.JM,($PQ*&(T%09;*J$S\P,+*D8J0Q^&2B))`S^-
M,*92_T</*/4H`SW"0SH<#CHY(%!"@1E()74&TS682E$&#D5X,TE4##L,(P8Z
M/D!&0$=`F4P:%"5*U`/X!#0%O0LY/0\SFB+*/NT453"\3%<[2P<O1$`O3`>C
M#%0LI28Z*#-$TDX[/;L&N2)Y*$@42#/,(3XS>B3Y-E$C*P[=$6M%6S5K#5HC
MM`9-$?,O9Q%1/?H$Y@5<*DD3)1']-8XT#16$([TO,5/=-Z<[5#W");8&5SW`
M+[LZN"F]311"#@J//#<O7SGU&?4':C"2/!M"[T,Y4@90^#E>*K\OG1H1+Z(W
M!ALB*YT('R;=*T`E\P^]-,42+$OU,^E"-SG-4GE,A!O;#R8;[1Q`4"U4$QD!
M-.DPV`R(.!!/.A69)98ZHCU-'`P&`@IH(KX%64-=1_<T#5$V(4HY/Q3H+M8W
M0D3O,QA/9S,C4Y(V@C(Y/]H%-@U,(H--%T2R4#8C[1F5&"\5"A*Y)>H%-`HN
M.]LKC@_3*`@0@Q884654,#H7'7\0\!BM(\XQ(2;84,4OURG'-@(J`RH@-[-%
MVR9F,F<R,BV-(S\NO`9S-:`/J`]A+8H8H$*N#SL7KP^P#[T?:DUK3>1';A/W
M1&869E37)VD6O3?2*JDQJC&Z$Z5%44W!/F\Q;B;]$VXP`P;0,;!%QPJT1\-/
MBDRV#9LU?!XN!'48`C\P#LP;KTRR$&HS-S=J%^0^ABRZ'EPXCP2X31LPBRB^
M0.<88BB!3L\13Q+Y+"%,7C!)+.\7TT*\#J9.^`U4!]\CHU)S3'I,>PJ(0OHM
MDBXQ"V4WIDF,!3!2C`3;$;L47BC54A%/[T'7-TY`'BMP.?0'@PH2*W<SYBU/
M'%TT-#?\!1$.\C*?.X0>:SP30OI"5"LG!)LENCWL0?Y3R`?L)H!4S#:6&*5.
MT`O$110V;#2P'<L4!1SV25`G[4$D4P<2"AU,,.T79DIC*VY1KC'J,95(X0WB
M$I,TLA\((-$F!U2S3B4M?%!X'40**P_R$YA2<DEJ%8\T&!?W+VDG(#].!&4T
MSS!.$_`%(1R+0!,@SPY`!R-,LA8=,,8M&D4"//P$I1."3X$@<A7^.&`/&`W-
M.XX>ISFL&-I#)A&R`R!`3E#"4A!+U2:H*3\^DDEJ2NT&8$#4'7PB8A810[(4
M3AJ*)%$3V2%N16X0/R$P/:LKWC>#3Z@[@C.]3&XM=5"S%NX4^#I506<T>C<<
M,<H9K3UA)3LW/#?:(1$KZ@DW)9M4(D+C2T,X&U3&,<XSVT-O+98+,!S3#CT,
M%S\`0S4LH5';1\DXXPF)/N<D72-E+^H8*3W%10$7E#QW)&4',1XF0H\@8R69
M1@8YK`P_$/@S949)#(\&\`3!._0<X!+(,F]1Y!)M-Z4E%C]5'%('_#LB(P4S
MSP5?0_]"-QO$'5\F#!R?"V<9,@H"4I\..0=W458=%0\I"TI22B!M$*$,5C`6
M-A$N#R]N,>\*$2%!,9<12PS:4B<GI@C:)KY4V42J4<D.?"QG18HL(##2&.@@
ML3=F%014<#.Y%8E28@_.(_81DRUU2F(CWRCE'^0(/A]F*7,GE50Z)2,K9U08
M4LHM`!G!3$X.TCA%.,L9,SV;&!]%R5*Q(VA4)1P<!AT&S!D--3E/]S_X/\),
M@@L<-AD/_1E/)JA',#0Q-!@==P4!$3I(K!.W-M<<L$(R/_$893F5-B5&JT#;
M'*\7/$$[+_`VNB?(*0(YTSCV%1Y4`#W0.YU(N13$2Y$RT3&L0)8V2C@C)OD#
MJ20\&AHL-QRP/98TWQQ&.`0J"!4@.P!2,U3I,WD?B4RF);I`]ST-'($O\!%-
M-^5*>0.D0]TID`E&(,P$I3T-5-Y*YDRO"QY!G"NF320_=%.,.[,@#""F*8L@
MMPKY,RDIJ$&Y3J`L%02Q)SH%]$083,X13`3),,4M82CU.ID3JAC].UH6@AY4
M0",1#AS('==#LD;L%"DE#B;#'/TXJSVQ%C@WQ1D2',TS:B>45/$17R/C"+@5
MDBW'+=`.SS@65&X2%@_]$"LTJ1/X&1D&[#9/0FHT@`8X'#0<VU*,'3,T1%.^
M2PE0O"%S1H,&94V7-/%#"P<4'KU&,SO^&?)4JS>L-WH1H!8')[Y&NRMM0D]/
MP$-P$O@5K1BS(CI/\3;$3P\4H1:9.&8E``G"),<YF@-!-CD<_$4J&<DYZR7=
M)JPIX"N\4-]#!A%Z*"(6224=0[4-QQOC/BT$Y1<<3']/,`<6,-<A-#XW3ZL8
MJ2*`3SPAX4NZ,4(X=`7^""T]J$#T/PDUAATX+]$<E$!*0B<9#A3W`\0QSCOT
M%9E(J"1_!G)&`2H8++I+GA:I-_%49"7@#!%(X@PN,_\IT!P6(!DV,14Y!;8>
M4SY[(G4530Z8&*\4_"'V!3@H*3*W(KD&TP_6*C\$H$=M)B)$SS\2"M-#WD?5
M/<4\O4M2!E0C6BI=-:H]&AP55&Q%"C6\'[H&HQG<)D<L.!H\*\L;/2'S4CXK
MR3'X`QDX!B<<#2$+/$S80DI)E#3.#SPEX#/%!](#51)63%9!M4<O0F8T&1=J
M3\%/`Q;G+;-)0!.N);D?;`?61QL3RPXX&[@243;Z$\HXN1(M+.0$A$U742$9
MG#/M$E`2OT#$',TX0TW+$FE(`R$$(3`P=QGQ4.8$WT?D1C!1R!&Z$L!`RBX9
M#8T4,C9K)]<K2A,A/_XKNR4J!@E2CA2(3=<+JS0C1`\*=`T4(+)(<Q4X4DM-
M$TA,3>9&S3U-37@]-4L5$#I!)Q')%9,#65'F1S$8*D1U'-8FPU(W2"X]?1C5
M*#@VH2R1%)TUU1UO14U73E=/5U!745=25U-75%=55U975U=85UE76E=;5UQ7
M75=>5U]78%=A5V)78U=D5V579E=G5VA7:5=J5VM7;%=M5VY7;U=P5W%7<E=S
M5W17=5=V5W=7>%=Y5WI7>U=\5WU7?E=_5X!7@5>"5X-7A%>%5X97AU>(5XE7
MBE>+5XQ7C5>.5X]7D%>15Y)7DU>45Y57EE>75YA7F5>:5YM7G%>=5YY7GU>@
M5Z%7HE>C5Z17I5>F5Z=7J%>I5ZI7>U(0"JDI,AC(+;T0*BEV'"8<C3YY&3$_
M;@=409\@64U)!ULA7"%V!2-"72$Q(&P^/1\Q/;00M1#3(J,5?D%$.-PC#1XD
M+^`H(S"K.503M`/=4\,O:#1B,@T%U`[A*$,UU1PS()T^Z$:*3<<Q.R4@27M3
M4"*6$&,CD3C(,3\?=DIW2D`?'%3/(V,/<3&7"^$4%R`3(7A*[U1=&^PY[3EQ
M"KHK'3:V`S(T-#WR&#4]`A%.'E\J51.#"XX^J4?U%\5-JU>L5ZU7KE>O5[!7
ML5>R5[-7M%>U5[97MU>X5[E7NE>[5[Q7O5>^5[]7P%?!5\)7PU?$5\57QE?'
M5\A7R5?*5\M7S%?-5\Y7SU?05]%7TE?35]17U5?65]=7V%?95]I7VU?<5]U7
MWE??5^!7X5?B5^-7Y%?E5^97YU?H5^E7ZE?K5^Q7[5?N5^]7\%?Q5_)7\U?T
M5_57]E?W5_A7^5?Z5_M7_%?]5_Y7_U<`6`%8`E@#6`18!5@&6`=8"%A-,&0C
MM"KS&#Y+1PNP038@9`_B!]X1]!A*2\9-&4/G0-0X#ACP"IH\VD*7-KLGN!MV
M%=P<DSMH%]L+W`N"2LY(\D=D&]\E>SUN(@P]#3V#2H\^QRDT1%84?#V#";D;
ML3Z)4/H#MDA,2<\N<@H>4M@GOTOT*`<&"SKB4\-,5T$@(>A*23QV.MP=ATI(
M&0@&3DLT._\9G1'=':<F^T=8%.D?2T-,0Y`^XRGS5&9-4$OH*+(^34-L1HE*
M1##(.8<I,4()6`I8"U@,6`U8#E@/6!!8$5@26!-8%%@56!98%U@86!E8&E@;
M6!Q8'5@>6!]8(%@A6")8(U@D6"58)E@G6"A8*5@J6"M8+%@M6"Y8+U@P6#%8
M,E@S6#18-5@V6#=8.%@Y6#I8.U@\6#U8/E@_6$!805A"6$-81%A%6$981UA(
M6$E82EA+6$Q835A.6$]84%A16%)84UA46%585EA76%A865A:6%M87%A=6%Y8
M7UA@6&%88EAC6&1895AF6)I);1LK3\1,Q4\C23Q(13!`+BL92RM12Q@K.`X1
M3F=-WR1O!WLH$A@0*`\Z%$Y22R$6OS1*)3PIMCC5!P-$12=D1BT8;E).054C
M43+;%()-&COH%R4T2$KD0*4GJAM)2D5)G1F]3Q,K##J"*-0>;"<9'4=#K0P>
M'2$=>D?P2S4,7P8V#%0O*U/.'#TKZTRT)X$)0"'_)I0MYA]!(4$?TB6\0W)'
M7QQ"*^`E"E!$'],Q?"=[1S<,["GI%S8)[A*O*V=8:%AI6&I8:UAL6&U8;EAO
M6'!8<5AR6'-8=%AU6'98=UAX6'E8>EA[6'Q8?5A^6']8@%B!6()8@UB$6(58
MAEB'6(A8B5B*6(M8C%B-6(Y8CUB06)%8DEB36)18E5B66)=8F%B96)I8FUB<
M6)U8GEB?6*!8H5BB6*-8I%BE6*98IUBH6*E8JEBK6*Q8K5BN6*]8L%BQ6+)8
MLUBT6+58MEBW6+A8N5BZ6+M8O%B]6+Y8OUC`6,%8PEC#6,18L"OP$EPOU#21
M-*(L\1*>0]`CLBL5"I\2C32Q*T8L6BR65)TN7!+8&=4>-A9A/5L^7AGM(GX8
M%PH4&$I*4`V;0MH^ARR+,J`.I4?&*JI'#$Z-#4!'KD>O1_10V5`B#<8'34FV
M*MQ/MT?7#WPH7Q(1+,!-2@S8-#`)3C_(4EQ1)"O[`X0&)C\)!B@)?2LS#P]4
ME15A#U<2C$WE"%<4``B-37,\[SRZ.2$2QD!!!-(.(C\[4J\TD#C_.`$Y^STW
M($(?Q5C&6,=8R%C)6,I8RUC,6,U8SEC/6-!8T5C26--8U%C56-98UUC86-E8
MVEC;6-Q8W5C>6-]8X%CA6.)8XUCD6.58YECG6.A8Z5CJ6.M8[%CM6.Y8[UCP
M6/%8\ECS6/18]5CV6/=8^%CY6/I8^UC\6/U8_EC_6`!9`5D"60-9!%D%6099
M!UD(60E9"ED+60Q9#5D.60]9$%D161)9$UD46159%ED761A9&5D:61M9'%D=
M61Y9'UD@62%9(EG"&C@@L4=M/G<ZI4/%),5(JT&M08L8UD0/&(M%]4!K3W(N
M.RVS,9U/)QP=5&4;:QM+"I4)E@GS%_Q&YDK41-$$*4]F.1]4$PJK1TT@KSUV
M)W`GT@H/-=5$YTH<+N@?M4BT"U1.[4S_"KY)E2TJ3[8+R#153K9'T"X%$1]!
MBTJN#)A4E0X`"QT?(T?9%]5*]"<Y+P\5.B^L1P4H"B@0%90AZ@Q])^L,8Q8T
M-(8&8@OX%R,AE4033C<D5B8"%%PE[R8C6219)5DF62=9*%DI62I9*UDL62U9
M+EDO63!9,5DR63-9-%DU6399-UDX63E9.ED[63Q9/5D^63]90%E!64)90UE$
M64591EE'64A925E*64M93%E-64Y93UE065%94EE3651955E665=96%E965I9
M6UE<65U97EE?66!985EB66-99%EE66999UEH66E9:EEK66Q9;5EN66]9<%EQ
M67)9<UET6759=EEW67A9>5EZ67M9?%E]67Y9?UF`68%!]!H".@9-HC$V$T<@
M3"5V`VL6B3B8#WT;7$1#1<$-+ETO73!=,5TR73-=-%TU739=-UTX73E=.ET[
M73Q=/5T^73]=0%U!74)=0UU$745=1EU'74A=25U*74M=3%U-74Y=3UU075%=
M4EU3751=55U675==6%U975I=6UU<75U=7EU?76!=85UB76-=9%UE769=9UUH
M76E=:EUK76Q=;5UN76]=<%UQ77)=<UUT775==EUW77A=>5UZ77M=?%U]78%9
M@EF#6819A5F&68=9B%F)68I9BUF,68U9CEF/69!9D5F269-9E%F56999EUF8
M69E9FEF;69Q9G5F>69]9H%FA6:)9HUFD6:59IEFG6:A9J5FJ6:M9K%FM6:Y9
MKUFP6;%9LEFS6;19M5FV6;=9N%FY6;I9NUF\6;U9OEF_6<!9P5G"6<-9Q%G%
M6<99QUG(6<E9REG+6<Q9S5G.6<]9T%G16=)9TUG46=59UEG76=A9V5G:6=M9
MW%G=6=Y9````````````````````````````````5:GRI@``]*;UIN"FX:;P
MIO&FXJ;CINZF[Z;FIN>FY*;EINBFZ:;JINNF``````````!HJ6FI:JEKJ6RI
M;:ENJ6^I<*EQJ0``<JESJ72I=:D``':I=ZEXJ7FI>JE[J7RI?:E^J8"I@:F"
MJ8.IA*D``(6IAJF'J8BI````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````*&C
MHJ.CH^>AI:.FHZ>CJ*.IHZJCJZ.LHZVCKJ.OH["CL:.RH[.CM*.UH[:CMZ.X
MH[FCNJ.[H[RCO:.^H[^CP*/!H\*CPZ/$H\6CQJ/'H\BCR:/*H\NCS*/-H\ZC
MSZ/0H]&CTJ/3H]2CU:/6H]>CV*/9H]JCVZ/<H]VCWJ/?H^"CX:/BH^.CY*/E
MH^:CYZ/HH^FCZJ/KH^RC[:/NH^^C\*/QH_*C\Z/TH_6C]J/WH_BC^:/ZH_NC
M_*/]HZNA````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````Z:'JH5:I
M_J-7J:2C``````````````````````````"<_0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MG?T`````````````````````````````````````````````````````````
M``````````````">_0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````)_]````
M````````````````````H/T`````````````````````````````````````
M````````````````````````````````0/Y!_D+^0_X``$3^``!%_D;^````
M````1_X```````````````!(_DG^2OX``$O^3/X`````3?Y._D_^`````+O2
MH;9`@=_&08%"@4.!\LW)U?W(S\G"SZ+8N[+KTT2!I-CSLT6!J-?2QZ?8P,I&
M@?#'^[&UTM2TJ[:_RZG81X%(@4F!JK9*@;W!S]%+@:7)K=A,@?:XOM'<X]#6
M38%.@>&W3X&NM%"!V<%1@;S84H'HS:2UJL[WUE.!]L#9OJ_85(%5@5:!R\17
M@<.^6(&QV+3#Y=)9@:[6VLZGU?6ZIK?6P%J!N<;2Q<?'6X'4N5R!R[/2TEV!
M7H&_V,6^\L:RTK#/Y\]?@6"!88%B@>G*8X%D@<#898%F@6>!:(%I@6J!\L+2
MPFN!Z<AL@6V!;H%O@7"!<8%R@7.!=(%U@:S'=H%W@7B!>8%Z@7N!?('+P7V!
MZ-/YU7Z!PLK^MJ'8VM/WOX"!QM2EN\'8Y<ZNOH&!@H&HV(.!Q]&IT(2!A8&&
M@;W8[]GVS;J_AX&[O:6ZX-+ZLN"ZML2(@>W/J;ZDS<'!B8&*@8N!U\?QV8R!
M]-F-@8Z!CX&0@<O(Z=B1@9*!DX':TK+*RLCLV.K8QMCVO<W&\+.4@>O8\;WI
MO96!U,C3M):!EX'8PIB!UK+0U\O*^\O,U;:XR<^9@9J!FX':V?#8JL><@>[8
MG8'ZM.[!U-*>@9^![=B@@<?2[]C'PZ&!HH&C@?;1I('9UO+8I8'UV/Z\V[RF
M@:>!J('.R*F!W;>J@<*WJX'SQJR!K8&N@:^!L(&Q@;*!^-C!TK.!M('ISK^\
M_+>EM]W0M8&V@;>!N(&Y@=K6Q=/ON^&[\=BZ@;N!H<FPSJNTO('SV+V!R\GV
MV-?"]]B^@;^!L<[YV,"!P8'"@:ZRP+G#@:/9Q('IL,6!YL'&@>S)QX'%R\B!
MQLNDV<F!RH'+@<R!S8'HM<Z!SX&KM="!T8'2@=.!U('5@;O.S;6AU_37T]/6
M@>7,UX'.NMB!HMG<V>#3_=CPM_?7_MCZV*'9X\39@=J!MM/TV-W9VX'[V-R!
MY<7=@=Z!T,#?@>"!\-';L.&!XH'1O*;9XX&EV>2!Y8'F@>>!K-FNV>B!J]FY
MRNF!ZH'K@:G9MM;L@>V![H'>LZC9[X']P/"!S,KQ@:K9\H&GV?.!](&PV?6!
M]H&QMO>!^('Y@:FY^H'`TON!_('`S_V!_H'"PD""Q+WLU>"RR,?KOZW908*O
MV4*"ZL[NND."1()%@D:"1X+6QTB"28)*@DN"3()-@DZ"3X)0@N.Q48)2@E."
MV;3MMK395()5@E:"5X*AOUB"68):@M[9SL?^P+C96X)<@EV"7H)?@M?+_;=@
M@K7988*WV:.QX=.YV6*"Q=!C@K;99()E@K'99H*RV:G!L]EG@FB"\[S>T*FX
M:8+COFJ"O=EK@FR";8)N@KK9;X*SL'""<8)R@L+9<X)T@G6"=H)W@GB">8)Z
M@GN"?()]@GZ"@(+$V;:Q@8*_V8*"@X*YM82"\[Z%@H:"AX+(S/*ZT-*(@L/9
MB8**@NB]BX*KLXR"C8*.@L79Z[Z/@L;9N]G?Q)""OMG!V<#9D8*2@I."E(*5
M@I:"EX*8@IF"FH*;@J[5G(*UUIV"X\>>@I^"H(*A@LC9HH*C@J2"V;S*V:6"
MIH*G@KS9J(++V:O&J8*J@JN"K(*M@LG9KH*O@K""L8+VU[*"H\VS@K2"M8*V
M@K>"N(*Y@KJ"H;V[@KR"O8*^@K^"P(+,V<&"PH+#@L2"Q8+&@L>"R(+)@KS%
MM<W*@LN"S(+-V<V"SH+'V:6S_K_/@M""T8+2@K6XTX+4@OS`U8+6@M>"V(+X
ML-F"VH+;@MR"W8+>@M^"X(+A@N*"XX+D@N6"YH+G@NB"Z8+J@NN"[(+M@O:T
M[H+.V>^"S]FBM-#9\(+Q@M^T\H+S@O2"]8+V@L&P]X+X@OF"^H+[@OR"_8+1
MV;7)_H)`@T&#0H-#@T2#18-&@T>#2(-)@TJ#2X-,@TV#3H-/@U"#48/QSU*#
M4X-4@U6#5H-7@]+96(-9@UJ#Q<%;@UR#78->@U^#8(-A@V*#8X-D@V6#UMFN
MR6:#9X-H@VF#U=G4V=?9:H-K@VR#;8/;RVZ#J;UO@W"#<8-R@W.#I\9T@W6#
M=H-W@WB#>8-Z@WN#?(-]@]/9V-E^@X"#@8/9V8*#@X.$@X6#AH.'@^7(B(.)
M@XJ#BX.,@XV#CH./@Y"#D8.2@Y.#E(.5@]S`EH.7@YB#F8.:@YN#G(.=@YZ#
MGX.@@Z&#HH.C@Z2#I8.F@Z>#J(.I@ZJ#JX.L@ZV#KH.O@["#L8.R@_FVH]C*
MU+.#JM36T.2SU]6T@\C/XKFU@\N_MH/BP[>#N(.Y@]*VNH.[@\/-[MGPV;R#
MO8.^@[.UOX.UML"#P8/"@\.#Q(.DOL6#QH/KR,>#R(.KR,F#RH/+L*NY^<'B
MV<N#O,"RN<R#V+G+T/BQY,;?ON2UR-?-@_C1YKS>RLZ#SX.]O.;9Y]C0@]&#
MVL32@].#U+B]R-2#U8/ALMG4UH/7@]B#V8.PP]J#VX/APZ+:W\C<@[30W8/\
MOJG%WH/?@^"#VKGA@Z/:XH.IU*3:XX/D@^6#YH/G@_O9K+;H@^F#Z[?YL?S9
MY;/VONJ#]K^QTN3`ZX/L@^V#L[;^V?W9[H/O@[N^\(/Q@_*#X,;S@[S7H=KT
M@[G!]8/RM>C!]H/W@_6\^(/5M/F#^H/[@_R#_8/^@T"$081"A-W!0X3]Q$2$
M182XO+*W1H1'A.^W2(1)A$J$2X1,A$V$[-E.A+[&3X2MO\N[4(11A,JU4H3)
MV]?04X2YS;RP]K/WN\K;K[I4A.34MK7SM=;8T,A5A%:$UK?0Q]?85X2OOUB$
M682[V]C86H1;A,S0KKM<A%V$7H2^Z]#!]<'RU-6XM+1?A/6S8(1AA+[)8H1C
MA&2$T,5EA&:$9X39Q?O`:(3PL6F$V=C.N6J$O;5KA&R$VMAMA&Z$QM:BRZ_(
MLLG,M,R_;X3TN7"$V]C<V.>VP;SJS'&$<H1SA'2$=81VA/?/=X3=V+#'>(1Y
MA-"YH[UZA'N$WLQ\A,K&?81^A("$@82"A.#8@X3>V(2$A83?V(:$AX2(A/ZP
MB83GOHJ$H\KTO(N$C(2-A(Z$L;B/A)"$[KB1A)*$DX24A)6$EH27A)B$F82:
MA.+8FX3+O9R$Y-CCV)V$GH2?A*"$H83\Q:*$HX2DA*6$IH2GA*B$Y=BIA*J$
MYMBKA*R$K82NA*^$L(2QA*;!LH2PR.RPIKG3O/'.O=O3P;.$M(2UA+:$K[;Z
MUJS%V;V^V[_;MX2XA+F$^,"BOLW`NH2[A+R$O82^A+^$P(3!A,*$PX3`V\;*
MQ(3%A,:$JK+'A,B$R83"T\J$X\/+A*O1S(3-A,Z$SX3"V]"$U<#1A-*$TX3#
MV]2$L;_5A-:$UX38A-F$VH2\Q-N$W(3=A-Z$VL??A."$X83BA..$Y(3EA.:$
MYX3HA.F$Q-OJA.N$[(3MA.Z$[X3PA/&$Z-G7R?*$\X3TA+2Y\,[(U/6$]H3W
MA/B$_+#2M/F$V=#ZA/N$_(3]A.G9_H3+WNO90(5!A4*%0X6PV*^[L;%$A=>S
MSMA%A4:%T=1'A4B%L[WOOTF%N\]*A4N%T-A,A4V%3H7+MT^%4(51A='84H53
MA52%5856A5>%6(59A5J%6X6EQOC'O=)<A5V%TMCDQ%Z%KLI?A:?'8(6FV&&%
M_<GGSMR[Z[!BA6.%9(6JNZW0986PL>37O]=FA:6U],+/Q&>%:(6ILFF%M[)J
MA>6QLM^\U:B_K,+5V+'":X74V-3.;(7@VFV%P,YNA6^%M-BNPZ'3H\YPA;2\
MM,C1PG&%[;ZVT'*%X=ISA72%=85VA>3'=X5XA:>S>87RMOS,^L!ZA7N%]\!\
MA;G1X=''V'V%?H6`A8&%@H6#A82%WK*%A8:%Y<"'A?&ZB(6)A<C8BH6MU(N%
MC(7AS\G8C87*V,//CH7XL\>^CX60A9&%DH7+V).%E(65A9:%EX68A9F%S-N:
MA9N%G(6=A:7(GH6?A:"%V,^AA?[(SK*BA:.%I(6EA::%UM/FLK"\T=.KR[2W
MIX6HA:F%HK>JA:N%Y<JLA:'(W,KDL?#0K871Q:Z%KX6PA<7;_K6QA;*%VK_%
MN>2^[<&SA;;?M=^[UM"]V=7(L*.VR;^HS+/?M\K2T[2%S]BVTL6ZOLN^S+6%
MM]_PM;3?MH6WA;B%]=.YA=2S][BZA;K?NX7/NJJ\];6\A:S-^\/SNO3`PLWR
MS[C?Q<^]A<#"N=_PPKZ%OX7`A?V^P87?P<S-]]+-M\'?PH7$W\.%Q(7QM\FP
MUK;4M\6%K+K]S-2_L<OTQL:%J-;%W\>%XLZSL\B%R87\SK6TRH7'SO"ZRX7A
MSLR%O='-A<Z%P-_/A="%]+31A<JSTH7FN+O?TX74A=6%UH7%Q->%O-^]W[[?
MN\6_W\+?L=3#W]B%NL?8SMF%VH7;A=R%W878Q-Z%RM_?A<_?X(7<UN&%XH7C
MA>2%Y87FA>>%Z(7)W]K?ML[IA<>ZSM_(W][%ZH7KA>O)]+K\P^R%[877ONZ%
MQM_OA<W?\(78Q?&%\H7SA?2%IM7-NO6%S+Z]T\"X]H7DUO>%Q]^^N:>_^(7Y
MA?S!R]_,W_J%T-_[A?R%_87^A4"&V]_EWT&&U]_6W\G7X]_DW^OEI]+2WT*&
MJ;]#AMO41(;(O]3?189&AD>&S,](ADF&W=]*ALK12X;>WZ>PM\;3WTR&Y;I-
MAM^VV\W^N=743H9/AM_?[,^EL.??T=_&T=7?V-_9W]S?4(:INU&&X-_AWU*&
MXM_FW^C?M--3AE2&5896AE>&Y[BVQ>K?VLFHP<3$6(99AMZ_^,]:AEN&7(;<
MU>[?789>AE^&8(9AAF*&N+)CAM^Z[-]DAL';98;DT6:&9X9HAFF&],N]M&J&
MIK!KAFR&;89NAF^&\=_&S/+?<(9QANW?<H9SAG2&=89VAG>&Z=]XAGF&>H9[
MANO??(;OW_#?O;M]AGZ&\]^`AH&&]-^"AJ.[@X;;RJC.I^"JLX2&IN"%AH:&
MAX:AX(B&B8:*AHN&_M^,AMG-_-^-AOK?CH;0O\37CX;,R9"&D8;XWZ&PDH:3
MAI2&E8:6AOW?EX:8AIF&FH;[WZ+@FX:<AIV&GH:?AJC@H(:AAJ*&HX;(MZ2&
MI8:AQK;)LL#UWZ:&IX:^Q:B&Q-CYW_;$J8:JAJN&K(:MAJZ&H^"DX*7@I="O
MAK"&M.#DS+&&L>"RAJ:_K^"YSJO@QLFSAK2&KL"NX.VZL+JIX+6&MH:WAO;?
MN(:SX+F&NH:XX+N&O(:]AJVTN>"^AK^&LL_(NL"&L.#!AL*&PX;$AL6&QH;'
MAOK0R(;)ALJ&RX;,ALV&SH;/AM"&K.#1AOO4TH;WW].&Y\74AJW@U8;WT]:&
MMN"WX->&V(;9AMJ&VX;$X.'0W(;=AMZ&O.#?AN"&R>#*X.&&XH;CAK[@JN"D
MR<'@Y(:RX.6&YH;GANB&Z8;(RL/@ZH:UX.N&R\[LAL/+S>#&X,+@[8;+X.Z&
MNN"_X,#@[X;PAL7@\8;RAL?@R.#SALS@](:[X/6&]H;WAOB&^8;4R]7@^H;6
MX-+@^X;\AOV&_H9`AT&'T.#.O$*'0X?1X$2'PKC%V$6'1H='ATB'28=*ATN'
M3(?JT$V'3H?OPD^'4(?/X+W@48=2AU.'U.#3X%2'58?7X%:'5X=8AUF'W.#8
MX%J'6X=<A_;6L+-=A^S77H>[RU^'8(?:X&&'^\YBAV.'9(?9NF6'9H=GAVB'
M:8=JAVN';(=MAVZ';X=PA^'@W>"MTG&'<H=SAW2'=8?BX':'=X?;X-G@W^!X
MAWF'X.!ZAWN'?(=]AWZ'WN"`A^3@@8>"AX.']\:LV.O4YN#)RH2'A8>&AX>'
MY>"(AXF'BH>+A\&XC(>-AXZ'CX?GX.C@D(>1AY*'DX>4AY6'EH>7A^G@X^"8
MAYF'FH>;AYR'G8>>A[^ZY\R?AZ"'H8?JX**'HX>DAZ6'IH>GAZB'J8>JAZN'
MK(>MAZZ'KX>PA_G/L8>RA[.'M(>UA[:'MX>XA[F'NH>[A^O@O(>]A[Z'OX?`
MA\&'PH?"R,.'Q(?%A\:'P+W'A\B'R8?*A\N'S(?-A\Z'SX?0A]&'TH?3A]+$
MU(?5A]:'UX?8A]F'VH?;A]R'[.#=A]Z'[>#?A^"'],?$R^&'[N#8N[;8\M+O
MX,7-XH?:MN.'Y(?EA^:'YX?HA_'@Z8>PU.J'ZX>GP-&T[(?MAZ?.\.#NA^^'
M\(?RX,RY\8?RA_JYO,WSX/.'](?UA]3&].#VA[+4]X>FR/;@]>#XA_F'^H?[
MA_R'_8?^AT"(08A"B$.(1(A%B$:(1XA(B$F(]^!*B$N(P<U,B$V(3HBERD^(
M4(A1B%*(VM37V]G;4XC8V^>YW-O=V]BU5(A5B-K;5HA7B%B(68A:B-O;H;/?
MVUN(7(CXNUV(M]9>B.#;7XA@B&&(8HCYOF.(9(B[MV6(T-NNS+*_M;OXU]._
M9HAGB&B(:8AJB.F_:XALB.&\L\S>V].PZ\[8M[G7PL9MB&Z(I,!OB+G,<(CG
MV^';NL;CVW&(Z-MRB/?%<XATB'6(ZMMVB'>(Z=O`OWB(>8AZB.;;Y=M[B'R(
M?8A^B("(N;2LP*+"XMODVX&(@HB#B(2(S=#MVX6(AHB'B(B(B8C=P/+;BHB+
MB(R(C8B.B(^(D(CBMI&(DHB3B)2(\]O2V[BYJ]3LVY6(T;_PVY:(T=N7B.:U
MF(CKV^6_F8B:B)N([MN<B/';G8B>B)^(^=N@B*&(HHBCB*2(I8BFB*>(J(BA
MN:.PJ8BJB*N(K(BMB*Z(KXCQPK"(L8C'L^_;LHBSB/C;M(C2QO3;M8BVB/7;
M]]OVV[>(N(C^V[F(\M.ZLKJ(NXB\B/W;O8B^B+^(P(C!B,*(PXC$B*3<Q8C[
MV\:(QXC(B,F(^MO*B,N(S(C\V^#%^;O-B,Z(H]S/B-"(I=S1B,/,THC3B-2(
MT;;`W=6(UHC7B*'<V(BBW-F(VHC;B+7'W(C=B-Z(Z;;?B."(X8BGW.*(XXCD
MB.6(IMSFB*G<I+'GB.B(S+7IB.J(ZXCLB.V(L+_NB.^(\(CQB/*(W]'SB/2(
M]8CVB,*V]XCXB/F(^HC[B/R(_8C^B$")08E"B4.)1(E%B:C<1HE'B4B)28E*
MB4N)3(GZR_/K38E.B4^)W,M0B5&)_LM2B5.)5(G!S%6)5HE7B5B)68G[R%J)
M6XE<B5V)7HE?B:K<8(EAB6*)8XEDB>[,J]QEB6:)9XEHB6F):HEKB6R);8EN
MB6^)<(EQB7*)<XETB76)T]MVB:_<K-QWB;.^>(G[RGF)>HE[B:W<?(E]B7Z)
M@(F!B8*)@XF$B<K)N<2%B8:)AXF(B8F)O<>NW(J)BXF,B?;4YM"-B8Z)CXF0
MB9&)DHF3B92)J\35MI6)EHF7B9B)F8F:B9N)G(F=B9Z)GXF@B:&)HHFCB:2)
MI8FFB=3;IXFHB:F)JHG:L:N)K(FMB=7;KHFOB;")L8FRB;.)M(FUB;:)MXFX
MB=;;N8FZB;N)OKJ\B;V)OHF_B<")P8G"B<.)Q(G%B<:)QXG(B<F)P,C*B<N)
MS(G-B<Z)SXF_RLG(T(FSU]&)^<G2B=.)Q[_4B=6)^+K6B=>)O-+8B=F)VHG;
MB=R)W8G>B=^)NN+@B::TX8GBB;BQXXGDB>6)YHGGB;2XZ(G$S^F)ZHGKB>R)
MY]FFS^+-[8GNB>W9X+;OB;G2\(GQB;NY\HGSB?2)]8FYXK?B]HGSM/>)[,RK
MS/*W^(FRV.O1N[KYB:?*^HG[B;?-_(G]B<32Y+_0O.&V_HG%WD"*08I"BD.*
MQMZ\VT2*V=%%BD:*YL;.Q.ZW1XK<MTB*28K\O^#72HKUQDN*3(J\L<C>L;W7
MS,K>38K)WDZ*3XI0BE&*4HKLM5.*W<E4BE6*PK!6BE>*6(I9BEJ*6XI<BEV*
M7HI?BF"*88IBBJ[%J\5CBLS$9(KIO/W+98IFBF>*P[IHBFF*:HKYY>?(^N7]
MS6N*L=>^N.C";(K1R&V*;HK[Y6^*<(IQBG**RK;+O'.*=(K]T:'F=8KNPW:*
M=XIXBGF*I.9ZBGN*?(I]BO[EI>;7S7Z*@(K!M_SE_>6CYH&*@HK=Q*CF@XJ$
MBJ?FA8J&BH>*B(J)BHJ*P\.+BM[&C(J-BJKFCHJ/BI"*D8J2BI.*E(JWQ)6*
MEHJ7BJ+FO,J8BIF*FHJ;BN.]P[FFYM70K\Z<BIV*J>:PYIZ*IM*?BJJ]K>:@
MBJ&*HHJCBJ2*K^:EBM'`IHJGBLS2J(JIBJJ*I[RKBJR*K8JNBJ^*L(JQBK**
MLXJTBK6*MHJQYK>*]M*XBKF*NHK+U[N*_LV\BM[-IL*KYJSFO[VNYK/FO8J^
MBK+FOXK`BL&*PHJVYL.*N.;$BL6*QHK'BN_$R(K)BLJ*R,3+BLR*ZK[OR<V*
MSHJWYL^*\+;0BM&*THKDP].*U(K5BM:*UXK8BMF*Z=.TYMJ*M>;;BJ+(W(K=
MBMZ*WXK@BKWFX8KBBN.*N>;DBN6*YHKGBNB*Q<;IBNJ*\<V[YNN*[(KMBNZ*
M[XKPBO&*\HKSBO2*O.;UBO:*]XKXBNF[^8KZBON*_(K]BOZ*0(N^YD&+0HM#
MBT2+NN9%BT:+M\!'BTB+28M*BTN+3(M-BTZ+3XNDT[_F],G#YE"+48O$YE*+
M4XM4BU6+]M!6BU>+6(M9BUJ+6XM<BUV+7HM?BV"+88MBBV.+9(MEBV:+9XN]
MPVB+:8MJBVN+;(MMBVZ+Q,/"YF^+<(MQBW*+<XMTBW6+=HMWBWB+>8MZBWN+
M?(O!YGV+?HN`BX&+@HN#BX2+Q^:QSX6+].N&BX>+RN:(BXF+BHN+BXR+Q>:-
MBXZ+WKRIR8^+D(N1BY*+DXN4B[6\E8N6B]//EXN8BYF+FHN;B\CFG(O)YIV+
MSN:>B]#FGXN@BZ&+T>:BBZ.+I(O+YM6UI8O,YJ:+IXO/YJB+J8O;Q*J+QN:K
MBZR+K8NNBZ^+S>:PB[&+LHNSB[2+M8NVB[>+N(NYB[J+NXN\B[V+OHN_B\"+
MP8O"B\.+Q(O%B\:+TN;'B\B+R8O*B\N+S(O-B\Z+SXO0B]&+THO4YM/FTXO4
MB]6+UHO7B]B+V8O:B]N+W(O=B]Z+WXO@B^&+XHOCB^2+Y8OFB^>+Z(OIB^J+
MZXOLB]7F[8OXV>Z+[XO6YO"+\8ORB_.+](OUB_:+]XO7YOB+^8OZB_N+_(O]
MB_Z+0(Q!C$*,0XQ$C$6,1HQ'C-/7W>9(C-[FU[_0U$F,UM?FM._+VN;#V,[7
MHM!*C,_#2XQ,C-_FOKS"N=OFI]%-C$Z,HKK/PD^,J]A0C%&,4HSKRN[E4XS<
MYE2,];=5C%:,5XQ8C.;(68Q:C/7$6XQ<C++E_L1=C/S+L^6LU5Z,[M/8RK*P
M7XS.R^K-8(QAC.JZ8HQCC&2,M>5EC+3E9HS:U]FYYM:HMO#-R]*FL;7*9XSH
ML_/)S;_[T-+*MN7"NVB,:8QJC-S/K+EKC&R,;8QNC-?4;XQPC*:ZY]'\S]*\
M<8RWY=W(<HQSC'2,[;_VL=[+=8QVC,6\=XS$O/K2W,/<OWB,>8QZC'N,N[A\
MC'V,?HS"PX",KKJBU(&,@HR#C(2,A8R&C(>,B(R)C-['K\3LLHJ,T;F+C(R,
MN^7(P8V,CHROU8^,D(R1C)*,DXR\Y92,ON65C):,EXR8C)F,FHR;C.>TU+;"
MR[#1O+6<C)V,V<J>C.*WGXR@C.3)H8RKO:*,HXR^SO#7I(REC*:,IXRAT*B,
MV<FIC*J,^[;8YN*\JXR^LZR,T,FMC-GFHK.NC*^,L(RQC,S>LHS(T\W>LXRB
MTK2,M8RVC+>,SMZXC+F,NHR[C,V^O(R]C,_>OHR_C,",K,K\TM^SZN7AQ*&^
MLL[RQ-:^J,;CLL&,PHS3OL.,Q(S\Q^O,[+W=SL6,QHRZRL'&[.6\T,>,R(S)
MC+G5RHS+C,R,[>7-C,Z,SXS0C/3*T8S`S<7"THSOY=.,Q,+PY=2,U8S6C->,
MV(S9C-J,^.7-S=N,O<G<C-V,WHS?C.",X8SBC-G2J.'CC.2,Y8SFC.S3YXSJ
MR_'&Z(SIC.J,ZXSLC*SA[8SNC.^,I^&IX?",\8RJX:_A\HSSC.VR](RKX=JX
MK>&NX;#ANK6QX?6,]HSWC/B,^8RSX;CA^HS[C/R,_8S^C-+10(VVX;7AZ\%!
MC4*-0XVWX42-P-1%C;+A1HVZX;:P1XU(C4F-2HVTX4N-^;],C;GA38U.C;OA
M3XU0C5&-4HU3C52-ON%5C5:-5XU8C5F-6HV\X5N-7(U=C5Z-7XU@C<7688UB
MC6.-9(UEC6:-9XV_SVB-:8V]X;_AS<)JC>NV:XWXTVR-;8W-QVZ-;XWEMW"-
M<8URC7.-=(UUC7:-=XUXC7F-_KYZC7N-?(U]C7Z-@(W`X<'A@8V"C<?AY[.#
MC82-A8V&C8>-B(WIQHF-BHV+C8R-C8W>M(Z-PM&/C9"-D8V2C<CADXV4C<;A
ME8V6C9>-F(V9C<7AFHW#X<+AFXW`L9R-G8V>C;C5Q.&?C:"-H8VBC:.-R^&D
MC:6-IHVGC:B-J8VJC:N-S.'*X:R-K8VNC:^-L(VQC;*-LXWZ[[2-M8W3X=+A
MML>VC;>-N(VYC;J-NXV\C;V-OHV_C<"-R>'!C<*-SN'#C=#AQ(W%C<:-QXW(
MC<F-RHW+C<R-S8W.C=3ASXW1X<WAT(W1C<_ATHW3C=2-U8W5X=:-UXW8C=F-
MVHW;C=R-W8W>C=^-X(WAC>*-UN'CC>2-Y8WFC>>-Z(WIC>J-ZXWLC>V-[HWO
MC?"-\8WRC?.-](WUC?:-]XWXC=?A^8WZC?N-V.'\C?V-_HU`CD&.0HY#CD2.
M18Y&CD>.2(Y)CDJ.2XY,CDV.3HY/CE".48Y2CE..5(Y5CMKA5HY7CEB.68Y:
MCEN.7(Y=CEZ.7XY@CF&.8H[;X6..9(YECF:.9XYHCFF.H<YJCFN.;(YMCFZ.
M;XYPCG&.<HYSCG2.=8YVCMWG=XZHM-W6>(YYCK+1LK-ZCGN.I+GSU\G'WKZN
MN7R.U\Y]CGZ.[K+/VX".NKS1TLC+S;"!CH*.[\^#CH2.A8Z&CH>.X]GMO8B.
MB8[2L=#*O+**CJ?+J[>+CJ;*C(Z-CHZ.H\^/CI".^.#*U?O@D8Z2COK@P<7[
MS)..L<'YX./6K[+$UMNUE(Z5CI:.EXZ8CIF.FHZ;COBTH=:<CIV.GHZ?CJ".
MK\_OL*&.HH[\X*..I(ZECJ:.IXZAX:.SJ(ZICOW@_N"QPZJ.JXZLCJV.W<.N
MCJ+A^;>OCK".L8ZRCK..M([/N[6.MHZWCKB.N8ZZCKN.H^&[Q+R.O8Z^CK^.
MP(ZDX<&.PHZEX<..Q(ZFX;&TQ8[&CL>.R([)CLJ.RX[,CLV.SH[/CM".T8[2
MCM..R;B]QNK$U(ZBLM6.TM#6CMOGP[O7T\33UX[CN<_BV([9CMJ.K]?;CNS'
MT['<CMV.LK31XMZ.WX[@CO+0KL+0XN&.XK^FT]>UTN+JM>*.[</]N...KKCD
MCM/%S[?4XN6.YH[GCNB.T^+(MOG7Z8[JCNN.[([MCJ7-[H[OCO".\8[RCMCB
M\X[6XOS*M;^YT]7B]([UCO:.]X[7XOB.^8[ZCON._([]COZ.0(]!CT*/KL'(
MP$./1(]%CT:/1X](C]OBVN*JP$F/2H_.P4N/3(]-CTZ/W.)/CU"/48]2CU./
M5(]5CU:/5X]8CUF/6H_=XEN/WN)<CUV/7H]?CV"/88]BCV./9(_(VV6/T]&B
MS6:/9X^HO6B/:8]JC\/>I=BJO\W;[-+ZQJK%:X]LCVV/Q-YNC]>QKM]OCW"/
M<8^]RG*/L=]SCZVY=(_]TG6/I;CKNG:/=X_:LWB/>8]ZC]RUQ=5[CWR/?8]^
MC];#TL^ANX"/\^7RY8&/@H_TY8./Y,V$C_7(A8^&CX>/B(^)CXJ/BX^OM;_'
MC(_VY8V/CH^/C[#LD(^1CY*/DX^4CY6/EH^7CYB/F8^:CYN/G(^=CYZ/YN6?
MC^FYL;6@C[S"Z.7GY>GEH8^BCZ./I(_-TJ6/IH^GC^KASM"HCZ[-J8_ET:J/
MJX_*LNNQK(_RL>W%K8^NC\/5L-.OC]SAL(^QC[*/W>&SC]O2M(^YL\NQM8^V
MC[>/^<WWU=[AN(^VOOVTN8_?X=RZX.&RN\G"X>&ZC[N/O(_LT+V/O<V^C[^/
MXN'`C\.UQ\7CX<&/PH_DX<./Q(_%C\:/^=/'C\B/R8_*C\N/S(_EX<V/K='.
MC\^/YN&BSM"/T8_2C]./U(_5C^?AUH_"M=>/V(_9C]J/Z.'5N]N/W(_=C]Z/
MWX_$T.#BV+'DTN"/X8_AXN*/XX_)O,S(Y(_CXO[L_>ROW^6/YH_GC^+BOM;\
MS:;#Z(_IC^J/P^/KC^R/TM;GXNV/[H_HXN^/\(_'T_&/\H_LXNR_\X_MXN7B
M](_UC\"S]H_WC_B/[L3YC_J/[N+[C_R/P]#]C_:ZZ>+>M[.[K,S+R^3BYN+J
MXNOB_H]`D$&0]^)"D$.0].+UU//B1)!%D*W%1I#ZU<+%P+)'D$B0[^))D/+B
MK\&\RTJ02Y"AM?GB3)!-D$Z0L;SQXM30N=3UXM:Y]N)/D%"049#3QU*04Y!4
MD%605I#PXE>06)!9D%J06Y#<UZ'M7)!=D/CB7I"E[?[BT<I?D&"089!BD&.0
M9)!ED+7!9I#0NV>0:)#6OVF0X[IJD&N0H<MLD&V0;I"F[:/M;Y!PD*+M<9!R
MD'.0=)#6NZ?M]-!UD':0I.W>NO>VH>.RMO',I[EWD*+/H<=XD'F0TK]ZD'N0
M\;9\D/KB^^+]XOSBU<2BXWV0P=-^D("0@9"GX\3'@I"#D(20A9"DSX:0AY"I
MX[>ZB)")D(J0BY"HXXR0VKN-D*/CCI"/D)"0I..JXY&0IN.2D/+.QM.3D)20
MO+N5D):0P]27D/K$F)"9D*CM_-"EXYJ0]<.;D*WCK[&<D++CG9">D)^0PKR@
MD*&0K.._M:*0HY"DD*60II"GD*B0J9#IQ[#CJI"KD*R0JK[OS:V0KI"OD+"0
ML9#SN[*0LY"TD.C,M9"VD*_CMY"QX[B0I\^NX[F0J<[=N[J0NY"\D+V0OI#K
MM>6^TK+-L[^0N;&KX]&RK+7?N>BVP)#!D.O/M^/"D,R[PY#$D,?(RM#%D,:0
MQY#(D,F0N./NL\J0RY#,D,V0J>W.D/K3Y-//D-"0T9"J[;GCXM+2D-.0U)#5
MD-:0M>/7D-B0V9#:D-[3VY#<D-V0WI#0N+/CWY#@D+;CW[?AD+3CHL#BD..0
MY)"ZX^60YI#GD.B0Z9#JD.N0[)#MD.Z0[Y#PD/&0\I#SD/20]9#VD/>0N-3X
MD/F0^I#[D/R0_9#^D$"1R+1!D;OC0I'%NT.1]\E$D461Y<E&D4>12)&]Q$F1
M2I%+D4R139%.D4^1J^U0D5&14I%3D?W"5)%5D5:15Y';NZZ_6)%9D5J16Y%<
MD5V17I&_SE^18)%AD6*1O.-CD;:_9)%ED6:19Y%HD6F1:I%KD6R1;9%ND6^1
M<)%QD7*1<Y%TD761=I'OL7>1>)'WU'F1>I%[D7R1?9&^XWZ1@)&!D8*1@Y&$
MD861AI&M[8>1B)&)D8J1BY&,D8V1CI&/D;_CJ;JL[9"1D9&]XY*1DY&4D961
MEI&7D9B1F9&:D9N1P..<D9V1GI&?D:"1H9&VNJ*1HY&DD:ZVI9&FD:>1J)&I
MD;C0JI'#L*[MJY&LD:V1KI&OD:_MP<"PD<'CL9&RD;.1M)&UD;:1MY&XD;F1
MNI&[D;R1O9&^D;^1P)'!D;/%PI'#D<21Q9'&D<>1R)')D<J1RY',D<V1SI'/
MD<+CT)'1D=*1TY'4D=61UI'7D=B1LMS9D=J1VY'<D=V1WI&P[=^1ZKC@D>S.
MI^KGT/G*ULBWS\FSTL[DO>&1XI'>X_*[J.J]U>.1W<:IZN21Y9'FD:KJYY&L
MZJOJZ)&NZJWJZ9'JD>N1[)'8O>V1K^KND;["[Y'PD?&1\I'!M/>T\Y'TD:>[
M]9'VD?>1^)'YD>;LY>R_M_G+XK'ZD>?L^Y'\D?V1R,GH[.GL_I'6RM#>Q;+Z
MU$"209++QL>P\K33R$*20Y)$DM#-19)&DKB_1Y)(DDF22I)+DDR239+;OTZ2
M3Y*DQ[364)*IP-'>J,GOT:3%Y["VL\7(49)2DN*P4Y)4DO:W59)6DOK%5Y)8
MDO.V69+2U="SO+Q:DEN27)*MLUV27I)?DF"2\;[1L&&28I)CDF2299)FDM;2
MX\JEUV>2MLVVMKF_V]5HDJ>XU\5IDFJ2:Y+2WMF_U<+`QVR2I+NHL6V2;I+J
MQ6^2<)+[Q:?,<9)RDG.2=)*GL762=I)WDM:U>))YDGJ2J,1[DM/>NM'ILWR2
M\L-]DGZ2][>`DO36H[7PLK3$Z<2MP-3>@9+HL,3%X,&"DM6Y@Y+<OMC-SK"$
MDL_-UM[0OK[7U=[0U=VPA9*&DN+$AY*(DJ/"\+R)DK73N<"AQ::R\=2*DHN2
MJ,##RM?>_-6,DK"YC9*MR*G+CI+9WKV_CY*0DI&2DI*TQJ?7L,K#Q).2UK/2
MN922E9*6DI>2N-;\ZK2PF)*9DIJ2FY+FOYR2G9+TS)Z2GY*@DJ&2VLVBDJ.2
MI)*_UL["I9+.SJ+,KM#3Q+*UV-[UU;>\T[NFDJ>2I+"HDK+%[+2IDJJ2JY+Q
MU:R2K9+]ZJZ2KY*PDK&2LI*SDMK>ILVTDK62[,VVDK>2N)*YDN;.W-ZZDK'-
MIL"[DKR2O=>]DMO>QK"TNM/)\\3HOKZ2OY+`DL&2MK+"DL.2Q)+%DL:2QY+(
MDLF2S,#PR\J2\;R[N[>URY+,DLV2]<7.DN;>SY+0DM&2X][=OM*2TY+?WM22
MU9+6DM>2M[3=O=B2V9+@WNW$VI+;DMR2W9+&S]Z2X+7?DN"2X9+BDMZVVLKT
MM>7>XY+&U>22X=[-S/[&Y9+%Q>:2YY+HDK32Z9+RONJ2ZY+LDNV2[I+ODO"2
MT\+QDKW,N+/RDM.]\Y+8O\;-VM'KM/22Y-[=WN?>]9+^ZO:2]Y*PPN+>^)+Y
MDL#6I[7ZDO2R^Y+HWOR2\M[]DOZ20)-!DT*3[=Y#D_'>1)-%D^#(1I-'DTB3
MX=?OWNC#X<Q)D^6R2I-+DTR3OM)-DTZ33Y-0DU&34I-3D^[>5)/KWM7.59.G
MM%:35Y-8DUF36I.KO[Z^6Y-<D]*]79->DU^38)/IWF&3KM1BD][>8Y/JWF23
M99-FDV>3O\!HD^S>\[+IN*?":9-JD\&]:Y-LDVV3;I-OD_7>^-YPDW&3J[*D
MM'*3<Y/JM*;)=)-UDW:3=Y-XDWF3]M[1RWJ3X[A[D_?>^MY\DWV3?I.`D_G>
M@9."DX.3PLR$D^&P[K2%DX:3AY.(DXF3BI.ZY8N3C).-DXZ3CY.OT)"3D9/K
MLI*3H>N3D_3>E).5D^/)\][:L*'2][&6DZ_,EY.8DYF3FI.;DYR3G9/PWIZ3
MI,N?DZ"3H9.JU:*3HY.DDZ63II/[WJ>3J).IDZJ3JY.LDZV3KI/=M*^3IL2P
MD[&3LI/]WK.3M).UD[:3MY.XD[F3NI.[D[R3_L.AQ*'?O9.^D[^3P)/!D\*3
MPY/,P<23_-[OOL63LL;&D\>3R)/)D\J3RY/,D\V3SI/%L_;(SY/0D[K+_M[1
MD]*3I-_3D]23U9/6D[+7UY/8D]F3VI/;D[>SW)/=D]Z3WY/#P>"3X9/+QZ6R
MZ;3BDZO7XY/DD^63YI/LQ.>3HM^CW^B3I=_ID[.ZZI/KD^R3IM_MD][`[I/O
MD\/)\)/QD_*3\Y/TD_63]I/9LN;']Y.GW_B3W,?YD_J3^Y/\DZC?HNO]D_Z3
M0)1!E$*4T\M#E$24192JWT:4J=]'E,&R2)1)E$J42Y1,E$V43I1/E%"44912
ME%.45)15E%:45Y18E%F46I1;E%R4791>E%^48)3*Q6&48I1CE&24991FE&>4
M:)2KWVF4:I1KE&R4;91NE&^4<)3<U'&4<I1SE'24=93!R':4=Y1XE'F4>I1[
ME'R4?91^E("4@92"E*S?@Y2$E(64AI2'E/"^B)2)E*W?I]:*E(N4C)2-E+?J
MMNO5RHZ4_-C$N(^4I;F0E)&4Q;?^U9*4DY24E)64EI3*N9>4F)2GT,WTF92:
ME-"UFY2<E/3#G93(OIZ4GY2@E+?KO;"AE**4S+VCE++!I)36L:BSI92FE*>4
MTKBBR:B4J938MJJ4JY2LE*V4N.NTOJZ4KY2PE/W*L93#Q[*4^]6SE+24\[>U
ME+:4MY2XE+F4NI2[E+R4O92^E+^4P)3!E,*4PY3$SL24Q93&E*O5\[''E,B4
MR92S[-^PRI2U[,N4S)3-E+>VSI3/P<^4^O6QT-"4T93EU=*4T\[3E-24[[WB
ML]64J[C6E+;5UY2][=B4S[;9E+G+PM#:E-N4W)3=E-Z4WY3@E.&4O;?BE..4
MMNRIRN24Y93FE-3%YY2Y[+CLP\*W[.B4Z93JE.N4_="Z[.R4N^SEU^V4[I2\
M[.^4\)3QE+WL[,;RE/.4])3UE/:4]Y3XE/F4WL[ZE,B\^Y3\E-7(J;7)OKS6
MY]3]E/Z4KM'QT+CJN>JZZK6Z0)5!E4*50Y6QRO6_1)5%E?K-1I5'E4B5295*
ME<#J2Y6ZL+[J3)5-E:7`3I5/E5"5N^I1E?VR4I7WP^B[4Y54E565U]+TSK_J
M5I57E5B5O.I9E5J56Y7#ZER5Q]"STUV57I5?E6"5NK1AE<'#\M=BE6.59)5E
ME='59I7'RF>5Q>IHE6F5Q.K'ZL;J:I5KE6R5;95NE>?6;Y74SW"5<97+ZG*5
MSKMSE725=95VE7>5>)5YE?J]SLEZE7N5S.I\E7V5N<G^S\KJSM3-ZL_J?I6`
ME>W-@96"E8.5A)7)ZH65SNJ&E8>5[LZ(E=Z[B96_LXJ5BY6,E8V5CI75QK"^
M^LZ/E9"5D97GQY*5I[[0ZI.5E)7'UI65EI67E<#!F)69E9J5W=2;E='JG)6=
ME;[/GI6?E:"5H972ZJ*5HY6DE:65[LJFE:>5J)6IE:_%M;"JE:N5K)6ME:Z5
MU.JOE;"5L96RE;.5M)6UE;:5MY73ZM_TN)6YE;J5NY6\E;K$O96^E;^5P)7!
ME:FQPI7#E<25Q97?Y<:5QY7(E<F5U>K*E<N5S)7-E<Z5SY70E=&5TI73E=25
MU976E=>5V)79E=J5VY7<E=V5WI7?E>"5X97BE>.5[\KDE=;JU^K8QN65YI7G
ME>B5Z97JE>N5[)78ZNV5[I79ZN^5\)7QE?*5\Y7TE;O4]97ZQ[?2_+CVE?>5
MPNKXE=RR^97ZE?S"^Y7XU.;,[M?\E?V5_I5`ED&60I9#EL+4T-/#Z_/%1);^
MMT661I;4ZT>62)9)EK?+WNM*ELK`2Y9,EDV6^\U.EJ^S3Y;:QE"64992EE.6
M5)95EOSK5I:^Q%>6M,ZIQ+ZQ_=18EO7*69;LUEJ66Y;3QN2V7)9=EEZ67Y;Z
MNV"689;@T&*68Y:QR626T]2HR&669I;+N&>6ONB\R6B6:9:[Z&J6[L#3T,2R
MY;1KEKSH;)9MELC5;I9OEG"6<99REL6V<Y:]Z/C*W+CUS'26=99VEK3`=Y9X
MEN[1O^C"Z'F6>I:\NGN6K;'<O7R6O>K#Z'V6QNA^ELOH@):!EH*6@Y;,Z(26
MR<OEL(66J[R&EH>6N;F(EHF6P>B*EO?-BY;*Z(R6C9:.EH^6]LZ0EI&6DI:3
MENW5E);6P<3HE9:VPY:6^[FFULCHEY:8EIF6X,KFU)J6P.B;EL7HQ^B<EKG'
MX[>=ELGHGI;=O]+HGY:@EM?HH9;5Z-R\S[S;Z**6HY:DEJ66II:GEJB6J9;>
MZ*J6VNCZL:N6K):MEJZ6KY:PEK&6LI:SEK26V+"SQ,RXXL:^R.'(M9:VEK>6
MS^C4Z-;HN);QN=CH]=>YEOO$NI;<Z+N6O);ILKV6OI:_EM'HP);!ENV\PI;#
MEL*_S>CYUL26^,'QLL66QI;'ELB6R9;*ELN6S);?Z,V6P<K9Z,Z6SY;0EM&6
MI-72ENJQN]7.Z-#HL+;3Z-.6W>BXP-26]\K5EJC+UI;7EMS&]<#8EMF6VI;;
MEMR6Z>C=EMZ6WY:CT."6X9;BEN.6Y);EEN:6\NCJUN>6Z);IENJ6ZY;LENV6
MX.CAZ.Z6[Y;PEOG1R[KYN/&6\I;QN-34[^CSEN[H[.CPN=+,YNBFSO*_]):X
ML/'H\.CUEL#7]I;DZ/>6J<VCR?B6N+O;O>KH^9;ZEON6_);]EOZ60)=!ET*7
M0Y?BZ./HY>BUM>?HQ<?KZ.WHL+VNUT27^.A%ET:71Y=(ETF72I=+ETR7]>A-
ME[#-]NA.ET^74)=1EU*74Y=4EU675I>ZP5>7Z.A8E[?#\+!9EUJ76Y=<EUV7
M7I=?EV"7].AAEV*78Y?WZ&2799=FEZ.Y9Y=HEVF7:I=KEVR7;9=NEV^7<)?2
MR7&7<I=SE\[#X,[FP'27=9=VEW>7\\MXE]W,M=!YEWJ7X<I[E_/H?)=]EWZ7
M@)>!EX*7@Y>$EX67AI?LO(>7^>B(EXF7BI>+EXR7C9?>PXZ7Y<:/E_>YD)>1
MEY*7DY?TL)27E9?8UY:7EY>LO)B7[\69EYJ7FY><EYV7Q,R>EY^7INF@EZ&7
MHI>CEZ27I9>FEZ>7J)>IEZW)JI>BZ>+`JY>LEZV7P[^NEZ^7L)?^Z->YL9?[
MZ+*7LY>TE[67I.FVE[>7N)?.TKF7NI>[E[R7O9>CZ;Z7LM:UU[^7I^G`E[>]
MP9?"E\.7Q)?%E\:7QY?(E\F7RI?+E\R7_.C]Z,V7SI?/EZ'IT)?1E]*7TY?4
ME]67UI?7E];-V)?9EZS2VI?;E]R7LNG=E]Z7WY?@EZGIX9?BE^.7JK3DE[NT
MY9?FEZOIYY?HE^F7ZI?KE^R7[9?NE^^7\)?QE_*7\Y?TE_67]I?WEZC0^)?Y
MEZ7I^I?[E_ZS_)?]EZSIX\#^EZKI0)A!F+GI0IA#F+CI1)A%F$:81YBNZ4B8
M29CZZ$J82YBHZ4R839A.F$^84)BLO['INNE1F%*8I<)3F%2859BOZ5:8Q;A7
MF*WI6)C<T[3IM>FWZ5F86IA;F,?I7)A=F%Z87YA@F&&8QL#%Z6*88YBPZ628
M99B[Z?&P9IAGF&B8:9AJF&N8;)AMF&Z8;YB\Z:75<)AQF+[I<IB_Z7.8=)AU
MF,'I=IAWF/'!>)AYF+;(>IA[F'R8O>E]F'Z8@)B!F(*8PNF#F(28A9B&F(>8
MB)B)F(J8P^F+F+/IC)BVZ8V8L;N.F(^8D)C`Z9&8DIB3F)28E9B6F/>\EYB8
MF)F8Q.G&Z9J8FYB<F)V8GIB?F*"8H9BBF*.8I)BEF,KIIIBGF*B8J9C.Z:J8
MJYBLF*V8KIBOF+"8L9BRF+.8V[*TF,CIM9BVF+>8N)BYF+J8NYB\F+V8OIBN
MM[^8P)C!F,*8PYC$F,68QIC'F,B8R9C*F,OIS.G+F,R8S9C.F,^8T)C!U=&8
MH\32F-.8U)C5F-:8UYC8Z=B8X;K9F-J8VYC<F,GIW9BCT]Z8WYC@F-3IX9CB
MF..8Y)CEF.:8YYC7Z=#IZ)CIF.J8ZYCLF,_I[9CNF,''[YCPF/&8\ICSF/28
M]9CVF-+I]YCXF/F8^IC[F/R8_9C9Z<BS_IC3Z4"909E"F4.91)GPST691IE'
MF<WI2)E)F4J92YE,F4V93IE/F5"949E2F?>S4YE4F5695IE7F5B969G6Z5J9
M6YG:Z5R979E>F;3,7YE@F6&9K<]BF6.99)EEF6:99YEHF6F9:IG5Z6N9W.G;
MZ6R9;9ENF6^9<)G>Z7&9<IESF729=9EVF7>9>)G1Z7F9>IE[F7R9?9E^F8"9
M@9G=Z8*9W^G*PX.9A)F%F8:9AYF(F8F9BIF+F8R9C9F.F8^9D)F1F9*9DYF4
MF969EIF7F9B9F9F:F9N9G)F=F9Z9GYF@F:&9HIFCF:29I9FFF:>9J)FIF:J9
MJYFLF:V9KIFOF;"9L9FRF;.9M)FUF;:9MYFXF;F9NIF[F;R9O9F^F;^9P)G!
MF<*9PYG$F<69QIG'F<B9R9G*F<N9S)G-F<Z9SYG0F=&9TIG3F=29U9G6F=>9
MV)G9F=J9VYG<F=V9WIG?F>"9X9GBF>.9Y)GEF>:9YYGHF>F9ZIGKF>R9[9GN
MF>^9\)GQF?*9\YGTF?69M\?.M+:[P-"C[/:9]YFWQ?B9^9GZF?N9_)G]F?Z9
M0)I!FD*:^]-#FD2:19I&FJ3L1YJE[-O&2)I)FDJ:[K]+FDR:39I.FJ;L3YI0
MFJ?LJM!1FKC'4II3FNBX5)I5FE::5YI8FEF:6II;FER:79I>FE^:J.Q@FF&:
M8IICFF2:99IFFF>:N=;]U<NTO;+DSN?&:)IIFN'-:IIKFFR:;9INFF^:<)IQ
MFG*:<YITFG6:=IIWFO6T>)K`R]^\>9IZFGN:?)KBZ>/IZM'EZ7V:^;3DZ7Z:
ML]'BRM"R@)KHZ8&:@IJ#FH2:YNGGZ86:AIJSUH>:B)J)FNGIZNF*FHN:C)J-
MFHZ:Z^F/FI":D9J2FI.:E)J5FI::[.F7FIB:F9J:FIN:G)J=FIZ:K^RYQ<ZV
MGYKSTJ":H9JBFJ.:I)JEFJ::[K6GFMF[L>RHFJF:X]*JFJN:K)JMFJZ:X\ZO
MFKC$L)J_P[&:LIJ^MKG8R+'/L=&Q_L6SFM"QM)JKP[6:MIJWFKB:N9JQU;J:
MNYJ\FKV:OIJ_FL":P9JDZ\&ZPIK#FL2:NLS%FL::QYJEZ\B:I^O)FLJ:RYJH
MZ\R:S9K.FJ;KSYK0FM&:TIK3FM2:U9JIZZOKJNO6FM>:V)K9FMJ:K.O;FL_*
MM=CQP]R:I</XQJWKRL3=FJ[KK^NPZ]6WWIK?FN":^K?AFK'KXL?BFK/KXYJD
MNO71L;"RZ[3KY)KEFN::JK7(PNC'YYJUZ^B:KLO?X^F:ZIK`T^N:[)KMFNZ:
MV]GOFO":H<VMUO/'\9KRFO.:X-GCN_2:NKKBX_6:]IKWFOB:^9JKS_J:^YK\
MFN#CQ\G]FKFZ_II`FT&;M-'AX^K(K[FMO=BSV\Y"FT.;P,Q$FT6;1IOHX^GC
M],U'FTB;29M*FTN;K<Q,F[.\39OJXTZ;Z^-/FU";VM!1FU*;4YO[QMJW5)M5
MF]_'RM+6SE:;Y./LXU>;\LG!LUB;69OGXUJ;6YOCQN7C7)M=F[/MYN->FU^;
M8)MAF[/)8IOFQ6.;9)MEF[6Y9IN[PV>;X^.]Q:3!V<+7LFB;[>.FNZW$:9OP
MX]J^:IMKF_OC]>/3NFR;;9MNFV^;T+?-TW";SM;3U<&YM-78T7&;<IMSFW2;
MN=#VQW6;=IMWFZK(M+)XF]K#>9MZFWN;[N-\FWV;_./OXZBW]^/TXWZ;@)N!
MF[JW@IN#FZ+%A)OVX]W%J++\QH6;X,2&FX>;HM>(F^'`^>.)FXJ;^N/]XZG,
M\^.+F[[3C)O#L;3M\>/RXXV;^..ZT,/&\]3^XXZ;CYO@O9";D9NGY)*;DYNF
MY)2;E9N6F_/1H^27FZGDF)N9FYJ;]\B;FYR;G9N>F[3/GYNHY*[DY<*@FZ&;
MM+:BFZ.;I)NEFZ:;IYORO:B;HN2IFZJ;Z;JJY*N;K)NLY*V;KIO]MM[6LN2O
MFZWDL)NQF[*;H>2SF^Z[W<VBQ\G%M)NUF_?!MINDY+>;L\>LO;V]I>2XF\?7
MXK*YFZODP[ROY+J;Z[NPY*C%L>2[F[R;O9N^F^/5H[^_F[KDP)NWY,&;N^3"
MF\.;O>3$F\6;UL;&F\>;QKK+P,B;R9O*FZ&XM.3+F\R;S9O.FZ'4SYO0FZ.Z
M_KW1F]*;TYN\Y-2;U9O6F]>;V)N_S=F;VIOYQ-N;W)O[S^;)W9O>F[_3WYO1
MS^";X9NSY.*;N.2YY.G,XYODF^6;YIOGF\[,Z)O4P+7DL,&VY-#.Z9O!N].U
MZIOSR*>]Q]6LR:*XRN3KF^R;S.3$T>V;[INZTN^;\)NMNO&;\IO4NO.;])OU
MF_:;]YOXF\/D[;7YF_J;^YO-U\#D_<^_Y/R;_9O^F]S!RLQ`G$&<0IQ#G.?*
M1)Q%G$:<1YS7Q$B<U,S(Y$F<2IQ+G,?DP>1,G,3DK;5-G$Z<V=-/G,;D4)Q1
MG%*<4YSYTN.T5)RTNU6<5ISNR5><OK18G%F<6ISLNUN<S=%<G.W,M>U=G%Z<
M7YQ@G&&<8IQCG&2<Y<=EG&:<9YQHG*C4:9S+Y-77PN1JG*6]Q>1KG&R<YM-M
MG,GD^,ENG&^<ON1PG'&<Y=-RG'.<_L?)MG2<_-2SLM?D=9QVG'><PLYXG,WD
M>9R\SGJ<V[A[G'R<UN1]G,J_?IR`G(&<SM."G.S#@YR$G(6<AIR'G(B<B9R*
MG,C%V.2+G(R<C9R.G(^<D)R1G)*<Q,W/Y).<E)R5G):<U.35Y)><_KJ8G.;/
MF9R:G+_5FYR<G)V<TN2>G)^<H)RAG**<HYRDG*6<IIRGG*B<T.2IG*J<SN2K
MG*R<K9RNG*^<L)RQG+*<LYRTG+6<MIRWG+B<N9SES:K*NIR[G+R<H\"]G*:]
MT^2^G+^<R+C`G,&<PIS#G,2<Y^2TU,6<QIS'G,B<R9S*G,N<V^3,G,V<SISO
MP<^<T)SIY-&<TISGTM.<U)S?Y-6<X.36G-><JL_8G-F<VIS;G-W+W)S:Y-'D
MW9SEY-Z<W,CCY-^<X)SGQ.+DX9SAY.*<XYSDG/RSZ.3EG.:<YYSHG.&UZ9SJ
MG.N<S-?LG.V<[ISFY.^<K+OPG-+7S\SXZ_&<Y.3RG/.<]KGTG/6<]IS-UMGD
MW.3ZPM[D]YS+PL3`T,+XG/6QLLSYG/J<^YS\G/V<_IQ`G4&=0IU#G<ZU1)U%
MG4:=1YWOY$B=29U*G4N=3)U-G4Z=3YVOQE"=49U2G>'&4YU4G?7D59U6G5>=
M6)U9G:G"6IU;G5R=[,#=T>[D79U>G5^=8)UAG6*=8YUDG66=9IVNQ&>=:)UI
MG>WD:IUKG6R=;9WVY/3D_L)NG=WD;YWPY'"=_LIQG<35<IUSG?'D=)UUG7:=
M=YUXG7F=>IWZT7N=?)U]G7Z=@)V!G8*=Z^3LY(.=A)V%G?+DAIVKSH>=B)V)
MG8J=BYV,G8V=CIV/G9"=R\61G9*=DYVQQY2=NL*5G9:=EYWJY)B=F9V:G<K!
MFYV<G9V=GIV?G:"=MLRQLZ&=HIVCG?ODI)WSY*6=IIVGG?KDJ)W]Y*F=_.2J
MG:N=K)VMG:Z=KYVPG<ZSL9VRG;.=NK/WY+2=M9WYY/CD[,6VG;>=N)VYG;J=
MNYV\G;V=OIV_G<"=P9W"G;W`PYW$G<6=QIWHU,>=R)W)G<J=RYVBY<R=S9W.
MG<^=T)W1G=*=TYW4G=6=UIW$L->=V)VDY=F=VIVCY=N=W)W=G=Z=WYW@G:2\
MX9VEY>*=XYWDG>6=YIWGG:'EZ)WIG>J=ZYWLG>V=[IW^Y/2Q[YWPG?&=\IWS
MG?2=]9WVG?>=^)WYG:CE^IVIY:;E^YW\G?V=_IU`GD&>0IY#GD2>19Y&GD>>
MI^6JY4B>29Y*GDN>3)Y-GDZ>3YY0GE&>4IY3GE2>59Y6GE>>6)Y9GEJ>6YY<
MGEV>7IY?GF">89YBGF.>9)YEGF:>9YYHGMG&:9YJGFN>;)YMGFZ>;YYPGJOE
MK>5QGG*><YYTGG6>=IYWGJSE>)YYGGJ>>YY\GGV>?IZ`GH&>@IZ#GH2>A9Z&
MGH>>B)Z)GJ_EBIZ+GHR>KN6-GHZ>CYZ0GI&>DIZ3GI2>E9Z6GI>>F)Z9GIJ>
MFYZ<GIV>GI[@N9^>H)ZPY:&>HIZCGJ2>I9ZFGJ>>J)ZIGJJ>JYZLGJV>KIZQ
MY:^>L)ZQGK*>LYZTGK6>MIZWGKB>N9ZZGO"[X>SPP[N>QK72N[R>O9Z^GK^>
MZ<'NU,">Q+[!GL*>PY[&U\2>UM33LK[LQ9[&GL>>R)[!ZLF>RI[+GJ_"MK3,
MGLV>SI[7T<^>T)[1GK2STIZRR+N_P.S3GM2>R];5GM:>O^S![->>V)[9GMJ>
MVY[<GMV>WI[?GN">X9[BGN.>Q>SFOK_,VL6\ON2>QNSEGOZQYI[GGNB>Q.RH
MU>.UZ9["[+;!X[/JGNN>P^RXR\/`_LSLGNV>[I[OGM+!\)[([/&>\I[SGO2>
M]9[VGO>>^)[YGOJ>^Y[\GOV>YKK3P/Z>\M9`GT&?0I_,T4.?1)]%GT:?OK]'
MG[.WU<G'[.*[2)_,S/V]R,A)GZG/2I]+GTR?39].GT^?4)_IS5&?Z\52GU.?
M5)_IMU6?5I]7GUB?69]:GUN?7)]=GUZ?7Y_)T;BZ8)]AGV*?8Y]DG\GL99]F
MG\KL9Y_`N\OL:)_B[+JQV;=IGVJ?:Y]LGVV?;I]OGW"?<9]RGW.?N;UTGW6?
M=I]WGWB?>9]ZGWN?S.SFT<WL?)]]GWZ?@)^[R(&?@I^#GX2?A9^&GX>?B)^)
MGXJ?BY^,GXV?CI_1[(^?D)^1GY*?T^R3G\V[E)_EO)6?EI^7GYB?F9^:GYN?
MG)^=GYZ?GY^@GZ&?S^RBG[?)HY^DGZ6?II^GG[K#J)_C[-75T.RIGZJ?JY^L
MGZV?\]:NGZ^?L)_2[,[LL9^RG[.?M)_4[+6?U>RVG[>?O\FXG[F?NI^[G[R?
MO9^HS[Z?OY_`G\&?PI_<T,.?Q)_%G\:?K-''G\B?R9_*G]O(RY_,G\V?UNSU
MSLZ?SY_0G]&?TI_LRMKLTY_4G]6?UI_7G]B?V9_9[-J?VY_<G[ZPW9_>G]^?
MX)_AG^*?U^SCG]CLY)_EG^:?Y.SGG^B?Z9_JG^N?[)_MG^Z?[Y^\R/"?\9_R
MG_.?])_UG_:?]Y_XG_F?Q\'ZG_N?_)_]G_Z?W.S@T4"@0:!"H$.@1*!%H$:@
M1Z!(H$F@V^Q*H$N@3*!-H._43J#=[$^@4*!1H%*@4Z!4H,;;5:!6H%>@6*!9
MH%J@6Z!<H%V@7J#>[%^@8*!AH&*@8Z!DH&6@9J!GH&B@::!JH*RQ:Z!LH&V@
M;J!OH'"@<:!RH'.@=*!UH':@=Z!XH'F@>J![H'R@?:!^H("@@:#?[(*@@Z"$
MH(6@AJ"'H(B@B:"*H(N@X.R,H*;7C:#`Q8Z@CZ"0H+SKKK"1H)*@DZ#TOKBX
MK]+6L/FUE*"SV)6@K,N6H-WCEZ"8H)F@FJ";H)R@G:"LQN:PGJ"?H*"@QL6Y
MZZ&@HJ"CH*2@NNNEH*:@IZ"[ZZB@J:#`T:J@H\6KH/+JK*"RQ*V@M<3.P*Z@
MKZ"PH//JP<2QH._.LJ"SH+2@M:#PZO3JMJ"WH/S)N*"YH*/'NJ"[H+R@V,S^
MSKV@OJ"_H/7J]NJLS^?`P*#!H/?JPJ##H,2@Q:#&H+^V^.K'H/GJR*#ZZLF@
MRJ#[ZLN@S*#-H,Z@SZ#0H-&@TJ#3H-2@U:#6H/'JUZ#8H-F@VJ#;H-R@W:#>
MH-^@X*#AH.*@KLCKX>.@N+?LX>2@Y:#FH.WAYZ"TU^[A[^',T^B@Z:#JH.N@
M[*#MH.Z@\>'QO_#ATK7OH/"@\:"WL?*@\Z#TH/6@\^'RX?:@_+KWH/3A^*#Y
MH/J@^Z"WN?R@T;[]H/Z@0*I!JOS$0JK=NL:]0ZI$JD6J1JI'JDBJ]>'WX4FJ
M2JK`ML'/J,KVX?C5_-/XX?SA^>%+JDRJ^N'JP$VJ_N&AXL?`3JI/JE"J4:K[
MX5*J_>%3JE2J5:I6JE>J6*JEXEFJ6JI;JM3!7*I=JEZJ7ZJCXF"JJ.+^LJ+B
M8:IBJF.JS</"LJ?BIN)DJF6JI.*IXF:J9ZJKXFBJ::IJJLG0[=:HPZSB:ZK7
MSVRJ;:JNXFZJ;ZKONG"J<:K@Z:WBJN)RJG.J=*IUJJN[L]1VJG>J>*IYJGJJ
M>ZI\JGVJ?JJ`JH&J@JJ#JK#BA*J%JJ_BAJKAZ8>JB*J)JHJJL>*+JHRJC:J.
MJH^JD*J1JI*JLN*3JI2JE:J6JI>JF*J9JIJJFZJ<JIVJL^*AS)ZJM.*?JJ"J
M0*M!JT*K0ZM$JT6K1JM'JTBK2:M*JTNKM>),JTVK3JM/JU"K_M!1JU*KRL)3
MJ_'35*OUS56K5JO@YU>K6*OAYUFK6JM;JURKP;Y=JUZK7ZM@J^K"8:MBJV.K
MY.=DJV6KX^=FJV>K:*MIJVJK:ZOFS6RKM<-MJVZKXN>WN];/;ZOAP>GG<*MQ
MJW*KZ.=SJW2K].>CLG6K=JMWJWBKZN=YJ^;G>JM[JWRK?:M^J^SGZ^>ZR8"K
M@:ODU8*KY>>IM^?G@ZN$JX6KAJN'JXBKB:ONYXJKBZN,JXVK\^>.J^G6CZN0
MJY&KDJOMYY.K\N>4J_'GE:N6JY>KX+"8JYFKFJN;J_7GG*N=JYZKGZN@JT"L
M0:Q"K$.L1*Q%K$:L1ZQ(K$FL2JSRQTNLQ<#MP$RL3:SPP?#G3JQ/K%"L4:SV
MY_;+4JQ3K%2L5:Q6K%>L6*Q9K%JLHNBAZ%NL7*Q=K%ZL7ZQ@K,'78:QBK/KG
M^>=CK/OG9*SWYV6L_N=FK/WG9ZS\YVBL::S5P=G'_<7#Q6JL:ZQLK&VL;JSM
MQV^L<*QQK'*LH^ASK'2L=:QVK'>L>*QYK'JL>ZQ\K'VL?JR`K(&L@JR#K(2L
MA:R&K*;HAZREZ(BLI^CWNOCGI.B)K/#(JLF*K(NLC*R-K(ZLCZR0K)&LDJR3
MK)2LE:R6K*GHEZR8K.6YF:R:K)NLG*R=K/[1J.B>K)^LH*Q`K4&M0JVJZ$.M
MK>BNZ$2MI\%%K4:M1ZVOZ$BM2:U*K;#H2ZU,K:SH3:VTZ$ZM3ZU0K5&M4JU3
MK52M5:U6K5>M6*VKZ%FML>A:K5NM7*U=K5ZM7ZU@K6&MM>BRZ+/H8JUCK62M
M9:UFK6>M:*UIK6JM:ZULK6VM;JUOK7"M<:VWZ'*M<ZUTK76M=JUWK7BM>:UZ
MK7NM?*U]K7ZM@*V!K8*M@ZV$K86MAJV'K8BMB:VVZ(JMBZV,K8VMCJV/K9"M
MD:V2K<^YDZVL\)2MK?"5K;#&ZK"_R):MW\V7K9BMF:V:K9NMG*V=K<W.L>J>
MK9^MH*U`KK+J0:Z_QLFT0JY#KD2N1:Y&KD>N2*ZSZDFN2JY+KDRNY]5-KDZN
M3ZY0KE&N4JY3KE2N^=U5KK3J5JZUZE>NMNI8KEFN6JY;KLJXL-_UR5RN\,Q=
MKEZN^LE?KF"N8:YBKF.N^\EDKF6NP].FRV:NIKBN\,*Q9ZZXY>_,R=/7O.K)
M:*[GM6FNT,3IM6JNKNZMNVNN;*[>YVVNK^YNKF^N<*YQKJFS<JYSKK+N=*YU
MKK'NY[UVKK#NM\YWKGBN>:YZKL_%>ZY\KGVN?J[TP<[;L^[ST("N@:Z"KH.N
MA*Z%KH:NAZ[4PNC&B*Z)KHJNK+>+KHRNC:Z.KH^ND*Z1KK3NDJ[KLY.NE*Z5
MKON[M>Z6KI>NF*Z9KIJNW.>;KIRNG:ZV[IZNGZZNO:"N0*]!KT*OXO%#KT2O
M1:_HRD:OR=+:\$>OV_!(K]SPQL%)K^VXSKY*KTNOWO!,K['%W?#QT4VOX/#,
ML.J]3J]/KU"O4:]2K]_2W_!3KZ^TZ+?F\.7PH\;A\.+PP[14KU6OX_#NU5:O
M5Z_;S-*^LKQ8KUFO6J_H\.?PY/"ALENOHM:XT[>^K,A<KUVOZO!>KU^O8*]A
MK_?18J_,UMNZZ?!CK[NV9*]EK[3-9J]GKZ;&:*]IKVJOH<'K\.[P:Z_M\/#P
M[/!LK[Z[[_!MKVZO;Z]PK[7,\O!QKW*OU;-SKW2O=:]VK]2Q=Z]XK_/P>:]Z
MK_3P]O#AM'NO\?!\K_?P?:]^KX"O@:_Z\(*O^/"#KX2OA:_U\(:OAZ^(KXFO
M_?"*K_GP_/#^\(NOH?&,KXVOCJ_!SJ3QCZ^C\9"O]L'[\-W*D:^2K_&T\;&Q
MS).OIO&4KY6OI_&6KY>OK/'.U:GQF*^9K[/(FJ^;KYROHO&=KZOQJ/&E\9ZO
MGZ^J\:"O0+!!L$*P0[!$L$6P1K"IL*WQ1[!(L$FP2K!+L$RPK_%-L+'Q3K!/
ML%"P4;!2L+#Q4["N\52P5;!6L%>PHM%8L%FP6K!;L%RP7;!>L++Q7[!@L&&P
ML_%BL&.P9+!EL&:P9[!HL&FP[[EJL&NPQ[5LL->PV;!ML&ZP;[#MU'"PQ+5Q
ML-2]RKNG\'*P<[#>N'2P=;"H\':P=["HL'BPJ?!YL'JP[LU[L'RPJO!]L'ZP
M@+"!L(*P@["$L(6PAK"'L*OPB+")L(JPB[",L(VPCK"/L)"PI,:1L)*PY=;D
M\9.PY?&4L)6PEK"7L)BPF;":L)NPG+"=L//#GK"?L-O3H+!`L='6Z,5!L:_3
M0K'FTD.Q1+'![KNPM=7.T>"\T+I%L?B_1K''N,&US,5'L4BQHLI)L4JQ2['+
MPTRQ3;%.L4^Q4+'"[E&Q4K%3L52Q5;%6L5>Q6+&_Q**V6;'L[:3#6K&QUENQ
M7+%=L>#/[^U>L5^QSL5@L=RV8;%BL:'*8[%DL>WM9;%FL?#M\>V\PV>QM+]H
ML>[M:;%JL6NQ;+%ML6ZQ;[%PL7&Q<K%SL?3M\NUTL76Q=K%WL>;5W\-XL?/M
M>;%ZL7NQ]NU\L:/5H]%]L7ZQ@+'U[8&QT,."L8.QA+&%L8:Q]^WTO^R^^.V'
ML??,B+';T8FQBK&+L<77]M6,L?SMC;&.L8^Q^^V0L9&QDK&3L92QE;&6L9>Q
M^>WZ[9BQF;&:L9NQG+&=L9ZQG['][::^H+%`LD&R0K)#LJ_+H>Z]MD2RHN[`
MQ$6R_NU&LD>RWKW'LDBR2;)*LDNR3+)-LDZR3[)0LE&R4K)3LL.V5+)5LE:R
MI>ZZV*/NINY7LEBR6;+IP_*S6K);LERR7;)>LE^RI^ZD[KG/8+)ALJCN]\)B
MLF.R9+)ELF:R9[)HLFFR:K)KLFRR;;*I[JKN;K*KWF^R<+*SQG&RQL=RLO76
MR;5SLK++=+)ULG:RJ^YWLGBRJ\UYLJSN>K)[LGRR?;)^LK#5@+*M[H&RQ/:"
MLH.RA+*%LH:RA[*(LHFRBK*+LHRRC;*.LL?;C[*0LI&RDK*3LI2RE;*6LI>R
MH[28LIFRFK*LP^;QF[*<LIVRGK*?LKC*T]*@LJK60+/R[T&SV+Y"L\.]\^_,
MMJNP0[-$LT6S1K.ORD>S2+.V[4FSM^U*LTNS3+--L_G.K[?SO[CMZ\*PR4ZS
M3[-0LU&S4K-3L[GM5+-5L_;&L[]6LU>S6+.\[?C%6;/0T5JSJ=>Z[;OM6[/B
MT5RSO^W`[5VSQ.U>LU^S8+/([6&SQNW.[>C58K/)[6.S9+/'[;[M9;-FL^G%
M9[-HLVFSQL9JLVNSZ<G2U,'MPNW#[<7M;+/YP&VSH;1NLV^S<+-QL^BY<K/0
M[7.S=+-ULW:ST>UWL\KM>+//[7FS^,YZLWNSMLO,[<WM?+-]LWZS@+.!L_7/
M@K.#LX2SA;.&LX>SB+.)LXJSB[.,LXVSTNWRP;+3R^VWR(ZSC[.0LY&SDK.3
MLY2SE;/OO):SE[.8LYFS\,6:LYNSG+.=LYZSG[.@LT"T0;1"M-;M0[3OM42T
M1;2UPJVPZ<M&M$>TKK%(M-3M2;1*M$NTZ\WBM4RTU>W3[=?M3;1.M/JU3[38
M[5"TV>U1M-SM4K3,L5.T5+15M%:T5[18M%FT6K3VQ>Z\VNV\S.JR6[1<M%VT
M7K3;[5^T8+1AM&*TZ\1CM&2TQ;1EM&:T9[3UL&BT:;1JM-_MVL#HM&NT;+1M
MM&ZTS<5OM'"T<;3=[<2_<K1SM'2TWNUUM':T=[1XM'FT>K1[M'RT?;1^M("T
M@;2"M(.TI<2$M(6TAK3@[8>TB+2)M(JTB[3A[8RTX^V-M(ZTU\&/M)"TQ[N1
MM)*TD[24M)6TEK2XO9>TF+29M.+MFK2;M)RTG;2>M)^TH+1`M4&U0K5#M42U
M1;7D[4:U1[5(M4FU2K5+M4RU3;5.M4^UYNU0M5&U4K53M52UY>U5M5:U5[58
MM5FU6K5;M5RU7;5>M5^U8+5AM6*U8[7G[62U9;5FM6>U:+6^RNKL\<!IM>?)
M:K7K[.[&:[5LM6VU;K7L[&^U[<;M['"U<;5RM7.U=+5UM7:U=[5XM?#L>;5Z
MM>;7\^Q[M7RU\>SN[._LH]?QR>[+].Q]M?+L?K6`M>G/@;7V[+'&@K6#M82U
MA;7`O(:U]>R'M8BUB;6*M8NUC+6-M;NU]KN.M??LC[60M9&UDK63M??9^[V4
MM96UN\+X[):UE[68M9FU^>R:M9NUG+6=M:.XGK6?M:"U0+9!MD*V0[9$MD6V
M1K;Z[$>V2+9)MDJV2[9,MDVV3K9/ME"V4;92MOOL4[94ME6V5K97MEBV6;9:
MMENV7+9=MOSL7K9?MF"V8;9BMNW3KMCKP&.VW<?,NF2VX]"]RV6VNLUFMF>V
MT;AHMFFV_+%JMN_':[;6UFRV;;9NML:_Z\-OMG"V]>]QMG*VV,-SMG2V=;9V
MMG>V>+;BUWFV>K9[MO?OT[-\MMC'[=%]MLC6?K;X[X"V]N^!MOV[QK."MH.V
MA+:%MH:VA[:(MM6]B;:*ML;2B[;@NXRVC;:ASXZV_._[[X^VD+;Y[Y&VDK:3
MMI2VS+.5MM3)L,N6MI>VF+:9MIJV_N^;MIRVWK"=MIZVR=:?MJ"V0+?][T&W
M[;-"MT.WU?9$MT6W1K='MTBW2;=*MTNW3+=-MTZW3[=0MU&W4K?(SE.W5+=5
MMZ+P5K>A\%>WOK7:O/R[6+?EN%FW6K=;MURW7;=>M\+$7[=@MV&W8K=CMV2W
M9;=FMV>W:+>C\&FW:K=KMVRW;;?KRVZW;[=PMW&W<K=SMW2W=;=VMW>W>+=Y
MMWJW>[=\MWVW?K>`MX&W@K>#MX2WA;>&MZ;PA[>(MXFWJ-&*M[^^[L>V\;?Q
MU;^+MXRWC;>.MZFTN/&[S8^WU,>MU9"WN?&1M[KQDK>3MY2WE;?/QY:WE[>8
MMZ32S]:9MYJWN_'1O;"TO;Z;MYRWG;?<M-'.GK??O[WQG[>@MT"X0;CZO[SQ
M0KB_\4.X1+A%N+[QP/%&N$>X2+A)N$JXP?%+N$RX3;A.N$^X4+A1N%*X4[A4
MN%6X_L%6N%>X6+A9N%JX6[A<N%VX7KA?N&"XHL%AN&*X8[ADN&6X9KAGN&BX
M:;AJN/K*:[ALN+[5;;ANN&^X<+BZOKF^PM5QN'*XHK]SN*_-M?%TN'6X=KAW
MN'BX>;C?O7JXR[9[N'RX?;A^N("X@;B"N(.XA+CQUL/SA;B&N,3SA[C-N(BX
MB;B*N,;SQ_.+N,JPC+C%\XVXR?/QRXZXC[B0N,OSD;BFT)*XD[C*L<CSE+B5
MN):XS_.7N-&UF+B9N-?SFKC2\YNXG+B=N-3ST_/[MYZXO[&?N,[SRO/:M:"X
MT/-`N4&YT?-"N=7S0[E$N46Y1KG-\T>YX[Q(N?W!2;G6\TJY2[E,N4VY3KE/
MN=KS4+G,\U&YR+52N>Z]W/-3N52YI+?PO_[6LLU5N?"T5KG?LE>YV/-8N=GS
MN,E9N=WS6KE;N=[S7+GA\UVY7KE?N6"Y8;EBN6.Y9+EEN6:Y9[G?\VBY:;GC
M\^+S:KEKN=OS;+GJOVVY[[-NN>#S;[EPN:G'<;GRO'*Y<[ETN76YZ_-VN7>Y
M>+EYN7JY>[E\N;^Y?;E^N>3S@+F!N8*YK;+^NX.YX\N$N86YAKF'N>WSZ?.(
MN8FYBKG<N>[SB[F,N8VYY?/F\^KSX<+L\^_SZ//]O(ZYC[F0N>3/D;F2N?#S
MD[F4N96YY_.6N9>YF+F9N9JYF[F<N9VY\O.>N9^YH+E`NJW7JL9!ND*Z0[I$
MNO/S1;I&ND>Z2+KQ\TFZJ,)*NDNZ3+I-NDZZW;CU\T^Z4+KT\U&Z4KI3NMNT
M5+I5NE:Z]O/W\U>Z6+I9NOCS6KI;NERZNL!=NEZZZ<!?NF"Z8;IBNF.Z\<5D
MNF6Z9KIGNOOS:+KZ\VFZ:KIKNFRZ;;INNF^Z<+K8M'&Z<KISNO[S^?-TNG6Z
M_/-VNG>Z>+IYNGJZ>[K]\WRZ?;I^NH"Z@;J"NH.ZA+JA](6ZAKJ'NHBZB;J*
MNJ/TR;N+NHRZHO2-NHZZC[J0NI&ZDKJ3NI2ZE;J6NI>ZF+J9NJ3TFKJ;NIRZ
MG;J>NI^ZOK*F]*7TH+I`NT&[0KM#NT2[1;M&NT>[2+M)NZZ\2KM+NTR[3;M.
MNT^[4+M1NU*[4[M4NU6[5KM7NUB[6;M:NUN[7+M=NUZ[7[M@NV&[8KMCNV2[
M9;MFNV>[:+MINVJ[:[MLNVV[;KO7P^'9;[MPNW&[<KMSNW2[X,#,]-'7=;MV
MNW>[>+MYNWJ[>[M\NWV[?KN`N]NW@;N"NX.[A+N%NX:[A[O.]*/!B+N)N\G&
MBKO6M+/5B[N,NXV[T/3/]-'TVLN.NX^[TO20N\'4X-:1NY*[D[N4N^"WE;N6
MNY>[N,&8NYF[N\'3]*R^FKN;NYR[G;N>N^*TG[N@N]3TU?2KOD"\0;S6]$*\
M0[Q$O-OT1;S7]-KT1KS]ND>\V/39]$B\2;Q*O$N\3+Q-O$Z\XKC'S-ST3[S:
MLE"\4;S3PU*\4[SCU+>_5+Q5O%:\5[Q8O%F\6KS=]%N\7+Q=O%Z\7[Q@O+3%
M8;QBO&.\9+QEO&:\9[QHO.GT:;QJO+7/:[QLO&V\;KQOO'"\<;QRO'.\=+QU
MO':\=[QXO,G.>;QZO'N\?+Q]O'Z\@+R!O(*\@[R$O(6\AKR'O(B\B;R*O(N\
MC+R-O(Z\V,N/O/?+D+R1O)*\D[STO92\E;R6O,_7E[R8O)F\V\":O)N\G+R=
MO)Z\G[R@O$"]0;U"O4.]1+U%O4:]1[U(O4F]2KU+O4R]3;U.O4^]4+U1O5*]
M4[U4O56]5KU7O5B]6;U:O5N]7+U=O5Z]7[U@O6&]8KUCO62]9;UFO6>]:+UI
MO6J]:[ULO6V];KUOO7"]<;URO7.]=+UUO7:]]=!WO7B]>;UZO7N]?+U]O7Z]
MZO2`O8&]@KV#O82]A;V&O8>]B+V)O8J]B[V,O8V]CKV/O9"]D;V2O9.]E+V5
MO9:]E[V8O9F]FKV;O9R]G;V>O9^]H+U`OD&^0KY#OD2^1;Y&OD>^2+Y)ODJ^
M2[Y,ONOT3;Y.OD^^4+Y1OE*^4[[L]%2^5;Y6OE>^6+Y9OEJ^6[Y<OEV^7KY?
MOF"^8;YBOF.^9+YEOF:^9[YHOFF^:KYKOFR^;;YNOF^^<+YQOG*^<[YTOG6^
M=KYWOGB^>;YZOGN^?+Y]OGZ^@+Z!OH*^@[Z$OH6^AKZ'OHB^B;Z*OHN^C+Z-
MOHZ^C[Z0OI&^DKZ3OI2^E;Z6OI>^F+Z9OIJ^F[Z<OIV^GKZ?OJ"^0+]!OT*_
M0[]$OT6_1K]'OTB_2;]*OTN_3+]-OTZ_3[]0OU&_4K]3OU2_5;]6OU>_6+]9
MOUJ_6[]<OUV_7K]?OV"_8;]BOV._9+]EOV:_9[]HOVF_:K]KOVR_;;]NOV^_
M<+]QOW*_<[]TOW6_=K]WOWB_>;]ZOWN_?+]]OWZ_@+_C]X&_@K^#OX2_A;^Q
MMX:_A[^(OXF_BK_M](N_C+^-OXZ_C[^0OY&_DK^3OY2_E;^6OY>_F+^9OYJ_
MF[^<OYV_GK^?OZ"_0,!!P$+`0\!$P$7`1L!'P$C`2<!*P$O`3,!-P$[`3\!0
MP%'`4L!3P%3`5<!6P%?`6,!9P%K`6\!<P%W`7L!?P&#`8<!BP&/`Z]=DP&7`
M9L!GP&C`:<!JP&O`;,!MP&[`;\!PP''`<L!SP'3`=<!VP'?`>,!YP'K`>\#N
M]'S`?<!^P/GFP+[ZYNRZ^^;+S_SFO-2VO/WF_N;-O-+(L\ZAYX#`O[2BY[3)
MV;C)Q('`W=?:PM>WO=;&SL2W@L"#P*;%H^??SZ3GI>>FY[?!Z=?PR;C/K];5
MUJ?G[;"HYZGGW,GOTJV^JN?SL-[(X;VKY\;(A,"LY^:[^+BDT:WGY\+XOLJ]
ML\VNYZ_G[K[ET(7`Y\O0S,R\L.>HO/?0L>>&P/C0LN>SY\*TM.>UY_[)K,[@
MP[?GP;'QLX?`N.>YY]O7P-6ZY\S"NM>[Y[SGO>?JO.7#PL"^Y[_GJ;R(P,#G
MP>>VY]"VPN>)P,/GQ.>ZN]ZUQL+@L<7GM=3&Y[^XR.?'Y^RWBL#)Y_BRRN?+
MY\SGS>?.Y\_GT.>GT_7+T>?2Y]/GU.?)R=7GUN?7Y]CGV>?)O=KGOO.+P->X
MC,"QR(W`CL"/P)#`D<"2P)/`O_.4P,#SP?.5P);`E\"8P)G`FL";P)S`G<">
MP-ZY^,V?P*#`Z-BQND#!WL*W[D'!H[="P4/!1,%%P;GN1L&X[M6P1\%(P4G!
M2L%+P;ONUM7OUTS!3<%.P</63\%0P;WN\,I1P;SN4L%3P53!5<&^[E;!5\%8
MP5G!P.Y:P5O!O^Y<P5W!7L%?P6#!8<%BP6/!\M%DP;S'9<'`PV;!9\%HP6G!
M:L'AN&O!;,%MP6[!;\'GP7#!<<'&]-_0Q_1RP=O/<\%TP;K(=<%VP<CT=\%X
MP7G!>L%[P7S!?<')],KT?L'+](#!@<&"P8/!A,'ZV?ZXA<&&P?'E\-.'P>#T
MB,',SHG!BL&+P>&SC,&-P8[!C\&T\9#![M*1P>'TDL&3P93!E<&6P>C/XO27
MP9C!S,>9P9K!F\&<P9W!GL'4M>2TY/2?P:#!0,+C].7T0<)"PN;T0\)$PD7"
M1L+G]$?"LKJ_L$C"Z/1)PDK"2\),PDW"3L)/PJVW[=)0PE'"4L*KTL_`4\*\
MOZ/KW]7(ZE3"5<)6PE?"\_'XMJ/+6,)9PLW$6L+G\5O"Z/'[N.GQQ+K%U-*P
M7,)=PNKQ7L)?PF#"Z_%APNSQ8L)CPNWQ[O'O\?'Q\/'5Q63"9<)FPF?":,)I
MPO+Q:L+ZMFO"]/&NTL?>RLMLPFW"W+-NPJ*U;\*BN7#"<<+TQ/7Q<L)SPO;Q
M=,)UPG;"Q,'[P;#6]_%WPGC"><)ZPOCQ>\*JP7S"?<)^PKC&@,+;OH'"@L*#
MPH3"A<*&PH?"B,*)PHK"B\*,PHW"CL+Y\<^TC\*0PI'"DL*3PI3"^O&5PI;"
ME\*8PIG"FL*;PIS"G<*>PI_"H,)`P[+ML>U!PT+#X,O>TD/#P<O8U43#XLA%
MP]_`H;Q&PT?#2,-)PTK#2\/!ZTS#3<.DT$[#XM9/P\>VV+C`Z\ZX4,._ZZ:S
MR;FKUE'#]+?*MU+#4\-4P^>\OK?&ZU7#Q^NYL,^_5L/%Z_W35\/(ZUC#6</)
MZUK#6\/.MUS#PNO$Z_;)U];-U;+0S^NXSM#K7<.HM5[#7\-@PV'#8L.SL=+K
MI<QCPV3#9<-FPV?#:,-IP];%T^MJP]'KW\7.ZZ3*U>O[L&O#;,/ZNFW#;L.W
MV./Q;\/*Z\OKS.O-Z];KP.;9ZW##Z+_(TM?KW.OLN-CK<<.ZO7+#V-!SP[>P
M=,/=Z]S$=<-VPW?#>,.LUGG#>L-[P^"T?,-]P_;"N;Q^PX##VNO;Z^#4ZL;4
MQ-_KI\7UV8'#L;*"P^3K@\/%O83#A<.&P^+KA\.(PXG#BL.+PXS#C<..PX_#
MD,.1PY+#D\/CZY3#E<.LN);#T<WEZY?#F,.9P^'KFL.SP9O#G,.=PY[#G\.B
MQJ##0,1!Q$+$0\1$Q$7$\\Q&Q.;K1\2PP+C2Y^M(Q$G$2L2ON*VX2\3HZ[O'
M\\U,Q$W$3L3JZ^OK3\10Q%'$4L13Q.WK5,15Q%;$5\3(T%C$\NM9Q.[K6L1;
MQ%S$\>OYR%W$_-'LZU[$7\3IZV#$8<1BQ&/$N;C9S^7$[^OPZ]K,R,WRL&3$
M]NMEQ&;$9\1HQ&G$]>MJQ+*R:\1LQ&W$;L3@N&_$]^MPQ''$<L1SQ'3$=<3L
ML7;$=\3%S*3$I<]XQ'G$>L1[Q'S$^>M]Q'[$HNR`Q/+%@<3ZZX+$@\2$Q(7$
MAL2'Q(C$B<3%R8K$B\2,Q(W$CL2/Q-_B_NN0Q)'$DL23Q,[-H>S;L;?3E,25
MQ-S2EL27Q)C$_>N9Q/OKFL2;Q)S$G<2>Q)_$H,1`Q4'%0L5#Q43%1<5&Q4?%
M2,5)Q4K%2\5,Q4W%3L6\LT_%4,51Q;#J4L53Q=375,6K]/2S5<56Q5?%6,59
MQ<'6PM9:Q5O%7,5=Q5[%7\7IU<J^8,6G]&'%J-*H]*GT8L6J],N^W]-CQ63%
M9<5FQ6?%X,GAR6C%:<7"\VK%YLIKQ?+,;,5MQ6[%;\5PQ7'%MN*TRW+%Z,[;
MUG/%K?2N]*_T=,5UQ7;%=\6R]'C%O;JS]..PL/1YQ;'THKW5LGK%MO2W].:V
ML++/S[3TK+1[Q;7T?,5]Q;CT?L6`Q8'%@L6#Q;GTA,6%Q:?-AL6Z](?%N_2(
MQ8G%BL6\](O%C,6-Q8[%C\60Q9'%DL72RY/%O?24Q97%EL67Q;[TF,69Q9K%
MF\6<Q9W%GL6?Q;_TH,5`QD'&0L9#QM[TO,'HO$3&J\G>T?7E1<9&QD?&2,:S
MW-722<9*QK3<K+"UW$O&3,;:O4W&N=Q.QD_&4,;"V%'&M]SSTU+&ULFZW+;<
M4\:[W*+#5,95QE;&5\:\W,7<O=Q8QEG&W\ZEUEK&S]Q;QLW<7,9=QM+<YKVK
MPE[&N-S+W,[<OMS2M\6PQ]R^T,'<J+M?QKRWS-Q@QF'&QMR_W-O'8L9CQF3&
MO]'`W&7&9L;*W&?&:,;0W&G&:L:MSL+<:\;#W,C<R=S4LM'<U<MLQK?4V]S?
MW*;,YMQMQN?#W-QNQF_&P;_9W'#&^K"VN>7<T]QQQL3<UMSTR."_<L9SQG3&
M=<:[R7;&=\9XQKVQ><:BTWK&>\;:W'S&?<;5W'[&N\:`QM[<@<:"QH/&A,:%
MQL+7K\.VM]''J</BW-C<Z]S4W(;&A\;=W(C&I;[7W(G&X-R*QHO&X]SDW(S&
M^-R-QH[&X=RBW>?<C\:0QI'&DL:3QI3&E<:6QI?&F,;KO,2TF<::QJ/#Y[+Z
MW)O&\MR<QN_<G<;\W.[<\-+HLI[&U\CCR/O<G\;MW*#&0,=!Q_?<0L=#Q_7<
M1,=%QZ.^]-Q&Q]VR1\=(QTG'2L=+Q_/<]KSHW,2[3,?SP$W'3L=/QU#'4<?4
MO.G<ZMQ2Q_'<]MSYW+2U4\?9R.>[_MS]W*O3H=VCW:7=\=*DW:;=I]VITE3'
M5<=6QU?'6,=9QUK'R;JIW5O'7,>VW;'=M-U=QU['7\=@QV''8L=CQ[#=SL9D
MQV7'\L!FQV?':,=IQZ_):L=KQVS'[-RNW6W';L=OQW#'M]UQQW+'\-ROW7/'
MN-UTQZS==<=VQW?'>,=YQWK'>\>YW;/=K=VJQ'S'?<=^QX#'J-VSP*O!JMVK
MW8''LMWQN[7=J-.ZW8+'N]VGPX/'A,?2W;S=A<>&QX?'T=V(Q[VYB<>*Q]6^
MB\?ZOHS'C<?*NH['C\>0QY''RMV2Q\7=D\>_W93'E<>6Q\NRP]V7Q\O=I++5
MW9C'F<>:Q[[=F\><QYW'T,;0W9['G\>@QT#(0<C4W>+!QK="R$/(1,A%R$;(
MSMW/W4?(2,A)R,3=2LA+R$S(O=U-R,W=T<Q.R,G=3\A0R%'(4LC"W<C#O,:N
MSLS=4\C(W53(5<A6R%?(6,A9R,'=6LA;R%S(QMW<PEW(7LA?R&#(8<ABR*G3
MJM/3W?3/^,ACR&3(9<AFR&?(:,AIR&K(YMUKR&S(;<ANR&_(<,C'W7'(<LAS
MR.#=Y,)TR'7(=LAWR'C(><AZR'O(X=U\R'W(?LB`R('(@LB#R(3(A<B&R-?=
MA\B(R(G(BLB+R/C6C,C9W=C=\+C6W8W(CLB/R)#(S\:1R*VVDLB3R)3(E<B6
MR.+=E\CYNN'4Y]V8R)G(FLC0M)O(VMV<R/N_X]V=R-_=GLC=W9_(H,A`R4')
M0LE#R43)V;5%R4;)1\E(R=O=W-W>W4G)K[WDW4K)Y=U+R4S)3<E.R4_)4,E1
MR5+)]=U3R<G#5,E5R>++5LE7R5C)6<GRW5K)6\E<R5W)7LE?R6#)8<EBR6/)
M9,EER6;)X=AGR6C)T<9IR?3=:LEKR6S)]-7SW?#=;<ENR>S=;\GOW7#)Z-UQ
MR7+)[M!SR73)=<EVR=C([MUWR7C)Z=UYR7K)ZMWRRWO)[=U\R7W)S;%^R8#)
M@<F"R8/)A,FVP(7)N[SQW8;)A\GWW8C)]MWKW8G)BLF+R8S)C<GNQ8[)C\F0
MR?O=D<F2R9/)E,F5R9;)E\F8R9G)FLF;R:3>G,F=R:/>GLF?R:#)0,I!RD+*
M0\I$RD7*1LI'RDC*^-U)RDK*2\I,RN_#3<K[PD[*3\I0RN'54<I2RK7.4\I4
MRE7*5LK]W5?*S+)8REG*6LI;RES*7<I>RE_*8,KHQ-_*8<IBRF/*9,IERF;*
M9\IHRFG*:LJ^Q_K=_-W^W:+>JK#.L6O*;,IMRF[*;\JLWG#*<<IRRG/*IMZV
MO>_(=,IURG;*=\IXRGG*>LI[RGS*?<I^RJ'>@,J!RJ7>@LJ#RH3*A<JIWH;*
MA\J(RHG*BLJHWHO*C,J-RJ?>CLJ/RI#*D<J2RI/*E,J5RI;*K=Z7RLS4F,J9
MRIK*F\JSWJK>KMZ<RIW*V<">RI_*H,I`RT'+H;&VWD++L=Y#RT3+1<M&RT?+
M2,M)R[+>2LM+RTS+3<M.RT_+4,M1RU++4\M4RZ;1M=Y5RU;+5\M8RUG+6LM;
MRZ_>7,M=RU[+L-Y?R[W08,MARV++M-[MRKG>8\MDRV7+9LMGRVC+N-YIR[?>
M:LMKRVS+;<MNRV_+<,N[WG'+<LMSRW3+=<MVRW?+Y;UXRWG+>LM[RWS+V++J
MPWW+?LNZWH#+NL6!RX++@\N$RX7+ALN\WH?+B,N)RXK+B\N,RXW+V<R.RX_+
MD,N1RZJWDLN3RY3+E<N6RY?+F,N9RYK+F\N<RYW+GLN?RZ#+0,Q!S.740LQ#
MS$3,O=Y%S$;,1\Q(S$G,O]Y*S$O,3,Q-S$[,3\Q0S%',4LQ3S%3,HL15S%;,
M5\Q8S,'>6<Q:S%O,7,Q=S%[,7\Q@S&',8LQCS&3,9<QFS&?,:,R^WFG,P-YJ
MS&O,;,QMS&[,;\QPS'',<LQSS'3,=<QVS'?,NM5XS'G,>LS"WGO,?,Q]S'[,
M@,R!S(+,@\R$S(7,ALR'S(C,B<R*S(O,KO*BN[+"L,7'PHS,C<RO\H[,C\R0
MS)',DLSIT)/,E,R5S-W3ELR7S)C,O>N9S)K,F\R<S)W,GLR?S*#,YK.P\D#-
ML?)!S4+-K<I#S43-1<U&S4?-2,U)S>>ZL_*U\K3RY,NZS[+RM,K/TNS"2LU+
MS4S-3<U.S4_-4,W#SKCR]K"W\E'-4LU3S53-5<V^\E;-S[)7S5C-6<U:S5O-
M7,W!T;KR7<U>S5_-8,UAS;SRZ=1BS6/-N_*V\K_RO?)DS;GR9<UFS<?RQ/+&
M\F?-:,W*\L+RP/)IS6K-:\W%\FS-;<UNS6_-<,W[UG'-<LUSS<'R=,WYQ]_)
M=<W(\L:YL+5VS7?-P_+)\M#RUO)XS7G-U[MZS7O-?,W5\MS-?<WKUG[-@,W2
M\M3R@<V"S8/-A,WRN(7-ALV'S8C-R_*)S8K-B\W.\OG"C,W=U<SRS?+/\M/R
MC<V.S8_-V?*\TY#-D<V2S9/-ZK:4S?'*E<WDM]?RELV7S9C-V/+:\MWRV_*9
MS9K-W/*;S9S-G<V>S='1T?*?S<G-H,W/SJG60,[C\D'.V\-"SN#R0\Y$SJ_`
M[/+>\D7.X?)&SD?.2,[H\DG.2LY+SDS.XO)-SD[.Y_)/SE#.YO)1SE+.Z?)3
MSE3.5<[?\E;.5\[D\NKR6,Y9SEK.6\Y<SEW.7LZLT^7R];)?SF#.\O)ASJO0
M8LYCSF3.9<[U\F;.9\YHSLB[:<[Y\FK.:\YLSFW.;LYOSO#R<,YQSO;R^/+Z
M\G+.<\YTSG7.=LYWSGC.><[S\GK.\?)[SGS.?<[[NG[.^[6`SH'.@LZ#SN_R
M]_+M\N[RA,Z%SH;.Z_*F\X?.H_.(SHG.HO.*SHO.]/*,SMK(C<Z.SH_.D,Z1
MSOORDLZ3SI3.I?.5SI;.E\Z8SIG.FLZ;SOC#G,Z=SI[.G\Z@SD#/0<]"S_WR
M0\]$SZ?SJ?.D\T7/_/)&ST?/2,^K\TG/JO-*STO/3,]-S]W"3L]/SZ[S4,]1
MS[#S4L]3SU3/5<]6SZ'S5\]8SUG/L?.L\UK/6\]<SUW/7L^O\_[RK?-?SV#/
M8<]BSV//9,]ES[+S9L]GSVC/:<^T\VK/:\]LSVW/J/-NSV_/<,]QS[/S<L]S
MSW3/M?-USW;/=\]XSWG/>L][SWS/?<]^S[?0@,^!SX+/@\^X\X3/A<^&SX?/
M^=F(SXG/BL^+SXS/C<^Y\X[/C\^0SY'/DL^3SY3/E<^W\Y;/Y,BV\Y?/F,^9
MSYK/NO.;SYS/G<^>SY_/N_/`M*#/0-!!T$+00]!$T$701M!'T$C02=!*T$O0
M3-!-T,/N3M!/T%#04=!2T%/0O/-4T%70O?-6T%?06-"JT5G06M!;T*STQM!<
MT%W07M!?T&#08=#0T-S18M!CT&309=!FT&?0SL]HT&G0UKUJT,/1:]!LT&W0
M;M!OT'#0<=#BNNGAPM+"\;FR<M!ST.VQP_%TT,#)Q+-UT/+9=M"ERW?0Q/%X
MT'G0>M![T-36?-!]T'[0@-"!T,7QP/3&\8+0K-3'\8/0P+#!](30A=#"](;0
MA]#\M(C0V\6)T(K0B]",T+O,C=".T(_0Y-"0T)'0DM"3T)30X,V5T);0E]"8
MT)G0R/&:T//9F]"<T)W0GM"?T*#0N[%`T:[/0=%"T4/1I+A$T4711M%'T4C1
MRO%)T4K12]%,T<OQ3=%.T4_14-'#LM'!4=%2T;#7R?%3T531S/%5T5;15]%8
MT<[Q6=%:T5O1]ME<T>'2H]1=T5[1P_2YR%_18-%AT6+18]'$]&319='-\<_Q
MX[_0\6;19]'4\6C1:=%JT6O1;-%MT6[1UO'1\6_1T<GAQ7#1<=%RT>/"_+ES
MT731T_%UT=7Q=M%WT7C1T[EYT7K1>]%\T7W1?M&`T=OQ@=&"T8/1A-&%T=:Z
MAM']L-GQA]&(T8G1BM&+T=CQTO':\8S1C=&.T8_1D-'7\9'1DM&3T>S(E-&5
MT9;1E]'*S=WQF-&9T9K1F]&]Y9S1G=&>T=SQG]'>\:#10-)!TD+20])$TD72
M1M)'TDC2W_%)TDK2Y<]+TDS23=).TD_24-)1TE+24])4TE725M)7TEC26=):
MTEO27-)=TE[27])@TF'28M)CTL7T\[UDTF729M)GTFC2:=+@\6K2:])LTFW2
M;M)OTG#2<=)RTG/2=-)UTG;2=])XTGG2>M)[TGS2?=+A\7[2@-*!TO?.@M*J
MTH/2^_&$TH72LKB&TH?2B-*)THK2B]*,THW2CM*/TI#2D=*2TI/2E-*5TI;2
ME]*8TIG2FM*;TIS2G=*>TI_2H-)`TT'30M-#TT331=-&TT?32--)TTK32]-,
MTTW33M-/TU#34=-2TU/35--5TU;35]-8TUG36M-;TUS37=->T_N\V[E?T^:Y
MV</3RNCJP,#UONGJZNKKZF#3[.KMZN[J[^K'O6'38M-CT_OU9--ETV;3_?5G
MT_[U:-/\]6G3:M-KTVS3XKUMTZ'VI;1NTV_3<--QTZ+V<M-STW33H_9UTW;3
M=].R['C3>=-ZTWO3?--]TW[3@-.!TX+3@].$T]31A=.&TX?3B-.)TXK3ZMF+
MTXS3C=..TX_3D-.1TY+3D].4TY73EM.7TYC3F=.:TYO3G-.=TY[3G].@TT#4
M0=1"U$/41-1%U$;41]1(U$G42M1+U$S43=1.U$_44-11U%+44]14U%745M17
MU%C46=1:U%O47-1=U%[47]2D]F#48=1BU&/49-1EU&;49]1HU+KN:=1JU&O4
M;-1MU&[4;]1PU''4<M1SU'34==1VU'?4>-1YU'K4>]1\U'W4?M2`U('4@M2#
MU(34A=2&U(?4B-2)U(K4B]2,U(W4CM2/U)#4D=22U)/4E-25U);4E]28U)G4
MLM6:U)O4G-2=U)[4G]2@U$#50=5"U4/51-5%U4;51]7^T]S,2-5)U4K52]5,
MU4W53M5/U<3*4-51U5+54]54U5755M57U5C56=5:U5O57-5=U5[57]5@U6'5
M8M5CU6359=5FU6?5:-5IU6K5:]5LU6W5;M5OU7#5<=5RU7/5=-5UU7;5=]5X
MU7G5>M5[U7S5?=5^U8#5@=6"U8/5A-6%U8;5A]6(U8G5BM6+U8S5C=6.U8_5
MD-61U9+5D]64U975EM67U9C5F=6:U9O5G-6=U9[5G]6@U4#60=9"UD/61-9%
MUD;61]9(UDG62M9+UDS63=9.UD_64-91UE+64]94UE765M97UEC66=9:UEO6
M7-9=UE[67]9@UF'68M;`Y6/69-9EUF;69]9HUFG6:M9KUFS6;=9NUF_6<-9Q
MUG+6<]9TUG76=M9WUGC6>=9ZUGO6?-9]UG[6@-:!UJ7V@M:#UH36A=:&UH?6
MB-:)UHK6B]:,UHW6CM:/UI#6D=:2UI/6E-:5UI;6E]:8UIG6FM:;UIS6G=:>
MUI_6H-9`UT'70M=#UT371==&UT?72-=)UTK72]=,UTW73M=/UU#74==2UU/7
M5-=5UU;75]=8UUG76M=;UUS77==>UU_7K[Y@UV'78M=CUV37J<9EUV;79]=H
MUVG7:M=KUVS7;==NUV_7<-=QUW+7<]=TUW77=M=WUWC7>==ZUWO7?-=]UW[7
M@->!UX+7@]>$UX77AM>'UXC7B=>*UXO7C->-UX[7C]>0UY'7DM>3UY37E=>6
MUY?7F->EVL:\J;:\N,_(I;RFVJ?:ULS#R*C:_<:9U[71Z=*VT<>\FM>RO>2[
MJ=JJVLC1J]KMT.^VV\*;U\_+[;?HR<.W][ZDUJS:K=K`QN?7MLJ<UZG5W\OO
MU:[:W];*M+#:K]J=U^O2L=JRVK/:U,JTVJO*M=JVVL^S[]:WVK"[KK6XVKG:
M[KFOT>C2NMK#N.K/[[*[VKS:GM?KO=S.[].]VO/.OMK5T^6[O]JUR]#+P-KK
MQ^[6P=JUQ<&VPMK,M\Z_P]K$VJW+Q=KWM<;:PL&[U\?:N,R?U^K2L<3(VOVU
MT;O)VK/0RMK+VKW.S-K-VL[:][+1VL_:Z-'0VM7#TMJ@U]/:U-K5VKO0I=+Y
ML-;:J\?7VO>]H</8VMG:_<.WS-K:V]J^P-?&W-K=VK3'WMK?VLBY0-A!V$+8
M0]A$V$781MA'V$C8[;M)V$K82]A,V+FV^/1-V/GT3MA/V./-4-A1V%+84]A4
MV%785MA7V+GU6-A9V%K86]C@ZUS87=A>V%_88-AAV///O[MBV&/89-AEV&;8
M9]AHV,"ZI=1IV&K8:]ALV&W8;MAOV-GA<-AQV'+8<]CT]:JQ\K)TV'78=MAW
MV'C8>=AZV/7U>]A\V/?U?=A^V(#8T;KV]8'8LL."V(/8A-B%V(;8A]B(V/GU
MB=B*V(O8^/6,V(W8CMB/V)#8D=B2V)/8E-B5V);8E]B8V)G8FMB;V)S8G=B>
MV)_8H-A`V4'90ME#V4391=E&V4?92-E)V4K92]E,V4W93ME/V5#94=E2V5/9
M5-E5V5;95]E8V5G96ME;V5S97=E>V5_98-EAV6+98]EDV6799MEGV6C9:=EJ
MV6O9;-EMV6[9;]EPV7'9<MESV739==EVV7?9>-EYV7K9>]E\V7W9?MF`V8'9
M@MF#V839A=F&V8?9B-F)V8K9B]F,V8W9CMF/V9#9D=F2V9/9E-F5V9;9E]F8
MV9G9FMF;V9S9G=F>V9_9H-E`VD':0MI#VD3:1=I&VD?:2-I)VDK:2]I,VDW:
M3MJTL>K5NKA/VK&YQK+PU,W/W+#+U?6[RM:WM[#,ML;AL;JY_-;AN:&W^KS:
MZMOJ^<SSN=SJ^[2SP]&WV+K=ZO34WNK6O-^[W^K>P;C"W]3*U^#JX>KDZN+J
MX^K>R;.XQ+;EZNK*S<G-M%#:4=K9XN+%YNJUP%+:N-?GZJS7_,C3V,W8WM13
MVOG4Q,FNT].XX+-4VN+)]O15VE;:5]K5NEC:]_19VEK:W]=;VES:\?2PN-35
MS[CPQEW:7MI?VF#:8=IBVF/:9-IEVL.S9MIGVO+TK+-HVFG::MIKVKW4]\=L
MVFW:;MIOVG#:]/1QVG+:\_1SVG3:==IVVG?:>-IYVGK:>]I\VLO,?=I^VH#:
MI,B!VH+:@]J$VH7:AMJ'VHC:B=J*VHO:C-J-VO7TCMKCU[_%P/6/VI#:N_61
MVL/UDMK"]9/:NM;!]93:E=J6VK[4Q/67VLSUF-J9VIK:F]K/L/BUG-K)]<KU
MG=K<Q9[:G]J@VD#;Q?7&]4';0MO']<OU0]O@OLCU^KA$VT7;1MO0]=/U1]M(
MVTG;Y[]*V_*YO/7-]4O;3-NWPDW;3MM/V_C,4-OYO%';SO7/]='UY;;2]5+;
MU?53VU3;5=M6VU?;6-M9V[WU6MM;VUS;U/6[TUW;[+->VU_;I,Q@VV';8MMC
MV];U9-MEVV;;9]MHVVG;:MMKV]?UX;[8]6S;;=O?S-OU;MMOVW#;<=MRV\BR
MV==SV]GU=-O:]=SU==OB]7;;=]MXV^#U>=MZVWO;W_7=]7S;?=OA]7[;@-O>
M]>3UY?6!V^/,@MN#V[_EN+7C]>CUH\R$VX7;AMN'VXC;YO7G]8G;BMN+VXS;
MC=N.V[[UC]N0VY';DMN3VY3;E=N6VY?;F-N9VYK;Q+&;VYS;O_6=VY[;Q;7D
MLI_;[/7I]:#;U[9`W.WU0=SJ]4+<0]Q$W$7<1MSK]4?<2-S:M$G<ZM1*W$O<
M3-SN]4W<^;-.W$_<4-Q1W%+<4]Q4W._U\?55W%;<5]SP]5C<6=Q:W%O<7-Q=
MW%[<\O5?W//U8-QAW&+<8]QDW&7<9MQGW&C<:=QJW&O<[<FJN6S<;=S[QV[<
M;]SCMG#<<=QRW'/<=-QUW';<R<QWW'C<>=QZW'O<?-Q]W'[<@-R!W(+<@]R$
MW(7<AMR'W(C<B=R*W*;JB]R,W(W<CMR/W)#<D=R2W)/<E-R5W);<E]R8W)G<
MFMR;W)S<G=R>W)_<H-Q`W4'=0MU#W43=1=U&W4?=2-U)W4K=2]U,W4W=3MU/
MW5#=4=U2W5/=5-U5W5;=5]U8W5G=6MU;W5S=7=U>W5_=8-UAW6+=8]UDW67=
M9MUGW6C=:=UJW6O=;-UMW6[=;]UPW7'=<MUSW73===UVW7?=>-UYW7K=>]U\
MW7W=?MV`W8'=@MV#W83=A=V&W8?=B-V)W8K=B]V,W8W=CMV/W9#=D=V2W9/=
ME-V5W9;=E]V8W9G=FMV;W9S=G=V>W9_=H-U`WD'>0MY#WD3>1=Y&WD?>2-Y)
MWDK>2]Y,WDW>3MY/WE#>4=Y2WE/>5-Y5WE;>5]Y8WEG>6MY;WES>7=Y>WE_>
M8-ZUL_[4[+GYT&'>[>FJU^[IUL+MR.2Z[^GPZ?'IX=;RZ?/I]>GTZ?;I]^GA
MQ_CIV-3YZ<Z]8M[ZZ?OIS[W\Z:BXOL']Z;*QU+OUN?[I8]ZAZJ+JH^KXMZV\
M9-[DRL[@K]2]S[?5I.K>U:7JP="\N67>Q[39L6;>9]YHWK'`:=YJWFO>;-[F
ML>>Q;=[HL6[>;]YPWG'>O;/HR'+><]YTWG7>P>5VWG?>W[%XWGG>>M[)P>^T
M>]Y\WJC'V--]WOG&N-%^WOVY]<*`WH'>@MZ#WH3>K=.%WLO4_+V&WL+EM;?#
MY8?>B-ZYN^+5B=[XO;;4I<ZLP=FSBMZ+WO;,C-[&Y<3ER.6-WLKEQ^7/M<C&
MCM[\M<7EC][VRI#>D=[)Y9+>D]Z4WM3#Q;&CO)7>EMZ7WK?7F-Z9WLO-S<O*
MRM/,S.7+Y>;$FMZ;WJ'1M]'-Y9S>T.6=WKC-\-;/Y=VUGMZ^S9_>T>6ZMJ#>
M0-^HS>2Y0=_%RM&SV<OLU-+EZK="WT/?1-_.Y47?1M]'WTC?2=]*W]7E_K36
MY4O?3-]-WT[?3]_3Y=3E4-_=TE'?4M_?PL:Q4]_BTU3?5=_=MNS+5M_7Y5??
M6-_VTUG?6M];WUS?7=_IL5[?]+;:Y=CEV>7`M5_?8-]AW\72W.5BWV/?WN5D
MWV7?9M]GWVC?:=_=Y;+':M^CTFO?;-_;Y6W?;M]OWW#?XM3:U7'?<M]SWW3?
M==_@Y?'7=M]WWWC?>=]ZWWO??-_AY7W?W+'[T7[?XN7DY8#?@=^"WX/?X^6$
MWX7?Y>6&WX??B-^)WXK?V-*+W\NUC-_?YXW?]=J.W_C:C]_VVI#?]]J1WY+?
MD]_ZVL_0Q\24WY7?[K"6WY??F-^PT)G?^=J:W\K3JKJBV_''F]_\VOO:V\G]
MVIS?H=O>U_[:VL&=WY[?I=N?WZ#?]--`X$'@I]NDVT+@J-M#X$3@O+U%X$;@
M1^#)P*/;IMNCUDC@J=M)X$K@2^"MVTS@3>!.X*[;K-O"ND_@4.!1X*2_J]M2
MX%/@5."JV\?4O[)5X%;@K]M7X/FY6."PVUG@6N!;X%S@N[-=X%[@7^"FM6#@
M8>!BX&/@O+:QVV3@9>!FX/6V9^"RVVC@:>!JX&O@;.!MX&[@;^!PX''@<N!S
MX'3@=>!VX'?@>.!YX'K@>^#)L7S@?>!^X(#@M-N!X(+@@^"SV[7;A."%X(;@
MA^"(X(G@BN"+X(S@C>".X+?;C^"VVY#@D>"2X)/@E."5X);@N-N7X)C@F>":
MX)O@G."=X)[@G^"YVZ#@0.&ZVT'A0N'/T_KT]<?#U^3%_/3]]/OT0^'&OD3A
M1>%&X4?A[]!(X4GAT[=*X4OAS=2JS$SA3>&B]:'UJ+K^]-;+3N%/X5#AI/72
MP%'AZK-2X:K-I?6C];2]J/53X:GUS;VXP^&_X<NJ]53A5>%6X:;UI_7PQ%?A
M6.%9X5KA6^&L]5SAO+1=X>W77N'7M*OUKO5?X6#AK?6O]='08>%BX6/A9.%E
MX6;A9^'1PZG(:.%IX6KA:^%LX6WAL/6Q]6[A;^%PX7'A<N%SX;+U=.%UX;/U
MM/6U]7;A=^%XX7GAM_6V]7KA>^%\X7WAN/5^X8#A@>&"X8/AA.&%X8;AA^&(
MX8GABN')LHOAU-/-RHSA[\#8UK#2O\&-X?"]CN&/X9#AD>&2X9/AE.&5X9;A
ME^&JN)CAF>&:X9OAG.&=X9[AG^&@X4#B0>)"XD/B1.)%XD;B1^)(XDGB2N)+
MXDSB3>).XD_B4.)1XE+B4^)4XE7B5N)7XECB6>):XEOB7.)=XE[B7^)@XF'B
M8N)CXF3B9>)FXF?B:.)IXFKB:^)LXFWB;N)OXG#B<>)RXG/B=.)UXG;B=^)X
MXGGB>N)[XGSB?>)^XH#B@>*"XH/BA.*%XH;BA^*(XHGBBN*+XHSBC>*.XH_B
MD.*1XI+BD^*4XI7BEN*7XICBF>*:XIOBG.*=XI[BG^*@XD#C0>-"XT/C1.-%
MXT;C1^-(XTGC2N-+XTSC3>-.XT_C4.-1XU+C4^-4XU7C5N-7XUCC6>-:XUOC
M7.-=XU[C7^-@XV'C8N-CXV3C9>-FXV?C:.-IXVKC:^-LXVWC^+QNXV_C<.-Q
MXW+C<^-TXW7C=N-WXWCC>>-ZXWOC?.-]XW[C@..!XX+C@^.$XX7CAN.'X\;V
MB..)XXKCB^.,XXWCCN./XY#CD>.2XY/CE..5XY;CE^.8XYGCFN.;XYSCG>.>
MXY_CH.-`Y$'D0N1#Y$3D1>3']D;D1^1(Y$GD2N1+Y$SD3>1.Y$_D4.11Y%+D
M4^14Y%7D5N17Y%CD6>1:Y%OD7.1=Y%[DR/9?Y&#D8>1BY&/D9.1EY&;D9^1H
MY&GD:N1KY&SD;>1NY&_D<.1QY'+D<^1TY'7D=N1WY'CD>>1ZY'OD?.1]Y'[D
M@.2!Y(+D@^2$Y(7DAN2'Y(CDB>2*Y(ODC.2-Y([DC^20Y)'DDN23Y)3DE>26
MY)?DF.29Y)KDF^2<Y)WDGN2?Y*#D0.5!Y4+E0^5$Y47E1N5'Y4CE2>5*Y4OE
M3.5-Y4[E3^50Y5'E4N53Y53E5>56Y5?E6.59Y5KE6^5<Y5WE7N5?Y6#E8>5B
MY6/E9.5EY6;E9^5HY6GE:N5KY6SE;>5NY6_E<.5QY7+E<^7)]G3E=>5VY7?E
M>.5YY7KE>^5\Y7WE?N6`Y8'E@N6#Y83EA>6&Y8?EB.6)Y8KEB^6,Y8WECN6/
MY9#ED>62Y9/EE.65Y9;EE^68Y9GEFN6;Y9SEG>6>Y9_ERO:@Y4#F0>9"YD/F
M1.9%YD;F1^9(YDGF2N9+YDSF3>9.YD_F4.91YE+F4^94YE7F5N97YECF6>9:
MYEOF7.9=YE[F7^9@YF'F8N;,]F/F9.9EYF;F9^9HYFGF:N9KYFSF;>9NYF_F
M<.9QYG+F<^9TYG7F=N9WYGCF>>9ZYGOF?.9]YG[F@.:!YH+F@^:$YH7FAN:'
MYHCFB>:*YHOFC.:-YH[FC^:0YI'FDN:3YI3FE>:6YI?FF.:9YIKFF^:<YIWF
MR_:>YI_FH.9`YT'G0N=#YT3G1>=&YT?GZ?=(YTGG2N=+YTSG3>=.YT_G4.=1
MYU+G4^=4YU7G5N=7YUCG6>=:YUOG7.==YU[G7^=@YV'G8N=CYV3G9>=FYV?G
M:.=IYVKG:^=LYVWG;N=OYW#G<>=RYW/G=.=UYW;G=^=XYWGG>N=[YWSG?>=^
MYX#G@>>"YX/GA.>%YX;GA^>(YXGGBN>+YXSGC>>.YX_GD.>1YY+GD^>4YY7G
MEN>7YYCGF>>:YYOGG.>=YY[GG^>@YT#H0>A"Z$/H1.A%Z$;H1^A(Z$GH2NA+
MZ$SH3>A.Z,WV3^A0Z%'H4NA3Z%3H5>A6Z%?H6.A9Z%KH6^A<Z%WH7NA?Z&#H
M8>ABZ&/H9.AEZ&;H9^AHZ&GH:NAKZ&SH;>ANZ&_H<.AQZ'+H<^ATZ'7H=NAW
MZ'CH>>AZZ,[V>^A\Z'WH?NB`Z('H@NB#Z(3HA>B&Z(?HB.B)Z(KHB^B,Z(WH
MCNB/Z)#HD>B2Z)/HE.C$[L7NQN[KU:2VR.['[LGNRNZEQ\ONS.Z5Z+"W]K7-
M[L_NENC.[I?HQKC0[M'NTN[;MJZST];&Q+6QUKC3[M3NO]35Q_N^V<ZSN=;N
MU>[8[M?NI<79[MKNKL?;[J_'W.ZGLMWNWN[?[N#NX>[JU^+NX^[8O.3NR]/Z
MS*RRY<'E[J;'K<.8Z.;NY^[H[NGNZN[K[NSNF>CM[N[N[^Z:Z)OH\.[Q[O+N
M].[S[ISH]>ZMS<'"]N[W[OCNH=7Y[K//^N[[[IWH_.[][J'O_NZB[_6X^L.C
M[Z3OPKV_TOFRI>^F[Z?O^-*H[_W6J>_,QI[HJN^K[[3!K._ZS_C+KN^M[_JS
M^+FO[[#OXM"Q[[+OYK>_T+/OM.^U[_'(X,RV[[?ON.^Y[[KOX-6[[^VTJL.\
M[Y_HO>^^[[_OH.C]SL#OX,*XM+;7];U`Z<?/P^_![\+OQ.^GMOR\XK[,P\7O
MQN]!Z<?OS^_([\GORN_"Q_'OS;;+[T+IS._-[\:VOL/.[T/IT._1[]+O\M5$
MZ=/O]\1%Z=3O^,35[];OY+CWL-?OV._9[T;IVN_;[]SOW>]'Z=[OM;[A[]_O
MX.](Z>+OX^_-P>3OY>_F[^?OZ._I[^KOZ^_L[]C`2>GM[ZW![N_O[_#O2NE+
MZ>+/3.E-Z4[I3^E0Z5'I4NE3Z:2S5.E5Z5;I5^E8Z5GI6NE;Z5SI7>E>Z5_I
M8.EAZ6+I8^EDZ67I9NEGZ6CI:>EJZ6OI;.EMZ6[I;^EPZ7'I<NESZ73I=>EV
MZ7?I>.EYZ7KI>^E\Z7WI?NF`Z8'I@NF#Z83IA>F&Z8?IB.F)Z8KIB^F,Z8WI
MCNF/Z9#ID>F2Z9/IE.F5Z9;IE^F8Z9GIFNF;Z9SIG>F>Z9_IH.E`ZD'J0NI#
MZD3J1>I&ZD?J2.I)ZDKJ2^I,ZDWJ3NI/ZE#J4>I2ZE/J5.I5ZE;J5^I8ZEGJ
M6NI;ZL7#Q>/!R<;C7.K5L<K.L[3RR,?CT,_(X^2\R>/*X\;#HM76Q.NYQ<[+
MX_;#S.-=ZJ>W\[C2NLWCSN/$U,_C7NK0X\O1T>/2X]/CU./6T=7C^[*[P-;C
M7^JKP-?CV./9XV#JVN/;XV'JM[CBVF+JT[9CZN3:X]IDZF7J9NIGZFCJ:>IJ
MZN;::^ILZFWJ[LANZF_JY=K`M_31]=+SU=>]<.IQZG+J<^KHU^C:Y]ITZJ*P
MT\UUZNG:=NJ]N,J\O<*DPL*SZMIWZJK"L,2UO7CJ>>K>SWKJ>^I\ZNO:PLE]
MZG[J@.J!ZH+JW;&#ZH3JA>KLVH;JN+:ZU(?J_;.(ZHGJ[=K)U-7/X\6*ZN[:
MB^J,ZHWJCNJ/ZN_:D.KPVNK!U<S=SY'JDNJ3ZI3JE>J6ZI?JF.J9ZIKJF^J<
MZIWJY].API[J\=J?ZJ#JY<M`Z_+:0>OFR_[20NM#ZT3K]+A%ZT;K\]JOL+;/
M1^M(Z\_52>M*ZTOK3.M-ZT[K3^M0ZU'K4NOMRU/K5.M5ZU;K5^M8ZUGK6NOT
MVEOK7.O$XUWK7NNEP5_K8.N_]F'K8NO`]L'VT<1CZ[C(X]%DZV7KV]#%T:^\
MS;EFZ_3O9^MHZ\:TNM/"]ONS:>MJZ\/V:^MLZ_&U;>MNZV_K<.MQZW+K<^MT
MZW7K=NO%]G?K>.MYZWKK>^M\ZWWKZM.G]JG1?NN`ZX'K@NNI]H/KA.N%ZZCV
MANN'Z^/!U\"(ZZ*QB>N*ZXOKC.OMSHWKZ-"K]H[KC^OVSY#KJO;PU:SVN<.1
MZY+KD^OTNZ[VK?:4ZY7KENO>Q)?KF.O8P9GKFNN;ZYSKG>NJRY[KO,^?ZZ#K
M0.Q![$+L0^Q$[$7L1NQ'[$CLK_9)[$KLL/9+[$SLL?9-[+;"3NQ/[%#L4>Q2
M[-2P^<53[%3L5>Q6[++V5^Q8[%GL6NQ;[%SL7>Q>[%_L8.QA[&+L8^QD[&7L
M9NQG[&CL:>S@QZ;V:NQK[+B^;.QM[+*^;NSEM6_L<.S'MW'LO[_2P^;#<NQS
M[,S8=.QU[';L[[AW['CL>>QZ['OL?.Q]['[L@.SYO:71@>S0L(+L@^R$[(7L
MANRP]X?LB.R)[(KLB^R,[(WLCNRQ]X_LD.R1[)+LD^RLT)3LL+"5[);LE^RR
M][/WF.RT]YGLFNR;[,K'G.R=[)[LG^R@[$#M0>W/OD+M0^VW]T3M1>U&[4?M
M2.U)[4KMMO=+[=ZQ3.VU]TWM3NVX]T_MN?=0[5'M4NU3[53M5>U6[5?M6.U9
M[5KM6^U<[5WM7NU?[6#M8>UB[6/M9.UE[6;M9^UH[6GM:NUK[6SM;>UN[6_M
M<.UQ[7+M<^UT[77M=NUW[7CM>>UZ[7OM?.U][7[M@.V![:3.S<B"[:NZN.BY
MZ+KHPKZ#[83MA>V&[8?M]-*([<_4V,F)[8KMB^V,[8WMCNV/[9#MD>V2[9/M
ME.V5[9;ME^V8[9GMFNV;[9SMG>V>[9_MH.U`[D'N0NY#[D3N1>Y&[D?N2.Y)
M[DKN2^Y,[DWN3NY/[E#N4>Y2[E/N5.Y5[E;N5^Y8[EGN6NY;[ESN7>Y>[E_N
M8.YA[F+N8^YD[F7N9NYG[FCN:>YJ[FON;.YM[F[N;^YP[G'N<NYS[G3N=>YV
M[G?N>.YY[GKN>^Y\[GWN?NZ`[H'N@NZ#[H3NA>Z&[H?NB.Z)[HKNB^Z,[HWN
MCNZ/[I#ND>Z2[I/NE.Z5[I;NE^Z8[IGNFNZ;[ISNG>Z>[I_NH.Y`[T'O0N]#
M[T3O1>^STJ6VZL?\\>[/L\OKT._GY\W+N=FV_?'DL,S+_O&DU*W"[,'$QK&^
MH?+5O$;OHO*C\D?OI/+#TK7&2._'S:7R2>^QT\6_XLQ*[Z;RI_+5T>ZVJ/*I
M\M^UJO*K\DOO_+*L\JWRI\A,[TWO3N]/[U#O4>]2[U/O5.]5[U;O5^]8[UGO
M6N];[USO7>]>[U_O8.]A[V+O8^]D[V7O9N]G[VCO:>]J[VOO;.]M[V[O;^]P
M[W'OY[=R[W/OJ>RJ[*OL=.^L['7O=N^NQJWLKNQW[WCO>>_)M[/*>N][[WSO
M?>]^[X#O@>^XXL_W@N^#[X3OA>^&[X?OB.^)[XKOB^^,[XWOCN^/[Y#OD>^2
M[Y/OE.^5[Y;OE^^8[YGOFN^;[YSOG>^>[Y_OH.]`\$'P0O!#\$3PT/=%\$;P
MS;)'\$CP2?!*\$OP3/!-\$[P3_!0\%'P4O!3\%3P5?!6\%?P6/!9\%KP6_!<
M\%WP7O!?\&#P8?!B\&/PT?=D\&7P9O!G\&CP:?!J\&OP;/!M\&[P;_!P\''P
M<O!S\'3P=?!V\'?P>/!Y\'KP>_!\\'WP?O"`\('P@O"#\(3PA?"&\(?PB/")
M\-/WTO>*\(OPC/"-\([PC_"0\)'PDO"3\)3PE?"6\+OBE_"BO)CPO.*]XK[B
MO^+`XL'BN;?[TJ2]SLJEL<?+F?#"XORVQ,C#XIKPF_#(O9SP_;'$XIWP]K;%
MXMG$GO"?\,;BVL_=N<?BH<"@\,CB]K)`\<GB0?'SP<KBR^+XPLSBS>+.XM?*
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M]ZKWJ_>=]Y[WK/>M]]O!KO>?]Z#WK_=`^$'X0OA#^$3X1?A&^$?X2/A)^$KX
M2_A,^$WX3OA/^%#X4?A2^%/X5/A5^%;X5_A8^%GX6OA;^%SX7?A>^%_X8/AA
M^&+X8_AD^&7X9OAG^&CX:?AJ^&OX;/AM^&[X;_AP^''X<OAS^'3X=?AV^'?X
M>/AY^'KX>_A\^'WX?OB`^('X@OB#^(3XA?B&^(?XB/B)^(KXB_B,^(WXCOB/
M^)#XD?B2^)/XE/B5^);XE_B8^)GXFOB;^)SXG?B>^)_XH/A`^4'Y0OE#^43Y
M1?E&^4?Y2/E)^4KY2_E,^4WY3OE/^5#Y4?E2^5/Y5/E5^5;Y5_E8^5GY6OE;
M^5SY7?E>^5_Y8/EA^6+Y8_ED^67Y9OEG^6CY:?EJ^6OY;/EM^6[Y;_EP^7'Y
M<OES^73Y=?EV^7?Y>/EY^7KY>_E\^7WY?OF`^8'Y@OF#^83YA?F&^8?YB/F)
M^8KYB_F,^8WYCOF/^9#YD?F2^9/YE/F5^9;YE_F8^9GYFOF;^9SYG?F>^9_Y
MH/E`^D'Z0OI#^D3Z1?I&^D?Z2/I)^DKZ2_I,^DWZ3OI/^E#Z4?I2^E/Z5/I5
M^E;Z5_I8^EGZ6OI;^ESZ7?I>^E_Z8/IA^F+Z8_ID^F7Z9OIG^FCZ:?IJ^FOZ
M;/IM^F[Z;_IP^G'Z<OIS^G3Z=?IV^G?Z>/IY^GKZ>_I\^GWZ?OJ`^H'Z@OJ#
M^H3ZA?J&^H?ZB/J)^HKZB_J,^HWZCOJ/^I#ZD?J2^I/ZE/J5^I;ZE_J8^IGZ
MFOJ;^ISZG?J>^I_ZH/I`^T'[0OM#^T3[1?M&^T?[2/M)^TK[2_M,^TW[3OM/
M^U#[4?M2^U/[5/M5^U;[5_M8^UG[6OM;^_'$K_"FO+#P^<-<^[C%N]%=^['P
MLO"S\+3PM?"\T5[[[-%?^[?PMO"GU&#[TLVX\+KPN?"[\+SP8?MB^^NXO?#H
MNF/[OO"_\.F^P/#LML'PPO##\,3PM<C%\,;P9/O'\/3%9?O(\&;[9_MH^\GP
M:?O*\+WW:OO+\,SPS?!K^\[P;/MM^V[[;_O/\->Z</O0\-'PTO#3\-3PU?#6
M\-CP<?MR^Z73U_!S^]GP=/MU^W;[=_MX^WG[>OM[^WS[??NZ];G"?ON`^^3W
M@?N"^X/[A/OE]^;WA?N&^^?WA_N(^XG[BON+^XS[Z/>TPHW[CON/^Y#[D?N2
M^Y/[E/N5^^KWEOOK]Y?[F/N9^YK[F_N<^_/"G?N>^Y_[H/M`_$'\0OQ#_$3\
M1?Q&_$?\2/SP]$G\2OQ+_._T3/Q-_.G"3OSA]^+W3_Q0_%'\4OQ3_,:[5/Q5
M_%;\5_SDV5C\6?Q:_/+*Z,"D\%O\VKI<_%W\K<=>_%_\8/RLQ&'\8OSL]^WW
M[O=C_/#W[_=D_/'W9?QF_/3W9_SS]VC\\O?U]VG\:OQK_&S\]O=M_&[\;_QP
M_''\<OQS_'3\=?SI[7;\ZNWK[7?\O/9X_'G\>OQ[_'S\??Q^_(#\@?R"_(/\
MA/R]]H7\OO:FMH;\OMB'_(C\Q+F)_(K\B_R[V(S\L=R-_([\C_R0_)'\DOSS
MRI/\]_>4_)7\EOR7_)C\F?R:_)O\G/SX]YW\GOSY]Y_\H/Q`_4']0OU#_43]
M^_=%_?KW1OW'L4?]_/?]]TC]2?U*_4O]3/W^]TW]3OU/_5#]4?U2_5/]5/U5
M_5;]5_WKQK3L6/U9_5K]6_U<_5W]7OU?_6#]8?UB_6/]9/UE_6;]9_UH_6G]
M:OUK_6S];?UN_6_]</UQ_7+]<_UT_77]=OUW_7C]>?UZ_7O]?/U]_7[]@/V!
M_8+]@_V$_87]W;.S]H;]A_VT]N3!M?:V]K?VN/:Y]KKVH\B[]HC]B?V*_8O]
MC/V-_8[]C_V0_9']DOV3_?K!J+GH[93]E?V6_>JYW]F7_9C]F?V:_9O]````
M``````````````````````!*J4NI````````````````````````````````
M3*E-J4ZI`````$^I````````````````````````````````````````````
M``````````````````````````````````````````````!0J0``````````
M`````````````%&I`````%*I4ZD`````5*D`````````````````````Y:+F
MHN>BZ*+IHNJBZZ+LHNVB[J(``````````````````%JI````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$FI````````````
M````````````````````H:&BH:.AJ*$``*FA9:F6J;2AM:&VH;>AN*&YH;JA
MNZ&^H;^ADZC^H;*ALZ&\H;VA`````````````)2HE:@`````0*E!J4*I0ZE$
MJ46I1JE'J4BI````````````````````````````````````````````````
M`````````````*&DHJ2CI*2DI:2FI*>DJ*2II*JDJZ2LI*VDKJ2OI+"DL:2R
MI+.DM*2UI+:DMZ2XI+FDNJ2[I+RDO:2^I+^DP*3!I,*DPZ3$I,6DQJ3'I,BD
MR:3*I,NDS*3-I,ZDSZ30I-&DTJ33I-2DU:36I->DV*39I-JDVZ3<I-VDWJ3?
MI."DX:3BI..DY*3EI.:DYZ3HI.FDZJ3KI.RD[:3NI.^D\*3QI/*D\Z0`````
M`````````````&&I8JEFJ6>I`````*&EHJ6CI:2EI:6FI:>EJ*6II:JEJZ6L
MI:VEKJ6OI;"EL:6RI;.EM*6UI;:EMZ6XI;FENJ6[I;REO:6^I;^EP*7!I<*E
MPZ7$I<6EQJ7'I<BER:7*I<NES*7-I<ZESZ70I=&ETJ73I=2EU:76I=>EV*79
MI=JEVZ7<I=VEWJ7?I>"EX:7BI>.EY*7EI>:EYZ7HI>FEZJ7KI>RE[:7NI>^E
M\*7QI?*E\Z7TI?6E]J4`````````````8*ECJ62I````````````````Q:C&
MJ,>HR*C)J,JHRZC,J,VHSJC/J-"HT:C2J-.HU*C5J-:HUZC8J-FHVJC;J-RH
MW:C>J-^HX*CAJ.*HXZCDJ.6HYJCGJ.BHZ:@```````````````#9HMJBVZ+<
MHMVBWJ+?HN"BX:+BH@``````````````````````````Q:+&HL>BR*+)HLJB
MRZ+,HLVBSJ+/HM"BT:+2HM.BU*+5HM:BUZ+8HK&BLJ*SHK2BM:*VHK>BN**Y
MHKJBNZ*\HKVBOJ*_HL"BP:+"HL.BQ*(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````*2I
MI:FFJ:>IJ*FIJ:JIJZFLJ:VIKJFOJ;"IL:FRJ;.IM*FUJ;:IMZFXJ;FINJF[
MJ;RIO:F^J;^IP*G!J<*IPZG$J<6IQJG'J<BIR:G*J<NIS*G-J<ZISZG0J=&I
MTJG3J=2IU:G6J=>IV*G9J=JIVZG<J=VIWJG?J>"IX:GBJ>.IY*GEJ>:IYZGH
MJ>FIZJGKJ>RI[:GNJ>^I``````````!4J%6H5JA7J%BH6:A:J%NH7*A=J%ZH
M7ZA@J&&H8JACJ&2H9:AFJ&>H:*AIJ&JH:ZALJ&VH;JAOJ'"H<:ARJ'.H=*AU
MJ':H=Z@``````````````````````````````````'BH>:AZJ'NH?*A]J'ZH
M@*B!J(*H@ZB$J(6HAJB'J````````(BHB:B*J```````````````````````
M````]J'UH0``````````````````````````````````````````^*'WH0``
M``````````````````"+J(RH`````````````````````/2A\Z$```````#P
MH0````#RH?&A````````````````````````````````````````````````
MC:B.J(^HD*@`````````````````````````````````````````````````
M`````````````````````````````````.^A[J$`````D:@`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#BH0``X:$``````````````````````````````````%RI````
M`$.HJJ%$J*RA``"NH:^A`````+"AL:$``````````````````$6HK:$`````
M``````````````````#KH0``Y*'EH0``1J@`````````````^:$`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````.:A``!'J````````$BH
M````````````````````````````````[:$`````````````````````````
M`%FI````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````/&B\J+SHO2B
M]:+VHO>B^*+YHOJB^Z+\H@``````````H:*BHJ.BI**EHJ:BIZ*HHJFBJJ(`
M`````````````````````````````````````````````````````````/NA
M_*'ZH?VA`````$FH2JA+J$RH````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````,JA````````````````QZ$``,:A````````3:@`````
M`````,RA`````-BAWJ%.J,^A`````$^H``#.H0``Q*'%H<FAR*'2H0````#3
MH0````````````#@H=^APZ'+H0````````````#7H0``````````````````
M````````UJ$```````#5H0````````````!0J```````````````````````
M````````````V:'4H0````#<H=VA4:A2J````````````````-JAVZ$`````
M````````````````````````````````````````````````````````````
M`````````````````````````````````)*H````````T:$`````````````
M````````````````S:$`````````````````````````````````````````
M`````````````````````````%.H````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#0H0``````````````````````````````````Z*$`````[*&GH0``
M````````````````XZ'`H0````````````"DH0``````````````````````
M````````````````````````````````````````````````````````````
MP:$`````````````````````I*BBJ````````````````*BHIJBZJ```K*BJ
MJ```````````L*BNJ````````,*A``"TJ+*H``"YJ```````````H:@`````
M````````````````````````````````````````I:@`````````````````
M`*>H````````````````````````````````````````J:@`````````````
M``````````````````````````````````````````````````"]J```````
M`+ZH``````````"MJ```````````````````````````````````````````
M``````````````````````````````````"QJ```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"C
MJ```JZ@``*^H``"SJ```M:@``+:H``"WJ```N*@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````NZ@`````````
M``````````````````````````````#`J```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"FH0``I:%`J$&H``````````````````````````````````!"J```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`*&FHJ:CIJ2FI::FIJ>FJ*:IIJJFJZ:LIJVFKJ:OIK"FL:8``+*FLZ:TIK6F
MMJ:WIKBF``````````````````#!IL*FPZ;$IL6FQJ;'ILBFR:;*ILNFS*;-
MILZFSZ;0IM&F``#2IM.FU*;5IM:FUZ;8I@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MIZ<`````````````````````````````````````H:>BIZ.GI*>EIZ:GJ*>I
MIZJGJZ>LIZVGKJ>OI["GL:>RI[.GM*>UI[:GMZ>XI[FGNJ>[I[RGO:>^I[^G
MP*?!I]&GTJ?3I]2GU:?6I]BGV:?:I]NGW*?=I]ZGWZ?@I^&GXJ?CI^2GY:?F
MI^>GZ*?II^JGZZ?LI^VG[J?OI_"G\:<``->G``````).!$X%3@9.#TX23A=.
M'TX@3B%.(TXF3BE.+DXO3C%.,TXU3C=./$Y`3D%.0DY$3D9.2DY13E5.5TY:
M3EM.8DYC3F1.94YG3FA.:DYK3FQ.;4YN3F].<DYT3G5.=DYW3GA.>4YZ3GM.
M?$Y]3G].@$Z!3H).@TZ$3H5.ATZ*3@``D$Z63I=.F4Z<3IU.GDZC3JI.KTZP
M3K%.M$ZV3K=.N$ZY3KQ.O4Z^3LA.S$[/3M!.TD[:3MM.W$[@3N).YD[G3NE.
M[4[N3N].\4[T3OA.^4[Z3OQ._DX`3P)/`T\$3P5/!D\'3PA/"T\,3Q)/$T\4
M3Q5/%D\<3QU/(4\C3RA/*4\L3RU/+D\Q3S-/-4\W3SE/.T\^3S]/0$]!3T)/
M1$]%3T=/2$])3TI/2T],3U)/5$]63V%/8D]F3VA/:D]K3VU/;D]Q3W)/=4]W
M3WA/>4]Z3WU/@$^!3X)/A4^&3X=/BD^,3XY/D$^23Y-/E4^63YA/F4^:3YQ/
MGD^?3Z%/HD\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````I$^K3ZU/L$^Q3[)/LT^T3[9/MT^X3[E/ND^[3[Q/O4^^3\!/P4_"3\9/
MQT_(3\E/RT_,3\U/TD_33]1/U4_63]E/VT_@3^)/Y$_E3^=/ZT_L3_!/\D_T
M3_5/]D_W3_E/^T_\3_U/_T\`4`%0`E`#4`10!5`&4`=0"%`)4`I0```+4`Y0
M$%`14!-0%5`64!=0&U`=4!Y0(%`B4"-0)%`G4"M0+U`P4#%0,E`S4#10-5`V
M4#=0.%`Y4#M0/5`_4$!005!"4$1015!&4$E02E!+4$U04%!14%)04U!44%90
M5U!84%E06U!=4%Y07U!@4&%08E!C4&109E!G4&A0:5!J4&M0;5!N4&]0<%!Q
M4')0<U!T4'50>%!Y4'I0?%!]4(%0@E"#4(10AE"'4(E0BE"+4(Q0CE"/4)!0
MD5"24)-0E%"54)90EU"84)E0FE";4)Q0G5">4)]0H%"A4*)0I%"F4*I0JU"M
M4*Y0KU"P4+%0LU"T4+50ME"W4+A0N5"\4```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"]4+Y0OU#`4,%0PE##4,10Q5#&4,=0R%#)
M4,I0RU#,4,U0SE#04-%0TE#34-10U5#74-A0V5#;4-Q0W5#>4-]0X%#A4.)0
MXU#D4.50Z%#I4.I0ZU#O4/!0\5#R4/10]E#W4/A0^5#Z4/Q0_5#^4/]0`%$!
M40)1`U$$4051"%$```E1"E$,40U1#E$/41!1$5$34111%5$641=1&%$941I1
M&U$<41U1'E$?42!1(E$C4211)5$F42=1*%$I42I1*U$L42U1+E$O43!1,5$R
M43-1-%$U4391-U$X43E1.E$[43Q1/5$^44)11U%*44Q13E%/45!14E%345=1
M6%%945M175%>45]18%%A46-19%%F46=1:5%J46]1<E%Z47Y1?U&#4811AE&'
M48I1BU&.48]1D%&149-1E%&849I1G5&>49]1H5&C4:91IU&H4:E1JE&M4:Y1
MM%&X4;E1NE&^4;]1P5'"4<-1Q5'(4<I1S5'.4=!1TE'34=11U5'64==1````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-A1V5':4=Q1
MWE'?4>)1XU'E4>91YU'H4>E1ZE'L4>Y1\5'R4?11]U'^4012!5()4@M2#%(/
M4A!2$U(44A52'%(>4A]2(5(B4B-2)5(F4B=2*E(L4B]2,5(R4C12-5(\4CY2
M1%)%4D921U)(4DE22U).4D]24E)34E525U)84@``65):4EM275)?4F!28E)C
M4F129E)H4FM2;%)M4FY2<%)Q4G-2=%)U4G92=U)X4GE2>E)[4GQ2?E*`4H-2
MA%*%4H92AU*)4HI2BU*,4HU2CE*/4I%2DE*44I52EE*74IA2F5*:4IQ2I%*E
M4J92IU*N4J]2L%*T4K52ME*W4KA2N5*Z4KM2O%*]4L!2P5+"4L12Q5+&4LA2
MRE+,4LU2SE+/4M%2TU+44M52UU+94MI2VU+<4MU2WE+@4N%2XE+C4N52YE+G
M4NA2Z5+J4NM2[%+M4NY2[U+Q4O)2\U+T4O52]E+W4OA2^U+\4OU2`5,"4P-3
M!%,'4PE3"E,+4PQ3#E,`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````$5,24Q-3%%,84QM3'%,>4Q]3(E,D4R53)U,H4RE3*U,L4RU3
M+U,P4S%3,E,S4S13-5,V4S=3.%,\4SU30%-"4T131E-+4TQ335-04U136%-9
M4UM375-E4VA3:E-L4VU3<E-V4WE3>U-\4WU3?E.`4X%3@U.'4XA3BE..4X]3
M``"04Y%3DE.34Y13EE.74YE3FU.<4YY3H%.A4Z13IU.J4ZM3K%.M4Z]3L%.Q
M4[)3LU.T4[53MU.X4[E3NE.\4[U3OE/`4\-3Q%/%4\93QU/.4\]3T%/24]-3
MU5/:4]Q3W5/>4^%3XE/G4_13^E/^4_]3`%0"5`54!U0+5!14&%095!I4'%0B
M5"14)50J5#!4,U0V5#=4.E0]5#]4051"5$14151'5$E43%1-5$Y43U115%I4
M751>5%]48%1A5&-4951G5&E4:E1K5&Q4;51N5&]4<%1T5'E4>E1^5']4@52#
M5(54AU2(5(E4BE2-5)%4DU275)A4G%2>5)]4H%2A5```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"B5*54KE2P5+)4M52V5+=4N52Z
M5+Q4OE3#5,54RE3+5-94V%3;5.!4X53B5.-4Y%3K5.Q4[U3P5/%4]%3U5/94
M]U3X5/E4^U3^5`!5`E4#5015!54(50I5"U4,50U5#E4251-5%54651=5&%49
M51I5'%4=51Y5'U4A5255)E4``"A5*54K52U5,E4T5355-E4X53E5.E4[53U5
M0%5"54551U5(54M53%5-54Y53U5155)54U5455=56%5955I56U5=55Y57U5@
M56)58U5H56E5:U5O57!5<55R57-5=%5Y57I5?55_5855AE6,58U5CE6059)5
MDU655995EU6:59M5GE6@5:%5HE6C5:15I56F5:A5J56J5:M5K%6M5:Y5KU6P
M5;)5M%6V5;A5NE6\5;]5P%7!5<)5PU7&5<=5R%7*5<M5SE7/5=!5U5775=A5
MV57:5=M5WE7@5>)5YU7I5>U5[E7P5?%5]%7V5?A5^57Z5?M5_%7_50)6`U8$
M5@56````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````96
M!U8*5@M6#5805A%6$E835A16%5865A=6&58:5AQ6'58@5B%6(E8E5B96*%8I
M5BI6*U8N5B]6,%8S5C56-U8X5CI6/%8]5CY60%9!5D)60U9$5D561E9'5DA6
M259*5DM63U905E%64E935E565E9:5EM6759>5E]68%9A5@``8U9E5F969U9M
M5FY6;U9P5G)6<U9T5G56=U9X5GE6>E9]5GY6?U:`5H%6@E:#5H16AU:(5HE6
MBE:+5HQ6C5:05I%6DE:45I56EE:75IA6F5::5IM6G%:=5IY6GU:@5J%6HE:D
M5J56IE:G5JA6J5:J5JM6K%:M5JY6L%:Q5K)6LU:T5K56ME:X5KE6NE:[5KU6
MOE:_5L!6P5;"5L-6Q%;%5L96QU;(5LE6RU;,5LU6SE;/5M!6T5;25M-6U5;6
M5MA6V5;<5N-6Y5;F5N=6Z%;I5NI6[%;N5N]6\E;S5O96]U;X5OM6_%8`5P%7
M`E<%5P=7"U<,5PU7#E</5Q!7$5<`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````$E<35Q17%5<65Q=7&%<95QI7&U<=5QY7(%<A5R)7
M)%<E5R97)U<K5S%7,E<T5S57-E<W5SA7/%<]5S]705=#5T1715=&5TA725=+
M5U)74U=45U575E=85UE78E=C5V579U=L5VY7<%=Q5W)7=%=U5WA7>5=Z5WU7
M?E=_5X!7``"!5X=7B%>)5XI7C5>.5X]7D%>15Y17E5>65Y=7F%>95YI7G%>=
M5YY7GU>E5ZA7JE>L5Z]7L%>Q5[-7M5>V5[=7N5>Z5[M7O%>]5[Y7OU?`5\%7
MQ%?%5\97QU?(5\E7RE?,5\U7T%?15]-7UE?75]M7W%?>5^%7XE?C5^57YE?G
M5^A7Z5?J5^M7[%?N5_!7\5?R5_-7]5?V5_=7^U?\5_Y7_U<!6`-8!%@%6`A8
M"5@*6`Q8#E@/6!!8$E@36!18%E@76!A8&E@;6!Q8'5@?6")8(U@E6"98)U@H
M6"E8*U@L6"U8+E@O6#%8,E@S6#18-E@W6#A8.5@Z6#M8/%@]6```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````^6#]80%A!6$)80UA%
M6$981UA(6$E82EA+6$Y83UA06%)84UA56%985UA96%I86UA<6%U87UA@6&%8
M8EAC6&189EAG6&A8:5AJ6&U8;EAO6'!8<5AR6'-8=%AU6'98=UAX6'E8>EA[
M6'Q8?5A_6()8A%B&6(=8B%B*6(M8C%@``(U8CEB/6)!8D5B46)58EEB76)A8
MFUB<6)U8H%BA6*)8HUBD6*58IEBG6*I8JUBL6*U8KEBO6+!8L5BR6+-8M%BU
M6+98MUBX6+E8NEB[6+U8OEB_6,!8PEC#6,18QEC'6,A8R5C*6,M8S%C-6,Y8
MSUC06-)8TUC46-98UUC86-E8VEC;6-Q8W5C>6-]8X%CA6.)8XUCE6.98YUCH
M6.E8ZECM6.]8\5CR6/18]5CW6/A8^EC[6/Q8_5C^6/]8`%D!60-9!5D&60A9
M"5D*60M9#%D.61!9$5D261-9%UD861M9'5D>62!9(5DB62-9)EDH62Q9,%DR
M63-9-5DV63M9````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#U9/ED_64!90UE%64992EE,64U94%E265-965E;65Q975E>65]985EC
M66199EEG66A9:5EJ66M9;%EM66Y9;UEP67%9<EEU67=9>EE[67Q9?EE_68!9
MA5F)68M9C%F.68]9D%F16919E5F869I9FUF<69U9GUF@6:%9HEFF60``IUFL
M6:U9L%FQ6;-9M%FU6;99MUFX6;I9O%F]6;]9P%G!6<)9PUG$6<59QUG(6<E9
MS%G-6<Y9SUG56=99V5G;6=Y9WUG@6>%9XEGD6>99YUGI6>I9ZUGM6>Y9[UGP
M6?%9\EGS6?19]5GV6?=9^%GZ6?Q9_5G^60!:`EH*6@M:#5H.6@]:$%H26A1:
M%5H66A=:&5H:6AM:'5H>6B%:(EHD6B9:)UHH6BI:*UHL6BU:+EHO6C!:,UHU
M6C=:.%HY6CI:.UH]6CY:/UI!6D):0UI$6D5:1UI(6DM:3%I-6DY:3UI06E%:
M4EI36E1:5EI76EA:65I;6EQ:75I>6E]:8%H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````85IC6F1:95IF6FA::5IK6FQ:;5IN6F]:
M<%IQ6G):<UIX6GE:>UI\6GU:?EJ`6H%:@EJ#6H1:A5J&6H=:B%J)6HI:BUJ,
M6HU:CEJ/6I!:D5J36I1:E5J66I=:F%J96IQ:G5J>6I]:H%JA6J):HUJD6J5:
MIEJG6JA:J5JK6JQ:``"M6JY:KUJP6K%:M%JV6K=:N5JZ6KM:O%J]6K]:P%K#
M6L1:Q5K&6L=:R%K*6LM:S5K.6L]:T%K16M-:U5K76ME:VEK;6MU:WEK?6N):
MY%KE6N=:Z%KJ6NQ:[5KN6N]:\%KR6O-:]%KU6O9:]UKX6OE:^EK[6OQ:_5K^
M6O]:`%L!6P);`UL$6P5;!EL'6PA;"EL+6PQ;#5L.6P];$%L16Q);$UL46Q5;
M&%L96QI;&UL<6QU;'EL?6R!;(5LB6R-;)%LE6R9;)ULH6RE;*ELK6RQ;+5LN
M6R];,%LQ6S-;-5LV6SA;.5LZ6SM;/%L]6SY;/UM!6T);0UM$6T5;1EM'6P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!(6TE;2EM+
M6TQ;35M.6T];4EM66UY;8%MA6V=;:%MK6VU;;EMO6W);=%MV6W=;>%MY6WM;
M?%M^6W];@EN&6XI;C5N.6Y!;D5N26Y1;EEN?6Z=;J%NI6ZQ;K5NN6Z];L5NR
M6[=;NEN[6[Q;P%O!6\-;R%O)6\I;RUO-6\Y;SUL``-%;U%O56]9;UUO86]E;
MVEO;6]Q;X%OB6^-;YEOG6^E;ZEOK6^Q;[5OO6_%;\EOS6_1;]5OV6_=;_5O^
M6P!<`EP#7`5<!UP(7`M<#%P-7`Y<$%P27!-<%UP97!M<'EP?7"!<(5PC7"9<
M*%PI7"I<*UPM7"Y<+UPP7#)<,UPU7#9<-UQ#7$1<1EQ'7$Q<35Q27%-<5%Q6
M7%=<6%Q:7%M<7%Q=7%]<8EQD7&=<:%QI7&I<:UQL7&U<<%QR7'-<=%QU7'9<
M=UQX7'M<?%Q]7'Y<@%R#7(1<A5R&7(=<B5R*7(M<CER/7))<DUR57)U<GER?
M7*!<H5RD7*5<IERG7*A<````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````*I<KERO7+!<LERT7+9<N5RZ7+M<O%R^7,!<PES#7,5<QES'
M7,A<R5S*7,Q<S5S.7,]<T%S17--<U%S57-9<UUS87-I<VUS<7-U<WES?7.!<
MXESC7.=<Z5SK7.Q<[ESO7/%<\ESS7/1<]5SV7/=<^%SY7/I<_%S]7/Y<_UP`
M70```5T$705="%T)70I="UT,70U=#UT071%=$ET3715=%UT871E=&ET<71U=
M'UT@72%=(ETC725=*%TJ72M=+%TO73!=,5TR73-=-5TV73==.%TY73I=.UT\
M73]=0%U!74)=0UU$745=1EU(74E=35U.74]=4%U175)=4UU4755=5EU775E=
M6EU<75Y=7UU@76%=8EUC761=95UF76==:%UJ76U=;EUP77%=<EUS775==EUW
M77A=>5UZ77M=?%U]77Y=?UV`78%=@UV$785=AEV'78A=B5V*78M=C%V-78Y=
MCUV079%=DEV3791=E5V679==F%V:79M=G%V>79]=H%T`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````H5VB7:-=I%VE7:9=IUVH7:E=
MJEVK7:Q=K5VN7:]=L%VQ7;)=LUVT7;5=MEVX7;E=NEV[7;Q=O5V^7;]=P%W!
M7<)=PUW$7<9=QUW(7<E=REW+7<Q=SEW/7=!=T5W27=-=U%W57=9=UUW87=E=
MVEW<7=]=X%WC7>1=ZEWL7>U=``#P7?5=]EWX7?E=^EW[7?Q=_UT`7@1>!UX)
M7@I>"UX-7@Y>$EX37A=>'EX?7B!>(5XB7B->)%XE7BA>*5XJ7BM>+%XO7C!>
M,EXS7C1>-5XV7CE>.EX^7C]>0%Y!7D->1EY'7DA>25Y*7DM>35Y.7D]>4%Y1
M7E)>4UY67E=>6%Y97EI>7%Y=7E]>8%YC7F1>95YF7F=>:%YI7FI>:UYL7FU>
M;EYO7G!><5YU7G=>>5Y^7H%>@EZ#7H5>B%Z)7HQ>C5Z.7I)>F%Z;7IU>H5ZB
M7J->I%ZH7JE>JEZK7JQ>KEZO7K!>L5ZR7K1>NEZ[7KQ>O5Z_7L!>P5["7L->
MQ%[%7@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#&
M7L=>R%[+7LQ>S5[.7L]>T%[47M5>UU[87ME>VE[<7MU>WE[?7N!>X5[B7N->
MY%[E7N9>YU[I7NM>[%[M7NY>[U[P7O%>\E[S7O5>^%[Y7OM>_%[]7@5?!E\'
M7PE?#%\-7PY?$%\27Q1?%E\97QI?'%\=7QY?(5\B7R-?)%\``"A?*U\L7RY?
M,%\R7S-?-%\U7S9?-U\X7SM?/5\^7S]?05]"7T-?1%]%7T9?1U](7TE?2E]+
M7TQ?35].7T]?45]47UE?6E];7UQ?7E]?7V!?8U]E7V=?:%]K7VY?;U]R7W1?
M=5]V7WA?>E]]7WY??U^#7X9?C5^.7X]?D5^37Y1?EE^:7YM?G5^>7Y]?H%^B
M7Z-?I%^E7Z9?IU^I7ZM?K%^O7[!?L5^R7[-?M%^V7[A?N5^Z7[M?OE^_7\!?
MP5_"7\=?R%_*7\M?SE_37]1?U5_:7]M?W%_>7]]?XE_C7^5?YE_H7^E?[%_O
M7_!?\E_S7_1?]E_W7_E?^E_\7P=@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````A@"6`+8`Q@$&`18!-@%V`88!I@'F`?8")@(V`D
M8"Q@+6`N8#!@,6`R8#-@-&`V8#=@.&`Y8#I@/6`^8$!@1&!%8$9@1V!(8$E@
M2F!,8$Y@3V!18%-@5&!68%=@6&!;8%Q@7F!?8&!@86!E8&9@;F!Q8')@=&!U
M8'=@?F"`8```@6""8(5@AF"'8(A@BF"+8(Y@CV"08)%@DV"58)=@F&"98)Q@
MGF"A8*)@I&"E8*=@J6"J8*Y@L&"S8+5@MF"W8+E@NF"]8+Y@OV#`8,%@PF##
M8,1@QV#(8,E@S&#-8,Y@SV#08-)@TV#48-9@UV#98-M@WF#A8.)@XV#D8.5@
MZF#Q8/)@]6#W8/A@^V#\8/U@_F#_8`)A`V$$805A!V$*80MA#&$081%A$F$3
M811A%F$781AA&6$;81QA'6$>82%A(F$E82AA*6$J82QA+6$N82]A,&$Q83)A
M,V$T835A-F$W83AA.6$Z83MA/&$]83YA0&%!84)A0V%$845A1F$`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1V%)84MA36%/85!A
M4F%3851A5F%785AA66%:85MA7&%>85]A8&%A86-A9&%E869A:6%J86MA;&%M
M86YA;V%Q87)A<V%T879A>&%Y87IA>V%\87UA?F%_88!A@6&"88-AA&&%889A
MAV&(88EABF&,88UACV&089%ADF&3895A``"689=AF&&989IAFV&<89YAGV&@
M8:%AHF&C8:1AI6&F8:IAJV&M8:YAKV&P8;%ALF&S8;1AM6&V8;AAN6&Z8;MA
MO&&]8;]AP&'!8<-AQ&'%8<9AQV')8<QAS6'.8<]AT&'38=5AUF'78=AAV6':
M8=MAW&'=8=YAWV'@8>%AXF'C8>1AY6'G8>AAZ6'J8>MA[&'M8>YA[V'P8?%A
M\F'S8?1A]F'W8?AA^6'Z8?MA_&']8?YA`&(!8@)B`V($8@5B!V()8A-B%&(9
M8AQB'6(>8B!B(V(F8B=B*&(I8BMB+6(O8C!B,6(R8C5B-F(X8CEB.F([8CQB
M0F)$8D5B1F)*8@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!/8E!B56)68E=B66):8EQB76)>8E]B8&)A8F)B9&)E8FAB<6)R8G1B
M=6)W8GAB>F)[8GUB@6*"8H-BA6*&8H=BB&*+8HQBC6*.8H]BD&*48IEBG&*=
M8IYBHV*F8J=BJ6*J8JUBKF*O8K!BLF*S8K1BMF*W8KABNF*^8L!BP6(``,-B
MRV+/8M%BU6+=8MYBX&+A8N1BZF+K8O!B\F+U8OAB^6+Z8OMB`&,#8P1C!6,&
M8PIC"V,,8PUC#V,08Q)C$V,48Q5C%V,88QEC'&,F8R=C*6,L8RUC+F,P8S%C
M,V,T8S5C-F,W8SAC.V,\8SYC/V-`8T%C1&-'8TAC2F-18U)C4V-48U9C5V-8
M8UEC6F-;8UQC76-@8V1C96-F8VAC:F-K8VQC;V-P8W)C<V-T8W5C>&-Y8WQC
M?6-^8W]C@6.#8X1CA6.&8XMCC6.18Y-CE&.58Y=CF6.:8YMCG&.=8YYCGV.A
M8Z1CIF.K8Z]CL6.R8[5CMF.Y8[MCO6._8\!C````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````,%CPF/#8\5CQV/(8\ICRV/,8]%CTV/4
M8]5CUV/88]ECVF/;8]QCW6/?8^)CY&/E8^9CYV/H8^MC[&/N8^]C\&/Q8_-C
M]6/W8_EC^F/[8_QC_F,#9`1D!F0'9`AD"60*9`UD#F019!)D%6069!=D&&09
M9!ID'60?9")D(V0D9```)60G9"AD*60K9"YD+V0P9#%D,F0S9#5D-F0W9#AD
M.60[9#QD/F1`9$)D0V1)9$MD3&1-9$YD3V109%%D4V159%9D5V199%ID6V1<
M9%UD7V1@9&%D8F1C9&1D961F9&AD:F1K9&QD;F1O9'!D<61R9'-D=&1U9'9D
M=V1[9'QD?61^9']D@&2!9(-DAF2(9(EDBF2+9(QDC62.9(]DD&239)1DEV28
M9)IDFV2<9)UDGV2@9*%DHF2C9*5DIF2G9*ADJF2K9*]DL62R9+-DM&2V9+ED
MNV2]9+YDOV3!9,-DQ&3&9,=DR&3)9,IDRV3,9,]DT6339-1DU6369-EDVF0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````VV3<9-UD
MWV3@9.%DXV3E9.=DZ&3I9.IDZV3L9.UD[F3O9/!D\63R9/-D]&3U9/9D]V3X
M9/ED^F3[9/QD_63^9/]D`64"90-E!&4%909E!V4(90IE"V4,90UE#F4/91!E
M$643911E%64691=E&64:91ME'&4=91YE'V4@92%E```B92-E)&4F92=E*&4I
M92IE+&4M93!E,64R93-E-V4Z93QE/65`94%E0F5#941E1F5'94IE2V5-94YE
M4&5295-E5&5795AE6F5<95]E8&5A961E965G96AE:65J96UE;F5O97%E<V5U
M979E>&5Y97IE>V5\97UE?F5_98!E@66"98-EA&6%989EB&6)98IEC66.98]E
MDF64995EEF6899IEG66>9:!EHF6C9:9EJ&6J9:QEKF6Q9;)ELV6T9;5EMF6W
M9;AENF6[9;YEOV7`9<)EQV7(9<EERF7-9=!ET6739=1EU6789=EEVF7;9=QE
MW67>9=]EX67C9>1EZF7K90``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#R9?-E]&7U9?AE^67[9?QE_67^9?]E`68$9@5F!V8(9@EF
M"V8-9A!F$6829A9F%V889AIF&V8<9AYF(68B9B-F)&8F9BEF*F8K9BQF+F8P
M9C)F,V8W9CAF.68Z9CMF/68_9D!F0F9$9D5F1F9'9DAF269*9DUF3F909E%F
M6&8``%EF6V9<9EUF7F9@9F)F8V9E9F=F:69J9FMF;&9M9G%F<F9S9G5F>&9Y
M9GMF?&9]9G]F@&:!9H-FA6:&9HAFB6:*9HMFC6:.9H]FD&:29I-FE&:59IAF
MF6::9IMFG&:>9I]FH&:A9J)FHV:D9J5FIF:I9JIFJV:L9JUFKV:P9K%FLF:S
M9K5FMF:W9KAFNF:[9KQFO6:_9L!FP6;"9L-FQ&;%9L9FQV;(9LEFRF;+9LQF
MS6;.9L]FT&;19M)FTV;49M5FUF;79MAFVF;>9M]FX&;A9N)FXV;D9N5FYV;H
M9NIFZV;L9NUF[F;O9O%F]6;V9OAF^F;[9OUF`6<"9P-G````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````1G!6<&9P=G#&<.9P]G$6<2
M9Q-G%F<89QEG&F<<9QYG(&<A9R)G(V<D9R5G)V<I9RYG,&<R9S-G-F<W9SAG
M.6<[9SQG/F<_9T%G1&=%9T=G2F=+9TUG4F=49U5G5V=89UEG6F=;9UUG8F=C
M9V1G9F=G9VMG;&=N9W%G=&=V9P``>&=Y9WIG>V=]9X!G@F>#9X5GAF>(9XIG
MC&>-9XYGCV>19Y)GDV>49Y9GF6>;9Y]GH&>A9Z1GIF>I9ZQGKF>Q9[)GM&>Y
M9[IGNV>\9[UGOF>_9\!GPF?%9\9GQV?(9\EGRF?+9\QGS6?.9]5GUF?79]MG
MWV?A9^-GY&?F9^=GZ&?J9^MG[6?N9_)G]6?V9_=G^&?Y9_IG^V?\9_YG`6@"
M:`-H!&@&:`UH$&@2:!1H%6@8:!EH&F@;:!QH'F@?:"!H(F@C:"1H)6@F:"=H
M*&@K:"QH+6@N:"]H,&@Q:#1H-6@V:#IH.V@_:$=H2VA-:$]H4FA6:%=H6&A9
M:%IH6V@`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M7&A=:%YH7VAJ:&QH;6AN:&]H<&AQ:')H<VAU:'AH>6AZ:'MH?&A]:'YH?VB`
M:()HA&B':(AHB6B*:(MHC&B-:(YHD&B1:))HE&B5:)9HF&B9:)IHFVB<:)UH
MGFB?:*!HH6BC:*1HI6BI:*IHJVBL:*YHL6BR:+1HMFBW:+AH``"Y:+IHNVB\
M:+UHOFB_:,%HPVC$:,5HQFC':,AHRFC,:,YHSVC0:-%HTVC4:-9HUVC9:-MH
MW&C=:-YHWVCA:.)HY&CE:.9HYVCH:.EHZFCK:.QH[6CO:/)H\VCT:/9H]VCX
M:/MH_6C^:/]H`&D":0-I!&D&:0=I"&D):0II#&D/:1%I$VD4:15I%FD7:1AI
M&6D::1MI'&D=:1YI(6DB:2-I)6DF:2=I*&DI:2II*VDL:2YI+VDQ:3)I,VDU
M:39I-VDX:3II.VD\:3YI0&E!:4-I1&E%:49I1VE(:4EI2FE+:4QI36E.:4]I
M4&E1:5)I4VE5:59I6&E9:5MI7&E?:0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!A:6)I9&EE:6=I:&EI:6II;&EM:6]I<&ER:7-I
M=&EU:79I>FE[:7UI?FE_:8%I@VF%:8IIBVF,:8YICVF0:9%IDFF3:99IEVF9
M:9IIG6F>:9]IH&FA::)IHVFD::5IIFFI::IIK&FN::]IL&FR:;-IM6FV:;AI
MN6FZ:;QIO6D``+YIOVG`:<)IPVG$:<5IQFG':<AIR6G+:<UISVG1:=)ITVG5
M:=9IUVG8:=EIVFG<:=UIWFGA:>)IXVGD:>5IYFGG:>AIZ6GJ:>MI[&GN:>]I
M\&GQ:?-I]&GU:?9I]VGX:?EI^FG[:?QI_FD`:@%J`FH#:@1J!6H&:@=J"&H)
M:@MJ#&H-:@YJ#VH0:A%J$FH3:A1J%6H6:AEJ&FH;:AQJ'6H>:B!J(FHC:B1J
M)6HF:B=J*6HK:BQJ+6HN:C!J,FHS:C1J-FHW:CAJ.6HZ:CMJ/&H_:D!J06I"
M:D-J16I&:DAJ26I*:DMJ3&I-:DYJ3VI1:E)J4VI4:E5J5FI7:EIJ````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````%QJ76I>:E]J8&IB
M:F-J9&IF:F=J:&II:FIJ:VIL:FUJ;FIO:G!J<FIS:G1J=6IV:G=J>&IZ:GMJ
M?6I^:G]J@6J":H-JA6J&:H=JB&J):HIJBVJ,:HUJCVJ2:I-JE&J5:I9JF&J9
M:IIJFVJ<:IUJGFJ?:J%JHFJC:J1JI6JF:@``IVJH:JIJK6JN:J]JL&JQ:K)J
MLVJT:K5JMFJW:KAJN6JZ:KMJO&J]:KYJOVK`:L%JPFK#:L1JQ6K&:L=JR&K)
M:LIJRVK,:LUJSFK/:M!JT6K2:M-JU&K5:M9JUVK8:MEJVFK;:MQJW6K>:M]J
MX&KA:N)JXVKD:N5JYFKG:NAJZ6KJ:NMJ[&KM:NYJ[VKP:O%J\FKS:O1J]6KV
M:O=J^&KY:OIJ^VK\:OUJ_FK_:@!K`6L":P-K!&L%:P9K!VL(:PEK"FL+:PQK
M#6L.:P]K$&L1:Q)K$VL4:Q5K%FL7:QAK&6L::QMK'&L=:QYK'VLE:R9K*&LI
M:RIK*VLL:RUK+FL`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+VLP:S%K,VLT:S5K-FLX:SMK/&L]:S]K0&M!:T)K1&M%:TAK2FM+
M:TUK3FM/:U!K46M2:U-K5&M5:U9K5VM8:UIK6VM<:UUK7FM?:V!K86MH:VEK
M:VML:VUK;FMO:W!K<6MR:W-K=&MU:W9K=VMX:WIK?6M^:W]K@&N%:XAK``",
M:XYKCVN0:Y%KE&N5:Y=KF&N9:YQKG6N>:Y]KH&NB:Z-KI&NE:Z9KIVNH:ZEK
MJVNL:ZUKKFNO:[!KL6NR:[9KN&NY:[IKNVN\:[UKOFO`:\-KQ&O&:\=KR&O)
M:\IKS&O.:]!KT6O8:]IKW&O=:]YKWVO@:^)KXVOD:^5KYFOG:^AKZ6OL:^UK
M[FOP:_%K\FOT:_9K]VOX:_IK^VO\:_YK_VL`;`%L`FP#;`1L"&P);`IL"VP,
M;`YL$FP7;!QL'6P>;"!L(VPE;"ML+&PM;#%L,VPV;#=L.6PZ;#ML/&P^;#]L
M0VQ$;$5L2&Q+;$QL36Q.;$]L46Q2;%-L5FQ8;```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!9;%IL8FQC;&5L9FQG;&ML;&QM;&YL
M;VQQ;'-L=6QW;'AL>FQ[;'QL?VR`;(1LAVR*;(MLC6R.;)%LDFR5;)9LEVR8
M;)ILG&R=;)YLH&RB;*ALK&RO;+!LM&RU;+9LMVRZ;,!LP6S";,-LQFS';,AL
MRVS-;,YLSVS1;-)LV&P``-ELVFS<;-ULWVSD;.9LYVSI;.QL[6SR;/1L^6S_
M;`!M`FT#;05M!FT(;0EM"FT-;0]M$&T1;1-M%&T5;19M&&T<;1UM'VT@;2%M
M(FTC;21M)FTH;2EM+&TM;2]M,&TT;39M-VTX;3IM/VU`;4)M1&U);4QM4&U5
M;59M5VU8;5MM76U?;6%M8FUD;65M9VUH;6MM;&UM;7!M<6UR;7-M=6UV;7EM
M>FU[;7UM?FU_;8!M@6V#;81MAFV';8IMBVV-;8]MD&V2;99MEVV8;9EMFFV<
M;:)MI6VL;:UML&VQ;;-MM&VV;;=MN6VZ;;MMO&V];;YMP6W";<-MR&W);<IM
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````,UMSFW/
M;=!MTFW3;=1MU6W7;=IMVVW<;=]MXFWC;>5MYVWH;>EMZFWM;>]M\&WR;?1M
M]6WV;?AM^FW];?YM_VT`;@%N`FX#;@1N!FX';@AN"6X+;@]N$FX3;A5N&&X9
M;AMN'&X>;A]N(FXF;B=N*&XJ;BQN+FXP;C%N,VXU;@``-FXW;CEN.VX\;CUN
M/FX_;D!N06Y";D5N1FY';DAN26Y*;DMN3&Y/;E!N46Y2;E5N5VY9;EIN7&Y=
M;EYN8&YA;F)N8VYD;F5N9FYG;FAN:6YJ;FQN;6YO;G!N<6YR;G-N=&YU;G9N
M=VYX;GEN>FY[;GQN?6Z`;H%N@FZ$;H=NB&Z*;HMNC&Z-;HYND6Z2;I-NE&Z5
M;I9NEVZ9;IINFVZ=;IYNH&ZA;J-NI&ZF;JANJ6ZK;JQNK6ZN;K!NLVZU;KAN
MN6Z\;KYNOV[`;L-NQ&[%;L9NR&[);LINS&[-;LYNT&[2;M9NV&[9;MMNW&[=
M;N-NYV[J;NMN[&[M;NYN[VX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````\&[Q;O)N\V[U;O9N]V[X;OIN^V[\;OUN_F[_;@!O`6\#
M;P1O!6\';PAO"F\+;PQO#6\.;Q!O$6\2;Q9O%V\8;QEO&F\;;QQO'6\>;Q]O
M(6\B;R-O)6\F;R=O*&\L;RYO,&\R;S1O-6\W;SAO.6\Z;SMO/&\];S]O0&]!
M;T)O``!#;T1O16](;TEO2F],;TYO3V]0;U%O4F]3;U1O56]6;U=O66]:;UMO
M76]?;V!O86]C;V1O96]G;VAO:6]J;VMO;&]O;W!O<6]S;W5O=F]W;WEO>V]]
M;WYO?V^`;X%O@F^#;X5OAF^';XIOBV^/;Y!OD6^2;Y-OE&^5;Y9OEV^8;YEO
MFF^;;YUOGF^?;Z!OHF^C;Z1OI6^F;ZAOJ6^J;ZMOK&^M;ZYOKV^P;[%OLF^T
M;[5OMV^X;[IONV^\;[UOOF^_;\%OPV_$;\5OQF_';\AORF_+;\QOS6_.;\]O
MT&_3;]1OU6_6;]=OV&_9;]IOVV_<;]UOWV_B;^-OY&_E;P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#F;^=OZ&_I;^IOZV_L;^UO
M\&_Q;_)O\V_T;_5O]F_W;_AO^6_Z;_MO_&_];_YO_V\`<`%P`G`#<`1P!7`&
M<`=P"'`)<`IP"W`,<`UP#G`/<!!P$G`3<!1P%7`6<!=P&'`9<!QP'7`><!]P
M('`A<")P)'`E<"9P)W`H<"EP*G```"MP+'`M<"YP+W`P<#%P,G`S<#1P-G`W
M<#AP.G`[<#QP/7`^<#]P0'!!<$)P0W!$<$5P1G!'<$AP27!*<$MP37!.<%!P
M47!2<%-P5'!5<%9P5W!8<%EP6G!;<%QP77!?<&!P87!B<&-P9'!E<&9P9W!H
M<&EP:G!N<'%P<G!S<'1P=W!Y<'IP>W!]<(%P@G"#<(1PAG"'<(APBW",<(UP
MCW"0<)%PDW"7<)APFG";<)YPGW"@<*%PHG"C<*1PI7"F<*=PJ'"I<*IPL'"R
M<+1PM7"V<+IPOG"_<,1PQ7#&<,=PR7#+<,QPS7#.<,]PT'#1<-)PTW#4<-5P
MUG#7<-IP````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-QPW7#><.!PX7#B<.-PY7#J<.YP\'#Q</)P\W#T</5P]G#X</IP^W#\</YP
M_W``<0%Q`G$#<01Q!7$&<0=Q"'$+<0QQ#7$.<0]Q$7$2<11Q%W$;<1QQ'7$>
M<1]Q('$A<2)Q(W$D<25Q)W$H<2EQ*G$K<2QQ+7$N<3)Q,W$T<0``-7$W<3AQ
M.7$Z<3MQ/'$]<3YQ/W%`<4%Q0G%#<41Q1G%'<4AQ27%+<4UQ3W%0<5%Q4G%3
M<51Q57%6<5=Q6'%9<5IQ6W%=<5]Q8'%A<6)Q8W%E<6EQ:G%K<6QQ;7%O<7!Q
M<7%T<75Q=G%W<7EQ>W%\<7YQ?W&`<8%Q@G&#<85QAG&'<8AQB7&+<8QQC7&.
M<9!QD7&2<9-QE7&6<9=QFG&;<9QQG7&><:%QHG&C<:1QI7&F<:=QJ7&J<:MQ
MK7&N<:]QL'&Q<;)QM'&V<;=QN'&Z<;MQO'&]<;YQOW'`<<%QPG'$<<5QQG''
M<<AQR7'*<<MQS''-<<]QT''1<=)QTW$`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````UG'7<=AQV7':<=MQW''=<=YQWW'A<>)QXW'D
M<>9QZ''I<>IQZW'L<>UQ[W'P<?%Q\G'S<?1Q]7'V<?=Q^''Z<?MQ_'']<?YQ
M_W$`<@%R`G(#<@1R!7('<@AR"7(*<@MR#'(-<@YR#W(0<A%R$G(3<A1R%7(6
M<A=R&'(9<AIR```;<AQR'G(?<B!R(7(B<B-R)'(E<B9R)W(I<BMR+7(N<B]R
M,G(S<C1R.G(\<CYR0')!<D)R0W)$<D5R1G))<DIR2W).<D]R4')1<E-R5')5
M<E=R6'):<EQR7G)@<F-R9')E<FAR:G)K<FQR;7)P<G%R<W)T<G9R=W)X<GMR
M?')]<H)R@W*%<H9RAW*(<HERC'*.<I!RD7*3<I1RE7*6<I=RF'*9<IIRFW*<
M<IURGG*@<J%RHG*C<J1RI7*F<J=RJ'*I<JIRJW*N<K%RLG*S<K5RNG*[<KQR
MO7*^<K]RP'+%<L9RQW+)<LIRRW+,<L]RT7+3<M1RU7+6<MARVG+;<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````P`3`",+<`R0+'`J@``S`%,!0@7O\6("8@&"`9(!P@'2`4,!4P"#`)
M,`HP"S`,,`TP#C`/,!8P%S`0,!$PL0#7`/<`-B(G(B@B$2(/(BHB*2(((C<B
M&B*E(B4B("(2(YDB*R(N(F$B3")((CTB'2)@(FXB;R)D(F4B'B(U(C0B0B9`
M)K``,B`S(`,A!/^D`.#_X?\P(*<`%B$&)@4FRR7/)<XEQR7&):$EH"6S);(E
M.R"2(9`AD2&3(1,P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````<"%Q(7(A<R%T(74A=B%W(7@A>2$`````
M``````````"()(DDBB2+)(PDC22.)(\DD"21))(DDR24))4DEB27))@DF22:
M))LD="1U)'8D=R1X)'DD>B1[)'PD?21^)'\D@"2!)((D@R2$)(4DAB2')&`D
M821B)&,D9"1E)&8D9R1H)&DD`````"`R(3(B,B,R)#(E,B8R)S(H,BDR````
M`&`A82%B(6,A9"%E(68A9R%H(6DA:B%K(0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````!_P+_`__E
M_P7_!O\'_PC_"?\*_PO_#/\-_P[_#_\0_Q'_$O\3_Q3_%?\6_Q?_&/\9_QK_
M&_\<_QW_'O\?_R#_(?\B_R/_)/\E_R;_)_\H_RG_*O\K_RS_+?\N_R__,/\Q
M_S+_,_\T_S7_-O\W_SC_.?\Z_SO_//\]_S[_/_]`_T'_0O]#_T3_1?]&_T?_
M2/])_TK_2_],_TW_3O]/_U#_4?]2_U/_5/]5_U;_5_]8_UG_6O];_US_7?_C
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$$P0C!#,$0P13!&,$<P2#!),$HP2S!,,$TP3C!/,%`P43!2
M,%,P5#!5,%8P5S!8,%DP6C!;,%PP73!>,%\P8#!A,&(P8S!D,&4P9C!G,&@P
M:3!J,&LP;#!M,&XP;S!P,'$P<C!S,'0P=3!V,'<P>#!Y,'HP>S!\,'TP?C!_
M,(`P@3"",(,PA#"%,(8PAS"(,(DPBC"+,(PPC3".,(\PD#"1,)(PDS``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````H3"B,*,PI#"E,*8PIS"H,*DP
MJC"K,*PPK3"N,*\PL#"Q,+(PLS"T,+4PMC"W,+@PN3"Z,+LPO#"],+XPOS#`
M,,$PPC##,,0PQ3#&,,<PR##),,HPRS#,,,TPSC#/,-`PT3#2,-,PU##5,-8P
MUS#8,-DPVC#;,-PPW3#>,-\PX##A,.(PXS#D,.4PYC#G,.@PZ3#J,.LP[##M
M,.XP[S#P,/$P\C#S,/0P]3#V,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"1
M`Y(#DP.4`Y4#E@.7`Y@#F0.:`YL#G`.=`YX#GP.@`Z$#HP.D`Z4#I@.G`Z@#
MJ0,`````````````````````L0.R`[,#M`.U`[8#MP.X`[D#N@.[`[P#O0.^
M`[\#P`/!`\,#Q`/%`\8#QP/(`\D#```````````````````U_C;^.?XZ_C_^
M0/X]_C[^0?Y"_D/^1/X`````._X\_C?^./XQ_@``,_XT_@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````!`$$002!!,$%`05!`$$%@07!!@$&00:!!L$'`0=
M!!X$'P0@!"$$(@0C!"0$)00F!"<$*`0I!"H$*P0L!"T$+@0O!```````````
M`````````````````````````````#`$,00R!#,$-`0U!%$$-@0W!#@$.00Z
M!#L$/`0]!#X$/P1`!$$$0@1#!$0$101&!$<$2`1)!$H$2P1,!$T$3@1/!```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````,H"RP+9`A,@%2`E(#4@!2$)(98AER&8(9DA
M%2(?(B,B4B)F(F<BOR)0)5$E4B53)50E5256)5<E6"59)5HE6R5<)5TE7B5?
M)6`E825B)6,E9"5E)68E9R5H)6DE:B5K)6PE;25N)6\E<"5Q)7(E<R6!)8(E
M@R6$)84EAB6')0``B"6))8HEBR6,)8TECB6/)9,EE"65);PEO27B)>,EY"7E
M)0DFE2(2,!TP'C```````````````````````````````0'A`,X!X``3`>D`
M&P'H`"L![0#0`>P`30'S`-(!\@!K`?H`U`'Y`-8!V`':`=P!_`#J`%$"``!$
M`4@!``!A`@``````````!3$&,0<Q"#$),0HQ"S$,,0TQ#C$/,1`Q$3$2,1,Q
M%#$5,18Q%S$8,1DQ&C$;,1PQ'3$>,1\Q(#$A,2(Q(S$D,24Q)C$G,2@Q*3$`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(3`B,",P)#`E
M,"8P)S`H,"DPHS*.,X\SG#.=,YXSH3/$,\XST3/2,]4S,/[B_^3_```A(3$R
M```0(````````/PPFS"<,/TP_C`&,)TPGC!)_DK^2_Y,_DW^3OY/_E#^4?Y2
M_E3^5?Y6_E?^6?Y:_EO^7/Y=_E[^7_Y@_F'^``!B_F/^9/YE_F;^:/YI_FK^
M:_X```````````````````````````````````<P````````````````````
M````````````````)0$E`B4#)00E!24&)0<E""4))0HE"R4,)0TE#B4/)1`E
M$242)1,E%"45)18E%R48)1DE&B4;)1PE'24>)1\E("4A)2(E(R4D)24E)B4G
M)2@E*24J)2LE+"4M)2XE+R4P)3$E,B4S)30E-24V)3<E."4Y)3HE.R4\)3TE
M/B4_)4`E025")4,E1"5%)48E1R5()4DE2B5+)0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#<<MURWW+B<N-RY'+E<N9RYW+J<NMR]7+V<OER_7+^<O]R`',"
M<P1S!7,&<P=S"',)<PMS#',-<P]S$',1<Q)S%',8<QES&G,?<R!S(W,D<R9S
M)W,H<RUS+W,P<S)S,W,U<S9S.G,[<SQS/7-`<T%S0G-#<T1S17-&<T=S2',`
M`$ES2G-+<TQS3G-/<U%S4W-4<U5S5G-8<UES6G-;<UQS77-><U]S87-B<V-S
M9'-E<V9S9W-H<VES:G-K<VYS<'-Q<P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````')S<W-T<W5S=G-W<WAS>7-Z<WMS
M?'-]<W]S@'.!<X)S@W.%<X9SB'.*<XQSC7./<Y!SDG.3<Y1SE7.7<YASF7.:
M<YQSG7.><Z!SH7.C<Z1SI7.F<Z=SJ'.J<ZQSK7.Q<[1SM7.V<[ASN7.\<[US
MOG._<\%SPW/$<\5SQG/'<P``RW/,<\YSTG/3<]1SU7/6<]=SV'/:<]MSW'/=
M<]]SX7/B<^-SY'/F<^ASZG/K<^QS[G/O<_!S\7/S<_1S]7/V<_=S````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````^'/Y
M<_IS^W/\<_US_G/_<P!T`70"=`1T!W0(=`MT#'0-=`YT$702=!-T%'05=!9T
M%W08=!ET''0==!YT'W0@="%T(W0D="=T*70K="UT+W0Q=#)T-W0X=#ET.G0[
M=#UT/G0_=$!T0G1#=$1T171&=$=T2'1)=$IT2W1,=$UT``!.=$]T4'11=%)T
M4W14=%9T6'1==&!T871B=&-T9'1E=&9T9W1H=&ET:G1K=&QT;G1O='%T<G1S
M='1T=71X='ET>G0`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````![='QT?71_=()TA'2%=(9TB'2)=(ITC'2-=(]TD722
M=)-TE'25=)9TEW28=)ETFG2;=)UTGW2@=*%THG2C=*1TI72F=*ITJW2L=*UT
MKG2O=+!TL72R=+-TM'2U=+9TMW2X=+ETNW2\=+UTOG2_=,!TP73"=,-TQ'3%
M=,9TQW0``,ATR73*=,MTS'3-=,YTSW30=-%TTW34=-5TUG37=-ATV73:=-MT
MW73?=.%TY73G=.ATZ73J=.MT['3M=/!T\73R=```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````/-T]73X=/ET^G3[=/QT
M_73^=`!U`74"=0-U!74&=0=U"'4)=0IU"W4,=0YU$'42=11U%746=1=U&W4=
M=1YU('4A=2)U(W4D=29U)W4J=2YU-'4V=3EU/'4]=3]U075"=4-U1'5&=4=U
M275*=4UU4'51=5)U4W55=59U5W58=0``775>=5]U8'5A=6)U8W5D=6=U:'5I
M=6MU;'5M=6YU;W5P=7%U<W5U=79U=W5Z=7MU?'5]=7YU@'6!=8)UA'6%=8=U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B'6)=8IUC'6-=8YUD'63=95UF'6;=9QUGG6B=:9UIW6H=:EUJG6M=;9U
MMW6Z=;MUOW7`=<%UQG7+=<QUSG7/==!UT773===UV77:==QUW77?=>!UX77E
M=>EU['7M=>YU[W7R=?-U]77V=?=U^'7Z=?MU_77^=0)V!'8&=@=V```(=@EV
M"W8-=@YV#W81=A)V$W84=A9V&G8<=AUV'G8A=B-V)W8H=BQV+G8O=C%V,G8V
M=C=V.78Z=CMV/79!=D)V1'8`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!%=D9V1W9(=DEV2G9+=DYV3W90=E%V4G93
M=E5V5W98=EEV6G9;=EUV7W9@=F%V8G9D=F5V9G9G=FAV:79J=FQV;79N=G!V
M<79R=G-V='9U=G9V=W9Y=GIV?'9_=H!V@7:#=H5VB7:*=HQVC7:/=I!VDG:4
M=I5VEW:8=IIVFW8``)QVG7:>=I]VH':A=J)VHW:E=J9VIW:H=JEVJG:K=JQV
MK7:O=K!VLW:U=K9VMW:X=KEVNG:[=KQVO7:^=L!VP7;#=DI5/Y;#5RACSE0)
M5<!4D79,=CR%[G=^@HUX,7*8EHV7*&R)6_I/"6.79KA<^H!(:*Z``F;.=OE1
M5F6L<?%_A(BR4&59RF&S;ZV"3&-28NU3)U0&>VM1I'7T7=1BRXUVEXIB&8!=
M5SB78G\X<GUVSV=^=D9D<$\EC=QB%WJ19>US+&1S8BR"@9A_9TAR;F+,8C1/
MXW1*4YY2RGZFD"Y>AFB<:8"!T7[2:,5XC(91E8U0)(S>@MZ`!5,2B652````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````,1VQW;)=LMV
MS';3=M5VV7;:=MQVW7;>=N!VX7;B=N-VY';F=N=VZ';I=NIVZW;L=NUV\';S
M=O5V]G;W=OIV^W;]=O]V`'<"=P-W!7<&=PIW#'<.=P]W$'<1=Q)W$W<4=Q5W
M%G<7=QAW&W<<=QUW'G<A=R-W)'<E=R=W*G<K=P``+'<N=S!W,7<R=S-W-'<Y
M=SMW/7<^=S]W0G=$=T5W1G=(=TEW2G=+=TQW37=.=T]W4G=3=U1W57=6=U=W
M6'=9=UQWA(7YEMU/(5AQF9U;L6*E8K1F>8R-G`9R;V>1>+)@45,74XB/S(`=
MC:&4#5#(<@=9ZV`9<:N(5%GO@BQG*'LI7?=^+77U;&:.^(\\D#N?U&L9D11[
M?%^G>-:$/875:]EKUFL!7H=>^77ME5UE"E_%7Y^/P5C"@7^06Y:ME[F/%G\L
MC4%BOT_84UY3J(^ICZN/39`':&I?F(%HB-:<BV$K4BIV;%^,9=)OZ&Z^6TAD
M=5&P4<1G&4[)>7R9LW``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````77=>=U]W8'=D=V=W:7=J=VUW;G=O=W!W<7=R=W-W='=U=W9W
M=W=X=WIW>W=\=X%W@G>#=X9WAW>(=XEWBG>+=X]WD'>3=Y1WE7>6=Y=WF'>9
M=YIWFW><=YUWGG>A=Z-WI'>F=ZAWJW>M=ZYWKW>Q=[)WM'>V=[=WN'>Y=[IW
M``"\=[YWP'?!=\)WPW?$=\5WQG?'=\AWR7?*=\MWS'?.=\]WT'?1=])WTW?4
M=]5WUG?8=]EWVG?==]YWWW?@=^%WY'?%=79>NW/@@ZUDZ&*UE.)L6E/#4@]D
MPI24>R]/&UXV@A:!BH$D;LIL<YI58UQ3^E1EB.!7#4X#7F5K/WSHD!9@YF0<
M<\&(4&=-8B*-;'<ICL>1:5_<@R&%$)G"4Y6&BVOM8.A@?W#-@C&"TTZG;,^%
MS639?/UI^69)@Y535GNG3XQ12VU"7&V.TF/)4RR#-H/E9[1X/63?6Y1<[EWG
MB\9B]&=ZC`!DNF-)AXN9%XP@?_*4ITX0EJ28#&86<P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#F=^AWZG?O=_!W\7?R=_1W]7?W
M=_EW^G?[=_QW`W@$>`5X!G@'>`AX"G@+>`YX#W@0>!-X%7@9>!MX'G@@>"%X
M(G@D>"AX*G@K>"YX+W@Q>#)X,W@U>#9X/7@_>$%X0GA#>$1X1GA(>$EX2GA+
M>$UX3WA1>%-X5'A8>%EX6G@``%MX7'A>>%]X8'AA>&)X8WAD>&5X9GAG>&AX
M:7AO>'!X<7AR>'-X='AU>'9X>'AY>'IX>WA]>'YX?WB`>(%X@GB#>#I7'5PX
M7G^5?U"@@()37F5%=3%5(5"%C81BGI0=9S)6;F_B7354DG!FCV]BI&2C8WM?
MB&_TD..!L(\87&AF\5^);$B6@8ULB)%D\'G.5UEJ$&)(5%A."WKI8(1OVHM_
M8AZ0BYKD>0-4]'4!8QE38&S?CQM?<)H[@'^?B$\Z7&2-Q7^E9;UP15&R46N&
M!UV@6[UB;)%T=0R.('H!87E[QT[X?H5W$4[M@1U2^E%Q:JA3AXX$E<^6P6YD
MEEII````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(1X
MA7B&>(AXBGB+>(]XD'B2>)1XE7B6>)EXG7B>>*!XHGBD>*9XJ'BI>*IXJWBL
M>*UXKGBO>+5XMGBW>+AXNGB[>+QXO7B_>,!XPGC#>,1XQGC'>,AXS'C->,YX
MSWC1>-)XTWC6>-=XV'C:>-MXW'C=>-YXWWC@>.%XXGCC>```Y'CE>.9XYWCI
M>.IXZWCM>.YX[WCP>/%X\WCU>/9X^'CY>/MX_'C]>/YX_W@`>0)Y`WD$>09Y
M!WD(>0EY"GD+>0QY0'BH4-=W$&3FB019XV/=77]Z/6D@3SF"F%4R3JYUEWIB
M7HI>[Y4;4CE4BG!V8R25@E<E9C]IAY$'5?-MKWXBB#-B\'ZU=2B#P7C,EIZ/
M2&'W=,V+9&LZ4E"-(6MJ@'&$\58&4\Y.&T[149=\BY$'?,-/?X[A>YQZ9V04
M7:Q0!H$!=KE\[&W@?U%G6%OX6\MXKF039*IC*V,9E2UDOH]4>REV4V(G6494
M>6NC4#1B)EZ&:^-.-XV+B(5?+I``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````#7D.>0]Y$'D1>1)Y%'D5>19Y%WD8>1EY&GD;>1QY
M'7D?>2!Y(7DB>2-Y)7DF>2=Y*'DI>2IY*WDL>2UY+GDO>3!Y,7DR>3-Y-7DV
M>3=Y.'DY>3UY/WE">4-Y1'E%>4=Y2GE+>4QY37E.>4]Y4'E1>5)Y5'E5>5AY
M67EA>6-Y``!D>69Y:7EJ>6MY;'EN>7!Y<7ER>7-Y='EU>79Y>7E[>7QY?7E^
M>7]Y@GF#>89YAWF(>8EYBWF,>8UYCGF0>9%YDGD@8#V`Q6(Y3E53^)"X8\:`
MYF4N;$9/[F#A;=Z+.5_+AE-?(6-:46&#8V@`4F-C2(X24)M<=WG\6S!2.WJ\
M8%.0UW:W7Y=?A'9LCF]P>W9)>ZIW\U&3D"183D_T;NJ/3&4;>\1RI&W??^%:
MM6*57C!7@H0L>QU>'U\2D!1_H)B"8\=NF'BY<'A16Y>K5S5U0T\X=9=>YF!@
M6<!MOVN)>/Q3U9;+40%2B6,*5).4`XS,C3ERGWAVA^V/#8S@4P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"3>91YE7F6>9=YF'F9
M>9MYG'F=>9YYGWF@>:%YHGFC>:1YI7FF>:AYJ7FJ>:MYK'FM>:YYKWFP>;%Y
MLGFT>;5YMGFW>;AYO'F_><)YQ'G%><=YR'G*><QYSGG/>=!YTWG4>=9YUWG9
M>=IYVWG<>=UYWGG@>>%YXGGE>>AYZGD``.QY[GGQ>?)Y\WGT>?5Y]GGW>?EY
M^GG\>?YY_WD!>@1Z!7H'>@AZ"7H*>@QZ#WH0>A%Z$GH3>A5Z%GH8>AEZ&WH<
M>@%.[W;N4XF4=I@.GRV5FENBBR).'$ZL46.$PF&H4@MHET]K8+M1'FU<499B
MEV5AED:,%Y#8=?V08W?2:XIR['+[BS58>7=,C5QG0)6:@*9>(6Z26>]Z[7<[
ME;5KK64.?P9845$?EOE;J5@H5'*.9F5_F.16G93^=D&0AV/&5!I9.EF;5[*.
M-6?ZC36"05+P8!58_H;H7$6>Q$^=F+F+)5IV8(13?&)/D`*1?YEI8`R`/U$S
M@!1<=9DQ;8Q.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````!UZ'WHA>B)Z)'HE>B9Z)WHH>BEZ*GHK>BQZ+7HN>B]Z,'HQ>C)Z-'HU
M>C9Z.'HZ>CYZ0'I!>D)Z0WI$>D5Z1WI(>DEZ2GI+>DQZ37I.>D]Z4'I2>E-Z
M5'I5>E9Z6'I9>EIZ6WI<>EUZ7GI?>F!Z87IB>F-Z9'IE>F9Z9WIH>@``:7IJ
M>FMZ;'IM>FYZ;WIQ>G)Z<WIU>GMZ?'I]>GYZ@GJ%>H=ZB7J*>HMZC'J.>H]Z
MD'J3>I1ZF7J:>IMZGGJA>J)Z,(W14UI_3WL03T].`);5;-!SZ84&7FIU^W\*
M:OYWDI1!?N%1YG#-4]2/`X,IC:]R;9G;;$I7LX*Y9:J`/V(REJA9_TZ_B[I^
M/F7R@UZ7857>F*6`*E/]BR!4NH"?7KAL.8VL@EJ1*50;;`92MWY?5QIQ?FR)
M?$M9_4[_7R1AJGPP3@%<JV<"A_!<"Y7.F*]U_7`BD*]1'7^]BTE9Y%%;3R94
M*UEW9:2`=5MV8L)BD(]%7A]L)GL/3]A/#6<`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````HWJD>J=ZJ7JJ>JMZKGJO>K!ZL7JR>K1Z
MM7JV>K=ZN'JY>KIZNWJ\>KUZOGK`>L%ZPGK#>L1ZQ7K&>L=ZR'K)>LIZS'K-
M>LYZSWK0>M%ZTGK3>M1ZU7K7>MAZVGK;>MQZW7KA>N)ZY'KG>NAZZ7KJ>NMZ
M['KN>O!Z\7KR>O-Z``#T>O5Z]GKW>OAZ^WK\>OYZ`'L!>P)[!7L'>PE[#'L-
M>PY[$'L2>Q-[%GL7>QA[&GL<>QU['WLA>R)[(WLG>RE[+7MN;:IMCWFQB!=?
M*W6:8H6/[T_<D:=E+X%1@9Q>4(%TC6]2AHE+C0U9A5#83AR6-G)Y@1^-S%NC
MBT26AUD:?Y!4=E8.5N6+.66":9F4UG:);G)>&'5&9]%G_WJ=@':-'V'&>6)E
M8XV(41I2HI0X?YN`LGZ77"]N8&?9>XMVV)J/@91_U7P>9%"5/WI*5.543&L!
M9`AB/9[S@)EU<E)IEUN$/&CDA@&6E);LE"I.!%39?CEHWXT5@/1FFEZY?P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O>S![,GLT
M>S5[-GLW>SE[.WL]>S][0'M!>T)[0WM$>T9[2'M*>TU[3GM3>U5[5WM9>UQ[
M7GM?>V%[8WMD>V5[9GMG>VA[:7MJ>VM[;'MM>V][<'MS>W1[=GMX>WI[?'M]
M>W][@7N">X-[A'N&>X=[B'N)>XI[BWN,>XY[CWL``)%[DGN3>Y9[F'N9>YI[
MFWN>>Y][H'NC>Z1[I7NN>Z][L'NR>[-[M7NV>[=[N7NZ>[M[O'N]>[Y[OWO`
M>\)[PWO$>\)7/X"7:.5=.V6?4FU@FI^;3ZR.;%&K6Q-?Z5U>;/%B(8UQ4:F4
M_E*?;-^"UW*B5X1G+8T?69R/QX.55(U[,$^];&1;T5D3G^13RH:HFC>,H8!%
M97Z8^E;'EBY2W'104N%;`F,"B59.T&(J8/IH<U&86Z!1PHFA>X:94'_O8$QP
M+XU)47]>&Y!P=,2)+5=%>%)?GY_ZE6B//)OABWAV0FC<9^J--8T]4HJ/VF[-
M:`65[9#]5IQG^8C'C\A4````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````,5[R'O)>\I[RWO->\Y[SWO0>])[U'O5>]9[UWO8>]M[W'O>
M>]][X'OB>^-[Y'OG>^A[Z7OK>^Q[[7OO>_![\GOS>_1[]7OV>_A[^7OZ>_M[
M_7O_>P!\`7P"?`-\!'P%?`9\"'P)?`I\#7P.?!!\$7P2?!-\%'P5?!=\&'P9
M?```&GP;?!Q\'7P>?"!\(7PB?"-\)'PE?"A\*7PK?"Q\+7PN?"]\,'PQ?#)\
M,WPT?#5\-GPW?#E\.GP[?#Q\/7P^?$)\N)II6W=M)FRE3K-;AYICD:AAKY#I
MERM4M6W26_U1BE55?_!_O&1-8_%EOF&-8`IQ5VQ);"]9;6<J@M58CE9JC.MK
MW9!]61>`]U-I;754G55W@\^#.&B^>8Q454\(5-)VB8P"EK-LN&UKC1")9)XZ
MC3]6T9[5=8A?X')H8/Q4J$XJ:F&(4F!PC\14V'!YAC^>*FV/6QA?HGZ)5:]/
M-',\5)I3&5`.5'Q43D[]7UIT]EAKA.&`=(?0<LI\5FX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````0WQ$?$5\1GQ'?$A\27Q*?$M\
M3'Q.?$]\4'Q1?%)\4WQ4?%5\5GQ7?%A\67Q:?%M\7'Q=?%Y\7WQ@?&%\8GQC
M?&1\97QF?&=\:'QI?&I\:WQL?&U\;GQO?'!\<7QR?'5\=GQW?'A\>7QZ?'Y\
M?WR`?(%\@GR#?(1\A7R&?(=\``"(?(I\BWR,?(U\CGR/?)!\DWR4?)9\F7R:
M?)M\H'RA?*-\IGRG?*A\J7RK?*Q\K7RO?+!\M'RU?+9\MWRX?+I\NWPG7TZ&
M+%6D8I).JFPW8K&"UU1.4SYST6X[=1)2%E/=B]!IBE\`8.YM3U<B:Z]S4VC8
MCQ-_8F.C8"15ZG5BC!5QHVVF6WM>4H-,8<2>^GA7AR=\AW;P4?9@3'%#9DQ>
M36`.C'!P)6.)C[U?8F#4AMY6P6N48&=A25/@8&9F/XW]>1I/Z7!';+.+\HO8
M?F2##V9:6D*;46WW;4&,.VT93VMPMX,68M%@#9<GC7AY^U$^5_I7.F=X=3UZ
M[WF5>P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"_
M?,!\PGS#?,1\QGS)?,M\SGS/?-!\T7S2?--\U'S8?-I\VWS=?-Y\X7SB?.-\
MY'SE?.9\YWSI?.I\ZWSL?.U\[GSP?/%\\GSS?/1\]7SV?/=\^7SZ?/Q\_7S^
M?/]\`'T!?0)]`WT$?05]!GT'?0A]"7T+?0Q]#7T.?0]]$'T``!%]$GT3?11]
M%7T6?1=]&'T9?1I]&WT<?1U]'GT??2%](WTD?25])GTH?2E]*GTL?2U]+GTP
M?3%],GTS?31]-7TV?8R`99GYC\!OI8LAGNQ9Z7X)?PE4@6?8:)&/37S&ELI3
M)6"^=7)L<U/)6J=^)&/@40J!\5W?A(!B@%%C6PY/;7E"4KA@3FW$6\);H8NP
MB^)ES%]%EI-9YWZJ?@E6MV<Y67-/MEN@4EJ#BI@^C3)UOI1'4#QZ]TZV9WZ:
MP5I\:]%V6E<67#I[])5.<7Q1J8!P@GA9!'\G@\!H[&>Q>'=XXV)A8X![[4]J
M4L]14(/;:722]8TQC<&)+I6M>_9.````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#=].'TY?3I].WT\?3U]/GT_?4!]07U"?4-]1'U%
M?49]1WU(?4E]2GU+?4Q]37U.?4]]4'U1?5)]4WU4?55]5GU7?5A]67U:?5M]
M7'U=?5Y]7WU@?6%]8GUC?61]97UF?6=]:'UI?6I]:WUL?6U];WUP?7%]<GUS
M?71]=7UV?0``>'UY?7I]>WU\?7U]?GU_?8!]@7V"?8-]A'V%?89]AWV(?8E]
MBGV+?8Q]C7V.?8]]D'V1?9)]DWV4?95]EGV7?9A]95`P@E%2;YD0;H5NIVWZ
M7O50W%D&7$9M7VR&=8N$:&A66;*+(%-QD4V62842:0%Y)G'V@*1.RI!';82:
M!UJ\5@5D\)3K=Z5/&H'A<M*)>IDT?]Y^?U)99761?X^#C^M3EGKM8Z5CAG;X
M>5>(-I8J8JM2@H)4:'!G=V-K=^UZ`6W3?N.)T%D28LF%I8),=1]0RTZE=>N+
M2ES^74M[I&71D<I.)6U?B2=])I7%3BB,VX]SETMF@7G1C^QP>&T`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````F7V:?9M]G'V=?9Y]
MGWV@?:%]HGVC?:1]I7VG?:A]J7VJ?:M]K'VM?:]]L'VQ?;)]LWVT?;5]MGVW
M?;A]N7VZ?;M]O'V]?;Y]OWW`?<%]PGW#?<1]Q7W&?<=]R'W)?<I]RWW,?<U]
MSGW/?=!]T7W2?=-]U'W5?=9]UWW8?=E]``#:?=M]W'W=?=Y]WWW@?>%]XGWC
M?>1]Y7WF?>=]Z'WI?>I]ZWWL?>U][GWO??!]\7WR??-]]'WU??9]]WWX??E]
M^GT]7+)21H-B40Z#6W=V9KB<K$[*8+Y\LWS/?I5.9HMO9HB869>#6&QE7)6$
M7\EU5I??>MYZP%&O<)AZZF-V>J!^EG/MET5.>'!=3E*1J5-19>=E_($%@HY4
M,5R:=:"7V&+9<KUU15QYFLJ#0%R`5.EW/DZN;%J`TF)N8^A==U'=C1Z.+Y7Q
M3^53YV"L<&=24&-#GA]:)E`W=W=3XGZ%9"MEB6*88Q10-7+)B;-1P(O=?D=7
MS(.GE)M1&U3[7```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#[??Q]_7W^??]]`'X!?@)^`WX$?@5^!GX'?@A^"7X*?@M^#'X-?@Y^
M#WX0?A%^$GX3?A1^%7X6?A=^&'X9?AI^&WX<?AU^'GX??B!^(7XB?B-^)'XE
M?B9^)WXH?BE^*GXK?BQ^+7XN?B]^,'XQ?C)^,WXT?C5^-GXW?CA^.7X``#I^
M/'X]?CY^/WY`?D)^0WY$?D5^1GY(?DE^2GY+?DQ^37Y.?D]^4'Y1?E)^4WY4
M?E5^5GY7?EA^67Y:?EM^7'Y=?LI/XWI:;>&0CYJ`599485.O5`!?Z6-W:>]1
M:&$*4BI8V%).5PUX"W>W7G=AX'Q;8I=BHDZ5<`.`]V+D<&"7=U?;@N]G]6C5
M>)>8T7GS6+-4[U,T;DM1.U*B6_Z+KX!#5:97<V!15RU4>GI08%1;IV.@8N-3
M8V+'6Z]G[52?>N:"=Y&37N2(.%FN5PYCZ(WO@%=7=WNI3^M?O5L^:R%34'O"
M<D9H_W<V=_=EM5&/3M1VOURE>G6$3EE!FX!0````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````%Y^7WY@?F%^8GYC?F1^97YF?F=^:'YI
M?FI^:WYL?FU^;GYO?G!^<7YR?G-^='YU?G9^=WYX?GE^>GY[?GQ^?7Y^?G]^
M@'Z!?H-^A'Z%?H9^AWZ(?HE^BGZ+?HQ^C7Z.?H]^D'Z1?I)^DWZ4?I5^EGZ7
M?IA^F7Z:?IQ^G7Z>?@``KGZT?KM^O'[6?N1^['[Y?@I_$'\>?S=_.7\[?SQ_
M/7\^?S]_0']!?T-_1G]'?TA_27]*?TM_3']-?TY_3W]2?U-_B)DG88-N9%<&
M9D9C\%;L8FEBTUX4EH-7R6*'52&'2H&CCV95L8-E9U:-W81J6@]HYF+N>Q&6
M<%&<;S",_6/(B=)A!G_"<.5N!724:?QRRE[.D!=G:FU>8[-28G(!@&Q/Y5EJ
MD=EPG6W24E!.]Y9ME7Z%RG@O?2%1DE?"9(N`>WSJ;/%H7FFW49A3J&B!<LZ>
M\7OX<KMY$V\&=$YGS)&DG#QYB8-4@P]4%V@]3HE3L5(^>(93*5*(4(M/T$\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````5G]9?UM_
M7']=?UY_8']C?V1_97]F?V=_:W]L?VU_;W]P?W-_=7]V?W=_>']Z?WM_?']]
M?W]_@'^"?X-_A'^%?X9_AW^(?XE_BW^-?X]_D'^1?Y)_DW^5?Y9_EW^8?YE_
MFW^<?Z!_HG^C?Z5_IG^H?ZE_JG^K?ZQ_K7^N?[%_``"S?[1_M7^V?[=_NG^[
M?[Y_P'_"?\-_Q'_&?\=_R'_)?\M_S7_/?]!_T7_2?]-_UG_7?]E_VG_;?]Q_
MW7_>?^)_XW_B=<MZDGRE;+:6FU*#=.E4Z4]4@+*#WH]PE<E>'&"?;1A>6V4X
M@?Z42V"\<,-^KGS)48%HL7QO@B1.AH_/D7YFKDX%C*ED2H#:4)=USG'E6[V/
M9F^&3H)D8Y767IEE%U+"B,APHU(.<S-TEV?W>!:7-$Z[D-Z<RVW;44&-'53.
M8K)S\8/VEH2?PY0V3YI_S%%U<'66K5R&F.93Y$Z<;@ETM&EK>(^967484B1V
M06WS9VU1F9]+@)E4/'N_>@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#D?^=_Z'_J?^M_['_M?^]_\G_T?_5_]G_W?_A_^7_Z?_U_
M_G__?P*`!X`(@`F`"H`.@`^`$8`3@!J`&X`=@!Z`'X`A@".`)(`K@"R`+8`N
M@"^`,(`R@#2`.8`Z@#R`/H!`@$&`1(!%@$>`2(!)@$Z`3X!0@%&`4X!5@%:`
M5X```%F`6X!<@%V`7H!?@&"`88!B@&.`9(!E@&:`9X!H@&N`;(!M@&Z`;X!P
M@'*`<X!T@'6`=H!W@'B`>8!Z@'N`?(!]@(:6A%?B8D>6?&D$6@)DTWL/;TN6
MIH)B4X68D%Z)<+-C9%-/AH&<DYZ,>#*7[XU"C7^>7F^$>55?1I8N8G2:%53=
ME*-/Q65E7&%<%7]1AB]LBU^'<^1N_W[F7!MC:EOF;G53<4Z@8V5UH6)NCR9/
MT4ZF;+9^NHL=A+J'5W\[D".5J7NAFOB(/80;;8::W'Z(6;N>FW,!>(*&;)J"
MFAM6%U3+5W!.IIY64\B/"8&2=Y*9[H;A;A.%_&9B82MO````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'Z`@8""@(6`B("*@(V`CH"/
M@)"`D8"2@)2`E8"7@)F`GH"C@*:`IX"H@*R`L("S@+6`MH"X@+F`NX#%@,>`
MR(#)@,J`RX#/@-"`T8#2@-.`U(#5@-B`WX#@@.*`XX#F@.Z`]8#W@/F`^X#^
M@/^``($!@0.!!($%@0>!"($+@0``#($5@1>!&8$;@1R!'8$?@2"!(8$B@2.!
M)($E@2:!)X$H@2F!*H$K@2V!+H$P@3.!-($U@3>!.8$Z@3N!/($]@3^!*8R2
M@BN#\G83;-E?O8,K<P6#&I7;:]MWQI1O4P*#DE$]7HR,.(U(3JMSFF>%:':1
M"9=D<:%L"7>26D&5SVN.?R=FT%NY69I:Z)7WE>Q.#(29A*QJWW8PE1MSIFA?
M6R]WFI%AE]Q\]X\<C"5?<WS8><6)S&P<A\9;0E[):"!W]7Z544U1R5(I6@5_
M8I?7@L]CA'?0A=)Y.FZ97IE9$85M<!%LOV*_=D]EKV#]E0YFGX<CGNV4#51]
M5"R,>&0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M0(%!@4*!0X%$@46!1X%)@4V!3H%/@5*!5H%7@5B!6X%<@5V!7H%?@6&!8H%C
M@62!9H%H@6J!:X%L@6^!<H%S@76!=H%W@7B!@8&#@82!A8&&@8>!B8&+@8R!
MC8&.@9"!DH&3@92!E8&6@9>!F8&:@9Z!GX&@@:&!HH&D@:6!``"G@:F!JX&L
M@:V!KH&O@;"!L8&R@;2!M8&V@;>!N(&Y@;R!O8&^@;^!Q('%@<>!R(')@<N!
MS8'.@<^!T('1@=*!TX%Y9!&&(6J<@>AX:614F[EB*V>K@ZA8V)ZK;"!OWEM,
ME@N,7W+09\=B87*I3L99S6N36*YF55[?4E5A*&?N=F9W9W)&>O]BZE105*"4
MHY`<6K-^%FQ#3G99$(!(65=3-W6^ELI6(&,1@7Q@^976;6)4@9F%4>E:_8"N
M61.7*E#E;#Q<WV)@3S]3>X$&D+IN*X7(8G1>OGBU9'MC]5\86G^1'YX_7$]C
M0H!]6VY52I5-E85MJ&#@9]YRW5&!6P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#4@=6!UH'7@=B!V8':@=N!W('=@=Z!WX'@@>&!
MXH'D@>6!YH'H@>F!ZX'N@>^!\('Q@?*!]8'V@?>!^('Y@?J!_8'_@0."!X((
M@@F""H(+@@Z"#X(1@A."%8(6@A>"&((9@AJ"'8(@@B2")8(F@B>"*8(N@C*"
M.H(\@CV"/X(``$""08)"@D."18)&@DB"2H),@DV"3H)0@E&"4H)3@E2"58)6
M@E>"68);@ER"78)>@F""88)B@F."9()E@F:"9X)I@N=BWFQ;<FUBKI2]?A.!
M4VV<401?=%FJ4A)@<UF69E"&GW4J8^9A[WSZB^94)VLEGK1KU8555'90I&QJ
M5;2-+'(57A5@-G3-8I)C3'*87T-N/FT`95AOV';0>/QV5'4D4MM34TZ>7L%E
M*H#6@)MBAE0H4JYPC8C1C>%L>%3:@/E7](A4C6J639%I3YMLMU7&=C!XJ&+Y
M<(YO;5_LA-IH?'CW>ZB!"V=/GF=CL'AO5Q)X.9=Y8JMBB%(U=-=K````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````&J":X)L@FV"<8)U
M@G:"=X)X@GN"?(*`@H&"@X*%@H:"AX*)@HR"D(*3@I2"E8*6@IJ"FX*>@J""
MHH*C@J>"LH*U@K:"NH*[@KR"OX+`@L*"PX+%@L:"R8+0@M:"V8+:@MV"XH+G
M@NB"Z8+J@NR"[8+N@O""\H+S@O6"]H+X@@``^H+\@OV"_H+_@@"#"H,+@PV#
M$(,2@Q.#%H,8@QF#'8,>@Q^#((,A@R*#(X,D@R6#)H,I@RJ#+H,P@S*#-X,[
M@SV#9%4^@;)UKG8Y4]YU^U!!7&R+QWM/4$=REYK8F`)OXG1H>8=DI7?\8I&8
M*XW!5%B`4DYJ5_F"#81S7NU1]G3$BT]<85?\;(>81EHT>$2;ZX^5?%9246+Z
ME,9.AH-AA.F#LH345S1G`U=N9F9M,8S=9A%P'V<Z:Q9H&F*[60-.Q%$&;])G
MCVQV4<MH1UEG:V9U#ET0@5"?UV5(>4%YD9IWC8)<7DX!3R]445D,>&A6%&S$
MCP-??6SC;*N+D&,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/H,_@T&#0H-$@T6#2(-*@TN#3(--@TZ#4X-5@U:#5X-8@UF#78-B
M@W"#<8-R@W.#=(-U@W:#>8-Z@WZ#?X.`@X&#@H.#@X2#AX.(@XJ#BX.,@XV#
MCX.0@Y&#E(.5@Y:#EX.9@YJ#G8.?@Z&#HH.C@Z2#I8.F@Z>#K(.M@ZZ#``"O
M@[6#NX.^@[^#PH/#@\2#QH/(@\F#RX/-@\Z#T(/1@]*#TX/5@]>#V8/:@]N#
MWH/B@^.#Y(/F@^>#Z(/K@^R#[8-P8#UM=7)F8HZ4Q91#4\&/?GO?3B:,?D[4
MGK&4LY1-4EQO8Y!%;32,$5A,72!K26NJ9UM45(&,?YE8-X4Z7Z)B1VHYE7)E
MA&!E:*=W5$ZH3^==F)>L9-A_[5S/3XUZ!U($@Q1.+V"#>J:4M4^R3N9Y-'3D
M4KF"TF2]>=U;@6Q2EWN/(FP^4']3!6[.9'1F,&S%8'>8]XN&7CQT=WK+>1A.
ML9`#=$)LVE9+D<5LBXTZ4\:&\F:OCDA<<9H@;@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#N@^^#\X/T@_6#]H/W@_J#^X/\@_Z#
M_X,`A`*$!80'A`B$"80*A!"$$H03A!2$%806A!>$&80:A!N$'H0?A""$(80B
MA".$*80JA"N$+(0MA"Z$+X0PA#*$,X0TA#6$-H0WA#F$.H0[A#Z$/X1`A$&$
M0H1#A$2$181'A$B$280``$J$2X1,A$V$3H1/A%"$4H13A%2$5816A%B$781>
MA%^$8(1BA&2$981FA&>$:(1JA&Z$;X1PA'*$=(1WA'F$>X1\A-93-EJ+GZ.-
MNU,(5Z>80V>;D<EL:%'*=?-BK'(X4IU2.G^4<#AV=%-*GK=I;GC`EMF(I'\V
M<<-QB5'39^1TY%@89;=6J8MVF7!BU7[Y8.UP[%C!3KI.S5_GE_M.I(L#4HI9
MJWY48LU.Y64.8CB#R81C@XV'E'&V;KE;TGZ74<ECU&>)@#F#%8@247I;@EFQ
MCW-.76QE426);X\NEDJ%7G00E?"5IFWE@C%?DF02;2B$;H'#G%Y86XT)3L%3
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'V$?H1_
MA("$@82#A(2$A82&A(J$C82/A)"$D822A).$E(25A):$F(2:A)N$G82>A)^$
MH(2BA*.$I(2EA*:$IX2HA*F$JH2KA*R$K82NA+"$L82SA+6$MH2WA+N$O(2^
MA,"$PH3#A,6$QH3'A,B$RX3,A,Z$SX32A-2$U837A```V(39A-J$VX3<A-Z$
MX83BA.2$YX3HA.F$ZH3KA.V$[H3OA/&$\H3SA/2$]83VA/>$^(3YA/J$^X3]
MA/Z$`(4!A0*%'D]C95%HTU4G3A1DFIIK8L):7W1R@JEM[FCG4(Z#`GA`9SE2
MF6RQ?KM0955><5M[4F;*<^N"26=Q7"!2?7%KB.J559;%9&&-LX&$555L1V(N
M?Y)8)$]&54^-3&8*3AI<\XBB:$YC#7KG<(V"^E+VEQ%<Z%2UD,U^8EE*C<>&
M#((-@F:-1&0$7%%AB6T^>;Z+-W@S=7M4.$^KCO%M(%K%?EYYB&RA6W9:&G6^
M@$YA%V[P6!]U)75R<D=3\WX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````X4$A06%!H4'A0B%"84*A0N%#84.A0^%$(42A12%%846
MA1B%&84;A1R%'84>A2"%(H4CA22%)84FA2>%*(4IA2J%+84NA2^%,(4QA3*%
M,X4TA36%-H4^A3^%0(5!A4*%1(5%A4:%1X5+A4R%385.A4^%4(51A5*%4X54
MA56%``!7A5B%6H5;A5R%785?A6"%885BA6.%985FA6>%:85JA6N%;(5MA6Z%
M;X5PA7&%<X5UA7:%=X5XA7R%?85_A8"%@84!=]MV:5+<@"-7"%XQ6>YRO65_
M;M>+.%QQAD%3\W?^8O9EP$[?F("&GEO&B_)3XG=_3TY<=IK+60]?.GGK6!9.
M_V>+3NUBDXH=D+]2+V;<56Q6`I#53HU/RI%PF0]L`EY#8*1;QHG5BS9E2V*6
MF8A;_UN(8RY5UU,F=GU1+(6B9[-HBFN28I./U%,2@M%MCW5F3DZ-<%N?<:^%
MD6;99G)_`(?-GB"?7EPO9_"/$6A?9PUBUGJ%6+9><&4Q;P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````""A8.%AH6(A8F%BH6+A8R%
MC86.A9"%D862A9.%E(65A9:%EX68A9F%FH6=A9Z%GX6@A:&%HH6CA:6%IH6G
MA:F%JX6LA:V%L86RA;.%M(6UA;:%N(6ZA;N%O(6]A;Z%OX7`A<*%PX7$A<6%
MQH7'A<B%RH7+A<R%S87.A=&%TH4``-2%UH77A=B%V87:A=N%W87>A=^%X(7A
MA>*%XX7EA>:%YX7HA>J%ZX7LA>V%[H7OA?"%\87RA?.%](7UA?:%]X7XA55@
M-U(-@%1D<(@I=05>$VCT8AR7S%,]<@&,-&QA=PYZ+E2L=WJ8'(+TBU5X%&?!
M<*]EE60V5AU@P7GX4QU.>VN&@/I;XU7;5CI//$]RF?-=?F<X@`)@@I@!D(M;
MO(OUBQQD6(+>9/U5SX)ED==/('T?D)]\\U!16*]NOUO)BX.`>)&<A)=[?8:+
MEH^6Y7[3FHYX@5Q7>D*0IY9?>5E;7V,+>]&$K6@&52E_$'0B?0&50&),6-9.
M@UMY6518````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`/F%^H7\A?V%_H4`A@&&`H8#A@2&!H8'A@B&"88*A@N&#(8-A@Z&#X80AA*&
M$X84AA6&%X88AAF&&H8;AAR&'88>AA^&((8AAB*&(X8DAB6&)H8HABJ&*X8L
MABV&+H8OAC"&,88RAC.&-(8UAC:&-X8YACJ&.X8]ACZ&/X9`A@``089"AD.&
M1(9%AD:&1X9(ADF&2H9+ADR&4H93AE6&5H97AEB&689;AER&789?AF"&889C
MAF2&989FAF>&:(9IAFJ&;7,>8TN.#X[.@-2"K&+P4_!L7I$J60%@<&Q-5TID
M*HTK=NEN6U>`:O!U;6\MC`B,9E?O:Y*(LWBB8_E3K7!D;%A8*F0"6.!HFX$0
M5=9\&%"ZCLQMGXWK<(]CFVW4;N9^!(1#:`.0V&UVEJB+5UEY<N2%?H&\=8J*
MKVA44B*.$9708YB81(Y\55-/_V:/5M5@E6U#4DE<*5G[;6M8,'4<=6Q@%()&
M@1%C86?BCSIW\XTTC<&4%EZ%4RQ4PW``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````;89OAG"&<H9SAG2&=89VAG>&>(:#AH2&A8:&
MAH>&B(:)AHZ&CX:0AI&&DH:4AI:&EX:8AIF&FH:;AIZ&GX:@AJ&&HH:EAJ:&
MJX:MAJZ&LH:SAK>&N(:YAKN&O(:]AKZ&OX;!AL*&PX;%ALB&S(;-AM*&TX;5
MAM:&UX;:AMR&``#=AN"&X8;BAN.&Y8;FAN>&Z(;JANN&[(;OAO6&]H;WAOJ&
M^X;\AOV&_X8!AP2'!8<&APN'#(<.AP^'$(<1AQ2'%H=`;/=>7%"M3JU>.F-'
M@AJ04&AND;-W#%3<E&1?Y7IV:$5C4GO??MMU=U"58C19#Y#X4<-Y@7K^5I)?
M%)"";6!<'U<05%1136[B5JACDYA_@16'*HD`D!Y4;US`@=9B6&(Q@36>0)9N
MFGR:+6FE6=-B/E468\=4V88\;0-:YG2<B&IK%EE,C"]??FZI<WV8.$[W<(Q;
MEW@]8UIFEG;+8)M;25H'3E6!:FR+<Z%.B6=1?X!?^F4;9]A?A%D!6@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````9AQN''8<?AR"'
M)(<FAR>'*(<JARN'+(<MAR^',(<RAS.'-8<VASB'.8<ZASR'/8=`AT&'0H=#
MAT2'18=&ATJ'2X=-AT^'4(=1AU*'5(=5AU:'6(=:AUN'7(==AUZ'7X=AAV*'
M9H=GAVB':8=JAVN';(=MAV^'<8=RAW.'=8<``'>'>(=YAWJ'?X>`AX&'A(>&
MAX>'B8>*AXR'CH>/AY"'D8>2AY2'E8>6AYB'F8>:AYN'G(>=AYZ'H(>AAZ*'
MHX>DA\U=KE]Q4^:7W8]%:/16+U7?8#I.36_T?L>"#H3461]/*D\^7*Q^*F<:
MA7-43W7#@()53YM-3RUN$XP)7'!A:U,?=BENBH:'9?N5N7X[5#-Z"GWNE>%5
MP7_N=!UC%X>A;9UZ$6*A96=3X6.#;.M=7%2HE$Q.86SLBTM<X&6<@J=H/E0T
M5,MK9FN43D)C2%,>@@U/KD]>5PIB_I9D9FER_U*A4I]@[XL49IEQD&=_B5)X
M_7=P9CM6.%0AE7IR````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````*6'IH>GAZF'JH>NA["'L8>RA[2'MH>WA[B'N8>[A[R'OH>_A\&'
MPH?#A\2'Q8?'A\B'R8?,A\V'SH?/A]"'U(?5A]:'UX?8A]F'VH?<A]V'WH??
MA^&'XH?CA^2'YH?GA^B'Z8?KA^R'[8?OA_"'\8?RA_.'](?UA_:']X?XAP``
M^H?[A_R'_8?_AP"(`8@"B`2(!8@&B`>("(@)B`N(#(@-B`Z(#X@0B!&($H@4
MB!>(&(@9B!J('(@=B!Z('X@@B".(`'IO8`Q>B6"=@159W&"$<>]PJFY0;(!R
MA&JMB"U>8$ZS6IQ5XY07;?M\F98/8L9^CG=^AB-3'I>6CX=FX5R@3^UR"TZF
M4P]9$U2`8RB52%'93IR<I'ZX5"2-5(@W@O*5CFTF7\Q:/F9IEK!S+G._4WJ!
MA9FA?ZI;=Y90EK]^^':B4W:5F9FQ>T2)6&YA3M1_97GFB_-@S52K3GF8]UUA
M:L]0$51AC">$77@$ETI2[E2C5@"5B&VU6\9M4V8`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````)(@EB":()X@HB"F(*H@KB"R(+8@N
MB"^(,(@QB#.(-(@UB#:(-X@XB#J(.X@]B#Z(/XA!B$*(0XA&B$>(2(A)B$J(
M2XA.B$^(4(A1B%*(4XA5B%:(6(A:B%N(7(A=B%Z(7XA@B&:(9XAJB&V(;XAQ
MB'.(=(AUB':(>(AYB'J(``![B'R(@(B#B(:(AXB)B(J(C(B.B(^(D(B1B).(
ME(B5B)>(F(B9B)J(FXB=B)Z(GXB@B*&(HXBEB*:(IXBHB*F(JH@/7%U;(6B6
M@'A5$7M(951IFTY':TZ'BY=/4Q]C.F2JD)QEP8`0C)E1L&AX4_F'R&'$;/ML
M(HQ17*J%KX(,E2-KFX^P9?M?PU_A3T6('V9E@2ES^F!T41%2BU=B7Z*03(B2
MD7A>3V<G8--91%'V4?B`"%-Y;,26BG$13^Y/GG\]9\55")7`>9:(XWZ?6`QB
M`)=:AAA6>YB07[B+Q(17D=E3[66/7EQU9&!N?7]:ZG[M?FF/IU6C6ZQ@RV6$
M<P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"LB*Z(
MKXBPB+*(LXBTB+6(MHBXB+F(NHB[B+V(OHB_B,"(PXC$B,>(R(C*B,N(S(C-
MB,^(T(C1B-.(UHC7B-J(VXC<B-V(WHC@B.&(YHCGB.F(ZHCKB.R([8CNB.^(
M\HCUB/:(]XCZB/N(_8C_B`")`8D#B02)!8D&B0>)"(D```F)"XD,B0V)#HD/
MB1&)%(D5B1:)%XD8B1R)'8D>B1^)((DBB2.))(DFB2>)*(DIB2R)+8DNB2^)
M,8DRB3.)-8DWB0F08W8I=]I^=)>;A69;='KJED"(RU*/<:I?[&7BB_M;;YKA
M78EK6VRMBZ^+"I#%CXM3O&(FGBV>0%0K3KV"67*<AA9=68BO;<66T52:3K:+
M"7&]5`F6WW#Y;=!V)4X4>!*'J5SV7@"*G)@.EHYPOVQ$6:EC/'=-B!1O<X(P
M6-5QC%,:>,&6`55F7S!QM%L:C(R:@VLN62^>YWEH9VQB;T^A=8I_"VTSEB=L
M\$[2=7M1-V@^;X"0<(&6679T````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#B).8DZB3N)/(D]B3Z)/XE`B4*)0XE%B4:)1XE(B4F)
M2HE+B4R)38E.B4^)4(E1B5*)4XE4B56)5HE7B5B)68E:B5N)7(E=B6")88EB
MB6.)9(EEB6>):(EIB6J):XELB6V);HEOB7")<8ERB7.)=(EUB7:)=XEXB7F)
M>HE\B0``?8E^B8")@HF$B86)AXF(B8F)BHF+B8R)C8F.B8^)D(F1B9*)DXF4
MB96)EHF7B9B)F8F:B9N)G(F=B9Z)GXF@B:&)1V0G7&60D7HCC-I9K%0`@F^#
M@8D`@#!I3E8V@#=RSI&V45].=9B68QI.]E/S9DN!'%FR;0!.^5@[4]9C\92=
M3PI/8XB0F#=95Y#[>>I.\("1=8)LG%OH65U?!6F!AAI0\EU93N-WY4YZ@I%B
M$V:1D'E<OTYY7\:!.)"$@*MUID[4B`]AQ6O&7TE.RG:B;N.+KHL*C-&+`E_\
M?\Q_SGXU@VN#X%:W:_.7-);[61]4]I3K;<5;;IDY7!5?D)8`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````HHFCB:2)I8FFB:>)J(FI
MB:J)JXFLB:V)KHFOB;")L8FRB;.)M(FUB;:)MXFXB;F)NHF[B;R)O8F^B;^)
MP(G#B<V)TXG4B=6)UXG8B=F)VXG=B=^)X(GAB>*)Y(GGB>B)Z8GJB>R)[8GN
MB?")\8GRB?2)]8GVB?>)^(GYB?J)``#[B?R)_8G^B?^)`8H"B@.*!(H%B@:*
M"(H)B@J*"XH,B@V*#HH/BA"*$8H2BA.*%(H5BA:*%XH8BAF*&HH;BAR*'8IP
M4_&",6IT6G">E%XH?[F#)(0EA&>#1X?.CV*-R'9Q7Y:8;'@@9M]4Y6)C3\.!
MR'6X7LV6"H[YAH]4\VR,;3AL?V#'4BAU?5X83Z!@YU\D7#%UKI#`E+ERN6PX
M;DF1"6?+4_-344_)D?&+R%-\7L*/Y&V.3L)VAFE>AAIA!H)93]Y//I!\G`EA
M'6X4;H66B$XQ6NB6#DY_7+EYAUOMB[U_B7/?5XN"P9`!5$>0NU7J7*%?"&$R
M:_%RLH")B@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```>BA^*((HABB**(XHDBB6*)HHGBBB**8HJBBN*+(HMBBZ*+XHPBC&*,HHS
MBC2*-8HVBC>*.(HYBCJ*.XH\BCV*/XI`BD&*0HI#BD2*18I&BD>*28I*BDN*
M3(I-BDZ*3XI0BE&*4HI3BE2*58I6BE>*6(I9BEJ*6XI<BEV*7HH``%^*8(IA
MBF**8XIDBF6*9HIGBFB*:8IJBFN*;(IMBFZ*;XIPBG&*<HISBG2*=8IVBG>*
M>(IZBGN*?(I]BGZ*?XJ`BG1MTUO5B(28:XQMFC.>"FZD44-1HU>!B)]3]&.5
MC^U66%0&5S]SD&X8?]R/T8(_82A@8I;P9J9^BHW#C:64LURD?`AGIF`%EAB`
MD4[GD`!3:)9!4="/=(5=D55F]9=56QU3.'A"9SUHR51^<+!;?8^-42A7L502
M98)F7HU#C0^!;(1MD-]\_U'[A:-GZ66A;Z2&@8YJ5B"0@G9V<.5Q(XWI8AE2
M_6P\C0Y@GEB.8?YF8(U.8K-5(VXM9V>/````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(&*@HJ#BH2*A8J&BH>*B(J+BHR*C8J.BH^*
MD(J1BI**E(J5BI:*EXJ8BIF*FHJ;BIR*G8J>BI^*H(JABJ**HXJDBJ6*IHJG
MBJB*J8JJBJN*K(JMBJZ*KXJPBK&*LHJSBK2*M8JVBK>*N(JYBKJ*NXJ\BKV*
MOHJ_BL"*P8K"B@``PXK$BL6*QHK'BLB*R8K*BLN*S(K-BLZ*SXK0BM&*THK3
MBM2*U8K6BM>*V(K9BMJ*VXK<BMV*WHK?BN"*X8KBBN.*X93XE2AW!6BH:8M4
M34ZX<,B+6&2+985;A'HZ4.A;NW?A:WF*F'R^;,]VJ667CRU=55PXA@AH8%,8
M8MEZ6V[]?A]JX'IP7S-O(%^,8ZAM5F<(3A!>)HW73L"`-':<EMMB+69^8KQL
M=8UG<6E_1E&'@.Q3;I"88O)4\(:9CP6`%Y47A=F/66W-<Y]E'W<$=2=X^X$>
MC8B4ID^59[EURHL'ER]C1Y4UEKB$(V-!=X%?\'*)3A1@=&7O8F-K/V4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````Y(KEBN:*YXKH
MBNF*ZHKKBNR*[8KNBN^*\(KQBO**\XKTBO6*]HKWBOB*^8KZBON*_(K]BOZ*
M_XH`BP&+`HL#BP2+!8L&BPB+"8L*BPN+#(L-BPZ+#XL0BQ&+$HL3BQ2+%8L6
MBQ>+&(L9BQJ+&XL<BQV+'HL?BR"+(8LBBR.+```DBR6+)XLHBRF+*HLKBRR+
M+8LNBR^+,(LQBS*+,XLTBS6+-HLWBSB+.8LZBSN+/(L]BSZ+/XM`BT&+0HM#
MBT2+18LG7L=UT9#!BYV"G6<O93%4&(?E=Z*``H%!;$M.QWY,@/1V#6F6:V=B
M/%"$3T!7!V-B:[Z-ZE/H9;A^UU\:8[=C\X'T@6Y_'%[97#92>F;I>1IZ*(V9
M<-1UWFZ[;))Z+4[%=N!?GY1WB,A^S7F_@,V1\DX73Q^":%3>73)MS(NE?'2/
MF(`:7I)4L7:96SQFI)K@<RIHVX8Q9RIS^(O;BQ"0^7K;<&YQQ&*I=S%6.TY7
MA/%GJ5+`ABZ-^)11>P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!&BT>+2(M)BTJ+2XM,BTV+3HM/BU"+48M2BU.+5(M5BU:+5XM8
MBUF+6HM;BUR+78M>BU^+8(MABV*+8XMDBV6+9XMHBVF+:HMKBVV+;HMOBW"+
M<8MRBW.+=(MUBW:+=XMXBWF+>HM[BWR+?8M^BW^+@(N!BX*+@XN$BX6+AHL`
M`(>+B(N)BXJ+BXN,BXV+CHN/BY"+D8N2BY.+E(N5BY:+EXN8BYF+FHN;BYR+
MG8N>BY^+K(NQB[N+QXO0B^J+"8P>C$]/Z&Q=>7N:DV(J<OUB$TX6>&R/L&1:
MC<9[:6B$7L6(AEF>9.Y8MG(.:265_8]8C6!7`'\&C,9126/98E-33&@B=`&#
M3)%$54!W?'!*;7E1J%1$C?]9RV[$;5Q;*WW43GU\TVY06^J!#6Y76P.;U6@J
MCI=;_'X[8+5^N9!PC4]9S6/?>;.-4E//959YQ8L[EL1^NY2"?C16B9$`9VI_
M"EQUD"AFYEU03]YG6E!<3U!7IUX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#B,.8PZC#N,/(P]C#Z,/XQ`C$*,
M0XQ$C$6,2(Q*C$N,38Q.C$^,4(Q1C%*,4XQ4C%:,5XQ8C%F,6XQ<C%V,7HQ?
MC&",8XQDC&6,9HQGC&B,:8QLC&V,;HQOC'",<8QRC'2,=8QVC'>,>XQ\C'V,
M?HQ_C(",@8R#C(2,AHR'C```B(R+C(V,CHR/C)",D8R2C).,E8R6C)>,F8R:
MC)N,G(R=C)Z,GXR@C*&,HHRCC*2,I8RFC*>,J(RIC*J,JXRLC*V,C4X,3D!1
M$$[_7D53%4Z83AY.,IML6VE6*$ZZ>3].%5-'3BU9.W)N4Q!LWU;D@)>9TVM^
M=Q>?-DZ?3A"?7$YI3I-.B();6VQ5#U;$3HU3G5.C4Z53KE-EEUV-&E/U4R93
M+E,^4UR-9E-C4P)2"%(.4BU2,U(_4D!23%)>4F%27%*OA'U2@E*!4I!2DU*"
M451_NT[#3LE.PD[H3N%.ZT[>3AM/\TXB3V1/]4XE3R=/"4\K3UY/9T\X95I/
M74\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````KHRO
MC+",L8RRC+.,M(RUC+:,MXRXC+F,NHR[C+R,O8R^C+^,P(S!C,*,PXS$C,6,
MQHS'C,B,R8S*C,N,S(S-C,Z,SXS0C-&,THS3C-2,U8S6C->,V(S9C-J,VXS<
MC-V,WHS?C.",X8SBC..,Y(SEC.:,YXSHC.F,ZHSKC.R,``#MC.Z,[XSPC/&,
M\HSSC/2,]8SVC/>,^(SYC/J,^XS\C/V,_HS_C`"-`8T"C0.-!(T%C0:-!XT(
MC0F-"HT+C0R-#8U?3U=/,D\]3W9/=$^13XE/@T^/3WY/>T^J3WQ/K$^43^9/
MZ$_J3\5/VD_C3]Q/T4_?3_A/*5!,4/-/+%`/4"Y0+5#^3QQ0#%`E4"A0?E!#
M4%502%!.4&Q0>U"E4*=0J5"Z4-90!E'M4.Q0YE#N4`=1"U'=3CUL6$]E3\Y/
MH)]&;'1\;E']7<F>F)F!4119^5(-4P>*$%/K41E955&@3E91LTYNB*2(M4X4
M@=*(@'DT6P.(N'^K4;%1O5&\40``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````.C0^-$(T1C1*-$XT4C16-%HT7C1B-&8T:C1N-'(T@
MC5&-4HU7C5^-98UHC6F-:HULC6Z-;XUQC7*->(UYC7J->XU\C7V-?HU_C8"-
M@HV#C8:-AXV(C8F-C(V-C8Z-CXV0C9*-DXV5C9:-EXV8C9F-FHV;C9R-G8V>
MC:"-H8T``**-I(VEC::-IXVHC:F-JHVKC:R-K8VNC:^-L(VRC;:-MXVYC;N-
MO8W`C<&-PHW%C<>-R(W)C<J-S8W0C=*-TXW4C<=1EE&B4:51H(NFBZ>+JHNT
MB[6+MXO"B\.+RXO/B\Z+THO3B]2+UHO8B]F+W(O?B^"+Y(OHB^F+[HOPB_.+
M]HOYB_R+_XL`C`*,!(P'C`R,#XP1C!*,%(P5C!:,&8P;C!B,'8P?C"",(8PE
MC">,*HPKC"Z,+XPRC#.,-8PVC&E3>E,=EB*6(98QEBJ6/98\ED*62994EE^6
M9Y9LEG*6=):(EHV6EY:PEI>0FY"=D)F0K)"AD+20LY"VD+J0````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-6-V(W9C=R-X(WAC>*-
MY8WFC>>-Z8WMC>Z-\(WQC?*-](WVC?R-_HW_C0".`8X"C@..!(X&C@>."(X+
MC@V.#HX0CA&.$HX3CA6.%HX7CAB.&8X:CAN.'(X@CB&.)(XECB:.)XXHCBN.
M+8XPCC*.,XXTCC:.-XXXCCN./(X^C@``/XY#CD6.1HY,CDV.3HY/CE".4XY4
MCE6.5HY7CEB.6HY;CER.78Y>CE^.8(YACF*.8XYDCF6.9XYHCFJ.:XYNCG&.
MN)"PD,^0Q9"^D-"0Q)#'D-.0YI#BD-R0UY#;D.N0[Y#^D`21(I$>D2.1,9$O
MD3F10Y%&D0U20EFB4JQ2K5*^4O]4T%+64O!2WU/N<<UW]%[U4?Q1+YNV4P%?
M6G7O74Q7J5>A5WY8O%C%6-%8*5<L5RI7,U<Y5RY7+U=<5SM70E=I5X57:U>&
M5WQ7>U=H5VU7=E=S5ZU7I%>,5[)7SU>G5[17DU>@5]57V%?:5]E7TE>X5_17
M[U?X5^17W5<`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````<XYUCG>.>(YYCGJ.>XY]CGZ.@(Z"CH..A(Z&CHB.B8Z*CHN.C(Z-CHZ.
MD8Z2CI..E8Z6CI>.F(Z9CIJ.FXZ=CI^.H(ZACJ*.HXZDCJ6.IHZGCJB.J8ZJ
MCJV.KHZPCK&.LXZTCK6.MHZWCKB.N8Z[CKR.O8Z^CK^.P([!CL*.``##CL2.
MQ8[&CL>.R([)CLJ.RX[,CLV.SX[0CM&.TH[3CM2.U8[6CM>.V([9CMJ.VX[<
MCMV.WH[?CN".X8[BCN..Y(X+6`U8_5?M5P!8'E@96$18(%AE6&Q8@5B)6)I8
M@%BHF1F?_V%Y@GV"?X*/@HJ"J(*$@HZ"D8*7@IF"JX*X@KZ"L(+(@LJ"XX*8
M@K>"KH++@LR"P8*I@K2"H8*J@I^"Q(+.@J2"X8()@_>"Y((/@P>#W(+T@M*"
MV((,@_N"TX(1@QJ#!H,4@Q6#X(+5@AR#48-;@UR#"(.2@SR#-(,Q@YN#7H,O
M@T^#1X-#@U^#0(,7@V"#+8,Z@S.#9H-E@P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#ECN:.YX[HCNF.ZH[KCNR.[8[NCN^.\([Q
MCO*.\X[TCO6.]H[WCOB.^8[ZCON._([]COZ._XX`CP&/`H\#CP2/!8\&CP>/
M"(\)CPJ/"X\,CPV/#H\/CQ"/$8\2CQ./%(\5CQ:/%X\8CQF/&H\;CQR/'8\>
MCQ^/((\ACR*/(X\``"2/)8\FCR>/*(\ICRJ/*X\LCRV/+H\OCS"/,8\RCS./
M-(\UCS:/-X\XCSF/.H\[CSR//8\^CS^/0(]!CT*/0X]$CVB#&X-I@VR#:H-M
M@VZ#L(-X@[.#M(.@@ZJ#DX.<@X6#?(.V@ZF#?8.X@WN#F(.>@ZB#NH.\@\&#
M`83E@]B#!U@8A`N$W8/]@]:#'(0XA!&$!H34@]^##X0#A/B#^8/J@\6#P(,F
MA/"#X8-<A%&$6H19A'.$AX2(A'J$B81XA#R$1H1IA':$C(2.A#&$;83!A,V$
MT(3FA+V$TX3*A+^$NH3@A*&$N82TA)>$Y83CA`R%#74XA?"$.84?A3J%````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$6/1H]'CTB/
M28]*CTN/3(]-CTZ/3X]0CU&/4H]3CU2/58]6CU>/6(]9CUJ/6X]<CUV/7H]?
MCV"/88]BCV./9(]ECVJ/@(^,CY*/G8^@CZ&/HH^DCZ6/IH^GCZJ/K(^MCZZ/
MKX^RC[./M(^UC[>/N(^ZC[N/O(^_C\"/PX_&CP``R8_*C\N/S(_-C\^/TH_6
MC]>/VH_@C^&/XX_GC^R/[X_QC_*/](_UC_:/^H_[C_R/_H__CP>0")`,D`Z0
M$Y`5D!B05H4[A?^$_(19A4B%:(5DA5Z%>H6B=T.%<H5[A:2%J(6'A8^%>86N
MA9R%A86YA;>%L(73A<&%W(7_A2>&!88IAA:&/(;^7@A?/%E!63>`55E:65A9
M#U,B7"5<+%PT7$QB:F*?8KMBRF+:8M=B[F(B8_9B.6-+8T-CK6/V8W%C>F..
M8[1C;6.L8XIC:6.N8[QC\F/X8^!C_V/$8]YCSF-29,9COF-%9$%D"V0;9"!D
M#&0F9"%D7F2$9&UDEF0`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````&9`<D".0))`ED">0*)`ID"J0*Y`LD#"0,9`RD#.0-)`WD#F0
M.I`]D#^00)!#D$601I!(D$F02I!+D$R03I!4D%605I!9D%J07)!=D%Z07Y!@
MD&&09)!FD&>0:9!JD&N0;)!OD'"0<9!RD'.0=I!WD'B0>9!ZD'N0?)!^D(&0
M``"$D(60AI"'D(F0BI",D(V0CI"/D)"0DI"4D):0F)":D)R0GI"?D*"0I)"E
MD*>0J)"ID*N0K9"RD+>0O)"]D+^0P)!Z9+=DN&299+IDP&309-=DY&3B9`EE
M)64N90M?TE\9=1%?7U/Q4_U3Z5/H4_M3$E065`942U125%-45%165$-4(517
M5%E4(U0R5()4E%1W5'%49%2:5)M4A%1V5&94G5305*U4PE2T5-)4IU2F5--4
MU%1R5*-4U52[5+]4S%395-I4W%2I5*I4I%3=5,]4WE0;5>=4(%7]5!15\U0B
M52-5#U4152=5*E5G58]5M55)56U5055553]54%4\50``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#"D,.0QI#(D,F0RY#,D,V0TI#4
MD-60UI#8D-F0VI#>D-^0X)#CD.20Y9#ID.J0[)#ND/"0\9#RD/.0]9#VD/>0
M^9#ZD/N0_)#_D`"1`9$#D061!I$'D0B1"9$*D0N1#)$-D0Z1#Y$0D1&1$I$3
MD121%9$6D1>1&)$:D1N1')$``!V1'Y$@D2&1))$ED2:1)Y$HD2F1*I$KD2R1
M+9$ND3"1,I$SD321-9$VD3>1.)$ZD3N1/)$]D3Z1/Y%`D4&10I%$D3=55E5U
M5795=U4S53!57%6+5=)5@U6Q5;E5B%6!59]5?E7659%5>U7?5;U5OE6459E5
MZE7W5<E5'U;15>M5[%745>95W57$5>]5Y57R5?-5S%7-5>A5]57D592/'E8(
M5@Q6`58D5B-6_E4`5B=6+5985CE65U8L5DU68E995EQ63%945H969%9Q5FM6
M>U9\5H56DU:O5M16UU;=5N%6]5;K5OE6_U8$5PI7"5<<5P]>&5X47A%>,5X[
M7CQ>````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$61
M1Y%(D5&14Y%4D5615I%8D5F16Y%<D5^18)%FD6>1:)%KD6V1<Y%ZD7N1?)&`
MD8&1@I&#D821AI&(D8J1CI&/D9.1E)&5D9:1EY&8D9F1G)&=D9Z1GY&@D:&1
MI)&ED::1IY&HD:F1JY&LD;"1L9&RD;.1MI&WD;B1N9&[D0``O)&]D;Z1OY'`
MD<&1PI'#D<21Q9'&D<B1RY'0D=*1TY'4D=61UI'7D=B1V9':D=N1W9'>D=^1
MX)'AD>*1XY'DD>61-UY$7E1>6UY>7F%>C%QZ7(U<D%R67(A<F%R97)%<FER<
M7+5<HER]7*Q<JURQ7*-<P5RW7,1<TESD7,M<Y5P"70-=)UTF72Y=)%T>709=
M&UU873Y=-%T]76Q=6UUO75U=:UU+74I=:5UT78)=F5V=77.,MUW%77-?=U^"
M7X=?B5^,7Y5?F5^<7ZA?K5^U7[Q?8HAA7ZURL'*T<K=RN'+#<L%RSG+-<M)R
MZ'+O<NER\G+T<O=R`7/S<@-S^G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````YI'GD>B1Z9'JD>N1[)'MD>Z1[Y'PD?&1\I'SD?21
M]9'VD?>1^)'YD?J1^Y'\D?V1_I'_D0"2`9("D@.2!)(%D@:2!Y((D@F2"I(+
MD@R2#9(.D@^2$)(1DA*2$Y(4DA62%I(7DAB2&9(:DAN2')(=DAZ2'Y(@DB&2
M(I(CDB22```EDB:2)Y(HDBF2*I(KDBR2+9(NDB^2,)(QDC*2,Y(TDC62-I(W
MDCB2.9(ZDCN2/)(]DCZ2/Y)`DD&20I)#DD2219+[<A=S$W,A<PIS'G,=<Q5S
M(G,Y<R5S+',X<S%S4'--<U=S8'-L<V]S?G,;@B59YY@D60)98YEGF6B9:9EJ
MF6N9;)ETF7>9?9F`F829AYF*F8V9D)F1F9.9E)F5F8!>D5Z+7I9>I5Z@7KE>
MM5Z^7K->4XW27M%>VU[H7NI>NH'$7\E?UE_/7P-@[E\$8.%?Y%_^7P5@!F#J
M7^U?^%\98#5@)F`;8`]@#6`I8"M@"F`_8"%@>&!Y8'M@>F!"8```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!&DD>22)))DDJ22Y),
MDDV23I)/DE"249)2DE.25))5DE:25Y)8DEF26I);DER279)>DE^28))ADF*2
M8Y)DDF629I)GDFB2:9)JDFN2;))MDFZ2;Y)PDG&2<I)SDG62=I)WDGB2>9)Z
MDGN2?))]DGZ2?Y*`DH&2@I*#DH22A9(``(:2AY*(DHF2BI*+DHR2C9*/DI"2
MD9*2DI.2E)*5DI:2EY*8DIF2FI*;DIR2G9*>DI^2H)*ADJ*2HY*DDJ62II*G
MDFI@?6"68)I@K6"=8(-@DF",8)M@[&"[8+%@W6#88,9@VF"T8"!A)F$582-A
M]&``80YA*V%*875AK&&48:=AMV'48?5AW5^SENF5ZY7QE?.5]97VE?R5_I4#
ME@26!I8(E@J6"Y8,E@V6#Y82EA66%I87EAF6&I8L3C]R%6(U;%1L7&Q*;*-L
MA6R0;)1LC&QH;&EL=&QV;(9LJ6S0;-1LK6SW;/AL\6S7;+)LX&S6;/ILZVSN
M;+%LTVSO;/YL````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````*B2J9*JDJN2K)*MDJ^2L)*QDK*2LY*TDK62MI*WDKB2N9*ZDKN2O)*]
MDKZ2OY+`DL&2PI+#DL22Q9+&DL>2R9+*DLN2S)+-DLZ2SY+0DM&2TI+3DM22
MU9+6DM>2V)+9DMJ2VY+<DMV2WI+?DN"2X9+BDN.2Y)+EDN:2YY+HD@``Z9+J
MDNN2[)+MDNZ2[Y+PDO&2\I+SDO22]9+VDO>2^)+YDOJ2^Y+\DOV2_I+_D@"3
M`9,"DP.3!),%DP:3!Y,(DPF3.6TG;0QM0VU(;0=M!&T9;0YM*VU-;2YM-6T:
M;4]M4FU4;3-MD6UO;9YMH&U>;9-ME&U<;6!M?&UC;1INQVW%;=YM#FZ_;>!M
M$6[F;=UMV6T6;JMM#&ZN;2MN;FY.;FMNLFY?;H9N4VY4;C)N)6Y$;M]NL6Z8
M;N!N+6_B;J5NIVZ];KMNMV[7;K1NSVZ/;L)NGVYB;T9O1V\D;Q5O^6XO;S9O
M2V]T;RIO"6\I;XEOC6^,;WAO<F]\;WIOT6\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````"I,+DPR3#9,.DP^3$),1DQ*3$Y,4DQ63
M%I,7DQB3&9,:DQN3'),=DQZ3'Y,@DR&3(I,CDR23)9,FDR>3*),IDRJ3*Y,L
MDRV3+I,ODS"3,9,RDS.3-),UDS:3-Y,XDSF3.I,[DSR3/9,_DT"309-"DT.3
M1)-%DT:31Y-(DTF3``!*DTN33)--DTZ33Y-0DU&34I-3DU2359-6DU>36)-9
MDUJ36Y-<DUV37I-?DV"389-BDV.39)-EDV:39Y-HDVF3:Y/);Z=ON6^V;\)O
MX6_N;]YOX&_O;QIP(W`;<#EP-7!/<%YP@%N$6Y5;DUNE6[A;+W6>FC1DY%ON
M6S")\%M'C@>+MH_3C]6/Y8_NC^2/Z8_FC_./Z(\%D`20"Y`FD!&0#9`6D"&0
M-9`VD"V0+Y!$D%&04I!0D&B06)!BD%N0N69TD'V0@I"(D(.0BY!07U=?5E]8
M7SM<JU107%E<<5MC7&9<O'\J7RE?+5]T@CQ?.YMN7(%9@UF-6:E9JEFC60``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!LDVV3;I-O
MDW"3<9-RDW.3=)-UDW:3=Y-XDWF3>I-[DWR3?9-^DW^3@).!DX*3@Y.$DX63
MAI.'DXB3B9.*DXN3C).-DXZ3D).1DY*3DY.4DY63EI.7DYB3F9.:DYN3G).=
MDYZ3GY.@DZ&3HI.CDZ23I9.FDZ>3J).IDZJ3JY,``*R3K9.NDZ^3L).QD[*3
MLY.TD[63MI.WD[B3N9.ZD[N3O).]D[Z3OY/`D\&3PI/#D\23Q9/&D\>3R)/)
MD\N3S)/-DY=9REFK69Y9I%G26;)9KUG76;Y9!5H&6MU9"%KC6=A9^5D,6@E:
M,EHT6A%:(UH36D!:9UI*6E5:/%IB6G5:[("J6IM:=UIZ6KY:ZUJR6M):U%JX
M6N!:XUKQ6M9:YEK86MQ:"5L76Q9;,ELW6T!;%5P<7%I;95MS6U%;4UMB6W6:
M=YIXFGJ:?YI]FH":@9J%FHB:BIJ0FI*:DYJ6FIB:FYJ<FIV:GYJ@FJ*:HYJE
MFJ>:GWZA?J-^I7ZH?JE^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````,Z3SY/0D]&3TI/3D]23U9/7D]B3V9/:D]N3W)/=D]Z3WY/@
MD^&3XI/CD^23Y9/FD^>3Z)/ID^J3ZY/LD^V3[I/OD_"3\9/RD_.3])/UD_:3
M]Y/XD_F3^I/[D_R3_9/^D_^3`)0!E`*4`Y0$E`64!I0'E`B4"90*E`N4#)0-
ME```#I0/E!"4$902E!.4%)05E!:4%Y08E!F4&I0;E!R4'90>E!^4()0AE"*4
M(Y0DE"64)I0GE"B4*90JE"N4+)0ME"Z4K7ZP?KY^P'[!?L)^R7[+?LQ^T'[4
M?M=^VW[@?N%^Z'[K?NY^[W[Q?O)^#7_V?OI^^W[^?@%_`G\#?P=_"'\+?PQ_
M#W\1?Q)_%W\9?QQ_&W\??R%_(G\C?R1_)7\F?R=_*G\K?RQ_+7\O?S!_,7\R
M?S-_-7]Z7G]UVUT^=960CG.1<ZYSHG.?<\]SPG/1<[=SLW/`<\ESR'/E<]ES
M?)@*=.ESYW/><[IS\G,/="IT6W0F="5T*'0P="YT+'0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+Y0PE#&4,I0SE#24-90VE#>4
M.)0YE#J4.Y0\E#V4/Y1`E$&40I1#E$24191&E$>42)1)E$J42Y1,E$V43I1/
ME%"44912E%.45)15E%:45Y18E%F46I1;E%R4791>E%^48)1AE&*48Y1DE&64
M9I1GE&B4:91JE&R4;91NE&^4``!PE'&4<I1SE'24=91VE'>4>)1YE'J4>Y1\
ME'V4?I1_E("4@92"E(.4A)21E):4F)3'E,^4TY34E-J4YI3[E!R5()4;=!IT
M071<=%=T5719='=T;71^=)QTCG2`=(%TAW2+=)YTJ'2I=)!TIW32=+ITZI?K
ME^R73&=39UYG2&=I9Z5GAV=J9W-GF&>G9W5GJ&>>9ZUGBV=W9WQG\&<):-AG
M"FCI9[!G#&C99[5GVF>S9]UG`&C#9[AGXF<.:,%G_6<R:#-H8&AA:$YH8FA$
M:&1H@V@=:%5H9FA!:&=H0&@^:$IH26@I:+5HCVAT:'=HDVAK:,)H;FG\:!]I
M(&GY:```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````G
ME3.5/95#E4B52Y55E5J58)5NE725=95WE7B5>95ZE7N5?)5]E7Z5@)6!E8*5
M@Y6$E865AI6'E8B5B96*E8N5C)6-E8Z5CY60E9&5DI63E925E966E9>5F)69
ME9J5FY6<E9V5GI6?E:"5H96BE:.5I)6EE::5IY6HE:F5JI4``*N5K)6ME:Z5
MKY6PE;&5LI6SE;25M96VE;>5N)6YE;J5NY6\E;V5OI6_E<"5P97"E<.5Q)7%
ME<:5QY7(E<F5RI7+E21I\&@+:0%I5VGC:!!I<6DY:6!I0FE=:81I:VF`:9AI
M>&DT:<QIAVF(:<YIB6EF:6-I>6F;::=INVFK::UIU&FQ:<%IRFG?:95IX&F-
M:?]I+VKM:1=J&&IE:O)I1&H^:J!J4&I;:C5JCFIY:CUJ*&I8:GQJD6J0:JEJ
MEVJK:C=S4G.!:X)KAVN$:Y)KDVN-:YIKFVNA:ZIK:X]MCW&/<H]SCW6/=H]X
MCW>/>8]ZCWR/?H^!CX*/A(^'CXN/````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````,R5S97.E<^5T)71E=*5TY74E=65UI77E=B5V97:
ME=N5W)7=E=Z5WY7@E>&5XI7CE>25Y97FE>>5[)7_E0>6$Y88EAN6'I8@EB.6
M))8EEB:6)Y8HEBF6*Y8LEBV6+Y8PEC>6.)8YECJ6/I9!ED.62I9.ED^64992
MEE.65I97E@``6)99EEJ67)9=EEZ68)9CEF669I9KEFV6;I9OEG"6<99SEGB6
M>99ZEGN6?)9]EGZ6?Y:`EH&6@I:#EH26AY:)EHJ6C8^.CX^/F(^:C\Z."V(7
M8AMB'V(B8B%B)6(D8BQBYX'O=/1T_W0/=1%U$W4T9>YE[V7P90IF&69R9P-F
M%68`9H5P]V8=9C1F,68V9C5F!H!?9E1F069/9E9F86979G=FA&:,9J=FG6:^
M9MMFW&;F9NEF,HTSC3:-.XT]C4"-18U&C4B-28U'C4V-58U9C<>)RHG+B<R)
MSHG/B=")T8EN<I]R77)F<F]R?G)_<H1RBW*-<H]RDG((8S)CL&,`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````C):.EI&6DI:3EI66
MEI::EIN6G9:>EI^6H):AEJ*6HY:DEJ66II:HEJF6JI:KEJR6K9:NEJ^6L9:R
MEK26M9:WEKB6NI:[EK^6PI;#ELB6RI;+EM"6T9;3EM26UI;7EMB6V9;:EMN6
MW);=EMZ6WY;AEN*6XY;DEN66YI;GENN6``#LENV6[I;PEO&6\I;TEO66^);Z
MEON6_);]EO^6`I<#EP67"I<+EPR7$)<1EQ*7%)<5EQ>7&)<9EQJ7&Y<=EQ^7
M()<_9-AD!(#J:_-K_6OU:_EK!6P';`9L#6P5;!AL&6P:;"%L*6PD;"IL,FPU
M955E:V5-<E)R5G(P<F*&%E*?@)R`DX"\@`IGO8"Q@*N`K8"T@+>`YX#H@.F`
MZH#;@,*`Q(#9@,V`UX`09]V`ZX#Q@/2`[8`-@0Z!\H#\@!5G$H%:C#:!'H$L
M@1B!,H%(@4R!4X%T@5F!6H%Q@6"!:8%\@7V!;8%G@4U8M5J(@8*!D8'5;J.!
MJH',@29GRH&[@0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````AER*7(Y<DER67)I<GERB7*9<KERR7+I<OES&7,Y<TES67-I<WESJ7
M.Y<\ESV7/Y=`ET&70I=#ET2719=&ET>72)=)ETJ72Y=,ETV73I=/EU"749=4
MEU675Y=8EUJ77)==EU^78Y=DEV:79Y=HEVJ7:Y=LEVV7;I=OEW"7<9<``'*7
M=9=WEWB7>9=ZEWN7?9=^EW^7@)>!EX*7@Y>$EX:7AY>(EXF7BI>,EXZ7CY>0
MEY.7E9>6EY>7F9>:EYN7G)>=E\&!IH$D:S=K.6M#:T9K66O1F-*8TYC5F-F8
MVIBS:T!?PFOSB9!E49^39;QEQF7$9<-ES&7.9=)EUF6`<)QPEG"=<+MPP'"W
M<*MPL7#H<,IP$'$3<19Q+W$Q<7-Q7'%H<45Q<G%*<7AQ>G&8<;-QM7&H<:!Q
MX''4<>=Q^7$=<BAR;'`8<69QN7$^8CUB0V)(8DEB.WE`>49Y27E;>5QY4WE:
M>6)Y5WE@>6]Y9WEZ>85YBGF:>:=YLWG17]!?````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````)Z7GY>AEZ*7I)>EEZ:7IY>HEZF7JI>L
MEZZ7L)>QE[.7M9>VE[>7N)>YE[J7NY>\E[V7OI>_E\"7P9?"E\.7Q)?%E\:7
MQY?(E\F7RI?+E\R7S9?.E\^7T)?1E]*7TY?4E]67UI?7E]B7V9?:E]N7W)?=
ME]Z7WY?@E^&7XI?CEP``Y)?EE^B7[I?OE_"7\9?RE_27]Y?XE_F7^I?[E_R7
M_9?^E_^7`)@!F`*8`Y@$F`68!I@'F`B8"9@*F`N8#)@-F`Z8/&!=8%I@9V!!
M8%E@8V"K8`9A#6%=8:EAG6'+8=%A!F*`@'^`DVSV;/QM]G?X=P!X"7@7>!AX
M$7BK92UX''@=>#EX.G@[>!]X/'@E>"QX(W@I>$YX;7A6>%=X)GA0>$=X3'AJ
M>)MXDWB:>(=XG'BA>*-XLGBY>*5XU'C9>,EX['CR>`5Y]'@3>21Y'GDT>9N?
M^9[[GOR>\78$=PUW^78'=PAW&G<B=QEW+7<F=S5W.'=0=U%W1W=#=UIW:'<`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````#Y@0F!&8
M$I@3F!28%9@6F!>8&)@9F!J8&Y@<F!V8'I@?F""8(9@BF".8))@EF":8)Y@H
MF"F8*I@KF"R8+9@NF"^8,)@QF#*8,Y@TF#68-I@WF#B8.9@ZF#N8/)@]F#Z8
M/YA`F$&80IA#F$2819A&F$>82)A)F$J82YA,F$V8``!.F$^84)A1F%*84YA4
MF%685IA7F%B869A:F%N87)A=F%Z87YA@F&&88IACF&2899AFF&>8:)AIF&J8
M:YALF&V8;IAB=V5W?W>-=WUW@'>,=Y%WGW>@=[!WM7>]=SIU0'5.=4MU2'5;
M=7)U>76#=5A_87]??TB*:']T?W%_>7^!?WY_S7;E=C*(A92&E(>4BY2*E(R4
MC92/E)"4E)27E)64FI2;E)R4HY2DE*N4JI2ME*R4KY2PE+*4M)2VE+>4N)2Y
ME+J4O)2]E+^4Q)3(E,F4RI3+E,R4S93.E-"4T932E-64UI37E-F4V)3;E-Z4
MWY3@E.*4Y)3EE.>4Z)3JE```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!OF'"8<9ARF'.8=)B+F(Z8DIB5F)F8HYBHF*F8JIBKF*R8
MK9BNF*^8L)BQF+*8LYBTF+68MIBWF+B8N9BZF+N8O)B]F+Z8OYC`F,&8PIC#
MF,28Q9C&F,>8R)C)F,J8RYC,F,V8SYC0F-28UIC7F-N8W)C=F."8X9CBF..8
MY)@``.68YICIF.J8ZYCLF.V8[ICOF/"8\9CRF/.8])CUF/:8]YCXF/F8^IC[
MF/R8_9C^F/^8`)D!F0*9`YD$F069!ID'F>F4ZY3NE.^4\Y3TE/64]Y3YE/R4
M_93_E`.5`I4&E0>5"94*E0V5#I4/E1*5$Y44E165%I48E1N5'94>E1^5(I4J
ME2N5*94LE3&5,I4TE3:5-Y4XE3R5/I4_E4*5-95$E4651I5)E4R53I5/E5*5
M4Y54E5:55Y58E5F56Y5>E5^5795AE6*59)5EE6:59Y5HE6F5:I5KE6R5;Y5Q
ME7*5<Y4ZE>=W['?)EM5Y[7GC>>MY!GI'70-Z`GH>>A1Z````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````B9"9D*F0N9#)D.F0^9$9D2
MF1.9%)D5F1:9%YD8F1F9&ID;F1R9'9D>F1^9()DAF2*9(YDDF269)IDGF2B9
M*9DJF2N9+)DMF2^9,)DQF3*9,YDTF369-IDWF3B9.9DZF3N9/)D]F3Z9/YE`
MF4&90IE#F42919E&F4>92)E)F0``2IE+F4R939E.F4^94)E1F5*94YE6F5>9
M6)E9F5J96YE<F5V97IE?F6"989EBF6299IESF7B9>9E[F7Z9@IF#F8F9.7HW
M>E%ZSYZEF7!ZB':.=I-VF7:D=MYTX'0L=2">(IXHGBF>*IXKGBR>,IXQGC:>
M.)XWGCF>.IX^GD&>0IY$GD:>1YY(GDF>2YY,GDZ>49Y5GE>>6IY;GER>7IYC
MGF:>9YYHGFF>:IYKGFR><9YMGG.>DG64=99UH'6==:QUHW6S=;1UN'7$=;%U
ML'7#=<)UUG7-=>-UZ'7F=>1UZW7G=0-V\77\=?]U$'8`=@5V#'87=@IV)788
M=A5V&78`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MC)F.F9J9FYF<F9V9GIF?F:"9H9FBF:.9I)FFF:>9J9FJF:N9K)FMF:Z9KYFP
MF;&9LIFSF;29M9FVF;>9N)FYF;J9NYF\F;V9OIF_F<"9P9G"F<.9Q)G%F<:9
MQYG(F<F9RIG+F<R9S9G.F<^9T)G1F=*9TYG4F=69UIG7F=B9``#9F=J9VYG<
MF=V9WIG?F>"9X9GBF>.9Y)GEF>:9YYGHF>F9ZIGKF>R9[9GNF>^9\)GQF?*9
M\YGTF?69]IGWF?B9^9D;=CQV(G8@=D!V+78P=C]V-79#=CYV,W9-=EYV5'9<
M=E9V:W9O=LI_YGIX>GEZ@'J&>HAZE7JF>J!ZK'JH>JUZLWIDB&F(<HA]B'^(
M@HBBB,:(MXB\B,F(XHC.B..(Y8CQB!J)_(CHB/Z(\(@AB1F)$XD;B0J)-(DK
MB3:)08EFB7N)BW7E@+)VM';<=Q*`%(`6@!R`((`B@"6`)H`G@"F`*(`Q@`N`
M-8!#@$:`38!2@&F`<8"#B7B8@)B#F```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#ZF?N9_)G]F?Z9_YD`F@&:`IH#F@2:!9H&F@>:
M")H)F@J:"YH,F@V:#IH/FA":$9H2FA.:%)H5FA::%YH8FAF:&IH;FAR:'9H>
MFA^:()HAFB*:(YHDFB6:)IHGFBB:*9HJFBN:+)HMFBZ:+YHPFC&:,IHSFC2:
M-9HVFC>:.)H``#F:.IH[FCR:/9H^FC^:0)I!FD*:0YI$FD6:1II'FDB:29I*
MFDN:3)I-FDZ:3YI0FE&:4II3FE2:59I6FE>:6)I9FHF8C)B-F(^8E)B:F)N8
MGIB?F*&8HIBEF*:83894AFR&;H9_AGJ&?(9[AJB&C8:+AJR&G8:GAJ.&JH:3
MAJF&MH;$AK6&SH:PAKJ&L8:OALF&SX:TANF&\8;RANV&\X;0AA.'WH;TAM^&
MV(;1A@.'!X?XA@B'"H<-APF'(X<[AQZ')8<NAQJ'/H=(AS2',8<IAS>'/X>"
MAR*'?8=^AWN'8(=PATR';H>+AU.'8X=\AV2'68=EAY.'KX>HA]*'````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````%J:6YI<FEV:7II?
MFF":89IBFF.:9)IEFF::9YIHFFF::IIKFG*:@YJ)FHV:CIJ4FI6:F9JFFJF:
MJIJKFJR:K9JNFJ^:LIJSFK2:M9JYFKN:O9J^FK^:PYK$FL::QYK(FLF:RIK-
MFLZ:SYK0FM*:U)K5FM::UYK9FMJ:VYK<F@``W9K>FN":XIKCFN2:Y9KGFNB:
MZ9KJFNR:[IKPFO&:\IKSFO2:]9KVFO>:^)KZFOR:_9K^FO^:`)L!FP*;!)L%
MFP:;QH>(AX6'K8>7AX.'JX?EAZR'M8>SA\N'TX>]A]&'P(?*A]N'ZH?@A^Z'
M%H@3B/Z'"H@;B"&(.8@\B#9_0G]$?T5_$(+Z>OUZ"'L#>P1[%7L*>RM[#WM'
M>SA[*GL9>RY[,7L@>R5[)'LS>SY['GM8>UI[17MU>TQ[77M@>VY[>WMB>W)[
M<7N0>Z9[IWNX>ZQ[G7NH>X5[JGN<>Z)[JWNT>]%[P7O,>]U[VGOE>^9[ZGL,
M?/Y[_'L/?!9\"WP`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````!YL)FPJ;"YL,FPV;#IL0FQ&;$IL4FQ6;%IL7FQB;&9L:FQN;')L=
MFQZ;()LAFR*;))LEFR:;)YLHFRF;*ILKFRR;+9LNFS";,9LSFS2;-9LVFS>;
M.)LYFSJ;/9L^FS^;0)M&FTJ;2YM,FTZ;4)M2FU.;59M6FU>;6)M9FUJ;``!;
MFUR;79M>FU^;8)MAFV*;8YMDFV6;9IMGFVB;:9MJFVN;;)MMFVZ;;YMPFW&;
M<IMSFW2;=9MVFW>;>)MYFWJ;>YL??"I\)GPX?$%\0'S^@0&"`H($@NR!1(@A
M@B*"(X(M@B^"*((K@CB".X(S@C2"/H)$@DF"2X)/@EJ"7X)H@GZ(A8B(B-B(
MWXA>B9U_GW^G?Z]_L'^R?WQ\2661?)U\G'R>?*)\LGR\?+U\P7S'?,Q\S7S(
M?,5\UWSH?&Z"J&:_?\Y_U7_E?^%_YG_I?^Y_\W_X?'=]IGVN?4=^FWZXGK2>
M<XV$C92-D8VQC6>-;8U'C$F,2I%0D4Z13Y%DD0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!\FWV;?IM_FX";@9N"FX.;A)N%FX:;
MAYN(FXF;BIN+FXR;C9N.FX^;D)N1FY*;DYN4FY6;EIN7FYB;F9N:FYN;G)N=
MFYZ;GYN@FZ&;HINCFZ2;I9NFFZ>;J)NIFZJ;JYNLFZV;KINOF[";L9NRF[.;
MM)NUF[:;MYNXF[F;NIL``+N;O)N]F[Z;OYO`F\&;PIO#F\2;Q9O&F\>;R)O)
MF\J;RYO,F\V;SIO/F]";T9O2F].;U)O5F]:;UYO8F]F;VIO;FV*189%PD6F1
M;Y%]D7Z1<I%TD7F1C)&%D9"1C9&1D:*1HY&JD:V1KI&OD;61M)&ZD56,?IZX
MC>N-!8Y9CFF.M8V_C;R-NHW$C=:-UXW:C=Z-SHW/C=N-QHWLC?>-^(WCC?F-
M^XWDC0F._8T4CAV.'XXLCBZ.(XXOCCJ.0(XYCC6./8XQCDF.08Y"CE&.4HY*
MCG".=HY\CF^.=(Z%CH^.E(Z0CIR.GHYXC(*,BHR%C)B,E(R;9=:)WHG:B=R)
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-R;W9O>
MF]^;X)OAF^*;XYODF^6;YIOGF^B;Z9OJF^N;[)OMF^Z;[YOPF_&;\IOSF_2;
M]9OVF_>;^)OYF_J;^YO\F_V;_IO_FP"<`9P"G`.<!)P%G`:<!YP(G`F<"IP+
MG`R<#9P.G`^<$)P1G!*<$YP4G!6<%IP7G!B<&9P:G```&YP<G!V<'IP?G""<
M(9PBG".<))PEG":<)YPHG"F<*IPKG"R<+9PNG"^<,)PQG#*<,YPTG#6<-IPW
MG#B<.9PZG#N<Y8GKB>^)/HHFBU.7Z9;SEN^6!I<!EPB7#Y<.ERJ7+9<PESZ7
M@)^#GX6?AI^'GXB?B9^*GXR?_IX+GPV?N9:\EKV6SI;2EK]WX):.DJZ2R)(^
MDVJ3RI./DSZ4:Y1_G(*<A9R&G(><B)PC>HN<CIR0G)&<DIR4G)6<FIR;G)Z<
MGYR@G*&<HIRCG*6<IIRGG*B<J9RKG*V<KIRPG+&<LIRSG+2<M9RVG+><NIR[
MG+R<O9S$G,6<QIS'G,J<RYP`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/)P]G#Z</YQ`G$&<0IQ#G$2<19Q&G$><2)Q)G$J<2YQ,
MG$V<3IQ/G%"<49Q2G%.<5)Q5G%:<5YQ8G%F<6IQ;G%R<79Q>G%^<8)QAG&*<
M8YQDG&6<9IQGG&B<:9QJG&N<;)QMG&Z<;YQPG'&<<IQSG'2<=9QVG'><>)QY
MG'J<``![G'V<?IR`G(.<A)R)G(J<C)R/G).<EIR7G)B<F9R=G*J<K)ROG+F<
MOIR_G,"<P9S"G,B<R9S1G-*<VIS;G."<X9S,G,V<SIS/G-"<TYS4G-6<UYS8
MG-F<W)S=G-^<XIQ\EX67D9>2EY27KY>KEZ.7LI>TE[&:L)JWFEB>MIJZFKR:
MP9K`FL6:PIK+FLR:T9I%FT.;1YM)FTB;39M1F^B8#9DNF5695)G?FN&:YIKO
MFNN:^YKMFOF:")L/FQ.;'YLCF[V>OIX[?H*>AYZ(GHN>DI[6DYV>GY[;GMR>
MW9[@GM^>XI[IGN>>Y9[JGN^>(I\LGR^?.9\WGSV?/I]$GP``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#CG.2<Y9SFG.><Z)SIG.J<
MZYSLG.V<[ISOG/"<\9SRG/.<])SUG/:<]YSXG/F<^IS[G/R<_9S^G/^<`)T!
MG0*=`YT$G06=!IT'G0B="9T*G0N=#)T-G0Z=#YT0G1&=$IT3G12=%9T6G1>=
M&)T9G1J=&YT<G1V='IT?G2"=(9T``"*=(YTDG26=)ITGG2B=*9TJG2N=+)TM
MG2Z=+YTPG3&=,ITSG32=-9TVG3>=.)TYG3J=.YT\G3V=/IT_G4"=09U"G0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$.=1)U%G4:=1YU(G4F=2IU+G4R=39U.G4^=4)U1G5*=4YU4G56=5IU7G5B=
M69U:G5N=7)U=G5Z=7YU@G6&=8IUCG62=99UFG6>=:)UIG6J=:YULG6V=;IUO
MG7"=<9URG7.==)UUG7:==YUXG7F=>IU[G7R=?9U^G7^=@)V!G0``@IV#G82=
MA9V&G8>=B)V)G8J=BYV,G8V=CIV/G9"=D9V2G9.=E)V5G9:=EYV8G9F=FIV;
MG9R=G9V>G9^=H)VAG:*=````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````HYVDG:6=IIVGG:B=J9VJG:N=K)VMG:Z=KYVP
MG;&=LIVSG;2=M9VVG;>=N)VYG;J=NYV\G;V=OIV_G<"=P9W"G<.=Q)W%G<:=
MQYW(G<F=RIW+G<R=S9W.G<^=T)W1G=*=TYW4G=6=UIW7G=B=V9W:G=N=W)W=
MG=Z=WYW@G>&=``#BG>.=Y)WEG>:=YYWHG>F=ZIWKG>R=[9WNG>^=\)WQG?*=
M\YWTG?6=]IWWG?B=^9WZG?N=_)W]G?Z=_YT`G@&>`IX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````#G@2>!9X&G@>>
M")X)G@J>"YX,G@V>#IX/GA">$9X2GA.>%)X5GA:>%YX8GAF>&IX;GAR>'9X>
MGB2>)YXNGC">-)X[GCR>0)Y-GE">4IY3GE2>5IY9GEV>7YY@GF&>8IYEGFZ>
M;YYRGG2>=9YVGG>>>)YYGGJ>>YY\GGV>@)X``(&>@YZ$GH6>AIZ)GHJ>C)Z-
MGHZ>CYZ0GI&>E)Z5GI:>EYZ8GIF>FIZ;GIR>GIZ@GJ&>HIZCGJ2>I9ZGGJB>
MJ9ZJG@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````*N>K)ZMGJZ>KYZPGK&>LIZSGK6>MIZWGKF>NIZ\GK^>P)[!GL*>
MPY[%GL:>QY[(GLJ>RY[,GM">TI[3GM6>UI[7GMF>VI[>GN&>XY[DGN:>Z)[K
MGNR>[9[NGO">\9[RGO.>])[UGO:>]Y[XGOJ>_9[_G@"?`9\"GP.?!)\%GP``
M!I\'GPB?"9\*GPR?#Y\1GQ*?%)\5GQ:?&)\:GQN?')\=GQZ?'Y\AGR.?))\E
MGR:?)Y\HGRF?*I\KGRV?+I\PGS&?````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````,I\SGS2?-9\VGSB?.I\\GS^?0)]!
MGT*?0Y]%GT:?1Y](GTF?2I]+GTR?39].GT^?4I]3GU2?59]6GU>?6)]9GUJ?
M6Y]<GUV?7I]?GV"?89]BGV.?9)]EGV:?9Y]HGVF?:I]KGVR?;9]NGV^?<)]Q
MGW*?<Y]TGW6?=I]WGWB?``!YGWJ?>Y]\GWV??I^!GX*?C9^.GX^?D)^1GY*?
MDY^4GY6?EI^7GYB?G)^=GYZ?H9^BGZ.?I)^EGRSY>?F5^>?Y\?D`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````,^@WZ
M#OH/^A'Z$_H4^ACZ'_H@^B'Z(_HD^B?Z*/HI^E@``````````````!$```!2
MOA@(5[X8"/2;&`@`````H+L@"*"Z(`B@N2`(````````````````````````
M``````````````$````!`````@``````_P`@N2`(@"HE"`````#(XP<(#.0'
M"'!<"`BX7`@(8.L'"(""!P@HZP<(6.H'"!#I!PA$=`<(9'0'"(1T!PBH=`<(
MS'4'"'Q]!PA,?@<(-(('"%!V!PC0=P<(*'D'"%1[!P@T?0<(](4'",R!!P@`
M``````````````````````````````````````$"`P0%!@<("0H+#`T.#Q`1
M$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^
M/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8$%"0T1%1D=(24I+
M3$U.3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8
MF9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%
MQL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R
M\_3U]O?X^?K[_/W^_P`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?
M("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`86)C9&5F9VAI:FML
M;6YO<'%R<W1U=G=X>7I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY
M>GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6F
MIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3
MU-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O\`
M("`@("`@("`@*"@H*"@@("`@("`@("`@("`@("`@("!($!`0$!`0$!`0$!`0
M$!`0A(2$A(2$A(2$A!`0$!`0$!"!@8&!@8$!`0$!`0$!`0$!`0$!`0$!`0$!
M`1`0$!`0$(*"@H*"@@("`@("`@("`@("`@("`@("`@("$!`0$"`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$```````````````````````
M```````````````````````-``````````````!A````4KX8"&"^&`CTFQ@(
M`````*"[(`B@NB`(H+D@"&"](`@````````````````````````````````!
M`````0````(``````/\`(+D@"""](`@`````,.0'"&3E!P@`YP<(M.<'",A8
M"`C,=`<(8%T(".AU!P@```````````````````````````````````````$"
M`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO
M,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<
M75Y?8$%"0T1%1D=(24I+3$U.3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)
MBHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6V
MM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+C
MY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_TF!``"4@9"!DX&5@0``:8%J
M@9:!>X%#@0``1(%>@4^"4()1@E*"4X)4@E6"5H)7@EB"1H%'@8.!@8&$@4B!
MEX%@@F&"8H)C@F2"98)F@F>":()I@FJ":X)L@FV";H)O@G""<8)R@G."=()U
M@G:"=X)X@GF";8$``&Z!3X%1@4V!@8*"@H."A(*%@H:"AX*(@HF"BH*+@HR"
MC8*.@H^"D(*1@I*"DX*4@I6"EH*7@IB"F8*:@F^!8H%P@0```````*$`H@"C
M`*0`I0"F`*<`J`"I`*H`JP"L`*T`K@"O`+``L0"R`+,`M`"U`+8`MP"X`+D`
MN@"[`+P`O0"^`+\`P`#!`,(`PP#$`,4`Q@#'`,@`R0#*`,L`S`#-`,X`SP#0
M`-$`T@#3`-0`U0#6`-<`V`#9`-H`VP#<`-T`W@#?````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````4($``(^!````````````
M`````````````````+>2`````````````````````.66``!XZ$V1````````
M>>@``,*5>NA*B@```````%N)``#5B@``U(I[Z```?.@``'WH?N@`````````
M``````"`Z```UHITBGV-M)0``(+H@>@``````````(/H``````````![B0``
M`````````````(;H``"%Z(3H``"'Z```````````BN@```````#%B`````"(
MZ```C.B+Z````````````````([HC>B/Z```K),```````"0Z```````````
MD>B3Z`````"2Z```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(R5``````````"4Z```````
M`````````)7H``#CC0```````);HE^@`````:)8`````````````````````
M:I$```````"BB,F1``"8Z```C94```````````````";Z)GH?HT``)KHP(P`
M`````````````````````````,.5G>B?Z)[HH.@`````0(EWD)R/UXJAZ```
M`````(:4``"CZ````````$&)``"BZ,*2``#+EZF3G.BDEP``KXP`````>I<`
M`````````````````/>+LI<``$>,``#@D4#D``"DZ$N*CY```````````'6*
MIN@``*?HI>B$C```VXWACP```````$*)`````->7````````J>BLYP``J.@`
M````````````K.BJZ*OH``"MZ```KNCJEZ_HL.@``,>0N90```````"=D.6*
M`````%F7ZXE7C]F,``"SZ```LNB3CK3HL>@`````1XX```````"XZ*OE````
M`-29``"7D+;H`````````````*.7[Y,``````````$J)``#AD+2.````````
M``"UE0``7XD```````#KEXN7``"YZ```9),``````````/F.````````NN@`
M`+OH:Y"\Z```[)<`````M^B^Z,#H``"_Z```O>@`````P>@`````PN@`````
MFI$``.")`````````````,/H`````+:6`````,3H`````````````,7H``!)
MF`````````````!0GL;H````````Q^C(Z````````,SH``#)Z```RN@``,OH
MS>@`````````````````````PI````````#UE@````##D`````#.Z```\90`
M`,_H<NK*E@``T.@``-'H``#2Z':*``#4Z```>)````````#5Z`````!#C```
M````````UNC:Z```V.@``````````-GH`````).*U^C;Z```````````W.@`
M`,:(``#=Z-[H``````````````````#BCP```````-_H````````9HL`````
MXN@`````X>@``.#H`````)'F``#:E0````````````#CZ.3H````````````
M`````````````````````````.7H`````.;H``#GZ`````#HZ```````````
M````````V(H`````````````````````Z>@`````````````````````````
M`````````````````.KH0I0```````#LZ+F)``#OZ.[H``````````!#B0``
M`````+^+``#%E;B2H(T``("-AX\``'N0````````\>@`````\.AAE^:*T)3:
MDP```````)R0S)<``'J,````````````````].@`````\^@`````````````
M`````&J6JI,```````````````!OB0````#UZ/+H`````'"5BI?VZ```````
M``````````````#WZ```````````^>CHD7J*>XKXZ```````````YXJPC```
M``#HB@````!>DP````#>EP````````````````````#:C````````/KH````
M````^^C\Z$#I``!"Z4'I````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````EY4``$/I``````````!$Z0``
M1>D``````````$;I````````````````````````````````2.E'Z0``2>D`
M````````````````````````````````````````````````````\I3*XP``
M``!(D`````!1BP```````````````$KI``!+Z0``JIE:G]&4`````/F(``"Y
MB```````````````````E(Y/EOR/``````````!,Z0``W98```````!-Z7N7
M``!AB0```````&".``!.Z>R)3^D```````!0Z0``````````4NE3Z0``5>E1
MZ0````!4Z0```````-F*````````5ND``%?I````````````````````````
M`````````````%CI6>D```````!:Z0````!<Z0```````%OI``!>Z6'I````
M````7>E?Z6#I`````&+I``#`BP``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#QCF/I9.F!C0````````````````````````````!EZ0````!=
MB@```````&Z49NEGZ0``````````>9+IDP``````````````````:.D`````
M`````)V4`````,J1=XGLBP``[8L``````````````````).2;>GNBP````#M
MB0````!LZ0````!JZ0``:^D``&GI`````'?I````````````````````````
M``!NZ6_I`````'#I<>D`````````````<^D`````<ND```````!XCP``=.D`
M``````!VZ0````````````````````!2BW7I`````)N1L8P`````````````
M>.D`````````````````````````````````````RY$`````>>D`````````
M`*N3````````````````>ND```````````````"`Z0``?>D``'SI?ND``'OI
M``````````````````""Z0``````````````````@>D``(3I`````,&+@^D`
M``````"%Z0````"&Z0``B.F'Z0```````(GIB^F*Z0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````)R-``````````",Z0````"-Z0``````````````
M````6XH```````".Z0```````(_I````````D9``````````````````````
M`````)#I``"1Z0``DNF3Z0```````(*-`````````````)3IE>D`````ENF7
MZ0````"8Z0```````*^4FND``$65F^F9Z0``G>D`````G.D`````GND`````
M``"?Z0``````````````````````````H.D`````````````````````````
M````````````````````H>D``*+I``````````"CZ0````"DZ:7I``"FZ0``
MI^FHZ:GIJND```````"KZ:SI``!4GZWI`````````````````````/;B4XL`
M`````````$"*L(VOZ:[IHY8``````````````````+'ILNFPZ0``L^D`````
M@I8```````"TZ0``FXL`````````````````````````````````````````
M````````````1)@``````````+7I````````````````````````````````
M`````+?I``````````````````````````"\B`````"XZ:F5MND`````N>FZ
MZ0``````````````````N^F\Z0``````````````````O>D``(Z63(X``/B-
M3I$`````````````OND``````````,'I````````````````O^D`````````
M````PND`````[XS`Z0``````````P^D``,3IQ>D``,GI``!)C@``````````
MXI$`````````````RNG'Z<;IR.D```````!^C```````````````````SNG-
MZ<SI`````+&(`````````````````````````````````````-CI``#4Z0``
MU>G1Z=?I``#3Z8**`````&N8``#6Z=+IT.G/Z0````````````#:Z0``````
M``````#=Z0````#<Z=OI``````````````````!HE=GI\8C>Z0``X.D`````
M``````````"/BLOI5HD`````XND``````````````````.'IW^E,D@``````
M`````````````````)"6``````````#8EP````#CZ0````````````#DZ0``
M`````````````.7I`````````````````````````````````````.;I``#G
MZ0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````+F2``#HZ0``
MM90``.WIZ>D```````#JZ0````!0EL*6``#.DP``````````````````````
M`````````.[I`````._IO)/LZ>OI``````````"HB0```````/?I`````/;I
M`````````````)6)````````].D```````#SZ0````#QZ0``FXH``/#IL(ZG
MB0````````````````````````````````````"#C0````#ZZ?GI``#XZ0``
M``#UZ0``^^D``/SI``````````````````!$ZD/J``````````````````!%
MZ@````!,B4#J0>H``)2-MY8`````0NH``````````````````%&6`````$KJ
M`````$;J``````````````````!+Z@``````````````````````````````
M`$CJ``!'Z@````````````![C```````````````````````````3.H`````
M``````````````````!-Z@``````````3NH``$GJ````````\ND`````3^H`
M`-^2````````4^H``%3J4NH`````````````4>I7Z@``4.H``%7J````````
M`````````````%;J````````6>H`````````````6.H`````````````````
M``````````````!;Z@```````````````%SJ``!=Z@````!HF```````````
M``!:ZNF1ZXT`````7NH`````````````````````````````````````````
M`````````````````````````````````%_J8.H`````8>H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````8NH`````LHQCZ@```````&3J
M``"MC@``9>H```````````````!FZ@````!GZFCJ``````````!KZFGJ6Y@`
M`&KJ``#MEP````````````!LZ@``V9<`````````````;>J>E`````!NZG#J
M`````''J``````````````````````````!OZHV-RY:#EO6;``"`GYN6````
M``````"IB0``````````````````<^IOBW3J=>IVZ@``E8T``'?J````````
MTN#9E@``X9%XZGKJ>>H``'OJ``````````!\Z@````!]Z@``````````````
M`'[J``````````"`Z@``@>J"Z@``@^H``(3JA>J&Z@``````````````````
M`````(?JB.H`````````````0Y,``````````-N,``"*Z@``````````````
M````````````;)&+Z@``````````````````````````C.H`````````````
M````````````````````````0)4`````C>H`````````````````````````
M````CNI6X@````#8YNOH`````(_J``"0Z@``````````````````````````
MDNJ3ZI3J[I>1Z@````"5ZI;J`````)CJ``"7Z@````````````":Z@``````
M`)OJF>H`````````````````````````````````````````````````````
M``"TEP``````````````````G.H```````````````"=ZG/B`````)[J````
M````````````ZHB:D@``M8X```````"<EN2/3X[CC[J)``!SE5Z7``"@F$Z)
M`````(Z*H9BBD,"9=8NXE0``````````Y8\`````O)<``````````,"5````
M````HI@`````AI(```````"CF/B+````````I)@``-N*3Y(``.6.I9@`````
MII@`````IYA4E```=HL`````````````5I0``.&3P8Q2E@````````````!H
MY:B8YH^IF+.)````````XXONC.>6`````*2;````````````````````````
M`````````````)"7``#[DP``````````````````````````HXH``%2+``"J
MF`````"KF+F7``!<EXB1K9B6CO&3``"PF`````!=B=V,``#<C.2(`````&J8
M:9@``+&-GX@``+&8LIBSF%.6M)@``/",Y8B2E@``G(L`````G8N>B^"2NI<`
M`+68`````+:8`````+>8````````;)``````````````68]MD+R8``"ZF```
MNYAWBP````"AC>Z)``"YF+B8IY4``````````&6.9(Z\D;V8=)7ED```````
M`%>!OIC`F````````..1WY?(B```````````````````OYB\B0``PHL``(>2
M````````CXS!F````````$.4`````````````.F*``````````````````#"
MF,F(`````-Z,ZHJ:E;"4>(L`````````````````````[XD``.688),`````
M````````````````````````````````````````C)3$F````````+J4``#@
MEP``3)```&:.``"7CKZ)`````````````,^2`````$&2R)@`````````````
MRHCADEJ/LHU#EP``S)$``+V)``#'F```79?#F,68[(W&F$.;````````````
M``````````````#.F`````````````#1F,^8`````,")``"YE<F8````````
M``#-F/&,`````&>.````````I(H`````TI@``,J8`````.&7``"8C@``RY@`
M`-"8``````````#3F```S)@`````GXL``,N(`````*"+OXD`````````````
M``````````!$FP``F9:.E?*,`````````````$Z0M9<`````````````````
M````UI4`````5XRCD>*)`````````````'*/````````UY@``-R8VI@`````
MU9@`````K9'8F```VYC9F```VY4``-:8``!-D```DY;=F-Z8````````````
M`````````$./ZY@```````!OE```597FF```[I4``+2)````````ZI@`````
M``````````#DF.V8`````'&1``#"C```>Y0``,7@``#LF'R3``#AF```](P`
M````\XS?F```````````V(X``.>8``#ME6R2XYB1C```X)CHF.*8SY?IF&"8
M`````````````````````.2+`````)",````````````````````````[I@`
M``````#OF/.8S(@`````````````SI7RF```````````\9CUF````````/28
M``#BD@````````````````````"2C````````````````/:8````````````
M`,..``"DD>.2](L``/>8``````````!5BP````#XF```````````^I@`````
M`````````````%26````````AHP```````````````!0CO64^9@`````````
M````````````````````````````````````PXUBEP``````````_)A"F?N8
MPHT``)V/````````````````6(P```````!#F0````#-BP```````$"909D`
M````K9,``)R1``"ABP```````&R61)D```````"[EP```````$69````````
M``!(F0``1ID``&V1`````````````$>929D```````````````!+F0``````
M`$J9``#&E0``````````5HM-F4Z9``"MB0``````````3)D`````````````
M````````\HX``%&94)E/F0``U)@``%*9``````````">CP``4YD`````````
M````````````1)<``````````````````->6``````````!5F0````!4F5>9
M5ID`````6)E9F?*(``"SC%J,6X^;DJ*+YI#UC```CHU;F<:699,``)F.``!:
MF0``7)D`````````````?9,``)6*`````````````%V9`````/R3`````%.1
M7YE@F:J4]HQ:F&&9`````*2+````````NI6TD>^+5),```````"3C```````
M`&*9``!CF0````#@DWZ)`````&:9^XT``&69Q(T``&>9[.-HF6"6:9D``&J9
M:YGGCP``RHX```````````````"EB@``;ID``&R9NY9MF0``>95OF7"9<9E^
MDP```````'69<YETF7*9X8UVF>B6XI<`````````````=YD`````````````
M``"FD'B9>8\`````>9D``)R2O9>`DP````````````````````##F0``````
M````>IFCZL.+`````'N9?98``````````(B/^I$``'V9XI,`````?ID`````
M@)E-B@```````(&9I8L``,J3FHEOCP````"?E(*9``"!DP````!ND(.9``"J
ME=B0H(H``*>*A)D`````AID`````68P`````A9D`````\9<`````````````
MB8\```````````````"[E,J5``"'F0``F)>(F0```````(F9``">DP````"*
MF0````"GD/R-E(R+F6B.CXT``````````````````.22C9D`````I9$`````
M[8V.F8^93Y$``(R9``````````"1F0``598``````````(2-`````)"9````
M``````"5C-R-C90```````"4F9*9``````````";E>B/FYF$BI69DYEND0``
M````````````````EYD``):9````````8XH```````"`C)R9JY<```````"8
MF0```````)V9FID``)F9````````````````S9<```````#WC,&)`````/*7
M`````````````)6/=Y.%C:"9H9D```````#CEP````!*F*.9````````^(P`
M````HID``$Z*`````*29``!UE@``NI(``$67``#7E0```````*69````````
M``#3Z`````"NDP``IIFHBK&6````````GX^GF>65JYD``*B0J)G.BP``J9FI
MB@``````````````````````````38RLF0``K9D`````KIFOF=F.````````
M^8S<E@``YI;UDP````#OE;"9``"QF0``````````LYD``+69M)D`````````
M`+:9NXEKE@``^HVWF0````!XD0````"@CZ>+``"XF0```````````````-F4
M``````````"YF0``NID``+N9``````````"\F4.5YHOCB````````+V3O9E<
MCP``YY```+^9OIFAC]^,P9F\E`````#"F0```````-J4LI'LD::+`````.R3
M4)(``(Z4``!ME@``Q)D``.B0`````````````%2,`````,69``````````#&
MF4N)\XCKB@``II%PBY&7``#)F;6)`````,B9````````J(L`````RID``.^6
M`````````````````````````````````````````````,N9``#0EP``^HP`
M`````````+2,S)D``````````,Z9S9D``'Z06(D```````!]B<^9``#0F0``
M``"UC`````#1F0``````````CHL```````````````!1CM*9``````````"4
MEK.->8M&EV^1O93[C@````````````!FCP``YH[SC@``EH\``+Z4````````
MU9D``&*)<)'[C,.,Y8L`````V9E`DOR1J8NBC]J9V)G"B>21MHYJCD6)````
M`)"*AHUIC@``VYD```````````````#<F0``:(MEB@```````(>-9XO=DD2)
MKY.\ED"-F9=FD_R,````````````````````````3HP``.69``#ABVF6````
M`````````-N4`````.29``#<BM^9X)GBF0``````````````````XYD``'J+
M@9```*N5X9G=F>&,``#>F0``0Y@```````#PE0``YI+@C)"-````````YID`
M````VY,``````````````````````````````````.J9````````````````
M`````/R.``#TC@````````````#MF>N9``"AE@``Z)GQF>R9````````[YG$
MC+V6`````/"9````````\ID``/29``````````#NC6&8``#IF>>9\YD``.Z9
M````````````````````````````````````````]ID``$*:^)D`````_)D`
M````0)KYF0````!=F@````#GC5"*``````````#WF0```````$2:](A#F@``
MHXAIE4&:``#ZF0````#UF?N9QHT`````````````````````````````````
M````19H`````````````````````]8A.F@````!&FD>:``"CCXF6````````
M3)I+F@```````$Z3``````````````````!-F@````!*F@``````````````
M`%.)``"TC4^0``````````````````!(FH*3````````29H``*"(````````
M`````````````````````````````````````````````````````%.:0I<`
M`*6/``!9F@``````````6)I/F@``````````P9$``%":````````[9%5FJ2/
M`````````````%*:`````.*6````````6XP`````5II7F@``````````5)I:
MF@````````````!1F@``````````````````````````````````````````
M``````````````````!@FF6:``!AF@``7)H`````9II0D0````!HF@``08U>
MFIV2````````````````````````````````8II;FJN*``#LBH6*8YI?F@``
M````````````````EHQIFF>:<I%IBZJ+``!DF@``\HL`````````````8XD`
M`````````````````````````````````&V::YH``*6:````````````````
M````````````````<)H`````````````:IH``&Z:`````&R:````````:XYO
MF@```````````````````````````````````````````````'*:``!WF@``
M`````'6:=)H``````````````````%&2`````,.)````````````````````
M``````!QF@``<YJFCU*)`````'::````````````````````````````````
M``#<B0````````````""F@``^H]]F@``>YH``'R:``!^F@``````````````
M`````````%R)````````````````````````6)$``'B:``!YF@``````````
M````````````````FHH`````````````````````@9H```````#MB@``A)J`
MFH.:``````````````````"LE0```````-.3``"VE`````````````"&F@``
M``````````"%FF2*`````(>:``````````"*F@``````````B9H`````````
M````````````````````B)H``%B4`````(N:`````````````````````(R:
M`````````````(Z:``"-F@````````````"0F@```````).:D9J/FI*:````
M``````"4F@````````````"5F@````"6F@``EYH```````"8FF29``#ZCFR.
M`````/&)``#VB`````!CD@``````````````````````````F9H``**-``#-
MB'V0`````````````)J:Q8P`````D8T``)R:FYH`````WI6=F@```````)^:
MGIH``*":``"AF@``EXP`````@(FBF@````"DF@``HYH```````"FF@````!Y
MDP```````````````*>:LXC=C0``````````7(P`````;I(`````````````
M``"HFJF:`````*N:``````````"LF@``XHT``````````,^+`````%:6````
M````JIJMFK^-0HT```````````````````````````````````````"QF@``
M``"CC0``4I(`````KIK8D@``````````````````````````````````````
M``````````````"RF@````""D`````````````"PFK.:``!>C```````````
M````````M)H```````````````````````````````"UF@``0XU?BK>:````
M`````````+B:`````````````+F:`````+::````````````````````````
M````````KYH`````NIH`````NYH``````````(26`````.F/````````O9J^
MFKR:``#`F@````````````!7E`````#FB'65`````,&:````````````````
M``````````````````````````#[CP````"WC@``?)3NB@``Z8T```````!X
ME@``L),`````F(S-D0```````+^:PIH```````````````````````#"D0``
M`````,.:````````Q)H```````#&F@````#GD@````````````"LB@``````
M````G^J!B?&5`````.J/9Y,``````````.2-`````,R:`````+N5VY<`````
M````````````````\HG(F@````````````!9D<N:``"#DP````!HDX23MY3+
MD@```````,>-````````QYH```````````````"6B0``59,``````````,F:
M``#%F@````!OD````````,V:``````````!MCP``````````JXL``,Z:````
M``````````````````````````````#FE0```````)V1``````````#$D@``
M``#0F@````````````````````!NE@````#1F@````#6F@``````````K94`
M`````````-6:SYK2FM2:`````*2-`````,>5````````UYH``&22`````/.)
M``#KCP``````````V9H``-B:``"(C0``VIK<FMN:`````-Z:``#3FN":````
M``````#?FMV:`````````````&V.<)```'.1X9JZD.N(A)0``````````-F2
M``#CFN*:Y)KEFN::``````````#GF@```````````````,^5Z)H`````````
M`,2)Z9H``````````%N73XH``,>99X^]D>J:Z98`````````````LI8`````
M[)H``.61``!6D[Z1=I7MFNZ:FXD`````N([OF@``````````SHCPF@``````
M``````#QF@````````````""B0````#OBMZ3\I4``````````/6:=)'TFE^,
M`````'J6\YH``(63]YH``/::`````````````/F:``#XF@````"<B0``^IJG
MC_R:1)(``/N:``"QE0``````````EX]ZDP```````$";``````````!$C0``
M`````$&;0)3<E,^6`````````````$24`````$J;`````````````%>+````
M`&27`````*V6``"JFP``0IL`````````````19L``,.1`````%>6````````
M:9,`````````````1IL```````````````"%E@``R(T`````J(\`````````
M`````````$>;`````&^.``!NC@``````````MXC&C```J9#/B```````````
M2YM,FP``29L`````````````````````5XFMB@``2)L``,.64)4`````````
M`````````````````*:(``````````#WB````````'".``#0B```H8@`````
M````````49L``````````````````$^;````````````````NI8``%*;``!0
MFP````!.FU"0``````````!-FP```````-B5`````````````.*,````````
M`````%:;5YL`````````````J8\```````!3FTN8``````````!KE`````!5
MFP``````````````````````````````````````````I8T`````````````
M`````%B;````````=Y4```````!9FP``5)L`````````````````````````
M``````````````````````"YE@``````````````````````````````````
M`````````````'V4``````````````````!:FU&5````````````````````
M````````````````````````````````````````````````````````````
M`````%N;7YM<FP````#%B5Z;````````````````N8X``%V;F8P```````!K
MFP````````````!DFV&;````````````````````````A)(``&";`````&*;
M`````&.;``````````````````````````````````````````!EFV:;````
M``````````````````````````````#PB@``:)MGFP``````````````````
M`````&F;`````````````````````````````.R/``````````````````!L
MFP``VI(```````!DB0``:IL```````!MFP``````````````````;IL``'&;
M`````&^;``!PFP``````````````````````````<8YRFP````!%C7.;``":
MCK:1``!TFW6;>8Y&C0``T)8```````!'B\>,=IMWB@````!WFP``MY$`````
M`````'B;H9L``'F;``!ZFP````![FP``?9L`````````````?IL`````@)L`
M`.Z1``!&B>>.P(@``':1KHJSC@``1XT`````````````AI,``$"/KXJ(DNB2
MMHA8B_.5``#`C@````!QB^F0NHY'EX&;``````````````````![BP``R8T`
M````48J#B:J/QHD``(*;99<`````````````:(\`````XHZ#F_&*T).GEH2;
M``"%FP````!XE0```````(>;``"FBO6+AIL```````````````"PB@``49"+
MFT".``#'B8J;``"(FXR;B9M*E,N>4I```(V;`````+Z7``".FP````"0FP``
MGI*/FP``H9```)N.````````SI'UC@``E97JD```RXZ1FZN/DIN3F]&(N)%Q
MD```E)NQDZR/``"MCP``E9L`````ZY````````"NCP````````````"6FP``
MEYL``-Z6````````F)L``````````,2+````````08\```````````````"9
MFYJ;VHY+D/*3<Y#VE$&4QXN;FP```````(^+G)L``/R+``#-DZZ)``!RCIV;
MH)N?F_N+``">FP``5Y,`````````````````````KI$``&J3QHX`````=Y&:
MEP```````````````**;``"CF]23``!2C@``````````I9L`````IIL`````
M``````````````````````````````````````````"GFP```````/**J)L`
M````J9L```````````````````````````````"JB0```````````````%J1
MXHH``*N;II8``````````-"1``!XB@````"MFZ^;W8H`````K)NNFP``L9L`
M``````````````"PFP``LIL`````````````````````````````````````
M````````LYL```````````````"[DZR+````````````````XXFTF[F;````
M`+>;``#UE?25`````````````(>3````````MIMSCP``M9L`````````````
M``````````"2D````````+J;`````.B-`````,";`````,&;NYM2BKR;Q9O$
MF\.;OYL```````"^FP````#"FP```````````````/:5````````````````
M````````````````````````````````````````````````````````````
M````````````R9O&FP``R)L``)*7``#'FP```````````````````````+V;
M````````````````````````````````DY``````RIL`````M8T```````#+
MFP````#,FP````````````````````````````#/FP``SIL`````S9L`````
M``"(D[B;````````U9L```````````````````````````````#1FP``````
M````T)L```````````````````````#2FP``TYL`````````````````````
MUIL`````Y)<``->;U)L`````````````````````````````V)L`````WHK9
MFP``````````VYO:FP````#<FP``````````W9L``.R00H\`````A(\``(.1
M``!(C;:-28V0BP````#>FP````"WC0````#(C-^;I)9BE.";``!*C0``````
M`*J*``!&DM"+````````<XYZE0````"_E```````````X9OSB@``````````
MY)L``````````)^2`````..;XIOEFP``Z9(``````````````````(.0````
M`````````'2.``#(D```T9%!BP````"@D@````#FF^>;[8\``````````%B6
M`````.J;`````.F;Z)N=E0``\9L``````````'F6``#KFP````````````#M
MFXN6``#LFP``````````````````[IL``*:4[YN\E?";````````````````
M``````````````````"QBKV53I3RF_.;``!+C;**])NVC&.72)?TBO:;``"A
MD@``3(VOCP````#=E`````"PCP``````````F(\`````````````ZI+WE5B3
M`````$V-``![E0```````/>;`````````````'B3P(T```````#)C```ZY(`
M`````````````````,&(CH].C6:7`````````````````````/B;^9MPE```
M````````^IOUETR8``````````#\F_N;`````&:*`````$"<````````0YQ$
MG```0IP``%^5L8]&G$6<09P``````````$><2)P`````29P```````!,G$J<
M``!+G$V<``"$B>R23IP``)J,](E5E```3YSYDP``V94``%"<39@`````````
M`%&<OI54G)^8KY@``*Z.\Y-5G```?(NBDOB(5IRDE4^-`````&^2````````
M[9(`````````````[9:WC,J,``!7G````````%B<``!>G```XXX```````"C
MD@``K8M9G````````$J5``!ED@````!:G````````````````%N<``"NBP``
M7)P``%V<`````%^<``"6DP````!@G&&<``!BG`````!3G%*<````````8YQ@
MC````````$:5`````,J-5I6DDFJ59)P`````LH]EB0``99P```````!FG```
M\)8`````WI0`````:9R=B:J0:)QGG&&,TI$``&V<:YP``&J<I9?CC```````
M`)F/;)QKDUV/````````OI-PG&^<``````````!NG```<9SDC```````````
M`````'*<G)5ZCP````!SG/>4``````````"_DZ62``````````!/DP````!T
MG$J+`````````````%.0``!+E0```````````````/6*190`````````````
M````````=9QUCEF66I8`````GHEZG`````")D@```````'><````````````
M````]8D``````````*N<>9P```````!/E`````!XG`````!VG```FHT``'R<
M`````````````````````````````````````(.<B9R!G```>Y,`````AIQ\
ME0````"`G```A9SEEW:.`````-.1?9P```````!]BXB<JY"%B8*<]HF'G```
M`````*^+``"$G`````````````````````"*G````````````````(R<EIR4
MG`````"1G````````)"<]I<``)*<`````+"+``!0C0````":CP```````)F<
MBYP``````````(^<?IP``/B)DYR5G'"2`````*:-MHF-G)B<EYRQBP``IY&&
MB@``````````8HP``(Z<````````````````````````FIP``)V<GYP`````
M`````+N.``"EG.Z2FYP``````````*.<``#WB0``H9RBG`````">G*"<````
M````Y8Q)EP````"SB@````!XB:2<``!9E*N(``````````````````#?E'N<
MJIRNG..6``"GG````````(F3K)P``````````````````.Z/K9S5DP``````
M`````````````````&:8``"IG```````````KYP``)N-``#)D`````#2B*B<
MIIP``'F1````````G)Q3C@``````````````````Q)&[G```>I&VG```LYRT
MG```Y(ZWG+J<``````````"UG$2/``"XG`````"RG```^I;YE@```````+R<
MO9S3B`````````````"QG```````````\(NDB````````+2*``"YG```````
M``````#!G,"<````````Q9P``````````````````,:<````````````````
M``#$G,><OYS#G`````#(G```R9P`````OIR<C@``PIS4D5&-L)Q4D```````
M````UIP``.>5`````,R<S9S.G`````#5G```U)P`````G9:UB@``TIP``&2,
M4XH`````SYP`````MI?1G-2(TYP``,J<T)S7G&.,RYP```````````````!\
MEP```````$J7``````````#:G`````#>G````````)Z1``#WE]^<`````-R<
M``#9G`````#8G-V<````````````````````````KI4`````LI,``&6,``#@
MG-N<``#AG````````)N,````````KXD```````#IG````````+:*````````
M``#GG`````#HG*>-YISDG..<ZISBG.R<`````/F)````````````````````
M````````````````````````````[IP`````[9P`````````````````````
M````````II(``/&<``#OG.6<G(P``/"<``#TG/.<]9SRG/:<````````````
M``````#WG/B<Z)4``/J<^9Q>CP``K)#DB?J)``#[G```O8@```````#*D/R<
M``#!YD"=@8P``$&=``````````#MD````````$*=````````0YU9BT2=``!%
MG4:=U9$```````#+C`````#?E@```````%N6BH]'G0````````````#ND+OG
MX)0``.B.``#+C4B=``````````#%D0``I94`````[Y$`````2YT`````29T`
M`$R=`````$J=``````````!-G0````````````"OE0````"UB```````````
M?94`````X90`````3IT``%&=LX]:BP``3YU6G;2/``````````!0G6.4````
M````````````?9=2G5.=5YV*DU2=4HW<D`````!EG;*4``#PD0``````````
M`````````````````````.*4JYT``````````/B5````````[Y(```````"5
ME@``6IV?B8J2``````````!CG0````!3DEV=9)U?G6:=8IT``&&=CY0``%N=
M^XE9G9&+\9%5G0````!8G5.-V9```+6/8)UQE`````"2BV>*````````````
M``````````````"'BD"0:)UMG0``:9T``)V,``!NG4&.B8T`````````````
M``!%CUR=``"=CFN=``````````!WCFR=PH@`````9YT``````````*>2````
M``````````````"3BP````````````"RBP``````````````````:IVEB```
M``#!C0```````%60``````````````````````````#PD@````#2E'"=?9$`
M``````````````````````"HD0````!*CG&=``!SG6^=``````````#?E0``
MNY(``````````'N1``````````````````````````#YE<R.@)T``'Z=````
M`)B0````````GHP```````!XG;>/`````.:34)0``````````':=`````'R1
M``````````#VCGN=`````+:/``!UG7J=`````'*4````````=)T``$",````
M`'R*````````?)VIE\R-5))YG0``VI```%2-A)"&B5N1=YUDBP``````````
M``!FC```S9)]G0````````````!^D0````"!G0``@YT`````M9&)G0``A)T`
M````AIT`````````````8)7QD@``AYT```````!+EP```````&>7MXH`````
M````````K(@``(6=`````````````(*=``````````#VB@````````````"'
MB0``B)T```````!HEP````````````````````````````",G0``````````
M`````+F1``"3G0```````(V=`````(J=D9T``````````'*=````````````
M````````````CIT``)*=````````P)2+DP```````````````(N=``"/G0``
M`````&>,````````[XT```````#;D`````````````````````````````"7
MG0```````````````````````$63````````````````````````````````
M`````)2=``"`E@````````````"5G0```````````````):=``#,E@``H)``
M````````````````````@HP``````````)V=````````````````````````
M5(Z:G0``F9T``````````%&4````````LY,`````````````4).;G0``````
M`)R=``"/E0``9)1"C@``[Y```&^6````````````````:(H``*.=GIT`````
M`````&F7I9T`````H9T``**=`````````````("1``````````"@G0``7IT`
M``````"DG0``GYT`````````````J9VJG4:3K)T`````0XZGG0``````````
M6XL`````K9T``*:=L9T``+"=``"OG0```````+*=`````+2=[X\``+.=````
M``````"WG0```````````````````````````````````````````````+6=
M````````MIV0G0````````````"YG;B=`````````````)B=NIVNG0````!X
MC@``````````NYV\G;Z=O9V_G?R)``!5C0````#ZE:V0`````````````,R,
M`````,&=``````````#$G0``<94``'Z+````````PYW"G7.4Q9VSBP``````
M`,>=QIT```````"XBE6.`````-:3`````````````&B,````````E)```,B=
M``"ND$>3``!^E<F=````````````````````````RIW+G0```````+:5?)O$
MD`````!KE0``UHT``..4P90`````````````;),``+^7``#-G<Z.`````,Z=
M``"TB`````#2B\N0``"`E0```````,^=88YFD@``>HY6D```````````````
M`-"=``#[E0````"7B7N.````````TYT``-&=U)VWE]*=``````````#YD-6=
M`````+"1`````-:=``````````#XB@``V)T``->=``````````#9G=J=^8H`
M````^I-5DHR+?(Z!D0````![CZZ(````````VYT`````````````````````
MH(G?G0```````````````%:-WIT`````J8VXCP````#=G0``N8\``+Z6J(T`
M``````#5B,R0``````````````````#DG0````"OD&:)``````````!TCP``
MAI;PC0``````````NH\``*60``````````#CG>&=XIT`````````````BY(`
M````19X``.B=GHY7C>:=``````````#GG0``5Y````````#EG0````!.C@``
M````````````````````````ZIWIG>Z=`````.^=``#KG0``08KLG>V=TY0`
M`````````(&5:8SPG0```````+"0``"[CP```````'&2````````````````
MQ8L``/&=]9T`````R8GRG?2=``````````#SG0````"+CP``````````9Y+#
MB/:=``````````#WG0``````````J)(```````#OEP``````````8HX`````
MZ94`````````````7)8```````!!GOF=`````/R=``#[G0````#XG0````!`
MG@````#<DP``^IT```````````````````````````````!"G@````",CT.>
M``!JEYB4`````$2>`````````````$:>`````$>>````````````````2)X`
M`,B+9XE8C4F>``!*GI&/@I$`````UIE=D5R1UI'%C0````#PF```````````
MCHQ,EP``_)4``)Z5``!+G@``````````\8V]DDR>3I@```````!=E@``J9)-
MGOJ*````````````````3IY/GMB6``"BEI:6>Y9$CE&>`````.F.`````'"6
M``!3GE:>59X``/>*`````("+``!2G@``5)X``````````%>>`````)F0````
M``````";E\>(WHVZD0``VXX`````\8\`````6IX`````;9,``%B>J9%9GO"/
MVY9;GER>B)<``````````&&>`````%F-``!TE%Z>C)/<G>"=``!NBP``9I0`
M`````````&">``"\C\*4`````````````&:>``#XE```79X``&.>8IX`````
M``#-D```````````C98``-&7`````(>6``#*B7V.`````&>899Z5D```````
M`&2>`````%^>`````````````,V,````````:YYIG@``RXEGGFV><YX`````
M`````````````,:1`````+^5``!UG@```````$&5````````=)Z0E%Z6N8H`
M`/607X\```````#1D@``39<`````<)YOG@```````'&>``!NG@````!VG@``
M;)X`````:IX``'*>:)X``(R2``#VEL2.\HT`````````````N(T`````CY9@
MB@````#,DLB3:(D`````````````````````````````````````\)``````
MLI!)C````````````````'B>`````%J-G(H```````````````!ZGI2*@9X`
M``````````````!]G@``\9````````!JBJJ-`````&F*S8T`````>YZ%C&J,
MC9,`````>9X``,2(``````````!\GGZ>``#+BTN,``"ZBFJ+``````````""
MG@````#WC9&6``!6C@```````(.>````````3Y4`````````````````````
M``````````"/G@``L8F$G@```````````````)6>A9X``,"7``",G@``?I0`
M`````````````````)2>``"'G@```````+*(B9X`````6XT```````"+G@``
MBIX``(:>D9X``+V/````````ZYKFC)R7``````````"(G@``\I)"BJN-``"`
MG@``D)Z!B@````".GI*>``".DP``````````````````_(H``+">`````,>6
MEY[[B@``GIX``````````%^6``"?GJ&>``"EGIF>``!)D@``````````CY.I
MGIR>``"FG@```````*">````````````````6)"JG@````"QD```````````
M`````*B>NXH`````````````;YB6G@````"DGM:(`````)B>`````+B6G9Y!
MD,62DYX`````HYX```````````````":D*V>D8J?C```````````KYZ:GJZ>
M``"GGIN>``"KG@``K)X`````````````O9X```````#,DP``HIX`````N9X`
M``````"[G@``UI(``````````````````````````&N7````````````````
M`````):5MI[(D0```````+R>7I$``+.>P)Z_G@``[9.^GNB3````````````
M``````#"GK6>``#&B[B>?(\```````"`E+J>R8L``+*>M)ZQG@````!/F'F*
MMYX`````P9Y4B@``````````````````Y8T```````!\B0````#2G@````!0
MF-6>`````````````%F0U)X```````#3G@```````````````-">````````
M````````Q)X`````X9[#G@``UIX```````````````#.G@````#)GL:>``#'
MG@``SYX```````"@Z@````#,GER-QI*$D<J>``#%G@````#(G@``````````
M;)>*E@```````,V>UYX`````````````````````WY[8G@````#EG@``XYX`
M`````````-Z>````````````````W9X``,Z2``"%D0``VYX`````V9X`````
MX)X``````````.:>\Y3LG@````````````#GGNJ>Y)X`````E)(``%>5``#:
MG@````#BGKZ/``#-EO:>Z9X`````````````H(RAB7Z*`````-&>````````
M````````OX_NG@``]9[WCI**`````$V2````````````````ZYX`````\)[T
MG@````"TBP```````````````````````````````&N+\IX`````````````
M0(L``,F3\9X```````#SG@````````````````````````````#MG@``````
M``````#OG@```````````````("*:)(```````#ZG@``````````````````
M``#XGN>,``#WG@```````````````$"?``````````!WG@```````/F>``#[
MGOR>````````````````2Y\``$>?``"-G@``````````1I\``````````$6?
M`````$*?`````````````.B>1)]#GP``````````````````````````````
M````29\``$68````````````````3)_YBP````!(GTJ?````````````````
M`````*64``!-GP```````````````````````````````````````%&?3I\`
M````````````````````DY=/GP``````````W)X``````````````````%*?
M````````4Y\```````````````!4B0``59^'C)^.``#3BP```````**)````
M``````````````````````!^EP``````````5Y]6GUF?7(L`````U(N\B@``
M````````7)\```````!;GP``79\`````S(D``%:2``!>GP````"]BF"?````
M``````!?GP``89\```````!BGP``8Y]^CK.0GXT``)"5`````."58Y@`````
M`````)6.````````SHWPEP```````&2?99\``(".````````9I]GGP````!I
MGVB?``!WE@````!]C^J.8XX``&J?``````````````````!LGT*0``!KGP``
M``````````!MGP````````````!NGP````````````!OGW"?````````<9\`
M`'.?<I]TGZ.):9(``'6?`````$6.:XIVGP````!AD\J:``````````!"BW>?
M``````````!XGP``ZI6(E@```````,63>9_DE````````/F4`````-&6````
M````>I\`````````````````````````````?)][GP````!^GP```````'V?
M`````````````````````````````````````````````````````(&?````
M````````````@8X``*^6``""GX.?`````$.+````````A)\`````````````
M`````(:?A9\```````````````````````````````````````"%D`````!8
ME6F)`````````````,.4``#SDF"/@8L`````````````````````````````
MQ)0``*R.``````````"(GP``OHH`````F(D`````\).'GUV-<I(``(F?````
M`````````)&?``"*GP````````````"_D0``@HN2GP```````````````(B,
M`````$2+D)\`````CI^+GX"7``````````"^D@```````->3C)\`````E)\`
M`).?0HP`````JXD`````N8V-GX^?`````````````':6\I$`````````````
M````````EY8`````G)\`````G9\``,V)``````````"FE?N6GY^ACL"/F)^>
MGXB)``"UBP````"5GYJ?````````\I"1E```Y90```````````````"7GP``
M0)8``)F?``"BGP``H)\``)N?````````099GE(.+``!$DP````"-D@``HY\`
M`````````*&?UY&6GP``:HD`````````````````````````````````````
M````````````````````````;9>NGP````````````"MGP``````````])``
M`*J?``",EP````"TDZ2?`````````````,.2````````:XE>C:>?````````
M````````1H^LGP``JY^FGP``J9\`````B(H``*B?:)0`````K)<`````\H_S
MD```````````````````````````````````````````````````M)^RGP``
M;)4```````````````"OG[&?``!9B0````!?C5&8``!<B@``@I4`````````
M````@9<`````0XI:D+.?`````````````````````````````+B?`````,&/
M````````3Y<``+6?``````````"PGP``MI\```````#<EP``DY/`DP``````
M`````````````````````````````````````````%6*`````'2)`````+R?
M`````+^?````````P9<```````"$EP``````````QI_`G[V?````````TI?#
MGP``````````:8_%GP````#*GP````"1D\B?``````````#"GP````!7D@``
M``#)GP``OI\``,2?``#+G_J(P9\``,R?`````%N0``!^CP``HY4``*R-``"Y
MG\>?69,```````````````````````"TD```B8K/C<*/NY]ACP``````````
M````````:XP``+J?````````T)^-C[B,``#?GP``V9^4BVZ3``#4G]V?K8A1
MB0````"WB0``UI^JD<V?SY]@C0````````````````````#@GP``VY\`````
M``#3GP``````````VI\```````````````"IE@````#8G]R?````````````
M``````#.C```PX\`````6)(```````#2GP``````````````````3I<`````
M``#5GP````#.GY*3`````-&?````````UY\``````````````````'"8O(Z>
ME@``X9\```````````````````````"LE`````#MG[F,`````````````("/
M``#CGP```````*V788T``/"?`````.R(`````.Z?``````````#BGP``````
M````Z)\`````ZI\```````!NE^6?`````$V3`````.>?``````````#OGP``
MZ9_%E@```````.2?``"@COR?``````````"*B@``YI_KG^R?````````````
M``````#JD=B1``````````````````````````````````#TGP````#ZGP``
M``#XGP``2),`````0N#UGP````````````#VG]Z?``"9BUF5````````O8X`
M````EXT`````````````4I@``/*?``!!X(F)AI$`````````````````````
M`````)F4``"_BOB7``````````````````"?EM"2``````````#YG_N?````
M`````````%&1`````````````$#@]Y\``/&?````````P8H`````````````
M````````````````````````B8P```````!.X`````!)X/:0`````(.*````
M``````"!CP``4N````````````````!+X*J22.#7D@```````&O@````````
M1>```$3@``!-X````````$?@1N!,X```GY```$/@``````````````````!/
MX`````!0X`````````````#`B@```````````````````````%7@``!4X%;@
M`````````````%G@````````````````8I,``%/@`````````````%?@````
M````````````@XSWD5'@6I0`````6.``````````````````````````````
M`````%W@6^``````7N``````8>````````!:X(J-1Y0`````MY\`````````
M``````"4EUS@``!@X/.1``!?X```2N``````B>@```````!DX````````&C@
M`````&;@``````````````````!BX```8^````````!GX```9>````````!M
ME0````!MX```:N!IX```;.#2DV[@````````````````E9+KD0``````````
MHY````````!OX```<>``````````````````````````````<.``````````
M`````````````````````````/.?``````````!RX````````````````.63
M``````````````````````````!SX```````````````````SHD```````"4
MDT2*``````````````````"$BP```````-R.T(T`````````````````````
M````````1IB&D````````(J)````````=>````````````````!TX```````
M`````````````````````````````````````````'C@69)[X';@````````
M>N```````````'G@7Y/7B```````````````````````````````````\Y<`
M````?>````````!'B0```````````````````````(#@````````?N```'S@
M`````````````````````````````````````````````'?@````````````
M``````!"E@```````(+@`````````````````````````````('@````````
M``````````````````"+B0``````````A."PE0``@^```````````+.6````
M``````#%CP```````````````````````````````````````%*1````````
M`````,2/````````````````````````````````^9<`````BN```/>0````
M````````````AN"+X`````",B0````````````````````")X```@92%X(C@
MQH\``,^4`````(S@``#/C@````````````````````````````````````#X
MD````````````````(_@````````A^```$:,``````````"-X```````````
M;Y>0X````````*3J`````````````&Z/`````````````````````)'@````
M````DN```````````$V4``````````````````"4X```````````E>``````
M`````%*4``````````"5DY?@``````````"9X```TY<``);@``"8X(V)``"3
MX```````````````````>IJ:X```````````AY%7CIS@``````````";X$.0
MUYD```````````````"=X````````)_@``".X)[@`````*#@````````````
M````FI0```````````````"AX`````"BX```````````````````````````
MH^````````````````````````````````"DX```W)(``*;@I>``````I^``
M`*C@`````-V.@Y4```````#JEJG@JN!UD:*.J^"LX`````````````"MX-"5
MQ90`````KN!VE`````````````"KD@````````````"OX.6)``"-BP``Q)8`
M`+26``"RB5.8``````````!QE@``J)4`````````````````````M9```+#@
M``````````#!DP```````*&,L>```-*-L^"RX```````````M.``````````
M`````````````````+7@````````MN````````````````````````!=BP``
MM^```````````+C@``````````"BC`````#&E`````"ZX````````/./````
M`+G@`````````````````````+:+N^"]X```O.```````````````````+[@
M``#/C```O^```````````.>+``!?D0``G8T``````````,'@PN#`X```````
M`````````.N.`````,:3MXL```````````````````````#$X$N2P^``````
M5)B"E````````````````````````````````,?@````````````````````
M`````````,G@QN````````#2ELC@RN```,*7`````````````,[@````````
MS>"6DDR4`````*.,S.```````````,O@``!0EU&7````````````````S^".
MB0``````````EHV"C@````````````````````#0X-'@````````````````
M``#3X`````````````````````````````!BCP``````````U>```-3@````
M`````````-;@``!LB@````#8X`````#7X```VN#9X```````````````````
M``"ZC`````"FEP``RHL``*2)``````````````````````````#HBP``````
M`````````````````````````````````````````-^*````````````````
M`````.:7W.```````````````````-[@``````````#?X```SXD`````````
M````V^```%B.`````+^2W>``````````````````````````````````````
M``#BX```[(X``````````.#@``````````!=C`````#'E.'@`````/S@````
M````````````Y^``````````````NXP``````````(6+``#DX)V7`````*Z7
M````````````````````````````````````````````````````````````
M````])$`````YN````````````````````````````````#HX-27U8OZE&F4
M````````Z>```````````.O@``#NX```````````````````````````````
M````````````````````ZN````````#MX.B,;(GOX```D)#LX-J7`````/+@
MHNH``````````/#@\^```````````.7@\>``````NHT`````].``````````
M`````````/7@``````````">EP``````````````````]N``````````````
M``````````````````````````````````#WX````````./@``````````#X
MX`````````````````````#"B@```````````````````````````````*..
M````````````````````````````````^>```````````/K@``````````#[
MX```````````````````6HD```````!`X0``6I5!X0````"BBD+A``!#X0``
M````````1.$``$;A1^%%X0```````'*52>%(X0``````````````````````
M````2^%*X4SA````````````````3>%/X4[A`````)F-``!1X0``4.$`````
MPXH``'*0``!;DP``4N&VD````````%F.``"9B5/A``!PEP````#AE53A````
M````8Y-2EV*-7)````````!JDK*9``"LDN:)5>$``````````````````%;A
M``!;X0````!9X5CAP)U%BE?A``#8B```J)0`````R)0``````````*^77.%:
MX7N2I)``````J90``$R5``!>X:J7;(Q?X0``7>'4E&#A``!AX0````#9B```
M``#TCV;A``!CX>N38N$```````````````!%BP````!IX0```````&3A9>$`
M`&CA9^%$E0````!AD6"1``!>BP````!JX0````````````!KX0````!LX0``
M``````````!NX0``;>$`````````````=8D`````````````=N'FE'#A``!R
MX0````!TX5V0`````'7A<^&^C@```````&_A<>$``&&5``#'CP````!XX0``
M``!WX0``````````>>$``*2.K8T`````EY-ZX0``R9(`````?.$```````"?
MEWOA`````````````(F1````````````````@N$``(3AA>%SD@``````````
M``"#X0``@.$``'WA?N$``('A``````````````````"(X0``AN$``(?A````
M`````````````````````````````````````````(GAB^&,X8WA``".X0``
M``"*X0````````````````````"0X0```````(_A````````````````D>$`
M``````````````##EP```````)3ADN&3X0```````."*`````````````/R6
M````````R)4``);A````````E>$``````````)?AF.$``````````)SAF>&:
MX9OA``"=X0```````)[A``"?X0```````*#A``"AX0``K91ODZ+ADI13E0``
MH^$`````I.%)DP``1HICC:7A`````*;A`````*?A``!(C@````"IX0````"H
MX0````"JX:OA````````````````````````````````````````````````
M``#GE```K.$```````"MX0````")ZJ[AK^&PX0``````````38X`````L>%U
ME`````!^E@``;8D``':)`````++A``````````"TX0```````+/AD),`````
M``"WD%B?``"UX;^6``"VX0``Q(K5E+?A``"XX0````"YX0```````-J6````
M````TY8``+R2````````BI$`````N^$`````@H\`````R(\`````ON$`````
MO>&\X?N4``#%BJ>,`````````````````````````````````````,3A````
M`,'A7I"PE@```````,#APN'#X0````"_X0``````````````````````````
M````````Q>'&X0``K9(``.&*````````A9(```````````````#'X0``````
M`````````````````````````````````````````,CAR^$`````````````
MAY```,*3``#,X7*6``#)X0````#*X0``````````````````````````````
M````S^$``````````,[AS>$`````````````````````````````T>$`````
MT.$`````TN$```````````````````````````````#4X0``T^$`````````
M`,N5````````````````=8_$EP````#5X0````"UDP````#6X0````#7X0``
MV^'9X=KA``#8X0``````````````````W.$`````````````W>$`````````
M``````````````#>X0````#?X;66X.$`````````````[I;AX0``;9(``(J4
M``#IBP```````%J2XN&XBP```````,Z0`````````````````````./A````
M`````````+N-````````````````````````Y.$`````````````Y>$``*2,
MTXT``````````````````````````.?A``````````!UD]2-;8L`````````
M`````````````````$.6``!JE`````````````!VDP``````````>XT`````
M````````Z>$`````````````````````````````````````````````````
M````````````R8\``````````````````````````````````+"79(T`````
MI8P`````H90``.OA``````````````````#MX0``````````Z8P`````````
M`.SA])(``````````._A5HKJX0````#HE```3XD``.J-``!QF`````#NX0``
M``````````````````#PX0```````,F5``#7D/+A``````````#SX0``````
M``````#QX0``````````;8H``/GA``#XX0````"EC@```````/KA]>$`````
M``#[X?;A``````````#6E/3A`````/?A`````````````$'B````````````
M````````````````````0.*!E@```````/SA`````.F(``````````!#X@``
M``````````````````!"X@```````,J/`````````````$3B````````````
M````8I$`````1N)%X@```````````````$?B````````````````````````
M````````YN$```````#HX4GB2.(`````````````````````````````````
M`*:.``#GEP``T(X``$KB5HP`````````````7XM&BX..````````````````
M4Y<`````4.(``$_B8Y%,X@````!.X@````!JCU^03>)+X@``290`````RX\`
M````6Y4``````````-6-````````````````````````F),`````4>(`````
M`````%+B:.+6BP````!<F%21``````````!3X@````#0B?62GY4`````````
M`````````````````````````%3B`````````````````````)J+5>(`````
M5^(```````!8X@``2)0`````6>(`````````````6N);X@````#7B]&)PY-'
MCX2.``````````````````!<X@``2(\`````````````R(EBE0````!=X@``
M``#IE````````````````&21``!@X@``8>*)E```8)!>X@``@9(`````7^(`
M``````#,CP``````````````````````````VH@``````````$B+````````
M``````````!BX@````#VD@``8^+%D`````````````"KE@````!"E63B9>)T
MD@``Q9<`````9^)FX@``````````````````````````````````[8X`````
M:>+NB```````````;.(```````!JXM*);8QKXF6-DHT``.25;>(`````<Y8`
M````;^(```````#/D&Z)N(FJB````````````````&[B````````````````
M````````<.)QXO6/`````````````'+B``!NB@``````````=.(```````"*
MC```AHL`````=>+SBP````!VX@``^I```,N3``#>D/.-````````=^(`````
M``````````````````""DHN1``!YXGOB>.)ZX@```````````````$&,````
M````````````````````?.)%C````````(>+<9=^X@````````````"`X@``
M`````$V)``````````"#X@```````):*@N*!X@``A>)]X@``AN*GEP``A^(`
M`(CB`````/*:BN(``(GB````````B^*,X@``LY>-X@``[>C-CX[BC^)VCP``
MMI.0X@```````$>2`````)'B``!;DI+B`````````````*.+``!>F7R2L8X`
M`````````,:*`````)/B``"@X@``EN(``(B+``"5XJ+B````````E.(``,Z/
M````````````````F.*9X@``2I,`````FN(``'V*``````````!YD(25``"<
MX@```````.:1````````````````E^(``)OBG>(`````^8T`````````````
M````````````````I.)-E0``I)29DP``V(NCXJ'B``"SE)[B?9*;DP``FI,`
M`/2-````````````````MN(``````````````````*;B``"HX@``````````
MJ^(``*SB``"IXJKB`````*?BI>(``````````)_B````````````````````
M`````````,V5TXD```````"SX@``L.(``+7B`````+3B``"3E*66``!:CJ[B
MM^*RX@``L>*MX@``K^(``,>*`````````````````````%R2`````/N0````
M````H)0`````O.(```````"BE```````````````````WY"YX@````#-E```
MO>+1E0``>I(``+CBNN(`````N^(`````````````````````````````````
M`+[B`````,*.````````Q)/#XL+B`````+_B````````59@`````````````
MR.(`````S.+)X@````````````````````#%X@```````````````,;B````
M`````````,OB````````P.+3F<?BP>(`````RN(``````````````````-#B
M``#(B@``S>(```````#.X@````#/XM+B````````````````````````````
M`-'B])0``````````-/B^I?KE=CB`````-7B`````````````````````-3B
MT)```-?BV>(```````#6X@``W>(``-KB````````````````V^+$X@``````
M`-SBWN(```````````````#?X@```````````````,25``#@X@``````````
M``````````#@E@````#,BTB,X>(`````````````LI4``(B0``"NE@````#B
MX@``L9<`````E)0``&614Y0`````;(\```````"^B```Y^+EX@``X^*?B@``
MSX_HX@````#FX@``Y.+LX@````#KXNKBZ>(`````````````[>(```````#N
MXKB0``#OX@``\>(`````\.(``````````-",````````5Y$```````#SX@``
M`````)R3``#RX@```````/3B``"SE8R19HT``/7B``````````#&EP``````
M````````````]^(`````^.(``/GB``#ZX@``A8X``/OB;HP`````BHL``$F+
M``!`XP``\99GC?SB````````0^/DE@``6Y0`````4I4```````"#CT+C``#1
MCFB-AHZ)B[250>,```````!FD6&6]8T`````````````````````AX[;D@``
M1N/=E]>-``!'XV&0``!)XP```````-"/KHT``````````$CC`````$F/O(QG
MD43C2N,``````````$7C;XP``$WC4>.+C`````````````!,XP``````````
M5>,`````:8T`````C9>ZB%+C`````(N+``!/XP````````````!0XP````"=
MDT[C2^,``$>*XI``````IHP```````!7XP``````````````````````````
M``!4XP````````````!6XP```````%/C`````````````'",L9%8XXZ1````
M`&7C`````&'C6^,``````````````````%_C^([;B%KC8N-FXVJ-U)8``-22
M7.,`````9.,``%GC79(``%[CNXC(E@``````````````````7>,`````V8OJ
ME````````(V1``#.EX^/`````([C`````&?C``#\D```8^-HXVKC``#WDFWC
M`````&GC````````TI7)B@````#)E@````#<B`````!LXP``^Y<`````````
M``````!KXP````````````"/B0````#JDV[C````````=>-OXW;C````````
M````````<N,`````````````````````FY0`````R(YTXP``<>-WXW#C````
M`&./``````````!$E@````!KCP````!SXX#C`````'OC``!^XP``?..!XWKC
M``!@X]&0`````,F4``!]XP````!XXP```````$"1<8P``$J/````````````
M````1)!5D83C`````(;CA^,`````@^.%XP``````````````````>>."XP``
MBN.)XP````":E@````!*C`````````````````````"(XP``C..+XX_C``"1
MXP````!;CHWC``````````"2XY/C`````)3C``":XUJ3EN,``)7CE^.8XP``
MF>,``````````)OCG.,`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#*B@``G>,``)[C``````````````````````````"?XP``````````
M`````*#CH>.BXP``H^.DXP````"FXZ7C`````*?C````````````````J..I
MXP```````````````*SCJN.KX]^-<HP`````=9(``+&4``"0CP````!LE```
MZY2MX^N<`````````````````````*[CL.,``(67K^.RX['C``!REP``L^,`
M`/R4`````````````+3C`````````````+?C`````+;CM>,``````````+CC
M48P```````!!D6"+``````````"\X[GC`````+KC````````O>,``+[CN^,`
M``````!(B0```````*6)````````P./!XP```````,+C``""EP``````````
M``!+CP``Q./#XP``````````````````````````B9#%XP``````````QN,`
M````Q^,``..*``````````#+B@````#(XP````````````#)XP``?):#EP``
M`````'.75I@``&R-S./2CLOC``````````#-XZ>.````````SY$``,[C````
M`&N-``#5EL_CT.,`````T>,``````````-+C````````````````T^,`````
M`````````````````````*B.`````.N6``````````#5XP``7I(``-3C````
M````````````U^,```````#6XP``````````````````V.,```````"YD```
MV>,``-KC````````MY7;XP``CY'<XP````````````#=XP``````````````
M`/R7X.,``-_CWN.ND@``X>-%D```XN,```````#CXU>8Y.,``````````.7C
MY^/FXZ.4``#WDP``79BGE````````````````.GC`````-&/``!)E0``ZN/H
MXP``S(H```````#2C(B.`````.R4````````J(QBE@``[>/KXP``;8T``&Z-
MYX@``.:-`````````````'B4`````````````````````-V(\N,``%^2````
M`````````'>4``#9D0``````````````````].,`````\./SX^[C``#QXT66
M`````-.,`````/N([^,```````````````````````#VXP``]^,`````MY,`
M``````"YBP```````$7D7)0``````````(F.`````+J+QI!EF*R6]>/2D```
M`````````````````````````````````````'*+^.,`````````````````
M`/KC`````````````/GC`````````````/OC``!%D@``790`````````````
MKY(``````````$+D``````````````````!!Y```````````_.,`````=)``
M`(651.0``$/D;XURF````````````````````````%3D`````````````$CD
M2>0``````````.Z.`````$?D``"8C4;D`````$KD````````L)*@E4*1````
M``````#:D4[D``!/Y$OD``````````!,Y```3>0``````````'"-````````
M5>0``%'D``````````"&E0``C)9'E0````!0Y`````!3Y%+D````````8Y96
MY````````````````%?D`````%:1``!8Y`````!:Y```7N0`````6^19Y%Z4
M7.0``%WD````````L(D``&3D7^0```````!@Y````````&'D``"?D0``````
M````8^1BY&7D``````````!FY&?D`````&*0``#GB0``:.35EP``J8X`````
M3(\`````````````BHYVD@````````````!IY&KD4(D``&OD`````&SD;>0`
M````;N0``&_DNXNHG7#D``#CD''DR8X``'+D``"NF````````'/DW)7:B@``
M``!#D7>/``"1E4V/````````````````````````=.1QC77DRI0``(3D````
M``````!WY```QY&5E+V,=N1$D0```````````````'CD````````````````
M^)(``````````````````````````````````````````'KD>>1\Y`````![
MY```?>0`````@.0``'[D``#-B@``@>0``(+D@^0`````KXW'EP``A>1&D```
M`````)")AN2'Y`````````````"(Y```````````````````````````````
M`/"(``")Y```````````BN0```````````````"'E0```````,6.``",Y```
M``````````!(BK"(``````````"+Y([D;90``&.0``#4B0``1I8`````````
M`'R,VHL``(WD``#HB0``````````````````H8H`````````````````````
M````````D8F2Y.B7VY$`````8Y4``)[D``#5B9SD``":Y)'D``"/Y```D.0`
M`.&.ZHN7D@```````,^3`````````````'")``"4Y)/D``````````"9Y)7D
MF.0```````````````#.EI?DUHF=BIOD`````)WD``````````!SC```````
M````````````H>2JY*OD````````J8@```````````````"RY```````````
M[X@`````J>0```````"HY```H^2BY```H.2?Y(.2``#YD:7D````````````
M````I.0``````````*?D````````D)%TC```````````8(FFY```<HT`````
M````````D9$`````````````````````````````````````````````````
M````````````````````N.0``+GD``#7B0```````*R)MN0`````````````
M````````K.0``+3D``"[Y+7D````````L^0``````````);D`````+'D````
M````K>0```````#.BJ_DNN0``+#D`````````````+SD``"NY)R4````````
M`````(F7````````M^0``````````````````,WD````````Q>0```````";
MD```````````98L``-N+``#`Y```````````V8D`````TH\``,/D````````
MV(T`````<)/(Y`````````````````````#LE0``O^0```````#8B=2,2)7)
MY```O>0`````QN0```````#0Y```P>0`````````````PN2XDP````#'Y```
M`````,3D1Y;*Y-Z(``````````"^Y```````````````````````````````
M`,SD``#+Y````````````````(N4TN0``-WD``````````">B@```````.#D
M`````,[D````````T^2.EP````````````````````#<Y`````!TEP``````
M````J)<`````````````````````F)(```````"+B@````````````"2E>+D
MGY,`````KX@`````V^0``-?DDI'1Y-GDWN0``$N4````````J(@``-;D``#?
MY)B5``````````````````#:Y```U>0```````````````#3CP``````````
M3H\```````"JC@``````````UI8`````9I4`````Y>0``.[D````````````
M`````````````````-CD``````````"7B@````````````#VC^/D``#HY).1
M`````.3D``#KY`````!^D@``[.0`````=9?AY%>*``#GY`````#JY*J6````
M``````#MY`````#FY.GD````````````````````````````````````````
M`````$B6``!`F`````````````#QY```````````````````^.0`````\.3!
MC@````````````#/Y```````````````````````````S)4``*"6]^3VY```
M\N3SY```58D``````````/7D``#OY```````````TY(`````````````].3\
MB```````````````````H)$``````````````````,&5`````/GD0.4``->4
M``````````#\Y-2/QXY"Y0````"\BP```````````````$/E``"9E?OD``#4
MY`````````````````````#ZY```````````;IB@DY.5`````$KE````````
M````````````````4.4```````````````!1Y0``1.4```````"6E`````!.
MY4;E``!(Y0````````````!2Y4?E`````$OE`````)*)``#CDP``3.5/Y0``
M````````````````1>4``$61``!)Y4:.9)!/C/*6``#WEI*/````````````
M````````````5N54Y0```````````````&V8``````````````````!3Y0``
M`````)67``!5Y5?E``````````!8Y0```````````````%OE6>4`````````
M``````"ADUKE````````RY1-Y0```````````````````````````````)./
M``!<Y6'EE)$`````8.4```````!!Y0```````&+E:)$`````7>5?Y0``````
M````````````7N4`````4)]!GP````!DY0``````````````````8^4`````
M`````````````````````):7``"ZX67E````````````````````````````
M`````````&;E``````````````````````````````````!GY=6,``!SBP``
M`````&GE?)D``````````)6+``"XEP``\8MJY0``````````````````:^4`
M``````".D@````````````!LY0``````````````````^),``+B(````````
M`````````````````````````````.&)<>5RY0```````````````&WE``!<
MC@``````````````````````````````````;N5AE```````````;^5PY7KE
M````````=.5WY0````````````!SY0``````````````````````````````
M````=>4``';EUHX``'CE``!@D@``=8QAB@````````````![Y0``````````
M7HH``('E`````'SE@.4``````````+B4``````````!]Y0````!^Y6>5V)2"
MY0````````````````````#[D8SE``"(Y0````#IB0``AN4``$F6A^4`````
MA.4``(7EBN6-Y0````"+Y0```````(GE@^4`````````````=Y(``)3E``"H
ME@````````````````````"2Y0```````)/E````````````````````````
M``".Y0````"0Y0```````)'E````````C^4```````````````````````#D
MD```6)B8Y0``F>4``````````)_E``!)D```F^4``)[E`````````````);E
ME>4`````H.4`````VHD``)SE``"AY0```````)WE`````````````)KE``"Q
MD@``E^4```````````````"(E`````"EY0``````````````````````````
M6I<`````````````````````````````````````````````I.4`````H^4`
M````````````````````K.4```````"FY0```````*[E````````````````
MAI>QY0``J.4`````J>4```````"MY0``L.6OY0```````*?E``````````"J
MY0``N^4``````````````````````````````````+3E````````````````
M`````````````````````++E`````+/E````````N.6YY0``28H``&&+````
M`+?E````````````````HN4``````````````````+;ENN6UY0``O.4`````
M``"^Y;WE``````````````````````````#`Y;_E>>4```````#$Y0``````
M`````````````````,'E``````````#"Y0````##Y0``Q>4``````````(R,
M``#'Y0``QN4``$^/`````````````'.-I9\``````````,CE<(\```````!8
MB@``R>4``'&)``#5C\KE`````'2-R^7?B```````````7)4`````S.4`````
M`````(J0``#3Y0````#0Y0``CY(`````````````T>7.Y=R+``#-Y=3E````
M`````````%6,`````-R1``#:Y0``````````UN4```````"SD=7E``#8Y0``
M````````S^4```````#9Y0``V^4```````````````#ME`````#7Y0``W.7>
MY0````#1C-+E``"_B```````````````````W>4``-F-])??Y>#EE9$`````
M``````````````````"@EP``````````X>54EP````#BY>/E`````.*5Y.4`
M`+Z-``"AEP```````````````.GE````````````````````````ZN76C^CE
M````````AY?EY0````#GY;N0GI````````#FY0``Z^4`````H94`````[>4`
M`.SE````````C(H``$J6[N4```````````````````````#ZY?#E````````
M````````\>4``````````/+E\^4``````````````````````````/?E``#X
MY0````#VY0````````````#TY0``[^7UY0``````````````````^>6UZ```
M``````````````````"FB0``````````````````_.7=B_OE````````0>8`
M`$#F````````0^8`````0N8``$3F`````%"/``!%Y@````!&Y@``````````
M`````$?FO)```':7``!(Y@````"BE6642>8``$KFJ8P```````!+BP``````
M`$OF`````(N.8)1,Y@``;XH```````````````!-Y@``````````3^:7EP``
M3N9ED```4.8`````4>8`````4N;/B@```````````````%/F`````%3F``!5
MYE;F`````````````````````````````````````````````'"*````````
M``````````!7Y@``6.99Y@````````````#PB0````!'D%KF````````````
M````````````````````6^8```````!<Y@``````````````````OHP``/F2
M7>8``````````':,``!UD```8.8``**3``!?Y@````!0C`````!>YO613(L`
M````8>8``&+F``#7CP```````(V,``!CY@``````````2Y8`````W9``````
M``"6BP``\Y9ID0``9.8```````!FD)"2V(\``````````&7F``````````!H
MY@``:>8``````````````````+R-P)%GY@``V8]=E0````````````!FY@``
M``",C@``<HD``&WF=XP`````CHX`````C8X``&R8;.9KYD:1``!LBV*868K:
MCP````````````````````!JY@````````````!OY@``<.9NY@``UHP``%^7
M`````(^.1I0```````!SY@``OI```&&2`````%67``!VY@```````.J,``"]
MD'+F``!WYNN,=.9UY@``<>8```````#@D,>3`````$Z2``#;B0``````````
M`````.Z4`````&*+`````+*2`````'KF``!XY@````!KD@```````+^0T(IY
MY@``>I``````R)<```````!?F````````'OFA^:SD@``AN8``(/FB^:$Y@``
M@.8``/J2?N8```````!\Y@``0)>0C@````"!Y@``?>8```````"%YI2/``"_
MC````````/B1``!DEGF)X(@``*.3`````(GF``````````"(Y@``Y),``(WF
M````````@N8``(SFCN8``*J,BN9UC0``TXX`````C^9WEP``````````DN8`
M`)7F`````)/F5)4```````````````"0Y@````````````#>BP``````````
ME.8`````EN8``````````````````)KF`````)?F``"9YICF````````````
M````F^8``*^.``"=YISFB)4`````G^8```````````````!XC```````````
MGN:@Y@````"AYF.+O^/WCP``HN8`````[(P`````````````H^8`````I.8`
M````78X```````````````#,G0``I>8``*;F``!1CP``I^:HY@````"IY@``
M``"JYJOF````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````2I(`````K.8``````````*[F``"MY@``````````I),``*_F``!,E@``
ML.8``+'F``"RY@``````````L^8``````````-B3````````````````VX^T
MY@``````````````````BXVLF+7F`````````````````````````````+;F
M7I6WY@``O^8`````````````N.8`````NN8```````"YYKOF``!EEKSFO>8`
M````````````ON8```````#`Y@``````````3(KED@``B97@C7:-````````
M``!NE=V)S)3#YM&*TY#"YL?FF9+AE@``Q>;&YDV+``#(YH.4W9$`````[Y1<
MD\3F``!FENJ)RN9'F,"29)@`````D8[)Y@``KY$`````VN9'D0````#VDP``
M;Y4```````````````#-YEZ.DHX``-R/``"%E```JXS,YLOF``"*E0``````
M`+^.`````'&3````````````````````````````````S^;0YG>-SN8`````
M``````````#1YM+F``#4YJ&1``#3YN2*``#6Y@``U>;7Y@````#9YMOF``#<
MY@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#4D```S8[=Y@```````'&*``#>Y@````"6
MD=_F``#@YHN5`````$Z+````````````````````````X>8```````"TD@``
M````````>HD`````````````````````````````````````XN8`````````
M``````````````#OC@``````````EI```````````````````````````*N1
M````````````````Y>8```````#DY@```````./F````````````````````
M`.OFZ>8`````YN8```````````````#HY@```````.?FZN8``)>+``#NY@``
MU9```._F``````````#7C```[.;MY@```````$B8````````M9(``$B1````
M````````````\.8`````\^8`````````````````````\>;RYGB7````````
M``"ED_;F````````````````````````````````].;UYO?F````````````
M``````````````!(YP````````````#ZY@```````/OF^>8`````````````
M``````````````````#XY@``^Y(`````0.=$YT'G_.8``$+G````````0^<`
M`````````$KG````````1><`````````````UI!'YP````!)YT;G````````
M``````````````````````````!,YP``4H\``$OG`````````````$WG````
M``````!.YP````!1YU#G``!/YP````!3YU+G``#TE@```````%7G``!4YU;G
M``````````!7YP``````````````````6><`````````````````````6.=G
MD%KG`````.N+6^==YP```````````````````````````````%[G````````
M````````7^=<YP``8.<``-2.8>=/BU*,``````````"LC```````````````
M``````!BYP```````.Z3`````%V38^<``````````````````&;G````````
M````````````````````````LHX`````9>=DYWF,9^<``````````'**``!I
MYP```````-J-:.<``''G`````````````&OG;>?CE6KG````````;.<``'#G
M;N=0BP``;^<```````````````!RYP````!YE-:7``````````!3CP``````
M`'/G``````````!!EW7G``!TYP````!XYV"7`````'?G``"-BG;G>^<`````
M>N<`````>>=1DWSG`````````````````````'WG``````````!^YP````",
MC0``1(R`YX'G@N<`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!HD(/G``"KCH3G````````
MA><```````"?F9Z9``````````"&YY#CA^=#DDJ07Y0``````````(CG````
M`-.5TI*>C0````!(D@````!)B0``F)9VD`````````````````````!]C```
M``#?BP````#4E0````````````")YP``````````````````B^<`````BN?>
MB0````#TDXSGEY0``%*3``"-YW&/````````C^<`````P):>YY'GDN<`````
MQY(`````WI&7D0``II,``)#G=(L``````````)GG``"6YZ/GIY.`DI/G``#\
MDG*3E.>8YX"0``"'E,J2`````,"0E^>LD:*1E>>GB$&8````````FN<`````
M``````````#?D0````!4CVF0`````)SGF^<``.V(G><`````3I4``*7G````
M`-F3BY``````>)(``/:+``"DYU:77HD``-65WXF?YZ#GH>>BY[F30I+AB*;G
M``"GYZ'J`````+N1``"HYP``DXEKD0``K8P``'F7`````*GG2Y,```````"8
MD=6.JN<`````K><`````A8^KYTJ129$``.*(``#)EZ_G``#PE+'GL.>NYX3B
MTHH`````CN<``+/GLN<``````````+3G``!7EP``````````````````````
M``````````````````````#?DP````!-E@``M><``->.``````````"VYP``
MM^<```````"XYP````!`DP````````````````````#HB```````````````
M``````!XC0```````%F8````````````````````````````````O.<`````
M````````4XRYYP``NN<```````"4E0``````````<XH`````````````````
M`%B7``"]BP````````````!SDP``````````O><`````````````````````
M``````````````````"^YP```````````````+_G````````````````````
M``````````````````````````````!!DP````#!YP``P.<`````````````
M`````````````````````````````````````````````-&3PN=5C]Z.>I21
MD@```````/".``",D```P^<``,3G````````````````````````?)#%YP``
MQN<```````#'YX^7``!6CP````````````#)Y\CG``!YC0``DXU?C@``````
M`````````````````,SG``````````"&CP``R^<``,KG``#GD0````#MC```
MP9```````````*Z4``````````!8CP````````````#-YP``W8\`````````
M````T.?.YP```````,_G``````````#2Y]'G`````/B/``#3YP``````````
M``#4Y]7G``````````#.E-&-WX[6YP``U^>BEV2/[);*E]CGX(L`````````
M`-GG``!"DP````#<YYB*:I```-KG``#;YP``WI(`````=);ZBP``````````
M````````````````````````WN??YP````````````#=YP````#AYP``````
M````````````````````````````W9-BB@````#EYP````#BY^3G````````
M`````````````.#G``````````````````````````!NZ`````#CYP``````
M````````````Z9<`````V(P``````````````````.WG``````````!3D^CG
M`````.OGZ><``.[G``````````#OYP```````````````.?G`````/3GE(D`
M````YN<```````"KE```ZN<``-Z/``````````````````````````!ZC0``
M`````````````````````````````&>6``#BBP````!ECP``NI,`````````
M````````````````````3)$``/+G``#LY_'G``#!E@``MI+SY_#G````````
M``````````````````````````````````!+D0``````````````````````
M`/?G``#VYP``````````````````````````````````````````````````
M`````/7G`````$Z6````````````````````````````````````````````
M`)N/``````````#XY]V5`````'.)``````````!EE9*2``````````"8BP``
M^N<``'R-````````````````````````2XX`````````````````````^>>-
MD```````````````````CI!`Z$+H`````````````/F/``!!Z$/H`````-&+
M``!DE0````#@CD*8``#\Y_:-`````%Z8`````$7H``````````!$Z$;H````
M`````````````````/OG````````````````YY,``'23````````````````
MU9(``$OH``````````!BDD?H````````2.@`````````````````````````
M````3(P``$KH````````````````KHP```````````````!)Z```WX\`````
M`````````````````````````````)F*``````````````````!/Z```O8V9
MD0````#(D@```````````````````````````````%J*``````````!-Z$[H
MP9(``$SH`````````````````````%#H````````````````````````5N@`
M`````````%GH``````````````````!8Z$R3``````````!1Z%+H5>@`````
M`````%?H````````OHL`````6NA4Z`````!3Z```````````````````````
M``````````````````````````````````````````````!>Z````````%_H
M`````````````````````&#H`````%WH7.@```````#@CZB36^@`````````
M``````!DZ````````````````````````&+H````````````````````````
M8^AAZ```]I$``&7H````````````````9N@`````:.@`````````````````
M``````````````#3BF?H^)8```````````````!SZ&GH`````&SH``!JZ```
M:^@``````````````````&WH`````````````&_H``````````!PZ```<>@`
M`````````'3H<NAUZ'?H``!VZ```````````````````````````````````
M``!`@4&!0H%6@0``6(%9@5J!<8%R@7.!=(%U@7:!=X%X@7F!>H&G@:R!:X%L
M@0```````````````&"!````````````````````````````````````````
M````````````````````````````````````````````````````````GX*@
M@J&"HH*C@J2"I8*F@J>"J(*I@JJ"JX*L@JV"KH*O@K""L8*R@K."M(*U@K:"
MMX*X@KF"NH*[@KR"O8*^@K^"P(+!@L*"PX+$@L6"QH+'@LB"R8+*@LN"S(+-
M@LZ"SX+0@M&"TH+3@M2"U8+6@M>"V(+9@MJ"VX+<@MV"WH+?@N""X8+B@N."
MY(+E@N:"YX+H@NF"ZH+K@NR"[8+N@N^"\(+Q@@``````````````````2H%+
M@52!58$`````0(-!@T*#0X-$@T6#1H-'@TB#28-*@TN#3(--@TZ#3X-0@U&#
M4H-3@U2#58-6@U>#6(-9@UJ#6X-<@UV#7H-?@V"#88-B@V.#9(-E@V:#9X-H
M@VF#:H-K@VR#;8-N@V^#<(-Q@W*#<X-T@W6#=H-W@WB#>8-Z@WN#?(-]@WZ#
M@(.!@X*#@X.$@X6#AH.'@XB#B8.*@XN#C(.-@XZ#CX.0@Y&#DH.3@Y2#E8.6
M@P``````````18%;@5*!4X$``)^$JH2@A*N$`````````````````````*&$
M`````*R$HH0`````K82DA`````"OA*.$`````*Z$I82ZA`````"UA`````"P
MA*>$O(0`````MX0`````LH2FA`````"VA+N$`````+&$J(0`````N(2]A```
M``"SA*F$`````+F$`````+Z$`````````````````````+2$````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````H8&@@0``````````````````````
M````````````````````HX&B@0````````````````````"E@:2!````````
M`````````````)^!GH$```````";@0````"=@9R!````````````````````
M````````````````````````````````````````````````````````````
M``#\@0``````````````````````````````````````````````````````
M`)J!F8$`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"*@0``B8$`````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#T@0````#S@0``\H%=@0``````````
M7(%A@0``98%F@0````!G@6B!`````/6!]H$```````!D@6.!````````````
M````````````\8$``(R!C8$``````````````````*:!````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````".@0``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/"!````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"I@:J!J(&K
M@0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#+@0``S($`````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````,V!``#=@<Z!
M````````WH&X@0````"Y@0```````````````'R!``````````````````#C
M@0````#E@8>!``#:@0```````````````,B!R8&_@;Z!YX'H@0``````````
M````````B('F@0``````````````````Y($`````````````````````````
M````````````````````````````X($`````````````````````````````
M`````(*!WX$``````````(6!AH$`````X8'B@0``````````````````````
M````````````````````````````````````O(&]@0````"Z@;N!````````
M````````````````````````````````````````````````````````````
M`````````-N!````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MW($``````````````````````````````````)^#H(.A@Z*#HX.D@Z6#IH.G
M@ZB#J8.J@ZN#K(.M@ZZ#KX,``+"#L8.R@[.#M(.U@[:#````````````````
M``"_@\"#P8/"@\.#Q(/%@\:#QX/(@\F#RH/+@\R#S8/.@\^#``#0@]&#TH/3
M@]2#U8/6@P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1H0`````````````````````
M````````````````0(1!A$*$0X1$A$6$1X1(A$F$2H1+A$R$381.A$^$4(11
MA%*$4X14A%6$5H17A%B$681:A%N$7(1=A%Z$7X1@A'"$<81RA'.$=(1UA'>$
M>(1YA'J$>X1\A'V$?H2`A(&$@H2#A(2$A82&A(>$B(2)A(J$BX2,A(V$CH2/
MA)"$D80``':$````````````````````````````````````````7X$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"1
M@9*!````````F(%.@0```````,J!````````BX%]@0````!,@0``]X$`````
M````````````````````````````````````````````````````````````
M````````````````````?H$`````````````````````````````````````
M`````````````````````````````````````````````("!```````````^
M;Q-O]VZ&;WIO>&^!;X!O;V];;_-O;6^";WQO6&^.;Y%OPF]F;[-OHV^A;Z1O
MN6_&;ZIOWV_5;^QOU&_8;_%O[F_;;PEP"W#Z;Q%P`7`/</YO&W`:<'1O'7`8
M<!]P,'`^<#)P47!C<)EPDG"O</%PK'"X<+-PKG#?<,MPW7```-EP"7']<!QQ
M&7%E<55QB'%F<6)Q3'%6<6QQCW'[<81QE7&H<:QQUW&Y<;YQTG')<=1QSG'@
M<>QQYW'U<?QQ^7'_<0UR$'(;<BAR+7(L<C!R,G([<CQR/W)`<D9R2W)8<G1R
M?G*"<H%RAW*2<I9RHG*G<KERLG+#<L9RQ'+.<M)RXG+@<N%R^7+W<@]0%W,*
M<QQS%G,=<S1S+W,I<R5S/G-.<T]SV)Y7<VIS:'-P<WAS=7-[<WISR'.S<\YS
MNW/`<^5S[G/><Z)T!71O="5T^',R=#IT570_=%]T671!=%QT:71P=&-T:G1V
M='YTBW2>=*=TRG3/=-1T\7,`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````.!TXW3G=.ET[G3R=/!T\73X=/=T!'4#=05U#'4.
M=0UU%743=1YU)G4L=3QU1'5-=4IU275;=49U6G5I=61U9W5K=6UU>'5V=89U
MAW5T=8IUB76"=91UFG6==:5UHW7"=;-UPW6U=;UUN'6\=;%US77*==)UV77C
M==YU_G7_=0``_'4!=O!U^G7R=?-U"W8-=@EV'W8G=B!V(78B=B1V-'8P=CMV
M1W9(=D9V7'98=F%V8G9H=FEV:G9G=FQV<'9R=G9V>'9\=H!V@W:(=HMVCG:6
M=I-VF7::=K!VM':X=KEVNG;"=LUVUG;2=MYVX7;E=N=VZG8OAOMV"'<'=P1W
M*7<D=QYW)7<F=QMW-W<X=T=W6G=H=VMW6W=E=W]W?G=Y=XYWBW>1=Z!WGG>P
M=[9WN7>_=[QWO7>[=\=WS7?7=]IWW'?C=^YW_'<,>!)X)GD@>"IY17B.>'1X
MAGA\>)IXC'BC>+5XJGBO>-%XQGC+>-1XOGB\>,5XRGCL>```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````YWC:>/UX]'@'>1)Y
M$7D9>2QY*WE`>6!Y5WE?>5IY57E3>7IY?WF*>9UYIWE+GZIYKGFS>;EYNGG)
M>=5YYWGL>>%YXWD(>@UZ&'H9>B!Z'WJ`>3%Z.WH^>C=Z0WI7>DEZ87IB>FEZ
MG9]P>GEZ?7J(>I=ZE7J8>I9ZJ7K(>K!Z``"V>L5ZQ'J_>H.0QWK*>LUZSWK5
M>M-ZV7K:>MUZX7KB>N9Z[7KP>@)[#WL*>P9[,WL8>QE['GLU>RA[-GM0>WI[
M!'M->PM[3'M%>W5[97MT>V=[<'MQ>VQ[;GN=>YA[GWN->YQ[FGN+>Y)[CWM=
M>YE[RWO!>\Q[SWNT>\9[W7OI>Q%\%'SF>^5[8'P`?`=\$WSS>_=[%WP-?/9[
M(WPG?"I\'WPW?"M\/7Q,?$-\5'Q/?$!\4'Q8?%]\9'Q6?&5\;'QU?(-\D'RD
M?*U\HGRK?*%\J'RS?+)\L7RN?+E\O7S`?,5\PGS8?-)\W'SB?#N;[WSR?/1\
M]GSZ?`9]````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````"?1Q]%7T*?45]2WTN?3)]/WTU?49]<WU6?4Y]<GUH?6Y]3WUC?9-]
MB7U;?8]]?7V;?;I]KGVC?;5]QWV]?:M]/7ZB?:]]W'VX?9]]L'W8?=U]Y'W>
M??M]\GWA?05^"GXC?B%^$GXQ?A]^"7X+?B)^1GYF?CM^-7XY?D-^-WX``#)^
M.GYG?EU^5GY>?EE^6GYY?FI^:7Y\?GM^@W[5?7U^KH]_?HA^B7Z,?I)^D'Z3
M?I1^EGZ.?IM^G'XX?SI_17],?TU_3G]0?U%_57]4?UA_7W]@?VA_:7]G?WA_
M@G^&?X-_B'^'?XQ_E'^>?YU_FG^C?Z]_LG^Y?ZY_MG^X?W&+Q7_&?\I_U7_4
M?^%_YG_I?_-_^7_<F`:`!(`+@!*`&(`9@!R`(8`H@#^`.X!*@$:`4H!8@%J`
M7X!B@&B`<X!R@'"`=H!Y@'V`?X"$@(:`A8";@).`FH"M@)!1K(#;@.6`V8#=
M@,2`VH#6@`F![X#Q@!N!*8$C@2^!2X$`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(N61H$^@5.!48'\@'&!;H%E@6:!=(&#
M@8B!BH&`@8*!H(&5@:2!HX%?@9.!J8&P@;6!OH&X@;V!P('"@;J!R8'-@=&!
MV8'8@<B!VH'?@>"!YX'Z@?N!_H$!@@*"!8('@@J"#8(0@A:"*8(K@CB",X)`
M@EF"6()=@EJ"7X)D@@``8H)H@FJ":X(N@G&"=X)X@GZ"C8*2@JN"GX*[@JR"
MX8+C@M^"TH+T@O."^H*3@P.#^X+Y@MZ"!H/<@@F#V8(U@S2#%H,R@S&#0(,Y
M@U"#18,O@RN#%X,8@X6#FH.J@Y^#HH.6@R.#CH.'@XJ#?(.U@W.#=8.@@XF#
MJ(/T@Q.$ZX/.@_V#`X38@PN$P8/W@P>$X(/R@PV$(H0@A+V#.(0&A?N#;80J
MA#R$6H6$A'>$:X2MA&Z$@H1IA$:$+(1OA'F$-83*A&*$N82_A)^$V83-A+N$
MVH30A,&$QH36A*&$(87_A/2$%X48A2R%'X45A12%_(1`A6.%6(5(A0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````084"ADN%
M586`A:2%B(61A8J%J(5MA92%FX7JA8>%G(5WA7Z%D(7)A;J%SX6YA="%U87=
MA>6%W(7YA0J&$X8+AOZ%^H4&AB*&&H8PAC^&38953E2&7X9GAG&&DX:CAJF&
MJH:+AHR&MH:OAL2&QH:PALF&(XBKAM2&WH;IANR&``#?AMN&[X82AP:'"(<`
MAP.'^X81APF'#8?YA@J'-(<_AS>'.X<EARF'&H=@AU^'>(=,ATZ'=(=7AVB'
M;H=9AU.'8X=JAP6(HH>?AX*'KX?+A[V'P(?0A]:6JX?$A[.'QX?&A[N'[X?R
MA^"'#X@-B/Z']H?WAPZ(TH<1B!:(%8@BB"&(,8@VB#F()X@[B$2(0HA2B%F(
M7HABB&N(@8A^B)Z(=8A]B+6(<HB"B)>(DHBNB)F(HHB-B*2(L(B_B+&(PXC$
MB-2(V(C9B-V(^8@"B?R(](CHB/*(!(D,B0J)$XE#B1Z))8DJB2N)08E$B3N)
M-HDXB4R)'8E@B5Z)````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!FB62);8EJB6^)=(EWB7Z)@XF(B8J)DXF8B:&)J8FFB:R)
MKXFRB;J)O8F_B<")VHG<B=V)YXGTB?B)`XH6BA"*#(H;BAV*)8HVBD&*6XI2
MBD:*2(I\BFV*;(IBBH6*@HJ$BJB*H8J1BJ6*IHJ:BJ.*Q(K-BL**VHKKBO.*
MYXH``.2*\8H4B^"*XHKWBMZ*VXH,BP>+&HOABA:+$(L7BR"+,XNKER:+*XL^
MBRB+08M,BT^+3HM)BU:+6XM:BVN+7XMLBV^+=(M]BX"+C(N.BY*+DXN6BYF+
MFHLZC$&,/XQ(C$R,3HQ0C%6,8HQLC'B,>HR"C(F,A8R*C(V,CHR4C'R,F(P=
M8JV,JHR]C+*,LXRNC+:,R(S!C.2,XXS:C/V,^HS[C`2-!8T*C0>-#XT-C1"-
M3I\3C<V,%(T6C6>-;8UQC7.-@8V9C<*-OHVZC<^-VHW6C<R-VXW+C>J-ZXW?
MC>.-_(T(C@F._XT=CAZ.$(X?CD*.-8XPCC2.2HX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$>.28Y,CE".2(Y9CF2.8(XJ
MCF..58YVCG*.?(Z!CH>.A8Z$CHN.BHZ3CI&.E(Z9CJJ.H8ZLCK".QHZQCKZ.
MQ8[(CLN.VX[CCOR.^X[KCOZ."H\%CQ6/$H\9CQ./'(\?CQN/#(\FCS./.X\Y
MCT6/0H\^CTR/28]&CTZ/5X]<CP``8H]CCV2/G(^?CZ./K8^OC[>/VH_EC^*/
MZH_OCX>0](\%D/F/^H\1D!60(9`-D!Z0%I`+D">0-I`UD#F0^(]/D%"049!2
MD`Z029`^D%:06)!>D&B0;Y!VD*B6<I""D'V0@9"`D(J0B9"/D*B0KY"QD+60
MXI#DD$ABVY`"D1*1&9$RD3"12I%6D5B18Y%ED6F1<Y%RD8N1B9&"D:*1JY&O
MD:J1M9&TD;J1P)'!D<F1RY'0D=:1WY'AD=N1_)'UD?:1'I+_D122+)(5DA&2
M7I)7DD6229)DDDB2E9(_DDN24)*<DI:2DY*;DEJ2SY*YDK>2Z9(/D_J21),N
MDP``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M&9,BDQJ3(Y,ZDS63.Y-<DV"3?)-NDU:3L).LDZV3E).YD]:3UY/HD^63V)/#
MD]V3T)/(D^23&I04E!.4`Y0'E!"4-I0KE#64(90ZE$&44I1$E%N48)1BE%Z4
M:I0IDG"4=91WE'V46I1\E'Z4@91_E(*5AY6*E925EI68E9F5``"@E:B5IY6M
ME;R5NY6YE;Z5RI7V;\.5S97,E=65U)76E=R5X97EE>*5(98HEBZ6+Y9"EDR6
M3Y9+EG>67)9>EEV67Y9FEG*6;):-EIB6E9:7EJJ6IY:QEK*6L):TEK:6N):Y
MELZ6RY;)ELV638G<E@V7U9;YE@27!I<(EQ.7#I<1EP^7%I<9ER27*I<PESF7
M/9<^ET271I=(ET*729=<EV"79)=FEVB7TE)KEW&7>9>%EWR7@9=ZEX:7BY>/
MEY"7G)>HEZ:7HY>SE[27PY?&E\B7RY?<E^V73Y_RE]]Z]I?UEP^8#)@XF"28
M(9@WF#V81IA/F$N8:YAOF'"8````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!QF'28<YBJF*^8L9BVF,28PYC&F.F8ZY@#F0F9
M$ID4F1B9(9D=F1Z9))D@F2R9+ID]F3Z90IE)F4694)E+F5&94IE,F569EYF8
MF:69K9FNF;R9WYG;F=V9V)G1F>V9[IGQF?*9^YGXF0&:#YH%FN*9&9HKFC>:
M19I"FD":0YH``#Z:59I-FEN:5YI?FF*:99IDFFF::YIJFJV:L)J\FL":SYK1
MFM.:U)K>FM^:XIKCFN::[YKKFNZ:])KQFO>:^YH&FQB;&IL?FR*;(YLEFR>;
M*)LIFRJ;+ILOFS*;1)M#FT^;39M.FU&;6)MTFY.;@YN1FY:;EYN?FZ";J)NT
MF\";RINYF\:;SYO1F]*;XYOBF^2;U)OAFSJ<\IOQF_";%9P4G`F<$YP,G`:<
M")P2G`J<!)PNG!N<)9PDG"&<,)Q'G#*<1IP^G%J<8)QGG':<>)SGG.R<\)P)
MG0B=ZYP#G0:=*ITFG:^=(YT?G42=%9T2G4&=/YT^G4:=2)T`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````%V=7IUDG5&=4)U9
MG7*=B9V'G:N=;YUZG9J=I)VIG;*=Q)W!G;N=N)VZG<:=SYW"G=F=TYWXG>:=
M[9WOG?V=&IX;GAZ>=9YYGGV>@9Z(GHN>C)Z2GI6>D9Z=GJ6>J9ZXGJJ>K9YA
ME\R>SI[/GM">U)[<GMZ>W9[@GN6>Z)[OG@``])[VGO>>^9[[GOR>_9X'GPB?
MMW85GR&?+)\^GTJ?4I]4GV.?7Y]@GV&?9I]GGVR?:I]WGW*?=I^5GYR?H)\O
M6,=I69!D=-Q1F7$`````````````````````````````G$X650-:/Y;`5!MA
M*&/V62*0=80<@U!ZJF#A8R5N[65FA*:"]9N3:"=7H65Q8IM;T%E[AO288GV^
M?8Z;%F*??+>(B5NU7@ECEV9(:,>5C9=/9^5."D]-3YU/25#R5C=9U%D!6@E<
MWV`/87!A$V8%:;IP3W5P=?MYK7WO?<.`#H1CB`*+59!ZD#M3E4ZE3M]7LH#!
MD.]X`$[Q6*)N.)`R>BB#BX(OG$%1<%.]5.%4X%;[615?\ICK;>2`+84`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````&*6<):@
MEON7"U3S4X=;SW"]?\*/Z)9O4UR=NGH13I-X_($F;AA6!%4=:QJ%.YSE6:E3
M9FW<=(^50E:13DN0\I9/@PR9X5.V53!;<5\@9O-F!&@X;/-L*6U;=,AV3GHT
MF/&"6XA@BNV2LFVK=<IVQ9FF8`&+BHVRE8YIK5.&40``$E<P6$19M%OV7BA@
MJ6/T8[]L%&^.<!1Q67'5<3]S`7YV@M&"EX5@D%N2&YUI6+QE6FPE=?E1+EEE
M68!?W%^\8OIE*FHG:[1KBW/!?U:)+)T.G<2>H5R6;'N#!%%+7+9AQH%V:&%R
M64[Z3WA3:6`I;D]Z\Y<+3A93[DY53SU/H4]S3Z!2[U,)5@]9P5JV6^%;T7F'
M9IQGMF=,:[-L:W#"<XUYOGD\>H=[L8+;@@2#=X/O@].#9H>RBBE6J(SFCTZ0
M'I>*AL1/Z%P18EER.W7E@;V"_H;`C,66$YG5F<M.&D_CB=Y62EC*6/M>ZU\J
M8)1@8F#081)BT&(Y90``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````09MF9K!H=VUP<$QUAG9U?:6"^8>+E8Z6G8SQ4;Y2%EFS
M5+-;%EUH88)IKVV->,N$5XARBJ>3N)IL;:B9V8:C5_]GSH8.DH-2AU8$5-->
MX6*Y9#QH.&B[:W)SNGAK>IJ)THEKC0./[9"CE926:9=F6[-<?6E-F$Z8FV,@
M>RMJ``!_:K9H#9Q?;W)2G55P8.QB.VT';M%N6X00B42/%$XYG/93&VDZ:H27
M*FA<4<-ZLH3<D8R36U8HG2)H!8,QA*5\"%+%@N9T?DZ#3Z!1TEL*4MA2YU+[
M79I5*ECF68Q;F%O;6W)>>5ZC8!]A8V&^8=MC8F719U-H^F@^:U-K5VPB;Y=O
M16^P=!AUXW8+=_]ZH7LA?.E]-G_P?YV`9H*>@[.)S(JKC(204923E9&5HI5E
MEM.7*)D8@CA.*U2X7,Q=J7-,=CQWJ5SK?PN-P981F%286)@!3PY/<5.<56A6
M^E='60E;Q%N07`Q>?E[,7^YC.F?79>)E'V?+:,1H````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!?:C!>Q6L7;'UL?W5(>6-;
M`'H`?;U?CXD8BK2,=XW,CAV/XI@.FCR;@$Y]4`!1DUF<6R]B@&+L9#IKH'*1
M=4=YJ7_[A[R*<(NL8\J#H)<)5`-4JU54:%AJ<(HG>'5GS9YT4Z);&H%0A@:0
M&$Y%3L=.$4_*4SA4KEL37R5@464``#UG0FQR;.-L>'`#='9ZKGH(>QI]_GQF
M?>=E6W*[4T5<Z%W28N!B&6,@;EJ&,8K=C?B2`6^F>5J;J$ZK3JQ.FT^@3]%0
M1U'V>G%1]E%44R%3?U/K4ZQ5@UCA7#=?2E\O8%!@;6`?8UEE2VK!;,)R[7+O
M=_B`!8$(@DZ%]Y#AD_^75YE:FO!.W5$M7(%F;6E`7/)F=6F)<U!H@7S%4.12
M1U?^72:3I&4C:SUK-'2!>;UY2WO*?;F"S(-_B%^).8O1C]&1'U2`DEU.-E#E
M4SI3UW*6<^EWYH*OCL:9R)G2F7=1&F%>AK!5>GIV4--;1Y"%EC).VVKGD5%<
M2%P`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`)ACGWJ3;'2788^J>HIQB):"?!=H<'Y1:&R3\E(;5*N%$XJD?\V.X9!F4XB(
M07G"3[Y0$5)$45-5+5?J<XM745EB7X1?=6!V86=AJ6&R8SID;&5O9D)H$VYF
M=3UZ^WQ,?9E]2WYK?PZ#2H/-A@B*8XIFB_V.&IB/G;B"SH_HFP``AU(?8H-D
MP&^9ED%HD5`@:WIL5&]T>E!]0(@CB@AG]DXY4"9095!\43A28U*G50]7!5C,
M6OI>LF'X8?-B<F,<:2EJ?7*L<BYS%'AO>'E]#'>I@(N)&8OBC-*.8Y!UDWJ6
M59@3FGB>0U&?4[-3>UXF7QMND&Z$<_YS0WTW@@"*^HI0EDY."U#D4WQ4^E;1
M661;\5VK7B=?.&)%9:]G5F[0<LI\M(BA@.&`\(-.AH>*Z(TWDL>69Y@3GY1.
MDDX-3TA3250^5"]:C%^A7Y]@IVB.:EIT@7B>BJ2*=XN0D5Y.R9ND3GQ/KT\9
M4!9025%L49]2N5+^4II3XU,15```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````#E2)55%7HE=]651;75N/6^5=YUWW77A>@UZ:
M7K=>&%]28$QAEV+88J=C.V4"9D-F]&9M9R%HEVC+:5]L*FUI;2]NG6XR=8=V
M;'@_>N!\!7T8?5Y]L7T5@`.`KX"Q@%2!CX$J@E*#3(AAB!N+HHS\C,J0=9%Q
MDC]X_)*DE4V6```%F)F9V)H[G5M2JU+W4PA4U5CW8N!O:HQ?C[F>2U$[4DI4
M_59`>G>18)W2GD1S"6]P@1%U_5_:8*B:VW*\CV1K`YC*3O!69%>^6%I::&#'
M80]F!F8Y:+%H]VW5=3I];H)"FYM.4$_)4P95;UWF7>Y=^V>9;'-T`GA0BI:3
MWXA05Z=>*V.U4*Q0C5$`9\E47EB[6;!;:5]-8J%C/6AS:PAN?7#'D8!R%7@F
M>&UYCF4P?=R#P8@)CYN69%(H5U!G:G^AC+110E<JECI8BFFT@+)4#EW\5Y5X
M^IU<3TI2BU0^9"AF%&?U9X1Z5GLB?2^37&BMFSE[&5.*43=2````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#?6_9BKF3F9"UG
MNFNIA=&6D';6FTQC!I.KF[]V4F8)3IA0PE-Q7.A@DF1C95]HYG'*<R-UEWN"
M?I6&@XO;C'B1$)FL9:MFBVO53M1..D]_3SI2^%/R4^-5VU;K6,M9R5G_65!;
M35P"7BM>UU\=8`=C+V5<6Z]EO67H99UG8FL``'MK#VQ%<TEYP7GX?!E]*WVB
M@`*!\X&6B5Z*:8IFBHR*[HK'C-R,S);\F&]KBTX\3XU/4%%76_I;2&$!8T)F
M(6O+;KML/G*]=-1UP7@Z>0R`,X#J@92$GH]0;'^>#U]8BRN=^GKXCHU;ZY8#
M3O%3]U<Q6<E:I%N)8']N!F^^=>J,GUL`A>![<E#T9YV"85Q*A1Y^#H*9401<
M:&-FC9QE;G$^>1=]!8`=B\J.;I#'AJJ0'U#Z4CI<4V=\<#5R3)'(D2N3Y8+"
M6S%?^6`[3M93B%M+8C%GBFOI<N!S+GIK@:.-4I&6F1)1UU-J5/];B&,Y:JQ]
M`)?:5LY3:%0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````)=;,5S>7>Y/`6'^8C)MP'G+>4)]37[2?^V!'X*0A$:(<HF0BW2.
M+X\QD$N1;)'&EIR1P$Y/3T5105.37PYBU&=!;`MN8W,F?LV1@Y+44QE9OUO1
M;5UY+GZ;?'Y8GW'Z45.(\(_*3_M<)6:L=^-Z'(+_F<91JE_L96]IB6OS;0``
MEFYD;_YV%'WA7760AY$&F.91'5)`8I%FV68:;K9>TGUR?_AFKX7WA?B*J5+9
M4W-9CUZ07U5@Y))DEK=0'U'=4B!31U/L4^A41E4Q51=6:%F^63Q:M5L&7`]<
M$5P:7(1>BE[@7G!??V*$8MMBC&-W8P=F#&8M9G9F?F>B:!]J-6J\;(AM"6Y8
M;CQQ)G%G<<=U`7==>`%Y97GP>>!Z$7NG?#E]EH#6@XN$285=B/.('XH\BE2*
M<XIAC-Z,I)%FDGZ3&)2<EIB7"DX(3AY.5TZ747!2SE<T6,Q8(ELX7L5@_F1A
M9U9G1&VV<G-U8WJXA'*+N)$@DS%6]%?^F```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````[6(-:99K[7%4?G>`<H+FB=^858>Q
MCSM<.$_A3[5/!U4@6MU;Z5O#7TYA+V.P94MF[FB;:7AM\6TS=;EU'W=>>>9Y
M,WWC@:^"JH6JB3J*JXZ;CS*0W9$'E[I.P4X#4G58[%@+7!IU/5Q.@0J*Q8]C
MEFV7)7O/B@B88I'S5JA3```7D#E4@E<E7JAC-&R*<&%WBWS@?W"(0I!4D1"3
M&)./EEYTQ)H'76E=<&6B9ZB-VY9N8TEG&6G%@Q>8P);^B(1O>F3X6Q9.+'!=
M=2]FQ%$V4N)2TUF!7R=@$&(_971E'V9T9O)H%FAC:P5N<G(?==MVOGQ6@/!8
M_8A_B:"*DXK+BAV0DI%2EUF7B64.>@:!NY8M7MQ@&F*E911FD&?S=TUZ37P^
M?@J!K(QDC>&-7XZI>`=2V6*E8T)DF&(MBH-ZP'NLBNJ6=GT,@DF'V4Y(44-3
M8%.C6P)<%ES=729B1V*P9!-H-&C);$5M%VW39UQO3G%]<<ME?WJM>]I]````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!*?JA_
M>H$;@CF"IH5NBLZ,]8UXD'>0K9*1DH.5KIM-4H15.&\V<6A1A7E5?K.!SGQ,
M5E%8J%RJ8_YF_69::=ERCW6.=0YY5GG?>9=\('U$?0>&-(H[EF&0()_G4'52
MS%/B4PE0JE7N6$]9/7*+6V1<'5/C8/-@7&.#8S]CNV,``,UDZ67Y9N-=S6G]
M:15OY7&)3NEU^':3>M]\SWV<?6&`28-8@VR$O(3[A<6(<(T!D&V0EY,<EQ*:
MSU"76(YATX$UA0B-()##3W101U)S4V]@26-?9RQNLXT?D-=/7ES*C,]EFGU2
M4Y:(=E'#8UA;:UL*7`UD46=<D-9.&EDJ67!L48H^5158I5GP8%-BP6<U@E5I
M0);$F2B:4T\&6/Y;$("Q7"]>A5\@8$MA-&+_9O!LWF[.@'^!U(*+B+B,`)`N
MD(J6VY[;F^-.\%,G62Q[C9%,F/F=W6XG<%-31%6%6UABGF+38J)L[V\B=!>*
M.)3!;_Z*.(/G4?B&ZE,`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````.E31D]4D+"/:EDQ@?U=ZGJ_C]IH-XSX<DB</6JPBCE.
M6%,&5F97Q6*B8^9E3FOA;5MNK7#M=^]ZJGN[?3V`QH#+AI6*6Y/C5L=8/E^M
M999F@&JU:S=UQXHD4.5W,%<;7V5@>F9@;/1U&GIN?_2!&(=%D+.9R7M<=?EZ
M47O$A```$)#I>9)Z-H/A6D!W+4[R3IE;X%^]8CQF\6?H;&N&=X@[BDZ1\Y+0
MF1=J)G`J<^>"5X2OC`%.1E'+48M5]5L67C->@5X47S5?:U^T7_)A$6.B9AUG
M;F]2<CIU.G=T@#F!>(%VA[^*W(J%C?.-FI)WE0*8Y9S%4E=C]'859XALS7/#
MC*Z3<Y8E;9Q8#FG,:?V/FI/;=1J06E@":+1C^VE#3RQOV&>[CR:%M'U4DS]I
M<&]J5_=8+%LL?2IR"E3CD;2=K4Y.3UQ0=5!#4IZ,2%0D6)I;'5Z57JU>]UX?
M7XQ@M6(Z8]!CKVA`;(=XCGD+>N!]1X("BN:*1(X3D```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````N)`MD=B1#I_E;%ADXF1U
M9?1NA'8;>VF0T9.Z;O)4N5^D9$V/[8]$DGA1:U@I655<EU[[;8]^''6\C.*.
M6YBY<!U/OVNQ;S!U^Y9.41!4-5A76*Q98%R27Y=E7&<A;GMVWX/MC!20_9!-
MDR5X.GBJ4J9>'U=T61)@$E!:4:Q1``#-40!2$%546%A85UF56_9<BUV\8)5B
M+61Q9T-HO&C?:-=VV&UO;IMM;W#(<5-?V'5W>4E[5'M2>]9\<7TP4F.$:87D
MA0Z*!(M&C`^.`Y`/D!F4=I8MF#":V)7-4-52#%0"6`Y<IV&>9!YMLW?E>O2`
M!(13D(62X%P'G3]3EU^S7YQM>7)C=[]YY'O2:^QRK8H#:&%J^%&!>C1I2ESV
MG.N"Q5M)D1YP>%9O7,=@9F6,;%J,09`3F%%4QV8-DDA9HY"%44U.ZE&9A0Z+
M6'!Z8TN38FFTF01^=W574V!IWX[CEEULC$X\7!!?Z8\"4]&,B8!YAO]>Y65S
M3F51````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``""63]<[I?[3HI9S5^-BN%OL'EB>>=;<80K<[%Q=%[U7WMCFF3#<9A\0T[\
M7DM.W%>B5JE@PV\-??V`,X&_@;*/EXFDAO1=BF*M9(>)=V?B;#YM-G0T>$9:
M=7^M@JR9\T_#7MUBDF-796]GPW9,<LR`NH`ICTV1#5#Y5Y):A6@``'-I9'']
M<K>,\EC@C&J6&9!_A^1YYW<IA"]/95):4\UBSV?*;'UVE'N5?#:"A(7KC]UF
M(&\&<AM^JX/!F::>_5&Q>W)XN'N'@$A[Z&IA7HR`475@=6M18I*,;GIVEY'J
MFA!/<'^<8D][I97IG'I665CDAKR6-$\D4DI3S5/;4P9>+&2197]G/FQ.;$AR
MKW+M<U1U07XL@NF%J8S$>\:1:7$2F.^8/6-I9FIUY';0>$.%[H8J4U%3)E2#
M68=>?%^R8$EB>6*K8I!EU&O,;+)UKG:1>-AYRWUW?Z6`JXBYBKN,?Y!>E]N8
M"VHX?)E0/ERN7X=GV&LU=`EWCG\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#N?RF<7>CE3BW7MFF9?G8'Q@YB`/%_%7V)U
M1GL\D&=HZUF;6A!]?G8LB_5/:E\9:C=L`F_B=&AY:(A5BGF,WU[/8\5UTGG7
M@BB3\I*<A.V&+9S!5&Q?C&5<;15PIXS3C#N83V7V=`U.V$[@5RM99EK,6ZA1
M`UZ<7A9@=F)W90``IV5N9FYM-G(F>U"!FH&9@ER+H(SFC'2-')9$EJY/JV1F
M:QZ"881JA>B0`5Q3::B8>H17A0]/;U*I7T5>#6>/>7F!!XF&B?5M%U]58KAL
MSTYI<I*;!E([5'16LUBD86YB&G%N68E\WGP;??"6AV5>@!E.=4]U44!88UYS
M7@I?Q&<F3CV%B95;EG-\`9C[4,%85G:G>"52I7<1A89[3U`)64=RQWOH?;J/
MU(]-D+]/R5(I6@%?K9?=3Q>"ZI(#5U5C:6LK==R(%(]">M]2DUA580IBKF;-
M:S]\Z8,C4/A/!5-&5#%825F=6_!<[UPI799>L6)G8SYEN64+9P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````U6SA;/EP,G@K
M?MZ`LX(,A.R$`H<2B2J*2HRFD-*2_9CSG&R=3TZA3HU05E)*5ZA9/5[87]E?
M/V*T9AMGT&?2:))1(7VJ@*B!`(N,C+^,?I(REB!4+)@74]507%.H6+)D-&=G
M<F9W1GKFD<-2H6R&:P!83%Y462QG^W_A4<9V``!I9.AX5)N[GLM7N5DG9IIG
MSFOI5-EI55Z<@95GJIO^9U*<76BF3N-/R%.Y8BMGJVS$CZU/;7Z_G@=.8F&`
M;BMO$X5S5"IG19OS795[K%S&6QR'2F[1A!1Z"(&968U\$6P@=]E2(EDA<5]R
MVW<GEV&="VE_6AA:I5$-5'U4#F;?=O>/F)+TG.I977+%;DU1R6B_?>Q]8I>Z
MGGAD(6H"@X197UO;:QMS\G:R?1>`F80R42AGV9[N=F)G_U(%F21<.V)^?+",
M3U6V8`M]@)4!4U].ME$<63IR-H#.D25?XG>$4WE?!'VLA3.*C8Y6E_-GKH53
ME`EA"&&Y;%)V````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#MBCB/+U513RI1QU++4Z5;?5Z@8()AUF,)9]IG9VZ,;39S-W,Q
M=5!YU8B8BDJ0D9#UD,26C8<568A.64\.3HF*/X\0F*U0?%Z66;E;N%[:8_IC
MP63<9DIIV&D+;;9NE'$H=:]ZBG\`@$F$R82!B2&+"HYED'V6"IE^89%B,FL`
M`(-L=&W,?_Q_P&V%?[J'^(AE9[&#/)CWEAMM87T]A&J1<4YU4U!=!&OK;\V%
M+8:GB2E2#U1E7$YGJ&@&=(-TXG7/B.&(S)'BEGB6BU^'<\MZ3H2@8V5UB5)!
M;9QN"719=6MXDGR&EMQZC9^V3VYAQ65<AH9.KD[:4"%.S%'N6YEE@6B\;1]S
M0G:M=QQZYWQO@M**?)#/D766&)B;4M%]*U"84Y=GRVW0<3-TZ($JCZ.65YR?
MGF!T05B9;2]]7ICD3C9/BT^W4;%2NET<8+)S/'G3@C22MY;VE@J7EYYBGZ9F
M=&L74J-2R'#"B,E>2V"082-O27$^?/1];X``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````.Z$(Y`LDT)4;YO3:HEPPHSOC3*7
MM%)!6LI>!%\79WQIE&EJ;0]O8G+\<NU[`8!^@$N'SI!M49.>A'F+@#*3UHHM
M4(Q4<8IJ:\2,!X'18*!G\IV93IA.$)QKBL&%:(4`:7YNEWA5@0``````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````,7Q!.%4XJ3C%.
M-DX\3C].0DY63EA.@DZ%3FN,BDX2@@U?CDZ>3I].H$ZB3K!.LTZV3LY.S4[$
M3L9.PD[73MY.[4[?3O=."4]:3S!/6T]=3U=/1T]V3XA/CT^83WM/:4]P3Y%/
M;T^&3Y9/&%'43]]/SD_83]M/T4_:3]!/Y$_E3QI0*%`44"I0)5`%4!Q/]D\A
M4"E0+%#^3^]/$5`&4$-01U`#9U504%!(4%I05E!L4'A0@%":4(50M%"R4```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````R5#*
M4+-0PE#64-Y0Y5#M4.-0[E#Y4/50"5$!40)1%E$54111&E$A43I1-U$\43M1
M/U%`45)13%%446)1^'II46I1;E&`48)1V%:,48E1CU&149-1E5&64:11IE&B
M4:E1JE&K4;-1L5&R4;!1M5&]4<51R5';4>!158;I4>U1``#P4?51_E$$4@M2
M%%(.4B=2*E(N4C-2.5)/4D122U),4EY25%)J4G12:5)S4G]2?5*-4I12DE)Q
M4HA2D5*HCZ>/K%*M4KQ2M5+!4LU2UU+>4N-2YE+MF.!2\U+U4OA2^5(&4PA3
M.'4-4Q!3#U,54QI3(U,O4S%3,U,X4T!31E-%4Q=.25--4]917E-I4VY3&%E[
M4W=3@E.64Z!3IE.E4ZY3L%.V4\-3$GS9EM]3_&;N<>Y3Z%/M4_I3`50]5$!4
M+%0M5#Q4+E0V5"E4'51.5(]4=52.5%]4<51W5'!4DE1[5(!4=E2$5)!4AE3'
M5*)4N%2E5*Q4Q%3(5*A4````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"K5,)4I%2^5+Q4V%3E5.94#U445?U4[E3M5/I4XE0Y
M54!58U5,52Y57%5%55955U4X53-5756958!5KU2*59]5>U5^59A5GE6N57Q5
M@U6I58=5J%7:5<55WU7$5=Q5Y%745116]U465OY5_54;5OE53E905M]Q-%8V
M5C)6.%8``&M69%8O5FQ6:E:&5H!6BE:@5I16CU:E5JY6ME:T5L)6O%;!5L-6
MP%;(5LY6T5;35M=6[E;Y5@!7_U8$5PE7"%<+5PU7$U<85Q97QU4<5R97-U<X
M5TY7.U=`5T]7:5?`5XA785=_5XE7DU>@5[-7I%>J5[!7PU?&5]17TE?35PI8
MUE?C5PM8&5@=6')8(5AB6$M8<%C`:U)8/5AY6(58N5B?6*M8NEC>6+M8N%BN
M6,58TUC16-=8V5C86.58W%CD6-]8[UCZ6/E8^UC\6/U8`ED*61!9&UFF:"59
M+%DM63)9.%D^6=)Z55E064Y96EE866)98%EG66Q9:5D`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'A9@5F=65Y/JT^C6;)9
MQEGH6=Q9C5G96=I9)5H?6A%:'%H)6AI:0%IL6DE:-5HV6F)::EJ:6KQ:OEK+
M6L):O5KC6M=:YEKI6M9:^EK[6@Q;"UL66S);T%HJ6S9;/EM#6T5;0%M16U5;
M6EM;6V5;:5MP6W-;=5MX6XAE>EN`6P``@UNF6[A;PUO'6\E;U%O06^1;YEOB
M6]Y;Y5OK6_!;]EOS6P5<!UP(7`U<$UP@7")<*%PX7#E<05Q&7$Y<4UQ07$]<
M<5ML7&Y<8DYV7'E<C%R17)1<FUFK7+M<MER\7+=<Q5R^7,=<V5SI7/U<^ESM
M7(Q=ZEP+715=%UU<71]=&UT1711=(ET:71E=&%U,75)=3EU+76Q=<UUV78==
MA%V"7:)=G5VL7:Y=O5V07;==O%W)7<U=TUW27=9=VUWK7?)=]5T+7AI>&5X1
M7AM>-EXW7D1>0UY`7DY>5UY47E]>8EYD7D=>=5YV7GI>O)Y_7J!>P5["7LA>
MT%[/7@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````UE[C7MU>VE[;7N)>X5[H7NE>[%[Q7O->\%[T7OA>_EX#7PE?75]<7PM?
M$5\67RE?+5\X7T%?2%],7TY?+U]17U9?5U]97V%?;5]S7W=?@U^"7W]?BE^(
M7Y%?AU^>7YE?F%^@7ZA?K5^\7]9?^U_D7_A?\5_=7[-@_U\A8&!@```98!!@
M*6`.8#%@&V`58"M@)F`/8#I@6F!!8&I@=V!?8$I@1F!-8&-@0V!D8$)@;&!K
M8%E@@6"-8.=@@V":8(1@FV"68)=@DF"G8(M@X6"X8.!@TV"T8/!?O6#&8+5@
MV&!-815A!F'V8/=@`&'T8/I@`V$A8?M@\6`-80YA1V$^82AA)V%*83]A/&$L
M831A/6%"841A<V%W85AA66%:86MA=&%O865A<6%?85UA4V%U89EAEF&'8:QA
ME&&:88IAD6&K8:YAS&'*8<EA]V'(8<-AQF&Z8<MA>7_-8>9AXV'V8?IA]&'_
M8?UA_&'^80!B"&()8@UB#&(48AMB````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````>8B%B*F(N8C!B,F(S8D%B3F)>8F-B6V)@
M8FAB?&*"8HEB?F*28I-BEF+48H-BE&+78M%BNV+/8O]BQF+49,ABW&+,8LIB
MPF+'8IMBR6(,8^YB\6(G8P)C"&/O8O5B4&,^8TUC'&1/8Y9CCF.`8ZMC=F.C
M8X]CB6.?8[5C:V,``&ECOF/I8\!CQF/C8\ECTF/V8\1C%F0T9`9D$V0F9#9D
M'6479"AD#V1G9&]D=F1.9"IEE6239*5DJ62(9+QDVF329,5DQV2[9-ADPF3Q
M9.=D"8+@9.%DK&+C9.]D+&7V9/1D\F3Z9`!E_60891QE!64D92-E*V4T935E
M-V4V93AE2W5(959E565-95AE7F5=97)E>&6"98-EBHN;99]EJV6W9<-EQF7!
M9<1ES&729=MEV67@9>%E\65R9PIF`V;[97-G-68V9C1F'&9/9D1F269!9EYF
M769D9F=F:&9?9F)F<&:#9HAFCF:)9H1FF&:=9L%FN6;)9KYFO&8`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````,1FN&;69MIF
MX&8_9N9FZ6;P9O5F]V8/9Q9G'F<F9R=G.)<N9S]G-F=!9SAG-V=&9UYG8&=9
M9V-G9&>)9W!GJ6=\9VIGC&>+9Z9GH6>%9[=G[V>T9^QGLV?I9[AGY&?>9]UG
MXF?N9[EGSF?&9^=GG&H>:$9H*6A`:$UH,FA.:```LV@K:%EH8VAW:']HGVB/
M:*UHE&B=:)MH@VBN:KEH=&BU:*!HNF@/:8UH?F@!:<IH"&G8:")I)FGA:`QI
MS6C4:.=HU6@V:1)I!&G7:.-H)6GY:.!H[V@H:2II&FDC:2%IQFAY:7=I7&EX
M:6MI5&E^:6YI.6ET:3UI66DP:6%I7FE=:8%I:FFR::YIT&F_:<%ITVF^:<YI
MZ%O*:=UINVG#::=I+FJ1::!IG&F5:;1IWFGH:0)J&VK_:0IK^6GR:>=I!6JQ
M:1YJ[6D4:NMI"FH2:L%J(VH3:D1J#&IR:C9J>&I':F)J66IF:DAJ.&HB:I!J
MC6J@:H1JHFJC:@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````EVH7AKMJPVK":KAJLVJL:MYJT6K?:JIJVFKJ:OMJ!6L6AOIJ
M$FL6:S&;'VLX:S=KW'8Y:^Z81VM#:TEK4&M9:U1K6VM?:V%K>&MY:W]K@&N$
M:X-KC6N8:Y5KGFND:ZIKJVNO:[)KL6NS:[=KO&O&:\MKTVO?:^QKZVOS:^]K
M``"^G@AL$VP4;!ML)&PC;%YL56QB;&IL@FR-;)IL@6R;;'YL:&QS;))LD&S$
M;/%LTVR];-=LQ6S=;*YLL6R^;+ILVVSO;-ELZFP?;4V(-FTK;3UM.&T9;35M
M,VT2;0QM8VV3;61M6FUY;5EMCFV5;>1OA6WY;15N"FZU;<=MYFVX;<9M[&W>
M;<QMZ&W2;<5M^FW9;>1MU6WJ;>YM+6YN;BYN&6YR;E]N/FXC;FMN*VYV;DUN
M'VY#;CIN3FXD;O]N'6XX;H)NJFZ8;LENMV[3;KUNKV[$;K)NU&[5;H]NI6["
M;I]N06\1;TQP[&[X;OYN/V_R;C%O[VXR;\QN```````P`3`",`S_#O_[,!K_
M&_\?_P'_FS"<,+0`0/^H`#[_X_\___TP_C"=,)XP`S#=3@4P!C`',/PP%2`0
M(`__7``<,!8@7/\F("4@&"`9(!P@'2`(_PG_%#`5,#O_/?];_UW_"#`),`HP
M"S`,,`TP#C`/,!`P$3`+_Q(BL0#7````]P`=_V`B'/\>_V8B9R(>(C0B0B9`
M)K``,B`S(`,AY?\$_Z(`HP`%_P/_!O\*_R#_IP`&)@4FRR7/)<XEQR7&):$E
MH"6S);(EO26\)3L@$C"2(9`AD2&3(1,P````````````````````````````
M``@B"R*&(H<B@B*#(BHB*2(`````````````````````)R(H(JP`TB'4(0`B
M`R(`````````````````````````````("*E(A(C`B('(F$B4B)J(FLB&B(]
M(ATB-2(K(BPB```````````````````K(3`@;R9M)FHF("`A(+8`````````
M``#O)0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````$/\1_Q+_$_\4_Q7_
M%O\7_QC_&?\``````````````````"'_(O\C_R3_)?\F_R?_*/\I_RK_*_\L
M_RW_+O\O_S#_,?\R_S/_-/\U_S;_-_\X_SG_.O\``````````````````$'_
M0O]#_T3_1?]&_T?_2/])_TK_2_],_TW_3O]/_U#_4?]2_U/_5/]5_U;_5_]8
M_UG_6O\``````````$$P0C!#,$0P13!&,$<P2#!),$HP2S!,,$TP3C!/,%`P
M43!2,%,P5#!5,%8P5S!8,%DP6C!;,%PP73!>,%\P8#!A,&(P8S!D,&4P9C!G
M,&@P:3!J,&LP;#!M,&XP;S!P,'$P<C!S,'0P=3!V,'<P>#!Y,'HP>S!\,'TP
M?C!_,(`P@3"",(,PA#"%,(8PAS"(,(DPBC"+,(PPC3".,(\PD#"1,)(PDS``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"A,*(PHS"D,*4PIC"G,*@PJ3"J,*LPK#"M
M,*XPKS"P,+$PLC"S,+0PM3"V,+<PN#"Y,+HPNS"\,+TPOC"_,,`PP3#",,,P
MQ##%,,8PQS#(,,DPRC#+,,PPS3#.,,\PT##1,-(PTS#4,-4PUC#7,-@PV3#:
M,-LPW##=,-XPWS```.`PX3#B,.,PY##E,.8PYS#H,.DPZC#K,.PP[3#N,.\P
M\##Q,/(P\S#T,/4P]C``````````````````````D0.2`Y,#E`.5`Y8#EP.8
M`YD#F@.;`YP#G0.>`Y\#H`.A`Z,#I`.E`Z8#IP.H`ZD#````````````````
M`````+$#L@.S`[0#M0.V`[<#N`.Y`[H#NP.\`[T#O@._`\`#P0/#`\0#Q0/&
M`\<#R`/)`P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!`$$002!!,$
M%`05!`$$%@07!!@$&00:!!L$'`0=!!X$'P0@!"$$(@0C!"0$)00F!"<$*`0I
M!"H$*P0L!"T$+@0O!````````````````````````````````````````#`$
M,00R!#,$-`0U!%$$-@0W!#@$.00Z!#L$/`0]!```/@0_!$`$001"!$,$1`1%
M!$8$1P1(!$D$2@1+!$P$301.!$\$````````````````````````````````
M````)0(E#"40)1@E%"4<)2PE)"4T)3PE`24#)0\E$R4;)1<E(R4S)2LE.R5+
M)2`E+R4H)3<E/R4=)3`E)24X)4(E``!A_V+_8_]D_V7_9O]G_VC_:?]J_VO_
M;/]M_V[_;_]P_W'_<O]S_W3_=?]V_W?_>/]Y_WK_>_]\_WW_?O]__X#_@?^"
M_X/_A/^%_X;_A_^(_XG_BO^+_XS_C?^._X__D/^1_Y+_D_^4_Y7_EO^7_YC_
MF?^:_YO_G/^=_Y[_G_\``%D``````````````!$```!QOA@(>+X8"/2;&`@`
M````H+TA"*"\(0B@NR$(``````````````````````````````````````$`
M```!`````0`````````@NR$(``P9"```````````J(<'"$R"!PAD@@<(;(('
M"(""!PA8@@<(Z/('"!SS!PA$=`<(9'0'"(1T!PBH=`<(S'4'"'Q]!PA,?@<(
M-(('"%!V!PC0=P<(*'D'"%1[!P@T?0<(](4'",R!!P@`````````````````
M``````````````````````$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP=
M'A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*
M2TQ-3D]045)35%565UA96EM<75Y?8$%"0T1%1D=(24I+3$U.3U!14E-45597
M6%E:>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.D
MI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1
MTM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^
M_P`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK
M+"TN+S`Q,C,T-38W.#DZ.SP]/C]`86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X
M>7I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%
MAH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&R
ML[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?
MX.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O\`("`@("`@("`@*"@H
M*"@@("`@("`@("`@("`@("`@("!($!`0$!`0$!`0$!`0$!`0A(2$A(2$A(2$
MA!`0$!`0$!"!@8&!@8$!`0$!`0$!`0$!`0$!`0$!`0$!`1`0$!`0$(*"@H*"
M@@("`@("`@("`@("`@("`@("`@("$!`0$"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````2``````````````!A````<;X8"(.^&`CTFQ@(`````*"](0B@O"$(
MH+LA"&"_(0@````````````````````````````````$`````0````$`````
M````(+LA"""_(0@`````T.L'"#3N!PC\\`<('/('"'Q_!PC,=`<(H(('".AU
M!P@```````````````````````````````````````$"`P0%!@<("0H+#`T.
M#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[
M/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EQ=6UY?14%"0T1%1D=(
M24I+3$U.3U!14E-455976%E:>WQ]67^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25
MEI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"
MP\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O
M\/'R\_3U]O?X^?K[_/W^_P`````````````````````'````````````````
M``````````<`````````````````````````!P``````````````````````
M```'``````````````````````````<`````````````````````````!P``
M```````````````````````'``````````````````````````<`````````
M````````````````!P`````````````````````````'````````````````
M``````````<`````````````````````````!P``````````````````````
M```'``````````````````````````<`````````````````````````!P``
M```````````````````````'``````````````````````````<`````````
M````````````````!P`````````````````````````'````````````````
M``````````<`````````````````````````!P``````````````````````
M```'``````````````````````````<`````````````````````````!P``
M```````````````````````'``````````````````````````<`````````
M````````````````!P`````````````````````````'````````````````
M``````````<`````````````````````````!P``````````````````````
M```'``````````````````````````<```````````````8`````````!P``
M````````````#0`````````'```````````````7``````````<`````````
M`````"<`````````!P``````````````(``````````'```````````````H
M``````````<``````````````"8`````````!P``````````````%@``````
M```'```````````````8``````````<``````````````!T`````````!P``
M````````````)``````````'```````````````I``````````<`````````
M``````H`````````!P``````````````"0`````````'```````````````0
M``````````<```````````````\`````````!P````4````%````!0````4`
M```'````!@````4````%````!0````<````'````!0````4````%````!P``
M``@````%````!0````4````'````"0````4````%````!0````<````*````
M!0````4````%````!P````L````%````!0````4````'````#`````4````%
M````!0````<````-````!0````4````%````!P````X````%````!0````4`
M```'```````````````,``````````<```````````````L`````````!P``
M````````````*@`````````'```````````````K``````````<`````````
M`````"P`````````!P``````````````#@`````````'```````````````>
M``````````<````/````!0````4````'````!P```!`````%````!0````<`
M```'````$0````4````%````!P````<````2````!0````4````'````!P``
M`!,````%````!0````<````'````%`````4````%````!P````<````5````
M!0````4````'````!P```!8````%````!0````<````'````%P````4````%
M````!P````<````8````!0````4````'````!P```!D````%````!0````<`
M```'````&@````4````%````!P````<````;````!0````4````'````!P``
M`!P````%````!0````<````'````'0````4````%````!P````<````>````
M!0````4````'````!P```!\````%````!0````<````'````(`````4````%
M````!P````<````A````!0````4````'````!P```"(````%````!0````<`
M```'````(P````4````%````!P````<````D````!0````4````'````!P``
M`"4````%````!0````<````'````)@````4````%````!P````<````G````
M!0````4````'````!P```"@````%````!0````<````'```````````````9
M``````````<``````````````"4`````````!P``````````````'```````
M```'```````````````4``````````<```````````````@`````````!P``
M````````````$P`````````'````#P````4````%````!@````<````0````
M!0````4````&````!P```!$````%````!0````8````'````$@````4````%
M````!@````<````3````!0````4````&````!P```!0````%````!0````8`
M```'````%0````4````%````!@````<````6````!0````4````&````!P``
M`!<````%````!0````8````'````&`````4````%````!@````<````9````
M!0````4````&````!P```!H````%````!0````8````'````&P````4````%
M````!@````<````<````!0````4````&````!P```!T````%````!0````8`
M```'````'@````4````%````!@````<````?````!0````4````&````!P``
M`"`````%````!0````8````'````(0````4````%````!@````<````B````
M!0````4````&````!P```",````%````!0````8````'````)`````4````%
M````!@````<````E````!0````4````&````!P```"8````%````!0````8`
M```'````)P````4````%````!@````<````H````!0````4````&````!P``
M````````````&@`````````'```````````````M``````````<`````````
M`````!L`````````!P``````````````%0`````````'````````````````
M``````````<`````````````````````````!P``````````````````````
M```'``````````````````````````<`````````````````````````!P``
M```````````````````````'``````````````````````````<`````````
M````````````````!P`````````````````````````'````````````````
M``````````<`````````````````````````!P``````````````````````
M```'``````````````````````````<`````````````````````````!P``
M```````````````````````'``````````````````````````<`````````
M````````````````!P`````````````````````````'````````````````
M``````````<`````````````````````````!P``````````````````````
M```'``````````````````````````<`````````````````````````!P``
M```````````````````````'``````````````````````````<`````````
M````````````````!P`````````````````````````'````````````````
M``````````<`````````````````````````!P``````````````````````
M```'``````````````````````````<`````````````````````````!P``
M```````````````````````'```````````````'``````````<````I````
M!0````4````%````%P```"H````%````!0````4````7````*P````4````%
M````!0```!<````L````!0````4````%````%P```"T````%````!0````4`
M```7````+@````4````%````!0```!<````O````!0````4````%````%P``
M`#`````%````!0````4````7````,0````4````%````!0```!<````R````
M!0````4````%````%P```#,````%````!0````4````7````-`````4````%
M````!0```!<````U````!0````4````%````%P```#8````%````!0````4`
M```7````-P````4````%````!0```!<````X````!0````4````%````%P``
M`#D````%````!0````4````7````.@````4````%````!0```!<````[````
M!0````4````%````%P```#P````%````!0````4````7````/0````4````%
M````!0```!<````^````!0````4````%````%P```#\````%````!0````4`
M```7````0`````4````%````!0```!<```!!````!0````4````%````%P``
M`$(````%````!0````4````7````0P````4````%````!0```!<```!$````
M!0````4````%````%P```$4````%````!0````4````7````1@````4````%
M````!0```!<```!'````!0````4````%````%P```$@````%````!0````4`
M```7````20````4````%````!0```!<```!*````!0````4````%````%P``
M`$L````%````!0````4````7````3`````4````%````!0```!<```!-````
M!0````4````%````%P```$X````%````!0````4````7````3P````4````%
M````!0```!<```!0````!0````4````%````%P```%$````%````!0````4`
M```7````4@````4````%````!0```!<```!3````!0````4````%````%P``
M`%0````%````!0````4````7````50````4````%````!0```!<```!6````
M!0````4````%````%P``````````````$0`````````'````6`````4````%
M````!0```$<```!9````!0````4````%````A@```%H````%````!0````4`
M``!'````6P````4````%````!0```$<```!<````!0````4````%````A@``
M`%T````%````!0````4```"&````7@````4````%````!0```(8```!?````
M!0````4````%````A@```&`````%````!0````4````(`0``80````4````%
M````!0````@!````````"`````4````%````"```````````````````````
M```'``````````````````````````<`````````````````````````!P``
M```````````````````````'```````````````?``````````<```!B````
M!0````4````%````)P```&,````%````!0````4````G````9`````4````%
M````!0```"<```!E````!0````4````%````)P```&8````%````!0````4`
M```G````6@````4````%````"````$<``````````````!(`````````!R``
M```````*````!0````4````&)`````````L````%````!0````4R````````
M#`````4````%````!3(````````-````!0````4````%,@````````X````%
M````!0````4R````````"0````4````%````!3@``%<````%````!0````4`
M```&!`````````<````%````!0````8$`````````````"$`````````!P``
M``4````&````!0````4````'0```!@````8````%````!0````=````'````
M!@````4````%````!T````@````&````!0````4````'0```"0````8````%
M````!0````=````*````!@````4````%````!T````L````&````!0````4`
M```'0```#`````8````%````!0````=````-````!@````4````%````!T``
M``X````&````!0````4````'0``````````````B``````````<`````````
M`````",`````````!P`````````````````````````'````````````````
M``````````<`````````````````````````!P```/\`````````````````
M```'````8-HA"```````````````````````````````````````````````
M``````````````````````!@V2$(````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````8-@A"```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#_````H:*CI*6FIZBIJJNLK:ZOL+&R
ML[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9V@````#?
MX.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@
M(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-
M3D]045)35%565UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ
M>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GP``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`0`"``,`!``%``8`!P`(``D`"@`+``P`#0`.``\`$``1`!(`$P`4`!4`%@`7
M`!@`&0`:`!L`'``=`!X`'P`@`"$`(@`C`"0`)0`F`"<`*``I`"H`*P`L`"T`
M+@`O`#``,0`R`#,`-``U`#8`-P`X`#D`.@`[`#P`/0`^`#\`0`!!`$(`0P!$
M`$4`1@!'`$@`20!*`$L`3`!-`$X`3P!0`%$`4@!3`%0`50!6`%<`6`!9`%H`
M6P!<`%T`7@!?`&``80!B`&,`9`!E`&8`9P!H`&D`:@!K`&P`;0!N`&\`<`!Q
M`'(`<P!T`'4`=@!W`'@`>0!Z`'L`?`!]`'X`?P"``($`@@"#`(0`A0"&`(<`
MB`")`(H`BP",`(T`C@"/`)``D0"2`),`E`"5`)8`EP"8`)D`F@";`)P`G0">
M`)\`_?\!#@(.`PX$#@4.!@X'#@@."0X*#@L.#`X-#@X.#PX0#A$.$@X3#A0.
M%0X6#A<.&`X9#AH.&PX<#AT.'@X?#B`.(0XB#B,.)`XE#B8.)PXH#BD.*@XK
M#BP.+0XN#B\.,`XQ#C(.,PXT#C4.-@XW#C@..0XZ#OW__?_]__W_/PY`#D$.
M0@Y##D0.10Y&#D<.2`Y)#DH.2PY,#DT.3@Y/#E`.40Y2#E,.5`Y5#E8.5PY8
M#ED.6@Y;#OW__?_]__W_6P``````````````$0```)*^&`B7OA@(])L8"```
M``!`X"$(0-\A"$#>(0@``````````````````````````````````````0``
M``$````#``````#_`,#=(0B`*B4(`````%SS!PC\\P<(<%P("+A<"`@P]`<(
M@(('"+CT!PC\]`<(A`4(",Q6"`@H5P@(A%<("-17"`C,=0<(?'T'"$Q^!P@T
M@@<(4'8'"-!W!P@H>0<(5'L'"#1]!PCTA0<(S($'"```````````````````
M`````````````````````0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>
M'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+
M3$U.3U!14E-455976%E:6UQ=7E]@04)#1$5&1TA)2DM,34Y/4%%24U155E=8
M65I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2E
MIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2
MT]35UM?8V=K;W-W>W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_
M``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL
M+2XO,#$R,S0U-C<X.3H[/#T^/T!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY
M>EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#A(6&
MAXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*S
MM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@
MX>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`@("`@("`@("`H*"@H
M*"`@("`@("`@("`@("`@("`@($@0$!`0$!`0$!`0$!`0$!"$A(2$A(2$A(2$
M$!`0$!`0$(&!@8&!@0$!`0$!`0$!`0$!`0$!`0$!`0$!$!`0$!`0@H*"@H*"
M`@("`@("`@("`@("`@("`@("`@(0$!`0(```````````````````$!``````
M`````````````````!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!``````````````````````````````````````
M``````P``````````````"$```"2OA@(H+X8"/2;&`@`````0.`A"$#?(0A`
MWB$(`.(A"`````````````````````````````````$````!`````P``````
M_P#`W2$(P.$A"``````D<P<(F','"*1R!PCT@`<(R%@(""18"`A@70@(Z'4'
M"````````````````````````````````````````0(#!`4&!P@)"@L,#0X/
M$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\
M/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@04)#1$5&1TA)
M2DM,34Y/4%%24U155E=865I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66
MEYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#
MQ,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;GZ.GJZ^SM[N_P
M\?+S]/7V]_CY^OO\_?[_,2$``&\A````````````````````````````````
M```J(0``="%P(7,A=2$``$HA2R%V(5PA)"$``"4A/R$P(S$C,B,S(S0C-2,V
M(S<C.",Y(R<A*"%C(6$A9"$I(7<A02-"(T,C1"-%(T8C1R-((TDC2B-+(TPC
M32-.(T\C4"-1(U(C4R-4(U4C5B-7(U@C62-:(TXA``!/(3`A,B$N(6$C8B-C
M(V0C92-F(V<C:"-I(VHC:R-L(VTC;B-O(W`C<2-R(W,C="-U(W8C=R-X(WDC
M>B-0(4,A42$````````V3@``````````````````?',```````````````!]
M<U1C`````'YS````````````````````````````````0W,`````-#A$<P``
M`````$5S```O/```1G,```````````````!'<P````!(<TES``````````!,
M<TIS/$\``$MS``!O3@````````````!-<P``6TX`````````````3G-^1P``
M``!/<U%S`````%)S``````````````````````````!0<VTY34QC2W=6``!@
M77M+```````````K,@``````````````````5'-0-55S5G-7<P``=3D``%AS
M````````5&!;3```8T)9<UMS6G,``%QS``````````!=<P````!><P``````
M`````````%]S``````````!@<P``87-B<P``8W,``&1S97-F<P``````````
M`````````````&=S:',`````````````)$4``````````%TX``!J<P``````
M````````````````````34%K<P``````````````````````````;',`````
M````````````````````````````````(4D`````;7,`````````````````
M````````````;G,W8P````!:;&UP`````&]S``!P<P``````````````````
M````````<G-S<W1S<$YQ<P````!U<W9S`````'AS``!W<P````````````!Z
M<P```````'MS>7-`<T%S`````$)S`````````````````````#M$``!J<@``
M-T@``&]R:W(```````!L<@`````Q2T1,``!01@``````````````````````
M`````````'!R`````'%R/D9N<FUR```````````J,@```````'ER`````'AR
M`````````````'4Q````````=G(```````!U<@````!S<@``>S,``')R,CPI
M,@````````````````````````````````````!C.0````!\<GMR``!Z<@``
M``!W<@``?7(``'YR```````````````````E<R1S```````````````````F
M<P`````M,2%S(G,``'0Y.4P`````(W,``````````````````#)+`````"MS
M`````"=S```````````````````L<P``````````````````````````````
M`"ES```H<P````````````!<-P``````````````````````````+7,`````
M```````````````````N<P``````````+W,``"IS````````='(`````,',`
M`&%$````````-',``#5S,W,`````````````,G,X<P``,7,``#9S````````
M`````````````#=S````````.G,`````````````.7,`````````````````
M```````````````\<P```````````````#US```^<P````!)3P``````````
M```[<VM";3H`````/W,``````````````````"5/```````````W<@``````
M```````````````````````````````Y<@``````````````````````````
M/C``````.G(K2CAR`````#MR/'(``````````````````#UR/G(`````````
M`````````#]R``!N2RT[``!Z.B]!`````````````$!R``````````!#<@``
M`````````````$%R`````````````$1R`````'$X0G(``````````$5R``!&
M<D=R``!+<@``*CL``````````&1"`````````````$QR27)(<DIR````````
M7S<``````````````````%!R3W).<@`````S,```````````````````````
M``````````````!:<@``5G(``%=R4W)9<@``57)B,P````!,3P``6')4<E)R
M47(`````````````7'(`````````````7W(`````7G)=<@``````````````
M````24E;<G,P8'(``&)R````````````````;S--<C<Q`````&1R````````
M``````````!C<F%R+4,```````````````````````!P2P``````````6DX`
M````97(`````````````9G(```````````````!G<@``````````````````
M``````````````````!H<@``:7(```````````````!\.0``````````;'$`
M````;7$``````````````````#PS````````;G$```````!O<0```````'$_
M``````````````````````````!P<0``<7$``')Q<W$```````!B.0``````
M``````!T<75Q`````'9Q=W$`````>'$````````Q2'IQ```F27MQ>7$``'UQ
M`````'QQ`````'YQ````````(7(``````````````````````````")R````
M`````````````````````````````````````````"-R```D<@``````````
M)7(`````)G(G<@``*'(``"ER*G(K<BQR````````+7(N<@``-5TO<@``````
M``````````````!X9#0U```````````A,S(Z,7(P<B5,````````````````
M```S<C1R,G(``#5R`````&)+````````-G(``'LU````````````````````
M``````````````!S/$1Q17%A.0````````````````````````````!&<0``
M```^,P```````$]'1W%(<0``````````6D-K1@``````````````````27$`
M`````````'U'`````$Q"6#%N-@``;S8``````````````````'-#3G%P-@``
M``!O,@````!-<0````!+<0``3'$``$IQ`````%AQ````````````````````
M``````!/<5!Q`````%%Q4G$`````````````5'$`````4W$```````!9/0``
M57$```````!7<0`````````````````````S-59Q`````'M!,S@`````````
M````67$`````````````````````````````````````34(`````6G$`````
M`````"U&````````````````6W$```````````````!@<0``7G$``%UQ7W$`
M`%QQ``````````````````!B<0``````````````````87$``&1Q`````$,V
M8W$```````!E<0````!F<0``:'%G<0```````&EQ:W%J<0``````````````
M````````````=$A,9@`````I/P`````R-0```````````````"MQ```L<0``
M+%([75-(`````'LP```[,```````````````````=#LP2WX^```````````M
M<0``7TP````````N<5Q-``!",0```````$$[```O<6XR,'$````````Q<0``
M````````,W$T<0``-G$R<0`````U<0```````%LT````````-W$``#AQ````
M`````````````````````````````````#EQ.G$````````[<0`````]<0``
M`````#QQ```_<4)Q````````/G%`<4%Q`````$-Q``!"-@```````'=)```D
M<0``````````)7$``"9Q```````````G<0``````````````````````````
M`````"EQ*'$``"IQ``!L20``````````=&\```````````````!U;P``93H`
M``````!V;W=O`````$E+`````````````````````$M!````````)#!+0@``
M>&\``&U)````````````````>V]Y;U\Y``!Z;T(X````````````````````
M``````!%2GUO(7!^;R)P`````"$Q6#]\/5DT(W````````!F1P``)7``````
M```B,0``)'!$1```34XK1GQO)DX``#$X`````%M-``````````````````!Y
M-C1.```H-P``8D(A9P``)G`L,V\_``````````!6,RAP```I<"=P9#<``%TZ
M8SX````````C,0````!93@```````"MP+FX``"IP`````````````"YP+'`M
M<```+W```#!P;$XQ<#)P``!)0#M(````````?3]G-``````Z36TR.#U;.```
M-7```#1P<SLV<#-P`````"@[````````.G`M:@````!64@``=S\X<```````
M```````E3G%&```````````K,0``8T`V/```````````-TH``$`Q````````
M;4YK30``.W```$5%``````````![/````````#QP```]<$P_/G```&Y.````
M`#EP0'!"<```07```#]P`````$-P`````$1P`````'I!``!B,@``````````
M``!%<``````X3`````!&<`````````````!'<```*D\`````````````,5M(
M<````````$EP2G````````!.<```2W```$QP``!-<$]P````````````````
M`````$1`````````=TP`````14``````4'```'-(``!1<%-S3$P``%)P``!3
M<```5'!7,P``5G```%D_````````5W``````)#<``````````%AP7'```%IP
M``````````!;<`````!S,UEP77```````````%YP``!(,```7W!@<```````
M````````````9#X```````!A<````````$<U`````&1P`````&-P``!B<```
M``!Q:P``7$H`````````````97!F<```````````````````````````````
M``````!G<`````!H<```:7``````:G```````````````````%HT````````
M`````````````&MP``````````````````````````````````````````!L
M<"-'````````;G`[,@``<7!P<```````````)#$```````!!-@``1THZ1"(Z
M``!@.6<]``!</P```````'-P`````')P0DUH-%)(7$8```````!\/TY.``!;
M-P```````````````'9P`````'5P``````````````````!+2RQ&````````
M````````4#$`````=W!T<`````!126I->'``````````````````````>7``
M`````````'MP:D);,UPS>G```````````&DT,C@`````:C0`````/T4`````
M8$X`````````````````````7#@```````!\<````````'UP?G`A<0``(W$B
M<0``````````````````.40`````````````````````9TP``%EO+D$`````
M``!:;P``1$I;;RLS````````/#$``%<T``!6-%QO``!=;P``7F]?;P``````
M`````````&!O``!8-%4S7CDV2```8F]A;P``````````8V\``````````%PQ
M````````````````9F\``&5O9&\``&=O``````````!J;P```````$<P````
M`&AO``!L;VMO````````````````;F]M;V]O```N1@```````'!O````````
M``!Q;W-O`````')O```_;P```````$!O`````````````````````$%O````
M`#YO/6\```````!B/BI&/&\```````````````!%;P``````````````````
M`````$-O````````````````````````1&]";P``>$(``$9O````````````
M````1V\`````26\```````````````````````````````!5-$AO>DP`````
M``````````!4;TIO`````$UO``!+;P``3&\``````````````````$YO````
M`````````%!O``````````!1;P``4F\``````````%5O4V]6;UAO``!7;P``
M=VX`````+TL`````````````````````````````````````````````>ST`
M`````````'IN7TH`````5#$``````````$9)<D,``````````'@U``!\;@``
M73D````````````````````````L.P````````````````````![;FT_````
M``````````````!N/R%O(V\`````````````>SX``")O)&\`````4S8``$5)
M`````&(\(T\``'YN>#H`````/T\`````)F\``````````"5O)V\`````````
M````````````?6X```````````````!I1@``544```````````````!71```
M+&\``````````$-#*&\````````I;P`````````````````````````````M
M-P``*V\````````````````P.````````````````"IO``!A/@``````````
M````````````````````````>3,``````````````````#!O```_.GE!````
M`$I$````````````````````````````````.S,``````````"YO+V]#1```
M+6\`````````````````````,6\````````````````````````W;P``````
M````.F\``````````````````#EO+44``````````#)O,V\V;P``````````
M.&\```````!`-@`````[;S5O`````#1O````````````````4T9$;C8]8#Q;
M1W%#````````<CP``&P_``!%;@``1FX```````````````````````!=/T=N
M``!(;@```````$EN;TT``#<]`````````````$MN2FX``%HY``!S.4`[````
M````````````````````3FX``````````&8]``!-;@``3&X``&E"`````&\X
M``!#0```````````,$@``````````#D]`````````````$]N``!?/@``````
M``````!2;E!N````````46X``````````%1N4VX`````>CX``%5N````````
M`````%9N5VX``````````%!(4SIA/%AN``!9;B1.13UN3$Q.6FYB-@``````
M````6VX``"-%`````%YN>#-+/P``7&X``%UN``!@1`````!52WPV````````
M``````````````````````````!@;F%N`````````````%]N`````&-N````
M``````````````````````````````!?1D,S`````&=N`````&1N9FX`````
M````````````````8FX``````````````````````````$]O`````&5N````
M``````````````!K3@````!:.```````````````````;VX``````````#1%
M:FX`````;6YK;@``<&X``````````'%N````````````````:6X`````=FYT
M,0````!H;@```````"U(``!L;@``8#X``````````````````````````%LY
M````````````````````````````````2$L``&0V`````$8]```\1@``````
M```````````````````````M00``=&X``&YN<VX``$-,```X1'5N<FX`````
M`````````````````````````````````````"Q!````````````````````
M````>6X``'AN````````````````````````````````````````23]C;0``
M+3QD;0```````&5M````````(5)^40``````````9FUP96=M)$,K/T!'````
M``````!H;0````!52E1$?CD`````*4,`````*C$``'A+5S\`````````````
M````````7C<`````838`````5DH`````````````:6T`````````````````
M`&MM`````&IM8#(`````=D9L;7='```S10``;6U2/0```````&]M`````$),
M?FUQ;7)M`````$E$`````&!"=T$``"A&``!P;54U``````````!Y;0``=FTE
M;BE&8$-S;0``?D13171M>&U@/P``9T=,1`````!"0'=M+D(D0G5M*3`B3P``
M`````'IM````````````````84(`````-3U*/P````!\;7MM``!O,'UM````
M`"])```G;@````!;1FL_`````%E#``!X-@``)FXW33\Q``!72F$R(6XB;B-N
M)&X[1B-#8S`H;@``*6XC=``````]0@``*FX``',Q3$$``"\X``!:30`````K
M;BQ%````````>$%7/"QN`````"]N`````&4]+6XK02I!``!D,```2TXQ;@``
M<D@S;C)N,&YD8U0T`````&YM```U;C1N```````````V;@``.$T`````````
M````````````````````````````````````848`````+DL``#=N``!9/```
M````````.&X``#EN````````.FX`````(44`````````````````````:C``
M````````````````````63D````````Z3P``````````````````````````
M`````#YN`````````````#0W.VX``#QN````````=$D``````````%0S````
M```````````````Y30``/S8`````````````5$4``````````#]N````````
M````````````````````````````````0&X```````````````!!;@``````
M````````````````````````````````````````````(D4`````0VX``$)N
M`````````````````````%9```!//%]L````````4C,``&!L`````'9!86P`
M`&)L:TD`````+S4```````````````````````!C;````````#9$````````
M``!;,0````````````````````````````````````!D;```````````````
M`````````'$\``````````!V/P``````````````````````````+4(`````
M``````````!G;````````&9L````````96P`````````````````````;6QK
M;`````!H;````````````````&IL````````:6QL;```=S4``'!L``!70```
M<6P``````````%DX``!N;&]L````````*4\````````W1```*4$`````````
M``````!R;`````!U;`````````````````````!S;'1L64T``````````"=&
M>&P```````````````````````````````!V;'=L>6P`````````````````
M`````````"EM`````````````'QL````````?6Q[;```````````````````
M`````````````'IL``!]1``````A;25M(FU^;```(VT````````D;0``````
M````*VT````````F;0````````````!80"AM`````"IM)VT`````````````
M`````````````````````"UM```S/0``+&T`````````````+FT`````````
M`"]M`````#)M,6T``#!M`````#1M,VT``'9,````````-FT``#5M-VT`````
M`````#AM```````````````````Z;0`````````````````````Y;4@_.VT`
M````;38\;3YM````````````````````````````````/VT`````````````
M``!`;3UM``!!;0``5CQ";3`U,S<``````````"XX````````````````````
M`$-M````````<$8`````/D5$;0``````````````````1VT`````````````
M```````````````````T/`````!&;45M6C=(;0``````````4S,``$IM````
M````7#I);0``4FT`````````````3&U.;65*2VT```````!-;0``46U/;3$U
M``!0;0```````````````%-M`````%I'6$X``````````#0]````````5&T`
M`````````")-5FT``%5M`````%EM04T`````6&T``&TS5VU<;0````!;;0``
M``!:;3)%76T`````````````````````7FT``````````%]M`````&PY```E
M-V!M86UB;0```````````````````````````````````````"M#`````"YL
M```````````P;```+VP``````````"9&```Q;```+4L``#)L```S;```-&P`
M`````````#5L``````````!:1@```````````````%T^-FP`````````````
M`````&LY+E`W;``````````````````````````````X;#]).6P``$%L````
M`````````#IL`````#QL````````.VP];```1DL^;#]L`````````````$!L
M````````0FP``````````"TS9T0``&E)8CI7.0``````````3TE?,DY(16Q3
M-%5`1&Q);'E#8TP``$=L2&PN-0``2FQC1U]"`````'%(/45&;```1TML,DQL
M*$]"1$5/`````'$[2VP``#%"`````%QL*$$`````>$8``%!)````````````
M````3VP_.W([``!>/@``94<``"TX3FQ-;```:DD```````!!/`````!210``
M`````````````````````````````%%L4FQ8.5!L````````````````4VQ4
M;```5FPC0@``56QF-```6&P``%=L66P`````6VQ=;```7FPZ:```.V@``%DR
M````````+C(X:``````````````````````N:```-F@``#UH-V@````````U
M:```````````=F<`````,V@````````O:````````%`T,6@\:```,F@`````
M````````/F@``#!H?$<`````````````:4T````````Y:```````````````
M````3V@```````!':````````'L_``````````!&-0``738``$)H````````
M``!;,@````!4/@``16@```````!:.@````!114IH````````````````````
M`&Y*``!!:````````%HR5C@I24MH```_:`````!(:````````%)H``!#:```
M``````````!$:#I&`````$EH````````1F@H2TQH8#```````````$!H````
M````````````````````````````3F@``$UH````````````````:T=4:```
M7V@``````````'XS````````8F@`````4&@```````!5:&Y-````````````
M`````````%YH`````%5-```````````J3@````````````````````!X0P``
M`````&LS`````````````'))9&@A1@`````Q,`````!=:```66AR05-H6VA@
M:```+$<````````J,```6&@``&%H>$D``````````````````%QH``!7:```
M`````````````%4^```````````O/0```````"P\``````````!83`````!'
M20````!G:```<&@`````````````````````````````6F@``````````'<S
M`````````````'@^96@``&IH<T$`````9F@``&UH`````%]#``!N:`````!6
M36-H.#,``&EH`````&QH+$P``````````&]H`````&AH:V@`````````````
M````````````````````````````````*4L``"%/`````````````'-H````
M``````````````!Z:`````!R:$,\`````````````%%H````````````````
M``````````!.2@``(DQY:'AH``!T:'5H```V,0``````````=V@``'%H````
M``````!51`````````````!V:'XP```````````````````B0@``````````
M````````0TH`````>V@A:0``64@``````````'YH5CY)/"-I`````#XV````
M````````````)&D``'E)?6@``%9H`````````````````````'QH````````
M``!/3R)&<TD`````*VD````````````````````````Q:0``````````````
M`#)I```E:0```````'9'`````"]I)VD``"EI`````````````#-I*&D`````
M+&D`````<C$``&5&```M:3!I```````````````````F:0``)D$``"II)SM%
M/S`W=$P``'E,<CT````````````````````````W:35I````````````````
M3D\``````````````````#1I````````=4T``#9I.&D``````````#EI````
M````````````/&DZ:0```````````````"-&.VD```````!-2"YI````````
M````````````````````````<ST``#UI0FET00````!!:0```````")I````
M````0VE)00`````^:4!I```````````````````_:0`````Q72)=`````$5I
M``````````````````!$:0``````````````````````````=DT``#QB1FD`
M````````````````````````````````````1VD`````````````````````
M`````````````$AI5S@``%0U````````2FE=40``````````=34``#I.``!S
M-DMI``````````````````!,:0```````&Y#`````````````$UI````````
M``````````!Z1@``.C``````````````````````````````````````8S)2
M:5-I````````````````3FD``#T[````````````````````````````````
M``!/:4)'``````````!0:5%I6VD```````!5:5AI`````````````%1I````
M``````````````````````````````!6:0``5VE8/```66D``$%#``!6-T(S
M`````````````%QI```````````_,P``86D`````76E@:0``````````.D@`
M`````````%YI`````%]I2$E:2&)I`````````````````````'U";&D``&AI
M`````&LR``!F:0``*DMG:0````!D:0``96EJ:6UI`````&MI````````:6EC
M:0````````````!80P``=&D``"I,`````````````````````')I````````
M<VD``````````````````````````&YI`````'!I````````<6D```````!O
M:0```````````````````````&9````Y3WAI``!Y:0``````````(6H``"H_
M``![:0``?FD`````````````=FEU:0`````B:@````!<,@``?&D``"-J````
M````?6D`````````````>FD``#-$``!W:0```````````````&A'`````"=J
M```````````````````````````[30``````````````````````````````
M```````````````F:@`````E:@`````````````````````N:@```````"AJ
M````````,&H```````````````!F33-J```J:@`````K:@```````"]J```R
M:C%J````````*6H``````````"QJ```]:@``````````````````````````
M````````-FH`````````````````````````````````````-&H`````-6H`
M```````Z:CMJ```J,P``0C4`````.6H````````````````D:@``````````
M````````.&H\:C=J```^:@```````$!J/VH`````````````````````````
M`$)J06I::0```````$9J````````````````````````0VH``````````$1J
M`````$5J``!':@``````````;#<``$EJ``!(:@``,#T`````````````5#DG
M7@``````````2FI1/0```````#DS``!+:@``4C$``%<^3&H`````53E-:F$P
M```````````]20````!.:@``````````:C\``%5J`````%)J``!O0P``````
M``````!3:E!J7C8``$]J5FH`````````````-C<`````7D(``%QJ````````
M``!8:@```````#5"5VH``%IJ``````````!1:@```````%MJ``!=:@``````
M`````````&](`````%EJ``!>:F!J`````%,X5&H``$$P````````````````
M``!?:@``6SIV3F%J8FIU00```````````````````````").``````````!C
M:C5-`````&1J96H`````9$IF:@``0#H``"-.````````````````:VH`````
M``````````````````!L:E@^:FH```````!G36=J`````&EJ/4!^/P``````
M`&AJ``!M:@`````C2@````!O:@``;FH```````!L,P``*TMP:@``````````
M`````````````'QJ<FH```````````````!S:@``````````=&IU:@``````
M````````````````````>6H``'IJ`````'AJ`````````````'9J``!Q:G=J
M``````````````````![:C=P`````````````````````"@R````````````
M``````!^:E\V?6H````````B:P``(6L````````D:P`````C:P``)6L`````
M,3T``"9K`````"=K````````````````*&L^0```5TT``"EK`````"1*1D<J
M:P``*VLK.````````"PU````````+&L`````:SM!1RUK``!0,P``````````
M`````"YK```````````P:W=-```O:T8_```Q:P`````R:P`````S:U$T````
M````````````-&L`````-6L``#9K-VL`````````````````````````````
M````````````````43,``````````````````#AK```Y:SIK````````````
M`'(R`````"@_.VL````````````````````````````````\:P```````#UK
M``````````````````!`.```>T0^:P``````````5S<``%8_``!!:P``)$8`
M`$!K`````#$W`````#]K=T(M-0````!":P``0VL``%D^````````;3<``$1K
M```````````L2P````!?0````````'8U``!U3$I!``!%:P```````$<_<$-:
M/@``````````1FL``````````$EK``!*:P``````````````````/CI"0DAK
M``!;/CY)`````````````$=K`````&P[``!3,0``3FM8-P````!N.P````!M
M.P``34]-:TQK)T$``$TU0T\Z,UP^`````````````````````$MK````````
M`````%!K``!1:T]K``!8.```0$T`````;SLG1P```````%1K``!`0```0D,`
M````-DT``%=K````````;#@``#]`4VL``%AK;3A5:U9K``!2:P```````&)`
M248`````+T,``%TR````````````````<$@`````0S4`````-$0`````6VL`
M`%EK`````$Q#````````04!2-%IK``!;/P````!*3@```````$!/````````
M7&MG:S5$``!F:P``8VMK:V1K``!@:P``?$1?:P```````%UK```A37`[````
M`&%K``!>:P```````&5K=#T``$$X````````>D(``$5+6C%B,```)48`````
M:6L``````````&AK``!F1@``;6L```````!B:P``;&MN:P``+#AJ:U8Y``!5
M/`````!O:UA-``````````!R:P``=6L`````<VLU20```````````````'!K
M`````````````&`V``````````!T:P````!V:P``````````````````>FL`
M````=VL``'EK>&L```````````````![:P``,3P``'UK?&MH20`````A;```
M`````````````%DW``````````!^:R)L`````"-L1#5!9GD^```D;`````!N
M.``````````````E;``````F;``````^.P```````````````$Y:```G;```
M*&P``#(]```I;"IL`````"ML`````"QL+6P`````````````````````3#0`
M`'UE``!^90``````````````````````````(68````````````````B9B-F
M)&8``"5F)F8`````*&8G9@`````I9@```````````````"IF*V8`````````
M```````N9BQF+69A.E,W`````%9#```S2```<#T`````34<``&U(+V9M6```
M```````````````````P9C)F``!E33%F-&8S9@``4TT``#5F``!^2```````
M```````V9@`````````````Y9@`````X9C=F```````````Z9C(W````````
M(D%!-0``````````/F8[9@`````\9@```````#]F``!`9CUF````````*3$`
M```````G,@```````$)F0V8```````!$9@``8DT`````````````+#T``$9F
M168``````````````````````````&D_1V8``````````$AF`````$EF``!E
M-```````````330`````2F8`````````````2V8``%U+8TT```````!433=/
M``!-.4YF5#Q-9@``````````3V8I/````````%%"``!09@````!,.0``5TQ1
M9E)F`````%-F``````````!49@```````````````%5F````````````````
M```````````J/`````!M3```````````5V8``#]#``!69@``````````````
M`%EF````````6&8``````````````````%IF````````.T```%MF``!<9@``
M`````#E*768``&]!7F8`````````````7V8```````````````!^3F)F``!A
M9F!F,$0``&-F)C\``&1F````````968X3V9F``````````!G9FEF:&8E2```
M>48``#Y/*4@```````````````!K9@````!3/@``*DD``&QF:F8``$XT````
M````5#AH.P````!N2````````"HX0TL``&]F;68``$XY``!/.6DP``!H.@``
M``````````!91P````````````````````!?,'1F``!`0P````````````!8
M1P``6T(``````````````````'9F`````')F=69P9@``<V8F2P````!5.```
M``!],'%F````````````````````````>&8``'EF`````#E&````````.S8`
M```````F9SU'``````````!I.P`````\-DA`1D\N3'=F5$``````````````
M``````````````````````````!3-7IF``````````````````!\9@``````
M``````![9@````````````!]9@``)D,``#Y'`````````````#%$````````
M```C9P``````````````````(F<``````````'YF`````%4_``!E225G```D
M9U`Y4T\````````````````````````U9P`````````````I9RIG````````
M``!P/``````H9P``>#DG9P`````K9P```````#)$(DHC00``````````7$(O
M9P``,&<L9P``````````+6<``"YG``````````!1.0```````#9G```R9P``
M````````9DD``&Q+*$D`````,6<`````-&<S9P```````$1+-V<`````````
M```````X9P`````W00``.6<`````.V<``#]G`````#QG.F<_1SUG```^9P``
M`````#(R``!%9T!G````````06<```````!"9P``(4(``````````$1G0V=&
M9P``````````1V=(9P````!#/P``:3(``$EG5TX``"L\`````"T]````````
M`````&H[5T,`````````````2F=+9S$Q``!,9P````!-9TYG`````$]G``!0
M9STV*EI19P``94!29TL\``!39P``,%````````!49UY*7#0`````)$%8/0``
M<4DN/0```````````````````````%5G4CE69TQ(``!D9P``````````6&<`
M`$E"=4<_.%=G)4$```````````````!99P```````````````'I$````````
M``````````````````````````````````!;9UIG76<`````7&<``%YG````
M`&!G``!?9P``3S0``&%G``!B9V-G`````#$Z24X``&5G)S\```````!P,69G
M9V<`````````````:&<```````````````````````````````!R,```:6<`
M`````````&IG````````````````9TD```````!'/```;&<`````````````
M*3,R,```````````:V=N9TY'``!$/P``5C(``"=+``````````!=-UPV``!M
M9P``:C(``````````````````",T`````````````````````````````'$Q
M<F=J3EU"`````$1)``!^9P``5S)\9P``>F=Q9P``;V<``'!G``!C/&PV=T,`
M``````!11@````````````!1,0``=&=S9P``````````>6=U9WAG````````
M````````4$QW9U@R?3-[9P````!]9P``````````5#<`````````````````
M`"-H+&@M:````````"LP````````````````-&@``````````'$P`````"MH
M````````*F@``"5H)&@``")H(6AC0P``>T(G:````````````````"9H````
M```````I:````````'!!53<``````````$$Q*&@``%,Y`````````````'%!
M``````````````````````````````````!+/@``````````````````````
M````````````,DY%.0`````G.``````C2```;6(``````````````````&]B
M``````````!K.```````````;F)V1```````````<6(W,VQB`````&I(```P
M,0``;#H``%)/`````'!B`````````````````````')B````````2TH``%E`
M=&(``````````'5B`````````````'-B``````````!.,P``>V(``'IB````
M`"<\````````?&)W8@```````'UB>&(``````````%A(=F(`````>6(`````
M````````(F,````````````````````````````````A8V%+````````?F(`
M````:S```````````"1C`````````````````````"-C````````3#X`````
M````````)6,```````````````!#00`````G8R9C````````````````*&,`
M``````````````````````````````!H8@```````&IB*F,I8P``````````
M````````````````````````*#P``&E.``!2/```*V,W-P````````````!`
M-2<U8SL````````````````T30`````Q8P``,&-$02UC`````"]C`````$L]
M0#\N8RQC```J1P````!-/@`````\20``````````5SH`````````````````
M``````!X10`````R8P``````````,V-)8U@V`````#U/-4$``````````#1C
M`````%(R=T0A2@``````````````````````````````````-6,`````````
M````````````>C4V8P`````X8P```````#EC```I1P`````Z8P``````````
M```[8SQC`````%DV4S)%1B@]9#L``````````````````#UC```I/0``````
M``````!*,D-)`````#YC`````&M(````````````````14$``$%C``!"8VE'
M``!!/S]C``!A0P````!`8P```````$X^``````````````````````````!<
M,```````````*34``````````````````$-C`````'A$``!$8T=`````````
M`````"U,`````"-)16-&8U5#``!'3@````!(8T=C````````````````````
M``````````````!O/`````!*8W`P``````````!-8P```````$MC5#).-TQC
M1CER.0``9DI.8P````!42P````!08P```````%%`3S$Z,BPP````````````
M````3V,```````````````````````!18U)C=SX`````````````4V,``$\S
M``````````!58P```````&HW``!F-0````!68W4V`````%=C``!\0```348`
M`&!`=3H```````!88P```````````````````````&)#:T$``%IC7&-98UMC
M````````````````(C<```````````````````````!=8R8W````````9S52
M35]C`````````````&!C````````+C$``````````&-C````````=C-B8V%C
M``!E8UYC``!F8RE.``!G8P``:&,`````=%1J8P``:6,```````!K8VQC```U
M3FUC``!O<$\^;F-O8U<]```X1G!C````````*$,`````<6,``#Q#<F,`````
M````````)38``#]174,S/```````````2#0`````<V,``")D``!V8P``:#4`
M`'5C)&0```````!T8P``4#X```````````````!X8WEC```K10````!Z8P``
M7C,``````````%H_9$D``'QC````````:$(```````````````!W8P``>V-]
M8P````![.@`````````````````````````````F9"Y)```F2'E%``!:-B5D
M(V0``#5(?F->0WM%``!Z10``=CH````````````````X9```````````````
M````*&0``"ID```````````M9```+F0``"MD+&0`````*60G9```````````
M(60`````````````````````````````3TI5,@```````#5D```R9```-V0`
M````-F0``'-')TP``#L[,&0Y9#1D```S9"]D```Q9```230`````````````
M````````/4,`````?4`````````B2``````^9````````"1(````````````
M``````!A0#MD`````$](```_9%-*``!;0P``.F0\9``````]9```````````
M````````````````````````0&0`````1#P```````!&1D5D1&0`````060`
M```````V3P````````````!*9`````!.9$MD`````````````````````$=D
M````````````````2&0`````````````360```````!"9%52261#9`````!,
M9```````````````````4F0``$HT``!/9````````%!D`````%%D5&0`````
M````````````````````````4V1V2```````````561\3FU*6F0`````5V0`
M````````````````````5F120```661;9````````%AD``!?9```7&0`````
M``````````!=9$9D````````7F1@9````````````````&%D````````````
M````1DH``&)D`````````````````````&),`````$XV*3=C9```````````
M```T2@``:#\``#!,`````&1D```S3@````!T1P``1D$T1P````!-/0``````
M`$`P``!I9&=D``!E9"$T``!1/FID`````&AD``!F9&YD`````&UD;&1K9```
M``````````!O9````````'!D.D```'%D``!S9`````!R9```````````4C@`
M```````X00```````'5D````````?$4``'1D````````=F0``#5*;$%'.0``
M=V0``````````$A.``````````````````!Y9`````!Z9```>V0``'QD``!E
M.P``?61/-P````!J-0``*C4``"%E``!S3$@Y?F0````````D969,```\1P``
M```S20```````&,](V4``%,\23EF.VDU-DHB90```````$=!0DMW.@``````
M``````````````!G.UU$```G95].63H``"AE0C\``"IE````````4CXP.@``
M````````*64`````*CT^.$A!)64K90``````````)F50-P``+F4R96LW````
M`````````"UE```````````V90````!*.0````!M33PP,V4`````:S4``#!E
M`````````````#%E`````'U%+V4L90``*#-D0``````H.````````#AE````
M`````````````````````````#5E`````````````#=E````````-&4`````
M````````43<S0CEE;D$`````1F4`````0F4\90``````````````````0&5Z
M/%TP.V5#94=E2SE63```5D0]90````!%90``.F4^0P``/V4],$I,````````
M```````````^90````!;-FQ(````````;4$``%!.;ST`````;F4`````2&4`
M`'Y```!$94EE2V4``'E$3F4`````2F4```````!42DLT`````$M,`````%XP
M`````$UE``!]3@```````````````$QE`````````````&\Q`````&Q&3V4`
M``````!695!E5V4```````````````!390````````````````````![1P``
M``!*/%5E``!295AE464`````1#T``````````"5+`````$P]`````%1E8&4`
M````7&4``%]E``!=96%E6V4``$%E4T``````2T@``%YE`````%EE````````
M(4%2-P``*ST````````````````E/S9!9&4`````9F5G90````!C965E````
M``````````````!:96)E``!J96EE`````'I+`````"LW````````````````
M`````&AE``!L96ME;V4``'%E`````#P[;64``````````')E<V4`````=&4`
M`'IE.T5V90``=65W97AE``!Y90``````````>V5\979"`````&A@````````
M````````````````````````:F!63E<V?$A*1P```````&M@``````````!M
M8```<&```````````````````````````````````````````````````&Q@
M````````;V!J.$TQ<6```'`_;F!<3@````!T8"1T``````````!R8'5@````
M``````!G8'-@`````#PZ`````'9@``````````````````!W8```````````
M?DT``````````````````'A@````````````````````````````````````
M````````````>6````````!E8```````````>F``````````````````````
M1#0````````````````````````````````E/```````````````````````
M`````````'M@``````````!\8```````````?6```````````````````#LQ
M````````(6$``#M)(F$`````)#0C80``)&$``````````"5A```G82AA)F$`
M``````!322IA*6$``````````````````````````"QA*V$M80``````````
M`````"YA,&$O80````!Y.0``,F$``#%A`````$4T``!3/P``/$4``#-A.$``
M```````Z.P``>3$T80``44T`````8THU80```````$1%,TU#.3T_````````
M2T,T4@``+D1H,C9A```````````````````W80``/&$`````.F$Y84):)C,X
M80``6C```"I(`````$I(```````````Q3CUA.V%<0R9``````"M(```M20``
M/V$L3DTW0&$``#YA5DA!80``0F$`````6S``````=CY'80``1&%M1D-A````
M````````````)C4`````2F$```````!%849A``!)84AA)4D`````0D%!00``
M/S4`````2V$`````````````3&$`````36$`````````````3V$``$YA````
M`````````%8Q`````````````%=A:$A180``4V$`````56$^/P````!6851A
M0#P```````!085)A``!"20``23X`````66$`````6&$``````````%IA```F
M/"\Z`````'=%6V$``$M$`````%UA````````(4Y<80````````````!I00``
M`````````````&)A``!D865A5$,`````````````8V$``&!A``!>85]A``!A
M80``````````````````:&$``&9A``!G80``````````````````````````
M``````````````````!I86MA;&%M80``;F$`````:F$`````````````````
M````<&$```````!O80```````````````'%A````````````````14X`````
M``!T87)A<V$```````!B-`````````````!^3````````$I*``!V80``````
M`'5A``````````!W87AA``````````!\87EA>F%[80``?6$```````!^80``
M(6(````````B8@``(V(``"](4$4D8G)'-$D``"5B`````"9B*D4``"<S1#DG
M8@`````H8@`````I8@``*3L`````*V(`````*F(`````+&(M8@``````````
M````````````````````````````````````````:4@``"YB````````+V(`
M````:7,P8C%B,F(``````````"X[`````#-B5D<`````7TL``$XQ``!7,0``
M```T8@``````````-F(````````U8G!%````````.4`Y70``-V)!3```.&(`
M`$8T5T@Y8@``.F(`````.V(```````!<3````````%5,```^1````````&I!
M`````#UB`````&(]`````$H^`````$!B`````#]B/F)]2```1S0I.```````
M``````````````````````````````!&8@````!#8C\_,DP```````!"8D1B
M16(`````06(``````````````````````````````````$=B2&(``"]$``!C
M-````````&5#````````````````26(`````````````````````````````
M``````````````````!*8DUB`````````````&<_``!$1@``3F)32P``2V(`
M````3&(``````````````````````````````````%%B``````````!08D]B
M`````````````````````````````%-B`````%)B`````%1B````````````
M````````````````````5F(``%5B``````````!-2@```````````````%8]
M1DX`````5V(`````-T8`````6&(`````66(``%UB6V)<8@``6F(`````````
M`````````%YB`````````````%]B````````````````````````8&(`````
M86(W3&)B`````````````'!,8V(``$Y#``!J1P``:S8````````[0V1B.C8`
M``````!00`````````````````````!E8@`````````````].@``````````
M`````````````&9B`````````````&=B```F.%4Z````````````````````
M``````!I8@``````````5D56.DXU```````````````````````````D2P``
M2T<`````````````5T4``````````%PY`````````````&MB````````````
M````````````````````3DTP7@`````````````O7@``````````=D```"Q>
M``!L30`````V1B9>`````````````$5$````````3#$_.2E>````````````
M````)STN7@``+5XH7@``*UX`````:#,``"I>24<`````+DX`````=#YU0```
M````````````````````````````````````````````````-EXT7@``34D`
M```````````````Q7C->```Z,0````!`.3)/```],P``8DD`````````````
M84T`````)#,[/S5>`````````````````````````````#I>`````$,^````
M````,$T``#=>```````````R7@``.%X```````!>3@``<T5"1@``````````
M`````````````````````````````````````#8S`````%4Q`````#Y>````
M`$%>````````0TX```````!D30``````````2%Y"7C]>````````5$Y%7@``
M````````2CU'7@````!,7@````!Q14I>``````````!$7@`````X0P````!+
M7@``0%X``$9>``!-7GPP0UX``$Y>`````#P_``!?/0``)4H``"XZ```[7DE>
M.D4````````````````````````V0```:3-1.D0^/5Y"/0``````````````
M````3#<``#Q>````````4EYM/3HX``!A7@``6UYT-4]%``!67E]>+S`R,0``
M```Y,@``6%XL0D]>45Y!.0````````````````````!B7@``75X```````!5
M7@``````````7%X````````````````K3`````!:7EY>````````````````
M``!0.```13X`````.4,```````!47@``````````````````+TT```````!7
M7@````!07G)%`````%->````````65X``````````````````%%//CQ^2P``
M8UX````````````````````````N2`````!O7CLX`````````````&`]``!E
M7@```````"].0CD``')>`````&XP`````'!>``````````!D7@``````````
M:EX`````;%X```````!/36=>`````"Y%`````&E>``````````!Q7@``:UY'
M3````````&9>```B/'Y>``````````!J,P``:%YM7FY>````````````````
M``!L0EI"``````````````````````````````````!V7@````!\7@````!Z
M7@``*44`````(U]W7@````````````!X7F!>``!Y-3I)````````/SP`````
M=SD`````````````,T\``'1>```B7VDQ9D$`````````````````````````
M`'E'``!!-'I.```````````````````A3%)$``````````![7GU>````````
M`````#)!`````````````"%?>5X``'->````````0S0`````````````````
M````````````````````:3<````````O7P`````J7WA``````&,S````````
M``!A/0``,U\````````````````L7RQ$*5]91````````$Q?````````)E\`
M`"5?```N7P```````"A?)U\M7P``(4```"1?```````````````````P7P``
M```Q7P````````````!"-````````````````````````#9?```U7S=?````
M`````````#I?````````````````0T4``#1?`````````````#A?````````
M````````8S=Y0C)?.T<`````.5\`````````````````````````````````
M`#Y?/%\`````/U\`````0E\````````[7VHY*$<`````.5X`````````````
M``!T33U?``!!7W5"``!`7P``*U\`````:6\```````!%7P```````$E?````
M`$=?``````````````````!#7P``1%\```````!(7P``1E\```````!.20``
M``!.7P``2U]*7P``35]41D]?````````````````=4-M0@``````````)4``
M``````!07P``4E\`````````````````````````````45\`````````````
M`````````````````````'5>``````````!37P```````````````&=&````
M``````````````````````!47P``````````````````4#(```````!T124S
M``````````````````!D-0```````%X\4CH`````````````````````````
M````)T]F/P```````&HQ````````5E\```````````````!57P``````````
M`````````````````````````````````````%E?.D-<7U=?````````6U\`
M`````````%I?0$59,```````````````````````````````````=4X`````
M7E\````````H,0```````````````````````&!?````````7U\``%U?````
M`````````````````````````````````````````%A?````````````````
M```C2P```````&)?`````````````````````````````&%?````````````
M``````````````!K,0``````````9%\R2@``8U\``````````#5,````````
M``!'/@```````````````````````````````````````#-!````````````
M`$8^````````````````````````````````>TX`````:E\``'E`````````
M````````9E]K7P````!L,0````````````````````!I7P``84=E7VA?2#X`
M`%%(`````&Q?``!1/`````````````````````````````````````!Z0```
M`````````````&]?````````9U\``"<W``````````!M7P``````````4$UP
M7P```````"9T`````````````$\]`````````````````````'%?````````
M<E\``````````"Y'``````````````````!T7P``````````=5\`````````
M`#-'``````````!U17=?``````````!Y7P``54X``'9?``!X7VTQ``!S7P``
M````````````````6U-Z7P``````````9T$X.WQ?``````````![7R0_65(`
M``````````````!]7P```````"%@``!N7WY?`````")@````````````````
M>D<````````````````C8``````D8```````````````````````````)6``
M```````````````````````````````F8```7D0``"A@)V``````*6```"I@
M`````%\\8TD```````!L3"M@+&!6020\+6`N8``````````````O8%)*1T@`
M````,&!71P`````````````M1``````````````Q8&<R``!M-0``1DP``#9,
M```T,C1/``````````!22P``*DH`````````````````````-T```#)@````
M``````!#1@```````",X,V```%0Z-6`T8```````````-F``````````````
M`````````````#=@````````.&`````````````````````````^-0``.6``
M`````````#I@```````````D.`````!(2``````\8````````'4^`````#M@
M`````````````````````#@V/6`_8```/F```````````````````$!@``!1
M.```06```````````&DV``!`00``?3D``````````$-@1&!"8```````````
M`````&T\`````$A&.38```````````````````````!&8"Q#16``````-4]B
M1P```````````````````````````````$E@````````````````````````
M`````$M@2&````````!43$I@3&```$1.`````````````%!@````````3V!V
M0RU'`````"4X3F```````````$U@```Q33)-````````````````46!N,0``
M````````=CEB.P````````````````````!28%-@``````````````````!5
M8`````````````````````````````!#/0``````````5V```%9@````````
M`````%A@``!-,P````!:8`````!98```7&!;8``````````````````````\
M.``````H3@``3#8``"8R``````````````````````````!J-@``````````
M`````````````````````````````````````&$T````````````````````
M`&A.7F```````````````````&!@``````````!A8```43(`````````````
M76```#D[`````$%$7V````````````````````````````````````````!D
M8```;CP``````````&)@```````````^-P````!)2&-@`````'Y@````````
M````````:6``````````````/3@``````````&4U``!F8'U-`````#!.``!A
M70```````````````&$[```Q3```8EUC70`````D-0```````&1=````````
M``````````!F765=````````````````````````````````````````93\`
M````.4E*,0````````````!%2```=41!/6$U````````````````````````
M`````$9(```N/```````````:%T``$`T`````'@Q`````')&9UT^.5-#``!I
M70````````````!Q70``:ET`````````````04(``&(U<ET`````````````
M``!H-P`````E-7!=`````&Y=:UU@30``````````0$0```````!91FQ=````
M`'1=``!S72,W`````"TR`````#LZ;5UO70````````````!72W1"````````
M`````````````'=+`````'Q=`````'U=``!/,@``````````*$I]3"%>(SQ"
M/GA=?EUH,0``-S8`````=5UZ70```````'1`<4<``&=(````````````````
M=UT``"%+``!Y70``)%X``")>``![70```````")+2$=C-0``)44`````;4,`
M`"5>```````````C7EE"=ET``$LQ``````````!+5DA6``!*5@``<DT``$E6
M````````````````````````/U8```````````````````````````````!S
M/P````!,5@`````W.@```````$U6`````$Y6````````````````````````
M`````%%6``!05@````!/5@```````&A%.E8```````!75@``````````````
M`````````````````%-6``````````!25@```````````````````````%16
M``!55@````````````````````!85@````!F3@``65965@``````````````
M``````````````!:5@````!@-%M6``````````!=5EQ6`````%Y6````````
M``!?5@``;D`C/0````!D/0``8T$``"DY.#HJ.7`U`````&!6`````#DZ````
M`$HX858F3$-'8E8``"LY````````+#0``"=#4C8```````!4.UM)`````$%(
M``````````!C5G4T``````````!F5@``````````(40`````959D5F=6``!K
M1```````````````````8S\`````````````53L``$I```!30B(U`````")$
M`````&A6:59O/@``````````.4L`````;%8`````:U9J5GU)``!S5@``````
M````6DL``&U6`````````````&]6:TL``&Y6``````````````````!P5@``
M*$AQ5CY*<E8``````````````````````````````````#,T/THO1W16=58`
M`"PY-#1V5C@X1$TI378T>%8``"-$```M.3$^`````%](`````#(^````````
M``!X/0````````````!L1'E*.44`````+CD``%Q)````````>58`````````
M````645".@```````$LX``!M1```````````````````0S!N/2\Y1TT`````
M````````````````>E9[5E%'``````````!\5G=.+4\``````````'Y6?58`
M````1S,`````(5<````````D5R57```C5P``0$DS/B=7)E<B5P``````````
M*%<I5P`````J5P```````"U7*U<``"Q7+E<``&0Q;D0O5P``>C=V,C9'```P
M5WM&``!;2@``,5<N3P``````````,E=`2C57(5`Q4```,#QU1C97``!=-21$
M>C`W5R9*,#D`````4$,```````!O1`````````````!O3#DX3#@``#A7````
M````.5<``#]7``!E/````````"5$```O-CI7````````*TD``$9#`````#M7
M````````````````/%<``#`V```]5P``/E<`````0%<``'9%`````$%70E<`
M`$-7`````#17,U<```````!$5T$W````````)TD`````3#HW229$2TE%5P``
M```T/D8Q``!&5P```````$=7``!R3`````!@2`````!*5WTQ+$!)5TA70C=4
M0@``3E=,5P``2U<G3F4X````````>3U-5TQ%/CT```````!`1E%74%<`````
M`````$]7``!25V8X````````````````4U=\25L]`````%17>4@`````````
M`$%&)T0``````````#!%`````%57*S4`````````````-#\``"Q)````````
M````````=S0F1P````````````````````!65U8[.DL[2P````!^,5M7````
M`&E#````````6%<```````````````!W,@``````````+5A:5P```````#!'
M`````%E7`````%=7``!Z.0``75<`````````````````````````````````
M````8U=I5V%7``!<10````!F5UU)`````&!7``!E5V=.5SL`````54)>5P``
M`````%XU:%<M0&4Q8E=X,F=7````````,38``&17````````````````````
M`&I7````````````````;%=V5W17`````'%7````````<%=X3@``<E<`````
M,C8``#$Y`````'H]````````>5=K5P``````````;U=?5P``>C)S5W5744,`
M````*#HX,FU7>%=W5S,V```I0F8S``````````!#-P``;E<`````````````
M``````````!Z5P``?5<A6```````````/3P``"=8<$1[5P``````````)5@`
M`'DR```C6"18`````'Y7(E@```````!G."I-`````#4T`````%DQ)E@``#I'
M+3```````````````````&%(7%<L6#!894P``"E8````````:44N6```````
M````````````<#XO6%=&````````````````````````1T\``"M8````````
M```Q6```>SD``$M``````%0P*E@H6```6D$```````!\5S0[````````````
M``````!&0CU8``!;03A8```U6#98``!F/#E8/%@``````````#=8)3T``#I8
M`````#18``!\3'M,````````/E@_6%4P`````````````#-8``````````!R
M-B8P````````-C0``#M8`````````````$-80E@```````!'6```````````
M````````2%@``````````````````$9825A!6$58`````$I8``!+6`````!`
M6'P[``!$6%9",CDR6#4_``````````!86```:4H`````3EA/6%!8`````%=8
M``!66`````!]2S<T``!46```13<T,P````!16``````X3E-85C!56```3%A2
M6%E81#=-6````````````````%U-````````*TT``````````%Q8`````&!8
M````````?D$``'E.85@`````7E@``%M8`````%I87U@`````````````````
M```````P2@`````T1@``1C<``&)875@``&-8````````>S<````````Q,@``
M`````&M8````````.#0``````````&E8`````&I8*3IH6&9895AL6&18;E@`
M````>S(```````````````````````````````````````````````!P6```
M``!O6``````````````````````````````H1```<U@``'%89UA\-P``<E@`
M`'98=5AW6'18>%@``````````````````'E8>EAJ2@``?%A[6#\]```N0&8R
M?#(``'U8```_,````````$Q`?E@``$-L(5EA-P``(ED``````````&]`````
M````(UD````````D63HU)5D``"99)UE70@```````$TX`````&%,````````
M/$MJ/2A9`````````````'!`/6YB2```:CP``$TZ*5D``````````$="```G
M2@````!Q0@`````L60`````J60``+5D`````*UD``````````"Y9````````
M`````#%*`````#<P``````````!>20````!C2``````O60``,EDU/CLU```P
M63=9-CX``````````#%91$<```````````````!>33-9-%DX66I%-5DS.5Y`
M`````$99-$@``')"````````````````````````````````9$@M6@``````
M````>DH```````!Q1````````'5+```[62$R:D,``````````$19`````#1#
M/EE%64!91UE#60``0EEO1P``/%E],CI9<35S0C99`````#E9-#E;0```-SY!
M65)'`````'(U2#,``````````````````````````&<S(3])64Y9``!*60``
M?3<``$]9(CMI.0```````````````"8]/5D``'T[3%D``````````%@[35E$
M,`````!(60``````````*40``````````````````',U`````````````#0V
M``````````````````!+62<P`````$,Z````````-C\`````````````````
M`````````')$`````%1(45E>00```````````````````````"I"`````"L[
M4ED``%194%D``````````&%*```]1```````````7$$`````````````````
M`````````'M*3CQ@60``7UD`````>#\```````!^-P```````%E9.3X`````
M:$8Q1P``````````5UD`````74$``````````'@\7%D`````.#X``%996UD`
M````4T<```````!560``(3<`````73,```````!=62M.3CHU0UI9``!<0```
M-3ED/V8Q/$%8644U`````````````$<W``!/1%Y9`````````````%]!````
M`&%9``!C60`````W0FE9``!D60````!F60````````````!!27-$``!G60``
M`````"Q-````````2$TY-``````````````N,```95D`````````````8ED`
M`````````'@T`````````````&<Q``!H60```````$E-````````````````
M`````````````&Q9````````````````.T(``'-9````````;5D`````:EEQ
M60``````````4UD```````````````````````!N60``<ED```````!"2&M%
M````````````````:UD``&]9````````2#<```````!Q.@```````%U`````
M`````````````````````````'=9````````````````````````)D4`````
M````````````````````````````````=%D``&!+`````````````'59````
M````````````=ED``$Y,```B0`````````````````````!B-P``````````
M?5D````````````````````````U.WI9``!Y60``````````,D<````````U
M1@`````````````Q17M9````````?%D``&])``!%1R,[``!Q0```4$L`````
M``````````!),P``)5I^60``````````2DTG6@`````C6@``)%H`````````
M````8$$``````````"):```_60```````"9:```A6@`````````````K6BQ:
M)T4N6@`````D.RE:```````````\-0`````O6@``*%HS6@``,EH``#%:````
M````-%H`````-EIQ/@``-5H``````````#E:````````````````````````
M````````````````````````-UH````````X6G!9`````````````#M:.EH`
M````````````>%D\6C!:`````%D[```````````]6CY:0%H_6D%:?C(``#8Y
M`````'Q*+T``````````````3C@`````0UH``````````$9:``!220``7S4`
M``````!%6D1:5$='6C4V````````25I(6@```````#HT-CL`````6$8`````
M````````23<```````!T/P``2EH``#!`*$4``%])2UH`````````````````
M``````!,6DU:````````.$I=549``````$Q)``!8.@``94A#2```````````
M``!-10``04X``$]:4#P`````4%H``#8P`````%0V34```&!)````````45I"
M.T=#``!;.S<_````````````````4EH``'U*`````'<Q7#L```````!56@``
M4UI66CE.5%H``````````'M`5UH`````,D(`````6%H``````````'HT``!:
M6@``65H``````````%M:7%I[-`````!\1C9#;#5=.V%!`````%P],#``````
M``!=6@`````````````````````B,F%:````````````````-SE@6@`````K
M.CH^`````%]:```[/@``0$PJ.@```````%<P3D```````````````````&9:
M`````#%`1S$``````````%4]``!F2W(Z```````````\/@``)T``````````
M`&5:8UID6@````````````!K0P`````F6P``:EI^.S@Y:%H``````````&E:
M```X/P```````&=:`````"\[``````````````````````````!L6FM:<%H`
M````<5H``&U:```B,VY:;UI52```````````84E*-W):````````,D```#T^
M````````4D,```````````````!'-@``<UIW6@````!+,G1:=EH`````````
M`'5:`````&L]``````````!(0T4P>%H``````````'E:```````````J1```
M`````'%.``````````!#.P````!K2@`````````````]2P```````");>UH`
M````?EH``'U:`````'I:`````"%;`````%Y&``!\6@``````````````````
M`````````````"-;`````&P])%L``$M->$<`````)5L`````````````)UL`
M````*%L````````````````I6P``2C9(,3DY*EL``"M;<3UB00````!84CY!
M/4%80D<Z`````')0``````````!N-RU-``!^2@``?DD``"Q;``````````!S
M.C]$+5LO3P```````#Y+```K1"Y;?#0````````````````O6S!;6DP``"1,
M=DM<2R4[,EL`````:SP`````44L``#1;-ULV6P``>30`````8#4``#-;```U
M6P``````````.%L`````>3\``````````'M-23!@.CQ"``!=/`````!S/@``
M```[6P````!.10``.5LK0CI;<CY=3#Q;/5MH30``````````0EL`````.CD`
M`%5'/UML15Y:8EH``$\U``!'1P``````````05L``#X^1$@`````````````
M1UL``'I(```^6P``1%M#6P```````$]```````````!M2P``4TX`````9TL`
M`$PR7CL`````2$]&6W4_````````15L`````0%L`````````````3S@`````
M``!,6TI;``!-,DA;3EM46P``````````````````2$(`````04H``%9;````
M````(DD```````!56W!'/TL[-```=T!`/0```````%-$```N30````!16U!;
M````````4EL``$];`````%=;``!-6P````!+6P``4UM)6P``;$,``'A,1CQT
M.@`````````````Z.@````!O2T$S`````$Y$2D9),0``````````````````
M``````````````````!R0``````T0"HW````````````````65L`````.SE\
M,P```````````````%M;=#-A6P```````````````%Y;``!S0````````$LS
M+#H`````2C-/.@````!<6V4W2S=M10````!:6P``1C```````````%U;7UL`
M`$TV+#<``#PT2S4``````````&);`````'DZ<4L``#<[````````8UL`````
M```P20```````````````````````````````&];```S,F1;````````````
M````=5ME6P``0DX``&Q;``!?1P``````````````````=%L``&=;````````
M-#!I6P`````\.0```````&M;``!J6P``9EMQ6P``/SX```````!M5&@X?$T`
M`````````&A;``!T1",S+3H``&!;``!P6V$S`````&Y;<EL``&Y%````````
M``````````!^-```,EP`````24QW6WTT``!^6P``````````0$L``"%<(UP`
M`"=<>5L``"I#``````````!O12M<?%L``"A<````````(EP`````````````
M```Y/RQ<`````#-`````````````````*EP]-`````````````!03W9;````
M`"9<6#``````>%L`````.DQ]6R(_1T1S6P`````E7````````````````'H_
M+UQQ,R$X```````````Q7'I;,%P``"E<>UL``"U<```N7``````````````_
M7````````$Y&```D7``````[7````````#U<``!81```````````````````
M````````3$T`````````````````````=DDX7$I"````````/EP_00``-5Q"
M7$%<``!O1D!<:D8``````````````````$1<-UP``$@V.EQ=/0```````&!'
M/%Q+-@``-%PV7#-<`````#!/6C,Y7`````!#7#4S``````````````````!G
M.@```````%TQ`````%1<`````#%/5UP`````````````.C]67````````%5<
M````````````````4EP```````````````!&7`````!C7$5<``!87```````
M`````````%!<`````$M<2%P``$E<``!17````````")T`````$Y</3E(1&1!
M3%P``$=<`````$I<``````````!-36I+````````3UQ97```````````````
M``````!A7%I<`````&=<``!E7```````````8%P```````````````!?7```
M4$0``&5!``!=7`````!;7`````!B7```````````:%QU2&Y<````````````
M`&E<;%QF7`````!T0P``.$D``%Q<`````&1<0#X``$],>%QK7```````````
M```B.",R7S,`````4UP```````````````!!/G!<``!W7'D\<C,`````+D,`
M``````````````!M7`````!R7'9<`````#8V````````````````````````
M````````3#5T7``````````````A-0``2T9S7````````'5<````````````
M`````````````````&]<`````````````'%<````````````````8#-)0P``
M`````'Q<`````````````````````'I<:3@``'E<````````````````(5T`
M`````````%A;````````>UP``'U<?EP````````````````L70``*%T``&U;
M```````````G70``````````)ET`````(UT`````````````:EPE721=````
M```````````````````````````````J70``)D\````````````````M77LV
M`````"E=*UT`````````````````````)T@``"Y=````````````````````
M````````````````````,ETO70````````````````````!S33!=````````
M``!>7```````````````````,UT````````T70```````````````#4Q```V
M76<W(3P``%4V````````)#(``````````````````````````%]-````````
M```X73==.ET]-0````!6-CXT```````````]70```````#Q=```^70````!.
M,@``-T,``#]=`````#\T05T``````````$!=``!"70```````$-=``!$75\[
M-4`A.@``<$D`````8DI$3P``````````=3L```````!0.G).````````15U&
M70``8#L```````!'74A=`````$I=25T``%A+`````%X];#Q$.P``2UT`````
M`````````````$U=(S\``$Q=`````````````$Y=`````````````$]=````
M`````````%!=45T```````!270``5%U3755=)3)*0P``5ET`````)CM,,U==
M`````$)%3%0``````````",U6%T``````````%E=``!L2FA+````````1T9:
M769(````````>T@`````4TP```````!;70``````````````````````````
M``!=75Q=`````%]=````````7ET``````````````````#Q50%4]50````!'
M,C]5````````````````.SP``#Y5>3<```````!,50````````````!%54)5
M````````````````````````9$,``$%5`````$-5`````$15````````````
M``````````````````````````````!&54=5````````````````````````
M``````````!R-```255(50```````````````````````$I5````````````
M`````````````````&X^``````````````````!-50``7$0```````!%,0``
M2U4```````!.50``````````````````3U4``%)5`````%!5``!150``````
M````````````````````4CM350`````F.515``!Z.SA"``!555956CLG.0``
M4DP````````H-4DX5U58,P````!850``.4(``````````%E5(U8``%I5``!;
M50````!<50``7E4`````````````7U4`````8%4``'!"```G,6D\0C```%=!
M,#0U/```*#D`````````````9D4``"$],31H0VI$.#`Y-75*``!"/`````!2
M-6M`/#PH36%5``````````````````!<-0``2SH`````,C-C,2P^2#(``&)5
M1DT`````````````23T`````9#QC57,T4D8I3&15``!E50````!920``````
M`&=5```H-'<V9E4````````````````R-```,C]K52$[``!),FI5``!H56Q5
M:54K1TU<,S\``&U5`````$!.``!N50````!P50``?D-O50``(T```'L[````
M````4$)W/```=4EL0```33QQ52T^<E5S55,P.D)2/P``=%4S1BX^```O/@``
M=54`````;4`````````P/@````````````!V50``=U4``&!,````````>%4`
M`````````$8V````````(CT```````````````!Y57I57#PL/W1&5#]X2")'
M239[50```````&\U?%4``'XV``!/1C`R``!3.WU5(E8A5GTV``!^50``.$4`
M````````````````````,$(``$M%2#P`````6$%Z30```````````````"16
M```E5E9&```S.P``````````)U8`````*%8`````````````````````````
M```````````````````````I5@```````'0T*E8`````*U8`````````````
M```````````````````L,@```````````````#M!9#0``"U6*$P`````````
M`%)"``!9,P`````O5C%67S0`````+E8P5@``,U8````````````````R5@``
M-%8`````````````````````````````````````````````-58`````````
M```````]1BXV````````````````93(V5CM6`````#E6``!W2G9*````````
M`````&=%````````.%94/0``-U8```````````````````````!R/P``````
M`#Q6`````&HZ`````$)6`````$-6/58S,SY61U9&5D56058```````!`5@``
M``!$5@```````````````'A*`````#14`````&(_`````````````#)4-50`
M`#\W```````````````````V5````````````````````````````````#=4
M```D.4`S.50`````````````.E0`````````````.U0`````.%0`````````
M```````````````````````Q5``````\5``````]5```````````9$L`````
M:SX````````_5$!4/E0``$)4`````````````#A'`````&@P5DD`````0U0`
M`````````````````````````````````````````'T^`````#D\``!=1W`T
M``!K.@```````%E+```R1@````!X-T]"````````051$5```````````````
M`````````$1"````````150```````!&5````````$A4`````&E$````````
M`````"XT```````````A=&$Q<TH`````;#Y(10``````````9CH`````3E0`
M````/4I=3@````````````````````!T,DI4`````````````#I!350``&-%
M`````$E%9$4Y2$U$````````23H```````!)5````````````````'8Q```V
M10``````````2U0``$=4`````%`_````````3U0``````````$X]````````
M```M-@``4%0``````````````````````````````````&A*````````?4$`
M`````````$9$`````%)4`````````````````````$]+`````%-4`````%A4
M```````````O2@``````````5U115%145E0`````)CH`````24H```````!9
M5```14,`````=3(``&T^``````````!;5```6E0``&@Y``!<5%Y4750`````
M8%0``%548E0``````````&%47U0`````````````3CM1/P``5$%C5#Q`;3!D
M1P``````````6T0``&549%1F5&=4:%0``````````&E4````````````````
M44IJ5```````````1C)K5```````````/$TP,P``25)(/3]";%1K3```````
M```````T3`````!N5```9T(``#=%0$)726]4<%1[,0`````Z/'%4````````
M``!0,')4`````````````'-4`````````````&(Q`````'$T8$9T2@``````
M````=U1507940#<`````6TMU5```945Y5```>%0`````````````>U0``'I4
M`````'PQ``!\5"D^?E0E0P``?50``#-*``````````!W/5M%````````(54`
M`````````"4Y````````(E4A1UY(44P`````````````)4<`````*U4`````
M````````.#4`````14T`````+TP``"Q6```C50`````````````F50``14(`
M````.$L```````!*10`````````````G50```````````````&5+``!*.@``
M```J/@``````````````````*%4`````4#L``$\[```````````Y,$@X```K
M0%$P```````````L52U5```J50`````````````````````X,2\T```I50``
M14PQ20``````````````````````````*#```````````'DP````````43L`
M`%(P```C,``````````````R50``````````````````,%4`````````````
M```\3```,U4``#%5`````"]5,3\``````````"Y5````````6DH`````````
M````9#@`````````````-U4X50`````````````K/@```````#15+$\`````
M`````$Q'`````#95```````````````````````````````````````````G
M.@``````````````````.54```````!820```````#I5```U50``````````
M`````````````````````````````````````#M,````````````````````
M````````````````````````````7D<``````````````````#M5,DD`````
M``!!4T93``!"4P``/5,`````1U,Q00````!)4P``(CD_4WU#````````````
M````````````````````0U,\4RTT``!N-&4S1%-`4P``````````````````
M=C=*4TA34T%*-2PV``!%4P``=#8`````````````1#$`````````````````
M`````````````````$Y33%,``"=4````````````````````````````````
M45,`````````````2U,``$]3`````$U3````````3#M04P``````````````
M`````````````````````````````````%-3``!84P```````%9355,`````
M`````````````#)#`````$4R``````````````````````````!24P``5%,H
M/C,Q`````%=3``````````````````````````````````!>,@``````````
M``!B4P``?#Y>4P``7%,``%U3``!?4P```````````````````````#TQ````
M````````````````````.4$``%E3``!:4P``````````````````````````
M>C,`````````````````````85,```````!O-```9%-@4V-3````````````
M```````N2@```````%5&```X2`````````````!F4P````````````!E4T4S
M`````&=3``````````!J4P``````````:5,`````````````````````````
M````:%,``#E'`````&M3`````````````````````&Q3`````````````&Y3
M``!M4P````````````!P4P```````'-3<5-O4W)3``````````!T4P``````
M``````!U4P````!V4P``=U,```````!X4T51``!\/$T[`````',R``!X,```
M``!$0P``````````````````````````>5,``"0Z``!/,%X_````````````
M`'I31S@`````<3D``'Q3>U,`````8$I]4P```````"%4?E,``")4```C5```
M=S<`````8#$D5``````F5```)50````````H5`````!:10``````````````
M`"E4-3!?.@``````````/3<`````3T,````````````````J5"M4`````"U4
M```````````N5```9#H``````````%$V`````#=+````````+%0O5$$Z(SD`
M```````````````````````````````````````S5``````E.@``,T,`````
M,%1:1#13(TT``"<^```Z4P``````````.5,P4P``````````0T(``#%3````
M````;T(V4R8^`````````````#-3`````&1,````````/#<`````-U,X4P``
M````````-5,[4P`````````````R4P``````````````````````````;#!Z
M0P``-SP```````!\2V8^,#ME/CPR``!423]-```B4"\Q`````&XS(U`D0$)2
M5C4Z2@``````````9SX`````/DX``````````$)*````````)%``````9D,`
M```````E4'HV````````)E```%TT,$,``&<\)U``````*%``````*5`U1P``
M5S4`````````````-T<``&-&0S@S2P````````````!):2I0:#XK4#4R````
M````939P.&E,`````"96`````````````````````````````````````'!-
M``!]1@``````````````````````````)30``#4U```L4``````M4#M.```]
M36A!+U!V.W-&```R4``````^,5\X``!>.&8P`````$M/2D\``#,Z(3```#-0
M-%`U4#1+-E```'(X9S!R2P``?#4`````?35^-6)$/$X``#=0`````#A0````
M`#E0````````33\`````````````.CU./SY0```\4```/5!8-0`````C.G`R
M```[4#I0*4H``````````$8[13L^0C]054EG0````````#@A0%!"4```````
M`&5"84Y*,```````````````````05`^,@``1#8``&=#````````;S=#4```
M`````"1'`````````````&LT``````````````````!$4$LP`````&`X;#1Z
M23)(634`````````````````````<3(``&=0044`````````````````````
M````````````````````````;$=&4````````#Q(``!B3@``+3\``$<[``!W
M.T`R`````````````%%$`````")#2E``````````````3#!C1#L]-#HD30``
M3D(``#\R``!)4```/DU%4$=0;CI(4"15``````````````````````````!0
M4`````````````!34%%0`````$(R```[2DM0``````````!/4',X`````$@[
M````````)C0`````5%```$Q0`````&-.``!X.P``35```%)0``````````!5
M4```3E``````(38``$TP`````"(V03(````````````````````````E50``
M>4MN270X`````````````"\_-TX`````````````````````6$H`````.#<E
M0F0R`````````````%,]````````65```%Y07%``````5U``````+T):4```
M75!;4```74H``%A0```N/P``<TM?4&!0`````````````````````"0];5``
M``````!01P``-DEH4```<$H``#8R````````;%````````````````!F4&]0
M`````%)!``!$.```7$<``$=@``!N4%U%``!C4```=C@`````=3AA4```````
M````6CP``&E0``!O2DU#95!Q-P``8E!J4&1044YK4$%/````````````````
M`````&8V`````'`W````````````````````````<%````````!Q4'503C``
M````````````4$IT4```````````<U!W4````````'90``!D1```````````
M``````````!R-P```````````````'A0`````````````$4\```F0F5$=C8`
M`'E0```````````V-0````!Z4```````````?%```````````````````#5+
M````````9C<````````````````Q.W=(>U``````````````````````````
M````````````````````13I#30``````````?E`C47U01#H``'T]````````
M````````.3<````````D40````!/-@```````"%1(E$`````+T8``'Q!```C
M-@```````$U+)5$````````]3@```````"91```````````I40``)U$``$Y!
M`````````````"A1*E$````````````````L40```````"M1``!(2@``````
M````-S4N42]1```O,@``````````+5$`````````````````````=#P``#)1
M,5$P40``5E```#-1``````````!^/0``-%$`````````````````````)4T`
M`````````````````%E,```````````V40`````U43A1-U$`````.5$Z470P
M```U.#LW/#U[0R0V:$!W.```;CD\44A,1D4``'D[```[40``/5$`````````
M````7D4``'4S`````````````#Y1`````'Y&`````#1!0%%!42Q(>#@[3T)1
M`````"8V````````/$HV0G$V-44```````!S-P```````$-1``!$40````!B
M1E\Q`````$=1?3H``$911CH``$A1;F9)44%+2E$``$M13%%I/@``3#P`````
M```````````G-```3U$``$U1/4Q.40``6DE045%14E%?10```````%915%%5
M45-18SI746I,9$X`````````````6%$````````````````H0%E16CT`````
M6E$``'Q#/TY@10````````````````````!%4@``````````6U$E=$4V````
M`%Q17DL``````````&@]?$(``%Y19$8`````7U$`````8%$N,P```````&%1
M)S8``$Q&>C%0/0`````A2&)1``!A10````!//V-1```L2EI`(C0``"DT9%$`
M````9E$`````.C<`````95$`````<TX`````````````:3T`````````````
M```]2$Q*``!G40``>$UH40```````&E1``!^10````!J40`````I0'XZ=#=K
M44D[;SD``````````````````&9$;5$`````)T(`````;SIN46]1,$$``&Q1
M``````````!Q40``-DL``````````&0Y`````'!1``````````!U-UXZ;4<`
M``````!T47)1``````````![26H^>U%D,W51<U%/00``````````````````
M=U$``'91````````1#,```````!@-WQ1+4X```````!X40```````'U1>E$`
M`'E1````````````````3TX```````!Y.$,R`````'1.`````````````'4]
M6$5E.2)2(U(```````!E3@`````K3R52````````>C@`````)%(``"\S````
M`"92``!62P``/$0``"9-``!92@```````"=2``````````!5<``````P1@``
M*%(J-#-,````````(3XI4F=*+5(``"I`*E)0-@``*U(K-```````````````
M````````````+C<N4@``+U(`````,%(Q4EL\````````>SA>3```:$QW1@``
M``!Q2C)2```S4@``````````-5(``#=2-E(``````````#A2/3),2P``?#HY
M4@````!900`````B/BDV```Z4@```````````````%M(```````````[4@``
M/%(``#U2```````````^4B1):#9E,````````#]&/U(]/0``:4```$%20%(C
M/F$X0U(^2`````!$4@```````%Q(-$)N0B@V`````&Y&,4,``&Y'``!.2P``
M1E(``&I``````````````#4W`````$=2``````````!(4BPQ=3!M-```*$)1
M-7%-``!+4C<R`````$I2````````*C8`````3%(``'%,````````````````
M`````````````````````````````$U2``!23@``?#@``````````#8X3E(`
M`````````%!23U(``%\_.3$```````!>,5%2``!24@`````W.`````!34@``
M````````;C4````````````````R.U12``````````!T2S4Z6C4G35!!/TA]
M/`````````````!'/0``:#QU/```=CT``$!(````````5U(``$,Q44%].$4X
M9S8`````6U(A0WY"*S8D/EQ26E)$,F9".#Q+.R8Q`````'`S9CE*.P``75(`
M``````````````!>4@``235&,P```````&<Y2#5?1"4Q,48^3"$Y>4U'17XX
M````````````````````````+S<``&=2``!C-DI+`````````````%U(````
M`&92``!>-&%28E)D4@``````````````````95(``%LU83\``"U*8U)?4F,X
M``!@4@``)$\```````!R2@``:$1B.'`Y````````:%(`````748`````````
M`````````````````````````&Q2`````````````````````'X\``!V/```
M``````````!O4FU2```C3```:E)S4FY2````````<5)&.#],`````')2````
M````=%(``'92``````````!P.D)/``!K4FE2=5(``'!2````````````````
M````````````````````````>%(``"-3>E(`````?E(`````(5-[4@`````^
M4P````!I.C$S``````````!Y4@```````"53=C`D4P``)3!*22)3``!\4@``
M``!W4GU22#H`````````````````````````````````````)E,`````````
M````````````=S`O4P`````G4RA3```E/FE+````````+5,L4P```````"]%
M```````````````````N4P`````K4P```````````````#0Q```V.C`_````
M```````````````I4V)%````````*E,``"(P````````````````````````
M(20B)",D)"0E)"8D)R0H)"DD*B0K)"PD+20N)"\D,"0Q)#(D,R0T)#4D-B0W
M)#@D.20Z)#LD/"0])#XD/R1`)$$D0B1#)$0D121&)$<D2"1))$HD2R1,)$TD
M3B1/)%`D4212)%,D5"15)%8D5R18)%DD6B1;)%PD721>)%\D8"1A)&(D8R1D
M)&4D9B1G)&@D:21J)&LD;"1M)&XD;R1P)'$D<B1S)```````````````````
M*R$L(34A-B$`````(24B)2,E)"4E)28E)R4H)2DE*B4K)2PE+24N)2\E,"4Q
M)3(E,R4T)34E-B4W)3@E.24Z)3LE/"4])3XE/R5`)4$E0B5#)40E125&)4<E
M2"5))4HE2R5,)4TE3B5/)5`E4252)5,E5"55)58E5R58)5DE6B5;)5PE725>
M)5\E8"5A)6(E8R5D)64E9B5G)6@E:25J)6LE;"5M)6XE;R5P)7$E<B5S)70E
M=25V)0``````````)B$\(3,A-"$`````(2$B(2,A-R$``#DA.B$[(5(A4R%4
M(54A5B%7(5@A62%:(5LA*2(N(DPA32$```````````````!!(78B`````'4B
M``!T(FHA``!I(7HA>2%^(@``````````````````(R(B(@``````````````
M````````````````````````````)2(D(@`````````````````````G(B8B
M`````````````````````"$B?B$```````![(0````!](7PA(2@L*"(H+2@`
M````````````````````(R@`````+B@D*``````O*"8H`````#$H)2@`````
M,"@G*#PH`````#<H`````#(H*2@^*``````Y*``````T*"@H`````#@H/2@`
M````,R@J*``````Z*#\H`````#4H*R@`````.R@`````0"@`````````````
M````````-BA>(ETB/B(_(@`````\(CTB````````````````````````````
M````8B(``````````````````````````````````&(A82(``````````&4A
M9B$`````8R)D(@```````````````$\B``!?(E`B````````8"(Z(@`````[
M(@```````````````%TA``````````````````!E(@````!G(F<A``!<(@``
M`````````````$HB2R)!(D`B:2)J(@``````````````````:"%H(@``````
M````````````9B)-(@``3B(K(BPB*B(M(G(B;B$`````````````````````
M```^(0``````````/2%"(0``1B%'(0````!((4DA`````'<B>"(```````!%
M(40A````````````````````````<R(``&PA;2$``````````````````"@B
M```````````G)P`````````````````````````````````````A)R(G(R<D
M)R4G)B<H)RDG*B<K)RPG+2<N)R\G,"<Q)S(G,R<T)S4G-B<W)S@G.2<Z)SLG
M/"<])SXG/R=`)T$G42=2)U,G5"=5)U8G6"=9)UHG6R=<)UTG7B=?)V`G82=B
M)V,G9"=E)V8G9R=H)VDG:B=K)VPG;2=N)V\G<"=Q)P``5R<`````````````
M```````````````````````````A)B(F(R8D)B4F)B8G)B@F*28J)BLF+"8M
M)BXF+R8P)C$F```R)C,F-"8U)C8F-R8X)@``````````````````029")D,F
M1"9%)D8F1R9()DDF2B9+)DPF329.)D\F4"91)@``4B93)E0F5296)E<F6"9@
M(5\A`````````````'$A<B$```````!X(2\A````````3"(```````!K(5XA
M`````"TA``!Y(D`A``````````````````````````!9;%IL6VP```````!<
M;```76Q>;%]L8&P``&%L````````````````8FQC;````````````````&1L
M``!E;`````!F;`````!G;`````````````!H;````````&EL````````:FP`
M`&ML;&QM;`````!N;&]L<&P`````````````````````````````````````
M`````'%L``!R;`````!S;````````````````````````'1L````````````
M````````````=6P``````````'9L`````'=L``````````!X;'EL>FP``'ML
M?&Q];`````!^;``````A;0```````````````")M`````"-M)&T`````````
M````)6T`````````````)FTG;2AM*6T``"IM```K;2QM```M;2YM+VT`````
M```P;0`````Q;0```````#)M````````,VTT;0```````#5M```V;3=M```X
M;0`````Y;0``.FT[;0``/&T];0``/FT``#]M``!`;4%M0FU#;41M````````
M`````````````````````$5M``!&;4=M2&U);0``2FT`````2VU,;0``````
M`````````````````$UM3FT```````!/;5!M46U2;5-M``!4;0``56T`````
M`````%9M`````%=M````````````````````````````````````````````
M`%AM66U:;5MM``!<;0``76U>;0```````````````%]M`````&!M86UB;0``
M8VT``````````%EK`````````````````````````````%IK``````````!;
M:P``7&L`````````````````````7FL`````````````````````76L`````
M````````7VL`````````````8&MA:P```````&)K8VMD:P``````````````
M````````````````````````````96MF:P``9VMH:VEK`````````````&IK
M``!K:VUK``````````!N:V]K``!L:P``<&L`````<6L`````````````````
M````<FMS:P``````````````````````````=&L`````=FMU:P``=VL`````
M``!X:WEK>FL``````````'MK`````````````'QK?6L```````!^:R%L```B
M;```````````(VPD;```)6P````````F;``````G;"AL````````*6PJ;```
M*VPL;"UL+FP`````````````````````+VP`````````````````````,&P`
M`#%L```R;``````S;````````#1L````````-6P`````-FP`````-VP`````
M```X;````````#EL```Z;#ML````````````````````````/&P];#YL/VP`
M````0&P```````!!;$)L0VP``````````$1L``!%;```1FP``$=L`````$AL
M``!);`````!*;$ML````````````````````````3&P```````!.;```````
M````3VP`````36P```````!0;```46Q2;%-L`````%1L56P`````5FP`````
M5VQ8;`````````````````````!6:0``5VD``%AI66D`````6FD``%MI7&E=
M:0````!>:0``7VD`````8&EA:0``8FD``&-I`````&1I``!E:0``````````
M``!F:0``9VD``&AI`````&EI:FEK:0```````&QI;6D```````!N:0``````
M`&]I<&D``'%I``!R:0````!S:0````````````!T:75I``!V:0```````'=I
M>&D`````>6D``'II>VE\:7UI?FDA:B)J`````"-J)&H``"5J)FHG:BAJ```I
M:@``*FH````````K:@`````L:@``+6HN:@```````"]J`````````````#!J
M```````````Q:@``,FH`````````````,VHT:C5J```V:@``-VHX:@`````Y
M:@``````````````````````````.FH`````.VH\:@``````````````````
M```]:CYJ/VH```````!`:@````!!:@````!":@``0VH``$1J16H``$9J``!'
M:DAJ26I*:DMJ``````````!,:@``36H``$YJ3VI0:@````````````!1:E)J
M````````4VI4:E5J5FH``%=J6&I9:@``6FH``%MJ7&H```````!=:@``````
M``````!>:@````!?:F!J``````````````````!A:F)J``!C:@````!D:@``
M`````&5J9FIG:@``````````:&II:@````!J:FMJ``!L:FUJ``!N:@``````
M``````!O:G!J`````````````'%J``!R:@```````````````'-J=&H`````
M`````'5J``!V:@````````````!W:@``>&H`````>6IZ:@```````'MJ````
M````?&H```````!]:GYJ(6LB:P`````C:P``)&LE:P``)FL`````````````
M````````)VL````````H:P``*6L``````````"IK```K:RQK+6L``"YK```O
M:P```````#!K,6L`````,FLS:S1K-6LV:P```````````````#=K````````
M.&LY:SIK`````````````#MK````````/&L``#UK/FL_:P```````$!K06L`
M``````!":T-K1&L`````16M&:P``1VL``$AK`````$EK4&M*:TMK3&L`````
M``!-:P``````````4FM.:T]K46L`````4VL``%1K``!5:P````!6:P``5VL`
M``````!8:P````````````````````````````````````!W:```>&@``'EH
M````````````````>F@```````````````````````![:'QH?6@`````?F@`
M```````A:2)I`````"-I```D:0```````"5I`````````````"9I````````
M````````````````)VDH:0``````````*6DJ:0``*VD``"QI````````````
M`````````"UI`````"YI+VDP:0```````#%I````````,FDS:0```````#1I
M````````-6DV:0```````#=I.&DY:0```````````````#II.VD````````\
M:3UI```````````^:0``````````````````/VD``$!I``!!:4)I0VD`````
M1&D`````````````16E&:0``````````1VD``$AI26D``$II````````````
M`````````$QI`````$UI`````$MI`````$YI3VE0:0``46D`````4FD`````
M4VD``%1I````````````````56D`````````````````````````````````
M`$AH``!):```2FA+:$QH`````$UH`````````````````````$YH`````$]H
M`````````````````````````````%!H``````````!1:%)H````````````
M`````````%-H````````5&A5:%9H`````%=H6&A9:`````!::`````!;:```
M`````%QH76@```````!>:`````````````!?:&!H86AB:&-H````````9&AE
M:&9H9V@```````!H:&EH``````````!J:&MH;&@``````````&UH;F@`````
M````````;V@```````!P:'%H``!R:'-H``!T:'5H=F@Z:```.V@\:```/6@`
M```````^:``````_:$!H``!!:$)H````````0V@`````1&@`````16@`````
M1F@```````!':`````````````````````````````````````!$9D5F````
M````1F8``$=F2&9)9@````````````!*9@``````````2V8``$QF````````
M369.9D]F4&8``%%F4F8```````!39@``````````````````````````````
M````````````5&8``%5F``!69E=F6&8`````````````````````668`````
M``````````````````````````!:9@````````````!;9@``````````````
M`%QF768``%YF7V8``&!F869B9F-F``````````!D9@``````````````````
M968``````````&9F````````9V8`````:&8``&EF``````````!J9FMF;&8`
M````;68``````````&YF;V8```````!P9@```````````````'%F````````
M````````````````````````````````<F8``````````````````'-F````
M`````````'5F``!V9@````!W9GAF>68```````````````````````!Z9@``
M``````````![9@``?&8`````````````````````?68`````````````````
M`'YF(6<``")G````````(V<`````````````````````````````````````
M`````"1G)6<``"9G````````)V<H9REG```````````J9P``````````````
M```````K9P``+&<``````````````````````````````````"UG```N9P``
M`````````````"]G````````,&<Q9P`````````````R9P``,V<T9P``-6<V
M9P``````````````````-V<````````X9P`````Y9P```````#IG````````
M```[9P`````\9SUG/F<`````/V<``$!G``!!9T)G````````````````````
M`$-G`````````````````````````````$1G16=&9P``1V=(9P```````$EG
M2F<`````2V<```````````````````````!,9P``36<`````3F=/9P````!0
M9U%G``!29U-G5&<``%5G``!69U=G``!89P````!99UIG``!;9P``7&==9P``
M7F=?9V!G``!A9V)G`````&-G`````&1G96=F9P``:F<``&=G:&<``&EG:V<`
M````;&<``````````````````````````&UG``!N9P````!O9P````!P9W%G
M``!R9P```````````````````````````````'-G`````'1G`````'9G=V<`
M````````````>&<``'EG`````'5G`````'IG``![9P``?&<`````?6<``"AH
M?F<``````````"%H`````")H(V@D:```)6@F:```)V@`````````````````
M````*6@`````````````*F@`````*V@`````+&@````````````````M:"YH
M+V@`````,&@Q:```,F@S:```````````````````-&@U:```-F@W:```````
M`#AH```Y:'UE?F4``````````"%F`````````````")F````````(V8`````
M```D9B5F)F8`````````````````````````````````````)V8H9BEF```J
M9@``````````*V8`````+&8``"UF+F8``````````````````"]F```P9@``
M`````#%F`````#)F```S9@```````````````#1F```U9C9F```W9@``````
M````.&8Y9CIF.V8`````````````/&8]9@`````^9C]F0&9!9@```````$)F
M``!#9@``+6$`````+F$O80`````P83%A,F$`````````````````````````
M````````````,V$T80``-6$`````````````-F$``#=A.&$``````````#EA
M````````.F$[80``/&$`````/6$``#YA/V$``$!A````````````````````
M``````!!80````!"84-A````````1&$`````````````16$`````1F$`````
M``!'84AA``````````!)80````!*80```````$MA``!,80```````$UA````
M````3F$`````````````````````````````3V$`````4&$`````````````
M``````````````````!185)A5&$``%5A5F$``%-A````````5V%880````!9
M80``````````````````6F$```````!;85QA``````````````````!=80``
M``````````````````````````````````!>80``7V$``````````&!A````
M````86%B80``````````8V$```````!D80```````&5A``````````!F80``
M``````````````````````````!G80````!H80````!I86IA``!K80``;&$`
M`````````&UA``!N86]A<&$``'%A``````````!R87-A=&$`````=6$`````
M`````````````````````'9A``!W87AA>6$``'IA````````````````>V%]
M80``````````?F$A8B)B```C8B1B````````?&$`````````````+6(`````
M)6(``"9B)V(H8@`````I8BIB```K8@`````````````L8@`````````````O
M8@```````#!B,6(````````R8@``+F(``````````````````#-B-&(U8@``
M`````#9B-V(X8@``.6(``````````#IB`````#MB````````/&(``#UB/F(_
M8@``0&(``$%B``!"8@``0V(``$5B1F(``$1B``!'8@``2&(``````````$EB
M2F(``$MB`````$QB``!-8DYB``!/8E!B``!18E)B`````````````%-B````
M````5&)58@```````````````%9B````````5V(```````!88@``66):8EMB
M`````````````%QB`````%UB`````%YB`````````````%]B````````````
M````8&(``````````&%B8F)C8@````````````!D8@``96(``&9B9V(`````
M``!H8@```````&EB`````&IB``!K8FQB;6(`````;F(`````````````;V(`
M````<&(``````````'%B``!R8@```````'-B=&)U8@``=F)W8GAB>6(`````
M>F(``````````'MB?&)]8@``?F(`````(6,B8P``(V,`````````````````
M`````````````````"1C)6,`````)F,``"=C*&,````````I8P``````````
M```J8RMC````````+&,M8P``+F,O8S!C,6,R8S-C`````````````#1C```U
M8P``-F,``#=C`````#AC.6,`````.F,[8SQC/6,``#YC/V,``$!C````````
M06,``$)C0V,`````1&,``$5C````````1F-'8P````````````!(8TEC2F-+
M8P``3&,`````````````36-.8T]C`````%!C``!18U)C``!38U1C56,``%9C
M``!78P``6&,``%EC6F,`````6V-<8P````!=8P````!>8U]C8&,``&%C````
M````````````8F-C8P````!D8V5C`````&9C9V,```````!H8P``:6-J8VMC
M``````````!L8VUC;F,``````````&]C<&-Q8W)C<V,``'1C=6-V8P``=V,`
M````````````````````>&-Y8WIC`````'MC?&,```````!]8P``````````
M?F,``"%D`````````````")D(V0````````D9"5D```F9"=D`````"AD````
M````*60`````*F0````````K9```+&0``"UD+F0O9#!D```Q9#)D,V0T9#5D
M```V9#=D.&0Y9``````Z9#MD/&0]9```/F0`````/V0``$!D``!!9$)D0V0`
M````1&1%9```1F1'9$AD``!)9```2F0``$MD3&0```````!-9```3F0``$]D
M`````````````````````%!D``!19````````%)D4V0``%1D````````````
M`%5D``````````!69````````%=D`````%AD660```````````````!:9%MD
M7&1=9```7F0`````7V1@9```860``&)D8V0`````````````````````9&1E
M9```9F1G9````````````````````````````````````````&AD:61J9```
M`````````````&MD;&1M9`````!N9```;V1P9```<60```````!R9```````
M``````!S9'1D``!U9```=F1W9`````!X9```>61Z9'MD``!\9'UD``!^9```
M`````"%E`````")E```C921E)64F90`````````````G90``*&4I90``*F4`
M`"ME`````"QE`````"UE`````"YE`````"]E`````#!E`````#%E```R93-E
M```T90``-64[90``-F4`````````````````````-V4X93EE````````.F4`
M```````````````\90`````]93YE/V5`90``065"94-E1&5%90``````````
M``!&90````````````!'90````!(90``265*90````!+90```````$QE364`
M``````````````````````````````````````!/95!E3F5195)E``!390``
M`````%1E564``%9E````````5V5890```````%EE6F5;90````````````!<
M95UE7F4``````````````````%]E````````````````````````````````
M`````&!E864``&)E8V5D965E````````````````9F4``&AE``!G90``````
M`&EE``!J90````!K90``;&4``&UE`````````````````````&YE````````
M;V4`````<&4`````<64``')E``!S90``````````=&4`````=64``'9E=V5X
M90``>65Z90``````````````````````````````````````````?&5[90``
M``````````````````!&7P```````$=?`````$A?``!)7P``````````````
M````````````````````````````2E\`````2U\``$Q?````````35\`````
M`````$Y?`````$]?4%\```````!17P````````````````````!27U-?5%\`
M````````````55\``````````%9?5U\`````6%\`````65\`````6E\``%M?
M``!<7P``75]O7P```````%Y?``````````!?7V!?85]B7P``8U\```````!D
M7P````!E7P````!F7V=?``!H7P``:5\``````````````````````````&I?
M:U\``&Q?``````````!M7P```````&Y?<%]Q7P``<E\`````````````````
M````<U\```````!T7P````!U7W9?=U\``````````'A?`````````````'E?
M`````'I?``![7P```````````````````````'Q??5]^7R%@`````")@(V``
M```````````````````````D8```)6``````)F`G8"A@*6`````````J8```
M```K8"Q@````````````````````````+6```"Y@+V`P8```````````,6``
M```````````````R8#-@-&`U8``````V8#=@````````````````.&``````
M.6`Z8```.V`\8#U@```````````````````^8#]@0&````````````````!!
M8$)@`````````````$-@````````````````1&```$5@`````$9@````````
M``!'8$A@``!)8$I@````````2V```````````$Q@``!-8````````$Y@3V``
M`````````%!@``!18```````````4F!38```````````5&!58```5F!78```
M``!88```````````````````66```%I@`````%M@``````````````````!<
M8`````````````````````````````!=8```````````9&!>8```7V!@8```
M``````````!A8```8F!C8`````````````!E8```9F```````````&=@:&``
M``````````````!I8&I@`````````````&M@;&!M8`````````````!N8```
M;V!P8```<6```')@``!S8'1@````````=6!V8'=@`````````````'A@>6!Z
M8'M@`````'Q@`````````````'U@?F```"%A````````(F$`````````````
M`````"-A```D825A)F$G82AA`````"EA```````````J82MA````````````
M````+&$````````````````````````````````````````J7RM?````````
M```````````````````L7RU?`````"Y?```O7P```````#!?````````````
M`#)?,5\`````,U\````````T7P```````#5?````````````````-E\`````
M```W7P`````X7SE?```Z7P`````[7P``/%\]7P`````````````^7S]?``!`
M7P``05\`````````````0E\`````````````````````0U\``````````$1?
M````````15\``````````````````````````````````&)>8UX```````!D
M7F5>````````````````9EX``&=>``!H7@``:5X```````!J7@``:UX``&Q>
M;5X`````;EYO7G)>``!P7@``<5X`````````````<UYT7@``=5X``'9>=UX`
M``````!X7@````````````!Y7@``>EY[7@``````````?%X`````?5X`````
M`````````````'Y>(5\````````B7P``````````(U\``"1?)5\`````````
M````)E\``"=?*%\``````````````````"E?````````-%TU739=-UTX70``
M`````````````````````````````#E=````````.ET``#M=```\70``````
M`#U=```^70`````_70````!`70```````$%=``!"70``````````0UU$70``
M15T``````````````````$9=``!'74A=``!)74I=````````````````````
M`$M=``!,70``35T``$Y=``!/70``````````4%U170````!270``````````
M``!370``5%T`````````````55U670``5UT`````6%T``%E=``!:70``6UT`
M``````!<75U=``````````!>70````!?76!=85T```````!B76-=````````
M9%T```````!E70``9ET``````````````````````````````````&==:%UI
M70``:EUK76Q=`````&U=;EUO70````!P70````!Q70``````````<ET`````
M``!S771=``!U70```````'9==UT``'A=`````````````'E=````````````
M``````!Z70``>UT``````````'Q=?5T```````!^70`````A7B)>````````
M(UX`````)%X``````````"5>`````"9>```G7BA>*5X````````````````J
M7@``*UXL7BU>```N7@`````````````O7@``,%X`````````````````````
M```````````Q7@```````#)>````````,UXT7C5>`````````````#9>````
M`#=>`````````````#A>.5X````````_7CI>`````````````#M>````````
M```````````````````\7@``/5X^7@``````````````````````````````
M````0%X`````05X```````````````!"7@``````````0UX`````````````
M1%Y%7D9>1UY(7@``25X``````````$Y>``````````!*7DM>3%X`````````
M`$U>``````````!/7@``````````4%X```````````````````````!17@``
M``````````````````!27@``4UY47@````!57@``5EX`````5UX`````6%Y9
M7@````````````!:7@``6UX``%Q>``````````!=7EY>````````````````
M7UX``&!>85X``````````#E<```Z7#M</%P`````/5P^7```````````````
M````/UP``$!<````````````````````````````````````````05P`````
M0EQ#7```1%P```````````````````````!%7$9<1UQ(7$E<`````$I<2UQ,
M7```````````````````35P`````3EP`````````````````````3UP`````
M`````````````%!<45Q27````````%-<``!47```````````````````````
M`%5<``````````!67````````````````%=<6%Q97`````````````!:7%M<
M``!<7%U<7EP``%]<````````8%P`````````````85QB7&-<````````````
M``````!D7&5<9EP`````9UP```````!H7&E<````````:EP``&M<``!L7```
M``!M7&Y<`````&]<`````````````'!<`````'%<``````````!R7`````!S
M7'1<=5P``````````'9<=UQX7```````````````````>5P`````>EP``'M<
M`````'Q<``!]7```````````?EPA72)=(UT`````````````````````````
M````)%T````````E70`````F70```````"==*%T`````````````*5TJ70``
M```K72Q=```````````M70``````````````````````````+ET````````O
M73!=,5TR70``````````,UT`````````````````````````````35@`````
M``````````````````!.6`````````````````````````````!/6```4%A1
M6```4E@`````4U@``%18``!56%98````````5U@``%A865A:6```6U@`````
M``!<6````````%U87E@``%]8`````&!8`````````````&%8`````&)88U@`
M`&18``!E6````````&989U@```````!H6````````&E8````````````````
M````````````````:EAK6```;%@`````````````````````;5@`````````
M`````````&Y8``!O6'!8<5@``````````')8``!S6`````!T6```````````
M``!U6`````!V6'=8``!X6```>5@``````````'I8>U@```````!\6`````!]
M6````````'Y8`````````````````````"%9````````````````````````
M```B60`````C60``````````)%DE6299)UD``````````"A9`````"I9*UD`
M`"Q9```````````M62Y9````````+UD``````````#!9```Q60``,ED`````
M````````````````````````,UD``#19````````-5DV63=9.%D``#E9````
M`#I9.UD````````\60`````I63U9/ED``#]9`````````````````````$!9
M````````````````05D`````````````````````0EE#641915E&60````!'
M60````!(60````!)64I92UE,64U93EE/60``4%D```````````````!160``
M`````%)9````````````````````````4UE46559``!660``5UD``%A9````
M````65E:60````!;60``7%E=60````!>60```````%]9``````````!@60``
M````````85D``&)98UD``&19`````&59``!F60````````````!T60``````
M`````````&=9``!H66E9:ED```````!K66Q9;5EN60````!O60``````````
M<%D`````<5ER60````!S60```````````````````````'59``!V60``````
M````=UEX60````````````!Y60``>ED``````````'M9`````````````'Q9
M`````'U9`````````````'Y9`````"%:(EH````````C6B1:````````````
M```````E6B9:```G6BA:*5H`````````````*EHK6@``+%H`````+5H`````
M+EH`````````````+UH``#!:````````````````````````````````,5H`
M`#):```S6@``-%HU6@`````V6F8X-UH````````X6@``````````````````
M```````````Y6CI:`````#M:/%H]6CY:````````/UH`````0%I!6D):0UI$
M6@``````````15H`````1EH`````1UH`````````````2%I)6DI:`````$M:
M``````````````````````````````````!M6@``````````3%H```````!-
M6@``````````3EH``$]:``!06@``45H``````````%):``````````!36E1:
M55H``````````%9:````````5UH``%A:65I:6@``6UI<6EU:````````````
M`%Y:7UI@6@``85H``&):`````````````````````````````&-:9%H`````
M95H``&9:`````&=:``!H6@```````&E:`````&I:``!K6@``;%H`````````
M``````````````````````````````````````!N6@``;UIP6@``````````
M`````'%:<EH``'-:````````=%H`````=5IV6G=:`````'A:>5H`````````
M`'I:``````````![6GQ:``!]6@``?EH``````````"%;`````````````");
M(UL``"1;)5L````````````````F6R=;```H6RE;*EL``"M;`````"Q;```M
M6P``````````````````+EL``````````````````````````"];````````
M```P6P```````#%;`````#);,UL````````````````````````T6P``-5LV
M6P`````````````````````W6P``````````````````.%LY6SI;.UL\6SU;
M/EL``#];0%L```````!!6P````!"6P``0UL``$1;15M&6P``````````1UL`
M`$A;`````$E;````````2EL``````````$M;3%M-6P````!.6P```````$];
M`````````````````````%!;45L``%);````````````````4UM46U5;````
M````5EL```````````````!76UA;`````%E;6EL``%M;`````%Q;`````%U;
M7EM?6P````````````!@6V%;``!B6P```````&-;``!D6P``````````95L`
M`&9;``````````!G6P``:%L``&E;`````&I;`````&M;;%MM6P``````````
M;EL``'!;<5MR6P```````'-;;UMT6W5;=EL``'=;>%L`````````````````
M````>5L``````````'I;>UL``'Q;``!]6P````!^6P``````````(5P``")<
M```````````C7```)%P``"5<`````"9<)UPH7"E<`````"I<`````"M<````
M````+%PM7```+EP``"]<```P7``````Q7#)<````````,UP``````````#1<
M```````````````````U7```````````````````-EP``#=<```````````X
M7`````````````````````````````````````!]5P``````````````````
M?E<``````````"%8```B6"-8```D6```)5@``"98````````````````)U@`
M`````````"A8```I6"I8`````"M8+%@``"U8+E@O6```````````````````
M```P6#%8```R6``````S6$Q8````````````````````````````````````
M```````T6#58-E@````````````````W6```.%@`````````````.5@Z6#M8
M`````#Q8`````````````````````#U8```````````````````````````_
M6```0%@`````````````````````````````05@``$)80U@`````1%@`````
M`````$58``````````!&6````````$=8``````````!(6```25@```````!*
M6````````$M8````````````````9%4```````!E50``9E4`````````````
M``!G50```````&A5````````:54`````````````````````````````:E4`
M``````````````!K50````````````!L50``````````````````````````
M````````;54``&Y5``````````````````!O57!5````````<54`````````
M``````````````````````!R57-5````````````````````````````````
M`````'15``````````!U50``=E4`````=U4``'A5>54``'I5>U4`````````
M`````````'Q5````````````````````````````````?55^50``(58``")6
M(U8`````)%8`````)58F5@```````"=6```````````H5@``````````````
M````*58``````````````````````````"I6*U8L5@```````"U6```N5@``
M+U8````````P5@`````Q5@``````````,E8````````S5@``````````-%8`
M`````````#56```V5@`````````````````````W5@``.%8`````.58``#I6
M`````````````#M6```````````\5@`````````````````````]5CY6````
M`````````#]60%9!5@```````$)6``!#5@``````````````````1%8`````
M``````````````````!%5@````!'5DA6258``````````$I6`````$M6``!&
M5@````````````!,5@``358`````3E8`````3U8```````!05@``````````
M``````````````````!15@```````%)6``!35@```````````````%16````
M``````````````!65@``5U8``````````%A6558`````659:5@``````````
M``!;5@``7%8```````!=5@``7E9?5@````!@5@````!A5@``````````````
M`&)68U8```````!D5F569E8`````9U9H5@``:59J5@```````&M6``!L5FU6
M`````&Y6`````````````````````````````&]6````````<%9Q5@``````
M````<E9S5@````!T5@```````'56=E8`````````````=U8`````````````
M``````````!X5@``>58`````````````>E8`````````````````````>U9\
M5GU6?E8``````````"%7`````")7(U<``"17```````````E5P``````````
M```F5P```````"=7`````"A7````````*5<`````````````*E<`````````
M```````K5P```````````````"Q7```M5P``+E<O5S!7```Q5S)7`````#-7
M```T5S57````````-E<`````-U<`````.%<``#E7```Z5P``.U<\5P``````
M````/5<^5P``/U=`5P````!!5T)70U=$5P```````$57``!&5P``1U<``$A7
M`````$E7`````$I7``!+5P``3%=-5P```````````````$Y7````````````
M````````````3U<``````````%!7``````````!15P````````````!25P``
M4U<``%17````````55<``%97`````%=7``!85P```````````````%E76E<`
M````````````6U=<5P``75=>5P````````````!?5V!7``!A5V)7````````
M````````````````````````````````9%<``&579E=G5P``:%=I5P``````
M`````````````````&I7:U=L5P``;5<`````;E<```````!O5P````!P5P``
M<5=R5P``````````<U=T5W57`````'97`````````````'=7>%<`````>5<`
M`#Y88U=Z5WM7?%<`````````````````````;%1K5&U4;E1O5````````'!4
M<50`````<E0``````````````````'-4`````'14=50`````````````````
M`'94=U1X5````````'E4``!Z5'M4?%1]5````````````````'Y4````````
M(54`````````````````````````````(E4C5215)54`````````````````
M`````````"95```G50``*%4I52I5```````````K52Q5```````````M50``
M````````+E4O50```````#!5````````,54`````,E4````````````````S
M50``````````````````-%4`````-54V50`````W50``````````.%4`````
M````````.54Z50`````````````````````````````[50```````#Q5````
M````/54``#Y5`````#]5````````0%4``$%50E4`````0U4`````````````
M`````$15`````$551E5'50``````````````````2%5)50``2E4`````2U5,
M54U5``!.50``3U5050``454```````````````!255-55%5550```````%95
M``!750````````````!850``654``%I5````````6U5<50``754``%Y57U4`
M`&!5``!A50``8E4```````!C50```````````````#Q*`````````````#U*
M```^2@```````````````#]*0$I!2@```````````````````````$)*````
M````0TH`````1$H`````14H``$9*``````````!'2@```````````````$A*
M````````24H``````````$I*````````2TI,2@``````````````````34I.
M2D]*``!02@````````````````````!12E)*4TH`````5$H``%5*5DH`````
M``!72@``6$H``%E*``!:2@````!;2@``````````7$H`````74H`````7DI?
M2@``8$H`````````````84IB2@````!C2F1*`````&5*``````````!F2@``
M````````9TH```````!H2FE*``````````!J2@``````````````````:TH`
M``````````````````````````````!L2@``````````;4IN2@````!O2@``
M``!P2@```````````````````````'%*`````')*`````````````'-*``!T
M2@````!U2@````````````````````!V2G=*``!X2@```````````````'E*
M`````````````'I*``````````````````````````````````![2GQ*````
M`````````'U*?DH`````(4L````````B2P``(TLD2P``)4L````````F2P``
M)TL``````````"A+*4L``````````"I+*TL``````````"Q+````````+4L`
M`"Y+`````"]+,$L````````Q2P``````````,DLS2P`````T2P``````````
M-4LV2P``-TL`````````````.$L````````````````````````Y2P`````Z
M2P``.TL````````\2P``/4L``````````#Y+/TM`2T%+`````````````$)+
M0TL``$1+``!%2T9+``!'2TA+``!)2P````````````!*2P``2TL`````3$L`
M``````!-2TY+``!/2P``4$M12P``````````````````4DL``%-+`````%1+
M``!52P``5DM72P```````%A+``!92UI+6TL``%Q+`````%U+7DL```````!?
M2V!+``!A2P``````````````````8DL``&-+``!D2P````!E2V9+``!G2P``
M``````````!H2VE+`````&I+``!K2VQ+`````&U+`````&Y+;TL`````<$L`
M````<4L```````!R2P```````'-+``!T2P````!U2W9+``!W2P``````````
M````````````````>$MY2P``>DL``'M+?$M]2P``?DL``"%,(DPC3``````D
M3``````E3``````F3````````````````"=,`````````````````````"A,
M*4P`````````````````````*DP``"M,```L3"U,+DPO3#!,,4PR3#-,-$PU
M3```````````````````-DP````````````````W3``````X3#E,```Z3#M,
M````````/$P``#U,````````/DP_3```````````0$P`````````````04P`
M`````````$),````````0TQ$3$5,`````$9,``!'3$A,`````$E,2DP`````
M`````````````````````````````$M,3$P```````!-3$Y,3TP``%!,````
M`````````%%,4DQ33%1,`````````````%5,5DQ73```6$P`````64Q:3%M,
M``!<3`````!=3```7DQ?3&!,84P`````8DQC3```9$QE3`````!F3```````
M`&=,``!H3````````&E,`````````````````````&I,:TP`````;$P`````
M``!M3`````!N3```````````;TP``'!,<4P`````<DQS3```````````=$P`
M``````!U3```=DQW3````````'A,``````````!Y3`````````````!Z3'M,
M?$P`````?4P```````````````!^3``````````````````````````````A
M30```````")-(TT`````````````````````)$TE30`````F30`````G30``
M*$TI30``````````*DT````````````````K30`````L30```````"U-+DTO
M33!-`````#%-````````,DTS30`````````````T30``-4T``#9-````````
M```W30```````````````#A-.4T``#I-````````````````````````````
M```````[30``/$T``````````````````#U-/DT_34!-04U"30````!#30``
M`````$1-``````````````````````````!%30``1DU'30``2$T```````!)
M30````!*30````````````!+30``3$T`````````````````````````````
M``````````!-30````````````!.30``````````3TU035%-`````%)-``!3
M30````````````!430``54U630``````````````````5TT``````````%A-
M`````%E-6DU;30````!<30````!=30``````````7DT``%]-8$T``&%-````
M``````````````!B30```````````````&--``!D365-9DT`````9TUH30``
M:4T``&I-`````&M-`````&Q-;4T``&Y-;TT`````<$T``'%-<DUS371-````
M``````!U30``=DUW30````!X30```````'E-``````````!Z37M-``!\30``
M``!]37Y-(4X``").````````)$XE3@``)DXG3BA.````````*4XC3BI.````
M````````````````````*TX````````L3@`````````````M3@``````````
M+DXO3@``````````````````,$XQ3C).```S3@`````T3@``````````````
M`````````````````#5.````````-DX````````````````W3CA.````````
M```````````Y3@`````````````Z3CM./$X``#U./DX``#].0$Y!3D).0TY$
M3D5.``!&3@````!'3@```````````````````````````````````````$A.
M````````24X```````!*3@```````$M.``!,3DU.``!.3@````````````!/
M3@``````````4$X```````````````!13@````````````!23@``4TX`````
M``!43@```````%5.5DX``````````%=.`````%A.`````%E.````````6DX`
M````````````6TX```````!<3@```````%U.````````7DX``%].8$X``&%.
M``!B3F-.``!D3@````````````!E3@````````````!F3@``````````9TYH
M3FE.``````````!J3FM.;$X`````;4X```````!N3F].````````<$X`````
M<4YR3@```````'-.`````'1.=4YV3@````!W3@```````'A.>4X`````````
M`'I.``![3GQ.?4X``'Y.```A3P`````B3P`````C3P``)$\````````E3P``
M)D\G3RA/`````````````"E/`````"I/`````"M/````````+$\`````````
M`````````"U/+D\````````````````O3S!/,4\````````R3P``````````
M,T\`````-$\``````````#5/`````#9/````````-T\X3P``.4\````````Z
M3P`````````````````````[3P``````````/$\`````````````/4\`````
M`````````````#Y//T\`````0$\```````!!3P``````````0D]#3T1/````
M````14\``$9/````````1T\``$A/````````24]*3P````!+3P```````$Q/
M`````$U/````````````````````````3D]/3P````!03P```````%%/4D\`
M````4T\`````````````````````````````5$\```````!53U9/5T\`````
M``````````````````!83UE/``!:3P``````````6T\``%Q/````````````
M`````````````````%U/7D\`````7T]@3P```````&%/``!B3P```````&-/
M````````````````````````9$\``&5/``!F3V=/``!H3VE/````````:D\`
M`&M/````````;$\`````````````````````````````;4\```````!N3P``
M``````````````````````````!O3P``````````<$\``````````'%/````
M````<D\``````````'1/=4]V3P``<T\`````=T\```````!X3P```````'E/
M>D\`````>T]\3WU/?D\``````````````````"%0```B4```(U``````````
M`````````"10)5`F4``````G4```*%`````````I4"I0```K4"Q0````````
M```N4````````"]0,%`Q4``````M4```,E`````````S4```````````````
M````-%`U4``````W4#A0`````#E0.E`````````[4#90`````````````#Q0
M`````````````#U0````````/E`````````````````````````_4```0%``
M`$%00E!#4```````````1%```$50``!&4````````$=0````````2%``````
M25!*4`````````````!+4```3%```$U0``````````!.4$]04%````````!1
M4%)0````````4U```%10`````%50````````5E``````5U!84```````````
M````````````````65```%I0``!;4````````````````%Q0````````````
M````75```%Y07U```&!0````````````````````````````````85!B4```
M````````8U```&1095!F4&=0``!H4`````!I4&I0``````````!K4```````
M`````````&Q0;5```&Y0````````;U```'!0`````'%0````````<E``````
M<U````````````````!T4```=5``````=E!W4```>%```````````'E0````
M``````!Z4```>U````````!\4`````!]4'Y0```A40``(E$`````(U$`````
M`````"11)5$``"91````````)U$````````````````H40```````"E1````
M`````````"I1*U$````````L40``+5$N40``+U$``````````#!1````````
M,5$`````````````,E$`````,U$`````-%$`````````````-5$````````V
M40``-U$``#A1.5$````````Z43M1`````#Q1/5$^40``````````````````
M`````#]10%$``$%10E$```````!#40````````````````````!$4451````
M`$91`````$=12%$``$E12E$``````````$M1``!,40````!-40````!.40``
M````````````````3U$`````4%$`````````````45$``%)1``!340````!4
M4551````````5E%740``````````6%%940````!:40``````````````````
M`````%M1``!<40````!=40````````````````````!>40``````````````
M`%]1``!@40```````&%1``!B46-1````````````````````````9%$`````
M95$`````9E$``&=1`````&A1````````````````````````:5$`````````
M``````````````````````!J46M1``!L46U1``````````!N40````!O40``
M`````````````'!1``!Q47)1`````````````````````'-1````````````
M````````````````````=%$``````````````````````````'51````````
M=E$```````!W40``>%%Y47I1``![47Q1?5%^42%2`````")2````````````
M`````````"-2```D4B52)E(`````````````)U(````````````````H4@``
M`````````````"E2```````````````````````````J4@```````"M2```L
M4@`````M4BY2`````"]2```P4@`````Q4C)2````````,U(`````````````
M```````````````````T4@``````````-5(``````````#92```W4CA2````
M```````Y4@``````````.E(`````.U(``#Q2```````````]4@``````````
M`````#Y2`````#]20%(``$%2`````$)20U(```````!$4D521E)'4@``````
M````2%(`````25(`````2E(``$M2````````````````````````3%(``$U2
M3E(``$]24%)14@```````````````````````````````%)2``!34@``````
M````````````5%(``%525E(`````5U)84EE2``!:4@``6U(`````7%)=4EY2
M7U(``&!2`````&%2``!B4F-2``!D4F52````````````````````````9E(`
M`&=2``````````!H4@``````````:5)J4@``:U(```````!L4@``````````
M;5(``&Y2;U(``'!2`````'%2<E(`````````````````````````````<U(`
M``````!T4@```````````````'92=U)X4@``=5(```````!Y4GI2>U)\4GU2
M?E(`````(5,``")3````````(U,``"13````````)5,F4P``)U,``"A3````
M````````````*5,`````*E,K4P`````````````````````L4RU3````````
M```````````N4P``````````+U,````````````````````````P4P``,5,`
M````````````,E,````````````````````````S4P`````````````T4S53
M`````#93-U,X4P`````Y4P``````````.E,`````.U,\4SU3````````/E,`
M`#]3````````0%-!4T)3``!#4P``1%-%4P````!&4P``````````````````
M``!'4P````!(4P``25,```````````````````````!*4P``````````````
M````````````````````2U,```````!,4TU33E,`````````````3U,``%!3
M45-24P````!34P```````````````%1355,``````````%93`````%=3````
M````6%,`````65,```````!:4P``````````````````````````6U-<4UU3
M``!>4U]3`````````````&!385,``````````&)3````````8U,``&13````
M````95,``&939U,``&A3:5,``````````````````&I3``!K4P````!L4P``
M``````````!M4P``````````````````;E,``&]3<%,```````!Q4P``<E-S
M4W13``!U4W93``!W4P````!X4WE3>E,```````![4P``````````?%-]4P``
M``````````!^4R%4```````````````````B5"-4`````"14````````````
M`````````"54`````"94)U0``"A4`````````````````````"E4*E0K5"Q4
M+50`````````````+E0O5#!4`````````````````````#%4```R5```````
M```````````````T5``````U5#94````````-U0X5```.50````````Z5```
M`````#M4/%0`````/50^5``````````````S5```````````````````/U0`
M`````````````````$!4050```````!"5```0U0``````````$14150`````
M1E0```````````````!'5$A4````````251*5```2U0```````!,5`````!-
M5`````````````````````!.5```````````3U105```450`````````````
M``!25```4U0``%14`````````````%54````````````````5E0``%=46%0`
M````650`````````````6E0`````6U1<5````````%U4``````````!>5```
M``````````!?5`````!@5```````````851B5`````!C5`````!D5```````
M`&54````````9E0`````9U0``&A4`````&E4:E0`````````````````````
M``!A20````````````````````!B26-)9$EE269)````````9TEH20````!I
M20````````````````````````````````````!J20``:TD`````````````
M`````````````&Q)``!M20``;DEO27!)````````````````<4D`````````
M````````````<DD```````!S271)=4D`````=DEW20``````````>$D``'E)
M``````````!Z20````![20``?$D``'U)``!^20``````````````````(4H`
M`````````````````````````````````````````")*````````````````
M(TH``````````"1*```E2@``````````)DH`````````````)TH`````````
M`````````"A**4H``````````"I*```K2@``````````````````````````
M`````"Q*+4H``"Y*+TH````````````````P2@``````````,4HR2C-*````
M`#1*````````````````-4HV2@```````````````#=*`````#A*`````#E*
M.DH``#M*```````````````````````````````````[2```/$@]2```````
M````````````````````/D@``#](``!`2````````````````$%(````````
M0D@``$-(``!$2$5(`````````````````````$9(``!'2```2$A)2```````
M````````````````````2D@`````2TA,2`````!32```34A.2`````!/2```
M``!02```````````44A22```````````````````````````````````````
M`````````%1(``!52%9(5T@```````!82```64A:2`````!;2%Q(`````%U(
M7D@`````````````7T@```````!@2```````````````````````````````
M````````````84AB2```````````8T@```````!D2&5(`````&9(9TAH2```
M``!I2```:DAK2&Q(``!M2````````&Y(``````````!O2'!(``````````!Q
M2')(<TAT2`````````````!U2'9(=T@``````````'A(>4@`````````````
M>D@`````````````````````>T@``'Q(?4@``'Y(````````````````````
M````````````````````(4D````````B20```````````````````````"-)
M)$D````````````````E20``````````)DD````````G20`````H22E)````
M`"I)```````````K22Q)+4D`````````````+DD`````````````````````
M```O20`````````````````````P20`````Q20``````````````````````
M```````R20``````````,TD`````-$D``#5)`````#9)````````````````
M-TDX20```````#E).DD[23Q)`````$%)`````````````#U)/DD`````````
M`````````#])0$D`````````````0DE#20```````````````$1)``!%20``
M`````````````$9)1TD``````````````````$A)`````$E)````````2DE+
M20``````````````````````````````````3$E-24Y)3TE020````!120``
M``````````````````!220```````````````%-)``````````!4255)````
M`%9)`````%=)````````````````````````````````````````````````
M6$D```````````````!920``6DE;25Q)74D``%Y)````````7TD`````````
M`````````&!)````````````````:4<```````!J1P``````````:T<`````
M`````````````````````&Q'````````;4<`````;D<``&]'<$<`````````
M`````````'%'<D<`````<T=T1P``=4<```````!V1P``=T=X1WE'>D<`````
M>T<``````````'Q'?4=^1P```````"%((D@``````````"-(````````````
M```````````````D2```````````````````)4@``"9(````````````````
M````````````````````````)T@`````````````*$@`````````````*4@`
M```````````````J2````````````````"M(`````````````"Q(+4@`````
M+D@``"](```````````````````P2````````#%(,D@S2```-$@````````U
M2#9(```W2``````X2#E(.D@`````````````````````````````````````
M/4<````````````````^1S]'``!`1P```````$%'``!"1P``````````````
M````0T=$1P````````````````````````````!%1P````````````!&1P``
M````````1T<```````````````````````!(1TE'``!*1P``2T=,1TU'````
M`````````````````````````````````````````$Y'``!/1P``````````
M````````4$<`````44<``%)'````````4T<``%1'``````````!51P``````
M`%9'``!71P```````%A'64<```````````````!:1P``````````6T<``%Q'
M``!=1UY'``!?1P````!@1P```````&%'`````````````&)'8T<```````!D
M1P``94<`````````````9D<```````!G1P```````&A'`````#U$```^1```
M/T0`````0$0`````040```````````````!"1`````!#1````````$1$````
M``````!%1`````````````````````!&1````````$=$````````````````
M``!(1$E$2D1+1```3$1-1`````!.1````````$]$4$111```````````````
M````4D131````````%1$540```````````````````````````````!61```
M````````5T0```````!81```640`````````````````````6D0```````!;
M1%Q$``!=1`````!>1```7T0``&!$``````````````````!A1&)$``!C1```
M9$0`````````````````````940`````9D0`````````````````````9T0`
M`````````&A$:40``````````````````````````&I$`````&M$````````
M`````````````&Q$;40``&Y$``!O1```<$0`````````````````````<40`
M`')$<T0``'1$`````````````````````````````'5$``!V1````````'=$
M``````````!X1`````!Y1`````!Z1````````'M$````````?$0`````````
M`````````'U$``!^1```(44`````(D4````````C10`````D125%````````
M`````"9%)T4`````*$4I10```````"I%```K12Q%+44`````+D4O10``````
M````,$4`````````````````````,44`````,D4`````,T4`````````````
M```T10``-44``````````````````````````#9%`````#=%```X10`````Y
M13I%```[10``/$4`````````````/44````````````````````````^10``
M/T5`14%%`````````````$)%`````````````$-%````````1$5%149%````
M`$=%`````````````````````$A%245*10```````````````$M%``!-14Q%
M`````$Y%````````3T4```````!015%%4D4`````````````4T5410``````
M`````````%5%`````%9%``````````!710```````%A%645:10``````````
M`````````````%M%7$4``````````%U%7D4`````7T5@10``844`````````
M````8D5C161%`````````````&5%````````9D4`````9T4`````````````
M:$4```````!I10````!J16M%`````&Q%`````````````&U%;D4`````````
M`&]%````````<$4```````````````!Q10```````')%`````'-%````````
M``!T10```````'5%``!V10``````````=T4`````>$4```````````````!Y
M10```````'I%`````'M%``!\10``````````?44``````````````````'Y%
M(48````````B1@`````C1@``````````````````````````````````````
M```````D1@```````"5&````````)D8G1@``*$8I1@``````````*D8K1@``
M```L1BU&+D8``"]&```````````````````P1C%&````````,D8S1@``````
M````-$8U1@``````````-D8`````-T8````````````````````````X1@``
M`````#E&````````````````.D8``#M&`````#Q&/48````````````````^
M1@`````_1@````````````!`1@``048`````````````0D8`````0T8``$1&
M148```````!&1@```````$=&2$8``$E&``!*1@```````````````$M&````
M`````````$Q&````````````````349.1D]&````````4$8``%%&````````
M``!21@``4T941@```````%5&5D8```````!71@``````````````````````
M````6$991@``6D8``%M&`````%Q&``!=1@``````````7D8``%]&8$8`````
M`````````````````````#9'````````848``&)&``!C1@``````````9$8`
M`&5&``!F1F=&``!H1@```````````````````````&E&:D9K1@``;$8`````
M`````````````````````&U&;D8``&]&<$8```````!Q1@````!R1@``````
M````````````````````````````````````<T8``'1&``!U1@``````````
M````````````````````````=D8```````!W1@```````````````'A&``!Y
M1GI&>T9\1@``?48``'Y&````````(4<``")'````````(T<`````````````
M```D1P``)4<``"9')T<``"A'````````*4<``"I'````````````````````
M````````````````````*T<`````+$<`````+4<````````N1R]'```P1P``
M,4<````````````````R1P`````````````````````````````S1S1'-4<`
M````````````-T<X1P``.4<``````````````````#I'`````#M'`````#Q'
M``!*0P``````````2T,```````!,0P``34,``````````````````$]#3D,`
M``````!00U%#``!20U-#5$,``%5#``````````````````!60P```````%=#
M``````````!80UE#``````````!:0P``6T,`````````````24,`````7$,`
M`%U#7D,`````7T,```````````````````````````````````````!@0P``
M``!A0V)#8T-D0V5#`````&9#````````9T-H0VE#:D,`````````````:T,`
M`&Q#``!M0P``;D,``````````````````````````````````&]#``!P0P``
M<4,``')#``````````!S0P``=$,``'5#````````=D-W0P```````'A#````
M````>4,`````````````````````>D,```````````````````````![0P``
M``!\0P```````'U#`````'Y#(40B1```(T0`````)$0`````)40`````)D0G
M1```````````````````*$0`````*40``"I$*T0L1"U$`````"Y$+T0`````
M```P1#%$```````````R1#-$-$0`````````````````````-40`````-D0W
M1``````````````X1#E$```Z1``````[1#Q$````````````````````````
M````````,4,R0S-#`````#1#`````````````#5#-D,W0P`````Y0P``.D,[
M0P``/$,`````/4,^0P`````````````````````_0P``````````0$,``$%#
M`````$)#``````````!#0P``````````1$,```````````````````````!%
M0P``1D,```````!'0TA#```X0P```````````````$D_``!*/P``````````
M````````````````2S\`````3#]-/P````!./P```````$\_4#\`````````
M`%$_````````````````````````4C\```````````````!3/U0_````````
M53\```````````````````````````````````````!6/P``````````````
M````5S\``%@_``````````````````!9/UH_`````````````%L_7#\`````
M````````73]>/P``7S\`````8#\`````83\`````8C\``&,_````````````
M``````````````````````````````!D/V4_`````&8_````````````````
M``!G/V@_`````&D_`````&H_``````````!K/VP_;3]N/P``;S\```````!P
M/W$_`````'(_````````<S]T/W4_````````=C\`````=S\`````````````
M``````````!X/WD_`````````````'H_>S\```````!\/P````!]/WX_````
M`"%`````````(D`C0```)$``````)4```"9``````"=``````"A`````````
M`````"E`````````*D`K0````````"Q`+4`````````N0``````````````O
M0```,$`````````````````Q0#)`,T``````````````````````````````
M`````#1`````````-4`````````V0``````W0``````````````X0``````Y
M0```.D`[0#Q`````````````````/4`````````^0```````````/T``````
M`````$!```!!0`````````````!"0$-```!$0`````!%0$9`````````````
M````````````````````````````1T!(0`````````````!)0```2D```$M`
M````````3$``````````````34```$Y```!/0```4$!10````````%)`4T``
M`````````%1`54```````````%9```````````````````!70```6$``````
M````````````````````````64````````!:0```6T!<0%U`7D``````````
M````7T!@0&%`8D```&-`9$!E0```9D````````````````````````!G0```
M``````````!H0&E`````````````````:D```&M```````````````````!L
M0```;4```````````````````&Y`;T!P0````````````````'%`<D```'-`
M``!T0```=4```'9```!W0`````!X0```>4````````!Z0```````````````
M`'M`````````````````````````?$!]0'Y````````````A00``````````
M(D$C021!)4$``"9!```G02A!````````*4$``"I!````````````````````
M````````````*T$L00```````"U!+D$`````+T$`````,$$``````````#%!
M```R00```````#-!````````-$$``#5!`````#9!````````-T$X03E!````
M```````Z00```````#M!/$$``#U!`````#Y!```_00````!`04%!`````$)!
M````````0T$`````1$$``````````$5!`````$9!````````````````````
M`$=!``!(04E!`````````````$I!````````2T$``$Q!````````````````
M34$``$Y!``!/00``````````````````````````4$%100``````````````
M`%)!````````4T$`````````````````````````````````````5$$`````
M54$```````!600```````%=!``````````!800``````````````````64$`
M````6D$`````6T$``````````%Q!`````%U!`````%Y!`````%]!````````
M``````````!@00```````&%!8D%C00``````````````````````````9$$`
M````94$`````````````9D%G00``````````:$$``&E!````````:D$``&M!
M``!L00```````````````&U!````````````````````````````````````
M``````!N00``;T$``'!!<4$```````!R00``````````<T%T075!````````
M=D$```````!W07A!````````>4$```````!Z07M!`````'Q!?4$`````````
M``````!^02%"`````")"(T(D0B5"```F0@`````G0BA"*4(J0@``*T(``"Q"
M+4(``"Y"````````,$(``"]"````````````````,4(``````````#)",T(`
M```````T0@``-4(``#="`````#9"`````````````#A".4(Z0@``.T(\0@``
M`````#U"/D(`````````````````````0$)!0D)"````````````````1$(`
M`$5"``!'0DA"24(``$I"3$(``$-"1D)+0@``````````````````````````
M34).0D]"`````%!"``!10@```````````````%)"4T)40E5"`````%9"5T(`
M``````!80@````````````````````!90@```````%I"6T(`````7$(`````
M````````74(```````!>0E]"``!@0F%"``````````!B0@```````&-"``!D
M0F5"``````````!F0@```````````````&="````````:$(`````````````
M````````:4(`````:D)K0@``;$(`````````````````````````````;4(_
M0@```````````````````````&Y"``!O0@```````````````'!"````````
M``!Q0@````````````!R0@````!S0@```````'1"``!U0@``````````````
M````````````````````````````=D(``````````````````````````'="
M````````````````>$(``'E">D(```````![0@``````````````````?$)]
M0@``````````````````?D(`````````````````````(4,`````````````
M(D,``"-#`````````````"1#```E0P``````````)D,`````````````)T,`
M````*$,````````````````````````I0RI#```K0P``+$,`````+4,``"Y#
M+T,``#!#``````````````````````````!3/@``5#X`````````````````
M````````````53X`````````````5CX`````````````5SX`````6#Y9/@``
M``!:/EL^7#X``%T^7CX```````````````!?/@``8#X``````````&$^8CX`
M``````!C/F0^````````93YF/@``9SYH/@``````````:3X`````:CX``&L^
M`````&P^``````````````````````````!M/FX^`````&\^````````<#YQ
M/G(^`````````````````````````````',^=#X`````````````=3X`````
M``````````!V/G<^>#YY/@``>CY[/@````!^/@``?#X``'T^`````"$_(C\`
M`",_`````````````````````````````````````````````"0_```E/R8_
M`````"<_`````````````````````````````"@_```I/P``````````````
M`"H_````````*S\``"P_+3\````````N/P``+S\``#`_````````````````
M```````````````````Q/P```````#(_```````````S/S0_-3\``#8_````
M`````````#<_````````.#\Y/SH_```[/P``/#\````````]/P``/C\`````
M`````````````#\_`````````````````````$`_``!!/P```````$(_````
M````````````0S\`````1#\`````````````````````````````````````
M``!%/T8_1S](/P``````````````````````````````````7#P```````!=
M/%X\7SP`````````````8#P``````````````````````````&$\`````&(\
M8SP```````!D/&4\9CQG/````````&@\`````&D\:CP``&L\``!L/```````
M`&T\``!N/```````````;SP``'`\``!Q/'(\````````<SQT/```=3P`````
M````````=CP`````=SP```````!X/````````'D\`````'H\``````````![
M/`````!\/'T\`````'X\```````````````````A/0`````B/0``(STD/0``
M```E/0``)CT`````)STH/0``````````````````````````*3T````````J
M/0``*ST````````````````L/0`````````````M/2X]```````````O/0``
M,CT`````,#T````````Q/3,]`````#0]-3TV/0```````````````#<]````
M`````````````````````````#@]`````#D].CT[/0``/#T``````````#T]
M/CT_/4`]03T```````````````````````!"/0````!#/40]````````````
M`$4]1CU'/0``2#U)/4H]2ST`````3#U-/0````!./0```````$\]``!0/0``
M````````````````````````43T`````4CT`````4ST`````````````5#U5
M/0````!6/5<]``!8/0``````````63T``````````%H]````````````````
M`````%L]`````````````%P]``!=/0``````````````````````````7CT`
M``````````````!?/6`]83T`````8CT``````````&,]`````&0]``!E/68]
M`````````````&<]````````:#T`````````````:3T`````````````````
M``````!J/0```````````````````````````````&L];#T`````;3T`````
M``!N/0``;ST``'`]````````<3T`````<CT``',]``!T/0````!U/0``````
M````=CUW/0```````'@]``!Y/7H]`````'L]``````````````````!\/7T]
M`````````````'X]````````(3X`````(CX````````C/@``)#X````````E
M/B8^)SXH/@`````I/BH^```````````K/BP^````````+3X``"X^```O/C`^
M````````,3X`````,CX````````````````````````````````S/@`````T
M/@`````U/@```````#8^-SX``````````#@^```````````Y/@`````Z/@``
M.SX````````\/CT^/CX_/D`^``!!/D(^``!#/@````!$/@``13X```````!&
M/@``````````````````1SY(/@``````````23Y*/@```````$L^3#Y-/@``
M3CX``````````````````$\^````````4#Y1/@````!2/@``````````````
M``````!W.G@Z``!Y.@````````````!Z.GLZ````````?#I].GXZ````````
M(3L`````(CL````````C.R0[```````````E.R8[)SLH.P``````````````
M`````````"D[*CL``"L[```````````L.P`````M.P``````````````````
M````````+CL``"\[,#L``#$[,CL`````,SL````````T.P``````````````
M````-3L``#8[-SL``````````#@[````````````````````````````````
M`````#D[```Z.P```````````````#L[```````````].P`````````````\
M.P``````````````````````````````````````````/CL`````/SM`.P``
M03L```````````````````````````````!".P``````````0SL`````````
M``````!$.P``````````13L`````````````````````````````````````
M`````$<[2#L``$D[2CL```````!&.P````````````!+.P````!,.P``````
M````33L```````!..P``3SL`````4#M1.P````!2.P``4SL``%<[````````
M````````53L```````!4.P```````%8[`````````````%@[63M:.UL[``!<
M.P````````````!=.P````!>.P````!?.P````````````````````!@.V$[
M````````8CMC.P``9#L``&4[``````````!F.P``9SL`````````````````
M`&@[:3MJ.VL[````````;#L``&T[````````;CMO.P```````````````'`[
M````````<3L``````````'([``!T9@``<SL```````!T.W4[````````````
M````````````=CL```````!W.P```````'@[`````'H[``!Y.P``````````
M````````>SM\.P```````````````'T[````````?CL``````````"$\````
M`````````````````````````````````"(\(SP````````````````D/```
M`````````````"4\`````````````"8\```````````G/```*#PI/``````J
M/````````````````"L\+#P``````````````````"X\`````````````"T\
M````````+SP`````,#P`````````````````````,3P`````````````````
M`````````#0\```R/```````````,SPU/```````````-CP``#<\`````#@\
M.3P``#H\````````````````````````.SP``#P\/3P^/#\\0#P``$$\````
M````````````````````````````````````0CP`````````````````````
M`````$,\`````$0\````````````````````````````````````````````
M``````!%/```1CQ'/`````!(/```23P``$H\``````````!+/```3#P`````
M``````````````````!-/$X\3SP```````````````!0/```````````4CQ1
M/```4SP`````5#Q5/```5CQ7/````````````````%@\``!9/```````````
M`````%H\`````````````%L\``````````````````````````````````!E
M-0``9C5G-0```````&@U``!I-0````````````!J-6LU``!L-6TU;C5O-0``
M``!P-0````````````````````````````!Q-7(U````````````````````
M`',U``````````!T-0```````````````````````````````'4U``!V-0``
M=S4`````>#4`````>34``'HU>S4``'PU`````'TU?C4A-@```````"(V(S8`
M````)#8`````)38````````F-@```````````````"<V````````````````
M````````````````*#8`````````````````````*38`````````````*C8`
M````*S8``"PV`````"TV+C8O-C`V,38R-@```````````````#,V````````
M````````````````````````````````````````-#8````````U-@`````V
M-@``-S8``#@V```Y-@``.C8[-CPV```]-CXV/S8``$`V038``$(V`````$,V
M``!$-@``138``$8V``````````!'-@```````````````````````$@V``!)
M-DHV2S9,-@````!--@````!.-@```````$\V``!0-@``4392-@````!3-@``
M``````````````````````````````````!4-E4V`````%8V`````%<V6#8`
M````````````````````638```````!:-ELV`````%PV739>-@``````````
M`````%\V8#9A-F(V``!C-F0V938```````!F-@``9S8```````!H-@``````
M`````````&DV````````````````:C8```````!K-FPV;39P-G$V``!N-F\V
M`````````````````````'(V`````',V=#8``'4V``!V-@````!W-G@V>39Z
M-GLV`````'TV``!^-@```````'PV```````````A-R(W````````````````
M````````(S<D-P``````````)3<`````)C<``"<W```````````H-P``````
M`"DW```````````J-RLW```L-P`````M-P``+C<O-S`W,3<````````R-S,W
M```T-P``-3<V-P```````#<W.#<`````````````````````.3<Z-SLW````
M`````````#PW/3<`````````````/C<_-P``````````0#<`````````````
M``````````````````````````!!-P````!"-P``0S=$-P````!%-P``1C='
M-T@W23=*-P``2S=,-TTW``!.-P``3S=0-U$W4C<``%,W`````%0W``!5-P``
M``````````````````!6-P``````````````````5S=@-P``6#<``%DW6C<`
M`%LW7#==-UXW``!?-P````````````!A-V(W8S<`````9#<`````````````
M````````````````93<``````````&8W````````````````````````9S=H
M-P```````&DW`````&HW`````````````&LW``````````````````!L-VTW
M`````'XW`````&XW``!O-W`W``!Q-P```````'(W`````',W``````````!T
M-W4W``!V-P``````````=S=X-WDW````````>C=[-P```````'PW?3<`````
M(3@B.```````````````````````````````````(S@`````)#@E."8X````
M`````````"<X*#@`````````````*3@``````````"HX````````````````
M*S@`````````````+#@````````````````````````M.``````N."\X```P
M.#$X```````````R.````````````````````````#,X```T.``````U.```
M```V.#<X````````````````````````````````````````.#@````````Y
M.``````Z.#LX/#@`````````````/3@^.#\X0#@``$$X0C@``$,X1#@`````
M``!%.```1C@```````````````!'.`````!(.$DX2C@```````!+.`````!,
M.```````````````````33A..````````````````````````%`X````````
M`````%$X``!/.````````%(X``````````!3.%0X``!5.```5C@``%<X``!8
M.````````%DX`````%HX````````6SA<.````````````````%TX````````
M````````````````7C@`````````````````````````````````````````
M````7SA@.```````````83AB.`````````````!C.&0X93@`````````````
M````````9S@```````!H.```:3AJ.````````&LX````````````````;#AM
M.`````!N.```;SAP.`````````````````````!Q.````````'(X`````',X
M`````````````````````````````'0X=3@`````````````=C@``'<X``!X
M.'DX>C@``'LX``!\.```````````````````?3@``'XX```A.0`````B.0``
M```C.20Y`````"4Y```F.2<Y````````````````````````````````````
M`"@Y*3D``"HY````````*SD`````+#D``"TY```````````````````N.0``
M````````+SD`````,#D`````````````,3DR.3,Y-#D`````-3D````````V
M.0`````W.0``.#D``````````#DY```Z.3LY````````/#D``#TY`````#XY
M```````````_.0``````````````````````````0#E!.4(Y````````0SE$
M.0````!%.0```````````````$8Y1SD``$@Y23D``$HY`````$LY````````
M`````````````$PY````````33D``````````````````$XY3SE0.0``````
M`%$Y4CD``````````````````````````%,Y``````````!4.54Y`````%8Y
M5SD``%@Y`````%DY`````%HY````````````````````````````````````
M``````````````!;.5PY``!=.5XY````````7SD```````!@.0``````````
M83D`````````````````````8CD``````````&,Y``!D.0``93D`````````
M````9CD```````````````````````!G.0````!H.6DY`````&HY````````
M````````````````````````:SD``````````&PY`````&TY`````&XY````
M`&\Y`````'`Y``!Q.7(Y<SD``'0Y``````````!U.0``````````=CD`````
M`````'<Y>#EY.0``>CD`````>SD``'PY?3D```````!^.0``````````(3H`
M`"(Z```C.@```````````````"0Z```````````````````````````E.@``
M)CH````````G.@``````````*#H``````````"DZ````````*CH`````````
M```````K.BPZ````````````````+3H`````+CHO.@```````````````#`Z
M`````````````````````````````````````#$Z```S.@``-#H``#4Z````
M````-CH````````W.@``````````````````.#H````````````````R.@``
M`````#DZ`````````````````````#HZ````````````````````````.SH\
M.@`````````````].@```````#XZ```````````````````_.@``````````
M`````````````$`Z`````````````$$Z0CH`````````````````````````
M``````!#.D0Z13I&.@``1SH`````2#H``$DZ````````2CH```````!+.@``
M3#I-.@``3CI/.@``4#H`````````````````````````````````````````
M````43I2.@````!3.E0Z``!5.@``5CI7.@``````````6#H`````63H``%HZ
M````````6SI<.@````````````````````````````!=.@``7CH`````````
M``````!?.F`Z83IB.F,Z`````````````&0Z````````````````````````
M`````````````&4Z``!F.@````!G.@````````````````````!H.@``````
M``````````````````````````````!I.@``````````````````````````
M:CH```````````````!K.FPZ````````;3H`````;CH`````;SH``'`Z<3H`
M`'(Z``!S.@``=#H`````=3IV.@````````````````````!.-4\U````````
M````````4#4`````4352-0``````````4S54-54U````````5C4`````````
M````5S4``%@U634`````6C4`````6S5<-0```````````````%TU``!>-5\U
M`````&`U``!A-6(U`````&,U``!D-0```````&\R``````````!P,G$R````
M````````````<C(`````<S(```````````````````````!T,@``````````
M=3(```````!V,@``=S(```````````````````````!X,@``````````````
M````````````>3(``'HR``![,@``?#)],@````!^,@`````````````A,P``
M`````````````"(S```C,R0S)3,``"8S`````"<S`````````````"@S````
M````*3,`````*C,`````````````````````*S,````````L,RTS+C,`````
M+S,````````````````````````P,S$S`````#(S````````````````````
M````````````,S,T,P``-3,V,P``-S,````````````````````````X,P``
M```````````Y,P`````````````````````Z,SLS`````#PS````````````
M````/3,`````````````````````/C,````````_,P``````````````````
M``````````!`,P``03-",P``0S,``$0S`````$4S1C-',P``````````2#,`
M`````````````````$DS`````````````````````$HS2S-,,P``````````
M`````$TS``!.,P````!/,P``````````4#,``%$S````````````````4C,`
M`%,S5#-5,U8S``!7,P``6#,``````````````````%DS6C-;,UPS````````
M``````````!=,UXS`````````````%\S8#-A,P``8C-C,P``9#,`````93,`
M``````!F,P``9S,``&@S````````:3,`````:C,``&LS`````&PS``!M,P``
M````````;C-O,P``````````<#,```````!Q,P````!R,W,S=#,``'4S````
M````=C-W,P````!X,P``>3-Z,P````````````````````![,P````!\,P``
M`````````````'TS?C,A-```````````(C0``",T```````````D-``````E
M-"8T```G-"@T`````````````"DT```J-"LT+#0``"TT+C0O-``````P-```
M,30`````,C0````````````````S-#0T-30````````V-```````````````
M```````X-#<T````````````````````````````````.30``#HT````````
M`````#LT```\-```/30````````````````^-#\T``````````!`-```````
M`````````$$T``````````!"-```````````0S0```````!$-$4T````````
M`````$8T``````````!'-$@T``````````!)-````````$HT````````2S0`
M````3#0`````````````331.-````````$\T`````%`T``!1-%(T``!3-%0T
M``!5-`````!6-`````!7-```````````6#0```````````````````````!9
M-`````!:-%LT``!<-```````````730`````7C1?-```8#0`````````````
M831B-```````````````````````````````````8S0`````````````````
M``````````````!D-```````````````````````````````````````````
M930```````````````!F-````````````````&<T`````````````&@T:30`
M`&HT``````````!K-```;#0`````;31N-```````````````````````````
M````````;S1P-`````!Q-`````````````!R-```<S0`````````````````
M````````````````````=#0```````!U-```=C0``'<T>#0``'DT``!Z-```
M>S1\-`````````````!]-```````````````````````````?C0``"$U```B
M-0``(S4`````)#4E-0```````"8U````````)S4````````H-2DU````````
M`````"HU`````"LU```L-0``````````+34N-0``+S4P-0`````Q-3(U````
M`#,U`````````````#0U```U-38U-S4````````X-0```````````````#DU
M````````.C4`````.S4\-0``````````````````````````````````````
M```````]-0```````````````````````#XU```_-0````!`-0``````````
M`````$$U`````````````$(U``!#-40U135&-0```````$<U`````$@U234`
M````2C5+-4PU````````````````334`````````````````````73``````
M7C```&`P``!A,```8C```&,P``!D,`````!E,```9C```&<P````````````
M`&@P:3```&HP:S``````````````;#```&TP``!N,```;S``````````````
M``!P,%\P`````'$P````````````````<C```',P``!T,`````!U,```````
M``````!V,'<P>#!Y,`````!Z,'LP`````'PP?3```'XP(3$````````B,2,Q
M```D,0``)3$``"8Q```G,2@Q*3$`````*C$``"LQ+#$````````M,2XQ````
M````````````````````````````````````````````+S$``````````#`Q
M```Q,0``,C$S,30Q-3$``#8Q-S$````````X,3DQ```Z,3LQ```\,3TQ/C$`
M`#\Q`````$`Q````````````````````````03$```````!",0``0S$`````
M`````````````````````````````$0Q``!%,0``````````````````````
M`$8Q1S$``$@Q23%*,0````!+,0````!,,0````!-,0``3C$``$\Q``!0,0``
M``!1,0```````%(Q4S$`````5#%5,58Q5S$```````!8,0``````````63$`
M``````````````!:,0``6S$``%PQ73$``%XQ`````````````'8Q````````
M``!?,6`Q83$`````8C%C,0```````&0Q``!E,0``9C$`````9S%H,6DQ````
M````:C$``&LQ`````````````&PQ;3$``&XQ;S$`````<#%Q,0````!R,0``
M``!S,0````!T,74Q````````````````````````````````````````=S$`
M`'@Q>3$``'HQ````````>S$```````!\,7TQ?C$``"$R(C(C,@``)#(`````
M`````"4R)C(``"<R*#(I,BHR*S(``````````````````"PR```````````M
M,BXR`````````````````````"\R,#(`````,3(`````,C(`````,S(T,@``
M```U,@``````````-C(``#<R```X,@`````Y,CHR````````.S(````````\
M,CTR```^,@`````_,@``0#(``$$R``!",D,R`````````````$0R``!%,E$R
M````````1C(```````!',@```````$@R``````````!),@````!*,DLR3#(`
M````33).,D\R4#(``%(R````````````````4S(``%0R``!5,E8R5S)8,@``
M````````63(```````!:,ELR````````7#)=,@``7C(``%\R``!@,F$R8C(`
M````8S)D,@````````````````````!E,@``````````````````9C(`````
M`````&<R````````:#(``&DR``!J,FLR````````````````;#(`````````
M`&TR``!N,@``````````````````(3```"(P(S`````````````````D,```
M```````````E,````````````````````````````````"8P````````)S`H
M,````````"DP`````"HP`````"LP+#`M,```````````+C``````````````
M`````````````"\P,#``````,3``````,C`````````````````````````S
M,``````````````````````T,```-3`````````````````V,```````````
M-S`X,```````````````````````````.3`Z,````````#LP````````````
M`#PP```````````````````````````````````],```````````````````
M```^,#\P`````````````$`P````````````````````````````````````
M`````````$$P````````````````````````0C``````````````````````
M``!#,````````````````````````````````$0P````````````````````
M````13!&,```````````1S!(,$DP`````````````$HP````````````````
M2S```$PP``!-,```3C```````````````````$\P4#!1,%(P``!3,%0P````
M``````!5,`````!6,%<P`````````````%@P`````%DP6C!;,```7#!Q(@``
M``````````````````````````!O(G(G<R=T)W4G=B=W)W@G>2=Z)WLG?"<`
M`'TG?B=")T,G1"=%)T8G1R=()TDG2B=+)TPG``!-)TXG````````````````
M````````````````````````929J)G$F<B9S)G0F>R8`````````````````
M````````````````````````````>"8``````````````````'4F>B9W)GDF
M?"8X(CDB828``&(F8R9D)@``9R8``&DF;"9V)@``````````````````````
M```````````````P(@``````````````````````````````````````````
M+R(R(C8B-2(``#,B.2L`````````````````````)BHF*T,J0RM5*E4K9RIG
M*W`J<"MM*FTK;RIO*VXJ;BM"(@````!P(@``0R(`````;2)L(@```````&XB
M-"(`````````````````````,2(``&LB``````````!$(B(J(2HD*BHJ(RHI
M*B$I+BHR*C$J-"HS*D`J/RI"*D$J``!0*E(J42I4*E@J4RH``"PI8RIB*F4J
M9"IR*C`I3BDB*R$K)"LJ*R,K*2M!*2XK,BLQ*S0K,RM`*S\K0BM!*T,I4"M2
M*U$K5"M8*U,K``!,*6,K8BME*V0K<BM0*7,K)RHG*R4J)2LH*B@K*RHK*RPJ
M+"LO*B\K+2HM*S`J,"LB*4(I-RHW*P`````V*C8K."HX*S4J-2LZ*CHK.RH[
M*STJ/2L\*@``/BH^*R0I1"E'*D<K12I%*P````!&*D8K1"I%*28I1BE(*D@K
M22I)*T<I2BI**TPJ3"M+*DLK*2E)*2@I2"E-*DTK3RI/*TXJ3BM**2LI2RE7
M*E<K`````%8J5BLM*4TI62I9*ULJ6RM:*EHK7"I<*UTJ72M?*E\K7BI>*V$J
M82M@*F`K+RE/*6PJ;"MI*FDK9BIF*VLJ:RMH*F@K:BIJ*W$J<2MT*G0K<RIU
M*G4K=RIW*W8J=BLW(B]8QVE9D&1TW%&9<0``````````````````````````
M``!=G5Z=9)U1G5"=69URG8F=AYVKG6^=>IV:G:2=J9VRG<2=P9V[G;B=NIW&
MG<^=PIW9G=.=^)WFG>V=[YW]G1J>&YX>GG6>>9Y]GH&>B)Z+GHR>DIZ5GI&>
MG9ZEGJF>N)ZJGJV>89?,GLZ>SY[0GM2>W)[>GMV>X)[EGNB>[Y[TGO:>]Y[Y
MGON>_)[]G@>?")^W=A6?(9\LGSZ?2I]2GU2?8Y]?GV"?89]FGV>?;)]JGW>?
M<I]VGY6?G)^@GP````#[F@:;&)L:FQ^;(ILCFR6;)YLHFRF;*ILNFR^;,IM$
MFT.;3YM-FTZ;49M8FW2;DYN#FY&;EIN7FY^;H)NHF[2;P)O*F[F;QIO/F]&;
MTIOCF^*;Y)O4F^&;.ISRF_&;\)L5G!2<"9P3G`R<!IP(G!*<"IP$G"Z<&YPE
MG"2<(9PPG$><,IQ&G#Z<6IQ@G&><=IQXG.><[)SPG`F=")WKG`.=!ITJG2:=
MKYTCG1^=1)T5G1*=09T_G3Z=1IU(G0````!QF'28<YBJF*^8L9BVF,28PYC&
MF.F8ZY@#F0F9$ID4F1B9(9D=F1Z9))D@F2R9+ID]F3Z90IE)F4694)E+F5&9
M4IE,F569EYF8F:69K9FNF;R9WYG;F=V9V)G1F>V9[IGQF?*9^YGXF0&:#YH%
MFN*9&9HKFC>:19I"FD":0YH^FE6:39I;FE>:7YIBFF6:9)IIFFN::IJMFK":
MO)K`FL^:T9K3FM2:WIK?FN*:XYKFFN^:ZYKNFO2:\9KWF@````!=EE^69I9R
MEFR6C9:8EI66EY:JEJ>6L9:REK"6M):VEKB6N9;.ELN6R9;-EDV)W)8-E]66
M^98$EP:7")<3EPZ7$9</EQ:7&9<DERJ7,)<YESV7/I=$ET:72)="ETF77)=@
MEV279I=HE])2:Y=QEWF7A9=\EX&7>I>&EXN7CY>0EYR7J)>FEZ.7LY>TE\.7
MQI?(E\N7W)?MET^?\I??>O:7]9</F`R8.)@DF"&8-Y@]F$:83YA+F&N8;YAP
MF``````9DR*3&I,CDSJ3-9,[DUR38)-\DVZ35I.PDZR3K9.4D[F3UI/7D^B3
MY9/8D\.3W9/0D\B3Y),:E!24$Y0#E`>4$)0VE"N4-90AE#J40912E$246Y1@
ME&*47I1JE"F2<)1UE'>4?91:E'R4?I2!E'^4@I6'E8J5E)66E9B5F96@E:B5
MIY6ME;R5NY6YE;Z5RI7V;\.5S97,E=65U)76E=R5X97EE>*5(98HEBZ6+Y9"
MEDR63Y9+EG>67)9>E@````!/D%"049!2D`Z029`^D%:06)!>D&B0;Y!VD*B6
M<I""D'V0@9"`D(J0B9"/D*B0KY"QD+60XI#DD$ABVY`"D1*1&9$RD3"12I%6
MD5B18Y%ED6F1<Y%RD8N1B9&"D:*1JY&OD:J1M9&TD;J1P)'!D<F1RY'0D=:1
MWY'AD=N1_)'UD?:1'I+_D122+)(5DA&27I)7DD6229)DDDB2E9(_DDN24)*<
MDI:2DY*;DEJ2SY*YDK>2Z9(/D_J21),NDP````!'CDF.3(Y0CDB.68YDCF".
M*HYCCE6.=HYRCGR.@8Z'CH6.A(Z+CHJ.DXZ1CI2.F8ZJCJ&.K(ZPCL:.L8Z^
MCL6.R([+CMN.XX[\CON.ZX[^C@J/!8\5CQ*/&8\3CQR/'X\;CPR/)H\SCSN/
M.8]%CT*//H],CTF/1H].CU>/7(]BCV./9(^<CY^/HX^MCZ^/MX_:C^6/XH_J
MC^^/AY#TCP60^8_ZCQ&0%9`AD`V0'I`6D`N0)Y`VD#60.9#XCP````!?BVR+
M;XMTBWV+@(N,BXZ+DHN3BY:+F8N:BSJ,08P_C$B,3(Q.C%",58QBC&R,>(QZ
MC(*,B8R%C(J,C8R.C)2,?(R8C!UBK8RJC+V,LHRSC*Z,MHS(C,&,Y(SCC-J,
M_8SZC/N,!(T%C0J-!XT/C0V-$(U.GQ.-S8P4C1:-9XUMC7&-<XV!C9F-PHV^
MC;J-SXW:C=:-S(W;C<N-ZHWKC=^-XXW\C0B."8[_C1V.'HX0CA^.0HXUCC".
M-(Y*C@````!FB62);8EJB6^)=(EWB7Z)@XF(B8J)DXF8B:&)J8FFB:R)KXFR
MB;J)O8F_B<")VHG<B=V)YXGTB?B)`XH6BA"*#(H;BAV*)8HVBD&*6XI2BD:*
M2(I\BFV*;(IBBH6*@HJ$BJB*H8J1BJ6*IHJ:BJ.*Q(K-BL**VHKKBO.*YXKD
MBO&*%(O@BN**]XK>BMN*#(L'BQJ+X8H6BQ"+%XL@BS.+JY<FBRN+/HLHBT&+
M3(M/BTZ+28M6BUN+6HMKBP````!3AV.':H<%B**'GX>"AZ^'RX>]A\"'T(?6
MEJN'Q(>SA\>'QH>[A^^'\H?@AP^(#8C^A_:']X<.B-*'$8@6B!6((H@AB#&(
M-H@YB">(.XA$B$*(4HA9B%Z(8HAKB(&(?HB>B'6(?8BUB'*(@HB7B)*(KHB9
MB**(C8BDB+"(OXBQB,.(Q(C4B-B(V8C=B/F(`HG\B/2(Z(CRB`2)#(D*B1.)
M0XD>B26)*HDKB4&)1(D[B3:).(E,B1V)8(E>B0````!!A0*&2X55A8"%I(6(
MA9&%BH6HA6V%E(6;A>J%AX6<A7>%?H60A<F%NH7/A;F%T(75A=V%Y87<A?F%
M"H83A@N&_H7ZA0:&(H8:AC"&/X9-AE5.5(9?AF>&<8:3AJ.&J8:JAHN&C(:V
MAJ^&Q(;&AK"&R88CB*N&U(;>ANF&[(;?AMN&[X82AP:'"(<`AP.'^X81APF'
M#8?YA@J'-(<_AS>'.X<EARF'&H=@AU^'>(=,ATZ'=(=7AVB';H=9AP`````U
M@S2#%H,R@S&#0(,Y@U"#18,O@RN#%X,8@X6#FH.J@Y^#HH.6@R.#CH.'@XJ#
M?(.U@W.#=8.@@XF#J(/T@Q.$ZX/.@_V#`X38@PN$P8/W@P>$X(/R@PV$(H0@
MA+V#.(0&A?N#;80JA#R$6H6$A'>$:X2MA&Z$@H1IA$:$+(1OA'F$-83*A&*$
MN82_A)^$V83-A+N$VH30A,&$QH36A*&$(87_A/2$%X48A2R%'X45A12%_(1`
MA6.%6(5(A0````"+ED:!/H%3@5&!_(!Q@6Z!98%F@72!@X&(@8J!@(&"@:"!
ME8&D@:.!7X&3@:F!L(&U@;Z!N(&]@<"!PH&Z@<F!S8'1@=F!V('(@=J!WX'@
M@>>!^H'[@?Z!`8("@@6"!X(*@@V"$((6@BF"*X(X@C."0()9@EB"78):@E^"
M9()B@FB":H)K@BZ"<8)W@GB"?H*-@I*"JX*?@KN"K(+A@N."WX+2@O2"\X+Z
M@I.#`X/[@OF"WH(&@]R""8/9@@````!%?TQ_37].?U!_47]5?U1_6']??V!_
M:']I?V=_>'^"?X9_@W^(?X=_C'^4?YY_G7^:?Z-_KW^R?[E_KG^V?[A_<8O%
M?\9_RG_5?]1_X7_F?^E_\W_Y?]R8!H`$@`N`$H`8@!F`'(`A@"B`/X`[@$J`
M1H!2@%B`6H!?@&*`:(!S@'*`<(!V@'F`?8!_@(2`AH"%@)N`DX":@*V`D%&L
M@-N`Y8#9@-V`Q(#:@-:`"8'O@/&`&X$I@2.!+X%+@0`````"?1Q]%7T*?45]
M2WTN?3)]/WTU?49]<WU6?4Y]<GUH?6Y]3WUC?9-]B7U;?8]]?7V;?;I]KGVC
M?;5]QWV]?:M]/7ZB?:]]W'VX?9]]L'W8?=U]Y'W>??M]\GWA?05^"GXC?B%^
M$GXQ?A]^"7X+?B)^1GYF?CM^-7XY?D-^-WXR?CI^9WY=?E9^7GY9?EI^>7YJ
M?FE^?'Y[?H-^U7U]?JZ/?WZ(?HE^C'Z2?I!^DWZ4?I9^CGZ;?IQ^.'\Z?P``
M``!Z>P1[37L+>TQ[17MU>V5[='MG>W![<7ML>VY[G7N8>Y][C7N<>YI[BWN2
M>X][77N9>\M[P7O,>\][M'O&>]U[Z7L1?!1\YGOE>V!\`'P'?!-\\WOW>Q=\
M#7SV>R-\)WPJ?!]\-WPK?#U\3'Q#?%1\3WQ`?%!\6'Q??&1\5GQE?&Q\=7R#
M?)!\I'RM?*)\JWRA?*A\LWRR?+%\KGRY?+U\P'S%?,)\V'S2?-Q\XGP[F^]\
M\GST?/9\^GP&?0````#G>-IX_7CT>`=Y$GD1>1EY+'DK>4!Y8'E7>5]Y6GE5
M>5-Y>GE_>8IYG7FG>4N?JGFN>;-YN7FZ><EYU7GG>>QYX7GC>0AZ#7H8>AEZ
M('H?>H!Y,7H[>CYZ-WI#>E=Z27IA>F)Z:7J=GW!Z>7I]>HAZEWJ5>IAZEGJI
M>LAZL'JV>L5ZQ'J_>H.0QWK*>LUZSWK5>M-ZV7K:>MUZX7KB>N9Z[7KP>@)[
M#WL*>P9[,WL8>QE['GLU>RA[-GM0>P````!R=G9V>'9\=H!V@W:(=HMVCG:6
M=I-VF7::=K!VM':X=KEVNG;"=LUVUG;2=MYVX7;E=N=VZG8OAOMV"'<'=P1W
M*7<D=QYW)7<F=QMW-W<X=T=W6G=H=VMW6W=E=W]W?G=Y=XYWBW>1=Z!WGG>P
M=[9WN7>_=[QWO7>[=\=WS7?7=]IWW'?C=^YW_'<,>!)X)GD@>"IY17B.>'1X
MAGA\>)IXC'BC>+5XJGBO>-%XQGC+>-1XOGB\>,5XRGCL>`````#@=.-TYW3I
M=.YT\G3P=/%T^'3W=`1U`W4%=0QU#G4-=15U$W4>=29U+'4\=41U375*=4EU
M6W5&=5IU:75D=6=U:W5M=7AU=G6&=8=U='6*=8EU@G64=9IUG76E=:-UPG6S
M=<-UM76]=;AUO'6Q=<UURG72==EUXW7>=?YU_W7\=0%V\'7Z=?)U\W4+=@UV
M"78?=B=V('8A=B)V)'8T=C!V.W9'=DAV1G9<=EAV879B=FAV:79J=F=V;'9P
M=@````#Y<?]Q#7(0<AMR*'(M<BQR,'(R<CMR/'(_<D!R1G)+<EAR=')^<H)R
M@7*'<I)REG*B<J=RN7*R<L-RQG+$<LYRTG+B<N!RX7+Y<O=R#U`7<PIS'',6
M<QUS-',O<RES)7,^<TYS3W/8GE=S:G-H<W!S>'-U<WMS>G/(<[-SSG.[<\!S
MY7/N<]YSHG0%=&]T)73X<S)T.G15=#]T7W19=$%T7'1I='!T8W1J='9T?G2+
M=)YTIW3*=,]TU'3Q<P`````^;Q-O]VZ&;WIO>&^!;X!O;V];;_-O;6^";WQO
M6&^.;Y%OPF]F;[-OHV^A;Z1ON6_&;ZIOWV_5;^QOU&_8;_%O[F_;;PEP"W#Z
M;Q%P`7`/</YO&W`:<'1O'7`8<!]P,'`^<#)P47!C<)EPDG"O</%PK'"X<+-P
MKG#?<,MPW7#9<`EQ_7`<<1EQ97%5<8AQ9G%B<4QQ5G%L<8]Q^W&$<95QJ'&L
M<==QN7&^<=)QR7'4<<YQX''L<>=Q]7'\<0````"Z;-ML[VS9;.IL'VU-B#9M
M*VT];3AM&6TU;3-M$FT,;6-MDVUD;5IM>6U9;8YME6WD;X5M^6T5;@INM6W'
M;>9MN&W&;>QMWFW,;>AMTFW%;?IMV6WD;=5MZFWN;2UN;FXN;AEN<FY?;CYN
M(VYK;BMN=FY-;A]N0VXZ;DYN)&[_;AUN.&Z";JINF&[);K=NTVZ];J]NQ&ZR
M;M1NU6Z/;J5NPFZ?;D%O$6],<.QN^&[^;C]O\FXQ;^]N,F_,;@````"7:A>&
MNVK#:L)JN&JS:JQJWFK1:M]JJFK::NIJ^VH%:Q:&^FH2:Q9K,9L?:SAK-VO<
M=CEK[IA':T-K26M0:UEK5&M;:U]K86MX:WEK?VN`:X1K@VN-:YAKE6N>:Z1K
MJFNK:Z]KLFNQ:[-KMVN\:\9KRVO3:]]K[&OK:_-K[VN^G@AL$VP4;!ML)&PC
M;%YL56QB;&IL@FR-;)IL@6R;;'YL:&QS;))LD&S$;/%LTVR];-=LQ6S=;*YL
ML6R^;`````#4:.=HU6@V:1)I!&G7:.-H)6GY:.!H[V@H:2II&FDC:2%IQFAY
M:7=I7&EX:6MI5&E^:6YI.6ET:3UI66DP:6%I7FE=:8%I:FFR::YIT&F_:<%I
MTVF^:<YIZ%O*:=UINVG#::=I+FJ1::!IG&F5:;1IWFGH:0)J&VK_:0IK^6GR
M:>=I!6JQ:1YJ[6D4:NMI"FH2:L%J(VH3:D1J#&IR:C9J>&I':F)J66IF:DAJ
M.&HB:I!JC6J@:H1JHFJC:@````#$9KAFUF;:9N!F/V;F9NEF\&;U9O=F#V<6
M9QYG)F<G9SB7+F<_9S9G06<X9S=G1F=>9V!G66=C9V1GB6=P9ZEG?&=J9XQG
MBV>F9Z%GA6>W9^]GM&?L9[-GZ6>X9^1GWF?=9^)G[F>Y9\YGQF?G9YQJ'FA&
M:"EH0&A-:#)H3FBS:"MH66AC:'=H?VB?:(]HK6B4:)UHFVB#:*YJN6AT:+5H
MH&BZ:`]IC6A^:`%IRF@(:=AH(FDF:>%H#&G-:`````#:9-)DQ63'9+MDV&3"
M9/%DYV0)@N!DX62L8N-D[V0L9?9D]&3R9/ID`&7]9!AE'&4%921E(V4K931E
M-64W939E.&5+=4AE5F5594UE6&5>95UE<F5X98)E@V6*BYMEGV6K9;=EPV7&
M9<%EQ&7,9=)EVV799>!EX67Q97)G"F8#9OME<V<U9C9F-&8<9D]F1&9)9D%F
M7F9=9F1F9V9H9E]F8F9P9H-FB&:.9HEFA&:89IUFP6:Y9LEFOF:\9@`````>
M8B%B*F(N8C!B,F(S8D%B3F)>8F-B6V)@8FAB?&*"8HEB?F*28I-BEF+48H-B
ME&+78M%BNV+/8O]BQF+49,ABW&+,8LIBPF+'8IMBR6(,8^YB\6(G8P)C"&/O
M8O5B4&,^8TUC'&1/8Y9CCF.`8ZMC=F.C8X]CB6.?8[5C:V-I8[YCZ6/`8\9C
MXV/)8])C]F/$8Q9D-&0&9!-D)F0V9!UE%V0H9`]D9V1O9'9D3F0J995DDV2E
M9*EDB&2\9`````"$8)M@EF"78))@IV"+8.%@N&#@8--@M&#P7[U@QF"U8-A@
M36$5809A]F#W8`!A]&#Z8`-A(6'[8/%@#6$.84=A/F$H82=A2F$_83QA+&$T
M83UA0F%$87-A=V%885EA6F%K871A;V%E87%A7V%=85-A=6&9899AAV&L891A
MFF&*89%AJV&N8<QARF')8?=AR&'#8<9ANF'+87E_S6'F8>-A]F'Z8?1A_V']
M8?QA_F$`8@AB"6(-8@QB%&(;8@````#67N->W5[:7MM>XE[A7NA>Z5[L7O%>
M\U[P7O1>^%[^7@-?"5]=7UQ?"U\17Q9?*5\M7SA?05](7TQ?3E\O7U%?5E]7
M7UE?85]M7W-?=U^#7X)??U^*7XA?D5^'7YY?F5^87Z!?J%^M7[Q?UE_[7^1?
M^%_Q7]U?LV#_7R%@8&`98!!@*6`.8#%@&V`58"M@)F`/8#I@6F!!8&I@=V!?
M8$I@1F!-8&-@0V!D8$)@;&!K8%E@@6"-8.=@@V":8`````!07$]<<5ML7&Y<
M8DYV7'E<C%R17)1<FUFK7+M<MER\7+=<Q5R^7,=<V5SI7/U<^ESM7(Q=ZEP+
M715=%UU<71]=&UT1711=(ET:71E=&%U,75)=3EU+76Q=<UUV78==A%V"7:)=
MG5VL7:Y=O5V07;==O%W)7<U=TUW27=9=VUWK7?)=]5T+7AI>&5X17AM>-EXW
M7D1>0UY`7DY>5UY47E]>8EYD7D=>=5YV7GI>O)Y_7J!>P5["7LA>T%[/7@``
M``!X68%9G5E>3ZM/HUFR6<99Z%G<68U9V5G:625:'UH16AQ:"5H:6D!:;%I)
M6C5:-EIB6FI:FEJ\6KY:RUK"6KU:XUK76N9:Z5K66OI:^UH,6PM;%ELR6]!:
M*ELV6SY;0UM%6T!;45M56UI;6UME6VE;<%MS6W5;>%N(97I;@%N#6Z9;N%O#
M6\=;R5O46]!;Y%OF6^);WEOE6^M;\%OV6_-;!5P'7`A<#5P37"!<(EPH7#A<
M.5Q!7$9<3EQ37``````(5PM7#5<35QA7%E?'51Q7)E<W5SA73E<[5T!73U=I
M5\!7B%=A5W]7B5>35Z!7LU>D5ZI7L%?#5\97U%?25]-7"EC65^-7"U@96!U8
M<E@A6&)82UAP6,!K4E@]6'E8A5BY6)]8JUBZ6-Y8NUBX6*Y8Q5C36-%8UUC9
M6-A8Y5C<6.18WUCO6/I8^5C[6/Q8_5@"60I9$%D;6:9H)5DL62U9,EDX63Y9
MTGI565!93EE:65A98EE@66=9;%EI60````"K5,)4I%2^5+Q4V%3E5.94#U44
M5?U4[E3M5/I4XE0Y54!58U5,52Y57%5%55955U4X53-5756958!5KU2*59]5
M>U5^59A5GE6N57Q5@U6I58=5J%7:5<55WU7$5=Q5Y%745116]U465OY5_54;
M5OE53E905M]Q-%8V5C)6.%9K5F16+U9L5FI6AE:`5HI6H%:45H]6I5:N5K96
MM%;"5KQ6P5;#5L!6R%;.5M%6TU;75NY6^58`5_]6!%<)5P````"GCZQ2K5*\
M4K52P5+-4M=2WE+C4N92[9C@4O-2]5+X4OE2!E,(4SAU#5,04P]3%5,:4R-3
M+U,Q4S-3.%-`4T9315,73DE335/645Y3:5-N4QA9>U-W4X)3EE.@4Z93I5.N
M4[!3ME/#4Q)\V9;?4_QF[G'N4^A3[5/Z4P%4/51`5"Q4+50\5"Y4-E0I5!U4
M3E2/5'54CE1?5'%4=U1P5))4>U2`5'94A%205(94QU2B5+A4I52L5,14R%2H
M5`````#)4,I0LU#"4-90WE#E4.U0XU#N4/E0]5`)40%1`E$64151%%$:42%1
M.E$W43Q1.U$_44!14E%,45118E'X>FE1:E%N48!1@E'85HQ1B5&/49%1DU&5
M4991I%&F4:)1J5&J4:M1LU&Q4;)1L%&U4;U1Q5')4=M1X%%5ANE1[5'P4?51
M_E$$4@M2%%(.4B=2*E(N4C-2.5)/4D122U),4EY25%)J4G12:5)S4G]2?5*-
M4I12DE)Q4HA2D5*HCP`````,7Q!.%4XJ3C%.-DX\3C].0DY63EA.@DZ%3FN,
MBDX2@@U?CDZ>3I].H$ZB3K!.LTZV3LY.S4[$3L9.PD[73MY.[4[?3O=."4]:
M3S!/6T]=3U=/1T]V3XA/CT^83WM/:4]P3Y%/;T^&3Y9/&%'43]]/SD_83]M/
MT4_:3]!/Y$_E3QI0*%`44"I0)5`%4!Q/]D\A4"E0+%#^3^]/$5`&4$-01U`#
M9U504%!(4%I05E!L4'A0@%":4(50M%"R4`````#NA".0+)-"5&^;TVJ)<,*,
M[XTRE[1205K*7@1?%V=\:91I:FT/;V)R_'+M>P&`?H!+A\Z0;5&3GH1YBX`R
MD]:*+5",5'&*:FO$C`>!T6"@9_*=F4Z83A"<:XK!A6B%`&E^;I=X58$`````
M`````````````````````````````.)USXCAB,R1XI9XEHM?AW/+>DZ$H&-E
M=8E206V<;@ET675K>))\AI;<>HV?MD]N8<5E7(:&3JY.VE`A3LQ1[EN998%H
MO&T?<T)VK7<<>N=\;X+2BGR0SY%UEAB8FU+1?2M0F%.79\MMT'$S=.B!*H^C
MEE><GYY@=$%8F6TO?5Z8Y$XV3XM/MU&Q4KI='&"R<SQYTX(TDK>6]I8*EY>>
M8I^F9G1K%U*C4LAPPHC)7DM@D&$C;TEQ/GST?6^``````.V*.(\O55%/*E''
M4LM3I5M]7J!@@F'68PEGVF=G;HQM-G,W<S%U4'G5B)B*2I"1D/60Q):-AQ59
MB$Y93PY.B8H_CQ"8K5!\7I99N5NX7MIC^F/!9-QF2FG8:0MMMFZ4<2AUKWJ*
M?P"`283)A(&)(8L*CF60?98*F7YAD6(R:X-L=&W,?_Q_P&V%?[J'^(AE9[&#
M/)CWEAMM87T]A&J1<4YU4U!=!&OK;\V%+8:GB2E2#U1E7$YGJ&@&=(-T````
M`"MO$X5S5"IG19OS795[K%S&6QR'2F[1A!1Z"(&968U\$6P@=]E2(EDA<5]R
MVW<GEV&="VE_6AA:I5$-5'U4#F;?=O>/F)+TG.I977+%;DU1R6B_?>Q]8I>Z
MGGAD(6H"@X197UO;:QMS\G:R?1>`F80R42AGV9[N=F)G_U(%F21<.V)^?+",
M3U6V8`M]@)4!4U].ME$<63IR-H#.D25?XG>$4WE?!'VLA3.*C8Y6E_-GKH53
ME`EA"&&Y;%)V`````-5LX6SY<#)X*W[>@+."#(3LA`*'$HDJBDJ,II#2DOV8
M\YQLG4].H4Z-4%922E>H63U>V%_97S]BM&8;9]!GTFB242%]JH"H@0"+C(R_
MC'Z2,I8@5"R8%U/54%Q3J%BR9#1G9W)F=T9ZYI'#4J%LAFL`6$Q>5%DL9_M_
MX5'&=FEDZ'A4F[N>RU>Y62=FFF?.:^E4V6E57IR!E6>JF_YG4IQ=:*9.XT_(
M4[EB*V>K;,2/K4]M?K^>!TYB88!N`````(]Y>8$'B8:)]6T77U5BN&S/3FER
MDIL&4CM4=%:S6*1A;F(:<6Y9B7S>?!M]\):'95Z`&4YU3W510%AC7G->"E_$
M9R9./86)E5N6<WP!F/M0P5A6=J=X)5*E=Q&%AGM/4`E91W+'>^A]NH_4CTV0
MOT_)4BE:`5^ME]U/%X+JD@-756-I:RMUW(@4CT)ZWU*36%5A"F*N9LUK/WSI
M@R-0^$\%4T94,5A)69U;\%SO7"E=EEZQ8F=C/F6Y90MG`````#N?RF<7>CE3
MBW7MFF9?G8'Q@YB`/%_%7V)U1GL\D&=HZUF;6A!]?G8LB_5/:E\9:C=L`F_B
M=&AY:(A5BGF,WU[/8\5UTGG7@BB3\I*<A.V&+9S!5&Q?C&5<;15PIXS3C#N8
M3V7V=`U.V$[@5RM99EK,6ZA1`UZ<7A9@=F)W9:=E;F9N;39R)GM0@9J!F8)<
MBZ",YHQTC1R61):N3ZMD9FL>@F&$:H7HD`%<4VFHF'J$5X4/3V]2J5]%7@UG
M`````/U1L7MR>+A[AX!(>^AJ85Z,@%%U8'5K46*2C&YZ=I>1ZIH03W!_G&)/
M>Z65Z9QZ5EE8Y(:\EC1/)%)*4\U3VU,&7BQDD65_9SYL3FQ(<J]R[7-4=4%^
M+(+IA:F,Q'O&D6EQ$ICOF#UC:69J=>1VT'A#A>Z&*E-14R94@UF'7GQ?LF!)
M8GEBJV*09=1KS&RR=:YVD7C8><M]=W^E@*N(N8J[C'^07I?;F`MJ.'R94#Y<
MKE^'9]AK-70)=XY_`````()9/USNE_M.BEG-7XV*X6^P>6)YYUMQA"MSL7%T
M7O5?>V.:9,-QF'Q#3OQ>2T[<5Z)6J6##;PU]_8`S@;^!LH^7B:2&]%V*8JUD
MAXEW9^)L/FTV=#1X1EIU?ZV"K)GS3\->W6*28U=E;V?#=DQRS("Z@"F/39$-
M4/E7DEJ%:'-I9'']<K>,\EC@C&J6&9!_A^1YYW<IA"]/95):4\UBSV?*;'UV
ME'N5?#:"A(7KC]UF(&\&<AM^JX/!F::>`````&.$:87DA0Z*!(M&C`^.`Y`/
MD!F4=I8MF#":V)7-4-52#%0"6`Y<IV&>9!YMLW?E>O2`!(13D(62X%P'G3]3
MEU^S7YQM>7)C=[]YY'O2:^QRK8H#:&%J^%&!>C1I2ESVG.N"Q5M)D1YP>%9O
M7,=@9F6,;%J,09`3F%%4QV8-DDA9HY"%44U.ZE&9A0Z+6'!Z8TN38FFTF01^
M=W574V!IWX[CEEULC$X\7!!?Z8\"4]&,B8!YAO]>Y65S3F51`````+B0+9'8
MD0Z?Y6Q89.)D=67T;H1V&WMID-&3NF[R5+E?I&1-C^V/1))X46M8*5E57)=>
M^VV/?AQUO(SBCEN8N7`=3[]KL6\P=?N63E$05#585UBL66!<DE^795QG(6Y[
M=M^#[8P4D/V039,E>#IXJE*F7A]7=%D28!)06E&L4<U1`%(055186%A7695;
M]ER+7;Q@E6(M9'%G0VB\:-]HUW;8;6]NFVUO<,AQ4U_8=7=Y27M4>U)[UGQQ
M?3!2`````!9>,UZ!7A1?-5]K7[1?\F$18Z)F'6=N;U)R.G4Z=W2`.8%X@7:'
MOXK<BH6-\XV:DG>5`ICEG,525V/T=A5GB&S-<\.,KI-SEB5MG%@.:<QI_8^:
MD]MU&I!:6`)HM&/[:4-/+&_89[N/)H6T?523/VEP;VI7]U@L6RQ]*G(*5..1
MM)VM3DY/7%!U4$-2GHQ(5"18FEL=7I5>K5[W7A]?C&"U8CICT&.O:$!LAWB.
M>0MZX'U'@@**YHI$CA.0`````.E31D]4D+"/:EDQ@?U=ZGJ_C]IH-XSX<DB<
M/6JPBCE.6%,&5F97Q6*B8^9E3FOA;5MNK7#M=^]ZJGN[?3V`QH#+AI6*6Y/C
M5L=8/E^M999F@&JU:S=UQXHD4.5W,%<;7V5@>F9@;/1U&GIN?_2!&(=%D+.9
MR7M<=?EZ47O$A!"0Z7F2>C:#X5I`=RU.\DZ96^!?O6(\9O%GZ&QKAG>(.XI.
MD?.2T)D7:B9P*G/G@E>$KXP!3D91RU&+5?5;`````-.!-84(C2"0PT]T4$=2
M<U-O8$EC7V<L;K.-'Y#73UY<RHS/99I]4E.6B'91PV-86VM;"EP-9%%G7)#6
M3AI9*EEP;%&*/E456*59\&!38L%G-8)5:4"6Q)DHFE-/!EC^6Q"`L5PO7H5?
M(&!+831B_V;P;-YNSH!_@=2"BXBXC`"0+I"*EMN>VYOC3O!3)UDL>XV13)CY
MG=UN)W!34T15A5M88IYBTV*B;.]O(G07BCB4P6_^BCB#YU'XANI3`````$I^
MJ']Z@1N".8*FA6Z*SHSUC7B0=Y"MDI&2@Y6NFTU2A%4X;S9Q:%&%>55^LX'.
M?$Q645BH7*IC_F;]9EIIV7*/=8YU#GE6>=]YEWP@?41]!X8TBCN689`@G^=0
M=5+,4^)3"5"J5>Y83UD]<HM;9%P=4^-@\V!<8X-C/V.[8\UDZ67Y9N-=S6G]
M:15OY7&)3NEU^':3>M]\SWV<?6&`28-8@VR$O(3[A<6(<(T!D&V0EY,<EQ*:
MSU"76(YA`````(1O>F3X6Q9.+'!==2]FQ%$V4N)2TUF!7R=@$&(_971E'V9T
M9O)H%FAC:P5N<G(?==MVOGQ6@/!8_8A_B:"*DXK+BAV0DI%2EUF7B64.>@:!
MNY8M7MQ@&F*E911FD&?S=TUZ37P^?@J!K(QDC>&-7XZI>`=2V6*E8T)DF&(M
MBH-ZP'NLBNJ6=GT,@DF'V4Y(44-38%.C6P)<%ES=729B1V*P9!-H-&C);$5M
M%VW39UQO3G%]<<ME?WJM>]I]`````.UB#6F6:^UQ5'YW@'*"YHG?F%6'L8\[
M7#A/X4^U3P=5(%K=6^E;PU].82]CL&5+9NYHFVEX;?%M,W6Y=1]W7GGF>3-]
MXX&O@JJ%JHDZBJN.FX\RD-V1!Y>Z3L%.`U)U6.Q8"UP:=3U<3H$*BL6/8Y9M
MER5[SXH(F&*1\U:H4Q>0.52"5R5>J&,T;(IP87>+?.!_<(A"D%21$),8DX^6
M7G3$F@==:5UP9:)GJ(W;EFYC26<9:<6#%YC`EOZ(`````-U2(%-'4^Q3Z%1&
M53%5%U9H6;Y9/%JU6P9<#UP17!I<A%Z*7N!><%]_8H1BVV*,8W=C!V8,9BUF
M=F9^9Z)H'VHU:KQLB&T);EAN/'$F<6=QQW4!=UUX`7EE>?!YX'H1>Z=\.7V6
M@-:#BX1)A5V(\X@?BCR*5(ISBF&,WHRDD6:2?I,8E)R6F)<*3@A.'DY73I=1
M<%+.5S18S%@B6SA>Q6#^9&%G5F=$;;9R<W5C>KB$<HNXD2"3,5;T5_Z8````
M`)=;,5S>7>Y/`6'^8C)MP'G+>4)]37[2?^V!'X*0A$:(<HF0BW2.+X\QD$N1
M;)'&EIR1P$Y/3T5105.37PYBU&=!;`MN8W,F?LV1@Y+44QE9OUO1;5UY+GZ;
M?'Y8GW'Z45.(\(_*3_M<)6:L=^-Z'(+_F<91JE_L96]IB6OS;99N9&_^=A1]
MX5UUD(>1!ICF41U20&*19MEF&FZV7M)]<G_X9J^%]X7XBJE2V5-S68]>D%]5
M8.229):W4!]1`````"%KRVZ[;#YRO734=<%X.GD,@#.`ZH&4A)Z/4&Q_G@]?
M6(LKG?IZ^(Z-6^N6`T[Q4_=7,5G)6J1;B6!_;@9OOG7JC)];`(7@>W)0]&>=
M@F%<2H4>?@Z"F5$$7&AC9HV<96YQ/GD7?06`'8O*CFZ0QX:JD!]0^E(Z7%-G
M?'`U<DR1R)$KD^6"PELQ7_E@.T[64XA;2V(Q9XIKZ7+@<RYZ:X&CC5*1EID2
M4==3:E3_6XAC.6JL?0"7VE;.4VA4`````-];]F*N9.9D+6>Z:ZF%T9:0=M:;
M3&,&DZN;OW929@E.F%#"4W%<Z&"29&-E7VCF<<IS(W67>X)^E8:#B]N,>)$0
MF:QEJV:+:]5.U$XZ3W]/.E+X4_)3XU7;5NM8RUG)6?]94%M-7`)>*U[77QU@
M!V,O95Q;KV6]9>AEG6=B:WMK#VQ%<TEYP7GX?!E]*WVB@`*!\X&6B5Z*:8IF
MBHR*[HK'C-R,S);\F&]KBTX\3XU/4%%76_I;2&$!8T)F`````&1K`YC*3O!6
M9%>^6%I::&#'80]F!F8Y:+%H]VW5=3I];H)"FYM.4$_)4P95;UWF7>Y=^V>9
M;'-T`GA0BI:3WXA05Z=>*V.U4*Q0C5$`9\E47EB[6;!;:5]-8J%C/6AS:PAN
M?7#'D8!R%7@F>&UYCF4P?=R#P8@)CYN69%(H5U!G:G^AC+110E<JECI8BFFT
M@+)4#EW\5Y5X^IU<3TI2BU0^9"AF%&?U9X1Z5GLB?2^37&BMFSE[&5.*43=2
M``````Y4B5515Z)7?5E46UU;CUOE7>==]UUX7H->FEZW7AA?4F!,89=BV&*G
M8SME`F9#9O1F;6<A:)=HRVE?;"IM:6TO;IUN,G6'=FQX/WK@?`5]&'U>?;%]
M%8`#@*^`L8!4@8^!*H)2@TR(88@;BZ*,_(S*D'61<9(_>/R2I)5-E@68F9G8
MFCN=6U*K4O=3"%356/=BX&]JC%^/N9Y+43M22E3]5D!Z=Y%@G=*>1',);W"!
M$77]7]I@J)K;<KR/`````!QI*6I]<JQR+G,4>&]X>7T,=ZF`BXD9B^*,THYC
MD'63>I95F!.:>)Y#49]3LU-[7B9?&VZ0;H1S_G-#?3>"`(KZBE"63DX+4.13
M?%3Z5M%99%OQ7:M>)U\X8D5EKV=6;M!RRGRTB*&`X8#P@TZ&AXKHC3>2QY9G
MF!.?E$Z23@U/2%-)5#Y4+UJ,7Z%?GV"G:(YJ6G2!>)Z*I(IWBY"17D[)FZ1.
M?$^O3QE0%E!)46Q1GU*Y4OY2FE/C4Q%4`````)ACGWJ3;'2788^J>HIQB):"
M?!=H<'Y1:&R3\E(;5*N%$XJD?\V.X9!F4XB(07G"3[Y0$5)$45-5+5?J<XM7
M45EB7X1?=6!V86=AJ6&R8SID;&5O9D)H$VYF=3UZ^WQ,?9E]2WYK?PZ#2H/-
MA@B*8XIFB_V.&IB/G;B"SH_HFX=2'V*#9,!OF99!:)%0(&MZ;%1O='I0?4"(
M(XH(9_9..5`F4&50?%$X4F-2IU4/5P58S%KZ7K)A^&'S8G)C`````)M/H$_1
M4$=1]GIQ4?915%,A4W]3ZU.L58-8X5PW7TI?+V!08&U@'V-994MJP6S"<NUR
M[W?X@`6!"().A?>0X9/_EU>96IKP3MU1+5R!9FUI0%SR9G5IB7-0:(%\Q5#D
M4D=7_ETFDZ1E(VL]:S1T@7F]>4M[RGVY@LR#?XA?B3F+T8_1D1]4@))=3C90
MY5,Z4]=REG/I=^:"KX[&F<B9TIEW41IA7H:P57IZ=E#36T>0A98R3MMJYY%1
M7$A<`````%]J,%[%:Q=L?6Q_=4AY8UL`>@!]O5^/B1B*M(QWC<R.'8_BF`Z:
M/)N`3GU0`%&369Q;+V*`8NQD.FN@<I%U1WFI?_N'O(IPBZQCRH.@EPE4`U2K
M551H6&IPBB=X=6?-GG13HEL:@5"&!I`83D5.QTX13\I3.%2N6Q-?)6!193UG
M0FQR;.-L>'`#='9ZKGH(>QI]_GQF?>=E6W*[4T5<Z%W28N!B&6,@;EJ&,8K=
MC?B2`6^F>5J;J$ZK3JQ.`````*5\"%+%@N9T?DZ#3Z!1TEL*4MA2YU+[79I5
M*ECF68Q;F%O;6W)>>5ZC8!]A8V&^8=MC8F719U-H^F@^:U-K5VPB;Y=O16^P
M=!AUXW8+=_]ZH7LA?.E]-G_P?YV`9H*>@[.)S(JKC(204923E9&5HI5EEM.7
M*)D8@CA.*U2X7,Q=J7-,=CQWJ5SK?PN-P981F%286)@!3PY/<5.<56A6^E='
M60E;Q%N07`Q>?E[,7^YC.F?79>)E'V?+:,1H`````$&;9F:P:'=M<'!,=89V
M=7VE@OF'BY6.EIV,\5&^4A99LU2S6Q9=:&&"::]MC7C+A%>(<HJGD[B:;&VH
MF=F&HU?_9\Z&#I*#4H=6!%337N%BN60\:#AHNVMR<[IX:WJ:B=*):XT#C^V0
MHY64EFF79ENS7'UI39A.F)MC('LK:G]JMF@-G%]O<E*=57!@[&([;0=NT6Y;
MA!")1(\43CF<]E,;:3IJA)<J:%Q1PWJRA-R1C)-;5BB=(F@%@S&$`````+QB
M^F4J:B=KM&N+<\%_5HDLG0Z=Q)ZA7)9L>X,$44M<MF'&@79H87)93OI/>%-I
M8"EN3WKSEPM.%E/N3E5//4^A3W-/H%+O4PE6#UG!6K9;X5O1>8=FG&>V9TQK
MLVQK<,)SC7F^>3QZAWNQ@MN"!(-W@^^#TX-FA[***5:HC.:/3I`>EXJ&Q$_H
M7!%B67([=>6!O8+^AL",Q983F=69RTX:3^.)WE9*6,I8^U[K7RI@E&!B8-!A
M$F+08CEE`````&*6<):@EON7"U3S4X=;SW"]?\*/Z)9O4UR=NGH13I-X_($F
M;AA6!%4=:QJ%.YSE6:E39FW<=(^50E:13DN0\I9/@PR9X5.V53!;<5\@9O-F
M!&@X;/-L*6U;=,AV3GHTF/&"6XA@BNV2LFVK=<IVQ9FF8`&+BHVRE8YIK5.&
M41)7,%A$6;1;]EXH8*EC]&._;!1OCG`4<5EQU7$_<P%^=H+1@I>%8)!;DAN=
M:5B\95IL)77Y42Y995F`7]Q?`````)Q.%E4#6C^6P%0;82AC]EDBD'6$'(-0
M>JI@X6,E;NUE9H2F@O6;DV@G5Z%E<6*;6]!9>X;TF&)]OGV.FQ9BGWRWB(E;
MM5X)8Y=F2&C'E8V73V?E3@I/34^=3TE0\E8W6=19`5H)7-]@#V%P81-F!6FZ
M<$]U<'7[>:U][WW#@`Z$8X@"BU60>I`[4Y5.I4[?5[*`P9#O>`!.\5BB;CB0
M,GHH@XN"+YQ!47!3O53A5.!6^UD57_*8ZVWD@"V%```````E`B4,)1`E&"44
M)1PE+"4D)30E/"4!)0,E#R43)1LE%R4C)3,E*R4[)4LE("4O)2@E-R4_)1TE
M,"4E)3@E0B40!!$$$@03!!0$%00!!!8$%P08!!D$&@0;!!P$'00>!!\$(`0A
M!"($(P0D!"4$)@0G!"@$*00J!"L$+`0M!"X$+P0`````````````````````
M```````````````````P!#$$,@0S!#0$-011!#8$-P0X!#D$.@0[!#P$/00^
M!#\$0`1!!$($0P1$!$4$1@1'!$@$201*!$L$3`1-!$X$3P0`````````````
M``````````````````````````"1`Y(#DP.4`Y4#E@.7`Y@#F0.:`YL#G`.=
M`YX#GP.@`Z$#HP.D`Z4#I@.G`Z@#J0,`````````````````````L0.R`[,#
MM`.U`[8#MP.X`[D#N@.[`[P#O0.^`[\#P`/!`\,#Q`/%`\8#QP/(`\D#````
M`````````````````*$PHC"C,*0PI3"F,*<PJ#"I,*HPJS"L,*TPKC"O,+`P
ML3"R,+,PM#"U,+8PMS"X,+DPNC"[,+PPO3"^,+\PP##!,,(PPS#$,,4PQC#'
M,,@PR3#*,,LPS##-,,XPSS#0,-$PTC#3,-0PU3#6,-<PV##9,-HPVS#<,-TP
MWC#?,.`PX3#B,.,PY##E,.8PYS#H,.DPZC#K,.PP[3#N,.\P\##Q,/(P\S#T
M,/4P]C```````````````````````````$$P0C!#,$0P13!&,$<P2#!),$HP
M2S!,,$TP3C!/,%`P43!2,%,P5#!5,%8P5S!8,%DP6C!;,%PP73!>,%\P8#!A
M,&(P8S!D,&4P9C!G,&@P:3!J,&LP;#!M,&XP;S!P,'$P<C!S,'0P=3!V,'<P
M>#!Y,'HP>S!\,'TP?C!_,(`P@3"",(,PA#"%,(8PAS"(,(DPBC"+,(PPC3".
M,(\PD#"1,)(PDS```````````````````````````````````!#_$?\2_Q/_
M%/\5_Q;_%_\8_QG_```````````````````A_R+_(_\D_R7_)O\G_RC_*?\J
M_RO_+/\M_R[_+_\P_S'_,O\S_S3_-?\V_S?_./\Y_SK_````````````````
M0?]"_T/_1/]%_T;_1_](_TG_2O]+_TS_3?]._T__4/]1_U+_4_]4_U7_5O]7
M_UC_6?]:_P````````````#&):$EH"6S);(EO26\)3L@$C"2(9`AD2&3(1,P
M``````````````````````````````@B"R*&(H<B@B*#(BHB*2(`````````
M````````````)R(H(JP`TB'4(0`B`R(`````````````````````````````
M("*E(A(C`B('(F$B4B)J(FLB&B(](ATB-2(K(BPB```````````````````K
M(3`@;R9M)FHF("`A(+8```````````#O)0``````,`$P`C`,_P[_^S`:_QO_
M'_\!_YLPG#"T`$#_J``^_^/_/__],/XPG3">,`,PW4X%,`8P!S#\,!4@$"`/
M_UP`'#`6(%S_)B`E(!@@&2`<(!T@"/\)_Q0P%3`[_SW_6_]=_P@P"3`*,`LP
M##`-,`XP#S`0,!$P"_\2(K$`UP#W`!W_8"(<_Q[_9B)G(AXB-")")D`FL``R
M(#,@`R'E_P3_H@"C``7_`_\&_PK_(/^G``8F!2;+)<\ESB7')0````````$`
M`@`#``0`!0`&``<`"``)``H`"P`,``T`#@`/`!``$0`2`!,`%``5`!8`%P`8
M`!D`&@`;`!P`'0`>`!\`(``A`"(`(P`D`"4`)@`G`"@`*0`J`"L`+``M`"X`
M+P`P`#$`,@`S`#0`-0`V`#<`.``Y`#H`.P`\`#T`/@`_`$``00!"`$,`1`!%
M`$8`1P!(`$D`2@!+`$P`30!.`$\`4`!1`%(`4P!4`%4`5@!7`%@`60!:`%L`
MI0!=`%X`7P!@`&$`8@!C`&0`90!F`&<`:`!I`&H`:P!L`&T`;@!O`'``<0!R
M`',`=`!U`'8`=P!X`'D`>@![`'P`?0`^(```````````````````````````
M````````````````````````````````````````````````````````````
M````8?]B_V/_9/]E_V;_9_]H_VG_:O]K_VS_;?]N_V__</]Q_W+_<_]T_W7_
M=O]W_WC_>?]Z_WO_?/]]_W[_?_^`_X'_@O^#_X3_A?^&_X?_B/^)_XK_B_^,
M_XW_CO^/_Y#_D?^2_Y/_E/^5_Y;_E_^8_YG_FO^;_YS_G?^>_Y__````````
M````````````````````````````````````````````````````````````
M`````````````````/B>_YX"GP.?"9\/GQ"?$9\2GQ2?%I\7GQF?&I\;GQ^?
M(I\FGRJ?*Y\OGS&?,I\TGS>?.9\ZGSR?/9\_GT&?0Y]$GT6?1I]'GU.?59]6
MGU>?6)]:GUV?7I]HGVF?;9]NGV^?<)]QGW.?=9]ZGWV?CY^0GY&?DI^4GY:?
MEY^>GZ&?HI^CGZ6?``````````````````````````````````!\G7Z=@YV$
MG8:=BIV-G8Z=DIV3G96=EIV7G9B=H9VJG:R=KIVQG;6=N9V\G;^=PYW'G<F=
MRIW4G=6=UIW7G=J=WIW?G>"=Y9WGG>F=ZYWNG?"=\YWTG?Z="IX"G@>>#IX0
MGA&>$IX5GA:>&9X<GAV>>IY[GGR>@)Z"GH.>A)Z%GH>>CIZ/GI:>F)Z;GIZ>
MI)ZHGJR>KIZOGK">LYZTGK6>QI[(GLN>U9[?GN2>YY[LGNV>[I[PGO&>\I[U
MG@````#YF_J;_9O_FP"<`IP+G`^<$9P6G!B<&9P:G!R<'IPBG".<)IPGG"B<
M*9PJG#&<-9PVG#></9Q!G$.<1)Q%G$F<2IQ.G$^<4)Q3G%2<5IQ8G%N<79Q>
MG%^<8YQIG&J<7)QKG&B<;IQPG'*<=9QWG'N<YISRG/><^9P+G0*=$9T7G1B=
M')T=G1Z=+YTPG3*=,YTTG3J=/)U%G3V=0IU#G4>=2IU3G52=7YUCG6*=99UI
MG6J=:YUPG7:==YU[G0`````$FP6;")L)FPN;#)L-FPZ;$)L2FQ:;&9L;FQR;
M()LFFRN;+9LSFS2;-9LWFSF;.IL]FTB;2YM,FU6;5IM7FUN;7IMAFV.;99MF
MFVB;:IMKFVR;;9MNFW.;=9MWFWB;>9M_FX";A)N%FX:;AYN)FXJ;BYN-FX^;
MD)N4FYJ;G9N>FZ:;IYNIFZR;L)NQF[*;MYNXF[N;O)N^F[^;P9O'F\B;SIO0
MF]>;V)O=F]^;Y9OGF^J;ZYOOF_.;]YOXFP````"YF;J9O9F_F<.9R9G3F=29
MV9G:F=R9WIGGF>J9ZYGLF?"9])GUF?F9_9G^F0*:`YH$F@N:#)H0FA&:%IH>
MFB":(IHCFB2:)YHMFBZ:,YHUFC::.)I'FD&:1)I*FDN:3)I.FE&:5)I6FEV:
MJIJLFJZ:KYJRFK2:M9JVFKF:NYJ^FK^:P9K#FL::R)K.FM":TIK5FM::UYK;
MFMR:X)KDFN6:YYKIFNR:\IKSFO6:^9KZFOV:_YH`FP&;`IL#FP`````KF"Z8
M+Y@PF#*8,Y@UF"68/IA$F$>82IA1F%*84YA6F%>869A:F&*88YAEF&:8:IAL
MF*N8K9BNF+"8M)BWF+B8NIB[F+^8PIC%F,B8S)CAF..8Y9CFF.>8ZICSF/:8
M`ID'F0B9$9D5F1:9%YD:F1N9')D?F2*9)IDGF2N9,9DRF3.9-)DUF3F9.ID[
MF3R90)E!F4:91YE(F4V93IE4F5B969E;F5R97IE?F6"9FYF=F9^9IIFPF;&9
MLIFUF0`````#EP67"9<:EQN7'9<AER*7(Y<HES&7,Y=!ET.72I=.ET^759=7
MEUB76I=;EV.79Y=JEVZ7<Y=VEW>7>)=[EWV7?Y>`EXF7E9>6EY>7F9>:EYZ7
MGY>BEZR7KI>QE[*7M9>VE[B7N9>ZE[R7OI>_E\&7Q)?%E\>7R9?*E\R7S9?.
ME]"7T9?4E]>7V)?9E]V7WI?@E]N7X9?DE^^7\9?TE_>7^)?ZEP>8"I@9F`V8
M#I@4F!:8')@>F""8(Y@FF`````!^E825B)6,E8V5CI6=E9Z5GY6AE::5J96K
ME:R5M)6VE;J5O96_E<:5R)7)E<N5T)71E=*5TY79E=J5W97>E=^5X)7DE>:5
M'98>EB*6))8EEB:6+)8QEC.6-Y8XECF6.I8\ECV60992EE265I97EEB6899N
MEG26>Y9\EGZ6?Y:!EH*6@Y:$EHF6D9:6EIJ6G9:?EJ26I9:FEJF6KI:OEK.6
MNI;*EM*6LEW8EMJ6W9;>EM^6Z9;OEO&6^I8"EP````!ZDWV3?Y.`DX&3@I.(
MDXJ3BY.-DX^3DI.5DYB3FY.>DZ&3HY.DDZ:3J).KD[23M9.VD[J3J9/!D\23
MQ9/&D\>3R9/*D\N3S)/-D].3V9/<D]Z3WY/BD^:3YY/YD_>3^)/ZD_N3_9,!
ME`*4!)0(E`F4#90.E`^4%906E!>4'Y0NE"^4,90RE#.4-)0[E#^4/91#E$64
M2)1*E$R45919E%R47Y1AE&.4:)1KE&V4;I1OE'&4<I2$E(.4>)5YE0````"9
MDI^2H)*DDJ62IY*HDJN2KY*RDK:2N)*ZDKN2O)*]DK^2P)+!DL*2PY+%DL:2
MQY+(DLN2S)+-DLZ2T)+3DM62UY+8DMF2W)+=DM^2X)+ADN.2Y9+GDNB2[)+N
MDO"2^9+[DO^2`),"DPB3#9,1DQ23%9,<DQV3'I,?DR&3)),EDR>3*9,JDS.3
M-),VDS>31Y-(DTF34)-1DU*359-7DUB36I->DV2399-GDVF3:I-MDV^3<)-Q
MDW.3=)-VDP````#"D<.1Q9'3D=21UY'9D=J1WI'DD>61Z9'JD>R1[9'ND>^1
M\)'QD?>1^9'[D?V1`)(!D@22!9(&D@>2"9(*D@R2$)(2DA.2%I(8DAR2'9(C
MDB22)9(FDBB2+I(ODC"2,Y(UDC:2.)(YDCJ2/)(^DD"20I)#DD:21Y)*DDV2
M3I)/DE&26))9DER279)@DF&299)GDFB2:9)NDF^2<))UDG:2=Y)XDGF2>Y)\
MDGV2?Y*(DHF2BI*-DHZ2DI*7D@````#$D,60QY#(D-60UY#8D-F0W)#=D-^0
MY9#2D/:0ZY#OD/"0])#^D/^0`)$$D061!I$(D0V1$)$4D1:1%Y$8D1J1')$>
MD2"1)9$BD2.1)Y$ID2Z1+Y$QD321-I$WD3F1.I$\D3V10Y%'D4B13Y%3D5>1
M69%:D5N189%DD6>1;9%TD7F1>I%[D8&1@Y&%D8:1BI&.D9&1DY&4D961F)&>
MD:&1II&HD:R1K9&ND;"1L9&RD;.1MI&[D;R1O9&_D0````!#CT>/3X]1CU*/
M4X]4CU6/6(]=CUZ/98^=CZ"/H8^DCZ6/IH^UC[:/N(^^C\"/P8_&C\J/RX_-
MC]"/TH_3C]6/X(_CC^2/Z(_NC_&/]8_VC_N/_H\"D`20")`,D!B0&Y`HD"F0
M+Y`JD"R0+9`SD#20-Y`_D$.01)!,D%N079!BD&:09Y!LD'"0=)!YD(60B)"+
MD(R0CI"0D)60EY"8D)F0FY"@D*&0HI"ED+"0LI"SD+20MI"]D,R0OI##D```
M```CCB:.)XXQCC..-HXWCCB..8X]CD".08Y+CDV.3HY/CE2.6XY<CEV.7HYA
MCF*.:8YLCFV.;XYPCG&.>8YZCGN.@HZ#CHF.D(Z2CI6.FHZ;CIV.GHZBCJ>.
MJ8ZMCJZ.LXZUCKJ.NX[`CL&.PX[$CL>.SX[1CM2.W([HCNZ.\([QCO>.^8[Z
MCNV.`(\"CP>/"(\/CQ"/%H\7CQB/'H\@CR&/(X\ECR>/*(\LCRV/+H\TCS6/
M-H\WCSJ/0(]!CP````"'C(N,D(R2C).,F8R;C)R,I(RYC+J,Q8S&C,F,RXS/
MC-:,U8S9C-V,X8SHC.R,[XSPC/*,]8SWC/B,_HS_C`&-`XT)C1*-%XT;C66-
M:8ULC6Z-?XV"C82-B(V-C9"-D8V5C9Z-GXV@C::-JXVLC:^-LHVUC;>-N8V[
MC<"-Q8W&C<>-R(W*C<Z-T8W4C=6-UXW9C>2-Y8WGC>R-\(V\C?&-\HWTC?V-
M`8X$C@6.!HX+CA&.%(X6CB".(8XBC@````"VBK>*NXJ^BL.*QHK(BLF*RHK1
MBM.*U(K5BM>*W8K?BNR*\(KTBO6*]HK\BO^*!8L&BPN+$8L<BQZ+'XL*BRV+
M,(LWBSR+0HM#BT2+18M&BTB+4HM3BU2+68M-BUZ+8XMMBW:+>(MYBWR+?HN!
MBX2+A8N+BXV+CXN4BY6+G(N>BY^+.(PYC#V,/HQ%C$>,28Q+C$^,48Q3C%2,
M5XQ8C%N,78Q9C&.,9(QFC&B,:8QMC'.,=8QVC'N,?HR&C`````![B7R)?8F)
MB8V)D(F4B96)FXF<B9^)H(FEB;")M(FUB;:)MXF\B=2)U8G6B=>)V(GEB>F)
MZXGMB?&)\XGVB?F)_8G_B02*!8H'B@^*$8H2BA2*%8H>BB"*(HHDBB:**XHL
MBB^*-8HWBCV*/HI`BD.*18I'BDF*38I.BE.*5HI7BEB*7(I=BF&*98IGBG6*
M=HIWBGF*>HI[BGZ*?XJ`BH.*AHJ+BH^*D(J2BI:*EXJ9BI^*IXJIBJZ*KXJS
MB@`````ZB#R(08A#B$6(2(A)B$J(2XA.B%&(58A6B%B(6HA<B%^(8(ADB&F(
M<8AYB'N(@(B8B)J(FXB<B)^(H(BHB*J(NHB]B+Z(P(C*B,N(S(C-B,Z(T8C2
MB-.(VXC>B.>([XCPB/&(]8CWB`&)!HD-B0Z)#XD5B1:)&(D9B1J)'(D@B2:)
M)XDHB3"),8DRB36).8DZB3Z)0(E"B46)1HE)B4^)4HE7B5J)6XE<B6&)8HEC
MB6N);HEPB7.)=8EZB0`````HARZ'+X<QAS*'.8<ZASR'/8<^AT"'0X=%ATV'
M6(==AV&'9(=EAV^'<8=RAWN'@X>$AX6'AH>'AXB'B8>+AXR'D(>3AY6'EX>8
MAYF'GH>@AZ.'IX>LAZV'KH>QA[6'OH>_A\&'R(?)A\J'SH?5A]:'V8?:A]R'
MWX?BA^.'Y(?JA^N'[8?QA_.'^(?ZA_^'`8@#B`:("8@*B`N($(@9B!*($X@4
MB!B(&H@;B!R('H@?B"B(+8@NB#"(,H@UB`````#_A0"&!(8%A@V&#H80AA&&
M$H88AAF&&X8>AB&&)X8IAC:&.(8ZACR&/89`AD*&1H92AE.&5H97AEB&689=
MAF"&889BAF.&9(9IAFR&;X9UAG:&=X9ZAHV&D8:6AIB&FH:<AJ&&IH:GAJB&
MK8:QAK.&M(:UAK>&N(:YAK^&P(;!AL.&Q8;1AM*&U8;7AMJ&W(;@AN.&Y8;G
MAHB&^H;\AOV&!(<%AP>'"X<.AP^'$(<3AQ2'&8<>AQ^'(8<CAP````#<A.>$
MZH3OA/"$\83RA/>$,H7ZA/N$_80"A0.%!X4,A0Z%$(4<A1Z%(H4CA22%)84G
MA2J%*X4OA3.%-(4VA3^%1H5/A5"%4852A5.%5H59A5R%785>A5^%8(5AA6*%
M9(5KA6^%>85ZA7N%?85_A8&%A86&A8F%BX6,A8^%DX68A9V%GX6@A:*%I86G
MA;2%MH6WA;B%O(6]A;Z%OX7"A<>%RH7+A<Z%K878A=J%WX7@A>:%Z(7MA?.%
M]H7\A0````!]@W^#@(."@X2#AH.-@Y*#E(.5@YB#F8.;@YR#G8.F@Z>#J8.L
M@[Z#OX/`@\>#R8//@]"#T8/4@]V#4X/H@^J#]H/X@_F#_(,!A`:$"H0/A!&$
M%809A*V#+X0YA$6$1X1(A$J$381/A%&$4H16A%B$681:A%R$8(1DA&6$9X1J
MA'"$<X1TA':$>(1\A'V$@82%A)*$DX25A)Z$IH2HA*F$JH2OA+&$M(2ZA+V$
MOH3`A,*$QX3(A,R$SX33A`````!+@DZ"3X)1@E:"7()@@F."9X)M@G2">X)]
M@G^"@(*!@H."A(*'@HF"BH*.@I&"E(*6@IB"FH*;@J""H8*C@J2"IX*H@JF"
MJH*N@K""LH*T@K>"NH*\@KZ"OX+&@M""U8+:@N""XH+D@NB"ZH+M@N^"]H+W
M@OV"_H(`@P&#!X,(@PJ#"X-4@QN#'8,>@Q^#(8,B@RR#+8,N@S"#,X,W@SJ#
M/(,]@T*#0X-$@T>#38-.@U&#58-6@U>#<(-X@P````#P@/*`\X#V@/F`^H#^
M@`.!"X$6@1>!&($<@1Z!(($D@2>!+($P@36!.H$\@46!1X%*@4R!4H%7@6"!
M88%G@6B!:8%M@6^!=X&!@9"!A(&%@8:!BX&.@9:!F(&;@9Z!HH&N@;*!M(&[
M@<N!PX'%@<J!SH'/@=6!UX';@=V!WH'A@>2!ZX'L@?"!\8'R@?6!]H'X@?F!
M_8'_@0""`X(/@A."%((9@AJ"'8(A@B*"*((R@C2".H)#@D2"18)&@@````!Q
M?WU_?G]_?X!_BW^-?X]_D'^1?Y9_EW^<?Z%_HG^F?ZI_K7^T?[Q_OW_`?\-_
MR'_.?\]_VW_??^-_Y7_H?^Q_[G_O?_)_^G_]?_Y__W\'@`B`"H`-@`Z`#X`1
M@!.`%(`6@!V`'H`?@""`)(`F@"R`+H`P@#2`-8`W@#F`.H`\@#Z`0(!$@&"`
M9(!F@&V`<8!U@(&`B(".@)R`GH"F@*>`JX"X@+F`R(#-@,^`TH#4@-6`UX#8
M@."`[8#N@`````">?:9]IWVJ?;-]MGVW?;E]PGW#?<1]Q7W&?<Q]S7W.?==]
MV7T`?N)]Y7WF?>I]ZWWM??%]]7WV??E]^GT(?A!^$7X5?A=^''X=?B!^)WXH
M?BQ^+7XO?C-^-GX_?D1^17Y'?DY^4'Y2?EA^7WYA?F)^97YK?FY^;WYS?GA^
M?GZ!?H9^AWZ*?HU^D7Z5?IA^FGZ=?IY^/'\[?SU_/G\_?T-_1']'?T]_4G]3
M?UM_7']=?V%_8W]D?V5_9G]M?P````!A?&-\9WQI?&U\;GQP?')\>7Q\?'U\
MAGR'?(]\E'R>?*!\IGRP?+9\MWRZ?+M\O'R_?,1\QWS(?,E\S7S/?--\U'S5
M?-=\V7S:?-U\YGSI?.M\]7P#?0=]"'T)?0]]$7T2?1-]%GT=?1Y](WTF?2I]
M+7TQ?3Q]/7T^?4!]07U'?4A]37U1?5-]5WU9?5I]7'U=?65]9WUJ?7!]>'UZ
M?7M]?WV!?8)]@WV%?89]B'V+?8Q]C7V1?99]EWV=?0`````Q>S1[/7L_>T![
M07M'>TY[57M@>V1[9GMI>VI[;7MO>W)[<WMW>X1[B7N.>Y![D7N6>YM[GGN@
M>Z5[K'NO>[![LGNU>[9[NGN[>[Q[O7O">\5[R'O*>]1[UGO7>]E[VGO;>^A[
MZGOR>_1[]7OX>_E[^GO\>_Y[`7P"?`-\!'P&?`E\"WP,?`Y\#WP9?!M\('PE
M?"9\*'PL?#%\,WPT?#9\.7PZ?$9\2GQ5?%%\4GQ3?%E\6GQ;?%Q\77Q>?```
M``#@>>)YY7GJ>>MY[7GQ>?AY_'D">@-Z!WH)>@IZ#'H1>A5Z&WH>>B%Z)WHK
M>BUZ+WHP>C1Z-7HX>CEZ.GI$>D5Z1WI(>DQZ57I6>EEZ7'I=>E]Z8'IE>F=Z
M:GIM>G5Z>'I^>H!Z@GJ%>H9ZBGJ+>I!ZD7J4>IYZH'JC>JQZLWJU>KEZNWJ\
M>L9ZR7K,>LYZT7K;>NAZZ7KK>NQZ\7KT>OMZ_7K^>@=[%'L?>R-[)WLI>RI[
M*WLM>RY[+WLP>P````"[>+UXOWC'>,AXR7C,>,YXTGC3>-5XUGCD>-MXWWC@
M>.%XYGCJ>/)X\W@`>?9X]WCZ>/MX_W@&>0QY$'D:>1QY'GD?>2!Y)7DG>2EY
M+7DQ>31Y-7D[>3UY/WE$>45Y1GE*>4MY3WE1>51Y6'E;>5QY9WEI>6MY<GEY
M>7MY?'E^>8MYC'F1>9-YE'F5>99YF'F;>9QYH7FH>:EYJWFO>;%YM'FX>;MY
MPGG$><=YR'G*><]YU'G6>=IYW7G>>0````!D=V=W:G=L=W!W<G=S=W1W>G=]
M=X!WA'>,=XUWE'>5=Y9WFG>?=Z)WIW>J=ZYWKW>Q=[5WOG?#=\EWT7?2=]5W
MV7?>=]]WX'?D=^9WZG?L=_!W\7?T=_AW^W<%>`9X"7@->`YX$7@=>"%X(G@C
M>"UX+G@P>#5X-WA#>$1X1WA(>$QX3GA2>%QX7GA@>&%X8WAD>&AX:GAN>'IX
M?GB*>(]XE'B8>*%XG7B>>)]XI'BH>*QXK7BP>+%XLGBS>``````Z=CQV2G9`
M=D%V0W9$=D5V279+=E5V679?=F1V979M=FYV;W9Q=G1V@7:%=HQVC7:5=IMV
MG':==I]VH':B=J-VI':E=J9VIW:H=JIVK7:]=L%VQ7;)=LMVS';.=M1VV7;@
M=N9VZ';L=O!V\7;V=OEV_'8`=P9W"G<.=Q)W%'<5=Q=W&7<:=QQW(G<H=RUW
M+G<O=S1W-7<V=SEW/7<^=T)W17=&=TIW37=.=T]W4G=6=U=W7'=>=U]W8'=B
M=P`````2=19U%W4@=2%U)'4G=2EU*G4O=39U.74]=3YU/W5`=4-U1W5(=4YU
M4'52=5=U7G5?=6%U;W5Q=7EU>G5[=7QU?75^=8%UA760=9)UDW65=9EUG'6B
M=:1UM'6Z=;]UP'7!=<1UQG7,=<YUSW77==QUWW7@=>%UY'7G=>QU[G7O=?%U
M^74`=@)V`W8$=@=V"'8*=@QV#W82=A-V%786=AEV&W8<=AUV'G8C=B5V)G8I
M=BUV,G8S=C5V.'8Y=@````#_<P!T`70$=`=T"G01=!IT&W0D="9T*'0I="IT
M*W0L="UT+G0O=#!T,70Y=$!T0W1$=$9T1W1+=$UT4712=%=T771B=&9T9W1H
M=&MT;71N='%T<G2`=(%TA72&=(=TB72/=)!TD722=)ATF72:=)QTGW2@=*%T
MHW2F=*ATJ72J=*MTKG2O=+%TLG2U=+ETNW2_=,ATR73,=-!TTW38=-ITVW3>
M=-]TY'3H=.ITZW3O=/1T^G3[=/QT_W0&=0````#^<@)S!',%<P=S"W,-<Q)S
M$W,8<QES'G,B<R1S)W,H<RQS,7,R<S5S.G,[<SUS0W--<U!S4G-6<UAS77->
M<U]S8'-F<V=S:7-K<VQS;G-O<W%S=W-Y<WQS@'.!<X-SA7.&<XYSD'.3<Y5S
MEW.8<YQSGG.?<Z!SHG.E<Z9SJG.K<ZUSM7.W<[ESO'.]<[]SQ7/&<\ESRW/,
M<\]STG/3<]9SV7/=<^%SXW/F<^=SZ7/T<_5S]W/Y<_IS^W/]<P````!H<7EQ
M@'&%<8=QC'&2<9IQFW&@<:)QKW&P<;)QLW&Z<;]QP''!<<1QRW',<=-QUG'9
M<=IQW''X<?YQ`'('<@AR"7(3<A=R&G(=<A]R)'(K<B]R-'(X<CER07)"<D-R
M17).<D]R4')3<E5R5G):<EQR7G)@<F-R:')K<FYR;W)Q<G=R>')[<GQR?W*$
M<HERC7*.<I-RFW*H<JURKG*Q<K1ROG+!<L=RR7+,<M5RUG+8<M]RY7+S<O1R
M^G+[<@````#:;]YOZ&_I;_!O]6_Y;_QO_6\`<`5P!G`'<`UP%W`@<"-P+W`T
M<#=P.7`\<$-P1'!(<$EP2G!+<%1P57!=<%YP3G!D<&5P;'!N<'5P=G!^<(%P
MA7"&<)1PE7"6<)=PF'";<*1PJW"P<+%PM'"W<,IPT7#3<-1PU7#6<-APW'#D
M</IP`W$$<05Q!G$'<0MQ#'$/<1YQ('$K<2UQ+W$P<3%Q.'%!<45Q1G%'<4IQ
M2W%0<5)Q5W%:<5QQ7G%@<0````!B;F-N:&YS;GMN?6Z-;I-NF6Z@;J=NK6ZN
M;K%NLVZ[;K]NP&[!;L-NQV[(;LINS6[.;L]NZV[M;NYN^6[[;OUN!&\(;PIO
M#&\-;Q9O&&\:;QMO)F\I;RIO+V\P;S-O-F\[;SQO+6]/;U%O4F]3;U=O66]:
M;UUO7F]A;V)O:&]L;WUO?F^#;X=OB&^+;XQOC6^0;Y)ODV^4;Y9OFF^?;Z!O
MI6^F;Z=OJ&^N;Z]OL&^U;[9OO&_%;\=OR&_*;P````#:;-QLX&SG;.ELZVSL
M;.YL\FST;`1M!VT*;0YM#VT1;1-M&FTF;2=M*&UG;"YM+VTQ;3EM/&T_;5=M
M7FU?;6%M96UG;6]M<&U\;8)MAVV1;9)ME&V6;9=MF&VJ;:QMM&VW;;EMO6V_
M;<1MR&W*;<YMSVW6;=MMW6W?;>!MXFWE;>EM[VWP;?1M]FW\;0!N!&X>;B)N
M)VXR;C9N.6X[;CQN1&Y%;DAN26Y+;D]N46Y2;E-N5&Y7;EQN76Y>;@````!^
M:X)KA6N7:YMKGVN@:Z)KHVNH:ZEKK&NM:ZYKL&NX:[EKO6N^:\-KQ&O):\QK
MUFO::^%KXVOF:^=K[FOQ:_=K^6O_:P)L!&P%;`EL#6P.;!!L$FP9;!]L)FPG
M;"AL+&PN;#-L-6PV;#IL.VP_;$IL2VQ-;$]L4FQ4;%EL6VQ<;&ML;6QO;'1L
M=FQX;'EL>VR%;(9LAVR);)1LE6R7;)ALG&R?;+!LLFRT;,)LQFS-;,]LT&S1
M;-)LU&S6;``````T:C=J.VH^:C]J16I&:DEJ2FI.:E!J46I2:E5J5FI;:F1J
M9VIJ:G%J<VI^:H%J@VJ&:H=JB6J+:I%JFVJ=:IYJGVJE:JMJKVJP:K%JM&J]
M:KYJOVK&:LEJR&K,:M!JU&K5:M9JW&K=:N1JYVKL:O!J\6KR:OQJ_6H":P-K
M!FL':PEK#VL0:Q%K%VL;:QYK)&LH:RMK+&LO:S5K-FL[:S]K1FM*:TUK4FM6
M:UAK76M@:V=K:VMN:W!K=6M]:P````#0:-%HTVC6:-EHW&C=:.5HZ&CJ:.MH
M[&CM:/!H\6CU:/9H^VC\:/UH!FD):0II$&D1:1-I%FD7:3%I,VDU:3AI.VE"
M:45I26E.:5=I6VEC:61I96EF:6AI:6EL:7!I<6ER:7II>VE_:8!IC6F2:99I
MF&FA::5IIFFH::MIK6FO:;=IN&FZ:;QIQ6G(:=%IUFG7:>)IY6GN:>]I\6GS
M:?5I_FD`:@%J`VH/:A%J%6H::AUJ(&HD:BAJ,&HR:@````!F9VQG;F=T9W9G
M>V>!9X1GCF>/9Y%GDV>69YAGF6>;9[!GL6>R9[5GNV>\9[UG^6?`9\)GPV?%
M9\AGR6?29]=GV6?<9^%GYF?P9_)G]F?W9U)H%&@9:!UH'V@H:"=H+&@M:"]H
M,&@Q:#-H.V@_:$1H16A*:$QH56A7:%AH6VAK:&YH;VAP:'%H<FAU:'EH>FA[
M:'QH@FB$:(9HB&B6:)AHFFB<:*%HHVBE:*EHJFBN:+)HNVC%:,AHS&C/:```
M```>9B%F(F8C9B1F)F8I9BIF*V8L9BYF,&8Q9C-F.68W9D!F169&9DIF3&91
M9DYF5V989EEF6V9<9F!F86;[9FIF:V9L9GYF<V9U9G]F=V9X9GEF>V:`9GQF
MBV:,9HUFD&:29IEFFF:;9IQFGV:@9J1FK6:Q9K)FM6:[9K]FP&;"9L-FR&;,
M9LYFSV;49MMFWV;H9NMF[&;N9OIF!6<'9PYG$V<99QQG(&<B9S-G/F=%9T=G
M2&=,9U1G56==9P````#$9,EDRF3+9,QDSF309-%DU6379.1DY63I9.ID[63P
M9/5D]V3[9/]D`64$90AE"64*90]E$V44919E&64;91YE'V4B929E*64N93%E
M.F4\93UE0V5'94EE4&52951E7V5@96=E:V5Z97UE@66%98IEDF6599AEG66@
M9:-EIF6N9;)ELV6T9;]EPF7(9<EESF709=1EUF789=]E\&7R9?1E]67Y9?YE
M_V4`9@1F"&8)9@UF$6829A5F%F8=9@````!X8WQC?6-_8X)CA&.'8XICD&.4
M8Y5CF6.:8YYCI&.F8ZUCKF.O8[UCP6/%8\ACSF/18]-CU&/58]QCX&/E8^IC
M[&/R8_-C]6/X8_EC"60*9!!D$F049!AD'F0@9")D)&0E9"ED*F0O9#!D-60]
M9#]D2V1/9%%D4F139%1D6F1;9%QD761?9&!D861C9&UD<V1T9'MD?62%9(=D
MCV209)%DF&299)MDG62?9*%DHV2F9*ADK&2S9+UDOF2_9`````#L8>UA[V$!
M8@-B!&('8A-B%6(<8B!B(F(C8B=B*6(K8CEB/6)"8D-B1&)&8DQB4&)18E)B
M5&)68EIB7&)D8FUB;V)S8GIB?6*-8HYBCV*08J9BJ&*S8K9BMV*Z8KYBOV+$
M8LYBU6+68MIBZF+R8O1B_&+]8@-C!&,*8PMC#6,08Q-C%F,88REC*F,M8S5C
M-F,Y8SQC06-"8T-C1&-&8TIC2V-.8U)C4V-48UAC6V-E8V9C;&-M8W%C=&-U
M8P````"[8+Y@PF#$8,A@R6#*8,M@SF#/8-1@U6#98-M@W6#>8.)@Y6#R8/5@
M^&#\8/U@`F$'80IA#&$081%A$F$3811A%F$781EA'&$>82)A*F$K83!A,6$U
M839A-V$Y84%A16%&84EA7F%@86QA<F%X87MA?&%_88!A@6&#881ABV&-89)A
MDV&789AAG&&=89]AH&&E8:AAJF&M8;AAN6&\8<!AP6'"8<YASV'58=QAW6'>
M8=]AX6'B8>=AZ6'E80````!O7W)?=%]U7WA?>E]]7WY?B5^-7X]?EE^<7YU?
MHE^G7ZM?I%^L7Z]?L%^Q7[A?Q%_'7\A?R5_+7]!?T5_27]-?U%_>7^%?XE_H
M7^E?ZE_L7^U?[E_O7_)?\U_V7_I?_%\'8`I@#6`38!1@%V`88!I@'V`D8"U@
M,V`U8$!@1V!(8$E@3&!18%1@5F!78%U@86!G8'%@?F!_8()@AF"(8(I@CF"1
M8)-@E6"88)U@GF"B8*1@I6"H8+!@L6"W8`````#I7?A=^5T`7@=>#5X27A1>
M%5X87A]>(%XN7BA>,EXU7CY>2UY07DE>45Y67EA>6UY<7EY>:%YJ7FM>;%YM
M7FY><%Z`7HM>CEZB7J1>I5ZH7JI>K%ZQ7K->O5Z^7K]>QE[,7LM>SE[17M)>
MU%[57MQ>WE[E7NM>`E\&7P=?"%\.7QE?'%\=7R%?(E\C7R1?*%\K7RQ?+E\P
M7S1?-E\[7SU?/U]`7T1?15]'7TU?4%]47UA?6U]@7V-?9%]G7P````!M7'!<
M=%QU7'I<>UQ\7'U<AUR(7(I<CUR27)U<GUR@7*)<HURF7*I<LERT7+5<NES)
M7,M<TES=7-=<[ESQ7/)<]%P!709=#5T272M=(UTD729=)UTQ731=.5T]73]=
M0EU#749=2%U575%=65U*75]=8%UA76)=9%UJ76U=<%UY77I=?EU_78%=@UV(
M78I=DEV3791=E5V979M=GUV@7:==JUVP7;1=N%VY7<-=QUW+7=!=SEW87=E=
MX%WD70````#$6L9:R%K/6MI:W%K@6N5:ZEKN6O5:]EK]6@!;`5L(6Q=;-%L9
M6QM;'5LA6R5;+5LX6T%;2UM,6U);5EM>6VA;;EMO6WQ;?5M^6W];@5N$6X9;
MBEN.6Y!;D5N36Y1;EENH6ZE;K%NM6Z];L5NR6[=;NEN\6\!;P5O-6\];UEO7
M6]A;V5O:6^!;[UOQ6_1;_5L,7!=<'EP?7"-<)EPI7"M<+%PN7#!<,EPU7#9<
M65Q:7%Q<8EQC7&=<:%QI7`````!O67)9=5EV67E9>UE\68M9C%F.69)9E5F7
M69]9I%FG6:U9KEFO6;!9LUFW6;I9O%G!6<-9Q%G(6<I9S5G26=U9WEG?6>-9
MY%GG6>Y9[UGQ6?)9]%GW60!:!%H,6@U:#EH26A-:'EHC6B1:)UHH6BI:+5HP
M6D1:15I'6DA:3%I06E5:7EIC6F5:9UIM6G=:>EI[6GY:BUJ06I-:EEJ96IQ:
MGEJ?6J!:HEJG6JQ:L5JR6K-:M5JX6KI:NUJ_6@`````,6`U8&U@>6!]8(%@F
M6"=8+5@R6#E8/UA)6$Q835A/6%!855A?6&%89%AG6&A8>%A\6']8@%B!6(=8
MB%B)6(I8C%B-6(]8D%B46)98G5B@6*%8HEBF6*E8L5BR6,18O%C"6,A8S5C.
M6-!8TEC46-98VEC=6.%8XECI6/-8!5D&60M9#%D261-9%%E!AAU9(5DC6219
M*%DO63!9,UDU6399/UE#64994EE365E96UE=65Y97UEA66-9:UEM60````#V
M5O=6`5<"5P=7"E<,5Q%7%5<:5QM7'5<@5R)7(U<D5R57*5<J5RQ7+E<O5S-7
M-%<]5SY7/U=%5T973%=-5U)78E=E5V=7:%=K5VU7;E=O5W!7<5=S5W17=5=W
M5WE7>E=[5WQ7?E>!5X-7C%>45Y=7F5>:5YQ7G5>>5Y]7H5>55Z=7J%>I5ZQ7
MN%>]5\=7R%?,5\]7U5?=5]Y7Y%?F5^=7Z5?M5_!7]5?V5_A7_5?^5_]7`U@$
M6`A8"5CA5P````#35==5V%7;5=Y5XE7I5?95_U4%5@A6"E8-5@Y6#U805A%6
M$E895BQ6,%8S5C56-U8Y5CM6/%8]5C]60%9!5D-61%9&5DE62U9-5D]65%9>
M5F!6859B5F-69E9I5FU6;U9Q5G)6=5:$5H56B%:+5HQ6E5:95II6G5:>5I]6
MIE:G5JA6J5:K5JQ6K5:Q5K-6MU:^5L56R5;*5LM6SU;05LQ6S5;95MQ6W5;?
M5N%6Y%;E5N96YU;H5O%6ZU;M5@````"!5(-4A52(5(E4C5215)54EE2<5)]4
MH52F5*=4J52J5*U4KE2Q5+=4N52Z5+M4OU3&5,I4S53.5.!4ZE3L5.]4]E3\
M5/Y4_U0`50%5!54(50E5#%4-50Y5%54J52M5,E4U5395.U4\53U5055'54E5
M2E5-55!5455855I56U5>56!5855D5695?U6!58)5AE6(58Y5CU6159)5DU64
M59=5HU6D5:U5LE6_5<%5PU7&5<E5RU7,5<Y5T57250`````,4Q%3$U,84QM3
M'%,>4Q]3)5,G4RA3*5,K4RQ3+5,P4S)3-5,\4SU3/E-"4TQ32U-94UM385-C
M4V53;%-M4W)3>5-^4X-3AU.(4XY3DU.44YE3G5.A4Z13JE.K4Z]3LE.T4[53
MMU.X4[I3O5/`4\53SU/24]-3U5/:4]U3WE/@4^93YU/U4P)4$U0:5"%4)U0H
M5"I4+U0Q5#14-51#5$141U1-5$]47E1B5&149E1G5&E4:U1M5&Y4=%1_5```
M``#(4<]1T5'24=-1U5'84=Y1XE'E4>Y1\E'S4?11]U$!4@)2!5(24A-2%5(6
M4AA2(E(H4C%2,E(U4CQ215))4E525U)84EI27%)?4F!285)F4FY2=U)X4GE2
M@%*"4H52BE*,4I-2E5*64I=2F%*:4IQ2I%*E4J92IU*O4K!2ME*W4KA2NE*[
M4KU2P%+$4L92R%+,4L]2T5+44M92VU+<4N%2Y5+H4NE2ZE+L4O!2\5+T4O92
M]U(`4P-3"E,+4P````"24)-0E%"64)M0G%">4)]0H%"A4*)0JE"O4+!0N5"Z
M4+U0P%##4,10QU#,4,Y0T%#34-10V%#<4-U0WU#B4.10YE#H4.E0[U#Q4/90
M^E#^4`-1!E$'40A1"U$,40U1#E'R4!!1%U$941M1'%$=41Y1(U$G42A1+%$M
M42]1,5$S4311-5$X43E10E%*44]14U%545=16%%?46119E%^48-1A%&+48Y1
MF%&=4:%1HU&M4;A1NE&\4;Y1OU'"40````"%3XE/BD^,3XY/D$^23Y-/E$^7
M3YE/FD^>3Y]/LD^W3[E/NT^\3[U/OD_`3\%/Q4_&3\A/R4_+3\Q/S4_/3])/
MW$_@3^)/\$_R3_Q/_4__3P!0`5`$4`=0"E`,4`Y0$%`34!=0&%`;4!Q0'5`>
M4")0)U`N4#!0,E`S4#500%!!4$)015!&4$I03%!.4%%04E!34%=065!?4&!0
M8E!C4&909U!J4&U0<%!Q4#M0@5"#4(10AE"*4(Y0CU"04``````"3@1.!4X,
M3A).'TXC3B1.*$XK3BY.+TXP3C5.0$Y!3D1.1TY13EI.7$YC3FA.:4YT3G5.
M>4Y_3HU.EDZ73IU.KTZY3L-.T$[:3MM.X$[A3N).Z$[O3O%.\T[U3OU._D[_
M3@!/`D\#3PA/"T\,3Q)/%4\63Q=/&4\N3S%/8$\S3S5/-T\Y3SM//D]`3T)/
M2$])3TM/3$]23U1/5D]83U]/8T]J3VQ/;D]Q3W=/>$]Y3WI/?4]^3X%/@D^$
M3P````#A`.``Y`#B``,!S@$!`04!Y0#C``<!"0$-`><`"P$/`>D`Z`#K`.H`
M&P$7`1,!&0'U`1T!'P$``"$!)0'M`.P`[P#N`-`!```K`2\!*0$U`3<!.@$^
M`3P!1`%(`48!\0#S`/(`]@#T`-(!40%-`?4`50%9`5<!6P%=`6$!7P%E`6,!
M^@#Y`/P`^P!M`=0!<0%K`7,!;P%I`=@!W`':`=8!=0']`/\`=P%Z`7X!?`$`
M``````````````````````#!`,``Q`#"``(!S0$``00!Q0##``8!"`$,`<<`
M"@$.`<D`R`#+`,H`&@$6`1(!&`$``!P!'@$B`2`!)`'-`,P`SP#.`,\!,`$J
M`2X!*`$T`38!.0$]`3L!0P%'`44!T0#3`-(`U@#4`-$!4`%,`=4`5`%8`58!
M6@%<`6`!7@%D`6(!V@#9`-P`VP!L`=,!<`%J`7(!;@%H`=<!VP'9`=4!=`'=
M`'@!=@%Y`7T!>P$```````````````````````#&`!`!```F`0``,@$``$$!
M/P$``$H!V`!2`0``9@'>````````````````````````````````````````
M````Y@`1`?``)P$Q`3,!.`%"`4`!20%+`?@`4P'?`&<!_@!2!%,$5`15!%8$
M5P18!%D$6@1;!%P$7@1?!`($`P0$!`4$!@0'!`@$"00*!`L$#`0.!`\$````
M````````````A@.(`XD#B@.J`P``C`,``(X#JP,``(\#``````````"L`ZT#
MK@.O`\H#D`/,`\(#S0/+`[`#S@.Z`*H`J0"N`"(AI``6(0``````````````
M````````````````````V`+'`K@`V0+=`J\`VP+:`GX`A`.%`P``````````
M``````````"A`*8`OP```````````````````````````-``````````````
M`,$```#<O1@(L;X8"/2;&`A@P1@(@(DC"```````````````````````````
M``````````````````````@````!`````P````D`__^`G1P(H)`C"``@("`@
M("`@("`H*"@H*"`@("`@("`@("`@("`@("`@($@0$!`0$!`0$!`0$!`0$!"$
MA(2$A(2$A(2$$!`0$!`0$(&!@8&!@0$!`0$!`0$!`0$!`0$!`0$!`0$!$!`0
M$!`0@H*"@H*"`@("`@("`@("`@("`@("`@("`@(0$!`0(`,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,`````````````````````````
M`````````````````,\``````````````,$```#<O1@(P;X8"/2;&`BPQ!@(
M@(DC"`````````````````````````````````````````````````@````!
M`````P````D`__^`G1P(H)`C",X``````````````,$```#<O1@(S[X8"/2;
M&`C@Q!@(@(DC"```````````````````````````````````````````````
M``@````!`````P````D`__^`G1P(H)`C",T``````````````,$```#<O1@(
MX+X8"/2;&`A`Q1@(@(DC"```````````````````````````````````````
M``````````@````!`````P````D`__^`G1P(H)`C",P``````````````,$`
M``#<O1@([[X8"/2;&`C@Q1@(@(DC"```````````````````````````````
M``````````````````@````!`````P````D`__^`G1P(H)`C",L`````````
M`````,$```#<O1@(`K\8"/2;&`B`QA@(@(DC"```````````````````````
M``````````````````````````@````!`````P````D`__^`G1P(H)`C",H`
M`````````````,$```#<O1@($;\8"/2;&`A@QQ@(@(DC"```````````````
M``````````````````````````````````@````!`````P````D`__^`G1P(
MH)`C",D``````````````,$```#<O1@('[\8"/2;&`C@QQ@(@(DC"```````
M``````````````````````````````````````````@````!`````P````D`
M__^`G1P(H)`C",@``````````````,$```#<O1@(+[\8"/2;&`B`R!@(@(DC
M"`````````````````````````````````````````````````@````!````
M`P````D`__^`G1P(H)`C",<``````````````,$```#<O1@(/[\8"/2;&`@#
MR1@(@(DC"`````````````````````````````````````````````````@`
M```!`````P````D`__^`G1P(H)`C",8``````````````,$```#<O1@(3[\8
M"/2;&`@@R1@(@(DC"```````````````````````````````````````````
M``````@````!`````P````D`__^`G1P(H)`C",4``````````````,$```#<
MO1@(8+\8"/2;&`C`R1@(@(DC"```````````````````````````````````
M``````````````@````!`````P````D`__^`G1P(H)`C",0`````````````
M`,$```#<O1@(;[\8"/2;&`B@RA@(@(DC"```````````````````````````
M``````````````````````@````!`````P````D`__^`G1P(H)`C",,`````
M`````````,$```#<O1@(@;\8"/2;&`@`RQ@(@(DC"```````````````````
M``````````````````````````````@````!`````P````D`__^`G1P(H)`C
M",(``````````````,$```#<O1@(DK\8"/2;&`B@RQ@(@(DC"```````````
M``````````````````````````````````````@````!`````P````D`__^`
MG1P(H)`C",$``````````````,$```#<O1@(HK\8"/2;&`B`S!@(@(DC"```
M``````````````````````````````````````````````@````!`````P``
M``D`__^`G1P(H)`C",```````````````,$```#<O1@(M+\8"/2;&`CTFQ@(
M@(DC"```````````@)LC"`````"`ER,(``````````````````````@````!
M`````P````D`__^`G1P(H)`C"&09"`@()`@(@"0("$@E"`CD7P@(9!4("```
M``!@70@(L"0("`````````````````````````````````````"0````````
M``````#!````:K48",2_&`CTFQ@(8,$8"```````````````````````````
M```````````````````````````(`````@````(````)`/__P.@<"$"7(PB/
M``````````````#!````:K48"-2_&`CTFQ@(L,08"```````````````````
M```````````````````````````````````(`````@````(````)`/__P.@<
M"$"7(PB.``````````````#!````:K48".*_&`CTFQ@(X,08"```````````
M```````````````````````````````````````````(`````@````(````)
M`/__P.@<"$"7(PB-``````````````#!````:K48"/._&`CTFQ@(0,48"```
M```````````````````````````````````````````````````(`````@``
M``(````)`/__P.@<"$"7(PB,``````````````#!````:K48"`+`&`CTFQ@(
MX,48"``````````````````````````````````````````````````````(
M`````@````(````)`/__P.@<"$"7(PB+``````````````#!````:K48"!7`
M&`CTFQ@(@,88"```````````````````````````````````````````````
M```````(`````@````(````)`/__P.@<"$"7(PB*``````````````#!````
M:K48""3`&`CTFQ@(8,<8"```````````````````````````````````````
M```````````````(`````@````(````)`/__P.@<"$"7(PB)````````````
M``#!````:K48"#+`&`CTFQ@(X,<8"```````````````````````````````
M```````````````````````(`````@````(````)`/__P.@<"$"7(PB(````
M``````````#!````:K48"$+`&`CTFQ@(@,@8"```````````````````````
M```````````````````````````````(`````@````(````)`/__P.@<"$"7
M(PB'``````````````#!````:K48"%+`&`CTFQ@(`\D8"```````````````
M```````````````````````````````````````(`````@````(````)`/__
MP.@<"$"7(PB&``````````````#!````:K48"&+`&`CTFQ@((,D8"```````
M```````````````````````````````````````````````(`````@````(`
M```)`/__P.@<"$"7(PB%``````````````#!````:K48"'/`&`CTFQ@(P,D8
M"``````````````````````````````````````````````````````(````
M`@````(````)`/__P.@<"$"7(PB$``````````````#!````:K48"(+`&`CT
MFQ@(H,H8"```````````````````````````````````````````````````
M```(`````@````(````)`/__P.@<"$"7(PB#``````````````#!````:K48
M")3`&`CTFQ@(`,L8"```````````````````````````````````````````
M```````````(`````@````(````)`/__P.@<"$"7(PB"``````````````#!
M````:K48"*7`&`CTFQ@(H,L8"```````````````````````````````````
M```````````````````(`````@````(````)`/__P.@<"$"7(PB!````````
M``````#!````:K48"+7`&`CTFQ@(@,P8"```````````````````````````
M```````````````````````````(`````@````(````)`/__P.@<"$"7(PB`
M``````````````#!````:K48",?`&`CTFQ@(])L8"````````````````(";
M(P@`````@)<C"``````````````````````(`````@````(````)`/__P.@<
M"$"7(PAD&0@(W"4("%0F"`@<)P@(O-8'"&05"`@`````8%T("(0F"`@`````
M````````````````````````````````@"`E"(`:)0B`%"4(@`PE"(`&)0B`
M`"4(@/HD"(#T)`@`````@.XD"(#H)`B`XB0(@-PD"(#6)`B`T"0(@,HD"(#$
M)`B`OB0(@+@D"("R)`B`K"0(@*@D"("B)`B`G"0(@)8D"("0)`@`````````
M``````"`BB0(@(0D"(!^)`B`="0(@&HD"(!B)`B`7"0(@%(D"(!.)`B`2"0(
M@$(D"(`^)`B`.B0(@#`D"(`J)`@``````````(`D)`B`'B0(@!@D"(`2)`B`
M`B0(@/`C"```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"`ZB,(````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(#F(PB`XB,(@-XC
M"(#:(PB`U",(````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````@,XC"(#((PB`P",(@+HC
M"("H(PB`HB,(@)PC"`0#`P0#`P,#``,#`P,#`P,#`P,#`P(#`P,#`````P,#
M!04$`P4"`P,"`@4#```#`P,#"`D`````````````````````````````````
M`P``````````````````````````````````````````````````````````
M```````````````````````````````````````````````````"`@("`P``
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````,#!`,)`P/!
M^P#_``!1`@````!^`@````#2`@`````/#@````#3`@````#/`@````!W`@``
M``"(`@````")`@````#(`@`````H!``````O`@`````A`@````!=`@````#,
M`@`````I#@`````J#@`````K#@`````L#@`````M#@`````N#@`````O#@``
M```P#@`````Q#@`````R#@`````]`@`````Z`@`````L!``````M!``````N
M!`````!5`@````#'`@`````S#@````!*#@````!@#@````!M#@````"+#@``
M``"Y#@````#!#@````#A#@````#[#@`````0#P`````A#P`````N#P````!;
M#P````!D#P````""#P````"G#P````"T#P````#`#P````#J#P`````"$```
M```?$`````!$$`````!1$`````!:$`````!>$`````!J$`````"*`@````#.
M`@````"+`@`````/`@`````;`@`````,`@`````S#@````!*#@````!@#@``
M``!M#@````"+#@````"Y#@````#!#@````#A#@````#[#@`````0#P`````A
M#P`````N#P````!;#P````!D#P````""#P````"G#P````"T#P````#`#P``
M``#J#P`````"$``````?$`````!$$`````!1$`````!:$`````!>$`````!J
M$`````",`@`````P!`````"-`@`````S!`````":`@````";`@````!F`@``
M``"R`@````"S`@`````W`@`````N`@````"`'@````!2'@````!3'@````!4
M'@````!5'@````!6'@````!U'@````!V'@````!W'@````!C'@`````+#@``
M``!2'@````!3'@````!4'@````!5'@````!6'@````!7'@````!8'@````!9
M'@````!:'@````!;'@````!<'@````!='@````!>'@````!?'@````!@'@``
M``!A'@````!B'@````!C'@````!D'@````!E'@````!F'@````!G'@````!H
M'@````!I'@````!J'@````!K'@````!L'@````!M'@````!N'@````!O'@``
M``!P'@````!Q'@````!R'@````!S'@````!T'@````!U'@````!V'@````!W
M'@````!X'@````!Y'@````!Z'@````!['@````!\'@````!]'@````"!'@``
M``````````````````"]'0````!B'0````!C'0`````"'@````!D'0`````$
M'@`````%'@````!E'0````!F'0````!G'0`````('@`````)'@`````*'@``
M```+'@`````,'@`````-'@````!\'0````!H'0````!I'0````!J'0````"#
M'0````!K'0````!L'0````!M'0````!N'0````!O'0````!P'0````!Q'0``
M``!R'0````!S'0````!T'0````#!^[__``#!^\#_``#!^\'_``"^'0````"_
M'0````#`'0````#!'0````#"'0````##'0````#!^\C_``#!^\G_``#$'0``
M``#%'0````#&'0````#''0````#('0````#)'0````#!^]#_``#!^]'_``#*
M'0````#+'0````#,'0````#-'0````#.'0````#/'0````#!^]C_``#!^]G_
M``#0'0````#1'0````#2'0````#!^]W_``#!^][_``#!^]__```.#@`````0
M#@`````O!``````0`@`````Q!``````1#@`````@#@````#!^^?_``#^!0``
M``"N`P````"P`P````"O`P````"Q`P````"<!@````#'!@````#!^^__``#!
M^_#_``#!^_'_``#!^_+_``#!^_/_``#!^_3_``#!^_7_``#!^_;_``#!^_?_
M``#!^_C_``````````````````````````#%#0````#&#0````#!^_[_``#!
M^___````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#!^Q#^``#!^Q'^``#!^Q+^``#!^Q/^``#!^Q3^``#!^Q7^
M``#!^Q;^``#!^Q?^``#!^QC^``#!^QG^``#!^QK^``#!^QO^``#!^QS^``#!
M^QW^``#!^Q[^``#!^Q_^``````````````````````````````````#!^R3^
M``#!^R7^``#!^R;^``#!^R?^``#!^RC^``#!^RG^``#!^RK^``#!^RO^``#!
M^RS^``#!^RW^``#!^R[^``#!^R_^``!=`ET"```H`@`````G`@`````;`@``
M```;`@````"(`@````")`@````",`@````"-`@````"X`@````"Y`@````"V
M`@````"W`@````"P`@````"Q`@````"N`@````"O`@````"R`@````"S`@``
M``"T`@````"U`@`````X`@`````Y`@````"*`@````"+`@`````1`@`````1
M`@`````1`@`````1`@`````;`@`````;`@`````;`@`````O`@`````W`@``
M``!=`@````#!^U/^```Z`@`````]`@````!5`@````!1`@`````H`@````"(
M`@````")`@````",`@````"-`@````"X`@````"Y`@````#2`@````#/`@``
M``#(`@`````H!``````A`@`````L!``````N!``````M!`````#!^V?^``#.
M`@`````/#@````#3`@````#'`@````#!^VS^``#!^VW^``#!^V[^``#!^V_^
M``````````````````````````````````````````#!^W7^````````````
M````````````````````````````````````````````````````````````
M``````````!'$P````!($P````!($P````!)$P````!)$P````!,$P````!,
M$P````!-$P````!-$P````!/$P````!/$P````!/$P````!/$P````!0$P``
M``!0$P````!2$P````!2$P````!2$P````!2$P````!6$P````!6$P````!7
M$P````!7$P````!7$P````!7$P````!8$P````!8$P````!8$P````!8$P``
M``!>$P````!>$P````!>$P````!>$P````!D$P````!D$P````!D$P````!D
M$P````!E$P````!E$P````!E$P````!E$P````!I$P````!I$P````!J$P``
M``!J$P````!U$P````!U$P````!V$P````!V$P````"!$P````"!$P````"!
M$P````"!$P````""$P````""$P````""$P````""$P````"'$P````"'$P``
M``"'$P````"'$P````"($P````"($P````"($P````"($P````",$P````",
M$P````",$P````",$P````"-$P````"-$P````"-$P````"-$P````"/$P``
M``"/$P````"/$P````"/$P````"0$P````"0$P````"0$P````"0$P````"3
M$P````"3$P````"3$P````"3$P````";$P````";$P````";$P````";$P``
M``">$P````">$P````">$P````">$P````"K$P````"K$P````"K$P````"K
M$P````"P$P````"P$P````"P$P````"P$P````"Q$P````"Q$P````"Q$P``
M``"Q$P````"W$P````"W$P````"W$P````"W$P````"]$P````"]$P````#'
M$P````#'$P````#($P````#($P````#($P````#($P````"K$T@3``"K$T@3
M``"K$TD3``"K$TD3``"K$TT3``"K$TT3``"K$U`3``"K$U`3``#!^_W^``#!
M^_[^``````````!D$\@3``````````````````!>$\<3````````````````
M``!>$\@3``````````````````!E$\<3``````````````````!E$\@3````
M``````````````"'$\<3``````````````````"'$\@3````````````````
M``"($\<3``````````````````"($\@3``````````````````""$UX3````
M``````````````""$V03``````````````````""$V43````````````````
M``""$[`3``````````````````""$W43``````````````````"!$W43````
M``````````````"'$W43``````````````````"($W43````````````````
M``",$\<3``````````````````",$\@3``````````````````"/$\<3````
M``````````````"/$\@3``````````````````"0$\<3````````````````
M``"0$\@3``````````````````"!$\<3``````````````````"!$\@3````
M``````````````""$\<3``````````````````""$\@3````````````````
M``!D$\<3``````````````````!D$\@3``````````````````!>$\<3````
M``````````````!>$\@3``````````````````!E$\<3````````````````
M``!E$\@3``````````````````"'$\<3``````````````````"'$\@3````
M``````````````"($\<3``````````````````"($\@3````````````````
M``""$UX3``````````````````""$V03``````````````````""$V43````
M``````````````""$[`3``````````````````""$W43````````````````
M``"!$W43``````````````````"'$W43``````````````````"($W43````
M``````````````""$UX3``````````````````""$V03````````````````
M``""$V43``````````````````""$[`3``````````````````"!$[<3````
M``````````````""$[<3``````````````````",$[`3````````````````
M``"!$UX3``````````````````"!$V03``````````````````"!$V43````
M``````````````""$UX3``````````````````""$V03````````````````
M``""$V43``````````````````",$[`3``````````````````"-$[`3````
M``````````````!0$P````````````````````!0$P``````````````````
M``#``@````````````````````#!`@````````````````````#!^T#]````
M``````````````#!^T']``````````````````#!^T+]````````````````
M``#!^T/]``````````````````#!^T3]``````````````````#!^T7]````
M``````````````#!^T;]``````````````````#!^T?]````````````````
M``#!^TC]``````````````````#!^TG]``````````````````#!^TK]````
M``````````````#!^TO]``````````````````#!^TS]````````````````
M``#!^TW]``````````````````#!^T[]``````````````````#!^T_]````
M``````````````!7$UX3L!,```````````````!7$V037A,`````````````
M``!7$V037A,```````````````!7$V03L!,```````````````!7$V43L!,`
M``````````````!7$[`37A,```````````````!7$[`39!,`````````````
M``!7$[`391,```````````````!>$[`39!,```````````````!>$[`39!,`
M``````````````!D$[`3R!,```````````````!D$[`3QQ,`````````````
M``"!$V037A,```````````````"!$UX39!,```````````````"!$UX3QQ,`
M``````````````"!$[`39!,```````````````"!$[`39!,`````````````
M``"!$[`37A,```````````````"!$[`3L!,```````````````"!$[`3L!,`
M``````````````"'$V039!,```````````````"'$V039!,`````````````
M``"'$[`3L!,```````````````""$V03L!,```````````````""$V03L!,`
M``````````````""$UX3R!,```````````````""$[`391,`````````````
M``""$[`391,```````````````""$[`3L!,```````````````""$[`3L!,`
M``````````````"($V03QQ,```````````````"($V43L!,`````````````
M``"($V43L!,```````````````",$[`39!,```````````````",$[`39!,`
M``````````````",$[`3L!,```````````````",$[`3R!,`````````````
M``"/$UX3L!,```````````````"/$[`3L!,```````````````"/$[`3L!,`
M``````````````"/$[`3QQ,```````````````"0$[`3L!,`````````````
M``"0$[`3R!,```````````````"0$[`3QQ,```````````````"3$V43L!,`
M``````````````"3$V43L!,```````````````";$[`39!,`````````````
M``";$[`3L!,```````````````"K$V03L!,```````````````"K$V03R!,`
M``````````````"K$V03QQ,```````````````"K$UX37A,`````````````
M``"K$UX37A,```````````````"K$V43L!,```````````````"K$V43L!,`
M``````````````"K$[`39!,```````````````"K$[`39!,`````````````
M``"P$V037A,```````````````"P$V03L!,```````````````"P$V03R!,`
M``````````````"P$UX39!,```````````````"P$UX3L!,`````````````
M``"P$V437A,```````````````"P$V43L!,```````````````#!^Y#]````
M``````````````#!^Y']``````````````````"P$UX391,`````````````
M``"W$[`37A,```````````````"W$[`3L!,```````````````"Q$V03L!,`
M``````````````"Q$V03QQ,```````````````"Q$UX3L!,`````````````
M``"Q$UX3L!,```````````````"Q$UX3QQ,```````````````"Q$[`3R!,`
M``````````````"Q$[`3QQ,```````````````#($[`3L!,`````````````
M``#($[`3L!,```````````````!2$V43R!,```````````````!7$UX3R!,`
M``````````````!7$UX3QQ,```````````````!7$V43R!,`````````````
M``!7$V43QQ,```````````````!7$[`3R!,```````````````!7$[`3QQ,`
M``````````````!>$[`3R!,```````````````!>$V03QQ,`````````````
M``!>$[`3QQ,```````````````"!$V43QQ,```````````````"'$V03R!,`
M``````````````""$V03R!,```````````````"($V03R!,`````````````
M``"K$UX3R!,```````````````"K$[`3R!,```````````````#($V03R!,`
M``````````````#($UX3R!,```````````````#($[`3R!,`````````````
M``"P$[`3R!,```````````````";$[`3R!,```````````````"Q$V03R!,`
M``````````````";$[`39!,```````````````"K$V03L!,`````````````
M``"/$[`3R!,```````````````">$[`3R!,```````````````"Q$UX39!,`
M``````````````"P$V43R!,```````````````"K$UX3L!,`````````````
M``">$[`3L!,```````````````"K$UX3L!,```````````````"Q$UX39!,`
M``````````````!>$V03R!,```````````````!D$UX3R!,`````````````
M``"P$UX3R!,```````````````"3$[`3R!,```````````````!2$V03R!,`
M``````````````">$[`3L!,```````````````"/$UX3L!,`````````````
M``"'$[`3L!,```````````````"!$V43R!,```````````````"Q$UX3R!,`
M``````````````#!^\C]``````````````````#!^\G]````````````````
M``#!^\K]``````````````````#!^\O]``````````````````#!^\S]````
M``````````````#!^\W]``````````````````#!^\[]````````````````
M``#!^\_]``````````````````#!^]#]``````````````````#!^]']````
M``````````````#!^]+]``````````````````#!^]/]````````````````
M``#!^]3]``````````````````#!^]7]``````````````````#!^];]````
M``````````````#!^]?]``````````````````#!^]C]````````````````
M``#!^]G]``````````````````#!^]K]``````````````````#!^]O]````
M``````````````#!^]S]``````````````````#!^]W]````````````````
M``#!^][]``````````````````#!^]_]``````````````````#!^^#]````
M``````````````#!^^']``````````````````#!^^+]````````````````
M``#!^^/]``````````````````#!^^3]``````````````````#!^^7]````
M``````````````#!^^;]``````````````````#!^^?]````````````````
M``#!^^C]``````````````````#!^^G]``````````````````#!^^K]````
M``````````````#!^^O]``````````````````#!^^S]````````````````
M``#!^^W]``````````````````#!^^[]``````````````````#!^^_]````
M``````````````"'$ZL3SA,```````````````";$ZL3SA,`````````````
M``!0$ZL3JQ.W$P````````````!0$YX34A-U$P````````````"P$V03L!-I
M$P````````````"'$ZL3CQ.P$P````````````!U$X$3O1.K$P``````````
M``"/$ZL3R!.W$P````````````"]$X$3JQ.P$P````````````"'$ZL3QQ,`
M``````````````#!^_K]``````````````````!>$ZL3"0)>$ZL34!.K$[<3
M``!U$\D34!.K$P````````````!/`P````````````````````#!^_[]````
M``````````````#!^__]``````````````````!/$UX3``!/$V03``!/$[`3
M``!/$\<3``!/$\@3``!2$UX3``!2$V03``!2$V43``!2$[`3``!2$\<3``!2
M$\@3``!7$UX3``!7$V03``!7$V43``!7$[`3``!7$\<3``!7$\@3``!8$UX3
M``!8$[`3``!8$\<3``!8$\@3``!>$V03``!>$[`3``!D$UX3``!D$[`3``!E
M$UX3``!E$V03``!E$[`3``"!$UX3``"!$V03``"!$V43``"!$[`3``"'$V03
M``"'$[`3``"($UX3``"($V03``"($V43``"($[`3``",$V03``",$[`3``"-
M$[`3``"/$UX3``"/$[`3``"0$UX3``"0$[`3``"3$UX3``"3$V03``"3$V43
M``"3$[`3``"3$\<3``"3$\@3``";$V03``";$[`3``";$\<3``";$\@3``">
M$U`3``">$UX3``">$V03``">$V43``">$ZL3``">$[`3``">$\<3``">$\@3
M``"K$UX3``"K$V03``"K$V43``"K$[`3``"K$\<3``"K$\@3``"P$UX3``"P
M$V03``"P$V43``"P$[`3``"P$\<3``"P$\@3``"Q$UX3``"Q$V03``"Q$V43
M``"Q$[`3``"Q$\<3``"Q$\@3``"W$UX3``"W$[`3``"W$\<3``"W$\@3``#(
M$UX3``#($V03``#($V43``#($[`3``#($\<3``#($\@3``!J$P````!U$P``
M``#'$P````````````````````````````````````````````````````!/
M$W43``!/$W83``!/$[`3``!/$[$3``!/$\<3``!/$\@3``!2$W43``!2$W83
M``!2$[`3``!2$[$3``!2$\<3``!2$\@3``!7$W43``!7$W83``!7$[`3``!7
M$[$3``!7$\<3``!7$\@3``!8$W43``!8$W83``!8$[`3``!8$[$3``!8$\<3
M``!8$\@3``"3$\<3``"3$\@3``";$\<3``";$\@3``">$U`3``">$ZL3``">
M$[`3``">$\<3``">$\@3``"K$[`3``"K$\<3``"K$\@3``"P$U`3``"P$[`3
M``"Q$W43``"Q$W83``"Q$[`3``"Q$[$3``"Q$\<3``"Q$\@3``#'$P````#(
M$W43``#($W83``#($[`3``#($[$3``#($\<3``#($\@3``!/$UX3``!/$V03
M``!/$V43``!/$[`3``!/$[<3``!2$UX3``!2$V03``!2$V43``!2$[`3``!2
M$[<3``!7$UX3``!7$V03``!7$V43``!7$[`3``!7$[<3``!8$[`3``!>$V03
M``!>$[`3``!D$UX3``!D$[`3``!E$UX3``!E$[`3``"!$UX3``"!$V03``"!
M$V43``"!$[`3``"'$V03``"'$V43``"'$[`3``"($UX3``"($V03``"($V43
M``"($[`3``",$V03``"-$[`3``"/$UX3``"/$[`3``"0$UX3``"0$[`3``"3
M$UX3``"3$V03``"3$V43``"3$[`3``";$V03``";$[`3``">$UX3``">$V03
M``">$V43``">$ZL3``">$[`3``"K$UX3``"K$V03``"K$V43``"K$[`3``"K
M$[<3``"P$UX3``"P$V03``"P$V43``"P$[`3``"Q$UX3``"Q$V03``"Q$V43
M``"Q$[`3``"Q$[<3``"W$UX3``"W$[`3``"W$P````#($UX3``#($V03``#(
M$V43``#($[`3``#($[<3``!/$[`3``!/$[<3``!2$[`3``!2$[<3``!7$[`3
M``!7$[<3``!8$[`3``!8$[<3``"!$[`3``"!$[<3``""$[`3``""$[<3``">
M$ZL3``">$[`3``"K$[`3``"Q$[`3``"Q$[<3``#($[`3``#($[<3````````
M``````````````````",$\<3``",$\@3``"/$\<3``"/$\@3``"0$\<3``"0
M$\@3``"!$\<3``"!$\@3``""$\<3``""$\@3``!D$\<3``"Y#KD.`````+D.
M^PX`````N0XN#P````"Y#KD.^PX``+D.N0XN#P``Z@\"$`````#J#P(0````
M`,'[!_L`````P?L(^P````#!^PG[`````,'["OL`````P?L+^P````#!^PS[
M`````,'[#?L`````P?L.^P````#!^P_[`````,'[$/L`````P?L1^P````#!
M^Q+[`````!T3'Q,`````'1,.$P`````=$Q03`````"<3'Q,`````'1,6$P``
M``#!^QC[`````,'[&?L`````P?L:^P````#!^QO[`````,'['/L`````.A,`
M`````````````````#H3.A,`````0!,````````Q$P```````#03````````
M-1,````````[$P```````#P3````````/1,```````!$$P```````$83````
M````*`0```````!%$P```````$43````````11,```````!%$P```````#$3
M````````,1,````````Q$P```````#(3````````,Q,````````T$P``````
M`#43````````-A,````````W$P```````,'[-_L`````.1,````````Z$P``
M`````#L3````````.Q,````````\$P```````,'[/?L`````/1,```````#!
M^S_[`````#X3````````/Q,```````#!^T+[`````$$3````````01,`````
M``#!^T7[`````$(3````````0Q,```````!$$P```````$43````````1A,`
M```````V$P```````#(3````````.Q,```````!!$P```````#$3/!,`````
M2Q,```````!+$P```````%,3````````4Q,```````!3$P```````%,3````
M````5!,```````!4$P```````%03````````5!,```````!5$P```````%43
M````````51,```````!5$P```````%H3````````6A,```````!:$P``````
M`%H3````````71,```````!=$P```````%T3````````71,```````!9$P``
M`````%D3````````61,```````!9$P```````)<3````````EQ,```````"7
M$P```````)<3````````F1,```````"9$P```````)D3````````F1,`````
M``!@$P```````&`3````````8!,```````!@$P```````%\3````````7Q,`
M``````!?$P```````%\3````````81,```````!A$P```````&$3````````
M81,```````!C$P```````&,3````````8Q,```````!C$P```````'`3````
M````<!,```````!O$P```````&\3````````<1,```````!Q$P```````&L3
M````````:Q,```````!^$P```````'X3````````=Q,```````!W$P``````
M`)\3````````GQ,```````"?$P```````)\3````````I1,```````"E$P``
M`````*43````````I1,```````"I$P```````*D3````````J1,```````"I
M$P```````*<3````````IQ,```````"G$P```````*<3````````LA,`````
M``"R$P```````+,3````````LQ,```````"S$P```````+,3````````O!,`
M``````"\$P```````+D3````````N1,```````"Y$P```````+D3````````
MN!,```````"X$P```````+@3````````N!,```````#.$P```````,X3````
M````SA,```````#.$P```````,'[LOL`````P?NS^P````#!^[3[`````,'[
MM?L`````P?NV^P````#!^[?[`````,'[N/L`````P?NY^P````#!^[K[````
M`,'[N_L`````P?N\^P````#!^[W[`````,'[OOL`````P?N_^P````#!^\#[
M`````,'[P?L`````P?O"^P````#!^\/[`````,'[Q/L`````P?O%^P````#!
M^\;[`````,'[Q_L`````P?O(^P````#!^\G[`````,'[ROL`````P?O+^P``
M``#!^\S[`````,'[S?L`````P?O.^P````#!^\_[`````,'[T/L`````P?O1
M^P````#!^]+[`````*,3````````HQ,```````"C$P```````*,3````````
MP1,```````#!$P```````,`3````````P!,```````#"$P```````,(3````
M````P1-'$P````#%$P```````,43````````OQ,```````"_$P```````,,3
M````````PQ,```````#,$P```````,P3````````S!,```````#,$P``````
M`,<3````````QQ,```````!/$U`3`````$\34!,`````3Q.\$P````!/$[P3
M`````$\3O1,`````3Q.]$P````!/$\$3`````$\3P1,`````3Q/`$P````!/
M$\`3`````$\3PA,`````3Q/"$P````!/$\P3`````$\3S!,`````3Q/,$P``
M``!/$\<3`````$\3QQ,`````3Q/'$P````#)$P```````,D3````````R1,`
M``````#)$P```````$#[!](``$#[IMX``$#[T^(``$#[UOP``$#[A=L``$#[
M'NT``$#[M.8``$'[.X\``$'[3(@``$'[398``$'[BXD``$#[T]X``$#[0-$`
M`$#[P-4``$'[#OH``$'[#_H``$#[6M@``$'[$?H``$#[=.8``$'[$_H``$'[
M%/H``$#[WM$``$#[*O,``$#[RO8``$#[//D``$#[7OD``$#[9?D``$#[C_D`
M`$'[5I<``$#[OOP``$#[O?\``$'['_H``$'[$H8``$'[(?H``$'[^(H``$'[
M(_H``$'[)/H``$'[.)```$'[_9```$'[)_H``$'[*/H``$'[*?H``$'[[Y@`
M`$'[_)@``$'[*)D``$'[M)T``,'[+OH``,'[+_H``$#[KL\``$#[Y]```$#[
M3=$``$#[R=(``$#[Y-(``$#[4=,``$#[G=4``$#[!M8``$#[:-8``$#[0-@`
M`$#[J-@``$#[9-P``$#[;MP``$#[E.```$#[:.$``$#[CN$``$#[\N$``$#[
M3^4``$#[XN4``$#[D>8``$#[A>@``$#[=^T``$#[&NX``$#[(N\``$#[;O$`
M`$#[*_(``$#[(O0``$#[D?@``$#[/OD``$#[2?D``$#[2/D``$#[4/D``$#[
M5OD``$#[7?D``$#[C?D``$#[COD``$#[0/H``$#[@?H``$#[P/L``$#[]/T`
M`$#["?X``$#[0?X``$#[<O\``$'[!8```$'[[8$``$'[>8(``$'[>8(``$'[
M5X0``$'[$(D``$'[EHD``$'[`8L``$'[.8L``$'[TXP``$'["(T``$'[MH\`
M`$'[.)```$'[XY8``$'[_Y<``$'[.Y@``,'[:_H``,'[;/H``,'[;?H``,'[
M;OH``,'[;_H``,'[</H``,'[<?H``,'[<OH``,'[<_H``,'[=/H``,'[=?H`
M`,'[=OH``,'[=_H``,'[>/H``,'[>?H``,'[>OH``,'[>_H``,'[?/H``,'[
M??H``,'[?OH``,'[?_H``,'[@/H``,'[@?H``,'[@OH``,'[@_H``,'[A/H`
M`,'[A?H``,'[AOH``,'[A_H``,'[B/H``,'[B?H``,'[BOH``,'[B_H``,'[
MC/H``,'[C?H``,'[COH``,'[C_H``,'[D/H``,'[D?H``,'[DOH``,'[D_H`
M`,'[E/H``,'[E?H``,'[EOH``,'[E_H``,'[F/H``,'[F?H``,'[FOH``,'[
MF_H``,'[G/H``,'[G?H``,'[GOH``,'[G_H``,'[H/H``,'[H?H``,'[HOH`
M`,'[H_H``,'[I/H``,'[I?H``,'[IOH``,'[I_H``,'[J/H``,'[J?H``,'[
MJOH``,'[J_H``,'[K/H``,'[K?H``,'[KOH``,'[K_H``,'[L/H``,'[L?H`
M`,'[LOH``,'[L_H``,'[M/H``,'[M?H``,'[MOH``,'[M_H``,'[N/H``,'[
MN?H``,'[NOH``,'[N_H``,'[O/H``,'[O?H``,'[OOH``,'[O_H``,'[P/H`
M`,'[P?H``,'[POH``,'[P_H``,'[Q/H``,'[Q?H``,'[QOH``,'[Q_H``,'[
MR/H``,'[R?H``,'[ROH``,'[R_H``,'[S/H``,'[S?H``,'[SOH``,'[S_H`
M`,'[T/H``,'[T?H``,'[TOH``,'[T_H``,'[U/H``,'[U?H``,'[UOH``,'[
MU_H``,'[V/H``,'[V?H``,'[VOH``,'[V_H``,'[W/H``,'[W?H``,'[WOH`
M`,'[W_H``,'[X/H``,'[X?H``,'[XOH``,'[X_H``,'[Y/H``,'[Y?H``,'[
MYOH``,'[Y_H``,'[Z/H``,'[Z?H``,'[ZOH``,'[Z_H``,'[[/H``,'[[?H`
M`,'[[OH``,'[[_H``,'[\/H``,'[\?H``,'[\OH``,'[\_H``,'[]/H``,'[
M]?H``,'[]OH``,'[]_H``,'[^/H``,'[^?H``,'[^OH``,'[^_H``,'[_/H`
M`,'[_?H``,'[_OH``,'[__H``$'[2(P``$#[].8``$'[RHX``$'[R(P``$#[
MT>X``$#[,LX``$#[Y=,``$'[G)\``$'[G)\``$#[4=D``$'[T9$``$#[A]4`
M`$#[2-D``$#[]N$``$#[:?8``$#[A?\``$'[/X8``$'[NH<``$'[^(@``$'[
MCY```$#[`NH``$#[&^T``$#[V?```$#[WO,``$'[/80``$'[:I$``$'[\9D`
M`$#[@LX``$#[==,``$#[!.L``$#[&_(``$'[+88``$'['IX``$#[4-T``$#[
MZ^\``$'[S84``$'[9(D``$#[R>(``$'[V($``$'['X@``$#[RMX``$#[%^<`
M`$#[:NT``$#[_/(``$'[SI```$#[AL\``$#[M]$``$#[WM(``$#[Q.0``$#[
MT^H``$#[$/(``$#[Y_8``$'[`8```$'[!H8``$'[7(8``$'[[XT``$'[,I<`
M`$'[;YL``$'[^IT``$#[C/@``$#[?_D``$#[H/T``$'[R8,``$'[!),``$'[
M?YX``$'[UHH``$#[W]@``$#[!-\``$#[8/P``$'[?H```$#[8O(``$#[RO@`
M`$'[PHP``$'[]Y8``$#[V-@``$#[8MP``$#[$^H``$#[VNT``$#[#^\``$#[
M+_T``$#[-_X``$'[2Y8``$#[TM(``$'[BX```$#[W-$``$#[S-$``$#['/H`
M`$#[OOT``$'[\8,``$'[=98``$'[@(L``$#[S^(``$#[`NH``$'[_HH``$#[
M.<X``$#[Y]L``$#[$N```$#[A_,``$#[</4``$#[%],``$#[^_@``$#[O\\`
M`$#[J=\``$#[#<X``$#[S.P``$#[>.4``$#[(OT``$#[P],``$#[7M@``$#[
M`?<``$'[280``$'[JHH``$#[NNL``$'[L(\``$#[B.P``$#[_N(``$'[Y8(`
M`$#[H.,``$#[9?4``$#[KLX``$#[:=$``$#[R=$``$#[@>@``$#[Y_P``$'[
M;X(``$'[THH``$'[SY$``$#[]=(``$#[0M0``$#[<]D``$#[[-X``$#[Q>4`
M`$#[_N\``$#[*OD``$'[K94``$'[:IH``$'[EYX``$'[SIX``$#[F](``$#[
MQN8``$#[=^L``$'[8H\``$#[=-X``$#[D.$``$#[`.(``$#[FN0``$#[(^\`
M`$#[2?$``$#[B?0``$#[ROD``$#[]/T``$'[;X```$'[)H\``$'[[H0``$'[
M(Y```$'[2I,``$#[%](``$#[H](``$#[O=0``$#[R/```$'[PH@``$'[JHH`
M`$#[R=X``$#[]=\``$#[>^,``$#[KNL``$#[/OP``$#[=?,``$#[Y,X``$#[
M^=8``$#[Y]L``$#[NMT``$#['.```$#[LO,``$#[:?0``$#[FO\``$'[1H``
M`$'[-)(``$'[]I8``$'[2)<``$'[&)@``$#[B\\``$#[KOD``$'[M)$``$'[
MN)8``$#[X>```$#[ALX``$#[VM```$#[[ML``$#[/]P``$#[F>4``$#[`NH`
M`$#[SO$``$#[0O8``$'[_(0``$'[?)```$'[C9\``$#[B.8``$'[+I8``$#[
MB=(``$#[>^<``$#[\^<``$#[0>T``$#[G.X``$#["?0``$#[6?4``$#[:_@`
M`$#[$/T``$'[7I@``$#[;=$``$#[+N(``$'[>)8``$#[*]```$#[&=T``$#[
MZNT``$'[*H\``$#[B]\``$#[1.$``$#[%^@``$#[A_,``$'[AI8``$#[*=(`
M`$#[#]0``$#[9=P``$#[$^8``$#[3N<``$#[J.@``$#[Y>P``$#[!O0``$#[
MXO4``$#[>?\``$'[SX@``$'[X8@``$'[S)$``$'[XI8``$#[/],``$#[NNX`
M`$#['=0``$#[T/$``$#[F/0``$'[^H4``$'[HY8``$'[5YP``$'[GYX``$#[
ME^<``$#[R^T``$'[Z($``$#[R_H``$#[(/L``$#[DOP``$#[P/(``$#[F?``
M`$'[6(L``$#[P,X``$'[-H,``$#[.M(``+$B`````+(B`````+,B`````+0B
M`````+4B`````+8B`````+<B`````+@B`````+DB`````+HB`````+LB````
M`+PB`````+TB`````+XB`````+\B`````,`B`````,$B`````,(B`````,,B
M`````,0B`````,4B`````,8B`````,<B`````,@B`````,DB`````,HB````
M`,LB`````,PB`````,TB`````,XB`````,\B`````-`B`````-$B`````-(B
M`````-,B`````-0B`````-4B`````-8B`````-<B`````-@B`````-DB````
M`-HB`````-LB`````-PB`````-TB`````-XB`````-\B`````.`B`````.$B
M`````.(B`````.,B`````.0B`````.4B`````.8B`````.<B`````.@B````
M`.DB`````.HB`````.LB`````.PB`````.TB`````.XB`````.\B`````/`B
M`````/$B`````/(B`````/,B`````/0B`````/4B`````/8B`````/<B````
M`/@B`````/DB`````/HB`````/LB`````/PB`````/TB`````/XB`````/\B
M```````C``````$C``````(C``````,C``````0C``````4C``````8C````
M``<C``````@C``````DC``````HC``````LC``````PC``````TC``````XC
M``````\C`````!`C`````!$C`````!(C`````!,C`````!0C`````!4C````
M`!8C`````!<C`````!@C`````!DC`````!HC`````!LC`````!PC`````!TC
M`````!XC`````!\C`````"`C`````"$C`````"(C`````",C`````"0C````
M`"4C`````"8C`````"<C`````"@C`````"DC`````"HC`````"LC`````"PC
M`````"TC`````"XC`````"\C`````#`C`````#$C`````#(C`````#,C````
M`#0C`````#4C`````#8C`````#<C`````#@C`````#DC`````#HC`````#LC
M`````#PC`````#TC`````,'[C:0``,'[CJ0``,'[CZ0``,X+`````,\+````
M`-`+`````-$+`````-(+`````-,+`````-0+`````-4+`````-8+`````-<+
M`````-@+`````-D+`````-H+`````-L+`````-P+`````-T+`````-X+````
M`-\+`````.`+`````.$+`````.(+`````.,+`````.0+`````.4+`````.8+
M`````.<+`````.@+`````.D+`````.H+`````.L+`````.P+`````.T+````
M`.X+`````.\+`````/`+`````/$+`````/(+`````/,+`````/0+`````/4+
M`````/8+`````/<+`````/@+`````/D+`````/H+`````/L+`````/P+````
M`/T+`````/X+`````/\+```````,``````$,``````(,``````,,``````0,
M`````,'[QZ0``,'[R*0``,'[R:0``,'[RJ0``,'[RZ0``,'[S*0``,'[S:0`
M`,'[SJ0``,'[SZ0``,'[T*0``,'[T:0``,'[TJ0``,'[TZ0``,'[U*0``,'[
MU:0``,'[UJ0``,'[UZ0``,'[V*0``,'[V:0``,'[VJ0``,'[VZ0``,'[W*0`
M`,'[W:0``,'[WJ0``,'[WZ0``,'[X*0``,'[X:0``,'[XJ0``,'[XZ0``,'[
MY*0``,'[Y:0``,'[YJ0``,'[YZ0``,'[Z*0``,'[Z:0``,'[ZJ0``,'[ZZ0`
M`,'[[*0``,'[[:0``,'[[J0``,'[[Z0``,'[\*0``,'[\:0``,'[\J0``,'[
M\Z0``,'[]*0``,'[]:0``,'[]J0``,'[]Z0``,'[^*0``,'[^:0``,'[^J0`
M`,'[^Z0``,'[_*0``,'[_:0``,'[_J0``,'[_Z0``+$A``"R(0``LR$``+0A
M``"U(0``MB$``+<A``"X(0``N2$``+HA``"[(0``O"$``+TA``"^(0``OR$`
M`,`A``#!(0``PB$``,,A``#$(0``Q2$``,8A``#'(0``R"$``,DA``#*(0``
MRR$``,PA``#-(0``SB$``,\A``#0(0``T2$``-(A``#3(0``U"$``-4A``#6
M(0``UR$``-@A``#9(0``VB$``-LA``#<(0``W2$``-XA``#?(0``X"$``.$A
M``#B(0``XR$``.0A``#E(0``YB$``.<A``#H(0``Z2$``.HA``#K(0``["$`
M`.TA``#N(0``[R$``/`A``#Q(0``\B$``/,A``#T(0``]2$``/8A``#W(0``
M^"$``/DA``#Z(0``^R$``/PA``#](0``_B$``/\A````(@```2(```(B```#
M(@``!"(```4B```&(@``!R(```@B```)(@``"B(```LB```,(@``#2(```XB
M```/(@``$"(``!$B```2(@``$R(``!0B```5(@``%B(``!<B```8(@``&2(`
M`!HB```;(@``'"(``!TB```>(@``'R(``"`B```A(@``(B(``",B```D(@``
M)2(``"8B```G(@``*"(``"DB```J(@``*R(``"PB```M(@``+B(``"\B```P
M(@``,2(``#(B```S(@``-"(``#4B```V(@``-R(``#@B```Y(@``.B(``#LB
M```\(@``/2(``#XB```_(@``0"(``$$B``!"(@``0R(``$0B``!%(@``1B(`
M`$<B``!((@``22(``$HB``!+(@``3"(``$TB``!.(@``3R(``%`B``!1(@``
M4B(``%,B``!4(@``52(``%8B``!7(@``6"(``%DB``!:(@``6R(``%PB``!=
M(@``7B(``%\B``!@(@``82(``&(B``!C(@``9"(``&4B``!F(@``9R(``&@B
M``!I(@``:B(``&LB``!L(@``;2(``&XB``!O(@``<"(``'$B``!R(@``<R(`
M`'0B``!U(@``=B(``'<B``!X(@``>2(``'HB``![(@``?"(``'TB``!^(@``
M?R(``(`B``"!(@``@B(``(,B``"$(@``A2(``(8B``"'(@``B"(``(DB``"*
M(@``BR(``(PB``"-(@``CB(``(\B``"0(@``D2(``)(B``"3(@``E"(``)4B
M``"6(@``ER(``)@B``"9(@``FB(``)LB``"<(@``G2(``)XB``"?(@``H"(`
M`*$B``"B(@``HR(``*0B``"E(@``IB(``*<B``"H(@``J2(``*HB``"K(@``
MK"(``*TB``"N(@``KR(``+`B``"Q(```LB```+,@``"T(```M2```+8@``"W
M(```N"```+D@``"Z(```NR```+P@``"](```OB```+\@``#`(```P2```,(@
M``##(```Q"```,4@``#&(```QR```,@@``#)(```RB```,L@``#,(```S2``
M`,X@``#/(```T"```-$@``#2(```TR```-0@``#5(```UB```-<@``#8(```
MV2```-H@``#;(```W"```-T@``#>(```WR```.`@``#A(```XB```.,@``#D
M(```Y2```.8@``#G(```Z"```.D@``#J(```ZR```.P@``#M(```[B```.\@
M``#P(```\2```/(@``#S(```]"```/4@``#V(```]R```/@@``#Y(```^B``
M`/L@``#\(```_2```/X@``#_(````"$```$A```"(0```R$```0A```%(0``
M!B$```<A```((0``"2$```HA```+(0``#"$```TA```.(0``#R$``!`A```1
M(0``$B$``!,A```4(0``%2$``!8A```7(0``&"$``!DA```:(0``&R$``!PA
M```=(0``'B$``!\A```@(0``(2$``"(A```C(0``)"$``"4A```F(0``)R$`
M`"@A```I(0``*B$``"LA```L(0``+2$``"XA```O(0``,"$``#$A```R(0``
M,R$``#0A```U(0``-B$``#<A```X(0``.2$``#HA```[(0``/"$``#TA```^
M(0``/R$``$`A``!!(0``0B$``$,A``!$(0``12$``$8A``!'(0``2"$``$DA
M``!*(0``2R$``$PA``!-(0``3B$``$\A``!0(0``42$``%(A``!3(0``5"$`
M`%4A``!6(0``5R$``%@A``!9(0``6B$``%LA``!<(0``72$``%XA``!?(0``
M8"$``&$A``!B(0``8R$``&0A``!E(0``9B$``&<A``!H(0``:2$``&HA``!K
M(0``;"$``&TA``!N(0``;R$``'`A``!Q(0``<B$``',A``!T(0``=2$``'8A
M``!W(0``>"$``'DA``!Z(0``>R$``'PA``!](0``?B$``'\A``"`(0``@2$`
M`((A``"#(0``A"$``(4A``"&(0``AR$``(@A``")(0``BB$``(LA``",(0``
MC2$``(XA``"/(0``D"$``)$A``"2(0``DR$``)0A``"5(0``EB$``)<A``"8
M(0``F2$``)HA``";(0``G"$``)TA``">(0``GR$``*`A``"A(0``HB$``*,A
M``"D(0``I2$``*8A``"G(0``J"$``*DA``"J(0``JR$``*PA``"M(0``KB$`
M`*\A``"P(0``L1\``+(?``"S'P``M!\``+4?``"V'P``MQ\``+@?``"Y'P``
MNA\``+L?``"\'P``O1\``+X?``"_'P``P!\``,$?``#"'P``PQ\``,0?``#%
M'P``QA\``,<?``#('P``R1\``,H?``#+'P``S!\``,T?``#.'P``SQ\``-`?
M``#1'P``TA\``-,?``#4'P``U1\``-8?``#7'P``V!\``-D?``#:'P``VQ\`
M`-P?``#='P``WA\``-\?``#@'P``X1\``.(?``#C'P``Y!\``.4?``#F'P``
MYQ\``.@?``#I'P``ZA\``.L?``#L'P``[1\``.X?``#O'P``\!\``/$?``#R
M'P``\Q\``/0?``#U'P``]A\``/<?``#X'P``^1\``/H?``#['P``_!\``/T?
M``#^'P``_Q\````@```!(````B````,@```$(```!2````8@```'(```""``
M``D@```*(```"R````P@```-(```#B````\@```0(```$2```!(@```3(```
M%"```!4@```6(```%R```!@@```9(```&B```!L@```<(```'2```!X@```?
M(```("```"$@```B(```(R```"0@```E(```)B```"<@```H(```*2```"H@
M```K(```+"```"T@```N(```+R```#`@```Q(```,B```#,@```T(```-2``
M`#8@```W(```."```#D@```Z(```.R```#P@```](```/B```#\@``!`(```
M02```$(@``!#(```1"```$4@``!&(```1R```$@@``!)(```2B```$L@``!,
M(```32```$X@``!/(```4"```%$@``!2(```4R```%0@``!5(```5B```%<@
M``!8(```62```%H@``!;(```7"```%T@``!>(```7R```&`@``!A(```8B``
M`&,@``!D(```92```&8@``!G(```:"```&D@``!J(```:R```&P@``!M(```
M;B```&\@``!P(```<2```'(@``!S(```="```'4@``!V(```=R```'@@``!Y
M(```>B```'L@``!\(```?2```'X@``!_(```@"```($@``""(```@R```(0@
M``"%(```AB```(<@``"((```B2```(H@``"+(```C"```(T@``".(```CR``
M`)`@``"1(```DB```),@``"4(```E2```)8@``"7(```F"```)D@``":(```
MFR```)P@``"=(```GB```)\@``"@(```H2```*(@``"C(```I"```*4@``"F
M(```IR```*@@``"I(```JB```*L@``"L(```K2```*X@``"O(```L"```+$>
M``"R'@``LQX``+0>``"U'@``MAX``+<>``"X'@``N1X``+H>``"['@``O!X`
M`+T>``"^'@``OQX``,`>``#!'@``PAX``,,>``#$'@``Q1X``,8>``#''@``
MR!X``,D>``#*'@``RQX``,P>``#-'@``SAX``,\>``#0'@``T1X``-(>``#3
M'@``U!X``-4>``#6'@``UQX``-@>``#9'@``VAX``-L>``#<'@``W1X``-X>
M``#?'@``X!X``.$>``#B'@``XQX``.0>``#E'@``YAX``.<>``#H'@``Z1X`
M`.H>``#K'@``[!X``.T>``#N'@``[QX``/`>``#Q'@``\AX``/,>``#T'@``
M]1X``/8>``#W'@``^!X``/D>``#Z'@``^QX``/P>``#]'@``_AX``/\>````
M'P```1\```(?```#'P``!!\```4?```&'P``!Q\```@?```)'P``"A\```L?
M```,'P``#1\```X?```/'P``$!\``!$?```2'P``$Q\``!0?```5'P``%A\`
M`!<?```8'P``&1\``!H?```;'P``'!\``!T?```>'P``'Q\``"`?```A'P``
M(A\``",?```D'P``)1\``"8?```G'P``*!\``"D?```J'P``*Q\``"P?```M
M'P``+A\``"\?```P'P``,1\``#(?```S'P``-!\``#4?```V'P``-Q\``#@?
M```Y'P``.A\``#L?```\'P``/1\``#X?```_'P``0!\``$$?``!"'P``0Q\`
M`$0?``!%'P``1A\``$<?``!('P``21\``$H?``!+'P``3!\``$T?``!.'P``
M3Q\``%`?``!1'P``4A\``%,?``!4'P``51\``%8?``!7'P``6!\``%D?``!:
M'P``6Q\``%P?``!='P``7A\``%\?``!@'P``81\``&(?``!C'P``9!\``&4?
M``!F'P``9Q\``&@?``!I'P``:A\``&L?``!L'P``;1\``&X?``!O'P``<!\`
M`'$?``!R'P``<Q\``'0?``!U'P``=A\``'<?``!X'P``>1\``'H?``!['P``
M?!\``'T?``!^'P``?Q\``(`?``"!'P``@A\``(,?``"$'P``A1\``(8?``"'
M'P``B!\``(D?``"*'P``BQ\``(P?``"-'P``CA\``(\?``"0'P``D1\``)(?
M``"3'P``E!\``)4?``"6'P``EQ\``)@?``"9'P``FA\``)L?``"<'P``G1\`
M`)X?``"?'P``H!\``*$?``"B'P``HQ\``*0?``"E'P``IA\``*<?``"H'P``
MJ1\``*H?``"K'P``K!\``*T?``"N'P``KQ\``+`?``"`^P#-``"`^P'-``"`
M^P+-``"`^P/-``"`^P3-``"`^P7-``"`^P;-``"`^P?-``"`^PC-``"`^PG-
M``"`^PK-``"`^PO-``"`^PS-``"`^PW-``"`^P[-``"`^P_-``"`^Q#-``"`
M^Q'-``"`^Q+-``"`^Q/-``"`^Q3-``"`^Q7-``"`^Q;-``"`^Q?-``"`^QC-
M``"`^QG-``"`^QK-``"`^QO-``"`^QS-``"`^QW-``"`^Q[-``"`^Q_-``"`
M^R#-``"`^R'-``"`^R+-``"`^R/-``"`^R3-``"`^R7-``"`^R;-``"`^R?-
M``"`^RC-``"`^RG-``"`^RK-``"`^RO-``"`^RS-``"`^RW-``"`^R[-``"`
M^R_-``"`^S#-``"`^S'-``"`^S+-``"`^S/-``"`^S3-``"`^S7-``"`^S;-
M``"`^S?-``"`^SC-``"`^SG-``"`^SK-``"`^SO-``"`^SS-``"`^SW-``"`
M^S[-``"`^S_-``"`^T#-``"`^T'-``"`^T+-``"`^T/-``"`^T3-``"`^T7-
M``"`^T;-``"`^T?-``"`^TC-``"`^TG-``"`^TK-``"`^TO-``"`^TS-``"`
M^TW-``"`^T[-``"`^T_-``"`^U#-``"`^U'-``"`^U+-``"`^U/-``"`^U3-
M``"`^U7-``"`^U;-``"`^U?-``"`^UC-``"`^UG-``"`^UK-``"`^UO-``"`
M^US-``"`^UW-``"`^U[-``"`^U_-``"`^V#-``"`^V'-``"`^V+-``"`^V/-
M``"`^V3-``"`^V7-``"`^V;-``"`^V?-``"`^VC-``"`^VG-``"`^VK-``"`
M^VO-``"`^VS-``"`^VW-``"`^V[-``"`^V_-``"`^W#-``"`^W'-``"`^W+-
M``"`^W/-``"`^W3-``"`^W7-``"`^W;-``"`^W?-``"`^WC-``"`^WG-``"`
M^WK-``"`^WO-``"`^WS-``"`^WW-``"`^W[-``"`^W_-``"`^X#-``"`^X'-
M``"`^X+-``"`^X/-``"`^X3-``"`^X7-``"`^X;-``"`^X?-``"`^XC-``"`
M^XG-``"`^XK-``"`^XO-``"`^XS-``"`^XW-``"`^X[-``"`^X_-``"`^Y#-
M``"`^Y'-``"`^Y+-``"`^Y/-``"`^Y3-``"`^Y7-``"`^Y;-``"`^Y?-``"`
M^YC-``"`^YG-``"`^YK-``"`^YO-``"`^YS-``"`^YW-``"`^Y[-``"`^Y_-
M``"`^Z#-``"`^Z'-``"`^Z+-``"`^Z/-``"`^Z3-``"`^Z7-``"`^Z;-``"`
M^Z?-``"`^ZC-``"`^ZG-``"`^ZK-``"`^ZO-``"`^ZS-``"`^ZW-``"`^Z[-
M``"`^Z_-``"`^[#-``"`^['-``"`^[+-``"`^[/-``"`^[3-``"`^[7-``#`
M^[;-``#`^[?-``#`^[C-``#`^[G-``#`^[K-``#`^[O-``#`^[S-``#`^[W-
M``#`^[[-``#`^[_-```W"P`````X"P`````Y"P`````Z"P`````["P`````\
M"P`````]"P`````^"P`````_"P````!`"P````!!"P````!""P````!#"P``
M``!$"P````!%"P````!&"P````!'"P````!("P````!)"P````!*"P````!+
M"P````!,"P````!-"P````!."P````!/"P````!0"P````!1"P````!2"P``
M``!3"P````!4"P````!5"P````!6"P````!7"P````!8"P````!9"P````!:
M"P````!;"P````!<"P````!="P````!>"P````!?"P````!@"P````!A"P``
M``!B"P````!C"P````!D"P````!E"P````!F"P````!G"P````!H"P````!I
M"P````!J"P````!K"P````!L"P````!M"P````!N"P````!O"P````!P"P``
M``!Q"P````!R"P````!S"P````!T"P````!U"P````!V"P````!2'FL>"PYE
M'@````````````!2'GH>;1Y2'@````````````!2'H$>;AY2'@``````````
M``!2'@L.>AX```````````````!3'F<>@1Y9'@````````````!3'H$>8AX`
M``````````````!4'E8>@1X```````````````!5'EX>61X+#F4>````````
M``!5'@L.5QX+#@````````````!6'H$>7AX```````````````!6'@L.<AX`
M``````````````!7'E,>>1X```````````````!7'G@>8QYE'@``````````
M``!7'GP>>1X+#@````````````!7'GP>@1X```````````````!7'H$><!X`
M``````````````!8'E<>``````````````````!8'F<>"PX`````````````
M``!8'G8>>1X+#@````````````!8'GH>81X+#@````````````!8'GP>````
M``````````````!8'GP>61YX'G(>``````````!8'GP><QX+#F4>>AX`````
M``!8'GP>?1YC'F4>``````````!9'G@><AX```````````````!9'G@><AYE
M'H$>``````````!9'GH>7QY3'GP>``````````!9'GP>"PYI'@``````````
M``!:'@L.7AX```````````````!;'GH>9AX```````````````!;'@L.;QX`
M``````````````!<'E,>61YZ'@````````````!<'H$>8AX+#G(>````````
M``!='GD>@1Y9'@````````````!?'H$>8AX```````````````!?'H$>91X`
M``````````````!A'@L.7AX```````````````!D'ET>````````````````
M``!E'GH>``````````````````!E'H$>``````````````````!F'FH>````
M``````````````!J'F,>91X```````````````!K'E,>8QX`````````````
M``!K'@L.7QZ!'F4>``````````!K'@L.8QX```````````````!K'@L.>QYZ
M'@````````````!L'E(>7AYE'GH>``````````!L'ED>>AX`````````````
M``!L'EL>``````````````````!L'GH>``````````````````!M'E(>>!YC
M'F4>``````````!M'E,>"PYE'@````````````!M'F,>71Y5'GH>````````
M``!M'G@>@1X```````````````!N'ED>81X+#GH>``````````!N'F`>````
M``````````````!N'F<>;!X```````````````!N'GH>8QX`````````````
M``!N'H$>7AX```````````````!N'@L.71X```````````````!N'@L.81X`
M``````````````!O'E,>@1YE'@````````````!O'GH>91X`````````````
M``!O'H$>``````````````````!O'H$>91X```````````````!O'@L.>AX`
M``````````````!O'@L.@1X```````````````!P'E,>61Y\'@``````````
M``!P'E,>>AX```````````````!P'F,>:QX```````````````!P'GH>61X`
M``````````````!P'H$>71YW'H$>``````````!Q'ED>?!Z!'@``````````
M``!Q'GD>``````````````````!Q'GD>:QX+#GH>``````````!S'E<>````
M``````````````!S'E<>91Z!'@````````````!S'@L.91YZ'@``````````
M``!U'@L.91X```````````````!U'@L.>AX```````````````!V'E(>@1X`
M``````````````!Y'F,>91YZ'@````````````!Y'G@>````````````````
M``!Z'FP>"PX```````````````!Z'@L.;1YZ'@````````````!['G(>````
M``````````````!['H$>91Y:'H$>``````````!]'F,>91X`````````````
M```I#D#[N?`````````````````J#D#[N?`````````````````K#D#[N?``
M```````````````L#D#[N?`````````````````M#D#[N?``````````````
M```N#D#[N?`````````````````O#D#[N?`````````````````P#D#[N?``
M```````````````Q#D#[N?`````````````````R#D#[N?``````````````
M```J#BD.0/NY\``````````````J#BH.0/NY\``````````````J#BL.0/NY
M\``````````````J#BP.0/NY\``````````````J#BT.0/NY\```````````
M```J#BX.0/NY\``````````````J#B\.0/NY\``````````````J#C`.0/NY
M\``````````````J#C$.0/NY\``````````````J#C(.0/NY\```````````
M```K#BD.0/NY\``````````````K#BH.0/NY\``````````````K#BL.0/NY
M\``````````````K#BP.0/NY\``````````````K#BT.0/NY\```````````
M``#A#J</,PX```````````````!M#C,.```````````````````S#A\0````
M``````````````!*#C,.P`\```````````````""#T00````````````````
M``"G#V`.``````````````````!M#EL/``````````````````!M#EL/*PX`
M``````````````!M#EL/+`X```````````````#[#A\0````````````````
M``!`^W/>0/L0X@````````````!`^RWF0/N,U`````````````!`^R?90/MC
MZP````````````!`^P[F0/N[[`````````````!`^RKH0/L/WT#[&L]`^S[Y
M``"G#S,.``````````````````!D#S,.``````````````````#X$#,.````
M``````````````!;#S,.```````````````````A#S,.````````````````
M```A#TH.``````````````````!;#TH.``````````````````#!#DH.````
M``````````````!@#C,.+@\````````````````A#V`.,PXN#P``````````
M``"G#[D.``````````````````!D#[D.``````````````````#X$+D.````
M``````````````#X$,$.``````````````````!;#\$.````````````````
M```A#\$.``````````````````#A#FH0```````````````````A#^$.:A``
M``````````````!;#^$.:A````````````````#!#N$.:A``````````````
M```"$.$.:A````````````````#X$"X/``````````````````!;#RX/````
M``````````````!M#BX/```````````````````A#RX/````````````````
M``"Y#EL/``````````````````!D#UL/``````````````````#X$%L/````
M``````````````!;#UL/``````````````````!@#EL/````````````````
M```A#UL/``````````````````!;#UL/*PX```````````````!@#EL/*PX`
M``````````````!;#RL.```````````````````A#UL/*PX`````````````
M``!;#UL/+`X```````````````!@#EL/+`X```````````````!;#RP.````
M```````````````A#UL/+`X```````````````!;#S<$Z@\`````````````
M``!;#S<$Z@\K#@````````````"G#S,.```````````````````A#Z</,PX`
M``````````````!;#Z</,PX```````````````#!#J</,PX`````````````
M``#`#S,.;0X```````````````#`#S,.;0XW!.H/``````````#`#S,.;0XW
M!.H/*PX```````"G#^H/``````````````````!D#^H/````````````````
M``#X$.H/``````````````````!;#^H/``````````````````"G#T00````
M``````````````!D#T00``````````````````#X$$00````````````````
M``!;#T00```````````````````A#T00``````````````````!;#T00````
M``````````````"G#U$0``````````````````!D#U$0````````````````
M``#X$%$0``````````````````!;#U$0```````````````````A#U$0````
M``````````````!;#U$0```````````````````A#PD1````````````````
M``!;#PD1```````````````````S#ET"6P]=`@````````````!*#K0/````
M``````````````!@#F`.``````````````````!@#FT.````````````````
M``!@#C<$(0_!#@````````````!@#H(/70(```````````````!M#DH.````
M``````````````#!#EX0``````````````````#A#C,.````````````````
M``#A#J</``````````````````#[#F0/```````````````````A#R$/````
M```````````````A#UL/```````````````````A#P(0````````````````
M```N#UL/```````````````````N#V0/```````````````````N#X(/P0X`
M```````````````N#UH0``````````````````!;#TH.````````````````
M``!;#_L.+@\```````````````!;#X(/+@\```````````````"G#^$.````
M``````````````"G#UT"6P]=`@````````````"G#Z</6P\`````````````
M``"G#\`/``````````````````#J#\`/``````````````````#J#T00````
M``````````````!1$$H.``````````````````!$$#<$6P\`````````````
M```S#C<$6P\````````````````J#D#[Y>4````````````````K#D#[Y>4`
M```````````````L#D#[Y>4````````````````M#D#[Y>4`````````````
M```N#D#[Y>4````````````````O#D#[Y>4````````````````P#D#[Y>4`
M```````````````Q#D#[Y>4````````````````R#D#[Y>4`````````````
M```J#BD.0/OEY0`````````````J#BH.0/OEY0`````````````J#BL.0/OE
MY0`````````````J#BP.0/OEY0`````````````J#BT.0/OEY0``````````
M```J#BX.0/OEY0`````````````J#B\.0/OEY0`````````````J#C`.0/OE
MY0`````````````J#C$.0/OEY0`````````````J#C(.0/OEY0``````````
M```K#BD.0/OEY0`````````````K#BH.0/OEY0`````````````K#BL.0/OE
MY0`````````````K#BP.0/OEY0`````````````K#BT.0/OEY0``````````
M```K#BX.0/OEY0`````````````K#B\.0/OEY0`````````````K#C`.0/OE
MY0`````````````K#C$.0/OEY0`````````````K#C(.0/OEY0``````````
M```L#BD.0/OEY0`````````````L#BH.0/OEY0````````````#!#C,.+@\`
M``````````````"(`F(=B0(`````````````B`)D'8D"`````````````(@"
M91V)`@````````````"(`F<=B0(`````````````B`)H'8D"````````````
M`(@":1V)`@````````````"(`FL=B0(`````````````B`)M'8D"````````
M`````(@";AV)`@````````````"(`G`=B0(`````````````B`)Q'8D"````
M`````````(@"<AV)`@````````````"(`G,=B0(`````````````B`)T'8D"
M`````````````(@"8AV^'8D"``````````"(`F0=OAV)`@``````````B`)E
M';X=B0(``````````(@"9QV^'8D"``````````"(`F@=OAV)`@``````````
MB`)I';X=B0(``````````(@":QV^'8D"``````````"(`FT=OAV)`@``````
M````B`)N';X=B0(``````````(@"<!V^'8D"``````````"(`G$=OAV)`@``
M````````B`)R';X=B0(``````````(@"<QV^'8D"``````````"(`G0=OAV)
M`@``````````B`)N'<L=B0(``````````(@";1W&'6X=PAT#'HD"``"(`FT=
MQAUT'<L=B0(`````P/L?L@```````````````(@"0/L`SHD"``````````"(
M`D#[C,Z)`@``````````B`)`^PG.B0(``````````(@"0/O;UHD"````````
M``"(`D#[E,Z)`@``````````B`)`^VW1B0(``````````(@"0/L#SHD"````
M``````"(`D#[:]&)`@``````````B`)`^UW.B0(``````````(@"0/M!TXD"
M``````````"(`D#[".>)`@``````````B`)`^VOPB0(``````````(@"0/LT
M[(D"``````````"(`D#[*.>)`@``````````B`)!^]&1B0(``````````(@"
M0/L?UXD"``````````"(`D#[Y>6)`@``````````B`)`^RKHB0(`````````
M`(@"0/L)YXD"``````````"(`D#[/OF)`@``````````B`)`^PW4B0(`````
M`````(@"0/MY\HD"``````````"(`D'[H8R)`@``````````B`)`^UWYB0(`
M`````````(@"0/NTTHD"``````````"(`D#[X\Z)`@``````````B`)`^WS4
MB0(``````````(@"0/MFVXD"``````````"(`D#[X_:)`@``````````B`)`
M^P'/B0(``````````(@"0?O'C(D"``````````"(`D#[5-.)`@``````````
MB`)`^VWYB0(``````````(@"0/L1SXD"``````````"(`D'[ZH&)`@``````
M````B`)!^_.!B0(``````````,#[1+(```````````````#`^T6R````````
M````````P/M&L@```````````````,#[1[(```````````````#`^TBR````
M````````````P/M)L@```````````````,#[2K(```````````````#`^TNR
M````````````````P/M,L@```````````````,#[3;(```````````````#`
M^TZR````````````````P/M/L@```````````````*</`A"+#@``````````
M```K#BH.````````````````*PXK#@```````````````"L.+`X`````````
M```````K#BT.````````````````*PXN#@```````````````"L.+PX`````
M```````````K#C`.````````````````*PXQ#@```````````````"L.,@X`
M```````````````L#BD.````````````````+`XJ#@```````````````"P.
M*PX````````````````L#BP.````````````````+`XM#@``````````````
M`"P.+@X```````````````!B'0``````````````````9!T`````````````
M`````&4=``````````````````!G'0``````````````````:!T`````````
M`````````&D=``````````````````!K'0``````````````````;1T`````
M`````````````&X=``````````````````!P'0``````````````````<1T`
M`````````````````'(=``````````````````!S'0``````````````````
M=!T``````````````````&(=OAT```````````````!D';X=````````````
M````91V^'0```````````````&<=OAT```````````````!H';X=````````
M````````:1V^'0```````````````&L=OAT```````````````!M';X=````
M````````````;AV^'0```````````````'`=OAT```````````````!Q';X=
M````````````````<AV^'0```````````````',=OAT```````````````!T
M';X=````````````````<!V^'0\>8AW&'0```````&X=RQUM'=$=````````
M``#`^WZR````````````````Q`T``````````````````$#[`,X`````````
M``````!`^XS.````````````````0/L)S@```````````````$#[V]8`````
M``````````!`^Y3.````````````````0/MMT0```````````````$#[`\X`
M``````````````!`^VO1````````````````0/M=S@```````````````$#[
M0=,```````````````!`^PCG````````````````0/MK\```````````````
M`$#[-.P```````````````!`^RCG````````````````0?O1D0``````````
M`````$#[']<```````````````!`^^7E````````````````0/LJZ```````
M`````````$#["><```````````````!`^S[Y````````````````0/L-U```
M`````````````$#[>?(```````````````!!^Z&,````````````````0/M=
M^0```````````````$#[M-(```````````````!`^]CY````````````````
M0/LW]0```````````````$#[<]D```````````````!!^VF0````````````
M````0/LJT0```````````````$#[<-,```````````````!`^^CL````````
M````````0?L%F````````````````$#[$<\```````````````!`^YG1````
M````````````0/MCZP```````````````$#["LX```````````````!`^RW.
M````````````````0/L+S@```````````````$#[YMT```````````````!`
M^_/3````````````````0/L[TP```````````````$#[E]L`````````````
M``!`^V;;````````````````0/OC]@```````````````$#[`<\`````````
M``````!!^\>,````````````````0/M4TP```````````````$#['-D`````
M```````````L#B\.````````````````+`XP#@```````````````"P.,0X`
M```````````````L#C(.````````````````+0XI#@```````````````"T.
M*@X````````````````M#BL.````````````````+0XL#@``````````````
M`"T.+0X````````````````M#BX.````````````````+0XO#@``````````
M`````"T.,`X````````````````M#C$.````````````````+0XR#@``````
M`````````"X.*0X````````````````J#D#[".<`````````````*PY`^PCG
M`````````````"P.0/L(YP`````````````M#D#[".<`````````````+@Y`
M^PCG`````````````"\.0/L(YP`````````````P#D#[".<`````````````
M,0Y`^PCG`````````````#(.0/L(YP`````````````J#BD.0/L(YP``````
M````*@XJ#D#[".<``````````"H.*PY`^PCG``````````#A#L$.````````
M````````BP[`#\$.`````````````(L.1!`````````````````N#P(0;0X`
M````````````4AX``````````````````%,>``````````````````!4'@``
M````````````````51X``````````````````%8>``````````````````!7
M'@``````````````````6!X``````````````````%D>````````````````
M``!:'@``````````````````6QX``````````````````%P>````````````
M``````!='@``````````````````7AX``````````````````%\>````````
M``````````!@'@``````````````````81X``````````````````&(>````
M``````````````!C'@``````````````````9!X``````````````````&4>
M``````````````````!F'@``````````````````9QX`````````````````
M`&@>``````````````````!I'@``````````````````:AX`````````````
M`````&L>``````````````````!L'@``````````````````;1X`````````
M`````````&X>``````````````````!O'@``````````````````<!X`````
M`````````````'$>``````````````````!R'@``````````````````<QX`
M`````````````````'0>``````````````````!U'@``````````````````
M=AX``````````````````'<>``````````````````!X'@``````````````
M````>1X``````````````````'H>``````````````````!['@``````````
M````````?!X``````````````````'T>``````````````````!^'@``````
M````````````?QX``````````````````(`>``````````````````#`^_^R
M````````````````P/L`L0``P/L!L0``P/L"L0``P/L#L0``P/L$L0``@AX`
M````@QX`````A!X`````A1X`````AQX`````B!X`````B1X`````BAX`````
MBQX`````C!X`````CQX`````D!X`````D1X`````DAX`````E!X`````E1X`
M````EAX`````EQX`````F!X`````F1X`````FAX`````FQX`````G!X`````
MGAX`````GQX`````H1X`````HAX`````HQX`````I!X`````I1X`````IAX`
M````IQX`````J1X`````K1X`````KAX`````KQX`````L!X`````AAX`````
MC1X`````DQX`````P/LML0``P/LNL0``P/LOL0``P/LPL0``8AT`````8QT`
M`````AX`````9!T`````!!X`````!1X`````91T`````9AT`````9QT`````
M"!X`````"1X`````"AX`````"QX`````#!X`````#1X`````?!T`````:!T`
M````:1T`````:AT`````@QT`````:QT`````;!T`````;1T`````;AT`````
M;QT`````<!T`````<1T`````<AT`````<QT`````=!T`````OAT`````OQT`
M````P!T`````P1T`````PAT`````PQT`````Q!T`````Q1T`````QAT`````
MQQT`````R!T`````R1T`````RAT`````RQT`````S!T`````S1T`````SAT`
M````SQT`````T!T`````T1T`````TAT`````O1T`````=AT`````=QT`````
M'QX`````(!X`````)!X`````)AX`````*QX`````+QX`````,1X`````?AT`
M````-1X`````-QX`````?QT`````@!T`````@AT`````A!T`````A1T`````
MB1T`````BQT`````C1T`````CAT`````CQT`````D!T`````D1T`````E!T`
M````F!T`````HAT`````J1T`````KAT`````21X`````2AX`````N1T`````
MNAT`````NQT`````X1T`````XAT`````Y1T`````[AT`````[QT`````\1T`
M````^QT`````_AT`````P/N/L0``P@T`````PPT`````0/L`S@``0/N,S@``
M0/L)S@``0/O;U@``0/L*S@``0/LMS@``0/L+S@``0/LR]0``0/M9S@``0/L9
MS@``0/L!S@``0/LIV0``0/LPUP``0/NZS@``@AX`````F!X`````D!X`````
MBQX`````H!X`````H!X`````G1X`````G!X`````KQX`````FQX`````KAX`
M````KQX`````K!X`````CAX`````H1X`````HQX`````JAX`````JQX`````
MJ!X`````KAX`````@QX`````B!X`````C!X`````CQX`````P/NXL0``P/NY
ML0``P/NZL0``P/N[L0``P/N\L0``P/N]L0``P/N^L0``P/N_L0``P/O`L0``
MP/O!L0``P/O"L0``P/O#L0``P/O$L0``P/O%L0``P/O&L0``P/O'L0``P/O(
ML0``P/O)L0``P/O*L0``P/O+L0``P/O,L0``P/O-L0``P/O.L0``P/O/L0``
MP/O0L0``P/O1L0``P/O2L0``P/O3L0``P/O4L0``P/O5L0``P/O6L0``P/O7
ML0``P/O8L0``P/O9L0``P/O:L0``P/O;L0``P/O<L0``P/O=L0``P/O>L0``
MP/O?L0``P/O@L0``P/OAL0``P/OBL0``P/OCL0``P/ODL0``P/OEL0``P/OF
ML0``P/OGL0``P/OHL0``P/OIL0``P/OJL0``P/OKL0``P/OLL0``P/OML0``
MP/ONL0``P/OOL0``61X`````71X`````7AX`````91X`````:!X`````:QX`
M````;!X`````;1X`````;AX`````;QX`````<AX`````>!X`````>1X`````
M>AX`````>QX`````?!X`````"0(`````-P(`````9@(`````X@(`````NPT`
M````!0X`````71YS'@``*0X`````K@(`````KP(`````L`(`````L0(`````
ML@(`````LP(`````M`(`````M0(`````M@(`````MP(`````O`T`````O0T`
M````N`(`````N0(`````N@(`````NP(`````O`(`````O0(`````O@(`````
MOP(`````*P(`````@P(`````A`(`````A0(`````O@T`````*@X`````*PX`
M````+`X`````+0X`````+@X`````+PX`````,`X`````,0X`````,@X`````
M````````````````````````````````````````````````+`(`````!PX`
M````!PX`````"`X`````"`X`````"0X`````O`T`````OPT`````0/M!TP``
M0/M$TP``0/M%TP``!@X`````<!Y>'@``XP(`````P`T`````P0T`````P/M`
ML```4AX`````4AX`````4QX`````4QX`````5!X`````5!X`````51X`````
M51X`````5AX`````5AX`````5QX`````5QX`````6!X`````6!X`````61X`
M````61X`````6AX`````6AX`````6QX`````6QX`````7!X`````7!X`````
M71X`````71X`````7AX`````7AX`````7QX`````7QX`````8!X`````8!X`
M````81X`````81X`````8AX`````8AX`````8QX`````8QX`````8QX`````
M9!X`````9!X`````91X`````91X`````9AX`````9QX`````:!X`````:1X`
M````:AX`````:QX`````:QX`````:QX`````;!X`````;!X`````;!X`````
M;1X`````;1X`````;1X`````;AX`````;AX`````;AX`````;QX`````;QX`
M````;QX`````<!X`````<1X`````<AX`````<QX`````=!X`````=1X`````
M=1X`````=AX`````=AX`````=QX`````=QX`````>!X`````>1X`````>AX`
M````>QX`````?!X`````?1X`````?1X`````?AX`````?QX`````@!X`````
M@1X`````5!X`````5QX`````6AX`````P/N7L```P/N8L```````````````
M````'@(`````'P(`````"@X`````"@X`````=QYY'@``+0(`````4AX`````
M4AX`````4QX`````4QX`````5!X`````5!X`````51X`````51X`````5AX`
M````5AX`````5QX`````5QX`````6!X`````6!X`````61X`````61X`````
M6AX`````6AX`````6QX`````6QX`````7!X`````7!X`````71X`````71X`
M````7AX`````7AX`````7QX`````7QX`````8!X`````8!X`````81X`````
M81X`````8AX`````8AX`````8QX`````8QX`````8QX`````9!X`````9!X`
M````91X`````91X`````9AX`````9QX`````:!X`````:1X`````:AX`````
M:QX`````:QX`````:QX`````;!X`````;!X`````;!X`````;1X`````;1X`
M````;1X`````;AX`````;AX`````;AX`````;QX`````;QX`````;QX`````
M<!X`````<1X`````<AX`````<QX`````=!X`````=1X`````=1X`````=AX`
M````=AX`````=QX`````=QX`````>!X`````>1X`````>AX`````>QX`````
M?!X`````?1X`````?1X`````?AX`````?QX`````@!X`````@1X`````5!X`
M````5QX`````6AX`````?1X`````?AX`````?QX`````@!X`````+@(`````
M"PX`````#`X`````#`X`````6QYE'@``0/L`S@``0/LHS@``0/LVS@``0/L_
MS@``0/M9S@``0/N%S@``0/N,S@``0/N@S@``0/NZS@``0/L_T0``0/MET0``
M0/MKT0``0/N"T0``0/N6T0``0/NKT0``0/O@T0``0/OUT0``0/L`T@``0/N;
MT@``0/OYT@``0/L5TP``0/L:TP``0/LXTP``0/M!TP``0/M<TP``0/MITP``
M0/N"TP``0/NVTP``0/O(TP``0/OCTP``0/O7U@``0/L?UP``0/OKV```0/L"
MV0``0/L*V0``0/L5V0``0/LGV0``0/MSV0``0/M0VP``0/N`VP``0/OXVP``
M0/L/W```0/LBW```0/LXW```0/MNW```0/MQW```0/O;W0``0/OEW0``0/OQ
MW0``0/O^W0``0/MRW@``0/MZW@``0/M_W@``0/OTW@``0/O^W@``0/L+WP``
M0/L3WP``0/M0WP``0/MAWP``0/MSWP``0/O#WP``0/L(X@``0/LVX@``0/M+
MX@``0/LOY0``0/LTY0``0/N'Y0``0/N7Y0``0/NDY0``0/NYY0``0/O@Y0``
M0/OEY0``0/OPY@``0/L(YP``0/LHYP``0/L@ZP``0/MBZP``0/MYZP``0/NS
MZP``0/O+ZP``0/O4ZP``0/O;ZP``0/L/[```0/L4[```0/LT[```0/MK\```
M0/LJ\@``0/LV\@``0/L[\@``0/L_\@``0/M'\@``0/M9\@``0/M;\@``0/NL
M\@``0/N$\P``0/N)\P``0/O<]```0/OF]```0/L8]0``0/L?]0``0/LH]0``
M0/LP]0``0/N+]0``0/N2]0``0/MV]@``0/M]]@``0/NN]@``0/N_]@``0/ON
M]@``0/O;]P``0/OB]P``0/OS]P``0/LZ^0``0/NX^0``0/N^^0``0/MT^@``
M0/O+^@``0/OY^@``0/MS_```0/OX_```0/LV_P``0/M1_P``0/N*_P``0/N]
M_P``0?L!@```0?L,@```0?L2@```0?LS@```0?M_@```0?N)@```0?OC@0``
M0?OJ@0``0?OS@0``0?O\@0``0?L,@@``0?L;@@``0?L?@@``0?MN@@``0?MR
M@@``0?MX@@``0?M-A@``0?MKA@``0?M`B```0?M,B```0?MCB```0?M^B0``
M0?N+B0``0?O2B0``0?L`B@``0?LWC```0?M&C```0?M5C```0?MXC```0?N=
MC```0?MDC0``0?MPC0``0?NSC0``0?NKC@``0?O*C@``0?N;CP``0?NPCP``
M0?NUCP``0?N1D```0?M)D0``0?O&D0``0?O,D0``0?O1D0``0?MWE0``0?N`
ME0``0?L<E@``0?NVE@``0?NYE@``0?OHE@``0?M1EP``0?M>EP``0?MBEP``
M0?MIEP``0?O+EP``0?OMEP``0?OSEP``0?L!F```0?NHF```0?O;F```0?O?
MF```0?N6F0``0?N9F0``0?NLF0``0?NHF@``0?O8F@``0?O?F@``0?LEFP``
M0?LOFP``0?LRFP``0?L\FP``0?M:FP``0?OEG```0?MUG@``0?M_G@``0?NE
MG@``0?N[G@``0?O#G@``0?O-G@``0?O1G@``0?OYG@``0?O]G@``0?L.GP``
M0?L3GP``0?L@GP``0?L[GP``0?M*GP``0?M2GP``0?N-GP``0?N<GP``0?N@
MGP``P/O6KP``P/O7KP``P/O8KP``P/O9KP``P/O:KP``P/O;KP``P/O<KP``
MP/O=KP``P/O>KP``P/O?KP``P/O@KP``P/OAKP``P/OBKP``P/OCKP``P/OD
MKP``P/OEKP``P/OFKP``P/OGKP``P/OHKP``P/OIKP``P/OJKP``P/OKKP``
MP/OLKP``P/OMKP``P/ONKP``P/OOKP``KPT`````L`T`````L0T`````L@T`
M````LPT`````M`T`````M0T`````M@T`````MPT`````N`T`````N0T`````
MN@T`````P/O\KP``P/O]KP``P/O^KP``P/O_KP``P/L`K@``P/L!K@``P/L"
MK@``P/L#K@``P/L$K@``P/L%K@``P/L&K@``P/L'K@``P/L(K@``P/L)K@``
MP/L*K@``P/L+K@``P/L,K@``P/L-K@``P/L.K@``P/L/K@``P/L0K@``P/L1
MK@``P/L2K@``P/L3K@``P/L4K@``P/L5K@``P/L6K@``P/L7K@``P/L8K@``
MP/L9K@``P/L:K@``P/L;K@``P/L<K@``P/L=K@``P/L>K@``P/L?K@``P/L@
MK@``P/LAK@``P/LBK@``P/LCK@``P/LDK@``P/LEK@``P/LFK@``P/LGK@``
MP/LHK@``P/LIK@``P/LJK@``P/LKK@``P/LLK@``P/LMK@``P/LNK@``P/LO
MK@``P/LPK@``P/LQK@``P/LRK@``P/LSK@``P/LTK@``P/LUK@``P/LVK@``
MP/LWK@``P/LXK@``P/LYK@``P/LZK@``P/L[K@``P/L\K@``P/L]K@``P/L^
MK@``P/L_K@``P/M`K@``P/M!K@``P/M"K@``P/M#K@``P/M$K@``P/M%K@``
MP/M&K@``P/M'K@``P/M(K@``P/M)K@``P/M*K@``P/M+K@``P/M,K@``P/M-
MK@``P/M.K@``P/M/K@``P/M0K@``P/M1K@``P/M2K@``P/M3K@``P/M4K@``
MP/M5K@``P/M6K@``P/M7K@``P/M8K@``P/M9K@``P/M:K@``P/M;K@``P/M<
MK@``P/M=K@``P/M>K@``P/M?K@``P/M@K@``P/MAK@``P/MBK@``P/MCK@``
MP/MDK@``P/MEK@``P/MFK@``P/MGK@``P/MHK@``P/MIK@``P/MJK@``P/MK
MK@``P/MLK@``P/MMK@``P/MNK@``P/MOK@``P/MPK@``P/MQK@``P/MRK@``
MP/MSK@``P/MTK@``P/MUK@``P/MVK@``P/MWK@``P/MXK@``P/MYK@``P/MZ
MK@``P/M[K@``P/M\K@``P/M]K@``P/M^K@``P/M_K@``0/LVS@``0/N"TP``
M0/M;S@``0/M:S@``0/M9S@``0/N[S@``0/N"T0``0/O@T0``0/L`T@``0/L"
MT@``0/M<TP``0/MITP``0/L/W```0/L/W```0/LBW```0/LCW```0/LBW```
M0/LCW```0/OSW0``0/MZW@``0/M1WP``0/M0WP``0/O$WP``0/O#WP``0/M,
MX@``0/LUY0``P/N:K@``0/OAY0``0/OEY0``0/L(YP``0/MZZP``0/O-ZP``
M0/L1[```0/LU[```0/LZ[```0/ML\```0/LK\@``0/LK\@``0/LLS@``0/M;
M\@``0/NM\@``0/N+\P``0/N+]0``0/ON]@``0/LZ^0``0/L[^0``0/OY^@``
M0/OY_```0/N?_@``0/M3_P``0/M2_P``0/M3_P``0/M3_P``0/M2_P``0/N*
M_P``0/N*_P``0/N+_P``0?L"@```0?N`@```0?M_@```0?N)@```0?O\@0``
M0?MY@@``0?MY@@``0?MY@@``0?M.A@``0?MDB```0?N`B0``0?M_B0``0?O!
MB0``0?O2B0``0?O2B0``0?N@BP``0?L=C0``0?NSC0``0?MFCP``0?NVCP``
M0?NVCP``0?NVCP``0?N1D```0?N%E```0?MWE0``0?MXE0``0?M_E0``0?OH
ME0``0?L<E@``0?L=E@``0?OHE@``0?M2EP``0?OFEP``0?MUF```0?O.F```
M0?O>F```0?O?F```0?O@F```0?O@F```0?MCF0``0?N6F0``0?MLF@``0?NH
MF@``0?L\FP``0?M\G```0?L?G@``0?MUG@``0?NFG@``0?O$G@``0?O^G@``
M0?M*GP``0?M0GP``0?M2GP``0?M_GP``0?N-GP``0?N9GP``0?N<GP``0?N<
MGP``0?N?GP``P/OTK@``P/OUK@``P/OVK@``P/OWK@``P/OXK@``P/OYK@``
MP/OZK@``P/O[K@``P/O\K@``P/O]K@``P/O^K@``P/O_K@``&PH`````'`H`
M````'0H`````'@H`````'PH`````(`H`````(0H`````(@H`````(PH`````
M)`H`````)0H`````)@H`````)PH`````*`H`````P/L.JP``P/L/JP``P/L0
MJP``P/L1JP``P/L2JP``P/L3JP``P/L4JP``P/L5JP``P/L6JP``P/L7JP``
MP/L8JP``P/L9JP``P/L:JP``P/L;JP``P/L<JP``P/L=JP``P/L>JP``P/L?
MJP``P/L@JP``P/LAJP``P/LBJP``P/LCJP``P/LDJP``P/LEJP``P/LFJP``
MP/LGJP``P/LHJP``P/LIJP``P/LJJP``P/LKJP``P/LLJP``P/LMJP``P/LN
MJP``P/LOJP``P/LPJP``P/LQJP``P/LRJP``P/LSJP``P/LTJP``P/LUJP``
MP/LVJP``P/LWJP``P/LXJP``P/LYJP``P/LZJP``P/L[JP``P/L\JP``P/L]
MJP``P/L^JP``P/L_JP``P/M`JP``P/M!JP``P/M"JP``P/M#JP``P/M$JP``
MP/M%JP``P/M&JP``P/M'JP``P/M(JP``P/M)JP``P/M*JP``P/M+JP``P/M,
MJP``P/M-JP``P/M.JP``P/M/JP``P/M0JP``P/M1JP``P/M2JP``P/M3JP``
MP/M4JP``P/M5JP``P/M6JP``P/M7JP``P/M8JP``P/M9JP``P/M:JP``P/M;
MJP``P/M<JP``P/M=JP``P/M>JP``P/M?JP``P/M@JP``P/MAJP``P/MBJP``
MP/MCJP``P/MDJP``P/MEJP``P/MFJP``P/MGJP``P/MHJP``P/MIJP``P/MJ
MJP``P/MKJP``P/MLJP``P/MMJP``P/MNJP``P/MOJP``P/MPJP``P/MQJP``
MP/MRJP``P/MSJP``P/MTJP``P/MUJP``P/MVJP``P/MWJP``P/MXJP``P/MY
MJP``P/MZJP``P/M[JP``P/M\JP``P/M]JP``P/M^JP``P/M_JP``P/N`JP``
MP/N!JP``P/N"JP``P/N#JP``P/N$JP``P/N%JP``P/N&JP``P/N'JP``P/N(
MJP``P/N)JP``P/N*JP``P/N+JP``P/N,JP``P/N-JP``P/N.JP``P/N/JP``
MP/N0JP``P/N1JP``P/N2JP``P/N3JP``P/N4JP``P/N5JP``P/N6JP``P/N7
MJP``P/N8JP``P/N9JP``P/N:JP``P/N;JP``P/N<JP``P/N=JP``P/N>JP``
MP/N?JP``P/N@JP``P/NAJP``P/NBJP``P/NCJP``P/NDJP``P/NEJP``P/NF
MJP``P/NGJP``P/NHJP``P/NIJP``P/NJJP``P/NKJP``P/NLJP``P/NMJP``
MP/NNJP``P/NOJP``P/NPJP``P/NQJP``P/NRJP``P/NSJP``P/NTJP``P/NU
MJP``P/NVJP``P/NWJP``P/NXJP``P/NYJP``P/NZJP``P/N[JP``P/N\JP``
MP/N]JP``P/N^JP``P/N_JP``P/O`JP``P/O!JP``P/O"JP``P/O#JP``P/O$
MJP``P/O%JP``P/O&JP``P/O'JP``P/O(JP``P/O)JP``P/O*JP``P/O+JP``
MP/O,JP``P/O-JP``P/O.JP``P/O/JP``P/O0JP``P/O1JP``P/O2JP``P/O3
MJP``P/O4JP``P/O5JP``P/O6JP``P/O7JP``P/O8JP``P/O9JP``P/O:JP``
MP/O;JP``P/O<JP``P/O=JP``P/O>JP``P/O?JP``P/O@JP``P/OAJP``P/OB
MJP``P/OCJP``P/ODJP``P/OEJP``P/OFJP``P/OGJP``P/OHJP``P/OIJP``
MP/OJJP``P/OKJP``P/OLJP``P/OMJP``P/ONJP``P/OOJP``P/OPJP``P/OQ
MJP``P/ORJP``P/OSJP``P/OTJP``P/OUJP``P/OVJP``P/OWJP``P/OXJP``
MP/OYJP``P/OZJP``P/O[JP``P/O\JP``P/O]JP``P/O^JP``P/O_JP``(`D`
M`````````"$)```````````B"0``````````(PD``````````"0)````````
M```E"0``````````)@D``````````"<)```````````H"0``````````*0D`
M`````````"H)```````````K"0``````````2P1+!$L$2P0``"P)````````
M```M"0``````````+@D``````````"\)```````````P"0``````````,0D`
M`````````#()```````````S"0``````````-`D``````````#4)````````
M```V"0``````````-PD``````````#@)```````````Y"0``````````.@D`
M`````````#L)```````````\"0``````````/0D``````````#X)````````
M```_"0``````````0`D``````````$$)``````````!""0``````````0PD`
M`````````$0)``````````!%"0``````````1@D``````````$<)````````
M``!("0``````````20D``````````$H)``````````!+"0``````````3`D`
M`````````$T)``````````!."0``````````3PD``````````%`)````````
M``!1"0``````````4@D``````````%,)``````````!4"0``````````50D`
M`````````%8)``````````!7"0``````````6`D``````````%D)````````
M``!:"0``````````6PD``````````%P)``````````!="0``````````7@D`
M`````````%\)``````````!@"0``````````80D``````````&()````````
M``!C"0``````````9`D``````````&4)``````````!F"0``````````9PD`
M`````````&@)``````````!I"0``````````:@D``````````&L)````````
M``!L"0``````````;0D``````````&X)``````````!O"0``````````<`D`
M`````````'$)``````````!R"0``````````<PD``````````'0)````````
M``!U"0``````````=@D``````````'<)``````````!X"0``````````>0D`
M`````````'H)``````````!["0``````````?`D``````````'T)````````
M``!^"0``````````?PD``````````(`)``````````"!"0``````````@@D`
M`````````(,)``````````"$"0``````````A0D``````````(8)````````
M``"'"0``````````B`D``````````(D)``````````"*"0``````````BPD`
M`````````(P)``````````"-"0``````````C@D``````````(\)````````
M``"0"0``````````D0D``````````)()```````````]`CT"+00`````+00M
M!````````"T$+00M!`````"3"0``````````E`D``````````)4)````````
M``"6"0``````````EPD``````````)@)``````````"9"0``````````F@D`
M`````````)L)``````````"<"0``````````G0D``````````)X)````````
M``"?"0``````````H`D``````````*$)``````````"B"0``````````HPD`
M`````````*0)``````````"E"0``````````I@D``````````*<)````````
M``"H"0``````````J0D``````````*H)``````````"K"0``````````K`D`
M`````````*T)``````````"N"0``````````KPD``````````+`)````````
M``"Q"0``````````L@D``````````+,)``````````"T"0``````````M0D`
M`````````+8)``````````"W"0``````````N`D``````````+D)````````
M``"Z"0``````````NPD``````````+P)``````````"]"0``````````O@D`
M`````````+\)``````````#`"0``````````P0D``````````,()````````
M``##"0``````````Q`D``````````,4)``````````#&"0``````````QPD`
M`````````,@)``````````#)"0``````````R@D``````````,L)````````
M``#,"0``````````S0D``````````,X)``````````#/"0``````````T`D`
M`````````-$)``````````#2"0``````````TPD``````````-0)````````
M``#5"0``````````U@D``````````-<)``````````#8"0``````````V0D`
M`````````-H)``````````#;"0``````````W`D``````````-T)````````
M``#>"0``````````WPD``````````.`)``````````#A"0``````````X@D`
M`````````.,)``````````#D"0``````````Y0D``````````.8)````````
M``#G"0``````````Z`D``````````.D)``````````#J"0``````````ZPD`
M`````````.P)``````````#M"0``````````[@D``````````.\)````````
M``#P"0``````````\0D``````````/()``````````#S"0``````````]`D`
M`````````/4)``````````#V"0``````````]PD``````````/@)````````
M``#X"0``````````^0D``````````/H)``````````#["0``````````_`D`
M`````````/T)``````````#^"0``````````_PD````````````*````````
M```!"@```````````@H```````````,*```````````$"@``````````!0H`
M``````````8*```````````'"@``````````"`H```````````D*````````
M```*"@``````````"PH```````````P*```````````-"@``````````#@H`
M``````````\*```````````0"@``````````$0H``````````!(*````````
M```3"@``````````%`H``````````!4*```````````6"@``````````%PH`
M`````````!@*```````````9"@``````````&@H``````````#@(```Y"```
M.@@``#L(```\"```/0@``#X(```_"```0`@``$$(``!""```0P@``$0(``!%
M"```1@@``$<(``!("```20@``$H(``!+"```3`@``$T(``!."```3P@``%`(
M``!1"```4@@``%,(``!4"```50@``%8(``!7"```6`@``%D(``!:"```6P@`
M`%P(``!="```7@@``%\(``!@"```80@``&((``!C"```9`@``&4(``!F"```
M9P@``&@(``!I"```:@@``&L(``!L"```;0@``&X(``!O"```<`@``'$(``!R
M"```<P@``'0(``!U"```=@@``'<(``!X"```>0@``'H(``!["```?`@``'T(
M``!^"```?P@``(`(``"!"```@@@``(,(``"$"```A0@``(8(``"'"```B`@`
M`(D(``"*"```BP@``(P(``"-"```C@@``(\(``"0"```D0@``)((``"3"```
ME`@``)4(``"6"```EP@``)@(``"9"```F@@``)L(``"<"```G0@``)X(``"?
M"```H`@``*$(``"B"```HP@``*0(``"E"```I@@``*<(``"H"```J0@``*H(
M``"K"```K`@``*T(``"N"```KP@``+`(``"Q"```L@@``+,(``"T"```M0@`
M`+8(``"W"```N`@``+D(``"Z"```F`(``)D"``":`@``FP(``)P"``"=`@``
MG@(``)\"``"@`@``H0(``*("``"C`@``I`(``*4"``"F`@``IP(``*@"``"I
M`@``J@(``*L"``"L`@``K0(``+L(``"\"```O0@``+X(``"_"```P`@``,$(
M``#""```PP@``,0(``#%"```Q@@``,<(``#("```R0@``,H(``#+"```S`@`
M`,T(``#."```SP@``-`(``#1"```T@@``-,(``#4"```U0@``-8(``#7"```
MV`@``-D(``#:"```VP@``-P(``#="```W@@``-\(``#@"```X0@``.((``#C
M"```Y`@``.4(``#F"```YP@``.@(``#I"```Z@@``.L(``#L"```[0@``.X(
M``#O"```\`@``/$(``#R"```\P@``/0(``#U"```]@@``/<(``#X"```^0@`
M`/H(``#["```_`@``/T(``#^"```_P@````)```!"0```@D```,)```$"0``
M!0D```8)```'"0``"`D```D)```*"0``"PD```P)```-"0``#@D```\)```0
M"0``$0D``!()```3"0``%`D``!4)```6"0``%PD``!@)```9"0``&@D``!L)
M```<"0``'0D``)8"``"7`@``'@D``!\)```I"@``*@H``"L*```L"@``+0H`
M`"X*```O"@``,`H``#$*```R"@``,PH``#0*```U"@``-@H``#<*```X"@``
M.0H``#H*```["@``/`H``#T*```^"@``/PH``$`*``!!"@``0@H``$,*``!$
M"@``10H``$8*``!'"@``2`H``$D*``!*"@``2PH``$P*``!-"@``3@H``$\*
M``!0"@``40H``%(*``!3"@``5`H``%4*``!6"@``5PH``%@*``!9"@``6@H`
M`%L*``!<"@``70H``%X*``!?"@``8`H``&$*``!B"@``8PH``&0*``!E"@``
M9@H``&<*``!H"@``:0H``&H*``!K"@``;`H``&T*``!N"@``;PH``'`*``!Q
M"@``<@H``',*``!T"@``=0H``'8*``!W"@``>`H``'D*``!Z"@``>PH``'P*
M``!]"@``?@H``'\*``"`"@``@0H``((*``"#"@``A`H``(4*``"&"@``APH`
M`(@*``")"@``B@H``(L*``","@``C0H``(X*``"/"@``D`H``)$*``"2"@``
MDPH``)0*``"5"@``E@H``)<*``"8"@``F0H``)H*``";"@``G`H``)T*``">
M"@``GPH``*`*``"A"@``H@H``*,*``"D"@``I0H``*8*``"G"@``J`H``*D*
M``"J"@``JPH``*P*``"M"@``K@H``*\*``"P"@``L0H``+(*``"S"@``M`H`
M`+4*``"V"@``MPH``+@*``"Y"@``N@H``+L*``"\"@``O0H``+X*``"_"@``
MP`H``,$*``#""@``PPH``,0*``#%"@``Q@H``,<*``#("@``R0H``,H*``#+
M"@``S`H``,T*``#."@``SPH``-`*``#1"@``T@H``-,*``#4"@``U0H``-8*
M``#7"@``V`H``-D*``#:"@``VPH``-P*``#="@``W@H``-\*``#@"@``X0H`
M`.(*``#C"@``Y`H``.4*``#F"@``YPH``.@*``#I"@``Z@H``.L*``#L"@``
M[0H``.X*``#O"@``\`H``/$*``#R"@``\PH``/0*``#U"@``]@H``/<*``#X
M"@``^0H``/H*``#["@``_`H``/T*``#^"@``_PH````+```!"P```@L```,+
M```$"P``!0L```8+```'"P``"`L```D+```*"P``"PL```P+```-"P``#@L`
M``\+```0"P``$0L``!(+```3"P``%`L``!4+```6"P``%PL``!@+```9"P``
M&@L``!L+```<"P``'0L``!X+```?"P``(`L``"$+```B"P``(PL``"0+```E
M"P``)@L``"<+```H"P``P/L`IP``?`<`````?0<`````?@<`````?P<`````
MP/L%IP``@`<`````@0<`````@@<`````@P<`````P/L*IP``P/L+IP``A`<`
M````A0<`````A@<`````AP<`````B`<`````B0<`````B@<`````BP<`````
MC`<`````C0<`````C@<`````CP<`````D`<`````D0<`````D@<`````DP<`
M````E`<`````E0<`````E@<`````EP<`````F`<`````F0<`````F@<`````
MFP<`````G`<`````G0<`````G@<`````GP<`````P/LHIP``H`<`````H0<`
M````H@<`````HP<`````I`<`````I0<`````I@<`````IP<`````J`<`````
MJ0<`````J@<`````JP<`````K`<`````K0<`````K@<`````KP<`````L`<`
M````L0<`````L@<`````LP<`````M`<`````M0<`````M@<`````MP<`````
MN`<`````N0<`````N@<`````NP<`````O`<`````O0<`````O@<`````OP<`
M````P`<`````P0<`````P@<`````P/M,IP``PP<`````P/M.IP``Q`<`````
MQ0<`````Q@<`````QP<`````P/M3IP``P/M4IP``P/M5IP``R`<`````P/M7
MIP``R0<`````R@<`````RP<`````S`<`````S0<`````S@<`````SP<`````
MP/M?IP``P/M@IP``T`<`````T0<`````T@<`````TP<`````U`<`````U0<`
M````U@<`````UP<`````V`<`````V0<`````V@<`````VP<`````W`<`````
MW0<`````W@<`````WP<`````X`<`````X0<`````X@<`````XP<`````Y`<`
M````*@X`````*PX`````+`X`````+0X`````+@X`````+PX`````,`X`````
M,0X`````,@X`````*@XI#@``*@X`````*PX`````+`X`````+0X`````+@X`
M````+PX`````,`X`````,0X`````,@X`````*@XI#@``*@X`````*PX`````
M+`X`````+0X`````+@X`````+PX`````,`X`````,0X`````,@X`````*@XI
M#@``Y0<`````P/N5IP``P/N6IP``P/N7IP``Y@<`````YP<`````Z`<`````
MZ0<`````Z@<`````ZP<`````[`<`````[0<`````[@<`````[P<`````\`<`
M````\0<`````\@<`````\P<`````]`<`````]0<`````]@<`````]P<`````
M^`<`````^0<`````^@<`````^P<`````_`<`````_0<`````P/NPIP``_@<`
M````_P<```````@``````0@``````@@``````P@`````!`@`````!0@`````
M!@@`````!P@`````"`@`````"0@`````"@@`````"P@`````P/N_IP``P/O`
MIP``P/O!IP``P/O"IP``P/O#IP``P/O$IP``P/O%IP``P/O&IP``P/O'IP``
MP/O(IP``P/O)IP``P/O*IP``P/O+IP``P/O,IP``P/O-IP``P/O.IP``P/O/
MIP``#`@`````#0@`````#@@`````#P@`````$`@`````$0@`````$@@`````
M$P@`````%`@`````%0@`````%@@`````%P@`````&`@`````&0@`````&@@`
M````&P@`````'`@`````'0@`````'@@`````'P@`````(`@`````(0@`````
M(@@`````(P@`````)`@`````)0@`````)@@`````)P@`````P/OLIP``P/OM
MIP``P/ONIP``P/OOIP``*`@`````*0@`````*@@`````*P@`````+`@`````
M+0@`````+@@`````+P@`````,`@`````,0@`````,@@`````,P@`````-`@`
M````-0@`````-@@`````-P@`````_`8`````_08`````_@8`````_P8`````
M``<``````0<``````@<``````P<`````!`<`````!0<`````!@<`````!P<`
M````"`<`````"0<`````"@<`````"P<`````#`<`````#0<`````#@<`````
M#P<`````$`<`````$0<`````$@<`````$P<`````P/L8I@``%`<`````%0<`
M````%@<`````%P<`````&`<`````&0<`````&@<`````&P<`````'`<`````
M'0<`````'@<`````'P<`````(`<`````(0<`````(@<`````(P<`````)`<`
M````)0<`````)@<`````)P<`````*`<`````*0<`````*@<`````+PL`````
M,`L`````,0L`````,@L`````,PL`````-`L`````-0L`````-@L`````*P<`
M````+`<`````+0<`````+@<`````+P<`````,`<`````,0<`````,@<`````
M,P<`````-`<`````-0<`````-@<`````-P<`````.`<`````.0<`````.@<`
M````.P<`````/`<`````/0<`````/@<`````/P<`````0`<`````00<`````
M0@<`````0P<`````1`<`````10<`````1@<`````1P<`````2`<`````20<`
M````2@<`````2P<`````3`<`````30<`````3@<`````3P<`````4`<`````
M40<`````4@<`````4P<`````5`<`````50<`````5@<`````5P<`````6`<`
M````60<`````6@<`````6P<`````7`<`````70<`````7@<`````7P<`````
M*PT`````+`T`````+0T`````8`<`````80<`````8@<`````8P<`````9`<`
M````90<`````9@<`````9P<`````:`<`````:0<`````:@<`````:P<`````
M;`<`````;0<`````P/M^I@``P/M_I@``;@<`````;P<`````<`<`````<0<`
M````<@<`````<P<`````=`<`````=0<`````=@<`````=P<`````*0L`````
M*@L`````*PL`````+`L`````+0L`````+@L`````>`<`````>0<`````P/N2
MI@``P/N3I@``P/N4I@``P/N5I@``P/N6I@``P/N7I@``P/N8I@``P/N9I@``
MP/N:I@``P/N;I@``P/N<I@``P/N=I@``P/N>I@``P/N?I@``>@<`````>P<`
M````P/NBI@``P/NCI@``P/NDI@``P/NEI@``P/NFI@``P/NGI@``P/NHI@``
MP/NII@``P/NJI@``P/NKI@``P/NLI@``P/NMI@``P/NNI@``P/NOI@``P/NP
MI@``P/NQI@``P/NRI@``P/NSI@``P/NTI@``P/NUI@``P/NVI@``P/NWI@``
MP/NXI@``P/NYI@``P/NZI@``P/N[I@``P/N\I@``P/N]I@``P/N^I@``P/N_
MI@``P/O`I@``P/O!I@``P/O"I@``P/O#I@``P/O$I@``P/O%I@``P/O&I@``
MP/O'I@``P/O(I@``P/O)I@``P/O*I@``P/O+I@``P/O,I@``P/O-I@``P/O.
MI@``P/O/I@``P/O0I@``P/O1I@``P/O2I@``P/O3I@``P/O4I@``P/O5I@``
MP/O6I@``P/O7I@``P/O8I@``P/O9I@``P/O:I@``P/O;I@``P/O<I@``P/O=
MI@``P/O>I@``P/O?I@``P/O@I@``P/OAI@``P/OBI@``P/OCI@``P/ODI@``
MP/OEI@``P/OFI@``P/OGI@``P/OHI@``P/OII@``P/OJI@``P/OKI@``P/OL
MI@``P/OMI@``P/ONI@``P/OOI@``P/OPI@``P/OQI@``P/ORI@``P/OSI@``
MP/OTI@``P/OUI@``P/OVI@``P/OWI@``P/OXI@``P/OYI@``P/OZI@``P/O[
MI@``P/O\I@``P/O]I@``P/O^I@``P/O_I@``_`4``/T%``#^!0``_P4````&
M```!!@```@8```,&```$!@``!08```8&```'!@``"`8```D&```*!@``"P8`
M``P&```-!@``#@8```\&```0!@``$08``!(&```3!@``%`8``!4&```6!@``
M%P8``!@&```9!@``&@8``!L&```<!@``'08``!X&```?!@``(`8``"$&```B
M!@``(P8``"0&```E!@``)@8``"<&```H!@``*08``"H&```K!@``+`8``"T&
M```N!@``+P8``#`&```Q!@``,@8``#,&```T!@``-08``#8&```W!@``.`8`
M`#D&```Z!@``.P8``#P&```]!@``/@8``#\&``!`!@``008``$(&``!#!@``
M1`8``$4&``!&!@``1P8``$@&``!)!@``2@8``$L&``!,!@``308``$X&``!/
M!@``4`8``%$&``!2!@``4P8``%0&``!5!@``5@8``%<&``!8!@``608``%H&
M``!;!@``7`8``%T&``!>!@``7P8``&`&``!A!@``8@8``&,&``!D!@``908`
M`&8&``!G!@``:`8``&D&``!J!@``:P8``&P&``!M!@``;@8``&\&``!P!@``
M<08``'(&``!S!@``=`8``'4&``!V!@``=P8``'@&``!Y!@``>@8``'L&``!\
M!@``?08``'X&``!_!@``@`8``($&``""!@``@P8``(0&``"%!@``A@8``(<&
M``"(!@``B08``(H&``"+!@``C`8``(T&``".!@``CP8``)`&``"1!@``D@8`
M`),&``"4!@``E08``)8&``"7!@``F`8``)D&``":!@``FP8``)P&``"=!@``
MG@8``)\&``"@!@``H08``*(&``"C!@``I`8``*4&``"F!@``IP8``*@&``"I
M!@``J@8``*L&``"L!@``K08``*X&``"O!@``L`8``+$&``"R!@``LP8``+0&
M``"U!@``M@8``+<&``"X!@``N08``+H&``"[!@``O`8``+T&``"^!@``OP8`
M`,`&``#!!@``P@8``,,&``#$!@``Q08``,8&``#'!@``R`8``,D&``#*!@``
MRP8``,P&``#-!@``S@8``,\&``#0!@``T08``-(&``#3!@``U`8``-4&``#6
M!@``UP8``-@&``#9!@``V@8``-L&``#<!@``W08``-X&``#?!@``X`8``.$&
M``#B!@``XP8``.0&``#E!@``Y@8``.<&``#H!@``Z08``.H&``#K!@``[`8`
M`.T&``#N!@``[P8``/`&``#Q!@``\@8``/,&``#T!@``]08``/8&``#W!@``
M^`8``/D&``#Z!@``^P8``,H%``````````#+!0``````````S`4`````````
M`,T%``````````#.!0``````````SP4``````````-`%``````````#1!0``
M````````T@4``````````-,%``````````#4!0``````````U04`````````
M`-8%``````````#7!0``````````V`4``````````-D%``````````#:!0``
M````````VP4``````````-P%``````````#=!0``````````W@4`````````
M`-\%``````````#@!0``````````X04``````````.(%``````````#C!0``
M````````Y`4``````````.4%``````````#F!0``````````YP4`````````
M`.@%``````````#I!0``````````Z@4``````````.L%``````````#L!0``
M````````[04``````````.X%``````````#O!0``````````\`4`````````
M`,#[)Z0```````#`^RBD````````P/LII````````,#[*J0```````#`^RND
M````````P/LLI````````,#[+:0```````#`^RZD````````P/LOI```````
M`,#[,*0```````#`^S&D````````P/LRI````````,#[,Z0```````#`^S2D
M````````P/LUI````````,#[-J0```````#`^S>D````````P/LXI```````
M`,#[.:0```````#`^SJD````````P/L[I````````,#[/*0```````#`^SVD
M````````P/L^I````````,#[/Z0```````#Q!0``````````\@4`````````
M`/,%``````````#T!0``````````]04``````````/8%``````````#W!0``
M````````^`4``````````/D%``````````#Z!0``````````^P4`````````
M`,#[2Z0```````#`^TRD````````P/M-I````````,#[3J0```````#`^T^D
M````````P/M0I````````,#[4:0```````#`^U*D````````P/M3I```````
M`,#[5*0```````#`^U6D````````P/M6I````````,#[5Z0```````#`^UBD
M````````P/M9I````````,#[6J0```````#`^UND````````P/M<I```````
M`,#[7:0```````#`^UZD````````P/M?I````````"H.```````````K#@``
M````````+`X``````````"T.```````````N#@``````````+PX`````````
M`#`.```````````Q#@``````````,@X``````````"H.*0X````````J#BH.
M````````*@XK#@```````"H.+`X````````J#BT.````````*@XN#@``````
M`"H.+PX````````J#C`.````````*@XQ#@```````"H.,@X````````K#BD.
M````````B`(J#HD"`````(@"*PZ)`@````"(`BP.B0(`````B`(M#HD"````
M`(@"+@Z)`@````"(`B\.B0(`````B`(P#HD"`````(@",0Z)`@````"(`C(.
MB0(`````B`(J#BD.B0(``(@"*@XJ#HD"``"(`BH.*PZ)`@``B`(J#BP.B0(`
M`(@"*@XM#HD"``"(`BH.+@Z)`@``B`(J#B\.B0(``(@"*@XP#HD"``"(`BH.
M,0Z)`@``B`(J#C(.B0(``(@"*PXI#HD"```J#ET"````````*PY=`@``````
M`"P.70(````````M#ET"````````+@Y=`@```````"\.70(````````P#ET"
M````````,0Y=`@```````#(.70(````````J#BD.70(`````*@XJ#ET"````
M`"H.*PY=`@`````J#BP.70(`````*@XM#ET"`````"H.+@Y=`@`````J#B\.
M70(`````*@XP#ET"`````"H.,0Y=`@`````J#C(.70(`````*PXI#ET"````
M`(@",PZ)`@````"(`DH.B0(`````B`)@#HD"`````(@";0Z)`@````"(`HL.
MB0(`````B`*Y#HD"`````(@"P0Z)`@````"(`N$.B0(`````B`+[#HD"````
M`(@"$`^)`@````"(`B$/B0(`````B`(N#XD"`````(@"6P^)`@````"(`F0/
MB0(`````B`*"#XD"`````(@"IP^)`@````"(`K0/B0(`````B`+`#XD"````
M`(@"Z@^)`@````"(`@(0B0(`````B`(?$(D"`````(@"1!")`@````"(`E$0
MB0(`````B`):$(D"`````(@"7A")`@````"(`FH0B0(`````,PX`````````
M`$H.``````````!@#@``````````;0X``````````(L.``````````"Y#@``
M````````P0X``````````.$.``````````#[#@``````````$`\`````````
M`"$/```````````N#P``````````6P\``````````&0/``````````""#P``
M````````IP\``````````+0/``````````#`#P``````````Z@\`````````
M``(0```````````?$```````````1!```````````%$0``````````!:$```
M````````7A```````````&H0```````````S#@``````````2@X`````````
M`&`.``````````!M#@``````````BPX``````````+D.``````````#!#@``
M````````X0X``````````/L.```````````0#P``````````(0\`````````
M`"X/``````````!;#P``````````9`\``````````((/``````````"G#P``
M````````M`\``````````,`/``````````#J#P```````````A``````````
M`!\0``````````!$$```````````41```````````%H0``````````!>$```
M````````:A```````````"D.```````````J#BH.````````*@XK#@``````
M`"H.+`X````````J#BT.````````*@XN#@```````"H.+PX````````J#C`.
M````````*@XQ#@```````"H.,@X````````K#BD.````````*@X`````````
M`"L.```````````L#@``````````+0X``````````"X.```````````O#@``
M````````,`X``````````#$.```````````R#@``````````*@XI#@``````
M`"D.``````````#[!`````#\!`````#]!`````#^!`````#_!```````!0``
M```!!0`````"!0`````#!0`````$!0`````%!0`````&!0`````'!0`````(
M!0`````)!0`````*!0`````+!0`````,!0`````-!0`````.!0`````/!0``
M```0!0`````1!0`````2!0`````3!0`````4!0`````5!0`````6!0`````7
M!0`````8!0`````9!0`````:!0`````;!0`````<!0`````=!0`````>!0``
M```?!0`````@!0`````A!0`````B!0`````C!0````"N`@````"O`@`````D
M!0`````E!0`````F!0`````G!0`````H!0`````I!0`````J!0`````K!0``
M```L!0`````M!0`````N!0`````O!0`````P!0`````Q!0`````R!0`````S
M!0`````T!0`````U!0`````V!0`````W!0`````X!0`````Y!0`````Z!0``
M```[!0`````\!0`````]!0`````^!0`````_!0````!`!0````!!!0````!"
M!0````!#!0````!$!0````!%!0````!&!0````!'!0````!(!0````!)!0``
M``!*!0````!+!0````!,!0````!-!0````!.!0````!/!0````!0!0````!1
M!0````!2!0````!3!0````!4!0````!5!0````!6!0````!7!0````!8!0``
M``!9!0````!:!0````!;!0````!<!0````!=!0````!>!0````!?!0````!@
M!0````!A!0````!B!0````!C!0````!D!0````!E!0````!F!0````!G!0``
M``!H!0````!I!0````!J!0````!K!0````!L!0````!M!0````!N!0````!O
M!0````!P!0````!Q!0````!R!0````!S!0````!T!0````!U!0````!V!0``
M``!W!0````!X!0````!Y!0````!Z!0````![!0````!\!0````!]!0````!^
M!0````!_!0````"`!0````"!!0````""!0````"#!0````"$!0````"%!0``
M``"&!0````"'!0````"(!0````")!0````"*!0````"+!0````",!0````"-
M!0````".!0````"/!0````"0!0````"1!0````"2!0````"3!0````"4!0``
M``"5!0````"6!0````"7!0````"8!0````"9!0````":!0````";!0````"<
M!0````"=!0````">!0````"?!0````"@!0````"A!0````"B!0````"C!0``
M``"D!0````"E!0````"F!0````"G!0````"H!0````"I!0````"J!0````"K
M!0````"L!0````"M!0````"N!0````"O!0````"P!0````"Q!0````"R!0``
M``"S!0````"T!0````"U!0````"V!0````"W!0````"X!0````"Y!0````"Z
M!0````"[!0````"\!0````"]!0````"^!0````"_!0````#`!0````#!!0``
M``#"!0````##!0````#$!0````#%!0````#&!0````#'!0````#(!0````#)
M!0````#`^]&C``#`^]*C``#`^].C``#`^]2C``#`^]6C``#`^]:C``#`^]>C
M``#`^]BC``#`^]FC``#`^]JC``#`^]NC``#`^]RC``#`^]VC``#`^]ZC``#`
M^]^C``#`^^"C``#`^^&C``#`^^*C``#`^^.C``#`^^2C``#`^^6C``#`^^:C
M``#`^^>C``#`^^BC``#`^^FC``#`^^JC``#`^^NC``#`^^RC``#`^^VC``#`
M^^ZC``#`^^^C``#`^_"C``#`^_&C``#`^_*C``#`^_.C``#`^_2C``#`^_6C
M``#`^_:C``#`^_>C``#`^_BC``#`^_FC``#`^_JC``#`^_NC``#`^_RC``#`
M^_VC``#`^_ZC``#`^_^C```8!````````!D$````````&@0````````;!```
M`````!L$````````'`0````````=!````````!X$````````'P0````````?
M!````````"`$````````(00````````A!````````"($````````)`0`````
M```E!````````"8$````````)P0````````T!````````#4$````````-@0`
M```````W!````````#@$````````.00````````Z!````````#L$````````
M/`0````````]!````````#X$````````/P0```````!`!````````$$$````
M````0@0```````!#!````````$0$````````100```````!%!````````$8$
M````````1@0```````!'!````````$@$````````200```````!*!```````
M`$L$````````2P1+!`````!+!$L$2P0``$P$````````3`1,!`````!,!$P$
M3`0``$T$````````3@0```````!/!````````%`$````````400```````!2
M!````````%,$````````5`0```````!5!````````%8$````````5P0`````
M``!8!````````%D$````````6@0```````!;!````````%P$````````6`0`
M``````!=!````````%X$````````7@0```````!?!````````&`$````````
M7P0```````!A!````````&$$````````8@0```````!C!````````&0$````
M````900```````!F!````````&<$````````:`0```````!I!````````&H$
M````````:P0```````!L!````````&T$````````;@0```````!O!```````
M`'`$````````<00```````!R!````````',$````````=`0```````!U!```
M`````'8$````````=P0````````M!````````'@$````````>`0```````!Y
M!````````'H$````````>P0```````!\!````````'T$````````?@0`````
M``!_!````````(`$````````@00```````""!````````&4$````````+`0`
M```````N!````````'H$````````>P0```````"#!````````(0$````````
M@P0```````"$!````````(4$````````A@0```````"%!````````(8$````
M````AP0```````"(!````````(D$````````B@0```````"+!````````(P$
M````````AP0```````"(!````````(T$````````C@0```````"-!```````
M`(X$````````CP0```````"0!````````(\$````````D`0```````"1!```
M`````)($````````DP0```````"4!````````)4$````````E@0```````"7
M!````````)@$````````F00```````":!````````)L$````````G`0`````
M``"=!````````)X$````````GP0```````"@!````````*$$````````H@0`
M``````"C!````````*0$````````I00```````"F!````````*<$````````
MJ`0```````"I!````````*H$````````JP0```````"L!````````*T$````
M````K@0```````"O!````````+`$````````L00```````"R!````````*D$
M````````KP0```````"P!````````+($````````LP0```````"T!```````
M`+4$````````M@0```````"W!````````+@$````````N00```````"Z!```
M`````+L$````````O`0```````"]!````````+X$````````OP0```````#`
M!````````,$$````````P@0```````##!````````,0$````````Q00`````
M``#&!````````,<$````````R`0```````#)!````````,H$````````RP0`
M``````#,!````````,T$````````S@0```````#/!````````-`$````````
MT00```````#2!````````-,$````````U`0```````#5!````````-8$````
M````UP0```````#8!````````-D$````````V@0```````#;!````````-P$
M````````W00```````#>!````````-\$````````X`0```````#A!```````
M`.($````````B00```````"*!````````)@$````````F00```````#C!```
M`````.0$````````Y00```````#F!````````.<$````````Z`0```````"U
M!````````+8$````````MP0```````"X!````````.D$````````Z@0`````
M``#K!````````.P$````````[00```````#N!````````.\$````````\`0`
M``````#Q!````````/($````````\P0```````#T!````````/4$````````
M]@0```````#W!````````/@$````````^00```````#Z!````````#,.S`)@
M#@`````S#LP"Z@\`````8`X``````````$H#8`X```````";`P``````````
M8`[,`H(/`````&`.S`(?$`````"8#@``````````G`,``````````$H#N0X`
M``````#!#@``````````X0X``````````.$.``````````#A#@``````````
MX0X``````````.T.``````````#[#@``````````^PX``````````"X/````
M```````N#P``````````G0,``````````&0/``````````!D#X(/````````
MG@,``````````)\#``````````"G#P``````````M`\``````````,`/````
M``````#`#P``````````P`\``````````*`#``````````"A`P``````````
MZ@];#P````````(0BPXN#P`````"$%L/````````H@,``````````&H0````
M``````"C`P``````````"1$``````````*0#``````````!J$```````````
MI0,``````````"$/```````````S#@``````````2@X``````````&`.````
M``````"F`P``````````BPX``````````(L.``````````"Y#@``````````
MIP,``````````%L/``````````""#P``````````,1,``````````#(3````
M```````S$P``````````-!,``````````/L.``````````"H`P``````````
MN0XS#EH0`````,#[/*$```````#J$```````````ZA```````````/P0````
M```````G!```````````J0,``````````*H#``````````"K`P``````````
MK`,``````````&T.``````````!M#@``````````BPX``````````/L.````
M```````0#P``````````K0,``````````-`"``````````#`^TRA````````
MP/M-H0```````,#[3J$```````#`^T^A````````P/M0H0```````,#[4:$`
M``````#`^U*A````````*@[-`BP.`````"L.S0(L#@`````J#LT"+@X`````
M*P[-`BX.`````"P.S0(N#@`````M#LT"+@X`````*@[-`B\.`````"X.S0(O
M#@`````J#LT",0X`````+`[-`C$.`````"X.S0(Q#@`````P#LT",0X`````
M*@[-`@```````/L.``````````#[#OL.````````^P[[#OL.`````/L.1!``
M``````!$$```````````1!#[#@```````$00^P[[#@````!$$/L.^P[[#@``
M^PY:$````````%H0``````````!:$/L.````````6A#[#OL.`````"X/````
M``````!@#@``````````;0X``````````%L/``````````#[#@``````````
M^P[[#@```````/L.^P[[#@````#[#D00````````1!```````````$00^PX`
M``````!$$/L.^PX`````1!#[#OL.^PX``/L.6A````````!:$```````````
M6A#[#@```````%H0^P[[#@`````N#P``````````8`X``````````&T.````
M``````!;#P``````````UPT``````````-@-``````````#9#0``````````
MV@T``````````,#[A*$```````#`^X6A````````P/N&H0```````,#[AZ$`
M``````#`^XBA````````P/N)H0```````,#[BJ$```````#`^XNA````````
MP/N,H0```````,#[C:$```````#`^XZA````````P/N/H0```````*X#````
M``````"P`P``````````KP,``````````+$#``````````"R`P``````````
MLP,``````````+0#``````````"U`P``````````M@,``````````+<#````
M``````"N`P``````````KP,``````````+@#``````````"Y`P``````````
MN@,``````````+L#``````````"\`P``````````O0,``````````+X#````
M``````"_`P``````````P`,``````````,$#``````````#"`P``````````
MPP,``````````,0#``````````#%`P``````````Q@,``````````,<#````
M``````#(`P``````````R0,``````````+(#``````````#*`P``````````
MRP,``````````,P#``````````#-`P``````````S@,``````````,\#````
M``````#0`P``````````T0,``````````-(#``````````#3`P``````````
MU`,``````````-4#``````````#6`P``````````UP,``````````-@#````
M``````#9`P``````````V@,``````````-L#``````````#<`P``````````
MW0,``````````-X#``````````#?`P``````````X`,``````````.$#````
M``````#B`P``````````XP,``````````.0#``````````#E`P``````````
MY@,``````````.<#``````````#H`P``````````[`,``````````.H#````
M``````#H`P``````````Z0,``````````.H#``````````#K`P``````````
M[`,``````````.T#``````````#N`P``````````[P,``````````/`#````
M``````#Q`P``````````\@,``````````/,#``````````#T`P``````````
M]0,``````````/8#``````````#W`P``````````^`,``````````/D#````
M``````#Z`P``````````^P,``````````/P#``````````#]`P``````````
M_@,``````````/\#````````````!````````````00```````````($````
M```````#!```````````!`0```````````4$```````````&!```````````
M!P0```````````@$```````````)!```````````"@0```````````L$````
M```````,!```````````#00```````````X$```````````/!```````````
M$`0``````````!$$```````````2!```````````$P0``````````!0$````
M```````5!```````````%@0``````````!<$```````````)`@``````````
M"0(```````````D"```````````)`@``````````"0(```````````D"````
M```````)`@``````````"0(```````````D"```````````)`@``````````
M"0(`````````````````````````````````````````````````````````
M````````````````````)0(``````````"4"```````````F`@``````````
M)P(``````````"@"```````````I`@``````````,@0``````````!P"````
M``````!X`@``````````>0(``````````'H"``````````![`@``````````
M?P(``````````(`"``````````"!`@``````````@@(``````````-@"````
M``````#9`@``````````V@(``````````-L"``````````!=`@``````````
M70)=`@```````%T"70)=`@````#<`@``````````!P(```````````@"````
M````````````````````````````````````````````````````````````
M``````````````D"``````````#5`@``````````U@(``````````.`"````
M``````#@`N`"````````X`+@`N`"`````.$"``````````#A`N$"````````
MX0+A`N$"`````.0"``````````!\`@``````````?0(``````````.4"````
M``````!1`E$"````````7`(``````````!$"``````````#F`@``````````
MZ`(``````````.H"``````````#K`@``````````W0(``````````,T"````
M``````"4`@``````````E0(``````````%4"50(```````!5`E$"````````
M40)5`@```````-$"``````````#$`@``````````W@(``````````-\"````
M``````#)`@``````````/`(``````````.D"``````````#*`@``````````
MUP(``````````"H"``````````#G`@``````````P/M5H````````,#[5J``
M``````#@`N`"X`+@`@``P/M8H````````,#[6:````````#`^UJ@````````
MP/M;H````````,#[7*````````#`^UV@````````P/M>H`````````D"````
M````````````````````````````````````````````````````````````
MP/MDH````````,#[9:````````#`^V:@````````P/MGH````````,#[:*``
M``````#`^VF@````````````````````````````````````````````````
M````````````````````````````````````````*0X``````````/L.````
M``````#`^W*@````````P/MSH````````"T.```````````N#@``````````
M+PX``````````#`.```````````Q#@``````````,@X``````````"@$````
M```````T!```````````+00``````````(@"``````````")`@``````````
M9`\``````````"D.```````````J#@``````````*PX``````````"P.````
M```````M#@``````````+@X``````````"\.```````````P#@``````````
M,0X``````````#(.```````````H!```````````-`0``````````"T$````
M``````"(`@``````````B0(``````````,#[CZ````````#`^Y"@````````
MP/N1H````````,#[DJ````````#`^Y.@````````P/N4H````````,#[E:``
M``````#`^Y:@````````P/N7H````````,#[F*````````#`^YF@````````
MP/N:H````````,#[FZ````````#`^YR@````````P/N=H````````,#[GJ``
M``````#`^Y^@````````&`X``````````!D.```````````:#@``````````
M&PX``````````!P.```````````=#@``````````'@X``````````!\.````
M``````#`#^H/````````(`X``````````"$.```````````B#@``````````
M(PX``````````"0.```````````E#@``````````)@X``````````"<.````
M```````H#@``````````P/NRH````````,#[LZ````````#`^[2@````````
MP/NUH````````,#[MJ````````#`^[>@````````P/NXH````````,#[N:``
M``````#`^[J@````````P/N[H````````,#[O*````````#`^[V@````````
MP/N^H````````,#[OZ````````#`^\"@````````P/O!H````````,#[PJ``
M``````#`^\.@````````P/O$H````````,#[Q:````````#`^\:@````````
MP/O'H````````,#[R*````````#`^\F@````````P/O*H````````,#[RZ``
M``````#`^\R@````````P/O-H````````,#[SJ````````#`^\^@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MP/OKH````````,#[[*````````#`^^V@````````P/ONH````````,#[[Z``
M``````#`^_"@````````P/OQH````````,#[\J````````#`^_.@````````
MP/OTH````````,#[]:````````#`^_:@````````P/OWH````````,#[^*``
M``````#`^_F@````````P/OZH````````,#[^Z````````#`^_R@````````
MP/O]H````````,#[_J````````#`^_^@````````Z!``````Z!``````Z!``
M````Z!``````Z!``````Z!``````Z!``````Z!``````Z!``````Z!``````
MZ!``````Z!``````Z!``````Z!``````Z!``````Z!``````[1``````[1``
M````[1``````[1``````[1``````[1``````P/L6GP``P/L7GP``[1``````
M[1``````[1``````[1``````[1``````[1``````P/L>GP``P/L?GP``\1``
M````\1``````\1``````\1``````\1``````\1``````\1``````\1``````
M\1``````\1``````\1``````\1``````\1``````\1``````\1``````\1``
M````\Q``````\Q``````\Q``````\Q``````\Q``````\Q``````\Q``````
M\Q``````\Q``````\Q``````\Q``````\Q``````\Q``````\Q``````\Q``
M````\Q``````^Q``````^Q``````^Q``````^Q``````^Q``````^Q``````
MP/M&GP``P/M'GP``^Q``````^Q``````^Q``````^Q``````^Q``````^Q``
M````P/M.GP``P/M/GP``!!$`````!!$`````!!$`````!!$`````!!$`````
M!!$`````!!$`````!!$`````P/M8GP``!!$`````P/M:GP``!!$`````P/M<
MGP``!!$`````P/M>GP``!!$`````"1$`````"1$`````"1$`````"1$`````
M"1$`````"1$`````"1$`````"1$`````"1$`````"1$`````"1$`````"1$`
M````"1$`````"1$`````"1$`````"1$`````Z!``````Z!``````[1``````
M[1``````\1``````\1``````\Q``````\Q``````^Q``````^Q``````!!$`
M````!!$`````"1$`````"1$`````P/M^GP``P/M_GP``Z!``````Z!``````
MZ!``````Z!``````Z!``````Z!``````Z!``````Z!``````Z!``````Z!``
M````Z!``````Z!``````Z!``````Z!``````Z!``````Z!``````\1``````
M\1``````\1``````\1``````\1``````\1``````\1``````\1``````\1``
M````\1``````\1``````\1``````\1``````\1``````\1``````\1``````
M"1$`````"1$`````"1$`````"1$`````"1$`````"1$`````"1$`````"1$`
M````"1$`````"1$`````"1$`````"1$`````"1$`````"1$`````"1$`````
M"1$`````Z!``````Z!``````Z!``````Z!``````Z!``````P/NUGP``Z!``
M````Z!``````Z!``````Z!``````Z!``````Z!``````Z!``````%P(`````
M\Q``````%P(`````'0(`````%`(`````\1``````\1``````\1``````P/O%
MGP``\1``````\1``````[1``````[1``````\1``````\1``````\1``````
M%P(`````%P(`````%P(`````\Q``````\Q``````\Q``````\Q``````P/O4
MGP``P/O5GP``\Q``````\Q``````\Q``````\Q``````\Q``````\Q``````
MP/O<GP``&`(`````&`(`````&`(`````!!$`````!!$`````!!$`````!!$`
M`````!$``````!$`````!!$`````!!$`````!!$`````!!$`````!!$`````
M!!$``````!$`````%`(`````%`(`````#`(`````P/OPGP``P/OQGP``"1$`
M````"1$`````"1$`````P/OUGP``"1$`````"1$`````^Q``````^Q``````
M"1$`````"1$`````"1$`````#0(`````&`(`````P/O_GP``,PX`````,PX`
M````2@X`````2@X`````2@X`````2@X`````2@X`````2@X`````8`X`````
M8`X`````;0X`````;0X`````;0X`````;0X`````;0X`````;0X`````;0X`
M````;0X`````;0X`````;0X`````BPX`````BPX`````BPX`````BPX`````
MBPX`````BPX`````BPX`````BPX`````BPX`````BPX`````N0X`````N0X`
M````P0X`````P0X`````X0X`````X0X`````X0X`````X0X`````X0X`````
MX0X`````X0X`````X0X`````X0X`````X0X`````^PX`````^PX`````^PX`
M````^PX`````(0\`````(0\`````(0\`````(0\`````(0\`````(0\`````
M+@\`````+@\`````+@\`````+@\`````+@\`````+@\`````+@\`````+@\`
M````6P\`````6P\`````6P\`````6P\`````6P\`````6P\`````9`\`````
M9`\`````9`\`````9`\`````9`\`````9`\`````9`\`````9`\`````@@\`
M````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`````
MIP\`````IP\`````IP\`````IP\`````P`\`````P`\`````P`\`````P`\`
M````P`\`````P`\`````P`\`````P`\`````Z@\`````Z@\`````Z@\`````
MZ@\`````Z@\`````Z@\`````Z@\`````Z@\`````Z@\`````Z@\``````A``
M`````A```````A```````A```````A```````A```````A```````A``````
M'Q``````'Q``````'Q``````'Q``````'Q``````'Q``````'Q``````'Q``
M````'Q``````'Q``````1!``````1!``````1!``````1!``````41``````
M41``````41``````41``````41``````41``````41``````41``````41``
M````41``````6A``````6A``````6A``````6A``````7A``````7A``````
M:A``````:A``````:A``````:A``````:A``````:A``````X0X``````A``
M````41``````7A``````,PZS$```Z@\`````P/N<G@``P/N=G@``P/N>G@``
MP/N?G@``,PX`````,PX`````,PX`````,PX`````,PX`````,PX`````,PX`
M````,PX`````,PX`````,PX`````,PX`````,PX`````,PX`````,PX`````
M,PX`````,PX`````,PX`````,PX`````,PX`````,PX`````,PX`````,PX`
M````,PX`````,PX`````BPX`````BPX`````BPX`````BPX`````BPX`````
MBPX`````BPX`````BPX`````BPX`````BPX`````BPX`````BPX`````BPX`
M````BPX`````BPX`````BPX`````^PX`````^PX`````^PX`````^PX`````
M@@\`````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`
M````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`````
M@@\`````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`
M````@@\`````'Q``````'Q``````'Q``````'Q``````'Q``````'Q``````
M'Q``````'Q``````'Q``````'Q``````'Q``````'Q``````'Q``````'Q``
M````7A``````7A``````7A``````7A``````7A``````7A``````7A``````
M7A``````P/OZG@``P/O[G@``P/O\G@``P/O]G@``P/O^G@``P/O_G@``-PX`
M````/`X`````/0X`````5PX`````9`X`````<0X`````B@X`````CPX`````
MJ`X`````!P\`````%`\`````)0\`````.@\`````7P\`````;0\`````A@\`
M````E@\`````AP\`````EP\`````D0\`````C`\`````I@\`````F`\`````
MF0\`````JP\`````R`\`````S0\`````!A``````(Q``````)!``````)1``
M````.Q``````2!``````51``````;A``````@Q``````NA``````NQ``````
MZQ``````]Q``````_1```````1$`````"!$`````M!$`````,PX`````.`X`
M````2@X`````5@X`````;0X`````BPX`````D`X`````P0X`````X0X`````
M^PX`````$`\`````(0\`````+@\`````6P\`````9`\`````;`\`````@@\`
M````H@\`````IP\`````P`\``````A``````'Q``````41``````,PX`````
M/@X`````0@X`````/0X`````2@X`````;0X`````BPX`````E`X`````F`X`
M````J`X`````P0X`````!P\`````(0\`````6P\`````?@\`````@@\`````
MD@\`````F`\`````F0\`````IP\``````A``````'Q``````)!``````-Q``
M````1!``````NQ``````Z1``````ZA``````[!``````!1$`````!A$`````
M^PX`````P`\`````'Q``````1!``````Z1``````ZA```````!$`````!1$`
M````!A$`````)A``````P/MLG0``P/MMG0``P/MNG0``P/MOG0``P/MPG0``
MP/MQG0``P/MRG0``P/MSG0``P/MTG0``P/MUG0``P/MVG0``P/MWG0``P/MX
MG0``P/MYG0``P/MZG0``P/M[G0``P/M\G0``P/M]G0``P/M^G0``P/M_G0``
MP/N`G0``P/N!G0``P/N"G0``P/N#G0``P/N$G0``P/N%G0``P/N&G0``P/N'
MG0``P/N(G0``P/N)G0``P/N*G0``P/N+G0``P/N,G0``P/N-G0``P/N.G0``
MP/N/G0``P/N0G0``P/N1G0``P/N2G0``P/N3G0``P/N4G0``P/N5G0``P/N6
MG0``P/N7G0``P/N8G0``P/N9G0``P/N:G0``P/N;G0``P/N<G0``P/N=G0``
MP/N>G0``P/N?G0``P/N@G0``P/NAG0``P/NBG0``P/NCG0``P/NDG0``P/NE
MG0``P/NFG0``P/NGG0``P/NHG0``P/NIG0``P/NJG0``P/NKG0``P/NLG0``
MP/NMG0``P/NNG0``P/NOG0``P/NPG0``P/NQG0``P/NRG0``P/NSG0``P/NT
MG0``P/NUG0``P/NVG0``P/NWG0``P/NXG0``P/NYG0``P/NZG0``P/N[G0``
MP/N\G0``P/N]G0``P/N^G0``P/N_G0``P/O`G0``P/O!G0``P/O"G0``P/O#
MG0``P/O$G0``P/O%G0``P/O&G0``P/O'G0``P/O(G0``P/O)G0``P/O*G0``
MP/O+G0``P/O,G0``P/O-G0``P/O.G0``P/O/G0``P/O0G0``P/O1G0``P/O2
MG0``P/O3G0``P/O4G0``P/O5G0``P/O6G0``P/O7G0``P/O8G0``P/O9G0``
MP/O:G0``P/O;G0``P/O<G0``P/O=G0``P/O>G0``P/O?G0``P/O@G0``P/OA
MG0``P/OBG0``P/OCG0``P/ODG0``P/OEG0``P/OFG0``P/OGG0``P/OHG0``
MP/OIG0``P/OJG0``P/OKG0``P/OLG0``P/OMG0``P/ONG0``P/OOG0``P/OP
MG0``P/OQG0``P/ORG0``P/OSG0``P/OTG0``P/OUG0``P/OVG0``P/OWG0``
MP/OXG0``P/OYG0``P/OZG0``P/O[G0``P/O\G0``P/O]G0``P/O^G0``P/O_
MG0``L!@`````L1@`````LA@`````LQ@`````M!@`````M1@`````MA@`````
MMQ@`````N!@`````N1@`````NA@`````NQ@`````O!@`````O1@`````OA@`
M````OQ@`````P!@`````P1@`````PA@`````PQ@`````Q!@`````Q1@`````
MQA@`````QQ@`````R!@`````R1@`````RA@`````RQ@`````S!@`````P/L=
MF0``P/L>F0``P/L?F0``S1@`````SA@`````SQ@`````T!@`````T1@`````
MTA@`````TQ@`````U!@`````U1@`````UA@`````UQ@`````V!@`````P/LL
MF0``P/LMF0``P/LNF0``P/LOF0``V1@`````VA@`````VQ@`````W!@`````
MW1@`````WA@`````WQ@`````X!@`````X1@`````````````````````````
M````P/L\F0``P/L]F0``P/L^F0``P/L_F0``#0,`````P/M!F0``P/M"F0``
MP/M#F0``5`(`````6P(`````*0X`````*@X`````*PX`````+`X`````+0X`
M````+@X`````+PX`````,`X`````,0X`````,@X`````M!D`````M1D`````
MMAD`````MQD`````N!D`````N1D`````NAD`````NQD`````O!D`````O1D`
M````OAD`````OQD`````P!D`````P1D`````PAD`````PQD`````Q!D`````
MQ1D`````QAD`````QQD`````R!D`````R1D`````RAD`````RQD`````S!D`
M````S1D`````SAD`````SQD`````T!D`````T1D`````P/MNF0``P/MOF0``
MTAD`````TQD`````U!D`````U1D`````UAD`````P/MUF0``P/MVF0``P/MW
MF0``P/MXF0``P/MYF0``P/MZF0``P/M[F0``P/M\F0``P/M]F0``P/M^F0``
MP/M_F0``P/N`F0``P/N!F0``P/N"F0``P/N#F0``P/N$F0``P/N%F0``P/N&
MF0``P/N'F0``P/N(F0``P/N)F0``P/N*F0``P/N+F0``P/N,F0``P/N-F0``
MP/N.F0``P/N/F0``P/N0F0``P/N1F0``P/N2F0``P/N3F0``P/N4F0``P/N5
MF0``P/N6F0``P/N7F0``P/N8F0``P/N9F0``P/N:F0``P/N;F0``P/N<F0``
MP/N=F0``P/N>F0``P/N?F0``P/N@F0``P/NAF0``P/NBF0``P/NCF0``P/ND
MF0``P/NEF0``P/NFF0``P/NGF0``P/NHF0``P/NIF0``P/NJF0``P/NKF0``
MP/NLF0``P/NMF0``P/NNF0``P/NOF0``P/NPF0``P/NQF0``P/NRF0``P/NS
MF0``P/NTF0``P/NUF0``P/NVF0``P/NWF0``P/NXF0``P/NYF0``P/NZF0``
MP/N[F0``P/N\F0``P/N]F0``P/N^F0``P/N_F0``P/O`F0``P/O!F0``P/O"
MF0``P/O#F0``P/O$F0``P/O%F0``P/O&F0``P/O'F0``P/O(F0``P/O)F0``
MP/O*F0``P/O+F0``P/O,F0``P/O-F0``P/O.F0``P/O/F0``P/O0F0``P/O1
MF0``P/O2F0``P/O3F0``P/O4F0``P/O5F0``P/O6F0``P/O7F0``P/O8F0``
MP/O9F0``P/O:F0``P/O;F0``P/O<F0``P/O=F0``P/O>F0``P/O?F0``>P,`
M````?`,`````?0,`````?@,`````?P,`````@`,`````@0,`````@@,`````
M@P,`````A`,`````A0,`````A@,`````AP,`````B`,`````B0,`````B@,`
M````BP,`````C`,`````C0,`````C@,`````CP,`````D`,`````D0,`````
MD@,`````DP,`````E`,`````E0,`````E@,`````EP,`````F`,`````F0,`
M````F@,`````^`(`````7@(`````-0(`````8P(`````2@(`````2P(`````
M(P(`````)`(`````-@(`````9`(`````^0(`````````````````````````
M````````````P/L/F```*0X`````*@X`````*PX`````+`X`````+0X`````
M+@X`````+PX`````,`X`````,0X`````,@X`````P/L:F```P/L;F```P/L<
MF```P/L=F```P/L>F```P/L?F```WQD`````X1D`````Y!D`````ZAD`````
M[!D`````[QD`````\1D`````]!D`````]1D`````]AD`````^QD`````_1D`
M`````!H``````AH`````!QH`````"1H`````"AH`````"QH`````$AH`````
M%1H`````&!H`````'1H`````(1H`````)!H`````)AH`````*!H`````*QH`
M````,!H`````,1H`````-!H`````.!H`````.QH`````/!H`````/1H`````
M/AH`````WAD`````XAD`````Y1D`````ZQD`````[1D`````\!D`````\AD`
M````]QD`````_!D`````_AD``````1H``````QH`````"!H`````$QH`````
M%AH`````&1H`````'AH`````,AH`````(AH`````)QH`````+!H`````-AH`
M````.1H`````/QH`````0!H`````&QH`````XQD`````YAD`````Z1D`````
M\QD`````[AD`````^!D`````+1H`````!!H`````!AH`````_QD`````#!H`
M````%!H`````%QH`````'QH`````*1H`````-QH`````.AH`````,QH`````
M-1H`````01H`````&AH`````(QH`````YQD`````+AH`````)1H`````*AH`
M````(!H`````P/MXF```P/MYF```P/MZF```P/M[F```P/M\F```P/M]F```
MP/M^F```P/M_F```UQD`````V!D`````V1D`````VAD`````VQD`````W!D`
M````W1D`````X!D`````Z!D`````+QH`````^1D`````'!H`````0AH`````
M1!H`````11H`````1QH`````2!H`````2QH`````31H`````3AH`````4!H`
M````4AH`````5!H`````51H`````21H`````4QH`````!1H`````^AD`````
M#1H`````#AH`````0QH`````1AH`````2AH`````3!H`````#QH`````41H`
M````$!H`````$1H`````5AH`````5QH`````3QH`````6!H`````P/NJF```
MP/NKF```P/NLF```P/NMF```P/NNF```P/NOF```P/NPF```P/NQF```P/NR
MF```P/NSF```P/NTF```P/NUF```P/NVF```P/NWF```P/NXF```P/NYF```
MP/NZF```P/N[F```P/N\F```P/N]F```P/N^F```P/N_F```P/O`F```P/O!
MF```P/O"F```P/O#F```P/O$F```P/O%F```P/O&F```P/O'F```P/O(F```
MP/O)F```P/O*F```P/O+F```P/O,F```P/O-F```P/O.F```P/O/F```P/O0
MF```P/O1F```P/O2F```P/O3F```P/O4F```P/O5F```P/O6F```P/O7F```
MP/O8F```P/O9F```P/O:F```P/O;F```P/O<F```P/O=F```P/O>F```P/O?
MF```P/O@F```P/OAF```P/OBF```P/OCF```P/ODF```P/OEF```P/OFF```
MP/OGF```P/OHF```P/OIF```P/OJF```P/OKF```P/OLF```P/OMF```P/ON
MF```P/OOF```P/OPF```P/OQF```P/ORF```P/OSF```P/OTF```P/OUF```
MP/OVF```P/OWF```P/OXF```P/OYF```P/OZF```P/O[F```P/O\F```P/O]
MF```P/O^F```P/O_F```XA@`````XQ@`````Y!@`````Y1@`````YA@`````
MYQ@`````Z!@`````Z1@`````ZA@`````ZQ@`````[!@`````[1@`````[A@`
M````P/L-EP``[Q@`````\!@`````\1@`````\A@`````\Q@`````]!@`````
M]1@`````P/L5EP``P/L6EP``P/L7EP``P/L8EP``P/L9EP``P/L:EP``P/L;
MEP``P/L<EP``P/L=EP``P/L>EP``P/L?EP``]A@`````]Q@`````^!@`````
M^1@`````^A@`````^Q@`````_!@`````_1@`````_A@`````_Q@``````!D`
M`````1D``````AD``````QD`````!!D`````!1D`````!AD`````!QD`````
M"!D`````"1D`````"AD`````:@(`````:P(`````P/LWEP``P/LXEP``P/LY
MEP``P/LZEP``P/L[EP``P/L\EP``P/L]EP``P/L^EP``P/L_EP``"QD`````
M#!D`````#1D`````#AD`````#QD`````$!D`````$1D`````$AD`````$QD`
M````%!D`````%1D`````%AD`````%QD`````&!D`````&1D`````&AD`````
M&QD`````'!D`````'1D`````'AD`````P/M4EP``P/M5EP``P/M6EP``P/M7
MEP``P/M8EP``P/M9EP``P/M:EP``P/M;EP``P/M<EP``P/M=EP``P/M>EP``
MP/M?EP``'QD`````(!D`````(1D`````(AD`````(QD`````)!D`````)1D`
M````)AD`````)QD`````*!D`````*1D`````*AD`````*QD`````P/MMEP``
M+!D`````+1D`````+AD`````P/MQEP``+QD`````,!D`````P/MTEP``P/MU
MEP``P/MVEP``P/MWEP``P/MXEP``P/MYEP``P/MZEP``P/M[EP``P/M\EP``
MP/M]EP``P/M^EP``P/M_EP``;!D`````;1D`````;AD`````;QD`````<!D`
M````<1D`````<AD`````<QD`````=!D`````=1D`````=AD`````=QD`````
M>!D`````>1D`````>AD`````>QD`````?!D`````?1D`````?AD`````?QD`
M````@!D`````@1D`````@AD`````@QD`````A!D`````A1D`````AAD`````
MAQD`````B!D`````B1D`````BAD`````BQD`````C!D`````C1D`````CAD`
M````D!D`````D1D`````DAD`````DQD`````E!D`````E1D`````EAD`````
MEQD`````F!D`````F1D`````FAD`````FQD`````G!D`````G1D`````GAD`
M````GQD`````H!D`````H1D`````HAD`````HQD`````I!D`````I1D`````
MIAD`````IQD`````J!D`````J1D`````JAD`````JQD`````K!D`````K1D`
M````KAD`````KQD`````L!D`````L1D`````LAD`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````LQD`````````````;@(`````;P(`````30(`````
M$@,`````$P,`````%`,`````%0,`````%PX`````CQD`````````````P/O>
MEP``P/O?EP``*0X`````*@X`````*PX`````+`X`````+0X`````+@X`````
M+PX`````,`X`````,0X`````,@X`````P/OJEP``P/OKEP``P/OLEP``P/OM
MEP``P/ONEP``P/OOEP``*0X`````*@X`````*PX`````+`X`````+0X`````
M+@X`````+PX`````,`X`````,0X`````,@X`````P/OZEP``P/O[EP``P/O\
MEP``P/O]EP``P/O^EP``P/O_EP``M1P`````MAP`````MQP`````N!P`````
MN1P`````NAP`````NQP`````O!P`````O1P`````OAP`````OQP`````P!P`
M````P1P`````PAP`````PQP`````Q!P`````Q1P`````QAP`````QQP`````
MR!P`````R1P`````RAP`````RQP`````S!P`````S1P`````SAP`````SQP`
M````T!P`````T1P`````TAP`````TQP`````U!P`````U1P`````UAP`````
MUQP`````V!P`````V1P`````VAP`````VQP`````W!P`````W1P`````WAP`
M````WQP`````X!P`````X1P`````XAP`````XQP`````Y!P`````Y1P`````
MYAP`````YQP`````Z!P`````Z1P`````ZAP`````ZQP`````[!P`````[1P`
M````[AP`````[QP`````\!P`````\1P`````\AP`````\QP`````]!P`````
M]1P`````]AP`````]QP`````^!P`````^1P`````^AP`````^QP`````_!P`
M````_1P`````_AP`````_QP``````!T``````1T``````AT``````QT`````
M!!T`````!1T`````!AT`````!QT`````"!T`````"1T`````"AT`````"QT`
M````#!T`````#1T`````#AT`````#QT`````$!T`````$1T`````$AT`````
M$QT`````%!T`````%1T`````%AT`````%QT`````&!T`````&1T`````&AT`
M````&QT`````'!T`````'1T`````'AT`````'QT`````(!T`````(1T`````
M%@,`````90(`````*AP`````.QP`````1!P`````11P`````1AP`````1QP`
M````2!P`````21P`````P/MWE@``P/MXE@``P/MYE@``P/MZE@``P/M[E@``
MP/M\E@``P/M]E@``P/M^E@``P/M_E@``"@(`````(AT`````(QT`````)!T`
M````)1T`````)AT`````)QT`````*!T`````*1T`````*AT`````*QT`````
M+!T`````+1T`````+AT`````+QT`````,!T`````,1T`````,AT`````,QT`
M````-!T`````-1T`````-AT`````-QT`````.!T`````.1T`````.AT`````
M.QT`````D@(`````DP(`````P/N=E@``P/N>E@``P/N?E@``/!T`````/!T`
M````/1T`````61T`````/1T`````/1T`````/AT`````/AT`````/QT`````
M/QT`````5QT`````6!T`````/QT`````/QT`````/QT`````0!T`````01T`
M````0AT`````0QT`````0QT`````0QT`````0QT`````0QT`````1!T`````
M7!T`````11T`````1AT`````1AT`````1AT`````1AT`````1QT`````1QT`
M````1QT`````2!T`````2!T`````21T`````21T`````2AT`````2AT`````
M2QT`````3!T`````31T`````3AT`````3AT`````3AT`````3AT`````3AT`
M````3QT`````3QT`````3QT`````4!T`````4!T`````4!T`````3!T`````
M41T`````4AT`````4AT`````4AT`````4QT`````4QT`````5!T`````5!T`
M````51T`````5AT`````6AT`````7AT`````7QT`````6QT`````71T`````
M8!T`````81T`````81T`````81T`````11T`````3AT`````3@(`````3P(`
M````4`(`````2AU3'0``4AU2'0``/AT^'0``P/OQE@``P/ORE@``P/OSE@``
MP/OTE@``P/OUE@``P/OVE@``P/OWE@``P/OXE@``P/OYE@``P/OZE@``P/O[
ME@``P/O\E@``P/O]E@``P/O^E@``P/O_E@``K1L``*X;``"O&P``L!L``+$;
M``"R&P``LQL``+0;``"U&P``MAL``+<;``"X&P``N1L``+H;``"[&P``O!L`
M`+T;``"^&P``OQL``,`;``#!&P``PAL``,,;``#$&P``Q1L``,8;``#'&P``
MR!L``,D;``#*&P``RQL``,P;``#-&P``SAL``,\;``#0&P``T1L``-(;``#3
M&P``U!L``-4;``#6&P``UQL``-@;``#9&P``VAL``-L;``#<&P``W1L``-X;
M``#?&P``X!L``.$;``#B&P``XQL``.0;``#E&P``YAL``.<;``#H&P``Z1L`
M`.H;``#K&P``[!L``.T;``#N&P``[QL``/`;``#Q&P``\AL``/,;``#T&P``
M]1L``/8;``#W&P``^!L``/D;``#Z&P``^QL``/P;``#]&P``_AL``/\;````
M'````1P```(<```#'```!!P```4<```&'```!QP```@<```)'```"AP```L<
M```,'```#1P```X<```/'```$!P``!$<```2'```$QP``!0<```5'```%AP`
M`!<<```8'```&1P``!H<```;'```'!P``!T<```>'```'QP``"`<```A'```
M(AP``",<```D'```)1P``"8<```G'```*!P``%L<```I'```*QP``"P<```M
M'```+AP``"\<```P'```,1P``#(<```S'```-!P``#4<```V'```-QP``#@<
M```Y'```.AP``#P<```]'```/AP``#\<``!`'```01P``$(<``!#'```2AP`
M`$L<``!,'```31P``$X<``!/'```4!P``%$<``!2'```4QP``%0<``!5'```
M5AP``%<<``!8'```61P``%H<``!<'```71P``%X<``!?'```8!P``&$<``!B
M'```8QP``&0<``!E'```9AP``&<<``!H'```:1P``&H<``!K'```;!P``&T<
M``!N'```;QP``'`<``!Q'```<AP``',<``!T'```=1P``'8<``!W'```>!P`
M`'D<``!Z'```>QP``'P<``!]'```?AP``'\<``"`'```@1P``((<``"#'```
MA!P``(4<``"&'```AQP``(@<``")'```BAP``(L<``",'```C1P``(X<``"/
M'```D!P``)$<``"2'```DQP``)0<``"5'```EAP``)<<``"8'```F1P``)H<
M``";'```G!P``)T<``">'```GQP``*`<``"A'```HAP``*,<``"D'```I1P`
M`*8<``"G'```J!P``*D<``"J'```JQP``*P<``"M'```KAP``*\<``"P'```
ML1P``+(<``"S'```M!P``,#[`)0``*X:`````*\:`````+`:`````+$:````
M`+(:`````+,:`````+0:`````+4:`````+8:`````+<:`````+@:`````+D:
M`````+H:`````+L:`````+P:`````+T:`````+X:`````+\:`````,`:````
M`,$:`````,(:`````,,:`````,0:`````,4:`````,8:`````,<:`````,@:
M`````,D:`````,H:`````,L:`````,P:`````,T:`````,X:`````,\:````
M`-`:`````-$:`````-(:`````-,:`````-0:`````-4:`````-8:`````-<:
M`````-@:`````-D:`````-H:`````-L:`````-P:`````-T:`````-X:````
M`-\:`````.`:`````.$:`````.(:`````.,:`````.0:`````.4:`````.8:
M`````.<:`````.@:`````.D:`````.H:`````.L:`````.P:`````.T:````
M`.X:`````.\:`````/`:`````/$:`````/(:`````/,:`````/0:`````/4:
M`````/8:`````/<:`````/@:`````/D:`````/H:`````/L:`````/P:````
M`/T:`````/X:`````/\:```````;``````$;``````(;``````,;``````0;
M``````4;``````8;``````<;``````@;``````D;``````H;``````L;````
M``P;``````T;``````X;``````\;`````!`;`````!$;`````!(;`````!,;
M`````!0;`````!4;`````!8;`````!<;`````!@;`````!D;`````!H;````
M`!L;`````!P;`````!T;`````!X;`````!\;`````"`;`````"$;`````"(;
M`````",;`````"0;`````"4;`````"8;`````"<;`````"@;`````"D;````
M`"H;`````"L;`````"P;`````"T;`````"X;`````"\;`````#`;`````#$;
M`````#(;`````#,;`````#0;`````#4;`````#8;`````#<;`````#@;````
M`#D;`````#H;`````#L;`````#P;`````#T;`````#X;`````#\;`````$`;
M`````$$;`````$(;`````$,;`````$0;`````$4;`````$8;`````$<;````
M`$@;`````$D;`````$H;`````$L;`````$P;`````$T;`````$X;`````$\;
M`````%`;`````%$;`````%(;`````%,;`````%0;`````%4;`````%8;````
M`%<;`````%@;`````%D;`````%H;`````%L;`````%P;`````%T;`````%X;
M`````%\;`````&`;`````&$;`````&(;`````&,;`````&0;`````&4;````
M`&8;`````&<;`````&@;`````&D;`````&H;`````&L;`````&P;`````&T;
M`````&X;`````&\;`````'`;`````'$;`````'(;`````',;`````'0;````
M`'4;`````'8;`````'<;`````'@;`````'D;`````'H;`````'L;`````'P;
M`````'T;`````'X;`````'\;`````(`;`````($;`````((;`````(,;````
M`(0;`````(4;`````(8;`````(<;`````(@;`````(D;`````(H;`````(L;
M`````(P;`````(T;`````(X;`````(\;`````)`;`````)$;`````)(;````
M`),;`````)0;`````)4;`````)8;`````)<;`````)@;`````)D;`````)H;
M`````)L;`````)P;`````)T;`````)X;`````)\;`````*`;`````*$;````
M`*(;`````*,;`````*0;`````*4;`````*8;`````*<;`````*@;`````*D;
M`````*H;`````*L;`````*P;``````05``````45``````85``````<5````
M``@5``````D5``````H5``````L5``````P5``````T5``````X5``````\5
M`````!`5`````!$5`````!(5`````,#[#Y,``!,5`````,#[$9,``!05````
M`!45`````!85`````!<5`````,#[%I,``,#[%Y,``!@5`````!D5`````!H5
M`````!L5`````!P5`````!T5`````!X5`````,#['Y,``!\5`````"`5````
M`"$5`````"(5`````",5`````"05`````"45`````"85`````"<5`````"@5
M`````"D5`````"H5`````"L5`````"P5`````"T5`````"X5`````"\5````
M`#`5`````#$5`````#(5`````#,5`````#05`````#45`````#85`````#<5
M`````#@5`````#D5`````#H5`````#L5`````#P5`````#T5`````#X5````
M`#\5`````$`5`````$$5`````$(5`````$,5`````$05`````$45`````,#[
M1Y,``$85`````$<5`````$@5`````$D5`````$H5`````$L5`````$P5````
M`$T5`````$X5`````$\5`````%`5`````%$5`````%(5`````%,5`````%05
M`````%45`````%85`````%<5`````%@5`````,#[6Y,``,#[7),``,#[79,`
M`,#[7I,``,#[7Y,``,#[8),``$4"`````&("`````$8"`````$<"`````$@"
M`````$D"`````%H"`````'("`````"H.`````"L.`````"P.`````"T.````
M`"X.`````"\.`````#`.`````#$.`````#(.`````,P-`````,T-`````,X-
M`````,\-`````-`-`````-$-`````-(-`````-,-`````-0-`````-4-````
M`-8-`````,#[?9,``,#[?I,``,#[?Y,``,#[@),``,#[@9,``,#[@I,``,#[
M@Y,``,#[A),``,#[A9,``,#[AI,``,#[AY,``,#[B),``,#[B9,``,#[BI,`
M`,#[BY,``,#[C),``,#[C9,``,#[CI,``,#[CY,``,#[D),``,#[D9,``,#[
MDI,``,#[DY,``,#[E),``,#[E9,``,#[EI,``,#[EY,``,#[F),``,#[F9,`
M`,#[FI,``,#[FY,``,#[G),``,#[G9,``,#[GI,``,#[GY,``%D:`````%H:
M`````%L:`````%P:`````%T:`````%X:`````%\:`````&`:`````&$:````
M`&(:`````&,:`````&0:`````&4:`````&8:`````&<:`````&@:`````&D:
M`````&H:`````&L:`````&P:`````&T:`````&X:`````&\:`````'`:````
M`'$:`````'(:`````',:`````'0:`````'4:`````'8:`````'<:`````'@:
M`````'D:`````'H:`````'L:`````'P:`````'T:`````'X:`````'\:````
M`(`:`````($:`````((:`````(,:`````(0:`````(4:`````(8:`````(<:
M`````(@:`````(D:`````(H:`````(L:`````(P:`````(T:`````(X:````
M`(\:`````)`:`````)$:`````)(:`````),:`````)0:`````)4:`````)8:
M`````)<:`````)@:`````)D:`````)H:`````)L:`````)P:`````)T:````
M`)X:`````)\:`````*`:`````*$:`````*(:`````*,:`````*0:`````*4:
M`````*8:`````*<:`````*@:`````*D:`````*H:`````*L:`````*P:````
M`*T:`````,#[]9,``,#[]I,``,#[]Y,``,#[^),``,#[^9,``,#[^I,``,#[
M^Y,``,#[_),``,#[_9,``,#[_I,``,#[_Y,``!P4`````!T4`````!X4````
M`!\4`````"`4`````"$4`````"(4`````,#[!Y(``",4`````"04`````"44
M`````"84`````"<4`````"@4`````"D4`````"H4`````"L4`````"P4````
M`"T4`````"X4`````"\4`````#`4`````#$4`````#(4`````#,4`````#04
M`````#44`````#84`````#<4`````#@4`````#D4`````#H4`````#L4````
M`#P4`````#T4`````#X4`````#\4`````$`4`````$$4`````$(4`````$,4
M`````$04`````$44`````$84`````$<4`````$@4`````$D4`````$H4````
M`$L4`````$P4`````$T4`````$X4`````$\4`````%`4`````%$4`````%(4
M`````%,4`````%04`````%44`````%84`````%<4`````%@4`````%D4````
M`%H4`````%L4`````%P4`````%T4`````%X4`````%\4`````&`4`````&$4
M`````,#[1Y(``&(4`````,#[29(``&,4`````&04`````&44`````&84````
M`,#[3I(``,#[3Y(``&<4`````&@4`````&D4`````&H4`````&L4`````&P4
M`````&T4`````,#[5Y(``&X4`````,#[69(``&\4`````'`4`````'$4````
M`'(4`````,#[7I(``,#[7Y(``',4`````'04`````'44`````'84`````'<4
M`````'@4`````'D4`````'H4`````'L4`````'P4`````'T4`````'X4````
M`'\4`````(`4`````($4`````((4`````(,4`````(04`````(44`````(84
M`````(<4`````(@4`````(D4`````(H4`````(L4`````(P4`````(T4````
M`(X4`````(\4`````)`4`````)$4`````)(4`````),4`````)04`````)44
M`````)84`````)<4`````)@4`````)D4`````,#[AY(``)H4`````,#[B9(`
M`)L4`````)P4`````)T4`````)X4`````,#[CI(``,#[CY(``)\4`````*`4
M`````*$4`````*(4`````*,4`````*04`````*44`````*84`````*<4````
M`*@4`````*D4`````*H4`````*L4`````*P4`````*T4`````*X4`````*\4
M`````+`4`````+$4`````+(4`````+,4`````+04`````+44`````+84````
M`+<4`````+@4`````+D4`````+H4`````+L4`````+P4`````+T4`````,#[
MKY(``+X4`````,#[L9(``+\4`````,`4`````,$4`````,(4`````,#[MI(`
M`,#[MY(``,,4`````,04`````,44`````,84`````,<4`````,@4`````,D4
M`````,#[OY(``,H4`````,#[P9(``,L4`````,P4`````,T4`````,X4````
M`,#[QI(``,#[QY(``,\4`````-`4`````-$4`````-(4`````-,4`````-04
M`````-44`````,#[SY(``-84`````-<4`````-@4`````-D4`````-H4````
M`-L4`````-P4`````,#[UY(``-T4`````-X4`````-\4`````.`4`````.$4
M`````.(4`````.,4`````.04`````.44`````.84`````.<4`````.@4````
M`.D4`````.H4`````.L4`````.P4`````.T4`````.X4`````.\4`````/`4
M`````/$4`````/(4`````/,4`````,#[[Y(``/04`````/44`````/84````
M`/<4`````/@4`````/D4`````/H4`````/L4`````/P4`````/T4`````/X4
M`````/\4```````5``````$5``````(5``````,5`````&(=`````&,=````
M`&0=`````&4=`````&8=`````&<=`````&@=`````&D=`````&H=`````&L=
M`````&P=`````&T=`````&X=`````&\=`````'`=`````'$=`````'(=````
M`',=`````'0=`````'4=`````'8=`````'<=`````'@=`````'D=`````'H=
M`````'L=`````'P=`````'T=`````'X=`````'\=`````(`=`````($=````
M`((=`````(,=`````(0=`````(4=`````(8=`````(<=`````(@=`````(D=
M`````(H=`````(L=`````(P=`````(T=`````(X=`````(\=`````)`=````
M`)$=`````)(=`````),=`````)0=`````)4=`````)8=`````)<=`````)@=
M`````)D=`````)H=`````)L=`````)P=`````)T=`````)X=`````)\=````
M`*`=`````*$=`````*(=`````*,=`````*0=`````*4=`````*8=`````*<=
M`````*@=`````*D=`````*H=`````*L=`````*P=`````*T=`````*X=````
M`*\=`````+`=`````+$=`````+(=`````+,=`````+0=`````+4=`````+8=
M`````+<=`````+@=`````+D=`````+H=`````+L=`````,#[6I$``,#[6Y$`
M`,#[7)$``,#[79$``,#[7I$``+P=`````+T=`````+X=`````+\=`````,`=
M`````,$=`````,(=`````,,=`````,0=`````,4=`````,8=`````,<=````
M`,@=`````,D=`````,H=`````,L=`````,P=`````,T=`````,X=`````,\=
M`````-`=`````-$=`````-(=`````-,=`````-0=`````-4=`````-8=````
M`-<=`````-@=`````-D=`````-H=`````-L=`````-P=`````-T=`````-X=
M`````-\=`````.`=`````.$=`````.(=`````.,=`````.0=`````.4=````
M`.8=`````.<=`````.@=`````.D=`````.H=`````.L=`````.P=`````.T=
M`````.X=`````.\=`````/`=`````/$=`````/(=`````/,=`````/0=````
M`/4=`````/8=`````/<=`````/@=`````/D=`````/H=`````/L=`````/P=
M`````/T=`````/X=`````/\=`````,#[HY$``,#[I)$``,#[I9$``,#[II$`
M`,#[IY$````>``````$>``````(>``````,>``````0>``````4>``````8>
M``````<>``````@>``````D>``````H>``````L>``````P>``````T>````
M``X>``````\>`````!`>`````!$>`````!(>`````!,>`````!0>`````!4>
M`````!8>`````!<>`````!@>`````!D>`````!H>`````!L>`````!P>````
M`!T>`````!X>`````!\>`````"`>`````"$>`````"(>`````",>`````"0>
M`````"4>`````"8>`````"<>`````"@>`````"D>`````"H>`````"L>````
M`"P>`````"T>`````"X>`````"\>`````#`>`````#$>`````#(>`````#,>
M`````#0>`````#4>`````#8>`````#<>`````#@>`````#D>`````#H>````
M`#L>`````#P>`````#T>`````#X>`````#\>`````$`>`````$$>`````$(>
M`````$,>`````$0>`````$4>`````$8>`````$<>`````$@>`````$D>````
M`$H>`````$L>`````$P>`````$T>`````$X>`````$\>`````%`>`````%$>
M`````,#[^I$``,#[^Y$``,#[_)$``,#[_9$``,#[_I$``,#[_Y$``#$9````
M`#(9`````#,9`````#09`````#49`````#89`````#<9`````#@9`````#D9
M`````#H9`````#L9`````#P9`````#T9`````#X9`````#\9`````$`9````
M`$$9`````$(9`````$,9`````$09`````$49`````$89`````$<9`````$@9
M`````$D9`````$H9`````$L9`````$P9`````$T9`````$X9`````%$9````
M`%(9`````%,9`````%09`````,#[(I```%49`````%89`````%<9`````%@9
M`````%D9`````,#[*)```%H9`````%L9`````,#[*Y```&`9`````&$9````
M`&(9`````&,9`````&09`````&49`````&89`````,#[,Y```,#[-)```,#[
M-9```````````````````````````&L9`````,#[.I```,#[.Y```,#[/)``
M`,#[/9```,#[/I```,#[/Y```"D.`````"H.`````"L.`````"P.`````"T.
M`````"X.`````"\.`````#`.`````#$.`````#(.`````&P"`````&T"````
M``X#``````\#`````!`#`````!$#`````$\9`````%`9`````%P9`````%T9
M`````%X9`````%\9`````&<9`````&@9`````&D9`````&H9`````,#[6I``
M`,#[6Y```,#[7)```,#[79```,#[7I```,#[7Y```,#[8)```,#[89```,#[
M8I```,#[8Y```,#[9)```,#[99```,#[9I```,#[9Y```,#[:)```,#[:9``
M`,#[:I```,#[:Y```,#[;)```,#[;9```,#[;I```,#[;Y```,#[<)```,#[
M<9```,#[<I```,#[<Y```,#[=)```,#[=9```,#[=I```,#[=Y```,#[>)``
M`,#[>9```,#[>I```,#[>Y```,#[?)```,#[?9```,#[?I```,#[?Y```,#[
M@)```,#[@9```,#[@I```,#[@Y```,#[A)```,#[A9```,#[AI```,#[AY``
M`,#[B)```,#[B9```,#[BI```,#[BY```,#[C)```,#[C9```,#[CI```,#[
MCY```,#[D)```,#[D9```,#[DI```,#[DY```,#[E)```,#[E9```,#[EI``
M`,#[EY```,#[F)```,#[F9```,#[FI```,#[FY```,#[G)```,#[G9```,#[
MGI```,#[GY```.$2`````.(2`````.,2`````.02`````.42`````.82````
M`.<2`````.D2`````.H2`````.L2`````.P2`````.T2`````.X2`````/`2
M`````/$2`````/(2`````/,2`````/02`````/42`````/<2`````/@2````
M`/D2`````/H2`````/L2`````/P2`````/T2`````/X2`````/\2```````3
M``````$3``````(3``````03``````43`````.@2`````.\2`````/82````
M``,3``````83`````,#[QI```,#[QY```,#[R)```,#[R9```,#[RI```,#[
MRY```,#[S)```,#[S9```,#[SI```,#[SY```.$2`````.(2`````.,2````
M`.02`````.42`````.82`````.<2`````.D2`````.H2`````.L2`````.P2
M`````.T2`````.X2`````/`2`````/$2`````/(2`````/,2`````/02````
M`/42`````/<2`````/@2`````/D2`````/H2`````/L2`````/P2`````/T2
M`````/X2`````/\2```````3``````$3``````(3``````03``````43````
M`.@2`````.\2`````/82``````,3``````83``````<3``````@3``````D3
M`````,#[^9```,#[^I```'$"`````,#[_)```,#[_9```,#[_I```,#[_Y``
M`)H8K1@``%H#`````%L#`````%P#`````/X"`````/\"```````#``````$#
M``````(#``````,#``````0#``````4#``````4#``````8#``````<#````
M``@#``````D#``````H#``````L#`````%T#`````$P"`````%X#`````%\#
M`````&`#`````````````````````&$#`````&(#`````&,#`````&0#````
M`&4#`````&8#`````"D.`````"H.`````"L.`````"P.`````"T.`````"X.
M`````"\.`````#`.`````#$.`````#(.`````"H.`````"L.`````"P.````
M`"T.`````"X.`````"\.`````#`.`````#$.`````#(.`````"D.`````&<#
M`````````````&@#`````````````&D#`````````````(X"`````(\"````
M`)`"`````)$"`````&H#`````&L#`````%88`````%@8`````%H8`````%H8
MF1@``%P8`````%X8`````&`8`````&(8`````,#[2(\``&08`````&88````
M`&@8`````&H8`````&H8F1@``&P8`````&X8`````'`8`````'(8`````'(8
MF1@``'08`````'88`````'@8`````'H8`````'H8F1@``'P8`````'X8````
M`(`8`````((8`````((8F1@``(08`````(88`````(@8`````(H8`````(P8
M`````(X8`````)`8`````)(8`````)08`````)88`````)@8`````)H8````
M`%88E1@``(X8`````,#[:X\``,#[;(\``,#[;8\``,#[;H\``,#[;X\``,#[
M<(\``*`8`````*$8`````*(8`````*48`````*88`````*<8`````*@8````
M`*D8`````*H8`````*L8`````*P8`````*T8`````*X8````````````````
M`````*,8`````*08`````````````````````*\8``````P#````````````
M`````````)P8`````)T8`````)X8`````)\8`````,#[C(\``,#[C8\``,#[
MCH\``,#[CX\``%<8`````%D8`````%L8`````%L8F1@``%T8`````%\8````
M`&$8`````&,8`````,#[F(\``&48`````&<8`````&D8`````&L8`````&L8
MF1@``&T8`````&\8`````'$8`````',8`````',8F1@``'48`````'<8````
M`'D8`````'L8`````'L8F1@``'T8`````'\8`````($8`````(,8`````(,8
MF1@``(48`````(<8`````(D8`````(L8`````(T8`````(\8`````)$8````
M`),8`````)48`````)<8`````)D8`````)L8`````%<8E1@``(48`````(T8
M`````(\8`````,#[O8\``&P#`````&T#`````&X#`````&\#`````'`#````
M`'$#`````'(#`````',#`````````````'0#`````'4#`````'8#`````'<#
M`````'@#`````'D#`````,#[S8\``,#[SH\``'H#`````,#[T(\``,#[T8\`
M`,#[TH\``,#[TX\``,#[U(\``,#[U8\``,#[UH\``,#[UX\``,#[V(\``,#[
MV8\``,#[VH\``,#[VX\``,#[W(\``,#[W8\``,#[WH\``,#[WX\``,#[X(\`
M`,#[X8\``,#[XH\``,#[XX\``,#[Y(\``,#[Y8\``,#[YH\``,#[YX\``,#[
MZ(\``,#[Z8\``,#[ZH\``,#[ZX\``,#[[(\``,#[[8\``,#[[H\``,#[[X\`
M`,#[\(\``,#[\8\``,#[\H\``,#[\X\``,#[](\``,#[]8\``,#[]H\``,#[
M]X\``,#[^(\``,#[^8\``,#[^H\``,#[^X\``,#[_(\``,#[_8\``,#[_H\`
M`,#[_X\``,#[`(X``.07`````.47`````.87`````.<7`````.@7`````.D7
M`````.H7`````.L7`````.P7`````.T7`````.X7`````.\7`````/`7````
M`/$7`````/(7`````/,7`````/07`````/47`````/87`````/<7`````/@7
M`````/D7`````/H7`````/L7`````/P7`````/T7`````/X7`````/\7````
M```8``````$8``````(8``````,8``````08``````48``````88``````<8
M``````@8``````D8``````H8``````L8``````P8``````T8``````X8````
M``\8`````!`8`````!$8`````!(8`````!,8`````!08`````!48`````!88
M`````!<8`````!@8`````!D8`````!H8`````!L8`````!P8`````!T8````
M`,#[.XX``,#[/(X``,#[/8X``,#[/HX``!8.`````!X8`````!\8`````"`8
M`````"$8`````"(8`````",8``````,.````````````````````````````
M`````````````````"08`````"48`````````````%D#`````"D.`````"H.
M`````"L.`````"P.`````"T.`````"X.`````"\.`````#`.`````#$.````
M`#(.`````/P"`````/T"`````,#[7(X``,#[78X``,#[7HX``,#[7XX``,#[
M8(X``,#[88X``,#[8HX``,#[8XX``,#[9(X``,#[98X``,#[9HX``,#[9XX`
M`,#[:(X``,#[:8X``,#[:HX``,#[:XX``,#[;(X``,#[;8X``,#[;HX``,#[
M;XX``,#[<(X``,#[<8X``,#[<HX``,#[<XX``,#[=(X``,#[=8X``,#[=HX`
M`,#[=XX``,#[>(X``,#[>8X``,#[>HX``,#[>XX``,#[?(X``,#[?8X``,#[
M?HX``,#[?XX``,#[@(X``"88`````"<8`````,#[@XX``"@8`````,#[A8X`
M`,#[AHX``"D8`````"H8`````,#[B8X``"L8`````,#[BXX``,#[C(X``"P8
M`````,#[CHX``,#[CXX``,#[D(X``,#[D8X``,#[DHX``,#[DXX``"T8````
M`"X8`````"\8`````#`8`````,#[F(X``#$8`````#(8`````#,8`````#08
M`````#48`````#88`````#<8`````,#[H(X``#@8`````#D8`````#H8````
M`,#[I(X``#L8`````,#[IHX``#P8`````,#[J(X``,#[J8X``#T8`````#X8
M`````,#[K(X``#\8`````$`8`````$$8`````$(8`````$,8`````$08````
M`$48`````$88`````$<8`````$@8`````$D8`````$H8`````$L8`````,#[
MNHX``$P8`````$T8`````$X8`````,#[OHX``,#[OXX``$\8`````%`8````
M`%$8`````%(8`````%,8`````,#[Q8X```0.`````,#[QXX`````````````
M`````````````````````%08`````%48`````,#[SHX``,#[SXX``"D.````
M`"H.`````"L.`````"P.`````"T.`````"X.`````"\.`````#`.`````#$.
M`````#(.`````,#[VHX``,#[VXX``#X8,1@``#X8.!@``,#[WHX``,#[WXX`
M`,#[X(X``,#[X8X``,#[XHX``,#[XXX``,#[Y(X``,#[Y8X``,#[YHX``,#[
MYXX``,#[Z(X``,#[Z8X``,#[ZHX``,#[ZXX``,#[[(X``,#[[8X``,#[[HX`
M`,#[[XX``,#[\(X``,#[\8X``,#[\HX``,#[\XX``,#[](X``,#[]8X``,#[
M]HX``,#[]XX``,#[^(X``,#[^8X``,#[^HX``,#[^XX``,#[_(X``,#[_8X`
M`,#[_HX``,#[_XX``,#[`(T``,#[`8T``````````````````,#[!(T``%47
M`````%87`````%<7`````%@7`````%D7`````%H7`````%L7`````%T7````
M`,#[#8T``%\7`````&`7`````&$7`````,#[$8T``&(7`````&,7`````&07
M`````&47`````&87`````&<7`````&@7`````&D7`````&H7`````&L7````
M`&P7`````&T7`````&X7`````&\7`````'`7`````'$7`````'(7`````',7
M`````'07`````'47`````'87`````'<7`````'@7`````,#[*8T``'D7````
M`'H7`````'L7`````'P7`````'T7`````'X7`````'\7`````(`7`````($7
M`````((7`````(,7`````(07`````(47`````(87`````(<7`````(@7````
M`,#[.HT``,#[.XT``,#[/(T``,#[/8T``(D7`````(H7`````(L7`````(P7
M`````(T7`````(X7`````,#[1(T``,#[18T``(\7`````)`7`````)$7````
M`,#[28T``)(7`````),7`````)07`````)47`````,#[3HT``,#[3XT``,#[
M4(T``,#[48T``,#[4HT``,#[4XT``,#[5(T``,#[58T``,#[5HT``)87````
M`,#[6(T``,#[68T``,#[6HT``,#[6XT``,#[7(T``,#[78T``,#[7HT``,#[
M7XT``%P7`````%X7`````,#[8HT``,#[8XT``,#[9(T``,#[98T``"D.````
M`"H.`````"L.`````"P.`````"T.`````"X.`````"\.`````#`.`````#$.
M`````#(.`````,#[<(T``,#[<8T``,#[<HT``,#[<XT``,#[=(T``,#[=8T`
M`,#[=HT``,#[=XT``,#[>(T``,#[>8T``,#[>HT``,#[>XT``,#[?(T``,#[
M?8T``,#[?HT``,#[?XT``,#[@(T``,#[@8T``````````````````,#[A(T`
M`)<7`````)@7`````)D7`````)H7`````)L7`````)P7`````)T7`````)X7
M`````)\7`````*`7`````*$7`````*(7`````*,7`````*07`````*47````
M`*87`````*<7`````*@7`````,#[EXT``,#[F(T``,#[F8T``*D7`````*H7
M`````*L7`````*P7`````*T7`````*X7`````*\7`````+`7`````+$7````
M`+(7`````+,7`````+07`````+47`````+87`````+<7`````+@7`````+D7
M`````+H7`````+L7`````+P7`````+T7`````+X7`````+\7`````,`7````
M`,#[LHT``,$7`````,(7`````,,7`````,07`````,47`````,87`````,<7
M`````,@7`````,D7`````,#[O(T``,H7`````,#[OHT``,#[OXT``,L7````
M`,P7`````,T7`````,X7`````,\7`````-`7`````-$7`````,#[QXT``,#[
MR(T``,#[R8T``-(7`````,#[RXT``,#[S(T``,#[S8T``,#[SHT``-,7````
M`-07`````-47`````-87`````-<7`````-@7`````,#[U8T``-D7`````,#[
MUXT``-H7`````-L7`````-P7`````-T7`````-X7`````-\7`````.`7````
M`.$7`````,#[X(T``,#[X8T``,#[XHT``,#[XXT``,#[Y(T``,#[Y8T``,#[
MYHT``,#[YXT``,#[Z(T``,#[Z8T``,#[ZHT``,#[ZXT``,#[[(T``,#[[8T`
M`,#[[HT``,#[[XT``,#[\(T``,#[\8T``.(7`````.,7`````/L"`````,#[
M]8T``,#[]HT``,#[]XT``,#[^(T``,#[^8T``,#[^HT``,#[^XT``,#[_(T`
M`,#[_8T``,#[_HT``,#[_XT``,#[`(P``````````````````````````,#[
M!(P``,T6`````,X6`````,\6`````-`6`````-$6`````-(6`````-,6````
M`-46`````,#[#8P``-<6`````-@6`````-D6`````,#[$8P``-H6`````-L6
M`````-P6`````-T6`````-X6`````-\6`````.`6`````.$6`````.(6````
M`.,6`````.06`````.46`````.86`````.<6`````.@6`````.D6`````.H6
M`````.L6`````.P6`````.T6`````.X6`````.\6`````/`6`````,#[*8P`
M`/$6`````/(6`````/,6`````/06`````/46`````/86`````/<6`````/@6
M`````/D6`````/H6`````,#[-(P``/L6`````/P6`````/T6`````/X6````
M`/\6`````,#[.HP``,#[.XP``,#[/(P``,#[/8P````7``````$7``````(7
M``````,7``````07``````47``````87`````,#[18P```<7``````@7````
M``D7`````,#[28P```H7``````L7``````P7``````T7`````,#[3HP``,#[
M3XP``,#[4(P``,#[48P``,#[4HP``,#[4XP``,#[5(P```X7``````\7````
M`,#[5XP``,#[6(P``,#[68P``,#[6HP``,#[6XP``,#[7(P``,#[78P``,#[
M7HP``,#[7XP``-06`````-86`````,#[8HP``,#[8XP``,#[9(P``,#[98P`
M`"D.`````"H.`````"L.`````"P.`````"T.`````"X.`````"\.`````#`.
M`````#$.`````#(.`````,#[<(P``,#[<8P``,#[<HP``,#[<XP``,#[=(P`
M`,#[=8P``,#[=HP``,#[=XP``,#[>(P``,#[>8P``,#[>HP``,#[>XP``,#[
M?(P``,#[?8P``,#[?HP``,#[?XP``,#[@(P``,#[@8P`````````````````
M`,#[A(P``!`7`````!$7`````!(7`````!,7`````!07`````!47`````!87
M`````!@7`````,#[C8P``!H7`````!L7`````!P7`````,#[D8P``!T7````
M`!X7`````!\7`````"`7`````"$7`````"(7`````",7`````"07`````"47
M`````"87`````"<7`````"@7`````"D7`````"H7`````"L7`````"P7````
M`"T7`````"X7`````"\7`````#`7`````#$7`````#(7`````#,7`````,#[
MJ8P``#07`````#47`````#87`````#<7`````#@7`````#D7`````#H7````
M`#L7`````#P7`````$,7`````,#[M(P``#T7`````#X7`````#\7`````$`7
M`````$$7`````,#[NHP``,#[NXP``````````$(7`````$47`````$87````
M`$<7`````$@7`````$D7`````$H7`````$L7`````,#[Q8P``$P7`````$T7
M`````$X7`````,#[R8P``$\7`````%`7`````%$7`````%(7`````,#[SHP`
M`,#[SXP``,#[T(P``,#[T8P``,#[THP``,#[TXP``,#[U(P``%,7`````%07
M`````,#[UXP``,#[V(P``,#[V8P``,#[VHP``,#[VXP``,#[W(P``,#[W8P`
M`$07`````,#[WXP``!<7`````!D7`````,#[XHP``,#[XXP``,#[Y(P``,#[
MY8P``"D.`````"H.`````"L.`````"P.`````"T.`````"X.`````"\.````
M`#`.`````#$.`````#(.`````,#[\(P``,#[\8P``,#[\HP``,#[\XP``,#[
M](P``,#[]8P``,#[]HP``,#[]XP``,#[^(P``,#[^8P``,#[^HP``,#[^XP`
M`,#[_(P``,#[_8P``,#[_HP``,#[_XP``,#[`(L`````````````````````
M`````,#[!(L``%T6`````%X6`````%\6`````&`6`````&$6`````&(6````
M`&,6`````&46`````,#[#8L``,#[#HL``&<6`````&@6`````,#[$8L``,#[
M$HL``&D6`````&H6`````&L6`````&P6`````&T6`````&X6`````&\6````
M`'`6`````'$6`````'(6`````',6`````'06`````'46`````'86`````'<6
M`````'@6`````'D6`````'H6`````'L6`````'P6`````'T6`````'X6````
M`,#[*8L``'\6`````(`6`````($6`````((6`````(,6`````(06`````(86
M`````,#[,8L``(<6`````(@6`````,#[-(L``(D6`````(L6`````(P6````
M`(T6`````(X6`````,#[.HL``,#[.XL``````````(\6`````)`6`````)$6
M`````)(6`````),6`````)06`````)46`````,#[1(L``,#[18L``,#[1HL`
M`)86`````)<6`````,#[28L``,#[2HL``)@6`````)D6`````)H6`````,#[
M3HL``,#[3XL``,#[4(L``,#[48L``,#[4HL``,#[4XL``,#[5(L``,#[58L`
M`)L6`````)P6`````,#[6(L``,#[68L``,#[6HL``,#[6XL``'<6`````'@6
M`````,#[7HL``(46`````&06`````&86`````,#[8HL``,#[8XL``,#[9(L`
M`,#[98L``"D.`````"H.`````"L.`````"P.`````"T.`````"X.`````"\.
M`````#`.`````#$.`````#(.`````%$#`````(H6`````,#[<HL``,#[<XL`
M`,#[=(L``,#[=8L``,#[=HL``,#[=XL``,#[>(L``,#[>8L``,#[>HL``,#[
M>XL``,#[?(L``,#[?8L``,#[?HL``,#[?XL``,#[@(L``,#[@8L`````````
M`)T6`````,#[A(L``)X6`````)\6`````*`6`````*$6`````*(6`````*,6
M`````,#[BXL``,#[C(L``,#[C8L``*06`````*46`````*86`````,#[D8L`
M`*<6`````*@6`````*D6`````*H6`````,#[EHL``,#[EXL``,#[F(L``*L6
M`````*P6`````,#[FXL``*T6`````,#[G8L``*X6`````*\6`````,#[H(L`
M`,#[H8L``,#[HHL``+`6`````+$6`````,#[I8L``,#[IHL``,#[IXL``+(6
M`````+,6`````+06`````,#[JXL``,#[K(L``,#[K8L``+46`````+86````
M`+<6`````+@6`````+D6`````+H6`````+L6`````+P6`````,#[MHL``+T6
M`````+X6`````+\6`````,#[NHL``,#[NXL``,#[O(L``,#[O8L``,`6````
M`,$6`````,(6`````,,6`````,06`````,#[PXL``,#[Q(L``,#[Q8L``,46
M`````,86`````,<6`````,#[R8L``,@6`````,D6`````,H6`````,L6````
M`,#[SHL``,#[SXL``,#[T(L``,#[T8L``,#[THL``,#[TXL``,#[U(L``,#[
MU8L``,#[UHL``,P6`````,#[V(L``,#[V8L``,#[VHL``,#[VXL``,#[W(L`
M`,#[W8L``,#[WHL``,#[WXL``,#[X(L``,#[X8L``,#[XHL``,#[XXL``,#[
MY(L``,#[Y8L``,#[YHL``"H.`````"L.`````"P.`````"T.`````"X.````
M`"\.`````#`.`````#$.`````#(.`````,D-`````,H-`````,L-`````%(#
M`````%,#`````%0#`````%4#`````%8#`````%<#`````!4.`````%@#````
M`,#[^XL``,#[_(L``,#[_8L``,#[_HL``,#[_XL``,#[`(H`````````````
M`````````````,#[!(H``.<5`````.@5`````.P5`````.T5`````.05````
M`.45`````,#["XH``,#[#(H``,#[#8H``,#[#HH``.X5`````.D5`````,#[
M$8H``,#[$HH``.85`````.H5`````/$5`````/(5`````/,5`````/05````
M`/45`````/85`````/<5`````/@5`````/D5`````/H5`````/L5`````/P5
M`````/T5`````/X5`````/\5```````6``````$6``````(6``````,6````
M``06`````,#[*8H```46``````86``````<6``````@6``````D6``````H6
M``````L6`````,#[,8H```P6``````P6`````,#[-(H```T6`````.\5````
M`,#[-XH``.\5`````/`5`````,#[.HH``,#[.XH``````````,#[/8H```\6
M`````!`6`````!$6`````!(6`````!,6`````,#[0XH``,#[1(H``,#[18H`
M`,#[1HH``!06`````!46`````,#[28H``,#[2HH``!86`````!<6`````!@6
M`````,#[3HH``,#[3XH``,#[4(H``,#[48H``,#[4HH``,#[4XH``,#[5(H`
M`,#[58H``,#[5HH``,#[5XH``,#[6(H``/(5`````/,5`````/@5``````X6
M`````,#[78H```86`````,#[7XH``,#[8(H``,#[88H``,#[8HH``,#[8XH`
M`,#[9(H``,#[98H``"D.`````"H.`````"L.`````"P.`````"T.`````"X.
M`````"\.`````#`.`````#$.`````#(.`````````````````````.L5````
M`.,5`````.(5`````,#[=8H``,#[=HH``,#[=XH``,#[>(H``,#[>8H``,#[
M>HH``,#[>XH``,#[?(H``,#[?8H``,#[?HH``,#[?XH``,#[@(H`````````
M`````````````````,#[A(H``!H6`````!L6`````!P6`````!T6`````!X6
M`````!\6`````"`6`````"(6`````"06`````,#[CHH``"46`````"86````
M`"<6`````,#[DHH``"@6`````"D6`````"H6`````"L6`````"P6`````"T6
M`````"X6`````"\6`````#`6`````#$6`````#(6`````#,6`````#06````
M`#46`````#86`````#<6`````#@6`````#D6`````#H6`````#L6`````#P6
M`````#T6`````,#[J8H``#X6`````#\6`````$`6`````$$6`````$(6````
M`$,6`````$06`````,#[L8H``$46`````$86`````,#[M(H``$<6`````$@6
M`````$D6`````$H6`````$L6`````,#[NHH``,#[NXH``````````$P6````
M`$T6`````$X6`````$\6`````%`6`````%$6`````%(6`````%,6`````%86
M`````,#[QHH``%<6`````%@6`````%D6`````,#[RHH``%H6`````%L6````
M`%P6`````,#[SHH``,#[SXH``!D6`````,#[T8H``,#[THH``,#[TXH``,#[
MU(H``,#[U8H``,#[UHH``,#[UXH``,#[V(H``,#[V8H``,#[VHH``,#[VXH`
M`,#[W(H``,#[W8H``,#[WHH``,#[WXH``"$6`````",6`````%06`````%46
M`````,#[Y(H``,#[Y8H``"D.`````"H.`````"L.`````"P.`````"T.````
M`"X.`````"\.`````#`.`````#$.`````#(.`````,#[\(H``!0.`````,#[
M\HH``,#[\XH``,#[](H``,#[]8H``,#[]HH``,#[]XH``,#[^(H``,#[^8H`
M`,#[^HH``,#[^XH``,#[_(H``,#[_8H``,#[_HH``,#[_XH``,#[`(D`````
M`````````````````````%H5`````%L5`````%P5`````%T5`````%X5````
M`%\5`````&`5`````&$5`````&,5`````&45`````&85`````&<5`````&@5
M`````&D5`````&H5`````&L5`````&P5`````&T5`````&X5`````&\5````
M`'`5`````'$5`````'(5`````',5`````'05`````'45`````'85`````'<5
M`````'@5`````'D5`````'H5`````'L5`````'P5`````'T5`````'X5````
M`'\5`````(`5`````(`5`````($5`````((5`````(,5`````(05`````(45
M`````(85`````(<5`````(<5`````(@5`````(D5`````(D5`````(H5````
M`(L5`````(P5`````(T5`````(X5`````,#[.HD``,#[.XD``````````(\5
M`````)`5`````)$5`````)(5`````),5`````)05`````)45`````)85````
M`)D5`````)H5`````)L5`````)P5`````)T5`````)X5`````)\5`````*`5
M`````*$5`````,#[3HD``,#[3XD``%D5````````````````````````````
M`````````,#[58D``,#[5HD``,#[5XD``&T5`````&X5`````&\5`````'05
M`````'D5`````'H5`````((5`````(85`````&(5`````&05`````)<5````
M`)@5`````&@"`````&D"`````"D.`````"H.`````"L.`````"P.`````"T.
M`````"X.`````"\.`````#`.`````#$.`````#(.`````/H"`````,#[<8D`
M`,#[<HD``,#[<XD``,#[=(D``,#[=8D``,#[=HD``,#[=XD``,#[>(D``,#[
M>8D``,#[>HD``,#[>XD``,#[?(D``,#[?8D``,#[?HD``,#[?XD``,#[@(D`
M`````````````````````````,#[A(D``*(5`````*,5`````*05`````*45
M`````*85`````*<5`````*@5`````*H5`````,#[C8D``,#[CHD``*P5````
M`*T5`````,#[D8D``,#[DHD``*X5`````*\5`````+`5`````+$5`````+(5
M`````+,5`````+05`````+45`````+85`````+<5`````+@5`````+D5````
M`+H5`````+L5`````+P5`````+T5`````+X5`````+\5`````,`5`````,$5
M`````,(5`````,,5`````,#[J8D``,05`````,45`````,85`````,<5````
M`,@5`````,D5`````,H5`````,#[L8D``,P5`````,#[LXD``,#[M(D``,#[
MM8D``,X5`````,\5`````-`5`````-$5`````,#[NHD``,#[NXD`````````
M`-(5`````-,5`````-05`````-45`````-85`````-<5`````-@5`````-D5
M`````,#[Q8D``,#[QHD``-P5`````-T5`````,#[R8D``,#[RHD``-X5````
M`-\5`````.`5`````,#[SHD``,#[SXD``,#[T(D``,#[T8D``,#[THD``,#[
MTXD``,#[U(D``,#[U8D``,#[UHD``.$5`````,#[V(D``,#[V8D``,#[VHD`
M`,#[VXD``+P5`````+T5`````,#[WHD``,D5`````*D5`````*L5`````-H5
M`````-L5`````,#[Y(D``,#[Y8D``"D.`````"H.`````"L.`````"P.````
M`"T.`````"X.`````"\.`````#`.`````#$.`````#(.`````,L5`````,T5
M`````!(.`````!,.`````"H.`````"L.`````"P.`````"T.`````,<-````
M`,@-`````%`#`````,#[^XD``,#[_(D``,#[_8D``,#[_HD``,#[_XD``'`"
M`````&`"`````&$"`````#\"`````$`"`````$$"`````$("`````$,"````
M`$0"`````%D"`````/0"`````/4"`````/8"`````/<"`````,#[#H<`````
M`````,\3`````````````-`3`````-$3`````-$3`````-,3`````-(3````
M`-03`````-43`````-83`````-@3`````-D3`````-D3`````-H3`````-L3
M`````-P3`````-X3`````-\3`````.`3`````.$3`````.$3`````.(3````
M`.,3`````.,3`````.43`````.83`````.<3`````.@3`````.D3`````-`3
M`````-$3`````-,3````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````,#[
M2X<``,#[3(<``-<3`````-T3`````.03`````,#[4(<``,#[48<``,#[4H<`
M`,#[4X<``,#[5(<``,#[58<``,#[5H<``,#[5X<``,#[6(<``,#[68<``,#[
M6H<``,#[6X<``,#[7(<``,#[78<``,#[7H<``,#[7X<``,#[8(<``,#[88<`
M`,#[8H<``,#[8X<``,#[9(<``,#[98<``,#[9H<``,#[9X<``,#[:(<``,#[
M:8<``,#[:H<``,#[:X<``,#[;(<``,#[;8<``,#[;H<``,#[;X<``,#[<(<`
M`,#[<8<``,#[<H<``,#[<X<``,#[=(<``,#[=8<``,#[=H<``,#[=X<``,#[
M>(<``,#[>8<``,#[>H<``,#[>X<``,#[?(<``,#[?8<``,#[?H<``,#[?X<`
M`.H3`````.T3`````.X3`````.\3`````/$3`````/(3`````/,3`````/03
M`````/<3`````/D3`````/H3`````/L3`````/T3``````$4``````(4````
M``04``````44``````D4``````H4``````L4``````P4``````T4``````X4
M``````\4`````/X3`````.L3`````.P3`````/P3`````/`3``````84````
M``<4``````@4`````/\3```````4`````/43`````/83``````,4`````/@3
M`````!$4`````!(4`````!,4`````!04`````!44`````!84`````!<4````
M`!@4`````!D4`````!H4`````!L4`````!`4`````,#[LH<``,#[LX<``,#[
MM(<``,#[M8<``,#[MH<``,#[MX<``,#[N(<``,#[N8<``,#[NH<``,#[NX<`
M`,#[O(<``,#[O8<``,#[OH<``,#[OX<``,#[P(<``,#[P8<``,#[PH<``,#[
MPX<``,#[Q(<``,#[Q8<``,#[QH<``,#[QX<``,#[R(<``,#[R8<``,#[RH<`
M`,#[RX<``,#[S(<``,#[S8<``,#[SH<``,#[SX<``,#[T(<``,#[T8<``,#[
MTH<``,#[TX<``,#[U(<``,#[U8<``,#[UH<``,#[UX<``,#[V(<``,#[V8<`
M`,#[VH<``,#[VX<``,#[W(<``,#[W8<``,#[WH<``,#[WX<``,#[X(<``,#[
MX8<``,#[XH<``,#[XX<``,#[Y(<``,#[Y8<``,#[YH<``,#[YX<``,#[Z(<`
M`,#[Z8<``,#[ZH<``,#[ZX<``,#[[(<``,#[[8<``,#[[H<``,#[[X<``,#[
M\(<``,#[\8<``,#[\H<``,#[\X<``,#[](<``,#[]8<``,#[]H<``,#[]X<`
M`,#[^(<``,#[^8<``,#[^H<``,#[^X<``,#[_(<``,#[_8<``,#[_H<``,#[
M_X<``````````````````````````````````,#[!(8``,#[!88``,#[!H8`
M`,#[!X8``,#["(8``,#["88``,#["H8``,#["X8``#$"`````#("`````$P#
M`````$T#````````````````````````````````````````````````````
M`,#[%H8``,#[%X8``,#[&(8``,#[&88``,#[&H8``#L"`````,#['(8``,#[
M'88``,#['H8``%@"`````,#[((8``$<3`````$@3`````$D3`````$P3````
M`$T3`````$\3`````%`3`````%(3`````%83`````%<3`````%@3`````%X3
M`````&03`````&43`````&D3`````&H3`````'43`````'83`````($3````
M`((3`````(<3`````(@3`````(P3`````(T3`````(\3`````)`3`````,#[
M.X8``,#[/(8``,#[/88``,#[/H8``,#[/X8```L"`````),3`````)L3````
M`)X3`````*L3`````+`3`````+$3`````+<3`````+T3`````,<3`````,@3
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````,#[
M688``,#[6H8``,#[6X8``,#[7(8``,#[788``,#[7H8``,#[7X8``"D.````
M`"H.`````"L.`````"P.`````"T.`````"X.`````"\.`````#`.`````#$.
M`````#(.`````-0"`````#,"`````#0"`````,L"`````%$3`````)H3````
M`````````$L3`````$H3`````$X3`````$<3`````%`31Q,``+T31Q,``,$3
M1Q,``,@31Q,``%D3`````%H3`````%,3`````%L3`````%P3`````%03````
M`%T3`````%43`````&83`````&<3`````%\3`````&`3`````&@3`````&$3
M`````&,3`````&L3`````&P3`````&T3`````&X3`````&\3`````'`3````
M`'$3`````'(3`````',3`````'<3`````'@3`````'D3`````'H3`````'L3
M`````'P3`````'T3`````'X3`````'\3`````(,3`````(03`````(43````
M`(D3`````(H3`````(X3`````)$3`````)03`````)43`````)83`````)<3
M`````)@3`````)D3`````)P3`````)T3`````)\3`````*`3`````*$3````
M`*(3`````*,3`````*03`````*43`````*83`````*<3`````*@3`````*D3
M`````*H3`````*P3`````*T3`````*X3`````*\3`````+83`````+(3````
M`+,3`````+03`````+43`````+@3`````&(3`````+P3`````+D3`````+D3
M`````+H3`````+X3`````+\3`````,`3`````,$3`````,(3`````,,3````
M`,03`````,43`````,D3`````,H3`````,L3`````,83`````,P3`````,T3
M`````,X3`````,X3`````%\"`````+P3````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````+T3`````,@3````````````
M`````````$X#`````````````````````````````````````'03`````(`3
M`````"D.`````"H.`````"L.`````"P.`````"T.`````"X.`````"\.````
M`#`.`````#$.`````#(.`````(83`````(L3`````)(3`````$<3`````+`3
M`````+L3`````$01`````$01`````$D1`````$D1`````&X1`````&X1````
M`'L1`````'L1`````+T1`````+T1`````-X1`````-X1``````<2``````<2
M`````!`2`````!`2`````,#[$(4``,#[$84``,#[$H4``,#[$X4``,#[%(4`
M`,#[%84``,#[%H4``,#[%X4``,#[&(4``,#[&84``,#[&H4``,#[&X4``,#[
M'(4``,#['84``,#['H4``,#['X4``,#[((4``,#[(84``,#[(H4``,#[(X4`
M`,#[)(4``,#[)84``,#[)H4``,#[)X4``,#[*(4``,#[*84``,#[*H4``,#[
M*X4``,#[+(4``,#[+84``,#[+H4``,#[+X4``,#[,(4```H3``````L3````
M``P3``````T3``````X3``````\3`````!`3`````!$3`````!(3`````!,3
M`````!03`````!43`````!83`````!<3`````!@3`````!D3`````!H3````
M`!L3`````!P3`````!T3`````!X3`````!\3`````"`3`````"$3`````"(3
M`````",3`````"03`````"43`````"83`````"<3`````"@3`````"D3````
M`"H3`````"L3`````"P3`````"T3`````"X3`````"\3`````,#[5X4``,#[
M6(4``#`3`````.P"`````.T"`````%,"`````#`"`````%<"`````.X"````
M`,#[8(4```H3``````L3``````P3``````T3``````X3``````\3`````!`3
M`````!$3`````!(3`````!,3`````!03`````!43`````!83`````!<3````
M`!@3`````!D3`````!H3`````!L3`````!P3`````!T3`````!X3`````!\3
M`````"`3`````"$3`````"(3`````",3`````"03`````"43`````"83````
M`"<3`````"@3`````"D3`````"H3`````"L3`````"P3`````"T3`````"X3
M`````"\3``````X3*Q,``,#[B(4``#X"`````"("`````,#[BX4``,#[C(4`
M`,#[C84``,#[CH4``,#[CX4``,#[D(4`````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````,#[HH4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`,#[NH4``````````````````````````.\"`````````````/`"````````
M`````````````/$"`````````````,#[Q84``,#[QH4``,#[QX4``,#[R(4`
M`,#[R84``,#[RH4``,#[RX4``,#[S(4``,#[S84``,#[SH4``,#[SX4``#$3
M`````#(3`````#,3`````#03`````#43`````#83`````#<3`````#@3````
M`#D3`````#H3`````#L3`````#L3`````#P3`````#T3`````#T3`````#X3
M`````#X3`````#\3`````$`3`````$$3`````$$3`````$(3`````$(3````
M`$,3`````$03`````$43`````$83`````,#[ZX4``,#[[(4``,#[[84``,#[
M[H4``,#[[X4``#83-A,``#83.A,``#H3.A,``/("`````/,"`````,#[]84`
M`,#[]H4``,#[]X4``,#[^(4``,#[^84``,#[^H4``,#[^X4``,#[_(4``,#[
M_84``,#[_H4``,#[_X4``%(1`````%(1`````$41`````$H1`````%H1````
M`',1`````(@1`````(P1`````)01`````+D1`````-H1`````!42`````!D2
M`````'P1`````"$2`````'T2`````!01`````"P1`````#`1`````#01````
M`$`1`````%(1`````%X1`````&H1`````'P1`````)`1`````)@1`````+`1
M`````+X1`````,81`````-\1`````.\1`````/L1``````,2``````P2````
M`!T2`````#D2`````#T2`````%D2`````&$2`````($2`````(42`````(D2
M`````(T2`````)42`````*$2`````*D2`````*T2`````!01`````"P1````
M`#`1`````#01`````$`1`````%(1`````%X1`````&H1`````'P1`````)`1
M`````)@1`````+`1`````+X1`````,81`````-\1`````.\1`````/L1````
M``,2``````P2`````!T2`````#D2`````#T2`````%D2`````&$2`````($2
M`````(42`````(D2`````(T2`````)42`````*$2`````*D2`````*T2````
M`%(1`````%(1`````$41`````$H1`````%H1`````',1`````(@1`````(P1
M`````)01`````+D1`````-H1`````!42`````!D2`````'P1`````"$2````
M`'T2`````$D2`````$D2`````)T2`````)T2`````+$2`````+$2`````+42
M`````+42`````+T2`````+T2`````+D2`````+D2`````,$2`````,$2````
M`,42`````,42`````,D2`````,D2`````,T2`````,T2`````-$2`````-$2
M`````-42`````-42`````#42`````#42`````%42`````%42`````%$2````
M`%$2`````$T2`````$T2`````/<1`````/<1`````$L#````````````````
M`````````````````````,#[AX0``````````````````(`1`````(`1````
M`)D2`````)D2`````/\1`````/\1`````#01`````#01`````#@1`````#@1
M`````#P1`````#P1`````&81`````&81`````$X1`````$X1`````)P1````
M`)P1`````*P1`````*P1`````*@1`````*@1`````*01`````*01`````,X1
M`````,X1`````-81`````-81`````/,1`````/,1`````-D2`````-D2````
M``@2``````@2`````!$2`````!$2`````"T2`````"T2`````#$2`````#$2
M`````$$2`````$$2`````%T2`````%T2`````&D2`````&D2`````'$2````
M`'$2`````$42`````$42`````'42`````'42`````'D2`````'D2`````-T2
M`````%X1`````%X1`````*`1`````*`1`````+41`````+41`````-(1````
M`-(1`````,H1`````,H1`````&T2`````&T2`````,(1`````,(1`````,#[
MSX0``!@1`````!@1`````!P1`````!P1`````"@1`````"@1`````%81````
M`%81`````"`1`````"`1`````"01`````"01`````&(1`````&(1`````&\1
M`````&\1`````'<1`````'<1`````'P1`````'P1`````(01`````(01````
M`.,1`````.,1`````.<1`````.<1`````.L1`````.L1`````*42`````*42
M`````!T2`````!T2`````"42`````"42`````"D2`````"D2`````&42````
M`&42`````,#[]H0``,#[]X0``)$2`````)$2`````,#[^H0``,#[^X0``,#[
M_(0``,#[_80``,#[_H0``,#[_X0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````P/M8@P````#`^UF#`````,#[6H,`````P/M;@P````#`^UR#````
M````````````````````````````````````````````````````````````
M`````#,.````````BPX```````#[#@```````((/````````'Q````````!@
M#@```````&T.````````X0X```````!;#P```````,`/`````````A``````
M``!$$````````%H0````````P/MP@P````#`^W&#`````,#[<H,`````P/MS
M@P`````7`P```````!@#````````P/MV@P````#`^W>#`````,#[>(,`````
MP/MY@P````#S$````````,#[>X,`````P/M\@P````#`^WV#`````#H"````
M````P/M_@P````#`^X"#`````,#[@8,`````P/N"@P````#`^X.#``````T"
M````````%`(```````#H$````````&<"````````[1````````#Q$```````
M`/,0````````P/N+@P````#[$````````,#[C8,`````!!$````````)$0``
M`````/,0````````Z!````````#I$````````.H0````````[!````````#M
M$````````/`0````````\1````````#R$````````/,0````````]1``````
M``#V$````````/@0````````^1````````#Z$````````/L0````````_!``
M````````$0```````,#[HH,``````A$````````#$0````````01````````
M!1$````````&$0````````<1````````"1$```````#S$`````````01````
M````Z!````````#M$````````/$0````````\Q`````````$$0```````.@0
M````````Z1````````#J$````````.P0````````[1````````#P$```````
M`/$0````````\A````````#S$````````/40````````]A````````#X$```
M`````/D0````````^A````````#[$````````/P0`````````!$````````"
M$0````````(1`````````Q$````````$$0````````41````````!A$`````
M```'$0````````D1````````\Q`````````$$0```````/L0````````!!$`
M```````)$0```````,#[SX,`````Z1````````#R$`````````01````````
M!!$````````$$0````````41````````_!````````#U$.@0\Q```/\0````
M````_Q````````#O$````````.\0````````[A````````#N$````````/X0
M````````_A`````````*$0````````H1````````#1$````````-$0``````
M``X1````````#A$````````/$0````````\1````````$!$````````0$0``
M`````!$1````````$1$````````2$0```````!(1````````$Q$````````3
M$0```````/40`````````!$````````"$0```````/00````````\A``````
M``#M$````````",$````````"Q$````````+$0````````(1````````#!$`
M```````,$0```````,#[_(,`````P/O]@P````#`^_Z#`````,#[_X,`````
M,PX`````,PX`````,PX`````,PX`````BPX`````BPX`````BPX`````BPX`
M````^PX`````^PX`````^PX`````^PX`````@@\`````@@\`````@@\`````
M@@\`````P`\`````P`\`````P`\`````P`\`````'Q``````'Q``````'Q``
M````'Q``````Z@\`````Z@\``````A```````A``````D!``````D!``````
MX0X`````X0X`````<@\`````@@X`````H@\`````H@\`````<Q``````<Q``
M````,PX`````,PX`````BPX`````BPX`````@@\`````@@\`````@@\`````
M@@\`````@@\`````@@\`````@@\`````@@\`````7A``````7A``````2P\`
M````>@\`````%Q``````P/LW@@``P/LX@@``P/LY@@``P/LZ@@``P/L[@@``
MP/L\@@``P/L]@@``P/L^@@``P/L_@@``P/M`@@``P/M!@@``P/M"@@``P/M#
M@@``P/M$@@``P/M%@@``P/M&@@``P/M'@@``P/M(@@``P/M)@@``P/M*@@``
MP/M+@@``P/M,@@``P/M-@@``P/M.@@``P/M/@@``/@X`````0@X`````1@X`
M````6`X`````D@\`````:0X`````=@X`````>@X`````G`X`````E`X`````
MH`X`````F`X`````I`X`````J0X`````K0X`````&0\`````T0X`````Q0X`
M````R0X`````V0X`````M0X`````*Q``````\0X`````]0X`````"`\`````
M#`\``````P\`````/P\`````0P\`````1P\`````3P\`````-Q``````/!``
M````8`\`````;@\`````=@\`````:`\`````F@\`````B`\`````G@\`````
ML`\`````R0\`````S@\`````T@\`````U@\`````V@\`````W@\`````X@\`
M````Q`\`````Y@\`````[@\`````\@\`````'0\`````^@\`````_@\`````
M&Q``````$Q``````)Q``````0!``````21``````31``````5A``````5P\`
M````8A``````=Q``````>Q``````?Q``````C!``````K!``````M!``````
MQ!``````V!``````W!``````3@X`````L0X`````U0X`````Y0X`````%0\`
M````*@\`````,@\`````N`\`````O!``````P!``````;0YJ$```;0Y_$```
M;0Y[$````A#J#P```A#R#P```A!I#@``N0Y^#P``+@_J#P``+@]J$```X!``
M````Y!``````+Q``````,Q``````X0X`````\0X`````$`\`````P`\`````
MR0\`````T@\`````Y@\`````41``````7A``````%P,`````&0,`````^0X`
M````L1``````^@X`````LQ``````N!``````L!``````N1``````&@,`````
M&P,`````'`,`````'0,`````'@,`````'P,`````(`,`````(0,`````(@,`
M````(P,`````)`,`````)0,`````)@,`````)P,``````0X``````@X`````
M*`,`````*0,`````*@,`````*P,`````+`,`````+0,`````$@(`````$P(`
M````%0(`````&@(`````#@(`````%@(`````+@,`````+P,`````V0X`````
M+@\`````Z@\`````6A``````M!``````,`,`````,0,`````,@,`````,P,`
M````-`,`````-0,`````-@,`````-P,`````.`,`````LA``````.0,`````
M.@,`````.P,`````/`,`````/0,`````/@,`````/P,`````0`,`````00,`
M````0@,`````0P,`````1`,`````10,`````1@,`````1P,`````2`,`````
M20,`````,PX`````,PX`````,PX`````,PX`````,PX`````,PX`````8`X`
M````8`X`````8`X`````8`X`````8`X`````8`X`````8`X`````8`X`````
M;0X`````;0X`````<@X`````<@X`````BPX`````BPX`````BPX`````BPX`
M````BPX`````BPX`````BPX`````BPX`````BPX`````BPX`````P0X`````
MP0X`````P0X`````P0X`````P0X`````P0X`````P0X`````P0X`````X0X`
M````X0X`````[0X`````[0X`````^PX`````^PX`````^PX`````^PX`````
M^PX`````^PX`````^PX`````^PX`````^PX`````_PX`````^PX0#P``^PX0
M#P``$`\`````$`\`````(0\`````(0\`````O`\`````+@\`````+@\`````
M+@\`````+@\`````+@\`````+@\`````+@]G`@``+@]G`@``-@\`````-@\`
M````9`\`````9`\`````9`\`````9`\`````9`\`````9`\`````L1!D#P``
M?@\`````?@\`````@@\`````@@\`````@@\`````@@\`````@@\`````@@\`
M````@@^+#@``@@^+#@``P`\`````P`\`````P`\`````P`\`````P`\`````
MP`\`````Z@\`````Z@\`````Z@\`````Z@\`````Z@\`````Z@\`````Z@\`
M````Z@\``````A```````A```````A```````A``````!Q``````!Q``````
M'Q``````'Q``````'Q``````'Q``````'Q``````'Q``````'Q``````'Q``
M````'Q``````'Q``````'Q``````'Q``````41``````41``````7A``````
M7A``````7A``````:A``````:A``````:A``````:A``````:A``````:A``
M````Z@\`````4@X`````6`X`````7`X`````7`X`````J!``````J!``````
MD@\`````90X`````90X`````=@X`````>@X`````?@X`````?@X`````:A!1
M$```D`X`````E`X`````F`X`````O0X`````O0X`````T0X`````V0X`````
MZ0X`````#`\`````"`\`````)@\`````)@\`````.P\`````4P\`````-Q``
M````;@\`````<@\`````F@\`````@@\`````@@\`````W0X`````W0X`````
MK`\`````K`\`````Q`\`````H!``````H!``````\@\`````]@\`````"Q``
M````#Q``````#Q``````$Q``````'Q``````'Q``````0!``````21``````
M9A``````9A``````;Q``````;Q``````?Q``````A!``````A!``````B!``
M````G!``````I!``````I!```````A#J#P``F!``````R!``````S!``````
MT!``````U!``````;0YJ$```;0YJ$```;0YJ$```+@\0#P``+@\0#P``+@\0
M#P``9`\0#P``9`\0#P``9`\0#P``,PX`````,PX`````^PX`````^PX`````
M@@\`````@@\`````'Q``````'Q``````'Q``````'Q``````'Q``````'Q``
M````'Q``````'Q``````'Q``````'Q``````D`X`````,PX`````,PX`````
M,PX`````,PX`````.`X`````.`X`````S0X`````S0X`````P0X`````P0X`
M````(0\`````(0\`````@@\`````@@\`````@@\`````@@\`````?Q``````
M?Q``````$`\`````;0YJ$```;0YJ$```;0YJ$```P0X`````P0X`````Z0X`
M````F!``````9`\`````9`\`````,PX`````,PX`````.`X`````.`X`````
MC0\`````C0\`````````````````````````````````````````````````
M`````````````````````````````````````````````````````0(`````
M```"`@````````,"````````!`(````````%`@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````D"
M````````40(```````!^`@```````-("````````#PX```````#3`@``````
M`,\"````````=P(```````"(`@```````(D"````````R`(````````H!```
M`````"\"````````(0(```````!=`@```````,P"````````*0X````````J
M#@```````"L.````````+`X````````M#@```````"X.````````+PX`````
M```P#@```````#$.````````,@X````````]`@```````#H"````````+`0`
M```````M!````````"X$````````50(```````#'`@```````#,.````````
M2@X```````!@#@```````&T.````````BPX```````"Y#@```````,$.````
M````X0X```````#[#@```````!`/````````(0\````````N#P```````%L/
M````````9`\```````""#P```````*</````````M`\```````#`#P``````
M`.H/`````````A`````````?$````````$00````````41````````!:$```
M`````%X0````````:A````````"*`@```````,X"````````BP(````````/
M`@```````!L"````````#`(````````S#@```````$H.````````8`X`````
M``!M#@```````(L.````````N0X```````#!#@```````.$.````````^PX`
M```````0#P```````"$/````````+@\```````!;#P```````&0/````````
M@@\```````"G#P```````+0/````````P`\```````#J#P````````(0````
M````'Q````````!$$````````%$0````````6A````````!>$````````&H0
M````````C`(````````P!````````(T"````````,P0`````````````````
M```````````````````````````````````````````````````````&`@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````)`@```````%("````
M````#@X````````0#@````````T.````````$0X````````Q!````````,("
M````````%`(```````#%`@```````#,.````````A@(````````O!```````
M`"`"````````Q@(````````0`@```````$H#````````*00````````K#@``
M`````"P.````````#0(```````#X$````````,,"````````9P(````````9
M`@```````"H.````````@@\```````"'`@```````"H.S0(M#@``*@[-`BL.
M```L#LT"+0X``%8"````````,PX````````S#@```````#,.````````,PX`
M```````S#@```````#,.````````.`X```````!@#@```````(L.````````
MBPX```````"+#@```````(L.````````^PX```````#[#@```````/L.````
M````^PX```````"&#@```````&0/````````@@\```````""#P```````((/
M````````@@\```````""#P```````"L$````````C0\````````?$```````
M`!\0````````'Q`````````?$````````%X0````````E!````````#J#^H/
M`````#,.````````,PX````````S#@```````#,.````````,PX````````S
M#@```````#@.````````8`X```````"+#@```````(L.````````BPX`````
M``"+#@```````/L.````````^PX```````#[#@```````/L.````````A@X`
M``````!D#P```````((/````````@@\```````""#P```````((/````````
M@@\````````J!````````(T/````````'Q`````````?$````````!\0````
M````'Q````````!>$````````)00````````7A````````#X$`@(,!$(")@2
M"`C,$@@(``````````````````````$````*````9````.@#```0)P``H(8!
M`$!"#P"`EI@``.'U!0`````````````````````````````````````?'!\>
M'QX?'QX?'A\```````````````````````````$`````````"@````````!D
M`````````.@#````````$"<```````"@A@$``````$!"#P``````@):8````
M````X?4%``````#*FCL``````.0+5`(`````Z'9(%P`````0I=3H`````*!R
M3A@)````0'H0\UH```"`QJ1^C0,```#!;_*&(P```(I=>$5C`0``9*>SMN`-
M``#HB00CQXH``0(#!`4&_SH`````````````````````````````````````
M`/`_````````)$````````!90```````0(]```````"(PT```````&KX0```
M``"`A"Y!`````-`28T$`````A->700````!ES<U!````````````````````
M`````````/`_````(%^@`D)`C+5X':\51.J,H#E9/BE&I5S#\2EC/4B:9'[%
M#AM12D3SPN3DZ6-,/<?=UKHN=TY?^_!1[_R*4,=9*0D/:Y]2````````````
M``````````````!(7@@(E%X(""!?"`CT@`<(H&$("(!?"`A@70@(F%\("```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````,`_)0@`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````,`^)0@`
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#`/24(````
M`,`\)0@`````P#LE"`````#`.B4(`````,`Y)0@!``````````$`````````
M`0`````````!``````````$``````````0`````````!``````````$`````
M`````0`````````!``````````$``````````0`````````!``````````$`
M`````````0`````````!``````````$``````````0`````````!````````
M``$``````````0`````````!``````````$``````````0`````````!````
M``````$``````````````,`X)0@!``````````$``````````0`````````!
M``````````$``````````0`````````!``````````$``````````0``````
M```!``````````$``````````0`````````!``````````$``````````0``
M```````!``````````$``````````0`````````!``````````$`````````
M`0`````````!``````````$``````````0`````````!``````````$`````
M`````0`````````!``````````$``````````0`````````!``````````$`
M`````````0`````````!``````````$``````````0`````````!````````
M``$``````````0`````````!``````````$``````````0`````````!````
M``````$``````````0`````````!``````````$``````````0`````````!
M``````````$``````````0`````````!``````````$``````````0``````
M```!``````````$``````````0`````````!``````````$``````````0``
M```````!``````````$``````````0`````````!``````````$`````````
M`0`````````!``````````$``````````0`````````!``````````$`````
M`````0`````````!``````````$``````````0`````````!``````````$`
M`````````0`````````!``````````$``````````0``````````````P#<E
M"`$``````````0`````````!``````````$``````````````,`V)0@`````
M````````````````````````````````````````````````````````````
M``````````$``````````0`````````!``````````$``````````0``````
M```!``````````$``````````0`````````!``````````$``````````0``
M```````!``````````$``````````0`````````!``````````$`````````
M`0`````````!``````````$``````````0`````````!``````````$`````
M`````0`````````!``````````$``````````0`````````!``````````$`
M`````````0`````````!``````````$``````````0`````````!````````
M``$``````````0`````````!``````````$``````````0`````````!````
M``````$``````````0`````````!``````````$``````````````,`U)0@`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````!````````
M``````#`-"4(`````````````````````````````````````,`S)0@`````
MP#(E"``!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````0$!`0$!`0``````````````````````````````````````````````
M```````````````````````````````````````````````````!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!
M`0$!``$!`0$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0```0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$`
M```!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!````````````````````````````````````````````
M`````````````````````````````````0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!````````````````````````````````````````````
M```````````````````````````````````````````````````````!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0````````````````$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$````````!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!``````$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0``````````````````
M`````````````````````````````````````````````````````````0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0```0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$```$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!````````````````
M```````````````````!`0$!`0$!`0$!`0$`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0``````````````````````````````````````````````````````
M`````````````````0$`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$```````$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````%``````````!>E(`
M`7P(`1L,!`2(`0``*````!P```"\)./_#`$````$`0````X(A0($`@````T%
M!`4```"&!(<#```H````2````)PEX_^J`0````0!````#@B%`@0"````#04$
M!0```(8$AP,````````!`````0````$```#4`````0```#X!```!````7@$`
M``P````HE00(#0```'AH"`@$````*($$"`4```!XC00(!@```$B%!`@*````
M_@,```L````0````%0`````````#````$$(E"`(```"(`P``%````!$````7
M````H)$$"!$```!XD00($@```"@````3````"```````````````````````
M`````````````````````````````````````````````/____\`````____
M_P``````````-$$E"```````````2I4$"%J5!`AJE00(>I4$"(J5!`B:E00(
MJI4$"+J5!`C*E00(VI4$".J5!`CZE00("I8$"!J6!`@JE@0(.I8$"$J6!`A:
ME@0(:I8$"'J6!`B*E@0(FI8$"*J6!`BZE@0(RI8$"-J6!`CJE@0(^I8$"`J7
M!`@:EP0(*I<$"#J7!`A*EP0(6I<$"&J7!`AZEP0(BI<$")J7!`BJEP0(NI<$
M",J7!`C:EP0(ZI<$"/J7!`@*F`0(&I@$""J8!`@ZF`0(2I@$"%J8!`AJF`0(
M>I@$"(J8!`B:F`0(JI@$"+J8!`C*F`0(VI@$".J8!`CZF`0("ID$"!J9!`@J
MF00(.ID$"$J9!`A:F00(:ID$"'J9!`B*F00(FID$"*J9!`BZF00(RID$"-J9
M!`CJF00(^ID$"`J:!`@:F@0(*IH$"#J:!`A*F@0(6IH$"&J:!`AZF@0(BIH$
M")J:!`BJF@0(NIH$",J:!`C:F@0(ZIH$"/J:!`@*FP0(&IL$""J;!`@ZFP0(
M2IL$"%J;!`AJFP0(>IL$"(J;!`B:FP0(JIL$"+J;!`C*FP0(VIL$".J;!`CZ
MFP0("IP$"!J<!`@JG`0(.IP$"$J<!`@`1T-#.B`H1TY5*2!C(#(N.34N-"`R
M,#`R,#,R,"!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=
M``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N
M,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z
M("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E
M94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I
M(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T`
M`$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS
M(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@
M*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E
M0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@
M,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``
M1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@
M6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H
M1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"
M4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S
M+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'
M0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;
M1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'
M3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)3
M1%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N
M-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#
M0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&
M<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.
M52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$
M70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT
M+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#
M.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R
M965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5
M*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=
M``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N
M,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z
M("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E
M94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I
M(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T`
M`$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS
M(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@
M*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E
M0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@
M,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``
M1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@
M6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H
M1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"
M4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S
M+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'
M0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;
M1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'
M3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)3
M1%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N
M-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#
M0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&
M<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.
M52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$
M70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT
M+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#
M.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R
M965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5
M*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=
M``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N
M,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z
M("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E
M94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I
M(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T`
M`$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``@``````````0```#`Q+C`Q
M`````"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YR96PN8G-S`"YR96PN<&QT`"YI;FET`"YT97AT`"YF
M:6YI`"YR;V1A=&$`+F1A=&$`+F5H7V9R86UE`"YD>6YA;6EC`"YC=&]R<P`N
M9'1O<G,`+FIC<@`N9V]T`"YC;VUM96YT`"YN;W1E````````````````````
M````````````````````````````````````"P````$````"````](`$"/0`
M```9```````````````!`````````!,````'`````@```!"!!`@0`0``&```
M````````````!``````````A````!0````(````H@00(*`$``"`$```$````
M``````0````$````)P````L````"````2(4$"$@%```P"```!0````$````$
M````$````"\````#`````@```'B-!`AX#0``_@,``````````````0``````
M```W````"0````(```!XD00(>!$``"@````$````%`````0````(````0```
M``D````"````H)$$"*`1``"(`P``!`````D````$````"````$D````!````
M!@```"B5!`@H%0``"P``````````````!`````````!$`````0````8````T
ME00(-!4``"`'``````````````0````$````3P````$````&````5)P$"%0<
M```DS`,````````````$`````````%4````!````!@```'AH"`AXZ`,`!@``
M````````````!`````````!;`````0````(```"`:`@(@.@#`.AJ$```````
M`````"``````````8P````$````#````@.,8"(!3%`!`70P````````````@
M`````````&D````!`````@```,!`)0C`L"``=```````````````!```````
M``!S````!@````,````T024(-+$@`,@````%``````````0````(````?```
M``$````#````_$$E"/RQ(``(```````````````$`````````(,````!````
M`P````1")0@$LB``"```````````````!`````````"*`````0````,````,
M0B4(#+(@``0```````````````0`````````CP````$````#````$$(E"!"R
M(`#0`0`````````````$````!````#L````(`````P```.!#)0C@LR``@-8`
M````````````(`````````"4`````0``````````````X+,@`!@+````````
M``````$`````````G0````<``````````````/B^(``4```````````````!
M``````````$````#```````````````,OR``HP```````````````0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO<V)I;B]P86-K86=E
M;6YG````````````````````````````````````````````````````````
M````````````````````````````,#$P,#4U,``P,#(S-#(W`#`P,#<V-#$`
M,#`P,3`R-#$U-3``,3`T,3<S-C,P,C$`,#$V-3<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````']%3$8!`0$)```````````"
M``,``0```,BH!`@T````,#\A```````T`"``!@`H`!L`&@`&````-````#2`
M!`@T@`0(P````,`````%````!`````,```#T````](`$"/2`!`@9````&0``
M``0````!`````0``````````@`0(`(`$"%"U%`!0M10`!0`````0```!````
M8+44`&!%&0A@11D(4'T,`,!T#0`&`````!````(````H+R$`*+\E""B_)0CP
M````\`````8````$````!````!`!```0@00($($$"!@````8````!`````0`
M```O=7-R+VQI8F5X96,O;&0M96QF+G-O+C$`````"`````0````!````1G)E
M94)31``0>@<`@P```*T````6``````````````"@````7````$````!4````
M/````$T````_`````````%D````;````B@```*0````?`````````#<```"K
M````G@``````````````A0```$@```!V`````````)<`````````<````'D`
M```:`````````&H``````````````'T`````````=0```*H`````````8@``
M`"````"<````E0```'0````8`````````)H````Y```````````````3````
M@``````````&````*`````````"E````7@````````"I````00```((`````
M````H@```%H````Q````;P```(P````<``````````````!L`````````#T`
M``!+````AP````L``````````````"X```!\````I@```$(```"A````D@``
M`*<```"8````B````!D````B````D````)\`````````B0````````!Q````
M``````@```````````````H```"3````@P```*@```!W````@0```"L```!3
M````40``````````````K````!$```!I`````````#4``````````````&4`
M````````?@```(X```"=````50```)0```"9````A@```(L```!%````````
M`````````````````````````````0``````````````````````````````
M````````````````#0``````````````````````````````````````````
M```````````````%`````````!``````````````````````````````````
M``````````````````````````````0````#````````````````````"0``
M```````G```````````````>````````````````````,P```"\`````````
M``````````````````````(````X````!P``````````````````````````
M`````````!4`````````.@```$0`````````)0```"P````D`````````#8`
M`````````````$<````I````.P```````````````````"H`````````,@``
M```````,`````````"$```!8````3`````````!0``````````````!/````
M#P````````!6````2@``````````````9@```$,````P````4@`````````C
M``````````````!)````)@```!0```!H`````````&<````=````;0```"T`
M````````>````'L````^``````````````!K`````````$X```!C````70``
M`#0```!D`````````',```!A````````````````````;@````````!@````
MC0```)$`````````6P```'\``````````````!(````````````````````7
M````CP``````````````<@````X```";````7P``````````````5P```*,`
M``"6````1@```(0```!Z`````````````````````````%,!``!HGP0(I0``
M`!(````+````>)\$"``````2````+`$``(B?!`BJ````$@```&@!``"8GP0(
M^@```!(```!Z`0``P,(E"`0````1`!<`M@4``*B?!`@H````$@```(0!``"X
MGP0(6@```!(````L````R)\$""\````2````O@4``-B?!`A9````$@```,<%
M``#HGP0(`````!(```#5!0``^)\$""0````2````W@4```B@!`@`````$@``
M`)(!```8H`0(.P$``!(```#F!0``**`$"%L````2````[P4``#B@!`@`````
M$@```)D!``!(H`0(`````!(```"A`0``6*`$"!\````2````*@```&B@!`AL
M````$@```+4!``!XH`0(/````!(````2````*+\E"``````1`/'_]P4``(B@
M!`@G````$@```-P!``"8H`0(3````!(```#\!0``J*`$"*(````2````#`(`
M`+B@!`BU````$@````4&``#(H`0(/0```!(````3`@``V*`$"``````2````
M&0(``.B@!`A;````$@```"P"``#XH`0(\````!(````-!@``"*$$"#@````2
M````&08``!BA!`C`!P``$@```#D"```HH00(\0```!(````?!@``.*$$"&(`
M```2````)@8``$BA!`A,`0``$@```"P&``!8H00(X0```!(````;````:*$$
M"``````2````-`8``'BA!`A]````$@```$\"``#$PB4(!````!$`%P`Z!@``
MB*$$"``````2````(04``)BA!`BY````$@```$,&``"HH00(`````!(````B
M````N*$$"!H!```2````2`8``,BA!`B'````$@```"D```#8H00(?````!(`
M``!1!@``Z*$$""\"```2````608``/BA!`@`````$@```&`&```(H@0(````
M`!(```!G!@``&*($"*(````2````,P```"BB!`B(````$@```%D"```XH@0(
M*0$``!(```!O!@``2*($"&8$```2````:P(``,C")0@L````(0`7`)0"``!8
MH@0(H0```!(```">`@``:*($""L````2````I0(``'BB!`@@````$@```-8"
M``"(H@0(I````!(```#T`@``F*($"),````2````^@(``*BB!`B$````$@``
M`#H```!,GP0(`````!(`"@!X!@``N*($"%T````2````?@8``,BB!`A/`@``
M$@```(4&``#8H@0(`````!(```"3!0``Z*($"`P!```2````B@8``/BB!`@`
M````$@```)(&```(HP0(S0```!(````*`P``&*,$"`L$```2````'P,``/C"
M)0@(````(0`7`)L&````PR4(!````!$`%P!`````**,$"$(````2````HP8`
M`#BC!`@E````$@```"8!``!(HP0(`````!(```"I!@``$+0F"`0````1`!<`
M,`,``%BC!`@`````$@```$<```!HHP0(*@```!(```!/````>*,$"``````2
M````#@@``""Z)@@`````$`#Q_[$&``"(HP0(`````!(```"W!@``F*,$"```
M```2````5@```*BC!`@@````(@```,(&``"XHP0(%`4``!(````V`P``",,E
M"!`````A`!<`6`,``!C#)0@$````(0`7`,X&``!@11D(!````!$`#P#9!@``
MR*,$"``````2````;@```-BC!`@9````$@```'$#``#HHP0(*````!(```#?
M!@``^*,$"``````2````Y@8```BD!`AP````$@```'<````8I`0(`````!(`
M``#;````**0$"&8````2````[08``!0%!0A!````$@`,`.<````XI`0(````
M`!(```#O````2*0$"#D````2````]08``%BD!`@`````$@```/P&``!HI`0(
M`````!(````&!P``>*0$",X!```2````#0<``(BD!`CP````$@```(0#``"8
MI`0(8P$``!(```"8`P``J*0$"'(!```2````]P```!S#)0@$````$0`7`#<!
M``"XI`0(V0```!(````8!P``R*0$"``````2````H`,``-BD!`AR````$@``
M`!T'``#HI`0(3@```!(````I!P``^*0$"#,````2````"@$```BE!`@Z````
M$@```*<#```8I00(4`$``!(```!V````**4$"/D````2````$@$``#BE!`A6
M````$@```+\#```@PR4(+````"$`%P#E`P``2*4$"'$````2````+P<``%BE
M!`CX`@``$@```#<'``!HI00(`````!(```!\````>*4$"*<````2`````0@`
M`+#")0@`````$`#Q_X(```"(I00(`````!(````_!P``6`4%"'(````2``P`
MB0```)BE!`@-`0``$@```/$#``"HI00(:`$``!(```!'!P``N*4$"(`````2
M````3P<``,BE!`A#````$@```%0'``#8I00()0```!(````S!```Z*4$"```
M```2````.`0``/BE!`A5````$@```!D!```(I@0(`````!(```!<!P``&*8$
M"``````2````90<``"BF!`CR````$@```$H$```XI@0(;P```!(```!N!P``
M2*8$"%(&```2````=0<``%BF!`AL````$@```(,'``!HI@0([@```!(```"0
M````D+D("``````2``T`C`<``'BF!`C9````$@```+\%``"(I@0(60```!(`
M``!=!```F*8$"$L````2````F@<``*BF!`A,`0``$@```*$'``"XI@0(````
M`!(```"M!P``R*8$".L````2````<P0``-BF!`C=````$@```(($``#HI@0(
M;0```!(```"6````^*8$"($````2````F@0```BG!`B1````$@```+8'```8
MIP0(-@```!(````Q`P``**<$"``````2````K`0``#BG!`C8````$@```"4!
M``!(IP0(EP```!(```#Z!P``L,(E"``````0`/'_G````$S`)0@`````$0#Q
M_PT(```@NB8(`````!``\?_%!```6*<$"#L````2````]00``&BG!`B9````
M$@```)P'``!XIP0(6P```!(```#"!P``B*<$")H````2````(`$``)BG!`@G
M````$@```)T%``"HIP0(N0```!(```"R````N*<$""4````B````+@$``,BG
M!`@N````$@```(D%``#8IP0(J@$``!(```#[!```Z*<$"*0````2````.0$`
M`/BG!`@`````$@```!D%```(J`0(`````!(````@!0``&*@$"(D````2````
MRP<``"BH!`AG````$@```"8%`````````````"`````Z!0``.*@$"((````2
M````U`<``$BH!`@`````$@```-H'``!8J`0(`````!(```#A!P``:*@$"```
M```2````B@```'BH!`@`````$@```.<'``"(J`0(.@```!(```#O!P``F*@$
M"%L````2````R````*BH!`BV````$@```%D%``"XJ`0(4````!(`````;&EB
M>BYS;RXR`'-T<F-P>0!?1%E.04U)0P!M96UC<'D`;6%L;&]C`'9S;G!R:6YT
M9@!F9FQU<V@`7VEN:70`8V%L;&]C`&9P<FEN=&8`<W1R8V%T`%]?9&5R96=I
M<W1E<E]F<F%M95]I;F9O`%]?97)R;W(`9G)E860`9F]P96X`;65M<V5T`&9C
M;&]S90!?9FEN:0!F<'5T8P!?1TQ/0D%,7T]&1E-%5%]404),15\`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`&9R964`;&EB8W)Y<'0N<V\N,@!?7U]R=6YE='EP
M90!S=')N8VUP`'-T<FYC<'D`7T-U<G)E;G12=6YE3&]C86QE`'-T<FYC870`
M<W1R9'5P`'-T<F-M<`!A=&]I`&9W<FET90!U;F-O;7!R97-S`&9D;W!E;@!L
M:6)S=&1C*RM?<&QE<VLN<V\N-@!?7V-X85]F<F5E7V5X8V5P=&EO;@!?6DY3
M<S9A<W-I9VY%4$MC:@!?7W-T9&]U='``7U]C>&%?<F5T:')O=P!U;F=E=&,`
M;65M;6]V90!?6DY3=#EE>&-E<'1I;VY$,D5V`%]:3CE?7V=N=5]C>'@Q.%]?
M97AC:&%N9V5?86YD7V%D9$505FEI`%]:4W0Q.%]28E]T<F5E7V1E8W)E;65N
M=%!3=#$X7U)B7W1R965?;F]D95]B87-E`&=E=&5N=@!F;&]O<@!?6DY+4W,W
M8V]M<&%R94502V,`7UI.4W-#,4522U-S`%]?8WAA7V-A;&Q?=6YE>'!E8W1E
M9`!?7W-T9&5R<G``7UI.4W,V87-S:6=N15)+4W,`7UI45DXQ,%]?8WAX86)I
M=C$R,%]?<VE?8VQA<W-?='EP95]I;F9O10!?6DY3<T0Q178`7UID;%!V`%]:
M4W0Q.%]28E]T<F5E7VEN8W)E;65N=%!+4W0Q.%]28E]T<F5E7VYO9&5?8F%S
M90!?6E-T,C!?7W1H<F]W7VQE;F=T:%]E<G)O<E!+8P!A8F]R=`!?7V-X85]E
M;F1?8V%T8V@`7U]G>'A?<&5R<V]N86QI='E?=C``7UI425-T.65X8V5P=&EO
M;@!F<W1A=`!?6DY3<S1?4F5P,C!?4U]E;7!T>5]R97!?<W1O<F%G944`7UI.
M4W,T7U)E<#$Q7U-?;6%X7W-I>F5%`%]?8WAA7W!U<F5?=FER='5A;`!?6DY3
M<SE?35]M=71A=&5%:FIJ`')E86QL;V,`<W-C86YF`%]:3E-T.&EO<U]B87-E
M-$EN:71#,45V`%]:5%9.,3!?7V-X>&%B:78Q,3=?7V-L87-S7W1Y<&5?:6YF
M;T4`7U]C>&%?=&AR;W<`7UI3=#(Y7U)B7W1R965?:6YS97)T7V%N9%]R96)A
M;&%N8V5B4%-T,3A?4F)?=')E95]N;V1E7V)A<V53,%]24U\`<&]L;`!?6DY3
M<S9A<'!E;F1%4DM3<P!?6DY3<T,Q15!+8U)+4V%)8T4`7UI.4W,Q,E]-7VQE
M86M?:&%R9$5V`%]:3E-S0S%%4DM3<VIJ`%]:3E-T.&EO<U]B87-E-$EN:71$
M,45V`%]?8WAA7V)E9VEN7V-A=&-H`%]?8WAA7V%L;&]C871E7V5X8V5P=&EO
M;@!?6E-T,3A?4F)?=')E95]I;F-R96UE;G104W0Q.%]28E]T<F5E7VYO9&5?
M8F%S90!?6FYW:@!?6E-T,C!?7W1H<F]W7V]U=%]O9E]R86YG95!+8P!S=')C
M:'(`9G!U=',`7TIV7U)E9VES=&5R0VQA<W-E<P!?6DY3<S1?4F5P,3!?35]D
M97-T<F]Y15)+4V%)8T4`7UI.4W,V87!P96YD15!+8VH`;&EB;2YS;RXR`&QI
M8F=C8U]S7W!L97-K+G-O+C$`7U]U;6]D9&DS`%]?=61I=F1I,P!?56YW:6YD
M7U)E<W5M90!L:6)C+G-O+C0`=V%I='!I9`!V<W!R:6YT9@!G971D=&%B;&5S
M:7IE`&=E=&QO9VEN`&-O;FYE8W0`<W1R97)R;W(`9V5T975I9`!A=&]L`&=E
M=&=R9VED`%]?<W)G970`7U]I;F5T7V%D9'(`<7-O<G0`9G-C86YF`&9G971S
M`&1I<FYA;64`97AE8VP`<F5A9&QI;FL`9'5P,@!E;F1P=V5N=`!S=')T;W5L
M`'-O8VME=`!S96QE8W0`<F5A9&1I<@!R96%L<&%T:`!A;&%R;0!S=')T;VP`
M<&EP90!S=')R8VAR`&)A<V5N86UE`&A?97)R;F\`:7-I;F8`96YV:7)O;@!C
M:&1I<@!S971S;V-K;W!T`&YL7VQA;F=I;F9O`%]?<')O9VYA;64`;'-T870`
M<V5T9VED`'-I9VYA;`!S=')L8W!Y`'5N;&EN:P!G971R=7-A9V4`<V5T96YV
M`'-T<F-A<V5C;7``9F]R:P!?7VEN971?;G1O80!E>&5C=@!R96=C;VUP`'-Y
M;6QI;FL`<W1R;&-A=`!R96=E>&5C`'1I;64`;W!E;F1I<@!S:'5T9&]W;@!G
M971P=W5I9`!G971C=V0`9V5T:&]S=&)Y;F%M90!G971P=VYA;0!G971S97)V
M8GEN86UE`&%T97AI=`!G971P965R;F%M90!R96=E<G)O<@!L;V-A;'1I;65?
M<@!G971G<FYA;0!C;&]S961I<@!F8VYT;`!S971U:60`;6MD:7(`<W1R<&)R
M:P!?7U]T;VQO=V5R`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`$=#0U\S+C``
M``````````````````````````````````````````````````````$`````
M````````````````````````````````````````````````````````````
M```````````````````````````````````!``````````(`````````````
M``````````$``````````0```````@`````````!````````````````````
M`0``````````````````````````````````````````````````````````
M`````0````$```````````````````````````````````````$`````````
M``````````````````````````````$``0`!```````````````"``(````"
M``````````````````````````````````````````$``0!U!0``$```````
M``!0)GD+```"`!((````````P,(E"`4%``#$PB4(!24``,C")0@%,P``^,(E
M"`5"````PR4(!4,```C#)0@%4```&,,E"`51```<PR4(!6,``"##)0@%;0``
M6,`E"`<!``!<P"4(!P(``&#`)0@'`P``9,`E"`<$``!HP"4(!P8``&S`)0@'
M!P``<,`E"`<(``!TP"4(!PD``'C`)0@'"@``?,`E"`<+``"`P"4(!PP``(3`
M)0@'#0``B,`E"`<.``",P"4(!P\``)#`)0@'$```E,`E"`<1``"8P"4(!Q(`
M`)S`)0@'$P``H,`E"`<5``"DP"4(!Q8``*C`)0@'%P``K,`E"`<8``"PP"4(
M!QD``+3`)0@'&@``N,`E"`<;``"\P"4(!QP``,#`)0@''0``Q,`E"`<>``#(
MP"4(!Q\``,S`)0@'(```T,`E"`<A``#4P"4(!R(``-C`)0@'(P``W,`E"`<D
M``#@P"4(!R8``.3`)0@')P``Z,`E"`<H``#LP"4(!RD``/#`)0@'*@``],`E
M"`<K``#XP"4(!RP``/S`)0@'+0```,$E"`<N```$P24(!R\```C!)0@',```
M#,$E"`<Q```0P24(!S(``!3!)0@'-```&,$E"`<U```<P24(!S8``"#!)0@'
M-P``),$E"`<X```HP24(!SD``"S!)0@'.P``,,$E"`<\```TP24(!ST``#C!
M)0@'/@``/,$E"`<_``!`P24(!T```$3!)0@'00``2,$E"`=$``!,P24(!T4`
M`%#!)0@'1@``5,$E"`=(``!8P24(!TD``%S!)0@'2@``8,$E"`=,``!DP24(
M!TT``&C!)0@'3@``;,$E"`=/``!PP24(!U,``'3!)0@'5```>,$E"`=5``!\
MP24(!U8``(#!)0@'5P``A,$E"`=8``"(P24(!UD``(S!)0@'6P``D,$E"`=<
M``"4P24(!UT``)C!)0@'7@``G,$E"`=?``"@P24(!V```*3!)0@'80``J,$E
M"`=B``"LP24(!V0``+#!)0@'90``M,$E"`=F``"XP24(!V<``+S!)0@':```
MP,$E"`=I``#$P24(!VH``,C!)0@':P``S,$E"`=L``#0P24(!VX``-3!)0@'
M;P``V,$E"`=P``#<P24(!W$``.#!)0@'<P``Y,$E"`=U``#HP24(!W8``.S!
M)0@'=P``\,$E"`=X``#TP24(!WD``/C!)0@'>@``_,$E"`=[````PB4(!WP`
M``3")0@'?0``",(E"`=^```,PB4(!W\``!#")0@'@```%,(E"`>!```8PB4(
M!X(``!S")0@'A```(,(E"`>%```DPB4(!X8``"C")0@'AP``+,(E"`>(```P
MPB4(!XD``#3")0@'B@``.,(E"`>+```\PB4(!XP``$#")0@'C0``1,(E"`>.
M``!(PB4(!X\``$S")0@'D```4,(E"`>1``!4PB4(!Y4``%C")0@'E@``7,(E
M"`>7``!@PB4(!Y@``&3")0@'F0``:,(E"`>:``!LPB4(!YL``'#")0@'G```
M=,(E"`>=``!XPB4(!YX``'S")0@'GP``@,(E"`>@``"$PB4(!Z$``(C")0@'
MH@``C,(E"`>D``"0PB4(!Z4``)3")0@'I@``F,(E"`>G``"<PB4(!Z@``*#"
M)0@'J0``I,(E"`>J``"HPB4(!ZL``*S")0@'K```Z%L*``#H%AH$`,,`_S50
MP"4(_R54P"4(`````/\E6,`E"&@`````Z>#_____)5S`)0AH"````.G0____
M_R5@P"4(:!````#IP/____\E9,`E"&@8````Z;#_____)6C`)0AH(````.F@
M_____R5LP"4(:"@```#ID/____\E<,`E"&@P````Z8#_____)73`)0AH.```
M`.EP_____R5XP"4(:$````#I8/____\E?,`E"&A(````Z5#_____)8#`)0AH
M4````.E`_____R6$P"4(:%@```#I,/____\EB,`E"&A@````Z2#_____)8S`
M)0AH:````.D0_____R60P"4(:'````#I`/____\EE,`E"&AX````Z?#^____
M)9C`)0AH@````.G@_O___R6<P"4(:(@```#IT/[___\EH,`E"&B0````Z<#^
M____):3`)0AHF````.FP_O___R6HP"4(:*````#IH/[___\EK,`E"&BH````
MZ9#^____);#`)0AHL````.F`_O___R6TP"4(:+@```#I</[___\EN,`E"&C`
M````Z6#^____);S`)0AHR````.E0_O___R7`P"4(:-````#I0/[___\EQ,`E
M"&C8````Z3#^____)<C`)0AHX````.D@_O___R7,P"4(:.@```#I$/[___\E
MT,`E"&CP````Z0#^____)=3`)0AH^````.GP_?___R78P"4(:``!``#IX/W_
M__\EW,`E"&@(`0``Z=#]____)>#`)0AH$`$``.G`_?___R7DP"4(:!@!``#I
ML/W___\EZ,`E"&@@`0``Z:#]____)>S`)0AH*`$``.F0_?___R7PP"4(:#`!
M``#I@/W___\E],`E"&@X`0``Z7#]____)?C`)0AH0`$``.E@_?___R7\P"4(
M:$@!``#I4/W___\E`,$E"&A0`0``Z4#]____)03!)0AH6`$``.DP_?___R4(
MP24(:&`!``#I(/W___\E#,$E"&AH`0``Z1#]____)1#!)0AH<`$``.D`_?__
M_R44P24(:'@!``#I\/S___\E&,$E"&B``0``Z>#\____)1S!)0AHB`$``.G0
M_/___R4@P24(:)`!``#IP/S___\E),$E"&B8`0``Z;#\____)2C!)0AHH`$`
M`.F@_/___R4LP24(:*@!``#ID/S___\E,,$E"&BP`0``Z8#\____)33!)0AH
MN`$``.EP_/___R4XP24(:,`!``#I8/S___\E/,$E"&C(`0``Z5#\____)4#!
M)0AHT`$``.E`_/___R5$P24(:-@!``#I,/S___\E2,$E"&C@`0``Z2#\____
M)4S!)0AHZ`$``.D0_/___R50P24(:/`!``#I`/S___\E5,$E"&CX`0``Z?#[
M____)5C!)0AH``(``.G@^____R5<P24(:`@"``#IT/O___\E8,$E"&@0`@``
MZ<#[____)63!)0AH&`(``.FP^____R5HP24(:"`"``#IH/O___\E;,$E"&@H
M`@``Z9#[____)7#!)0AH,`(``.F`^____R5TP24(:#@"``#I</O___\E>,$E
M"&A``@``Z6#[____)7S!)0AH2`(``.E0^____R6`P24(:%`"``#I0/O___\E
MA,$E"&A8`@``Z3#[____)8C!)0AH8`(``.D@^____R6,P24(:&@"``#I$/O_
M__\ED,$E"&AP`@``Z0#[____)93!)0AH>`(``.GP^O___R68P24(:(`"``#I
MX/K___\EG,$E"&B(`@``Z=#Z____):#!)0AHD`(``.G`^O___R6DP24(:)@"
M``#IL/K___\EJ,$E"&B@`@``Z:#Z____):S!)0AHJ`(``.F0^O___R6PP24(
M:+`"``#I@/K___\EM,$E"&BX`@``Z7#Z____);C!)0AHP`(``.E@^O___R6\
MP24(:,@"``#I4/K___\EP,$E"&C0`@``Z4#Z____)<3!)0AHV`(``.DP^O__
M_R7(P24(:.`"``#I(/K___\ES,$E"&CH`@``Z1#Z____)=#!)0AH\`(``.D`
M^O___R74P24(:/@"``#I\/G___\EV,$E"&@``P``Z>#Y____)=S!)0AH"`,`
M`.G0^?___R7@P24(:!`#``#IP/G___\EY,$E"&@8`P``Z;#Y____)>C!)0AH
M(`,``.F@^?___R7LP24(:"@#``#ID/G___\E\,$E"&@P`P``Z8#Y____)?3!
M)0AH.`,``.EP^?___R7XP24(:$`#``#I8/G___\E_,$E"&A(`P``Z5#Y____
M)0#")0AH4`,``.E`^?___R4$PB4(:%@#``#I,/G___\E",(E"&A@`P``Z2#Y
M____)0S")0AH:`,``.D0^?___R40PB4(:'`#``#I`/G___\E%,(E"&AX`P``
MZ?#X____)1C")0AH@`,``.G@^/___R4<PB4(:(@#``#IT/C___\E(,(E"&B0
M`P``Z<#X____)23")0AHF`,``.FP^/___R4HPB4(:*`#``#IH/C___\E+,(E
M"&BH`P``Z9#X____)3#")0AHL`,``.F`^/___R4TPB4(:+@#``#I</C___\E
M.,(E"&C``P``Z6#X____)3S")0AHR`,``.E0^/___R5`PB4(:-`#``#I0/C_
M__\E1,(E"&C8`P``Z3#X____)4C")0AHX`,``.D@^/___R5,PB4(:.@#``#I
M$/C___\E4,(E"&CP`P``Z0#X____)53")0AH^`,``.GP]____R58PB4(:``$
M``#IX/?___\E7,(E"&@(!```Z=#W____)6#")0AH$`0``.G`]____R5DPB4(
M:!@$``#IL/?___\E:,(E"&@@!```Z:#W____)6S")0AH*`0``.F0]____R5P
MPB4(:#`$``#I@/?___\E=,(E"&@X!```Z7#W____)7C")0AH0`0``.E@]___
M_R5\PB4(:$@$``#I4/?___\E@,(E"&A0!```Z4#W____)83")0AH6`0``.DP
M]____R6(PB4(:&`$``#I(/?___\EC,(E"&AH!```Z1#W____)9#")0AH<`0`
M`.D`]____R64PB4(:'@$``#I\/;___\EF,(E"&B`!```Z>#V____)9S")0AH
MB`0``.G0]O___R6@PB4(:)`$``#IP/;___\EI,(E"&B8!```Z;#V____):C"
M)0AHH`0``.F@]O___R6LPB4(:*@$``#ID/;__U6)Y8/L#%=64XG2C74(BU[\
MC7R>!(D]$+0F"(7;?BF#?0@`=".+10BC8$49"(`X`'06B?:`."]U"8U(`8D-
M8$49"$"`.`!U[+@HOR4(A<!T#(/$]%+HAOW__X/$$(/$]&B0N0@(Z';]___H
M%?;__X/D\(/L&(E<)`")="0$B7PD".@R!@``B40D`.@A_O__C67H6UY?R<.0
M58GE@^P(@#U,PR4(`'0/ZSB-=@"#P`2C:$49"/_2H6A%&0B+$(72=>NXJ*,$
M"(7`=!"#[`QHH*(E".@)^O__@\00Q@5,PR4(`<G#D%6XN*<$"(GE@^P(A<!T
M%8/L"&A0PR4(:*"B)0CHZ_W__X/$$*%(P"4(A<!T&[@`````A<!T$H/L#&A(
MP"4(Z!%6^_>#Q!")]LG#B?95B>6#[!#_-6C#)0AHO+D(".BJAP``@\00A<!T
M!8`X`'4V4?\U:,,E"&C3_A@(:+RY"`CH%'(``%C_-6C#)0CH*)H#`(/$#&C-
MN0@(:@%J`>B#FP``R<.04FH_:&"\"`C_-6C#)0CH(9\#`%C_-6C#)0CH]9D#
M`(/$#&C-N0@(:@%J`>A0FP``R<.)]E6)Y593@>P($```:/BI!`AJ#HMU".AJ
M^?__QP0D+`$``.@.^/__@\0,:``0``"-G?CO__]35NA94```@\0,4U9HX+D(
M".CZ]/__C67X6U[)PY")]E6)Y5=64X/L0(UUR%;_-0!&&0B-7=A3Z$3[__^+
M%6Q%&0C\N?____\QP(G7\J[WT8/$#$E14E/HI/W__X/L"&H!:.>Y"`CH#5L`
M`(/$%%#HS/C__X/L"&H`:.>Y"`CH]5H``(/$%%#H%/W__X/$#&B``0``:``"
M``#_==CHG_S__X/$$(/X_XG#='^#[`Q3Z`S]__^+1=B-6/2#Q!"!^PC#)0@/
MA8L```"-9?1;7E_)PXUV`(G'BT78C5CT@?L(PR4(=16#[`Q7Z`/\__^-=@"#
M[`Q0Z/?[__^#[`AJ_X/H!%#HN?3__X/$$(7`?]:#[`A64^AH_/__@\00@^P,
M5^O'C78`@^P,4.O*@^P0Z.[W__]?_S#H-O3__X/$$%!HG+L("&H!:@'HS)D`
M`(/$$.E7____@^P(:O^#Z`10Z%[T__^#Q!"%P`^/7/___X/L"%93Z`G\__^#
MQ!#I2O___Y!5B>575E.#['SH"E,``(/L#&H%Z,17``"#Q!!`#X2.`0``@^P(
M:/BI!`AJ#NB?]___QP0D+`$``.A#]O__Z.(%``"-1<B)!"3HWQ<``%A:C56H
M4FC8NP@(C5VX4^B?^?__@\00BW74C57,.=8/A(T!```[==1T+(M5N(MZ](L-
M&,,E""GY@_D!#X+^````:@%J`%=3Z,?W__^+1;B#Q!#&!#@LO^ZY"`C\N?__
M__\QP/*N]]%)5U%H[KD("%/HOOO__UA:C5804HE5E%/H[_C___R_\;D("+G_
M____,<#RKO?1@\0,25%H\;D("%/HCOO__XM]E(M/!(L1B0PD_U((@\00A,`/
MA$(!``"+392+002#[`B+$(U]F%!7_U(,B3PD4^B9^/__BT68C7CTN0C#)0B#
MQ!`Y^0^%HP$``#'`_+G_____O_6Y"`CRKO?125!1:/6Y"`A3Z"3[__^)-"3H
MO/G__X/$$(G&Z?G^__^)]HG'@^P(_W70C5W(4^C'`P``B3PDZ.?Y__^-=@"#
M[`QH^+D(".BW]/__@\00Z>W^__^-=@"#[`Q0Z,/Y__^-=@"#[`QJ`.BVE@``
M@\00Z6#^__^)]HG'BT6XC5CTO@C#)0@YWG2=@^P(:O^#Z`10Z%WR__^#Q!"%
MP'^(@^P(C4VH45/H"?K__X/$$.ES____@^P(_W6X_S5HPR4(Z(P,`@"#Q!"%
MP`^%G0```(M%N(U8]+\(PR4(.=\/A>(```"#[`C_=="-5<A2Z`L#``"#Q!"-
M9?1;7E_)P^DC_____+\5N@@(N?_____RKO?125!1:!6Z"`A3Z!;Z__^#Q!#I
MR_[__XG'BT68C5CTO@C#)0@YW@^$/____X/L"&K_@^@$4.BK\?__@\00A<`/
MCR;___^#[`B-5:A24^A3^?__@\00Z1'___^-=@"#[`S_-6C#)0CH2K@#`(/$
M$%!H!+P("&H!:@'HP)8``(/$$.D[____@^P(:O^#Z`10Z%+Q__^#Q!"%P`^/
M1/[__X/L"(U%J%!7Z/KX__^#Q!#I+_[__XGV@^P(:O^#Z`10Z"+Q__^#Q!"%
MP`^/!?___X/L"(U%J%!3Z,KX__^#Q!#I\/[__XGVZ7_^__^0B?95B>575E.!
M[$P0``"+70R#Y/"#[!"+$XD5!$89".@J6```BTT(28U#!(/Y`8F%V.___XF-
MM.___W]J="SHKW4``(7`HVC#)0@/A/8```"+G;3O__^%VW5HZ%O\__\QP)"-
M9?1;7E_)PXM;!/R_([H("(G>N0,```#SIG04OR:Z"`B)WKD'````\Z8/A80`
M``"#[`S_-7!%&0CHJN___S'`Z[Z)]H/L#/\U<$49".B6[___C67T6UZX`0``
M`%_)PY"#[`B+A=CO__^+,&CXJ00(:@[HL?/__\<$)"P!``#H5?+__X/$#&@`
M$```C9WH[___4U;HH$H``(/$#%-6:."Y"`CH0>___X/$$#'`Z4____^-=@#\
MORVZ"`B)WKD1````\Z8/A1/____H*OK__S'`Z2O___^-=@!*=""#[`Q0Z.3V
M__]3:"R\"`AJ`6H!Z/V4``"#Q!#I\_[__X/L#%#H)/;__XL0B00D_U((@\0,
M4&A7U0@(_S7$PB4(Z&CR___HH_'__^DH____B<?HE_'__X/L#%?HCO;__XGV
M58GE@?K__P``4XG#470%BUW\R<.#^`%T&87;=?*#[`QH;,,E".BB]?__@\00
MBUW\R<.#[`QH;,,E".B]\___@\00Z]55B>6Z__\``+@!````R>NL58GENO__
M```QP,GKGXUV`%6)Y5=64X/L+(M%"(M=#(E%U.LQ@^P(_W,,_W74Z-[___^+
M0Q"-</2Z",,E"(/$$#GRBWL(=1J#[`Q3Z*CP__^)^X/$$(7;=<N-9?1;7E_)
MPX/L"&K_@^@$4.B9[O__@\00A<!_T8/L"(U-V%%6Z$7V__^#Q!#KOX/L#%#H
MI_7__XUV`%6)Y5.#[!S_=0QH<,,E"(M=".AA%0``@\00/73#)0AT&HM`%(/L
M#(L04/]2"(D#@\00B=B+7?S)P@0`@^P,:@'H[_3__X/$#&H`:*"\"`A0Z._R
M__^0B?95B>575E.#[%"-1<A0:""_"`B-?=A7Z,'S__]96U=H<,,E".AT'```
M@\0,C4VH46@DOP@(C56XB<-2Z)WS___'!"0(````Z,'T__^)QEA:C56XQP:H
MO@@(C48$4E#H.N[__XDSC5VXB1PDZ(WO__^)/"3HA>___X/$#(U%J%!H*K\(
M"(U-N%'H4//__UE;C56X4FAPPR4(Z``<``"#Q`R-=<A6:"2_"`B)PU?H+//_
M_\<$)`@```#H4/3__XG&6%J-3@3'!JB^"`A74>C,[?__B3.)/"3H(N___XU=
MN(D<).@7[___@\0,C56H4F@WOP@(C46X4.CB\O__65N-=;A6:'##)0CHDAL`
M`(/$#(U-R%%H0;\("(G&5^B^\O__QP0D"````.CB\___B<-86HU#!,<#J+X(
M"%=0Z%[M__^)'HD\).BT[O__C5VXB1PDZ*GN__^#Q`R-=:A6:$6_"`B-5;A2
MZ'3R__]96XU-N%%H<,,E".@D&P``@\0,B<:-1<A0:$V_"`A7Z%#R___'!"0(
M````Z'3S__^)PUA:QP.HO@@(C5,$5U+H\.S__XD>B3PDZ$;N__^-7;B)'"3H
M.^[__X/$#(U-J%%H5+\("(UUN%;H!O+__UE;C46X4&APPR4(Z+8:``"#Q`R-
M5<A2:%Z_"`B)QE?HXO'__\<$)`@```#H!O/__XG#6%J-2P3'`ZB^"`A74>B"
M[/__B1Z)/"3HV.W__XU=N(D<).C-[?__@\0,C46H4&AEOP@(C76X5NB8\?__
M65N-5;A2:'##)0CH2!H``(/$#(U-R%%H)+\("(G&5^AT\?__QP0D"````.B8
M\O__B<-86HU#!,<#J+X("%=0Z!3L__^)'HD\).AJ[?__C5VXB1PDZ%_M__^#
MQ`R-5:A2:'N_"`B-=;A6Z"KQ__]96XU-N%%H<,,E".C:&0``@\0,B<:-1<A0
M:(B_"`A7Z`;Q___'!"0(````Z"KR__^)PUA:QP.HO@@(C5,$5U+HINO__XD>
MB3PDZ/SL__^-7;B)'"3H\>S__X/$#(U-J%%HC;\("(UUN%;HO/#__UE;C46X
M4&APPR4(Z&P9``"#Q`R-5<A2:)V_"`B)QE?HF/#__\<$)`@```#HO/'__XG#
M6%J-2P3'`ZB^"`A74>@XZ___B1Z)/"3HCNS__XU=N(D<).B#[/__@\0,C46H
M4&BEOP@(C76X5NA.\/__65N-5;A2:'##)0CH_A@``(/$#(U-R%%HJ[\("(G&
M5^@J\/__QP0D"````.A.\?__B<-86HU#!,<#J+X("%=0Z,KJ__^)'HD\).@@
M[/__C5VXB1PDZ!7L__^#Q`R-5:A2:+*_"`B-=;A6Z.#O__]96XU-N%%H<,,E
M".B0&```@\0,B<:-1<A0:+Z_"`A7Z+SO___'!"0(````Z.#P__^)PUA:QP.H
MO@@(C5,$5U+H7.K__XD>B3PDZ++K__^-7;B)'"3HI^O__X/$#(U-J%%HP[\(
M"(UUN%;H<N___UE;C46X4&APPR4(Z"(8``"#Q`R-5<A2:"2_"`B)QE?H3N__
M_\<$)`@```#H<O#__XG#6%J-2P3'`ZB^"`A74>CNZ?__B1Z)/"3H1.O__XU=
MN(D<).@YZ___@\0,C46H4&C/OP@(C76X5N@$[___65N-5;A2:'##)0CHM!<`
M`(/$#(U-R%%HU[\("(G&5^C@[O__QP0D"````.@$\/__B<-86HU#!,<#J+X(
M"%=0Z(#I__^)'HD\).C6ZO__C5VXB1PDZ,OJ__^#Q`R-5:A2:+B_"`B-=;A6
MZ);N__]96XU-N%%H<,,E".A&%P``@\0,B<:-1<A0:-V_"`A7Z'+N___'!"0(
M````Z);O__^)PUA:QP.HO@@(C5,$5U+H$NG__XD>B3PDZ&CJ__^-7;B)'"3H
M7>K__X/$#(U-J%%HXK\("(UUN%;H*.[__UE;C46X4&APPR4(Z-@6``"#Q`R-
M5<A2:/6_"`B)QE?H!.[__\<$)`@```#H*.___XG#6%J-2P3'`ZB^"`A74>BD
MZ/__B1Z)/"3H^NG__XU=N(D<).COZ?__@\0,C46H4&CZOP@(C76X5NBZ[?__
M65N-5;A2:'##)0CH:A8``(/$#(U-R%%H`L`("(G&5^B6[?__QP0D"````.BZ
M[O__B<-86HU#!,<#J+X("%=0Z#;H__^)'HD\).B,Z?__C5VXB1PDZ('I__^#
MQ`R-5:A2:`G`"`B-=;A6Z$SM__]96XU-N%%H<,,E".C\%0``@\0,B<:-1<A0
M:!/`"`A7Z"CM___'!"0(````Z$SN__^)PUA:QP.HO@@(C5,$5U+HR.?__XD>
MB3PDZ![I__^-7;B)'"3H$^G__X/$#(U-J%%H%\`("(UUN%;HWNS__UE;C46X
M4&APPR4(Z(X5``"#Q`R-5<A2:![`"`B)QE?HNNS__\<$)`@```#HWNW__XG#
M6%J-2P3'`ZB^"`A74>A:Y___B1Z)/"3HL.C__XU=N(D<).BEZ/__@\0,C46H
M4&@EP`@(C76X5NAP[/__65N-5;A2:'##)0CH(!4``(/$#(U-R%%H)+\("(G&
M5^A,[/__QP0D"````.AP[?__B<-86HU#!,<#J+X("%=0Z.SF__^)'HD\).A"
MZ/__C5VXB1PDZ#?H__^#Q`R-5:A2:"S`"`B-=;A6Z`+L__]96XU-N%%H<,,E
M".BR%```@\0,B<:-1<A0:"2_"`A7Z-[K___'!"0(````Z`+M__^)PUA:QP.H
MO@@(C5,$5U+H?N;__XD>B3PDZ-3G__^-7;B)'"3HR>?__X/$#(U-J%%H2<`(
M"(UUN%;HE.O__UE;C46X4&APPR4(Z$04``"#Q`R-5<A2:%/`"`B)QE?H<.O_
M_\<$)`@```#HE.S__XG#6%J-2P3'`ZB^"`A74>@0YO__B1Z)/"3H9N?__XU=
MN(D<).A;Y___@\0,C46H4&A9P`@(C76X5N@FZ___65N-5;A2:'##)0CHUA,`
M`(/$#(U-R%%H8<`("(G&5^@"Z___QP0D"````.@F[/__B<-86HU#!,<#J+X(
M"%=0Z*+E__^)'HD\).CXYO__C5VXB1PDZ.WF__^#Q`R-5:A2:&7`"`B-=;A6
MZ+CJ__]96XU-N%%H<,,E".AH$P``@\0,B<:-1<A0:&_`"`A7Z)3J___'!"0(
M````Z+CK__^)PUA:QP.HO@@(C5,$5U+H-.7__XD>B3PDZ(KF__^-7;B)'"3H
M?^;__X/$#(U-J%%H<\`("(UUN%;H2NK__UE;C46X4&APPR4(Z/H2``"#Q`R-
M5<A2:'S`"`B)QE?H)NK__\<$)`@```#H2NO__XG#6%J-2P3'`ZB^"`A74>C&
MY/__B1Z)/"3H'.;__XU=N(D<).@1YO__@\0,C46H4&B!P`@(C76X5NC<Z?__
M65N-5;A2:'##)0CHC!(``(/$#(U-R%%HC,`("(G&5^BXZ?__QP0D"````.C<
MZO__B<-86HU#!,<#J+X("%=0Z%CD__^)'HD\).BNY?__C5VXB1PDZ*/E__^#
MQ`R-5:A2:)/`"`B-=;A6Z&[I__]>6(U-N%%H<,,E".@>$@``B</'!"0$````
MZ(#J___'``B]"`B)`XU%N(D$).A=Y?__@\0,C76H5FB>P`@(C5VX4^@HZ?__
M65N-5;A2:'##)0CHV!$``(/$#(U-R%%HI<`("(G&5^@$Z?__QP0D"````.@H
MZO__B<-86HU#!,<#J+X("%=0Z*3C__^)'HD\).CZY/__C5VXB1PDZ._D__^#
MQ`R-5:A2:(V_"`B-=;A6Z+KH__]96XU-N%%H<,,E".AJ$0``@\0,B<:-1<A0
M:(V_"`A7Z);H___'!"0(````Z+KI__^)PUA:QP.HO@@(C5,$5U+H-N/__XD>
MB3PDZ(SD__^-7;B)'"3H@>3__X/$#(U-J%%HS[\("(UUN%;H3.C__UE;C46X
M4&APPR4(Z/P0``"#Q`R-5<A2:,^_"`B)QE?H*.C__\<$)`@```#H3.G__XG#
M6%J-2P3'`ZB^"`A74>C(XO__B1Z)/"3H'N3__XU=N(D<).@3Y/__@\0,C46H
M4&A6$!D(C76X5NC>Y___65N-5;A2:'##)0CHCA```(/$#(U-R%%HK,`("(G&
M5^BZY___QP0D"````.C>Z/__B<-86HU#!,<#J+X("%=0Z%KB__^)'HD\).BP
MX___C5VXB1PDZ*7C__^#Q`R-5:A2:+/`"`B-=;A6Z'#G__]96XU-N%%H<,,E
M".@@$```@\0,B<:-1<A0:+?`"`A7Z$SG___'!"0(````Z'#H__^)PUA:QP.H
MO@@(C5,$5U+H[.'__XD>B3PDZ$+C__^-7;B)'"3H-^/__X/$#(U-J%%HO<`(
M"(UUN%;H`N?__UE;C46X4&APPR4(Z+(/``"#Q`R-5<A2:,K`"`B)QE?HWN;_
M_\<$)`@```#H`NC__XG#6%J-2P3'`ZB^"`A74>A^X?__B1Z)/"3HU.+__XU=
MN(D<).C)XO__@\0,C46H4&C0P`@(C76X5NB4YO__65N-5;A2:'##)0CH1`\`
M`(/$#(U-R%%HXL`("(G&5^APYO__QP0D"````.B4Y___B<-86HU#!,<#J+X(
M"%=0Z!#A__^)'HD\).AFXO__C5VXB1PDZ%OB__^#Q`R-5:A2:.C`"`B-=;A6
MZ";F__]96XU-N%%H<,,E".C6#@``@\0,B<:-1<A0:.W`"`A7Z`+F___'!"0(
M````Z";G__^)PUA:QP.HO@@(C5,$5U+HHN#__XD>B3PDZ/CA__^-7;B)'"3H
M[>'__X/$#(U-J%%H\\`("(UUN%;HN.7__UY8C46X4&APPR4(Z&@.``")P\<$
M)`0```#HRN;__\<`.+X("(D#C56XB10DZ*?A__^#Q`R-=:A6:/G`"`B-7;A3
MZ'+E__]96XU-N%%H<,,E".@B#@``@\0,B<:-1<A0:!FZ"`A7Z$[E___'!"0(
M````Z'+F__^)PUA:QP.HO@@(C5,$5U+H[M___XD>B3PDZ$3A__^-7;B)'"3H
M.>'__X/$$(UE]%M>7\G#B?:)PX/L#%?H(>'__X/$$(/L#%/H9>;__Y")PX/L
M#%/K\H/L#,<&(+X("%:)P^@+X?__@\00@^P,C76X5NCLX/__@\00Z[V)P^OK
MB</KS8G#@^P,C7VX5^NNZ_.)PX/L#%?HQ^#__X/$$.OE@^P,QP8@O@@(5HG#
MZ,'@__^#Q!#KW(G&@^P,5NCQY?__@^P,QP,@O@@(4XG&Z*#@__^#Q!"#[`Q7
MZ(3@__^#Q!"#[`R-?;A7Z'7@__^#Q!"#[`Q6Z\:)QNOGZ_KKN.O!B<;KT>OP
MZ^[K[.NJZ[/K\.ODZ^+KH.NIZ^;KVNO8ZY;KG^O<Z]#KSNO,ZXKKD^O0Z\[K
MPNO`Z7O____KA.O!Z[7KL^EN____Z73____KL>NEZZ/I7O___^ED____ZZ'K
ME>N3Z4[____I5/___^N1ZX7K@^D^____Z43____K@>ER____Z6W____I<O__
M_^EC____Z5[____I&?___^D?____Z5G____I2O___^E%____Z0#____I!O__
M_^E`____Z3'____I+/___^GG_O__Z>W^___I)____^D8____Z1/____ISO[_
M_^G4_O__Z0[____I__[__^GZ_O__Z;7^___IN_[__^GU_O__Z>;^___IX?[_
M_^F<_O__Z:+^___IW/[__^G-_O__Z8C^___ICO[__^G(_O__Z;G^___IM/[_
M_^EO_O__Z77^___IK_[__^F@_O__Z9O^___I5O[__^D>_O__B</IY/W__^E0
M_O__Z8K^___I>_[__^EV_O__Z3'^___I-_[__^EQ_O__Z6+^___I7?[__^D8
M_O__Z1[^___I6/[__^E)_O__Z43^___I__W__^D%_O__Z3_^___I,/[__^DK
M_O__Z>;]___I[/W__^DF_O__Z1?^___I$O[__^G-_?__Z=/]___I#?[__^G^
M_?__Z?G]___IM/W__^FZ_?__Z?3]___IY?W__^G@_?__Z9O]___IH?W__^G;
M_?__Z<S]___IQ_W__^F"_?__Z8C]___IPOW__^FS_?__Z:[]___I:?W__^EO
M_?__Z:G]___IFOW__^F5_?__Z5#]___I5OW__Y")]E6)Y5=64X/L?(M="(U#
M!(E##(E%A(E#$,=#%`````#'0P0`````QT,(`````*%\PR4(/73#)0B)19QU
M#(UE](G86UY?R<($`(M(%(/L#(L14?]2"%Y?BWV<@\<05U.)19B)?93H0P0`
M`(MUA(/$$#GPB460=&R+=9R)PHM]D(M&$(M(](MW$(M&](F-?/___XE%@(E-
MI(N-?/___X/"$#E-@(E%H(U%H'(#C46DBS")=8R+18R+?92)P8LW.<"+.OSS
MI@^7P0^2PBC1#[[!A<!U"8N%?/___RM%@,'H'X3`=%Z#[`B-=;C_=916Z*/;
M__^#Q`Q6_W60QT6\`````%/H<PT``(E%D(M%N(UP](/$$('^",,E"(U]J'0D
M@^P(:O^#Z`10Z.K:__^#Q!"%P'\/@^P(5U;HF>+__X/$$(GVBT68BTV0B4$4
M@^P,_W6<Z*#A__^#Q!#IUO[__XG&@^P(_W,(4^BRZ___B30DZ-+A__^)QHM%
MN(UX]('_",,E"'3<@^P(:O^#Z`10Z(3:__^#Q!"%P'_'@^P(C56H4E?H,.+_
M_X/$$.NUC78`@^P,4.B/X?__ZZ6058GE@^PH@?K__P``=`+)PX/X`70<A<!U
M]8/L"/\U>,,E"&APPR4(Z%P#``"#Q!#)P\<%A,,E"`````#'!73#)0@`````
MQP5XPR4(`````,<%?,,E"'3#)0C'!8##)0ATPR4(Z["#[`Q0Z![A__^)]E6)
MY;K__P``N`$```#)ZX!5B>6Z__\``#'`R>EP____58GEBT4(QP`(O@@(R<.)
M]E6)Y8M%",<`"+X(",GIFMO__XGV58GE4U"+70B`>P0`=0H/MD,%BUW\R<.0
M@^P,BP-3_U`0QD,$``^V0P6#Q!"+7?S)PXUV`%6)Y8M%",<`(+X(",G#B?95
MB>6+10C'`""^"`C)Z4+;__^)]E6)Y593BUT,@'L$`(MU"'4;@^P(C5,(4E;H
MLMG__XUE^%N)\%[)P@0`C78`@^P,BP-3_U`0@\00@^P(C5,(QD,$`%)6Z(?9
M__^-9?A;B?!>R<($`%6)Y5=64X/L/(M%"(M8"(M5#(/`!(7;B57@B46XB47<
M=&^+"HM1](E-P(E5U.L+D(E=W(M;"(7;=%>+2Q"+0?2)1=B+==B+?=0Y==2)
M1?"-4Q")?>R-1>QR`XU%\(L`B470BS(YP(G!_(M]P/.F#Y?`#Y+"*-`/OL"%
MP'4&BT78*T74P>@?A,!TIHM;#(7;=:F+7;@Y7=QT68M=X(L3BTW<BT+TBWD0
MB46\BU_TBW7<@\80.UV\B47HB5WDC47D<@.-1>B+`(G!B47,BSXYP(G6_/.F
M#Y?!#Y+"*-$/OL&%P'4%BT6\*=C!Z!^$P(M5W'0#BU6X@\0\6UZ)T%_)PY!5
MB>575E.#[!R+10B+6`B#P`2%VXE%Z'1NBW4,BPZ+4?3\B4W8B57@ZPR)]HE=
MZ(M;"(7;=%&+<Q"+3O2)3>2+?>2+1>`Y?>")1>R-4Q")3?"-1>QR`XU%\(L(
MBS(YR8M]V/.F#Y?`#Y+"*-`/OL"%P'4&BT7D*T7@P>@?A,!TK(M;#(7;=:^+
M1>B#Q!Q;7E_)PXGV58GE5U93@^P<BT4(BU@(@\`$A=N)1>AT;HMU#(L.BU'T
M_(E-V(E5X.L,B?:)7>B+6PB%VW11BW,0BT[TB4WDBWWDBT7@.7W@B47LC5,0
MB4WPC47L<@.-1?"+"(LR.<F+?=CSI@^7P`^2PBC0#[[`A<!U!HM%Y"M%X,'H
M'X3`=*R+6PR%VW6OBT7H@\0<6UY?R<.)]E6)Y5=64X/L+(M%"(M=#(E%U.LQ
M@^P(_W,,_W74Z-[___^+0Q"-</2Z",,E"(/$$#GRBWL(=1J#[`Q3Z(38__^)
M^X/$$(7;=<N-9?1;7E_)PX/L"&K_@^@$4.AUUO__@\00A<!_T8/L"(U-V%%6
MZ"'>__^#Q!#KOX/L#%#H@]W__XUV`%6)Y5=64X/L.(M%"&H8B47HBW44Z"?=
M__^)PX/$$(/#$(E%S'03@^P(5E/HH-;__XM6!(/$$(E3!(M-#(M]Z(7)QD7G
M`(U?!'16QD7G`5/_=1#_=<P/ME7G4N@AV___BUWH_T,4BT7,@\00C67T6UY?
MR<.0@^P,4.ACW/__6?]US.BZU___@\00Z`+5__^)]HG#Z.G7__^#[`Q3Z.#<
M__\[71!TI8M5$(/"$(E5X(M-$(L6BW+TBWD0BT?TB770B474B77PBW70.774
MB47LC47L<@.-1?"+"(E-W(MUX(L&BWW<.?^+3=R)Q_R)UO.F#Y?`#Y+!*,@/
MOL"%P'4&BT70*T74P>@?A,`/A#_____I-O___U6)Y5=64X/L;(M%"(M("(E%
MQ(M5#(/`!(7)B46XB57`B4V\L`$/A(,```"+.HM7](E]G(E5M.L0BWV\BU\(
MB5V\BU6\A=)T9HM=O(M+$(M5O(MUM(M9](E5N(/"$#GSB77LB5WHC47H<@.-
M1>R+`(L2B46PB56L.<")UXG!_(MUG/.F#Y?`#Y+"*-`/OL"%P'4%BT6T*=C!
MZ!^$P'6:BTV\BW$,B76\BU6\A=)UFH3`BUVX=#N+?<0[7PQU)?]UP%/_=;Q7
MZ"+^__^)1>#&1>0!BT7@BU7D@\00C67T6UY?R<.#[`Q3Z''4__^)PX/$$(M[
M$(M7](M%P(E5E(E5W(L0BTKTBWV4.?F-<Q")39B)3=B-1=AR`XU%W(L`B<&)
M1:@YP(LV_(G7\Z8/DL`/E\$HP0^^P87`=0:+190K19C!Z!^$P'45B5W(QD7,
M`(M%R(M5S(UE]%M>7\G#_W7`_W6X_W6\_W7$Z(#]__^)1=#&1=0!BT70BU74
M@\00C67T6UY?R<-5B>575E.#['R+10B+30R+51`[2`R)1=")5<P/A',!``"+
M7="#PP0Y70P/A/0```"#[`S_=0SHG=/__XG"BUW,B46TBT`0BW#TBSN+7_2)
M=9"#Q!"#PA`[79")=>")?82)7=R-1=QR`XU%X(L`B46PBS(YP(G!_(M]A/.F
M#Y?`#Y+"*-`/OL"%P'4%BT60*=C!Z!^$P`^$90$``(M=#(M-A(MQ](M[$(M?
M](M5#(EUE(/"$#M=E(EUV(E=U(U%U`^#6P$``(L`BQ*)1:2)5:`YP(G7B<'\
MBW6$\Z8/E\`/DL(HT`^^P(7`=06+190IV,'H'X3`#X0&`0``BT6TBU@,A=L/
MA"`!``#_=<S_=0S_=0S_==#H3_S__XUE]%M>7\G#C78`BWW0BU\0BU,0BTW,
MBT+TBQ&)18R-<Q"+6O0[78R)1>B)7>2-1>0/@\@```"+`(G!B46\.<"+-OR)
MU_.F#Y+`#Y?!*,$/OL&%P'4%BT6,*=C!Z!^$P`^$@0```/]US(M5T/]R$&H`
M4NC8^___ZX>)]HMX%(7_=&6+?<R+-XM>](M!$(E=B(G*B5WPBUCT@\(0.UV(
MB5WLC47L<@.-1?"+,(EUR(L2B57$BT7(BWW,B<&+-SG`_(M]Q/.F#Y?!#Y+"
M*-$/OL&%P'4%BT6(*=C!Z!^$P`^%"____XUV`(/L"/]US/]UT.AN_/__C67T
M6UY?R<.)]HU%Z.DP____C478Z9W^____=<Q0:@#_==#IWO[__XGV58GE5U93
M@^Q4BTT,BU4(45*)5;R)3;CH:/G__XE%M(M%O(/`!(/$$#E%M'17BTVXBP&+
M7;2+>/2+<Q"+7O2+5;2)?:B#PA`[7:B)?<2)7<"-1<!S>XLXB7VPBT6XBTVP
MBS"+.OPYR?.F#Y?`#Y+"*-`/OL"%P'4%BT6H*=C!Z!^$P'0\@^P(_W6XC5W8
M4^AMT?__@\0,4_]UM,=%W`````#_=;SH'_W__XE%M(M%V(U8](/$$('[",,E
M"(UUR'5<BT6TC67T6UZ#P!1?R<.)]HU%Q.N`C78`B<:+1=B-6/2!^PC#)0B-
M?<AU"8/L#%;HO-?__X/L"&K_@^@$4.A^T/__@\00A<!_XH/L"%=3Z"W8__^#
MQ!"#[`Q6Z].#[`AJ_X/H!%#H5M#__X/$$(7`?X^#[`A64^@%V/__@\00ZX"#
M[`Q0Z&?7__^-=@!5B>575E.#[#B+10AJ&(E%Z(MU%.@+U___B<.#Q!"#PQ")
M1<QT$X/L"%93Z(30__^+5@2#Q!")4P2+?0R+3>B%_\9%YP"-601T5L9%YP%3
M_W40_W7,#[95YU+H!=7__XM=Z/]#%(M%S(/$$(UE]%M>7\G#D(/L#%#H1];_
M_UC_=<SHGM'__X/$$.CFSO__B?:)P^C-T?__@^P,4^C$UO__.UT0=*6+51"#
MPA")5>"+31"+%HMR](MY$(M'](EUT(E%U(EU\(MUT#EUU(E%[(U%['(#C47P
MBPB)3=R+=>"+!HM]W#G_BTW<B<?\B=;SI@^7P`^2P2C(#[[`A<!U!HM%T"M%
MU,'H'X3`#X0_____Z3;___]5B>575E.#[&R+10B+2`B)1<2+50R#P`2%R8E%
MN(E5P(E-O+`!#X2#````BSJ+5_2)?9R)5;3K$(M]O(M?"(E=O(M5O(72=&:+
M7;R+2Q"+5;R+=;2+6?2)5;B#PA`Y\XEU[(E=Z(U%Z'(#C47LBP"+$HE%L(E5
MK#G`B=>)P?R+=9SSI@^7P`^2PBC0#[[`A<!U!8M%M"G8P>@?A,!UFHM-O(MQ
M#(EUO(M5O(72=9J$P(M=N'0[BWW$.U\,=27_=<!3_W6\5^@B_O__B47@QD7D
M`8M%X(M5Y(/$$(UE]%M>7\G#@^P,4^A5SO__B<.#Q!"+>Q"+5_2+1<")592)
M5=R+$(M*](M]E#GYC7,0B4V8B4W8C478<@.-1=R+`(G!B46H.<"+-OR)U_.F
M#Y+`#Y?!*,$/OL&%P'4&BT64*T68P>@?A,!U%8E=R,9%S`"+1<B+5<R-9?1;
M7E_)P_]UP/]UN/]UO/]UQ.B`_?__B470QD74`8M%T(M5U(/$$(UE]%M>7\G#
M58GE5U93@^Q\BT4(BTT,BU40.T@,B470B57,#X1S`0``BUW0@\,$.5T,#X3T
M````@^P,_W4,Z('-__^)PHM=S(E%M(M`$(MP](L[BU_TB760@\00@\(0.UV0
MB77@B7V$B5W<C47<<@.-1>"+`(E%L(LR.<")P?R+?83SI@^7P`^2PBC0#[[`
MA<!U!8M%D"G8P>@?A,`/A&4!``"+70R+382+<?2+>Q"+7_2+50R)=92#PA`[
M792)==B)7=2-1=0/@UL!``"+`(L2B46DB56@.<")UXG!_(MUA/.F#Y?`#Y+"
M*-`/OL"%P'4%BT64*=C!Z!^$P`^$!@$``(M%M(M8#(7;#X0@`0``_W7,_W4,
M_W4,_W70Z$_\__^-9?1;7E_)PXUV`(M]T(M?$(M3$(M-S(M"](L1B46,C7,0
MBUKT.UV,B47HB5WDC47D#X/(````BP")P8E%O#G`BS;\B=?SI@^2P`^7P2C!
M#[[!A<!U!8M%C"G8P>@?A,`/A($```#_=<R+5=#_<A!J`%+HV/O__^N'B?:+
M6!2%VW1EBWW,BQ^+<_2+01"+6/2)RHEUB(/"$#M=B(EU\(E=[(U%['(#C47P
MBS")=<B+$HE5Q(M%R(M]S(G!BS<YP/R+?<3SI@^7P0^2PBC1#[[!A<!U!8M%
MB"G8P>@?A,`/A0O___^-=@"#[`C_=<S_==#H;OS__XUE]%M>7\G#B?:-1>CI
M,/___XU%V.F=_O___W7,4&H`_W70Z=[^__^)]E6)Y5=64X/L'(M="(M#"(UP
M]('^",,E"(U]V'4.QP,(O@@(C67T6UY?R<.#[`C'`ZB]"`B#Z`1J_U#H)<O_
M_X/$$(7`?]>#[`A75NC4TO__@\00Z\B#[`S'`PB^"`A0Z##2__]5B>575E.#
M[!R+70B+0PB-</2!_@C#)0B-?=AU&H/L#,<#"+X("%/HQ,S__X/$$(UE]%M>
M7\G#@^P(QP.HO0@(@^@$:O]0Z+7*__^#Q!"%P'_+@^P(5U;H9-+__X/$$.N\
M@^P,QP,(O@@(4.C`T?__58GE5U93@^P<BUT(BT,$C7#T@?X(PR4(C7W8=0['
M`R"^"`B-9?1;7E_)PX/L",<#J+X("(/H!&K_4.A1RO__@\00A<!_UX/L"%=6
MZ`#2__^#Q!#KR(/L#,<#(+X("%#H7-'__U6)Y5=64X/L'(M="(M#!(UP]('^
M",,E"(U]V'4:@^P,QP,@O@@(4^CPR___@\00C67T6UY?R<.#[`C'`ZB^"`B#
MZ`1J_U#HX<G__X/$$(7`?\N#[`A75NB0T?__@\00Z[R#[`S'`R"^"`A0Z.S0
M__]5B>6+10C'`""^"`C)PXGV58GEBT4(QP`@O@@(R>F*R___B?95B>6+10C'
M`""^"`C)PXGV58GEBT4(QP`@O@@(R>EFR___B?95B>564X/L#&H,Z%70__^)
MQHD$).B[!P``@\00C67X6XGP7LG#C78`@^P,B<-6Z#'+__^)'"3H:=#__Y!5
MB>6#["1J#.@;T/__QD`$`<9`!0#'0`@4PR4(QP`8P0@(@\00R<.058GE5E.#
M[`QJ".CQS___B<98BT4(6H/`!%!6Z.@&``"#Q!"-9?A;B?!>R<.#[`R)PU;H
MR<K__XD<).@!T/__D%6)Y5=64X'LD%```&C_#P``:@"-O>GO__^*'6?!"`B+
M10A7B)WH[___B85XK___Z*S-__^#Q`QH_P\``&H`C;7IW___5HB=Z-___^B0
MS?__@\0,:/\/``"-C>G/__]J`%&(G>C/___H=,W__X/$#&C_#P``C97IO___
M:@!2B)WHO___Z%C-__^#Q`QH`!```&H`C86(K___4.A"S?__Z"5-``"#Q!"%
MP(G##X0G`@``@^P(4VAGT0@(Z%)9``"#Q!"%P(G"=!8Q]HG'_+G_____B?#R
MKO?128/Y`7<+C67T6UY?R<.-=@!1:``0``!2C97H[___4NAQ+```6%I3:'C1
M"`CH"%D``(/$$(7`B<)TS(G'_+G_____B?#RKO?128/Y`7:X4&@`$```4HV=
MZ-___U/H-"P``%-HB=$("&@`$```C9WHS___4^AQQ___OY'1"`BY!0```/R-
MM>CO___SI@^7P@^2P8/$(#C*#X1[`0``4&@`$```:);1"`A3Z"PL``"#Q`QH
M`!```&A8P0@(C97HO___4NC/*P``7E^-A8B___]04^C4S?__@\000`^$)___
M_P^WE9"___^)UX'G`/```('_`(```'4*]L8!=`6#XD!U$E-HV-$("&H!:@'H
M0FP``(/$$(/L#(VU@*___U;H.,G__X/$$(7`#X74`0``Z!C+__^%P(G&#X3_
M````@^P,_[6$K___Z+#.__^#Q!"#_O\/A/\!``!1:@*-G7RO__]35NC$Q?__
M@\000`^$NP$``%=H`!```(V%B*___U#_M8"O___H$LK__X/$$$`/A.T!``"#
M[`S_M8"O___H6L[__XJ%B*___X/$$(3`C96(K___=`Z-=@`\"G0'0HH"A,!U
M]<8"`/PQP(V]B*___[G_____\J[WT4E348NU>*___XV]B*___U>#Q@A6Z"O%
M__^+E7BO__^#Q!#&0@4!Z0;^__]6:"R\"`AJ`6H!Z$)K``"#Q!#IPOW__U!H
M`!```&B=T0@(4^BQ*@``@\0,:``0``!H7L$(".F`_O__@^P,4^AVRO__B00D
MB<?HC,;__XD$).BTR/__@\000`^$G0$``(/L#&H`Z)#-___'!"0!````Z(3-
M___'!"0"````Z'C-__]8_[6`K___Z&S-__]?6&H!_[6$K___Z(W&__^#Q!!`
M#X0L`0``@^P(:@+_M82O___H<\;__X/$$$`/A.@```!J`(V-Z+___U%74^BY
MQ___6EE04^@@QO__Z'O(__]?_S#HP\3__XD$)%-H#-(("&H!:@'H66H``(/$
M(.D[_O__@^P0Z%'(__]9_S#HF<3__X/$$%!HHM$("&H!:@'H+VH``(/$$.D"
M_O__@^P0Z"?(__]:_S#H;\3__X/$$%!H+-(("&H!:@'H!6H``(/$$.D;_O__
M@^P0Z/W'__];_S#H1<3__X/$$%!HN]$("&H!:@'HVVD``(/$$.G7_?__@^P0
MZ-/'__]>_S#H&\3__X/$$%!H5-(("&H!:@'HL6D``(/$$.GI_?__@^P0Z*G'
M__]:_S#H\</__X/$$%!H>-(("&H!:@'HAVD``(/$$.GN_O__@^P0Z'_'__]9
M_S#HQ\/__X/$$%!H>-(("&H!:@'H76D``(/$$.FJ_O__@^P0Z%7'__]:_S#H
MG</__XD$)(/L#%?HP<3__X/$$%!HI-(("&H!:@'H)VD``(/$(.DM_O__D(GV
M58GE@?K__P``4XG#470%BUW\R<.#^`%T&87;=?*#[`QHB,,E".@*RO__@\00
MBUW\R<.#[`QHB,,E".@ER/__@\00Z]55B>6Z__\``+@!````R>NL58GENO__
M```QP,GKGXUV`%6)Y5=64X/L'(M="(M#"(UP]('^",,E",<#J+T("(U]V'4.
MQP,(O@@(C67T6UY?R<.#[`AJ_X/H!%#H(</__X/$$(7`?]V#[`A75NC0RO__
M@\00Z\Z#[`S'`PB^"`A0Z"S*__]5B>575E.#[!R+70B+0PB-</2!_@C#)0C'
M`ZB]"`B-?=AU&H/L#,<#"+X("%/HNL3__X/$$(UE]%M>7\G#@^P(:O^#Z`10
MZ+'"__^#Q!"%P'_1@^P(5U;H8,K__X/$$.O"@^P,QP,(O@@(4.B\R?__58GE
MN`$```#)PXGV58GEBT4(#[9`!,G#58GEBT4(#[9`!,G#58GE4X/L#(M%#(/`
M"(M="%!3Z-'"__^)V(M=_,G"!`!5B>53@^P,BT4,@\`(BUT(4%/HL<+__XG8
MBUW\R<($`%6)Y5.#[`R+10R#P`2+70A04^B1PO__B=B+7?S)P@0`58GE4X/L
M#(M=",<#V-(("(U#!/]U#%#H;,+__X/$$(M=_,G#@^P,QP,(O@@(4.@%R?__
MD%6)Y5.#[`R+70C'`]C2"`B-0P3_=0Q0Z#C"__^#Q!"+7?S)PX/L#,<#"+X(
M"%#HT<C__Y!5B>575E.![*````"+?0B-E73____'1P@4PR4(QP=@TP@(QD<$
M`%)J`(U%R,=%R`````#'1<P`````QT70`````,>%=/___P````!0Z),8``"#
MQ`R-3=A1:*/3"`B-=:A6Z/K&__]:_W6HZ/'%__^+5<R#Q!`[5=")0OS'A7#_
M__\`````#X02`@``A=)T!L<"`````(U:!(E=S(M%J(U8]+D(PR4(.=D/A38"
M``"-79A04VC.TP@(5NBBQO__6/]UJ.B9Q?__BU7,@\00.U70B4+\QX5L____
M``````^$>@(``(72=`;'`@````"-2@2)3<R+1:B-6/2Z",,E"#G:#X5>`P``
MC5V84%-HH],("(U=B,=%J!3#)0A3Z$#&__^#Q`R-3<A14U;HTKD!`(F%:/__
M_XM%B(U0](F59/___[D(PR4(@\00.XUD____#X6&`P``BXUH____A<D/A!4"
M``"+1:B-6/2^",,E"#G>#X6;`P``4VBHJ`0(_W7,_W7(Z"H7``"+1<B#Q!"%
MP'0,@^P,4.CWP?__@\00C67T6UY?R<.)QE!HJ*@$"/]US/]UR.CY%@``@\00
MB?:+1<B%P'0,@^P,4.C$P?__@\00BT<(C5CTN@C#)0@YVG5*@^P,QP<(O@@(
M5NCCQO__C78`B<;KR(G&BT6HC5CTN@C#)0@YVG2A@^P(:O^#Z`10Z(V___^#
MQ!"%P'^,@^P(C468ZV:)]HG&ZY2#[`AJ_X/H!%#H:K___X/$$(7`?Z&#[`B-
M39A14^@6Q___@\00ZX^0B<;KBHG&BT6HC5CTN0C#)0@YV0^$/?___X/L"&K_
M@^@$4.@IO___@\00A<`/CR3___^#[`B-1=A04^C1QO__@\00Z0____^0Z0?_
M__^-C7#___]045*-1<A0Z#46``"#Q!#IY/W__XG&BT6HC5CTN0C#)0@YV0^$
MVO[__X/L"&K_@^@$4.C&OO__Z33____IP/[__X/L"&K_@^@$4.BNOO__@\00
MA<`/C[']__^#[`B-19A04^A6QO__@\00Z9S]__^)]NF+_O__B<:+18B-6/2Z
M",,E"#G:=(^#[`AJ_X/H!%#H:+[__X/$$(7`#X]V____@^P(C4784%/H$,;_
M_X/$$.EA____Z4?^__]0C85L____4%*-5<A2Z'45``"#Q!#I?/W__XM5J(M"
M_(7`#XD@`0``B=`#0O2`>/\*C4C_#X0B`0``:@AJ`%93Z%[$__]86FB:TP@(
M4^AAOO__@\00A<`/E,`/MMB+18B)G6#___^Z",,E"(U8]#G:#X5\`0``BY5@
M____A=)T7HM=J(U'"(-[]`?&1P0!B85<____=Q"#[`QHT=,(".@0Q?__@\00
M:O]J"%:-G7C___]3Z.S#__]86E/_M5S____H/K___XN%>/___XU8]+X(PR4(
M@\00.=X/A;8!``"+1:B-6/2^",,E"#G>#X4R`0``4VBHJ`0(_W7,_W7(Z%$4
M``#I(OW__X/L"&K_@^@$4.@NO?__@\00A<`/CXG\__^#[`B-1=A04^C6Q/__
M@\00Z73\__^)]ND+_?__B<;I'/W__^G__/__@^P,5N@2P___@\00BU6HZ<S^
M__]J`&H!*=%15NCZP/__BPZ#Z0R#Q!#'00C_____Z;W^__^#[`AJ_X/H!%#H
MN+S__X/$$(7`#X]A_/__@^P(C4784/^U9/___^A;Q/__@\00Z4?\__^-=@"#
M[`AJ_X/H!%#H@KS__X/$$(7`#X],_/__@^P(C5684E/H*L3__X/$$.DW_/__
MB?;I<OW__^EM_?__Z57\__^#[`AJ_X/H!%#H0[S__X/$$(7`#X]K_O__@^P(
MC4V845/HZ\/__X/$$.E6_O__C78`@^P(:O^#Z`10Z!*\__^#Q!"%P`^/M?[_
M_X/L"(U%F%!3Z+K#__^#Q!#IH/[__XGVZ0+]__^)QHN%>/___XU8]+D(PR4(
M.=D/A.S\__^#[`AJ_X/H!%#HQ;O__X/$$(7`#X_3_/__@^P(C468Z5C]__^#
M[`AJ_X/H!%#HH;O__X/$$(7`#X\Q_O__@^P(C5684E/H2</__X/$$.D<_O__
MZ9/\___ICOS__Y")]E6)Y5=64X'LH````(M]"(V5=/___\='"!3#)0C'!V#3
M"`C&1P0`4FH`C47(QT7(`````,=%S`````#'1=``````QX5T____`````%#H
M9Q(``(/$#(U-V%%HH],("(UUJ%;HSL#__UK_=:CHQ;___XM5S(/$$#M5T(E"
M_,>%</___P`````/A!("``"%TG0&QP(`````C5H$B5W,BT6HC5CTN0C#)0@Y
MV0^%-@(``(U=F%!3:,[3"`A6Z';`__]8_W6HZ&V___^+5<R#Q!`[5=")0OS'
MA6S___\`````#X1Z`@``A=)T!L<"`````(U*!(E-S(M%J(U8]+H(PR4(.=H/
MA5X#``"-79A04VBCTP@(C5V(QT6H%,,E"%/H%,#__X/$#(U-R%%35NBFLP$`
MB85H____BT6(C5#TB95D____N0C#)0B#Q!`[C63___\/A88#``"+C6C___^%
MR0^$%0(``(M%J(U8]+X(PR4(.=X/A9L#``!3:*BH!`C_=<S_=<CH_A```(M%
MR(/$$(7`=`R#[`Q0Z,N[__^#Q!"-9?1;7E_)PXG&4VBHJ`0(_W7,_W7(Z,T0
M``"#Q!")]HM%R(7`=`R#[`Q0Z)B[__^#Q!"+1PB-6/2Z",,E"#G:=4J#[`S'
M!PB^"`A6Z+?`__^-=@")QNO(B<:+1:B-6/2Z",,E"#G:=*&#[`AJ_X/H!%#H
M8;G__X/$$(7`?XR#[`B-19CK9HGVB<;KE(/L"&K_@^@$4.@^N?__@\00A<!_
MH8/L"(U-F%%3Z.K`__^#Q!#KCY")QNN*B<:+1:B-6/2Y",,E"#G9#X0]____
M@^P(:O^#Z`10Z/VX__^#Q!"%P`^/)/___X/L"(U%V%!3Z*7`__^#Q!#I#___
M_Y#I!____XV-</___U!14HU%R%#H"1```(/$$.GD_?__B<:+1:B-6/2Y",,E
M"#G9#X3:_O__@^P(:O^#Z`10Z)JX___I-/___^G`_O__@^P(:O^#Z`10Z(*X
M__^#Q!"%P`^/L?W__X/L"(U%F%!3Z"K`__^#Q!#IG/W__XGVZ8O^__^)QHM%
MB(U8]+H(PR4(.=ITCX/L"&K_@^@$4.@\N/__@\00A<`/CW;___^#[`B-1=A0
M4^CDO___@\00Z6'____I1_[__U"-A6S___]04HU5R%+H20\``(/$$.E\_?__
MBU6HBT+\A<`/B2`!``")T`-"](!X_PJ-2/\/A"(!``!J"&H`5E/H,K[__UA:
M:)K3"`A3Z#6X__^#Q!"%P`^4P`^VV(M%B(F=8/___[H(PR4(C5CT.=H/A7P!
M``"+E6#___^%TG1>BUVHC4<(@WOT!\9'!`&)A5S___]W$(/L#&C1TP@(Z.2^
M__^#Q!!J_VH(5HV=>/___U/HP+W__UY84_^U7/___^@2N?__BX5X____C5CT
MO@C#)0B#Q!`YW@^%M@$``(M%J(U8]+X(PR4(.=X/A3(!``!1:*BH!`C_=<S_
M=<CH)0X``.DB_?__@^P(:O^#Z`10Z`*W__^#Q!"%P`^/B?S__X/L"(U%V%!3
MZ*J^__^#Q!#I=/S__XGVZ0O]__^)QND<_?__Z?_\__^#[`Q6Z.:\__^#Q!"+
M5:CIS/[__VH`:@$IT5%6Z,ZZ__^+#H/I#(/$$,=!"/_____IO?[__X/L"&K_
M@^@$4.B,MO__@\00A<`/CV'\__^#[`B-1=A0_[5D____Z"^^__^#Q!#I1_S_
M_XUV`(/L"&K_@^@$4.A6MO__@\00A<`/CTS\__^#[`B-59A24^C^O?__@\00
MZ3?\__^)]NER_?__Z6W]___I5?S__X/L"&K_@^@$4.@7MO__@\00A<`/CVO^
M__^#[`B-39A14^B_O?__@\00Z5;^__^-=@"#[`AJ_X/H!%#HYK7__X/$$(7`
M#X^U_O__@^P(C4684%/HCKW__X/$$.F@_O__B?;I`OW__XG&BX5X____C5CT
MN0C#)0@YV0^$[/S__X/L"&K_@^@$4.B9M?__@\00A<`/C]/\__^#[`B-19CI
M6/W__X/L"&K_@^@$4.AUM?__@\00A<`/CS'^__^#[`B-59A24^@=O?__@\00
MZ1S^___ID_S__^F._/__D(GV58GE5U93@>R@````BWT(C95T____QT<(%,,E
M",<'&-,(",9'!`!2:@"-1<C'1<@`````QT7,`````,=%T`````#'A73___\`
M````4.@[#```@\0,C4W846B^TP@(C76H5NBBNO__6O]UJ.B9N?__BU7,@\00
M.U70B4+\QX5P____``````^$$@(``(72=`;'`@````"-6@2)7<R+1:B-6/2Y
M",,E"#G9#X4V`@``C5V84%-HYM,("%;H2KK__UC_=:CH0;G__XM5S(/$$#M5
MT(E"_,>%;/___P`````/A'H"``"%TG0&QP(`````C4H$B4W,BT6HC5CTN@C#
M)0@YV@^%7@,``(U=F%!3:+[3"`B-78C'1:@4PR4(4^CHN?__@\0,C4W(45-6
MZ'JM`0")A6C___^+18B-4/2)E63___^Y",,E"(/$$#N-9/___P^%A@,``(N-
M:/___X7)#X05`@``BT6HC5CTO@C#)0@YW@^%FP,``%-HJ*@$"/]US/]UR.C2
M"@``BT7(@\00A<!T#(/L#%#HG[7__X/$$(UE]%M>7\G#B<93:*BH!`C_=<S_
M=<CHH0H``(/$$(GVBT7(A<!T#(/L#%#H;+7__X/$$(M'"(U8]+H(PR4(.=IU
M2H/L#,<'"+X("%;HB[K__XUV`(G&Z\B)QHM%J(U8]+H(PR4(.=ITH8/L"&K_
M@^@$4.@UL___@\00A<!_C(/L"(U%F.MFB?:)QNN4@^P(:O^#Z`10Z!*S__^#
MQ!"%P'^A@^P(C4V845/HOKK__X/$$.N/D(G&ZXJ)QHM%J(U8]+D(PR4(.=D/
MA#W___^#[`AJ_X/H!%#HT;+__X/$$(7`#X\D____@^P(C4784%/H>;K__X/$
M$.D/____D.D'____C8UP____4%%2C47(4.C="0``@\00Z>3]__^)QHM%J(U8
M]+D(PR4(.=D/A-K^__^#[`AJ_X/H!%#H;K+__^DT____Z<#^__^#[`AJ_X/H
M!%#H5K+__X/$$(7`#X^Q_?__@^P(C4684%/H_KG__X/$$.F<_?__B?;IB_[_
M_XG&BT6(C5CTN@C#)0@YVG2/@^P(:O^#Z`10Z!"R__^#Q!"%P`^/=O___X/L
M"(U%V%!3Z+BY__^#Q!#I8?___^E'_O__4(V%;/___U!2C57(4N@="0``@\00
MZ7S]__^+5:B+0OR%P`^)(`$``(G0`T+T@'C_"HU(_P^$(@$``&H%:@!64^@&
MN/__6%IHN-,("%/H";+__X/$$(7`#Y3`#[;8BT6(B9U@____N@C#)0B-6/0Y
MV@^%?`$``(N58/___X72=%Z+7:B-1PB#>_0$QD<$`8F%7/___W<0@^P,:-'3
M"`CHN+C__X/$$&K_:@56C9UX____4^B4M___7EA3_[5<____Z.:R__^+A7C_
M__^-6/2^",,E"(/$$#G>#X6V`0``BT6HC5CTO@C#)0@YW@^%,@$``%%HJ*@$
M"/]US/]UR.CY!P``Z2+]__^#[`AJ_X/H!%#HUK#__X/$$(7`#X^)_/__@^P(
MC4784%/H?KC__X/$$.ET_/__B?;I"_W__XG&Z1S]___I__S__X/L#%;HNK;_
M_X/$$(M5J.G,_O__:@!J`2G145;HHK3__XL.@^D,@\00QT$(_____^F]_O__
M@^P(:O^#Z`10Z&"P__^#Q!"%P`^/8?S__X/L"(U%V%#_M63____H`[C__X/$
M$.E'_/__C78`@^P(:O^#Z`10Z"JP__^#Q!"%P`^/3/S__X/L"(U5F%)3Z-*W
M__^#Q!#I-_S__XGVZ7+]___I;?W__^E5_/__@^P(:O^#Z`10Z.NO__^#Q!"%
MP`^/:_[__X/L"(U-F%%3Z).W__^#Q!#I5O[__XUV`(/L"&K_@^@$4.BZK___
M@\00A<`/C[7^__^#[`B-19A04^ABM___@\00Z:#^__^)]ND"_?__B<:+A7C_
M__^-6/2Y",,E"#G9#X3L_/__@^P(:O^#Z`10Z&VO__^#Q!"%P`^/T_S__X/L
M"(U%F.E8_?__@^P(:O^#Z`10Z$FO__^#Q!"%P`^/,?[__X/L"(U5F%)3Z/&V
M__^#Q!#I'/[__^F3_/__Z8[\__^0B?95B>575E.![*````"+?0B-E73____'
M1P@4PR4(QP<8TP@(QD<$`%)J`(U%R,=%R`````#'1<P`````QT70`````,>%
M=/___P````!0Z`\&``"#Q`R-3=A1:+[3"`B-=:A6Z':T__]:_W6HZ&VS__^+
M5<R#Q!`[5=")0OS'A7#___\`````#X02`@``A=)T!L<"`````(U:!(E=S(M%
MJ(U8]+D(PR4(.=D/A38"``"-79A04VCFTP@(5N@>M/__6/]UJ.@5L___BU7,
M@\00.U70B4+\QX5L____``````^$>@(``(72=`;'`@````"-2@2)3<R+1:B-
M6/2Z",,E"#G:#X5>`P``C5V84%-HOM,("(U=B,=%J!3#)0A3Z+RS__^#Q`R-
M3<A14U;H3J<!`(F%:/___XM%B(U0](F59/___[D(PR4(@\00.XUD____#X6&
M`P``BXUH____A<D/A!4"``"+1:B-6/2^",,E"#G>#X6;`P``4VBHJ`0(_W7,
M_W7(Z*8$``"+1<B#Q!"%P'0,@^P,4.ASK___@\00C67T6UY?R<.)QE-HJ*@$
M"/]US/]UR.AU!```@\00B?:+1<B%P'0,@^P,4.A`K___@\00BT<(C5CTN@C#
M)0@YVG5*@^P,QP<(O@@(5NA?M/__C78`B<;KR(G&BT6HC5CTN@C#)0@YVG2A
M@^P(:O^#Z`10Z`FM__^#Q!"%P'^,@^P(C468ZV:)]HG&ZY2#[`AJ_X/H!%#H
MYJS__X/$$(7`?Z&#[`B-39A14^B2M/__@\00ZX^0B<;KBHG&BT6HC5CTN0C#
M)0@YV0^$/?___X/L"&K_@^@$4.BEK/__@\00A<`/CR3___^#[`B-1=A04^A-
MM/__@\00Z0____^0Z0?___^-C7#___]045*-1<A0Z+$#``"#Q!#IY/W__XG&
MBT6HC5CTN0C#)0@YV0^$VO[__X/L"&K_@^@$4.A"K/__Z33____IP/[__X/L
M"&K_@^@$4.@JK/__@\00A<`/C[']__^#[`B-19A04^C2L___@\00Z9S]__^)
M]NF+_O__B<:+18B-6/2Z",,E"#G:=(^#[`AJ_X/H!%#HY*O__X/$$(7`#X]V
M____@^P(C4784%/HC+/__X/$$.EA____Z4?^__]0C85L____4%*-5<A2Z/$"
M``"#Q!#I?/W__XM5J(M"_(7`#XD@`0``B=`#0O2`>/\*C4C_#X0B`0``:@5J
M`%93Z-JQ__]86FBXTP@(4^C=J___@\00A<`/E,`/MMB+18B)G6#___^Z",,E
M"(U8]#G:#X5\`0``BY5@____A=)T7HM=J(U'"(-[]`3&1P0!B85<____=Q"#
M[`QHT=,(".B,LO__@\00:O]J!5:-G7C___]3Z&BQ__]>6%/_M5S____HNJS_
M_XN%>/___XU8]+X(PR4(@\00.=X/A;8!``"+1:B-6/2^",,E"#G>#X4R`0``
M46BHJ`0(_W7,_W7(Z,T!``#I(OW__X/L"&K_@^@$4.BJJO__@\00A<`/CXG\
M__^#[`B-1=A04^A2LO__@\00Z73\__^)]ND+_?__B<;I'/W__^G__/__@^P,
M5NB.L/__@\00BU6HZ<S^__]J`&H!*=%15NAVKO__BPZ#Z0R#Q!#'00C_____
MZ;W^__^#[`AJ_X/H!%#H-*K__X/$$(7`#X]A_/__@^P(C4784/^U9/___^C7
ML?__@\00Z4?\__^-=@"#[`AJ_X/H!%#H_JG__X/$$(7`#X],_/__@^P(C568
M4E/HIK'__X/$$.DW_/__B?;I<OW__^EM_?__Z57\__^#[`AJ_X/H!%#HOZG_
M_X/$$(7`#X]K_O__@^P(C4V845/H9['__X/$$.E6_O__C78`@^P(:O^#Z`10
MZ(ZI__^#Q!"%P`^/M?[__X/L"(U%F%!3Z#:Q__^#Q!#IH/[__XGVZ0+]__^)
MQHN%>/___XU8]+D(PR4(.=D/A.S\__^#[`AJ_X/H!%#H0:G__X/$$(7`#X_3
M_/__@^P(C468Z5C]__^#[`AJ_X/H!%#H':G__X/$$(7`#X\Q_O__@^P(C568
M4E/HQ;#__X/$$.D<_O__Z9/\___ICOS__XUV`%6)Y8M%"%:+=0PY\%.+71!T
M&8GV@^P,_S#_TXM%"(/`!(/$$(E%"#GP=>F-9?B)V%M>R<-5B>575E.#[`R+
M?0B+5P0[5PB+=1!T/872=3&-2@2)3P2+'HUR_"MU#(/F_%%6_W4,*?)2Z%.H
M__^+50R)&H/$$(UE]%M>7\G#C78`BT+\B0+KR)`K%XG0P?@"N0$```!U:L'A
M`H/L#(E-[%'H.Z___XE%\(M=#(L'@\0,*<-34/]U\.@$J/__BU7P@\00`=IT
M!(L.B0J+7P10*UT,4XUR!/]U#%;HXJ?__XL'@\00`?.%P'4<BU7PB1<#5>R)
M7P2)5PB-9?1;7E_)PY"-#`#KD8/L#%#HTJG__X/$$.O6D%6)Y5=64X/L'(M=
M"(M#!(UP]('^",,E"(U]V'4.QP,(O@@(C67T6UY?R<.#[`C'`]C2"`B#Z`1J
M_U#HG:?__X/$$(7`?]>#[`A75NA,K___@\00Z\B#[`S'`PB^"`A0Z*BN__]5
MB>575E.#[!R+70B+0P2-</2!_@C#)0B-?=AU&H/L#,<#"+X("%/H/*G__X/$
M$(UE]%M>7\G#@^P(QP/8T@@(@^@$:O]0Z"VG__^#Q!"%P'_+@^P(5U;HW*[_
M_X/$$.N\@^P,QP,(O@@(4.@XKO__58GE5U93@^P<BUT(BT,(C7#T@?X(PR4(
MC7W8=0['`PB^"`B-9?1;7E_)PX/L",<#&-,("(/H!&K_4.C)IO__@\00A<!_
MUX/L"%=6Z'BN__^#Q!#KR(/L#,<#"+X("%#HU*W__U6)Y5=64X/L'(M="(M#
M"(UP]('^",,E"(U]V'4:@^P,QP,(O@@(4^AHJ/__@\00C67T6UY?R<.#[`C'
M`QC3"`B#Z`1J_U#H6:;__X/$$(7`?\N#[`A75N@(KO__@\00Z[R#[`S'`PB^
M"`A0Z&2M__]5B>575E.#[!R+70B+0PB-</2!_@C#)0B-?=AU#L<#"+X("(UE
M]%M>7\G#@^P(QP-@TP@(@^@$:O]0Z/6E__^#Q!"%P'_7@^P(5U;HI*W__X/$
M$.O(@^P,QP,(O@@(4.@`K?__58GE5U93@^P<BUT(BT,(C7#T@?X(PR4(C7W8
M=1J#[`S'`PB^"`A3Z)2G__^#Q!"-9?1;7E_)PX/L",<#8-,("(/H!&K_4.B%
MI?__@\00A<!_RX/L"%=6Z#2M__^#Q!#KO(/L#,<#"+X("%#HD*S__U6)Y5=6
M4X'L#!```.A'*@``A<")QP^$:0$``/]U"&@`U`@(:``0``"-G>CO__]3Z!RE
M__]97E-7Z'^_`0"#Q!"%P`^%H````(/L#%?H.V8#`(/$$(7`B<8/A`,!``"#
M[`Q6Z)UK`P"#Q!"#^@!W88/X`7=<@^P,5NB':P,`@\00@_H`=PF#^``/AKH`
M``"#[`Q6Z&%G`P"#Q!"%P(G##X3W````BQ.%TG1B4/]U$/\S_W4,Z'BH__^)
M-"3H6#D#`(D\).B$2`,`C67T6UY?R</_=0AH0-0("&H!:@'HUTD``(/$$.N.
MB?:#[`Q7Z#]K`P"#Q!!0:#W5"`AJ`6H!Z+5)``"#Q!#I/?___Y#_=0AH=-0(
M"&H!:@'HFTD``(/$$%#_=1#_,_]U#.@"J/__B30DZ.(X`P")/"3H#D@#`(UE
M]%M>7\G#B?;_=0AHH-0("&H!:@'H7TD``(/$$.DM____@^P,5^C&:@,`@\00
M4&C0U`@(:@%J`>@\20``@\00Z=K^__]0:/34"`AJ`6H!Z"5)``"#Q!#I@/[_
M_X/L#%?HC&H#`(/$$%!H'-4("&H!:@'H`DD``(/$$.GF_O__B?95B>575H'L
M%!```&@`$```C;7X[___5O]U".@A_O__OQ6Z"`BY#@```/SSI@^7P@^2P8/$
M$#C*#Y7`C67X7@^VP%_)PU6)Y5=64X'L+!```.A#*```B874[___BXW4[___
M,<"%R71Q_W4(:`#4"`AH`!```(V=Z.___U/H$*/__UA:4_^UU.___^ANO0$`
M@\00A<!U,X/L#/^UU.___^@I9`,`@\00A<")A=#O__]T&(/L#%#HBVD#`(G&
M@_8!@\00"=9T&XUV`(/L#/^UU.___^BV1@,`,<"-9?1;7E_)PX/L#/^UT.__
M_^A*90,`@\00A<!TTXL`A<!TS;L5N@@(_+D-````B<>)WO.F#Y+`#Y?"@^P,
M*,+_M=#O__\/OOKH,S<#`%C_M=3O___H6T8#`#'`@\00A?\/E<#KFXUV`%6)
MY5.#[!#_=0CH$:?__XG#@\00,<"%VW07@^P(:B]3Z+ND__^#Q!"%P'0#Q@``
MB=B+7?S)PXGV58GE5U93@>R(````BW4(5NC3IO__B46$BU6$@\00,<"%TG1#
MBWV$_+G_____,<#RKO?1C5G_,?\YWW()ZQF)]D<YWW,&@#P^+W7UA?]U(&:_
M`0`YWW+N@^P,_W6$Z/:I__^X`0```(UE]%M>7\G#BTV$Q@0Y`.@-I?__@^P(
MC56(QP``````4O]UA.A(J/__@\00A<!U&@^W19`E`/```#T`0```=3J+583&
M!!<O1^N'Z-*D__^#.`)U%X/L"&CM`0``_W6$Z$VI__^#Q!"%P'35@^P,_W6$
MZ'NI__\QP.N&@^P,_W6$Z&RI___HEZ3__\<`%````#'`Z6G___^)]E6)Y5=6
M4X'L#"```/\U`$89"&A:U0@(:``0``"-M>CO__]6Z/"@__^#Q`QH@`$``&@!
M`@``5NAMJ/__HXS#)0B#Q!!`=`J-9?1;7E_)PXGVZ#.D__^#.`)T0H/L$.@F
MI/__6?\PZ&Z@__^)!"16:'#5"`AH`!```(V]Z-___U?HE*#__X/$'&H!:@%7
MZ-=$``"#Q!"-9?1;7E_)PX/L#%;H0Z7__X/$$(7`B<,/A)H```"#[`AJ+U#H
MZZ+__X/$$(7`=`/&``")WX/L#%?H+O[__X/$$(7`="Y0:(`!``!H`0(``%;H
MOJ?__Z.,PR4(@\000`^$E````(/L#%?H5JC__X/$$.N-@^P0Z'FC__]:_S#H
MP9___XD$)%9H<-4("&@`$```C9WHW___4^CGG___@\045^@>J/__@\0,:@%J
M`5/H(40``(/$$.N-@^P0Z#2C__]9_S#H?)___XD$)%9H<-4("&@`$```C9WH
MW___4^BBG___@\0<:@%J`5/HY4,``#'_@\00Z3S___^#[!#H\Z+__UO_,.@[
MG___B00D5FAPU0@(:``0``"-M>C?__]6Z&&?__^#Q!17Z)BG__^#Q`QJ`6H!
M5NB;0P``@\00Z23___^-=@!5B>53@>P0$```_S6,PR4(Z#NG__^#Q!"%P'4(
MBUW\R<.-=@"#[!#HA*+__UO_,.C,GO__@\004&B8U0@(C9WX[___:``0``!3
MZ/*>__^#Q`QJ`6H!4^@U0P``@\00BUW\R<.058GE5U93@>PL$```BW4(A?8/
MB)<```")\,'X'V;'1=P#`&;'1=X``(EUR(E%S,=%T`$```#'1=0`````C5W(
MC;W([___ZTJ0Z/^A__^#.`1T-(/L$.CRH?__6O\PZ#J>__^)!"16:,S5"`AH
M`!```%?H9I[__X/$'&H!:@%7Z*E"``"#Q!#HP:'__\<``````%!3:@G_-8S#
M)0CH'*;__X/$$$!THHUE]%M>7\G#5FCTU0@(:``0``"-G<CO__]3Z!>>__^#
MQ`QJ`6H!4^A:0@``@\00Z3W___^)]E6)Y5=64X'L+!```(MU"(7V#XB7````
MB?#!^!]FQT7<`@!FQT7>``")=<B)1<S'1=`!````QT74`````(U=R(V]R.__
M_^M*D.@CH?__@S@$=#2#[!#H%J'__UK_,.A>G?__B00D5F@TU@@(:``0``!7
MZ(J=__^#Q!QJ`6H!5^C-00``@\00Z.6@___'``````!14VH(_S6,PR4(Z$"E
M__^#Q!!`=**-9?1;7E_)PU9H7-8("&@`$```C9W([___4^@[G?__@\0,:@%J
M`5/H?D$``(/$$.D]____B?95B>564X'L(!```(MU"(7V#XB.````C4784U!J
M!XGRP?H?_S6,PR4(9L=%[`,`9L=%[@``B778B57<QT7@`0```,=%Y`````#H
MMZ3__X/$$(7`>!0QP&:#?>P"=`.+1>B-9?A;7LG#D(/L$.@DH/__6?\PZ&R<
M__^)!"16:)S6"`AH`!```(VUV.___U;HDIS__X/$'&H!:@%6Z-5```"#Q!#K
ML%9HQ-8("&@`$```C9W8[___4^AIG/__@\0,:@%J`5/HK$```(/$$.E&____
M58GE5U93@>PL$```BW4(A?8/B+H```")\,'X'V;'1=P#`&;'1=X``(EUR(E%
MS,=%T`$```#'1=0`````C5W(C;W([___ZUZ0Z'>?__^#.`UT<NAMG___@S@C
M=&CH8Y___X,X!'0T@^P0Z%:?__]:_S#HGIO__XD$)%9HS-4("&@`$```5^C*
MF___@\0<:@%J`5?H#4```(/$$.@EG___QP``````4%-J"/\UC,,E".B`H___
M@\000'2.C67T6UXQP%_)PXUE]%M>N/____]?R<-6:/35"`AH`!```(V=R.__
M_U/H;)O__X/$#&H!:@%3Z*\_``"#Q!#I&O___XUV`%6)Y5=6BW40BWT,A?93
MB?J+70AT&XGQD$ET#HH"B`-"0X3`=?.%R74.A?9T`\8#`(H*0H3)=?E;*?I>
MC4+_7\G#C78`58GE5U93BWT0C4?_BUT(BW4,@_C_B=J)\70-D(`Z`'0'2$*#
M^/]U](G0*=@IQXG#=1J)]S'`_+G_____\J[WT8U$&?];7E_)PXUV`(`^`'04
MC78`@_\!=`:*`8@"3T)!@#D`=>_&`@`I\8T$&5M>7\G#B?95B>575E.#[!B+
M=0A6BUT,BWT0Z(2@__^#Q!"%P(G"="N%VW0%BT`(B0.%_W0%BTH,B0^+712%
MVW0(BW(<BU44B3(QP(UE]%M>7\G#5F@$UP@(:@!J`.BI/P``N/_____KXHGV
M58GE4U&+50R%THM="'0E@^P,4^@@H/__@\00A<!T/(M`#(E%^#'`0'0BBT7X
MBUW\R<.)]H/L#%/H^Y___X/$$(7`=!>+0`CKV8UV`,=%^`````"+1?B+7?S)
MPU-H!-<("&H`:@#H-C\``(/$$+C_____Z[-5B>53@>P0$```BUT(4^C1H/__
M@\00A<!T"(M`"(M=_,G#@^P0Z`J=__]:_S#H4IG__XD$)%-H)-<("(V=^.__
M_V@`$```4^AXF?__@\0<:@!J`%/HNST``#'`BUW\R<-5B>53@^P0BUT(4^@4
MG___@\00A<!T*5%H_P\``/\P:*##)0CH&YW__\8%G],E"`"#Q!"XH,,E"(M=
M_,G#C78`4VA(UP@(:``0``!HH,,E".@/F?__@\00N*##)0B+7?S)PXGV58GE
M4X/L$(M="%/H,)G__X/$$(7`="E3:/\/``#_,&B@TR4(Z+><___&!9_C)0@`
M@\00N*#3)0B+7?S)PXUV`%-H2-<("&@`$```:*#3)0CHJYC__X/$$+B@TR4(
MBUW\R<.)]E6)Y5=64X'LC!```(LU`$89"(7V=`J-9?1;7E_)PXGV@^P,:$O7
M"`CHPPH``(/$$(7`B<8/A(H*``"`.``/A($*``"#[`R)-0!&&0AH6M<(".B:
M"@``@\00A<")QG0%@#@`=2=1:.S9"`AH`!```(V]Z.___U?H(9C__X/$#&H!
M:@%7Z&0\``"#Q!"#[`R)-?A%&0AH:=<(".A2"@``@\00A<")QG0%@#@`=2=2
M:!#:"`AH`!```(V=Z.___U/HV9?__X/$#&H!:@%3Z!P\``"#Q!"#[`R)-?1%
M&0AH=M<(".@*"@``@\00A<")QG0%@#@`=2=0:#3:"`AH`!```(V]Z.___U?H
MD9?__X/$#&H!:@%7Z-0[``"#Q!"#[`R)-?!%&0AH@M<(".C""0``@\00A<")
MQG0%@#@`=2=0:%3:"`AH`!```(V=Z.___U/H29?__X/$#&H!:@%3Z(P[``"#
MQ!"#[`R)->Q%&0AHC]<(".AZ"0``@\00A<")QG0%@#@`=2=0:'C:"`AH`!``
M`(V]Z.___U?H`9?__X/$#&H!:@%7Z$0[``"#Q!"#[`R)->A%&0AHH=<(".@R
M"0``@\00A<")QG0%@#@`=2=0:*O7"`AH`!```(V=Z.___U/HN9;__X/$#&H!
M:@%3Z/PZ``"#Q!"#[`R)->1%&0AHR=<(".CJ"```@\00A<")QG0%@#@`=2=0
M:*#:"`AH`!```(V]Z.___U?H<9;__X/$#&H!:@%7Z+0Z``"#Q!"#[`R)->!%
M&0AHU]<(".BB"```@\00A<")PW0%@#@`=19HU]<("&C$V@@(:@%J`>B5.P``
M@\00@^P,B1W<11D(:.+7"`CH:P@``(/$$(7`B<9T!8`X`'4G4&CTV@@(:``0
M``"-G>CO__]3Z/*5__^#Q`QJ`6H!4^@U.@``@\00@^P,B37811D(://7"`CH
M(P@``(/$$(7`B<9T!8`X`'4G5VC\UP@(:``0``"-O>CO__]7Z*J5__^#Q`QJ
M`6H!5^CM.0``@\00@^P,B37011D(:!G8"`CHVP<``(/$$(7`B<9T!8`X`'4G
M4V@CV`@(:``0``"-G>CO__]3Z&*5__^#Q`QJ`6H!4^BE.0``@\00@^P,B37,
M11D(:$'8"`CHDP<``(/$$(7`B<9T!8`X`'4G46@<VP@(:``0``"-O>CO__]7
MZ!J5__^#Q`QJ`6H!5^A=.0``@\00@^P,B37(11D(:$W8"`CH2P<``(/$$(7`
MB<-T!8`X`'424F@\VP@(:@%J`>A".@``@\00@^P,B1W$11D(:%G8"`CH&`<`
M`(/$$(7`B<9T!8`X`'4G4&A<VP@(:``0``"-G>CO__]3Z)^4__^#Q`QJ`6H!
M4^CB.```@\00@^P,B37`11D(:&78"`CHT`8``(/$$(7`B<9T!8`X`'4G4&A\
MVP@(:``0``"-O>CO__]7Z%>4__^#Q`QJ`6H!5^B:.```@\00@^P,B36\11D(
M:'+8"`CHB`8``(/$$(7`B<9T!8`X`'4G4&B@VP@(:``0``"-G>CO__]3Z`^4
M__^#Q`QJ`6H!4^A2.```@\00@^P,B36X11D(:('8"`CH0`8``(/$$(7`B<9T
M!8`X`'4G4&C$VP@(:``0``"-O>CO__]7Z,>3__^#Q`QJ`6H!5^@*.```@\00
M@^P,B36T11D(:(_8"`CH^`4``(/$$(7`B<9T!8`X`'4G4&CHVP@(:``0``"-
MG>CO__]3Z'^3__^#Q`QJ`6H!4^C"-P``@\00@^P,B36P11D(:)S8"`CHL`4`
M`(/$$(7`B<9T!8`X`'4G4&BCV`@(:``0``"-O>CO__]7Z#>3__^#Q`QJ`6H!
M5^AZ-P``@\00@^P,B37411D(:+[8"`CH:`4``(/$$(7`B<9T!8`X`'4G5V@,
MW`@(:``0``"-G>CO__]3Z.^2__^#Q`QJ`6H!4^@R-P``@\00@^P,B36L11D(
M:,S8"`CH(`4``(/$$(7`B<9T!8`X`'4G4V@PW`@(:``0``"-O>CO__]7Z*>2
M__^#Q`QJ`6H!5^CJ-@``@\00@^P,B36H11D(:-G8"`CHV`0``(/$$(7`B<9T
M!8`X`'4G46A4W`@(:``0``"-G>CO__]3Z%^2__^#Q`QJ`6H!4^BB-@``@\00
M@^P(B36D11D(:``0``!J`>CZE/__,=N^_____XL5`$89"(F%=.___XF5Y.__
M_Z.@11D(_(G7B-B)\?*N]]&#Q`Q)4?^UY.____^U=.___^C;E?__6%IHY=@(
M"/\UH$49".CYE/__65]H`!```&H!Z)N4__^+%0!&&0B)A73O__^)E=SO__^C
MG$49"/R)UXC8B?'RKO?1@\0,25%2_[5T[___Z(B5__]86FCZV`@(_S6<11D(
MZ*:4__]97V@`$```:@'H2)3__XL5`$89"(F%=.___XF5U.___Z.811D(_(G7
MB-B)\?*N]]&#Q`Q)4?^UU.____^U=.___^@PE?__6%IH#-D("/\UF$49".A.
ME/__65]H`!```&H!Z/"3__^+%0!&&0B)A73O__^)E<SO__^CE$49"/R)UXC8
MB?'RKO?1@\0,25'_M<SO____M73O___HV)3__UA::!_9"`C_-91%&0CH]I/_
M_UE?:``0``!J`>B8D___BQ4`1AD(B85T[___B97$[___HY!%&0C\B=>(V(GQ
M\J[WT8/$#$E1_[7$[____[5T[___Z("4__]86F@RV0@(_S6011D(Z)Z3__]9
M7V@`$```:@'H0)/__XL5`$89"(F%=.___XF5O.___Z.,11D(_(G7B-B)\8/$
M#/*N]]%)4?^UO.____^U=.___^@HE/__6%IH2-D("/\UC$49".A&D___65]H
M`!```&H!Z.B2__^+%0!&&0B)A73O__^)E;3O__^CB$49"/R)UXC8B?'RKO?1
M@\0,25'_M;3O____M73O___HT)/__UA::%W9"`C_-8A%&0CH[I+__UE?:``0
M``!J`>B0DO__BQ4`1AD(B85T[___B96L[___HX1%&0C\B=>(V(GQ\J[WT8/$
M#$E1_[6L[____[5T[___Z'B3__]86FAQV0@(_S6$11D(Z):2__]97V@`$```
M:@'H.)+__XL5`$89"(F%=.___XF5I.___Z.`11D(_(G7B-B)\?*N]]&#Q`Q)
M4?^UI.____^U=.___^@@D___6%IHAMD("/\U@$49".@^DO__65]H`!```&H!
MZ."1__^+%0!&&0B)A73O__^)E9SO__^C?$49"/R)UXC8B?'RKO?1@\0,25'_
MM9SO____M73O___HR)+__UA::)C9"`C_-7Q%&0CHYI'__UE?:``0``!J`>B(
MD?__BQ4`1AD(B85T[___B964[___HWA%&0C\B=>(V(GQ\J[WT4F#Q`Q1_[64
M[____[5T[___Z'"2__]86FBMV0@(_S5X11D(Z(Z1__]?6&@`$```:@'H,)'_
M_X/$#*-T11D(:``0``#_-0!&&0A0Z#>2__^+%71%&0B)E8SO__^)U_R(V(GQ
M\J[WT;\`$```@\0,*<]7:,+9"`C_M8SO___HQ9+__XL5`$89"(F5A.___XG7
M_(C8B?'RKO?1@\$1B0PDZ%./__]97O\U`$89"%")Q^@#C?__6%IHU]D("%?H
M]I#__XD]_$49"(UE]%M>7\G#4VATW`@(:``0``"-G>CO__]3Z,&-__^#Q`QJ
M`6H!4^@$,@``@\00Z5/U__]5B>575E.#['PQP/RY_____XM]"/*N]]&+%:#C
M)0A)A=*)380/A,$````Q_\=%@``````[/:3C)0@/@Z(```"+78`#':#C)0CK
M%HGVBS4<PR4(BT26-"4`0```A<!T(4,/MA.!^O\```!VX8/L#%+H^)#__R4`
M0```@\00A<!UWXM5A/PYTHG>BWT(B='SIG4JBT6$#[84`X'Z_P````^'40$`
M`(L]',,E"(M$ES0E`$```(7`#X5F`0``BQ6DXR4(.56`<QN+#:#C)0B+78#_
M18"`/`L`#X01`0``.56`<NLQP(UE]%M>7\G#@^P(:)D!&0AHE]P(".B_D?__
MB<>#Q!`QP(7_=-N#[`B-=8A6#[]?#E/H@X___X/$$(7`#X6[````BU6X@^P,
M@\("4NC)C?__@\00A<"CH.,E"`^$G````%=J`?]UN%#H'9'__X/$$$@/A:T`
M``"+1;B+#:#C)0BCI.,E",8$"``Q]HL5I.,E"#G6<Q60BPV@XR4(@#PQ"HT<
M,70O1CG6<NR#[`Q7Z$>1__^#Q!#IC?[__XUV`*$<PR4(BT20-"4`0```A<!T
M),8#`$L/OA.!^O\```!VWX/L#%+HHH___R4`0```@\00A<!UW(L5I.,E"$;K
MJ8/L#%?H])#__^GT_O__.56`Z43^__^#[`Q2Z&Z/__^#Q!#IJ/[__X/L#/\U
MH.,E".C8D___6,<%H.,E"`````#KP0-=A.L4BS4<PR4(BT26-"4`0```A<!T
M)$.*`X3`=!T\"G09#[;0@?K_````=M>#[`Q2Z!2/__^#Q!#KTXM-@#L-I.,E
M"(G8#X)U_O__Z6[^__^058GE5U93@>P8$```_W4(_W4,:*S<"`AH`!```(V=
MZ.___U.+=1")W^@+B___,<#\N?_____RKO?1@\0<25%35N@/-`,`@\00,=*%
MP'4*C67T6UZ)T%_)PX/L#%;HMU$#`(D$)/]U"&C8W`@(:``0``!3Z,&*__^#
MQ!QJ`&H`4^@$+P``NO_____KPY!5B>534(M%"#';A<!T'H/L"&@=X`@(4.BP
MDO__@\00A<!T"8G8BUW\R<.)]KL!````B=B+7?S)PU6)Y5=64X'L'!```(M=
M#(7;BW4(BWT0QX7D[___`````'0E@^P(:!W@"`A3Z&.2__^#Q!"%P'00C67T
M6UZX_____U_)PXUV`(7_=!6#[`AH'>`("%?H.I+__X/$$(7`==>+112%P'1U
MA?]T98/L"%=35F@0W0@(:``0``"-M>CO__]6Z.R)__^)]S'`_+G_____\J[W
MT8/$'$E15O]U%.CL,@,`@\00A<!U88N=Y.___X7;=0HQP(UE]%M>7\G#@^P,
M_W44Z*8M`P"#Q!`QP.OF@^P,4U9H6-T(".N:Z)H.``"%P(E%%,>%Y.___P$`
M```/A7'___]3:@!J`&B0W0@(Z+XM``#I+?___Y"#[`S_=13H/5`#`(D$)%-H
MN-T("&@`$```5NA)B?__@\0<:@!J`%;HC"T``(N5Y.___X/$$(72#X3O_O__
M@^P,_W44Z!PM`P"#Q!#IW/[__U6)Y5=64X'L'!```(M=#(7;QX7D[___````
M`'0G@^P(:!W@"`A3Z`V1__^#Q!"%P+K_____=`V-9?1;7HG07\G#C78`BT40
MA<!T:X/L#%/_=0AH[-T("&@`$```C;7H[___5NBPB/__B?<QP/RY______*N
M]]&#Q!Q)45;_=1#HL#$#`(/$$(7`=5Z+G>3O__^%VW4/,=*-9?1;7HG07\G#
MC78`@^P,_W40Z&4L`P"#Q!`QTNOAZ&4-``"%P(E%$,>%Y.___P$````/A7O_
M__]0:@!J`&B0W0@(Z(DL``"Z_____^E.____@^P,_W40Z`1/`P")!"13:"3>
M"`AH`!```%;H$(C__X/$'&H`:@!6Z%,L``"+E>3O__^#Q!"%TG2]@^P,_W40
MZ.<K`P"#Q!"Z_____^G]_O__B?95B>575E.![!P0``"+70B%V\>%Y.___P``
M``!T)X/L"&@=X`@(4^C1C___@\00A<"Z_____W0-C67T6UZ)T%_)PXUV`(MU
M#(7V=&-3:%C>"`AH`!```(VUZ.___U;H>H?__XGW,<#\N?_____RKO?1@\0,
M25%6_W4,Z'HP`P"#Q!"%P'58BYWD[___A=MU#3'2C67T6UZ)T%_)PY"#[`S_
M=0SH,2L#`(/$$#'2Z^/H,0P``(7`B44,QX7D[___`0```'6'46H`:@!HD-T(
M".A9*P``NO_____I6O___X/L#/]U#.C430,`B00D4VA\W@@(:``0``!6Z."&
M__^#Q!QJ`&H`5N@C*P``BY7D[___@\00A=)TO8/L#/]U#.BW*@,`@\00NO__
M___I"?___XGV58GE5U93@>P,$```BUT,,?:%VXM]$'0D@^P(:!W@"`A3Z*:.
M__^#Q!"%P'0/C67T6UZX_____U_)PXGVA?]T%8/L"&@=X`@(5^A^CO__@\00
MA<!UV(M%%(7`=&N#[`A74_]U"&BHW@@(:``0``"-E>CO__]2Z#*&__^-O>CO
M__\QP/RY______*N]]&#Q!Q)48V5Z.___U+_=13H*"\#`(/$$(7`=46%]G4*
M,<"-9?1;7E_)PX/L#/]U%.CH*0,`@\00,<#KYNCH"@``A<")112^`0```'6$
M5VH`:@!HD-T(".@5*@``Z4'___^#[`S_=13HE4P#`(D$)%-H\-X("&@`$```
MC8WH[___4>B;A?__@\0<:@!J`(V=Z.___U/HV"D``(/$$(7V#X3^_O__@^P,
M_W44Z&XI`P"#Q!#IZ_[__XGV58GE5U93@>P,$```BUT,,?:%VXM]$'0D@^P(
M:!W@"`A3Z&*-__^#Q!"%P'0/C67T6UZX_____U_)PXGVA?]T%8/L"&@=X`@(
M5^@ZC?__@\00A<!UV(M%%(7`=&N#[`A74_]U"&@@WP@(:``0``"-E>CO__]2
MZ.Z$__^-O>CO__\QP/RY______*N]]&#Q!Q)48V5Z.___U+_=13HY"T#`(/$
M$(7`=46%]G4*,<"-9?1;7E_)PX/L#/]U%.BD*`,`@\00,<#KYNBD"0``A<")
M112^`0```'6$4&H`:@!HD-T(".C1*```Z4'___^#[`S_=13H44L#`(D$)%-H
M:-\("&@`$```C8WH[___4>A7A/__@\0<:@!J`(V=Z.___U/HE"@``(/$$(7V
M#X3^_O__@^P,_W44Z"HH`P"#Q!#IZ_[__XGV58GE5U93@>P,$```BUT(,?:%
MVXM]#'0D@^P(:!W@"`A3Z!Z,__^#Q!"%P'0/C67T6UZX_____U_)PXGVA?]T
M%8/L"&@=X`@(5^CVB___@\00A<!UV(M%$(7`#X2)````A?]T:8/L#%=3:)C?
M"`AH`!```(V5Z.___U+HI8/__X/$(/Q0C;WH[___,<"Y______*N]]%)48V]
MZ.___U?_=1#HFBP#`(/$$(7`=6>%]G4*,<"-9?1;7E_)PX/L#/]U$.A:)P,`
M@\00,<#KYE-HS-\("&@`$```C8WH[___4>A`@___@\00ZYGH/@@``(7`B440
MO@$````/A6+___]0:@!J`&B0W0@(Z&<G``#I&____XGV@^P,_W40Z.5)`P")
M!"13:/3?"`AH`!```(V5Z.___U+HZX+__X/$'&H`:@"-G>CO__]3Z"@G``"#
MQ!"%]@^$UO[__X/L#/]U$.B^)@,`@\00Z</^__^)]E6)Y5=64X'LJ!```&@A
MX`@(QX6`[___`````.CH@O__@\00A<")A83O__]T$8N5A.___S'`@#H`#X6F
M`0``Z.6%__^#[`C'``````!HF0$9"&@QX`@(Z&V'__^#Q!"%P(G##X3F````
M45-H`!```(VUZ.___U;H'8/__X/$$(7`#X2\````C8WH[___B8UD[___ZQBA
M',,E"(M$D#0E`$```(7`="S_A63O__^+M63O__\/OA:!^O\```!VUX/L#%+H
MLH7__R4`0```@\00A<!UU(N]9.___XH'/"-TBCP[=(:$P'2"@[V`[___`0^$
M^0```(N5@.___X72#X7S````_+\]X`@(B[5D[___N0@```#SI@^%3O___U%3
M:``0``"-M>CO__]6QX6`[___`0```.AA@O__@\00A<`/A43___^#[`Q3Z)V&
M__^#Q!"+G83O__^%VW0+BX6$[___@#@`=32#[`B-C8CO__]1:$;@"`CH`8C_
M_X/$$(7`=1D/MY60[___@>(`\```@?H`P```#X1V`0``B[V$[___A?]T"XNU
MA.___X`^`'4R@^P(C9V([___4VA@X`@(Z+B'__^#Q!"%P'47#[>%D.___R4`
M\```/0#````/A"`!``"+A83O__^-9?1;7E_)PSQ;#X1._____+^4`!D(B[5D
M[___N08```#SI@^%6_[__XN]9.___XN59.___XI'!H/"!H3`=`L\/70/0HH"
MA,!U]3P]#X4,____C7(!ZQ.A',,E"(M$D#0E`$```(7`="%&#[X6@?K_````
M=N*#[`Q2Z!:$__\E`$```(/$$(7`==\Q_X`^`'49Z<C^__^+#1S#)0B+1)$T
M)0!```"%P'4B1P^^%#Z!^O\```!VX(/L#%+HU8/__R4`0```@\00A<!TWH/L
M"(V5B.___\8$/@!25NBUAO__@\00A<`/A73^__\/M[V0[___@><`\```@?\`
MP```#X5;_O__@^P,5NB8A/__@\00B86$[___Z43^___'A83O__]@X`@(Z='^
M___'A83O__]&X`@(Z87^__]5B>53@^P0:'#@"`CHVW___X/$$(7`=!-1:@IJ
M`%#H^8#__X/$$(/X`W0%BUW\R<.#[`QH?>`(".BO?___@\00A<")PW3E@^P,
M:(G@"`CH.8/__UA::(G@"`A3Z#R$__^+7?S)PXUV`%6)Y5=64X'L$!```&C_
M#P``C9WH[___4VB)X`@(Z#*`__^#Q!"#^/\/A!X!``!6:@!3:'W@"`C&A`7H
M[___`.@`@___@\00A<!U28/L"&B9`1D(:)K@"`CHYX/__XG&@\00A?:X____
M_W0?4%9H`!```%/HG'___X/$$(7`=7&#[`Q6Z-R#__\QP(UE]%M>7\G#B?:#
M[`QH<.`(".CC?O__@\00A<!TX%%J"FH`4.@!@/__@\00@_@#=<V#[`QH?>`(
M".B\?O__@\00A<")PW2W@^P,:(G@"`CH1H+__UA::(G@"`A3Z$F#__^#Q!#K
MF%!J"FH`4^B9@/__@\00A<")QP^$=____U!7:*K@"`A3Z#^$__^#Q`QJ`%-H
ML.`(".@?@O__@\0,5VB\X`@(4^@@A/__@\0,:@!3:,3@"`CH`(+__X/$$.DS
M____@^P,:'#@"`CH*W[__X/$$(7`=!-2:@IJ`%#H27___X/$$(/X`W0*N/__
M___I#?___X/L#&A]X`@(Z/I]__^#Q!"%P(G#=."#[`QHB>`(".B$@?__7UAH
MB>`("%/HAX+__X/$$+C_____Z=#^__^)]E6)Y5=64X'L1"```&H`:-'@"`CH
M\(3__X/$$(7`B<,/B`@"``!0:``0``"-A=CO__]04^CP@/__@\00A<")QP^(
M%`(``(/L#%/H.H7__X/$$("\/=?O__\*QH0]V.___P`/A#4!``#HV/W__X/L
M#&A]X`@(Z$]]__^#Q!"%P(F%Q-___P^$`@$``(`X``^$^0```(/L#&CFX`@(
MZ"A]__^#Q!"%P'0)@#@`#X7\````@^P,QX6\W___`````&BPX`@(Z`%]__^#
MQ!"%P(G'#X0(`0``@#@`#X3_````@^P,:,3@"`CHWGS__X/$$(7`B<,/A`4!
M``"`.``/A/P```#HN_G__X/L#(F%P-___VH`Z-<<`P"#Q!"%P(G&#X16`0``
M:@#_M<#?____M;S?__]7C;W8[___5U/_M<3?__]0Z/,E`P"#Q""%P`^$M@``
M`%%H\N`("(V=R-___V@!$```4^@1?/__B=_\,<"Y______*N]]&#Q`Q)45-6
MZ!,E`P"-9?1;B?!>7\G#D,>%Q-___POA"`CI^/[__Y#&A#W7[___`.F^_O__
MC78`5FH*:@!0Z$%]__^#Q!"#[`R)A;S?__]HL.`(".C[>___@\00A<")QP^%
M^O[__XGV@^P,:,3@"`CHWWO__X/$$(7`OR"_"`B)PP^%_/[__Y"[%>$(".GZ
M_O__@^P,5NA)0@,`@\004&CLX0@(_W4,_W4(Z%5[__\QP(UE]%M>7\G#@^P0
MZ+-^__]:_S#H^WK__XD$)&C1X`@(:"3B"`C_=0S_=0CH(WO__S'`Z\R#[!#H
MAW[__U__,.C/>O__B00D:-'@"`AH7.((".O24VB4X@@(ZYA5B>53@>P<$```
M:`$0``"-G>CO__]3Z&7]__^#Q!"%P'0%BUW\R<-1:@!J`%/H%A\``#'`BUW\
MR<.-=@!5B>575E.!["P0``"+70PQ]H7;#X3/````_W4(:%?5"`AH`!```&C`
MXR4(Z(QZ__^_P.,E"#'`_+G_____\J[WT8/$#$E1:,#C)0A3Z(<C`P"#Q!"%
MP`^%SP```(/L#%/HDSL#`(D$)(G'Z/4\`P"#Q!"%P'0&BQ"%TG4D@^P,5^C_
M#@,`@\00A?9U1,8%P.,E"`"-9?1;7KC`XR4(7\G#4FC_#P``_S!HP.,E".CJ
M??__B3PDZ,H.`P"#Q!"%]G32@^P,4^CN'0,`@\00Z\20@^P,4^C?'0,`@\00
MQ@7`XR4(`.NNC78`@^P(:`$0``"-G=CO__]3Z$C\__^#Q!"%P'1SA<")P[X!
M````#X4'____4VH!:@!H++P(".CK'0``,<"-9?1;7E_)PX/L#%/H:$`#`(D$
M)/]U"&C,X@@(:``0``!HP.,E".AN>?__@\0<:@%J`&C`XR4(Z*T=``"#Q!"%
M]G2[@^P,4^A)'0,`@\00,<#KK59J`&H`4^B+'0``@\00,<#I>/___Y!5B>53
M@>P($```_W4(_W40_W4,_W44:/CB"`B-G?CO__]H`!```%/H!'G__X/$&/]U
M&%/H//[__XM=_,G#C78`58GE5U93@>PL$```BUT,,?:%VP^$$P$``/]U"&@8
MXP@(:``0``!HP/,E".C`>/__O\#S)0@QP/RY______*N]]&#Q`Q)46C`\R4(
M4^B[(0,`@\00A<!U4(/L#%/HRSD#`(/$$(7`B<=T/H/L#%#H)3L#`(/$$(7`
M=`:+$(72=6R#[`Q7Z"\-`P"#Q!"%]@^%V````,8%P/,E"`"-9?1;7KC`\R4(
M7\G#@^P,4^@?/P,`@\004&B8XP@(:``0``!HP/,E".@G>/__@\0,:@!J`&C`
M\R4(Z&8<``"#Q!"%]G4[,<"-9?1;7E_)PY!2:/\/``#_,&C`\R4(Z-)[__^)
M/"3HL@P#`(/$$(7V=(Z#[`Q3Z-8;`P"#Q!#K@)"#[`Q3Z,<;`P"#Q!`QP.NW
M@^P(:`$0``"-G=CO__]3Z#CZ__^#Q!"%P'0VA<")P[X!````#X7#_O__4VH`
M:@!HN.,(".C;&P``,<#I=____X/L#%/H=QL#`(/$$.D7____5FH`:@!3Z+@;
M``"#Q!`QP.NXD%6)Y5.![`@0``#_=0AHKQ(9"&@;X0@(:"/A"`AH^.(("(V=
M^.___V@`$```4^@N=___@\08_W4,4^AF_/__@\00BUW\R<.)]E6)Y5=64X/L
M#(MU"%9H\.,("&@`$```:,`#)@B+71"_P`,F".CO=O__,<#\N?_____RKO?1
M@\0,25%HP`,F"%/H[Q\#`(/$$(7`=4J#[`Q3Z/\W`P")!"2)Q^AA.0,`@\00
MA<")PW1G@^P,5^AO"P,`@\0,_W4,:$C7"`C_,^@%>___@\00,=*%P'YXC67T
M6UZ)T%_)PX/L#%/H63T#`(D$)%9H'.0("&@`$```:,`#)@CH87;__X/$'&H`
M:@!HP`,F".B@&@``NO_____KO59H4.0("&@`$```:,`#)@CH-';__X/$#&H`
M:@!HP`,F".AS&@``B3PDZ.,*`P"Z_O___^N(5FB8Y`@(:``0``!HP`,F".C_
M=?__@\0,:@!J`&C``R8(Z#X:``"Z_?___^E8____58GE5U93@>PX$```BW4,
M5HM=$,>%U.___P````#H%NO__X/$$#'2A<`/A)$```"%VP^$Y0```(/L#%;_
M=0AH`.4("&@`$```:,`3)@CHDG7__[_`$R8(,<#\N?_____RKO?1@\0<25%H
MP!,F"%/HC1X#`(/$$(7`#X7C````@^P,4^B9-@,`B00DB<?H^S<#`(/$$(7`
M=`:+,(7V=2Z#[`Q7Z`4*`P"+C=3O__^#Q!"%R750Q@7`$R8(`+K`$R8(C67T
M6UZ)T%_)PXGV4FC_#P``_S!HP!,F".CF>/__B3PDZ,8)`P"+O=3O__^#Q!"%
M_W3(@^P,4^CD&`,`@\00Z[J-=@"#[`Q3Z-,8`P"#Q!#&!<`3)@@`ZZ*-=@"#
M[`AH`1```(V=V.___U/H//?__X/$$(7`='R%P(G#QX74[___`0````^%[/[_
M_U!J`&H`:)#="`CHVA@``#'2Z5____^#[`Q3Z%H[`P")!"16:#SE"`AH`!``
M`&C`$R8(Z&)T__^#Q!QJ`&H`:,`3)@CHH1@``(N5U.___X/$$(72=+J#[`Q3
MZ#<8`P"#Q!`QTND-____4&H`:@!3Z'88``"#Q!`QP.EO____58GE5U93@>PX
M$```BW4,5HM=$.A8Z?__@\00,=*%P`^$FP```(7;QX74[___``````^$Y0``
M`(/L#%;_=0AH:.4("&@`$```:,`C)@CHRG/__[_`(R8(,<#\N?_____RKO?1
M@\0<25%HP",F"%/HQ1P#`(/$$(7`#X7C````@^P,4^C1-`,`B00DB<?H,S8#
M`(/$$(7`=`:+,(7V=2Z#[`Q7Z#T(`P"+C=3O__^#Q!"%R750Q@7`(R8(`+K`
M(R8(C67T6UZ)T%_)PXGV4FC_#P``_S!HP",F".@>=___B3PDZ/X'`P"+O=3O
M__^#Q!"%_W3(@^P,4^@<%P,`@\00Z[J-=@"#[`Q3Z`L7`P"#Q!#&!<`C)@@`
MZZ*-=@"#[`AH`1```(V=V.___U/H=/7__X/$$(7`='R%P(G#QX74[___`0``
M``^%[/[__U!J`&H`:"R\"`CH$A<``#'2Z5____^#[`Q3Z)(Y`P")!"16:#SE
M"`AH`!```&C`(R8(Z)IR__^#Q!QJ`&H`:,`C)@CHV18``(N5U.___X/$$(72
M=+J#[`Q3Z&\6`P"#Q!`QTND-____4&H`:@!3Z*X6``"#Q!`QP.EO____58GE
M5U93@>PX$```BW40BWT,BUT4QX74[___`````%;H@^?__X/$$(7`#X3\````
M@^P,5^AOY___@\00A<`/A.@```"%VP^$.0$``(/L"%97_W4(:-#E"`AH`!``
M`&C`,R8(Z.QQ__^_P#,F"#'`_+G_____\J[WT8/$'$E1:,`S)@A3Z.<:`P"#
MQ!"%P'5.@^P,4^CW,@,`B00DB<?H630#`(/$$(7`=`J+,(7V#X60````@^P,
M5^A?!@,`BXW4[___@\00A<EU;,8%P#,F"`"XP#,F"(UE]%M>7\G#@^P,4^A-
M.`,`B00D5F@\Y0@(:``0``!HP#,F".A5<?__@\0<:@!J`&C`,R8(Z)05``"+
ME=3O__^#Q!"%TG0/@^P,4^@J%0,`@\00C78`C67T6UXQP%_)PX/L#%/H$14#
M`(/$$.N&4FC_#P``_S!HP#,F".C>=/__B3PDZ+X%`P"+O=3O__^#Q!"%_P^$
M8O___X/L#%/HV!0#`(/$$+C`,R8(Z5'___^#[`AH`1```(V=V.___U/H0_/_
M_X/$$(7`="B%P(G#QX74[___`0````^%F/[__U!J`&H`:"R\"`CHX10``.ED
M____4&H`:@!3Z-$4``"#Q!`QP.O&B?95B>575E.![#@0``"+=0Q6BUT0QX74
M[___`````.BJY?__@\00,=*%P`^$D0```(7;#X3E````@^P,5O]U"&A<Y@@(
M:``0``!HP$,F".@F</__O\!#)@@QP/RY______*N]]&#Q!Q)46C`0R8(4^@A
M&0,`@\00A<`/A>,```"#[`Q3Z"TQ`P")!"2)Q^B/,@,`@\00A<!T!HLPA?9U
M+H/L#%?HF00#`(N-U.___X/$$(7)=5#&!<!#)@@`NL!#)@B-9?1;7HG07\G#
MB?92:/\/``#_,&C`0R8(Z'IS__^)/"3H6@0#`(N]U.___X/$$(7_=,B#[`Q3
MZ'@3`P"#Q!#KNHUV`(/L#%/H9Q,#`(/$$,8%P$,F"`#KHHUV`(/L"&@!$```
MC9W8[___4^C0\?__@\00A<!T?(7`B</'A=3O__\!````#X7L_O__4&H`:@!H
M++P(".AN$P``,=+I7____X/L#%/H[C4#`(D$)%9HR.8("&@`$```:,!#)@CH
M]F[__X/$'&H`:@!HP$,F".@U$P``BY74[___@\00A=)TNH/L#%/HRQ(#`(/$
M$#'2Z0W___]0:@!J`%/H"A,``(/$$#'`Z6____]5B>53@>P($```_W4(:"GA
M"`AH+^$("&@TX0@(:/CB"`B-G?CO__]H`!```%/H?F[__X/$&/]U#%/HMO/_
M_X/$$(M=_,G#B?95B>575E.!["P@``"+=0R%]L>%U-___P`````/A(L!``#_
M=0AH\.8("&@`$```C97H[___4N@N;O__C;WH[___,<#\N?_____RKO?1@\0,
M25&-A>CO__]05N@F%P,`@\00A<`/A;L```"#[`Q6Z#(O`P"#Q!"%P(G'#X2E
M````@^P,4.B4-`,`@\00A<")PW1R_W4(:(SG"`AH`!```(V5Z.___U+HOFW_
M_XV]Z.___S'`_+G_____\J[WT8/$#$E1C9WH[___4U;HMA8#`(/$$(7`#X6_
M````@^P,5NC"+@,`@\00A<")QP^$J0```(/L#%#H)#0#`(/$$`G0#Y3`#[;8
M@^P,5^@D`@,`BY74W___@\00A=)U6XUE](G86UY?R<.0@^P,5N@;-`,`@\00
M4&C,YP@(:``0``"-O>CO__]7Z"%M__^#Q`QJ`&H`C8WH[___4>A>$0``BYW4
MW___@\00A=MU';C_____C67T6UY?R<.#[`Q6Z.<0`P"#Q!#KEXGV@^P,5NC7
M$`,`@\00N/_____KU9"#[`Q6Z*<S`P"#Q!!0:.SG"`CKBH/L"&@!$```C9W8
MW___4^@P[___@\00A<!T+87`B<;'A=3?__\!````#X5&_O__4&H`:@!H++P(
M".C.$```N/_____I>/___U!J`&H`4^BY$```@\00,<#KP8GV58GE5U93@>PL
M(```BW4,A?;'A=3?__\`````#X3+````_W4(:!#H"`AH`!```(V=Z.___U/H
M)FS__XG?,<#\N?_____RKO?1@\0,25%35N@H%0,`@\00A<!U28/L#%;H."T#
M`(D$)(G'Z)HN`P"#Q!"%P'0*BQ"%T@^%L0```(/L#%?HH``#`(N=U-___X/$
M$(7;=4:-=@"-9?1;7C'`7\G#B?:#[`Q6Z),R`P"#Q!!0:#CA"`AH`!```%/H
MGVO__X/$#&H`:@!3Z.(/``"+G=3?__^#Q!"%VW2]@^P,5NAX#P,`@\00ZZ^-
M=@"#[`AH`1```(V=V-___U/HZ.W__X/$$(7`='>%P(G&QX74W___`0````^%
M!O___U%J`&H`:"R\"`CHA@\``.EI____D%%H_P\``/\P4^@";___B3PDZ.+_
M`@"+C=3?__^#Q!"%R74=B=Z_5N$("/RY!````/.F#Y3`C67T6UX/ML!?R<.#
M[`Q6Z.,.`P"#Q!#KU59J`&H`4^@G#P``@\00,<#I=/___Y!5B>575E.![#@@
M``"+?0A7BW40QX74W___`````.C^W___@\00,=*%P`^$A0```(7V#X09`0``
MBTT,A<D/A,8```!7:&CH"`AH`!```(V=Z.___U/H<VK__XG?,<#\N?_____R
MKO?1@\0,25%35NAU$P,`@\00A<!T1H/L#%;H*3$#`(/$$%!HP.@("&@`$```
M4^@U:O__@\0,:@!J`%/H>`X``(N=U-___X/$$(7;=44QTI"-9?1;7HG07\G#
MB?:#[`Q6Z#\K`P")!"2)Q^BA+`,`@\00A<!T!HL0A=)U,X/L#%?HJ_X"`(N=
MU-___X/$$(7;=+N#[`Q6Z,D-`P"#Q!`QTNNNB?97:.CH"`CI-?___U)H_P\`
M`/\P4^B+;?__B3PDZ&O^`@"+C=3?__^#Q!"%R75?_+D$````OU;A"`B)WO.F
M#Y3`#[;0Z63___^#[`AH`1```(V=V-___U/H\.O__X/$$(7`=#B%P(G&QX74
MW___`0````^%N/[__U-J`&H`:"R\"`CHC@T``#'2Z1____^#[`Q6Z"H-`P"#
MQ!#KDU9J`&H`4^AN#0``@\00,<#KMHUV`%6)Y5=64X'L+#```(MU#(7VQX74
MS___``````^$8P$``/]U"&@\Z0@(:``0``"-E>CO__]2Z-IH__^-O>CO__\Q
MP/RY______*N]]&#Q`Q)48V%Z.___U!6Z-(1`P"#Q!"%P`^%7P$``(/L#%;H
MWBD#`(/$$(7`B<=T&H/L#%#H."L#`(/$$(7`=`J+$(72#X6#````4&A;X0@(
M:"GA"`AH+^$("&@TX0@(:/CB"`AH`!```(V=V,___U/H5&C__X/$&%93Z([M
M__^#Q!"%P'0%@#@`=693:&?A"`AH`!```(V%Z.___U#H)VC__X/$#&H`:@"-
MO>CO__]7Z&0,``"+C=3/__^#Q!"%R74?C67T6UXQP%_)PY"`.@`/A'3___]2
M:``0``#_,.L8D(/L#%;HVPL#`(/$$.O3B?92:``0``!0:,!3)@CHIVO__XD\
M).B'_`(`BY74S___@\00A=)U#;C`4R8(C67T6UY?R<.#[`Q6Z)@+`P"#Q!"X
MP%,F".OEB?:#[`AH`1```(V=V-___U/H!.K__X/$$(7`=$"%P(G&QX74S___
M`0````^%;O[__U%J`&H`:"R\"`CHH@L``.E&____D(/L#%;H(RX#`(/$$%!H
MD.D(".G]_O__5FH`:@!3Z'H+``"#Q!`QP.NNC78`58GE5U93@>PX$```_W4(
MBW4,QX74[___`````.A3W/__@\00,=*%P`^$ZP```(7V#X0Z`0``@^P,_W4(
MZ`,&``"#Q!"%P(G'#X1J`0``5VBTZ0@(:``0``!HP&,F".B]9O__B3PDZ/5N
M__^_P&,F"#'`_+G_____\J[WT8/$#$E1:,!C)@A6Z+`/`P"#Q!"%P`^%G0``
M`(/L#%;HO"<#`(D$)(G#Z!XI`P"#Q!"%P(G'=`:+$(72=32#[`Q3Z";[`@#_
M=0AHW.D("&@`$```:,!C)@CH1V;__X/$'&H!:@%HP&,F".B&"@``@\004&C_
M#P``_S=HP&,F".@!:O__B1PDZ.'Z`@"+G=3O__^#Q!"%VW40NL!C)@B-9?1;
M7HG07\G#D(/L#%;H[PD#`(/$$.OBB?:#[`Q6Z,,L`P"#Q!!0:!3J"`AH`!``
M`&C`8R8(Z,ME__^#Q`QJ`6H!:,!C)@CH"@H``(/$$.DI____B?:#[`AH`1``
M`(V=V.___U/H).C__X/$$(7`=%6%P(G&QX74[___`0````^%E_[__U!J`&H`
M:"R\"`CHP@D``#'2Z63___^-=@"#[`S_-12T)@CHZ@,``(/$$%!HA>$("&H!
M:@'HL`H``(/$$.EN_O__4&H`:@!3Z(4)``"#Q!`QP.N9B?95B>53@^P(:/\/
M``#_=0AHP',F".CS:/__,=N#Q!"@P',F".L<C78`H1S#)0B+A)`T!```B(/`
M<R8(0XJ#P',F"(3`=!L/OM"!^O\```!VV(/L#%+H`VW__X/$$.O6B?:XP',F
M"(M=_,G#B?95B>575E.![#@0``"+=0A6Z/_9__^#Q!`QTH7`#X21````@^P(
M:`$0``"-O=CO__]7Z!+G__^#Q!"%P(G##X1;`0``A=L/A#P!``!6:#3J"`AH
M`!```&C`@R8(Z&!D__^_P(,F"#'`_+G_____\J[WT8/$#$E1:,"#)@A3Z%L-
M`P"#Q!"%P'4X@^P,4^AK)0,`B00DB<?HS28#`(/$$(7`=`:+$(72=5"#[`Q7
MZ-?X`@`QTHUE]%M>B=!?R<.-=@"#[`Q3Z-<J`P"#Q!!0:&#J"`AH`!```&C`
M@R8(Z-]C__^#Q`QJ`6H!:,"#)@CH'@@``(/$$.N1D%)H_P\``/\P:,"#)@CH
MEF?__XD\).AV^`(`B1PDZ*('`P"#Q`QH_P\``&C`@R8(:,!S)@CH;V?__S'_
M@\00H,!S)@CK'8UV`(L=',,E"(N$DS0$``"(A\!S)@A'BH?`<R8(A,!T&@^^
MT('Z_P```';7@^P,4NA^:___@\00Z]:0C67T6UZZP',F"(G07\G#5VH!:@%H
M++P(".AZ!P``@\00Z:W^__]0:@!J`%?H9P<``(/$$.F2_O__C78`58GE5U93
M@>PL$```BUT,,?:%V\>%U.___P`````/A-4```#_=0AHGN$("&@`$```:,"3
M)@CHTF+__[_`DR8(,<#\N?_____RKO?1@\0,25%HP),F"%/HS0L#`(/$$(7`
M=5J#[`Q3Z-TC`P"#Q!"%P(G'=$B#[`Q0Z#<E`P"#Q!"%P'03@^P,_S#HGF+_
M_XF%U.___X/$$(/L#%?H-/<"`(/$$(7V#X6#````BX74[___C67T6UY`7\G#
MB?:#[`Q3Z"<I`P"#Q!!0:+7A"`AH`!```&C`DR8(Z"]B__^#Q`QJ`&H`:,"3
M)@CH;@8``(UE]%M>,<!?R<.#[`AH`1```(V=V.___U/HB.3__X/$$(7`="R%
MP(G#O@$````/A0'___]0:@!J`&@LO`@(Z[N#[`Q3Z-$%`P"#Q!#I;/___U!J
M`&H`4^@2!@``@\00,<#KPHUV`%6)Y8/L%&APX`@(Z/AA__^)PH/$$#'`A=)T
M%E!J"FH`4N@28___C5#_@\00@_H"=P/)PY!0:-'A"`AJ`6H!Z-T&``"#Q!#)
MPU6)Y8M5"(/Z!;B!Z@@(="1_)H/Z`KB0Z@@(=!A_/H72N)_J"`AT#4IT8XGV
MN*?J"`B-=@#)PXGV@_H(N+7J"`AT\G\P@_H&N,;J"`ATYH/Z!W79N-OJ"`C)
MPXGV@_H#N.CJ"`ATSH/Z!'7!N`3K"`C)PXGV@_H)N!/K"`ATMH'ZR0```'6F
MN!_K"`C)P[@VZP@(R<-5B>53@^P(:@"-1?A0_W4(Z!L/``"#Q!`]R0```(G#
M=`^%P'4=BT7XBUW\R<.-=@!0:$?K"`AJ`6H!Z`4&``"#Q!"#[`R)'12T)@C_
M=?CHR6C__S'`BUW\R<.)]E6)Y593@^P4BW4(C47T:@!05NB]#@``@\00/<D`
M``")PP^$P0```(7`=&V#[`R)'12T)@C_=?3HA&C__S';@\00H12T)@B#^`6Z
M@>H("'0D?U:#^`*ZD.H("'08#X^\````A<"ZG^H("'0)2'56NC;K"`B0@^P(
M4E9HKNL("&A9ZP@(:@%J`>A<!0``@\0@C67XB=A;7LG#BUWTA=MTHHUE^(G8
M6U[)PX/X"+JUZ@@(=,)_2X/X!KK&Z@@(=+:#^`=T>)"#[`BZI^H("%)6:*[K
M"`AH6>L("&H!:@'H!P4``(/$(.NIB?92:$?K"`AJ`6H!Z/$$``"#Q!#I+/__
M_X/X";H3ZP@(#X1G____/<D```!UL+H?ZP@(Z5;___^#^`.ZZ.H("`^$2/__
M_X/X!'63N@3K"`CI.?___[K;Z@@(Z2____^-=@!5B>53@^P(:@"-1?A0_W4(
MZ/</``"#Q!`]R0```(G#=!.%P'0&B1T4M"8(BT7XBUW\R<.046A'ZP@(:@%J
M`>A=!```@\00B1T4M"8(Z]V)]E6)Y5=64X'L<"`!`(M]"&H!:,#K"`B-M>C_
M_O]6Z+9C__^#Q!"%P'5;@^P,:@"-A9C__O]0:@575NCZ8___@\0@A<`/A6,"
M``"+C<C__O^+E<S__O\AT4%T$8NUT/_^_XN=U/_^_R'>1G5%4&AKZP@(:@%J
M`.C6`P``C67T6UXQP%_)PV@`$```C9V8[_[_4U90Z+%D__]3:(3K"`AJ`6H!
MZ*H#``"#Q"#I>____XGVQ@7`HR8(`%"+C<C__O^+E=#__O\IRE(!^5%HP*,F
M".BT8O__@\0,:@"-A93?_O]0:,"C)@CH4@P``(/$$#W)````B<,/A-`!``"%
MP'1>@^P,B1T4M"8(_[64W_[_Z!9F__^#Q!"A%+0F"(/X!;J!Z@@(="P/C\\`
M``"#^`*ZD.H("'0<#X_*`0``A<"ZG^H("'0-2`^$50$``+JGZ@@(D%)HA>$(
M".D6____D(N=E-_^_X7;=*_&!<"C)@@`B[6H__[_BX6L__[_(<9&=!6+C;#_
M_O^+E;3__O\AT4$/A><```"+C;C__O^+E;S__O\AT4%T%8NUP/_^_XN%Q/_^
M_R'&1@^%G````(/L"%-HP*,F".@Q8/__BYW8__[_B[7<__[_(?.#Q!!#=!&+
MA>#__O^+C>3__O\AR$!U0KC`HR8(C67T6UY?R<.#^`BZM>H("`^$2?___P^/
MU````(/X!KK&Z@@(#X0U____@_@'#X4F____NMOJ"`CI(O___U.+E=C__O^+
MG>#__O\ITU,!^E)HP*,F".@]8?__@\00N,"C)@CKG%:+C;C__O^+E<#__O\I
MRE(!^5%HP*,F".@68?__@\00Z3____]0B[6H__[_BX6P__[_*?!0`?Y6:,"C
M)@CH\6#__X/$$.GT_O__NC;K"`CII_[__XUV`&@`$```C;V8W_[_5U90Z(EB
M__]7:)GK"`CII_W__U!H1^L("&H!:@'H=P$``(/$$.D=_O__@_@)NA/K"`@/
MA&'^__\]R0````^%4/[__[H?ZP@(Z4S^__^#^`.ZZ.H("`^$/O[__X/X!`^%
M+_[__[H$ZP@(Z2O^__^-=@!5B>6#[!3_=0CHPF+__XGV58GE5U93@^P,H01&
M&0@Q]H7`BUT(#X7!````@^P(_S7$PB4(4^@V8___B=\QP/RY______*N]]&#
MQ!"`?!G^"G03@^P(_S7$PB4(:@KH[F'__X/$$(/L#/\UQ,(E".@-7?__@\00
MA?9T%5)6:.SK"`C_-<#")0CH-%[__X/$$(/L"/\UP,(E"%/HTF+__XG?,<#\
MN?_____RKO?1@\00@'P9_@IT$X/L"/\UP,(E"&H*Z(IA__^#Q!"#[`S_-<#"
M)0CHJ5S__XM5#(/$$(72=3N-9?1;7C'`7\G#D(/L#%#H:UW__X/$$(7`B<8/
MA"G___]14&CLZP@(_S7$PB4(Z*Q=__^#Q!#I#____X/L#/]U#.BI8?__D%6)
MY5=64X/L'(M-"(M5#(E-\(E5[.CN7?__BP"#[`R)1>3'1>@`$```:``0``#H
MM5O__X/$$(7`B<,/A"@!``"-=116_W40:``0``!0Z+9;__^#Q!`]`!```(G&
M#XW2````Z*%=__^+5>2)$.B77?__BSB%_W4I5O]U[/]U\%/H9/[__X/$$(7;
M=`R#[`Q3Z$1B__^#Q!"-9?1;7E_)PY"+3>@Q_RGQB4W@=#N#[!#H5%W__UG_
M,.B<6?__B00DZ$1=____,&CQZP@(_W7@C3PS5^C!6?__@\0@.T7@#YW`#[;X
MA?]TD(/L"(U4-P%24^CC7?__@\00A<`/A'?___^#[!")P^C^7/__6O\PZ$99
M__^)!"3H[ES___\P:/'K"`A7C0PS4>AM6?__@\0@Z43___^0@^P(C7@!5U/H
MEUW__X/$$(7`#X06____B<.-112)?>A0_W405U/HJ5K__X/$$.G[_O__D%#_
M=>S_=?!H".P(".AO_?__C67T6UY?R<.-=@!5B>575E.#[`PQP#M%#(MU"+H!
M````<Q:#/(9_=@(QTD`[10QR\H72#X2R`0``BWT,P><"@^P,C4<$4.@D6O__
MB<.#Q!"%V[C)````#X3X````B?G\P>D"B=_SI8M5#,<$DP````#V110"='.+
M,S')A?9T2XGRB?:#^BP/A@X"``"#^BX/A`4"``"#^B\/A/P!``"-0L:#^`8/
MAO`!``"->J6#_P4/AN0!``"-0H6#^`0/AM@!``!!BQ2+A=)UN8/^+70+A<ET
M&8-\B_PM=1*#[`Q3Z'Q@__^X!````.MKBS,QTH7VN0$```!T(XL#B?:#^']V
M`C')@_H_=P:+=1"(!!9"BP23A<!UYH/Z/W<'BWT0Q@07`(7)#X6'````L0$Q
MTHGV#[:",.P("#L$DW0",<E"A<ET&X/Z`W;H@^P,4^@/8/__N`@```"-9?1;
M7E_)PXL+,=*%R>L(B?9"BS23A?9U^(M%$(/L#(/`!,<$DP````"-??#'1?`[
M````4%=J`%-2Z',H``"#Q""%P`^%.`$``(M-\(M5$,9$"@0`QP)X;BTM@^P,
M4^BF7___BW40@\00@#X`=!HQP/RY_____XGW\J[WT4DQP(/Y/P^&=____XUE
M]%M>N`4```!?R<-J`&H`_W4,5NA/&P``B<:#Q!"%]KC)````#X1+____,<#\
MN?____^)]_*N]]'V110!C5G_=4J)]H/L"(U<&PI35N@N6___@\00A<")Q@^$
MCP```&A@10H(:@134.C')0``@\00@_AD=,^%P'18@^P,5NC^7O__N`$```#I
MZO[__X/L"(U<&PI35NCF6O__@\00A<")QG1+:&!%"@AJ`%-0Z(,E``"#Q!"#
M^&1TT^NZ@^P,4^B\7O__C67T6UZX`P```%_)PU-J`&K_5NA$&0``B30DB</H
MFE[__X/$$.FD_?__N,D```#I?O[__X/L#%/H?U[__[@"````Z6O^__^058GE
M5U93@^QLB464B56D,<"+?93\N?_____RKHE-H/=5H(M=E(H#,?\QTH3`N0$`
M``!U#^MRB?9"BW64B@06A,!T$83`>?%"BW64B@06,<F$P'7OA<EU4/9%#`$/
MA?8```")]HM=H(/L"`'[4_]UE.C_6?__@\00A<")190/A#P!``!H8$4*"&H$
M4U#HER0``$>#Q!"#^&1TRH7`N0$````/A:0```"0N00```#\OC#L"`B+?93S
MI@^7P@^2PSC:N08````/A8`````QVU:+?92(V+G_____\J[WT8/I!%&+=92#
MQ@16_W64Z"55__^+50C_"L<$)`````#_=:12_W64BWV4_(C8N?_____RKO?1
M25'HJ"@``(/$((7`N0(```!U)XM5"(L*BUVDQP2+`````/]U#(UUJ%;_,E/H
MWOO__X/$$(7`B<%T38UE]%M>B<A?R<.-=@"+7:"#[`@!^U/_=93H"UG__X/$
M$(7`B464=$QH8$4*"&H`4U#HIR,``$>#Q!"#^&1TSH7`N0$```!UN.D0____
M@^P(C7VL5_]UE.BM6/__@\00A<"Y!P```'68C67T6UXQR8G(7\G#C67T6UZY
MR0```(G(7\G#B?95B>575E.#[`R+112+.&H`:@#_=0R+=0A6Z&X8``")PX/$
M$(7;N,D```!T2X/L"/]U&/]U%(M5$(G8Z/']__^#Q!"%P(E%\'0B.WT,B?AV
M`XM%#(T,A0````#\P>D"BWT0\Z6+30R+512)"H/L#%/H,%S__XM%\(UE]%M>
M7\G#D%6)Y5=64X/L7(M-"(L!A<")RL=%I``````/A$H!``"#^"YT%3T",```
M=`X]#O\``'0'/6'_``!U"XM!!(7`#X2W`0``BUT,QP,`````C78`BP*%P(G3
M=%2#^"X/A&D!```]`C````^$:`$``#T._P``#X1P`0``/6'_```/A&\!``")
M]H/#!(L#A<!T)8/X+G0</0(P``!T%3T._P``=`X]8?\``'7=ZQ&-=@"+`H7`
M=0@YV@^$)`$``(G>_W40*=:-?:A7P?X"5E+H`?K__X/$$(7`#X54`0``BU6D
MA=(/A*\````Q]HM]I/R)\+G_____\JZ)RHU]J+G_____\J[WTO?1@^P(`=%1
M_W6DZ!)7__^#Q!"%P(E%I`^$!`$``(G'_(GPN?_____RKHMUI(/L"/?1C56H
M9L=$,?\N`%)6Z*]5__^+"X/$$(7)C5,$#X7[_O__BU6DBUT,B1.-9?1;7C'2
MB=!?R<.#[`QJ`>C!4___BU4,@\00A<")`KK)````=`7&```PTHUE]%M>B=!?
MR<.0,<#\N?____^-?:CRKH/L#/?14>B(4___@\00A<")1:1T;H/L"(UUJ%;_
M=:3H+U'__^E[____N"X```#IVO[__[@",```Z=#^___&1:@`Z?/^__^X#O\`
M`.F]_O__N&'_``#IL_[__X/L#&H"Z"]3__^+30R#Q!"%P(D!NLD````/A&__
M__]FQP`N`.EC____NLD```#I6____XG"Z53___^-=@!5B>564X/L%(U%]%!J
M__]U".AV%```B<:#Q!"%]K@)````=!E0_W40_W4,5NB7_?__B<.)-"3HL5G_
M_XG8C67X6U[)PU6)Y5=64X/L&/]U".C/%P``B<>#Q!"%_[@)````=$!0C47P
M4&K_5^@<%```@\00A<")QKL)````=!I0_W40_W4,5N@]_?__B<.)-"3H5UG_
M_X/$$(/L#%?H2UG__XG8C67T6UY?R<.058GE5U93@^P<BT4,BW4(QT7H````
M`,=%Y`````#'``````"0BP:%P(EUW'0G@_@N="(]`C```'0;/0[_``!T%#UA
M_P``=`V#1=P$BU7<BP*%P'79BUW<*?/!^P*#[`R-#)T$````B5WP4>CA4?__
M@\00A<")1>P/A`@!``"+??!J`&H`4U;HG10``(/$$(7`B47@=$6#[`C_=1"-
M1?!0BU7LBT7@Z"+Z__^#Q!"%P'0;.=^)^'8"B=B-#(4`````_,'I`HM][/.E
MB5WP@^P,_W7@Z&E8__^#Q!"+7>B%VP^$BP```(M5Y`-5\(/L"(TTE0@```!6
M_W7HZ$)4__^#Q!"%P(E%Z'1]BU7DBUWHQP23+@```(M-\(G0BUWH0,'A`HMU
M[(T\@_S!Z0+SI0-%\(/L#(E%Y,<$@P````#_=>SH^U?__X/$$(M5W(MUW(LZ
M@\8$A?\/A<G^__^+7>B+=0R)'HUE]%M>,<!?R<.-=@"+1>R+3?")1>B)3>3'
M!(@`````Z\.-9?1;7K#)7\G#D%6)Y593@^P4C47T4&K__W4(Z#H2``")QH/$
M$(7VN`D```!T&5'_=1#_=0Q6Z#_^__^)PXDT).AU5___B=B-9?A;7LG#58GE
M5U93@^P0C47L4&K__W4(BWT,Z/(1``"#Q!"%P(G&NPD```!T&U#_=1"-5?!2
M5NCV_?__B<.)-"3H+%?__X/$$&H`:@!J__]U\.@#$P``B0=8_W7PZ!!7__^+
M-X/$$(7VN`D```!T`HG8C67T6UY?R<-5B>575E.#[!"-1>A0:O__=0CH@1$`
M`(/$$(7`B<:_"0```'0=4?]U$(U5[%)0Z(7]__^)PXDT)(G?Z+E6__^#Q!!J
M`&H`:O__=>SHD!(``%K_=>R)1?#HG%;__XMU\(/$$(7VNPD```!T`HG[@^P,
M_W7PZ`05``"+50R)`EG_=?#H<E;__XM]#(L/@\00A<FX"0```'0"B=B-9?1;
M7E_)PXUV`%6)Y5=64X/L&/]U".A[%```B<>#Q!"%_[@)````#X26````4(U%
MZ%!J_U?HQ!```(/$$(7`B<:["0```'0;4/]U$(U5[%)6Z,C\__^)PXDT).C^
M5?__@\00:@!J`&K__W7LZ-41``!>_W7LB47PZ.%5__^+3?"#Q!"%R;X)````
M=4*#[`S_=?#H2Q0``(M=#%J)`_]U\.BY5?__BU4,BP*#Q!"%P+L)````=`*)
M\X/L#%?HG57__XG8C67T6UY?R<.-=@")WNNZ58GE5U93@^P<,?8Q_X72B47P
MQT7L`````'A=.=8/C:8```"%TGA1BTWPBP2YA<`/A)0````/C-4!``"#^']V
M?SW_!P``#X9Q`0``/?__```/AI`!```]__\?``^&IP$``#W___\##X>Y`0``
M@\8%ZT^-=@"#Q@)'BU7PBP2ZA<!T1P^,B`$``(/X?P^&TP```#W_!P``=MP]
M__\```^&]P```#W__Q\`#X86`0``/?___P,/AS4!``"#Q@5'Z[E&1SG7#XQ>
M____@^P,C48!4.C'3?__B47LBWWL@\00,<"%_W1VBUWL`=XQ_SG>B77D=D>)
M]HGZBW7PBPR61X/Y?W=IQT7H`````+X!````A=MT((U6_^L0D(C(@^`_@\B`
MB`03P>D&2H72?^V*5>@)RH@3`?,Y7>1WN\8#`(M-#(7)=`@K7>R+=0R)'HM=
M"(7;=`6+10B).(M%[(UE]%M>7\G#B?9&1^D-____@?G_!P``=PZ^`@```,=%
MZ,````#KC8'Y__\``'<:O@,```#'1>C@````Z73___^#Q@-'Z=7^__^!^?__
M'P!W(KX$````QT7H\````.E2____@\8"Z?S^__^#Q@1'Z:O^__^!^?___P-W
M(KX%````QT7H^````.DH____@\8#Z=+^__^#Q@9'Z8'^__^^!@```,=%Z/P`
M``#I!O___X/&!.FP_O__BUT(A=L/A#S___^+30B).>DF____@\8&Z9/^__^-
M=@!5B>575E-*@^P0B47PB57HBT7PBQ"!^O_Z`@#'1>0`````#X=\`0``B='!
MZ0AFBX0)8`<)"&8]_Q`/CI(!``"8+0`1``")1>PQR8-]Z``/AN$```"+7?"+
M5(L$@?K_^@(`#X?Q````B=;![@AFBX0V8`<)"&8]_Q`/COX```"8C;``[___
MA?8/A+L````Y=>R->0$/CHX```")^87_ZS:0B=C!Z`AFBY0`8`<)"&:!^O\0
M?E@/O\(M`!$``#GP?F2+5?"+!(J)1(K\B1R*QT7D`0```$ET38M5\(M<BOR!
M^__Z`@!VNHV#``#R_SW__P(`#X>=````P>@(9HN4`&#M"`AF@?K_$'^KC78`
M#[_2#[;#P>((#[:$`F#S"`@Y\'^?C78`BW7LB77LB?DY?>@/AQ____^+?>2%
M_P^%T/[__X/$$%M>7\G#C7D!B?DY?>B)=>SKVHUV`(V"``#R_S'V/?__`@!W
MX<'H"&:+A`!@[0@(9CW_$`^/`O___YB!XO\```#!X`@/MK008/,(".GR_O__
MD(7V#X@D____BW7LZX:-=@"-@@``\O\]__\"`,=%[``````/AXS^___!Z`AF
MBX0`8.T("&8]_Q`/CV[^__^8@>+_````P>`(#[:$$&#S"`CI7?[__U6)Y5=6
M4X/L7(E5[(M5"(U:_H/[`0^6P8E%\(/Z`0^VP8E%W,=%V``````/A$`&``"#
M^@,/A#<&``#'1>@`````BWWPBTWLA<EX#HMU\`-U[#G^#X;A`0``B@>$P(A%
MLP^$U`$```^,4`$``+X!````N'\````/ODVSNP$````AP3GS?22-=@`/OA0?
MB=`EP````(/`@`^%E`$``,'A!H/B/PG10SGS?-^)RXV+`%3__X'YKRL``'<W
M@?FC*P``N`$```!W$HG(F;L<````]_N#^@$9P(/``P%%Z`^V5;,/OII@[`@(
M`=_I5____XUV`#').1T`3@D(OA<4```/A[$````Y';#N"0@/@J4```"0C10Q
MB=#!Z!^-!`+1^(L4Q0!."0@YVG0F.<@/A(0````YVG-HB<&-%#&)T,'H'XT$
M`M'XBQ3%`$X)"#G:==J+3=R%R71.#[<,Q09."0B!^?__```/A*0(``")R`5@
M#0D(=$*)PC';BH%@#0D(ZP\/ML`/OK!@[`@(`?)#B@*$P'7M`5WHZ4+___^-
M=@")QNEM____#[<,Q01."0B!^?__``!UMI#_1>CI'____P^V5;.)T"7@````
M/<`````/A(<$``")T"7P````/>`````/A)D$``")T"7X````/?`````/A)\$
M``")T"7\````/?@````/A*4$``"!XOX```"!^OP```"[_____P^%C/[__[X&
M````N`$```#I2/[__XGVN?_____I;_[__XM5Z(/L#(T<E00```!3Z#=(__^)
M1>2+?>2#Q!`QP(7_#X0@!0``QT7@`````,=%K`````"+??"-=@"+5>R%TG@.
MBUWP`UWL.?L/AO\$``"*%X32#X3U!```#XQ7`P``O@$```"X?P````^^RKL!
M````(<$Y\WTDC78`#[X4'XG0)<````"#P(`/A?T#``#!X0:#XC\)T4,Y\WS?
MB<Z+3:R)3=2-C@!4__^!^:\K``!W*8M%K(M5Y('YHRL``(T<@@^&.0(``(7;
M=`*),[D!`````4VLZ;X!``"0,<DY-0!."0B[%Q0```^'G0$``#DUL.X)"`^"
MD0$``)"-%!F)T,'H'XT$`M'XBQ3%`$X)"#GR="HYR`^$<`$``#GR#X-,`0``
MB<&-%!F)T,'H'XT$`M'XBQ3%`$X)"#GR==:+7=R%VP^$+@$```^W%,4&3@D(
M@?K__P``#X1K!@``B=`%8`T)"`^$(@$``(E%R(J"8`T)"(3`#X0>`0``B,*+
M=:S_1:R$THEUQ'ARO@$```"X?P````^^RKL!````(<$Y\WTFB?:+1<@/OA08
MB=`EP````(/`@`^%C08``,'A!H/B/PG10SGS?-R)R(M-Q(MUY(D$CHM-R`^V
M&0^^DV#L"`@!T8E-R(H1A-(/A*H```"+=:S_1:R$THEUQ'F.#[;*B<@EX```
M`#W`````#X2?!0``B<@E\````#W@````#X29!0``B<@E^````#WP````#X30
M!0``B<@E_````#WX````#X3A!0``@>'^````@?G\````N/____\/A6S___^^
M!@```+@!````Z2?___^-=@")P^F%_O__#[<4Q01."0B!^O__```/A=+^__^0
MBT6LBU7DB32"0(E%K(M=K(7;=%"+3=2+=>2+%(Z!^O_Z`@`/A\8```")T,'H
M"&:+A`!@!PD(9CW_$`^.U0```)@M`!$``(7`=1J+5:R+=>"+7>0K5>"-!+/H
M]OC__XM5U(E5X`^V!P^^B&#L"`@!S^D[_?__N">N=&_WZ8G(P?@?P?H(*<*-
ML@`1``"-!-*)=="--,*-!'+!X`*)SBG&B?"9OAP```#W_@5A$0``B46@B<B9
M]_Z%VXV"IQ$``'0+BU70BTV@B1.)2P0]IQ$``+D"````#X1L_?__A=MT`XE#
M"+D#`````4VLZ1[___^-@@``\O\]__\"``^'2O___\'H"&:+A`!@[0@(9CW_
M$`^/*____YB!XO\```#!X`@/MH008/,(".D:____#[;*B<@EX````#W`````
M=&2)R"7P````/>````!T>HG()?@````]\`````^$@````(G()?P````]^```
M``^$A@```('A_@```('Y_````+[_____#X6-_/__O@8```"X`0```.E*_/__
MO@(```"P'^D1^O__O@(```"P'^DR_/__QT78`0```.F]^?__O@,```"P#^GM
M^?__O@,```"P#^D._/__O@0```"P!^G5^?__O@0```"P!^GV^___O@4```"P
M`^F]^?__O@4```"P`^G>^___N?_____I!OS__X'YHRL```^'/P(``+H<````
MB<B)UIGW_H72#X4K`@``BTVTA<D/B"`"``"#?;0<#X\6`@``BWV\`WVTBUVX
MB3N+5<#K"HMUY(L$EHE$EOQ".U6L<O#_3<"+5:C_3:PQR3E5P'0TBUW`BTWD
MBU29_('Z__H"``^'T`(``(G7P>\(9HN$/V`'"0AF/?\0#X[H`@``F(V(`.__
M__]%P(M%K#E%P')/BU6LBT7DQP20`````(UE]%M>7\G#BWVLA?\/A>\!``"+
M1=B%P'39BU6LA=)TTC')BUVL.=G'1:@`````QT7``````'.[BWWDQP2?````
M`(M%P(MUY(L<AH'[__H"``^'!P$``(G:P>H(9HN$$F`'"0AF/?\0#XX8`0``
MF(VX`.___XM%P(7`#X3-````A<ET"#GY#X3!````BW7DBU6HBTVHBPR.C026
MB46XB<@M`!$``(E-O(V36>[__X'I`*P``(/X$HVSG^[__XE5M`^'B?[__X7V
M#XB!_O__@_X4#X]X_O__C12`C3R0`?>-'/T`````*?N-!)T`K```BU6XB0+I
MEO[__XG8P>@(,=*#^#`/AQ(!``!FBX0`X#4*"&8]_Q"-D`#O__]_$9@/MLO!
MX`@!R&:+E`#@%0H(9H'Z@P$/AN(````/M](/MQR5$`P*"#M=O`^$GP$``(7_
M=0:+=<")=:B)^>F*_O__C8,``/+_,?\]__\"``^'!/___\'H"&:+A`!@[0@(
M9CW_$`^/Z/[__Y@/MO/!X`@/MKPP8/,(".G;_O__BT6\P>@(,?:#^#!W)F:+
MA`#@-0H(9CW_$(VP`.___W\2F`^V=;S!X`@!\&:+M`#@%0H(C89M____9CW1
M``^''/___P^WU@^W#)4T$`H(.=D/A5W___\/MP25-A`*"(M5N(D"Z8W]__^+
M5:R+=>"+3>0K5>"-!+'H@O3__^GX_?__C4;_9CV1``^')?___V:!^F0!#X8:
M____9H'Z@P$/AP____\/M]X/M\J)VL'B!2G:`<H/MX02N.L)"(7`#X3P_O__
MBWVXB0?I*/W__Y"^`@```+`?Z=CY__^^`P```+`/Z<SY__\/MQ3%!$X)".F(
M^?__#[<,Q01."0CI3_?__XV"``#R_S')/?__`@`/ASO]___!Z`AFBX0`8.T(
M".D:_?__O@0```"P!^F#^?__F('B_P```,'@"`^VC!!@\P@(Z0C]__^^!0``
M`+`#Z6#Y__\/MS25$@P*"(M]N(DWZ9'\__^)]KG_____Z7;Y__^)]E6)Y5=6
M4XM]"(H'A,!X/;X!````N'\````/O@^[`0```"'!.?-]'I`/OA0?B=`EP```
M`(/`@'5]P>$&@^(_"=%#.?-\XXG(6UY?R<,/MM")T"7@````/<````!T3(G0
M)?`````]X````'13B=`E^````#WP````=%&)T"7\````/?@```!T3X'B_@``
M`('Z_````+C_____=:V^!@```+@!````Z7#___^^`@```+`?Z63___^Y____
M_XG(ZXF^`P```+`/Z4____^^!````+`'Z4/___^^!0```+`#Z3?___^)]E6)
MY8M-"%=6@_E_4XM=#'<S,?^^`0```(7;="&-5O_K$HUV`(C(@^`_@\B`B`03
MP>D&2H72?^V(R@GZB!-;B?!>7\G#@?G_!P``=PR_P````+X"````Z\"!^?__
M``!V%('Y__\?`'<8O_````"^!````.NDO^````"^`P```.N8@?G___\#=PR_
M^````+X%````ZX2__````+X&````Z77___^058GE5U93@^P,BT4,BUT(A<")
MVL=%[``````/B/D```"-#`,YV78BB@.$P'0<C78`#[;X#[ZW8.P("`'R_T7L
M.=%V!HH"A,!UYXM-[(/L#(T$C00```!0Z!0^__^)1?"+5?"#Q!`QP(72=#<Q
M_SM][(G>?14/M@:#^']W,(M=\(D$NT9'.WWL?.N+=1"+5?"%]L<$N@````!T
M!8M=$(D[BT7PC67T6UY?R<.)]CW?````=RV)PKL"````@^(?N0$```#K#0^V
M!`[!X@:#X#\)PD$YV7SOBTWPB12Y`=Y'ZZ0][P```'<,B<*[`P```(/B#^O*
M/?<```!W#(G"NP0```"#X@?KMSW[````=RJ)PKL%````@^(#ZZ2*`^L1#[;(
M#[Z!8.P("`'"_T7LB@*$P'7KZ1+___^)PKL&````@^(!Z7?___^)]E6)Y5.+
M71"+312+10B+50S'11``````B4T,B5T(6\GI:.[__U6)Y593@^P,BU4,BT4(
M:@/H:_+__X/$#&H`:@!J`+K_____B<;H/N[__XG#B30DZ,!#__^#Q!"-9?B)
MV%M>R<-5B>564U%J`&H`:@"+50R+10CH$>[__[K_____B<;'!"0#````Z!;R
M__^)PXDT).B`0___C67XB=A;7LG#C78`58GE@^P4:&`V"@CH=#O__X/$$(7`
M=`6`.`!U'(/L#&H`Z%X^__^#Q!"%P'0%@#@`=0:X:#8*")#)PXGV58GE5U93
M@^PDBUT0QT78`````(MU#%-6Z'M`__^#Q!"%P'4XBWT(_+G_____\JZ#[`SW
MT5'H#CS__XG"@\00,<"%TG0,@^P(_W4(4NBW.?__C67T6UY?R<.-=@"#[`A3
M5NB6'0$`B47@@\00,<"#?>#_=-V+50B)5>0QP(M]"/RY______*N]]%)C1R)
M@^P,C4,%B4WHB47<4.BI.___@\00A<")QHE%[`^$A````(U#!.M&Z*\]__^+
M`(/X%G1>#X^>````@_@'#X65````BWW<@^P(T>>+7>R)?=Q75NA4/O__*?.#
MQ!"%P'0_C108B<:)^"G8B57L2(/L#(E%\(U%\%"-?>Q7C4WH48U=Y%/_=>#H
M#"(!`(/$($!TEHM-[,8!`(M=Y(`[`'0'QT78`0```(/L#/]UX.@N(@$`BWW8
M@\00A?]U"HGPC67T6UY?R<.#[`Q6,?;HVT'__X/$$(GPZ^;'1=@!````Z[&-
M=@!5B>6#[!1H8#8*".C(.?__@\00A<!T!8`X`'4<@^P,:@#HLCS__X/$$(7`
M=`6`.`!U!KAH-@H(D%)0:&XV"@C_=0CH2?[__\G#C78`58GE@^P4:&`V"@CH
M?#G__X/$$(7`=`6`.`!U'(/L#&H`Z&8\__^#Q!"%P'0%@#@`=0:X:#8*")!1
M:&XV"@A0_W4(Z/W]___)PXUV`%6)Y5=64X/L?(M-&(M5#(LYBP*%_XE%\,=%
MZ``````/A.$```"+?>B-''^+=1B+!)Z#^`@/A]X```#_)(5T-@H(BU7HC012
MBTT8BT2!!*G___]_=0V%111U"(7`#X6-````BWWHC1Q_BW48BT2>!*G___]_
M=`6%111U=/9%%`%T"(7`#X3R!@``@^P(_W7P_W4(Z.7\__^#Q!"%P(G##X3#
M!@``QT7P`````(L`,=*%P'05N`$```")1?")PHU``8M,@_R%R77P.U40#X.#
M!@``C0R5`````(M]"(/L#/S!Z0*)WO.E4^A$0/__@\00_T7HBUWHC3Q;BU48
MBS2ZA?8/A1____^+1?"+30R)`8UE]%M>,<!?R<.X90```(UE]%M>7\G#BWWH
MC01_BW48BT2&!*G___]_#X3J!```BU7HC012P>`"BTT8BU0(!/?"____?W0%
MA544=97V110$=(^+7?#'1=0`````BW48.5W4B5W8BT0P"`^#<O___XLXB7V8
MBTV8BU74BUT(,?^%R8LTDP^$\@0``#';ZQ<Y\0^#3@4``(/#&(L,`T>%R0^$
MUP0``(L4`SGR=^J+3`,$A<EUVCGRZ]B+7>B-!%N+?1B+1(<$J?___W\/A#,$
M``"+5>B-!%+!X`*+31B+5`@$]\+___]_=`F%510/A?#^__^+?1B+1#@(BW7P
MB470B76LQT6``````(M=K#E=@`^#S?[__XM5T(L*B4VHBT4(BWV`BW6HBQRX
M,<"%]@^$``0``#'_ZQ8YWG,H@\<8BU70BPP70(7)#X3F`P``BTW0BQ0/.=IW
MY(MT#P2%]G78.=IRV(/X_P^$QP,``(U=[(7;=`.)1>R+58"#^O\/A&#^__^+
M1>R-!$#!X`.+=="+?#`4A?^[!````'40C40P%(/H!$MT!HL(A<ET](M-K(UT
M&?\[=1`/@Y4$```IT8T\C?S___]05XMU"(T\EHT$&HU/!%&-#(91Z.<U__^+
M=>R-#)T`````C11VBT70C730"/S!Z0+SI0-=\(U3_X/$$(E5K(E5\.GX_O__
MD(M]\(E]X(M-Z,=%W`````"+5>"-!$F+71@Y5=R+=(,(#X.Q_?__BQ:)5:"+
M?0B+3=R+1:"+'(\Q_X7`#X0,`P``,<GK%CG:<R6-=@"#P1B+%#%'A=(/A/("
M``"+!#$YV'?JBU0Q!(72==LYV'+>1P^$V`(``(-]W/\/A%C]__^X`@```.E\
M_?__C78`BU48BQJ%V\=%S`````#'1<@`````QT7$`````,=%P/_____'1;S_
M____QT7D``````^$/?W__XM%\(E%C(E%D(E%B(E5A.LF@_@'#X0K`0``@_@(
M#X2>`0``@T6$#(M]A(L?_T7DA=L/A(T```"+=82+!H/X!G70QT6X`````(M5
MD#E5N,=%S`$```"+?@ASR8LWB764B?:+70B+1;B+392+-(,QVX7)=#(QR>L1
MB?8Y\G,>@\$8BQ0Y0X72=!V+!#DY\'?NBU0Y!(72=>(Y\'+B0P^%(0(``(UV
M`/]%N(MUD#EUN'*Q@T6$#(M]A(L?_T7DA=L/A7/___^+5<R%T@^$;OS__XM%
MR(7`#X1C_/__BTW$A<D/A%C\__^#?<#_#X0E_/__@WV\_P^%G0(``(M5P(M-
M"(M]&(T$4HLQBTR'"(L9,?^%VP^$\P$``#';ZQ<Y\@^##@(``(/#&(L$"T>%
MP`^$V`$``(L$"SGP=^J+5`L$A=)UVCGPZ]C'1;0`````BTV,BUV$.4VTQT7(
M`0```(M["`^#OO[__XL'B46DC78`BUVTBTT(BU6DBS29,=N%TG0R,<GK$8GV
M.?)S'H/!&(L$.4.%P'0=BP0Y.?!W[HM4.02%TG7B.?!RXD,/A2L!``"-=@#_
M1;2+=8PY=;1RL>EB_O__QT6P`````(M5B(M-A#E5L,=%Q`$```"+<0@/@T+^
M__^+'HE=G(M]"(M5L(M%G(L<ES'_A<!T+C')ZQ"0.=IS'H/!&(L$,4>%P'0:
MBP0Q.=AW[HM4,02%TG7B.=ARXD</A<@```#_1;"+38@Y3;!RM>GM_?__A444
M#X7$^___A<`/A<WZ___IM_O__X5%%`^%#?O__X7`#X6W^O__Z0#[__^-=@#_
M18"+=:PY=8`/@MO[____1>B+7>B-/%N+51B+-+J%]NF;^O___T7<BUW@.5W<
M#X+/_/___T7HBUWHC3Q;BU48BS2ZA?;I=OK___]%U(MUV#EUU`^"Z?K__^E1
M^O__@WVX_P^$5OW__[@%````Z6OZ__^)]H-]M/\/A$#]__^+?>2)?<#I-?W_
M_X-]L/\/A"O]__^+=>2)=;SI(/W__T</A0KZ__^-9?1;7K@$````7\G#1W25
M@WW4_P^$\/G__[@!````Z13Z__^-=@!'=-:+5<"+?1B-#%*+70B+5(\(BT7P
MBW2#_(L:,?^%VW2W,=OK#SGQ<ZB#PQB+#!-'A<ETI(L$$SGP=^Z+3!,$A<EU
MXCGPZ^"#[`Q3Z-,Y__^X9````.FV^?__N,@```#IK/G__[@#````Z:+Y__^P
M9NF;^?__B?95B>564X/L$(M=##'`.=B+=0AS%(L.A<ET#HGV0#G8<P>+%(:%
MTG7T@^P,_W44_W404XE%](U%]%!6Z#WX__^#Q""%P'42BU7T.=JP9',)QP26
M`````##`C67X6U[)PY!5B>575E.#[`PQV[XR````A=MT#(/L#%/H+SG__X/$
M$(U%\%%0:O__=0CHO?/__XM]\%L!]UJ-%+T`````4E#H"#7__X/$$(7`B<,/
MA(T```"#[`S_=13_=1!7C4WP45#HM_?__X/&,H/$((/X9(G'=)Z%P'03@^P,
M4^C-./__B?B-9?1;7E_)PVH`:@#_=?!3Z)[T__^)QHD<).BL./__@\00A?:X
MR0```'35,<#\N?____^)]_*N]]%).TT,<RN#[`A6_W4(Z%`O__^)-"3H>#C_
M_XUE]%M>,<!?R<.-9?1;7KC)````7\G#@^P,5NA8./__N&0```#KAI!5B>57
M5E.#[`PQP(M]",=%\`````#\N?_____RKJ%`1@H(B<Z%P(M=$/?6OT!&"@AT
M+HGV@^P(4_\WZ'$U__^#Q!"%P`^$C````(/'"(L7A=)UX;AG````C67T6UY?
MR<.A0$8*"(7`=.J+7P2%VW3CBTWPA<ET#H/L#/]U\.C.-___@\00@^P,5NC2
M,/__@\00A<")1?!T0H/L"/]U"%#H?"[___]W!/]U%%;_=?#H4?[__X/&,H/$
M((/X9(G#=+"%P'4@BW4,BWWPB3Z)V(UE]%M>7\G#BP?KB[C)````Z73___^#
M[`S_=?#H83?__X/$$(G8Z]B)]E6)Y5=64X/L-(M-%#';BU4(BP$YT\=%[(``
M``#'1>@`````QT74`````(E%T,=%W$@```!S9(GVBW4,BQ2>@_I_=U&+?=`K
M?=2#_P$/AH8!``"+31"+?=3_1=2%R8C0="V+11`/MC08C4*?@_@9B=%W`XU*
MX#'2A?9U#8UQOX/^&0^&Z````)#!X@6-!`J+51B(!!=#.UT(<IZ+3=2%R8E-
MX(E-Y'0*BUT8Q@09+?]%U(M]"#E]X`^#H````#'2.U4(QT78_____W,;D(M-
M#(L$D3M%['().T78<P2)1=B00CM5"'+FBT7HBTWD03'2BUW8]]`K7>SW\3G#
M#X>9`0``#Z_9QT7,`````(MU"`-=Z#EUS(E=R',JC78`BU7,BUT,BP23.T78
M<PG_1<@/A&<!```[1=AT/O]%S(MU"#EUS'+9BUW(BU780T*+?0B)7>B)5>PY
M?>0/@F#___^+112+3=2)"(/$-%M>,<!?R<.R`>D2____BU7(OR0```#K4#M]
MW+D!````=A*+1=R#P!HY^+$:=@:)^2M-W)`YRG)%*<J[)````"G+B=`QTO?S
MB<.-!`J+==3_1=2#^!F-4!9W`XU088M-&(@4#H/')(G:BTW0.4W4<JBX`@``
M`(/$-%M>7\G#BWT0BTW4,=O_1=2%_W0.BW40BT7,@#P&`'0"LP&#^AF-0A9W
M`XU"887;#[[0=`:#Z"`/OM"+71B(%!F+?>2+5>!'.57D=6>XD7.?7?=ER(G1
MP>D(B<@QTO?W`<$QVX'YQP$``'8DOM5!'=2)R/?F*='1Z8E5Q`--Q,'I!8/#
M)('YQP$``(E%P'?AC03)P>`"C7$F,=+W]@'8_T7,B47<QT7(`````(E]Y.FH
M_O__BTW(T>GKG[@#````Z3G___]5B>575E.#["R+31"+`8E%X(M5"#'`,<DY
MT,=%[(````#'1>0`````QT7H`````,=%W$@```!R"NLGB?9`.T4(<Q&+70R`
M/`,M=?&)P4`[10AR[SM-X+@"````#X<5`0``,=(YRG-%BW48A?8/A`X!``"+
M=0P/O@06@^A!@_@9BUT8BWWH#Y8$.XH$%H3`#XC+````BWWH#[[`BUT40HD$
MNT<YRHE]Z'+)C78`,?^%R70#C7D!.WT(#X.N````BU7DNP$```"^)````(E5
MV.F#````D(M-#`^^%`^-0M!'@_@)C4KJ=A6-0K^#^!F)P78+C4*?@_@9=V:)
MP9"#^2-W7HM%Y#'2]]#W\SG(#X*2````B<H/K],!5>0[==RZ`0```'84BT7<
M@\`:.?"R&G8(B?(K5=R-=@`YT7)UN20````IT;C_____,=+W\3G8<E0/K]F#
MQB0[?0@/@G7___^-9?1;7K@!````7\G#BW7HBWT0B3<QP(UE]%M>7\G#B?:+
M=0R*!!:$P'C5BWWH#[[`BUT40HD$NT<YRHE]Z'+AZ0C___^-9?1;7K@#````
M7\G#BU7DBUWHBW780RM5V(7VB5W4#X7>````N)%SGUWWXHG1P>D(B<@QTO=U
MU`'!,=N!^<<!``!V)+[501W4B<CWYBG1T>F)5<P#3<S!Z06#PR2!^<<!``")
M1<AWX8T$R<'@`HUQ)C'2]_8!V#'2B47<BT7D]W74B=:+5>SWTCG0#X=O____
MBUW@`47L.5WH<W"+51B%TG0J4(M=Z"GS4XM=&`'S4XU3`5+H]RG__XM-#`^^
M1#G_@^A!@\00@_@9#Y8#4"EUZ(M-Z,'A`E&+712-%+-2@\($4NC(*?__BT7L
MBTT4B02Q1HEUY(/$$(MUU(EUZ.D._O__B='1Z>DE____N`(```#IO/[__XGV
M58GEBT40B@"$P+K_____>`T/MM"+30R)$;H!````B=#)PXGV58GEBU40@_I_
MN/____]W"HM%#(@0N`$```#)PU6)Y5=64U&+31"*$832BW4,BUT4>!(/ML*)
M!K@!````6EM>7\G#B?:`^L&X_____W;N@/K?=RE+L/Y^Y(I)`8/Q@(#Y/[#_
M=]>)TX/C'\'C!@^VT0G3N`(```")'NO!D(#Z[W=?@_L"N/[___]^L8I9`8C8
M@_"`/#\/AV4!``"*20*(R(/P@#P_#X=5`0``@/K@=PF`^Y\/AD<!``")UX/S
M@`^VTX/G#\'G#,'B!H/Q@`G7#[;9"=^X`P```(D^Z5S___^`^O</AJ<```"`
M^OL/AQ@!``"#^P2X_O___P^.//___XI9`8C8@_"`/#\/A_`````/MGD"B?B#
M\(`\/P^'WP```(I!`XA%\X/P@#P_#X?.````BDD$B,B#\(`\/P^'O@```(#Z
M^'<)@/N'#X:P````@_.`#[;#@_>`@^(#B?O!X!+!XA@)PH!U\X`/ML/!X`P/
MMEWS"<+!XP:#\8`)V@^V^0GZN`4```")%NFM_O__D(/[`[C^____#XZ>_O__
MBED!B-B#\(`\/W=6#[9Y`HGX@_"`/#]W28I)`XC(@_"`/#]W/8#Z\'<%@/N/
M=C.#\X`/ML.#]X"#X@?!X`R)^\'B$@G"#[;#P>`&@_&`"<(/MOD)^K@$````
MB1;I/?[__Y"X_____^DR_O__@/K]N/____\/AR3^__^#^P6P_@^.&?[__XI9
M`8C8@_"`/#]WT0^V>0*)^(/P@#P_=\2*00.(1?*#\(`\/W>WBD$$B$7Q@_"`
M/#]WJHI)!8C(@_"`/#]WGH#Z_'<%@/N#=I2#\X"#]X")V(/B`8G[P>`8#[;[
MP>(>@'7R@`G"P><2#[9%\H!U\8`)^L'@#`^V7?$)PL'C!H/Q@`G:#[;Y"?JX
M!@```(D6Z87]__^058GE4XM5$(/Z?XM=#+D!````=@R!^O\'``"Q`G=^B?8Y
M312X_O___WQN@_D&=V?_)(VP]A@(B-"#X#^#R(#!Z@:(0P6!R@````2(T(/@
M/X/(@,'J!HA#!('*```@`(C0@^`_@\B`P>H&B$,#@<H```$`B-"#X#^#R(#!
MZ@:(0P*`S@B(T(/@/X/(@,'J!HA#`8#*P(@3B<A;R<.0@?K__P``L0,/AG;_
M__^!^O__'P"Q!`^&:/___X'Z____`[$%#X9:____A=*Q!KC_____#XE+____
M6\G#58GE5U93BT4(BTT0BUT4BW`4,?^#^P%^,87V=$,/MD$!#[81P>`(`<*#
MP0*#ZP*#QP*!^O_^``!TVH'Z_O\``'4M@_8!@_L!?\^+50BY_O___XER%"GY
M6UZ)R%_)PXGV#[8!P>`(#[91`8T4$.NZC9H`*/__@?O_!P``N?____]VU8M-
M"(M%#(D0B7$4B?F)R%M>7\G#B?95B>6+51"!^O__``"+30QW,X'Z_O\``'0K
MC8(`*/__/?\'``!V'H-]%`&X_O___WX/B=#!Z`B(`8A1`;@"````R<.)]KC_
M____R<.058GE@WT4`5.Z_O___XM=$'XAB@N-02@\![+_=A8/ML'!X`@/MDL!
MBU4,`<B)`KH"````B=!;R<-5B>6+51"!^O__``"+30QW*XV"`"C__SW_!P``
M=AZ#?10!N/[___]^#XG0P>@(B`&(40&X`@```,G#B?:X_____\G#D%6)Y8-]
M%`%3N?[___^+71!^(8I3`8U"*#P'L?]V%0^V"P^VVL'C"`'9BU4,B0JY`@``
M`(G(6\G#58GEBU40@?K__P``BTT,=R>-@@`H__\]_P<``'8:@WT4`;C^____
M?@V($<'J"(A1`;@"````R<.X_____\G#D%6)Y5=64XM%"(M-$(M=%(MP%#'_
M@_L#?D.%]G13#[9!`<'@"`^V$0'"#[9!`L'@$`'"#[9!`\'@&`'"@\$$@^L$
M@\<$@?K__@``=,B!^@``_O]U.H/V`8/[`W^]BUT(N/[___^)<Q0I^%M>7\G#
MB?8/MA$/MD$!P>`0P>(8`<(/MD$"P>`(`<(/MD$#ZZN%TKC_____>-*+30R)
M$8M5"(ER%(GX6UY?R<.-=@!5B>6+51"%THM-#+C_____>">#?10#L/Y^'XG0
MP>@8B`&)T,'H$(A!`8G0P>@(B$$"B%$#N`0```#)PY!5B>6#?10#BTT0N/[_
M__]^*`^V$0^V00'!X!#!XA@!P@^V00+!X`@!P@^V00,!PHM%#(D0N`0```#)
MPY!5B>6#?10#BTT,BU40N/[___]^'XG0P>@8B`&)T,'H$(A!`8G0P>@(B$$"
MB%$#N`0```#)PXUV`%6)Y8-]%`.+31"X_O___WXH#[9!`0^V$<'@"`'"#[9!
M`L'@$`'"#[9!`\'@&`'"BT4,B1"X!````,G#D%6)Y8-]%`.+30R+51"X_O__
M_WX9B!'!Z@B(40'!Z@B(40+!Z@B(40.X!````,G#D%6)Y5=64U:+10B+31"+
M712+<!0Q_^LID`^V00$/MA'!X`@!PH'Z__X``'0+@?K^_P``=22#]@&#P0*#
MZP*#QP*#^P%^*X7V=<\/M@'!X`@/ME$!C100Z\R-@@`H__\]_P,``(E%\'<=
M@_L#?SJ-=@"+50BY_O___XER%"GY6UM>B<A?R<.-@@`D__\]_P,``+G_____
M=N:+30B+70R)$XEQ%(U/`NO6A?9T/@^V60,/ME$"P>,(`=J-F@`D__^!^_\#
M``"Y_____W>RP67P"HM=\(V$$P`D``"+30B+50R)`HEQ%(U/!.N4#[9!`L'@
M"`^V40.-%!#KOXUV`%6)Y5=64XM5$('Z_O\``(MU"(M=#(M-%'1BC8(`*/__
M/?\'``!V58M&*#'_A<!U&X/Y`;C^____?C7&`_[&0P'_@^D"@\,"9K\"`('Z
M__\``'<A2;C^____?A2)T<'I"(@+B%,!C4<"QT8H`0```%M>7\G#@?K__Q``
M=@Q;7KC_____7\G#B?:#^0.X_O___W[=C8(``/__B<'!Z0J!P0#8```E_P,`
M`(G*!0#<``#!Z@B($XG"P>H(B$,#B$L!B%,"QT8H`0```%M>C4<$7\G#C78`
M58GE5U93BW44@_X!BWT,BTT0?D0/M@'!X`@/ME$!C100C9H`*/__@?O_`P``
M=B&-F@`D__^!^_\#``"Y_____W8;B1=;7KD"````B<A?R<.#_@-_#XUV`+G^
M____6UZ)R%_)PP^V00+!X`@/ME$#C100C;(`)/__@?[_`P``N?____]WV,'C
M"HV,$P`D``")#UM>N00```")R%_)PXUV`%6)Y5.+51"-@@`H__\]_P<``(M=
M#(M-%'9N@?K__P``=QI)N/[___]^#XG1P>D(B`N(4P&X`@```%O)PX'Z__\0
M`'=$@_D#N/[___]^ZXV"``#__XG!P>D*@<$`V```)?\#``")R@4`W```P>H(
MB!.)PL'J"(A#`XA+`8A3`K@$````6\G#B?:X_____UO)PU6)Y5=64XMU%(/^
M`8M]#(M-$'Y$#[9!`<'@"`^V$0'"C9H`*/__@?O_`P``=B*-F@`D__^!^_\#
M``"Y_____W8<B1=;7KD"````B<A?R<.0@_X#?P^-=@"Y_O___UM>B<A?R<,/
MME$##[9!`L'B"(T4$(VR`"3__X'^_P,``+G_____=]C!XPJ-C!,`)```B0];
M7KD$````B<A?R<.-=@!5B>53BU40C8(`*/__/?\'``"+70R+311V:H'Z__\`
M`'<:2;C^____?@V($\'J"(A3`;@"````6\G#B?:!^O__$`!W0(/Y`[C^____
M?NF-B@``__^)RL'J"H'A_P,``('"`-@``('!`-P``(@3B$L"P>H(P>D(B%,!
MB$L#N`0```!;R<.X_____UO)PU6)Y5=64XM%"(M-$(M=%(MP%#'_ZSR)]@^V
M00'!X`@/MA$!P@^V00+!X!`!P@^V00/!X!@!PH/'!('Z__X``'0+@?H``/[_
M=46#]@&#P02#ZP2#^P-^)87V=;T/MA$/MD$!P>`0P>(8`<(/MD$"P>`(`<(/
MMD$#Z[N-=@"+10B)<!1;7KC^____*?A?R<.!^O__$`!W((V*`"C__X'Y_P<`
M`'82BUT,B1.+50B)<A1;7HGX7\G#6UZX_____U_)PU6)Y5=64XM=$('[__\0
M`(M]"(M5#(M-%'=RC8,`*/__/?\'``!V98M'*#'VA<!U(X/Y`[C^____?DO&
M`@#&0@$`QD("_L9"`_^#Z02#P@1FO@0`@?O__Q``=S&#^0.X_O___WX@B=B)
MV<'H$,'I"(A"`<8"`(A*`HA:`XU&!,='*`$```!;7E_)PXGV6UZX_____U_)
MPXGV58GE@WT4`XM-$+C^____?CD/MA$/MD$!P>`0P>(8`<(/MD$"P>`(`<(/
MMD$#`<*!^O__$`!W#HV*`"C__X'Y_P<``'<'N/_____)PXM%#(D0R;@$````
MPU6)Y8M5$('Z__\0`(M-#'<WC8(`*/__/?\'``!V*H-]%`.X_O___WX;B=#!
MZ!"(00&)T,'H"(A!`L8!`(A1`[@$````R<.)]KC_____R<.058GE@WT4`XM-
M$+C^____?CD/MD$!P>`(#[81`<(/MD$"P>`0`<(/MD$#P>`8`<*!^O__$`!W
M#HV*`"C__X'Y_P<``'<'N/_____)PXM%#(D0R;@$````PU6)Y8M5$('Z__\0
M`(M-#'<SC8(`*/__/?\'``!V)H-]%`.X_O___WX7B!'!Z@B(40'!Z@B(40+&
M00,`N`0```#)PXGVN/_____)PY!5B>575E.#[!R+50B+0A2H`XMU$(E%\,=%
M[`````!U?(M][$<[?10/CSL!``"*%H32>"&(T,#H`P^VV`^V@Z#V&`@/MMJ)
MV8/A!]/XJ`$/A<$!``"`^BN[_____P^%%P$``(M%[(/``CM%%`^/]P```(!^
M`2UU&8M=\(MU#(M]",<&*P```(E?%(G#Z>D```!&B7WLQT7P`0```)`Q_XM-
M\,=%Z`(```#'1>0`````QT7@`````.M##[;"C5B_B<B#X`-&_T7@@_@!=%@/
M@K(```"#^`(/A`$!``"#^`,/A!H!``"+1>@Y1>1T2(M5[(M=X(U$&@$Y111R
M;8H6C4*_/!EVM(U:GX#[&0^'F`````^VPHU8N8G(@^`#1O]%X(/X`76HBT7H
M.47DC0R=`````'6YD(/X`@^%\@```(V?`"C__X'[_P,```^'X````(M5[(M=
MX(U$&@$Y113'1>@$````<Y:-=@"+3?"+?0B[_O___XE/%"M=[(/$'(G86UY?
MR<.0@^'\P><("<^)V8G:@^$/P>H$P>$$"=?_1>2#R0+I/O___XGVC5K0@/L)
M=PP/ML*-6`3I`____Y"`^BN[/@````^$]/[__X#Z+P^%Q````+,_Z>3^__^)
M]H/A_,'G"`G/B=F)V(/A`\'H`L'A!@G'_T7D@\D#Z>;^__^#X?S!YP@)SPG?
M_T7DN0$```#IS_[__XMU"(M-#(M5\(D9B584B?N#Q!R)V%M>7\G#]L$##X2/
M````@WWH!'06BU4,B3J+7>R+10@#7>")2!3I)?___XGXP>@0B?Z-D``H__^!
MYO__``"!^O\#``!W6(V^`"3__X'__P,``+O_____#X?S_O__P>(*C9PR`"0`
M`(MU#(D>ZZR#X?R[_____P^%U/[__XM-X(7)#X7)_O__@/HM=`S'1?``````
MZ5_]__]&_T7LZ^[H^!K__U6)Y5=64X/L'(M%"(M8*(M]$/;#`XMU#(E]\,=%
M[`````!U7H/_?W8DQ@8K1H/_*W5$@WT4`;C^____?@C&!BVX`@```(/$'%M>
M7\G#B?K!Z@.)^8/A!P^V@I#V&`C3^*@!=,6*7?"('H/$'%M>N`$```!?R</'
M1>P!````NP$```"#_W\/A]T```")^L'J`XGY@^$'#[:"D/88"-/XJ`$/A,(`
M```/MH*`]A@(T_BH`<=%Z`````!T!\=%Z`$```")V(/@`XM-Z(M5[(U,$0*#
M^`&)3>1W"HM-Z(U$$0&)1>2+5>0Y512X_O___P^,4O___XG8@^`#@_@!=C*)
MV(/@_(/X&8U0078B@_@SC5!'=AJ#^#V-4/QV$H/X/K(K=`N#^#^R+P^%X`$`
M`(@61H/_?W<;B?O!ZP.)^8/A!P^V@X#V&`C3^*@!=`3&!BU&B?J(%HMU",=&
M*`````"+1>2#Q!Q;7E_)PX'___\```^'R0```(G8@^`#@_@!OP(````/A@<!
M``"+5>R#P@.)5>"+5>`Y512X_O___P^,I/[__XUV`(G8@^`#@_@!#X0&`0``
M#X+P````@_@"#X0?`0``@_@##X5"`0``3XT,_0````"+5?#3Z@^VPHC9@^'\
MP>@&@^(_"<&-')4`````B?:`^1F-04%V)(#Y,XU!1W8<@/D]C4'\=A2`^3ZP
M*W0-@/D_#X7T````L"^)]H@&1O;#`W2`A?\/A7C___^+=0B)7BB+1>"#Q!Q;
M7E_)PX'___\0`+C_____#X?W_?__C8<``/__B<?![PJ!QP#8```E_P,``(G:
M!0#<``#!YQ"#X@,)QX/Z`HE]\+\$````=AR+3>R#P0:)3>#I`O___XM-[(/!
M`HE-X.GT_O__BU7L@\(%Z>;^__^0B=G!Z0*[`0```.DY____D$^-#/T`````
MBU7PT^H/MMJ)V8G3@^,#P>,$P>D"@\L"Z1/___^-=@!/C0S]`````(M5\-/J
M#[;"B-F#X@^#X?S!Z`2-')4`````"<&#RP/IY/[__^CG%___C78`58GE5E.+
M10B+4"B)T3'`@^$#BUT,=$V#^0(9P(UP`CEU$+C^____<CN#^0%V,8/B_(/Z
M&8U*078C@_HSC4I'=AN#^CV-2OQV$X/Z/K$K=`R#^C^Q+W0%Z(@7__^("T/&
M`RV)\%M>R<-5B>6#?10!N?[___]^(8M%$&:+$(V"`"@``&8]_P>Q_W8-BTT,
M#[?2B1&Y`@```(G(R<.058GEBU40@?K__P``=R:-@@`H__\]_P<``'89@WT4
M`;C^____?@N+30QFB1&X`@```,G#D+C_____R<.058GE@WT4`;G^____?BR+
M51`/MP*)PF;!Z@C!X`@)PHV"`"@``&8]_P>Q_W8-BTT,#[?"B0&Y`@```(G(
MR<.)]E6)Y8M5$('Z__\``'<VC8(`*/__/?\'``!V*8-]%`&X_O___WX9B=$/
MM\'!X`AFP>H("<*+30QFB1&X`@```,G#C78`N/_____)PY!5B>6#?10#N/[_
M__]^#XM-$(M%#(L1B1"X!````,G#D%6)Y8-]%`.X_O___WX-BT4,BU40B1"X
M!````,G#C78`58GE@WT4`[C^____?C&+51"+"HG(B<K!Z`@E`/\``,'J&`G"
MB<@E`/\``,'@"`G"P>$8BT4,"<J)$+@$````R<.-=@!5B>6#?10#BTT0N/[_
M__]^+(G(B<K!Z`@E`/\``,'J&`G"B<@E`/\``,'@"`G"P>$8BT4,"<J)$+@$
M````R<.058GE5U9348M]$(H'/)\/APX!```\7'04#[;`BU4,B0*X`0```%I;
M7E_)PY"#?10!N/[___]^[HI'`3QU=&$\50^%S@```#'VNQP```#'1?`"````
MZQ^)]HU"R9"(V0^VT-/B_T7P"=:#ZP2#??`)#X^W````BU7P.544#XX#`0``
MBA07C4+0/`EVT8U*OX#Y&7;%C4*?/!EW>HU"J>N],?;'1?`"````NPP```"-
M=@"+3?`Y310/CL@```"*%`^-0M`\"782C4J_@/D9#X>`````C4+)C78`B-D/
MMM#3XO]%\`G6@^L$@WWP!7[#@?Z?````=WR#_B1T"H/^0'0%@_Y@=1Z+?0RX
M!@```(DWZ1+___^0BW4,QP9<````Z?[^__^X_____^GY_O__@?Z?````=RV#
M_B1T"H/^0'0%@_Y@==^+?0RX"@```(DWZ=/^__^-0I\\&7>[C4*IZ7?___^-
MG@`H__^!^_\'``!WU.O#C9X`*/__@?O_!P``=X7I<?___[C^____Z9?^__^)
M]E6)Y5=64XMU$('^GP```(M5#'<0B?"(`K@!````6UY?R<.)]H'^__\``'9+
MOPH```"Q53E]%+C^____?.#&`ER(2@&-6@*)^H/J`W@CC78`C0R5`````(GP
MT^B#X`^#^`F)V8U;`7<8@\`PB`%*>>!;7HGX7\G#OP8```"Q=>NS@\!72H@!
MZ^95B>575E.#[`B+?1"*!SQ<=!8/ML"+50R)`K@!````@\0(6UY?R<.0@WT4
M`;C^____?NR`?P%U=`N+70S'`UP```#KUC'VQT7L`@```+L,````B?:+3>PY
M310/C@,!``"*%`^-0M`\"782C4J_@/D9#X?:````C4+)C78`B-D/MM#3XO]%
M[`G6@^L$@WWL!7[#C9X`*/__@?O_!P``#X?:````@?[_VP``=XZ#?10&N/[_
M__\/CF7___^`?P9<#X5U____@WT4!P^.4?___X!_!W4/A6'____'1?``````
MQT7L"````+X,````BU7L.544?G"*%!>-0M`\"78+C4J_@/D9=VB-0LF)\0^V
MT-/B_T7L"57P@^X$@WWL"W[-BW7P@>X`W```@?[_`P``#X<&____P>,*BU7P
MC803`"0``(M]#(D'N`P```#IT/[__Y"-0I\\&0^'WO[__XU"J>D9____N/[_
M___ILO[__XU"GSP9#X?!_O__C4*IZXN+70RX!@```(DSZ9/^__]5B>53BTT0
M@_E_BUT,BU44=PJ("[@!````6\G#@?G__P``#X;T````@?G__Q``N/____]W
MY(/Z"[#^?MV-@0``__^)PL'J"H'"`-@``(G1P>D,)?\#``"#X0\%`-P``(/Y
M"<8#7,9#`74/AUD!``"#P3"(2P*)T<'I"(/A#X/Y"0^'.@$``(/!,(A+`XG1
MP>D$@^$/@_D)#X<;`0``@\$P@^(/@_H)B$L$#X<!`0``@\(PB%,%B<+!Z@R#
MX@^#^@G&0P9<QD,'=0^'V@```(/",(A3"(G"P>H(@^(/@_H)#X>[````@\(P
MB%,)B<+!Z@2#X@^#^@D/AYP```"#PC"#X`^#^`F(4PH/AX(```"#P#"(0PM;
MN`P```#)PX/Z!;C^____#X[O_O__B<K!Z@R#X@^#^@G&`US&0P%UC4(P=@.-
M0E>)RL'J"(/B#X/Z"8A#`HU",'8#C4)7B<K!Z@2#X@^#^@F(0P.-0C!V`XU"
M5XA#!(G(@^`/@_@)=PZ#P#"(0P5;N`8```#)PX/`5^OP@\!7Z7G___^#PE?I
M7____X/"5^E`____@\)7Z2'___^#PE?I^O[__X/!5^G@_O__@\%7Z<'^__^#
MP5?IHO[__U6)Y8M-$(M%#`^V$8D0R;@!````PXUV`%6)Y8M5$('Z_P```+C_
M____=PJ+10R($+@!````R<.058GEBT40B@`\GXM5#'<-#[;`B0+)N`$```##
MD`^VR`^WA`F`]!@(B0+)N`$```##58GEBU40@?J?````BTT,=PN($;@!````
MR<.)]HV"8/___SW?````=Q.*@D#T&`B$P'0=B`&X`0```.O<C8)`_?__@_@?
M=PF*@@#R&`CKX)"X_____\G#D%6)Y8M%$(H`/)^+30QW#0^VP(D!N`$```#)
MPY`/ML!FBY0`P/(8"&:#^OVX_____W3G#[?"Z]N058GEBU40@?J?````BTT,
M=PN($;@!````R<.)]HV"8/___X/X7W<5BH(`\Q@(A,!T,X@!N`$```#KWHGV
MC8+X_O__@_AW=A6-@BC]__^#^`=W$HJ"*/`8".O3B?:*@ACR&`CKR;C_____
MR<.058GEBT40B@`\GXM5#'<-#[;`B0+)N`$```##D`^VR`^WA`D`\1@(B0+)
MN`$```##58GEBU40@?J?````BTT,=PN($;@!````R<.)]HV"8/___SW?````
M=Q.*@L#P&`B$P'0=B`&X`0```.O<C8)`_?__@_@?=PF*@H#N&`CKX)"X____
M_\G#D%6)Y8M%$(H`/)^+50QW#0^VP(D"R;@!````PY`/ML@/MX0)0.\8"(D"
MR;@!````PU6)Y8M5$('ZGP```(M-#'<+B!&X`0```,G#B?:-@F#___^#^`]W
M%8J"P.\8"(3`="F(`;@!````Z]Z)]HV"`/S__X/X7W<)BH(`[!@(Z]Z0@?H6
M(0``L/!TU[C_____R<.-=@!5B>6+11"*`#R?BTT,=PT/ML")`;@!````R<.0
M#[;`9HN4``#N&`AF@_K]N/____]TYP^WPNO;D%6)Y8M5$('ZGP```(M-#'<+
MB!&X`0```,G#B?:-@F#___^#^`]W%8J"D.X8"(3`=!^(`;@!````Z]Z)]HV"
M^/G__X/X3W<)BH+8Z!@(Z]Z0N/_____)PY!5B>6+11"*`#R?BTT,=PT/ML")
M`;@!````R<.0#[;`9HN4`.#L&`AF@_K]N/____]TYP^WPNO;D%6)Y8M5$('Z
MGP```(M-#'<+B!&X`0```,G#B?:-@F#___^#^!]W%8J"8.T8"(3`=#.(`;@!
M````Z]Z)]HV"@/S__X/X3W85C8+PW___@_@/=Q**@G#-&`CKTXGVBH(@ZA@(
MZ\FX_____\G#D%6)Y8M%$(H`/)^+30QV)0^VP&:+E`"`ZQ@(9H/Z_;C_____
M=`H/M\*)`;@!````R<.-=@`/ML")`<FX`0```,-5B>6+51"!^I\```"+30QW
M"X@1N`$```#)PXGVC8)@____@_A7=Q6*@L#K&`B$P'0SB`&X`0```.O>B?:-
M@C#Z__^#^!]V%8V"^-___X/X#W<2BH(8S!@(Z].)]HJ"<.88".O)N/_____)
MPY!5B>6+11"*`#S/BU4,=A4/ML@/MX0)(.H8"(D"R;@!````PY`/ML")`LFX
M`0```,-5B>6+51"!^L\```"+30QW"X@1N`$```#)PXGVC8(P____@_@O=Q6*
M@K#J&`B$P'0?B`&X`0```.O>B?:-@NC^__^#^$=W"8J"".H8".O>D+C_____
MR<.058GEBT40B@`\GXM5#'<-#[;`B0+)N`$```##D`^VR`^WA`D@Z1@(B0+)
MN`$```##58GEBU40@?J?````BTT,=PN($;@!````R<.)]HV"8/___SW?````
M=Q.*@N#H&`B$P'03B`&X`0```.O<@?H5(```L+UT[;C_____R<.-=@!5B>6+
M11"*`#R?BU4,=PT/ML")`LFX`0```,.0#[;(#[>$"8#G&`B)`LFX`0```,-5
MB>6+51"!^I\```"+30QW"X@1N`$```#)PXGVC8)@____/=\```!W$XJ"0.<8
M"(3`=!V(`;@!````Z]R-@NC?__^#^`=W"8J"J,<8".O@D+C_____R<.058GE
MBT40B@`\GXM5#'85#[;(#[>$"<#E&`B)`LFX`0```,.0#[;`B0+)N`$```##
M58GEBU40@?J?````BTT,=PN($;@!````R<.)]HV"8/___X/X7W<5BH(`YA@(
MA,!T6X@!N`$```#KWHGVC8+X_O__@_@?=A6-@I#^__^#^`]W$HJ"^.08".O3
MB?:*@GCE&`CKR8V"`.+__SV'````=A.-@A#A__^#^`=W$(J"T,88".NIBH+@
MQQ@(ZZ&X_____\G#D%6)Y8M%$(H0C4)@/!^+30QW%@^VP@^WA`!`Y!@(B0')
MN`$```##B?8/ML*)`<FX`0```,-5B>53BU40@?J?````BUT,=PJ($[@!````
M6\G#C8)@____@_@?=Q6*BL#D&`B$R70UN`$```"("^O?B?:-@D#___^#^#^(
MT7;DC8JP_O__@_DO=PB*BM#C&`CKT8'ZK"```+&D=,NX_____UO)PXGV58GE
MBT40B@`\GXM5#'<-#[;`B0+)N`$```##D`^VR`^WA`D@XQ@(B0+)N`$```##
M58GEBU40@?J?````BTT,=PN($;@!````R<.)]HV"8/___SW?````=Q.*@N#B
M&`B$P'0[B`&X`0```.O<C8+H_?__@_@'=A6-@NC?__^#^`=W$HJ"2,,8".O5
MB?:*@E#A&`CKRX'ZK"```+"D=,6X_____\G#C78`58GEBT40B@"$P(M5#'@-
M#[;`B0+)N`$```##D`^VR`^WA`E@X1@(B0+)N`$```##58GEBU40@_I_BTT,
M=PJ($;@!````R<.0C8)@____@_A7=Q6*@F#A&`B$P'1;B`&X`0```.O?B?:-
M@@#\__^#^%=V%8V"Z-W__X/X3W<2BH(HOQ@(Z].)]HJ"H-T8".O)C8+@W/__
M@_@'=A6-@@#;__\]IP```'<0BH*`NQ@(ZZF*@@B^&`CKH;C_____R<.058GE
MBT40B@"$P(M5#'@-#[;`B0+)N`$```##D`^VR`^WA`F`WA@(B0+)N`$```##
M58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A7=Q6*@H#>&`B$P'1;
MB`&X`0```.O?B?:-@@#\__\]EP```'83C8+HW?__@_A/=Q"*@@B\&`CKT8J"
M@-H8".O)C8+@W/__@_@'=A6-@@#;__\]IP```'<0BH)@N!@(ZZF*@NBZ&`CK
MH;C_____R<.058GEBT40B@"$P(M5#'@-#[;`B0+)N`$```##D`^VR`^WA`E@
MVQ@(B0+)N`$```##58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A7
M=Q6*@F#;&`B$P'1;B`&X`0```.O?B?:-@@#\__\]EP```'83C8+HW?__@_A/
M=Q"*@NBX&`CKT8J"8-<8".O)C8+@W/__@_@'=A6-@@#;__\]IP```'<0BH)`
MM1@(ZZF*@LBW&`CKH;C_____R<.058GEBT40B@"$P(M-#'@-#[;`B0&X`0``
M`,G#D`^VP&:+E`!`V!@(9H/Z_;C_____=.</M\+KVY!5B>6+51"#^G^+30QW
M"H@1N`$```#)PY"-@F#___\]WP```'<3BH+`UQ@(A,!T18@!N`$```#KW8V"
M0/W__X/X'W85C8+PW___@_@O=Q**@O"W&`CKU8GVBH*`U1@(Z\N!^JP@``"P
M@'3%@?HB(0``L)ETN[C_____R<.058GEBT40B@"$P(M-#'@-#[;`B0&X`0``
M`,G#D`^VP&:+E```UA@(9H/Z_;C_____=.</M\+KVY!5B>6+51"#^G^+30QW
M"H@1N`$```#)PY"-@F#___^#^!]W%8J"0-88"(3`=%&(`;@!````Z]^)]HV"
M`/S__SV7````=A.-@O#?__^#^"]W$(J"\+48".O1BH)`TA@(Z\F!^JP@``"P
MB'3#@?H6(0``L+ETN8'Z(B$``+"9=*^X_____\G#C78`58GEBT40BA"-0H`\
M'XM-#'8.#[;"B0&X`0```,G#B?8/ML)FBY0`P-08"&:#^OVX_____W3F#[?"
MZ]J058GE4XM-$(/Y?XM=#'<-B`NX`0```%O)PXUV`(V!8/___X/X7XC*=A^-
MD;#^__^#^D=V)(V!0/W__X/X'W<EBI&`TA@(C78`A-)T-[@!````B!/KP8UV
M`(J1$-08"(32=>KK'XV1\-___X/Z+W8<@?FL(```LH!TTX'Y(B$``+*9=,FX
M_____UO)PXJ1\+08".NUD%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/
MML!FBY0``-,8"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!
M````R<.0C8)@____@_@?=Q6*@D#3&`B$P'1'B`&X`0```.O?B?:!^I(!``"P
M@W3KC8*`_/__@_A/=PB*@@#0&`CKU(V"\-___X/X+W8;@?JL(```L(!TPX'Z
M(B$``+"9=+FX_____\G#BH(PLQ@(ZZ:058GEBT40B@"$P(M-#'@-#[;`B0&X
M`0```,G#D#R?=QP/ML!FBY0``-(8"&:#^OVX_____W3C#[?"Z]>0/,]VSSS?
M=A$\[W;'#[;`#[>$`.#0&`CKO0^VT`^WA!)`T1@(Z[")]E6)Y5.+31"#^7^+
M70QW#8@+N`$```!;R<.-=@"-@6#___^#^"^(RG8?C9$P____@_HO=B2-@>C^
M__^#^']W)8J1Z-`8"(UV`(32=%*X`0```(@3Z\&-=@"*D;#1&`B$TG7JZSJ-
MD4#]__^#^A]V$XV!\-___X/X+W<0BI&0L1@(Z\:*D2#/&`CKOH'YK"```+*`
M=+B!^2(A``"RF72NN/____];R<.)]E6)Y8M-"(M1%#'`A=)T$8M%#,=!%```
M``")$+@!````R<.)]E6)Y5=64XM%$(H`A,"+=0B+?0QF#[;0>&]FBUX49H7;
M="*-@E#Z__]F@_@4=T8/M\(MM`4``(/X#G<Y_R2%S/88"(GVC8HP^O__9H/Y
M(@^&'P$```^W\HDW6UZX`0```%_)PV8Y'(W`SQ@(B<@/A(<```"0#[?3QT84
M`````(D76UXQP%_)PY`/MLAFBY0)H,\8"&:#^OVX_____P^%=____UM>7\G#
MN`<```"+%,5DT!@(BP3%8-`8"`'09CD<E<#/&`B-2/]WJV8Y'(W`SQ@(<J&0
MC00*T>AF.1R%P,\8"'07=G\YPG2+B<&-!`K1Z&8Y'(7`SQ@(=>EFBQ2%PL\8
M"(V:U@0``&:#^P%V96:!^DG[=%['1A0`````Z3/___^X!@```.N$N`4```#I
M>O___[@"````Z7#___^X`0```.EF____,<#I7____[@$````Z57___^X`P``
M`.E+____C78`.<(/A/?^__^)PNEA____#[?ZB7X46UZX_?___U_)PY!5B>57
M5E.+71"#^W^+?0QW#X@?N0$```!;7HG(7\G#D(V#8/___X/X5P^'O0```(J#
MP,X8"(3`#X7S````#[<%@,T8"#').=B^(0````^'Y`````^W%8C.&`@YV@^"
MU0```(GVC10QT>H/MP35@,T8"#G8="$/ALD````YT0^$M````(G6C10QT>H/
MMP35@,T8"#G8==\/MQS5@LT8"(J#,,D8"(H<U87-&`B$VP^(Y````(-]%`*Y
M_O___P^.5O___X@'#[X$U83-&`B*B&#-&`@/OO.(3P&*EF#-&`BY`P```(A7
M`NDM____D('[D@$``+"#=#J-DT#]__^#^A]W3HJ#@,P8".DI____@?NJ(```
ML*1T&H'[K"```+"`=!"!^R(A``"PF0^%#____XGVB`?IW/[__UM>N?____^)
MR%_)PY`YT70SB='I%?___XV+4/K__X/Y1W86C;/XW___@_XW=Z>*@YBN&`CI
MQ?[__XJ#,,D8".FZ_O__B?(/MS3U@,T8"#G>N?____\/A`3____I@?[__X-]
M%`&Y_O___P^.<O[__X@'#[X$U83-&`B*B&#-&`B(3P&Y`@```.E5_O__D%6)
MY8M%$(H`A,"+50QX#0^VP(D"R;@!````PY`/ML@/MX0)8,L8"(D"R;@!````
MPU6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X7W<5BH)@RQ@(A,!T
M9X@!N`$```#KWXGVC8*P_O__@_A'=BV!^L8"``"PB'3@C8+X^?__/<\```!V
M'HV"^-___X/X-W<;BH)XJA@(Z[R-=@"*@E#*&`CKL8J"N,08".NI@?JL(```
ML(!THX'Z(B$``+"9=)FX_____\G#D%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$`
M``#)PY`/ML!FBY0`@,@8"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_BTT,
M=PJ($;@!````R<.0C8)@____/=\```!W$XJ"`,@8"(3`=$6(`;@!````Z]V-
M@D#]__^#^!]V%8V"\-___X/X+W<2BH(PJ!@(Z]6)]HJ"P,48".O+@?JL(```
ML(!TQ8'Z(B$``+"9=+NX_____\G#D%6)Y5=64X/L#(M%$(H`A,"+=0B+?0QF
M#[;0>'1FBUX49H7;=2.-6K]F@?MO`0^&#0$```^WPHD'N`$```"#Q`Q;7E_)
MPXUV`(V"`/W__V:#^#]W)`^WPBT``P``@_@C=TO_)(4(]Q@(9CD<A:"/&`B)
MP@^$B@````^WT\=&%`````")%X/$#%M>,<!?R<.)]@^VR&:+E`E`QA@(9H/Z
M_;C_____#X5R____ZY'H7_S^_S'`D(L,Q<22&`B+!,7`DA@(`<A(9CD<C:"/
M&`AWJ68Y'(6@CQ@(<I^-=@"-%`'1ZF8Y')6@CQ@(=!=V1SG1=(>)T(T4`='J
M9CD<E:"/&`AUZ0^W!)6BCQ@(QT84`````.D@____N`$```#KE[@"````ZY"X
M`P```.N)N`0```#K@HGV.=$/A"S___^)T>N<#[?ZN/W___^)?A3I[?[__U6)
MY5=64XM=$(/[?XM]#'</B!^Y`0```%M>B<A?R<.0C8-@____@_@?B-IV)XV3
M0/___X/Z5P^&^P```(V+L/[__X/Y9P^'%`$``(J3$,48"(UV`(32#X74````
M#[<%H(H8"#').=B^R`````^'U0````^W%<"-&`@YV@^"Q@```(UV`(T4,='J
M#[<$E:"*&`@YV'0A#X:Y````.=$/A*0```")UHT4,='J#[<$E:"*&`@YV'7?
M#[<$E:**&`@E_P\``#W_````B,-V$3T7`0``#X?0````BI@@QA@(@WT4`;G^
M____#XXL____B@25HXH8",#X!`^^R(@?BIF@Q1@(N0(```"(7P'I"O___X'[
MJR```++^=!B!^ZP@``"R@'0.@?LB(0``LID/A2S___^(%^G<_O__BI,@QA@(
MA-(/A!?____KZ5M>N?____^)R%_)PY`YT70SB='I)?___XVS0/W__X/^'W86
MC8,`_?__@_@G=SV*DP##&`CIU/[__XJ3@,,8".G)_O__B?(/MS2UH(H8"#G>
MN?____\/A!3____I<?[__XJ8$,48".DK____C9/`_/__@_H!=PN*D\#"&`CI
MC/[__XV+\-___X/Y+P^'-____XJ3L*48".ER_O__B?95B>6+11"*`(3`BU4,
M>`T/ML")`LFX`0```,.0#[;(#[>$"6!F#@B)`LFX`0```,-5B>6+51"#^G^+
M30QW"H@1N`$```#)PY"-@F#___^#^%]W%8J"8&8."(3`=#Z(`;@!````Z]^)
M]H'Z,0$``+#5=.N!^I(!``"PGW3A@?H7(```L/)TUXV"`-O__SVG````=PB*
M@D!!#@CKOKC_____R<.)]E6)Y8M%$(H`A,"+50QX#0^VP(D"R;@!````PY`/
MML@/MX0)H,,8"(D"R;@!````PU6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"
M8/___X/X7W<5BH*@PQ@(A,!T7X@!N`$```#KWXGV@?J2`0``L)]TZXV"</S_
M_X/X-W<(BH)PP!@(Z]2-@C#Z__^#^!IV)X'Z?R```+#\=,.!^J<@``"PGG2Y
MC8+HW?__@_A/=Q2*@HBA&`CKHHU"L.N=N/_____)PX'Z$",``+"I=)"-@N#<
M__^#^`%W"(U"U.EY____C8(`V___/:<```!WSXJ"X)T8".EA____58GEBT40
MB@"$P(M5#'@-#[;`B0+)N`$```##D#RO=Q0/ML`%D`,``(D"R;@!````PXUV
M``^VR`^WA`G@P!@(B0+)N`$```##58GEBU40@_I_BTT,=PJ($;@!````R<.0
MC8)@____@_@7=Q6*@H#!&`B$P'13B`&X`0```.O?B?:-@@#\__^#^%]V+8'Z
M%B$``+#\=."-@NC=__^#^`=V((V"`-O__SVG````=QN*@@"<&`CKO(UV`(J"
MP+T8".NQBH*0GQ@(ZZFX_____\G#D%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$`
M``#)PY`/ML!FBY0``+\8"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_BTT,
M=PJ($;@!````R<.0C8)@____@_A?=Q6*@@"_&`B$P'10B`&X`0```.O?B?:-
M@M#^__^#^&=V%8V"0/W__X/X'W<2BH)`O!@(Z].)]HJ"\+T8".O)@?K``P``
ML+ETPXV"\-___X/X-W</BH*PGA@(ZZRX_____\G#C8+@WO__@_@'=PB*@HB=
M&`CKDHV"`-[__X/X9W<+BH)`G!@(Z7S___^!^LHE``"PUP^$<O___XV"``7_
M_X/X!W>WBH(@PQ<(Z5C___^-=@!5B>6+11"*`(3`BU4,>`T/ML")`LFX`0``
M`,.0#[;(#[>$"2"\&`B)`LFX`0```,-5B>6+51"#^G^+30QW"H@1N`$```#)
MPY"-@F#___\]WP```'<3BH*@NQ@(A,!T8(@!N`$```#KW8'ZQP(``+#_=.V-
M@O#?__^#^"]W"(J"\)L8".O6@?HB(0``L*ITT(V"`-[__X/X'W83C8*@W?__
M@_@'=Q"*@F"9&`CKKHJ"X)D8".NF@?K*)0``L-=TH+C_____R<.)]E6)Y8M%
M$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`P+D8"&:#^OVX_____W3G
M#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A?=Q6*@L"Y
M&`B$P'1:B`&X`0```.O?B?:-@M#^__^#^&=V%8V"0/W__X/X'W<2BH(`MQ@(
MZ].)]HJ"L+@8".O)@?K``P``L+ETPXV"\-___X/X-W<9BH)PF1@(ZZR!^LHE
M``"PUW2FN/_____)PXV"X-[__X/X!W<(BH)(F!@(ZXB-@@#>__^#^&=WT8J"
M`)<8".ER____D%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`
M`+<8"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0
MC8)@____/?<```!W$XJ"8+88"(3`=%>(`;@!````Z]V-@D#]__^#^!]V*8'Z
MP`,``+#Y=.*-@O#?__^#^#=V'(V"X-[__X/X!W<JBH)HE1@(Z\"0BH(@M!@(
MZ[>*@I"6&`CKKX'ZRB4``+#7=*FX_____\G#C8(`WO__@_AG=^2*@B"4&`CK
MBU6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`(+08"&:#^OVX
M_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____/?<`
M``!W$XJ"@+,8"(3`=%>(`;@!````Z]V-@D#]__^#^!]V*8'ZP`,``+"Y=.*-
M@O#?__^#^#=V'(V"X-[__X/X!W<JBH*(DA@(Z\"0BH)`L1@(Z[>*@K"3&`CK
MKX'ZRB4``+#7=*FX_____\G#C8(`WO__@_AG=^2*@D"1&`CKBU6)Y8M%$(H`
MA,"+50QX#0^VP(D"R;@!````PY`/ML@/MX0)0+$8"(D"R;@!````PU6)Y8M5
M$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X'W<5BH*`L1@(A,!T6(@!N`$`
M``#KWXGV@?KW````L-9TZX'ZD@$``+#$=.&-@@#\__^#^%]W"(J"P*T8".O*
MC8+PW___@_@7=A.-@O#>__^#^!=W%XJ">)`8".NLBH*0D1@(ZZ2X_____\G#
MC8(`WO__@_AG=^Z*@B"/&`CKBI!5B>6+11"*`(3`BU4,>`T/ML")`LFX`0``
M`,.0#[;(#[>$"2"O&`B)`LFX`0```,-5B>6+51"#^G^+30QW"H@1N`$```#)
MPY"-@F#___^#^!]W%8J"8*\8"(3`=%J(`;@!````Z]^)]H'Z]P```+#6=.N!
M^I(!``"PQ'3AC8(`_/__/9<```!W"(J"8*L8".O(C8+PW___@_@7=A.-@O#>
M__^#^!=W%XJ"&(X8".NJBH(PCQ@(ZZ*X_____\G#C8(`WO__@_AG=^Z*@L",
M&`CKB(UV`%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`P*P8
M"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@
M____@_A?=Q6*@L"L&`B$P'18B`&X`0```.O?B?:!^E,!``"PSW3KC8*`_/__
M@_A/=PB*@H"I&`CKU(V"\-___X/X)W8=@?HB(0``L)-TPXV"N-W__X/X'W<0
MBH)8BA@(ZZR*@K",&`CKI+C_____R<-5B>6+11"*`(3`BTT,>`T/ML")`;@!
M````R<.0#[;`9HN4`*"J&`AF@_K]N/____]TYP^WPNO;D%6)Y8M5$(/Z?XM-
M#'<*B!&X`0```,G#D(V"8/___X/X7W<5BH*@JA@(A,!T6H@!N`$```#KWXGV
MC8+H_O__@_A_=A6-@D#]__^#^!]W$HJ"X*<8".O3B?:*@JBI&`CKR8'ZP`,`
M`+"Y=,.-@O#?__^#^"=W&8J"4(H8".NL@?K*)0``L-=TIKC_____R<.-@N#>
M__^#^`=W"(J"*(D8".N(C8(`WO__@_AG=]&*@N"'&`CI<O___Y!5B>6+11"*
M`(3`BTT,>`T/ML")`;@!````R<.0#[;`9HN4`."G&`AF@_K]N/____]TYP^W
MPNO;D%6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X7W<5BH+@IQ@(
MA,!T4(@!N`$```#KWXGVC8)0^O__@_@_=A6-@O#?__^#^!=W$HJ""(@8".O3
MB?:*@I"B&`CKR8'ZJB```+"F=,.-@N@$__^#^#=W"(J"R*P7".NLN/_____)
MPU6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`X*48"&:#^OVX
M_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A?
M=Q6*@N"E&`B$P'0MB`&X`0```.O?B?:-@OCY__\]SP```'<+BH*8GQ@(Z]R-
M=@"!^B8@``"PDW33N/_____)PXUV`%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$`
M``#)PY`/ML!FBY0`H*,8"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_BTT,
M=PJ($;@!````R<.0C8)@____@_@?=Q6*@N"C&`B$P'1:B`&X`0```.O?B?:-
M@@#R__^#^%]V%8V"^-___X/X'W<2BH+X@Q@(Z].)]HJ"()88".O)@?HB(0``
ML.YTPXV"@`?__X/X'W<(BH)@JQ<(ZZR!^O_^``"PVW2FN/_____)PXGV58GE
MBT40B@`\GXM-#'<-#[;`B0&X`0```,G#D`^VP&:+E`#@H1@(9H/Z_;C_____
M=.</M\+KVY!5B>6+51"!^I\```"+30QW"X@1N`$```#)PXGVC8)@____@_A?
M=Q6*@B"B&`B$P'11B`&X`0```.O>B?:-@J#^__^#^#=V%8V"0/W__X/X'W<2
MBH*@GQ@(Z].)]HJ"(*$8".O)@?H4(```L/9TPX'ZI"```+"O=+F!^J`E``"P
M_'2ON/_____)PXUV`%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!F
MBY0`8*`8"&:#^OVX_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````
MR<.0C8)@____@_A?=Q6*@F"@&`B$P'19B`&X`0```.O?B?:-@M#^__^#^&=V
M%8V"0/W__X/X'W<2BH*@G1@(Z].)]HJ"4)\8".O)C8+PW___@_@W=A.-@@`%
M__^#^`=W$(J"`*47".NKBH(0@!@(ZZ.X_____\G#C78`58GEBT40B@`\GXM-
M#'<-#[;`B0&X`0```,G#D`^VP&:+E```GA@(9H/Z_;C_____=.</M\+KVY!5
MB>53BU40@_HGBUT,=PV($[@!````6\G#C78`C4+8@_@'=Q2*BOB>&`B$R71-
MN`$```"("^O?D(U"T(/X;XC1=NB-BF#___^#^1]W"(J*8)X8".O5C8+0^O__
M@_A?=A.-BO#?__^#^1=W$(J*<'X8".NWBHIPF1@(ZZ^X_____UO)PY!5B>6+
M11"*$(U"@#P?BTT,=Q8/ML(/MX0`0)T8"(D!R;@!````PXGVC4)`/"9W$0^V
MP@40$```B0')N`$```###[;"B0')N`$```##58GEBU40@_I_BTT,=PJ($;@!
M````R<.0C4*`@_@?=Q2*@J"=&`B$P'14B`&X`0```.OBD(V"8/___X/X'W8I
MC8(9____@_@8=AZ-@K#^__^#^$=V%XV"0/W__X/X'W<EBH+@FA@(Z[Z(T.NZ
MBH)PG!@(Z[*!^B(A``"PF72LN/_____)PXV",.___X/X)G<%C4+PZY&-@O#?
M__^#^"]WU(J"4'T8".E[____D%6)Y8M%$(H0C4*`/!^+30QW%@^VP@^WA``@
MG!@(B0')N`$```##B?:-0D`\)7<5#[;"#[>$`$";&`B)`<FX`0```,.0#[;"
MB0')N`$```##58GEBU40@_I_BTT,=PJ($;@!````R<.0C4*`@_@?=Q2*@B"<
M&`B$P'14B`&X`0```.OBD(V"8/___X/X'W8IC8(:____@_@9=AZ-@K#^__^#
M^$=V%XV"0/W__X/X'W<EBH)@F1@(Z[Z(T.NZBH+PFA@(Z[*!^B(A``"PF72L
MN/_____)PXV",.___X/X)W<(BH(0BQ@(ZXZ-@O#?__^#^"]WT8J"D'L8".EX
M____B?95B>6+11"*`(3`BTT,>`T/ML")`;@!````R<.0#[;`9HN4`*"9&`AF
M@_K]N/____]TYP^WPNO;D%6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/__
M_X/X'W<5BH+@F1@(A,!T1H@!N`$```#KWXGVC8(`_/__/>\```!V$XV"\-__
M_X/X+W<0BH(P>1@(Z]&*@H"5&`CKR8V"\-[__X/X%W<(BH(0>!@(Z[:X____
M_\G#B?95B>6+11"*`#R?BTT,=PT/ML")`;@!````R<.0#[;`9HN4`""7&`AF
M@_K]N/____]TYP^WPNO;D%6)Y8M5$('ZGP```(M-#'<+B!&X`0```,G#B?:!
M^J````"PH'05C8*`\?__@_A?=Q.*@H")&`B$P'0)B`&X`0```.O4N/_____)
MPY!5B>6+11"*`#R?BU4,=PT/ML")`LFX`0```,.0/-]W&`^VR&:+A`E`EA@(
M9H/X_70?#[?`Z]R)]CSO=A0/ML!FBX0`@)48"&:#^/UUY(UV`+C_____R<.0
M58GEBU40@?J?````BTT,=PN($;@!````R<.)]HV"8/___X/X#W<5BH*@EA@(
MA,!T*8@!N`$```#KWHGVC8*`\?__@_A?=PF*@F"(&`CKWI"!^JT@``"PWW37
MN/_____)PXUV`%6)Y8M%$(H0A-*+30P/ML)X"HD!R;@!````PY"-0E\\6G<1
MC4(E/`-V"@^VP@5@#0``Z]ZX_____\G#D%6)Y8M5$(/Z?XM-#'<*B!&X`0``
M`,G#D(V"__'__X/X6G<9C8+%\?__@_@#=@Z-0J"(`;@!````Z]N)]KC_____
MR<.058GEBT40B@"$P(M-#'@-#[;`B0&X`0```,G#D`^VP&:+E``@[A$(9H/Z
M_;C_____=.</M\+KVY!5B>6+51"#^G^+30QW"H@1N`$```#)PY"!^J````"P
MH'0BC8(`\O__@_A?=B.-@O#?__^#^!=W((J"D,X1"(GVA,!T'H@!N`$```#K
MR(UV`(J"P.`1".OH@?JL(```L(!TXKC_____R<.-=@!5B>6+11"*`#P?BU4,
M=Q4/ML@/MX0)H)88"(D"R;@!````PY"$P'@,#[;`B0+)N`$```###[;`#[>$
M`*"4&`B)`LFX`0```,-5B>6+31"#^7^+50QW&H/Y'W<+N&0`$$+3^*@!=0J(
M"K@!````R<.0C8%`____/?<```!W$XJ!X),8"(3`=!V(`K@!````Z]V-@6#A
M__^#^%]W"8J!H'48".O@D+C_____R<.058GE5U93@^P,BT40B@`\%XMU"(M]
M#'<T#[;(9HN4"0"4&`AFBUX49H7;=#R-@@#]__]F@_@_=UP/M\(M``,``(/X
M(W=E_R2%F/<8"(3`9@^VT'G/#[;89HN4&P"2&`AFBUX49H7;=<2-2K]F@?EO
M`0^&O`````^WPHD'N`$```"#Q`Q;7E_)PV8Y'(6@CQ@(B<)T;@^WT\=&%```
M``")%X/$#%M>,<!?R</HT>3^_S'`C78`BPS%Q)(8"(L$Q<"2&`@!R$AF.1R-
MH(\8"'?%9CD<A:"/&`ARNXUV`(T4`='J9CD<E:"/&`AT%W97.=%THXG0C10!
MT>IF.1R5H(\8"'7I#[<$E:*/&`C'1A0`````Z6/___^X`0```.N7N`0```#K
MD+@"````ZXFX`P```.N"#[?ZN/W___^)?A3I/O___XGV.=$/A#S___^)T>N,
M58GE5U93BTT0@_E_BWT,=Q^#^1]W"[AV`/X`T_BH`74/B`^[`0```(G86UY?
MR<.0C9%@____@?H7`0``=PZ*@>"-&`B$P'0XB`?KUXV9`/W__X/[)P^&WP``
M`(VQP/S__X/^`7<(BH$`BQ@(Z]:-@6#A__^#^%\/AM8```"-=@`/MQ6@BA@(
M,=LYRK[(````#X>8````#[<%P(T8"#G(#X*)````C78`C10ST>H/MP25H(H8
M"#G(=!T/AHD````YTW1KB=:-%#/1Z@^W!)6@BA@(.<AUXP^W!)6BBA@()?\/
M``"#^'^(P783BHC@C1@(A,F[_____P^$*____X-]%`&[_O___P^.'/___XH$
ME:.*&`C`^`0/OMB(#XJ+A(H8"+L"````B$\!Z?K^__^[_____XG86UY?R<.*
M@4"+&`CI__[__XUV`#G3=!*)T^E5____BH%`;Q@(Z>;^__^)\@^W-+6@BA@(
M.<Z[_____P^$8?___^FN_O__B?95B>6+11"*`(3`BTT,NO____]X$CQ<="0\
M?G00#[;0B1&Z`0```(G0R<.)]KH!````QP$^(```Z^V-=@"Z`0```,<!I0``
M`.O=C78`58GEBU40@_I_BTT,=Q:#^EQT$8/Z?G0,B!&X`0```)#)PXGV@?JE
M````=!B!^CX@``"X_____W7GN`$```#&`7[KW9"X`0```,8!7.O2B?95B>6+
M11!3BA"$THM=#'@L@/I<=!>`^GX/ML)T-XD#N0$```")R%O)PXUV`+D!````
MQP.E````Z^N-=@"-0E\\/KG_____=]P/ML(%P/X``(D#Z\NY`0```,<#/B``
M`.O#C78`58GEBU40@_I_4XM-#'<9@_I<=!2#^GYT#X@1NP$```")V%O)PXUV
M`('ZI0```'0D@?H^(```="B-@I\`__^#^#Z[_____W?8C5I`B!F[`0```.O,
MNP$```#&`5SKPHGVNP$```#&`7[KMHGV58GE4XM=$(H3C4+?/`=V#(U"T#Q$
MN?____]W3(-]%`&Y_O___WY!BDL!C5G?@/M==S$/MMJ-%%O!X@0IV@^VP8V$
M4,'S__\]@04``'8B/7\>``!W#F:+A``<2!@(9H/X_74>N?____^)R%O)PXUV
M`#VQ`@``=^QFBX0`((48".O<BTT,#[?0B1&Y`@```(G(6\G#D%6)Y5=64X-]
M%`&+?0R+51"X_O___WY$@?K_````=D&-B@#]__^!^5\!``!W0XG6P>X$C1RU
MP%$8"(UV`(7;=!9FBW,"B=&#X0\/M\;3^*@!#X6)````N/____];7E_)PXG0
MP>@$C1R%X%(8".O.B?:-F@#@__^!^Q\#``!V'HV*`-O__X'Y;P$``'<>B=;!
M[@2-'+4`2!@(ZZ*)]HG0P>@$C1R%H$D8".N2C9H`T/__@?O_````#X:2````
MC8H`LO__@?FO40``#X>1````B=;![@2-'+4`*1@(Z5W___^X`0```-/@2"'P
MB<8EJJH``-'X@>9550```<:)\8'FS,P``,'^`H'A,S,```'QB<J!X?!P``#!
M^02!X@\/```!R@^VPF;!Z@@!T`^W,P^WV`'>9HN4-H`&&`B)T6;!Z0B(#XA7
M`5M>N`(```!?R<.)T,'H!(T<A0!%&`CIW?[__XV:``'__X'[[P````^'Y?[_
M_XG0P>@$C1R%@/P7".FZ_O__B?95B>53BUT0BA.`^B)T!XU"VCP!=U.#?10!
MN?[___]^08I+`8U9WX#[77<Q#[;:C11;P>($*=H/ML&-A%#!\___/=4!``!W
M/3VN````=PYFBX0`!`48"&:#^/UU:;G_____B<A;R<.)]HU*UX#Y`G:EC4+0
M/#VY_____W:9B<A;R<.-=@`][P(``'<1/9$"``!WRF:+A`"4`!@(Z[H]@04`
M`'<1/0($``!WLF:+A``@_!<(ZZ(]*AP``'>A9HN$`)S)%PCKD8M-#`^WT(D1
MN0(```")R%O)PY!5B>575E.#?10!BWT,BU40N/[___]^/('Z7P0``'8YC8H`
MW___@_DO=SZ)T\'K!(TTG2S+%PB)]H7V=!)FBUX"B=&#X0\/M\/3^*@!=5"X
M_____UM>7\G#B=#!Z`2--(6`TQ<(Z]*)]HVR`++__X'^KU$``'8:C8H``?__
M@_E?=\V)T\'K!(TTG29_%PCKJ9")T,'H!(TTA8"K%PCKFK@!````T^!((=B)
MPR6JJ@``T?B!XU55```!PXG9@>/,S```P?L"@>$S,P```=F)RH'A\'```,'Y
M!('B#P\```'*#[;"9L'J"`'0#[<>#[?P`?-FBY0;@(\7"(G19L'I"(@/B%<!
M6UZX`@```%_)PXUV`%6)Y8M%$(H`A,"+30RZ_____W@2/"1T)#Q^=!`/MM")
M$;H!````B=#)PXGVN@$```#'`3X@``#K[8UV`+H!````QP&E````Z]V-=@!5
MB>6+51"#^G^+30QW%H/Z)'01@_I^=`R($;@!````D,G#B?:!^J4```!T&('Z
M/B```+C_____=>>X`0```,8!?NO=D+@!````Q@$DZ]*)]E6)Y5.+71"*$XU"
MWSP(=@R-0M`\1[G_____=TR#?10!N?[___]^08I+`8U9WX#[77<Q#[;:C11;
MP>($*=H/ML&-A%#!\___/8$%``!V(CWQ'P``=PYFBX0`'$D7"&:#^/UU'KG_
M____B<A;R<.-=@`]/@,``'?L9HN$``")%PCKW(M-#`^WT(D1N0(```")R%O)
MPY!5B>564X-]%`&+=0R+31"X_O___WX_@?E?!```=CZ-D0#@__^!^D\&``!W
M0(G(P>@$C1R%8$D7"(7;=!1FBU,"@^$/#[?"T_BH`0^%AP```+C_____6U[)
MPXUV`(G(P>@$C1R%`%,7".O.B?:-F0#0__^!^R\"``!V'HV!`++__SWO3@``
M=Q^)RL'J!(T<E8`I%PCKHXUV`(G*P>H$C1R5P$07".N2C9D`8O__@?NO`0``
M#X:+````C9$``?__@?KO````=XJ)R,'H!(T<A8#\%@CI8?___[@!````T^!(
M(=")PB6JJ@``T?B!XE55```!PHG0@>+,S```P?H")3,S```!T(G!)?!P``#!
M^`2!X0\/```!P0^VT6;!Z0@!R@^W`P^WT@'09HN,```"%PB)RV;!ZPB('HA.
M`5NX`@```%[)PXG(P>@$C1R%`!47".GD_O__58GE5E.#?0P!B=:+30BX_O__
M_WY`@?G_`0``=C^-D0#]__^!^K\```!W08G(P>@$C1R%`/D6")"%VW049HM3
M`H/A#P^WPM/XJ`$/A8<```"X_____UM>R<.-=@")R,'H!(T<A0#Z%@CKSHGV
MC9D`XO__@?N_`0``=AJ-@0#0__^#^#]W'8G*P>H$C1R5(.T6".NED(G*P>H$
MC1R5P/$6".N6C9D`SO__@?O_`0``#X:/````C9$`LO__@?K_+@``#X>.````
MB<C!Z`2-'(5@V18(Z6'___^X`0```-/@2"'0B<(EJJH``-'X@>)550```<*)
MT('BS,P``,'Z`B4S,P```=")P27P<```P?@$@>$/#P```<$/MM%FP>D(`<H/
MMP,/M](!T&:+C`#@W18(B<MFP>L(B!Z(3@%;N`(```!>R<.)R,'H!(T<A2#L
M%@CIY/[__XV9`(+__X'[SQ0``'<1B<K!Z@2-')4@R!8(Z<7^__^-@0!L__\]
M[P@``'<1B<K!Z@2-')5@P!8(Z:?^__^-F0!B__^!^X\!``!W$8G(P>@$C1R%
M8+T6".F(_O__C9$``?__@_I/#X>1_O__B<C!Z`2-'(7XI!8(Z6C^__]5B>57
M5E.#[`R+71"*$X#Z*(M]#(MU%`^$%P$``(U"WSP(#X:0````C4K0@/E'#X:$
M````BA.`^BH/A'D!``"-2M6`^00/AU4!``!.N?[___]^68I+`8U9WX#[70^'
MD@$```^VPHT40,'B!"G"#[;QC816P?/__SVM(```#X9^`0``/8,B```/AV<!
M``!FBX0`)+D6"&:#^/T/A%4!```/M\B)#[D"````C78`B<J#Q`Q;7HG07\G#
M@_X!N/[___]^9HI+`8U!WSQ=#X=D____#[;"C11`P>($*<(/ML&-A%#!\___
M/8$%``!W%3T^`P``#X<]____9HN$``")%PCK$SWQ'P``#X<H____9HN$`!Q)
M%PAF@_C]#X06____#[?8B1^X`@```(G"@\0,6UZ)T%_)PX/^`0^.X/[__XI#
M`8U(WX#Y'P^'T?[__X#Y7<9%\BN(1?,/A[@````/ML`%BP,``#VM(```#X?!
M````/8$%```/AYH```!FBX0`Z/86"&:#^/T/A(@````/M\")![H"````@\0,
M6UZ)T%_)PXU"ACP$N?____\/AIO^__^)RNGW_O__D$ZZ_O___P^.9O___XI+
M`8U!WSQ=LO\/AU;___^$R7A3@/DD=#Z`^7X/ML%UJKH"````QP<^(```ZZ2)
M]KG_____B<KIKO[__SV!!0``=^UFBX0`Z/86".F!_O__BA/I`O[__[H"````
MQP>E````Z6O____HQ-;^_SV#(@``=]UFBX0`)+D6".D^____58GE5U93@^P,
MBWT4@_\!BW40#X[H````@?Y?!```#X>H````B?#!Z`2-'(4`4Q<(A=L/A.0`
M``!FBU,"B?&#X0\/M\+3^*@!#X3.````N`$```#3X$@AT(G"):JJ``#1^('B
M554```'"B="!XLS,``#!^@(E,S,```'0B<$E\'```,'X!('A#P\```'!#[;1
M9L'I"`'*#[<##[?2`=!FBY0```(7"(G39L'K"(M-#&:#^RB(&8A1`0^$F@``
M`+@"````C67T6UY?R<.0C98`X/__@?I/!@``=BZ-G@#0__^!^R\"```/AZH`
M``")\,'H!(T<A<!$%PCI,____XUV`.BKU?[_C78`B?'!Z02-'(U@21<(A=L/
MA1S___^#_G^-1?-W2(/^)'1#@_Y^=#Z)\XA=\XI5\XU*WX#Y77<^3[C^____
M#XYY____BW4,Q@8JB%8!Z6;___^`^B`/AEW___^`^D`/AU3____KL('^I0``
M`'0=@?X^(```=$=75HM5#(M%".AC^O__C67T6UY?R</&`"3KG8V6`++__X'Z
M[TX``'8GC9X`8O__@?NO`0``=RJ)\,'H!(T<A0`5%PCI;?[__\8`?NEH____
MB?'!Z02-'(V`*1<(Z53^__^-E@`!__^!^N\````/AR[___^)\<'I!(T<C8#\
M%@CI,?[__Y!5B>575E.#[`B+=0B*#H#Y@(G7#X8_`0``@/G_#X0V`0``@WT,
M`;C^____#X['````C4%?/%8/A\0```"`^:&*7@$/A,\!``"`^Z`/AJ\```"`
M^_\/A*8```"-0X"(1?&(1?.-05^-48`\"(A5\@^&4@$``(U!4#Q'#X9'`0``
MD(U5\H#YIHA-\HA:`70%@/FH=6V-0\`\/G8)A-MY8H#[_W1=#[;1C032C01"
MC12`T>*)5>R$VP^VTXU"OW@#C4+``T7LC9!"H/__@?KQ'```#X?D`0``+=-[
M``"#^!5W(&:+A!*V;14(9H/X_702#[?`B0>X`@```(/$"%M>7\G#C5E_@/L?
M=S2*%HU"?SP?N?____]W'(I.`8U9P(#[/@^&'0$``(3)#X@,`0``N?____^)
MR(/$"%M>7\G#@/FG=R>`^:)U$HI6`8U*7X#Y"0^&/@$``(UV`(/$"%M>N/__
M__]?R<.-=@"`^?]TU(H6@/JG=N2`^O]TWXI.`8U!P#P^=@B-68"`^R!WS0^V
M\HT$=L'@!83)#[;1#X@V`0``@^I`C800H,___SWO+@``=ZAFBX0`8+@5"&:#
M^/UTF@^WP.DK____C4-?/%T/AZ_^__\/ML*-%$#!X@0IP@^V1?&-A%#!\___
M/8$%```/A[`````]/@,```^'@_[__V:+A```B1<(9H/X_0^$<?[__P^WP.G:
M_O__@/ND#X2]````@/NJ#X4?_O__N`(```#'`A0@``#IO_[__X#Y_P^$Z_[_
M_P^VTHT<THT$6HTT@`^VV83)C10VC4._>`.-0\"-A`)"H/__/;\7```/A[W^
M__]FBX0`(*85"&:#^/T/A*O^__\/M\B)#[D"````B<CIH?[__P^VP@7/(```
MB0?I4?[__SWQ'P``#X?3_?__9HN$`!Q)%PCI2____RTJ?0``@_@%#X<X_O__
M9HN$$O!J%0CI$_[__X/J0>G%_O__N`(```#'`K<```#I"_[__XUV`%6)Y5=6
M4U:+70B!^_LP``")UP^$"`$``('[%2````^$_````('[7P0```^'N````(G8
MP>@$C32%`%,7"(7V#X3<````9HM6`HG9@^$/#[?"T_BH`0^$Q@```+L!````
MT^-+(=.)V8'CJJH``-'[@>%550```=F)R('AS,P``,'Y`B4S,P```<B)PR7P
M<```P?@$@>,/#P```<,/MM-FP>L(`=H/MPX/M_(!\6:+E`D``A<(B=-FP>L(
M@WT,`8A=\HA5\[C^____?A>*1?*#P("(!XC0@\"`B$<!B?:X`@```%M;7E_)
MPY"-DP#@__^!^D\&```/AHX!``"-LP#0__^!_B\"```/A_<!``")V,'H!(TT
MA<!$%PCI'____XUV`(VS`/[__X'^WP````^'K@```(G:P>H$C3250)L5"(7V
M#X3B````9HM6`HG9@^$/#[?"T_BH`0^$S````+@!````T^!((=")PR6JJ@``
MT?B!XU55```!PXG8@>/,S```P?L")3,S```!V(G!)?!P``"!X0\/``#!^`0!
MP0^VT6;!Z0@!R@^W'@^W\@'S9HN4&Z`4%0B)T6;!Z0B#?0P!B$WRB%7SN/[_
M__\/CA+___^*7?*(T(@?B$<!Z?[^__^)]HV+`.#__X'YOP(``'8FC;,`V___
M@?X/`0``#X?)````B=K!Z@2--)5@D14(Z2W___^-=@")V,'H!(TTA0"3%0B%
M]@^%'O___XVSD-[__X/^"0^&2`$``(V3P/[__X/Z#W=:9HN4&P":%0AFA=(/
MA6'___^!^[<````/A(D```"!^Q0@``"X_____P^%<?[__X-]#`&P_@^.9?[_
M_\8'H<9'`:KI5/[__XG9P>D$C32-8$D7".FC_?__C78`C8.P_?__@_@7=PUF
MBY0;H)<5".N9C78`C8O0`?__@_D7=Y1FBY0;H)\3".N!C8L`T/__@?G_````
M=VJ)V,'H!(TTA6".%0CI5O[__X-]#`&X_O___P^.ZOW__\8'H<9'`:3IV?W_
M_XV3`++__X'Z[TX``'8?C;,`8O__@?ZO`0``=VZ)V,'H!(TTA0`5%PCI#/W_
M_XG9P>D$C32-@"D7".G[_/__C;,`SO__@?[?`0``=Q&)VL'J!(TTE6"-%0CI
MWOW__XV+`++__X'YKU$``'="B=C!Z`2--(7@<14(Z;_]__^-0S'&!Z*(1P'I
M3_W__XV3``'__X'Z[P````^'@?W__XG9P>D$C32-@/P6".F,_/__C;,`!___
M@?XO`0``=Q&)VL'J!(TTE<!&%0CI;_W__XV+``+__X'Y[P$```^'1_[__XG8
MP>@$C32%`$45".E,_?__B?95B>564X-]#`&)UHM-"+C^____?D"!^?\```!V
M/XV1`/[__X'ZSP$``'=!B<C!Z`2-'(4@3!$(D(7;=!1FBU,"@^$/#[?"T_BH
M`0^%B````+C_____6U[)PXUV`(G(P>@$C1R%($T1".O.B?:-F0#@__^!^[\"
M``!V'HV!`-S__SU/`@``=Q^)RL'J!(T<E4!"$0CKHXUV`(G*P>H$C1R5X$,1
M".N2C9D`T/__@?NO;P``#X:4````C9$`!O__@_HO#X>6````B<C!Z`2-'(6<
M\!`(Z6#___^X`0```-/@2"'0B<$EJJH``-'X@>%550```<&)R('AS,P``,'Y
M`B4S,P```<B)PB7P<```P?@$@>(/#P```<(/MLIFP>H(`=%F`PL/M\&-'$"*
MBX!Z#@B(#HJ3@7H."(J+@GH."(A6`8A.`ENX`P```%[)PXG(P>@$C1R%0",1
M".G;_O__C9D``O__@?OO`0``=Q&)RL'J!(T<E2#O$`CIO/[__XV!``#^_SW?
MI@``=Q&)RL'J!(T<E>"$$`CIGO[__XV9``C]_X'['P(```^'I/[__XG(P>@$
MC1R%0$80".E[_O__C78`58GE5E.#?0P!B=:+30BX_O___WY`@?G_````=C^-
MD0#^__^!^E\"``!W08G(P>@$C1R%`,T2")"%VW049HM3`H/A#P^WPM/XJ`$/
MA8L```"X_____UM>R<.-=@")R,'H!(T<A2#.$@CKSHGVC9D`X/__@?N_`@``
M=AZ-@0#<__\]3P(``'<?B<K!Z@2-')4@PQ((ZZ.-=@")RL'J!(T<E<#$$@CK
MDHV9`-#__X'[WP,```^&CP```(V1`++__X'ZKU$```^'C@```(G(P>@$C1R%
M(*,2".E=____N`$```#3X$@AT(G"):JJ``#1^('B554```'"B="!XLS,``#!
M^@(E,S,```'0B<$E\'```,'X!('A#P\```'!#[;19L'I"`'*#[<##[?2`=!F
MBXP`($L2"(G+9L'K"(@>B$X!6[@"````7LG#B<C!Z`2-'(4@OQ((Z>#^__^-
MF0`&__^#^P]W$8G*P>H$C1R5''@2".G$_O__C8$``O__/6\!```/A\O^__^)
MRL'J!(T<E<!V$@CIHO[__XGV58GE4XM=$(H3C4+?/`MV"(U*T(#Y&'=L@WT4
M`;G^____?D&*2P&-6=^`^UUW,0^VVHT46\'B!"G:#[;!C810P?/__SV!!0``
M=R(]6@0``'<.9HN$`"#5%@AF@_C]=4JY_____XG(6\G#C78`/0T/``!W)3VO
M#@``=^5FBX0`O+<6".O5C4*V/#.Y_____W:(B<A;R<.-=@`])2(``'?`9HN$
M`&1^%@CKL(M-#`^WT(D1N0(```")R%O)PY!5B>575E.#?10!BWT,BU40N/[_
M__]^1('Z7P0``'9!C8H`X/__@?EO!@``=T.)UL'N!(T<M<"1%@B-=@"%VW06
M9HMS`HG1@^$/#[?&T_BH`0^%B0```+C_____6UY?R<.)T,'H!(T<A6";%@CK
MSHGVC9H`T/__@?O?`P``=AZ-B@"R__^!^9]1``!W'HG6P>X$C1RUP'`6".NB
MB?:)T,'H!(T<A<",%@CKDHV:`%3__X'[GRL```^&D@```(V*``?__X'Y#P$`
M``^'D0```(G6P>X$C1RUH#H6".E=____N`$```#3X$@A\(G&):JJ``#1^('F
M554```'&B?&!YLS,``#!_@*!X3,S```!\8G*@>'P<```P?D$@>(/#P```<H/
MML)FP>H(`=`/MS,/M]@!WF:+E#9`.!8(B=%FP>D(B`^(5P%;7K@"````7\G#
MB=#!Z`2-'(5`3A8(Z=W^__^-F@`!__^!^^\````/A^7^__^)T,'H!(T<A>`X
M%@CINO[__XGV58GE5U934(M%$(H0A-*+=0R+711X$@^VPHD&N0$```!?6UZ)
MR%_)PX#ZH`^'TP```(#ZC@^$Y@$``(#ZC[G_____==R#^P&Q_G[5BE`!@/J@
M#X9M`0``@/K_#X1D`0``@_L"?KN`^O0/AV,!``"*0`(\H`^&2P$``#S_#X1#
M`0``C4J`C5B`@/DBB$WPB%WQ=!F-0EH\`782C4)7/`)V"XU"4#P]#X<9`0``
MC5/?@/I=#X<-`0``#[;!C3Q`P><$*<</MLN-A'G!\___/=4!```/A\\!```]
MK@````^'X@```&:+A``$!1@(9H/X_0^$T`````^WV+D#````B1[I'?___Y"`
M^O\/A"3___]+N?[___\/C@?___^`^O0/AY(```"*2`&`^:`/AI8```"`^?\/
MA(T```"->8")^(A%\XU"7XU:@#P'B%WR=@R-0E`\1+K_____=U6-45^`^ET/
MAP8!```/ML.-%$#!X@2)^2G"#[;9C813P?/__SV!!0``#X<,`0``/;$"```/
MA]D```!FBX0`((48"&:#^/T/A,<````/M_B)/KH"````B='I;/[__XI(`8#Y
MH'8(@/G_=3Z-=@!?6UZY_____XG(7\G#BD@"@/F@=NN`^?]TY@^VVHT\6\'G
M!`^VP2G?C91X%8D``+D#````B1;I(?[__P^V^HT4?\'B!`^VP2GZC9Q0:84`
M`+D"````B1[I`/[__TNY_O___P^.]/W__XI0`8U:7X#[/K'_#X?C_?__A-)X
M18#Z7'0P@/I^#[;"=`R)!KD"````Z<;]__^Y`@```,<&/B```.FV_?__NO__
M__^)T>FJ_?__N0(```#'!J4```#IFOW__P^VP@7`_@``B0;KOCU_'@``=]%F
MBX0`'$@8".GS_O__/>\"``!W&#V1`@``#X<,____9HN$`)0`&`CI)?[__SV!
M!0``=Q@]`@0```^'[?[__V:+A``@_!<(Z0;^__\]*AP```^'U?[__V:+A`"<
MR1<(Z>[]__]5B>575E.#[`R+71"#^W^+=0R+?12X_____W<'B!ZX`0```(/X
M_W0(C67T6UY?R<-J`E.-1?)0_W4(Z$7D__^#Q!"#^/]T*8/X`@^%U@(``$^X
M_O___W[0BE7R@\*`B!:*1?.#P("(1@&X`@```.NX@_M_#X<4`0``@_M<#X0+
M`0``@_M^#X0"`0``B%WRN0$```"#^?]T"XI5\H32#XCE`0``@?M?!```#X<<
M`0``B=K!Z@2-!)6`TQ<(B47LBT7LA<`/A/L```"+3>QFBU$"B=F#X0\/M\+3
M^*@!#X3B````N`$```#3X$@AT(G"):JJ``#1^('B554```'"B="!XLS,``#!
M^@(E,S,```'0B<$E\'```,'X!('A#P\```'!#[;19L'I"`'*BTWL#[<!#[?*
M`<AFBY0`@(\7"(G09L'H"(A%\HA5\[@"````@_C_#X24````@_@"#X7&`0``
M@_\"N/[___\/CKK^___&!H^*3?*#P8"(3@&*7?.#PX"X`P```(A>`NF;_O__
M@?NE````#X2^````@?L^(```#X3:````C8.?`/__@_@^N?____\/A]K^__^-
M2T"(3?+IRO[__[C_____ZX.-@P#?__^#^"\/AX8```")V<'I!(T$C2S+%PCI
MT/[__X'[I0````^$U````('[/B````^$%@$``(V+`"#__X'Y5P<``+C_____
M#X<._O__@?NKXP``#X>R````3[#^#X[Y_?__N%U!3*[WX<'J!HT$4L'@!"G0
MT>`HP8C(@^H+@^A?B!:(1@'I$O[__\9%\ESI+O[__XV3`++__X'ZKU$``'<]
MB=C!Z`2-!(6`JQ<(Z3S^___&1?)^Z0;^__])#X67````3[C^____#XZ-_?__
MN`(```#&!HZ(5@'I??W__XV+``'__X/Y7P^'"O___XG:P>H$C025)G\7".GP
M_?__N`$```#&!ESI4/W__T^X_O___P^.1/W__XV+5!S__[A=04RN]^'!Z@:-
M'%+!XP0IT]'C*-F#Z@N#Z5^X`P```,8&CXA6`8A.`ND/_?__N`$```#&!G[I
M`OW__^@-PO[_D%6)Y5=64U&+31"*$832BW4,BUT4>":`^EQT&8#Z?@^VP@^$
M@0```(D&N`$```!:6UY?R</'!J4```#K[8U"7SP^=G&->G^)^#P>=G>-0B`\
M"G9PC4(0/`D/AR(!``!+N/[___]^R(I)`8U9P(#[/G8+C4&`/'P/AP0!```/
MMM*-/%+!YP0IUX3)C12]P"\```^(&0$```^VV8U$&L")!K@"````ZXB)]L<&
M/B```.EV____D`^VP@7`_@``B0;I9O___TNX_O___P^.7____XI)`8U9P(#[
M/@^'EP```(#ZWXGX=@.-0C^$R8U1P`^(HP````^VP-'@@/I=C4@B=P.-2"&`
M^EV(3?*-6B%V`XU:PXU1WXU]\H#Z!XA?`78,C4'0/$2Z_____W=#C5/?@/I=
M=U</ML&-/$#!YP0IQP^VRXV$><'S__\]@04``'=//;$"``!W-&:+A``@A1@(
M9H/X_70F#[?8B1ZZ`@```(G0Z;G^__^-08`\?`^&7O___[C_____Z:3^__^Z
M_____XG0Z9C^__^-4;_I5?___SU_'@``=^5FBX0`'$@8".NO#[;!C40"O^GB
M_O__D%6)Y5=64X/L#(M=$(/[?XM]#(UU\G<U@_M<=#"#^WYT*XA=\KH!````
M@_K_=%Y*#X7M````BE7RA-)X2(@7N`$```"-9?1;7E_)PY"!^Z4```!T(('[
M/B```'0@C8.?`/__@_@^NO____]WO8U30(@6Z[&0Q@9<ZZN-=@#&!G[KHXUV
M`(U*7X#Y/G:P:@)35O]U".@$W___@\00@_C_="2#^`)U?8-]%`&X_O___WZ3
MBE7RC4+?/%.*3@%W!XU!WSQ==F.-BP`@__^!^5<'``"X_____P^':/___X-]
M%`&P_@^.7/___[A=04RN]^'!Z@>-'%+!XP0IT\'C`BC9@^H0@/D^B,B(%W<3
M@\!`B$<!C67T6UZX`@```%_)PX/`0>OKZ"F__O\/ML*#Z"&)PM'J#[;)J`&-
M6=]T`XU9/8#Z'HC9C4*!=@.-0L&`^3Z(!XU!0':XC4%!Z[.)]E6)Y5935HM-
M$(H1A-*+=0R+710/ML)X#(D&N`$```!;6U[)PXU"7SP^#X;=````C4)_/!X/
MA]\```"`^H</A-8```!+N/[___]^U(I)`8U9P(#[/G8+C4&`/'P/AV,!``"`
M^M^-0G]V`XU"/X3)#XA:`0``@^E`#[;`T>"`^5V-4")W`XU0(8#Y78A5]@^'
M*0$``(/!(8U:WXU%]H#[!XA(`78,C4+0/$2[_____W=3C5G?@/M=#X?T````
M#[;:C11;P>($*=H/ML&-A%#!\___/8$%```/A_H````]L0(```^'R0```&:+
MA``@A1@(9H/X_0^$MP````^WR(D.NP(```")V%M;7LG#B?8/ML(%P/X``.G_
M_O__C4(@/`H/AA____^`^H=T$(U"$SP!=@F`^OD/AN````!+N/[___\/CMK^
M__^`^H=T%(U:$X#[`78,C4(&/`*[_____W>EBDD!C5G`@/L^=@>-08`\?'=`
MA,D/MMH/ML$/B`$!``"-2,"`^M]V?XT46\'B!"G:C8211'+__SU/(```=TX]
MPP0``'<-9HN$`+`N%@CI/____[O_____B=CI2?___X/I/>G2_O__6UNX____
M_U[)PX/I0>FA_O__/7\>``!WTV:+A``<2!@(Z07___\]VRD``'=V/<<A``!W
MN&:+A`#@\Q4(Z>K^__^-!%O!X`0IV(V$@42A___I?/___XU"$#P)=Z1+N/[_
M__\/CO/]__^*20&-6<"`^SYV!XU!@#Q\=X8/MM*-'%+!XP0ITX3)C12=P"\`
M`'@S#[;!C40"P(D&6UNX`@```%[)PSU?*P``#X<^____9HN$`*C=%0CI</[_
M_XU(O^GZ_O__#[;9C40:O^O+58GE5U93@^P,BUT0@_M_BWT,N/____]W"(A=
M\K@!````@_C_=!Y(#X6$`@``BD7RA,!X$(@'N`$```"-9?1;7E_)PY"#^W]W
M+X/[7'0J@_M^="6(7?*)]KH!````@_K_=$I*#X5(`@``BE7RC4I?@/D^=SB(
M%^N^@?NE````#X1H`0``@?L^(```=!B-@Y\`__^#^#ZZ_____W?!C5-`B%7R
MZ[3&1?)^ZZZ)]FH"4XUU\E;_=0CH]=K__X/$$(/X_W0P@_@"#X7E`0``@WT4
M`;C^____#XY@____BE7RC4+?/%.*3?-W"XU!WSQ=#X;B`0``C9,`W___@?J_
M`0``#X?+````B=G!Z02--(V@*!8(A?8/A&\!``!FBU8"B=F#X0\/M\+3^*@!
M#X19`0``N`$```#3X$@AT(G"):JJ``#1^('B554```'"B="!XLS,``#!^@(E
M,S,```'0B<$E\'```,'X!('A#P\```'!#[;19L'I"`'*#[<&#[?R`?!FBY0`
M0!H6"(G19L'I"(A-\HA5\[@"````@_C_=%B#^`(/A0L!``"#?10!N/[___\/
MCH;^__^*7?*('XI%\XA'`8UE]%M>N`(```!?R<.-=@"-LP#<__^#_G]W:(G8
MP>@$C32%P"<6".DE____QD7R7.EC_O__C8L`(/__@?E7!P``N/____\/AR_^
M__^#?10!L/X/CB/^__^X74%,KO?AP>H'C012P>`$*=#!X`(HP8/J$(#Y/HC(
MB!=W0X/`0.EZ____C9,`T/__@_H?=A^-LP#.__^!_L\!``!W-HG8P>@$C32%
MP",6".FD_O__B=G!Z02--(VT)!8(Z9/^__^#P$'I-____XGVN/_____I!O__
M_XV3`++__X'ZCP<``'<6B=G!Z02--(W`&A8(Z6#^___HKKG^_XVS`*G__X'^
MOP(``'=+B=C!Z`2--(7`%Q8(Z3S^__\/ML*#Z"&)PM'J#[;)J`&-6=]T`XU9
M/8#Z'HC9C4*!=@.-0L&`^3Z(!XU!0`^&MO[__XU!0>FN_O__C9,`I?__@?K?
M`@``=Q&)V<'I!(TTC0`6%@CIX_W__XVS`*'__X'^GQP``'<1B=C!Z`2--(7`
M#18(Z<3]__^-DP"#__^!^J\"``!W$8G9P>D$C32-@`46".FE_?__C;,`??__
M@?Z_`@``=Q&)V,'H!(TTA4`#%@CIAOW__XV3`'C__X'ZSP8``'<1B=G!Z02-
M-(U``!8(Z6?]__^-LP!P__^!_M\.``!W$8G8P>@$C32%@/H5".E(_?__C9,`
M!___@?HO`0``=Q&)V<'I!(TTC>#?%0CI*?W__XVS``'__X'^[P````^'CO[_
M_XG8P>@$C32%(-X5".D&_?__D%6)Y5=64X/L#(M%"(M5$(M]%(M8%#'VD(H*
M@/D;=6*-3@,Y^7\GBD(!/"AT-SPD=4F*0@(\0'0$/$)U/KL"````B<Z-20&#
MP@,Y^7[+BTT(N/[___^)610I\(/$#%M>7\G#B?:*0@(\0G0+/$IU"[L!````
MZ\LQV^O'N/_____KV8/[`0^$K0````^"A````(/[`@^%_0```(U&`CGXB47P
M?ZJ$R7C3BEH!A-MXS(U1WX#Z!W8'C4'0/$1WO8U3WX#Z77>U#[;YC0Q_P>$$
M*?D/MO.-A$[!\___/8$%```/AYD````]L0(``'>.9HN$`""%&`AF@_C]=(`/
MM\"+50R)`HM="(M%\,=#%`(```#I1O___X3)N/____\/B#G___\/ML&+?0R)
M!XM5"(U&`8E:%.DC____A,FX_____P^(%O___X#Y7'0?@/E^="4/MOF+50R)
M.HM%",=`%`$```"-1@'I\O[__XM=#,<#I0```.OCBTT,QP$^(```Z]@]?QX`
M``^'\?[__V:+A``<2!@(Z5[____HO;;^_Y!5B>575E.#[`R+51"+?0B#^G^+
M70R+=RBX_____W<(B%7RN`$```"#^/]T3$@/A5,!``"*3?*$R7@^@_X!&<"#
MX/V-4`0Y512X_O___WP,A?9U$9"("XG0B7<HC67T6UY?R<.0Q@,;QD,!*,9#
M`D(Q]H/#`^O>B?:#^G]W5X/Z7'12@_I^=$V(5?*)]KD!````@_G_='))#X7I
M````BDWRA,EX9#'`@_X!#Y7`C51``3E5%+C^____?*&#_@%TE<8#&\9#`2C&
M0P)*O@$```"#PP/K@('ZI0````^$DP```('Z/B```'08C8*?`/__@_@^N?__
M__]WF8U*0(A-\NN,QD7R?NN&B?9J`E*-5?)25^CSU/__@\00@_C_=%^#^`)U
M9(I5\H32>%.`??,`>$TQP(/^`@^5P(U,0`(Y312X_O___P^,$O___X/^`G03
MQ@,;QD,!),9#`D*^`@```(/#`X@3BE7SB<B(4P&)=RCIZ/[__\9%\ESI$/__
M_[C_____Z=7^___H,;7^_Y!5B>6+10B+0"@QTH7`BTT,=!Z#?1`"NO[___]^
M$\8!&\9!`2C&00)"N@,```"-=@")T,G#58GE5U93@^P,BT4(BU40BWT4BW`4
M,=N0B@J`^1L/A8@```"-2P,Y^7\XBD(!/"AT4SPD=6^*0@(\0'0\/$)T.#PH
M=6"-0P0Y^'\7@'H#1'53O@,```"#P@2)PXU+`3GY?K:+30BX_O___XEQ%"G8
M@\0,6UY?R<.0O@(```"#P@.)R^O7BD("/$)T$#Q*=16^`0```(/"`XG+Z\`Q
M]H/"`XG+Z[>X_____^O$@_X!#X3+````#X*B````@_X"#X3U````@_X##X4(
M`@``C4,".?B)1>Q_C(3)>,J*6@&$VWC#@/DB=!>-4=J`^@%V#XU!USP"=@B-
M4="`^CUWIXU#WSQ==Z`/MOF-#'_!X00I^0^V\XV$3L'S__\]U0$```^'0P$`
M`#VN````#X=U____9HN$``0%&`AF@_C]#X1C____#[?`BU4,B0*+70B+1>S'
M0Q0#````Z13___^0A,FX_____P^(!O___P^VP8M]#(D'BU4(C4,!B7(4Z?#^
M__^$R;C_____#XCC_O__@/E<#X2V````@/E^#X2[````#[;YBU4,B3J+10C'
M0!0!````C4,!Z;?^__^-0P(Y^(E%\`^/G/[__X3)#XC6_O__BEH!A-L/B,O^
M__^-4=^`^@=V"XU!T#Q$#X>X_O__C5/?@/I=#X>L_O__#[;YC0Q_P>$$*?D/
MMO.-A$[!\___/8$%``!W<CVQ`@``#X>%_O__9HN$`""%&`AF@_C]#X1S_O__
M#[?`BU4,B0*+70B+1?#'0Q0"````Z23^__^+=0S'!J4```#I3?___XM-#,<!
M/B```.D_____/>\"``!W+CV1`@``#X<K_O__9HN$`)0`&`CIL?[__SU_'@``
M#X<3_O__9HN$`!Q(&`CKC)`]@04``'<9/0($```/A_;]__]FBX0`(/P7".E\
M_O__D#TJ'```#X?=_?__9HN$`)S)%PCI8_[__^@CLO[_C78`58GE5U93@^P,
MBUT0BT4(@_M_BW`HBWT,N/____]W"(A=\K@!````@_C_=$Q(#X6U`@``BDWR
MA,EX/H/^`1G;@^/]C5,$.544N/[___]\'H7V=!#&!QO&1P$HQD<"0C'V@\<#
MB`^+30B)<2B)T(UE]%M>7\G#C78`@_M_=U^#^UQT6H/[?G15B%WRB?:Z`0``
M`(/Z_W1^2@^%2P(``(I-\H3)>'`QVX/^`0^5PXU46P$Y512X_O___WRS@_X!
M=!/&!QO&1P$HQD<"2KX!````@\<#B`^+?0B)=RCKCX'[I0````^$HP```('[
M/B```'08C8.?`/__@_@^NO____]WD8U30(A5\NN$QD7R?NE[____C78`:@)3
MC4WR4?]U".A)T/__@\00@_C_=&F#^`(/A;0!``"*5?*$TGA9@'WS`'A3,<"#
M_@(/E<"-3$`".4T4N/[___\/C!+___^#_@)T$\8'&\9'`23&1P)"O@(```"#
MQP.(%XI5\XA7`8M]"(EW*(UE]%M>B<A?R</&1?)<Z?C^__^!^U\$```/AP,!
M``")VL'J!(T$E8#3%PB)1>R+3>R%R0^$X@```(M-[&:+40*)V8/A#P^WPM/X
MJ`$/A,D```"X`0```-/@2"'0B<,EJJH``-'X@>-550```<.)V('CS,P``,'[
M`B4S,P```=B)P27P<```P?@$@>$/#P```<$/MMEFP>D(`<N+5>P/MP(/M\L!
MR&:+G`"`CQ<(B=IFP>H(B%7RB%WSN`(```"#^/]T>X/X`@^%FP```(I5\H32
M>&N`??,`>&4QVX/^`P^5PXT,G0(````Y312X_O___P^,]OW__X/^`P^$\_[_
M_\8'&\9'`23&1P(HQD<#1+X#````@\<$Z=?^__^X_____^N<C8L`W___@_DO
M=QN)V,'H!(T$A2S+%PCI[?[__[C_____Z:3]__^-DP"R__^!^J]1``!W%HG9
MP>D$C02-@*L7".G$_O__Z#.O_O^-@P`!__^#^%]WI(G:P>H$C025)G\7".FC
M_O__C78`58GEBT4(BT`H,=*%P(M-#'0>@WT0`KK^____?A/&`1O&00$HQD$"
M0KH#````C78`B=#)PU6)Y5=64X/L'(M="(M#%`^VR(G'BU40BW44B4WPP>\(
M,=N)]HH*@/D;#X7T````C4L#.?%_.(I"`3PH=$\\)'1G/"X/A0D$``"*0@(\
M0;\!````=`T\1@^%ZP,``+\"````@\(#C4$!.?")RWZVP><("WWPBTT(OO[_
M__^)>10IWH/$'%N)\%Y?R<.0BD("/$)T73Q*=&4\20^%J0,``,=%\`(```#K
MNHI"`CQ`=#4\0G0Q/$%T8#PH#X6)`P``C4L$.?%_J(I"`SQ$=#L\0P^%<P,`
M`(/"!,=%\`8```#KA(UV`,=%\`,```#I<O___\=%\`````#I9O___\=%\`$`
M``#I6O___X/"!,=%\`0```#I3O___\=%\`4```#I/____X-]\`8/AWL$``"+
M1?#_)(4H^!@(C4,".?")1>`/CRG___^$R0^(^P(``(I:`83;#XCP`@``C5'?
M@/H+=A.-0=`\&'8,C5&V@/HS#X?5`@``C4/?/%T/A\H"```/MM&--%+!Y@0I
MU@^VRXV$<<'S__\]@04```^'Z@,``#U:!```#X>?`@``9HN$`"#5%@AF@_C]
M#X2-`@``P><(#[?`BTT,"WWPBUT(BW7@B0&)>Q3IJO[__XU#`CGPB47D#X^)
M_O__A,D/B%L"``"*6@&$VP^(4`(``(U1WX#Z"'8+C4'0/$</AST"``"-4]^`
M^ET/AS$"```/ML&-#$#!X00IP0^V\XV$3L'S__\]@04```^'#P,``#T^`P``
M#X<&`@``9HN$``")%PAF@_C]#X3T`0``#[?PBU4,P><(B3(+??"+70B+=>2)
M>Q3I$?[__XU#`CGPB47H#X_P_?__A,D/B,(!``"*6@&$VP^(MP$``(#Y(G0;
MC5':@/H!=A.-0=<\`G8,C5'0@/H]#X>7`0``C4/?/%T/AXP!```/MM&--%+!
MY@0IU@^VRXV$<<'S__\]U0$```^'T0(``#VN````#X=A`0``9HN$``0%&`AF
M@_C]#X1/`0``P><(#[?`BTT,"WWPBUT(BW7HB0&)>Q3I;/W__X3)OO____\/
MB%_]__\/ML&+30R)`8/X"@^$M0$``(/X#0^$K`$``,'G"`M]\(M5"(US`8EZ
M%.DQ_?__A,F^_____P^()/W__XC*@.J`#XB[`0``@/I<#X2D`0``@/I^#X3F
M`0``#[;"BU4,B0+KN(U#`CGPB47L#X_<_/__A,D/B*X```"*6@&$VP^(HP``
M`(U1WX#Z!W8+C4'0/$0/AY````"-4]^`^ET/AX0````/ML&-#$#!X00IP0^V
M\XV$3L'S__\]@04```^'B@$``#VQ`@``=UUFBX0`((48"&:#^/UT3P^W\(M5
M#,'G"(DR"WWPBUT(BW7LB7L4Z6S\__^$R;[_____#XA?_/__@/E<#X37````
M@/E^#X2[````#[;!BTT,B0&+50R+`NGD_O__B?:^_____^DO_/__/$Z^____
M_P^%(OS__X/_`71@<N*#_P(/A3D!``"*0@*$P+[_____#X@"_/__@\"`/)]W
M'P^VP(MU#(D&@4WP``(``(M=\(M5"(G.B5H4Z=S[__\/MM!FBX02X.P8"&:#
M^/V^_____P^$POO__P^WP.O%BD("A,"^_____P^(K?O__X/`@`^V\(M]#(%-
M\``!``")-^NM,?_I3?[__XMU#,<&/B```(M5#(L"Z2C^__^+50S'`J4```"+
M50R+`ND5_O__BW4,QP:E````Z1G^__^-0=\\/K[_____#X=.^___#[;*@<'`
M_@``BW4,B0[I]OW__SWQ'P``#X?W_O__9HN$`!Q)%PCI[/S__XGVBTT,QP$^
M(```Z<[]__\]?QX```^'S_[__V:+A``<2!@(Z6W^__^)]CT-#P``=UP]KPX`
M``^'KO[__V:+A`"\MQ8(Z0K\__^0Z#.I_O\][P(``'<8/9$"```/AXG^__]F
MBX0`E``8".DC_?__/8$%``!W,#T"!```#X=J_O__9HN$`"#\%PCI!/W__STE
M(@``#X=2_O__9HN$`&1^%@CIKOO__STJ'```#X<Z_O__9HN$`)S)%PCIU/S_
M_Y!5B>575E.#[!R+70B+0RB+=1`/ML@/MM2)PXGPP>@'P>L0/0`<``")3>R)
M5>@/A+4```"#^P,/AX````"#_G^X_____W<*B?"(1?*X`0```(/X_W1O2`^%
M&`$``(I5\H32>&&#?>P!&<"#X/V#P`0Y112Y_O___WPWBWWLA?\/A;@```"+
M30R#_@J($0^$U@```(/^#0^$S0```,'C$,%EZ`@+7>@+7>R+=0B)7BB)P8UE
M]%M>B<A?R<.)]C';Z7G___^0BQ2=1/@8"(E5Y(GVBT7D@^`'@_@%#X>5````
M_R2%5/@8"(GVB?*#XG^-0K\\&0^&_`0```^^PH/X:@^$T@4```^/8`4``(/X
M80^$O@8```^.)P8``(/X:`^%O@4``(/[!P^%M04``,%EZ`B!3>@```,`Z5`%
M``"0BTT,Q@$;QD$!*,9!`D*#P0.)30R+30R#_@K'1>P`````B!$/A2W___^-
M=@#'1>@`````Z2?____H2Z?^_XUV`(/^?XU5\@^'K`0``(/^7`^$HP0``(/^
M?@^$F@0``(GPB$7RD+D!````@_G_#X2.````277#BE7RA-(/B8`````QP(-]
M[`(/E<"-=$`!.744N?[___\/C-G^__^#?>P"=!N+?0S&!QO&1P$HQD<"28/'
M`XE]#,=%[`(```"-2H"+50R("NG/`0``C78`:@)6C7WR5_]U".CUW/__@\00
M@_C_=!V#^`(/A4S___^*5?*$TG@-@'WS``^)4P<``(UV`,%MY`,/A8K^__^Y
M_____^E@_O__@_Y_#X>C`P``@_Y<#X2:`P``@_Y^B?`/A(\#``"(1?*Z`0``
M`(/Z_W022@^%\_[__XI5\H32#XDQ!@``:@)6C57R4O]U".AUQ?__@\00@_C_
M=!J#^`(/A<C^__^*5?*$TG@*@'WS``^)B@8``('^7P0```^'GP0``(GQP>D$
MC3R-@-,7"(7_#X1W!```9HM7`HGQ@^$/#[?"T_BH`0^$800``+@!````T^!(
M(=")PB6JJ@``T?B!XE55```!PHG0@>+,S```P?H")3,S```!T(G!)?!P``#!
M^`2!X0\/```!P0^VT6;!Z0@!R@^W!P^W^@'X9HN,`("/%PB)RF;!Z@B(5?*(
M3?.X`@```(/X_P^$U_[__X/X`@^%!O[__XI5\H32#XC#_O__@'WS``^(N?[_
M_S')@WWL!`^5P8TTC0(````Y=12Y_O___P^,#_W__X-][`1T'XM]#,8'&\9'
M`23&1P(HQD<#1(/'!(E]#,=%[`0```"+?0R(%XI-\XM5#(A*`<'C$,%EZ`@+
M7>@+7>R+10B)\8E8*.G"_/__B?:!_O\```"X_____W<*B?"(1?*X`0```(/X
M_W022`^%8?W__XI5\H32#XCD!```@?Z?````B?!V+(V68/___X/Z'P^&V`(`
M`(V&@/S__X/X3P^'XP,``(J&(.H8"(3`#X3&`@``B$7RN`$```"#^/\/A-?]
M__](#X4(_?__BE7RA-(/B<7]__\QP(-]Z`(/E<"-=$`#.744N?[___\/C![\
M__^#?>@"=!N+?0S&!QO&1P$NQD<"1H/'`XE]#,=%Z`(```"+10S&`!O&0`%.
MC4J`BU4,B$H"Z0G___^0@?Y?!```#X?.`0``B?+!Z@2-/)4`4Q<(A?\/A'("
M``!FBU<"B?&#X0\/M\+3^*@!#X1<`@``N`$```#3X$@AT(G"):JJ``#1^('B
M554```'"B="!XLS,``#!^@(E,S,```'0B<$E\'```,'X!('A#P\```'!#[;1
M9L'I"`'*#[<'#[?Z`?AFBY0```(7"(G19L'I"(A-\HA5\[@"````@_C_#X3(
M_/__@_@"#X7W^___BE7RA-(/B+3\__^`??,`#XBJ_/__,<F#?>P%#Y7!C71)
M`CEU%+G^____#XP#^___@WWL!70;BWT,Q@<;QD<!),9'`D&#QP.)?0S'1>P%
M````BTT,B!&*1?.(00'!XQ#!9>@("UWH"UWLBU4(B?&)6BCIO?K__Y"#PB#I
M_/K__X'^I0````^$IP$``('^/B````^$U@$``(V^GP#__X/_/KK_____#X=-
M_/__C49`B$7RZ3W\__^0@?ZE````#X1G`0``@?X^(```#X2G`0``C;Z?`/__
M@_\^N?____\/AT7[__^-3D"("NDV^___@_AO#X1%`0``#XZK````@_AZ#X0`
M`@``@_A_=5G!9>@(BU7L"57HBWWHBW4(B7XH,<F-9?1;7HG(7\G#C88`X/__
M/4\&``!V2XV^`-#__X'_+P(```^'1@$``(GRP>H$C3R5P$07".D._O__@_L$
M#X0<`0``D(/[`W8",=O!XQ#!9>@("UWHBTT("UWLB5DH,<GKGHGQP>D$C3R-
M8$D7".G5_?__BH9@[1@(Z3+]__^X_____^DX_?__@_AK=;>#^P1ULL%EZ`B!
M3>@```8`Z4W___^)]DAUG<%EZ`B!3>@```0`Z3C___^0N/_____I_OO__[C_
M____Z0/^__^-E@#?__^#^B]W$8GPP>@$C3R%+,L7".E1^___C;X`LO__@?^O
M40``#X>M````B?'!Z02-/(V`JQ<(Z2[[___&`ESI\?G__\9%\ESIN/K__X/[
M!@^%'____\%EZ`B!3>@```(`Z;K^__^#^P4/A0;____!9>@(@4WH```!`.FA
M_O__QD7R?NE]^O__Q@)^Z:7Y___!9>@(@4WH```%`.F`_O__C88`LO__/>].
M``!W2XGQP>D$C3R-@"D7".F[_/__C8[PW___@_D/#X?B_O__BH9PS1@(Z0G\
M__^-E@`!__^#^E\/AP+___^)\,'H!(T\A29_%PCI<OK__XV^`&+__X'_KP$`
M`'<JB?+!Z@2-/)4`%1<(Z6+\__^#^P0/A57^___!9>@(@4WH```'`.GP_?__
MC88``?__/>\````/A[+^__^)\<'I!(T\C8#\%@CI)_S__S')@WWL`0^5P8U$
M20$Y112Y_O___P^,V/?__X-][`$/A*+W__^+?0S&!QO&1P$HQD<"2H/'`XE]
M#,=%[`$```#I@O?__S')@WWH`0^5P8UT20,Y=12Y_O___P^,D_?__X-]Z`$/
MA(S[__^+?0S&!QO&1P$NQD<"08/'`XE]#,=%Z`$```#I;/O__S'`@WWL`P^5
MP(UT0`(Y=12Y_O___P^,3O?__X-][`,/A&+\__^+?0S&!QO&1P$DQD<"0H/'
M`XE]#,=%[`,```#I0OS__S')@WWL!@^5P8TTC0(````Y=12Y_O___P^,!O?_
M_X-][`8/A!+Z__^+10S&`!O&0`$DQD`"*,9``T.#P`2)10S'1>P&````Z>[Y
M__]5B>6+10@QTH!X*`"+30QT&X-]$`*Z_O___WX0Q@$;QD$!*,9!`D*Z`P``
M`(G0R<-5B>575E-6BTT0BA&$THM=#'@1#[;"B0.X`0```%M;7E_)PY"`^J`/
MAH,```"`^O]T?H-]%`&X_O___W[@BDD!@/F@=FN`^?]T9HUR@(GPC7F`B$7R
MB?B(1?.-0E\\"'=:C5%?@/I==V6)\@^VPHT40,'B!(GY*<(/MO&-A%;!\___
M/8$%``!W43T^`P``=SYFBX0``(D7"&:#^/UT,+H"````#[?XB=").^EN____
MD%M;7KC_____7\G#C4)0/$>Z_____W::B=#I3____[K_____B=#I0____SWQ
M'P``=^UFBX0`'$D7".NMD%6)Y5=64U"+51"#^G^+?0QW#H@7N`$```!?6UY?
MR<.0@?I?!```#X>X````B=#!Z`2-'(4`4Q<(A=L/A-0```!FBW,"B=&#X0\/
MM\;3^*@!#X2^````N`$```#3X$@A\(G"):JJ``#1^('B554```'"B="!XLS,
M``#!^@(E,S,```'0B<$E\'```,'X!('A#P\```'!#[;Q9L'I"`'.#[?6#[<+
M`=%FBY0)``(7"(G39L'K"(-]%`&(7?*(5?.X_O___P^.4/___XI-\HU:@(/!
M@(@/B%\!7UM>N`(```!?R<.)]HV*`.#__X'Y3P8``'8NC9H`T/__@?LO`@``
M=S&)T,'H!(T<A<!$%PCI)____XUV`%];7KC_____7\G#D(G6P>X$C1RU8$D7
M".D'____C8H`LO__@?GO3@``=A^-F@!B__^!^Z\!``!W(HG0P>@$C1R%`!47
M".G:_O__B=;![@2-'+6`*1<(Z<G^__^-B@`!__^!^>\```!WEXG6P>X$C1RU
M@/P6".FJ_O__B?95B>564XM-$(H!A,"+=0B+70R+511X$0^VP(D#N`$```!;
M7LG#C78`/(!V(O[`=!Y*N/[___]^Z<=%#`(```")30B)VEN)\%[)Z4+'__];
MN/____]>R<.058GE4U"+51"#^G^+70RX_____W<'B!.X`0```(/X_W0'BUW\
MR<.)]H/L"&H"4HM%"(U5^NCOR?__B<*#Q!"#^O^X_____W39@_H"=2"#?10!
MN/[___]^R8I5^H@3BD7[B$,!BUW\N`(```#)P^AVF_[_B?95B>575E.#[!"+
M71"*`X3`BW4,BWT4>!0/ML")!KD!````C67T6UZ)R%_)PU=3B?*+10CHC,;_
M_X/X_UI9B<%UX8H3@/JB#X0$`0``C4I8@/D!#X;X````@/K^N/____\/A.H`
M``"#^/^)P76UBA.-0G\\`P^'5`$``(/_`;'^#XY)`0``BD,!B$7S@^@P/`FQ
M_P^'-@$``(/_`K'^#XXK`0``BD,"/("(1?(/AA@!``#^P`^$$`$``(/_`P^.
M#`$``(I+`XU!T#P)#X?Y````#[;"C02`#[95\XT$0HG"P>(&*<(/MD7RC110
MC122#[;!C8Q03D'F_X'Y^YD```^'Q0```,=%[`````#'1>C!````ZP^)5>B+
M5>@Y5>P/@[X!``"+5>P#5>C1Z@^W!)4B%Q8(.<ASW0^W!)4D%Q8(.<@/AX(`
M``!"B57LZ\J-=@"#_P&X_O___P^."/___XI+`8U!P#P^=A.$R7@*N/_____I
M\/[__X#Y_W3Q#[;2C032C01"C02`A,F-%``/ML$/B$0!``"#Z$"-!`*-B$*@
M__^!^?$<```/A],```"!^2`9``"ZK"```'6R#[?*N`(```")#NF=_O__N?__
M__^#^?\/A4O^__^*`XA%YX/`<#Q3#X<[_O__@_\!L?X/CC#^__^*4P&-0M`\
M";'_#X<@_O__@_\"L?X/CA7^__^*0P(\@(A%YG9*_L!T1H/_`P^._OW__XI+
M`XU9T(#["7<R#[9%YP^V^HT<@(T$7XG'P><&*<</ME7FC1QZC12;#[;!C110
MC;H&7^/_@?___P\`=@JY_____^FW_?__C8H&7^3_B0ZY!````.FE_?__C78`
M@?G%7```=SN!^7`=``"Z^0$```^$(?___RVV?0``@_@,#X?%_O__9HN4"0[;
M%0AF@_K]#X4!____N/_____IH_W__X'Y)%T```^'G?[__V:+E`FT7!4(Z]:#
MZ$'IM_[__XM5[`^WA!(@H14(C00!N00```")!NG3_O__D%6)Y5=64X/L+(M=
M$(/[?XMU#(M]%+C_____=P>('K@!````@_C_=`B-9?1;7E_)PX/L"%=3B?*+
M10CH><;__X/$$(/X_W7A@_\!L/Y^2H'[^0$``+J_J/__="V!^ZP@``"ZXZ+_
M_W0@C8.`T?__@_A/#X>;`0``9HN4&X!#%0AFA=(/A+,!``")T&;!Z`B(!HA6
M`;@"````@_C_=8N#_P.Z_O___P^.T@```(U+@('Y?_\``++_#X?!````,<G'
M1>S!````ZPB)5>P[3>QS*8M%[(T4`='J#[<$E<*B%0@YV'/D#[<,E<2B%0@Y
MV0^'I`$``(U*`>O2#[>4"2"A%0B)V2G1B4W<B<@QTKD*````]_&#PC"(5@.X
MS<S,S/=EW,'J`XE5W(G0L7XQTO?QB57,BE7,@^I_B%8"BT7<T>BZ@R`(@O?B
MB='!Z06)3=")R#'2N0H```#W\8/",(A6`;C-S,S,]V70B574BU74P>H#@^I_
MB470B!:Z!````(/Z_XG0#X6@_O__@_\#L/X/CI7^__^-NP``__^!____#P"P
M_P^'@?[__[C-S,S,]^>)5=2+3=3!Z0.)1="-!(G1X"G'C5<PNWX```")R(A6
M`S'2]_.#ZG_1Z;B#(`B"B%8"]^&)U\'O!;L*````B?@QTO?S@\(PN,W,S,R(
M5@'WYXG0P>@#@^APB`:X!````.D6_O__C9,0T/__@_H/=RAFBY0;@$`5".E5
M_O__@?NN30``NI_^__\/A$W^__^X_____^E3_O__@?L^,```NHFI__\/A#+^
M__^-B\#+__^#^3=W#6:+E!M@-Q4(Z1'^__^!^YXU``"Z6O[__P^$"?[__XV#
M^,G__X/X%W<79HN4&Y`S%0CIZ/W__[K_____Z=S^__^!^Q@Y``"Z8/[__P^$
MUOW__X'[;CD``+)?#X3(_?__C9,XQO__@_H7=PUFBY0;T"L5".FG_?__@?MS
M.@``NF3^__\/A)_]__^!^TX[``"R:`^$D?W__X'[;CP``+)I#X2#_?__@?O@
M/```LFH/A'7]__^!^U9```"R;P^$9_W__X'[7T$``+)P#X19_?__@?LW0P``
MLG(/A$O]__^-BUB\__^#^3=W#6:+E!N0%Q4(Z2K]__^!^]9$``"Z>_[__P^$
M(OW__XV#N+G__X/X'W<-9HN4&Q`2%0CI`?W__XV3X+C__X/Z#W<-9HN4&T`0
M%0CIZ?S__XV+B+C__X/Y%W<-9HN4&U`/%0CIT?S__XV#P+;__X/X=W<-9HN4
M&\`*%0CIN?S__XV3D+/__X/Z-W<-9HN4&^`#%0CIH?S__XV+\++__X/Y#P^'
M/?[__V:+E!N``A4(Z87\__^)]E6)Y5=64X/L'(MU"(M&%`^VV`^VU(G&B5WP
MBTT0BWT4B57LP>X0,=N*$8#Z&W1!@/H.='"`^@\/A9T```#'1?``````04.-
M4P$Y^G[;P>80P67L"`MU[`MU\(M]"+C^____B7<4*=B#Q!Q;7E_)PY"-0P0Y
M^(E%Y'_3BD$!/"0/A5D!``"*00(\*70J/"IU0X!Y`TAU/;X!````@\$$BUWD
MZZ.0BT7L2(/X`7<FQT7P`0```.N.BD$#/$%T#3Q'=1+'1>P"````Z]''1>P!
M````Z\BX_____^N-BT7PA<`/A*,!``"#??`!#X61`@``C4,".?B)1>@/CU#_
M__^$TGC2BED!A-MXRX-][`$/A+@!``!ROX-][`(/A6("``"-2M^`^09V$8#Z
M0G0,C4*\/#FY_____W=UC4O?@/E==V@/ML*-%$#!X@0IP@^V^XV$5\'S__\]
M'0P```^'T0$``#WS`0``=QUFBY0`H*P1"&:#^OUT,P^WPHM=#+D"````B0/K
M*3T[`@``NJ!.``!TY3U"`@``NJM1``!TV3U'`@``NOE2``!TS;G_____@_G_
MN/____\/A*W^__^#^0(/A;T!``#!YA#!9>P("W7L@\X!BTT(BT7HB7$4Z8G^
M__\\3@^%[?[__X7VN/____\/A'3^__].#X6&`0``BE$"A-(/B,[^__^`>0,`
M#XC$_O__C5K?@\$"@/M1#X>U_O__BDD!C4'?/%T/AZ?^__\/MO*-%';!X@0I
M\@^V^8V$5\'S__\]X1T```^'A_[__V:+A`"@L!$(9H/X_0^$=?[__\%E[`@/
MM]"!3>P```$`BT7P"47LBWT,BUWLBTT(BT7DB1>)613IW_W__X32N/____\/
MB-+]__\/ML*+30R#^`J)`70=@_@-=!C!YA#!9>P("W7LBWT(C4,!B7<4Z:C]
M__\Q]L=%[`````#KW8U*WX#Y"'80C4+0/$>Y_____P^'RO[__XU+WX#Y70^'
MN?[__P^VPHT40,'B!"G"#[;[C817P?/__SV!!0``=T8]/@,```^'DO[__V:+
MA```B1<(9H/X_0^$@/[__P^WP.E(_O__D#W9#```=S$]/@P```^'9?[__V:+
ME``$E!$(Z1_^__^0/?$?```/ATS^__]FBX0`'$D7".NXC78`/?(A```/AS3^
M__]FBY0`3&@1".GN_?__Z/>0_O^-=@!5B>575E.#["R+70B+0RB)PP^VR`^V
MU,'K$(-]$'^+?0R)3=2)5="X_____W<+BD40B$78N`$```"#^/]T=D@/A;8#
M``"*5=B$TGAH@WW4`1GVC4X".4T4N/[___]\*HM%U(7`=2Z(%X-]$`IT.H-]
M$`UT-,'C$,%ET`@+7=`+7=2+?0B)7RB)R(UE]%M>7\G#C78`Q@</1\=%U```
M``"(%X-]$`IUQY`QV\=%T`````#KP9"!?1!?!```#X?7````BU40P>H$C325
M`%,7"(7V=!=FBU8"BTT0@^$/#[?"T_BH`0^%ZP```+C_____@_C_#X1A`0``
M@_@"#X7[`@``BDW8A,D/B$T!``"*5=F$THA5SP^(/P$``#'`@WW0`0^5P,'@
M`H-]U`&)P@^$8P$``(/"`SE5%+C^____#XQ'____@WW0`709Q@<;QD<!),9'
M`BG&1P-!@\<$QT70`0```(-]U`%T"\8'#D?'1=0!````B`^*1<^(1P'!9=`(
MP>,0"UW0"UW4BWT(B5\HC67T6UZ)T%_)PY"+31"!Z0`@``"!^4\&```/AI<`
M``"+=1"![@`P``"!_B\"```/ATX!``"+51#!Z@2--)7`1!<(Z?K^__^X`0``
M`-/@2"'0B<(EJJH``-'X@>)550```<*)T('BS,P``,'Z`B4S,P```=")P27P
M<```P?@$@>$/#P```<$/MM%FP>D(`<H/MP8/M_(!\&:+E````A<(B=%FP>D(
MN`(```"(3=B(5=GIK/[__XGVBT40P>@$C32%8$D7".EX_O__B?9J`_]U$(U5
MV(M%".C`P/__@_C_6EET&(/X`P^%@P$``(I%V#P!=!T\`@^$Q0```(UE]%M>
MN/____]?R<.-4`+IF/[__XI-V83)>.2*1=J$P(A%SGC:,<"#?=`"#Y7`P>`"
M@WW4`8G"#X0[`0``@\(#.544N/[___\/C+/]__^#?=`"=!G&!QO&1P$DQD<"
M*<9'`T>#QP3'1=`"````@WW4`70+Q@<.1\=%U`$```"(#XI%SNEG_O__BTT0
M@>D`3@``@?GO3@``#X:=````BW40@>X`G@``@?ZO`0``#X>:````BU40P>H$
MC325`!47".F"_?__BE79A-(/B##___^*3=J$R0^()?___S'`@_L!#Y7`C32%
M!````#EU%+C^____#XP*_?__@_L!=!?&!QO&1P$DQD<"*L9'`TB[`0```(/'
M!,8'&\9'`4Z(5P*(3P/!XQ#!9=`("UW0"UW4BTT(B?")62CIQ_S__XM%$,'H
M!(TTA8`I%PCI^OS__XM-$('I`/\``('Y[P````^'`/W__XM%$,'H!(TTA8#\
M%@CIT_S__^CTC/[_C5`"Z<#^__]5B>6+10@QTH!X*`!T%XM-$(7)NO[___]^
M"XM5#,8"#[H!````B=#)PXUV`%6)Y5=64X/L'(M5"(M"%`^V\`^VW,'H$(EU
M\`^VT(G&B5WLBTT0BWT4B57HP>X(,=N-=@"*$8#Z&W1-@/H.#X2@````@/H/
M#X7Z````QT7P`````$%#C5,!.?I^U\'F&,%EZ!`+=>C!9>P("W7L"W7PBWT(
MN/[___^)=Q0IV(UE]%M>7\G#B?:-0P0Y^(E%X'_+BD$!/"0/A40!``"*00(\
M*715/"IT:3PK#X6-````BD$#/$F^`0```'1D/$J^`@```'1;/$N^`P```'12
M/$R^!````'1)/$UU8KX%````ZSZ)]HM%[$B#^`)W4,=%\`$```#I6____XI!
M`SQ!=#0\1W0G/$5U-<=%[`,```#K#X!Y`TAU)L=%Z`$```")]H/!!(M=X.DK
M____QT7L`@```.OLQT7L`0```.OCN/_____I-____XM%\(7`#X0.`P``@WWP
M`0^%$`4``(U#`CGXB47D#X_S_O__A-)XSXI9`83;>,B#?>P!#X3%`P``<KR#
M?>P"#X1.!```@WWL`P^%UP0``&H"4?]U#/]U".@ILO__B<*#Q!"#^O^X____
M_P^$R/[__X/Z`@^%K00``,'F&,%EZ!`+=>C!9>P("W7L@\X!BTT(BT7DB7$4
MZ9W^__\\3@^$QP(``#Q/#X5,____@_X%#X=R!```_R2U;/@8"(I1`H32#X@Q
M____@'D#``^()____XU:WX/!`H#[10^'&/___XI)`8U!WSQ=#X<*____#[;:
MC11;P>($*=H/MOF-A%?!\___/8H9```/A^K^__]FBX0`8*44"`^VS`^VP`L$
MC4"B%`@]_?\```^$RO[__XM]#,'F&,%EZ!")!PMUZ,%E[`@+=>P+=?"+50B+
M1>")<A3IY/W__XGVBE$"A-(/B);^__^`>0,`#XB,_O__C5K?@\$"@/M##X=]
M_O__BDD!C4'?/%T/AV_^__\/MMJ-%%O!X@0IV@^V^8V$5\'S__\]\Q@```^'
M3_[__V:+A`!`<!0(#[;,#[;`"P2-`&T4".E@____BE$"A-(/B"K^__^`>0,`
M#X@@_O__C5K?@\$"@/M;#X<1_O__BDD!C4'?/%T/AP/^__\/MMJ-%%O!X@0I
MV@^V^8V$5\'S__\]FB$```^'X_W__V:+A`#`*10(#[;,#[;`"P2-("84".GT
M_O__BE$"A-(/B+[]__^`>0,`#XBT_?__C5K?@\$"@/M-#X>E_?__BDD!C4'?
M/%T/AY?]__\/MMJ-%%O!X@0IV@^V^8V$5\'S__\]80L```^'@0(``&:+A`!`
M#Q0(#[;,#[;`"P2-X`L4".F(_O__BE$"A-(/B%+]__^`>0,`#XA(_?__C5K?
M@\$"@/M!=@N-0IP\`P^',OW__XI)`8U9WX#[70^'(_W__P^VPHT40,'B!"G"
M#[;YC817P?/__SV9&```#X<W`@``/0,8```/A_C\__]FBX0`X%$1"`^VS`^V
MP`L$C<!/$0CI"?[__Y"$TKC_____#X@1_/__#[;"BTT,@_@*B0%T)(/X#70?
MP>88P67H$`MUZ,%E[`@+=>R+?0B-0P&)=Q3IX/O__S'VQT7L`````,=%Z```
M``#KSXM]Z(7_N/____\/A+[[__^#?>@!#X6B`0``BE$"A-(/B&C\__^`>0,`
M#XA>_/__C5K?@\$"@/M1#X=/_/__BDD!C4'?/%T/AT'\__\/MMJ-%%O!X@0I
MV@^V^8V$5\'S__\]X1T```^'(?S__V:+A`"@L!$(9H/X_0^$#_S__\'F&`^W
MP(M-#('.```!`(D!Z3[]__^-2M^`^0AV#(U"T#Q'N?____]W2HU+WX#Y77=M
M#[;"C11`P>($*<(/MON-A%?!\___/8$%```/A[,````]/@,``'=&9HN$``")
M%PAF@_C]=#@/M\"+70R)`[D"````B<KI__O__ST[`@``NJ!.``!T=CU"`@``
MNJM1``!T:CU'`@``NOE2``!T7KG_____B<KIS_O__XU*WX#Y!G81@/I"=`R-
M0KP\.;G_____=["-2]^`^5UWTP^VPHT40,'B!"G"#[;[C817P?/__ST=#```
M=W,]\P$``'>,9HN4`*"L$0AF@_K]=*(/M\+I9?___SWQ'P``=Y-FBX0`'$D7
M".E(____/8$<```/A^OZ__]FBY0`W-(3"`^V_@^VP@L$O<#E$PCI_/O__^A/
MAO[_/;T9```/A\'Z__]FBX0`+!P1".G$_?__/=D,``!W%3T^#```#X<R____
M9HN4``24$0CK@#WR(0``#X<=____9HN4`$QH$0CI:/___XUV`%6)Y5=64X/L
M+(MU"(M&*`^VV`^VS,'H$(G&#[;0P>X(@WT0?XM]#(E=T(E-S(E5R+C_____
M=PN*11"(1=BX`0```(/X_P^$A0```$@/A3\'``"*5=B$TGAW@WW0`1G;C4L"
M.4T4N/[___]\,8M%T(7`=36(%X-]$`IT08-]$`UT.\'F&,%ER!`+=<C!9<P(
M"W7,"W70BWT(B7<HB<B-9?1;7E_)PXUV`,8'#T?'1=``````B!>#?1`*=<"0
M,?;'1<P`````QT7(`````.NSB?:!?1!?!```#X?7````BU40P>H$C1R5`%,7
M"(7;=!=FBU,"BTT0@^$/#[?"T_BH`0^%ZP```+C_____@_C_#X1A`0``@_@"
M#X5U!@``BDW8A,D/B$T!``"*7=F$VP^(0@$``#'`@WW,`0^5P,'@`H-]T`&)
MP@^$Z@(``(/"`SE5%+C^____#XQ"____@WW,`709Q@<;QD<!),9'`BG&1P-!
M@\<$QT7,`0```(-]T`%T"\8'#D?'1=`!````B`^(7P'!9<@0P>88P67,"`MU
MR`MUS`MUT(M]"(EW*(UE]%M>B=!?R<.+31"!Z0`@``"!^4\&```/AI<```"+
M71"!ZP`P``"!^R\"```/AYH"``"+51#!Z@2-')7`1!<(Z?K^__^X`0```-/@
M2"'0B<(EJJH``-'X@>)550```<*)T('BS,P``,'Z`B4S,P```=")P27P<```
MP?@$@>$/#P```<$/MM%FP>D(`<H/M\(/MPL!P6:+G`D``A<(B=IFP>H(N`(`
M``"(5=B(7=GIK/[__XGVBT40P>@$C1R%8$D7".EX_O__B?9J`_]U$(U5V(M%
M".BPM?__@_C_6ED/A+4```"#^`,/A?D$``"*1=@\`0^$<@,``#P"#X31`P``
M/`,/A#`$```\!`^$H@(``#P%#X3;!```/`8/A$X%```\!W5UBE79A-)X;HI-
MVH3)>&<QP(/^!0^5P(T<A00````Y712X_O___P^,H_W__X/^!707Q@<;QD<!
M),9'`BO&1P--O@4```"#QP3&!QO&1P%/B%<"B$\#P>88P67($`MUR,%ES`@+
M=<P+=="+30B)V(EQ*.E9_?__@7T07P0```^'ZP```(M5$,'J!(T<E0!3%PB%
MVW079HM3`HM-$(/A#P^WPM/XJ`$/A3L!``"#?1!_C477#X=4`@``@WT0)`^$
M2@(``(-]$'X/A$`"``"*71"(7=>*5=>-2M^`^5T/AT4"``#&1=@JB%79N`(`
M``"#^/\/A$<"``"#^`(/A<0#``"*3=B$R0^(,P(``(I=V83;#X@H`@``,<"#
M?<P##Y7`P>`"@WW0`8G"#X3@`@``@\(#.544N/[___\/C)'\__^#?<P##X1D
M_?__Q@<;QD<!),9'`BG&1P-%@\<$QT7,`P```.E&_?__C5`"Z1']__^+71"!
MZP`@``"!^T\&```/AN@```"+31"!Z0`P``"!^2\"```/A]T"``"+51#!Z@2-
M')7`1!<(Z>;^__^+31"!Z0!.``"!^>].```/AKX```"+71"!ZP">``"!^Z\!
M```/A\@"``"+51#!Z@2-')4`%1<(Z3;\__^X`0```-/@2"'0B<(EJJH``-'X
M@>)550```<*)T('BS,P``,'Z`B4S,P```=")P27P<```P?@$@>$/#P```<$/
MMM%FP>D(`<H/MP,/M](!T&:+E````A<(B=%FP>D(9H/Y*(A-V(A5V0^%E/[_
M_X#Z(`^&B_[__X#Z0`^'@O[__^E`_O__BT40P>@$C1R%8$D7".D3_O__BT40
MP>@$C1R%@"D7".F-^___BE79A-(/B-S]__^*3=J$R0^(T?W__S'`@_X"#Y7`
MC1R%!````#E=%+C^____#XP-^___@_X"=!?&!QO&1P$DQD<"*\9'`TJ^`@``
M`(/'!,8'&\9'`4^(5P*(3P/!YAC!9<@0"W7(P67,"`MUS`MUT(M]"(G8B7<H
MZ</Z__^!?1"E````#X14`0``@7T0/B````^$H@$``&H"_W40C578BT4(Z#BE
M__]96^FP_?__N/_____IB/K__XI-V83)#X@D_?__BEW:A-L/B!G]__\QP(-]
MS`(/E<#!X`*#?=`!B<(/A"X"``"#P@,Y512X_O___P^,2?K__X-]S`(/A!S[
M___&!QO&1P$DQD<"*<9'`T>#QP3'1<P"````Z?[Z__^*5=F$T@^(O?S__XI-
MVH3)#XBR_/__,<"#?<@!#Y7`C1R%!````#E=%+C^____#XSM^?__@WW(`709
MQ@<;QD<!),9'`BK&1P-(@\<$QT7(`0```,8'&\9'`4[IV/[__XU0`ND;_?__
MBE79A-(/B%;\__^*3=J$R0^(2_S__S'`@_X!#Y7`C1R%!````#E=%+C^____
M#XR'^?__@_X!#X3W^___Q@<;QD<!),9'`BO&1P-)O@$```"#QP3IV_O__\8`
M).E=_/__BUT0@>L`3@``@?OO3@``#X>>````BT40P>@$C1R%@"D7".GT^___
MBTT0@>D`_P``@?GO````#X>&^?__BT40P>@$C1R%@/P6".E9^?__Z&I^_O_&
M`'[I`OS__XI5V832#XB;^___BDW:A,D/B)#[__\QP(/^`P^5P(T<A00````Y
M712X_O___P^,S/C__X/^`P^$//O__\8'&\9'`23&1P(KQD<#2[X#````@\<$
MZ2#[__^+31"!Z0">``"!^:\!``!W<HM5$,'J!(T<E0`5%PCI1?O__XI5V832
M#X@@^___BDW:A,D/B!7[__\QP(/^!`^5P(T<A00````Y712X_O___P^,4?C_
M_X/^!`^$5_W__\8'&\9'`23&1P(KQD<#3+X$````@\<$Z3O]__^-4`+IS?W_
M_XM=$('K`/\``('[[P````^'Z_K__XM%$,'H!(T<A8#\%@CIOOK__U6)Y8M%
M"#'2@'@H`'07BTT0A<FZ_O___WX+BU4,Q@(/N@$```")T,G#C78`58GE5U93
M48M%"(M-$(M]%(MP%#';C78`BA&`^GYU6HU#`CG'<B:%]HI1`74S@/I^#X3*
M````@/I[=#&`^@IU,HU0`8/!`CG7B<-SS(M%"(EP%+C^____*=A:6UY?R<.0
M@/I]=0TQ]NO7C78`9KX!`.O.N/_____KX(7V=1</MOJ+=0R+30B-0P&)/L=!
M%`````#KQ8U#`CG'B47P<JZ-6M^`^PAV!XU"T#Q'=\6*20&-6=^`^UUWN@^V
MPHT40,'B!"G"#[;YC817P?/__SV!!0``=T0]/@,``'>79HN$``")%PAF@_C]
M=(D/M_B+70R+30B+1?").XEQ%.E:____D(M5#(MU",<"?@```,=&%`````#I
M0?___SWQ'P``#X=/____9HN$`!Q)%PCKMHUV`%6)Y5=64U:+51"+10B#^G^+
M>"AW-X32B%7R>#"#_P$9VX/C_HU+`SE-%+C^____?!6%_P^%.P$``(M%#(@0
MBU4(B7HHB<A;6UY?R<.!^E\$```/A_````")T<'I!(T<C0!3%PB%VP^$-`$`
M`&:+<P*)T8/A#P^WQM/XJ`$/A!X!``"X`0```-/@2"'PB<(EJJH``-'X@>)5
M50```<*)T('BS,P``,'Z`B4S,P```=")P27P<```@>$/#P``P?@$`<$/MO%F
MP>D(`<X/M]8/MPL!T6:+E`D``A<(B=-FP>L(A-N(7?*(5?.(V0^(L````(32
M#XBH````@_\!&=N#XP*-4P(Y512X_O___P^,-?___X7_=12+=0S&!G[&1@%[
M@\8"B74,9K\!`(MU#(@.BD7SBUT,B$,!BTT(B7DH6UM>B=!?R<.-=@"-F@#@
M__^!^T\&``!V-HV"`-#__STO`@``=TB)T<'I!(T<C<!$%PCI\/[__XMU#,8&
M?L9&`7TQ_X/&`HEU#.FN_O__D(G6P>X$C1RU8$D7"(7;#X7,_O__6UM>N/__
M__]?R<.-F@"R__^!^^].``!V'HV"`&+__SVO`0``=R*)T<'I!(T<C0`5%PCI
MC?[__XG6P>X$C1RU@"D7".E\_O__C9H``?__@?OO````=ZJ)UL'N!(T<M8#\
M%@CI7?[__Y!5B>6+10B+0"@QTH7`BTT,=!>#?1`!NO[___]^#,8!?L9!`7VZ
M`@```(G0R<.-=@!5B>575E.#[`R+31"*$832BW4,BUT4>!0/ML*)!K@!````
M@\0,6UY?R<.)]H#ZH`^&EP```(#Z_P^$C@```$NX_O___W[<BD$!/*`/AM<`
M```\_P^$SP```(U8@(U"7XU*@#P&B$WRB%WS#X?%````C5/?@/I=#X=&!```
M#[;!C3Q`P><$*<</MLN-A'G!\___/1T,```/AS($```]\P$```^'ZP,``&:+
ME`"@K!$(9H/Z_0^$"00```^WVKH"````B=")'NE8____B?:`^HYU5X/[`[C^
M____#XY#____BED!C5-?@/H/=SZ*00(\H(I1`W8T//]T,(#ZH'8K@/K_=":-
M2("-0H"(1?$/ML,MH````(/X#XA-\(U]\'<*_R2%A/@8"(UV`(/$#%M>N/__
M__]?R<.`^4(/A#+___^-0CP\.;K_____#X8B____B=#IS?[__XU!WSQ,NO__
M__]W5HI?`8U3WX#Z70^'&`,```^VP8T,0,'A!"G!#[;[C81/P?/__ST`'```
M#X?X`@``9HN4`(#<%`@/MMX/ML(+!)V`V!0(/?W_```/A-@"``")!KH"````
M@_K_N/____\/A%W^__^#^@*X!`````^$3_[__^CT=_[_C4'?/$6Z_____W?3
MBE\!C5/?@/I=#X>5`@``#[;!C0Q`P>$$*<$/MON-A$_!\___/8H9```/AW4"
M``!FBY0`8*44"`^VW@^VP@L$G4"B%`CI>/___XU!WSQ#NO____\/AWK___^*
M7P&-4]^`^ET/ASP"```/ML&-#$#!X00IP0^V^XV$3\'S__\]\Q@```^''`(`
M`&:+E`!`<!0(#[;>#[;""P2=`&T4".D?____C5G?@/M;NO____\/AR#___^*
M7P&-4]^`^ET/A^(!```/ML&-#$#!X00IP0^V^XV$3\'S__\]FB$```^'P@$`
M`&:+E`#`*10(#[;>#[;""P2=("84".G%_O__C4'?/$VZ_____P^'Q_[__XI?
M`8U3WX#Z70^'B0$```^VP8T\0,'G!"G'#[;+C81YP?/__SUA"P``#X<5`@``
M9HN4`$`/%`@/MMX/ML(+!)W@"Q0(Z6S^__^-6=^`^T%V$(U!G#P#NO____\/
MAV;^__^*7P&-4]^`^ET/AR@!```/ML&-/$#!YP0IQP^VRXV$><'S__\]F1@`
M``^'W`$``#T#&```#X?]````9HN$`.!1$0@/MMP/ML`+!)W`3Q$(Z0#^__^-
M6=^`^U&Z_____P^'`?[__XI?`8U3WX#Z70^'PP````^VP8T\0,'G!"G'#[;+
MC81YP?/__SWA'0``#X>C````9HN$`*"P$0AF@_C]#X21````#[?`Z;']__^-
M6=^`^P9V%8#Y0G00C4&\/#FZ_____P^'F_W__XI?`8U3WX#Z77=A#[;!C3Q`
MP><$*<</MLN-A'G!\___/1T,```/A[8````]\P$``'<69HN4`*"L$0AF@_K]
M="P/M\+I3/W__ST[`@``NJ!.``!T[#U"`@``NJM1``!TX#U'`@``NOE2``!T
MU+K_____Z27]__\].P(``+J@3@``#X07_/__/4("``"ZJU$```^$!_S__SU'
M`@``NOE2```/A/?[__^Z_____XG0Z53[__\]V0P``'<4/3X,``!WYF:+E``$
ME!$(Z<;[__\]\B$``'?29HN4`$QH$0CILOO__SW9#```=Q@]/@P```^'>?__
M_V:+E``$E!$(Z3K___\]\B$```^'8?___V:+E`!,:!$(Z2+___\]@1P```^'
M2?___V:+A`#<TA,(#[;,#[;`"P2-P.43".E,_/__C78`/;T9```/AR'___]F
MBX0`+!P1".D?_O__58GE5E.#[!"+31"#^7^+70R+=12X_____W<'B`NX`0``
M`(/X_W0)C67X6U[)PXGV:@-1C57HBT4(Z$ZF__^)PH/Z_UA9N/____]TVX/Z
M`W54BE7H@/H!="R#_@.X_O___W[$C4J@Q@..B$L!BD7I@\"`B$,"BDWJ@\&`
MN`0```"(2P/KHDZX_O___WZ:BE7I@\*`B!.*1>J#P("(0P&X`@```.N"Z*YS
M_O^)]E6)Y5=64XM-$(H1A-*+?0QX$@^VPHD'N`$```!;7E_)PXUV`(#ZH`^&
ME0```(#Z_P^$C````(-]%`&X_O___W[;BDD!C7'`B?.`^SYV"H#YH'9O@/G_
M=&J-0E\\)G8,C4(W/#"[_____W=0B?.`^SYW6@^VTHTTDL'F`RG6#[;9@/F@
MC12RC4.>=P.-0\"-A`)#G?__/8<8``!W0SWH%P``=S-FBX0`0'D3"&:#^/UT
M)0^WR(D/NP(```")V%M>7\G#6UZX_____U_)PX#YH'8%@/G_=9R[_____XG8
MZ]X]:S8``'?P9HN$`%`,$PCKNU6)Y5-3BU40@_I_BUT,N/____]W!X@3N`$`
M``"#^/]T!XM=_,G#B?9J`E*+10B-5?KH>J;__XG"@_K_6%FX_____W3=@_H"
M=2"#?10!N/[___]^S8I5^H@3BD7[B$,!BUW\N`(```#)P^A.<O[_B?95B>57
M5E.+=1"*#H3)BWT,>!(/ML&)![@!````6UY?R<.-=@"`^:!V<X#Y_W1N@WT4
M`;C^____?N.*7@&-4\"`^CYV9X#[H'==C78`@/GY=4N`/OEU1HI6`8U*P(#Y
M/G8*@/J@=C:`^O]T,8#ZH`^VP@^&.`$``(/H8HV0^#4``(/H=(/X*'<49HN$
M$HAX$PAF@_C]#X6=````B?:X_____UM>7\G#@/O_=*&`^:(/AI(```"`^<8/
MA+T```"`^<=TBHU17X#Z)G8+C4$W/#`/AW?___^-4\"`^CYV$H#[H`^&9O__
M_X#[_P^$7?___P^VT8T$DL'@`RG0@/N@C12"#[;##X:>````@^ABC80"0YW_
M_SV'&```=W@]Z!<```^')____V:+A`!`>1,(9H/X_0^$%?___P^WV(D?6UZX
M`@```%_)PP^VT8T$DL'@`RG0@/N@C12"#[;#=C&#Z&*-A`)#G?__9HN$`.#B
M$PAF@_C]#X0\____Z[V`^Z`/AC____^X_____^D4____@^A`Z\T]:S8```^'
MK_[__V:+A`!0#!,(ZX:#Z$#I7?___X/H0.G#_O__D%6)Y5=64X/L#(M=$(/[
M?XM]#+C_____=P>('[@!````@_C_B<)T#8UE]%M>B=!?R<.-=@")V,'H"(/X
M(@^$R@```'=`@_@"#X2U`@``#X9$`0``@_@@#X7H````@?LG(```#X1L`P``
M@?LB(```=`R!^SX@```/A<@```"Z_____^NDD(/X)@^$C@(```^&*0$``#W^
M````#X3*`@``/?\````/A9L```"!^P__```/A#X#``"!^SS_```/A%X#``"!
M^U[_```/A%\#``"!^^#_```/A(,#``"!^^'_```/A(0#``"!^^/_```/A(4#
M``"!^^7_```/A(8#``"Z_____X'[9/\``.LQB?:!^Q4B```/A!H"``"!^Y4B
M```/A+,```"!^YDB```/A"L"``"Z_____X'[/"(```^$YO[__XUV`&H"4XU5
M\HM%".@VH___@_C_7EH/A(L```"#^`(/A8@"``"*1?(\QG1T/,=T=X-]%`&Z
M_O___P^.I_[__X@'BEWSB%\!C67T6UZZ`@```(G07\G#A<!UJ8'[KP````^$
M`0(``(V#7O___X/X`KK_____=XWI:_[__X/X)76#@?MT)0``#X5W____QD7R
MH<9%\UKKC\9%\J'&1?/RZX6`??.@=HJ0C9,`V___@?J?````#X?*````B=G!
MZ02--(U@V1,(A?8/A*\```!FBU8"B=F#X0\/M\+3^*@!#X29````N`$```#3
MX$@AT(G"):JJ``#1^('B554```'"B=&!XLS,``#!^@*!X3,S```!T8G+@>'P
M<```P?D$@>,/#P```<L/ML-FP>L(`=@/MPX/M_`!\6:+G`G`X!,(B=IFP>H(
MB%7RB%WSN`(```"#^/^Z_____P^$BOW__X/X`@^%2`$``(-]%`&Z_O___P^.
M<OW__XI%\NG#_O__N/_____KRXVS`*C__X'^OP```'<1B=C!Z`2--(5@S!,(
MZ2/___^-DP"F__^!^O\```!W3HG9P>D$C32-H,L3".D$____@?O-`@``#X4V
M_O__QD7RH<9%\\7I2_[__X'["28```^$5?W__X'[028``.E$_?__QD7RHL9%
M\T'I)_[__XVS`*#__X/^7W<_B=C!Z`2--(4$RA,(Z:O^___&1?*AQD7S\^G^
M_?__@?M1_@``='&!^VC^```/A<C]___&1?*BQD7S0NG=_?__C9,`B/__@?J/
M````=QZ)V<'I!(TTC>##$PCI7O[__\9%\J'&1?/"Z;']__^-LP"$__^!_J\`
M``!W/8G8P>@$C32%H,(3".DR_O__QD7RH<9%\T7IA?W__\9%\J'&1?-.Z7C]
M___HH6S^_\9%\J'&1?/^Z6;]__^-DP!X__^!^L\```!W*XG9P>D$C32-8+\3
M".GG_?__QD7RHL9%\T#I.OW__\9%\J'&1?/CZ2W]__^-LP!N__^!_K\````/
MAW+^__^)V,'H!(TTA:"\$PCIJOW__\9%\J+&1?-&Z?W\___&1?*BQD7S1^GP
M_/__QD7RH<9%\\/IX_S__\9%\J+&1?-$Z=;\__]5B>575E-3BTT0BA&$THMU
M#(M]%'@2#[;"B0:X`0```%E;7E_)PXGV@/J@#X:G````@/K_#X2>````@_\!
MN/[___]^W(I9`8U#P#P^B$7S#X<Z`0``@/K&#X2#`0``@/K'='6-0E\\)G8'
MC4(W/#!W8X!]\SYV"H#[H'98@/O_=%,/MM*-!)+!X`,IT(#[H(T4@@^VPP^&
M;`$``(/H8HV$`D.=__\]AQ@```^'/P$``#WH%P``=QUFBX0`0'D3"&:#^/UT
M#P^WR+@"````B0[I3/___XH1B?:-6GB`^P-V)(U"<SP3=AV-6CJ`^P)V%8#Z
M^`^&C0```(#Z_P^$A````(UV`$^X_O___P^.$/___XI)`8U!P#P^=V$/MOJ-
M'+_!XP,I^X#YH(T4GP^VP0^&B@```(/H8HV$`H"Q__\]^`<``'=A/5H'``!W
M.6:+E`#PT1,(B=!FP>@&@^(_#[?("Q2-X,P3"('Z_?\``'06N`(```")%NFE
M_O__@/F@=@6`^?]UE;C_____Z9'^__^`^Z`/AD#___^`^_\/A;3^___I,O__
M_SWM*@``=QD]/!0``'?19HN4`$ZD$PCKEH/H0.EQ____/31*``!W0CW$+```
M=[%FBY0`I%H3".ES____@/N@#X?N_O__Z73^__\]:S8```^'VO[__V:+A`!0
M#!,(Z;C^__^#Z$#IC_[__SWB30``#X=K____9HN4`+84$PCI+?___Y!5B>57
M5E.#[`R+71"#^W^+?0R+=12X_____W<'B!^X`0```(/X_W0(C67T6UY?R<-J
M`E.-5?*+10CHDIW__X/X_UI9=#.#^`(/A7(!``"*5?*`^L9T'(#ZQW0=3KC^
M____?L6(%XI%\XA'`;@"````Z[:`??.@=N-.N/[___]^J('[SP(```^'GP``
M`(G:P>H$C325H#P3"(7V#X2!````9HM6`HG9@^$/#[?"T_BH`71ON`$```#3
MX$@AT(G"):JJ``#1^('B554```'"B=&!XLS,``#!^@*!X3,S```!T8G+@>'P
M<```P?D$@>,/#P```<L/ML-FP>L(`=@/MPX/M_`!\6:+G`E@SA((B=IFP>H(
MN`(```"(%XA?`>D'____N/_____I_?[__XV+`/S__X/Y7W<1B=C!Z`2--(5T
M.Q,(Z5'___^-LP#B__^!_L\```!W$8G:P>H$C325P#03".DR____C8L`W___
M@?GO````=Q&)V,'H!(TTA<`S$PCI$____XVS`-S__X'^?P$``'<1B=K!Z@2-
M-)6@,A,(Z?3^__^-BP#9__^#^3]W%HG8P>@$C32%P#$3".G8_O__Z!=H_O^-
MLP#2__^!_O\"``!W$8G:P>H$C3250"\3".FT_O__C8L`SO__@_D_=Q&)V,'H
M!(TTA2PN$PCIF/[__XVS`,S__X'^KVL``'<1B=K!Z@2--)7`$A,(Z7G^__^-
MBP`@__^!^;\.``!W$8G8P>@$C32%`.02".E:_O__C;,`#?__@?[O!```=Q&)
MVL'J!(TTE0#>$@CI._[__XV+``'__X'Y[P```'<1B=C!Z`2--(7`VA((Z1S^
M__^-LP``_O^!_M\W``!W$8G:P>H$C325@(P2".G]_?__C8L`QOW_@?E/1```
M=Q&)V,'H!(TTA>!L$@CIWOW__XVS`(#]_X'^[P8``'<1B=K!Z@2--)6@61((
MZ;_]__^-BP!X_?^!^=\&``!W$8G8P>@$C32%X%42".F@_?__C;,`</W_@?[O
M`0``=Q&)VL'J!(TTE6!3$@CI@?W__XV+`&S]_X'Y[P$``'<1B=C!Z`2--(7@
M41((Z6+]__^-LP!H_?^!_I\!``!W$8G:P>H$C3258%`2".E#_?__C8L`9?W_
M@?FO"```=Q&)V,'H!(TTA6!-$@CI)/W__XVS`%O]_X'^KP$``'<1B=K!Z@2-
M-)5@2A((Z07]__^-BP`(_?^!^=\!```/AWS]__^)V,'H!(TTA2`U$@CIXOS_
M_XGV58GE5E-6BTT0BA&$THM=#'@2#[;"B0.X`0```%M;7LG#C78`@/J@=G^`
M^O]T>H-]%`&X_O___W[CBD$!/*!V:#S_=&2-<H")\8A-]HU(@(U"7SP+B$WW
M=UF-4=^`^EUW:(GR#[;"C11`P>($*<(/MO&-A%;!\___/8$%``!W4SU:!```
M=T-FBX0`(-46"&:#^/UT-0^WR+H"````B0N)T%M;7LG#C78`6UNX_____U[)
MPXU"4#P8=J"-0C8\,[K_____=I2)T.O7NO____^)T.O./0T/``!W$3VO#@``
M=^EFBX0`O+<6".ND/24B``!WV&:+A`!D?A8(ZY.058GE4U"+51"#^G^+70RX
M_____W<'B!.X`0```(/X_W0'BUW\R<.)]FH"4HU%^E#_=0CH.9O__XG"@\00
M@_K_N/____]TVX/Z`G4F@WT4`;C^____?LN*3?J#P8"("XI5^X/"@(A3`;@"
M````BUW\R</HLF3^_XGV58GE5E-1BTT0BA&$THMU#(M=%'@/#[;"B0:X`0``
M`%I;7LG#C4)_/!\/AK$```"`^J`/AKD!``"`^O\/A+`!``!+N/[___]^UHI)
M`8#YH`^'"@$``(U"7SPEN_____]W=XU9OX#[&783C4&?/!EV#(U9?X#['P^'
MB`$```^VPHV07____X#Y@`^VP8U8LW<+@/E@C5BY=P.-6+^-#)4`````C001
MC02"C12#@?HU#```#X=-`0``@_LIB<AV`XU!`@^WB(!*$@@/MI)`/A((`=&)
M#KL"````B=A:6U[)PY!+N/[___\/CC/___^*20&-6;^`^QD/A]T````/MMH/
MML&`^8"-DW____^-6+-W"X#Y8(U8N7<#C5B_C0R5`````(T$$8T$0HT$PHT4
M0X'Z/Q8```^'N````(/[6(G(=@.-00(/MXC`/1((#[:2@"<2"`'1B0Y:6[@"
M````7LG#@/G_#X2)````C4)?@\&`C5J`/`N(7?:(3?=V$XU"4#P8=@R-0C8\
M,[K_____=T.-4=^`^EUW90^VPXT40,'B!"G"#[;9C813P?/__SV!!0``=UX]
M6@0``'="9HN$`"#5%@AF@_C]=#0/M\B)#KH"````B=!:6U[)PXU!GSP9#X88
M____@/F`=@F`^?\/A0K___]:6[C_____7LG#NO____^)T.O/N_____^)V.G*
M_O__/0T/``!W$3VO#@``=]UFBX0`O+<6".N9/24B``!WS&:+A`!D?A8(ZXB-
M=@!5B>575E.#[`R+71"#^W^+?0R+=12X_____W<'B!^X`0```(/X_W0(C67T
M6UY?R<-J`E.-1?)0_W4(Z'V8__^#Q!"#^/]T*8/X`@^%J@$``$ZX_O___W[0
MBE7R@\*`B!>*1?.#P("(1P&X`@```.NXC9,`5/__@?JC*P``N/____]WI8'[
MI,@```^'L````$ZP_GZ4@?JO'```#X=0`0``B=G!Z02--(T`````9HN6@N01
M"(G9@^$/#[?"T_BH`0^$*P$``+@!````T^!((=")PB6JJ@``T?B!XE55```!
MPHG3@>+,S```P?H"@>,S,P```=.)V8'C\'```,'[!('A#P\```'9#[;!9L'I
M"`'(9@.&@.01"(G"9L'J!P^W\`^WVF8/MH;@^!$(9@.$&R`/$@B)P6;!Z0B(
M#^DG____3KC^____#X[=_O__C;,`./__@?ZO#P``#X>3````B=G!Z02--(T`
M````9HN6@O$1"(G9@^$/#[?"T_BH`71RN`$```#3X$@AT(G"):JJ``#1^('B
M554```'"B=.!XLS,``#!^@*!XS,S```!TXG9@>/P<```P?L$@>$/#P```=D/
MML%FP>D(`<AF`X:`\1$(B<)FP>H&#[?P#[?:9@^VAL`6$@AF`X0;`",2".E"
M____N/_____I+O[__^AU8/[_D%6)Y5=64X/L#(M5$(H*A,F+?0R+711X((#Y
M7'03#[;!B0>X`0```(/$#%M>7\G#D,<'J2```.OJ@/G7#X?#````C4%\/$^^
M_____P^'J0```$MFOO[_#XZ>````BE(!C5J_@/L]=A*`^H`/AK`!``"`^O\/
MA*<!```/ML'!X`@/MM()T(G#P>L*@^,?B<+!Z@6#X!\/OHO`^!$(@^(?B47H
MA<D/OH"`^!$(#[ZRH/@1"(E%[`^(9@$``(7V#XA>`0``A<`/B%8!``"%R0^%
MA@$``(7V#X6:`0``BTWHBH%@^!$(//T/A#4!```/MMB!PS`Q``")'V:^`@")
M\(/$#%M>7\G#C4$G/`5V"XU!(#P9#X?;````2[C^____#XX%____BE(!C5K/
M@/M-=A*`^I`/AKL```"`^O\/A+(```"`^=H/A*(```"`^=^-7`EI#X:F````
M@/J0C4+/=@.-0KT\70^VTP^&K0```(/"(CQ=B%7RC5WR#X>4````@\`AC4K?
M@/D+B$,!=A.-0M`\&'8,C4*V/#.Y_____W=&BDL!C5G?@/M==UP/ML*-%$#!
MX@0IP@^V\8V$5L'S__\]@04``'=H/5H$``!W.6:+A``@U18(9H/X_70K#[?(
MB0^Y`@```(G(Z3W^__^-0E\\,G<*N/_____I+/[__XU<"4[I4?___[G_____
MB<CI%_[__X/H/>EG____@\(AZ4[___^^_____XGPZ=#^__\]#0\``'<1/:\.
M``!WRF:+A`"\MQ8(ZX\])2(``'>Y9HN$`&1^%@CI>____X7V=4.+1>R%P'6]
MBH/@4`T(//UTLSS_Z7'^__^+=>R%]G6EBH+`4`T(//UTFSS_=)</ML`%,#$`
M`+X"````B0>)\.E=_O__C1R)C029`?"-#,4`````*<&+5>R-A(J8J0``Z]55
MB>575E.#[!R+71"#^W]W%X/[7'02BT4,B!BX`0```(UE]%M>7\G#@?NI(```
M#X3@````C8O/SO__@_DR=U%FBY0;_NX,"(G19L'I"(A-[HA5[[@"````@_C_
M#X3#````@_@"#X5!`0``@WT4`;C^____?A.*7>Z+50R(&HI%[XA"`;@"````
MC67T6UY?R<.-BP!4__^!^:,K``"X_____W>UOAP```")R#'2]_;!Z0*X)4F2
M)(G6]^&)5>2_%0```(G0,=+W][F'81B&BT7DB=?WX2E5Y-%MY(E5W(E%V(M%
MY`-%W,'H!(J(,5$-"(/)(`^^P0^^EQQ1#0C!X`4)T,'@!68/OI8`40T("<+I
M-/___Y"+50RX`0```,8"7.G\_O__:@)3C7WN5_]U".C-DO__@\00@_C_=#"#
M^`)U:X-]%`&X_O___P^..?___XI5[HU"WSP+BDWO=@B-6K:`^S-W!XU!WSQ=
M=@JX_____^D3____@/I)=S8/ML(%D0$```^VT:@!C4K?=`.-2CW1Z(C*BW4,
M@/E-B`:-0C%V`XU"0XM5#.G5_O__Z`A<_O\/ML(%=@$``.O(B?95B>575E.#
M[`R+50B+0A2)PXM-$`^V^,'K"#'VBA&`^AMT,8#Z#G14@/H/=6(Q_T%&C48!
M.T44?N/!XP@)^XM5"+C^____B5H4*?"#Q`Q;7E_)PY"-1@0[111_W8!Y`21U
M)H!Y`BEU((!Y`T-U&KL!````@\$$B<;KMXGV@_L!=0>_`0```.NGN/_____K
MO(7_#X29````@_\!#X7G````C48"B47PBT44.47P?XM+#X72````A-)XSXI)
M`83)>,B-6M^`^PMV#XU"T#P8=@B-6K:`^S-WL8U!WSQ==ZH/MOJ-%'_!X@0I
M^@^V\8V$5L'S__\]@04``'=</5H$``!WAV:+A``@U18(9H/X_0^$=?___P^W
MP(M=#(D#BTT(BT7PQT$4`0$``.D>____C78`A-*X_____P^(#O___P^VPHM]
M#(D'P>,(BTT(C48!B5D4Z?7^__\]#0\``'<5/:\.```/AR#___]FBX0`O+<6
M".N7/24B```/APO___]FBX0`9'X6".N"Z'!:_O]5B>575E.#[`R+50B+0BB)
MPXM-$`^V^,'K"(/Y?XMU#+C_____=PB(3?*X`0```(/X_W1H2`^%!P$``(I%
M\H3`B$7K>%>#_P$9P(/``HE%[(M5[#E5%+C^____?"&%_W4GBE7K@_D*B!9T
M+8/Y#70HP>,("?N+30B)62B+1>R-9?1;7E_)PXGVQ@8/,?]&BE7K@_D*B!9U
MTS';Z]1J`E&-1?)0_W4(Z`V0__^#Q!"#^/]T?8/X`@^%A@```(I-\H3)>&V`
M??,`>&<QP(/[`0^5P,'@`H/_`8G"=&*#P@,Y512X_O___WR6@_L!=!?&!AO&
M1@$DQD8"*<9&`T.[`0```(/&!(/_`70)Q@8.OP$```!&B`Z*3?.(3@'!XPB+
M=0@)^XE>*(UE]%M>B=!?R<.0C67T6UZX_____U_)PXU0`NN<Z"E9_O^058GE
MBT4(,=*`>"@`=!>+31"%R;K^____?@N+50S&`@^Z`0```(G0R<.-=@!5B>6+
M11"*`(3`BTT,>`T/ML")`;@!````R<.0#[;`9HN4`&#V$0AF@_K]N/____]T
MYP^WPNO;D%6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X5W<5BH)@
M]A$(A,!T/X@!N`$```#KWXGVC8(P^O__@_@?=B&!^A<@``"P\G3@C8(`V___
M/:<```!W$HJ"(-$1".O'B?:*@A#Q$0CKO;C_____R<.058GEBT40B@`\GXM5
M#'8=/*]W%0^VR`^WA`G`]!$(B0+)N`$```##D#S/=PP/ML")`LFX`0```,,\
MWW<-#[;`#[>$`$#T$0CKYCSO=M\/ML@/MX0)X/,1".O5B?95B>6+51"!^J<`
M``"+30QW"X@1N`$```#)PXGVC8)8____@_A7=Q6*@KCT$0B$P'0IB`&X`0``
M`.O>B?:-@J#^__^#^!]W"8J"X/,1".O>D('Z/B```+"O=->X_____\G#C78`
M58GEBT40B@"$P(M-#'@-#[;`B0&X`0```,G#D`^VP&:+E`!`\Q$(9H/Z_;C_
M____=.</M\+KVY!5B>6+51"#^G^+30QW"H@1N`$```#)PY"-@GC___^#^&]W
M%8J"./,1"(3`=%"(`;@!````Z]^)]HV"^/G__X/X9W85C8(`V___@_@?=Q**
M@B#.$0CKTXGVBH(X[1$(Z\F!^J`E``"PB73#C8(0!___@_@/=P^*@B#Z$`CK
MK+C_____R<.-@I`!__\]CP```'?LBH(0]!`(ZY"-=@!5B>6+11"*`#R?BU4,
M=PT/ML")`LFX`0```,.0#[;(#[>$"8#P$0B)`LFX`0```,-5B>6+51"!^I\`
M``"+30QW"X@1N`$```#)PXGVC8)@____@_@/=Q6*@OCP$0B$P'0MB`&X`0``
M`.O>B?:-@@#\__\]EP```'<+BH(`[1$(Z]R-=@"!^A8A``"P\'33N/_____)
MPXUV`%6)Y8M%$(H`/)^+50QW#0^VP(D"R;@!````PY`/ML@/MX0)H.P1"(D"
MR;@!````PU6)Y8M5$('ZIP```(M-#'<+B!&X`0```,G#B?:-@EC___\]#P$`
M`'<3BH(8[!$(A,!T)X@!N`$```#KW(V"`/W__X/X)W<)BH*`Z1$(Z^"0@?JK
M(```L/YTV;C_____R<.-=@!5B>6+11"*`(3`BTT,>!$/ML")`;H!````B=#)
MPXUV`#R?NO____]V\`^VT`^WA!(`[Q$(Z]R)]E6)Y8M5$(/Z?XM-#'<*B!&X
M`0```,G#D(V"8/___X/X#W<5BH*`[Q$(A,!T.H@!N`$```#KWXGVC8*X\?__
M@_@#=A6-@@#R__^#^%]W#XJ"P.`1".O3B?:-0J#KS('ZK"```+#>=,:X____
M_\G#B?95B>6+11!3B@"$P(M-#'@0#[;`B0&Z`0```(G06\G#D`^VV&:+E!L@
M[A$(9H/Z_70'#[?"B0'KW3R?NO____]WV;H!````B1GKT(GV58GEBU40@_I_
MBTT,=PJ($;@!````R<.0C4*`@_@?=CB!^J````"PH'0BC8(`\O__@_A?=C.-
M@O#?__^#^!=W,(J"D,X1"(GVA,!T+H@!N`$```#KP(UV`&:#O!(@[A$(_8C0
M=;OKX9"*@L#@$0CKV('ZK"```+"`=-*X_____\G#C78`58GEBT40B@`\GXM5
M#'<-#[;`B0+)N`$```##D#RD=!`/ML@/MX0)H.P1".OEC78`QP*L(```N`$`
M``#)PXUV`%6)Y8M5$('ZGP```(M-#'9'@?JG````=C>!^M````!T-XV"6/__
M_ST/`0``=C:-@@#]__^#^"=W,XJ"@.D1")"$P'1%B`&X`0```)#)PXGV@?JD
M````=,&X`0```(@1Z^N-=@"*@ACL$0CKU('Z/B```+"O=,Z-@EC?__^#^`=W
M"(J"O,L1".NWN/_____)PU6)Y5=64U&+31"*`83`BW4,>!4/ML")!KH!````
MB=!:6UY?R<.-=@"-6%^`^U-W?(-]%`&Z_O___W[BBE$!@/J@=FF`^O]T9(UX
M@(GYB$WR@/L'C4J`B$WQB$WS=UN-6E^`^UUW9HGY#[;!C11`P>($*<(/MGWQ
MC817P?/__SV!!0``=U,]L0(``'=`9HN$`""%&`AF@_C]=#*Y`@````^WV(G*
MB1[I<O___Y"Z_____XG06EM>7\G#@\!0/$2Y_____W:9B<KI4?___[G_____
MB<KI1?___SU_'@``=^UFBX0`'$@8".NKC78`58GE4U.+51"#^G^+70RX____
M_W<'B!.X`0```(/X_W0'BUW\R<.)]FH"4HU%^E#_=0CH<7'__XG"@\00@_K_
MN/____]TVX/Z`G4F@WT4`;C^____?LN*3?J#P8"("XI5^X/"@(A3`;@"````
MBUW\R</HYE'^_XGV58GE5U93@^P(BTT0BA&$THM]#(MU%'@4#[;"B0>X`0``
M`(/$"%M>7\G#B?:`^J`/AJ,```"`^O\/A)H```"#_@&X_O___W[:@/K"BED!
M#X09`0``@/N@=G>`^_]T<HU"7X/#@(U*@#P&B$WPB%WQ=A6`^4)T$(U"/#PY
MNO____\/AZ@```"-4]^`^ET/A\\````/ML&--$#!Y@0IQ@^VRXV$<<'S__\]
M'0P```^'>@$``#WS`0``=WQFBY0`H*P1"&:#^OT/A)8````/M\+K5XU+WX#Y
M778-@\0(6UZX_____U_)PXU"7XU*@#Q1B$WNB%WONO____]W-`^VP8T40,'B
M!"G"#[;SC816P?/__SWA'0``=TMFBX0`H+`1"&:#^/UT/0^WP(D'N@(```")
MT.GM_O__/3L"``"ZH$X``'2*/4("``"ZJU$```^$>O___SU'`@``NOE2```/
MA&K___^Z_____XG0Z;7^__^`^\L/A=[^__^#_@,/CJ/^__^*40*`^J`/ADW_
M__^`^O\/A$3___^*20.`^:`/ACC___^`^?\/A"____^-<8")\(A%\XU"7XU:
M@#Q!B%WR=@N-0AP\`P^'#____XU17X#Z70^'`____P^VPXT40,'B!(GQ*<(/
MMMF-A%/!\___/9D8``!W<#T#&```#X?:_O__9HN$`.!1$0@/MO0/ML`+!+7`
M3Q$(/?W_```/A+K^__^)![@$````Z?C]__^)]CW9#```=Q@]/@P```^'(___
M_V:+E``$E!$(Z7;^__\]\B$```^'"____V:+E`!,:!$(Z5[^__\]O1D```^'
M:O[__V:+A``L'!$(ZXY5B>564X/L$(M-$(/Y?XM=#(MU%+C_____=P>("[@!
M````@_C_=`F-9?A;7LG#B?9J`U&-5>B+10CH8H'__X/X_UI9=!2#^`-U?(I%
MZ#P!=#D\`G18/`-T![C_____Z\>#_@.X_O___WZ]Q@/"QD,!RXI%Z8/`@(A#
M`HI-ZH/!@+@$````B$L#ZYU.N/[___]^E8I%Z8/`@(@#BD7J@\"`B$,!N`(`
M``#I>O___TZX_O___P^.;O___XI5Z8/"@(@3BD7JZ]KHH4[^_Y!5B>6+11"*
M`(3`BU4,>`T/ML")`LFX`0```,.0#[;(#[>$"8!X#@B)`LFX`0```,-5B>6+
M51"#^G^+30QW"H@1N`$```#)PY"-@F#___^#^%]W%8J"@'@."(3`=$^(`;@!
M````Z]^)]H'ZD@$``+"?=.N-@G#\__^#^#=W"(J"4'4.".O4@?I_(```L/QT
MSH'ZIR```+">=,2-@NC=__^#^$]W#XJ":%8.".NMN/_____)PXV"\-S__X/X
M%W<(BH)850X(ZY.-@@#;__\]IP```'?9BH+`4@X(Z7O___^)]E6)Y8M%$(H`
MA,"+50QX#0^VP(D"R;@!````PY`/ML@/MX0)P'4."(D"R;@!````PU6)Y8M5
M$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X%W<5BH+P=0X(A,!T6H@!N`$`
M``#KWXGV@?KW````L/9TZXV"@/S__X/X3W<(BH+`<@X(Z]2!^G\@``"P_'3.
MC8+HW?__@_A/=A6-@@#;__\]IP```'<0BH(@4`X(ZZJ*@LA3#@CKHKC_____
MR<.)]E6)Y8M%$(H`A,"+50QX#0^VP(D"R;@!````PY`/ML@/MX0)(',."(D"
MR;@!````PU6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___SW?````=Q.*
M@J!R#@B$P'0]B`&X`0```.O=C8+HW___@_@'=B&!^ADB``"P^73BC8(`V___
M/:<```!W$HJ"@$T.".O)B?:*@A!3#@CKO[C_____R<.058GEBT40B@"$P(M5
M#'@-#[;`B0+)N`$```##D`^VR`^WA`F`<`X(B0+)N`$```##58GEBU40@_I_
MBTT,=PJ($;@!````R<.0C8)@____/=\```!W$XJ"`'`."(3`=#&(`;@!````
MZ]V-@D#]__^#^!]V%8V"`-O__SVG````=Q"*@L!*#@CKTXJ"P&T.".O+N/__
M___)PY!5B>6+11"*`(3`BTT,>`T/ML")`;@!````R<.0#[;`9HN4`,!M#@AF
M@_K]N/____]TYP^WPNO;D%6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/__
M_X/X7W<5BH+`;0X(A,!T4H@!N`$```#KWXGVC8+X_O__@_AW=A6-@BC]__^#
M^`=W$HJ"\&H.".O3B?:*@MAL#@CKR8'Z$R$``+#R=,.-@@#;__\]IP```'<(
MBH(@2`X(ZZJX_____\G#B?95B>6+11"*`(3`BU4,>`T/ML")`LFX`0```,.0
M#[;(#[>$"2!K#@B)`LFX`0```,-5B>6+51"#^G^+30QW"H@1N`$```#)PY"-
M@F#___^#^!]W%8J"8&L."(3`=#^(`;@!````Z]^)]HV"`/S__X/X7W8A@?H6
M(0``L.]TX(V"`-O__SVG````=Q**@N!%#@CKQXGVBH*@9PX(Z[VX_____\G#
MD%6)Y8M%$(H`A,"+30QX#0^VP(D!N`$```#)PY`/ML!FBY0`X&@."&:#^OVX
M_____W3G#[?"Z]N058GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A?
M=Q6*@N!H#@B$P'0SB`&X`0```.O?B?:-@NC^__^#^$=V%8V"`-O__SVG````
M=Q"*@F!##@CKT8J""&@.".O)N/_____)PY!5B>6+11"*`(3`BU4,>`T/ML")
M`K@!````R<.0/-5T#0^VR`^WA`E@9@X(Z^7'`JP@``#KWXUV`%6)Y8M5$(/Z
M?XM-#'<*B!&X`0```,G#D(V"8/___X/X7W<5BH)@9@X(A,!T/H@!N`$```#K
MWXGV@?J2`0``L)]TZX'Z%R```+#R=.&!^JP@``"PU737C8(`V___/:<```!W
M"(J"0$$.".N^N/_____)PXGV58GEBT40B@"$P(M5#'@-#[;`B0+)N`$```##
MD`^VR`^WA`E`9`X(B0+)N`$```##58GEBU40@_I_BTT,=PJ($;@!````R<.0
MC8)@____@_A?=Q6*@D!D#@B$P'17B`&X`0```.O?B?:-@G#\__^#^#=V,8'Z
M?R```+#\=."!^J<@``"PGG36C8+HW?__@_A/=AJ-@N#<__^#^`%W'HU"U.NW
MB?:*@A!A#@CKK8J"*$(.".NEN/_____)PXV"`-O__SVG````=^R*@H`^#@CK
MB56)Y8M%$(H`A,"+50QX#0^VP(D"R;@!````PY`/ML@/MX0)@&$."(D"R;@!
M````PU6)Y8M5$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X7W<5BH*`80X(
MA,!T3X@!N`$```#KWXGV@?J2`0``L)]TZXV"</S__X/X-W<(BH)07@X(Z]2!
M^G\@``"P_'3.@?JG(```L)YTQ(V"Z-W__X/X3W</BH)H/PX(ZZVX_____\G#
MC8+PW/__@_@7=PB*@E@^#@CKDXV"`-O__SVG````=]F*@L`[#@CI>____XGV
M58GEBT40B@"$P(M5#'@-#[;`B0+)N`$```##D`^VR`^WA`G`7@X(B0+)N`$`
M``##58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@____@_A?=Q6*@L!>#@B$
MP'1/B`&X`0```.O?B?:!^I(!``"PGW3KC8)P_/__@_@W=PB*@I!;#@CKU('Z
M%R```+"-=,Z!^G\@``"P_'3$C8+HW?__@_A/=P^*@J@\#@CKK;C_____R<.-
M@O#<__^#^!=W"(J"F#L.".N3C8(`V___/:<```!WV8J"`#D.".E[____B?95
MB>6+11"*`#P?BU4,=AT\+W<5#[;(#[>$":!=#@B)`K@!````R<.0A,!X#`^V
MP(D"R;@!````PP^VP&:+C`#@6PX(9H/Y_;C_____=-</M\'KW)!5B>53BU40
M@_H?BUT,=PV($[@!````6\G#C78`C4+@@_@'=Q2*BKA<#@B$R71.N`$```"(
M"^O?D(U"V(/X5XC1=NB-BF#___^#^5=W"(J*X%L.".O5@?JR`P``L9!TSX'Z
MQ@,``+&2=,6-@OCY__^#^&=W$(J*^%4.".NNN/____];R<.-BNC=__^#^3=W
M"(J*J#D.".N3C8(`V___@_@_=PB*BH`V#@CK@('ZDB4``+&$#X1V____@?J@
M)0``L?X/A&C___^-BH@!__^!^8<```!WJ(J*:%P-".E+____D%6)Y8M%$(H`
MA,"+50QX#0^VP(D"R;@!````PY`/ML@/MX0)X%@."(D"R;@!````PU6)Y8M5
M$(/Z?XM-#'<*B!&X`0```,G#D(V"8/___X/X7W<5BH+@6`X(A,!T3X@!N`$`
M``#KWXGV@?J2`0``L)]TZXV"</S__X/X-W<(BH*P50X(Z]2!^G\@``"P_'3.
M@?JG(```L)YTQ(V"Z-W__X/X3W</BH+(-@X(ZZVX_____\G#C8+PW/__@_@7
M=PB*@K@U#@CKDXV"`-O__SVG````=]F*@B`S#@CI>____XGV58GEBT40B@"$
MP(M-#'@-#[;`B0&X`0```,G#D`^VP&:+E``@5@X(9H/Z_;C_____=.</M\+K
MVY!5B>6+51"#^G^+30QW"H@1N`$```#)PY"-@F#___^#^!]W%8J"8%8."(3`
M=$B(`;@!````Z]^)]HV"@/S__X/X3W85C8+PW___@_@/=Q**@G@V#@CKTXGV
MBH(@4PX(Z\F-@@#;__\]IP```'<(BH+@,`X(Z[2X_____\G#58GEBT40B@"$
MP(M5#'@-#[;`B0+)N`$```##D#RO=Q0/ML`%D`,``(D"R;@!````PXUV``^V
MR`^WA`G@4PX(B0+)N`$```##58GEBU40@_I_BTT,=PJ($;@!````R<.0C8)@
M____@_@7=Q6*@GA4#@B$P'1+B`&X`0```.O?B?:-@@#\__\]EP```'8K@?H6
M(0``L/QTWH'Z&B(``+#[=-2-@@#;__\]IP```'<2BH+`+@X(Z[N)]HJ"@%`.
M".NQN/_____)PY!5B>575E.#[`R+?0B+1Q2%P(M5$(MU%'07BU4,QT<4````
M`(D",<"#Q`Q;7E_)PY"*"H3)>!:+70P/ML&)`X/$#%M>N`$```!?R<.0@/F@
M#X8F`0``@/G_#X0=`0``@_X!N/[___]^OXI:`8#[H`^&&0$``(#[_P^$$`$`
M`(#YC@^$&0$``(#YCP^$+0$```^V\8V&7____XV6@````(/S@(/X78E5[`^V
MVXG"=EB!?>PA`@``C9:]_O__=$F-AEW^__^#^`*-EKS^__]V.(%]["@"``"-
MEKK^__]T*8V&5/[__X/X`XV6M_[__W88C982_O__@_H0QT7H`````'=#C99Y
M_O__@^LA@_M=QT7H`````'<NC012P>`$*="--$,/MX0VH/H-"(G#P>L()?\`
M```#!)V@]@T(/?W_``!T5XE%Z(M5Z(72=$.#^G\/AR,!```/MS25'/8-"(M=
M#`^W%)4>]@T(B3.)5Q0QP(#YCP^4P(/``NFL_O__@/F.#X3:_O__@/F/#X31
M_O__N/_____ID/[__V8QP(E%Z.ND@/O?=^D/MO.!QL#^``"+30RX`@```(DQ
MZ6O^__^#_@*X_O___P^.7?[__XI"`H/P@`^VVP^VT(U#7X/X78E5\(VS@`$`
M`(G"=D6!_B$"``"-4[UT.HV#7?___X/X`HU3O'8L@?XH`@``C5.Z="&-LU3_
M__^#_@.-4[=V$XV3$O___S'V@_H0=T"-DWG___^+7?"#ZR$Q]H/[77<MC312
MP>8$*=:-!',/MX0`H/H-"(G#P>L()?\````#!)V@]@T(/?W_``!T"8G&B?+I
MU_[__V8QP(G&Z_*+?0R)%^GK_O__58GE5U93@^P,BT4(9HM(*#'_9H7)BW4,
MBUT0='.!^^4"```/A`L!``"!^^D"```/A/X!``"!^P`#```/A*(!``"!^P$#
M```/A/4!``"!^YHP``!U';H+````N`X```"09CD,E4!3#@@/A.,!``!"2'7N
M@WT4`;C^____?D6)R&;!Z`B(!HA.`;\"````@\8"@_M_=C>-DY\`__^#^CYW
M4(U7`CM5%+C^____?Q6-2T#&!HZ(3@&+?0C'1R@`````B="#Q`Q;7E_)PXGV
M.7T4N/[___]^[(@>BW4(QT8H`````(/$#%M>C4<!7\G#C78`@?N_I@(`=D@Q
MP(G"9H72N/____]TO/?"@`````^$X````&:%T@^(K0$``('*@(#__XMU"`^W
MRHE.*(/$#%M>B?A?R<,QTK@!````Z2#___^)V,'H!@^_E`#@X`T(A=)XIXG8
MP>(&@^`_C0P"P>D$P>$"9HN1HK8-"(E-\(G9@^$/#[?"T_BH`0^$>O___[L!
M````T^-+(=.)VH'CJJH``-'[@>)550```=J)T('BS,P``,'Z`B4S,P```=")
MPR7P<```P?@$@>,/#P```<,/ML-FP>L(`=B+3?`/M]`/MYF@M@T(`=,/MX0;
M(%\-".D7____N@(```"X!0```.EN_O__9H72#XB4````C4\".TT4N/[___\/
MC[;^__^)TXC09L'K"(/(@(/+@(A&`8@>BU4(QT(H`````(G(@\0,6UY?R<.Z
M`0```+@!````Z1[^__^Z!P```+@$````Z0_^__^%P`^$&?[__X-]%`&X_O__
M_P^.6O[__V:+#)5"4PX(B<MFP>L(B!Z(3@&+50BX`@```,="*`````#I,_[_
M_XU/`SM-%+C^____#X\B_O__B=-FP>L(B-"#R("#RX"(1@+&!H^(7@&+?0B)
MR,='*`````#I8____^BG/?[_C78`58GEBT4(BU`H,<"%THM-#'0:@WT0`;C^
M____?@^)T,'H"(@!B%$!N`(```#)PXGV58GE5U935HMU"(M&%(7`BUT,BTT0
M=!''1A0`````B0,QP%M;7E_)PXH1A-)X&H#Z7'0U@/I^#[;"="")`[@!````
M6UM>7\G#C4)?/#YW)@^VP@7`_@``B0/KXK@!````QP,^(```Z]JX`0```,<#
MI0```.O-C7I_B?@\'@^'`P$``(-]%`&X_O___WZ5BDD!C4'`/#YV"XU!@#Q\
M#X?9````@/K?B?AV`XU"/X3)#X@A`0``@^E`#[;X@/E=C10_=@2#Z5Y"@_I=
MC4$A=@^#^F8/AND```"!PN8````/MLB#^EV)3?"-NB$!``")T79/@?\A`@``
MC8I>____=$&-@O[^__^#^`*-BEW___]V,('_*`(``(V*6____W0BC;KU_O__
M@_\#C8I8____=A&-BK/^__^#^1!W0HV*&O___XM5\(/J(8/Z77<QC3Q)P><$
M*<^-!'H/MX0`H/H-"(G"P>H()?\````#!)6@]@T(/?W_``!T<X7`B<)U'[C_
M____Z9W^__^-0B`\'`^&\O[__[C_____Z8C^__^#^']W3@^W!(4<]@T(B0,/
MMPR5'O8-"+@"````B4X4Z63^__^)]H/Z8G<8@_I?=!.!PJ(```#I"/___X/I
M0>G:_O__@<*H````Z?7^__]F,<#KB(D#N`(```#I*?[__XUV`%6)Y5=64X/L
M#(M%"&:+2"@Q_V:%R8MU#(M=$'1S@?OE`@``#X38`0``@?OI`@``#X3]`0``
M@?L``P``#X3,`0``@?L!`P``#X0F`@``@?N:,```=1VZ"P```+@.````D&8Y
M#)7`4@X(#X2$`@``0DAU[H-]%`&X_O___WX[B<AFP>@(B`:(3@&_`@```(/&
M`H/[?W<K@_M<=":#^WYT(3E]%+C^____?@^('HMU",=&*`````"-1P&#Q`Q;
M7E_)PX'[I0````^$``$``('[/B````^$1`$``(V+GP#__X/Y/@^&!0$``('[
MOZ8"`'<^B=C!Z`8/OY0`X.`-"(72>"V)V,'B!H/@/XT,`L'I!,'A`F:+D:*V
M#0B)3?")V8/A#P^WPM/XJ`$/A6`!```QP(G#9H7;N/____\/A'G___\/M\,/
MML^)1>R-4=^#X'^#Z"&#^EUV*H'ZS`````^'(`$``('ZB@````^'P@$``('Z
MAP````^$M@$``(U1O8UV`/;"`70#@\!>T>J#^AX/AZX```"!PH$```"#^#Z-
M2$!V`XU(0?=%[(`````/A)L```!FA=L/B'X!``#!X@@)RHMU"(GXB58HZ>S^
M__\Y?12X_O___P^.WO[__\8&7(M=",=#*`````#IR?[__SE]%+C^____#XZ^
M_O__C5-`B!;KW#'2N`$```#I4_[__[H"````N`4```#I1/[__SE]%+C^____
M#XZ._O__Q@9^Z7G^__^Z`0```+@!````Z1_^__^!PL$```#I3?___XU?`CM=
M%+C^____#X];_O__B!:(3@&+?0B)V,='*`````#I1?[__[H'````N`0```#I
MWOW__XV1>?___^GS_O__NP$```#3XTLATXG:@>.JJ@``T?N!XE55```!VHG0
M@>+,S```P?H")3,S```!T(G#)?!P``#!^`2!XP\/```!PP^VPV;!ZP@!V(M-
M\`^WT`^WF:"V#0@!TP^WA!L@7PT(Z3W^__^%P`^$>/W__X-]%`&X_O___P^.
MK_W__V:+%)7"4@X(B=-FP>L(B!Z(5@&+30BX`@```,=!*`````#IB/W__XU1
MM^E(_O__Z#LX_O^-=@!5B>6+10B+4"@QP(72BTT,=!J#?1`!N/[___]^#XG0
MP>@(B`&(40&X`@```,G#B?95B>575E.#[`R+50B+0A2)PL'J`XM-$(MU%'0<
M@^`'BTT(B4$4BT4,B1`QR8/$#%M>B<A?R<.)]HG',=N*$8#Z&P^%I0```(U3
M`SGR?T:*00$\*'1C/"0/A84```"*00(\0'1(/$)T1#PH=7:-4P0Y\G\ABD$#
M/$^_!````'0)/%!U7[\%````@\$$B=.-4@$Y\GZHBT4(B7@4N?[___^#Q`PI
MV5M>B<A?R<.0OP,```"#P0/KU8GVBD$"/$)T$CQ*=!4\274;OP(```"#P0/K
MNC'_@\$#Z[._`0```(/!`^NIN?_____I0/___X/_!0^'A@(``/\DO<3X&`B-
M0P(Y\(E%Z'^.A-)XV(I)`83)>-&)^\'C"`^VTHV4$P#]__^-LM_^__^#_ET/
MMMF)\791@?HA`@``N5X```!T1(V"W?W__X/X`HV*//[__W8S@?HH`@``N6(`
M``!T)HVRU/W__X/^`XV*-_[__W85C8J2_?__@_D0#X=G____C8KY_?__C5/?
M@_I=#X=5____C01)P>`$*<B-'$(/MX0;H/H-"(G"P>H()?\````#!)6@]@T(
M/?W_```/A-<!``"%P`^$'O___X/X?P^'LP$```^W-(4>]@T(BTT,#[<4A1SV
M#0C!Y@.)$0G^BTWHBWT(B7<4Z3?^__^-=@"-0P(Y\(E%[`^/CO[__X32#XC4
M_O__BDD!A,D/B,G^__^-6M^`^P=V"XU"T#Q$#X>V_O__C5G?@/M=#X>J_O__
M#[;"C11`P>($*<(/MO&-A%;!\___/8$%```/APL!```]L0(```^'?_[__V:+
MA``@A1@(9H/X_0^$;?[__XM-"`^W\(M=#(DSB7D4BTWLZ:']__^0A-*Y____
M_P^(D_W__XC1@.F`B$WS>'F`^5P/A)L```"`??-^#X2?````#[95\XMU#(D6
MBW4(C4L!B7X4Z5_]__^$TKG_____#[;"#XA/_?__BTT,B0'KVX32N?____\/
MB#O]__^`^EQT&X#Z?G1!#[;RBTT,B3&+50B-2P&)>A3I&_W__XMU#,<&I0``
M`.OGC4+?/#ZY_____P^'`/W__P^V1?,%P/X``(M-#(D!ZX.+10S'`#X@``#K
MO(M%#,<`I0```.EJ____BTT,QP$^(```Z5S___\]?QX```^'=/W__V:+A``<
M2!@(Z?#^___HB#3^_XMU#(M="(M-Z(D&B7L4Z9G\__]F,<#I(?[__Y!5B>53
MBUT(BU,4B=$QP,'I`W00BT4,@^('B5,4B0BX`0```%O)PXGV58GE5U93@^P\
MBTT(BT$HB<'!Z0.)PHG'P>H3@^<'9H7)BW4,QT7``````(E5Q`^$G0```(%]
M$.4"```/A+(!``"!?1#I`@``#X2A`@``@7T0``,```^$I`$``(%]$`$#```/
MA"0#``"!?1":,```=1VZ"P```+@.````D&8Y#)6@7@T(#X2(!```0DAU[C';
M.7W$#Y7#C51;`CE5%(E5P+O^____?'PY?<1T%X/_`P^%Z00``,8&&\9&`23&
M1@)"@\8#B<AFP>@(B`:(3@&#Q@*#?1!_N/____]V5(/X_W1?2`^%M@0``(I5
MYH32>%&%_P^%\0```(M%P$`Y112[_O___WP>A?]T$,8&&\9&`2C&1@)",?^#
MQ@.(%HMU"(E^*(G#C67TB=A;7E_)PXUV`+@!````BDT0@_C_B$WF=:&#?1!_
M=VJ#?1!<=&2#?1!^=%Z*11"(1>:Z`0```(/Z_P^$L@```$H/A3$$``"*5>:$
MT@^(H````(/_`0^$`@(``(M%P(/`!#E%%+O^____?)*#_P%T@\8&&\9&`2C&
M1@)*OP$```"#Q@/I:____XGV@7T0I0````^$O0$``(%]$#X@``!T2(M=$('K
M8?\``(/[/KK_____=X2*11"#P$"(1>;I<?___Y"+1<"#P`3I"/___S'2N`$`
M``#I??[__[H"````N`4```#I;O[__\9%YG[I0?___Y"!?1"_I@(`=T*+11#!
MZ`8/OY0`X.`-"(72>#"+71#!X@:#XS^-#!K!Z02-'(T`````9HN3HK8-"(M-
M$(/A#P^WPM/XJ`$/A;8!```QP&H"_W40C5WF4_]U"&:)1<CH%E'__X/$$(/X
M_W1\@_@"#X43`P``BD7FA,!X;(!]YP!X9O=%R(`````/A5L!``"#_P,/A/4"
M``"+5<"#P@4Y512[_O___P^,8?[__X/_`W03Q@8;QD8!),9&`D*_`P```(/&
M`X@&BD7GB$8!BW4(B=.)?BCI-/[__[H!````N`$```#I?OW__V:#?<@`#X22
M````#XR*`0``@_\$="R#1<`$BTW`.4T4N_[___\/C/K]___&!AO&1@$DQD8"
M*,9&`T^_!````(/&!/=%R(`````/A"8"``!F@WW(``^(1@(``(M%R(GZ)7]_
M``#!XA/!X`,)P@G7BUT(B7LHBUW`Z:G]___&1>9<Z=7]__^+1<!`Z?O]__^Z
M!P```+@$````Z>'\__^#?1!_#X;5````@7T0I0````^$_`$``(%]$#X@```/
MA/@!``"+11`M8?\``(/X/KK_____=PZ*71"#PT"(7>:Z`0```(/Z_W022@^%
MLP$``(I%YH3`#XC=````N______I(_W__XMUR('F?W\``,'G$\'F`PGW@\\#
MZ5/___^X`0```-/@2"'0B<(EJJH``-'X@>)550```<*)T('BS,P``,'Z`B4S
M,P```=")P27P<```P?@$@>$/#P```<$/MM%FP>D(`<H/MX.@M@T(#[?2`=`/
MMX0`(%\-".GK_?__@WT07`^$(?___X-]$'X/A!?___^*51"(5>;I0?___X/_
M!0^$GO[__X-%P`2+?<`Y?12[_O___P^,;/S__\8&&\9&`23&1@(HQD8#4+\%
M````@\8$Z6W^__^#_P(/A.0```"+5<"#P@0Y512[_O___P^,,_S__X/_`G03
MQ@8;QD8!*,9&`DF_`@```(/&`X/`@(@&Z=#]__^%P`^$=/O__S';@_\$#Y7#
MC0R=`@```#E-%+O^____#XSL^___@_\$=!?&!AO&1@$DQD8"*,9&`T^_!```
M`(/&!&:+%)6B7@T(B=!FP>@(B`:(5@&+=0B)RXE^*.FP^___BU7`@\(".544
MN_[___\/C)S[__^+3<AFP>D(@^%_B`Z*1<B#X'_I0?W__^BA+O[_BU7`@\("
MZ0;]___&1>9<Z2/^___&1>9^Z1K^__^+5<!"Z1G___^-=@!5B>575E.#[`R+
M30B+02B)QHG'B<'![@/![Q.#X0<QP&:%]HM5#'0+,=LYSP^5PXU$6P*%R8G#
M=`.#PP,Y71"X_O___WP]9H7V="<YSW03@_D#=3?&`AO&0@$DQD("0H/"`XGP
M9L'H"(@"B?"(0@&#P@*%R70+Q@(;QD(!*,9"`D*)V(/$#%M>7\G#Z.@M_O]5
MB>6+11"*`#P_BTT,=Q$/ML")`;H!````B=#)PXUV`(3`NO____]X\`^VT`^W
MA!*@70T(Z]R)]E6)Y8M5$(/Z/XM-#'<*B!&X`0```,G#D(U"P(/X/W<4BH*@
M70T(A,!T/(@!N`$```#KXI"-@D#___^#^#]V%8V"P/[__X/X/W<2BH(@7`T(
MZ]2)]HJ"X%P-".O*@?H6(0``L&!TQ+C_____R<.-=@!5B>6+11"*$(U"@#P?
MBTT,=Q8/ML(/MX0`(%P-"(D!R;@!````PXGV#[;"B0')N`$```##58GEBU40
M@_I_BTT,=CZ!^H,```!T-H'ZAP```'0NC8)@____@_A?=B.-@K#^__^#^"=W
M(8J"D%L-"(3`=$>(`;@!````C78`R<.)]K@!````B!'K\XV"\-___X/X+W8=
M@?HB(0``L(UTU(V"(-[__X/X#W<7BH*<.@T(Z[V*@I`\#0CKM;C_____R<.-
M@O#=__^#^`]W"(J"7#H-".N;@?IS)0``L(1TE8V"_P3__X/X`7?1C4*=ZX&-
M=@!5B>575E.![(P```#V0"0$B47$B57`BW4(BWT,#X0^`0``B=`M,3$``(/X
M,@^'!@(``&:+E!+^[@P(B=-FP>L(B%W6B%77C476#[95U@^V2`'!X@@)RHG3
MB=#!ZPK!Z`6#XQ^#X!^*B^!0#0B*F,!0#0B)T(/@'\'J#XJ`H%`-"$J(1;</
MA14$``"`^?T/A,T```"`^_T/A,0```"`?;?]#X2Z````@/G_C578=`X/ML$%
M,#$``(E%V(/"!(#[_W0.#[;+@<$P,0``B0J#P@2`?;?_=`\/MEVW@<,P,0``
MB1J#P@2-1=@IPL'Z`HE5@$)T;HM-Q#';BU$H.UV`B56PB76LB7VH?2V%_W0S
M5_]TG=A6_W7$BU7$_U(<@\00@_C_?B$Y^`^'=`,```'&*<=#.UV`?-.)\BM5
MK.GN````N/[___^+?;"+=<1`B7XHNO[___^+=:R+?:@/A<X```"0@7W`!C``
M`,=%I`````!T/(%]P/8P``#'1:0!````="R+7<"!ZP!.``"!^_]1```/AT<!
M``"+3<`/OX0)H!`,"(7`B46D#X@Q`0``D(M=Q(M3*(E5A(M%I&:+G`"`3@P(
MB=J!X_]_``"!PP`P```/M\N!X@"`__^+181FB56BB4W(QT7,/C```(E%G(EU
MF(E]E#';A?\/A$("``!7_W2=R%;_=<2+3<3_41R#Q!"#^/\/CBP"```Y^`^'
M@0(``$,!QBG'@_L!?LN)\BM5F(UE]%M>B=!?R<.0BTW`@>D`K```@?FC*P``
M#X<3____NQP```")R#'2]_/!Z0*X)4F2)(E5O/?AB95T____NQ4```")T#'2
M]_.YAV$8AHN%=/___XG3]^$IE73____1K73___^)E6S___^)A6C___^+A73_
M__\#A6S____!Z`2*B#%1#0B#R2`/OL$/OI,<40T(P>`%"="+7;S!X`5F#[Z3
M`%$-"`G"Z6']__^-=@"+7<"!ZQ@@``"#^P(/AJ(```"+1<`MH````#U7`0``
M#X?N````BUW`#[^$&X!*#`B%P`^(@0$``,'@`HN0X)D+"(M=Q`7DF0L(B85\
M____BT,H,=LYTXE5D(E%C(EUB'-"C78`A?\/A#,!``!7BY5\_____S2:5O]U
MQ(M-Q/]1'(/$$(/X_W1M@_C_#XX3`0``.?@/ARH!``!#`<8IQSM=D'+!B?(K
M58B-9?1;7HG07\G#B?:+5<2+0B2H`@^$@````(M5P('Z&B````^$%0$``%=2
M5O]UQ(M-Q/]1'(/$$(/X_XG"#X0G____C67T6UZ)T%_)PXN%?/___X/L"(L4
MF%=6BT7$Z!G\__^#Q!#I=?___XM5P('J&`(``(/Z!W9NBT7`+;@"``"#^"</
MAY8```"+7<`/OX0;\$4,".GN_O__J`&Z)P```'2&@7W`&2```+*T#X1W____
MLF#I</___[C^____BWV<BW7$0(E^*(MUF(M]E`^%Y0```&:#?:(`#X5Y_O__
M_T6DZ4K]__^+3<`/OX0)@$<,".F1_O__N/[___^+?8R+=<1`B7XHNO[___\/
MA9C]__^Z_____^F._?__Z*PG_O^+5<"!ZM`#``"#^B]W%XM-P`^_A`E@0PP(
MZ4K^__^R&.GD_O__@7W`AP4``'0[BT7`+?`%``"#^`=W$(M=P`^_A!L`/PP(
MZ1W^__^+5<"!ZG`&``"#^@]W&HM-P`^_A`G@/0P(Z?_]__^XC@(``.G]_?__
M@7W`,PX``'1%BT7`+;`.``"#^"]W&HM=P`^_A!L`+0P(Z<_]__^Z_O___^GF
M_/__BU7`@>IP#P``@_H/=QJ+3<`/OX0)8"L,".FG_?__N*8"``#II?W__XM%
MP"T`'@``/9\```!W$(M=P`^_A!L`#0P(Z7[]__^+5<"!ZO`>``"#^@=W$(M-
MP`^_A`D0"PP(Z6#]__^+1<`M`"```(/X5W<0BUW`#[^$&T`(#`CI0_W__XM5
MP('JJ"```(/Z!W<0BTW`#[^$">`&#`CI)?W__XM%P"T`(0``/=<```!W$(M=
MP`^_A!N`!`P(Z0;]__^+5<"!ZA`B``"#^E]W$(M-P`^_A`F@`0P(Z>C\__^+
M1<`MP"(``(/X+W<0BUW`#[^$&^#_"PCIR_S__XM5P('J`"0``('Z[P```'<0
MBTW`#[^$"8#["PCIJOS__XM%P"T`)0``@_@_=Q"+7<`/OX0;`/D+".F-_/__
M@7W`YB4``'0G@7W`#"H``'19BU7`@>IP*@``@_H'=QJ+3<`/OX0)$.X+".E=
M_/__N.D'``#I6_S__X%]P)\N``!T78%]P/,N``!T2HM%P"T`+P``/=<```!W
M&HM=P`^_A!M`XPL(Z2+\__^XZP<``.D@_/__BU7`@>H`,```@?KW````=R2+
M3<`/OX0)0-\+".GW^___N/T'``#I]?O__[C[!P``Z>O[__^+1<`M,#$``(/X
M7W<0BUW`#[^$&R#<"PCIQOO__XM5P('J\#$``('Z#P(``'<0BTW`#[^$"8#6
M"PCII?O__XM%P"T`^0``/6\!``!W$(M=P`^_A!N`10H(Z8;[__^+5<"!Z@#[
M``"#^D]W$(M-P`^_A`G@0`H(Z6C[__^+1<`M2/X``(/X)W<0BUW`#[^$&_`Y
M"@CI2_O__XM5P('J`/\``('Z[P```'<0BTW`#[^$":`V"@CI*OO__XM%P"T`
MU`$`/?\#``!W$(M=P`^_A!N@A`@(Z0O[__^+5<"!Z@#X`@"!^A\"```/AW_\
M__^+3<`/OX0)8#@&".GF^O__B?95B>575E.#[!R+10R+,(M5$(EUZ(M=%(LR
MBT48BPN+$(M]"(7VQT7L`````(E-Y(E5X.FE````D(M?%%;_=>B-3?!1B5W<
M5_]7#(/$$(7`B<,/B+4```"+3>"%R0^$!`$``/]UX/]U\/]UY%?_5QR#Q!"#
M^/]U08M5\(G0P>@'/0`<``!T28M/+/]%[(7)#X61````BU<PA=)U-/]UX&C]
M_P``_W7D5_]7'(/$$(/X_P^$Y@```(GVA<`/B*8````[1>`/A[H````!1>0I
M1>`Y\P^'K`````%=Z"G>#X56____BT7HBWT,BUT0B0>),XM]&(MUX(M5Y(M-
M%(D1B3>+1>R-9?1;7E_)PXGV@_C_=#6#^/X/A)4```"X_O___RG8B</KJH/L
M"/]UX/]UY(GXZ*/V__^#Q!"#^/\/A7?____I3O___XM7,(72=%6+1PB#^!)W
M!_\DA=SX&`B[`0```.EI____BT7<B4<4Z/<C_O_'``<```#'1>S_____Z5__
M___HH"+^_[L$````Z3W___^[`@```.DS____BUW<B5\4Z,$C_O_'`%8```#K
MR.BT(_[_QP`6````Z[M5B>575E.#[!R+?0R%_XM="'0YBP>%P'0SBU,0A=+'
M1>P`````=3V+0R"%P`^%O@```,=#%`````#'0R@`````BT7LC67T6UY?R<.0
MQT,4`````,=#*``````QP(UE]%M>7\G#@^P(BW,4C4WPB77H45/_TH/$$(7`
M=*R+11"+%XLPB57D5O]U\%)3_U,<@\00@_C_=3Z+5?")T<'I!X'Y`!P``'0[
MBT,LA<#'1>P!````=6R+4S"%TG4F5FC]_P``_W7D4_]3'(/$$(/X_P^$AP``
M`(7`>&@Y\'=?`47D*<:+1>2+31")!XDQZ3?___^+-XM5$(EUX(LR4E;_=>!3
M_]"#Q!"%P'@].?!W+HM-X`'!B0\IQHM]$(DWZ1+___^#[`A6_W7DB=CH[O3_
M_X/$$(/X_W6>Z7G____H+"'^_XMUZ(ES%.AA(O[_QP`'````N/_____I`?__
M_XM]Z(E[%.A&(O[_QP!6````N/_____IYO[__XGV58GE5U9348M5$(M-#(M%
M%(M]&(LRBQF)\HL(BP?!Z`+!Z@(YPG8"B<*%TG0NC025`````"G&B47PBT40
MB3"+=?`I-Y"+.XDY@\,$@\$$2G7SBU4,B1J+712)"UI;7C'`7\G#D%6)Y8M-
M#(U!_E:#^"M3BW4(#X?-````@_D*B<N)R@^&S`````^V5@H/MX020/D8"(T4
M`0^V1@D/MXP`0/D8"`'*#[9&"`^WC`!`^1@(`<H/MD8'#[>,`$#Y&`@!R@^V
M1@8/MXP`0/D8"`'*#[9&!0^WC`!`^1@(`<H/MD8$#[>,`$#Y&`@!R@^V1@,/
MMXP`0/D8"`'*#[9&`@^WC`!`^1@(`<J*#@^VP0^WA`!`^1@(C00"#[94'O\/
MMY020/D8"(T<`H'[;P,``'<9BQ3=8'X+"(72>`XZBF!Q"PB-@F!Q"PAT%#'2
MC67X6XG07LG#D/\DC4#Z&`B0@^P(0%"-3@%1Z/HB_O^#Q!"%P(T4W6!^"PAT
MTNO.B?95B>575E.#[`R+?0B^`&\+"+M*````ZP:#Q@A+="*+!H/L"`7`;`L(
M4%?HN2+^_X/$$(7`=>*-9?1;B?!>7\G#C67T6UXQP%_)PXGV58GE5U93@>R,
M````BT4(QT6D`````,=%H`````")P8U=J+XX````ZQB-=@"-0I\\&7<#@^H@
MA-*($W0C3G0(04.*$832>>7H("#^_\<`%@```+C_____C67T6UY?R<.)V8U5
MJ"G1@_D)?AR-0_:)193\N0H```"+=92_X/H8"/.F#X21````B=J-?:@I^H/Z
M!WX7C4/XB460_+D(````B<:_Z_H8"/.F=%^`?:@`="V)V8U5J"G1C5G^@_LK
M=CPQTH72B=`/A%@!``"+6`2!^X4```")79P/A8@!``#HN@8``(`X``^%,O__
M_^A\'_[_QP`6````Z5?___^#^0J)RG<H_R2-;/H8"(M=D,8#`,=%H`$```#K
MDHM=E,8#`,=%I`$```#I7?___P^V=;(/M[PV0/D8"(T4.0^V7;$/MX0;0/D8
M"`'"#[9UL`^WO#9`^1@(`?H/MEVO#[>$&T#Y&`@!P@^V=:X/M[PV0/D8"`'Z
M#[9=K0^WA!M`^1@(`<(/MG6L#[>\-D#Y&`@!^@^V7:L/MX0;0/D8"`'"#[9U
MJ@^WO#9`^1@(`?J*1:@/MOB(19H/MYP_0/D8"(T$&@^V5`VG#[>,$D#Y&`B-
M'`&!^V\#```/A^;^__^+%-U@?@L(A=(/B-?^__^*39HZBF!Q"PB-@F!Q"P@/
MA<+^__^#[`A`C76H4$96Z)`@_O^#Q!"%P(T4W6!^"P@/A*/^___IG/[__[X`
M;PL(NTH```#K!Y"#Q@A+="N+/H/L"(''P&P+"%>-5:A2Z%$@_O^#Q!"%P'7>
MB?"%P`^%;_[__^GF_?__,<#K[X%]G(8````/A-7]__^-1:B+30R[.````(E%
MC.LAB?:-0I\\&7<#@^H@BWV,A-*(%W072P^$J?W__T=!B7V,BA&$TGG;Z9G]
M__^+38R-=:@I\8/Y"7X=BUV,@^L*_+D*````B=Z_X/H8"/.F=0:)78S&`P"+
M78R-5:@ITX/[!WX=BUV,@^L(_+D(````B=Z_Z_H8"/.F=0:)78S&`P"`?:@`
M="2+38R-7:@IV8U!_H/X*P^'ZP```(/Y"HG*=QG_)(V8^A@(B?;H:P0``(E%
M#(`X`.DP____#[95L@^WO!)`^1@(C10Y#[9%L0^WM`!`^1@(`?(/MGVP#[><
M/T#Y&`@!V@^V1:\/M[0`0/D8"`'R#[9]K@^WG#]`^1@(`=H/MD6M#[>T`$#Y
M&`@!\@^V?:P/MYP_0/D8"`':#[9%JP^WM`!`^1@(`?(/MGVJ#[></T#Y&`@!
MVHI%J`^VV(A%FP^WA!M`^1@(C30"#[94#:</MXP20/D8"(T<,8'[;P,``'<@
MBQ3=8'X+"(72>!6*39LZBF!Q"PB-@F!Q"P@/A.H````QTH72B=`/A*T```"+
M<`2!_H4````/A`K___^!_H8````/A!G\__^#[`QJ-.@4&O[_@\00A<")PW1O
MC12VBTV<B7`(BS25X%$-"(EP#(TTB<'F`HL\E>11#0B)>!")2!B+ANA1#0C'
M0Q0`````QT,H`````(N6[%$-"(N^\%$-"(E#'(M-I(MUH(G8B5,@B7LDQP-P
M?@8(QT,$+(`&"(E++(ES,.FG^___Z+<;_O_'``P```#IDOO__[L`;PL(ODH`
M``#K!H/#"$YT18L#@^P(!<!L"PA0C56H4NBV'?[_@\00A<!UWXG8ZRB#[`A`
MC7VH4$=7Z)P=_O^#Q!"%P(T4W6!^"P@/A/?^___I\/[__S'`A<`/A?+^___I
M(?O__XGV58GE5E.+10R%P(M5"(MU$(M=%(M-&'0%@S@`=1.)31")70R)50A;
MBTH$7LG_X8GVB4T8B5T4B740B44,B54(6XL*7LG_X8GV58GE@^P4_W4(Z+X?
M_O\QP,G#B?95B>564XM%#(/X!(M5"(M-$'=M_R2%Q/H8"(GV,<"#.0`/E<")
M0C`QP(UV`%M>R<.+&C'V@?MP?@8(=#.!^Z2!!@AT,XDQ,<#KXHGVBT(LB0$Q
MP.O7C78`,=N#.0`/E<,QP(E:+.O%D(M",(D!Z^*+0A@Y0@AUQ;X!````B3'K
MQNAC&O[_QP`6````6[C_____7LG#58GEBT4(BT`$BU4,*T($R<.-=@!5B>56
M4XM%#(/L"(M5"(LPBQI64^A7'/[_@\00A<!T&C'2@#M#=!TQR8`^0W0B*<K!
MX@*%P'@EC4(!C67X6U[)PXUV`(![`5-UW;(!Z]F)]H!^`5-UV+$!Z]2)]HUE
M^%N-0O]>R<.)]E6)Y5=64X'LS"P``#'V,<F[;P,``(UV`(N!8'X+"(7`>"J+
MD61^"PB!^H4```!T'('ZA@```'04!6!Q"PB)A/48XO__B93U'.+__T:#P0A+
M><8QTHL,U0!O"PB!P<!L"PB+!-4$;PL(0HF,]1CB__^)A/4<XO__1H/Z27;7
M@_X!=U$QVSGS<T.+E-T<XO__,?^)V8N$S1CB__]#B82]*-/__T<Y\W,).93=
M'.+__W3A@_\!=S=0_W4,C84HT___4%?_50B#Q!"%P'2YC67T6UY?R<-HA(D&
M"&H(5HV5&.+__U+H,1;^_X/$$.N6:)B)!@AJ!%>-E2C3__]2Z!@6_O^#Q!#K
ML(UV`%6)Y5=64X'LN````&H`Z)T8_O^#Q!"%P(F%9/___P^$GP```(L]P+,F
M"(7_#X2@````@#\`B?MT9S'VZRR-=@")W_R)\+G_____\J[WT8T4&8G7N?__
M___RKO?1C4P1_X!Y`0"-60%T-X/L"%/_M63____HB!K^_X/$$(7`=`N`.RIU
MO(![`0!UMORY_____XG?B?#RKO?1`=F)C63___^+M63___^`/@!U"L>%9/__
M_V@V"@B+A63___^-9?1;7E_)P\>%9/____3Z&`CI4O___X/L#&@`^Q@(Z($#
M```QTHG'_(G&N?____^(T/*NB<N_GQ$9"+G_____\J[WT_?128/$$#'_2XF-
M7/___P^%^P```(T,.XN57/___X/L#(U$$0%0Z(85_O^#Q!"%P(F%8/___P^$
M*`(``%)35E#H'!7^_X/$$(7_=`J+M6#____&!!XOBX5@____`?B+O5S___]'
M45<!V&B?$1D(4.CM%/[_6%IHF0$9"/^U8/___^CK&/[_@\00A<")Q@^$T0$`
M`,>%6/___P````#'A53___\`````B?:+7@1+A=N)7@0/B)D!``"+#@^V$4&)
M#H/Z_P^$-0$``(/Z"G3;@_H@=-:#^@ETT8/Z(W5'ZQ:+!@^V$$")!H/Z_P^$
M#@$``(/Z"G2TBU8$2H72B58$>=^#[`Q6Z+@3_O^)PH/$$.O7@'P>_R\/A/K^
M__]FOP$`Z?'^__^#[`A64NCC$O[_C9UH____@\004XU]J%=H]?H8"%;HZA/^
M_X/$$$@/CJT```"Z_____S'`_(U]J(G1\J[WT4F)C5#___^-O6C___^)T?*N
M]]&->?^+C53___^%R0^%Y0```(N=4/___P'[C4,"@^P,@\,#4XF%5/___^@.
M%/[_B858____BYU8____@\00A=MT/HN=6/___P.=5/___RG[B=B#[`B-5:@K
MA5#___]2@^@"4.B5$?[_65^-O6C___]72U/HA1'^_X/$$.FU_O__QX54____
M`````(/L#%;HBA?^_XNU5/___X/$$(7VO_3Z&`AT$HN-6/___XN=5/___\8$
M&0")SXN%8/___X7`=!&#[`S_M6#____H7AK^_X/$$(D]P+,F".GB_/__@^P,
M5NAG$O[_B<*#Q!#I7/[__[_T^A@(Z\"+E5#___\!^@.55/___XU*`H/L"(/"
M`U+_M5C___^)C53____H#1;^_^D*____58GE5U93@^P,BUT(A=N+=0QT%87V
M=!&#[`A64^A'%_[_@\00A<!U',<%Q+,F"`````#'!<RS)@@`````C67T6UY?
MR<,QP/R)W[G_____\J[WT8U1_XD5R+,F"(GWN?_____RKHG/]]=/@^P,C40Z
M`HD]T+,F"%#HG!+^_X/$$(7`B<=THZ'(LR8(0%)04U?H-!+^_XL5T+,F"(/$
M#$*)/<2S)@@#/<BS)@A2C5\!5E/H$Q+^_XD=S+,F"(/$$(UE]%M>7\G#B?95
MH<2S)@B)Y87`5U-T"HL]S+,F"(7_=0R+10B-9?A;7\G#B?92_S7(LR8(4/]U
M".B<%/[_@\00A<!UW8M%"(L-R+,F"(H4"(32B?ATSH#Z+W7&BUT(`<LQP/R)
MW[G_____\J[WT8/L#`,-T+,F"%'HW!'^_X/$$(7`B<=TFU#_-="S)@C_-<RS
M)@A7Z'`1_O]96(GZ4P,5T+,F"%+H;P_^_XGXZ7/___]5B>564^C.#_[_B<:[
M`P```#GS?12-=@"#[`Q3Z$<8_O]#@\00.?-\[XUE^%M>R<-5B>575E.#[#R+
M=0B+70PYWHGP=!N#_O]T'H/L"%-6Z$01_O^)PXDT).@*&/[_B=B-9?1;7E_)
MPX/L"&H":$C[&`CH<1?^_X/$$(/X_XG&=<F-1<A74&A2^Q@(C7W85^B4%?[_
MZ"\3_O]:6?\P5^AI"P``BT78C7CT@\00@?\(PR4(=):#[`AJ_X/H!%#HI@_^
M_X/$$(7`?X&#[`B-5;A25^A2%_[_@\00Z6S___^)]HG#@^P,4^BM%O[_B<.+
M1=B-</2!_@C#)0B-?;ATY(/L"&K_@^@$4.A<#_[_@\00A<!_SX/L"%=6Z`L7
M_O^#Q!#KP(GVZ[J)]E6)Y5=64X'L3!```(M%#(F%M.___XVUZ.___U!H`!``
M`%;_=0CHMA+^_X/$$(7`B<-T+Y"#^/]T,U!35O^UM.___^@Y%_[_@\004&@`
M$```5O]U".B'$O[_@\00A<")PW72,<"-9?1;7E_)P^@O$O[_@S@$=*7H)1+^
M_X,X(P^$P````(V5R.___U=2:&3[&`B-O=CO__]7Z&,4_O_H_A'^_UI9_S!7
MZ#@*``"+A=CO__^->/2#Q!"!_PC#)0@/A'7___^#[`AJ_X/H!%#H;@[^_X/$
M$(7`#X]<____@^P(C8VX[___45?H$Q;^_X/$$.E$____C78`B<.+A=CO__^-
M</2!_@C#)0B-O;CO__]U#8/L#%/H5A7^_XG#Z_.#[`AJ_X/H!%#H%`[^_X/$
M$(7`?]Z#[`A75NC#%?[_@\00Z\^)]K@!````Z1;___^)P^N_B?95B>575E.#
M[$R+12")1;2+?1SH)1+^_X/X_XG##X3>````A<!T"HUE](G86UY?R<.#[`AJ
M`/]U".AW_?__65MJ`?]U#.AK_?__6%IJ`O]U$.A?_?__@\00Z/\,_O^)QKL#
M````.?-]$8/L#%/H>Q7^_T.#Q!`Y\WSO@___=!.#[`Q7Z$45_O^#Q!!`#X2?
M`0``BW6TB?>+7@R#QP0Y^XG8="I2:@'_<!3_<!#H/!'^_X/$$$`/A*X```"#
M[`Q3Z"D/_O^)PX/$$#GX==:#[`B+?1C_-XM=%/\SZ(X1_O_H:1#^__\P:)C[
M&`AJ`6H!Z%&R_O^-9?1;7C'`7\G#C78`C57(45)H>/L8"(UUV%;HF1+^_^@T
M$/[_7UK_,%;H;@@``(M%V(UP](/$$('^",,E"(U]N`^$[/[__X/L"&K_@^@$
M4.BD#/[_@\00A<`/C]/^__^#[`A75NA/%/[_@\00Z<'^__^-=@"-1;A64&BX
M^Q@(C7785N@Q$O[_Z,P/_O]:6?\P5N@&"```BT78C7#T@\00@?X(PR4(#X0;
M____@^P(:O^#Z`10Z#\,_O^#Q!"%P`^/`O___X/L"(U5R%)6Z.<3_O^#Q!#I
M[?[__XUV`(G#BT78C7#T@?X(PR4(C7VX#X7I````D(/L#%/H*Q/^_XG#BT78
MC7#T@?X(PR4(C7W(=.2#[`AJ_X/H!%#HV@O^_X/$$(7`?\^#[`A75NB)$_[_
M@\00Z\")P^N\B</KN(U-N%=1:-C[&`B-7=A3Z&D1_O_H!`_^_UE>_S!3Z#X'
M``"+1=B-6/2#Q!"!^PC#)0B-=<@/A"?^__^#[`AJ_X/H!%#H=`O^_X/$$(7`
M#X\._O__@^P(5E/H'Q/^_X/$$.G\_?__C78`B</I2?___XG#BT78C7#T@?X(
MPR4(C7W(#X0R____@^P(:O^#Z`10Z"@+_O_I2?___XG#Z1C___^#[`AJ_X/H
M!%#H#@O^_^DO____B</I_O[__XG#Z??^__^)P^GP_O__B</IZ?[__Y!5B>57
M5E.![&@(``"-G;#W__^+50B+10Q3B96@]___B86<]___Z"(-_O^#Q!!`#X2X
M`0``@^P,C;6H]___5N@)#?[_@\000`^$I0$``%!J!&H$_[6P]___Z%\2_O^#
MQ!!`#X2W`0``4&H$:@3_M:CW___H11+^_X/$$$`/A)T!``"+C:CW__\YC;#W
M__^)\GP"B=J+.E#_=1S_=1C_=13_=1#_=@3_<P1J_^A1_/__@\04_W,$B868
M]___Z"P2_O]8_W8$Z",2_O]'@\00@[VP]____P^$5@(``(VUZ/?__U!H``@`
M`&H`5N@.#_[_BXVP]___@\00@_G_=!:)R[@!````@^$?P>L%T^`)A)WH]___
MBXVH]___@_G_=!:)RKL!````@^$?P>H%T^,)G)7H]___@^P,:@!J`&H`5E?H
M.0O^_X/$($`/A&,!``"+E;#W__^%TGX;B=/!ZP6)T8/A'XN$G>CW___3Z*@!
M#X4"`0``BY6H]___A=)^&XG3P>L%B=&#X1^+A)WH]___T^BH`0^%H0```(.]
ML/?___\/A3S___^#O:CW____#X4O____4VH`C;6D]___5O^UF/?__^A6"/[_
M0(/$$(/X`0^&;P$``(N%I/?__ZA_#X5A`0``P?@(C67T6UY?R<.-M:CW__]2
M:/C[&`AJ`6H!Z$.N_O^#Q!!0:@1J!/^UL/?__^BH$/[_@\000`^%2?[__U!H
M'/P8"&H!:@'H%Z[^_X/$$.E,_O__C78`@^P(_[6<]___4NAE^?__@\00A,`/
MA47___^#[`S_M:CW___HC!#^_X/$$,>%J/?________I)?___XGV@^P(_[6@
M]___4N@I^?__@\00A,`/A>3^__^#[`S_M;#W___H4!#^_X/$$,>%L/?_____
M___IQ/[__XGVZ)<+_O^#.`0/A(_^__^-C<CW__]346A,_!@(C9W8]___4^C5
M#?[_Z'`+_O]:6?\P4^BJ`P``BX78]___C5CT@\00@?L(PR4(#X1/_O__@^P(
M:O^#Z`10Z.`'_O^#Q!"%P`^/-O[__X/L"(V%N/?__U!3Z(4/_O^#Q!#I'O[_
M_Y"#O:CW____#X6=_?__Z6_^__^X_____^F8_O__B<.#[`Q3Z,4._O^)PXN%
MV/?__XUP]('^",,E"(V]N/?__W3>@^P(:O^#Z`10Z&X'_O^#Q!"%P'_)@^P(
M5U;H'0_^_X/$$.NZZ[:)]E6)Y8/L*(`]X+,F"`!T(8/L"&CHLR8(_W48_W44
M_W40_W4,_W4(Z#W\___)PXUV`(/L#,<%_+,F"`````#'!>RS)@@`````QP7P
MLR8(`````,<%]+,F".RS)@C'!?BS)@CLLR8(Q@7@LR8(`6B,F@8(Z`X-_O^#
MQ!"#[`AHZ+,F"/]U&/]U%/]U$/]U#/]U".C3^___R<.058GE@^P4:O__=13_
M=1#_=0S_=0CH3____\G#D%6)Y5=64X/L.&K__W40_W4,C4784+X(PR4(QT78
M%,,E"/]U".@C____B<>+1=B-6/2#Q"`YWG5,C67T6UZ)^%_)PXGVB<>+1=B-
M6/0YWG4)@^P,5^AW#?[_@^P(:O^#Z`10Z#D&_O^#Q!"%P'_B@^P(C4W(45/H
MY0W^_X/$$(/L#%?KT(/L"&K_@^@$4.@.!O[_@\00A<!_GX/L"(U5R%)3Z+H-
M_O^#Q!#KC8/L#%#H'`W^_U6)Y8/L$/\U\+,F"&CHLR8(Z'8```"#Q!#)PY"#
M[`Q0Z/<,_O^0B?95B>6!^O__``!3B<-1=`6+7?S)PX/X`709A=MU\H/L#&C8
MLR8(Z`H,_O^#Q!"+7?S)PX/L#&C8LR8(Z"4*_O^#Q!#KU56)Y;K__P``N`$`
M``#)ZZQ5B>6Z__\``#'`R>N?C78`58GE5U93@^PLBT4(BUT,B474ZT:#[`C_
M<PS_==3HWO___XM#%(UP]+H(PR4(@\00BTL(.?*)3="->Q!U*8L'C7#TN0C#
M)0@Y\75%@^P,4^C\!O[_@\00BUW0A=MUMHUE]%M>7\G#@^P(:O^#Z`10Z.P$
M_O^#Q!"%P'_"@^P(C4784%;HF`S^_X/$$.NPC78`@^P(:O^#Z`10Z,($_O^#
MQ!"%P'^F@^P(C4784%;H;@S^_X/$$.N4@^P,4.C0"_[_B<:+!XU8]+\(PR4(
M.=]U"8/L#%;HMPO^_X/L"&K_@^@$4.AY!/[_@\00A<!_XH/L"(U5V%)3Z"4,
M_O^#Q!"#[`Q6Z]!5B>575E.#[&R+70R#^P&+?0@/A-0!``"#^P(/A(L"``"#
M^P0/A$(#``"#^R,/A/D#``"#^PH/A.0```"#[`QJ$.C6"O[_68G&6(U.!,<&
MP/T8"%>)3<Q1Z'\$_O]86L<&J/T8"%>-?=A7Z&T$_O\QP/RY_____[_NZP@(
M\J[WT8/$#$E1:.[K"`B-1=A0Z`D,_O^)'"3H<0/^_UI9C4W8C58(48E%U(E5
MR%+H+`3^__RY_____S'`BWW4\J[WT8/$#$E1_W74_W7(Z,T+_O^-3=B)#"3H
M8@7^_X/$#(E>#&API`8(:'#\&`A6Z#P(_O^)QXG3@^P,5N@_`_[_@\00@^P,
M5NA#`O[_@\00@_O^#X3+````@^P,5^AN"O[_B?:#[`QJ$.CR"?[_6EG'`,#]
M&`B-2`17B<:)3:Q1Z)L#_O];6,<&J/T8"%>-?=A7Z(D#_O\QP/RY_____[_N
MZP@(\J[WT8/$#$E1:.[K"`B-1=A0Z"4+_O_'!"0*````Z(D"_O]:68U-V(U6
M"%&)PXE5J%+H10/^__RY_____S'`B=_RKO?1@\0,25%3_W6HZ.D*_O^-7=B)
M'"3H?@3^_X/$#,=&#`H```#'!B#^&`AH!*8&"&BT_!@(Z0W___^-=@"#[`Q7
MZ",#_O^-=@"#[`QJ$.@F"?[_7EJ)QL<`P/T8"(U`!%>)1;10Z,\"_O]96XU5
MV,<&J/T8"%=2Z+T"_O_\N?____\QP+_NZP@(\J[WT8/$#$E1:.[K"`B-3=A1
MZ%D*_O_'!"0!````Z+T!_O]?6HU-V(U6"%&)PXE5L%+H>0+^__RY_____S'`
MB=_RKO?1@\0,25%3_W6PZ!T*_O^-7=B)'"3HL@/^_X/$#,=&#`$```#'!I#]
M&`AHA*P&"&A<_1@(Z4'^__^-=@"#[`QJ$.AF"/[_65N-2`3'`,#]&`A7B<:)
M3:11Z`\"_O]86L<&J/T8"%>-?=A7Z/T!_O\QP/RY_____[_NZP@(\J[WT8/$
M#$E1:.[K"`B-1=A0Z)D)_O_'!"0"````Z/T`_O]96XU-V(U6"%&)PXE5T%+H
MN0'^__RY_____S'`B=_RKO?1@\0,25%3_W70Z%T)_O^-7=B)'"3H\@+^_X/$
M#,=&#`(```#'!MC]&`AHY*H&"&@T_1@(Z8']__^-=@"#[`QJ$.BF!_[_7EJ-
M2`3'`,#]&`A7B<:)3<11Z$\!_O]96\<&J/T8"%>-?=A7Z#T!_O\QP/RY____
M_[_NZP@(\J[WT8/$#$E1:.[K"`B-1=A0Z-D(_O_'!"0$````Z#T`_O]?6HU-
MV(U6"%&)PXE5P%+H^0#^__RY_____S'`B=_RKO?1@\0,25%3_W7`Z)T(_O^-
M7=B)'"3H,@+^_X/$#,=&#`0```#'!O#]&`AH1*D&"&@,_1@(Z<'\__^-=@"#
M[`QJ$.CF!O[_65N-2`3'`,#]&`A7B<:)3;Q1Z(\`_O]86L<&J/T8"%>-?=A7
MZ'T`_O\QP/RY_____[_NZP@(\J[WT8/$#$E1:.[K"`B-1=A0Z!D(_O_'!"0C
M````Z'W__?];7XU-V(U6"%&)PXE5N%+H.0#^__RY_____S'`B=_RKO?1@\0,
M25%3_W6XZ-T'_O^-7=B)'"3H<@'^_X/$#,=&#",```#'!@C^&`AHI*<&"&C@
M_!@(Z0'\__^-=@")QXG3@^P,C5784NA``?[_@\00QP;`_1@(@^P,_W7,Z"P!
M_O^#Q!#IW/O__X/L#(G35HG'Z!?__?^#Q!"#^_\/A<_[__^#[`Q7Z-+__?_I
ML?O__XG'B=/'!L#]&`B#[`S_=:SHZ`#^_X/$$.F8^___@^P,B=-6B<?HT_[]
M_X/$$(/[_P^%B_O__X/L#%?HCO_]_XG'B=/'!L#]&`B#[`S_=;3HJ0#^_X/$
M$.E9^___@^P,B=-6B<?HE/[]_X/$$(/[_P^%3/O__X/L#%?H3__]_XG'B=/'
M!L#]&`B#[`S_=:3H:@#^_X/$$.D:^___@^P,B=-6B<?H5?[]_X/$$(/[_P^%
M#?O__X/L#%?H$/_]_XG'B=/'!L#]&`B#[`S_=<3H*P#^_X/$$.G;^O__@^P,
MB=-6B<?H%O[]_X/$$(/[_P^%SOK__X/L#%?HT?[]_XG'B=/IR/K__XG'B=/I
MLO[__^F>^O__Z9GZ___IE/K__XG'B=.#[`R-5=A2Z-#__?^#Q!#IS_[__XG'
MB=.#[`R-5=A2Z+C__?^#Q!#I]O[__XG'B=.#[`R-5=A2Z*#__?^#Q!#I'?__
M_XG'B=/'!L#]&`B#[`S_=;SH@__]_X/$$.DS^O__@^P,B=-6B<?H;OW]_X/$
M$(/[_P^%)OK__X/L#%?H*?[]_XG'B=.#[`R-5=A2Z$G__?^#Q!#I!?___XG'
MB=.#[`R-5=A2Z#'__?^#Q!#KF(/L#/]UR(G'B=/H'?_]_X/$$.G)_?__@^P,
M_W6HB<>)T^@&__W_@\00Z2+___^#[`S_=;")QXG3Z._^_?^#Q!#I(____X/L
M#/]UT(G'B=/HV/[]_X/$$.DD____@^P,_W7`B<>)T^C!_OW_@\00Z63___^#
M[`S_=;B)QXG3Z*K^_?^#Q!#I9?___XGV58GE5U93@^P8BW4(QP;`_1@(C48$
M4.B%_OW_B30DZ'W\_?^#Q!"-9?1;7E_)PXGV@^P,B=-6B<?H8_S]_X/$$$-T
M"8/L#%?HI`/^_X/L#%?H&_W]_XUV`%6)Y5=64X/L&(MU"(U&!,<&P/T8"%#H
M+?[]_XDT).@E_/W_B74(@\00C67T6UY?R>DC_OW_C78`@^P,B=-6B<?H`_S]
M_X/$$$-T"8/L#%?H1`/^_X/L#%?HN_S]_XUV`%6)Y5=64X/L&(MU",<&J/T8
M"(U&"%#HS?W]_\<&P/T8"(U.!(D,).B\_?W_B30DZ+3[_?^#Q!"-9?1;7E_)
MPY"#[`R)TU:)Q^B;^_W_@\000W15@^P,5^C<`O[_B=/'!L#]&`B#[`R-5@2)
MQU+H=OW]_XDT).AN^_W_@\000W73@^P,5^@O_/W_C78`@^P,B=-6B<?H3_O]
M_X/$$$-UM(/L#%?H$/S]_X/L#%?H!_S]_XG'B=/KQI!5B>575E.#[!B+=0B-
M1@C'!JC]&`A0Z!7]_?^-3@3'!L#]&`B)#"3H!/W]_XDT).C\^OW_B74(@\00
MC67T6UY?R>GZ_/W_B?:#[`R)TU:)Q^C;^OW_@\000W19D(/L#%?H&P+^_XUV
M`(G3@^P,C58$QP;`_1@(4HG'Z++\_?^)-"3HJOK]_X/$$$-UT(/L#%?H:_O]
M_XUV`(/L#(G35HG'Z(OZ_?^#Q!!#=;&#[`Q7Z$S[_?^#[`Q7Z$/[_?^)QXG3
MZ\:058GEBT4(BT`(R<.058GEBT4(BT`$R<.058GE5U93@^P8BW4(QP:H_1@(
MC48(4.@Y_/W_QP;`_1@(C4X$B0PDZ"C\_?^)-"3H(/K]_X/$$(UE]%M>7\G#
MD(/L#(G35HG'Z`?Z_?^#Q!!#=&>0@^P,5^A'`?[_C78`B=/'!L#]&`B#[`R-
M5@2)QU+HWOO]_XDT).C6^?W_@\000W70@^P,5^B7^OW_C78`@^P,B=-6B<?H
MM_G]_X/$$$-UL8/L#%?H>/K]_T*)QW6C@^P,4.AJ^OW_@^P,5^AA^OW_B<>)
MT^NXC78`58GE5U93@^P8BW4(C48(QP:H_1@(4.AM^_W_C4X$QP;`_1@(B0PD
MZ%S[_?^)-"3H5/G]_XEU"(/$$(UE]%M>7\GI4OO]_XGV@^P,B=-6B<?H,_G]
M_X/$$$-T:9"#[`Q7Z',`_O^-=@")TX/L#(U6!,<&P/T8"%*)Q^@*^_W_B30D
MZ`+Y_?^#Q!!#=="#[`Q7Z,/Y_?^-=@"#[`R)TU:)Q^CC^/W_@\000W6Q@^P,
M5^BD^?W_0HG'=:.#[`Q0Z);Y_?^)]H/L#%?HB_G]_XG'B=/KMI!5B>575E.#
M[!B+=0C'!JC]&`B-1@A0Z)GZ_?_'!L#]&`B-3@2)#"3HB/K]_XDT).B`^/W_
M@\00C67T6UY?R<.0@^P,B=-6B<?H9_C]_X/$$$-T9Y"#[`Q7Z*?__?^-=@")
MT\<&P/T8"(/L#(U6!(G'4N@^^OW_B30DZ#;X_?^#Q!!#=="#[`Q7Z/?X_?^-
M=@"#[`R)TU:)Q^@7^/W_@\000W6Q@^P,5^C8^/W_0HG'=:.#[`Q0Z,KX_?^#
M[`Q7Z,'X_?^)QXG3Z[B-=@!5B>575E.#[!B+=0B-1@C'!JC]&`A0Z,WY_?^-
M3@3'!L#]&`B)#"3HO/G]_XDT).BT]_W_B74(@\00C67T6UY?R>FR^?W_B?:#
M[`R)TU:)Q^B3]_W_@\000W1ID(/L#%?HT_[]_XUV`(G3@^P,C58$QP;`_1@(
M4HG'Z&KY_?^)-"3H8O?]_X/$$$-UT(/L#%?H(_C]_XUV`(/L#(G35HG'Z$/W
M_?^#Q!!#=;&#[`Q7Z`3X_?]"B<=UHX/L#%#H]O?]_XGV@^P,5^CK]_W_B<>)
MT^NVD%6)Y5=64X/L&(MU",<&J/T8"(U&"%#H^?C]_\<&P/T8"(U.!(D,).CH
M^/W_B30DZ.#V_?^#Q!"-9?1;7E_)PY"#[`R)TU:)Q^C']OW_@\000W1GD(/L
M#%?H!_[]_XUV`(G3QP;`_1@(@^P,C58$B<=2Z)[X_?^)-"3HEO;]_X/$$$-U
MT(/L#%?H5_?]_XUV`(/L#(G35HG'Z'?V_?^#Q!!#=;&#[`Q7Z#CW_?]"B<=U
MHX/L#%#H*O?]_X/L#%?H(??]_XG'B=/KN(UV`%6)Y5=64X/L&(MU"(U&",<&
MJ/T8"%#H+?C]_XU.!,<&P/T8"(D,).@<^/W_B30DZ!3V_?^)=0B#Q!"-9?1;
M7E_)Z1+X_?^)]H/L#(G35HG'Z//U_?^#Q!!#=&F0@^P,5^@S_?W_C78`B=.#
M[`R-5@3'!L#]&`A2B<?HRO?]_XDT).C"]?W_@\000W70@^P,5^B#]OW_C78`
M@^P,B=-6B<?HH_7]_X/$$$-UL8/L#%?H9/;]_T*)QW6C@^P,4.A6]OW_B?:#
M[`Q7Z$OV_?^)QXG3Z[:058GE5U93@^P8BW4(QP:H_1@(C48(4.A9]_W_QP;`
M_1@(C4X$B0PDZ$CW_?^)-"3H0/7]_X/$$(UE]%M>7\G#D(/L#(G35HG'Z"?U
M_?^#Q!!#=&>0@^P,5^AG_/W_C78`B=/'!L#]&`B#[`R-5@2)QU+H_O;]_XDT
M).CV]/W_@\000W70@^P,5^BW]?W_C78`@^P,B=-6B<?HU_3]_X/$$$-UL8/L
M#%?HF/7]_T*)QW6C@^P,4.B*]?W_@^P,5^B!]?W_B<>)T^NXC78`58GE5U93
M@^P8BW4(C48(QP:H_1@(4.B-]OW_C4X$QP;`_1@(B0PDZ'SV_?^)-"3H=/3]
M_XEU"(/$$(UE]%M>7\GI<O;]_XGV@^P,B=-6B<?H4_3]_X/$$$-T:9"#[`Q7
MZ)/[_?^-=@")TX/L#(U6!,<&P/T8"%*)Q^@J]OW_B30DZ"+T_?^#Q!!#=="#
M[`Q7Z./T_?^-=@"#[`R)TU:)Q^@#]/W_@\000W6Q@^P,5^C$]/W_0HG'=:.#
M[`Q0Z+;T_?^)]H/L#%?HJ_3]_XG'B=/KMI!5B>575E.#[!B+=0C'!JC]&`B-
M1@A0Z+GU_?_'!L#]&`B-3@2)#"3HJ/7]_XDT).B@\_W_@\00C67T6UY?R<.0
M@^P,B=-6B<?HA_/]_X/$$$-T9Y"#[`Q7Z,?Z_?^-=@")T\<&P/T8"(/L#(U6
M!(G'4NA>]?W_B30DZ%;S_?^#Q!!#=="#[`Q7Z!?T_?^-=@"#[`R)TU:)Q^@W
M\_W_@\000W6Q@^P,5^CX\_W_0HG'=:.#[`Q0Z.KS_?^#[`Q7Z.'S_?^)QXG3
MZ[B-=@!5B>575E.#[!B+=0B-1@C'!JC]&`A0Z.WT_?^-3@3'!L#]&`B)#"3H
MW/3]_XDT).C4\OW_B74(@\00C67T6UY?R>G2]/W_B?:#[`R)TU:)Q^BS\OW_
M@\000W1ID(/L#%?H\_G]_XUV`(G3@^P,C58$QP;`_1@(4HG'Z(KT_?^)-"3H
M@O+]_X/$$$-UT(/L#%?H0_/]_XUV`(/L#(G35HG'Z&/R_?^#Q!!#=;&#[`Q7
MZ"3S_?]"B<=UHX/L#%#H%O/]_XGV@^P,5^@+\_W_B<>)T^NVD%6)Y<G#C78`
M58GE@^P(@#T!M"8(`'0),=*)T,G#C78`H"1'&0C&!0&T)@@!H@*T)@CH[EH`
M`(3`N@$```!UVNC06@``BQ60B24(A=)T'8L5C(DE"(72=&R#[`AJ`6H-Z(#U
M_?^#Q!`QTNNN@^P(:##^&`AH5A`9",<%D(DE".H,``#HS??]_X/$$(7`=`]F
MBT`(AN`/M\B)#9"))0B#[`QH-/X8".CJ\?W_@\00A<!TG8/L#%#HNOC]_X/$
M$*.0B24(ZXJ#[`QH(>`(",<%C(DE"$;@"`CHN?']_X/$$(7`#X1R____HXR)
M)0CI:/___U6)Y<G#C78`58GE@^P(@#T"M"8(`'01Q@4"M"8(`,8%`;0F"`#)
MPY"#[`QJ`.A^6P``Q@4"M"8(`,8%`;0F"`"#Q!#)PXUV`%6)Y;@@1AD(R<.)
M]E6)Y3'`R<.058GE@^P0:'"O!@AJ#>B&]/W_R<-5B>564XMU"(N>F`,``(L#
MA<!U(&H`:@!J`&H`:@!J`&H`4^A\F@$`@\0@A<"Z`0```'0BB9ZD`P``48NS
MK`,``&H!_W40_W4,:@!J`&H#4_]6!`^^T(UE^%N)T%[)PY!5B>564XMU"(N>
MF`,``(L#A<!U(&H`:@!J`&H`:@!J`&H`4^@<F@$`@\0@A<"Z`0```'0EB9ZD
M`P``4(N#K`,``&H!_W40_W4,:@!J`&H#4_]0!`^^T(/$((32N`$```!T"HUE
M^%M>R<.-=@"#[`R+GJP#``!6_Q.-9?A;#[[`7LG#B?95B>534(M5"(N"H`,`
M`(7`=%Z+F)P#``"+`X7`B9J@`P``B9JD`P``=2!J`&H`:@!J`&H`:@!J`%/H
M@ID!`(/$((7`N@$```!T'%"+@ZP#``!J`?]U$/]U#&H`:@!J`U/_4`0/OM")
MT(M=_,G#C78`BYJ<`P``ZZ!5B>564XMU"(N&H`,``(7`#X2"````BYB<`P``
MBPN%R8F>H`,``(F>I`,``'4@:@!J`&H`:@!J`&H`:@!3Z`:9`0"#Q""%P+H!
M````=!]2BX.L`P``:@'_=1#_=0QJ`&H`:@-3_U`$#[[0@\0@A-*X`0```'0*
MC67X6U[)PXUV`(/L#(N>K`,``%;_$XUE^%L/OL!>R<.)]HN>G`,``.EY____
MD%6)Y8M%",:`6`,```')PY!5B>6+10C&@%@#````R<.058GEBT4(#[Z`6`,`
M`,G#D%6)Y8M%",:`60,```#)PY!5B>6+10C&@%D#```!R<.058GEBU4(@+I9
M`P````^4P`^VP,G#C78`58GE4XM5"(G3`UT,.=IS%XL-0%L9"(GV#[8"]D0!
M`0-U"D(YVG+Q,<!;R<.+#41;&0@/O@0!@^AA@_@4=P?_)(7H_A@(N`$```!;
MR<,/MD(!@#P!:`^4P@^VPD!;R<.X`@```%O)PP^V6@&`/!EH#Y3`#[;`T>!;
MR<.)]E6)Y593@^P,BUT(4XMU#.@\@`$`@\00@_C_N@$```!T!4AT##'2C67X
M6XG07LG#D(M#$(`X_G7L]H/A`@``@'3C4/]U$(V3@@,``%)6Z%I.``"#Q`QJ
M"593Z,K/`0"#Q!"$P'40@^P,4^BRT`$`@\00A,!T08/L",>#7`(``-T'``"-
M@U,"``#_-8B))0A0Z,R>``!>6(NS7`(``/\TM0`G&0B-2U-1Z+2>``"Z`0``
M`.EP____@^P,4^B1?P$`@\000+H!````#X56____Z5/___^058GE5U93@>P,
M`@``BT4,A<"+?0B+=1`/A&<!``"%]@^$;P$``(/L"/]U#(V5Z/W__U+H59X`
M`(/$$(`^`(G#C5`!=#SVA^$"``"`#X2?````QD`!%(U(`E!6C8>"`P``4%'H
M85,``(U#%H/$$(M-%(/L"(7)=1JY]/H8".L3B?;&0`$`BTT4@^P(A<F-0`)T
MYE%0Z/2=``!`@\0,C8WH_?__BY>L`P``*<AJ`5!1:@!J`&H15_]2!(/$'(N?
MK`,``(V%Z/W__U905_]3.(V7J`,``(G#B10DZ".0`0"#Q!"%VW0HC67T#[[#
M6UY?R<.04%:-CX(#``!14NC93```C4,*@\00Z6/___^)]H/L#/^W=`(``.A*
M6```6/^W>`(``.@^6```6?^WC`(``.@R6```6%IJ$/]U#.CB6```B8=T`@``
M65AJ$%;HTE@``(MU%(F'>`(``(/$$#'`A?9T$(/L"&H0_W44Z+-8``"#Q!")
MAXP"``"-9?0/OL-;7E_)PXUV`(7VQT4,]/H8"`^%DO[__Y"^]/H8".F'_O__
MB?95B>5348M=".A/Z_W_A<!U%X/L"&A#_A@(4^C-G```@\00BUW\R<.0Z._J
M_?^%P'024FH04%/H-9T``(/$$(M=_,G#@^P0Z!'K_?^)!"3H^?#]_X/$$(7`
M=`2+`.O3@^P,:%C^&`CH<>O]_X/$$(7`=;^#[`QH2/X8".A=Z_W_@\00A<!U
MJX/L#&C+X`@(Z$GK_?^#Q!"%P'67N%#^&`CKD(UV`%6)Y8M%",>`:`,``(BY
M!@C'@&P#``#LMP8(QX!P`P``3+@&",>`=`,``%RZ!@C)PU6)Y5=64X/L'(M]
M"(V'^`(``(MW&('&[P\``(M8<('F`/#__X7;QD7O`8E%Y'0-BTATA<D/A>,`
M``")]L>':`,``(BY!@C'AVP#``#LMP8(QX=P`P``3+@&",>'=`,``%RZ!@B#
M[`AJ`%;HX54``(/$$(7`B47H#X0%`0``4XM-Y/^Q@````/]U#(U5\%+_47"#
MQ!"%P`^%G````%!6_W7H_W7PBUWD_U-T@\00A<")PP^."`$``%!3_W7H5^@>
MS`$`@\00A,!TTX/L"/\UB(DE"(V/4P(``%'H.IL``,>'7`(``-T'``!>6/\U
M=$89"(UW4U;H'YL``(/$$(/L#/]U\(M]Y/]7>%O_=>CHWU4```^^1>^-9?1;
M7E_)PXM0>(72#X04____BT!\A<`/A3'____I!/___U%J`&CT^A@(5^B:RP$`
MB3PDZ(K,`0!86O\UB(DE"(V'4P(``%#HMIH``(/$#&C_`0``C4=34/]U\(M=
MY/]3?(F'7`(``.EW____@^P(_S6(B24(C9]3`@``4^B!F@``7EB-=U/'AUP"
M``#8!P``_S5@1AD(5NAFF@``C67T6UZX`0```%_)PU!J`&CT^A@(5^@3RP$`
M@\00A,!U$(/L#%?H^\L!`(/$$(3`=$2#[`C_-8B))0B-EU,"``!2Z!^:``#'
MAUP"``#=!P``Z"#L_?^#Q`S_,(N/7`(``/\TC0`G&0B-=U-6Z+7N_?_IT?[_
M_X7;>`G&1>\`Z<?^__]0Z2K___^058GE5E.+=0AJ`/]U$/]U#/\VZ,%9``"#
MQ!"%P(G#>`R-9?B)V%M>R<.-=@"#[`S'1@0"````_S4`2AD(_W8(_S5(4AD(
M:/\!``"-1@Q0Z,6F``"#Q""-9?B)V%M>R<.058GE4U"+70B%VW0PBP.%P'D.
MB5T(BUW\R>DV5```B?:#[`AJ$%#H258``(E="(/$$(M=_,GI&E0``(GVBUW\
MR<.-=@!5B>575E.![(30`@"-=8B+70A64^@?Z_W_@\00,=*%P`^%N@```&:#
M?9(!#X>[````#[=%D"4`\```/0"@```/A*<```!1:`#P``!3C;V(+_W_5^A@
MZ_W_@^P(:B]7Z`7J_?^#Q"`QTH7`='2#[`C&``!65^B_ZOW_@\00,=*%P'5>
M#[=-D('A`/```('Y`$```'5,@^P(:`#P``"-G8@?_O]3Z!#M_?^)/"3H2.K]
M_UA::`#P``"-O8@/__]7Z/7L_?^^7?X8"/RY!````/.F#Y3"#[;RB1PDZ!KJ
M_?^)\HUE]%M>B=!?R<.)]HUE]%M>,=*)T%_)PU6)Y593@>P(!```BW4,:@!H
M#`(``.A>4@``B<.#Q!"+10B%VXD8N@$````/A(L```"#[`S&0PP`QT,$````
M`(ES"%;HP/[__X/$$(7`=3GH_.G]_XL(@^P,B4L$C97X^___45+_-4!2&0AH
M_P$``(US#%;H!*4``(UE^%NZ`0```(G07LG#B?:#[`QJ!&CT^A@(:/3Z&`A6
MC;7X^___5NA$;@``@\0<:@!J`%;H4U8``(/$$#'2A<")`W@)C67X6XG07LG#
MH0!*&0B#[`R)0P105NN058GE4U"+70B%VXM5#'064/]U$(U##%!2Z-.7``"+
M0P2+7?S)PX/L"/\U8$89"%+H.)<``+C8!P``BUW\R<.)]E6)Y8M5"(M%#(M-
M$(F":`,``(M%%(F*;`,``(F"<`,``(M-&(M%'(F*=`,``(F">`,``,G#C78`
M58GE5X/L"(M]#/PQP+G_____\J[WT4E1_W4,_W4(Z(V.`0"+??S)PU6)Y5=6
M4X'L+`0``(G&BP"%P,:%X_O__P%U'VH`:@!J`&H`:@!J`&H`5NC]C@$`@\0@
MA<`/A/P!```QP/Q7N?____^_8OX8"/*N]]%)46AB_A@(5N@OC@$`@\00A<`/
MA7@!``"#[`Q6Z#NF`0"#Q!"%P(F%Y/O__P^$7@$``(/L#/^UY/O__^BDJP$`
M@\00@_@%#X3M`0``@_@'#X5S`@``QX7<^___`0```,>%V/O__P0```#IZ@``
M`(GVBW@(BU`,@^P,BU@$B974^___BY78^___B9W0^____S20Z+KK_?^)A<S[
M___'!"0`````Z.R$`0"#Q!"%P(G##X03`@``@^P(A?]J`(GX#X3D`0``4.A*
M40``7UJ)@Q0#``!J`(N%U/O__X7`#X2J`0``4.@L40``6EF)@Q@#``"+A<S[
M__^)@P0#``!J`(N%T/O__X7`#X1D`0``4.@"40``B8,0`P``BX:,`@``@\00
MA<`/A2L!``"+AB`#``"%P`^%'0$``(7;QH.7`P````^$@@$``(N^G`,``(F[
MG`,``(F>G`,``(/L#/^UY/O__^ABI@$`@\00A<`/A%`!``"+C=S[__^%R0^%
M\?[__XN^=`(``(N6>`(``.GF_O__4VC_`0``C5Y34XV]Z/O__U?H7I4``(/$
M#&C_`0``_S6<1AD(4^A*E0``B<,I\[I2`@``@\0,*=I25U#H-)4``(/$$,>&
M7`(``.<'``"-9?1;7K@!````7\G#4&C_`0``C5Y34XV]Z/W__U?H!)4``(/$
M#&C_`0``_S6D1AD(4^CPE```B<$I\;I2`@``@\0,*<I25U#HVI0``(/$$,>&
M7`(``.D'``#KI,>%W/O__P````#'A=C[__\"````Z0;___^)]H/L"&H`4.BU
M3P``@\00B8,@`P``Z<K^__^-=@"+AG`"``"%P`^%CO[__XN&$`,``.F#_O__
MC78`BX9X`@``A<`/A4C^__^+AA@#``#I/?[__XUV`(N&=`(``(7`#X4._O__
MBX84`P``Z0/^___&A>/[__\`B[7D^___A?9T$8/L#/^UY/O__^@(=P$`@\00
M#[Z%X_O__XUE]%M>7\G#B?95B>575E.!["`"```QP,:%Y_W__P'\N?____^_
M<_X8"/*N]]%)46AS_A@(_W4(Z!6+`0"#Q!"%P'5J@^P,_W4(Z".C`0"#Q!"%
MP(G&=%:#[`Q0Z'VD`0"#Q!"%P(G#=`J+`(7`#X6>````BUT(B9N8`P``B=CH
M1OS__X3`=0?&A>?]__\`A?9T#(/L#%;H8G8!`(/$$`^^A>?]__^-9?1;7E_)
MPU-H_P$``(M]"(/'4U>-M>C]__]6Z%.3``"#Q`QH_P$``/\UF$89"%?H/Y,`
M`(G!*TT(NU("``"#Q`PIRU-64.@HDP``BU4(QX)<`@``Y@<``(/$$(UE]%M>
MN`$```!?R<.-=@"`.``/A%G___^#[`Q6Z-:G`0"#Q!"#^`*Z`0```'<0A=(/
MA5;___^+10CI/O___X/L#(L#B87@_?___W,(Z!+H_?_'!"0`````B<?H2($!
M`(/$$(7`B<,/A+4```"#[`AJ`(M5"(N"=`(``(7`=0:+@A0#``!0Z)U-``!:
M68F#%`,``&H`BU4(BX)X`@``A<!U!HN"&`,``%#H>DT``%I9B8,8`P``B;L$
M`P``:@"+A>#]__^%P'1D4.A:30``BU4(B8,0`P``BX*,`@``@\00A<!U*(M-
M"(N!(`,``(7`=1N%V\:#EP,```!T)HM]"#'2B9^8`P``Z2/___^#[`AJ`%#H
M$4T``(/$$(F#(`,``.O/N@$```#I`____XM5"(N"<`(``(7`=8^+@A`#``#K
MAXUV`%6)Y593BW4(BX:8`P``.?!T#8"XEP,````/A+D```"#[`QJ`.@[@`$`
MB<.#Q!`QP(7;='>+112#[`B%P&H`#X2\````4.B:3```6EF)@Q0#``"+11B%
MP&H`#X2]````4.A_3```6EF)@Q@#``"+11")@P0#``"+10R%P&H`=&U0Z%],
M``")@Q`#``"+AHP"``"#Q!"%P'4HBX8@`P``A<!U'L:#EP,```")V(7`B8:8
M`P``#Y3"C67X6P^VPE[)PX/L"&H`4.@93```@\00B8,@`P``Z\R)]H/L#%#H
M"X,!`(/$$.DV____C78`BX9P`@``A<!UB8N&$`,``.N!B?:+AG0"``"%P`^%
M-O___XN&%`,``.DK____C78`BX9X`@``A<`/A37___^+AA@#``#I*O___XUV
M`%6)Y593@^P,BW4(:@#H&G\!`(/$$(7`B<,/A+D```"#[`AJ`(M%%(7`#X2U
M````4.AW2P``6EF)@Q0#``!J`(M%&(7`#X2V````4.A<2P``6EF)@Q@#``"+
M11")@P0#``!J`(M%#(7`#X2N````4.@X2P``B8,0`P``BX:,`@``@\00A<!U
M,8N&(`,``(7`=2>%V\:#EP,```!T/(N6G`,``(F3G`,``(F>G`,``(UE^%LQ
MP%[)PY"#[`AJ`%#HZ4H``(/$$(7;B8,@`P``QH.7`P```'7%D(UE^%NX`0``
M`%[)PXN&=`(``(7`#X4]____BX84`P``Z3+___^-=@"+AG@"``"%P`^%//__
M_XN&&`,``.DQ____C78`BX9P`@``A<`/A43___^+AA`#``#I.?___XUV`%6)
MY8M-"(M10#'`.U$\<PV-!)+!X`1"`T$(B5%`R<.058GE4U"+70B+4T@QP(72
M=`J+0PR%P'4(BT,4BUW\R<-0BTM0_W,\4O]S%/]1$(/$$(M#%.OEB?95B>56
M4XMU"(M&##';A<!T*XM5#(/"_XM-$(/1_XM8#(G0(<A`=!60A=MT$(/"_X/1
M_XG0(<A`BQMU[9#'1D@`````B5X06U[)PXGV58GEBU4(BTT,BT(0QT)(````
M`(E*$,G#58GEBU4(BTT,BT)`B4I`R<.-=@!5B>575E.![!0!``!HA?X8"(VU
MZ/[__XM=#%;H\(T``(/$$(7;B=]T!8`[`'4Z_%"Y_____S'`B??RKO?125%6
M_W4(Z(2%`0"#Q!`QTH7`=0V#[`S_=0CHD)T!`(G"C67T6UZ)T%_)PX/L"&B4
M_A@(4.B:C0``B@N#Q!"$R8G"=#"-1>(YPG(>ZSV)]H#Y)W0:B@^("D>*!T*$
MP(C!=!R-7>(YVG,-@/E<=>'&`EQ"Z^"*`X3`=`3&`B5"Q@(GQD(!`.EG____
MB,CKZ)!5B>575E.![!0!``!HG/X8"(VUZ/[__XM=#%;H)(T``(/$$(7;B=]T
M!8`[`'4Z_%"Y_____S'`B??RKO?125%6_W4(Z+B$`0"#Q!`QTH7`=0V#[`S_
M=0CHQ)P!`(G"C67T6UZ)T%_)PX/L"&B4_A@(4.C.C```B@N#Q!"$R8G"=#"-
M1>(YPG(>ZSV)]H#Y)W0:B@^("D>*!T*$P(C!=!R-7>(YVG,-@/E<=>'&`EQ"
MZ^"*`X3`=`3&`B5"Q@(GQD(!`.EG____B,CKZ)!5B>53@^P(BUT(BY/@`@``
MP>H)@^(!@_H!&<"#X/Z#P`A0:@!3Z*9X`0")PH/$$#'`A=)T(8L"@^P,B8/H
M`@``_[/@`@``:@%0C8N8`@``45+HFG0!`(M=_,G#D%6)Y5=64X'L(`$``&B`
M````BT40A<`/A-0```!0@^P(:(````#_=0R-M=C^__]6Z&R,``!`@\044.AB
MC```B<-8_W4(Z)=K`0"#Q`R+50B+@JP#```I\VH!4U9J`&H`:@12_U`$@\0@
MA,!U>(/L#(M-"(NYK`,``%'_5QB#Q!"%P(G#=%^#[`AJ,&I4Z,-%``")PH/$
M$#'`A=)T/HM-"(G.BX&L`P``C7H<@<:8`@``_+D(````\Z6+?0B)0E"+A^@"
M``#'AY0"````````B4(\B5H(QD),`8G0C67T6UY?R<.)]HUE]%M>,<!?R<.)
M]KCT^A@(Z2+___^)]E6)Y593@^P4BUT(BX.L`P``:@!J`&H`:@!J`&H*4_]0
M!(/$(#')A,`/A8\```"#[`Q3Z*UJ`0"-=?2+4Q")5?2)-"3H^&<!`(G&BX/@
M`@``P>@)@^`!@\0,@_@!&<F#X?Z#P0>+DZP#``!1:@!3_U((@\00,<F%P'1#
M@^P,_[/@`@``:@!6C8N8`@``45#H!7,!`(/$(#')A<")@Y0"``!T&X/L#,>#
M?`,```$```")L^@"``!3Z$&:`0")P8UE^%N)R%[)PXGV58GE@^P,BTT,BU4(
MB$W_BXJL`P``:@!J`8U%_U!J`&H`:@A2_U$$#[[`R<-5B>6#[`R+30R+50B(
M3?^+BJP#``!J`&H!C47_4&H`:@!J!U+_400/OL#)PU6)Y8/L#(M-#(M5"(E-
M_(N*K`,``&H`:@2-1?Q0:@!J`&H,4O]1!`^^P,G#58GE@^P,BTT,BU4(9HE-
M_HN*K`,``&H`:@*-1?Y0:@!J`&H;4O]1!`^^P,G#C78`58GE@^P,BT4(BY"L
M`P``:@!J`&H`:@!J`&H-4/]2!`^^P,G#58GE4U.+70B+0Q"+D]0"``#&!!``
MBT,0@#@`=`>+7?S)PXGV@^P(C8M3`@``_S6(B24(4>A'B0``QX-<`@``V0<`
M`%I9_S5D1AD(@\-34^@LB0``B=B+7?S)PY!5B>53@^P(BUT(BX.L`P``:@!J
M`&H`:@!J`&H)4_]0!(/$((3`=`F-0U.+7?S)PY"+DZP#``"+2C")70B+7?S)
M_^&)]E6)Y8/L#(M%"(N0K`,``&H`:@!J`&H`:@!J#E#_4@0/OL#)PU6)Y8M%
M"(N`@`(``,G#B?95B>575E.#[!"-7?!J"HM5"%/_LH`"``#HK]C]_X/$#&H*
MBTWP05-1B<?HG=C]_X/$#&H*B<:+1?!30%#HB]C]_XT4OXT\DHT<MHTTOXT,
MFXT<MHUE],'C!(T4BUM>C00"7\G#58GEBT4(BX"$`@``R<.)]E6)Y8M%"(N`
MY`(``,G#B?95B>6XK,`(",G#B?95B>6XKYP``,G#B?95B>6+10@/OD!,R<-5
MB>6+10R-!("+50C!X`0#0@C)PU6)Y8M%"(M`",G#D%6)Y8M%"(M`$,G#D%6)
MY8M%"(M`0,G#D%6)Y8M5"(N"I`,``(N`Z`(``,G#58GEBU4(BX*D`P``BY"\
M`@``BX"X`@``R<.)]E6)Y8M5"(N"I`,``(N0Q`(``(N`P`(``,G#B?95B>6+
M10@%4P(``,G#C78`58GEBT4(BX#T`@``R<.)]E6)Y8M%"(N`B`(``,G#B?95
MB>6+10B+@-`"``#)PXGV58GEBU4(BX*0`@``BT`0R<.-=@!5B>4QP,G#D%6)
MY3'`R<.058GEBTT(H1!&&0B)02RA#$89"(L5&$89"(E!**$41AD(.=")41C'
M03`!````<P*)T(E!',G#B?95B>6+50Q64XM-"(G3B<X#71#K(XH"P.@$#[;`
MBH`@4QD(B`$/M@*#X`^*@"!3&0B(00%"@\$".=IRV<8!`%LI\8G(7LG#B?95
MB>6#[`C_=1#_=0S_=0C_-=12&0CHQGD``,G#58GEBU4(BX*0`@``B44(R>FO
M>0``C78`58GE5U93@^P,BUT,BWT(B=@#11"+CY`"``"#Z`6+45B+=12)1?"+
M0@2%P(GW#Y5%[P-]&#G^=#P[7?`/@X\```"`?>\`#X6]````BA8/OL*#^!H/
MA.<```!_)8/X"@^$ZP```'\YA<!T5XGVB!-&0SG^=<2-9?2)V%M>7\G#B?:#
M^"</A-4```!_)8/X(G7<Q@-<QD,!(H/#`HGV1NO1@_@-=<C&`US&0P%R@\,"
MZ^R#^%QUM\8#7,9#`5R#PP+KV\8#7,9#`3"#PP+KSXUV`(GY*?&!P0`"``")
M31"-51!04E/_=1S_52"#Q!"%P(G#='L#11"#Z`6`?>\`B47P#X1&____C78`
M4(M%"(N(D`(``(M16%=64?]2!(/$$(7`#X0E____C5#_ZPB0B@Z("T9#2H/Z
M_W7T3D;I,?___Y#&`US&0P%:@\,"Z4W____&`US&0P%N@\,"Z3[____&`US&
M0P$G@\,"Z2____^-9?1;7C'`7\G#D%6)Y5=64X/L#(MU"(N.D`(``(M16(M"
M!(7`#Y5%\X!]\P"+70QT#XG?@#L`ZP:)]D>`/P!U^HH#A,")WG06B?:`??,`
M=2H\7'06B`9&0XH#A,!U[,8&`(UE]%M>7\G#D(![`0!TY$.*`X@&1NO?B?:+
M30A0BX&0`@``BU!85U-0_U($@\00A<!T&HU0_^L(D(H#B`9#1DJ#^O]U]$M#
MB@/KKHGVB@/KGE6)Y593BU4,BUT(BT40A=*+=12)@XP```!T!8`Z`'48C8N<
M`@``B74,B4T(C67X6U[)Z1&$``"0@^P(4HV3G````%+H`(0``(V+G`(``(EU
M#(E-"(/$$(UE^%M>R>GF@P``B?95B>575E.#[!B+10B+F*0#``!3BWT,Z+ED
M`0"#Q!!`N@$````/A*D```"+2Q"+<0$/MU$'B;>(````#[=Q!8/!"872B57L
MB4WP#X61````A?9T98N#[`(``*@"#X2K````@^P,C57P4NCO8`$`@\0,B8/(
M`@``B9/,`@``BX.L`P``:@=J`%/_4`B#Q!"%P+H!````=#V#[`S_L^`"``!J
M`%974.BS:P$`@\0@A<")1SBZ`0```'0;BTWLB;>4````B8^0````,=+'@_0"
M````````C67T6UZ)T%_)PXUV`%"+@ZP#``!J!VH`4_]0"(/$$(7`N@$```!T
MV(/L#%#H+&(!`(/$$.E#____@\@!B8/L`@``Z4?___^)]E6)Y593@^P(:C!H
MJ`(``(MU".CI/```@\00A<")PW1H4&@`"```:``(``!3Z'=1``"#Q`QH`!``
M`&@`$```C5-,4NAA40``QT-8#````%I9C4,@4/^VJ`,``.CA80``B8:H`P``
MB5LHQX.8`````0```(ES+,>#A````%3=!@B)V(UE^%M>R<-0_S6(B24(:-@'
M``!6Z*YA`0`QP.OCB?95B>575E.#[`R+70B#NY@````!C7,\?E"+1@R%P(M[
M+'52A?]T+HN+E````(7)="2#NY@````"?AN-LZ4"```YM[0#``!T>XN'?`,`
M`(7`=56-=@#'@Y@````"````QX.$````5-T&"(UE]%M>,<!?R<.)]H/L"&H!
MC5-,4NC>4@``@\00QT8,`````,=#/`````#'0T``````QT-P`````.E\____
M@^P,BY>L`P``5_]2%(/$$,>'?`,```````#KDL>'M`,```````#I=O___XUV
M`%6)Y5=64X/L#(MU"(M>+(7;#X0:`@``@[Z8`````0^.KP```(U^/(M'#(7`
M#X4>`0``BXZ4````A<ET$(.^F`````(/CSL!``"-=@"#[`C'AI@````"````
MQX:$````5-T&",:&I`(```#&AJ,"````QX:4`````````,>&D`````````#'
MAHP`````````QH:<`````&H!5NCN40``BX:(````@\0,B47PBXNL`P``:@%J
M!(U]\%=J`&H`:AE3_U$$@\0@A,!U+L>&F`````$```!1B[NL`P``:@'_=1#_
M=0QJ`&H`:A93_U<$@\0@A,`/A,T```")V(N37`(``(/`4XV[4P(``(F6C```
M`'0&@'M3`'4B@^P(5XV6G`(``%+H+H```(/$$+@!````C67T6UY?R<.)]H/L
M"%"-GIP```!3Z`R```"#Q!#KR8UV`(/L"&H!C59,4N@N40``@\00QT<,````
M`,=&/`````#'1D``````QT9P`````.FP_O__B?:-OJ4"```YN[0#```/A.,`
M``"+@WP#``"%P`^$J/[__X/L#(N3K`,``%/_4A2#Q!#'@WP#````````Z8G^
M__^0@^P(BX.L`P``5E/_4!R#Q!"$P`^%&O___XN^E`````.^D````(T,_0``
M```I^8/L",'A`U%6Z'E/``"#Q!"%P(G!B48P=%.+AI````"-/,4`````*<>-
M'/DQP(E>-,>&F`````(```#I_?[__X/L",>&C````-T'``"+'8B))0C_-71&
M&0B-AIP```!0Z/Y^``!86E/IO/[__X/L",>&C````-@'``"+'8B))0C_-6!&
M&0CKT<>#M`,```````#I#O___U6)Y593BW4(BXZ4````,<"%R70V@^P(:C!J
M5.CD.```@\00A<")PG0HBTXLBYFL`P``QD!,`8E84(N.E````(M&.(E""(E*
M/(G0C67X6U[)PX/L",>&C````-@'``"-EIP```#_-6!&&0A2BQV(B24(Z%9^
M``!86E.-AIP"``!0Z$=^``"#Q!`QP.N^58GE,<#)PY!5B>6+10R+50B+0`B+
M2@R*`(@!_T(,R<-5B>6+50R+30B+0@AFBQ"+00QFB1"#P`*)00S)PXUV`%6)
MY8M5#(M-"(M""(L0BT$,B1"#P`2)00S)PY!5B>6+30Q3BT$(BUT(BQ"+2`2+
M0PR)$(E(!(/`"(E##%O)PY!5B>6+30R+50B+00B+`(M*#(D!@T(,!,G#C78`
M58GE@^P(BU4,BT((BU`$BP"+30B)1?B)5?R+00R+5?B)$(M5_(E0!(/`"(E!
M#,G#58GE5E.#[!"+30R+40B`>AP`#Y5%Z8M"#(M:"(A%[HM*$(A-[XE=ZHM:
M%(A=\(M"&(E%\8M*&(7)BW4(N`P```!U)HM:#(7;=1J+2A"%R743BUH4A=MU
M#(M*"##`A<ET"(UV`+@(````C5@!4E.(1>B-1>A0_W8,Z)?,_?\!7@R-9?A;
M7LG#D%6)Y593@^P0BUT,BU,(BTH$QT(8`````(L"QT(4`````,="$`````#'
M0@P`````B$WKBUH(B%WL9HE%Z8M"#(A%[8M*$(A-[HM:%(A=[XM"&(E%\(M*
M&(7)BW4(N`L```!U,8M*#(7)=4Z+0A"%P'5'BUH4A=MU0(L*A<EU$(M"!(7`
M=0F+6@@QP(7;=`:X!````)"(1>B-6`%24XU-Z%'_=@SHY,O]_P%>#(/$$(UE
M^%M>R<.-=@"X!P```(A%Z(U8`5)3C4WH4?]V#.B[R_W_`5X,@\00C67X6U[)
MPXGV58GE5E.#[!"+70R+4PB+2@2+`HA-ZXM:"(A=[&:)1>F+0@R(1>V+2A"(
M3>Z+6A2(7>^+0AB)1?"+2AB%R8MU"+@+````=3&+2@R%R75.BT(0A<!U1XM:
M%(7;=4"+"H7)=1"+0@2%P'4)BUH(,<"%VW0&N`0```"0B$7HC5@!4E.-3>A1
M_W8,Z"#+_?\!7@R#Q!"-9?A;7LG#C78`N`<```"(1>B-6`%24XU-Z%'_=@SH
M]\K]_P%>#(/$$(UE^%M>R<.)]E6)Y5=64X/L$(MU#(L^,=*+'U)3BTT(_W$,
MZ`U9`0"#Q`Q3_W8(B<=0Z+K*_?^-!!^+50B)0@R-9?1;7E_)PY!5B>575E.#
M[#R+10B+D)````"%T@^$@@```("XHP(```"+>"QT6HN'?`,``(7`#X3T````
MBU4(@^P(BQV(B24(QX*,````W@<``/\U>$89"(G0!9P```!0Z*MZ``!?6%.+
M30B!P9P"``!1Z)EZ``"#Q!"X`0```(UE]%M>7\G#D(/L"(L=B(DE",>`C```
M`.\'``#_-;Q&&0CKMY"+30B+@8@```"+62R)FZ0#``")1<C&1<P`QT7-`0``
M`%9J`6H`:@!J"8U]R%=J%U/H4X<!`(/$((3`#X2$`0``B=B+DUP"``"+30B#
MP%.-LU,"``")D8P```!T"H![4P`/A1X!``"#[`A6BWT(@<><`@``5^CS>0``
MN`$```"#Q!`/OL"-9?1;7E_)PX/L#%?HRZ8!`(MU"(N>D````(M/#(/#!XG.
MP>L#*W<$C50S`8/$$#'`.U<8#X>L````A,`/A=H```!64VH`4>A<S?W_B=F+
M70B+LY````"-!/4`````*?"+4S`#3PR--,*)3PR)=<2*@Z("``"(`8M7#$*)
M5;R)5PR#Q!"`NZ("````#X3Z````BXN0````BUV\*U\$C01+,=([1Q@/A\`!
M``"$TG5MBU4(BUHP.UW$B=D/@\X!``"+1PR0@'DH`(M1#'0#@,Z`@\$X9HD0
M@\`".TW$B4<,<N/IJP```(/L"%)7Z&"E`0"+3P0!\8/$$(E/#.DZ____@^P(
MB<M0@<.<````4^C6>```@\00Z<C^__^)]HN'7`(``(M5"(/L"(L=B(DE"(F"
MC````/\TA0`G&0CI\/W__X/L#(NSK`,``%/_%H/$$(3`#X5E_O__B[NX`@``
MBY.\`@``BTT(B7ETB5%XBX/``@``B[/$`@``B4%\,<`/OL")L8````#I=?[_
M_XMU"(M>,#M=Q(G><ACI\0```(UV`,9&*0"#QC@[=<0/@]@```"`?BD`=>J+
M30B+42R)5<"+7@2`.P!T)8M.((G+N`$```"#X0?!ZP.+4@33X`@$&C'`A<!T
MO^EH_?__B?:+5<"+!HM:#"M:!(L(C00+BTW`,=([01@/ASL!``"$TG1+BU4(
MBUW`BXM<`@``@^P(B="+'8B))0B)BHP````%G````/\TC0`G&0A0Z*MW``!8
M6E.+70B!PYP"``!3Z)EW``"#Q!"X`0```.N(@^P(5O]UP/]6+(/$$.ET____
M@^P(4%?HVZ,!`(C"`U\$@\00B5V\B5\,Z2/^__^+=PR)=;R+=;PK=P10:@!6
M_W<$Z#0R``"#Q!"%P(G'#X3Z````BU4(BXJ(````BUHLB9ND`P``B4W8QD7<
M`,=%W0$```!0:@%65VH)C4784&H74^@DA`$`@\0@A,!T>XN#7`(``(M-"(F!
MC````(G8@\!3C;-3`@``=`J`>U,`#X6[````@^P(5HM-"('!G`(``%'HR'8`
M`(/$$+@!````BW4(@^P,B,/&AJ("````5^B#,0``#[[#Z1+\__^#[`A04>@!
MHP$`BTW``UD$@\00B,*)60SIJ/[__X/L#(NSK`,``%/_%H/$$(3`#X5N____
MBY.X`@``BXN\`@``BW4(B59TB4YXBX/``@``BY/$`@``B49\,<")EH````#K
M@8M%"(/L"(L=B(DE",>`C````-@'``#_-6!&&0CI:OO__X/L"(G+4('#G```
M`%/H#G8``(/$$.DK____B?95B>53BTT(BU%PA=*+70QT#XM"!(D#BP*)07!;
M,<#)P\<#`````+AD````6\G#B?95B>575E.#[`R+?0B+=RR%]HM=#,=%\`$`
M```/A.@```"#OGP#```!=&**CZ4"``"`^0$9TH/BW('"`@@``(/L"(F7C```
M`(V'G````/\TE0`G&0A0BQV(B24(Z'1U``!86E.-CYP"``!1Z&5U``"#Q!"-
MAZ4"```YAK0#``!T/(M%\(UE]%M>7\G#D(/L"(N&K`,``%-6_U`H@\00A<!U
M)XL3,<"%TG7:QX9\`P```````,=%\&0```#KML>&M`,```````#KN(GPBY9<
M`@``@\!3C9Y3`@``B9>,````=`:`?E,`=6.#[`A3C9^<`@``4^C==```@\00
MQX9\`P```````.EI____@^P(QX>,````W0<``(V7G````/\U=$89"%*+'8B)
M)0CHIG0``%E>4XV'G`(``%#HEW0``(/$$+@!````Z3G___^#[`A0C8^<````
M4>AZ=```@\00ZXB058GE5E.+=0B#OI@````!N&0```!_/(/L",>&C````.X'
M``"-EIP```#_-;A&&0A2BQV(B24(Z#ET``!86E.-AIP"``!0Z"IT``"#Q!"X
M`0```(UE^%M>R<.-=@!5B>6+50R%THM-$+@!````=1,QTH7)=`**$8M%"(B0
MI@(``#'`R<.058GEBTT,A<FX`0```'41BTT(BT40#[Z1I@(``(D0,<#)PXGV
M58GE5U93@^P,BWT(BU\LA=L/A(\"``"#OY@````!C7<\?E6+3@R%R0^%1@(`
M`(NWE````(7V="R#OY@````"?B.-EZ4"```YD[0#```/A+,"``"+BWP#``"%
MR0^%A@(``(UV`,>'F`````(```#'AX0```!4W08(@^P,B[.L`P``5_]6((/$
M$(7`N@$````/A9$```"+D^@"``"%TG11BY^4````A=L/A(,```"+=RR-%)O!
MX@2+CI0"``"--`HY\8M7.',PB?:+64B+01R)6DB+64R)0AR)6DR+04"+642#
MP5")0D")6D2#PE`Y\7+8BY^4````A=O'AY@````#````=""+3RR-EZ4"``")
MD;0#``#'AX0```#TVP8(QH>E`@```#'2C67T6UZ)T%_)PXMW+(N>I`,``(N#
MZ`(``(T,@(/L",'A!(F'E````%%7Z)M"``"#Q!"%P(E'.'21BX^4````C13-
M`````"G*@^P(P>(#4E?H=4(``(/$$(7`B4<T#X1G____BYN4`@``B5WPBY^4
M````C02;P>`$BW<X`T7PA?:)1>P/A$?___\Y1?`/@S[____K(XE&&,=&(```
M``"#1?!0@\90#X0?____BT7L.47P#X,3____@^P(BU7P_W(05^BH10``6UJ+
M7?")1A#_<PA7Z)=%``!:68M-\(E&"/]Q#%?HAD4``%E;B48,BT7P_S!7Z'9%
M``!;6HM5\(D&_W($5^AF10``BU7PBUI(BTH<B48$B5Y(BT),BUI`B4X<BTI$
MBU(8@\00B49,,<"%THE>0(E.1`^$6/___X/L"%)7Z"A%``"#Q!#I1O___X/L
M"&H!C4=,4.B"0@``@\00QT8,`````,='/`````#'1T``````QT=P`````.F(
M_?__@^P(QX>,````W0<``(V7G````/\U=$89"%*+'8B))0CH`7$``%A:4XV'
MG`(``%#H\G```(/$$+H!````Z3_^__^#[`R+@ZP#``!3_U`4@\00QX-\`P``
M`````.E>_?__QX.T`P```````.D^_?__C78`58GEBT4(BX"0````R<.)]E6)
MY8M%"(M0>(M`=,G#B?95B>6+10B+@)0```#)PXGV58GEBT4(BY"`````BT!\
MR<.-=@!5B>575E.#[`R+50B+@I````"%P(MU#,=%\`````!U&(.ZF`````$/
MCJ$!``"-9?1;7E_)PXUV`(T,Q0`````IP8M=",'A`\'I`HM[,/SSI8M]"(N7
MD````(TTU0````"+2S`IUHT4\3G1#X.D````C5D0ZTB-=@"#^`,/A"<!```/
MA^4```"#^`$/A+$!``"#^`(/A;\!``")V(E;\,<#`@```,=#'*C3!@B0A<!U
M`XE;\(/!.(/#.#G1<U>+0_2+=?#_1?"%P(ES$,9#&0!U!\=#]`"T)@B+0_R#
M^`=T4':6@_@+#X2E````=UN#^`@/A#0!``"#^`H/A5D!``"+0_#'0QS<U`8(
MQP,%````ZYN-=@"+?0C&AZ("```!QH>C`@```8UE]%M>,<!?R<.0BT/PQT,<
MO-4&",<##````.EG____C78`@_@,=.,M^0```(/X!0^'_0```(M#\,=#'(#6
M!@CI0O___XGV@_@%#X2>````=TB)V(E;\,<#!````,=#'`C4!@CI'O___XGV
MBT/PQT,<5-0&",<##0```.D'____C78`B=B)6_#'`P0```#'0QS(TP8(Z>W^
M__^+0_#'0_0<1AD(Z=[^__^#[`B)T8L=B(DE",>"C````.X'``"!P9P```#_
M-;A&&0A1Z'MN``!?6%.+10@%G`(``%#H:FX``(/$$+@!````Z1K^__^)V(E;
M\,<#"````,=#'"34!@CI@O[__XG8B5OPQP,(````QT,<Y-,&".EK_O__B=B)
M6_#'`P$```#'0QR0TP8(Z53^__^#[`C_-8B))0B+30B!P9P"``!1Z`!N``#_
M=?#_<_R+50B)T\>"C````/0'``"!PYP```#_-=!&&0A3Z)G"_?^X`0```.F,
M_?__C78`58GE5U93@^P<BWT(BTT,.8^0````#X;5````C33-`````"G.BU<P
MC1SRBT,,+?D```"#^`5W<8M5%(72=0J`>RD`#X7H````BX>(````BW<LB478
M9HE-W,9#*0%0BYZL`P``:@'_=13_=1!J!HU-V%%J&%;_4P2#Q""$P`^$K@``
M`(GPBY9<`@``@\!3C9Y3`@``B9>,````='V`?E,`='>#[`A0ZV*0@^P(_S6(
MB24(C8><`@``4.@/;0``@\0,_W,@C8^<````QX>,````\P<``/\US$89"%'H
MK<']_Y"-9?1;7K@!````7\G#C78`@^P(BQV(B24(QX>,````\@<``/\UR$89
M"(VWG````%;HMVP``(/$$(/L"%.-GYP"``!3Z*1L``"#Q!#KLXUV`(UE]%M>
M,<!?R<.)]E6)Y5=64X/L+(G#BW@(BT`,@_@,QT7H`````'<'_R2%//\8"(M+
M&(MU"`'1C00R.<%S.8G&BT,0*<Z%P'05.?!V`HGP4E!15^CCN_W_@\00BT,0
M.?!V!,8$-P"+.XM5"(D7C67T6UY?R<.)]C'VZ^"#[`B-3>A1:@!J"O]U"%)H
M(%L9"*%X6QD(_U!(B`>#Q""-=@"-9?1;7E_)PX/L"(UUZ%9J`&H*_W4(4F@@
M6QD(BQUX6QD(_U-(@\0@9HD'ZZ&#[`B-3>A1:@!J"O]U"%)H(%L9"*%X6QD(
M_U!(B0>#Q"#KL(/L#(U-Z%&-1=Q0_W4(4F@@6QD(BS5X6QD(_U98V5WLBT7L
MB0?KU(/L"(U=Z%-J`&H*_W4(4F@@6QD(H7A;&0C_4%")1>")5>2+5>")%XM%
MY(E'!(/$(.E4____C4WH45?_=0A2Z!:(`0"#Q!#I#/___X/L#(U=Z%-J`%?_
M=0A2Z+.``0"#Q"#I(____X/L#(U%Z%"-==A6_W4(4F@@6QD(BQUX6QD(_U-8
MW5W0BU70B1>+1=2)1P3KFHGV58GE5U93@^Q<B<:)UXM("(M20(M`#(/B((/X
M"'<*_R2%</\8"(UV`(/Z`1G2@^+L@\(*4HU-N%'_=0S_=0CHA70``(G#C46X
M*<.#Q!#V1T!`=1F#[`Q3C56XB?#H__W__X/$$(UE]%M>7\G#BU<<.=IVX(/Z
M%'?;45,!V%"-1;@!T%#HJ'(``(M/'(/$#"G946HPC46X4.@4OOW_BU\<@\00
MZZ^*10B(`>NYBU4(9HD1Z[&+10B)`8UE]%M>7\G#A=)T9HMU#(M]"%97WRPD
M@\0(A?9X:=U=X-U%X-E=W(M%W(D!Z]*+70B)&8M%#(E!!(UE]%M>7\G#A=)T
M&HM5#(M%"%)0WRPD@\0(A=)X*-U=X-U%X.L#WVT(W5VPBUVPB1F+1;2)003K
MQ]]M"-E=I(M%I(D!ZX'8!?#_&`CKT-@%\/\8".N/D%6)Y593@>QP`0``B<.+
M2`B+0`R#^`AW"/\DA93_&`B0BT)$@_@>=F2#[`C_=0S_=0B+11"#^`Y_2U"+
M0Q`]2@$``'8%N$H!``!0:*C^&`B-M9C^__]6Z`V^_?^#Q!AJ(%;HGFT``,8`
M`"GPB00DB?*)V.BA_/__@\00C67X6U[)PXUV`+@.````ZZZ0@^P,_W4,_W4(
M4&BO_A@(C;68_O__5NC!O?W_@\045NBX:0``Z[>+10B)`8M%#(E!!(UE^%M>
MR</9O8[^__]FBY6._O__M@QFB96,_O__W44(V:V,_O__W[V0_O__V:V._O__
MB[60_O__B3&+A93^__^)003KN]U%"-E=](M=](D9Z6C____9O8[^__]FBX6.
M_O__M`QFB86,_O__W44(V:V,_O__VQG9K8[^___I//___]F]CO[__V:+E8[^
M__^V#&:)E8S^___=10C9K8S^___?G8K^___9K8[^__]FBX6*_O__B`'I`___
M_]F]CO[__V:+G8[^__^W#&:)G8S^___=10C9K8S^___?&=FMCO[__^G7_O__
MD%6)Y5=64X'LS````(M*0(F%-/___XM"3(/A((/X#8G7=PK_)(6X_Q@(C78`
M@^P,_W4(Z.U$`0")!"2)PXM%"(L0BX4T____Z"C[__^+=0@!'H/$$(UE]%M>
M7\G#BUT(BS.%R6:+'@^%H`(```^_PYF#[`A24(GZBX4T____Z)+\__^+?0B#
M!P+KQXM5"(L"A<F*&`^%:0(```^^PYF#[`A24(GZBX4T____Z&7\__^+30C_
M`>N;BT4(BQA6:@;9`X/L"(N%-/___]T<).B+_?__BWT(@P<$Z77___^+30B+
M`8L8BW`$B=E3:@]648GZBX4T____Z&+]__^+?0B#!PCI3/___XMU"(L.@^P(
M_W$$_S&+A33____H]_O__^O;BU4(BP*%R8L`#X7-`0``F8/L"%)0B?J+A33_
M___HT_O__^N.@^P,_W4(Z-9#`0"#Q!"%P(UUN(G!#X2X`0``BT4(BQ`/OQJ)
M7;@/MGH"B7V\#[9"`XM="`'*QD74`(E%P,=%S`````#'1<@`````QT7$````
M`,=%T`````#'1=@`````B1/I%@$``(/L#/]U".AO0P$`@\00A<"-M6C___^)
MP0^$90$``(M%"(L0BAJ(782+>@&)O7#___\/MD(%B85T____#[9:!HF=>/__
M_P^V>@<QP(/Y"(F]?/___W8#BT((B488BT8(A<#'1@0`````QP8`````=!"-
M/$#!YP,!?@S'1@@`````QT8@`@```.F"````@^P,_W4(Z.-"`0"#Q!"%P(VU
M./___XG!#X32````BUT(BQ/&A53___\`#[\ZB;TX____#[9"`HF%//___P^V
M6@.#^02)G4#___\/ALP````/MEH$B9U$____#[9Z!8F]2/___P^V0@:)A4S_
M__\QP(/Y!W8#BT('B488QT8@`0```(T$"HM-"(D!BY4T____BT(,@_@'=&YW
M9(/X!@^$>_W__X/L"(U]F%=6Z/*+`0")!"2)^HN%-/___^A^^/__Z5;]__\Q
MTNDM_O__#[;#,=+ID?W__P^WPS'2Z5K]__^#[`AJ`%;H%XL!`(/$$.N:@^P(
M:@'K[H/L"&H"Z^>#Z`J#^`)WG8N=-/___XM["/RY"0```/.EZ0+]___'A4S_
M__\`````QX5(____`````,>%1/___P````#I+____XUV`%6)Y8M5#(M%"(M(
M"(L"B@"(`?\"R<.)]E6)Y5.+70R+$XM%"&:+"HM`"(/"`F:)"(D36\G#C78`
M58GE4XM=#(L3BT4(BPJ+0`B#P@2)"(D36\G#D%6)Y8/L"(M-#(L!BU`$BP")
M1?B+10B)5?R+4`B+1?B)`HM%_(E"!(,!",G#58GEBU4,BP*+"(M%"(M`"(D(
M@P($R<.058GE4X/L#(M=#(L+BP&+402)1?"+10B)5?2+4`B+1?")`HM%](/!
M"(E"!(D+@\0,6\G#D%6)Y5=64X/L&(M%"(MU#(M8"%;HR$`!`(/$$(7`B<%T
M:XL6B@*(0QR+>@&)>P@/MGH%B7L,#[9"!HE#$`^V0@>)0Q0QP(/Y"'<ZB4,8
MBT,(A<#'0P0`````QP,`````=!"-!$"-%,>)4PS'0P@`````QT,@`@````$.
MC67T6UY?R<.)]HM"".O!C78`QT4,`@```(E="(UE]%M>7\GI4HD!`(GV58GE
M5E.#[`R+10B+=0R+6`A6Z"5``0"#Q!"%P(G!=$B+%@^_`HD##[9"`HE#!`^V
M0@/&0QP`B4,(QT,4`````,=#$`````#'0PP`````QT,8`````,=#(``````!
M#HUE^%M>R<.-=@#'10P`````B5T(C67X6U[)Z=.(`0"-=@!5B>564X/L#(M%
M"(MU#(M8"%;HI3\!`(/$$(7`B<%T:(L6QD,<``^_`HD##[9"`HE#!`^V0@.#
M^02)0PAW,L=#%`````#'0Q``````QT,,`````#'`@_D'=@.+0@>)0QC'0R`!
M`````0Z-9?A;7LG##[9"!(E##`^V0@6)0Q`/MD(&B4,4Z\R0QT4,`0```(E=
M"(UE^%M>R>DSB`$`C78`58GE5U93@^P8BW4,5HM]".@'/P$`B<.+1Q"#Q!`Y
MV'8"B=A24/\V_W<(Z&VQ_?^+!XD8`1Z-9?1;7E_)PXUV`%6)Y5=64X/L&(M]
M"/]U#.C(/@$`BU\0@\00.<.)QG8"B<-14XM%#/\P_W<(Z"NQ_?^#Q!`Y7Q!T
M!XM7",8$&@"+'XM-#(DS`3&-9?1;7E_)PXUV`%6)Y8M-"(M%$(M1)`$0R<-5
MB>53@^P0BUT04^AH/@$``0.+7?S)PY!5B>564X/L#(M=$%.+=0SH3#X!``$#
M@\00.48@<P.)1B"-9?A;7LG#58GE5U93@^P,BT4(BY"4````A=*+=0S'1?``
M````=6"+50B#NI@````!N.X'``!^!&:X!`B+?0B#[`B)_HL=B(DE"(F'C```
M`('&G````/\TA0`G&0A6Z+Q@``!86E.+30B!P9P"``!1Z*I@``"#Q!"-9?1;
M7K@!````7\G#B?:-!-4`````*=#!X`.+70B)P8M[-,'I`OSSI8M5"(M:-(T,
M&#G+BW(X#X/R````B?:+4P2%TG4&C4,JB4,$BQ.%TG4%C5,<B1.+0PR+??#_
M1?"#^`F)>R#'0Q@`````="!W;H/X!`^$M0$```^'PP```(/X`@^$:@$```^&
MT@$``,=#,'3M!@C'`@0```"+1DR#^`=T;P^']0```(/X`P^$B`$```^'3@$`
M`(/X`0^$$P(```^&'@$``,=#-&#P!@C'0R0"````QT8@!@```.M"@_@-#X0+
M`0``#X>!````@_@+#X3'`0``#X:/`0``QT,P+.\&"(M&3(/X!\<")````'62
MD,=#-'#P!@C'1B`>````@\,X@\90.<L/@A#___^+50C&@J0"```!C67T6UXQ
MP%_)PX/X!@^$?@$```^"*`$``(/X!W2F@_@(#X6;`0``QT,PD.T&".D5`0``
MC78`/?D````/@H$!```]_`````^&T````#W^````#X=K`0``QT,P#/`&".D`
M____C78`@_@,=RN#^`H/@V;___^#^`C'0S1@\`8(#X3N````@_@)#X5]`0``
MQT8@"0```.MZ@_@-#X3P_O__+?<```"#^`@/AU8!``#'0S2(\`8(Z2____^0
MQT,P5.T&",<"`@```.F7_O__B?:#^`7'0S1@\`8(#X38````=W_'0R0$````
MQT8@2P$``.GU_O__C78`QT,PO.T&".E;_O__QT,T8/`&",=&(`L```#'0R0$
M````Z<S^___'0S#,[P8(Z3O^__](#X63````QT,P/.T&",<"`0```.DB_O__
MQT,PU.T&",<""````.D0_O__QT,PK.X&".EL_O__QT,D`````,=&(`````#I
M=O[__\=&(!4```#'0R0(````Z6/^___'0S`([@8(Z3K^___'`@````#IQ_W_
M_\=#-&#P!@C'0R0!````QT8@!````.DR_O__QT,D"````.DE____@^P(_S6(
MB24(BW4(@<:<`@``5NB470``_W7P_W,,BT4(QX",````]`<``/\UT$89"`6<
M````4.@PLOW_Z<3\___'0S1@\`8(@^P(_S6(B24(BUT(@<.<`@``4^A,70``
M_W7P_W9,BTT(QX&,````]`<``(G(_S701AD(Z[2-=@!5B>53@^P0BUT(4^@,
M/@$`@\000+H!````=!2+0Q`PTH`X_G0#C5`!BT4,B1`QTHG0BUW\R<.)]E6)
MY5=64X/L)(U%\%#_=0B+50C_DH0```"#Q!"%P`^%H````(M-"("YI`(```"+
M1?`/A*T```")QXM%"(N(E````(U9"<'K`P'[BU4(C33-`````"G.B5WLBUHT
MC13SBT4(BW`X.=/&1><$B57HZR"+4P3'0Q0`````Q@(!T&7G=07&1><!1X/#
M.(/&4#M=Z'-5BDWGA`]UUXM3!,8"`(M##(M-[#E&3(E+%'13@^P,C4WL48GR
MB=CH,_3__X/$$.N[B?:+?0C'AY@````"````QX>$````5-T&"(UE]%M>7\G#
MD(E%[(MU",>&F`````0```"-9?1;7C'`7\G#B?:#[`B-1>Q04_]3,(/$$.EJ
M____D%6)Y5=64X/L#(M-$(MU"(T$S0`````IR(M6-(.^F`````.+?0R-',(/
MCJ(````YCI0```!V5HM#%(7`#X2K````C12)P>($B47PBT<$`U8XBW44A<")
M=Q@/A9X```"+#X7)#X2A````BP.+&(D9@^P,C77P5HGXZ&#S__^#Q!`QP(UE
M]%M>7\G#C78`@^P(BQV(B24(QX:,````\@<``/\UR$89"(V^G````%?H+UL`
M`%E?4XV.G`(``%'H(%L``(/$$(UE]%M>N`$```!?R<.#[`B+'8B))0C'AHP`
M```#"```_S4,1QD(Z[J0BT<$A<!TC,8``3'`ZX>)]L8``(L/A<D/A5____^-
M2QR)#^E;____D%6)Y5=64X/L#(M%"(M0+(M="(M]"(/#2(N*I`,``(/'/(E=
M\(E5[(E-Z.M>BTWLBW$0@#[^=0F#^P</AM<```"#[`B-0PM0C5<04NB@*@``
M@\00A<")P@^$C````(M-\(U`#(D1B4($B57PC4X!C5/_5E)14.CRJ?W_@P<!
MBTWP@U<$`(E9"(/$$(/L#/]UZ.@G.P$`@\00@_C_B<-UC8M5[(G3B="+LEP"
M``"!PU,"``"+30B#P%.)L8P```!T!H!Z4P!U>X/L"%.+30B!P9P"``!1Z/-9
M``"#Q!"-9?1;7K@!````7\G#BW4(@^P(BQV(B24(QX:,````V`<``(GP_S5@
M1AD(!9P```!0Z+I9``"#Q!#KKP^W1@&+?>@/MUX#BU7PB8?T`@``QP(`````
MB9_L`@``C67T6UXQP%_)PX/L"%")R.N^C78`58GE5U93@^P<BU4(BTT(BT(L
MBYF4````@\(\B57LBX"D`P``,=*%VXE%W'14@[F8`````GX)@[A\`P```71-
M@^P(BWT(QX>,````W@<``/\U>$89"(''G````%>+-8B))0CH&5D``%A:BTT(
M5H'!G`(``%'H!UD``(/$$+H!````C67T6UZ)T%_)PY"+1>R+6`R%VP^%I@$`
M`(M5"("ZI@(```!T#8"ZI`(````/A*P```"#[`R+3=R+N:P#``#_=0C_5R2#
MQ!"%P`^%M@$``(M="("[I@(````/A)L!``"+?>R+1PR%P(E%Z`^$`0$``(UV
M`(M%"(NXE````(M-Z(U?"8MQ!,'K`P'SBTT(C13]`````"GZB5WPBUDTC033
MBWDX.</&1>,$B47DZQ6)]M!EXW4%QD7C`4:#PSB#QU`[7>0/@Y,```"*5>.$
M%G7@4(U%\%!74_]3-(/$$.O1B[*4````C0SU`````"GQP>$#,<"+>C3\P>D"
M\ZN+10B+F)0```"-/-T`````BTHT*=^-!/GK$XGVQT$,!@```,=!$`$```"#
MP3@YP7+K@^P(BU4(_W(T4NBL]O__@\00A,"Z`0````^%M?[__XM=",:#I`(`
M``#IV/[__Y"+?>B+-X7VB77H#X4(____BUWLBT,,BW4(BTWLBU4(BWD$B49P
MBUT(BP&+==S'@H0```#$VP8(,=*)0W2)>WC'AK0#````````B8:X`@``B;Z\
M`@``QX9\`P```````.E!_O__@^P(BW4(:@&#QDQ6Z&<H``"+50B+3>R#Q!#'
M00P`````QT(\`````,="0`````#'0G``````Z1_^__^+3>R+00SI;/___X/L
M"(M5[(/"$&H!4N@A*```BW7LBT7<N@$```#'1@P`````QP8`````QT8$````
M`,>`?`,```````#IO/W__XUV`%6)Y8M5"(M-#(M"<(E*<,G#C78`58GEBT4(
MBT!PR<.058GE5E.+70B+2TB%R8M%#(M5$'07C78`B=8)QG0.@\#_BPF#TO^%
MR77NB?:)U@G&B4MP=1B%R704QX.$````Q-L&",>#F`````,```!;7LG#C78`
M58GEBT4(BU!`BT`\R<.)]E6)Y5=64X/L%(MU"(M>+(U&3&H`4.A2)P``6%IJ
M`%;H2"<``#'_@\00A=L/A+\```"#[`B-3B!1_[.H`P``Z)4U``"+DUP"``"#
MQ!"%THF#J`,```^%L@```(.^F`````$/CHD```"-OJ4"```YN[0#```/A.H`
M``"+DWP#``"%T@^%L````(N6B````(E5\%>+NZP#``!J`6H$C47P4&H`:@!J
M&5/_5P0/OOB#Q""%_W0]C8-3`@``B47LB=B+BUP"``"#P%.)CHP```!T"H![
M4P`/A9D```"#[`C_=>R-EIP"``!2Z$E5``"#Q!")]H/L#%;H$Q```(/$$#'`
MA?\/E<"-9?1;7E_)PY"#[`C&0U,`QX-<`@```````(V#4P(``/\UA(DE"%#H
M!54``(/$$.DC____@^P,BXNL`P``4_]1%(N#M`,``(/$$(7`=`/&``''@WP#
M````````Z23____'@[0#````````Z0?___^#[`A0C9Z<````4^BR5```@\00
MZ4____^)]E6)Y5=64X/L#(MU"#'`@[Z8`````7Y6BWXLBXZ(````BY^D`P``
MB4WP48N3K`,``&H`:@!J`&H$C47P4&H:4_]2!(/$((3`=2^+OI````"+3C"-
M-/T`````*?Z-!/'K!\9!*0"#P3@YP7+U,<"-9?1;7E_)PXUV`(G8BY-<`@``
M@\!3C;M3`@``B9:,````=`:`>U,`=2"#[`A7C8:<`@``4.@!5```@\00C67T
M6UZX`0```%_)PX/L"%"-GIP```!3Z.%3``"#Q!#KRU6)Y8M%"(N`C````,G#
MB?95B>6+10@%G`(``,G#C78`58GEBT4(!9P```#)PXUV`%6)Y8/L#&H&:+3^
M&`C_=0CH4TL!``^^P,G#B?95B>6#[`QJ"&B[_A@(_W4(Z#=+`0`/OL#)PXGV
M58GE@^P(@'T,`(M%"'0546H0:,3^&`A0Z!-+`0`/OL#)PXGV4FH0:-7^&`A0
MZ/Y*`0`/OL#)PY!5B>6+50B+@J0#``"+@.P"``#!Z`.#X`')PXGV58GE4U.+
M70B+BWP#``"%R70^@^P(_S6(B24(C9-3`@``4NCY4@``6%J-0U/'@UP"``#>
M!P``_S5X1AD(4.C>4@``N@$```")T(M=_,G#B?:#[`C&0U,`QX-<`@``````
M`(V#4P(``/\UA(DE"%#HK5(``(N+I`,``(/$$/:![`(```C'@[@"``#_____
MQX.\`@``_____[K_____=*F#[`R+@ZP#``!3_U`T#[[0B="+7?S)PXUV`%6)
MY8M%"(N0K`,``(M*#,G_X8GV58GE@^P4BT4(BY"L`P``4/\2#[[`R<.058GE
MBT4,4S'2N____S^+30CW\XD1BT40,=+W\\=!"/___S_'00P``(#_QT$0___/
M08E1!%O)PY!5B>575E.+30B+.8MQ!(T$?P'PBWD(,=+W]XD1C40R(3'2]_>)
M400QTHL!4E#?+"2#Q`A;7MQQ#%_)PY!5B>575E.#[`B+70R+11`!V#G#OC57
M,%#'1?`'````OW%6-!*)1>QS-HUV`(H#/"!T)SP)=",/MLB)\(/@/P-%\(GR
MP>((#Z_!`=")^C'&P>((,?(!UP%-\$,[7>QRS8M="('F____?X'G____?XDS
MB7L$@\0(6UY?R<.058GE5U93@^P<BUT,,<")W_RY______*N]]&-3!G_.<N_
M-5<P4,=%Y`<```"^<58T$HE-X',UB?:*`SP@="<\"70C#[;(B?B#X#\#1>2)
M^L'B"`^OP0'0B?(QQ\'B"#'Z`=8!3>1#.UW@<LV)\X'C____?U.!Y____W]7
M:/3_&`C_=0B)?>B)7>SH?J7]_XUE]%M>7\G#B?95B>575E.#[&R+?1"%_P^$
M#`(``(`_``^$`P(``(M5#(M="(/""(E=K#'`B568_+G_____B?ORKO?1C4P9
M_SG+OC57,%#'1:@'````OW%6-!*)3:1S-8GVB@,\('0G/`ET(P^VR(GP@^`_
M`T6HB?(/K\'!X@@!T#'&B?C!X`@Q\`''`4VH0SM=I'+-BUT,BTV8@>;___]_
M@>?___]_.<N)=<")?<2^-5<P4,=%H`<```"_<58T$G,SB@,\('0G/`ET(P^V
MR(GP@^`_`T6@B?(/K\'!X@@!T#'&B?C!X`@Q\`''`4V@0SM=F'+-@>;___]_
MB?&)^S--P('C____?S'2B76XB<B^____/_?VB5V\,UW$B57(B=@QTHM]F/?V
M.7T,QT70____/\=%U```@/_'1=C__\]!B=8/@_````"_____/Y"+3<B-!$D!
M\#'2]_>)5<B-1#(A,=+W]XG6,=)2BTW(4=\L)-PU```9"(/L"-P-"``9"(M=
M"-T<)/]%".A`GOW_V7VV9HM%MK0,9HE%M-P%$``9"-EMM-]=LMEMMF:+5;*(
M$_]%#(M=F(/$$#E=#'*0BTW(C01)`?`QTO?WB57(C40R(3'2,?;W]U:+?<A7
MWRPDW#4``!D(@^P(W`T(`!D(B57,W1PDZ-6=_?_9?;9FBUVVMPQFB5VTV6VT
MWUVRV6VV@\009HM5LNL*B?:+?:S_1:PP%XM="#E=K'7PBW4(Q@8`C67T6UY?
MR<.+?=#K@9!5B>575E.#[&R+70R-0P@YP[XU5S!0QT6@!P```+]Q5C02B46<
M<S20B@,\('0G/`ET(P^VR(GP@^`_`T6@B?+!X@@/K\$!T(GZ,<;!X@@Q\@'7
M`4V@0SM=G'+-B?N!YO___W^!X____W^)=;")7;2+51")]S'V,SHS6@2Y____
M/\=%T/___S]64;[___\_B?@QTO?VWRPDC4VXB57(W574,=*)V(E-I(M]"/?V
M@\0(@#\`B=8/A)X```"-7<@YRW<-Z9(```")]MU%U(MUS(M-R(T$20'P,=+W
M==")5<B-1#(A,=+W==")5<PQTHM=I(MUR/]%I%)6WRPDWO&#[`C<#0@`&0C=
M'"3H@YS]_]E]KF:+3:ZU#&:)3:S<!1``&0C9;:S?7:K9;:YFBT6JB`-'@\00
M@#\`="6-7<@[7:1WB"M]"(/_"+@!````=!V-=@"-9?1;7E_)P]W8B57,*WT(
M@_\(N`$```!UYHMUR(M=S(T$=HM]T`'8,=+W]XE5R(U$&B$QTO?W,?:)5<R+
M?<A65]\L)-QUU(/L"-@-&``9"-T<).CHF_W_V7VN9HM5KK8,9HE5K-EMK-]=
MJMEMKH/$$&:+7:J-3;B+?0B*%X32=!N*`3'80?]%"#C"=.NX`0```(UE]%M>
MZ6G___^-9?1;7C'`7\G#B?95B>6+30Q75HM]"(7)4\='!`````#'!P````!T
M3HH1A-)T2)`QP#';ZQ.)]HU"R4,/MM"#^P>-!!9W)8H1B<:-0M#!Y@1!/`EV
MY8U"OSP9=MN-0JE##[;0@_L'C006=MN)!X/'!(H1A-)UN5M>7\G#58GE@^P(
MBT4,_W`$_S!H]/\8"/]U".B]H/W_R<.-=@!5B>575E.#[`R+=0B+10P!\#G&
MBWT0B47H<V+9??)FBU7RM@S9!1P`&0C9!2``&0AFB57PBQ^-!%N+7P0!V#'2
M]W<(B1>-1!HA,=+W=P@QP(E7!(L?4%/?+"3<=PS8RMC!V6WPWUWNV6WR9HM-
M[H@.1H/$"#MUZ'*[W=C=V,8&`(/$#%M>7\G#58GE5U93@>RX````C9UX____
M4^C40@``_#'`BWT,N?_____RKO?1@\0,25'_=0Q3Z,-&``!97O]U"%/HA$4`
M`(D<).BD0@``@\0,:A3_=0A3Z*)&``!86HVU6/___U93Z%]%``"+10B)\X/$
M$(U(`8VU;/___\8`*NLAD`^V.XGZP>H$BH(@4QD(B`&#YP^*ER!3&0B(40%#
M@\$".?-UW,8!`(UE]%M>7\G#D%6)Y5=64X'LR````(V=>/___U/H*$(``/R+
M?1`QP+G_____\J[WT8/$#$E1_W404^@71@``65Z-M5C___]64^C41```B1PD
MZ/1!``"#Q`QJ%%93Z/1%``!86HV5./___U)3Z+%$``")'"3HT4$``(/$#&H4
M_W4,4^C/10``@\0,:A2-A3C___]04^B]10``7UC_=0A3Z'Y$``"+50B)\X/$
M$(G1C7(4ZPR-=@"*`S("B`%#0D$Y\G+SC67T6UY?R<.-=@!5B>575E.![-@`
M``"-G7C___]3Z&1!``"#Q`QJ%/]U#%/H8D4``(/$#&H4_W404^A410``6%J-
ME5C___]24^@11```C;UL____C8U8____@\00B<Z+50@Y^>L,D(H",@%!0H@&
M1CGY<O.#[`Q3Z`I!``"#Q`QJ%(V56/___U)3Z`1%``!?6(V]./___U=3Z,%#
M``"+=1"Y%````/SSI@^2PP^7P8UE]"C96UX/OL%?R<.-=@!5B>575E-3BT4,
MC5@!@\`IBWT(.<.)1?#K2(GVBA.-0M!#/`EV#HU*OX#Y&7<^C4+)C78`#[;0
M#[[*BA.-0M#!X01#/`F)_HU_`78,C4*_/!EW(8U"R8GV#[;0"<J(%CM=\'*X
M65M>7\G#B?:-0JGKPXUV`(U"J>O?C78`58GEBT4(4\8`*HM5#(U(`8U:%)`/
MM@+!Z`2*@"!3&0B(`0^V`H/@#XJ`(%,9"$*(00&#P0(YVG7;Q@$`6\G#D%6)
MY<<%R%(9"$!&&0C)PY!5B>53@^P4@#TD1QD(`'4JH212&0C_!2!'&0B%P,8%
M)$<9"`''!0A*&0BP`0``QP4$2AD(P`$``'0*,<"+7?S)PXUV`(/L#&C'V`@(
MZ!^7_?^#Q!"%P*,D4AD(#X7R````@^P,:(0)&0CH`I?]_X/$$(7`=&.*$(32
MB<$/A.T````/ML*+'4!;&0CV1`,!"'04C78`08H1A-)T"@^VPO9$`P$(=>^#
M[`R-7?A3,<"`^C!H____?P^5P&H`C5P`"%-1Z!9*``"+5?B!RH`!``"#Q"")
M%0A*&0B#[`QHB@D9".B+EOW_@\00A<`/A$K___^*$(32B<%T?0^VPHL=0%L9
M"/9$`P$(=!%!BA&$TG0*#[;"]D0#`0AU[X/L#(U=]%,QP(#Z,&C___]_#Y7`
M:@"-5``(4E'HHDD``(M-](')P`$``(D-!$H9"(/$(#'`BUW\R<.#[`A0:"!*
M&0CH;PX``(/$$*,D4AD(Z?/^__^*$.DP____BA#KH(UV`%6)Y5=64X/L;(M=
M"/;#`8L]Q,(E"'05BQ402AD(H11*&0B)T0G!#X7D````Z!<F``"#XP)U"#L]
MQ,(E"'05@^P(C4684&H`Z%B9_?^#Q!"%P'01Q@4D1QD(`(UE]%M>7\G#B?:#
M[`C_==S_==C_==3_==#_=<S_=<C_=<3_=<#_=;S_=;C_=;#_=:B+5:"+7:2-
M-)*-#+:)V+ZMB]MH]^Z)592+193!^Q_!^`PIV(T,B-D%M`H9"%'9P-H\)(/L
M!-T<)(M5F(M=G(T$DHT,@(G8]^Z)19")592+=93!^Q_!_@PIWHT4CE+:/"2#
M[`3='"1HE`D9"%?HJ)?]_\8%)$<9"`"#Q%"-9?1;7E_)PXGV4%+_-8Q2&0AH
M(+0F".BBFOW_@\0,:@1H(+0F"&H3Z/42``"#Q!#I\?[__Y!5B>575E.#[`R+
M70B%VXM]#'4"LP&#[`Q3Z)J5_?^#Q!"%P(G&="B#YR!U#(UE]%N)\%Y?R<.)
M]E!3:@!6Z$:9_?^#Q!"-9?1;B?!>7\G#Z(27_?^+$(GXP>@#@^`!B14`2AD(
MB47P=1>#YQAU((M=\(7;=+>#[`QJ`>CYFOW_D(L-2$<9"(D-3$<9".O;45-J
M)&H%Z%<&``"#Q!#KT(GV58GEBT4(A<!T!LGI^)O]_\G#B?95B>575E.#[`R+
M?0R%_XG^=06^`0```(/L#%;HY)3]_X/$$(7`B<-T+O9%$"!U&597_W4(4^AZ
ME/W_@\00C67TB=A;7E_)PY!05FH`4^B"F/W_@\00Z]CHR);]_XL0BT40P>@#
MB<>#YP&)%0!*&0AU%_9%$!AU'X7_=,*#[`QJ`>@_FOW_C78`BPU(1QD(B0U,
M1QD(Z]M05FHD:@7HFP4``(/$$.O1B?95B>575E.#[`PQP/RY_____XM]"/*N
MB<OWTX7;B=YU!;X!````@^P,5N@NE/W_@\00A<")QW0P]D4,('4;4%/_=0A7
MZ,23_?^#Q!"-9?1;7HGX7\G#C78`4%9J`%?HRI?]_X/$$.O6Z!"6_?^+50R+
M&,'J`XD=`$H9"(G3@^,!=1?V10P8=1^%VW3`@^P,:@'HAYG]_XUV`(L-2$<9
M"(D-3$<9".O;4%9J)&H%Z.,$``"#Q!#KT8GV58GE5U93@^P,BWT,B?Y&=06^
M`0```(/L#%;HA9/]_X/$$(7`B<-T,_9%$"!U'E!7_W4(4^@;D_W_Q@0[`(/$
M$(UE](G86UY?R<.)]E)6:@!0Z!Z7_?^#Q!#KT^ADE?W_BQ"+11#!Z`.)QX/G
M`8D5`$H9"'47]D40&'4?A?]TP8/L#&H!Z-N8_?^-=@"+#4A'&0B)#4Q'&0CK
MVU%6:B1J!>@W!```@\00Z]&)]E6)Y593@^P,BUT(4^BGF?W_@\00A<")QG4F
M.QW\1QD(<PVA^$<9"(M4V`2%TG5%_PT02AD(C67X6XGP7LG#B?;HTY3]_XL`
M]D4,&*,`2AD(=,CHP93]__\P@^P(4^BB!@``@\0,4&HD:@3HP0,``(/$$.NF
M@^P,_S38Z&']__^+#?A'&0C'1-D$`````/\-$$H9"(/$$(UE^%N)\%[)PY!5
MB>575E.#[`R+=0B%]HM]&`^(I0```#LU_$<9"'(1_P402AD(C67T6XGP7E_)
MPY"#[`B+'?A'&0A7_W4,Z+K]__^#Q!"%P(D$\W0=BT40BQ7X1QD(B43R!/\%
M$$H9"(UE]%N)\%Y?R<.#[`Q6Z*:8_?^#Q!"%P'5S.S7\1QD(<RFA^$<9"(M<
M\`2%VW0<@^P,_S3PZ*?\__^+%?A'&0B#Q!#'1/($`````/\-$$H9",<%`$H9
M"`P```#K#.BWD_W_BP"C`$H9"(/G&0^$5/____\U`$H9"/]U#&HD_W44Z*P"
M``"#Q!#I.?___^B'D_W_BPCWQQ@```")#0!*&0@/A'3____H;I/]__\P@^P(
M5NA/!0``@\0,4&HD:@3H;@(``(/$$.E/____B?95B>575E.#[!"+?0C_-0A*
M&0C_=0Q7Z%&7_?^#Q!"%P(G&#XBD````.P7\1QD(<A#_!1!*&0B-9?1;B?!>
M7\G#@^P(BQWX1QD(_W405^A^_/__@\00A<")!/-T':'X1QD(QT3P!`$```#_
M!1!*&0B-9?1;B?!>7\G#@^P,5NAJE_W_@\00A<!U<3LU_$<9"',IH?A'&0B+
M3/`$A<ET'(/L#/\T\.AK^___BQWX1QD(@\00QT3S!`````#_#1!*&0C'!0!*
M&0@,````ZPSH>Y+]_XL`HP!*&0CV11`9#X14_____S4`2AD(5VHD:@#H<@$`
M`(/$$.D\____Z$V2_?^+$/9%$!B)%0!*&0@/A'C____H-I+]__\P@^P(5N@7
M!```@\0,4&HD:@3H-@$``(/$$.E3____B?95B>575E.#[`R+112+=1#!Z`F+
M?0R)=?")1>SH])']_\<``````%)65_]U".@CDOW_@\00.?")PW1RZ-61_?^+
M"(7)NO____]U=O9%%!J)%0!*&0AT#X/[_P^$F@```/9%%`9U<X/[_P^$IP``
M`/9%%`9T"O9%[`$/A)<```"%VW0J]D7L`70DZ(>1_?_'```````IWE)6`=]7
M_W4(Z+*1_?^#Q!`Y\(G#=8^0]D44!G0:,=N)V(UE]%M>7\G#B?;H3Y']_XL0
MZX&-=@#V1>P!=.*+7?#KW9!2@^P(_W4(Z!P#``"#Q`Q0:B1J">@[````@\00
MZ6S___]2@^P(_W4(Z/L"``"#Q`Q0:B1J`N@:````@\00N/_____KFE6)Y<<%
MP%(9"$!2&0C)PY!5B>575E.![%P!``"-51"XTTUB$(F5Q/[___=M"(M%",'Z
M!L'X'SG"=0Z+#<!2&0B%R0^$1P(``+C336(0]VT(BW4(P?X?P?H&*?*-')*-
M!)N-/(#!YP.+=0@I_HL,E<!2&0B+'+&)G:3^__\QP/RY_____XN]I/[___*N
M]]%)B8W`_O__B[6D_O__B@:$P(V=R/[__W0:D#PE=#3_A:3^__^(`T.+M:3^
M__^*!H3`=>?&`P!0_W4,C9W(_O__4_]U"/\53$<9"(UE]%M>7\G#_X6D_O__
MBXVD_O__BA&`^B4/A*P```"`^B[&A;O^__\`#X0M`0``#[;"BPU`6QD(ZQ.)
M]O^%I/[__XN%I/[__XH0#[;"]D0!`01UZ(#Z+G3C@/HM=-Z`^FP/A#T!``"`
M^G-T;8#Z9'0-@/IU=`C&`R7I7O___XN%Q/[__X.%Q/[__P2`^F2+``^$*P$`
M`%)J"E-0Z"@_```IV(N5P/[__P'"@\00@?H!`0``=\&#Z@(!P_^%I/[__XF5
MP/[__^D2_____XW`_O__Q@,EZ0/___^+M<3^__^+%H.%Q/[__P0QP/RY____
M_XG7\J[WT8"]N_[__P"-<?]T&(N-O/[__X7)?@X[M;S^__]V!HNUO/[__XN]
MP/[__P'W@?\!`0``B;VL_O__#X="____5U924^A7/0``BY6L_O__@^H"`?/_
MA:3^__^#Q!")E<#^___I@?[___^%I/[___^-P/[__XN%I/[__XH0@/HJ#X6V
M_O__B[W$_O__0(L7_XW`_O__@X7$_O__!(F%I/[__XF5O/[__\:%N_[__P'K
M!O^%I/[__XNUI/[__XH6Z;#^___H;/W__^FO_?__46KVZ=#^__^-=@!5B>53
M@>PH`0``C4444/]U#(V=V/[__U/H-XK]_X/$#/]U$%/_=0C_%4Q'&0B+7?S)
MPXGV58GEBPU,1QD(R?_A58GEBU4(.Q7\1QD(N`80&0AS%872>!6A^$<9"(M,
MT`2%R70(BP30D,G#B?:X#A`9",G#D%6)Y5=64X'L5`0``&HZC87(^___BW4,
M5HF%Q/O__^C=C/W_@\00A<!T'RGPC5@!4E-6C97(^___4NC>.P``B87$^___
M`=Z#Q!"#[`AH%Q`9"(U]V5?&1=@OZ'([``"-3=@IR(F%K/O__XH&BYW$^___
M1H/$$(FUJ/O__^L3C78`BY6H^___B@)"0XF5J/O__X3`B`,/A$H!``"`.R]U
MX<8#+XG>*[7$^___.[6L^___#X:F````B=HKE:S[__^+A:S[__^)E;S[___\
M.<")UHU]V(G!\Z8/A8````"+G;S[__\[G<3[__]TEDN*`SQ^#X2Q`0``/"X/
MA#`!```[G<3[__^)G<#[__]R#Y"`.R]T"4L[G<3[__]S\H![`7YT&(N%K/O_
M__PYP(G>C7W8B<'SI@^%2/___X/L"(U=V(N5P/O__U-"4NB$.@``B<.#Q!#&
M`"_I)____XUV`(G9B[VL^___*XW$^___3SGY#X25````B=DKC<3[__^%R7X*
M@'O_+P^$G@```(G8*X7$^___2'X*@'O_+@^$]@```(V5R?O__SG:#X/4_O__
M@'O_?@^%RO[__X![_B\/A<#^__^-G<C[__^)G<3[__^)T\:%R/O__W[&A<G[
M__\OZ9_^__^-=@"#[`B-M<C[__]6_W4(C;W(^___Z-0Y```I^XUE](G86UY?
MR</\.<F+M<3[__^-?=GSI@^%5____XF=Q/O__^E9_O__2^E3_O__.YW$^___
M=`J`>_\O#X6^_O__4&H`:``$``!H($X9".B'<@$`@\00B[6L^___A<"-7#,!
M#X4:_O__@^P(:"!.&0B-C<C[__]1Z%8Y``"#Q!"`>/\OC5C_#X5S_O__C5C^
MZ6O^__^)]H![_B\/A0#___^#ZP+IVOW__SN=Q/O__W0*@'O_+P^%1?[__Z$D
M4AD(B[VL^___A<"-7#L!#X2Q_?__@^P(4(V=R/O__U/H\3@``(G"C5C_BD#_
M@\00/"\/A0/^__^-6OZ*0O[I^/W__XUV`%6)Y5.#[`AH_P,``(M="/]U#%/H
M/#D``"G8BUW\R<.058GE5E.![``$``"+=0B+70PY\W0?@^P(4U;HY08``%E:
MC00#4%;H-8K]_XUE^%N)\%[)PX/L"%:-G?C[__]3Z&PX``"#Q!#KS(UV`%6)
MY5=64X'L/`@``(VUV/O__XM=##GS#X2H`0``@^P(4U;HD08``%I9C10#4E;H
MX8G]_XGW,<#\N?_____RKO?1B<B#Q!!(=".*E`77^___@/HZ=!>`^B]T$L:$
M!=C[__\OQH0%V?O__P")]H/L"%96Z![\__^#Q!"`O=C[__]^B87$]___="!1
M:/\#``!6_W4(Z%$X```K10B#Q!"-9?1;7E_)PXUV`(V=V?O__X"]V?O__R^)
MG=3W__\/A!P!``"#[`AJ+U/HV(W]_X/$$(7`B<</A"L!``"*'X/L#,8'`/^U
MU/?__^@8C/W_B870]___@\00B!_H:(?]_XN-T/?__X7)=(*)O=3W__^+A=#W
M__^+>!R)O<CW__^+E<CW__^%T@^$7____XN5U/?__XF5S/?__XGS*YW,]___
MBXW$]___C50+`3'`B[W(]____+G_____\J[WT8U9_XT\$X'_``0```^''?__
M_XN]R/?__X!\'_\O#X2;````C0P>.XW,]___<V=04O^US/?__U'H3X7]_X/$
M#%/_M<CW__]6Z#^%_?^#Q!!1:/\#``!6_W4(Z#$W```K10B#Q!"-9?1;7E_)
MPX/L"%:-G=CW__]3Z(\V``"#Q!#I0/[__XL=)%(9"(F=R/?__^DM____5U*+
MO<SW__\!UU>-!!%0Z*(^``#KD8/L#%/H%S<``(G'@\00Z<+^__^-6?[I7?__
M_Y!5B>575E.![!0$``#_=0R-M>C[__]6Z'T$``!>7XV5Z/O__U)2B</HM/W_
M_XM-#(T4&8G&_#'`N?____^)U_*N]]&-3#'_@\00@?G_`P``=S>#[`B-A>C[
M__]2`?!0Z.$U``"#Q`QH_P,``(V]Z/O__U?_=0CH3C8``"M%"(/$$(UE]%M>
M7\G#4VC_`P``_W4,_W4(Z"\V```K10B#Q!"-9?1;7E_)PY!5B>575E.!["P(
M``"+70P[70@/A'@"``"#[`A3_W4(Z,P#``!97HT$`U#_=0CH&H?]_UA::CK_
M=0CHCH;]_X/$$(7`BUT(=`.-6`%0:@!H``0``(V5Z/O__U+H16X!`(/$$(7`
MB87D]___=33\N?____^-O>C[___RKO?1B=I)*U4(.UT(B8W8]___B97@]___
M#X2C`0``.=$/A(D!``"0@^P(_W4(_W4(Z![Y__^#Q!"%P(G#='6+%212&0B%
MTL>%W/?__P````!U:8N5Y/?__X72=5>#O=SW__\!#X?:````@^P(C97H^___
M4O]U".A\-0``@\00A<!T,3'`_+G_____C;WH^___\J[WT8U!_XM5"(`\`@`/
MA8T!``"+=0C&!B[&1@$OQD8"`)"-9?1;7E_)PS'`_+G_____B=?RKO?1C7'_
MB;7<]___@'PR_R\/A"P!``"#O=SW__\!#X9H____.9W<]___#X-<____BYW<
M]____#G;BW4(B=>)V?.F#X5$____BU4(BX7<]___@#P"+P^%,?___\8"?HG6
M@^P(`[7<]___B==61U?HZC,``(/$$.D1____B?:+C=CW__\YC=SW__\/@Q3_
M__^+G=SW__^+/212&0C\.=N-M>C[__^)V?.F#X7U_O__BY7<]___@+P5Z/O_
M_R\/A>'^__^-O>C[__^#[`@!UU>-A>G[__]0QH7H^___?NA\,P``@\00Z;K^
M__\YR8VUZ/O__XG?\Z8/A6;^__^*`SPO#X1<_O__A,`/A%3^___\BWT(,<"Y
M______*N@^P,]]%1_[78]___C8WH^___4?^UX/?___]U".CN.@``@\0@Z1[^
M__^#Z0*)C=SW___IQO[__X/L"/]U"(V=Z/?__U/H^C(``(/$$.EN_?__@^P(
M`=!04NCF,@``@\00Z6[^__^)]E6)Y8/L%/\UP,(E".@K@_W_@\00]D40!'4Z
MH2!2&0B%P'5-@^P(_S7$PB4(_W4,Z/B(_?]:6?\UQ,(E"&H*Z,F'_?]8_S7$
MPB4(Z.V"_?\QP,G#D(/L"/\UQ,(E"&H'Z*B'_?^A(%(9"(/$$(7`=+.#[`C_
M-<3")0A0Z*V(_?__-<3")0AJ`FH!:.[K"`CHR8?]_X/$(.N+58GE4X/L#&HZ
MBUT(4^AB@_W_@\00A<!T)HI0`832C4@!=`V0@/HO=`]!BA&$TG7T*=A`BUW\
MR<.)R$&*$>OMC4/_Z]55B>6+51!6A=*+=0A3BTT,B?-T.(G0*<@]_@,``'\M
M*<I04E%6Z%HR``"#Q!`YV'04BE#_@/HO=`R`^CIT!\8`+T#&``"-9?A;7LG#
MC9'^`P``Z\M5B>575E.#[!1J.HM=#%/HR(+]_X/$$(7`BWT(=&F*4`&$THU(
M`70,@/HO=%-!BA&$TG7T*=B-<`&)V@'R=`N)T"G8/?X#``!^!HV3_@,``"G:
M45)35^C5,0``@\00.?AT%(I0_X#Z+W0,@/HZ=`?&`"_&0`$`C67T6XGP7E_)
MPXG(08H1ZZF-0__KDE6)Y5=64X/L#(MU$(M%#(M="(/H'(7VQT,(`````,=#
M!`````#'`P````#'0PP@````B4,0QT,<`````,=#%`0```#'0Q@`````=0B-
M9?1;7E_)PX/L"&H`C7X05^CVZO__@\00A<")0PB)`W3>B7@(B7`$QP``````
MC67T6UY?R<.)]E6)Y5=64X/L#(M5#(M%$(/J'(M]"(7`B5<0='R+=1"+1PB#
MQA"%P'5_BP>%P(G[=#>)PNL+C78`B=.+$X72="B+2@@Y\71LBT($@\`0.<AU
MYXL*@^P,B0M2Z!;K__^+$X/$$(72==F0@^P(:@!6Z&'J__^#Q!"%P(G"=".)
M<`B+,XM%$(DRB4($B5<(B1.-9?1;7E_)PXGVQT<(`````(UE]%M>7\G#D#EP
M"`^%>/___^OLB5<(C67T6UY?R<.)]E6)Y5=64X/L#(M]"(MU#(/&!XL/@^;X
MA<F)??!T)CEQ!`^"D0```(L7A=)T%XUV`#ER!`^#MP```(E5\(L2A=)U[HGV
MBT<4P>@"#Z]'$(U>$#G#<E^#[`AJ$%/HM.G__X/$$(7`B<(/A),```"+3?"+
M`8D"_T<4B=F)6@B-0_"+7?")$RG!*?")0@0!T3M'#',6BP*+7?")`XMW!(DR
MQT<8`````(E7!(G(C67T6UY?R<.)]HG#ZYV+5QB-0@&#^@F)1Q@/AEW___^!
M>03_#P``#X=0____BQ&+7P2)%\='&`````")&8E/!.DX____D(72#X1,____
MBT($BTH(ZX2+1QR%P'4$,<#KG__0,<#KF8UV`%6)Y593BW4(A?:+10P/A(H`
M``"H`@^%B0```*@!=0?'1@@`````BUX$A=L/A+\```"+5@B)V#G"BQMT#X/L
M#%#H6^G__X/$$(M6"(7;=>6+'HUV`(7;=!N)V#G"BQMT](/L#%#H-^G__X/$
M$(M6"(7;=>6%TL=&!`````!T:HM:"(/K$(D6B5H$QP(`````QT84!````,=&
M&`````"-9?A;7LG#B?"+%NL/B?:+0@B#Z!")0@2)T(L2A=)U[XM6!(D0ZPN+
M2@B#Z1")2@2+$H72=?''1@0`````QT88`````(UE^%M>R</'!@````#KGXM6
M".E7____58GE4XM="(M3!(72BTT,=!:-=@`YRG<)BT((`=`YR'<EBQ*%TG7M
MBQ.%TG06C78`.<IW"8M""`'0.<AW"8L2A=)U[5O)PXE3"%O)PU6)Y5=64X/L
M#(M]"(MU$(/&"(L/@^;XA<F)??!T)CEQ!`^"T0```(L7A=)T%XUV`#ER!`^#
M]P```(E5\(L2A=)U[HGVBT<4P>@"#Z]'$(U>$#G#<G>#[`AJ$%/H7.?__X/$
M$(7`B<)T>8M-\(L!B0+_1Q2)V8E:"(U#\(M=\(D3*<$I\(E"!`'1.T<,<Q:+
M`HM=\(D#BW<$B3+'1Q@`````B5<$A<F)RW074O]U$/]U#%'H;7S]_XM]$,8$
M.P"#Q!"-9?2)V%M>7\G#D(/L"&H0B<-3Z./F__^#Q!"%P(G"=8>+1QR%P'5:
M,=N-9?2)V%M>7\G#C78`BU<8C4(!@_H)B4<8#X8=____@7D$_P\```^'$/__
M_XL1BU\$B1?'1Q@`````B1F)3P3I^/[__Y"%T@^$#/___XM"!(M*".D]____
M_]`QV^NBC78`58GE5U93@^P,,<#\N?____^+?0SRKO?1BW4(C4'_C5D'BPZ#
MX_B%R8E%\(EU['0D.5D$#X+/````BQ:%TG05D#E:!`^#]P```(E5[(L2A=)U
M[HGVBT84P>@"#Z]&$(U[$#G'<G>#[`AJ$%?H`.;__X/$$(7`B<)T>8M-[(L!
MB0+_1A2)^8EZ"(U'\(M][(D7*<$IV(E"!`'1.T8,<Q:+`HM][(D'BUX$B1K'
M1A@`````B58$A<F)RW074?]U\/]U#%/H$7O]_XMU\(/$$,8$,P"-9?2)V%M>
M7\G#D(/L"&H0B<=7Z(?E__^#Q!"%P(G"=8>+1AR%P'5:,=N-9?2)V%M>7\G#
MC78`BU88C7H!@_H)B7X8#X8?____@7D$_P\```^'$O___XL1BT8$B1;'1A@`
M````B0&)3@3I^O[__Y"%T@^$#/___XM"!(M*".D]_____]`QV^NBC78`58GE
M5U93@^P,BWT(BW40@\8'BP^#YOB%R8E]\'0F.7$$#X+)````BQ>%TG07C78`
M.7($#X/O````B57PBQ*%TG7NB?:+1Q3!Z`(/KT<0C5X0.<-R;X/L"&H04^BT
MY/__@\00A<")PG1QBTWPBP&)`O]'%(G9B5H(C4/PBUWPB1,IP2GPB4($`=$[
M1PQS%HL"BUWPB0.+=P2),L='&`````")5P2%R8G+=!!6_W40_W4,4>C%>?W_
M@\00C67TB=A;7E_)PX/L"&H0B<-3Z$/D__^#Q!"%P(G"=8^+1QR%P'5:,=N-
M9?2)V%M>7\G#C78`BU<8C4(!@_H)B4<8#X8E____@7D$_P\```^'&/___XL1
MBU\$B1?'1Q@`````B1F)3P3I`/___Y"%T@^$%/___XM"!(M*".E%_____]`Q
MV^NBC78`58GE4XM="(H3A-*)V8G8=0KK'9!`BA"$TG0<@/H@=?2)P8GV0(H0
M@/H@=/B$TG7K*=F)R%O)PXG!*=F)R%O)PU6)Y5=64X'L-`@``(M%#%"-E>C[
M__]2BW40BWT4BUT8B87D]___Z('W__^+C>3W__\!P8/$$(7`B8W<]___=`GV
MPP$/A)(```!0:@!6C;7H^___5NC_]O__@\00]L,(#X7_`0``]L,$#X42`@``
M@^P(:B[_M=SW___H&G_]_X/$$(7`#X0E`@``]L,"#X6]````BXW<]___BA&$
MTHG(=0_K(HGV0(H0A-(/A'\"``"`^B!U\(G!B?9`BA"`^B!T^(32=>N)SBNU
MW/?__\>%X/?___3Z&`CI@@```/?#@`````^$=?___X/L#(V-Z/O__U'H!F(!
M`(/$$(7`#X5;____4(V-Z/O__VC_`P``48V%Z/?__U#HPB@``(/$#&H`5HVU
MZ/O__U;H+/;__XG!*?&^_P,``(/$#"G.5HV5Z/?__U)0Z)0H``#I#/___XG0
MB<8KM=SW__^)O>#W__^Z_____S'`_(G1C;WH^___\J[WT8F-U/?__XN]X/?_
M_XG1\JXIC=3W__^+E=3W__^-?#+]@?__`P``=PR!_O\````/AD$!```QP/;#
M0`^%@@```(N-Y/?__XH1A-*)R'4-ZR!`BA"$T@^$7`$``(#Z('7PB<&)]D"*
M$(#Z('3XA-)UZU")R"N%Y/?__SW_`P``=@6X_P,``%#_M>3W____=0CHV"<`
M`(/$$/;#('0NP>L$@^,!@_L!&=OWTX'C@````%!3_W4(_W4(Z!P"``"#Q!"+
M10B-9?1;7E_)PX/C$'3P@^P(_W4(C;WH]___5^@')P``@\0,:@!7_W4(Z`D!
M``"#Q!#KRX/L"(VUZ/O__U96Z$CQ__^#Q!#VPP0/A.[]__^#[`B-C>C[__]1
M4>AD[O__@\00@^P(:B[_M=SW___H]7S]_X/$$(7`#X7;_?__BX7<]___B<**
M"(3)#X2/_O__@/D@ZQ"-=@!"B@*$P`^$>O[__SP@=?&)T(UV`$**"H#Y('3X
MZ]*+A>3W__\Y10AT5E=6_[7<]___@^P,C;7H^___5O]U".A-)@``@\044.C(
M)@``6EG_M>#W__]0Z#8F``#IW?[__XG!Z;+^__^)P8G.*[7<]___QX7@]___
M]/H8".D6_O__4%;_M=SW__^-O>CW__]7Z'UT_?^#Q!")O=SW___KBXGV58GE
M5U93@^P0:/\#``"+70A3BWT,5^B5=?W_,?:#Q!"%P'@0Q@0#`(UE]%N)\%Y?
MR<.)]NC'=_W_BP"#^!:C`$H9"'0H]D40$'4'OO_____KUNBI=_W__S!7:@!J
M&.BUYO__OO____^#Q!#KNX/L"%=3Z'DE``!FO@$`@\00ZZA5B>575E.#[!2+
M=0Q6BUT(4^CZ>/W_,?^#Q!"%P'4-C67T6UZ)^%_)PXUV`.A/=_W_BP#V11`0
MO_____^C`$H9"'3<@^P0Z#5W_?]:_S!35FH`:AGH/^;__X/$(.O!B?95B>57
M5E.![&P$``"+=1`Q__?&@````(M=#'0L@^P(C86(^___4%/HY';]_X/$$(7`
M=3X/MY60^___@>(`\```@?H`H```=2F#[`B-C>C[__]14^@X=?W_@\00A<!T
M'5-H_P,``%#_=0CH)B4``(/$$(UE]%M>B?A?R<.0Z)]V_?^+`(/F$*,`2AD(
M=1-1:@!3_W4(Z!<```"______^O.4%-J`&H:Z(WE__^#Q!#KW56)Y5=64X'L
M'`0``(M=#(`[?HMU"(M]$`^$@@```(/L#%/HW5T!`(/$$(7`=":#[`A3C;WH
M^___5^@B)```6%I75N@9)```C67T6XGP7E_)PXUV`,>%Y/O__P````"`.RYT
M28/L"&@7$!D(4^C#)```@\00A<!U1(7_=$!J`%-7C;WH^___5^CP(P``6%I7
M5NC+(P``C67T6XGP7E_)PY"`>P$O#X5T____ZX*`>P$O=;''A>3[__\"````
M46H`,<#\B=^Y______*N]]&+A>3[__\IR`4!!```4(V]Z/O__U?H@5P!`(/$
M$(7`=2:+E>3[__^-#!.#[`A15^@/=?W_6%I75NA6(P``C67T6XGP7E_)PX/L
M"%/I&____XUV`%6)Y5=64X/L#(M="(/#!Z&,1QD(@^/X,<F%P+^,1QD(=!>)
M]HM0!#G:<TTYRG8"B=&)QXL`A<!UZXT$C0````"+%8A'&0@YT(US$','.=9R
M0XUV`(/L#%;HTW+]_X/$$(7`=#2)\8U6\,<``````(EP"(D'ZPR)]H7`=+V+
M4`2+2`@IT2G:B5`$C00!C67T6UY?R<.)UNN\Z+-T_?^+$/9%#!B)%0!*&0AU
M!#'`Z]U05FHD:@7HKN/__X/$$#'`Z\N-=@!5B>575E.#[`PQP(M]"/RY____
M__*NB<OWTXU[!Z&,1QD(@^?X,<F%P,=%\(Q'&0AT&(GVBU`$.?IS43G*=@*)
MT8E%\(L`A<!UZHT$C0````"+%8A'&0@YT(UW$',&.=9R68GV@^P,5NC_<?W_
M@\00A<!T2XGRB7`(C4[PBW7PQP``````B0;K#8UV`(7`=+J+2`2+4`@IRBGY
MB=<!QXE(!'0.4E/_=0A7Z&YQ_?^#Q!"-9?1;7HGX7\G#B=;KI>C(<_W_BQ#V
M10P8B14`2AD(=00Q_^O;459J)&H%Z,/B__\Q_X/$$.O)58GE5U93@^P,BUT,
M@\,'H8Q'&0B#X_@QR87`OXQ'&0AT%XGVBU`$.=IS33G*=@*)T8G'BP"%P'7K
MC02-`````(L5B$<9"#G0C7,0<P<YUG)8C78`@^P,5N@G<?W_@\00A<!T28GR
MC4[PQP``````B7`(B0?K#(GVA<!TO8M(!(M0""G**=F)TP'#B4@$=!!6_W4,
M_W4(4^B8</W_@\00C67TB=A;7E_)PXG6ZZ?H\G+]_XL0]D40&(D5`$H9"'4$
M,=OKVU=6:B1J!>CMX?__,=N#Q!#KR8GV58GE4U"+'8Q'&0CK$XUV`(G8@^P,
MBQM0Z']W_?^#Q!"%VW7LQP6,1QD(`````(M=_,G#D%6)Y8M-"(7)BT4,=!.+
M$872=`.)0@2)$(E(!(D!R<.0QP``````B4@$R<.058GEBTT,4XL1A=*+70AT
M%(M!!(E"!(M!!(7`=`*)$(G86\G#BUD$B=CK[I!5B>56BW4(A?93=""+10R%
MP'4AD(/L#(M>!%;HZ-K__X/$$(7;B=YUZXUV`(UE^%M>R<.0@^P,BUX$_W8(
MZ,;:__^)-"3HOMK__X/$$(7;B=YTV8/L#(M>!/]V".BGVO__B30DZ)_:__^#
MQ!"%VXG>=<+KN%6)Y5.#[`QJ"&H,BUT,Z.'9__^)PH/$$#'`A=)T'(M%"(7;
MB4((=!B+`X7`=`.)4`2)`HE:!(D3B="+7?S)PY")T,<"`````(E:!.OMC78`
M58GEBTT(B<J%R>L.B<J+`HM)!(D*B4($A<EU\(G0R<-5B>6+50@QP.L&B?:+
M4@1`A=)U^,G#B?95B>575E.#[`R+70B+?0R+=1#K$X/L"%;_<PC_UX/$$(7`
M=0F+6P2%VW7I,<"-9?1;7E_)PXUV`%6)Y5-0BU4(BT4,,=LYPG05@^P(_W`0
M_W(0Z!US_?^#Q!"%P'4%NP$```")V(M=_,G#B?95B>575E.#[!2)1?!J$&@`
M`0``Z'#[__^+5?"#Q!"%P(E"0+H!````=0J-9?1;7HG07\G#@^P(:A!H``$`
M`.A%^___BUWP@\00A<")1>B)0T2Z`0```'32BT-`,?^)PXE%[.L5J`0/A-@`
M``#&`PU'0X'__P```'<AB?B+5?`/MO"+2B`/MD0Q`:@#=-='Q@,"0X'__P``
M`';?BUWL,=+&0R0"QD-?`L9#)PG&0RX/QD,A!\9#/0?&0SX'QD,\",9#?!#&
M0R80QD,C"L9#.Q7&0SH6Q@,1QD-<$L9#+Q/&0RH4QD-`%\9#8!K&0R(@ZQ,\
M#70;BWWHB`P70H'Z_P```'<=BW7LB@06,<D\`G7AL0&+?>B(#!="@?K_````
M=N.+1>S&0%@=QD!X'<9`8A[&0$X?QD!N'XUE]%M>,=*)T%_)PY"#[`B+3?"+
M05A74?]0"(/$$$@/CS'___^+5?"+2B`/MD0Q`<'H`X/@`8/X`1G2@^+H@\(9
MB!/I\/[__Y!5B>575E.#Q(!2B<>-18A05XG6Z*P9``"#Q!"%P'0+BUVX@?L`
M`!``=@ZX`0```(UE]%M>7\G#D(/L"%93Z#[7__^#Q!"%P(E%A'3>4%9J`%?H
MMMO__X/$$(7`B<=X-%!3_W6$5^@N;_W_68G#6%97Z,O9__^#Q`QHJ#<'"%/_
M=83H$C$``%K_=83HD=?__S'`ZYR#[`S_=83H@M?__^N*58GE4U&AV%(9"(7`
MBUT(=!]2:/\#``!04^@.'0``@\004&H`4U/H?>K__XM=_,G#@^P,:!P0&0CH
M#U8!`(/$$(7`="R#[`QJ`&@]$!D(:$40&0AH'!`9"%/H9AP``(/$(%!J`%-3
MZ#WJ__^+7?S)PX/L"&A'$!D(:!P0&0CH^AP``(/$$(7`=;M0:@!H/1`9"&A%
M$!D(:!P0&0AH11`9"&A'$!D(Z[&058GEBT4(BQ"!2`P``@``B025(+8F",G#
M58GE@^P0:A#_=0CHF/C__\G#B?95B>564X'L``0``(L5!+0F"(G&,<"%TG0+
MC67X6P^^P%[)PY!3:``$``!J`&@@MB8(Z%YO_?^[(+8F"(DT).@=$```@\00
M@?L<NB8(<QZ)]HL#A<!T"XM(((7)#X6C````@\,$@?L<NB8(<N2AV%(9"(7`
MC9WX^___#X6@````@^P,:!P0&0CH[%0!`(/$$(7`=1V#[`AH1Q`9"&@<$!D(
MZ`,<``"#Q!"%P`^$@0```(/L#&H`:#T0&0AH11`9"&@<$!D(4^@F&P``@\0@
M4&H`4U/H_>C__UI9:%P0&0A0Z/`:``")\HG8Z)_]___'!02T)@@!````@\00
MC67X6P^^P%[)P^@#_/__A,`/A%#____'`P````"#PP3I1?___U)H_P,``%!3
MZ"P;``"#Q!#KG%!J`&@]$!D(:$40&0AH'!`9"&A%$!D(:$<0&0CI<O___XGV
M58GE5E,QP+L@MB8(BW4(Z)C^__^!^QRZ)@AS&(L#A<!T!XM0%(72=1>#PP2!
M^QRZ)@ARZ#'`C67X6U[)PXUV`%%6_W`4:"!;&0BA?%L9"/]0&(/$$(7`=="+
M"XL!Z]>058GE5U93@^P,BUT(BWL4A?\/A&D!``"+,X7V#X1K`0``BSRU(+8F
M"(7_#X2X`0``.7,$#X3X`0``.7,(#X3F`0``BPRU(+8F"(E-\(M##(M5\`M"
M#*@!B4(,#X70````A?:)\'4"BP*+5?")`HM#$(7`#X7H`0``BT,4A<`/A2X"
M``"+0QB%P`^%;`(``(M#((7`#X6'`@``BT,DA<`/A:@#``"+0RB%P`^%Q@,`
M`(M#+(7`#X7D`P``BT,XA<`/A0($``"+0QR%P`^%O@$``(MS$/RY!0```+]F
M$!D(\Z8/A9@"``"+5?"AN/<C"(E"6(L-O/<C"(LUJ/<C"&:+/;3W(PAFH;;W
M(PB!2@P(`@``B4I<B7)(9HEZ5&:)0E;'0DP"````QT)0`@```.LGD(M#&(M5
M\(7`B3(/A?H```"+0Q"%P`^%B0$``(M#%(7`#X4"`@``QP,`````QT,$````
M`,=#"`````#'0Q0`````QT,L`````,=##`````"0,=*-9?1;7HG07\G#,<"^
M(+8F".BT_/__@?X<NB8(<QB+!H7`=`>+2!2%R74;@\8$@?X<NB8(<N@QP(7`
MB0.)Q@^%6_[__^NX4E?_<!1H(%L9"*%\6QD(_U`8@\00A<!US(L6BP+KTY"#
M[`AJ`&I@Z.ST__^#Q!"%P(D$M2"V)@BZ`0````^$=____XLS46I@:@#_-+4@
MMB8(Z,)K_?^#Q!"+,^D(_O__@TL,$.D1_O__@TL,(.G__?__@^P(:A!0Z%_U
M__^+=?"#Q!"%P(E&&+H!````#X0G____Z>#^__^#[`AJ$%#H.?7__X/$$(M]
M\(7`B4<0#X7\_?__N@$```"-=@"-9?1;7HG07\G#@^P(:A!0Z`OU__^#Q!"+
M5?"%P(E"'`^%)O[__[H!````Z].#[`AJ$%#HZ/3__X/$$(MU\(7`B484#X6V
M_?__N@$```#KL(/L"&H04.C%]/__BTWP@\00A<")01"Z`0````^$C?[__^E1
M_O__@^P(:A!0Z)_T__^#Q!"+3?"%P(E!&`^%>/W__[H!````Z63___]2:A!H
M`0$``%#H7O7__X/$$(M5\(7`B4(@#X0]____B=#H$OC__X3`#X1+_?__N@$`
M``#I+/___X/L"&H04.A!]/__BWWP@\00A<")1Q2Z`0````^$"?[__^G8_?__
MBQ.+!)4@MB8(]D`,$(MP+`^$7`$``,=`7(!L&0C'0%C`:!D(BP25(+8F"(M-
M\(MX$,=!3`$```#'05`!````,<F%_W0VBW@XA?]T+XMX((7_="B+>"B%_W0A
MBW@DA?]T&HLXA?]T%(MX%(7_=`V+>"R%_W5/]D`,$'5)A<ET"XL$E2"V)@B#
M2`P(BQ25(+8F"(M*#(G(@,P"A?:)0@P/A#3]__^*1F$X1D$/@RC]__\Z1D(/
M@Q_]__^`S0:)2@SI%/W__[D!````Z["-=@!7:A!H``$``%#H,O3__X/$$(M5
M\(7`B4(D#X4Y_/__N@$```#I#_[__U9J$&@``0``4.@)]/__@\00BWWPA<")
M1R@/A1O\__^Z`0```.GF_?__46H0:``!``!0Z.#S__^#Q!"+=?"%P(E&+`^%
M_?O__[H!````Z;W]__]2:A!H``(``%#HM_/__X/$$(M-\(7`B4$X#X7?^___
MN@$```#IE/W__\=`7(!H&0CIG_[__U6)Y<<%!+0F"`````#)PY!5B>575E.#
M[`PQP+L@MB8(BWT(BW4,Z"7Y__^!^QRZ)@AS()"+`X7`=`Z+2!"%R70'A7`,
M=1>)]H/#!('['+HF"'+A,<"-9?1;7E_)PU)7_W`0:"!;&0BA?%L9"/]0&(/$
M$(7`==*+$XL"Z]E5B>534(M="#'`Z,7X__^+!)T@MB8(A<!T!#D8=`JX:Q`9
M"%M;R<.0BT`4A<!U]+AK$!D(Z^V)]E6)Y5=64X'L+`@``*'44AD(BWT(.3B)
MPG1N,<#H>_C__XU/_S'2@?G]````=UJ+-+T@MB8(A?8/A`<!``"+1@RH`710
M]L0"B?-U`C';A=N)W@^$[0```/9##0%U(8M36(L"A<`/A>(!``"+1ER+`(7`
M#X6T````@4L,``$``(7V#X2^````B?*-9?1;7HG07\G#B?:H"'6LH=A2&0B%
MP(V=Z/O__P^%9`$``(/L#&@<$!D(Z%Q-`0"#Q!"%P'4=@^P(:$<0&0AH'!`9
M".AS%```@\00A<`/A(T!``"#[`QJ`&@]$!D(:$40&0AH'!`9"%/HEA,``(/$
M(%%J`%-3Z&WA__^#Q!!J`&AA$!D(_W804.AV$P``@\00BU4,B=CH!?;__XM&
M#.D9____@^P(:.`U!PA6_]"#Q!"$P`^$-O___S'VD/9%#!`/A#C___^AV%(9
M"(7`=&U2:/\#``!0C9WH]___4^B*$P``@\004VH`C87H]___4%#H\^#__UI9
M:%P0&0A0Z.82``"#Q`QJ"HV5R??__U)7C;WH]___QH7(]___(XV=R/?__^AY
M%```5U-J!&H6Z-[3__^#Q"")\NG$_O__@^P,:!P0&0CH0TP!`(/$$(7`=4R#
M[`AH1Q`9"&@<$!D(Z%H3``"#Q!"%P'4S4&H`:#T0&0AH11`9"&@<$!D(:$40
M&0AH1Q`9".LI4FC_`P``4%/HV!(``(/$$.G5_O__@^P,:@!H/1`9"&A%$!D(
M:!P0&0B-C>CW__]1Z$@2``"#Q"#I(?___X/L"&C@-0<(4__0@\00A,`/A`C^
M__\Q]NG;_O__4&H`:#T0&0AH11`9"&@<$!D(:$40&0AH1Q`9".EF_O__B?95
MB>575E.![`P(```QP(M]#+L@MB8(Z/7U__\QP.CN]?__@?L<NB8(<QJ)]HL#
MA<!T!XMP%(7V=6>#PP2!^QRZ)@ARZ#'V@^<0=$JAV%(9"(7`C9WH]___#X0>
M`0``4FC_`P``4%/H_1$``(/$$%!J`%-3Z&S?__]97VA<$!D(4.A?$0``4_]U
M"&H$:ASH>M+__X/$((UE]%N)\%Y?R<.04?]U"/]P%&@@6QD(H7Q;&0C_4!B#
MQ!"%P`^%>O___XL3BP*%P`^$>?___XL<A2"V)@B%VP^$D````(M##*@!=5.H
M"'5/H=A2&0B%P(VUZ/O__P^$\0```%)H_P,``%!6Z&,1``"#Q!!1:@!65NC2
MWO__@\00:@!H81`9"/]S$%#HVQ```(/$$(GZB?#H:_/__XM##/;$`HG>=0(Q
M]H7VB?-T)_9&#0%U(8M.6(L!A<`/A>(```"+0UR+`(7`#X7R````@4X,``$`
M`(7;B=X/A2'____IS?[__XUV`(/L#&@<$!D(Z/])`0"#Q!"%P'0B@^P,:@!H
M/1`9"&A%$!D(:!P0&0A3Z%80``"#Q"#IO/[__X/L"&A'$!D(:!P0&0CH]!``
M`(/$$(7`=<50:@!H/1`9"&A%$!D(:!P0&0AH11`9"&A'$!D(Z[N#[`QH'!`9
M".B220$`@\00A<!U&8/L"&A'$!D(:!P0&0CHJ1```(/$$(7`=%R#[`QJ`&@]
M$!D(:$40&0AH'!`9"%;HT`\``(/$(.G0_O__@^P(:.`U!PA6_]"#Q!"$P`^$
M"/___S';Z17___^#[`AHX#4'"%/_T(/$$(3`#X3X_O__,=OI^/[__U!J`&@]
M$!D(:$40&0AH'!`9"&A%$!D(:$<0&0CKFE6)Y5=64X'L#`@``#'`BW4,BWT0
MNR"V)@CH8O/__S'`Z%OS__^!^QRZ)@AS(HUV`(L#A<!T#HM0$(72=`>%<`QU
M:(GV@\,$@?L<NB8(<N$Q]H/G$'1*H=A2&0B%P(V=Z/?__P^$&P$``%)H_P,`
M`%!3Z&(/``"#Q!!1:@!34^C1W/__7UIH7!`9"%#HQ`X``%/_=0AJ!&H6Z-_/
M__^#Q""-9?1;B?!>7\G#4?]U"/]P$&@@6QD(H7Q;&0C_4!B#Q!"%P`^%>___
M_XL+BP&%P`^$>O___XL<A2"V)@B%VP^$D````(M##*@!=5.H"'5/H=A2&0B%
MP(VUZ/O__P^$[P```%)H_P,``%!6Z,D.``"#Q!!1:@!65N@XW/__@\00:@!H
M81`9"/]S$%#H00X``(/$$(GZB?#HT?#__XM##/;$`HG>=0(Q]H7VB?-T)_9&
M#0%U(8M66(L"A<`/A?T```"+0UR+`(7`#X73````@4X,``$``(7;B=X/A2+_
M___ISO[__Y"#[`QH'!`9".AG1P$`@\00A<!T(H/L#&H`:#T0&0AH11`9"&@<
M$!D(4^B^#0``@\0@Z;_^__^#[`AH1Q`9"&@<$!D(Z%P.``"#Q!"%P'7%5VH`
M:#T0&0AH11`9"&@<$!D(:$40&0AH1Q`9".N[@^P,:!P0&0CH^D8!`(/$$(7`
M=1F#[`AH1Q`9"&@<$!D(Z!$.``"#Q!"%P'1<@^P,:@!H/1`9"&A%$!D(:!P0
M&0A6Z#@-``"#Q"#ITO[__X/L"&C@-0<(4__0@\00A,`/A!?___\QV^D7____
M@^P(:.`U!PA6_]"#Q!"$P`^$[?[__S';Z?K^__]0:@!H/1`9"&A%$!D(:!P0
M&0AH11`9"&A'$!D(ZYI5B>575E.#[`R+50B+0EB+=1"+>`2%_XGW#Y5%[P-]
M%(M=##G^B5WP=#:)]H!][P`/A8H```"*%@^^PH/X&@^$K````'\J@_@*#X3:
M````?SZ%P'1<C78`B!-&0SG^=<S&`P`K7?"-9?2)V%M>7\G#@_@G#X2_````
M?R6#^")UV,8#7,9#`2*#PP*)]D;KS8/X#77$Q@-<QD,!<H/#`NOL@_A<=;/&
M`US&0P%<@\,"Z]O&`US&0P$P@\,"Z\^-=@!1BTT(BT%85U91_U`$@\00A<!T
M*(U0_^L*C78`B@:(`T9#2H/Z_W7T3D;I;?___Y#&`US&0P%:@\,"ZY"#[`@/
MOA:+30B+05A2_W4(_U`(@\002`^.'?___\8#7(H&B$,!@\,"Z6/____&`US&
M0P%N@\,"Z53____&`US&0P$G@\,"Z47___^058GE4X/L$&A`:1D(Z&/O___'
M!"0@6QD(Z%?O___'!"1@4QD(Z$OO___'!"1@5QD(Z#_O___'!"3`<!D(Z#/O
M___'!"3`;!D(Z"?O___'!"1@[!P(Z!OO___'!"1@UAH(Z`_O___'!"0@XQH(
MZ`/O___'!"0@WQH(Z/?N___'!"0`3AT(Z.ON___'!"0`2AT(Z-_N___'!"0`
MI!X(Z-/N___'!"0`H!X(Z,?N___'!"1`'2$(Z+ON___'!"1`&2$(Z*_N___'
M!"1`'R((Z*/N___'!"1`&R((Z)?N___'!"2@2!T(Z(ON___'!"3@1!T(Z'_N
M___'!"1@]R,(Z'/N___'!"0`]R,(Z&?N___'!"2@]B,(Z%ON___'!"1`]B,(
MZ$_N___'!"3@]2,(Z$/N___'!"2`]2,(Z#?N___'!"0@]2,(Z"ON___'!"3`
M]",(Z!_N___'!"1@]",(Z!/N___'!"0`]",(Z`?N___'!"2@\R,(Z/OM___'
M!"1`\R,(Z._M___'!"3@\B,(Z./M___'!"2`\B,(Z-?M___'!"0@\B,(Z,OM
M___'!"3`\2,(Z+_M___'!"1@\2,(Z+/M___'!"3@02((Z*?M___'!"3@/2((
MZ)OM___'!"1@_1P(Z(_M___'!"3@^1P(Z(/M___'!"3`\",(Z'?M___'!"1@
M\",(Z&OM___'!"0`\",(Z%_M___'!"2@[R,(Z%/M___'!"1`[R,(Z$?M___'
M!"3@[B,(Z#OM___'!"2`[B,(Z"_M___'!"0@[B,(Z"/M___'!"3`[2,(Z!?M
M___'!"1@[2,(Z`OM___'!"0`[2,(Z/_L___'!"2@[",(Z//L___'!"1`[",(
MZ.?L___'!"3@ZR,(Z-OL___'!"2`ZR,(Z,_L___'!"0@ZR,(Z,/L___'!"2@
MZ2,(Z+?L__^+%91$'0B#Q!"%TKN`1!T(=!>0@^P,4X/#8.B8[/__BT,4@\00
MA<!UZC'`BUW\R<.-=@!5B>6+10C'``````#'0`0`````9L=`)```QT`(`2-%
M9\=`#(FKS>_'0!#^W+J8QT`4=E0R$,=`&/#ATL/'0!P`````QT`@`````,DQ
MP,.)]E6)Y5=64X'L?`$``#';B86D_O__C0R=`````(N5I/[__P^V1!$FP>`8
MB82=J/[__P^V?!$GP><0"<>)O)VH_O__#[9$$2C!X`@)^(F$G:C^__\/ME01
M*0G0B82=J/[__T.#^P]^KKH0````D(N<E8C^__\SG)6<_O__,YR5</[__S.<
ME6C^___1PXF<E:C^__]"@_I/?M6+E:3^__^+0@B+G:3^__^+2PR+O:3^__^)
MA9#^__^)A:#^__^+M:3^__^+A:3^__^+5Q2)C8S^__^)RXMV$(M(&(FUB/[_
M_XF5F/[__XG7B8V4_O__B8V<_O__QX6$_O__`````(G:B=GWTB'Z(?&+A:#^
M__\)T<'`!0'(`X6<_O__BY6$_O__`X25J/[__XF]G/[__T*)]XG>C8B9>8):
MP<8>@_H3BYV@_O__B96$_O__B8V@_O__?JNZ%````(GVB=@Q\,'!!3'XC00!
M`X6<_O__`X25J/[__XF]G/[__T*)]XG>C8BAZ]ENP<8>@_HGBYV@_O__B8V@
M_O__?L+'A8#^__\H````B?`)^(GR(?HAV,'!!0G0C00!`X6<_O__BY6`_O__
M`X25J/[__XF]G/[__T*)]XG>C8C<O!N/P<8>@_H[BYV@_O__B96`_O__B8V@
M_O__?K"Z/````(UV`(G8,?#!P04Q^(T$`0.%G/[__P.$E:C^__^)O9S^__]"
MB?>)WHV(UL%BRL'&'H/Z3XN=H/[__XF-H/[__W["BY6,_O__`=J+G8C^__\!
M\XNUF/[__XN%D/[__P'^B[V4_O__`[V<_O__`<B+C:3^__^)00B)40R)61")
M<12)>1AFQT$D``"!Q'P!``!;7E_)PU6)Y5=64X/L#(MU"(M>'(7;#X6B````
M#[]&)(/X-P^/PP```,9$,":`NC@```!`*<)14FH`C40&)E"-7B;H*EG]_X/$
M$&;'1B0X`(E=\(M^!(GZP>H0B?F+!L'I&(A67XGZB$Y>P>H(B<&(5F`/K/D8
MB<(/K/H0B$YB#ZSX"(H.B?N(5F.(1F2(3F6)\(A>8>CC_/__4&I`:@#_=?#H
MREC]_\<&`````,=&!`````#'1AP!````@\00,=*0B=&)T_?1P?L"@^$#P>$#
MBT2>"-/HBWT,B`070H/Z$W[?C67T6UXQP%_)P\9$,":`C7@!N$````"-3#XF
M*?A74&H`4>AH6/W_B?"#Q!!FQT8D0`#H9/S__XU6)ORY#@```(G7B=B)5?#S
MJV;'1B0X`.D=____C78`58GEBT405U:%P%.+?0B+=0QT+XU8_X/[_W0GD&:+
M1R2*%@^_R$"#!PB#5P0`9H/X0(A4.29FB4<D=!%&2X/[_W7:6UXQP%_)PXUV
M`(GXZ/'[__]&2^OFD%6)Y5-1BUT(A=MT*(U3"(/L#%+H!%4!`%A::@"-0R!0
MZ#/5__^)70B#Q!"+7?S)Z<2^__^+7?S)PXUV`%6)Y8M%#(M5"(L(BP*)30R)
M10C)Z0M8_?^-=@!5B>534XM%#(`X`(M="'4%N!@0&0B#[`A04^BI`P``@\00
M@'C_+W0'Q@`OQD`!`(G8BUW\R<.)]E6)Y<GI%U7]_XUV`%6)Y5=64X/L#(M=
M#(7;#Y3`#[;PA?:+?1!T%(/L"%=J8.B6O?__@\00A<")PW1!@^P(4_]U".BI
M6/W_@\00A<")VG4,C67T6UZ)T%_)PXGVZ#]5_?^+$(7VB14`2AD(=`^#[`Q3
MZ/*]__^#Q!"-=@`QTH/G&'3-_S4`2AD(_W4(:B1J#>@CQ/__,=+KMXUV`%6)
MY5=64X'L/`0``(M%",>%S/O__P````"`.`!U!;@8$!D(@^P(4(V%V/O__U#H
MP0(``(/$$(!X_R]T!\8`+\9``0"#[`R-E=C[__]2Z+)6_?^#Q!"%P(G'#X3!
M`0``@^P(_W4,:D#HP+S__X/$$(7`B<8/A*<!``!H`"```&@`!```C4@(:@B-
M6"!1B8W(^___B9W$^___Z`]1`0"#Q!"$P`^%:@$``%-H`(```&@`@```_[7$
M^___Z!;1__^-A=C[__^)!"2)M<S[___HX@(``(F%P/O__X/$$.LMC78`QX74
M^___`````(/L"(V-T/O__U'_M<C[___H?5$!`(/$$(3`#X46`0``@^P,5^@Q
M4OW_@\00A<`/A)4!``"#[`B-6`A3_[7$^___Z(S5__^#Q!"%P(F%T/O__P^$
MWP```/=%#``$``!TEH/L"&I@_[7$^___Z+[1__^#Q!"%P(F%U/O__P^$M0``
M`%%J8&H`4.@^5?W_6%I3_[7`^___Z'`!``"+G=3[__\QTH/$$(7;#Y3"A=*)
ME;S[__]T%H/L"/]U#&I@Z(&[__^#Q!"%P(G#=#:#[`A3C8W8^___4>B05OW_
M@\00A<`/A!O____H,%/]_XL0BX6\^___A<")%0!*&0@/A;@```#V10P8#X3V
M_O___S4`2AD(C9W8^___4VHD:@WH$L+__X/$$.G8_O__@^P,5NBQN___@\00
MB?;HWU+]_XLPA?^)-0!*&0AT#(/L#%?H&E?]_X/$$(N5S/O__X72=#2+C<S[
M__^#P0B#[`Q1Z)=1`0!?6(N=S/O__VH`@\,@4^C`T?__7O^US/O__^A4N___
M@\00]D4,&'4*,<"-9?1;7E_)P_\U`$H9"/]U"&HD:@SH?\'__X/$$.O?@^P,
M4^@AN___@\00Z3?___^#[`Q7Z)A6_?^+O<C[__^+!XD&@\00BT<$]T4,``(`
M`(E&!'0$B?#KIVCD30<(:@A0_S;H64_]_X/$$(GPZY&)]E6)Y8M-"(M5#(UV
M`(H"B`%"083`=?:-0?_)PY!5B>6+50A3BTT,C5T0ZQ.0B@&(`D%"A,!U]HG8
M2H/#!(L(A<EUZL8"`(G06\G#B?95B>564XM-$$F#^?^+=0B+70QT%HU6_Y"*
M`XA"`4-&0H3`=`Q)@_G_=>Y;B?!>R<-;B=!>R<.)]E6)Y593BTT028/Y_XMU
M"(M=#'06C5;_D(H#B$(!0T9"A,!T#TF#^?]U[L8&`%N)\%[)PUN)T%[)PXUV
M`%6)Y8M5"(GVB@)"A,!U^8U"_\G#58GE4XM="(M-#(GVBA&$TG0.B@-!0SC0
M=/(QP%O)PY"X`0```%O)PU6)Y5=64X/L?(M5%(72BUT,BWT0QT64(%,9"'4'
MQT64X%(9"(7_>&^-=_XQTH/^(G=;BT4(,=+W]XG!BE4(#Z_'*,(/ML+&1=@`
MBU64B@00C777B$77ZQR)R)GW_XE%A`^OQRC!#[;)BU64B@013H@&BTV$A<EU
MX$:(`T.$P'0*B@:(`T9#A,!U]HU3_X/$?%M>B=!?R<.-1R0QTH/X(G?LBTT(
MA<EX!/??ZX;&`RWW70A#]]_I>/___XGV58GE5U93@^QLBW40A?:+70QX>KC-
MS,S,]V4(B='!Z0.-!(G1X(I5""C"B-"#P#"-==?&1=@`B$77ZRZ0N&=F9F;W
MZ8E5E(M5E(E%D,'Z`HG(P?@?B=$IP8T$B='@B?HHPHC03H/`,(@&A<F)SW7-
M1H@#0X3`=`N0B@:(`T9#A,!U]H/$;(U#_UM>7\G#BTT(A<D/B7O____&`RWW
M70A#Z6____]5B>575E.![)P```"+11C'``````"+51"%THMU"(F58/___WX*
MB='WV8F-8/___XM%%(7`?@+WV#N%8/___WT&B85@____B@X/ML&+%4!;&0CK
M!Y!&B@X/ML'V1`(!"'7S@/DKQX5D_________P^$/P$``(#Y+0^$!P$``(#Y
M,(GW=0A&B@Z`^3!T^#';ZQL/OL&-4-`[50R)E)UH____?2^#^Q-_*D9#B@Z-
M4="`^@EVW8U1OX#Z&0^'V0````^^P8U0R3M5#(F4G6C___]\T3GW#X07`0``
MO______'A5S___\`````ZSJ)]HN,G6C___^)RO?:.Y5@____#XS5````BY5@
M____`<J)T)D/K\_W?0R)A6#___\!C5S___\/KWT,2X7;?\.%VW4?BY5H____
MB=/WVSN=8/___P^,E0````^OUP&57/___XN]9/___X7_>&6+11`YA5S___]\
M=XN=7/___XM5&(D:Z$-._?_'``````"!Q)P```!;B?!>7\G#1L>%9/___P$`
M``"*#NGG_O__B?:-09\\&;I_````#X?N_O__#[[!C5"IZ>/^__]&B@[IPO[_
M_X&]7/___P```(!T$?>=7/___XM-%#F-7/___WZ)Z-=-_?_'`"(````QP('$
MG````%M>7\G#Z+]-_?_'`"$````QP.OFD%6)Y8M%"(I-#(UV`(H0.,IT!D"$
MTG7U2,G#B?95B>6+31`[312X_____W,@#[8!#[>4`(!E&0B+10R)$#'`A=)U
M!8`Y`'4%N`$```#)PXGV58GE5HMU$#MU%%.X_____XM=#',G#[;'BPR%@%P9
M"#'2A<ET!@^VPXH4"#'`A-*(%G4$A=MU!;@!````6U[)PU6)Y5=64X/L#(I%
M'(M-#(M=%(A%\XM5$(M%&`'*`=B)5>R)1>@Q]C'_ZP^0B?@Q]H3`=#DQ_SC"
M=4@[3>QR!HGRA-)T3SM=Z'(&B?B$P'1$B?*$TG76#[8!#[:P`%D9"(J0(%H9
M"(GX083`=<</M@,/MK@`61D(BH`@6AD(0SC"=+B#Q`P/MO!;#[;2*?)>B=!?
MR<,[3>QR)(GQA,EU'CM=Z'((B?LQP(3;=`6X_____XG"@\0,6UZ)T%_)PS'`
M@'WS``^4P(G"Z^F)]E6)Y5=64X/L$(M=#(M-%(M%$(MU&`'8`<Z)1?")=>0Q
M_\9%[P#K%I")^C'_@'WO`'0^BD7O.,+&1>\`=4H[7?!R!HGZA-)T7#M-Y'(&
M@'WO`'1&B?J$TG7/#[8S0X!][P`/MKX`61D(BI8@6AD(=<(/MC&*A@!9&0B(
M1>^*AB!:&0A!.,)TM@^VT@^VR"G*@\006UZ)T%_)PXGXA,"Z`0```'7K@'WO
M`+K_____=>`[7?!T,SM=\+@!````=#([7?!S#8H3@/H@=1)#.UWP<O,QTH/$
M$%M>B=!?R<.`^A]W`O?8B<+KJ#M-Y'7(,=+KXHM=Y(E=\+C_____B<OKOY!5
MB>575E.#[`R+512)U@-U&(M-#(M]$#GRC1PY<RN)]CG9<RP/M@**@"!:&0B(
M`0^V`HJ``%D9"$&$P'0'.=ES`X@!04(Y\G+7.=ER#8UV`(UE]%M>B?A?R<,I
MRU!3:B!1Z*),_?^#Q!"-9?1;7HGX7\G#D%6)Y5=6BW4,B?<#?1`Y]U-V#H!_
M_R!U"$\Y]W?UC78`.?YS=8M%&(L8C78`#[8.BT44#[:1(%H9"(L(B<B#X#\!
MV`^OPHG*P>((`=`QP8M=%(D+BU48BQJ#PP.)&@^V#@^VD0!9&0B%TG0IBT44
MBPB)R(/@/P'8#Z_"B<K!X@@!T#'!BUT4B0N+51B+`H/``XG#B0)&.?YRDUM>
M7\G#B?95B>575E.#[`R+31B+10R+712)RBG".=B+=0B+?1!S+%!2C00.4(T$
M%@'84.A#````B5T0B7T,B74(@\00C67T6UY?R>F+1_W_C78`45*-#`:-%!Y1
M4NA91OW_B5T0B7T,B74(@\00C67T6UY?R>EA1_W_D%6)Y8M-#%.+51"+70CK
M!Y!)2XH!B`-*@_K_=?1;R<.058GE5U93@>R,````BU44A=(/B`L!``"+=12#
M[@(QTH/^(@^'\````(M]#`M]"`^$UP```(U5V(-]#`")593&1=@`#X8!`0``
MBTT4B4V(QT6,`````(UV`/]UC/]UB/]U#/]U".A72/W_B85P____BT6(B95T
M____]Z5P____B<&+50C_390IRHJ"(%,9"(MUE(@&BYUT____@\00BX5P____
M@_L`B44(B5T,=ZL]____?W>DBTT(A<ET.9")R)GW?12)PXM%%`^OPRC!_TV4
M#[;!BH`@4QD(BW64A=N(!HG9==F+51#_192(`D*$P(E5$'1+D(M]E(H'BU40
M_T64B`)"A,")51!UZ^LSBT40Q@`PQD`!`(U0`8UE]%M>B=!?R<.+112#P"0Q
MTH/X(G?IBTT,A<EX)?==%.GJ_O__C67T6UY*B=!?R<.!?0C___]_#X?R_O__
MZ5G___^+71#&`RU#]UT(@U4,`/==#/==%(E=$.FQ_O__D%6)Y5=64X/L?(M-
M%(7)BW4(BWT,#XC:````B?H)\G45BUT0Q@,PQD,!`(UE](U#`5M>7\G#C4W8
MB4V4QD78`.LNC78`:@!J"E=6Z/E&_?^)P<'A`H/$$`'!T>$ISO]-E(J>(%,9
M"(MUE(@>B=>)QH/_`'?0@?[___]_=\B%]HGQ#X2,````OF=F9F:0B<CW[HE5
MA(M5A(G/P?H"P?\?*?J)18"-!)+1X"C!_TV4#[;!BH`@4QD(BUV4A=*(`XG1
M=<N+31#_192(`4&$P(E-$'08C78`BTV4B@&+31#_192(`4&$P(E-$'7KC67T
M6UZ)R$A?R<.%_P^)'O___XM%$,8`+4#WWH/7`/??B440Z0C___^+=92*!NO`
MC78`58GE5U93@^Q<BUT(B=@#10Q(BW40B5W$B47`B@:$P'06C78`/"5T(#M=
MP'0*B`-#1HH&A,!U[<8#`"M=Q(UE](G86UY?R<.01HH.@/DM#X07`0``#[;!
MBSU`6QD(QT6P`````,=%M`````#'1;@`````QT6\`````.LBD(M%O(T4@`^^
MP8U,4-"%R8E-O'4'QT6T`0```$:*#@^VP?9$!P$$==B`^2YT3X#Y;,=%N/__
M__]T58#Y<W1?@/ED#X2P````@/EU#X2G````@/EX#X2>````.UW`#X19____
MQ@,E0^E)____D(M5N(T$D@^^T8U,0M")3;A&B@X/MM'V1!<!!'7C@/EL=:M&
MQT6P`0```(H.@/ES=:&+312+?<`IWXL1@T44!(E]J$>%THE]K`^$PP```#'`
M_+G_____B=?RKO?1C4'_.T6X=@.+1;@Y1:QW`XM%J%%04E/H^//__XG#@\00
M1NG&_O__1HH.Z>'^__^+5<`IVH/Z#XE=H(E5I'8'BWV\A?]T!HU%R(E%H(M5
ML(72=06`^61T08M]%(-%%`2`^62+!W0\@/EU=$5J`&H0_W6@4.A,]/__B<<K
M?:"#Q!`[?:0/AVK^__^-1<@[1:!T+@'[1NE4_O__BTT4BP&#110$5VKV_W6@
M4.C2]/__Z\A1:@KK\+K*$!D(Z3/___^+5:0Y5;QV`XE5O#M]O',CBTV\*?F#
M?;0!4AG2@^+P48/",%)3B4V<Z)Q&_?\#79R#Q!!05_]UH%/H2T']_P'[@\00
MZX]5B>6-112#[`A0_W40_W4,_W4(Z*#]___)PXGV58GE5U93@^P,BTT(H81G
M&0B+D1`!``"%P(M]#(MU$(E5\+N`9QD(=!^-=@!05O]S!%?HX43]_X/$$(7`
M=!2#PPB+0P2%P'7DC67T6UXQP%_)PX7;=/*+`X/X"'04@_@)=>:+7?#'@P0'
M````````Z]=2:F"+=?!J`('&"`<``%;HXT7]_X/$$(L#Z]%5B>575E.#[`R+
M50B+@A`!``")1?"AA&<9"(7`BWT,BW40NX!G&0AT'XUV`%!6_W,$5^A51/W_
M@\00A<!T%(/#"(M#!(7`=>0QP(UE]%M>7\G#A=MT\H,["77MBTWPBY%H!P``
M,<"%TG3@BUWP@^P,@<,(!P``4__2@\00Z\R)]E6)Y5=64X/L7(MU"(N6$`$`
M`(V>@````#'`B=^)5<3\N?_____RKJ&$9QD(]]&%P(UY_[Z`9QD(=!Z)]E!7
M_W8$4^C%0_W_@\00A<!T$X/&"(M&!(7`=>0QV_\DG?`3&0B%]G3SBQZ#^Q5V
M[HUE]%M>,<!?R<.+7<2!PT$"``")79R+70S'1<```````UT0BWT,B?8YWP^#
MG`0``(/L"`^^!U!HUR@9".@O1_W_@\00A<!T!4<YWW+CB?[K'(UV`(/L"`^^
M#U%HUR@9".@+1_W_@\00A<!U!4<YWW+C.?</A%,$``"!?<```0``#X=&!```
M4&H0:@!6Z+]`_?^+=<"+59R(!#*#Q!!&B77`ZX51:@IJ`/]U#.B`0?W_BTW$
MB8$0!P``@\00C67T6UXQP%_)PU)J"FH`_W4,Z%U!_?^+?<2#Q!")APP'``#K
MVXM%Q(/`0(M=#(E%I,=%L``````#71"+?0R)]CG?#X/J`P``@^P(#[X74FC7
M*!D(Z%M&_?^#Q!"%P'0%1SG?<N.)_NL<C78`@^P(#[X/46C7*!D(Z#=&_?^#
MQ!"%P'4%1SG?<N,Y]P^$H0,``(%]L`$!```/AY0#``!2:A!J`%;HZS_]_XMU
ML(M5I(@$,H/$$$:)=;#KA8M%Q`5!`P``BUT,B46LQT6T``````-=$(M]#(GV
M.=\/@T$#``"#[`@/O@]1:-<H&0CHPT7]_X/$$(7`=`5'.=]RXXG^ZQR-=@"#
M[`@/OA=2:-<H&0CHGT7]_X/$$(7`=05'.=]RXSGW#X3X`@``@7VT``$```^'
MZP(``%%J$&H`5NA3/_W_BW6TBTVLB`0Q@\001HEUM.N%BT7$BW40!8(&``"+
M3<2#_@_'1<BR$AD(QT7,MA(9",=%T+42&0C'1=2T$AD(C7W8B8$D!P``#X=M
M`@``4%;_=0Q7Z'H^_?_&1#78`(M-Q(N1!`<``(UR%(/$$(/^?P^'C?W__XMU
MQ%?_=)V`C80R@@8``&BX$AD(4.AC0_W_BU7$`8($!P``@\00Z1[^__^+=<2+
M71"!QD(&``"#^S]V!;L_````4%/_=0Q6Z!$^_?^+5<2#Q!#&A!I"!@```(FR
M(`<``.DH_?__BT7$!4($``"+70R)1:C'1;@``````UT0BWT,D#G?#X,4`@``
M@^P(#[X74FC7*!D(Z&-$_?^#Q!"%P'0%1SG?<N.)_NL<C78`@^P(#[X/46C7
M*!D(Z#]$_?^#Q!"%P'4%1SG?<N,Y]P^$RP$``(%]N``!```/A[X!``!0:A!J
M`%;HTS[]_XMUN(M5J&:)!'*#Q!!&B76XZX2+1<0%00$``(M=#(E%H,=%O```
M```#71"+?0R0.=\/@VL!``"#[`@/O@]1:-<H&0CHRT/]_X/$$(7`=`5'.=]R
MXXG^ZQR-=@"#[`@/OA=2:-<H&0CHIT/]_X/$$(7`=05'.=]RXSGW#X0B`0``
M@7V\``$```^'%0$``%!J$&H`5NA;/?W_BW6\BTV@B`0Q@\001HEUO.N%BT40
M@_@(#X^O````_#G`OK\2&0B+?0R)P?.F#X7Y````BUW$@XL4!P``(.G)^___
MBW7$BUT0@\8@@_L?=@6['P```%!3_W4,5NA[//W_BT7$@\00QD08(`")L!P'
M``#IE?O__XM=$(/['W8%NQ\```!04_]U#/]UQ.A+//W_BW7$@\00Q@0>`(FV
M&`<``.EF^___4VH*:@#_=0SHB3W]_XM=Q(/$$(F#"`<``.D$_/__O@\```#I
MB?W__[@(````Z4?___^+79R+?<2)GS`'``#I(_O__XM=K(M]Q(F?-`<``.D2
M^___BUVDBWW$B9\H!P``Z0'[__^+7:"+?<2)GRP'``#I\/K__XM=J(M]Q(F?
M0`<``.G?^O__BT40@_@'?@6X!P```/PYP+['$AD(BWT,B<'SIG4/BT7$@X@4
M!P``$.FR^O__BT40@_@)?@6X"0```/PYP+[.$AD(BWT,B<'SI@^%D/K__XM5
MQ(.*%`<```'I@?K__Y!5B>564XVUV/[__X'LG`@``%;H^<,``%E;:"!?!PA6
MZ"#$``!86F@L8`<(5NC_PP``65MHK%\'"%;H&L0``(M5$%B)E=#^__^-A6CW
M__]:4%;H%L0``(/$#/]U#/]U"%;H][<``(7`#Y7#B30DZ+;#``"-9?@/OL-;
M7LG#58GE5U93@^P,BW40BUT8BT4(.=Z+30R+512+>"R)=?!V`HG>.=%T0XT<
M,NL-C78`#[8"B@0XB`%"03G:<O(Y=?!W"XM%\(UE]%M>7\G#4(M5\"GR4FH@
M4>B7/OW_BT7P@\00C67T6UY?R<.-%#'K"0^V`8H<.(@903G1<O/KOY!5B>57
M5E.+31@Y31"+70R+=12*51QW`XM-$(M%"(32BW@L="2+11@Y11!V'$F#^?^)
M11!T&8UV``^V!@^V$XH$.$9#.`0Z=1-)@_G_=>J+51!;*U487HG07\G##[9#
M_P^V3O\/MA0X6P^V!#E>*<*)T%_)PU6)Y5=64U&+50B+11B+<BR+51`YT(M-
M#(M=%(E%\'8#B57PBWWP`<\Y^7,L#[8##[81B@0P0T$X!#)T[`^V0?\/MGO_
M#[84,`^V##<IRHG06EM>7\G#B?:+11@Y11!T++X!````<PJ)11")V;[_____
MBUT0C009*T7P.<%S#HGVBA&`^B!U#T$YP7+T,=*)T%I;7E_)PX#Z'XGP=P+W
MV(G"B=!:6UY?R<.-=@!5B>6+10B+50R+2"CK`XGV0@^V`HH$"(3`B`)U\\G#
MD%6)Y8M%"(M5#(M().L#B?9"#[8"B@0(A,"(`G7SR<.058GEBTT04XM%"(M5
M#(M8*(7)ZPH/M@**!!B(`D))=?1;R<.058GEBTT04XM%"(M5#(M8)(7)ZPH/
MM@**!!B(`D))=?1;R<.058GE5U935HM="(M]#(M+*(H?#[;SB77PBU40#[8"
MC7(!B@0(BU7P.`0*=19'A-MT*@^V!HH?#[;31HH$"#@$"G3J#[;##[9>_P^V
M%`@/MCP+6ULI^EZ)T%_)PUM;7C'2B=!?R<.-=@!5B>6+31`[312X_____W,B
MBT4(#[81BT`X#[<44(M%#(D0,<"%TG4%@#D`=06X`0```,G#58GE5U93BWT0
M.WT4BW4,N/____]S*8M%"(M0/(M*!(7)=!J0#[<:.?-W"`^W0@(Y\',1@\((
MBTH$A<EUYS'`6UY?R<.)\BG:BAP1,=*$VX@?=02%]G4%N@$```!;7HG07\G#
MD%6)Y8U%&(/L"%#_=13_=1#_=0SHZ/+__\G#B?95B>575E.#[`B+70R+11`!
MV(M-"(M1+#G#BW48B57PB47L<SJ+%HGVBT44BPB)R(/@/P'0BWWP#[83#[84
M.@^OPHG*P>((`=`QP8M%%(D(BSY#@\<#.UWLB?J)/G+*@\0(6UY?R<.)]E6)
MY5=64X/L%(M-#(M%',<``````(G.`W40.?%S(8M]"`^V$8M?(/9$$P$(=!&)
M]D$Y\7,*#[8!]D0#`0AU\3GQ#X07`0``BA&`^BV(5>,/A,X```"`?>,KQT7P
M``````^$[0```#'2N/_____W=10QVSGQB57HB4WLB<?'1>0`````BE7C=#6-
M0M`\"78-C4*_/!EW?HU"R8UV``^VT#M5%'T9.?MW8'16BU44#Z_3#[;`08T<
M`HH1.?%URSM-[`^$F````(MU&(7V=`6+?1B)#XM-\(7)=%R!^P```(!V6(-]
M\`&+71P9P,<#(@```"T```"`@\046UY?R<.-=@`[5>AVI8UV`,=%Y`$```!!
MBA'KI8U"GSP9=Z*-0JGI>?___\=%\`$```!!BAF(7>/I,?___X7;>*B+1>2%
MP'6ABU7PA=*)V'2L@\046U[WV%_)PT&*`8A%X^D(____BW48BWT<A?;'!R$`
M``!T"(M%#(M-&(D!@\046UXQP%_)PU6)Y5=64X/L%(M-#(M%',<``````(G.
M`W40.?%S(8M]"`^V$8M?(/9$$P$(=!&)]D$Y\7,*#[8!]D0#`0AU\3GQ#X3>
M````BA&`^BV(5>,/A+,```"`?>,KQT7P``````^$M````#'2N/_____W=10Q
MVSGQB57DB4WLB<?'1>@`````BE7C=#6-0M`\"78-C4*_/!EW9HU"R8UV``^V
MT#M5%'T9.?MW2'0^BU44#Z_3#[;`08T<`HH1.?%URSM-['1CBW48A?9T!8M]
M&(D/BTWHA<EU<HM5\(72B=AT`O?8@\046UY?R<,[5>1VO8UV`,=%Z`$```!!
MBA'KO8U"GSP9=[J-0JGKE,=%\`$```!!BAF(7>/I3/___T&*`8A%X^E!____
MBT48BW4<A<#'!B$```!T"(M-#(M]&(D/@\046UXQP%_)PXM='+C_____QP,B
M````ZXF058GE5U93@^Q,BWT,BT4<QP``````B?H#51`YUXE5S',CBW4(#[8?
MBTX@]D09`0AT$XUV`$<[?<QS"@^V%_9$$0$(=?`[?<P/A+L!``"*!SPM#X1S
M`0``/"O'1>P`````#X1K`0``BT44QT7$`````(E]R(E%P/]UQ/]UP&K_:O_H
M2S7]_X/$$(E%X(E5Y/]UQ/]UP&K_:O_H(SK]_S'V@\00.WW,B47<QT70````
M`,=%U`````!T:XM%%)F)1;B)5;R)]HH7C4K0@/D)B,MV&(U"OSP9C5K)=@Z-
M6I^`^QEW08U:J8UV``^VRSM-%'TSBU7D.574=R!R"(M%X#E%T'<6BU74BT70
M,U7D,T7@"<)U=CM-W'9QD+X!````1SM]S'6A.WW(#X3<````BUT8A=MT!8M-
M&(DYBWWLA?\/A)0```"!?=0```"`<@AW#H-]T`!W"(7V#X20````BW7LBU4<
M,<"%]L<"(@```+H```"`=0JX_____[K___]_C67T6UY?R<.-=@"+1=#W9;B)
M5;2)1;"+1=`/KT6\BTVTBU6X#Z]5U`'!`=$/ML.)3;2)1="+7;#'1=0`````
MBTVT`5W0$4W4Z5/____'1>P!````1^F/_O__@7W4____?P^#;O___X7V#X5P
M____BUWLA=N+1="+5=1TA/?8@](`C67T6U[WVE_)PXM%&(M-'(7`QP$A````
M=`B+=0R+?1B)-XUE]%M>,<`QTE_)PU6)Y5=64X/L3(M]#(M%',<``````(GZ
M`U40.=>)5<QS(XMU"`^V'XM.(/9$&0$(=!.-=@!'.WW,<PH/MA?V1!$!"'7P
M.WW,#X17`0``B@<\+0^$0`$``#PKQT7L``````^$.`$``(M%%,=%Q`````")
M?<B)1<#_=<3_=<!J_VK_Z!\S_?^#Q!")1>")5>3_=<3_=<!J_VK_Z/<W_?\Q
M]H/$$#M]S(E%W,=%T`````#'1=0`````=&N+1129B46XB56\B?:*%XU*T(#Y
M"8C+=AB-0K\\&8U:R78.C5J?@/L9=T&-6JF-=@`/MLL[311],XM5Y#E5U'<@
M<@B+1>`Y1=!W%HM5U(M%T#-5Y#-%X`G"=48[3=QV09"^`0```$<[?<QUH3M]
MR'1\BUT8A=MT!8M-&(DYA?8/A8P```"+=>R%]HM%T(M5U'0']]B#T@#WVHUE
M]%M>7\G#BT70]V6XB56TB46PBT70#Z]%O(M-M(M5N`^O5=0!P0'1#[;#B4VT
MB470BUVPQT74`````(M-M`%=T!%-U.N&QT7L`0```$?IPO[__XM5&(M%'(72
MQP`A````=`B+30R+71B)"XUE]%M>,<`QTE_)PXM]'+C_____NO_____'!R(`
M``#I</___U6)Y5.+11`]____?XM=#(M5%(M-&'05C00#B0*)31")50R)70A;
MR>EL,@$`N/__``"-!`.)`HE-$(E5#(E="%O)Z5(R`0")]E6)Y5=64X/L?(M%
M%(7`QT64`````(UUV<9%V0`/B(8```"XS<S,S/=E&(G1P>D#C02)T>"*51@H
MPHC0@\`PA<F-7O^(1O^)SG0VOV=F9F:0B<CW[XE5A(M5A,'Z`HE%@(G(P?@?
MB=$IP8T$B='@B?(HPHC02X/`,(7)B`.)SG70C479*=@Y11!V`XE%$%;_=1!3
M_W4,Z&(O_?^+11`#192-9?1;7E_)PXM]&(7_#XEO____BU4,]UT8Q@(M_TT0
M0HE5#,=%E`$```#I4____Y!5B>575E.#['R+112%P(MU&(M]',=%D``````/
MB.4```")^8U=V`GQB5V4QD78`'4QZ:(```")]FH`:@I75NAI,/W_B</!XP*#
MQ!`!P]'C*=Z)\?]-E(M]E(/!,(@/B<:)UX/_`'?1@?[___]_=\F%]HGQ=#B^
M9V9F9HGVB<CW[HE5A(M5A(G/P?\?P?H"*?J-')+1XRC9_TV4B46`B,B#P#"+
M?92%TH@'B=%USXU%V"M%E#E%$'8#B4404/]U$/]UE/]U#.AB+OW_BT40`T60
MC67T6UY?R<.-==>)=93&1=<PQT40`0```%#_=1#_=93_=0SH-"[]_XM%$`-%
MD(UE]%M>7\G#A?\/B1/____WWHM5#,8"+8/7`/??0O]-$(E5#,=%D`$```#I
M\_[__XGV58GE5U934(M=%(M]&#G[BW4,N?____]T4XUV`(H3#[[".T4D=#([
M12!T+3M%''1,.W40=%6+10B+4"P/M@8/M@N*!`)&0S@$"G4_.?MT';D!````
MZ\:)]@^^PCM%('0X#[[".T4D=%4Y^W6R,<`[=1`/E<"-9?1;7E_)PXU#`3GX
M=*T[=1")PW6KC67T6UZX`0```%_)PY`[=1!T%D-&.?MS"`^^$SM5('3M.?MT
MO8H3ZZV-9?1;7HG(7\G#C4L!.?ET&@^^`3M%)'0/.T4@=1$[=1`/A(H```!&
M0>OB,<#KDCGY=/@[=1"X_____W2$BA$/ML([11R-60%T<8M-"`^VTHM!+(H,
M$(A-\SMU$'0<BTT(#[8&BU$LZPE&.W40=`L/M@:*3?,X#`)U[XGP1CM%$'0O
M_W4D_W4@_W4<5U/_=1!6_W4(Z+3^__^#Q""%P`^.'?___SMU$'0(#[X3.U4D
M=:BX_____^D&____.?MTBXH30^N&D%6)Y5=64X/L#(I%%(M=#(A%\XMU$(I%
M&`'>B$7RBD4<BU4DB$7Q.?.+12"+32B)=>R)5>B-/`)T)XUV`#GZ=""*`SI%
M\W1%.D7R=%`Z1?%T7X@!0X@"04([7>QUWXUV`(G0*T7HBW4PBUTLB0:)`^L+
MC78`Q@$@Q@(@04(Y^G7T@\0,6UXQP%_)PXGVC7,!.W7L=+.)\XH&Z[>)]L8"
M`(MU"&:+1E:(`4-"03M=[.NKB=,K7>B+=2R)'HM%((M=,(D#B?;&`@"+=0A"
M9HM&5H@!03GZ=>[KJ%6)Y593BTT4BU4,@_D!BUT0B=9T+S'`@_D"=`1;7LG#
M.=IS%XM%"(M(((GV#[8"]D0!`0AT!4(YVG+QB=`I\%M>R<.0,<"`.BYUT8U"
M`3G8=.N`>@$P=>5`.=ATX(`X,'3V*?#KV8GV58GEBU4,BT44B44,B54(R>E/
M+_W_C78`58GEBT40*T4,R<.058GEBT40*T4,R<.058GEBT44R<-5B>6+51`K
M50R+110YT'8"B=#)PU6)Y8M5#(G0`T40.=!V#8!X_R!U!T@YT'?UB?8IT,G#
M58GE5U93@^P,BT40.448=TN+51B%TG10BTT,C30!*W48BUT41@-=&(EU\(E=
M[#M-\'0IB<J+?0B+110K50R+=RR-6O\/MCB0#[81B@0^04,X!!9T/CM-\'7N
MB?8QP(/$#%M>7\G#B?:+12"%P'07BTT<QP$`````QT$$`````,=!"`````"#
MQ`Q;7K@!````7\G#BWT4B4WH1SM]['0;BT7H#[80#[8'_T7HB@0&1S@$%@^%
M=O___^O@BTT@A<ET*8M5'(-](`''`@````")6@2)6@AV%(E:#(M5&(T\$XMU
M'(E^$"G?B7X4N`(```#I:O___U6)Y5.+70R+`XM-"(G"*Q%U"@^W400/MTL&
M*<J)T%O)PXUV`%6)Y5=64X'L'`P``(M]"(M7.(72N`$```!U"XUE]%M>#[[`
M7\G#4&@`#```:@"-C>CS__]1Z*8M_?\Q]HM'.(/$$(F%W//__^L=B?9FB5$$
M9HE1!HT46_^$E>CS__]&@?[_````?TV+G=SS__]FBQ1S9H72#[;>=02%]G7A
MC0Q;C42-Z(V(`/3__XN``/3__X7`=+AFBT$$9CG0=@*)T&:)001FBT$&9CG0
M<P*)T&:)00;KH&B$=P<(:@QH``$``(VUZ//__U;HI"C]_XVUZ//__X/$$,>%
MV//__P````"-7>B+@P#T__^%P`^$F0````^WBP;T__\/MY,$]/__*=%!@^P,
MB8W@\___4?]5#(/$$(7`B8,(]/__#X3=````4?^UX//__VH`4.BR+/W_@\00
MN0$```")]HM'.&:+!$AFBY,$]/__9CG"=QEF.48&<A-FA<!T#@^WT@^WP"G0
MBU8(B`P"08'Y_P```'[+_X78\___@\,,@\8,@;W8\____P````^.6?___XNU
MV//__X/L#(T<]0@```")M>3S__]3_U4,B<.#Q!"%VXE'/+@!````#X1C_O__
M,<D[C>3S__]]'HVU[//__XL&BWX$B7S+!(D$RT&#Q@P[C>3S__]\Z,<$RP``
M``#'1,L$`````(UE]%M>,<`/OL!?R<.X`0```.D5_O__B?95B>564XMU"(M>
M+(7;=!\/MD96B@P#,=**!!,XR'8&B,%FB5960H'Z_P```';J6S'`7LG#58GE
MBTT,BU40BT44B440B54,B4T(R>G]L```D%6)Y8M%"&;'0%;_`,DQP,-5B>57
M5E-1BD4<B$7SBUT8BT40.<-V`HG#B=G\.=N+=0R+?13SI@^7P0^2PBC1#[[!
MA<!U#H!]\P")V'4#BT40*T486EM>7\G#C78`58GE5U93BUT8.UT0B=AV`XM%
M$#G`B<'\BW4,BWT4\Z8/E\`/DL(HT`^^P(7`=06+11`IV%M>7\G#C78`58GE
M5U935HI%'(A%\XM=&(M%$#G#=@*)PXG9_#G;BW4,BWT4\Z8/E\$/DL(HT0^^
MP87`=0Z`??,`B=AU`XM%$"M%&%M;7E_)PXUV`%6)Y5=64XM]&#M]$(M-#(M=
M%'8#BWT0C30/B?8Y\7,<BA.*`4-!.-!T\@^V2?\/MG/_*?&)R%M>7\G#D(M%
M&#E%$'0LO@$```!S"HE%$(G9OO____^+71"-!!DI^#G!<P^-=@"*$8#Z('4.
M03G!<O1;7C')B<A?R<.`^A^)\'<"]]A;7HG!B<A?R<.058GER<.-=@!5B>7)
MPXUV`%6)Y8M5#(M%$(E%#(E5",GI<RK]_XUV`%6)Y;@!````R<.)]E6)Y8M5
M$#M5%+C_____<PV+10P/MA*)$+@!````R<.058GEBU40.U44BTT,N/____]S
M#C'`@?G_````=P2("K`!R<.058GE5U93BUT,B=\#?1`Y^XMU&',QBQ:0BT44
MBPB)R(/@/P'0#[83#Z_"B<K!X@@!T#'!BU44B0J+!D.#P`,Y^XG"B09RTEM>
M7\G#D%6)Y5=64X/L#(M-%(MU&#GQBUT,BWT0QT7P_____W1$BA$/OL([121T
M)CM%('0A.T4<=$`Y^W1)BA.*`4-!.-!U/SGQ=!['1?`!````Z]&0#[[".T4@
M=#@/OL([121T53GQ=;XQP#G[#Y7`C67T6UY?R<.0C4$!.?!TN3G[B<%UMXUE
M]%M>N`$```!?R<.)]CG[=!9!0SGQ<P@/OA$[52!T[CGQ=+Z*$>NNBT7PC67T
M6UY?R<.-40$Y\G05#[X".T4D=`H[12!U##G[='=#0NOG,<#KECGR=/@Y^[C_
M____=(F*"@^VP8A-[SM%'(U*`8E-Z'19.?MT$XI5[S@3ZPI#.?MT!XI-[S@+
M=?2)V$,Y^'0Q_W4D_W4@_W4<5O]UZ%=3_W4(Z-;^__^#Q""%P`^.-O___SG[
M=`N+5>@/O@H[321UL;C_____Z1W___\Y\8G*=*&*`4*(1>^)5>CKEI!5B>57
M5E.#[`R+?0R+510YUXM=$(MU&'02.=Z)\'<=45!25^BL(_W_@\00.?-W$8UE
M](G86UY?R<.-=@")V.O?B=B-%#<I\%=0:@!2Z*,G_?^#Q!"-9?2)V%M>7\G#
MB?95B>575E.#[`R+?0R+510YUXM=$(MU&'02.=Z)\'<=45!25^A,(_W_@\00
M.?-W$8UE](G86UY?R<.-=@")V.O?B=HI\E!2C00W:B!0Z$,G_?^#Q!"-9?2)
MV%M>7\G#B?95B>575E.#[`R+11`Y11AW.XM5&(72=$"+30R-%`&+710K51@#
M71B-<@&)7?`Y\70;B<^+110K?0R*$(U?_XGVB@%#03C0=#LY\77T,<"#Q`Q;
M7E_)PXGVBWT@A?]T%XM%',<``````,=`!`````#'0`@`````@\0,6UZX`0``
M`%_)PXM]%(E-[$<[??!T$8M%[(H7B@!'_T7L.-!UC^OJBW4@A?9T*8M5'(-]
M(`''`@````")6@2)6@AV%(E:#(M5&(T\$XM-'(EY$"G?B7D4N`(```#I=/__
M_XGV58GE5U93@^P,BT48B47LBT40BE4<.448B%7S=@.)1>R+=0R+?12+3>R-
M=@!)@_G_#X26````A<ET4HH6C5I?@/M8=Q2*1@&(1>N#Z$`\/G9'@'WKH'<Y
MD(H?#[;##[;2BIA@<1D(1T8XFF!Q&0ATO`^V7O\/MG?_#[:+8'$9"`^VAF!Q
M&0@IP>M*B?:*%NO(@'WK_W3"B?:*'XU#7SQ8=[F*1P&(1>J#Z$`\/G=`.-IU
M5HI%ZCA%ZW5.24F#Q@*#QP*#^?\/A6O___^0B74,B7T4,<F%R8G(=0R`??,`
M=".+1>PK11B#Q`Q;7E_)PX!]ZJ`/AF+___^`?>K_=;#I5____XM%$.O;#[;*
M#[;#P>$(#[9]Z\'@"`^V=>H)^0GP*<'KL%6)Y5=64X/L"(M%&(M5$#G0B47P
M=@.)5?"+=0R+?12+3?")]DF#^?\/A*X```"%R71>BA:-6E^`^UAW%(I&`8A%
M[X/H0#P^=E.`?>^@=T60BA\/ML,/MM**F&!Q&0A'1CB:8'$9"'2\#[9>_P^V
M3_\/MK-@<1D(#[:!8'$9""G&A?9T8(GP@\0(6UY?R<.)]HH6Z[R`?>__=+:)
M]HH?C4-?/%AWK8I'`8A%[H/H0#P^#X>2````.-H/A:@```"*1>XX1>\/A9P`
M``!)28/&`H/'`H/Y_P^%4____Y")=0R)?10Q]HM5&#E5$'28OP$```!S;HM%
M%(E5$(E%#+______BU40C1P0*UWP.=@/@W+___^-4`&*2O^`^2!U&8UV`(G0
MB54,0CG8#X-6____BDK_@/D@=.J`^1^)^`^'1?____?8Z3[___^`?>Z@#X8`
M____@'WN_P^%6O___^GQ_O__BT4,ZYL/MO(/ML/!Y@@/MDWOP>`(#[95[@G.
M"=#I^_[__Y!5B>575E.#[`R+11"+?0R+=12)1?"+71A+@_O_#X1>`0``A=L/
MA&H!``"*%HU*7X#Y6`^'7@$``(I.`8U!P#P^=A*`^:`/ADL!``"`^?\/A$(!
M```/ML+!X`AF#[;)"<&-@<!;``!F@_@!ND"D```/ANP```"-D;Y;``!F@_H1
M#X8C`0``C8'`-@``9H/X!`^&$P$``(V1K%L``&:#^BH/ACH!``"-@;LV``!F
M@_@'#X8J`0``C9%?6P``9H/Z7`^&-@$``(V!LS8``&:#^!4/AB8!``"-D0);
M``!F@?KA``^&'P$``(V!G38``&:#^$</A@\!``"-D2!:``!F@?H)`0^&"`$`
M`(V!538``&8]K@`/AO@```"-D199``!F@?K8`0^&\0```(V!IC4``&8]5@$/
MAN$```!F@?E@HG0=C9$]5P``9H'Z@0)V$(V!3S0``&8]*P(/A\<```"ZPZ@`
M`(G19L'I"(@/B%<!@\8"@\<"2TN#^_\/A:7^__^-=@"+71@Y7?!W.8M%\(UE
M]%M>7\G#D(H6#[;"BI!@<1D(B!=&1^EP_O__ND*D``")T6;!Z0B(#XA7`8/&
M`H/'`DOKLE"+=?`K=1A6:B!7Z-\A_?^+1?"#Q!"-9?1;7E_)P[I4I```B=%F
MP>D(B`^(5P&#Q@*#QP)+Z7C___^ZH:0``.E<____NOZD``#I4O___[K@I0``
MZ4C___^ZZJ8``.D^____9H'Y6:)T(&:!^=KY=!F-D;M4``!F@?IV`G8,C8$C
M,@``9CWJ`G<*ND6K``#I#?___V:!^5JB=!F-D412``!F@?KQ`G8,C8$X+P``
M9CV"`W<*NKRM``#IX_[__XV1I5T``&:#^@%V&8V!4D\``&8]%`-V#8V1M2L`
M`&:!^@4$=PJZKK```.FT_O__9H'YV_ET&8V!/4P``&8]_P)V#8V1KR<``&:!
M^E\$=PJZP[,``.F*_O__9H'Y7:)T-6:!^5^B="YF@?FAQG0G9H'YUOET(&:!
M^=CY=!F-@3U)``!F/>@"=@V-D4\C``!F@?H^!'<*NL.V``#I1/[__V:!^=SY
M=!F-@51&``!F/4@"=@V-D1`?``!F@?KU`W<*NJRY``#I&O[__V:!^6&B=!F-
M@0M$``!F/;$"=@V-D1H;``!F@?H-!'<*NO6[``#I\/W__V:!^5ZB="=F@?G7
M^70@9H'YV?ET&8V!64$``&8]S0%V#8V1#!<``&:!^L0#=PJZI[X``.FX_?__
MC8&+/P``9CW9`78-C9%'$P``9H'Z_0)W"KIUP```Z97]__^-@;$]``!F/0\!
M=@V-D4D0``!F@?HS`G<*ND_"``#I<OW__XV!H3P``&8]]0!V#8V1%0X``&:!
M^A$"=PJZ7\,``.E/_?__C8&K.P``9CV!`'8-C9$##```9H'ZP@%W"KI5Q```
MZ2S]__^-@2D[``!F/9,`=@V-D4`*``!F@?H5`7<*NM?$``#I"?W__XV!E3H`
M`&:#^%QV#8V1*@D``&:!^OD`=PJZ:\4``.GF_/__C8$X.@``9H/X*'8-C9$P
M"```9H'ZU`!W"KK(Q0``Z</\__^-@0\Z``!F@_AC=@R-D5L'``!F@_I(=PJZ
M\<4``.FA_/__C8&K.0``9H/X#W8,C9$2!P``9H/Z?'<*NE7&``#I?_S__XV!
MFSD``&:#^`9V#(V1E08``&:#^C9W"KIEQ@``Z5W\__^-@90Y``!F@_@)=@R-
MD5X&``!F@_H7=PJZ;,8``.D[_/__C8&*.0``9H/X`G8,C9%&!@``9H/Z"W<*
MNG;&``#I&?S__XV!ASD``&:#^`-V#(V1.08``&:#^@1W"KIYQ@``Z??[__]F
M@?E]QG0,C8$T!@``9H/X`W<*NGW&``#IVOO__V:!^=#YNM#Y```/A,K[__]F
M@?E^QG1(9H'YT?ET06:!^<;Y=$1F@?G2^70]9H'YT_FZT_D```^$GOO__V:!
M^=3YLM0/A)'[__]F@?G5^;+5#X2$^___9KI`H>E[^___NG[&``#I<?O__[K&
M^0``Z6?[__^)]E6)Y5=64X/L$(I%%(I5&(M-#(A%\XA5\HI%'(M5$(M=)`'*
MB$7QBT4@`=@YT8MU*(E5[(E=Z(E%Y'0_.<-T.Y"->0$[?>QT7(H1C4)?/%AW
M5XI)`8U!P#P^=V6(%H@3B@^(3@&(2P&#Q@*#PP)'.WWLB?ET!3M=Y'7&B=@K
M1>B+33"+?2R)`8D'ZPF0Q@,@Q@8@0T8[7>1U\X/$$%M>,<!?R<.0BA&)]CI5
M\W0C.E7R="XZ5?%T,X@6B!-&0^NOD(#YH';C_L%UDCI5\W7?B?8[?>QTV(H7
MB!:($T9#ZXZ0Q@,`Q@;_0T;KA(G:*U7HBTTLB1&+12"+?3")!\8#`,8&_T-&
M.UWD=?/KCI!5B>6+30R*`8/`7SQ8BU40=R(IRDI^'8I1`8U*P(#Y/G8*@/J@
M=@W^PG0)D+@"````R<.0,<#)PU6)Y8I%#(/`7SQ9&<#WT(/``LG#58GE5E.+
M71"+=10Y\XM-#+K_____<RR#^7]^((V!7O___X/X57=)#[>,"9PE&@B%R749
M6S'2B=!>R<.0B`NZ`0```%N)T%[)PXUV`(U#`CGPNO____]WZXG*P?H(B!.(
M2P%;N@(```")T%[)PXUV`(V1.?W__X'ZB@$``'8:C8'MW___/:P"``!W%P^W
MC`DZWAD(ZYJ-=@`/MXP),AX:".N-C9&@V___@?KB`0``=AJ-@0#0__\]*0$`
M`'<:#[>,"2"X&0CI9?___P^WC`G`T1D(Z5C___^!^:,R``!T,HV1<LS__X/Z
M1W<-#[>,"62P&0CI./___XV!`++__SV#1@``=QD/MXP)8.X8".D>____#[<-
M$!@:".D2____C9&):O__@?HM"@``=PT/MXP)$DL8".GW_O__C8'T!?__@_@!
M=PT/MXP)Y($7".G?_O__C9'0`?__@?K-`0``#X?1_O__#[>,"0!V%PCIP/[_
M_Y!5B>575E.+71"+=10Y\XM]#`^V"[K_____<SR#^7]^0(U#`CGPNO____]W
M*\'A"`^V<P$!\8V1P%[__X'ZO"8``'<M#[>4"6!&&0B#^@&)%QG2]]*#X@);
M7HG07\G#B?:)#UM>N@$```")T%_)PXGVC9G`-O__,=*!^Y4P``!WRP^WE`D@
ME1@(Z\&)]E6)Y5=64U&+71"+50R-0_^+=12)UXE%\(7V=!`YVG,,B@*$P'@2
M0H7V=?&0*?J)T%I;7E_)PXGV.U7P<^^#P%\\6'?HBDH!C4'`/#YV"8#YH';9
M_L%TU8/"`NN\58GE5U93@^PL@'T<`,=%Y`````#'1>``````=`R+11@Y11`/
MAZX!``"+?0R+712)?>R)7>B-=@")^"M%##M%$`^,\@```(-]Y`/'1?``````
M=!G_1>2#?>0!BWWL=`.+?0S'1?`!````C78`B=HK510[51A]((MUX`^V`XL,
MM<3>&@@/MC0!A?9U*4.)VBM5%#M5&'S@,?:#?>`#='[_1>"#?>`!BUWH=`.+
M712^`0```.MH@_X"#X6M`0``0XG8*T44.T48B=I]'@^V`X`\`0)U%9!"B=`K
M110[11A]"0^V`H`\`0)T[(G0*T44.T48?`*)TX-]X`)_"CM%&'T%B=.-=@")
MV2M-%#M-&`^-6O___X-]X`$/CL,```"+1?`I\'4-BW7PA?8/A0K___\QP(/$
M+%M>7\G#BT7D#[8WBQ2%Q-X:"`^V##*%R8E-\'4&1^GB_O__@WWP`@^$EP``
M`(%]\/\```!T!D?I_?[__\=%W`````"+==R+#/7@WAH(B4W8BU78B@(Q]H3`
MB?D/A.0```"(PHGVB<@K10P[11`/C=<````X$0^%SP```$:+1=B*%#!!A-)U
MWHM]W(L$_>3>&@B+5>2->?\/MC001XEU\.F5_O__B440Z4K^__^)VKL!````
M*UW@B5W@BUWHB57HZ27___]'B?XK=0P[=1")^7T=#[8'@#P"`G4408G(*T4,
M.T40?0D/M@&`/`("=.R)R"M%##M%$'P"B<^#?>0"?P<[11!]`HG/B?HK50P[
M51`/C?#]__^#?>0!#X\:_O__B?F_`0```"M]Y(E]Y(M][(E-[.D"_O__@?[_
M````="9#Z:3^__^+==B*%H32#X0U_____T7<@WW<)P^.Y/[__T?IU/W__\=%
MU`````"+1=2+#,7@WAH(B4W0QT7,`````(M5T(H"A,")V71"B$7+B<HK510[
M51A]/8I%RS@!=3;_1<R+5="+1<R*%`)!A-*(5<MUVXMUU(L$]>3>&@B+5>"-
M6?\/MC000^D<_O__BT70BA"(5<N`?<L`=-C_1=2#?=0G?HA#Z?_]__^-=@!5
MB>6+51"%TE.+312+70R+11AT#(!\$_\@=05*=?:)]H7`=`R`?`'_('4%2'7V
MB?9J`%!14E/_=0CHHOS__XM=_,G#D%6)Y5=64X/L'(M-%,=%Z`````#'1>0`
M````B4WLC78`B<@K110[11A\6H-]Z`/'1?``````=!;_1>B#?>@!BTWL=`.+
M313'1?`!````BWT0.7WD<PR*5?"+70R+=>2(%#.+1?#_1>2%P'6UBU7D.540
M#X<I`0``BT40C67T6UY?R<.)]HM]Z`^V,8L4O<3>&@@/MAPRA=N)7?!U!$'K
M@9"#??`"=&J!??#_````=`-!ZYO'1>``````BUW@BSS=X-X:"(H',?:$P(G+
M#X2R````B,*0B=@K110[11@/C:,````X$P^%FP```$:*%#=#A-)UX8M5X(L$
MU>3>&@B+=>B-2_\/MCPP08E]\.D]____08G(*T44.T48B<M]'0^V`8`\`@)U
M%$.)WBMU%#MU&'T)#[8#@#P"`G3LB=@K110[11A\`HG9@WWH`G\'.T48?0*)
MV8G**U44.U48#XV__O__@WWH`0^/XO[__XG+N0$````K3>B)3>B+3>R)7>SI
MRO[__XH7A-(/A&;_____1>"#?>`G#XX?____0>FM_O__48M]$"G75VH@BTT,
M`=%1Z.P4_?^+11"#Q!"-9?1;7E_)PXGV58GE5U93@^P0BE44BW4,BD4<B%7S
MBU40BUTD`?*(1?&+12`!V(I-&#G6BWTHB$WRB57LB5WHB47D=%$YP^L*D$8[
M=>QT1CM=Y'1!B@XZ3?)T.CI-\70U.DWS="`/MM&AQ-X:"(H$$(3`=-4\`G8=
M_L!T&8@/B`M'0^O%D(U&`3M%['38B<:*".O2B?:)V"M%Z(M5+(D"BW4PBTT@
MB0[K",8#(,8'.4-'.UWD=?.#Q!!;7C'`7\G#D%6)Y5.+70R*$S'`A-*+31!X
M!EO)PXUV`(#ZH'87_L)T$RG927X.BE,!@/J@=@;^PK`"==XQP%O)PXUV`%6)
MY8M5#(#ZH'8-_L*X`@```'0$R<.)]K@!````R<.058GE5E.+71"+=10Y\XM-
M#+K_____<S"#^7]V)(V!7____SW&````=TL/MXP)/O,;"(7)=1M;,=*)T%[)
MPXUV`(@+N@$```!;B=!>R<.-=@"-0P(Y\+K_____=^N)RL'Z"(@3B$L!6[H"
M````B=!>R<.-=@"-D3G]__^!^HH!``!V&HV!Z]___SW]`@``=Q</MXP)-JL;
M".N8C78`#[>,"=+K&PCKBXV1H-O__X'Z#0(``'8:C8$`T/__/7\"``!W&@^W
MC`E`@AL(Z6/___\/MXP)@)X;".E6____C9&`S/__@_I==PT/MXP)@'H;".D^
M____C8$`LO__/7]&``!W#0^WC`F`N!H(Z23___^-D8EJ__^!^B4*``!W#0^W
MC`DR%1H(Z0G___^-@0!4__\]HRL``'<-#[>,"<"0&0CI[_[__XV1``?__X'Z
M"P$``'<-#[>,":#T&`CIU/[__XV!_P#__SWE````#X?'_O__#[>,";[F&`CI
MMO[__Y!5B>575E.+71"+=10Y\XM]#`^V"[K_____<SR#^7]^0(U#`CGPNO__
M__]W*\'A"`^V<P$!\8V1OW[__X'ZO4<``'<M#[>4"5Y:&PB#^@&)%QG2]]*#
MX@);7HG07\G#B?:)#UM>N@$```")T%_)PXGVC9E?-?__,=*!^UTS``!WRP^W
ME`G>8!H(Z\&)]E6)Y5=64X/L&(!]'`#'1>0`````QT7@`````'0,BT48.440
M#X<7`@``BT4,B47HBWT4B?:+5>@K50P[51`/C$4!``"+3>2%R0^%Y@$``(M=
M$(7;#X[;`0``BW4,B77HQT7D`0```(M5Z(H"#[;PB$7?#[:&X/<<"(E%\(%]
M\/\````/A"T!``#_1>B)^RM=%#M=&'Q;BW7@A?8/A8@!``"+51B%T@^.?0$`
M`(M]%,=%X`$```"*%P^V\@^VAN#W'`B)1>R!?>S_````B%7>=$)'BT7P*T7L
M=0V+3?"%R0^%4/___S'`@\086UY?R<.)]HM%X(7`=;Z*'P^VRP^V@>#X'`B)
M1>R!?>S_````B%W>=;XQ]HL,]:#W'`B*$832B?MT1)")^"M%%#M%&'T<.E7>
M=1>008H10X32="N)V"M%%#M%&'T$.A-TZH32=!E&@_XG#X]X____BPSUH/<<
M"(H1A-*)^W6]BWW@A?\/A=8````/MC3UI/<<"(U[_XEU[.E+____C78`BT7D
MA<`/A=/^__^+7>B*"P^VT0^V@N#X'`B)1?"!??#_````B$W?#X73_O__,?:+
M#/6@]QP(BA&$THM=Z'1%D(G8*T4,.T40?1PZ5=]U%Y!!BA%#A-)T+(G8*T4,
M.T40?00Z$W3JA-)T&D:#_B</CXS^__^+#/6@]QP(BA&$THM=Z'6\BTWDA<EU
M0@^V-/6D]QP(2XEU\(E=Z.EA_O__D,=%[`````#IG?[__\=%\`````#I2_[_
M_XE%$.GA_?__#[8T]:7W'`CI)?___P^V-/6E]QP(Z[R058GEBU40A=)3BTT4
MBUT,BT48=`R`?!/_('4%2G7VB?:%P'0,@'P!_R!U!4AU]HGV:@!045)3_W4(
MZ&+]__^+7?S)PY!5B>575E.#[!R+=13'1>P`````QT7H`````(GVB?`K110[
M11A\<HM][(7_#X7[````BUT8A=L/CO````"+=13'1>P!````BAZ(7></MOL/
MMH?@]QP(B47P@7WP_P```'191HM]$#E]Z'<,BDWPBT4,BUWHB`P8BU7P_T7H
MA=)UG(M-Z#E-$`^'K````(M%$(UE]%M>7\G#D(M-[(7)=:>*!HA%YP^VT`^V
M@N#X'`B)1?"!??#_````=:<Q_XL,_:#W'`B*$832B?-T1)")\"M%%#M%&'T<
M.E7G=1>008H10X32="N)V"M%%#M%&'T$.A-TZH32=!E'@_\G#X]A____BPS]
MH/<<"(H1A-*)\W6]BW7LA?9U1`^V#/VD]QP(C7/_B4WPZ3C___^-=@#'1?``
M````Z2K___]0BWT0*<]7:B"+=0P!SE;HT`W]_XM%$(/$$(UE]%M>7\G##[84
M_:7W'`B-<_^)5?#I]/[__XUV`%6)Y5=64X/L$(I%%(A%\XI%&(A%\HI%'(M-
M)(M5#(A%\8MU$(M%(`'6BUTHC3P!QT7L`0```(EUZ(E-Y.LPB?8Z1?)T1SI%
M\71"#[[PBH:@]AP(A,"(`70'QT7L``````^^,HJ&H/4<"(@#04-".U7H=!DY
M^705B@(Z1?-UPHUR`3MUZ'2ZB?**!NN^B<@K1>2+=2R)!HM5((M%,(D0ZPC&
M`0#&`_]!0SGY=?0/OD7L@\006UY?R<-5B>575E.#[!R+50B+2EB+02"+?0R+
M=12)1>B0.W48#X0M`0``_W485HU%\%#_=0C_5>@QVX/$$(7`#XZ*````BU7P
M.54D#X3``````<8Y51P/A-T```#_=1!7C4WL4?]U"/]5Z(/$$(7`?EX!QX3;
M=6J+3?`Y32!THHM5*(72=&6+5>R+12@/MMZ+')B%VXG0=`L/ML*-%$`/MT13
M!(G"B47L#[;=BT4HBQR8A=N)R'0+#[;!C0Q`#[=$2P2)P8E%\#G*#X12____
MN@$```"-9?1;7HG07\G#C78`BU4HA=*+3?!UFXM5[.O7.54@=7O_=1!7C5WL
M4_]U"`'&_U7H@\00A<!^PP''C78`.W48=%/_=1A6C57P4O]U"/]5Z(/$$(7`
M?J2+5?`Y521UO0'&Z]J)]O]U&%:-7?!3_W4(_U7H@\00A<!^@0'&LP'I!?__
M_S'2.WT0#Y7"C67T6UZ)T%_)PS'2Z63___\[=1AT]#M]$+K_____#X11____
M_W485HU-\%'_=0C_5>B#Q!"%P+H!````#XXS____BU4<.U7P#X2W````.WT0
M=';_=1!7C5WL4_]U"/]5Z(/$$(7`B47D#XX!____BTTHA<ET2XM5[`^VQHM=
M*(L,@X7)B=!T"P^VVHT46P^W1%$$BU7PB<&)1>P/MMZ+12B+')B%VXG0=`L/
MML*-%$`/MT13!(E%\#G!=!<#?>3KC8M%\(M-[.OONO_____IHO[__SM]$'3Q
M@^P,_W4H_W4D_W4@_W4<_W485O]U$%?_=0CHK_W__X/$,(7`?[Z)PNEP_O__
M_W48`<96C47P4/]U"/]5Z(/$$(7`N@$````/CRG____I2_[__U6)Y5=64XMU
M%(M=$#GSBWT,NO____]S$(H+A,EX$@^VP8D'N@$```!;7HG07\G#D#'2@/G!
M=O&`^=]W,(U#`CGPNO____]WX(I;`8/S@#'2@/L_=].)SH/F'P^VT\'F!@G6
MN@(```")-^N]D#'2@/GO=[6-0P,Y\+K_____=ZF*4P&(T(/P@#P_=Q:*6P*(
MV(/P@#P_=PJ`^>!W"8#ZGW<$,=+K@XG.@_*`@^8/#[;2P>(&P>8,@_.`"=8/
MMLL)SKH#````B3?I7/___U6)Y5=64XMU$(M]%#G^BTT,NO____]S)H/Y?[L!
M````=R:-!!XY^+K_____=Q"#^P)T37\S@_L!=%>)]HG:6UZ)T%_)PXUV`('Y
M_P<``+,"=M"!^?__``"S`W;&6UXQTHG07\G#C78`@_L#=<^(RH/B/X/*@,'I
M!HA6`H#-"(GVB,B#X#^#R(#!Z0:(1@&`R<"(#NNGC78`58GE5U93@^P,BW4,
MBT40`?")1>SK)HGV@?O_!P``9K\"`'9J@?O__P``9K\#`'9>,=*)]CM5Z'5U
M`W7H.W7L<VV*#H3)#XB=````#[;1B57PQT7H`0```(M5\`^VWHL,G8#^'`B%
MR8G3=`H/MOJ-%'\/MQQ1.W7LB5WPB=FZ_____W.P@_M_OP$```!WBHT$/CM%
M[+K_____=YF#_P)T+G\4@_\!=#B)^CM5Z'2+@\0,6UY?R<.#_P-U[(C9@^$_
M@\F`B$X"B=G!Z0:`S0B(RX/C/X/+@,'I!HA>`8#)P(GZB`[KQ(UV`(#YP7;!
M@/G?=S*-?@([?>QWM(I6`8/R@(#Z/W>IB<B#X!_!X`8/MLH)R(E%\,=%Z`(`
M``#I-____XUV`(#Y[W>%C5X#.UWL#X=Y____BE8!B-"#\(`\/P^':?___XI>
M`HC8@_"`/#\/AUG___^`^>!W"8#ZGP^&2____XG/@_*`#[;*@^</P><,P>$&
M@_.`"<\/MM,)UXE]\,=%Z`,```#IR_[__XUV`%6)Y5=64X/L#(MU#(M%$`'P
MBWT8B47LZWN-=@`/MMF)7?#'1>@!````BU7P#[;>BPR=@/X<"(7)B=-T"P^V
MPHT40`^W7%$$B5WPBT44BPB)R(/@/P,'#[;3#Z_"B<K!X@@!T#'!BT44B0B+
M%X/"`XD7BPB)R(/@/P'0P>L(B<H/K\/!X@@!T#'!BUT4B0N#!P,#=>@[=>P/
M@Z0```"*#H3)#XEU____@/G!#X:1````@/G?=S.-5@([5>P/AX````"*5@&#
M\H"`^C]W=8G(@^`?P>`&#[;*"<B)1?#'1>@"````Z4'___^`^>]W5(U>`SM=
M['=,BE8!B-"#\(`\/W=`BEX"B-B#\(`\/W<T@/G@=P6`^I]V*HG(@_*`#[;*
M@^`/P>`,P>$&@_.`"<@/MM,)T(E%\,=%Z`,```#IZ/[__X/$#%M>7\G#C78`
M58GE5U93@^P,BUT,_+G_____,<")W_*N]]&-3!G_B4WLZR60@?__!P``9KX"
M`'9J@?___P``9KX#`'9>,=*)]CM5Z'5U`UWH.UWL<VV*"X3)#XB=````#[;Q
MB77PQT7H`0```(M5\`^V]HL,M8#^'`B%R8G7=`H/MOJ-%'\/MSQ1.UWLB7WP
MB?FZ_____W.P@_]_O@$```!WBHT$,SM%[+K_____=YF#_@)T+G\4@_X!=#B)
M\CM5Z'2+@\0,6UY?R<.#_@-U[(GY@^$_@\F`B$L"B?G!Z0:`S0B(RH/B/X/*
M@,'I!HA3`8#)P(GRB`OKQ(UV`(#YP7;!@/G?=S*->P([?>QWM(I3`8/R@(#Z
M/W>IB<B#X!_!X`8/MLH)R(E%\,=%Z`(```#I-____XUV`(#Y[W>%C5,#.U7L
M#X=Y____BE,!B-"#\(`\/P^':?___P^V<P*)\(/P@#P_#X=8____@/G@=PF`
M^I\/ADK___^)SX/R@(/V@(/G#P^VTL'G#,'B!HGQ"=</MO$)]XE]\,=%Z`,`
M``#IR/[__U6)Y5=64X/L#(MU#(M%$`'PB47LZR:)]H'[_P<``&:_`@!V:X'[
M__\``&:_`P!V7S'2B?8[5>AU=@-UZ#MU['-NB@Z$R0^(G0````^VT8E5\,=%
MZ`$```"+5?`/MMZ+#)V`_AP(A<F)TW0+#[;ZC11_#[=<40([=>R)7?")V;K_
M____<Z^#^W^_`0```'>)C00^.T7LNO____]WF(/_`G0N?Q2#_P%T.(GZ.U7H
M=(J#Q`Q;7E_)PX/_`W7LB-F#X3^#R8"(3@*)V<'I!H#-"(C+@^,_@\N`P>D&
MB%X!@,G`B?J(#NO$B?:`^<%VPH#YWW<RC7X".WWL=[6*5@&#\H"`^C]WJHG(
M@^`?P>`&#[;*"<B)1?#'1>@"````Z3?___^-=@"`^>]WAHU>`SM=[`^'>O__
M_XI6`8C0@_"`/#\/AVK___^*7@*(V(/P@#P_#X=:____@/G@=PF`^I\/ADS_
M__^)SX/R@`^VRH/G#\'G#,'A!H/S@`G/#[;3"=>)??#'1>@#````Z<O^__^-
M=@!5B>575E.#[`R+70S\N?____\QP(G?\J[WT8U,&?^)3>SK)9"!__\'``!F
MO@(`=FN!____``!FO@,`=E\QTHGV.U7H=78#7>@[7>QS;HH+A,D/B)T````/
MMO&)=?#'1>@!````BU7P#[;VBPRU@/X<"(7)B==T"P^V^HT4?P^W?%$".UWL
MB7WPB?FZ_____W.O@_]_O@$```!WB8T$,SM%[+K_____=YB#_@)T+G\4@_X!
M=#B)\CM5Z'2*@\0,6UY?R<.#_@-U[(GY@^$_@\F`B$L"B?G!Z0:`S0B(RH/B
M/X/*@,'I!HA3`8#)P(GRB`OKQ(GV@/G!=L*`^=]W,HU[`CM]['>UBE,!@_*`
M@/H_=ZJ)R(/@'\'@!@^VR@G(B47PQT7H`@```.DW____C78`@/GO=X:-4P,[
M5>P/AWK___^*4P&(T(/P@#P_#X=J____#[9S`HGP@_"`/#\/AUG___^`^>!W
M"8#ZGP^&2____XG/@_*`@_:`@^</#[;2P><,P>(&B?$)UP^V\0GWB7WPQT7H
M`P```.G(_O__58GE5U93@^P@BUT,BU40`=J+310#31B*11PYTXA%ZXE5Y(E-
MX`^#Q0```#E-%`^#O````#M=Y,=%W/____]S%XH+A,D/B"(!```/MO&)=?#'
M1=P!````BT7@.444O_____]S&(M]%(H/A,D/B*,````/MO&)=>R_`0```(M%
MW(7`#XY#`0``A?\/CCL!``"+5?`/ML:+-(6`_AP(A?:)T70+#[;*C11)#[=,
M5@2+5>P/ML:+-(6`_AP(A?:)3?")T'0+#[;"C11`#[=$5@0YP8E%[`^%$P(`
M``-=W`%]%#M=Y',,BWW@.7T4#X)$____@'WK`'0.BT44*T7@@\0@6UY?R<.+
M1>0IV(M=%"E=X.OHC78`,?^`^<$/AEW___^`^=\/AT0!``"+512#P@([5>"_
M_____P^'0/___XM%%(I0`8/R@#'_@/H_#X<L____B<Z#YA_!Y@8/MLH)SF:_
M`@")=>SI$____XUV`(#YP<=%W``````/AMO^__^`^=\/AXT```"->P([?>3'
M1=S_____#X>__O__BE,!@_*`@/H_QT7<``````^'J?[__XG(@^`?P>`&#[;*
M"<B)1?#'1=P"````Z8W^__^+=>0IWHEUV(M]X"M]%(M-V#G/B7W4B?@/C],`
M``")P3G`B=[\BWT4\Z8/E\,/DL$HRP^^PX7`#X7U_O__BT78*T74Z>K^__^`
M^>_'1=P`````#X<U_O__C5,#.U7DQT7<_____P^'(O[__XI3`8C0@_"`/#]W
M'P^V<P*)\(/P@#P_=Q*`^>`/AYX```"`^I\/AY4```#'1=P`````Z>O]__\Q
M_X#Y[P^'!?[__XM5%(/"`SM5X+______#X?Q_?__BWT4BE<!B-"#\(`\/W<:
MBWT4#[9W`HGP@_"`/#]W"H#YX'<3@/J?=PXQ_^G!_?__B<CI)O___XG(@_*`
M@_:`@^`/#[;2P>`,P>(&B?$)T`^V\0GPOP,```")1>SID/W__RG!B<CI!_[_
M_XG/@_*`@_:`@^</#[;2P><,P>(&B?$)UP^V\0GWB7WPQT7<`P```.DV_?__
MC78`58GE5U93@^PDBT4,`T40BUT4BU48`=HY10R)1>B)5>0/@]`````YTP^#
MR````(GVBTWH.4T,QT7@_____W,:BWT,B@^$R0^(7`$```^VT8E5\,=%X`$`
M```[7>3'1=S_____<Q>*"X3)#XC8````#[;!B47LQT7<`0```(M%X(7`#XZ5
M`0``BWW<A?\/CHH!``"+5?`/ML:+-(6`_AP(A?:)T70+#[;ZC11_#[=,5@2+
M5>P/ML:+-(6`_AP(A?:)3?")T'0+#[;ZC11_#[=$5@0YP8E%[`^%-`(``(M-
MX`%-#(MUZ`-=W#EU#',).UWD#X(Z____BU7HBT7D*U4,*=@YPG0XN`$```!S
M#HE=#(M=Y(E=Z+C_____BWWH.7T,<QN)]HMU#(H6@/H@#X7:````_T4,BWWH
M.7T,<N<QP(/$)%M>7\G#@/G!QT7<``````^&)?___X#YWP^'5P$``(U[`CM]
MY,=%W/____\/APG___^*4P&#\H"`^C_'1=P`````#X?S_O__B<Z#YA_!Y@8/
MMLH)SHEU[,=%W`(```#IU_[__XUV`(#YP<=%X``````/AJ'^__^`^=\/AYX`
M``"+=0R#Q@([=>C'1>#_____#X>"_O__BT4,BE`!@_*`@/H_QT7@``````^'
M:?[__XG/@^<?P><&#[;*"<^)??#'1>`"````Z4W^__^`^A\/ARK____WV.DC
M____BWWHBT7D*WT,*=@Y^(E]V(E%U`^/U````(G!.<")W_R+=0SSI@^7PP^2
MP2C+#[[#A<`/A>O^__^+1=@K1=3IX/[__X#Y[\=%X``````/A^K]__^+50R#
MP@,[5>C'1>#_____#X?4_?__BWT,BE<!B-"#\(`\/W<7#[9W`HGP@_"`/#]W
M"H#YX'=S@/J?=V['1>``````Z:+]__^`^>_'1=P`````#X>U_?__C5,#.U7D
MQT7<_____P^'HOW__XI3`8C0@_"`/#]W%P^V<P*)\(/P@#P_=PJ`^>!W38#Z
MGW=(QT7<`````.ES_?__B?CI)?___RG!B<CI)O[__XG/@_*`@_:`@^</#[;2
MP><,P>(&B?$)UP^V\0GWB7WPQT7@`P```.D4_?__B<^#\H"#]H"#YP\/MM+!
MYPS!X@:)\0G7#[;Q"?>)?>S'1=P#````Z0O]__^-=@!5B>575E.#[`R+?0R+
M=1"0B@^$R71*BAZ$VW1(A,EX3`^VT8T$4@^WC`""/AT(1X3;B4WP#XBN````
M#[;3C1Q2#[>$&X(^'0B)1>Q&.<%TP(G*B?8IPHUE]%M>B=!?R<.*'HGV#[;1
M#[;#Z^B-5P,YUP^#EP$``(#YP0^&C@$``(#YWP^'TP```(U'`CG0#X=Z`0``
MBE<!@_*`@/H_#X=K`0``B<B#X!_!X`8/MLH)R(E%\+@"````BU7P`<</ML:+
M#(6`_AP(A<F)T'0+#[;"C11`#[=$40*$VXG!B47P#XE5____C78`C58#.=8/
M@R\!``"`^\$/AB8!``"`^]\/A[<```"-1@(YT`^'$@$``(I6`8/R@(#Z/P^'
M`P$``(G8@^`?P>`&#[;:"=B)1>RX`@```(M5[`'&#[;&BQR%@/X<"(7;B=!T
M"P^VPHT40`^W1%,"B47LZ?#^__^`^>\/AZD```"*5P&(T(/P@#P_#X>9````
MBD<"B$7K@_"`/#\/AX@```"`^>!W!8#ZGW9^B<B#\H`/MLJ#X`_!X`S!X0:`
M=>N`"<@/ME7K"=")1?"X`P```.G^_O__B?:`^^]W88I6`8C0@_"`/#]W58I&
M`HA%ZH/P@#P_=TB`^^!W!8#ZGW8^B=B#\H`/MMJ#X`_!X`S!XP:`=>J`"=@/
MME7J"=")1>RX`P```.DF____@^P(5E?H./G\_XG"@\00Z33^__^#[`A65^@D
M^?S_B<*#Q!#I(/[__XGV58GE@^P4:(#^'`C_=23_=2#_=1S_=1C_=13_=1#_
M=0S_=0CH?.O__\G#B?95B>575E.#[`R+?12+11@!^(MU#(M5$`'R.<>)5>R)
M1>@/@XX```"0.W7L#X./````.WWH<W^*#X3)#XC(````#[;9B5WPN`$```"+
M5?`/MMZ+#)V`_AP(`<>%R8G3=`L/MMJ-!%L/MUQ!!#MU[(E=\(G:<TN#^W^Y
M`0```'85@?O_!P``L0)V"X'[__\``+$#=VF0C00..T7L=QF#^0)T0W\I@_D!
M=$V)R`'&.WWH#X)S____.W7L#X*-````B?:+11"-9?1;7E_)PY"#^0-UUXC:
M@^(_@\J`B%8"B=K!Z@:`S@B(TX/C/X/+@,'J!HA>`8#*P(G(B!;KKY`QP`'&
M.WWHZZJ-=@`QP(#YP0^&./___X#YWW=0C4<".T7H=Y6*5P&#\H`QP(#Z/P^'
M&O___XG+@^,?P>,&#[;*"<NX`@```(E=\.D`____4"EU[/]U[&H@5N@2]_S_
MBT40@\00C67T6UY?R<,QP(#Y[P^'V/[__XU7`SM5Z`^'-O___XI7`8C0@_"`
M/#]W/HI?`HC8@_"`/#]W,H#YX'<%@/J?=BB)R(/R@(/@#P^VTL'@#,'B!H/S
M@`G0#[;+"<B)1?"X`P```.F"_O__,<#I>_[__U6)Y59348M5#(M=$#G:<PR*
M"H3)>`X/ML&)1?1:6S'`7LG#D(#YP7;S@/G?=EJ`^>]WZ8U"`SG8=^**6@&(
MV(/P@#P_=]8/MG("B?*#\H"`^C]WR(#YX'<%@/N?=KZ)R(/S@`^VTX/V@(/@
M#\'B!L'@#(GQ"=`/MO$)\(E%]%I;N`,```!>R<.-<@(YWG>-BE(!@_*`@/H_
M=X*)RX/C'P^VTL'C!@G3B5WT6ENX`@```%[)PU6)Y8M5#(/Z?[@!````=B`P
MP('ZP0```'86@?K?````L`)V#('Z\````!G`@^`#D,G#B?95B>6+51"-0@([
M112Y_____W<6#[8*#[9"`<'A"`'!BU4,B0JY`@```(G(R<.-=@!5B>6+51"-
M0@([1113N?____^+70QW#XG9P>D(B`J(6@&Y`@```(G(6\G#D%6)Y5=64U*+
M30R)SP-]$.M5C78`C7$".?Z)=?!W3`^V&<'C"`^V40&-%!,/ML:+-(6`_AP(
MA?:)TW0*#[;:C01;#[<<1CE]\+C_____=P^)VL'J"(@1B%D!N`(```"#^`)U
M!X/!`CGY<JI86UY?R<-5B>575E-3BW4,BT40`?"+?1B)1?#K>Y"-7@([7?!W
M=P^V#L'A"`^V5@&-%!$/MMZ+#)V`_AP(A<F)TW0+#[;:C01;#[=<002+112+
M"(G(@^`_`P</MM,/K\*)RL'B"`'0,<&+112)"(L7@\(#B1>+"(G(@^`_`=#!
MZP@/K\.)R\'C"`'8,<&+512)"H,'`X/&`CMU\'*!65M>7\G#C78`58GER<.-
M=@!5B>575E-7BTT,B<\#?1#K5HUV`(UQ`CG^B77P=TT/MAG!XP@/ME$!C103
M#[;&BS2%@/X<"(7VB=-T"P^VVHT$6P^W7$8".7WPN/____]W#XG:P>H(B!&(
M60&X`@```(/X`G4'@\$".?ERJ5Y;7E_)PXUV`%6)Y<G#C78`58GE5U93@^P8
MBUT,BW44BU40`=J)]XI%'`-]&#G3B$7SB57D#X.Z````B?8Y_@^#L````(U+
M`CM-Y,=%X/____]W%@^V`P^V4P'!X`@!T(E%[,=%X`(```"-3@(Y^<=%W/__
M__]W%@^V!@^V5@'!X`@!T(E%Z,=%W`(```"+3>"%R7Y]BT7<A<!^=HM-[`^V
MU8L,E8#^'`B%R8M5['0+#[;"C01`#[=4002+3>@/ML6+#(6`_AP(A<F)5>R+
M1>AT#`^V1>B-!$`/MT1!!#G"B47H=3,#7>`#==P[7>0/@DG___^0@'WS`(GP
M=0>+1>0IV"GW@\08*?A;7HG"B=!?R<,/MA,/M@:#Q!A;7BG"B=!?R<.058GE
M5U93@^P4BWT8@^?^BT40@^#^B7W@B47DBT7@BUT,BW44BTWDBU7@B47HBT7D
M`=D!\CE%X(E-\(E5['8#B47HBU7HA=)T1XUV``^V$XL,E8#^'`B%R71Z#[9[
M`8T$?P^V%@^W?$$$BPR5@/X<"(7)='@/MD8!C11`#[=$400YQW5V@\,"@\8"
M@VWH`G6\BWW@.7WD=#"X`0```',-B?.+=>R)=?"X_____SM=\',7C78`BA.$
MTG5,@'L!('5&@\,".UWP<NPQP(/$%%M>7\G#B?;!X@@/MDL!C3P*#[86BPR5
M@/X<"(7)=8C!X@@/MDX!C00*.<=TBH/$%%LIQUZ)^%_)PX32=<"`>P$?=[KW
MV.NV58GE5U93@^P4NO____\QP/R+?0R)T?*N]]&-6?^+?1")T?*N]]&-0?\Y
MV',"B=B+30R-%`&+71`YT8E5Z(TT`P^#M@```(GV.?,/@ZP```"-00([1>C'
M1>3_____=Q8/MCD/ME$!P><(`=>)??#'1>0"````C4,".?#'1>#_____=Q8/
MMCL/ME,!P><(`=>)?>S'1>`"````BT7DA<!^;XM]X(7_?FB+5?`/ML:+/(6`
M_AP(A?]T"P^VPHT$0`^W5$<"BT7L#[;\BSR]@/X<"(7_B57P=`P/MD7LC01`
M#[=$1P(YPHE%['4K`TWD`UW@.TWH#X)/____C78`BU7H@\04*=XIRELI\EZ)
MT%_)PP^^$0^^`X/$%%M>*<*)T%_)PXUV`%6)Y5=64X/L#(M=%(M5&`':BW4,
MBT40`?`YTXE%\(E5['-A.<9S4I"-2P([3>QW5`^V.P^V4P'!YP@!UXGZ#[;&
MBSR%@/X<"(7_B<N)T70+#[;*C01)#[=,1P2-5@([5?!W(8G(P>@(B`:(3@$[
M7>R)UG,0.U7P<J^+11"-9?1;7E_)PSMU\'/PBWT(BU]8:B`I=?#_=?!65_]3
M1(M%$(/$$(UE]%M>7\G#B?95B>6X`@```,G#B?95B>6X`@```,G#B?95B>57
M5E.#[#R+=0R)\`-%$$B-51B+712)5=2)==")1<R*`X3`=!R0/"5T*#MUS'02
MQ@8`B@N(3@&#Q@)#B@.$P'7EQ@8`*W70C67T6XGP7E_)PY!#BA.-0M`\"7;V
M@/HN=/&`^BUT[(#Z;'1U@/IS=!N`^F1T>8#Z=71T.W7,=,+&!@#&1@$E@\8"
MZZ^+3=2+.8M5S"GR@T74!(7_B7W(B57$#X2+````,<#\N?____^+?<CRKO?1
MC5'_C002.T7$<R2%TNL3Q@8`BTW(B@%!B$8!@\8"B4W(2G7K0^E;____0XH3
MZX;1;<2+5<1*Z].+3<PI\8/Y'XU]V`^&0O___XM%U(-%U`2`^F2+`'0Q4FH*
M5U#HDYS__X/$$.L*Q@8`B$8!1X/&`HH'A,!U\$/I"?___\=%R,H0&0CI:?__
M_U%J]NO-C78`58GE5U93@^P<BUT,B=^+11P#?1"+=0C'1>P`````QP``````
MBT985U.-5?!25O]0((/$$(7`B<)^+HGVBT7P@_@K=`QW2H/X"70%@_@@=54!
MTXM&6%=3C57P4E;_4""#Q!"%P(G"?]2+=1B%]G0%BWT8B1^#^@$9P(/@-8/`
M(8M='(D#,<"-9?1;7E_)PXGV@_@M=1`QR8-][``/E,$!TXE-[.NMN/____\Q
MTO=U%,=%V`````#'1>@`````B5WDB57<B47@B?:+1EA74XU-\%%6_U`@@\00
MA<!^08M5\`'#C4+0@_@)=V.)PCM5%(E5\'ULBT7@.47H=T5T/(M-Z`^O310!
MT8E-Z(M&6%=3C4WP45;_4""#Q!"%P'^_=4"+=1B%]G0%BWT8B1^+71S'`U8`
M``#I2____SM5W':_B?;'1=@!````Z7S___^-0K^#^!EW2(/J-SM5%(E5\'R4
MBU48A=)T!8M%&(D8.UWD=%^+=>R%]G0U@7WH````@'8S@WWL`8M5',<"(@``
M`!G`C67T6UXM````@%_)PXU*GX/Y&7>[@^I7Z3____^+?>B%_WC-BUW8A=MU
MQHM-[(7)BT7H#X2^_O__]]CIM_[__XM-',<!(0```.FG_O__C78`58GE5U93
M@^P<BUT,B=^+11P#?1"+=0C'1>P`````QP``````BT985U.-5?!25O]0((/$
M$(7`B<)^+HGVBT7P@_@K=`QW2H/X"70%@_@@=54!TXM&6%=3C57P4E;_4""#
MQ!"%P(G"?]2+=1B%]G0%BWT8B1^#^@$9P(/@-8/`(8M='(D#,<"-9?1;7E_)
MPXGV@_@M=1`QR8-][``/E,$!TXE-[.NMN/____\QTO=U%,=%Z`````#'1>0`
M````B5W@B578B47<B?:+1EA74XU-\%%6_U`@@\00A<!^08M5\`'#C4+0@_@)
M=V.)PCM5%(E5\'ULBT7<.47D=T5T/(M-Y`^O310!T8E-Y(M&6%=3C4WP45;_
M4""#Q!"%P'^_=4"+=1B%]G0%BWT8B1^+71S'`U8```#I2____SM5V':_B?;'
M1>@!````Z7S___^-0K^#^!EW/(/J-SM5%(E5\'R4BU48A=)T!8M%&(D8.UW@
M=#"+=>B%]G4WBUWLA=N+1>0/A`'___^-9?1;7O?87\G#D(U*GX/Y&7?'@^I7
MZ4O___^+31S'`2$```#IUO[__XM]'+C_____QP<B````Z<7^__^-=@!5B>57
M5E.#[$R+11"+?0P!^(M5'(MU",=%Z`````")1<S'`@````"+7EC_=<Q7C4WL
M45;_4R"#Q!"%P(G"?B^0BT7L@_@K=`QW3H/X"70%@_@@=5D!UXM>6/]US%>-
M3>Q15O]3((/$$(7`B<)_THMU&(7V=`6+71B).X/Z`1G2@^(U@\(ABWT<B1<Q
MP#'2C67T6UY?R<.)]H/X+740,<"#?>@`#Y3``=>)1>CKJ8M-%,=%Q`````#_
M=<2)3<#_=<!J_VK_QT6T`````,=%T`````#'1=0`````B7W(Z$?G_/^#Q!#_
M=<3_=<!J_VK_B47@B57DZ!_L_/^)1=R+1129@\00B46XB56\BUY8_W7,5XU5
M[%)6_U,@@\00A<!^<HM5[`''C4+0@_@)=@^-0K^#^!D/A[0```"-0LF)1>R+
M3>P[310/C;P```"+7>0Y7=1W(G((BU7@.570=QB+7=2+1=`S7>0S1>`)PW5$
M.TW<=C^-=@"+7EC_=<Q7C57L4E;'1;0!````_U,@@\00A<!_CG5SBW48A?9T
M!8M%&(DXBWT<QP=6````Z=W^__^-=@"+1=#W9;B+7=`/KUV\B=&+5;@/KU74
M`=D!T8E%J(M%[#';B4VLB470BU6HB5W4BTVL`570$4W4Z1W___^-2I^#^1EW
M$HU"J8E%[(M-[#M-%`^,1/___XM-&(7)=`6+51B).CM]R'1QBW7HA?9T$8%]
MU````(!R$W<8@WW0`.L)@7W4____?W("=P>+1;2%P'0JBWWHBTT<,<"%_\<!
M(@```+H```"`#X4R_O__N/____^Z____?^DC_O__BUWHA=N+1="+5=0/A!+^
M___WV(/2`/?:Z0;^__^+71S'`R$```#I]/W__XGV58GE5U93@^Q,BT40BWT,
M`?B+51R+=0C'1>@`````B47$QP(`````BUY8_W7$5XU-[%%6_U,@@\00A<")
MPGXOD(M%[(/X*W0,=TZ#^`ET!8/X('59`=>+7EC_=<17C4WL45;_4R"#Q!"%
MP(G"?]*+=1B%]G0%BUT8B3N#^@$9TH/B-8/"(8M]'(D7,<`QTHUE]%M>7\G#
MB?:#^"UU$#'`@WWH``^4P`'7B47HZZF+313'1;P`````B4VXQT7D`````,=%
MR`````#'1<P`````B7W`_W6\_W6X:O]J_^BOY/S_@\00B478B57<_W6\_W6X
M:O]J_^B'Z?S_B474BT44F8/$$(E%L(E5M(M>6/]UQ%>-5>Q25O]3((/$$(7`
M?G*+5>P!QXU"T(/X"78/C4*_@_@9#X>T````C4+)B47LBTWL.TT4#XV\````
MBUW<.5W,=R)R"(M5V#E5R'<8BUW,BT7(,UW<,T78"<-U1#M-U'8_C78`QT7D
M`0```(M>6/]UQ%>-5>Q25O]3((/$$(7`?XYU<XMU&(7V=`6+11B).(M]',<'
M5@```.G=_O__C78`BT7(]V6PBUW(#Z]=M(G1BU6P#Z]5S`'9`=&)1:B+1>PQ
MVXE-K(E%R(M5J(E=S(M-K`%5R!%-S.D=____C4J?@_D9=Q*-0JF)1>R+3>P[
M310/C$3___^+31B%R70%BU48B3H[?<!T)XMUY(7V=2Z+?>B%_XM%R(M5S`^$
M7_[___?8@](`C67T6U[WVE_)PXM=',<#(0```.D^_O__BT4<QP`B````NO__
M__^X_____^DJ_O__58GE5U93@>P<`0``BT40BU48/?\```"-M>C^__^+70S'
M`@````!V!;C_````BWT,`<?K$XN5Y/[__P'#C4+_@_AD=Q^(%D:+50B+0EA7
M4XV-Y/[__U'_=0C_4""#Q!"%P'_1BUT4B3-2_W484XV-Z/[__U'HA^,``(M%
M%(LPC;WH_O__*?X#=0R+712),XUE]%M>7\G#B?95B>575E.#['R+112%P(M]
M#,=%D`````"-==G&1=D`#XBD````N,W,S,SW91B)T<'I`XT$B='@BE48*,*(
MT(/`,(U>_XA&_^LPC78`N&=F9F;WZ8E5A(M5A(E%@,'Z`HG(P?@?B=$IP8T$
MB='@B?(HPHC02X/`,(@#A<F)SG7-BTV0A<ET!$O&`RV)_@-U$#GWB7V4<R:*
M`X3`=""+30B+45A65P^^P%!1_U(D@\00A<!^"0''0SGW<MR)]BM]E(UE]%M>
MB?A?R<.+71B%VP^)4?____==&,=%D`$```#I0O___Y!5B>575E.#['R+112%
MP(MU&(M]',=%D``````/B/H```")^HU-V`GRB4V4QD78`'4QZ=D```")]FH`
M:@I75NAMX?S_B<?!YP*#Q!`!Q]'G*?Z)\?]-E(MUE(/!,(@.B=>)QH/_`'?1
M@?[___]_=\F%]HGQ=#B^9V9F9HGVB<CW[HE5A(M5A(G/P?H"P?\?*?J-')+1
MXRC9_TV4B46`B,B#P#"+792%TH@#B=%USXMUD(7V=`G_392+393&`2V+?0R)
M_@-U$#GW<SB+592*`H3`="^)]HM-"(M96%;_=0P/OL!04?]3)(/$$(7`?A0!
M10S_190Y=0QS"8M5E(H"A,!UTRE]#(M%#(UE]%M>7\G#C5W7B5V4QD77,.N2
MA?\/B?[^___WWH/7`/??QT60`0```.GK_O__B?95B>575E.#[$R+=1"+70R%
M]HG9#X3_`0``BWT0BP<IV(G"P>H?`="#X/Z-/!@Y^W,;@#L`=1:*0P$\(`^$
M`P(``#P)#X3[`0``C78`.?D/A,0!``#'1=0`````@#D`=0J`>0$M#X3^`0``
MBT44QP``````B@&$P'4*@'D!*P^$-P(``,=%T/"__@K'1<Q<+^\KQT7(#P``
M`(3`#X5X`0``BD$!/#`/A/`!``"#Z#`\"0^'8@$``(/!`@^V\(U9$#G[=BB)
M^^LDD(`Y``^%/0(``(I!`8/H,#P)#X<O`@``C12V#[;`C310@\$".=EUV3GY
M#X07`@``C5D2.?O'1=P`````B4WDB5W@B5VL=@:)?:R-=@"`.0`/A18"``"*
M00&#Z#`\"0^'"`(``(M=W(T4FP^VP(/!`HT44#M-K(E5W'72.?D/A((!``"`
M.0`/A7X!``"*00&#Z#`\"0^'<`$```^VT(U!`CGXB578B47$#X36`0``@'D"
M``^%S`$``(I``8/H,#P)#X>^`0``BUW8C12;#[;`C1Q0C4$$BU40.?B)7<")
M`G05@'D$`'4/BD@!@^DP@/D)#X8R`@``.W70#X<I`@``#X0+`@``B76PNP#H
M=DB+1;#WXVM]L!>)P\=%M`````")T`'X:56T`.AV2(T\$+ED````BT7<]^&)
M1>@!7>B)5>R+1<`1?>PQ]@%%Z!%U[.L=D(M5%(M-$,<"(0```(D9QT7H````
M`,=%[`````"+1>B+5>R#Q$Q;7E_)PXGV@\$".?D/@_W]__^`.0`/A?3]__^*
M00$\('3E/`ETX>GD_?__@\$".?G'1=0!````=**+=13'!O_____'1=#X7W\%
MQT7,KI?W%<=%R`@```"*`>G]_?__,?:-=@"#P0(Y^71G@#D`=0:`>0$P=.Z-
M61+I!?[__X/!`CGY#X13____B@'IM_W__SM-X'5BOP#*FCN)\/?GB<.+?1"+
M1=R)UHD/,=*+3=0!PQ'6A<ET!_?;@]8`]]Z)7>B)=>R+1>B+5>R#Q$Q;7E_)
MPXM%U(M]$(7`B0]T*_?>B?"9B47HB57LBT7HBU7L@\1,6UY?R<.)RRM=Y-'K
MB?#W))W`21T(ZY6)\#'2Z]2)=;"[`.0+5(M%L/?CBWVPB</1YXG0QT6T````
M``'X:56T`.0+5(T\$+D*````BT7<]^&)1;@!7;B)5;R+==@1?;PQ_P%UN!%]
MO(MUU(M%Q(M5$(M-N(M=O(7VB0*)3>B)7>P/A(#^__^!?;P```"`<@AW,(-]
MN`!W*HM%N/?8BU6\@](`]]KI2/___XM]S#E]W`^"Z?W__XM5R#E5P`^&W?W_
M_XM-U(M5%#'`A<G'`B(```"Z````@`^%%?___[C_____NO_____I!O___XUV
M`%6)Y8M%$"M%#(G"P>H?`=#1^,G#58GEBT44T>#)PXGV58GEBU40*U4,BT44
M@^+^T>`YT'8"B=#)PXUV`%6)Y8M%#(M5$(M-%.L.B?;&``"(2`&#Z@*#P`*#
M^@%W[\G#D%6)Y8M5#(G0`T40C4H!.<%S!H!X_R!T!"G0R<.`>/X`=?:#Z`(Y
MP7/O@'C_('3M*=#)PY!5B>6#[!1H@/X<"/]U)/]U(/]U'/]U&/]U%/]U$/]U
M#/]U".A,T?__R<.)]E6)Y8/L%&H`_W4D_W4@_W4<_W48_W44_W40_W4,_W4(
MZ"/1___)PY!5B>575E.#[!"+30R+712+11`!R(G>BE4<`W48.<&(5?.)1>1S
M8HGV.?-S7(U!`CM%Y+______=Q0/MCD/ME$!P><(`=>)?>R_`@```(U#`CGP
MNO____]W%`^V`P^V4P'!X`@!T(E%Z+H"````A?]^-(72?C"+1>@Y1>QU,@'Y
M`=,[3>1RHHGV@'WS`(G8=0>+1>0IR"G>*?")PH/$$%M>B=!?R<,/MA$/M@LI
MRNOLBU7L*U7HZ^2058GE5U93@^P,BTT,BUT4B<\#?1")W@-U&#GY<V>-=@`Y
M\W-@C4$".?C'1>C_____=Q8/M@$/ME$!P>`(`=")1?#'1>@"````C4,".?"Z
M_____W<4#[8##[93`<'@"`'0B47LN@(```"+1>B%P'XGA=)^(XM%[#E%\'4M
M`TWH`=,Y^7*<@\0,B?HIWBG*6RGR7HG07\G##[81#[8#*<*#Q`Q;7HG07\G#
MBU7P*<+K[Y!5B>575E.#[!2Z_____S'`_(M]#(G1\J[WT8U9_XM]$(G1\J[W
MT8U!_SG8<P*)V(M-#(T4`8M=$#G1B57HC30##X.V````B?8Y\P^#K````(U!
M`CM%Z,=%Y/____]W%@^V.0^V40'!YP@!UXE]\,=%Y`(```"-0P(Y\,=%X/__
M__]W%@^V.P^V4P'!YP@!UXE][,=%X`(```"+1>2%P'YOBWW@A?]^:(M5\`^V
MQHL\A8#^'`B%_W0+#[;"C01`#[=41P*+1>P/MOR+/+V`_AP(A?^)5?!T#`^V
M1>R-!$`/MT1'`CG"B47L=2L#3>0#7>`[3>@/@D____^-=@"+5>B#Q!0IWBG*
M6RGR7HG07\G##[X1#[X#@\046UXIPHG07\G#C78`58GE5U93@^P,BWT,BT44
M.<>+=1"+71AT$#GS=QM24U!7Z$+7_/^#Q!`YWG</C67T6XGP7E_)PY")\^OA
MBU4(B?&+0E@IV6H@48T4'U+_=0C_4$2#Q!"-9?1;B?!>7\G#58GE5U93BUT,
MB=\#?1`Y^XMU&',QBQ:0BT44BPB)R(/@/P'0#[83#Z_"B<K!X@@!T#'!BU44
MB0J+!D.#P`,Y^XG"B09RTEM>7\G#D%6)Y5=64X/L&(I%%(A%\XI%&(M=#(A%
M\HMU$(I%'(M-)`'>B$7QBWT@C4,!`<\Y\(M5*(EU[(E-Z(E]Y`^#TP```(UQ
M`3G^<UZ-=@"*`X3`B$7?=2J*1?,X0P$/A+D```"*0P&(1>.*1?(X1>,/A+P`
M``"*1?$X1>,/A-D```"*1=^(`H@!BDL!B$H!B`Z#P@*-3@&#PP*-<P$[=>QS
M=HUQ`3MUY'*EB<@K1>B+73"+?2R)`XD'C4'_.T7H=BZ`>?\`=2B`>?X`=2*)
M]L8`(,9`_P"-6/^#Z`([1>AV#H![_P!U"(![_@!TXHGVB?#K%L8"`,8!`,9"
M`2"-2`'&`""#P@*#P`([1>1RY8/$&%M>,<!?R<.-<0'KC8U[`CM][`^#.___
M_XG[B@?I4____XM]"&8/MD=5B`%FBT]4B`YF#[9'5X@"9HM'5HA"`8U.`8/"
M`ND\____B<B+72PK1>B)`XM]((M=,(D[Q@$`Q@8`BWT(9@^V7U>(&F:+1U:(
M0@&-3@&#Q@*#P@([=>1RV^EW____58GE4XM-$(M5#$DQP(-]%`*)TW0#6\G#
M.<IS$H`Z`'4-@'H!('4'@\(".<IR[HG0*=A;R<.-=@!5B>6+30R*`8/`7SQ6
MBU40=QHIRDI^%8I1`8#ZH'8-_L*X`@```'0$R<.)]C'`R<-5B>6*10R#P%\\
M5QG`]]"#P`+)PU6)Y5=64XMU$(M]%#G^BU4,N?____]S4X/Z?W9'C8)<____
M/3@!``!W2@^WG!)8_AT(,<F%VW0SC58".?JY_____W<GB=F!R8"```")R\'[
M"(A.`8@>6UZY`@```(G(7\G#B?:(%KD!````6UZ)R%_)PXGVC8HY_?__@?F*
M`0``=AJ-FNO?__^!^_T"``!W%@^WG!)6MAT(ZYB)]@^WG!+R]AT(ZXR-@J#;
M__\]X@$``'8;C8H`T/__@?DI`0``=QH/MYP20)`=".ED____#[><$N"I'0CI
M5____XV:X,W__X/["7<-#[><$NJ+'0CI/____XV"`++__SU430``=PT/MYP2
M@+D<".DE____C8J$8___@_EF=PT/MYP2J!L<".D-____C9KA8?__@?N!`0``
M=PT/MYP20A4<".GR_O__C8+_`/__,=L]Y`````^'W_[__P^WG!*>41L(Z=+^
M__]5B>575E.+71"+=10Y\XM]#`^V"[K_____<T.#^7]^2(U#`CGPNO____]W
M,L'A"`^V<P&-%#&!XG]_``"-BM_>__^!^3<%``!W+@^WC!(^4QX(@_D!&=+W
MTHD/@^("6UZ)T%_)PXUV`(D/6UZZ`0```(G07\G#B?:-FM_8__^!^TX"``!V
M&HV"W\___S')/5U'``!WO0^WC!+>H1T(Z[.0#[>,$IY"'@CKJ(GV58GE5U93
M48M5"(M%#(LRBSB+71!+@_O_#X2R````A=MT6HH6@/J`=AN`^O]T%HI.`8A-
M\X/I0(#Y/G9,@'WS`'@^B?:*#P^VP0^VTHJ(H*0>"$=&.(J@I!X(=+@/MD[_
M#[9?_P^VD:"D'@@/MH.@I!X(*<*)T%I;7E_)PXH6Z\2`??/_=+Z)]HH/@/F`
M=K>`^?]TLHI'`8A%\H/H0#P^=T,/MM+!X@@/MD7S#[;)"<+!X0@/MD7R"<$Y
MRG4\2TN#Q@*#QP*#^_\/A5#___^)]HM5"(DRBW4,B3XQTHG06EM>7\G#@'WR
M``^)6/___X!]\O]UK>E-____#[;:@_M_B=!V9(/K00^VQ(T\P(TT>(T4MHV\
M4T*@__]FB[0_H*4>"`^VT8'N`'\``(/Z?XG(#[?>C4J_=P.-2L`/ML2-%,"-
M/%"--+^-E'%"H/__9HN,$J"E'@B!Z0!_```/M\&)VBG"Z0W___^#ZT#KFE6)
MY5=64X/L#(M%&(E%[(M%$(I5'#E%&(A5\W8#B47LBW4,BWT4BUWLC78`2X/[
M_P^$K@```(7;=%:*%H#Z@'8;@/K_=!:*3@&(3>N#Z4"`^3YV2(!]ZP!X.HGV
MB@\/ML$/MM**B*"D'@A'1CB*H*0>"'2X#[9._P^V7_\/MI&@I!X(#[:#H*0>
M""G"ZUZ)]HH6Z\B`?>O_=,*)]HH/@/F`=KN`^?]TMHI'`8A%ZH/H0#P^=U8/
MMM+!X@@/MD7K#[;)"<+!X0@/MD7J"<$YRG5/2TN#Q@*#QP*#^_\/A53___^)
M]HEU#(E]%#'2A=*)T'4,@'WS`'0.BT7L*T48@\0,6UY?R<.+11#K\(!]Z@`/
MB4G___^`?>K_=9KI/O___P^VVH/[?XG0=F2#ZT$/ML2-/,"--'B-%+:-O%-"
MH/__9HNT/Z"E'@@/MM&![@!_``"#^G^)R`^WWHU*OW<#C4K`#[;$C13`C3Q0
MC32_C91Q0J#__V:+C!*@I1X(@>D`?P``#[?!B=HIPNE>____@^M`ZYJ058GE
M5U93@^P(BT48BU40.=")1?!V`XE5\(MU#(M]%(M=\(GV2X/[_P^$P@```(7;
M=&**%H#Z@'8;@/K_=!:*3@&(3>^#Z4"`^3YV5(!][P!X1HGVB@\/ML$/MM**
MB*"D'@A'1CB*H*0>"'2X#[9._P^V7_\/MK&@I!X(#[:#H*0>""G&A?9T<(GP
M@\0(6UY?R<.)]HH6Z[R`?>__=+:)]HH/@/F`=J^`^?]TJHI'`8A%[H/H0#P^
M#X>D````#[;2P>((#[9%[P^VR0G"P>$(#[9%[@G!.<H/A9T```!+2X/&`H/'
M`H/[_P^%0/___XGVB74,B7T4,?:+51@Y51!TB+\!````<U6+112)51")10R_
M_____XM5$(T<$"M=\#G8#X-B____C5`!BDK_@/D@=1F-=@")T(E5#$(YV`^#
M1O___XI*_X#Y('3J@/D?B?@/AS7____WV.DN____BT4,Z[2`?>X`#XGK_O__
M@'WN_P^%2/___^G<_O__#[;:@_M_B=!V8H/K00^VQ(T4P(TT4(T\MHV4>T*@
M__]FB[02H*4>"`^VT8'N`'\``(/Z?XG(#[?>C4J_=P.-2L`/ML2-/,"-%'B-
M-)*-O'%"H/__9HN,/Z"E'@B!Z0!_```/M\&)WNF<_O__@^M`ZYR058GE5U93
M@^P,BT40BW4,BUT4B47PBTT828/Y_W0YB?:%R71(BA.`^H!V&8#Z_W04#[9[
M`8U'P#P^=CF)^(3`>"^-=@`/MOJ*AZ"D'@B(!D-&28/Y_W7)BTT8.4WP=V:+
M1?"-9?1;7E_)PXGVBA/KU/[`=-"!Y_\```#!X@@)^@^VPH/X?XUXOW<#C7C`
M#[;6C032C01"C12`C8170J#__V:+E`"@I1X(@>H`?P``B=!FP>@(B`:(5@&#
MPP*#Q@))Z5/___]3BUWP*UT84VH@5NC_T/S_BT7P@\00C67T6UY?R<.058GE
M5U93@^P0BE44B%7SBE48B%7RBE4<BT4,B%7QBU40`<*+322)5>R+52`!RCM%
M[(M=*(E-Z(E5Y'1".=%T/HUP`3MU['1@BA"`^H!V78#Z_W18#[9X`8U'P#P^
M=V2($X@1BA:(4P&(40&#PP*#P0)&.W7LB?!T!3M-Y'7"B<\K?>B+53"+=2R)
M.HD^ZPF0Q@$@Q@,@04,[3>1U\X/$$%M>,<!?R<.0BA")]CI5\W0?.E7R="HZ
M5?%T+X@3B!%#0>NOB?B$P'GC_L!UDNO=D#MU['3<B@:(`X@!0T'KDI#&`0#&
M`_]!0^N(B<@K1>B+52R)`HM]((MU,(D^Q@$`Q@/_04,[3>1U\^N2D%6)Y8M%
M#(H0@/J`BTT0=AC^PG04*<%)?@^*4`&-0L`\/G8-A-)X!9`QP,G#_L)T^+@"
M````R<.058GEBU4,@/J`=@W^PK@"````=`3)PXGVN`$```#)PY!5B>564XM=
M$(MU%#GSBTT,NO____]S,(/Y?W8DC8%<____/:T#``!W2P^WC`EX%B`(A<EU
M&ULQTHG07LG#C78`B`NZ`0```%N)T%[)PXUV`(U#`CGPNO____]WZXG*P?H(
MB!.(2P%;N@(```")T%[)PXUV`(V1\-___X'Z`@,``'8:C8&@V___/>(!``!W
M%P^WC`D`Q1\(ZYB-=@`/MXP)@-$?".N+C9$`T/__@?HI`0``=AJ-@>#-__\]
M@P```'<:#[>,"0"F'PCI8____P^WC`E@JQ\(Z5;___^-D7+,__^#^D=W#0^W
MC`F$HA\(Z3[___^-@0"R__\]I5$``'<-#[>,"4#*'@CI)/___XV1U`;__X'Z
M_0```'<-#[>,">AQ'0CI"?___XV!T`'__SVU`0``#X?\_O__#[>,"6!D'0CI
MZ_[__XGV58GE5U93BUT0BW44.?.+?0RY_____W-"#[83@_I_?D2-0P(Y\+G_
M____=R[!X@@/MG,!C0PRC9G`?O__,=*!^P]]``!W"`^WE`F@'!\(@_H!&<GW
MT8D7@^$"6UZ)R%_)PXUV`(D76UZY`0```(G(7\G#B?95B>53BUT,B@N-07\\
M'HM5$'8'C4$@/!QW%BG:2GX1BE,!C4K`@/D^=A*$TG@'B?8QP%O)PX#Z_'?V
MB?:X`@```%O)PU6)Y8M5#(U"?SP>=@V-2B"`^1RZ`0```'<%N@(```")T,G#
MD%6)Y5=64X/L#(M-#(M%$(T\`8M=%(M%&`'8BE4<.?F(5?.)1>P/@Z\````Y
MPP^#IP```)`/MC&-1G\\'G8(C58@@/H<=VJ)^"G(2'YCBE$!C4+`/#YW58H3
MC4)_/!YV!XU"(#P<=TN+1>PIV$A^0XI#`8A%ZX/H0#P^#X>2````@>;_````
MP>8(#[9!`0^VT@G&P>((#[9#`0G".=8/A8H```"#P0*#PP+K(I"$TGA8BA.!
MYO\````/MM**AN`=(0B*DN`=(0@XT'5804,Y^7,).UWL#X):____B4T,B5T4
M,<F`??,`=`R+11@Y11!V!(E%$)"%R8G(=0:+11`K11B#Q`Q;7E_)PX#Z_'>C
MZ47___^`?>L`>9J`?>O\=Y3I7?___P^VR`^VVBG9Z[6)\2G1ZZ^058GE5U93
M@^P(BU4,BT44BTT8`<&)UXE-\`-]$(G1B<,Y^0^#G````#M=\`^#DP````^V
M,8U&?SP>=@V-5B"`^AP/A\4```"0B?@IR$@/CKD```"*40&-0L`\/@^'IP``
M`(H3C4)_/!YV"XU"(#P<#X>9````BT7P*=A(#XZ-````BD,!B$7O@^A`/#X/
MAZ8```"!YO\```#!Y@@/MD$!#[;2"<;!X@@/MD,!"<(YU@^%WP```(/!`H/#
M`CGY#X)E____D(E=%(E-##';BT4,.?@/A(`````Y^+X!````#X2(````.?AS
M%HU0`9"*2O^`^2!U6(G0B54,0CGX<NZ)V(/$"%M>7\G#A-)X(HH3@>;_````
M#[;2BH;@'2$(BI+@'2$(.-!U6$%#Z?+^__^`^OQWV>DI____@'WO`'G0@'WO
M_'?*Z4G___^-=@"`^1^)\'>M]]CKJ8M-\#E-%'2?.?B^`0````^%>/___XM%
M%(M]\+[_____B44,Z67___\/MM@/MO(I\X7;#X5O____Z3C___^)\RG3Z^V)
M]E6)Y5=64X/L#(M=#(M-$(M5%`'9BT48B4WPC3P".UWP<T(Y^G,^B@J-07\\
M'G8'C4$@/!QW&HG^*=9.?A,/MG(!C4;`/#YV-(GPA,!X*8GV#[;QBH;@'2$(
MB`-"0SM=\'+`B?:+51@Y51!W*(M%$(UE]%M>7\G#//QWU9"("T-".UWP<]\Y
M^G.4B@*(`T)#Z\R-=@!0BWT0*WT85VH@4^CTR?S_BT40@\00C67T6UY?R<.)
M]E6)Y5=64X/L%(I%%(I-&(M]#(A%\XA-\HI%'(M-$(M5)`'YB$7QBT4@`=`Y
MSXM=*(E-[(E5Z(E%Y'-9.<)S59"*#XU!?SP>=@>-02`\''<<BW7L*?Y.?A0/
MMG<!C4;`/#YV8(GPA,!X5HUV`#I-\W1K.DWR#X2B````.DWQ#X2R````B`M'
M0X@*0CM][',%.U7D<JR)UBMUZ(M-,(M]+(DQB3?K"XUV`,8#(,8"($-".U7D
M<O.#Q!1;7C'`7\G#//QWJ8@+1T.("D([5>1SNXH'B`-'0X@"Z["-=@"-=P$[
M=>QSC8H.B,B#P'\\'HGWB$WC=S:+3>PI^4E^SHI/`8U!P#P^=@F$R7G`@/G\
M=[N*3>.("XU^`4.("NNMQ@(`1\8#_T)#Z6#___^(R(/`(#P<=Y?KOXG0*T7H
MBTTLB0&+=2"+?3")-\8"`,8#_T)#.U7D<O/I7/___XUV`%6)Y5=64XMU$(M]
M%#G^BTT,NO____]S78/Y?WY'C4&D/9L```!W50^WE`DHSB$(B=,QTH7;=#Z-
MBU____^#^3YV8HU&`CGXNO____]W)XG:P?H(B!:(7@%;7KH"````B=!?R<.#
M^5R[7X$``'34B`ZZ`0```%M>B=!?R<.-D6_\__^!^L````!V)HV9\-___X'[
M`@,``'<E#[>4"0"'(0CKC8GVB!Y;7K(!B=!?R<.0#[>4"1[&(0CI<O___XV!
M`-O__SUO`0``=AN-D0#0__^!^OX```!W&@^WE`E`8B$(Z4K___\/MY0)0'HA
M".D]____C9D`LO__@?N!1@``=PT/MY0)()D@".DB____C8&):O__/2D*``!W
M#0^WE`G2]1\(Z0C___^-F?\`__\QTH'[Y`````^']/[__P^WE`G>(!\(Z>?^
M__]5B>575E.+71"+=10Y\XM]#`^V$[G_____<Q^#^G]^)(V"7____X/X/G<=
M#[>,$GX9(@B)#[D!````6UZ)R%_)PXUV`(D7Z^V-0P(Y\+G_____=^;!X@@/
MMG,!`?*-FE____^#^SYV+(V*P'[__X'Y?@,``'<H#[>,$D`1(0B)]H/Y`8D/
M&<E;]]%>@^$"B<A?R<.0#[>,$GX9(@CKXHV"87?__SU=%P``=AJ-FL`?__\Q
MR8'[9`H``'?%#[>,$J`/(`CKNP^WC!+"TR`(Z[&058GE5E.+=1`QVXM5##GR
M<Q:-=@"*"HU!7SP^=@2$R7@/0T(Y\G+MB=A;7LG#C78`@\,"@\("Z]55B>57
M5E-1BU4,BW40BWT4B57PA?]T$9`Y\G,,B@J$R7@20H7_=?&0*U7PB=!:6UY?
MR<.0C4%_/!YV"(U9((#[''<5B?`IT$A^#HI:`8U#P#P^=A2$VW@+C5E?@/L^
M=\A"Z\"`^_QW\(/"`NNFC78`58GE5U93@^Q\@'T<`'0,BT48.440#X?N````
MBTT0BW48C40Q`HU5F(/X4(E5E`^'\0```%;_=1"+790#71#_=0R->P'_=92)
M?9#H6<'\_X/$#,8#`/]U&/]U%/]UD.A%P?S_BT48QD0#`0"+31"#Q!"%R;_X
M____BUV4?B6-=@"*$X32#XBR````#[;RBH8@'2((@^\(B`.-<?]#B?&%R7_>
MBTT8A<F_^/___XM=D'XEC78`BA.$T@^($@$```^V\HJ6(!TB"(/O"(@3C7'_
M0XGQA<E_WH/L"/]UD/]UE(U]F.AAQ?S_@\00.WV4B<-T#H/L#/]UE.CLQ_S_
M@\00C67TB=A;7E_)PXE%$(M-$(MU&(U$,0*-59B#^%")590/A@____^#[`Q0
MZ,K`_/^#Q!")193I^_[__XUV``^VPHT$@,'@`HVPX"`B"(N`\"`B"*@0B76,
M=`.#[PBH('0Q@_D!="R*0P&(18L/ML"--(#V!+7P("(($'06BD6+B`.(4P&-
M<?Y#0XGQZ1#___^)]HUQ_XM-C(-Y!`@/COO^__]1C5,!5E)3Z/R__/^+38R)
M^`)!!(/H"(M-$(M5E$N(1`K_@\000XGQZ='^__^-=@`/ML*-!(#!X`*-L.`@
M(@B+@/`@(@BH$(EUA'0#@^\(J"!T,8/Y`70LBD,!B$6##[;`C32`]@2U\"`B
M"!!T%HI%@X@#B%,!C7'^0T.)\>FP_O__B?:-<?^+382#>00(#XZ;_O__4E:-
M0P%04^AHO_S_BTV$B?@"002#Z`B+31B+59!+B$0*_X/$$$.)\>EQ_O__C78`
M58GE5U93@^Q\BU40BTT8C40*`H/X4,=%D`````#'18P`````C7V8#X<K`@``
MBW404%:-'#?_=0R-2P%7B4V4Z`"__/^#Q`S&`P#_=1C_=13_=93H[+[\_XM%
M&(/$$(7VQD0#`0")\<9%B_B)^WXDD(H3A-(/B*8````/MO**EB`=(@B`;8L(
MC7'_B!-#B?&%]G_=BTT8A<G&18+XBUV4?B:-=@"*$X32#X@*`0``#[;RBI8@
M'2((@&V""(UQ_X@30XGQA<E_W8M=&#M=$'8#BUT0C0P[C78`.<\/@Y`!``"+
M=92*%D:)=92*!T<XT'3H#[9?_XE=C`^V?O\I?8R)]HM-D(7)=`Z#[`S_=9#H
M<L7\_X/$$(M%C(UE]%M>7\G##[;"C02`P>`"C;#@("((BX#P("((J!")=81T
M!(!MBPBH('0T@_D!="^*0P&(18,/ML"--(#V!+7P("(($'09BD6#C7'^B`.(
M4P%#0XGQA?;I'/___XUV`(M5A(-Z!`B-<?\/C@3___]15HU#`5!3Z+"]_/^*
M18N+580"0@2#Z`B+31!+@\00B$0/_T.)\87VZ=S^__^-=@`/ML*-!(#!X`*-
ML.`@(@B+@/`@(@BH$(FU?/___W0$@&V""*@@=#6#^0%T,(I#`8B%>____P^V
MP(TT@/8$M?`@(@@0=!>*A7O___^(`XA3`8UQ_D-#B?'IK_[__XUQ_XN-?/__
M_X-Y!`@/CIG^__]25HU#`5!3Z!&]_/^+C7S___^*18("002#Z`B+31B+591+
MB$0*_X/$$$.)\>EK_O__@^P,4.@SO?S_B<>#Q!")19#IO_W__XGVBT48.440
M#X2$_O__N0$```!S"XE%$(M]E+G_____BW40C10W*=HYUP^#8O[__XH'/"!U
M#T<YUP^#4_[__XH'/"!T\3P?B4V,#X="_O__]]F)38SI./[__U6)Y5=64X/L
M((M%$(E%\(M%&#M%\'8#BT7P4/]U%/]U#.@Z;?__B<<K?0R#Q!"%_XGYQD7O
M^(M=#'X@D(H3A-)X+@^V\HJ&(!TB"(!M[PB-<?^(`T.)\87V?^$Y??`/AYD`
M``"+1?"-9?1;7E_)PY`/ML*-!(#!X`*-L.`@(@B+@/`@(@BH$(EUZ'0$@&WO
M"*@@=#"#^0%T*XI#`8A%YP^VP(TT@/8$M?`@(@@0=!6*1>>-<?Z(`XA3`4-#
MB?&%]NN7B?:+5>B#>@0(C7'_?H12C4L!5E%3Z*"[_/^*1>^+5>@"0@2#Z`B+
M30Q+@\00B$0Y_T.)\87VZ5S___]0BU7P*?I2:B"+70P!^U/HB[_\_XM%\(/$
M$(UE]%M>7\G#D%6)Y5=64X/L#(M=#(I%%(MU$`'>B$7SBD48B$7RB77LBD4<
MBU4DB$7Q.UWLBT4@BTTHB57HC3P"=":)]CGZ=""*`SI%\W1%.D7R=%`Z1?%T
M5H@!0X@"04([7>QUWXUV`(G6*W7HBT4PBUTLB3"),^L+C78`Q@$@Q@(@04(Y
M^G7T@\0,6UXQP%_)PXGVC7,!.W7L=+.)\XH&Z[>)]L8"`$/&`?]"0>NQB="+
M=2PK1>B)!HM=((MU,(D>C78`Q@(`0L8!_T$Y^G7TZ[:)]E6)Y8M-$#M-%+C_
M____<R`/M@$/MY0`X#LB"(M%#(D0,<"%TG4%@#D`=06X`0```,G#B?95B>56
MBW40.W444[C_____BUT,<R</ML>+#(7@-"((,=*%R70&#[;#BA0(,<"$TH@6
M=02%VW4%N`$```!;7LG#58GE5E.+70R*$S')A-*+=1!X"5N)R%[)PXUV``^V
MPBVA````@_A==Q>)\"G82'X0#[9#`2VA````@_A=L0)VTX#ZCG0-@/J/="0Q
MR5N)R%[)PXGQ*=E)?NP/MD,!+:$```"#^#ZY`@```':GZ]<IWH/^`G[5#[93
M`8'JH0```(/Z77?&#[9S`H'NH0```(/^7;D#````#X9W____,<GKK%6)Y0^V
M50R-@E____^#^%VY`@```'87@?J.````=`\QP('ZCP````^4P(U,``&)R,G#
MB?95B>575E.+312+70R%R8MU$(G:=!<Y\W,3C78`#[8"@_A_=Q1"270$.?)R
M\(G0*=A;7E_)PXUV`(G70CGR<R(]C@```'0F/8\```!T+"VA````@_A==PJ*
M`CR@=@3^P'7#B?@IV%M>7\G#B?:*`H/`8#P_=J^)^.OJ#[8"0CGR<LR)^.O>
MC78`58GE,<!3BTT,BUT0.=ES%HH1@/J.=!6`^H]T&(32>!Q`03G9<NI;R<.-
M=@!`@\$"Z]J)]H/``H/!`^O0@\`"@\$"Z\A5B>575HM-$(MU%#GQ4[O_____
M<WT/MA&#^G]^:XUY`CGWN_____]W:8V:7____X/[70^V>0%W9(V/7____S';
M@_E==TV!^O0````/CUH!``#!X@B-E#H`@/__C;)?WO__@_Y=C4J`#X?>````
M#[>4"7YS(PB+30PQVX72B1%T$KL"````ZPN0BT4,B1"[`0```(G86UY?R<.-
M=@"!^HX```!T;3';@?J/````=>2-AU____^#^%UWV8U1`SGRN_____]WS0^V
M40*-BE____\QVX/Y77>\@?_T````#X^C`0``P><(C107C9I17?__@_L5C8J`
M?___#X?,````#[>4"0*E(PB+30R)$;L#````ZX&-EU____\QVX/Z/@^'</__
M_P^WM#^`MB,(A?:+?0R)-P^%2?___X!Y`0`/A5'___^[`@```.E'____C8)?
MW?__@_A==AB-NE#<__^#_TIW&@^WE`D`;B,(Z0?___\/MY0)OG`C".GZ_O__
MC9I?V___@_M2=PT/MY0)7FLC".GB_O__C;)?VO__@_Y5=T@/MY0)GF@C".G*
M_O__C012P>`$*="+70R-M$=IA0``B3.[`@```.G)_O__C;(57?__@_X&=RH/
MMY0)8J0C"(M-#(D1Z23___^-@E_9__^#^#=W*@^WE`D>9B,(Z7?^__^-NA]9
M__^#_QMW*@^WE`D^G",(BTT,B1'I[_[__XVZ7]C__X/_4'<J#[>4"5YC(PCI
M0O[__XV"/EC__X/X#'<J#[>4"5::(PB+30R)$>FZ_O__C9I?U___@_L?=T@/
MMY0)'F$C".D-_O__C9H.6/__@_L,=T@/MY0)W)DC"(M-#(D1Z87^__^-!'_!
MX`0I^(V\0A6)``"[`P```(M5#(DZZ>_]__^-LE_/__^#_EUW*@^WE`E>4",(
MZ;K]__^-LE]6__^#_B]W*@^WE`D>EB,(BTT,B1'I,O[__XV1W\[__X/Z77<J
M#[>4"9Y-(PCIA?W__XVZ7U7__X/_5G<J#[>4"5Z3(PB+30R)$>G]_?__C8'?
MS?__@_A==RP/MY0)WDHC".E0_?__C8)?5/__@_A6=RP/MY0)GI`C"(M-#(D1
MZ<C]__^)]HVYW\S__X/_77<J#[>4"1Y((PCI&?W__XV:7T___X/[77<J#[>4
M"=Z%(PB+30R)$>F1_?__C9G?R___@_M==RH/MY0)7D4C".GD_/__C9'?SO__
M@_I==RH/MY0)'H,C"(M-#(D1Z5S]__^-L=_*__^#_EUW*@^WE`F>0B,(Z:_\
M__^-L=_-__^#_EUW*@^WE`E>@",(BTT,B1'I)_W__XV1W\G__X/Z77<J#[>4
M"=X_(PCI>OS__XVYW\S__X/_77<J#[>4"9Y](PB+30R)$>GR_/__C8'?R/__
M@_A==RH/MY0)'CTC".E%_/__C8'?R___@_A==RH/MY0)WGHC"(M-#(D1Z;W\
M__^-N=_'__^#_UUW*@^WE`E>.B,(Z1#\__^-F=_*__^#^UUW*@^WE`D>>",(
MBTT,B1'IB/S__XV9W\;__X/[77<J#[>4"9XW(PCIV_O__XV1W\G__X/Z77<J
M#[>4"5YU(PB+30R)$>E3_/__C;'?Q?__@_Y==RH/MY0)WC0C".FF^___C;'?
MR/__@_Y==RH/MY0)GG(C"(M-#(D1Z1[\__^-D=_$__^#^EUW*@^WE`D>,B,(
MZ7'[__^-N=_'__^#_UUW*@^WE`G>;R,(BTT,B1'IZ?O__XV!W\/__X/X77<J
M#[>4"5XO(PCI//O__XV!W\;__X/X77<J#[>4"1YM(PB+30R)$>FT^___C;G?
MPO__@_]==RH/MY0)GBPC".D'^___C9G?Q?__@_M==RH/MY0)7FHC"(M-#(D1
MZ7_[__^-F=_!__^#^UUW*@^WE`G>*2,(Z=+Z__^-D=_$__^#^EUW*@^WE`F>
M9R,(BTT,B1'I2OO__XVQW\#__X/^77<J#[>4"1XG(PCIG?K__XVQW\/__X/^
M77<J#[>4"=YD(PB+30R)$>D5^___C9'?O___@_I==RH/MY0)7B0C".EH^O__
MC;G?PO__@_]==RH/MY0)'F(C"(M-#(D1Z>#Z__^-@=^^__^#^%UW*@^WE`F>
M(2,(Z3/Z__^-@=_!__^#^%UW*@^WE`E>7R,(BTT,B1'IJ_K__XVYW[W__X/_
M77<J#[>4"=X>(PCI_OG__XV9W\#__X/[77<J#[>4"9Y<(PB+30R)$>EV^O__
MC9G?O/__@_M==RH/MY0)'APC".G)^?__C9'?O___@_I==RH/MY0)WEDC"(M-
M#(D1Z4'Z__^-L=^[__^#_EUW*@^WE`E>&2,(Z93Y__^-L=^^__^#_EUW*@^W
ME`D>5R,(BTT,B1'I#/K__XV1W[K__X/Z77<J#[>4"9X6(PCI7_G__XVYW[W_
M_X/_77<J#[>4"5Y4(PB+30R)$>G7^?__C8'?N?__@_A==RH/MY0)WA,C".DJ
M^?__C8'?O/__@_A==RH/MY0)GE$C"(M-#(D1Z:+Y__^-N=^X__^#_UUW*@^W
ME`D>$2,(Z?7X__^-F=^[__^#^UUW*@^WE`G>3B,(BTT,B1'I;?G__XV9W[?_
M_X/[77<J#[>4"5X.(PCIP/C__XV1W[K__X/Z77<J#[>4"1Y,(PB+30R)$>DX
M^?__C;'?MO__@_Y==RH/MY0)G@LC".F+^/__C;'?N?__@_Y==RH/MY0)7DDC
M"(M-#(D1Z0/Y__^-D=^U__^#^EUW*@^WE`G>"",(Z5;X__^-N=^X__^#_UUW
M*@^WE`F>1B,(BTT,B1'ISOC__XV!W[3__X/X77<J#[>4"1X&(PCI(?C__XV!
MW[?__X/X77<J#[>4"=Y#(PB+30R)$>F9^/__C;G?L___@_]==RH/MY0)7@,C
M".GL]___C9G?MO__@_M==RH/MY0)'D$C"(M-#(D1Z63X__^-F=^R__^#^UUW
M*@^WE`F>`",(Z;?W__^-D=^U__^#^EUW*@^WE`E>/B,(BTT,B1'I+_C__XVQ
MW['__X/^77<J#[>4"=[](@CI@O?__XVQW[3__X/^77<J#[>4"9X[(PB+30R)
M$>GZ]___C9'?L/__@_HR=RH/MY0)7OLB".E-]___C;G?L___@_]==RH/MY0)
MWC@C"(M-#(D1Z<7W__^-@=^O__^#^%UW*@^WE`F>^"((Z1CW__^-@=^R__^#
M^%UW*@^WE`D>-B,(BTT,B1'ID/?__XVYWZ[__X/_77<J#[>4"=[U(@CIX_;_
M_XV9W['__X/[77<J#[>4"5XS(PB+30R)$>E;]___C9G?K?__@_M==RH/MY0)
M'O,B".FN]O__C9'?L/__@_I==RH/MY0)GC`C"(M-#(D1Z2;W__^-L=^L__^#
M_EUW*@^WE`E>\"((Z7GV__^-L=^O__^#_EUW*@^WE`G>+2,(BTT,B1'I\?;_
M_XV1WZO__X/Z77<J#[>4"9[M(@CI1/;__XVYWZ[__X/_77<J#[>4"1XK(PB+
M30R)$>F\]O__C8'?JO__@_A==RH/MY0)WNHB".D/]O__C8'?K?__@_A==RH/
MMY0)7B@C"(M-#(D1Z8?V__^-N=^I__^#_UUW*@^WE`D>Z"((Z=KU__^-F=^L
M__^#^UUW*@^WE`F>)2,(BTT,B1'I4O;__XV9WZC__X/[77<J#[>4"5[E(@CI
MI?7__XV1WZO__X/Z77<J#[>4"=XB(PB+30R)$>D=]O__C;'?I___@_Y==RH/
MMY0)GN(B".EP]?__C;'?JO__@_Y==RH/MY0)'B`C"(M-#(D1Z>CU__^-D=^F
M__^#^EUW*@^WE`G>WR((Z3OU__^-N=^I__^#_UUW*@^WE`E>'2,(BTT,B1'I
ML_7__XV!WZ7__X/X77<J#[>4"1[=(@CI!O7__XV!WZC__X/X77<J#[>4"9X:
M(PB+30R)$>E^]?__C;G?I/__@_]==RH/MY0)7MHB".G1]/__C9G?I___@_M=
M=RH/MY0)WA<C"(M-#(D1Z4GU__^-F=^C__^#^UUW*@^WE`F>UR((Z9ST__^-
MD=^F__^#^EUW*@^WE`D>%2,(BTT,B1'I%/7__XVQWZ+__X/^77<J#[>4"=[4
M(@CI9_3__XVQWZ7__X/^77<J#[>4"5X2(PB+30R)$>G?]/__C9'?H?__@_I=
M=RH/MY0)'M(B".DR]/__C;G?I/__@_]==RH/MY0)G@\C"(M-#(D1Z:KT__^-
M@=^@__^#^%UW*@^WE`E>SR((Z?WS__^-@=^C__^#^%UW*@^WE`G>#",(BTT,
MB1'I=?3__XVYWY___X/_77<J#[>4"9[,(@CIR//__XV9WZ+__X/[77<J#[>4
M"1X*(PB+30R)$>E`]/__C9G?GO__@_M==RH/MY0)WLDB".F3\___C9'?H?__
M@_I==RH/MY0)7@<C"(M-#(D1Z0OT__^-L=^=__^#_EUW*@^WE`D>QR((Z5[S
M__^-L=^@__^#_EUW*@^WE`F>!",(BTT,B1'IUO/__XV1WYS__X/Z77<J#[>4
M"5[$(@CI*?/__XVYWY___X/_77<J#[>4"=X!(PB+30R)$>FA\___C8'?F___
M@_A==RH/MY0)GL$B".GT\O__C8'?GO__@_A==RH/MY0)'O\B"(M-#(D1Z6SS
M__^-N=^:__^#_UUW*@^WE`G>OB((Z;_R__^-F=^=__^#^UUW*@^WE`E>_"((
MBTT,B1'I-_/__XV9WYG__X/[77<J#[>4"1Z\(@CIBO+__XV1WYS__X/Z77<J
M#[>4"9[Y(@B+30R)$>D"\___C;'?F/__@_Y==RH/MY0)7KDB".E5\O__C;'?
MF___@_Y==RH/MY0)WO8B"(M-#(D1Z<WR__^-D=^7__^#^EUW*@^WE`F>MB((
MZ2#R__^-N=^:__^#_UUW*@^WE`D>]"((BTT,B1'IF/+__XV!WY;__X/X77<J
M#[>4"=ZS(@CIZ_'__XV!WYG__X/X77<J#[>4"5[Q(@B+30R)$>EC\O__C;G?
ME?__@_]==RH/MY0)'K$B".FV\?__C9G?F/__@_M==RH/MY0)GNXB"(M-#(D1
MZ2[R__^-F=^4__^#^UUW*@^WE`E>KB((Z8'Q__^-D=^7__^#^EUW*@^WE`G>
MZR((BTT,B1'I^?'__XVQWY/__X/^77<J#[>4"9ZK(@CI3/'__XVQWY;__X/^
M77<J#[>4"1[I(@B+30R)$>G$\?__C9'?DO__@_I==RH/MY0)WJ@B".D7\?__
MC;G?E?__@_]==RH/MY0)7N8B"(M-#(D1Z8_Q__^-@=^1__^#^%UW*@^WE`D>
MIB((Z>+P__^-@=^4__^#^%UW*@^WE`F>XR((BTT,B1'I6O'__XVYWY#__X/_
M77<J#[>4"5ZC(@CIK?#__XV9WY/__X/[77<J#[>4"=[@(@B+30R)$>DE\?__
MC9G?C___@_M==S`/MY0)GJ`B".EX\/__C;'?DO__,=*#_D(/A_?P__\/MY0)
M/MXB"(M-#(D1Z>KP__^-L=^.__^#_EUW#0^WE`G>G2((Z3WP__^-D=^-__^#
M^EUW#0^WE`D>FR((Z27P__^-@=^,__^#^%UW#0^WE`E>F"((Z0WP__^-N=^+
M__\QTH/_!0^'_.___P^WE`D\EB((Z>_O__^)]E6)Y5=64XM]$#M]%(M=#+G_
M____<PR#^W]_$8@?N0$```!;7HG(7\G#C78`@_M<#X2_````C8->____@_@4
M=S@/MY0;?.$B"(72=&R-7P([712Y_____W?)@<*`@```B=#!^`B(!XA7`;D"
M````6UZ)R%_)PXUV`('[UP````^$9`$``('[]P````^$9`$``(V3;_S__X/Z
M.`^&X````(V+__O__X/Y4`^'L@$```^WE!M^V2((ZY"#^WU^0XVSGP#__X/^
M/@^'FP```(U30(@7C5\".UT4N?____\/AT#___^*#XA/`;D"````Q@>.Z7K_
M__\/MQ7JXB((Z4C___^#^UR('W7*@_M^#X3P````C8-?____/=T```!V;XVS
M,_[__X/^#P^'3`$```^WE!L&>2,(A=)T9HU?`SM=%+G_____#X?9_O__@<*`
M@```B=#!^`BY`P```,8'CXA'`8A7`NF[_O__@?NE````=">!^SX@``!UD,8'
M?NE2____#[>4&Q[;(@CIO/[__P^WE!M^>R,(ZY[&!USI,____XVS`"#__X'^
MJP,``'=@C5<".U44N?____\/AV7^__^X74%,KO?FP>H&C1Q2P>,$*=/1XRG>
MC4ZAC4+UB$\!N0(```"(!^F&_O__#[<5M.(B".E4_O__#[<5LN(B".E(_O__
M#[<5?'XC".DH____@>NLXP``,<F!^ZL#```/AP+^__^-=P,[=12Y_____P^'
M\?W__[A=04RN]^/!Z@:-#%+!X00IT='A*<N-0O6Y`P```(U3H<8'CXA'`8A7
M`NG"_?__C;/PW___@_XK=RT/MY0;`*$B".G0_?__@?OU`0``=%B-DSG]__^#
M^A9W-0^WE!O2=B,(Z9S^__^!^P,A``!T7('[*R$``'1XC8-PWO__@_@#=U4/
MMY0;XITB".F(_?__C8M\_/__@_D,=QD/MY0;(G4C".E<_O__#[<5CGPC".E0
M_O__C8-6_/__@_@D=ST/MY0;C'0C".DX_O__#[<5#.$B".E`_?__C9,NWO__
M@_H"=S$/MY0;6)TB".DH_?__#[<5"N$B".D<_?__C;/^^___@_X-=R4/MY0;
MHG,C".GP_?__C8L`WO__@_D]=R4/MY0;@)PB".GL_/__C9.N^___@_H-=R4/
MMY0;YG(C".G`_?__C;.NW?__@_X9=R4/MY0;G)LB".F\_/__C8OJWO__@_D,
M=R4/MY0;1#DC".F0_?__C8-^W?__@_@%=R</MY0;&)LB".F,_/__C8/^L?__
M/1<!``!W/P^WE!L\W2((Z5[]__^!^Z4B```/A!$!``"!^Q(C```/A-(```"-
MDP#;__^#^DMW10^WE!N`E2((Z4+\__^)]HVSTK#__X'^.`(``'<-#[>4&V36
M(@CI$?W__XV3@J[__X'ZEP,``'<E#[>4&X3*(@CI]OS__XV+8-K__X/Y+W<E
M#[>4&^"3(@CI\OO__XV+UJK__X/Y/'<M#[>4&ZS"(@CIQOS__X'[[R4``'16
MC;/[V?__@_X!=R</MY0;`I,B".FZ^___C8.!JO__/;<&``!W/0^WE!N"M"((
MZ8S\__^-@\#9__^#^`)W3`^WE!N&DB((Z8C[__\/MQ48X"((Z7S[__\/MQ40
MWR((Z7#[__^-LZ>C__^!_I("``!W,0^WE!N.H2((Z4'\__\/MQ4:X"((Z4G[
M__^-DY;9__^#^@5W*`^WE!LFDB((Z3'[__^-D_Z@__^!^D<"``!W)0^WE!N<
MER((Z0+\__^-BP#0__^#^1QW*`^WE!O`?B((Z?[Z__^-BZ*>__^!^3(!``!W
M*`^WE!MDD"((Z<_[__^-L[_/__^!_KT```!W)P^WE!N^?"((Z<CZ__^-@UJ=
M__\]]00``'<G#[>4&]2#(@CIFOO__XV#`++__ST6!P``=R4/MY0;`#,B".F4
M^O__C;-0F/__@_Y)=R4/MY0;('DB".EH^___C9/2JO__@_HU=R@/MY0;)"0B
M".ED^O__C9/LE___@?H#`0``=R@/MY0;.'8B".DU^___C8N%JO__@?GO`0``
M=R@/MY0;JA\B".DN^O__C8O/EO__@?D.!```=R@/MY0;WFLB".G_^O__C;.!
MJ/__@?X<`P``=R</MY0;8A4B".GX^?__C8.IDO__/:T```!W)P^WE!LR8B((
MZ<KZ__^-@T2E__\];0(``'<H#[>4&P@*(@CIQ/G__XVSXI'__X'^L0```'<H
M#[>4&R1?(@CIE?K__XV3M:+__X'ZJ`X``'<H#[>4&XKG(0CICOG__XV3%9'_
M_X'Z^0$``'<H#[>4&XI9(@CI7_K__XV+^)/__X'YZP```'<H#[>4&S#((0CI
M6/G__XV+!H___X'YX@```'<H#[>4&XQ3(@CI*?K__XVS]9+__X'^_@8``'<G
M#[>4&RJX(0CI(OG__XV#"([__SVF#```=R</MY0;,#@B".GT^?__C8/>B___
M/2,$``!W*`^WE!N<H2$(Z>[X__^-L\6`__^!_@D!``!W*`^WE!N*&R((Z;_Y
M__^-DZ.'__^!^C\&``!W*`^WE!NFC"$(Z;CX__^-DZ!___^!^O<"``!W*`^W
ME!M`$R((Z8GY__^-B\J`__^!^2($``!W*`^WE!N4=B$(Z8+X__^-BY!\__^!
M^:D```!W*`^WE!O`"R((Z5/Y__^-LXU\__^!_B<(``!W)P^WE!NZ72$(Z4SX
M__^-@]%[__\]400``'<G#[>4&X(!(@CI'OG__XV#R7/__SW?````=R@/MY0;
M<DHA".D8^/__C;-H=___@?XD`0``=R@/MY0;4/8A".GI^/__C9.<<O__@?H`
M`@``=R@/MY0;^$,A".GB]___C9,L=O__@?K+`0``=R@/MY0;./`A".FS^/__
MC8ME</__@?F7`0``=R4/MY0;2CPA".FL]___C8O(<___@_EL=R@/MY0;D.HA
M".F`^/__C;.W;O__@?YP`0``=R4/MY0;[C4A".EY]___C8-'<___@_AB=R</
MMY0;KN@A".E-^/__C8,Q;?__/1D!``!W*`^WE!NB,"$(Z4?W__^-LYMR__^!
M_@`"``!W)0^WE!LVXR$(Z1CX__^-D_UK__^#^GYW*`^WE!LZ+2$(Z13W__^-
MDV-P__^!^N<$``!W)0^WE!OFU"$(Z>7W__^-BXEJ__^#^6YW)0^WE!MR*2$(
MZ>'V__^-BXAJ__^#^6YW*`^WE!M0R"$(Z;7W__^-L^1I__^!_E@"``!W)P^W
ME!MH(R$(Z:[V__^-@^-I__\]3P(``'<E#[>4&V;"(0CI@/?__XV#6&?__X/X
M'G<E#[>4&Q`>(0CI?/;__XVS56?__X/^(7<E#[>4&^J\(0CI4/?__XV3)6?_
M_X/Z?'<E#[>4&ZH<(0CI3/;__XV3'V?__X/Z?W<H#[>4&WZ[(0CI(/?__XV+
M:F;__X'YU0```'<H#[>4&W09(0CI&?;__XV+96;__X'YP@```'<H#[>4&VJX
M(0CIZO;__XVS6&7__X'^L@```'<G#[>4&]`5(0CIX_7__XV#5F7__SW1`0``
M=R</MY0;C+(A".FU]O__C8.19/__/0D!``!W*`^WE!LB$B$(Z:_U__^-LQIC
M__^!_C<!``!W*`^WE!N4JR$(Z8#V__^-DQMC__^!^A@!``!W+@^WE!OV#"$(
MZ7GU__^-BX9A__\QTH'Y*P$```^'4?;__P^WE!L,IB$(Z43V__^-B^9A__^#
M^01W#0^WE!MR"B$(Z4#U__^-LXMA__^!_@(!``!W#0^WE!NV!R$(Z27U__^-
M@W-@__^#^!-W#0^WE!M&!2$(Z0WU__^-D_\`__^#^EQW#0^WE!N>12`(Z?7T
M__^-BQT`__\QTH/Y`@^'Y/3__P^WE!NZ0R`(Z=?T__^-=@!5B>6+30B+11"+
M5113B4$$C400_HM=#(E!"(M#+,<!"+0F"(E!#(M3-(M#,(E1$(E!%%O)PXUV
M`%6)Y5=64X/L%(M]"(L'9HL09H72#X6,````BU\$B5WLBT<(B47HBUWLBT\0
MBU<,.UWHB4W@B57D=U^)]@^V,XM7%(EW'`^V2P&-0P*%THE/((E%[(E'!(E5
M\'00.T7H=PN%]G4'@'L"`'1+D(M=X(L4LX72#X2"````BUWD#[8$'@^OR(T$
M2F:+$&:%TG47BUWL.UWHB0=VHX/$%%M>N/____]?R<.#P`*)!P^WPH/$%%M>
M7\G#BD`!/$!VKX3`>*N#^4!^IH/Y?W^A#[;0B<C!X`:-%!"+1?`/MY10@-__
M_X72=(>-1QB)!XU+!(G09L='&```B4\$Z[2)]HGSP>,(C10+C4\8B=")#XGQ
MC;(`S/__#0"`___!^0>!_K49``")5R!FB4<89L='&@``=Q&-@8#[``")1QR#
MQ!1;7E_)PXVR`++__X'^I5$``'<+C8%`^P``B4<<Z]^-@<#[``")1QSKU(UV
M`%6)Y8M5"(M%$(E"!`-%%(M-#(E""(M!+,<""+0F"(E"#(M!-(E"$(M!,(E"
M%(E*),G#B?95B>575E.#[`R+=0B+!F:+$&:%T@^$HP```(/``HD&#[?"C67T
M6UY?R<.+5B2+6EC_=@A7C7WP5U+_4R"#Q!"%P(G##X@F`0``BU7PB='!Z0B%
MR0^%%@$``('B_P```(/Z0`^&!P$``(/Z?P^'_@```(M.((G(P>`&`="+5A0/
MMY1"@-___X72#X4=`0``BUX<C78`BT7LBQ28A=(/A(@```"+?>@/M@0[#Z_(
MC01*9HL09H72#X5?____B0:+7A"+3@R+1B2+4%B)7>R)3>C_=@C_=@2-??!7
M4/]2((/$$(7`B<(/CI````"+1?"+?@0!UXG#BU84P>L(#[;(A=*)7AR)3B")
M?@1TBH7;=8:#^4!^@8/Y?P^.#O___XM%[(L4F(72#X5X____B=_!YPB-%`^-
M3AB)T(D.B=F-F@#,__\-`(#__\'Y!X'[M1D``(E6(&:)1AAFQT8:``!W*8V!
M@/L``(E&'(UE]%M>7\G#BUX<BTX@Z1K___^-9?1;7KC_____7\G#C9H`LO__
M@?NE40``=PN-@4#[``")1ASKQXV!P/L``(E&'.N\C7X8`5X$B=!FQT88``")
M/NEB_O__58GE5U93@^Q\B46$_W4,_W4(4(U%N%")UO\2_W44_W40_W6$C7V(
M5_\6@\0@C78`@^P,C4VX4?]6!(D\)(G#_U8$@\00.<.)P744A=M_X87;>$J)
MV"G(C67T6UY?R<.%VW[LA<!YZ(M%A(M0+(MX-`^V`L'@!HL7#[<\$#G[=5"#
M[`R-7;A3_U8$@\00A<")PW_I,<"-9?1;7E_)PX7)?K*+182+4#2+0"P/M@"+
M$L'@!@^W'!")]CG+=9>#[`Q7_U8$@\00A<")P7_L,<#KQ8G8*?CK@8GV58GE
M5U93@^Q\BU4(BUI8BTT8BT,@.4T4B47H#X2C`0``C78`_W48_W44C77P5O]U
M"/]5Z#';@\00A<`/CD(!``"+5?`Y520/A(,!```!110Y51P/A#L!``#_=1#_
M=0R-3>Q1_W4(_U7H@\00A<`/C@\!```!10R$VP^%O0```(M=\#E=(`^$C```
M`(M]"(M-[(G8P>@(BW<TB<J)18B)=9#!Z@B+1RP/MCP0B7WDBW6(#[8$,(E%
MA`^VP0^OQXM]D(L4EXT$0HE%X`^VPP^O182+%+>-!$*+5>"%THE%W`^$TP``
M`(7`#X3+````BT6$.47D=D_1X(E%V/PYP(MUX(M]W(G!\Z9U>HM5A(M-X`^W
M!%&%P'5LBT48.444#X4!____BU40.54,#Y7`C67T6UX/MM")T%_)PXUV`(M=
M\.E'____<QR+7>31X_PYVXMUX(M]W(G9\Z9U*8M5Y(M-W.NMBUWDT>/\.=N+
M=>"+?=R)V?.F#Y?`#Y+"*-`/OL"%P'24N@$```"-9?1;7HG07\G#B?;_=1C_
M=12-??!7_W4(_U7H@\00A<!^V`%%%+,!Z:3^__^-=@`QP#G9#Y7`Z4____^+
M31`Y30SI6O___Y"+?1@Y?11T3?]U&/]U%(UU\%;_=0C_5>B#Q!"%P'Z4BU7P
M.54D=#4Y52!U-0%%%/]U$/]U#(U-[%'_=0C_5>B#Q!"%P`^.:?___P%%#(M=
M&#E=%'6S,=+I7/___P%%%.OLBT48.444=.R+?1`Y?0RZ_____P^$/O____]U
M&/]U%(U=\%/_=0C_5>B#Q!"%P+H!````#XX>____BU4<.U7P#X0F`0``BTT0
M.4T,ZS")\M'B_#G2BW6PB=^)T?.F=1*+?;2+7;`/MP1[A<`/A!\!``"+790!
M70R+51`Y50P/A+T```#_=1#_=0R-7>Q3_W4(_U7H@\00A<")190/CK'^__^+
M=?"+70B+?>R)\,'H"(M+-(GZB46\B4V,P>H(BT,L#[8<$(E=N(M-O`^V!`B)
M1;2)^"7_````#Z_#BUV,BQ23C01"B46PB?`E_P````^O1;2+%(N-'$*+1;"%
MP'0UA=MT,8MUM#EUN`^'/O___W,YBT6XT>#\.<"+=;")WXG!\Z8/A4G___^+
M5;@/MP13Z37___\QP#GW#Y7`Z2G___^Z_____^D-_O__BT6XT>")P3G`B=_\
MBW6P\Z8/E\,/DL$HRP^^P^G^_O__`444_W48_W444_]U"/]5Z(/$$(7`N@$`
M```/C[K^___IQ_W__XM]$#E]#'2H_W4D_W4@_W4<_W48_W44_W40_W4,_W4(
MZ!K\__^#Q""%P'X+BW64`74,Z7[^__^)PNF)_?__D%6)Y5=64X'L#`X``(M%
M"(M0'(72QX4\\O__`````+D!````#X11`0``B=?\,<"Y______*NB<[WUHV]
M*//__[D&````,<#&A6CS__\`B95(\___\ZN)E5#S__^)UXU4%O^-M4CS___'
MA3CR__\&````,=O'A33R__\`````B944\O__B95,\___QX54\___`````,>%
M6//__P````")M?3Q___'A0CR__\`````C78`B?DYO13R___K*(GVBA&`^B!T
M%8#Z"700@/H-=`N`^@H/A?D!``")]D&+O?3Q__\Y3P1WV#'2B[7T\?__BP:%
MTHE&"(D.#X0Q`P``@_H&#X3V`P``@_L!='Q^$8/[`@^$CP```(N]2//__^N4
MA=MU](/Z!`^$R`(``(N54//__U"+A13R__\IT(/X'78%N!T```!04HV]Z/+_
M_U?HJ$/__XD\),:%YO/__P!HWQL9"&CJ&QD(:GZ-A6CS__]0Z#Y0__^#Q""Y
M`0```(UE]%M>#[[!7\G#@_H$=`F#^@$/A3L'``"[`@```(F5./+__^EQ____
M@_H%#X5K!P``@[TX\O__!`^$QP$``(.]./+__P$/A<`'``"+M?3Q___\C;V(
M\O__B='SI8V-2//__XN]3//__XF-]/'__XN-2//__XNU6//__SG/B;4L\___
MB;T4\O__ZR&*$8#Z('03@/H)=`Z`^@UT"8#Z"@^%4@,``$$YC4SS__]WW3'2
MBYU(\___@_H%B9U0\___B8U(\___#X2;`0``_+D%````C;U(\___C;6(\O__
M\Z6+O4SS___'A3#S__\`````B;T4\O__BX54\___@_@##X17`0``@_@"#X1^
M`0``2`^$C`$``(&]-/+__X`````/@R,'``"-O>CS__\#O0CR___\N08```"-
MM2CS___SI?^%-/+__X.%"/+__QB[`0```.E%_O__@/HF#X1J`@``@/H\#X1L
M`@``C4*?/!D/AL@```"-0K\\&0^&O0```(#Z7`^%RP```(N5]/'__XMZ!(U!
M`CGXB;T0\O__#X.Q````@'D!=0^%IP```(G!BX7T\?__QT`0`````.LY#[XY
MC4?0@_@)B<)V%HUWGX/^!8U7J78+C5>_@_H%=R&-5\F%TG@:B[7T\?__BWX0
MP><$`=>)?A!!.8T0\O__=[^Z!0```.EF_?__BX58\___NP$```")A2CS___'
MA33S__\`````QX4X\___`````,>%///__P````#I8/W__P^^\HN5]/'__XER
M$$&Z!0```.D;_?__N@8```#I$?W___^%///__^FN_O__BXU8\___B8TP\___
MZ7[^__^[`@```,>%./+__P0```#I#_W___^%.//__\>%///__P````#I=/[_
M__^%-//__\>%.//__P````#KWXN%-/+__X7`B84$\O__#X@U_?__@^P,:``$
M``#_50R#Q!"%P(F%0/+__[D!````#X09_?__46@`!```:@!0Z,63_/_'!"0`
M`0``_U4,@\00A<")A43R__^Y`0````^$Z_S__U)H``$``&@`_",(4.ATC_S_
MBXT$\O__@\00A<D/CC`!``"-7>B+E03R___K+`^VLP'T__^*A@#\(P@/MHL%
M]/__B[5$\O__.`0.<P.(!`Z#PQA*#X0\`@``B[L(]/__A?]TRO^%//+__^OD
MBY50\___4(N%%/+__RG0@_@=#X>4````4%*-G0CS__]3Z-@___^)'"3&A>;S
M__\`:/4;&0AHZAL9"&I^C95H\___4NDK_/__0;H$````Z9G[__^+M?3Q__]!
MBU8$.<K'1@P!````=@6`.3QT2;H!````Z77[__^`^B9T8(#Z/`^$?00``(U:
MGX#[&78+C4*_/!D/A\X#```/OOI!B;U8\___N@4```#IA/S__[@=````Z6+_
M__^+O?3Q__^+1PQ!0#G*B4<,=J6`.3QUH(/X`G[DN@$```#I$/O__T&Z!```
M`.E)_/__,=*0BX5`\O__BQR0A=MU$(L,E0#X(PB+M4#R__^)#)9"@?K_````
M?MJ+E3SR__^+70B+A43R__^+O4#R__^%THE#+(E[-,=#,`````!U!S')Z4/[
M__^#[`QH`"```/]5#(/$$(7`B4,PN0$````/A"7[__]7:``@``!J`%`Q_^C/
MD?S_@\00.[T$\O__?<"-=>CK7HUV`(N6!/3__X/Z/P^&[OK__X/Z?P^'Y?K_
M_X/[/P^&W/K__X/[?P^'T_K__\'B!HV,&L#O__^+70B+4S!FBP"+G1SR__]F
M`T,,9HD$2D>#QA@[O03R__\/C5W___^+G@CT__^%VW3FBY8`]/__#[;.C88`
M]/__@>+_````B84<\O__#[:!`/PC"`^OPHL4C0#X(PB-!$)F@W@"``^$8?__
M_[D!````Z5GZ__^-=@#'A0#R__\`````BYT$\O__.9T`\O__#XVA_O__C57H
MB94,\O__ZQ__A0#R__^+O03R__^#A0SR__\8.;T`\O__#XUW_O__BXT,\O__
MB[4,\O__BX$(]/__#[:^`?3__X7`B;T@\O__#[:Y!?3__W6WBY5`\O__BQRZ
MA=N)G1CR__\/A8<```"+A43R__\/MAPX@^P,P>,)4_]5#(/$$(N-0/+__X7`
MB02Y#X2B^?__4E-J`%#H5Y#\_S';@\00B?:+M43R__\/M@0^#[:7`/PC"`^O
MPXT,$@^OTX/L!-'@B[5`\O__T>(#!+X#%+T`^",(45)00^CVB_S_@\00@?O_
M````=KN+'+Z)G1CR__^+C0SR__\/MK$$]/__B;7\\?__BY4,\O__BX5$\O__
MBYT@\O__#[:*`/3__P^V%#@/MH,`_",(C1P`#Z_!T>"+C2#R__\#!(T`^",(
M45.+M1CR__\/KY7\\?__C1164%+H?8O\_XN=1/+__P^V%#N+M4#R__\/KY7\
M\?__BPR^9HL\48N%#/+__V8#N`ST__^#Q!!FB3Q1Z7W^__^+E5#S__]0BX44
M\O__*="#^!UV!;@=````4%*-M<CR__]6Z`,\__^)-"1H!QP9"&CJ&QD(:GZ-
MC6CS__]1QH7F\___`.E6^/__BY50\___BX44\O__*="#^!U7=@6X'0```%!2
MC9VH\O__4^BZ.___B1PD:!<<&0AHZAL9"&I^C95H\___4L:%YO/__P#I#?C_
M_X#Z7'47C4$"B[U,\___.?AS"H!Y`74/A,H```"Z!@```.FD^/__BY50\___
MBX44\O__*="#^!U3=@6X'0```%!2C9U(\O__4^A+.___B1PD:"H<&0C&A>;S
M__\`Z6[[__^+E5#S__^+A13R__\IT(/X'59V!;@=````4%*-G6CR__]3Z!`[
M__^)'"1H/AP9",:%YO/__P#I8_?__T&+E4SS__\YRL>%5//__P$```!V!8`Y
M/'04N@$```#I"OC__X`Y/'7Q@_@"?^R+A53S__]!0#G*B854\___=^2Z`0``
M`.GD]___B<''A5CS__\`````ZT$/OAF-0]"#^`F)PG8:C7.?@_X%C5.I=@^-
M4[^#^@4/AR3[__^-4\F%T@^(&?O__XNU6//__\'F!`'6B;58\___03G/=[NZ
M!0```.F']___D%6)Y5=64X/L?/]U$/]U#(M="(I%'%.-?;B(18=7_Q4(B24(
M@\00_W48_W444XUUB%;_%0B))0B#Q!")]H/L#%?_%0R))0B)-"2)P_\5#(DE
M"(/$$#G#=02%VW_@@'V'`'0&,=*%P'@$B=HIPHUE]%M>B=!?R<.)]E6)Y593
MBW4,BUT0BTT4BU48B544B4T0B5T,BT4(B74(6UZZ"(DE",GIW^___XUV`%6)
MY5=64X/L0(M="(M#6/]U$/]U#%.+=12+?1C_4!B#Q!!0_W4,4XU%N%#_%0B)
M)0B#Q!#K0HGVBPZ)R(/@/XG:`P?!^@@/K\*)RL'B"`'0,<&)#HL7@\(#B1>+
M#HG(@^`_`=`/MM,/K\*)RL'B"`'0,<&)#H,'`X/L#(U=N%/_%0R))0B#Q!"%
MP(G#?ZJ-9?1;7E_)PXGV58GE5U93@^P\_W48_W44_W4(BT40C7VXBUT,@^#^
M5XTT&/\5"(DE"(/$$.LCC78`@^P,5_\5#(DE"(/$$(7`B<)^$8G1P?D(B`N(
M4P&#PP(Y\W+<BWT(BT<LBU<T#[8XP><&BQ(Y\P^W%!=S$XG0P?@(B?:(`XA3
M`8/#`CGS<O3V11`!=`/&`P"+11"-9?1;7E_)PU6)Y5=64X/L?/]U$/]U#(M=
M"(I%'%.-?;B(18=7_Q4`B24(@\00_W48_W444XUUB%;_%0"))0B#Q!")]H/L
M#%?_%02))0B)-"2)P_\5!(DE"(/$$#G#=02%VW_@@'V'`'0&,=*%P'@$B=HI
MPHUE]%M>B=!?R<.)]E6)Y593BW4,BUT0BTT4BU48B544B4T0B5T,BT4(B74(
M6UZZ`(DE",GI"^[__XUV`%6)Y5=64X/L0(M="(M#6/]U$/]U#%.+=12+?1C_
M4!B#Q!!0_W4,4XU%N%#_%0"))0B#Q!#K0HGVBPZ)R(/@/XG:`P?!^@@/K\*)
MRL'B"`'0,<&)#HL7@\(#B1>+#HG(@^`_`=`/MM,/K\*)RL'B"`'0,<&)#H,'
M`X/L#(U=N%/_%02))0B#Q!"%P(G#?ZJ-9?1;7E_)PXGV58GE5U93@^P\_W48
M_W44_W4(BT40C7VXBUT,@^#^5XTT&/\5`(DE"(/$$.LCC78`@^P,5_\5!(DE
M"(/$$(7`B<)^$8G1P?D(B`N(4P&#PP(Y\W+<BWT(BT<LBU<T#[8XP><&BQ(Y
M\P^W%!=S$XG0P?@(B?:(`XA3`8/#`CGS<O3V11`!=`/&`P"+11"-9?1;7E_)
MPU6)Y5=64X/L+(G#B57PB[`(`0``B[@,`0``ZQ^#[`@/O@90:-<H&0CH.XS\
M_X/$$(7`="E&B;,(`0``.?YRW8MU\(D^BXL,`0``BU7PB4H$N$4```"-9?1;
M7E_)PXM]\(DWBX,(`0``BU7PB4($B[,(`0``B77@_+D$````O\`H&0CSI@^%
MA````(NS#`$``#EUX(EUZ'-!N0,```"+=>"_Q2@9"/.F=#"+5>!"B57DBW7D
MBT7H.<:)=>")LP@!``!S%D:)=>3\N0,```"+=>"_Q2@9"/.F==?\N0,```"+
M=>"_Q2@9"/.F=0V#1>`#BU7@B9,(`0``BT7@BUWPB4,$C67T6UZX0P```%_)
MPXMUX(H.@^P(#[[YB$WO5VC)*!D(Z$&+_/^#Q!"%P'0=BT7@0(F#"`$``(M=
M\(E#!(L3#[X"C67T6UY?R<.`?>\B#X2A````@'WO)P^$EP```(NS#`$``.LG
MBTW@@^P(#[XY5VC0*!D(Z.V*_/^#Q!"%P'41_T7@BU7@B9,(`0``.77@<M2+
M1?"+=>")<`2+&.L>@^P(#[X[5VC7*!D(Z+>*_/^#Q!"%P'0P0XM5\(D:.UW@
M<MWK(XUV`(/L"`^^1O]0:-<H&0CHCHK\_X/$$(7`=`M.BTWPB7$$.?-RW+A)
M````Z5_^__^+5>!"B[L,`0``.?J)DP@!```/@Z$```"+=?"+#HH!BW7@ZQB)
MUD(Y^HF3"`$```^#G@```(M%\(L(B@$X1@%UXXG6BU7PB7($BY,(`0``B@(X
M`71KC5D!BT7PB1CK'H/L"`^^.U=HUR@9".@"BOS_@\00A<!T-$.+5?")&CGS
M<MZX4P```.G4_?__@^P(#[Y&_U!HUR@9".C5B?S_@\00A<!TW4Z+3?")<00Y
M\W+<N%,```#IIOW__XM]\(L/ZX&-2@&)BP@!``"+??"+#XMW!.N"BW7PBP[I
M9/___Y!5B>575E.![#P!``"+10R+50B+71"+30B#ZH`!PXF5O/[__XF1``$`
M`(F!!`$``(G'B8$(`0``B9W`_O__B9D,`0``.=B-=@`/@]0```"`/SP/A-4`
M```[O<#^__^)O>#^__]S(8`_/.L:B?:)^$>+70@[O<#^__^)NP@!``!S!H!X
M`3QUYHG^B;WD_O__BYW@_O__ZR&)]H/L"`^^"U%HUR@9".CKB/S_@\00A<!T
M,$.)G>#^__\Y^W+=.?-S)9"#[`@/OD;_4&C7*!D(Z,*(_/^#Q!"%P'0+3HFU
MY/[__SGS<MR+E>#^__^+A>3^__\YPG1TBUT(B<&+@Q@!```IT87`=&-645)3
M_]"#Q!"+BPP!``"+NP@!``")C<#^___K1HUE]%M>,<!?R</'A=3^__\`````
MQX70_O__`````(V5X/[__XM%".C>^___@_A#=2"+50B+L@P!``"+N@@!``")
MM<#^__\[O<#^___IU?[__XV5X/[__XM%".BK^___@_@O#X1,!0``@_@A#X3U
M!0``@_@_#X04!```@_A)#X5A"```BT4(BY```0``BXW@_O__BYWD_O__B=8I
MRRMU"(U\'H&!_X`````/A^0$```[E;S^__]V$\8"+HM]"(N7``$``$*)EP`!
M``!64U%2Z/^`_/^+50B+B@`!```!V8F*``$``,8!`(M-"(N1%`$``(/$$(72
M#X5S`P``C78`C97@_O__BT4(Z/[Z__^#^$F)PW0)@_A3#X6@`P``C978_O__
MBT4(Z.#Z__^#^#V)PP^$50$``(/X4W0)@_A)#X5Y`P``BWT(BY<``0``BXW@
M_O__BYWD_O__B=`IRRM%"(UT&(&!_H`````/AR0$```[E;S^__]V$\8"+HMU
M"(N6``$``$*)E@`!``!04U%2Z#^`_/^+10B+B``!```!V8F(``$``,8!`(M-
M"(N1%`$``(/$$(72#X6G````BU4(BYH``0``B[W@_O__BXWD_O__*?DYG;S^
M__^)V'(/ZUQ+.9V\_O__#X/#`@``BA.`^BYU[(G&*=Z`^BYT2H7_=`@Y\0^%
M?`0``(MU"(N6'`$``#')A=)U,L8#`(M%"(F8``$``(7)#X34_O__N`$```"-
M9?1;7E_)PXUV`(H3B<8IWH#Z+G6V3NNS42M%"(/`@%#_M;S^____=0C_THG!
M@\00Z[10BYD``0``*<N#PX!3_[6\_O__4?_2@\00A<`/A#C___^X`0```.NE
MC978_O__BT4(Z'+Y__^#^$ET"8/X4P^%)`4``(M]"(N7``$``(N-X/[__XN=
MY/[__XG0*<LK10B-=!B!@?Z`````#X?!`@``.Y6\_O__=A/&`BZ+=0B+E@`!
M``!"B98``0``4%-14NC<?OS_BU4(BXH``0```=F)B@`!``#&`0"+30B+D10!
M``"#Q!"%T@^%)`$``(M="(N-V/[__XN%W/[__XN3&`$``"G(A=(/A>H```"+
M10B+F``!``"+O>#^__^+C>3^__\I^3F=O/[__XG8<A+IKP```$LYG;S^__\/
M@T4!``"*$X#Z+G7LB<8IWH#Z+@^$G0```(7_#X1[_O__.?$/A'/^___'A<C^
M__\?````.8W(_O__=@:)C<C^__]0_[7(_O__5XU-B%'H%7[\_XU#`;L?````
MB[W(_O__@\00.?/&1#V(`(V]:/___W8"B?-14U!7Z.I]_/^#Q!#&A!UH____
M`%>-78A3:%`I&0C_=0CH[8+\_X/$$+@!````Z1W^__^*$XG&*=Z`^BX/A6/_
M__].Z5W___]64%%3_]*#Q!"%P`^$!?___[@!````Z>W]__]7BYD``0``*<N#
MPX!3_[6\_O__4?_2@\00A<`/A+O^__^X`0```.G"_?__D%.+F0`!```IRX/#
M@%/_M;S^__]1_]*#Q!"%P.F6_?__C97@_O__BT4(Z&[W___'A=3^__\!````
MZ<_[__^-=@"*$^D]_?__BA/IN_[__X/[+P^$*0(``(NUU/[__X7V=&&#^S\/
MA1\#``"+10B+F``!```YG;S^__^)V',.@#LN=`E+.9V\_O__<O*+50B+BAP!
M```QTH7)#X5W`@``Q@,`BWT(A=*)GP`!```/A0K]__^-E>#^__^+10CHW/;_
M_XG#BXW0_O__A<ET2(M%"(NP``$``#FUO/[__XGP<PZ`/BYT"4XYM;S^__]R
M\HM5"(N*'`$``#'2A<D/A3@"``#&!@"+?0B%THFW``$```^%J/S__X/[/@^%
M;`,``(M=".E9^O__BU4(N`$```#'`E1O(&3'0@1E97`@QT((6$U,`.E[_/__
MC97@_O__BT4(Z$CV__^#^$D/A3\"``"+=0B+O>#^__^+G@`!``"+C>3^__\I
M^3F=O/[__XF]S/[__XG8<A+I:`$``$LYG;S^__\/@[\!``"*$X#Z+G7LB<8I
MWH#Z+@^$B`$``(N5S/[__X72=`@Y\0^%J`,``(MU"(N.'`$``#'2A<D/A2D!
M``#&`P"+10B%THF8``$```^%V?O__XV5X/[__XM%".BK]?__B</I'/___XV5
MX/[__XM%".B6]?__QX70_O__`0```.GW^?__QX7$_O__'P```#F-Q/[__W8&
MB8W$_O__4/^UQ/[__U>-C6C___]1Z"-[_/^-0P&['P```(N]Q/[__X/$$#GS
MQH0]:/___P"-?8AV`HGS5E-05^CX>OS_@\00QD0=B`!7C9UH____Z0G]__^+
M50B+F@`!```YG;S^__^)V',.@#LN=`E+.9V\_O__<O*+?0B+CQP!```QTH7)
M=!A2*T4(@\"`4/^UO/[___]U"/_1B<*#Q!#&`P"+30B%THF9``$```^%X/K_
M_XV5X/[__XM%".BR]/__B</I9OW__XH3Z:7^__]7*T4(@\"`4/^UO/[___]U
M"/_1B<*#Q!#INO[__U8K10B#P(!0_[6\_O___W4(_]&)PH/$$.EL_?__3NER
M_O__4BM%"(/`@%#_M;S^____=0C_T8G"@\00Z:O]__^*$^E!_O__@^@A@_@S
M=P?_)(7H*1D(N`80&0A24&AT*1D(_W4(Z`5__/^X`0```.DX^O__C4/?@_@S
M#X?7````_R2%N"H9"(/H(8/X,W=P_R2%B"L9"+C<*!D(5U!HX2@9".N^N/\H
M&0CK\+C<*!D(4E!HH"D9".NIN/\H&0CK\+@&*1D(Z^FX#"D9".OBN!`I&0CK
MV[@8*1D(Z]2X'"D9".O-N"`I&0CKQK@D*1D(Z[^X*"D9".NXN"PI&0CKL;@&
M$!D(ZZJX!BD9".N.N`PI&0CKA[@0*1D(ZX"X&"D9".EV____N!PI&0CI;/__
M_[@@*1D(Z6+___^X)"D9".E8____N"@I&0CI3O___[@L*1D(Z43___^X!A`9
M".DZ____@^@A@_@S#X?8````_R2%6"P9"(U#WX/X,P^'H````/\DA2@M&0BX
MW"@9"%)0:,`I&0CIRO[__[C_*!D(Z^VX!BD9".OFN`PI&0CKW[@0*1D(Z]BX
M&"D9".O1N!PI&0CKRK@@*1D(Z\.XW"@9"%=0:#`I&0CIB/[__[C_*!D(Z^VX
M!BD9".OFN`PI&0CKW[@0*1D(Z]BX&"D9".O1N!PI&0CKRK@@*1D(Z\.X)"D9
M".N\N"@I&0CKM;@L*1D(ZZZX!A`9".NGN"0I&0CI6____[@H*1D(Z5'___^X
M+"D9".E'____N`80&0CI/?___[\?````.<]V`HG/45?_M<S^__^-3<A1Z.1W
M_/^-0P&['P```(/$$#GSQD0]R`"-?:AV`HGS4E-05^C"=_S_@\00QD0=J`!7
MC5W(Z=;Y__^XW"@9".FS_?__N/\H&0CIJ?W__[@&*1D(Z9_]__^X#"D9".F5
M_?__N!`I&0CIB_W__[@8*1D(Z8']__^X'"D9".EW_?__N"`I&0CI;?W__[@D
M*1D(Z6/]__^X*"D9".E9_?__N"PI&0CI3_W__XUV`%6)Y8/L#&@@`0``:@#_
M=0CH2WO\_\G#D%6)Y<G#C78`58GEBU4,BT4(B9`8`0``R<.-=@!5B>6+50R+
M10B)D!0!``#)PXUV`%6)Y8M5#(M%"(F0'`$``,G#C78`58GEBU4,BT4(B9`0
M`0``R<.-=@!5B>6+10C)PU6)Y8M%"(N(!`$``(N`"`$``#G(B<IV"H`Z"G0+
M0CG0=_8IR,G#B?:)T4(YT.OQD%6)Y8M%"(N0!`$``(N`"`$``#').=!V"H`Z
M"G0+0CG0=_:)R,G#B?9!0NOR58GE5U93@^Q4BW4,BU4(A?:)T0^$"@(``(M%
M#(LX.?IT$HH"/"`/A(P!```\"0^$A`$``#GY#X24`0``B@$\+<=%S``````/
MA`$"``"+11#'``````"*`3PK#X1-`@``/##'1<CPO_X*QT7$7"_O*\=%P`\`
M```/A`D"``"#Z#`\"0^'2`$``$$/MO"-60@Y^W8<B?OK&)"*`8/H,#P)#X=5
M`0``C12V#[;`C31003G9=>4Y^0^$/P$``(U9"3G[QT74`````(E-W(E=V(E=
MI'8&B7VDC78`B@&#Z#`\"0^'=@(``(M=U(T4FP^VP$&-%%`[3:2)5=1UWCGY
M#X14`@``B@&#Z#`\"0^'C@(``(U1`0^VP#GZB470B56\#X2C`0``BE$!@^HP
M@/H)#X>4`0``BUW0C02;#[;:C01#C5D"BU4,.?N)1;B)&G0/BE$"@^HP@/H)
M#X9D`@``.W7(#X=;`@``#X0]`@``B76HNP#H=DB+1:CWXVM]J!>)P\=%K```
M``")T`'X:56L`.AV2(T\$+ED````BT74]^&)1>`!7>")5>2+1;@1?>0Q]@%%
MX!%UY.LVB?9!.?ET$XH!/"!T]3P)#X5I_O__03GY=>V+11"+30S'`"$```")
M$<=%X`````#'1>0`````BT7@BU7D@\146UY?R<.+1<R+?0R%P(D/#X2S````
M]]Z)\)F)1>")5>2+1>"+5>2#Q%1;7E_)PXU=[(E=#(H"/"!T<3P)=&V*`H3`
MC;G__P``=)$\+<=%S``````/A?_]__]!.?G'1<P!````#X1R____BW40QP;_
M____QT7(^%]_!<=%Q*Z7]Q7'1<`(````B@$\,`^%]_W__S'V03GY#X1I____
M@#DP=/*-60GI\?W__XGV08H!/"!T^3P)=/7KB$$Y^0^$&O___XH!Z:/]__^)
M\#'2Z4G___^)=:B[`.0+5(M%J/?CBWVHB</1YXG0QT6L``````'X:56L`.0+
M5(T\$+D*````BT74]^&)1;`!7;")5;2+==`1?;0Q_P%UL!%]M(MUS(M%O(M5
M#(M-L(M=M(7VB0*)3>")7>0/A+W^__^!?;0```"`<@P/AX(```"#?;``=WR+
M1;#WV(M5M(/2`/?:Z;G^__\[3=AT0HG+*UW<B?#W))T@B24(B<.+?0R+1=2)
MUHD/,=*+3<P!PQ'6A<ET!_?;@]8`]]Z)7>")=>2+1>"+5>2#Q%1;7E_)P[\`
MRIH[B?#WY^O!BTW$.4W4#X*W_?__BWW`.7VX#X:K_?__BTW,BU40,<"%R<<"
M(@```+H```"`#X4T_O__N/____^Z_____^DE_O__B?95B>6+30B+$8H"//IW
M"HU"`8D!#[8"R<,\^W0O//QT$#S]=!B-0@F)`8M"`<G#B?:-0@.)`0^W0@')
MPY"-0@2)`8M"`27___\`R<.-0@&)`<FX_____\.058GE4XM5"(L*B@$\^G<-
MC4$!B0(/M@$QTEO)PSS[=#L\_'04//UT((U!"8D"6XM!`8M1!<G#B?:-00.)
M`@^W00$QTNO4C78`C5D$B1J+40&)T"7___\`,=+KOHU9`8D:N/____\QTNNP
MC78`58GE5E.+71"#^P"+=0B+30QW&8'Y^@```'<AB`Y;C48!7LG#@_L`=BZ-
M=@#&!OZ)3@&)7@5;C48)7LG#@_L`=^N!^?__``!WV\8&_&:)3@%;C48#7LG#
M@?G___\`=\V)RXG*C48!P>L(P>H0Q@;]B$X!B%@!B%`"6XU&!%[)PY!5B>57
M5E.#[!R+=12%]HM]"(M=$'4645/_=0Q7Z+MO_/^-9?1;7E_)PXUV`%)J`&H#
M5^CE=_S_B<*#Q`R#R@12:@17B<;HTG?\_X/$#%/_=0Q7Z(5O_/^)P^A.<_S_
MBP"#Q`R)1>16:@17Z*UW_/^#Q!`QP(7;=*F#?>0D=5F)?>AFQT7L`P!0BU44
MC022C32`C1RVP>,#4VH!C7WH5^@9=?S_@\00A<!T&WP,,<#V1>X##X5I____
MN/____^-9?1;7E_)P^CB<OS_QP`$````N/_____KYNC0<OS_BTWDB0BX____
M_^O558GE4U"+70B%VW0@@^P(:@"-0Q!0Z-+Q_O^)70B#Q!"+7?S)Z6/;_O^-
M=@"+7?S)PXUV`%6)Y593BUT(BU4,@^P(BW40B9-<`@``C4-3_S25`"<9"%"!
MPU,"``#H4R#__XEU#(E="(/$$(UE^%M>R>D_(/__C78`58GE5E.+=0B+AI0"
M``"%P(V>F`(``'4L4&H`:``@``!3Z/;N_O_'AI0"````````QX;H`@``````
M`(UE^%M>R<.-=@"#[`AJ`%/H)?'^_X/$$.O$58GE5E.+=0B+!H7`="LQV_:&
MW0(``!!U>X/L#/\VZ-U'``"#Q!#VAMT"```0#X61````QP8`````@^P,5NCN
M2P``BY:4`@``@\00A=*-GI@"``!U+U!J`&@`(```4^AE[O[_QX:4`@``````
M`,>&Z`(```````"#Q!"-9?A;7LG#C78`@^P(:@!3Z)'P_O^#Q!#KP8/L"&AP
MKP8(:@WHA7'\_X/$$(/L#/\VB</H3D<``(/$$/:&W0(``!`/A''___^)]H/L
M"%-J#>A9<?S_@\00Z5S___^058GE5U93@^P,BW4(,=LQ__:&W0(``!`/A0<!
M``"+!H7`#X4=`0``]H;=`@``$`^%+`$``(/[_W0(A=L/A<L```"+%H72="\Q
MV_:&W0(``!`/A1T!``"#[`S_-NC(1@``@\00]H;=`@``$`^%+P$``,<&````
M`(/L#%;HV4H``(N.E`(``(/$$(7)C9Z8`@``#X7V````4&H`:``@``!3Z$SM
M_O^#Q!"!OEP"``"!!```QX:4`@```````,>&Z`(```````"XY`<``'0"L-V#
M[`B+'8B))0B)AEP"``#_-(4`)QD(C4934.@C'O__6EE3C;Y3`@``5^@4'O__
M@\00C67T6UZX_____U_)PXM^$(`__XG8#X28````C67T6UY?R<.)]H/L"&AP
MKP8(:@WH'7#\_XG'BP:#Q!"%P`^$Y?[__XGV@^P,5NC/4P``@\00]H;=`@``
M$(G##X35_O__D(/L"%=J#>CE;_S_@\00Z<'^__^#[`AH<*\&"&H-Z,YO_/^)
MPX/$$.G*_O__@^P(:@!3Z+'N_O^#Q!#I]_[__X/L"%-J#>BF;_S_@\00Z;[^
M__^#^P-V/P^W1P&#ZP+VAN$"```"B89<`@``C5<#=`:`?P,C=#Z!^_\!``")
MV%=V!;C_`0``4%*-7E-3Z*,=___I!O___X/L"(L=B(DE",>&7`(``-`'``#_
M-4!&&0CIT/[__U!J!8U/!%&-EE,"``!2Z&T=__^-5PF#Q!#KIY!5B>534(M=
M"(/L#%/HO_W__X/$$(/X_W0I@_@(=^J+4Q"`.OYUXO:#X0(```)T$P^W"@^W
M0@*)B_0"``")@^P"``"+7?S)PY!5B>564XMU"(7V#X24````BUX8A=MT'(U&
M33F#M`,```^$A@```(.[?`,```(/A(@```"+7@R%VW09@^P(:@"-2Q!1Z(CM
M_O^)'"3H(-?^_X/$$(M>"(7;=1:+1D2%P'4GB74(C67X6U[)Z0'7_O^0@^P(
M:@"-1AQ0Z%+M_O^+1D2#Q!"%P'39@^P,4.C?UO[_B74(@\00C67X6U[)Z<[6
M_O^)]HUE^%M>R<.0QX.T`P```````.EK____@^P,BY.L`P``4_]2%(/$$,>#
M?`,```````#I6?___XGV58GE5U93@^PLC4W048U5S%*-1=A0BUT0_W4,C7W4
MBW4(QT7,`0```(E]T,=%U)TO&0C'1=B=+QD(B5W<QT7@`````.@,8@``@\00
M@WW,`70=BT70C5@$BT`$A<!T$(GV@#@M=!^#PP2+`X7`=?*#[`S_==#H$UD`
M`(UE]%M>7\G#C78`@'@!+77;@^P(:CW_,^B"'___,?^#Q!"`.`!T!HUX`<8`
M`(L#ZP6)]L8`+8/L"&I?4.A>'___@\00@#@`=>I1:@)HW(DE"(L3@\("4NC/
M50``@\00@_@A=XC_)(7L+QD(QT80`P```(7_#X1R____@^P,5^B0</S_B0:#
MQ!"#PP2+`^E?____@\,$@684?____XL#Z4[___^%_W00@^P,5^AC</S_@\00
MA<!TVX/#!(%.%(````"+`^DI____QD9A`(/#!(L#Z1O____&1E\!@\,$BP/I
M#?___X/#!(%.%````@"+`^G\_O__4&H`:&"))0A7Z"A5``"#Q!"%P(E&$`^%
MV_[__U%7:,PO&0C_-<3")0CHP&O\_\<$)`$```#HQ&_\_X7_#X2U_O__@^P,
M5^C3;_S_@\00B498Z3W____&1F`!@\,$BP/IF/[__X/#!(%.%``$``"+`^F'
M_O__@^P,_W8\Z*;4_O]86FH05^A8U?[_@\00B48\Z?[^__^#[`S_=CCHAM3^
M_UE8:A!7Z#C5_O^#Q!")1CCIWO[__X/#!(-.%`*+`^DY_O__@^P,A?^)^`^$
ME@$``%#HU'7^_X/$$.FU_O__A?\/A!'^__^#[`S_=BCH-=3^_UA::A!7Z.?4
M_O^#Q!")1BCIC?[__X7_#X3I_?__@^P,_W88Z`W4_O]96&H05^B_U/[_@\00
MB488Z67^__^+3BR%R0^$!P$``(/L"&H05^B>U/[_@\00A<")1<AT&H/L"(U]
MR%?_=BSH>6@``(/$$(3`#X2/_?__@^P,_W7(Z+/3_O^#Q!#I&/[__X7_#X1T
M_?__@^P,_W8<Z)C3_O]86FH05^A*U/[_@\00B48<Z?#]__^%_P^$3/W__X/L
M#/]V(.APT_[_65AJ$%?H(M3^_X/$$(E&(.G(_?__QD9=`8/#!(-.%""+`^D?
M_?__A?\/A!+]__^#[`S_=B3H-M/^_UA::A!7Z.C3_O^#Q!")1B3ICOW__X7_
M#X3J_/__@^P,5^@(;OS_@\00B48,Z7+]___&1FP!@\,$BP/IS?S__X/#!(%.
M%````P"+`^F\_/__@^P(:A!J%.@ZTO[_@\00B48L:@5J`&H$4.BH9@``@\00
MZ=/^__^XI"\9".E@_O__B?95B>575E-6BTT,BT40BUT(,?:-?($$QT7P````
M`.L-D,<#`````(/!!(/#!#GY=!R+$872=.J%]G0*B=`I\$B+=?")!HG6B5WP
MZ]N06UM>7\G#B?95B>575E.#['2+11"--(#!Y@16BE44_W4,B%6WZ(OG_O^#
MQ!"%P(E%K(G##X2#`P``B?'!Z0(QP/R+?:SSJ_=%&``"``!T;8MU"(MV#(7V
MB76P#X3D`0``@'VW`8M-L(MQ!!G`B?&#P`B-1($$B768C7VX,?8YP<=%J```
M``")1:3K$)#'!P````"#P02#QP0[3:0/A(L```"+$872=.6%]G0*B=`I\$B+
M=:B)!HG6B7VHZ]:+30B+>0R)?9"%_Y`/A'8!``"`?;<!&<"+=9"+5@2#P`:-
M1(($,?:-?;B)T3G"B56,QT6@`````(E%G.L2C78`QP<`````@\$$@\<$.TV<
M#X1G`0``BQ&%TG3EA?9T"HG0*?!(BW6@B0:)UHE]H.O6@^P(BTV8_S'_=0SH
M'.K^_XE#%%F+?;!>BW<$_W8$_W4,Z`;J_O^)0Q"+=;!86HM6!/]R"/]U#.CP
MZ?[_B4,(65^+1@3_<`S_=0SHW>G^_XE##%A:BTX$_W$0_W4,Z,KI_O^)`UE?
MBWX$_W<4_W4,Z+CI_O^+5;B+3<")0P2)4SB)2RR+5<B+3@2+?<2)4R2+41B+
M1;R)>S`/MSJ)0S2)>TB+1<R+>@*)0RB)392)>QP/MDH&#[=R!XE+3(ES0`^V
M0@F#Q!"#^0F)0T0/AUX!``"#^0</A*@!``"!S@"```")<T"`?;<`=`Z+592+
M0AR%P`^%1@$``,=#&`````"+=;"+-L=#(`````")=;"#PU"%]@^%'/[__XM=
M"(7;=!V#[`B+50AJ`(/"$%+H;.;^_U__=0CH`]#^_X/$$(M]K(UE]%M>B?A?
MR<.-=@"#[`B+58S_,O]U#.C0Z/[_B4,(B4,,6(M%D%J+<`3_=@3_=0SHM^C^
M_XM]D(D#BW<$BTX(BSF!Y____P"+5@R)>QP/M@J+1;B+5;R#Q!#V11@$B4M,
MQT,4]/H8",=#$/3Z&`C'0S@`````QT,T`````(E#+(E#,(E3)'18BT80#[<0
MB5-`#[9``H/Y"8E#1'<\@_D'#X2.````@,Z`B5-`@'VW`'0'BT84A<!U8<=#
M&`````"+=9"+/L=#(`````"#PU"%_XE]D.F#_?__@_D-=<[KQHM&$`^V$(E3
M0`^V0`'KIH/Y#0^%J_[__^F=_O__@^P(4/]U#.CCY_[_B4,8@\00BT74B4,\
MZ:3^__^#[`A0_W4,Z,;G_O^+3<R#Q!")0QB)2SSKC(/_#@^$:?___X/_".N:
M@_\.#X1/_O__@_\(ZZ*+30B%R70=@^P(BUT(:@"#PQ!3Z/3D_O]?_W4(Z(O.
M_O^#Q!`Q_^F$_O__D%6)Y5=64X/L./]U".B']/__B<.#Q!`QP(/[_P^$U`$`
M`(/L"&HP:C3HL\W^_X/$$(7`B47H#X1$`@``5FH`:``@``"+5>B#PA")5=Q2
MZ#;B_O^+?>B+10B+=>C'1QP,````BU`0@\<,BTT0B7WDQP8`````QT8$````
M`(E."(E5\(/$$(`Z_@^$RP$``(M%$,'@`HE%U(GVBW7H@P8!@U8$`(/L"&H,
M_W7<Z!WC_O^#Q!"%P(E%X`^$J0$``(M5U(/L"(U\&@17_W7<Z/SB_O^+3>"#
MQ!"%P(E!!`^$A0$``(MUX(M5Y(M]U(DRB77DC70X!#'_C4P>_SM]$(E-[`^#
MD0```,=%V`````#K4HGVBU7LBTW@*?*+000YVHDTN`^"UP```%!3_W7P5N@7
M8OS_Q@0>`(M5#`%=\(/$$(72C70>`700BT78BU4,.5P0(',$B5P0($>#1=A0
M.WT0<S"#[`R-1?!0Z%SO__^#Q!"#^/^)PW6:BTW@BUD$QP2[`````$>#1=A0
M.WT0<M.-=@"+7>"+0P2#[`R)-+C_=0CH]/+__X/$$(/X_XG##X3K````BWT(
MBU<0B57P@#K^#X74_O__@_@'#X?+_O__BW7D@_L!QP8`````=A>+30@/MUH!
M#[="`XF9]`(``(F![`(``(M%Z(UE]%M>7\G#@^P(:@#_==SHUN+^_UG_=>CH
M;<S^_UA:BU4(BQV(B24(QX)<`@``ZP<``(G0_S6L1AD(@\!34.AO$?__6%I3
MBUT(@<-3`@``4^A=$?__@\00,<"-9?1;7E_)PX/[!P^'+/[__^EG____@^P(
M:@#_==SH;>+^_UG_=>CH!,S^_X/$$(M%"(/L"(L=B(DE",>`7`(``-@'``#_
M-6!&&0CKDX/L"&H`_W7<Z#;B_O]?_W7HZ,W+_O^#Q!`QP.N6B?95B>53@^P(
M:@!J`&H`BUT(Z#MM_O^#Q!`QTH7`=6^%VW1R4&BX`P``:@!3Z'QD_/^#Q!"+
M%=12&0B#[`B)DY`"``#'@_@"````````B9N8`P``B9N<`P``B9ND`P``C8-3
M`@``_S6$B24(4.A\$/__QH.7`P```8&+#`,``(````#'@UP#```0````B=J)
MT(M=_,G#@^P(:C!HN`,``.B!RO[_@\00,=*%P(G#=-_&@(`#```!Z7G___^)
M]E6)Y3'`R<.058GE5U93@^P0BW4(BUT,BY:L`P``,<!J`/RY_____XG?\J[W
MT4E14VH`:@!J`E;_4@0/OL"#Q""%P'0(C67T6UY?R<.#[`S_MHP"``#HKLK^
M_UA::A!3Z&#+_O^)AHP"``"-9?1;7C'`7\G#58GE5U93@^P,BU4(BX*D`P``
MB47PBU7PB[J4`@``,<"%_P^$QP```(.Z?`,```$/A<,```"#[`AJ,(M5\(N"
MZ`(``(T\A50```!7Z*3)_O^)PX/$$#'`A=L/A)````"+??"#[`B+AZP#``"-
M4U2)4Q2)0U!J$(NWZ`(``(T,M00```!1Z&O)_O^#Q!"%P(E#1`^$I````(M5
M\(G6C7L<@<:8`@``_+D(````\Z6+@I0"``"+LN@"``"-2TV)0PB)<SS'0T``
M````B5,8QT-(`````,>"E`(```````#'@GP#```"````B8JT`P``B=B-9?1;
M7E_)PY"#[`B)UHL=B(DE",>"7`(``-X'``"#QE/_-7A&&0A6Z*`.__]97E.+
M3?"!P5,"``!1Z(X.__^#Q!`QP(UE]%M>7\G#@^P,4^A0R?[_,<#KZU6)Y5=6
M4X/L&/^P%`,``(G&Z#;)_O]8_[80`P``Z"K)_O]8_[88`P``Z![)_O]8_[8<
M`P``Z!+)_O]8_[8@`P``Z`;)_O]8_[8H`P``Z/K(_O]8_[8L`P``Z.[(_O]?
M_[8P`P``Z.+(_O];_[8T`P``Z-;(_O]9_[9@`P``Z,K(_O^+OB0#``"#Q!"%
M_W0ZBQ^+5P2-!),YPXE%\',7B?:#[`S_,X/#!.B?R/[_@\00.UWP<NN#[`Q7
MZ+)>``")/"3HALC^_X/$$%)HA````(V.^`(``&H`4>A78?S_C67T6UY?R<.-
M=@!5B>6+30B+$>L/B?:+0@C'0"P`````BU($A=)U[\<!`````,G#C78`58GE
M5U93@^P,BW4(A?8/A-,!``"+!H7`#X37````BY:4`@``A=*-GI@"```/A?L!
M``!0:@!H`"```%/H!-S^_X/$#,>&E`(```````#'AN@"````````QX9\`P``
M`````,:&@0,```"+OJP#``!J`6H`:@!J`&H`:@%6_U<$BPZ#Q""%R70O,?_V
MAMT"```0#X59`0``@^P,_S;HW#0``(/$$/:&W0(``!`/A9`!``#'!@````"#
M[`Q6Z.TX``"+AI0"``"#Q!"%P`^%2@$``%!J`&@`(```4^AFV_[_@\00QX:4
M`@```````,>&Z`(```````")\.CT_?__@^P,_[:$`@``Z#+'_O]?_[9T`@``
MZ";'_O];_[9X`@``Z!K'_O]9_[:,`@``Z`['_O^#Q!"-CJ@#``"+EJ@#``#'
MAHP"````````QX9X`@```````,>&=`(```````#'AH0"````````ZPZ0BUH(
MQT,L`````(M2!(72=>_'`0````"`OI<#````=">+AIP#``#K%(/L#(NXG`,`
M`%#H8?[__XGX@\00.?!UZ,:&EP,```"+AI@#```Y\'0,@^P,4.@^_O__@\00
MBY:P`P``A=)U.8"^@`,```!T#XEU"(UE]%M>7\GI5<;^_XUE]%M>7\G#@^P(
M:'"O!@AJ#>BF7?S_B<>#Q!#ICO[__X/L#(N.K`,``%;_42R#Q!#KM8/L"&H`
M4^AWW/[_@\00Z:/^__^#[`AJ`%/H9-S^_X/$$.GR_?__@^P(5VH-Z%E=_/^#
MQ!#I7?[__Y!5B>575E.#[!B+10B+L*0#``!6Z.CK__^#Q!"#^/^)Q[H!````
M#X2/````BXZ4`@``C8:8`@``A<F)1>P/A8(```!2:@!H`"```/]U[.B>V?[_
M@\00QX:4`@```````,>&Z`(```````"-=@"+7A"#[`R-5?")7?!2Z++G__^#
MQ!"%P(G#=%"#^/\/A;P```"#[`C_=?!6Z%QN_O^)-"0/OMCH6>O__X/$$(/X
M_XG'=`2%VW2WN@$```"-9?1;7HG07\G#@^P(:@!0Z'G;_O^#Q!#I:____X/L
M#(U%\%#HI>?__XU=\(F&N`(``(F6O`(``(D<).B.Y___B8;``@``BX;@`@``
M@\00]L0"B9;$`@``#X3=````BTWP#[<!#[=1`H/!!(F&[`(``(F6]`(``(E-
M\`-^$#M]\`^'[0```#'2C67T6UZ)T%_)PXN&[`(``*@"#X3%````@^P,C7WP
M5^@BY___B9;,`@``BY;@`@``P>H)@^(!@\0,@_H!B8;(`@``&<"#X/Z#P`>+
MCJP#``!0:@!6_U$(@\00A<"Z`0````^$$?___X/L#/^VX`(``&H`4_]U[%#H
MRO'__X/$((7`B8:4`@``N@$````/A.;^__\PTL>&?`,```$```")GN@"``#'
MAO0"````````Z<7^___VQ"`/A#;___^+3?`/MQ&#P0*)ENP"``")3?#'AO0"
M````````Z17___^#R`&)ANP"``#I+?___X/L#%/H^N7__X/$$(7`#X3__O__
MBWWP,=*)OH@"``#I\?[__XUV`%6)Y5=64X/L#(M="("[6`,```"+?0R+=1!T
M"8"[EP,```!U*(F;I`,``%"+@ZP#``!J`597:@!J`&H#4_]0!(UE]%M>#[[`
M7\G#B?:#[`A65^B*:/[_@\00A<!T#DAUQ%!65U/H\V;^_^O44%974^@$9O[_
MZ\F)]E6)Y5=64X/L#(M="("[6`,```"+?0R+=1!T"8"[EP,```!U-(F;I`,`
M`%"+@ZP#``!J`597:@!J`&H#4_]0!(/$(`^^R(7)N@$```!T+HUE]%M>B=!?
MR<.#[`A65^@&:/[_@\00A<!T+$AUN%!65U/H;V;^_X/$$.O(B?:#[`R+LZP#
M``!3_Q:-9?1;7@^^T(G07\G#4%974^AB9?[_@\00ZY^058GE5U93@>R\#0``
MBT4(]H#=`@``$,>%?/+__P`````/A8X%``"+50B+@B@#``"%P,>"K`,``*")
M)0C'`@````#'@MP"````````=0J+DBP#``"%TG19BTT(5X7`_[$L`P``#X0/
M`P``4(M%"`7X`@``4.ALZ___7HM]"/^W*`,``.CQP?[_6XMU"/^V+`,``.CB
MP?[_BUT(QX,L`P```````,>#*`,```````"#Q!"+50R%TG0(BTT,@#D`=0R+
M=0B+GA`#``")70R+?1"%_W0(BT40@#@`=12+30B+D10#``"%THE5$`^$F@<`
M`(M=%(7;#X0'!0``BT48A<!T"(M5&(`Z`'4,BUT(BXL@`P``B4T8BW4<A?9U
M#(M%"(NX!`,``(E]'(M5((72#X0*!0``BW4(QH:!`P```8M5"(L"A<#'ANP"
M```"````#X7]````BX((`P``A<`/A","``"#^`(/A!H"``"+?0B#OP@#```!
M#X?B`@``BT4<A<#'12``````#X1D!```BTT,A<D/A`\'``#_=0S_-6Q&&0AH
MLP```(VU*/___U:)M8#R___H)1/__X/$#&H`:@%J`N@+5OS_@\00@_C_B<,/
MA#0'``!0:@!J`5/H4BT``(VU&/___XM5"(D"_(M%(+D$````B??SJUC_=0S&
MA1G___\"Z-I4_/^#Q!"#^/\/A/$'``")A1S___^+30C_L?@"``!J$%93BU4<
MAO)FB94:____Z,[C__^#Q!"%P`^%@@<``(MU"(L&A<`/A`X"``")]H/L"%#_
M=0CHP#```(/$$(3`#X7I`P``@^P(:@&+10C_,.BF+@``BU4(BX+\`@``@\00
MA<`/A5X#``"+30B+@0`#``"%P'0#B4$HBU4(BX)0`P``A<!T`XE"'(M-"(N!
M^`(``(7`QX'D`@``"@```'06@^P(4/\QZ/@O``"#Q!"$P`^%T@<``(/L#/]U
M".BNY?__@\00@_C_B<8/A*<!``"+30B+41`/MCJ#_PJ)N>0"```/A+`#``"#
M[`B)RO\UB(DE"('"4P(``%+H@03__XM%",>`7`(``-<'``#'!"0*````_[#D
M`@``_S5<1AD(:/\!``"#P%-0Z(\1__^#Q""+70CV@]T"```0#X1'`0``@^P(
M_[5\\O__:@WH<%;\_X/$$.DO`0``N+PO&0CIY_S__XGVBWT@A?\/A`4%``"+
M50R%TG06_+D*````OPOA"`B+=0SSI@^%OOW__XM=((7;QT4,"^$("`^$(04`
M`%-J`&H!BQ5H1AD(:@&)E8#R___H^E/\_X/$$(/X_XG&#X2;!0``46H!:@)0
MZ$$K``"#Q`R+30B)`6IJ:@"-O:C^__]7Z%E7_/^#Q`QJ9_]U((V5JO[__U+&
MA:G^__\!Z`($__^+10C_L/@"``!J:E=6Z-#A__^#Q""%P`^%(08``(M="(L#
MA<#'@P@#```"````#X7Z_?__Z0_]__^0BTT(@^P(QX%<`@``_P<``(L=B(DE
M"/\U_$89"(G(@\!34.@=`___6%I3BT4(!5,"``!0Z`P#__^#Q!"+70CV@]T"
M```0#X6Y_O__BTT(BQ&%TG0X,=OV@=T"```0#X7=`0``@^P,BTT(_S'H["H`
M`(MU"(/$$/:&W0(``!`/A:D!``"+10C'``````"#[`S_=0CH]2X``(M5"(NZ
ME`(``(/$$(7_C9J8`@``#X7'````4&H`:``@``!3Z&71_O]?BWT(QX>4`@``
M`````,>'Z`(```````#_MX0"``#H.KW^_UZ+10C_L'0"``#H*[W^_UN+30C_
ML7@"``#H'+W^_UF+=0C_MHP"``#H#;W^_XM=)(M-"(/$$(7;QX&,`@``````
M`,>!>`(```````#'@70"````````QX&$`@```````'@'B<CHA?/__S'`C67T
M6UY?R<.-=@"#[`AH<*\&"&H-Z!U4_/^#Q!")A7SR___I5?K__XUV`(/L"&H`
M4^CYTO[_@\00Z2;___^0B4(LZ9K\__^+%9"))0B)51SICOO__XGVBWT(B[<8
M`P``A?:)=10/A>7Z__^#[`QHOR\9".AO4/S_@\00A<")110/A<KZ___'113T
M^A@(Z;[Z__^0BUT(BXL<`P``B4T@Z>7Z__^-=@"#[`R+70C_,^A;*0``BU4(
MQP(`````65N)T,>"7`(``-@'``"+'8B))0C_-6!&&0CI]?W__XUV`(/L"%-J
M#>A-4_S_@\00Z43^__^0@^P(:'"O!@AJ#>@U4_S_B<.#Q!#I"O[__XUV`(U:
M`8/L#%/HG`'__XG#@\0,BT`!BTT(B8'0`@``C7L%:@B!P8(#``!748F-9/+_
M_^@W`?__BU4(C4L.BWH0B8U$\O__*?F-00&#Q!`Y\'<-#[=3#HM%"(F0X`(`
M`(U!$CGP=QV+E43R__\/OD("BTT(B8'P`@``#[="`XF![`(``(/#((G9*?F#
MP0TY\0^&H0$``(M]"(&GX`(``/]___^+50B`NF0#````=`R+112`.``/A4(!
M``"+30B+D30#``"%T@^$U@$``(M]"(N',`,``(7`BS784AD(=`6CV%(9"%=J
M$&H@BT4(_[`T`P``Z*#P_O^+50B#Q!"%P(F"D`(``(DUV%(9"`^$[@0``(/L
M"&H`BU4(*UH04XM%((G3@<.``@``A<!3N0$```!T#_RY_____S'`BWT@\J[W
MT8M5"%&!PGP"``!2OO____\QTOR+?0R(T(GQ\J[WT8M="%&!PW`"``!3B[V`
M\O__B-")\?*N]]%1BTT(@<&$`@``46H`Z$T\``"#Q#"%P'0A@^P(:@#_=1#H
MX;K^_XMU"(/$$(7`B89T`@``#X5C`@``BT4(@^P(QX!<`@``V`<``(L=B(DE
M"/\U8$89".GR^___QT40]/H8".E:^/__H8R))0B%P`^$R?C__^GI^O__QT4,
M"^$(".GE^/__]H+A`@``@`^%L?[__X/L",>"7`(```$(``"+'8B))0C_-01'
M&0B)T.F;^___H8R))0B)12#ITOK__U!J#(MU"%.!QHH#``!6Z"7__O^#Q!#I
M4?[__X/L"(M%",>`7`(``-0'``#_-8B))0@%4P(``%#H>/[^_^B#4/S__S"+
M70B+NUP"``#_-+T`)QD(:/\!``")V(/`4U#HC0O__X/$(.GY^?__@^P(:A!H
ME!`9".C.N?[_BW4(@\00A<")AC0#```/A0?^___I&/O__XM="(/L"(G9QX-<
M`@``T0<``('!4P(``/\UB(DE"%'H_?W^_^@(4/S__S"+?0B+MUP"``#_-+4`
M)QD(:/\!``")^.N#@^P(BWT(QX=<`@``TP<``/\UB(DE"(''4P(``%?HN_W^
M_^C&3_S_7O\P_W4,_S5,1AD(:/\!``"+10CI0?G__X/L#(V%A/+__U!H``@`
M`(V]B/;__U>-C8C^__]1_W4,Z$A/``"#Q""%P`^$Q08``(M(#(/Y!'8%N00`
M``"+0!!74?\PC94<____4NCM3/S_Z#1/``"#Q!#IN/?__X/L"(MU",>&7`(`
M`-('``#_-8B))0B!QE,"``!6Z![]_O_H*4_\_UK_,/]U((M5"(NZ7`(``/\T
MO0`G&0AH_P$``(G0Z9OX__^+10B#[`C'@%P"``#=!P``BQV(B24(_S5T1AD(
MZ;#Y__^#[`AJ`/]U%.A=N/[_BUT(@\00A<")@W@"```/A'S]__^#[`C_M8#R
M__^+10C_L(0"``#HGOS^_UA:_W4,BWT(_[=P`@``Z(O\_O^+32"#Q!"%R0^$
M1@(``(/L"/]U((M5"/^R?`(``.AI_/[_@\00BU4(BT(0@^P(0%#_LH`"``#H
M4/S^_XM5)(M="`N3#`,``(G0#06B``"+?1R+30B#Q!"I```!`(FYV`(``'0'
MB=`-!:("`(MU&(7V=`.#R`B+50B+BN`"``"!R=_U__\AP?;%`HE-)`^$CP$`
M`(F-*/___XMZ'(NRD`(``(L>B;TL_____#'`C;TQ____N04```"(G3#____S
MJV:KJHV=2/___XMU$(M%)(M]"(7VB8?<`@``=`R+51"`.@`/A7\!``"#[`Q3
MZ*]>_O^)'"3H4_S^_XM-%(/$$(`Y`(G#C4`!#X0)`0``BU4(]H+A`@``@`^$
M60$``,9#`11248US`O^U9/+__U;HEK#^_X/#%H/$$(M-&(7)=!"+?0CVA^`"
M```(#X4_`0``C;4H____*?-04U;_=0CH\BL``(/$$(3`=1:#[`S_=0CHV"P`
M`(/$$(3`#X1"`0``BTT(@^P(QX%<`@``W0<``(L=B(DE"/\U=$89".G$]___
M@^P(B=/'@EP"``#C!P``@<-3`@``_S6(B24(4^C+^O[_BTT(BX$P`P``@\00
MA<!T(X/L#%#_L30#``"+D5P"``#_-)4`)QD(:/\!``")R.D\]O__@^P,C;6(
M\O__5NCAW?[_BTT(B30D_[$T`P``B<KI9OW__\9#`0"#PP+I%O___XM5"(M"
M'(B%*O___\'H"(M-)(B%*____XV=+?___\'H"&:)C2C___^(A2S____I=/[_
M_XMU",>&?`(```````#IO_W__U%J$%)3Z)_Z_O_I>_[__U?_=13_M63R__]0
MZ%*I_O^#PPKII_[__U%J0/]U&%/H=OK^_XU8`5A::A#_=1CH=[7^_XM5"(/$
M$(F"C`(``,=%&`````#ICO[__X/L#/]U".BPVO__@\00@_C_#X2K]O__2`^$
MH@,``/9%)"!T!XM%",9`.`&+=1B%]G1@BUT(48N3K`,``#'`:@#\BWT8N?__
M___RKO?125'_=1AJ`&H`:@+_=0C_4@2#Q""$P`^%6?;__X/L#(M5"/^RC`(`
M`.@IM/[_6%IJ$/]U&.C9M/[_BW4(@\00B8:,`@``BTT(BX$D`P``A<`/A,T"
M``"+&(M`!(T\@XF==/+__XF]</+__XJ)@0,``#G[B(UO\O__#X.6`@``BW4(
MQH:!`P```.GB`0``BT4(B8"D`P``BTT(5XNYK`,``&H!5E-J`&H`:@-1_U<$
M@\0@#[[8A=L/A;GU__^#[`R+50B+LJP#``!2_Q:#Q!"$P`^%G_7__XM%"(NX
ME`(``(7_#X1O`0``BY"D`P``BXJ4`@``A<F)E6CR__\/A'3U__^#NGP#```!
M#X7]`@``@^P(:C"+O6CR__^+E^@"``"--)54````5NB*LO[_@\00A<")PP^$
M//7__XNU:/+__X/L"(N6K`,``(UX5(EX%(E04&H0BX;H`@``C0R%!````%'H
M4++^_X/$$(7`B4-$#X2)`@``BY5H\O__B=:->QR!QI@"``#\N0@```#SI8N"
ME`(``(N-:/+__XE#"(NQZ`(``(U#387)B7,\QT-``````(E+&,=#2`````")
MWL>!E`(```````#'@7P#```"````B8&T`P``B<MT)(/L#,>!M`,```````"+
MB:P#``!3_U$4@\00QX-\`P```````(M>#(7;=!F#[`AJ`(U[$%?HHLC^_XD<
M).@ZLO[_@\00BUX(A=MT$8/L"&H`C58<4NB"R/[_@\00BT9$A<!T#(/L#%#H
M#[+^_X/$$(/L#%;H`[+^_X/$$(.%=/+__P2+M7#R__\YM73R__\/@Z4```"+
ME73R__^+&C'`_+G_____B=_RKO?1C7'_BTT(@+E8`P````^$]?W__X"YEP,`
M```/A.C]__^#[`A64^CS5O[_@\00A<`/A#`!``!(#X7,_?__4%93_W4(Z%)5
M_O^#Q!#IW?W__XGVZ(](``"+70B#[`B)WL>#7`(``-4'``"!QE,"``#_-8B)
M)0A6Z'_V_O]8_[6$\O___W4,_S541AD(Z<#X__^*A6_R__^+30B(@8$#``"+
M30B`N5<#````=2^+?0CVA]T"```0=0B+10CI1/3__X/L"/^U?/+__VH-Z&M(
M_/^#Q!"+10CI*?3__X/L#%'HBV+^_X/$$(3`=,'I`O/__XM5"(M:$(`[_@^%
M3_S___:"X0(``(`/A$+\__]7_W44_[5D\O__5N@KI?[_@\0,:@E6_W4(Z)DF
M``"#Q!"$P`^%N?K__X/L#/]U".A[)P``@\00A,`/A:/Z__^#[`S_=0CHE=;_
M_X/$$$`/A>[[___IC?+__XGV4%93_W4(Z$53_O^#Q!#IM/S__X/L#%/H4+#^
M_^EG\O__@^P(B=#'@EP"``#>!P``@\!3_S5X1AD(4(L=B(DE".A/]?[_6%I3
MBX5H\O__Z2KR__^058GE5U93@>S,`P``BW4(@+Z!`P````^$.`$``(N&[`(`
M`*@!#X4P`0``BXZ$`@``A<D/A"(!``!0:@!J`&H`Z&!1_O^#Q!"%P(V=*/S_
M_P^$A0$``%)HA````(V^^`(``%>-C2#___]1Z')$_/^+AMP"```-````@(J6
MEP,``%#_MGP"``#_MM@"``#_MHP"``#_MG@"``#_MG0"``#_MG`"``!3B%6_
MZ//L__^#Q#"%P`^$[````(J&@`,``%%HA````&H`5XA%J.@Q2/S_QH:``P``
M`(DT).C^YO__@\0,:+@#``!35NCS0_S_@\00.9Z8`P``#X12`0``.9ZD`P``
M#X0[`0``.9Z@`P``#X0D`0``B?*+AIP#``#K"HGVB<*+@)P#```YV'7T@^P,
MB;*<`P``5NCY(```,<#'AK@"``#_____QX:\`@``_____^M)D(N&[`(``(/L
M"(/@_HF&[`(``,>&7`(``-8'``"-5E/_-5A&&0A2BQV(B24(Z+OS_O]86E.-
MAE,"``!0Z*SS_O^#Q!"X`0```(UE]%M>7\G#@^P(BXV$_O__C95[_/__B8Y<
M`@``C4934E#H??/^_UM?C;U[_O__5XV>4P(``%/H://^_^N]4&BX`P``:@!3
MZ!A'_/]97_\UA(DE"(V]>_[__XL-U%(9"%?'A2#___\`````B5W`B5W$B5W,
MB8VX_O__Z"7S_O^#Q!"!C33___^`````QD6_`<=%A!````#I'?[__XFVH`,`
M`.G1_O__B;:D`P``Z;K^__^)MI@#``#IH_[__XUV`%6)Y5=64X/L#(MU"(I%
M(/:&W0(``!"(1?._`0```,=%[``````/A<T!``"+%H72#X2?`0``BXY\`P``
MA<ET18/L"(L=B(DE",>&7`(``-X'``"-?E/_-7A&&0A7Z(/R_O]97U.-GE,"
M``!3Z'3R_O^#Q!"-9?1;7KH!````B=!?R<.)]H/L",9&4P"-EE,"``#'AEP"
M````````_S6$B24(4N@]\O[_QH9H`@```,>&B`(```````#'AK@"``#_____
MQX:\`@``_____XDT).@$'P``6%K_=1S_=1C_=13_=1`/MD4,4%;H^R,``(/$
M((3`#X2\````@;Y<`@``@00```^$=P$``(L.A<ET+S';]H;=`@``$`^%B@$`
M`(/L#/\VZ-49``"#Q!#VAMT"```0#X5=`0``QP8`````@^P,5NCF'0``BX:4
M`@``@\00A<"-GI@"```/A>L```!0:@!H`"```%/H6<#^_\>&E`(```````#'
MAN@"````````B30DZ!W\__^#Q!"$P'4N@^P(_W4<_W48_W44_W40#[9=#%-6
MZ$`C``"#Q""$P`^%J````)`Q_X!]\P!T;_:&W0(``!!U3XGX#[[0C67T6UZ)
MT%_)PX/L#%;HQ_O__X/$$(3`N@$````/A$C^__^-9?1;7HG07\G#D(/L"&AP
MKP8(:@WH'4/\_X/$$(E%[.D9_O__B?:#[`C_=>QJ#>@#0_S_B?B#Q!`/OM#K
MGX/L#%;HH-'__XF&U`(``(/$$$`/E,&)S^ET____@^P(:@!3Z,G!_O^#Q!#I
M`O___X/L",>&7`(``-8'``#_-5A&&0B-5E-2Z&WP_O^#Q!#I/?___X/L",>&
M7`(``.0'``#_-9!&&0CKVH/L"%-J#>B%0OS_@\00Z9#^__^#[`AH<*\&"&H-
MZ&Y"_/^)PX/$$.E=_O__58GE5U93@^P,BT4(BYBD`P``BXN4`@``,<"%R0^$
MV@```(.[?`,```$/A=4```"#[`C'@WP#````````:C"+L^@"``"-%+54````
M4N@+JO[_@\00A<")1?`/A/````"+5?")UHN[K`,``(/&5(EZ4,9"3`&)<A10
MBX.L`P``_[/H`@``_[.4`@``4_]0"(MU\(/$$(7`B48,#X2C````BQ"+>`2+
M=?")%HE^!(M`#(F3N`(``(F[O`(``(N3E`(``(GWB480B58(@\<<C;.8`@``
M_+D(````\Z6+@^@"``"+3?")03S'@Y0"````````QX.T`P```````(G(C67T
M6UY?R<.#[`B+-8B))0C'@UP"``#>!P``_S5X1AD(C4M34>C^[O[_6%I6C;M3
M`@``5^CO[O[_@\00,<"-9?1;7E_)PX/L#%;HL:G^_S'`Z^N#[`B+-8B))0C'
M@UP"``#8!P``_S5@1AD(Z[.)]E6)Y5=64X/L+(M]"(M/#(7)#X6!````@'],
M`'5QBW<8@[Y\`P```@^$G````(I738#Z`1G`@^#<!0((``"#[`B+'8B))0B)
MAEP"``#_-(4`)QD(C4934.A<[O[_6%I3C993`@``4NA-[O[_@\00QD=,`8U7
M33F6M`,``,>&?`,```````!T-L='&`````"-9?1;7C'`7\G#BT<0A<!T%8MP
M!(L(B4\0B7=(B?"-9?1;7E_)P\='2`````#K[\>&M`,```````#KOH/L#(M'
M/(M/1(M?%(E%[(E-Z(E=U%;HQ,[__X/$$(/X_W2"@_@(#X?2````BU80@#K^
M#X3.````QT7@`````(M=[(E5\`'".5W@B57<QT7D`````.MCD(/L#(U-\%'H
MK,K__X/$$(/X_XG!='.+1?")1=B+5=PK5=@YR@^"IP```(M%V(M=Z(M5Y(D$
MDXM=U`'(B0N#PP2)1?")7=2+3>"%R70&BT7@Q@``BU7P_T7DBUWLB57@.5WD
M<IR+1>!`BUWDBTWHBW7@B029Q@8`@P<!BT=$@U<$`(E'2.D#____BU74BUWD
MBT7HQP(`````@\($QP28`````(E5U.N?BU80Z3+___^#^`$/AI;^__\/MTH!
M#[=:`XF.]`(``(F>[`(``.E]_O__@^P(BQV(B24(QX9<`@``T`<``/\U0$89
M".E$_O__D%6)Y593@^P0BT4,@_@2BUT(BW40=PK_)(5T,!D(C78`C67X6[@!
M````7LG#A?9T"HL&A<`/A(H!``"!BPP#``"`````,<")]HUE^%M>R<.+#C'`
MB8L(`P``Z^V#[`S_LS0#``#H%Z?^_UA::A!6Z,FG_O^)@S0#``"#Q!`QP.O(
M@^P,_[,P`P``Z/*F_O]96&H05NBDI_[_@\00B8,P`P``Z]F#[`S_LRP#``#H
MSZ;^_UA::A!6Z(&G_O^#Q!")@RP#``#KMH/L#/^S*`,``.BLIO[_65AJ$%;H
M7J?^_X/$$(F#*`,``.N3@</X`@``BU,LA=(/A-L```"#[`AJ$%;H-Z?^_X/$
M$(7`B47T=!J#[`B-=?16_W,LZ!([``"#Q!"$P`^$&____X/L#/]U].A,IO[_
M@\00Z4#___\QP,>#"`,```,```#I^_[__X.+#`,``"`QP,:#50,```'IYO[_
M_XL&B8/X`@``,<#IU_[__XH&B(-D`P``,<#IR/[__X/L"&H05NBQIO[_@\00
MB8-@`P``Z>/^__^)@UP#```QP.FB_O__BPXQP(F+``,``.F3_O__BQ8QP(F3
M_`(``.F$_O__@:,,`P``?____S'`Z7/^__^#[`AJ$&H4Z/^D_O^#Q!")0RQJ
M!6H`:@10Z&TY``"#Q!#I__[__Y!5B>6+10B+4`2+`,G#C78`58GEBT4(BT`\
MR<.058GEBT4(BX!<`@``R<.)]E6)Y8M%"(/`4\G#D%6)Y5=64X'LK````(M]
M"(M%#`'XBU48.<?'19@`````B46$QD6#`,9%@@#'`@`````/A%D"```/M@>+
M%4!;&0CV1`(!"'05D$<[?80/A#X"```/M@?V1`(!"'7L.WV$#X0K`@``#[8/
MBS5`6QD(]D0.`00/A!<"``#&18\`B?J00CM5A'0*#[8:]D0>`01U\,=%E```
M``"*'6"+)0B)T2GY#[;#.U6$B)UG____QT2%J``````/A'<%``"`O6?___\"
M=B4[581S%XUV``^V"O9$#@$(#X7/`0``0CM5A'+L.U6$#X0$!@``BAUABR4(
M.)UG____#[;+=@</MHUG____BA5BBR4(#[;".<B(E7/___]V`HG!N`$```")
MP]/CB@UFBR4(T^`)PX/C#XF=8/___XM=E(/[!HB-<O___\=%D``````/AX$!
M```[?80/A'@!``"*%P^VPO9$!@$$#X1H`0``B;U\____1XU*T#M]A`^VT70Z
MB@\/ML'V1`8!!'0N@'V/`'04Z1,$``"-=@"*#P^VP?9$!@$$=!2-0=!'C122
M#[;(.WV$C111=>*)]HGY*XU\____@?H_0@\`B4R=J`^'9`4```E5D(E4G<B*
M@V&+)0@\`1G2@^("0CM]A(E5I(E]B`^$.@4```^VC7/___\YV0^$F0,```^V
M%66+)0@YV@^$-P,``#M]A'1IBA</ML(/MD0&`:@0#X3+`P``QX54____`0``
M`(C9TZ54____BXU@____(8U4____D`^VPO9$!@$(=!*+E53___^%T@^$;`0`
M`,9%@@%'.WV$QD6#`702BA</MLH/MD0.`:@0=<RH"'7(#[:%<O___SG8#X38
M`P``B7V(Z;T"``"0BT48QP`!````N/[___^!Q*P```!;7E_)PSM5A`^#+O[_
M_P^V`O9$!@$$#X4@_O__0CM5A'+LZ17^__^0B=\K?92+38B)?9SK%(UV`,=$
MG:@`````QT2=R`````!#@_L'=NJ`?8\`#X78`0``#[:%9____XM<A:B%VXE=
MH'2"BWR%R(M5$(DZ#[8U88LE"(M<M<B)6@2)G7C___\/M@5BBR4(BW2%R(ER
M"(FU=/___P^V'6.+)0B+=)W(B7(,#[8%9(LE"(M<A<B)6A")G6S___\/M@5E
MBR4(BUR%R(F=:/___XE:%`^V%6:+)0B+7)6H@_L%#X>@`@``N`8````IV(L$
MQ<"*)0@/KT25R(E$E<B+51")0AB`/6>+)0C_=""#_@P/AR<#``"[#````(GP
M,=+W\XM%F(TT`HM=$(ES#(M%$,9`'`"#?:`"#X09`@``@WV<`@^&F@```('_
M#R<```^'C@```(.]>/___PP/AX$```"#O73___\?=WB#_A=W<X.];/___SMW
M:H.]:/___SMW8?9%%`%U%(N]>/___X7_=%&+M73___^%]G1',<"+=82#?9P#
M#Y?`.76(=""+71")0R"+%4!;&0@/M@'V1`(!"`^$T@(``$$[381U[#'`@WV<
M`P^7P(M]$(E'(.D<_O__B?:+19"%P'4CBUV$.5V(="2+%4!;&0B-=@`/MCGV
M1#H!"'0(03M-A'7PZPF+31C'`0$```"+?1`QP/RY"0```/.K@<2L````6UZX
M_____U_)PXM]R(M=$(D[BT7,B4,$BW70B7,(B;5T____BW74B7,,BUW8B85X
M____BT40B5@0BU7<B5`4B95H____BU7`@_H%B9UL____#X<``0``NP8````I
MTXL$W<"*)0@/KT7@B47@BU40B4(8Z8[^__^`/RX/A(@!``")]D.#^P9W%3M]
MA'00BA</MLKV1`X!!`^%_?O__X!]@P`/A%O]__^`?8(`#X51_?__]D44`@^$
M1_W__XMU&,<&`0```.D&_?__D(`_5`^%7OS__T?KK/]-I(-]I/\/A`/\__^`
M?8\`=2+IY/O__XH/#[;!]D0&`00/A.C[____3:2#?:3_#X3;^___C4'01XT4
MD@^VR#M]A(T44771Z<3[__^H"`^%+?S__^E__/__BUV0A=L/A-S]__^#_T6-
MA]`'``!V!HV';`<``(M5$(G'B0+IO_W__XM%X.D-____BT25R.EN_?__@_D$
M=!&#^0AT#(/Y#<=%H`(```!V!\=%H`0```"+5:!*B56DQD6/`>F*^O__0X`]
M9XLE"/\/A!K\__^-5P([580/AP[\__^*1P$\370(/&T/A?_[__^*!SQP=`@\
M4`^%MO[__XG7.WV$QT68#`````^$W_O__P^V%_9$%@$(#X31^___1SM]A'7L
MB7V(Z8C^__^+51C'`@$```#IQ_O__T?'1:0%````Z6W^__^+31C'`0$```#I
MROW___9%%`(/A8[^___'1=@`````QT74`````,=%T`````#'1<P`````QT7(
M`````,=%E`4```#IP_G__T/I._[__XM-&,<!`0```.E?^___BU48QP(!````
MZ2;]__]5B>575E.#[%R+50R+10@!T(M-$(E%P,9!'`"+710Y10C'`P`````/
MA%<"``"+?0@/M@>+#4!;&0CV1`$!"'0=_T4(BW7`2CEU"`^$-`(``(M="`^V
M`_9$`0$(=>.+1<`Y10@/A!L"``"+10B`."T/A!P"``"+?<`Y?0@/A`,"``"#
M^@L/AQ@"``"+7<`Y70C'1<0`````=$&+10B*"`^VP8L=0%L9"/9$`P$$="R)
M]HM%Q`^^\8T4@/]%"(M-P(U\5M`Y30B)?<1T#XM]"(H/#[;!]D0#`01UUHM-
M"(M=P#G9="@/M@&+%4!;&0CV1`(!"'08_T4(BW7`.74(=`V+?0@/M@?V1`(!
M"'7HBU7`*U4(@_H!QD6^`,9%OP`/AJH!```Y30@/A*$!``"+10@/M@B+'4!;
M&0CV1`L!!`^$B@$``(MUQ(EUR,9%OP&^`0```(M%P#'2.44(=#2+?0B*#P^V
MP?9$`P$$="60#[[Y_T4(BTW`C122.4T(C517T'0/BT4(B@@/ML'V1`,!!'7<
MB52UR$:#_@1T4XM-P"M-"$E^':!HBR4(BU4(.`)U$0^V>@'V1#L!!'0&0HE5
M".N2@_X$="B`?;X`=0J`?;\`#X3]`@``N00````I\<'A`HU<M<C\P>D",<")
MW_.KBTW0BW7`*W4(3GX,BT4(@#@N#X0'`@``QT78`````(`]9XLE"/]T5(M5
MP#E5"'0KBWT(#[8'BQ5`6QD(]D0"`0AT&/]%"(M%P#E%"'0-BW4(#[8&]D0"
M`0AUZ(M5"(/"`CM5P'<6BUT(BD,!/$T/A$X!```\;0^$1@$``(/Y.W\,BU74
M@_H[#X[3````BTT4QP$!````D+@!````C67T6UY?R<.+31!`2L9!'`&)10CI
MT_W___]U%&H#_W404O]U".@%]O__@\04@_C_#XSU`0``#Y3"C67T6UX/ML)?
MR<.+7<`K70A+?A&*#6B+)0B+50@X"@^$\0```+BMB]MH]VW$OQ^%ZU&)T8M=
MQ(M%Q/?OP?L?P?D,*=F)5:2)3<R+3:3!^04IV8E%H(G(]^^)TXG(F<'[!2G3
MC12;C3R2BT7$P><"NV0```"9*?GW^\=%R`````")3=")5=3IH_[__XMU$(E6
M%(M5P(M]R(M=S(M%V#E5",<&`````,=&!`````")?@B)7@R)3A")1AC'1B`"
M````="2+%4!;&0B)]HM-"`^V,?9$,@$(#X0E`0``08M%P#G!B4T(=>0QP.G:
M_O__BWT(B@<\<`^$WP```#Q0#X37````/&%T"#Q!#X69_O__B54(Z9'^__\/
MMGH!BQU`6QD(]D0[`00/A/K^__^+1<1"O@(```#'1<@`````B47,QD6^`8E5
M".E&_?__BE`!#[;ZBS5`6QD(]D0^`00/A.+]__^#10@"BT7`C5K0.44(QT6T
M!0````^VTW1,BT4(BA@/MOOV1#X!!'0]QT6T!````(U#T/]%"(M=P(T4D@^V
M^#E="(T45W08BT4(BA@/MOOV1#X!!'0)_TVT@WVT_W71BW6TA?9T"XM=M`^O
M%-W`BB4(B578Z7']__^+1<R)50B[#````)GW^X/"#(E5S.FU_?__BW44QP8`
M````Z<C[__^+?10QP,<'`0```.FW_?__C3RU`````(U=R%"-1_Q0C0P[48U5
MV%+H?N;^_[D$````*?'!X0+\P>D",<")W_.K@\00Z>/\__^)]E6)Y593BUT(
MA=N+30R+=1!U7H7)#X2V````@<-L!P``@?NQ!P``=P.#PV2)RHT$V\'B!8T$
MPRG*C02``<*#^0*-=#+A=TY+N!^%ZU'WXXG1P>D%C01)C5`#P?H"A=N)V'AG
MP?@"`?!;*=!>R<.-=@"!^\<```!VHHG*C03;P>(%C03#*<J-!(`!PH/Y`HUT
M,N%VLY"-#(T7````N&=F9F;WZ8G0P?D?P?@"*<@IQK@?A>M1]^.)T<'I!8T$
M28U0`\'Z`H7;B=AYF8/``^N4B?8QP(7V#X5`____6U[)PXGV58GE5U93@^Q,
MBWT(BQ^%VXM/!(MW"`^%?`$``(7)#X3D`0``@<-L!P``@?NQ!P``=P.#PV2)
MRHT$V\'B!8T$PRG*C02``<*#^0*-=#+A#X=P`0``2[@?A>M1]^.)T<'I!8T$
M28U0`\'Z`H7;B=@/B(D!``#!^`(!\"G0+:CZ"@"-'("-%)B-'-"+3PS!XP(I
MPXT$S0`````IR,'@!0'(BW<0P>`$P>,'`<.-!':+3Q2--("-!+$!PXLU#+0F
M"(V4,_#Q__^#[`B)=:R-=;B)5;2-7;164^BU,?S_BU<,@\00.U7`QT6P````
M``^$O@$``(M/$(M?%(M'""M&#(/X_P^-E@$``+@!````*U8(C01`C03"C13%
M`````"G"*TX$P>(%`<*-!$G!X@2-!(`K'HT,@@'9BUVL@^P(C909$`X```%-
MM(E5K(U%M%90Z#XQ_/__1;"#Q!"#?;`!=QJ+5PP[5<!UBXM/$#M-O'6&BU\4
M.UVX=8&)]H-]L`(/A)8```"+=0R+?:R+3;2)/HUE]%M>B<A?R<.0@?O'````
M#X:`_O__B<J-!-O!X@6-!,,IRHT$@`'"@_D"C70RX0^&D?[__Y"-#(T7````
MN&=F9F;WZ8G0P?D?P?@"*<@IQK@?A>M1]^.)T<'I!8T$28U0`\'Z`H7;B=@/
MB7?^__^#P`/I;_[__XUV`#'`A?8/A&G^___I#?[__Y"+5PR+3@@YR@^$7/__
M_XM'""M&#(/X_P^,EP```(/X`7X&N/____^0*<J-!$"-#,*-%,T`````*<K!
MX@4!RHM/$(G+*UX$C01;P>($C1R`C02:BU\4B=\K/@'X/1`.``!T7#WP\?__
M='"+3;2+71#&`P&+=0R+?:R)/HUE]%M>B<A?R<.#^`$/CF;^__^X_____^E<
M_O__BT\0.TV\#X4Y_O__BU\4.UVX#X4P_O__Z;;^__^X`0```.EJ____C3Q)
MC32_P>8"]]XIW@-UM(V.$`X``(E-M.N3C01)C0R`C12+BTVT*=&)3;3K@%6)
MY8'LA````&H`Z"PN_/^)19186HU%R(U-E%!1Z&HO_/^+5=R!PFP'``")59B+
M1=B+5="#Q`R)5:1`C5634HE%G(M%S(M-U(E%J&@,M"8(C468B4V@4(M-R(E-
MK,<%#+0F"!`.``#HD/S__\G#B?95B>4QP%?\BWT(N0D```#SJXM%#(M5"(E"
M(%_)PXUV`%6)Y8/L$(M%"/]P%/]P$/]P#(!X'`"ZPR@9"'4%NO3Z&`A2:,`P
M&0C_=0SH/"[\_\G#B?95B>6#[!2+10C_<`C_<`3_,&C1,!D(_W4,Z!HN_/_)
MPU6)Y8/L"(M%"/]P%/]P$/]P#/]P"/]P!/\P:.`P&0C_=0SH\2W\_\G#C78`
M58GE4U&+30B+42"#P@(QP(/Z!(M=#'<S_R25`#$9")"#[`C_<13_<1#_<0R`
M>1P`N,,H&0AU!;CT^A@(4&C`,!D(4^BD+?S_@\0@BUW\R</&`P`QP(M=_,G#
MB?:#[`S_<0C_<03_,6C1,!D(Z]2)]O]Q%/]Q$/]Q#/]Q"/]Q!/\Q:.`P&0CK
MNE6)Y5934&I4BUT(:@!3BW48Z$XL_/^+10R)0S"+31"+512)\(D+B5,$B$,(
MC67X6U[)PY!5B>575E.#[!1J$&I4BW4(BWT0Z)"2_O^#Q!"%P(G#=%M0:E1J
M`%/H!"S\_X/$#(M5#(GXB5,PB$,(B3/'0P0`````5H-[,`*X2@`9"'0%N!0Q
M&0B-2S104>C2+/S_@\0,_W,,:@16Z(0N_/]:66H#5NAZ+OS_B4,,@\00C67T
MB=A;7E_)PXGV58GE4U"+70B%VW04BT,PA<!U%8E="(M=_,GIH9+^_Y"+7?S)
MPXUV`(/L#%/HJP$``(E="(/$$(M=_,GI@)+^_U6)Y8/L".BM*?S_BP#)PY!5
MB>575E.#[`R+?0B+=0R+71#HD2G\_\<``````(L'B5T0B74,B44(@\0,6UY?
MR>FT*?S_58GEBU4(BP*)10C)Z=,H_/^-=@!5B>564XM-"(M!#,'H`H/P`8/@
M`8M5$(I=#(@"BP$Q]H7`>".$VXM1#'4EB="#R`0YT(E!#'004E!J!/\QZ(XM
M_/^)QH/$$(UE^%N)\%[)PXG0@^#[Z]F058GEBT4(BT`,P>@"@_`!@^`!R<-5
MB>53@^P@:@2-1?A0:@-J`(M="/\SQT7X"````.B2*/S_@\0@A<!T"[C_____
MBUW\R<.0@^P,:@2-5?12:@%J!O\SQT7T`0```.AE*/S_@\0@A<!TV+C_____
MZ]&-=@!5B>6#[`B+30@QP(-Y,`.*50QT*#'`A-(/E<"#[`R)1?QJ!(U%_%!J
M"&C__P``_S'H'RC\_X/$(,G#B?;'1?P`````R<.-=@!5B>6#[`CH02C\_XL`
M,=*#^"-T$(/X!'0+@_@C=`:)T,G#B?:Z`0```(G0R<.-=@!5B>564XM="(M#
M,#'VA<!U%\=#,`````#'`_____^-9?A;B?!>R<.0@^P(:@+_,^@H*OS_@\00
MA<!U+8/L#/\SZ'<L_/^#Q!"%P'3%QT,P`````,<#_____XUE^+[_____6XGP
M7LG#D+[_____Z\R058GEBT4(@\`TR<.058GEBT4(BT`PR<.058GEBT4(BP#)
MPXGV58GE5U93@^P,BUT(@'L(`(MU#(M]$'0D@^P(:"`Q&0A6Z%+5_O]FQP<`
M`(/$$#'2C67T6UZ)T%_)PXGVC57P4%*-0R!0_S/'1?`0````Z!4J_/^#Q!"%
MP+H!````==&#[`A6_W,DZ+DF``"#Q!!FBTLBANEFB0_KM8UV`%6)Y8M%"(!X
M"`"+50QT"<<"`````,G#D(M`)(D"R<.058GE@^P,BTT,BT4(BQ"-!(F-#(")
M5?B-%(G!X@-FQT7\`0!FQT7^``!2:@&-1?A0Z,<H_/^#Q!"%P'X,,<#V1?X!
M#Y3`R<.0]]#!Z!_)PY!5B>7)PXUV`%6)Y593@^P,BUT(4XMU#.A43?[_6%IJ
M$(M#&(/`!U#HF([^_XG"@\00A=*)0P2X`0````^$B0```(G1`TL8A?:)2PB)
M,\9#4@#&@V`"````QH-I`@```,=#3`````#'0R0`````QT,@`````(E3$(E3
M#,9#4P#&0S@`QD-0`,=#/`````#'0T@`````QX-<`@```````,>#9`(`````
M``#&@V@"````=!>#[`Q6Z$[^__^)0Q2)-"3HX_S__X/$$#'`C67X6U[)PXUV
M`%6)Y5.#[!"+70C_<P3H?H[^_\=#!`````"+7?S)PXGV58GE5E.+70B+10PY
M0QQW),:#8`(```'&@V@"```!QX-<`@``@00``+@!````C67X6U[)PXVP_P\`
M`('F`/#__U%J$(U&!U#_<P3HN0L``(/$$(7`=!B-%`:)0PR)0P2)<QB)4PB-
M9?A;,<!>R<.P`<:#8`(```'&@V@"```!QX-<`@``$00``.NCB?95B>564X/L
M%(UU]XM="%9J`/\SZ*3[__^#Q!"%P'0=BT,$QT,D`````,=#(`````")0PR-
M9?A;7LG#B?90_W,8_W,$_S/H*OO__X/$$(7`?^M05FH!_S/H8/O__XM#!,=#
M)`````#'0R``````B4,,@\00C67X6U[)PXGV58GE5U93@^PHBT4(QT7H````
M`/\PZ'[[__^(1>>+50B#Q!"`NF`"```"N/____]T>(!Z.`#&0E`"=7:#[`B+
M=0C&1>T`_W8H_S;HM?W__XMU#(GW`WT0@\00.?YT)HGVB?LI\U!35HM-"/\Q
MZ+OZ__^#Q!"%P(G##X[*`````<8Y_G7<BTT(@'DX``^%.P$``(!][0`/A4D!
M```QP(M-"#G^QD%0``^5P(UE]%M>7\G#@^P(:A"+51"#P@=2Z`:,_O^#Q!"%
MP(G&#X0Q`0``C5@'4/]U$/]U#%/H42'\_X/$#(U%\%"-?1!74^@P'P``@\00
MA,!T!\=%\`````"+5?"(5@2+1?#!Z`B(1@4/MUWRB%X&BTT0B`Z+51#!Z@B(
M5@$/MT42B$8"BWT(BU<DBTT(C5H!B5DDB%8#@T40!XEU#.GT_O__D(/L#(M%
M"/\PZ/_Z__^#Q!"$P'4$A=MU,H!][0!U,L9%[0&-3>]046H!BU4(_S+HQ?G_
M_X/$$(7`#XB.````QT7H`````.G(_O__@'WM`'06A,!T$HM%Z(M="/]%Z#M#
M,`^"K/[__XM5",:"8`(```+&@F@"```!BTT(@'DX``^$Q?[__X/L#/]U#.B1
MB_[_@\00@'WM``^$M_[__XU5[E!2#[Y%YU"+70C_,^A(^?__@\00Z9O^__^+
M30C&05``C67T6UZX`0```%_)PX/L#(M5"/\RZ#/Z__^#Q!"$P'02BUWHBTT(
M_T7H.UDP#X(P____BT4(QH!@`@```L:`:`(```'I-/[__U6)Y5=64X/L#(E5
M\(I(.(3)B<.+=0AT#8%X&/___P`/AZ<```"+>PB+4PPIUSG^=GX[4P1T.E!7
M_W7P4NB?'_S_BU,$BTL,*=&#Q`P!^5%24^A:_?__@\00A<"Z`0```'5=BT,$
M`7WPB4,,*?Z*2SB$R70S@?[___\`=BM0:/___P#_=?!3Z"7]__^#Q!"%P'5M
M@47P____`('N____`('^____`'?5.7,8<C2+4PQ15O]U\%+H)A_\_P%S##'2
MC67T6UZ)T%_)PXUV`(M0#(G0*T,$O____P`IQ^E-____5U;_=?!3Z,7\__^#
MQ!`QTH7`#Y7"C67T6UZ)T%_)P[H!````Z[F)]E6)Y5=64X/L#(M="(L#,=*%
MP(M]#(MU$`^$H````('^_O__`'9<B?;&1?#_QD7Q_\9%\O^+2R"#[`R-40&)
M4R")V(A-\XU5\&H$Z*G^__^#Q!"$P'5R@^P,:/___P")^HG8Z)'^__^#Q!"$
MP'5:@<?___\`@>[___\`@?[^__\`=Z:)\8GRP>D(P>H0B?"(1?"(5?*(3?&+
M2R"#[`R-00&)0R"-5?"(3?.)V&H$Z$;^__^#Q!"$P+H!````=!F-9?1;7HG0
M7\G#C67T6UZZ`0```(G07\G#@^P,5HGZB=CH%/[__X/$$#'2A,`/E<*-9?1;
M7HG07\G#58GE4U.+70B+4P2+0PPQR3G"=!DIT%%04E/HD?O__X/$$(7`BT,$
M#Y7!B4,,@'LX`'0&BU,DB5,@#[[!BUW\R<.-=@!5B>575E.#["R+?12+51R-
M7#H!BT4,@?O^__\`BW4(N04```"(1=P/AID```#'1=3^__\`*7W4D,9%V/_&
M1=G_QD7:_XM&((/L#(U0`8E6((A%VXU5V%&)\.A>_?__@\00A,`/A08!``"#
M[`Q7BU40B?#H1?W__X/$$(3`#X7M````@^P,_W74BU48B?#H*OW__X/$$(3`
M#X72````BTW4@>O___\``4T8,?^!^_[__P#'1=3___\`N00````/AW7___^)
M71R(7=C!ZPB(7=G!ZPB(7=J+7B"#[`R-0P&)1B"-5=B(7=N)\%'HS?S__S';
M@\00A,!U<(7_=5:#[`S_=1R+51B)\.BP_/__@\00A,!U58M6!(M&##').<)T
M&2G05U!25NA"^O__@\00BWX$A<`/E<&)?@R`?C@`=`:+5B2)5B"$R74@C67T
MB=A;7E_)PX/L#%>+51")\.A<_/__@\00A,!TE9"[`0```.O9C67T6UZX`0``
M`%_)PU6)Y5=64X/L*(G&_S")5>S'1>0`````QT7@_____^AE]?__@\00@'XX
M`(A%WL=%V`<```!U!\=%V`0```"#[`B+1>S'``````#_=BS_-L9&4`'&1=\`
MZ)GW__^+?D@#?@3'1>@`````@\00BU78A=)T)XGV4/]UV%?_-NAH]/__@\00
MA<")PP^.WP```"E%V`''BU78A=)UVXM5Z(72#X60````BTX$BU9(BT8@.$01
M`P^%NP$``$"`?C@`B48@B48D=!*+7!$$@>/___\`BWWLB1^+5DB+!!$E____
M`(E%X'1>BWWLBP<[1>!S`XM%X`'0.488=S0Y1AP/A^,```#&AF`"```!QH9H
M`@```<>&7`(``($$``"X`0```(7`#X59`0``BTX$BU9(BUW@C3P1B5W8_T7H
M@WWH`0^&*O___X!]WP!T%(U]\E!7#[Y%WE#_-NC8\___@\00QD90`(M%X(UE
M]%M>7\G#B?:#[`S_-NC.]/__@\00A,!U!(7;=2^`?=\`=2_&1=\!C5WS4%-J
M`?\VZ)?S__^#Q!"%P`^(E````,=%Y`````#IN_[__X!]WP!T$X3`=`^+1>3_
M1>0[1C`/@J+^___'1>#_____QH9@`@```L:&:`(```'I7O___XV8_P\``('C
M`/#__U!J$(U3!U)1Z/0"``"#Q!"%P'06C0P#B48,B48$,<")7AB)3@CI!/__
M_[`!QH9@`@```<:&:`(```''AEP"```1!```Z>7^__^#[`S_-N@"]/__@\00
MA,!T#XM-Y/]%Y#M.,`^",____\=%X/_____&AF`"```"QH9H`@```>G5_O__
MQT7@_____^E9____QT7@_____^FW_O__B?95B>575E.#[!R+10B`>#@`#X1%
M`0``BUT(BT,\A<#'1>0`````#X69````QT7H`````#'V,=N)]HG:*?*#^@,/
MAJ,```"+10B+2`2+/#&!Y____P`/A/\!``"-1P0YT`^'@P```(M%Y(7`#X5>
M`0``C70W!('_____``^$$@$``(M5",=%Y`````"+2@2+?0@#3>B)7T0I\RMU
MZ"MUY(U!!(E'$(E?/(U&_(I<`02+=0B(7E'&1`$$`(UE]%M>7\G#C78`B=F+
M6T2)WBG&B77HBU$$BD%1B`0RB=HI\H/Z`P^'7____XGVBU7HA=)U18M%"(E8
M2(U5\.AW_/__B47L0`^$^0```%*-5?!2C4WL48M%"(MX2`-X!%?H%1<``(/$
M$(3`#X7%`````UWLZ0;___^)]E$K7>A3BU4(BWH$BTWHC00/4%?H*!?\_RMU
MZ(/$$,=%Z`````#KE(U5\.@1_/__/?___P`/A)\```"+=0B+5DB+30@#402#
M^/^)41`/A#/____&!`(`C67T6UY?R<.+?>B%_\=%Y`0````/A)3^__]0*UWH
M4XM]"(M7!(M-Z(T$"E!2Z+@6_/\K=>B#Q!#'1>@`````Z6K^__]04HM5Z(T$
M$0'PC4@$45#HDA;\_P'^@^L$@\00Z87^__^+70C&@V`"```"QH-H`@```8UE
M]%M>N/____]?R<.+50B+<DB)\#';ZPF-=@"+30B+04@%____`(M]"(E'2(U5
M\(M%".@\^___@</___\`/?___P!TUX/X_W0"`=B+70B)\HES2.D;____@\8$
MZ2S^__^-=@!5B>575E.#[`R+70B%VXM]#(MU$'0B@^P(5U/H4!K\_X/$$(7`
MB47P="J+1?"-9?1;7E_)PXUV`/?&0````'36B74,B7T(C67T6UY?R>EV@?[_
MB?;WQH````!U*_?&``$``(G8=<?H-1G\_XL`@^88HP!*&0ATLU!7:B1J!>@V
MB/[_@\00ZZ.#[`Q3Z-B!_O^#Q!#KQXUV`%6)Y5-1@#T@3AD(`(M="(M%#'08
M2%)0:"!.&0A3Z%K'_O^#Q!`QP(M=_,G#@^P(@^@"4%/H/QO\_X/$$(7`=0;V
M11`0=2>#[`Q3Z&G'_O^#Q!"`>/\O=`?&`"_&0`$`4&C_`P``4V@@3AD(Z[#H
MEAC\_XL`@^P0HP!*&0CHAQC\_X/$#/\P:B1J$.B1A_[_N/____^+7?S)PXUV
M`%6)Y5-3BTT(BA&`^GYT)8#Z+[@!````=!:#[`AJ.E'H>!S\_X/$$(7`#Y7`
M#[;`BUW\R<.`>0$O==^A)%(9"#';A<!U!XG8BUW\R<.#[`Q0Z*O___^#Q!"%
MP'3ILP&)V.OEB?95B>564XM5"(H"A,")TW0,/"]U#8!Z`0!U!XGVND40&0B#
M[`Q2Z(X7_/^#Q!"%P(G&=76*`SQ^=$\\+W02@^P(:CI3Z/`;_/^#Q!"%P'1)
M4&C_`P``4V@@3AD(Z!S&_O^#Q!"`>/\O=!,M($X9",:`($X9""_&@"%.&0@`
MC67X6XGP7LG#C78`@'L!+W6OH212&0B%P'4YD,8%($X9"`"-9?A;B?!>R</H
M6Q?\_XL`]D4,$*,`2AD(=,+H21?\__\P4VHD:A'H58;^_X/$$.NL@^P,4.C#
M_O__Z6K___^)]E6)Y5=64X/L'(M5#(L*,<"%R0^$J````(M""(L8A=O'1?``
M````QT7L`````(E%W`^$SP```(M]"(H7#[;RB%7CB77DBSU(6QD(B?:`?>,`
MBW4(#X3'````B@N(3=L/ML&*#`>+5>0X#!=T;XM%"(H(@'W;`'5Y@/D@=0A&
MB@Z`^2!T^(3)#X2C````_T7LBT7LBTW<BQR!A=MUL(M]\(7_=&*+=0B`/@!T
M:(-]\`%U"O9%$`$/A*\```"X_____XUE]%M>7\G#BA.(5=L/MM(/ML&*%!<X
M%`=UED:*#D.$R77EBA.(5=N`?=L`=(F)]H3)=9CV11`!=9*+=>S_1?")=>CK
MA_9%$`1T"(M5"(`Z(W0HC67T6UXQP%_)PXUV`(H+B$W;BUT(B@OI0O___XM%
M[$"-9?1;7E_)PX/L#%+HE,3^_X/$$(!X_R-UQHM="(/L#$-3Z(X9_/^#Q!!(
MB47H>+"+50P[`G.I]D40`G0&BT7H0.N]BWT,@^P(BT\(BT7H_S2!_W4(Z(O#
M_O^#Q!"+1>CKWHUV`%6)Y8M5"(M-##D*=@^+0@B%P'0(BP2(R<.-=@"X:Q`9
M",G#D%6)Y8M%#(7`BTT(BU40=!A(.0)W&[AK$!D(B44,B4T(R>DVP_[_B?;&
M`0#)PXUV`(M2"(72=-Z+!(*)10R)30C)Z1;#_O^)]E6)Y5=64X/L#(M5##')
MA=*-?0QT&(U5%(M:_(/#!X/""(/C^(M"^`'9A<!UZX/L"/]U"%'H$WW^_XG&
M@\00,<"%]G0FB?.-3P2+!^L7C78`BQ&#P@>->02#XOB)&(/!"`'3BP>%P'7H
MB?"-9?1;7E_)PXGV58GE5U93@^P,BUT0BWT4@WT(`<<#`````(MU#,<'````
M`'\(C67T6UY?R<.#[`AH3#$9"/]V!.@XP_[_@\00A<!T#8M&!(D#C67T6UY?
MR<.#[`AH73$9"/]V!.@4P_[_@\00A<!TO8M6!(D7Z[:)]E6)Y5=6@^PHBW4(
M_(U]V(/N(+D(````\Z6-1=AJ`%#H1)/^_XUE^%Y?R<.058GE5U93@>S,%```
MB95LZ___NO____^)A7#K___'A63K__\`````,<#&A6/K__\`QH5BZ___`/R)
MT8M]$/*NBUT(]]&%VXUQ_P^$`0<``(G1B=_RKO?1C40Q_SW\`P``#X?;`0``
MA=L/A.X&``!1:@!3C978^___4NB&C_[_@\00@#M^#X3#`0``:@#_=0S_=1!0
MZ(C!_O_'!"0$````:/3Z&`AH]/H8"(VUV/O__U96Z/:7_O^#Q!QJ`(V->.O_
M_U%6Z+B]_O^#Q!"%P+H!````#X1K`0``#[>%@.O__Z@"=!`E`/```#T`@```
M#X0\`0``4&H`:@!J!&CT^A@(:/3Z&`B-M=C[__]65NB;E_[_@\044.@.)@``
M@\00,=*%P(F%:.O__P^$%@$``(UV`%#_M6CK__]H_P\``(VUV.O__U;H/!#\
M_X/$$(7`#X1Y`@``_X5DZ___#[:%V.O__XL=0%L9"/9$`P$(C;W8Z___#X3A
M````D$>*%P^VRO9$"P$(=?.`^B-TIH#Z.W2AA-)TG8#Z(0^$QP```(#Z6P^$
MQP,``("]8NO__P`/A*P&``"`O6/K__\`#X1Q____,?:$THGYQH5/Z___``^$
M&`(``(H'ZSX\(G0^B?*$TG4(/",/A/D!``")\H32QH4WZ___`'0(/%P/A+\#
M``"*A3?K__]!B(5/Z___B@&$P`^$U@$``#PG=;Z`O4_K__\`=;F)\H32#X6J
M`P``B<;KJU)6:*PQ&0C_-<3")0CH8Q'\_S'2C67T6UZ)T%_)P\8`+D#I-/[_
M_XGVBI78Z___Z2+___^#?1@)#X\X____C7<!#[9'`>L$1@^V!O9$`P$(=?50
M:@IHES$9"%;HY1'\_X/$$(7`#X6&`P``#[9^"O9$.P$(#X1W`P``@\8*B;5$
MZ____X5$Z___BY5$Z___#[8R]D0S`0AUZHG7_+G_____,<#RKO?1C501_NL!
M2@^V<O_V1#,!"'7TQ@(`.Y5$Z___#X2/!0``@^P(:A#_M43K___H";S^_X/$
M$(7`B858Z___#X0!!0``BU`$A=+'A5SK__\`````=&^+M5CK__^+/HN%7.O_
M_XT<QX/L#/\SB9U4Z___Z/HB``"+#9B+)0B#Q!"%R8G&NYB+)0@/A$X#``"#
M[`C_,U;HUQ+\_X/$$(7`#X0Z!```@\,$BQ.%TG7A_X5<Z___BY5<Z___BYU8
MZ___.5,$=Y&#[`S_M5CK___H/KK^_X/$$%#_M6CK__]H_P\``(VUV.O__U;H
MPPW\_X/$$(7`#X6'_?__@^P(:@#_M6CK___HL"(``.E@_O__Q@$`BQU`6QD(
M@^P(:CV)C4#K__]7Z$D4_/^#Q!"%P(G"B<%T#HF%0.O__^L&_XU`Z___B[5`
MZ___#[9&__9$`P$(=>F%R0^$C`,``(UQ`0^V0@'K!$8/M@;V1`,!"'7U@^P,
M5NAZOO[_B<.#Q!`/MD#_BQ5`6QD(ZP5+#[9#__9$`@$(=?0Y\W,"B?.*!CPB
M#X29`0``/"</A)$!``"+A4#K__\I^(F%2.O__XG9*?&+E4CK__^#[`B-1`H$
M4/^U;.O__^A^C?[_@\00A<")A73K__\/A%X#``"#[`B-C73K__]1_[5PZ___
MZ+P,``"#Q!"$P`^%/@,``%+_M4CK__]7@^P,:,(H&0C_M73K___H#KW^_X/$
M%%#H4;W^_X/$$#G>Q@`]C4@!=`^*%H#Z7'00B!%!1CG>=?'&`0#I#?S__XU[
M_SGW=.E&#[X&@_AN#X30````#X^I````@_A<#X11`@``#X\Y`@``@_@B#X14
M`@``@_@G#X35`@``Q@%<BA:(40%&@\$"ZZN#[`AJ78UW`5;&A6+K__\!Z,,2
M_/^#Q!"%P(G"=0?IK0(``)!*#[9Z__9$.P$(=?3&`@!7:@/_=116Z$'W__^#
MQ!"%P`^?A6/K___I=/O__X"]3^O__P`/A33\___&A3?K__\!Z2C\__^)\CC0
M#X7[^___,?;I^OO__X/X<P^$L0$```^/?@$``(/X<@^%8/___\8!#4'I#___
M_\8!"D'I!O___SI#_P^%9O[__T9+Z5_^__]0:@=HHC$9"%;H1@[\_X/$$(7`
M#X7W^O__#[9&!_9$`P$(#X3H^O__@\8'1@^V#O9$"P$(=?7\N?____\QP(GW
M\J[WT8U4,?[K`4H/MDK_]D0+`0AU]#GRQ@(`#X3Q`0``BU48@^P,0E+_=116
M:/3Z&`AH]/H8"(N5;.O__XN%<.O__^A8^?__@\0@Z8#Z__^AF(LE"(7`#X3$
M_/__B[54Z___BSXQP/RY______*NB<N+O43K__^Y______*N]]/WT8/L"`'9
M4?^U;.O__^@UB_[_@\00A<")A73K__\/A!4!``"#[`QJ1&CT^A@(_[5$Z___
M_S90Z)"1_O^+=1B#Q!1&5O]U%/^U=.O__VCT^A@(:/3Z&`B+E6SK__^+A7#K
M___HN/C__X/$(.DQ_/__@?[\`P``#X?E^O__@^P(_W40C9W8^___4^B6NO[_
MZ27Y__^#^'0/A>+]___&`0E!Z9']__^#^&(/A=#]___&`0A!Z7_]___&`5Q!
MZ7;]___&`2!!Z6W]___&`2)!Z63]__^+`^G\_O__BYU`Z___*?N#[`B-2P-1
M_[5LZ___Z%6*_O^#Q!"%P(F%=.O__W0Y5E-7@^P,:,(H&0A0Z!.Z_O^#Q!10
MZ(ZZ_O]96XV==.O__U/_M7#K___H?@D``(/$$(3`#X07^?__@^P(:@#_M6CK
M___H8QX``+K_____Z1#Z___&`2=!Z=K\____M63K__^-A=C[__]0:.`Q&0C_
M-<3")0CH2PO\_X/$$.N[_[5DZ___C8W8^___46@@,AD(Z]S_M63K__^-G=C[
M__]3:&PR&0CKR/^U9.O__XV]V/O__U=HK#(9".NTB?95B>575E.![,````"+
M70S&19,`QT6,`````&H`:``"``"-39A1Z!Z(_O^+11"+$(F51/___X/$$$H/
MCJD```"+?12+!XM0!(F%=/____RY#@```+]T,1D(B=;SI@^%D0```(N-1/__
M_X/L"(TTC20```!6C5V84^@0B?[_@\00A<")18@/A'X"``"+312)PXLQBT40
MBU6(BSZ+"(/#((EZ((/Y`KH"````ZPN0BP26B423_$(YT7?TC4'_BTT0B0''
M1)/\`````(M]B(M5%(UUF/RY"````(D:\Z6-9?1;7C'`7\G#C78`BW44BSZ)
MO73___\Q_X.]1/___P''!92+)0@`````#X\<`@``BQ64BR4(A=(/A;L!``"%
M_P^5P<=%O(HQ&0B#^@$/MO&+$X/>_X72QT6X`````(E=P'02,<"-=@"#PP2+
M$T"%TG7VB46X:B"+11#_,&H$C5W(4^B]!@``@\00A,`/A9H!``"%_P^$^@$`
M`(/L#&H`C4VX45=H]/H8"&CT^A@(C568C47(Z,_U__^#Q""%P(E%C`^,90$`
M``^/1P$``(M5$(L"`T7,@^P(C0R%)````%&-79A3Z,>'_O^#Q!"%P(F%</__
M_P^$,@$``(/`((F%;/___XM%%(L(BQF+E7#___^+?<R)6B#!YP)35X/")/]U
MR%+H!0?\_XM%$(L8BWT4*?.+#XTTL8/$$(/[`8D8B;5H____B3=^,HM6!/RY
M$0```+^",1D(B=;SIG4>@X5H____!(US_XM]$(N%:/___XM=%,9%DP&)-XD#
MBU40BP*%P'0GBYUH____B[5L____C0R%_/___X/#!(M%S(U\A@3\P>D"B=[S
MI8L"`T7,BY5L____BTT0BUT4B0''!((`````@^P,B1.+O7#____\C57(N0@`
M``"-=9CSI5+HIP<``(/$$(!]DP"+18P/A?@!``"-9?1;7E_)PX/L"&H]4NC(
M#/S_0(/$$(G"HY2+)0CI*O[__U)7:/`R&0C_-<3")0CH!@C\_X/$$(UV`/\U
MQ,(E"&HR:@%H'#,9".C,"_S_QP0D`0```.CP"_S_@^P(:$PQ&0B+E73_____
M<@3H_K;^_X/$$(7`#X1-`0``BX5T____BW@$A?\/A++]__^#[`AJ/5?H0PS\
M_XUX`8/$$.F<_?__@^P,_W4(Z*F#_O^#Q!"%P`^%Q0```*&`BR4(A<#'192`
MBR4(#X0/_O__B<.`.P!T4Z&8BR4(A<"_F(LE"'0OD(/L#&H`C56X4O]U"/\W
M4XU5F(U%R.B:\___@\0@A<`/B#/___^#QP2+!X7`==*#190$BWV4BQ^%VP^$
MNOW__X`[`'6MBSV4BR4(A?]TX*&8BR4(A<"[F(LE"'32@^P,:@"-1;A05_\S
M:@"-59B-1<CH/_/__X/$((7`#XC8_O__@\,$BP.%P'73@T64!(M]E(L?A=MU
MJ>E>_?__H9B+)0B%P(U]N+N8BR4(="B#[`QJ`%?_=0C_,VH`C568C47(Z/#R
M__^#Q""%P'@+@\,$BP.%P'78,<"%P(E%C`^)&/W__^ER_O__@^P(:%TQ&0B+
MM73_____=@3HD+7^_X/$$(7`#X15_/__BTX$B0V4BR4(Z4?\__^+=12#[`B+
M/O\W:%`S&0CHCP+\_XM%$(/$$(,X`;L!````?B"+112#[`B+"/\TF6B3,1D(
MZ&H"_/]#BU40@\00.1I_X(/L#&CT^A@(Z"($_/_'!"0`````Z/8)_/^)]E6)
MY5=64X'L&`0``&B,,QD(Z/X#_/]>_W4(Z.&!_O^#Q!"%P`^%%P$``(L=@(LE
M"(7;OH"+)0@/A(````"-O>C[__^0BPV8BR4(NYB+)0B%R>L4D*&4BR4(A<!U
M$XUV`(/#!(L#A<!T2XL&@#@`=.12:@!05^C*@?[_@\00@+WH^___?@^$K@``
M`(/L#&H`:._K"`C_,_]U"%#HP;/^_X/$&/\UP,(E"%?HY@G\_X/$$.NMD(/&
M!(L6A=)UAX/L#&CT^A@(Z$H#_/^#Q!#_-<#")0AJ'FH!:-0S&0CHXPC\_XM]
M#(LW@\00A?9T-8UV`(/L"/\UP,(E"&H@Z'0(_/]86O\UP,(E"(M=#/\SZ(()
M_/^#10P$@\00BWT,BS>%]G7.@^P,:/0S&0CHY0+\_XUE]%M>7\G#D,8`+D#I
M2?___X/L"/\UP,(E"/]U".A""?S_Z7/___^058GE5U93@^P4BW4,BPZ-%$F-
M!)+!X`.Z'X7K4??BB=#!Z`6#P`R+?1")!VH04.CQ;/[_B<.#Q!`QP(7;="'_
M-O]U"%=3Z*((_/^#Q!"%P'4<BP>+%CG0<PZ)!HD7B=B-9?1;7E_)P\<'````
M`(/L#%/H3FW^_S'`Z^6)]E6)Y5=64X/L#(M]#(L'@_@QBUT0=Q+'`P````"-
M9?1;7C'`7\G#B?:-%$"-!)+!X`.Z'X7K4??BB=#!Z`6#[`B#P`R)`VH04.A;
M;/[_@\00A<")QG1*_S?_=0A34.@."/S_@\00A<!U*XL#BQ<YT',=B0>)$U#_
M-U;_=0CHCP'\_XDT).B_;/[_@\00ZX['`P````"#[`Q6Z*ML_O^#Q!`QP(,[
M``^4P(UE]%M>7\G#58GE5U93@^P,BUT0BP.%P(M]#'4+,<"-9?1;7E_)PY"#
M[`AJ$%#HS6O^_XG&@\00A?:X`0```'3>_S?_=0A35N@[__O_@\00A<!T$(/L
M#%;H0VS^_[@!````Z[N+`XD'4E!6_W4(Z/4`_/^)-"3H)6S^_X/$$.N=58GE
MBT445H7`4XMU"(M-#(M=$'4;,=)FN/@?]_&#^!!R4H/["'8)C10;.<)R3HGV
MA=MU`HG#@^P(B4X0QT8$`````(E>"(E&#`^ORVH04>@L:_[_@\00,=*%P(D&
M=0G'1@@`````L@&-9?A;B=!>R<.-=@"X$````.NGD(G0Z[!5B>534HM="(M3
M!#M3"'04B=`/KT,00@,#B5,$BUW\R<.-=@!0:E`#4PP/KU,04O\SZ`+I__^)
MPH/$$#'`A=)TVXM##(D3`4,(BU,$Z\*)]E6)Y5-1BUT(BT,$.T,(="")P8M3
M$`^ORD`#"XE#!%-2_W4,4>CO__O_,<"+7?S)PU)J4`-##`^O0Q!0_S/HINC_
M_X/$$#'2A<")P708B0.+0PP!0PB+0P2)P@^O4Q!`C101B4,$A=*)T;@!````
M=+N+4Q#KJ8UV`%6)Y8M-"(M1!#'`A=)T#(U"_XE!!`^O01`#`<G#C78`58GE
M5U93@^P,BUT(BWT0BTL$.?EW)SE["'9!BT,0B?HIR@^OR`,+#Z_05E)J`%&-
M=P'H:0/\_XES!(/$$(MS$(GQ#Z_/`PM35O]U#%'H+O_[_S'`C67T6UY?R<.+
M2PR-%#F)T#'2]_&)QE!J4(M#$`^O\0^OQE#_,^C2Y___B<*#Q!"%TK@!````
M=,B+2P2)$XES".N%B?95B>53BTT(BT40.4$$BUT,=QJ+01")11#'10P`````
MB5T(6\GIWP+\_XUV`(M1$`^OP@,!B44,B540B5T(6\GII/[[_U6)Y5-0BUT(
MBP.%P'4&BUW\R<.0@^P,4.B_:?[_QP,`````QT,(`````,=#!`````"#Q!"+
M7?S)PXUV`%6)Y593BU4(BTH0BT($BW4,B<M(B4($#Z_>*?`#&@^OP5)0`=E1
M4^@<_?O_C67X6U[)PY!5B>564XMU"(M>!(/[`7,%NP$```"+%H72=!TY7@AT
M&%%J$(M&$`^OPU!2Z-3F__^)!HE>"(/$$(UE^%M>R<.058GE4X/L$(M=#/]U
M".AB`?S_B44,B5T(@\00BUW\R>DPKO[_58GE@^P4_W4(Z+("_/^+#0##)0B+
M51B)"LG#D%6)Y<G#C78`58GE5U93@^Q,BT4,BTT(BQC9[HM5$#G9V<#'1>0`
M````QT7<`````,=%V`````#'1=0`````QT70`````,9%RP#'`@````!S4XH1
M#[;"BSU`6QD(]D0'`0AT$I!!.=ET.XH1#[;"]D0'`0AU[S'`@/HM#Y3`A<")
MSHE%Y'4&@/HK=0N003G9=!.-=@"*$8#Z,'4]03G9=`0Q]NOPW=B+70R`?<L`
MB0L/A/<```#=V(M-$-T%2#49",<!5````(MUY(7V=`+9X(UE]%M>7\G#D(#Z
M+XE-S'X\@/HY?S?9!30U&0CK!8UV`-G*#[["@^@P4-S*V<I!V@0D@\0$.=D/
MA#,"``"*$3'V@/HO?@6`^CE^UMW:B<@K1<R`^BZ)1>`/A#D!``"`^F4/A)<`
M``"`^D4/A(X```"+7=0K7="%VP^$5____P^,W@$``(M]X(TT.X'^-`$```^&
M;@$``-G)W>'?X(#D18#\0`^$M@$``('^-0$``'<7W04X-1D(V<G=X=_@W=GV
MQ`$/A9<!``"+==B%]@^%`____]W9QD7+`>GZ_O__@^P0W10DW5VHZ,K]^_^#
MQ!"%P-U%J`^$_O[__^GH_O__BW7<`W7@A?8/A&3___^-4_\YR@^&6?___XG.
M08H1,<"`^BT/E,"%P(E%V`^%2@$``(#Z*P^$00$``#G9#X0_`0``BA&(5<,/
MML+V1`<!!`^$+`$``(%]U`XG``!_$8MUU(T4M@^^1<.-=%#0B77403G9<P^*
M$8A5PP^VPO9$!P$$==*+7=B%VP^$Y/[__XM=U`-=T.G?_O__C5/_.<H/AL[^
M__]!B4W$BA$/ML+V1`<!!'0UV04T-1D(ZP+9R@^^PH/H,%#<RMG*0=H$)/]%
MT(/$!#G9#X2M````BA$/ML+V1`<!!'75W=J)R"M%Q(E%W`^%:?[__X7V#X1A
M_O__B?'I6O[__]W8@_MCV>A^%-T%0#49"(GV@^MD@_MCW,E_]MW8N&=F9F;W
MZXG8P?H"P?@?*<*-/)+1YRG[W03=H(LE"-P,U0",)0B+5=B%TM[)=`?>^>F`
M_?__WLGI>?W__]W9ZZ3WV\=%V`$```#I%/[__]W:,=+IU/W__T'IN?[__XGQ
MZ?O^___=VC'2Z5C___^)]E6)Y8/L#(M5"(V"__\``(U-_%&)1?B-1?A04NB(
M_/__R<.)]E6)Y5=64X/L#(M=##'`B=_\N?_____RKHMU"/?1BT8HC7P9_XE%
M\(`[`'084(M&6%=35O]0!(/$$(7`=`\!PX`[`'7HC67T6UY?R<,/M@.+5?"*
M#!"("T/KS8GV58GE5U93@^P,BUT,,<")W_RY______*NBW4(]]&+1B2-?!G_
MB47P@#L`=!A2BT985U-6_U`$@\00A<!T#P'#@#L`=>B-9?1;7E_)PP^V`XM5
M\(H,$(@+0^O-B?95B>575E.#[`R+?0B+70R)WHM'*`-U$(E%\#GS<Q=1BT=8
M5E-7_U`$@\00A<!T$0'#.?-RZ8UE]%M>7\G#C78`#[8#BU7PB@P0B`M#Z\R)
M]E6)Y5=64X/L#(M]"(M=#(G>BT<D`W40B47P.?-S%U"+1UA64U?_4`2#Q!"%
MP'01`<,Y\W+IC67T6UY?R<.-=@`/M@.+5?"*#!"("T/KS(GV58GE5U93@^P,
MBUT,,<")W_RY______*NBU4(]]&+0BB+=1"-?!G_B47P.?MS.E"+50B+0EA7
M4U+_4`2#Q!"%P'0QC4C_ZP*028/Y_W3<BA:*`T9#.-!T\+@!````C67T6UY?
MR<.-=@`/O@:-9?1;7E_)PX/L"(M-"`^^%HM!6%)1_U`(@\002'_.#[8&BTWP
M#[83B@0(1D,X!`ITC;@!````Z[E5B>575E.#[!R+11@Y112[_____P^$T@``
M`(GVBW44BA8/OL([120/A)\````[12`/A)8````[11P/A,$```!0BUT(BW-8
M_W48_W444_]6!(/$$(7`B<-T.XM-#`'!BU40.=&)3?!W5?PYP(MU#(M]%(G!
M\Z9U1HM%\(E%#`%=%(M]&#E]%`^$!P$``+L!````ZXF0BUT0.5T,="&+30P/
MMC&+111!BUT(#[8XBU,LB4T,_T44B@0R.`0Z=,.-9?1;7K@!````7\G#B?8/
MOLH[32!T80^^^CM])`^$R````(M-&#E-%`^%-?___XMU$#EU#`^5P`^VP(UE
M]%M>7\G#BWT41SM]&`^$,O___XE]%.DJ____C78`BW4,_T44BWT81CE]%(EU
M#'-3BU44#[X*.TT@=4B+11`Y10QT85"+50B+>EC_=1#_=0Q2_U<$@\00A<!T
MPU>+10B+<%C_=1#_=0Q0_U8$BTT,_T44BWT8@\00C30(.7T4B74,<JV+=1@Y
M=10/A&/___^+112*$.E!____BU40.54,Z53___^-9?2)V%M>7\G#BWT41SM]
M&'19#[X'.T4D=/([12!U4XM=$#E=#`^$(@$``%:+30B+<5C_=1#_=0Q1_U8$
M@\00A<!U"8MU#$:)=0SKP%.+70B+0UC_=1#_=0Q3_U`$BU4,C300@\00B74,
MZZ$QP.GG_O__.WT8=/2+=1`Y=0RX_____P^$T?[__XH?#[;+.TT<#X1<`0``
MB7WL48MU"(M&6/]U&%=6_U`$@\0,BU4(B47HBWI8_W48_W7L4O]7!(/$$(7`
M#X4*`0``BU7L0HE5Y(M]"`^V\XM'+(H<,(A=XXM-$#E-#'-FBU7HA=(/A(L`
M``"+70P#7>@[71!W7(M%Z/PYP(MU#(M][(G!\Z9U2HE=#/]U)/]U(/]U'/]U
M&/]UY/]U$/]U#/]U".@R_?__@\0@A<`/CA_^__^+71`Y70QT"XM5Y`^^.CM]
M)'62N/_____I`O[__XGV4(M5"(MZ6/]U$/]U#%+_5P2#Q!"%P'5`BW4,1HEU
M#.EB____4(M5"(M:6/]U$/]U#%+_4P2#Q!"%P'7$BUT,BT4(#[8[BW`LBDWC
M.`P^=;#_10SI8?___U"+10B+<%C_=1#_=0Q0_U8$BTT,C30(@\00B74,Z0S_
M__]2BTT(BWE8_W48_W7L4?]7!`-%[(/$$(E%Y.G>_O__C4<!.T48#X28_O__
MB<>*&.F/_O__B?95B>575E.#[`R+70R+=1`Q_SGS<R"-=@"+50A0BT)85E-2
M_U`$@\00A<!T%`'8B<-'.?-RXXUE]%M>B?A?R<.0C4,!B<-'Z^E5B>575E.#
M[`R+=12+70R%]HM]$(E=\'0?.?MS,U"+50B+0EA74U+_4`2#Q!"%P'07`=B)
MPTYUX8G8*T7PC67T6UY?R<.-=@"-0P&)PT[KYH7V=.0K??"-9?1;7HU'`E_)
MPXGV58GE5U93@^P,BW44BUT,A?:+?0B)7>QT'HUV`(M'6/]U$%.-5?!25_]0
M((/$$(7`?@4!PTYUY2M=[(UE](G86UY?R<-5B>575E.#[`R+11`Y11B+?0B+
M70S'1>P`````=U:+31B%R71;C0P#*TT8C7$!.?.)7?!S/XUV`(/L"(M'7&H`
M_W48_W44_W484U?_4`2#Q""%P'164(M'6%935_]0!(/$$(7`=0*P`0'#_T7L
M.?-RQXUV`#'`C67T6UY?R<.)]HM5((72=!>+11S'``````#'0`0`````QT`(
M`````(UE]%M>N`$```!?R<.+=2"%]G0MB=B+51PK1?"+7>R#?2`!QP(`````
MB4($B5H(=A")0@P#11B)0A#'0A0`````N`(```#KD(GV58GE5U935HI%'(A%
M\XM=&(M%$#G#=@*)PXG9_#G;BW4,BWT4\Z8/E\$/DL(HT0^^P87`=0Z`??,`
MB=AU`XM%$"M%&%M;7E_)PXUV`%6)Y5=64XM]&#M]$(M-#(M=%'8#BWT0C30/
MB?8Y\7,<BA.*`4-!.-!T\@^V2?\/MG/_*?&)R%M>7\G#D(M%&#E%$'0LO@$`
M``!S"HE%$(G9OO____^+71"-!!DI^#G!<P^-=@"*$8#Z('4.03G!<O1;7C')
MB<A?R<.`^A^)\'<"]]A;7HG!B<A?R<.058GE5U93@^P,BWT,BU44.=>+71"+
M=1AT$CG>B?!W'5%04E?HM/'[_X/$$#GS=Q&-9?2)V%M>7\G#C78`B=CKWXG:
M*?)04HT$-VH@4.BK]?O_@\00C67TB=A;7E_)PXGV58GEBU4,BT40B44,B54(
MR>D']OO_C78`58GE5U93BUT,B=\#?1`Y^XMU&',QBQ:0BT44BPB)R(/@/P'0
M#[83#Z_"B<K!X@@!T#'!BU44B0J+!D.#P`,Y^XG"B09RTEM>7\G#D%6)Y5=6
M4X/L3(I5%(MU)(I%&(I-'(A5UXM5(`'RB$76B$W5BT4HBTT(`T4@B57,BU%8
MB56TBTT(B47(,=*+12#W<5"+?0R+71!0C00?4%=1B770B46\BU6T_U(0@\00
M.=AS*(T<!XE=O.L@D#I%U@^$K0```#I%U0^$I````(M=*(@#0XE=*$>(!D8[
M?;QT'#MUS'07B@<Z1==UT(U7`3M5O'3(B=>*`NO4B?:)\"M%T(M5,(M]+(D"
MB0?K!XUV`,8&($8[=<QU]XM-"(U5XHMQ6(U%V%)0BTT(#[=Y5E=1BUTH_U8D
M#[[X@\00ZPN)]L8#($,[7<AS'XTT'SMUR'/O4%>-1=A04XGSZ`GP^_^#Q!`[
M7<ARXI"-9?1;7C'`7\G#BU4(BUI8BTT(BT4@,=+W<5!05O]UT%&)]_]3$"M]
MT(/$$#G'=@6+==`!QHGP*T70BTTLB0&+72"+?3")'Y"+50AFBUI4B!Y&.W7,
M=?&+?0B-5>*+=UB-1=A24`^W3U915XM=*/]6)`^^^(/$$.L0C78`Q@,@0SM=
MR`^#=____XTT'SMUR'/K4%>-3=A14^AC[_O_B?.#Q!#KW%6)Y5=64X/L'(M%
M&#E%%+O_____#X3&````B?:+112*$`^^PCM%)`^$DP```#M%(`^$B@```#M%
M'`^$M0```%"+50B+6EC_=1C_=112_U,$@\00A<")PW0[BTT,`<&+=1`Y\8E-
M\'=*_#G`BW4,BWT4B<'SIG4[BT7PB44,`5T4BTT8.4T4#X3[````NP$```#K
MB9"+71`Y70QT%HMU#(H61HM]%(EU#(H'1SC0B7T4=,Z-9?1;7K@!````7\G#
MD`^^^CM]('1A#[[*.TTD#X3(````BWT8.7T4#X5!____BT40.44,#Y7!#[;!
MC67T6UY?R<.+?11'.WT8#X0^____B7T4Z3;___^-=@"+=0Q&B74,_T44BW48
M.744<U.+?10/O@\[32!U2(M5$#E5#'1A4(M-"(MQ6/]U$/]U#%'_5@2#Q!"%
MP'3#5XM5"(M"6/]U$/]U#%+_4`2+?0R--#B)=0S_112+=1B#Q!`Y=11RK8M%
M&#E%%`^$8____XMU%(H6Z4'___^+71`Y70SI5/___XUE](G86UY?R<.+?11'
M.WT8=%D/O@<[121T\CM%('53BUT0.5T,#X06`0``5HM5"(M"6/]U$/]U#%+_
M4`2#Q!"%P'4)BW4,1HEU#.O`4XM="(MS6/]U$/]U#%/_5@2+30R--`B#Q!")
M=0SKH3'`Z>?^__\[?1AT](M5$#E5#+C_____#X31_O__B@\/ML$[11R(3>\/
MA$<!``")?>A1BU4(BT)8_W485U+_4`2#Q`R+=0B)1>2+?EC_=1C_=>A6_U<$
M@\00A<`/A?4```"+?>A'B7W@BW40.74,<V:+1>2%P`^$BP```(M=#`-=Y#M=
M$'=<BU7D_#G2BW4,BWWHB='SIG5*B5T,_W4D_W4@_W4<_W48_W7@_W40_W4,
M_W4(Z$K]__^#Q""%P`^.*_[__XM-$#E-#'0+BU7@#[X:.UTD=9*X_____^D.
M_O__B?90BU4(BUI8_W40_W4,4O]3!(/$$(7`=3J+=0Q&B74,Z6+___]0BT4(
MBUA8_W40_W4,4/]3!(/$$(7`=<2+30P/OC$/MGWO.?YUMO]%#.EG____4(MU
M"(M&6/]U$/]U#%;_4`2+?0R--#B#Q!")=0SI$O___U*+30B+65C_=1C_=>A1
M_U,$`T7H@\00B47@Z?/^__^-1P$[11@/A*W^__^*&(G'B%WOZ:'^__^058GE
M5U93@^P,BUT,BW40,?\Y\W,]BTT(BT%85E.-5?!2_W4(_U`@@\00A<!^/HM-
M\`'##[;%BQ3%I(PE"(72=!L/ML$/O@0"C00'C7@!.?-RPXUE]%M>B?A?R<,#
M/,6@C"4(B?B->`'KY(GV0^NBD%6)Y5.![`P$``"+70A3C87X^___4.CZ:?[_
M@^P(:BZ-'!A3Z-CQ^_^#Q""%P'0%BUW\R<.#[`Q3Z$.<_O^#Q!"+7?S)PXUV
M`%6)Y593@^P,BT4(#[]8#E#H,^_[_X/$$(7`B<9X1O\-%$H9"#L=_$<9"',-
MH?A'&0B+3-@$A<EU"XUE^%N)\%[)PXGV@^P,QT38!`````#_--CH^57^_X/$
M$(UE^%N)\%[)PY#H'^W[_XL0]D4,&(D5`$H9"'2MZ`SM^___,(/L"%/H[5[^
M_X/$#%!J)&H$Z`Q<_O^#Q!#KBXUV`%6)Y5=64X/L'(M=#(7;C578=4'&1=AR
MC479@^P(Q@``4O]U".AC[OO_@\00A<")Q@^$$`$```^_>`X[/?Q'&0AR,O\%
M%$H9"(UE]%N)\%Y?R<.)]H-]#`%T4H-]#`)T8/9%#`AU4L9%V'>-1=G&`"M`
MZZ>0@^P(BQWX1QD(_W40_W4(Z.A5_O^#Q!"%P(D$^W0T#[]6#J'X1QD(_P44
M2AD(QT30!`,```#KG9#&1=AWZ6+___^-=@#&1=AAZZR)]L9%V'+KI(/L#`^_
M7@Y6Z-GM^_^#Q!"%P'A[_PT42AD(.QW\1QD(<R.A^$<9"(MTV`2%]G06@^P,
MQT38!`````#_--CHK%3^_X/$$,<%`$H9"`P```#V11`9=0HQP(UE]%M>7\G#
M_S4`2AD(_W4(:B0QVX-]#``/E<-3Z,5:_O^#Q!`QP.O7Z*'K^_^+.(D]`$H9
M".O`Z)+K^_^+"/9%$!B)#0!*&0@/A'3____H>^O[__\P@^P(4^A<7?[_@\0,
M4&HD:@3H>UK^_X/$$.E/____C78`58GE5U93@^P<BT40A<"+?0B-5=AU5L9%
MV'*-1=F#[`C&``!25^@.[/O_@\00A<")Q@^$@P```/\%%$H9"#L]_$<9"',<
MBQWX1QD(BU3[!(72=$7_#1!*&0C'1/L$!````(UE]%N)\%Y?R<.0@_@!=!>#
M^`)T/J@(=1;&1=AWC479Q@`K0.N6D,9%V'?KC(GVQD788>OHB?:#[`C_=13_
M=0SH-E3^_XD$^X/$$(L=^$<9".NEQD78<NO$Z)GJ^_^+`/9%%!BC`$H9"'25
M@^P0Z(3J^_^#Q`S_,&HD:@_HCEG^_X/$$.EW____B?95B>534KLHP"4(H2C`
M)0CK"HUV`(/K!/_0BP.#^/]U]%A;R</HR^_[_\,``````````````"]T;7`O
M8V]M<&]N96YT<U]D:7)T>5]F;&%G`'!A8VMA9V5M;F=?9F%I;',`4&%C:V%G
M96UN9R!T:6UE;W5T`"5S.B5S"@!P<V%A9&T`*"<`)RPG`"<I`&)A<VEC7W-T
M<FEN9SHZ7TU?<F5P;&%C95]A=7@`;F]T7VEN<W1A;&QE9``M:``M+6AE;'``
M+2US970M9&ER='DM9FQA9P```%5S86=E.B!P86-K86=E;6YG("A;/'!A8VMA
M9V4^77PM+7-E="UD:7)T>2UF;&%G*0H@<&%C:V%G96UN9PH@("`@=7!D871E
M<R!C;VUP;VYE;G1S(&QI<W0@:6X@1$(*('!A8VMA9V5M;F<@+2US970M9&ER
M='DM9FQA9PH@("`@8W)E871E<R!T:&4@9FQA9R!I;F1I8V%T:6YG('1H870@
M;F5X="!A=71O<')E<&5N9"@I(&-A;&P*("`@('=I;&P@:6YV;VME('!A8VMA
M9V5M;F<@=&\@=7!D871E(&-O;7!O;F5N=',@;&ES="!I;B!T:&4@1$(*('!A
M8VMA9V5M;F<@/'!A8VMA9V4^"B`@("!S:&]W<R!T:&4@/'!A8VMA9V4^('9E
M<G-I;VX*('!A8VMA9V5M;F<@+2UH96QP"B`@("!S:&]W<R!T:&ES(&UE<W-A
M9V4*`````%5N86)L92!T;R!C<F5A=&4@)V1I<G1Y)R!F;&%G(&EN('1H92!0
M4D]$54-47U)/3U1?1"]V87(Z("5S`%)%4$Q!0T4@0V]M<&]N96YT<R`H;F%M
M92P@=F5R<VEO;BD@5D%,5453````56YA8FQE('1O('5P9&%T92!#;VUP;VYE
M;G1S(&EN($1".B`E<P```%5N86)L92!T;R!C;VYN96-T('1O('1H92!M>7-Q
M;"!D871A8F%S90H```````````````!54$1!5$4@;6ES8R!3150@=F%L(#T@
M=F%L("L@,2!72$5212!P87)A;2`]("=P86-K86=E;6YG7V9A:6QS)P``*,,E
M","\"`@```````````````````````````````!.-7!L97-K,C).;U-U8VA0
M86-K86=E17AC97!T:6]N10``````````````````````````````````````
M`````````!B]"`B\U@0(S-8$"$#7!`@`````T,(E"&"]"`@DO0@(*,,E""R]
M"`A.-7!L97-K,3!0:V=#<F5A=&]R10``````````````````````````````
M````````````3C5P;&5S:S$Q4&MG0W)E871O<C!)3E-?,3=#;VQD9G5S:6]N
M4&%C:V%G945%10````````````````````````````#`O0@(%-4$"'C5!`C0
MQ@0(*,<$".BC!`@`````T,(E".6]"`C,O0@(*,,E"-2]"`A.-7!L97-K-U!A
M8VMA9V5%`$XU<&QE<VLQ,5!A8VMA9V5);7!L10````````````#,O0@(K,8$
M"+S&!`CHHP0(Z*,$"``````DO0@(!,<$"!3'!`CHHP0(``````````!(O@@(
MX-8$"/#6!`@$UP0(`````-#")0A@O@@()+T("````````````````$XU<&QE
M<VLQ,5!K9T-R96%T;W(P24Y37S$Y4V%M8F%&<F5E0G-D4&%C:V%G945%10``
M````````````````````````N+X(".C5!`A,U@0(:-<$"`````#0PB4(X+X(
M""2]"`@`````````````````````````````````````3C5P;&5S:S$Q4&MG
M0W)E871O<C%)3E-?,31&<F5E0G-D4&%C:V%G945%10``````````````````
M`````````'!S80`W+C4N-`!P<V$M<W1A;F1A<F0`9G)O;G1P86=E`#4N,`!M
M86EL;6%N`#(N,"XQ,P!W96)A;&EZ97(`,BXQ+C$P`'!S82UM:6=R871I;VXM
M;6%N86=E<@!S<&%M87-S87-S:6X`,BXV,0!P97)L+4%P86-H92U!4U``,BXU
M-RTV,`!D<G=E8@`T+C,R+C(`9')W96(M<6UA:6P`-"XS,@!P<V$M87!I+7)P
M8P!34TA497)M`#`N,BXR`#$N,#,`<'-A+7%M86EL+7)B;'-M='!D`#`N-S``
M<')O9G1P9``Q+C(N,3``;&]G<F]T871E`#,N-P!T;VUC870`-"XQ+C,P`'!S
M82UB=0!P<V$M;6%N=6%L+6-U<W1O;2US:VEN+6=U:61E`'!S82UH;W)D90`S
M+C$N,0!P<V$M:6UP`#0N,0!P<V$M='5R8F$`,BXQ`&UO9%]P97)L`#$N,CD`
M;6]D7W!Y=&AO;@`R+C<N,3``8V]L9&9U<VEO;@!A<&%C:&4`,2XS+C,S`#0N
M,2XQ,0!P:'``-"XT+C(`8V]U<FEE<BUI;6%P`#,N,"XX`'!O<W1G<F5S<6PM
M<V5R=F5R`#<N-"XV`&)I;F0`.2XR+C4`<V%M8F$`8V]L9&9U<VEO;BUS=7!P
M;W)T````````````,,$("!C=!`A\W00(T,8$""C'!`BHUP0(`````-#")0@\
MP0@(P+T("$XU<&QE<VLQ-T-O;&1F=7-I;VY086-K86=E10`M:6YF;P`M=F5R
M<VEO;@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````8V9?:6YS=&%N8V5?='EP90!C9E]I;G-T86YC95]P871H`"5S+V)I
M;B\`:C)E90!C9FEN9F\`:G)U;@!5;F%B;&4@=&\@;W!E;B!P:7!E.B`E<PH`
M56YA8FQE('1O(&-R96%T92!C:&EL9#H@)7,*``!"860@9FEL92!P97)M:7-S
M:6]N<R!O;B!#;VQD1G5S:6]N(&)I;F%R>2!F:6QE("5S"@``56YA8FQE('1O
M(&5X96,@<')O9W)A;2`E<SH@)7,*``!%<G)O<B!O8V-U<F5D(&1U<FEN9R!E
M>&5C('!R;V=R86TZ("5S"@``56YA8FQE('1O(')E860@<')O9W)A;2!O=71P
M=70Z("5S"@``56YA8FQE('1O(&1U<&QI8V%T92!A(&9I;&4@9&5S8W)I<'1O
M<CH@)7,*``!5;F%B;&4@=&\@8VAA;F=E(&1I<F5C=&]R>2!T;R`E<SH@)7,*
M``````````````#HT@@(G/@$"`#Y!`CLW00(4-X$"-#")0CTT@@(S+T("$XU
M<&QE<VLQ-$9R965"<V1086-K86=E10``````````*-,("'#Y!`C4^00(^-T$
M"##>!`C0PB4(--,(",R]"`A.-7!L97-K,3A":6YD1G)E94)S9%!A8VMA9V5%
M````````````````<-,("$3Z!`BH^@0(!-X$"!#>!`C0PB4(?-,(",R]"`A.
M-7!L97-K,3E386UB849R965"<V1086-K86=E10!697)S:6]N(``O=7-R+VQO
M8V%L+W-B:6XO<VUB9`!"24Y$(``O=7-R+W-B:6XO;F%M960`+58`8F%S:6-?
M<W1R:6YG.CIS=6)S='(`+78```````````````````````````````!314Q%
M0U0@=F5R<VEO;B!&4D]-($-O;7!O;F5N=',@5TA%4D4@;F%M92`]("<E<R<`
M````````````````````1'5P;&EC871E(')E8V]R9"!I;B!#;VUP;VYE;G1S
M('1A8FQE(&9O<B!P86-K86=E("5S`$Y53$P@=F5R<VEO;B!F;W(@<&%C:V%G
M92`G)7,G(&EN(&1A=&%B87-E````4&%C:V%G92`G)7,G(&ES(&YO="!F;W5N
M9"!I;B!#;VUP;VYE;G1S('1A8FQE````17)R;W(@9'5R:6YG(&UY<W%L7W-T
M;W)E7W)E<W5L=#H@)7,`56YA8FQE('1O(&-O;FYE8W0@=&\@=&AE(%!L97-K
M(&1A=&%B87-E`$5R<F]R(&1U<FEN9R!M>7-Q;%]F971C:%]R;W<Z("5S`$5R
M<F]R(&1U<FEN9R!M>7-Q;%]Q=65R>3H@)7,`)7,O=F%R+W5T:6QI=&EE<RYS
M96T``&9A:6QE9"!T;R!O<&5N('-E;6%P:&]R92!F:6QE("5S.B`E<P````!S
M:'5T9&]W;E]S96TH*3H@9F%I;&5D('1O(&-L;W-E('-E;6%P:&]R92!F:6QE
M.B`E<P``<V5M7VQO8VLH*2!F86EL960@9F]R('-E;6YU;2`E;&0Z("5S````
M`'-E;5]L;V-K*"D@9F%I;&5D(&9O<B!S96UN=6T@)6QD.B!S96UN=6T@;75S
M="!N;W0@8F4@;F5G871I=F4```!S96U?=6YL;V-K*"D@9F%I;&5D(&9O<B!S
M96UN=6T@)6QD.B`E<P``<V5M7W5N;&]C:R@I(&9A:6QE9"!F;W(@<V5M;G5M
M("5L9#H@<V5M;G5M(&UU<W0@;F]T(&)E(&YE9V%T:79E`'-E;5]T97-T*"D@
M9F%I;&5D(&9O<B!S96UN=6T@)6QD.B`E<P````!S96U?=&5S="@I(&9A:6QE
M9"!F;W(@<V5M;G5M("5L9#H@<V5M;G5M(&UU<W0@;F]T(&)E(&YE9V%T:79E
M````56YA8FQE('1O(&=E='!W;F%M(&9O<B!U<V5R("5S``!5;F%B;&4@=&\@
M9V5T9W)N86T@9F]R(&=R;W5P("5S.B`E<P`E=0!04D]$54-47U)/3U1?1`!(
M5%101%]62$]35%-?1`!(5%101%]#3TY&7T0`2%144$1?0DE.7T0`44U!24Q?
M4D]/5%]$`%%-04E,7TU!24Q.04U%4U]$`$944$1?0T].1@!%<G)O<CH@1E10
M1%]#3TY&(&YO="!D969I;F5D"@!&5%!$7T-/3D9?24Y#`$944$1?0DE.7T0`
M3D%-141?4E5.7U)/3U1?1`!714)?4U1!5`!%<G)O<CH@5T5"7U-4050@;F]T
M(&1E9FEN960*`$Q/1U)/5$%410!%<G)O<CH@3$]'4D]4051%(&YO="!D969I
M;F5D"@!-65-13%]605)?1`!-65-13%]"24Y?1`!01U-13%]"24Y?1`!01U-1
M3%]$051!7T0`34%)3$U!3E]23T]47T0`34%)3$U!3E]605)?1`!04D]$54-4
M7U)#7T0`1%5-4%]$`$5R<F]R.B!$54U07T0@;F]T(&1E9FEN960*`$-!5$%,
M24Y!7TA/344`1%)714)?4D]/5%]$`$125T5"7T540U]$`"]A9&UI;B]C;VYF
M+W-E='1I;F=S`"]A9&UI;B]B:6XO9&YS;6YG`"]A9&UI;B]B:6XO;6%I;&UN
M9P`O861M:6XO8FEN+W5S97)M;F<`+V%D;6EN+V)I;B]F<%]W<F%P<&5R`"]A
M9&UI;B]B:6XO<FU?<&1?=7-R`"]A9&UI;B]B:6XO;6%K95]V<G0`+V%D;6EN
M+V)I;B]W96)S<G9M;F<`+V%D;6EN+V)I;B]R;5]F<FT`+V%D;6EN+V)I;B]I
M;G1E<F9A8V4`+V%D;6EN+V)I;B]D;VUA:6YM;F<`+V%D;6EN+V)I;B]C:&MC
M;VYF:6<`+W9A<B]C97)T:69I8V%T97,`````17)R;W(Z($A45%!$7U9(3U-4
M4U]$(&YO="!D969I;F5D"@``17)R;W(Z($A45%!$7T-/3D9?1"!N;W0@9&5F
M:6YE9`H`````17)R;W(Z($A45%!$7T))3E]$(&YO="!D969I;F5D"@!%<G)O
M<CH@44U!24Q?4D]/5%]$(&YO="!D969I;F5D"@````!%<G)O<CH@44U!24Q?
M34%)3$Y!34537T0@;F]T(&1E9FEN960*````17)R;W(Z($944$1?0T].1E])
M3D,@;F]T(&1E9FEN960*````17)R;W(Z("5S(&YO="!D969I;F5D(&EN('!R
M;V1U8W0@8V]N9FEG(&9I;&4`````17)R;W(Z($Y!345$7U)53E]23T]47T0@
M;F]T(&1E9FEN960*`````$5R<F]R.B!-65-13%]605)?1"!N;W0@9&5F:6YE
M9`H`17)R;W(Z($U94U%,7T))3E]$(&YO="!D969I;F5D"@!%<G)O<CH@4$=3
M44Q?0DE.7T0@;F]T(&1E9FEN960*`$5R<F]R.B!01U-13%]$051!7T0@;F]T
M(&1E9FEN960*`````$5R<F]R.B!-04E,34%.7U)/3U1?1"!N;W0@9&5F:6YE
M9`H``$5R<F]R.B!-04E,34%.7U9!4E]$(&YO="!D969I;F5D"@```$5R<F]R
M.B!04D]$54-47U)#7T0@;F]T(&1E9FEN960*`````$5R<F]R.B!#051!3$E.
M05](3TU%(&YO="!D969I;F5D"@```$5R<F]R.B!$4E=%0E]23T]47T0@;F]T
M(&1E9FEN960*`````$5R<F]R.B!$4E=%0E]%5$-?1"!N;W0@9&5F:6YE9`H`
M17)R;W(Z(%!23T150U1?4D]/5%]$(&YO="!D969I;F5D"@`O971C+W!S82]P
M<V$N8V]N9@````!U<&1A=&4@9&]M86EN<R!S970@<W1A='5S/25U('=H97)E
M(&ED/2(E<R(``%5N86)L92!T;R!U<&1A=&4@<W1A='5S(&9O<B!D;VUA:6X@
M=VET:"!I9#TB)7,B.B`E<RX`````9&5L971E(&9R;VT@4&%R86UE=&5R<R!W
M:&5R92!I9#TG)7,G(&%N9"!P87)A;65T97(])R5S)R!A;F0@=F%L=64])R5S
M)P``9&5L971E(&9R;VT@4&%R86UE=&5R<R!W:&5R92!I9#TG)7,G(&%N9"!P
M87)A;65T97(])R5S)P!5;F%B;&4@=&\@8V]N;F5C="!T;R!M>7-Q;"!D871A
M8F%S90H`````56YA8FQE('1O(&1E;&5T92!P87)A;65T97(@)7,@9G)O;2!0
M87)A;65T97)S.B`E<P```&1E;&5T92!F<F]M(&1O;5]P87)A;2!W:&5R92!D
M;VU?:60])R5S)R!A;F0@<&%R86T])R5S)P``56YA8FQE('1O(&1E;&5T92!P
M87)A;65T97(@)7,@9G)O;2!D;VU?<&%R86TZ("5S`````&1E;&5T92!F<F]M
M(&UI<V,@=VAE<F4@<&%R86T])R5S)P```%5N86)L92!T;R!D96QE=&4@<&%R
M86UE=&5R("5S(&9R;VT@;6ES8SH@)7,`<F5P;&%C92!I;G1O(%!A<F%M971E
M<G,@*&ED+"!P87)A;65T97(L('9A;'5E*2!V86QU97,H)R5S)RP@)R5S)RP@
M)R5S)RD`56YA8FQE('1O('!U="!P87)A;65T97(@)7,@:6YT;R!087)A;65T
M97)S.B`E<P``<F5P;&%C92!I;G1O(&1O;5]P87)A;2`H9&]M7VED+"!P87)A
M;2P@=F%L*2!V86QU97,H)R5S)RP@)R5S)RP@)R5S)RD`````56YA8FQE('1O
M('!U="!P87)A;65T97(@)7,@:6YT;R!D;VU?<&%R86TZ("5S````<F5P;&%C
M92!I;G1O(&UI<V,@*'!A<F%M+"!V86PI('9A;'5E<R@G)7,G+"`G)7,G*0``
M`')E<&QA8V4@:6YT;R!M:7-C("AP87)A;2D@=F%L=65S*"<E<R<I``!5;F%B
M;&4@=&\@<'5T('!A<F%M971E<B`E<R!I;G1O(&UI<V,Z("5S`%PB)P!-65-1
M3%]53DE87U!/4E0`+V5T8R]M>2YC;F8`6VUY<W%L9%T`+W9A<B]L:6(O;7ES
M<6PO;7ES<6PN<V]C:P`O=&UP+VUY<W%L+G-O8VL`4%-!7U)53E]-3T1%`%!3
M05]$0E](3U-4`"]E=&,O<'-A+W9Z7VUO9&4`+W!R;V,O=GHO=F5I;F9O`'!S
M825D`%!305]$0E].04U%`&%D;6EN)60`4%-!7T1"7TQ/1TE.`"]E=&,O<'-A
M+RYP<V$N<VAA9&]W`%!305]$0E]03U)4`'-E="!F;W)E:6=N7VME>5]C:&5C
M:W,],`!L;V-A;&AO<W0`861M:6X`9&]M86EN<P!H='EP90!P87)A;0!M:7-C
M`'9A;`!5;F%B;&4@=&\@<75E<GD@86YO;E]F='`Z("5S"@!T<G5E`&%D;6EN
M7V5M86EL`%5N86)L92!T;R!D969I;F4@861M:6X@96UA:6P*`&ED;E]T;V%S
M8VEI*"D@9F%I;&5D.B`E<P!314Q%0U0@;6%X*&ED*2!&4D]-("5S`%5N86)L
M92!T;R!D969I;F4@;6%X(&ED.B`E<P!U;G)E8V]G;FEZ960@4%-!7U)53DU/
M1$4```!D8E]C;VYN96-T.B!F86EL960@=&\@8V]N;F5C="!T;R!D871A8F%S
M93H@17)R;W(Z("5S`````&1B7V-O;FYE8W0Z(%5N86)L92!T;R!O<&5N(&%D
M;6EN('!A<W-W;W)D(&9I;&4@)7,Z("5S````9&)?8V]N;F5C=#H@56YA8FQE
M('1O(')E860@861M:6X@<&%S<W=O<F0@9FEL92`E<SH@)7,```!D8E]C;VYN
M96-T.B!I;G-U9F9I8VEE;G0@;65M;W)Y('1O(&%L;&]C871E(&YE=R!O8FIE
M8W0N`%5N86)L92!T;R!Q=65R>2!P87)A;65T97(@8GD@<75E<GD@)7,Z("5S
M"@``<V5L96-T("5S(&9R;VT@)7,@=VAE<F4@)7,])R5S)P!S96QE8W0@:7!A
M+FEP7V%D9')E<W,@9G)O;2!D;VUA:6YS(&0L(&AO<W1I;F<@:"P@25!?061D
M<F5S<V5S(&EP82!W:&5R92!D+FED/2<E<R<@86YD(&0N:60]:"YD;VU?:60@
M86YD(&@N:7!?861D<F5S<U]I9#UI<&$N:60``%5N86)L92!T;R!Q=65R>2!)
M4"!A9&1R97-S.B`E<PH`9V5T7VEP7V%D9')E<W,Z(%5N86)L92!T;R!C;VYN
M96-T('1O('1H92!M>7-Q;"!D871A8F%S90!S96QE8W0@<W1A='5S(&9R;VT@
M9&]M86EN<R!W:&5R92!I9#TB)7,B`````%5N86)L92!T;R!G970@<W1A='5S
M(&9O<B!D;VUA:6X@=VET:"!I9#TB)7,B.B`E<P````!5;F%B;&4@=&\@9V5T
M('-T871U<R!F;W(@9&]M86EN('=I=&@@:60](B5S(CH@<W5C:"!D;VUA:6X@
M:7,@;F]T(&5X:7-T+@!5;F%B;&4@=&\@9V5T('-T871U<R!F;W(@9&]M86EN
M('=I=&@@:60](B5S(CH@97)R;W(@=')A;G-L871E('-T871U<R!V86QU92!F
M<F]M(&-H87(@=&\@=6YS:6=N960@:6YT+@```'-E;&5C="!V86P@9G)O;2!D
M;VU?<&%R86T@=VAE<F4@9&]M7VED/2<E<R<@86YD('!A<F%M/2<E<R<``%5N
M86)L92!T;R!Q=65R>2!D;VUA:6X@<&%R86UE=&5R("5S.B`E<PH`````<V5L
M96-T('(N=F%L=64@9G)O;2!D;VUA:6YS(&0L(%!A<F%M971E<G,@<B`)"7=H
M97)E(&0N:60])R5S)R!A;F0@9"YP87)A;7-?:60]<BYI9"!A;F0@<BYP87)A
M;65T97(])R5S)P!S96QE8W0@<BYV86QU92!F<F]M($1O;6%I;E-E<G9I8V5S
M(',L(%!A<F%M971E<G,@<B`)"0D)('=H97)E(',N9&]M7VED/2<E<R<@86YD
M(',N='EP93TG)7,G(&%N9"!S+G!A<F%M971E<G-?:60]<BYI9"`@86YD('(N
M<&%R86UE=&5R/2<E<R<``'-E;&5C="!L+G9A;'5E(&9R;VT@9&]M86EN<R!D
M+"!,:6UI=',@;"`)"0D)('=H97)E(&0N:60])R5S)R!A;F0@9"YL:6UI='-?
M:60];"YI9"`@86YD(&PN;&EM:71?;F%M93TG)7,G`````%5N86)L92!T;R!Q
M=65R>2!D;VUA:6X@;&EM:70@)7,Z("5S"@````!S96QE8W0@*B!F<F]M(&1O
M;6%I;G,@9&]M+"!D;G-?<F5C<R!D;G,@"0EW:&5R92!D;VTN:60])R5S)R!A
M;F0@9&]M+FED/61N<RYD;VU?:60@86YD("@H9&YS+G1Y<&4])T$G*2!O<B`H
M9&YS+G1Y<&4])T-.04U%)RDI(`D)86YD(&1N<RYH;W-T(&QI:V4@)W=W=RXE
M)2<```!S96QE8W0@*B!F<F]M('-U8F1O;6%I;G,@"0D)=VAE<F4@9&]M7VED
M/2<E<R<@86YD(&YA;64])W=W=R<`````56YA8FQE('1O('%U97)Y('=W=R!P
M<F5F:7@Z("5S"@!5;F%B;&4@=&\@<75E<GD@=W=W('-U8F1O;6%I;CH@)7,*
M``!S96QE8W0@82YS=&%T=7,@9G)O;2!D;VUA:6YS(&0L(&%N;VY?9G1P(&$@
M"0D)"0D)"0D)=VAE<F4@9"YI9#TG)7,G(&%N9"!A+F1O;5]I9#UD+FED````
M<V5L96-T(&@N9G!?<W-L(&9R;VT@9&]M86EN<R!D+"!H;W-T:6YG(&@@"0D)
M"0D)"0D)=VAE<F4@9"YN86UE/2<E<R<@86YD(&@N9&]M7VED/60N:60``%5N
M86)L92!T;R!Q=65R>2!F<F]N='!A9V4@<W1A='5S.B`E<PH```!S96QE8W0@
M:"YF<"!F<F]M(&1O;6%I;G,@9"P@:&]S=&EN9R!H(`D)"0D)"0D)"7=H97)E
M(&0N;F%M93TG)7,G(&%N9"!H+F1O;5]I9#UD+FED``!S96QE8W0@8RYE;6%I
M;"!F<F]M(&1O;6%I;G,@9"P@8VQI96YT<R!C(`D)"0D)"0D)"7=H97)E(&0N
M8VQ?:60]8RYI9"!A;F0@9"YI9#TG)7,G``!5;F%B;&4@=&\@9&5F:6YE(&-L
M:65N=',@96UA:6PZ("5S"@!S96QE8W0@:60@9G)O;2!D;VUA:6YS('=H97)E
M(&YA;64])R5S)P``9V5T7V1O;5]I9"@I.B!D;VUA:6YS(')E8V]R9"!N;W0@
M9F]U;F0@:6X@1$(@9F]R("<E<R<*``!5;F%B;&4@=&\@<75E<GD@9&]M86EN
M($E$.B`E<PH``'-E;&5C="!N86UE(&9R;VT@9&]M86EN<R!W:&5R92!N86UE
M/2<E<R<`````56YA8FQE('1O('%U97)Y(&1O;6%I;B!N86UE.B`E<PH`26YV
M86QI9"!L96YG=&@`4'5N>6-O9&4@97)R;W(`4W5C8V5S<P!5;FMN;W=N(&5R
M<F]R`$%#12!P<F5F:7@@9F]U;F0`04-%('!R969I>"!N;W0@9F]U;F0`5F5R
M:69Y(&5R<F]R`$-O;G1A:6YS(&YO;BU,1$@@8VAA<F%C=&5R<P!#;VYT86EN
M<R!M:6YU<P!)8V]N=B!E<G)O<@!#86YN;W0@86QL;V-A=&4@8G5F9F5R`%-T
M<FEN9W!R97`@97)R;W(`06QL;V-A=&EO;B!F86EL960`)7,H)7,I(&9A:6QE
M9#H@)7,`;F\@:&]S=&YA;64@9F]U;F0@:6X@55),`')E9V-O;7`H*2!F86EL
M960Z("5S`')E9V5X96,H*2!F86EL960Z("5S`&ED;E]T;V%S8VEI7W-A9F4`
M`%XH9G1P.B\O?&AT='!S/SHO+RD_*%M>0%TK0"D_*%M>+SI=*RDH+BHI/R0`
M)7,Z(``*4WES=&5M(&5R<F]R("5D.B`E<P```$-A;B=T(&%L;&]C871E(&UE
M;6]R>2!F;W(@97)R;W(@;65S<V%G90!X;BTM````````````````8.P("```
M```````````````````````````````````!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$"`@("`@("
M`@("`@("`@("`@("`@("`@("`@("`@("`@,#`P,#`P,#`P,#`P,#`P,$!`0$
M!`0$!`4%!04&!@$!`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1YN;FYN;FYN;FYN;FYN;FYN;FYN;FZ-S<W-SH
MV-S<W-S<RLK<W-S<RLK<W-S<W-S<W-S<W`$!`0$!W-S<W.;FYN;FYN;F\.;<
MW-SFYN;<W```````````````````````ZNKIYN;FYN;FYN;FYN;FY@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MYN;FY@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MW.;FYN;<YN;FWMSFYN;FYN8`W-S<W-SFYMSFYM[DY@H+#`T.#Q`1$A,`%!46
M`!<`&!D`Y@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````&QP='A\@(2+FYMP``````````````````````````````````",`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````.;FYN;FYN8``.;FYN;<Y@``YN8`W.;FW```````````````
M````````````````````````````````)```````````````````````````
M`````````````.;<YN;<YN;<W-SFW-SFW.;FYMSFW.;<YMSFY@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````'``````````````````````D```#FW.;F````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``<`````````````````````"0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````!P``````
M```````````````)````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````'````````````````
M``````D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````<`````````````````````"0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````)````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````D`````````5%L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````"0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````)````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````9V<)`````````````````&MK:VL`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!V=@``````````````````>GIZ>@``````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#<W```````````````````````````
M`````````-P`W`#8````````````````````````````````````````````
M`````````````````````````````(&"`(0``````(*"@H(``((`YN8)`.;F
M````````````````````````````````````````````````````````````
M``````````````````````#<````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````<`"0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````"0``````````
M```````````````````````````````)````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````Y```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````.;F`0'FYN;F`0$!YN8`````Y@````$!YMSF`0``
M````````````````````````````````````````````````````````````
M`````````````````````-KDZ-[@X```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````@(````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````:````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#FYN;F````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````V-@!`0$```#BV-C8
MV-@``````````-S<W-S<W-S<``#FYN;FYMS<````````````````````````
M````````````````YN;FY@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````$0`1`!$```$``@`#``0``!$%``8`!P`(``D`"@`+``P``!$`
M$0`1`!$`$0`1#0`.```1`!$`$0`1`!$`$0`1#P``$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$0```1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1$0``$0`1$@``$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$3```1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1`!$`$0`1
M`!$`$0`````````````@`"#,B`!A`"#,A``R`#,`(,R!`,Z\`"#,IP`Q`&\`
M,>*!A#0`,>*!A#(`,^*!A#0`0<R``$',@0!!S((`0<R#`$',B`!!S(H`0\RG
M`$7,@`!%S($`1<R"`$7,B`!)S(``2<R!`$G,@@!)S(@`3LR#`$_,@`!/S($`
M3\R"`$_,@P!/S(@`5<R``%7,@0!5S((`5<R(`%G,@0!AS(``8<R!`&',@@!A
MS(,`8<R(`&',B@!CS*<`9<R``&7,@0!ES((`9<R(`&G,@`!IS($`:<R"`&G,
MB`!NS(,`;\R``&_,@0!OS((`;\R#`&_,B`!US(``=<R!`'7,@@!US(@`><R!
M`'G,B`!!S(0`8<R$`$',A@!AS(8`0<RH`&',J`!#S($`8\R!`$/,@@!CS((`
M0\R'`&/,AP!#S(P`8\R,`$3,C`!DS(P`1<R$`&7,A`!%S(8`9<R&`$7,AP!E
MS(<`1<RH`&7,J`!%S(P`9<R,`$?,@@!GS((`1\R&`&?,A@!'S(<`9\R'`$?,
MIP!GS*<`2,R"`&C,@@!)S(,`:<R#`$G,A`!IS(0`2<R&`&G,A@!)S*@`:<RH
M`$G,AP!)2@!I:@!*S((`:LR"`$O,IP!KS*<`3,R!`&S,@0!,S*<`;,RG`$S,
MC`!LS(P`3,*W`&S"MP!.S($`;LR!`$[,IP!NS*<`3LR,`&[,C`#*O&X`3\R$
M`&_,A`!/S(8`;\R&`$_,BP!OS(L`4LR!`'+,@0!2S*<`<LRG`%+,C`!RS(P`
M4\R!`'/,@0!3S((`<\R"`%/,IP!SS*<`4\R,`'/,C`!4S*<`=,RG`%3,C`!T
MS(P`5<R#`'7,@P!5S(0`=<R$`%7,A@!US(8`5<R*`'7,B@!5S(L`=<R+`%7,
MJ`!US*@`5\R"`'?,@@!9S((`><R"`%G,B`!:S($`>LR!`%K,AP!ZS(<`6LR,
M`'K,C`!S`$_,FP!OS)L`5<R;`'7,FP!$6LR,`$1ZS(P`9'K,C`!,2@!,:@!L
M:@!.2@!.:@!N:@!!S(P`8<R,`$G,C`!IS(P`3\R,`&_,C`!5S(P`=<R,`%7,
MB,R$`'7,B,R$`%7,B,R!`'7,B,R!`%7,B,R,`'7,B,R,`%7,B,R``'7,B,R`
M`$',B,R$`&',B,R$`$',A\R$`&',A\R$`,.&S(0`PZ;,A`!'S(P`9\R,`$O,
MC`!KS(P`3\RH`&_,J`!/S*C,A`!OS*C,A`#&M\R,`,J2S(P`:LR,`$1:`$1Z
M`&1Z`$?,@0!GS($`3LR``&[,@`!!S(K,@0!AS(K,@0##ALR!`,.FS($`PYC,
M@0##N,R!`$',CP!AS(\`0<R1`&',D0!%S(\`9<R/`$7,D0!ES)$`2<R/`&G,
MCP!)S)$`:<R1`$_,CP!OS(\`3\R1`&_,D0!2S(\`<LR/`%+,D0!RS)$`5<R/
M`'7,CP!5S)$`=<R1`%/,I@!SS*8`5,RF`'3,I@!(S(P`:,R,`$',AP!AS(<`
M1<RG`&7,IP!/S(C,A`!OS(C,A`!/S(/,A`!OS(/,A`!/S(<`;\R'`$_,A\R$
M`&_,A\R$`%G,A`!YS(0`:`#)I@!J`'(`R;D`R;L`RH$`=P!Y`"#,A@`@S(<`
M(,R*`"#,J``@S(,`(,R+`,FC`&P`>`#*E0#,@`#,@0#,DP#,B,R!`,JY`"#-
MA0`[`,*HS($`(,R(S($`SI',@0#"MP#.E<R!`,Z7S($`SIG,@0#.G\R!`,ZE
MS($`SJG,@0#.N<R(S($`SIG,B`#.I<R(`,ZQS($`SK7,@0#.M\R!`,ZYS($`
MSX7,B,R!`,ZYS(@`SX7,B`#.O\R!`,^%S($`SXG,@0#.L@#.N`#.I0#/DLR!
M`,^2S(@`SX8`SX``SKH`SX$`SX(`SI@`SK4`T)7,@`#0E<R(`-"3S($`T(;,
MB`#0FLR!`-"8S(``T*/,A@#0F,R&`-"XS(8`T+7,@`#0M<R(`-"SS($`T9;,
MB`#0NLR!`-"XS(``T8/,A@#1M,R/`-&US(\`T);,A@#0MLR&`-"0S(8`T+#,
MA@#0D,R(`-"PS(@`T)7,A@#0M<R&`-.8S(@`TYG,B`#0ELR(`-"VS(@`T)?,
MB`#0M\R(`-"8S(0`T+C,A`#0F,R(`-"XS(@`T)[,B`#0OLR(`-.HS(@`TZG,
MB`#0K<R(`-&-S(@`T*/,A`#1@\R$`-"CS(@`T8/,B`#0H\R+`-&#S(L`T*?,
MB`#1A\R(`-"KS(@`T8O,B`#5I=:"`-BGV9,`V*?9E`#9B-F4`-BGV94`V8K9
ME`#8I]FT`-F(V;0`VX?9M`#9BMFT`-N5V90`VX'9E`#;DMF4`."DJ."DO`#@
MI+#@I+P`X*2SX*2\`."DE>"DO`#@I);@I+P`X*27X*2\`."DG."DO`#@I*'@
MI+P`X*2BX*2\`."DJ^"DO`#@I*_@I+P`X*>'X*:^`."GA^"GEP#@IJ'@IKP`
MX*:BX*:\`."FK^"FO`#@J++@J+P`X*BXX*B\`."HEN"HO`#@J)?@J+P`X*B<
MX*B\`."HJ^"HO`#@K8?@K98`X*V'X*R^`."MA^"MEP#@K*'@K+P`X*RBX*R\
M`."NDN"OEP#@KX;@KKX`X*^'X*Z^`."OAN"OEP#@L8;@L98`X+*_X+.5`."S
MAN"SE0#@LX;@LY8`X+.&X+."`."SAN"S@N"SE0#@M8;@M+X`X+6'X+2^`."U
MAN"UEP#@MYG@MXH`X+>9X+>/`."WF>"WC^"WB@#@MYG@MY\`X+F-X+BR`."[
MC>"ZL@#@NJO@NID`X+JKX+JA`."\BP#@O8+@OK<`X+V,X+ZW`."]D>"^MP#@
MO9;@OK<`X+V;X+ZW`."]@."^M0#@O;'@O;(`X+VQX+VT`."^LN"^@`#@OK+@
MO;'@OH``X+ZSX+Z``."^L^"]L>"^@`#@O;'@OH``X+Z2X+ZW`."^G."^MP#@
MOJ'@OK<`X+ZFX+ZW`."^J^"^MP#@OI#@OK4`X8"EX8"N`$',I0!AS*4`0LR'
M`&+,AP!"S*,`8LRC`$+,L0!BS+$`0\RGS($`8\RGS($`1,R'`&3,AP!$S*,`
M9,RC`$3,L0!DS+$`1,RG`&3,IP!$S*T`9,RM`$7,A,R``&7,A,R``$7,A,R!
M`&7,A,R!`$7,K0!ES*T`1<RP`&7,L`!%S*?,A@!ES*?,A@!&S(<`9LR'`$?,
MA`!GS(0`2,R'`&C,AP!(S*,`:,RC`$C,B`!HS(@`2,RG`&C,IP!(S*X`:,RN
M`$G,L`!IS+``2<R(S($`:<R(S($`2\R!`&O,@0!+S*,`:\RC`$O,L0!KS+$`
M3,RC`&S,HP!,S*/,A`!LS*/,A`!,S+$`;,RQ`$S,K0!LS*T`3<R!`&W,@0!-
MS(<`;<R'`$W,HP!MS*,`3LR'`&[,AP!.S*,`;LRC`$[,L0!NS+$`3LRM`&[,
MK0!/S(/,@0!OS(/,@0!/S(/,B`!OS(/,B`!/S(3,@`!OS(3,@`!/S(3,@0!O
MS(3,@0!0S($`<,R!`%#,AP!PS(<`4LR'`'+,AP!2S*,`<LRC`%+,H\R$`'+,
MH\R$`%+,L0!RS+$`4\R'`'/,AP!3S*,`<\RC`%/,@<R'`'/,@<R'`%/,C,R'
M`'/,C,R'`%/,H\R'`'/,H\R'`%3,AP!TS(<`5,RC`'3,HP!4S+$`=,RQ`%3,
MK0!TS*T`5<RD`'7,I`!5S+``=<RP`%7,K0!US*T`5<R#S($`=<R#S($`5<R$
MS(@`=<R$S(@`5LR#`';,@P!6S*,`=LRC`%?,@`!WS(``5\R!`'?,@0!7S(@`
M=\R(`%?,AP!WS(<`5\RC`'?,HP!8S(<`>,R'`%C,B`!XS(@`6<R'`'G,AP!:
MS((`>LR"`%K,HP!ZS*,`6LRQ`'K,L0!HS+$`=,R(`'?,B@!YS(H`8<J^`,6_
MS(<`0<RC`&',HP!!S(D`8<R)`$',@LR!`&',@LR!`$',@LR``&',@LR``$',
M@LR)`&',@LR)`$',@LR#`&',@LR#`$',H\R"`&',H\R"`$',ALR!`&',ALR!
M`$',ALR``&',ALR``$',ALR)`&',ALR)`$',ALR#`&',ALR#`$',H\R&`&',
MH\R&`$7,HP!ES*,`1<R)`&7,B0!%S(,`9<R#`$7,@LR!`&7,@LR!`$7,@LR`
M`&7,@LR``$7,@LR)`&7,@LR)`$7,@LR#`&7,@LR#`$7,H\R"`&7,H\R"`$G,
MB0!IS(D`2<RC`&G,HP!/S*,`;\RC`$_,B0!OS(D`3\R"S($`;\R"S($`3\R"
MS(``;\R"S(``3\R"S(D`;\R"S(D`3\R"S(,`;\R"S(,`3\RCS((`;\RCS((`
M3\R;S($`;\R;S($`3\R;S(``;\R;S(``3\R;S(D`;\R;S(D`3\R;S(,`;\R;
MS(,`3\R;S*,`;\R;S*,`5<RC`'7,HP!5S(D`=<R)`%7,F\R!`'7,F\R!`%7,
MF\R``'7,F\R``%7,F\R)`'7,F\R)`%7,F\R#`'7,F\R#`%7,F\RC`'7,F\RC
M`%G,@`!YS(``6<RC`'G,HP!9S(D`><R)`%G,@P!YS(,`SK',DP#.L<R4`,ZQ
MS)/,@`#.L<R4S(``SK',D\R!`,ZQS)3,@0#.L<R3S8(`SK',E,V"`,Z1S),`
MSI',E`#.D<R3S(``SI',E,R``,Z1S)/,@0#.D<R4S($`SI',D\V"`,Z1S)3-
M@@#.M<R3`,ZUS)0`SK7,D\R``,ZUS)3,@`#.M<R3S($`SK7,E,R!`,Z5S),`
MSI7,E`#.E<R3S(``SI7,E,R``,Z5S)/,@0#.E<R4S($`SK?,DP#.M\R4`,ZW
MS)/,@`#.M\R4S(``SK?,D\R!`,ZWS)3,@0#.M\R3S8(`SK?,E,V"`,Z7S),`
MSI?,E`#.E\R3S(``SI?,E,R``,Z7S)/,@0#.E\R4S($`SI?,D\V"`,Z7S)3-
M@@#.N<R3`,ZYS)0`SKG,D\R``,ZYS)3,@`#.N<R3S($`SKG,E,R!`,ZYS)/-
M@@#.N<R4S8(`SIG,DP#.F<R4`,Z9S)/,@`#.F<R4S(``SIG,D\R!`,Z9S)3,
M@0#.F<R3S8(`SIG,E,V"`,Z_S),`SK_,E`#.O\R3S(``SK_,E,R``,Z_S)/,
M@0#.O\R4S($`SI_,DP#.G\R4`,Z?S)/,@`#.G\R4S(``SI_,D\R!`,Z?S)3,
M@0#/A<R3`,^%S)0`SX7,D\R``,^%S)3,@`#/A<R3S($`SX7,E,R!`,^%S)/-
M@@#/A<R4S8(`SJ7,E`#.I<R4S(``SJ7,E,R!`,ZES)3-@@#/B<R3`,^)S)0`
MSXG,D\R``,^)S)3,@`#/B<R3S($`SXG,E,R!`,^)S)/-@@#/B<R4S8(`SJG,
MDP#.J<R4`,ZIS)/,@`#.J<R4S(``SJG,D\R!`,ZIS)3,@0#.J<R3S8(`SJG,
ME,V"`,ZQS(``SK7,@`#.M\R``,ZYS(``SK_,@`#/A<R``,^)S(``SK',D\V%
M`,ZQS)3-A0#.L<R3S(#-A0#.L<R4S(#-A0#.L<R3S('-A0#.L<R4S('-A0#.
ML<R3S8+-A0#.L<R4S8+-A0#.D<R3S84`SI',E,V%`,Z1S)/,@,V%`,Z1S)3,
M@,V%`,Z1S)/,@<V%`,Z1S)3,@<V%`,Z1S)/-@LV%`,Z1S)3-@LV%`,ZWS)/-
MA0#.M\R4S84`SK?,D\R`S84`SK?,E,R`S84`SK?,D\R!S84`SK?,E,R!S84`
MSK?,D\V"S84`SK?,E,V"S84`SI?,D\V%`,Z7S)3-A0#.E\R3S(#-A0#.E\R4
MS(#-A0#.E\R3S('-A0#.E\R4S('-A0#.E\R3S8+-A0#.E\R4S8+-A0#/B<R3
MS84`SXG,E,V%`,^)S)/,@,V%`,^)S)3,@,V%`,^)S)/,@<V%`,^)S)3,@<V%
M`,^)S)/-@LV%`,^)S)3-@LV%`,ZIS)/-A0#.J<R4S84`SJG,D\R`S84`SJG,
ME,R`S84`SJG,D\R!S84`SJG,E,R!S84`SJG,D\V"S84`SJG,E,V"S84`SK',
MA@#.L<R$`,ZQS(#-A0#.L<V%`,ZQS('-A0#.L<V"`,ZQS8+-A0#.D<R&`,Z1
MS(0`SI',@`#.D<V%`"#,DP#.N0`@S8(`PJC-@@`@S(C-@@#.M\R`S84`SK?-
MA0#.M\R!S84`SK?-@@#.M\V"S84`SI7,@`#.E\R``,Z7S84`X;Z_S(``(,R3
MS(``X;Z_S($`(,R3S($`X;Z_S8(`(,R3S8(`SKG,A@#.N<R$`,ZYS(C,@`#.
MN<V"`,ZYS(C-@@#.F<R&`,Z9S(0`SIG,@`#AO[[,@``@S)3,@`#AO[[,@0`@
MS)3,@0#AO[[-@@`@S)3-@@#/A<R&`,^%S(0`SX7,B,R``,^!S),`SX',E`#/
MA<V"`,^%S(C-@@#.I<R&`,ZES(0`SJ7,@`#.H<R4`,*HS(``(,R(S(``8`#/
MB<R`S84`SXG-A0#/B<R!S84`SXG-@@#/B<V"S84`SI_,@`#.J<R``,ZIS84`
MPK0`(,R4`.*`@@#B@(,`XH"0`"#,LP`N`"XN`"XN+@#B@++B@+(`XH"RXH"R
MXH"R`.*`M>*`M0#B@+7B@+7B@+4`(2$`(,R%`#\_`#\A`"$_`.*`LN*`LN*`
MLN*`L@`P`&D`-``U`#8`-P`X`#D`*P#BB)(`/0`H`"D`;@!2<P!A+V,`82]S
M`$,`PK!#`&,O;P!C+W4`QI``PK!&`&<`2`#$IP!)`$P`3@!.;P!0`%$`4@!3
M30!414P`5$T`6@#.J0!+`$(`90!%`$8`30#7D`#7D0#7D@#7DP#.LP#.DP#.
MH`#BB)$`1`!D`#'B@80S`#+B@80S`#'B@80U`#+B@80U`#/B@80U`#3B@80U
M`#'B@80V`#7B@80V`#'B@80X`#/B@80X`#7B@80X`#?B@80X`#'B@80`24D`
M24E)`$E6`%8`5DD`5DE)`%9)24D`25@`6`!820!824D`:6D`:6EI`&EV`'8`
M=FD`=FEI`'9I:6D`:7@`>&D`>&EI`&,`;0#BAI#,N`#BAI+,N`#BAI3,N`#B
MAY#,N`#BAY3,N`#BAY+,N`#BB(/,N`#BB(C,N`#BB(O,N`#BB*/,N`#BB*7,
MN`#BB*OBB*L`XHBKXHBKXHBK`.*(KN*(K@#BB*[BB*[BB*X`XHB\S+@`XHF#
MS+@`XHF%S+@`XHF(S+@`/<RX`.*)H<RX`.*)C<RX`#S,N``^S+@`XHFDS+@`
MXHFES+@`XHFRS+@`XHFSS+@`XHFVS+@`XHFWS+@`XHFZS+@`XHF[S+@`XHJ"
MS+@`XHJ#S+@`XHJ&S+@`XHJ'S+@`XHJBS+@`XHJHS+@`XHJIS+@`XHJKS+@`
MXHF\S+@`XHF]S+@`XHJ1S+@`XHJ2S+@`XHJRS+@`XHJSS+@`XHJTS+@`XHJU
MS+@`XX"(`..`B0`Q,``Q,0`Q,@`Q,P`Q-``Q-0`Q-@`Q-P`Q.``Q.0`R,``H
M,2D`*#(I`"@S*0`H-"D`*#4I`"@V*0`H-RD`*#@I`"@Y*0`H,3`I`"@Q,2D`
M*#$R*0`H,3,I`"@Q-"D`*#$U*0`H,38I`"@Q-RD`*#$X*0`H,3DI`"@R,"D`
M,2X`,BX`,RX`-"X`-2X`-BX`-RX`."X`.2X`,3`N`#$Q+@`Q,BX`,3,N`#$T
M+@`Q-2X`,38N`#$W+@`Q."X`,3DN`#(P+@`H82D`*&(I`"AC*0`H9"D`*&4I
M`"AF*0`H9RD`*&@I`"AI*0`H:BD`*&LI`"AL*0`H;2D`*&XI`"AO*0`H<"D`
M*'$I`"AR*0`H<RD`*'0I`"AU*0`H=BD`*'<I`"AX*0`H>2D`*'HI`$$`1P!*
M`$\`4P!4`%4`5P!9`&(`9@!K`'``<0!T`'4`>@#BB*OBB*OBB*OBB*L`.CH]
M`#T]`#T]/0#BJYW,N`#FKXT`Z;Z?`.2X@`#DN*@`Y+BV`.2XOP#DN9D`Y+J%
M`.2ZC`#DNJ``Y+JZ`.6$OP#EA:4`Y86K`.6&@@#EAI8`Y8:K`.6'H`#EA[4`
MY8B``.6*FP#EB[D`Y8R5`.6,F@#EC+@`Y8V!`.6-G`#EC:D`Y8Z"`.6.M@#E
MCX@`Y8^C`.6;EP#EG)\`Y:.K`.6D@@#EI(H`Y:25`.6DIP#EI;,`Y:V0`.6N
M@`#EK[@`Y;"/`.6PH@#EL+@`Y;&N`.6QL0#EMYL`Y;>E`.6WL0#EM[X`Y;FR
M`.6YN@#EN;\`Y;NT`.6[O@#EO(L`Y;R3`.6]D`#EO:$`Y;VS`.6_@P#FB(@`
MYHBV`.:)BP#FE*\`YI2T`.:6AP#FEI<`YI:D`.:6N0#FEZ``YI>E`.:;L`#F
MG(@`YIRH`.:LH`#FK:(`YJVY`.:NLP#FKXL`YJ^4`.:OFP#FL(\`YK"4`.:P
MM`#G@:L`YXBJ`.>(M@#GB+L`YXB_`.>)AP#GB9D`YXF;`.>*K`#GCH0`YXZ)
M`.>3G`#GDZ8`YY28`.>4GP#GE*@`YY2P`.>6BP#GEI(`YYFV`.>9O0#GFJX`
MYYJ_`.>;K@#GGYL`YY^B`.>?LP#GI+H`YZ:X`.>FO@#GJ;0`YZN+`.>KN0#G
ML;,`Y[.X`.>\M@#GO9$`Y[Z*`.>^O0#H@($`Z(",`.B`D@#H@+,`Z(&_`.B"
MB0#HAZ,`Z(>J`.B'LP#HA[P`Z(B,`.B(FP#HB)\`Z(FN`.B)L@#HB;@`Z)F-
M`.B9JP#HH8``Z*&,`.BAHP#HI;X`Z*:+`.BGD@#HJ(``Z+"W`.BQA@#HL94`
MZ+&X`.BRG0#HM:0`Z+6P`.BVLP#HNJL`Z+N*`.B^FP#HOK``Z+ZU`.F"D0#I
MA8D`Z8>&`.F'C`#IAY$`Z96W`.F6@`#IF)P`Z9JV`.F:N0#IFZ@`Z9V1`.F=
MG@#IG:(`Z9VI`.F?BP#IGZT`Z9^S`.F@@0#IHJ@`Z:.;`.FCGP#III8`Z::9
M`.FFK`#IJJ@`Z:N8`.FKGP#IK*4`Z:RO`.FLL@#IK+P`Z:V:`.FSI0#IN;4`
MZ;F_`.FZI0#INKL`Z;N#`.F[C0#INY$`Z;NY`.F[O0#IO(X`Z;R3`.F\H`#I
MO+L`Z;V*`.F]D@#IOHT`Z;Z<`.F^H`#C@)(`Y8V$`.6-A0#C@8OC@ID`XX&-
MXX*9`..!C^."F0#C@9'C@ID`XX&3XX*9`..!E>."F0#C@9?C@ID`XX&9XX*9
M`..!F^."F0#C@9WC@ID`XX&?XX*9`..!H>."F0#C@:3C@ID`XX&FXX*9`..!
MJ.."F0#C@:_C@ID`XX&OXX*:`..!LN."F0#C@;+C@IH`XX&UXX*9`..!M>."
MF@#C@;CC@ID`XX&XXX*:`..!N^."F0#C@;OC@IH`XX&&XX*9`"#C@ID`(.."
MF@#C@IWC@ID`XX*(XX**`.."J^."F0#C@JWC@ID`XX*OXX*9`.."L>."F0#C
M@K/C@ID`XX*UXX*9`.."M^."F0#C@KGC@ID`XX*[XX*9`.."O>."F0#C@K_C
M@ID`XX.!XX*9`..#A.."F0#C@X;C@ID`XX.(XX*9`..#C^."F0#C@X_C@IH`
MXX.2XX*9`..#DN."F@#C@Y7C@ID`XX.5XX*:`..#F.."F0#C@YCC@IH`XX.;
MXX*9`..#F^."F@#C@J;C@ID`XX.OXX*9`..#L.."F0#C@['C@ID`XX.RXX*9
M`..#O>."F0#C@K/C@X@`X82``.&$@0#AAJH`X82"`.&&K`#AAJT`X82#`.&$
MA`#AA(4`X8:P`.&&L0#AAK(`X8:S`.&&M`#AAK4`X82:`.&$A@#AA(<`X82(
M`.&$H0#AA(D`X82*`.&$BP#AA(P`X82-`.&$C@#AA(\`X820`.&$D0#AA)(`
MX86A`.&%H@#AA:,`X86D`.&%I0#AA:8`X86G`.&%J`#AA:D`X86J`.&%JP#A
MA:P`X86M`.&%K@#AA:\`X86P`.&%L0#AA;(`X86S`.&%M`#AA;4`X86@`.&$
ME`#AA)4`X8>'`.&'B`#AAXP`X8>.`.&'DP#AAY<`X8>9`.&$G`#AAYT`X8>?
M`.&$G0#AA)X`X82@`.&$H@#AA*,`X82G`.&$J0#AA*L`X82L`.&$K0#AA*X`
MX82O`.&$L@#AA+8`X86``.&%AP#AA8P`X8>Q`.&'L@#AA9<`X868`.&%F0#A
MAH0`X8:%`.&&B`#AAI$`X8:2`.&&E`#AAIX`X8:A`.2XB0#EFYL`Y+B*`.2X
MK0#DN(L`YY2R`.2XF0#DN($`Y:2I`.6<L``HX82`*0`HX82"*0`HX82#*0`H
MX82%*0`HX82&*0`HX82'*0`HX82)*0`HX82+*0`HX82,*0`HX82.*0`HX82/
M*0`HX820*0`HX821*0`HX822*0`HX82`X86A*0`HX82"X86A*0`HX82#X86A
M*0`HX82%X86A*0`HX82&X86A*0`HX82'X86A*0`HX82)X86A*0`HX82+X86A
M*0`HX82,X86A*0`HX82.X86A*0`HX82/X86A*0`HX820X86A*0`HX821X86A
M*0`HX822X86A*0`HX82,X86N*0`HY+B`*0`HY+J,*0`HY+B)*0`HY9N;*0`H
MY+J4*0`HY86M*0`HY+B#*0`HY86K*0`HY+F=*0`HY8V!*0`HYIR(*0`HYX&K
M*0`HYK"T*0`HYIRH*0`HZ8>1*0`HY9R?*0`HYI>E*0`HYJ"J*0`HYIR)*0`H
MYZ2^*0`HY9"-*0`HYXFY*0`HZ+*A*0`HYZ6=*0`HY8JT*0`HY+NC*0`HY9&\
M*0`HY:VF*0`HYYNC*0`HY+R!*0`HZ+.'*0`HY8V4*0`HYZ6M*0`HY+R1*0`H
MZ(>J*0`HZ(>S*0`R,0`R,@`R,P`R-``R-0`R-@`R-P`R.``R.0`S,``S,0`S
M,@`S,P`S-``S-0#AA(#AA:$`X82"X86A`.&$@^&%H0#AA(7AA:$`X82&X86A
M`.&$A^&%H0#AA(GAA:$`X82+X86A`.&$C.&%H0#AA([AA:$`X82/X86A`.&$
MD.&%H0#AA)'AA:$`X822X86A`.2ZE`#EA:T`Y+B#`.2YG0#FH*H`YIR)`.>D
MO@#ED(T`YXFY`.BRH0#GI9T`Y8JT`.>GF`#GE+<`Z8&I`.6$J@#EC;``YK.H
M`.F@A0#DO)$`Y8:9`.:MHP#EMZ8`Y8^S`.6,NP#EKI<`Y:VF`.>;HP#DO($`
MZ+.'`.6-E`#EI)P`,S8`,S<`,S@`,SD`-#``-#$`-#(`-#,`-#0`-#4`-#8`
M-#<`-#@`-#D`-3``,>:<B``RYIR(`#/FG(@`-.:<B``UYIR(`#;FG(@`-^:<
MB``XYIR(`#GFG(@`,3#FG(@`,3'FG(@`,3+FG(@`XX*B`.."I`#C@J8`XX*H
M`.."J@#C@JL`XX*M`.."KP#C@K$`XX*S`.."M0#C@K<`XX*Y`.."NP#C@KT`
MXX*_`..#@0#C@X0`XX.&`..#B`#C@XH`XX.+`..#C`#C@XT`XX..`..#CP#C
M@Y(`XX.5`..#F`#C@YL`XX.>`..#GP#C@Z``XX.A`..#H@#C@Z0`XX.F`..#
MJ`#C@ZD`XX.J`..#JP#C@ZP`XX.M`..#KP#C@[``XX.Q`..#L@#C@J+C@X_C
M@IKC@[SC@X@`XX*BXX.KXX.5XX*A`.."HN.#L^.#F.."FN."H@#C@J+C@[SC
M@ZL`XX*DXX.+XX.SXX*OXX*9`.."I..#L^.#@0#C@J;C@JGC@[,`XX*HXX*Y
MXX*OXX.\XX.(XX*9`.."J..#O.."J^.#O`#C@JKC@[/C@KD`XX*JXX.\XX.@
M`.."J^."I..#J@#C@JOC@ZGC@X/C@X@`XX*KXX.MXX.JXX.\`.."J^."F>.#
MK>.#LP#C@JOC@IGC@[/C@YX`XX*MXX*9XX*KXX*9`.."K>."F>.#B^.#O`#C
M@JWC@Z7C@ZKC@[P`XX*MXX*9XX.KXX*_XX*9XX.\`.."K>.#K0#C@JWC@ZWC
M@J_C@IGC@ZGC@Z``XX*MXX.MXX.AXX.\XX.(XX.K`.."K>.#K>.#K^.#@^.#
MB`#C@J_C@IGC@ZGC@Z``XX*OXX*9XX.IXX.@XX.(XX.S`.."K^.#J^."N^."
MF>."I..#K0#C@J_C@ZWC@[SC@XT`XX*QXX.\XX*Y`.."L^.#J^.#B@#C@K/C
M@[SC@YOC@IH`XX*UXX*DXX*OXX.K`.."M>.#L^.#@>.#O..#H`#C@K?C@ZKC
M@[/C@J_C@ID`XX*[XX.SXX.!`.."N^.#L^.#B`#C@K_C@IGC@[SC@KD`XX.&
MXX*9XX*W`..#B.."F>.#JP#C@XCC@[,`XX.*XX..`..#CN.#@^.#B`#C@X_C
M@J3C@X0`XX./XX*:XX.\XX*[XX.SXX.(`..#C^."FN.#O..#A`#C@X_C@IGC
M@[SC@ZSC@ZL`XX.2XX*:XX*BXX*YXX.(XX.K`..#DN."FN."K^.#JP#C@Y+C
M@IKC@K,`XX.2XX*9XX.K`..#E>."H>.#J>.#@^.#B.."F0#C@Y7C@J/C@[SC
M@X@`XX.5XX*9XX.#XX*WXX*GXX.K`..#E>.#J>.#LP#C@YCC@J_C@K_C@[SC
M@ZL`XX.8XX*:XX*]`..#F.."FN.#B^.#D@#C@YCC@ZOC@X0`XX.8XX*:XX.S
MXX*Y`..#F.."FN.#O.."M^."F0#C@YCC@IGC@[SC@K\`XX.;XX*:XX*DXX.S
MXX.(`..#F^."F>.#J^.#B`#C@YOC@[,`XX.;XX*:XX.SXX.(XX*9`..#F^.#
MO..#JP#C@YOC@[SC@[,`XX.>XX*DXX*OXX.M`..#GN."I..#JP#C@Y[C@X/C
M@X\`XX.>XX.KXX*O`..#GN.#L^."M^.#I^.#LP#C@Y_C@J_C@ZWC@[,`XX.?
MXX.J`..#G^.#JN.#C^."F>.#O..#JP#C@Z'C@JOC@ID`XX.AXX*KXX*9XX.(
MXX.S`..#H>.#O..#B..#JP#C@Z3C@[SC@XCC@ID`XX.DXX.\XX.K`..#IN."
MHN.#LP#C@ZKC@X/C@XCC@ZL`XX.JXX.I`..#J^.#DN."FN.#O`#C@ZOC@[SC
M@Y7C@IGC@ZL`XX.LXX.@`..#K..#L^.#B.."L>."F>.#LP#C@Z_C@X/C@X@`
M,.>"N0`QYX*Y`#+G@KD`,^>"N0`TYX*Y`#7G@KD`-N>"N0`WYX*Y`#CG@KD`
M.>>"N0`Q,.>"N0`Q,>>"N0`Q,N>"N0`Q,^>"N0`Q-.>"N0`Q->>"N0`Q-N>"
MN0`Q-^>"N0`Q..>"N0`Q.>>"N0`R,.>"N0`R,>>"N0`R,N>"N0`R,^>"N0`R
M-.>"N0!H4&$`9&$`054`8F%R`&]6`'!C`.6YL^:(D`#FF*WEDHP`Y:2GYJVC
M`.:8CN:RNP#FH*KEO(_DO)KGI+X`<$$`;D$`SKQ!`&U!`&M!`$M"`$U"`$="
M`&-A;`!K8V%L`'!&`&Y&`,Z\1@#.O&<`;6<`:V<`2'H`:TAZ`$U(>@!'2'H`
M5$AZ`,Z\;`!M;`!D;`!K;`!F;0!N;0#.O&T`;6T`8VT`:VT`;6TR`&-M,@!M
M,@!K;3(`;6TS`&-M,P!M,P!K;3,`;>*(E7,`;>*(E7,R`%!A`&M080!-4&$`
M1U!A`')A9`!R863BB)5S`')A9.*(E7,R`'!S`&YS`,Z\<P!M<P!P5@!N5@#.
MO%8`;58`:U8`358`<%<`;E<`SKQ7`&U7`&M7`$U7`&O.J0!-SJD`82YM+@!"
M<0!C8P!C9`!#XHB5:V<`0V\N`&1"`$=Y`&AA`$A0`&EN`$M+`$M-`&MT`&QM
M`&QN`&QO9P!L>`!M8@!M:6P`;6]L`%!(`'`N;2X`4%!-`%!2`'-R`%-V`%=B
M`#'FEZ4`,N:7I0`SYI>E`#3FEZ4`->:7I0`VYI>E`#?FEZ4`..:7I0`YYI>E
M`#$PYI>E`#$QYI>E`#$RYI>E`#$SYI>E`#$TYI>E`#$UYI>E`#$VYI>E`#$W
MYI>E`#$XYI>E`#$YYI>E`#(PYI>E`#(QYI>E`#(RYI>E`#(SYI>E`#(TYI>E
M`#(UYI>E`#(VYI>E`#(WYI>E`#(XYI>E`#(YYI>E`#,PYI>E`#,QYI>E`.BQ
MB`#FF[0`Z+.(`.:[D0#DN+(`Y8^E`.6ED0#EEH<`Y:6(`.:'M@#GF:D`Y[Z%
M`.B8OP#HGKH`Z*.X`.F"CP#FJ((`YK2;`.>#F0#GCYX`Z)"]`.F%J@#II[$`
MY+J"`.6-M0#FK(0`YXB;`.B8K0#IN)X`Y;60`.:_JP#HEXT`Z*6D`.:+B0#H
MAY@`Z*"?`.6[B@#FG)<`YK6J`.>+O`#I@XX`Y+Z&`.6&MP#EBYX`YI.$`.:K
MDP#GB)``YYNG`.B8A@#HF9P`Z+>O`.F<L@#IK:\`Z;>Z`.>BC`#GI;\`Y[:@
M`.B/B0#IC(0`Z*N6`.6CGP#EO(0`Y[&@`.B!O@#GB:(`YZ.*`.BS@@#IF[<`
MY:.8`.6QH@#FJ),`YK>:`.:\CP#GM*\`Y[BW`.F9BP#EBY(`Z(*+`.6'G`#E
MAXP`YZB<`.>VO@#HC[$`Z9FU`.BN@`#FBX\`Z*N^`.2XN0#EKZ<`YH"2`.>.
MAP#GE;``Y8R7`.>CNP#DOK\`Y;ZI`.2XC0#FLXP`YI6X`.>TH@#ECX,`Y:&>
M`.><@0#HD8D`Z*JJ`.:NN@#FLH@`YHN^`.B+I0#FCJ``YY6E`.2ZK@#EA:D`
MY8>)`.:B@0#GLZ<`Z(FO`.BKD@#IAX\`Y8NU`.61@@#ENZP`YI>%`.:_O@#G
MI*H`Z9:M`.FIJ@#INI<`Z;N.`.:;A@#FK;<`Z+VB`.6YM`#FAI``YHB``.:2
MF@#FO*,`YX6)`.>2B0#GIXH`Y[>T`.B!KP#HO*8`Z).N`.F`HP#IC8H`Y8B7
M`.6*HP#EDKT`YX.(`.BC@@#ENXD`Y;^U`.:-NP#FKJX`Y["^`.>-M0#DNZ0`
MY9NY`.6VN@#F@)P`YXZR`.>1J0#GOIH`Z(&&`.F(M`#IF[8`Z9V(`.F@F`#D
MOHL`YZ:N`.F&M`#IFK@`YH.A`.2ZA@#E@YH`Y:^N`.6POP#FEID`YX>.`.>9
M@@#HD[P`Z8&\`.::B`#IF*X`Y8J)`.:=NP#FG[,`YK6!`.:ZG`#GD(D`YY69
M`.>AJP#GM)``Z:&>`.:(K@#IF;@`Y8"K`.6TF0#FMZH`Z+RJ`.6^BP#FA80`
MYJ"7`.F:A@#EB*D`Y9"/`.6QI0#FF),`YIV.`.:BJ`#FLZ4`YY"&`.>7H@#G
MO;D`Z*./`.BCH0#IFZ(`Y8R_`.:ZN@#ED)T`YX>0`.>2F`#HE[H`Z9JC`.FQ
MEP#INI\`YIZ7`.:WBP#HAZ@`YZR@`.>RD@#GBX``YX*9`.BMF`#DNX``Z(RV
M`.6(N@#EB(<`Y;JF`.:+DP#GLY8`Y:Z%`.:TG@#FFK0`Z+R[`.F9C0#ENY,`
MY86``.67@`#EH9H`YIFT`.6'G@#GC*H`YYN*`.>DO`#GI9X`YZ6E`.>FCP#I
MG98`Y[*^`.B8D@#HJ[@`Z8"X`.F#O0#IHZ\`Z:.\`.FDJ`#IMK0`Y+ZN`.6#
MIP#EA8T`Y8N)`.6+I`#EC9$`Y9:=`.68A@#EF:@`Y:&``.6BJ`#EL:0`YH*4
M`.:%J`#FAHX`YH>R`.:5CP#FEZ(`YIJ1`.:BA0#FM;<`YKB:`.:\H@#GA:X`
MYXBK`.>0H@#GHI$`YZ6)`.>EB`#GI9``YZ66`.>FC0#GIHX`YZF``.>J@0#G
MKX``Y[B)`.>Y@0#GO;(`Z("%`.B'K0#HB;D`Z)&7`.BDD`#HII8`Z*R!`.BL
MN0#HLY,`Z+2(`.B^M@#IFZ,`Z9^_`.F@NP!F9@!F:0!F;`!F9FD`9F9L`'-T
M`-6TU;8`U;35I0#5M-6K`-6^U;8`U;35K0#7F=:T`->RUK<`UZ(`UY0`UYL`
MUYP`UYT`UZ@`UZH`UZG7@0#7J=>"`->IUKS7@0#7J=:\UX(`UY#6MP#7D-:X
M`->0UKP`UY'6O`#7DM:\`->3UKP`UY36O`#7E=:\`->6UKP`UYC6O`#7F=:\
M`->:UKP`UYO6O`#7G-:\`->>UKP`UZ#6O`#7H=:\`->CUKP`UZ36O`#7IM:\
M`->GUKP`UZC6O`#7J=:\`->JUKP`UY76N0#7D=:_`->;UK\`UZ36OP#7D-><
M`-FQ`-F[`-F^`-J``-FZ`-F_`-FY`-JD`-JF`-J$`-J#`-J&`-J'`-J-`-J,
M`-J.`-J(`-J8`-J1`-JI`-JO`-JS`-JQ`-JZ`-J[`-N!`-J^`-N2`-JM`-N'
M`-N&`-N(`-N+`-N%`-N)`-N0`-F)`-F*V938IP#9BMF4VY4`V8K9E-F(`-F*
MV93;AP#9BMF4VX8`V8K9E-N(`-F*V93;D`#9BMF4V8D`VXP`V8K9E-BL`-F*
MV938K0#9BMF4V84`V8K9E-F*`-BHV*P`V*C8K0#8J-BN`-BHV84`V*C9B0#8
MJ-F*`-BJV*P`V*K8K0#8JMBN`-BJV84`V*K9B0#8JMF*`-BKV*P`V*O9A0#8
MJ]F)`-BKV8H`V*S8K0#8K-F%`-BMV*P`V*W9A0#8KMBL`-BNV*T`V*[9A0#8
ML]BL`-BSV*T`V+/8K@#8L]F%`-BUV*T`V+79A0#8MMBL`-BVV*T`V+;8K@#8
MMMF%`-BWV*T`V+?9A0#8N-F%`-BYV*P`V+G9A0#8NMBL`-BZV84`V8'8K`#9
M@=BM`-F!V*X`V8'9A0#9@=F)`-F!V8H`V8+8K0#9@MF%`-F"V8D`V8+9B@#9
M@]BG`-F#V*P`V8/8K0#9@]BN`-F#V80`V8/9A0#9@]F)`-F#V8H`V838K`#9
MA-BM`-F$V*X`V839A0#9A-F)`-F$V8H`V878K`#9A=BM`-F%V*X`V879A0#9
MA=F)`-F%V8H`V8;8K`#9AMBM`-F&V*X`V8;9A0#9AMF)`-F&V8H`V8?8K`#9
MA]F%`-F'V8D`V8?9B@#9BMBL`-F*V*T`V8K8K@#9BMF%`-F*V8D`V8K9B@#8
ML-FP`-BQV;``V8G9L``@V8S9D0`@V8W9D0`@V8[9D0`@V8_9D0`@V9#9D0`@
MV9'9L`#9BMF4V+$`V8K9E-BR`-F*V939A@#8J-BQ`-BHV+(`V*C9A@#8JMBQ
M`-BJV+(`V*K9A@#8J]BQ`-BKV+(`V*O9A@#9A=BG`-F&V+$`V8;8L@#9AMF&
M`-F*V+$`V8K8L@#9BMF&`-F*V938K@#9BMF4V8<`V*C9AP#8JMF'`-BUV*X`
MV839AP#9AMF'`-F'V;``V8K9AP#8J]F'`-BSV8<`V+39A0#8M-F'`-F`V8[9
MD0#9@-F/V9$`V8#9D-F1`-BWV8D`V+?9B@#8N=F)`-BYV8H`V+K9B0#8NMF*
M`-BSV8D`V+/9B@#8M-F)`-BTV8H`V*W9B0#8K=F*`-BLV8D`V*S9B@#8KMF)
M`-BNV8H`V+79B0#8M=F*`-BVV8D`V+;9B@#8M-BL`-BTV*T`V+38K@#8M-BQ
M`-BSV+$`V+78L0#8MMBQ`-BGV8L`V*K8K-F%`-BJV*W8K`#8JMBMV84`V*K8
MKMF%`-BJV878K`#8JMF%V*T`V*K9A=BN`-BLV878K0#8K=F%V8H`V*W9A=F)
M`-BSV*W8K`#8L]BLV*T`V+/8K-F)`-BSV878K0#8L]F%V*P`V+/9A=F%`-BU
MV*W8K0#8M=F%V84`V+38K=F%`-BTV*S9B@#8M-F%V*X`V+39A=F%`-BVV*W9
MB0#8MMBNV84`V+?9A=BM`-BWV879A0#8M]F%V8H`V+G8K-F%`-BYV879A0#8
MN=F%V8D`V+K9A=F%`-BZV879B@#8NMF%V8D`V8'8KMF%`-F"V878K0#9@MF%
MV84`V838K=F%`-F$V*W9B@#9A-BMV8D`V838K-BL`-F$V*[9A0#9A-F%V*T`
MV878K=BL`-F%V*W9A0#9A=BMV8H`V878K-BM`-F%V*S9A0#9A=BNV*P`V878
MKMF%`-F%V*S8K@#9A]F%V*P`V8?9A=F%`-F&V*W9A0#9AMBMV8D`V8;8K-F%
M`-F&V*S9B0#9AMF%V8H`V8;9A=F)`-F*V879A0#8J-BNV8H`V*K8K-F*`-BJ
MV*S9B0#8JMBNV8H`V*K8KMF)`-BJV879B@#8JMF%V8D`V*S9A=F*`-BLV*W9
MB0#8K-F%V8D`V+/8KMF)`-BUV*W9B@#8M-BMV8H`V+;8K=F*`-F$V*S9B@#9
MA-F%V8H`V8K8K=F*`-F*V*S9B@#9BMF%V8H`V879A=F*`-F"V879B@#9AMBM
MV8H`V+G9A=F*`-F#V879B@#9AMBLV*T`V878KMF*`-F$V*S9A0#9@]F%V84`
MV*S8K=F*`-BMV*S9B@#9A=BLV8H`V8'9A=F*`-BHV*W9B@#8L]BNV8H`V8;8
MK-F*`-BUV83;D@#9@MF$VY(`V*?9A-F$V8<`V*?9@]BHV+$`V878K=F%V*\`
MV+79A-BYV84`V+'8L]F(V80`V+G9A-F*V8<`V8C8L]F$V84`V+79A-F)`-BU
MV839B2#8I]F$V839AR#8N=F$V8K9AR#9B-BSV839A0#8K-F$(-BLV838I]F$
MV8<`V+';C-BGV80`XH"4`.*`DP!?`'L`?0#C@)0`XX"5`..`D`#C@)$`XX"*
M`..`BP#C@(P`XX"-`..`C@#C@(\`+`#C@($`.@`_`"$`(P`F`"H`+0`\`#X`
M7``D`"4`0``@V8L`V8#9BP`@V8P`(-F-`"#9C@#9@-F.`"#9CP#9@-F/`"#9
MD`#9@-F0`"#9D0#9@-F1`"#9D@#9@-F2`-BA`-BG`-BH`-BI`-BJ`-BK`-BL
M`-BM`-BN`-BO`-BP`-BQ`-BR`-BS`-BT`-BU`-BV`-BW`-BX`-BY`-BZ`-F!
M`-F"`-F#`-F$`-F%`-F&`-F'`-F(`-F*`-F$V*?9DP#9A-BGV90`V838I]F5
M`-F$V*<`(@`G`"\`6P!=`%X`?`!^`.*FA0#BIH8`XX""`..#NP#C@J$`XX*C
M`.."I0#C@J<`XX*I`..#HP#C@Z4`XX.G`..#@P#C@[P`XX.S`.."F0#C@IH`
MPJ(`PJ,`PJP`PJ8`PJ4`XH*I`.*4@@#BAI``XH:1`.*&D@#BAI,`XI:@`.*7
MBP#PG867\)V%I0#PG868\)V%I0#PG868\)V%I?"=A:X`\)V%F/"=A:7PG86O
M`/"=A9CPG86E\)V%L`#PG868\)V%I?"=A;$`\)V%F/"=A:7PG86R`/"=AKGP
MG86E`/"=AKKPG86E`/"=AKGPG86E\)V%K@#PG8:Z\)V%I?"=A:X`\)V&N?"=
MA:7PG86O`/"=AKKPG86E\)V%KP#.D0#.D@#.E`#.E0#.E@#.EP#.F0#.F@#.
MFP#.G`#.G0#.G@#.GP#.H0#.HP#.I`#.I@#.IP#.J`#BB(<`SK$`SK0`SK8`
MSK<`SKL`SKT`SKX`SK\`SX,`SX0`SX4`SX<`SX@`SXD`XHB"`.2XO0#DN+@`
MY+F!`/"@A*(`Y+V@`.2^NP#E@((`Y8&Z`.6"F0#E@X\`XY*>`/"@F+H`Y864
M`.6%I`#EA;<`\*"4G`#CDKD`Y86G`.6&C0#PH)6+`.6&EP#EAJ0`Y+N,`.6&
MK`#EAK4`\*F'GP#EB(,`XY.?`.6(NP#EB88`Y8FR`.6)MP#CE)4`Y8N'`.6+
MN@#EC(4`Y8R&`.6-B0#EC9H`Y8VS`.6-O0#EC;\`\*"HK`#G@;``Y8^*`.6/
MGP#PH*VC`.6/JP#EC[$`Y9"&`.62G@#ED+@`Y9&(`.61J`#EDJ(`Y9.V`.64
MD`#EE9,`Y96C`.66A`#EEID`Y9:K`.66LP#EEX(`Y9R6`.6<EP#EF9$`Y9FT
M`.6CK@#EGXX`Y9^T`.6@C0#EGHL`Y:"R`.6@L0#EHJP`\*&3I`#EH[(`Y:.W
M`.6DA@#EI)H`Y:2B`.6EH@#PH9JH`/"AFZH`Y:>L`.6HFP#EJ*<`Y:>8`.6I
MI@#CFZX`\*&-J@#EK(@`Y:R^`/"AIX@`Y:^#`.6OF`#EK[,`\*&LF`#EK[\`
MY;"&`.6\LP#CGH$`Y;&@`.6S@`#ELHT`\*&WI`#EM8,`\*&WI@#EM:X`Y;6K
M`.6UO`#EMZ$`Y;>B`..@KP#EM[T`Y;BH`.6XO0#EN:D`XZ&B`/"BAH,`XZ&\
M`.6ZL`#ENK,`Y;JV`/"JCI(`\**,L0#HB($`Y;RB`..CAP#PHXJX`/"FAYH`
MY;VB`.6]JP#CHZ,`Y;Z:`.6_C0#EOY<`Y;^Y`.:"@0#CI+H`XZ2<`/"BFY0`
MYH.'`.:%B`#FA8P`YH6.`.:%N@#FAK(`YH:D`.:&KP#FAYX`YHB0`.:(FP#F
MB9T`YHJQ`.:+E`#FC9``\**LC`#FC+T`YHN\`.:-J`#FCH,`YH^D`/"BK[$`
MYI"B`.:/A0#FCJD`XZBN`.:1J0#FD;X`YI*=`.:1MP#CJ:P`YI6L`/"C@(H`
MYI>C`.:;N`#FF8D`XZR9`..LB`#CJZ0`Y8:2`.6&E0#FG(``YIJ<`.B"K0#D
MCYD`YIR;`.:<H0#FG9X`YIV3`/"CCX,`XZV)`.:?N@#FGH4`YJ&2`/"CD:T`
MYJ*.`.:@GP#FI)0`XZZ=`.:E@@#FIJ,`YJ>J`.:JJ`#PHYJC`.:KFP#CL)@`
MYJRA`/"CHJ<`YJV4`..QC@#FK;(`YJZ?`.:NNP#PHZJ-`/"AM(L`\*.KN@#F
ML8X`\*.RO`#FLK\`YK.-`.:QIP#FM)8`YK2^`.:UJ0#FM;@`YK:%`/"CM)X`
MYK2T`.:XKP#FN:X`X[2S`.:[BP#FNX<`\*.[D0#FM[D`YKVN`/"CO9X`\*.^
MC@#FOX8`YX"Y`.>`G@#G@)L`X[:6`.>!B@#G@;T`YX&W`.>"K0#PH)2E`.>%
MA0#PI(FC`.>&G`#DCJL`YXBH`.>(M0#GB9``\*28B`#GBH``YXJ5`/"DG+4`
M\*2@E`#GC;H`YXZ+`..ZK`#GCJ4`X[JX`.>1AP#GD9P`YY&Q`.>2A0#GDXH`
MX[R;`.>4I`#PI+"V`.>4O@#PI+*2`/"BAI\`YYB0`/"DOJ$`\*2^N`#PI8&$
M`.._O`#D@(@`YYNT`/"E@[,`\*6#L@#PI829`/"EA+,`YYR>`.><GP#GG8H`
MY("Y`.>>BP#D@88`Y(*6`/"ED)T`YZ&.`.>CC`#D@Z,`\*68I@#PI9J:`/"E
MFX4`YZ>K`.2$KP#GJ8H`YZF/`/"EI;P`\*6JIP#GJJX`Y(B"`/"EKJL`YZ^&
M`.>OB0#DB*<`\*6R@`#GLY(`Y(J@`.>SJ`#GLZ,`Y[2``/"EOH8`Y[6C`.2,
M@0#GMX<`Y[B"`.>YA0#DC+0`\*:(J`#PIHF'`.2-F0#PIHN9`.>]N@#PIHR^
M`.>^E0#GO[H`\*:3F@#PII2C`.B!H`#PII:H`.B!L`#PHXV?`.2/E0#H@K(`
MZ(2#`.20BP#HA+X`Y:JU`/"FGJ<`\*:>M0#PHXZ3`/"CCIP`Z(B$`.B^G@#D
MD:L`Z(J1`.B*BP#HBIT`Y8JS`.B*L0#HBK,`Z(J]`.B+I@#PIJR\`.B,G0#H
MC:,`Z(ZM`.B,HP#HCKT`Z(^G`.B-DP#HCXH`Z(^,`.B/G`#PIK"V`/"FM:L`
M\*:SE0#DE*L`Z).Q`.B3LP#HE)8`\*>/B@#HE:0`\*:\K`#DE9T`Y)6A`/"F
MOK$`\*>#D@#DE:L`Z)F0`.B9IP#HF:D`Z)JI`.B:B`#HG(X`Z)NB`.B=N0#H
MG*@`Z)VK`.B>A@#DM9<`Z)^A`.B@@0#DE[D`Z*&@`/"GF:<`Z*.7`.BCG@#D
MF+4`Z*.Z`..2NP#PIZ*N`/"GI:8`Y)J^`.2;AP#HJJ``Z*NM`.BNB@#PI[*H
M`.BRJP#HLX$`Z+2;`.BUMP#PI[RO`/"@H(0`Z+>+`.BVO`#HM[``\*"CG@#H
MNY0`Z+RX`/"HEY(`\*B7K0#I@I0`Z8.Q`.F$D0#PJ)RN`.F$FP#IB+@`Z8N7
M`.F+F`#IB;P`Z8^Y`.F0E0#PJ*^Z`.F6BP#DII4`Z9:W`/"HM;<`Y*>F`.F;
M@P#EMK(`Z9RC`/"IA84`\*F(F@#DJ:X`Y*FV`.F?H`#PJ9"*`.2JL@#PJ9*6
M`.F@BP#IH*D`\*F6M@#IHZ(`Y*RS`.FDJ0#IIJ<`Z:>"`.FGO@#DKXX`\*FL
ML`#IK)(`Z;&``.FSO0#DLXX`Y+.M`.FUIP#PJH..`.2SN`#PJH2%`/"JB(X`
M\*J*D0#DM98`Z;N^`.F\A0#IO(\`Z;R6`/"JF(```````````````````*``
M``#__P``J````/__`@"J````__\&`*\```#__P@`L@```/__#`"S````__\.
M`+0```#__Q``M0```/__%`"X````__\7`+D```#__QL`N@```/__'0"\````
M__\?`+T```#__R4`O@```/__*P#`````,0#__\$````U`/__P@```#D`___#
M````/0#__\0```!!`/__Q0```$4`___'````20#__\@```!-`/__R0```%$`
M___*````50#__\L```!9`/__S````%T`___-````80#__\X```!E`/__SP``
M`&D`___1````;0#__](```!Q`/__TP```'4`___4````>0#__]4```!]`/__
MU@```($`___9````A0#__]H```")`/__VP```(T`___<````D0#__]T```"5
M`/__X````)D`___A````G0#__^(```"A`/__XP```*4`___D````J0#__^4`
M``"M`/__YP```+$`___H````M0#__^D```"Y`/__Z@```+T`___K````P0#_
M_^P```#%`/__[0```,D`___N````S0#__^\```#1`/__\0```-4`___R````
MV0#___,```#=`/__]````.$`___U````Y0#___8```#I`/__^0```.T`___Z
M````\0#___L```#U`/___````/D`___]````_0#___\````!`?__``$```4!
M__\!`0``"0'__P(!```-`?__`P$``!$!__\$`0``%0'__P4!```9`?__!@$`
M`!T!__\'`0``(0'__P@!```E`?__"0$``"D!__\*`0``+0'__PL!```Q`?__
M#`$``#4!__\-`0``.0'__PX!```]`?__#P$``$$!__\2`0``10'__Q,!``!)
M`?__%`$``$T!__\5`0``40'__Q8!``!5`?__%P$``%D!__\8`0``70'__QD!
M``!A`?__&@$``&4!__\;`0``:0'__QP!``!M`?__'0$``'$!__\>`0``=0'_
M_Q\!``!Y`?__(`$``'T!__\A`0``@0'__R(!``"%`?__(P$``(D!__\D`0``
MC0'__R4!``"1`?__*`$``)4!__\I`0``F0'__RH!``"=`?__*P$``*$!__\L
M`0``I0'__RT!``"I`?__+@$``*T!__\O`0``L0'__S`!``"U`?__,@$``/__
MN0$S`0``__^\`30!``"_`?__-0$``,,!__\V`0``QP'__S<!``#+`?__.0$`
M`,\!__\Z`0``TP'__SL!``#7`?__/`$``-L!__\]`0``WP'__SX!``#C`?__
M/P$``/__YP%``0``___K`4,!``#O`?__1`$``/,!__]%`0``]P'__T8!``#[
M`?__1P$``/\!__](`0```P+__TD!``#__P<"3`$```L"__]-`0``#P+__TX!
M```3`O__3P$``!<"__]0`0``&P+__U$!```?`O__5`$``","__]5`0``)P+_
M_U8!```K`O__5P$``"\"__]8`0``,P+__UD!```W`O__6@$``#L"__];`0``
M/P+__UP!``!#`O__70$``$<"__]>`0``2P+__U\!``!/`O__8`$``%,"__]A
M`0``5P+__V(!``!;`O__8P$``%\"__]D`0``8P+__V4!``!G`O__:`$``&L"
M__]I`0``;P+__VH!``!S`O__:P$``'<"__]L`0``>P+__VT!``!_`O__;@$`
M`(,"__]O`0``AP+__W`!``"+`O__<0$``(\"__]R`0``DP+__W,!``"7`O__
M=`$``)L"__]U`0``GP+__W8!``"C`O__=P$``*<"__]X`0``JP+__WD!``"O
M`O__>@$``+,"__][`0``MP+__WP!``"[`O__?0$``+\"__]^`0``PP+__W\!
M``#__\<"H`$``,D"__^A`0``S0+__Z\!``#1`O__L`$``-4"___$`0``___9
M`L4!``#__]X"Q@$``/__XP+'`0``___H`L@!``#__^L"R0$``/__[@+*`0``
M___Q`LL!``#___0"S`$``/__]P+-`0``^@+__\X!``#^`O__SP$```(#___0
M`0``!@/__]$!```*`___T@$```X#___3`0``$@/__]0!```6`___U0$``!H#
M___6`0``(`/__]<!```F`___V`$``"P#___9`0``,@/__]H!```X`___VP$`
M`#X#___<`0``1`/__]X!``!*`___WP$``%`#___@`0``5@/__^$!``!<`___
MX@$``&(#___C`0``9P/__^8!``!L`___YP$``'`#___H`0``=`/__^D!``!X
M`___Z@$``'P#___K`0``@`/__^P!``"$`___[0$``(H#___N`0``D`/__^\!
M``"5`___\`$``)H#___Q`0``__^>`_(!``#__Z$#\P$``/__I`/T`0``IP/_
M__4!``"K`___^`$``*\#___Y`0``LP/___H!``"W`___^P$``+T#___\`0``
MPP/___T!``#(`____@$``,T#____`0``T@/__P`"``#7`___`0(``-L#__\"
M`@``WP/__P,"``#C`___!`(``.<#__\%`@``ZP/__P8"``#O`___!P(``/,#
M__\(`@``]P/__PD"``#[`___"@(``/\#__\+`@```P3__PP"```'!/__#0(`
M``L$__\.`@``#P3__P\"```3!/__$`(``!<$__\1`@``&P3__Q("```?!/__
M$P(``",$__\4`@``)P3__Q4"```K!/__%@(``"\$__\7`@``,P3__Q@"```W
M!/__&0(``#L$__\:`@``/P3__QL"``!#!/__'@(``$<$__\?`@``2P3__R8"
M``!/!/__)P(``%,$__\H`@``5P3__RD"``!;!/__*@(``%\$__\K`@``903_
M_RP"``!K!/__+0(``'$$__\N`@``=P3__R\"``![!/__,`(``'\$__\Q`@``
MA03__S("``"+!/__,P(``(\$__^P`@``__^3!+$"``#__Y4$L@(``/__F`2S
M`@``__^:!+0"``#__YP$M0(``/__GP2V`@``__^B!+<"``#__Z4$N`(``/__
MIP38`@``__^I!-D"``#__ZT$V@(``/__L03;`@``__^U!-P"``#__[D$W0(`
M`/__O03@`@``___!!.$"``#__\0$X@(``/__QP+C`@``___&!.0"``#__\@$
M0`,``,L$__]!`P``S@3__T,#``#1!/__1`,``-0$__]T`P``V03__WH#``#_
M_]P$?@,``.`$__^$`P``__\0`(4#``#B!.<$A@,``.T$__^'`P``\@3__X@#
M``#U!/__B0,``/H$__^*`P``_P3__XP#```$!?__C@,```D%__^/`P``#@7_
M_Y`#```3!?__J@,``!H%__^K`P``'P7__ZP#```D!?__K0,``"D%__^N`P``
M+@7__Z\#```S!?__L`,``#@%___*`P``/P7__\L#``!$!?__S`,``$D%___-
M`P``3@7__\X#``!3!?__T`,``/__6`71`P``__];!=(#``#__UX%TP,``&$%
M"074`P``9@4?!=4#``#__VL%U@,``/__;@7P`P``__]Q!?$#``#__W0%\@,`
M`/__=P7T`P``__]Z!?4#``#__WT%``0``(`%__\!!```A07__P,$``"*!?__
M!P0``(\%__\,!```E`7__PT$``"9!?__#@0``)X%__\9!```HP7__SD$``"H
M!?__4`0``*T%__]1!```L@7__U,$``"W!?__5P0``+P%__]<!```P07__UT$
M``#&!?__7@0``,L%__]V!```T`7__W<$``#5!?__P00``-H%___"!```WP7_
M_]`$``#D!?__T00``.D%___2!```[@7__],$``#S!?__U@0``/@%___7!```
M_07__]H$```"!O__VP0```<&___<!```#`;__]T$```1!O__W@0``!8&___?
M!```&P;__^($```@!O__XP0``"4&___D!```*@;__^4$```O!O__Y@0``#0&
M___G!```.0;__^H$```^!O__ZP0``$,&___L!```2`;__^T$``!-!O__[@0`
M`%(&___O!```5P;___`$``!<!O__\00``&$&___R!```9@;___,$``!K!O__
M]`0``'`&___U!```=0;___@$``!Z!O__^00``'\&__^'!0``__^$!B(&``")
M!O__(P8``(X&__\D!@``DP;__R4&``"8!O__)@8``)T&__]U!@``__^B!G8&
M``#__Z<&=P8``/__K`9X!@``__^Q!L`&``"V!O__P@8``+L&___3!@``P`;_
M_RD)``#%!O__,0D``,P&__\T"0``TP;__U@)``#:!O__60D``.$&__]:"0``
MZ`;__UL)``#O!O__7`D``/8&__]="0``_0;__UX)```$!___7PD```L'___+
M"0``$@?__\P)```9!___W`D``"`'___="0``)P?__]\)```N!___,PH``#4'
M__\V"@``/`?__UD*``!#!___6@H``$H'__];"@``40?__UX*``!8!___2`L`
M`%\'__]+"P``9@?__TP+``!M!___7`L``'0'__]="P``>P?__Y0+``""!___
MR@L``(D'___+"P``D`?__\P+``"7!___2`P``)X'___`#```I0?__\<,``"L
M!___R`P``+,'___*#```N@?__\L,``#!!___2@T``,L'__]+#0``T@?__TP-
M``#9!___V@T``.`'___<#0``YP?__]T-``#N!___W@T``/@'__\S#@``____
M![,.``#__P8(W`X``/__#0C=#@``__\4"`P/``#__QL(0P\``!\(__]-#P``
M)@C__U(/```M"/__5P\``#0(__]<#P``.PC__VD/``!""/__<P\``$D(__]U
M#P``4`C__W8/``!7"/__=P\``/__7@AX#P``:`C__WD/``#__V\(@0\``'D(
M__^3#P``@`C__YT/``"'"/__H@\``(X(__^G#P``E0C__ZP/``"<"/__N0\`
M`*,(__\F$```J@C__P`>``"Q"/__`1X``+4(__\"'@``N0C__P,>``"]"/__
M!!X``,$(__\%'@``Q0C__P8>``#)"/__!QX``,T(__\('@``T0C__PD>``#7
M"/__"AX``-T(__\+'@``X0C__PP>``#E"/__#1X``.D(__\.'@``[0C__P\>
M``#Q"/__$!X``/4(__\1'@``^0C__Q(>``#]"/__$QX```$)__\4'@``!0G_
M_Q4>```+"?__%AX``!$)__\7'@``%PG__Q@>```="?__&1X``"$)__\:'@``
M)0G__QL>```I"?__'!X``"T)__\='@``,PG__QX>```Y"?__'QX``#T)__\@
M'@``00G__R$>``!%"?__(AX``$D)__\C'@``30G__R0>``!1"?__)1X``%4)
M__\F'@``60G__R<>``!="?__*!X``&$)__\I'@``90G__RH>``!I"?__*QX`
M`&T)__\L'@``<0G__RT>``!U"?__+AX``'D)__\O'@``?PG__S`>``"%"?__
M,1X``(D)__\R'@``C0G__S,>``"1"?__-!X``)4)__\U'@``F0G__S8>``"=
M"?__-QX``*$)__\X'@``I0G__SD>``"K"?__.AX``+$)__\['@``M0G__SP>
M``"Y"?__/1X``+T)__\^'@``P0G__S\>``#%"?__0!X``,D)__]!'@``S0G_
M_T(>``#1"?__0QX``-4)__]$'@``V0G__T4>``#="?__1AX``.$)__]''@``
MY0G__T@>``#I"?__21X``.T)__]*'@``\0G__TL>``#U"?__3!X``/D)__]-
M'@``_PG__TX>```%"O__3QX```L*__]0'@``$0K__U$>```7"O__4AX``!T*
M__]3'@``(PK__U0>```I"O__51X``"T*__]6'@``,0K__U<>```U"O__6!X`
M`#D*__]9'@``/0K__UH>``!!"O__6QX``$4*__]<'@``20K__UT>``!/"O__
M7AX``%4*__]?'@``60K__V`>``!="O__81X``&$*__]B'@``90K__V,>``!I
M"O__9!X``&T*__]E'@``<PK__V8>``!Y"O__9QX``'\*__]H'@``A0K__VD>
M``"+"O__:AX``)$*__]K'@``E0K__VP>``"9"O__;1X``)T*__]N'@``H0K_
M_V\>``"E"O__<!X``*D*__]Q'@``K0K__W(>``"Q"O__<QX``+4*__]T'@``
MN0K__W4>``"]"O__=AX``,$*__]W'@``Q0K__W@>``#)"O__>1X``,\*__]Z
M'@``U0K__WL>``#;"O__?!X``.$*__]]'@``Y0K__WX>``#I"O__?QX``.T*
M__^`'@``\0K__X$>``#U"O__@AX``/D*__^#'@``_0K__X0>```!"___A1X`
M``4+__^&'@``"0O__X<>```-"___B!X``!$+__^)'@``%0O__XH>```9"___
MBQX``!T+__^,'@``(0O__XT>```E"___CAX``"D+__^/'@``+0O__Y`>```Q
M"___D1X``#4+__^2'@``.0O__Y,>```]"___E!X``$$+__^5'@``10O__Y8>
M``!)"___EQX``$T+__^8'@``40O__YD>``!5"___FAX``/__60N;'@``70MA
M"J`>``!B"___H1X``&8+__^B'@``:@O__Z,>``!N"___I!X``'(+__^E'@``
M>`O__Z8>``!^"___IQX``(0+__^H'@``B@O__ZD>``"0"___JAX``)8+__^K
M'@``G`O__ZP>``"B"___K1X``*@+__^N'@``K@O__Z\>``"T"___L!X``+H+
M__^Q'@``P`O__[(>``#&"___LQX``,P+__^T'@``T@O__[4>``#8"___MAX`
M`-X+__^W'@``Y`O__[@>``#J"___N1X``.X+__^Z'@``\@O__[L>``#V"___
MO!X``/H+__^]'@``_@O__[X>```"#/__OQX```@,___`'@``#@S__\$>```4
M#/__PAX``!H,___#'@``(`S__\0>```F#/__Q1X``"P,___&'@``,@S__\<>
M```X#/__R!X``#X,___)'@``0@S__\H>``!&#/__RQX``$H,___,'@``3@S_
M_\T>``!2#/__SAX``%8,___/'@``6@S__]`>``!>#/__T1X``&0,___2'@``
M:@S__],>``!P#/__U!X``'8,___5'@``?`S__]8>``""#/__UQX``(@,___8
M'@``C@S__]D>``"4#/__VAX``)H,___;'@``H`S__]P>``"F#/__W1X``*P,
M___>'@``L@S__]\>``"X#/__X!X``+X,___A'@``Q`S__^(>``#*#/__XQX`
M`-`,___D'@``U@S__^4>``#:#/__YAX``-X,___G'@``X@S__^@>``#F#/__
MZ1X``.P,___J'@``\@S__^L>``#X#/__[!X``/X,___M'@``!`W__^X>```*
M#?__[QX``!`-___P'@``%@W___$>```<#?__\AX``"(-___S'@``)@W___0>
M```J#?__]1X``"X-___V'@``,@W___<>```V#?__^!X``#H-___Y'@``/@W_
M_P`?``!"#?__`1\``$<-__\"'P``3`W__P,?``!3#?__!!\``%H-__\%'P``
M80W__P8?``!H#?__!Q\``&\-__\('P``=@W__PD?``![#?__"A\``(`-__\+
M'P``APW__PP?``".#?__#1\``)4-__\.'P``G`W__P\?``"C#?__$!\``*H-
M__\1'P``KPW__Q(?``"T#?__$Q\``+L-__\4'P``P@W__Q4?``#)#?__&!\`
M`-`-__\9'P``U0W__QH?``#:#?__&Q\``.$-__\<'P``Z`W__QT?``#O#?__
M(!\``/8-__\A'P``^PW__R(?````#O__(Q\```<.__\D'P``#@[__R4?```5
M#O__)A\``!P.__\G'P``(P[__R@?```J#O__*1\``"\.__\J'P``-`[__RL?
M```[#O__+!\``$(.__\M'P``20[__RX?``!0#O__+Q\``%<.__\P'P``7@[_
M_S$?``!C#O__,A\``&@.__\S'P``;P[__S0?``!V#O__-1\``'T.__\V'P``
MA`[__S<?``"+#O__.!\``)(.__\Y'P``EP[__SH?``"<#O__.Q\``*,.__\\
M'P``J@[__ST?``"Q#O__/A\``+@.__\_'P``OP[__T`?``#&#O__01\``,L.
M__]"'P``T`[__T,?``#7#O__1!\``-X.__]%'P``Y0[__T@?``#L#O__21\`
M`/$.__]*'P``]@[__TL?``#]#O__3!\```0/__]-'P``"P___U`?```2#___
M41\``!</__]2'P``'`___U,?```C#___5!\``"H/__]5'P``,0___U8?```X
M#___5Q\``#\/__]9'P``1@___UL?``!+#___71\``%(/__]?'P``60___V`?
M``!@#___81\``&4/__]B'P``:@___V,?``!Q#___9!\``'@/__]E'P``?P__
M_V8?``"&#___9Q\``(T/__]H'P``E`___VD?``"9#___:A\``)X/__]K'P``
MI0___VP?``"L#___;1\``+,/__]N'P``N@___V\?``#!#___<!\``,@/__]Q
M'P``)`7__W(?``#-#___<Q\``"D%__]T'P``T@___W4?```N!?__=A\``-</
M__]W'P``,P7__W@?``#<#___>1\``$D%__]Z'P``X0___WL?``!.!?__?!\`
M`.8/__]]'P``4P7__X`?``#K#___@1\``/(/__^"'P``^0___X,?```"$/__
MA!\```L0__^%'P``%!#__X8?```=$/__AQ\``"80__^('P``+Q#__XD?```V
M$/__BA\``#T0__^+'P``1A#__XP?``!/$/__C1\``%@0__^.'P``81#__X\?
M``!J$/__D!\``',0__^1'P``>A#__Y(?``"!$/__DQ\``(H0__^4'P``DQ#_
M_Y4?``"<$/__EA\``*40__^7'P``KA#__Y@?``"W$/__F1\``+X0__^:'P``
MQ1#__YL?``#.$/__G!\``-<0__^='P``X!#__YX?``#I$/__GQ\``/(0__^@
M'P``^Q#__Z$?```"$?__HA\```D1__^C'P``$A'__Z0?```;$?__I1\``"01
M__^F'P``+1'__Z<?```V$?__J!\``#\1__^I'P``1A'__ZH?``!-$?__JQ\`
M`%81__^L'P``7Q'__ZT?``!H$?__KA\``'$1__^O'P``>A'__[`?``"#$?__
ML1\``(@1__^R'P``C1'__[,?``"4$?__M!\``)D1__^V'P``H!'__[<?``"E
M$?__N!\``*P1__^Y'P``L1'__[H?``"V$?__NQ\``.T$__^\'P``NQ'__[T?
M``#__\`1OA\``,01__^_'P``___`$<`?``#__\<1P1\``,L1T!'"'P``UA'_
M_\,?``#=$?__Q!\``.(1___&'P``Z1'__\<?``#N$?__R!\``/41___)'P``
M]03__\H?``#Z$?__RQ\``/H$___,'P``_Q'__\T?```$$@H2SA\``!`2%A+/
M'P``'!(B$M`?```H$O__T1\``"T2___2'P``,A+__],?```3!?__UA\``#D2
M___7'P``/A+__]@?``!%$O__V1\``$H2___:'P``3Q+__]L?``#_!/__W1\`
M`%026A+>'P``8!)F$M\?``!L$G(2X!\``'@2___A'P``?1+__^(?``""$O__
MXQ\``#@%___D'P``B1+__^4?``".$O__YA\``),2___G'P``F!+__^@?``"?
M$O__Z1\``*02___J'P``J1+__^L?```)!?__[!\``*X2___M'P``LQ*X$NX?
M``#B!.<$[Q\``+X2___R'P``P!+___,?``#'$O__]!\``,P2___V'P``TQ+_
M__<?``#8$O__^!\``-\2___Y'P``!`7___H?``#D$O__^Q\```X%___\'P``
MZ1+___T?``#N$A``_A\``/__\1(`(```]1(```$@``#Y$@```B```/__```#
M(```__\```0@``#__P``!2```/__```&(```__\```<@``#__P``""```/__
M```)(```__\```H@``#__P``$2```/___1(7(```__\!$R0@``#__P43)2``
M`/__!Q,F(```__\*$R\@``#__P``,R```/__#A,T(```__\5$S8@``#__Q\3
M-R```/__)A,\(```__\P$SX@``#__S,31R```/__-Q-((```__\Z$TD@``#_
M_ST35R```/__0!-?(```__\``'`@``#__TT3<2```/__3Q-T(```__]1$W4@
M``#__U,3=B```/__51-W(```__]7$W@@``#__UD3>2```/__6Q-Z(```__]=
M$WL@``#__U\3?"```/__8Q-](```__]E$WX@``#__V<3?R```/__:1.`(```
M__]-$X$@``#__QL`@B```/__#`"#(```__\.`(0@``#__U$3A2```/__4Q.&
M(```__]5$X<@``#__U<3B"```/__61.)(```__];$XH@``#__UT3BR```/__
M7Q.,(```__]C$XT@``#__V43CB```/__9Q.H(```__]K$P`A``#__VX3`2$`
M`/__<A,"(0``__]V$P,A``#__W@3!2$``/__?!,&(0``__^`$P<A``#__X03
M"2$``/__AQ,*(0``__^+$PLA``#__XT3#"$``/__C1,-(0``__^-$PXA``#_
M_Y,$#R$``/__CQ,0(0``__^2$Q$A``#__Y(3$B$``/__E!,3(0``___$!!4A
M``#__Y83%B$``/__F!,9(0``__^;$QHA``#__YT3&R$``/__GQ,<(0``__^?
M$QTA``#__Y\3("$``/__H1,A(0``__^D$R(A``#__Z@3)"$``/__JQ,F(0``
MK1/__R@A``#__ZL3*B$``+`3__\K(0``10#__RPA``#__[(3+2$``/__=A,O
M(0``__^T$S`A``#__[83,2$``/__N!,S(0``__^Z$S0A``#__QT`-2$``/__
MO!,V(0``__^_$S<A``#__\(3."$``/__Q1,Y(0``__]/$STA``#__\@3/B$`
M`/__RQ,_(0``___.$T`A``#__]$312$``/__U1-&(0``___7$T<A``#__[03
M2"$``/__3Q-)(0``__^8!%,A``#__]D35"$``/__WQ-5(0``___E$U8A``#_
M_^L35R$``/__\1-8(0``___W$UDA``#___T36B$``/__`Q1;(0``__\)%%PA
M``#__P\472$``/__%11>(0``__\;%%\A``#__R$48"$``/__DA-A(0``__\F
M%&(A``#__RD48R$``/__+11D(0``__\P%&4A``#__S(49B$``/__-11G(0``
M__\Y%&@A``#__SX4:2$``/__011J(0``__]#%&LA``#__T84;"$``/__E!-M
M(0``__]V$VXA``#__]43;R$``/__NA-P(0``__]/$W$A``#__TH4<B$``/__
M311S(0``__]1%'0A``#__U04=2$``/__5A1V(0``__]9%'<A``#__UT4>"$`
M`/__8A1Y(0``___&!'HA``#__V44>R$``/__:!1\(0``___$!'TA``#__VP4
M?B$``/__UQ-_(0``__]N%)HA``!P%/__FR$``'84__^N(0``?!3__\TA``""
M%/__SB$``(@4___/(0``CA3__P0B``"4%/__"2(``)H4__\,(@``H!3__R0B
M``"F%/__)B(``*P4__\L(@``__^R%"TB``#__[D4+R(``/__PQ0P(@``___*
M%$$B``#4%/__1"(``-H4__]'(@``X!3__TDB``#F%/__8"(``.P4__]B(@``
M\!3__VTB``#V%/__;B(``/P4__]O(@```!7__W`B```$%?__<2(```H5__]T
M(@``$!7__W4B```6%?__>"(``!P5__]Y(@``(A7__X`B```H%?__@2(``"X5
M__^$(@``-!7__X4B```Z%?__B"(``$`5__^)(@``1A7__ZPB``!,%?__K2(`
M`%(5__^N(@``6!7__Z\B``!>%?__X"(``&05___A(@``:A7__^(B``!P%?__
MXR(``'85___J(@``?!7__^LB``""%?__["(``(@5___M(@``CA7__RDC``"4
M%?__*B,``)@5__]@)```__\;`&$D``#__PP`8B0``/__#@!C)```__]1$V0D
M``#__U,3920``/__51-F)```__]7$V<D``#__UD3:"0``/__6Q-I)```__^<
M%6HD``#__Y\5:R0``/__HA5L)```__^E%6TD``#__Z@5;B0``/__JQ5O)```
M__^N%7`D``#__[$5<20``/__M!5R)```__^W%7,D``#__[H5="0``/__O15U
M)```___!%78D``#__\45=R0``/__R15X)```___-%7DD``#__]$5>B0``/__
MU15[)```___9%7PD``#__]T5?20``/__X15^)```___F%7\D``#__^L5@"0`
M`/__\!6!)```___U%8(D``#___H5@R0``/___Q6$)```__\$%H4D``#__PD6
MAB0``/__#A:')```__\3%H@D``#__Q@6B20``/__&Q:*)```__\>%HLD``#_
M_R$6C"0``/__)!:-)```__\G%HXD``#__RH6CR0``/__+1:0)```__\P%I$D
M``#__S,6DB0``/__-Q:3)```__\[%I0D``#__S\6E20``/__0Q:6)```__]'
M%I<D``#__TL6F"0``/__3Q:9)```__]3%IHD``#__U<6FR0``/__6Q:<)```
M__]?%ITD``#__V,6GB0``/__9Q:?)```__]K%J`D``#__V\6H20``/__<Q:B
M)```__]W%J,D``#__WL6I"0``/__?Q:E)```__^#%J8D``#__X<6IR0``/__
MBQ:H)```__^/%JDD``#__Y,6JB0``/__EQ:K)```__^;%JPD``#__Y\6K20`
M`/__HQ:N)```__^G%J\D``#__ZL6L"0``/__KQ:Q)```__^S%K(D``#__[<6
MLR0``/__NQ:T)```__^_%K4D``#__\,6MB0``/__QQ:W)```__^R$[@D``#_
M_W83N20``/__U1.Z)```__^V$[LD``#__[@3O"0``/__R1:])```__^-$[XD
M``#__Y(3OR0``/__RQ;`)```__^P$\$D``#__Y03PB0``/__NA/#)```__^6
M$\0D``#__\T6Q20``/__FQ/&)```__^=$\<D``#__Y\3R"0``/__SQ;))```
M___1%LHD``#__],6RR0``/__,!3,)```___5%LTD``#__T$4SB0``/__UQ;/
M)```__^K$]`D``#__P8`T20``/__V1;2)```__]L%-,D``#__]<3U"0``/__
MM!/5)```___;%M8D``#__XL3UR0``/__DP38)```__]/$]DD``#__Y@$VB0`
M`/__W1;;)```___$!-PD``#__VX4W20``/__:1/>)```__\=`-\D``#__]\6
MX"0``/__X1;A)```__^:!.(D``#__\<"XR0``/__XQ;D)```___E%N4D``#_
M_U04YB0``/__I03G)```___&!.@D``#__Z<$Z20``/__YQ;J)```__]-$PPJ
M``#__^D6="H``/__]A9U*@``___Z%G8J``#___T6W"H```$7__^?+@``__\'
M%_,N``#__PL7`"\``/__#Q<!+P``__\3%P(O``#__Q<7`R\``/__&Q<$+P``
M__\?%P4O``#__R,7!B\``/__)Q<'+P``__\K%P@O``#__R\7"2\``/__,Q<*
M+P``__\W%PLO``#__SL7#"\``/__/Q<-+P``__]#%PXO``#__T<7#R\``/__
M2Q<0+P``__]/%Q$O``#__U,7$B\``/__5Q<3+P``__];%Q0O``#__U\7%2\`
M`/__8Q<6+P``__]G%Q<O``#__VL7&"\``/__;Q<9+P``__]S%QHO``#__W<7
M&R\``/__>Q<<+P``__]_%QTO``#__X,7'B\``/__AQ<?+P``__^+%R`O``#_
M_X\7(2\``/__DQ<B+P``__^7%R,O``#__YL7)"\``/__GQ<E+P``__^C%R8O
M``#__Z<7)R\``/__JQ<H+P``__^O%RDO``#__[,7*B\``/__MQ<K+P``__^[
M%RPO``#__[\7+2\``/__PQ<N+P``___'%R\O``#__\L7,"\``/__SQ<Q+P``
M___3%S(O``#__]<7,R\``/__VQ<T+P``___?%S4O``#__^,7-B\``/__YQ<W
M+P``___K%S@O``#__^\7.2\``/__\Q<Z+P``___W%SLO``#___L7/"\``/__
M_Q<]+P``__\#&#XO``#__P<8/R\``/__"QA`+P``__\/&$$O``#__Q,80B\`
M`/__%QA#+P``__\;&$0O``#__Q\812\``/__(QA&+P``__\G&$<O``#__RL8
M2"\``/__+QA)+P``__\S&$HO``#__S<82R\``/__.QA,+P``__\_&$TO``#_
M_T,83B\``/__1QA/+P``__]+&%`O``#__T\842\``/__4QA2+P``__]7&%,O
M``#__UL85"\``/__7QA5+P``__]C&%8O``#__V<85R\``/__:QA8+P``__]O
M&%DO``#__W,86B\``/__=QA;+P``__][&%PO``#__W\872\``/__@QA>+P``
M__^'&%\O``#__XL88"\``/__CQAA+P``__^3&&(O``#__Y<88R\``/__FQAD
M+P``__^?&&4O``#__Z,89B\``/__IQAG+P``__^K&&@O``#__Z\8:2\``/__
MLQAJ+P``__^W&&LO``#__[L8;"\``/__OQAM+P``___#&&XO``#__\<8;R\`
M`/__RQAP+P``___/&'$O``#__],8<B\``/__UQAS+P``___;&'0O``#__]\8
M=2\``/__XQAV+P``___G&'<O``#__^L8>"\``/__[QAY+P``___S&'HO``#_
M__<8>R\``/__^QA\+P``____&'TO``#__P,9?B\``/__!QE_+P``__\+&8`O
M``#__P\9@2\``/__$QF"+P``__\7&8,O``#__QL9A"\``/__'QF%+P``__\C
M&88O``#__R<9AR\``/__*QF(+P``__\O&8DO``#__S,9BB\``/__-QF++P``
M__\[&8PO``#__S\9C2\``/__0QF.+P``__]'&8\O``#__TL9D"\``/__3QF1
M+P``__]3&9(O``#__U<9DR\``/__6QF4+P``__]?&94O``#__V,9EB\``/__
M9QF7+P``__]K&9@O``#__V\9F2\``/__<QF:+P``__]W&9LO``#__WL9G"\`
M`/__?QF=+P``__^#&9XO``#__X<9GR\``/__BQF@+P``__^/&:$O``#__Y,9
MHB\``/__EQFC+P``__^;&:0O``#__Y\9I2\``/__HQFF+P``__^G&:<O``#_
M_ZL9J"\``/__KQFI+P``__^S&:HO``#__[<9JR\``/__NQFL+P``__^_&:TO
M``#__\,9KB\``/__QQFO+P``___+&;`O``#__\\9L2\``/__TQFR+P``___7
M&;,O``#__]L9M"\``/__WQFU+P``___C&;8O``#__^<9MR\``/__ZQFX+P``
M___O&;DO``#___,9NB\``/__]QF[+P``___[&;PO``#___\9O2\``/__`QJ^
M+P``__\'&K\O``#__PL:P"\``/__#QK!+P``__\3&L(O``#__Q<:PR\``/__
M&QK$+P``__\?&L4O``#__R,:QB\``/__)QK'+P``__\K&L@O``#__R\:R2\`
M`/__,QK*+P``__\W&LLO``#__SL:S"\``/__/QK-+P``__]#&LXO``#__T<:
MSR\``/__2QK0+P``__]/&M$O``#__U,:TB\``/__5QK3+P``__];&M0O``#_
M_U\:U2\``/__8QH`,```__\``#8P``#__V<:.#```/__:Q<Y,```__]K&CHP
M``#__V\:3#```',:__].,```>AK__U`P``"!&O__4C```(@:__]4,```CQK_
M_U8P``"6&O__6#```)T:__]:,```I!K__UPP``"K&O__7C```+(:__]@,```
MN1K__V(P``#`&O__93```,<:__]G,```SAK__VDP``#5&O__<#```-P:__]Q
M,```XQK__W,P``#J&O__=#```/$:__]V,```^!K__W<P``#_&O__>3````8;
M__]Z,```#1O__WPP```4&___?3```!L;__^4,```(AO__YLP``#__RD;G#``
M`/__+AN>,```,QO__Y\P``#__SH;K#```$$;__^N,```2!O__[`P``!/&___
MLC```%8;__^T,```71O__[8P``!D&___N#```&L;__^Z,```<AO__[PP``!Y
M&___OC```(`;___`,```AQO__\(P``".&___Q3```)4;___',```G!O__\DP
M``"C&___T#```*H;___1,```L1O__],P``"X&___U#```+\;___6,```QAO_
M_]<P``#-&___V3```-0;___:,```VQO__]PP``#B&___W3```.D;___T,```
M\!O___<P``#W&___^#```/X;___Y,```!1S___HP```,'/___C```!,<____
M,```__\:'#$Q``#__R$<,C$``/__)1PS,0``__\I'#0Q``#__RT<-3$``/__
M,1PV,0``__\U'#<Q``#__SD<.#$``/__/1PY,0``__]!'#HQ``#__T4<.S$`
M`/__21P\,0``__]-'#TQ``#__U$</C$``/__51P_,0``__]9'$`Q``#__UT<
M03$``/__81Q",0``__]E'$,Q``#__VD<1#$``/__;1Q%,0``__]Q'$8Q``#_
M_W4<1S$``/__>1Q(,0``__]]'$DQ``#__X$<2C$``/__A1Q+,0``__^)'$PQ
M``#__XT<33$``/__D1Q.,0``__^5'$\Q``#__YD<4#$``/__G1Q1,0``__^A
M'%(Q``#__Z4<4S$``/__J1Q4,0``__^M'%4Q``#__[$<5C$``/__M1Q7,0``
M__^Y'%@Q``#__[T<63$``/__P1Q:,0``___%'%LQ``#__\D<7#$``/__S1Q=
M,0``___1'%XQ``#__]4<7S$``/__V1Q@,0``___='&$Q``#__^$<8C$``/__
MY1QC,0``___I'&0Q``#__^T<93$``/__\1QF,0``___U'&<Q``#___D<:#$`
M`/___1QI,0``__\!'6HQ``#__P4=:S$``/__"1UL,0``__\-'6TQ``#__Q$=
M;C$``/__%1UO,0``__\9'7`Q``#__QT=<3$``/__(1UR,0``__\E'7,Q``#_
M_RD==#$``/__+1UU,0``__\Q'78Q``#__S4==S$``/__.1UX,0``__\]'7DQ
M``#__T$=>C$``/__11U[,0``__])'7PQ``#__TT=?3$``/__41U^,0``__]5
M'7\Q``#__UD=@#$``/__71V!,0``__]A'8(Q``#__V4=@S$``/__:1V$,0``
M__]M'84Q``#__W$=AC$``/__=1V',0``__]Y'8@Q``#__WT=B3$``/__@1V*
M,0``__^%'8LQ``#__XD=C#$``/__C1V-,0``__^1'8XQ``#__Y4=DC$``/__
M#Q>3,0``__\G%Y0Q``#__YD=E3$``/__G1V6,0``__^A'9<Q``#__Z4=F#$`
M`/__J1V9,0``__^M'9HQ``#__Q\7FS$``/__L1V<,0``__^U'9TQ``#__[D=
MGC$``/__O1V?,0``__\O%P`R``#__\$=`3(``/__QQT",@``___-'0,R``#_
M_],=!#(``/__V1T%,@``___?'08R``#__^4=!S(``/__ZQT(,@``___Q'0DR
M``#___<="C(``/___1T+,@``__\#'@PR``#__PD>#3(``/__#QX.,@``__\5
M'@\R``#__QX>$#(``/__)QX1,@``__\P'A(R``#__SD>$S(``/__0AX4,@``
M__]+'A4R``#__U0>%C(``/__71X7,@``__]F'A@R``#__V\>&3(``/__>!X:
M,@``__^!'ALR``#__XH>'#(``/__DQX@,@``__^<'B$R``#__Z(>(C(``/__
MJ!XC,@``__^N'B0R``#__[0>)3(``/__NAXF,@``___`'B<R``#__\8>*#(`
M`/__S!XI,@``___2'BHR``#__]@>*S(``/__WAXL,@``___D'BTR``#__^H>
M+C(``/__\!XO,@``___V'C`R``#___P>,3(``/__`A\R,@``__\('S,R``#_
M_PX?-#(``/__%!\U,@``__\:'S8R``#__R`?-S(``/__)A\X,@``__\L'SDR
M``#__S(?.C(``/__.!\[,@``__\^'SPR``#__T0?/3(``/__2A\^,@``__]0
M'S\R``#__U8?0#(``/__7!]!,@``__]B'T(R``#__V@?0S(``/__;A]1,@``
M__]T'U(R``#__W<?4S(``/__>A]4,@``__]]'U4R``#__X`?5C(``/__@Q]7
M,@``__^&'U@R``#__XD?63(``/__C!]:,@``__^/'ULR``#__Y(?7#(``/__
ME1]=,@``__^8'UXR``#__YL?7S(``/__GA]@,@``__\A'&$R``#__RT<8C(`
M`/__.1QC,@``__]!'&0R``#__V$<93(``/__91QF,@``__]Q'&<R``#__WD<
M:#(``/__?1QI,@``__^%'&HR``#__XD<:S(``/__C1QL,@``__^1'&TR``#_
M_Y4<;C(``/__H1]O,@``__^H'W`R``#__Z\?<3(``/__MA]R,@``__^]'W,R
M``#__\0?=#(``/__RQ]U,@``___2'W8R``#__]D?=S(``/__X!]X,@``___G
M'WDR``#__^X?>C(``/__]1][,@``___\'X`R``#__P\7@3(``/__)Q>",@``
M__^9'8,R``#__YT=A#(``/__`R"%,@``__\'((8R``#__PL@AS(``/__.Q>(
M,@``__\/((DR``#__VL7BC(``/__,QB+,@``__]C&(PR``#__U\8C3(``/__
M-QB.,@``__^G&8\R``#__XL7D#(``/__*QB1,@``__\3()(R``#__Q<@DS(`
M`/__&R"4,@``__\?()4R``#__R,@EC(``/__)R"7,@``__\K()@R``#__R\@
MF3(``/__,R":,@``__\W()LR``#__Z,7G#(``/__.R"=,@``__\_()XR``#_
M_T,@GS(``/__1R"@,@``__]+(*$R``#__T\@HC(``/__4R"C,@``__]7(*0R
M``#__Z$=I3(``/__I1VF,@``__^I':<R``#__UL@J#(``/__7R"I,@``__]C
M(*HR``#__V<@JS(``/__:R"L,@``__]O(*TR``#__W,@KC(``/__=R"O,@``
M__][(+`R``#__W\@L3(``/__@R"R,@``__^&(+,R``#__XD@M#(``/__C""U
M,@``__^/(+8R``#__Y(@MS(``/__E2"X,@``__^8(+DR``#__YL@NC(``/__
MGB"[,@``__^A(+PR``#__Z0@O3(``/__IR"^,@``__^J(+\R``#__ZT@P#(`
M`/__L"#!,@``__^U(,(R``#__[H@PS(``/__OR#$,@``___$(,4R``#__\D@
MQC(``/__SB#',@``___3(,@R``#__]@@R3(``/__W2#*,@``___C(,LR``#_
M_^D@T#(``/__[R#1,@``___S(-(R``#___<@TS(``/__^R#4,@``____(-4R
M``#__P,AUC(``/__!R'7,@``__\+(=@R``#__P\AV3(``/__$R':,@``__\7
M(=LR``#__QLAW#(``/__'R'=,@``__\C(=XR``#__R<AWS(``/__*R'@,@``
M__\O(>$R``#__S,AXC(``/__-R'C,@``__\[(>0R``#__S\AY3(``/__0R'F
M,@``__]'(><R``#__TLAZ#(``/__3R'I,@``__]3(>HR``#__U<AZS(``/__
M6R'L,@``__]?(>TR``#__V,A[C(``/__9R'O,@``__]K(?`R``#__V\A\3(`
M`/__<R'R,@``__]W(?,R``#__WLA]#(``/__?R'U,@``__^#(?8R``#__X<A
M]S(``/__BR'X,@``__^/(?DR``#__Y,A^C(``/__ER'[,@``__^;(?PR``#_
M_Y\A_3(``/__HR'^,@``__^G(0`S``#__ZLA`3,``/__NR$",P``___((0,S
M``#__]@A!#,``/__XB$%,P``___R(08S``#___PA!S,``/__!B((,P``__\9
M(@DS``#__R8B"C,``/__,"(+,P``__\Z(@PS``#__T0B#3,``/__42(.,P``
M__]>(@\S``#__VLB$#,``/__>"(1,P``__^%(A(S``#__Y(B$S,``/__GR(4
M,P``__^R(A4S``#__[DB%C,``/__S"(7,P``___?(A@S``#__^\B&3,``/__
M_"(:,P``__\/(QLS``#__R(C'#,``/__+R,=,P``__\Y(QXS``#__T,C'S,`
M`/__4",@,P``__]=(R$S``#__VTC(C,``/__?2,C,P``__^'(R0S``#__Y$C
M)3,``/__GB,F,P``__^H(R<S``#__[(C*#,``/__N2,I,P``___`(RHS``#_
M_\HC*S,``/__U",L,P``___G(RTS``#___0C+C,``/__!"0O,P``__\7)#`S
M``#__R0D,3,``/__+B0R,P``__\X)#,S``#__TLD-#,``/__6"0U,P``__]K
M)#8S``#__W4D-S,``/__A20X,P``__^/)#DS``#__YPD.C,``/__IB0[,P``
M__^S)#PS``#__\,D/3,``/__T"0^,P``___@)#\S``#__^TD0#,``/__]"1!
M,P``__\$)4(S``#__PXE0S,``/__&"5$,P``__\E)44S``#__R\E1C,``/__
M.25',P``__]#)4@S``#__U,E23,``/__8"5*,P``__]G)4LS``#__WHE3#,`
M`/__A"5-,P``__^4)4XS``#__Z$E3S,``/__KB50,P``__^X)5$S``#__\(E
M4C,``/__SR53,P``___6)50S``#__^,E53,``/__\R56,P``___Z)5<S``#_
M_PTF6#,``/__%R99,P``__\<)EHS``#__R$F6S,``/__)B9<,P``__\K)ETS
M``#__S`F7C,``/__-29?,P``__\Z)F`S``#__S\F83,``/__1"9B,P``__])
M)F,S``#__T\F9#,``/__529E,P``__];)F8S``#__V$F9S,``/__9R9H,P``
M__]M)FDS``#__W,F:C,``/__>29K,P``__]_)FPS``#__X4F;3,``/__BR9N
M,P``__^1)F\S``#__Y<F<#,``/__G29Q,P``__^C)G(S``#__Z<F<S,``/__
MJB9T,P``__^M)G4S``#__[$F=C,``/__M"9[,P``__^W)GPS``#__[XF?3,`
M`/__Q29^,P``___,)G\S``#__],F@#,``/__X":!,P``___C)H(S``#__^8F
M@S,``/__ZB:$,P``___M)H4S``#___`FAC,``/__\R:',P``___V)H@S``#_
M__DFB3,``/___2:*,P``__\")XLS``#__P4GC#,``/__"">-,P``__\,)XXS
M``#__Q`GCS,``/__$R>0,P``__\6)Y$S``#__QDGDC,``/__'2>3,P``__\A
M)Y0S``#__R4GE3,``/__*2>6,P``__\M)Y<S``#__S`GF#,``/__,R>9,P``
M__\V)YHS``#__SDGFS,``/__/"><,P``__]`)YTS``#__T,GGC,``/__1B>?
M,P``__]))Z`S``#__TTGH3,``/__42>B,P``__]4)Z,S``#__U@GI#,``/__
M7">E,P``__]@)Z8S``#__V,GIS,``/__9R>H,P``__]M)ZDS``#__W0GJC,`
M`/__=R>K,P``__][)ZPS``#__W\GK3,``/__@R>N,P``__^')Z\S``#__X\G
ML#,``/__F">Q,P``__^;)[(S``#__YXGLS,``/__HB>T,P``__^E)[4S``#_
M_Z@GMC,``/__JR>W,P``__^O)[@S``#__[(GN3,``/__M2>Z,P``__^X)[LS
M``#__[LGO#,``/__OB>],P``___")[XS``#__\4GOS,``/__R"?`,P``___+
M)\$S``#__\\GPC,``/__TR?#,P``___8)\0S``#__]LGQ3,``/__WB?&,P``
M___A)\<S``#__^@GR#,``/__["?),P``___O)\HS``#___(GRS,``/__]2?,
M,P``___X)\TS``#___LGSC,``/___B?/,P``__\!*-`S``#__P0HT3,``/__
M!RC2,P``__\**-,S``#__PXHU#,``/__$2C5,P``__\4*-8S``#__Q@HUS,`
M`/__'"C8,P``__\?*-DS``#__R0HVC,``/__*"C;,P``__\K*-PS``#__RXH
MW3,``/__,2C@,P``__\T*.$S``#__SDHXC,``/__/BCC,P``__]#*.0S``#_
M_T@HY3,``/__32CF,P``__]2*.<S``#__U<HZ#,``/__7"CI,P``__]A*.HS
M``#__V<HZS,``/__;2CL,P``__]S*.TS``#__WDH[C,``/__?RCO,P``__^%
M*/`S``#__XLH\3,``/__D2CR,P``__^7*/,S``#__YTH]#,``/__HRCU,P``
M__^I*/8S``#__Z\H]S,``/__M2CX,P``__^[*/DS``#__\$H^C,``/__QRC[
M,P``___-*/PS``#__],H_3,``/__V2C^,P``___?*`#Y``#E*/__`?D``.DH
M__\"^0``AQG__P/Y``#M*/__!/D``/$H__\%^0``]2C__P;Y``#Y*/__!_D`
M`%\:__\(^0``7QK__PGY``#]*/__"OD``*<9__\+^0```2G__PSY```%*?__
M#?D```DI__\.^0``#2G__P_Y```1*?__$/D``!4I__\1^0``&2G__Q+Y```=
M*?__$_D``"$I__\4^0``)2G__Q7Y```I*?__%OD``"TI__\7^0``,2G__QCY
M```U*?__&?D``#DI__\:^0``/2G__QOY``!!*?__'/D``$4I__\=^0``22G_
M_Q[Y``!-*?__'_D``%$I__\@^0``52G__R'Y``!9*?__(OD``%TI__\C^0``
M82G__R3Y``!E*?__)?D``&DI__\F^0``;2G__R?Y``!Q*?__*/D``'4I__\I
M^0``>2G__RKY``!]*?__*_D``($I__\L^0``A2G__RWY``")*?__+OD``(TI
M__\O^0``D2G__S#Y``"5*?__,?D``)DI__\R^0``G2G__S/Y``"A*?__-/D`
M`/\8__\U^0``I2G__S;Y``"I*?__-_D``*TI__\X^0``L2G__SGY``"U*?__
M.OD``+DI__\[^0``O2G__SSY``#!*?__/?D``,4I__\^^0``R2G__S_Y``#-
M*?__0/D``",:__]!^0``T2G__T+Y``#5*?__0_D``-DI__]$^0``W2G__T7Y
M``#A*?__1OD``.4I__]'^0``Z2G__TCY``#M*?__2?D``/$I__]*^0``]2G_
M_TOY``#Y*?__3/D``/TI__]-^0```2K__T[Y```%*O__3_D```DJ__]0^0``
M#2K__U'Y```1*O__4OD``!4J__]3^0``&2K__U3Y```=*O__5?D``"$J__]6
M^0``)2K__U?Y```I*O__6/D``"TJ__]9^0``,2K__UKY```U*O__6_D``#DJ
M__]<^0``)2G__UWY```]*O__7OD``$$J__]?^0``12K__V#Y``!)*O__8?D`
M`$TJ__]B^0``42K__V/Y``!5*O__9/D``%DJ__]E^0``72K__V;Y``!A*O__
M9_D``&4J__]H^0``:2K__VGY``!M*O__:OD``'$J__]K^0``=2K__VSY``!Y
M*O__;?D``'TJ__]N^0``@2K__V_Y``"%*O__</D``(DJ__]Q^0``CQG__W+Y
M``"-*O__<_D``)$J__]T^0``E2K__W7Y``"9*O__=OD``)TJ__]W^0``H2K_
M_WCY``"E*O__>?D``*DJ__]Z^0``K2K__WOY``"Q*O__?/D``+4J__]]^0``
MN2K__W[Y``"]*O__?_D``,$J__^`^0``Q2K__X'Y``"C%___@OD``,DJ__^#
M^0``S2K__X3Y``#1*O__A?D``-4J__^&^0``V2K__X?Y``#=*O__B/D``.$J
M__^)^0``Y2K__XKY``!7%___B_D``.DJ__^,^0``[2K__XWY``#Q*O__COD`
M`/4J__^/^0``^2K__Y#Y``#]*O__D?D```$K__^2^0``!2O__Y/Y```)*___
ME/D```TK__^5^0``$2O__Y;Y```5*___E_D``!DK__^8^0``'2O__YGY```A
M*___FOD``"4K__^;^0``*2O__YSY```M*___G?D``#$K__^>^0``-2O__Y_Y
M```Y*___H/D``#TK__^A^0``A2K__Z+Y``!!*___H_D``$4K__^D^0``22O_
M_Z7Y``!-*___IOD``%$K__^G^0``52O__ZCY``!9*___J?D``%TK__^J^0``
M12K__ZOY``!A*___K/D``&4K__^M^0``:2O__Z[Y``!M*___K_D``'$K__^P
M^0``=2O__['Y``!Y*___LOD``'TK__^S^0``@2O__[3Y``"%*___M?D``(DK
M__^V^0``C2O__[?Y``"1*___N/D``)4K__^Y^0``F2O__[KY``"=*___N_D`
M`*$K__^\^0``I2O__[WY``"I*___OOD``*TK__^_^0``)2G__\#Y``"Q*___
MP?D``+4K___"^0``N2O__\/Y``"]*___Q/D``%L:___%^0``P2O__\;Y``#%
M*___Q_D``,DK___(^0``S2O__\GY``#1*___ROD``-4K___+^0``V2O__\SY
M``#=*___S?D``.$K___.^0``Y2O__\_Y``#I*___T/D``.TK___1^0``!R#_
M_]+Y``#Q*___T_D``/4K___4^0``^2O__]7Y``#]*___UOD```$L___7^0``
M!2S__]CY```)+/__V?D```TL___:^0``$2S__]OY``!-*O__W/D``!4L___=
M^0``&2S__][Y```=+/__W_D``"$L___@^0``)2S__^'Y```I+/__XOD``"TL
M___C^0``,2S__^3Y```U+/__Y?D``#DL___F^0``/2S__^?Y``!!+/__Z/D`
M`$4L___I^0``HQG__^KY``!)+/__Z_D``$TL___L^0``42S__^WY``!5+/__
M[OD``%DL___O^0``72S___#Y``!A+/__\?D``&4L___R^0``:2S___/Y``!M
M+/__]/D``'$L___U^0``=2S___;Y``!Y+/__]_D``-\8___X^0``?2S___GY
M``"!+/__^OD``(4L___[^0``B2S___SY``"-+/___?D``)$L___^^0``E2S_
M___Y``"9+/__`/H``)TL__\!^@``H2S__P+Z``"E+/__`_H``*DL__\$^@``
MK2S__P7Z``"Q+/__!OH``+4L__\'^@``N2S__PCZ``!+&?__"?H``+TL__\*
M^@``5QG__POZ``#!+/__#/H``,4L__\-^@``R2S__Q#Z``#-+/__$OH``-$L
M__\5^@``U2S__Q;Z``#9+/__%_H``-TL__\8^@``X2S__QGZ``#E+/__&OH`
M`.DL__\;^@``[2S__QSZ``#Q+/__'?H``/4L__\>^@``^QC__R#Z``#Y+/__
M(OH``/TL__\E^@```2W__R;Z```%+?__*OH```DM__\K^@``#2W__RSZ```1
M+?__+?H``!4M__\P^@``&2W__S'Z```=+?__,OH``"$M__\S^@``)2W__S3Z
M```I+?__-?H``"TM__\V^@``,2W__S?Z```U+?__./H``#DM__\Y^@``/2W_
M_SKZ``!!+?__._H``$4M__\\^@``OQ?__SWZ``!)+?__/OH``$TM__\_^@``
M42W__T#Z``!5+?__0?H``%DM__]"^@``72W__T/Z``!A+?__1/H``&4M__]%
M^@``:2W__T;Z``!M+?__1_H``'$M__](^@``=2W__TGZ``!Y+?__2OH``'TM
M__]+^@``@2W__TSZ```;(/__3?H``(4M__].^@``B2W__T_Z``"-+?__4/H`
M`)$M__]1^@``*R#__U+Z``"5+?__4_H``)DM__]4^@``G2W__U7Z``"A+?__
M5OH``*4M__]7^@``%2O__UCZ``"I+?__6?H``*TM__]:^@``L2W__UOZ``"U
M+?__7/H``+DM__]=^@``O2W__U[Z``"]+?__7_H``,$M__]@^@``Q2W__V'Z
M``#)+?__8OH``,TM__]C^@``T2W__V3Z``#5+?__9?H``-DM__]F^@``W2W_
M_V?Z```!+?__:/H``.$M__]I^@``Y2W__VKZ``#I+?__`/L``/__[2T!^P``
M___P+0+[``#___,M`_L``/__]BT$^P``___Z+07[``#___XM!OL``/___BT3
M^P``__\!+A3[``#__P8N%?L``/__"RX6^P``__\0+A?[``#__Q4N'?L``!HN
M__\?^P``'R[__R#[``#__R0N(?L``/__O!,B^P``___%$R/[``#__R<N)/L`
M`/__*BXE^P``__\M+B;[``#__S`N)_L``/__,RXH^P``__\V+BG[``#__UT3
M*OL``#DN__\K^P``/B[__RS[``!#+O__+?L``$HN__\N^P``42[__R_[``!6
M+O__,/L``%LN__\Q^P``8"[__S+[``!E+O__,_L``&HN__\T^P``;R[__S7[
M``!T+O__-OL``'DN__\X^P``?B[__SG[``"#+O__.OL``(@N__\[^P``C2[_
M_SS[``"2+O__/OL``)<N__]`^P``G"[__T'[``"A+O__0_L``*8N__]$^P``
MJR[__T;[``"P+O__1_L``+4N__](^P``NB[__TG[``"_+O__2OL``,0N__]+
M^P``R2[__TS[``#.+O__3?L``-,N__].^P``V"[__T_[``#__]TN4/L``/__
MXBY1^P``___B+E+[``#__^4N4_L``/__Y2Y4^P``___E+E7[``#__^4N5OL`
M`/__Z"Y7^P``___H+EC[``#__^@N6?L``/__Z"Y:^P``___K+EO[``#__^LN
M7/L``/__ZRY=^P``___K+E[[``#__^XN7_L``/__[BY@^P``___N+F'[``#_
M_^XN8OL``/__\2YC^P``___Q+F3[``#___$N9?L``/__\2YF^P``___T+F?[
M``#___0N:/L``/__]"YI^P``___T+FK[``#___<N:_L``/__]RYL^P``___W
M+FW[``#___<N;OL``/__^BYO^P``___Z+G#[``#___HN<?L``/__^BYR^P``
M___]+G/[``#___TN=/L``/___2YU^P``___]+G;[``#__P`O=_L``/__`"]X
M^P``__\`+WG[``#__P`O>OL``/__`R][^P``__\#+WS[``#__P,O??L``/__
M`R]^^P``__\&+W_[``#__P8O@/L``/__!B^!^P``__\&+X+[``#__PDO@_L`
M`/__"2^$^P``__\,+X7[``#__PPOAOL``/__#R^'^P``__\/+XC[``#__Q(O
MB?L``/__$B^*^P``__\5+XO[``#__Q4OC/L``/__&"^-^P``__\8+X[[``#_
M_QLOC_L``/__&R^0^P``__\;+Y'[``#__QLODOL``/__'B^3^P``__\>+Y3[
M``#__QXOE?L``/__'B^6^P``__\A+Y?[``#__R$OF/L``/__(2^9^P``__\A
M+YK[``#__R0OF_L``/__)"^<^P``__\D+YW[``#__R0OGOL``/__)R^?^P``
M__\G+Z#[``#__RHOH?L``/__*B^B^P``__\J+Z/[``#__RHOI/L``/__M@:E
M^P``__^V!J;[``#__RTOI_L``/__+2^H^P``__\M+ZG[``#__RTOJOL``/__
M,"^K^P``__\P+ZS[``#__S`OK?L``/__,"^N^P``__\S+Z_[``#__S,OL/L`
M`/__P`:Q^P``___`!M/[``#__S8OU/L``/__-B_5^P``__\V+];[``#__S8O
MU_L``/__.2_8^P``__\Y+]G[``#__SPOVOL``/__/"_;^P``__\_+]S[``#_
M_S\OW?L``/__K`;>^P``__]"+]_[``#__T(OX/L``/__12_A^P``__]%+^+[
M``#__T@OX_L``/__2"_D^P``__]++^7[``#__TLOYOL``/__2R_G^P``__]+
M+^C[``#__TXOZ?L``/__3B_J^P``__]1+^O[``#__U$O[/L``/__6"_M^P``
M__]8+^[[``#__U\O[_L``/__7R_P^P``__]F+_'[``#__V8O\OL``/__;2_S
M^P``__]M+_3[``#__W0O]?L``/__="_V^P``__][+_?[``#__WLO^/L``/__
M>R_Y^P``__^"+_K[``#__X(O^_L``/__@B_\^P``__^)+_W[``#__XDO_OL`
M`/__B2__^P``__^)+P#\``#__XPO`?P``/__DR\"_```__^:+P/\``#__X(O
M!/P``/__H2\%_```__^H+P;\``#__ZTO!_P``/__LB\(_```__^W+PG\``#_
M_[PO"OP``/__P2\+_```___&+PS\``#__\LO#?P``/__T"\._```___5+P_\
M``#__]HO$/P``/__WR\1_```___D+Q+\``#__^DO$_P``/__[B\4_```___S
M+Q7\``#___@O%OP``/___2\7_```__\",!C\``#__P<P&?P``/__##`:_```
M__\1,!O\``#__Q8P'/P``/__&S`=_```__\@,![\``#__R4P'_P``/__*C`@
M_```__\O,"'\``#__S0P(OP``/__.3`C_```__\^,"3\``#__T,P)?P``/__
M2#`F_```__]-,"?\``#__U(P*/P``/__5S`I_```__]<,"K\``#__V$P*_P`
M`/__9C`L_```__]K,"W\``#__W`P+OP``/__=3`O_```__]Z,##\``#__W\P
M,?P``/__A#`R_```__^),#/\``#__XXP-/P``/__DS`U_```__^8,#;\``#_
M_YTP-_P``/__HC`X_```__^G,#G\``#__ZPP.OP``/__L3`[_```__^V,#S\
M``#__[LP/?P``/__P#`^_```___%,#_\``#__\HP0/P``/__SS!!_```___4
M,$+\``#__]DP0_P``/__WC!$_```___C,$7\``#__^@P1OP``/__[3!'_```
M___R,$C\``#___<P2?P``/___#!*_```__\!,4O\``#__P8Q3/P``/__"S%-
M_```__\0,4[\``#__Q4Q3_P``/__&C%0_```__\?,5'\``#__R0Q4OP``/__
M*3%3_```__\N,53\``#__S,Q5?P``/__.#%6_```__\],5?\``#__T(Q6/P`
M`/__1S%9_```__],,5K\``#__U$Q6_P``/__5C%<_```__];,5W\``#__V`Q
M7OP``/__93%?_```__]K,6#\``#__W$Q8?P``/__=S%B_```__]],6/\``#_
M_X,Q9/P``/__B3%E_```__^0,6;\``#__YHO9_P``/__ES%H_```__^"+VG\
M``#__Z$O:OP``/__GC%K_```__^C,6S\``#__[<O;?P``/__J#%N_```__^\
M+V_\``#__\$O</P``/__K3%Q_```__^R,7+\``#__]4O<_P``/__MS%T_```
M___:+W7\``#__]\O=OP``/__O#%W_```___!,7C\``#__^DO>?P``/__QC%Z
M_```___N+WO\``#___,O?/P``/__A#!]_```__^),'[\``#__Y@P?_P``/__
MG3"`_```__^B,('\``#__[8P@OP``/__NS"#_```___`,(3\``#__\4PA?P`
M`/__V3"&_```___>,(?\``#__^,PB/P``/__RS&)_```___W,(K\``#__]`Q
MB_P``/__U3&,_```__\5,8W\``#__]HQCOP``/__&C&/_```__\?,9#\``#_
M_V`QD?P``/__WS&2_```___D,9/\``#__T<QE/P``/__Z3&5_```__],,9;\
M``#__U$QE_P``/__C"^8_```__^3+YG\``#__^XQFOP``/__FB^;_```___U
M,9S\``#__Z@OG?P``/__K2^>_```__^R+Y_\``#__[<OH/P``/___#&A_```
M___&+Z+\``#__\LOH_P``/__T"^D_```___5+Z7\``#__P$RIOP``/__Z2^G
M_```___X+ZC\``#___TOJ?P``/__`C"J_```__\',*O\``#__PPPK/P``/__
M%C"M_```__\;,*[\``#__R`PK_P``/__)3"P_```__\J,+'\``#__R\PLOP`
M`/__!C*S_```__\T,+3\``#__SDPM?P``/__/C"V_```__]#,+?\``#__T@P
MN/P``/__33"Y_```__]7,+K\``#__UPPN_P``/__83"\_```__]F,+W\``#_
M_VLPOOP``/__<#"__```__]U,,#\``#__WHPP?P``/__?S#"_```__^.,,/\
M``#__Y,PQ/P``/__IS#%_```__^L,,;\``#__[$PQ_P``/__MC#(_```__^[
M,,G\``#__\HPROP``/__SS#+_```___4,,S\``#__]DPS?P``/__"S+._```
M___H,,_\``#__^TPT/P``/__\C#1_```___W,-+\``#__P8QT_P``/__"S'4
M_```__\0,=7\``#__Q4QUOP``/__$#+7_```__\D,=C\``#__RDQV?P``/__
M%3+:_```__\X,=O\``#__STQW/P``/__0C'=_```__]',=[\``#__QHRW_P`
M`/__FB_@_```___U,>'\``#__[<OXOP``/___#'C_```___5+^3\``#__P$R
MY?P``/__Z2_F_```__\?,N?\``#__RHPZ/P``/__)#+I_```__\I,NK\``#_
M_RXRZ_P``/__MC#L_```__^[,.W\``#__]DP[OP``/__%3'O_```__\0,O#\
M``#__T<Q\?P``/__&C+R_```__\S,O/\``#__SHR]/P``/__03+U_```__](
M,O;\``#__TTR]_P``/__4C+X_```__]7,OG\``#__UPR^OP``/__83+[_```
M__]F,OS\``#__VLR_?P``/__<#+^_```__]U,O_\``#__WHR`/T``/__?S(!
M_0``__^$,@+]``#__XDR`_T``/__CC($_0``__^3,@7]``#__Y@R!OT``/__
MG3('_0``__^B,@C]``#__Z<R"?T``/__K#(*_0``__^Q,@O]``#__[8R#/T`
M`/__*3(-_0``__^[,@[]``#__\`R#_T``/__Q3(0_0``___*,A']``#__T@R
M$OT``/__33(3_0``__]2,A3]``#__U<R%?T``/__7#(6_0``__]A,A?]``#_
M_V8R&/T``/__:S(9_0``__]P,AK]``#__W4R&_T``/__>C(<_0``__]_,AW]
M``#__X0R'OT``/__B3(?_0``__^.,B#]``#__Y,R(?T``/__F#(B_0``__^=
M,B/]``#__Z(R)/T``/__IS(E_0``__^L,B;]``#__[$R)_T``/__MC(H_0``
M__\I,BG]``#__[LR*OT``/__P#(K_0``___%,BS]``#__\HR+?T``/__K#(N
M_0``__^Q,B_]``#__[8R,/T``/__*3(Q_0``__\D,C+]``#__RXR,_T``/__
M4C`T_0``__\;,#7]``#__R`P-OT``/__)3`W_0``__^L,CC]``#__[$R.?T`
M`/__MC(Z_0``__]2,#O]``#__U<P//T``/__SS(]_0``___/,E#]``#__]0R
M4?T``/__VS)2_0``___;,E/]``#__^(R5/T``/__Z3)5_0``___P,E;]``#_
M__<R5_T``/___C)8_0``__\%,UG]``#__P4S6OT``/__##-;_0``__\3,US]
M``#__QHS7?T``/__(3->_0``__\H,U_]``#__R\S8/T``/__+S-A_0``__\V
M,V+]``#__STS8_T``/__/3-D_0``__]$,V7]``#__T0S9OT``/__2S-G_0``
M__]2,VC]``#__U(S:?T``/__63-J_0``__]@,VO]``#__V`S;/T``/__9S-M
M_0``__]G,V[]``#__VXS;_T``/__=3-P_0``__]U,W']``#__WPS<OT``/__
M?#-S_0``__^#,W3]``#__XHS=?T``/__D3-V_0``__^8,W?]``#__Y@S>/T`
M`/__GS-Y_0``__^F,WK]``#__ZTS>_T``/__M#-\_0``__^[,WW]``#__[LS
M?OT``/__PC-__0``___),X#]``#__]`S@?T``/__US."_0``___>,X/]``#_
M_^4SA/T``/__Y3.%_0``___L,X;]``#__^PSA_T``/__\S.(_0``___S,XG]
M``#___HSBOT``/__`32+_0``__\(-(S]``#__P\TC?T``/__%C2._0``__\=
M-(_]``#__R0TDOT``/__*S23_0``__\R-)3]``#__SDTE?T``/__0#26_0``
M__]'-)?]``#__TXTF/T``/__3C29_0``__]5-)K]``#__UPTF_T``/__8S2<
M_0``__]J-)W]``#__VHTGOT``/__<32?_0``__]X-*#]``#__W\TH?T``/__
MAC2B_0``__^--*/]``#__Y0TI/T``/__FS2E_0``__^B-*;]``#__ZDTI_T`
M`/__L#2H_0``__^W-*G]``#__[XTJOT``/__Q32K_0``___,-*S]``#__],T
MK?T``/__VC2N_0``___A-*_]``#__^@TL/T``/__[S2Q_0``___V-++]``#_
M__TTL_T``/__!#6T_0``___",[7]``#__]`SMOT``/__"S6W_0``__\2-;C]
M``#__QDUN?T``/__(#6Z_0``__\G-;O]``#__RXUO/T``/__)S6]_0``__\9
M-;[]``#__S4UO_T``/__/#7`_0``__]#-<']``#__THUPOT``/__437#_0``
M__\N-<3]``#__Y$SQ?T``/__2S/&_0``__]8-<?]``#__U\U\/T``/__9C7Q
M_0``__]M-?+]``#__W0U\_T``/__?37T_0``__^&-?7]``#__X\U]OT``/__
MF#7W_0``__^A-?C]``#__ZHU^?T``/__LS7Z_0``__^Z-?O]``#__]PU_/T`
M`/__[#4P_@``__\'$S'^``#___4U,OX``/__^34S_@``___]-33^``#___TU
M-?X``/__91,V_@``__]G$S?^``#___\U./X``/__`38Y_@``__\#-CK^``#_
M_P<V._X``/__"S8\_@``__\/-CW^``#__Q,V/OX``/__%S8__@``__^4%4#^
M``#__Y@50?X``/__&S9"_@``__\?-D/^``#__R,V1/X``/__)S9)_@``__\S
M$TK^``#__S,32_X``/__,Q-,_@``__\S$TW^``#___TU3OX``/___35/_@``
M___]-5#^``#__RLV4?X``/__+392_@``__\%$U3^``#__^`$5?X``/__,396
M_@``__\S-E?^``#__S4V6/X``/__]359_@``__]E$UK^``#__V<36_X``/__
M_S5<_@``__\!-EW^``#__P,V7OX``/__!S9?_@``__\W-F#^``#__SDV8?X`
M`/__.S9B_@``__]=$V/^``#__STV9/X``/__/S9E_@``__]!-F;^``#__V,3
M:/X``/__0S9I_@``__]%-FK^``#__T<V:_X``/__239P_@``__]+-G'^``#_
M_T\V<OX``/__5#9T_@``__]8-G;^``#__UPV=_X``/__8#9X_@``__]E-GG^
M``#__VDV>OX``/__;C9[_@``__]R-GS^``#__W<V??X``/__>S9^_@``__^`
M-G_^``#__X0V@/X``/__B3:!_@``__^)!H+^``#__XD&@_X``/__C@:$_@``
M__^.!H7^``#__Y,&AOX``/__DP:'_@``__^8!HC^``#__Y@&B?X``/__G0:*
M_@``__^=!HO^``#__YT&C/X``/__G0:-_@``__^,-H[^``#__XPVC_X``/__
MCS:0_@``__^/-I'^``#__X\VDOX``/__CS:3_@``__^2-I3^``#__Y(VE?X`
M`/__E3:6_@``__^5-I?^``#__Y4VF/X``/__E3:9_@``__^8-IK^``#__Y@V
MF_X``/__F#:<_@``__^8-IW^``#__YLVGOX``/__FS:?_@``__^;-J#^``#_
M_YLVH?X``/__GC:B_@``__^>-J/^``#__YXVI/X``/__GC:E_@``__^A-J;^
M``#__Z$VI_X``/__H3:H_@``__^A-JG^``#__Z0VJOX``/__I#:K_@``__^G
M-JS^``#__Z<VK?X``/__JC:N_@``__^J-J_^``#__ZTVL/X``/__K3:Q_@``
M__^P-K+^``#__[`VL_X``/__L#:T_@``__^P-K7^``#__[,VMOX``/__LS:W
M_@``__^S-KC^``#__[,VN?X``/__MC:Z_@``__^V-KO^``#__[8VO/X``/__
MMC:]_@``__^Y-K[^``#__[DVO_X``/__N3;`_@``__^Y-L'^``#__[PVPOX`
M`/__O#;#_@``__^\-L3^``#__[PVQ?X``/__OS;&_@``__^_-L?^``#__[\V
MR/X``/__OS;)_@``___"-LK^``#__\(VR_X``/__PC;,_@``___"-LW^``#_
M_\4VSOX``/__Q3;/_@``___%-M#^``#__\4VT?X``/__R#;2_@``___(-M/^
M``#__\@VU/X``/__R#;5_@``___+-M;^``#__\LVU_X``/__RS;8_@``___+
M-MG^``#__\XVVOX``/__SC;;_@``___.-MS^``#__\XVW?X``/__T3;>_@``
M___1-M_^``#__]$VX/X``/__T3;A_@``___4-N+^``#__]0VX_X``/__U#;D
M_@``___4-N7^``#__]<VYOX``/__US;G_@``___7-NC^``#__]<VZ?X``/__
MVC;J_@``___:-NO^``#__]HV[/X``/__VC;M_@``___=-N[^``#__]TV[_X`
M`/__3B_P_@``__].+_'^``#__^`V\OX``/__X#;S_@``___@-O3^``#__^`V
M]?X``/__XS;V_@``___C-O?^``#__^HV^/X``/__ZC;Y_@``___Q-OK^``#_
M__$V^_X``/__^#;\_@``___X-@'_``#__S4V`O\``/___38#_P``__\W-@3_
M``#__T4V!?\``/__1S8&_P``__\Y-@?_``#___\V"/\``/__91,)_P``__]G
M$PK_``#__SLV"_\``/__71,,_P``__\K-@W_``#__STV#O\``/__!1,/_P``
M__\!-Q#_``#__TT3$?\``/__&P`2_P``__\,`!/_``#__PX`%/\``/__41,5
M_P``__]3$Q;_``#__U43%_\``/__5Q,8_P``__]9$QG_``#__UL3&O\``/__
M,38;_P``___@!!S_``#__S\V'?\``/__8Q,>_P``__]!-A__``#__S,V(/\`
M`/__238A_P``___'%B+_``#__[(3(_\``/__=A,D_P``___5$R7_``#__[83
M)O\``/__N!,G_P``___)%BC_``#__XT3*?\``/__DA,J_P``___+%BO_``#_
M_[`3+/\``/__E!,M_P``__^Z$R[_``#__Y83+_\``/__S18P_P``__^;$S'_
M``#__YT3,O\``/__GQ,S_P``___/%C3_``#__]$6-?\``/__TQ8V_P``__\P
M%#?_``#__]46./\``/__010Y_P``___7%CK_``#__ZL3._\``/__`S<\_P``
M__]#-CW_``#__P4W/O\``/__!S<__P``___]-4#_``#__[X20?\``/__!@!"
M_P``___9%D/_``#__VP41/\``/__UQ-%_P``__^T$T;_``#__]L61_\``/__
MBQ-(_P``__^3!$G_``#__T\32O\``/__F`1+_P``___=%DS_``#__\0$3?\`
M`/__;A1._P``__]I$T__``#__QT`4/\``/__WQ91_P``___A%E+_``#__YH$
M4_\``/__QP)4_P``___C%E7_``#__^465O\``/__5!17_P``__^E!%C_``#_
M_\8$6?\``/__IP1:_P``___G%EO_``#___\U7/\``/__"3==_P``__\!-E[_
M``#__PLW7_\``/__#3=@_P``__\1-V'_``#__Q4W8O\``/__&S9C_P``__\?
M-F3_``#__RTV9?\``/__&3=F_P``__^G(6?_``#__QTW:/\``/__(3=I_P``
M__\E-VK_``#__RDW:_\``/__+3=L_P``__\Q-VW_``#__S4W;O\``/__.3=O
M_P``__\]-W#_``#__T$W<?\``/__[R!R_P``___S('/_``#___<@=/\``/__
M^R!U_P``____(';_``#__P,A=_\``/__!R%X_P``__\+(7G_``#__P\A>O\`
M`/__$R%[_P``__\7(7S_``#__QLA??\``/__'R%^_P``__\C(7__``#__R<A
M@/\``/__*R&!_P``__\O(8+_``#__S,A@_\``/__-R&$_P``__\[(87_``#_
M_S\AAO\``/__0R&'_P``__]'(8C_``#__TLAB?\``/__3R&*_P``__]3(8O_
M``#__U<AC/\``/__6R&-_P``__]?(8[_``#__V,AC_\``/__9R&0_P``__]K
M(9'_``#__V\ADO\``/__<R&3_P``__]W(93_``#__WLAE?\``/__?R&6_P``
M__^#(9?_``#__X<AF/\``/__BR&9_P``__^/(9K_``#__Y,AF_\``/__ER&<
M_P``__^;(9W_``#__T4WGO\``/__23>?_P``__]--Z#_``#__^T<H?\``/__
M(1RB_P``__\E'*/_``#__RD<I/\``/__+1RE_P``__\Q'*;_``#__S4<I_\`
M`/__.1RH_P``__\]'*G_``#__T$<JO\``/__11RK_P``__])'*S_``#__TT<
MK?\``/__41RN_P``__]5'*__``#__UD<L/\``/__71RQ_P``__]A'++_``#_
M_V4<L_\``/__:1RT_P``__]M'+7_``#__W$<MO\``/__=1RW_P``__]Y'+C_
M``#__WT<N?\``/__@1RZ_P``__^%'+O_``#__XD<O/\``/__C1R]_P``__^1
M'+[_``#__Y4<PO\``/__F1S#_P``__^=',3_``#__Z$<Q?\``/__I1S&_P``
M__^I',?_``#__ZT<RO\``/__L1S+_P``__^U',S_``#__[D<S?\``/__O1S.
M_P``___!',__``#__\4<TO\``/__R1S3_P``___-'-3_``#__]$<U?\``/__
MU1S6_P``___9'-?_``#__]T<VO\``/__X1S;_P``___E'-S_``#__^D<X/\`
M`/__43?A_P``__]4-^+_``#__U<WX_\``/__"`#D_P``__]:-^7_``#__UTW
MYO\``/__8#?H_P``__]D-^G_``#__V@WZO\``/__;#?K_P``__]P-^S_``#_
M_W0W[?\``/__>#?N_P``__]\-U[1`0"`-___7]$!`(DW__]@T0$`DC?__V'1
M`0"?-___8M$!`*PW__]CT0$`N3?__V31`0#&-___N]$!`-,W__^\T0$`W#?_
M_[W1`0#E-___OM$!`/(W__^_T0$`_S?__\#1`0`,./__`-0!`/__QQ8!U`$`
M__^R$P+4`0#__W83`]0!`/__U1,$U`$`__^V$P74`0#__[@3!M0!`/__R18'
MU`$`__^-$PC4`0#__Y(3"=0!`/__RQ8*U`$`__^P$PO4`0#__Y03#-0!`/__
MNA,-U`$`__^6$P[4`0#__\T6#]0!`/__FQ,0U`$`__^=$Q'4`0#__Y\3$M0!
M`/__SQ83U`$`___1%A34`0#__],6%=0!`/__,!06U`$`___5%A?4`0#__T$4
M&-0!`/__UQ89U`$`__^K$QK4`0#__P8`&]0!`/__V18<U`$`__]L%!W4`0#_
M_]<3'M0!`/__M!,?U`$`___;%B#4`0#__XL3(=0!`/__DP0BU`$`__]/$R/4
M`0#__Y@$)-0!`/__W18EU`$`___$!";4`0#__VX4)]0!`/__:1,HU`$`__\=
M`"G4`0#__]\6*M0!`/__X18KU`$`__^:!"S4`0#__\<"+=0!`/__XQ8NU`$`
M___E%B_4`0#__U04,-0!`/__I00QU`$`___&!#+4`0#__Z<$,]0!`/__YQ8T
MU`$`___'%C74`0#__[(3-M0!`/__=A,WU`$`___5$SC4`0#__[83.=0!`/__
MN!,ZU`$`___)%CO4`0#__XT3/-0!`/__DA,]U`$`___+%C[4`0#__[`3/]0!
M`/__E!-`U`$`__^Z$T'4`0#__Y830M0!`/__S19#U`$`__^;$T34`0#__YT3
M1=0!`/__GQ-&U`$`___/%D?4`0#__]$62-0!`/__TQ9)U`$`__\P%$K4`0#_
M_]462]0!`/__011,U`$`___7%DW4`0#__ZL33M0!`/__!@!/U`$`___9%E#4
M`0#__VP44=0!`/__UQ-2U`$`__^T$U/4`0#__]L65-0!`/__BQ-6U`$`__]/
M$U?4`0#__Y@$6-0!`/__W199U`$`___$!%K4`0#__VX46]0!`/__:1-<U`$`
M__\=`%W4`0#__]\67M0!`/__X19?U`$`__^:!&#4`0#__\<"8=0!`/__XQ9B
MU`$`___E%F/4`0#__U049-0!`/__I01EU`$`___&!&;4`0#__Z<$9]0!`/__
MYQ9HU`$`___'%FG4`0#__[(3:M0!`/__=A-KU`$`___5$VS4`0#__[83;=0!
M`/__N!-NU`$`___)%F_4`0#__XT3<-0!`/__DA-QU`$`___+%G+4`0#__[`3
M<]0!`/__E!-TU`$`__^Z$W74`0#__Y83=M0!`/__S19WU`$`__^;$WC4`0#_
M_YT3>=0!`/__GQ-ZU`$`___/%GO4`0#__]$6?-0!`/__TQ9]U`$`__\P%'[4
M`0#__]46?]0!`/__012`U`$`___7%H'4`0#__ZL3@M0!`/__!@"#U`$`___9
M%H34`0#__VP4A=0!`/__UQ.&U`$`__^T$X?4`0#__]L6B-0!`/__BQ.)U`$`
M__^3!(K4`0#__T\3B]0!`/__F`2,U`$`___=%HW4`0#__\0$CM0!`/__;A2/
MU`$`__]I$Y#4`0#__QT`D=0!`/__WQ:2U`$`___A%I/4`0#__YH$E-0!`/__
MQP*5U`$`___C%I;4`0#__^46E]0!`/__5!28U`$`__^E!)G4`0#__\8$FM0!
M`/__IP2;U`$`___G%IS4`0#__\<6GM0!`/__=A.?U`$`___5$Z+4`0#__\D6
MI=0!`/__RQ:FU`$`__^P$ZG4`0#__Y83JM0!`/__S1:KU`$`__^;$ZS4`0#_
M_YT3KM0!`/__SQ:OU`$`___1%K#4`0#__],6L=0!`/__,!2RU`$`___5%K/4
M`0#__T$4M-0!`/__UQ:UU`$`__^K$[;4`0#__P8`M]0!`/__V1:XU`$`__]L
M%+G4`0#__]<3N]0!`/__VQ:]U`$`__^3!+[4`0#__T\3O]0!`/__F`3`U`$`
M___=%L+4`0#__VX4P]0!`/__:1/%U`$`___?%L;4`0#__^$6Q]0!`/__F@3(
MU`$`___'`LG4`0#__^,6RM0!`/__Y1;+U`$`__]4%,S4`0#__Z4$S=0!`/__
MQ@3.U`$`__^G!,_4`0#__^<6T-0!`/__QQ;1U`$`__^R$]+4`0#__W83T]0!
M`/__U1/4U`$`__^V$]74`0#__[@3UM0!`/__R1;7U`$`__^-$]C4`0#__Y(3
MV=0!`/__RQ;:U`$`__^P$]O4`0#__Y03W-0!`/__NA/=U`$`__^6$][4`0#_
M_\T6W]0!`/__FQ/@U`$`__^=$^'4`0#__Y\3XM0!`/__SQ;CU`$`___1%N34
M`0#__],6Y=0!`/__,!3FU`$`___5%N?4`0#__T$4Z-0!`/__UQ;IU`$`__^K
M$^K4`0#__P8`Z]0!`/__V1;LU`$`__]L%.W4`0#__]<3[M0!`/__M!/OU`$`
M___;%O#4`0#__XL3\=0!`/__DP3RU`$`__]/$_/4`0#__Y@$]-0!`/__W1;U
MU`$`___$!/;4`0#__VX4]]0!`/__:1/XU`$`__\=`/G4`0#__]\6^M0!`/__
MX1;[U`$`__^:!/S4`0#__\<"_=0!`/__XQ;^U`$`___E%O_4`0#__U04`-4!
M`/__I00!U0$`___&!`+5`0#__Z<$`]4!`/__YQ8$U0$`___'%@75`0#__[(3
M!]4!`/__U1,(U0$`__^V$PG5`0#__[@3"M4!`/__R18-U0$`___+%@[5`0#_
M_[`3#]4!`/__E!,0U0$`__^Z$Q'5`0#__Y83$M4!`/__S183U0$`__^;$Q35
M`0#__YT3%M4!`/__SQ87U0$`___1%AC5`0#__],6&=4!`/__,!0:U0$`___5
M%AO5`0#__T$4'-4!`/__UQ8>U0$`__\&`!_5`0#__]D6(-4!`/__;!0AU0$`
M___7$R+5`0#__[03(]4!`/__VQ8DU0$`__^+$R75`0#__Y,$)M4!`/__3Q,G
MU0$`__^8!"C5`0#__]T6*=4!`/__Q`0JU0$`__]N%"O5`0#__VD3+-4!`/__
M'0`MU0$`___?%B[5`0#__^$6+]4!`/__F@0PU0$`___'`C'5`0#__^,6,M4!
M`/__Y18SU0$`__]4%#35`0#__Z4$-=4!`/__Q@0VU0$`__^G!#?5`0#__^<6
M.-4!`/__QQ8YU0$`__^R$SO5`0#__]43/-4!`/__MA,]U0$`__^X$S[5`0#_
M_\D60-4!`/__DA-!U0$`___+%D+5`0#__[`30]4!`/__E!-$U0$`__^Z$T;5
M`0#__\T62M4!`/__SQ9+U0$`___1%DS5`0#__],63=4!`/__,!1.U0$`___5
M%D_5`0#__T$44-4!`/__UQ92U0$`__\&`%/5`0#__]D65-4!`/__;!15U0$`
M___7$U;5`0#__[035]4!`/__VQ98U0$`__^+$UG5`0#__Y,$6M4!`/__3Q-;
MU0$`__^8!%S5`0#__]T67=4!`/__Q`1>U0$`__]N%%_5`0#__VD38-4!`/__
M'0!AU0$`___?%F+5`0#__^$68]4!`/__F@1DU0$`___'`F75`0#__^,69M4!
M`/__Y19GU0$`__]4%&C5`0#__Z4$:=4!`/__Q@1JU0$`__^G!&O5`0#__^<6
M;-4!`/__QQ9MU0$`__^R$V[5`0#__W83;]4!`/__U1-PU0$`__^V$W'5`0#_
M_[@3<M4!`/__R19SU0$`__^-$W35`0#__Y(3==4!`/__RQ9VU0$`__^P$W?5
M`0#__Y03>-4!`/__NA-YU0$`__^6$WK5`0#__\T6>]4!`/__FQ-\U0$`__^=
M$WW5`0#__Y\3?M4!`/__SQ9_U0$`___1%H#5`0#__],6@=4!`/__,!2"U0$`
M___5%H/5`0#__T$4A-4!`/__UQ:%U0$`__^K$X;5`0#__P8`A]4!`/__V1:(
MU0$`__]L%(G5`0#__]<3BM4!`/__M!.+U0$`___;%HS5`0#__XL3C=4!`/__
MDP2.U0$`__]/$X_5`0#__Y@$D-4!`/__W1:1U0$`___$!)+5`0#__VX4D]4!
M`/__:1.4U0$`__\=`)75`0#__]\6EM4!`/__X1:7U0$`__^:!)C5`0#__\<"
MF=4!`/__XQ::U0$`___E%IO5`0#__U04G-4!`/__I02=U0$`___&!)[5`0#_
M_Z<$G]4!`/__YQ:@U0$`___'%J'5`0#__[(3HM4!`/__=A.CU0$`___5$Z35
M`0#__[83I=4!`/__N!.FU0$`___)%J?5`0#__XT3J-4!`/__DA.IU0$`___+
M%JK5`0#__[`3J]4!`/__E!.LU0$`__^Z$ZW5`0#__Y83KM4!`/__S1:OU0$`
M__^;$[#5`0#__YT3L=4!`/__GQ.RU0$`___/%K/5`0#__]$6M-4!`/__TQ:U
MU0$`__\P%+;5`0#__]46M]4!`/__012XU0$`___7%KG5`0#__ZL3NM4!`/__
M!@"[U0$`___9%KS5`0#__VP4O=4!`/__UQ.^U0$`__^T$[_5`0#__]L6P-4!
M`/__BQ/!U0$`__^3!,+5`0#__T\3P]4!`/__F`3$U0$`___=%L75`0#__\0$
MQM4!`/__;A3'U0$`__]I$\C5`0#__QT`R=4!`/__WQ;*U0$`___A%LO5`0#_
M_YH$S-4!`/__QP+-U0$`___C%L[5`0#__^46S]4!`/__5!30U0$`__^E!-'5
M`0#__\8$TM4!`/__IP33U0$`___G%M35`0#__\<6U=4!`/__LA/6U0$`__]V
M$]?5`0#__]43V-4!`/__MA/9U0$`__^X$]K5`0#__\D6V]4!`/__C1/<U0$`
M__^2$]W5`0#__\L6WM4!`/__L!/?U0$`__^4$^#5`0#__[H3X=4!`/__EA/B
MU0$`___-%N/5`0#__YL3Y-4!`/__G1/EU0$`__^?$^;5`0#__\\6Y]4!`/__
MT1;HU0$`___3%NG5`0#__S`4ZM4!`/__U1;KU0$`__]!%.S5`0#__]<6[=4!
M`/__JQ/NU0$`__\&`._5`0#__]D6\-4!`/__;!3QU0$`___7$_+5`0#__[03
M\]4!`/__VQ;TU0$`__^+$_75`0#__Y,$]M4!`/__3Q/WU0$`__^8!/C5`0#_
M_]T6^=4!`/__Q`3ZU0$`__]N%/O5`0#__VD3_-4!`/__'0#]U0$`___?%O[5
M`0#__^$6_]4!`/__F@0`U@$`___'`@'6`0#__^,6`M8!`/__Y18#U@$`__]4
M%`36`0#__Z4$!=8!`/__Q@0&U@$`__^G!`?6`0#__^<6"-8!`/__QQ8)U@$`
M__^R$PK6`0#__W83"]8!`/__U1,,U@$`__^V$PW6`0#__[@3#M8!`/__R18/
MU@$`__^-$Q#6`0#__Y(3$=8!`/__RQ82U@$`__^P$Q/6`0#__Y03%-8!`/__
MNA,5U@$`__^6$Q;6`0#__\T6%]8!`/__FQ,8U@$`__^=$QG6`0#__Y\3&M8!
M`/__SQ8;U@$`___1%AS6`0#__],6'=8!`/__,!0>U@$`___5%A_6`0#__T$4
M(-8!`/__UQ8AU@$`__^K$R+6`0#__P8`(]8!`/__V18DU@$`__]L%"76`0#_
M_]<3)M8!`/__M!,GU@$`___;%BC6`0#__XL3*=8!`/__DP0JU@$`__]/$RO6
M`0#__Y@$+-8!`/__W18MU@$`___$!"[6`0#__VX4+]8!`/__:1,PU@$`__\=
M`#'6`0#__]\6,M8!`/__X18SU@$`__^:!#36`0#__\<"-=8!`/__XQ8VU@$`
M___E%C?6`0#__U04.-8!`/__I00YU@$`___&!#K6`0#__Z<$.]8!`/__YQ8\
MU@$`___'%CW6`0#__[(3/M8!`/__=A,_U@$`___5$T#6`0#__[830=8!`/__
MN!-"U@$`___)%D/6`0#__XT31-8!`/__DA-%U@$`___+%D;6`0#__[`31]8!
M`/__E!-(U@$`__^Z$TG6`0#__Y832M8!`/__S19+U@$`__^;$TS6`0#__YT3
M3=8!`/__GQ-.U@$`___/%D_6`0#__]$64-8!`/__TQ91U@$`__\P%%+6`0#_
M_]464]8!`/__0114U@$`___7%E76`0#__ZL35M8!`/__!@!7U@$`___9%EC6
M`0#__VP46=8!`/__UQ-:U@$`__^T$UO6`0#__]L67-8!`/__BQ-=U@$`__^3
M!%[6`0#__T\37]8!`/__F`1@U@$`___=%F'6`0#__\0$8M8!`/__;A1CU@$`
M__]I$V36`0#__QT`9=8!`/__WQ9FU@$`___A%F?6`0#__YH$:-8!`/__QP)I
MU@$`___C%FK6`0#__^46:]8!`/__5!1LU@$`__^E!&W6`0#__\8$;M8!`/__
MIP1OU@$`___G%G#6`0#__\<6<=8!`/__LA-RU@$`__]V$W/6`0#__]43=-8!
M`/__MA-UU@$`__^X$W;6`0#__\D6=]8!`/__C1-XU@$`__^2$WG6`0#__\L6
M>M8!`/__L!-[U@$`__^4$WS6`0#__[H3?=8!`/__EA-^U@$`___-%G_6`0#_
M_YL3@-8!`/__G1.!U@$`__^?$X+6`0#__\\6@]8!`/__T1:$U@$`___3%H76
M`0#__S`4AM8!`/__U1:'U@$`__]!%(C6`0#__]<6B=8!`/__JQ.*U@$`__\&
M`(O6`0#__]D6C-8!`/__;!2-U@$`___7$X[6`0#__[03C]8!`/__VQ:0U@$`
M__^+$Y'6`0#__Y,$DM8!`/__3Q.3U@$`__^8!)36`0#__]T6E=8!`/__Q`26
MU@$`__]N%)?6`0#__VD3F-8!`/__'0"9U@$`___?%IK6`0#__^$6F]8!`/__
MF@2<U@$`___'`IW6`0#__^,6GM8!`/__Y1:?U@$`__]4%*#6`0#__Z4$H=8!
M`/__Q@2BU@$`__^G!*/6`0#__^<6J-8!`/__&3BIU@$`__\<.*K6`0#__\L3
MJ]8!`/__'SBLU@$`__\B.*W6`0#__R4XKM8!`/__*#BOU@$`__]Z!;#6`0#_
M_RLXL=8!`/__+CBRU@$`__\Q.+/6`0#__S0XM-8!`/__-SBUU@$`__\Z.+;6
M`0#__STXM]8!`/__SA.XU@$`__]`.+G6`0#__WH%NM8!`/__0SB[U@$`__]&
M.+S6`0#__UX%O=8!`/__23B^U@$`__],.+_6`0#__T\XP-8!`/__K1/!U@$`
M__]2.,+6`0#__U8XP]8!`/__6`7$U@$`___($\76`0#__UDXQM8!`/__?07'
MU@$`__]<.,C6`0#__U\XR=8!`/__6P7*U@$`___$$<O6`0#__W$%S-8!`/__
M8CC-U@$`__\4`,[6`0#__V4XS]8!`/__:#C0U@$`__]K.-'6`0#__VX%TM8!
M`/__=`73U@$`__]W!=36`0#__VXXU=8!`/__<3C6U@$`__]T.-?6`0#__VL%
MV-8!`/__=SC9U@$`__]Z.-K6`0#__WTXV]8!`/__@#C<U@$`__]]!=W6`0#_
M_UL%WM8!`/__<07?U@$`__]K!>#6`0#__W0%X=8!`/__;@7BU@$`__\9../6
M`0#__QPXY-8!`/__RQ/EU@$`__\?..;6`0#__R(XY]8!`/__)3CHU@$`__\H
M..G6`0#__WH%ZM8!`/__*SCKU@$`__\N..S6`0#__S$X[=8!`/__-#CNU@$`
M__\W.._6`0#__SHX\-8!`/__/3CQU@$`___.$_+6`0#__T`X\]8!`/__>@7T
MU@$`__]#./76`0#__T8X]M8!`/__7@7WU@$`__])./C6`0#__TPX^=8!`/__
M3SCZU@$`__^M$_O6`0#__U(X_-8!`/__5CC]U@$`__]8!?[6`0#__\@3_]8!
M`/__63@`UP$`__]]!0'7`0#__UPX`M<!`/__7S@#UP$`__];!037`0#__\01
M!=<!`/__<04&UP$`__]B.`?7`0#__Q0`"-<!`/__93@)UP$`__]H.`K7`0#_
M_VLX"]<!`/__;@4,UP$`__]T!0W7`0#__W<%#M<!`/__;C@/UP$`__]Q.!#7
M`0#__W0X$=<!`/__:P42UP$`__]W.!/7`0#__WHX%-<!`/__?3@5UP$`__^`
M.!;7`0#__WT%%]<!`/__6P48UP$`__]Q!1G7`0#__VL%&M<!`/__=`4;UP$`
M__]N!1S7`0#__QDX'=<!`/__'#@>UP$`___+$Q_7`0#__Q\X(-<!`/__(C@A
MUP$`__\E."+7`0#__R@X(]<!`/__>@4DUP$`__\K."77`0#__RXX)M<!`/__
M,3@GUP$`__\T."C7`0#__S<X*=<!`/__.C@JUP$`__\]."O7`0#__\X3+-<!
M`/__0#@MUP$`__]Z!2[7`0#__T,X+]<!`/__1C@PUP$`__]>!3'7`0#__TDX
M,M<!`/__3#@SUP$`__]/.#37`0#__ZT3-=<!`/__4C@VUP$`__]6.#?7`0#_
M_U@%.-<!`/__R!,YUP$`__]9.#K7`0#__WT%.]<!`/__7#@\UP$`__]?.#W7
M`0#__UL%/M<!`/__Q!$_UP$`__]Q!4#7`0#__V(X0=<!`/__%`!"UP$`__]E
M.$/7`0#__V@X1-<!`/__:SA%UP$`__]N!4;7`0#__W0%1]<!`/__=P5(UP$`
M__]N.$G7`0#__W$X2M<!`/__=#A+UP$`__]K!4S7`0#__W<X3=<!`/__>CA.
MUP$`__]].$_7`0#__X`X4-<!`/__?051UP$`__];!5+7`0#__W$%4]<!`/__
M:P54UP$`__]T!577`0#__VX%5M<!`/__&3A7UP$`__\<.%C7`0#__\L36=<!
M`/__'SA:UP$`__\B.%O7`0#__R4X7-<!`/__*#A=UP$`__]Z!5[7`0#__RLX
M7]<!`/__+CA@UP$`__\Q.&'7`0#__S0X8M<!`/__-SACUP$`__\Z.&37`0#_
M_STX9=<!`/__SA-FUP$`__]`.&?7`0#__WH%:-<!`/__0SAIUP$`__]&.&K7
M`0#__UX%:]<!`/__23ALUP$`__],.&W7`0#__T\X;M<!`/__K1-OUP$`__]2
M.'#7`0#__U8X<=<!`/__6`5RUP$`___($W/7`0#__UDX=-<!`/__?05UUP$`
M__]<.';7`0#__U\X=]<!`/__6P5XUP$`___$$7G7`0#__W$%>M<!`/__8CA[
MUP$`__\4`'S7`0#__V4X?=<!`/__:#A^UP$`__]K.'_7`0#__VX%@-<!`/__
M=`6!UP$`__]W!8+7`0#__VXX@]<!`/__<3B$UP$`__]T.(77`0#__VL%AM<!
M`/__=SB'UP$`__]Z.(C7`0#__WTXB=<!`/__@#B*UP$`__]]!8O7`0#__UL%
MC-<!`/__<06-UP$`__]K!8[7`0#__W0%C]<!`/__;@60UP$`__\9.)'7`0#_
M_QPXDM<!`/__RQ.3UP$`__\?.)37`0#__R(XE=<!`/__)3B6UP$`__\H.)?7
M`0#__WH%F-<!`/__*SB9UP$`__\N.)K7`0#__S$XF]<!`/__-#B<UP$`__\W
M.)W7`0#__SHXGM<!`/__/3B?UP$`___.$Z#7`0#__T`XH=<!`/__>@6BUP$`
M__]#.*/7`0#__T8XI-<!`/__7@6EUP$`__]).*;7`0#__TPXI]<!`/__3SBH
MUP$`__^M$ZG7`0#__U(XJM<!`/__5CBKUP$`__]8!:S7`0#__\@3K=<!`/__
M63BNUP$`__]]!:_7`0#__UPXL-<!`/__7SBQUP$`__];!;+7`0#__\01L]<!
M`/__<06TUP$`__]B.+77`0#__Q0`MM<!`/__93BWUP$`__]H.+C7`0#__VLX
MN=<!`/__;@6ZUP$`__]T!;O7`0#__W<%O-<!`/__;CB]UP$`__]Q.+[7`0#_
M_W0XO]<!`/__:P7`UP$`__]W.,'7`0#__WHXPM<!`/__?3C#UP$`__^`.,37
M`0#__WT%Q=<!`/__6P7&UP$`__]Q!<?7`0#__VL%R-<!`/__=`7)UP$`__]N
M!<[7`0#__TT3S]<!`/__&P#0UP$`__\,`-'7`0#__PX`TM<!`/__41/3UP$`
M__]3$]37`0#__U43U=<!`/__5Q/6UP$`__]9$]?7`0#__UL3V-<!`/__31/9
MUP$`__\;`-K7`0#__PP`V]<!`/__#@#<UP$`__]1$]W7`0#__U,3WM<!`/__
M51/?UP$`__]7$^#7`0#__UD3X=<!`/__6Q/BUP$`__]-$^/7`0#__QL`Y-<!
M`/__#`#EUP$`__\.`.;7`0#__U$3Y]<!`/__4Q/HUP$`__]5$^G7`0#__U<3
MZM<!`/__61/KUP$`__];$^S7`0#__TT3[=<!`/__&P#NUP$`__\,`._7`0#_
M_PX`\-<!`/__41/QUP$`__]3$_+7`0#__U43\]<!`/__5Q/TUP$`__]9$_77
M`0#__UL3]M<!`/__31/WUP$`__\;`/C7`0#__PP`^=<!`/__#@#ZUP$`__]1
M$_O7`0#__U,3_-<!`/__51/]UP$`__]7$_[7`0#__UD3_]<!`/__6Q,`^`(`
MA#C__P'X`@"(./__`O@"`(PX__\#^`(`D#C__P3X`@"5./__!?@"`!DM__\&
M^`(`F3C__P?X`@"=./__"/@"`*$X__\)^`(`I3C__PKX`@`=+?__"_@"`*DX
M__\,^`(`K3C__PWX`@"Q./__#O@"`"$M__\/^`(`MCC__Q#X`@"Z./__$?@"
M`+XX__\2^`(`PCC__Q/X`@#'./__%/@"`,LX__\5^`(`SSC__Q;X`@#3./__
M%_@"`-@X__\8^`(`W#C__QGX`@#@./__&O@"`.0X__\;^`(`Z#C__QSX`@#L
M./__'?@"`$\7__\>^`(`\3C__Q_X`@#U./__(/@"`/DX__\A^`(`_3C__R+X
M`@`!.?__(_@"``4Y__\D^`(`"3G__R7X`@`-.?__)O@"`"4M__\G^`(`*2W_
M_RCX`@`1.?__*?@"`!4Y__\J^`(`&3G__ROX`@!5*O__+/@"`!TY__\M^`(`
M+2W__R[X`@`A.?__+_@"`"4Y__\P^`(`*3G__S'X`@`M.?__,O@"`"TY__\S
M^`(`+3G__S3X`@`Q.?__-?@"`#8Y__\V^`(`.CG__S?X`@`^.?__./@"`$(Y
M__\Y^`(`1SG__SKX`@!+.?__._@"`$\Y__\\^`(`4SG__SWX`@!7.?__/O@"
M`%LY__\_^`(`7SG__T#X`@!C.?__0?@"`&<Y__]"^`(`:SG__T/X`@!O.?__
M1/@"`',Y__]%^`(`=SG__T;X`@!W.?__1_@"`'LY__](^`(`?SG__TGX`@"#
M.?__2O@"`(<Y__]+^`(`BSG__TSX`@`U+?__3?@"`(\Y__].^`(`DSG__T_X
M`@"7.?__4/@"`)TL__]1^`(`FSG__U+X`@"?.?__4_@"`*,Y__]4^`(`ISG_
M_U7X`@"K.?__5O@"`*\Y__]7^`(`LSG__UCX`@"W.?__6?@"`+LY__]:^`(`
MP#G__UOX`@#$.?__7/@"`,@Y__]=^`(`S#G__U[X`@#0.?__7_@"`-0Y__]@
M^`(`V#G__V'X`@#=.?__8O@"`.(Y__]C^`(`YCG__V3X`@#J.?__9?@"`.XY
M__]F^`(`\CG__V?X`@#V.?__:/@"`/HY__]I^`(`_SG__VKX`@`#.O__:_@"
M``,Z__]L^`(`!SK__VWX`@`,.O__;O@"`!`Z__]O^`(`12K__W#X`@`4.O__
M<?@"`!@Z__]R^`(`'3K__W/X`@`A.O__=/@"`"4Z__]U^`(`MQ?__W;X`@`I
M.O__=_@"`"TZ__]X^`(`OQ?__WGX`@`Q.O__>O@"`#4Z__][^`(`.3K__WSX
M`@`^.O__??@"`$(Z__]^^`(`1SK__W_X`@!+.O__@/@"`$\Z__^!^`(`4SK_
M_X+X`@!7.O__@_@"`%LZ__^$^`(`7SK__X7X`@!C.O__AO@"`&<Z__^'^`(`
M:SK__XCX`@!O.O__B?@"`',Z__^*^`(`>#K__XOX`@!\.O__C/@"`(`Z__^-
M^`(`A#K__X[X`@!U*?__C_@"`(@Z__^0^`(`YQ?__Y'X`@"-.O__DO@"`(TZ
M__^3^`(`DCK__Y3X`@"6.O__E?@"`)8Z__^6^`(`FCK__Y?X`@">.O__F/@"
M`*,Z__^9^`(`J#K__YKX`@"L.O__F_@"`+`Z__^<^`(`M#K__YWX`@"X.O__
MGO@"`+PZ__^?^`(`P#K__Z#X`@#$.O__H?@"`,@Z__^B^`(`S#K__Z/X`@!)
M+?__I/@"`-`Z__^E^`(`U3K__Z;X`@#9.O__I_@"`-TZ__^H^`(`X3K__ZGX
M`@#=.O__JO@"`.4Z__^K^`(`42W__ZSX`@#I.O__K?@"`.TZ__^N^`(`\3K_
M_Z_X`@#U.O__L/@"`%4M__^Q^`(`"2G__[+X`@#Y.O__L_@"`/TZ__^T^`(`
M`3O__[7X`@`%.___MO@"``D[__^W^`(`#3O__[CX`@`1.___N?@"`!8[__^Z
M^`(`&CO__[OX`@`>.___O/@"`"([__^]^`(`)CO__[[X`@`J.___O_@"`"\[
M___`^`(`,SO__\'X`@`W.___PO@"`#L[___#^`(`/SO__\3X`@!#.___Q?@"
M`$<[___&^`(`2SO__\?X`@!/.___R/@"`%DM___)^`(`4SO__\KX`@!7.___
MR_@"`%P[___,^`(`8#O__\WX`@!D.___SO@"`&@[___/^`(`82W__]#X`@!L
M.___T?@"`'`[___2^`(`=#O__]/X`@!X.___U/@"`'P[___5^`(`@#O__];X
M`@"$.___U_@"`(@[___8^`(`>2G__]GX`@",.___VO@"`)`[___;^`(`E#O_
M_]SX`@"8.___W?@"`)P[___>^`(`H3O__]_X`@"E.___X/@"`*D[___A^`(`
MK3O__^+X`@!E+?__X_@"`+$[___D^`(`MCO__^7X`@"Z.___YO@"`+X[___G
M^`(`PCO__^CX`@#&.___Z?@"`,H[___J^`(`SCO__^OX`@#2.___[/@"`-8[
M___M^`(`VSO__^[X`@#?.___[_@"`.,[___P^`(`YSO___'X`@#L.___\O@"
M`/`[___S^`(`]#O___3X`@#X.___]?@"`(DJ___V^`(`_#O___?X`@``//__
M^/@"``4\___Y^`(`"CS___KX`@`///__^_@"`!,\___\^`(`&#S___WX`@`<
M//___O@"`"`\____^`(`)#S__P#Y`@`H//__`?D"`&DM__\"^0(`U2O__P/Y
M`@`L//__!/D"`#`\__\%^0(`-#S__P;Y`@`X//__!_D"`#T\__\(^0(`03S_
M_PGY`@!%//__"OD"`$D\__\+^0(`33S__PSY`@!1//__#?D"`%4\__\.^0(`
M6CS__P_Y`@!>//__$/D"`&(\__\1^0(`9SS__Q+Y`@!L//__$_D"`'`\__\4
M^0(`=#S__Q7Y`@!X//__%OD"`'P\__\7^0(`@#S__QCY`@"$//__&?D"`(@\
M__\:^0(`C#S__QOY`@"0//__'/D"`)4\__\=^0(`F3S__Q[Y`@">//__'_D"
M`*(\__\@^0(`ICS__R'Y`@"J//__(OD"`*X\__\C^0(`LCS__R3Y`@"W//__
M)?D"`+L\__\F^0(`OSS__R?Y`@#$//__*/D"`,D\__\I^0(`S3S__RKY`@#1
M//__*_D"`-4\__\L^0(`V3S__RWY`@#9//__+OD"`-T\__\O^0(`X3S__S#Y
M`@#E//__,?D"`.D\__\R^0(`[3S__S/Y`@#Q//__-/D"`/4\__\U^0(`^3S_
M_S;Y`@#^//__-_D"``(]__\X^0(`42K__SGY`@`'/?__.OD"``P]__\[^0(`
M$#W__SSY`@`5/?__/?D"`!H]__\^^0(`'SW__S_Y`@`C/?__0/D"`"<]__]!
M^0(`*SW__T+Y`@`P/?__0_D"`#4]__]$^0(`.CW__T7Y`@`_/?__1OD"`$,]
M__]'^0(`0SW__TCY`@!'/?__2?D"`$L]__]*^0(`3SW__TOY`@!3/?__3/D"
M`%<]__]-^0(`6SW__T[Y`@!@/?__3_D"`+TI__]0^0(`9#W__U'Y`@!H/?__
M4OD"`&P]__]3^0(`D2W__U3Y`@!Q/?__5?D"`'8]__]6^0(`[2S__U?Y`@![
M/?__6/D"`'\]__]9^0(`G2W__UKY`@"#/?__6_D"`(<]__]<^0(`BSW__UWY
M`@"0/?__7OD"`)`]__]?^0(`E3W__V#Y`@"9/?__8?D"`)T]__]B^0(`HCW_
M_V/Y`@"F/?__9/D"`*H]__]E^0(`KCW__V;Y`@"S/?__9_D"`+<]__]H^0(`
MNSW__VGY`@"_/?__:OD"`,,]__]K^0(`QSW__VSY`@#,/?__;?D"`-`]__]N
M^0(`U#W__V_Y`@#8/?__</D"`-P]__]Q^0(`X#W__W+Y`@#D/?__<_D"`.D]
M__]T^0(`[CW__W7Y`@#R/?__=OD"`/<]__]W^0(`^SW__WCY`@``/O__>?D"
M``0^__]Z^0(`M2W__WOY`@`(/O__?/D"``T^__]]^0(`$C[__W[Y`@`6/O__
M?_D"`!L^__^`^0(`'S[__X'Y`@`D/O__@OD"`"@^__^#^0(`+#[__X3Y`@`P
M/O__A?D"`#0^__^&^0(`.#[__X?Y`@`\/O__B/D"`$$^__^)^0(`1C[__XKY
M`@!+/O__B_D"`)(Z__^,^0(`4#[__XWY`@!4/O__COD"`%@^__^/^0(`7#[_
M_Y#Y`@!@/O__D?D"`&0^__^2^0(`:#[__Y/Y`@!L/O__E/D"`'`^__^5^0(`
M=#[__Y;Y`@!X/O__E_D"`'P^__^8^0(`E2K__YGY`@"!/O__FOD"`(4^__^;
M^0(`B3[__YSY`@"-/O__G?D"`)$^__^>^0(`E3[__Y_Y`@#!+?__H/D"`)D^
M__^A^0(`G3[__Z+Y`@"A/O__H_D"`*4^__^D^0(`J3[__Z7Y`@"N/O__IOD"
M`+,^__^G^0(`N#[__ZCY`@"\/O__J?D"`,`^__^J^0(`Q#[__ZOY`@#(/O__
MK/D"`,T^__^M^0(`T3[__Z[Y`@#6/O__K_D"`-H^__^P^0(`WC[__['Y`@#C
M/O__LOD"`.@^__^S^0(`[#[__[3Y`@"I*?__M?D"`/`^__^V^0(`]#[__[?Y
M`@#X/O__N/D"`/P^__^Y^0(``#___[KY`@`$/___N_D"``@___^\^0(`##__
M_[WY`@`0/___OOD"`!0___^_^0(`&#___\#Y`@`</___P?D"`"`____"^0(`
M)#___\/Y`@`H/___Q/D"`$\9___%^0(`+#___\;Y`@`Q/___Q_D"`#4____(
M^0(`.3___\GY`@`]/___ROD"`$$____+^0(`13___\SY`@!*/___S?D"`$\_
M___.^0(`4S___\_Y`@!7/___T/D"`%L____1^0(`7S___]+Y`@!K&?__T_D"
M`&,____4^0(`:#___]7Y`@!L/___UOD"`'`____7^0(`=#___]CY`@!X/___
MV?D"`'T____:^0(`@C___]OY`@"&/___W/D"`(H____=^0(`CC___][Y`@"3
M/___W_D"`)<____@^0(`FS___^'Y`@"@/___XOD"`*4____C^0(`J3___^3Y
M`@"M/___Y?D"`+$____F^0(`MC___^?Y`@"Z/___Z/D"`+X____I^0(`PC__
M_^KY`@#&/___Z_D"`,H____L^0(`SC___^WY`@#2/___[OD"`-<____O^0(`
MVS____#Y`@#?/___\?D"`.,____R^0(`Z#____/Y`@#L/___]/D"`/`____U
M^0(`]#____;Y`@#X/___]_D"`/T____X^0(``D#___GY`@`&0/__^OD"``I`
M___[^0(`#D#___SY`@`30/___?D"`!=`___^^0(`'$#____Y`@`<0/__`/H"
M`"!`__\!^@(`)$#__P+Z`@`I0/__`_H"`"U`__\$^@(`,4#__P7Z`@`U0/__
M!OH"`#E`__\'^@(`/4#__PCZ`@!!0/__"?H"`$5`__\*^@(`2D#__POZ`@!.
M0/__#/H"`%)`__\-^@(`5D#__P[Z`@!:0/__#_H"`%Y`__\0^@(`8D#__Q'Z
M`@!G0/__$OH"`&M`__\3^@(`<$#__Q3Z`@!U0/__%?H"`"L:__\6^@(`>D#_
M_Q?Z`@`[&O__&/H"`'Y`__\9^@(`@D#__QKZ`@"&0/__&_H"`(I`__\<^@(`
M3QK__QWZ`@".0/__``````````#``,$`P@##```!`@$F`L0`HA[%````S0$`
M`@("````````H!X````>``````0!````````````````````````````````
M``````(>```````````````````````````$'@`````````````````````&
M'@`````````````&`0@!````````"@$```````````P!````````````````
M````````QP`````````````````````````````````````````*'@``````
M````#@$`````````````#!X````````0'@``$AX`````#AX``````````,@`
MR0#*`+P>$@$4`18!RP"Z'@`````:`00"!@(```````"X'@```````"@"&`$8
M'@``&AX```````````````#T`1P!```@'AX!(`$``````````.8!````````
M````````````````(@$`````````````````````````````)`$````````B
M'B8>````````'@(`````````````)!X````````H'@`````J'@``````````
M`````,P`S0#.`"@!*@$L`3`!SP#('@````#/`0@""@(```````#*'@``````
M````+@$`````+!X````````````````P'@```````````````````````.@!
M`````````````#(>````````-@$``````````#0>`````````````#D!````
M````````````````````/0$`````````````-AX````````[`0``/!X`````
M.AX`````````````/AX``````````$`>``````````````````````````!"
M'@``````````````````````````````````^`%#`0``T0``````1!X`````
M`````$<!`````````````$8>````````10$``$H>`````$@>``````````#2
M`-,`U`#5`$P!3@$N`M8`SAX``%`!T0$,`@X"`````*`!S!X``````````.H!
M````````````````````````5!X``````````%8>````````````````````
M``````````````````````````````````````````````!4`0``````````
M6!X``````````%@!$`(2`@```````%H>````````5@$``````````%X>````
M`````````%H!7`$```````!@'@``````````8`$`````````````8AX`````
M&`)>`0```````````````````````````````````````&H>``````````!D
M`0````````````!L'@`````:`F(!``!P'@````!N'@``````````V0#:`-L`
M:`%J`6P!``#<`.8>;@%P`=,!%`(6`@````"O`>0><AX```````!R`78>``!T
M'@````````````````````!\'@``````````````````````````````````
M?AX``````````````````````````````````(`>@AYT`0```````(8>A!X`
M``````````````````````"('@``````````````````````````````````
M````````````````BAZ,'@``````````````````````````````````````
M``````````````````````#R'MT`=@'X'C("``".'G@!]AX`````````````
M````````]!X`````````````````````````````````````>0&0'@``````
M`'L!``````````!]`0````````````"2'@````````````````````"4'@``
M````````X`#A`.(`XP`!`0,!)P+D`*,>Y0```,X!`0(#`@```````*$>```!
M'@`````%`0`````````````````````````````````````#'@``````````
M````````````````!1X`````````````````````!QX`````````````!P$)
M`0````````L!```````````-`0```````````````````````.<`````````
M````````````````````````````````"QX```````````\!````````````
M``T>````````$1X``!,>``````\>``````````#H`.D`Z@"]'A,!%0$7`>L`
MNQX`````&P$%`@<"````````N1X````````I`AD!&1X``!L>````````````
M````]0$=`0``(1X?`2$!``````````#G`0```````````````````````",!
M`````````````````````````````"4!````````(QXG'@```````!\"````
M`````````"4>````````*1X`````*QX``)8>``````````#L`.T`[@`I`2L!
M+0$``.\`R1X`````T`$)`@L"````````RQX``````````"\!`````"T>````
M```````````````U`0````````````````````#P`0``````````````````
M```````````````````````````````````Q'@``````````````````````
M`.D!`````````````#,>````````-P$``````````#4>`````````````#H!
M````````````````````````/@$`````````````-QX````````\`0``/1X`
M````.QX`````````````/QX``````````$$>````````````````````````
M``!#'@``````````````````````````````````^0%$`0``\0``````11X`
M`````````$@!`````````````$<>````````1@$``$L>`````$D>````````
M``#R`/,`]`#U`$T!3P$O`O8`SQX``%$!T@$-`@\"`````*$!S1X`````````
M`.L!````````````````````````51X``````````%<>````````````````
M``````````````````````````````````````````````````!5`0``````
M````61X``````````%D!$0(3`@```````%L>````````5P$``````````%\>
M`````````````%L!70$```````!A'@``````````80$`````````````8QX`
M````&0)?`0```````````````````````````````````````&L>EQX`````
M``!E`0````````````!M'@`````;`F,!``!Q'@````!O'@``````````^0#Z
M`/L`:0%K`6T!``#\`.<>;P%Q`=0!%0(7`@````"P`>4><QX```````!S`7<>
M``!U'@````````````````````!]'@``````````````````````````````
M````?QX``````````````````````````````````($>@QYU`0```````(<>
MA1X``)@>``````````````````")'@``````````````````````````````
M````````````````````BQZ-'@``````````````````````````````````
M``````````````````````````#S'OT`=P'Y'C,"``"/'O\`]QZ9'@``````
M````````````]1X`````````````````````````````````````>@&1'@``
M`````'P!``````````!^`0````````````"3'@````````````````````"5
M'@``````````[1^%`P``````````````````````````````````````````
M````````````````````````P1\```````"F'J0>``"J'@``````````J!X`
M````````````````````````````````````````````````````````````
M_`$`````X@$`````````````````````````````````````````````````
M````````````````````P!Z^'@``Q!X``````````,(>````````````````
M``````````````````````````````````````````#2'M`>``#6'@``````
M````U!X`````````````````````````````````````````````````````
M````````3!X`````+`(`````3AX`````````````````````````````````
M````````````````````````````VP'7`0````#5`0```````````````-D!
M``````````````````````````````````````````````````"G'J4>``"K
M'@``````````J1X`````````````````````````````````````````````
M````````````````_0$`````XP$`````````````````````````````````
M````````````````````````````````````P1Z_'@``Q1X``````````,,>
M``````````````````````````````````````````````````````````#3
M'M$>``#7'@``````````U1X`````````````````````````````````````
M````````````````````````31X`````+0(`````3QX`````````````````
M````````````````````````````````````````````W`'8`0````#6`0``
M`````````````-H!````````````````````````````````````````````
M``````"P'JX>``"T'@``````````LAX`````````````````````````````
M`````````````````````````````+$>KQX``+4>``````````"S'@``````
M````````````````````````````````````````````````````%!X6'@``
M````````````````````````````````````````````````````````````
M```````````````5'A<>````````````````````````````````````````
M`````````````````````````````````````%`>4AX`````````````````
M````````````````````````````````````````````````````````````
M41Y3'@``````````````````````````````````````````````````````
M``````````````````````#<'MH>``#@'@``````````WAX`````````````
M````````XAX``````````````````````````````````-T>VQX``.$>````
M``````#?'@````````````````````#C'@``````````````````````````
M````````ZA[H'@``[AX``````````.P>`````````````````````/`>````
M``````````````````````````````#K'ND>``#O'@``````````[1X`````
M````````````````\1X``````````````````````````````````+H?A@,`
M````N1^X'P`````````````````````('PD?````````````````````````
M````````O!\`````R!^(`P```````````````````````````````!@?&1\`
M``````````````````````````````````````#*'XD#````````````````
M````````````````*!\I'P```````````````````````````````,P?````
M`-H?B@,`````V1_8'P``J@,````````````````X'SD?````````````````
M````````````````````````^!^,`P``````````````````````````````
M`$@?21\```````````````````````````````````````#J'XX#`````.D?
MZ!\``*L#``````````````````!9'P``````````````````````````````
M`````````/H?CP,```````````````````````````````!H'VD?````````
M````````````````````````_!\`````<!^L`P````"Q'[`?````````````
M```````````?`1\`````````````````````````````MA^S'P````!R'ZT#
M````````````````````````````````$!\1'P``````````````````````
M`````````````````'0?K@,````````````````````````````````@'R$?
M`````````````````````````````,8?PQ\`````=A^O`P````#1']`?``#*
M`P```````````````#`?,1\`````````````````````````````UA\`````
M``!X'\P#````````````````````````````````0!]!'P``````````````
M````````````````````````````````````````````````````````````
M``#D'^4?````````````````````````````````````````>A_-`P````#A
M'^`?``#+`P```````````````%`?41\`````````````````````````````
MYA\```````!\'\X#````````````````````````````````8!]A'P``````
M``````````````````````#V'_,?`````-(?D`,`````````````````````
M`````````````````````````````````````````````-<?````````XA^P
M`P``````````````````````````````````````````````````````````
M````````YQ\``````````-,#`````````````-0#````````````````````
M``````````````````````````````````````````````````````#0!```
MT@0`````````````````````````````````````````````````````````
M``````0``````````-8$```!!```````````````````````````````````
M````````````````````````````````````````P00``-P$````````````
M``````````````````````````````````````````````````T$````````
MX@09!```Y`0`````````````````````````````````````````````````
M``````````````````````#N!`X$``#P!`````#R!```````````````````
M````````````````````````````````````````````````T00``-,$````
M`````````````````````````````````````````````````````````%`$
M``````````#7!```400`````````````````````````````````````````
M`````````````````````````````````,($``#=!```````````````````
M``````````````````````````````````````````!=!````````.,$.00`
M`.4$````````````````````````````````````````````````````````
M````````````````[P1>!```\00`````\P0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````K!X`````MAX`````````````````````````````````````
M``````````````````````````````````"M'@````"W'@``````````````
M`````````````````````````````````````````````````````A\$'P``
M````````````````````````````````````````````````````````````
M````!A^`'P`````#'P4?````````````````````````````````````````
M```````````````````````````''X$?``````H?#!\`````````````````
M``````````````````````````````````````````````````X?B!\`````
M"Q\-'P``````````````````````````````````````````````````````
M````````````#Q^)'P`````2'Q0?````````````````````````````````
M`````````````````````````````````````````````!,?%1\`````````
M````````````````````````````````````````````````````````````
M````````&A\<'P``````````````````````````````````````````````
M```````````````````````````````;'QT?````````````````````````
M`````````````````````````````````````````````````````"(?)!\`
M````````````````````````````````````````````````````````````
M`````"8?D!\`````(Q\E'P``````````````````````````````````````
M````````````````````````````)Q^1'P`````J'RP?````````````````
M```````````````````````````````````````````````````N'Y@?````
M`"L?+1\`````````````````````````````````````````````````````
M`````````````"\?F1\`````,A\T'P``````````````````````````````
M````````````````````````````````````-A\````````S'S4?````````
M```````````````````````````````````````````````````````````W
M'P```````#H?/!\`````````````````````````````````````````````
M`````````````````````#X?````````.Q\]'P``````````````````````
M````````````````````````````````````````````/Q\```````!"'T0?
M````````````````````````````````````````````````````````````
M`````````````````$,?11\`````````````````````````````````````
M````````````````````````````````````````2A],'P``````````````
M````````````````````````````````````````````````````````````
M``!+'TT?````````````````````````````````````````````````````
M`````````````````````````%(?5!\`````````````````````````````
M`````````````````````````````````````%8?````````4Q]5'P``````
M````````````````````````````````````````````````````````````
M5Q\```````!;'UT?````````````````````````````````````````````
M``````````````````````!?'P```````&(?9!\`````````````````````
M`````````````````````````````````````````````&8?H!\`````8Q]E
M'P``````````````````````````````````````````````````````````
M````````9Q^A'P````!J'VP?````````````````````````````````````
M``````````````````````````````!N'Z@?`````&L?;1\`````````````
M`````````````````````````````````````````````````````&\?J1\`
M````S1_.'P``````````````````````````````````````````````````
M````````````````SQ\```````#=']X?````````````````````````````
M``````````````````````````````````````#?'P``````````````````
M````````````````````````````````````````````````````````````
M``````!P,'$P````````````````````````````````````````````````
M`````````````````````````````',P=#``````````````````````````
M````````````````````````````````````````````````````=C!W,```
M````````````````````````````````````````````````````````````
M``````````````!Y,'HP````````````````````````````````````````
M`````````````````````````````````````'PP?3``````````````````
M````````````````````````````````````````````````````````````
MT##1,```````````````````````````````````````````````````````
M``````````````````````#3,-0P````````````````````````````````
M`````````````````````````````````````````````-8PUS``````````
M````````````````````````````````````````````````````````````
M````````V3#:,```````````````````````````````````````````````
M``````````````````````````````#<,-TP`````"<&(@8G!B,&)P8E!L<)
MRPG'"<P)1PM+"T<+2`M'"TP+Q@O*"\8+S`O&#,H,Q@S'#,8,R`Q&#4H-1@U,
M#=D-V@W9#=P-V0W>#0```````````````````````````````#@#;B(X`V`B
M.`-O(@<#'AX"`S0!!P,?'@0#W@$!`_H!`0,('@$#+AX$`RH"`0/^`00#WP$!
M`_L!`0,)'@$#+QX$`RL"`0/_`0<#9!X'`V4>!P-F'@<#9QX!`W@>`0-Y'@@#
M>AX(`WL>!P.;'@P#[@$$`^P!!`/M`00#X`$$`^$!!@,<'@8#'1X$`S`"!`,Q
M`@P#[P$4`^P?10.T'T4#Q!]%`_0?"`,'!`$#`P0(`]X$`0,,!`@#Y@0(`_0$
M"`/X!`@#[`0!`U,$"`/?!`$#7`0(`^<$"`/U!`@#^00(`^T$"`-7!`\#=@0/
M`W<$"`/:!`@#VP0(`^H$"`/K!%0&)`94!B8&5`;"!E0&TP94!L`&/`DI"3P)
M,0D\"30)UPN4"[X+RPM6#$@,U0S`#-4,RPP^#4L-R@W=#2X0)A`$`S@>!`,Y
M'@0#7!X$`UT>!P-H'@<#:1X"`\8>`@/''@(#V!X"`]D>10."'T4#@Q]%`X0?
M10.%'T4#AA]%`X<?10.*'T4#BQ]%`XP?10.-'T4#CA]%`X\?10.2'T4#DQ]%
M`Y0?10.5'T4#EA]%`Y<?10.:'T4#FQ]%`YP?10.='T4#GA]%`Y\?10.B'T4#
MHQ]%`Z0?10.E'T4#IA]%`Z<?10.J'T4#JQ]%`ZP?10.M'T4#KA]%`Z\?10.R
M'T4#PA]%`_(?10.W'T4#QQ]%`_<?.`.:(3@#FR$X`ZXA.`/-(3@#SR$X`\XA
M.`,$(C@#"2(X`PPB.`,D(C@#)B(X`T$B.`-$(C@#1R(X`TDB.`-M(C@#8B(X
M`W`B.`-Q(C@#="(X`W4B.`-X(C@#>2(X`X`B.`.!(C@#X"(X`^$B.`.$(C@#
MA2(X`X@B.`.)(C@#XB(X`^,B.`.L(C@#K2(X`ZXB.`.O(C@#ZB(X`^LB.`/L
M(C@#[2*9,)0PF3!,,)DP3C"9,%`PF3!2,)DP5#"9,%8PF3!8,)DP6C"9,%PP
MF3!>,)DP8#"9,&(PF3!E,)DP9S"9,&DPF3">,)DP]#"9,*PPF3"N,)DPL#"9
M,+(PF3"T,)DPMC"9,+@PF3"Z,)DPO#"9,+XPF3#`,)DPPC"9,,4PF3#',)DP
MR3"9,/<PF3#X,)DP^3"9,/HPF3#^,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````),`E`"5```````!``(`
M`P`$``4`E@`&``<`"`"7``D`"@`+``P`#0`.````#P`0`!$`$@`3`!0`%0`6
M`!<`````````````````&``9`!H`&P`<`)@`'0`>`!\`(``A`"(`(P`D`"4`
M)@```"<`*``I`"H`*P`L`"T`+@`O````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#``````````````````````````````
M```````````````````````````````````````Q````F0":`#(`FP``````
M,P```````````)P````````````T`#4`G0```)X`````````-@``````````
M````-P```)\`H``X`*$``````#D```````````"B````````````.@`[`*,`
M``"D`````````#P``````````````#T`/@``````````````````````````
M````````````/P!`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!!`$(`````````
M````````````````````````I0"F````````````IP"H````````````````
M`*D`J@"K`*P`````````````````````````````````````````````````
M``"M````````````````````````````````````````````````````````
M``````````````````````````````!#`$0`````````````````````````
M``````````!%`$8`````````````````K@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````KP"P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````L0"R`+,`M````````````+4`M@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````MP``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````&4!9@%G`6@!:0$``&H!:P%L`6T!;@%O`7`!`````'$!``!R`0``
M<P%T`0```````````````'4!``````````````````!V`7<!>`%Y`7H!>P$`
M`````````'P!?0$``'X!?P$`````````````````````````````````````
M`````(`!`````($!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1P````````!(````20```$H`
M`````````````$L```"X`````````$P`````````30``````N0```+H`````
M`$X`````````3P```%````!1``````````````!2````4P````````!4````
M`````%4`5@!7``````"[`````````%@`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````O```````````
M``````````````!9``````"]````6@!;`+X`7````+\`````````P```````
M`````%T`````````P0````````#"````PP``````7@``````Q````%\`8`#%
M`&$```#&`````````,<```````````!B`````````,@`````````R0```,H`
M`````````````````````,L`````````````````````````````````````
M`````````````````````````````````````````,P`S0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````S@#/``````````````````````````````````````#0`-$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!C````````````````````
M````````````````````````````````````````````````````````````
M``````#2````TP``````````````````````A`&%`88!````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-0`````````````````````````````
M``````````````#5``````#6````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````UP```````````````````-@``````-D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````AP$`````````````
M````````9`````````````````````````````````````````"(`0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(D!`````````````````````&4`````````
M`````````````````````````````(H!BP$`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````",`0``````````````````9@#;````````````````````````````
M`````````````(T!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-P`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````W0``````C@$```````!G````````
M`-X```````````````````````````"/`9`!````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"1`0``````````````````:`#?````````````````````````
M`````````````````)(!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````DP$``````````)0!````````````````````
M````:0``````X```````E0$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#A````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#B`.,`````````````````````
M````````````````````````````````````````````````````````````
M``````````#D`.4`````````````````Y@#G````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````&H`:P``````````````````````````````````````
M`````````````````````.@`Z0``````````````````````````````````
M``````````````#J`.L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````&P`;0#L`.T`[@#O`/``\0!N`&\`
M\@#S`/0`]0#V`/<`<`!Q`````````````````'(`<P````````````````!T
M`'4`^`#Y`/H`^P#\`/T`=@!W`/X`_P```0$!`@$#`7@`>0``````````````
M``!Z`'L`````````````````?`!]`````````````````'X`?P``````````
M``````"``($```````````````````""`````````````````(,`A``$`04!
M!@$'`0@!"0&%`(8`"@$+`0P!#0$.`0\!$`$````````1`0``````````````
M````$@$`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````3`0``````````````````
M``"'`````````````````!0!````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````!4!``````````````````"(````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````%@$``!<!```8`0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````9`0``&@$``!L!````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````<`0``````````'0$`````'@$`````````
M````````````````````````````````````````````````````'P$``"`!
M```````````````````````````````````````````````````````````A
M`0```````````````"(!```C`0`````D`0``````````)0$`````````````
M`````````````````````````````````````"8!`````"<!*`$`````````
M```````````````````````I`2H!`````"L!+`$`````+0$N`2\!,`$`````
M`````#$!,@$`````,P$T`0```````````````````````#4!-@$`````````
M```````````````````````````````W`0`````````````X`3D!```Z`0``
M`````````````#L!/`$]`3X!````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/P$`````````
M`$`!``!!`0``0@$``$,!``!$`0``10$``$8!``!'`0``2`$``$D!``!*`0``
M2P$`````3`$``$T!``!.`0```````````````(D``````(H``````(L`````
M`(P``````(T`````````````````````````````````````````````````
M`````````````````````````````((!@P$`````3P$`````````````````
M````4`$``````````%$!``!2`0``4P$``%0!``!5`0``5@$``%<!``!8`0``
M60$``%H!``!;`0``7`$`````70$``%X!``!?`0```````````````(X`````
M`(\``````)```````)$``````)(`````````````````````````````````
M``````````````````!@`6$!8@%C`0``````````````````````````9`$`
M```````!``(``P`$```1!0``$0`1!@``$0<`"``)```1`!$*```1`!$`$0`1
M`!$`$0`1`!$`$0`1`!$`$0`1"P`,```1#0`.```1`!$`$0`1`!$`$0`1`!$`
M$0`1`!$`$0`1#P````````````````````````````````````````!#2$%2
M4T54`$%30TE)`%541BTX`)!H!0BY9P4('&L%"#YI!0B=:`4(D&H%"&=H!0AG
M:`4(9V@%"````````````P````````"@-PH(`P````````#@1`L(`0``````
M````````!0````````"`<PH(!0`````````@<PH(!0````````"`<0H(!0``
M```````@<0H(!0````````!`;PH(!0``````````;PH(!0````````!@;@H(
M!0`````````@;@H(!0````````"@;`H(!0````````!`;`H(`@``````````
M````!@````````"@;`H(!P```/W____@:`H("````/W___\`1PH(!````/O_
M__^`1PL(````````````````````````````````````````````````````
M`*``````````(````````````````````(`6````````(```````````````
M```````@````````(`````````````````````$@````````(```````````
M``````````(@````````(`````````````````````,@````````(```````
M``````````````0@````````(`````````````````````4@````````(```
M``````````````````8@````````(`````````````````````<@````````
M(`````````````````````@@````````(`````````````````````D@````
M````(`````````````````````H@````````(`````````````````````L@
M````````(````````````````````"\@````````(```````````````````
M`%\@````````(``````````````````````P````````(```````````````
M```````````````````````````````````````````````````````````#
M`````````.!$"P@#`````````$#$"@@!```````````````%`````````"!S
M"@@%`````````(!Q"@@%`````````"!S"@@%`````````(!Q"@@%````````
M`"!Q"@@%`````````$!O"@@%``````````!O"@@%`````````&!N"@@%````
M`````*!L"@@%`````````$!L"@@%`````````&`Z"@@"```````````````&
M`````````*!L"@@'````_?___^!H"@@(````_?___P!'"@@$````^____X!'
M"P@`````````````````````````````````````````````````````````
M`````````````0```````````````````````````````@``````````````
M`````````````````P``````````````````````````````!```````````
M````````````````````!0``````````````````````````````!@``````
M````````````````````````!P``````````````````````````````"```
M````````````````````````````"0``````````````````````````````
M"@``````````````````````````````"P``````````````````````````
M````#```````````````````````````````#0``````````````````````
M````````#@``````````````````````````````#P``````````````````
M````````````$```````````````````````````````$0``````````````
M````````````````$@``````````````````````````````$P``````````
M````````````````````%```````````````````````````````%0``````
M````````````````````````%@``````````````````````````````%P``
M````````````````````````````&```````````````````````````````
M&0``````````````````````````````&@``````````````````````````
M````&P``````````````````````````````'```````````````````````
M````````'0``````````````````````````````'@``````````````````
M````````````'P``````````````````````````````(```````````````
M````````````````(0``````````````````````````````(@``````````
M````````````````````(P``````````````````````````````)```````
M````````````````````````)0``````````````````````````````)@``
M````````````````````````````)P``````````````````````````````
M*```````````````````````````````*0``````````````````````````
M````*@``````````````````````````````*P``````````````````````
M````````+```````````````````````````````+P``````````````````
M````````````.P``````````````````````````````/```````````````
M````````````````/0``````````````````````````````/@``````````
M````````````````````/P``````````````````````````````0```````
M````````````````````````6P``````````````````````````````7```
M````````````````````````````70``````````````````````````````
M7@``````````````````````````````7P``````````````````````````
M````8```````````````````````````````>P``````````````````````
M````````?```````````````````````````````?0``````````````````
M````````````?@``````````````````````````````?P``````````````
M`````````````````C``````````````````````````````````````````
M```````````````````````````````%`````````"!S"@@%`````````(!Q
M"@@%`````````"!Q"@@%`````````$!O"@@%``````````!O"@@%````````
M`&!N"@@%`````````*!L"@@%`````````$!L"@@"```````````````&````
M`````*!L"@@'````_?___^!H"@@(````_?___P!'"@@`````````````````
M````!0`````````@<PH(!0````````"`<0H(!0`````````@<0H(!0``````
M``!`;PH(!0``````````;PH(!0````````!@;@H(!0````````"@;`H(!0``
M``````!`;`H(`@``````````````!@````````"@;`H(!P```/W____@:`H(
M"````/W___\`1PH(``````````````````````,`````````X$0+"`$`````
M``````````4`````````@',*"`4`````````(',*"`4`````````@'$*"`4`
M````````('$*"`4`````````0&\*"`4``````````&\*"`4`````````8&X*
M"`4`````````(&X*"`4`````````H&P*"`4`````````0&P*"`(`````````
M``````8`````````H&P*"`<```#]____X&@*"`@```#]____`$<*"`0```#[
M____@$<+"````````````````````````````P````````#@1`L(`P``````
M``!`Q`H(`0``````````````!0````````!`=0H(!0````````"`<PH(!0``
M```````@<PH(!0````````"`<0H(!0`````````@<0H(!0````````!`;PH(
M!0``````````;PH(!0````````!@;@H(!0`````````@;@H(!0````````"@
M;`H(!0````````!`;`H(!0````````"@0PH(`@``````````````!@``````
M``"@;`H(!P````````#@:`H("```````````1PH(!````/O___^`1PL(````
M`````````````````"(``````````````````````````````"8`````````
M`````````````````````"<``````````````````````````````"\`````
M`````````````````````````#H``````````````````````````````#P`
M`````````````````````````````#X`````````````````````````````
M`$``````````````````````````````````````````````````````````
M`````````````````P````````#@1`L(`P````````"`=0H(`0``````````
M````!0````````"`<PH(!0````````"`<0H(!0`````````@<0H(!0``````
M``!`;PH(!0``````````;PH(!0````````!@;@H(!0`````````@;@H(!0``
M``````"@;`H(!0````````!`;`H(`@``````````````!@```/W___^@;`H(
M!P````````#@:`H("```````````1PH(!````/O___^`1PL(````````````
M```````````````#`````````.!$"P@#`````````$#$"@@!````````````
M```%`````````(!S"@@%`````````(!Q"@@%`````````"!Q"@@%````````
M`$!O"@@%``````````!O"@@%`````````&!N"@@%`````````"!N"@@%````
M`````*!L"@@%`````````$!L"@@"```````````````&````_?___Z!L"@@'
M`````````.!H"@@(``````````!'"@@$````^____X!'"P@`````````````
M`````````````*!&"@A@10H(J48*"(!$"@BQ1@H(H$(*"+I&"@C`00H(QT8*
M""!!"@BV+QD(@$`*",U&"@B@-@H(UD8*"&`Y"@C@1@H(8#D*"```````````
M`````````````````````$YA;65P<F5P`$M20G!R97``3F]D97!R97``4F5S
M;W5R8V5P<F5P`'!L86EN`%-!4TQP<F5P`$E30U-)<')E<`!I4T-320``````
M`````````````````````````````$$```!:````````````````````````
M`&$```!Z`````````````````````````*H`````````````````````````
M`````+4``````````````````````````````+H`````````````````````
M`````````,````#6`````````````````````````-@```#V````````````
M`````````````/@````@`@```````````````````````"("```S`@``````
M`````````````````%`"``"M`@```````````````````````+`"``"X`@``
M`````````````````````+L"``#!`@```````````````````````-`"``#1
M`@```````````````````````.`"``#D`@```````````````````````.X"
M`````````````````````````````'H#````````````````````````````
M`(8#`````````````````````````````(@#``"*`P``````````````````
M`````(P#`````````````````````````````(X#``"A`P``````````````
M`````````*,#``#.`P```````````````````````-`#``#U`P``````````
M```````````````$``""!````````````````````````(H$``#.!```````
M`````````````````-`$``#U!````````````````````````/@$``#Y!```
M```````````````````````%```/!0```````````````````````#$%``!6
M!0```````````````````````%D%``!?!0```````````````````````&$%
M``"'!0```````````````````````(D%````````````````````````````
M``,)``````````````````````````````4)```Y"0``````````````````
M`````#T)``!`"0```````````````````````$D)``!,"0``````````````
M`````````%`)`````````````````````````````%@)``!A"0``````````
M`````````````&0)``!P"0```````````````````````(()``"#"0``````
M`````````````````(4)``","0```````````````````````(\)``"0"0``
M`````````````````````),)``"H"0```````````````````````*H)``"P
M"0```````````````````````+()`````````````````````````````+8)
M``"Y"0```````````````````````+X)``#`"0``````````````````````
M`,<)``#("0```````````````````````,L)``#,"0``````````````````
M`````-<)`````````````````````````````-P)``#="0``````````````
M`````````-\)``#A"0```````````````````````.8)``#Q"0``````````
M`````````````/0)``#Z"0````````````````````````4*```*"@``````
M``````````````````\*```0"@```````````````````````!,*```H"@``
M`````````````````````"H*```P"@```````````````````````#(*```S
M"@```````````````````````#4*```V"@```````````````````````#@*
M```Y"@```````````````````````#X*``!`"@``````````````````````
M`%D*``!<"@```````````````````````%X*````````````````````````
M`````&8*``!O"@```````````````````````'(*``!T"@``````````````
M`````````(,*`````````````````````````````(4*``"+"@``````````
M`````````````(T*`````````````````````````````(\*``"1"@``````
M`````````````````),*``"H"@```````````````````````*H*``"P"@``
M`````````````````````+(*``"S"@```````````````````````+4*``"Y
M"@```````````````````````+T*``#`"@```````````````````````,D*
M`````````````````````````````,L*``#,"@``````````````````````
M`-`*`````````````````````````````.`*````````````````````````
M`````.8*``#O"@````````````````````````(+```#"P``````````````
M``````````4+```,"P````````````````````````\+```0"P``````````
M`````````````!,+```H"P```````````````````````"H+```P"P``````
M`````````````````#(+```S"P```````````````````````#8+```Y"P``
M`````````````````````#T+```^"P```````````````````````$`+````
M`````````````````````````$<+``!("P```````````````````````$L+
M``!,"P```````````````````````%<+````````````````````````````
M`%P+``!="P```````````````````````%\+``!A"P``````````````````
M`````&8+``!P"P```````````````````````(,+````````````````````
M`````````(4+``"*"P```````````````````````(X+``"0"P``````````
M`````````````)(+``"5"P```````````````````````)D+``":"P``````
M`````````````````)P+`````````````````````````````)X+``"?"P``
M`````````````````````*,+``"D"P```````````````````````*@+``"J
M"P```````````````````````*X+``"U"P```````````````````````+<+
M``"Y"P```````````````````````+X+``"_"P``````````````````````
M`,$+``#""P```````````````````````,8+``#("P``````````````````
M`````,H+``#,"P```````````````````````-<+````````````````````
M`````````.<+``#R"P````````````````````````$,```##```````````
M``````````````4,```,#`````````````````````````X,```0#```````
M`````````````````!(,```H#````````````````````````"H,```S#```
M`````````````````````#4,```Y#````````````````````````$$,``!$
M#````````````````````````&`,``!A#````````````````````````&8,
M``!O#````````````````````````((,``"##```````````````````````
M`(4,``",#````````````````````````(X,``"0#```````````````````
M`````)(,``"H#````````````````````````*H,``"S#```````````````
M`````````+4,``"Y#````````````````````````+X,````````````````
M`````````````,`,``#$#````````````````````````,<,``#(#```````
M`````````````````,H,``#+#````````````````````````-4,``#6#```
M`````````````````````-X,`````````````````````````````.`,``#A
M#````````````````````````.8,``#O#`````````````````````````(-
M```##0````````````````````````4-```,#0``````````````````````
M``X-```0#0```````````````````````!(-```H#0``````````````````
M`````"H-```Y#0```````````````````````#X-``!`#0``````````````
M`````````$8-``!(#0```````````````````````$H-``!,#0``````````
M`````````````%<-`````````````````````````````&`-``!A#0``````
M`````````````````&8-``!O#0```````````````````````((-``"##0``
M`````````````````````(4-``"6#0```````````````````````)H-``"Q
M#0```````````````````````+,-``"[#0```````````````````````+T-
M`````````````````````````````,`-``#&#0``````````````````````
M`,\-``#1#0```````````````````````-@-``#?#0``````````````````
M`````/(-``#T#0````````````````````````$.```P#@``````````````
M`````````#(.```S#@```````````````````````$`.``!&#@``````````
M`````````````$\.``!;#@```````````````````````($.``""#@``````
M`````````````````(0.`````````````````````````````(<.``"(#@``
M`````````````````````(H.`````````````````````````````(T.````
M`````````````````````````)0.``"7#@```````````````````````)D.
M``"?#@```````````````````````*$.``"C#@``````````````````````
M`*4.`````````````````````````````*<.````````````````````````
M`````*H.``"K#@```````````````````````*T.``"P#@``````````````
M`````````+(.``"S#@```````````````````````+T.````````````````
M`````````````,`.``#$#@```````````````````````,8.````````````
M`````````````````-`.``#9#@```````````````````````-P.``#=#@``
M```````````````````````/```7#P```````````````````````!H/```T
M#P```````````````````````#8/`````````````````````````````#@/
M`````````````````````````````#X/``!'#P``````````````````````
M`$D/``!J#P```````````````````````'\/````````````````````````
M`````(4/`````````````````````````````(@/``"+#P``````````````
M`````````+X/``#%#P```````````````````````,</``#,#P``````````
M`````````````,\/```````````````````````````````0```A$```````
M`````````````````",0```G$````````````````````````"D0```J$```
M`````````````````````"P0`````````````````````````````#$0````
M`````````````````````````#@0`````````````````````````````$`0
M``!7$````````````````````````*`0``#%$```````````````````````
M`-`0``#X$````````````````````````/L0````````````````````````
M```````1``!9$0```````````````````````%\1``"B$0``````````````
M`````````*@1``#Y$0`````````````````````````2```&$@``````````
M``````````````@2``!&$@```````````````````````$@2````````````
M`````````````````$H2``!-$@```````````````````````%`2``!6$@``
M`````````````````````%@2`````````````````````````````%H2``!=
M$@```````````````````````&`2``"&$@```````````````````````(@2
M`````````````````````````````(H2``"-$@``````````````````````
M`)`2``"N$@```````````````````````+`2````````````````````````
M`````+(2``"U$@```````````````````````+@2``"^$@``````````````
M`````````,`2`````````````````````````````,(2``#%$@``````````
M`````````````,@2``#.$@```````````````````````-`2``#6$@``````
M`````````````````-@2``#N$@```````````````````````/`2```.$P``
M`````````````````````!`3`````````````````````````````!(3```5
M$P```````````````````````!@3```>$P```````````````````````"`3
M``!&$P```````````````````````$@3``!:$P``````````````````````
M`&$3``!\$P```````````````````````*`3``#T$P``````````````````
M``````$4``!V%@```````````````````````($6``":%@``````````````
M`````````*`6``#P%@`````````````````````````7```,%P``````````
M``````````````X7```1%P```````````````````````"`7```Q%P``````
M`````````````````#47```V%P```````````````````````$`7``!1%P``
M`````````````````````&`7``!L%P```````````````````````&X7``!P
M%P```````````````````````(`7``"V%P```````````````````````+X7
M``#%%P```````````````````````,<7``#(%P``````````````````````
M`-07``#:%P```````````````````````-P7````````````````````````
M`````.`7``#I%P```````````````````````!`8```9&```````````````
M`````````"`8``!W&````````````````````````(`8``"H&```````````
M```````````````>``";'@```````````````````````*`>``#Y'@``````
M```````````````````?```5'P```````````````````````!@?```='P``
M`````````````````````"`?``!%'P```````````````````````$@?``!-
M'P```````````````````````%`?``!7'P```````````````````````%D?
M`````````````````````````````%L?````````````````````````````
M`%T?`````````````````````````````%\?``!]'P``````````````````
M`````(`?``"T'P```````````````````````+8?``"\'P``````````````
M`````````+X?`````````````````````````````,(?``#$'P``````````
M`````````````,8?``#,'P```````````````````````-`?``#3'P``````
M`````````````````-8?``#;'P```````````````````````.`?``#L'P``
M`````````````````````/(?``#T'P```````````````````````/8?``#\
M'P````````````````````````X@`````````````````````````````'$@
M`````````````````````````````'\@````````````````````````````
M``(A``````````````````````````````<A````````````````````````
M``````HA```3(0```````````````````````!4A````````````````````
M`````````!DA```=(0```````````````````````"0A````````````````
M`````````````"8A`````````````````````````````"@A````````````
M`````````````````"HA```M(0```````````````````````"\A```Q(0``
M`````````````````````#,A```Y(0```````````````````````#TA```_
M(0```````````````````````$4A``!)(0```````````````````````&`A
M``"#(0```````````````````````#8C``!Z(P``````````````````````
M`)4C`````````````````````````````)PD``#I)```````````````````
M``````4P```',````````````````````````"$P```I,```````````````
M`````````#$P```U,````````````````````````#@P```\,```````````
M`````````````$$P``"6,````````````````````````)TP``"?,```````
M`````````````````*$P``#Z,````````````````````````/PP``#_,```
M``````````````````````4Q```L,0```````````````````````#$Q``".
M,0```````````````````````)`Q``"W,0```````````````````````/`Q
M```<,@```````````````````````"`R``!#,@``````````````````````
M`&`R``![,@```````````````````````'\R``"P,@``````````````````
M`````,`R``#+,@```````````````````````-`R``#^,@``````````````
M```````````S``!V,P```````````````````````'LS``#=,P``````````
M`````````````.`S``#^,P`````````````````````````T``"U30``````
M``````````````````!.``"EGP````````````````````````"@``",I```
M``````````````````````"L``"CUP````````````````````````#8```M
M^@```````````````````````##Z``!J^@````````````````````````#[
M```&^P```````````````````````!/[```7^P``````````````````````
M`"'_```Z_P```````````````````````$'_``!:_P``````````````````
M`````&;_``"^_P```````````````````````,+_``#'_P``````````````
M`````````,K_``#/_P```````````````````````-+_``#7_P``````````
M`````````````-K_``#<_P`````````````````````````#`0`>`P$`````
M`````````````````"`#`0`C`P$``````````````````````#`#`0!*`P$`
M```````````````````````$`0`E!`$``````````````````````"@$`0!-
M!`$```````````````````````#0`0#UT`$```````````````````````#1
M`0`FT0$``````````````````````"K1`0!FT0$`````````````````````
M`&K1`0!RT0$``````````````````````(/1`0"$T0$`````````````````
M`````(S1`0"IT0$``````````````````````*[1`0#=T0$`````````````
M``````````#4`0!4U`$``````````````````````%;4`0"<U`$`````````
M`````````````)[4`0"?U`$``````````````````````*+4`0``````````
M`````````````````*74`0"FU`$``````````````````````*G4`0"LU`$`
M`````````````````````*[4`0"YU`$``````````````````````+O4`0``
M`````````````````````````+W4`0#`U`$``````````````````````,+4
M`0##U`$``````````````````````,74`0`%U0$`````````````````````
M``?5`0`*U0$```````````````````````W5`0`4U0$`````````````````
M`````!;5`0`<U0$``````````````````````![5`0`YU0$`````````````
M`````````#O5`0`^U0$``````````````````````$#5`0!$U0$`````````
M`````````````$;5`0```````````````````````````$K5`0!0U0$`````
M`````````````````%+5`0"CU@$``````````````````````*C6`0#)UP$`
M`````````````````````````@#6I@(```````````````````````#X`@`=
M^@(`````````````````````````#P#]_P\`````````````````````````
M$`#]_Q``````````````````````````````````````````````````````
M````````````O@4`````````````````````````````P`4`````````````
M````````````````PP4`````````````````````````````T`4``.H%````
M````````````````````\`4``/0%````````````````````````&P8`````
M````````````````````````'P8`````````````````````````````(08`
M`#H&````````````````````````0`8``$H&````````````````````````
M;08``&\&````````````````````````<08``-4&````````````````````
M````W08`````````````````````````````Y08``.8&````````````````
M````````^@8``/X&``````````````````````````<```T'````````````
M````````````$`<`````````````````````````````$@<``"P'````````
M````````````````@`<``*4'````````````````````````L0<`````````
M````````````````````#R``````````````````````````````'?L`````
M````````````````````````'_L``"C[````````````````````````*OL`
M`#;[````````````````````````./L``#S[````````````````````````
M/OL`````````````````````````````0/L``$'[````````````````````
M````0_L``$3[````````````````````````1OL``+'[````````````````
M````````T_L``#W]````````````````````````4/T``(_]````````````
M````````````DOT``,?]````````````````````````\/T``/S]````````
M````````````````</X``'3^````````````````````````=OX``/S^````
M````````````````````````````````````````````````````````````
M`````````````````````````0`.````````````````````````````(``.
M`'\`#@``````````````````````````````````````````````````````
M````````````````````````````````0`,`````````````````````````
M````00,`````````````````````````````#B``````````````````````
M````````#R``````````````````````````````*B``````````````````
M````````````*R``````````````````````````````+"``````````````
M````````````````+2``````````````````````````````+B``````````
M````````````````````:B``````````````````````````````:R``````
M````````````````````````;"``````````````````````````````;2``
M````````````````````````````;B``````````````````````````````
M;R``````````````````````````````````````````````````````````
M````\"\``/LO````````````````````````````````````````````````
M`````````````````````````````/G_````````````````````````````
M`/K_`````````````````````````````/O_````````````````````````
M`````/S_`````````````````````````````/W_````````````````````
M````````````````````````````````````````````````````````````
M````V```_]\`````````````````````````````````````````````````
M````````````````````````````T/T``._]````````````````````````
M_O\``/__````````````````````````_O\!`/__`0``````````````````
M````_O\"`/__`@``````````````````````_O\#`/__`P``````````````
M````````_O\$`/__!```````````````````````_O\%`/__!0``````````
M````````````_O\&`/__!@``````````````````````_O\'`/__!P``````
M````````````````_O\(`/__"```````````````````````_O\)`/__"0``
M````````````````````_O\*`/__"@``````````````````````_O\+`/__
M"P``````````````````````_O\,`/__#```````````````````````_O\-
M`/__#0``````````````````````_O\.`/__#@``````````````````````
M_O\/`/__#P``````````````````````_O\0`/__$```````````````````
M````````````````````````````````````````````````````````````
M`````````.```/_X```````````````````````````/`/W_#P``````````
M```````````````0`/W_$```````````````````````````````````````
M````````````````@````)\`````````````````````````W08`````````
M````````````````````#P<`````````````````````````````#A@`````
M````````````````````````#"``````````````````````````````#2``
M````````````````````````````*"``````````````````````````````
M*2``````````````````````````````8"``````````````````````````
M````82``````````````````````````````8B``````````````````````
M````````8R``````````````````````````````:B```&\@````````````
M````````````__X`````````````````````````````^?\``/S_````````
M````````````````<]$!`'K1`0``````````````````````````````````
M````````````````````````````````````'P``````````````````````
M``!_````````````````````````````````````````````````````````
M``````````````````````````````````````"@````````````````````
M``````````"`%@``````````````````````````````(```````````````
M```````````````!(``````````````````````````````"(```````````
M```````````````````#(``````````````````````````````$(```````
M```````````````````````%(``````````````````````````````&(```
M```````````````````````````'(``````````````````````````````(
M(``````````````````````````````)(```````````````````````````
M```*(``````````````````````````````+(```````````````````````
M```````O(`````````````````````````````!?(```````````````````
M````````````,```````````````````````````````````````````````
M````````````````````````````````````(```````````````````````
M````````````````````````````````````````````````````````````
M`$$`````````80```````````````````$(`````````8@``````````````
M`````$,`````````8P```````````````````$0`````````9```````````
M`````````$4`````````90```````````````````$8`````````9@``````
M`````````````$<`````````9P```````````````````$@`````````:```
M`````````````````$D`````````:0```````````````````$H`````````
M:@```````````````````$L`````````:P```````````````````$P`````
M````;````````````````````$T`````````;0```````````````````$X`
M````````;@```````````````````$\`````````;P``````````````````
M`%``````````<````````````````````%$`````````<0``````````````
M`````%(`````````<@```````````````````%,`````````<P``````````
M`````````%0`````````=````````````````````%4`````````=0``````
M`````````````%8`````````=@```````````````````%<`````````=P``
M`````````````````%@`````````>````````````````````%D`````````
M>0```````````````````%H`````````>@```````````````````+4`````
M````O`,``````````````````,``````````X````````````````````,$`
M````````X0```````````````````,(`````````X@``````````````````
M`,,`````````XP```````````````````,0`````````Y```````````````
M`````,4`````````Y0```````````````````,8`````````Y@``````````
M`````````,<`````````YP```````````````````,@`````````Z```````
M`````````````,D`````````Z0```````````````````,H`````````Z@``
M`````````````````,L`````````ZP```````````````````,P`````````
M[````````````````````,T`````````[0```````````````````,X`````
M````[@```````````````````,\`````````[P```````````````````-``
M````````\````````````````````-$`````````\0``````````````````
M`-(`````````\@```````````````````-,`````````\P``````````````
M`````-0`````````]````````````````````-4`````````]0``````````
M`````````-8`````````]@```````````````````-@`````````^```````
M`````````````-D`````````^0```````````````````-H`````````^@``
M`````````````````-L`````````^P```````````````````-P`````````
M_````````````````````-T`````````_0```````````````````-X`````
M````_@```````````````````-\`````````<P```',````````````````!
M`````````0$```````````````````(!`````````P$`````````````````
M``0!````````!0$```````````````````8!````````!P$`````````````
M``````@!````````"0$```````````````````H!````````"P$`````````
M``````````P!````````#0$```````````````````X!````````#P$`````
M`````````````!`!````````$0$``````````````````!(!````````$P$`
M`````````````````!0!````````%0$``````````````````!8!````````
M%P$``````````````````!@!````````&0$``````````````````!H!````
M````&P$``````````````````!P!````````'0$``````````````````!X!
M````````'P$``````````````````"`!````````(0$`````````````````
M`"(!````````(P$``````````````````"0!````````)0$`````````````
M`````"8!````````)P$``````````````````"@!````````*0$`````````
M`````````"H!````````*P$``````````````````"P!````````+0$`````
M`````````````"X!````````+P$``````````````````#`!````````:0``
M``<#`````````````#(!````````,P$``````````````````#0!````````
M-0$``````````````````#8!````````-P$``````````````````#D!````
M````.@$``````````````````#L!````````/`$``````````````````#T!
M````````/@$``````````````````#\!````````0`$`````````````````
M`$$!````````0@$``````````````````$,!````````1`$`````````````
M`````$4!````````1@$``````````````````$<!````````2`$`````````
M`````````$D!````````O`(``&X``````````````$H!````````2P$`````
M`````````````$P!````````30$``````````````````$X!````````3P$`
M`````````````````%`!````````40$``````````````````%(!````````
M4P$``````````````````%0!````````50$``````````````````%8!````
M````5P$``````````````````%@!````````60$``````````````````%H!
M````````6P$``````````````````%P!````````70$`````````````````
M`%X!````````7P$``````````````````&`!````````80$`````````````
M`````&(!````````8P$``````````````````&0!````````90$`````````
M`````````&8!````````9P$``````````````````&@!````````:0$`````
M`````````````&H!````````:P$``````````````````&P!````````;0$`
M`````````````````&X!````````;P$``````````````````'`!````````
M<0$``````````````````'(!````````<P$``````````````````'0!````
M````=0$``````````````````'8!````````=P$``````````````````'@!
M````````_P```````````````````'D!````````>@$`````````````````
M`'L!````````?`$``````````````````'T!````````?@$`````````````
M`````'\!````````<P```````````````````($!````````4P(`````````
M`````````((!````````@P$``````````````````(0!````````A0$`````
M`````````````(8!````````5`(``````````````````(<!````````B`$`
M`````````````````(D!````````5@(``````````````````(H!````````
M5P(``````````````````(L!````````C`$``````````````````(X!````
M````W0$``````````````````(\!````````60(``````````````````)`!
M````````6P(``````````````````)$!````````D@$`````````````````
M`),!````````8`(``````````````````)0!````````8P(`````````````
M`````)8!````````:0(``````````````````)<!````````:`(`````````
M`````````)@!````````F0$``````````````````)P!````````;P(`````
M`````````````)T!````````<@(``````````````````)\!````````=0(`
M`````````````````*`!````````H0$``````````````````*(!````````
MHP$``````````````````*0!````````I0$``````````````````*8!````
M````@`(``````````````````*<!````````J`$``````````````````*D!
M````````@P(``````````````````*P!````````K0$`````````````````
M`*X!````````B`(``````````````````*\!````````L`$`````````````
M`````+$!````````B@(``````````````````+(!````````BP(`````````
M`````````+,!````````M`$``````````````````+4!````````M@$`````
M`````````````+<!````````D@(``````````````````+@!````````N0$`
M`````````````````+P!````````O0$``````````````````,0!````````
MQ@$``````````````````,4!````````Q@$``````````````````,<!````
M````R0$``````````````````,@!````````R0$``````````````````,H!
M````````S`$``````````````````,L!````````S`$`````````````````
M`,T!````````S@$``````````````````,\!````````T`$`````````````
M`````-$!````````T@$``````````````````-,!````````U`$`````````
M`````````-4!````````U@$``````````````````-<!````````V`$`````
M`````````````-D!````````V@$``````````````````-L!````````W`$`
M`````````````````-X!````````WP$``````````````````.`!````````
MX0$``````````````````.(!````````XP$``````````````````.0!````
M````Y0$``````````````````.8!````````YP$``````````````````.@!
M````````Z0$``````````````````.H!````````ZP$`````````````````
M`.P!````````[0$``````````````````.X!````````[P$`````````````
M`````/`!````````:@````P#`````````````/$!````````\P$`````````
M`````````/(!````````\P$``````````````````/0!````````]0$`````
M`````````````/8!````````E0$``````````````````/<!````````OP$`
M`````````````````/@!````````^0$``````````````````/H!````````
M^P$``````````````````/P!````````_0$``````````````````/X!````
M````_P$````````````````````"`````````0(```````````````````("
M`````````P(```````````````````0"````````!0(`````````````````
M``8"````````!P(```````````````````@"````````"0(`````````````
M``````H"````````"P(```````````````````P"````````#0(`````````
M``````````X"````````#P(``````````````````!`"````````$0(`````
M`````````````!("````````$P(``````````````````!0"````````%0(`
M`````````````````!8"````````%P(``````````````````!@"````````
M&0(``````````````````!H"````````&P(``````````````````!P"````
M````'0(``````````````````!X"````````'P(``````````````````"`"
M````````G@$``````````````````"("````````(P(`````````````````
M`"0"````````)0(``````````````````"8"````````)P(`````````````
M`````"@"````````*0(``````````````````"H"````````*P(`````````
M`````````"P"````````+0(``````````````````"X"````````+P(`````
M`````````````#`"````````,0(``````````````````#("````````,P(`
M`````````````````$4#````````N0,``````````````````(8#````````
MK`,``````````````````(@#````````K0,``````````````````(D#````
M````K@,``````````````````(H#````````KP,``````````````````(P#
M````````S`,``````````````````(X#````````S0,`````````````````
M`(\#````````S@,``````````````````)`#````````N0,```@#```!`P``
M`````)$#````````L0,``````````````````)(#````````L@,`````````
M`````````),#````````LP,``````````````````)0#````````M`,`````
M`````````````)4#````````M0,``````````````````)8#````````M@,`
M`````````````````)<#````````MP,``````````````````)@#````````
MN`,``````````````````)D#````````N0,``````````````````)H#````
M````N@,``````````````````)L#````````NP,``````````````````)P#
M````````O`,``````````````````)T#````````O0,`````````````````
M`)X#````````O@,``````````````````)\#````````OP,`````````````
M`````*`#````````P`,``````````````````*$#````````P0,`````````
M`````````*,#````````PP,``````````````````*0#````````Q`,`````
M`````````````*4#````````Q0,``````````````````*8#````````Q@,`
M`````````````````*<#````````QP,``````````````````*@#````````
MR`,``````````````````*D#````````R0,``````````````````*H#````
M````R@,``````````````````*L#````````RP,``````````````````+`#
M````````Q0,```@#```!`P```````,(#````````PP,`````````````````
M`-`#````````L@,``````````````````-$#````````N`,`````````````
M`````-4#````````Q@,``````````````````-8#````````P`,`````````
M`````````-@#````````V0,``````````````````-H#````````VP,`````
M`````````````-P#````````W0,``````````````````-X#````````WP,`
M`````````````````.`#````````X0,``````````````````.(#````````
MXP,``````````````````.0#````````Y0,``````````````````.8#````
M````YP,``````````````````.@#````````Z0,``````````````````.H#
M````````ZP,``````````````````.P#````````[0,`````````````````
M`.X#````````[P,``````````````````/`#````````N@,`````````````
M`````/$#````````P0,``````````````````/(#````````PP,`````````
M`````````/0#````````N`,``````````````````/4#````````M0,`````
M```````````````$````````4`0```````````````````$$````````400`
M``````````````````($````````4@0```````````````````,$````````
M4P0```````````````````0$````````5`0```````````````````4$````
M````500```````````````````8$````````5@0```````````````````<$
M````````5P0```````````````````@$````````6`0`````````````````
M``D$````````600```````````````````H$````````6@0`````````````
M``````L$````````6P0```````````````````P$````````7`0`````````
M``````````T$````````700```````````````````X$````````7@0`````
M``````````````\$````````7P0``````````````````!`$````````,`0`
M`````````````````!$$````````,00``````````````````!($````````
M,@0``````````````````!,$````````,P0``````````````````!0$````
M````-`0``````````````````!4$````````-00``````````````````!8$
M````````-@0``````````````````!<$````````-P0`````````````````
M`!@$````````.`0``````````````````!D$````````.00`````````````
M`````!H$````````.@0``````````````````!L$````````.P0`````````
M`````````!P$````````/`0``````````````````!T$````````/00`````
M`````````````!X$````````/@0``````````````````!\$````````/P0`
M`````````````````"`$````````0`0``````````````````"$$````````
M000``````````````````"($````````0@0``````````````````",$````
M````0P0``````````````````"0$````````1`0``````````````````"4$
M````````100``````````````````"8$````````1@0`````````````````
M`"<$````````1P0``````````````````"@$````````2`0`````````````
M`````"D$````````200``````````````````"H$````````2@0`````````
M`````````"L$````````2P0``````````````````"P$````````3`0`````
M`````````````"T$````````300``````````````````"X$````````3@0`
M`````````````````"\$````````3P0``````````````````&`$````````
M800``````````````````&($````````8P0``````````````````&0$````
M````900``````````````````&8$````````9P0``````````````````&@$
M````````:00``````````````````&H$````````:P0`````````````````
M`&P$````````;00``````````````````&X$````````;P0`````````````
M`````'`$````````<00``````````````````'($````````<P0`````````
M`````````'0$````````=00``````````````````'8$````````=P0`````
M`````````````'@$````````>00``````````````````'H$````````>P0`
M`````````````````'P$````````?00``````````````````'X$````````
M?P0``````````````````(`$````````@00``````````````````(H$````
M````BP0``````````````````(P$````````C00``````````````````(X$
M````````CP0``````````````````)`$````````D00`````````````````
M`)($````````DP0``````````````````)0$````````E00`````````````
M`````)8$````````EP0``````````````````)@$````````F00`````````
M`````````)H$````````FP0``````````````````)P$````````G00`````
M`````````````)X$````````GP0``````````````````*`$````````H00`
M`````````````````*($````````HP0``````````````````*0$````````
MI00``````````````````*8$````````IP0``````````````````*@$````
M````J00``````````````````*H$````````JP0``````````````````*P$
M````````K00``````````````````*X$````````KP0`````````````````
M`+`$````````L00``````````````````+($````````LP0`````````````
M`````+0$````````M00``````````````````+8$````````MP0`````````
M`````````+@$````````N00``````````````````+H$````````NP0`````
M`````````````+P$````````O00``````````````````+X$````````OP0`
M`````````````````,$$````````P@0``````````````````,,$````````
MQ`0``````````````````,4$````````Q@0``````````````````,<$````
M````R`0``````````````````,D$````````R@0``````````````````,L$
M````````S`0``````````````````,T$````````S@0`````````````````
M`-`$````````T00``````````````````-($````````TP0`````````````
M`````-0$````````U00``````````````````-8$````````UP0`````````
M`````````-@$````````V00``````````````````-H$````````VP0`````
M`````````````-P$````````W00``````````````````-X$````````WP0`
M`````````````````.`$````````X00``````````````````.($````````
MXP0``````````````````.0$````````Y00``````````````````.8$````
M````YP0``````````````````.@$````````Z00``````````````````.H$
M````````ZP0``````````````````.P$````````[00`````````````````
M`.X$````````[P0``````````````````/`$````````\00`````````````
M`````/($````````\P0``````````````````/0$````````]00`````````
M`````````/@$````````^00````````````````````%`````````04`````
M``````````````(%`````````P4```````````````````0%````````!04`
M``````````````````8%````````!P4```````````````````@%````````
M"04```````````````````H%````````"P4```````````````````P%````
M````#04```````````````````X%````````#P4``````````````````#$%
M````````804``````````````````#(%````````8@4`````````````````
M`#,%````````8P4``````````````````#0%````````9`4`````````````
M`````#4%````````904``````````````````#8%````````9@4`````````
M`````````#<%````````9P4``````````````````#@%````````:`4`````
M`````````````#D%````````:04``````````````````#H%````````:@4`
M`````````````````#L%````````:P4``````````````````#P%````````
M;`4``````````````````#T%````````;04``````````````````#X%````
M````;@4``````````````````#\%````````;P4``````````````````$`%
M````````<`4``````````````````$$%````````<04`````````````````
M`$(%````````<@4``````````````````$,%````````<P4`````````````
M`````$0%````````=`4``````````````````$4%````````=04`````````
M`````````$8%````````=@4``````````````````$<%````````=P4`````
M`````````````$@%````````>`4``````````````````$D%````````>04`
M`````````````````$H%````````>@4``````````````````$L%````````
M>P4``````````````````$P%````````?`4``````````````````$T%````
M````?04``````````````````$X%````````?@4``````````````````$\%
M````````?P4``````````````````%`%````````@`4`````````````````
M`%$%````````@04``````````````````%(%````````@@4`````````````
M`````%,%````````@P4``````````````````%0%````````A`4`````````
M`````````%4%````````A04``````````````````%8%````````A@4`````
M`````````````(<%````````904``((%```````````````>`````````1X`
M``````````````````(>`````````QX```````````````````0>````````
M!1X```````````````````8>````````!QX```````````````````@>````
M````"1X```````````````````H>````````"QX```````````````````P>
M````````#1X```````````````````X>````````#QX`````````````````
M`!`>````````$1X``````````````````!(>````````$QX`````````````
M`````!0>````````%1X``````````````````!8>````````%QX`````````
M`````````!@>````````&1X``````````````````!H>````````&QX`````
M`````````````!P>````````'1X``````````````````!X>````````'QX`
M`````````````````"`>````````(1X``````````````````"(>````````
M(QX``````````````````"0>````````)1X``````````````````"8>````
M````)QX``````````````````"@>````````*1X``````````````````"H>
M````````*QX``````````````````"P>````````+1X`````````````````
M`"X>````````+QX``````````````````#`>````````,1X`````````````
M`````#(>````````,QX``````````````````#0>````````-1X`````````
M`````````#8>````````-QX``````````````````#@>````````.1X`````
M`````````````#H>````````.QX``````````````````#P>````````/1X`
M`````````````````#X>````````/QX``````````````````$`>````````
M01X``````````````````$(>````````0QX``````````````````$0>````
M````11X``````````````````$8>````````1QX``````````````````$@>
M````````21X``````````````````$H>````````2QX`````````````````
M`$P>````````31X``````````````````$X>````````3QX`````````````
M`````%`>````````41X``````````````````%(>````````4QX`````````
M`````````%0>````````51X``````````````````%8>````````5QX`````
M`````````````%@>````````61X``````````````````%H>````````6QX`
M`````````````````%P>````````71X``````````````````%X>````````
M7QX``````````````````&`>````````81X``````````````````&(>````
M````8QX``````````````````&0>````````91X``````````````````&8>
M````````9QX``````````````````&@>````````:1X`````````````````
M`&H>````````:QX``````````````````&P>````````;1X`````````````
M`````&X>````````;QX``````````````````'`>````````<1X`````````
M`````````'(>````````<QX``````````````````'0>````````=1X`````
M`````````````'8>````````=QX``````````````````'@>````````>1X`
M`````````````````'H>````````>QX``````````````````'P>````````
M?1X``````````````````'X>````````?QX``````````````````(`>````
M````@1X``````````````````((>````````@QX``````````````````(0>
M````````A1X``````````````````(8>````````AQX`````````````````
M`(@>````````B1X``````````````````(H>````````BQX`````````````
M`````(P>````````C1X``````````````````(X>````````CQX`````````
M`````````)`>````````D1X``````````````````)(>````````DQX`````
M`````````````)0>````````E1X``````````````````)8>````````:```
M`#$#`````````````)<>````````=`````@#`````````````)@>````````
M=P````H#`````````````)D>````````>0````H#`````````````)H>````
M````80```+X"`````````````)L>````````81X``````````````````*`>
M````````H1X``````````````````*(>````````HQX`````````````````
M`*0>````````I1X``````````````````*8>````````IQX`````````````
M`````*@>````````J1X``````````````````*H>````````JQX`````````
M`````````*P>````````K1X``````````````````*X>````````KQX`````
M`````````````+`>````````L1X``````````````````+(>````````LQX`
M`````````````````+0>````````M1X``````````````````+8>````````
MMQX``````````````````+@>````````N1X``````````````````+H>````
M````NQX``````````````````+P>````````O1X``````````````````+X>
M````````OQX``````````````````,`>````````P1X`````````````````
M`,(>````````PQX``````````````````,0>````````Q1X`````````````
M`````,8>````````QQX``````````````````,@>````````R1X`````````
M`````````,H>````````RQX``````````````````,P>````````S1X`````
M`````````````,X>````````SQX``````````````````-`>````````T1X`
M`````````````````-(>````````TQX``````````````````-0>````````
MU1X``````````````````-8>````````UQX``````````````````-@>````
M````V1X``````````````````-H>````````VQX``````````````````-P>
M````````W1X``````````````````-X>````````WQX`````````````````
M`.`>````````X1X``````````````````.(>````````XQX`````````````
M`````.0>````````Y1X``````````````````.8>````````YQX`````````
M`````````.@>````````Z1X``````````````````.H>````````ZQX`````
M`````````````.P>````````[1X``````````````````.X>````````[QX`
M`````````````````/`>````````\1X``````````````````/(>````````
M\QX``````````````````/0>````````]1X``````````````````/8>````
M````]QX``````````````````/@>````````^1X```````````````````@?
M`````````!\```````````````````D?`````````1\`````````````````
M``H?`````````A\```````````````````L?`````````Q\`````````````
M``````P?````````!!\```````````````````T?````````!1\`````````
M``````````X?````````!A\```````````````````\?````````!Q\`````
M`````````````!@?````````$!\``````````````````!D?````````$1\`
M`````````````````!H?````````$A\``````````````````!L?````````
M$Q\``````````````````!P?````````%!\``````````````````!T?````
M````%1\``````````````````"@?````````(!\``````````````````"D?
M````````(1\``````````````````"H?````````(A\`````````````````
M`"L?````````(Q\``````````````````"P?````````)!\`````````````
M`````"T?````````)1\``````````````````"X?````````)A\`````````
M`````````"\?````````)Q\``````````````````#@?````````,!\`````
M`````````````#D?````````,1\``````````````````#H?````````,A\`
M`````````````````#L?````````,Q\``````````````````#P?````````
M-!\``````````````````#T?````````-1\``````````````````#X?````
M````-A\``````````````````#\?````````-Q\``````````````````$@?
M````````0!\``````````````````$D?````````01\`````````````````
M`$H?````````0A\``````````````````$L?````````0Q\`````````````
M`````$P?````````1!\``````````````````$T?````````11\`````````
M`````````%`?````````Q0,``!,#`````````````%(?````````Q0,``!,#
M`````P```````%0?````````Q0,``!,#```!`P```````%8?````````Q0,`
M`!,#``!"`P```````%D?````````41\``````````````````%L?````````
M4Q\``````````````````%T?````````51\``````````````````%\?````
M````5Q\``````````````````&@?````````8!\``````````````````&D?
M````````81\``````````````````&H?````````8A\`````````````````
M`&L?````````8Q\``````````````````&P?````````9!\`````````````
M`````&T?````````91\``````````````````&X?````````9A\`````````
M`````````&\?````````9Q\``````````````````(`?`````````!\``+D#
M`````````````($?`````````1\``+D#`````````````((?`````````A\`
M`+D#`````````````(,?`````````Q\``+D#`````````````(0?````````
M!!\``+D#`````````````(4?````````!1\``+D#`````````````(8?````
M````!A\``+D#`````````````(<?````````!Q\``+D#`````````````(@?
M`````````!\``+D#`````````````(D?`````````1\``+D#````````````
M`(H?`````````A\``+D#`````````````(L?`````````Q\``+D#````````
M`````(P?````````!!\``+D#`````````````(T?````````!1\``+D#````
M`````````(X?````````!A\``+D#`````````````(\?````````!Q\``+D#
M`````````````)`?````````(!\``+D#`````````````)$?````````(1\`
M`+D#`````````````)(?````````(A\``+D#`````````````),?````````
M(Q\``+D#`````````````)0?````````)!\``+D#`````````````)4?````
M````)1\``+D#`````````````)8?````````)A\``+D#`````````````)<?
M````````)Q\``+D#`````````````)@?````````(!\``+D#````````````
M`)D?````````(1\``+D#`````````````)H?````````(A\``+D#````````
M`````)L?````````(Q\``+D#`````````````)P?````````)!\``+D#````
M`````````)T?````````)1\``+D#`````````````)X?````````)A\``+D#
M`````````````)\?````````)Q\``+D#`````````````*`?````````8!\`
M`+D#`````````````*$?````````81\``+D#`````````````*(?````````
M8A\``+D#`````````````*,?````````8Q\``+D#`````````````*0?````
M````9!\``+D#`````````````*4?````````91\``+D#`````````````*8?
M````````9A\``+D#`````````````*<?````````9Q\``+D#````````````
M`*@?````````8!\``+D#`````````````*D?````````81\``+D#````````
M`````*H?````````8A\``+D#`````````````*L?````````8Q\``+D#````
M`````````*P?````````9!\``+D#`````````````*T?````````91\``+D#
M`````````````*X?````````9A\``+D#`````````````*\?````````9Q\`
M`+D#`````````````+(?````````<!\``+D#`````````````+,?````````
ML0,``+D#`````````````+0?````````K`,``+D#`````````````+8?````
M````L0,``$(#`````````````+<?````````L0,``$(#``"Y`P```````+@?
M````````L!\``````````````````+D?````````L1\`````````````````
M`+H?````````<!\``````````````````+L?````````<1\`````````````
M`````+P?````````L0,``+D#`````````````+X?````````N0,`````````
M`````````,(?````````=!\``+D#`````````````,,?````````MP,``+D#
M`````````````,0?````````K@,``+D#`````````````,8?````````MP,`
M`$(#`````````````,<?````````MP,``$(#``"Y`P```````,@?````````
M<A\``````````````````,D?````````<Q\``````````````````,H?````
M````=!\``````````````````,L?````````=1\``````````````````,P?
M````````MP,``+D#`````````````-(?````````N0,```@#`````P``````
M`-,?````````N0,```@#```!`P```````-8?````````N0,``$(#````````
M`````-<?````````N0,```@#``!"`P```````-@?````````T!\`````````
M`````````-D?````````T1\``````````````````-H?````````=A\`````
M`````````````-L?````````=Q\``````````````````.(?````````Q0,`
M``@#`````P```````.,?````````Q0,```@#```!`P```````.0?````````
MP0,``!,#`````````````.8?````````Q0,``$(#`````````````.<?````
M````Q0,```@#``!"`P```````.@?````````X!\``````````````````.D?
M````````X1\``````````````````.H?````````>A\`````````````````
M`.L?````````>Q\``````````````````.P?````````Y1\`````````````
M`````/(?````````?!\``+D#`````````````/,?````````R0,``+D#````
M`````````/0?````````S@,``+D#`````````````/8?````````R0,``$(#
M`````````````/<?````````R0,``$(#``"Y`P```````/@?````````>!\`
M`````````````````/D?````````>1\``````````````````/H?````````
M?!\``````````````````/L?````````?1\``````````````````/P?````
M````R0,``+D#`````````````"8A````````R0,``````````````````"HA
M````````:P```````````````````"LA````````Y0``````````````````
M`&`A````````<"$``````````````````&$A````````<2$`````````````
M`````&(A````````<B$``````````````````&,A````````<R$`````````
M`````````&0A````````="$``````````````````&4A````````=2$`````
M`````````````&8A````````=B$``````````````````&<A````````=R$`
M`````````````````&@A````````>"$``````````````````&DA````````
M>2$``````````````````&HA````````>B$``````````````````&LA````
M````>R$``````````````````&PA````````?"$``````````````````&TA
M````````?2$``````````````````&XA````````?B$`````````````````
M`&\A````````?R$``````````````````+8D````````T"0`````````````
M`````+<D````````T20``````````````````+@D````````TB0`````````
M`````````+DD````````TR0``````````````````+HD````````U"0`````
M`````````````+LD````````U20``````````````````+PD````````UB0`
M`````````````````+TD````````UR0``````````````````+XD````````
MV"0``````````````````+\D````````V20``````````````````,`D````
M````VB0``````````````````,$D````````VR0``````````````````,(D
M````````W"0``````````````````,,D````````W20`````````````````
M`,0D````````WB0``````````````````,4D````````WR0`````````````
M`````,8D````````X"0``````````````````,<D````````X20`````````
M`````````,@D````````XB0``````````````````,DD````````XR0`````
M`````````````,HD````````Y"0``````````````````,LD````````Y20`
M`````````````````,PD````````YB0``````````````````,TD````````
MYR0``````````````````,XD````````Z"0``````````````````,\D````
M````Z20```````````````````#[````````9@```&8```````````````'[
M````````9@```&D```````````````+[````````9@```&P`````````````
M``/[````````9@```&8```!I``````````3[````````9@```&8```!L````
M``````7[````````<P```'0```````````````;[````````<P```'0`````
M`````````!/[````````=`4``'8%`````````````!3[````````=`4``&4%
M`````````````!7[````````=`4``&L%`````````````!;[````````?@4`
M`'8%`````````````!?[````````=`4``&T%`````````````"'_````````
M0?\``````````````````"+_````````0O\``````````````````"/_````
M````0_\``````````````````"3_````````1/\``````````````````"7_
M````````1?\``````````````````";_````````1O\`````````````````
M`"?_````````1_\``````````````````"C_````````2/\`````````````
M`````"G_````````2?\``````````````````"K_````````2O\`````````
M`````````"O_````````2_\``````````````````"S_````````3/\`````
M`````````````"W_````````3?\``````````````````"[_````````3O\`
M`````````````````"__````````3_\``````````````````##_````````
M4/\``````````````````#'_````````4?\``````````````````#+_````
M````4O\``````````````````#/_````````4_\``````````````````#3_
M````````5/\``````````````````#7_````````5?\`````````````````
M`#;_````````5O\``````````````````#?_````````5_\`````````````
M`````#C_````````6/\``````````````````#G_````````6?\`````````
M`````````#K_````````6O\````````````````````$`0``````*`0!````
M``````````````$$`0``````*00!``````````````````($`0``````*@0!
M``````````````````,$`0``````*P0!``````````````````0$`0``````
M+`0!``````````````````4$`0``````+00!``````````````````8$`0``
M````+@0!``````````````````<$`0``````+P0!``````````````````@$
M`0``````,`0!``````````````````D$`0``````,00!````````````````
M``H$`0``````,@0!``````````````````L$`0``````,P0!````````````
M``````P$`0``````-`0!``````````````````T$`0``````-00!````````
M``````````X$`0``````-@0!``````````````````\$`0``````-P0!````
M`````````````!`$`0``````.`0!`````````````````!$$`0``````.00!
M`````````````````!($`0``````.@0!`````````````````!,$`0``````
M.P0!`````````````````!0$`0``````/`0!`````````````````!4$`0``
M````/00!`````````````````!8$`0``````/@0!`````````````````!<$
M`0``````/P0!`````````````````!@$`0``````0`0!````````````````
M`!D$`0``````000!`````````````````!H$`0``````0@0!````````````
M`````!L$`0``````0P0!`````````````````!P$`0``````1`0!````````
M`````````!T$`0``````100!`````````````````!X$`0``````1@0!````
M`````````````!\$`0``````1P0!`````````````````"`$`0``````2`0!
M`````````````````"$$`0``````200!`````````````````"($`0``````
M2@0!`````````````````",$`0``````2P0!`````````````````"0$`0``
M````3`0!`````````````````"4$`0``````300!````````````````````
M````````````````````````````````````````````````````````````
M`$$`````````80```````````````````$(`````````8@``````````````
M`````$,`````````8P```````````````````$0`````````9```````````
M`````````$4`````````90```````````````````$8`````````9@``````
M`````````````$<`````````9P```````````````````$@`````````:```
M`````````````````$D`````````:0```````````````````$H`````````
M:@```````````````````$L`````````:P```````````````````$P`````
M````;````````````````````$T`````````;0```````````````````$X`
M````````;@```````````````````$\`````````;P``````````````````
M`%``````````<````````````````````%$`````````<0``````````````
M`````%(`````````<@```````````````````%,`````````<P``````````
M`````````%0`````````=````````````````````%4`````````=0``````
M`````````````%8`````````=@```````````````````%<`````````=P``
M`````````````````%@`````````>````````````````````%D`````````
M>0```````````````````%H`````````>@```````````````````+4`````
M````O`,``````````````````,``````````X````````````````````,$`
M````````X0```````````````````,(`````````X@``````````````````
M`,,`````````XP```````````````````,0`````````Y```````````````
M`````,4`````````Y0```````````````````,8`````````Y@``````````
M`````````,<`````````YP```````````````````,@`````````Z```````
M`````````````,D`````````Z0```````````````````,H`````````Z@``
M`````````````````,L`````````ZP```````````````````,P`````````
M[````````````````````,T`````````[0```````````````````,X`````
M````[@```````````````````,\`````````[P```````````````````-``
M````````\````````````````````-$`````````\0``````````````````
M`-(`````````\@```````````````````-,`````````\P``````````````
M`````-0`````````]````````````````````-4`````````]0``````````
M`````````-8`````````]@```````````````````-@`````````^```````
M`````````````-D`````````^0```````````````````-H`````````^@``
M`````````````````-L`````````^P```````````````````-P`````````
M_````````````````````-T`````````_0```````````````````-X`````
M````_@```````````````````-\`````````<P```',````````````````!
M`````````0$```````````````````(!`````````P$`````````````````
M``0!````````!0$```````````````````8!````````!P$`````````````
M``````@!````````"0$```````````````````H!````````"P$`````````
M``````````P!````````#0$```````````````````X!````````#P$`````
M`````````````!`!````````$0$``````````````````!(!````````$P$`
M`````````````````!0!````````%0$``````````````````!8!````````
M%P$``````````````````!@!````````&0$``````````````````!H!````
M````&P$``````````````````!P!````````'0$``````````````````!X!
M````````'P$``````````````````"`!````````(0$`````````````````
M`"(!````````(P$``````````````````"0!````````)0$`````````````
M`````"8!````````)P$``````````````````"@!````````*0$`````````
M`````````"H!````````*P$``````````````````"P!````````+0$`````
M`````````````"X!````````+P$``````````````````#`!````````:0``
M``<#`````````````#(!````````,P$``````````````````#0!````````
M-0$``````````````````#8!````````-P$``````````````````#D!````
M````.@$``````````````````#L!````````/`$``````````````````#T!
M````````/@$``````````````````#\!````````0`$`````````````````
M`$$!````````0@$``````````````````$,!````````1`$`````````````
M`````$4!````````1@$``````````````````$<!````````2`$`````````
M`````````$D!````````O`(``&X``````````````$H!````````2P$`````
M`````````````$P!````````30$``````````````````$X!````````3P$`
M`````````````````%`!````````40$``````````````````%(!````````
M4P$``````````````````%0!````````50$``````````````````%8!````
M````5P$``````````````````%@!````````60$``````````````````%H!
M````````6P$``````````````````%P!````````70$`````````````````
M`%X!````````7P$``````````````````&`!````````80$`````````````
M`````&(!````````8P$``````````````````&0!````````90$`````````
M`````````&8!````````9P$``````````````````&@!````````:0$`````
M`````````````&H!````````:P$``````````````````&P!````````;0$`
M`````````````````&X!````````;P$``````````````````'`!````````
M<0$``````````````````'(!````````<P$``````````````````'0!````
M````=0$``````````````````'8!````````=P$``````````````````'@!
M````````_P```````````````````'D!````````>@$`````````````````
M`'L!````````?`$``````````````````'T!````````?@$`````````````
M`````'\!````````<P```````````````````($!````````4P(`````````
M`````````((!````````@P$``````````````````(0!````````A0$`````
M`````````````(8!````````5`(``````````````````(<!````````B`$`
M`````````````````(D!````````5@(``````````````````(H!````````
M5P(``````````````````(L!````````C`$``````````````````(X!````
M````W0$``````````````````(\!````````60(``````````````````)`!
M````````6P(``````````````````)$!````````D@$`````````````````
M`),!````````8`(``````````````````)0!````````8P(`````````````
M`````)8!````````:0(``````````````````)<!````````:`(`````````
M`````````)@!````````F0$``````````````````)P!````````;P(`````
M`````````````)T!````````<@(``````````````````)\!````````=0(`
M`````````````````*`!````````H0$``````````````````*(!````````
MHP$``````````````````*0!````````I0$``````````````````*8!````
M````@`(``````````````````*<!````````J`$``````````````````*D!
M````````@P(``````````````````*P!````````K0$`````````````````
M`*X!````````B`(``````````````````*\!````````L`$`````````````
M`````+$!````````B@(``````````````````+(!````````BP(`````````
M`````````+,!````````M`$``````````````````+4!````````M@$`````
M`````````````+<!````````D@(``````````````````+@!````````N0$`
M`````````````````+P!````````O0$``````````````````,0!````````
MQ@$``````````````````,4!````````Q@$``````````````````,<!````
M````R0$``````````````````,@!````````R0$``````````````````,H!
M````````S`$``````````````````,L!````````S`$`````````````````
M`,T!````````S@$``````````````````,\!````````T`$`````````````
M`````-$!````````T@$``````````````````-,!````````U`$`````````
M`````````-4!````````U@$``````````````````-<!````````V`$`````
M`````````````-D!````````V@$``````````````````-L!````````W`$`
M`````````````````-X!````````WP$``````````````````.`!````````
MX0$``````````````````.(!````````XP$``````````````````.0!````
M````Y0$``````````````````.8!````````YP$``````````````````.@!
M````````Z0$``````````````````.H!````````ZP$`````````````````
M`.P!````````[0$``````````````````.X!````````[P$`````````````
M`````/`!````````:@````P#`````````````/$!````````\P$`````````
M`````````/(!````````\P$``````````````````/0!````````]0$`````
M`````````````/8!````````E0$``````````````````/<!````````OP$`
M`````````````````/@!````````^0$``````````````````/H!````````
M^P$``````````````````/P!````````_0$``````````````````/X!````
M````_P$````````````````````"`````````0(```````````````````("
M`````````P(```````````````````0"````````!0(`````````````````
M``8"````````!P(```````````````````@"````````"0(`````````````
M``````H"````````"P(```````````````````P"````````#0(`````````
M``````````X"````````#P(``````````````````!`"````````$0(`````
M`````````````!("````````$P(``````````````````!0"````````%0(`
M`````````````````!8"````````%P(``````````````````!@"````````
M&0(``````````````````!H"````````&P(``````````````````!P"````
M````'0(``````````````````!X"````````'P(``````````````````"`"
M````````G@$``````````````````"("````````(P(`````````````````
M`"0"````````)0(``````````````````"8"````````)P(`````````````
M`````"@"````````*0(``````````````````"H"````````*P(`````````
M`````````"P"````````+0(``````````````````"X"````````+P(`````
M`````````````#`"````````,0(``````````````````#("````````,P(`
M`````````````````$4#````````N0,``````````````````'H#````````
M(````+D#`````````````(8#````````K`,``````````````````(@#````
M````K0,``````````````````(D#````````K@,``````````````````(H#
M````````KP,``````````````````(P#````````S`,`````````````````
M`(X#````````S0,``````````````````(\#````````S@,`````````````
M`````)`#````````N0,```@#```!`P```````)$#````````L0,`````````
M`````````)(#````````L@,``````````````````),#````````LP,`````
M`````````````)0#````````M`,``````````````````)4#````````M0,`
M`````````````````)8#````````M@,``````````````````)<#````````
MMP,``````````````````)@#````````N`,``````````````````)D#````
M````N0,``````````````````)H#````````N@,``````````````````)L#
M````````NP,``````````````````)P#````````O`,`````````````````
M`)T#````````O0,``````````````````)X#````````O@,`````````````
M`````)\#````````OP,``````````````````*`#````````P`,`````````
M`````````*$#````````P0,``````````````````*,#````````PP,`````
M`````````````*0#````````Q`,``````````````````*4#````````Q0,`
M`````````````````*8#````````Q@,``````````````````*<#````````
MQP,``````````````````*@#````````R`,``````````````````*D#````
M````R0,``````````````````*H#````````R@,``````````````````*L#
M````````RP,``````````````````+`#````````Q0,```@#```!`P``````
M`,(#````````PP,``````````````````-`#````````L@,`````````````
M`````-$#````````N`,``````````````````-(#````````Q0,`````````
M`````````-,#````````S0,``````````````````-0#````````RP,`````
M`````````````-4#````````Q@,``````````````````-8#````````P`,`
M`````````````````-@#````````V0,``````````````````-H#````````
MVP,``````````````````-P#````````W0,``````````````````-X#````
M````WP,``````````````````.`#````````X0,``````````````````.(#
M````````XP,``````````````````.0#````````Y0,`````````````````
M`.8#````````YP,``````````````````.@#````````Z0,`````````````
M`````.H#````````ZP,``````````````````.P#````````[0,`````````
M`````````.X#````````[P,``````````````````/`#````````N@,`````
M`````````````/$#````````P0,``````````````````/(#````````PP,`
M`````````````````/0#````````N`,``````````````````/4#````````
MM0,````````````````````$````````4`0```````````````````$$````
M````400```````````````````($````````4@0```````````````````,$
M````````4P0```````````````````0$````````5`0`````````````````
M``4$````````500```````````````````8$````````5@0`````````````
M``````<$````````5P0```````````````````@$````````6`0`````````
M``````````D$````````600```````````````````H$````````6@0`````
M``````````````L$````````6P0```````````````````P$````````7`0`
M``````````````````T$````````700```````````````````X$````````
M7@0```````````````````\$````````7P0``````````````````!`$````
M````,`0``````````````````!$$````````,00``````````````````!($
M````````,@0``````````````````!,$````````,P0`````````````````
M`!0$````````-`0``````````````````!4$````````-00`````````````
M`````!8$````````-@0``````````````````!<$````````-P0`````````
M`````````!@$````````.`0``````````````````!D$````````.00`````
M`````````````!H$````````.@0``````````````````!L$````````.P0`
M`````````````````!P$````````/`0``````````````````!T$````````
M/00``````````````````!X$````````/@0``````````````````!\$````
M````/P0``````````````````"`$````````0`0``````````````````"$$
M````````000``````````````````"($````````0@0`````````````````
M`",$````````0P0``````````````````"0$````````1`0`````````````
M`````"4$````````100``````````````````"8$````````1@0`````````
M`````````"<$````````1P0``````````````````"@$````````2`0`````
M`````````````"D$````````200``````````````````"H$````````2@0`
M`````````````````"L$````````2P0``````````````````"P$````````
M3`0``````````````````"T$````````300``````````````````"X$````
M````3@0``````````````````"\$````````3P0``````````````````&`$
M````````800``````````````````&($````````8P0`````````````````
M`&0$````````900``````````````````&8$````````9P0`````````````
M`````&@$````````:00``````````````````&H$````````:P0`````````
M`````````&P$````````;00``````````````````&X$````````;P0`````
M`````````````'`$````````<00``````````````````'($````````<P0`
M`````````````````'0$````````=00``````````````````'8$````````
M=P0``````````````````'@$````````>00``````````````````'H$````
M````>P0``````````````````'P$````````?00``````````````````'X$
M````````?P0``````````````````(`$````````@00`````````````````
M`(H$````````BP0``````````````````(P$````````C00`````````````
M`````(X$````````CP0``````````````````)`$````````D00`````````
M`````````)($````````DP0``````````````````)0$````````E00`````
M`````````````)8$````````EP0``````````````````)@$````````F00`
M`````````````````)H$````````FP0``````````````````)P$````````
MG00``````````````````)X$````````GP0``````````````````*`$````
M````H00``````````````````*($````````HP0``````````````````*0$
M````````I00``````````````````*8$````````IP0`````````````````
M`*@$````````J00``````````````````*H$````````JP0`````````````
M`````*P$````````K00``````````````````*X$````````KP0`````````
M`````````+`$````````L00``````````````````+($````````LP0`````
M`````````````+0$````````M00``````````````````+8$````````MP0`
M`````````````````+@$````````N00``````````````````+H$````````
MNP0``````````````````+P$````````O00``````````````````+X$````
M````OP0``````````````````,$$````````P@0``````````````````,,$
M````````Q`0``````````````````,4$````````Q@0`````````````````
M`,<$````````R`0``````````````````,D$````````R@0`````````````
M`````,L$````````S`0``````````````````,T$````````S@0`````````
M`````````-`$````````T00``````````````````-($````````TP0`````
M`````````````-0$````````U00``````````````````-8$````````UP0`
M`````````````````-@$````````V00``````````````````-H$````````
MVP0``````````````````-P$````````W00``````````````````-X$````
M````WP0``````````````````.`$````````X00``````````````````.($
M````````XP0``````````````````.0$````````Y00`````````````````
M`.8$````````YP0``````````````````.@$````````Z00`````````````
M`````.H$````````ZP0``````````````````.P$````````[00`````````
M`````````.X$````````[P0``````````````````/`$````````\00`````
M`````````````/($````````\P0``````````````````/0$````````]00`
M`````````````````/@$````````^00````````````````````%````````
M`04```````````````````(%`````````P4```````````````````0%````
M````!04```````````````````8%````````!P4```````````````````@%
M````````"04```````````````````H%````````"P4`````````````````
M``P%````````#04```````````````````X%````````#P4`````````````
M`````#$%````````804``````````````````#(%````````8@4`````````
M`````````#,%````````8P4``````````````````#0%````````9`4`````
M`````````````#4%````````904``````````````````#8%````````9@4`
M`````````````````#<%````````9P4``````````````````#@%````````
M:`4``````````````````#D%````````:04``````````````````#H%````
M````:@4``````````````````#L%````````:P4``````````````````#P%
M````````;`4``````````````````#T%````````;04`````````````````
M`#X%````````;@4``````````````````#\%````````;P4`````````````
M`````$`%````````<`4``````````````````$$%````````<04`````````
M`````````$(%````````<@4``````````````````$,%````````<P4`````
M`````````````$0%````````=`4``````````````````$4%````````=04`
M`````````````````$8%````````=@4``````````````````$<%````````
M=P4``````````````````$@%````````>`4``````````````````$D%````
M````>04``````````````````$H%````````>@4``````````````````$L%
M````````>P4``````````````````$P%````````?`4`````````````````
M`$T%````````?04``````````````````$X%````````?@4`````````````
M`````$\%````````?P4``````````````````%`%````````@`4`````````
M`````````%$%````````@04``````````````````%(%````````@@4`````
M`````````````%,%````````@P4``````````````````%0%````````A`4`
M`````````````````%4%````````A04``````````````````%8%````````
MA@4``````````````````(<%````````904``((%```````````````>````
M`````1X```````````````````(>`````````QX```````````````````0>
M````````!1X```````````````````8>````````!QX`````````````````
M``@>````````"1X```````````````````H>````````"QX`````````````
M``````P>````````#1X```````````````````X>````````#QX`````````
M`````````!`>````````$1X``````````````````!(>````````$QX`````
M`````````````!0>````````%1X``````````````````!8>````````%QX`
M`````````````````!@>````````&1X``````````````````!H>````````
M&QX``````````````````!P>````````'1X``````````````````!X>````
M````'QX``````````````````"`>````````(1X``````````````````"(>
M````````(QX``````````````````"0>````````)1X`````````````````
M`"8>````````)QX``````````````````"@>````````*1X`````````````
M`````"H>````````*QX``````````````````"P>````````+1X`````````
M`````````"X>````````+QX``````````````````#`>````````,1X`````
M`````````````#(>````````,QX``````````````````#0>````````-1X`
M`````````````````#8>````````-QX``````````````````#@>````````
M.1X``````````````````#H>````````.QX``````````````````#P>````
M````/1X``````````````````#X>````````/QX``````````````````$`>
M````````01X``````````````````$(>````````0QX`````````````````
M`$0>````````11X``````````````````$8>````````1QX`````````````
M`````$@>````````21X``````````````````$H>````````2QX`````````
M`````````$P>````````31X``````````````````$X>````````3QX`````
M`````````````%`>````````41X``````````````````%(>````````4QX`
M`````````````````%0>````````51X``````````````````%8>````````
M5QX``````````````````%@>````````61X``````````````````%H>````
M````6QX``````````````````%P>````````71X``````````````````%X>
M````````7QX``````````````````&`>````````81X`````````````````
M`&(>````````8QX``````````````````&0>````````91X`````````````
M`````&8>````````9QX``````````````````&@>````````:1X`````````
M`````````&H>````````:QX``````````````````&P>````````;1X`````
M`````````````&X>````````;QX``````````````````'`>````````<1X`
M`````````````````'(>````````<QX``````````````````'0>````````
M=1X``````````````````'8>````````=QX``````````````````'@>````
M````>1X``````````````````'H>````````>QX``````````````````'P>
M````````?1X``````````````````'X>````````?QX`````````````````
M`(`>````````@1X``````````````````((>````````@QX`````````````
M`````(0>````````A1X``````````````````(8>````````AQX`````````
M`````````(@>````````B1X``````````````````(H>````````BQX`````
M`````````````(P>````````C1X``````````````````(X>````````CQX`
M`````````````````)`>````````D1X``````````````````)(>````````
MDQX``````````````````)0>````````E1X``````````````````)8>````
M````:````#$#`````````````)<>````````=`````@#`````````````)@>
M````````=P````H#`````````````)D>````````>0````H#````````````
M`)H>````````80```+X"`````````````)L>````````81X`````````````
M`````*`>````````H1X``````````````````*(>````````HQX`````````
M`````````*0>````````I1X``````````````````*8>````````IQX`````
M`````````````*@>````````J1X``````````````````*H>````````JQX`
M`````````````````*P>````````K1X``````````````````*X>````````
MKQX``````````````````+`>````````L1X``````````````````+(>````
M````LQX``````````````````+0>````````M1X``````````````````+8>
M````````MQX``````````````````+@>````````N1X`````````````````
M`+H>````````NQX``````````````````+P>````````O1X`````````````
M`````+X>````````OQX``````````````````,`>````````P1X`````````
M`````````,(>````````PQX``````````````````,0>````````Q1X`````
M`````````````,8>````````QQX``````````````````,@>````````R1X`
M`````````````````,H>````````RQX``````````````````,P>````````
MS1X``````````````````,X>````````SQX``````````````````-`>````
M````T1X``````````````````-(>````````TQX``````````````````-0>
M````````U1X``````````````````-8>````````UQX`````````````````
M`-@>````````V1X``````````````````-H>````````VQX`````````````
M`````-P>````````W1X``````````````````-X>````````WQX`````````
M`````````.`>````````X1X``````````````````.(>````````XQX`````
M`````````````.0>````````Y1X``````````````````.8>````````YQX`
M`````````````````.@>````````Z1X``````````````````.H>````````
MZQX``````````````````.P>````````[1X``````````````````.X>````
M````[QX``````````````````/`>````````\1X``````````````````/(>
M````````\QX``````````````````/0>````````]1X`````````````````
M`/8>````````]QX``````````````````/@>````````^1X`````````````
M``````@?`````````!\```````````````````D?`````````1\`````````
M``````````H?`````````A\```````````````````L?`````````Q\`````
M``````````````P?````````!!\```````````````````T?````````!1\`
M``````````````````X?````````!A\```````````````````\?````````
M!Q\``````````````````!@?````````$!\``````````````````!D?````
M````$1\``````````````````!H?````````$A\``````````````````!L?
M````````$Q\``````````````````!P?````````%!\`````````````````
M`!T?````````%1\``````````````````"@?````````(!\`````````````
M`````"D?````````(1\``````````````````"H?````````(A\`````````
M`````````"L?````````(Q\``````````````````"P?````````)!\`````
M`````````````"T?````````)1\``````````````````"X?````````)A\`
M`````````````````"\?````````)Q\``````````````````#@?````````
M,!\``````````````````#D?````````,1\``````````````````#H?````
M````,A\``````````````````#L?````````,Q\``````````````````#P?
M````````-!\``````````````````#T?````````-1\`````````````````
M`#X?````````-A\``````````````````#\?````````-Q\`````````````
M`````$@?````````0!\``````````````````$D?````````01\`````````
M`````````$H?````````0A\``````````````````$L?````````0Q\`````
M`````````````$P?````````1!\``````````````````$T?````````11\`
M`````````````````%`?````````Q0,``!,#`````````````%(?````````
MQ0,``!,#`````P```````%0?````````Q0,``!,#```!`P```````%8?````
M````Q0,``!,#``!"`P```````%D?````````41\``````````````````%L?
M````````4Q\``````````````````%T?````````51\`````````````````
M`%\?````````5Q\``````````````````&@?````````8!\`````````````
M`````&D?````````81\``````````````````&H?````````8A\`````````
M`````````&L?````````8Q\``````````````````&P?````````9!\`````
M`````````````&T?````````91\``````````````````&X?````````9A\`
M`````````````````&\?````````9Q\``````````````````(`?````````
M`!\``+D#`````````````($?`````````1\``+D#`````````````((?````
M`````A\``+D#`````````````(,?`````````Q\``+D#`````````````(0?
M````````!!\``+D#`````````````(4?````````!1\``+D#````````````
M`(8?````````!A\``+D#`````````````(<?````````!Q\``+D#````````
M`````(@?`````````!\``+D#`````````````(D?`````````1\``+D#````
M`````````(H?`````````A\``+D#`````````````(L?`````````Q\``+D#
M`````````````(P?````````!!\``+D#`````````````(T?````````!1\`
M`+D#`````````````(X?````````!A\``+D#`````````````(\?````````
M!Q\``+D#`````````````)`?````````(!\``+D#`````````````)$?````
M````(1\``+D#`````````````)(?````````(A\``+D#`````````````),?
M````````(Q\``+D#`````````````)0?````````)!\``+D#````````````
M`)4?````````)1\``+D#`````````````)8?````````)A\``+D#````````
M`````)<?````````)Q\``+D#`````````````)@?````````(!\``+D#````
M`````````)D?````````(1\``+D#`````````````)H?````````(A\``+D#
M`````````````)L?````````(Q\``+D#`````````````)P?````````)!\`
M`+D#`````````````)T?````````)1\``+D#`````````````)X?````````
M)A\``+D#`````````````)\?````````)Q\``+D#`````````````*`?````
M````8!\``+D#`````````````*$?````````81\``+D#`````````````*(?
M````````8A\``+D#`````````````*,?````````8Q\``+D#````````````
M`*0?````````9!\``+D#`````````````*4?````````91\``+D#````````
M`````*8?````````9A\``+D#`````````````*<?````````9Q\``+D#````
M`````````*@?````````8!\``+D#`````````````*D?````````81\``+D#
M`````````````*H?````````8A\``+D#`````````````*L?````````8Q\`
M`+D#`````````````*P?````````9!\``+D#`````````````*T?````````
M91\``+D#`````````````*X?````````9A\``+D#`````````````*\?````
M````9Q\``+D#`````````````+(?````````<!\``+D#`````````````+,?
M````````L0,``+D#`````````````+0?````````K`,``+D#````````````
M`+8?````````L0,``$(#`````````````+<?````````L0,``$(#``"Y`P``
M`````+@?````````L!\``````````````````+D?````````L1\`````````
M`````````+H?````````<!\``````````````````+L?````````<1\`````
M`````````````+P?````````L0,``+D#`````````````+X?````````N0,`
M`````````````````,(?````````=!\``+D#`````````````,,?````````
MMP,``+D#`````````````,0?````````K@,``+D#`````````````,8?````
M````MP,``$(#`````````````,<?````````MP,``$(#``"Y`P```````,@?
M````````<A\``````````````````,D?````````<Q\`````````````````
M`,H?````````=!\``````````````````,L?````````=1\`````````````
M`````,P?````````MP,``+D#`````````````-(?````````N0,```@#````
M`P```````-,?````````N0,```@#```!`P```````-8?````````N0,``$(#
M`````````````-<?````````N0,```@#``!"`P```````-@?````````T!\`
M`````````````````-D?````````T1\``````````````````-H?````````
M=A\``````````````````-L?````````=Q\``````````````````.(?````
M````Q0,```@#`````P```````.,?````````Q0,```@#```!`P```````.0?
M````````P0,``!,#`````````````.8?````````Q0,``$(#````````````
M`.<?````````Q0,```@#``!"`P```````.@?````````X!\`````````````
M`````.D?````````X1\``````````````````.H?````````>A\`````````
M`````````.L?````````>Q\``````````````````.P?````````Y1\`````
M`````````````/(?````````?!\``+D#`````````````/,?````````R0,`
M`+D#`````````````/0?````````S@,``+D#`````````````/8?````````
MR0,``$(#`````````````/<?````````R0,``$(#``"Y`P```````/@?````
M````>!\``````````````````/D?````````>1\``````````````````/H?
M````````?!\``````````````````/L?````````?1\`````````````````
M`/P?````````R0,``+D#`````````````*@@````````<@```',`````````
M``````(A````````8P````````````````````,A````````L````&,`````
M``````````<A````````6P(```````````````````DA````````L````&8`
M``````````````LA````````:`````````````````````PA````````:```
M``````````````````TA````````:````````````````````!`A````````
M:0```````````````````!$A````````:0```````````````````!(A````
M````;````````````````````!4A````````;@```````````````````!8A
M````````;@```&\``````````````!DA````````<```````````````````
M`!HA````````<0```````````````````!LA````````<@``````````````
M`````!PA````````<@```````````````````!TA````````<@``````````
M`````````"`A````````<P```&T``````````````"$A````````=````&4`
M``!L`````````"(A````````=````&T``````````````"0A````````>@``
M`````````````````"8A````````R0,``````````````````"@A````````
M>@```````````````````"HA````````:P```````````````````"LA````
M````Y0```````````````````"PA````````8@```````````````````"TA
M````````8P```````````````````#`A````````90``````````````````
M`#$A````````9@```````````````````#,A````````;0``````````````
M`````#XA````````LP,``````````````````#\A````````P`,`````````
M`````````$4A````````9````````````````````&`A````````<"$`````
M`````````````&$A````````<2$``````````````````&(A````````<B$`
M`````````````````&,A````````<R$``````````````````&0A````````
M="$``````````````````&4A````````=2$``````````````````&8A````
M````=B$``````````````````&<A````````=R$``````````````````&@A
M````````>"$``````````````````&DA````````>2$`````````````````
M`&HA````````>B$``````````````````&LA````````>R$`````````````
M`````&PA````````?"$``````````````````&TA````````?2$`````````
M`````````&XA````````?B$``````````````````&\A````````?R$`````
M`````````````+8D````````T"0``````````````````+<D````````T20`
M`````````````````+@D````````TB0``````````````````+DD````````
MTR0``````````````````+HD````````U"0``````````````````+LD````
M````U20``````````````````+PD````````UB0``````````````````+TD
M````````UR0``````````````````+XD````````V"0`````````````````
M`+\D````````V20``````````````````,`D````````VB0`````````````
M`````,$D````````VR0``````````````````,(D````````W"0`````````
M`````````,,D````````W20``````````````````,0D````````WB0`````
M`````````````,4D````````WR0``````````````````,8D````````X"0`
M`````````````````,<D````````X20``````````````````,@D````````
MXB0``````````````````,DD````````XR0``````````````````,HD````
M````Y"0``````````````````,LD````````Y20``````````````````,PD
M````````YB0``````````````````,TD````````YR0`````````````````
M`,XD````````Z"0``````````````````,\D````````Z20`````````````
M`````'$S````````:````'````!A`````````',S````````80```'4`````
M`````````'4S````````;P```'8``````````````(`S````````<````&$`
M`````````````($S````````;@```&$``````````````((S````````O`,`
M`&$``````````````(,S````````;0```&$``````````````(0S````````
M:P```&$``````````````(4S````````:P```&(``````````````(8S````
M````;0```&(``````````````(<S````````9P```&(``````````````(HS
M````````<````&8``````````````(LS````````;@```&8`````````````
M`(PS````````O`,``&8``````````````)`S````````:````'H`````````
M`````)$S````````:P```&@```!Z`````````)(S````````;0```&@```!Z
M`````````),S````````9P```&@```!Z`````````)0S````````=````&@`
M``!Z`````````*DS````````<````&$``````````````*HS````````:P``
M`'````!A`````````*LS````````;0```'````!A`````````*PS````````
M9P```'````!A`````````+0S````````<````'8``````````````+4S````
M````;@```'8``````````````+8S````````O`,``'8``````````````+<S
M````````;0```'8``````````````+@S````````:P```'8`````````````
M`+DS````````;0```'8``````````````+HS````````<````'<`````````
M`````+LS````````;@```'<``````````````+PS````````O`,``'<`````
M`````````+TS````````;0```'<``````````````+XS````````:P```'<`
M`````````````+\S````````;0```'<``````````````,`S````````:P``
M`,D#`````````````,$S````````;0```,D#`````````````,,S````````
M8@```'$``````````````,8S````````8P```!4B``!K````9P```,<S````
M````8P```&\````N`````````,@S````````9````&(``````````````,DS
M````````9P```'D``````````````,LS````````:````'``````````````
M`,TS````````:P```&L``````````````,XS````````:P```&T`````````
M`````-<S````````<````&@``````````````-DS````````<````'````!M
M`````````-HS````````<````'(``````````````-PS````````<P```'8`
M`````````````-TS````````=P```&(```````````````#[````````9@``
M`&8```````````````'[````````9@```&D```````````````+[````````
M9@```&P```````````````/[````````9@```&8```!I``````````3[````
M````9@```&8```!L``````````7[````````<P```'0```````````````;[
M````````<P```'0``````````````!/[````````=`4``'8%````````````
M`!3[````````=`4``&4%`````````````!7[````````=`4``&L%````````
M`````!;[````````?@4``'8%`````````````!?[````````=`4``&T%````
M`````````"'_````````0?\``````````````````"+_````````0O\`````
M`````````````"/_````````0_\``````````````````"3_````````1/\`
M`````````````````"7_````````1?\``````````````````";_````````
M1O\``````````````````"?_````````1_\``````````````````"C_````
M````2/\``````````````````"G_````````2?\``````````````````"K_
M````````2O\``````````````````"O_````````2_\`````````````````
M`"S_````````3/\``````````````````"W_````````3?\`````````````
M`````"[_````````3O\``````````````````"__````````3_\`````````
M`````````##_````````4/\``````````````````#'_````````4?\`````
M`````````````#+_````````4O\``````````````````#/_````````4_\`
M`````````````````#3_````````5/\``````````````````#7_````````
M5?\``````````````````#;_````````5O\``````````````````#?_````
M````5_\``````````````````#C_````````6/\``````````````````#G_
M````````6?\``````````````````#K_````````6O\`````````````````
M```$`0``````*`0!``````````````````$$`0``````*00!````````````
M``````($`0``````*@0!``````````````````,$`0``````*P0!````````
M``````````0$`0``````+`0!``````````````````4$`0``````+00!````
M``````````````8$`0``````+@0!``````````````````<$`0``````+P0!
M``````````````````@$`0``````,`0!``````````````````D$`0``````
M,00!``````````````````H$`0``````,@0!``````````````````L$`0``
M````,P0!``````````````````P$`0``````-`0!``````````````````T$
M`0``````-00!``````````````````X$`0``````-@0!````````````````
M``\$`0``````-P0!`````````````````!`$`0``````.`0!````````````
M`````!$$`0``````.00!`````````````````!($`0``````.@0!````````
M`````````!,$`0``````.P0!`````````````````!0$`0``````/`0!````
M`````````````!4$`0``````/00!`````````````````!8$`0``````/@0!
M`````````````````!<$`0``````/P0!`````````````````!@$`0``````
M0`0!`````````````````!D$`0``````000!`````````````````!H$`0``
M````0@0!`````````````````!L$`0``````0P0!`````````````````!P$
M`0``````1`0!`````````````````!T$`0``````100!````````````````
M`!X$`0``````1@0!`````````````````!\$`0``````1P0!````````````
M`````"`$`0``````2`0!`````````````````"$$`0``````200!````````
M`````````"($`0``````2@0!`````````````````",$`0``````2P0!````
M`````````````"0$`0``````3`0!`````````````````"4$`0``````300!
M``````````````````#4`0``````80````````````````````'4`0``````
M8@````````````````````+4`0``````8P````````````````````/4`0``
M````9`````````````````````34`0``````90````````````````````74
M`0``````9@````````````````````;4`0``````9P``````````````````
M``?4`0``````:`````````````````````C4`0``````:0``````````````
M``````G4`0``````:@````````````````````K4`0``````:P``````````
M``````````O4`0``````;`````````````````````S4`0``````;0``````
M``````````````W4`0``````;@````````````````````[4`0``````;P``
M``````````````````_4`0``````<````````````````````!#4`0``````
M<0```````````````````!'4`0``````<@```````````````````!+4`0``
M````<P```````````````````!/4`0``````=````````````````````!34
M`0``````=0```````````````````!74`0``````=@``````````````````
M`!;4`0``````=P```````````````````!?4`0``````>```````````````
M`````!C4`0``````>0```````````````````!G4`0``````>@``````````
M`````````#34`0``````80```````````````````#74`0``````8@``````
M`````````````#;4`0``````8P```````````````````#?4`0``````9```
M`````````````````#C4`0``````90```````````````````#G4`0``````
M9@```````````````````#K4`0``````9P```````````````````#O4`0``
M````:````````````````````#S4`0``````:0```````````````````#W4
M`0``````:@```````````````````#[4`0``````:P``````````````````
M`#_4`0``````;````````````````````$#4`0``````;0``````````````
M`````$'4`0``````;@```````````````````$+4`0``````;P``````````
M`````````$/4`0``````<````````````````````$34`0``````<0``````
M`````````````$74`0``````<@```````````````````$;4`0``````<P``
M`````````````````$?4`0``````=````````````````````$C4`0``````
M=0```````````````````$G4`0``````=@```````````````````$K4`0``
M````=P```````````````````$O4`0``````>````````````````````$S4
M`0``````>0```````````````````$W4`0``````>@``````````````````
M`&C4`0``````80```````````````````&G4`0``````8@``````````````
M`````&K4`0``````8P```````````````````&O4`0``````9```````````
M`````````&S4`0``````90```````````````````&W4`0``````9@``````
M`````````````&[4`0``````9P```````````````````&_4`0``````:```
M`````````````````'#4`0``````:0```````````````````''4`0``````
M:@```````````````````'+4`0``````:P```````````````````'/4`0``
M````;````````````````````'34`0``````;0```````````````````'74
M`0``````;@```````````````````';4`0``````;P``````````````````
M`'?4`0``````<````````````````````'C4`0``````<0``````````````
M`````'G4`0``````<@```````````````````'K4`0``````<P``````````
M`````````'O4`0``````=````````````````````'S4`0``````=0``````
M`````````````'W4`0``````=@```````````````````'[4`0``````=P``
M`````````````````'_4`0``````>````````````````````(#4`0``````
M>0```````````````````('4`0``````>@```````````````````)S4`0``
M````80```````````````````)[4`0``````8P```````````````````)_4
M`0``````9````````````````````*+4`0``````9P``````````````````
M`*74`0``````:@```````````````````*;4`0``````:P``````````````
M`````*G4`0``````;@```````````````````*K4`0``````;P``````````
M`````````*O4`0``````<````````````````````*S4`0``````<0``````
M`````````````*[4`0``````<P```````````````````*_4`0``````=```
M`````````````````+#4`0``````=0```````````````````+'4`0``````
M=@```````````````````++4`0``````=P```````````````````+/4`0``
M````>````````````````````+34`0``````>0```````````````````+74
M`0``````>@```````````````````-#4`0``````80``````````````````
M`-'4`0``````8@```````````````````-+4`0``````8P``````````````
M`````-/4`0``````9````````````````````-34`0``````90``````````
M`````````-74`0``````9@```````````````````-;4`0``````9P``````
M`````````````-?4`0``````:````````````````````-C4`0``````:0``
M`````````````````-G4`0``````:@```````````````````-K4`0``````
M:P```````````````````-O4`0``````;````````````````````-S4`0``
M````;0```````````````````-W4`0``````;@```````````````````-[4
M`0``````;P```````````````````-_4`0``````<```````````````````
M`.#4`0``````<0```````````````````.'4`0``````<@``````````````
M`````.+4`0``````<P```````````````````./4`0``````=```````````
M`````````.34`0``````=0```````````````````.74`0``````=@``````
M`````````````.;4`0``````=P```````````````````.?4`0``````>```
M`````````````````.C4`0``````>0```````````````````.G4`0``````
M>@````````````````````35`0``````80````````````````````75`0``
M````8@````````````````````?5`0``````9`````````````````````C5
M`0``````90````````````````````G5`0``````9@``````````````````
M``K5`0``````9P````````````````````W5`0``````:@``````````````
M``````[5`0``````:P````````````````````_5`0``````;```````````
M`````````!#5`0``````;0```````````````````!'5`0``````;@``````
M`````````````!+5`0``````;P```````````````````!/5`0``````<```
M`````````````````!35`0``````<0```````````````````!;5`0``````
M<P```````````````````!?5`0``````=````````````````````!C5`0``
M````=0```````````````````!G5`0``````=@```````````````````!K5
M`0``````=P```````````````````!O5`0``````>```````````````````
M`!S5`0``````>0```````````````````#C5`0``````80``````````````
M`````#G5`0``````8@```````````````````#O5`0``````9```````````
M`````````#S5`0``````90```````````````````#W5`0``````9@``````
M`````````````#[5`0``````9P```````````````````$#5`0``````:0``
M`````````````````$'5`0``````:@```````````````````$+5`0``````
M:P```````````````````$/5`0``````;````````````````````$35`0``
M````;0```````````````````$;5`0``````;P```````````````````$K5
M`0``````<P```````````````````$O5`0``````=```````````````````
M`$S5`0``````=0```````````````````$W5`0``````=@``````````````
M`````$[5`0``````=P```````````````````$_5`0``````>```````````
M`````````%#5`0``````>0```````````````````&S5`0``````80``````
M`````````````&W5`0``````8@```````````````````&[5`0``````8P``
M`````````````````&_5`0``````9````````````````````'#5`0``````
M90```````````````````''5`0``````9@```````````````````'+5`0``
M````9P```````````````````'/5`0``````:````````````````````'35
M`0``````:0```````````````````'75`0``````:@``````````````````
M`';5`0``````:P```````````````````'?5`0``````;```````````````
M`````'C5`0``````;0```````````````````'G5`0``````;@``````````
M`````````'K5`0``````;P```````````````````'O5`0``````<```````
M`````````````'S5`0``````<0```````````````````'W5`0``````<@``
M`````````````````'[5`0``````<P```````````````````'_5`0``````
M=````````````````````(#5`0``````=0```````````````````('5`0``
M````=@```````````````````(+5`0``````=P```````````````````(/5
M`0``````>````````````````````(35`0``````>0``````````````````
M`(75`0``````>@```````````````````*#5`0``````80``````````````
M`````*'5`0``````8@```````````````````*+5`0``````8P``````````
M`````````*/5`0``````9````````````````````*35`0``````90``````
M`````````````*75`0``````9@```````````````````*;5`0``````9P``
M`````````````````*?5`0``````:````````````````````*C5`0``````
M:0```````````````````*G5`0``````:@```````````````````*K5`0``
M````:P```````````````````*O5`0``````;````````````````````*S5
M`0``````;0```````````````````*W5`0``````;@``````````````````
M`*[5`0``````;P```````````````````*_5`0``````<```````````````
M`````+#5`0``````<0```````````````````+'5`0``````<@``````````
M`````````++5`0``````<P```````````````````+/5`0``````=```````
M`````````````+35`0``````=0```````````````````+75`0``````=@``
M`````````````````+;5`0``````=P```````````````````+?5`0``````
M>````````````````````+C5`0``````>0```````````````````+G5`0``
M````>@```````````````````-35`0``````80```````````````````-75
M`0``````8@```````````````````-;5`0``````8P``````````````````
M`-?5`0``````9````````````````````-C5`0``````90``````````````
M`````-G5`0``````9@```````````````````-K5`0``````9P``````````
M`````````-O5`0``````:````````````````````-S5`0``````:0``````
M`````````````-W5`0``````:@```````````````````-[5`0``````:P``
M`````````````````-_5`0``````;````````````````````.#5`0``````
M;0```````````````````.'5`0``````;@```````````````````.+5`0``
M````;P```````````````````./5`0``````<````````````````````.35
M`0``````<0```````````````````.75`0``````<@``````````````````
M`.;5`0``````<P```````````````````.?5`0``````=```````````````
M`````.C5`0``````=0```````````````````.G5`0``````=@``````````
M`````````.K5`0``````=P```````````````````.O5`0``````>```````
M`````````````.S5`0``````>0```````````````````.W5`0``````>@``
M``````````````````C6`0``````80````````````````````G6`0``````
M8@````````````````````K6`0``````8P````````````````````O6`0``
M````9`````````````````````S6`0``````90````````````````````W6
M`0``````9@````````````````````[6`0``````9P``````````````````
M``_6`0``````:````````````````````!#6`0``````:0``````````````
M`````!'6`0``````:@```````````````````!+6`0``````:P``````````
M`````````!/6`0``````;````````````````````!36`0``````;0``````
M`````````````!76`0``````;@```````````````````!;6`0``````;P``
M`````````````````!?6`0``````<````````````````````!C6`0``````
M<0```````````````````!G6`0``````<@```````````````````!K6`0``
M````<P```````````````````!O6`0``````=````````````````````!S6
M`0``````=0```````````````````!W6`0``````=@``````````````````
M`![6`0``````=P```````````````````!_6`0``````>```````````````
M`````"#6`0``````>0```````````````````"'6`0``````>@``````````
M`````````#S6`0``````80```````````````````#W6`0``````8@``````
M`````````````#[6`0``````8P```````````````````#_6`0``````9```
M`````````````````$#6`0``````90```````````````````$'6`0``````
M9@```````````````````$+6`0``````9P```````````````````$/6`0``
M````:````````````````````$36`0``````:0```````````````````$76
M`0``````:@```````````````````$;6`0``````:P``````````````````
M`$?6`0``````;````````````````````$C6`0``````;0``````````````
M`````$G6`0``````;@```````````````````$K6`0``````;P``````````
M`````````$O6`0``````<````````````````````$S6`0``````<0``````
M`````````````$W6`0``````<@```````````````````$[6`0``````<P``
M`````````````````$_6`0``````=````````````````````%#6`0``````
M=0```````````````````%'6`0``````=@```````````````````%+6`0``
M````=P```````````````````%/6`0``````>````````````````````%36
M`0``````>0```````````````````%76`0``````>@``````````````````
M`'#6`0``````80```````````````````''6`0``````8@``````````````
M`````'+6`0``````8P```````````````````'/6`0``````9```````````
M`````````'36`0``````90```````````````````'76`0``````9@``````
M`````````````';6`0``````9P```````````````````'?6`0``````:```
M`````````````````'C6`0``````:0```````````````````'G6`0``````
M:@```````````````````'K6`0``````:P```````````````````'O6`0``
M````;````````````````````'S6`0``````;0```````````````````'W6
M`0``````;@```````````````````'[6`0``````;P``````````````````
M`'_6`0``````<````````````````````(#6`0``````<0``````````````
M`````('6`0``````<@```````````````````(+6`0``````<P``````````
M`````````(/6`0``````=````````````````````(36`0``````=0``````
M`````````````(76`0``````=@```````````````````(;6`0``````=P``
M`````````````````(?6`0``````>````````````````````(C6`0``````
M>0```````````````````(G6`0``````>@```````````````````*C6`0``
M````L0,``````````````````*G6`0``````L@,``````````````````*K6
M`0``````LP,``````````````````*O6`0``````M`,`````````````````
M`*S6`0``````M0,``````````````````*W6`0``````M@,`````````````
M`````*[6`0``````MP,``````````````````*_6`0``````N`,`````````
M`````````+#6`0``````N0,``````````````````+'6`0``````N@,`````
M`````````````++6`0``````NP,``````````````````+/6`0``````O`,`
M`````````````````+36`0``````O0,``````````````````+76`0``````
MO@,``````````````````+;6`0``````OP,``````````````````+?6`0``
M````P`,``````````````````+C6`0``````P0,``````````````````+G6
M`0``````N`,``````````````````+K6`0``````PP,`````````````````
M`+O6`0``````Q`,``````````````````+S6`0``````Q0,`````````````
M`````+W6`0``````Q@,``````````````````+[6`0``````QP,`````````
M`````````+_6`0``````R`,``````````````````,#6`0``````R0,`````
M`````````````-/6`0``````PP,``````````````````.+6`0``````L0,`
M`````````````````./6`0``````L@,``````````````````.36`0``````
MLP,``````````````````.76`0``````M`,``````````````````.;6`0``
M````M0,``````````````````.?6`0``````M@,``````````````````.C6
M`0``````MP,``````````````````.G6`0``````N`,`````````````````
M`.K6`0``````N0,``````````````````.O6`0``````N@,`````````````
M`````.S6`0``````NP,``````````````````.W6`0``````O`,`````````
M`````````.[6`0``````O0,``````````````````._6`0``````O@,`````
M`````````````/#6`0``````OP,``````````````````/'6`0``````P`,`
M`````````````````/+6`0``````P0,``````````````````//6`0``````
MN`,``````````````````/36`0``````PP,``````````````````/76`0``
M````Q`,``````````````````/;6`0``````Q0,``````````````````/?6
M`0``````Q@,``````````````````/C6`0``````QP,`````````````````
M`/G6`0``````R`,``````````````````/K6`0``````R0,`````````````
M``````W7`0``````PP,``````````````````!S7`0``````L0,`````````
M`````````!W7`0``````L@,``````````````````![7`0``````LP,`````
M`````````````!_7`0``````M`,``````````````````"#7`0``````M0,`
M`````````````````"'7`0``````M@,``````````````````"+7`0``````
MMP,``````````````````"/7`0``````N`,``````````````````"37`0``
M````N0,``````````````````"77`0``````N@,``````````````````";7
M`0``````NP,``````````````````"?7`0``````O`,`````````````````
M`"C7`0``````O0,``````````````````"G7`0``````O@,`````````````
M`````"K7`0``````OP,``````````````````"O7`0``````P`,`````````
M`````````"S7`0``````P0,``````````````````"W7`0``````N`,`````
M`````````````"[7`0``````PP,``````````````````"_7`0``````Q`,`
M`````````````````##7`0``````Q0,``````````````````#'7`0``````
MQ@,``````````````````#+7`0``````QP,``````````````````#/7`0``
M````R`,``````````````````#37`0``````R0,``````````````````$?7
M`0``````PP,``````````````````%;7`0``````L0,`````````````````
M`%?7`0``````L@,``````````````````%C7`0``````LP,`````````````
M`````%G7`0``````M`,``````````````````%K7`0``````M0,`````````
M`````````%O7`0``````M@,``````````````````%S7`0``````MP,`````
M`````````````%W7`0``````N`,``````````````````%[7`0``````N0,`
M`````````````````%_7`0``````N@,``````````````````&#7`0``````
MNP,``````````````````&'7`0``````O`,``````````````````&+7`0``
M````O0,``````````````````&/7`0``````O@,``````````````````&37
M`0``````OP,``````````````````&77`0``````P`,`````````````````
M`&;7`0``````P0,``````````````````&?7`0``````N`,`````````````
M`````&C7`0``````PP,``````````````````&G7`0``````Q`,`````````
M`````````&K7`0``````Q0,``````````````````&O7`0``````Q@,`````
M`````````````&S7`0``````QP,``````````````````&W7`0``````R`,`
M`````````````````&[7`0``````R0,``````````````````('7`0``````
MPP,``````````````````)#7`0``````L0,``````````````````)'7`0``
M````L@,``````````````````)+7`0``````LP,``````````````````)/7
M`0``````M`,``````````````````)37`0``````M0,`````````````````
M`)77`0``````M@,``````````````````);7`0``````MP,`````````````
M`````)?7`0``````N`,``````````````````)C7`0``````N0,`````````
M`````````)G7`0``````N@,``````````````````)K7`0``````NP,`````
M`````````````)O7`0``````O`,``````````````````)S7`0``````O0,`
M`````````````````)W7`0``````O@,``````````````````)[7`0``````
MOP,``````````````````)_7`0``````P`,``````````````````*#7`0``
M````P0,``````````````````*'7`0``````N`,``````````````````*+7
M`0``````PP,``````````````````*/7`0``````Q`,`````````````````
M`*37`0``````Q0,``````````````````*77`0``````Q@,`````````````
M`````*;7`0``````QP,``````````````````*?7`0``````R`,`````````
M`````````*C7`0``````R0,``````````````````+O7`0``````PP,`````
M`````````````````````````````````````````````*T`````````````
M`````````````````$\#``````````````````````````````88````````
M``````````````````````L8``````````````````````````````P8````
M``````````````````````````T8``````````````````````````````L@
M``````````````````````````````P@````````````````````````````
M``T@`````````````````````````````&`@````````````````````````
M``````#^``````````````````````````````'^````````````````````
M``````````+^``````````````````````````````/^````````````````
M``````````````3^``````````````````````````````7^````````````
M``````````````````;^``````````````````````````````?^````````
M``````````````````````C^``````````````````````````````G^````
M``````````````````````````K^``````````````````````````````O^
M``````````````````````````````S^````````````````````````````
M``W^``````````````````````````````[^````````````````````````
M``````_^`````````````````````````````/_^````````````````````
M`````````````````````````````````````````"$"````````````````
M`````````````#0"``!/`@```````````````````````*X"``"O`@``````
M`````````````````.\"``#_`@```````````````````````%`#``!?`P``
M`````````````````````'`#``!S`P```````````````````````'8#``!Y
M`P```````````````````````'L#``!]`P```````````````````````'\#
M``"#`P```````````````````````(L#````````````````````````````
M`(T#`````````````````````````````*(#````````````````````````
M`````,\#`````````````````````````````/<#``#_`P``````````````
M`````````(<$`````````````````````````````,\$````````````````
M`````````````/8$``#W!````````````````````````/H$``#_!```````
M`````````````````!`%```P!0```````````````````````%<%``!8!0``
M`````````````````````&`%`````````````````````````````(@%````
M`````````````````````````(L%``"0!0```````````````````````*(%
M`````````````````````````````+H%````````````````````````````
M`,4%``#/!0```````````````````````.L%``#O!0``````````````````
M`````/4%```+!@````````````````````````T&```:!@``````````````
M`````````!P&```>!@```````````````````````"`&````````````````
M`````````````#L&```_!@```````````````````````%8&``!?!@``````
M`````````````````.X&``#O!@```````````````````````/\&````````
M``````````````````````X'`````````````````````````````"T'```O
M!P```````````````````````$L'``!_!P```````````````````````+('
M````"0````````````````````````0)````````````````````````````
M`#H)```["0```````````````````````$X)``!/"0``````````````````
M`````%4)``!7"0```````````````````````'$)``"`"0``````````````
M`````````(0)`````````````````````````````(T)``"."0``````````
M`````````````)$)``"2"0```````````````````````*D)````````````
M`````````````````+$)`````````````````````````````+,)``"U"0``
M`````````````````````+H)``"["0```````````````````````+T)````
M`````````````````````````,4)``#&"0```````````````````````,D)
M``#*"0```````````````````````,X)``#6"0``````````````````````
M`-@)``#;"0```````````````````````-X)````````````````````````
M`````.0)``#E"0```````````````````````/L)```!"@``````````````
M``````````,*```$"@````````````````````````L*```."@``````````
M`````````````!$*```2"@```````````````````````"D*````````````
M`````````````````#$*`````````````````````````````#0*````````
M`````````````````````#<*`````````````````````````````#H*```[
M"@```````````````````````#T*`````````````````````````````$,*
M``!&"@```````````````````````$D*``!*"@``````````````````````
M`$X*``!8"@```````````````````````%T*````````````````````````
M`````%\*``!E"@```````````````````````'4*``"`"@``````````````
M`````````(0*`````````````````````````````(P*````````````````
M`````````````(X*`````````````````````````````)(*````````````
M`````````````````*D*`````````````````````````````+$*````````
M`````````````````````+0*`````````````````````````````+H*``"[
M"@```````````````````````,8*`````````````````````````````,H*
M`````````````````````````````,X*``#/"@``````````````````````
M`-$*``#?"@```````````````````````.$*``#E"@``````````````````
M`````/`*````"P````````````````````````0+````````````````````
M``````````T+```."P```````````````````````!$+```2"P``````````
M`````````````"D+`````````````````````````````#$+````````````
M`````````````````#0+```U"P```````````````````````#H+```["P``
M`````````````````````$0+``!&"P```````````````````````$D+``!*
M"P```````````````````````$X+``!5"P```````````````````````%@+
M``!;"P```````````````````````%X+````````````````````````````
M`&(+``!E"P```````````````````````'$+``"!"P``````````````````
M`````(0+`````````````````````````````(L+``"-"P``````````````
M`````````)$+`````````````````````````````)8+``"8"P``````````
M`````````````)L+`````````````````````````````)T+````````````
M`````````````````*`+``"B"P```````````````````````*4+``"G"P``
M`````````````````````*L+``"M"P```````````````````````+8+````
M`````````````````````````+H+``"]"P```````````````````````,,+
M``#%"P```````````````````````,D+````````````````````````````
M`,X+``#6"P```````````````````````-@+``#F"P``````````````````
M`````/,+````#`````````````````````````0,````````````````````
M``````````T,`````````````````````````````!$,````````````````
M`````````````"D,`````````````````````````````#0,````````````
M`````````````````#H,```]#````````````````````````$4,````````
M`````````````````````$D,`````````````````````````````$X,``!4
M#````````````````````````%<,``!?#````````````````````````&(,
M``!E#````````````````````````'`,``"!#```````````````````````
M`(0,`````````````````````````````(T,````````````````````````
M`````)$,`````````````````````````````*D,````````````````````
M`````````+0,`````````````````````````````+H,``"]#```````````
M`````````````,4,`````````````````````````````,D,````````````
M`````````````````,X,``#4#````````````````````````-<,``#=#```
M`````````````````````-\,`````````````````````````````.(,``#E
M#````````````````````````/`,```!#0````````````````````````0-
M``````````````````````````````T-````````````````````````````
M`!$-`````````````````````````````"D-````````````````````````
M`````#H-```]#0```````````````````````$0-``!%#0``````````````
M`````````$D-`````````````````````````````$X-``!6#0``````````
M`````````````%@-``!?#0```````````````````````&(-``!E#0``````
M`````````````````'`-``"!#0```````````````````````(0-````````
M`````````````````````)<-``"9#0```````````````````````+(-````
M`````````````````````````+P-`````````````````````````````+X-
M``"_#0```````````````````````,<-``#)#0``````````````````````
M`,L-``#.#0```````````````````````-4-````````````````````````
M`````-<-`````````````````````````````.`-``#Q#0``````````````
M`````````/4-````#@```````````````````````#L.```^#@``````````
M`````````````%P.``"`#@```````````````````````(,.````````````
M`````````````````(4.``"&#@```````````````````````(D.````````
M`````````````````````(L.``",#@```````````````````````(X.``"3
M#@```````````````````````)@.`````````````````````````````*`.
M`````````````````````````````*0.````````````````````````````
M`*8.`````````````````````````````*@.``"I#@``````````````````
M`````*P.`````````````````````````````+H.````````````````````
M`````````+X.``"_#@```````````````````````,4.````````````````
M`````````````,<.`````````````````````````````,X.``#/#@``````
M`````````````````-H.``#;#@```````````````````````-X.``#_#@``
M`````````````````````$@/`````````````````````````````&L/``!P
M#P```````````````````````(P/``"/#P```````````````````````)@/
M`````````````````````````````+T/````````````````````````````
M`,T/``#.#P```````````````````````-`/``#_#P``````````````````
M`````"(0`````````````````````````````"@0````````````````````
M`````````"L0`````````````````````````````#,0```U$```````````
M`````````````#H0```_$````````````````````````%H0``"?$```````
M`````````````````,80``#/$````````````````````````/D0``#Z$```
M`````````````````````/P0``#_$````````````````````````%H1``!>
M$0```````````````````````*,1``"G$0```````````````````````/H1
M``#_$0````````````````````````<2````````````````````````````
M`$<2`````````````````````````````$D2````````````````````````
M`````$X2``!/$@```````````````````````%<2````````````````````
M`````````%D2`````````````````````````````%X2``!?$@``````````
M`````````````(<2`````````````````````````````(D2````````````
M`````````````````(X2``"/$@```````````````````````*\2````````
M`````````````````````+$2`````````````````````````````+82``"W
M$@```````````````````````+\2`````````````````````````````,$2
M`````````````````````````````,82``#'$@``````````````````````
M`,\2`````````````````````````````-<2````````````````````````
M`````.\2``````````````````````````````\3````````````````````
M`````````!$3`````````````````````````````!83```7$P``````````
M`````````````!\3`````````````````````````````$<3````````````
M`````````````````%L3``!@$P```````````````````````'T3``"?$P``
M`````````````````````/43````%````````````````````````'<6``!_
M%@```````````````````````)T6``"?%@```````````````````````/$6
M``#_%@````````````````````````T7````````````````````````````
M`!47```?%P```````````````````````#<7```_%P``````````````````
M`````%07``!?%P```````````````````````&T7````````````````````
M`````````'$7`````````````````````````````'07``!_%P``````````
M`````````````-T7``#?%P```````````````````````.H7``#_%P``````
M``````````````````\8`````````````````````````````!H8```?&```
M`````````````````````'@8``!_&````````````````````````*H8``#_
M'0```````````````````````)P>``"?'@```````````````````````/H>
M``#_'@```````````````````````!8?```7'P``````````````````````
M`!X?```?'P```````````````````````$8?``!''P``````````````````
M`````$X?``!/'P```````````````````````%@?````````````````````
M`````````%H?`````````````````````````````%P?````````````````
M`````````````%X?`````````````````````````````'X?``!_'P``````
M`````````````````+4?`````````````````````````````,4?````````
M`````````````````````-0?``#5'P```````````````````````-P?````
M`````````````````````````/`?``#Q'P```````````````````````/4?
M`````````````````````````````/\?````````````````````````````
M`%,@``!6(````````````````````````%@@``!>(```````````````````
M`````&0@``!I(````````````````````````'(@``!S(```````````````
M`````````(\@``"?(````````````````````````+(@``#/(```````````
M`````````````.L@``#_(````````````````````````#LA```\(0``````
M`````````````````$PA``!2(0```````````````````````(0A``"/(0``
M`````````````````````,\C``#_(P```````````````````````"<D```_
M)````````````````````````$LD``!?)````````````````````````/\D
M`````````````````````````````!0F```5)@``````````````````````
M`!@F`````````````````````````````'XF``!_)@``````````````````
M`````(HF````)P````````````````````````4G````````````````````
M``````````HG```+)P```````````````````````"@G````````````````
M`````````````$PG`````````````````````````````$XG````````````
M`````````````````%,G``!5)P```````````````````````%<G````````
M`````````````````````%\G``!@)P```````````````````````)4G``"7
M)P```````````````````````+`G`````````````````````````````+\G
M``#/)P```````````````````````.PG``#O)P``````````````````````
M```K``!_+@```````````````````````)HN````````````````````````
M`````/0N``#_+@```````````````````````-8O``#O+P``````````````
M`````````/PO``#_+P```````````````````````$`P````````````````
M`````````````)<P``"8,``````````````````````````Q```$,0``````
M`````````````````"TQ```P,0```````````````````````(\Q````````
M`````````````````````+@Q``#O,0```````````````````````!TR```?
M,@```````````````````````$0R``!0,@```````````````````````'PR
M``!^,@```````````````````````,PR``#/,@``````````````````````
M`/\R`````````````````````````````'<S``!Z,P``````````````````
M`````-XS``#?,P```````````````````````/\S````````````````````
M`````````+9-``#_30```````````````````````*:?``#_GP``````````
M`````````````(VD``"/I````````````````````````,>D``#_JP``````
M`````````````````*37``#_UP```````````````````````"[Z```O^@``
M`````````````````````&OZ``#_^@````````````````````````?[```2
M^P```````````````````````!C[```<^P```````````````````````#?[
M`````````````````````````````#W[````````````````````````````
M`#_[`````````````````````````````$+[````````````````````````
M`````$7[`````````````````````````````++[``#2^P``````````````
M`````````$#]``!/_0```````````````````````)#]``"1_0``````````
M`````````````,C]``#/_0```````````````````````/W]``#__0``````
M`````````````````!#^```?_@```````````````````````"3^```O_@``
M`````````````````````$?^``!(_@```````````````````````%/^````
M`````````````````````````&?^`````````````````````````````&S^
M``!O_@```````````````````````'7^````````````````````````````
M`/W^``#^_@````````````````````````#_````````````````````````
M`````+__``#!_P```````````````````````,C_``#)_P``````````````
M`````````-#_``#1_P```````````````````````-C_``#9_P``````````
M`````````````-W_``#?_P```````````````````````.?_````````````
M`````````````````.__``#X_P```````````````````````````0#_`@$`
M`````````````````````!\#`0```````````````````````````"0#`0`O
M`P$``````````````````````$L#`0#_`P$``````````````````````"8$
M`0`G!`$``````````````````````$X$`0#_SP$`````````````````````
M`/;0`0#_T`$``````````````````````"?1`0`IT0$`````````````````
M`````-[1`0#_TP$``````````````````````%74`0``````````````````
M`````````)W4`0```````````````````````````*#4`0"AU`$`````````
M`````````````*/4`0"DU`$``````````````````````*?4`0"HU`$`````
M`````````````````*W4`0```````````````````````````+K4`0``````
M`````````````````````+S4`0```````````````````````````,'4`0``
M`````````````````````````,34`0````````````````````````````;5
M`0````````````````````````````O5`0`,U0$`````````````````````
M`!75`0```````````````````````````!W5`0``````````````````````
M`````#K5`0```````````````````````````#_5`0``````````````````
M`````````$75`0```````````````````````````$?5`0!)U0$`````````
M`````````````%'5`0```````````````````````````*36`0"GU@$`````
M`````````````````,K7`0#-UP$```````````````````````#8`0#]_P$`
M`````````````````````->F`@#_]P(``````````````````````![Z`@#]
M_P(``````````````````````````P#]_P,`````````````````````````
M!`#]_P0`````````````````````````!0#]_P4`````````````````````
M````!@#]_P8`````````````````````````!P#]_P<`````````````````
M````````"`#]_P@`````````````````````````"0#]_PD`````````````
M````````````"@#]_PH`````````````````````````"P#]_PL`````````
M````````````````#`#]_PP`````````````````````````#0#]_PT`````
M````````````````````#@````````````````````````````(`#@`?``X`
M`````````````````````(``#@#]_PX`````````````````````````````
M````````````````````````````````````0U`X-38`0U`Y,C(`0U`Y-#,`
M0U`Q,#0V`$-0,3$R-`!#4#$Q,CD`0U`Q,38Q`$E"33$Q-C$`24)-+3$Q-C$`
M0U-)0DTQ,38Q`$-0,3$V,@!)0DTQ,38R`$E"32TQ,38R`$-324)-,3$V,@!#
M4#$Q-C,`24)-,3$V,P!)0DTM,3$V,P!#4TE"33$Q-C,`1$5#+4M!3DI)`$1%
M0RU(04Y950!#4#0S-P!)0DTT,S<`-#,W`$-34$,X0T]$15!!1T4T,S<`0U`W
M,S<`0U`W-S4`24)--S<U`$-34$,W-S5"04Q424,`0U`X-3(`24)-.#4R`#@U
M,@!#4U!#4#@U,@!#4#@U,P!#4#@U-0!)0DTX-34`.#4U`$-324)-.#4U`$-0
M.#4W`$E"33@U-P`X-3<`0U-)0DTX-3<`0U`X-3@`0U`X-C``24)-.#8P`#@V
M,`!#4TE"33@V,`!#4#@V,0!)0DTX-C$`.#8Q`$-0+4E3`$-324)-.#8Q`$-0
M.#8S`$E"33@V,P`X-C,`0U-)0DTX-C,`0U`X-C0`24)-.#8T`$-324)-.#8T
M`$-0.#8U`$E"33@V-0`X-C4`0U-)0DTX-C4`0U`X-CD`24)-.#8Y`#@V.0!#
M4"U'4@!#4TE"33@V.0!#4#$Q,C4`155#+4I)4U@P,C$S`%-(24947TI)4U@P
M,C$S`$E33RTR,#(R+4I0+3,`5$13-38U`$E33RU)4BTR,S``4DE30T]3+4Q!
M5$E.,0```````````````````````&8````&````9P````P```!H````$@``
M`&D````9````:@```"````!K````)P```&P````N````;````#8```!L````
M/P```&P```!)````;0```%````!M````6````&T```!A````;0```&L```!N
M````<@```&X```!Z````;@```(,```!N````C0```&\```"7````<````*$`
M``!Q````IP```'$```"N````<0```+(```!Q````PP```'(```#)````<P``
M`,\```!S````U@```',```#D````=````.H```!T````\0```'0```#U````
M=````/X```!U````!`$``'8````*`0``=@```!$!``!V````%0$``'8````>
M`0``=P```"0!``!W````*P$``'<````O`0``=P```#@!``!X````/@$``'D`
M``!$`0``>0```$L!``!Y````3P$``'D```!8`0``>@```%X!``!Z````90$`
M`'H```!I`0``>@```&\!``!Z````>`$``'L```!^`0``>P```(4!``![````
MB0$``'L```"2`0``?````)@!``!\````GP$``'P```"H`0``?0```*X!``!]
M````M0$``'T```"Y`0``?0```,(!``!^````R`$``'X```#/`0``?@```-,!
M``!^````V0$``'X```#B`0``?P```.D!``"`````]@$``($````%`@``@@``
M`!,"``"#````&@(``(,````E`@``A`````````````````````````!#3@!,
M,0!,,@!,-@!,-0!,.``X-C(`3#,`.#8V`$,Y.0!%54-#3@!#4#$R-3$`0U`Q
M,C4R`$-0.#8R`$550RU#3@!#4#$R-38`0U`X-C8`0U`Q,C4U`$A:`$-0,3,V
M,0!#4#DS,@!#4#@Q.0!#4#DS-@!8,#(Q,@!#4#$R-3@`3#<`0U`Q,C4S`$PT
M`$-0,3$S,P!2.`!#2$E.15-%`$E33S@X-3DM,0!)4T\X.#4Y+3(`25-/.#@U
M.2TV`$E33RTX.#4Y+3$`25-/.#@U.2TU`$E33RTX.#4Y+3(`6#`R,#$`25-/
M.#@U.2TQ-@!)4T\M.#@U.2TV`$E33S@X-3DM,34`25-/+3@X-3DM-0!)4T\X
M.#4Y+3D`25-/.#@U.2TX`$E33RTX.#4Y+3$V`#@U,`!)4T\M.#@U.2TQ-0!)
M4T\M.#@U.2TY`$-0.30Y`$E33RTX.#4Y+3@`25-/.#@U.2TS`$E33RU)4BTV
M`%@P,C`X`$-94DE,3$E#`$E33RTR,#(R+4-.`$E33S@X-3DM,3,`25-/+3@X
M-3DM,P!#4#$R-3``0U`Y-3``0U`X-3``25-/-C0V+4-.`%-*25,`25-/+3@X
M-3DM,3,`25-/+4E2+3$R-@!)4T\M25(M,C(V`$E33RU)4BTQ-C8`25-/+4E2
M+3$V-0!#4#$R-3<`05-#24D`25-/+4E2+34X`$-0,S8W`$Q!5$E.,0!)4T\M
M25(M,34Y`$Q!5$E.,@!)4T\M25(M,3DY`$Q!5$E.-@!,051)3C4`25-/7S@X
M-3DM,0!#4TE33S(P,C)#3@!)4T]?.#@U.2TR`$E33RU)4BTQ,S@`0U`Q,C4T
M`$E33U\X.#4Y+38`25-/7S@X-3DM-0!,051)3C@`25-/+4E2+3$P,0!)4T]?
M.#@U.2TQ-@!'0C(S,3(`25-/7S@X-3DM,34`25-/+4-%3%1)0P!)4T]?.#@U
M.2TY`$Q!5$E.,P!)4T]?.#@U.2TX`%5(0P!)4T\X.#4Y+3$P`$E33U\X.#4Y
M+3$U.C$Y.3@`34%#`$E33U\X.#4Y+3,`25-/+4E2+3$P.0!)4T\X.#4Y+3<`
M25-/+3@X-3DM,3``0U-!4T-)20!)4T]?.#@U.2TQ,P!)4T\M25(M,3<Y`$E3
M3RTX.#4Y+3<`25-/+4E2+3(P,P!)4T\M25(M,30Y`$U3+45%`$E33RU)4BTQ
M-#@`55,`0U`X-S0`25-/.#@U.2TT`$E33RU)4BTQ,3``25-/7S@X-3DM,3`Z
M,3DY,@!)4T]?.#@U.2TQ-CHR,#`P`$E33S@X-3DM,30`25-/+3@X-3DM-`!)
M0DTX-C(`25-/+4E2+34W`$E"33@V-@!)4T\M.#@U.2TQ-`!)4T\M25(M,3(W
M`$E33RTR,#(R+4-.+4585`!)4T\M25(M.#<`25-/+4E2+3$U-P!50U,M,@!)
M0DTX,3D`25-/7S@X-3DM,30Z,3DY.`!)4T\M25(M,30`14Q/5%\Y,C@`3$%4
M24XW`%541BTQ-@!)4T]?.#@U.2TQ,`!#4U5.24-/1$4`54-3+3),10!55$8M
M.`!)4T\M25(M,3`P`$E33U\X.#4Y+3<`551&+3,R`$-(05(`54Y)0T]$12TQ
M+3$`0U-53DE#3T1%,3$`5$E3-C(P`$550TM2`%541BTQ-DQ%`$Q!5$E.-`!+
M4T-?-38P,0!425,M-C(P`$550RU+4@!)0DTM0U`Q,3,S`$E33U\X.#4Y+30`
M551&+3,R3$4`5DE30TE)`$M/23@M4@!)4T]?.#@U.2TQ-`!#4TM/23A2`$=2
M145+.`!-4RU#65),`$-35DE30TE)`$E"33@U,`!)4T\M25(M,30T`$))1S4`
M54-3+31,10!'0C$X,#,P`$U!0T-94DE,3$E#`$-354Y)0T]$13$Q551&-P!5
M3DE#3T1%+3$M,2U55$8M-P!"24<M-0!)0DTS-C<`5$E3-C(P+3``0U-"24<U
M`$Y%6%135$50`$-32U-#-38P,3$Y.#<`0U-)4T],051)3C$`2T]214%.`$-3
M25-/3$%424XR`$-.+4))1S4`551&+3<`0U-)4T],051)3C8`0U-)4T],051)
M3D-94DE,3$E#`$-325-/3$%424XU`%1#5DX`5$E3-C(P+C(U,CDM,0!#4T="
M,C,Q,@!)4T\M,3`V-#8M54-3+3(`54-3+30`355,14Q!3RTQ`$E33RTR,#(R
M+4M2`$5#34$M,3$X`$="7S(S,3(M.#``0U-50U,T`$="2P!#4TE33TQ!5$E.
M,P!)4T\V-#8M55,`55,M05-#24D`5$E3-C(P+C(U,S,M,0!+3TDX+50`35,M
M04Y320!+4U]#7S4V,#$M,3DX.0!'0E\Q.3@X+3@P`$550U17`$=2145+`$55
M0RU45P!724Y$3U=3+3$R-3$`5TE.1$]74RTQ,C4R`$I0`%=)3D1/5U,M,3(U
M-@!724Y$3U=3+3$R-34`5DE30TE),2XQ+3$`0U-)4T\R,#(R2U(`5TE.1$]7
M4RTQ,C4X`%=)3D1/5U,M,3(U,P!!4DU30TE)+3@`0U-)0DTX-C8`4D]-04XX
M`$A:+4="+3(S,3(`155#2E``5$E3-C(P+C(U,S,M,`!+4U]#7S4V,#$M,3DX
M-P!-04-)0T5,04Y$`$E33RTQ,#8T-BU50U,M-`!50U,M,D)%`$550RU*4`!7
M24Y$3U=3+3$R-3``05)!0DE#`%541BTQ-D)%`%1#5DXM-3<Q,@!724Y$3U=3
M+3$R-3<`0U-00S@V,DQ!5$E.2$5"4D57`%1#5DXU-S$R+3$`551&+3,R0D4`
M5TE.1$]74RTQ,C4T`$-3155#2U(`05--3RTW,#@`0U-)4T],051)3D%204))
M0P!-04-)3E1/4T@`54-3+3(M24Y415).04P`0U-)4T],051)3C0`14--02TQ
M,30`0TXM1T(M25-/25(Q-C4`04Y325]8,RXT+3$Y.#8`0U-)4T\U-T=",3DX
M.`!#4TE33S4X1T(R,S$R.#``2%`M4D]-04XX`$%.4TE?6#,N-"TQ.38X`$U!
M0U1(04D`54-3+31"10!#4TA04D]-04XX`$-.+4="`%5.24-/1$5,25143$4`
M25-/7S@X-3DM-3HQ.3@X`$E33U\X.#4Y+3DZ,3DX.0!)4T]?.#@U.2TX.C$Y
M.#@`2T])."U5`$E33U\X.#4Y+3,Z,3DX.`!)4T\M,C`R,BU*4`!)4T\M,C`R
M,BU*4"TQ`$E33RTR,#(R+4I0+3(`0U-)4T],051)3DA%0E)%5P!)4T\V-#8M
M2E``15A414Y$141?54Y)6%]#3T1%7U!!0TM%1%]&3U)-051?1D]27TI!4$%.
M15-%`%5#4RTT+4E.5$523D%,`$E33U\X.#4Y+3$Z,3DX-P!)4T]?.#@U.2TR
M.C$Y.#<`25-/7S@X-3DM-CHQ.3@W`$-325-/,C`R,DI0`$-325-/,C`R,DI0
M,@!)4T]?.#@U.2TT.C$Y.#@`34%#0T5.5%)!3$554D]010!(14)215<`35,M
M2$5"4@!)4T]?-C0V+DE25CHQ.3DQ`$-3155#5%<`2T])."U250!724Y$3U=3
M+3@W-`!*25,P,C`X`$=%3U)'24%.+5!3`$E33U\X.#4Y+3<Z,3DX-P!#4TE3
M3TQ!5$E.1U)%14L`2DE37T,V,C(V+3$Y.#,`34%#4D]-04X`54-3+3(M4U=!
M4%!%1`!#4TU!0TE.5$]32`!"24=&259%`$-325-/,34Y2DE36#`R,3(Q.3DP
M`$-325-/,31*25-#-C(R,%)/`$-34$,X-3!-54Q424Q)3D=504P`0DE'+49)
M5D4`2DE37T,V,C(P+3$Y-CDM4D\`2DE37U@P,C$R`$))1S5(2U-#4P!*25-8
M,#(P,2TQ.3<V`$=%3U)'24%.+4%#041%35D`0DE'-2U(2U-#4P!#4TE33S@W
M2DE36#`R,#@`34%#1U)%14L`35,M1U)%14L`54-3+30M4U=!4%!%1`!-04-#
M4D]!5$E!3@!*25-?6#`R,#$`5T-(05)?5`!53DE#3T1%0DE'`$I)4U]8,#(Q
M,BTQ.3DP`$I)4U]8,#(P.`!-04-!4D%"24,`0U-(04Q&5TE$5$A+051!2T%.
M00!*25-?6#`R,#@M,3DX,P!32$E&5"U*25,`34%#54M204E.10!#4T550U!+
M1$9-5$I!4$%.15-%`$I)4U]8,#(P."TQ.3DP`$-34TA)1E1*25,`2DE37U@P
M,C$R+C$Y.3`M,`!-04-(14)215<`4TA)1E1?2DE3`%1#5DXU-S$R+3$Z,3DY
M,P!-4RU455)+`$U!0U154DM)4T@`34%#4D]-04Y)00!-4RU!4D%"`$I!5D$`
M35-?2T%.2DD`2D](04(`5TE.0D%,5%))30``````````````````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\``````````$X```#_____``````,````5
M````!@```!8```#_____``````D````>````#````!T```#_____`````/__
M__\`````_____P````#_____``````\````@````_____P````#_____````
M`!(````P````%@```!<```#_____`````/____\`````&0```#$````=````
M$P```/____\`````_____P````#_____`````"$```!8````_____P````#_
M____`````"<````G````_____P`````N````*````#4````P````.P```%@`
M``#_____`````$(````L````20```#$```!/````*P```%8```!=````____
M_P````!9````9````&````!4````_____P````!F````%0```/____\`````
M;````%D```!R````30```'@````N````_____P````#_____`````'\````?
M````_____P````#_____`````/____\`````_____P````""````*0```/__
M__\`````_____P````#_____`````/____\`````B0```!@```#_____````
M`/____\`````C````$4```#_____`````),````^````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````E@```$\```">
M````%0```/____\`````J````!8```#_____`````/____\`````_____P``
M``"R````&@```+P````5````QP```!D```#1````%@```-P```!+````____
M_P````#B````(@```.T````:````^````"$````#`0``&0````X!```=````
M_____P`````8`0``'````"(!```B````+@$``"\````R`0``(0```/____\`
M````/@$``!T```!)`0``8P```$\!```<````6@$``!<```!D`0```````&T!
M``!,````<P$``!D```#_____`````'P!``!;````B`$``!\```"3`0``%P``
M`)X!```F````I0$``&````"K`0``+P```+$!``!.````NP$``%,```#``0``
M'P```,P!```;````UP$``"(```#B`0``1@```/____\`````[0$``%````#_
M____`````/@!```M````_P$```````#_____``````4"``!/````_____P``
M```/`@```````!4"```5````'`(``$T````G`@``%@```/____\`````____
M_P`````N`@``(````#D"```>````_____P````!``@``'0```$<"```5````
M4@(``%L```!>`@``%@```&D"```<````_____P````!T`@``*@```'L"```:
M````_____P````"&`@``&0```)$"```@````_____P````"8`@``%@```*,"
M```B````KP(``%@```"V`@``(0```,("```@````S0(``!T```#8`@``%P``
M`-\"```<````Z@(``&,```#_____`````/____\`````_____P````#N`@``
M'@```/D"```A````"@,``#(````.`P``%P```!D#```7````_____P`````D
M`P``&P```"X#```>````.@,```````!"`P``'P```$X#```?````_____P``
M``#_____`````%D#```;````_____P````!D`P``(0```/____\`````____
M_P````#_____`````/____\`````;P,``&(```!Z`P``)@```(`#```=````
MBP,```````#_____`````(X#``!'````E`,``!@```">`P``&````*D#```>
M````_____P````"Z`P``(@```/____\`````RP,``"````#6`P``&````.$#
M```P````_____P````#_____`````.@#``!.````\@,``#$```#Y`P``(```
M``4$```:````$`0``%P````@!```3````"H$```>````-00```(````[!```
M%0```/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````$($```@````4P0``$H```#_____`````/____\`````700``!L`
M``#_____`````&8$```?````;00```@```#_____`````'0$```>````____
M_P````"`!````@```(H$```$````D@0```$```"8!```%0```*,$```;````
MK@0```L```"U!```A0```/____\`````_____P````"Z!````P```,8$```#
M````_____P````#2!```1@```-D$``!B````WP0```H```#H!```&````/__
M__\`````_____P````#O!```8@```/@$``!&``````4``&(```#_____````
M``<%``!%````_____P`````2!0``&````!T%```-````)@4``$@````M!0``
M(P```/____\`````_____P`````T!0``(````/____\`````0`4``",```#_
M____`````$@%```;````3P4``"<```#_____`````/____\`````5P4``$@`
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````!@!0``+P```/____\`````
M_____P````!G!0``&0```/____\`````_____P````!R!0``7P```'<%```'
M````?P4``%H```#_____`````(<%```W````DP4```X```"C!0``#@```+4%
M``!?````_____P````"[!0```````,(%``!&````_____P````#+!0``7P``
M`-(%```_````_____P````#;!0``8@```.D%```5````]04``&(```#\!0``
M%@````@&``!?````$`8```X```#_____`````!8&```>````(@8``!D````U
M!@``'0```/____\`````008``$D```#_____`````/____\`````1@8``$8`
M``#_____`````/____\`````5`8``%@```#_____`````%T&```"````;08`
M``4```!S!@``1````'T&``!E````B08``!L```"2!@``3P```)T&```%````
MI`8``%D```"H!@``%P```+0&````````_____P````"^!@```````,<&``!&
M````U08``$,```#<!@``*````.0&``!B````\P8``$X```#_____`````/__
M__\`````_@8``%X```#_____`````/____\`````_____P`````$!P``&P``
M`/____\`````_____P`````*!P``7@```!$'```G````'@<``"@````K!P``
M2@```"X'```L````.P<``"L```#_____`````$@'``!(````5`<``&4```#_
M____`````&`'```N````_____P````#_____`````/____\`````;0<``"D`
M``!Z!P``0````/____\`````_____P````#_____`````/____\`````A`<`
M`#$```#_____`````(T'```^````E`<``%T```"?!P``4@```*4'``!&````
MLP<``&(```#"!P``-````,T'```%````W0<```,```#_____`````.4'``!2
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````.P'```F````^0<``!H`````"```"0``
M`/____\`````_____P`````)"```20```!,(```M````_____P`````@"```
M,````/____\`````,P@``$D```#_____`````/____\`````/@@```P```#_
M____`````/____\`````1P@``"H```#_____`````%0(``!B````_____P``
M``!<"```&@```/____\`````_____P````!E"```&@```'8(```R````@`@`
M``\```"/"```&````/____\`````_____P````#_____`````)L(```:````
M_____P````"D"```4````/____\`````LP@```````#""```3@```/____\`
M````T`@``$\```#@"```/@```/____\`````Z@@```````#Y"```/0```/__
M__\``````0D```8````)"0``/@```/____\`````%`D``%@```#_____````
M`!H)```$````*`D``!D```#_____`````/____\`````.`D``!T```#_____
M`````$@)```<````6`D``"0```#_____`````/____\`````7PD``!<```#_
M____`````/____\`````_____P````!O"0``50```'L)``!6````B0D``%<`
M``"7"0``'````/____\`````_____P````"H"0``2@```/____\`````____
M_P````"R"0``4@```/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````X`D``!$```#_____`````.\)```5
M````_PD``!8```#_____``````\*```:````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`!\*``!5````*PH``%<```#_____`````/____\`````_____P````#_____
M`````/____\`````.`H``!@```#_____`````/____\`````2`H``#,```#_
M____`````/____\`````60H``!P```#_____`````&`*```K````_____P``
M``!H"@```````/____\`````>0H``%X```#_____`````/____\`````____
M_P````#_____`````($*```E````_____P````")"@``1P```/____\`````
M_____P````"5"@``3````)T*``!"````_____P````#_____`````*D*```;
M````_____P````"Y"@``&P```,D*``!,````_____P````#_____`````-@*
M```R````X0H``!````#_____`````/____\`````_____P````#_____````
M`.\*```R````_____P````#_____`````/L*``!?`````PL``$T````8"P``
M2@```"H+```O````_____P````#_____`````/____\`````/@L``%\```#_
M____`````/____\`````_____P````#_____`````/____\`````_____P``
M``!'"P``2@```/____\`````_____P````#_____`````%D+``!-````____
M_P````#_____`````/____\`````8PL``&$```#_____`````/____\`````
M_____P````!M"P``2P```'L+``!!````_____P````","P``80```/____\`
M````_____P````#_____`````)<+``!,````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````IPL``#D```"P"P``*0```/____\`````N0L``!(```#_____
M`````/____\`````_____P````#_____`````,<+```U````_____P````#_
M____`````/____\`````TPL``$L```#_____`````/____\`````W0L``(8`
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````Y0L```,```#_____`````/____\`````
M_____P````#_____`````/`+``!-````_PL``$P```#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M``D,```\````_____P````#_____`````/____\`````_____P`````3#```
M2P```"<,``!,````-@P``%,```#_____`````/____\`````_____P````#_
M____`````$`,```X````_____P````#_____`````/____\`````_____P``
M``#_____`````/____\`````_____P````#_____`````$L,``!2````____
M_P````#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````!?#```3````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````;@P``%,```!Y#```
M30```(H,```[````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````_____P````#_____`````/____\`````E`P``%,`
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````">#```20```/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````"N#```*@```/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````M@P``#H```#_____`````/____\`````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````,$,```V````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````S`P``"P```#_____`````/____\`````U`P``!0```#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````_____P````#_____`````/____\`````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````V0P``%,```#B#```
M9````/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````_____P````#_____`````/____\`````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````_____P````#_____`````/____\`````_____P````#_____````
M`/____\`````_____P````#_____`````/____\`````_____P````#_____
M`````/____\`````_____P````#_____`````/____\`````_____P````#_
M____`````/____\`````_____P````#_____`````/____\`````_____P``
M``#_____`````/____\`````_____P````#_____`````/____\`````____
M_P````#_____`````/____\`````_____P````#_____`````/____\`````
M_____P````#_____`````/____\`````_____P````#_____`````/____\`
M````_____P````#_____`````/____\`````_____P````#_____`````/__
M__\`````Z`P``"T````!````(`````$````A`````0```&,````"````;```
M`&(````#````>0```&4```!N`````0```'P````"````4P```%,````!````
M(@````,````H````8P```"D````!````80````(````\````/`````,```!N
M````;P```'0````!````+0````,````H````4@```"D````"````7@```#``
M```#````*P```"\````M`````@```%X````R`````@```%X````S`````0``
M`"<````!````=0````$```!0`````0```"X````!````+`````(```!>````
M,0````$```!O`````@```#X````^````!0```"`````Q````1"```#0````@
M````!0```"`````Q````1"```#(````@````!0```"`````S````1"```#0`
M```@`````0```#\````"````8````$$````"````M````$$````"````7@``
M`$$````"````?@```$$````"````(@```$$````!````00````(```!!````
M10````$```!#`````@```&````!%`````@```+0```!%`````@```%X```!%
M`````@```"(```!%`````@```&````!)`````@```+0```!)`````@```%X`
M``!)`````@```"(```!)`````0```$0````"````?@```$X````"````8```
M`$\````"````M````$\````"````7@```$\````"````?@```$\````"````
M(@```$\````!````>`````$```!/`````@```&````!5`````@```+0```!5
M`````@```%X```!5`````@```"(```!5`````@```+0```!9`````@```%0`
M``!H`````@```',```!S`````@```&````!A`````@```+0```!A`````@``
M`%X```!A`````@```'X```!A`````@```"(```!A`````0```&$````"````
M80```&4````!````8P````(```!@````90````(```"T````90````(```!>
M````90````(````B````90````(```!@````:0````(```"T````:0````(`
M``!>````:0````(````B````:0````$```!D`````@```'X```!N`````@``
M`&````!O`````@```+0```!O`````@```%X```!O`````@```'X```!O````
M`@```"(```!O`````0```#H````!````;P````(```!@````=0````(```"T
M````=0````(```!>````=0````(````B````=0````(```"T````>0````(`
M``!T````:`````(````B````>0````$```!!`````0```&$````!````00``
M``$```!A`````0```$$````!````80````(```"T````0P````(```"T````
M8P````(```!>````0P````(```!>````8P````$```!#`````0```&,````!
M````0P````$```!C`````0```$0````!````9`````$```!$`````0```&0`
M```!````10````$```!E`````0```$4````!````90````$```!%`````0``
M`&4````!````10````$```!E`````0```$4````!````90````(```!>````
M1P````(```!>````9P````$```!'`````0```&<````!````1P````$```!G
M`````0```$<````!````9P````(```!>````2`````(```!>````:`````$`
M``!(`````0```&@````"````?@```$D````"````?@```&D````!````20``
M``$```!I`````0```$D````!````:0````$```!)`````0```&D````!````
M20````$```!I`````@```$D```!*`````@```&D```!J`````@```%X```!*
M`````@```%X```!J`````0```$L````!````:P````$```!,`````0```&P`
M```!````3`````$```!L`````0```$P````!````;`````$```!,`````0``
M`&P````!````3`````$```!L`````@```+0```!.`````@```+0```!N````
M`0```$X````!````;@````$```!.`````0```&X````"````)P```&X````!
M````3P````$```!O`````0```$\````!````;P````(````B````3P````(`
M```B````;P````(```!/````10````(```!O````90````(```"T````4@``
M``(```"T````<@````$```!2`````0```'(````!````4@````$```!R````
M`@```+0```!3`````@```+0```!S`````@```%X```!3`````@```%X```!S
M`````0```%,````!````<P````$```!3`````0```',````!````5`````$`
M``!T`````0```%0````!````=`````$```!4`````0```'0````"````?@``
M`%4````"````?@```'4````!````50````$```!U`````0```%4````!````
M=0````$```!5`````0```'4````"````(@```%4````"````(@```'4````!
M````50````$```!U`````@```%X```!7`````@```%X```!W`````@```%X`
M``!9`````@```%X```!Y`````@```"(```!9`````@```+0```!:`````@``
M`+0```!Z`````0```%H````!````>@````$```!:`````0```'H````!````
M<P````$```!F`````@```$0```!]`0```@```$0```!^`0```@```&0```!^
M`0```@```$P```!*`````@```$P```!J`````@```&P```!J`````@```$X`
M``!*`````@```$X```!J`````@```&X```!J`````@```$0```!:`````@``
M`$0```!Z`````@```&0```!Z`````0```%,````!````<P````$```!4````
M`0```'0````!````,B````$````S(````0```!@@```!````&2````$````;
M(````0```%X````!````)P````$```"O`````0```+0````!````8`````$`
M``!?`````0```'X````!````(@````$```"R`P```0```+@#```!````I0,`
M``$```#&`P```0```,`#```!````N@,```$```#!`P```0```,(#```!````
MF`,```$```"U`P```0```*,#```"````904``((%```"````U04``-4%```"
M````U04``-D%```"````V04``-D%```"````)P8``'0&```"````2`8``'0&
M```"````QP8``'0&```"````2@8``'0&```"````30X``#(.```"````S0X`
M`+(.```"````JPX``)D.```"````JPX``*$.```"````L@\``($/```"````
MLP\``($/```!````0@````$```!B`````0```$0````!````9`````$```!&
M`````0```&8````!````30````$```!M`````0```%`````!````<`````$`
M``!3`````0```',````!````5`````$```!T`````@```&````!7`````@``
M`&````!W`````@```+0```!7`````@```+0```!W`````@```"(```!7````
M`@```"(```!W`````@```&$```"^`@```@```&````!9`````@```&````!Y
M`````0```"`````!````(`````$````@`````0```"`````!````(`````$`
M```@`````0```"`````!````(`````$````M`````0```"T````!````+0``
M``$````M`````0```"T````!````+0````$````G`````0```"<````!````
M+`````$````G`````0```"(````!````(@````$````B`````0```"(````!
M````*P````$```!O`````0```"X````"````+@```"X````#````+@```"X`
M```N````!````&\````O````;P```&\````!````M`````(```"T````M```
M``,```"T````M````+0````"````-2```#4@```#````-2```#4@```U(```
M`0```#P````!````/@````(````A````(0````$````O`````@```#\````_
M`````@```#\````A`````@```"$````_````!````+0```"T````M````+0`
M```"````4@```',````$````$`$``-,>``!N````9P````,```!%````50``
M`%(````#````80```"\```!C`````P```&$````O````<P````$```!#````
M`@```+````!#`````P```&,````O````;P````,```!C````+P```'4````!
M````D`$```(```"P````1@````$```!G`````0```$@````!````2`````$`
M``!(`````0```&@````!````)P$```$```!)`````0```$D````!````3```
M``$```!L`````0```$X````"````3@```&\````!````4`````$```!1````
M`0```%(````!````4@````$```!2`````P```%0```!%````3`````(```!4
M````30````$```!:`````P```$\```!H````;0````$```!:`````0```$(`
M```!````0P````$```!E`````0```&4````!````10````$```!&`````0``
M`$T````!````;P````$```#0!0```0```-$%```!````T@4```$```#3!0``
M`0```&D````#````1@```$$```!8`````0```+,#```!````DP,```$```"@
M`P```0```!$B```!````1`````$```!D`````0```&4````!````:0````$`
M``!J````!0```"`````Q````1"```#,````@````!0```"`````R````1"``
M`#,````@````!0```"`````Q````1"```#4````@````!0```"`````R````
M1"```#4````@````!0```"`````S````1"```#4````@````!0```"`````T
M````1"```#4````@````!0```"`````Q````1"```#8````@````!0```"``
M```U````1"```#8````@````!0```"`````Q````1"```#@````@````!0``
M`"`````S````1"```#@````@````!0```"`````U````1"```#@````@````
M!0```"`````W````1"```#@````@`````P```"`````Q````1"````$```!)
M`````@```$D```!)`````P```$D```!)````20````(```!)````5@````$`
M``!6`````@```%8```!)`````P```%8```!)````20````0```!6````20``
M`$D```!)`````@```$D```!8`````0```%@````"````6````$D````#````
M6````$D```!)`````0```$P````!````0P````$```!$`````0```$T````!
M````:0````(```!I````:0````,```!I````:0```&D````"````:0```'8`
M```!````=@````(```!V````:0````,```!V````:0```&D````$````=@``
M`&D```!I````:0````(```!I````>`````$```!X`````@```'@```!I````
M`P```'@```!I````:0````$```!L`````0```&,````!````9`````$```!M
M`````@```#P````M`````0```%X````"````+0```#X````!````5@````,`
M```\````+0```#X````"````/````#T````"````/0```#X````#````/```
M`#T````^`````0```"T````!````+P````$```!<`````0```"H````!````
M(B````$```!\`````@```"LB```K(@```P```"LB```K(@``*R(```(````N
M(@``+B(```,````N(@``+B(``"XB```!````.@````$```!^`````@```"\`
M```]`````@```#P````]`````@```#X````]`````@```#P````\`````@``
M`#X````^`````0```+<````#````/````#P````\`````P```#X````^````
M/@````,```"W````MP```+<````%````6P```$X```!5````3````%T````%
M````6P```%,```!/````2````%T````%````6P```%,```!4````6````%T`
M```%````6P```$4```!4````6````%T````%````6P```$4```!/````5```
M`%T````%````6P```$4```!.````40```%T````%````6P```$$```!#````
M2P```%T````%````6P```$(```!%````3````%T````$````6P```$(```!3
M````70````0```!;````2````%0```!=````!````%L```!,````1@```%T`
M```$````6P```%8```!4````70````0```!;````1@```$8```!=````!```
M`%L```!#````4@```%T````$````6P```%,```!/````70````0```!;````
M4P```$D```!=````!0```%L```!$````3````$4```!=````!0```%L```!$
M````0P```#$```!=````!0```%L```!$````0P```#(```!=````!0```%L`
M``!$````0P```#,```!=````!0```%L```!$````0P```#0```!=````!0``
M`%L```!.````00```$L```!=````!0```%L```!3````60```$X```!=````
M!0```%L```!%````5````$(```!=````!0```%L```!#````00```$X```!=
M````!````%L```!%````30```%T````%````6P```%,```!5````0@```%T`
M```%````6P```$4```!3````0P```%T````$````6P```$8```!3````70``
M``0```!;````1P```%,```!=````!````%L```!2````4P```%T````$````
M6P```%4```!3````70````0```!;````4P```%````!=````!0```%L```!$
M````10```$P```!=````!````%L```!.````3````%T````#````*````#$`
M```I`````P```"@````R````*0````,````H````,P```"D````#````*```
M`#0````I`````P```"@````U````*0````,````H````-@```"D````#````
M*````#<````I`````P```"@````X````*0````,````H````.0```"D````$
M````*````#$````P````*0````0````H````,0```#$````I````!````"@`
M```Q````,@```"D````$````*````#$````S````*0````0````H````,0``
M`#0````I````!````"@````Q````-0```"D````$````*````#$````V````
M*0````0````H````,0```#<````I````!````"@````Q````.````"D````$
M````*````#$````Y````*0````0````H````,@```#`````I`````P```"@`
M```Q````*0````,````H````,@```"D````#````*````#,````I`````P``
M`"@````T````*0````,````H````-0```"D````#````*````#8````I````
M`P```"@````W````*0````,````H````.````"D````#````*````#D````I
M````!````"@````Q````,````"D````$````*````#$````Q````*0````0`
M```H````,0```#(````I````!````"@````Q````,P```"D````$````*```
M`#$````T````*0````0````H````,0```#4````I````!````"@````Q````
M-@```"D````$````*````#$````W````*0````0````H````,0```#@````I
M````!````"@````Q````.0```"D````$````*````#(````P````*0````(`
M```Q````+@````(````R````+@````(````S````+@````(````T````+@``
M``(````U````+@````(````V````+@````(````W````+@````(````X````
M+@````(````Y````+@````,````Q````,````"X````#````,0```#$````N
M`````P```#$````R````+@````,````Q````,P```"X````#````,0```#0`
M```N`````P```#$````U````+@````,````Q````-@```"X````#````,0``
M`#<````N`````P```#$````X````+@````,````Q````.0```"X````#````
M,@```#`````N`````P```"@```!A````*0````,````H````8@```"D````#
M````*````&,````I`````P```"@```!D````*0````,````H````90```"D`
M```#````*````&8````I`````P```"@```!G````*0````,````H````:```
M`"D````#````*````&D````I`````P```"@```!J````*0````,````H````
M:P```"D````#````*````&P````I`````P```"@```!M````*0````,````H
M````;@```"D````#````*````&\````I`````P```"@```!P````*0````,`
M```H````<0```"D````#````*````'(````I`````P```"@```!S````*0``
M``,````H````=````"D````#````*````'4````I`````P```"@```!V````
M*0````,````H````=P```"D````#````*````'@````I`````P```"@```!Y
M````*0````,````H````>@```"D````#````*````$$````I`````P```"@`
M``!"````*0````,````H````0P```"D````#````*````$0````I`````P``
M`"@```!%````*0````,````H````1@```"D````#````*````$<````I````
M`P```"@```!(````*0````,````H````20```"D````#````*````$H````I
M`````P```"@```!+````*0````,````H````3````"D````#````*````$T`
M```I`````P```"@```!.````*0````,````H````3P```"D````#````*```
M`%`````I`````P```"@```!1````*0````,````H````4@```"D````#````
M*````%,````I`````P```"@```!4````*0````,````H````50```"D````#
M````*````%8````I`````P```"@```!7````*0````,````H````6````"D`
M```#````*````%D````I`````P```"@```!:````*0````,````H````80``
M`"D````#````*````&(````I`````P```"@```!C````*0````,````H````
M9````"D````#````*````&4````I`````P```"@```!F````*0````,````H
M````9P```"D````#````*````&@````I`````P```"@```!I````*0````,`
M```H````:@```"D````#````*````&L````I`````P```"@```!L````*0``
M``,````H````;0```"D````#````*````&X````I`````P```"@```!O````
M*0````,````H````<````"D````#````*````'$````I`````P```"@```!R
M````*0````,````H````<P```"D````#````*````'0````I`````P```"@`
M``!U````*0````,````H````=@```"D````#````*````'<````I`````P``
M`"@```!X````*0````,````H````>0```"D````#````*````'H````I````
M`P```"@````P````*0````$````M`````0```'P````!````*P````$````K
M`````0```"L````!````*P````$````K`````0```"L````!````*P````$`
M```K`````0```"L````!````;P````0````K(@``*R(``"LB```K(@```P``
M`#H````Z````/0````(````]````/0````,````]````/0```#T````!````
MS6L```$```"?GP```0````!.```!````*$X```$````V3@```0```#].```!
M````64X```$```"%3@```0```(Q.```!````H$X```$```"Z3@```0```#]1
M```!````95$```$```!K40```0```()1```!````EE$```$```"K40```0``
M`.!1```!````]5$```$`````4@```0```)M2```!````^5(```$````54P``
M`0```!I3```!````.%,```$```!!4P```0```%Q3```!````:5,```$```""
M4P```0```+93```!````R%,```$```#C4P```0```-=6```!````'U<```$`
M``#K6````0````)9```!````"ED```$````560```0```"=9```!````<UD`
M``$```!06P```0```(!;```!````^%L```$````/7````0```")<```!````
M.%P```$```!N7````0```'%<```!````VUT```$```#E70```0```/%=```!
M````_ET```$```!R7@```0```'I>```!````?UX```$```#T7@```0```/Y>
M```!````"U\```$````37P```0```%!?```!````85\```$```!S7P```0``
M`,-?```!````"&(```$````V8@```0```$MB```!````+V4```$````T90``
M`0```(=E```!````EV4```$```"D90```0```+EE```!````X&4```$```#E
M90```0```/!F```!````"&<```$````H9P```0```"!K```!````8FL```$`
M``!Y:P```0```+-K```!````RVL```$```#4:P```0```-MK```!````#VP`
M``$````4;````0```#1L```!````:W````$````J<@```0```#9R```!````
M.W(```$````_<@```0```$=R```!````67(```$```!;<@```0```*QR```!
M````A',```$```")<P```0```-QT```!````YG0```$````8=0```0```!]U
M```!````*'4```$````P=0```0```(MU```!````DG4```$```!V=@```0``
M`'UV```!````KG8```$```"_=@```0```.YV```!````VW<```$```#B=P``
M`0```/-W```!````.GD```$```"X>0```0```+YY```!````='H```$```#+
M>@```0```/EZ```!````<WP```$```#X?````0```#9_```!````47\```$`
M``"*?P```0```+U_```!`````8````$````,@````0```!*````!````,X``
M``$```!_@````0```(F````!````XX$```$```#J@0```0```/.!```!````
M_($```$````,@@```0```!N"```!````'X(```$```!N@@```0```'*"```!
M````>((```$```!-A@```0```&N&```!````0(@```$```!,B````0```&.(
M```!````?HD```$```"+B0```0```-*)```!`````(H```$````WC````0``
M`$:,```!````58P```$```!XC````0```)V,```!````9(T```$```!PC0``
M`0```+.-```!````JXX```$```#*C@```0```)N/```!````L(\```$```"U
MCP```0```)&0```!````29$```$```#&D0```0```,R1```!````T9$```$`
M``!WE0```0```("5```!````')8```$```"VE@```0```+F6```!````Z)8`
M``$```!1EP```0```%Z7```!````8I<```$```!IEP```0```,N7```!````
M[9<```$```#SEP```0````&8```!````J)@```$```#;F````0```-^8```!
M````EID```$```"9F0```0```*R9```!````J)H```$```#8F@```0```-^:
M```!````)9L```$````OFP```0```#*;```!````/)L```$```!:FP```0``
M`.6<```!````=9X```$```!_G@```0```*6>```!````NYX```$```##G@``
M`0```,V>```!````T9X```$```#YG@```0```/V>```!````#I\```$````3
MGP```0```""?```!````.Y\```$```!*GP```0```%*?```!````C9\```$`
M``"<GP```0```*"?```!````(`````$````2,````0```$%3```!````1%,`
M``$```!%4P```0```$(P```!````1#````$```!&,````0```$@P```!````
M2C````$```!D,````0```(0P```!````AC````$```"(,````0```(\P```!
M````2S````$```!1,````@```"````"9,````@```"````":,````0```#T`
M```!````HC````$```"D,````0```*8P```!````J#````$```"J,````0``
M`,0P```!````Y#````$```#F,````0```.@P```!````[S````$```"K,```
M`0```+$P```!`````!$```$````!$0```0```*H1```!`````A$```$```"L
M$0```0```*T1```!`````Q$```$````$$0```0````41```!````L!$```$`
M``"Q$0```0```+(1```!````LQ$```$```"T$0```0```+41```!````&A$`
M``$````&$0```0````<1```!````"!$```$````A$0```0````D1```!````
M"A$```$````+$0```0````P1```!````#1$```$````.$0```0````\1```!
M````$!$```$````1$0```0```!(1```!````81$```$```!B$0```0```&,1
M```!````9!$```$```!E$0```0```&81```!````9Q$```$```!H$0```0``
M`&D1```!````:A$```$```!K$0```0```&P1```!````;1$```$```!N$0``
M`0```&\1```!````<!$```$```!Q$0```0```'(1```!````<Q$```$```!T
M$0```0```'41```!````8!$```$````4$0```0```!41```!````QQ$```$`
M``#($0```0```,P1```!````SA$```$```#3$0```0```-<1```!````V1$`
M``$````<$0```0```-T1```!````WQ$```$````=$0```0```!X1```!````
M(!$```$````B$0```0```",1```!````)Q$```$````I$0```0```"L1```!
M````+!$```$````M$0```0```"X1```!````+Q$```$````R$0```0```#81
M```!````0!$```$```!'$0```0```$P1```!````\1$```$```#R$0```0``
M`%<1```!````6!$```$```!9$0```0```(01```!````A1$```$```"($0``
M`0```)$1```!````DA$```$```"4$0```0```)X1```!````H1$```$```"O
M,````0```+<P```!````N3````$```#(,````0```,PP```!````SS````$`
M``#2,````0```-4P```!````V#````$```#;,````0```.`P```!````Z3``
M``$```#J,````0```.LP```!````[#````$```#M,````P```"@`````$0``
M*0````,````H`````A$``"D````#````*`````,1```I`````P```"@````%
M$0``*0````,````H````!A$``"D````#````*`````<1```I`````P```"@`
M```)$0``*0````,````H````"Q$``"D````#````*`````P1```I`````P``
M`"@````.$0``*0````,````H````#Q$``"D````#````*````!`1```I````
M`P```"@````1$0``*0````,````H````$A$``"D````$````*``````1``!A
M$0``*0````0````H`````A$``&$1```I````!````"@````#$0``81$``"D`
M```$````*`````41``!A$0``*0````0````H````!A$``&$1```I````!```
M`"@````'$0``81$``"D````$````*`````D1``!A$0``*0````0````H````
M"Q$``&$1```I````!````"@````,$0``81$``"D````$````*`````X1``!A
M$0``*0````0````H````#Q$``&$1```I````!````"@````0$0``81$``"D`
M```$````*````!$1``!A$0``*0````0````H````$A$``&$1```I````!```
M`"@````,$0``;A$``"D````'````*`````L1``!I$0``#!$``&41``"K$0``
M*0````8````H````"Q$``&D1```2$0``;A$``"D````#````*`````!.```I
M`````P```"@```",3@``*0````,````H````"4X``"D````#````*````-M6
M```I`````P```"@```"43@``*0````,````H````;5$``"D````#````*```
M``-.```I`````P```"@```!K40``*0````,````H````74X``"D````#````
M*````$%3```I`````P```"@````(9P``*0````,````H````:W```"D````#
M````*````#1L```I`````P```"@````H9P``*0````,````H````T9$``"D`
M```#````*````!]7```I`````P```"@```#E90``*0````,````H````*F@`
M`"D````#````*`````EG```I`````P```"@````^>0``*0````,````H````
M#50``"D````#````*````'ER```I`````P```"@```"AC```*0````,````H
M````77D``"D````#````*````+12```I`````P```"@```#C3@``*0````,`
M```H````?%0``"D````#````*````&9;```I`````P```"@```#C=@``*0``
M``,````H`````4\``"D````#````*````,>,```I`````P```"@```!44P``
M*0````,````H````;7D``"D````#````*````!%/```I`````P```"@```#J
M@0``*0````,````H````\X$``"D````#````4````%0```!%````!````"@`
M```R````,0```"D````$````*````#(````R````*0````0````H````,@``
M`#,````I````!````"@````R````-````"D````$````*````#(````U````
M*0````0````H````,@```#8````I````!````"@````R````-P```"D````$
M````*````#(````X````*0````0````H````,@```#D````I````!````"@`
M```S````,````"D````$````*````#,````Q````*0````0````H````,P``
M`#(````I````!````"@````S````,P```"D````$````*````#,````T````
M*0````0````H````,P```#4````I`````P```"@`````$0``*0````,````H
M`````A$``"D````#````*`````,1```I`````P```"@````%$0``*0````,`
M```H````!A$``"D````#````*`````<1```I`````P```"@````)$0``*0``
M``,````H````"Q$``"D````#````*`````P1```I`````P```"@````.$0``
M*0````,````H````#Q$``"D````#````*````!`1```I`````P```"@````1
M$0``*0````,````H````$A$``"D````$````*``````1``!A$0``*0````0`
M```H`````A$``&$1```I````!````"@````#$0``81$``"D````$````*```
M``41``!A$0``*0````0````H````!A$``&$1```I````!````"@````'$0``
M81$``"D````$````*`````D1``!A$0``*0````0````H````"Q$``&$1```I
M````!````"@````,$0``81$``"D````$````*`````X1``!A$0``*0````0`
M```H````#Q$``&$1```I````!````"@````0$0``81$``"D````$````*```
M`!$1``!A$0``*0````0````H````$A$``&$1```I````!P```"@````.$0``
M81$``+<1````$0``:1$``"D````&````*`````P1``!N$0``"Q$``'01```I
M`````P```"@`````3@``*0````,````H````C$X``"D````#````*`````E.
M```I`````P```"@```#;5@``*0````,````H````E$X``"D````#````*```
M`&U1```I`````P```"@````#3@``*0````,````H````:U$``"D````#````
M*````%U.```I`````P```"@```!!4P``*0````,````H````"&<``"D````#
M````*````&MP```I`````P```"@````T;```*0````,````H````*&<``"D`
M```#````*````-&1```I`````P```"@````?5P``*0````,````H````Y64`
M`"D````#````*````"IH```I`````P```"@````)9P``*0````,````H````
M/GD``"D````#````*`````U4```I`````P```"@```!Y<@``*0````,````H
M````H8P``"D````#````*````%UY```I`````P```"@```"T4@``*0````,`
M```H````V'D``"D````#````*````#=U```I`````P```"@```!S60``*0``
M``,````H````:9```"D````#````*````"I1```I`````P```"@```!P4P``
M*0````,````H````Z&P``"D````#````*`````68```I`````P```"@````1
M3P``*0````,````H````F5$``"D````#````*````&-K```I`````P```"@`
M```*3@``*0````,````H````+4X``"D````#````*`````M.```I`````P``
M`"@```#F70``*0````,````H````\U,``"D````#````*````#M3```I````
M`P```"@```"76P``*0````,````H````9EL``"D````#````*````.-V```I
M`````P```"@````!3P``*0````,````H````QXP``"D````#````*````%13
M```I`````P```"@````<60``*0````0````H````,P```#8````I````!```
M`"@````S````-P```"D````$````*````#,````X````*0````0````H````
M,P```#D````I````!````"@````T````,````"D````$````*````#0````Q
M````*0````0````H````-````#(````I````!````"@````T````,P```"D`
M```$````*````#0````T````*0````0````H````-````#4````I````!```
M`"@````T````-@```"D````$````*````#0````W````*0````0````H````
M-````#@````I````!````"@````T````.0```"D````$````*````#4````P
M````*0````(````Q````"&<```(````R````"&<```(````S````"&<```(`
M```T````"&<```(````U````"&<```(````V````"&<```(````W````"&<`
M``(````X````"&<```(````Y````"&<```,````Q````,`````AG```#````
M,0```#$````(9P```P```#$````R````"&<```(```!(````9P````,```!E
M````<@```&<````"````90```%8````#````3````%0```!$`````P```"@`
M``"B,```*0````,````H````I#```"D````#````*````*8P```I`````P``
M`"@```"H,```*0````,````H````JC```"D````#````*````*LP```I````
M`P```"@```"M,```*0````,````H````KS```"D````#````*````+$P```I
M`````P```"@```"S,```*0````,````H````M3```"D````#````*````+<P
M```I`````P```"@```"Y,```*0````,````H````NS```"D````#````*```
M`+TP```I`````P```"@```"_,```*0````,````H````P3```"D````#````
M*````,0P```I`````P```"@```#&,```*0````,````H````R#```"D````#
M````*````,HP```I`````P```"@```#+,```*0````,````H````S#```"D`
M```#````*````,TP```I`````P```"@```#.,```*0````,````H````SS``
M`"D````#````*````-(P```I`````P```"@```#5,```*0````,````H````
MV#```"D````#````*````-LP```I`````P```"@```#>,```*0````,````H
M````WS```"D````#````*````.`P```I`````P```"@```#A,```*0````,`
M```H````XC```"D````#````*````.0P```I`````P```"@```#F,```*0``
M``,````H````Z#```"D````#````*````.DP```I`````P```"@```#J,```
M*0````,````H````ZS```"D````#````*````.PP```I`````P```"@```#M
M,```*0````,````H````[S```"D````#````*````/`P```I`````P```"@`
M``#Q,```*0````,````H````\C```"D````$````HC```-$P``#\,```R#``
M``0```"B,```ZS```-4P``"A,```!````*(P``#S,```VC```*(P```#````
MHC```/PP``#K,```!````*0P``#+,```\S```+`P```#````I#```/,P``#!
M,````P```*8P``"I,```\S````4```"H,```N3```*\P``#\,```R3````0`
M``"H,```_#```*LP``#\,````P```*HP``#S,```N3````,```"J,```_#``
M`.`P```#````JS```*0P``#J,```!````*LP``#I,```PS```,@P```$````
MJS```.TP``#J,```_#````,```"L,```[3```/,P```#````K#```/,P``#>
M,````@```*XP``"L,````P```*XP``#+,```_#````0```"M,```Y3```.HP
M``#\,```!````*XP``#K,```P#```/PP```"````K3```.TP```%````K3``
M`.TP``"P,```Z3```.`P```&````K3```.TP``#A,```_#```,@P``#K,```
M!0```*TP``#M,```[S```,,P``#(,````P```+`P``#I,```X#````4```"P
M,```Z3```.`P``#(,```\S````4```"O,```ZS```+PP``"D,```[3````0`
M``"O,```[3```/PP``#-,````P```+$P``#\,```N3````,```"S,```ZS``
M`,HP```#````LS```/PP``#=,```!````+4P``"D,```KS```.LP```%````
MM3```/,P``#!,```_#```.`P```$````MS```.HP``#S,```L#````,```"[
M,```\S```,$P```#````NS```/,P``#(,````P```,`P``#\,```N3````(`
M``#',```MS````(```#),```ZS````(```#(,```\S````(```#*,```SC``
M``,```#.,```PS```,@P```#````SS```*0P``#$,```!0```-$P``#\,```
MNS```/,P``#(,````P```-$P``#\,```Q#````0```#0,```_#```.PP``#K
M,```!0```-0P``"B,```N3```,@P``#K,````P```-0P``"O,```ZS````(`
M``#4,```LS````(```#3,```ZS````4```#5,```H3```.DP``##,```R3``
M``0```#5,```HS```/PP``#(,```!0```-8P``##,```MS```*<P``#K,```
M`P```-4P``#I,```\S````4```#8,```KS```+\P``#\,```ZS````(```#:
M,```O3````,```#:,```RS```-(P```#````V#```.LP``#$,````P```-HP
M``#S,```N3````,```#:,```_#```+@P```#````V3```/PP``"_,```!```
M`-TP``"D,```\S```,@P```#````W#```.LP``#(,````@```-LP``#S,```
M`P```-TP``#S,```R3````,```#;,```_#```.LP```#````VS```/PP``#S
M,```!````-XP``"D,```KS```.TP```#````WC```*0P``#K,````P```-XP
M``##,```SS````,```#>,```ZS```*\P```%````WC```/,P``"W,```YS``
M`/,P```$````WS```*\P``#M,```\S````(```#?,```ZC````4```#?,```
MZC```-`P``#\,```ZS````(```#A,```K#````0```#A,```K#```,@P``#S
M,```!````.$P``#\,```R#```.LP```#````Y#```/PP``#),````P```.0P
M``#\,```ZS````,```#F,```HC```/,P```$````ZC```,,P``#(,```ZS``
M``(```#J,```Z3````,```#K,```U#```/PP```$````ZS```/PP``#6,```
MZS````(```#L,```X#````4```#L,```\S```,@P``"R,```\S````,```#O
M,```PS```,@P```"````,````+EP```"````,0```+EP```"````,@```+EP
M```"````,P```+EP```"````-````+EP```"````-0```+EP```"````-@``
M`+EP```"````-P```+EP```"````.````+EP```"````.0```+EP```#````
M,0```#````"Y<````P```#$````Q````N7````,````Q````,@```+EP```#
M````,0```#,```"Y<````P```#$````T````N7````,````Q````-0```+EP
M```#````,0```#8```"Y<````P```#$````W````N7````,````Q````.```
M`+EP```#````,0```#D```"Y<````P```#(````P````N7````,````R````
M,0```+EP```#````,@```#(```"Y<````P```#(````S````N7````,````R
M````-````+EP```#````:````%````!A`````@```&0```!A`````@```$$`
M``!5`````P```&(```!A````<@````(```!O````5@````(```!P````8P``
M``(```!D````;0````0```!D````;0```%X````R````!````&0```!M````
M7@```#,````"````20```%4````"````<UX``!!B```"````+68``(Q4```"
M````)UD``&-K```"````#F8``+ML```$````*F@```]?```:3P``/GD```(`
M``!P````00````(```!N````00````(```"\`P``00````(```!M````00``
M``(```!K````00````(```!+````0@````(```!-````0@````(```!'````
M0@````,```!C````80```&P````$````:P```&,```!A````;`````(```!P
M````1@````(```!N````1@````(```"\`P``1@````(```"\`P``9P````(`
M``!M````9P````(```!K````9P````(```!(````>@````,```!K````2```
M`'H````#````30```$@```!Z`````P```$<```!(````>@````,```!4````
M2````'H````"````O`,``&P````"````;0```&P````"````9````&P````"
M````:P```&P````"````9@```&T````"````;@```&T````"````O`,``&T`
M```"````;0```&T````"````8P```&T````"````:P```&T````$````;0``
M`&T```!>````,@````0```!C````;0```%X````R`````P```&T```!>````
M,@````0```!K````;0```%X````R````!````&T```!M````7@```#,````$
M````8P```&T```!>````,P````,```!M````7@```#,````$````:P```&T`
M``!>````,P````,```!M````+P```',````%````;0```"\```!S````7@``
M`#(````"````4````&$````#````:P```%````!A`````P```$T```!0````
M80````,```!'````4````&$````#````<@```&$```!D````!0```'(```!A
M````9````"\```!S````!P```'(```!A````9````"\```!S````7@```#(`
M```"````<````',````"````;@```',````"````O`,``',````"````;0``
M`',````"````<````%8````"````;@```%8````"````O`,``%8````"````
M;0```%8````"````:P```%8````"````30```%8````"````<````%<````"
M````;@```%<````"````O`,``%<````"````;0```%<````"````:P```%<`
M```"````30```%<````"````:P```*D#```"````30```*D#```$````80``
M`"X```!M````+@````(```!"````<0````(```!C````8P````(```!C````
M9`````0```!#````+P```&L```!G`````P```$,```!O````+@````(```!D
M````0@````(```!'````>0````(```!H````80````(```!(````4`````(`
M``!I````;@````(```!+````2P````(```!+````30````(```!K````=```
M``(```!L````;0````(```!L````;@````,```!L````;P```&<````"````
M;````'@````"````;0```&(````#````;0```&D```!L`````P```&T```!O
M````;`````(```!0````2`````0```!P````+@```&T````N`````P```%``
M``!0````30````(```!0````4@````(```!S````<@````(```!3````=@``
M``(```!7````8@````,```!6````+P```&T````#````00```"\```!M````
M`P```&<```!A````;`````(````Q````Y64```(````R````Y64```(````S
M````Y64```(````T````Y64```(````U````Y64```(````V````Y64```(`
M```W````Y64```(````X````Y64```(````Y````Y64```,````Q````,```
M`.5E```#````,0```#$```#E90```P```#$````R````Y64```,````Q````
M,P```.5E```#````,0```#0```#E90```P```#$````U````Y64```,````Q
M````-@```.5E```#````,0```#<```#E90```P```#$````X````Y64```,`
M```Q````.0```.5E```#````,@```#````#E90```P```#(````Q````Y64`
M``,````R````,@```.5E```#````,@```#,```#E90```P```#(````T````
MY64```,````R````-0```.5E```#````,@```#8```#E90```P```#(````W
M````Y64```,````R````.````.5E```#````,@```#D```#E90```P```#,`
M```P````Y64```,````S````,0```.5E```!````2(P```$```#T9@```0``
M`,J.```!````R(P```$```#1;@```0```#).```!````Y5,```$```"<GP``
M`0```)R?```!````45D```$```#1D0```0```(=5```!````2%D```$```#V
M80```0```&EV```!````A7\```$````_A@```0```+J'```!````^(@```$`
M``"/D````0````)J```!````&VT```$```#9<````0```-YS```!````/80`
M``$```!JD0```0```/&9```!````@DX```$```!U4P```0````1K```!````
M&W(```$````MA@```0```!Z>```!````4%T```$```#K;P```0```,V%```!
M````9(D```$```#)8@```0```-B!```!````'X@```$```#*7@```0```!=G
M```!````:FT```$```#\<@```0```,Z0```!````AD\```$```"W40```0``
M`-Y2```!````Q&0```$```#3:@```0```!!R```!````YW8```$````!@```
M`0````:&```!````7(8```$```#OC0```0```#*7```!````;YL```$```#Z
MG0```0```(QX```!````?WD```$```"@?0```0```,F#```!````!),```$`
M``!_G@```0```-:*```!````WU@```$````$7P```0```&!\```!````?H``
M``$```!B<@```0```,IX```!````PHP```$```#WE@```0```-A8```!````
M8EP```$````3:@```0```-IM```!````#V\```$````O?0```0```#=^```!
M````2Y8```$```#24@```0```(N````!````W%$```$```#,40```0```!QZ
M```!````OGT```$```#Q@P```0```'66```!````@(L```$```#/8@```0``
M``)J```!````_HH```$````Y3@```0```.=;```!````$F````$```"'<P``
M`0```'!U```!````%U,```$```#[>````0```+]/```!````J5\```$````-
M3@```0```,QL```!````>&4```$````B?0```0```,-3```!````7E@```$`
M```!=P```0```$F$```!````JHH```$```"Z:P```0```+"/```!````B&P`
M``$```#^8@```0```.6"```!````H&,```$```!E=0```0```*Y.```!````
M:5$```$```#)40```0```(%H```!````YWP```$```!O@@```0```-**```!
M````SY$```$```#U4@```0```$)4```!````<UD```$```#L7@```0```,5E
M```!````_F\```$````J>0```0```*V5```!````:IH```$```"7G@```0``
M`,Z>```!````FU(```$```#&9@```0```'=K```!````8H\```$```!T7@``
M`0```)!A```!`````&(```$```":9````0```"-O```!````27$```$```")
M=````0```,IY```!````]'T```$```!O@````0```":/```!````[H0```$`
M```CD````0```$J3```!````%U(```$```"C4@```0```+U4```!````R'``
M``$```#"B````0```*J*```!````R5X```$```#U7P```0```'MC```!````
MKFL```$````^?````0```'5S```!````Y$X```$```#Y5@```0```.=;```!
M````NET```$````<8````0```+)S```!````:70```$```":?P```0```$:`
M```!````-)(```$```#VE@```0```$B7```!````&)@```$```"+3P```0``
M`*YY```!````M)$```$```"XE@```0```.%@```!````ADX```$```#:4```
M`0```.Y;```!````/UP```$```"990```0````)J```!````SG$```$```!"
M=@```0```/R$```!````?)````$```"-GP```0```(AF```!````+I8```$`
M``")4@```0```'MG```!````\V<```$```!!;0```0```)QN```!````"70`
M``$```!9=0```0```&MX```!````$'T```$```!>F````0```&U1```!````
M+F(```$```!XE@```0```"M0```!````&5T```$```#J;0```0```"J/```!
M````BU\```$```!$80```0```!=H```!````AW,```$```"&E@```0```"E2
M```!````#U0```$```!E7````0```!-F```!````3F<```$```"H:````0``
M`.5L```!````!G0```$```#B=0```0```'E_```!````SX@```$```#AB```
M`0```,R1```!````XI8```$````_4P```0```+IN```!````'50```$```#0
M<0```0```)AT```!````^H4```$```"CE@```0```%><```!````GYX```$`
M``"79P```0```,MM```!````Z($```$```#+>@```0```"![```!````DGP`
M``$```#`<@```0```)EP```!````6(L```$```#`3@```0```#:#```!````
M.E(```$````'4@```0```*9>```!````TV(```$```#6?````0```(5;```!
M````'FT```$```"T9@```0```#N/```!````3(@```$```!-E@```0```(N)
M```!````TUX```$```!`40```0```,!5```!````6E@```$```!T9@```0``
M`-Y1```!````*G,```$```#*=@```0```#QY```!````7GD```$```!E>0``
M`0```(]Y```!````5I<```$```"^?````0```+U_```!````$H8```$```#X
MB@```0```#B0```!````_9````$```#OF````0```/R8```!````*)D```$`
M``"TG0```0```*Y/```!````YU````$```!-40```0```,E2```!````Y%(`
M``$```!14P```0```)U5```!````!E8```$```!H5@```0```$!8```!````
MJ%@```$```!D7````0```&Y<```!````E&````$```!H80```0```(YA```!
M````\F$```$```!/90```0```.)E```!````D68```$```"%:````0```'=M
M```!````&FX```$````B;P```0```&YQ```!````*W(```$````B=````0``
M`)%X```!````/GD```$```!)>0```0```$AY```!````4'D```$```!6>0``
M`0```%UY```!````C7D```$```".>0```0```$!Z```!````@7H```$```#`
M>P```0```/1]```!````"7X```$```!!?@```0```')_```!````!8````$`
M``#M@0```0```'F"```!````>8(```$```!7A````0```!")```!````EHD`
M``$````!BP```0```#F+```!````TXP```$````(C0```0```+:/```!````
M.)````$```#CE@```0```/^7```!````.Y@```(```!F````9@````(```!F
M````:0````(```!F````;`````,```!F````9@```&D````#````9@```&8`
M``!L`````@```'\!``!T`````@```',```!T`````@```'0%``!V!0```@``
M`'0%``!E!0```@```'0%``!K!0```@```'X%``!V!0```@```'0%``!M!0``
M`0```.(%```!````T`4```$```#3!0```0```-0%```!````VP4```$```#<
M!0```0```-T%```!````Z`4```$```#J!0```0```"L````"````T`4``-P%
M```!````/B````$````^(````0```#X@```!````/B````$```!?`````0``
M`%\````!````7P````$````L`````0````$P```!````+@````$````[````
M`0```#H````!````/P````$````A`````0```!0@```!````*`````$````I
M`````0```'L````!````?0````$````4,````0```!4P```!````(P````$`
M```F`````0```"H````!````*P````$````M`````0```#P````!````/@``
M``$````]`````0```%P````!````)`````$````E`````0```$`````!````
M(0````$````B`````0```",````!````)`````$````E`````0```"8````!
M````)P````$````H`````0```"D````!````*@````$````K`````0```"P`
M```!````+0````$````N`````0```"\````!````,`````$````Q`````0``
M`#(````!````,P````$````T`````0```#4````!````-@````$````W````
M`0```#@````!````.0````$````Z`````0```#L````!````/`````$````]
M`````0```#X````!````/P````$```!``````0```$$````!````0@````$`
M``!#`````0```$0````!````10````$```!&`````0```$<````!````2```
M``$```!)`````0```$H````!````2P````$```!,`````0```$T````!````
M3@````$```!/`````0```%`````!````40````$```!2`````0```%,````!
M````5`````$```!5`````0```%8````!````5P````$```!8`````0```%D`
M```!````6@````$```!;`````0```%P````!````70````$```!>`````0``
M`%\````!````8`````$```!A`````0```&(````!````8P````$```!D````
M`0```&4````!````9@````$```!G`````0```&@````!````:0````$```!J
M`````0```&L````!````;`````$```!M`````0```&X````!````;P````$`
M``!P`````0```'$````!````<@````$```!S`````0```'0````!````=0``
M``$```!V`````0```'<````!````>`````$```!Y`````0```'H````!````
M>P````$```!\`````0```'T````!````?@````$```"%*0```0```(8I```!
M`````C````$````,,````0````TP```!`````3````$```#[,````0```/(P
M```!````H3````$```"C,````0```*4P```!````IS````$```"I,````0``
M`.,P```!````Y3````$```#G,````0```,,P```!````_#````$```"B,```
M`0```*0P```!````IC````$```"H,````0```*HP```!````JS````$```"M
M,````0```*\P```!````L3````$```"S,````0```+4P```!````MS````$`
M``"Y,````0```+LP```!````O3````$```"_,````0```,$P```!````Q#``
M``$```#&,````0```,@P```!````RC````$```#+,````0```,PP```!````
MS3````$```#.,````0```,\P```!````TC````$```#5,````0```-@P```!
M````VS````$```#>,````0```-\P```!````X#````$```#A,````0```.(P
M```!````Y#````$```#F,````0```.@P```!````Z3````$```#J,````0``
M`.LP```!````[#````$```#M,````0```.\P```!````\S````$```"9,```
M`0```)HP```!````9#$```$````Q,0```0```#(Q```!````,S$```$````T
M,0```0```#4Q```!````-C$```$````W,0```0```#@Q```!````.3$```$`
M```Z,0```0```#LQ```!````/#$```$````],0```0```#XQ```!````/S$`
M``$```!`,0```0```$$Q```!````0C$```$```!#,0```0```$0Q```!````
M13$```$```!&,0```0```$<Q```!````2#$```$```!),0```0```$HQ```!
M````2S$```$```!,,0```0```$TQ```!````3C$```$```!/,0```0```%`Q
M```!````43$```$```!2,0```0```%,Q```!````5#$```$```!5,0```0``
M`%8Q```!````5S$```$```!8,0```0```%DQ```!````6C$```$```!;,0``
M`0```%PQ```!````73$```$```!>,0```0```%\Q```!````8#$```$```!A
M,0```0```&(Q```!````8S$```$```"B`````0```*,````!````K`````$`
M``"O`````0```*8````!````I0````$```"I(````0````(E```!````D"$`
M``$```"1(0```0```)(A```!````DR$```$```"@)0```0```,LE```!````
M00````$```!"`````0```$,````!````1`````$```!%`````0```$8````!
M````1P````$```!(`````0```$D````!````2@````$```!+`````0```$P`
M```!````30````$```!.`````0```$\````!````4`````$```!1`````0``
M`%(````!````4P````$```!4`````0```%4````!````5@````$```!7````
M`0```%@````!````60````$```!:`````0```&$````!````8@````$```!C
M`````0```&0````!````90````$```!F`````0```&<````!````:`````$`
M``!I`````0```&H````!````:P````$```!L`````0```&T````!````;@``
M``$```!O`````0```'`````!````<0````$```!R`````0```',````!````
M=`````$```!U`````0```'8````!````=P````$```!X`````0```'D````!
M````>@````$```!!`````0```$(````!````0P````$```!$`````0```$4`
M```!````1@````$```!'`````0```$@````!````20````$```!*`````0``
M`$L````!````3`````$```!-`````0```$X````!````3P````$```!0````
M`0```%$````!````4@````$```!3`````0```%0````!````50````$```!6
M`````0```%<````!````6`````$```!9`````0```%H````!````80````$`
M``!B`````0```&,````!````9`````$```!E`````0```&8````!````9P``
M``$```!I`````0```&H````!````:P````$```!L`````0```&T````!````
M;@````$```!O`````0```'`````!````<0````$```!R`````0```',````!
M````=`````$```!U`````0```'8````!````=P````$```!X`````0```'D`
M```!````>@````$```!!`````0```$(````!````0P````$```!$`````0``
M`$4````!````1@````$```!'`````0```$@````!````20````$```!*````
M`0```$L````!````3`````$```!-`````0```$X````!````3P````$```!0
M`````0```%$````!````4@````$```!3`````0```%0````!````50````$`
M``!6`````0```%<````!````6`````$```!9`````0```%H````!````80``
M``$```!B`````0```&,````!````9`````$```!E`````0```&8````!````
M9P````$```!H`````0```&D````!````:@````$```!K`````0```&P````!
M````;0````$```!N`````0```&\````!````<`````$```!Q`````0```'(`
M```!````<P````$```!T`````0```'4````!````=@````$```!W`````0``
M`'@````!````>0````$```!Z`````0```$$````!````0P````$```!$````
M`0```$<````!````2@````$```!+`````0```$X````!````3P````$```!0
M`````0```%$````!````4P````$```!4`````0```%4````!````5@````$`
M``!7`````0```%@````!````60````$```!:`````0```&$````!````8@``
M``$```!C`````0```&0````!````9@````$```!H`````0```&D````!````
M:@````$```!K`````0```&P````!````;0````$```!N`````0```'`````!
M````<0````$```!R`````0```',````!````=`````$```!U`````0```'8`
M```!````=P````$```!X`````0```'D````!````>@````$```!!`````0``
M`$(````!````0P````$```!$`````0```$4````!````1@````$```!'````
M`0```$@````!````20````$```!*`````0```$L````!````3`````$```!-
M`````0```$X````!````3P````$```!0`````0```%$````!````4@````$`
M``!3`````0```%0````!````50````$```!6`````0```%<````!````6```
M``$```!9`````0```%H````!````80````$```!B`````0```&,````!````
M9`````$```!E`````0```&8````!````9P````$```!H`````0```&D````!
M````:@````$```!K`````0```&P````!````;0````$```!N`````0```&\`
M```!````<`````$```!Q`````0```'(````!````<P````$```!T`````0``
M`'4````!````=@````$```!W`````0```'@````!````>0````$```!Z````
M`0```$$````!````0@````$```!$`````0```$4````!````1@````$```!'
M`````0```$H````!````2P````$```!,`````0```$T````!````3@````$`
M``!/`````0```%`````!````40````$```!3`````0```%0````!````50``
M``$```!6`````0```%<````!````6`````$```!9`````0```&$````!````
M8@````$```!C`````0```&0````!````90````$```!F`````0```&<````!
M````:`````$```!I`````0```&H````!````:P````$```!L`````0```&T`
M```!````;@````$```!O`````0```'`````!````<0````$```!R`````0``
M`',````!````=`````$```!U`````0```'8````!````=P````$```!X````
M`0```'D````!````>@````$```!!`````0```$(````!````1`````$```!%
M`````0```$8````!````1P````$```!)`````0```$H````!````2P````$`
M``!,`````0```$T````!````3P````$```!3`````0```%0````!````50``
M``$```!6`````0```%<````!````6`````$```!9`````0```&$````!````
M8@````$```!C`````0```&0````!````90````$```!F`````0```&<````!
M````:`````$```!I`````0```&H````!````:P````$```!L`````0```&T`
M```!````;@````$```!O`````0```'`````!````<0````$```!R`````0``
M`',````!````=`````$```!U`````0```'8````!````=P````$```!X````
M`0```'D````!````>@````$```!!`````0```$(````!````0P````$```!$
M`````0```$4````!````1@````$```!'`````0```$@````!````20````$`
M``!*`````0```$L````!````3`````$```!-`````0```$X````!````3P``
M``$```!0`````0```%$````!````4@````$```!3`````0```%0````!````
M50````$```!6`````0```%<````!````6`````$```!9`````0```%H````!
M````80````$```!B`````0```&,````!````9`````$```!E`````0```&8`
M```!````9P````$```!H`````0```&D````!````:@````$```!K`````0``
M`&P````!````;0````$```!N`````0```&\````!````<`````$```!Q````
M`0```'(````!````<P````$```!T`````0```'4````!````=@````$```!W
M`````0```'@````!````>0````$```!Z`````0```$$````!````0@````$`
M``!#`````0```$0````!````10````$```!&`````0```$<````!````2```
M``$```!)`````0```$H````!````2P````$```!,`````0```$T````!````
M3@````$```!/`````0```%`````!````40````$```!2`````0```%,````!
M````5`````$```!5`````0```%8````!````5P````$```!8`````0```%D`
M```!````6@````$```!A`````0```&(````!````8P````$```!D`````0``
M`&4````!````9@````$```!G`````0```&@````!````:0````$```!J````
M`0```&L````!````;`````$```!M`````0```&X````!````;P````$```!P
M`````0```'$````!````<@````$```!S`````0```'0````!````=0````$`
M``!V`````0```'<````!````>`````$```!Y`````0```'H````!````00``
M``$```!"`````0```$,````!````1`````$```!%`````0```$8````!````
M1P````$```!(`````0```$D````!````2@````$```!+`````0```$P````!
M````30````$```!.`````0```$\````!````4`````$```!1`````0```%(`
M```!````4P````$```!4`````0```%4````!````5@````$```!7`````0``
M`%@````!````60````$```!:`````0```&$````!````8@````$```!C````
M`0```&0````!````90````$```!F`````0```&<````!````:`````$```!I
M`````0```&H````!````:P````$```!L`````0```&T````!````;@````$`
M``!O`````0```'`````!````<0````$```!R`````0```',````!````=```
M``$```!U`````0```'8````!````=P````$```!X`````0```'D````!````
M>@````$```!!`````0```$(````!````0P````$```!$`````0```$4````!
M````1@````$```!'`````0```$@````!````20````$```!*`````0```$L`
M```!````3`````$```!-`````0```$X````!````3P````$```!0`````0``
M`%$````!````4@````$```!3`````0```%0````!````50````$```!6````
M`0```%<````!````6`````$```!9`````0```%H````!````80````$```!B
M`````0```&,````!````9`````$```!E`````0```&8````!````9P````$`
M``!H`````0```&D````!````:@````$```!K`````0```&P````!````;0``
M``$```!N`````0```&\````!````<`````$```!Q`````0```'(````!````
M<P````$```!T`````0```'4````!````=@````$```!W`````0```'@````!
M````>0````$```!Z`````0```$$````!````0@````$```!#`````0```$0`
M```!````10````$```!&`````0```$<````!````2`````$```!)`````0``
M`$H````!````2P````$```!,`````0```$T````!````3@````$```!/````
M`0```%`````!````40````$```!2`````0```%,````!````5`````$```!5
M`````0```%8````!````5P````$```!8`````0```%D````!````6@````$`
M``!A`````0```&(````!````8P````$```!D`````0```&4````!````9@``
M``$```!G`````0```&@````!````:0````$```!J`````0```&L````!````
M;`````$```!M`````0```&X````!````;P````$```!P`````0```'$````!
M````<@````$```!S`````0```'0````!````=0````$```!V`````0```'<`
M```!````>`````$```!Y`````0```'H````!````00````$```!"`````0``
M`$,````!````1`````$```!%`````0```$8````!````1P````$```!(````
M`0```$D````!````2@````$```!+`````0```$P````!````30````$```!.
M`````0```$\````!````4`````$```!1`````0```%(````!````4P````$`
M``!4`````0```%4````!````5@````$```!7`````0```%@````!````60``
M``$```!:`````0```&$````!````8@````$```!C`````0```&0````!````
M90````$```!F`````0```&<````!````:`````$```!I`````0```&H````!
M````:P````$```!L`````0```&T````!````;@````$```!O`````0```'``
M```!````<0````$```!R`````0```',````!````=`````$```!U`````0``
M`'8````!````=P````$```!X`````0```'D````!````>@````$```"1`P``
M`0```)(#```!````DP,```$```"4`P```0```)4#```!````E@,```$```"7
M`P```0```)@#```!````F0,```$```":`P```0```)L#```!````G`,```$`
M``"=`P```0```)X#```!````GP,```$```"@`P```0```*$#```!````]`,`
M``$```"C`P```0```*0#```!````I0,```$```"F`P```0```*<#```!````
MJ`,```$```"I`P```0````<B```!````L0,```$```"R`P```0```+,#```!
M````M`,```$```"U`P```0```+8#```!````MP,```$```"X`P```0```+D#
M```!````N@,```$```"[`P```0```+P#```!````O0,```$```"^`P```0``
M`+\#```!````P`,```$```#!`P```0```,(#```!````PP,```$```#$`P``
M`0```,4#```!````Q@,```$```#'`P```0```,@#```!````R0,```$````"
M(@```0```/4#```!````T0,```$```#P`P```0```-4#```!````\0,```$`
M``#6`P```0```)$#```!````D@,```$```"3`P```0```)0#```!````E0,`
M``$```"6`P```0```)<#```!````F`,```$```"9`P```0```)H#```!````
MFP,```$```"<`P```0```)T#```!````G@,```$```"?`P```0```*`#```!
M````H0,```$```#T`P```0```*,#```!````I`,```$```"E`P```0```*8#
M```!````IP,```$```"H`P```0```*D#```!````!R(```$```"Q`P```0``
M`+(#```!````LP,```$```"T`P```0```+4#```!````M@,```$```"W`P``
M`0```+@#```!````N0,```$```"Z`P```0```+L#```!````O`,```$```"]
M`P```0```+X#```!````OP,```$```#``P```0```,$#```!````P@,```$`
M``##`P```0```,0#```!````Q0,```$```#&`P```0```,<#```!````R`,`
M``$```#)`P```0````(B```!````]0,```$```#1`P```0```/`#```!````
MU0,```$```#Q`P```0```-8#```!````D0,```$```"2`P```0```),#```!
M````E`,```$```"5`P```0```)8#```!````EP,```$```"8`P```0```)D#
M```!````F@,```$```";`P```0```)P#```!````G0,```$```">`P```0``
M`)\#```!````H`,```$```"A`P```0```/0#```!````HP,```$```"D`P``
M`0```*4#```!````I@,```$```"G`P```0```*@#```!````J0,```$````'
M(@```0```+$#```!````L@,```$```"S`P```0```+0#```!````M0,```$`
M``"V`P```0```+<#```!````N`,```$```"Y`P```0```+H#```!````NP,`
M``$```"\`P```0```+T#```!````O@,```$```"_`P```0```,`#```!````
MP0,```$```#"`P```0```,,#```!````Q`,```$```#%`P```0```,8#```!
M````QP,```$```#(`P```0```,D#```!`````B(```$```#U`P```0```-$#
M```!````\`,```$```#5`P```0```/$#```!````U@,```$```"1`P```0``
M`)(#```!````DP,```$```"4`P```0```)4#```!````E@,```$```"7`P``
M`0```)@#```!````F0,```$```":`P```0```)L#```!````G`,```$```"=
M`P```0```)X#```!````GP,```$```"@`P```0```*$#```!````]`,```$`
M``"C`P```0```*0#```!````I0,```$```"F`P```0```*<#```!````J`,`
M``$```"I`P```0````<B```!````L0,```$```"R`P```0```+,#```!````
MM`,```$```"U`P```0```+8#```!````MP,```$```"X`P```0```+D#```!
M````N@,```$```"[`P```0```+P#```!````O0,```$```"^`P```0```+\#
M```!````P`,```$```#!`P```0```,(#```!````PP,```$```#$`P```0``
M`,4#```!````Q@,```$```#'`P```0```,@#```!````R0,```$````"(@``
M`0```/4#```!````T0,```$```#P`P```0```-4#```!````\0,```$```#6
M`P```0```)$#```!````D@,```$```"3`P```0```)0#```!````E0,```$`
M``"6`P```0```)<#```!````F`,```$```"9`P```0```)H#```!````FP,`
M``$```"<`P```0```)T#```!````G@,```$```"?`P```0```*`#```!````
MH0,```$```#T`P```0```*,#```!````I`,```$```"E`P```0```*8#```!
M````IP,```$```"H`P```0```*D#```!````!R(```$```"Q`P```0```+(#
M```!````LP,```$```"T`P```0```+4#```!````M@,```$```"W`P```0``
M`+@#```!````N0,```$```"Z`P```0```+L#```!````O`,```$```"]`P``
M`0```+X#```!````OP,```$```#``P```0```,$#```!````P@,```$```##
M`P```0```,0#```!````Q0,```$```#&`P```0```,<#```!````R`,```$`
M``#)`P```0````(B```!````]0,```$```#1`P```0```/`#```!````U0,`
M``$```#Q`P```0```-8#```!````,`````$````Q`````0```#(````!````
M,P````$````T`````0```#4````!````-@````$````W`````0```#@````!
M````.0````$````P`````0```#$````!````,@````$````S`````0```#0`
M```!````-0````$````V`````0```#<````!````.`````$````Y`````0``
M`#`````!````,0````$````R`````0```#,````!````-`````$````U````
M`0```#8````!````-P````$````X`````0```#D````!````,`````$````Q
M`````0```#(````!````,P````$````T`````0```#4````!````-@````$`
M```W`````0```#@````!````.0````$````P`````0```#$````!````,@``
M``$````S`````0```#0````!````-0````$````V`````0```#<````!````
M.`````$````Y`````0```#U.```!````.$X```$```!!3@```0```"(!`@`!
M````8$\```$```"N3P```0```+M/```!`````E````$```!Z4````0```)E0
M```!````YU````$```#/4````0```)XT```!````.@8"``$```!-40```0``
M`%11```!````9%$```$```!W40```0```!P%`@`!````N30```$```!G40``
M`0```(U1```!````2P4"``$```"740```0```*11```!````S$X```$```"L
M40```0```+51```!````WY$"``$```#U40```0````-2```!````WS0```$`
M```[4@```0```$92```!````<E(```$```!W4@```0```!4U```!````QU(`
M``$```#)4@```0```.12```!````^E(```$````%4P```0````93```!````
M%U,```$```!)4P```0```%%3```!````6E,```$```!S4P```0```'U3```!
M````?U,```$```!_4P```0```']3```!````+`H"``$```!P<````0```,I3
M```!````WU,```$```!C"P(``0```.M3```!````\5,```$````&5````0``
M`)Y4```!````.%0```$```!(5````0```&A4```!````HE0```$```#V5```
M`0```!!5```!````4U4```$```!C50```0```(15```!````A%4```$```"9
M50```0```*M5```!````LU4```$```#"50```0```!97```!````!E8```$`
M```75P```0```%%6```!````=%8```$````'4@```0```.Y8```!````SE<`
M``$```#T5P```0````U8```!````BU<```$````R6````0```#%8```!````
MK%@```$```#D%`(``0```/)8```!````]U@```$````&60```0```!I9```!
M````(ED```$```!B60```0```*@6`@`!````ZA8"``$```#L60```0```!M:
M```!````)UH```$```#860```0```&9:```!````[C8```$```#\-@```0``
M``A;```!````/EL```$````^6P```0```,@9`@`!````PUL```$```#86P``
M`0```.=;```!````\UL```$````8&P(``0```/];```!````!EP```$```!3
M7P```0```")<```!````@3<```$```!@7````0```&Y<```!````P%P```$`
M``"-7````0```.0=`@`!````0UT```$```#F'0(``0```&Y=```!````:UT`
M``$```!\70```0```.%=```!````XET```$````O.````0```/U=```!````
M*%X```$````]7@```0```&E>```!````8C@```$```"#(0(``0```'PX```!
M````L%X```$```"S7@```0```+9>```!````REX```$```"2HP(``0```/Y>
M```!````,2,"``$````Q(P(``0````&"```!````(E\```$````B7P```0``
M`,<X```!````N#("``$```#:80(``0```&)?```!````:U\```$```#C.```
M`0```)I?```!````S5\```$```#77P```0```/E?```!````@6````$````Z
M.0```0```!PY```!````E&````$```#4)@(``0```,=@```!````2&$```$`
M``!,80```0```$YA```!````3&$```$```!Z80```0```(YA```!````LF$`
M``$```"D80```0```*]A```!````WF$```$```#R80```0```/9A```!````
M$&(```$````;8@```0```%UB```!````L6(```$```#48@```0```%!C```!
M````#"L"``$````]8P```0```/QB```!````:&,```$```"#8P```0```.1C
M```!````\2L"``$````B9````0```,5C```!````J6,```$````N.@```0``
M`&ED```!````?F0```$```"=9````0```'=D```!````;#H```$```!/90``
M`0```&QE```!````"C`"``$```#C90```0```/AF```!````268```$````9
M.P```0```)%F```!````"#L```$```#D.@```0```))1```!````E5$```$`
M````9P```0```)QF```!````K8````$```#90P```0```!=G```!````&V<`
M``$````A9P```0```%YG```!````4V<```$```##,P(``0```$D[```!````
M^F<```$```"%9P```0```%)H```!````A6@```$```!M-`(``0```(YH```!
M````'V@```$````4:0```0```)T[```!````0FD```$```"C:0```0```.II
M```!````J&H```$```"C-@(``0```-MJ```!````&#P```$````A:P```0``
M`*<X`@`!````5&L```$```!./````0```')K```!````GVL```$```"Z:P``
M`0```+MK```!````C3H"``$````+'0(``0```/HZ`@`!````3FP```$```"\
M/`(``0```+]L```!````S6P```$```!G;````0```!9M```!````/FT```$`
M``!W;0```0```$%M```!````:6T```$```!X;0```0```(5M```!````'CT"
M``$````T;0```0```"]N```!````;FX```$````S/0```0```,MN```!````
MQVX```$```#1/@(``0```/EM```!````;F\```$```!>/P(``0```(X_`@`!
M````QF\```$````Y<````0```!YP```!````&W````$```"6/0```0```$IP
M```!````?7````$```!W<````0```*UP```!````)04"``$```!%<0```0``
M`&-"`@`!````G'$```$```"K0P(``0```"AR```!````-7(```$```!0<@``
M`0````A&`@`!````@'(```$```"5<@```0```#5'`@`!````%$@"``$```!Z
M<P```0```(MS```!````K#X```$```"E<P```0```+@^```!````N#X```$`
M``!'=````0```%QT```!````<70```$```"%=````0```,IT```!````&S\`
M``$````D=0```0```#9,`@`!````/G4```$```"23`(``0```'!U```!````
MGR$"``$````0=@```0```*%/`@`!````N$\"``$```!$4`(``0```/P_```!
M````"$````$```#T=@```0```/-0`@`!````\E`"``$````940(``0```#-1
M`@`!````'G<```$````?=P```0```!]W```!````2G<```$````Y0````0``
M`(MW```!````1D````$```"60````0```!U4`@`!````3G@```$```",>```
M`0```,QX```!````XT````$````F5@(``0```%9Y```!````FE8"``$```#%
M5@(``0```(]Y```!````ZWD```$````O00```0```$!Z```!````2GH```$`
M``!/>@```0```'Q9`@`!````IUH"``$```"G6@(``0```.YZ```!`````D(`
M``$```"K6P(``0```,9[```!````R7L```$````G0@```0```(!<`@`!````
MTGP```$```"@0@```0```.A\```!````XWP```$`````?0```0```(9?`@`!
M````8WT```$````!0P```0```,=]```!`````GX```$```!%?@```0```#1#
M```!````*&("``$```!'8@(``0```%E#```!````V6("``$```!Z?P```0``
M`#YC`@`!````E7\```$```#Z?P```0````6````!````VF0"``$````C90(`
M`0```&"````!````J&4"``$```!P@````0```%\S`@`!````U4,```$```"R
M@````0````.!```!````"T0```$````^@0```0```+5:```!````IV<"``$`
M``"U9P(``0```),S`@`!````G#,"``$````!@@```0````2"```!````GH\`
M``$```!K1````0```)&"```!````BX(```$```"=@@```0```+-2```!````
ML8(```$```"S@@```0```+V"```!````YH(```$````\:P(``0```.6"```!
M````'8,```$```!C@P```0```*V#```!````(X,```$```"]@P```0```.>#
M```!````5X0```$```!3@P```0```,J#```!````S(,```$```#<@P```0``
M`#9L`@`!````:VT"``$```#5;`(``0```"M%```!````\80```$```#SA```
M`0```!:%```!````RG,"``$```!DA0```0```"QO`@`!````744```$```!A
M10```0```+%O`@`!````TG`"``$```!K10```0```%"&```!````7(8```$`
M``!GA@```0```&F&```!````J88```$```"(A@```0````Z'```!````XH8`
M``$```!YAP```0```"B'```!````:X<```$```"&AP```0```-=%```!````
MX8<```$````!B````0```/E%```!````8(@```$```!CB````0```&=V`@`!
M````UX@```$```#>B````0```#5&```!````^H@```$```"[-````0```*YX
M`@`!````9GD"``$```"^1@```0```,=&```!````H(H```$```#MB@```0``
M`(J+```!````58P```$```"H?`(``0```*N,```!````P8P```$````;C0``
M`0```'>-```!````+W\"``$````$"`(``0```,N-```!````O(T```$```#P
MC0```0```-X(`@`!````U(X```$````XCP```0```-*%`@`!````[84"``$`
M``"4D````0```/&0```!````$9$```$````NAP(``0```!N1```!````.)(`
M``$```#7D@```0```-B2```!````?)(```$```#YDP```0```!64```!````
M^HL"``$```"+E0```0```)5)```!````MY4```$```!WC0(``0```.9)```!
M````PY8```$```"R70```0```".7```!````19$"``$````:D@(``0```&Y*
M```!````=DH```$```#@EP```0````J4`@`!````LDH```$```"6E`(``0``
M``N8```!````"Y@```$````IF````0```+:5`@`!````XI@```$````S2P``
M`0```"F9```!````IYD```$```#"F0```0```/Z9```!````SDL```$````P
MFP(``0```!*;```!````0)P```$```#]G````0```,Y,```!````[4P```$`
M``!GG0```0```,Z@`@`!````^$P```$````%H0(``0````ZB`@`!````D:("
M``$```"[G@```0```%9-```!````^9X```$```#^G@```0````6?```!````
M#Y\```$````6GP```0```#N?```!`````*8"``````````````````````!@
M'V(?9!]F'V@?:A]L'VX?<!]R'W0?=A]X'WH??!]^'X`?@A^$'X8?B!^*'XP?
MCA^0'Y(?E!^6'Y@?FA^<'YX?H!^B'Z0?IA^H'ZH?K!^N'[`?LA^T'[8?N!^Z
M'[P?OA_`'\(?Q!_&'\@?RA_,'\X?T!_2']0?UA_8']H?W!_>'^`?XA_D'^8?
MZ!_J'^P?[A_P'_(?]!_V'_@?^A_\'_X?`"`"(`0@!B`((`H@#"`.(!`@$B`4
M(!8@&"`:(!P@'B`@("(@)"`F("@@*B`L("X@,"`R(#0@-B`X(#H@/"`^($`@
M0B!$($8@2"!*($P@3B!0(%(@5"!6(%@@6B!<(%X@8"!B(&0@9B!H(&H@;"!N
M('`@<B!T('8@>"!Z('P@?B"`(((@A""&((@@BB",((X@D""2()0@EB"8()H@
MG"">(*`@HB"D(*8@J""J(*P@KB"P(+(@M""V(+@@NB"\(+X@P"#"(,0@QB#(
M(,H@S"#.(-`@TB#4(-8@V"#:(-P@WB#@(.(@Y"#F(.@@ZB#L(.X@\"#R(/0@
M]B#X(/H@_"#^(``A`B$$(08A""$*(0PA#B$0(1(A%"$6(1@A&B$<(1XA("$B
M(20A)B$H(2HA+"$N(3`A,B$T(38A."$Z(3PA/B%`(4(A1"%&(4@A2B%,(4XA
M4"%2(50A5B%8(5HA7"%>(6`A8B%D(68A:"%J(6PA;B%P(7(A="%V(7@A>B%\
M(7XA@"&"(80AAB&((8HAC"&.(9`ADB&4(98AF"&:(9PAGB&@(:(AI"&F(:@A
MJB&L(:XAL"&R(;0AMB&X(;HAO"&^(<`APB'$(<8AR"'*(<PASB'0(=(AU"'6
M(=@AVB'<(=XAX"'B(>0AYB'H(>HA["'N(?`A\B'T(?8A^"'Z(?PA_B$`(@(B
M!"(&(@@B"B(,(@XB$"(2(A0B%B(8(AHB'"(>(B`B(B(D(B8B*"(J(BPB+B(P
M(C(B-"(V(C@B.B(\(CXB0")"(D0B1B)((DHB3").(E`B4B)4(E8B6"):(EPB
M7B)@(F(B9")F(F@B:B)L(FXB<")R(G0B=B)X(GHB?")^(H`B@B*$(H8BB"**
M(HPBCB*0(I(BE"*6(I@BFB*<(IXBH"*B(J0BIB*H(JHBK"*N(K`BLB*T(K8B
MN"*Z(KPBOB+`(L(BQ"+&(L@BRB+,(LXBT"+2(M0BUB+8(MHBW"+>(N`BXB+D
M(N8BZ"+J(NPB[B+P(O(B]"+V(O@B^B+\(OXB`","(P0C!B,((PHC#",.(Q`C
M$B,4(Q8C&",:(QPC'B,@(R(C)",F(R@C*B,L(RXC,",R(S0C-B,X(SHC/",^
M(T`C0B-$(T8C2"-*(TPC3B-0(U(C5"-6(U@C6B-<(UXC8"-B(V0C9B-H(VHC
M;"-N(W`C<B-T(W8C>"-Z(WPC?B.`(X(CA".&(X@CBB.,(XXCD".2(Y0CEB.8
M(YHC_____Z`7HA>D%Z87J!>J%ZP7KA>P%[(7M!>V%[@7NA>\%[X7P!?"%\07
MQA?(%\H7S!?.%]`7TA?4%]87V!?:%]P7WA?@%^(7Y!?F%^@7ZA?L%^X7\!?R
M%_07]A?X%_H7_!?^%P`8`A@$&`88"!@*&`P8#A@0&!(8%!@6&!@8&A@<&!X8
M(!@B&"08)A@H&"H8+!@N&#`8,A@T&#88.!@Z&#P8/AA`&$(81!A&&$@8__]*
M&$P83AA0&%(85!A6&%@86AA<&%X88!AB&&089AAH&&H8;!AN&'`8<AAT&'88
M>!AZ&'P8?AB`&((8A!B&&(@8BAB,&(X8D!B2&)08EAB8&)H8G!B>&*`8HABD
M&*88J!BJ&*P8KABP&+(8M!BV&+@8NAB\&+X8P!C"&,08QAC(&,H8S!C.&-`8
MTAC4&-88___8&-H8_____]P8_____]X8X!C_____XACD&.88Z!C__^H8[!CN
M&/`8\ACT&/88^!CZ&/P8_A@`&?__`AG__P09!AD(&0H9#!D.&1`9__\2&109
M%AD8&1H9'!D>&2`9(ADD&289*!DJ&2P9+ADP&3(9-!DV&3@9.AD\&3X90!E"
M&4091AE(&4H93!E.&5`94AE4&5896!E:&5P97AE@&6(99!EF&6@9:AEL&6X9
M<!ER&709=AEX&7H9?!E^&8`9@AF$&889B!F*&8P9CAF0&9(9__^4&989F!F:
M&?____^<&9X9H!FB&:09IAFH&:H9__^L&:X9L!FR&;09MAFX&?__NAF\&;X9
MP!G"&<09QAG(&<H9S!G.&=`9TAG4&=89V!G:&=P9WAG@&>(9Y!GF&>@9ZAGL
M&>X9\!G___(9]!GV&?@9___Z&?P9_AD`&@(:__\$&O_______P8:"!H*&@P:
M#AH0&A(:__\4&A8:&!H:&AP:'AH@&B(:)!HF&B@:*AHL&BX:,!HR&C0:-AHX
M&CH:/!H^&D`:0AI$&D8:2!I*&DP:3AI0&E(:5!I6&E@:6AI<&EX:8!IB&F0:
M9AIH&FH:;!IN&G`:<AIT&G8:>!IZ&GP:?AJ`&H(:A!J&&H@:BAJ,&HX:D!J2
M&I0:EAJ8&IH:G!J>&J`:HAJD&J8:J!JJ&JP:KAJP&K(:M!JV&K@:NAJ\&KX:
MP!K"&L0:QAK(&LH:S!K.&M`:TAK4&M8:V!K:&MP:WAK@&N(:Y!KF&N@:ZAKL
M&NX:\!KR&O0:]AKX&OH:_!K^&@`;`AL$&P8;"!L*&PP;#AL0&Q(;%!L6&Q@;
M&AL<&QX;(!LB&R0;)ALH&RH;+!LN&S`;,ALT&S8;.!LZ&SP;/AM`&T(;1!M&
M&T@;2AM,&TX;4!M2&U0;5AM8&UH;7!M>&V`;8AMD&V8;:!MJ&VP;;AMP&W(;
M=!MV&W@;>AM\&WX;@!N"&X0;AAN(&XH;C!N.&Y`;DAN4&Y8;F!N:&YP;GAN@
M&Z(;I!NF&Z@;JANL&ZX;L!NR&[0;MANX&[H;O!N^&\`;PAO$&\8;R!O*&\P;
MSAO0&](;U!O6&]@;VAO<&]X;X!OB&^0;YAOH&^H;[!ON&_`;\AOT&_8;^!OZ
M&_P;_AL`'`(<!!P&'`@<"AP,'`X<$!P2'!0<%AP8'!H<'!P>'"`<(APD'"8<
M*!PJ'"P<+APP'#(<-!PV'#@<.AP\'#X<0!Q"'$0<1AQ('$H<3!Q.'%`<4AQ4
M'%8<6!Q:'%P<7AQ@'&(<9!QF'&@<:AQL'&X<<!QR''0<=AQX''H<?!Q^'(`<
M@AR$'(8<B!R*'(P<CAR0')(<E!R6')@<FAR<')X<H!RB'*0<IARH'*H<K!RN
M'+`<LART'+8<__________^X'+H<O!R^',`<PAS$',8<R!S*',P<SAS0'-(<
MU!S6'-@<VAS<'-X<X!SB'.0<YASH'.H<[!SN'/`<\AST'/8<^!SZ'/P<_AP`
M'0(=!!T&'0@="AT,'0X=$!T2'10=%AT8'1H='!T>'2`=(ATD'28=*!TJ'2P=
M+ATP'3(=-!TV'3@=.AT\'3X=0!U"'40=1AU('4H=3!U.'5`=4AU4'58=6!U:
M'5P=7AU@'6(=9!UF'6@=:AUL'6X=<!UR'70==AUX'7H=?!U^'8`=@AV$'88=
MB!V*'8P=CAV0'9(=E!V6'9@=FAV<'9X=H!VB':0=IAVH':H=K!VN';`=LAVT
M';8=N!VZ';P=OAW`'<(=Q!W&'<@=RAW,'<X=T!W2'=0=UAW8'=H=W!W>'>`=
MXAWD'>8=Z!WJ'>P=[AWP'?(=]!WV'?@=^AW\'?X=`!X"'@0>!AX('@H>#!X.
M'A`>$AX4'A8>&!X:'AP>'AX@'B(>)!XF'B@>*AXL'BX>,!XR'C0>-AXX'CH>
M/!X^'D`>0AY$'D8>2!Y*'DP>3AY0'E(>5!Y6'E@>6AY<'EX>8!YB'F0>9AYH
M'FH>;!YN'G`><AYT'G8>>!YZ'GP>?AZ`'H(>A!Z&'H@>BAZ,'HX>D!Z2'I0>
MEAZ8'IH>G!Z>'J`>HAZD'J8>J!ZJ'JP>KAZP'K(>M!ZV'K@>NAZ\'KX>P!["
M'L0>QA[('LH>S![.'M`>TA[4'M8>V![:'MP>WA[@'N(>Y![F'N@>ZA[L'NX>
M\![R'O0>]A[X'OH>___________\'OX>`!\"'P0?!A\('PH?#!\.'Q`?$A\4
M'Q8?&!\:'QP?'A\@'R(?)!\F'R@?*A\L'RX?,!\R'S0?-A\X'SH?/!\^'T`?
M0A]$'T8?2!]*'TP?3A]0'U(?5!]6'U@?6A]<'UX?___>%>`5XA7D%>85Z!7J
M%>P5[A7P%?(5]!7V%?@5^A7\%?X5`!8"%@06!A8(%@H6#!8.%A`6$A84%A86
M&!8:%AP6'A8@%B(6)!8F%B@6*A8L%BX6,!8R%C06-A8X%CH6/!8^%D`60A9$
M%D862!9*%DP63A90%E(65!96%E@66A9<%EX68!9B%F069A9H%FH6;!9N%G`6
M<A9T%G86>!9Z%GP6?A:`%H(6A!:&%H@6BA:,%HX6D!:2%I06EA:8%IH6G!:>
M%J`6HA:D%J86J!:J%JP6KA:P%K(6M!:V%K@6NA:\%KX6P!;"%L06QA;(%LH6
MS!;.%M`6TA;4%M86V!;:%MP6WA;@%N(6Y!;F%N@6ZA;L%NX6\!;R%O06]A;X
M%OH6_!;^%@`7`A<$%P87"!<*%PP7#A<0%Q(7%!<6%Q@7&A<<%QX7(!<B%R07
M)A<H%RH7+!<N%S`7,A<T%S87.!<Z%SP7/A=`%T(71!=&%T@72A=,%TX74!=2
M%U075A=8%________UH77!=>%V`78A=D%_____]F%V@7:A=L%VX7<!?_____
M<A=T%W87>!=Z%WP7_____WX7@!>"%________X07AA>(%XH7C!>.%Y`7__^2
M%Y07EA>8%YH7G!>>%_____^<%9X5H!6B%:05IA6H%:H5K!6N%?__L!6R%;05
MMA6X%;H5O!6^%<`5PA7$%<85R!7*%<P5SA70%=(5U!7__]85V!7:%=P5____
M______\`````````````````````7Q5B%645:!5L%7`5<Q7_____________
M__________________]V%7D5?!5_%8(5_____________________X45AQ6)
M%8L5C16/%9$5DQ65%9<5________________________________________
M__________________________________________________________^9
M%:42IQ*I$JL2K1*O$K$2LQ*U$K<2N1*[$KT2OQ+!$L,2Q1+'$LD2RQ+-$L\2
MT1+3$M42UQ+9$ML2W1+?$N$2XQ+E$N<2Z1+K$NT2[Q+Q$O,2]1+W$OD2^Q+]
M$O\2`1,#$P43!Q,)$PL3#1,/$Q$3$Q,5$Q<3&1,;$QT3'Q,A$R,3)1,G$RD3
M*Q,M$R\3,1,S$S43-Q,Y$SL3/1,_$T$30Q-%$T<321-+$TT33Q-1$U,351-7
M$UD36Q-=$U\381-C$V439Q-I$VL3;1-O$W$3<Q-U$W<3>1-[$WT3?Q.!$X,3
MA1.'$XD3BQ.-$X\3D1.3$Y43EQ.9$YL3G1.?$Z$3HQ.E$Z<3J1.K$ZT3KQ.Q
M$[,3M1.W$[D3NQ.]$[\3P1/#$\43QQ/)$\L3S1//$]$3TQ/5$]<3V1/;$]T3
MWQ/A$^,3Y1/G$^D3ZQ/M$^\3\1/S$_43]Q/Y$_L3_1/_$P$4`Q0%%`<4"10+
M%`T4#Q01%!,4%107%!D4&Q0=%!\4(10C%"44)Q0I%"L4+10O%#$4,Q0U%#<4
M.10[%#T4/Q1!%$,4111'%$D42Q1-%$\44113%%445Q19%%L4711?%&$48Q1E
M%&<4:11K%&T4;Q1Q%',4=11W%'D4>Q1]%'\4@12#%(44AQ2)%(L4C12/%)$4
MDQ25%)<4F12;%)T4GQ2A%*,4I12G%*D4JQ2M%*\4L12S%+44MQ2Y%+L4O12_
M%/_____!%/__PQ3_____Q13'%,D4RQ3-%,\4T133%-44UQ3__]D4___;%/__
M___=%-\4________X13C%.44YQ3_____Z13K%.T4[Q3Q%/,4]13W%/D4^Q3]
M%/\4`14#%045!Q4)%0L5#14/%1$5$Q45%1<5&14;%1T5'Q4A%2,5)14G%2D5
M*Q4M%2\5,14S%345-Q4Y%3L5/14_%4$50Q5%%4<5215+%4T53Q51%5,55157
M%5D56Q5=%?____________^I"JL*K0JO"K$*LPJU"K<*N0J["KT*OPK!"L,*
MQ0K'"LD*S0K1"M4*V0K="N$*Y0KI"NT*\0KU"OD*_0H!"P8+"PL0"Q4+&@L?
M"R0+*0LN"S,+.`L]"T(+1PM,"U0+__];"U\+8PMG"VL+;PMS"W<+>PM_"X,+
MAPN+"X\+DPN7"YL+GPNC"Z<+JPNO"[,+MPN["[\+PPO'"\L+SPO3"]<+VPO?
M"^,+YPO________________________________K"^\+]`OY"_X+`PP(#`T,
M$@P7#!P,(0PF#"L,,`PU##H,/@Q"#$8,2@Q.#%(,5@Q:#%X,8@QF#&H,;@QR
M#'<,?`R!#(8,BPR0#)4,F@R?#*0,J0RN#+,,N`S`#/_____'#,L,SPS3#-<,
MVPS?#.,,YPSK#.\,\PSW#/L,_PP##0<-"PT/#1,-%PT;#1\-(PTG#2L-+PTS
M#3<-.PT_#4,-1PU+#4\-4PU7#5L-7PUC#6<-:PUO#7,-=PU[#7\-@PV'#8L-
MD`V5#9H-GPVD#:D-K@VS#;@-O0W"#<<-S`W1#=8-V0W<#=\-X@WE#>@-ZPWN
M#?$-]0WY#?T-``X$#@<."PX/#A,.%PX;#A\.(PXG#BL.+PXS#C<..PX_#D,.
M1PY+#D\.4PY7#EL.7PYC#F<.:PYO#G,.=PY[#G\.@PZ'#HL.CPZ3#I<.FPZ?
M#J,.IPZK#J\.LPZW#KL.OP[##O__QP[,#M$.U@[:#M\.XP[G#NT.\@[V#OH.
M_@X##P@/#`\0#Q,/%P\<#R$/)`\J#S$/-P\[#T$/1P],#U`/5`]8#UT/8P]H
M#VP/<`]T#W</>@]]#X`/A`^(#XX/D@^7#YT/H0^D#Z</K0^R#[@/O`_"#\4/
MR0_-#]$/U0_9#]X/X@_E#^D/[0_Q#_8/^@_^#P(0"!`-$!`0%A`9$!X0(Q`G
M$"L0+Q`T$#<0.Q!`$$,021!-$%`04Q!6$%D07!!?$&(091!H$&L0;Q!S$'<0
M>Q!_$(,0AQ"+$(\0DQ"7$)L0GQ"C$*<0JQ"N$+$0M1"X$+L0OA##$,@0RQ#.
M$-$0U!#7$-P0WQ#B$.40Z!#K$.X0\1#T$/@0_1``$0,1!A$)$0P1#Q$2$181
M&A$>$2(1)1$H$2L1+A$Q$301-Q$Z$3T10!%%$4H13A%3$5@171%A$681:A%P
M$7,1=Q%[$7\1@Q&)$9$1E!&7$9H1G1&@$:,1IA&I$:P1KQ&R$;41N!&[$;X1
MP1'$$<<1S!'/$=(1U1':$=X1X1'D$><1ZA'M$?`1\Q'V$?D1_!$`$@,2!A(*
M$@X2$1(6$AH2'1(@$B,2)A(J$C(2-1(X$CL2/A)!$D021Q)*$DT241)5$ED2
M71)A$F42:1)M$G$2=1)Y$GT2@1*%$HD2C1*1$I42F1*=$J$2+A+__^T)[PGQ
M"?,)]0GW"?D)^PG]"?\)`0H#"@4*!PH)"@L*#0H/"A$*$PH5"A<*&0H;"AT*
M'PHA"B,*)0HG"BD**PHM"B\*,0HS"C4*-PHY"CL*/0H_"D$*0PI%"D<*20I+
M"DT*3PI1"E,*50I7"ED*6PI="E\*80IC"F4*9PII"FL*;0IO"G$*<PIU"G<*
M>0I["GT*?PJ!"H,*A0J'"HD*BPJ-"H\*D0J3"I4*EPJ9"IL*G0J?"J$*HPJE
M"J<*__^K"?__________________________________________________
M____________________________________________________________
M______________________________^M"?__KPFQ";,)________________
MM0G__[<)__^Y"?__NPG__[T)____________________________________
M______________________________^_"?__________________________
M________________________________________________________P0G_
M_\,)___%"?_______________\<)________________R0G+"?__________
MS0G0"?_______],)U0G__]<)___9"?__VPG__]T)____________________
M_______________________________________________?"?__________
M____________________________________________________________
M____________X0G__^,)___E"?_______________^<)________________
MZ0GK"?__`````````````````````/\'`0@#"`4(!P@)"`L(#0@/"!$($P@5
M"!<(&0@;"!T('P@A"",()0@G""D(*P@M""\(,0@S"#4(-P@Y"#L(/0@_"$$(
M0PA%"$<(20A+"$T(3PA1"%,(50A7"%D(6PA="%\(80AC"&4(9PAI"&L(;0AO
M"'$(<PAU"'<(>0A["'T(?PB!"(,(A0B'"(D(BPB-"(\(D0B3")4(EPB9")L(
MG0B?"*$(HPBE"*<(J0BK"*T(KPBQ"+,(M0BW"+D(NPB]"+\(P0C#",4(QPC)
M",L(S0C/"-$(TPC5"-<(V0C;"-T(WPCA".,(Y0CG".D(ZPCM".\(\0CS"/4(
M]PCY"/L(_0C_"`$)`PD%"0<)"0D+"0T)#PD1"1,)%0D7"1D)&PD="1\)(0DC
M"24))PDI"2L)+0DO"3$),PDU"3<).0D["3T)/PE!"4,)10E'"4D)2PE-"4\)
M40E3"54)5PE9"5L)70E?"6$)8PEE"6<):0EK"6T);PEQ"7,)=0EW"7D)>PE]
M"7\)@0F#"84)APF)"8L)C0F/"9$)DPF5"9<)F0F;"9T)GPFA":,)I0FG":D)
M________________\`?T!_<'___3!___U0?________________________7
M!________]D'________VP?________=!________]\'________________
M___A!___________________XP?__________________^4'____________
M_______G!________]<$W03C!.D$[P3U!/L$`04'!0P%$046!1L%(`4E!2H%
M+P4U!3L%005'!4T%4P59!5\%905J!7`%=@5[!8`%A06*!8\%_____Y4%____
M____________________________________________________________
M____________________________________________________________
M_________________________________YH%G@6B!:8%J@6N!;(%M@6Z!;X%
MPP7(!<T%T@77!=P%X07F!>L%\`7U!?D%_04!!@4&"08-!A$&%089!AX&(P8H
M!BT&,@8W!CP&009&!DL&4`93!E8&609<!E\&8@9E!F@&:P9O!G,&=P9[!G\&
M@P:'!HL&CP:3!I<&FP:?!J,&IP:K!J\&LP:W!KL&OP;#!L<&RP;/!M,&UP;;
M!M\&XP;G!NL&[P;S!O<&^P;_!@,'!P<+!P\'$P<7!QL''P<C!R<'*P<O!S,'
M-P<[!S\'0P='!TL'3P=3!U<'6P=?!V,'9P=K!V\'<P=W!WL'?P>#!X<'BP>/
M!Y,'EP>;!Y\'HP>G!ZL'KP>S![<'NP>_!\,'QP?+!\\'________________
M___________)!/______________________________________________
M_\L$SP3_____________________________________________________
M___3!/____^<!/____^>!*`$H@3__Z0$________________________I@3_
M____________________J`2K!/__KP2R!/____________^V!/__________
M__^X!/______________________________________________________
M______________________________________^Z!/_______[T$P`3_____
M_____\,$Q@3__________V`#9`-H`VH#__]M`W$#=0/__W<#>@-\`WX#@`."
M`X0#A@.(`XH#C`/__XX#D`/_____DP.5`Y<#F0.;`________YT#H0/__Z0#
M__^F`___J@/_______^L`ZX#L`.R`[0#M@/__[@#N@.\`[X#P`/"`\0#___&
M`___R@/,`\X#T`/__________](#U`/6`]@#V@/_____________________
M___<`^(#Z`/N`_0#^@,`!`8$#`02!!@$'@0D!"@$*@0M!#$$-`0V!#D$/01"
M!$4$1P1*!$X$4`12!%0$5@18!%L$7P1B!&0$9P1K!'`$<P1U!'@$?`1^!(`$
M@@3__________________________________________X0$AP2)!(P$C@3_
M____________________________________________________________
M____________________________________________________________
M____________________________________D@3__Y4$__^8!/_______U0#
M_____U<#7`/_____________[P+Q`O,"]0+W`O__^0+[`OT"____________
M__\"`0,#`P4#!P,)`_____\+`PT##P,1`Q,#%0,7`QD#&P/__QT#__\?`R$#
M)`/_______________________\H`___+0,O`S(#__\V`SD#__\]`S\#__]!
M`___________________1`/_____1@-)`TP#________________________
M__________]/`______I`NP"________________N`*Z`O______________
M_[P"O@+________________________________________________``L("
M____________________________________________________________
M_________________________\0"Q@+_____________________________
M________________________R`+*`O_____________________,`LX"____
M_________________]`"T@+_____________________________________
M________________U`+7`MH"W0+@`N,"____________________________
M_________________________^8"________________________________
ML@+__[4"________________________J0+_________________________
M____________________________________________________________
M_____________________ZP"KP+__________________YH"G0*@`J,"____
M______________^1`I0"EP+_____________`````````````````````'@"
M>@)\`O____]^`H`"____________________________________________
M______________________^"`H0"A@+__X@"B@+_______^,`O__________
M________7@)@`F("9`)F`O____________________]H`O__:@)L`FX"<`+_
M_W("_____________________________________W0"=@+_____5@)8`EH"
M7`+__________P```@`$``8`__\)``T`#P`2`!0`&``:`!T`(0`C`/__)P`J
M`"X`,0`T`#8`.``Z`#P`/@!!`$,`1@!,`%(`6`!:`%T`8`!C`&8`:0!K`&X`
M<`!S`'8`>0!\`'\`@@"%`(@`B@"-`)``DP"6`)D`G`">`*``HP"F`*D`K`"O
M`+(`M0"X`+L`O@#!`,0`Q@#)`,L`S@#1`-0`UP#:`-T`X`#C`.4`Z`#K`.X`
M\0#T`/<`^0#[`/X``0$$`0<!"@$-`1`!$@$4`18!&`$:`1P!'P$B`24!*`$J
M`2P!+@$P`3(!-`$V`3@!.@$\`3X!0`%"`40!1@%(`4H!3`%/`5(!5`%6`5@!
M6@%<`5X!80%D`68!:`%K`6X!<`%R`70!=@%X`7H!?`%^`8$!A`&'`8H!C`'_
M_XX!D`&2`90!E@&8`9H!G`&>`:`!H@&E`:@!J@&L`:X!L`'_____LP&U`;<!
MN0&[`;X!P0'$`<<!R@'-`<\!T0'3`=4!V`';`=X!X0'C`>4!YP'I`>L![0'O
M`?$!\P'U`?@!^P']`?\!`0(#`@4"!P(*`@T"#P(1`A0"%P(:`AT"(`(C`B8"
M*`(J`BP"+@+_______________________________________________\P
M`O__________________________________________________________
M____________________________________________________________
M____________,@(U`C@".P(^`D$"1`)'`DH"________________________
M____________________________________________________________
M____________30)0`E,"__________\`````````````````````1)XJ'@L@
MA\L,KPJ>"YXLU,$C#J\$G@6>=J$'T@,C!*,2'IQA5^L1G@(L"*P7'DNC%AY+
MHR`>=:=MN>(C-SH).\+5<;?X3'+-(AZ^HQ@>=:<D'FFA'QZ^HTGA(1YIH;,C
MM*:A('8NW<JJI?8`"R"'RY(W8#@/N3_"2EQ07#MG2F>H:,[H,YXRGNC1ND`R
MPF\JE^X9,^<T"=+*HP@BQ=+\+OK?!@"4GD8>>>5%'GGE&RQZ+H4NO&Z][JG/
MS\!].0*Z%Q\`-3Y'1MBLI4Y67=98'@FY5QX)N9!FH&:QYM+/]V`)80IA%>'X
MME@ARZFWW((>X.%^'H$>)[]Y'H$><BXGOYQOG^]Y'GX>)[]Q'N#AN#:MQVO<
M+<*+'M.CBA[3HPVOCQZ0'KRUCAZ0'KPU9]:.'H^>'1_RYD2>VZ:!+%<M<CMS
MNYF>F)Z<'IZ>FAZ>GHDUBC5*;U#OFAZ<G@_!OAYFH2)%(\5&15)%745>Q:^>
ML)ZKGJR>'*FJV3O9LJ:[GKJ>H1YFH02ASJ_-(*@BU:+8'L6@U:".V]^@JR&P
M(3>\DR^>KUN?'A^8H)8?&"T9K?H>":#%GLH@\J`,I.V>=*]/(7=E>&5_Y0"A
M$:#>GD<@S:.A'_F@TQX)H,>?;"^,M4Z?(R!W+ZPO!D?CZJ`@:\(1KE$>/D=&
MV"JA):D#M[2@!:"1'B`?LZ#0'I@@5LY)H!T?LZ#EG]2?MZ``H"N@EJ!](-Z@
M1Q_:RJJB,A]@'QZA,1]@'QZAD)_$T$"?/)\4L"N?`Z[^GBA+L%[&7K5JU.I@
MHQAI@.G/'G\O].I:H*N?,1\R'QXALZFMH,F@BJ_5/$O``B!VKHBO6*"W*>JI
M9;<E9C1F<&:"YDFU-9_1GE!3IM7@G_<>^:"VG^6@=2!)X'2@T:`(H16A7I\"
MH1@A/:SFQZ.?0*PWQ>.?^\S\G@&A%-\\PB,?D[!JH>+*H)\KVNZ?P9\AGQ2A
M/*$&H#>A"*`Y(`FAXA\IT3:@FB!(M7D@F2##(`>II4P[Z]XP([LEGW4?=JYZ
M(+$DDJ4<G^F?ZY_3'OJ>;*#V`"H>A\M&T1"@#Z#LGGBNN:"C+\G5_QX&QSR@
MM2+,HB:?6J+QG^T?":&UH"2@OJ#QTO#<[IX?GPM=%UU=W8.?P*!<GZ2O/.`*
M(*^@IY^F'TG@>*!WH/L?F2##(`>I`R"Q))*EPJ`J']Z@Z*`?H75/X6F"ZJRO
M<+<GG]`>'A]6SOL?>2##(`>I\A](M:VO$!]KPB8>=B[=RK:K#J$[H1"A,J$Z
MH6.?;*`='R"?&Y\ZH"2?'J`^H%F@>Z#['WD@F2`'J;&OQ9YEG]F>PAZH(M6B
MJ)_&GEZU>\8J'WV@R9[MH*6??J#TH'8PJC#AL..@Q^;9GNF@]QZAG^J>RI^L
MG[^>J9_M'SF@I*"GH.:?JI^M'SVL,1\R'V"??Z`YH1B?J*#JGR>AJ:"EH.B?
M4"%2H2K,]J%N0)?`3"%1H4LBRB(%K$HA4:%4H><>=V5X97_E/R%2H4HA3*$_
M(5"A3J%7H5:A:![+J>CN8*%<H?>UH1Z^GH6A(1XDGMZ?+=8I*51G7>>R)!%+
MHF779=SE"-(,G@I3,M.J3PKI8T-XPX"A?J'%IHNA/:Z)H6>A!B<.)Q.GH:R$
MH8PA)\N"H8HA)\MN(N>CYZ:2H<30D*&"JZDAZZO-WK+?D"N<JUJH`+?#J[PK
MQZO,JYDAZZM"+H//S!ZP(3>\.#85[Z[IS!ZK(3>\M*&6/%W8>KRQH<&\[[S-
MH0R]R"'HO7R]@KU3,+TPTKVXO=8AEK[`H;R]NZ$;ODJ^FL87N,8AEK[<(9^_
MVR&?OPA!54&(09G!?BXZM^(AXZ'A(>.AX2'BH?/L1:P$*576["'N(:AHS&C.
MZ.?LZ"'N(:AHS&C.Z/0A?S&1L>@A["&H:,QHSNCQH>^A,BPT+#8L-RQ0Z\BZ
M[2%_,9&Q1Z%7)THHI*B`+&/O@S3*M/ZA_:%_Y`(BUN$`(M;A!*(#HALB=:)"
M'L72'KB[TH,BD"([Q>VFB;*)HD>B6Z(%(C$B3R)9(G6B*J(KHB<B/"*KHB8B
M/"*KHDMB9&3'Y""B)2)&KU<B=R+?8_+D1**SZ!LB3R)9(G6B0:+]V$ZB/J(F
M(B<BJZ**HCJBC*)THC2B9"*1H@#K+:(9HDLARB(%K(*^;+LYHALB,2)9(G6B
M;B+GHV,B<2*-(HXBDB*4(O!A_.$L(G<BWV/RY!LB,2)/(G6B,Z`:HF6B42)Q
M(HTBCB*2(I0B\&'\X4(BD:)=HKEE">:'HG"BCB%0(N>C::)1(F,BC2*.(I(B
ME"+P8?SA+;=`H@4B&R(Q(D\B6:(L(E<BWV/RY"ZRYJ(2(I`B.\6:RV>B&*(]
MHC^B42)C(G$BCB*2(I0B\&'\X5$B8R)Q(HTBDB*4(O!A_.$2(H,B.\5"(F2B
M42)C(G$BC2*.(I0B\&'\X5$B8R)Q(HTBCB*2(O!A_.&M7.K<YR+XHJ;?_$S_
MS-FB\:+"'LT@U:(NGR8B)R(\HO6BP:*T(MXBI;&S(MXBI;$F(,RB2+7BHK*B
M3[71(E6UR*+'HDLA2R(%K-LB\B+SHB8@M:+%(I4OH"]5M<(>S2"HHM<B`K?6
M(@*WH:+IHLLB\B+SHMS0LR*T(J6Q+K*_HL.Q?Z*=(OBBVJ*BHLLBVR+SHLLB
MVR+RHK&BG2+GH@"C^Z(0'@2C$!X#HZWNZ2\Q,*2PK+,S46;1.*/I-_ZW`"[*
MWR"C'J,IHRVCR\LU5<_5(:,FHS&C1SS9OBZC,R-!*6FI,B-!*6FI&J-`H\D[
MJ^$ZH\;G4J,'-OLV*69>YI32%AX7GE"C"RWO4U#55"/V(^JU3:-&HTPXU;E/
M(_8CZK58(ZZE\BCCW%4CKJ4]L8?#U%,4U52?Y\9E(W<H]SZ;/P)`?UEU[F0C
M?]GET5M87MCUK1@I/+(!KGTCC<9[H_LM<K,WSV0PR=QTHW,CC<:(([`CX*XY
MLO`N\ZZD(Z\CIC;&-G0[=[O4R(*CLJ,G)].HK:.9HR7(CN\6K:`CP:[E*-LN
M/6'0X8VCE:?SKJ&CE2/!KI^CPJZTHX8CQK;(KMJNSR[0KHRCW:Z&(Z8VQC9T
M.W>[@B/@KHFC)1ZTIJ.CD+[!R;'0NV`P8:/FNZ.ZHQ\>(IX,1R/."1X.K\,C
MQ"/%H\(CQ"/%H\(CPR/%H\(CPR/$HTGG1N?YHVBR09[9YNX>VR.-P#:U+*FN
MPGI&?$;J:N[JBAZ+GK3-"2F*VTTU6+7-(XW`":QS18)%B46*Q>$H?\<;'C<Z
M"3O"U8XA4")NHM9)>5B[YDRD;B>Q-Z\Z^E&QZ$\C5"/J-4G47];((P8F3KLP
MIJDD]J1R3*7OJR5$IJ3E%*_='E78C*^N)L^VAZ9"I,ZE8;!1I"LE5B8AVGBF
M=%!]T!@E4R54)5\E[%K9Y30D2:0S)$FD4*07T4VD2J05I((RPL(S)#2D/Z3K
MHSVD-J0>I#BFR*84IJ:F!*7A))]<(-V\)(ZE^J3&I=JE1MHQX-REDB1+VDW:
M$2965CS;XZ2,)-(PHN^*)-(PHN]@VFHD2]JHIH"FI*1=IIRD`"3VI&GO@"5)
MV`,@>B"2I7,A$<N.87GN622.I:6FIV4HZ__G%B5>)=9%`L9@IC6F]J5FIBDF
M0=MRIHRF9::RI5@DGUP@W86D-MI@)88EGB;1)XJP`"2II%JDF%KQVU>D(]&>
MTWJE(Z71)%XEUD4"QB\D4R54)5\E[%K9Y1RFRJ4NINFE%:6:I9ZE'Z2OVO6O
M"J8JV^[E+R08)50E7R7L6MGE+R08)5,E7R7L6MGE2:9)IM$D%B7610+&+R08
M)5,E5"7L6MGE\B2&)9XFT2>*L%186%B<XA:FQZ7`IELFF2;3)F?O$Z;))E?/
M/:8OIA"EKR1)V"=I->EQV_(D8"6>)M$GBK!9)+RD?B86Q@,@>B"QI"2EF#&9
M,5:[)Z6[I2>>`R1$IE2>52-8H[<E=*;?:.!H8^G?I-]!)=2O)72FJ:4-IK.F
M1>];I&RE':47I%RD::1JX6"K-Z8BI<&F;Z;4I##;^2-.NT"EO:5\)#S;;Z55
MI&>ED"8=+![%4Z8;I;:F+Z;7)$';(*5X)2BF_:/1IM.DY:52I'2E=K!0VP,D
MJZ55IE8E5Z5HIABF1:8?)"':;B69II6FG:32I&O;W:35I%"F7]OSI=FDKR6W
MI5Q87UA3X"BD4Z^1I9ND$Z3<I)2F%R8=+![%CZ9<IFXE6R;3)F?O\B1@)88E
MT2>*L$^]RJ;"IKVD5J29I!&DN)Z^I24>LZ,DIL*F;:7KI:,FNZ:!H5.D<"57
MSZ*FS])QTC&F;B69)F?O\B;T)@VGWB;L)OLN_2[T7R7@X*:6GM@F[";[+OTN
M]%\EX%;HV:;C)A@G\,SB)A@G\,SU/0H^%;Z/H?&FV";>)OLN_2[T7R7@$R(2
M)Y?5]B;[)OTF`"<+IT_'ZJ;7)O0F#:?^)A8G%Z?7)O(F#:<'I^\F^R;])@`G
M"Z?EM>\F]B;])@`G"Z?O)O8F^R8`)PNG\R86)Q>G[R;V)OLF_28+IQ&GAB$.
M)Q.G]:8/I^\F]B;[)OTF`*?7)O(F]*:&(08G$Z<(IP.G[2:7U88A!B<.I_,F
M_B87I_,F_B86I^(FXZ8^.!*[(:<?ISI%/,56T(LCTZA7LD>WZL-4)\HGLZW9
MJ#0H<JA^.W\[@3NAO"_FA2PJYF\GRBC>*"OFIZXLYHNG,"?*)[.M]R%***2H
MX*T%J+`HM2C'*-PH2$].S^*HNR?IJ&(HEN:S**OFG"@(R0*H`ZB[L8RH0&9!
MYN6\\"/ZT4\G*^:GIX>G&!X@GJ*GHJC`I]^HX*C:J'.G4Z=!*-BH8<5[YIJC
M!J@O*"<L+:R<IYNGHJAXI[ZH<*>(JPHH5M"*J.&GMJC+J$^H%JA=)^FH@J=N
MR%;F,"=4)[.M\B1@)88EGB:*L-.GTJ=2J&0HSJ@=J,0HSN$D*(3FK:>7R&>R
M#BU<+97(@[-CIV2G6J>6I^O3J:=YJ*XHKZBTIWOFVJ?>)X3F-F:.YIHG)RPM
MK)4H@>:ELCHG<JA,14W%DB?8J.JH]R%7)Z2H%--[Q;*G4:A0J-BGEJB"O:>H
MHJ%LU&NH7J?9)\ZH8^;01GWN8:@Z)S2H&*QD(W7N$2C-J`Y%%DC:R$7"JZ=G
MIS`H@>94J)ZHNRA&PF`G",F7J'HGH:?W(5<G2JA9J!4HKZ@5**ZH6R>U*-PH
M2$].SU\GJ^9;)[`HW"A(3T[/KZ>'WIFHIJ?<)\[A6Z=/)]ZHL:?DJ'FHV2=D
MJ+W$BR,GIY(G0:@YIX:G6R>P*+4H2$].ST\GRJB$IX6GX2-_QURGS*B8(]LN
M/>%=)[NG1JCO*/6H[BCUJ'+0^:A6(^/<NSN\N^XH[ZCW*/JH]BCZJ/RH\:CV
M*/>H?RI?T/BH`"G_J_TH_ZL*J>8A5=9-YOL?>2"9(,.@V".*VP*IJ2\'68;9
M$ZD/J4'6;R,\LANI&JFQGB"I'ZDC*::X(BFFN!F?<B%49UWGSZ.`NRPW3;GP
MO"WHU+N'VCZI:JDYJ3(C,R-IJ5"ITLKPMVZIWNY"J8="*>!H*6PI3L,)KUK%
M9RFTK64IM*U6*6PI3L,R(S,C0:DZJ58I:"E.PTNILRDMJ^8IYZF=*20JITS:
MS&8JC:J]JMFI^"D%U:RI1<F%P[BJABDD*J=,VLSUJM>JKRH`JY*I8!]V*2VK
MA!_JJ3\J0*H2JLJIR:EH'EBAUZF.JC"JS:F*J9'5'ZIX*>>I>"GFJ80?MZGL
MJ>NIYJJ-*0758ZI!JFVJ"*L,JTRKQJDB*T.K+RHQJN*IABF=*:=,VLPJJPFK
M&RHQJM*I&RHOJJ>J^BK[JK@I0*JX*3\J4*H$JD"J^ZF'*8VJZ[T%JCT>E^[_
MJC`K1BM^JPNK.*O[*%_0AREFJM"I,JJ\J@.KJRD`JYNIJJJ(J2<Q;=`=*X78
M,JLAJRJKJJGNJ1FKJ:F4,43&-"K[JC0J^JISJJLIKZJMJ@:J+:IUJ@>J\:K+
M*H78TJH8*D.K-ZLF*M2J=BFSJ70J1BM^J]"J)*MVJM*Q&"HBJW0J,"M^JPBJ
M4ZM2JVNKXZ5X*VDUA36&-8BU?ZM9JV8K:36%-88UB+5]JWRK="HP*T:K:JO-
M*]4KURO<*^<K+\67H6!"=5;'UGG*J*>!RHG0G2&<JYTAD*O:*_,K]BODPY\K
MYJN>*^:K]:NW*^FK3JRRL:ZKJZN,6[SAHJ"A*^FKQJNF(<>KVROLJ]-<U-S'
MX:2ANZNF(;RK46=2Y[IF36=.9T]GM&T6;F3NJ*&!*]4KURO<*^<K+\6]KH$K
MS2O7*]PKYRLOQ8$KS2O5*]PKYRLOQ9TK\ROV*^3#O2OLJX$KS2O5*]<KYRLO
MQ>*K9]JM2K;*W:N>*Y^K@2O-*]4KURO<*R_%H2NWJYDAJ:&]*]NKG2O:*_8K
MY,.@JYTKVBOS*^3#_BL-K`NL#JSY*PVL_2@`J1,>"*Q+(4LBRJ('K`:L$QX"
MK-ZC^ZOY*_ZK_*L3+!0L/L(2+!0L/L(2+!,L/L)UJ!JL&:Q('H4NO&Z][A<F
MD"8>Q<[!("Q[7:YK>VR<[!\L>UVN:WMLG.PC+"0L([`BK"(L([`FK"6LFB<O
M*"VL*ZPIK$#KFB<O*">L\B$T+#8L-RQ0Z_(A,BPV+#<L4.OR(3(L-"PW+%#K
M\B$R+#0L-BQ0ZTVLK1\8(>'&MQ_\W62L4ZSEH4JL1JSE;!_N.*RIJULL2*Y#
MK$\L2*YLK&*L8:Q"K&BL9JQ>K+RM^J&7'E<M<CMSNTC<0B<JYCK<AZT7K?2L
M4*WV+(LMC"VY+69FG6:OYHBA4BU3+<PMUBW7+9[(NJV]K8>M+*W+K:BMIZW=
MK-*L_:RBK:"M(JW2K>FLZ*SPK.^LF*Q8+;@MQJV;+(LMC"VY+69FG6:OYN&L
MEZT-K:ZM"*T'K4XC[],#K?PG7"V5R).CEZS1'AFMT1X8K>6LO:R#+82MS\N:
MK*DL4RV>R*DL4BV>R)<>@2QR.W.[]2RX+<:ME*W\)PXME<B!K1,^JKYSK6^M
M7:TMK2VMEBRTK)LL]BR,+;DM9F:=9J_FFRSV+(LMN2UF9IUFK^9:K0*MY*SC
MK,2LPZP$K=_F,"=4)\JG92EGJ?4L6"W&K9LL]BR++8PM9F:=9J_FK:Q_K+.L
MTRW4K?4L6"VXK;^LJ2S6+=>MYJS%K<6MJ2S,+=>MJ2S,+=:MW:W;K5FGXZWB
MK8_G\*WOK6ZC5MC]K7<C<K/ZK<UGZ.<=(\K?<"-C+F2N2)\EKBNN&<U#KC.N
M%I^+V$C-/LR2RU\NV+4%KB\N-JY`K@BNQM1'+EHN:ZXF+C:N4B]X.XC&;*X0
MKB8N+ZY8KE>N@Z$GKJHA@\\/KBXN6BYKKD\L6ZPHSCRN.ZXN+D<N:ZX<+MBU
MV;4!+F2N`2YCKBXN1RY:KC&N?AYY+J:YRLDF'G4?`B"A('<NW<IVKA:@<BZF
MN4B>X*&#+K4NXZ[P+O.N?R[CKEA3BM-('ALLO&Z][G:Q0,+LKN&NJZ[<+\FQ
MWZZ0[\,NXJY0IY.N?R[T4TI4[=2[KGXW@#>I-]<WI;BVKLZNTZO?KI4CH*.B
MHY\NXJZFH[RNJ2/0KJDCSZZHHY@CY2@]X:ZCF2Z_KH(CL*.1KI\NPZY_+H.N
MZJ[IKI"NA2.!+O.NA2.;(X$N\*[JW]@FWB;L)OTN]%\EX$,>^M_8)MXF[";[
M+O1?)>"+Y>-$C5FA7Z=?J%^I7Z_?<,7$N`HS-;-8J0">C)X)'L&CKERS7##=
M$J\1KPJD-:],+S#`0\TSKTZO*J\@KSJO/B](KS>O/*\[KSDO2*\KHCDO/J\E
MKR^O4:]0KS`N>#N(QGDF=L55KU0O!&,RX_++6B]'O%DO1[Q<+UTO7J];+UTO
M7J];+UPO7J];+UPO7:]@KU\OIM1FKV6O<J^US=7F_1Z,M6BOXI[_'JPOX^JY
MKUL?].J#+^S?L"^T+[6O@*^1+_-?%>#EPG>?:I\.I%_FA"_S7Q7@SAZ>K]$B
MH*_.'I.OT2*5KZ;)'R#)U66@#2F&V?\>C2!WKYR@@:_$H+<O=#"SL($OM:^!
M+[2OLR]T,+.P>Z_$K\.OMK'!GO0Q^K&,VGZPE"[)L9^P);""L08C,3"DL+2P
M.*4^L=`Q][%+L6NQKK%JL;6P-+%"GY&PD+%6L"(L)*SCKV"P!B/I+Z2PXS!T
M,\]-ZTT]SM^QS+%2L`"R1K#$(;VP';`JL!TDB[!Y(\G<.]`9L84PIK#'L;,O
MMR^SL."PZR!!)JHPX;!?L>BQ-['[L*DP\;#RL-FOY3!"L1$Q.;%Q,*:P\B1@
M)88EGB;1IV&P`L,6L-2?`C&6VN_;XJ_*L`8CZ2\QL'$PA;!\,/&PZR!V,.&P
M9+'XL7.QJ[&S+[<O=+#PKP6P]^7$(5.PHC!:ZHHDC"2B[_T?([MUL.L@=C"J
ML#NP?S!"L?RQ6+'RL8JQ'+%9,5JQFK%CL7PPJ;!]L"+8>[`*V98PEMH)1E+&
M@#`YL6JP,<+LL$VQ@;&DL9*QORIMT/RQ!K!ZL(`P$;%.L5JC_J]8Z'\PY;`7
MN+>[`;`@L3PQ&C88QW0Q_K'HL.TP6K'M,%FQ>#"%L>^PJ[`$L`*PEK%1UJVP
M4;&&KGTQ&K)\,1JR,KOM(?0AD;$AL>>O7[&IL>NP'+#M(?0A?[$FL?8J1,9M
M,9>QEK&<)9DQ5KN<)9@Q5KONL"2QLR*T(MZBA[&OL`.PJJO&KV:GY*)SL)0N
MW*\_L-2Q`##WL>.Q/BOVL<VQ];&9U#RPT;'GL>:Q>;#IL,\O_['<L=*Q`##0
ML:RPSZ_G,#.Q(KM1L?2Q2[`'L@:R%+(O,C*R"[(GLB8R,+)\,7VQ'K*A7"+=
M&[(8,C"R%[(LLBFR>2+@H@\R,K(8,B:R#S(OLC<R.+(V,CBR-C(WLH2C/K)O
M(QBI.[),LDNRE,[@,R[-LC3(M,*R**<76JS;3;-HLN;A]Z?)(V"RX3+TM&NS
M@[/:LZ:T_K2\M4@DPL(4HJNTR[+4LM>RZ3+'M':T<[2$LS:T=]LQJ.&TWC)T
M0MW95;+4M)JTF[+_LK0W^K<HM)RRUK+5LIVRW;+<LK6R[+1N,]JT:3($,_2T
M#[7`L\&T%+7PM*4T>L:>,L>TS[*;L^$R]+0$+S6S/A[G-`G2;[0CM9>SOK2[
MM#ZSD[3+M)^TF;/@M.ZSC[0$+PJS$K03WQ^STK,%-+DT*K6Q.'5)D<U>LM&S
M>=,<M(BT#;2_M-NS%S3CM`W2:K+@,MJT=R/[K3NP%CCRN/TG:[*ALARS([,"
ML\?AT;0*H^VSQ+11M/*TH[1[M!2T7+2PR..R3[,_LVRR8K-.LK*S);/,T!8T
M1[0LM;.T&;7QM%^T/<Y!,[DT*K6$MU^S-[.[L_HS1[1CLUPSD-33LIBT*+6B
MLM4T'+6HN40T';5"-!VU!+7Z-&S9^C,6M.^T)+6TL[RS`K3/3>M-/<[UM!JS
MH+*?LKJS^R'*M!:U7K,FLY&TD+0@LRVTR+(BL\VTN+/H,GK&;[)5379-W<Z:
MLE$RR+3_LP:U][3\M$$S!30JM1NU'K,=LV&SY;*SLYXRZ;)1,K*T^R&#M"&S
MH;2EL\6R.C0<M>`R;K/[M"2SK+)CLRRU/AX9,PG2W[)(M.>R`;2WLVDRX3($
MLVFTMS1MV4:TWK2XM`JU<+)1GD6T(K6UM!^U_;3BLB*UYK*$M`"TNK0Z--6T
M0C1$M`BU!342M1NS2K0RM$$S!32YM#3"_3/EM#6U-+7.HP/0)TM62UY+H\OR
M'YH@N:*.GW6UV2-8M5FUQ*+%(M&B`5TEW=DC3;5.M8(U6[O8H&8K>"N%-88U
MB+5XM4RUR;5PM<9IR&E%:G'J7;M;-5N[V;MF*W@K:36&-8BU9BMX*VDUA36(
MM68K>"MI-84UAK6='HHU2F]0[YT>B35*;U#OCC5+[_T>;*^ZV8LU2^^5M9XU
MI->3M=AE)6LF:RIK+>N4-:376>&LM:FUM[6UM;*UK;6.'H\>=;+2M7>UR+4Q
M3$_,'"Y?KF$NV[79M2'!^*8*TD\C5"/VH_DU0K9D(3\VX+:8MO8U0K:`MB6V
M9+8[MD<C^[8FMAFW++;'MDZQJ,;^M0JV#[:DP#"V+[:LH0*V73;XMNBV56AO
MZ/<UX+;V-?FU1+9#MDNV2;;LMH$VR;;$MHBVB;9IMCPV^+9@ME^V_[7?MEJV
MG+:2-B#%E[;ZM5,VR;:KMFI/H-]5ME:V=+9605?!>S;S6AE<QV6,YOBU;K9%
MQ:TVS3:EQH8CKR/&MM:VP;:"MJ0VI<:&'JW'J+94MH8CI".O(Z:V&;93-H&V
MI$!G0?-!OL>DMA&DI[9HMO<U/[8]ME*V0#VL3*]NM&ZY[O6V\[9F'CPV7;;Z
MMOFV1R,'MOZV_;:CH=8BUZ(:G^C8%[<6MPZV(K<?MQZW&[?GT#(I3;ESHB^W
M+C=3V$/(.#J/NC:W-;?@(5^ZNKM-6=%FW.8I.@J[?[@LIV8W&3F&NJC@T[F=
MN`.XAI])MTJYJKEN.,/&D:`<GKHN@#>I-]<WI3@&Z\;ENBY^-ZDWUS>EN'6Y
M!C3+N6"Y*QY@.`\Y,+G;7O9>;=_3TP6Z7;@>NM>XZKH,N)BXUKBZ+GXW@#?7
M-Z6XS3F78U/D4[F?N/`CKSH<T-`R^K<GN#72(KA9N;HN?C>`-ZDWI;C#NKBZ
M^[<;(_ZW2*D!.'HX;KH%N/^WT#*TM^6WB;H;(^FW^;>4N/,W>CANNF0WU+JN
M.6/3];<9NE\XY[C;NMXY\[K?N*8WZ+JJ.M^Z!#L7NSFZ?S/RN-,A1+$*HL^W
MN[=#.D_+V#DCNHC9'2<2NW^Y4R/5N5*X4;@.N3$Z^[JAMP@XY[@K'I(W#[E(
MNFBYE+J_N=<Y2[HZNIRZ\[D!NC.Z;S?#Q@.Z\S<!.&ZZ!K]&MQ$Z%\SQN7,Y
MT;F!1H+&`+BGMV&WK;>Z+GXW@#>I-]>W(BDCJ48SD<VNNO:XY+D<.:*Z'KL#
MK\LXL3K`.H'(RCBQ.L`Z@<@VN:BWH[<+N`JZ"#A?N!S*?S,6N+ZXPKJ7R.BY
M5QY8GEBX*QZ2-V"X]$>'R%JY2;?`.**ZW;KGN?:Y#[L_NF*ZDK=NU-6X6M1H
MMS(I++>KMV*ZU;<8N8^WAKEFN66Y8KA#PIVZ&IZ%.-&Y@;<3NE`>`KI"N!:[
MLKEAN>RZVKKX.@6[4\)R+GFN/K1IMP0X8].%N4JZF.%DN-FY*%"2XX2WJK>%
M.'.Y8+?Y.7"Z4R-,N&4X2[HW.".ZQ[F?NKLZ?\X*N+.ZY[J_N""Y`;F$N&BX
M(KG4N6FX4!Y]N7FXGK?EN-.Z@3@7S,&Z?+D'N**W-SC8N4,W"KMK.LZZHSIB
MTEPX^[IJN!L>XB,).\+5-#>/NA&X9KA'SRNY,#A/RV&XM+EE.->Y.K<M.56Y
M*CK.NO,W`3AZN-2YY;K3.F-2:M+>NJFZ_;I)M_VW-#<XNC?,8[B8.A?6E[IG
MN&NYVKG`.!RY+[J!N@XXW[J\N/`CL;?*.,LXP#J!R-^YX+?;N<HXRSBQ.H'(
M$KKYN-RW\Z$PT"HZ:[H0.GFZ`[@1NXBY";@?N7RZ#CBJNG&ZX+D,N*6WA[D*
MN(FY'KM<.#&Z@[H/.!>[B;D;'N(C-SK"U4,W*;HDN=6Z'2<^N(2Y#S@$N\%@
M,&LQZ\(X^KHZ3SS/_3%3.V$[:>K]']XP(MI?NU"[?K$^NUB[IN0UNPS;^2,&
MIB>[(CMANYPEF#&9L3N[6S6"M8&U)+LB.U.[:#MINV4[:;ME.VB[3:(+/H`_
M@;]2;W_OEQZ!+%<M<[N7'H$L5RURNX8CKR-WNX8CKR-TNS`N4B^(QGJ[>;NQ
M.[*[/2=_.X$[H;P])WX[@3NAO"VI/2=^.W\[H;RDNYB[GKNNNXN[J[N2NZ^[
MA[N:NY.[H;M\.[*[?#NQN\:[1[%`M_,HO+OS*+N[P;O`.^Q!;=M"W[2[.R.K
MX<^[SKNR4*S8-JEBQ=B[U[N#M>Z["+P#Q-^[_[OUNV9"F\(,O.$["KP(O`>\
M%SPC/('`%#PC/('`\.8KO!0\%SR!P"R\(KPIO#.\,KPU/#J\-#PZO,P>JR&P
MH30\-;PO(UDO6B_9OB*_V[Q:/&&\63QAO%D\6KQOOG2\<[PVO;.A^+Z)/`O`
MB+RAO+*A^[V=OCTG?CM_.X$[DKS]/*2_0\`:OQW`ZKW$OB*^6;_L/@3,.^:R
MO+&\U+\1Y[6A<1]+P$Z\K[[8OVVG.]J9/=J]NJ$SJ:F_W3XGP!C`_+\)P(P^
M43]ZQJ(\I+^'O52_O:%1P%2_>;RJRO*V>;WHO?J]/[^&OUZ^KK[!ORR^KK\(
M/M^_H"8/P/N^/K[XOL._;[_<O^@^\3_UOZ._@C^$/Q/`E+]#O<*APR%7J'R^
M_KP)OF>^A5.>U.H\VKWDOPX^!L"'O_:]([]_OR:^L[X9OLR^9+^7/P#),K\+
M/H`_@3_'OP2_Q:')H;&_?;[SQ<2AZCR9O0R^P"%$O::\;"K;OGN^YB8*/A6^
MGKT%OD6]E[SXO32^3CW?OXF]YB;U/16^;CNI/8`_@;_EO2R_G#T&P#B_H+]@
M+:H^/UQ`W`&_YB;U/0J^"\#ROJ.]SZ&HO*&]J[Y+O0>^,&!*X%&]T:%(O8R]
M9+SSO86]Q+UCP+P^U;_A/O^^VK],HG"_^K\*OQ&__#Q1/WK&M:/;/YG4QB'6
MH9&_G[Q@+1,^/UQ`W"F^2;W=/&'@HKV4093C?S[5OZ>\;<"DO673=[\O(T>\
M_K[KO?<\)\#OODY`5$!GP$3`@#[_O@7`_K_KOV3`7#WQ/_6_6,"FOZH\!,S>
MOA>^9".;/P+`>SQ2O5"]VKZ`/N&^%+ZOO7RXA[Z)OE7`I+Q)O)^]>1Y^'H&>
ML\$-OD2_J+T0OD:]C>@QOTS`(,`?P#+`\+_\/(P^>L8!/2^]J;Q</_._6S_S
MOZ:]5+V#OB;`U[Z@O6X[J3T+/H&_;CNI/0L^@+]G/80_$\!G/8(_$\!'O9V]
MG+YIO:>]L[]D(_<^`L`^P-LAW*$1OF.]HCS]O.J^]KQ-O3+`P+V:OTJ]4[VI
MO2A`+,`5P+6\?SZ\OMZ\@3XOP)4^F=15O4X]"+Z;O>6^3;]</>@^];];/UR_
M7#WH/O&_RF44YH6^^KSDOF0C]SZ;O^*^G#T.OON\B#P6OD^]9SV"/X2_TK_X
MO*6\1[]&OW2_]SS=OM$_+,#1/RC`VK\EKTL_L+^<OZ.\X+YQ']6\1;_?/E3`
M7<`2O=\^3L`3O^F^3\!^ON:^W[[%ODDAE\#(P0IG&V=(Y\-*R,K^0&3=?D#6
MP'U`UL#FP6S!%#P7/".\$$(I8FKDS2/;HX_`CL!)(6[`4L&7P2TVS#9G0?-!
MOL<R2!])+LGQP#G/WNXZ'C+"24$L8TKCOL$-PM=!&T(DPO3`;,%,GGU`?L#M
MP5G!:<$\0=+!P4$7PO3!V<'\P;'!K\##P*+!>T!DW;?BWB%508A!F<&RXI^>
M,$'$P67!W,'^P<Q!T\'@M3/!8L$40<3!)L'G0-+!6^.\0"QC2N-NP9S`WB$(
M08A!F<&6MI:VW\`M0173%<',-J1`\T&^Q^;`@$#*P%'!?D&%P71!A<%T07[!
MWB$(055!F<'[P6?3MCZ4XYW`WB$(055!B,']P.W`CN@KO[K!N<&]P.A`%\(4
M03#!;\`:0=/!'JSW2*;,YT`\P1I!S,'P[<)`&T(DPNO`%L&V)274?\#!N]O`
MS#:D0&=!OL?IP(_![,`8P0#0P<")P.A`P<'"0-=!),+"0-=!&\*)GANQ.AZZ
MP"NU.L(WPLZ?$BP3+!2L+)Z*KFJYB:B9J#K+6,)50I-*ETJ[RIRY3D*32I=*
MN\I-PES"6\*#JP(\F\(0'Z"@M;)]PJ!"I\)UPH+"@<)4J:+"9M,"/&;">D*G
MPHK">D*@PJW"K,+0HWK<>UR+W,#"=\-!PS;#ML)()(*R_<)^W"G#;L-PPXG<
MAZ]HP_G"1<-JPQG#1,,[PPU#C=SMPLC"&,.-L&O#4]:.W/A"C=P?0W7#?,/^
MPO#"#D-UPX##/\/,PFS<D]Q?UWO#DMQFPW'#N<+RPBA#;]>XPO'"[L+AXU8I
M:"ELJ9C<GNY9PUC#?2%XPS+#[,+OP@-#@<-ZP]W"WL(UP[?3#D,?P[?"?2%C
MPVW#+L,5PYO<(<-KPSQ8G-R9J5NCH\2UQ%+$:L3/0W3$Z\]+Q+#$_L-RQ$?$
MO<0)1&!$HL3.P\W#J$-TQ#K$S\0T1#G$G2O:*_,K]JLMIZO$CD34Q#_$E,BP
MP^R[;\3+0V!$HL2#1,C$H<2)Q!%$8\001&/$U>;A0SG$X4,TQ-##RL3RP[/#
MKL.:PZ_(RT,)1*+$$$01Q';$H<2YTYO#!<3,Q+'#J$//PV3$IL2XQ`U$R,2_
MQ`_$\4/4Q`Y$:,3+0PE$8,21PW?$\,.OPYG#>,30*+K#A\0-1(/$VL0\Q'#$
MT</:Q/%#CL3)1-+$`:\XSQ7%#,4!13[/!L7V1#[/]\3OQ'PH%DC:R.[$0D],
MSQ<FD"8=K'2VIQXCQ:<>(L5,2L]2!]:!*\TKU2O7*]PKYZO[YKV?(B<\Q1(B
M@R*0(FM%=<4B)SK%3L5=Q5E%<<6BMJD>4D5=15[%%=`Z*$W%.BA,Q3W%8,6I
M'D9%745>Q41%<<59J:D>0D5&15)%7L6I'D9%4D5=Q5'%DZ?5NV?%9<5JQ6C%
M.T5UQ0*O1$59Q>`C@D6)18K%A\4[16O%4Z^%Q4VHX"-S18E%BL5Z18;%A<5T
MQ>`C<T6"18K%X"-S18)%B<6/10C>CD4(WF3&0L8GQEC&#<:LT&?&,L8AQ@O&
ML$9DY_[%9<9PQMG%8L;1)!8E7B4"QLG%1L8FQA/&1\8YT?-%N^[+/?)%N^YA
MQOK%^<6TQ=$D%B5>)=;%2<8NQ@@Q4L:OQ:'%ZL61I1[&.\87QJ[%1<;IQ9_%
M7\9QQ@;&K<4[QAA&.L9NQFW&E\7V*I2Q),;HQ>O%!<8(,0G&<$;#T:#%:<8J
MQO3%TL5LQI;%Q\6LQ5[&<L9CQC_&/L;>T<A%54;#T2O&:\9UQG3&T2/H,J4T
M_#R,/E$_?$9F89=AL>'<H-$C>L:-.(+&C3B!QHS<,"Y2+WB[D,9S(WVCR]R+
MQIK&TB&1QJ'&GL:D-JVV'[:Q163GNL:X1KG&$^^R1KG&LD:XQK'&$^_(QF\W
M;KC-QL'&/4]B8K7DE\C'QM[&:2A][N-&?-MB5,O4W,;DQB#,U\;/QCVLT49\
MV]C&8J-A4R_6_QXCH$+'OR,CSIC'EEG&V4ZQ'\<>QR;')<<OQ]/'*T>'QV#'
M41X7'T;85]1<QPG'\*9>Q[S'0<=0QS?'9<=DQZG9X2/AJ,''ML<OQY['\\\-
MQY+'JL?2Q]K'H,>&'KBVV<>&QU''S#:D0&=!\\&%QYG4HL<LQ[#'J<<VR^='
M(-JOG^1'(-KOQ^O'%SF'2/C([\@LR3]()DEQ8MMB6^2MR+S(Q\B.R'PH#D7:
MR&C(;\BXR(ZCJLC6R*Y`'TDNR2K),<DKR?]')DEQ8MMB6^0.R5S(,;>IR&3(
M_<C1R`3)0<A6R!?($LG&)[I(N\@:R.#(>&Y[;GSNRCC+.+$ZP+H7.?3'&<D5
MR/?#_"<.+5RMYB<`.<S&Y\CCR*DL4BU3K:CG5<@GR`#(6<2],RO>>&Y\[AS(
M;DB[R&Y(NL@!R"#)$LA9R)7FAZ,LR'PH#D46R'7(G,B;R/;'T,'TQ\3N5\BG
MO5K(:69Z9JKF8"><J$#(:LB-R*Y`,D@NR<'(_T<_2'%BVV);Y#K(/LC^QZY`
M,D@?R3O(.\DZR:[)M,FIR:')EJF5R=C)L,F.R4:SL<F-R83)'\I_R:K)>,EO
MR4[)0\FAKT#)A<D\R6+)=\D_R>+FP\FVH[_)",IZ4KA2'U3Z5-W5?,QTKLQ)
M4$JF9Z=GG>_+25!*G>\NRAC0"4JSS(/,ZJ/KZ%7)3<HQ2FK*+<IBRF#*/DH_
M2L%5\]4.REY*;<K&R=1)L\P%RKI,K=4Z2DG*\;B`R4S*^,G-R?!):LH[RD]*
M:<H:2DG*,LH!2C]*P57SU0%*/DK!5?/5TTPWW%?*ATS@S!I*.LHF12-*SU('
MUN_)-&B6Z#-*:<K+2<Q)G>]ARD+*!DIMRO[)4<K]R7#*.6@Z:#UHD^@S2D_*
M\$DQRK?3!DI>RF/*KDK&RH:K,>:*J\K*L\K%RK7*KTJPRDY"54*72KO*3D)5
M0I-*N\K$RJG*NLK'RIW*/+TPWN`KMLIW2L;*D4JPRI%*K\J*RH[*X"NMRJ7*
M3D)50I-*E\IV0,C*G,J-RG=*KLJFRG9`P\J#RD>IZDI.W"N?C6^2[R8>H2!V
MKO9*^,K?G[Q:"MS62D[<WDKXRMY*]LKJR^3+34NPRW,ALJ1&RV?+C<N*(8PA
M1S562UY+H\M3G\1+`]/BQTM"B\OM2V#,:<RRRQ3+U-D+2[#+,#A#NGK+R<M'
M-2=+7DNCRP;,@LOSR^G+.<R/RT<U)TM62Z/+%<O@RTS,4,O4RSU,5DQDS.#+
M(<Q9R^;+]@`J'@N@.LL?RUW+&JY9S(2B1S4G2U9+7LL`3#;5R\M<S&[,'LPK
MS-O+"TM-RT7+@M(U2P/3@]11RR<CI\M,K2/,#<Q\RT;,K,MQ2W_+$LP#RX;+
M6TL!3&W,_LH\2V#,0\Q;S&S,5Z]:RZ9+-M7I2VW,JCSLOEC+T\L43-'4X<L1
M3-'4:LR!.!&Z*\RJR]G&@,O1RT*AJTL8S-<U3\R0NES+?LL8KE),5<Q?S.[+
MU\MYR]<U,<Q8S$#,KE7JU4#,?DMDS%!,Y-63R^_+J,M!S#Q+[<M^2U;,/LL6
MS/'+Z4L!S*G+`22E[_3,7NC(R=7)14K@S+G,I.[/[H-0A=#VS/+,M<S\'SOK
MT,&&*9TI)"K:S-[,\C:O;K1NN>[GS-1)"<JDS(O,%\K)S-W,8F>J;JMNM6ZZ
M[C'IO<PLZ4!*-]P[Z88IG2DD*J?,P<RJS$5*A\Q.Z:[,XB;CIIW,=,R<S!T>
M^4QR39_.^$R?SO[,PA\83DM.:\Z?(O_,^DR@SI\B_,RJSJ/.ILZBSJ'.I<ZH
MSJO.N<ZSSKW.OLZOSK#.O,ZQSHM-KLX++KC.I\ZWSJW.34VTSKK.M\TNS<K-
MHDWXSDXR)<TR3HU.G4XGS\;.PL[!SL7.N\[-SL#.R\[0SLS.R,XFK\3.E\W*
M3GWG%:ZISI--S\X=S=?.P<[3SJ<T=DW=SHK.ZLTG3N;.U$ZTV-[.W,[:SJM-
MVDV_3A#/+]/9SM+.ULZ"3=_.'1[XS-O.:D[8SJ<T54W=SC;.;4X2V.+.T<YQ
M3=_.X<[@SNC.X\X8S>3.Y<Y&,[&X3$W/SD7-?$[GSHQ.[4[AW/S.#<_13?_.
M+$WXSOO.9$W:3;].$,_VSO3.^<[^SK+.4<]#3O?.U2,`SVFO(\VVSOK.[L[]
MSEM.\,[KSO7.\LX!SR?-[\[AS3LP8#3K33W.0<Z@3?_.UDWJSO'.@\[23>K.
M`\\$SP+/9$VK3;].$,_US@G/#L\4S\U-%\\!3AC/$]D,SQ;/$\]:S3LP8#3/
M33W.!<^LSA'/",_#S@_/!\_TT15."L_C31C/:4[SSB;4&<\BSQ+/R<XCS_Q-
M"L\>S_M,2TYKSAK/',\?SQO/OR,,QS%.M<Y;3>;.3*X=SR'/*<\F3K7.+TV=
M3B?/I,XFSW=-O>D5SR7/.S`#-&`TSTWKS>G.T,VS3??.<$XKSRK/9LZ.3I9.
MI,[[3!A.:\YA3N/.+\_'SB[/'A^8H/O/+<^]S=7.34[CS@O/@LY(S@1.\\YU
M3=C.^TP83DO.>$TG4Q+8,$_!YS//14XK3S+/-,_.SIE-Y\XDSS'/V[EDSM7-
MH^@LSYA.-<]63:G.FDWM3N'<+\U*3I9.I,Z23B#/CTX@SRC/3;)*3HY.I,Z)
M3C7/!L\O33).)\_X3/G,_LP&S07-`LTT3DI.CDZ6S@?-!,T:S0C-2TV*S@#-
M"<WOS1S-&,T4S17-%\VQS0W-'<TF3C'.N,T;S1G-"\TAS37-%LT0S1/-9$VK
M3=I-$,\ZS3)-3\TQS?3-1,TSS3#-5,Y"S1#.1LT\S4#-.<UYSDQ-D\T_S8'-
M:,U0S5W-7DYVX'#-3LUU36K.9LUBS7/-8<VG-%5-=LU>S7%-@LV&S8/-><V)
M34U.8<Z,S8_-6TTGSIE-?,Z(S3[.TDW6S;[-FDV,SKK-R\V]S=3-Q,T$3FG.
MK<V_3=S-K,VS34/.+$VBS:_-N<VCS9S-N\VPS:!-T<VTS<?-V<W7S=C-[,V<
MSOG-\LW=S?Q-%<YBSN;-GLW>S?;-9$VK3=I-O\[QS0O.Z<W@S3?.Z,WAS>--
M`<X)SAO.'\X=SBO.%\X>SH].DLXMS@K.$<Y]SCG.-<XO33).G<Z3SB[.1LY%
M3G#.B,Y:SE7.4LYN3L'G?LYPSF_.<\Z)3IC..T]03W7D>*/HQ+#`(#L\SS;/
M(#LZS\M&8F*UY/9$`<4614S//;I;)[`HM2C<*$[/%D5"SULGL"BU*-PH2,\V
M3W7DLDU23U//44]3SU%/4L]P)<DFA<]P3WC/=\^#-J#?6D]XSX;/C"#A:8+J
M@,]BSUI/<,]VSXA/BMFJ(4*N5\]TSXA/B5F*V8%/AT^)68K9B-*(TI?/D<^0
MSXS/I<^HSZ3/H\^?SZ'/29Y[(0KIN<^V3[O1M$^[T:[/Q4_DS\1/Y,_@SV">
M^<_]S^S/QL_$3\7/J</:S_K/EL?8S_'/64[<Z-G/_\$WM0C0!]`+T`K02L70
MR;&W!.4NT,G5+-#(.9+C)]`BT,RZ<]!EL$/0K=Y,4'=0Q-YVT#S0?M!`4'=0
MQ-YYT&A0;]`C)ZFG^^7[*'^J9E!J4'#085!J4'#05%!OT'7085!F4'#0;]"_
M*B>Q;]!44&A0:U!NT&%09E!JT/"H.-`L)'W0:=!"T$!03%#$WDW0+"1TT$O0
MFTR%T)M,@]"(T(?0C:NOT'A1D]$UT9K1VM"CQ:_JCE"[T+>CTSNLV!KIK]!.
MT6O1.=$%40=1"]$W'Y&ANU&]T?FSI]#=HEI8#>LGMU;1VM$;40'>V=&@T091
M.M'!4`O1`U$ZT<'0"=$(T<%0!=&^T=-1WU'2ZLW1,U%FT;_1X-$[I'-1"][K
M4`'>!Z7NGS'1*]$8(Q%19M&AT&'1R='N1<#0`U$&T5?1#J#(4=C1@^&^T.C0
M/M&5T:/1-M$8(Q%1,]&_T';O2^@:40O>H%"3T:G1@]$PZLCJD-%]T8+1S]&@
M4'C16-&DT/;07]'5['O13>G$:M/JM$^V3\90O='&4+O1#=$3T<O1549PQDI1
MV-$XT<#1$-&14=7J#U'?T4I1R-'MT.K0XM%OQ@]1T]$4T=S19Z,TGO#1[='[
MS?`C;J<_WPZ>=*$^'ADSY[3GM6@S#M(-TA/2$-(74NIB^N064NIB^N0HZ632
M.=([4FO29M)9TL&W2M(ITBY2:](VTC'2+[IY.FK2(](PTGDZ8](N4CO2<=+/
M)G#2=E)W4E-<5-QS4G=24UQ4W'-2=E)37%3<>=)XTL=)N%(?5/I4W=7`RXI/
MB\^,THO22:.,U6K5!M:RTK'2QTEZ4A]4MU3Z5%-5W=4-HN_40AX(HF;4]M6G
MTP?4O-3GTLPF)D5,2@=6$]91T^+2X=+.TD"@LE4+UI/3\-,U2\3+>2$RTY;3
M(M8FU4NH8L%4TVU.$MAES3C4>2$*TTK3E=-&TY\?IM70TAC3A"Z*TYC5HM-8
MU?W4--1.U8C5%52ZU>I&:54OU@0XKKEWU,Z^EL*2P4'5SM7`U"W54M52U&34
M;U2L5>751MQ7LQ#5ECV>U(0N6-/ZTD?3#M,-I5K3R](*U.[4E-0UU-_3G]5R
M0VO*5=5IQ"QMKVT.[I-4]-2^T[W36-2<MUPC%-6UTP>H3B,++5#5_=(&U;4N
M2E3MU$74S-*QTR#4\=1@4[K5`-8_UL=)>E*X4OI4W=4,U,U6HM>V)=_!",YM
MU:G5!YY_5?Q5$-9=T[33,--:U?G3]J.U+O13[=1MTT#'T=,YN9/5UD;+U&[3
MQ]**U5^H-+EOTR759-,5U<;+1M5BU2/5'M4<M+Q3]-2ST]XQE3[;/\?'ECV%
MTV"O,]6XTLW2:M,MKM9&8M013!3,S=6*U3K6=]6CXT#JM2[T4TK4LM/!T@W4
MO%.3U,=)>E*X4A]4W=5<TXTI^*GQTWO32MA<(]33@M2,U(O4<=01TVO3O-4[
MU:C4N^XH(\_5IDL`S)35'M;ZU3+5^55JVVC3A]1+50+62E4"UE[33B/OTVS3
MN-*XTUO3/-2)U&'3G-(GU(#5!-;T50K6X]0Q5/Q5$-9PU5_3:E3?U)?2W*E@
MU#?5[282IUG3MM.?'U#3*-2P50W6;U/EU1?*5$SJU??5JU4-UOE2"]9@4Q74
M+]4!2CY*/TKSU1L>XB,W.@F['R"C+R30W=1ITR@C-=4:UL=)>E*X4A]4^M0]
M5D;66,QO4ZS55$RNU0%*/DH_2L'5=%4*ULC2K]4\56K;.M4Q5']5$-8:U$I5
M2]5RU:;2)D5,2L]2$]9T5?35^5*RU:M5L-5E:J7J,51_5?S5SU('UI>ZT]4Y
MU0_3<*'J1F'3X-3?54;6'=04J=]5/=95'EW67-9NL0?#YB$$J7RD6E9;UE=6
M6]975EK63]95'D[6]Z-FUF76CYYZ5O+7;];CUVS6:->#*\?6:]9QU];F9M<&
MV%77^]>>UP'8H5?!USG7+]=%5S98.MB(U]36%-BZUHWL!M?4UJ;6@RMUUC'8
M)%2BUP=8(]CVUYA6M%86UP/O.]BGU\37^M;OUX37$-CQUA77G5P=W2W8K-:"
MU_O6U-9XUTM7']B,UHO63NN55C98.MA_5P78R-?LUR%7']@-V(#6+,,5V'[6
M<=8_PWO6%]>[UQ'81U<%V+_7"]?SUI;6CM>-U_O7)U@YV(+6BM8D5,W6E#6>
MM>_6SM=\UX#7BM;PUL?7QM=(UZC7*-@.V&[62=?RUFO6S]8AV`_8@5:8UX/6
M1U=_UW_6SE8CV$[7TM?YU_36?M=X36U.)].=UF'7(5=+U_C7][#.5@?8F5<Y
MV,_7`M?*UI5615<ZV)E7)]B55D57-MCNUH-#G-Q$V$+8P>%1'A<?/L>O)("E
M$=4OMV,E6%B<X@RD]ZUC)518G.+AT&LC7MAU)E]84^"RH6LC6]AU)EQ84^!D
MV&/8W-@VXV_9GMCJH[785MG+*ATKRM@8V1*N:EG(9^3G;MC3.[+0<MGY[D_9
M74WDV'W8S-C=V&#9#-F%V+?8X5C,X>#89=C%V-G8SUC,X3/97=FT6#+91]D2
M64/9![<KV?78]-@VH@VI_+#(V`_9#MGF6$/9Y<V&V#C93-GMV.38XMADV1O9
MM9[F6!+9Y=@=V4*WK]ATV838X]C&V#39G-A&M/>T;-BMV%59?=ETV60C9:,-
M*:FO..<XN(=/B$^*V8%/AT^(3XG9P=D!K\/9Q-F:6;I9R=F46<79DUG%V0Y'
MQMG'V9!9NEG)V<O9S=G.V;U9R-EYQ[*>RMG/V;?9T-G`6<+9O-FP6='9C360
M69I9R=FVV:=9R-G,V;-9PMF+V;-9P-F.V8_9DUF4V0Y'EMF8V:=9O=F069I9
MNMFLV:'9O]FEV:;9K]FRV;?92\OO6?;9M;+TV>?9^-GCV==9]MG>V==9[]GF
MV?U9_]GY6?_9^5G]V0%:H-L`6J#;HMNCVZ';K]NGVZC;IMNQVZW;JMNKVU@R
MK-NPV[[:N=NVV[S;Y$?GQQ\D5J8CN\#;M]N[V[_;X9^^V[C;;UO1V\G;["3#
MV\K;Z+Q)6\';;-K"VV<DR]MJ))*D;:2UV\C;TMO/V\3;T-O'V\[;Q=O-VXO;
MCZ3IV^+;X]O5V]^KU]OGVSU:W]OAV^#;V-MN6]W;Y=OFV]S;V=O6V]3;V]O3
MVSBI?=L$V]>OI-OSV_;;WMN6,`*Q`"7QV^[;[=O:V^O;[-OOV_#;]=ORVZQ:
M]-NJ6O3;@%O[VS&E`=S^VP?<_=OI2@K<&MH#W`3<!MP(W/_;]]OK6@_<Y-OY
MV_S;!=RZVP+<`-P-W![<'=S\6A;<&ELEW.C;C5L4W!O<$-Q<V\Q:#]PO)!@E
M4R54)5\EV>45W!C<L]N7-AG<#-R]6ZCH^-L:W.!:%MSZVPO<$MP3W(K:S-L.
MW$R['-PGW!'<(=PDW";<X5HEW++;(MPA6R/<(%LCW!_<1J6!6RK<+-Q^6RO<
M^:6TVRC<?"01IBG<UR0IICQ:P=NYVS+<I=M"IEM;+MS&VR_<+=Q66R[<Z5HQ
MW&JF/%7YU6$F-=S!NW%:W=LS6M';KMN$I9-;J=LTW*2RZMO11N/&B=HM6RO<
MK5K[VRM;*MR:6U[="=S8(PFI7]JT*[SAY%H4W,<>D%O@YHY;X.87W');J=LP
MW#;<@UM>W2#<,]P`6@':"-H"V@/:C=I/VQ#:#-H.VG);D]L5VA;:6#(7VA/:
M<-L*VAC:$MH;V_':,]M.VAW:)=HQVAM:3-O6VBG:']KW6JCH+=HJVB/:/%I)
MVT':-MI5VEO:6-M7VE#:--HZVD;:!=M>VEC:5-I6VC-:;]M2VH;:A-IFVG_:
M:=IPVGS:H-J%VG7:<5INVY7:;-INVFW:8MICVLW:<MISVFO:XMIAVGC;H=JC
MVI[:FMJ>,*3:I=H`)9C:J-J1VJI:K-JFVI+:R]KXVL_:_MJM6H#;T=JYVK+:
MR=K;VK#:U]J_VL+:TMK$VK;:Q]J%V^E*O-H`V_;:W-H*V\Q:Z]KGVA3;`=L"
MV^1:C=OMVN!:_-J2V^[:ES;SVOK:YMH.V][:W=HHVYS;%ML=VR!;(=L7V^%:
M&ML9VQ#;.=L^VRM;@=LM6W[;+-M:VU9;6]M9VY7;7-M.VY[;=-MKVY;;0$K3
MS(BL$SZJ/D#<$SZJ/C_<<]."K#`>4%P[9TKGUDKJRC`>2EP[9TKG<U)V4G=2
M5-QS4G92=U)3W%K<6-R'W(B>*L-VW&[<LL*TPI3<R<(F[V3<XL*TPH/&^$(-
MPPK#+\,KPWS<3\-^PX-#/-C]5AW='MU8).$D(-T?W1TR(MTAW2O=)]TIW2K=
M+]TCW94BZEPHW1`OLUPPW2[=,]U`W1`OKEPPW37=+-UPGC?=-MTYW33=.]TX
MW3K=,MU"W4'=/]U%W43=/MUY(V2P/-V.QA-=0]WD7#'=2-U*W;XKU-R^*]/<
M1]U*W5+=2=T*75[=4-U/W53=FDV,3E/=$ETDW58C\JC.7#'=2]U5W94BK5PH
MW4W=)MU,W4:@5ET\Z%?=35U.[UK=6=TMW5O=7-U7-27=/=U8W5_=8-W;7%[=
M4"`775W=8=UBW4;=XEPDW<U<0]U1W4[=4"`+75W=8]U#W?U6G=R>W*#<6"3A
M))_<HMP=,J'<K-SB7!+=5S4!W>S<J-RM7.K<J=RJW*?<MMS\W*_<J]P0+ZY<
ML]S.7.3<P=RPW+S<M-RZW+C<O]R[W,#<O=S*W`3=R-S$W++<P]S"W,U<$UT<
MW<?<Q=P0W=7<T=S:W-)<UMSFW.W<ZUSW7$[O%MW>W-S<%-W9W.'<X-SGW/1<
M/.CUW`7=^]SZW/W<_MQ0(`M=%]V#6YI;VUP*W0?="-T-W0_=&]U[0/[`;-UJ
MW7'=<-V9W97='RP@+*YK>VR<[-_?@MV!W:C=IMUVW77=D=V+W7K>PUV-WK+=
ML=V)WCC>KUV-WDS>DM[YW_K=*=X0WH+>>MY5WIK>Y=V+WD"LZU`;T8Y%C\4T
MWAI1<]&*WO7=9-[TW63>L,B3WI'>K,H*WKO=3]YY7J+>Q-U$WJ'>8][XW?G?
M4MXH7BK>BEZ5WDM>HMZL7??=I=[VW83>@]ZXJ+C=#%YP7I7>^UVNYJ]=P]VJ
MWB_>WMTLWG!>BMZJWOG=IMY1WDM>>=Y_WIS>CUZ9WK/>/=#`WE,?QEZU:M3J
MLMZQWJS>K]Y`4$Q0=]!3'[!>M6K4ZF;?9]]HWYNA:M]IWVO?F3?V7FW?;]])
M7VS?7U]PWW??>-\I7XC?<=^9-]M>;=]TWW7?>M]RWW;?%5][WWS?7-^#WX+?
M@=^`WWW??M\;7X;?-M\97X3?/;/,'X7?_5Y[WQ)?A-\,7X;?.E^.WXG?B]^-
MWU??BM^'W_!>B-]NWXS?;]^1WX_?#]^3WQQ?CM^0WY+?E]\&TK%GW&?LY\*[
MEE^+XY7?F-_B7FS?F=]_WYK?(=\`W^-><-^4WWG?<]_*WLO>S-[2WM'>U-[B
M7DG?F3?;7O;>*M_?7BW?XUY?W_+>^]YDW_C>^=[\WN3>Z]YBW_K>_5X5W_[>
M"=\*WT[?"-\'WP7?`]\27QG?%-\,7QO?)M_P7BG?'=\EWQ[?+-\?WQQ?.M\S
MWSO?+]\\WSC?8=]%WT3?/M]&WTW?5-^>7Z1?K=^=7Z1?K=_BY8,V:L\!+ZE?
MK]^=7YY?K=^>H@$OJ-\!+Z??`2^A7Z_?KM^=7YY?I-^KWP$OH5^IWYRAMM^U
MW[I?B6"*X+E?B6"*X'S@.6!4X'?@P]_"W^3?3N"!X!TC`*Y+X(3@&>`RX&#@
M5>`CX']=16!RX,;?"."'X/BN@*\#X(0OD2\5X-@FWB;L)OLN_2XEX.%=7]Y#
M'ORN:>#OW^7?>.!<X%+@$V!>X!)@7N"$+Y$O\]_9W][?V";>)NPF^R[]+O3?
MD.!4J3@^2N!HI-O?OE]4X&#@C^!JH&_@WU]RX*8?=:`X/C#@T-_'WP[@=29<
M6%_8OE\YX-W?>N!EX`K@$F`3X-Q?.N"OOEG@`N!!X-]?1>#5SL'?">!7X+W?
MR-_8W^G?N5^Z7XK@N5^Z7XG@.^`FX!WF)^$ZX:O@4;>FX!3A]>`2X33AN",P
M8:/FS.`=.S!K,>N]X-)@WN#?X#;A+>'.8-[@!N'.8-+@S^!(X1;A]N"NX.C@
M81X)80IA%>$RX=/@81[W8`IA%>%A'O=@"6$5X;G@K.!A'O=@"6$*X>?@D^#1
MX+@CNV"CYOC@NN#0X$;AG>!'X9@CY2C;KD?A-^$\84+AYN`CGI3AB>&?M99A
MGN&+X7I&EV&QX6QAN^'@I6=AN^&D8:SAQ>'#X;AAP.%,T97A5.$?Z6+AN"1Y
M[DOAA^%=89[A>D9F8;'AO+D1'E?K76&6X7%AK.$[(\F[<6&DX7I&9F&7X7]A
MP.%G86SAM"N,VW]AN.%%V'[A?>'`*Z&SRF'+X<AAR^'(8<KASUCAV-PGQ*B8
MH])AA>31887DVF'[88;DA^2,Y``B`J**Y(GDB^338?OAX>&(Y'$>@I[<X1]B
MD^20Y&.RC^22Y.GB42)C(G$BC2*.(I(BE"+\X9?DC>25Y([DTV':88;D42)C
M(G$BC2*.(I(BE"+PX:_DJ^28Y*WDI>1;8L7DFN2@Y)WD9&*IY*3DH^21Y)[D
MKN2>8J?DX^&?Y)GDK.2;Y*KDNN.)0&KD.&3.Y&ABS.3(Y+;DP^2TY+GDS>2P
MY+CDP.2_Y+[DE6+H8B%D-63!Y)SDN^3*Y,KDR>0H(L?DR^3"Y+?DL^3&Y`9B
MQ>2ZY$CCRT8]3[7D#F*IY++D+F+,Y+SDO>3_1S]()DG;8EOD<V-19%)D;.3/
MY/#DTN3LY.KD]N3SY-SDVN3CY.CD1&+H8B%D->3BY.WD0V3KY+UBYN1C)518
M6-@>XM'D]^3QY-_D]>3EY-7D[^30Y")CL>1^Y-[D"L'M8A#E!T$`Y0CE$>4)
MY9OBW>02Y0SEH>3DY-?D"^7[Y/]'/T@F27%B6^0*Y6]D$^6!8]CD!.4#Y13E
M1&*58B%D-60'Y>]AT^064A=2^N2S8A#EUN0&Y0+E_>1$9/CD#>4OY:+D'N55
M+S+C%N4KY2GE&F34Y"7E%>4?Y23E?V,QY>[D&^4LY2WE'.6M8K'D)N4:Y2#E
M(>6\0$E!2N,BY1GE52\$XS#E:-B&Y/SDZ.,=Y2CE*N64Y#3E8&(SY;Q`24$L
MXP7E0.4WY>'DEN1%03OE_^1%9#WE..4RY1CE.>738RKE/N5T8E%D4F1LY"[E
M-N47Y9]D.N49X^/B0>4_Y47E4>5$WRYD<.7(.2C0MCZ4P<%C`>6JMTGE).5(
MY4-E$N^HY.74`F1/Y>#DZ>0\Y5#EKF-'Y:UC1^52Y4WE4^5,Y2CB3N66XU[E
M7^7^Y$;E6>5@Y5WE;^/_Y#7E5^58Y5OE+")7(G<B\N1-0USE5N5"Y?UC".4^
MXUKEY^1DY6KEY6,(Y:9C3^79Y/3D8^7YY&;E8>4/Y9_D:^4/8]3D@61BY6CE
M1&*58NAB-63!Y`[E#^5$Y4SEC&-PY6_E;>5$8I5BZ&(A9,'D;N4L8L[DV^1Q
MY9IBZ^3S8OCD8.-LY53E=&)S8U)D;.1T8G-C461LY*JW<N4GY7UDN^3_1S](
M)DEQ8MOB"6E?Z73EQ.1SY2BB9>6)0"GB=&)S8U%D4N1GY=_BI>1UY7;E-D]0
MSTKE:>4CY5IDN^2NXO^A'61BY4OET6'2X=-A^V$WX]3AW>'8X=?AV>'5X??A
M^N'GX>3A$N+IX>/A1N/YX5KC]>$#XB/B".(FXD7B#>(4XB%B?F,89#KE">+'
MXOSB$>(0X@5B<.0]NQ[BHN,.8F3B)^(!XB7B!.(5X@#B.N*M8B+C9N)7XC?B
MRT8]3V+B,^)5XCWB..)>XD9B6F1]Y&SB;>)`XC_B/N)$8B%D->11XC3B8.0&
M8EOB6N(H(DOB,.))XD=B2.)-XBYB:.(YXBQB..1VXJSBH.)ZXNGB#V,:Y*KB
M[N+/XN/B`^2-XCKDA>+!XK'BIN*GXUCCEN*1XLSBJ>*;XO7CD^*IXW_BFF)#
MY'OBF.(:XZOB>.*EXBPB5R)W(M_C@^(+Y*CB@.*CXO-B1.02Y!92%U+JXMGB
M../QXLCC7F/7X[?BEN/PXN7B(5#DXDOC[^+HXKEBY6/]X[SBW>+2XL7B]N(F
MY!=D)^2S8NWBN^+#XM_BYN(2XP;C>N-IXR_C*.,;XR'C0.,!XQ7C*>,KXR[C
M?.088YKC$.,FXU7D0>,(XT-C;^,'XQ_C(.-UX_CB,^,9XV7C2.-'X]CC=N-4
MXV3C;.-^8Y_D6^.JXV#C<..$XTWC@N/DXZ'C*.2'X\SCK6.NXYOCF.-WY(+D
MN&,KY+/CO^.F8P+DK..*X[#CM>-,Y.+CW./=X\WC\./>X^'CT>/#X\?CT.,4
MY!UD@>00Y/?C9>03Y&WD(.1YY/GC&>1*Y#/D-N0RY(QC+N0_Y%3D8^1>Y''D
M<N3G'D\A>&5_Y><>3R%W97_E11Y&GN<>3R%W97CEZ.7IY>KEZ^6)9>WE[.6'
M9>WE`*_VY?/EH&7PY9)E\N619?+E].7UY?CE^64GZX]E\.4"YG,AUV7<Y0'F
M"*0`YL2D^N7]Y0/F!N;^Y;)E!>:Q907FPV42Y@KF9B()Y@[F#^8-Y@CF#.:T
M91+F?[>7MO'E]C\4YA7F$>8'YA?F&.;_Y1;F&>;OY7,AHF7<Y9<U)6LF:RIK
M+>LO)!@E4R54)5\E[-IS(:)EU^4:YA/F$.:?WQOF_.6`Y8+E@^6&Y8CEAV6)
MY4^EUN6/9:#ER.6199+ECN63Y93EC.6VL)CEF64GZZCE7M#EY:GEK>73Y:7E
MH^6AY:OE+NNQ9;+EK.7-Y;[E9B*YY;;E*>N_Y;WEN^6\Y>'ES.6T9</EX.7V
M/\KER^74Y=#ETN75Y=YE*^ODY1WFD6`<YHKFC!\T9G!F@N8S9GWF..9'(U[F
M0B>%K$\G;Z=1IT"G?<HF9GWFC!\E9G!F@N9CYB8HCN8HYJZ\:"=!YF@G0.:;
MYGCFM.9SYECF!:E<9EUF?^;(ITGF569_YE7F1R,IYH^O9B@UYG?FFRSV+(LM
MC"VY+9UFK^:5Y@9)>F:JYHP?)68T9H+F2.9EYD;F!DEI9JKFE"<9J"9F,^95
M9ESF,"B5J(P?)68T9G#FWB<DJ!_FE[8F*#;FJ.9:'J!FL>;22&CF7J>?YD7F
MFRSV+(LMC"VY+69FK^:9YEH>D&:QYK@CNV`PX8_F!DEI9GKF7R>SJ(O>FRSV
M+(LMC"VY+69FG>9:'I!FH.:8ZD?FMV:XYK9FN.:V9K?FR2M-9TYG3V>T;19N
M9.[JH\OFX^;K;`CM\2#X[+WFW>;;YD(WW.9K+S%$<.U]ULRC&^[/9K7M0C?1
MYLWFCVW$;2'NLJV.6Y#;N\F^YAN\D9Y"YQ?G0><:9R?G-<4:9R?G/>?T[G5`
M&V=(Y[Z\]N;Z9OYF)^=U0`IG2.<BYR'G^F;^9AKG1.>'V3`>2EQ07$KG`>?W
MYO/F+>?'HW5`"F<;Y\:C,!Y*7%!<.^?)*[IF3F=/9[1M%FYD[LDKNF9-9T]G
MM&T6;F3NR2NZ9DUG3F>T;19N9.[(*U+GR"M1YUKG<B$I*5WG7.=3YUGG<B$I
M*53GQDQC9ZINJVZU;KKN8N>Q1;#&:.<NZ&7G;6=QYVMG<6?GYVMG;6?GY[[G
M1LV)9Q?O@&<7[[7GC>>,Y^FMP^>]Y[GGRTFGY\M)IN>?R,GG05_<Y]WGB^>?
MYY+G=.=N3C#/D>=#HYQ8Y.>OY^;GY^?_+>CGZ>?JYT%?L6?LY[+GZ^><6,CG
MR^=M9W%GS.?_+<WGT^?9Y][G05_<Y^[G[>?QY^_G3V]1[_OG]>?-I'7H=NAW
MZ'GH>NAXZ'OH?.B"Z(#H@^B$Z'WH@>A_Z(?HAN@X:(CHC.B)Z"5HD.@D:)#H
MC^@P:(KH-*EG9Y+H+&B*Z(OH3DJ6Z)3H&FB(Z&A*.F@]:)/H:$HY:#UHD^B1
MZ/1<5MUH2CEH.FB3Z.WJE^ANT9CHG>B:Z%1HG.B9Z)OH3VB<Z#XV;^C?IC^Q
MH>A;:*#H6FB@Z'O,G^BBZ'[HI.BEZ#XV5>BFZ(5HUVH5[I[HI^@!Z`+H`^@'
MZ`7H!N@(:!KK"N@1Z&?H$^@.Z!+H#.@/Z!#H<6C7ZACH%^@::#CH(>@L:##H
M,N@<Z$&_LL$FZ"1H)>@[Z"[H:$HY:#IH/>@WZ$Y*-.A&Z$SH4NA.Z%/H3VA4
MZ$WH<^ABZ%IH6^A9Z&7HA\YKZ&SH<.ATZ#`>Z"'L(>XA]UJ]6\QHSNC0Z+=H
MQFC(:-'HTNCPHRZBT^BN:,9HR.C4Z,_HUNC5Z-?HQ&C8Z,-HV.BN:+=HQVC(
M:-GHQNBN:+=HQFC:Z.@A["'N(:AHSN@P'N@A["'N(:AHS.BZZ*WHKNBOZ+;H
MN.B\Z+OHP.C#:,3HQNC(Z-[H^\_;Z+`EX&ACZ;`EWVACZ1#I9>EDZ6;I5^EH
MZ6KIUTEKZ0KI;.GR:&[I\&AMZ>_H[FANZ73IG>ERZ7'I<.ESZ7KI>.D@:7SI
M7&1?:7?I>R&J3^SH=>E<Z7GI>^GAZ'WI)VF!Z7_I@NE^Z5D?@.FTT(3I@^EO
MZ8KA!6E\Z87I@B42:35I@>D84H;IRLS'S&?I6>F")2?IB>F'Z6?ICNG5S&GI
MB.F/Z8KIC.F-Z9+ID.F1Z9/IB.F4Z;/1YLQEZ7;IZ.@TZ0WIB^E<9`EI=^F5
MZ;`EWVC@Z./HXFA1Z>7H,VDYZ>GH/.GJZ.OH[>COZ.YH\N@>Z?[H_>C\Z/_H
M].@,Z5+I"6E?Z03I#ND#Z0_I!6D@Z1'I%ND3Z5D?&.D2:2?I%>D<Z1OI(>DH
MZ3?I/6E+Z3;I/^E>Z4'I0^DZZ3[I2.E)Z47I2NE,Z6+I]NB?Z9[I;.IMZJ^A
MQ&ENZEWJ<.IOZG+J-LYB:G3J<^JQ:6[J6VI_ZGHUR&E%:G'J>C7&:45J<>I[
MZGWJ>>IUZG[J@.IXZG;JWFE\ZMUI?.IWZHP@=4^"ZHCJA^ISZH/JANHN:E'J
MCNJ/ZHOJC>J3ZI+JD>J0ZA-J5VJ,ZC=JFNH0:E=JC.J;ZI?JF>I2ZI[JF.KU
M:5%JG>I^T7KJ$FJ:ZI_J1^JAZN;4G.J6ZJ#JHNIZ-<9IR&EQZCKJA>J5ZH'J
MH^KU:2YJG>HHZH3J$&H3:HSJRK#%:7_JLNFDZK]I=.JGZ@Y6I>JFZB*[BNJ)
MZJSIK>FQ:<3IM.FSZ7HUQFG(:47JN>G!:>[IOVEBZM3IV^G?Z=GITNDVZM#I
MW6G>Z='IU>G%:5OJV.E-ZHP@=4_AZ?#I5>I*ZO'I[>GBZ6OJ:NH!ZA!J$VI7
MZ@+J^.G_Z0_J#NH-Z@7J3.I"ZAGJLF8MZB3J$FHWZA;J0>HN:E'J*^HXZD/J
M/NI$ZD_J7^H.5F7J9NIDZJ[04Q^P7L9>U.J@[+A1T^K/ZH#1UNK5ZL7J#]&X
M4<3J4Q^P7L9>M>K/4<SJR^IQ:(5H%>[9ZMCJ_QYWK_GJ[^H":R+KT2/NZC[H
MT2/JZN7J6Q]_K^3J0Z+I:A-K(NM^M^'0`FLBZWOH(^OI:@)K$^L;ZY<UV&4F
M:RIK+>N7-=AE)6LJ:RWKF67YY<2D"^:7-=AE)6LF:RWK&N:7-=AE)6LF:RKK
M!.8=.\%@,>L=.\%@,.LYZS;K_!^ES"RL6.M.ZSU72>OR(3(L-"PV+#>L$1Z<
MX4?K?.Q]['[L;NR[ZX#L_^Z!['ALB.PD[(+L?^R$[(7LANS;:[?LC.R)[(_L
MA^SYZY#LC>R+[(KLDNR8[-=K=FR>[)7LENRW:_?KE.R;[)'L'RP@+'M=>VR<
M[)/LJNRG:_?KG>QFZ]CKI^R@[`!LJ>RD[,MKJ.S*ZZSLN^RO[*WLG6MV[+[K
MB6NW[+3LL>RU[++LL^RX[*[LL.RV[+KL.NRG:[=KP.R/ZZOLRNS':ZGLR.R7
M[,+L*&R][,?L#6S%[`QLQ>R^['=LQ.S&[,/L+FS![-+LT>S+[*7L<^M>;,_L
M"&S.[-#LS>P;[*+LS&P'[]/LV.RF[*/L]6NY[-?LV^S4[,GLV>S5[-9L"&^>
M[]_LW>S=[-SLWNR?[+SL)>R.[)GLX^SA[.+LO^R:[&/KX.R=:]=KGNP0;,3L
M<FN([*'L'RP@+'M=KFN<[%KK6^MBZW?K:.MOZW3K>NN!ZX/KCNMR:WCLB^N3
MZY+KBNNK5I'K7^R-ZY#KK>N:Z[/KJNN>ZZ;K`NR<ZV#L;>RKZQ\L("Q[7:YK
M>^RZZYUK=NQ8[+YJP>MZ[#'L.>S)ZR/L-^S`Z\KKQVL`[+;K_>O2Z];KZNO5
MZ^OKX>ODZ^?KW>OBZ_#KB6O;Z^CK.NSTZ]3K7>P([`_L:.SWZQOL`^P3[!!L
M=^P,;`WL$NP)[`'L0NS_ZR#L,FP'[RWL*.PE["GL'^P<[#/L/NRD44CL26P(
M[SOL->Q%[#SL5NQ3;%3L5^Q2[&_L9.QG[&/L3"P?[NLA[.P@[L%F".WG["3N
MY*$C[B+NQ^8I[BCNP6;K['9M)N[7;27N,.XU[C/N'&XR[B[N1&TQ[BKN+^XM
M[KI3K^TX[CGNP^T[[C_N^NT][CKN/.X?[4#N0^Y&[D'NJNU([EYM1>Y=;47N
M1.Y)[DSN3^Y0[D[NU>9*[@EM)NY3[J1M3>ZK;2ON4>Y2[MYFQ&TA[DON6>Y5
M[E?N5NY^[5ON7.Y9[8=M*^XG[KI3+.U?[LDKNF9-9TYG3V<6;F3NV^9@[F'N
M6.YC[EKN6NYB[E[N,^W>9H]M(>[/[<GMR.U=[L;M9^YE[@YM)>XW[FCN-NYJ
M[E3N:>[5P6ON]&U'[O-M1^YL[G#N/&UM[C3N"NYO[O_M<>ZZTW+N<6C7:BSN
MR2NZ9DUG3F=/9[1M9.YT[F;NVF9S[AWM0NX^[DPLY>SI[-YFCVW$[?;L].SR
M[`YMU^T);7;MK.T'[0;M(^V';:OM%>XH[1[M)NT2[1_M'>T;[?WM%>WE[=GM
M+^TP[4+M-.U#[3_M'NX[[5#M4^T=[E'M8.U=;5[M4NWS;?3M7.UA[7+MD^UJ
M[7[M;^UL[6[MB>V*[7?MZ^V8[:'MFNV[[9;MOVW`[:7MJ>W*[<+MLNVY[;KM
MP>V\[<DKNF9-9TYG3V>T;1;NUNT:[M/MVNWO[>;M\NWX[?KM!^[Y[0SN#^X;
M[ACN9"-WJ'=(L4A\[K@DCN%^[G?(=TBQ2'CN:2C0QGKNA>ZD[H/NC^Z'[CT>
M;ZI0PY=,A.ZF[J7NK&ZX[L9,8F>K;K5NNN[&3&)GJFZU;KKNJ6ZX[@6C\C:L
M3+1NN>[R-JQ,KVZY[L9,8F>J;JMNNNZI;JSN\C:L3*]NM.[&3&)GJFZK;K7N
M\D7S13352!X;+(4NO>Y('ALLA2Z\[L3N^DC#[LSNR>Z8S-+NT>[9[MCN\>Y,
M*;G`]N[M[EJA]^[R[N3NV^[J[@GGX>[I[J[8_N[][FUK"^\,[]G6,FS,[$EL
MUFR>[PWO_^X"[PGO$>\.[Z'CMT:\QJRA@&>)YR'O(.^"W#GO-._%I9T>B36*
M-5#OBS6.M?=<3=WR9U'OG1Z)-8HU2N_R9T_O;SM_[U3O4V^`[X'O@N^%[W#O
MA^^#[X;O8F^$[V%OA._ZH8CO;B69)M.FK*1Q;XKOB>]:[VKOB^]MT8SO;SM2
M[U3O5>]7[U_O86]B[UGO8.]<[V;O;.]J[W+O=^_<2I)OF>^0HYZNW$J-;YGO
MFN^;[XUODN^4[Y7O@!Z?[\M)S$E0RDEL".^`'ISOBB2,)-*P`21RS```````
M````````````````````!`#_______\%``8`__\'`/__"``*``L`#`#__PT`
M__\.`!``$P`4`/____\6`!@`&@#__QP`'0`A`"(`__\D`"8`*``J`"P`+0`O
M`#$`-`#_____-0`X`#L`________/`#__T(`0P!$`/____________]%`/__
M__]'`$D`_____TP`30!/`%$`4P!5`/__5P!<`/____]=`/_______UX`8`#_
M____9`!E`/__9P!I`/__:P#_____________;@!O`/__________<P#__W0`
M__________________]V`'<`__________________]Y`/__________?`#_
M_X``@@"%`/_______X<`__^)`(H`BP"-`(\`__^0`),`EP"9`/____^;`/__
MG`"=`*$`H@"C`/__I0"G`*L`K0#__ZX`_____________[``__^R`/__M@"W
M`/____^X`+D`N@"[`/____^\`/____^]`/__O@"_`/_____``,(`___#`,0`
M_____\<`R0#*`/__RP#_____S`#__\\`T0#2`-0`___7`/__________V0#:
M`/_______]P`W0#________>`/__________WP#_____XP#__^0`Y0#F`/__
M___________________H`/_____J`/__[`#M`.\`\`#_________________
M__________________________4`______________<`^`#[`/P`_0#^`/\`
M``$#`08!!P$)`?__"@$+`0P!#0$.`?____\/`1$!_____Q,!_____Q0!%P'_
M____&@'__QL!__________\<`?_______QT!__\>`?__________'P$@`?__
M__________\A`?__________(@$G`?__________*`'__RH!+0'__RX!__\O
M`?____\S`?__-`'__________S4!________________-@'_______\X`?__
M.@'_____________________________.P$\`?__/@'_____________/P'_
M_T,!__]$`?____________]%`?____________________]&`4@!20'__TL!
M__],`4T!3P%0`5$!4@%3`50!50'__U<!________________6`%9`?______
M______]:`?_______UL!7`'__________UT!_____UX!__]?`?__8`'_____
M________80'_______________________]C`60!90%F`6<!:`'__VD!:@'_
M_VL!;`%M`6X!__]O`7$!_____W,!=`'_____________________=@%Z`7P!
M_____WX!__]_`8$!__^$`84!__^&`8<!B0&*`?____^-`8X!CP&0`?______
M____D0'__________________Y(!DP'_______^5`9<!__^8`?__________
MF@'__________________YL!_____YP!_____YT!GP'__Z`!__^A`?__H@'_
M____________HP&D`?__I0'_______________^F`?__________________
MJ0&J`:L!__________________________^L`?__________K0'__ZX!____
M______________^P`;$!__^S`;0!M0&Y`;P!__^]`;\!P`'_____________
M___________________!`<0!________Q0'__________\8!___'`<H!S@'_
M_]`!________T0'3`=8!___7`=@!___9`=H!VP'________<`?__W0'_____
M___>`>`!X0'__^(!___C`?__________Y`'__^4!___F`><!ZP'L`?______
M_^T![@'_____[P'________R`?________,!______0!________]0'___8!
M^`'________Y`?__^@'_____^P'\`?___0'__P`"________`0("`O__`P+_
M_________P0"________________!@('`@@"__\)`O_______PH""P+_____
M_____PT"__\.`O_______P\"$`+_____$0+_____________$P(6`O______
M____________%P+_____&`+__________________QD"__________\:`O__
M&P(<`AT"'@+_____'P+_____(0+__________R("__\C`B4")P(J`O__+`(M
M`C$",P(U`O__-P+__S@".0(Z`O__/`+__ST"________/@+_______\_`O__
M0`)"`O__0P)%`O____________]&`O__1P)*`D\"__]0`O____]1`O__4P+_
M_U4"5P+__U@"60):`EL"7`)=`EX"__]A`F("8P)E`F8"__]H`FH":P)L`FT"
M__________]N`O__;P+__W$"<@)S`O__________=0)V`G<"__]X`O__>@)[
M`GT"?P*"`O____^$`H4"B`*)`HL"C`*-`O__________C@*/`O__D`+_____
MD0+__Y,"E`*5`I@"F0+__YL"G`+_______^=`O__G@+__Y\"H`*A`O____^B
M`O__________I`*F`O__J`+__ZP"K@*P`K("M`*U`K8"__^X`O____^]`KX"
MPP+&`LL"___,`LT"T@+3`O__U@+7`O_____:`MP"___>`M\"X`+A`O__XP+E
M`N8"YP+_____Z0+__^L"_____^P"___________M`O`"\0+________R`O,"
M]`+U`O__________^@+___________L"_`+_`@(#__\%`P8#"`,,`PT#____
M_PX#_____Q(#__\3`_____\4`Q4#__\6`QD#&@,;`QP#'0,>`R`#(0/_____
M(@/_______\C`R8#)P,H`RD#+0,O`_____________\W`___.P,_`T`#__]!
M`_____________]"`TH#3`--`T\#__]0`___________40/__U0#50/__UT#
M7@-?`___9`/__V@#_____________VD#________:@-M`_____]N`___;P-P
M`___<0-R`WH#__^"`X4#AP/__X\#EP/__________________YD#FP.<`___
MG@.?`_____________^@`___HP.D`_____________^G`Z@#J0.L`Z\#____
M____L0/_____________L@/__[,#_____[0#M0/__[<#N`/__[D#O`._`___
M________P0/________%`\@#R@/__\P#S0/.`___T0/2`___U0/__]8#___7
M`___V`/9`___VP/__________________]P#W0/@`___XP/_____Y`/_____
MY@/__________^<#_____^@#Z@/L`^T#________\`/_________________
M__________________$#___S`_0#___V`_@#___Y`_H#___________[`_P#
M_0/_`________P`$`00"!/__!`0%!`@$__________\+!/__#`0-!/______
M____#P3_____$`3_____$002!/__%@3__Q<$__\9!!H$'00@!/__(00B!"0$
M)P0I!/__*P3__RT$+@0O!/_______S$$__\R!/__,P0Z!/__/`3_______\]
M!/____\_!$`$0@3_____0P1%!/____]&!$@$203__TL$__],!/__________
M3@3__U$$4@14!%H$6P1<!/__701?!&`$803__V($_____V,$__]D!/____]F
M!&H$:P1L!/_______VT$;@1P!'$$<@1S!/__=03__W8$=P3_______]Y!'H$
M>P2`!/__@@2#!(4$A@2'!(@$B03__XP$C03_____C@20!/__D@24!)<$F@2=
M!*`$H02B!*,$I`3__Z4$I@2I!*H$JP2L!/__L`3__[($_____[,$M03__[<$
M_____[D$__^Z!+X$P`3__________\0$_____\<$R@3__________\L$____
M_________]`$U`3__]4$________V`3_____V03;!/__W03__________]\$
M___@!/__X03__^,$_____^0$___F!/__YP3__^@$_____________^D$Z@3K
M!/_____________________N!/_______^\$______$$________]P3Y!/__
M^P3___________P$___]!/___@3______P3_____________``4"!00%__\%
M!08%_____P<%"`4)!0H%__\+!0P%#04.!1$%$P44!14%________________
M__________\6!1<%&`49!?____\;!?______________________________
M______\<!?____________________\?!?__________(`7__R,%_____R8%
M_____R<%________________*07__RH%*P4L!?_______________RT%____
M______\N!?____\P!?____\Q!?__,P4V!?____________\X!?_______SH%
M/`7_______________\]!?____________________\_!?_______T`%1`5%
M!48%1P7__T@%__]*!?____]+!4P%__]-!?__3@7__U$%________________
M_____U(%_____________U,%________6`7_______]:!?____________];
M!?_______UT%_____UX%_____________U\%_____V`%__________]A!6(%
M__]F!?____]L!?__;07_____;@7__V\%<`5Q!?____]R!?_______W,%____
M_________W0%________________=07__________________W8%________
M_____W<%_____________________W@%________>05_!?__A06&!?______
M_________X<%BP61!?____^6!?_______YD%__________^:!9L%G`6@!:$%
M________HP7_______^D!?__I07_____________I@7__Z@%__^J!?__JP7_
M_________________[`%_____[(%M`7__________________[<%__^X!?__
MNP7__________________________[P%O06^!<`%___!!<,%Q07__\@%____
M____R07+!?_______\T%___.!<\%________________T`71!=(%_____],%
M________U`7_____________________________U07__]8%________UP7_
M____V`7__]D%________V@7__]L%___________________<!?_____=!?__
M___>!?_______________________________]\%________X07_____X@7_
M_______C!?__Y07F!?__YP7H!>L%________[`7__________________^T%
M________[@7O!?__________\07R!?0%]07________V!?__]P7X!?______
M____^07________Z!?L%___\!?X%_________P7_______________\!!O__
M__\"!O__`P8$!O__________!@8(!@D&_____PH&"P;_______\,!@T&__\.
M!O__#P;__________Q`&_____Q$&__\2!A0&_____Q<&&`;__________QD&
M__\:!O_______________QL&__________\<!O____\=!AX&________(08B
M!O_______R,&__________\G!O__+`;__RT&+@;__R\&,`;__S$&________
M_____S(&________,P8T!C4&__\W!O__________.`;__________SD&.@8[
M!O____\]!O____\^!C\&00;__T(&_____T,&__]$!O__10;_______](!DL&
M40;__U(&_____U,&609:!O__6P9>!O____]A!F0&_____V4&__]F!FP&__]O
M!G0&=09V!GD&?`9_!H`&__^%!O____^&!O__BP:0!O__DP;_____F`;_____
MF0:<!IT&_____YX&__^C!J8&J0;__ZH&JP:M!O____^P!K,&M@;_________
M_[@&__^Z!O__NP:\!KX&________OP;!!O_______\(&PP;_____Q`;_____
M________________QP;(!O_____*!O_____.!O__SP;_________________
M_______________1!M4&U@;__]<&V`;_____VP;__]X&WP;@!N8&YP;I!NL&
M[0;_____[P;P!O__\0;R!O,&___________U!O8&^`;Z!O_____[!O___`;_
M_____@;___\&__________________\`!___`0<"!P,'!`?_______\%!___
M_____________P8'"`<)!PH'"P?_______\,!P\'$`?__________Q$'$@?_
M______\3!Q0'%0<6!___&`?__QD'__\:!___&P<<!___'0?_____________
M__\>!___________(`?_____________(0?__R('__\C!_______________
M_R8'*P<L!___________+0<N!S`'__\Q!___,P?_____-0?__________S8'
M__________________________________________\W!___________.`<[
M!___________/`<]!___/@<_!T`'_____T$'________________0@?_____
M__]#!T4'_____T8'________1P?_______________](!___2@?_________
M____________3`=/!U$'_____U('_____________U0'________________
M5@?__________U@'________60=<!___70?__UX'7P=@!V$'__]B!_____]C
M!___9`=E!___________9@?__V<':`?__VD'__]K!_____]L!___;@?_____
M__________]O!_____]Q!___<@?__W0'_____W8'____________________
M____________>0=Z!___>P?_____________________?`=^!W\'__^`!___
M__^"!___A`?_______^%!___AP?_____B@?_______________^+!XT'CP?_
M____E`?__Y8'FP?__YP'_____YT'_____YX'_____________Y\'_____Z$'
M_____Z('I`>E!Z8'IP?__ZD'_____ZH'__________^L!ZX'KP?__[`'__^U
M![<'N`>Y![L'__^\![T'________P`?"!________\,'Q0?'!\@'R0?+!___
MS0?/!]$'TP?4!]4'UP?9!]H'_____]P'___>!___WP?A!___X@?__^8'Z`?_
M____Z0?__^P'________[0?N!________^\'___Q!_('\P?_____]`?U!___
M]@?X!___^@?________[!______^!_\'__________\`"`((`PC__P0(__\%
M"`8(!PC_______\("/____\)"`P(__________\-"`X(_____P\($`C_____
M__\1"/_______Q((__\4"/__%P@8"/____________________________\9
M"/__&P@=""`((PC__R0(__\G"/__________________*`C__RH(________
M__________________________\L"#`(,@C__S,(_____S0(__________\V
M"/_______S<(_____S@(__\Y"/__.@C_____________________________
M/@@_"$`(0@C_______________]#"/_______T8(2`C_________________
M_________________TH(_____TL(3`A-"/__3PC_____4`C__U$(________
M__]2"/__4PC_____5`C_____________50C_______]6"%@(_____UH(7`A=
M"/__7@C_______________________]?"/____]A"/__________________
M__]B"&,(9`AE"&8(________________________9PC_____________:`C_
M____:@C_______]L"/__________;0C__W$(________________<@C__W,(
M=0AV"'@(__]Y"/__________________________>PA]"(`(____________
M_________________________X$(________________________________
M________________@@C_____@PC_____________A0B&"/__APC_______^)
M"(H(C0B."/____________________^/"/__________________________
M________D0B3"/______________________________________________
M_________________Y0(_____Y4(_____Y8(__^7"/__________________
M__^9"/_______YH(FPC__YP(_____________________________YX(____
M______^@"/__H0C__Z((_____Z,(________________________________
M_____Z0(__________________________^E"/_______Z8(IPC_______^I
M"*L(________K0BN"/____^P"/__________L0BR"/__LPBT"/__________
M_____________________[4(________M@C_______^X"+D(__^["/______
M______^\"/____^^"/_____`"/__PPC__________\0(Q0C_____________
MQ@C__________\<(_____\D(_____________\P(_____________\T(S@C_
M____________SPC________________0"/_____________1"/_______]8(
MUPC________________________________8"/_______]T(W@C?".((___C
M".D(Z@C_____[0C__^X(___O"/_____P"/_____Q"/__________________
M___________S"/4(^0C["/T(_@C__________________P`)`0D""?____\#
M"?____________\$"?__!@D'"?_______PD)"@D,"0X)__\0"?____\1"?__
M__\2"1,)%0D7"?____\>"1\)_____________R4)__\F"?__+`G_____,@DV
M"3@)/@G__S\)0`G__T()________0PE%"?__2PG__TT)3PG_____________
M__]1"?__50E6"?____]:"?__7`E="?__7@E@"?____]B"?____]D"6<):`EI
M"6L)__]L"?__;0EO"?_______W`)<PEV"?_______WD)>@E["7P)__^`"8,)
MA`F)"?__C@F1"9()E`F5"98)__^9"?__F@F;"9P)__________^?"?__I`G_
M_ZD)K@FS"?__________M`G_____MPG__[D)N@G__[L)O`G_______^]"?__
MO@G`"<$)P@G________$"?__________________Q0G_____QPG_____R`G)
M"?__R@G__\L)___,"?_______\T)________________________________
M________________S@G/"=`)U`G_____U0G_____UPG_________________
M_________________]@)V0G:"?__VPG<"?_____________C"?__________
M________Y`G________J"?_____________K">P)____________________
M_^T)___N"?_______^\)\`G___________________________________$)
M___________________________R"?________,)___T"?4)]@GW"?__^`GY
M"?_____________Z"?L)_________`G]"0`*________________!PK_____
M_____P@*"0H*"O____\+"@P*_____PT*__\/"A`*__________________\3
M"A0*%0H7"O____________________\9"O_______________________QH*
M&PK_________________________________________________________
M______________________\="O_______QX*__\?"B(*________)0HI"O__
M+`K__RT*,`K_____,0K_____________________________________,PK_
M______\T"O__________________________________-0K__S8*-PK_____
M.`K_______\Z"D$*__________________]("O____])"O______________
M______]*"O__2PK__________TP*30K_____________3@K_______]/"E`*
M4PK_______]5"E@*7PK__V`*80K__________________V(*9`K_________
M_V<*:`K_____________:PIL"FT*__]N"G$*________=`K__W4*_____W8*
M__]W"G@*_____________WD*_____________WH*>PK__________WP*__]]
M"O____]^"G\*__^!"O__@@J$"H8*__^)"O__B@K_____BPK_____C`K_____
M__^-"HX*CPJ0"O____^1"O____^2"O__DPK__Y0*____________________
M_Y8*EPJ9"O_______YH*__^;"IP*GPJA"J0*__^E"O____^F"O__________
MJ`JI"JH*_____ZL*__^L"JX*________KPJR"O_______[0*____________
M______________^U"K8*__^W"O__________N@K__[P*__^]"K\*________
M________P0K$"O_____________%"O__R`K__\D*SPK0"M$*TPK________4
M"M4*___8"O__V@K<"MX*X@K________C"O_____________D"N4*___F"N<*
M___________I"O__________Z@KK"O__________________[0K________N
M"O_______________________^\*\PK________T"OD*^@K["O___`K___T*
M_PH`"___________`@O_____________`PL$"P8+____________________
M____"`L)"___#`O__PT+#PL1"Q(+%`O_____________%@L7"___&`O_____
M__\9"_____\<"___________(`O_____(0LG"RD+_____R\+,`LW"S@+.0O_
M_________SL+_____SP+/0L^"___0`M#"T0+__]%"___________________
M__________]&"___________1PM)"________TH+__________]+"_______
M_TP+__]-"___3@O__T\+40M2"U,+__]4"___________________5@O__U<+
M________60O__UH+__];"UP+70M@"V(+8PO__V8+__]G"VD+:PMN"W$+=`MW
M"W@+__________]Z"WL+__]\"WT+__]^"W\+_____________X$+__^""___
M__^#"________X8+________APN)"XL+__^."X\+_____Y(+DPO__Y0+__^5
M"_____^6"___EPO__YH+__^<"_____________________^>"___H`NB"___
MHPNE"___________I@O_____J`NK"_____^L"ZT+__^N"[$+LPO__[4+__^X
M"________________________[D+N@O__[L+__________________^\"[T+
M__________________^_"___P`O_____P0O_____________PPO$"_______
M_\4+___&"________________\D+___________*"___________________
M___+"___S`O."\\+T`O1"](+TPO_________________________________
M_]0+___5"______________6"]<+_____________]@+___:"___________
MVPO________________<"________________________]\+Y`O_____Y0O_
M_______________F"___________YPO________________H"^D+_____^L+
M________________________[`OM"______O"_$+___________R"_______
M__________,+___U"_8+^0OZ"____@O_"P`,`0P"#`0,!0P&#`@,________
M__\*#/__________#`P1#/__$@S_______\3#/__%`S_____%0S_________
M_________Q<,&`S_____&0S__QH,__\=#/____\?#"$,)`PE#"8,__\G#/__
M_____R@,*PPL#"T,________________+@S_________________________
M______\P#/__________________,@S_____________________________
M-0S__S<,.`S__SL,__\\#/__/@P_#$`,__]!#$(,0PQ%#$8,__]'#$D,____
M______]*#/_______TL,3`S_____________30S_____________3PS_____
M________________40S__________________U,,__]4#%4,________5@Q7
M#/____]8#/__60Q:#/____________________________]<#%T,_____UX,
M__]?#/____]A#&(,8PQD#/____]E#/__9PS_____:`S_______]I#/__:@QK
M#/____]N#/_______________W`,<0QS#/__________=0S_______]W#'@,
M_____________WD,>@S__WL,?`S__________WT,?@S__W\,____________
M_X`,@@R$#(4,__^(#(D,_____XH,__^+#/____^,#/____________^-#(X,
MD0S__Y(,__^4#)8,EPR:#)T,________________________G@R?#/______
M_Z(,__^C#/____^D#/_______Z4,________I@S__________Z<,________
M__________^H#/_______ZD,__^J#/____^L#*T,_____ZX,L`RQ#/__LPS_
M_________________[0,__^U#+8,________MPS_____N`RY#+H,________
M________________NPS__[P,O@R_#,`,P@S__\,,___$#,8,QPS(#,D,____
M_________\H,RPS________,#/_______\T,___________/#/_____0#-$,
M___3#-4,___6#-@,___________________9#-L,___<#/_____=#/__W@S@
M#.(,___D#/_______^8,Z`SJ#.P,___M#.X,___P#/__________________
M______________$,\@SS#/0,______8,________^`S___D,^@S_________
M_____`S___T,______X,_________PP`#0(-!`T%#08-_____P<-"`W_____
M_____PD-________________________________"@W_______________\,
M#?__________________________________________#0T.#0\-$`T1#1,-
M%`T5#18-__\7#1@-________________&0W_____________________&@W_
M______________________________\=#?____\>#?____\?#?____\@#?__
M_____R$-(@W_____)`TE#28-)PTH#?__________*0TJ#2L-+`TM#2\-,@TS
M#?__-`TU#38--PTY#?__________________________________________
M_____________SL-_____SP-__\]#?____________\_#?______________
M______________________]!#40-10U&#4<-2`U)#4H-2PU,#4T-3@U/#5`-
M_____________________________________U$-__]3#?____________]4
M#54-5@W__U<-__________]:#?_______________UT-__]>#?__________
M________7PW__________V`-__]A#6(-__]C#60-90W__________V<-____
M_V@-_____VD-________:PW__VT-__________________________]N#?__
M_____W`-<@W_______________________________________________]S
M#?__=`W__W4-_____________W8-________=PW_______________]X#?__
M__________]Y#7H->PW_____?`U]#?__?@U_#8`-@0W_____@@W_________
M_________________________________X,-A`W__________________X4-
MA@W__________X<-________________________________B`V)#?______
M____________________B@V+#?____^-#?__C@V/#9`-D0V2#?__DPV6#?__
M_____________Y<-__________^8#?__F0W__YH-G`W__________YT-____
M_________________________Y\-__________^@#?__________H0W_____
M__^B#?_______Z,-________I0W_______^F#?__J`VJ#:L-K0VO#?__L`W_
M______________^Q#?__________________________L@W_____LPVT#?__
M__________________^W#?____________^X#?_______[D-_____[H-____
M______^[#?__________________O`V^#?_______[\-________________
MP`W!#<(-___##?__________Q`W__\4-___________&#?__QPW__\@-___)
M#<L-S`W________/#?_______________]`-T@W__],-___4#=4-U@W9#=H-
M_____]L-W`W__]T-_____]X-_____]\-X0W__^,-Y0W__^8-________YPW_
M____Z`WI#?__________ZPW________M#?__[@WO#?__\`W___$-___R#?__
M________]0W_____]@WW#?@-^0W___H-_0W___X-_____P`.`0X"#@,.!`[_
M_P4.________!@X'#@@.__\)#O__"@[__________PL._____PP.__\-#O__
M#@[_____#P[__Q`.$0X3#O__%0[_____%@X8#AD.________&@[__QL.'@X?
M#O__________________(0XB#B,.)`[_____________________________
M__________\E#BD.+`[_____+0XN#C`.,0[_____________,@[__S0.-@XX
M#O__.0[_____.P[__________________________SP.________________
M00[__________T(.__]##D0.__]%#O_______________TD.2@Y,#O__30Y2
M#O__5PY<#F`.9`YF#F@.:0[__________VL.;`YN#O__;P[_____________
M__]T#G8.________________________=P[_____>`YY#O__________>@[_
M____>P[__WP.__________]]#O____________________________^`#H$.
M_____________________X(.__________^##H4.AP[__XD.__________^*
M#O__________BP[__XP._____XT._____________________________Y`.
MD@Z5#I8.F`[_______^9#IH._____YL.__________^<#O____^>#O______
M_Y\.H`[_______________________^A#J(.__________^C#O__________
M__^D#J4._____________Z8.IP[__Z@.J0[__________________ZH.____
M_ZL.K`ZN#J\.L0[_____LPZU#K8.__________^W#O__N`[_____________
M__^Y#KH.O`Z]#KX.________OP[_____P`[__\(.PP[________$#O______
M_\4.Q@[__________\<._____________\@.________________R@[_____
M_____\L.S`[.#L\.___________1#M(._____________________],.____
M____U`[6#ML.________W`[_____________W0[__]X.___A#N0.Y0[_____
MY@[__^<.___________________________I#O_____________________K
M#O_____L#O__[0[Q#O__\@[_____]`[X#O__^0[________________Z#O__
M___________________[#OP.___________________^#O________\.____
M_________P`/!0___P8/_____P</"@\+#PP/__\.#P\/__\0#___$0\3#___
M_____Q0/_____________________________________Q4/%@___Q</__\8
M#_____\9#QH/_____QL/__________\<#___________'0\?#R`/(0___R,/
M_____R0/)@\G#________R@/_____________RH/__\K#RX/_____S`/,0__
M_S(/__________________\U#___________________________________
M__\V#S</_____S@/.0\Z#___.P\\#_____________\]#S\/0`__________
M______________________]!#T</2`]-#_____].#___________________
M________4`______40________________]5#_____]8#___60______6@];
M#UP/__]=#UX/7P]@#V$/9@]I#___:@________]K#_____]N#___________
M_____W`/_____________W$/__________________________________]R
M#_____________]S#___=`___________WD/________>@___________WL/
M________?`________________]^#_____]_#___@@________^##X0/A@__
M_X</B`^*#XL/C`___X\/D0^3#___E`^5#Y</F`^:#YL/__^=#Y\/__^A#___
M________H@^D#________________Z8/________IP___________Z@/____
M_________________ZD/________________JP^M#_____________^N#___
M_____[`/________________________L0___________[,/M`__________
M____M0________^V#[@/__^Y#[L/O@^_#\`/P0_"#\0/Q0_&#\</R`______
M___)#___________________________RP_,#___SP______T`___]$/____
M_],/U`___________________]8/________________V`_________9#___
M________V@___]L/_____________]P/X0__________________________
M_^,/___________________________E#___Y@_G#^@/___J#___ZP______
M________[`_P#_________________________0/]0_V#_______________
M____]P______________^`____D/________________________^P_\#___
M______X/______\/________________`!`!$/__________________`A#_
M_________P00!1#__________________P@0"A`+$/____\,$/____\.$`\0
M__\0$/__$1#_______________\2$/__$Q#_____%!#_______\5$/__%A#_
M____%Q#__________________________________________Q@0_____QD0
M_____________QL0__\<$/_______QT0'A#_____________'Q`@$/______
M_R$0(A#__R,0__\D$"40__\F$/____________\G$/__*1#_____________
M__\J$"L0__\M$/__________+A`O$#`0,1`R$#,0____________________
M____________________________-1#_______________________\V$/__
M.!#__SD0________.A#_______\\$/__/1#__________________SX0____
M_S\0__________________]`$$$0_____T,0__]$$/_______T40__]'$$@0
M2A#__TP03A!0$%$04A#_____5!!5$%80________5Q#_____6!!9$/______
M______________]:$/__6Q#_____7!#_____71#__________________UX0
M7Q!A$/__8A#__________V,0_____________V0091!G$&@0____________
M_VD0__________]J$/__________:Q#_____________;1!O$/__________
M<1#__W,0__]U$/_______W80>A!\$'T0_____WX0__]_$/_______X`0____
M______^"$/__@Q"$$/__________________________________________
M________AA#_____AQ#_____________________B1#_____BQ#__XX0CQ#_
M_________________Y`0_____Y,0__________^4$/__E1#_____EA#_____
MEQ#_____________F!":$/_______YL0_____YP0GA#_______^?$*`0__^A
M$/____^B$*00_____________Z40IA#_______^H$*D0__^K$/__KQ#_____
M_____[`0_____[$0__________^R$+80MQ"X$/__________N1#_______^Z
M$/__NQ#__________[T0OQ#`$/__________P1#"$/__PQ#$$,40________
M_____\<0___($,D0___*$/__RQ#________________,$/__________S1#_
M_\X0SQ#__]$0________________TA#4$/_______]40V1#__________]L0
M___<$-T0________WQ#@$/_____________B$.40___G$/__Z1#M$/`0____
M__$0___________________________R$/_____S$/_____________T$/__
M]1#V$/__________________________________]Q#___@0___Z$/_____[
M$/_____]$/__`!'_____`1'__P,1__\$$?__!1'_______\'$?____\)$0L1
M_____PT1__\.$1$1_____Q,1%Q$;$?____\>$2$1)!$E$?__)A'__R@1+!$P
M$3$1_____________S41________-A'_______________\W$3@1________
M__\Y$?__.A'_______\[$?____\\$?____\]$?_______________SX1____
M_S\10!'__T$10Q'__T41_____T81_____T<12!%*$?_______TP131%0$?__
M_____U$1_____U(1__________]4$541________5A%8$5D1__]:$5L17!'_
M____________71'__UX1__________________________]?$?__8!'_____
M__________]A$?_______________________V(1_____V,1__________]E
M$681__]H$?__:1'__________________VH1_____VT1________<!'_____
M__________]Q$7(1_____________W41__]V$7<1_____________W@1>1%Z
M$7P1__]^$?____^!$?_______________________________X,1__^'$?__
M________B!'__________________________XD1BQ'_______________^-
M$?____^/$?____________________________________^0$9$1________
M__^2$9,1E!'_______________________________^5$9<1____________
M_________Y@1________F1&:$?__________________FQ'__YP1H1&C$:01
MI1&F$:<1J!&I$:H1________K!'_____K1&N$?____^O$?______________
M______^P$?____^Q$?__________________________________________
M________LA'_____________M!'__[41MA'_______________^W$?____^X
M$?__N1'__________[L1O!'_____________O1&^$<`1___!$<(1PQ'&$<@1
M_____\D1___________________________*$?_____________+$?______
M____________________________________________________________
M________S!'________________-$?_____________.$?_______\\1____
M_]`1T1'2$=,1U!'5$=81UQ'8$?__V1':$=P1WA'?$>`1X1'B$>,1________
M________Y!'________________G$?_______^@1___K$?______________
M_________________________^P1_____^T1_____________^X1______`1
M___Q$?__\A'_____\Q'________________________T$?_____V$?__^!'Y
M$?L1_!']$?X1_Q$`$@$2`A+__P,2!!(&$@<2_____________PL2________
M_____________PP2________#1+_______\.$O_______P\2____________
M____$!+_______________\1$O__________________$A+_____________
M_____________Q02_____Q42__\7$A@2__________________\:$O__&Q(>
M$O__'Q+__R`2(1+_______________________\B$O__(Q(D$B82)Q(J$BX2
M+Q(P$O__,A(S$O__-!(X$CD2/!(]$O__/A+__S\2________________0!+_
M______]!$O____]"$O____]#$O__________________1!+_______]%$O__
M__________]'$O____________________________]($O______________
M____________________________________21+_____________________
M2A+__________________TL2_____________________________TP231).
M$D\24!)2$E0251)6$O__5Q+__U@2__]9$O____]:$O_______UT2________
M__]>$F`2_____________V(28Q+_______________________________]D
M$F@2_____VD2:A+_______]L$O____]M$O____________]O$O__________
M________<1)R$O_______________W,2__]T$O____________________]U
M$O__=A)X$GD2__]Z$GP2?1*`$H$2@Q+__X02A1*&$O__AQ**$HL2__^,$O__
M__^.$O____^/$O__________D!*3$O____^5$O____^6$I<2__^9$O____^:
M$O__FQ+_______^<$O_______________YT2__^>$O_______________Y\2
M__________________^@$J$2________HA+_______^E$J82__________^G
M$J@2_____________ZD2________________JA+__ZL2_____ZP2K1*N$J\2
M________L!+__[$2________LA+_____M1+__________[<2__^X$KH2____
M______________^\$O__________________________O1*^$O_______[\2
M_____\`2___________________!$L(2QA+*$O__S1+__]`2T1+_________
M_______________2$O_____3$O_____4$O_____5$M82V1+_____VA+<$O__
M___=$MX2___@$O_____A$O__________XA+__^,2Y!+__^42____________
M_______________________F$O__YQ+________H$O__________________
M_____^D2ZQ+__^P2[1+_____[Q+___`2\A+T$O_____U$O__________]Q+_
M_______________X$O__________^1+Z$O___1+___\2`A/_______\$$___
M!1/__P83________!Q/_____"A,+$_____\-$___#A/_______\0$_______
M_Q$3__\4$_____\5$___________%A/__Q<3&!/_____________&1,:$QP3
M________'A/_____(!,A$___(A/_____________________________)!/_
M_________R43)A/_______________\G$RD3__\J$RP3__\M$_____\N$S`3
M_____S$3__________\R$_____________\S$S03_____S43____________
M_S83-Q,Y$_____________\Z$ST3__________\_$___01-#$T431A-'$___
M________________2A/_______]-$T\34!/__________________U$3____
M______]3$U03________________51/_______________________]:$UT3
M7A/_____________________7Q-@$___8A-E$________V839Q-J$_______
M_________VL3__________]L$________________VT3__________]O$___
M_____W`3________________<1-R$W03=A/__W<3>!-Y$________WH3____
M_WL3_____________________WP3?1/_____________________?Q.`$___
MA!/__________X43__________^&$X@3B1/__XH3__^+$_______________
M_XT3__________^.$________________X\3_____Y`3_____Y(3________
M_____________Y,3_____________________Y43________EA/_________
M_________YD3FA/_____FQ.?$Z`3__^A$_____________________^B$___
M__^D$___I1/__ZD3_____ZH3__^L$_____________^M$_______________
M_________Z\3________________L1/_____LQ/_______________^W$___
M__^X$___N1/_____NQ/__[P3_____________________\`3____________
M_________________________\$3PA/#$______________$$\43________
MQA/_____QQ/_____R1/________+$________\P3___.$___SQ/__]$3TQ/_
M_]43___6$___V1/_____VA/_____VQ/________________=$___________
M___>$]\3_____________^`3Y!/________________E$^83___G$^@3____
M_______________________________I$______J$________________^L3
M________[1/_____________________\!/_____________________\Q/_
M_______T$_43___W$______X$______Y$___^A/___L3_A/_$_____\`%/__
M`10"%/__________`Q3__P04!13__________PD4__\*%/____\.%/____\/
M%!`4________$13_____________$A3__________Q04________________
M_____Q84%Q3__________Q@4_____QH4________&Q0<%/__________'13_
M____'A3_____________________________'Q3__________R`4________
M__\B%/__)!3__________R44__________\G%"@4*13_______\J%/__*Q3_
M_RT4+A0O%#`4________________,13__S(4_____________S04-13_____
M-A3__________________________________________S<4.!3_______\Y
M%/____\Z%/_______________SL4/!0]%#X4/Q1`%$$4_____________T(4
M1!3_______]%%$84________1Q1(%/_______TD4_____TH4_____TL4313_
M______________]/%/____]0%%$4_____________U(4__]4%/__________
M_____U445A17%%@4613__UH46Q3_____7!3_____711>%/__________7Q3_
M______]@%/__8A3_____8Q1D%/__________________911F%&D4:A3_____
M_____________VL4;!3_______________________]M%/____]O%/__<!3_
M_W$4<A3__W04=13__W84=Q1X%/____]Y%/__>Q1\%/__?A1_%(`4__^!%/__
M@A2#%/__A!3__X84__^'%/_______________________X@4____________
M______^)%(H4BQ3_______________________________^,%(X4________
M__^/%)`4D122%/__DQ3_______________^4%/______________________
M____________________E13__Y@4F12:%)P4G13_____________________
M__________________^>%/____^@%/____________^D%/____________^E
M%*84J!3__________ZD4________________JA3__________ZL4__^L%/__
M_____ZT4________L!2R%+,4M!2V%/______________________________
M____________________________________________________N!3_____
MN13__________[L4O13__[X4_____[\4___________________`%/______
M_\$4________________PA3________________#%/_______________\04
M_____\<4R13________*%,L4S!3__________\T4SA3__\\4___0%/__TA33
M%-04___________________________5%/_______]<4___8%/__________
MV13________________________________________________;%-T4X!3_
M____X13__________^(4___________C%/__________Y!3_____Y13_____
M_____^84___H%/_____________________I%.L4[!3__^T4_____^X4____
M_^\4___P%/_____________R%/_____________________T%/__________
M]13_____________]A3W%/________________@4^A3_________________
M_______[%/___________13______________A3___\4________________
M`A4#%?__________________!17__P@5__\)%0L5_____PT5____________
M_________Q`5_____________Q85__\7%?____\8%1H5'Q4A%?__________
M(A7__R,5)14F%?_______RH5__\K%2T5+Q7_____,!4Q%?______________
M_S45-Q7_____.!4]%?__015"%4,5_____T05__]%%485__]'%4@5________
M__]*%4L5__]-%5$54A54%?_______U455A7_______________]7%?____];
M%5T57A7__U\58Q7_______]G%6D5________________:Q5L%?__________
M________;15N%6\5__]P%?____________________]Q%7(5<Q5T%?__=17_
M____=Q7_______________________________________________]X%7D5
M>A7_____________________>Q7_______]\%?____^`%?______________
M______________________^!%8(5@Q6$%?____^%%?_______X85B!6+%?__
M________C!6-%?_______XX5________CQ7_____DQ64%?____^5%?__EQ7_
M_Y@5_____________YD5_____YH5FQ6<%?____________^=%?____^>%?__
M__^?%?__H!6A%?____^B%:,5_____Z05________I17_________________
M_Z85IQ7_____J16J%?____^K%?__K!6N%:\5L!7__[$5________________
M_____[(5_____[05_____[85_____________[<5N!7__[D5NA6[%;P5O17_
M_[X5__^_%?__P!7!%<(5PQ7$%<45R!7)%?__RA7+%?__________S!76%=<5
M___________9%=L5W17__________]X5_____^$5___B%>05___E%>85____
M_________________^<5________Z17_____ZA7________K%?_____M%?__
M________________[A7P%?$5___________S%?05]A7X%?__^17_________
M__H5___[%?________T5_A7______Q4"%@,6__\$%@46!Q;__________PD6
M"Q8,%@T6_____PX6__\/%O____\0%O__$183%O____\4%O____\5%O______
M____________________________________________________________
M_____Q<6_____QD6_____QH6'!8=%O_______________________Q\6____
M_________R`6(1;_____________(A8C%O__________)!8E%O____\F%O__
M________________*!;_______________\I%O__+!8M%BX6____________
M____________________+Q8P%C$6__________________________\R%O__
M,Q;__S06________-18V%O______________________________________
M____________-Q;_____________.!;_____________.A8[%CP6________
M__________________\]%O_______SX6__\_%O____________]`%O__01;_
M_T(6________________0Q9$%O____]%%O____]'%O____________](%O__
M__________])%O__2A;_____3A;_____________3Q;_________________
M_________U`641;_____________4A93%O__________________5!;__U46
M__]7%E@6________6A;_______];%O__________7!;__U\6____________
M______]@%F$69A9G%O__________________________________________
M:!;_____:19J%FT6_____VX6__]O%O____________________]P%O__<1;_
M_________W(6_____________W,6__________________]V%G<6_____W@6
M>19^%G\6__^`%O____________________________________________^!
M%H(6@Q;__X06A1;__X86__________________^'%O_______X@6__^)%O__
M_____XH6C1;_____________CA;__X\6________________________DA;_
M____________EA;_____________F!:9%O____________^:%IL6__^>%O__
M_____Z$6HA;__Z,6IA;_______________________^G%J@6_____ZD6__^J
M%JL6K1;_______________^O%O__L!:R%K06__________^U%O__________
M__^V%O_______________________[<6N!;__[D6__^Z%O_______[L6____
M_________[X6_____[\6________P!;__________________\$6________
M___________"%L,6___$%O_____%%O_____&%O_______\<6___(%O__RQ;_
M____________S1;________.%O_______________\\6_____________]`6
MTQ;_____________U!;________9%MH6VQ;__]P6_____]\6____________
M_________^`6X1;B%O_____C%N06_____^46___F%O__________________
M___G%O_______________^@6________________________________Z1;_
M_______________________________J%O_____________K%O__[!;M%O__
M_____________^X6[Q;________P%O$6___________________R%O,6____
M____________]!;_____________________________]1;___________86
M______<6^!;________Y%O__^A;[%O_____\%O________________T6____
M_____A;___\6__\`%_____\!%P(7!Q?__P@7"1<.%Q$7_____Q(7________
M$Q<5%Q87%Q<8%_______________________________________________
M____________&1<:%___________________'!?__________QT7'A?_____
M'Q?_______\C%R07__\F%R<7__________\I%_____________________\J
M%_____\L%___+A?_____+Q?_______\P%________________________S$7
M,A?_____,Q<U%S87________________.!<Z%_____\[%S\70Q?__T47____
M_T87________2!?_____2A=.%T\741=3%U87_____________U<7________
M________6!?__UH76Q=<%UT7__________]>%V(79!=F%___9Q?_____:1?_
M______________]J%___;!?_______]M%________VX7__]O%___________
M_____W`7_____W$7<A?_____<Q?__W47________>1?__________WT7?A?_
M_________________W\7@!?_____@1>"%___@Q>$%X87B!>*%_____^,%___
MC1>.%________Y`7D1?__________________Y47EQ>8%YD7FQ><%___GA?_
M_________________Y\7________H!?_______^B%___HQ>E%Z@7________
MJA?_______________^K%ZT7_____________________________Z\7__^Q
M%_____________^S%___________M!?__________________[47________
M_____[<7_____[D7NA?_______________________^[%_______________
M____O!?"%________________________________\,7Q1?________&%___
MR!?__\H7________________RQ?,%___________S1?__\X7___0%](7TQ?_
M_________]07___8%]D7VA?;%]P7W1?>%______________________B%___
M_____________________^,7___________________D%^47___F%___YQ?J
M%^L7___L%________^T7[A?________Q%___\A?___,7______07]1?_____
M___________V%______________________W%______[%_T7_A?_%P`8`1@"
M&/_______P,8__\%&/__________________________________!AC_____
M__\'&/__"1C_____"AC__PL8________#1C__PX8__\/&!`8_____Q$8____
M____$AC__________Q,8%1C_____%AC__Q<8_____Q@8&QC_____'!@>&!\8
M__\@&"$8(AC_______________________________\C&"48_____R<8__\I
M&/_______________RH8________*Q@M&/__+AC__S`8,1@S&/__________
M__\T&/__-1@V&/__-QC_______________\X&#D8_____________SL8____
M_________ST8__\^&/_______S\80!C__T$80QC__T08_____T48________
M_____T88_____T<821C__TH8__]+&$T83AC__U`84AC__U,85!C_____51A6
M&/_______U@8__________]:&%L8__]<&%T87QC_______]@&/__8AC_____
M__________]C&&08________________91C_______]F&/_______V@8____
M_________________________VD8:AC_____:QAM&&X8________________
M;QAP&'(8<QC_____=QC__W@8__]\&/__________?1C__W\8________@!B!
M&/____^"&/_______X,8__________^$&(D8__^*&(L8________________
M_____XP8__^.&/__________CQC_____DQB4&/__E1C_____________EQB8
M&/____________________^9&/__FQC__YP8__^=&/__GABB&*08I1BI&/__
MJQBM&*\8__^P&/__L1BR&+,8M!BU&+88__^W&/__N!C_____N1C_____NAB[
M&+P8O1B^&+\8P1C#&,08Q1C&&/_______\@8___)&/__RAC__\L8________
M___,&/__SAC0&-08U1C6&-<8___8&/_______]D8VAC__]L8_____]P8W1C_
M_]X8WQC@&.$8XAC__^08_____^48YACH&.D8ZACK&/__________[!CO&/__
M______`8\1C___,8]1C_____]ACW&/__^!C\&/T8___^&/______________
M_____Q@`&0(9!!G__P49!QD*&0L9#1G__________________PX9#QD1&?__
M__\2&?__$QD4&?__%1D6&?____\7&?__&!G__QH9________'!G__QT9'QG_
M_R(9__\C&?__)!G__R89*!G__________________RD9+1DN&?__+QDP&3$9
M,ADS&349-QG__S@9.1DZ&3L9/!G__ST9/QE`&?__________01G_____0AG_
M____0QE$&?__11G__T892AE+&4T9__]/&5`941E3&50951E6&?__6AE;&5P9
M__]=&5X9__]@&?__8AEC&?__9!EE&6899QEK&?____]L&?__;1EN&?__;QG_
M_W`9_____W$9__]R&7,9__________]U&?____]W&?_______WD9>AE[&7P9
M__________]]&7X9________?QG__X$9@AG_____A1G__X89AQF(&?______
M_XD9_____XL9C1F/&?____^0&?__D1F2&?____^3&949__^8&9D9FAF<&?__
MG1G_______^>&:,9_____Z09__^E&?__IQFI&?__JAG__ZL9KAG__[$9____
M______^S&?__M!FU&;89_____[@9N1FZ&?____^[&?____^\&;X9__^_&?__
MP!G_____P1G#&<49___(&<L9S1G.&?_____1&?_____________2&?_____3
M&=49UAG7&?_____8&=D9________VAG;&=P9WAG__^`9XQGD&><9_____^D9
MZQGL&?__[1G___`9________\AGS&?__]AGX&?D9^AG[&?P9`!H!&@(:`QH$
M&@8:!QH(&@D:"AH+&@P:#1H.&@\:$!H1&A,:%!H5&A8:%QH8&AD:&AH;&AP:
M(!HA&B,:)!HE&B8:)QHH&BD:*AHK&BP:+1HN&B\:,!HR&C,:-!HU&C8:-QHY
M&CH:.QH]&CX:/QI`&D$:1!I%&D<:2!I)&DH:31I.&D\:41I3&E0:51I7&O__
M6!I:&EL:7!I=&EX:7QIA&F(:9!IE&F<::1IJ&FL:;!IM&FX:;QIQ&G(:<QIT
M&G4:=AIW&G@:>1IZ&GL:?1I^&G\:@!J!&H(:AAJ'&H@:B1J*&HL:C!J-&H\:
MD!J1&I(:DQJ4&I4:EAJ8&ID:FAJ;&IP:G1J>&J$:HAJC&J0:IAJG&J@:J1JJ
M&JP:K1JN&J\:L!JR&K4:MAJW&K@:NAJ[&KT:P!K________"&O__________
MQ!K%&O_______\H:___,&O__T1K3&M8:V!K________:&O_____=&O______
M____________WQK__________________^`:_____________^(:________
MY!KE&N@:Z1KJ&O__________________[!KM&O__[QK___$:\AKS&O8:___Z
M&OL:_!K________]&OX:______________\:__________________\`&___
M`1O__P(;`QL$&_____\%&P8;!QO_______\)&_____________\*&___#!O_
M____#AO__________________________P\;$1L3&___________________
M__________\4&_____________\5&Q8;%QO_____________&!O_______\9
M&________________QL;'!O__________QT;__\>&_____________\?&R`;
M(1O__R,;_____R0;_____R4;________)ALG&___*!LI&_______________
M_________RH;_____RL;________+!O__________RT;+AO__R\;_____S`;
M,1O_______\S&___-!O__S4;__________________\V&_____\W&S@;.1O_
M____.AO__ST;/AO__________________S\;0!M#&________________T0;
M__]&&___________________2!M)&___2QO__________TX;__]1&U,;5!M7
M&___6!M:&UL;7QO__V(;8QMD&V8;9QMH&___:QO_______]L&VX;________
M__]O&___<1O__W,;=!MU&___________=AO_________________________
M____________________=QMY&_____]Z&_____][&___________?!O__WT;
M?AO__X`;@1O__X,;________________A!O_____A1N&&X<;B!O_____BQO_
M_XT;_____________X\;__________________________________^0&___
MD1O__________Y(;_____________Y0;E1O__Y8;EQO__YD;____________
M_________YH;________________________________FQO__YT;GQNA&Z(;
MHQO__Z0;__^F&___IQNJ&ZL;__^M&ZX;_____Z\;_____[`;LAO_________
M_________[0;_____________[4;__^V&_____________^W&___N!O__[L;
MO!O__[T;OAO`&________\(;___________________#&________\0;___&
M&___QQO__________________\@;R1O*&________________\L;___,&___
M________S1O__________]`;___1&](;___________3&___________U1O_
M____UQO__]@;V1O__]H;___;&]P;________________________________
MW1O>&___WQO__^$;___________B&______________C&______D&^4;____
M_______F&________________________^<;___________H&______J&___
M[AOP&_$;\AO_____\QO___________4;]QO___@;___Y&___^AO________\
M&____________AL`'`$<__\"'/__`QP$'`8<__\''/____\('/____\)'/__
M________"AS_____"QS_______\,'/____________\-'/______________
M______________\/'!`<$1P2'!4<_____Q8<&!S__QD<_____QH<_____QL<
M'APA'/__________________________(AS_____________(QS_________
M_R0<__\F'"<<________*!PI'/____\J'/__*QS_____________________
M________________+1S_____________________________________+AS_
M____________________+QPP'#(<__\S'/_______S0<-AS__________S@<
M.1S__SL<_____S\<0QQ''$@<21S__________________TX<____________
M_T\<_____U$<4AS__________________U,<_____U0<__________]5'/__
M_____________________U8<__________________________]7'%@<____
M_________UD<_____V`<_____________V$<________8AS__V0<91S_____
M9AQG'&@<:1QJ'&\<__________________________________________]P
M''$<__________]R'/_______________________W,<________________
M__]T''8<_____W<<_____________W@<________________>AS_______]\
M''T<__]^'/____]_'(`<_____X$<________________________________
M_____X(<__________________^$'(4<__^&'/______________________
M____________________________B!R)'/____^*'/____________^+'(T<
M_____XX<________CQR1')(<DQR4')4<EAR7')@<FAS__YT<GQR@'*$<HARC
M'*0<I1RF'*<<J!RI'*H<________K1S_____________KAS__Z\<________
M________________L!S__________[(<_____________________[0<__^U
M'+8<__________________^W'/_______[@<__________^Y'/__________
M_____________[H<NQR\'+T<OAR_',`<PAS#',0<___'',D<RAS_________
M_______________________________________+'/__S!S-'/__________
M________________SQS_____________________________T!S________1
M'-0<U1S_____UAS__________]D<________________________________
M___:'/_____;'/__W!S='/__________________WAS__________^`<____
M_^$<___B'.<<________Z!SJ'.P<[1SN'/_______^\<___________P'/__
M___S'/0<______4<________]AS_____________________]QS________X
M'/D<___________________\'/___________1S^'/___QS_____________
M`!W__P$=__\#'?__!!W_______\%'?__!AW__P<="!W__PD=____________
M_PH=__________________________\+'0P=________#1W__PX=__\/'1`=
M________$1W_____$AT4'?__________%1W__________QD=____________
M______\;'?__'!W_____________________________________'1W_____
M_____QX=________'QW_____________(!W__________R$=____________
M_R,=_____________________________R4=__\F'2<=_____R@=__\I'2H=
M________________*QTN'2\=__\P'?____\Q'?____________\S'?____\X
M'?__________________.1T['?_______________________SP=/1W_____
M/AU`'?____________________]!'?__________0AW__T,=1!W_________
M______]%'?__1AW_____1QU('4D=2AU,'4X=__]/'5`=41U2'?__________
M5!W__________U4=________5AU8'?____]:'?__6QW__UT=7AW__U\=____
M_V`=__]A'?__________________8AW_______________]C'60=_____V4=
M_____V8=__]G'?__:!W_____:AW__________________VL=;AW_________
M_________V\=__]P'?__<AW__________W,=__]T'74=_____W8=>!W_____
M__________]Y'?_______________WH=_____WP=__]]'7\=@1V"'80=A1W_
M_X<=__________________^)'?__BQW__________XP=D!W_____________
M__^4'?_______Y<=F!V9'?_______YL=________________________G!W_
M_Z$=__________^C':0=__________^F'?____________________^H':P=
M__^N':\=__^P';(=__^S'?_______[8=__^W'?__N1W__[H=NQW_____OQW!
M'?__PQW%'?__QQW_____RAW________,'?_____-'?_______\X=________
MSQW__________________________]`=___1'?______________________
M____TQW_____U!W__]8=___7'?__________V!W__________________]H=
MW!W__]T=___>'?__WQWA'>(=_____^0=YAWH'>D=___K'?_____________L
M'>T=[AW________O'?$=___R'?,=___T'?________4=___________W'?@=
M___Y'?H=^QW\'?T=_AW_'?_______________P`>`AX#'O______________
M______\$'@<>__\('O__________"1[_____________________"A[_____
M_____PL>#![__________________PT>_____________PX>____________
M____________________#Q[_____$1[_____$AX4'A8>__________\7'O__
M________&A[_________________________________________________
M____&QX<'AT>'AX?'B`>(1[_____________(AXC'O__)![__________R8>
M________)Q[__________R@>________________________*1XJ'BL>____
M____________________+![__________________________________RX>
M________________________+Q[_______\P'O__________________,1[_
M_S0>-AXW'O__.![_____.A[_______________\['O__________________
M_____SP>__\]'O__________/A[__S\>________________0![__T$>____
M____________0A[_______]#'O__1!Y%'D<>__]('O__21[_______]*'O__
M________2QY,'O_______________________TT>3A[__________U`>____
M_U$>4A[__U0>_____U8>5Q[_____________________________________
M__________]8'O_______UD>__]:'O____];'O__7!Y='EX>____________
M_U\>8![_____81[__________________________________________V(>
M_____________________V,>_____V0>_____V4>________9A[__V<>:![_
M_VD>_____________VL>________;!YN'F\>_____________W$><AYS'G0>
M=1YV'O__>1YZ'O_______________________WL>__]]'GX>?Q[_______^!
M'H,>__________^$'O_______X4>__________^&'O____^)'HL>CAZ/'O__
M__________^1'O__DAZ3'I0>_____Y<>F1[_____________________FAZ;
M'IX>GQ[__Z`>__^C'J0>IAZI'JH>K![_______^O'K`>L1[_____LA[_____
M__^S'O__M![__________________________[4>________MA[_________
M______^W'K@>NQ[__________[P>________________________________
M__________^]'O__P![__________________________________\$>PQ[$
M'L4>___________&'L@>___)'O__________________________________
MRA[+'O__S![__\T>___.'O_____/'O_______________________]$>____
M_](>TQ[_____U![5'M<>V![9'ML>W![__]X>___________?'O__________
M_____^`>X1[__________________^(>________________________XQ[_
M____Y![__^4>___F'N<>_____^@>ZA[__________^L>_____^P>___M'O__
M________________________________[A[________________O'O`>\1[_
M_______R'O_____S'O__________________]![________V'O__________
M]Q[X'O__^1[_____________^A[['O________________P>______T>____
M_____A[______________Q[__P`?`1___P(?_____P,?__\$'___________
M__________\&'___!Q________________\)'PL?#!\-'Q`?%!___Q4?%A\7
M'Q@?_____QL?'1___Q\?__\A'___(A________________\E'________R8?
M)Q\H'___*A\K'___+!______+1\N'___+Q\P'_____\R'S,?_____S4?__\Y
M'SH?__\\'ST?/Q]`'T(?0Q]$'T8?2!])'TL?3A]/'U`?41]2'U,?5!]5'___
M__]6'_____]7'_____________]9'UH?__________];'_____]<'UT?____
M______________]>'___________8!___V$?__]C'V0?________9A___V@?
M:A]L'VX?;Q___________W`?__]Q'___<A___W,?__]T'___=1]V'___=Q]X
M'WD?>Q___WP??1___WX?__]_'X`?@A^$'X4?__^&'________X<?B!^)'___
MBA________^+'___C!^.'___CQ________^1'Y(?DQ^5'________Y8?____
M______^7'___________F1___YL?G!___YT?__^>'___GQ^@'Z$?HA^C'___
M__^D'_____^E'Z8?IQ^H'ZD?JA______JQ^L'___K1___ZX?KQ^Q'[(?__^S
M'[0?MA^W'___N!________________^Y'_____^Z'___________NQ^\'[T?
MOA___[\?P!___\$?PA_________#'\0?_____\4?QA___\@?___*'_______
M_\L?___,'\T?___.'\\?T!_1'___TA___],?___5']<?___9']H?___;'___
M_____]P?_____]T?_____]X?___@'^$?_____^(?___C'______D'___Y1__
M_^8?YQ_I'___ZA___^L?[!_________M'^X?________[Q_P'_$?\A____,?
M]1_W'___^!____H?^Q____P?___]'_\?!2`&(/____\'(/__""#_____"B`+
M(`T@__\.(/__#R#__Q$@__\2(!,@%"#__Q4@%B#__________Q<@__\8(/__
M&2#__QH@________&R#__QP@'2#__QX@'R`A(/__(B#_____(R`E(/______
M_________R<@__\H("D@*R`L(/____\N(/____\O(/____________\P(/__
M__\Q(/__,R#_____-"#__________________S8@_____S@@__\Y(#H@.R#_
M____________/"#__SX@/R!`($$@0R#_____12#_____________________
M_____T8@2"#__TH@2R!-($\@4"!1(/__4R#_____5"!5(/_______U8@6"!9
M(/__6R!=(/__7R#__V$@__________]B(&0@92!G(&D@__]L(/__;B!O(/__
M<2!R(/_______W,@__]U(/__=B#__W<@>2!Z('L@?"!]('X@?R"`(($@@R"$
M((4@AR"(((D@BB"+((P@C2".((\@D""1()(@DR"5()8@ER"8()H@FR"<()T@
MGR"@(*$@HB"C(*0@I2"F(*<@J""I(*H@JR"L(*T@KB"P(+$@LB"S(+0@M2"V
M(+<@N""Y(+H@NR"](+X@OR#`(,$@PB##(,0@Q2#&(,<@R"#)(,H@RR#,(,T@
MSB#0(-$@TR#4(-4@UR#8(-D@VB#;(-P@W2#?(.`@X2#B(.,@Y"#E(.8@YR#H
M(.D@ZB#K(.P@[2#O(/`@\2#R(/,@]2#V(/<@^"#Y(/L@_"#^(/\@`"$"(0,A
M!"$%(08A!R$((0DA"B$+(0TA#B$0(1$A$B$3(10A%B$8(1DA&B$<(1TA'B$?
M(2`A(2$B(2,A)"'_____)B'__________R<A*B'_____________+2'__RXA
M__\O(?_______S,A__\U(?____\Y(3TA________02'__T(A____________
M____________0R'_______________]$(44A__]&(?__________________
M1R'_______]((4DA2B'__TLA________3"'__________TTA__].(?__3R%0
M(5$A4R'_______]4(54A5B'_______]7(?____]8(5DA6R%=(5XA82%B(60A
M__________]E(68A9R%H(6DA:B%K(6XA<2%R(?__<R%T(7<A__]X(7DA>B'_
M_WLA?"%](7XA__]_(8`A@2&"(8,AA"&%(?__AB&'(8@ABB&+(?__C"&.(?__
M__^0(9$ADB&4(98AER'_____F"&9(9HAG"'__YTA__^>(9\AHB&D(:8A__^H
M(:DA_____ZHAK2&N(:\A_____[`A________L2&S(?__M"'_____MB&W(;@A
MN2&Z(?____^[(?____^](;XA__^_(<`A___!(<,A___&(?__QR'((?__R2'+
M(<TA___.(<\A________TB'3(=0AUB'7(=@AVR'<(=XAWR'A(>,AY"'E(><A
MZ"'I(>HAZR'L(>TA[B'Q(?,A]"'U(?8A]R'X(?DA^B'[(?PA_2'^(?\A`"(!
M(@(B`R($(@<B""()(@HB"R(,(@TB#R(0(A$B%"(5(A8B%R(8(ADB&B(;(APB
M'B(?(B`B(2(B(B,B)"(G(BLB+"(M(BXB+R(P(O____________\R(O__,R+_
M______\T(C4B________-B(W(O__________."+_______\](O__/B(_(O__
M__________________]`(O____________]!(O_______T(B________0R+_
M______________________________]$(O__12+_______]&(O____]'(O__
M22)*(O____________]+(O____],(O__________________32)/(O______
M____________________________________________________________
M4"+_____42+_______]2(O____________________________________]3
M(E0B52)6(E<B6")9(EHB6R+__________UPB________________7B+__V`B
M82)C(O_______V0B____________________________________________
M_________________V4B9B)G(F@B:2+_____:B)K(O_______VPB________
M;2+_____________________________;B+_______________]O(G$B____
M_W(B__]S(G0B_____W4B________________________=B+_______]W(G@B
M_____________________________WHB_____________________WPB?B+_
M_________X`B_____X$B@B*#(O____^$(O__A2*&(HDB__^+(O__C2+__XXB
MCR*0(O__D2+_______^3(I0B__^5(O__________EB*7(O____^9(IHB____
M____FR+__YTBGB+__Y\BH"*D(J4BIB+_____________________________
M__^G(O_______Z@B__^K(O_______Z\BL"*Q(K(B________LR*T(O__M2+_
M______________^V(O_______[DB_____[HBO"*^(O_______________[\B
M___________`(O__PB+________#(O__QB+'(L@BR2+*(LLBS2+__\XB____
M_\\B___0(O__T2+2(M,BU"+__]4B_____]<B_____]@BVB+;(MTB________
MWR+__^$BXR+E(N8BYR+__^@B________Z2+J(O_____K(NTB___N(N\B___P
M(O________$B______(B___S(O__]"+V(O<B___X(ODB___Z(OTB___^(@`C
M`2/_____`B/_______\$(P4C_____________P8C_____P<C__________\(
M(_____\)(___"R,,(___#2/__PXC#R,0(Q$C$B,3(Q0C%B,9(QHC'",>(Q\C
M(",A(R(C(R,D(R4C)B,G(R@C*B,K(RPC+2,N(R\C,",Q(S(C-",U(S<C.",Z
M(SLC/",](SXC/R-!(T(C0R-$(T4C1B-'(T@C22-*(TLC3"/_____32-0(U,C
M5"-6(_____]9(___7"-=(U\C82/__V0C__]E(V@C:2/_____;"/_____;2-N
M(_____]O(W(C_____W4C=B/_____>"-Y(WHC_____WLC?"-](___?B/_____
M________@"/__________________X$C@B/__X,CA".%(X8CAR/_________
M_XHCBR/_______^,(XTC__^.(_____^/(________Y`CDR/__________YDC
MFR/__________________YTCGB/__________Y\CH".A(________Z(C____
M____HR.E(___IR/_______^J(________________________ZLC__^L([(C
M_____[,C________________M".V([<C________________N".Z([LCO"/_
M_________[TC________OB/________`(\(CQ"/_____Q2/________&(\<C
MRB/,(___S2/__\XC_____\\C___0(___TB/4(________]4C________UB/_
M____________UR/_____V"/________:(]LCW"/__]TC___>(___________
MWR/_____X"/_____X2/__^(CY2/__________^@CZ2/J(___ZR/_________
M_______________L(______________________M(___[B/_____[R/P(___
M\2/___________________________(C\R/T(___]R/________X(_______
M____________________^R/___PC_B/_(P`D`20#)/__________________
M________!"0&)/_______________P<D""0))/______________________
M_________PHD"R0,)!`D__________________________________\1)/__
M__\2)!8D__________________\:)/__&R0<)"`D____________________
M______________________\A)/____________\B)/____\C)/__)B3__R<D
M__\H)"DD_____RHD__\K)"PD__________\O)/_______S`D,20S)#0D__\U
M)/____________________\V)/__________-R3_______\X)/__________
M.B3_______\[)#XD_____T`D__]!)/__________0R3_________________
M____________121&)$<D________223_______]*)/__2R1,)$TD_____TXD
M_____________U`D4212)%0D5R3_______]8)/__6B3_____________7"3_
M______________]>)&`D__________]B)/_______________V4D_____V<D
M:23_______]K)&TD__]N)/__;R3__W`D<B3__W0D=B1X)/__>B3__WPD?21_
M)($DA"2%)(8DB"2))(HDBR3__XTDCB3_____CR21)/__DB24)/__E226)/__
MER3_____________F"29)/__________H23__Z(D__^C)*0DI22H)/______
M_[`DL23__[(DLR2T)+4D__^W)+@D________N22Z)/__O"2])+XD__^_),`D
M_____________________\$DPR3__\0D___%)/__QB3'),@DR23*)/_____,
M)/__SB3__]`D_____]$DTB3_____TR34)-4DUB3_____UR38)-DDVB3_____
M___;).`DX23B).,DY"3__^4D___G)/_______^@D________Z23__^HD____
M_^LD["3_____[B3__^\D___P)/__\R3___4D___V)/________@D^23_____
M___Z)/______)/__`R7__P0E__\%)08E________!R4()?____\))?__"B7_
M_________________PLE________#"7__PTE__\.)1(E__\3)?__%"46)1@E
M__\;)?__'"7_____'27__QXE'R7__R`E(24B)2,E)"4E)2<E_____R@E*24J
M)?_______RPE__\N)?__+R4P)3$E________,B7__S,E__\T)?__-27_____
M_____S8E_____S<E_____S@E________________.27__SHE__\_)?__0"7_
M______]")40E125&)?__1R5,)4XE_____U$E4R54)54E5B7__U<E_____UDE
M__]:)?_______ULE__________]<)?____]=)?__7R5@)6$E____________
M____8B5D)?__927_____9B7_____9R5H)6HE:R7_______]L)6TE;B5O)?__
M_____W$E__]R)7,E__]T)74E__]X)7DE_____WHE?"7_____?25^)7\E____
M_________X`E__^!)8(E__^#)?____^$)84EAB7__X@EBR7__XPE________
M________C27_______^.)?__CR60)?____^2)?__DR7_______^5)98E____
M____ER7_____F"7_____F26;)?____^<)?__H"6A)?_______Z(E________
MHR6E)?__IB6G)?__J"7_____J27_____JB6K):PE_____________ZXE__^P
M)?__LB6T);4E__^V);<E_____________[@ENB6[)?____^\);XE__^_)<`E
M___!)<(EQ"7__\8E_____\<E___()?_____))?__RB7__________\LE___,
M)?__S27________.)<\E________T"71)?_____2)=,E___4)?_______]4E
MUB7________7)=@EV27:)?__WB7@)?__X27B)?_____D)?______________
M____Y27__________^8E___G)?__Z"7________I)?__________ZR7M)?__
M________________[B7__________^\E___P)?$E\B7_____\R7T)?4E]B7_
M____^"7_____^B7[)?__________`"8!)@(F_____P,F_____P0F________
M!B8')O__""8-)O__#B;__Q`F__________\1)O_______Q(F%"86)O______
M____%R;__Q@F__________\9)ATF(28B)B,F__________\D)B8F*R;__RTF
M__\N)O____\O)C`F,2;__________S(F__\T)C@F__\Y)CHF.R8\)O____\]
M)O__/R;__T`F_____T$F0B9$)D4F__]&)D@F_____TDF2R9.)D\F4"91)E(F
M4R94)E4F5B97)E@F629:)ELF7"9=)EXF7R9@)F$F8B9C)F0F929F)FHF:R9L
M)FTF;B9O)G$F<B9S)G0F=B9W)G@F>29Z)GLF?"9])G\F@":!)H(FA2:&)H<F
MB":))HHFC2:.)H\FD":1)I(FE2:6)I<FF"::)ILFG2:>)I\FH2:B)J0FI2:G
M)J@FJ2:J)JLFK":N)J\FL":Q)K(FLR:T)K4FMB:W)K@FN2:Z)KLFO":])KXF
MOR;`)L$FPB;#)L0FQB;')L@FR2;*)LLFS";0)M$FTB;3)M0FU2;7)M@FVR;<
M)MTFWB;?)N$FXB;C)N0FY2;G)N@FZ2;J)NTF[B;O)O`F\2;R)O,F]2;W)O@F
M^2;Z)OLF_";])OXF_R8`)P$G`B<#)P0G!2<&)P<G""<))PHG#"<-)PXG#R<0
M)Q$G$R<4)Q4G%B<7)Q@G&2<:)QLG'"<=)QXG'R<@)R$G(B<D)R4G)B<G)R@G
M*2<J)RLG+"<M)RXG+R<P)S(G,R<T)S4G-B<X)SDG.B<\)STG/B<_)T`G__]!
M)T(G0R=$)T4G1B=')T@G22=*)TLG3"=-)T\G4"=1)U(G4R=4)U4G5B=7)U@G
M62=:)ULG7"=>)U\G8"=A)V(G8R=D)V@G;"?_____________;B=R)___<R=T
M)_____]U)W8G>"=Y)___>R=\)___?2=^)___@">")X0GA2?_______^&)X<G
M________________B2>+)XPGCR>0)Y$G__^2)Y,GE"?__Y4GEB>7)_______
M_Y@GFB?__YPG__^>)_____^?)___H2>B)Z,GI">E)________Z8G_____Z@G
MJ2>J)___JR>M)ZXGKR?_____L"?__[$GLB>S)[0GM2>V)[DGOB?_____Q"?_
M_\<G___()\DGRB?__\LGS"?_____S2?.)\\GT"?1)](GU"?5)]8GV"?9)]LG
MW"?=)]XGWR?@)^$GXR?D)^4GYB?G)^@GZ2?J)^LG["?M)^XG\"?Q)_(G\R?U
M)_8G]R?X)_DG^B?[)_PG_2?_)P`H`B@#*`0H!2@&*`<H"2@**`LH__\-*/__
M__________\.*!(H__\4*!4H%R@9*!LH_____QPH__\=*/__'B@@*"0H)2C_
M_R<H_____R@H__________\I*"LH________+2@N*"\H,"@Q*/_______S(H
M__________________\S*#8H__\W*/_______S@H.B@[*#TH________/BC_
M_T`H02C__T@H22C_______________],*/____]0*/_______U$H4BC__U,H
M5BC__U@H__]:*/__7"A>*/__8BC_____________9"C__V4H__]F*&@H:2C_
M_________VPH;BC_____;RC__W`H__]Q*/__>"AY*/____]\*/__________
M?RC__X`H@RC_____A2B&*/__C2B0*/__D2C__Y(HE"B6*/__F"B?*/__H"BA
M*/____^B*/____________^D*/_______Z8H__^G*/__J"C__ZDH________
MJRBN*/____^O*+`HL2BS*+4HMBBY*+HH__^\*+TH____________________
M____________OBC__[\HP"C_____P2C"*/_____#*,4H_____\8H_____\@H
M___________________)*,HH________________S2C_____________SBC_
M____SRC2*/_____________5*-8H___________7*/_____________:*/__
M________________________VRC_____W"C__^`H________X2CB*/__XRC_
M_^0H___E*.@HZ2C_____[2CT*/LH__\"*00I!BD'*?__________"BD+*?__
M#"D-*?__________$"D6*1<I&2G__QHI&RG_____'"G__QXI________(2G_
M____)"G_____________________)2G_____)BG_____________________
M*"G__RHI*RDL*?__+2G__RXI+RG_______________________________\P
M*?_______________S$I,RDU*?_______________S8I__\W*3DI_____SHI
M________.RG_______\\*3TI_____SXI__]`*?____]!*?__0BE$*?__12E&
M*4<I_____________TDI_____________THI_____TLI3BE/*?__________
M__]0*?__4BE3*58I6"E9*5HI6RE=*5XI7RG__V`I82G_____8RG_________
M____9"G_______]E*?__9BEG*6@I__]I*6HI:REL*?__;2G__VXI__]O*7`I
M<2ER*7,I="G_______]U*78I__]W*?__>2G__________WHI_____WLI?2E_
M*?____________^`*8(I@RG__X4I__^'*?__B"G_____BBF+*8TID2F5*98I
MF"F<*?__________________G2G__________YXIGRF@*:$IHBG_____I"FE
M*:8IJ"FJ*?__JRFL*:TIKRG_____L2G_______^R*?____^S*?__M"G_____
M__^U*;8I_____[<IN2FZ*?__O2F^*;\IP"G!*<(IPRG$*<4IQRG(*<DIRBG+
M*<PIS2G.*<\IT"G2*=,IU"G6*=<IV2G:*=LIW"G=*=XIX"GA*>(IYBG__^<I
MZ2GJ*>LI["GM*>XI\"GQ*?(I\RGU*?8I]RGX*?DI^BG[*?PI__________\$
M*@4J"2K__PHJ__\+*O____\,*@TJ$"K__Q$J$BH3*O_______Q0J_____Q4J
M%RK__QDJ'BH?*O_______R,J__\H*BXJ+RHP*C$J,BHS*C0J-2HV*C<J.2HZ
M*CLJ/"K__STJ/BI!*D0J12I&*O__1RK_____2"I)*DHJ2RI-*DXJ3RI1*E,J
M__]4*O__5BK__U<J_____________U@J62I:*ELJ________7"I=*EXJ____
M____8"IC*O__9BIG*F@J:2IJ*FLJ;"IN*O__;RIP*O__<2K__W,J="IU*O__
M=BIW*G@J>BK_____________>RI_*O_______X$J__________^"*O__@RJ$
M*H4JARJ(*O__B2J**HLJC"J-*HXJCRK__Y`J__^1*O__DBK_____DRJ4*I4J
MEBJ7*I@JF2K_____FBJ;*O__________G"K__YTJ_____YXJ__^?*J`J____
M_Z,JI"JG*J@JJBJK*JTJKBJO*K`JL2JR*K,JM2JV*K<JN"JY*KHJNRJ\*KTJ
MORK`*L$JPBK#*L4JQBK'*L@JRBK,*LTJSBK/*M`JT2K2*M0JU2K6*M<JV"K9
M*MHJVRK<*MTJWBK?*N`J___________________A*N(JXRK_____________
M___________________D*N4JYBK_____YRKI*NHJZRK__________^PJ____
M____[2K__^XJ___P*O_____Q*O,J]2K___DJ___________________]*OXJ
M_RK__P`K`2O_____`BL#*___!"O__P4K!RL)*___"BL-*_______________
M____________#BL/*___$"L1*________Q(K_____Q0K________________
M%2O__Q8K%RO_____&"O__________________QDK&BL;*QPK__\?*R$K____
M_R0K_____R4K__________________________\F*________R<K_____R@K
M__\I*RHK__\M*_____________\N*R\K,2O__S(K________,RO__S0K-2LV
M*S<K."LY*___/2O_____/BO__S\K0"O__T$K__]"*T4K_____T8K__]'*___
M__]**TLK__]-*___3BO_____3RO__U$K4BM4*_____]5*U8K5RM8*UDK6BM<
M*UTK7BMB*V,K92MG*V@K:2MJ*VLK;"MM*VXK<"MQ*W(K="MU*W8K>2MZ*WLK
M?"M]*WXK?RN`*X$K@BN%*X8KARN(*XDKBBN+*___C"N-*XXKCRN1*Y(KE"N5
M*Y8KF"N9*YHKFRN<*YTKGBN?*Z$KHBO__________________Z,K________
M_____Z0K_____________________Z@K_____________ZDKJRO_____K"O_
M____K2NN*_____^O*_____^P*[$KLRNW*[DKNBN]*[XK________________
M________ORO!*\(K________PRO%*______'*\@KRBO__________\LK____
M_______-*________________\XK___/*________](K________________
MTRO_____________U"O________________6*]<K________________V"O;
M*___W"OA*^8KZ"OI*^HK[RO___`K]2O___8K^2O___________PK______TK
M___^*___________`"S_______________\!+/__`BS__________P,L__\%
M+/_______________PHL#"S__PTL#BS_______________\/+!`L_____Q$L
M__\2+/__________$RS__Q0L_____Q4L%RP8+/____\9+/____\:+/______
M_________QLL__\<+/____________\=+!\L("S__R$L(BPC+"0L)2PF+"<L
M________________*"S__RDL*BPM+/__________________+BPO+/____\Q
M+#(L__\S+#0L__________\Y+/____\Z+#LL_____STL/BS_____/RS__T`L
M02S_____________0BS__T0L12Q'+/_______________T@L__])+$HL2RQ,
M+$XL_____T\L__]1+/_______U(L4RS__U0L_____U4L5BS__U<L6"S_____
M_____UDL________6BQ;+/__7"S__U\L________8"S__V$L8BQD+&4L9BS_
M_________V<L:2S_____:BQL+/__;BQO+/__<2QR+/__________________
M<RQU+/____]V+'<L_____W@L>2QZ+/____]\+'XL________?RR`+/____^!
M+((LA"S__X4L__^&+/__ARR(+(HLBRS__XPL________C2S_____CBS_____
MCRR0+/____________________^3+)0LE2S__Y8LERR8+/__________F2R:
M+)LLG"S_____G2R>+/____^?+*`L__________^A+*(LHRS_____________
M__^D+*<LJ2S__ZLLK"RQ++(LLRRT++4LMBRW+/__N"RY++HLNRR\++XLORS`
M+,$LPBS$+,4LQBS'+,@LR2S*+,LLS"S-+,XLSRS0+-$LTBS7+-@LVBS;+-TL
MWBS?+.`LX2SB+.,LY"SE+.<LZ"SI+.HLZRSL+.TL[BSO+/`L\2SR+/,L]"SV
M+/<L^"SY+/HL^RS\+/TL_BS_+``M`2T"+00M!BT'+0@M"2T*+0LM#"T.+0\M
M$"T1+1(M$RT4+14M%BT8+1HM&RT<+?__'2T>+1\M(2TB+2,M)"TE+28M__\G
M+?__*2W__RLM__\L+2XM_____________R\M,"TQ+?__,BW__S,M________
M__________________________\T+34M-BTX+?__________.BW_______\\
M+?____\]+?____________\^+?__/RU!+4(M________1"W_____12W__T8M
M________1RW_____22U*+?____]++4PM________________32U.+?____]/
M+?____]0+5$M4BW_____________________________4RU4+54M5BW_____
M________5RW_____6"U9+5LM__]=+5XM_____________________U\M__]@
M+?__82UB+6,M__]D+?_______V4M9RW_______________]H+?__________
M__________]J+?__;"UM+?__________;BW_______]Q+?____]R+?__<RW_
M_W0M________________=2W_____=BUW+?_______W@M>2UZ+7PM_____WTM
M_____W\M__^`+8<M________B"V)+8HMBRW_____C"V-+8XMCRV0+9$M__^4
M+?__E2V6+9<M__________^8+?_______YDM_____YHMFRW__YTMGBW_____
M_____________________Y\MH"W__________Z$M________HBVC+?__I"VE
M+:<M________J2VJ+:LM_____ZTM__^N+?__________________KRW_____
ML"W__[$M__^R+;,M_____________[0MMRW__[XM__^_+<`MPBW#+<0MQ2W'
M+<@MRRW,+<TMSBW0+=(MTRW4+=4MUBW8+=DMVBW;+=PMW2W>+=\MX"WA+>(M
MXRWD+>4MYBWG+>@MZ2WJ+>LM["WM+>XM[RWP+?$M\RWT+?8M]RWX+?DM^BW[
M+?PM_2W^+?\M`"X!+@(N`RX$+@4N!BX'+@@N"BX++@PN#2X.+@\N$"X1+A(N
M$RX:+ALN'"X=+AXN'RX@+B$N(B[__R,N)"XE+B8N)RXH+BDN_____RLN+BXP
M+C$N,BXU+C<N__________\X+CDN.B[__SLN__________________\\+O__
M________________/2[_______________\_+O____________]`+D(N0R[_
M____1"Y&+DLN4"Y2+O__4R[__________U<N6R[_____8"YB+F8N:RYN+G(N
M_____________W8N=R[__________WDN_____WHN_____WLN__]\+GTN____
M_________WXN?R[__X`N_____X$N_____X,N_____X0N________A2Z&+H<N
M_____X@N________B2Z*+O__BR[__XPNC2[__XXN________CRZ0+I$N____
M_Y,NE"[_______^5+I<NFB[__YLNG"Z=+IXN_____Y\NH"ZA+O__HR[__Z0N
M_____________________Z8NIR[__________Z@N____________________
M______________^I+O__________JB[_____________________________
MJR[__________ZPNL"[_____LBZT+K8NNBZ\+KXNOR[!+O__PB[__\,NQ"[_
M_\4N_____\8NQR[(+LHNS"[_____S2[.+O__T2[2+O__U"[________5+M8N
MUR[________8+MDN___________________:+MPNW2[>+M\NX"[B+N,NY"[E
M+N8NYR[H+NDNZB[M+O__[B[__^\N___R+O,N________]"[V+O<N^"[Z+OTN
M_R[_____`2______!"__________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M___________________]_P$"`P0%!@<)"@L,#0X/$!']$A05%A<8&AL<'1[]
M_?W]_Q\@(2(C_?TD)28G*"G]_2HK+"TN+_W],#$R,_W]_?\!`@0'"`D1$A,5
M%A<8&1H;'!T>_?W]_?W]_?W]_?T!`@,$!08'"`D*"PP-#@\0$1,4%187&!D:
M&QP=`P0%!@<*"PP-#@\2$Q05%A<:&QP=`@,$!08'"`D*"PP-#@\0$1(3%```
M``````````````````````````````````!!B$&,1(1!D$:$1X1!E$&809Q*
MA$N$3(1-A$Z$3X10A$&@0:1!J%2$0:Q!L$&T0;A!O$'`0<1!R$',0=!AA(&$
MH83!A.&$085AA8&%H87!A>&%089AAH&&H8;!AN&&08=AAX&'H8<`````````
M`````````````````````````+!V!0@`````U'8%"```````````\'8%"```
M``",>04(``````<```!D>@4(`````/QZ!0@`````!P```$A[!0@`````@'L%
M"``````'````Q'L%"`````#\>P4(``````<````\?`4(`````.A\!0@`````
M!P```"1]!0@`````8'T%"``````'````F'T%"`````#4?04(``````<````$
M?@4(``````!_!0@`````!P```-1_!0@`````=(`%"``````'````!($%"```
M``"D@04(``````<````P@@4(`````/""!0@`````!P```(B#!0@`````X(,%
M"``````'````,(0%"`````"(A`4(``````<```#4A`4(`````*"'!0BTB@4(
M!P```!R+!0@`````4(L%"``````'````C(L%"`````#,BP4(``````<````8
MC`4(`````#B,!0@`````!P```%B,!0@`````G(P%"``````'````W(P%"```
M``!LC@4(``````<```#TC@4(`````("0!0@`````!P```%"2!0@`````:)(%
M"``````!````B)(%"`````"XD@4(``````$````0DP4(`````$B3!0@`````
M`0```+23!0@`````Y),%"``````!````/)0%"`````!LE`4(``````````#0
ME`4(``````B5!0@``````````&"5!0@`````F)4%"``````"````!)8%"```
M``!$E@4(``````$```"PE@4(`````."6!0@``````0```#B7!0@`````:)<%
M"```````````N)<%"`````#HEP4(``````````!`F`4(`````'"8!0@`````
M``````29!0@`````.)D%"```````````J)D%"`````#8F04(``````````!0
MF@4(`````(":!0@``````````!";!0@`````0)L%"```````````T)L%"```
M````G`4(``````````"0G`4(`````,B<!0@``````P```$2=!0@`````?)T%
M"``````"````!)X%"`````!`G@4(``````,```#4G@4(``````R?!0@`````
M`@```)"?!0@`````])\%"``````#````P*`%")R@!0A$H@4(``````,````(
MI`4(`````#BD!0@``````P```-2D!0@`````#*4%"``````#````B*4%")R@
M!0C8I@4(``````,```"\J`4(`````.RH!0@``````0```&"I!0@`````D*D%
M"```````````6*H%"`````"@J@4(```````````HJP4(`````&"K!0@`````
M`P```#2L!0@`````9*P%"``````"````_*P%"``````TK04(``````,```#L
MK04(`````"2N!0@``````P```,2N!0@`````_*X%"``````#````G*\%"```
M``#,KP4(``````(```!LL`4(`````)RP!0@``````@```$"Q!0@`````>+$%
M"``````"````!+(%"``````\L@4(``````,```#TL@4(`````"RS!0@`````
M`@```+"S!0@`````Z+,%"```````````3+0%"`````"$M`4(``````(````4
MM04(`````$RU!0@``````0```-BU!0@`````$+8%"``````!````H+8%"```
M``#8M@4(``````````!<MP4(`````*BW!0@``````P```%2X!0@`````I+@%
M"``````#````5+D%"`````",N04(``````(````(N@4(`````$"Z!0@`````
M`````(RZ!0@`````Y+H%"```````````2+L%"`````"$NP4(``````````#(
MNP4(``````"\!0@``````@```&R\!0@`````M+P%"```````````&+T%")R@
M!0AHO@4(``````$```#DOP4(`````##`!0@``````````(#`!0@`````Y,`%
M"```````````4,$%"`````#DP04(``````(```!HPP4(`````$#$!0@`````
M`````%#%!0@`````G,4%"```````````[,4%"`````"`Q@4(``````(```"D
MR04(`````.C+!0@``````@```"38!0@`````X-@%"``````&````9-H%"```
M``!@W04(``````,```",X`4(`````$CB!0@``````P```*3C!0@`````-.8%
M"``````#````0.H%"`````#<ZP4(:.T%"`,```"<[04(`````'CP!0B$\P4(
M`P```+CS!0@`````U/D%"*P#!@@'````W`,&"`````#(!`8(``````(```!8
M!@8(`````+`&!@@``````@```"0'!@@`````(`H&"``````'````'`X&"```
M``"D$08(K!4&"`(```#8%08(`````)@<!@@X)08(`@```&0E!@@`````E"8&
M")PH!@@"````S"@&"`````!`+@8(``````(```#L+@8(`````-PO!@@`````
M`@```$PP!@@`````!#(&"``````"````E#8&"`````"\.`8(``````(```!T
M/`8(`````'`]!@@`````!P```.@]!@@`````)$`&"``````'````)$(&"```
M``#@1`8(``````<```"<1@8(`````"A(!@AP208(!P```)Q)!@@`````U$D&
M"``````!````2$H&"`````"D2@8(``````$```"DXP4(`````#3F!0@`````
M`P````A+!@@`````0$L&"```````````W$L&"``````,3`8(``````````!T
M3`8(`````*1,!@@```````````A-!@@`````0$T&"```````````L$T&"```
M``#\308(``````(```"`3@8(`````,!.!@@``````````%!/!@@`````/%`&
M"``````#````M%`&"``````L4P8(``````(```#X4P8(`````"A4!@@`````
M`````-A4!@@`````"%4&"```````````F%4&"`````#(508(```````````\
M5@8(`````&Q6!@@``````0```-16!@@`````#%<&"``````!````E%<&"```
M``#$5P8(```````````X6`8(`````'!8!@@``````0```-A8!@@`````$%D&
M"``````!````A%D&"`````"T608(``````````!46@8(`````(1:!@@`````
M`````#1;!@@`````9%L&"``````!````%%P&"`````!H7`8(``````````!(
M708(`````'A=!@@``````````"A>!@@`````8%X&"``````"````W%X&"```
M```D7P8(``````````"D7P8(G*`%""1B!@CT9`8(`P```"1E!@B<H`4((&<&
M"&!J!@@#````D&H&""QN!@A4;@8(('0&"`,```"P=`8(`````.AT!@@`````
M`````%AU!@@`````C'4&"``````#````````````````````````````````
M````````````````````````````F0````````"```````````````"(BXF*
M``````````````````````````````````````"7F````)"1``"4E98`G)V/
M````C````````````(X``````````)*3````````````````````````````
M``":FP``````````````````````````````````````````@8*%A@``````
M`````````````````````````!HB=`%U`8,`<R5V`7<!AP#F(>@AZ2'G(28@
M(B$P("(@&"`9(#D@.B`<(!T@'B`3(!0@$B)2`5,!("`A(`'[`OL`````````
M47$```````````````````````````!7=P``````````````````````````
M````````````3&P``````$8``$,``````````````````%,``````%I=````
M````9@``8P``````````````````<P``````>GT``$!!0@!$14=(24I+34Y/
M4%)4`%566%D`6P!<7@````!?`&%B`&1E9VAI:FMM;F]P<G0`=79X>0![`'Q^
M`````']``$$`0@#'`$0`10#$`$8`1P!(`$D`2@!]`4L`3`!-`$X`1P%/`-8`
M4`!2`%,`7@%4`%4`W`!7`%D`W0!:`%\`%B%A`&(`YP!D`&4`Y`!F`&<`:`!I
M`&H`?@%K`&P`;0!N`$@!;P#V`'``<@!S`%\!=`!U`/P`=P!Y`/T`>@!_`&0K
M92M@*V8K7"E$*S@K2"LW*THK,"M,*T,K3BLX*TDK-RM+*S`K32M#*T\K*R1W
M)"TD>"0O)'DD,21Z)#,D>R0K)7<E+25X)2\E>24Q)7HE,R5[)3LE?"5$)7TE
M2"5^)74F>"8`````````````````````````````````````(BDC*7$A<B$D
M*24I>"$O(28I)RDH*4PB*2DJ*2LI:R%>(2PI+2DM(7DB+BDO*3`I,2DR*3,I
M-"DU*38I-RDX*3DI.BD[*3PI/2D^*3\I0"E!*4(I0RE$*44I1BE'*4@I22E*
M*4LI3"E-*5\A3BE/*5`I42E2*5,I5"E5*58I5RE8*5DI6BE;*=PI72E>*5\I
M8"EA*6(I8RED*64I9BEG*6@I:2EJ*6LI;"E@(6TI;BEO*7`I<2ER*7,I="EU
M*7HI.BI)*B$J+"H\*DLJ62I?*CTJ3"I`*D\J4"IX*7TI/BI-*C\J3BI:*F`J
M6RIA*GTJ=BE[*5PJ8BH[*DHJ)"HO*B,J+BI!*E$J0BI2*GHJ>2E^*4,J4RHK
M*RHK.2I(*D0J5"HE*C`J72IC*B<J,RHF*C(J1RI7*B@J-"IW*7PI7BID*D4J
M52I&*E8J*2HU*BLJ."HJ*C<J*2LD*V\H<"AQ*'8H=RAX*'DH>BA[*'PH="AU
M*$4K,RLY*SHK)2NX*S\K;BHF*RXKL"O#*S$K,BMU*B@K>2HV*SPK(BM"*RPK
M:BIT*FLJ-"M[*F4J=BIO*B\K;"I!*W,J<"IG*GPJ<2IH*B<K;2HM*S4K9BJW
M*SLK>"IR*D`K:2HA*WXJ(RMW*CXK/2LQ*E,K5"M5*U8K(BI8*BTJ-BIQ*^`K
M82MB*V,KY"M<*UHK7RM]*ULK5RMM*UDK7BM=*W@K>2M^*VHK=BMW*VLK;"MR
M*V<K;RMZ*V@K<"MS*W4K:2M[*WPK="MN*U(K(28B)B,F)"8E)B8F)R8H)BDF
M*B8K)BPF+28N)B\F,"8Q)C(F,R8T)C4F-B8W)C@F029")D,F1"9%)D8F1R9(
M)DDF2B9+)DPF329.)D\F4"91)EDF4B93)E0F5296)E<F6"8G)R$G(B<C)R0G
M)2<F)R@G*2<J)RLG+"<M)RXG+R<P)S$G,B<S)S0G-2<V)S<G."<Y)SHG.R<\
M)STG/B<_)T`G02=1)U(G4R=4)U4G5B=8)UDG6B=;)UPG72=>)U\G8"=A)V(G
M8R=D)V4G9B=G)V@G:2=J)VLG;"=M)VXG;R=P)W$G5R=R*',H1BM'*U`K42L^
M(7PC/2%"(48A1R%((4DA=R)X(D`C12%$(7,B;"%M(2@B:RA8*WXL;"AM*&XH
M?2PA*6XA72-?(V(M9"U@(W(B7"-X)WDG>B<U+38M-RTX+3DM.BT[+3PM/2T^
M+3\M5RTU+#8L-RPX+#DL.BP[+#PL/2P^+#\L0"PK(BPB*B(M(G$B)R,E(R8C
M*",I(TTB3B(K(RPC*B,M(T\B7R)0(D<B8"(Z(D8B.R)=(5LC92)G(F<A>"U<
M(E0B52)*(DLB02)`(FDB:B)S+6@A:")F(FPB;2)N(F(B8B%A(FLB92%F(6,B
M9")O(G`B/B(_(D(B0R(\(CTB1")%(E$B4B)3(CHC72)Y+78G=R=((DDB7B)\
M)T(G0R=$)T4G1B=')T@G22=*)TLG3"=-)TXG3R=0)WXG?2<A+2(M(RTD+24M
M)BTG+2@M*2TJ+2LM+"TM+2XM+RTP+3$M,BTS+30M02Q"+$,L1"Q%+$8L1RQ(
M+$DL2BQ++$PL32Q.+$\L4"Q1+%(L4RQ4+%4L5BQ7+%@L62Q:+"LL+"PM+"XL
M+RPP+#$L,BPS+#0L6B9;)EPF729>)E\F8"9A)F(F8R8A*"PH(B@M*",H+B@D
M*"\H)B@Q*"4H,"@G*#PH-R@R*"DH/B@Y*#0H*"@X*#TH,R@J*#HH/R@U*"LH
M.RA`*#8H(R(B(FTF)2(D(B(C(2,G(B8B)",C(R$B?B$[(WLA?2%\(6<H:"AI
M*&HH/R-^(F@F:29J)FLF>B%Y(6<F9"9E)GXM:B%I(3HF/28[)D`F.28^)CPF
M/R9L)GTB=B)[(GPB=2)Z(G0B>R=]+2$L(BPC+"0L)2PF+"<L*"PI+"HL+B,O
M(WTC?B,A(2(A(R$W(3DA.B$[(5(A4R%4(54A5B%7(5@A62%:(5LA*2(N(DPA
M32%:(ELB6")9(D$A8"UA+68F,R(T(C4B-B(W(CPC(20B)",D)"0E)"8D)R0H
M)"DD*B2K)"PDK20N)*\D,"2Q)#(DLR0T)#4D-B0W)#@D.20Z)#LD/"0])#XD
M/R1`)$$D0B1#)$0D121&)$<D2"1))$HD2R1,)$TD3B1/)%`D4212)%,D5"15
M)%8D5R18)%DD6B1;)%PD721>)%\D8"1A)&(D8R1D)&4D9B1G)&@D:21J)&LD
M;"1M)&XD;R1P)'$D<B1S)'0D=21V)"LA+"$U(38A.2)[(R$E(B4C)20E)24F
M)2<E*"4I)2HEJR4L):TE+B6O)3`EL24R);,E-"4U)38E-R4X)3DE.B6[)3PE
M/24^)3\E0"5!)4(E0R7$)44E1B5')<@E225*)4LE3"5-)4XE3R50)5$E4B53
M)50E5256)5<E6"59)5HE6R5<)5TE7B5?)6`E825B)6,E9"5E)68E9R5H)6DE
M:B5K)6PE;25N)6\E<"5Q)7(E<R5T)74E=B5R)W,G="=U)R8A/"$S(30A.")N
M)F\F<"9Q)G(F<R9T)O4F=B9W)GDF>B9[)GPF?29^)FHM:RUL+4$H0BA#*$0H
M12A&*$<H2"A)*$HH2RA,*$TH3BA/*&4M9BUG+6@M:2U0*%$H4BA3*%0H52A6
M*%<H6"A9*%HH6RA<*%TH7BA;+%PL72Q>+%\L8"QA+&(L8RQD+&4L9BQG+&@L
M:2QJ+&LL;"QM+&XL<2QP+',L<BQO+$8M2BU!+40M0BU,+4LM12U-+4<M3RU`
M+4XM0RU(+4DM7RUO+6XM;2U3+50M4"U1+5(M5BU5+5XC8RTC+BVA,J$SH5ZA
M5J%^H5,N*Z-H]"^C6RY(HUVC7J-AHV>C(Z0FI"^D.*1"I$JD>:0_I4.E0:57
MI2.H):@IJ"BH+*A?3SZH;T]6J%FH7*A>J&^H<:ATJ'FH>Z@[K$:L2JQ@K%NM
M7ZUQK3:N?*TNKC*N-*Y)=6VN9:XHKRFO+*\TKWYU(79(KUVO.G9WKSON0NYQ
M[G[N0.]4[W#O=^\H\&9W/_!!\$+P2?!0\#3Q37A&\4CQ7/%G\6SQ(O(M\CGR
M9/)T\G?R??(S\S?S1_-+\TCS4_-7\VUY*_0V]#OT3O1=]&'T/O5"]4CU2O5,
M]4_U67I:>FSU;O5W]37V,O8T]EGV5/9M]F[V47M/]VSW8'LD^#KX0_A.^%/X
M:_@I^3_Y2?E+?%SY)_I8?6K[</MU^WC[-_Q5_";]*/TJ_3']/GX__2K^+?Y+
M_F#^;#!Z0R*A-SQ\2V8^,#ME/CPR5$D_32.A(E`O,22A;C,C4"1`0E)6-3I*
M9SX^3D)*)"XEH210)J$N\&9#)Z$E+B8N)5!Z-B90730P0V<\)U`H4"BA*5`U
M1U<U*:$JH3='8T9#.#-++*%):2I0:#XK4#4R+Z%E-G`X:4PF5C"A<$U]1B4T
M-34L4"U0.TX]36A!+U!V.W-&)RXR4#XQ7SA>.&8P2T]*3S,Z(3`QH3-0-%`U
M4#1+-E!R.&<P<DM\-7TU?C5B1#Q.-U`X4#E0-*%-/S6A-Z$Z/4X_/E`XH3Q0
M/5!8-3FA(SIP,CM0.E`I2CJA1CM%.SY"/U!526=`/*$X(4!00E`H+F5"84Y*
M,#NA05`^,D0V/:%G0SZA;S=#4"1'*2XJ+C^A:S0K+D102S`L+F`X;#1Z23)(
M635`H7$R9U!!16Q'1E`\2&).0J$M/T<[=SM`,D.A440B0TI0+BXO+DPP8T0[
M/30Z)$U.0D2A/S(P+DE01:$^34501U!N.DA0)%4Q+BTN0:%04#(N,RY34%%0
M0C([2DM01Z%(H4FA3U!S.$JA-"Y(.TNA)C1,H5103%`U+F-.>#M-4%)03:$V
M+E50-RY.4$ZA(39-,"(V03(E57E+;DET.%"A+S\W3E&A6$HX-R5"9#)2H3DN
M4SU3H5E05*%>4%Q05:%74"]"6E!=4%M074I84#HN+C]S2U]08%!/H20];5!7
MH5!'-DEH4'!*-C)L4%BA.RX\+F90;U!2040X7$<]+D=@6:%N4%U%6J%C4'8X
M/BYU.&%06Z%<H5H\:5!=H6]*34-E4'$W/RYB4&I09%!13FM004]`+F8V<#="
M+D$N0RY?H7!08*%Q4'503C!AH5!*=%!BH7-0=U!CH7909$1DH7(W9:%FH7A0
M9Z%%/"9"941V-GE0-C5Z4'Q0::$U2V8W:J%KH40N;*%MH3$[=TA[4&ZA:*%O
MH44Z0TUQH7Y0(U%]4$0Z?3URH7.A.3<D472A3S9UH2%1(E%%+B]&>*%\04<N
M(S9ZH4U+)5%[H3U.)E%\H2E1)U%(+DY!?:$H42I11BYVH2Q1*U%(2C<U+E$O
M44LN+S)*+B&C+5%,+G0\,E$Q43!1(Z-64#-1)*--+GX]-%$E35E,3BXV4351
M.%$W43E1.E%T,#4X.S<\/7M#)#9H0'<X3RYN.3Q12$Q&17D[.U$]45$N4BY>
M174S)J,^47Y&-$%`44%1+$AX.#M/0E$F-BBC/$HV0G$V-45T]',W0U%$42FC
M8D9?,4=1?3HJHT911CI(46YF25%!2TI12U%,46D^+*-,/%0N)S1/42VC35$]
M3$Y16DE045%14E%?12ZC5E%445514U%C.E=1:DQD3C"C6%%5+BA`65%:/5I1
M5BY\0S].8$5%4EM1)71%-E<N7%%>2U@N:#U\0EY19$9?45DN8%$N,S.C-*-A
M42<V3$9Z,5`](4AB46%%6BXUHT\_8U$L2EI`(C0I-&119E$Z-S:C7"YE45TN
M-Z-S3FD]/4A,2F=1>$UH46E1?D5J42E`?CIT-VM123MO.69$;5$G0EXN;SIN
M46]1,$%L47%1.:,V2U\N9#DZHW!18"YU-UXZ;4=T47)1.Z-[26H^>U%D,W51
M<U%/03RC=U%V43ZC1#,]HV`W?%$M3GA1?5%Z46$N>5%`HT].>3A#,G1.0J-#
MHW4]6$5E.2)2(U)$HV5.*T\E4GHX1:-&HR12+S,F4E9+/$0F36(N64I'HV0N
M)U)E+DFC57`P1F8N*%(J-#-,9RXA/BE29THM4BI`*E)0-BM2*S1I+BXW+E(O
M4DNC,%(Q4EL\:BY[.%Y,:RYH3'=&<4HR4FPN,U),HTVC-5(W4C92.%(],DQ+
M?#HY4FTN64$B/BDV.E).HUM(.U(\4CU23Z,^4B1):#9E,%"C/T8_4CT]4:-I
M0$%20%(C/F$X0U(^2$127$@T0FY"*#9N1C%#;D=.2T92:D!O+G`N-3=4HT=2
M5:-(4BPQ=3!M-"A"435Q34M2-S)6HTI2<2XJ-DQ2<4QR+DU24DY\.',N-CA.
M4E>C4%)/4E\_.3%>,5%24E)T+C<X6*-34EJC;C5;HS([5%)T2S4Z6C4G35!!
M/TA]/$<]7Z-H/'4\=CU@HT!(5U)#,5%!?3A%.&<V6U(A0WY"*S8D/EQ26E)$
M,F9".#Q+.R8Q8J-CHW`S9CE*.UU27E))-48S9SE(-5]$)3$Q1CY,(3EY34=%
M?CAU+B\W9U)C-DI+9:-=2'8N9J-F4EXT85)B4F1295);-6$_+4IC4E]28SA@
M4B1/:*-R2FA$8CAP.7<N:%)=1F2C;%)IHVJC?CQV/'DN:Z-O4FU2(TQZ+FI2
M<U)N4G%21C@_3'LN<E)T4G92?"YLHW`Z0D]MHVM2:5)U4G!2;J-]+G@N;Z-^
M+GA2(U-Z4G"C?E(A+R%3>U)QHW*C/E-I.C$S<Z-Y4G2C)5-V,"13=:,E,$I)
M(E-VHWQ2(B]W4GU22#HF4W<P+U,G4RA3)3YI2WBC+5,L4WFC>J,O17NC+E,K
M4R,O?*-]HS0Q-CHP/WZC)"\I4V)%*E,B,"4O-%,C32<^.E,F+SE3,%,AI$-"
M,5,BI&]"-E,F/B2D):0S4V1,)R\\-S=3.%,U4SM3*"\GI"BD,E,II$%31E,K
MI$)3/5,I+RRD1U,Q02HO25,MI"(Y/U-]0RLO+J1#4SQ3+31N-&4S1%-`4W8W
M2E-(4U-!2C4L-BTO15-T-D0Q,Z1.4TQ3)U0TI#6D+B\VI#"D45-+4T]3-Z1-
M4SFD3#M04SND4U-84U9355,R0SZD,"]%,C$O/Z124U13*#XS,5=3/*1>,F)3
M0*1\/EY37%-=4T&D7U,R+T.D1*1%I#TQ1J0S+SE!65-:4WHS1Z1(I&%3-2]O
M-&138%-C4TFD-R\X+SDO+DHT+U5&.$AF4V5313-+I&=33*1J4VE33:0Z+TZD
M3Z0[+VA3.4=K4U"D/"\]+U&D;%-2I#XO;E-M4W!3<U-Q4V]3<E-3I'13/R]`
M+U2D=5-V4W=3>%-%47P\33MS,E6D>#!$0U:D>5,D.D\P7C]7I%BD>E-'.'$Y
M?%-[4V!*?5,A5'Y302\B5"-4=S=@,2146J0F5"54*%1:14,O6Z0I5#4P7SI=
MI#TW1"]/0T4O1B\J5"M4+50N5&0Z7Z1@I%$V-TMAI&*D+%0O5$$Z(SDS5"4Z
M,T-DI#!46D1EI$<O9J1GI&BD2"]II$DO-%1B/S)4-50_-S94;:1*+VZD;Z0W
M5"0Y0#,Y5'"D.E1LI#M4.%1-+S%4/%0]5$XO3R]D2W.D:SY0+S]40%0^5$)4
M<:0X1W:D:#!624-442]WI%(O>*1]/E,O5"\Y/'JD74=P-'ND:SI\I%4O64LR
M1GVD>#=/0E8O051$5$1"151&5'ZD(:5(5&E$(J4N-"%T83%S2B.E;#Y(122E
M9CI.5#U*74XFI70R2E0GI3I!351C14E%9$4Y2$U$23I8+TE462\HI78Q-D5+
M5$=44#]/5%LO3CTM-E!47"\II2JE*Z4LI2VE:$HNI7U!1D0OI5TO4E1/2U\O
M,*535%A4,:4O2E=445145%94)CI)2C.E651%0W4R;3XTI6(O6U1A+UI48R]H
M.5Q47E1=5&0O8%155&)492\UI6%47U1F+TX[43]406-4/$!M,&1'-J4WI5M$
M951D5&949U1H5&E4.*4YI5%*:E0ZI6<O.Z5&,FM4/*4\33`S25)(/3]";%1K
M3#1,/:5N5&="-T5`0E=);U1P5'LQ.CQQ5%`P<E1`I7-48C%"I7$T8$9T2G=4
M54%V5$`W6TMU5&5%>51X5$6E:2]&I7M4>E1\,7Q4*3Y^5"5#?51J+S-*=SU;
M14BE2:4A54JE)3DB52%'7DA13"5':R\K56PO.#5%32],+%8C54NE)E5M+T5"
M.$M*14RE)U5E2THZ3:4J/FXO*%5.I5`[3SM/I3DP2#AO+RM`43`L52U5*E5P
M+U"E4:52I3@Q+S13I2E514PQ252E*#!Y,%$[4C`C,#)56*59I3!5<2]:I3Q,
M,U4Q52]5,3]R+RY56Z5:2ERE9#@W53A5*SXT52Q/3$<V55VE)SHY55ZE6$ES
M+SI5-55T+W4O7Z5V+SM,=R]@I5Y'.U4R26&E>"]BI6.E9*5Y+V6E9J5GI6BE
M/%5`53U5::5',C]5>B\[/#Y5>3=,54550E5JI6NE;*5D0T%5;:5#5415;Z5N
MI7"E1E5'57&E<J5R-$E52%5*57.E?"]N/GTO355<1'6E13%+572E3E5/55)5
M54]055%5=J52.U-5=Z4F.5155D]Z.SA"555655H[)SE23"@U23A755@S>*58
M53E">:5952-66E5;55Q57E5ZI5=/>Z5?57RE8%5]I7!")S%I/$(P5T$P-#4\
M*#E83V9%(:@A/3$T:$-J1#@P.35U2D(\4C5K0#P\*$UA52*H7#5+.C(S8S$L
M/D@R8E5&34D])*AD/&-5<S121BE,9%5E55E))JAG52@T=S9F52>H64\R-#(_
M:U4A.TDR:E5H56Q5:54K1TU<,S]M55I/0$YN52JH<%5^0V]5(T![.RNH4$)W
M/'5);$`MJ$T\<54M/G)5<U53,#I"4C]T53-&+CXO/EM/=55M0#`^7$]V57=5
M74]@3'A5+JA>3T8V+Z@B/7E5>E5</"P_=$94/WA((D=)-GM5;S5\57XV3T8P
M,E,[?54B5B%6?39^53A%,$(QJ$M%2#Q@3S*H6$%Z33.H-*@UJ"16)5961C:H
M,SLG5BA69$\YJ#RH/:@I5F5/=#0J5BM69D]!J"PR0JAG3T.H1*@[060T:$\M
M5BA,1JA20EDS1Z@O5C%67S1I3RY6,%8S5C)6-%9)J&I/:T]L3S56/48N-F4R
M-E8[5CE6=TIV2FU/9T4X5E0]-U9,J'(_/%9P3VHZ3:A"5D-6/58S,SY61U9&
M5D56059/J$!64*A$5E&H4JAQ3WA*3JA3J%2H5:AS3W1/=D]+5DA62E9R34E6
M=4\_5E>H<S]8J$Q6=T\W.EJH359.5GA/45905D]67:AH13I65U9?J&"H8:AB
MJ%-6>4]25GI/>T]45E568ZADJ&6H6%9\3V>H9DY95E966E9]3V`T6U9HJ%U6
M7%9>5FFH:JA?5FY`(SUKJ&0]*'1C06VH*3DX.BHY<#5NJ&!6.3I*.&%6)DQ#
M1V)6*SDL-"=#4C9PJ%0[6TE!2&-6=31F5G*H*71SJ"%$*G1E5F169U9K1'6H
M8S]5.TI`=JA30B(U(D1H5FE6;SXY2W>H;%9K5FI6?4ES5GBH6DMM5F]6:TMZ
MJ&Y6*W0L='!6*$AQ5CY*<E9\J'VH?J@AK#,T/THO1W16=58L.30T=E8X.$1-
M*4UV-'A6(T0M.3$^7T@R/G@];$1Y2CE%+CE<27E6(ZQ914(Z)*Q+."6L;41#
M,&X]+SE'32:L+70GK'I6>U911RBL?%9W3BU/+W1^5GU6*:Q',R%7*JPD5R57
M(U=`23,^)U<F5R)7*%<I5RI7+5<K5RQ7+E=D,6Y$+U<P='HW=C(V1RRL,%=[
M1C%T6THR=#%7+D\S="VL,E=`2C57(5`Q4"ZL,#QU1C97734D1'HP-U<F2C`Y
M4$,OK#1T,:QO1#5T;TPY.$PX.%<Y5S]793PV="5$-W0O-CI7*TDX=$9#.70[
M5SIT,JP\5S`V/5<^5T!7=D4[=$%70E<\=$-7-%<S5T1703<SK#UT)TD^=$PZ
M-TDF1$M)15<T/D8Q-*Q&5T=7<DQ@2#]T-:Q*5WTQ+$!)5TA70C=40DY73%=`
M=$M7)TYE.#:L>3U-5TQ%/CU`1E%74%=!=$]74E=F.#>L.*Q"=%-7?$E;/517
M>4A#=$%&)T1$=$5T.:PP1557*S4T/SJL+$D\K$9T/:QW-"9'/JP_K$"L5E=6
M.SI+.TM^,5M71W1I0TAT0:Q85TET=S)"K$.L+5A:5T2L,$=95U=71:QZ.5U7
M2G1C5VE785=<14MT9E==24>L3'1@5V579TY7.U5"7E=(K$FL7C5H5RU`93%B
M5W@R9U<Q-F17371.=&I7;%=V5W17<5=/='!7>$Y+K')7,C8Q.7H]>5=K5V]7
M7U=Z,G-7=5=10R@Z.#)M5WA7=U<S-BE"9C-#-VY73*QZ5WU7(5@]/$VL)UAP
M1'M7)5AY,DZL(U@D6'Y7(EA1=%)T9S@J334T63$F6$^L.D<M,%&L4JQA2%Q7
M+%@P6&5,*5AI12Y84ZQP/B]85T94K%-T1T\K6%1T570Q6%6L>SE6K$M`5G14
M,"I8*%A:07Q7-#M7K$9"/5A8K%M!.%A9K#58-EA7=&8\.5@\6#=8)3TZ6#18
M?$Q[3#Y8/UA5,%JL6ZQ<K#-87:QR-B8P6'1>K#8T.UA#6$)8671'6%IT2%A;
M=%^L1EA)6$%815AAK$I82UABK$!8?#M$6%9",CDR6#4_6%AI2DY83UA06%=8
M5EACK'U+-S146$4W-#-16#A.4UA6,%583%A26%E81#=-6&2L74TK35Q88%A=
M='Y!>4YA6&:L9ZQ>6%M8:*QIK%I87U@P2FJL-$9KK$8W8EA=6&RL8UA[-S$R
M8'1K6%]T.#1I6&I8*3IH6&9895AL6&18;EA[,FZL;ZQPK'!8;U@H1'-8<:QQ
M6&=8?#=R6'98=5AW6'18>%AY6'I8:DI\6'M8/STN0&8R?#)]6'.L/S!,0'Y8
M0VPA66$W(EEB='2L;T!UK"-9)%DZ-259)EDG65="33AA3&-T/$MJ/2A99'1V
MK'!`/6YB2&H\=ZQ-.BE9>*QYK$=")TIE='%"9G0L62I9+5EZK"M9>ZPN67VL
M,4IG=#<P?JQ>26-(?*PO63)9-3X[-3!9-UDV/FAT,5E$1UY-,UDT63A9:D4U
M63,Y7D`AK499-$AR0B*M9$@M6GI*<41U2SM9(3)J0T19:70T0SY915E`64=9
M0UE"66]'/%E],CI9<35S0C99(ZUJ=#E9-#E;0#<^05E21W(U2#-G,R$_25E.
M64I9?3=/62([:3EK="6M)CT]67T[3%DFK5@[35E$,&QT2%DGK2BM*41M=',U
M-#9+62<P0SHV/RNM+*UN=')$+:TNK51(45E>02^M;W0PK2I"*SM263&M5%E0
M66%*/40SK5Q!<'1[2DX\8%E?63:M>#]^-UE9.3YH1C%'<71765U!-ZUX/%Q9
M.#Y665M94T<ZK559(3<XK5TS75DK3DXZ-4-:65Q`-3ED/V8Q/$%8644U1S=/
M1%Y97T$[K6%98UDW0FE99%EF64%)<T1G63VM/JTL34A-.30_K4"M+C!E67)T
M8EE!K4*M<W1X-$.M9S%T=&A9/*U)36Q91*T[0G-9=71M679T:EEQ65-91:UW
M=$:M;EER64>M0DAK14BM:UEO64@W<3I=0'=9>70F14FM2JU+K7IT=%E@2WMT
M=5E,K7993DQX=")`3:UB-TZM?5E/K34[>EEY63)'4*TU1E&M,45[67Q9;TE%
M1R,[<4!02TDS)5I^67UT?G1*32=:(74C6B1:(G52K5.M8$%\="-U(EH_652M
M5:TF6B%:*UHL6B=%+EI7K5BM)#LI6CPU+UHH6C-:,EHQ6B1U-%HE=39:<3Y9
MK35:6JTY6ERM7:U>K3=:.%IP66"M)G4[6CI:)W5X63Q:,%I9.V&M/5H^6D!:
M/UI!6GXR-CE\2B]`8JU..$-:1EI225\U8ZU%6D1:5$='6C4V25I(6CHT-CM8
M1BEU9*U)-W0_2EHP0"A%7TE+6F6M9JU,6DU:9ZUHK3A*755&0&FM3$E8.F5(
M0TA-14%.3UI0/"IU4%HV,%0V34!@25%:0CM'0UL[-S]JK6NM4EILK7U*=S%<
M.VVM55INK5-:5EHY3E1:;ZU[0%=:,D)86G"M>C1:6EE:6UI<6GLT?$8V0VPU
M73MA05P],#!=6G*M<ZTB,F%:=*TL=3<Y8%IUK2LZ.CYVK2UU7UH[/D!,*CI7
M,$Y`+G5F6B]U,4!',7>M,74R=54]9DMR.GBM,W4\/B=`-'4U=39U95IC6F1:
M,'5K0R9;:EI^.S@Y:%IYK3AU:5HX/SEU>ZUG6GJM+SM^K3MU/'4AKFQ::UIP
M6CUU<5HBKFU:/G4B,VY:;UI52"6N)JXGKBBN84E*-W):/W4R0#T^0'5!=5)#
M*:XJKD<V<UIW6DLR=%IV6D)U=5HKKFL]+*Y(0T4P>%HMKGE:1'4J1'%.0SLO
MKFM*,*Y%=3U+,:XB6WM:1G5^6GU:,ZYZ6B%;1W5>1DAU?%HC6VP])%M*=4M-
M>$<E6R=;2W4H6S6N*5M*-D@Q.3DJ6RM;<3UB04QU-W584CY!/4%80D<Z-ZYR
M4#BN;C<M37Y*?DDL6SFN375S.C]$+5LO3SNN/DLK1"Y;?#0O6S!;6DPD3'9+
M7$LE.S);:SQ/=5%+-%LW6S9;>31@-3-;-5LX6U%U4G5Y/SZN/ZY[34DP8#H\
M0ET\0*YS/CM;3D5!KCE;*T(Z6W(^74P\6SU;:$U0=4);.CE51S];;$5>6F):
M1:Y/-4:N1T=3=4%;/CY$2%1U1UMZ2#Y;1%M#6T]`2*Y5=6U+4TY6=6=+5W5,
M,EX[2$]&6W4_15M`6T\X3*Y-KDQ;2EM-,DA;3EM46UAU6G5(0DZN04I66T^N
M(DE56W!'/TL[-%"N=T!`/5MU4T11KBY-4JY16U!;4EM/6U=;35M+6U-;25M3
MKFQ#>$Q&/'0Z5*Y9=3HZ7'5O2T$S775.1$I&23%+KG)`-$`J-UBN7W596UFN
M.SE\,UM;=#-A6V!U6JYA=5Y;7*YS0$LS+#I=KDHS3SI>KEQ;93=+-VU%7ZY@
MKEI;1C!AKF*N75M?6TTV+#=>=3PT2S5CKF2N8EMB=7DZ<4LW.V-;,$EFKF>N
M8W5O6V1U,S)D6VBN::YU6V5;0DYJKFQ;7T=T6V=;:ZXT,&E;;*X\.6ZN;ZYP
MKFM;<:YJ6V9;<5L_/F9U9W5M5&@X?$URKG.N:%MT1",S+3IH=6!;=*YP6V$S
M;EMR6W6N;D5ZKGXT>ZXR7&EU24QW6WTT?*Y^6WVN:G5`2R%<(UQ^KB=<>5LA
MKRI#;T4K7'Q;*%PBKR.O(EQK=22O;'4Y/RQ<;75N=3-`):\J7#TT=JYO=5!/
M=ELFKR9<6#`GKWA;<'4Z3'U;(C]'1'-;)5QZ/R]<<3,A.#%<>ELP7"E<>ULM
M7"Y</UQ.1G-U)%P[7"NO/5Q81'1U+:]Q=4Q-=DDX7$I"=74^7#]!-5Q"7$%<
M;T9`7&I&=G5W=7AU+J]$7#=<+Z](-CI<73TPKV!'/%Q+-C1<-EPS7#&O,$]:
M,SE<,J]Y=4-<-3-G.ETQ5%PSKS%/5UPUKS:O.C]67%5<>W4WKU)<?'5&7#BO
M8UQ%7%A<.:\ZKU!<.Z]+7$A</*])7%%<(G1.7#TY2$1D04Q<?75'7#VO2EP^
MKTU-:DM/7%E<(G9$KV%<6EPC=B1V9UQE7$6O1J]@7$>O2:\E=B9V7UQ01&5!
M2J]=7%M<8EQH7'5(;EPG=DNO:5QL7&9<*'9T0SA)3*]<7$VO9%Q`/D],>%QK
M7"(X(S)?,U-<0:]/KU"O4:]!/G!<=UQY/'(S*G8N0RMV4J]M7"QV4Z]R7'9<
M5*\V-E:O+797KRYV3#5T7"]V(35+1G-<6*]U7#!V;UPQ=G%<5:]:KV`S24-;
MKWQ<,W9<KWI<:3AY7%ZO-'8A75A;-78V=E^O>UQ@KWU<?EPW=BQ=8J\H76U;
M)UTF72-=8Z]J7"5=)%UDKV:O*ETF3V6O+5U[-F>O:*\I72M=.'8Y=B=(+EUK
MKVRO;:]NKS)=+UUOKW--,%U>7'&O<J]SKW2O,UTT77:O/'8U,3UV-EUG-R$\
M538D,CYV>*]?33]V.%TW73I=/356-CXT/5U`=CQ=/EUYKTXR-T,_73\T05U!
M=GJO0%U"74-=0G9$75\[-4`A.D-V<$E$=F)*1$][KW4[4#IR3GRO179%749=
M?:]@.T==2%U^KT9V2EU)75A+7CUL/$0[2UU-72,_3%TA[DY=3UU'=E!=45U(
M=B+N4EU475-=55TE,DI#5ETF.TPS5UTD[B7N0D5,5",U6%TF[B?N*.Y976Q*
M:$M*=D=&6EUF2$MV3'9[2"GN4TQ;72KN*^Y=75Q=+.Y?72WN7EU-=B[N3G9A
M72_N,.YA.T]V,4QB76-=)#5D769=95U0=F4_,>XR[CE)2C$S[D5(->YU1$$]
M834V[D9(+CQH74`T479X,3?N4G9R1F==/CE30VE=3^YQ76I=..Y!0F(U<EU4
M=E5V:#<E-7!=;EUK76!-.>Y6=E=V0$0Z[EE&;%UT77-=(S<\[CWN+3(^[EAV
M.SIM76]=67972W1"4W9W2S_N?%U]74\R*$I]3"%>(SQ"/GA=?EUH,3<V0.YU
M77I=6W9T0'%'9TA![G==7'8A2T/N>5TD7D3N(EY%[GM=778B2TA'8S4E16U#
M1NXE7EYV1^Y([E]V(UY90G9=2S%:=DKN879+[DY-,%YB=B]>=D`L7FQ--D8F
M7DSN141-[D[N3#$_.2E>8W90[F1V)STN7F7N+5XH7BM>979H,U'N*EY)1V9V
M+DYT/G5`9W8V7C1>4NY-25/N5.XQ7C->:'8Z,4`Y,D\],V))5>YA320S.S\U
M7E;N5^YJ=CI>:W9#/FQV6.XP35GN-UY:[C)>;78X7EON7DYS14)&;G9A[F]V
M8NXV,U4Q8^X^7D%>0TYP=F1-9.YQ=DA>0EX_7F;N5$Y%7F?N:.YI[DH]1UY,
M7G)V<45*7G-V='9U=D1>:NXX0TM>0%Y&7FON35Y\,$->3EX\/U\])4IL[BXZ
M.UY)7CI%=G8V0&DS43I$/CU>0CU,-SQ>7>Y27FT].CAA7F[N6UYT-4]%;^Y6
M7E]>+S`R,7#N.3)87BQ"3UY17D$Y<NYX=FWN8EY=7G/N55Y<7GEV=.YU[BM,
M=NYW[EI>7EYX[GGN>NY[[E`X?.Y%/CE#>G9[=E1>?>XO35=>4%YR15->65Y1
M3SX\?DMC7BY(;UX[."'O8#UE7B].0CER7FXP<%XB[V1>?'9J7GUV;%XC[T]-
M9UXN16E>).]^=G%>)>]K7D=,(7=F7B;O(CQ^7B)W:C-H7FU>;EXG[VQ"6D(I
M[W9>?%YZ7BE%(U]W7BKO*^]X7F!>>34Z23\\=SDL[RWO,T\C=W1>(E]I,69!
M+N\D=WE'031Z3B_O)G<A3%)$)W=[7GU>*'<H[S#O,D$Q[R%?>5YS7D,T*7<S
M[VDW-.\O7RIW->\J7WA`*W=C,S;O+'<M=V$],U\W[RQ?+$0I7UE$3%\F7R5?
M+E\Y[RYW*%\G7RU?(4`D7R]W,'<Q=S!?.N\Q7S)W.^]"-#CO/>\S=S9?-5\W
M7S[O-'<Z7S_O0T4T7T'O-7<X7S9W/.]C-WE",E\[1SE?-W="[T/O.'<^7SQ?
M/U]$[T)?1>\[7VHY*$<Y7D;O=$T]7T%?=4(Z=T!?*U\[=VEO.7=%7TCO25])
M[T=?/'<]=TKO0U]+[T1?2%]&7TY)3E]+7TI?35]41D]?3.]U0VU"/G<E0%!?
M4E].[T_O4.]17U'O4N\_=U/O=5Y"=U-?5>]G1D!W07=47T-W5N]7[U`R6.]9
M[W1%)3-$=UKO9#5>/%(Z6^]<[T5W7>\G3V8_:C%67U[O7^]57V+O1G='=UE?
M.D-<7U=?8^];7TAW6E]`15DP8.]U3F;O7E\H,6?O:.])=TIW8%]I[U]?75]+
M=V7O6%\C2V)?:N]K[VSO;>]N[V%?;^],=VLQ9%\R2F-?3G=/=S5,1SY-=U!W
M<>]1=W+O,T%&/E)W4W=[3G3O:E]Y0'/O5'=6=W7O9E]K7VPQ5W=V[UAW:5]A
M1V5?:%](/EEW44AL7U$\>D!Y[V]?6W=<=V=?)S=M7UUW4$UP7WCO)G1Z[T\]
M>^]\[W%?<E]][W[O+D<A\'1?7W=U7UYW,T=@=W5%=U\C\'E?54YV7R3P>%]M
M,7-?)?`F\%M3>E]G03@[?%][7R0_65)]7R%@;E]^7V%W(F!B=WI')_`C8"1@
M8W<E8"9@7D0J\"A@)V`I8"I@*_!?/&-)+/`M\&Q,*V`L8%9!)#PM8"Y@+_`O
M8%)*1T@P8%='+40P\&1W97<Q\#%@9S)M-49,-DPT,C1/,O!22RI*-/`U\#=`
M,F`V\$-&(S@S8#?P5#HU8#1@-F!G=SCP-V`X8&AW/C4Y8#I@)#@Z\#OP2$@\
M\#WP/&!U/CM@:7=J=S[P.#8]8#]@/F!`\$!@43A!8&DV0$%].4-@1&!"8&T\
M2$8Y-D/P1F`L0T5@1/!K=S5/8D=%\$E@1O!+8$A@1_!(\%1,2F!,8$1.4&!M
M=VYW3V!V0RU'2_`E.$Y@3/!-\$U@,4TR34KP3O!18&XQ=CEB.U)@4V!P=T_P
M56!#/7%W5V!68%'P4O!4\%7P6&!6\$TS6F!7\%E@7&!;8')W6/`\.%GP*$Y,
M-EKP)C);\'-W:C9<\%WP7O!T=W5W=G=?\'=W8/!A-'AW:$Y>8&'P8O!C\&!@
M9/!E\&%@43)F\%U@>7<Y.V?P041?8'IW>W=\=V1@;CQH\'UW8F!I\'YW/C=)
M2&-@?F!I8&KP;/`].&WP935F8'U-(7@P3B)X:_`C>"1X=D)N\&A@)G@G>"AX
M*7@J>"MX+'@M>&_P:F!63E<V?$A*1W#P:V!M8'+P<&!S\"YX+W@P>#%X=/!U
M\''P;&`R>&]@:CA-,7%@=O!P/VY@7$XS>'1@)'1R8'5@-'@U>&=@<V!W\#PZ
M=F!W8'CP?DUY\#9X-WAZ\#AX>&`]>'SP??`Y>'[P.GAY8#MX(?$B\65@/'@C
M\3YX>F`_>$!X)/$E\40T07@F\2CQ)_$E/$)X0WA$>'M@?&!]8"GQ*O%%>#LQ
M*_$A83M)(F$D-"-A)&$M\25A+/$G82AA)F%322IA*6$O\49X1W@L82MA+6$N
M83!A+V%Y.3)A,6%(>$4T4S\\13-A.$`Q\3H[,O%Y,31A44TS\6-*-6%)>$1%
M,TU#.3T_2T,T4BY$:#(V83;Q-_$X\3=A/&$Y\3IA.6%"6B8S.&$Z\5HP._$J
M2#SQ2D@Q3CUA.V%<0R9`*T@M23]A+$Y--T!A/F%62$%A/?%"84IX6S`_\3[Q
M=CY'841A;49#84MX0/%!\4+Q)C5#\4IA16%&84EA2&$E247Q0D%!03\U3'A+
M84QA36%'\4]A3F%6,4GQ5V%H2%%A4V%*\55A/C]6851A0#Q+\4SQ4&%284))
M3?%)/EEA6&%.>$[Q6F%/\28\+SIW15MA2T10\5UA4?%2\2%.7&%/>%/Q:4%4
M\57Q8F%6\61A96%40U?Q8V%@85YA7V%0>&%A47A8\5KQ4GAH869A9V%;\5[Q
M4WA4>%GQ57A?\6#Q5GAI86MA;&%M86YA8O%J86/Q5WAP867Q;V%8>'%A9/%H
M\45.67AT87)A<V%J\5IX8C1^3&OQ2DIV875A=V%X85MX7'A\87EA>F%[87UA
M77AM\5YX?F%?>"%B(F(C8B](4$4D8G)'-$DE8F!X)F(J12<S1#DG8BAB*6(I
M.RMB;O$J8BQB+6)A>&_Q8GAC>''Q</%D>'+Q<_%E>&E(=/$N8B]B9GAI<S!B
M,6(R8BX[,V)61V=X7TM.,7;Q5S%H>#1B:7@V8FIX-6)P13E`.5TW8D%,.&)&
M-%=(.6)K>#IB>/$[8GGQ7$QL>%5,/D1J03UB;7AB/4H^0&(_8CYB?4AN>$<T
M*3A[\6]X?/%&8D-B/S\R3$)B1&)%8D%B??%P>'[Q<7A'8DAB+T1C-&5#<GA)
M8G-X='@E\DIB36)U>'9X)O)G/W=X1$9.8E-+2V(G\DQB*?)18GAX*O(K\E!B
M3V)Y>%-B4F)48GIX+O)68B_R56(P\C'R34HR\GMX5CU&3E=B-T988EEB76);
M8EQB6F)>8E]B8&)A8C=,8F(S\C3R?'AP3&-B-?).0S;R:D=K-C?R./([0V1B
M.C8Z\E!`._(\\F5B/3H^\C_R0/)F8D'R9V(F.%4Z0O)I8D/R5D56.DXU1/)]
M>"1+2T=715PY(7EK8D7R(GDC>21Y2SY&\B5Y1_(R3D4Y)GDG."-(;6)O8FLX
M;F)V1$GR<6(W,VQB:D@P,4KR;#I23W!B3/)-\D[R<F)+\DM*64!T8BIY=6(H
M>7-B3C-/\GMB>F(G/'QB=V)0\GUB>&)1\E+R6$AV8GEB4_(B8U3R5?(K>5;R
M(6-A2WYB:S`L>21C+GE7\ECR6?(C8UKR+7E,/B5C0T%<\B=C)F,H8UWR+WE?
M\FAB:F(J8REC,'E>\C%Y,GDH/&#R:4Y2/"MC-S<U>39Y0#4G-6,[8?(T33%C
M,&-$02UC8O(O8V/R.GE+/4`_+F,L8RI'33YE\CQ)5SIF\GA%/GDR8S-C26-8
M-CU/-4$T8U(R=T0A2F?R:/)I\D)Y:O(U8VOR>C4V8VSR.&,Y8RE'0WDZ8VWR
M1'D[8SQC;O)9-E,R148H/60[;_)P\D5Y/6-&>2D]<?)R\DHR0TE(>3YC<_)K
M2$EY14%!8T)C:4=!/S]C84-*>4!C2WE./EPP*35,>4-C>/)X1$1C1T!Y\BU,
M>O(C245C1F-50WOR1TY\\DAC1V-^\F\\2F-P,$UC(?-.>4MC5#).-TQC1CER
M.69*3F-42R+S4&,C\U%`3S$Z,BPP)/-/8R7S)O-/>2?S*/-18U)C=SXI\U-C
M*O-/,U!Y56-J-ROS9C4L\U9C=3978WQ`348M\V!`=3I2>5AC+O,O\V)#:T%:
M8UQC66-;8R(W4WDP\UUC)C<Q\V<U4DU?8U5Y8&,T\RXQ5GDU\S;S8V-V,V)C
M86-E8UYC9F,I3CCS9V-7>6AC.?-T5&IC:6-K8VQC-4YM8V]P3SYN8V]C5STX
M1G!C.O,[\RA#6'EQ8SQ#<F,\\R4V/U%=0S,\67E(-'-C(F1V8S_S:#5U8R1D
M=&-0/EIY>&-Y8RM%>F->,UH_9$E"\WQC0_-H0EMY1/-%\T;S=V-[8WUC>SI<
M>4'S2O,F9"Y)77DF2'E%6C8E9"-D7GDU2'YC7D-[17I%3/-V.CAD7WE.\RAD
M3_,J9%#S+61@>2YD87DK9"QD8GE1\RED)V1-\R%D2?-/2E4R-60R9#=D5/-5
M\S9D<T<G3#L[,&0Y9#1D5O,S9"]D8WDQ9$DT/4-]0%CS(D@^9%GS)$A:\V%`
M.V1/2%OS/V132EM#7/,Z9#QD/61?\V#S97EF>6'S0&1$/$9&161$9$%D8O,V
M3V/S2F1.9$MD1V1G>63S2&1E\TUD9O-G\T)D55))9$-D3&1I>5)D:GE*-$]D
M:/-09%%D5&1H>6MY;'E39'9(561\3FU*6F179&GS:O-69%)`661;9&OS6&1?
M9&SS7&1O>6WS761&9&[S7F1@9&_S861P>7#S<?-R\T9*8F1Q>6),3C8I-V-D
M-$IH/S!,<GED9#-.<WET1T9!-$=-/4`P='EI9&=D960A-';S43YJ9&AD9F1N
M9&UD;&1K9'CS>?-O9'5Y<&0Z0'KS<61S9'SS<F1^\U(X(?0X075D=GE\12/T
M=&1W>79D>'DU2FQ!1SEW9"7T2$XF]'ED>F1[9"CT?&1E.WUD3S=J-2HU(64I
M]'-,2#E^9'EY>GDJ]"1E9DP\1S-)+/1[>6,](V53/$DY9CMI-39*(F5\>2WT
M1T%"2W<Z?7EG.UU$)V5?3EDZ?GDH94(_*F52/C`Z,/0Q]"EE,O0A>BH]/CA(
M025E*V4S]")Z)F50-RYE,F5K-R-Z+64W]#CT-F4D>DHY;4T\,#-E:S4P93GT
M,64Z]'U%+V4L92@S9$`H."5Z.&4\]"9Z/O0_]#5E)WI`]#=E-&5!]%$W,T(Y
M96Y!0_1&92AZ0F4\92EZ1/1%]$!E>CQ=,#ME0V5'94LY5DQ61#UE1O1']$5E
M.F4^0S]E/3!*3$CT*GH^95LV;$@K>FU!4$YO/6YE+'I)]$AE2O1^0$1E265+
M97E$3F4M>DIE2_142DLT2TQ>,$ST365]3DWT3&5O,6Q&3V4P>E9E4&5795'T
M,7I393)Z4O1[1U/T2CQ5953T4F5895%E1#U5]"]Z)4M6]$P]5&5@95QE7V5=
M96%E6V5!95-`2TA>95?T664T>B%!4C<K/35Z)3\V061E9F5G96-E964V>EIE
M8F5J96EE>DLK-UCT6?1H96QE:V5O95KT<64\.VUE6_1<]')E<V4W>G1E.'IZ
M93M%=F5>]'5E=V5X97EE7_1@]'ME?&5,-'UE?F5C]&+T9/1E]&;T(68Y>B)F
M(V8D9F?T)68F9FKT*&8G9BEF*F8K9FST;?1N]"YF+&8M9F$Z4S=O]%9#,TAP
M/4U';4@O9FU8</1Q]#!F,F9E33%F-&8S9E---69^2'/T.WHV9G;T/'HY9G?T
M.&8W9CIF,C<B04$U>/0^9CMF/&8_9D!F/68I,3UZ)S)Z]$)F0V9$9F)-/GI[
M]"P]1F9%9C]Z0'II/T=F?/1]]$AF269E-$%Z0GI^]$TT(?5*9DMF0WI=2V--
M5$TW3R+U33E.9E0\368D]2/U3V8I/"7U44(F]5!F17I,.2?U5TQ19E)F4V94
M9BCU1GI59BGU*O4J/$=Z;4Q(>E=F27H_0U9F*_599EAF6F8[0%MF7&8Y2EUF
M;T%>9BSU7V9^3F)F+?5A9F!F,$0N]6-F)C]D9B_U968X3V9F9V9I9FAF)4AY
M1CY/*4AK9E,^*DDP]6QF:F8Q]4XT5#AH.S+U;D@S]2HX0TMO9FUF3CE/.6DP
M:#HT]5E'7S!T9C;U0$-*>EA'6T(W]79F2WHX]7)F=69P9G-F)DM,>E4X?3!Q
M9CGU>&9Y9DUZ.48\]3LV/?4F9SU':3L\-DA`1D\N3'=F5$`[]4#U3GI3-7IF
M0?5\9D/U1/5[9D7U?68F0SY'/_4Q1$?U(V<B9T]Z?F95/V5))6<D9U`Y4T\U
M9U!Z*6<J9U%Z4GI)]7`\4WHH9W@Y)V<K9S)$(DHC05Q"+V=+]3!G+&=-]4[U
M+6<N9U$Y-F<R9U#U9DEL2RA),6<T9S-G1$LW9SAG4?4W03EG.V<_9U1Z/&<Z
M9S]'/6=2]3YG4_4R,D5G0&=5>D%G5GI"9R%"5/57>D1G0V=&9U7U1V=(9T,_
M5_5I,DEG5TXK/%GU+3UJ.U=#2F=+9S$Q6_5,9USU36=.9U[U3V=09STV*EI1
M9V5`4F=+/%-G,%!49UY*7#1@]21!6#UQ22X]8?5B]55G4CE69TQ(9&=D]5AG
M9?5)0G5'/SA79R5!9O599VGU9_5Z1&CU:_5M]6_U6V=:9UUG<?5<9UYG6WI@
M9W+U7V=/-&%G8F=C9S$Z24YE9R<_7'IP,69G9V=V]7CU:&=Y]7KU>_5R,&EG
M7GIJ9WSU9TE'/&QG7WI@>F%Z*3,R,'WU?O5B>FMG;F=.1V-Z1#]6,B'V)TLB
M]F1Z73=<-B/V;6<D]FHR97IF>B,T9WIQ,7)G:DY=0FAZ1$E^9U<R?&=Z9W%G
M;V<E]G!G8SQL-G=#)O911E$Q=&=S9R?V>6=U9WAG:7IJ>FMZ;'I03'=G6#)]
M,WMG*/8I]GUG*O94-R-H+&@M:"SV*S`M]FYZ-&AQ,"MH;WHJ:"[V)6@D:")H
M(6AC0WM")VAP>B_V)FAQ>C#V*6AR>G!!53=!,2AH<WI3.2OV='HQ]G%!;7I*
MKCIH.VA9,BXR.&AU>C/V+FAV>C9H/6@W:#;V-6AW>G9G-_8X]C-H>'HO:#GV
M.O90-#%H/&@R:'EZ/FAZ>C!H?$=I33EH3VA[>GQZ1VA[/WUZ._9&-5TV0FA^
M>CSV(7M;,CWV5#Y%:%HZ/O9114IH(GL_]FY*(WM!:%HR5C@I24MH/VA(:$#V
M4FA#:"1[1&@Z1B5[26@F>T9H*$M,:&`P0?9"]D!H0_9%]DYH36AK1U1H7VA^
M,V)H4&A&]E5H;DU>:"A[54U']BI.2/9)]DKV>$-+]DSV:S--]BE[<DED:"%&
M3_8Q,%UH66AR05-H6VA@:"I[+$<K>RHP4/98:%'V86AX25+V4_9<:%=H+'M5
M/B\]+#Q6]EA,1TDM>V=H<&A7]EIH+GMW,R][>#YE:#![:FAS05CV9F@Q>VUH
M,GM?0VYH5DUC:#@S:6A:]EOV;&@L3%SV;VAH:&MH5?9>]E_V*4LA3V#V8?9B
M]G-H8_9Z:&3V<FA#/%%H9?9.2B),>6AX:'1H=6@V,6;V-7MW:'%H-GMG]FCV
M541I]G9H?C`W>S1[:O8B0D-*;_9[:"%I64A^:%8^23PC:3XV:_9P]G'V)&EY
M27UH.'M6:'+V<_9T]GQH.7M/3R)&<TDK:6SV,6D\>W;V=_8R:7CV)6EY]G9'
M>O8O:2=I*6D]>SY[,VDH:7OV+&ER,65&+6DP:7SV??8_>R9I)D$J:2<[13\P
M-W1,.WMY3'(]0'LC]S=I-6DD]TY/)?<T:2;W07MU34)[-FDX:3EI)_<H]SQI
M.FDI]RKW(T8[:2OW34@N:4-[+/=S/3UI0FET04%I17LM]R)I1GM'>T-I24$^
M:4!I2'LN]T1[/VDQ72)=2GM%:2_W,/=$:3'W,O=+>W9-/&)&:4Q[-/<U]T=I
M-_=H+TAI5SA4-3GW2FE=43KW37MU-4Y[.DYS-DMI4'M,:6Y#4GL[]TUI4WL\
M]WI&/?<Z,#[W/_=C,E)I4VE`]T'W3FD].U1[0O=#]T]I0D=$]U!I46E;:55I
M6&E&]T?W5&E5>TCW2?=6:5=I6#Q9:4%#5C=",TKW7&E+]TSW/S-A:5UI8&E-
M]SI(3O=>:5]I2$E:2&)I?4)L:59[:&E7>UA[:S)F:2I+9VE0]V1I4?=E:6II
M;6E9>VMI4O=3]VEI8VE4]UA#5?=T:2I,5O=7]UCW<FES:5GW;FEP:5KW<6E;
M]V]I7/==]V9`.4]X:7EI7O<A:BH_>VE?]WYI=FEU:2)J8/=A]UPR?&DC:GUI
M6GMB]WII,T1W:6/W:$<G:EM[7'MG]VCW.TUI]R9J:O<E:F;W+FI=>UY[*&HP
M:E][9DTS:BIJ;?<K:F_W+VHR:C%J*6IP]RQJ/6IA>W+W-FIT]W7W=O=W]WCW
M8GMY]S1J-6IQ]SIJ.VHJ,T(U.6IZ]WOW)&IC>V1[?/<X:CQJ-VIE>SYJ??=F
M>T!J/VIG>T)J06I::49J?O<A^$-J(OA$:D5J1VHC^&PW26I(:C`])?A4.2=>
M2FI1/3DS)OA+:E(Q5SY,:B?X53E-:F$P*/@]22OX3FHM^&H_56I2:F]#4VI0
M:EXV3VI6:C8W7D)<:EAJ-4)7:FA[6FI1:B[X6VI=:FE[;TA9:EYJ8&I3.%1J
M03`O^##X,?A?:C+X6SIV3F%J8FIU06I[:WLB3C7X,_@V^&-J-4UD:F5J-_AD
M2F9J0#HC3FMJ./@Y^&QJ6#YJ:FU[9TUG:FEJ/4!^/SOX:&IM:B-*;VIN:FPS
M*TMP:G![<7MR>VY[?&IR:G-J<WMT:G5J='MU>WEJ/?AZ:G9[>&IW>W9J/_AQ
M:G=J0/A!^'MJ-W`H,GYJ7S9]:D3X(FLA:R1K(VLE:S$])FLG:RAK/D!%^%=-
M*6LD2D9'*FM&^"MK*S@L-4?X+&MX>VL[04<M:U`S2/@N:S!K=TTO:T8_,6LR
M:TGX,VM1-$KX-&LU:S9K-VM1,WI[2_A,^#AK.6LZ:W(R>WLH/SMK3?A/^%#X
M/&M\>SUK4?A2^$`X>T0^:U<W5C]!:R1&0&M4^'U[,3=5^'Y[/VMW0BTU0FM#
M:UD^5_@A?&TW1&LL2U]`=C5U3$I!6/A%:R)\1S]P0UH^6?A&:UKX26LC?$IK
M6_@D?#XZ0D)(:UL^/DE<^$=K)7QL.U,Q)GQ.:U@W;CMM.TU/36M,:R=!335#
M3SHS7#XG?"A\2VM0:U%K3VM8.$!-;SLG1U[X5&M`0$)#-DU7:VPX/T!3:UAK
M;3A5:U9K*7Q2:V)`249=^"]#73)?^'!(0S5@^#1$6VM9:TQ#04!2-%IK6S\J
M?$I.0$]A^%QK9VLU1&9K*WQC:VMK9&M@:WQ$7VM=:R%-<#MA:UYK+'PM?&5K
M=#U!.&+X>D)%2UHQ8C`E1F7X:6MD^&AK9OAF1FUK8FML:VYK+#AJ:U8Y9_A5
M/&CX;VM837)K=6MS:S5):?AP:V`V=&MV:VKX,7QZ:W=K>6MX:VSX,GQ[:S$\
M,WQ]:WQK:$EM^"%L63<T?'YK(FPC;$0U069Y/B1L;OAN."5L;_@F;'#X/CM.
M6G'X)VPH;#(]*6PJ;'+X<_@K;"QL+6QT^#5\=?@K0W;X+FQX^#!L+VQ[^"9&
M?/@Q;#9\+4LR;#-L??@T;'[X-6PA^5I&73XV;#=\(OEK.2Y0-VPC^23Y.&P_
M23EL06PZ;#QL.VP];$9+/FP_;"?Y)OE`;$)L*/DJ^2TS9T1I26(Z5SDK^4])
M7S).2$5L4S150$1L26QY0V-,1VQ(;"XU2FQC1U]"<4@]149L1TML,DQL*$]"
M1$5/<3M+;#%"7&PH07A&4$DM^2SY+OE/;#\[<CM>/F5'.7PM.$YL36QJ24$\
M4D4P^3'Y.GP[?%%L4FQ8.5!L/'Q3;%1L5FPC0C/Y56QF-%AL-/E7;%EL/GQ;
M;%UL7FP_?%9`3SQ?;%(S-?E@;'9!86QB;&M)+S5C;#;Y-D1;,3?Y9&QQ/#CY
M=C]`?"U"9VQF;&5L.OD[^6UL:VQ!?&AL0GQJ;$-\//EI;&QL=S5P;%=`<6Q9
M.&YL;VP]^2E/-T0I07)L0/EU;$'Y<VQT;%E-/ODG1GAL0_E$^79L=VQY;$1\
M1?E&^45\1_DI;7QL?6Q[;$KY2_E&?'IL?40A;25M(FU^;$SY(VTD;4WY*VTF
M;5A`*&U.^2IM)VU/^5#Y4?E'?"UM,STL;4A\+FTO;3)M,6TP;31M,VUV3#9M
M-6TW;5+Y.&U3^3IM.6U(/SMM5/EM-CQM/FU5^5;Y5_E8^3]M2GQ`;3UM06U6
M/$)M,#4S-UKY+CA;^4-M<$8^141M1VTT/%WY3'Q&;45M6C=(;5_Y4S-*;6#Y
M7#I);5)M3&U.;65*2VUA^4UM46U/;3$U37Q0;5-M6D=83F+Y3GPT/51M3WPB
M359M56U9;4%-8_E8;6TS5VU<;5MM9/E:;3)%76U0?%YM9?E?;6PY)3=@;6%M
M8FU)/V-M+3QD;65M9_E2?"%2?E%F;7!E9VTD0RL_0$=H^5-\:OEH;55*5$1^
M.2E#;/DJ,7A+5S]M^6_Y</E>-V$V<?E62G+Y:6US^6MM5'QJ;6`R57QV1FQM
M=T<S159\;6U2/73Y;VUU^4),?FUQ;7)M=OE)1&!"=T%W^2A&<&U5-5=\>6UX
M^79M)6XI1F!#<VU^1%-%=&UX;6`_9T=,1$)`=VTN0B1"=6TI,")/>FU8?&%"
M-3U*/WQM>VUY^6\P?6TO22=N6T9K/WOY?/E90W@V)FXW33\Q5TIA,B%N(FXC
M;B1N.T8C0V,P*&XI;B-T/4)]^2IN<S%,02\X6DTK;BQ%>$%7/"QN+VYE/2UN
M*T$J060P2TXQ;G)(,VXR;C!N9&-4-"+Z;FU:?#5N-&XC^C9N)/HX35M\7'Q=
M?%Y\)OI??&%&+DLW;ED\.&XH^CEN8'PZ;BGZ(45A?&HP*OIB?&-\9'PK^EDY
M.D]E?#YN+?IF?&=\+OHT-SMN/&YT23/Z5#-H?#'Z:7PY33#Z/S94133Z-?HR
M^C]N-OHW^D!N:WQL?&U\./I!;CGZ.OIN?&]\<'PB17%\0VYR?$)N<WP[^CSZ
M/?IT?#[Z/_IU?%-&1&XV/6`\6T=Q0W(\;#]%;D#Z1FY!^G9\0OI=/T=N0_I(
M;DEN;TTW/4MN2FY$^EHY<SE`.T7Z3FYW?$;Z9CU-;DQN:4)'^F\X0T`P2#D]
M>'Q/;E\^2/I2;E!N>7Q)^E%N>GQ*^E1N4VY+^GH^56Y[?%9N5VY,^DWZ4$A3
M.F$\6&Y9;B1.13UN3$Q.6FYB-EMN?'PC14[Z7FYX,TL_7&Y=;F!$?GPA?55+
M?#91^B)]4OHC?6!N86Y]?%]N8VY3^B1]5/I?1D,S)7UG;F1N9FY5^E;Z8FY/
M;V5N6/IK3EHX)GTG?2A]*7UO;BI]6?HK?31%:FY:^FUN:VY;^G!N7/HL?7%N
M7?I>^FEN7_IV;G0Q:&Y@^F'Z+4AL;F+Z8#YC^F3Z6SDM?6?Z:/I(2VGZ9#9&
M/3Q&+GUJ^FOZ+4%T;FYN<VYL^D-,;?HX1'5N<FYN^F_Z</HL07/Z>6YX;G3Z
M=?HO?7;Z,'TQ?7?Z=VYX^B]+,GUY^GKZ,WU[/7OZ?/IZ;E]*5#%&27)#(OMX
M-2/[?&XD^UTY-'TE^S5]+#LF^WMN;3]]^B?[;C\A;R-O*/LI^S9]>SXW?2)O
M)&\X?5,V*OM%22O[8CPC3WYN>#H_3R9O)6\G;WUN+OLY?3I].WUI1E5%+_M7
M1"QO,/LQ^T-#*&\I;SQ]/7T^?3+[+3<K;S]],_LT^S`X*F]A/CC[.?MY,SK[
M,&\_.GE!2D1`?3O[-?M!?3LS+F\O;T-$+6\Q;T)]0/LW;T-]0?LZ;SEO+44R
M;S-O-F]"^SAO1'U%?4`V0_L[;S5O1/LT;S_[//M)^T=]/V]&?4!O1?M&^T%O
M/F\];T?[2/MB/BI&/&]%;T-O2OM(?4O[1&]";WA"1F],^T=O26]-^TE]531(
M;WI,5&]*;TUO2V],;TI]3F]+?5#[4?M0;TQ]37U1;U)O56]3;U9O6&]7;SE$
M4OM3^V=,66\N053[6F]$2EMO*S-5^U;[3GT\,5<T5C1<;UUO7F]?;T]]8&]8
M-%4S7CDV2%!]8F]A;U%]6/M2?6-O7#%9^U-]9F]E;V1O5'UG;VIO1S!;^VAO
M57UL;VMO5GU7?6YO;6]O;RY&67UP;UI]<6]S;W)O;$DE^G1O=6]E.E[[=F]W
M;TE+7_M@^TM!8OLD,$M"8_MX;VU)>V]Y;U\Y>F]".%M]14I];R%P?F\B<&3[
M(3%8/WP]630C<&9')7`B,21P1$1-3BM&?&\F3C$X6TUF^UQ]>38T3B@W8D(A
M9R9P+#-O/U8S*'`I<"=P9#=H^UTZ8SY>?2,Q64Y??6!]*W`N;FO[*G!L^RYP
M+'`M<&W[+W`P<&Q.,7`R<&[[24`[2&_[?3]G-#I-;3(X/5LX-7`T<',[-G`S
M<"@[87TZ<"UJ<OM64G/[=S\X<'3[8GTE3G%&*S%D?6-`-CQE?3=*0#%M3FM-
M.W!%17L\/'`]<$P_/G!N3CEP0'!"<$%P/W!V^T-P1'!Z06(R=_M%<#A,1G!'
M<"I/9GUY^S%;2'!G?4EP2G!Z^TYP2W!,<'O[37!/<&A]:7UJ?41`?/MW3'W[
M14!K?7[[4'!S2%%P4W-,3%)P4W!4<%<S(?Q6<%D_;'U7<&U])#=8<%QP6G!;
M<',S67!=<%YP2#!?<&!P;GTD_&0^)?QA<";\1S4G_&1P8W!B<'%K7$IO?2C\
M*?QE<&9P<'TJ_'%]9W!H<&EP<GUJ<"O\+/Q:-"W\+OPO_'1]:W!S?3#\;'`C
M1S'\;G`[,G5]<7!P<"0Q039'2CI$(CHR_&`Y9SU</W=]<W`S_#3\<G!"36@T
M4DA<1C7\-OQ\/TY.6S=X?79P.?QU<#S\>7U+2RQ&>GTZ_#O\4#%W<'1P44EJ
M37AP>7`]_'MP:D);,UPS>G!\?7U]:30R.'Y](7YJ-")^(WX_16!.)7X^_%PX
M?'`F?GUP?G`A<2-Q(G%W221Q/_Q`_"5Q0?PF<2=Q0_Q$_"=^1?Q&_$?\2/PI
M<2AQ*G%)_"A^2OQT2$QF*3]+_$W\,C5._$_\*7XK<5#\+'$L4CM=4TA1_%+\
M>S!3_#LP=#LP2WX^+7%?3%3\+G%<34(Q03LO<6XR,'%7_%C\,7%:_%O\7/PS
M<31Q-G$R<35Q6S0W<3AQ7OQ?_&#\8?QB_&/\.7$Z<63\9?P[<3UQ9OP\<3]Q
M0G%G_&C\/G%`<4%Q0W%"-BI^:?QJ_&O\<SQ$<45Q83DK?FS\1G%M_#XS3T='
M<4AQ6D-K1F[\27%O_'#\?4=Q_$Q"6#%N-F\V<OQS0TYQ<#9S_&\R37%T_$MQ
M3'%U_$IQ6'%/<5!Q=_Q1<5)Q5'%X_%-Q>?Q9/55Q+'XM?E=Q>OPS-59Q>_Q[
M03,X?/Q9<7W\?OPN?DU"6G$O?C!^+48A_2+]6W$Q?F!Q7G%=<5]Q(_U<<3)^
M)/UB<3-^-'YA<61Q)?U#-F-Q97%F<6AQ9W%I<6MQ:G%\.6QQ)_UM<35^*?T\
M,RO];G%O<39^-WYQ/RW].'YP<2[]<7$O_7)Q<W$P_3E^8CDR_71Q=7$S_79Q
M=W$T_7AQ-?TQ2'IQ)DE[<7EQ?7%\<7YQ.GXA<CM^-OTB<CQ^-_TX_3G].OTC
M<B1R._TE<CU^)G(G<BAR*7(J<BMR+'(\_3]^+7(N<C5=+W(]_7AD-#4^_2$S
M,CHQ<C!R)4Q`_3-R-'(R<C5R8DLV<GLU0'Y!_4+]0GY#_43])4]#?D7]-W)$
M?D;]1_U!?CER17Y&?CXP1WXZ<BM*.'([<CQR2'X]<CYR2/U)?C]R;DLM.TG]
M>CHO04K]3?U`<D[]0W)/_4%R2GY$<E#]<3A"<DM^17)&<D=R2W(J.U+]9$)3
M_4QR27)(<DIR3'Y4_5\W5?U6_5C]5_U0<D]R3G)1_3,P7/U-?EK]3GY/?EIR
M5G)7<E-R67)5<F(S3$]8<E1R4G)1<E[]7_U@_6']7')B_5]R8_U0?EYR77)D
M_67]9OU)25MR<S!@<FC]8G)I_6K];S--<C<Q9')1?FO]8W)A<BU#;OUO_5)^
M4WYP2U1^<?U:3G+]97)S_6S]=/UU_69R57Y6?F=R=OUW_7C]>?UZ_7O]?/U]
M_6AR5WYI<G[].T0A_FIR-TAO<FMR;'(B_C%+1$Q01B3^<')Q<CY&;G)M<B/^
M*C(F_GER>'(G_BC^=3%8?EE^=G)U<G-R>S-R<C(\*3(L_F,Y?')[<GIR+OY:
M?G=R?7);?GYR+_XE<R1S7'XF<RTQ(7,B<S#^=#DY3#'^77XC<S/^-/XR2RMS
M7GXG<S;^-_XX_BQS7WXY_CK^*7,H<V!^._Y<-V%^//XM<SW^+G,O<RIS8WYT
M<C!S840__C1S0/XU<S-S9'Y!_C[^8GXR<SAS0OXQ<S9S0_Y$_C=S.G-%_F5^
M.7-&_D?^2/Y)_CQS9WX]<SYS24]*_CMS:T)M.C]S3?YH?DS^3OYI?D_^0'-!
M<U#^4?Y"<T-S-#A$<U+^:GY%<R\\5/Y&<U7^1W-(<TES3'-*<SQ/2W-O3E;^
M37-K?EM.;'Y.<WY'5_Y/<U%S;7Y2<VY^;WYP?E!S;3E-3&-+=U99_F!=>TMQ
M?BLR5'-0-55S5G-7<W)^=3E8<U1@6TQC0EES6W-:<UO^7'-=<US^7G-=_E]S
M8'-A<V)S8W-D<V5S9G->_E_^8?YG<VAS)$5S?ETX:G-B_F/^34%K<VQS9/YE
M_G1^9OXA26?^;7-H_FG^:OYN<S=C6FQM<&]S:_YP<VS^=7YM_F_^<G-S<W1S
M<$YQ<W5S=G-Q_GAS=W-S_G3^>G-U_GMS>7,V3G9^=WY\<WA^?7-48WYS>7X[
M=BYT3G5/>TEV)'Y=?4LO5R]R3WFN>G5:=V]W/'D]>4%Y.GLX]T7W+GQN^6I\
M."Y)+E`N8RYH+FXN+"\O+S8O6B]>+V%/8D]0=%QT7G1A="AU*W5#=65U:79W
M=B5W57<I\"5X)WDS>31Y-WDX>3EY.WD_>4!Y37E1>61Y+GI0]#-Z.GI$>EAZ
M=/5U]2=[;WMY>R]\,'PX?#U\:?E9?&-]=GU[?3XC/2,J(3`B="%P(7,A=2$O
M(DHA2R%V(5PA)"$Q(B4A/R$P(S$C,B,S(S0C-2,V(S<C.",Y(R<A*"%C(6$A
M9"$I(7<A02-"(T,C1"-%(T8C1R-((TDC2B-+(TPC32-.(T\C4"-1(U(C4R-4
M(U4C5B-7(U@C62-:(TXA0"%/(3`A,B$N(6$C8B-C(V0C92-F(V<C:"-I(VHC
M:R-L(VTC;B-O(W`C<2-R(W,C="-U(W8C=R-X(WDC>B-0(4,A42$R(E8B5R(Q
M(6\A(BXAH2NA+J$VH4:A<*%YH7>A(J,EHR>C,:,RHSBC/Z-!HTJC4J-3HUFC
M7*-WHRJD.J0RI#&D/:19I$(O7*1CI%ZD:Z1JI'*D3"]TI'6D):4RI6`O/J5'
MI6-/5:56I7LO?J4PJ#>H.*@[J#JH1:A`J#^H2*A*J$NH;D];J&:H;*@BK%/^
M*ZPPK%"L9:QMK'*L)*TRK2FM*JTUK32M.:U6K22N?:TZ=2.N.JY"KCVN/*Y$
MKD>N2:Y#KE6N5ZY6KENN=ZYXKBJO<G5"KS^O0Z]`KUFO3J\I=C)V8:]JKVFO
M<*]UKR/N-.Y@=DGN=?1<[F#N7^Y>[C+O1^]-[V'O9.\B\#/P.?!L=U/P>_`N
M\3#Q-?%$\5WQ8?%F\6GQ=?%W\7KQ(?(D\B/R*/(L\CWR?GA(\BEY6_)'>77R
M=O)4>3+S/O,]\T#S4O-=\U[S;GES\W3S=_-U\WWS>_,B]"3T)_0O]"[T-?0T
M]#WT0O1/]&GT:_1R]'GT-?4Z]4;U5O58]5KU7?5?]6/U:O5P]7/U77I$I43V
M3O8S>UWV=?8A]R+W?O9)>S/W-O=E]V3W:_=N]W/W*O@I^"SX;'LT^#SX/OA"
M^%;X8_AW^'GX>O@E^2_Y,ODY^4+Y2/E)?%GY7OE1?&;Y:_EZ^7[Y(?HL^B_Z
M4/I/^E?Z9?IF^G'Z<OI^^B'[+?LL^S;[-_L^^SW[3OM/^U?[6OM<^UW[8?ME
M^V?[:?MQ^R+\(_PX_$+\3/Q6_%G\7?QV_"S]2_U9_4S]7?U;_6?]</UM_27^
M*_XI_C7^,OYF?EC^6OYN_G#^<OYV_@``````````````````W_\/`-__'@#_
M_RX`__\^`/__3@#__UX`__-L``X_=0"P#'H`,&:``)XYB0`__Y<`/_RC``-^
MJP```*L`"`"L````K````*P`!&"O`%<5MP```+<``".Z````N@#_U\@`\_'3
M`"]NW0`>?^@`-R'O``8`\0```/$`@!'T``-K^P#@`P`!`````5^9"@$`]Q$!
M,988`1$^'P$``!\!```?`0(`(`$``"`!```@`?[_+P'[`S@!_O]'`?\#40$`
M`%$!``!1`0``40$"`%(!__]B`?__<@'__X(!__^2`0(`DP$``),!``"3`0``
MDP$``),!``"3`0#`E0$``)4!``"5`0``E0$/`)D!``"9`6DSH0%G`*8!#9BL
M`80#L`$"`+$!``"Q`0``L0$``+$!``"Q`0`0L@$``+(!"("T`4@`M@&""+D!
M(`"Z`0``N@$X`+T!_P_)`?\/U0$``-4!WP/>`0``W@$``-X!$`#?`10`X0'`
M`^4!``#E`:T+[0$,Y/,!X5_]`3`@``(H`0,"!``$`L<,"P+```T"_`P5`N`"
M&0(@`!H"`(`;`@``&P(`#!T"```=`@``'0)@`!\"!`$A`@``(0(``"$"```A
M`@``(0(``"$"`,`C`O]?,0(``#$"```Q`@``,0(``#$"```Q`@@`,@(``#("
M```R`@``,@+__T("#P!&`@``1@+__U8"__ME`O]_=`(/D'H"F3F"`CF9B@*9
MF9("!`B4`@``E`(``)0"``"4`@``E`(``)0"`P"6`LXPG0+#RJ4"#P"I`D"`
MJP(``*L";T"R`L!`M0(``+4"``"U`@4`MP(``+<"___'`@``QP(``,<""`#(
M`@``R`(``,@"``#(`D``R0(``,D"P/_3`@``TP(``-,"``#3`C``U0(``-4"
M``#5`@``U0(`#-<"[__F`O^S\P(!`/0".#CZ`O[_"0/__QD#__\I`___.0/_
M_TD#?_A5`___90/__W4#__^%`___E0/__Z4#__^U`P``M0,``+4#``"U`___
MQ0,``,4#``#%`P``Q0,&`L@#``#(`_[_UP,``-<#``#7`P``UP,``-<#\`'<
M`_[_ZP,``.L#___[`R\R`P0`!`0$""`&!!`!"`3,"`T$0`@/!``F$@2"`!0$
M```4!`!X&`0`P!H$`'`=!`(`'@0``!X$$"@A!```(00``"$$```A!$0`(P0`
M`",$`%`E!```)00``"4$```E!``%)P0``"<$```G!`0`*`0``"@$(!`J!((`
M+`0`""T$```M!```+00``"T$`(`N!```+@0``"X$```N!`!@,`0(0#($```R
M!```,@0``#($0`$T!```-`0@`#4$``0V!```-@00`#<$(``X!```.`0``#@$
M```X!``$.00``#D$```Y!```.00``#D$0@(\!```/`0``#P$`(`]!```/00`
M`#T$```]!```/00``#T$!AA!!"``0@0`($,$``!#!```0P0``$,$`@!$!```
M1`0$`48$$"!(!`$`200``$D$`(!*!$``2P0!`$P$`!!-!`(`3@0``$X$``!.
M!```3@0``$X$``1/!```3P2`!%$$``!1!```400``%$$``!1!`"`4@0``%($
M``!2!```4@0`0%,$"`!4!```5`3``%8$``17!```5P0`0%@$`!1:!`0`6P0`
M`%L$``!;!```6P0`(%P$@`!=!(`A8`0``&`$$`!A!$``8@0((&0$``!D!```
M9`0!`&4$`(!F!```9@1``&<$``!G!`@`:`0$`&D$``!I!```:00``&D$`D!K
M!```:P0``&L$``!K!```:P00`&P$``!L!```;`0`!&T$``!M!```;00!`&X$
M$`!O!```;P0``&\$(`!P!```<`0``'`$`(!Q!```<00``'$$00%T!```=`0(
M`'4$$`!V!```=@0``'8$``!V!(``=P0``'<$I`!Z!```>@0``'H$`$![!```
M>P0``GP$@`!]!```?00``'T$``!]!```?00``'T$``)^!```?@0``7\$``!_
M!```?P0``'\$"`"`!```@`0``(`$(`"!!```@00``($$``"!!`"!@P0``(,$
M"`"$!```A`0``(0$``"$!```A`00@(8$``"&!```A@1`0(@$"`")!(!`BP0`
M`(L$``"+!```BP0``(L$``"+!!``C`0``(P$0`"-!$`@CP0``(\$``"/!`0`
MD`0``)`$``B1!```D00(`)($``"2!```D@0``)($``"2!```D@0`0),$`0"4
M!``!E02`$)<$!`"8!```F`0``)@$"`B:!```F@1`!)P$``"<!`(`G00``)T$
M"$"?!```GP00`*`$``"@!```H`0`(:($``"B!"``HP0``*,$"`"D!```I`0`
M`*0$``"D!```I`0`(*4$``"E!``!I@0``*8$``"F!"`$J`0``*@$`("I!```
MJ00``*D$``"I!`(`J@0``*H$(`"K!```JP0``*L$``"K!`*`K00``*T$`!"N
M!```K@0``*X$``"N!```K@0``*X$$`"O!```KP0``*\$``"O!```KP0`(+`$
M``"P!$``L00``+$$``"Q!!!`LP0``+,$``"S!```LP0``+,$``"S!```LP0@
M`+0$``"T!```M`0``+0$`0"U!```M00``+4$@`"V!``$MP00`+@$``"X!``"
MN00``+D$``"Y!```N00``+D$`!"Z!```N@0``+H$``"Z!``(NP0$!+T$!`"^
M!``!OP0``+\$``"_!(``P`0!`,$$``#!!!``P@0"`,,$``##!```PP2``,0$
M``#$!```Q`0``,0$``#$!```Q`0``,0$@`#%!(_OT03W0]L$0O_E!$>;[@2M
MZ?@$XN<"!00"!`4*0`<%97\2!3;['05W>2@%21XO!=_M/`7QYT<%.FA.!>>H
M5P4+[F`%0S1F!0"`9P71=7`%R.-X!?O_AP41EHT%Z?V9!6RMH@76+:L%`^BQ
M!63`M@4\SK\%EZW)!7O`T05L1=@%9^KB!5_7[@7^?_P%0`K_!<_#"0;I%!`&
M:!05!G4A'`8A(2`&?A<J!@@T+@:^3#<&M/9!!G-&20;J8E$&+`I6!E\+7P;T
MS6D&`@1K!J2<<@;[?X`&M12'!B5_D0;J&9D&;;ZD!N\CK@9]/[H&_S#$!G@^
MS09`>-(&QV;;!GMGY@;?3?$&_B#Y!K!&_P;)#P<'F+X0!_!8%P<ZEA\'OZ`H
M!YPC+P<>B38'6;Y`!S)>2`>J-U$'Y^M=!]T`8P>MSVX'YZUY!^$V@0<;A(<'
M*L^0!^\GFP>>5:0'R]*M![NMN`<4`+H'2*7`!W%CR`?=",\'#7_9!_".X0<^
M_^X'_P7X!QK_`P@'J`D(T7L3"$![&@A-9R,((H`F"$0=+`C[N#<(4?U!"&40
M1@AW^U,(C/5<"-\#90@``68(9O-P"`ZD=@C3PGX(40"!"`#(A`@J4XL(\Y24
M",EPFP@;`)\(`'BC"-]/KP@"][<(@'^_"$&`P@BP4L@(%K3/"!P"TPB`8M<(
MP$/<"-$)X@@`@^4(UZGO"(52]0@!2/@(4;T!"58%!PG!E0X),&84"25S'`E<
M$"$)+V<K"8K-,PD)03<)S:9`"1FO20ELD5`)RJ-8"9D)7@GE]&@)`P!J"5*'
M<0FYF'D)!`M]"0AT@@D=%8D)"0&,"<G9E0G<T)T)62"B"?&_K@EU#K8)(&*Z
M"9.$P`DW)L@)`Q[."99'U@F6"MP))5+B"2BNZ0F9\/$)`$_V"0I/_0FJ=`4*
MOM<1"C7:&@J?/B4*9+XN"G$?-PJT?D$*AF%'"M##3@JSK5@*I7=B"G@Q:0H>
M+'`*3*IW"CA1?0H$6H(*2"N("A]VD@KX39L*0(B>"@HRHPJ*E:H*J:*Q"F`0
MM`I#`K@*(`2Z"N0TP0J`Q,4*$`C'"@3<S0J%`-`**O38"A8:W@K!%.,*:T+J
M"B$,[@H!&_,*P`+V"B0T^PI50``+*Q`%"_>]$@MXBQH+*[4C"[N[+POHOSH+
M?%!!"WF#20O]4E,+7>E="_9;:`MKY7(+_N^`"TY$A@L=*XX+`_^8"V/MH@LK
MP*@+O].T"T,6N@L`E;X+$X#""\\_S@OJ7=@+H`K<"P4"WPL#I^8+42SL"\!H
M\0OSK_T+U0H$#`("!@S$7`T,#1`1#`*V%PQ)`!H,EADA#)4B)PR54"T,E3<V
M#``Z.@S.:4,,_TM/#+YH6`Q-&%X,=J]I#"#H;@S)874,N5)]#/#!A`P>>(P,
M?/^9#)J$GPS@%*0,X3RL#.##LPQ.C[P,3:[%#`\3S`S;_]H,G__H#/OY]0SH
MHOP,\G$%#:-5#0W:,Q8-WCXA#8_R*PV_GS@-CU-!#9?G3`VX,U0-N#I<#=QS
M9@T7RFX-*[EW#0#@>@WU.X4-]X^1#2H$E0W./)X-)8:D#3V_L`VA@+0-&CZ\
M#?3LQ@W)!\T-?W'8#>`)W0TZO^@-BT'N#?\/^@U+XP,.+=X-#H(9$@Z1]!H.
MUGTE#BBG+`ZMR34.^U`^#H1D0P[?!TT.L'M6#D167`[(/V4.(:!I#D@`:P[T
M]78.`7=]#G?LB`Y.QI`.'<F8#LM[HPYN3:P.&^&T#DK:O`X]!L,._EO/#D`8
MT@XB.M@.]+?C#O\[\`X#\/8.ZO#_#HXW"`\#@PT/@(D1#R3^&@\:\B(/H1(G
M#Z!;+@_$'#0/&=,\#U2+0P^O'TX/-&A4#UF"6@]U'&(/*WIK#_0$<0]`HG4/
MV5!\#V2SA`]01(@/!$"*#P(MCP^!HI0/2">:#X@!G0\NY*4/,&JK#P7:L@^V
M?+P/M07##_^0S0_6[-</,8#;#U!QX0\<GND/],OS#S"A^`_R8P$0S!@'$+4%
M#A"^5QD0@[HA$+*X*1"ELS(0?IH\$)0*01#G,TL0!AY1$-W771`XT&,0MZUN
M$'N4=Q`^VX(0ANZ+$/[_FA#9#:(0FV.K$,<CLQ!%:+D0-MO#$-(#R1!`/L\0
M01/4$+W_XA`KJ^L0_.KV$,!]_A#:I0<1PO,0$5OR&A%_I"01_]@P$:(:-A&M
M/4`11X)&$=T+3Q%;Q5@1GV]D$932:Q&[VG81'@!Z$<GA@A$&/HD1'GN3$7]S
MGQ&_NJL1B$BO$?34N!$NH+X1V;_*$>VMU1%_'N`1>+_K$?6']1&[\0`2AQX(
M$KO]%1($'AH2;@4A$G&J*1)$!BT2N'8V$A__0Q*\]T\2!T14$G897!+A8&(2
ME]QL$HO\=A)+8WX2C.^($GSJDA(DG)@2ONZD$@Y.JQ)][[@2\$O`$D6+QQ)6
M",P2#,72$AEJV1*3\.$2+USJ$@@I[A).`/(2&_S\$I`5`1,.+`<3,(P,$\?H
M%1.+D!L3I&<C$\A6*A-9BS(3_Y8^$[B/1Q-?+E$38$E6$Q#N71.^_&D3X>MS
M$]R-?!/`V((3"H"%$R3%BQ.;")$3&`"3$_C%G!,'8*$3H?ZK$X4EL1-=9+D3
M?C/#$_T?SQ,&;-43"O_?$W86YQ/Y/O(3+___$PL(`Q017`D4A,H/%/#.&!1^
M^R44,@`H%`!?+A1Y5C<4D0,\%*=W1Q0Z&T\4`-Q4%#216A3UV6449^]Q%%)?
M>A3J'H,4H`^)%*CNDA3_^J`45%6G%!C_L13:V;L4B,C`%$3`Q!0%D,@42;'/
M%*2,U136I-T4OE[H%#IB[Q0`F/(4E,OZ%$:6`14[!0@5+9P0%6[1&14B`!L5
MEM\F%5?A+Q41=3855W$_%=.!1A6[A$X5:E)5%<\'7A4PS645$]IM%6M6=A7C
MCG\5(NV'%<@1C!4%5I(5B%R8%1)AG14XVJ4587&L%6)&LA6D@K<5$/B]%8H/
MQ!4`C<@5&K/0%1`0TA4"(M45V)/=%1!6XA5#R.@50Q#L%<!6\A5O4OL5]5,%
M%@`@!A:QA0T6=(H4%@71&A8*1A\6&DLF%KV2+Q;A<#86(-H\%L$@0!8A"$,6
M`#U(%G7_51;%&5P6[*MF%H[";184XW06AV!Z%D0(?1:%\(061T**%E]0DA:%
M"I<6!S*=%H@_I1:`!*<6Q+NP%J#?N1;:XL(6,,#&%H4`R19(W=$6IQW:%K(.
MX19PT>@690OO%JR:]Q8E[P$70$($%ZMF#1<"1Q(7Z@89%P@,'!=TW287?X8P
M%]LH.!>L_D,7':Y,%TM`41?J"UD7A=-A%^\/;!<AKG,7`(=W%U!5?1?-RH87
MQX6.%SIPE1>JU9X7>9VH%X]]LQ=1_[X7%S['%_6^TQ??Y^`7QM[J%Q8D[Q<L
M"/,7K_/_%^WD"1@\ZQ,8G5(;&!_6)1B/JR\8:-LX&+<A0!@Y&$88SAM/&&01
M5!BV]V`81WUJ&-M)<QAI?GT8P\6%&-&'C1AL=Y<8U-B?&/I5J1@66;`8DA^X
M&(#.OAAQ(L08\!7+&,%@T!@`G=48;PW>&`3VY1@!2.@8$L3M&#4V]1A)NOT8
M@"#_&(#<!1G]]A(9&1@7&60R'1DT`B$9XS`H&12$+!FHP#$9`B`S&1#=.AD4
M$#T9PG1$&;KD31F8IE09(5Q:&6)=8ADS!&<9TY%O&91N=QF#0'L9!QJ!&6!<
MAQD37(X9XP>6&>G]HAFE(:@9A(:M&3/DM1EP*;L9PD;!&1OOS!F'/]89=L'>
M&=HZYQD!".D9"6WP&;+?^QD!8/X9AOL(&LWR$AK!LAD:CRXB&G&G*QH^!3(:
M[8$Z&@G601I)WDH:N/U5&BZV7AKOK6H:4:=R&M2->AH&2X`:X?6*&FHJD1KB
M^YP:=R"C&O'RK1H_AK8:P*B[&K?_R1H"I,T:,A'2&O.>W1K0)N,:<2;J&LD`
M[AJ+Z/8:GL#]&LL,!!O*X0P;*;03&]/#'!LS\B4;*4(J&PZJ,1NUB3D;]VE$
M&\[R3ALU958;Y/-@&\6(9AMT36X;_2]Z&[U_AQL/V(\;+^:9&__9IAM)7JX;
M3D6U&V^FOQM(F\8;B+[.&\W\V1OW[>8;A9SM&^9W^!M;DP$<%@H&'#(/#1RG
MZ!8<SUD@'*9N*1SJ+#$<=&8Y',(F/QPI^D@<S/=3'%\=71P``%T<``!='```
M71P``%T<``!='$!=8QRX\&L<-X%R')MO?1RE8X4<[%6.'--TEQP8XYX<1*.D
M'&K4K!PTB+$<:]J['`T>PAQ_7<X<]Q/8'%(1W1SIN.8<2`3I'$3%[QQ&@?0<
M_^H!'?`:"!U(/Q`=MK8:'18%'QUX5"8=X&\O'7.`-1TZ.3T=Y"=%'4!-2AV8
MDE`=*F)6'4!,6AT[@&`=X6MI'1.'<!T_A7D=*#5_'1D#A!TM[8X=3Z>8'<J/
MH1VY-:H=&/RR';9WO1W%V\<=!E[.'?P3UQWABMX=@+?E'5W-[QW6X_D="&S^
M'0RB`Q[Z^Q`>GO\='F``'QZ^VBH>[@DR'IIN.Q[_4T<>P#E-'@RI4QYW%UT>
MN89E'K<!;!X,`&X>J+AU'N!F?!Y\[8<>A0^.'B*@DAZCUIL>6[&D'B..JQZ7
M*K,>VOR^'JH`PAX%%L<>(C/-'D#'TQZ&GML>;OKF'NL7\!XV"/4>D=+\'D*@
M`!\4WPD?5^X4'TL6&Q^`U"`?$[0G'T$0*A^ZS30?>K@]'S1@0A\+STL?JD=3
M'QZG7!^`[&(?TY5K'YNZ=1]4_X`?@1:%'X+NC1\ALY0?<B:;'\#.HA_U#*H?
MST6S'Y:BNA\!D[\?`V##'_G<SA^$F-,?H@[9'X`^WQ\J,>4?&(_L'TL!\1_:
M:OH?LLH"(%CR"B``?Q$@[6\=(`^7)B`J`BH@DLPQ(`E:-R"J@SX@>45&(%:1
M32"$*U,@"(!5((6X7"`H;&(@TTAI($6`;2!IO'8@Y$I](&KLAB![@(T@CD&3
M($8:F2!5-*`@C.NI(!Z+L2"EX+@@!BF](,1#PR`53,D@L_#2(#_$VR`^N^8@
M`@'H(#]S\R"6%/D@#7<"(:`,!B'%"PTA/S(6(4#`&2%5I"`AE,`E(<N/+R'9
MA3<API8^(8VD12$!`$8A5#5-(>@(4B%:H5DA#55@(?^I;"$N)'(A^EQ\(>)A
M@R$W:8PA3WJ6(2\2G2&T,J0A*T6K(?MQMB&%TKTAE+C$(<7<S2'7:-8AVE7?
M(;=TZ2'1OO,A0SGZ(0A"_2%*T@0B4M\.(D":$R+7H!LB"UPB(GUV+2(``"TB
M```M(@``+2(``"TB```M(H"F,B+BUSPBL01!(@8_22((%TXB)'95(AQK72*7
M_VHBW;EU(I]E?R)J7H@B7R20(A-]F2*P[Z,B70BI(@``J2(``*DB``"I(@``
MJ2+0.*\BFP"T(C($N"(@`KHB2(&^(@A$P2)$V<@BPJ[0(@J=UR(HL-PB0)?B
M(E'@Z"*/!.XB<2+T(I0?_"(Q@@$C';`((U48#B.R+!4C&D,;(P+<(2-K2"@C
M83TP(Q:(-2,,"#@C`'\_(RD71B.\^E$C0*Y7(TC+7B-U=F@CD)%M(QX`<2,`
M`'$C``!Q(P#8=2/8X7TC]YR((W9DD",Z!)4C=>^A([,OJR-O^;<C^^;#(X]@
MRB/F4],CON[?(W]SZR,KX_0CY+7]([^7"22C"@\D3H46)&M!'22Z124D@/@K
M)!:I,B3TX#HD50`^)'131B2,H$LDER93),!_7"34"V,D/A9K)+P#<B2L:GHD
MA5!_)!3=AR1Z%8\DV_N<),.]IB3Z<*\D8IBU)()DNB3S0,$D`!+#))B7RR2]
MS]<DPT[?)/<!YR0"\>TD*2/S).J?_B2`*`$EA((%)478#"6-`A$EL288)8R?
M(254H"8E(^<O)>_;/"4D#$`ED"]')=(<3B4Q7%4E*U!;)0"97R703&4EBG!K
M)0$&;B7*`7,EP_%\);8!@B4B*(8EF(*+)=D'DR4"")4E?`V=)3($H24.3*<E
M#:RN):?PMR4"`+@E``"X)0``N"4``+@E``"X)0``N"4``+@E@`.[)<W^QR5:
M@\XE_3O:)51ZXB6(/>DE>57R)28`]24``/4E``#U)0`P]R4"U?TE')@#)A>X
M"R8!^1(F?A0:)NTE(R9T[2TFL#\V)KF'/R;?/TPF\WI7)F9_8B8,CVDFQ0IO
M)M'E>"9:4G\FF`2#)DUKC";6XY8FY%Z?)E=OJB8:%K`F<JBW)F%5OB9-:<8F
M'D3,)DH;TR8:6]LF`F#>)GZ(YB9^]?(FWT7\)CHX`R>=.0PGP/@3)_Q/'B?@
MF"0G&P`H)P``*"<``"@G`*TM)\.=-B?<"3TG`)A`)Z_N3"<?<%0G*!=:)]U]
M9B<346PG#GQT)V=Z?B>GD88G`0"')P``AR<``(<GP$.,)VAQDR<8LIDG>@.@
M)S?KJR<$8*XG!YNV)R[$O2=.!L,G$6G))\-!SR<]=-@GI(W?)S0.Y2<``.4G
M``#E)P``Y2<`H>@GP1/N)UO`]2=_T0`H;>X+*)(*$"A,$14H194<**WO*"@.
M."XH/N@W*!)%/"AHF$(H_`))*!C$3BC.P%4HP7U>*!9#9"C#QFPH5BES*+[-
M?BBO)8<H43>/*'TOFBB^YJ4HQTZN*.*'MBB=O<$HJ6[**.4%T2@``-$H``#1
M*.`:URA=`-PHS$OD**;I[2A('?,H!,CW*-X%_R@'\@<I'YH0*<U4&"F0IAXI
M0`8A*1*:)RDTOS$IWX(Z*<B&0"G)H$8I%"=,*80D4"D@?E<I``!7*0``5RD`
M`%<I``!7*0``5RD@NUXI(QED*:[H;2EPMW8I,/^`*1CPABD7^Y$IH<&7*="Z
MGRF,0:0IJ0*I*0.0K2F`;K,I8LRZ*;RAPBG/-LPIY0#1*0`@TBFQ,-@I!0#:
M*0``VBD``-HI`"#;*0`#W2E``-XI``#>*0``WBD``-XI`0#?*0``WRD!$.$I
M``#A*0``X2D`@.(I>X[L*5<`\2G__P$J__\1*O__(2K_!RPJ```L*F``+BH`
M`"XJ```N*@``+BK^_STJ__]-*O__72K__VTJ__]]*O__C2H!`(XJ``".*@``
MCBH``(XJ*`"0*@``D"H`")$J``"1*@``D2H``)$J``*2*@``DBH4`)0J``"4
M*@``E"H``)0J!`"5*@``E2H``)4J"`"6*@``EBH``)8J``"6*@``EBH`")<J
M``"7*@``ERH``)<J``"7*@(`F"H"`)DJ``"9*@``F2H``)DJ``"9*@``F2H`
M`)DJ``*:*@`$FRH``)LJ``";*@``FRH``IPJ``"<*@``G"H``)PJ``"<*D``
MG2H``)TJ``"=*@``G2H``)TJ``&>*@``GBH`@)\J``"?*@``GRH``)\J@`"@
M*@``H"H``*`J``2A*@``H2H``*$J``"A*@`"HBH``*(J``"B*@``HBH`$*,J
M``"C*@`@I"H``*0J``"D*@``I"H(`*4J``"E*@``I2H``*4J`""F*@``IBH`
M`*8J(`"G*@``IRH``*<J``"G*@``IRH``*<J`@"H*@``J"H``*@J``"H*A`@
MJBH``*HJ``"J*B``JRH``*LJ``"K*@``JRH`@*PJ``"L*@``K"H"`*TJ``"M
M*@``K2H`(*XJ``"N*B``KRH``*\J$`BQ*@``L2J``+(J$`"S*@`@M"H``+0J
M``BU*@``M2I``+8J$`"W*@``MRH``+<J``"W*A``N"H``+@J``"X*@``N"H`
M`+@J``"X*@!@NBH``+HJ``"Z*H``NRH``+LJ``"[*H``O"H``+PJ``"\*@``
MO"H``+PJ``"\*@``O"H0`+TJ0`"^*@``OBH``+XJ``"^*@0`ORH``+\J``"_
M*@``ORH``+\J``"_*@``ORH`(,`J"`#!*@``P2H``,$J``#!*@``P2I``,(J
M``#"*@``PBH``,(J``#"*@`@PRH``,,J(`#$*@``Q"H$`,4J``'&*@``QBH$
M$,@J`@#)*H``RBH``,HJ``#**@$`RRH``,LJ``#+*@``RRH``,LJ&`#-*@``
MS2H`0,XJ``#.*@``SBH``,XJ``#.*@``SBI``,\J``#/*@``SRH``,\J``30
M*@``T"H``-`J``#0*@`(T2H``-$J``'2*@``TBH``-(J``#2*@!`TRH``-,J
M``#3*@``TRH``-,J`"#4*@``U"H``-0J``#4*@``U"H(`-4J``#5*@`(UBH`
M`-8J``#6*@``UBH``-8J``C7*@``URH`@-@J``#8*@``V"H``-@J``#8*@``
MV"H``-@J``'9*D"`VRH!`-PJ``#<*@``W"H``-PJ``#<*D``W2H``-TJ``#=
M*@`@WBH0`-\J``#?*@``WRH``-\J`@#@*@``X"H``.`J``#@*@``X"I``.$J
M&`#C*@``XRH``.,J(`#D*@``Y"H``.0J``#D*@0`Y2H``.4J+83K*A``["H`
M`.PJ``SN*@(`[RH@`/`J``#P*@``\"H``/`J$`#Q*@``\2H``/$J``3R*@``
M\BH``/(J``#R*A``\RH``/,J``#S*A``]"H``/0J``#T*@``]"H``/0J``#T
M*@``]"H`!_<J@`#X*@``^"H``/@J``#X*@`0^2H`$/HJ``#Z*@"`^RH``/LJ
M``#[*A@`_2H``/TJ``#]*@``_2J``/XJ`(#_*@``_RH``/\J$```*P`@`2L`
M``$K``$"*P```BL```(K```"*P```BL```(K`(`#*P```RL```,K```#*P!`
M!"L!0`8K```&*P``!BL```8K`0`'*P``!RL```<K```'*P``!RL(``@K```(
M*P`&"BL```HK```**P``"BL`0`LK```+*T``#"L```PK```,*P@`#2L```TK
M```-*P``#2M```XK```.*P``#BL`0`\K```/*P``#RL```\K`!`0*P``$"L`
M`!`K``(1*P``$2L``!$K```1*R``$BL``!(K```2*P``$BL``!(K`@`3*P``
M$RM``!0K```4*P``%"L`(!4K```5*P``%2L``!4K```5*T``%BL`@!<K```7
M*P``%RM``!@K```8*P``&"L``!@K$``9*P``&2L``!DK`$`:*P``&BL``!HK
M@``;*P``&RL``!LK``0<*P``'"L`"!TK```=*P``'2L``!TK``0>*R``'RL`
M`!\K```?*P``'RL``!\K!``@*P``("L``"`K```@*P`"(2L``"$K`"`B*P``
M(BL@`",K```C*P``(RL`0"0K```D*P``)"L`$"4K```E*P``)2L``"4K```E
M*P``)2L`0"8K```F*P!`)RL``"<K```G*P``)RL``"<K``(H*P``*"L``"@K
M`$`I*P``*2L``"DK```I*P``*2L``"DK@``J*P``*BL``"HK```J*P``*BL"
M`"LK```K*P``*RL``BPK$``M*Q``+BL0`"\K```O*P``+RL``"\K```O*Q@`
M,2L"`#(K```R*P``,BL``#(K!``S*P`(-"L``#0K$``U*P``-2L``#4K```U
M*P(`-BL``#8K```V*P``-BL`0#<K```W*P``-RM``#@K)``Z*P``.BL$`#LK
M``$\*P`!/2L``#TK```]*P``/2L(`#XK```^*P``/BL`$#\K```_*P``/RL`
M`#\K$`!`*P$`02L`"$(K`!!#*X``1"L``$0K``!$*P``1"L``$0K`0!%*P``
M12L``$4K``!%*P`@1BL``$8K``!&*P``1BL``$8K`0!'*T``2"L``$@K``!(
M*P``2"L`$$DK``!)*P``22L``$DK!`!**P``2BL``$HK``!**P``2BL``$HK
M``!**P!`2RL``$LK``!+*P``2RL!`$PK``!,*P`@32L``$TK``!-*P``32L`
M($XK``1/*P``3RL``$\K`@!0*P"`42L``%$K``!1*P`@4BL``%(K``!2*P``
M4BL`0%,K``!3*P``4RL``%,K``%4*P``5"L``%0K`!!5*P``52L``%4K@`!6
M*P``5BL``%8K``!6*P"`5RL``%<K``!7*P`"6"L``%@K``!8*P``6"L``%@K
M"`!9*P``62L`(%HK``!:*P``6BL!`%LK``!;*R``7"L``%PK``!<*Q``72L`
M`%TK``!=*P``72L``%TK``!=*\`!8"L``&`K``!@*P``8"L0`&$K`"!B*P``
M8BL``&(K``)C*P``8RL`#&4K``!E*P!`9BL``&8K`0!G*P``9RL``&<K``)H
M*P``:"L``&@K``!H*P``:"LP`&HK``!J*P(`:RL0`&PK"`!M*P``;2L``&TK
M`$!N*P``;BL(`&\K``!O*P``;RL$`'`K``!P*P``<"L@`'$K``!Q*P``<2L`
M`'$K$`!R*P``<BL``'(K``!R*P``<BL``'(K``!R*PA`="N``'4K``!U*P``
M=2L``'4K``!U*P``=2L``'4K``%V*P``=BL``'8K`0!W*P``=RL``'<K`0!X
M*P``>"L``'@K``!X*P``>"L``'@K@`!Y*P`$>BL``'HK``!Z*P`(>RL``'LK
M``![*P``>RN``'PK!`!]*P``?2L``'TK``!]*P``?2L``'TK``!]*P@`?BL`
M('\K``!_*P``?RL``'\K`!"`*P``@"L``(`K``"`*P``@"L@`($K``"!*P``
M@2L``($K``"!*P`(@BL``((K``.$*P``A"L``(0K``"$*P``A"N``(4K``"%
M*P`$ABM``H@K``"(*P`(B2L``(DK@`&+*P``BRL``(LK``R-*P``C2L`0(XK
M``*/*P``CRL(`)`K``"0*P``D"L"`)$K``"1*P`"DBL``)(K``"2*P`@DRL`
M()0K$`"5*P``E2L"`)8K``"6*P"`ERL``)<K``"7*P$`F"L``)@K``"8*P``
MF"L``)@K``"8*P(`F2L``)DK``"9*P``F2L`")HK``":*P"`FRL``)LK0`"<
M*P`"G2L``)TK``"=*P``G2L``)TK``"=*P`(GBL``)XK``">*P``GBL``)XK
M!`"?*P``GRL``)\K``"?*P`!H"L``*`K``"@*P$`H2L"`*(K``"B*P$`HRL`
M`*,K``"C*P"`I"L``*0K``"D*P``I"L``*0K``"D*P``I"L`@*4K``"E*P``
MI2L``*4K`0"F*P``IBL``J<K``"G*P``IRL``*<K`0"H*P``J"L``*@K0`"I
M*P``J2L``*DK``"I*P``J2L``*DK``"I*P0`JBL``*HK``BK*P``JRL``*LK
M``"K*R``K"L``*PK`""M*P`"KBL``*XK``"N*P``KBL`!*\K``"O*P``KRL`
M`*\K$`"P*P`(L2L``K(K``"R*P!`LRL``+,K``"S*P``LRL``+,K``2T*P"`
MM2L``+4K!`"V*P``MBL``+8K``"V*P``MBL``+8K``"V*P`"MRL``+<K`0"X
M*P``N"L``+@K`!"Y*P``N2L``+DK``"Y*P``N2L``+DK``"Y*X``NBL``+HK
M``"Z*P``NBL"`+LK!`"\*P`$O2L``+TK``"]*P``O2L``+TK``"]*P0`____
M_P```0`"``,`!``%`/__!@`'``@`"0`*``L`#``-``X`________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________#P#__________Q``_____Q$`$@`3`/__%``5`!8`%P`8
M`!D`&@`;`!P`__\=`!X`'P`@`/__(0`B`",`)``E`"8`)P#_____*``I`/__
M_____________RH`_____RL`____________________________________
M____________________________+``M`"X`+P#_______\P`#$`,@`S`#0`
M-0`V`#<`.``Y`#H`.P`\`#T`/@`_`$``00!"`$,`1`#__T4`1@!'`$@`20#_
M_TH`2P!,`/_______TT`__].`$\`4`!1`%(`4P#_____5`!5`%8`5P!8`%D`
M6@!;`/____]<`%T`7@!?`&``80#__V(`8P!D`&4`9@!G`/__:`!I`&H`__]K
M`&P`;0!N`&\`<`!Q`'(`<P!T`'4`=@#__W<`>`#__WD`>@![`'P`________
M?0!^`'\`__^``/__@0#_____@@"#`/____^$`(4`A@#_____AP"(`(D`B@"+
M`(P`C0".`(\`D`"1`)(`DP"4`)4`E@"7`)@`F0":`)L`G`"=`)X`GP"@`*$`
MH@"C`*0`I0"F`*<`J`"I`*H`JP"L`*T`K@"O`+``L0"R`+,`M`"U`+8`MP"X
M`+D`N@"[`+P`O0"^`+\`P`#!`,(`PP#$`,4`Q@#'`,@`R0#*`,L`S`#-`,X`
MSP#0`-$`T@#3`-0`U0#6`-<`V`#9`-H`VP#<`-T`W@#?`.``X0#B`.,`Y`#E
M`.8`YP#H`.D`Z@#K`.P`[0#N`.\`\`#Q`/(`\P#T`/4`]@#W`/@`^0#Z`/L`
M_`#]`/X`_P```0$!`@$#`00!!0$&`0<!"`$)`0H!"P$,`0T!#@$/`1`!$0$2
M`1,!%`$5`18!%P$8`1D!&@$;`1P!'0$>`1\!(`$A`2(!(P$D`24!)@$G`2@!
M*0$J`2L!+`$M`2X!+P$P`3$!,@$S`30!-0$V`3<!.`$Y`3H!.P$\`3T!/@$_
M`4`!00%"`4,!1`%%`48!1P%(`4D!__]*`4L!3`%-`4X!3P%0`5$!4@%3`50!
M50%6`5<!6`%9`5H!6P%<`5T!7@%?`6`!80%B`6,!9`%E`68!9P%H`6D!:@%K
M`6P!;0%N`6\!<`%Q`7(!<P%T`74!=@%W`7@!>0%Z`7L!?`'__WT!?@%_`8`!
M@0&"`8,!A`&%`88!AP&(`8D!B@&+`8P!C0&.`8\!D`&1`9(!DP&4`94!E@&7
M`9@!F0&:`9L!G`&=`9X!GP'_____H`&A`:(!HP&D`:4!I@&G`:@!J0&J`:L!
MK`&M`:X!KP&P`;$!L@&S`;0!M0&V`;<!N`&Y`;H!NP&\`?__O0&^`;\!P`'!
M`<(!PP'$`<4!Q@''`<@!________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________R0'*`?__RP',`<T!________________________________
M________S@'_____SP'0`?__T0'_________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________________________](!
M___3`?_______]0!___5`?_______]8!UP'8`=D!___:`?_____;`?_____<
M`=T!___________>`?_____?`?__X`'_____X0'B`?__________XP'D`?__
M___________________E`?__Y@'__^<!Z`'_____Z0'_________________
M_________^H!ZP'__^P![0'N`?__[P'___`!______________$!___R`?,!
M___T`?4!___________V`?__________]P'________________________X
M`?_____Y`?H!^P'\`?T!_________@'_`?__``+_____________`0+_____
M`@+_______\#`O__!`+_______________________________\%`O______
M______\&`@<"________"`+_______\)`O____\*`@L"__\,`O__________
M_____PT"_____________________________________PX"#P+_________
M____$`+__Q$"__\2`O__$P+__Q0"%0(6`A<"&`+_____&0(:`O__&P(<`O__
M_____________________QT"________________'@+__Q\"(`(A`O__(@+_
M____________(P+__________R0"__\E`O____\F`O_______________R<"
M________________________*`+__RD"__________\J`O____\K`O______
M_________RP"________+0+_____+@+_______\O`O_______S`",0(R`O__
M_____________S,"_____S0"__\U`C8"-P(X`O_______________SD"__\Z
M`CL"/`+__ST"________________/@(_`O____________________]``O__
M_____T$"_____T("_____T,"__________]$`O__10)&`O__1P)(`DD"__]*
M`DL"3`+__TT"_____________TX"3P+_____4`+_____40+_____________
M________4@)3`O__5`+_______________]5`O__5@+__U<"6`)9`EH"6P+_
M_________UP"70+__UX"_____________U\"__________]@`F$"________
M8@)C`O__________________________9`)E`F8"________________9P+_
M_V@"__]I`FH"_____________________VL"________;`+_______]M`FX"
M_____V\"________<`+__W$"_____________W("________<P+_________
M______]T`G4"=@+_______]W`G@">0+_______]Z`O__>P+_______]\`O__
M_____________________WT"?@+__W\"@`*!`H("________@P+_________
M_X0"A0+__X8"AP+__X@"B0**`O____^+`O__________________________
MC`+__________________XT"__________^.`O__CP+__Y`"D0*2`O______
M______^3`O____________^4`O__________________________________
ME0*6`I<"F`*9`O_______YH"FP+__YP"G0+_____G@+_________________
M_Y\"__^@`O_______________Z$"H@+__Z,"`````````````$LPFC!-,)HP
M3S":,%$PFC!3,)HPJS":,*TPFC"O,)HPL3":,+,PFC"[,)HPQ#":,,@PFC#W
M,9HPY@```U0"``-4`@$#C`(``XP"`0-9`@`#60(!`UH"``-:`@$#Z0+E`N4"
MZ0(````````````````````````````````````````````!`````@````,`
M```$````'@```!\````@````(0```"(````C````)````"4````F````)P``
M`"D````P````,0```#(````S````-````#4````V````-P```#@````Y````
M.@```#L````\````/0```#X````_````0````$$```!"````0P```$0```!%
M````1@```$<```!(````20```$H```!+````3````$T```!.````3P```%``
M``!1````4@```%,```!4````50```%8```!7````6````%D```!:````6P``
M`%P```!=````7@```%\```!@````80```&(```!C````9````&4```!F````
M9P```&@```!I````:@```&L```!L````;0```&X```!O````<````'$```!R
M````<P```'0```!U````=@```'<```!X````>0```'H```![````?````'T`
M``!^````?P```(````"!````@@```(,```"$````A0```(8```"'````B```
M`(D```"*````BP```(P```"-````C@```(\```"0````D0```)(```"3````
ME````)4```"6````EP```)@```"9````F@```)L```"<````G0```)X```"?
M````^0```/H```#^````_P`````"`(`!`@```P(```0"```%`@``!@(```<"
M```(`@``"0(`@`H"```-`@``#@(```\"```2`@``$P(``!0"```5`@``%@(`
M`!<"```8`@``&0(``!P"```=`@``'@(``!\"```A`@``(@(``","```F`@``
M*`(``"D"```J`@``*P(``"P"```M`@``,0(``#,"```T`@``-0(``#8"```W
M`@``.`(``#H"```\`@``/0(``#\"``!``@``00(``$,"``!&`@``1P(``$@"
M``!*`@``2P(``$P"``!-`@``3@(``%`"``!1`@``4@(``%0"``!5`@``5P(`
M`%D"``!:`@"`6P(``%T"``!>`@``7P(``&`"``!B`@``8P(``&0"``!F`@``
M9P(``&@"``!I`@``:@(``&P"``!N`@``;P(`@'`"`(!S`@``=@(``'<"``!Y
M`@``>@(``'L"``!\`@"`?0(``'\"``"``@``@@(`@(,"``"%`@``A@(``(D"
M``"*`@``BP(``(T"``".`@``CP(``)("``"4`@``E0(``)8"``"7`@``F`(`
M`)H"``"=`@``G@(``)\"``"@`@``H0(`@*,"``"E`@``I@(`````````````
M```````````````````````````0`1`"$`R##H/[$!J#&X,?@P&#FQ"<$+0`
M0(.H`#Z#XX,_@_T0_A"=$)X0`Q#=+@40!A`'$/P0%0<0!P^#/(,<$!8'7(,F
M!R4'&`<9!QP''0<(@PF#%!`5$#N#/8-;@UV#"!`)$`H0"Q`,$`T0#A`/$!`0
M$1`+@Q()L0#7`/<`'8-@"1R#'H-F"6<)'@DT"4(-0`VP`#(',P<#".6#!(.B
M`*,`!8,#@P:#"H,@@Z<`!@T%#<L,SPS.#,<,Q@RA#*`,LPRR#+T,O`P[!Q(0
MD@B0")$(DP@3$`>#`H,-@UZ#,Q`T$#40.Q`\$/\0GQ`("0L)A@F'"8()@PDJ
M"2D)A`F%"8H)BPD)"04)!0H&"B<)*`FL`-((U`@`"0,)E0F6"9<))0DF"5^#
M8(,8$!D0%A`7$"`)I0D2"@()!PEA"5():@EK"1H)/0D="34)*PDL"6()0PE%
M"4@)=@EW"90(*P@P!V\-;0UJ#2`'(0>V`&X-:PUL#6D-[PRW#+8,P0S`#)<(
MF`B6")D(Q`CH".8(YPCI"#0/-0\0@Q&#$H,3@Q2#%8,6@Q>#&(,9@YD)R0P]
M$$:"18+F#"('(8,B@R.#)(,E@R:#)X,H@RF#*H,K@RR#+8,N@R^#,(,Q@S*#
M,X,T@S6#-H,W@SB#.8,Z@Q,)-0@/",L3$P@G"$&#0H-#@T2#18-&@T>#2(-)
M@TJ#2X-,@TV#3H-/@U"#48-2@U.#5(-5@U:#5X-8@UF#6H.@$!,'^@_[#T$0
M0A!#$$0011!&$$<02!!)$$H02Q!,$$T03A!/$%`041!2$%,05!!5$%805Q!8
M$%D06A!;$%P071!>$%\08!!A$&(08Q!D$&409A!G$&@0:1!J$&L0;!!M$&X0
M;Q!P$'$0<A!S$'00=1!V$'<0>!!Y$'H0>Q!\$'T0?A!_$(`0@1""$(,0A!"%
M$(80AQ"($(D0BA"+$(P0C1".$(\0D!"1$)(0DQ"4$)40EA`!``(``P`$``4`
M````````H1"B$*,0I!"E$*80IQ"H$*D0JA"K$*P0K1"N$*\0L!"Q$+(0LQ"T
M$+40MA"W$+@0N1"Z$+L0O!"]$+X0OQ#`$,$0PA##$,00Q1#&$,<0R!#)$,H0
MRQ#,$,T0SA#/$-`0T1#2$-,0U!#5$-80UQ#8$-D0VA#;$-P0W1#>$-\0X!#A
M$.(0XQ#D$.40YA#G$.@0Z1#J$.L0[!#M$.X0[Q#P$/$0\A#S$/00]1#V$`8`
M!P`(``D`"@`+``P`#0"1`Y(#DP.4`Y4#E@.7`Y@#F0.:`YL#G`.=`YX#GP.@
M`Z$#HP.D`Z4#I@.G`Z@#J0-D#6`-8@UF#6$-90UG#6,-L0.R`[,#M`.U`[8#
MMP.X`[D#N@.[`[P#O0.^`[\#P`/!`\,#Q`/%`\8#QP/(`\D#P@/U"_8+]POX
M"_D+^@O["_P+_0O^"Q8-%PT@$`X-``T!#0(-`PUH#;$,\!'Q$?(1\Q'T$?41
M]A'W$?@1^1$.`/H1^Q'\$?T1_A'_$1`$$002!!,$%`05!`$$%@07!!@$&00:
M!!L$'`0=!!X$'P0@!"$$(@0C!"0$)00F!"<$*`0I!"H$*P0L!"T$+@0O!+X*
MOPK`"L$*P@K#"L0*Q0K&"L<*R`K)"LH*RPK,"C`$,00R!#,$-`0U!%$$-@0W
M!#@$.00Z!#L$/`0]!#X$/P1`!$$$0@1#!$0$101&!$<$2`1)!$H$2P1,!$T$
M3@1/!/<0^!#Y$/H0V@G;"5,(5`A5"!,.&`HC"\X*``P"#`P,$`P8#!0,'`PL
M#"0,-`P\#`$,`PP/#!,,&PP7#",,,PPK##L,2PP@#"\,*`PW##\,'0PP#"4,
M.`Q"#%$24A)3$E0251)6$E<26!)9$EH26Q)<$ET27A)?$K$2LA*S$K02M1*V
M$K<2N!*Y$KH2NQ*\$KT2OA*_$@````````````````````#0#-$,T@S3##P'
M1P=(!TD'S0'.`=`!/@4_!?@!^0'1`=(!U`'6`=@!V@'<`0````"L!Z``H0"D
M`*8`J0"J`*L`K0"N`*\`L@"S`+<`N`"Y`+H`NP"\`+T`O@"_`,``P0#"`,,`
MQ`#%`,8`QP#(`,D`R@#+`,P`S0#.`,\`T`#1`-(`TP#4`-4`U@#8`-D`V@#;
M`-P`W0#>`-\`X`#A`.(`XP#D`.4`Y@#G`.@`Z0#J`.L`[`#M`.X`[P#P`/$`
M\@#S`/0`]0#V`/@`^0#Z`/L`_`#]`/X`_P```2H!:@$2`4P!`0$K`6L!$P%-
M`00!V`)!`3T!6@%@`5X!9`%Y`7T!>P$%`=L"0@$^`5L!QP)A`5\!90%Z`=T"
M?@%\`50!`@$Y`08!#`$8`1H!#@%#`4<!4`%8`6X!<`%B`54!`P$Z`0<!#0$9
M`1L!#P$1`40!2`%1`5D!;P%Q`6,!V0((`1P!)`$T`5P!;`$)`1T!)0$U`5T!
M;0%Q`HL"?@*#`I(";`)N`GD"B`)6`G,"?0*"`I`">P)M`E\"<@*=`HX"80)+
M`7`"@0(G`94"E`)F`I@"P@%3`E<"A`)@`I,!4P%2`6@"B0)8`G4"60)<`EX"
M4`)O`HH"9`*,`E0"40)2`HT"90*B`J$"50*1`GH"9P):`@\`_0%P!G$&$``1
M`!(`$P`4`!4`%@`7`'(&<P9A`\@"S`+0`M$"!@,_!PL#`0,$`P`##P,,`P(#
MY0+F`N<"Z`+I`A@`&0`E`RP#.0,<`Q\#(`,(`ST#*0,O`]X")`,P`SP#-`,=
M`QX#&`,9`RH#.@,[`P,#&@-V#G<.>`YY#GH.>PY\#GT.?@Y_#NL+[`OM"^X+
M[POP"_$+\@OS"_0+<`AQ"'((<PAT"'4(=@AW"'@(>0AZ"'L(T`O1"](+TPO4
M"]4+U@O7"]@+V0O:"]L+W`O="]X+WPO@"^$+X@OC"^0+Y0OF"^<+Z`OI"]`2
MT1+2$M,2U!+5$M82UQ+8$MD2VA+;$MP2W1+>$M\2X!+A$N(2XQ+Z$ND2Y1+M
M$NP2````````````````````````40="!V`+80MB"V,+9`ME"V8+9PMH"VD+
M:@MK"VP+;0MN"V\+<`MQ"W(+<PM@"&$(8@AC"&0(90AF"&<(:`AI"&H(21,4
M$R(331,8$R<3`Q,V$U$35Q,-$R83(Q,K$TH3.Q.<$YT3GA..$X\3Q!.A$VL(
M``````````````````![$QT0'Q`6",T3(0BD$J42IA*G$J@2,1(R$CD2?A-]
M$WP3````````+@D``````````!\)OPD```````!6#AX-```+A`(4*"XO+C`N
MC2[A+OTN_RX#+PLO8"](+TDO5B]?+VHO;"]^+XHOE"^7+S"!R2_@+P$P`C`.
M,!@P)S`N,$`P.S!!,)0PS##R,-`PYC`Q@08Q`S$+,1XQ-3%*,3*!53%7,;44
MG3'#,<HQWC'B,>XQ`3+;%!,R%3)),E<R83*3,L@R,X',,M`RUC+;,C2!\#+[
M,@`S!S,<,S6!83-C,WTSDS.=,[(S$C0G-$TTG#1K-'0T?S2(-)8TH32I-,8T
M_S0.-2LU-350-5XU@36&-8XU-H&M-<XU-X$(-@XV.S9)-G8V9C8X@6\V<39R
M-IDVGC:I-JPVLS;)-LHV"C<]D2$W+S<S-S0W<#=W-WPWG#</@1N2N#?'-\@W
MSS?D-^TW]3?V-_\W"3@0@6$X9#@Y@7PXB3B>.#J!J3AND](XSCC4.-HXX#CI
M.`PY069=.6TYBSF2.:0YPSG2.=TY$SHC.F<Z;3IW.GXZA#J>.J<ZQ#J]EQD[
M)3L``)PN%C4#.C]VP#0;02A#]CDB<'5D'&-06JI`X4,E3NU%9F2F8O5[DT@G
M-Z%%<4*;.]`Y>V;T>&)=OEV.>Q9"GURW:(D[M3X)0Y=&2$C'=8UW3T?E+@HO
M32^=+TDP\C8W.=0Y`3H)/-]`#T%P01-&!4FZ4$]5<%7[6:U=[UW#8`YD8V@"
M:U5P>G`[,Y4NI2[?-[)@P7#O6``N\3BB3CAP,EHH8XMB+WQ!,7`SO33A-.`V
M^SD5/_)XZTWD8"UE8G9P=J!V^W<+-/,SASO/4+U?PF_H=F\S7'VZ6A$NDUC\
M829.&#8$-1U+&F4[?.4YJ3-F3=Q4CW5"-I$N2W#R=D]C#'GA,[8U,#MQ/R!&
M\T8$2#A,\TPI35M4R%9.6C1X\6);:&!J[7*R3:M5RE;%>:9``6N*;;)UCDFM
M,X8Q$C<P.$0YM#OV/BA`J4/T0[],%$^.4!1165'543]3`5YV8M%BEV5@<%MR
M&WUI.+Q%6DPE5?DQ+CEE.8`_W#^\0OI%*DHG2[1+BU/!7U9I+'T.?<1^H3R6
M3'MC!#%+/+9!QF%V2&%262[Z+W@S:4`I3D]:\W<++A8S[BY5+STOH2]S+Z`R
M[S,)-@\YP3JV.^$[T5F'1IQ'MD=,2[-,:U#"4XU9OED\6H=;L6+;8@1C=V/O
M8]-C9F>R:BDVJ&SF;TYP'G>*9L0OZ#P10EE2.U7E8;UB_F;`;,5V$WG5><LN
M&B_C:=XV2CC*./L^ZS\J0)1`8D#001)"T$(Y14%[9D:P2'=-<%!,5896=5VE
M8OEGBW6.=IUL\3&^,A8YLS2S.Q8]:$&"2:]-C5C+9%=H<FJG<[AZ;$VH>=EF
MHS?_1\YF#G*#,H<V!#33/N%"N40\2#A(NTMR4[I8:UJ::=)I:VT#;^UPHW64
M=FEW9CNS/'U)37A.>)M#(%LK2G]*MD@-?%]/<C*=-7!`[$([30=.T4Y;9!!I
M1&\4+CE\]C,;23I*A'<J2%PQPUJR9-QQC'-;-BA](D@%8S%DI5P(,L5BYE1^
M+H,OH#'2.PHRV#+G,OL]FC4J..8YC#N8.]L[<CYY/J-`'T%C0;Y!VT-B1=%'
M4TCZ2#Y+4TM73")/ET]%3[!4&%7C5@M7_UJA6R%<Z5TV7_!?G6!F8IYCLVG,
M:JMLA'!1=)-UD76B=65VTW<H>1AB."XK-+@\S#VI4TQ6/%>I/.M?"VW!=A%X
M5'A8>`$O#B]Q,YPU:#;Z-T<Y"3O$.Y`\##Y^/LP_[D,Z1]=%XD4?1\M(Q$A?
M2C`^Q4L73'U,?U5(66,[`%H`7;T_CVD8:K1L=VW,;AUOXG@.>CQ[@"Y],``Q
MDSF<.R]"@$+L1#I+H%*154=9J5_[9[QJ<&NL0\ICH'<)-`,TJS542%A*<&HG
M6'5'S7YT,Z([&F%09@9P&"Y%+L<N$2_*,S@TKCL3/R5`444]1T),<DSC3'A0
M`U1V6JY:"%L:7?Y<9EWG15M2NS-%/.@]TD+@0AE#($Y:9C%JW6WX<@%/IEE:
M>Z@NJRZL+ILOH"_1,$<Q]EIQ,?8Q5#,A,W\SZS.L-8,XX3PW/TH_+T!00&U`
M'T-914M*P4S"4NU2[U?X8`5A"&).9?=PX7/_=U=Y6GKP+MTQ+3R!1FU)0#SR
M1G5)B5-02(%<Q3#D,D<W_CTF<Z1%(TL]2S14@5F]64M;REVY8LQC?VA?:3EK
MT6_1<1\T@')=+C8PY3,Z,]=2EE/I5^9BKV[&><AYTGEW,1I!7F:P-7I:=C#3
M.T=PA78R+MM*YW%1/$@\F$.?6I-,='=A;ZI:BE&(=H)<%TAP7E%(;'/R,ALT
MJV43:J1?S6[A<&8SB&A!6<(OOC`1,D0Q4S4M-^I3BS=1.6(_A#]U0'9!9T&I
M0;)#.D1L16]&0D@33F95/5K[7$Q=F5U+7FM?#F-*8\UF"&IC:F9K_6X:>(]]
MN&+.;^A[AS(?0H-$P$^9=D%(D3`@2WI,5$]T6E!=0&@C:@A']BXY,"8P93!\
M,3@R8S*G-0\W!3C,.OH^LD'X0?-"<D,<22E*?5*L4BY3%%AO6'E=#%>I8(MI
M&6OB;-)N8W!U<WIV57@3>GA^0S&?,[,S>SXF/QM.D$Z$4_Y30UTW8@!J^FI0
M=DXN"S#D,WPT^C;1.60[\3VK/B<_.$)%1:]'5D[04LI<M&BA8.%@\&-.9H=J
MZ&TW<L=V9W@3?Y0NDBX-+T@S230^-"\ZC#^A/Y]`ITB.2EI4@5B>:J1J=VN0
M<5XNR7ND+GPOKR\9,!8P23%L,9\RN3+^,IHSXS,1-`XTB351-Z(W?3E4.UT[
MCSOE/><]]SUX/H,^FCZW/A@_4D!,09="V$*G0SM%`D9#1O1&;4<A2)=(RTE?
M3"I-:4TO3IU.,E6'5FQ8/UK@7`5=&%U>7;%=%6`#8*]@L6!488]A*F)28TQH
M86@;:Z)L_&S*<'5Q<7(_6/QRI'5-=@5XF7G8>CM]6S*K,O<S"#35./="X$]J
M;%]ON7Y+,3LR2C3]-D!:=W%@?=)^1%,)3W!A$57]/]I`J'K;4KQO9$L#>,HN
M\#9D-[XX6CIH0,=!#T8&1CE(L4CW3=55.EUN8D)[FRY0+\DS!C5O/>8][CW[
M1YE,<U0"6%!JEG/?:%`WISXK0[4PK#"-,0!'R31>.+LYL#MI/TU"H4,]2'-+
M"$Y]4,=Q@%(56"98;5F.13!=W&/!:`EOFW9D,B@W4$=J7Z%LM#%"-RIV.CB*
M2;1@LC0./?PWE5CZ?5PO2C*+-#Y$*$841_5'A%I66R)=+W-<2*U[.5L9,XHQ
M-S+?._9"KD3F1"U'NDNI9=%VD%;6>TQ#!G.K>[]64D8)+I@PPC-Q/.A`DD1C
M15](YE'*4R-5EUN"7I5F@VO;;'AQ$'FL1:M&BTO5+M0N.B]_+SHR^#/R,^,U
MVS;K.,LYR3G_.5`[33P"/BL^US\=0`=#+T5<.Z]%O47H19U'8DM[2P],15-)
M6<%9^%P972M=HF`"8?-AEFE>:FEJ9FJ,:NYJQVS<;,QV_'AO2XLN/"^-+U`Q
M5SOZ.TA!`4-"1B%+RTZ[3#Y2O5345<%8.ED,8#-@ZF&49)YO4$Q_?@\_6&LK
M??I:^&Z-.^MV`R[Q,_<W,3G).J0[B4!_3@9/OE7J;)\[`&7@6W(P]$>=8F$\
M2F4>7@YBF3$$/&A#9FV<16Y1/ED7705@'6O*;FYPQV:J<!\P^C(Z/%-'?%`U
M4DQQR'$K<^5BPCLQ/_E`.R[6,X@[2T(Q1XI+Z5+@4RY::V&C;5)QEGD2,=<S
M:C3_.XA#.4JL70!WVC;.,V@TESLQ/-X][B\!0?Y",DW`6<M90EU-7M)?[6$?
M8I!D1FAR:9!K=&XO;S%P2W%L<<9VG''`+D\O13%!,Y,_#D+41T%,"TYC4R9>
MS7&#<M0S&3F_.]%-75DN7IM<?CB?4?HQ4VCP;\HO^SPE1JQ7XUH<8O]YQC&J
M/^Q%;TF)2_--EDYD3_Y6%%WA/75PAW$&>.8Q'3)`0I%&V48:3K8^TEUR7_A&
MKV7W9?AJJ3+9,W,YCSZ0/U5`Y')D=K<P'S'=,B`S1S/L,^@T1C4Q-1<V:#F^
M.3PZM3L&/`\\$3P:/(0^BC[@/G`_?T*$0MM"C$-W0P=&#$8M1G9&?D>B2!]*
M-4J\3(A-"4Y83CQ1)E%G4<=5`5==6`%995GP6>!:$5NG7#E=EF#68XMD265=
M:/-H'VH\:E1J<VIA;-YLI'%F<GYS&'2<=IAW"BX(+AXN5RZ7,7`RSC<T.,PX
M(CLX/L5`_D1A1U9'1$VV4G-58UJX9')KN'$@<S$V]#?^>.U"#4F62^U15%YW
M8')BYFG?>%5GL6\[/#@OX2^U+P<U(#K=.^D[PS].02]#L$5+1NY(FTEX3?%-
M,U6Y51]77EGF63-=XV&O8JIEJFDZ:JMNFV\R<-UQ!W>Z+L$N`S)U..PX"SP:
M53T\3F$*:L5O8W9M=R5;SVH(>&)Q\S:H,Q=P.32"-R4^J$,T3(I085>+7.!?
M<&A"<%1Q$',8<X]V7E3$>@<]:3UP1:)'J&W;=FY#24<92<5C%WC`=OYHA$]Z
M1/@[%BXL4%U5+T;$,38RXC+3.8$_)T`00C]%=$4?1G1&\D@62&-+!4YR4A]5
MVU:^7%9@\#C]:']IH&J3:LMJ'7"2<5)W67>)10Y:!F&[=BT^W$`:0J5%%$:0
M1_-735I-7#Y>"F&L;&1MX6U?;JE8!S+90J5#0D280BUJ@UK`6ZQJZG9V70QB
M26?9+D@Q0S-@,Z,[`CP6/-T])D)'0K!$$T@T2,E,14T73=-'7$].47U1RT5_
M6JU;VEU*7JA?>F$;8CEBIF5N:LYL]6UX<'=PK7*1<H-UKGM-,H0U.$\V46@Q
MA5E57K-ASEQ,-E$XJ#RJ0_Y&_49:2=E2CU6.50Y95EG?69=<(%U$70=F-&H[
M=F%P('_G,'4RS#/B,PDPJC7N.$\Y/5*+.V0\'3/C0/-`7$.#0S]#NT/-1.E%
M^4;C/<U)_4D53^51B2[I5?A6DUK?7,]=G%UA8$EC6&-L9+QD^V7%:'!M`7!M
M<)=S''<2>L\PESB.0=-A-64(;2!PPR]T,$<R<S-O0$E#7T<L3K-M'W#7+UX\
MRFS/19I=4C.6:'8QPT-8.VL["CP-1%%'7'#6+AHY*CEP3%%J/C45.*4Y\$!3
M0L%'-6)524!VQ'DH>E,O!CC^.Q!@L3PO/H4_($!+031"_T;P3-Y.SF!_8=1B
MBVBX;`!P+G"*=MM^VWOC+O`S)SDL6XUQ3'CY?=U.)U!3,T0UA3M80IY"TT*B
M3.]/(E07:CATP4_^:CACYS'X9NHSZ3-&+U1PL&]J.3%A_3WJ6K]OVD@W;/A2
M2'P]2K!J.2Y8,P8V9C?%0J)#YD5.2^%-6TZM4.U7[UJJ6[M=/6#&8,MFE6I;
M<^,VQS@^/ZU%ED:`2K5+-U7':B0PY5<P-QL_94!Z1F!,]%4:6FY?]&$89T5P
MLWG)6UQ5^5I16\1D$'#I69):-F/A.D!7+2[R+ID[X#^]0CQ&\4?H3&MF=V@[
M:DYQ\W+0>1=*)E`J4^=B5V2O;`$N1C'+,8LU]3L6/C,^@3X4/S4_:S^T/_)!
M$4.B1AU';D]24CI5.E=T8#EA>&%V9[]JW&J%;?-MFG)W=0)XY7S%,E=#]%85
M1XA,S5/#;*YS<W8E39PX#DG,2?UOFG/;51IP6C@"2+1#^TE#+RQ/V$>[;R9E
MM%U4<S])<$]J-_<X+#LL72I2"C3C<;1]K2Y.+UPP=3!#,IYL2#0D.)H['3Z5
M/JT^]SX?/XQ`M4(Z0]!#KTA`3(=8CED+6N!=1V(":N9J1&X3<+AP+7'8<0Y_
MY4Q81.)$=47T3H16&UMI<-%SND[R-+D_I$1-;^UO1')X,6LX*3E5/)<^^TV/
M7AQ5O&SB;EMXN5`=+[]+L4\P5?MV3C$0-#4X5SBL.6`\DC^715Q'(4Y[5M]C
M[6P4</UP37,E6#I8JC*F/A\W=#D20!(P6C&L,<TQ`#(0-50X6#A7.94[]CR+
M/;Q`E4(M1'%'0TB\2-](UU;836].FTUO4,A14S_857=925M46U);UEQQ73`R
M8V1I9>1E#FH$:T9L#VX#<`]P&71V=BUX,'K8=<TPU3(,-`(X#CRG09Y$'DVS
M5^5:]&`$9%-PA7+@/`=]/S.7/[,_G$UY4F-7OUGD6])+[%*M:@-(84KX,8%:
M-$E*//9\ZV+%.TEQ'E!X-F\\QT!F18Q,6FQ!<!-X433'1@UR2#FC<(4Q32[J
M,9EE#FM84'I#2W-B2;1Y!%YW55<S8$G?;N-V74R,+CP\$#_I;P(ST6R)8'EF
M_S[E17,N93&".3\\[G?[+HHYS3^-:N%/L%EB6><[<60K4[%1=#[U/WM#FD3#
M49A<0R[\/DLNW#>B-JE`PT\-7?U@,V&_8;)OEVFD9O0]BD*M1(=I=T?B3#Y-
M-E0T6$8Z=5^M8JQY\R_#/MU"DD-716]'PU9,4LQ@NF`I;TUQ#3#Y-Y(ZA4AS
M2611_5*W;/(XX&QJ=AEP?V?D6>=7*60O+V4R6C/-0L]'RDQ]5I1;E5PV8H1E
MZV_=1B!/!E(;7JMCP7FF?OTQL5MR6+A;AV!(6^A*83Z,8%%58%5K,6)RC$YZ
M5I=QZGH0+W!?G$)/6Z5UZ7QZ-EDXY&:\=C0O)#)*,\TSVS,&/BQ$D45_1SY,
M3DQ(4J]2[5-454%>+&+I9:ELQ%O&<6E1$GCO>#U#:49J5>16T%A#9>YF*C-1
M,R8T@SF'/GP_LD!)0GE"JT*01=1+S$RR5:Y6D5C86<M==U^E8*MHN6J[;']P
M7G?;>`M*.%R9,#X\KC^'1]A+-50)5XY?.W_*1Q=:.3.+5>UZ9C^=8?%CF&`\
M/\4_8E5&6SQP9TCK.9LZ$%U^5BQK]2]J/QE*-TP"3^)4:%EH:%5J>6S?/L]#
MQ5726==B*'/R<IQD[68M?,$T;#^,15Q-%5"G;--L.WA/1?94#2[8+N`W*SEF
M.LP[J#$#/IP^%D!V0G=%IT5N1FY--E(F6U!AFF&98EQKH&SF;'1M''9$=JXO
MJT1F2QYB861J9>AP`3Q32:AX>F1790\O;S*I/T4^#4>/67EA!VF&:?5-%S]5
M0KA,SRYI4I)[!C([-'0VLSBD06Y"&E%N.8E<WEP;7?!VAT5>8!DN=2]U,4`X
M8SYS/@H_Q$<F+CUEB75;=G-<`7C[,,$X5E:G6"4RI5<1989;3S`).4=2QUOH
M7;IOU&]-<+\OR3(I.@$_K7?=+Q=BZG(#-U5#:4LK5=QH%&]"6M\RDSA500I"
MKD;-2S]<Z6,C,/@O!3-&-#$X23F=._`\[SPI/98^L4)G0SY%N44+1]5,X4SY
M4#)8*U[>8+-B#&3L9`)G$FDJ:DILIG#2<OUX\WQL?4\NH2Z-,%8R2C>H.3T^
MV#_9/S]"M$8;1]!'TDB2,2%=JF"H80!KC&R_;'YR,G8@-"QX%S/5,%PSJ#BR
M1#1'9U)F5T9:YG'#,J%,ADL`.$P^5#DL1_M?X3'&5FE$Z%A4>[M^RS>Y.2=&
MFD?.2^DTV4E5/IQAE4>J>_Y'4GQ=2*8NXR_(,[E"*T>K3,1OK2]M7K]^!RYB
M08!.*T\397,T*D=%>_,]E5NL/,8['&=*3M%D%%H(89DYC5P13"!7V3(B.2%1
M7U+;5R=W87T+27\Z&#JE,0TT?30.1M]6]V^8<O1\ZCE=4L5.33')2+]=[%UB
M=[I^>$0A2@)CA#E?.]M+&U/R5K)=%V"99#(Q*$?9?NY68D?_,@5Y)#P[0GY<
ML&Q/-;9`"UV`=0$S7RZV,1PY.E(V8,YQ)3_B5X0S>3\$7:QE,VJ-;E9W\T>N
M95-T"4$(0;E,4E;M:CAO+S51+RHQQS++,Z4[?3Z@0()!UD,)1]I'9TZ,3393
M-U,Q55!9U6B8:DIPD7#U<,1VC6<5.8@N62\.+HEJ/V\0>*TP?#Z6.;D[N#[:
M0_I#P43<1DI)V$D+3;9.E%$H5:]:BE\`8$EDR62!:2%K"FYE<'UV"GE^09%"
M,DN#3'1-S%_\7\!-A5^Z9_AH94>Q8SQX]W8;36%=/61J<7$N=3-0/01+ZT_-
M92UFIVDI,@\T93Q.1ZA(!E2#5.)5SVCA:,QQXG9X=HL_AU/+6DYDH$-E58DR
M04V<3@E4655K6))<AG;<6HU_MB]N0<5%7&:&+JXNVC`A+LPQ[CN918%(O$T?
M4T)6K5<<6N=<;V+2:GQPSW%U=AAXFS+172LPF#.71\M-T%$S5.AA*F^C=E=\
MGWY@5$$XF4TO75YXY"XV+XLOMS&Q,KH]'$"R4SQ9TV(T<K=V]G8*=Y=^8G^F
M1G1+%S*C,LA0PFC)/DM`D$$C3TE1/EST76]@[F0C<"QS0C1O>]-*B5#";.]M
M,G>T,D$ZRCX$/Q='?$F426I-#T]B4OQ2[5L!8'Y@2V?.<&TQDWZ$68M@,G/6
M:BTPC#1Q:FI+Q&P'8=%`H$?R?9DNF"X0?&MJP65H90!)?DZ76%5A``!!.U8[
M?3N3.]@[[#L2/!X\(SPK/(T78CP[@3R!M)5Z/(\\GSRC/*H\NCS+/-`\TCST
M/#2;XA<-/2<]$8%&/4<]4SU*/6T]@3V@/:0]ISVX/<L]```,/Q`N%2XJ+C$N
M-BX\+C\N0BY6+E@N@BZ%+FMLBBX28@T_CBZ>+I\NH"ZB+K`NLRZV+LXNS2[$
M+L8NPB[7+MXN[2[?+O<N"2]:+S`O6R]=+U<O1R]V+X@OCR^8+WLO:2]P+Y$O
M;R^&+Y8O&#'4+]\OSB_8+]LOT2_:+]`OY"_E+QHP*#`4,"HP)3`%,!PO]B\A
M,"DP+##^+^\O$3`&,$,P1S`#1U4P4#!(,%HP5C!L,'@P@#":,(4PM#"R,,DP
MRC"S,,(PUC#>,.4P[3#C,.XP^3#U,`DQ`3$",18Q%3$4,1HQ(3$Z,3<Q/#$[
M,3\Q0#%2,4PQ5#%B,?A::3%J,6XQ@#&",=@VC#&),8\QD3&3,94QEC&D,:8Q
MHC&I,:HQJS&S,;$QLC&P,;4QO3'%,<DQVS'@,55FZ3'M,?`Q]3'^,00R"S(4
M,@XR)S(J,BXR,S(Y,D\R1#)+,DPR7C)4,FHR=#)I,G,R?S)],HTRE#*2,G$R
MB#*1,JAOIV^L,JTRO#*U,L$RS3+7,MXRXS+F,NUXX#+S,O4R^#+Y,@8S"#,X
M50TS$#,/,Q4S&C,C,R\S,3,S,S@S0#-&,T4S%RY),TTSUC%>,VDS;C,8.7LS
M=S.",Y8SH#.F,Z4SKC.P,[8SPS,27-EVWS/\1NY1[C/H,^TS^C,!-#TT0#0L
M-"TT/#0N-#8T*30=-$XTCS1U-(XT7S1Q-'<T<#22-'LT@#1V-(0TD#2&-,<T
MHC2X-*4TK#3$-,@TJ#2K-,(TI#2^-+PTV#3E-.8T#S44-?TT[C3M-/HTXC0Y
M-4`U8S5,-2XU7#5%-58U5S4X-3,U7369-8`UKS2*-9\U>S5^-9@UGC6N-7PU
M@S6I-8<UJ#7:-<4UWS7$-=PUY#74-10V]S46-OXU_34;-ODU3C90-M]1-#8V
M-C(V.#9K-F0V+S9L-FHVAC:`-HHVH#:4-H\VI3:N-K8VM#;"-KPVP3;#-L`V
MR#;.-M$VTS;7-NXV^38`-_\V!#<)-P@W"S<--Q,W&#<6-\<U'#<F-S<W.#=.
M-SLW0#=/-VDWP#>(-V$W?S>)-Y,WH#>S-Z0WJC>P-\,WQC?4-](WTS<*.-8W
MXS<+.!DX'3AR."$X8CA+.'`XP$M2.#TX>3B%.+DXGSBK.+HXWCB[.+@XKCC%
M.-,XT3C7.-DXV#CE.-PXY#C?..\X^CCY./LX_#C].`(Y"CD0.1LYID@E.2PY
M+3DR.3@Y/CG26E4Y4#E..5HY6#EB.6`Y9SEL.6DY>#F!.9TY7B^K+Z,YLCG&
M.>@YW#F-.=DYVCDE.A\Z$3H<.@DZ&CI`.FPZ23HU.C8Z8CIJ.IHZO#J^.LLZ
MPCJ].N,ZUSKF.NDZUCKZ.OLZ##L+.Q8[,CO0.BH[-CL^.T,[13M`.U$[53M:
M.UL[93MI.W`[<SMU.W@[B$5Z.X`[@SNF.[@[PSO'.\D[U#O0.^0[YCOB.]X[
MY3OK._`[]COS.P4\!SP(/`T\$SP@/"(\*#PX/#D\03Q&/$X\4SQ0/$\\<3ML
M/&X\8BYV/'D\C#R1/)0\FSFK/+L\MCR\/+<\Q3R^/,<\V3SI//T\^CSM/(P]
MZCP+/14]%SU</1\]&ST1/10](CT:/1D]&#U,/5(]3CU+/6P]<SUV/8<]A#V"
M/:(]G3VL/:X]O3V0/;<]O#W)/<T]TSW2/=8]VSWK/?(]]3T+/AH^&3X1/AL^
M-CXW/D0^0SY`/DX^5SY4/E\^8CYD/D<^=3YV/GH^O'Y_/J`^P3["/L@^T#[/
M/M8^XS[=/MH^VS[B/N$^Z#[I/NP^\3[S/O`^]#[X/OX^`S\)/UT_7#\+/Q$_
M%C\I/RT_.#]!/T@_3#]./R\_43]6/U<_63]A/VT_<S]W/X,_@C]_/XH_B#^1
M/X<_GC^9/Y@_H#^H/ZT_O#_6/_L_Y#_X/_$_W3^S0/\_(4!@0!E`$$`I0`Y`
M,4`;0!5`*T`F0`]`.D!:0$%`:D!W0%]`2D!&0$U`8T!#0&1`0D!L0&M`64"!
M0(U`YT"#0)I`A$";0)9`ET"20*=`BT#A0+A`X$#30+1`\#^]0,9`M4#80$U!
M%4$&0?9`]T``0?1`^D`#02%!^T#Q0`U!#D%'03Y!*$$G04I!/T$\02Q!-$$]
M04)!1$%S07=!6$%905I!:T%T06]!94%Q05]!74%3075!F4&608=!K$&409I!
MBD&10:M!KD',0<I!R4'W0<A!PT'&0;I!RT%Y7\U!YD'C0?9!^D'T0?]!_4'\
M0?Y!`$((0@E"#4(,0A1"&T(>0B%"*D(N0C!",D(S0D%"3D)>0F-"6T)@0FA"
M?$*"0HE"?D*20I-"ED+40H-"E$+70M%"NT+/0O]"QD+41,A"W$+,0LI"PD+'
M0IM"R4(,0^Y"\4(G0P)#"$/O0O5"4$,^0TU#'$1/0Y9#CD.`0ZM#=D.C0X]#
MB4.?0[5#:T-I0[Y#Z4/`0\9#XT/)0])#]D/$0Q9$-$0&1!-$)D0V1!U%%T0H
M1`]$9T1O1'9$3D0J195$DT2E1*E$B$2\1-I$TD3%1,=$NT381,)$\43G1`EB
MX$3A1*Q"XT3O1"Q%]D3T1/)$^D0`1?U$&$4<105%)$4C12M%-$4U13=%-D4X
M14M52$56155%345815Y%745R17A%@D6#18IKFT6?1:M%MT7#1<9%P47$1<Q%
MTD7;1=E%X$7A1?%%<D<*1@-&^T5S1S5&-D8T1AQ&3T9$1DE&049>1EU&9$9G
M1FA&7T9B1G!&@T:(1HY&B4:$1IA&G4;!1KE&R4:^1KQ&Q$:X1M9&VD;@1C]&
MYD;I1O!&]4;W1@]'%D<>1R9')T<X=RY'/T<V1T%'.$<W1T9'7D=@1UE'8T=D
M1XE'<$>I1WQ':D>,1XM'ID>A1X5'MT?O1[1'[$>S1^E'N$?D1]Y'W4?B1^Y'
MN4?.1\9'YT><2AY(1D@I2$!(34@R2$Y(LT@K2%E(8TAW2'](GTB/2*U(E$B=
M2)M(@TBN2KE(=$BU2*!(ND@/28U(?D@!2<I("$G82")))DGA2`Q)S4C42.=(
MU4@V21))!$G72.-()4GY2.!([T@H22I)&DDC22%)QDAY27=)7$EX26M)5$E^
M26Y).4ET23U)64DP26%)7DE=28%):DFR2:Y)T$F_2<%)TTF^2<Y)Z#O*2=U)
MNTG#2:=)+DJ12:!)G$F52;1)WDGH20)*&TK_20I+^4GR2>=)!4JQ21Y*[4D4
M2NM)"DH22L%*(TH32D1*#$IR2C9*>$I'2F)*64IF2DA*.$HB2I!*C4J@2H1*
MHDJC2I=*%V:[2L-*PDJX2K-*K$K>2M%*WTJJ2MI*ZDK[2@5+%F;Z2A)+%DLQ
M>Q]+.$LW2]Q6.4ON>$=+0TM)2U!+64M42UM+7TMA2WA+>4M_2X!+A$N#2XU+
MF$N52YY+I$NJ2ZM+KTNR2[%+LTNW2[Q+QDO+2]-+WTOL2^M+\TOO2[Y^"$P3
M3!1,&TPD3"-,7DQ53&),:DR"3(U,FDR!3)M,?DQH3'-,DDR03,1,\4S33+U,
MUTS%3-U,KDRQ3+Y,NDS;3.],V4SJ3!]-36@V32M-/4TX31E--4TS31)-#$UC
M39--9$U:37E-64V.395-Y$^%3?E-%4X*3K5-QTWF3;A-QDWL3=Y-S$WH3=)-
MQ4WZ3=E-Y$W53>I-[DTM3FY.+DX93G).7TX^3B-.:TXK3G9.34X?3D-..DY.
M3B1._TX=3CA.@DZJ3IA.R4ZW3M-.O4ZO3L1.LD[43M5.CTZE3L).GTY!3Q%/
M3%#L3OA._DX_3_).,4_O3C)/S$X^3Q-/]TZ&3WI/>$^!3X!/;T];3_-/;4^"
M3WQ/6$^.3Y%/PD]F3[-/HT^A3Z1/N4_&3ZI/WT_53^Q/U$_83_%/[D_;3PE0
M"U#Z3Q%0`5`/4/Y/&U`:4'1/'5`84!]0,%`^4#)045!C4)E0DE"O4/%0K%"X
M4+-0KE#?4,M0W5#94`E1_5`<41E195%548A19E%B44Q15E%L48]1^U&$4951
MJ%&L4==1N5&^4=)1R5'44<Y1X%'L4>=1]5'\4?E1_U$-4A!2&U(H4BU2+%(P
M4C)2.U(\4C]20%)&4DM26%)T4GY2@E*!4H=2DE*64J)2IU*Y4K)2PU+&4L12
MSE+24N)2X%+A4OE2]U(/,!=3"E,<4Q93'5,T4R]3*5,E4SY33E-/4]A^5U-J
M4VA3<%-X4W53>U-Z4\A3LU/.4[M3P%/E4^Y3WE.B5`54;U0E5/A3,E0Z5%54
M/U1?5%E4051<5&E4<%1C5&I4=E1^5(M4GE2G5,I4SU345/%3X%3C5.=4Z53N
M5/)4\%3Q5/A4]U0$50-5!54,50Y5#54551-5'E4F52Q5/%5$54U52E5)55M5
M1E5:56E59%5G56M5;55X5795AE6'5715BE6)58)5E%6:59U5I56C5<)5LU7#
M5;55O56X5;Q5L57-5<I5TE795>-5WE7^5?]5_%4!5O!5^E7R5?-5"U8-5@E6
M'U8G5B!6(58B5B16-%8P5CM61U9(5D967%985F%68E9H5FE6:E9G5FQ6<%9R
M5G96>%9\5H!6@U:(5HM6CE:65I-6F5::5K!6M%:X5KE6NE;"5LU6UE;25MY6
MX5;E5N=6ZE8O9OM6"%<'5P17*5<D5QY7)5<F5QM7-U<X5T=76E=H5VM76U=E
M5W]7?E=Y5XY7BU>15Z!7GE>P5[97N5>_5[Q7O5>[5\=7S5?75]I7W%?C5^Y7
M_%<,6!)8)ED@6"I915B.6'18AEA\6)I8C%BC6+58JEBO6-%8QEC+6-18OEB\
M6,58RECL6.=8VEC]6/18!UD261%9&5DL62M90%E@65=97UE:65594UEZ67]9
MBEF=6:=92W^J6:Y9LUFY6;I9R5G56>=9[%GA6>-9"%H-6AA:&5H@6A]:@%DQ
M6CM:/EHW6D-:5UI)6F%:8EII6IU_<%IY6GU:B%J76I5:F%J66JE:R%JP6K9:
MQ5K$6K]:@W#'6LI:S5K/6M5:TUK96MI:W5KA6N):YEKM6O!:`EL/6PI;!ELS
M6QA;&5L>6S5;*%LV6U!;>EL$6TU;"UM,6T5;=5ME6W1;9UMP6W%;;%MN6YU;
MF%N?6XU;G%N:6XM;DEN/6UU;F5O+6\%;S%O/6[1;QEO=6^E;$5P47.9;Y5M@
M7`!<!UP37/-;]UL77`U<]ELC7"=<*EP?7#=<*UP]7$Q<0UQ47$]<0%Q07%A<
M7UQD7%9<95QL7'5<@UR07*1<K5RB7*M<H5RH7+-<LERQ7*Y<N5R]7,!<Q5S"
M7-A<TES<7.)<.WOO7/)<]%SV7/I<!ET"71Q=%5T*745=2UTN73)=/UTU749=
M<UU674Y=<EUH76Y=3UUC79-=B5U;78]=?5V;7;I=KEVC7;5=QUV]7:M=/5ZB
M7:]=W%VX79]=L%W87=U=Y%W>7?M=\EWA705>"EXC7B%>$EXQ7A]>"5X+7B)>
M1EYF7CM>-5XY7D->-UXR7CI>9UY=7E9>7EY97EI>>5YJ7FE>?%Y[7H->U5U]
M7JYO?UZ(7HE>C%Z27I!>DUZ47I9>CEZ;7IQ>.%\Z7T5?3%]-7TY?4%]17U5?
M5%]87U]?8%]H7VE?9U]X7X)?AE^#7XA?AU^,7Y1?GE^=7YI?HU^O7[)?N5^N
M7[9?N%]Q:\5?QE_*7]5?U%_A7^9?Z5_S7_E?W'@&8`1@"V`28!A@&6`<8"%@
M*&`_8#M@2F!&8%)@6&!:8%]@8F!H8'-@<F!P8'9@>6!]8']@A&"&8(5@FV"3
M8)I@K6"0,:Q@VV#E8-E@W6#$8-I@UF`)8>]@\6`;82EA(V$O84MABW9&83YA
M4V%18?Q@<6%N865A9F%T88-AB&&*88!A@F&@895AI&&C85]ADV&I8;!AM6&^
M8;AAO6'`8<)ANF')8<UAT6'98=AAR&':8=]AX&'G8?IA^V'^80%B`F(%8@=B
M"F(-8A!B%F(I8BMB.&(S8D!B66)88EUB6F)?8F1B8F)H8FIB:V(N8G%B=V)X
M8GYBC6*28JMBGV*[8JQBX6+C8M]BTF+T8O-B^F*38P-C^V+Y8MYB!F/<8@EC
MV6(U8S1C%F,R8S%C0&,Y8U!C16,O8RMC%V,88X5CFF.J8Y]CHF.68R-CCF.'
M8XIC?&.U8W-C=6.@8XECJ&/T8Q-DZV/.8_UC`V388PMDP6/W8P=DX&/R8PUD
M(F0@9+UC.&0&9?MC;60J9#QD6F6$9'=D:V2M9&YD@F1I9$9D+&1O9'ED-63*
M9&)DN62_9)]DV63-9+MDVF309,%DQF369*%D(67_9/1D%V4892QE'V45911E
M_&1`96-E6&5(94%E`F9+955E@&6D98AED66*9:AE;66499MEZF6'99QE=V5^
M99!ER66Z9<]EN6709=5EW67E9=QE^64*9A-F"V;^9?IE!F8B9AIF,&8_9DUF
M52Y49E]F9V9Q9I-FHV:I9JIFBV:,9K9FKV;$9L9FL&;)9B-HJV;49MYFZ6;L
M9M]FVV;O9A)G!F<(9P!G`V?[9A%G"6<-9_EF"F<T9S]G-V<[9R5G*6<:9V!G
M7V=X9TQG3F=T9U=G:&=N9UEG4V=C9VIG!6BB9Y]G@F>O9\MGO6?`9]!GUG:K
M9\1GLV?'9\9GNV?O9_)GX&</:`UH_F?V9_=G#FC29Q%H%F@5:")H(6@Q:#9H
M.6@G:#MH1&A":%)H66A>:&)H:VB!:'YHGFAU:'UHM6AR:()HEVB2:*YHF6BB
M:(UHI&BP:+]HL6C#:,1HU&C8:-EHW6CY:`)I_&CT:.AH\F@$:0QI"FD3:4-I
M'FDE:2II*VE!:41I.VDV:3AI3&D=:6!I7FEF:61I;6EJ:6]I=&EW:7YI@VF(
M:8IIDVF8::%IJ6FF::QIKVFR:;IIO6F_:<!IVFG<:=UIYVGT:?AI`VH6:A!J
M#&H;:AUJ)6HV:D%J6VI2:D9J2&I\:FUJ;&IB:H5J@FJ$:JAJH6J1:J5JIFJ:
M:J-JQ&K-:L)JVFKK:O-JYVKD:O%J%&O@:N)J]VK>:MMJ#&L':QIKX6H6:Q!K
M%VL@:S-KJW<F:RMK/FLH:T%K3&M/:TYK26M6:UMK6FMK:U]K;&MO:W1K?6N`
M:XQKCFN2:Y-KEFN9:YIK.FQ!;#]L2&Q,;$YL4&Q5;&)L;&QX;'IL@FR);(5L
MBFR-;(YLE&Q\;)AL'4*M;*ILO6RR;+-LKFRV;,ALP6SD;.-LVFS];/IL^VP$
M;05M"FT';0]M#6T0;4Y_$VW-;!1M%FUG;6UM<6US;8%MF6W";;YMNFW/;=IM
MUFW,;=MMRVWJ;>MMWVWC;?QM"&X);O]M'6X>;A!N'VY";C5N,&XT;DIN1VY)
M;DQN4&Y(;EEN9&Y@;BIN8VY5;G9N<FY\;H%NAVZ%;H1NBVZ*;I-ND6Z4;IEN
MJFZA;JQNL&[&;K%NOF[%;LANRV[;;N-N_&[[;NMN_FX*;P5O%6\2;QEO$V\<
M;Q]O&V\,;R9O,V\[;SEO16]";SYO3&]);T9O3F]7;UQO8F]C;V1OG&^?;Z-O
MK6^O;[=OVF_E;^)OZF_O;X=P]&\%</EO^F\1<!5P(7`-<!YP%G`+<"=P-G`U
M<#EP^&]/<%!P47!2<`YP27`^<%9P6'!><&AP;W!V<*AV<G""<'UP@7"`<(IP
MB7"/<*APKW"Q<+5PXG#D<$A"VW`"<1)Q&7$R<3!Q2G%6<5AQ8W%E<6EQ<W%R
M<8MQB7&"<:)QJW&O<:IQM7&T<;IQP''!<<EQRW'0<=9QWW'A<=MQ_''U<?9Q
M'G+_<11R+'(5<A%R7G)7<D5R27)D<DARE7(_<DMR4'*<<I9RDW*;<EIRSW*Y
M<K=RZ7(/<_IR1',N<QES(G,:<R-S.G,U<SMS7'-@<WQS;G-6<[!SK'.M<Y1S
MN7/6<]=SZ'/E<]ASPW/=<]!SR'/D<QIT%'03=`-T!W00=#9T*W0U="%T.G1!
M=%)T1'1;=&!T8G1>=&IT*7)P='5T=W1]=%IT?'1^=(%T?W2"=8=UBG64=99U
MF'69=:!UJ'6G=:UUO'6[=;EUOG7*=?9/PW7-=<QUU774==9UW'7A=>5UXG4A
M=BAV+G8O=D)V3'9/=DMV=W9<=EYV779?=F9V<G9L=HUVF':5=I=VJG:G=K%V
MLG:P=K1VMG:X=KEVSG;+=LEVS79-:=QV#7?5=OEV!'<&=PAW$W<.=Q%W#W<6
M=QEW)'<J=S!W.7<]=SYW1'=&=TAW0G=)=UQW8'=D=V9W:'?2,FMW<7=Y=X5W
M?'>!=WIWAG>+=X]WD'><=ZAWIG>C=[-WM'?#=\9WR'?+=]QW[7=/?_)WWUKV
M=_5W#W@,>#AX)'@A>#=X/7A&>$]X2WAK>&]X<'AQ>'1X<WBJ>*]XL7BV>,1X
MPWC&>.EXZW@#>0EY$GD4>1AY(7D=>1YY)'D@>2QY+GD]>3YY0GE)>45Y4'E+
M>5%Y4GE,>55YEWF8>:5YK7FN>;QYWWG;>=UYV'G1>>UY[GGQ>?)Y^WGX>0%Z
M#WH%>N)Y&7HK>C=Z17I">D!Z0WH^>E5Z37I;>E=Z7WIB>F5Z9'II>FMZ:GJM
M>K!ZO'K`>L]ZT7K3>M1ZWGK?>N)ZXWKF>N]ZZWKN>O1Z\7KW>OMZ!GL8>QI[
M'WLB>R-[)7LG>RA[*7LJ>RY[+WLR>T1[0WM/>TU[3GM1>UA[='N3>X-[D7N6
M>Y=[GWN@>ZA[M'O`>\I[N7O&>\][T7O2>^-[XGOD>]1[X7LZ?/)[\7OP>Q5\
M%'P)?!-\#'P&?`A\$GP*?`1\+GP;?"5\)'PA?#!\1WPR?$9\/GQ:?&!\9WQV
M?'A\YWSL?/!\"7T(?>M\`WT&?2I])GVO?2-]'WU$?15]$GU!?3]]/GU&?4A]
M77U>?61]47U0?5E]<GV)?8=]JWUO?7I]FGVD?:E]LGW$?<%]NWVX?;I]QGW/
M?<)]V7W3??A]YGWM?>]]_7T:?AM^'GYU?GE^?7Z!?HA^BWZ,?I)^E7Z1?IU^
MI7ZI?KA^JGZM?F%WS'[.?L]^T'[4?MQ^WG[=?N!^Y7[H?N]^]'[V?O=^^7[[
M?OQ^_7X'?PA_MU85?R%_+'\^?TI_4G]4?V-_7W]@?V%_9G]G?VQ_:G]W?W)_
M=G^5?YQ_H'\O.,=)67!D5-PQF5$``.(]%#X8/E@^7CZ^/BB`RS[Y/@`_`C\'
M/QT_(S\T/S8_/3]`/T4_5#]8/V0_9S]]/XD_G#^G/Z\_M3^W/\D_WC_A/^D_
M#4`40!A`,T`U0$=`/8&=0)Y`RT#40-5`W4#X0!Q!*T$P03=!/H&-03^!O$&Y
M04"!(D(^0D-"5D):0F]"A4+$0M9"_$(*0QA#.4-#0V5#?$/E0^U#]4,01!1$
M(D1Y1%%$8$1M1,Y$OD2_1,1$RD301/=$^T0B12E%08%G19U%0H$`1@E&%48>
M1CI&(D8D1BM&,$8Q1C-&^T9(1DQ&Q*=91EI&849E1G-&=T9X1HU&0X&@1K)&
MNT;&1LA&(AO;1NA&^D831RF`,T=F1T='2$=[1X%'DT>81YM'NT?Y1\!'UT?\
M1P%(4D@=2"Q(,4A;2')(=4A$@:-(I4BR2,A(T$CH2.U(\$CQ2/Q("DE)2<2J
M-4E"25=)8TED26A)@$D4@:5)K4G/2;8;PQOB2>E)ZDGU2?9)#TH52C^L.TH^
M2D5*4$I62EM*:TIS2F.LB4J42IU*GDJE2N1*YTH/'!V`&TL>2RQ+-4M&2U9+
M8$ME2V=+=TN"2ZE+K4MP@,]+UDO72_]+!4P03#-,64Q<3*I,=$QV3(5,ADR8
M3)Q,^TS&3-1,X$SK3.Y,_J\$30Y-+DTQ33E-/TU8365-18&"38=-B4V43:I-
MK$V_3<1-UDW:3=M-W4W\34:!-$Y$3EQ.7DZK3K%.P4['3LY.$$\:3T>!*D\O
M3S-/44]93UY/84]B3WY/B$^,3XU/E$^@3Z=/MD^\3\=/RD_Y3_!/]4\%4`90
M*%!*4%U07E!.4&10=5"%4*10JU"W4-10V%#D4`]1*U$>42!1+E$P44911U%1
M44B!4E%<46!1:%$5@851AU&24<%1NE'$4?Y1`%(54E525E(_'HU2FU*^4L!2
M^U+QMB=3*%,6@5!39E-\4Y53GU.@4Z)3IE.K4\E3SU/64]E3XU/I4P=4"E0:
M5!M42H$F5"A4*E0K5"Q4+E0O5#!41%1&5$=42U175&)4:U1M5(94AU2)5)A4
MG%2?5*-4D%2F5*A4J52U5+]4R%3)5-I4_U0!51=5+U5O57E5DE5R'\Y5Y%4`
M5@)6"%855A96&58>5BU6-59#5DM69%9E5FU6;U9Q5H%6FU:=5IY6IE:J5K96
MQ5;,5LY6U%;F5O%6_%8*5QE7-%<V5T9735=.5UQ77U=B5WI7@%>45ZI7X%<M
M6([`0UA.6$]845AH6&Y82X&P6`[!K5CD6/)8`%GW6!Q9+EDQ63193(%-@459
M1EE.@4^!4(%<65&!&8$:@7E94H%3@1N!F%FQ6;A9R%G*67'"U%G>6>M9[5D#
M6E2!.5I=6FU:58&%6J!:Q,.S6KM:SEKK6OU:$ELM6SM;1UM.6V!;;5MO6W);
MGEM6@==;V5L!7#%<'EP@7#-<-EQD(J'&65QM7'E<CUR47*!<O%S57-E<W5P'
M70A=$UT=72-=,5U!74A=4UU<77I=@UV+7:!=IEW"7<Q=UEWC75>!*%X(7A%>
M%5Y9@4=>4EYA7HI>C5Y'7UJ!D5^77[]?SE_;7]]?[%_N7_I?6X$48"9@-6`W
M8#Q@RF#78.!@\V`884IA8&%G86AA;6&[8<IASV'785R!4R1;)&!B=&+_T8YB
MH6*C8J1BJ6*N8K=BOF*_8L9BU6+]8OYB`&,!8V)C(F,M8SIC0V-'8U%C56-]
M8X9CDF.88Z=CJ6._8\!CQV//8]%CX6/J8P%D!F0*9%^!2&1?9'!D<V2%9)YD
MKV2T9+IDP&3"9$#3,F4>92-E+V59961E'X&M97IEC&6/9:)EL&7+9<YE[642
M9O]E!&8%9A!F=-489BEF.&979EMF-H!B9ITE;&9U9IAFN&;Z9OQF_68+9W%G
MAV>(9ZQGK6>U9^HEUF?L9P9H"F@0:!1H'VB8:*IHRFC.:(37]6@<:6"!&&D9
M:1II)VDP:3)I.6E`:91I88'4:>5I]FD2:A5J(FHW:D=J3FI=:F%J=6IY:J=J
MT&K?:O1J]FHB@6*!8X%&:U1K66MI:YUK26QH;&2!X6ST;/AL_FQE@1)M&VVO
M;<YMT6W7;2!N(VX];G!N>VYWX,!N1"CZ;AYO+6\V;U1O3>&F;[5OY&_H;^YO
M"'`M<&>!B'"5<)=PF7";<*)PLW"^<,1PQ7#'<-=PW7#><.]P]'`F@11Q%7$6
M<2)Q(W$G<2]Q,7$T<3UQ2'%;<8-QGG&L<;%QO''7<?MQY''E<>UQ\7$'<A!R
M.'(Y<CIR/')`<D-R3W)X<HARPG++<LQRTW+@<O]R!',?<R%S)7-(<TES2G-D
M<V5S:G-P<YMSHW.Z<\9SWG/?<P1T_7,S=$IT8W1K='%T<G2.=9]UIG6I=:QU
MMG6]=<MUT'73=;`IVG7>=5AVA';<@)UVI':E=M)VWG9H@>EV[W8S=SMW37=.
M=T]W6G=N=W-WE7>N=[IWP7?)=]YWVW?T=VF!"G@>>"MX,'AJ@5)X4WA6>%=X
M67A:>-"`97AL>+IXR'CG>%AYGGD">@-Z)'HM>BYZ.'I*>DYZ4GJV>L%ZPWK.
M>M9Z^7H">PA[('L7+"U[7GMY>V9[<GMU>X1[BGN/>YY[IWO!>\Y[Y7OX>_U[
M`'PC?$%\3WQ0?%-\8WQE?'=\'7T>?4-]1WU2?6-]<'U\?8I]EGW`?:Q]O'W7
M?9#UYWT'?A5^?'Z>?J1^K'ZO?K1^M7[#?M%^$'\Y?U=_D'^4?Y=_HG\`````
M````````B80"+@\N$BXI+BLN+BY`+D<N2"ZBA%$N!A2DA%HN:2Z=+BP4+A2Y
M+KLN(H6\+L,NR"[0+NLNVB[Q+O4N`"\6+V0O-R\^+U0O6"^3A7<O>"]Z+WTO
M@B^%+Y(OFB_F+[(OOB_%+\LOSR_2+VH4\B\`,!`P$S`<,!XP(C!H%$(P1C!.
M,%,P5S!C,&8P:C!P,*,PB#"2,),PE3"6,)PPJC`KAK$PNC"[,,0PQS#S,(&&
MSC!QAM0PV3#A,.DPDA0(,?F&%S$;,4J'8#$)B',Q@S&+,;P4F#&C,:TQQQ2\
M,=:(*(GS,?0Q`C(2,A8R3XI5,EPR;#)W,H0R@C('BY@R.HND,J8RKS*Z,KLR
MRC(?%=$RN8OW,@HS"S,D,S4S/C-",WR,G8QG,VPS>C.D,[0S4XVW,\`SG8U=
M%5X5U3/:,V,5]#/U,U4T)#0H-&X50S1B-&8T;#2*-(TTE32@-*8TK32N-+<T
MNC2_-,,T18[L-.\T\33S-``U`34)-3PU036F%4<U2C6H%6`U835D->&.?36"
M-8@UD37%%=(UE8]MC[\UR37,-=$UW37:%>(U9(_I-2@V7Y`'-A`V,#8W-O05
M/38_-D`V1S9>-F`V;38%%H@VC#:5-IHVG3:H-JTVLC;%-LTVWS;H-O8V]S8!
MD14W(S=5D2DW>Y%%-T8W3#=--W21:#=O-W,W=#=U-WLWY)'7D:PWFC>=-YXW
MJ#?7-_V1S#<VDD22WC?F-_`W2A;X-_LW_3<$.!XX(#@G.#(X.3C$DDDX3#AG
M.(HXBSB-.(\XD#B4.)TXJCBQ.&V3PSC-..(X\SCT.`4Y!CD+.0TY%#DD.=>4
MD18].9D61CF6%BG26SE?.4>5=3EV.7PYGSFN.;PYR#G-.=XYXSGD.><Y[CD&
MED*6SQ8,.@TZ%SHG.BTZ53IE.GHZBSJ<.I\ZH#JB.K$ZLSJU.KHZOSK:.MPZ
MX#KE.O`Z[CKU.@`["#L7.S0[+3M,.U([:#MO.WP[?SN!.X0[PYB6.ZP[81?`
M.V(7SCO6.VP7:Q?Q._T[=1<#/"D\,#Q6F5\\8SQG/&@\:3QP/"V:19I\/'B:
M8IJ(/(H\P1>AFIR:H#RB/*8\ISR2FJT\M3RWFLD\X)HSFP8]$#TK/1T](#TD
M/28],3TY/4(]Z!=A/6H]]!=P/1Z<_1>(/0`8DCV4/9<]F3VP/;(]M#UVG+D]
MT3W7/=@]X#WZG.0]Z3TO&``^-A@2/A4^0!@?/BX^/CY)/EP85CYA&&L^;#YM
M/FX^>YVE/JH^K#ZY/K\^QC[2/MD^'I_]/@@_#C\</ZV?'C]'/V,_<C]^/X\_
MHC^D/[@_Q#_Z&,<_RS_2/],_U#_B/^X_[S_S/_P_%QD70")`)$`:&4Q`?T"*
M0)5`J$#SH+!`L4"^0,A`V4#;0.Y`\D#U0!!!$D$301E!'D$Z06\904%&06!!
M?$%;H9)!DT&709A!I4&H0:U!JZ'50=U!WT'U08^B%4(C0BE"1D),0E%"4D)A
M0F1">T)M0G-"F4*F0M5"N*/]0@-##4,00T^D4*0R0S5#.T,\0T%#1$-.0T:D
M64,=I::D;$.$0YE#)*640[U#]T/40]5#W$/@0^M#[$/R0PE$'D0E1"E$+T1:
M1%M$741S1'U$AT211)U$GT3+1,Q$U4371.&FY$3E1/]$!$5N&@]%%$4617,:
M'D4R141%5$5K17I%@46$185%BD6R1;5%N$6_1<)%R4741=8:\D7Y1?Q%!$8(
M1B%&*D9%1E%&3D;J&L.G5T9;1F-&]:>VIVI&:T9L1FU&>T:`1I!&DD:91@X;
MK4:Q1K5&&AN_1AP;[$;7&@%'!4<21W*H&4?3J-*H3$=-1U1'74?0J.2HU:AT
M1W9'VJB21]^H8V,02+!'LD?#1\A'TD?91]M'\$?W1TJI4:E+J1A('T@M2&6I
M,T@[2#Y(1$A%2$E(3$A52%=(=QMK2&Y(>DA\2()(D$B62&T;F$B92)I(G$BJ
M2*M(M$B[2/M(Y*E:JA.!PTC%2,Q(STC62-E(Y$CE2.Q(]T@#20=)AQN(&Y2J
M.TF-&T9):4EL27))>DE_29))I!N629A)IDFP2;=)NDF\2<!)T4G623FK1ZLP
M2CBK.JOC2>Y)[TGS2<T;]$G^21%*&DH=2ARL,DHS2C1*/TI&2DE*>DI.2E)*
M9$H,K'Y*@TJ+2O`;D4J?2J%*9*RK2KU*QDK42M!*W$K=2O^LYZSL2O%*\DKS
M2OU*)*T+2P]+$$L12SVM%TLF'"]+2DM82VQ+=4MZ2X%+FTNN2YBNO4N^2\=+
MR$O)2]I+YDOG2^Y+\4L"3`I,#DPU3#9,.DQ_KS],34Q;3&U,A$R)3,,<E$R5
M3)=,K4S"3-!,TAS63-I,W$SI3.Q,[4P`L`!-"DTD329-)TUG3"]-/$U;35Y-
M8$UP38!-@4V*38U-D4V834"P%T[ZL/FPT["K3:Y-M$W"331-R$W.3<]-T$W?
M3>E-]DTV3AY.(DXG3A$=,DX\3DA.24Y+3DQ.3TY13E-.5$Y73F-.'AV33J=.
MM$Z_3L-.RD[93C5/ZT[Y3OM."D\,3QA/)4\V3SQ/?K%23U=/6D]@3VA/F$]]
M3Y!/ED^^3Y]/I4^O3V0=M4_(3\E/VD_>3^E/EK+\3P!0!U`*4"-0`[,Y4#I0
M/%!#4$=02U":'51095!I4&Q0;E!V4'Y0@5"&4)50EU"[4,:SGU"Q4/ZS[%#*
M4-%0TU#<4`-1!%$&40=1"%$,4<`=+U$Q45!12E%345Y1U!V648!1FU&@4:)1
MKE&O4;-1O+3+4=-1V5'<40=2!1Y)@2M2-%(X4CE2+"Y"4E-25U)C4BFU;E)O
M4GA2?U*.4J6UK5*N4K!2L5+!4F`>S%)F'F@>\U+Z4@=3$E,84QE3@QXY4RQ3
M,5,S4SU34E.4'FM3;%.6MVY3;U-Q4W=3@5.%4XI3E%.84YQ3GE.E4ZA3M5.W
M4[E3O%._4\53RU/A4^=3^5,35/I3`50D5#%4.5135$!40U1-5%)4751Q5(%4
MA52(5$VXDE275)E4H%2A5*54JE2K5+E4NU2Z5-94V%3>5.]4ZU16N?I4;[D@
M5215*E57'Q:Z/54^54!52%5.55!54E5L57)5<55Z57U5?E6!512[C%5U'Z)5
M=Q^P5;=5OU7`5<95SU735=U5WU7@5>=5[%7N5?%5^54#5AA6!U8/5JX?#KP3
M5AM6'%8WO"56*%8\5C-6:KS)'T%6B[Q)5E56UQ]N5I56G%:A5J!6IU:H5J]6
M2KW)5E6]Z%;L5B*^%U<:5RU7-5>IOCD@Y;[-OEA78%=J5QZ_<E=\5WU73+]8
M()I7GU>B5Z17J5?>5]]7Y%?F5^I7[%>3(/!7]%?[5R[`!5@&6`E8#5@96"%8
M+%A'6&18:EC9P(I8E%BD6)U8GEB?6+M8R%C,6,Y8U5C@6.%8YECY6/I8^UC^
M6*?!$%D;63!9)5D[64I96%E;604A9UER6919E5F669M9H5FI6;19NUG"6<=9
MS%G-6=992"&IPK3"3R$*6A%:%5H;6AY:8R$M6CA:1UI,6E9:65I<6E]:8%IG
M6FI:=5IX6H):BEJ06J-:K%K4P[0AN5J\6KY:OR',6M%:YUKH6O1:Y,3CQ`=;
M\<0]6R=;*ELN6R];,5OF(?,A?UM!6^XA55MY6V1;9EMI6W-;,L4'(I!;D5N;
M6PXBKUNU6[Q;Q5O*6\O%Y,746]9;VEOJ6_!;`UP+7`Y<#UPF7$5<2EQ17%=<
M7EQA7&E<;EQO7'!<+L=6QV7'IEQBQ[9<MUR_7-C'Q%S"Q\A<S5SHQ]=<(\CF
M7.M<7,CU7`-="5W&(A)='EW@R-3(/5T^74!=1UT,R?O(UB)975I=:EUP7=TB
M?UT7R89=B%V,79==8,F=7:==JEVV7;==P%W77=E=YEWQ7?E=`B/MR5B!$%X7
M7AU>(%XG7BQ>15YS7G5>?EZ&7H=>*R.17IA>FEY#(SQ?.U\^7T-?1%]/7\$4
M<,I27X;*85]C7V1?;5]]7WY?3,N07WLQ#K"67YQ?K5\"S,-?SU_C7^5?[U_R
M7P)@"F`(8`Y@$6`68"1@+&`P8$-@9F!Q8'5@>V"98)Q@I&"G8+A@?LW%8-5@
MV&#F8+#-#6'U8/M@[B,U819A'F'P(R1A)V$L81W./6$()&EA%R2!81PDA&&%
M82(DF&&R8<%APV'68=MAW<_D8>K/[&%1T/UA_V%OT`1BW=`98B%B(F(>T3)B
M-&(\8D9B26)%8EC12V)V)$]B>B178HS17&)C8K?178%>@7EBD21]8G]B@V**
M8I-BIV*H8K)BM&*Z8KQBXF+H8O=B!V,(8PQC5&,;8QUC,&,\8T1C5V.^)']C
MU"2S)(UCE&.58YMCG6/)8]!CU&/=8^5C^6,/9!%D%61STA=D.61*9$]D4612
M9%ED6F1<9-W2961V9'AD?&2!9`TEW&279*9DOF0()<YDSV339&73YV3J9.]D
M\&3Q9/ID_60,91ME)&4E92ME-&5/96]E)25#)3YE465395YE865B9934>V5]
M97]E@66&99-EG66?9?C4]M3WU+=EO&7'9<IEV&799=]EX67F9?9E`&819AYF
M(68D9B=FC=4Y9CQFN=5`9B"!4V969F]F=V9Z9H=FB6:-9I%FG&:=9JAF(8&Q
M9K-FP6;#9M%FU6;79N-FYF:X)05G!V<.9Q!G$V<99Q]G(6<C9S%G.F<^9T!G
M0V=19UAG9&=E9W)G?&=;UEK6IV>)9XMGDV>@9W[6Y26^9Y#6P6?.9_5GWV?)
MUN-GY6?F9^IGZV?M9P%H`V@+:!-H*&@N:#)H/&@/)DIH6&A?:&1H%=<4UVEH
M,==O:*!HO&B]:+YHP&C2:)/7T6C3:-MH\&CQ:$$F`6D.V#=I(]A":45I26E2
MV&4F8FF`:8EID&F?:;!IMVG6:=AIZVFA)O%I\VG]:?]IKR81:A1JA=DA:C5J
M/FI%:DUJ6&JN:I!JMVJ^:M=J_&J$V@IK!6L-:QQK'VLM:T-K#"=1:UYK=FM_
M:X%KBVN4:Y5KG&N>:SELL]L];+[;Q]M%;$=L3VQ4;%=L:6QM;'-LN-R3;))L
MF6QD)YMLI&S6;-5LV6P@W?!L\6R0W0EM#FUL;81ME6VF;;?>QFW(;=EM[&T,
M;OTG_6T&;HK?%&X6;B%N(FXG;KO?%B@V;CEN2VY4;F)N;&YM;F]NF&Z>;JYN
MLVZU;K9NNVZ"X-%NU&Y.*/EN\^``;PAO%V\K;T!O2F]8;XSAI&^T;V:!MF_5
MX<%OQF\D@<IOS6_3;]5OX&_Q;_5O^V\"<`QP-W!KXD-P1'!=<,CBR>*%<(QP
MD'`==J%PM2BP<+9PPW#(<-?CW'#?</KC]G#R<`!QZW#^</]P!'$&<1AQ''$>
M<3=Q.7$Z<49Q1W%7<5EQ87%D<71Q>7&%<8YQJ'&N<;-QMG'#<<1QVG%)Y$;D
M[''N<0%R"G(6<A=R:^0S<D)R1W)*<DYR47)6<EER8')A<F5R9W)H<H?DB.1\
M<GUR?W*)<HUREW*9<I]RIW*K<KKDN^2R<K]RP'+&<LYRT'+7<MERY7+G<A%S
M'N4IY?=R^7+[<@)S#7,5<QUS'G,G<RES<>5#Y4=S47-7<UIS:W-Q<W-SH7.9
MY<WEB'.+<X]SGG/U<^3EW>7Q<\%SQW/<<^)SYW,)=`]T%G07=/MS,G0T=#MT
M173!YN_F;71O='AU>76&=8QUC740YZMUM'5QY\AU^^<?Z"QV,W8T=C;H/'9!
M=F%VB>B"=NOHFG8RZ><IJ7:O=K-VNG:]=OHI^.G8=MIVW78$*A1W(W<I*C9W
M07='=U5W5W=;=VIWH.JQZI9WFG>>=Z)WL7>R=[YWS'?1=]1WV'?9=^%W\7<$
M>`UX#G@4>!9XO"J0ZR-X,G@S>"5X1WAF>*MXK7BP>,_LMWBX>+MXO'B_>,)X
MQWC+>.!X?^WA>.-XY7CJ>/!X\7CS>`AY.ROP[19Y%WD9[AIY&WD<>5#N,7DR
M>3-Y.GD[>3QY0'E!>49Y37E.>5QY7WE@>:-YIGFY>;UYOWG#><EYU'G9>=YY
MQN_P>?EY_'D*>A%Z%GH:>B!Z,7HV>D1Z3'I8>L(KKWK**[=ZTBNY>G+PQGK0
M>M)ZU7KH*]QZX'KE>NEZ`WL,>Q![$GL6>QQ[*WLS>SU[("Q+>V-[97MK>VQ[
M<WMV>W=[IGNL>[%[V_$]\K)[N'N^>\=[\WO8>]U[YWOJ>^M[[WON>Q7R^GN*
M\O=[2?(6?!A\&7P:?!U\(GPG?"E\*GS$\C%\-GPW?$5\7'SI\DE\2GS;\E1\
M6'Q;?%U\7WQI?&I\:WQM?&Y\<'QR?'5\>GSF?/)\"WT"?<[S$7T7?1A]+_3$
M+!KT,GW1+$)]2GU??6)]^?1I?6M]@O1S?79]=WU^?81]C7V9?:%]OWVU?;E]
MO7W#?<=]R7W6?=I]WWW@?>-]]'T'+0I^`GX-?AE^''X=?GM^&)Z`?H5^FWZH
M?@SVO7ZW]M]^YW[N?O]^`G]W+0-_%W\9?R]_-W\Z?SU_07]%?T9_4W]5?UA_
M\?==?P+X:7\:^&U_<']U?[+X`````````````````````(2&A8:`AH:&>X5C
MAE>&9X96AFF&3X9KAF*&;897AFB&5H9JAD^&;(9BAFZ&J8+U@JN"]H*M@O>"
MKX+X@K&"^8)*@Y>#3(.8@TZ#F8-0@YJ#4H.;@UJ#G(-C@YV#9X.>@_.#]H,`
M````````````````````````````````````Y*OEJ^"KYJO<J<2KN*O(J[>K
MRJNPJ\RKPZO.J[BKR:NWJ\NKL*O-J\.KSZNKI/>DK:3XI*^D^:2QI/JDLZ3[
MI*NE]Z6MI?BEKZ7YI;&E^J6SI?NENZ7\I<2E_:7(I?ZE]:;XI@``````````
M``````````````````````````#$`+,```````````#:````OP```,````#9
M````PP````````"T`````````,(`````````P0````````#%````````````
M`````````````,VZU=;)N+>[U-/(OKV\QL?,M;:YT=++S]#*V-?.````````
M`````````````````-\```#<````VP```-T```#>L+&R````````````````
M_@``````````````````````````````````````````\```]`#V^```````
M````@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBI
MJJNLK:ZOX.'BX^3EYN?HZ>KK[.WN[P#Q``#U`/?Y````````````````````
M``````````````````````````````````````````````````````#R\P``
M`````/\```#]````````````````````````^@````````````````````"1
M)9(EDR4")20E825B)58E525C)5$E5R5=)5PE6R40)10E-"4L)1PE`"4\)5XE
M7R5:)50E:25F)6`E4"5L)6<E:"5D)64E6258)5(E4R5K)6HE&"4,)8@EA"6,
M)9`E@"5`!$$$0@1#!$0$101&!$<$2`1)!$H$2P1,!$T$3@1/!`$$4020!)$$
M!`14!`8$5@0'!%<$MP`:(A8AI`"@):``Q`"S````````````V@```+\```#`
M````V0```,,`````````M`````````#"`````````,$`````````Q0``````
M``````````````````#-N@``R0``NP``R```O```S```N0``RP``R@``S@``
M``````````````````````#?````W````-L``````````+"QL@``````````
M`````/X```````````````".``"+C````````````````````````._WA@"-
MCY``D@"5F*&DI::GJ*FJK*VUMK>XO;[&QP#/T-'2T]35D9:;G9Z?_-;7V-W>
MX.'BX^3EYN?HZ>KK[>SN\O/T]OJ@^Z*C_0``````````````````````_P``
MG```BO7YEP"NB?```/CQF9H```"(````KP"K``#]__W__?_]__W__?^&`_W_
MMP"L`*8`&"`9((@#%2")`XH#J@.,`_W__?^.`ZL#J0"/`[(`LP"L`Z,`K0.N
M`Z\#R@.0`\P#S0.1`Y(#DP.4`Y4#E@.7`[T`F`.9`ZL`NP"1)9(EDR4")20E
MF@.;`YP#G0-C)5$E5R5=)9X#GP,0)10E-"4L)1PE`"4\):`#H0-:)50E:25F
M)6`E4"5L):,#I`.E`Z8#IP.H`ZD#L0.R`[,#&"4,)8@EA"6T`[4#@"6V`[<#
MN`.Y`[H#NP.\`[T#O@._`\`#P0/#`\(#Q`.$`ZT`L0#%`\8#QP.G`,@#A0.P
M`*@`R0/+`[`#S@.@):``Q`"S````````````V@```+\```#`````V0```,,`
M````````M`````````#"`````````,$`````````Q0``````````````````
M``````#-NM76R;BWN]33R+Z]O,;'S+6VN='2R\_0RMC7S@``````````````
M``````````#?````W````-L```#=````WK"QL@```````````````/X`````
M````J0```````````````````/3U`````````/G[````[`````````````#O
M````````````````````````````````````````]P``````````````````
M`````````````/```//R````````````````````````````X@````#I````
M`````````.0``.@``.H`````````X```Z^X`````````````XP``Y><`[0``
M`````````/^M`)RO``````"FKJH```#X\?T``.8`^@``IP"LJP"H`````(Z/
MDH``D`````````"E`````)D`G0```)H``.&%H(,`A(:1AXJ"B(F-H8R+`*25
MHI,`E/:;EZ.6@0``F,<`_`#I`.(`Y`#@`.4`YP#J`.L`Z`#O`.X`[`#$`,4`
MR0#F`,8`]`#V`/(`^P#Y`/\`U@#<`/@`HP#8`*<@D@'A`.T`\P#Z`/$`T0"J
M`+H`OP`0(ZP`O0"\`*$`JP"D`)$EDB63)0(E)"5A)6(E5B55)6,E4257)5TE
M7"5;)1`E%"4T)2PE'"4`)3PE7B5?)5HE5"5I)68E8"50)6PE9R5H)60E9259
M)5@E4B53)6LE:B48)0PEB"6$)8PED"6`);$#WP"3`\`#HP/#`[4`Q`.F`Y@#
MJ0.T`QXBQ@.U`RDB82*Q`&4B9"(@(R$C]P!((K``&2*W`!HB?R"R`*`EH```
M`````/```,'"HL.EQ```````Q@#'J*D`R`#)`*H`R@"K`,L`K0#,`*X`S0"O
M`,X`SP#0`-$`T@"\`-,`O0#4`+X`U0#K`-8`UP```-@```#?Q=GL[NW:][H`
MX0#X`.(`_`#C`/L`Y`#O`.4`\@#F`/,`Y_3H`.GU_?;J`/GZF9H``)V>````
M````````````````````````````````A0"&````````````C0```(P```".
M````CP```(H`````````B`````````")`````````(L`````````AP````""
M@P```)$`````````````````````````````````````````````````````
M`)8`````````````````````````K```````````````````NP```+\`````
M`````````````````````````````````````.``````````````````````
M\0``````````````````L+&RL[2UMK>XN24`````````````````````````
M`````````````*``P*.D`-L`````E]RA``"`DP``````@0```)B5E```````
M``````````````````````````#>````````````````````````````````
M`````````-T@(2(C)``F)[``MP`9(AHBDB4`)0(E/"4D)2PE'"4T)1`E#"44
M)1@EL@,>(L8#L0"]`+P`2"*K`+L`]_[X_OW__?_[_OS^_?^@`*T`@OZC`*0`
MA/[]__W_COZ/_I7^F?X,!IW^H?ZE_F`&809B!F,&9`9E!F8&9P9H!FD&T?X;
M!K'^M?ZY_A\&H@"`_H'^@_Z%_LK^B_Z-_I'^D_Z7_IO^G_ZC_J?^J?ZK_JW^
MK_ZS_K?^N_Z__L'^Q?[+_L_^I@"L`/<`UP#)_D`&T_[7_MO^W_[C_N?^Z_[M
M_N_^\_Z]_LS^SO[-_N'^??Y1!N7^Z?[L_O#^\O[0_M7^]?[V_MW^V?[Q_J`E
M_?\@`"$`(@`C`"0`:@8F`"<`*``I`"H`*P`L`"T`+@`O`,0`LP``````````
M`-H```"_````P````-D```##`````````+0`````````P@````````#!````
M`````,4`````````````````````````S;K5ULFXM[O4T\B^O;S&Q\RUMKG1
MTLO/T,K8U\X`````````````````````````WP```-P```#;````W0```-ZP
ML;(```````````````#^`````````*D```````````````````#T]0``````
M``#Y^P```.P`````````````[P``````````````````````````````````
M`````/<```````````````````````````````#P``#S\@``````````````
M`````````````.(`````Z0````````````#D``#H``#J`````````.```.ON
M`````````````.,``.7G`.T```````````#_`)N<F`"@CZ0``*ZJ``"G^/']
MIJ'FAOJE``"OK*NM`(X`A`````"`D9"2E```J)4`````F0````"=`)Z:``#A
MA0"#`````(>*@HB)``",BP```**3``#V`)>CEH$```#'`/P`Z0#B`,(`X`"V
M`.<`Z@#K`.@`[P#N`!<@P`"G`,D`R`#*`/0`RP#/`/L`^0"D`-0`W`"B`*,`
MV0#;`)(!I@"T`/,`^@"H`+@`LP"O`,X`$".L`+T`O`"^`*L`NP"1)9(EDR4"
M)20E825B)58E525C)5$E5R5=)5PE6R40)10E-"4L)1PE`"4\)5XE7R5:)50E
M:25F)6`E4"5L)6<E:"5D)64E6258)5(E4R5K)6HE&"4,)8@EA"6,)9`E@"6Q
M`]\`DP/``Z,#PP.U`,0#I@.8`ZD#M`,>(L8#M0,I(F$BL0!E(F0B(",A(_<`
M2"*P`!DBMP`:(G\@L@"@):``Q`"S````````````V@```+\```#`````V0``
M`,,`````````M`````````#"`````````,$`````````Q0``````````````
M``````````#-NM76R;BWN]33R+Z]O,;'S+6VN='2R\_0RMC7S@``````````
M``````````````#?````W````-L```#=````WK"QL@```````````````/X`
M````````J0```````````````````/3U`````````/G[````[```````````
M``#O````````````````````````````````````````]P``````````````
M`````````````````/```//R````````````````````````````X@````#I
M`````````````.0``.@``.H`````````X```Z^X`````````````XP``Y><`
M[0```````````/^M`)P`````````KJH```#X\?T``.8`^@```*^LJP"H`*0`
M`(Z/DH``D````*4``(L``*8``)D`G0"G`)J7C>&%H(,`A(:1AXJ"B(D`H0``
MC```HI,`E/:;`*.6@9B5`,<`_`#I`.(`Y`#@`.4`YP#J`.L`Z`#0`/``W@#$
M`,4`R0#F`,8`]`#V`/X`^P#=`/T`U@#<`/@`HP#8`*<@D@'A`.T`\P#Z`,$`
MS0#3`-H`OP`0(ZP`O0"\`*$`JP"[`)$EDB63)0(E)"5A)6(E5B55)6,E4257
M)5TE7"5;)1`E%"4T)2PE'"4`)3PE7B5?)5HE5"5I)68E8"50)6PE9R5H)60E
M9259)5@E4B53)6LE:B48)0PEB"6$)8PED"6`);$#WP"3`\`#HP/#`[4`Q`.F
M`Y@#J0.T`QXBQ@.U`RDB82*Q`&4B9"(@(R$C]P!((K``&2*W`!HB?R"R`*`E
MH`#$`+,```````````#:````OP```,````#9````PP````````"T````````
M`,(`````````P0````````#%`````````````````````````,VZU=;)N+>[
MU-/(OKV\QL?,M;:YT=++S]#*V-?.`````````````````````````-\```#<
M````VP```-T```#>L+&R````````````````_@``````````````````````
M````````````````````^?L```#L`````````````.\`````````````````
M``````````````````````#W````````````````````````````````\```
M\_(```````````````````````````#B`````.D`````````````Y```Z```
MZ@````````#@``#K[@````````````#C``#EYP#M````````````_ZV;G```
M`````*:NJ@```/CQ_0``Y@#Z``"GKZRK`*B1AH^.````@)*0B0"8BP```*6I
MGXR9````G98`F@``X86@@X0```"'BH*(`(VA````I)6BDY0`]@"7HP"!````
MQP#\`.D`X@#C`.``P0#G`.H`R@#H`,T`U`#L`,,`P@#)`,``R`#T`/4`\@#:
M`/D`S`#5`-P`H@"C`-D`IR#3`.$`[0#S`/H`\0#1`*H`N@"_`-(`K`"]`+P`
MH0"K`+L`D262)9,E`B4D)6$E8B56)54E8R51)5<E725<)5LE$"44)30E+"4<
M)0`E/"5>)5\E6B54)6DE9B5@)5`E;"5G)6@E9"5E)5DE6"52)5,E:R5J)1@E
M#"6()80EC"60)8`EL0/?`),#P`.C`\,#M0#$`Z8#F`.I`[0#'B+&`[4#*2)A
M(K$`92)D(B`C(2/W`$@BL``9(K<`&B)_(+(`H"6@`,0`LP```````````-H`
M``"_````P````-D```##`````````+0`````````P@````````#!````````
M`,4`````````````````````````S;H``,D``+L``,@``+P``,P``+D``,L`
M`,H``,X`````````````````````````WP```-P```#;``````````"PL;(`
M``````````````#^`````````````````````````````````````````/^M
MO9S/OMWU^;BFKJKPJ>[X\?W\[^;T^O?[IZ^LJ_.HM[6VQXZ/DH#4D-+3WM;7
MV-&EX^#BY9F>G>OIZIKMZ.&%H(/&A(:1AXJ"B(F-H8R+T*25HI/DE/:;EZ.6
M@>SGF,<`_`#I`.(`Y`#@`.4`YP#J`.L`Z`#O`.X`[`#$`,4`R0#F`,8`]`#V
M`/(`^P#Y`/\`U@#<`/@`HP#8`-<`D@'A`.T`\P#Z`/$`T0"J`+H`OP"N`*P`
MO0"\`*$`JP"[`)$EDB63)0(E)"7!`,(`P`"I`&,E4257)5TEH@"E`!`E%"4T
M)2PE'"4`)3PEXP##`%HE5"5I)68E8"50)6PEI`#P`-``R@#+`,@`,0'-`,X`
MSP`8)0PEB"6$):8`S`"`)=,`WP#4`-(`]0#5`+4`_@#>`-H`VP#9`/T`W0"O
M`+0`K0"Q`!<@O@"V`*<`]P"X`+``J`"W`+D`LP"R`*`EH`#$`+,`````````
M``#:````OP```,````#9````PP````````"T`````````,(`````````P0``
M``````#%`````````````````````````,VZ``#)``"[``#(``"\``#,``"Y
M``#+``#*``#.`````````````````````````-\```#<````VP``````````
ML+&R````````````````_@``````````````````````````````````````
M``````````"FIP````````````````````"8C0``````````````````````
M````````````````````````````````````GI\`````````````````````
M``````````#_K;V<S[[=]?FXT:ZJ\*GN^/']_._F]/KW^]"OK*OSJ+>UML>.
MCY*`U)#2T][6U]@`I>/@XN69Z)WKZ>J:``#AA:"#QH2&D8>*@HB)[*&,BP"D
ME:*3Y)3VFY>CEH$``.W'`/P`Z0#B`.0`X`#E`.<`Z@#K`.@`[P#N`#$!Q`#%
M`,D`Y@#&`/0`]@#R`/L`^0`P`=8`W`#X`*,`V`!>`5\!X0#M`/,`^@#Q`-$`
M'@$?`;\`K@"L`+T`O`"A`*L`NP"1)9(EDR4")20EP0#"`,``J0!C)5$E5R5=
M):(`I0`0)10E-"4L)1PE`"4\)>,`PP!:)50E:25F)6`E4"5L):0`N@"J`,H`
MRP#(`/W_S0#.`,\`&"4,)8@EA"6F`,P`@"73`-\`U`#2`/4`U0"U`/W_UP#:
M`-L`V0#L`/\`KP"T`*T`L0#]_[X`M@"G`/<`N`"P`*@`MP"Y`+,`L@"@):``
MQ`"S````````````V@```+\```#`````V0```,,`````````M`````````#"
M`````````,$`````````Q0````````````````````````#-N@``R0``NP``
MR```O```S```N0``RP``R@``S@````````````````````````#?````W```
M`-L``````````+"QL@```````````````/X`````````````````````````
M`````````````````(6!@X>)BXV/D9.5EP"9FZ&C[*VGJ>KTN+['T=/5U]WB
MY.;HJ[:E_/;ZG_+N^)W@H*+KK*:HZ?.WO<;0TM36V.'CY>>JM:3[]?F>\>WW
MG-X`A(""AHB*C(Z0DI26`)B:_P```,\``/T```"N`/``````````````````
MKP````!2!`($4P0#!%$$`014!`0$500%!%8$!@17!`<$6`0(!%D$"01:!`H$
M6P0+!%P$#`1>!`X$7P0/!$X$+@1*!"H$,`00!#$$$01&!"8$-`04!#4$%01$
M!"0$,P03!*L`NP"1)9(EDR4")20E100E!#@$&`1C)5$E5R5=)3D$&000)10E
M-"4L)1PE`"4\)3H$&@1:)50E:25F)6`E4"5L):0`.P0;!#P$'`0]!!T$/@0>
M!#\$&"4,)8@EA"4?!$\$@"4O!$`$(`1!!"$$0@0B!$,$(P0V!!8$,@02!$P$
M+`06(:T`2P0K!#<$%P1(!"@$300M!$D$*01'!"<$IP"@):``Q`"S````````
M````V@```+\```#`````V0```,,`````````M`````````#"`````````,$`
M````````Q0````````````````````````#-N@``R0``NP``R```O```S```
MN0``RP``R@``S@````````````````````````#?````W````-L`````````
M`+"QL@```````````````/X`````````]/H`````````````````````````
M````CX:2D0````````````````````"=FZ:GY.4``*BIY^@``````````)C5
M``"LGP````````````````````````#S````````````````````````QL>X
MK0```````````````.SM`````````````````+V^``````````````#_``"<
MSP``]?D``*X`\```^`#]_._F``#W``"O`*L``+>UM@".``"`U)#2T][6U]@`
MI>/@X@"9G@#KZ>J:``#AA:"#`(0``(>*@HB)C:&,BP"DE:*3`)3V`)>CEH$`
M``#'`/P`Z0#B`.0`X``)`><`Z@#K`.@`[P#N`.P`Q``(`<D`"P$*`?0`]@#R
M`/L`^0`P`=8`W``=`:,`'`'7`#4!X0#M`/,`^@#Q`-$`'@$?`20!)0']_[T`
M-`%?`:L`NP"1)9(EDR4")20EP0#"`,``7@%C)5$E5R5=)7L!?`$0)10E-"4L
M)1PE`"4\)5P!70%:)50E:25F)6`E4"5L):0`_?_]_\H`RP#(`#$!S0#.`,\`
M&"4,)8@EA"7]_\P`@"73`-\`U`#2`"`!(0&U`"8!)P':`-L`V0!L`6T!_?^T
M`*T`_?\3(4D!V`*G`/<`N`"P`*@`V0+]_[,`L@"@):``Q`"S````````````
MV@```+\```#`````V0```,,`````````M`````````#"`````````,$`````
M````Q0````````````````````````#-N@``R0``NP``R```O```S```N0``
MRP``R@``S@````````````````````````#?````W````-L``````````+"Q
ML@```````````````/X`````````````````````````````````````````
M`````````/,`````````````````````]/H`\@#Q``#_````SP``]?D``*ZJ
M\```^````.\```#W``"O``````"UM@".``"``)``TP#6UP````#@X@"9G@``
MZ0":[0#A`*"#`(0``(<`@@")`*&,`````**3`)3V``"C`('L`````,;'I*6/
MA@````"LG]+4T=````````"HJ;?8````````````````````````````````
M``````"1D@``E98``)V(X^0``-7E`````````(J+``#HZ@``_/V7F```N*WF
MY]WNFYP``````````-Z%Z_L`````````C:N]OJ:G`,<`_`#I`.(`Y`!O`0<!
MYP!"`>L`4`%1`>X`>0'$``8!R0`Y`3H!]`#V`#T!/@%:`5L!U@#<`&0!90%!
M`=<`#0'A`.T`\P#Z``0!!0%]`7X!&`$9`:P`>@$,`5\!JP"[`)$EDB63)0(E
M)"7!`,(`&@%>`6,E4257)5TE>P%\`1`E%"4T)2PE'"4`)3PE`@$#`5HE5"5I
M)68E8"50)6PEI``1`1`!#@'+``\!1P'-`,X`&P$8)0PEB"6$)6(!;@&`)=,`
MWP#4`$,!1`%(`6`!80%4`=H`50%P`?T`W0!C`;0`K0#=`ML"QP+8`J<`]P"X
M`+``J`#9`G$!6`%9`:`EH`#$`+,```````````#:````OP```,````#9````
MPP````````"T`````````,(`````````P0````````#%````````````````
M`````````,VZ``#)``"[``#(``"\``#,``"Y``#+``#*``#.````````````
M`````````````-\```#<````VP```-T```#>L+&R````````````````_@``
M````````[P``\J;W``````````````````````#_`):<GP"G]0"H`*ZJ\*D`
M^/']_`#F]/H`^P"OK*OS``````".CY(``)````````````#@`.69GIT```":
M``#A`````(2&D0``@@```````````*(`Y)3VFP```($```"@@P``M="`AP``
M``"VT0````#MB0``N-.WT@``````````E84```````"AC```O=0```````#H
MZ0```.KK`````*V(X^?N[```````XI,``````````(J+``"7F`````"^U0``
M````````Q]<```````#&U@``````C:6CI,_8``8!_`#I``$!Y``C`>4`!P%"
M`1,!5@%7`2L!>0'$`,4`R0#F`,8`30'V`"(!H@!:`5L!U@#<`/@`HP#8`-<`
MI````2H!\P![`7P!>@$=(*8`J0"N`*P`O0"\`$$!JP"[`)$EDB63)0(E)"4$
M`0P!&`$6`6,E4257)5TE+@%@`1`E%"4T)2PE'"4`)3PE<@%J`5HE5"5I)68E
M8"50)6PE?0$%`0T!&0$7`2\!80%S`6L!?@$8)0PEB"6$)8PED"6`)=,`WP!,
M`4,!]0#5`+4`1`$V`3<!.P$\`48!$@%%`1D@K0"Q`!P@O@"V`*<`]P`>(+``
M&2*W`+D`LP"R`*`EH`#$`+,```````````#:````OP```,````#9````PP``
M``````"T`````````,(`````````P0````````#%````````````````````
M`````,VZU=;)N+>[U-/(OKV\QL?,M;:YT=++S]#*V-?.````````````````
M`````````-\```#<````VP```-T```#>L+&R````````````````_@``````
M````````````````````````````````````^?L`````````````````````
M``````````````````````````````````````#W````````````````````
M````````````````\_(```````````````````````````````#J`.OL[0#N
M`._P`("!@H.$A8:'B(F*BXR-CH^0`)&2DY25EI?T]>'BX^4`F)F:FYR=GI^@
MH:*CI*6FIZBJJ:NLK:ZOX.3HYN?I`/\```````````````````#X\?T`````
M^@```````````````````````````````)$#D@.3`Y0#E0.6`Y<#F`.9`YH#
MFP.<`YT#G@.?`Z`#H0.C`Z0#I0.F`Z<#J`.I`[$#L@.S`[0#M0.V`[<#N`.Y
M`[H#NP.\`[T#O@._`\`#P0/#`\(#Q`/%`\8#QP/(`Y$EDB63)0(E)"5A)6(E
M5B55)6,E4257)5TE7"5;)1`E%"4T)2PE'"4`)3PE7B5?)5HE5"5I)68E8"50
M)6PE9R5H)60E9259)5@E4B53)6LE:B48)0PEB"6$)8PED"6`)<D#K`.M`ZX#
MR@.O`\P#S0/+`\X#A@.(`XD#B@.,`XX#CP.Q`&4B9"*J`ZL#]P!((K``&2*W
M`!HB?R"R`*`EH`#$`+,```````````#:````OP```,````#9````PP``````
M``"T`````````,(`````````P0````````#%````````````````````````
M`,VZU=;)N+>[U-/(OKV\QL?,M;:YT=++S]#*V-?.````````````````````
M`````-\```#<````VP```-T```#>L+&R````````````````_@````````"I
M````````````````````]/4`````````^?L```#L`````````````.\`````
M``````````````````````````````````#W````````````````````````
M````````\```\_(```````````````````````````#B`````.D`````````
M````Y```Z```Z@````````#@``#K[@````````````#C``#EYP#M````````
M````_ZV;G`"=`````*:NJ@```/CQ_0``Y@#Z``"GKZRK`*@`````CH^2@`"0
M`````````*4`````F0``````F@``X86@@P"$AI&'BH*(B8VAC(L`I)6BDP"4
M]@"7HY:!``"8QP#\`.D`X@#D`.``Y0#G`.H`ZP#H`.\`[@#L`,0`Q0#)`.8`
MQ@#T`/8`\@#[`/D`_P#6`-P`H@"C`*4`IR"2`>$`[0#S`/H`\0#1`*H`N@"_
M`!`CK`"]`+P`H0"K`+L`D262)9,E`B4D)6$E8B56)54E8R51)5<E725<)5LE
M$"44)30E+"4<)0`E/"5>)5\E6B54)6DE9B5@)5`E;"5G)6@E9"5E)5DE6"52
M)5,E:R5J)1@E#"6()80EC"60)8`EL0/?`),#P`.C`\,#M0#$`Z8#F`.I`[0#
M'B+&`[4#*2)A(K$`92)D(B`C(2/W`$@BL``9(K<`&B)_(+(`H"6@``$A<`$B
M>`$B-`$A,0$B,@$B,P$E;P$E;0$E;@$E<`$E;`$D=0$D=@$D=P$D>`$D>0$D
M>@$D>P$D?`$D?0$D?@$E(0$E(@$E(P$E)`$E)0$E)@$E)P$E*`$E*0$E*@$E
M*P$E+`$E+0$E+@$E+P$E,`$E,0$E,@$E,P$E-`$E-0$E-@$E-P$E.`$E.0$E
M.@$E.P$E/`$E/0$E/@$E/P$E0`$E00$E0@$E0P$E1`$E10$E1@$A.0$A-P$B
M70$A9`$A90$A9@$A9P$A+0$A+`$A:@$A:P$A;P$B(P$B:@$B(@$B:P$D*P$D
M+`$D+0$D+@$D+P$D,`$D,0$D,@$D,P$D-`$F-0$F-@$F-P$F.`$F.0$F.@$F
M.P$F/`$F/0$F/@$B6`$B50$B5P$B5@$B60$B6@$B7`$B6P$B80$B-0$B/`$B
M20$B2`$B10$B1@$B30$B3@$B4`$B3P$B1`$B/0$B.P$B/@$B.0$B.@$B1P$B
M2@%"(0%"(@%"(P%")`%")0%")@%")P%"*`%"*0%"*@%"*P%"+`%"+0%"+@%"
M+P%",`%",0%",@%",P%"-`%"-0%"-@%"-P%".`%".0%".@%".P%"/`%"/0%"
M/@%"/P%"0`%"00$F(0$F(@$F(P$F)`$F)0$F)@$F)P$F*`$F*0$F*@$F*P$F
M+`$F+0$F+@$F+P$F,`$F,0$F,@$F,P$F-`$C.0$C.@$C/`$C/0$C/@$C/P$C
M-P$C-@$C-0$C-`$C,P$C1`$C10$C1P$C1@$C0`$C00$C0P$C0@$C3`$C30$C
M3@$C)`$C)0$C)@$C)P$C*`$C*0$C*@$C*P$C,@$C,0$C,`$C+P$C+@$C+0$C
M+`$C.`$C.P$A?`$A>P$A=0$A=`$A?@$A?0$A>@$A>0$A<@$A=@$A<P$C2`$C
M20$C2P$C2@$A>`$A=P$B5`$B40$B4P$B4@$A(0$A(P$A)`$A<0$A4@$A4P$A
M3@$A3P$A5@$A5P$A6@$A6P$A2@$A2P$B90$A1@$A1P$A:`$A:0$D-0$D-@$D
M-P$D.`$D.0$D.@$D.P$D/`$D/0$A)@$E1P$E2`$E20$E2@$E2P$E3`$E30$E
M3@$E3P$E4`$E40$E4@$E4P$E5`$E50$E5@$E5P$E6`$E60$E6@$E6P$E7`$E
M70$E7@$E7P$E8`$E80$E8@$E8P$E9`$E90$E9@$E9P$E:`$E:0$E:@$E:P$B
M(0$B=0$B=@$B<`$B<0$B<@$B=`$B=P$B<P$B3`$B2P$B;P8B+`0B)`8A,`8A
M(P\A;`0A5P0C-@0H-0,T.P,Y;0,G00,H;`,C(P0C-P0E-`-`-`0A60,A=0,A
M;@,A<0,A<P\A1`8C3@,B<00B,0,B:0,B:@\A<@4C-`,D2@,D1P,D308E<0,G
M1@4E)00E.00E/`,G104E*P0E.P0E.`,G4`\E2@,K,08N6@0H.0,K,`4H(00H
M.@,K*@0H-P0H/`4K;`,T20,O4@0K908U.`0P10,T/@,T2`0P2@0V.`,Y<P0V
M,@0V-P9&509)>P,Y=`-`-0-`.`-`.P0\+`0\+00\*`0\*@5$5P1"-P1",P1"
M+@-%>`9:<P1"+P-%<P1/60-%<@-%;P-%=P1",@1(>P-+)@-+)01(?0-+)`-+
M*`-+*@-0,@1/7053601/6P-4/P-74P1:9P1::`1?201C+P-<,P-<,0=2=`=7
M3`1J00-A/`0B,P\F6@0K:0-75`,A=@,B>0,D504C-P8E>P8E?0,D5@,K.`=-
M/0,J3`0P3`4Q)@0V/00\,@1J0@,K.@,Y>`1)(@,A4`,C(0,D6`4E+@,G5P,G
M5@,G6`0H0P,K/`,O70,O7`0P30,Y>P,Y?`0\-`-%>04Q*00A808B00,A?@0B
M/`4B,`0C/@0C/P0E2@0E3`0E2`0E1P,K00,K10,K0@4K?`0P4P,O9P,O:00P
M5P0P6`0P4@4Q+`0P5`0P60,Z)`90;`0V0@0V10,Z(@4]<`-`0@1"001"0P1"
M0@1"/`-%?0-%>P1"/P1"/@-%?`1)(P1/8@1/801/8P5A.P15;`<^?01?2@1C
M,`0A9`0B0`0C1`,D9`0E3P8I;P8O)P0K=0,O:P0P6@0V2P-&(@15;P-40P15
M<`538P1:;@0P7`0V304]>`8I<@,T4P5P>`0C2P8F.`0K=P,Z)090=@0\/@5$
M;`1M4P8F-@0V4`,A6`8C<0,C+`90>@,G9`0A*P8A.P8H9`0E5@,C,`4B/`,C
M+@,D:@,D:0,D:`,G:`8J*@,K3`,O<`0K>@,O<00V4091(@5,,0-&)`1))P-@
M<`,A70,O<@8]80,T5@1)*04A00,A7P,C,@0E6@0H5P,_>`-&)P1'5@0A:P,B
M,`,B+`,C.`,C-@,D;`0C40,D:P,D<00C5`0C60,D<@0C4P,D;P,D;@,D>@\C
M20,E)0,G>@,G;00E70,G=@4E0@8J.0,K4@,K8`,K7P,K8@,K6@0H600H7`,K
M5@\I7`0L)0,O?00K?@,O=0,O?`0L(00K?08U?0,P)`4L0P,T70,T900P:@4V
M<`,T8P,T7`0P<`,T6@0P<P0P<00P;00P;`\S0P,X4P0P;P4V=@,Z,@0V9P,Z
M-0,Z+`0V7@0V60,Z.0,Z/@,Z+00V8`,Z/00V7P,Z-P9'.04V>04V>@,Z,`0V
M6`0V900V8P,Z004V;@,Z/P,Z.@4^.00\2@0\1@-`3P4^/00\1P0\3`-`30-`
M4`91,@1"4@-&,@-&+P-&+01"3P1"2@1"50-&*P-+.@1"4P1"5@1"405%(@1)
M,`1)+`-+0@1)+0-+-@<A3@1/:P1/;`-0001/9P1/:@1/;P-0/`-0.@<W-P15
M<@-41@15<P1/;05A0`1:<`-75@5A101?3`5G605K<P-<-0->)P1F,@-@+@-@
M+01L;`=B+P,B,@,B(0,C/04E4P,G?@,K9`,P)@1"6`1C,@,B,P,E+@0C7P,E
M.0,E.@0C7@,E/0,E/P,E.P,E-`,H)P0E;0,H*P,H+`,K=@8O90,K=`,K=0,K
M<P,K;P,P*00L+P0L,0,P+0,P+`,P+@,P,0,T;`,T;0,T<P,T:@\S5P0Q(00V
M:P,Z1@0V;@,Z409'3@,Z2`,Z300\600\6P-`4P-`500\5@0\6`1"7@1"701"
M6P-&.P1"7P-&.0<A:@-+4@-+2`1),P-+2@-+3@].)0].+@1)*@-01`1/>`-0
M1P-00@-00P-01@-01015?`-430-42@15>P<_,`-770=&1`5K=@-@<@1L;@4W
M/`--00,K>`0H804E6`0V=P1"8`-&1P1:>@,B.@,C1@,C2`0C90,E2@0E<04E
M600E=P0E<P0E>`,K?00Q)08^0@,T>@,Z500\7`-0/@,A=`,C3`,C2@0B5@0B
M600B50,C20,E4@,E5P,E4`,E3P,E30,E5`,H,0,H.P0E>P,H0@,H,@,H.@,H
M0P,H1P,H-`0F(0,H1`,H/@,H-@,H/`4E70,H.0,H,`0H;00H:0,K?@,L(@\J
M*@0H9P,P/P,P0@,P/0,P20,P1P0L.P,P0P,P4`,P3`,P1`0L/P0L.@,P.00L
M/`,P40,P1@,P00,P.@\N:P\N>`0Q*0,U)@,U+0,U(0,U-@0Q*`,U+`,U(P,U
M)0,Z<0,Z9P,Z=`,Z9`,Z=@,Z;`,Z:@,Z904W3@,Z;@4W1@0V?@,Z;P,Z7P0V
M?0,Z<`,Z70\Z/`,Z;0,Z:0,Z:`0\7P-`8@0\80-`;@-`;0-`:`-`8P0\9`-`
M900\8P-`<`-`:P-`;P-`;`-`:0-&2P1"9P1";`1":`1"9@-&20-&4@-&401"
M:P1";0-&30-&3@1":01)/`1).@-+60-+5P1)0`-+50-04@-05010(0]4*@16
M(@16)`-77P-78`1?5`5G7@-:,`-:,@-<-P1C-0-<.`1F-P1H90-A8@-A8P,C
M3@8F>`0C;0,H200H<`0L00,P5`,Z?00\9P<M+0-A/0,B/`,C3P8F>0,E600C
M<`,E6P8F>@,H3P4H;@,L,`,L,0,L,P0L0@4L?`8V70,U0@,U/0,U/@0Q+@8^
M6@,U0`,[(00W(@0\:@0\;`0\;P-`=P1"=`1"=0-+8`1"=P1)0P1)101)1@1:
M?0->*P=B-00C<00F)@8V:`,[(@0L3`8^9`1">`5,8P0B700C=`0F*`0F)P0H
M=`0H=00L304Q=00Q,P4Q<P0Q,@0W*`0W*00\<01">0,B0`,C4P0F*@,H4@,H
M4P0H>00H>`,L.0,L.`,L-@0L3@8^:P,U100W*P4W9@1"?01)2@-:-P,A8@0C
M=P,B0@,B0P,B00,B1`,C5@0B804B400C>P4B4`,C5P,C6`0C>`0C>0,E8`4C
M<`4C=`,E9`,E900C=@,H6P8J>P0F,00F,@0F+@,H5@8J=@,H60,H6@4E;@,L
M.@0H>P0L6P0L4P0L40,P8`0L7P0L50,P7`0L6@0L7@0L5P,P708V?`4M+@,P
M900L5`,U5@,U200Q-P,U3`0Q/08^=0,U300Q.08^>`,U4`\T/P,U4P,[+P,[
M,@,[*00W,@0W-`,[-00\<@,[,`,[+`0\=@0\<P0\?@4^;00](092-`-`>P0\
M=P1#(@9<1`1#+01#*@1#(0-&501#)`-&6P-&6`1#+@-&5P1)4`1)3`5,;`-+
M8@5,:`1)2P1)4P-+9`1)3P1)30-+801)5`10)@10)P16*`10)054-@-060<M
M3`-46@-45@5;/`16)P-46`<_1`1?6@5G8P5G9`1F.@->+`1H:`5[/0,C6P8A
M;@,[.`1)50,B100Q0@,B1@0B900B9@,C700D(@0D)`,E:00D(0,E:@\D)00F
M-@0F-P0I)00D)00I(@0I)`8P8P,L1P0I(P0I(00L9@0L:`0Q1P0Q2`0Q100Q
M20,U7`0W.P0W-@0W/00W.@,[/`0W/`,[.00W.00]*`0](P0])P0])@0]*01#
M,P1#,@1#,01#+P-+;@-+;P10*016+016*P1C.P1C.@-?1`1H:P9(1`-&7@10
M*P,C8`,C7P,C7@,E;`8G1P0F.`0F/00F.P4F)@0F/`,H9`0F.@,H9@\O.`,L
M20,L2@0I*@4I)@0I*00I*`0L:P0L;00L;`,P;0,U7@0Q3@0Q3`0Q3P,U704X
M*00W0`0W00,[004_(01#-@-&7P1#.01#.@1)6P1)7`-+<0-07010+`10+@54
M0@1?7@1C/`0D*0,H:@-&8@<M6P0I*P0]+08A>00B:@,C8P,C9`,E<`,H;P0F
M0`0F00,L3@0I+08P>@0I+@,L3P0L<04R1@0Q400L<@,[1@,[0P4_*00]+P0]
M+@92301)701)7P->+@0F0@10,08D<`,H<P0F0P,H<@,U9`,[2`,[201#.P1)
M80-07P,B2P8K/@,H=`0I,@0I-`,L4@4I+P4I,P,L4P8Q)04M1P\O/@0Q5`,U
M9@,U9P0W20,[2@0W2`0],P5%:01#/09<9P-08`10-`16+P8A?@,C90,C:`0D
M,04B9P0B<`,H>P,H?0,E>00D+@,H?`0D,`0D,P,E<P0D+P0D,@,F)`,H>00I
M-00I-P0F30,L60,I)`0F2`,I(P0F3@0F3`0F1@\J/@,L6`0I00,L8@0I/`0F
M200I.0,P?08W5`0I/04I-00M*`0I2`0I.@0I.P0I0`,L508W6@,P?`,L7@0Q
M6P4M6@,U<P0M(@,U:0,P=00M(P,U<`0M)`,P=P8W7@,Q)`0M*P0Q6@0Q7`0Q
M8@,U:P9(;P0Q8P,U=00Q8`4R6P0Q70,U;`,[3@0Q;`0Q9P,[3`,U;0,U=P,[
M5P0Q9`9(=0,[4P0Q9@0Q7@4M5P,[4@4X0@0Q:@4X2`0W5@0W4`,[7`0W60,[
M7P0W5`0W3@4_,@-!)00W500]/@,[8`0]-P4R6`,[6P-!)@-!+00].P1#0P4_
M0@92:0-&9P0].@0]/`-!,`-&901#0@1#4`-&9@-!+P1#2`1#1P1#20-+?01#
M301)90-,(@-&:0-+>P1#2@1#3`1#1@-,)P-+>`1#2P10.`-,*@1)9P1):01)
M:`1):P<B?`1);0-0:01);`-,)@10.05;3`1;(P1;*016-@1;)0-79P1;)`]:
M*0-79@10.@5G>`1C0P1?9`5G<P='+`->,`1C0@1C0`-?1P1H;`-A>`,C:@,F
M)@0F5`8K4@0M+P0M,`4M70,U>@,[900]0@1#5`5--P-,*P-48@8G;@0F500F
M5@0I30,L9`0A>P0A>@,B3P0B=`0B<P0B=00D.@0D-@,F+`,F+0,F,`,F*P0F
M6`,I+04F.@,I+`,I.`0I500M,P0F60,I*P\G+@0I3@0I5`,L9@,I)P,L9P,L
M:00M/`,L<00I5@,L:`0I4@0M,@0M,0,L:@,L90,Q-`,Q*@,U>P,Q,0,Q.@0M
M.P,Q+0,Q*P0Q?`0R(00Q>P,V+`9`,@0R)0,V+P,V,`0Q>0,U?@0Q<0,V)00Q
M?@0Q>@,[:P,V*@0W;@0W8@,V(00]10-!,00W9`,[:@0W:P0W:`0W90,[;`,[
M:00W<`0W80,[;@0]4`0]3P-!-P0]3`0]2@-!-0-!.P0]2`0]3@-!/`-!2@-!
M0P-!/P-!1P-!0`-!1@-!00-!.01#6`1#809=,@-&>0-'+@-'+01#5@-&?`-'
M)P-'+P1#7`-&=P5&)0-&?01)=0-,-@1#9`5&(P-'*P-'+`1*)`-,,P<C.@1)
M>01)>@1)=@1**`1*(@5-.@1)?@5-/@-,/`1*(P-0=`16.01010-0<P-0;@-0
M>`-0<@-0<0-490-4:@-4:`-48P-49@1;+0-7:01;,@1;,`1;+@-7;P-7<01;
M,0-7:`1;+P-7<@]><P-:/0-:/@1C1P-<0`1C1@5P)`->,@1F0`-@,01J201J
M2`5Y*@0F6P0M0`0M/P0R)P0]5`0D0`,F.@0F7@0F7P0I70,L=0,Q/@0M0@8X
M*P,V,P0R*`,V-00R+`0W>00W=00W>`0W=P0W=@4X?`,[=P0]7`0]600]6P-!
M3`1#9@5&,`5&+@1#:01**P1**@1**01020103`-7<P1;.@1C3`1F0P,F.P8X
M+`-!3P,I.@0I80,Q00,Y*P,[>`1*+@16/@1J2P0I8@0M208X,`9)809=405-
M2P,C<08K<`8X-`,V.P,V/@0]901*,`1*,00B>`0B>00D0P,F/`,F/P,F/@,F
M0`,I/P,I/00F8P4I3P0I8P,L>P0I9`0I90,L>`,M)@8Q9P0M3`0R.P0M2P,Q
M1P8X-P,Q2@\O;@0M309`400R-@0R.@0R-P,V0P9`3P,\(@0W?@,[>@,[>P0X
M)0,\)P0X(@9)<P,\(093/04_8@-!4@-!5P-!6@-!50-!4P-!7`-!6`0]:`0]
M9P-!5`-'.`1#;@-',@-'-@5-4P1*,@-,0@-,10104@1040-1(05-4`-0>P-0
M?`104P<N6@-4<P-4;@160`1;0`1;001;/P<_=@-:0`-:00-<1`-?3`-?305U
M;@5U;0,C=`105@-4=`,I1`,Q3@4N)0,V20,\*`0Z0P5&105-6`-1)0,C=@,F
M0P0D2`,F1@,I2P,I1@\G3`,I4`,I304F40,M*`,M+`0I;P0I;`,M*00M5P0M
M400M5`0M6`,Q4@4N*P0M4@0M6P,Q500M5@,Q40,V600R0P,V2@,V3P4R>00R
M0@0R1@0R000X-`,V6`,V700X+P,\+@0X+`,\/P,\,`0X*@4Y,P0X+0,\+`4Y
M.00X-0,\-00X-P,\-@,\0P,\*P,\+00]>`-!<0-!9@-!<`0]:P0];@0];P-!
M;`-!:0-!9`0];0-!7@0]=0-!8@-!8P-!>@-!80-!7P1$(P0]=@-!8`-"6@-!
M9P](501$)`1#=01$(01#?`-'/P1#>`1#<P-'001#=`-'2@1#?01#?@1#>@1$
M(@-'3P-'0`1$)01#<05&2P-'200]<@-'4`](4@-,3@5-;01*.@-,3`5-80-,
M4P1*-P1*-@-,70-,6`<C;P1*.`1*0@-,6@-,7`-,2`-,50-10P-10@108`10
M6@-1-P-1,`10601*.0-1/P-1*@-1/01620-1,P-1.0-,2P107@-1+0109`-1
M-0-1-`-1-@-5(@162`-4?@-5)0-4?0162P<X505;:`-4=P-5)@]?*0-4>0-5
M*`1;2`1;1`-7?`1;2@1;201?;P1?<P-:201?<`1?;@1?<@1?=0-:3`-:2P]B
M4P-:2@-<3`-<1@1C401C3P-<2`-<301C5`-<2P-<10]E/@5P)P->-@-<2@-?
M4`1H;@-@-0-@,P-@-`4D2`8H,`0F;04F5@0F<`0F;`0M8`0I<`0I<08Q>`0I
M=`0I<P4N+@0M700M800M8@0M7@,V800R2`0R209`;@0X.P0X.0,\1@4Y0P0X
M/`8X9`0^(00]?`0]>P0]?00]?@0^(@-'4@9==P1$*@1*3`-,:`109@109P16
M3P163@-5*@-5+`1?=P=.(@1H<05U=P5Y+P8E)0,M/@,K>P,\2`0X/P5&7P-8
M)`0B?`,I5P4F8@0F=0,M/P,M00,M0`,Q:0,V8P0R2@0X100X1`0X1@0X0@,\
M2@-"(P0^(P0^)`-")`1$,@5&8`1$,P1$,`1*4`1*3P10:P10:@16401C50-<
M3@5U>`4D3@0F>`0M9`,Q:P0R3P0X200X2@0X2P-")01$-0-11P-12`10;@16
M4P-8)00I>P,C>P0F>0,I6P0F>@\G6P,M0P0M9@0R4@0R5`0R4P0R50,V9P0M
M9P0R404Y6P,\3`0X3P0X3`0^*0-")P0^*`0^)P1$/P1$.`1$.01$.@5&:`1$
M/`10;P10<010<@-1201;4`1;3P-:4`1M5P0M:@,I7`,V:`-,:0-12@0A3P,B
M5@,B50,D(@4A=`0C(@,F5`,F3P0D3P,F708H20,F6@0D40,F2P8H2@8H1`,F
M6`,I80,I7P,I7@,I8@,I8`0F?@,I:`,I9@\G9@,M1`4J)`0G(@,M5`4I>P4I
M?`0I?@,M5@,M3`\P208X<@,Q<`,Q<00M:P8Y,P,Q=`0M;`,V:0,R)`,R(P,Q
M?@,Q=00R5P,V<00R8P0R9`,V;@0R7@,W(@,V;0,\3P,V?@0R6`0R:`4Y7@0R
M6@0R7`9!*P4S/0,\7@,V>P,\7P,V<P9!00,V>`\V,P0X400X5@,\900X4@,\
M600X60,\:@,\9P,\500X5P0X6@,\4P,\5P,\80-"*P9*;0\\0P\\6@0^-P-"
M+`-"-P-"-0-"2`-".`0^,`0^.00^+0-"0@0^.`-"-`-"/`0^/`-"+P-"005`
M)P0^+P0^,@-",@-"0P-'501$20-'8`9>.P-'60944`-'6`1$1@1$301$2@9>
M0`-,;@1*7P1*80-,;P-,?`1*:`1*70-,;01*60-,<@5&>`<D80-,<`10=`-1
M2P-,=@10=P10?055-@10=@-13P-13@10>@55+0-14P-15P10>P165@-140-1
M3`10>`-14@1*8@55+@-5,@-5.`167@168`-5-`166`-5+@165P167`-5.P16
M60166P-5,P1;5@1;5`1;6@1;5P1;8`1?>P1??01;6P1?>0-:40-<4`1C6@1C
M7@1C6P-<4@1F205P/@1F2@1F3`1H<P->.0->.`-?401J3@-@.`1K;01K;@-A
M9@,D*@0D4@,F80\D;@,I;@0G)P,I>`\G;@,I<P,M9P,M60,M9@,M80,M8`,M
M6P0J)P,R+@0M<P,R,@,W*P,W*@,W-`0R<00R=@0R<`0R=P\V2`,\=@0X900X
M80,\=00X8@0X9`0X8`,[(P,\?@,\<`,\>`-"5`-"30-"5@0^2P-"2@-"500^
M2`0^1@0^20945`-"2P-"4`]">`]#/`1$60-'<P-':0949P1$5@1$6@1$7`-'
M<0])6`--)@--(P--*P--(0--)P1*:@11)0-170-16P11*P-17P-18011)`-1
M9`-190-5/0168@-5/P-51`<Y)@-740-8+`169`-<6@-:60-<5`-<6P1C7P1F
M3@5S5P1J4`-@.@-A>@0G+`,I>@,W6`-'=`,M:@0M=@,W-@0X:P,I>P0J+`0X
M;`,I?0,I?@4N4P8Y0`0M>@1$7P<Y+01;9`1F4`,A:@,R,P0C)@,F900D508L
M<00G,P4F=P0G,@0G+P,M;`,M;P0J+@,M;@,R-`,R-00M?00M?`0R>@4S300R
M>00R?@,W.`9!9@,W-P0X<`0X<@0X<P1$8P94>`0^3@-"7@1$8@1$8`1$9`1*
M;P1*;@1*<@1*<01*<P11+@11,`11+P169P-51@-51P1;9@1;901@)`=3:P1J
M400G-`0D60,F;00D5@,F;`8L=00G.04G+@,J*0,J)`,J)00G.@0J,@0J-`0J
M-0,M<@8R9P,R-P4N7`0N(00M?@0N(@0N)@9!;00N)P4S400S*`9!=00S*00S
M)00S*P0S)P0S+@0X>00X=P,]+`0X>P9+0P1$900^5`1$9@0^4P-"8`0^4@1$
M:@9>;@1$:01$:`1$9P-'=@0X>@1*>P1*=@1*>@1*?`<O=`11,@11-`-52`16
M:@16:P1;9P5H.P1C901C9@1C9P1C8P1K;P,D+@0C*0,D,`,D,0,F<0,F;P,F
M<`,J+@,M=@8M(0,J,`0G.P,J,0,M?0,R.@0J-P0J.`\L,@0S+P,R0P,R1`,R
M.P0S,`,R10\Q)P,R0@,W/P,W0@,W000S,P,W/@,W0P,]-`0X?04Z+0-"8P,]
M,0,],`-";`\V60\].P0^60-"90-":05`3@-"<@]#20]#5@-()`<E-P1+(@1+
M(0---P--/`--,P--.`---`--,@-1:`557011-P-1:0-52@16;P]5>@]6(@-5
M3@1;:0-53`];+0-8,01@*@]B>`]B>P-<800J.00J.@4N8@0N*P0S-00S-`0X
M?@1$<`1$<01$;P1+(P1+)`1;;`1M6@0D7@4G,@,J-`,N(P0J/0,R2@,R2P0N
M+0,R200N+`0S.P0Y(00S.@0S.`0S.00S-P0Y(P0Y)@0S/`0Y)`0^8@0^800^
M700^8`-"=@0^8P5'2`1$<P1$=@1$=`1$>`1$=P1$=01+)01+)P1+)@11/P-1
M;P110@110016<@16<P-54016=0-54`16<01;;P1;;@1@+`1@*P1H=01K<`1J
M4P,R3`0^90--/P16>`,]0`]03@4D8P8H8@,F<@0J00,N*00J0P0N+P0N,04S
M9`,W2`,]000Y*`0^:0-">0-">@0^:`1$>0--0`1+*@1+*0111`5<+P1;<@1;
M<P1@+@1C:01J5`0^;00D800D8@4G-P,J/`0J1@,N+00J20,N+`,N+@,R5@0N
M-P0N.P0N-00N-@,R5`0N,P0N/P0N.08Y:P,R4P0N.`0N.@4S;00S0@,W3`0S
M0`0N/`0S/P0S10,W2P0S0P0Y,@0Y,P,]1@,]2P9+6@,]200Y-@5`8`0Y+P0Y
M,`,]2`,]2@4Z.P0Y-00Y.`0^=`5`9`0^;P0^>`0^;@0^=@0^<P0^>@1%)`1%
M*`9?+0-(*@-(+`1%(P1%(0<E6`1+.`--0@1+-P1+-01+,P1++P<E7`1++@5'
M601+.P<P-@112`1120-1=0113@112@114`17)@17(@1;>P1;=P=`:P17)0=`
M9P1@,@1@+P1@,`1F6`1F60->0`5S7`1J501K<@1K<0-B+0,F=0,N,`,R6`,W
M3@-#(@-(+05'6P5.60115@1@-P1F6P1L<P0G1@0J3@,N,00N1@0N100S1P0S
M2`0Y.@954@1%,`1%,@-(+P--0P1+/0115P1;?@1C;`0G2`0J400J4`0N1P0N
M20,R600S2P,W3P,]3@-#(P5`;P-(,@116@1%-@17+`1@.`-?.`1N2`,F>00D
M900G3@0G3P0G300G3`0G2@0J4P0J5@0J5P0J5`0J6`4J;00J6@8S.`,N-`0N
M4@,R70,R9@,R8`0N30,R804S=@0S4`0S40,W5@,W5`0S4@0S3@0S30,]4`0Y
M20,]5`0Y2@,]500Y100Y2`0Y/P0Y000Y2P0Y1@0Y300Y1P0Y0P0_(@0Y3`0Y
M0@0_,`0_+0-#)`0_)00_)@0_)P0_*P0_+`95805'801%.01%001%/`1%-P-(
M-P1%0P1%1@1%/P1%1`-(.@1%.`--101+101+0@1+1`1+1P1+0P1+30--1P5.
M8`1+/P-1=P-1>`117`118`-1?`-1>@1170119`17,@17+@17,017+P-56@17
M,`17,P17-`56(@5B:01<)P1<*01<*@1<)0-8-P1<)@1C<`1C;@1C<01C;P1F
M70->001H>`1J5P1H>@1L=01N300G400J7P0S5P1%2@-57017.`1C=`1K=00N
M5P0N6`0S6@0S609,*P0_,P1%3`,D,@,F>@0G4P\H>@0J9`,N.`0J8@,N/`,M
M.P0N7P0N7`0N8@4O-`,W6P,R:@,R:P0N7@0N800S7@0S80,W7`0S7P,W6@0S
M8`,W7@,]6P4Z609,,P0Y6`,]6`0Y4P0_0`0_.00_/P-#+P0_/`-#,@0_/0-#
M+`0_/@0_.`0_.@0_.P0_0@1%3@-(0P1%40-(001%301%501%3P5'=@1+7`1+
M6`1+5@1+501+7@<F)`1+6P-2(P-1?011;`-1?@<P6056,P11<`11;017.P17
M00-(0@17.0-57@-57P17/P-8001<+0-8/01<,01<+P1<+@1@/P=.7`-<8P1C
M=@1C=01F7P1F8`1F801H?`1H>P-@=0-A9P,N/P0J9P0J9@8S2`,R;@0N9`,R
M<0,W9`0S8P0S8@,]80,]8`0Y600_100_1`-#.@-#.P-#/@0_1P-#/`-#/P-(
M1@5()`-(205.=@--3@11=@-2)011=`11=0170@-81@-81P-:9`1F8P-B-`4D
M;@,F?04G1@8M200G5@,J0`,J00,J0P0J:@0J;P0J:P0J:00J;`\L;00N90,R
M=0,R>@9"9@0S9P0S9@,W;00S904T.P4T.00S:@0S:00S:P,W:`0S;04T.`,W
M;@\W.P0S9`4Z900Y7@0Y8@,]9P0Y9`,]:@0Y8P,]:P0Y800_3P-#0`0_30-#
M100_3`-#0@0_2P-#0P1%5P0_205!,0-(40-(2@1%6P-(4P-(3@1%6@-(3`1%
M6`9?:P1%601+901+80--5`1+8@--4@<F,@--6`1+:`1+9@1+9`--6011?011
M?`-2*P11>011>`11>@-2+01710-58P171P-82`=!+@1<-P1<-01<-@->1@1C
M>01F90=83`1F9`1H?@1I(0-B.00D:08M3@,N1@,N100J<00J<@,S(0,R?@,R
M?00S;P0S<`,W;P4T100S<@0S<09";P,];`0Y9P,];09,4P,];@5!.00_4P0_
M4@96)P1%8`9?>`1+;`5/(P54)`12)012(@12)`<P;P-590-59@173`173017
M2P173P-59P1<.01<.@1@2`1@201C?`1I(@,D-`,J1@0J=@,N2@,S)00N;0,S
M(@4T1@,];P0Y:@-#2`0_5`0_500_6@1%8P174@1<.P-::`4K(00N=00N<`,S
M*`0N=P,S*00N<P0N<@0S=@0S?0,W=`4T2`0S=P0S>P,W=09"=@0S>`0Y;00Y
M=`0Y<0,]=`0_6P0Y<@,]>@0Y=0,]<P0Y;P9,6P9,5@-#4`0_9@0_8@0_80-#
M4@-#4P0_70-#3@0_8`-#2P0_8P5(1@0Y=@1%90-(6P1%:@1%:0-(7P1%;@1%
M:`-(601%;01%9@5(-@1+>P1+=01+<`--80--7@1,(@--9P1+?@--8@1,+@5/
M.P--9`1,,`1,)01,+01+>05/,@--7P5/101,+`1,)P1+=P--9@--:`1,*`5/
M-@12-`12.@-2,012-P12*P12.`-2-012.012.P12-@12+P12/012*0-2,@17
M6P5<;0177@176@178@5<?01790174P-5;`175@176`17605<?@17505=,`1<
M1`1<3P1<2P1<4`1<0P-82@1<2@-:;`1<0@1<3`=!/P1<1@1<201<0`5C-`1<
M2`-830-82P5C001@5@5H;@-::@1@4P5H9@-:;0-::0-::P1<401C?@1F:01F
M;`1F;@->2@1F:@->301F:`1F;0-?5@5P801I)@1I*`1J701J801J7`-@7P1K
M=@1M7`1M=@=E700J=P,S+P,S,P9#(@0T)04T60,W?`9,8`0Y>P0Y?`,]?0,]
M?`0Y?0-#6@-#5@-#5P-#60-#6P-(8P1%<@-(9`-(909@+`-(9@--:P--;`--
M:0--:@1,-P<F5P1,-0-2-@17;0-5<P-5<@17:017:@--=`17:P5C3@1<5@-8
M4@1<501<5`5C5`-84P-:<`1@6P1@701D(P-<:`=4.@5P<`1J905V.01L>@-A
M100G7`8S9`,N5P,N50,N6`0N>`0N?@,S-0,S-`0N?`,S.00O(0,S.`0N?0,S
M-@,S.@0T+@0T)@,X(P,X*@0T)P0T,`,X+`0T+00T*P0T*0,X*`,X+0,X)0,^
M-@4[+`,^+0,^,@,^)P,^,`,^)09,<0,^,00_:@-#90-#:P0_;@0_<P0_;P-#
M80-#70-(;`1%=01%?@1%>01&(0-(9P-#7P-(<@-(=01&(P5(5`-(;P-.*@5/
M4P1,/@1,/`1,0`-->P-.(0-.+0--=@-->01,.@1,/01,/P-->@1,1`5/5`-.
M)@-.(P-2.@1220-2/`121P-2/0-2/@17<P-5>`5=/P-5=@5=1@-5=P17;@-5
M?`-5>P<Z.01<8@1<8`17<@-85P-85@-9*01@9@1@8P1@:`1@8@='2@-:<P-:
M<05M(@-<:01D)`-<:@-<:P->3P->3@1I*@=86`-?601I*P1J9@1K>01K>`=?
M,P-@>`1L?`1L>P1M=P0J>00O*0,X+P,X,@4T8`0T-`,X,`0T,P0Z*`1&)0-(
M=@123@1J:P\A1P,J30,N7`,N6P,N600J>P0O*@8Z:P0O+00T-00_=00Z*@-#
M;`-#;05!90-(>@-(>P123P17=01<901@;01F>P1K>P8Z=`0O+@,Q/P0T.`0T
M-@0T-P9#/`0Z+00Z,00Z,`0_=@-(?@1&)P-(?01&*`-(?`1,20124P-20017
M=P1<:@1<:P1I+`,S0`,S000T.@,X,P0T.P0T/@0T/`,X-0,X-`0Z-`0Z-04[
M.@0Z,P-#<`0_>`-#<00_=P-#;P-)(01&*@1&*01&*P1250125@-87@-88`-8
M7P-<;@1F?0,^.0,^.@0K)P0K*`0O.`0K*0,X.`0_>@1&+@1&+01&+P1&,@1&
M,`1,3P17?017>@17>P1<<`1G(00D;0,S1@,S10,X.@0T000Z.05!<`-#=`1&
M-@1&-`1&-01&-P-))`-.,P1,4@126@-20@126P18(018)`18(P18(@-89`1D
M*`-?7`96;00C+08E200D;P0D;@,J408[*`,J50,J4`0G9@\H4@0G8@0G9P0G
M8P0G904G6`,J6@,J4P4K,P0K+P0K*@0K+`,N8@,N7P8S?04K.0,S400O000O
M1@0O1P0O/P8[,04O;0,X1@0T3`0T2`,X1`0T2P0T4@0T400T2@0T4P9#6`,X
M0`,X/P,X0P0Z200Z.@,^/P0Z104[300Z2@0Z000Z0`0Z0@0Z/0,^1@0Z/P0Z
M1`0Z2P9)?@9-5`96=@1`)P-#>`1`*@1`(P1`)@-#>@0_?01`*`-$(01`+`-#
M?0-#>04T:@1`)01&101&/@1&/`1&/01&/P-22`1&0@1&0`1&.P-)*0-)*`1&
M.`1&1P1&001,701,6`1,7@1,501,7`9@;P1,5`1,6P1,7P5"*`128P129`-2
M1@-210127@1280128@129@]1505=6P18*P18*`18+`1<=`-89@1<=@-89P-:
M=@1@=`1@<P5M+`1D*@1G(@1G)`1G(P1G)01I,`9#9`=")`,K1`-$)`0O2@0T
M6`1,8P12:P,S4P,S5`,X2@1,9`9A(0-22P->5`0G;P0K,P0K,@,N9P,S5@0O
M4`,X2P9#<09#<`,^2@0Z3@0Z3P9-8P5"+01`+P1&3P1&401&4`-)+`9A)`5)
M+`-./@1,:`1,9012;`12;018,`18-`18,P-6)0-6)@5=9P5<3018,@1<?`1D
M+00O4P0T7`12;P12;@18-01<?01I,P8E3P,D-P,D.0,G)P0D=@0D?0,G+`,J
M8P,J9P,J9`,J:@0G<@,J8@0H(00G<P,J90,J:04G8P,J80,N;00K-@,N<`,N
M<0,N;`,N<P,N=08T.@0O50,S800O80,S9`,S6P,S7@8[5@,S700O7@,S7`,S
M904P(00O600O9`,S8`0T7@0T;`0T<0,X6@0T:00T90,X5@0T9@0T8@0T700T
M8P9$+`,X3`9$*`4U*@,X60,X7`4U)`0Z;`0Z8`0Z7P0Z9`0Z604[5@0Z6P0Z
M5@,^4P0Z7@,^5`,^400Z7`0Z80,^509.)P,^3`\^:P1`,`1`,@0Z90-$-P1&
M:01`1P1`201`.@-$*P-$*0-$-`1`2`-$/01`3`1&90-)+P1&5P9A1`1&9`-)
M,01&4P5)/`1&80-),`1&;01&8`1&7`-)-`5).P9A6`-)-P-)0`-.0P1,<@-.
M/P1,<`1-)`1,:P-.001,<0-.4P1,;01,<P-.1P-.10-.5@1,?0-2401,;`-.
M2@1,;@-.2`-.50-.20501@-.4`]190]1<P]1=@1-(01,;P-.401,=P12=P12
M>P12>013+`13(012=@-24P13)0-25P12?@-23013(P12>@12?`12<@5D+0-2
M3`13(@12<P-23@13)P13,01&9P181`18/`18.`180@5=>018-@18.P-6+@-6
M)P18/0-6*@-6+P-8:01<?@1=*P-8;0-8<`-8:@-8<01=(P=".`1=(0]@3@<[
M,@1@=P-<<P-;(P1@>`-;(0-;)`=)4P1D+P1D-`-<?01D,P-<=`=4:`-<>01D
M,@1D.`-<>@1D,`-<=01D-@1G)P->601G*`]H.0-?701I-P=8<@-@00-@0@5X
M)01K?01M7@1L?0-A:@1M>01M>P]L;`1N-P1N-@5\/@,J;00K/@0O9P,S9P,S
M9@,S:`4U-0,X8@4[<`,^8`-$005"5`5"4P-$0@-$0P1-)@13-@1=,@5D.P5D
M.@1D.@,G+@,N?0,O(0,O(@0O:00O:P8[:0,X:`,X9P0T?`,X900T>P0T>04\
M)@9$2`0Z<@,^9P0Z=`,^904[=`0Z<`0Z;0,^9`,^9@1`5@1`5P-$2P-$1P1`
M6P0Z;@1`70-$2@1&>`-)1@1&<@1&<P1&<01&=0-)1P1&<`1&=@9A:0-)2`1&
M>P-.6@-.7`<H0@-.5P-.6`1-,`-.6P1&>01--@1-+P-)3013/@-27`<R<P13
M/01830-28`<R=0-2805>,@185P184@-6-P186`183P185@-6.`183@-6,@18
M5`187P-6-0-6/`-6,01=.P5>-01=.0-8<@1A)`5I00-;*@1A(01A)0]C;@5M
M2P1D.P1D/`1D0`1D/@1D00-=)@->7@1G,`1D/01I/@-?7@-?8`-@1`=9)0=<
M7@1J>`=<8P-A2`1N.0,O)08[<P,X:0-$3`1'(P1--P0O;P0Z>`-.7@132@-;
M+@,J;@,O*`0K1@4P/00O<@4P.00U*@0Z>@0U+00U+@0U+`\R400Z>0,^<00U
M,`,^;@,^;`,^:P,O2@1`8@1')098*P-)4P1'+05);`5);01`9@1',01')P-)
M501`8`1'*@1'+@1')@1'*P-)6@-)4`-)6P1-/`1-/P1-.@1-.01-0@1-0`1-
M1P134@1350135@-.8P133P188P189P-610-60P189`-6/@<[60-61`1890-6
M005D5@1=2@1=2`1=201=1`1=1@1A*@=#(@1D0P=0)0-=)P1D1`->7P1J>P=9
M,@-@>@1L)@-@>01M?04K1P0O<P0U,00[(0,S>0,S>`0U,P0U-00[(P4\-00[
M(@,^<P-$4`-$401'-@1'.`1-2@1-2`136@136P58,@137`5>0P18:`18:01=
M3@1=4`1A+01A+@-;,`1A+`1A,`->8`-B/`0U.@-$4P1`9P-$4@1'.@1-401-
M3`1-3@1-4P1-3P139`1380138@18:P18:@5D8P1A,01A-`1D1@1D1P1M(@,O
M*P4K20,O+00O?@,S?00U00,X?`,X>`4U5P0U1`4U7@,Y)`,Y*`,Y(00U/P,X
M?0,Y)P0U0P4U709$;0,Y)@4U5@0[,P,^>0,^>@0[-@0[-0,^=@,^>P,^=P0[
M-`0[*@0[*00[*P,_)@9.:P,_)0-$5P9800-$7@1`;@1`;01`;`-$6@-$7P-$
M8@1'/01'0`1'2@1'/`-):@1'1@1'0@-)801'0P-):0-)9P-)701-601-5@1-
M7`1-7@-.:`1-801-6`1-6P-.;01-7P1-6@-.:P1-8`<H>01-50-.<013:@-2
M;`-2;0<S3013:P-61P18<`-62P-63`5>501=6@=*)01=5P1=6P-9(@-9)01=
M5`-9)P1A0`5I4@-;,P1A.P1A/01A105I401D3@-=+0=0,01D3`-=+P1D2`-=
M,01G/01G/P=5,@1G/@1G0`1G.0=9.`-?8P1I2`5V3`0K200P(P9.>@,_)P1'
M3`-.=P18=01=801I3`0U2@,_*`1`=`1'3@1'3P-);`1-9`-2<`13<P-2;P13
M<@-2<018=@18=P-63@1G1`1M)`0P)00U2P9%(@0U3`]$=`1-9P1-901-:`13
M=013=P1=9`1A2`1A1@1G10-?90-A3`1M)00U4`9%)`,Y+P0[/@-);@-.>0-.
M>`-2<@-64`-9+`-9+01A2@=*00-;-P1=:`0U400U5`4\3`0[/P0[00,_+@0[
M0@9/*00[0P1!(0-$9@-$:`5**09B:@-);P-.>P-.?`1-;@1-;`<I-@1-;051
M.0-/(0-2=`13?013>013>P13>@-2=@<\,P18>@]@>@13?@-=-0->9`1K(04P
M2P5#-`1'601'6`1G2`4P3`0P)P0P*`0U500U5@,Y-`,Y-@,_,00[10,_-@,_
M,@4\4@,_-00[2`0[1P1!)@1!)P5#/`-$:@1!*`5#.`1'6@9B=01'6P-)=@5*
M-`-)=P5*,@-/)P1-<P1-<0-/)`1-=`<I/014)@587`5850-2>`18?019)018
M?`5>;01=;0-9+P1=;`1=:@1=;@-9,`1A30-=-@1D501D4P1D5@1G2@1I3@-?
M9@1I3P1K(P1L*`1M)P0K3`,O+P0P*@,S?@0U7@0U604U<@,Y.P0U6P0U7`0U
M70,Y/`4\8P0[3`0[4`,_/00[300[209/-@9//`4\7`0[2@0[2P0[3P,_/`4\
M7P0[401!*05#2P-$;`-$;@]%6`5*/@1'7@1'801'7P1'8@1'90-)>`1'9`-/
M*`-$;P1-=P1.(@-/*@<I3@-/+@-/*01-?@1.(01-?01->01->`1-=@-/+01.
M(P14+@-2?0-2>@14+P14+0588@14,`-2>05>>P19*P19+`19)@]<>`19*@19
M*`-64P-9,P1==`1=>`1=<@1==0=*5P1A4`-9-`1A401==P1D6P1D6@1G4`1G
M3`5T2P1K)`=<=P1L*0-A3P-B+@,_0@4\9P0[4@0[4P,_00-$<0-$<`-$<@1.
M)@14,@19,`-65@-;/@1D7P-@3`0K300K3@\M4P,T(@,Y0P,Y1`,Y2`0U800U
M8@,Y10,Y1@,Y0@9%10,_2`,_0P0[5`,_2@-$=01!*@-$=`99)`1!+`1'9@1'
M:01'9P-)?@1.*`1.)P1.*@1.*0-3(P58<@14,P14-`5180-66`19,@19-019
M-P-65P19,01=?`1=>P1=>@5E-01=?01=?@1A601A6`1A5P1D8`1D801G4@]H
M4P-?:`-?9P-@?01M801N(0-B/01.+@-=.01':P],9P-/.`1D8P=05@,G,@0E
M(@\H<@,J;P4G:00K4P0K4`,T(P0P+00P,`,T)`0P+@,Y200U:0,Y30,_4P0[
M5P,_3@9/2`,_4@1!+P-*)01';`-*(P-/.@1.,01.-0-//0-3*@-3*`-3*019
M.`19.0=#=P-9.01A7@1L+`,B7P0C,@,G-@,G-P,G.`,J=@0H*0,O-@0K5@-%
M(@,O/00K5`0K6`,O.0,O.@8T;00P.`0P-`,T*`0P,P1'<00U;`0U;@0U<P0U
M:P,Y4`0U<`0[7@,_6`1!-`1!-@-%(019/`1!.`1';01';@-**0-**`5*8`1'
M<`-//@1./01./`58?@5?/`-@301K)@,O/P,T*P,T+`0U>`0U=`,Y4P4V-@0U
M=00[8`,_6@,_6P,_7`0[9`993`-%)@1!/01!/`1!/P1!/@1'<P1'=`1./P1.
M001./@1.0`14/014/`14.@-3+@140`14.P<T5`-3,`19/0190@<\<`19005E
M101A801A9`1A8P1A8@1A901G6@1G6P1I5`1I4P1L+@1L+01N/00U>@8\8P,Y
M6@,_7P,_9`,_80,_9P-%+`5#;0-*+@1'>0-*-@1'=@1'>P1'>`-/3P1.0P-/
M1P-/1@<J.`-/2@<J/@-3,P-3-`142`141@<\>P-6:0<\=P1910191`]=3`-9
M/P-9001>+P1>+`=$.01>)P5E3P1>*P-92`-91P-;1@1A9@-;2P-;0`-;4@1A
M:05J,P1A:`-;40-;3`-;20]D-`-=.P1A;`-=0`1D9@1D;`5N-0-=2`1D;01G
M7P->:P1D:01G80->;`1G8P=5:`->:0->;@->;P-?;P-@405Q50=99P-?;0=9
M:`-?<`5T501K*@5V7P1K)P-@3@-@4`-A(P-A(01L,`-A)`-A;@8\900[9P\_
M=@1!201>,@,Y6P0U?`,_:@0[:P,_;@,_:P-%.P1!4`1!3@1((P-*.P-*/P-*
M.@5*;@-*/`<J1@1.2`-/5`-/5P143P142P-3/P143`-300-30P-31@-310<T
M<P193@193P195`-6;@-6;`1930194@1G9@1D<05Q6P1I504A?0,B8`,D/@4D
M>P8I-00H,00H,@,J>@4K9`0K6@,O000K600P0`0P/0,T-00P/@,T-P0P/`,Y
M8P,Y700U?0,Y8`,Y8@,Y9`,Y7P,_;P0[;0,_=`-%/P-%/@1!501!5`-%/0-%
M00-*00-*0`-*0P-*0@-/60-/6`<J5`-31P144P14401950-;5`1D<P1G9P,T
M.`0V)`,_>@,_=@,_>0,_=P1!5@-%1`-%0P-%10-*2`-/70-/7`-32P-32@-2
M.`196`-6<@-93`-;50-=2@-;5@-=2P1I5@-A40-B0`,Y9@,_?090,0-%2`1(
M+01(,01(+@-*2@1(-`-*2P1(,P9C>P-/7@-/80-/7P1460-33P-33@198`-6
M<P-6=P146`-6=@1970197P1>-0-930-93@1>-@=$6`=$8`1A=`1A<P-;5P-;
M6`-;601D=0-=301I6`1I6@1I6P-@6`-A4P-A)P-A4@-B)`-B1`-B1@1I7`0V
M*`0V*@0[=`1.3`1D>P1!6@-%2@-*301(.`1(-P1470147`198@1D?`1G;@5Q
M8P1L,P0[>0-`(P0[=@-%301!701!7P-%3`]&,@9:*`1(.@1(0`1(.P-*3P-*
M4`1(/01.3P148P1480148`149`148@198P14:`-34@-6?`19:`199`<]5@-6
M>0-6?0-6?@1>/@5E?@1>0@1>/`5E<P5E>P1>.P1>00-;7`-;6P1A=P1A>P-;
M6@1E(P1D?@5N20=6)P=6)01G<@1G<`5Q:0=6)@-?=`5T8@1K+`-@6@1L-`1M
M+0-A5`1M90-A<`1N(@1!801(0P1(001(0@1(1`-35`19:P=$=P1>10-94@1A
M?01A?@1G<P1I8`-@6P-%3@-7(0-;8P-;8@-=4@1G=01K+0-`)0-`)@-`)P-%
M4014:@14:0-94P1B(@1B(P-?=00[>P]`+01!901!9`5$-`5+/@1(30-*401(
M3@-*4P1(3`1(2P5+/P1(1P-/:`1.601.7`528`14;014;P-35@1.70-38`-3
M5P-37@<U40-7)019<P<]:0-7(@19=P-7(P-7)`-7)P-7*01>3@-95`1>201>
M1P1>2P-95P-9501>301>3`-96@1B)P1B*01B+01B)@1B+`-;9`1B)01B+P1B
M*`1B*P1E+P1E,01E,`-=5`1G=P1G>01G=@1G?`1G>P=6,@1I8P-?=@1I8@1L
M.05X2`-A500V*P0[?@-%4P1!;01!<@1!;@1(401(5@1(601(4`1(5`-*5P1.
M8`1.8014=@14=P14<P14=`14=019?01:(@1:(019?`19>@19?@1>40=$?@1>
M4`1>4@-970-97@-97P1B,@-;9P-;9@1E-@-=501G?@1K,`1L.@-7*P-98`,T
M.@0V+`-`*0-`*@0\)`-`*`0\)0-%70-`+`1!=P1!=`-*7`-%7@1!=0-%5@-%
M50-%6@1!>01!>@-*6`-*601(6P<K.`-*6@1(7`9D0`-/:@1.901.9`1.9P1.
M9@14>`1.:014?`14?014>@1:)P15(@1:*`1:*@5@,0-7+0-99`5@+`-7+`1>
M6`1>5P1>6P1>601>6@1E.01B-@-;:`1E/`1E.P-=5P-=601H)`1H(P->?01H
M(@1I9P1I90-?=P1I:`1K,0-A5@1M,`1M9P1N)0-/;`-39P1>7P1B/`1(70-7
M+P15)@-7+@-A<0-`+05$2@-%8`1(7@-*901(7P-*7P-*9P-*:`-*:P-*:01.
M;P-/<0-/<`1.;@-/;P1.;01.<`-3;P-3;@-3;05:+`-3:015+05:+@<V*`1:
M+@-7,@-7-01:+0-7,01>9P5J;@1>8@-9:`1>:`-9:01>8P1>90-9;`1B001B
M/P-;:@1B1@1B0`1B1`1B101E001E0`-=70-=6P1E1P5N9@5N;0-=7`1H*01H
M*@1H*P1H+0-?(P5R+01H*`=:/@5T=@1I:P1I:0-?>@1K,P1K-`1K,@-A*P=@
M+@=@+0-A5P1M:`-B)P1N/P-B-P1N5P,Y:0-`+@1(8@-*;0-/=01.=01.<P1.
M=@-/>`-3<@-3<P15,`15,@15+P15+@-7.01:,01:-01:,`-7.`1:,P5F401>
M;@-;<`1B2`1B1P1E20-=7P1H,`1I;@1K-01L/@1M,P-`,`1"(@1B2@5T>@=D
M=0-`,04]4@9D7@1(:@1(:01(9P-*=`5+601.>P-/>@15-015-@1:.`-7/01:
M.P1><`1><P-9;@1>=`1>=@1>=01>=P1B3@-;<@1B3`1E301E3P1E3@=1>05R
M/P-?)@1I<@1L0P1L00-A+05X4@1M-0=A:@1M:01N20=1?05R00-*=P-*=@--
M/@-3=@=:2P-A6`-*>01/)`1/)015/P-3=P1>?@-9<`1>?01>?`-;<P5F:`-=
M901I=P1I=@=:3P1L2`1L201N6`4]5`1(;05+9`1/*`1/-`-0(0<K:@1/.01/
M,@1/*P1/*0-4)P151`150@152`-3?@-4*`1500-4)@-4)`-4(@-3>P1:0`-7
M001?(0<^201:0@-9<@1?(P5F;@1?)P1?)0-9>`1?)`-9=P1?*01?*P1B705K
M-01B9P1B5P1B801B601B5`-;=@5K,01B8@5K*P1B8`1B9`-;>`-;>P-;?`]D
M<@-==P1E50=2,01E6P-=;`=2,P1E4P-=:P-=;01H/0-?+0-?,`1H/`-?+@-?
M*P1H.@-?*0-?+P1I?0-??01J(01I?`-??`1I?@-@)`1I>P-@(0]J/P1K/`1K
M/01K0`1K.P=>(P-@9P-@9`5X6P5X5@-A,`1L301L3@5W)`-A6@1M.0-A,01N
M+`1N+01N6P-%90-*>@-*>P-*?`-*?@5+:P-*?053.`1//P-0(P1/1`1/.P<K
M;01/0`-0*`-0*0-0)@-,8P1/00153@-4+P1530-4,`153P-4*P155`<V2@15
M2@-4+@155P-72P152P-4,01550-4-`154`<V40-6,P-73`1:40-71P-720-7
M1@1:4@-73@1:4`1?+P1?-01?+`-:(0-9?`1?,@1?,05G)@1?.`1B:@-<(01B
M;`1E80-<*`1B;P5K/`1?-@]D=0-=>`1E;`-=?0-=>P1E:@1E9`-=?`=20@1E
M8@1E:P-=?@-?-`1H0`1H0@1H005R8P-?,P1J)P1J+`-@*`1J)@-@)@-@)P1K
M10-@:P5W+`1K1`5W-`1K1P-@:@-@:01K2`1L4`1L4@1L40-A-@1L5`1M/0-A
M7`=C-P-B*@-B/@1N60-B0P1/1P1?.0=7*01K305Y<P5+;01/201/2@-0+0-4
M.`156`<V7`-:(P1B<@-?.0-A-P-A.`1(<P1(=`-+(01/301/2P1560157`15
M6@1570-73P1?/`1?.P-:)P1B>01B=@1B?01B=P1B?`1H201H2`1H2@5U305U
M2`1K3@-A.0=:?01M00<L,01E<01E<@<V901?/01C(01E=@1H2P1K4@1L6@<L
M,P157@<V9P5O4@1E>05O5`1H3`1H3@1H301J,01K501M0@1"+`-+(P1/4@1/
M4P157P1:7P5A(P5G0`5G/01?/P5G001C(P-<*P1E?`1F(01E?05O6`1H4@-?
M.P1K5@1L6P1M1`-A7@1M0P1M;P1?0`-<+`1J-P-A.@15801L801L8@1?0P1?
M0@1?1`1C)@1H60158@1:8P1?101C)P1H6@-@*@1K6`1K6P-:+`1?1@->(P=2
M9P5O801H7`1N,05[>@1:9@5A+01?2`1C*01C*P1F)P1F)01F)@-?/01H801J
M/01J/`-@;@5W301L:01L9@1L:@1M3`1M2P1M<`-A=@-B*P-B,@1N2P1N3`1N
M6@5U805K:05L1`1H8@1H8P1M40-B+`%$(0%$(P0A)@%$)`,A)@,A)0(A)@%$
M-P%$-0%$.`%$-@(A)P%$8@(A+P(A+0%$80%$8`0A.0%%8@%%80%%8`0A50%%
M8P%%7P%'(@%'(P,B8@,B80,B8P0C-0,D/P%+9`,A(00A)P,A+`%$.0%$8P(A
M,`0A.@%$9`(A0P%(:P(E,00K7@,A(@%$.@%$90%%9`(A1`,G0`,A(P0A(@0A
M(P(A(0%$)0%$/`,A,`(A*`%$/0,A+@%$9@%%90%%9P%%9@0B)P%')`%')0,C
M10%+90,K(@%3?0%$(@0A)`(A(@%$)@%$/P%$/@,A1@,A10,B9`%')@0B*`,D
M0`%+9@0E,00E,`,K(P%8<0(S3@,Y;`,Y;@%C*@)!5@)!5P,A)`%$)P,A+0%$
M:`,B90%+9P%$*`(A*0%$0`,A,0%$:0%$:P(A,0%$;`%$:@0A.P,A;`,B9@%'
M)P%+:`,D0@,G0@%+:0%/9P$G*`%$00%$;0,A1P%'*`%'*@%'*0%(;`%+:@%+
M:P%/:`%/:0,K)@,K)0,K)P,K)`%3?@0V+@)!6`-`,P)M1`%$*0,A,@,A,P%$
M;P%$;@(A,@%$<`%$=@,A20%$<0%$<@(A-`(A,P%$=`%$=0,A3`%$<P,A2P,A
M2@0A/`%%:@%%:P%%;`%%;0%%:0%%<`(A2@0A6P(A1@(A20%%<0%&(P,A;0(A
M2`0A6@%%;@%%;P%%:`,A<@,A<`(A10(A1P,B;P,B:`%'-P(A;P%'-`%'.`(A
M>0(A;0%'-0(A<0,B:P,B9P,B=@%'-@,B;@%'.00B+0%'*P(A<`%'.@(A=`,B
M;0(A>`(A=0,B;`,B=`(A<@%'+`%'+@%'.P0B*@%',`(A:@%',P%',0%',@(A
M>@(A=P(A;@%'+P,B<`,B=P(A:P%'+0,B=00B+@,B<P(A<P(A=@,B<@\A<0(A
M;`(C*`0C.0%))`%(=0,D4`,D2`(C*0%(<@,D3P%))@,D1@%(>@,D10%(>0(B
M>P%(?0%(>`(C(@(C*@,D3@(C)@,D20%(>P,D2P,D0P%(?@%(;P%)*0(B?0,D
M1`,D3`(E/0%(;0%))0%(;@%(=@%(=P(C)`(B?@%(?`%(=`(B>@%(<`(C)P%)
M)P%)*@%(<P%)(@%)*`%(<0(C)0%)(P(C*P(B?`%)(0(C(0-D2`(C(P-D20%+
M>0(E/P(E2P%+<0,G1P(E3`%+;`%+=@0E/@,G3P%+;P(E.0%+=P(E.`(E/`(E
M0P(E00%,(0%+>@(E,P(E-0%+?`%+<`(E-@(E0@(E20%+=0(E.P(E-`%+=`(E
M-P%+>`(E.@,G1`%+<P,G40%+;@,G2`%+?0(E1`%+?@(E2`,G0P(E1@(E2@%+
M>P(E/@(E,@0E-@(E0`%+<@(E10%+;0(E1P,G3`,G20,G2P,G2@,G30\E1`%/
M>`%/;`,K+0,K+@(I(@(I*@,K-@%/:P%/<P%0(0,K+`(I,`(I+@(I*00H.`0H
M/@,K*P%/;0(I+P(I)0%/>P%/<@%/>@(H?@,K,@(I+`,K+P(I(P%/=@(I)`,K
M,P(H?0%/?0%/<`%/>0%/;P,K*`(I(0(I)@,K*0(I+0%/=P%/=`(I*`%/?`(I
M*P(I)P%/<0%/?@%/=0%/;@%/:@0H/P,K-0\I+0,K-`-D2@0H/0(I,0%4.@%4
M)`,O2`%4-`,O30%4.0(M<0(M<`(M=0(M=@%4)P,O1`%4,`,O6`,O3`,O5@%4
M/0,O1@%4,00K8@,O2P,O20,O1P(M:@%4*@(M:P,O3P%4/P0K9`%4-@%4(0%4
M(@(M?@%9)`,O4P%4+P%4+@(M;`%4,@(S7@%4*0(M=P%4.`%4-P%4+0(M;P(M
M>`,O10(M:0%4+`(M>0%4-0(M;0%4(P,O3@%4)@%4)0(M>@%4,P%4*`%4/`%4
M/@(M=`%4.P,O40(M?`(M;@(M?0,O0P(M<@0K80(M>P,O4`(M<P,O5`,O50%4
M*P-D2P(S9@(S6@,T/`%8=@,T/P(S7P(S90%8=0(S6`%8>0(S7`(S50%8=P(S
M60%8?`%9(P,T1`(S:@,T00(S5`,T0@%8?0,O5P(S:0,T1P,T/0%8>`(S6P%8
M=`(S5@(S4@(S8`(S4P(S40(S70(S8P(S9`%8>@,T0`0P1P(Z/P(S80(S4`(S
M8@,T2P%9)@(S9P%9)0(S3P,T0P(S5P(S:`%9(0%8?@%8>P%9(@,T3`,T2@%8
M<@,T10,T1@%8<P%>+@,Y=0(Z0@(Z.P0V-`%>*P0V,P(Z0P,Y<0,Y<@0V-@(Z
M.0(Z/`%>*@(Z/0,Y;P0V,0%>+0(Z000V/`(Z-P(Z-@%>+P,Y<`%>,`%>+`%>
M,0(Z-0(Z0`(Z/@(Z.`0V.00V,`0V.@%>*0(Z.@-D30-`.0-`/`%C,0%C*P)!
M7`%C-`)!8@)!90%C+0%C+@)!7P%C+`)!:`%C,@)!:0-`.@)!9`%C,P-`-P)!
M60%C,`)!6@0\*0)!8P)!80-`/0)!70%C+P)!6P%C-0)!8`)!9P)!7@)!9@-`
M-@-`/@%G?`%G>0-%:P%G>@1"+0))(0)(=P%G>`%G=0)(>`-%;@-%;`%G=P)(
M>P-%;0)(?0-%=@1"-0)))@-%<`-%=0)))0)(?@%G=`)(=@%G<@)(>0%G?0)(
M?`-%<0))(@%G=@%G<P)))`))(P%G>P)(>@-%=`%L(P)/5`-+*0)/40%L)`1(
M>0%L(@-+*P)/6`)/50)/3@%L(0-++0%L)0)/3P%K?@%L*`)/4@)/4P%L)@%L
M)P)/60)/5@)/5P-++`-+)P-D3@%P,P)60P%P,`)60`%P,@%P-`-0,0)600%P
M,01/6@)60@-0-0)6/P-0,`-0-`%S00)<20%S0@)<1P1590)<2`)<1@)<10-4
M00-40`)<2@%S0`-0,P15:0)A1`)A10-74@)/4`)A0P%S0P%X*P)E-P)E.`-<
M,@%Z8@%Z8P)K3P)K3@%[6`%[5P)N?0-@;P%$*@%$0@%$>`0A/0%$=P%%<P%%
M<@%'/@%'/0%'/P%'/`,B>`%)+`%)*P%)+0,D5`0C.P,D4P,D40%,(P0E/P%,
M(@%,)`,G4@%0(@0H0`$B>0(N(0$B>@%9)P$B?`$B>P(Z1`,Y=@$B?0%G?@$B
M?@->)0%$*P,A-`%$>0%'0`%,)0,K-P%$+`%$?`%$>@%$>P%'00,B>@0B-`%)
M+@%,)P%,)@%,*`,N>P%40`-`/P-D4P%P-0,A)P0A/@,A30,A2`,A3@(A+@0A
M4@%%=`%%=0,A>`,A>0%'0@0B-@(C+`,G50%0)`%0(P(N(P(N(@%9*`,A*`%$
M?0(A-0,A>@,D5P(E30,K.0%0)0,O6P%40P,O60%400%40@,O6@,T30]&7`%P
M-@$G+P%%=@0A7@%'0P(A>P,B?@,B?0,B?`,D60%)+P%),`,D6@(C+00C/0(E
M3@%,*0(E3P0E0`0E0P,K.P,K/0,K/@(N)0(N)@%41@,O7@(N)P,O7P(N)`%4
M1P%410%41`(N*`,T3P(S:P,T3@,Y?0,Y>@(Z100V/P,Y?@)!:@)))P-++P-+
M+@-+,`%L*0%P-P)61`-40@%$+0%$.P,A+P,A-0,A40,A>P,C(@\B60,D6P,G
M600E10%9*0%>,P9&90%H(0-%>@(A(P%$?@0A8`%%>0%%=P%%>`%,*@,G6@%$
M+@%$+P0A*@%$0P,A-@,A4@%%(0%%(@%%(P(A3`%%>@,A?0(A2P%'1P,C)0(A
M?0%'10%'1@(A?`,C)`,C)@%'2`%'1`,C)P(C+@%/3P(C+P,D7P,D80(C,`0C
M0`,D7`%),@%),0,D7@,D70%)-0%),P%)-`,D8`%,,`,G6P%,+P(E5`(E40(E
M4@,G7@(E4`%,,0%,+0%,+`,G7P%,+@%,*P,G700E3@-D3P%,,@%0)P(I,@,K
M/P(E4P%0+`,K0`(I,P%0*`%0*P%0*@%0*0%0)@,K0P(N*P,O:`%42@(N+@%4
M2`,O900K;@,O8@(N*@%42P%420%43`(N+`(N+0,O8`(N*0(N+P,O9@,O80,O
M8P\N+0,O9`,T4`%>-P%9*@(S;`(S;@(S;0(S;P%9*P,Z(P%>-`,Z(0%>-0%>
M-@,T40%C-P)!;`-`00)!:P)!;0)!;@%C.`-`0`%C-@))*`))*0%H(P%H(@),
M801))0-+,0%L*@%L*P%L+`%L+@)/6@)/6P%L+0-+,@-0-@%P.`1/9`%P.0-0
M-P15;0)E.0)K40)K4`)N?@-@+`%$,`,A-P,A5`,A4P%%?`%%>P%'200B0@0B
M/P(A?@0B00,C*`%)-P%).`%)-@%).0(C,0(C,@0C1@0C1P0C2`,D8P,D8@,G
M804E.@4E-P4E.`,G8`4E.P%,-`(E500E4`%,,P,G8@(I-`%0,`(I-0%0+P,K
M2`,K1@0H20%0+00H2P%0+@,K1P,O;P(N,`,O;`,O:@,O;0,O;@%9+`(S<0,T
M4@%9+P(S<`%;*P%9+@%9+0%>.@4V:@%>.0%>.`%C.0-`10-`1`%C/`%C/0%C
M.P0\/`%C.@-`1@5$9P))*@-&(0))*P5$8P-%?@-+,P)/70%L+P)/7`--+`%P
M.@)<2P%S1`538@)E.@%Y80$G-`%$1`%%)`(A-@,A50%%)0%%)@,A5@\A,`,B
M(P,B(@%%?0%%?@,B)`%'2@(C,P(E5@(E5P0E40%0,0(N,0%9,0%9,`(Z1P(Z
M1@90=`-0.`%$,0%%)P%&(00P7@%9,@(A)`0A90(A30%&(@,B)@(B(@%'3`%'
M2P(B(0%).@-D4`,D90,K200H3@0H4`%4300K>`0P7P(S<@%C/@))+`%H)`-&
M(P-+-`)610-41`-<-`)H:@,A*0%%*`,A5P,D9@(E6`(I-@%9-0%9,P%9-`%$
M,@0A,`%$10$D/P%%*P,A60%%*@%%*0%&)0%&)`,C*@(A3@(B(P\B+`,C*P,C
M+0%,.`%,-0%,-P%,-@,G8P%0,@,K2@0P8`%>.P1F,`%$,P,A6@%%+`,B)P%&
M)P%&)@(C-`0C30-D40%,.0,J7`0P9`,A*@0A,0(A-P,B*`%&*0%&*`%'30%'
M3@(C-0%).P,D9P%)/`,G90%,.@%,.P%,/`,G9@%0,P(I-P,K2P0P90%43@-`
M1P(A)00A1`%%+0,A6P0A9P0A9@,B*0(B)`,C+P(C-@(C-P(E60,G9P(E6@(I
M.0(I.`(I.P(I.@%0-`-D4@(S<P%44`(N,@%43P,T5`0P:`(Z2`%>/`,Z*`(Z
M20,Z)P-`2@-`20-`2`))+0%H)0-&)00\0`-&)@-+-0%L,`-410)E.P]M+@,A
M*P,A7`0A10(A.`,B*@%&*@0B2`,C,00E60,G:0,G:@%9-@,T50,Z*0%$-`%$
M1@%%+P%%+@,A7@%%,`,A8`0A:0,B*P,C,P0C3P%,/@,G:P%,/0%,/P,K4`,K
M3P%0-0,K3@,K308U>`%440-`2P)61@%V.P%$1P%&+`%&.P%&-@0A;`%&,0%&
M,`%&-P%&-0%&+@%&/`%&+P%&*P%&.@%&.0%&.`%&+0,B,0%&-`,B+0,B+@%&
M,P,B+P\A4`%&/0%&,@0A:@,C-0,C-P%'5`0B3`%'6@%'5@,C.0%'7`(B)0%'
M60%'3P%'4@%'50%'40%'6`%'6P%'4`%'4P%'5P%'70,C.@,C.P,C-`(C0`(C
M/0,D=@%)20(C/@%)/0%)/P%)5P%)4@,D>0,D?@,D=0(C10(C/P%)00%)0P(C
M1`%)2@(C.@%)5@%)6`%)/@%)3P,E)`(C.`%)50,D=P%)1@,D>P%)4`%)40(C
M.0%)3@%)3`,D<`%)30%)4P(C00%)0`,E(0%)5`(C0P%)2`%)10,D<P(C/`%)
M1`(C1@%)1P,D?`%)2P,D>`,D=`,D;0%)0@(C0@,D?0,E(@(C.P,E(P0E9`0E
M8P,G;@(E:P(E:@%,40(E;0(E;P(E9`(E9P(E;@%,4@,G=`,G>`(E80(E90,G
M=00E7P(E:0(I2@%,30(I3@%,0`(E9@%,00%,3@%,1P%,0P,G<0(E8@%,1@%,
M2P%,5`(E8P(E7`%,10(E70(E7P0E8`%,2`,G;`%,2@(E6P(E8`,G<`,G>0%,
M4P%,3P(E:`%,50,G<P%,3`(E7@%,20,G;P,G=P%,1`%,0@(E;`%,4`\E<0,K
M7`,K70(I20(I/0(I3`,K5P,K60(I/P%0/`%02@%0.`%020%000%01@%0-@(I
M/@(I1`%010(I4`%01P,K6P%0/0,K5`,K7@(I1@(I0P%0.P,K40(I/`%02`(I
M2P%00`(I30%02P%0-P%00@%0/P(I00%00P(I1P(I2`%0/@%01`%0.@,K50-D
M5`,K8P,K80%0.0(I0`,K4P(I10,K6`(I3P(N1@%47@(N-`0L+0(N.0%45P%4
M8@(N-P%44@%47`%480(N/@0L)@%470%48`,O=P,P(0(N00%46`(N.`,O=`,O
M>`,P(@(N1`(N10,O>0%46@(N0P%45@%4900L*0(N.P,O>P%45`,O>@(N2`(N
M/`(N0`%460%49`(N/0%47P(N0@(N20(T)`,O<P(N1P%49@%44P(N/P(N-@,O
M=@%46P0L*`0L+@(N-0,O?@,P)0(N.@\I5`\N0@\N2@(N,P%48P-G(0,T7P(S
M>@,T:`%920(T*@%91P%91`(T(0%90`(T)0%92P(S>0(S?@(S?0%450%91@(T
M*`,T9@(T*P(S=@0P=P%>3@,T9P(T+`%93`0P<@%9/@%9.P(T(P%9.`0P=`(T
M*0,T6P%9/P(T+0,T6`(S=P(T)P%90@(S>`(S>P(T(@,T8@,T80%90P%900%9
M30,T5P,Z-@,T9`0P:P%92`,T7@%9/`%:=@0P>@%9/0(S?`%92@%910(T)@%9
M.@,T60%9.0-D5P-D5@-G(@-D50(S=`(S=0(Z3@,Z/`%>/0%>0`(Z60%>5`(Z
M7`%>/@(Z50%>1`%>2@%A0P,Z,0,Z.`%>2`(Z4@%>50%>00%>20(Z6@)!?`(Z
M7P(Z4P0V7`(Z2@(Z5P(Z40%>1P(Z70,Z+@,Z*@%>0P%>5P%>4`,Z,P%>10%>
M0@,Z0`%>30,Z-`(Z7@(Z4`(Z5@(Z6`(Z3`(Z6P%>/P(Z2P,Z0@%>1@%>5@%>
M4@(Z30%>3`,Z.P\Y<0%>4P%>3P%>2P,Z+P(Z5`9'*0-G(P%>40)!>@)!=@-`
M40)")P)!;P)!>`%C3`%C30%C10)"(P%C3P)!=`)!<P)!<0)")0%C0P)!?0)!
M<@%C1@)!>P%C00)!=P)!?@)"(@-`3@0\2P)")@%C2@)!<`%C1`)!=0,Z*P%C
M/P910P%C2P)"(0%C1P%C2`%C3@%C0@$C(0%C0`)!>0-`3`-G)0%C20-G)`]`
M8@)")`-D6`%H-0%H,`-&+@))/`)).`-&*`)),@%H*@%H)@)).P%H)P))-0))
M-P-&*0)).@-&-@%H+`-&+`%H,P%H+01"5P-&*@)),`%H+@%H+P)),P%H-`-&
M-`)),0))-@%H*P))+P%H,0%H*0-&,P1"2P%H*`))-`)).0-&,0%H,@-D6@-D
M60-&4`))+@-&,`%L-P)/;@-+00)/:P-+.`%L,0%L/0%L/@-+/0%L-`)/:0%L
M-@)/80%L/`-+1`)/;0%L,P)/;P%L,@1),0)/:@)/;`%L-0)/:`)/8@)/7P1)
M+@-+/@(Z3P)/90-+-P)/7@)/9`)/8P-+.P)/8`-+0P%L.0-+10-+0`-&-0-+
M/`%L.`-+.0<A8P-+/P%L.@)/9@%P.P)/9P)63P-0/P)62`-00`%P1P)63`%P
M/P%P0P)62P-0.P%P0@%P/@%P00%P/`%P1@)630)620%P10)61P%P1`)63@)6
M2@%L.P1/<0%P2`)64`%P0`%P/0]370-0/0-42`)<4@)<5`%S1@)<50)<4P)<
M40)<4`%S2`)<3P%S2015=`-420-41P15>`)<30)<3@%S10%S2@%S1P-D70-D
M6P)<3`-76P%V/`-76@)A2`)A1@)A2P)A20-76`)A1P)A2@-760-75P-77`%X
M+`)E/@)E/P%X+01?30)E0`)E/`)E00)E/0%V/0-:+0-D7@1C,0)H:P)H;0%Y
M9`)H;`%Y8P%Y8@-G)@-G)P-D7`->)@%Y90)K4P)K5`1F-`%Z90%Z9`%Z9@)K
M4@-G*`)M1@)M10-?0`%[60%[6P%[6@)M1P%\-`)P-`1J1`1J0P%\70-@<0)P
M,P)P?`(A*@,A=P0A;P%&/P%&/@0A;0%'8`%'7P(B)P%'7@(B)@,C/@%)6P(C
M20,E+`(C2`\C4`,E)@%)60%)7`,E*P,E*@(C1P,E*0%)6@,E2`,E)P,E*`,H
M(@(E<`,G?0(E<0%,5@,G?`,H(0,G>P%03`,K90(N2@(N2P%49P%4:`,P)P(T
M+P%93@%94`(T+@%93P(Z8`%>6`,Z1`,Z0P0V:`0\4@%C4`%C40)"*`-`4@%H
M-P-&-P%H-@)/<`)64@)640-?00)Q6@%$2`(A.0,A80(A3P(A4`,B-`0A<`0A
M<0%'8P%'9P(B*00B40%'90%'9`(B*`%'9@%'8@,C00,C0@%'80(B*@,C/P,C
M0`%)9@,E,0,E/@%)8P,E,`%)7P(C2@,E0`,E-@,E+P(C2P,E/`%)80,E+0(C
M30%)70(C3@(C3`%)8`%)8@%)90%)9`%)7@(C3P,E,@,E00,E0@,E,P,E.`,E
M-P-D7P\C4@,E-0%,6P(E?@,H)0%,70,H(P%,7`,H)@(F(0%,6@%,60(E=00E
M:0(E=`,H*`(E<@(E=P(E=@(E<P(E?`(E?0(E>@(E>`%,6`,H*00E9@0E:`(E
M>P%,7@(F(@0E90,H*@(E>0,H)`%030%,5P0E;@\F,P-D8`%03@(I50,K:0,K
M:`(I6P,K;`,K9P,K:@%05`(I60(I7P,K<0(I5@(I6@(I7`(I7@(I6`,K<`(I
M5P(I4@(I4P%03P,K:P%040%04`(I5`(I70,K;0,K<@,K;@0H8`\I:@\I<0,K
M9@%04P0H7@(I40(N50,P*@(N5`(N60(N4`,P,`(N4P(N4@,P+P(N5@,P.`(N
M6@%4:0%4;`,P-`,P-0(N40(N5P,P,P,P*`,P-P%4:P(N3`,P*P%04@(T/0(N
M6`,P-@(N3P0L,P%4:@(N3@\N7`,P,@(T-`,T;@,T<0%940%950(T1`(T,@(T
M0`%95@(T0@,T<@(T2`,T=`(T3`,T:00P>P(T0P(T-P(T/P,T:P(T30(T2P(T
M00(T/`(T-0(Z:`(T,P%96@(T.@%96P%95P(T,`(T1@(T.`,T;P,T=0(T-@(T
M20%96`,T=@(T3P%94@%95`(T/@(T.0%4;0%94P(T.P(T2@(T3@(T10-D80(T
M1P-D8@-D8P(T,00V:0,Z2@(Z8P,Z10(Z;`(Z:P%>8`(Z9`,Z1P%>80%>7P,Z
M4`(Z9@%>7`(Z:@,Z3`(Z90(Z9P(Z80%>6@0V;P(Z=`(Z<P(Z<`%>60%>70%>
M7@(N30(Z;0%>6P%960(Z;P(Z8@(Z<@(Z<0,Z3@(Z=0,Z20)"-@,Z2P(Z;@\Y
M?0\Y?@0\5P0V;00V<0-D9`(Z:0)"+@%C6P%C7@%C60)"+0)",0)"+`-`5P%C
M4P%C70)"*0%C5P)",`-`6P%C50%C5`)",P%C5@)"-0-`5@)",@%C4@-`7@-`
M7`-`6`%C7`)"-P)"*P)"-`-`700\4P)"*@-`6@-`60%C6`-`5`%C6@)"+P)"
M.`-&0P-&/@))1`%H.`))2@-&0@-&/`%H/0))1@))30))/@%H/P%H.0))0P%L
M/P))0@))2P%H.@-&/0%H/@))00))1P))3`))/0%H/`))10-&.@-&10))20))
M3P))/P))2`-&.`%H.P))3@-&00-&1`-&0`))0`1"60-D90%L0P)/<@%L00%L
M0`)/=`)/>0-+1@)/=0-+4`)/>`%L1@-+40%P+@%L10-+2P)/<0)/=P-&/P%L
M1`)/=@-+30)/<P-+20%L0@-+3P-+3`-+1P)65P-02@)660)65`%P2@)65@-0
M2P%P20)66`-02`-03`%P3`)66@%P2P)64P)650-020-42P%S3@)<6`-43`%S
M30)<60%S3`)<5P%S2P)<5@%V/P%V/@)E0@)E1`-:+P)E0P%X+@%X+P-:+@=&
M10%X,`)H;@%Y9@->*`)O(@)O(0%\7@%$20%%,0,C0P%)9P,E10,E0P,E1`,H
M+0(I8`,K=P,T=P%>8@%>8P,Z4@)".0%H0`))4`)/>@-D9@-030,A.0(A.@,B
M-0,C1`(C4`,K>@,K>0,A.@,E1@(F(P(I80(N6P%4;@-&1@-E8`)E101?4@%Z
M9P%$2@%&0`(A40,B-@%':`%':00B4@%,7P0E<`,T>0%97`4W/0%H0@-`7P%H
M0P%H00-+4P%$2P0A20%%,@%%-`%%,P(A.P%%-0%&00(A4@,B.`%&0@,B-P0A
M<@,B.00B4P,C1P%':@%':P(B*P,E20%):`0C8@(C400E=0%,8P(F)`0E<@%,
M80%,8@%,8`(N7`,H+@,H+P-D9P%06`%05P%060%05@,K?`(I8@%,9`%050%4
M;P%4<`0L.`%4<0,T>P(T4`,T?`,T?00Q)@%>9`(Z=@%970,Z4P,Z5`0V>0-`
M8`%C7P-`80%H10%H1`))40-&2`%L1P%P301/>P)A3`)M2`)O(P%$3`%&0P,B
M.P%&1`(B,0%';0%'<`,C2P(B+P(B+0%';P(B,`(B,@(B+`%'<@%'<0%';@%'
M;`(B+@,C30,E50%)<P0C9P,E3`%)<`(C5@(C60(C6`0C:0%):@%)<@,E2P0C
M:@%);P(C50(C4P%);@,E5@,E4P,E3@%):0%);`,E40(C5`(C6P(C5P%);0%)
M<0%)=`(C4@(C6@%):P,H00,H,P%,:0%,<0,H.`(F,`(F*0%,<@(F-`(F)0(F
M+`,H10,H0`%,:`(F)@%,9@(F+0(F,0%,90,H/0(F,@(F*P,H-P(F+@,H-0%,
M=`%,:P(F-0(F,P,H/P%,<`%,;@(F*@%,;0(F*`(F)P%,;`%,:@%,<P%,;P%,
M9P,L)@(F+P,H1@%06P,L+0%08@(I<`%06@(I:`(I9`,L(0(I=`(I8P,L+`%0
M70(I;0%08`%08P,L+@%07@(I<0%080,L(P%4>`(I=P(I90,L)`,L)0(I9P(I
M;@(I<@(I=@(I<P(I;`(I;P,L*P,L*0(I:0%090(I:P(I:@(I=0%07`(I9@%0
M9`,L*@%07P,L*`%4?@(N9`,P0`%4?0,L)P0L0`(N8@0L/@%4<@,P3P%4=P,P
M2@(N80(N7@(N8P%4<P(N70,P3@%4=@%4=`,P/@(N90%4=0%4>0,P.P,P10%4
M>@,P2`%4?`,P4@0L.00L/0%4>P,P/`,U(@,U.`(N7P(N8`,P308V5P,P2P(N
M9@(T5P%97@([)@(T5@(T:0,U*`,U)`%99`,U,0(T9P,U,P%98P%97P(T<`(T
M8`(T8P,U+@%99P(T;0(T90%98`%9:`,U*@(T:@(T:`,U+P,U.P(T60(T;@(T
M8@(T70,U.@(T4P(T;P(T7P(T4@,U.0%99@(T9`(T<0(T80(T50(T6@(T40,U
M)P%990,U/`(T7@(T6P%980(T5`,U,`(T;`%98@,U*P(T7`(T6`,U*0,U-`(T
M:P,U,@\S<P,U-P,U-0%>90(Z?0,Z=0(Z>@([+0([(0([+@,Z?`%>9P,Z8P,Z
M80,Z6`([*@([)P,Z6P,Z=P,Z<@,Z60,Z8`([*`([*P([+P,Z>P(T9@([,0)"
M30,Z9@%>:`([,@(Z>`([)`,Z8@([*0,Z7`,Z7@%>9@%>:0([,`([,P(Z?`(Z
M>0,Z<P,Z6@(Z>P,Z5P,Z>@([(@(Z?@%>:@,Z5@([+`,Z>0,Z>`([(P([)0(Z
M=P)"00)"/P%C:`%C9@)"20)"0`)"2@)"1@)"/@)"3`)"/0)"1`%C90%C9`%C
M8P)"0@)"1P%C8`%C9P-`9P)".P-`9@)"10)".@)"0P%C80)"2`)"/`%C8@)"
M2P-`9`,Z:P-`:@-D:`-D:0))50%H2@%H20%H2P))80))5P))70))4@))8`))
M7P))8P))7`%H1@))6P%H3`-&3`))5`%H1P-&2@))8@%H2`))5@))60))7@))
M6`))4P-&3P-&4P))6@)/?`%L2P)0(0)/?@)0(P)0)0-+7`%L20-+6`)/?0-+
M5`)/>P-+7@)0)@)0)`)0(@-+5@)0*`-+6@)0)P%L30%L2`-+6P%L2@%L3`-+
M70-+7P)0*0)680-04`-04P)68`)67P-040)68@)66P-03P)67`)69`)670-0
M5`%P3@)69@-03@)690)67@-05@)<70%S40)<6P)<8`)<7P)68P-44`%S4`-4
M3@)<7@)<6@)<8@)<80%S3P-44@)<7`-43P%P3P-440-44P%V0`-:,0-780-7
M7@)A30)E1@)E1P)E2`%Y9P1C-`-<-@%Y:`-<.0)H;P-<.@)K5@)K50->*0-?
M0@)M20)M2@)O)`)P-0-@<P%$30%$3@0A,@%$3P%%-@%&10(B,P%'<P%'=`%)
M=P%)>`%)=@%)=0%,=0,H2`0F(@(F-@%,=P%,=@(F-P0F(P-D:@0H;@%09@,L
M+P%5(0(N9P(T<P0Q+`%9:0%>;`(T<@%>:P-`<0%H30-`<@))9`%P4`-05P%S
M4@)<8P-:-`%Y:0-<.P%[7`,A.P(A4P,B/0%&1@(A5`%'=P,C4`%'=0%'=@%'
M>`0C;P%)>@%)>0,E6@(C7`%)>P0F)0(C70(F.`,H3`(F.0,H2@%,>`%,>@%,
M?`%,>0%,?0%,>P,H3@,H2P,H30%0:@%09P%0:0%0:P%0:`(N:`(I>`\J.0,L
M,@(N:@(N:0%5)P0L1@%5(P0L208V9@%5)`%5)@%5*`%5)0,P5P%5*@%5*00L
M2`,P5@,P50\N?@%9;@(T=0(T=`%9;0,U00%9;`%9:P%9;P%9:@,U/P([.0([
M-@%>;@([-0([.@0W)`%><`([.`%>;0%>;P([-P,Z?@)"3@-`=`)"3P)"4`-`
M=0-`=@-`<P0\;@%H3@%H5@))90%H4`%H5`))9@%H50%H40%H4@%H3P%H4P%L
M4`([-`%L40%L3P1)1`%L3@)69P%P40)<9`)<90-:-01?50%X,0%Y:@->*@%$
M4`,B/@%'>0,E7@,E7`,E70,H4`%0;`(N:P%5*P,P6`,P60%9<@%9<0%9<`%>
M<0%><@([.P%H5P%P4@%$40(A/`%%-P(A500A<P,B/P(B-`%'>@0B7`,C4@,H
M40%,?@,L-`,[)`)"40-`>`-E)0%$4@0A2P%%.`(B-0(C7@0F*0(C7P,E7P%)
M?`\E5`,L-0([/`%><P)"4@1)20-45`%S4P%$4P%$9P%%.0(A5@%&1P,C5`%*
M(@%*(0%)?0%)?@(F.@%-(@%-(P(F.P%-(0,H5`,H50%0<`(I>0%0;P%0;0%0
M;@%5+@%5+`,P6@,P6P(N;0%5+0(N;`-D:P%5(@(T=@0Q-0,U0P%9=`%9=0,[
M)@,[)0%9<P,U1`%H6`))9P%L4@%L4P)0*@%S5`)A3@)A3P-:.`%Z:`)P-@(A
M*P%%.@0B7P%$5`(A6`(A5P0A=@-D;`,C50%'>P(B-P(B.`(B-@0B8`(B.0,C
M6@\B1P,E80,E9@(C9P0C>@(C8@(C9`(C9@(C8P%*)@(C8`,E8@(C80%*(P%*
M)`(C90(C:`%*)0(C:0\C?`\C>`,E8P(F20,H70(F0P(F/@%-)0(F1@(F1`(F
M/0(F2@(F30(F2`(F00%-)P(F1P%-*`(F0@(F10(F/`(F0`(F3`%-*00F+P%-
M*@,H7@(F/P(F2P%-)`%-)@,H7`,H7P,H5P0F-`,H6`(J+`(J)0(J*P(J)`(J
M)@(I?@(I?`,L/P(J+0(J*@(I>@,L.P%0<@(J*`(J*0-D;0(J)P(I?0(I>P%0
M<0(J(P(J(0,L/`,L0@(J(@(J+@,L/@,L00,L0P,L/0%5,P,P8P%5,@,P7P(N
M;@%5+P(N<`,P9`%5-`(N<00L8`,P80%5-P,P8@%5-0(N<@(J+P(N=`,P7@%5
M,00L7`%5,`0L80(N;P(N<P%5-@%9=P%9=@,U2P,U2`,U1P(T>`(T?`(T?@%9
M>`(U(P,U40%9?`(U)0,U4@%9?@,U3P%9>@%:)`,U50%:(0(T>@%9>0,[*P(T
M>0(T=P(U)P(T>P,U1@%9>P(U)@%:(@(U(@(U(0%:(P(T?0%9?0,U3@8^=@,U
M2@(U*`,U5`(U)`([2P([4@([1P%>=@([0P([4P([/0([4`([3@([2`,[-@([
M40([2@,[*`([0@([5`([0`([30([/@,[)P([50,[-P%>=P,[*@([3P)"50([
M00%>=`,[+@([10,[-`%>=0([1`([20,[,P0W-0([1@0W+P,[,0([3`,[+0)"
M600\>0-!(00\>P)"7`)"5`-`?`)"5@-`>@)"6P)"6@%C:00\=0([/P)"6`-`
M>0-`?0%C:@0\=`)"4P)"5P0\?`0\>`-D;@));@-&7`))=0));`-&5`))<P))
M:@))<@))=@)):0));0)):`-&5@%H601#+`)):P%H6@))<0))<`));P-&60-&
M6@))=`-D;P-+90-+9@-+8P)0+@)0,`%L50)0,0-+:P)0+`-+9P)0*P)0-0-+
M:0)0,P%L5`)0-@)0+0)0,@)0-`)0+P-+:@-+:`-D<`-06`)6:P)6<`)6:@)6
M;P-06P)6:`)6<@)6;@)6<P)6;0)6:0)6<0-06@)6=`)6;`-D<0)<9@%S6`-4
M5P%S5@-460%S50%S5P-450-D<@)A4`-78@)D/@)E20-:.0)H<`)H<0-</0%Y
M:P-</`)K5P-</@%Z:01F.P)K6`->+0)M3`%[7@-?0P%[70)M2P%\-0-@,`)O
M)01K:`1J1@,A/`0A+`%$50%'?`(B.@(C:@%+5@%:)0,U5P-+;`%$5@%&2@%&
M20%&2`0B8P%*)P%5.`)"70%$5P%$6`%$60%%.P,E9P,H8`%0<P0L9`(J,`,L
M10,L1`%>>`%$6@(A/0,A8P0A3`%&2P%&3`(A60%'?04B7`,C7`,E:`(C:P,E
M:P%**`0D(P(C;`%-,`,H8@,H80(F3P%-+@%-+0(F3@%-*P(F4`%-+`%-+P%0
M=`,L1@%0=@(J-`(J,0(J,@(J,P(J-0%0=0(N=@(N=0,P9@%5.@,P:0%5.0,P
M:`,P:@,P9P,U6P%:*`(U*@,U60%:)P%:*0%:)@,U6`,U6@%>>@(U*04W?`%>
M>P([5P,Y>0%>?`([5@%>>0,[.@,[.P,[/0)"8`)"8@%C:P)"80)"7P)"7@0]
M*@1#-0-&70))>0%H7P%H701#,`%H7@))=P))>`-+;0%H6P)0.@)0.`-+<`%L
M5P)0.0%L6`%L5@%H7`].7@-D<P)6=P)6=0)6=@)0-P)<:`%S60)<9P)A40)A
M4@)6>`)E2@-F=P%$6P%&30%((0(B.P%'?@,H8P%-,0%C;`,A/0%%/`%&3@%0
M=P%>?0,A/@(A6@,B1P(A6P,B2`(B/`-F>`%**@(C<`(C;@%**P(C;0(C;P(C
M<00D*`%**0,E;@,E;0%--0%--@%-,P,H90,H9P%-,@(J.0%--`,H:`%0>`,L
M2`(J.`(J.@(J-P(J.P%0>0%5/0(N=P,P;`(N>0%5.P(N>@%5/`(N>`,P:P(J
M-@(U*P(U+@(U+P(U+`%:+0%:+`%:*@%:*P(U+0,U80,U8`,[/P%:+@,[0`,[
M/@%?(0%?(@9(10%?(P)"8P)"90)"9P%C;@%C;0%>?@)"9@)"9`-D=`))?0-&
M80-&8`))>P)*(P%H8`)*)`)*(0%H80))?`))>@)*(@%L6@)0/`))?@%L7`)0
M/0%L6P%L7@)0/@%L60%L70)6?0)6>P)6>@)6?`)6>0-07`1;(0%X,P-D=0)H
M<@)H<P-</P)K60)M30%](@,A/P,C80%--P%*+`,H:0,H:P%0>@,L3`,L2P,P
M;@%$7`%%/00A30%&3P(B/0,E;P%*+0(C<@,H;0(J/`%0>P%H8@%$70,A9`,B
M20,C8@%((@\B3@,[0@%C;P%$7@%%/@%%/P%&40%&4`0B:P(B/@%((P0B;`(C
M<P,E<0%*+@,H;@(F4@(F4P(F5`,H<`%-.`%-.0(F40%-.@0I+`0L<`%0?`(J
M/0,L30(N?`%5/@,P;P(N>P,U8@%:+P(U,`%:,`(U,0,U8P,[1P,[10%?)`0W
M10,[1`0],`)":`]!/P-!(@)*)@)*)0%H8P1)7@%L7P)0/P%P4P)6?@%S6@-7
M8P%[7P)O)P,A0`,A00,B2@,C40(F50,H<0(J/@%:,0([6`%C<`-!(P-07@]4
M0P-79`%V00-A9`,A0@%*,`,E<@%*+P%0?0,L4`(N?0%:,P%=*0%:-`%:,@%?
M)0-!)`)*)P%H9`%L8`-?10(A+`(B/P0B;0(C=0%*,0(C=`%*,@0D+`%-/@(F
M6`(F5P%-/0%-.P%-/`(F5@,H=@,H=0%1(0(J/P%1)`%0?@%1)@%1(@%1(P%1
M)00I,0,P<`,P<@%500%50`%5/P,P<0-D=@(U,P%:-0%:.`%:-@-D=P(U,@%:
M.P0Q4P%:-P(U-`%:.@%:.00Q4@0Q5P0W2@([6@([60,[2P%?*`%?)@%?)P([
M6P%C<0)":@%C<@)":00]-`1#/P)00`-&8P-&9`%L8@)**`%L80-+<@%H90-D
M>`)7(@)7(0%S6P)<:0)E2P)H=`)H=0->+P%%0`0A-@%&4@,B300B<0(A7`,B
M3`4B9@%*-`%*-@,E>`(B0@(C>`(C=P(C=@,C9@(B00(B0`%()0%*-0%*,P%(
M)`,C9P,C:0,E=P%-/P(F60,E>P%-0`(C?00F4`(D(0(C?@(F6@,E=@,E=`(C
M>@,H?@%*.@%*.`,E?`(C>0(C>P(D(P,F(@%*-P,F(0(C?`(D)P%-0@,E?0(D
M)`%*.0,F(P(D(@(D)0,E>@%-00,E=0%-0P(D)@,H>`,I(@(F;@(F80(F7P(F
M;0(F:`%1*P%-1`(F:0(F;`%1)P(F:P%-10%-2@%-2`(F8@0I-@(F70(F9`%-
M3P(F;P%1*`(F900F3P%1*0%-2P(F9P,L6@(J3@%1*@(F7`%-3`%1+`%-30%-
M20%-3@(F9@(F6P(F:@%-1@,H=P,L6P(F7@(F8P(F8`%-1P,H>@(J0`0I10(J
M00,I(0(J2P(O(P(J3`%1,@(J3P(J10%1,0(J1P0I/P(J2`,L8`,P>0(J2@%1
M+0,L5@,P<P%510,L5P,L70(J1@(J0@%51@,P?@0I/@(J4`%50@(O(0(J20,L
M5`(N?@(J1`(J30,L7P,L80%1,`%50P%1-@%51`(J40(O(@%1+P%52`%1-0%1
M-`%1,P%51P(J4@%520%1+@0I2P(J0P,P>@,P>`,P>P,L7`,P=@%:/`(O)@(O
M*`0M)0(O*@%52@%54`(U-P(O+@(O)0%:/@(U-0,Q(@%53P%530(O,`0M+0(U
M-@0M+`(O)P,Q)0%53@(O*P%540(O+0,U:`,P=`%53`(O+`(O+P(O*0,Q)P%5
M2P%:/P,U<0(O)`%:/0,U<@0Q:P,Q(P,Q*`%:0`,Q(0,U;P,Q)@(U.0(U0@%?
M*P,[5`%:0@%:1P%?+`(U1`%:3@([70(U.@%:1@%:20%:1`(U.`(U1@(U20([
M;`0Q:`(U1P([80%:10%:3`%:4`(U00([7`(U10%:00([7@(U2`([8`(U/0,U
M:@%?*0,[5@(U.P(U/`%:2P,[50,U;@%:2@(U/P%:3P(U0P%:2`(U0`,U>0%:
M30%?+0%?*@([7P,[6`(U/@,[60%:0P,U=@,U>`,[6@,[30,U=`%?,@%?-@([
M8P%C=P%?-`([9P%?.`)":P([:0%C>0%?,`%?,P([:@,[7@([:P([<0%?.@%C
M>@0]/0([;0([<@([9@%D)@,[3P%C>P%?.0([9`([<P,[40%D)0%?-P%C=`([
M<`,[70%?.P([:`([8@%?,0([904_,`([;@-!*P%C<P%C>`%?+@([;P,[80%C
M=@,[8@,[8P,[4`%?+P-D>0%D)`)**@)"=@-!*0)";@)**00].0)"<@)"=`-!
M)P-!+`)"<0-&;P%D(P0].`)"<`%D)P-&;@929`-!*`)*.0-&;`-!+@%D(@%H
M9P)"=P)**P-&;0-!*@%C?@)";P)"<P%H9@%C=0)";`)";0%H:`%C?0%D(0%C
M?`)"=0-D>@)*+P)*,`)*-0%L9P)*/`-+<P%H;@-+?@%H;0)*-P-+=`%L9@)*
M+`%H;`-&<0)*.P%H:@%H:P-+?`)*.`)040%L9`%?-0-&<@)*.@%L:P)*,@1)
M;P%L90-&:@%L:@)*+0)*,0)*+@)*-`%H;P%L8P%H:0-,(0)00P)*-@-&:`%L
M:0-&<P%L;`<B<0)*,P-&:P%L:`)00@5-*@-,(P-&=`-,)`-+=P)01P%P5P)0
M00)7+@)04`%L<`-+>@%L;@%P50)030)020%L=`-+=@)7)0-0:`-,*`-09P%L
M<@)02`-,*0)7(P-,)0)03`10.P)03P)01@-+>0%L<P10-P-+=0%L;0)7)`%P
M5@)03@%L;P%L<0)02P%L=0)02@)010)01`%P5`)04@)7)P)<:P%P60-080)7
M+0-08P)7*P-0:@)<;`-09`%P6@)7+`-09@)7*0%S70)<:@-0;`)7)@)7*`%S
M7@%P7`%S7`%P6P%S8`)7*@%P6`-08@-090-0:P-F>01;*P)A6P16,P)A4P-4
M80-47P-47`-47@-470)<<@)A5`)<;@16,@-46P%V0@)<<`)<;P%S7P)<;0)<
M<0)A7`)A6`)A6@1?8`)A50)A5@1?80)A60)A5P%X-`-790%X-P%X-@%X-0%Y
M;`)H=@%Y;0)E3`%Z:@)K6@%Z:P%[8`%\-@)O*`-?1@)O*0)O*@-A/@)R*@%%
M00(A70%&4P%()P%(*`%()@,C:P%(*0%*/`%*.P,F)0(F<`%-40%-4`,L8P(O
M,0%:40%:4@0Q;@0Q<`,[9`%?/`)">`%D*`%D*0)">@)"?`)">P0]0P)*/@-&
M=@)*/0%H<`)*/P-&=0)04P%L=@-,+`%P70-0;0%S80%V0P%S8@-?2`%%0@,A
M90,A9@,B3@(D*`,F*`,F*0(F<0%-4P%-4@%-5`%1-P(J4P(J5`,Q*0(O,@%5
M4@%:4P%?/0([=`%%0P0A-P%$7P%%1`,B4`(A7@%&5P%&5@%&5`%&50,C;P%(
M+`(B20(B2P%(*P(B0P,C;`(B1`,C;0(B2@(B1@(B2`%(*@(B10(B3`(B1P,C
M;@\B40%*0P%*3`%*2@(D,@(D+P(D-P%*2`(D.`,F.0%*00(D-0,F+@%*1P(D
M,0(D,`%*10(D-@%*1@%-50%*0`(D,P,F*@(D*0%*/0,F-P%*4`(D+@(D-`%*
M0@%*1`,F+P(D*@,F-@(D*P(D+`0D.0%*3P%*20%*3@(D+0%*30%*/P%*/@%*
M2P,F-00D/`,F,P,F-`,F.`,F,0-D>P\D.0,F,@,I,0,I*@%-8P(F?0(F=@%-
M7@%-<0(F<@(F>0(F>P(F?@%-;`,I)@(F>@(F<P%-:@(F=P,I*`(G(0%-6P,I
M)0(F?`%-90%-9`(F=0%-60,I-`,I,@%-6@\G,`%-6`,I,P%-<`%-:`%-8@%-
M5@(F>`%-80%-5P%-:0%-<@(J50%-9@(F=`%-7`%-7P%-8`,I+@%-;@%-;P%-
M;0%-9P%-:P%-70%1.`,I,`,I-P,I-0,I-@,I+P,I*0,L;0(J6P%11`%1/`%1
M/@%10P(J9P%100(O,P%54P%11@(J6`(J8`%10@(J7P(J7`(J9`(J9@%1.P%1
M/P%110%550(J80%1/0%12`(J6@,L;P,L<`4I10%10`%55`%1.@0I60(J5P(J
M7@(J5@(J60(J70(O-`%11P0I40(J8@(J8P(J90%1.0,L;`,Q,@,Q,P,L:P,L
M;@0I6P%58P(O0`%580%58@(O-@(O1@,Q+`%56`,Q+P,Q-0(U2@(O2`(O0@,Q
M.`(O.0,Q-P(O2P(O/`%57@(U80(O/P%58`%55P,Q/`(O30(O00%56@(O.@(O
M-P(O.`%56P(O1P(O3@%570(O/@(O/0%590%59`%55@%57`%57P(O2@,Q+@,Q
M.0(O1`%560(O-0(O3`(O0P(O10(O20,Q,`,Q.P,Q-@-D?`-D?0(U2P,V,0%:
M6P%:;P%:;@,V)P%:8P,V*0(U70(U60(U5@(U:`%:7@%:5@,V)@,V,@(U6P%?
M30%:6@(U8P,V(@%:<`%:;0(U7P(U3@,U?`,V*P%:;`(U90(U30%:80%:90(U
M9`,V(P(U5P%:9@%:8`(U3`,U?0%?/P(U9P(U50%::P(U6`(U9@%::@,V)`([
M=00Q=P%:5P(U4P%:7`%:9P0Q>`%:8@(U7`(U4@(U4`(U8@%:5`%::`%:6`%?
M/@(U8`%:600R(P%:50%:9`%:7P%:70(U5`%::0(U40(U7@(U6@([=P([=@,V
M+0-D?@,V+@(U3P(\*0,[<0%?00,[<`(\+P([?`(\+`)"?0%?1`(\,`(\,P%?
M0P(\(0(\,@(\,0%?10([>`%?0`%?2`,[<P%?1@(\+@0W<0(\)`%?2@(\-0(\
M+0(\-@%?4@%?4`(\*P(\*@,[9P(\*`(\(@%?20,[9@%?1P(O.P([>0,[:`)#
M/0([>@%?0@%?3P)#(00W8`%?2P%?3`([>P(\-`)"?@(\)0([?@%?3@(\)@(\
M(P,[<@,[;0%?4P0W;P,[;P-E(0%D.`-!20-!,@)#)`)#-P)#/`)#,`%D-`)#
M00%D,0)#(@-!.@)#(P%D*@%D,P)#*@%D-@%D-P)#*P-!.`)#.`)#/@%D,@-!
M/@%D+`)#*0)#)0)#0`)#+@)#+P)#)@)#.@)#,0)#.P)#,P-!/0%D+0)*0`%D
M,`%D+@)#/P)#-@)#,@-!-@-!,P)#)P%H>@)#-0%D-0)#+0-!-`)#+`-!2`-'
M)0-!0@%D+P%D*P)*50)#.0)#-`)#*`-!1`-!10-F=@)*4`-&>`)*00)*3`-'
M*`)*4P%H>`%?40)*40%H<P-&?@-')`-&>@%H<@)*6`1#70)*0@)*3P)*0P)*
M3@%H=@)*4@(\)P-'(01#7@-'*@)*60)*2@%H>0)080%L=P-'(P)*5P)*5@%H
M>P)05`%L>`)050-'(@)*1@)*1P)*1`)*20)*10)*6@%H=0%L>0%H=P%H?`-&
M>P)*2`-'*0)*5`-,+0-')@)*30-,-0)06`-,.`%H<0%L?`)7-0)070)07`)0
M7@-,,`-,+P)06P%L?0-,.P%M)0%M(@-,,0%M(P)05@)060)08P%M*P%M*0-,
M+@)06@([?0%L>@)08`)05P-,/@%M+`)07P%H=`%M(0)*2P-,/P-,-`%M)`-,
M/0%M*`%M*@%M)P%M)@-,.@%L?@)08@%L>P%M+0-,.0-E(@-,-P%P80%P8@)7
M-`%P:P%P:`-0<`%P7P%P9@)7-@%P9`%P7@-,,@%P90-0=P)7,P%S9`%P8`54
M7@%P9P%S8P)7,@)7,0-0=@%P:0-0;P%P:@-0>0)7,`)7+P%S90)7.0%P8P)7
M-P-0=0-49`%S9@-49P%S:P)<=0)<=P-7:P%S:`-7;0)<>`)<=`-7;`)<=@%S
M:0%S;`-4:0)<<P%S9P%S:@%V10)7.`%V1`<_8@-7:@%V2@)A8`-7<`%V2`%V
M20)A8P)A7P%V1@)A70%X.`)A801;-@)A8@)A7@-7;@%V1P)E30-:.P)E4`-:
M/`-:.@)E40)E3P)E4@%X.0)E3@->,0)H>@%Y;P)H>0)H>`)H=P%Y;@%Y<`-E
M(P)K6P%Z;0%Z;`-?2@-?2P)M3P)M3@)M40%\-P%[80)O+`)M4`-?20-@,@)O
M*P%\.0%\.`%\7P)P-P)P?0%%108C;`,L<@(\-P)7.@,A9P,A:`%(+0(B30%*
M4P%*400D/P%*4@0D/@(G(@%-<P%120,L=`(J:`,L=@(J:0,L<P%12@(O4`0M
M0P%59@%59P(O3P,Q/00M1`,V-P,V-@%:=P0R*P%:<P0R+P(U:0%:>@%:>0%:
M<@%:=0%:>`%:=`,V-`(\.P%:<0%?5`,[=`,[=0,[=@%?5@%?5P(\.@(\/0%?
M50(\.`(\/`(\.0-!2P%D.0-!3@0]70)#0@-!30-',`%H?0)*6P%P;`%M+@)0
M9`%M+P%M,`)09@)090)09P)7/`)7.P)<>@)<>0%S;0%S;@)E4P-<00%%1@,E
M6`,I.00M1P,Q0`(\/@,V.`,V.0%?60%?6`)#0P)A9`%Z;@)O+0%%1P0D00%5
M:`,Q0@%:?`%:>P(\/P(\0`%D.@)*7`%H?@)7/016/P%%2`%&6`,I.P%-=`(G
M(P(J:@%12P%:?0,V.@(\00%?6@%D.P0]8P)0:`)0:0103@-4:P)<>P%V2P)P
M?@%%20,I/`(G)`%-=0%13`,L=P(J:P%5:0(O5`(O4@(O4P%5:@(O40,V/`0R
M-`,V/P,V/0%;(0%;(@(U:@%;(P%:?@(\0@,[>0(\0P)#1`0]9`%I(@%I(010
M3P]49`)<?`)A90-:/P)E50)E5`)H>P,A:0(A/@%130,V00-!4`%%2@%&60,B
M40%(+P%(+@,C<P,C<@%(,`%(,0(B3P(B3@(D.0%*5`(D/`(D.P(D.@(D/0,F
M/00F8@%-=@(G*@(G)@(G+P,I0P,I/@%-?0,I0@%->P(G*P(G)P(G+@%->@%.
M(P(G*0(G)0%.(@(G+`%->0(G+0%-?`%-?@(G,0(G,`(G*`%->`%-=P%.(00F
M80,I0`,I00\G/@,L?@,L>@(J<`(J=@,M(P%14P%14`(J;0(J<@,L?`%15@%1
M3@(J<0%140%15`,L>00I9P(J=`,L?0%13P(J>0%14@,M(0%150(J;@(J<P(J
M=P(J;P(J;`,M)`,M)0(J>`(J=0,M(@,L-P,Q1@%5<@%5:P%5;@,Q3`%5<0,Q
M1`(O5P,Q20%5;`(O50,Q2`%5<`,Q30,Q10%5;0,Q0P(O6`%5;P,V0@0R.0(U
M;@%;)0(U;0(U;P%;)`%;*0(O5@,Q2P(U;`(U<`,V1`%;)@(U:P%;*`,V10%;
M)P,\)@(\2@,[?0(\10,\)0%?6P%?7P%?7`(\2`(\2P,\(P%?700X)`%?7@%?
M8P)#30(\20%?80(\1@(\1`,[?`%?8@,[?@(\1P,\)`%D000]:0)#10%D/@%D
M/P%D/0)#2@)#20)#1@%D0P-!6P-!5@)#2`%?8`-!60-!40)#3`)#1P%D0`%D
M/`%D0@)#2P-'-`1#:P-'-0%I)01#;P)*7P)*7@)*70%I(P1#;0-'.0-',P-'
M-P%I)`)0;`)0;P%M,@-,1`-,1@%M,0)0<`)0:P%M-`)0;0-,00%M,P)0:@-,
M0`)0;@%P<@%P;P)71@)710-,0P)71`)7/P-0?0)70`-1(P104`-0>@%P<`-0
M?@%P;0%P<0)7/@%P;@)700)70@)71P-1(@-4<0)70P-4;P-4<`)<?01600-4
M;`-4;0%S<`-4<@)A:`%S;P)A9@)A9P%V3`%X.P)E5@-:0P%X.@-:0@-E)@)H
M?0)H?@-<0@%Y<0-<0P)H?`%Z;P1J3`)O+@%\.@)P.`)P.0-A/P%%2P0A?`%(
M,@%(,P%*50,F00(G,@%15P%5<P%;*@\R<P%9-P%?9`%?90%>,@(\3`-E)P%D
M1`)*80)*8`-1)`=31P%%3`%(-`(G,P%.)0,I10%.)`,M)P(J>@(J>P-F,@(O
M60(O6@%5=`%5=0,V2`%5=@(U<0,V1P,V1@%;+`0X*0%?9P,\*0%?9@)#3@)&
M00)*8@)72`-1)@-F,P%V30%Y<@%%30%&7`%&70%&6P%&7@%&6@,B4@%(-P,C
M=P(B5P%(-@%(.`,C>`,C=0(B4@(B40(B5`(B4P(B5@%(-0(B4`(B50\B6`\B
M5P,F2`(D/@%*7P(D/P(D0P%*7@,F20(D1P(D0@(D10%*5P%*6`%*60%*6@,F
M10%*80,F1`(D00%*7`%*8@,F1P(D0`(D1@,F0@%*6P(D1`%*70%*5@%*8`,F
M2@\D(@0D1@\D4P%..@,I1P(G-0%.)@0F:0%.,`%.,0%.*0%..P%.*P(G/0%.
M-@(G.`%.+`(G1P(G2`(G0`(G.0%..0(G10%.-`%.,@,I4@(G1@,I20(G1`(G
M/`(G-`(G.P%.+00F90%.,P,I2@%.)P(G/P(G/@(G-@,I3P%.-0(G0@(G-P%.
M.`(G20%.*`,I2`%.+P(G.@(G0P%.-P0F9P%.*@%.+@0F:@(G00\G3@,I3@,I
M3`-E*`\G4`-E*0(K/0%17P%1;`,M-@(K.`(K+@%190(K+`%17@(K)P%1:`(K
M-`(K(0(K(P,M+@0M600I;@,M,`(K)@(J?`(K,P(K0P%18P(K*`(K.@,M+0(J
M?@(K00(K0@(K10(K/`(K+0(K-0%1:0%17`%19`%1<`%160%16P,M,0,M*P,M
M.@(K)0%1;0%19@(K/P(K(@%1;P%1:@(K*P0I;00M3@%1;@(K,@(K*@%19P(K
M/@(K-@,M*@%180(K1`(K*0%170(K.P(K,0%18@(K-P%16@(J?0%1:P%6)P%1
M8`(K,`(K+P(K)`,I40(K0`,M-`(K.0,M,@%16`,M.0,M-P8Q<@,M.`-E*P-E
M*@\K2`(O;@%6+@(O;P,Q70(O8P%6(P%6+P,Q5P(O7`,Q4P(O90(O;0,Q6P(O
M6P(O=@%5=P,Q7@,Q9`,Q4`(O=0(O<`,Q7P(O<0%6(0%6+`(O9P,Q5@(O:`(O
M<@(O:0,Q8P(O9`(O7@(O7P(O;`(O9@,Q5`,Q3P%5>`%5?`(O=`(O8`%6*@%6
M)@,Q6@0M50%6*0%6,`%5?0%6*P(O:P%6+0%5>@,Q60%5>0(O700M3P(O80%6
M)`(O<P(O:@(O8@%6*`%6)0,M+P%5>P%5?@,Q8@,Q6`\P)`,Q80,Q8`-E+0-E
M+`(V*`,V50(U=@(U=P(U>P,V8`(V+`(V*0,V3@(V(@(V(0%;,P(V)0(V-`(U
M<@,V6P(V-0(V)P(V.0(V+0%;,@(V*P%;+0%;0@%;.`,V5P%;/`%;.P(U<P0R
M/P(V,@(V.`(V,`(V-P,V40(V)`(U=`(V-@(V)@%;,`%;/0,V6@(V+P%;-@,V
M30,V7`,V4`(V+@(U=0%;/@,V2P%;0`(V,0%;00%;+P(U?`(V,P,V5`,T>`%;
M-0%;/P(U?@(V*@(U>0(U?0%;.@(U>`%;+@%;-P%;-`(V(P%6(@(\8P%;,0,V
M3`,V4@,V7@,V7P\U5P,V5@,\10%;.0,\00(\9@(\?`(\<0%?>P,\.`%?=@(\
M8`%?=P(\<`,\/@(\:0(\=@%?<P(\3@(\>`%?:0(\5@%?;`%?:P0X,@%??`,V
M4P(\4`(\<@(\<P%?;@%?:@(\7@,\/0%?=0(\60,\,@(\=`%?<0(\;`(\>0(\
M4P(\6`(\4@,\*@%?<`(\90)#9`(\5`%?=`(\70(\=0%?;P(\6@(\5P(\:`%?
M<@%?:`%??@(\:P(\:@,\,0,\0@,\.0,\.P,\-`,\+P(\3P%?;0(\=P(\7P(\
M80,\-P(\;@(\;0(\30%?>`%?>@(\50(\7`(\9`%?>0(\6P(\9P(\>@\[<`(\
M;P,\/`\\(0,\1`,\,P(\>P\\*0-E+P(\40\[;@-E+@,\0`)#>`%D3`-!90)#
M=@)#80)#9@)#7P-!=P)#<@)#40)#6`0]<0)#<`)#>@)#8@-!:`)#50)#:`)#
M;0)#60-!:P)#:@)#5@-!70-!=0)#70)#7@%D3@)#<0)#;P-!<P)#4@)#=`-!
M=`)#=0)#=P%D4@%D2@-!;P(U>@)#6@)#;`)#6P%D1P%D5P)#<P%D50%D40)#
M4`%D20-!>0)#4P%D5@-!>`)#8P)#3P-!=@%D3P)#9P)#5P%D4`)#8`%D1@%?
M?0)#:0(\8@)#5`0];`-!;0)#;@%D2P)#:P%D2`)#90%D4P)#7`)#>0-!:@-!
M>P]"20]"1P%D30)%+`-!<@%D5`]"*`]"/`)*<`)*;@-'.@)+)@)*;`-'/0)*
M?@%D10%I*`)*:`)+)0-'40)*;0)*>P%I+0%I)@-'3@)+(P-'1@)*9@)+(@-'
M1P%I.`)*=P)+*0%I-@)*;P%I)P)*<0)+(0%I,`)*:@%I-`%I*@)*<P)*:0)*
M8P-'/@)*?0%I,0)+*`)*9`%I+@1#=P)*>01#>0%I+P)*:P)*=@)*<@)*=`-'
M0P%I*0)+)P%I-P)*=0-'.P)+*@1$)P-'/`)*90)*>@%I+`%I-0%I,P)*9P)*
M?`%I,@-'10-'2`%I*P)*>`-'30-'1`1$*`-,5`)+)`-'3`)0?`-'0@)0>`)0
M=`)1*@)1)P%M-P-,9`-,8`)1+@)0>P%M0@)1)`-,3P-,40)0=P)1(P%M/P)1
M-P1*/0)1-`)1)@)0=0-,7P-,5P)1*P)1+0%M.P)1(0)0>@)0<0%M.`%M0`1*
M2`)1,`%M00)0<@)1-@)1*0)1+P%M/@-,30-,4`)1+`-,1P)1,P-,6P%M0P-,
M5@%M/0)1)0)0=@)1.`)0<P)1,0%M.@-,2@)0?0-,20)0?@%M.0%M-@)0>0%M
M/`-,4@%M-0-,8@)1,@)1-0)1(@)750-,7@-,60]/0@-,80-E,`)730-1+`)7
M20%Q(0-1/`-1.`%P=`%P>0%P=0)75P)78@%P<P)73P)76`)1*`)760-1*`-1
M*P%P>@-10`)7:`%P?@%Q(P)72P-1.P%P?0-1,0)79@)79P)770)77`)75`-1
M*0-1/@)77@)790)79`-1+P%P>`%P=@)75@)74P-11`)74`)78P%Q(@)780%P
M?`%P>P-1)P)76P1*2P)72@)73`)73@)78`)76@%P=P-1+@)740-1,@)77P-1
M00-1.@]4>P)74@-E,0]5*0-E,@-4=0%S>`)=,0%S<0)=(@-4>P)=+0%S<P)=
M-`-5(0)=*0-4?`)=)`-4=@1610)=-0)<?@)=*P-5)P%S>@)=,`)=-@)=*@%S
M<@)=+`)=(0%S>0-5(P-4>@)=,P)=)@%S=0-5)`)=*`)=)0%S>P)=)P%S=`%S
M=P)=+P)=(P)=,@-4>`)=+@-5*0-7=`%V3P)A<P%V5`%V50-7=P-8(0-7=@%V
M3@)A<@-7>`)A;P)A<`%V4@)A:@)A;@%V40-7?@)A:P-7>0-8(P-7?0-7>@%V
M4P%V4`-8(@)A:0)A;0)A<0-7>P-E,P)E7`)E60)E8@-:1`)E80)E7P)E6@-:
M3P%X/P-:10-:3@1?<0-:1P-:30)E6P%X/@%S=@)E7@%X/0)E8P)E70)E6`)A
M;`-:2`-:1@%X/`-E-`)E5P)I)`-<20)I(P)E8`%Y<P-7=0)I)P)I*`)I(@)I
M)@1C4`)I(0-<1P-E-01C3@)K7P)I)0%Z<@%Z<`)K70->-0->-`->,P)K8`->
M-P)K7`)K7@%Z<0-?3P-?3@)M4P)M5`%[8@)M4@]I3`-E-@-E-P)O,0%\.P)O
M+P)O,`)P.@-@=`]K40%](P)Q(P)Q(0)Q(@)Q)`-A0`-A90-A00)R*P%%3@%(
M.0,C>0%./`0F<0(G2@,I4P,I5`(K1@0I<@,M/`,Q9@(O=P(O>0,Q90(O>`,Q
M9P(O>@%;0P(V.P(O>P,V8@(V.@(V/`(V/0(\?0%@(@(\?@(](@%@(P%@(0(]
M(0-!?0)$(@)#?@)#?0-!?`)#?`)#>P%D6`)$(0%I.0)+*P)++0%I.@)++`%M
M10-,9@%M1`)1.0-,90-,9P)7:@)7:0)7:P-11@-110%Q)`]5.0)=-P%S?`-5
M*P)A=`%V5@)E9`%[8P%%3P%&7P%(.@%*8P%./0%./@,I50,I5@%1<0,M/0,Q
M:`(O?`,\20,\1P1$+0-!?@%D60-"(0-'4P1*3@)260%Q)0%V5P%%4`,B4P%(
M.P0F=@(G3`%./P(G2P,I6`(K1P%1<@(K2`4I:0%1<P(O?@%6,@%6,0,Q:@(V
M0@(V0`(V00(V/P,V9`(V/@(](P(])@%@)0(])`%@)`(])0)$(P-"(@1$,0)+
M+@)++P)+,`-'5`)1/`)1.P%M1@)1.@)1/0)7;`10;05;<@)7;0)7;@164@)=
M.`%S?0%V6`)E90%Z<P(A/P,I60%1=`(K20%6,P0R3@0R4`%;1`,V90%@)@(]
M)P,\2P%D6P%D6@-")@)+,0)+,@%M1P%M2`)7<`)7;P)A=0)O,@%%40(A0`%&
M8`,C>@%*9`(D2`,I6@%1=0%D7`%%4@(K2@%1=@(K2P%S?@%%4P-E.`-E.0(G
M30(K3`,M0@(P)0(P)`(P(@,Q;@(P(0(P)@(P(P,Q;`,Q;0%;10%;1@,V9@%@
M)P(]*`0X3@(]*0(]*@,\30\\/`-E.@)$)P)$*`)$)@-"*`)$)`)$)0%D70)+
M,P)10`)1/P)1/@)100)7<@)7<0%Q)@)7<P%T(0)=.0-5+0)A=@)E9@)M50%%
M5`%&8@%&800C(0%.0`(A00(A7P%(/`(B6`(D20(D2@%.00,I70(G3@-E.P%1
M=P(K30(K3@%6-`%6.`(P)P%6-P%6-0%6-@(V0P%;1P%@*@,\3@%@*`%@*0(]
M*P-"*0-"*@%I.P%%50(A8`,B5P%&8P,B5`(A8P,D(0%&9@(A8@%&90%&9`%*
M90(A80,B6`,B60(B60\A9@(B70(B7P(B8`%(1@%(1P(B7`%(0@,C?0(B6@,D
M)0(B7@%(0P,F50%(/@,C?`%(/P,D(P%(10(B6P%(/0%*9@%(0`%(00%(1`\B
M70-E/`(D6P(D60(D3`%*<@(D4P%*;0(D30,I9`(D50,F4`(D4@%*<`(D40%*
M=P(D6@%*>0,F4P%*>P,C?@(D2P,F5P%*;@(D7`,F40%*=0%*>`,F3`(G90%*
M:`%+(0%*=@(D3@%*:P%*>@(D5@%*:0%*:@(G8P(D3P%*<0%*?`(D70(D4`%*
M;P,F30%*=`(G3P%*?0(D5P%*<P,I8P%*?@%*9P(D5`%*;`(D6`(G9`,F3@,F
M4@,F7`,F60,F5@\D:`,F6P%.30%.70(G5@%.5`,M3@(G:P%.10,I:P%.2`(G
M8@0G)@(G5`(G6`%.4`%.4@(G6P%.60%.2P%.20%.2@%.6`(G9P%.4P(G6@(G
M7`%.40%.5@(G70(G:@,I;0%1>`%.7`0F?0%.1@(G:0,I;`(G;0(G60(G;P(G
M8`%.3P(G50%.3@%.8`%.50,I:@(G4P(K5P%.6P%.7P(G80(G9@,I90%.80%.
M6@%.3`%.0@,I:0%.1P0F>P(G5P%.0P(G;@,I9P(G40(G4`(G7@(G4@%.7@%6
M.0%.5P(G7P%.1`,M3P%2*0(G;`,M1@(K7@(K80,M4`(K9`(K60,M2`,M2@(K
M9P(K:@(K;`(K5@%1>0%1?@(P+`%2,`(K90(K;0(K70(K50,M20,M1P,M30(P
M1P%2(P(K8@(K6@(K7`%2*`,Q>@(K7P%2(@(K4@(K:`,M2P(K:P,M10,M5P%1
M?0,M4P%2*P(K3P%2+0%1>P%2,0(K:0(K40%2+@(P00(G:`%2(0%1>@(K6`(K
M4`%2+P%2)P(K8P%2+`%2*@(K6P%2)`(K4P%2)0%2)@(K5`(K9@%1?`(K8`0J
M(0,M50,M40,Q=P,Q<P(P+P%600%61@,Q>0,R)@,Q=@(P.`(P/@(P.@(P+0(P
M,`(P*0(P*@%630%6/@(P.0(P0@%62`%6.@,Q;P%60P(P,0%610(P,@(P/`,R
M(@,R)0,Q<@%61P(P2P(P*P%60`%6/P%62P(P*`(P20(P/0(P2@(P1`(P-@(P
M10,R(0(P/P(P2`(P1@%63`(P-P%6/0%6/`%61`%62@(P0P%620(P-`%;2`,Q
M>`(P3`(P,P(P+@%60@%63@%6.P,R)P(P.P(P0`,Q?0,Q>P,Q?`-E/0%;:@(V
M10(V20,V;P%;5P%;50,V>@,W(0%;3`(V1P(V1@%;8`,\4`(V3`%;6@,V<@(V
M7@(V:@%;20(V6P(V5`%;;`(V1`,V:@(V8`,V:P%;:0%;70%;:`%;4P(V4`(V
M8@(V6@%;5`%;3@(V:`,V;`(V80(V8P%;5@%;7@(V90(V3@(V7P(V4P(V9P%;
M8P%;2P%;80(V6`(V5@(V5P%;6`(V4@(V40%;30(V2P(V:0%;3P(V50%;;0,V
M=`%;9P(V2@%;9`%;8@%;:P(V7`%;9@(P-0(V70%;90(V9`%;2@(V60%;7`(V
M30%;6P,V?`%;60%;40%;4`(]+`(V9@,\70,W*`(V3P,W)@,W(P(]00,V<`%;
M4@,V=P,W)`,V=@,W)0,V>00R;0,V?0-E/@,W*0\V*0,W)P,\5`%@1P%;7P%@
M-0(].P%@0P,\4@(]+P%@,@%@+@(]30%@-`%@.`%@,P%@/`(]40(]2`,\:P,\
M;0(]-@%@00%@.P(]0@%@*P(]3@(]1P%@+P(]/`%@/@(]60(]6@0X6P%@+`(]
M3`%@0`(]0`(],@(],P%@1`(]-P(]/@(].`,\6@%@0@%@2@(]-`(]+0(]+@,\
M5@(],`%@,0(]/0,\;@%@/P%@2`,\6`,\:0(]/P(]5P(]3P%@+0(]50%@.0,\
M9@%@-P,\9`(]6P%@-@(]10(].0(]0P%@30(]20(]1@(]-0%@20(]4P(]4`(]
M6`%@,`(]1`%@3`,\6P(]2P-".@,\8`%@.@%@/0,\7`(]2@%@2P(].@(V2`,\
M40,\;`(]5`(]4@(]5@\\70,\8@-E0@0X7@,\8P,\:`\\1P-E0`0X7P(],0%@
M1@-E/P-E00)$1P)$1@)$+`%D8P-",`)$10)$+P)$,`0^/P%D;0)$3@%D:`)$
M1`-",P)$*0%D;@%D9`)$.`)$+@)$,0)$20%D7@)$4`)$2`%D9P)$/0%D<@-"
M+@-"-@%D<0%D:P-"0`0^-@)$3P%D7P)$.P)$,@)$/P)$2P%D<P-".0%D80)$
M.@-"+0)$,P%D:@-",0%D:0)$-@)$0`)$2@)$+0)$-P%D8@)$00%D;P%D9@)$
M-`%D90)$*P)$.0)$30%@10%I5P)$/`)+-`)$/@)$3`%D;`)$-0%D8`%D<`%M
M6@)$*@943@)$0P-"1`-"/@-"1P)$0@-"/0-"10-"/P-".P-"1@)+4`%I5`)+
M10)+2@%I20-'5@)+-@%I5@-'5P%I0`)+-0)+5@%I6`)+.0)+20-'90)+.P)+
M60)+50%I/@%I2`)16P%I50%I1@)+-P-'8P)+5`%I2@)+40)+7@)+/0)+1@-,
M>`-'6P)+7`)+4@%I10-,:@-'9`)+1`%I/P%I/0%I3P1$0P-'7P)+0@)+/P)+
M0`-'6@)+6`-'7`)+70)+6P%I0P)+7P%I1P%I3@1$1`)+.`)10P)+00-'7@%I
M00%I4P%I4`%I1`)+2P)+/`%I40)+30%I2P%I30%I/`-'70)+3P)+1P)+.@%I
M3`)+5P)+6@)+0P)+3@-,=`%I0@%M20)+3`)10@-'8@)+4P-'801$4@]/>0-E
M1`-E10-'9@-E0P)+/@)13`)15@%M3`)150)180%M3@)14P1*6`)15P%M60-,
M?0)13@%M40-,<P)16@)7>P%M70%M7`)17`)12P)19@%M5P-,:P%M30)17P1*
M:0)18P)1:`)170)140%M4`%M4P%M6P%M5@-,=0)15`)+2`-,?@-,;`)14`)1
M9P%M4@-,>0%M50)1:0%M2@)17@)11`)19`%T*@-,>@)14@10=0%M2P)130%M
M3P)110%I4@)1201*5P)18@)12@)12`%M5`-,>P)18`-,=P)11P)160)16`)1
M90)13P%M6`1*9`-E1P]/?0-E1@)7?@-15@%Q,P%Q*0)8+`)7=@%Q*P)8)`%Q
M,@%Q+0)8(@)=.P)8*`)8+@)8)P)7=`)8)0)8,`)8,@%Q*`)8,0%Q+@%Q-`-1
M5`%Q,0-16`)8*P%Q,`)8)@-130)7>`)7?0-14`)8*@%Q+P%Q+`%Q)P%Q*@)7
M?`11(@)11@)7=P)7>@)8+0)8(0)7=0)=.@)8+P)7>0)8*0-,<0-150)=/0%T
M+@-5,`-5+P%T(@-5-0-5-@%T)@)=/P)=10)=0P%T)`%T)0%T+`)=1@)=/@%T
M)P-5,0)=0@)=00)=1P%T+0-5-P%T*`%T*P)=0`%T+P%T*0%T,`%T(P)=1`-:
M50)=/`-160-5.0)B)0-E2`%V70)B(@)B)`-8*`%V6P)A?@)B(0)A>@-8*@-8
M)P)8(P)A>P%V7`)A=P-8)@%V60)B)@%V6@)A>`)A>0)A?0%V7P-8*0%V7@1;
M7@-8*P)A?`%X10)E:@)E<`%X1@)E9P%X0P%X0`)E<@%X1`-:4@%X00)E:0)E
M;`)E;0)E;@)E<0-:5`)B(P)E:`%X0@)E;P)I-`)E:P-:4P-E2@-E20)I*P%Y
M=0)I+@%Y=@)I-P)I+0)I*@-<40)I+`)I,`)I,P)I,@)I-@)I*0-<3P%Y=`)I
M,0)I-0)I.`)I+P)K80)K8@)K9@)K9P->/`)K9`)K90)K8P->.@%Z=`->.P%[
M9`)M60-@-@-?4@)M5@)M5P)M6`%[90-@-P)O-`)O,P-E2P)P/0%\8`)P.P)P
M/@)P/`)Q)0%])`%],@)Q<0)Q6P-A>0)Q<`)R/@)R/P%%5@0A4`,D*`,D)@%(
M2`(B80,D)P,D*P(D7@,F8@%+(@,F7P%+)0,F7@(D7P,F8P%+(P%+)`,F8`\D
M<0,I=P(G>`(G>@(G=0(G<@(G=`,I=`,I<`,I=0%.90,I;P,I>0,I=@%.8P,I
M<@,I<0(G=@%.9`(G<P(G<`%.8@(G=P0G*0(G<0%.9@(G>00G*P(K;P,M7@(K
M<P,M7`,M6@%2.@,M6`0J)@,M90,M8@(K=@,M7P%2,@%2-0%2-P%2.0%2-@(K
M<@(K<0,M9`%2-`(K=`(K=0,M8P(K;@%2.`,M:`%2,P,M70(K<`-E300J*`,R
M*`(P6@(P6P(P7`%64P0M=0%63P(P40,R*@(P60(P7@%65`,R*P(P3P(P50(P
M3@(P6`,R,0,R+P(P5`%64`%64@(P70,R*0(P30(P4`(P5@,R+0(P5P(P7P(P
M4P,R+`%640-E3P-E3@,R,`%;<@(V<0,W,`,W,@(V<P(V;P,W+P(V>P(V;0(V
M>@%;;@(V:P(]7P(V=0%;<0,W-0(V=@(V>0,W+@(V?0,W+`(V<@0R<@(V=P,W
M+0,W,0%;;P%;<`(V?`(V<`(V;`(V?@,W,P(V=`-E4`-E40(V>`(V;@%@3@%@
M3P(]:0%@50,\=`(]70(]9@(]7`%@4@(]9`(]8@,\?0(]8P%@4`,\?`(]9P\\
M?@,\;P,\>@,\<@,](0(]8`(]7@%@40(]80(]90,\>P,\>0,\<0%@4P,\<P,\
M=P-E4P(]:`-E5`-E50-E4@)$5@)$70)$7P)$90-"5P%E(@)$40-"3`%D>`-"
M3@)$8`%D?0)$9@%D=`-"40)$8P-"6`)$4P)$9`)$4@%E)`-"4@)$7@%D=0)$
M9P-(/`%D>@)$5P%E(0)$8@)$50)$7`)$6`)$5`%D=P%D?@%D?`%D>0%E(P%D
M=@)$6P-"3P%D>P-"60%@5`-"20)$80-E60)$60-"4P-E5P-E6`-E5@)$6@1$
M5P1$6P)+9P-';P%I6P-';@-';`)+8P)+:0)+90-'<`%I70)+9`)+:`)+8`-'
M<@)+8@%I7`-':@-';0-':P-':`)+9@)+80-'9P%I7@-E6P%I60])2P-E6@)+
M:@])7P%I6@)1;P)1;`)1>`)1<@)1=`%M7@)1;@)1=@--*@--)`)1=0)1<P--
M*0)1>0%M80)1<`)1=P--*`%M7P--)0--(@)1:P)1;0%M8`)1:@)1>@-E7`)1
M<0-18@-16@)8-@%Q.P-18`-17`)800)8/P%Q-0)8-0)8.`)8.0)8-`%Q/P%Q
M0`)8,P)80@)8/0%Q.0%Q-@)8/`)8.@-18P11(P%Q/`)8/@%Q-P-17@%Q.`-1
M9@)8.P%Q.@)8-P<O3P)80`%Q/0)80P)81`%Q/@-E70-E7@%T,@%T.0)=2`)=
M3@-5/`)=3`%T-0%T-`%T,0)=2@-5/@-50P-50`%T-P%T-@%T,P-500)=30)=
M20)=2P-50@%T.`]:<P%V8P)B*0-8+0%V8`%V80)B*P%V8@)B*`-8+@)B)P)E
M=@)B*@-:5@)E=P%X1P)E=0-:5P1??@)E=`-<60)E<P%X2`-E7P-<5@%Y=P-<
M6`-<50)I.0)I.@-:6`-<4P-<5P-E80)K:@)K:0%Z=0-?4P)K:`)M6@)M6P-?
M5`-@.0)O-0)P/P-A0P-A0@)Q)@)R+`%]1@)R0`%%5P0A40%.9P%.:`,M:00J
M*@%2.P,](@1*;`%T.@%%6`%.:0%650%E)0%%60,M:P%;<P%I7P(A0@,I?`(K
M=P(P8`0^3`)+:P1*;0%T.P%%6@%.:@(K>`(K>0(]:@%@5@-"70)$:`-"7`-"
M6P%E)@)+;`1$7@--+@%M8@--+0%X20%%6P(]:P%%7`%(2@(B8@%(20%+*`%+
M)P%+)@(D8`,F9`,J(0,J(@%.:P,J(P%.;`(G>P0G,0(K>@,M;0(K?0%2/0(K
M>P0J+P%2/`(K?`%2/@(P8P(P8@(P80%65@,R-@(W(@(W(P%;=`(W(0(W)`%@
M6`%;=0,])`,](P%@5P(];P(];@,])0(];`(];0(]<`)$:@)$:0)$;00^3P)$
M;`)$:P%I8`)+;P-'=0)+;@%I80)+;0)1>P--+P)1?`%M8P11+0)810)81@5.
M-P)E?`%X2@)E>P)E>@)E>`)E>0%Z=@)I.P)M7`)Q)P-A>P%%700A.`(A9`%&
M9P(A90,D+`,D+00C)P(B8P(B9`,F:P,F:0(D9@,F9@,F9P(D8@,F:@(D80%.
M;0(D90%+*@(D8P%+*0(D9P(D9`,F:`(H(0(K?@(G?0(H)@,J)@%.;@,J*@%.
M<0(H)P(H(P,J)P(H)`0G-@(G?`%.<`(G?@%.;P(H)0,J*`(H(@8L?@(L)`%2
M0`%200,M=0(L)P(L(0,M=`(L)@,M<`(L(@%2/P(L)0(L(P,M<P,M<0(P:0(P
M9@,R.`(P:`%66P%66@%66`(P90(P:@%65P%660(P9P(W+`(P9`(P:P,R.00S
M(P0S*@,])@(W)P(W*P4S5`(W*@(]<@(]?00S+0,W.P(W+0,W.@(W*`(]<0%;
M>00S(@0S+`%;>`(W)@(W*0%;>@,W.0%;=P%;=@(W)0(W+@(]=`(]>P,])P%@
M6@(]>@(]=P,]+@%@7`,]*0,]*P,]*@(]>0-"80,]+0(]<P(]=0(]>`(]=@%@
M6P(]?`%@60%E)P,]*`)$<0)$<`)$;@94?`%E*@%E*0)$<@-"7P)$;P)+<`%I
M8@%E*`-"8@-E8@-E8P)$=`)$<P--,`)+<P)+<0%M9`-'>0%I8P)+<@)1?@-'
M>`-'>@-'=P1*=P%M90)1?0)2*`)2)P)2)01*=0)2)`)2(0)2(@)2(P)2)@)2
M*0)82P)82`)820%Q00)81P)830)83`)82@)=4`)=40%T/`-520%T/0)=3P16
M;`%V90)B+`%V9`%X2P1@)0%X3`%Y>`)I/0)I/`)K:P)M70%[9@)O-P)O-@)O
M.`%&:`(L*`%67`%;>P(W+P%&:0(A9@%%7@,B6@,A:P(B90,D+P0C*@\B9@(D
M;`(D:@(D:P(D:`%+*P(D:0,F;@,J,P(H+P,J+0%.=`(H+0(H*0(H+`,J+`(H
M*`%.=@(H*P,J*P%.<P%.<@,J,@%.=0(H+@(H*@,J+P%210%22`(L,`(L+P(L
M+@%20@(L-P(L+00N*@%21`(P<`,M>`(L-`(L,@%21P,M>P(L*@(L-0,M=P(L
M+`(L-@(L,P(L*P,M>@%20P(L.`(L*0%21@,M?@,M>0,M?`(P=0(P;`(P=P,R
M/@(P;P(P>@(P>P(P;0(P>0(P=@(P=`(P>`%68@,R0`%68`,R1P,R/`(P<@,R
M1@(P;@,R00(P<0(P?`(P<P%680(L,0,R/0%670%67P-E9`,W/0(W/0(W,@(W
M,`,].`(W,0,R/P(W.`,W0`(W.0(W-0%<(@(W.@(W-P(W-`,W/`%;?@(W,P%;
M?`%<(0(W-@(W/@%67@%;?0(W/`(W.P%<(P-E90\V5P,]-@,].@(^)`,]+P,]
M.P,],@(^)0%@9@,].0(^*P-";0,]-0(^+0(^)@%@8`(^*@(^*0%@80%@9P-"
M9`%@:`(^+`%@7@(^(P(^(0(^)P(]?@%@90(^(@(^*`(^+@%@7P%@9`%@8@%@
M8P,],P,]/`%@70-E9@,]-P-":`-"=0%E,0)$>P%E,`)%(0-";P)$=0-"=`)%
M(@-";@-"9@-"<0)$=@)$=P-"<P)%(P)$?@)$?`)$?0)$>0)$>`-"9P)%)`%E
M+0-":P)$>@-"<`%E,@%E+`%E,P%E-`-":@%E+P%E+@-()0-'?@)+=`%I90%I
M9`-'?`-'?0)+>0-((@%M9@%I9@-((0-'>P%I:`)+>@%E*P%I9P)+=@)+>`)+
M=0-()P)+=P-((P])=@)2,P--,0--.P)2,@)2+P%M:0)83@%M:@)2+@--.0%M
M:`---@)2,`)2+0)2*@)2,0)2*P)2+`%M9P---0-E:`11.0)=5011.@)84@--
M.@)840)84P-1:@)=4@%Q1`11.`)83P-19P%Q0@-1;`%Q1@%Q10)84`)85`-1
M:P%Q0P-E9P)=60%T0`%V9@%T00%T/@)=5@)=5`-53P)=5P-52P)=6@%T/P)=
M6`)=4P-530-E:0)B+P)B,@)F(0)B+0-8+P)I/@)B,P-8,`%X30)B,0%V9P)B
M+@)B,`)B-`)F(@-:6@)E?@1@)P-:7`-:70-:6P%X3@)E?0-<7@-<7`-<7P%Y
M>0-<70-<8`->/0%Z>`)M7P%Z=P)M80)M7@)M8`%\/`)P0`%&:@(H,`(P?0(P
M?@%<)`)%)0%Q1P%X3P%[9P)P00%&:P(H,0$C(@0J/`,N(@(L.0,N(0(L.@,N
M)`,R2`(Q(0(Q(@%<)0%<)@\V9P,]/00Y)0(^+P)%*`)%)P)%)@)+>P-"=P)+
M?`)+?0%I:0-(*`)2-0)2-`--/0-1;0)850%Q2`%Q20-1;@)=7@)=6P)=7`)=
M70)B-@)B-0%V:`)F(P)K;`%&;`%220,W1`%<)P)%*0-">`%&;00J0`(Q(P%<
M*`,W10,]/@%@:0%@:@5'20%&;@%&;P(B9@%++0%++`%22@(L.P(^,`%&<`%&
M<0%&<@%&<P0C*P%++@%++P(D;@(D;0,J-P%.=P(H-`(H,@(H,P,J.`,J-00G
M0`,J-@,N)P(L/`(L/0,N)0,N*`%23@%23`,N*@%230%22P,N)@\K>@\L2@%6
M8P,R3@,R30,R4`,R3P%69P%69@(Q)`%690%69`,R40(Q)0,W1@%<*P(W0`(W
M/P%<*0%<*@,W20,W1P%@;`%@:P(^,@,]0P,]0@(^,0%<+`,]1`0Y+`0^:P%E
M-0)%*P%E-@)%*@-">P1$?`1$>P)+?@)2-@%M:P)85@-1<`-54@)=7P1;=`%X
M40%X4`1C:`-<8@%[:`%&=`(H-0,]10%<+0),(0%I:@,B6P,F<P(D;P(D<`(H
M-@%.>0%.>@,J.@0G0P%.>`,J.P%24@%24P%24`%240,N*P(L/@,N+P0J2@(L
M/P%23P(Q)@,R5P%6:P%6;`,R50%<,`(Q+`0N0`%6<0%6;P(Q+0(Q*`%6;@%6
M;0%6:`(Q*P(Q*@(Q)P%6<`,R4@(Q*0%6:00N-`%6:@%<,0(W1`(W10%<,@(W
M00(W0P(W1P(W1@(W0@,W2@%<+@%<+P(^.@%@<0%@<`(^-`%@;@0Y-`(^-P%@
M<@(^.`%@<P(^-0%@;0%@;P(^.0,]1P(^-@(^,P0^=P)%.`-"?`)%+0%E.`%E
M.P%E.@%E/P%E/@)%.0)%-P)%,`)%-`)%,P%E/`)%-@)%,@)%.@)%,0%E/0%E
M-P%E.0-"?0)%+P-(*P),(P%I;@),)P%I;0),)`%I;`-(*0)%+@)%-0),)@1$
M?@%I;P),*`),)0),(@)2.0)2/0)2/P)2.P)2.@)2.`%M;@%M;`%M<0%M<@)2
M/`%M;P)2-P%M<`%I:P)2/@%M;0-1<0)86`113P)85P)87P)860)87@)86P%Q
M2@)870-1<P-1<@%Q2P1130%Q3`-1=`)87`)86@17(017)`%T0P)=8`-550-5
M4P%T0@)=8P)=80)=8@55:05<-@%T1`-55`-8-`)B.@-8,P%V:P)B.P1;=01;
M>0%V:0)B/`%V:@)B.0)B/0-8,@)B-P%X4@)F)`%X4P%Y>@)B.`%Y>P->/P->
M/@%Z>0)K;0%[:@)M8@%[:0-@.P)O.0%\80%\8@-E:@=D4@)R.@,B7`-E:P%2
M5`(L0`%@=`%@=0%&=0%(2P(B9P,F=`(D<0%+,`,F=@%.>P0J3`%250%25@%2
M5P(W20(Q+@%6<@0N000N0P%<,P(W2`,W30(^/`%@=P,]3`(^.P%@=@-"?@-#
M(0)%.P%M<P)20P)20`)200)20@115`1150-1=@5<0P-55@)=9`-55P)B/@1;
M?`1;?0-:7@)I0`)I/P1F6@)M8P%&=@(H-P%6<P,]30%@>`)%/`1%-`-(,`),
M*0-(+@%M=`)88`-E;`)B/P)I00%&=P,F=P,F>`%.?`%26@(L00%26P%260,N
M,@%26`(Q+P%6=`,R6@,R6P%6=0%6=@%<-0(W2@%<-`,W4`,W4@,W40\W(P,]
M3P(^/0%<-@%@>0)%/0%E0`%E001%-0%I<`-(,0%I<0%M=0%Q3@)880%Q3017
M+0)=90%T10-8-0)B0`)I0@%&>`%+,0(H.@(H.0%.?0(H.`%.?@(H.P0J50(L
M1P%27@%270(L20(L2`%28@,N-0%280,N,P0J60%27`0J70(L0P(L1`(L100J
M4@%28P(L0@%27P(L1@%28`,R9`,R7P(Q,@(Q-@(Q-`(Q,P0N50(Q-P,R7@0N
M3P,R:`(Q.`(Q.0(Q,00N40(Q,`,W60%6>`%6>0,R9P(Q.@(Q-0,R90(W4P,W
M50(Q.P%6>@%6=P,R7`,R8P(W300S3P(W3`,W4P(W3@(W3P(W40(W4`(W50%<
M.@%<-P%<.P(W2P%</`(W5`%<.0(W4@%<.`,R8@,W5P0S5@,]5@,]4P(^0`(^
M0@(^/@(^/P,]40,]4@(^0P(^10(^1@(^00(^1`%@>@)%00-#)P)%1@)%/@)%
M0@0_*0-#*`)%1P)%0P%E0@%E2@-#)0%E10)%/P)%0`%I=0%E30%E1@-#)@%E
M2P%E1`)%10%E3`)%1`%E2`%E0P%E20)%2`),+@),,`1%0@-(.01%0`1%/0-(
M,P-(-@-(-0-(-`-(.`%E1P-(.P-(/0),*P%I<P),,0%I=`),+P),*@),+0),
M,@%I<@),+`%M=P)21P)21@--1`%M>@%M>`)21`%M=@)210--1@%M>0117P)8
M:0-1>P)8:P-1>0)8:@)88@)89@)890)88P%Q4`%Q40%Q3P)89`)89P)8:`-5
M60%Q4@-56`%T2@)=;0-56P%T1P)=9P%T20%T2P1180-57`%T2`)=;`)=:`%T
M1@)=:P)=9@)=:@)=:0-8-@-8.`)B0@%V;@%V;P%V;`-8.P%V;0-8.@-8.0)B
M001@.0)F)P-:8`-:7P%X5`)F)0)F)@)I0P)I1@)I1`)I10)K;@->0@1F7@%Z
M>@)O.@)P0@1K=`%\8P)Q*`)Q*0%],P%&>0%29`,R:0(^1P,]5P)%201L=@%&
M>@%+,@0G4@%/(0,N-@(L2@(L2P%6>P0S6P(^2`%@>P%E3@%T3`)=;@)F*`)I
M1P%&>P,F>P,F?`\E(P(H00(H/`(H/@(H0`(H/P(H/0%/(@\H-`%290(L5`,N
M.0(L3P(L3`,N.P,N/@(L4P,N-P,N.@%29P%2:`(L4@(L40(L4`(L30(L3@(L
M50%29@,N/0\L7`-E;0-E;@%7(0-F?`%7)P%7)@(Q1`(Q/@(Q/`,R;`%7)`(W
M7`%6?0(Q00(Q10(Q1P(Q0P(Q/0%7)0(Q0@(Q0`%6?`(Q2`%7*`(Q1@%7(@(Q
M/P,R;0%7(P%6?@-E;P,W8@%</@0S70(W70,W8P,W70(W5@(W6`(W6@,W7P(W
M6P(W60%</P,W80(W7@,W8`(W5P-E<`-E<0-E<@(^3`%@?`(^5`,]7`(^209,
M+P(^50,]60(^2@(^2P,]700Y5`(^4P(^4@(^3P%</0%@?0(^30(^4`%@?@(^
M40(^3@,]6@-#,0)%5`-#+0)%6`%E50-#+@),.`%E6`)%5@-#-P-#*0)%4P)%
M3@)%4`)%40)%2@-#-0%E5`-#*P-#,`%E4P-#-`%E3P)%30-#*@%E5@-#-@%E
M5P)%3`)%3P)%5P%E40%E4@)%50)%2P]$)01%4P),.@%I=P),/`)%4@),/@%I
M>P),/P),.P-(/@%I>`),-P%I>@),-`),.0),/0),-@-(/P-(10%E4`-(1`),
M,P%I>0),-0-E<P-(0`]*/P%M?0)220%N(P1+60%N(01+5P--2@%I=@--30)2
M4`)240%M?`--2`--3`)23P)24@%M?@%M>P)22P)22`)230)22@%N)`)23`--
M2P--20)23@%N(@-2(0-E=`%Q5`)8<@-2)`)8;`)8<`)8=@)8=P)8<P)8=`)8
M<01+70)8;@11;@%Q5@%Q4P)8;0)8;P-2(@%Q50)8=0-E=0%T4`-58`-58@)=
M=0)=;P%T3P17/@%T30-580)==P%T3@)=<@)=<P)=<`)=>`)==`170`%T40)=
M<0)=>0)==@-80P-8/@-80`)B1@-8/P-8/`)B0P-80@%V<`1<,@)B1P)B20)B
M2`)B1`)B10-81`)F+0-:80%X50-:8@)F*@)F+`)F*0)F+@1@0@-:8P)F*P-E
M=@)I20)I3`)I2`%Y?`)I2@)I2P)I30%Y?0%Z(0%Y?@)K;P->10)K<0->0P)K
M<`->1`)M9`]J9@-@/`)P0P)Q*@%&?`,D,P(D<@%/(P(H0P%/)`%/)0(H0@(L
M6@(L60%2:0%2;`%2:P%2:@(L5@(L6`(L5P-E=P(Q2P%7*@(Q3P(Q3@(Q30(Q
M20%7*0%7+0%7,`,R;P,R<`%7,0(Q2@(Q3`%7+P%7+@%7+`%7*P(W90,R<@(W
M8P(W7P%<0`,]7@(W8`%<00(W80(W8@(W9`,W9@%<0@,W90(^60,]7P(^6`(^
M5P(^5@,]9`,]8@0Y6@)%7`%E600_1@)%60)%6P-#.`%E6@-#/0%E6P)%6@-#
M.0,]8P-E>`-(2`),2`-(1P),00),0@5'?@%I?@%I?`%I?0),2@5((@),20),
M1@),10),1`),0P),1P),0`-E>0)24P)26`)25@--4`--40--3P)250)25`)2
M5P-E>@)8>`-2)@%Q5P%T4@)=>P-2)P%T4P)=>@)B2P)B2@%V<0-810)F+P%X
M5@)I3@%[:P)M90-@/0)P10)P1`(A9P%2;0%2;@(W9@-E>P%E70%&?0%+-0%+
M-`%+,P0D:`,J/@,J/0(H1`,J/P,J0@%/)P%/)@,J1`%2<0-E3`(L7`(L7P(L
M70,N0@%2;P%2<`,N0`,N00(L6P(L7@,N0P%7.`,R=`,R<P,R>0(Q5@(Q6`(Q
M5P%7-0(Q4@,R=@,R>P%7,P%7,@,R=P%7-@%7-`,R>`%7-P(Q50(Q4`(Q40(Q
M5`(Q4P,R?`,W:0,W9P,W:P,W:@(W:0(W:@(W:`,W;`(W9P%<0P\W/P,]90%A
M)09,2`(^6@(^7`(^7@%A)`9,0P,]9@%A(@,]:0(^6P%A(P(^70%A(0,]:`-#
M00)%9@)%70)%8`)%9`%E80)%8@0_4`)%80)%7@)%7P%E7P)%90%E7@-#1`%E
M8P%E8@%E8`0_2@)%8P-E)`),4`1%70),3P-(2P-(30),2P-(4`-(3P%J(0),
M3@),30%J(@-(4@]*9`1+8P1%7@1+:P%N*0--50)26@--5@%N*@%N)@%N*`--
M6@%N)0%N)P--4P--5P)8>0-2*@%Q6@)8>P)8>@-59`),3`%Q7`%Q6P%Q6`%Q
M60-2+`];60-2*0)>(@1720)=?@%T5`)>(0172`)>(P)=?0)=?`)B3`%V=`%V
M<@%V<P-:9@1@10-:90)F,`)F,0%X6`-:9P%X5P)I4`)I40)I3P-<9`)M9@)M
M9P-@=@-@=P%&?@(B:`%+-@(H10%/*0%/*`(H1@,N1`,N1P(L80%2<@(L8`%2
M<P,N20,N2`%7.0(Q6P(Q60(Q7P%7.@(Q6@(Q7@(Q7`(Q70(W:P(W;0,W<@%<
M1`,W<0(W;`%<10%A*`%A)P%A)@(^7P,W<`0Y90)%:0%E9`%E90-#1@)%:`)%
M9P-#1P-E?`),40%J)`%J(P),4@),4P%N+`%N*P--6P)9(0)26P)270)27`)8
M?@)8?`)9(@)8?0564@%Q70-2+P12)P-2+@)>)`%T50)>)0)>)@-5:`%V=0%V
M=@1@2P%Z(@->20->2`%\/0%'(0,F?@,G(00G6P,J1P,N3@(L8@,N3P,N30,N
M2P,N3`\L=@(Q8`%7.P,S(P,S)@,S)P,S)`%=?@%=?0,W<P,]<0%A*@(^80%A
M*0(^8`,]<`0_5P-#20-#2@)%:@-(5`%J)0),5`%J)@-(50-2,`-5:0-5:@17
M4`-820%Z(P)I4@-?50%(3`%/*@(H1P,N40%2=0,N4`%2=`(L8P(L9`(Q8@(Q
M9`%7/`(Q9@(Q:0(Q9P,S*P0N<0,S*@(Q:`(Q90(Q80%7/0(Q:@(Q8P,S+`,W
M>`,W>0(W=@%<2P(X(0%<2`,W=P(W>`%<3`,W>P%<1@,W=@(W<P(X(@(W=`(W
M<0%<2@0S?`%<1P0S>@(W=P(W>@%<20(W>P%<30(W?`(W<@(W>0(W?0(W=0(W
M<`(W;@,W>@-E?0(W?@\W30(W;P\V?@4[)`(^:`,]>P,]>`,]=0(^9`(^:@%A
M+0(^8P(^90%A*P(^8@%A,@(^9@%A,0(^9P%A,P%A+@%A-`%A+P,]>0%A,`,]
M<@%A+`,]=@(^:0-E?@-#3P0_9P%E:`)%=0-#3`)%>`)%;`)%<0)%:P%E:@-#
M50)%;P0_7@-#30,]=P)%;0%E:0-#5`)%=`)%<P)%<`)%<@)%;@%J*@)%=P%E
M9@)%=@-#40]$10-(5@),9`-(6`%J,0),7P-(8`%J,`),501%:P),5P%J*0),
M7`),6P),7@%J+@),60),6`-(6@-(7@%J+0%J*`),6@%J*P),8`),8@),70),
M5@%J+`-(5P-(70%N-`%J)P1%9`-(7`),8P1%<`)280%N+0--7`)28P1,*P%N
M+@--90--70%N,`)29@1+>@)27@%J+P)29`1+<P1,,01+=`1,*@)28`--8`%E
M9P%N,P1,(01+>`%N+P1,)@%N,0%N,@1+=@%Q8`)290)27P%N-0--8P)28@-F
M(0)9+`)9)P12+056:0)9,0%Q7@)9*0%Q8@)9+P)9)@)9(P)9,@%T6P%Q8P)9
M+@)9)`%Q80)9*`%Q90)9)0)9*@%Q9`)9+0)9,`-2,P-2-`)>.`)>.0)>*0)>
M,`)>+@177P-5;0%T60)>-0)9*P-5:P)>+`-5;@)>-@%T6`)>*P)>*@)>-`)>
M,0)>,P175`)>)P)>-P%T5@-5<`)>,@)>.P)>+P%T6@%T5P)>+0)>*`)>.@%Q
M7P-5<0];7P175P-5;P)B3P-84`-83@)B30)B4P%V>@)B40)B4`%V?`)B5@%V
M>P-840)B5P)B5`%V>`)B50)B3@%V>0%V=P)F-0)B4@-83`-F(@)B6`-F(P)F
M,@-:;P-:;@1@3@%X70%X6P)F-`1@3`)F-@)F,P%X7`%X60%X6@%X7@-F)`%Z
M)0-<9@)I5P5L>0)I5@)I5`)I4P)I50-<90%Z)`%Z)@-F)0]E9P%Z>P->3`1F
M;P)K<P)K<@-<9P->2P)M:`-?6`)M:@)M;`)M:P)M:0-?5P-@/P%[;0%[;`-@
M/@%\/P%\/@%\0`)O/`)O.P-F)@)Q*P)P1@)Q+`%])0-A1`%])@)Q7`1M6P-B
M.@%]2P%(30,J20(H2`,J2`,N4@(L9@(L9P(L90,N5`,N4P%2=@\M(0(L:`(L
M:0(L:@,S,0(Q:P(Q<0,S+@,S,`(Q;P%7/@(Q;0,S,@(Q;@(Q<`,S+0(Q;`%<
M3@,W?0(X(P%<4`(X)0%<3P(X)`,W?@,X(0,X/@,X(@0T(@(^;`%A-0,^(0(^
M;@(^:P(X)@,^(P%A-@,^(@,]?@(^;0-F)P\^(0\^(P-#6`)%>P-#7`%E:P)%
M>0%E;`)%>@%E;01%=`-(8@-(80%J,@),:`),90),9P%J,P%J-`),9@]+)P]+
M*P--;P--<0--;0)29P--<`--<P)2:`--<@%N-@)2:@)2:0--;@$C(P121`)9
M-@)9-P)9,P-2-P)9-`%Q9@%Q9P)9-0%T80-5=0-5=`%T70%T8@%T7@%T8`%T
M7`-2.0%T7P-8501<6@1<6P-85`%V?0)>/`=(5P)F.`1@6@)F-P-F*`)I6`%Z
M)P%Z*`)M;@)K=`-A:0)M;0-@0`)Q+0)Q<@%(3@,G(@%+-P,J2P(H20%/*P,J
M2@%2>0(L;0%2=P(L:P%2?`%2>`%2?0%2>P(L;`%2>@%70@%700(Q?`%72@(Q
M=0(Q>P%71@(Q=`(Q>@(Q>`%710%71P(Q=P%70`(Q=@%72P%72`%73`%720(Q
M<P(Q<@(Q>0%70P%7/P%71`0O)0,S-P,S.P(X-0(X+@0Z)@%A.P(X+0,X*0%<
M5`%<6P%<6`%<7@%<70%<60,X)@(X)P(X*@,X)P(X*0%<50(X*P(X-`%<5@(X
M*`(X,0(X,@%<5P(X+P%<7`%<4@%<6@(X+`%<40(X,`,X+@,X)`(X,P\W5`,X
M*P,^-`(_(0(^=@%A.`(^?0(^>@(^<@(^>P%A.@(^<P,^*0(^;P,^)@,^+@%E
M<P(^>`,^+P%A-P(^?@,^*`%A/@%A0`(^<0,^+`0Z)P%A/P(^=`%A.0(^?`(^
M=0(^>0,^*@(^=P%A/`(^<`%A00%<4P%A/0%A0@,^)`,^-0,^,P-#9P%E;P)&
M)`)&)@)&*`)&+`,^*P)&(@)%?@%E<00_<0)&)P)&*P)&(P)%?0-#9@)%?`-#
M:0-#8`-#8@)&*0)&(0)&)0%E<@-#7@%E<`)&+0%E;@)&*@-#9`),>0-#:`-#
M:@-#8P%J-P),<0%N0P),>P%J.@)-(0%J0`),;`-(=`1%>P),?`),:0-(;0),
M?@),;0-(;@%J1P%J1`),?0),=P%J-@%J/@%J/0-(<`%J/`%J0@-(:0),:@%J
M0P),>`%J/P%J-0),>@%J.`%J.0%J00),;P),;@),:P1%?`),<P),<`),=`%J
M1@-(:`)-(@%J.P),=0),=@-(<0),<@-(<P-F*0-(:P%J10-F*P-.(@)2;P%N
M.P%N1`%N0`)2;`--?`%N/0%N00)2>`%N-P)2<`-->`%N/P-.)`-.+P)2<P)2
M;@%N/@%N0@)2;0-.+@%N/`--=P)2=P%N.0)2=@)2=0%N10)0.P%N.`-.*P)2
M=`)2:P--=0%N1@)2<@%N.@-.*`-.*0-.)0-.+`-.)P--?@--?0)2<01,10-F
M*@%Q:@%Q;P%Q:`)91`)9.P)91P)9/P)910%Q<`%Q:0)9.`)9/@)92`)900)9
M1@)9.@123`-2.P)90@%Q:P)90`%Q;@%Q;0)9/`)9/0)9.0)90P%Q;`)92@)9
M20-20`-2/P)>1P)>0P%T:0-5>0)>/0%T8P%T<P)>20%T:P%T9P)>0`%T;@%T
M<0)>2P%T9@)>0@%T;P)>30)>2@)>/@%T:@%T9`%T<@)>10%T;0)>/P%T:`)>
M3`%T;`%T90)>1@%T<`)>1`)>2`-5>@1<7P-860)B6@)B8`%W)0)B8P%V?@%W
M(0)B6P)B8@)B70%W)@%W(P-86P)B60-86`%W(@)B7P)B80%W)`)B7@)B7`-F
M+`1<7@-86@)F0@%X8@%X8P%X7P-:<@%X8`-:=`)F/@)F/`-:=0)F0`%X9`)F
M00)F.@)F.0)F/0)F.P%X80)F/P)I60%Z*P%Z*@)I6@-<;`)I7`)I6P%Z+`->
M4P->4`)K>0)K=@)K=P->40)K=0)K>`%Z?0)K>@->4@%Z?`)M;P-?6@%\00%\
M0P)O/0%\0@)P1P)Q+P)Q,0)Q+@)Q,`%].01M>`-B-0%(3P0E5P%2?@(P4@%7
M30,X,0\Q>`%<7P(_(@(_(P-F+0-(=P)92P%T=`)>3@-5?0-87`%W)P)F1`)F
M0P%Z+0)K>P-?6P)M<`%\9`(B:00B(0%/+`%+.`\H2@(L;@,J3@(R)`(Q?0(R
M(P(R(0%73@(R(@(Q?@,S/`(X-@0Z*P(_)`(_)0)&,`)&,0%E=0%E=@)&+P)&
M,@)&+@%E=`-(>`%J2`-(>0%E=P)-(P%N1P)2>0%N2`-.,`%Q<0)93@)93`)9
M30)>40)>4`)>3P=!801<:`)F101@;P%X90)F1@)M<0%\90)P2`%(4`%/+@%/
M+0(L<`%3(0,N700O,`(L;P(R)@,S/0%73P(X-P(R)0,S/P0O+P,S/@%<80(X
M.@(X.`(X.0%<8`(_)P(_*`(_)@-#;@%E>@)&-`)&,P)&-0%E>0%E>`1&)@)2
M>@)2?`-.,0%N20)2>P)93P%Q<@)B90-870)B9`%X9@)F1P%X:`%X9P)I70)K
M?`%Z?@%(40(L<0%3(@(R*0%740(R*`(R)P,S0@%74`,S0P(X0`0T/0(X0@(X
M.P(X/`%<8@(X/0%<8P(X00(X/@(X/P%<9`,^-P%A1`%A10,^.`(_*0)&-@)&
M-P-#<@)-)P%J2P%J20%J2@)-)`)-)09@6`)-)@)3(P-.,@)3)`%N2@)3(0)2
M?@)3(@)2?0%Q=0)94`%Q<P%Q=`)>4P%T=0)>4@)A-`-5?@)B9@)B9P%W*`-8
M80%W*0%T=@)F2`)F20)I7@%Z+@%(4@-F>P%(4P%74P%/+P%74@(L<@,X-@0K
M)0,S1`%A1@%(5`%3)`(L<P(L=`%3(P%3)0%(500G80(L=0%750(R*@%75P%7
M5`%75@,X-P(X10%<90,X.0(X1`(X0P0Z.`)&.`-)(@)-*`1&+`%N2P%Q=@)9
M4@)940-6(0)>5`1<<0-88@-<;P)K?01I+@1I+0%(5@(D<P(H2@%3)@(L=@8[
M(0(R+`0O.@,S20,S2`%76`(R*P%760,S1P-F+P(X1P,X/0,X/`%<9P(X1@(X
M2`,X.P%<9@,^/`(_*P(_+`(_*@%A1P-G*00_?`%E>P-#<P%E?`1&,P%J30-)
M(P)-*@)-*0%J3`-))@,^.P-))0-F,`)3)0-.-`-.-@)3)@-.-P-.-0-..`)9
M4P127`-20P%T>@%T>0%T=P%T>`%T>P-6(@)B:`%W*P%W*@)F2@)I7P-<<`-<
M<0-<<@%[;P%[;@%(5P8[)`(O?0%E?@%A2`%E?0%J3@9@8`%(6`(A:`%(60%(
M6@,D-0,D-@(H2P(D=@,G)`(D=P%+.@,G)@(D=`%+.0,G)0%+/`(D=0%+/@%+
M/0(D>`%+.P0D<`,G(P%/-`%/,@(H30,J5@%/,0,J6P,J6`,J3P%/-@%/.`%/
M-0,J60(H4`(H3`%/.0,J4@%/,P%+/P,J5`%/-P(H3P,J5P0G9`(H3@0G:0%/
M,`-F,0(L?`%3*@%3*P(L?@,N9@(L>`(L>P(M)@(M)`,N8`%3+`(M*@%3+P(M
M)P(L?0(L>@,N80,N7@(_+@(M)0%3)P(M*`(L=P(M(@%3*0%3+@(M(P%3,@%3
M,`,N90(L>0%3+0,N9`(M(0%3,0%3*`(M*0%77@,S3`%79P%77`%76@(R+@%7
M8@%77P(R,`,S2@,S4@%780(R+P(R+0(R,@%79@%79`(_+0,S2P(R,P(R,0%7
M6P,S3@,S30%770%78`,S3P%78P,N8P%790,^1`(X4@%<:0,X20(X20(X2P,X
M1P(X3`0T30(X5`(X4`(X3@0Z.P(X40(X50%<:@%<;@(X2@0T1P(X4P0T4`%<
M;`,X00%<:P(X3P(X30,X0@%<:`%<;0,X10,X2`%A3@(_-@,^/@0Z/@(_-`%A
M4`0Z1P,^0P,^10,^00(_+P)&1@,^/0%A3P(_,P,^0`,^0@(_,`%A2P%A40(_
M-0%A30(_,@%J3P%A3`(_,0%A4@%A2@%A209#6@)&/@)&/`-#>P)&0@-#?@)&
M.@)&1P)&/P-#=0)&.0%F)`%F*@)&1`1`*0)&/0-#=@%F)P-#=P-$(P%F)0)&
M10%F(@%F(0)&0`%F)@%A4P-#?`)&0P)&.P%F(P%F*`%F*0-$(@%J5`%J4`-)
M)P%J50)-+0-)*@1&.0)-+`)-+@%J4@)-*P%J4P)-,0)-,`)-+P1&1@%J4012
M9P-..P-./0-..0)3*@-./`)3+0%N40)3+`%N4`%N3`%N30%N3@)3*0)3*`%N
M3P-..@)3*P)3)P)950)97P%Q>0%Q>`-220)960)96P-21P)95@-21`)96@)9
M5`)970%Q=P)97`)96`)97@-6(P)95P%T?@)>50)>6P%U)`%U)@%U(P%U(@18
M)P%U(0%T?0)>5@)>60%T?`)>6@-6)`%U)0)>6`=(?`)>5P%W+`-890%W+0)B
M:P)B:0)B:@-:=P)F3`-:>`)F2P%X:0)I80%Z+P)I8`)K?@)M<@%[<`)Q,@)Q
M,P%\1`%(6P0G;`%/.@(_-P%J5@%U)P)>7`%(7`0D<P%7:0%7:`(_.`,^1P0Z
M3`1,8@)98`%(70%3,P0Z30,^2`(_.0(_.@(_.P%J5P%Q>@%(7@0G;0%/.P(M
M*P%7:@(R-`%<;P,^20(_/`%F*P%J6`%Q>P%U*`%W+@)F30%(7P%//`,J700G
M;@%7:P(X5@%A5`-)*P%J60)-,@)3+@-22@-8:`-:>0%(8`%A50)&2`%J6@%(
M80(H40(M+`%3-`,N:`(R-@0O3P,S5P%7;@,S6`%7;`%7;0%7;P,S50(R-0(X
M6P(X6`(X6@%<<`%<<@%<<0(X5P%<<P(X60(_/0(_/@(_/P)&2P-$)@)&3`1`
M+@)&2@)&301`+0%F+`-F-`)&20-)+0%J6P-)+@)3,P)3+P)3,@)3-`)3,0)3
M,`)980)98@)98P%Q?`%Q?0)>7@)>70)>7P)B;0)B;`)F3P-:>@)F4`)F3@-:
M>P%Z,`1D+`)I8@)I8P->50)M<P)O/@)P20%(8@%+0`%U*0%(8P\R,@(X7`(_
M0`-:?`%\;`(B:@0A4P,D.`(B:P(B;0%(9`(B;@(B;`0C+P(E(@(E(P(D>P,G
M*`0D>P0D=0(E(0%+0@,G*0%+0P(D?`(D>@(D>0(D?0%+00(D?@(M+0,G*P0D
M>0(H5@%//P(H50(H5P,J8`%//@(H7`%/0@(H4@(H8`(H9@%/20(H8P%/1@,J
M:P(H60(H7P(H80,J9@(H5`%/10%/0`(H6@%/1P%/2@%/1`,J;`%//0(H7@(H
M6`(H90%/3`%/2`%/0P(H70%7<`(H6P%/00%/2P0G>@(H4P0G?@(H8@(H9`,J
M7@\H8P,J:`0G>P,N=@%310%3/P%31P%31`(M-`(M-P%30`,N:@(M+@0K.@%3
M.0%30P,N:P%31@%32`(M0P(M.@,N>`%3.`(M0@%3/`%3.@%3-0(M,@,N<@(M
M00(M-@(M.0(M1@,N=`%320(M0`%300(M.P(M10(M.`(M/`(M/P,N:0,N;@(M
M,`(M1`(M/@,N;P,N>@(M+P8T/`(M,P%30@%3/0%3-@%3.P%3-P%32@(M,0(R
M1P%3/@0K/0,N>0(M/0(I0@,N=P-F-0-F-P(R2@%7?@,S8@(R.@0O70(R10(R
M00,X30(R5`,S60(R3`,S7P(R0@,X6P(R2P(R/`(R0`(R5P%8(P(R3P(R1@%7
M<0(R50(R.`0O6@(R3@0O8P%8(@%7>P(R-P%7>0%7>`%7?0(R30%7=0%7?`(M
M-0(_00(R2`0O7P,J7P(R/@%8(0(R/P(R0P%8)`(R.0(R40,^5P(R4`(R6`%7
M=P%7=`(R5@(R4@(R20(R1`%7>@%7=@(R.P%7<@(R4P%7<P0O7`(R/0,S6@,S
M8P-F-@,M,P0T9P,X3@,X40(X8@(X9`(X:0(X?0%=(P%<=P,X5`(X80%=)`%=
M)0(X;`(X<P(X>0,X4`(X9@0T;0(X;0,X3P,X70%=)@(X>P(X=@%=(0%<?0(X
M<@(X;@(X8`%<=`(X90(X70,X50%<?`%<?@(X:@(X9P%<>0(X=P%<=@(X:`(_
M:@(X<`,X7@(X;P%<=0,X5P%=(@,X4@%<>`(X7@(X8P(X=`(X>@%=)P(X7P(X
M:P(X<0%<>P0T;P,X6`(X?`(X=0(X>`,X7P\W>`%<>@0Z:`(_40(_10%A70(_
M8@(_:P(_;@%A6P(_30(_9@(_3@(_7`%A:`(_6`%A90,^7@(_60(_0@4[;P(_
M9P,^3P,^60%A;@(_9`(_6@(_<`(_50)&;0,^30(_<P%A;`(_4P(_7P%A;P%A
M6@(_5P(_<0(_4`(_20(_5`,^7P(_2`(_1@%A5@(_:`(_3P(_;`,^2P(_;0%A
M7@%A8P%A7P%A9P(_8P%A8`(_6P(_2P\^9@%A6`(_0P(_90(_;P(_2@%A9@(_
M=`(_5@,^4@(_4@,^7`%A5P%A:P,^6@(_80%A;0,^4`(_70%A8@%A7`%A9`%A
M60%A:@(_7@(_3`(_8`(_1P(_:0,^6`0Z9P,^70,^5@,^3@(_<@-F.0,^6P-F
M.`(_1`)&;`-$+0)')`%E7`)&<0-$,0)&;P)&6@%F,`)&:@)&?@)&9@%F.`)&
M?0)&9`%A:0)&=`)&90)&>P%F-P%F+P-$.@)&3P)&5P-$-0)&<`)&:`)'(P)&
M:P%F/0)&?`-$+`%F-`-$/@)&;@)&=@)&6P)&=0-$)P)'*`)&5@)&=P-$,P)'
M)@-$/P)&4`%A80-$0`)&7@)&70%F-@-$,@)&80)&8P)&<@)')0%F.0-$.`%F
M.@-$,`)&50%F,@)&60)'(0%F.P1`1`%F,P%F-0%F/`)')P)&>`)&<P-$/`-$
M+P)&8`)&7P%F,0)&40%F+@)&:0)&4@)&9P-$+@1`00)&7`)'(@-$*@-$.01`
M-@%F+0-$.P-$*`)&6`1`1@)&5`)&>@)&4P%J:`)-6@-)-0-)1`)-20-),P-)
M.`)-,P)-40%J8`)-0@)-3`%J8P)-10%J80)--@)-5`)--0)-2`-)/`)--`-)
M.01&;`)-1@)-3P)-30)-00)-/`)-.@-)0@)-.P)-3@)-60)-0P%J8@-).P)-
M/@-).@)-4@-)00%J90)-/0)--P)-1P%J:0-),@1&6`%J70%J9@)-/P)-.0-)
M-@%J7P)&>0%J7@)-2@-$-@%J7`%J:P%J9`)-2P)-0`)-.`)-4P)-1`%J:@)-
M5P%J9P)-5@-)/P)-4`)-50-)/@-)0P)-6`-F.P-F/`-F.@-)/0)37`)370)3
M4`)33P)32P%N70-.3P%N50)37P)37@)&3@)32`)33`)31@-.1`)360)32@-.
M0@)38`)30P)300)330)35P)34@%N7P)3.`-.0`)35@-.3`-.1@-.5`%N8`)&
M8@)31`)3.P)3/@)39`)310)3/`)3.@)3-P1,>@%N60)33@%N6`%N7`)320)3
M40%N4@)380)390%N5`-.2P)30`)35`)36`)3/0)38@%N6P1,:@%N6@)3-0%N
M7@)36P)3/P)34P)3.0)31P)30@%N5@%N5P)350)39@)38P)36@1,>`-.30-.
M3@-.4@1,=`)3-@%N4P)9=`-26@)9:P)9;@-24@%R)0)9<`)990)9;`)9<@%R
M(@%R)@%Q?@-260-24`)99P)9=P1-)013,P)9<013)`)9:`):(@)9>@)99`)>
M<@)9:@%R(0-26`)9=0-25`):(0%R*0-25@)9?`)9:0)9;P)9<P)9;0):(P)9
M?@)9>P%R(P%R)`%R*`)99@):)`%R)P)9>`-23P-250)9=@-F/0)9>0)?(0)>
M;`)><0)>?@)><`)>:`)>;018/@%U+`-6*P)>80)>>0)>>P)>8`%U*P)>?0)>
M=0%U,@)>?`)>;@%U-`)>9@)9?0)>=@)><P)>8@)?(P%U+@-6*`-6*0%U+P)>
M9`)>=`-6+0)?(@)>=P)>:@%U,0%U+0)>>`)>:P)?)`)>90)>;P)>>@)>9P)>
M:0180`%U-0)>8P%U,P%W,`%U*@-6+`-6,`%U,`%W-`)B?0-8;`)B<P)B;@)B
M=`)B?@)C)`)C(P%W-@%W-0-8;@1=+`)B=0)C)0)B>`)B<`-8;P)B<@)B<0)B
M=P)B?`)B;P)B=@)B>P%W,P1=*`)B>0-8:P%W,0)B>@%W+P%W,@)F8`)C(0-F
M/@%X;0-:?@)F6`)F7`)F5`)F5P-:?0)F7P%X:P)F9`)F701@>@)F50)F90)F
M7@%X;@%X;P)F8@-;(@)F5@%X:@%X;`)F40)F60)F4P-<>P)F8P)F80)F4@)F
M6@1@>P-;)0-F/P)I:@%X<`)F6P%Z,@%Z-`%Z,0-<=@)I;P)I9P)I90)I:0)I
M9@-<>`-<?`)I:P)I;0%Z-0%Z-P-=(@)I;`%Z.`%Z-@)I;@-<?@1D-P-=(P-<
M=P%Z,P-=(0->6P->6@%[(0)L(0)L)P%[(P)I:`)L)@->7`)L+0)L)`)L*P)L
M*@)I9`)L)0)C(@)L+@)L(P)L*`->6`)L+`)L(@->5@)M=P%[(@)L*0->5P)O
M0P)M>`)M=@)M=`)M=0)M>0-F0`%\10)O00)O/P)O1`)O0@-@0P)O10%\1@)O
M0`-@+P-A1@)P2@-F00)Q-`)Q-0)Q-@-A1P-A?`)R-0)R+0(B;P%/30%32P0O
M:`(R6@(R60%8)0%=*`(Y(0,X8P,X8`(X?@,X80%A<`%F/P,^80%F/@%F0`5)
M3@)-6P)39P):)0):)P):)@<R80%U-@)?)0)C)@)Q<P%(90,G+0(H:0(H:@(H
M:`(H9P%/3@-F0@(M2@(M2`,O(P,N?`(M1P,N?@%33`%33@%330(M20,O)`\M
M/@,S:0(R9@(R8P(R800O;0,S;`%8)@(R9`%8*P(R7@(R;0,S;P(R;P(R7P,S
M;@%8*`(R<`(R:P(R70(R8@(R;`(R:`(R90,S:P%8+0(R;@(R8`,S:@,S<`(R
M:0(R6P%8+`%8*0(R9P,S;0(R:@(R7`%8*@%8)P0T>@,X9@%=,@(Y*`%=,0,X
M9`(Y*P(Y+@%=+@%=+`(Y(P(Y+`(Y*@(Y)P(Y+P(Y,`(Y,@(Y,P(Y(@%=*P(Y
M)0(Y)`(Y,0%=+0(Y)@%=+P%=*@(Y*0%=,P0U)@%=,`(Y+0\X.@%A=P)`)00Z
M<0(_>`%A=`,^8@)'+@)`(P(_=0%A<@(_>@%A=0(_?@(_?`%A>`%A<00Z=@,^
M8P(_=@(_>0%A=@0Z;P(_=P4[>P)`)`)`(@(_>P(_?0)`(0%A<P,^:`)'+P)'
M-0)'*P)',0%F00)'+0%F1P-$1`-$10%F1@-$20%F10)'-`%F2`%F20)'*@)'
M-P%F2@%F1`%F0P)',P%F2P)'*0)'+`)'-@)',@1`601`4@)->P)-<`%F0@5"
M70-$1@-$2`%J<@)-9`)->0)-90%J;0-)3P)-8@1`50)-:P)-8P%J;P)-70)-
M>`%J<`)-=0)-=@)-7@%J=0)-;0-)2@)-9P)-;@)-801&?@)->@)-<@)-;`)-
M7`%J<0)-<P-)10%J=`)-=P-)3`)-<0%J;@)-;P-)20)-:0%J;`)-8`)-:`)-
M=`)-9@],,P-)3@)-:@-)2P-F0P%N:@)',`)3>0)4)`)3>`)3=`)3<0%N:P)3
M;P%J<P)3:`%N:0)3;@%N:`)3<P)3<`)4(@)3>P)3=0)3>@%N9`)3<@)4)P)3
M:0)3:@)4(P%N90)4*`%N9P)4*0)3=P)-7P)3?0)3=@)4(0)3?`5050-.701-
M*`)3;0%N8@)4)@%N8P)3:P%N9@):,@)3?@)4)01-,0-.60):+P%N80%R*@):
M.0):-013/`):,P):+@):/0-26P-270131`%R+@-27P):*@):-@):-P):+0):
M+`):.@1300):,`):*P):,0-28@):/`):*0):.P):.`%R+`%R*P13.0-27@%R
M+0):-`):*`-F10-F1`)?)P%U/`)?*P)?*`)?+P)?-0)?*@-6.@)?/@%U.0)?
M.`)?+0)?.0)?-`)?.P)?+`%U/@%U/0)?+@)?/`)?)@)?.@%U-P-6.0)?,@)?
M,0)?-@)?*0%U.P-6.P%U/P)?,`)?-P%U0`)?,P-6-@-6-`%U.`%U.@)C,P)C
M,0-;*`-8=@)C-P)C-0)C.`-8>`)C*@)C,@)C/`)?/0)C+@%W.@)3;`)C*0)C
M-@)C,`)C+0)C*`)C)P)C.P-8<P)C+`)C*P%W.`)C-`-8=`%W-P-8=05D2`%W
M.0)C+P)C.@-F1@)F:0)F:@-;+`%X=`)F9P%X<0)F;P-;)P%X=0)F<0)F9@)C
M.0)F<P)F:`5I0P%X<@)F;@-;*0)F<`)F:P)F<@)F;0)F;`%X<P-8=P-;*P)I
M<0)I<@-=)0)I=`%Z.0%Z.@)I=0)I<P-=)`)I<`->70)L,0)L-`)L,`1A)@%[
M)P)L,@%[)@%[)0%[)`)L,P)M?@)M?`-?7P)M>P)L+P)M?0)L-0)M>@-@10)O
M2`)O)@)O1@%\1P)O1P)O20-F1P)P30%\9@)P3`)P2P%\9P1L(P%])P)Q70)Q
M=0)Q=`)Q=@%(9@(M2P,O)@(R<0(R<@,X:@,^:@,^:0)`)@9.3P)L-@)P3@%(
M9P%33P(M3`,S<0-F2`0U)P(Y-`%=-`)`*`)`)P%A>0-$30%F3`)4*@%N;`-.
M7P%N;0-28P-29`132P%R+P%\:`%(:`,O)P(M30%/4`(M3P(M3@%34`(R<P,S
M=`(R>@%8+@(R>`(R=@,S=P(R?0(R=`(R=0%8+P,S<@%8,P,S<P,S=0(R?@%8
M,@(R?`(R>0(R=P%8,`%8,0(R>P,S=@-F20%=-@(Y-0,X<@%=.P(Y10%=.@(Y
M1P,X;@,X=`(Y.P%=.`(Y1@,X;`(Y-@%=.0(Y0@(Y/@(Y0`(Y.@(Y00,X:P0U
M+P%=-0(Y/0,X<P(Y/`(Y.`,X;0(Y0P,X;P,X<0(Y/P(Y-P,X<`(Y.0%=-P(Y
M1`%A?`)`,P0Z>P,^<`,^<@)`+P)`,0)`+`)`*P)`*0,^;0)`,`)`,@)`+@,^
M;P)`+0%A>@%A>P)`-0%F5`)'.0)'/P)'.@)'.P-$3@)'0`5";`%F5@1`80%F
M3@%F50)'.`)`*@%F40%F3P)'/@)'/0%F4`%F4@)'/`%F30-$3P%F4P-.8`)-
M?0%J?`-)60-)4@).*@).*0-)5P).)`%J?@).*`)-?@).(0%J=@%J>`-)5`).
M)@)-?`%J>@%J>0).(@).)P).)0%J>P).(P-)40-)5@)`-`%J=P-)6`)4*P)4
M,@%N;P1-1@)4-@%N<P)4+@)4+`1-/@)4-0-.80%N;@)4-`%N<`%N<0)4+0%N
M<@)4,P)4+P)4,`)4,0%J?0-.8@):/@):2@134P%R-`):10):1P-290%R,@):
M/P):0P134`):1@%R,`%R,P):20):00):0@):2`):0`):1`%R,0)?0`)?/P%U
M0@)?10%U1`-60`188@%U00)?00%U10)?0@-6/P-6/0)?0P)?1@-60@%U0P)C
M00-8>0)C1`-8>@)C/@)C0`-8?`-8>P)C/P)C0@)C0P)?1`)C/0-F2@%X>`)F
M=P)F>@)F?`)F=0)F=@)F>0)F>P%X>0%X=P%X=@)F>`)F=`)I=@%Z.P-=*0)I
M=P-=*`)L.`%[*`)L.@%[*0)L-P)L.0%[<@5T.`)N(0%[<0)O3`)O2P1L)0)O
M2@]H2@-A20)Q-P)Q.`)Q.@)Q.0-A?0(B<`%(:0%340(Y2`%A?0-F2P)'00%W
M.P-;+P)F?0-@1@-A2@%+1`,O*00O=@0O=0%=/00U-`,X=@,X=0%=/`,X=P)`
M-@%A?@)`.`)`-P9.8`,^=`)'0@%F5P).*P).+@).+01'-0).+`)4-P)4.0)4
M.`-.90%R-@-29@1360-.9`%R-0-61@%U1@)?1P)?20)?2`-8?@-8?0%W/`-9
M(01A+P-;,0)G(0)F?@]C=P)I>`%Z/`-=*@->80%[*@)N(P)N(@%]*`%+10(M
M4`%34@(Y2P(Y200U.00U.`(Y2@)`.@)`.P)'20)`.0)'0P)'1P)'1@)'2`%F
M6`)'10)'1`)'2@-$5`).,0).+P-)7`).,`)4/`)4.@-.9@)4.P):2P)?2@)?
M2P%W/0-;,@)G(@)I>0%Z/01A-P)L.P)N)`%[<P1I10)O30)Q.P%+1@%35`%3
M50(M40,O*@,O+`(M4@%34P0O?`%8.0,S>P%8-P,S>@%8-@%8/0%8-0%8/@(S
M(0%8.P0O?0%8.`%8/`%8.@%8-`,S?`%=10,X?@%=/P(Y3P%=1`,Y(P,Y*0%=
M1@%=0`9$<`%=00,X>0(Y30,X>P,Y)0%=/@,Y(@(Y3@%=0P0U/04U6P(Y3`%=
M0@,X>@%B*P,^?`%B+00[+P,^?0)`/@%B+`%B(0%B)0,_)`%F:P)'3P)`0`%B
M)@,^?@,^=0)`0P)`1`%B*@0[,`)`1@,_(0)`2`,_(P)`20)`/0)`/`)`2@%B
M*0)`1P)`100[+`%B)P%B(P%B+@)`00)`0@)`/P,^>`%B*`0[,0,_(@%B)`%B
M(@)'3@%F9@%F80-$8`-$60%F7`-$8P%F;`%F70-$50%F60%F:`%F90%F9P-$
M6`%F7@%F8P%F6@%F6P)'5@)'4P)'2P)'4`-$6P%F:0)'5P%F:@%F8`-$7`-$
M80)'30-$5@)'50)'40)'5`)'4@%F9`)'3`%F7P-$70).-`%K(@%K)0-)7P).
M-@-)9`%K+0).-0%K)P-)8P%N>`).-P1'10%K+`).,P%K+@-)7@-)8@-):P%K
M(P-):`%F8@%K)@-)8`%K)`%K*`%K*@%K(0%K+P%K*P-)90%K*0).,@-)9@],
M00-.=`%O(0-.9P%N>P-.<@-.<`-.;@%O)`-.;`)4/P%O)0)42P)41`%N=`)4
M3`)41@%N?@)41P-.<P%N?0)42@%N=P)42`)4/@%N=@):5@%N?`-.=0%N>0-.
M:0%O(P-.:@)4/0-.=@)400%N=0)40`)40@)40P%O(@)410)420)430%O)@%R
M/`):40):5P):5`):3`):6`):30-2:@):4P-2:P%R-P%R/0):60-.;P-29P%R
M.0-2;@%R0P%R/@):6P):50%R.@):3@%R1`):3P):4`%R10%R0@%N>@-2:0%R
M.`):7`%R1@-2:`%R/P):6@%R.P%R0`%R00-F3`%U3@)?4`)?60)?5@)?6`-6
M20%U2P)?40-62@)?5P%U1P)?4P%U3P)?3P)?5`)?6P):4@)?50)?3@%U2`)?
M30%U20)?7`%U2@)?6@%U30)?3`-62`%U3`)?4@)C1P)C50)C4`)C4@)C1@%W
M/@-9*@)C10%W00%W0`-9)@)C5`)C3`)C20)C3P-9)`)C2`-9*`)C2@)C4P)C
M40-9(P%W/P)C6`)C5@)C30)C5P)C3@-;-`)G)@%X>@)G+0-;-01A.@)L/@%Y
M(P)C2P)G)`%X?0)G)0)G*@-;-@-=,P%Y(0%Y(@)G(P)G+`)G+@)G)P)G*0)G
M*P)G*`)G+P%X?`%Y)`%X?@%X>P)I?`1D30%Z0@)I>@-=,`-=+`)I?@-=,@)J
M(0%Z0`)J(@)I?0-=*P)I>P%Z0P%Z/P)J(P-=+@%Z00%Z/@-<;01G.P%[*P->
M8@1G00%[+`)L/0)L/`)L/P)L0`->8P%[+0)N)0)N*@%[=`-?80)N)P-?8@)N
M)@)N*0)N*`-@2`)O401J?`%\2`)O4`)O3@-@1P)O3P-@20-@>P%\:@%\:0)P
M3P)P4`%\:P-A2P)Q/`)Q/0%]-`-A:P%].@-A?@)Q=P)R-@%+1P4P1@(Y4`,Y
M*@(Y40)'6`)..`)43@%U40-630%U4`)C60)G,`-?9`)O4@%+2`(S(@%8/P%=
M1P)'6@)'60%O)P)43P%O*`)?70%W0@-=-`-F30-B(0%]0P%+20(H:P(S(P,Y
M+00U30%=2`,Y+`(Y4@(Y4P,_*@)`2P,_*0%B+P%F;0-$9`)'7`)'6P)'70-)
M;0)..0)..@%K,`%R1P%O*0%R2`)?80)?7@)?8`)?7P%U4@-9*P)C6@)G,@)G
M,0(E)`%800%80`(S)`,Y+@(Y5`,_+`,_*P)`30)`3`%B,`,_+0)'7P)'8`)'
M7@1`>`-$90%F;P%F;@1'5`%K,@%K,0-.>@)44`):7P):70):7@%R20)?8P)?
M8@-63P)C70)C7`)C6P)G,P-A30)Q>`%+2@%35@,O+@%35P%80@%80P(S)@(S
M)0(Y50,Y,`%=3@%=3`%=20%=30%=2P%=2@,Y,@,Y,0%B,0)`4`,_+P%F=`%B
M,P%B.`)`4@%B.@%B.0%B/`)`40)`3@%B-@%B,@%B-`)`3P%B.P%B-P%B-0%F
M=@%F=0%F<P%F=P1`?@%F<0%F<@-$:0%F<`5#+0)'80-$9P)./`-)<`%K-`%K
M-0%K,P-)<@)..P-)<0)./0-F3@)44P)450-.?@%O,@)45@%O*P)44@%O*@%O
M-`%O,`%O,0%O+0)440%O+`)45P)45`-.?0%O,P-/(@%O+@%O+P):80-2=0):
M8P):8@-2<P):9`%R2@):8`-640-64@%U5@)?9`%U4P%U5P%U50%U5`)C7@1=
M:0)C80=#4@)C8`-9+@)C7P%W0P)G-`)G-0%Y)0)G-@%Y)@-;.`-F3P%Z101D
M3P%Z1`)L00->90->9@%[+@)L0@)N*P%[=0%[=@-F4`)O4P-@2@%\;0-A3@%+
M2P,Y,P%=4`%=3P)'8@)'8P%K-@):90%O-0):9@)?90%+3`,D.@(M4P%360%3
M6`(S)P%81`(S*`(Y6`,Y.0(Y5P,Y-P(Y5@,Y-0,Y.`)`5`%B/P,_.0,_-`)`
M4P%B/@,_-P,_,`,_,P)`50%B/0,_.`)'90)':`)'9@)'9P)':P)'9`)';`)'
M:0)':@%K.`)./@-)=0-)<P%K-P-)=`)46P)460-/)@1-=0%O-@)46`)46@-/
M)0%O-P-/(P):9P-2=P)::`%U6`-9,0)G.`)G.@)G-P)G.0)J)`)L0P-F40)Q
M7@%+30%36@(S*0(S*P(S*@(Y6P%=4@,Y/@(Y60,Y.@%=40(Y7`,Y/0(Y70(Y
M6@9%.`)`80%B1P)`60)`7P,_/P,_.@%B0@%B10)`6`%B0`)`7`)'<@%B1`,_
M.P)`5P,_/@)`70)`6@)`8`)`5@)`7@%B0P%B1@)`6P%B00%F>0)';@%F>`)'
M=0)'=`%G(0%G(@)'=@%F>@)'<P%F?@)'>`)';P-$:P)'<0%F>P)';0)'<`)'
M=P%F?`)'>0%F?0%K.0).0P).20).00).2@-)>P).0`).10).2P).2`).1P).
M1@-)>@)./P).1`-)>0).0@%O/`%O.0)49`)4:0)4:P)4:`)480)48P)4;0)4
M:@)490)4;@)48@)4;`%O.@%O0`%O/@)47`%O/P%O.P)470)47P)47@)49@)4
M9P-/+`%O/0-/*P%O.`)48`):<@%R3`-2?@)::0%R30%R4`):;@512`)::P%R
M3P14*0-2>P):;P):<`)::@):<P):;`):<0%R3@-2?`%R2P):;0-65`)?:P%U
M6P%U60%U7`%U6@)?:@)?9P)?9@-650)?:019+0)?:`)C;P%W20)C9@)C90-9
M,@%W1`)C:P)C:@)C8@)C;0)C9P%W2`)C9`)C;`)C8P%W10%W1P)C:`%W1@)C
M:0-;.@)C;@)G/@-;.0%Y*P)G.P1A4@)G/P-;.P1A3P%Y*`)G/0%Y+0-;/`%Y
M*@-;/0)G/`1A5`%Y+`)G0`%Y)P%Z1P%Z20-=-P)J)P%Z2`)J)0%Y*0)J)@%Z
M1@%[+P%[,0)L10%[,`)L1`)N,`%[=P)N+P%[>`)N+0)N+`)N,0)N,@)O5`-@
M2P)N+@)P5`)P40)P4@)P4P%]*0-A4`)Q0`)Q/P)Q/@)Q7P-A;`)R+@)Q>0%]
M.P%+3@%810,Y/P\X;`,Y0`,_0`-$<P%G(P-)?0-)?`-/,`-/,@-/+P-/,0%O
M00-F4@):=`]8,P-9-0%W2@-9-@)G00-;/P1A5@-=.`1G40)Q>@%+3P%/40%3
M7`%36P4P50%82`,T(0(S+`%81@(S+0%81P-F4P,Y00(Y8@(Y7@,Y1P0U8P%=
M4P(Y80(Y8`(Y7P%=5`(Y8P(Y9`,_10)`:`)`9@)`:@)`:P)`<0,_1P)`;0)`
M;P5#4`)`9P)`8@0[50)`;@,_1`,_1@)`<`)`:0)`;`)`8P%B20)`90)`9`%B
M2`%B2@,_20%G)@)'>P)'?0)'?`)((P%G)`-$=@)'?@)'>@)((0)((@%G)0%G
M)P)()`).3P).3@1':@).3`).30%K.P%K/0%K.@%K/`)4=0)4=@)4<0-/-@)4
M<@%O0P%O2`%O0@%O20%O1`)4<P1.+0-/,P)4=`)4<`%O2@%O1@-/-01.*P%O
M10%O1P-/-`)4;P-3)`):=@%R4@-3(@-3(0):>`%R5`):>P):=P):=0):>@%R
M4P):>0<T,@%R40-3)0-660%U7@%U80)?;0-66@%U7P)?;`%U70%U8`)C<`)C
M<0)C<@%W2P-9-P)C<P%W3`%Y+P)G1`)G10)G0P)G0@)G1@%Y+@)J*P)J*0)J
M*@)J+`)J*`)J+0)L1P->9P)L2`)L1@%[,@)N,P%[>0)N-`)O5@)O50-B(@%+
M4`%B2P,_2P-$=P%G*`-$>`-*(0-*(@%K/@-/-P-3)P%R5@-3)@%R50-F5`-9
M.`%Y,`%Z*0%[,P%+40%820%G*0-/.0)G1P,G+P0A5`\A:@0C,`,D.P\B<0\B
M<@,G,`(E)@0E(0,G,P%+4@0E(P%+50%+5`%+4P,G,0\E,@(E)0,J<@(H;0,J
M<`(H;P%/4@,J=`0H)@%/5`(H;`(H;@%/4P(H<0(H<`(H<@,J<P,J<0\H<0\H
M;@(M5P(M50%37P(M5`%39`%380%37@,O,0%390,O,@%38`%38P8T8`%38@(M
M5@,O,P%370,O,`%83P(S+P(S-0%83`%84P,T)0%83@(S,@(S-`%840(S+@(S
M,0%830%82@(S,`%84`(S,P%84@%82P0P+P,T)P,T)@(Y9@(Y:0%=5@,Y2P%=
M8`%=7`(Y9P,Y2@,Y3@%=9`%=70%=8@%=6`0U:`%=50%=5P%=8P(Y:`%=6P%=
M7@%=6@%=7P(Y:@%=80%=60(Y90,Y3`,_3P,_4`,_30,_3`,_40)`<@%B3`)`
M=`,_50%B3@%B4`0U9@)`<P%B30%B40,_5@%B3P,_5`,_5P%G+P)(*0%G-P)(
M)@-$?0%G.`%G+0-$>0)()P-$?`-$>@%G,@-$>P)(*`%G*P%G*@-$?@%G-0%G
M-`%G,P%G,0%G-@)()0%G+`%G+@%G,`%K0`%K0P-*)`%K1P%K00%K1@%K1`-*
M)P%K/P-*)@%K10%K0@],:P1.,@)4>@%O30%O2P-//`)4>P1.,P%O3@%O3`)4
M>0)4>`-/.P%R6@)4=P%R6`%R5P):?`%O3P%R60):?0%R7`):?@%R6P%U8P)?
M;P%U8@%U9P%U90%U9@%W3@%U9`)?;@);(0%W30%W3P-9.@%Y,0%Y,@1A7P)J
M+@1I4@%\2@%\20%+5P,B7@,B70(B=0%85`,D/`(B<@(B<P(B<0,D/0(B=`-F
M50(E*@(E)P(E+`(E*`%+6`%+6P,G-0(E*0%+6@(E*P,G.0,G-`%+60,Y40,J
M=P0H*P(H=0(H=P%/5P(H<P(H=@(H=`%/50%/6`,J=0%/5@,J>`,O-0(M60(M
M70(M6@,O.`%3:`,O-`%3:0,O/@(M7`,O-P(M7@(M8`,O/`%39@(M7P1!.0,O
M.P%39P]%;0(Y<0(M6P(S-@(S/P(S/0(S.`(S.0(S/@(S0`%85@,T*0(S.P(S
M-P%850%85P(S.@(S00(S/`%=90(Y=`(Y;`(Y<@(Y<P%=9@,Y3P(Y:P(Y;0(M
M6`(Y;P(Y<`(Y;@%B4P1..P,Y4@)`>P);(@)`?`)`>0%=9P%B50)`>`)`?@)`
M?0%B4@)!(P)`=P)!(@)`=0)!(0)`>@%B5`,_60)(,`-%(P)(*P)(,0)(+`)(
M*@)(+0%G.0-%)`)(+P-%)0)(+@%G.@%K20%K2`).5@).60).40).50%K2@).
M5`).4@).6`).4P).4`).5P-**@)5(P%O4@)C=`)4?@)5(0)4?0)`=@%O40)5
M)`)4?`%O4`%O4P)5(@);(P%R70);)`);)0-3*P)?<`%U:`)C=0)C=@-9/`-9
M.P)C=P)G20)G2`)J,`)J+P)L2@)L2P)L20)N-0%[>@%+7`%3:P%3:@%86@%8
M60(S0P(S1`(S0@,T*@%86`(Y>`,Y50(Y>0(Y=0%=:`(Y=@,Y5`(Y=P-F5P)!
M)@)!*`)!)`)!)P%B5@)!)0%B5P-%*`)">0%G/0%G/`-%)P%G.P1!.@)(,@)(
M,P1!.P).6P).70%K3@%K2P-*+`%K30%K3`).7`).6@-**P-*+0)5*P)5*`)5
M*0%O5P)5*@)5)0)5)@%O5`-//P%O50)5)P%O5@-/0`);*0-3+0);*@);)P);
M*`%R7@);)@140@-3+`-3+P19/P)?=`)?<0)?<P%U:P)?=P%U:@)?=0)?>`)?
M=@)?<@%U:0)C>01>)`)C>@)C>`-9/0)C?`%W4`%W40)G2P%Y-`)C>P)G2@%Y
M,P)J,P)J-`%Z2@)J,@1D90)J,0)L3`%[-`->:`)O5P)P5@)P50-@?@%\;@%]
M*@)P5P)Q8`-A;0%]/`%+70%/60%G/@%Z2P%+7@%3;`%=:0%B6`%W4@%/6@(M
M8@(M80(S10,T,`%870%86P%87P(S1P,T+0%87@%87`,T+P,T+@,T,0(S1@%=
M;`(Z(0,Y6`%=:P%=;0(Z)@%=;P(Z(P(Z)`(Y>@%=;@(Z)P0U>P,Y5P(Y?`,Y
M5@(Y?0(Y>P%=:@,Y60(Z)0(Y?@(Z(@)!-`,_70)!,P)!,0)!*0)!.`)!+`)!
M-@)!/0)!-0%B8`,_9@%B7`)!*@,_8`)!,`%B7@,_:`)!+P%B7P%B80)!,@,_
M:0%B60%B6@)!/@)!/`,_8@)!.P)!+0,_90)!.00[9@%B709/;P,_7@-F60,_
M8P%B6P)!.@)!*P)!+@)!-P-F6`)/(@)(/0-%+@)(-@)(20)(4@)(.0%G20-%
M*P)(1@%G/P%G00%G30)(-P-%-P-%+P%G0@%G1`%G3@%G0P-%.01!001!1@-%
M.`%G3`)(/P1!2`)(-`%G2@)(/@%G1@)(4`%G2P)(3@)(0@)(3`%G2`)(-0)(
M3P)(2@-%*@)(40%G0`1!0`-%+0%G3P%G10-%,0-%*0)(.P-%-`)(0P)(1P-%
M,P)(2P%G1P)(.@)(.`)(1`1!0@1!0P-%,@-%-0)(00)(0`-%-@)(10)(2`)(
M30-F6@]%<@1'=0).8`]-(@%K3P).:@).8@%K50%K60).<P).>P).;`%K40-*
M-`).<`)(/`-*-0%K4@).=P).?`).=`-*+P).=@)/(0).>`).9@).;P-%,`-*
M.`%K6@-*,P%K5@).9`).<0%K5`).:P%K4P).>0).:`).80%K5P).?@-*.01'
M=P).8P).=0).<@).;0).7P).7@).9P).>@%K6`).?0).90).:0%K4`-*,@-*
M-P]-)P-G*@-*,0%O8P%O7@)530)520)5,0%O6@-/0@-/4`1.10%O60%O7P1.
M1P-/0P-/00)5+P%O70)5.P)5+0)5+@%O6`)53`%O80)5/@)50P)5/0);/`)5
M.0)500)5/P)5,@)5+`)51P%O8`)52`-/2`)50@-/20)5-P)5-0)5,`-/2P-/
M3@-/1`)5.`)510)5-`)51`)52@-/401.1@%O7`-/10)50`)51@)5/`)5-@%O
M6P-/4@1.1`-/3`).;@)5.@%O8@)5,P]2:P-/30-F6P-F7`-*,`);00%R80);
M0`);/@);4`%R90-3-0);30);10);3P);-P);0P-3/0%R9P-3/@);+P-3.`);
M+0);3@-3,@);3`);2P);.P);.@);,`%R:0140P);-@);/P);2@%R;`);40-3
M-@%U<P%R;@%R:`);-`-3-P);/0);+`);+@%R7P%R:P%R9`);-0);1`)52P%R
M:@);*P%U;@);1@);20%R9@-3.P);.0%R;0%R8P-3/`-3.0-3.@%R8@);0@);
M2`%R8`1410);,@);1P]860]82`);,P<T8P-F70]850-F7@1420-3,0);.`)?
M?@-690)@)0%U<`%U<@)@*P%U;`)@.0)@,0)@)@)@)P)@,`-69@%U>0)@+P)?
M?0)@+@)@(@)@.@%U>`%U=@)@(P-670)@-@-69P)@*`)@-0-69`)@-P)??`%U
M<0-66P)@.`-6:`-67@)@+`-6:P%U=0)@*0-6801920%U=P)@,@-68@-68P-6
M7P%U;P)@)`)@,P-67`)@+0);,0)@-`)@(0-68`%U=`-6:@)D+P191P%U;0)?
M>@191@]=00-F7P]=.0)D+`)D)0%W5`-90P)C?@)D,`)D)P)@*@-90`)D,@)D
M(0-90@%W4P)D*P%W50%W70%W6P)D+0%W7`)D(P-920)D)`)D*0)D+@-9/@)?
M>0%W5@)D-P)D-`)G80)D*@)D)@)D-0)G5@)D*`1>,0%W60-91`%W6`)?>P%W
M6@)D,0)D,P%W5P)D-@)C?01>*0)D(@-91@]A,P-910-F80-F8@-F8`]A0P)G
M7P-;4`)G3P%Y.`)G70-;1`-;10)G30%Y.01A9P)G6`-;0P)G5`%Y/@)G7@)G
M3@)G40%Y-@)G8`-;2`)G60)G7`%Y/`%Y00%Y/P)G50)G4`-;30%Y.@%Y.P)G
M3`%Y-P-;3P%Y-0%Y/0)G6P%Y0`-;2@)G5P)G8@%Y0@-;00-;0@-;3@)G4P-;
M1P)G6@-F90-F8P-F9`-=00->:@)J00)J4`)J0P)J2@)G4@)J2`)J-P)J3@%Z
M3@)J.P)J30)J0@1D9P-=0P%Z30-=/`-=/P)J4@)J1`-=/@)J20)J3`)J-0)J
M3P)J0`)J10)J.0)J/0)J40)J1P)J-@)J.@)J/`)J1@-=/0%Z3`)J/P-=1`-=
M10-=1P1D:P-=0@-=.@)J.`-F9@-F9P-F:`]F5P-=1@)J/@)L4`)L5`%[.P)L
M5@->;0%[-01D;P)L4@)L6`%[.@%[-@1G7`%[-P)L3P)L50%[.0)L4P%[.`)L
M3@)J2P)L401G8@)L30)L5P-?:0-?;@%[>P)N/`)N/P)N.P)N/0)N/@)N.`)N
M.0)N-@-?:@-?;`)N.@)N-P%[?`%[?0-?:P)O60-@4@)O6P1K*05V70-@50-@
M5`-@5@)O6@)O7`-@3P%\3`-@4P)O6`%\2P%\30-@5P-F:@-F:0)P60)P6@%\
M;P)P6`-A(@)Q0@)Q00)Q0P%]+`)Q1`%]*P)Q10)Q80)Q9`)Q8P%]-0)Q8@1M
M8@-A;P-B(P%]/P%]/0%]/@%]1`)R,`)R,0)R+P)R-P-B-@%/6P0E*P0P.@(Z
M*`)!/P)53@)G8P5Q5@%/7`,O0`%3;0%88`0P.P,T,@(Z*0,Y7`(Z*@%=<`%B
M9`)!00)!0`%B:`%B8P)!0@%B90%B9P%B9@%B8@,_;`\_?@-F:P%G4`-%/`-%
M.@)(5@)(5`1!4P)(50)(4P]%>P%K6P-*/0%K7@%K8`%K7P1((@-*/@%K7`%K
M70)54`)53P%O9`)540-/4P)54@%O90-/50-/5@1.2@);60);5P)@0`-30@);
M50);5@%R;P);4@);6@);5`);6`)@/`-31`-30`)@/@-6;0)@/P%U?@)@.P%U
M?0)@/0%U>@%U>P%U?`);4P-F;`%W8`)D.@)D.`)D.0%W7@%W80%W7P-92P-9
M2@=+0`)G9`)G90%Y0P-;4P)J4P)J50)J5`%Z3P%[/`)L6P)L6@)L60]H<@-F
M;0\E.0%/70,A0P(A:0(B>`%(:@(B=@(B>0(B=P0E+@,G.P,G.@(E+@,G/P%+
M8@,G/`%+8P(E,`%+8`(E+P(E+0%+80%+7P,G/0,G/@,J>00H,P(H>`(H>P%/
M8`(H>@(H>0,J?`%/7P%/7@,J>P%/8@(H?`%/80(M9P%3;P%3<`%3<0(M:`(M
M9`%3;@(M900K70(M9@(M8P0K6P,T-@0P/P%89P,T-`,Y7@%89`(S2`%890%8
M:`(S20,T,P%88P%880%88@%89@%=<0(Z+0%=>0(Z+`,Y80(Z+P%==0(Z+@%B
M<`%=<P%==@%=<@%==P%=>`%==`,Y90,_<0(Z*P%B;`)!1`,_<@)!2`,_<P,_
M=0)!1P%B<0%B;0%B;@)!0P)!10)!1@%B:0%B:P,_<`%B;P%B:@-%0`)(60)(
M5P)(6`%G4@%G4P-%0@)(6@%G40%K801()`%K8P%K8@-*10)/(P-*1@-*1`)/
M)`)55`-/6@)54P-/6P144@%R<`%R<0);6P%R<@-32`)@0P-6<`)@00-6;P)@
M0@%V(0-6<0)D.P%Y1`-=20,J?0-320%V(@%/8P0P00%8:0(S2@,T.0\R;P(Z
M,`%=>@%B<@)!20)!2P%B=`%B<P%B=0%B=@)!2@%G5@%G5P%G50%K9`%G5`)(
M6P1!5P-*1P-*20%K90)550);7`%R<P%V(P)D/`)D0`%W9`)D/0%W90%W8P)D
M00%W9@)D/P)G9@%W8@%Y10-><`)P6P-A)0-B+P%/9`%=?`%=>P\Y*@,_?@,_
M?`,_>P%B=P)!30)!3`%B>`-%1@)(7P%G6P%G6`)(7@%G6@)(7`%G60-%1P)(
M70)/)0%K9@)56`52.P%O9@)55@%O9P%O:`)55P%O:0-/8`);70-34`%R=P%R
M=`%R>0);7P%R=0);7@%R>`-330-33`%R=@-340)@1@)@2`-6=`-6=0%V)`)@
M1P%V)0)@10)@1`1>.`)D0P)D0@%W9P)D1`)G:P%Y1P)G:@)G9P%Y1@)G:`)G
M:0)J5@)J5P%Z4`-=3P%[/P-=3`-=3@)L7`-><@-><0%[/0%[/@)L70-F;@-?
M<0%[?@%\(0)N0`-?<@-@60%\<`)P70%\<@-A)@)P7`)P7@%\<0)Q1@1M9`)Q
M>P-F;P-B10,J?@%/90-%20%G7`1(-0)/)@-*3`)560%R>@%R>P-93P%/9@-`
M(0%O:@%Y2`%3<@,K(0-*3@%R?`-><P%\3@%3<P(Z,00[=P)!3@-`)`)!4`-`
M(@)!3P)(8P)(8`%G709:)`%G7@)(80)(8@-%2P)/*`)/+0%K9P)/)P)/*0)/
M,`)/*P)/+P)/+`)/*@)/+@%K:`-/8@)57`-/8P)56@%O;`-/9`%O:P)56P%O
M;0-34P);8@147P149P);80%R?0);8`)@20-6>@)@2P)@30)@3`-6>P%V)@)@
M2@)D2P%W:`)D20)D3`%W:01>0P)D1P-94`)D2@)D2`)D10%W:@)D1@1A?`-;
M7P-;70)G;`-;7@-;8`)G;@)G;0-=4`)J6`-=40)J601G<0->=0->=`)L7@-?
M<P%\(P1I7@%\(@)O70)O7@%\<P)P7P-A*`%]-@-B.P%3=`%B>0)/,@)/,0)5
M7@)5701.5P-350%V)P)@3P)@3@)D3P)D30)D4`)D3@-9401E*0%Y20)G;P)G
M<`)G<01E)P)L7P->=@)N00-A*0)P8`%3=0-%3P-/90);8P)@4`-;80%3=@1!
M8P-%4`%K:01(1@);9`%W:P)D40%Y2@-=4P)J6@)J6P%[0`)O7P%3=P%>(0%>
M(@(Z,@%B>@%B>P)!40%B?`1!:`%G8@-%4@%G9`)(90)(9@)(9`%G7P%G8`%G
M8P%G80-*5`-*50)/,P%K:@%K:P-*4@-*5@)590%O<`)58`)57P-/:0)59`%O
M;@-/9P1.6@%S)@14<`)580)59@)58P)58@-/9@%O;P%S)`-37`);9@%R?@-3
M60);9P-36@-2*`);90-36`%S(P%S(0%S)0-370%S(@-36P-37P1>3P-96P-7
M)@)@4019<`)@5@)@4@)@50%V*`-7*`)>00)@5`)@4P-960%W;@%W;`%W;P%W
M;0)D4@)D4P)D5`%W<`-95@-96`-;90)G=0%Y3`)G<P1B,`%Y30)G<@)G=`%Y
M2P)J7P)J7`1E+`)J70)J7@)L8`%[0@->>`%[00->=P)N0P)N0@%\)`-@70-@
M7@-@7`%\3P%\=`%]+0)Q1P)Q?`)Q?0%3>`)!4@1!<0)(9P)/-`)/-0%K;`1(
M5P%K;0)59P%O<0-380%V*0-7*@)D50-97`%W<0)G>`%Y3@)G=P)G>0)G=@)L
M8P)J8`)J80-=5@%Z40)L8@->>P->>0)L80->>@)N1`)Q?@-B)0%3>0->?`-B
M)@%3>@,Y9P%8:@(S2P-F<`(Z,P,Y:`%B?0%C(@%B?@)!4P-%6P%C)`%C(0-`
M*P-%7`%C(P-%5`%G9@-%60)(:`-%5P-*70)(:0)5:01!>P%G90%G9P%G:`-%
M6`)/-P-*7@)/-@%K;@5+3`%K;P-*6P)/.`)5:`%K<0%O<@1.8P%K<`-F>@%S
M)P)5:@%O=`%O<P)5:P)5;@)5;`)5;0%O=0-/:P%S+`%S*@-390-39@%S*0);
M:0-39`%S*P-38@-38P);:`)@5P14?@);:@%S*`);:P)@6@)@6`)@60)@7@%W
M=0)@70)@8`)@7P)@7`)@6P15(0%V*@-98@1:*0-980-99@)D6`-990)D5P%W
M=`%W<@%W<P-98P)D5@-F<0)G?`-;:0%Y3P1B.`)G>P)G>@%Y4`1E.@)J9@)J
M90-=6`)J8P->?@)J8@%Z4P%Z4@)J9P)N10%\)0)L90%[0P)L9`)J9`-?>`)N
M1@%\4`-A*@%]+@)Q2`1N)`)R(0%3>P(Z-`)@80%3?`-%7P5+3@)/.@)/.0);
M;`5:)@-3:`)@8P-7,`)@8@-99P%W=@)G?0)G?@%Z5`-?(0-@8`)R(@%8:P%C
M)@%C)0)(:@)(;`%G:@)(:P%G:0%G:P)(;0-*8P-*8@-*9@)//`)//@)//0-*
M80)/0`-*8`-*;`-*9`%K<@)//P)/.P-*:@1(8`)/00-/<P)5=0-/;0)5>`)5
M>@)5<`)5=`)5<0%O=P%O>@%O?`)5<@)5<P%O>P)5=@)5>0)5=P%O?0-/;@%O
M>0)5;P%O=@-/<@%O>`-/=`-3<`%S+@);<@);<`);;P-3<0);=0-3:P);=`);
M<P-3;`);;@%S+0);;0-3:@);<0%S+P-7-`)@9@-7-P)@:@)@9P)@:0)@:`)@
M90)@:P)@;@)@;`)@;0%V+`-7,P%V*P)@9`)@;P)D70)D8`)D8@)D80-9:@)D
M6P)D7P)D6@-9:P)D7`%W=P)D60-9;0)D7@)H+0)H(@%Y40-;;P-;;0%Y4@)H
M(0)H)@)H+`)H)`)H*P-;;`)H*`-;;@)H)P)H*@)H)0)H(P-;:P)H*0)J;@)J
M;`%Z50)J:P)J<0)J;P-=6@%Z5@)J:@)J:`1E1@)J:0%Z6`)J;0%Z5P)J<`)L
M9@)L;`-?)`-?(@)L9P%[1P)L;0%[1@)L:P)L:@%[10)L:0%[1`)L:`=640)N
M3`)N3@)N301I:@)N2@%\)P)N1P)N2P)N4`-?>0)N3P)N2`)N20%\)@)O8`%\
M4P-@8@)O80%\40%\4@-@801L/0)P80%\=0)Q90-A<@%]-P-A<P)R(P%].`)R
M)`)R)0)R,P)R,@%]1P)R.P%8;`-`+P1"(0)(;P1!?0)(;@1!?@%K<P%K=`)/
M0@1.=`)5>P);>`-/=P-/=@%O?@%S,`);=@15,0);>0%S,0-7.@)@<`);=P)D
M8P%W>`)H+@1B20-=80)J=`)J<@-=8`-=7@)J<P)L;@-?)0%[2`)N40%\5@%\
M*`%\5`%\50)P8@%]+P-A=`%8;00V+0-*;@1.>0)D9`-?>P-@8P(S3`-`,@%G
M;`-%80)/0P-*;P-*<P%K=0)/1`-*<0-*<`-*<@)5?0)5?`%S,P%P(0%P(@1/
M(0)6(@)6(0)5?@-/>0-3=0);>@);?0-3=`);?`);>P%S,@)@=`)@<@)@<01:
M-P-7.P)@<P-7/`%W>0)D9@)D9P%W>@-9;P)D90-;<0)H,`)H+P)H,@%Y4P)H
M,01B3P)J=0)J=P)J=@-?)P)L;P)L<@)L<`)L<0)N4@%\*01I=`1I<0-F<@)O
M8@)O8P)O9`-A+`%\=@%],`)R)@%8;@-*=0%P(P%S-`)D:`-=8@)N4P-A+@1M
M-P)Q9@(S30-B*`%]2`%8;P);?@-7/@)D:0)H,P-=8P1H-@)L<P)N5`%8<`-%
M8@)/10)/1@-*>`%K=@%K=P)6)`%P)0%P)`)6(P)@=0-7/P)D:@)D;`)D:P%W
M?0%W?`%W>P-=9`%[2@)L=`-?*`%[20)N5@)N50-A+P%\=P)P8P%>(P)(<`1"
M*0-%8P)/20)/1P)/2`1(:P-/?@)6+01/,`)6*`)6)0)6+`-/?`1/-0-/>P)6
M+@1/-P1/+`%P)P)6*P)6)P-/?01/*@)6)@)6*@)6*0%P)@]3/@)<*P)<)@)<
M)`)<+0)<)0151P)<(0150P)<)P-3>`-3>@)<(@)@?@)<(P)<+@-4(P1510-3
M?`-4(05:2@-4)0-3?0)<*@%S-0)<*0)<*`-3>0)<+`]9.`-F<P-71`)@=@)@
M>01:20-710)@>`-70`)A(@)@>P)A(0-70@)@?0)@?`)@>@1:00)@=P1:/P%V
M+P%V+@1:1`%V,`%V+0)A(P1:10]==@1:0P)D<@)D=01?)@)D<P)D=P5F>0-9
M=`1?(@)D>`1?*@)D<`%X)`)D<0-9<P)D;P)D=@-;=`)D;@)D;0%X(P%X(0%W
M?@-9=@-9=0-70P]A<@-9<0)D=`)H/`)H0@%Y5@)H/05K,P)H0`)H1`%Y5P)H
M/P1B7`)H-P-;=0)H-@)H0P)H.@-;=P)H.`)H00)H.0%Y50%Y5`-;>0)H-`)H
M-0)H/@1B9@-;>@1B:`)H.P]D:P1B50-=;P)J>@)J?0-=<01B5@-=9P-=:0%X
M(@-=:@-==`-==01E6@-=;@1E60-=:`)J>P)K(P)K(0)J>0)K)@-=9@)J>`-=
M=@%Z6@)K(@1E5`-=<P1E5P)J?`%Z60)K)0-=<@1E70)K)`-=<`)L=P)L=@5R
M40-?+`5R2P)L?05R3@)L>0)L?`%[3`1H.P1H/@)L>@)L>P1H.0)L=0)L>`%[
M2P-?*@]I*@%\*P)N80)N7`)N8`-@)0)N8P)N7P-??@)N6P-@(P%\+0)N7@)N
M8@%\+`)N60)J?@)N701J(P5U+0)N6@-@(@)N5P]J/@)N6`%\*@)O:`)O:@)O
M;0)O:0)O;@-@90)O9P-@9@)O90-@:`%\5P)O:P%\60%\6`)O9@)O;`-A,@)P
M:`%\>`)P:0-A,P)P9P)P9`1L2@-A-`)P9@)P90)Q20-A60)Q2P)Q2@-A6P)Q
M:05Z4P)Q:`)Q9P)Q:@-A=0%]0`%]00)R.`)R/`-B00%>)`)!5`)(<P-%9`%G
M;0)(<0-%9@,O0@)(<@-%:`-%9P)/2@)/2P%K>@%K>`)/3`%K>0)6,P-0)P)6
M-@)6,`)6-P)6+P)6,0-0*@)6,@)6-0-0)`-0*P%P*@)6.@)6.0%P*`)6-`)6
M.`%P*0-4+01/0@-0)0-0(@-4*@)<.`154@%S.@-4+`)<,P%S-@-4-@)<,`)<
M-@)<.0-4,P%S.P1:3@)<-0)<,@)<.@)<,0-4-P)<-P%S-P-4*0)<+P%S.`-4
M-0%S.0)<-`-4,@)A-0)A*`)A*0)A+`)A*@1:50)A)`1:5@-730)A)P)A,0)A
M*P-72`1:3P%V,01:30)A,P)A,`%V,@)A,@)A)0)A+@)A+P-72@)A+0]>)`-F
M=0)D?`)D?@)E(P-9>0-9>P)D>P-9?0%X)0)E)0)D>@)E)@-9?@)E(@)E)`)E
M*`)E(0)E*0)D?0)D>0%X)@-:(@)E)P%X)P%Y601?-`-9>@]A=P-;?0)A)@)H
M7@)H50%Y6P)H40%Y7`-<)P-<(@)H6@)H5`)H2@%Y6@)H5P)H4@)H4P-<)0)H
M10)H3`)H6P-;?@)H6`5K/P)H4`-<)@)H7`)H2P)H1@)H60-<)`)H2`)H5@)H
M30)H70)H20%Y6`)H1P)H3@)H3P)K+0-<(P)K*P1E:0)K,`-=>0)K/`)K,P)K
M+`)K*`)K-0)K+@)K,0)K*@)K.`)K)P)K+P)K-`)K-@)K.0)K*0-=>@)K/0)K
M/@)K-P)K.P)K,@)M+P)M,@-?-0%[30-?,0)M,0)M-@)M-`%[3@)M*P)M(0)L
M?@%[4`)M+0)M+@)M*@)M(@-?,@)M)P)K.@1H0P)M(P%[3P)M*0-?-@)M*`)M
M)`)M,`1H1`)M)0)N:`)M,P)M-0)M+`)M)@)N:0)N:P)N90%\+@1J)0)N<@)N
M<`%\+P)N;P)N;@)N9P)N9`)N:@)N<P)N9@)N;`5U10)O=P)O?`)O<@)O=0%\
M6@)O>01K1@)P(@)N;01K2@)O<P)O?0)P(P)O>`)O<0)O>P1K2P)O>@)P(0)O
M?@)N<0)O=@)O<`)O=`%\>0%\>@)O;P-@;`)P=`)P:P)P<P)P<`)P<0)P:@)P
M;0)P=0)P;P)P;@)P;`-A-0)P<@1L5@)Q3`1M.@)Q30-A70)Q3P)Q3@)Q40)Q
M4`)Q;`)Q:P)R)P-B*0)R*`-B,`)R-`%]10%]20-B.`)R/0%]2@%>)01/2`5:
M6P%Z6P)M-P-?-P%\>P%\?`%>)@)(=`-%:0%G;@)6.P-0+`-4.0)</`)</0)<
M.P)A-P)A-@%V,P)E*P)A.`)E*@1?.@-:)`)H8`%Y70%Y7P)H7P-<*01B=0%Y
M7@->(0)K/P)K00)K0`)M.`%[40-?.@%\6P)P=@)Q4@-B,0-B/P)R00%>)P,E
M1P)/301/3`%P*P-0+P-0+@-4.@)</P)</@-74`)A.0-:)@-:)01B?@%Y8`%Z
M7`)N=`)R.0%>*`%K>P-+(@%P+`]A?`)H80->(@)P)`%C)P,Y:@-4/`-4.P1:
M70)A.@-:*`1?/@%],0%C*`%P+0%V-`)P)0%C*0,Y:P)6/`%S/0)<0`)<00-4
M/0%S/`158`)A.P%V.`%V-@%V-P%V-0)E+`%X*`1C)`-<*@)K0P)K0@)K10)K
M1`%Z70)M.01H5@)M.P)M.@%[4@)N=0-@*0)P)@)P)P%\7`)Q4P)Q;0%]0@1N
M0P)!50)<0@)A/`)H8@)(=0,G<@)A/0)E+@)E+0-:*0-<+0-<+@-?/`)P*`%\
M?0-A7P)Q5`)Q;@%G;P)6/0)6/@1/5@)<0P%G<`-%:@%X*0)E+P-<,`)M/0%[
M4P)M/@)M/`)P*0-A8`)P=P1M2`%G<0)A0`)A/P)A/@)E,`-:*P-:*@)E-`)E
M,P)E,@)E,0%X*@)H8P)K1P%Z7@)K1@)M/P)N>`)N=P%\,`)N=@)P+`)P*P)P
M*@-@;01N1`%K?`158P)<1`%V.01:9`)H9`)H90)N>0)P+01K7`-A.P)P>`)Q
M50)R*0)R0P%K?0%V.@)E-0)H9@)M0`)P+@,C<`%P+P-4/@)A00)E-@)H9P)H
M:`)H:0)K3`->)`)K2`%[5`)K2P)K2@%Z7P)K20%Z80%Z8`)M0@)M00%[50%[
M5@1H8`-?/@%\,@)N>@%\,01K80)P,0)P,@)P,`)P+P%](01L9`)P>0)P>@)P
M>P%\?@)Q5@)Q60)Q6`)Q5P-B,P1N10)R0@%S/@-7501C+0%X,@)K30)M0P-@
M*P%\,P)N>P1N50-B0@)R1`\A60%S/P->1P1N,P)A0@-?/P)N?`-A80)Q;P-A
M=P]83`$A*P$A-@$A.`$A0`$A00$A1`$A10$A2`$A20$A3`$A30$A4`$A40$A
M5`$A50$A6`$A60$A7`$A70$B)P$B*`$B*P$B+`$B*0$B*@$A+@$A+P$A,`$A
M,@$A,P$A-`$A-0$A7@$A7P$A8`$A80$A8@$A8P$B+0$B+@$B+P$B/P$B0`$B
M00$B0P$B0@$B8@$B;`$B;0$B;@$A*@$A;`$B8P$B:`$A;0$A/@$A/P$A;@$B
M,`$A(@$B,0$A)0$B7P$D(0$D(@$D(P$D)`$D)0$D)@$D)P$D*`$D*0$D*@$A
M*`$A)P$B-@$B.`$B-P$A*0$B:0$D00$D0@$D0P$D1`$D10$D1@$D1P$D2`$D
M20$D2@$D2P$D3`$D30$D3@$D3P$D4`$D40$D4@$D4P$D5`$D50$D5@$D5P$D
M6`$D60$D6@$B8`$B)0$D6P$D7`$D70$D7@$D7P$D8`$D80$D8@$D8P$D9`$D
M90$D9@$D9P$D:`$D:0$D:@$D:P$D;`$D;0$D;@$D;P$D<`$D<0$D<@$D<P$D
M=`$A0@$B7@$A0P$B9@$B9P$B9`4A)0\A(08A+P8A+08A+@8A0@8A0P4A,P,A
M1`\A/@\A/P8B*P4A308C0`8C/@8C/P8D9P8E7P4C+P\B=`8E9P8E8P8I-P8I
M.@8I.`\I(@\I(P8N9@4P<@4S(P\Y,@\Y,P9'+0\[<P]`-0]`=0]'0@]-5@<A
M(0]91P1/?`]:/P8A+`8A(@8B7P0A5@8C008E8`8I.P4E(04G>@8N2@\I4`8U
M)08U)@9%?09&/P]&0`5$?@8A,@4A+08B+08C0@\M80904`]31`0A(04A)@8A
M)`\A(@8A,P8A1`\A)0\A)@4A3@8B,`\A108B3@8B+P\A0`\A008A108B,08B
M+@0B)@0B)04B)`4B)08C0P8I/@8D708E5@8E808E8@8L0P8I/`8Z90\I)08M
M+08I/08N2P4K9P8U*@8U)P8Y9`8U*08\>P9%?@9&0`9&004]5@4A(P4A(@8A
M)@8A)04A(04A*P\A(P8A1@4A-`\A)P\A*`8B,P8B,@8B*@4A3P8C1@8C1`\A
M;@8C10\B=08I/P8M+`0F)`8N308N3@\E0`8N3`8U*P\M8`8\?@4P<P8\?0\Y
M-`90405$50]&009:8P9:8@<V<P=&)P=-.@4A)`4A)P0A*`4A*`4A+`8A1P8A
M2`8A208C1P4C,`8E9`8I0`4P=`9&0@<L/`8A)P8A*`8A*08A2@8E908C2`8C
M208E:`\B=@0E,P4E(@0E,@8N4`4G>P\I)P8P?`8U+08U+`\M8@8](0]-;@8C
M2@\A;P\A<`\B*P4C,0\B=P\B>`\B>04E(P8I00\E0P8N4@8N40\I*`8U+P4L
M9@0K7P8U,`\M8P8U,09&0P8](P8](@0P1`4P=0\R=`\R=0\R<@9&109&1`9&
M1@0V+P\Y-0\Y-@\Y-P9,+0]`-@]`-P]`.`]&0@904@5+<0<A(@]-5P]-6`]-
M60<F>0<A)`<A(P<A1@<L/P534P<L/@<L/0=&(P=&*`8A-`8A-0\A)`8A3`\A
M*08A2P,A;P\A0P8B-08B-`8B-@0A6`0B+`0B*P0B*08C3P0B,`8C4`4B)P8C
M308C3`0B+P8C2P\A<P\A=`\A=0\A=@\A=P\A>`\A>04B*`8C404B)@\A>@4C
M,@8E:@0C.@8E:P8E=`8E<`8E;`\B>@\B>P\B?`\B?0\C(0\C(@\C(P\C)0\C
M*`\C*0\C*@\C*P\C+`0C.`8E;08E;P\C)@8E;@8E:04C,P8E<P8I0P8I100E
M.@4E*`8I1@4E*0,G3@4E*@0E-P0E-08I2@8I1`8I3`8I1P8I3@4E)@8I0@\E
M10\E1@\E2`\E20\E2P\E3`\E30\E3@\E3P\E4`\E408I308I2`8I208I2P4E
M)`4E)P4G?`8N9`8N604K<@0H-@8N8P8N5P8N5@4H(P0H.P8N704G?@4G?04H
M(@8N8@8N508N5`8N908N7`\I*0\I*@\I*P\I+`\I+@\I+P\I,0\I,@\I,P\I
M-`\I-0\I-@\I-P\I.`8N4P8N6`8N6P8N7@8N8`\E1P8N7P4H)`0K8P4K<`0K
M9P8U-@4K:P8U-04K=`0K9@0K:`4K;P8U,@4K:0\M9`\M;@8U-P4K;@\M9@\M
M9P\M:@\M:P\M;`\M;0\M;P\M<0\M<@\M<P\M=`\M=0\M=@\M>`\M>0\M>@\M
M>P\M?`8U(08U.@8U.P8U,P8U-`4K:`8U.0\M=P\M<`4K:@4K;04K=04K<04K
M<P0K8`8]*P8]+08]+`0P200P2`8],`8]*`4Q(08],P4P=P8]+@8])P4Q(@4P
M=@0P1@8]*@8],08]-P8],@8]*00P2P8]-`\M:0\R=P\R>`\R>0\R>@\R>P\R
M?`\R?@\S(0\S(P\S)`\S)0\S)@\S)P9&-P8].`8^908].08]+P4P>@9#8P4P
M?04Q(P8])`8])@\R?04P>04P?@4P>`8])08]-@4P?`9&209&3P4V5@4V409&
M3`4V3@4V4@4V8P4V4P9&2`4V504V4`9&5@0V-04V5`9&4@9&4`9&2P9&3@9&
M4P\R=@9&6`4V3P4V5P9&1P\Y.`\Y.0\Y.@\Y.P\Y/`\Y/0\Y/@\Y/P9&300V
M.P9&409&5`4V309&2@4T(0906@1".`4]6@4]6`904P4P>P4]7@4]7`906`4]
M6P907P90700\+@907`908@90500\+P4]8`905`4]5P905P907@]`.0]`.@]`
M.P]`/`]`/0]`/@]`/P]`0`]`00]`0@]`0P]`1`]`10]`1@9080963@906090
M5@9&5P4]604]704]7P0\*P908`9:<04]80<A+@1"-`5$5@9:9`9::04]8@9:
M:P1".09:=`1",09:=09::`9:9P9:=@]&0P]&1`]&10]&1@]&1P]&20]&2@]&
M2P]&3`]&30]&3@]&3P]&40]&4@]&4P]&5`]&5@]&5P]&6`]310<F+05$6`9:
M=P9>5P9:;09:;P9:90]&4`]&2`]&501",`9:9@9::@9:;@9:<`1"-@4_1@1(
M?@1(>@9:;`<A+P<A,0<A*0<A)@<A)05+=P1(?`<A*P<A+`5+<P<A*@5+>05+
M>`<A)P]-6@]-6P]-7`]-70]-7@]-8`]-80<A*`5+<@<A+0]-8@1)(05+=0<A
M,`5+=`5,10535`536@<L0`1/6`1/7P536`1/7`1/7@5350535@]31@]31P]3
M2`]320]32@536P535P<V>`5+=@5:;P5:<`159P159@<V=@]92`]92@]92P]9
M3`]93@<V=0<V=P]92015:`<V=`<^=@1::P1::01::@<^>`<^=P]>,`]>,0]>
M+`]>+@]>+P<^=05A,01:;`5A+P5A,`5A,@5G2@5G3@1C+@5G305G3P]A?@]B
M(0=';P5G3`5G2P5I?`=2=0=-/`]D>@5K:P=-.P=-:`1F+P1F+@5O:`=73@5K
M;`]G/P]G?@1F+0=730]I.`]I.@]I.05S,01J0`=;10]J2P]K005U8@1M4@]L
M208A300A7`0B,@8C4P8C5`8E=08E=P8E>`4C-08E=@8I408I4`8I3P8I4P\E
M4P8I4@\E4@8N9P8N:`4K=@\M?0\M?@\N(08U/`\S*`4Q)`4Q)0\S*0\S*@9&
M60\Y0`\Y00\Y0@4V6`\Y0P]`1P908P]`2`]&60]&6@5$60<A-`<A,@5+>P]-
M8P]-9`5+>@<A,P537`<L00]32P]33`]330]33@5:<0]93P]94`]940<^>05A
M,P]>,@=&*05G4`]D>P5G405K;0]G00]I.P]J3`5W4P]K0@8A-@4A-@4A-08B
M-P8C5@8C504C-@8E>04C.`4H)04H)@0K:@8U/0\N(@\N(P8].@9&6@909`4]
M8P0\,09:>`5:<@8A-P8A3@4A-P8A008A604A4`8C.P0B-08C5P8E?`8E?@4C
M.0\C+08E>@8I5`8N:P8N:04H)P8N:@8N3P8P>P8U0`8U/P8U008U/@8].P9&
M704]9`\Y1`\Y109&6P9&7`4]909090]`20]`2@1".@9:>0]41@]33P]34`5A
M-`]>,P=&*@=&*P0A+08A3P8A408B.00A708B.`4A4@\A1@8B.@4A408C6@8C
M6`8E1P8F(P8F(08F(@4C.@8H>@4E+`8I508I5@8N;`8U0@8U0P4K=P4K>`8]
M/09&7P,Y=P9&7@0\,P4]9@9:>P9:>@<A-05370<L0@]5=@1:;0]G0@=73P4A
M.`8B.P\A2`\A208C6P0B-P4B*0\A>P\C+@\C+P4E+0\E508N;08]/@\N)0\N
M)@\N)P\N*`\N*04Q)P9&8`\Y1P\Y2`9&80\Z70909@9:?`]&6P5.=P<L0P]9
M4@]340<^>@=&+`=-/P5O:05U8P\A2@8C7`\A?0\A?@0B.`4C.P8F)`0C/`\C
M,`\C,0\C,@\C,P\C)`\B?@0E000E0@8I6`8I604E+P\E5P4H*00H000H0@4H
M+`4H*`4H*@8N;P\I.@\I/`\I/0\I/@\I/P8N;@4K>@0K:P4K>04H*P8U104K
M>P\N*@\N*P8U1@4Q*`8]/P8]0`0P3@\S*P\S+`\S+0\S+P\S,`9&8@4V7`4V
M6@4V6P4V600V/@\S+@4];`4]9P4]:04]:@4]:`4]:P909P9:?05,(05$6@<A
M-P]&70]&7@5+?@5+?05+?`<A-@]-9P]34P<L10]-9@]34@15:@<L1@5:<P]9
M4P]95`5A-@5A-05A-P]>-`<^>P5G4@5G4P=2=@5S,@0A*08A4@\A*@\A*P\A
M+`\A+@8A7`\A+04A4P8B/00A7P8C7@8C708C7P8C8`\A2P8F)P8F)08F)@\C
M-`\C-00E1@8I6@0E1`8I6P8I7`8I70\E6`\E608N<@8N<`8N<08U1P\N+`8W
M)P8]0@8]0P8]00\S,0\S,@\S,P9&8P9&9@\Y209&9`\Y2@]&7P]&8`]&80]-
M:`<L1P]35`]350]30P]950]>-0]G0P0A+@4A.08A4P8A5`8B/P4A5`8B/@\A
M3`8C908C808C8@8C8P\B(04B*@8F*`\C-@8I8`8I7P8N<P8N=`8T>@8U2`8]
M1`8]104V709:?@]&8@<A<`<V>P5:=@5G5`=./@8A.00A0`8A504A.@4A.P8A
M5@0A00\A+P8A5P4A504A5@0A8@8B1`4A5P8B0P8B0`8B100B.@8C:@4B+@4B
M+`4B*P0B.P0B.08C:`8C9P4B+P8C:P8C:04B+00B/0\B(@\B(P0B/@8C9@0C
M008F*P0C0P4C/00C0@4C1@4C104C0P4C0`8F*04C/P4C0@4C008F*@8F+`4C
M/@4C1`8I:04E,P4E-00E200E2P,G7`8I9@0E308I9`8I908I;`8N=08I:@4E
M,`4E-@8I:P4E,@8I9P4E-`\E6@\E6P\E7`\E708I:`8I8@8I804E,08I5P0H
M1P4H+00H108O)`8N>P8O(@0H2`8O(00H1`0H1@8N>`8N?@8O(P8N>@8N?08N
M?`\I0`\I00\I0@8N>04H+@8N=P8U200K<`0K;04L)04L(P0K;P0K<P8U3@8U
M4@4L(@8U4P0K;`4L)@8U400K<08U4`8U3P8U3`8U2P0K<@4L)`8U30\N,P8U
M5`\N+@\N+P\N,`\N,@\N,08U2@4L)P4K?04L(04K?@0P4`4Q*P0P404Q*@8]
M1@0P5@0V200P508]208]1P4V7@0P3P4L*`\S-`\S-0\S-P8]2`8]2@8]2P0V
M0P4V7P9&;09&:00V1@0V1P4V8`4V9`0V2@0V1`0V000V0`9&:P9&:`9&;`4V
M804V8@9&:@\Y2P\Y3`\Y30\Y3@0V2`9,1@9&;@4V900\.090;P4]<P90;00\
M-04]=`90;@4];00\-P0\-@4];@0\.@4];P90:P]`2P90:@90:`90<`90:04]
M<@4]<0]`3`5$6P1".P9;)`5$809;(@9;(00\.`1"0`5$8@5$7`5$7P1"/01"
M1`9;*P9;*09;*`5$7@5,(@9;)@5$709;*@5$8`9;)0]&8P]&9`]&909;(P9;
M)P5,(P5,)P1))`5,)`5,)@<A/`<A/0<A.@<A/@<A.P5,)0<A.`<B6@<A.01/
M8`<L205:=P<L2@<L3@<L30<L3`537P5380538`537@<L2`<L2P<A/P]35@58
M405:>@15:P5:>05:>`<V?`]95@15;@<^?`5A.`5A.0<V?0]>-@5A.@=&+P=&
M+@=&+0=-0`=-005O:@=2=P]G1`5U9`1K90=B+0=B+`8A.@4A/`8A6`0A8P4A
M604A6`4B,04B,@\B)0\B)@\B)P\B*`4B,P8F+@0C104C1P\C.`\C.@\C.P8F
M+00C204E/04E.08I;04E/`8I;@\E8`\E80\E8@\E8P4H,`0H2@8O)@4H,04H
M+P8O*`\I0P\I1`\I108U508U600K=`4L+04L*04L*P4L+`4L*@\N-`\N-08U
M5@8U5P4Q+08]3@8]3`8]3P8]4`8]40\S.`\S.08]304V:04V9@4V:`4V:P4V
M9P\Y3P\Y4`9&;P9&<`9&<04]=@4]=00\.P90<@90<0]`304]=P1"1@5$9@5$
M9`5$905$:01"105$:`9;+@]&9@9;+`9;+05,*P5,*`1))@5,*05,*@<L3P5:
M?`]35P5:>P5:?0<V?@<W(@<W(05A/`<^?@<_(05G5@5G50=-0@5O:P=;1@5U
M901L:P=F.P4A/08B1P8B2`4B-04B-`4B-@\B*@8F+P4C2`4C200E4@8I<08I
M<`\E9`\E908O*@0H3`8O*P8O+`\I1@8O*00K=@8U7`8U6P8U7@8U7P8U6@8U
M704L+P0P708]4@4L+@4Q+@4Q+P8]4P0V3@\Y4090<P0P6P4]>0]`3@]`3P9;
M+P1"1P5$:@5$:P]&9P]-:01/90<L4`<L40<W(P<W)`5:?@=-0P8A*@0A0@8B
M2@8F,`8F,P4C2@8F,08F,@0H308O+P8O,08O+08O+@8O,`8]5`8U8`\N-@\N
M-P8U)`9&<@\Y4@0\/0]&:`<_(@5M,@8A*P\A,04B-P8C;@0B0P8C;08F-`0C
M2@8F-0\C/`8I<P4E/@4E/P0H3P8O-`4H,P8O,P4H,@8O,@8O-P8O-0\I1P4L
M,`8U8@8U804L,08]50\S.@0V3P90=09&<P8U8P4]>@1"2`9;,09;,`5,+`5,
M+05,+@]-:@539`<W)0]>-P1?2P<_(P=-1`=@:0=D0P\A,@4B.`8C;P4C3`8F
M-P\C/0\E9@8O-@4H-`8U9`]&:0=-10=74`8A6@4A6@4A6P8B2P8C<`0B1`0B
M108C<P8C<@4B.@4B.08C=`8F.04C308F.@8C=08F.P\C/@4E0`8I=`8I=P8I
M>`8I=@\E9P\E:0\E:@\E:P\E:`8I=08U908U9@\N.`\N.00P8P0P800P8@\S
M.P\Y4P\Y5`90>`90=P90>090>P]`4`]&:@]&:P5,+P]-:P]-;`<A0`<W)@]>
M.`=&,`=2>`=@:@=B+@8B3`8C=P8C=@8C>`0C3`4C3P4C3@8F/`0E500E5`8I
M?`8I>P8I?08I>@8I?@8I>0\E;`8J(@0H4@0H404H-P\I2`\I20\I2@\I2P8O
M.08U:`0K>04L,@8U9P8U:@8\>@8U:08]5P8]5@8U:P8]6`9&=09&=@9&=P4W
M/P90?`5$;09;,@<A00]36`=C2P4A/@0A0P\A-`8A6P0B1@8J)`8C>@8C>00C
M3@8O.P4H.`8O.@0H4P8U;`8O/`9&>`4L,P4]>P90?05$;@<_)`4A/P4A7`8C
M>P8B3P8B308B4`4A700B1P4B.P8C?`8C?04B/P4B0`4B/04B/@\B+08F/@4C
M4`8F/04C408E7@\C/P8J)P8J)@8J*08J*`4E000E6`\E;0\E;@8J)04H.00H
M5`8O1@8O008O1`8O108O0`8O/@8O0@8O0P\I30\I3@0H508O/P8U<P8U=`0K
M>P4L-`0K?`8U;P8U;08U<`8U<@8U<08U;@4L-0\N.@\N.P8]8`8]6P0P9P8]
M7P8]7`8]70\S/04Q,`8]7@0P9@0V4@9&?`9&>@0V4P9&>P9&>09&?0\Y509&
M?@4]?`4]?091)`91(P90?@]`4091(00\/P1"209;-`9;-P9;,P9;.`5$;P]&
M;0]&;@9;-@9;.09;.P9;.@9;-0<A0P1)*`5,,`<A1`<A0@]-;0<E2`5390<L
M4P<L4@]360]36@<[30]>.0]>.@]>.P]D?`=.)P=2>05W5`=>4`=E,P=F,P4A
M+@8A/`8A/08A708B4@8B400B2@8D(P8D(0\B+@0B208D(@8F0`\C0`4C/`8J
M+`8J*P8J+08J+@8O1P8O2`0H5@\I3P8U=@8U=08V208U+@4V;`9'(@9')`9-
M8@\Y5@9'(P4^(091)04]?@]`4@9;/`]&;P9@<@<A10539@]95P=+:@8A8`4A
M0`8A7@4A0@8A8@8A7P8B500A:`4A7@8B5@4A7P8B4P8B5`8D)00B2P8D)`4B
M0@8D)@4B008D)P8F1`8F0@4C4@\C00\C0@\C0P\C1`0C4`8J,08J+P8J,@8J
M,`\E;P8O308O2@8O3`8O2P8O20\I40\I4@8R<@4H-@8U>P4L-@8U?`8U>08U
M=P8U>@\N/`\N/0\N/@\N/P8\9P8]9@8]:`4Q,@4Q,P8]908]8P8]:P8]9`4L
M-P8]8@8]:08]:@8\?`8]9P0V5`4V;09')P9')0\S/@\Y5P\Y6`\Y60\Y6@9'
M)@0\0P0\0@91)P91*`91)@0\009'*`916P91*09?(09;/@9;/05$<`93>P]-
M505,,P5,-`]&<`5,,@<L50]36P-0.054+@<L5`<W*0<W*`]96`1:;P=&,@=&
M,01F,0]G10=7405U9@=>40=>4@4A0P8A9`0A1P0A1@\A-@8A8P4A808B608B
M6`8B7@8B6@8B708B5P8B0@\A3@8B7`4B1P8D+04B108D+@0B304B1@0B4`8D
M+`0B3P0B3@4B1`8D*`\B+P\B,`\B,@\B-`8D*@\B,0\B,P4B0P8D*08D*P0C
M5@8F3P8F1@8F308F3`4C5@0C6@0C704C6P4C5`8F2`0C5P0C4@0C6`4C6`8F
M204C600C504C508F1P4C7`\C10\C1@\C1P\C2@\C2P\C3`\C2`8F2P8F2@8F
M4`8F104C4P4C5P4C6@0E7`0E7@8J-@4E3`4E1`0E6P8J-`4E304E104E1P0E
M804E4`8J,P4E4@4H1P8J.P4E2`4E2P4E2@4E404E204E3@8J/04E3P\E<`\E
M<@\E<P\E=`\E=0\E=@\E=P\E>`\E>0\E>@\E?0\E?@\F(0\F(@\F(P4E1@8J
M-04E0P8J.`8J-P\E?`8J.@4L.`4H1@4H4@4H304H/`4H408O5`8O3@4H/P0H
M6P0H6@4H3P4H104H2P4H2@4H3@4H2`4H204H/04H004H3`0E8@8O608O6@4H
M4P8O3P4H.@8O5P8O5@4H4`8O4`8O6`8O4@4H0`4H0@\K,P\I4P\I50\I5@\I
M5P\I6`\I60\I6@\I6P\I7@\I7P\I8`\I80\I8@\I8P\I9`\I9@\I9P4H0P4H
M1`0H70\I908O508O4P0H6`4H.P4H/@8O408V*00L)`0L*P0L+`0L)P8V(@4L
M3@4L004L/P4L3`4L/04L1@4L5@4L200L*@4L304L5`4L4@0L(@8V(P8V)`4L
M400L(P4L0`8V)P8V*`4L5P8V)@4L4P4L6`4L1P4L604L1`4L50\N0`\N00\N
M0P\N1`\N2`\N20\N2P\N3`\N30\N3@\N3P\N4`\N40\N4@\N4P\N5`8Y7@8V
M(04L0@4L104L2`8V)04L4`4L2P4L.04L.@4L.P\N104L2@4L3P4L/@4L/`4L
M6@4Q1@0P:08]=P8]=`0P>`8];P0P=04Q404Q204Q3`0P;@0P>04Q1`8]=@4Q
M-@4Q2@4Q104Q3@4Q-`4Q304Q0@4Q.P8]<08]=08]?08]>@8]?@4Q.@4Q/`8]
M;`4Q.`8]<@8]>P\S/P\S0`\S00\S0@\S1`\S10\S1@\S1P\S2`\S20\S3`\S
M304Q-P8]<P4Q.08];04Q004Q2`8^(04Q4@8]<`4Q0`4Q-04Q1P4Q/@4Q0P4Q
M/04Q4`8]>0,T8`4Q4P4Q3P8]>`8];@4Q/P4Q2P0V500V809',@4W)`9'-P9'
M/@4V=P9'-04V?`0V5@4W*`4V;P4V<00V6@4V>`0V5P4W*04V?@0V8@0V6P4W
M(P4W)P0V9@4W,`0V704W+`4W+@9'+@9'/`4^(@9'*P9'+P9'.`4W(@9'-`9'
M/P9'.@0V9`4W)@4V<P\Y6P\Y70\Y7@\Y80\Y8@\Y8P\Y9`\Y90\Y9@\Y9P\Y
M:`\Y:@\Y;0\Y;@\Y;P\Y<`4V=`4V=04V>P4W)04W(09'.P\Y:P\Y7`\Y7P\Y
M:0\Y;`4W*P4W+P9'/04W+04W*@4V?09'-@91.04^(P0\204^)P0\3@4V<@91
M000\2`0\1`9;0@4^+091,P91-04^*@4^.`91.@91,`4^+@4^)`4^-04^/P91
M/P91-P4^-`4^-P0\304^.@0\104^,P4^+`0\3P4^+P0\404^,04^,@91.P91
M0`91*@91/@91/04^.P91.`4^*`4^,`4^*P91+`911`91+@91*P91+0]')@4^
M/@91,0]`5@]`5P]`6`]`60]`6@]`6P]`7`]`70]`7@]`7P]`8`]`80]`8P91
M+P91-`91/`]`5`910@4^/`4^-@4^)04^*04^)@]`9`9;1@9;0`9;2P1"309;
M3P9;109;409;4`1"3@9;3`5$<P5$=P5$=05$?`9;0P9;1P1"3`1"5`5$>P1"
M4`5$=@9;005$<05$<@5$>09;4@9;/P9;209;2@5$>`9;30]&<0]&<@]&<P]&
M=`]&=@]&=P]&>`]&>0]&>@]&>P]&?`]&?@]'(0]'(@]'(P]')P]'*`]'*0]'
M*@]'*P]'+`]'+0]')`9;2`]&=05$=`5$>@9;3@5%(0]&?09;1`]')05,-05$
M?0]&;`<A405,.P<A50<A4@5,.0<A6`<A2@5,0`5,1@5,/0<A3P5,/@<A5P<A
M4`5,-@<A2P5,/P<A5@<A605,001)+P<A6P5,.@<A2`5,.`5;)P<A6@1)*P<A
M5`5%(P<A4P<A20<A1P<A8@<A7`]->@<A7@5,0@<A80<L805,-P1),@5,1P]-
M;P]-<`]-<0]-<@]-<P]-=`]-=0]-=@]->`]->05,1`<A7P<F*P<A70<A30<A
M3`5,/`5,0P<L:@1/;@53=`<L7`53<@<L:`1/<@53:@53>`<L8`1/:`1/<P1/
M9@53<01/<`53;P53:`<L:P<L6P<L9`53;@<L7P53;`539P53=053<`53<P<L
M6053:P53:0<L9P<L6`<L5P]-=P1/:01/=`53=P<L9@]37`]37@]37P]38`]3
M80]38@]38P]39`]390]39P]3:`]3:0]3:@]3:P]3;`]3;0]3;@]3;P<L7@<L
M70<L8@<L:053;0]5=`53=@15>@5;)@5;(0<W+0<W*@<W-`<W-05;(P5;*P15
M<015=@5;*`15=P<W*P5;*015>0<W,0<W+P<W+@5;)`15=0<W,@<W.0]960]9
M6@]97@]97P]98`]980]98@<W.`<W,`<W-@<W,P<W+`5;*@5;(@1:=`<_*0<_
M+P1:<P5A/@<_*P1:<01:=@5A1@1:=P5G6`5A/05A1`5A0P1:>`<_*@1:=01:
M>01:<@<_+@5A00<_)P<_+0<_*`<_)@<_+`5A0@]96P<_)0]>/`]>/0]>/@]>
M/P]>0`]>0P]>1`]>105A/P]>2@=&-`1?3@5;)0=&.P=&.0=&-P5G6@5G6P1?
M4`5G5P=&/`=&.@=&,P=&-0=&.`1?3P]>1@5G7`]B(@]B(P]B)`]B)0]B)@=&
M-@=';@=&/05K=`5K=05K;P5K<05K<`=-1P=-20=-2P=-2`=-1@=-2@]D?0]D
M?@]E(0=-3`5K<@=2>P5O<05O;P1F-05O;@=2>@5O;0=2?@5O<`=2?01F,P]G
M1P]G2`5O;`=2?`=760=76@5S,P=750=75@=75P=75`=74@=74P]I/`1H9`=7
M6`=;20=;2@]J30=;2`=;1P5W505W5@1K9@=>4P=>50=>5`=>5@]K0P5U9P5Y
M(P1L;0]L(@]L(P=@:P=B,@=B,0=B-`=B,`=B,P]L>0]L>@8A908A9@\A-P0A
M;@8D,@8D,`4B20\B-08D,08D+P4B2`8F5`8O7`8J/@8F6`8F5@\C3P\C408F
M5P8F608F7`8F6@8F408F508F4@8F4P8F6P4E508J0P8J0`8J008J0@8M-`8J
M/P\F)`4E5`4H5`4H5@8O8`8O7P4H508O6P8O7@8O704L7`8V+08V*@8V+`4L
M6P8V*P4L704Q5@8^)04Q5P8^)`8^(P8^(@4Q5`8^)@4W,P9'0`9'004W,04Q
M50\Y<@\Y<P\Y=`9'0@4W,@4^0`91104^00911P912`4^0@911@]`909;5`9;
M6`5%)`9;509;6@9;5@]'+@]'+P]',`9;5P<A90<A9@<A9`]->P1/=0]3<P<W
M/`<W.@<W.P1?40=-30=3(@=3(00A2`4A1`8B8`\A40\A4@8B808D-0\B-@\B
M-P8D-`8F:@0C8`8F9@8F8@8F7@8F:08F708F908F9P\C4P\C5`\C5@\C6`\C
M6@8F8`8F8P8F:`8F9`8F808F7P4C7@\C604C704C7P4C8`4C800E:@8J3P8J
M1P8J3`8J1@0E9P8J2@0E;`8J2`4E5@8J408F008J20\F)@\F)P\F*`\F*0\F
M*@\F,`\F,0\F+`\F*P0E:P\F+P\F+@8J4`8J2P8J308J3@\F,@\F)08J108J
M1`4E5P4H6P8O8@4H5P8O9`8O804H6`0H7P8O:P8O8P\I>@\I:`\I:0\I:P\I
M;`\I;0\I;@\I;P\I<`\I<@\I<P\I=0\I=@\I=P\I>`\I>0\I>P\I?`\I?08O
M:@8O;`8T,08O9P8O:`8O9@\I=`4H704H6@4H7@4H7`4H604L7@0L,@8V-`0L
M,`0L-`8V,@8V/`8V-@8V/08V/@8V,08V+@8V.@8V+P8V0`\N50\N5@\N5P\N
M6`\N60\N6@\N6P\N7@\N7P\N8`8V,`8V/P8V-P8V.`8V.04L8`8V.P\N70\N
M808V,P4L7P4L8@0P?08^)P0P?`4Q708^-`8^+04Q6P8^*@4L808^,P8^,`4Q
M6@0Q(@0Q(P\S3P\S6P8^+@8^+P\S3@\S4`\S40\S4@\S4P\S5`\S50\S5@\S
M6`\S60\S6@\S7@\S7P\S8`\S804Q7`8^,08^-00P?@8^*`8^*04Q6`4Q60,Z
M3P913@0V<@9'1P0V:@9'100V<`0V;`9'2P9'4`0V=09'1`9'1@9'304W-`8^
M,@9'3P0\6@4W.00V<P9/;04W.`\Y=@\Y>`\Y>0\Y>@\Y>P\Y?`\Z(0\Z(@\Z
M(P\Z)`\Z)0\Z)@9'409'2@9'200V=`9'3`\Y=04W-P4W.@9'2`4W-04W-@4W
M.P4^1@915@912P91504^300\5`9;8@914@4^3`91404^1`4^2P4^0P915`91
M4`4^204^2@0\504^1P9120913`\Y=P914P9130]`9@]`9P]`:`]`:@]`:P]`
M;`]`;0]`;@]`;P]`<`]`<0]`<@]`<P913P4^3@4^2`4^105%*05%*`5%)P9;
M7`1"7`9;9`9;9@9;805%*@9;8`5%)@9;9P]',@]',P]'-`]'-0]'-@]'-P]'
M.0]'.@]'.P]'/`9;70]'.`9;:P9;8P9;4P]',01"6@9;909;7@5%)05%*P<A
M<@1)-`1)-0<A;P1)-@5,2P5,3`<A:P<A>`1)-P<A=P<A=`].(05,305,3P<A
M9P<A=0]-?`]-?0].)@].)P].*`].*0].*@].*P].+0<A;`<A;0<A;@5,<0<A
M<P<A<0<A:0]-?@].)`].(P5,3@5,2@5,2`<A:`5,20<L;P<L<0<L;`1/=P1/
M>@1/>0<L;0<L<`].+`]3=`]3=@]3>`53>@<L<@53>P53>0<T;P<L<P<L;@]3
M=P1/=@<W0P15?0<W/05;+@<W/P<W1`<W0@<W105;+`<L=`]99`]990]99@]9
M9P]9:`]9:0]9:@]9:P<^;`<W0`<W0015?@5;+P<_-`5A1P<W/@5A20<_,P]>
M1P]>2`]>20]>2P]>30]>3@<_,0<_,@5;,`5A2`]B*`5A2@=&0@=&/P5G70=&
M1P=&00]>3`]B)P=&0P=&1@=*.P=&0`<_-01C,P]E(@]E(P]E)`]E)0=-3@5K
M=P=3*`1F-@=3)`=3(P=3)P=3)05O=`]G20]G2@]G3`=3)@]G2P5O<@5O<P=7
M6P]I/05S-`=7705S-0=;2P=77`=>5P5W5P5[7P=E6@=F0@=F3P8B8@8O;08F
M:P8J4@\I?@\J(04L9`8V0@8O;@8V00\N8@4L8P8^-@\S8@9'4@9160916`9;
M:@9D>@9;:`]'/09;:0<A>@<A>0<L=0<_-@=#/P]>3P<_-P=&2`=&20=(.P=7
M7@4A+P8B8P8D-P8D-@8F;`\C7`8V0P8^-P8^.`916@8D.08D.`4C9`4C8P0E
M;P8J4P\F-`\N8P4Q7@8^.08^/`4L908^.P8^.@4^3P917`]`=`9;;`]'/@9;
M;05,4`].+P]3>0<L=@<L=P<W1@=&2@<_.@<_.`<_.0=&2P=-3P8B9`8B908D
M.@8F;@8F;08J5`\E0@4H7P4L:`0L-04L9P8V1@8V10\N9`\N908V1P4L:00Q
M)`4Q808^/04Q7P4Q8`4Q8@\S8P9'5`4W/@4W0@4W0`4W00\Z)P4^4`91704^
M4@4^40917P1"809;;P9;<`9;;@5%+`5%+@<A>P5,40<_.P5;,05;,@=&3`8A
M9P8A:`\A.`8B9@\A4P\A5`4A=@8D/`0B5`8D/P8D0`8D/@8D/0\A:P0C8P0C
M9`0C9@\C70\C7@\C7P\C8`\C80\C8@\C8P8F<`8F;P0E=@4E6@0E=`8J508J
M5@0H8P8J7`8J6`8J60\F-@\F-P8J6@8J6P8J700E>08J5P8I.00H9`0H8@4H
M804H8@4H8`\J(P\J)`\J)0\J)@\J*`\J*0\J)P\J(@4L;`8V2`8V2P4L:@4L
M;0\N9P\N:`\N:08V2@0L-P4L:P4Q9`\N9@0L-@8^008^1`,T?@8^/@8^0P8^
M0`8^108^/P\S9`\S900Q)P4Q8P0\7@9'6`9'6P9'709'6@\Z*`9'509'7`4W
M0P9'600V>@0V>`4W1`9'5P918`91800\70]`=@4^4P4^5`4^509;<@1"8P5%
M+P1"8@]'/P]'0`]'009;<05%,`1).`<B(@<A?`<B(0<L?`<A?@5,4P].,0].
M,@<A?01"9`5,4@<L?053?`<L>`<L>016(0]3>@<L>@<W2`<W1P5;,P16+@1:
M>P]B*05K>`=3*0]I/@5U:`]K1`=>6`]L7P4A8@\A50\A5@8D000B6`8D0@\B
M.0\B.@\B.P\B/`0B5P4B2P8D0P4B2@8F=`0C:`0C:P\C9`\C9@\C:`\C:0\C
M:P\C;`\C;0\C;@\C;P\C908F<@8F<P8F=08F<0\C:@\C9P4C9@4C9P4C900E
M?`8J808J8`4E8`0E>@4E7@0E?04E6P4E7`0E?@\F.@\F.P\F/@\F/P\F0`\F
M00\F0@\F0P\F10\F1@\F1P\F2`\F208J7P8J7@\F1`\F/`\F/04E8@4E7P4E
M8P4E800H:`4H9`8O=@8O>`8O>00H900H:P4H9@0H9@4H8P8O<`8O>P8O=`4H
M:P8O?@\J+0\J+@\J+P\J,`\J,0\J,@\J,P\J-`8O<P8O=P0H;`8O=08O>@8O
M;P8O?04H:00H:@4H:@4H9P8O<08O?`4H904H:`8O<@,P4P4L<`8V3P4L<@4L
M=04L;P8V504L;@8V5@8V4`8V40\N;`\N;@\N<`\N<0\N<P\N=`\N=0\N=@\N
M=P\N>08V5`8V3@4L<08V4P8V4@\N;P\N<@4L=P4L=`4L<P4L=@4L>`8^3`8^
M4@8^1@8^1P4Q:@8^2`8^208^3P4Q:04Q;08^300Q*P8^3@4Q:P8^4P\S:`\S
M:0\S:@\S:P\S;`\S;0\S;@\S;P\S<0\S<@\S=`\S=0\S=@\S=P\S>`\S>0\S
M>@\S>P\S?`\S?0\S?@\T(0\T(@\T(P\S<`8^400Q*@8^2P8^2@4Q9@4Q9P4Q
M:`4Q900V>P9'8@0V?`4W6@9'7P0W(04W2`4W609'9`9'9@4W3P9'909'8`4W
M4`4W204W5P4W5`4W1P4W2P\Z*0\Z*P\Z+`\Z+0\Z+@\Z+P\Z,`\Z,@\Z,P\Z
M-`\Z-@\Z-P\Z.`\Z.0\Z.@\Z/@\Z/P\Z00\Z0@\Z0P\Z1`\Z10\Z.P4W5@9'
M8P4W6`9'7@\Z/0\Z0`\Z,0\Z*@4W104^5@4W4P4W3`4W4@4W404W2@4W304W
M509'9P\S9P4^7P4^6@4^704^5P0\904^60918P0\8@0\8`919P91909;?`4^
M7`4^6P919@]`>`]`>0]`>@]`?`]`?0]`?@]!(@]!(P918@919`]`=P91:`4^
M6`4^7@4^8`91:@]!(01"<`5%,@1":@9;>P1"<09;<P5%-`<B*01"<P9;=0]'
M2`1";P5%-P1";@]'1P]'20]'2@]'2P]'3`]'30]'3@]'3P]'4`]'40]'4@]'
M5`9;=`9;>`1"<@1"909;=@]'4P5%,P5%-@5%-0<B)@5%,09;=P5,6P5,601)
M.05,5@<B+P5,5P1)/P1).P<B+`1)/@<B)09;>0<B)`]..@<W40]'105,5`5,
M7`].,P].-`].-0].-@].-P]..`]..0]..P]./0]./@]./P].0`].00].0@].
M1`9;>@<B)P<B+@<B+0<B*`<B(P].10].0P]./`5,6@5,501)/0<B*@5,6`<B
M*P]4)054*`54(P<M)0<L?@54*054)@<M(01/?@<M*`54(@<M*P53?0<M*@<M
M+`]3>P]3?`]3?0]3?@]4(@]4(P]4)`]4)@]4)P]4*P]4+`53?@<M)@<M)P<M
M(P<M(@<M)`]4(0]4*`54)P54(054)0<M*0<W2P<W5`<W3P1/?0<W3016(P<W
M4P<W2@5;-@5;-`<W3`<W3@<W4`5;-016)0]9;`]9;0]9;@]9;P]9<`]9<0<W
M4@<W50<W205A2P1:?`<_/P5A3`5A30<_/@<_0`]>4`]>40]>4@]>5`<_/0<_
M00]>4P<_/`5G7P1?4P=&30=&4@=&4`]>50]B*@]B*P=&3@5G805G8`]?<P=-
M405K>0]E)@5K>@5K>P=3*@5O=@=3*P5O=0]G30]G3@=78@5S-@=780=78P=7
M7P]I/P=78`=79`]I0`5U:0=;3`=>6@=>6P]K10=>60=>7`]L)`5Y)`]L2@=C
M305Z900A,P8B:`4A8P8B:0\A6`\A5P8D108D1`8F=@8F=P4C:@0C;`\C<`4C
M:00H;P8P)`8J8P8J8@\F2@\F2P\F3`\F30\F3P8J9`\F3@8P(P8P(08P)@8P
M)0\J-0\J-@\J-P8P(@8V604L>08V6`\N>@\N>P4L>@\S9@\T)`\T)0\T)@\T
M)P4W7`9':04W6P9':@\Z1P9':`\Z1@0\9@0\:`91;04^8@]!)0]!)@91:P91
M;`4^800\:09;?0]'50]'5@5%.`1)001)0@].1@5,70<M+P<M+@<M,0<M,@54
M*@<M,`]4+0]4+@<W5@=-4@]B+`]B+05K?`]L8`8A:04A9`8D1@8D208D2@0B
M6@\B/0\B/@\B/P\B0`\B008D1P8F?@8F?00C;@8F>P8F?`\C<@4E904E9`8J
M9@4E9@8J9P8J:`\F40\F4@\F5`\F508J90\F4P4H;`8P*`8P*@4H;00H<00H
M<@0H<P8P*P8P)P8P*0\J.`\J.@\J.P\J/`8P+`8P+00L2@8V800L100L1`0L
M0P0L1P8V9`8V908V7P8V7@4L?04M(@8V6P8V8@\N?`\N?08V8`8V8P8V6@8V
M7`4M(04L?@0Q+04Q;P8^5P8^608^6`8^5@8^6P4Q<`\T*`\T*0\T*@\T*P\T
M+`\T+0\T+@\T+P0Q+P8^7`4Q;@8^504W7@0W)@4W809'<`9':P0W(P4W704W
M8`9';@0W)04W7P9';P9';`\Z2`\Z20\Z2@\Z2P\Z3`\Z30\Z3@\Z3P9';04W
M8@\];`91=`91<`0\:P0\<`4^8P91=P4^9`91<@91<091=@0\;091<P91;P91
M=0]!)P]!*`]!*0]!*@]!+`]!+0]!+@91;@9;?@9<)P5%/`5%.@9<)`9<+`1"
M=@9<+@9<*P9<)@5%.0<B,P]'5P]'6`]'60]'6@9<*`9<)09<*09<+09<(09<
M(P5%.P9<*@]'1`9B9P<B,`5,7@1)1P<B-P1)2`<B-0<B,@].1P].2`].20].
M2@].2P].3`].3@].3P<B.`<B-@].305,805,7P<B,05,8`<M-0<M-P54+`10
M(@54+054*P<M-@<M,P<M-`]4+P]4,`]4,0]4,P]4-`]4-0]4-@]4-P<W60<W
M5P5;.`]9<@]9<P]9=`]9=0<W6`<W6@<B-`5;-P=&6`5A3@]9=@]>5@]>5P<_
M0@]B+@1?5P=&4P=&501?5@=&5P=&5@]B+P=&5`1C-@=-4P=3+`1F.`=3+0]G
M3P]G4`=3+@5S.`1H9@=7905S-P=79@1J101K9P]K1@=@;`=D105Y)0]L)01M
M5`5Z)P1M<0=C3@=E-`8A:@8J:@8J:0\F5@\F5P4H;P8P+@\J/08P,08P+P0Q
M,09#9P8^7@8^700W)P8^7P91>@91>`91>09<,`1$)@]'6P9<,05%/0].40<B
M.@<B.0<M.0534@<M.`<W6P<W7`5A3P=&60=-5`=3+P8A:P\A.08D3`4B3`8G
M)`0C<@8G(P8G(@\C<P4E9P\F6`8J:P8P,@8P,`8P,P4H<`0L2P\O(08V:08^
M804Q<04W8P8^8P8^8`8^8@\T,`9'<0\Z4`9'<P9'<@4^90]!+P5%/@9<,P9<
M,@5,8@<B.P54+P<M.@]9=P5A4`5O=P0A2@\A.@4A90\A30\A6@8B:P8B:@4B
M30\B0P4C;`0C<P4E:`8G)04C:P4C;@4C;08P-`4E:08J;`4E:P\F608P-04E
M:@4H<08P-P8P.`4H<@8P.04M(P8V;`8V:@4M)`8V:P8V;0\O(@8^9@4Q<@0Q
M-`4Q=`9'=@9'=`9'=00W*@9'=P\Z4091>P91?091?`5()@1">@9<-`5%0`5%
M/P9<-05%00<M/0<B/@<B/0<B/`<M.P54,`<M/`<M/@]4.`<W701F.01H9P5Y
M)@8A/@0A=00A=`8B;`8D300B7@4B3@8D3@8D4`8D408D3P\B1`8G*0\C=`8G
M)P8G)@8G*`4C;P0F+`0F*P8J;08J;@4E;`8J;P\F6P4E;00H=P8P.@8P/P0H
M>@0H=@4H=08P/@8P/08P/`8P.P\J0`\J00\J0@\J0P\J1`\J/P8P0`4H=`8V
M<@0L4`8V;P0L3P8^9P8V<`8V;@\O(P\O)`\O)@\O)P\O*`4M)@4M)P8V<08V
M<P4M)08V=`8^;08^:04Q>`4Q>@4Q=P4Q>04Q=@4Q>P8^<`8^:@\T,0\T,@\T
M-0\T-@\T-P\T.`\T.0\T.@8^:`8^;`8^;P8^;@\T,P9((P9()`9((@0W+`9'
M?@9'>@4W9`0W+04W909'>09'>`9()09((09()@9'?`\Z4@\Z4P\Z5`9'?00W
M+@92(P4^:04^9P92)@4^:`92)092*092(091?@92)P92)`]!,`]!,0]!,@92
M(@92*`4^9@1"?`1"?@1">P9<.`9<-@9<-P]'709<.05%0@<B0`5,9@].4@].
M4P].5`].50].5@5,905,9`<M0`<M/P<B/P]4.0<P+0<W7@<_0P1?6`5G8@]E
M)P]E*`5K?0]G405S.@4A,`8A;`8B;08D5`8D4P8D4@4B3P0C=08G*@0F+08J
M<08J<`4H=P8P0@8P0P4H=@8P1`8V=P8V>`8V=@8U*`8V=08^<08^<@9(*`4W
M9P9(*09()P\Z5092*@9<.@<B00<M00<B0@<B0P=3,`=>704A104A1@8B<`8B
M;@8B<@8B<0\A7`\A70\A7@8B<P4A9@8B;P8D5P8D508D60,C60\B10\B1@8D
M5@4B4P8D6@8D6`4B4@8G+@4C<04C>`4C>08G,`4C=@4C=04C=P4C<@4C<P8G
M,08G+`8G,@\C=@\C=P\C>0\C>@\C>P\C?@\D(08G+08G+P0C?0\C?08G-`8G
M,P0C?`8G*P4C>@0F,`4E=08J=00F,P8J<@4E<P4E=`8J>@4E<08J=P8J?`4E
M;P8J>04E<@4E<`8J=`8G-0\F7`\F70\F7@\F7P\F8`\F80\F8P\F9`\F90\F
M9@\F9P\F:`8J>`8M*P8J<P4E=@8P4`8P2@4H>`8P2P4H>00H?@4H>@8P1@8P
M208P4@\J10\J1P\J2`\J2P\J3`\J30\J3@\J3P\J4`\J408P308P108P1P8P
M408P3P8P3`\J2@\J1@8P2`4H>P0H?`4M+`4M*00L4@0L604M*@8W(00L6`4M
M-`4M,`4M*P8V?04M,04M+04M+P8W)`8V?@0L8@8V>00L8P0L5@8W)08W(@8W
M(P8V>P\O*0\O*@\O*P\O+`\O+0\O+@\O+P\O,0\O,P4M*`\O,`\O,@4M,P0L
M704M-04M-@4M,@8[3@0Q.@8_*P8_)`8_)@0Q/`0Q/@4Q?@8^>08_(@8^>P4R
M*`0Q.`8_)P8_+`8_*08^=`8_*@0Q0`0Q.P4Q?`4R)@8^<P0Q-@4Q?04R)`8_
M*`8_(P\T.P\T/`\T/0\T/@\T0`\T00\T0@\T0P\T1`\T1@\T1P\T2`8^=P8R
M*@8^?08^?`8^?@8_(08_)00Q/P4R*04R(04R)P4R(P4R(@4R)04R*@4W:09(
M,P4W;@9(*@9(-`4W;P4W;`4W:P0W,`4W<`4W:@4W<04W<@4W=`9(+@8^>@0W
M,09(+P4W;00W,P4W:`4W<P\Z5@\Z6`\Z60\Z6@\Z6P9(+04W=09(,@9(+`9(
M,09(,`\Z7`4^<`92+04^;`0\>@4^<092+@9<.P0\?092-04^:@4^<P92*P4^
M;P92+`92.092,`92.`4^;@92-@9<0`]!-P4^<@]!,P]!-`]!-@]!.`]!.092
M.@92,@92-P4^:P]!-092+P5%0P5%2P5%209<009</`1#*P1#)@1#)05%1`5%
M2`5%1P5%2@5%3@9</@9<1P5%305%105%1@9<0@1#*09<1@1#)P1#(P5%3`9<
M109<0P9</P1#*`]'7@]'7P]'8`]'8092,01)3@<B201)4@<B105,:0<B4`<B
M2@5,;@5,9P<B1P<B405,;P<B3P<B3`<B305,<`5,:@5,;0<M1`<B1@].5P].
M6`].60].6P].7`<B1`<B2P<B3@5,:P<B2`1)4054,P10(P<M2@10)`54-0<M
M0@54.`54-`54,0<M1P<M0P5;.054,@]4.@]4.P]4/`<M10<M20<M2`<M2P<M
M1@<M3054-P16*05;.P5A50<W8`5;/P<W9@5;.@<W8@<W9`<W805;/0<W7P<W
M90]9>0]9>@]9>P16*@<W8P<W9P<Y)P5;0`=&6@5A5`<_1P1:?@5A405A4@<_
M20]>605A4P<_1@]>6`<_10<_2`5A5@5A5P=&7`1?6P=&7@5G901?60=&70=&
M7P=&8`]B,`]B,0]B,@=&80=&8@=&6P1C.`=-501C-P5K?@=-5P]E*0=-5@5;
M/@5O>`5O>@5O>0=3,@=3,05S.P1H:01H:@=79P=7:0=7:`=7:@5S/`=>7@1K
M:@1K:0=>8`5W6`=>7P5Y)P]L)@5Z*`5Z9@5[/`=C3P5\-`8A;00A)00B8@4B
M5`8D6P8D7`4B508C?@0C?@4C>P8J?0\F:@\F:08P508P5`8P5@8P4P8W)@4R
M*P0Q008_+04W=@9<2`<B4@54.0].70]4/0<W:`<_2@=&8P5G9@=>80=E-08A
M;P8A<08A<`\A.P4A:`4A9P4C?`8G-P\F:P8P5P8W*`\O-`8_+@\Z7@<B4P=&
M9`8B=`4B5@8J?@8P608P6`0L908_+P4U7P4R+08_,`4R+`9(-@\Z7P\Z8`\Z
M80<B5`<_2P0A=P8B=08B=@4B604B6`0B9`4B6P8D808D8`8D7@\B2`\B2@4B
M5P8D7P4B6@8G008G.P4D(@8G.`4C?@4C?04D(P8G0`4D)`8G/`8G/P4D(0\D
M)`8G.08G.@8G/04D)08G/@4E>P0F-04E>04E?04E>@4E?`4F(08K(P4E?@4F
M(@8K(@\F;`4F(P8K(04E=P4E>`4H?@8P8@4H?04I(@4H?`4I(P8P7P4I)04I
M)`8P6P4I(08P6@8P908P9P\J4P\J5`\J500I)@8P808P8`8P7`8P708P9@8P
M9`8P7@4M.`8W,@4M-P8W+@4M.04R+@8W*@0L:00L:@8W+P4M.@8W+08W,08W
M,`0L9P8W,P8W-`\O-@\O-08W*08W*P8_-04R-00Q1@0Q0P0Q1`4R,P4R+P8_
M.@4R,`4R-`8_/`4R,04R-@8_-@8_.P8_,@4R,@8_-`\T20\T2@\T2P\T3`8_
M.08_,08_/08_-P8_,P9(.00W/@9(/@4W>04W>@0W.`4W>`9(.@0W-P4X(04X
M(@8_.`9(0`9(/09(.P4W?09(.`\Z8@\Z8P9(/P4W>P4W=P9(004W?@]`*P4^
M>`0](@5%4@0])04^=04^=`0])`4^=P4^>@92/@92.P92/09<2P4^>P92/`4^
M=@4^>09<3`9<305%6`1#-`5%3P5%509<2@5%5`5%5P]'8@5%605%4`5%5@5%
M40<B5P<B605,=`5,<P5,=01)5P5,=@5,>`1)5@<B5@<B50<B6`5,=P5,>05,
M<@<M4`54/@<M4@<M6`54/010*`<M5P<M5@54.P<M4054/`<M5`54/P<M3P10
M*@5;005;0@16+`<W:P]9?`<W:0<W:@5A6@5A605A6`=&9@1?705G9P1?7`=&
M90=&9P5G:`]B,P=-6`5L(0=3,P=7;`5O>P5S/0=7:P=>8@=>8P5W60=C4`=C
M=00A>`8G0@4D)@0D)@8K)`\F;0\F;@8P:08P:`\J5@8W-04R-P9(0@4X(P92
M/P5%6@]'9`=-60]J3@8A<@8A<P8B>`4A:08B=P\A8@0B9P0D)P4D)P\D)@8I
M7@8K)04F)`4F)08P:@8P000O)P8W-@0Q2@9(0P4^?`5%6P<B6P]'909<3@].
M7P<B7`<B7016)@=7;00B:`4B7@8D9`4B708D8P8D8@8D9@0B:08D908G104D
M*@4D+`4D*P4D*`4D*08G1`8G2`8K*`8G0P8G1@4D+04F+`4F*`4F)P4F*P4F
M*@0F.08K)@8K*08K)P0F/@8K*@\F<`\F<0\F<@\F<P\F=`4F*04F+08K*P4I
M*`4I*@0I)P8P;`4I*08P;0\J5P\J60\J6`\J6@\J6P\J7`8P:P4M/04M0`4M
M/@4M004M.P8W.@8W.P0L;@4M0@4M/P8W/`4M/`8W.0\O-P8W-P8W.`4L>P4R
M1`4R.P4R.00Q308_0P4R0@8_2`8_/@4R/04R/`4R/P4R/@8_/P8_0`4R004R
M.`0Q4`8_1`4R0P4X*`8_00\T30\T3@\T3P\T4`\T40\T4@\T4P8_1P9&/04R
M.@8_0@4R0`9(2@0Q2P4X*P4X+`4X+09(2P9(3@4X)P9(300W0@4X*@4X)@9(
M200W0P4X)0921`9(1@9(1P4X)`\Z90\Z9P\Z:`\Z:0\Z:@9(2`9(3`\Z9@0]
M*P4_)00]+`9200920@4_(@4_(P921P4^?09210]!.@]!.P]!/`920P922`4_
M)`4^?@921@1#.`5%7`1#-P5%7@9<4`5%8`5%7P9<3P]'9P]':`]':0]':@]'
M:P]';`]';0]';@]';P9<409@,0]*5`<B7@1)6@0W/P1)6`5,>@1)60<M60<B
M8@5,?`5,?@].8`].8@].8P<B7P<B80<B8P<B8`5,>P54005,?0540P540`10
M+0541`]4/P]40`]400]40@<W;@5;1`<W;`<W;0]9?@]:(0]:(@]:(P5;0P<W
M;P5;10<_40<_3@5A6P]>6@]>7`<_30<_3P<_3`]>6P<_4`=&:`=&:05A7`5G
M:0]B-`]B-0]B-@5G:@5L)`5L(P=-70=-6P5L(@=-6@=-7`=-7@1F/`=3-`=3
M805S/@=7;@=7;P5U:@]J3P=;30=>9`=B-@5Z:`5Z9P]L>P\A8P\B2P\B3`8K
M+`\D)P8K+08K+@\O.0\O.P\O/`\O.@4R10\T5`9(3P\Z:P\Z;`4_)@8A/P8A
M=08B>08G200D*@8P<`8G30\D*`8G2P8G3@0F/P8K,`4F+@8K,0,J.00G008U
M(P8P<@8P<P8P<08P;P8P;@8W/P8W/@0L;P8W/08W0`8_208_2@8_2P8_3`8_
M308_3@0W1`9(4`9(5`9(4P9(40\Z;09(4@92204_)P]!/09<4P9<5`9<4@5%
M80<B9`<M6@<M7`10+P5410<W<0<W<`=7<`=C40=C4@=E-@8A0`8A=@\B300D
M*P8G4`8G3P4D+@8K,@8P=@8P=08P=P4N:`8_3P4X+@922@9<50<B90<M704A
M*@4A1P8A>`8A?`8A=P8A>@8A>P8C(08C(@8B?`8B>@8C(P8B>P8B?08B?@4A
M:@4B8`4B7P8D:`8D:08D:@8D:P4D+P8G404D,08G4P4D,`\D*0\D*@\D*P\D
M+`8G4@4D,@4F+P8K-@8K,P8K-`8K-P8K-08P?@4I+`8P?00I,`8P>04I*P8P
M>`4M1`4M0P4M108W0P8W004M1@\O/08W0@4R2@4R2`4R208_5@8_4`0I+P9(
M508_4@8_4P4R1P8_40\T50\T5@\T5P8_5`8_5P8_509(5@9(604X+P4X,@4X
M,09(6@4X,`9(6`9(5P4_*`0],0922P]!0`923`5%8@9<5@5%8P9<5P9<60]'
M<`9<6@9<6`5-(05-(@1)8`<B9@].9`].90<B9P<M7P541@10,`<M8`<M7@<W
M<P<W<@<W=`]:)`1;(@5A7@<_4@]>705A70=&;0=&:P=&;P=&:@=&;`5G:P5L
M)0=-7P1?7P=-80=-8`5L)@5O?`5O?01F/0=3-05S/P=@/`=@;P=D1@8D;@8D
M;`8D;04D,P8Q(08K.`8M,@8Q)`8W1`8Q(@8Q(P8W1@8W108_6`9/(04X,P9(
M7`9(6P4_*@9<7`9<7P9<709<6P9<7@<M80<M3@10,@<W=0<_50<_5`<_4P=&
M<@=&<`=&<0=7<0=;3@=B-P8C)08C)`\A9`8D<08D;P\D+08G5`4F,`8K.P8K
M.@8W1P0L=`0L<P4U8`8_708_608_6@\T6`\T60\T6@8_7`8_6P4R2P9(709(
M8`9(7@9(7P\Z;@9240923@924`923P]!001#/`9<8`<B:P<B;`<B:0<B:@5-
M(P10,P541P<M9`<W=@<_5@]G5`=-8@=3-@5S00]L)P8A?04A:P0A>04B800B
M;@4B8@4D-`8G6`4D-08G5P8G608G6P8G5@4D-@8G508G6@4F,P8K/04F,08K
M/`4F,@4I+08K/P0I,P8Q)@4I,`4I+@8Q*`4I,@4I,0\J7@8Q)P8W300L>00L
M=P0L?`0L=04M2P4M200L>`0L>@0L=@0L>P4M2@8W208W3P8W3`\O/P\O0`8W
M2P8W4`8W3@8W2@0Q5@4R3P8_:`8_804R3`4R404R3@8_8`4R4`0Q6`8_9P8_
M908_8@0Q608_9@4R308_9`8_7P8_8P9(9`\T7`0W1@4X-@4X-04X.P4X.@4X
M-P0W1P9(804X-`9(8P4X.`0Q50\Z<`9(8@\Z;P4X.04_+`4_*P924@925`92
M5P924P]!0@]!0P]!1`]!10]!1@]!1P9250925@96;`4_+00],@9<9@9<8P5%
M9@9<8@1#/@5%901#001#0`9<805%:`5%:@5%9`9<:`9<:09<:@5%9P9<9`]'
M<0]'<@]'<P]'=`]'=09<901)9`5-)`5;2`1)8P1)8@5-)0<B;0<B;P].9@].
M9P<B;@<B<`<M90542`542@<M9P<M9@]41`]410<M:`54205;1P<W=P16,`]<
M7P5;1@5A8`<_5P5A7P<_6`]>7@5A80=&<P=&=0=&=@=-(@=&=`5L)P1C/@1C
M/0]E*@=-8P=3-P5O?@=7<@1J1P5Y*`4A,08B(00B;P4A;`8C)@\B3P8D=04B
M8P8G8`4B:08G704B9`8D<P8D=`4B908G7`8G7@8G808D<@4B:`4D-P4D.00F
M108G9@8G9`8K1@8G9P8K0`8G8@8G8P8K1`8G908G:`,E?@8G:04D.@\D+@\D
M+P\D,0\D,@\D-`\D-0\D-@\F=P\F>`\F>0\F>@\F>P\F?0\F?@\G(0\F?`8K
M108K008K0@0D+0\D,`0F1`4F-`8K0P0F1P8K3`0I1P8Q+P0F2P8K308Q*04F
M-08Q+`8K3P0F2@4F-P0I.`4F-@0I0P8K204F.`0F400I1`8Q*@8Q*P8K4`8K
M1P8Q+0\F=0\G(@\J<`0I1@8Q+@8K2`8K2@8K3@8K2P\J9`\J7P\J8@\J90\J
M:`\J;`8W6P8W608Q,@0I204I-P0I0@0M*04M3@4I-@8Q.08W5P8Q,P0L?04M
M3`8Q-08W4P0M(08Q.`4I-`0L?@8Q.@8Q,08Q-P8W5@8W500M*@8Q-`\J80\J
M9@\J:0\J:P\J;0\J;@\J;P\O1@\O1P\O2`\O2@8W4@\O1`8W6`\J8P4M308W
M404M4@4M6`4M6P8_;08W8P8_;P8_:P8_<`8W9`4M508_:00M+@8_<P4M5@0M
M)@4R704M404M7`8W8@8W704R5`8W7P8W808_;`8W8`8_<00M)P4M4`8W7`4R
M4P8_<@8_=`4R4@4M3P\O00\O0@\O0P\O20\O2P\T70\T7P\T8`\T9`\T90\T
M9@\T9P\T:`8_:@8W908W9@4M5`4M600W6@9(<00W304R608_?`0W2P9(<P9(
M:04X508_?@9(<@9`(@0Q904M4P0Q;08_=P9(;@0Q804X/P4R5P4R6@0W3`8_
M>04R7`8_=@8_;@0Q:04X/`9(<`4R7@0Q7P8_?08_>P8_>@9(9@9(;`4X/@4X
M009(=`4R509(:P9(=@9(9P9(908_=04X0`\T80\T7@\T8@\T8P\T:0\T:@\T
M:P\T;`\T;0\T;P\T<`\T<@\Z<@\Z<P\Z=`\Z=0\Z=@\Z=P\Z>0\Z>@\Z?`\Z
M?0\Z?@\[(0\[(@\[)0\[*0\[*@\[+`\[+@9(:`4R5@8_>`\[)P\T;@9))`9(
M;09`(0\[)`0]/P4X2@4X304X4@0W3P0W5P0W4092709)(P4X4`9)(@0W4P4X
M5@4X6`4X0P92804X6@4_,P0W6P4X4P9)(04X1@9(>P4_-`4X1`4X5`4R7P92
M6`4X1P0]-@0W6`4X604X404X2P4_,09(=P4X3P4X/09(?@928@928P926@9(
M?04X5P927@928`4_+P0]0`0W4@4X209(>0\Z<0\Z>P\[(P\[*`\[+0]!2`]!
M3@]!4`]!40]!4@927`927P926P9(>@\[*P4X3@4_+@4X3`\T<0]'?04_/`4_
M-@4_-092:P5-)@4_109<;P4_.04_/P4_1`9<=`92;P5%:P4_.P9<;`92904_
M.`4_/04_.@92601);@9<=@9<>04_0P92:`9<<@1#3P9<>`9<=P4_005%;04_
M/@9<<09<;@9<;04_-P929P92;0]!2@]!2P]!3`]!30]!3P]!4P]'=@]'=P]'
M>0]'>@]()0](*`9<<`9<=04_0`]!209<<P92;@9=(P9=)P1#101#1`5-)P9<
M?`5%=P5%=@5%<P0]-09<>P<B<@<B=05-*05%<`5%;P5%;`5%<05%<@5%>09=
M)09<?09<?@92:@9=(@<B=`9=(0<B=P5%=`5%>`<M:@1#4P]'>`]'?`]'?@](
M(0]((P]()`]()@].:0].:@].:P].;`].;0].;@].;P].<P].=0<B<P<B>`9<
M:P5%;@9<>@5-*`5%=0<M<01)9@1#4@<M:P1)<0<M;05-+P<M<P1):@5-+@<B
M>05-,P1)<@<M=04X105-,@5--010-010-@<C(05--`<W?`5-,`543@16-`<B
M>@<C(@545`5-*P5-+054305-+`<N(@<M=P<M=@<B?@10/`<M<`<M;P]((@].
M<`<M<@5-,0<M;`].<0].<@].=`].=@]41P]42`]42@]42P]440]44P<M=`54
M2P<P4`<B?0<E<01)<`543`543P].:`]43P544`544@<M>P<M>`5450545@54
M40<M?@<M?`<M?0545P10/05;20<N(0<W>P<W?0<W>@<X(05;2P<M>@<W>0<M
M;@]430544P<X(@]420]43@]44@]:)0]:)@]:+@]:)P5;2@546`]:*@]43`<W
M>`5;4016-016,01;*@5;3@5A9`5A8@<_6P<X)@1;)@5;305;3P<X(P<X)05;
M4`5A8P<_6@5A90<_60<B=@]:*P]:+0]>7P]>8`]>8@]>8P]>90]>9@]>9P<_
M7`<X)`]:*`1;)P5;4@=&>0<_705A:`=-9`1?8P1?8@=&?`5A:0=-9P1;*`5A
M:@=')0='(0=&>`5A9P=&?@5G;0=&>@5G<`=&=P='(@<_7@=&?05G;@]>9`5G
M;P=&>P5G;`]B.0='*@1C1`=')P5G=`=')`5L*@='*0=')@<_7P5G=01C/P5G
M<05L*`='*P='(P=-905G=P]B.@]B.`]B.P]B/`]B/0=-9@5A9@5G<@]E*P5G
M=@5L*0=3.0=-:@1C00=-:01C10=3.`=-:P]G50=;3P1F/@5L*P=7<P=7=`=7
M=0=3.P=3.@=3/`]I0@=7=@=;4`=;4@=;4P=;40]J4`]I00]J40]J4@=;505W
M6@=;5`=>90]J4P]K1P]K2`5W6P=>9@5Y*0=>9P]L*`]L*01M<@]L?`]L?05[
M/@5[8`]M-`4B:@0B<@8D=@8G:P4D.P8G:@8G;08G;`0F4@8K408K6`8K5`8K
M5@0F4P8K508K4P8K5P\G)`\G(P8Q/08Q.P8Q/@8Q0`0I3`8Q008Q/P\J<0\J
M<@8Q/`8W9P4M7P8W:04M7@8W:`4R800Q;P9`)0\T<P\T=`9`)`4R8`9)*`9)
M)P9))09))@0W7`9)*0\[+P4X6P4X7`\T=@0]1`92<04_1P4_20]!500]0092
M<`4_2`9=*09=*@5%>@5%?`5%>P<C)`5%?0](*0](*@9=*`5--@1)<P1)=`<C
M*`<C)P<C)09=*P<C(P].>P<C*0<C)@].=P].>`].>@<C*@<N*@<N)0<N)`<N
M)P<N)@<N*0<N*`<L8P<Q<`<N(P<X)P5;4P]:+P<_8`='+01?90='+@5L+`]E
M+`5P(0=3/08C)P4A;08D=P8D>`0D-`\D-P\D.`4F.08K608K6@8Q0P8Q0@8Q
M1`4I.0\J<P\J=`\J=08Q1@8Q104I.`8W;`8W:@8W:P4M804M8`9`)@\T=P4X
M704X7P4X8`4X7@4_2@5%?@1#50<C*P5;5`5P(@8C*`4A;@8C*08C*@4A;P4B
M;`0B=@8D>04B<@4B<`4B;P4B:P4B;0\B4`\B4@4B<00D-P8G<P8G=@8G=00F
M5P4D/08G;P0D.`0D-08G=P4D/@0D.P8G<@8K708G<08K908K6P8G<`4D/`8K
M7`8G=`\D.P\D/`\D/0\D/@\D/P\D0`\D00\D0P\D1`\D10\D.@8K7@8K7P8K
M804F.P4I.@8K9`8Q2`4F/08Q2@4F/`8Q208Q1P8K8@\G)@\G)P\G*`\G*0\G
M*@\G*P\G+`\G+0\G+P\G)04F/@8Q4@8Q5`0I6`0I3P0I4`8Q4P8W;04I/P4I
M0@4I008Q304I1P0M-`0I7`4I/@4I/04M8P0I4P8W;@4I2`0I6@8Q4`4I0`4I
M1`8Q3@8Q5@8Q2P4I0P4I/`8Q508Q40\J=@\J=P\J>`\J>0\J>@\J>P\J?`\J
M?0\J?@\K(0\K(P\K)`\K)0\K)@\K)P\K*`\K*0\K*@\O4P\O7`\O808Q3`\K
M(@4I.P4M8@4M9`0M/08W=00M.`4M;04M:P0M.00I5P0M-04M:@8W>P8W<`8W
M?08W<P4M:08W<@8W=P0M-@8W>`4M;`4M900M-P4M9P4M:`0M.@8W>@4M9@8Q
M5P8W=@9`)P8W>08W=`4I1@8W?`8W?@\O3`\O30\O3@\O3P\O4`\O40\O4@\O
M50\O5@\O5P\O6@\O6P\O70\O7@\O8`\O8@9`*`\O6`8W;P\O5`0Q<@0Q<P0W
M7@4R:09`,04M;@9`-P4R8P0Q=`0R(@0Q=@4R8@0Q?04X804R9`9`-`4R9P9`
M-09`+`9`*00R)`9)+P9)*@9`*@4R909)+00W709`+P9)+`9)*P4R:`9`+09)
M+@9`,P9`,`0Q=09`+@\T>`\T>0\T>@\T>P\T?`\T?@\U(@\U(P\U)`\U)0\U
M)@\U)P\U*`\U*0\U*@\U*P\U+`\U+@\U+0\U+P\U,`\[,0\T?04R9@0R)@\[
M004X:P9)-`0W:09).P9)-@4X;09)004X=`9),00]400W9P4X8@4X:@0W7P4X
M:`0W8P4X:00W:@4X9@0W;04X;P0W9@9)0@9)0P9).@4X<09),P9)1@9)-P4X
M<`0W;`9)1P9),@4X;`4X;@9)1`4X9`9)/`9)109)0`9)3`9)/P9)309)2`9)
M.04X<@9)/04X<P4X9P9).`9)2P4X9092<P\[,`\[,@\[-`\[-0\[-@\[-P\[
M.`\[.0\[.@\[.P\[/`\[/0\[/P\[0`\[0@\[0P\[1`\[10\[1@\[2`\[20\[
M2@92=`9)/@9)209)-04X8P\[1P4_4@92>P0]2P0]204_500]1@92>`0]300]
M4P0]1P0]4@92?@4_405&(04_2P9=+`93)092=093(P93(@4_304_4P4_3@92
M>093(04_4`93)`92?`4_3`92>@4_3P]!5@]!5P]!6`]!60]!6@]!6P]!7`]!
M70]!7@]!8`]!80]!8P]!9`]!90]!9@]!9P]!:0](,`92=P92?092=@]!:`4_
M5`9=-@5-.05&)P5&*@1#8@1#7P9=/`9=/09=+@1#5P9=/P5&)@1#8P5-.`5&
M*09=-01#60<C+P1#6P1#6@<C+@<C,05&)`1#909=.09=/@9=.@5&*`9=-P5&
M*P<C+`9=.P9=,P9=,05&(@1#8`9=+P9=-`](*P](+`](+0](+@](+P](,P](
M-`](-0](-P](.`](.@](.P](.0](/`](/0](/@](/P](0`](00](0@](0P](
M1`](10](1P](2`](20](1@9=,`](-@<C,P<C.`5-/`1*)0<C/0<C-P<C.01)
M>P1)>`5-/05-.P<C101)?0<N+P1*(05-001*)@1)?`5460<N/`<C-0<C-`<N
M+0<N*P<C1`<N+`<C/`5-0`<N+@5-/P<C.P<C0@<C0P<C/@<C001)=P](,0<C
M,@<C/P<C0`].?`].?0].?@]/(0]/(@]/(P]/)@]/)P]/*`]/*0]/*@]/*P]/
M+0]/+@]/+P]/,`]47P]/)`16.`1000<N-0<N,`546@546P<N/@<N.@<N,@<C
M-@10/@100P100`547010/P<N/0101@<N.P102`100@101P<N.0<N,0<N0`<X
M*0<N.`547P547`<N-P<X*`<N,P<N/P]450]45@]45P]46`]460]46@]46P]4
M7`]470]47@]48`<N-`<N-@101`]45`5;5@<X,05;5P<X-@16.P<X+P<X-016
M.@<X-`<X+`5;6`16-P5;50<X*@<X-P<X,`<X+@<X,@<X.`<X*P<X+0]:,`]:
M,0]:,@]:,P]:-`]:-0<X,P1;,P1;.`5A;@5A:P5A;`5A;0<_:`<_9P1;-01;
M-P5G>@5L+0<_:0<_9@1;-`<_8P<_90='+P<_80<_9`]>:`]>:0]>:@]>;0]>
M;@]>;P]><0]><@]>=`]>;`]>:P1?9@1?:`1?9P1?:05L+P=',@='-`='-@5G
M>P=',`5L+@='.`1?:P='-0=',P=',01?:@5G>0]B/@]B/P]B0`]B00]B0@]B
M0P]B1`]B10]B1@]B20]E+P<_:@='-P]B1P5L,@1F/P=-;01C2`=-;`1C20=-
M<`1C2@=-;@5L,P5L,`5L,0=-;P]E+0]E+@]E,`=31`=7=P1F00=3/P=30P=3
M0@1F0@5S10=300=30`]G5@]G5P]G6`]G60=7>`=7>05S1`5S1P5P(P=7>@5S
M0@5S1@=7?`=;5P=3/@]I0P]I1`5S0P=7>P=;6`]J5`]J50]J5@=>:@5W70=>
M:01K:P=>:P5W7`=>:`]K20]K2@]K2P]K3`=B.`]L*@]L*P1M<P=C4P]L80=F
M)@0B=P0D/00F6@\G,0\G,@\G,P8Q6`8X(@4O7`0M/@8X(08V1`9`.09`.`9)
M3P9)3@\[3`\[304X=093)@]!:@93)P5&+09=0`<C1@<C1P548`]480<X.P<X
M.@5;60<X/`=-<04D/P8G>04D0`8G>@4D008G>`8K:`0F8`4F0@4F0`0F708K
M;`8K9@8K:@8K:08K9P4F/P4F000F7`0I8`8Q604I3`4I2P8Q7`8Q7@8Q704I
M204I2@0I7@0I7P8Q6P8X(P8X)`8X)@4M<@8Q7P0M108X*`4M<`8X*@4M;P4M
M=`8X)04M<P4M<08X*08X)P0M004R;09`0`0R+@9`.@9`.P9`/04R;P4R<`0R
M,`9`/@9`/`4R:P9`000R,00R*@0R+00R*04R;@\U,0\U,@\U,P\U-`\U-04R
M:@9`/P9)6`4Y(@9)500W>@0W>P9)609)5`9)6@4X=@4X?@4Y(04X?04X=P9)
M5@4X>P9)409)4`9)4P0W<@0W<P0W=`4X>`4X>04R;`9)4@93+P4X>@4_5P4_
M6@4_7`0]5P0]7P93*P93+@93*04_6P93,`93+093*`0]8`4_5@93,04_600]
M7@0]500]5@0]6`4_6`93*@]!:P93+`4R<00]6@958`5&-`9=205&,@9=001#
M:`5&,09=0@5&+P9=1@5&-P5&-09=1P9=109=1`9=2`9=0P9=2@5&,P1#9P5&
M-@9=2P5()05-0@5-1P1*+`<C3@<C20<C2`5-1@<C4@<C3P<C305-10<C4`5-
M0P5-1`]/,0<C2P<C3`<C2@102P<N0@<N1@<N2`]48@5480<N2P<N1P<N20<N
M00<N10<N3`548P<N2@102@549`5490549@]48P<N1`548@<C40549P<X/@<X
M/05;6@5;7@5;7016/`16/05;6P]:-P]:.`<X/P5;7`5A<`<_;`5A;P1;.P<_
M;0<_;@1;.0<_:P5H(05G?@5G?`5G?0]B2@5L-`1C305L-0=-<@1C2P=-=0=-
M=`5L-@=-=@=-=P1F1`5P)05P)@5S2`]I10=;605U:P1J2@=;6@1L;P]L8@\B
M4P\D1@8K;0\K+0\K+@\K+P8X+08X+@\O909`0@9`1`\U-P\U.`9`0P\[3@4_
M70]!;`93,@\U-@5-2`<C5`<C4P5-20]/,P]/-`5-2@<N30]:.0]>=0]B2P]G
M6@=;6P8B(@\G-`8Q8`0M2`4M=@4M=08X+P4R<@\U.09`1@9`109)70]`,@9)
M6P9)7`0]809=3`4_7@]!;01#:@1*+0<C50<X0`1?;`8B(P\D1P8K;P8K;@8Q
M80\O9@0R,@9`2`9`1P9)8`9)9`9)8P4Y(P9)9@9)7P9)7@9)8@0W?`9,/@9)
M900]8@93-@93-`93-P4_7P9=3P9=3@9=4`-',01*+P9=305-3`5-30<N40<N
M4`<N3P<N4@<N3@1030<X00<X0@<_;P1;/`<_<`<_<0='.0]B3`=->`=7?00D
M0@8G>P\G-0\G-@4I308Q9`8Q8P\K,`8Q8@0M2@4M=P8X,08X,P8X-0\O9P\O
M:`\O:0\O:@8X,@0R,P0R-09`2@\U.@\U.P9`209):04Y)04Y)`9):`9):@9)
M9P\[3P\[4`93.`4_8`93.0]!;@]!;P5&.`5&.@9=4@5&.0<C5@]/-0<N4P54
M:`<X0P5;7P<_<P5A<01;/0<_=`<_<@='.@=3101H;0=7?@=>;`=@<`4D0@4I
M3@4M>04M>`0W?09):P93.@93.P0]9@]/-@8C+`8C*P8D>P4B<P8D>@8D?`\B
M5`\D2P8G?`8G?08H)04D0P8H(@8G?@8H)`8H(P8H(0\D2`\D2@\D3`0D1`4F
M2`8K=`8K<P4F208K?04F1`8K>04F1P8K>@8K=P4F1@4F108K=08K>`\G-P\G
M.`\G.0\G.@\G.P\G/`\G/08K<08K>P8K?`8K<@8K=@4I408Q908Q9@4I4`0I
M9@8Q:`8Q:00I:`\K,0\K,@8Q:@\K-0\K-@8Q;@8Q;`8Q:P4M?@8X.@4N(04N
M(@4M>P4N(P4M?`4M>@8X/@8X.`8X/`4M?08X.08X/0\O:P\O;08X.P\O;`8X
M008X/P4R<P0R.`0X(09`4P0R/09`3@9`2P9`3`9`4`9`309`504R=08X0`9`
M5`9`5@\U/`\U/0\U/@\U/P\U0`\U00\U0@\U0P\U1`\U10\U1@\U1P9`4@4R
M=`9)<09)=`0R/`4_804Y*@9);P4Y)P9)<`4Y*04Y)@9);`9);00X(P9)=@4Y
M*P0X)P9);@9)=09)=P\[40\[4P\[5`\[5@\[5P\[60\[6@\[7`\[70\[4@\[
M6`0X)@0X*`9)<@4Y+`4Y*`930P4_8P93009=4P930@93/P931`]&.0\[6P93
M/@]!<`]!<0]!<P]!=`]!=0]!=@]!=P]!>`]!>0]!>@]!>P]!?04]50931093
M0`4_9`5&.P5&/P5&/05&/@9=5@5&0`5&0P5&1`1#;`5&0@5-3@](2@](2P](
M3`](30](3@](3P9=5`5&/`9=5P9=609=6@9=509=6`<C80<C7`<C6P<C7@5-
M4@5-50<C6@<C5P<C6`<C8@]/-P]/.0]/.@5-5`<C8`].,`<C70<C7P<C605-
M4054:054:P<N5P1050<N50<N6P<N60<N70105`<N7`<N5`]490]49@]49P]4
M:0]4:@<N6`5-3P<M8@]4:`<N0P54:@<N5@]/.`<X1P5;8`5;80<X2`5;8@<X
M10<X1@<X20]:.@]:.P]:/`<X1`]:/01;/@5A<@5A<P<_=0]>=@]>=P]>>`]>
M>0]>>P<_>`5H(P='/0='/`5H(@5H)`='.P='/@]B305L-P]E,0]E,@5K;@=-
M>0=31@=8(0]I1@5S.05S20=;7`5W7@=>;0]K305Y*P=D1P\D308K?@\G/P\G
M0`8L(04I4P4I4@8Q<`\K-P\K.08Q;P8X0@\O;P\O<`\O<0\O<@\O<P\U20\U
M2@\[7P9)>@9)>04_901#<`931@5-5P5-5@<C8P]4:P5;8P<_>@5A=`<_>0<_
M=P1?;0=->@=->P5[/P=F/@8C+08D?04D1`8H*08H)P8H*`8H)@8L(@4I5`0I
M:00I:@\K.@8Q<08X0P\U2P4R=@9`609`6P9)?09)?`9`6@4Y+0\Y1@\[80\[
M8@931P4_9P\[8`]!?@]"(0932`9=709=7@<C9`1*-`5-601*,P]/.P]//`54
M;@54;`5;9`54;0]4;0]4;@<X2P<X2@]:/@5A=0]>?`<_>P5L.`5U;P5W7P4A
M2`0A3@0A?0\A904B=08E(@4B=`8D?@8E(0\B5@0B>P0B>@8H+`0D208H*@8H
M*P\D3@\D3P\D5`\D4`\D4@4D1@8H+04D100D100F:P4F3`0F9@4F2P8L*P4F
M4`4F4@8L*`8L)P8L)@4F304F4P4F3P4F3@\G0P\G10\G1@\G1P\G20\G2@\G
M2P\G30\G3P\G40\G5`\G508L)`8L*04F5`8L+`\G1`8L+08L*@\G2`\G0@8L
M)04F508M7`8Q=`8Q<P0I:P4I5@8Q=08Q=@4I504I608Q=P4N)@4I6@4I6`\G
M4P\K.P\K/`\K/0\K/P\K0`\K00\K0@\K0P\K1`\K10\K1@\K1P\K20\K2@\K
M2P\K3`\K30\K3@\K3P4I6P9`7`8X3P8X4P8X2P8X308X1@4N)P8X2`8X108X
M400M4`9`704I5P4N*04N*@8X1`\O=`\O=0\O=@\O>`\O>0\O>@\O>P\O?`\O
M?0\O?@\P(0\P(@\P(P\P)0\P)@\P)P\P*0\P*@\P*P\P+`\P+@8X3`8X1P8X
M200M4P8X3@\P,`\P*`0M6@\P+04N+`4N*`\O=P8X4@9`:`9`:09`7P4R=P4S
M(04Y-@0R100R0`4R?09`9P9*+@9`8P\U3`\U30\U3P\U4`\U40\U4@\U4P\U
M5`\U50\U5@\U6`\U60\U6@\U6P\U7`\U70\U7@\U7P\U8`\U80\U8@\U8P\U
M90\U9@9`9`9`9@9`900R1P9`8@9`8`9`800R1`4S(@4R>`4R>P4R>@4R?`9`
M:@\U3@9`7@0X-@9*-`4Y-093200X+@4Y.`9*(@4Y,@0X*P4Y,`4Y-`0X,09*
M+09*+P4Y.@9*)`9*(04Y-P9*,P4Y/`4Y.P9*)@0X,`9*)P9**@9*,04Y0`93
M2@4Y/09*.`9*(P9*)09*-00X,P0X.`9*-@9*-P\[9`\[90\[9P\[:`\[:0\[
M:P\[;`\[;0\[;P\[<0\[<@\[=`\[=0\[=@\[=P\[>`\[>0\[>@\[>P\[?`\[
M?0\[?@\\(@\\(P\\)`\\)0\\)@\\)P\\*`\\*@\\*P\\+`\\+0\\+@\\+P9*
M*09**P9*+`9*,@4Y0@9*,`9*.09**`4Y/@4Y004Y+@4Y+P4Y,0933@936`0]
M=P935@0]=`935P4_;P4_:@4_;@4_:P0]:@936P4_<P93804_:`0]>@4_=`4_
M:093504_<`4_;0938`0]<P9360936@9370934`0]<`937`4_;`938P933P93
M40933`]"(P]")`]")0]")@]")P]"*0]"*@]"*P]"+`]"+0]"+@]",`]",0]"
M,@]",P]"-`]"-0]"-@]".`]".0]".@]".P]"/0]"/@]"/P]"0`]"00]"0@]"
M0P]"1`]"10]"1@]"2`]"2@]"3`9330934@935`0]>0938@932P937P]"(@]"
M+P]"-P4Y/P4_<@934P]#=`5&3@]"2P5&4`1#>P1#<@5&305&3P9=:05&505&
M4@<C90939`5&1P9=7P5&5`5&1@5&6`9=8@5&2@5&4P9=8P1#=@5&2`5&209=
M905&3`5&40](5P](6`](60](6@](6P](7`](70](7@](7P](8`](80](8@](
M8P](9`](90](9@](9P](:`](:0](:@](:P](;`](;0](;@](;P](<0](<@](
M<P](=0-'2P9=:@9=9P9=:P9=;`5&5@5&5P](=`9=9`9=9@](4`](40](4P](
M5`9=8`9=;09=80](5@<C:`5-9P5-7@1*.P1*1P5-6P1*0`<C<0<C;`<C=`5-
M:P5-90<C<`1*1@5-7P1*/P5-9`1*0P1*/@1*-0<C<P5-7`1*2@5-:0<C;@5-
M8P5-:@<C:01*005-70<C=01*/`1*101*20<C9@<C:@]//0]//@]//P]/0P]/
M1`]/1@]/1P]/2`]/20]/2@]/2P]/3`]/30]/3@]/3P]/4`]/40]/4@]/4P]/
M0`<C:P5-;`5-:`5-9@<C9P<C;05-8`5-6@5-8@106P54?0<N:01090106`5;
M90<X3`<N8`<N8P54>P<N:`<N<@54>@<N;P<N8@108@163`105P<N7P107P54
M>0<N9P<N9`54<054=P107`<N;@<N=`54>`1070<N9@<N:P108P54<`<N805A
M>P54=054=@54<@1*1`<N<P<N;`<N90<N7@54?`54;P54<P]4;P]4<`]4<0]4
M<@]4<P]4=0]4=@]4=P]4>`]4>0]4>@]4?`]4?0]4?@]5(0]5(@]5)`]5)0]5
M)@]5)P]5*`]5*P]5+`]5+0]5+@]5+P]5,`]5,@]5,P]5-`]5-0]5-@]5-P]5
M.`<N<`<N<01080]5(P54=`](<`]/00<N;0160P<X4`<X3@161P<X4@<X5@5;
M:@5;:P162@161@5;;@<X4P5;;`<X40<X5P5A?`5;9P1630161`<X60160@5;
M:0<X6P5;9@<X5`]:0`]:00]:0P]:1`]:10]:1@]:1P]:2`]:20]:2@]:2P]:
M3`]:3@]:3P]:40]:4@]:5`<X6`5;;0<X6@<X30<X3P<W)P]:4P]:305;;P5;
M<`]5,0]:4`1;1P5A>`=`)P=`(P1;0@=`*P5B)`5A?05B)@=`*01;105A>@5B
M(@5B)P5A?@<X7`5B*P5A>01;0P1;3`1;1@=`+0=`*`5B(P='1@5B*0=`)@1;
M2P5B*`5B)05A=@<_?`<_?0]>?@]?(@]?(P]?)`]?)0]?)@]?)P]?*`]?*@]?
M*P]?+`]?+@]?+P]?,`=`(0=`)0=`+`=`*@5B(0]?(05B*@5A=P=`(@=`)`]?
M+05H)0='0P5H*`5H*P5H*0='0@='0`5H+0='001?=`='2`='205H)P5H)@='
M105H+P='1P<_?@]B4@]B5@]B6`]B60]B6@]B6P]B7`]B70]B7P]B8`]B805H
M+@='1`='/P]B5`5H+`]B5P]B3P]B7@]>?01C4P=-?`5L/P=-?@5L0@5H,`5L
M.@5L.05L/0=-?05L/`5L005L.P5H*@5L0`5L/@]E,P]E-`]E-0]E-@]E-P]E
M.0]E.@]E.P]E/`]E/0]E/P=.(01C4@=320=32`5P*P5P+01F1@5P*0=3305P
M*`5P*@5P+`=32@1F105P+P=33@5P,@]G6P]G7`]G70]G7@]G7P]G8`]G80]G
M8@]G8P]G9`=33`5P,05P,`=32P5P+@=8)@5S3@5S3P5S3`5S2@1H;P5S2P5S
M30=8)0]I1P]I2`]I20]I2P]I3@]I3P]I4`]I40=8)`=8(@]G905U<05U<P5W
M8`5U=`=;8`5U<@=;805U=0=;7P5W80=;70]J5P]J60=;7@5U=@5U<`1K;`=>
M;@5W8@=@<0]K3@]K3P]K4`]K4P]K5`=>;P=><`]J6`=@<@5Y+0]L+`=@<P5Y
M+`5Y+@]K4@5Z*0=C5`=@=`1M50]L+0]L3`]L8P=C3`=C505[0`=D2`=D20=E
M6P]M+P=E=`8E)`0D2P8H+P8L+@8H,@4D1P8H,00D2@4F7`4F6P4F6`8L+P0F
M;P8L,`4F700F;@4F604F6@4F5P\G5@4I7P8Q>@8X5`8Q?`4I8@0I=04I804I
M7@8Q>04I7`4I8`8Q>P4I70\L=P8X5P8X6`8X504N,P4N+08X5@9`:P4N,@0M
M7P4N+P4N-`4N,04N,`\P,04S)09`;`9`;0\U9P\U:`\U:0\U:@\U:P\U;`\U
M;0\U;@0X/04Y1P4_=P0X.@4Y109*/`4S)`4Y2`9*/04Y1`4Y209*/@4Y1@9*
M.P\\,`\\,09*.@93;@4_=@4_=04_>@93:P4_>0939P939@93:`93:093:@93
M;04_>`]"3@986@93;`9390]"305&7`1$*P5&7@9=;P9=;@1$+`5&701$*09=
M=09=<`5&6@9==@9==`5&6P9=<@9=<09=<P93;P](=@](>`5&605-;@<C?05-
M<`5-<01*30<C>0<C=P<C?@<C=@<C>@<C>P5-;P]/5`<C?`54?@<N=@10:`<N
M=0]5.@]5.P<X7@<X8`5;<0<X7P]:50<X705B+`5H,@5H,0]B8@5P-@=.(P5P
M-05P-`1H<`5P,P5S4`=8*0=8)P=8*`5W8P=@=01L<`1M5@4A,@4A<`8C+@8E
M)@4D2@8H-`8L,04D204D2P8H,P8L/`8L-`8L.P8L.@8L-@8L,P8L.`8L,@8L
M-P4F7@8L.08L-04F7P\G5P\G6`\G600F<@0I=@4I8P4H-08X608X7`4N-08X
M6@8X7@8X708X6P8W2`4S)@9`<`\U;P9`;P0X0`0X/@4Y2@4Y2P9*0P0X009*
M0@9*1`9*0`9*109*1@9*004_?`93<`4_>P]"3P9:80<D(@<D)0<D(P<D)@<D
M(0<D)`]/50<N>@<N>0<N=P<N>`<X80164`]:5@]:5P5B+05B+@=`+@5S40=;
M8@=;8P4A<04A204B=@8H-00B?08E)P4D3`0D308E*`8H-@8H.P8H-P0D3`8H
M/`4D308H.08H.`8H.@8L/P4F8`4F9@4F804F9`0F<P0F=`4F8P0F=P8L/08L
M/@8L0`8Q?04F904I:`0I>`0I>08R)@0I=P8Q?@4I9`4I904I:P4I9@4I9P8R
M)00I>@8R(@8R(P4I:@8R)`8X7P\K4`8R(04I;`4N-@0M8P8X8@4N.P8X904N
M/`4N.`4N.08X8P8X9@4N/04N-P4N.@4N/@8X8`8X804S*P9`=`4S*@9`<P4S
M)P4S*`4S*09`<00R2P4S+`9*209`=09`<@\U<093<@9*2@4Y4P0X2`9*2P0X
M0P4Y3@4Y304Y3P0X1P4Y4@4Y5`4Y4`4Y3`4Y409*3`93<09*2`\\,@93=`93
M>04_?04_?@93=@93>`0^)09=>`93>@93=093<P]"4`\U<`1$-`1$+@9=>P9=
M?`1$+P9=>09=>@9=+0<D*01*405-<@<D)P5-=0<D*`<D*P5-=`10:0<D+`<D
M*@]/5@5-<P<N>P<N?`55(010;`55(P55(@<N?@]5/`]5/0<X9`<X8@5;<P<X
M90<X8P5;=`5B,`5B+P1;30=`,`<N?05;=0=`+P5H,P5P-P5P.`=33P=8*@5U
M>@5U>04F:`4F9P8R)P8R*`4N/P0R3`0R309`>`9`>09`=@9`=P\U<P\U=0\U
M=@\U=P9`>P9`>@4S+09*3P9*3@\\,P\U<@94(094(@93?093?@94)`]"40]"
M4@94(P93?`5`(05`>P5&801$-@9>(01$-P9=?@9=?0](>@5-=@9>(@<D+01*
M4@<O)0<O(P<O)@<O(0<O)`55)`<O(@]5/@]5/P]50`<X9@<X9P1;3@=`,P5B
M,@5B,0=`,0=`,@1?>`='3`=.)0='30=34`1J305U>P=;9`5S4@=><P5W905W
M9`=@=@=C5@4A<@8H/08L008R*08X9P\\-`5`(@1*4P]/5P]/6`]:60]500]B
M8P]J6@4D3P8H/@8L108L1`4F:08X:`8X:@8X:09`?`9`?05`(P0^)@5&8@5&
M8P9>(P<D+@<O)P<O*`55)0='3@5L0P5Y,`4A2@0B?@\B6@\B6P8H0`8H/P0D
M3@\D50\D5@\D5P\D60\D6@4F;04F:@4F;`4F:P8L1P8L1@\G6@\G7`\G70\G
M7@\G7P4F0P8R+`4I;@4I;P4I;04I<`4I<08R+04I<P8R+P8X;08R+@4I=`8R
M*P4I<@\K40\K4@\K4P\K5`\K50\K5@\K5P\K6`\K60\K6@\K6P\K7`\K7@\K
M708X;P4N008X;@0M:04N0P0M:`8X;`4N0@\P,@\P,P\P-`\P-0\P-@\P-P\P
M.`\P.08X:P4N0`9!)@0R5@9!(04S,09!(@9!(P4S+@9!)04S,@4S,`4S+P9`
M?@9!)`\U>`\U>0\U>@\U>P\U?`4Y500X304Y5@0X4`9*409*4P4Y604Y6`4Y
M6@9*5@9*4`9*504Y5P9*4@\\.@\\-0\\-P\\.`\\.0\\.P\\/0\\/P\\0`9*
M5`\\-@4Y7`94+@94+`0^*P94)P94*P0^*@94*`94)094*094)@94+094*@94
M+P5`)`]"4P]"50]"5@]"5P94,`9>*05&9@5&909>*@9>*P9>+01$/09>)`1$
M/@5&9P1$.P9>+@9>+P9>)@9>)P](?`](?0](?@])(09>*`5&:09>,`9>)09>
M+`1*5@<D,P<D-P<D-01*501*5`5->0<D-`5-=P5->`<D,0<D,@<D,`<D+P<D
M-@<D.`<O*055)P<O*@10<`55)@10<P<O+`]50@]50P]51`]510<O*P<D.0<X
M:@1650165`<X:05;=@<X:`]:6@]:6P]:7`<X;`<X:P5B-05B-`5B-@=`-P='
M3P=`-05B-P=`-`=`-@]?,05B,P]?,@='4@5H-`='4`='40]E00=.)@1F1P5P
M.0=340]G9P=8*P5S4P]I4@5U?`=;90=D2@8L2`8R,`4I=04I=@8S3`9!)P\U
M?09!*`94,01$0`<O+0<X;01;40]:708E*@8E*0\D7`8L2P8L2@8L208R,08R
M,@\K7P4I=P4N1`\U?@4Y70\\0094,@<D.P<D.@=`.`=34@\A9P8B)`8E*P4A
M<P8E+`\B7@\D:00C(P8E+04D4`8E+P8E,0,D)`\B7`\D7P\D8`8E,`8L304D
M4@8H0@4D404D4P0D4`8H1@8H1P8L3`8H0P8H008H108H2`\D80\D7@\D8@\D
M8P\D9`\D90\D9@\D9P\G8P\G9`\G900G(P4F;P8R,P4F<@4F<P0G(08L5P0G
M)08L4`0G)`8L3@4F;@4F<`8L6`4F<08L6@8R-`8L5@8L7`0F?`8L4P\G8`\G
M80\G8@\G9P\G:`\G:0\G:@\G:P\G;0\K9`\K9P\K;`8L4@8L5`8L508L608L
M3P4I>`0I?`8R-@4J(@8R.P8R/@4I>00J(@0M<04J(04I?@8R.@8R0`4I>@8R
M004I?08X<`8R/08R/`0J(P0I?08R/P\K8`\K80\K8@\K8P\K90\K9@\K:`\K
M:0\K:@\K:P\K;0\K;@\P.@\P/0\P1`8R.`0J)`8R-08R-P4J(P\P5P0M;@4N
M208Y,`8Y+@4N2`4N1P8X?`4N2@8X<08X>P0M;00M;P8Y)08X=@8Y)@8Y*@8X
M=P8Y*08X?@8Y*`9!*@9!*00R9@8Y)`8Y+`4N108Y(P8X<P8Y*P8X>`8Y+P8Y
M,@9!1@\P.P\P/@\P/P\P0`\P00\P0@\P0P\P10\P1@\P1P\P2`\P2@\P2P\P
M3`\P30\P3@\P3P\P4`\P40\P4@\P4P\P5`\P50\P5@\P6`\P60\P6@8X>08Y
M(@8Y,00M<@8Y)P8X?08X=04N1@\V+00R704S0`0R6P0R:P9!-`9!.`9!/`0R
M:@9!0P0R809!-@0R909!-09!100R:04S,P9!,00R8`0R9P9*9`4S/P9!0@4S
M/@9!/P0R600R7P9!+`0E+P9!.P9!,`9*9@4S.`4S009*6`9*609!/@9!1`4S
M-@0R8@9!0`4S.P9!+P9!,@4S.@4S-00R;`0R;@4S-P9!/0\V(0\V(@\V(P\V
M)0\V)@\V)P\V*`\V*@\V+`\V+@\V+P\V,`\V,0\V,@\V-@\V-P\V.`\V.0\V
M.@\V.P\V/`\V/0\\0@\\2P\\30\\5P]"7P9*5P9!,P9!-P4S.09!.@9!.09!
M1P9!+09!+@4S-`4S/`8X>@9*8@9*<`0X5`4Y8P0X509*709*7P4Y9P4Y:@4Y
M8@942`4Y;`9*6@0X4P4S0@0X6`9*;`9*7`4Y:`9*<094-09*9P9*:`9*;@4Y
M8`94-`9*;P0^+`4Y7P4Y9@4Y904Y9`9*:@4Y8094,P9*<@4Y;09*80\\1`\\
M10\\1@\\2`\\20\\2@\\3@\\3P\\4`\\40\\4@\\4P\\5`\\50\\5@\\6`\\
M60\\6P\\7`9*:04Y:09*:P0X709*6P9*8`9*7@4Y:P]"<P94005`)00^0094
M.`0^-`94.P940P0^.P0^0P0^/@0^+@942@5`*05`)@0^0`9>,0940@0^.@5`
M+P5`+00^,09>,@0^0@5`+`5`+@94/@943`<D/`941P1$2P94/P941@94-P94
M-@5`*P5`*`0^/094/`94/0940`9410]"6`]"60]"6@]"6P]"7`]"70]"7@]"
M8`]"80]"8@]"90]"9@]"9P]":`]":0]":@]";`]";0]";@]";P]"<`]"<0]"
M<@]"=0])(@])/@5`*@941`0^-0943094.@942P])+P]":P]/;`94.0<D/01$
M5`1$1P1$2`1$3`5&:P1$3@5&:@5&=`5&=@1$101$4P9>1`5&;P9>009>.@1$
M401$4`5&=05&<@5&;0<D0`<D/P5&=P9>101$3P9>.09>0@5&<`5&<01$009>
M/05->@<D/@9>-`5&;@9>/P5&<P])(P]))`]))0]))@]))P])*`])*0])*P])
M+`])+0])+@]),`]),0])-`])-@])-P]).`]).0]).@])/`])/0])00])0@])
M0P]/;0<B:`1$0@9>/`9>0P9>-05&;`9>,P9>-P9>.`]).P9>-@])*@<D8@<D
M4@<D301*8`<D6@<D5`<D3`1*901*9P5.)0<D8P<D3@<D4`<D5@1*7`<D5P<D
M205.(0<D90<D1P<D1`1*9@5->P5.)`<D9`1*6P<D6P1*6@<D605-?@<D0P<D
M9P5.(P5-?0<D4P<D0@<Z:0<D10<D:`5.(@<D00<D7@<D9@5.)@5.*`5-?`1*
M7@<D7P<D2P<D405.)P<D7`]/60]/6@]/6P]/7`]/70]/7@]/7P]/8@]/8P]/
M9`]/90]/9@]/9P]/:`]/:@]/:P]/;P]/<`]/<0]/<@]/<P]/=`]/=0]/=@]/
M=P]/>`]/>P]/?`]540<D50<D8`<O,`1*8P<D1@<D70<D2`<D2@]52@]/?@])
M0`10?`55-055-`55*`55*055*P<O,P55,`<O1P<O0`<O.@10>0<O.010?@55
M,P<O/0<O,0<O-P<O1@<O.P<O.`<O0P<O-@<O,@55,055*@5;=P<O/`<O2055
M+`5;>055,@<O+P<O-`<O/@<O00]51@]52`]520]52P]53`]53P]54`]54@]5
M4P]55`]550]55P]:;055+P<O/P<O10<O2`<O2@<O+@<O1`11(0]/80]:9@]:
M7P54.@5;?`166@167P5;>@<X>@<X;@1;4@5;>P5;>`<X<`<X=@<X;P<X>0<X
M=`<X<P5B.`<X=0<X>P5;?0<X=P55-P-5.@<X>`]:8`]:80]:8@]:8P]:9`]:
M90]:9P]::0]::P]:<`<X<@5;?@<X?`<X<0]53@]:;`]:;P]51P]530]:7@<O
M-05B/P5B1@5B101;705B/05B.05B0@=`0`=`1@1;605B2P5B1`=`/`5B005B
M2@1;6`5B0P=`1P5B.P=`005B0`=`2`=`.@1;7P1;50=`10=`1`=`/@5B.@1;
M4P5B/`5B/@5B205B3`5B1P=`/P1;7`=`0@='7P5B30]?,P]?-0]?-@]?-P]?
M.0]?.@]?.P]?/`]?/0]?/@]?/P]?0`]?00]?0@]?0P]B9`]B90]B;`='7@=`
M/0=`.0=`0P=`.P]?-`]::@]:;@5B2`='90='7`='8@1??`1?>@='4P5H-@='
M5@='5`='6P='6@='505H-0='60='705L10='80]B9@]B9P]B:`]B:0]B:@]B
M;0]B;@]B;P]B<`]B<0='5P='8`='9@='9`='8P='6`5L1P5L2@5L2P=.*P1C
M601C70=.*@=.*05L2`1C7`=.+@1C5P1C6`1C5@=.+05P.P5L205L3`=.+P]E
M0@]E0P]E1`=.+`1F2`5P0`=35@5P/P5P/01F2P=35`5P/`=360=34P1F30=3
M7P5P00=350=36@]G:`]G:0]G:@]G:P]G;0]G;@]G;P=36P=37`=370=37@5P
M.@]G<`]I50=8+@=35P=8+P5S5`5P0@=8+05S50=8,01H<@=8,@]I4P]I5`=8
M,P=8,`=8+`5V(05V(@=;:0=;:`5U?@=;9P5U?0]J6P]J7`]J70=;:@=;9@=>
M=@5W9P=>=P1L<0=>=`5W9@=>=01L<@=@>0=@>`=@=P]L+P=B.01M6`5Z*P5Z
M*@1M601M=`5Z:05Z:@=C5P=D2P5[00]M)@=E7`5\/`8C+P8E,P0C)`0C)08E
M,@\B7P\B8`\B808E-`0D4P0D5`4D5`8H3`4D504D5P\D:P\D;`\D;0\D<`\D
M<@8H2P4F=`0G*`4F=0\G;P\G<`\G<0\G<P\G=`\G=0\G=@\G=P8L7P\G<@8L
M7@0G*@4D5@4J)08R3`4J)@8R1`4J)P8R2P8R1@\K;P\K<`\K<0\K<@\K<P\K
M=`\K=0\K=@\K=P\K>`\K>0\K>P\K?`\K?0\K?@\L(0\L(P0J*08R108R0P8R
M1P8Y.@4J*`8R2@\L(@8R204N3P4N3@8Y-@8Y.0\P:@0R;P8Y-P0M=`8Y-`4N
M2P\P70\P7@\P7P\P8`\P80\P8@\P8P\P9`\P90\P9@\P:`\P:0\P:P\P;`\P
M;@\P;P\P<`\P<0\P<@4N3`8Y-08Y.P8Y/`\P9P\P;08Y.`4N309!2P0R=`4S
M1`9!3P0R<P0R=09!3@9!5`9!409!309!3`9*<P9!4@9!4`9!4P\V)`\V/@\V
M/P\V0`\V00\V0P\V1`\V10\V1@\V1P\V20\V2@\V3`\V30\V3@\V4`9!209!
M2`\V2P4S0P4S109!500X:09*>`9!2@4Y<04Y;P9*?@9+(04Y;@9*=00X9@9*
M>@9*=`9*?00X8P4Y<`9*=P\\7@\\7P\\8`\\80\\8@\\8P\\9`\\9@\\9P\\
M:`\\:0\\:P\\;`\\;0\\;@\\;P\\<`\\<0\\<@\\=0\\=P\\>`\\>0\\>@\\
M>P\\?`\](09*>09*?`0X9P9*=@9*>P\\:@4Y<@5`-`946@946`5`,`945@94
M700^1P945P0^1`946P947@0^105`,@944P948P947P949`5`-0947`948@]"
M=@]">0]">P]"?`]"?0]#(0]#(@]#(P]#)0]#)@]#)P]#*`]#*0]#*@]#*P]#
M+0]#+@]#,`]#,P]#-`]#-0]#-@]#-P]#.`]#.0]#.@]#.P]#/0]#/@944094
M4@9450949@0^2@948094909:5`]#+`5`,P5`,0])5`9>409>4`5&?@9>2@5'
M(@1$505&?`5&>P5&>@<D<`<D:@9>1@5'(09>1P9>2`5&>09>2P9>3P])1`])
M10])1@])1P])20])2@])3`])30])3@])3P])4`])40])4@])4P])50])5@])
M5P])6@])6P])70])7@])8`])8@])8P])9`1$705&?09>3`9>4@9>209>30])
M7`948`]"?@]">@1*:P5.+`<D=`<D;0<D:05.*@<D;`<D<0<D<@<D=0<D:P5.
M*0].(@5.*P<D<P]0(P]0)`]0)@]0)P]0*`]0*0]0*@]0*P]0+@]0+P]0,0]0
M,@]0,P]0-`]0-0]0-P]0.`]0.0]0.@]0.P]0/`<D;@]0+`<J<0]0+0]0,`]0
M)0]0(@5.+@5.+09>3@11*@<O4@<O9@<O4`<O8`<O7@55.P11)P<O80<O8P<O
M50<D;P11*`<O5@<O9`<O9011)@<O6`<O5`11*0<O9P55.@55/`<O8@<O60<O
M70<O6@<O2P<O4P<O7`]560]56@]56P]57`]570]57@]57P]58`]580]58@]5
M8P]59@]59P]5:`]5:@]5:P]5;0]5;@]5<`]5<0]5<@]59055.`<O30<O3@<O
M6P<O7P<Q>@<O40<L>P]5;P55/055.0<O3`<D=@<O5P<Y(P1680<Y)055/@<Y
M*0<Y*`168P<O:`5<(0<X?05<)`5<(@]:<0]:<@]:=@]:=P]:>`]:>0]:>@]:
M>P]:?`]:?0]:?@];(0];(@];(P<X?@<Y)`<Y(@5<(P<Y(0]5:0=`3P1;8@=`
M3@5B3@=`2P=`4P=`40=`3`1;8P5B3P5B4`1;80=`5`=`2@=`4@]?1`]?1@]?
M10]?1P]?2`]?20]?2@]?3`]?30=`4`="(@=`50=`30=`20<Y*@]A=@]:=`]:
M=0=';`5H-P1@(0=';01@(@=':@]B=`]B=0]B=@]B=P=':0='9P=':P]?2P='
M:`]E105L3P=.,`=.,P=..P5L3@5L305L401@(P=.,@=..`1C8@1C8`=./`=.
M,0=.-0=.-P]E2`=.-`]E1@]E1P]E2@]E2P]E3`]E30]E3@=..0=.-@=..@5L
M4`=39`1C80=39@5P0P1F3P=39P=38@=38P=390]G<0]G<@]G<P]G=`]G=0=8
M-@5S5@1J3P=8-P=8.`=8-`]I5@]I5P]I6`=8-0=;)`=;;@=;<`=;;0=<1`=;
M;P=;;`=;:P5V(P]J8`=>>`]J7P5W:`=A(0=@?`=@?@=A.`=@>P=@?0=B.@5Z
M:P]L9`]L90=D30=D3`=D3@=E-P=F-`4A2P8C,`8H308H3@4D6`8L8@8L808L
M8P\G>`\G>08R3@4J*P4J*08R3P4J*@8R40\L)`\L)0\L)@8R308R4`4N404N
M4`\P<P9!5P9!5@9!6`\V400X:@9+(@9'0P9-7094:`94:09>4P5'(P9>5@9>
M509>5`<D>@5.+P<D=P<D>0<D>`<O:0<O:@55/P1690];)`];)0];)@]5<P=`
M5@5H.`]E3P]E4`=./0=3:`=;<0=>>0=A(@\D<P\D=`8L9`8L909!609!6@\]
M(@\](P94:@])905')`550`\A:`8K:P4J+`0J*P0M=P\P=`4Q;`9+(P94;`94
M:P5500<D>P<D?`550@8B)08C,08E-08H3P0G+08L9P8L9@8R4@0J+08R4P8R
M5`8Y/@0M>`\P=08Y/09!6P9!7@9!700R>`9!7`\V4@\V4P9+*`9+)`9+)@9+
M)P9+*09+)09-6`94;094;@]#/P9>6`9>60])9@<D?0]0/@<D?@550P5B4011
M+`<O:P<E(0551`<Y*P<Y+`5<)0='<`5L4@=8.0=;<@=C6`5[0@=D3P\A:08H
M404D608H4`0G+@8L:P8L:@8L:08L:`8R5@8R504J+08R5P4J+@4N4@0M>00M
M>P8Y008Y/P4S1@4S1P9!7P9!8@9!8`9+*P0X;09++@9+*@9++`9++04Y<P4Y
M=@4Y=`4Y=00X;@5`.`94;P0^305`-@5`-P94<`\])`5')09>6P9>7`9>6@])
M9P5.,@<E)05.,05.,`5.,P<E)`<E(@5.-`<E(P551@551P552`<O;05510<O
M;`5<)@169@];)P];*`5B4P5B4@5L4P=3:04C:`8Y0P8Y0@0X;P9++P\])0\]
M)@94<09>704A=0\B8P8E-@\B8@8H4P\D=08H4@8H5`4F>04G(@4F>`4F>P4F
M=@4F?08L;@0G,`4G(08L;`4F?@4G(P4F?`8L;0\G>P\G?`\G?@\H(04F>@8L
M;P8L<`4J,@4J,`4J+P8R7P8R7`4J,P4J,00J,`8R6@8R60\L*`\L*08R6P8R
M7@8R6`8R704J-`\G?04N6`4N5`4N5@4N5P4N508Y1`4N600R>P9!9P9!:`4S
M204Y=P0R?00R?`4S2P4S3`\V5`\V509!909!:09!9`4S2`0X<00X=`4Y?09+
M-`4Y>04Y>P4Y>`9+,@9+-0\])P\]*`9+,P9+,`9+,04Y>@4Y?`4S2@\]*09+
M-@5'*P5`/@5`/`0^4`9>9`94<P5')@94<@94=094=`]#0`]#005`/094=P5`
M.P1$805'+05'*`5'+@5'+`9>7P9>8P5')P5'*@9>9P9>8@9>805`.@9>9@])
M:`]):0]):@]):P5'+P5'*09>8`94=@9>90]);`5',`5.-@<E)@1*=`5..05.
M.@5..`1*<`5.-0]0/P<E*`<E)P<O<`5520553@<O<0552P5530552@553`<O
M;P<Y,`<Y+@5<)P16:`16:0<O;@<Y+P=`5P=`6`5H.@=3:@='<@='<P='<05H
M.0=./P5L5`5L505P10=3;`5P1`5P1@=8.@5S60=;=`5S6`=;=0=;<P5W:0=A
M(P]L,0=D4`\A/08C,@4A=P4A>`4B>`4B>P4B=P0C*`4B>@8E-P4B>04D7@4D
M7P0D6P0G-P8H6`0D6@4D6@8H7@4D6P8H6P4G+P8L<@0D5P4D704D7`8H6@8H
M608L<P\D=P8H5P8H7`8H708H5@0D6`8L>@4G*`8L>P4G+`8L>08L?`4G)P4G
M*@8L>`4G+04G)04G*04G)`8L=P0G.`4J-@8H508R8`4G*P8L=@\H(@8L?08L
M=`0G-04J-04J/@8R:`4J.08Y2P4J/08R808Y3`9!;`4J/`0J,04J.P8R9`4J
M.@8R9@0J,P4J0`8R8P4G)@4J-P4J.`\L*@\L+`\L+08R90\L*P4J/P8Y3@4N
M7@0S(08Y208Y300N)04N6P4N8`4N700N(P8Y108Y2@\P=P\P>`8Y2`4N6@0N
M)`8Y1P8Y3P4N7P8Y1@4S3@\P=@0S)`9!;@4S504Y?@4S4@9!<`9!<P4S3P9!
M;P9+.P0S)@4S4P9+.`9+-P4S4`9+.09!<09!<@9!=`9+.@4Z*`94>P4Z)@5`
M/P0X=04Z(@9+1`5`0`4Z)P0X=@4Z)04Z)`0X>`9+/P0^404Z(09+/`9+/@0^
M5P\]*@\]*P94>092<@94>@9+0`9+009+109+/04Z(P]#0P0^5@5`2`95(@5`
M1P0^5095)P5`2P95)`94?@94?095)@5`1@5`1`5`0P95(05`0@95*`5`2@5`
M000^6`5`2095)0]#10]#1@])<`]00`5`1095(P5`3`9>;05'.@9>:0<E*05'
M-P1$:P5'-05',P9>;`5'.P5'-@5'-`9><`1$;`5',0]);0<E*@]);P9>:P9>
M:`9>:@9>;P1*?05'/05'/`5'.05'.`9><05',@<E,01*>`1*>0<E,`5./`<E
M-`<O<P5.00<E+P<E*P5./@5.105..P5.1`5.0P5./0553P<O<@5./P5.0`5.
M1@<E+`<E+0]5=0554`<E+@<E,P]);@11,P5.0@555P11-055505540554@<O
M>011,0<O>`<O=P5<*`11-@554P555@<O=0<Y,@16;0<Y,0<O=@<E,@]5=P<E
M-0555`5<*@<Y,P5<*0='=P<Y-0<Y-`];*0];*@];*P];+`=`705B505B5`=`
M6@=`60=`7`1;:`=`6P]?3@]?3P5B5@1C9`='>`=.0`='=@='=`=.005L5@=.
M0@5P2`=3;05P1P1H=`5P20=8.P=;=@=;>`=;=P5W:@=>>@]K50=A)`=C60\H
M(P9+1@9><@4A3`8E.`8C,P8H7P4D800D700D7`8H808H8`\D>04D8`4G,`8M
M)00G/`4J00\H)0\H)@\H)P\H*`\H*08M(P\L0`\H)`8M(@\L/`8R:04J104J
M0@0J-@8R:P8O:0\L+P\L,`\L,0\L,P\L-`\L-0\L-@\L-P\L.`\L.@\L.P\L
M/08R:@8R;`\L/@\L/P\L+@4J1`4J0P8Y4P4S5@4N800N*08Y400N*`8Y4@8Y
M5`\P>0\P>@\P>P\P?`\P?0\P?@\Q(0\Q(P\Q)`\Q)0\Q)@8Y4`\V8P0S,08Y
M509!>@4S5P9!>P0S,@9!=P9!>`9!>0\Q(@\V5@\V6`\V7`\V7P\V8`\V80\V
M8@\V9`\V709!?`\V6P\V6@\V7@4S6`9!=@\]/@\]-`9+2P4Z*P4Z*@4Z+`95
M*00^6@5`30\].`0X?`9+209+3`\]+`\]+0\]+@\]+P\],`\],@\]-0\]-@\]
M-P\].0\].@\]/P]#4`9+3@95,@9+30\]0`9+2`9+2@95*@\],P\]/0\],04Z
M*095*P95,`0^6P95,095+P95+@5'/@]#1P]#2@]#3`]#30]#3@]#3P]#40]#
M4@]#4P]#5`]#50]#5P]#6`]#6@]#6P]#7`]#70]#7@]#7P]#8`]#80]#8@]#
M8P]#9095+`5`3P4Z+@]#2P]#2`5'/P95+0]#60])>@])>P]*)@<E.`9>=`5'
M00<E-@1$;05'0`9>=09>=P9>=@9><P])<0])<@])<P])=`])=0])=P])>`])
M>0])?`])?0])?@]*(0]*(@]*)`]*)0]*)P]**`]**05'0@-()@<E.0]*(P<E
M0`1*?@5.1P<O>P<E.@<O>@<E/`<E/P<E00<E0@]000]00@]00P]01`]010]0
M1@]02`]020]02@]02P]03`<E/05.2`<E.P5.20]5?`]6+@]01P<P(@<E/@55
M6`556P556011.P<P)`<O?0<O?@<O?`11/`<P(0]5>`]5>0]5>P]5?0]6(P]6
M)`]6)0]6)@]6)P]6*0]6+0]6+P<P)0<P(P<Y-@]6,`]6(0]6*`557`556@]6
M+`<Y.P<Y/05<+05<*P=`7@<Y.01;:@16;@16<`<Y.`];+@];+P];,`];,0];
M,@];,P];-`];-05<+`<Y.@<Y/`<Y-P=`7P5H/`1;:P5B5P1@)@=`8`1@*`]?
M40]?4P]?5`]?50]?5P]?60]?6@]?6P]?7`]?7P=`80=`8@]?4`]?4@]?6`]C
M(P='?`='>P5H/@='>@=.0P5H/0='>0]B?`]B?@]C(0]C(@1@*0]B>0]B>@]B
M?0=3;P5L5P1F4@]E4@]E4P]E5`]E50=.1`=3;@]?7@1F40=5?`1F4P=8/`]G
M=@=;>01J4@]I60]I6@5V)`]J80]J8P]K5@]J8@5Y,0=A)@=A)0]L,@5Z+`1N
M-`8M)@4J1P4J1@8R;0\L008R;@8Y5@4N8P4N9`8Y5P8Y6`0S-@4S604S6@\V
M904Z+P4Z,`9+3P\]009+4`0^7`5`4`5`40]#9@<E109>>`5'0P]**@5'1`<E
M1`<P)@11/05.2@]030<E0P11/@<Y/@5B6`]?8`1;;01F5`=3<`5P2@5V)0=;
M>@=>>P=B.P=B/`4D8@4G,00G/08M)P4J2`4J208R;P0J.P0J/@4N904N9P8Y
M7`4N9@\Q*08Y6P8Y608Y6@4S709"(@9!?@9")`4S7@9"(P4S7`\V9@\V:`0Y
M(@4Z,095-@0Y)P4Z-`4Z,P4S7P9+4@4Z,@4S6P9+409+4P0^9`5`4@95-P0^
M7@5`4P95,P95-00^7P95.`]#9P95-`5'1P9>?`5'109>>@1$<@9>>09>>P5'
M1@1+*`<E2@5.3`5.305.3@<E1@<E1P<E20<P)P16=`<P*`557P5580110`55
M8`557@16=@5<+@16=P<Y0`<Y/P5.2P1;<`5B6P5B6@=`9`5B60=`905H/P=.
M10=3<0=3<@1F5@5P2P1F50=3<P1H=@=8/05S6@5V*`5V)P=;>P5V)@=<:P5Z
M;`=E.`8C-`8M*`4G,P0G/@\H*P8R<`\L0P5`5`9>?0<P*P<P*0<P*@16>0=`
M9@5P3`8C-08E.08M*04G-`8M*@\L1`\L104J2@0J/P8R<08T>04N:09")@4S
M8`9")09")P\V:095.09+5`\]0P\]0@95.P]#:`95.@9>?@<E2P]**P16>@];
M-@]C)@=&;@]C)0=3=`8E.@\D>@4G-08M+@8Y704S80]*+`]?80='?0]L,P5S
M6P0D7P\D?`\D>P8H8P0G0@0E4P0G/P4G-@8M,08M,`8M,P\H+`\H+08M+P0J
M0@4J308R=`4J3`8R<P4J2P8R=@8R>@8R=P8Y904J3@8R>`8R=04N;@\L1@\L
M1P\L2`\L20\L2P\L3`\L30\L3@\L3P4J3P4N:@0N+@4N:P8Y808Y8`8Y8@8Y
M7P8Y8P\Q*@\Q*P\Q+`\Q+@0N,`\Q+04N;04N;`0S/@9"*`4S8P4S8@0S/09"
M+`9"+P9"*@9"+09"+@\V:P\V;`9"*P9"*09!:P0Y*P0Y*00Y*@9+5P9+60\V
M:@\]1@\]1P\]2`9+6`0Y+09+50\]1`\]10950`0^:@0^9P95/@95/P0^9@5`
M5@95/`950@5`50950P951`9500]#:0]#:@5`5P95/09?(P1$>@5'2@9?(@9?
M)09?*`]*+09?)@9?)`9?)P<E4`1++`<E3`<E3@<E30<E3P5.3P<E40]03P1+
M*P1110110P111@<P+`558@]6,@<L.P<Y005<,P<Y0P5<,016>P<Y0@5<-`];
M-P<\=@5<,`5<,@]6,01;<0='?@5H00=((P=.1@=((0=()`1@+0=((@=.2`=.
M1P=3=P]G=P=3=0=3=@]G4@=8/@1H=P=3>`=;?0]J9`=;?`=>?`=B/@=B/0=C
M6@=C7`=C6P=F*0=F-0=F1@8C-@8E.P\H+@0N,@4J4`0Y+@951@95109?*055
M8P<P+@<E4@=8/P4B?`4D9`4D900D8`8H9@8H9P8H908H:`0G108M-00G1`\H
M+P4G.`8M-@8R?00J2P8R?`8R>P4J4@4J5@0J1P0J2`4J4P0J104J5`4J404J
M508S)`\L4`8R?@\L408S(@8S(P8S(08Y:04N;P4N<P8Y;P4N<08Y<`8Y:@4N
M=@4N<@4N=08Y;08Y<08Y9@0N/04N=`8Y:`0N/@4N<`8Y;@\Q+P8Y9P8Y;`9"
M,09"-P4S:`9"-04S:P0S004S:@4S9@9",P0S1`4S:0\V;0\V;@\V;P9"-@9"
M.09"-`9".`\V<`9",`4S9P4S;`4Z-@4Z/P9+804Z-09+904Z.04Z.@4Z/`4Z
M-P9+8P9+7P4Z0`9+8@9+6P9+9@4Z/@9+7@0Y.09+709+8`9+9`\]20\]2@0Y
M-P9+7`0Y,04Z.`953`0^<@0^<`0^>P5`600^<00^=01$?00^>095205`6@5`
M7`5`8@0^?`951P5`8095305`905`8P5`6P4Z/05`7P5`7@952P952@0^?0]#
M:P]#;`952`953@5`6`5`9@5`705'6`5'4`1%)01%*P5'2P5'3P1%)@9?+P9?
M*@1%+@1%*@9?*P9?-`5'305'3@5'4P1%+`9?-P9?-05'6@9?+@1%)P1%(@5'
M405'4@9?,P5'3`5'5@9?,09?,`]*+@9?.`9?+`1%+09?,@9?-@5'501+.@1+
M-@1++01+.05.4P1+-`<E701+,@5.505.5P5.5`1+,0<E501+,`5.405.4@<E
M4P5'5P5.6`<E5`<E6P<E60]04`]040]04@]04P]05`<E5@<E6@<E7@5.5@5.
M4`112P5590<P+P<P,`55;`55;0113`111P55:`<P-0559@559P55:P<P,0<P
M-P55;@]6-`]6-0<P-`<P,P55:@<P,@<P.`<P.0559`<E5P16?`5<.055<`<Y
M4`11401%*016?@<Y1P5<-0<Y2`5</`5<.@5</0<Y3P=`:@55;P5<-P16?05<
M.`17(P<Y20<Y30<Y40<Y2P<Y1@<Y3`];.`<Y1`<Y10<Y3@5<.P5B7`5</@<Y
M2@1;>`5<0`5B8`=`:`5B90=`:05B805B9`1;=@5</P5B705B8@5B7@5B7P1;
M>@=`;05B8P=(*P1@,P=()P1@-`5H1`1@-0=()@5H0P5H0@1@-@]C)P1@,0=(
M*`=(*0=()0=(*@=`;`1C:@1C:P=.20=.30=.3`5L6`5L60=.3@=.2P=.2@5P
M405P4`5P3@1F5P=3>@5P3P=3>0]G>`5S7P5S7@5S70=<(@=;?@1J5@=<(05V
M*05W:P=>?0=>?@=A0@=A)P=B/P=B0`=B005Z;0=D40=E.00D8P8S)0\L4@8Y
M<P8Y<@\Q,`9".@\V<09+:09+9P4Z009+:`<E7P114P114@<P.@8E/`8E/04D
M9@4G.@4G.P4G.04G/`0J304J604J6`4J5P8S)P8S*`8S)@\L4P\L5`8S*04J
M6@8Y=`0N0@8Y=09"/`\Q,0\Q,@\Q,P\Q-0\Q-@\V=00S1@4S;@9".P\V<@\V
M<P\V=@9+:P9+;`9+:@\V=`5`:`5`9P954`0^?@953P5`:0]#;01%+P9?.09?
M.@]*,`]*,0]*,P]*-`]*,@1+/`<E8`<E8055<@<P/`55<0<P.P17)P17*`5<
M0@5<1`=`;@5<00<Y4@5B9@=`;P=`<`5H105H1@5H1P5H2`=(+`=.4`=.3P5B
M9P=80`=800]G>0=<(P1K<P=?(0=E.@4D9P4D:`8M.08M-P8M.`4G/08S*P4J
M6P0J3P8P-@8S*@4N=P4N>`8Y=@8Y>@4S;P0N1`8Y=P8Y>`8Y>00S204S<`9"
M/@\V>09"/00Y/`9+;04Z0@9+;P0Y.P\]2P9+;@\V>`5`:@5`;05`:P5`;`5`
M;@954P]#;@95400_(01%,01%,P9?/@]*-09?/05'7`9?/P9?.P9?/`<E8P5.
M6@5.6P5.7`<E8@55=@55>`55=`116`55=P55=0]6-@55<P<P/0<P/@<Y4P<P
M/P17*05B:`=`<@=`<P=`=`=`<05H2@5H20=(+01C;05L6P5L6@=.40=3?`1F
M7`=80@5W;`5W;0=C1`=E6`8H:0\D?00G204G/@0G1P8M.P4G/P4J7@4J7`4J
M708S+08S+`\L504N>08Z(08Z(P0N2`4N>@8Y?@8Y>P0N2@8Z(@\Q-P\Q.`8Z
M)`8Y?`8Y?00S3`4S<@0S2@9"/P\V>@\V>P\V?`\V?0\W(0\W(@9"0`9"008Z
M)09+=`9+<`4Z0P0Y/09+<@9+<P\]3`\]309+<0955`955@5`<`956`955P95
M50]#;P]#<`9?009?0`9?2P]*-@5.70<E9`<E90]050]05@]05P]06`]060]0
M6@1160<P1`116P<P0`<P1055>@55>0]6-P]6.`]6.0]6.@]6.P<P0P<P0017
M*P1<(P17*@<Y5`5<1P=`=05<1@];.P];/`<Y50<Y5@<V>05<10<P0@<Y5P1<
M(@1<(0=`=@=`>`=`=P]?8@=`>0=(+@5H2P=(+P]C*`]C*05L70=.4P5L7`=.
M50]E5@=.4@=.5`]G>P=81`5S8`=80P=810]G>@=?(@5V*@=?(P=B0@4B?0\B
M9P8H:@0D9`4D:@0D9@4D:P4D:0\D?@0G4`8M/`4G000G2P8M0`8M0@8M/@4G
M0@4G0P8M008M/P4G0`8M0P8M1`8S.08S-08S+@8S,@0J7@8S-@0J7`8S/`4J
M908S,P4J:00J6P8S+P8S.P4J8`4J9P4J:P4J804J:@4J:`4J8P4J;`8S,`4J
M7P4J9@4J8@4J9`\L5@\L6`8S-P8S.@8S-`0N4`4O)`,N6@0N3`4N>P8Z)@0N
M3@4O(@4N?`8Z*`0N2P8Z*04O(P8Z*@0N4P8Z+`4N?@4O)08Z*P\Q.0\Q.@\Q
M.P\Q/`\Q/08Z)P4O(04N?00N5`0S509"4P9"1@9"304S=`4S<P4S?00S5`9"
M1P9"1`9"0@4S>@4S>P4S=09"2@4S>`9"5`4S>09"0P9"3P9"2P9"4`\W)09"
M4@9"3`9"209"40\W)@4S?@9"109"3@4S=P4S?`4Z204Z3`9+>09,(P0S4P9+
M>`4Z2P9+?09,(04Z1@9,)@9+=P0Y3P4Z2@4Z2`4Z1`0Y3@5`<09,)05`?@0Y
M0`9+?@4Z309+>P4Z3@9,*`4Z104Z1P\]3P\]4`\]409+?`9,)P9+=@9,)`9,
M(@0Y1`0Y4`4Z3P0Y/@956P957@956@0_*@5`>`957`5`=P957P5`=095600_
M(P0_*`0_,00_+@5`>@958@5`=@0_+P0_)`959`5`>05`<@5`?`959@9570]#
M<0]#<@]#<P9+=0958P93-05`<P5`?05`=`95905'8`1%109?1`1%/@5'8P9?
M2`5'905'9@9?201+3P9?3@9?1@9?3P<E;`9?1P5'9P5'9`9?0P9?2@9?105'
M8@9?0@5'7P5'7@5'70<E9@]*-P]*.`]*.0]*.@]*.P]*/`]*/01%.@9?309?
M3`5':01%.P1+4`1+3`1+/@5.8@5.9P1+3@<E:P5.;`5.901+00<E<`1+0`11
M90<P305.9`56(05.9@<E;05.:@<E<@1+201+2P1+1@5.7P5.:P<E9P<E:`<E
M:@1+2@5.8P<E;@5.7@5.8055>P5.:05.:`<E:0]06P]07`]070<E;P1+2`56
M*@56*P117@56)056(P56)P55?0118P56*055?@56)@56)`118@<P1@<P3@<P
M3P<P2P<P1P5.;0119P55?`<P20]6/0<P40<P3`56+`119@5':`56*`1<*P5<
M2`5<2P17-017-@<P4@<Y7@<Y605<2@<Y6@5<3`<Y9`5<20=!(@<Y7P<Y8`<Y
M7017-P<Y8P5<3P<P2`5<3@<Y80<Y7`<Y6P];/@];/P];0`<Y8@<Y6`1<*`=!
M(P=`?@5B;@1<+`5B:P=`>P=`?`5B<`1<)`5B;`5B;P5B<05B:@]?8P]?9`=!
M)`=!)0=`?05B;0=`>@=!(05H3P5H3`5H401@/@5H4`1@.P5H5`5H3@=(,@1@
M.@=(-`1@/`1@/0=(,`5H30=(,05H4P5H4@]C*@=+70=(-0=(,P5L8`5L8@5L
M7@=.6`5L805L8P=.5P]E5P1C<@5L7P1C<P=.5@=4(@5P4@5P5`5P4P5P50=3
M?@=4(P=3?01H>05S8P=81@5S805S8@=81P5S901J60=4(05S9`=9,P5S9@5V
M*P=<)@1J6`=<)0=?)`1L=`=B0P=B10=B1`]L9@5[0P4G1`0J8`0J800N5@4O
M*`4O)P8Z+P8Z,`0S6`4T(@\W)P4Z4@0Y404Z4P4Z404Z504Z4`9,*04Z5`5!
M(P5!(@5!(09?409?4@1%1P1%2`5';`5':@5':P1%209?4`1%2P]-/P5.;@1+
M4@<E=05.;P1+40<E=`1+4P11:011:`11:@56+05B=0<Y905:=05<4`5B=`5B
M<P5B<@5H5P5H5@5H505H6`=(-@=(-P1J6@=F/P=F208F/P8H:P8H;`8S008S
M/P8S0`4J;@4O*@4O*P8Z,P\Q/P\Q0`8Z,08Z,@4O*04T(P4T)`0S7`9"609"
M5P4T)09"509"6P9"5@9"6@9"6`0Y4@9,+`\]4@9,*@\]4P5!)`0_,@95:00_
M-00_-`959P4Z5@0_-@]#=095:`5';05';@9?4P5';P5'<`]*/@<E>`1+5`<E
M=@<E=P]080<E>0<P5`11:P]6/P<P4P5<405<4@<Y9@<Y9P5S9P5V+`4B?@8E
M/@0D9P8H;04D;04D;`\E(0\E(@4G100G5`\H,`\H,0\H,@\H,P8M1P\H-00J
M900J8P8S104J<`\L60\L6@\L6P\L70\L7@\L7P\L80\L8P8S0P8S1`\L9`\L
M8`8S0@4J;P4J<00N8`4O,P8Z-`8S1@8Z-04O+P8Z.04O+`4O,04O,`0N6P0N
M704O-@4O,@4O-0\Q/@0N604O-P8Z.`\Q0@\Q0P\Q10\Q1@0N6@4O+08Z-P\Q
M2`\Q004T)@4O+@8Z-@4T+`4T*`9"809"7P4T,04T,`4T*@9"8`4T-`4T,@4O
M.`4T+@4T)P4T*04T+0\W*`\W*0\W*@\W*P\W+@\W+P\W,0\W,@\W,P9"7@9"
M7`9,+@\W,`4T*P\W+`9"8@4T+P4T,P9"704Z6`4Z7@4Z5P4Z6P0Y5@9,-00Y
M5P0Y504Z7`4Z709,,04Z6@4Z7P\]5`\]50\]5@\]5P9,-`9,,`9,,@4Z804Z
M8`5!*`95<00_-P5!*095:@95;`5!)095;@0_000_0P95;P95<@5!)@5!)P95
M;0]#=P]#>`]#>0]#>@]#>P]#?`]#?0]#?@]$(0]$(@]$(P]$)`]$)@95<`95
M<P9?6P5'>`9?5`<E?@5'>@9?5@1%4@5'<P5'<@9?5P5'>P9?609?6@5'=09?
M505'<05'?09?6`]*00]*0P]*1`]*10]*1@]*1P]*2`]*20]*2P]*3`]*30]*
M3P]*4`]*40]*4@1%5`]*0`5'=P5'?`5'>05'=`]09`1+6@5.<@5.<P<F(05.
M<`1%4`<F)05.=0<E?0]08@]08P]090]09@]0:`<F(@<E>@<F(P5.<05.=`<E
M?`]*2@<P6`56,056+@56,@<P5011<011<P56-`11<@<P5@<P6@11;P<P5P]6
M00]60@]60P56,`]61`56+P]610]61@]61P]620]62P]63`]6305<5@<Y:`5<
M5`<Y;P<Y:@5<4P17.@<Y:05<5017/0<Y;`17/`56-05<6`5<5P5<60];00];
M0@];0P];1`];10];1@];1P];2`];20<Y:P<Y;@]62@=!*05B=@5B>`=!)@=!
M*`5B=P1<,`5B>@=!)P5B>0=!*@]?90]?9@]?9P]?:`]?:01@0`5H6@5H60]C
M*P]C+`]C+0]C+@=(.@=(.`=(.0]C+P5L905L9@=.60=.6@5L9`5L9P1@00=.
M6P]E6@]E6P]E7`]E70=.705P5@5P5P]G?0=4)`1F8@]G?`5S:`=82`5S:0]I
M6P]I7`=8205S:@5V+@1J6P5V+05V+P]J90=<*`=<)P=?)@=?)0=?)P=B1@5Z
M+05Z;@1M=0=D4P=E.P5\0P8B)P8E0`8H;@\B:`8M2`\E)`8S1P8S20\H-@\H
M.`\H.0\H.@\H.P\H/0\H-P8Q6@4O.08Z.@0N8P4O.@8Z.P8S2P\L90\L9@\L
M9P\L:`\L:0\Q20\Q2P\Q3@8Z/@8Z/P8Z/08Z0`8Z/`\L:@0J:`4T-@8Z00\Q
M2@\Q3`\Q30\Q3P\Q4`\Q40\Q4@\Q4P\Q5`\W-P9"8P4T-09,.`4Z8@9,.09,
M.@9,/`4Z8P9,/09,.P9,-@9,-P\W-`\W-@\W.`\]6P\W-095=05!*P5!*@5!
M+`9,/P0_2`\]6`\]60\]6@\]7`\]70\]7@\]7P\]8@\]8P\]9`]$*`]$*@\]
M8095=`5((P9?7P9?8`1%5@9?8P9?80]$)P]$*0]$*P]$+`]$+0]$+@]$+P]$
M,`]$,0]$,@9?709?8@5((09?7@1+7P<F)@9?7`9?9`]*4P]*50]*5@]*5P]*
M6`]*6@<F*`56.`<P7`56-@<P7011=P56.056-P56.@<F*@<P6P]0:@]0:0]6
M40170P5<6@<Y<P171`<Y=@<Y=`<P7@]0:P]63@]63P]64`]64@<Y<0<Y=0<Y
M<@<Y<`];30];3P1<-`5B>P=!+`];2P];3`];3@];4`];40];4@=!*P1<,P5H
M6P=(/`=(/0]?:@]?:P5L:`1C=P]E7@=.7@=4)@=4)0]E7P1H?0=82@=82P=<
M*0]I70=<*@=<*P5W;@=<+`5W;P]J9P5Y,@=B20=B1P=C70]L9P\B:08S309"
M9`0Y6P9,0`95=@9?90<F+`<P7P<P8`=!+05S:P=A*`0A?@8E00\B:@8H;P\E
M)08H<`0G504G2`0G5P4G1P\H/@\H/P\H0`\H00\H0@8M2@8S408S5`4J=`4J
M<@0J<`4J=08S5@8S4`8S4@0J;08S3P4J<P8S5P\L:P\L;`\L;@\L;P\L<`8S
M508S4P8S3@4O/`4O.P8Z104O/08Z1@4O/@4J=@4T/`8Z1P\Q50\Q5@8Z0@8Z
M1`4T.@9":04T/P0S:`4T/09":`4T-P\W.@\W/`\W/0\W/@0S;`9"909":@0Y
M7P4Z9`0Y8`0Y7`9,009,0@9,109,1P0Y709,1`0_40\]90\]9P\]:04T/@\]
M9@5!-@5!+P95>095=P95>@5!,`5!+05!,@5!-`5!.`5!,P0_3@96(05!+@95
M>P95?@95?`]$,P]$-`]$-0]$-@]$-P]$.`]$.0]$.@95>`95?05!-P5!-05(
M*`9?:05%+05(+09?:`9?9@9?:@1%7`5(+@5(*09?;@9?;P5(*P5()P5(+`9?
M<`5(*@9?9P]*8`]*6P]*7`]*70]*7@]*7P]*80]*8@]*8P]*909?;09?;`5.
M>P5.>`5.>@<F,P<F,`5.>01+:0<F-`<F,0<F.`5(+P<F+P56105.?`5.?01+
M9P1+:@<F-0]0;`]0;@]0;P]0<`]0<0]0<@<F+@<F-@<F-P11>P<P;056/056
M0`<P:056/`56/P56/@11?@56.P560P<P8P<P9`560@<P8@561@5<6P561P<P
M:P<P:@<P;`<P80]65`]650<P90<P9P<P:`561`56005<7@5<805<8@5<7P5<
M7`5<70172@<Y=P5<9`171@5<8`<Y>@];5`];50];5@];5P];6`];6@<Y>`];
M4P562`<Y>05<8P]64P5B?05C)@5C)`5C(05C(@5C)0=!,`5B?@=!+P5C(P]?
M;`]?;0]?;@]?;P]?<`]?<0]?<@5B?`5H7@1@0P5H7`1@1`1@1P=(/P1@1@5H
M70=.8@=(00=(/@]C,`=(0`5L:P1C>@1C>`5L:@=.8`1<.`5L:05L;`=.7P=.
M80]E8`]E80]E8P=.8P5L;0=4*`=4)P5P6`=4*0=8305S;`=83@5V,`5V,0=8
M3P5W<`=<+0=<+@=?*`=><0]K5P]K6`1L=P5Y,P]L-`1L>`5Z+@5[805[8@8C
M-P4D;P4D<`0G600G6@0G6`8M308M3`8M3P,J108M2P\H0P0J=`8S608S6P8S
M6`4J=P0J<P4J>04J>`8S6@8S7`8S704J>@\L<0\L<@\L<P4O/P0N9@0N:P0N
M:`4O0P4O0@4O008Z3`0N:00N:@0N9P8Z2@8Z2`4O0`4O1`\Q6`\Q60\Q6@8Z
M2P8Z204T1`4T0P9";`9":P9";04T000S;@4T0@4T0`9";@\W0`\W00\W0@\W
M0P\W1`4Z<@0Y9@4Z=`9,3@9,2@0Y:09,4@4Z:04Z;P4Z<09,4`4Z9P9,404Z
M:`9,2P4Z:@0Y:`4Z<P9,3`4Z<`9,204Z9@4Z;09,3P4Z;@4Z:P9,30\]:P5!
M.@96*05!/`5!.P5!/@96(@96)`4Z;`5!/05!/P96*`96*P5!0`96)@96)0]$
M.P]$/0]$/@]$/P]$0`96(P96*@97)@1%809?=P5(,@9?=@9?<@9?=`9?<P5(
M,09?>0]*9@5(,P9?<0]$/`<F.P5/(05/)P5/*@5(,`<F.@5/*P5/)@5/(@5/
M+`5/)0<F.05.?@5/*`5/)`5/*0<G+@1+;0563P564012(P564`12)@562012
M*`<P<`562@563`562P564P5630565`<P;@563@5<905650]65@]65P]66`]6
M60]66@<P<05<:@5<9P<Z(0173@5<:0<Y?`<Y?0<Y>P5<9@<Y?@<P<@5<:`];
M6P5C*`5C)P]?=`1@2@=(1`=(0P5H7P=(0@=.9`=.9@5H8`1C>P5L;@=4+0=.
M9P=.90]E9`5P6P=4*P1F9P1F9@5P60=4+`5P6@]H(0]E905V,@=<+P5W<0=A
M*@]K60=?*05Y-`=B2@5[8P8H<@8H<04G204G2@0J=0\L=`\L>`0N;P4O1P4O
M2`0N;`4O1@4O100N;@\Q7`\Q70\Q7@\Q7P\Q80\Q8@8Z308Z3@9"<@0S<P9"
M<09"<P9"<`0S=`\W10\W1P4T1P\W2`0Y:P9,504Z=04Z=P4Z=@4Z>`9,5`\]
M;0\];@\];P\]<`0_5@0_6`5!0@0_6096+`5!0096+096+@]$00]$0@]$0P5!
M0P5(-`9?>@5(-01%8@]*9P]*:`]*:@]*:0<F/P1+;@5/+0]0<P]0=`]0=0<F
M/0]67`]66P1740<P=`565@];7`5<;`5=8P<Z(@5<:P5C*@<Z(P]?=0=!,05C
M*0=.:`=4+@]E9@=(105P7`]H(@=84`]I7@]J:`=A*P\E)@4G2P8M4`4G304G
M3`4J?`4J?04J>P8S7P8S7@4J?@\L>0\L>@\L>P\L?`\L?0\I)`4O3@4O200N
M=`4O2@4O3`4O308Z4`4O404O3P4O2P8Z3P8Z404O4`4O4@\Q8P\Q9`\Q90\Q
M9@\Q9P\Q:`\Q:0\Q:@0N=@9"=`9">@4T2@0S>04T309"=P4T3`9"?`0S=04T
M3@9"=04O4P4T209">09">P4T4`4T409">`\W20\W2@\W2P\W3`\W3@\W3P4Z
M?`4[(@4Z>P4Z?@0Y;`0Y;@9,6@4T2P0Y<P4[(04Z>@0Y>00Y=P0Y<`9,700Y
M>`9,5P4[)09,609,7`4T3P4Z?0\]<0\]<@\]<P\]=`\]=0\]=@\]>`\]>0\]
M>@\]=P4[(P5!5`5!2`5!3P0_7`5!305!100_9`0_905!4`0_7P4Z>096,`5!
M1@5!505!2P5!4@5!1`5!205!3`96-`96,@96-P96.@96,P96-@96.`9?>P5!
M4P5!405!3@5!1P96,09,6`96-096.0]$1`]$1@]$1P]$2`]$20]$2@]$2P]$
M3`]$30]$3@]$3P]$4`96+P]!/@5(105!5@1%;`5(0P9@)P1%9P9??`9??05(
M/`5(.P5(0@1%;P9@*`5(0`9@)@5(.`5(.09@)09@(05(.@5(005(-P5(/09@
M(@5!2@5(1P9??@5(/@9@)`5(/P1%<05(1`]*:P]*;`]*;0]*;@]*;P]*<`]*
M<P]*=`]*=0]*=@]*=P]*>`]*>0]*>@]*<@]*<05/.@<F20<F2P5/1`1,+P5/
M,P<F40<F2@5//@1+<01+;P5/005/+P5/-`5/0P<F0@5/0`5/,0120`5/.05/
M0@1+<@1,*01,(P1+?05/.`5/-P5//`<F3@5(2`5/-0<F4`<F1P<F1`5//P<F
M0`<F4P1,)`<F3P1+?`<F3`5//0<F10<F0P5/+@<F2`<F1@5/1@]0>`<F4@]0
M=P]0>@]0>P]0?`]0?0]0?@]1(@]1)`]1*0]1)0]1)@]1)P]1*@569`120012
M/@566`567@569@<Q*@567`12+@567012+`56:`<F00<Q)012,@569P12,0<Q
M*012/`<P?@<Q)@12,`568`<P>P12/P567P5660<P>@<Q*`12*@565P<Q)`12
M-05690<P?0568@12,P<Q*P<P=0<Q)P5/,`568P566@<P>`<Q(P<P=@5680]6
M<@566P<P?`<P=P<Q(@]670]67@]68`]680]68@]68P]69`]690]69@]69P]6
M:`]6:0]6:@]6:P]6;`]6;0]6;@]6;P]6<`]6<0]6<P<P>0]0>05=)`5=(017
M705<=05=+05<>0177`178P179P<Z+`5=*P178`5=(@5<<`5=(P5<<@5=,05<
M>P5=*@5<=P5=-`<Z)`5<=@5<?`5=)@179`5=)P<Z*05C0@5=+`5<>@<Z+P<Z
M*`5<;P5=,@5=*05<<P<Z*P5=+@5<<05<;@5=*`179@1</`5=,P5<>`5=+P5=
M)0<Q(05<=`<Z)P<Z)@<Z)0<Z+0];70];7@];8`];80];8@];8P];9`];9@];
M9P];:`];:0<Z*@<Z+@17:`];9017805C2P5C1P5=-01<4@5C105C.`5C,P1<
M1P5C2@5C0`-83P5C+@1<3@1<105C0P5C.05C3`1</0=!.P5C1@5C,`5C-P1<
M/@1</P5C2`=!.05C-05C,@5C/P=!-05C+`=!-@1<00=!,P1<4P5C/@=!.`5C
M/0=!.@=!/@=!-`5C,01<305C-@5C.@5C1`5C205C/`5C+0=!0@=!005C.P5C
M*P5C+P=!,@=!-P]?=@]?=P]?>`]?>0]?>@]?>P]??`]??0]??@]@(0]@(P]@
M)`]@)0=!0`=!/0];:@]C-@]C-P]@(@5H:@5H;P=(3@1@60=(3`5H8P1@5`1@
M501@405H:01@3P1@4`=(2`1@4@5H8@1@6`1@30=(1P5H;05H:`5H<`5H;`5H
M:P5H905H9`5H9P=(1@=(2@5H805H<0=(20]C,0]C,P]C-`]C-0]C.`]C.0]C
M.@]C.P]C/`=(2P=(305L?`5L>P5L=@1@5P5L=`=.;`5L>@1C?0=.=`1D(@5L
M>`5L<P1F<`=.:@5L;P5L=05L<0=.:0=.=05L=P=.;0=.;@5L<@=.;P=4.`=.
M<0=.<`=.<@=.<P]E:`]E:0=.:P5P9`5P:`5P:01F<01F:P5P9@5P:P=4+P5P
M7@5P8P5P8`1D(05P9P5P7P5L<`=4-05P:@5P70=4,05P901I)P5P;`=4-@=4
M,`=4-`]H(P]H)`]H)0]H)@]H)P]H*`]H*0=4,P=4.0=4,@=8501I)`1I(P5S
M<`5S;@5P8@5S<0=84@5P;0=8405S=`1I)05S;0=85`=4-P5S=@5S<P5S;P5S
M=05S<@=85@]I7P]I8`]I80]I8@=84P=9-`1J7@5V,P=<,05V-`1J7P1J8`1J
M8@=<,`5V-@=<,@5V-0=<-@=<-0]J:0=<,P=<-P=<-`5W<@=?*P=?+@5W=`5W
M=0=?+05V-P=?+`=?*@5W<P=?,01K=P]K6@]K6P]K7`=?+P5Y-0=A+`=A+@=A
M,01L>0=A+P=?,`=A+05Z,05Z+P5Z,`=A,`]L3P]L30=C7@=C7P]L:`=C8`5[
M1`5[9`]M)P=D5`1N3@5[?`5\*P4D<0\E)P4G3@8M40\H108S804K(@8S8`4K
M(P\L?@\M(@8Z4@4O5`8Z5@4O508Z5`4O5@\Q:P\Q;`\Q;0\Q;@8Z4P8Z500S
M?@4T500T)`4T5`0T(04T6`4T4P4T5@4T5P0T(P4T6@4T4@9"?09,8P9#(0\W
M4`\W409"?@\W4@4[)@0Y>@9,809,7@9,904[*`0Z(09,9`9,7P\]?`\]?@\^
M(@\]>P9,8@5!5P0_:`96/05!605!6@4[)P5!6`96/P96/@0Y?@5!6P5!705!
M7`9600]$4@]$4P]$50]$5@96.P]$5`960`]$409@+05(2@9@*P9@+@5(3`1%
M<P96/`9@,P9@,@5(2P9@,`5(205(30]*?`]*?0]*?@]+(0]+(@]+(P]+)0]+
M)@]+*`]+*0]+*@]++09@+P]++`9@*09@*@]+)`<F6`<F5`1,-@5/2P<F50<F
M601,,P5/2@5/3`5/4`5(3@5/3P5/30<F6P<F5@5/201,-`5/3@1,,@<F6@5/
M2`5/1P]1*P]1+`]1+0]1+P56;@56;`5=/`120P56:P120@<Q+P<Q,`56;P<Q
M+`56:@56;056<`]6=`]6=0<Q+@5=-@5=.`<Z,`5=.05=-P5=.@5=.P<Z,@<Z
M-`<Z-0<Z,0];:P];;`];;0];;P];<`];<0];<@17;`5C4@=!101<5P5C4P5C
M3P=(5@5C405=/0=!1@5C4`=.>`5C30=!0P]@)P]@*`]@*0];;@5H=`=(3P=(
M4`1@7@1@7`5H<P5P;@=(4@=(4P=!2`1@7P1<6`5H=0=!1P5H<@]C/@=(40=(
M5`=(50]C/P=.=P5L?@=.=@]E:@]E:P1F<P1F<@5P;P=4/0=4/`]H*@]H*P=4
M.P5S=P=85P5S>`1J8P1J9`=<.`]J:@5V.`=<.0=?,@5W=P5W=@5Y.`=A,P5Y
M-P5Y-@=A,@=B3`1M705Z,@=B2P5Z,P=C8@=C805[?0=F-@4G3P8M4@4G4`\H
M1P\H2`4G404K)@8S8@8S904K)`4K)08S9P8S8P4K)P\M(P8S:`8Z6P8Z5P0N
M>08Z8P0N>P8Z708Z7`8Z7P4O6@0N>@0O)`8Z9`8Z600O(P8Z7@0O(@8Z8`8Z
M6`4O608Z804O6`4O5P8Z6@\Q<0\Q<@\Q<P\Q=`\Q=0\Q=@\Q=P0O)@8Z8@4T
M7P4T700T,@0T*`0T*@9#*`0T+P4T7@0T,09#*04T6P0T+`9#*P9#*@9#)09#
M(P9#)`4T7`\W6`\W60\W6@\W6P9#)P9#+`\W504[,04[,`4[+@4[,@9,;00Z
M(P9,9@9,;`0Z(@0Z)`9,;@9#)@9,9P9,<`9,:`4[+09,:@9,:09,;P4[*@4[
M*04[*P\^)0\^)@\^)P\^*`\^*0\^*@\^*P\^+`\^+0\^+@9,:P4[+P962P96
M0@5!7P5!7@0_;`961`0_;0962`96100_:05!805!8`960P96200Z)00_:P96
M1@5!8@963`96300_<@962@]$5P]$6`]$60]$6@]$6P]$7`]$70]$7@]$7P]$
M8`]$80]$8@961P0_<`1%>`5(4`1%=@5(4@9@/P9@/@5(5@1%>@5(501%=P9@
M.09@0P9@0@9@-@1%?05(3P5!8P9@005(409@/`9@-`5(4P5(5P9@0`9@.P1&
M(@9@.`]++@]++P]+,`]+,0]+,@]+,P]+-`]+-0]+-@]+-P9@-09@-P9@/01,
M.`1,0P<F8`1,0@1,.P5/6P5/60122`5/6`5/705/501,1@5/6@<F;`<F7@<F
M9`5/7`5/4@<F80<F9@5/5P1,001,.0<F70<F90<F7`<F9P9@.@<F;0<F:P5/
M405/5@5/7@]1,`]1,0]1,@]1,P]1-`]1-0]1.`]1.0]1.@]1/0]1/@]1/P<F
M8@<F:`<F7P<F8P<Q1@121@<Q0P<Q1`122@<Q0`<Q/056=`56=@<Q,0<Q0@<Q
M,@<Z-@<Q,P<Q-@56=056=P56<P5=10121056<056<@122P<Q.@<Q-P<Q.`<Q
M001230<Q-056>0<Q-`<Q10<Q.P56>`<Q/P<Q/@<Q.0<Q/`]6=@]6=P]6>`]6
M>0]6>@]6>P]6?`]6?0]6?@<Z1`<Z0P5=0P5=0`17<0<Z-P5=00<Z0@17;P<Z
M.@5=1`5=/@<Z/@<Z.P<Z/`<Z0`5=0@<Z00<Z/05=1P];<P];=`];=0];=P];
M>`];>0];>@];>P];?`];?0];?@]<(0]<(@<Z/P<Z.`1<9`1<7`=!3@1<8P1<
M70=!30=!5`1<8017<`=!205C505C6`5C5P=!2P=!405C5@=!2@=!3P=!4@=!
M3`=!5P=!50=!4`=!6P5C6@=!5@]@*@]@*P]@+`]@+0]@+@]@+P]@,`]@,0]@
M,@5C60=!7`=!6@=!6`=!4P1@9`1@90=(7P1@:0=(9P5H=@=(9`1@9P=(9@1@
M:P5H>01@8`5H>@=(80='2P1@80=(705H=P=(8P=(6P=(8@5H>`=(60=(6@=(
M8`=(7@]C0`]C00]C0P]C1`]C10=*<P=(7`=(901@:@=.?0=.?`5M(P5M(01D
M)0=.?@=/(P=.>P=40@=(6`5M)`=/)`=/)@=.>@1F>0=/(@=.>0=/)0]E;`]E
M;0]E;@]E<`]E<0=/(05P<@1F=0=40P5P<P1F>`1F=@1F=P=87@=/)P=4/P=4
M/@=400]H+`]H+0]H+@]H+P1F=`=40`5P<0=41`5S>P=8605S?`5S>01I*05V
M.@=8705S>@=86P]I8P]I9`]I90]I9@=86@=87`1I2P1J9P=87P=<.@=<.P1J
M:`1J:01K>@5W>`=?-P=?-0]K70=?-@=?.`5Y.@=?-`5Y.0=A-`=B3P=B3@=C
M8P]L:0=C90=C9`=D505[90]M,`=E=08E0@0J>`4K*`0O*`8Z9@4O6P4T809#
M+04[-`9#+P9#+@9,=`0Z*09,<P4[,P\^+P964`963P0_=`1&)`9@105(6`9@
M1`<F;@]+.0]+.@]+.P<F<`1,1P]10`]100<F;P56>P56>@]7(@]7(05=20<Z
M105=2`]:6`]<(P]<)`=!70=!7@]@,P=(:`1@;`]C1@5P=`1D)P1F>@=4101J
M:@=</`]J:P=?.@=?.05Z-`=F*@8B*08B*`0D:@8E1`8E108H<P\A?`8E0P\E
M*`\E*@8M4P8S:@0G708S:08M5`0G7@8H=`0D:P8S:P0J>@0J?`\E5@4K*0\H
M204G4@8Z9P8Z:`8Z:04O7P8Z;`8Z:@0O+`0O*P8S;@8S;`8S;P9#-0\I.04O
M709#,`9#,09#,@9#-`9#-@\Q>08S;08V>@4K*@0J?09#,P9,=P9#-P8Z;09,
M=@9#.`4O7@4T8@\W7`9,=04[-@4[-00Z+`9,>`\^,`964@5!9P965`9,>@5!
M9`5!9@964P96509,>0965@\^,09640]$8P9@1@9@2`9@209@2@9@2P9@3`9@
M309@4`5(6P<F=09@3@5(6@965P5(609@3P9@1P]+/`<F<0<F<@<F<P<F=`5/
M8@5/7P9@4@<F=@5/8`5/809@40]10@]10P<E<P<Q1P<Q2`<Q3`<Q2056?`<Q
M2P1240<Z3@<Q2@<Q305/8P56?0124`<F=P<F>`<Z1P<Z2`<Z2P5=2@<Q3@17
M=`5C6P<Z3`<Z30]<)0]7(P=!7P=!8`=!8@=!9`1<9P1<9@5C7`=!8P=(:0<Z
M2@5C7@5H>P=(;`1@;@=(:@=(:P=/*`=/*0=/*@=/*P5M)05M)P=/+`5M)@5M
M*`=41@=/+05W>@1K?`=?.P5W>P5W>0=A-0=B4`=C9@=D5@=E/`0D;`0C+`\A
M8`8M5@4G4P8M50\M)`8S<08S<`0J?@\H2P8Z;@8Z;P9#.P8Z<P8Z<@8Z<08Z
M<`9#.@\Q>@\Q>P9#/04T9`0Z+@9#/@0T.04T90\W704T8P9#.0\W7@\W7P9#
M/P4[.04[-P9,?00Z+P9-(04[.`9,?@9,?`9-(@9'(0966@5!:`966P966`5!
M:09660967`5!:@\^,P\^-`5(7`9@4P9@505(709@5`5/9`1,2@<F>P<F?`1,
M2P<Q3P<F>@1,2`57(056?@124@]7)0<Q4`17>`17=@5=2P<Z4`<Z3P<Z4@]<
M)@125`<Z405C701<:05C7P=!:0=!:@1<;0=!9P=!:`=!9@]7)`]@-`]@-01<
M;`5H?`=(<`5V.P=(;P=/+@=(;@5M*0=/+P=/,`=/,0=/,@=!905P=0=41P=4
M2`5S?0=88`=</@=</0=A-@=C9P=E7@8M5P8S=08S<@8S=@4K*P0K(@0K(00K
M)`8S=`0K(P\M)0\M)@8S<P0O,P8Z=@4O804O8P4O8`0O,00O-@0O-08Z=04O
M8@0O-`0O,@8Z=P\O8P\O9`0O-P\Q?`4T9@9#009#0`9#0@9#0P9#1`9#1@9#
M1P0T/P9#104[.P0Z,@9-)@9-)P9-+04[/00Z-@9-+@9-*`9-)09-+P9-,`4[
M/`9-*@9-+`9-*P\^-0\^-@9-*05!;@5!:P0_>09670967@967P5!;05!;`]$
M9`9-)`5(905(7@9@5P5(7P5(8P5(8`5(9`5(805(8@9@5@5(9@]+/0]+/@]+
M/P]+0`5/:@5/:P<F?@5/:`1,3`5/;`5/90<F?05/9P]11@9@605/9@<G)`<G
M)0<G(01,3@<G(@1,30<G(P]11`]110<Q40<Q4P57)0<Q5@<Q4@<Q5`125P57
M(P57)@57)`5/:057(@<Q5057)P]7)@17>0<Z5`5=3`<Z50=(<05=30<Z4P]<
M)P]<*`5C8`1<;@=!<05=3@1<;P=!;0=!;P=!;`=!<`=!;@]@-@]@-P=!:P1@
M<`5H?@5H?0=(<@=/-0=/-@]E<@=/,P1F?`=420=42P=/-`=42@=88@=88P=8
M808E1@8M6`8H=00G7P0G8`8Z>`0T0`4K+`\W8`\W809#2`9-,0<G)@<Q6`<Q
M5P]K7@8M608M6@4A>0\H3`0O.04T9P4[/@5!;P9@6@<G)P<G*05(9P<Q6@<Q
M60<Z5@4C(08M6P\H308S=P\M)P8S>`\Q?@4T:`\W8@9#200Z-P4[004[0`0_
M>P968`9@7`5(;`5(:`5(;05(:@5(:05(:P1&,0]$909@6P5/;P5/<`5/<05/
M;05/;@<G*@57*057*`126`1260<Q7`<Q70<Q6P]11P5=3P17?`<Z6@<Z5P<Z
M6`]7*05C8017?@=!<@<Z60=(=05C8@=!=`=!<P]<*0]<*@=(=`5I(0=(<P1F
M?@=43`1J;`5W?`5Y.P4G504G5`8M7@\H3@\H3P8M704K+P4K+04K+@0O/`8Z
M?@0O.P8Z>@4O9`8[(@\R(0\R)`\R)@\R)P8Z>P\R(@8Z?08Z?`8[(P8Z>0\R
M)04O909#2P0T0P0T0@0T1`9#304T:09#3P9#3@9#3`9#2@\W8P\W9`\W90\W
M9@4[0@9-,P9--`4[0P9--0\^-P\^.`\^.0\^.@\^/`\^/0\^/@\^/P\^0`9-
M,@\^.P968@969@5!<05!<@968096:P96:0969P5!<P96:`969`96:@968P]$
M9@]$9P96905(<`5(<05(;@1,4`9@7@5(<@5(;P5(<P]+00]+0@]+0P]+1`]+
M10]+1@]+1P]+2`]+2@]+2P]+3`9@7P5/<@<G+`5/=0<G+P5/=`5/<P1,405/
M=P<G*P<G,`5/=@]12`]120]12@]12P]13`]130]13@]13P<G+057+`57+P57
M*P57+057+@<Q80<Q7P<Q7@]7*@]7*P]7+`]7+0]7+@]7+P<Q8`57*@5=4`5=
M405=4@<Z6P18)018)@5=5`5=4P]<+`<Z70<Z7`-88P=!=P5C9@5C8P1<<@=!
M>05=50=!>`5C9`5C90=!=0]@.`]@.0]@.@=!=@]<*P]C1P=(=@5I(@5I(P=(
M>`=(=P]C2`]C20=/.0]E<P]E=`]E=0=/.`=/-P5P=@]H,`]H,0=430=43@5S
M?@=89`1J;0]J;`]K7P]L-@]L4`4A>@8M7P4K,`9#4`9--@9(:@96;@9@8@9@
M80<G,0]14`<Q8@=/.@4C)04C(P8M8`8M808E2`\B;`\B;04C)`4C(@4D<P4D
M<@8H>08H>`8H=P8H=@8S>P8S>@8S>04G6@4G7@8M9`0O0P8M;08M;@8M8@4G
M708M9@4G604G5P8M:P4G6P0G:P8M:`8M;P\H4`\H40\H4P\H5`8M;`0F9`8M
M908M9P4G7`8M:@8M8P8[)P8[)00O/04G5@8[)@8T+00K+04K-`8T*`4K,04K
M.`8T*00K+@9#5`8T)P0K*P8T*P0K,`8T)04K-@8T)@4K-P4K,@0O2`4K-08S
M?`8T(08T(@8T)`\M*@\M+P\W9P\W:`8S?@8T+P8T+`8T*@8T,`8T+@9#4P9#
M4@\M*P9#509#5@8[,`9#40\M+04O9P0O/@0T100O108[,@4O;`0O1`8[+@4O
M;@8[*@4O<`4[1`4O;P8[*04O9@8[*P0O0`9-.P4O:0\M*0\R*`\R*0\R+0\^
M3`4O:`4N)`8[+P8[+08[+`8[,P9-.@9-.`9-.09--P8T(P4O:P4O<04O:@4T
M=`9#6P9#604T:P0T3@4T;`0O0@4T<00T1@0T505!=`0T5`9#5P4T;@9#7P0T
M204T=04T=@9#8`9#7@0T3P4T<@9#809#8@\W:0\W:P9#7`9#7096;P96<`96
M<04T<P4T;P4T<`9-0P4[2`9-/04[109-2P9-0@0Z/`4[2@9-3P9-/`9@904[
M1P9-4`96=00Z2`4[3`9-509-3@9-3`9-4P4[1@5(=09-/@9-1P9-2@\^00\^
M1`\^1@\^1P\^2`\^20\^2@\^2P9-1`9-20\[8P9-309-009-4@9-/P9-0`9@
M8P9@9P9@9`\^104[209-1@4T;04[2P4[3@4[3P9-404[409-109@:`9@9@5!
M?01`(05")@5"(05!=05!>05")P96?00_?@96<@0Z1@5"(@5!>`96=P1`)`96
M>01`(@97(096<P5"*096=`96>`5"(P96?`5!>P5!>@5")05")`96>@5!=@96
M?@]$:0]$:@]$:P]$;`]$;0]$;P]$<01`*P97(P97(@]$<`<G,@<G,P96>P5!
M?@5!?`1&1`5(>P1&3`1&0P5)(P9@:@5(>@1&2@5))`5)(01&205(=P5(?01&
M.@1&2P5(>`9@<09@;`5(=@9@;@5(>09@;05(?`<Q8P5)(@1&2`9@:P]+30]+
M3@]+3P]+40]+4@]+50]+4P9@<`9=7`5!=P5(?@1,4P5/>P<G-`1,5P<G.P5/
M>@1,60<Z8`<G-P5/?`<G-01,6@<Z7@5/>`<G.`]140]14@]14P]15`<G-@<G
M.0<G.@<Z7P9@:05/>0]<-0<Q;`57-P57,@12:`127057,0127P<Q9P<Q;@57
M-057-@12905/?057-`<Q90<Q;057.0<Q:@5I)`128`<Q;P]7,0]7,P]7,@<G
M/`<Q:`<Q:0<Q9`<Q9@<Q:P=!>@=(>0=!>P57.@57,`57.P57.`57,P="(05=
M6@5=60<Z8@18+@18*@18*05=6`5=5@1@<0=(>P5=7@<Z90]<+@]<+P]<,0]<
M,@]<,P]<-`]<-@]<,`<W?@<Z8P=(>@=(?05=70<Z805=7`5=5P<Z9`=(?@1<
M=05C:@5C9P5C:05C;`=!?`5C;@=!?@5C:P="(P5C:`5M*@5C;P]@.P]@/`]@
M/0]@0`]@00=!?0=";01<<P1@<@=)(P=)*05I)05I)@5C;0=))`]C2@=)*`=)
M*@]C3`]C30=)(@=))@=))0=))P=)(0]C2P=)*P=//05M+@5M+01D*P1D*05M
M*P]E=@=//`=/.P1G)@=43P5P=P=<0`=5.@=</P1I,01I+P=890]H,P=<005V
M/0=<0P=<10=<1@5V/`=<0@1J;@=<1P=<2`=?/05W?0=?/@5Y/`=D5P5Z;P5[
M108H?`0D<0\J208[-`\R+P9-5@9-5P]+6`]+60]15@9@<P]<-P=")0]@0@5P
M>0]H-`]I9P=E/05\+`8E2@8H?@0D<@8H?08M<`4K.@8T,@\M,`4O<@8[-@0O
M20\R,`8[-P8[-09#9@9#90\W;0\W;@9-609-6@97)`5))0]+6@1,8`1,805/
M?@]15P<G/012:057/`<Z9@5=8`5=7P]<.`]@0P5I)P1@=05M,0]C3@=)+`5M
M+P5M,`=B408I(08M<08M<@8[.@\M,08[.`8[.04T=P0T5@9-6P5"*@5))@]+
M6P50(0<G/@]16`50(@<Q<012:@57/0]7-`18+P5C<`5C<00D=`8E2P8C9`8M
M<P8M=`\M,@0O2P8T,P8[.P8[008[/08[/`0O3`8[/P8[0`9#:04T>`8[/@9#
M:`9#:P9#:@4[4@9-7`4[4P5))P97*`97)P97)09@=`9@>@9@=09@=@50(P<G
M/P9@=P9@>P9@>`<G0`<G00<G0@9@>05)*`50)`50)0<G0P<G1`<Q<@<G10<G
M1@]7-0<Q=`<Q<P5=8@<Q=P<Q=@<Q=05=805=9`<Z9P="*`=")P5=901<=P="
M)@]@1`]@10=)+05C<P5C<@=)+@=//P5I*`5M,P5M-`5M-0=//@=)+P]C3P5I
M*0=/0`=/005P>@]E>`]H-0]H-P=89@]H-@=89P=<205W?@=A-P5Y/05Y/P5Y
M/@]L:@=E/@=E/P=F4P5\4`\E*P8T-`0O3@0O308[0@8[0P8[1`4O<P4O=`9#
M;`9#;09!?09-8`9-7P9-80\^4`5)*01&305%4P1&3@97*0]+7`9@?`9@?@9@
M?0<G1P]160<G20<G2`<Q>`57/@<Q>0<Z:`]@1@5C=`="*@="*05M-@5P>P=<
M2@5V/@50)@50)P]@1P=/0@=<2P=?/P=A.05Z<`4D=`0G<00G<`8M=P8M=@8M
M=04G7P0K,00K-00K-`8T-08T-P8T-@8[2@4O=08[208[104O=@0O4@0O408[
M1@8[1P8[2`4T>@0T600T6P9#<@4T>P9#;@9#;P\W<04T>0\W<`\W<@4[5`9-
M909-9`0T6@0Z4@0Z4`0Z400Z4P9-9@5"*P97+`5"+`97*@]$<@97*P97+097
M+@5"+@9A)P5)+05)*P1&4@9A(@9A)@]+7@]+7P]+709A(P5)*@50+P1,9P1,
M9@50+@50*P50+`50,`50*`<G3P<G3050,0<G2@<G3`<G3@<G2P50+050*050
M*@570@57/P570P<Q?`570`<R(0<Q?0<R(P5700<R(@]7-@<Q?@<Q>P<Z:@18
M,05=;`5=9@5=:05=:`5=:@5=:P1<>05C>P="+`5C=05C>@5C?05C>01<>@1<
M>P5C=@5C=P5C?`1<>`="+0="*P5C>`=),`5I+05I+`5I*P5I*@=),0]C4`=)
M,@5M-P=/0P5P?05P?`=44@5T(05T(@1I,@=8:`=44`=4401J;P=<3`=A.P=A
M.@=B4@5Z<01N3P8T.`\W<P4[/P\^40]16@]<.0=/1`4T?`4T?09#<P4T?@\^
M4@97+P97,`97,09A*0]+8`9A*@9A*`<G40<G4`<G4@]16P]17`]170571`57
M10<R)0<R)`5M.05M.`=/10]L-P4A>P8C.`0C+@8E4`8E408M>`8E3@4C)@8E
M30\B;P\B<`\B;@8E3`0D=P0D>`0D?`8I(@0D>@8I)08I(P8I)`8I)@\E+`\E
M+0\E+@\E+P\E,`\E,08M>P0G?`0G=P0G>04G8@0G?00G>`0G=04G8`8M?`4G
M800G=`8[2P8G3`8N(04G9`0G=@8M>@8M?@8[308[3`\H5P\H6`\H60\H6@\H
M6P\H70\H7@\H7P\H8`\H80\H8@\H9`8M>00K.P0K-P0K.`0K.04K/P8T0P8T
M.P0K/`8T008T/04K/08T.08T0`8T/@8T0@8T108T1@4K.P4K/@4K/`\M,P\M
M-0\M-P\M.`\M.0\M.@\M.P\M/`\M-@8S/@8T/P\M-`8M?09-:`\J4@4O?`0O
M5@0O5P0O8@4O>`4O>@4O?@0O5`4O=P4P(P0O6P4P)P0O6`0O904P)`0O8`8[
M7@8[7P4P)08[804P(@0O9@8[608[6`9-9P9$(@8[504O?08[5`8[408[3P8[
M6@8[7`4O>P8[5P4P)@4O>08[4P8[6P8[708[8@\R,P\R-0\R-@\R-P\R.`\R
M.0\R.P\R/`\R/0\R/P\R0`\R0@\R0P\R1`\R10\R1P\R2`\R20\R2@\R2P8[
M4`\R1@\R3`\R/@4U*P4U+@4U)P0T<`4U+`0T800T;@0T:`9$,@0T<@0T=09$
M)@9#>P9$(P4U(P9#>09#=00T8`4U,@9#=`9$(09$.`0T9`9$-@9..@9$-`8[
M8`9->`0T7P4U(00T:P9#=P9$)`4U,`9$+P9$-09$+@9$*04U+P9$,P9#>`9$
M)P4U,05"+P97,@97,P9$,`9$,09#?@4U(@4U,P9$*@4U*04U+04U)@9.-P9$
M.09$.@9#?`9#>@\W=`\W=0\W=@\W=P\W>0\W>P\W?`\W?0\W?@\X(0\X(@\X
M)`\X)0\X)@\X)P\X*`\X*0\X*@\X*P\X+`\X+0\X+@\X+P\X,`\X,0\X,@\X
M,P\X-`\X-04[709#?04U*`9$)0\W>@9$+09$-P\X(P4U)04[500Z504[:04[
M:@4[8@4[;`4[;04[8P0Z709->@9-<@9.*P9-<`9-:P4[7P4[9P4[:`9->P9-
M>04[7@4[;@4[:P0T:@0Z5P0Z6@0Z6`0Z8@4[6@0Z5`9-:09.-00Z8P9-:@4[
M9`9-?`9.-@9-?09.+P9.,`0Z:P9.)@0Z:09.(P4[7`9.*`9-=09.+09-=`9.
M(@9.,09.*04[909A,@9A+09A+@4[5P9.)`9-;P9.+@5)+@9-<P9.+`9-=P9.
M)09-;09.*@0Z:@4[8`4[6P9-=@9..`9A*P4[9@9A+P4[809.-`9A,09A,`9-
M;`9-?@9,>P4[6`9-;@9-<09.,P9..0\^4P\^50\^5@\^6`\^6@\^6P\^7`\^
M70\^7@\^7P\^8`\^80\^8P\^9`\^90\^:`\^:0\^:@\^;0\^;P\^<`\^<0\^
M<@\^=`\^=0\^=@\^=P\^>`\^>0\^>@\^>P\^?`\^?0\^?@9A+`4[609.(0\^
M8@\^5`\^;@\^<P1`0P97-`971@5"3@97.@97.P5"-`1`/09720976@1`0`1`
M0@5"10977@5".@1`-P1`-`9700978P5",P974097505"0P972@1`.`1`.P5"
M-@970P1`/`1`105"001`305"3P1`/@5"1@97705"/P1`,P1`,097901`/P97
M0@5"2`5"0@5".`5"/@97.`974P973P970`979P5"/097.0979`97-P5"4`97
M3@971097/`5"205"305".P5"1P974@978`977`972`975@5".01`.0975P5"
M,`5"0`5",@5"2@97/P1`-01`2P973`5"-05",0971P976`<G4P97805"/`97
M1`975`97-@978@979@97601`3@5"1`5"2P97-097/@972P9730976P977P]$
M<P]$=0]$=@]$=P]$>`]$>0]$>@]$>P]$?`]$?0]$?@]%(0]%(@]%(P]%)`]%
M)0]%)@]%)P]%*`]%*0]%*@]%*P]%+`]%+@]%+P]%,`]%,05"3`1`2@97/09.
M,@\^5P5"-P1&9@9A8`5)109A,P9A0P5)2P1&8P9A5@1&5@9A101&609A/`5)
M009A2@1&509A4@5)/09A0`9A605)205)1@9A3`5).@1&6@9A.09A509A309A
M/P5)1`5).05),`1&8@9A001&7@9A-@1&701&:P1&6P5)/P<G6`9A-P5),@5)
M-P5),05)2`50.P1&7P5)0P9A.`1&:`9A4`5).`9A5P9A1@9A.P5)0`5)-@<R
M)P5)+P5)-`9A1P9A209A2P9A3@9A6@9A709A7@]+80]+8@]+8P]+9@]+:`]+
M:0]+:@]+:P]+;`]+;0]+;@]+;P]+<`]+<0]+<@]+<P]+=`]+=0]+=@]+>`]+
M>0]+>@]+?`]+?0]+?@],(0],(@],(P],)0],)@],)P],*`],*0],*@9A2`5)
M0@9A4P9A4097:`5)2@9A7`9A7P9A6P9A.@9A-09A0@9A/0974`]+9`]+9P9A
M5`1&:@1&5`5)-05)30<R)@5),P9A805)1P5)3`571@]+>P5)/@<G;`1,?@50
M,@1,:01,?`<H(050-0<H)`<G=P<G7`50.0<G:0<G>`<G>0<G:@<G<P50.@<G
M;P1,=050/0500@<G8`<H(@500`50/P571P5000502P<G:P<G=@<G60<G<@<G
M90502`50-P1,>P<G5`<G6P<G9`<G8P<G9P50,P<G9@<G?0<G7@50/@<G5@50
M-`502@<G?`<G8@<G70<G;@1,=@50205010<G=`576`1-(@500P<G50<G6@<G
M7P<G<`<G<0<H(P]17@]17P]18`]18@]18P]19@]19P]1:`]1:0]1:@]1;`]1
M;0]1;@]1;P]1<`]1<@]1=0]1=P1-(P<G>@501`<G?@<G=0<G:`]1<0]180]1
M:P50-@<G5P501P50/`9A-`="+@],)`<R4013+0<R,@13*@13-`<R4P572013
M*P5770<R0P575`12<013,`5740576P<R/`12=0576@572P577P<R,P578013
M+P<R*`5730573P<R3`5750578@<R/0<R.P503`12<`572`577@<R10<R2P<R
M00579`578`<H)0<G>P<R4@5=>@13)@<R+@13*0<R-@574P13*`12=`50.`<R
M+P574@<R.`575@573`<R+0<R5P<R3@13+@577`<R*@12>`<R.0="+P<R*P<R
M5013,@<R0@<R-0<R/P]7/@]7/P]70`]700572@574`575P<R+`<R-`<R-P<R
M/@<R0`<R1P<R20<R30<R3P<R5`<R60<R6@]7-P]7.`]7.0]7.@]7.P]7/`]7
M/0]70@]70P]71`]720]73`]730]73@]73P]74`]740]74@]74P]75`]75@]7
M5P]76`]760]76@]76P]77`<R,0]71012?0<R.@<R6`<R4`5790573@<R,`<R
M*0<R2`]72@<R5@578P5760<R1@<Z=@18.@18/P<Z;@=".P<Z>`182`182057
M9@5==05=?05=<P<[*P<[+P5=;P182@18-P<Z>P18105>(0<Z?`<[(P<[,P5=
M?@5>)0<[,05>(@5=;@5=>`<Z?@5=?`<Z<P<[)`<[*@5=>P182P5=;05>(P18
M00<[,`5==P181@5=<05>)`<[)05==@<Z<`<Z=0=".0<Z:P<Z;`<[-0<Z?018
M1P<[+@<Z<@<Z=P=)-`<Z<0<[(@<[*0<R2@<Z>0<[(0<[-P5==`5030180P=)
M-05=<`5=<@<Z;0<[)P<[*`<[+`<[-`]<.@]<.P]</`]</0]</@]<0`]<00]<
M0@]<0P]<1`]<10]<1@]<1P]<20]<2@]<2P]<3`]<3P]<4`18.0<Z>@<[+0<[
M-@<Z=`]<2`]</P]<3@]750]C6P5D+`="2P1=)`="3`5D(@1=)05>)@5D+P="
M2`5D)05C?@=",`5D(05D*05D-@5D.0="-@5D,P="1@1=(@5>)P5D.`5D)@5D
M,`="/05D)`5D+@="301=,`5D,01=+@1=)@1=*@5D-`5D,@="/@=/1@=".@="
M-P1=+P=)1`5D*P=",P="10="201=+0<[)@=",@="-`="-0="/P="0@="1`="
M2@="3@="3P]@2`]@20]@2@]@2P]@3`]@3P]@4`]@40]@4@]@4P]@5`]@50]@
M5@]@5P]@6`]@60]@6@]@6P]@7`]@7@]@7P1=)P="0`5D)P="00=),P5D-05D
M*@1=*0="1P5D(P5D*`5D-P="0P=",05I/@5I+P=/705I,`5I.@5I-@1@?01@
M>05I/P5I-P=).`=)105I.P5I-01@?`5I+@5M0@=)0P5I.`=)1@5I.0=)00=)
M5`=)40=)/`5I,P5I/0=)2P=)3@=)/@=)/0=)0@=)1P=/5`=)30=).0=)3`=)
M2@=/1P5I-`5I,@1@=@5I/`=)20=)0`=)/P=)-@=)-P=).@=)2`=)4`=)4@]C
M40]C4@]C5`]C50]C5@]C5P]C6`]C60]C6@]C7`]C70]C7@]C7P]C8`]C80]C
M8@]C8P]C9`]C90]C9@]C9P]C:`]C:0=)3P=/7@=/50=/3@5M0`5M1P=/805M
M005M1`1D.0=/6`5M1@1D-05M/P5P?@=/7P5M.P=/40=/4`=/3`5M/@5M10=/
M301D,0=/9P5M/`=/2P=/4P=/8@=/6P=).P=/905M0P1D+@=/605M/0=/9@=/
M6@5I,0=49P=8:0=/205M.@5M2`=/4@=/5@=/5P=/7`=/8P=/9`]E>0]E>@]E
M>P]E?`]E?0]E?@]F(0]F(@]F(P]F)`]F)0]F)@]F)P]F*`]F*0]F*@]F*P]F
M+`=/2@=/2`=/8`=48P1I-05Q*`=49@=47P5Q)`1G+`1G*@=4601G+@5Q(@=4
M9`5Q)0=4901G*05M205Q)P=46P=44P5Q)@=48@=45P=450=48`1G+05Q(P5Q
M*05Q*@=45`=47`=/3P=46@=8=@5Q(0=45@=470=480]H.`]H.@]H.P]H/`]H
M/0]H/@]H/P]H00]H0@]H0P]H1`]H0`=46`5T)`1I-@5T)05T)P5T*`=8<`5T
M*01I.P1I.@=8=P=8=0=8;0=<4P5T(P5T)@=8;P1I.`1I.0=8;@1I-`=8<P=8
M:P=8>`=8:@=8;`=8<0=8=`]I:`]I:P]I;`=<3P=<6@1J=05V0`1J=`5V/P1J
M<01J<P1J<@1J<`5V0P=<40=<6P5V0@5Y0`=<505V1`=<5P=<6`=<30=<4`5V
M00=<5@=<5`=<4@=<60]J;0]J;@]J;P=<3@]I:@5X(P5X(@5X(0=?0`5X)`=?
M0@=?1@=?0P=?1`=?20=?00=?1P5Y0@]K8`]K80]K8P=?10=?2`5Y0P=B505Y
M00=B4P=A/@=A/0=A/`]L.`]L.0=A/P5Z-05Z-@=B60=B5P=B5@=B6`=B5`]L
M40=B2`1M>@=C:`5Z<@1M7P1M?`]L:P]L;05[1@1N-0=D6`=D605\20=E0`5[
M9@=E8`=E=@5\3P5\/0=E7P\H900K/P8T208T2`\R3@4U-@4U-`0T=P0T=@9$
M000T>`9$0@9$0`9$/P8[8P9./`4[<09./0\_(@\_(P\_)`5"505"405"4@97
M:P97:@97:05)3P9A8@9A9@1&;P9A909A9P9A8P9A9`5)4`],*P],+`1&;@<H
M*0<H)P<R7P503@<H)@<H*`]1>0<F*057:@57:P57:`57:013-0579P<R8`<R
M7`<R7013.`13-P57;0<R7@]770]77@]77P57;`<R6P183`<[.0]<40]<4@]<
M4P="405D/01=,P="4`1=,0="4@5D/`]@8`=)5@=)501@?@=)5P=/:05M2@=/
M:@=,)@5Q+`=/:`5Q*P5P30=4:@=4:05T*@=<)`1N.`4D=08I*00H(@8N)0\H
M9@\H9P\H:0\H:@0K0P8T2P0K0`0K0@8T2@4K0`8T308T3`8T3@\M/0\M/P\M
M0@\M0P\M1`\M000K004P,`8[:`4P+`4P,P8[9P4P+04P,@8[9@0O;`0O:@0O
M;@4P+@8[<`4P*08[:P4P,04P*`8[:@4P+P4P-`8[;@8[9`4P*P8[90\R3P8[
M;`8[;04P*@8[;P4U-P0T?09$104U.`4U.04U.@4U0`0U(@\X/00U(P9$3`4U
M/`0U(04U/09$1@4U009$200U)`0T?@9$1P9$2@9$1`9$2P9$30\X-@\X-P\X
M.`\X.0\X.P\X/`\X/@\X/P\X0`4U/@9$3@0U)09$0P4U/P4U.P4[<P9.0`\_
M*`0Z<P9.2`4\*`4[>`4[=04[=P4[>@4\(P4[?09.209./@9.0P4[=@4\)P9.
M0@9.2P9.2@4[?`9./P4[>04\(09.309.1`9.1097;@4\)04[?@97>`4\)`9.
M3`9.1P4\(@4[<@9.00\_)0\_)@\_)P\_*00Z=P97<`97;P1`6@1`7`97=`1`
M5`5"6`5"6P5"5@1`401`4P5"7`5"7@5"6@5"5P1`7@1`4`97<@97<P97;`97
M;09A:`97<097=05"60]%,@]%,P]%-`]%-0]%-@]%-P]%.`]%.097=@=):P97
M=P97>05)405)5@5)6P5)5P5)7`1'(05)501&?09B(P5)7P1&=P5)601&=`9A
M=@9A:@9A=01'(@5)7@9A:P9A<05)5`9A?`5)705)6`9A>P9B(05)8`9A=`9A
M?09A;05)805)8@9A<@9B(@5)6@9A;`9A>09A>@9A<`5)4@9A;@5)4P9A<P],
M+0],+@],,`],,0],,@9A>`1`6`9A?@9A;P1-+0<H0P504P1-+@1-*P<H.`1-
M-`507P<H-P<H+`5040<H*P<H-0<H/P505P1-,@1-*@<H0`<H-`505@<H.P<H
M,0<H/@57;@1-+`1-*0507`506@504`5060506`<H*@506P1&>@504@507@50
M701--0<H1@<H,`<H+0<H1`<H.0<H10<H/`<H+P9A=P<H-@<H/0505`1-)P50
M3P]1>@]1>P]1?@]2(0]2(@]2(P]2)0]2*`]2*0]2*@]2*P<H,P<H00<H.@]2
M)P<H,@],+P57<`131057=@57=013.@57=`57<0<R;@<R?057=P132`57>P13
M20130`130@57?`<R;013.P<R9P13/P<R?`57>057;P58(057<@<[.@57>`<R
M:0131@57>@<R<`<S(@57<P<R9`57?@<R=`131P508`<R:P<R9057?0<R=@13
M0P<R>P<S)`<R8@<R=P<R8P<R>`<R;P<R?@<R<@<R:`<S(P]78`]780]78P]7
M9`]790]79@<R>0<R:@<R>@<R<0<R9@<R;`18605>*05>+`1850<[4@<[1`18
M8`187`<[2`<[0@<[50187@<[1@<H1P184`5>,0<[4`<[/P1870<[3P5>*P5>
M+P<[4P186@<[1P<[005>,P184P<[0`1840<[/@<[5`5>*@<[/`<[.P<[2018
M6P5>+05>+@<[10]<5`]<50]<5@]<5P]<6`]<60]<6@]<7`<[0P<[2P<[3@<[
M40<[/05>*`<[2@<[3`5>,`1=/01=-P="50="80="6`=":`5D0P5D1`5>-`1=
M.`5D4`="601=-@5D101=-01=.@5D/P5D0@5D301=-`5D2@="5@5D/@5D005D
M2P="5P="7`="6P5D0`=";P=":P5D3P=";@5D205D3`=":05D1@=";`5D1P="
M90="8@="70="8P="5`="6@="4P="7@=":@="9@]@8@]@9`]@90]@9@]@:`]@
M:0]@:@="9`1=/`="9P]@9P]@805D3@1A*`=):@=)60=)8`=);`=)6@=):0=)
M;01A(P5I0@5I0`=)8@=)9P=)905I1`=)70=):`=)9`=)9@=/:P=)80=);@=)
M;P=)8P5I10=)7`=)7P=)6`]C:P]C;`]C;0]C;P]C<`]C<0]C<@]C<P]C=`]C
M=0=)6P1A(@1A)P=)7@="<`=/=0=/>@5M30=/;`1D0@5M3`5M40=/>`=/<`5M
M4`=/=`5M4@5M4P=/<P5M3@=/<@=/=P=/<0=/;05M3P=/;P=4=P=/;@=/>P]F
M+0]F+@]F+P]F,`]F,0=/=@1G+P1G-`=4:P=4<`5Q+P=4=0=4;@=4<05Q+@=4
M<P5Q+05Q,`=4;`1G,P=4;P1G-01G,0=4<@5Q,@=4>`=/>0=4=`1G,@=4>05Q
M,05Q,P=4=@]H10]H1@]H1P]H2`]H20=4;05T+@1I/`5T+`5T*P=9(P=8?`5T
M+05T,05T,`=8>@5T,P5T-05T,@=8>01I/0=9)@=9*`=9)P=8?@=9(05T-`5T
M-@=9)`=9*05T+P=8?0=8>P]I;0]I;@5V1@1J=@1J=P=<705V1P1J>0=<7P=<
M7`5V2`=<8@5V10=?2@=<8`1J>@=<805V2@=9(@5V20]J<`]J<0]J<@5X+`=?
M2P1K?@5X*P5X*0=?3`5X)@1L(@=?305X*@5X*`1L)`5X+05X)P5Y1`1L?@5Y
M2`5Y2@1L(0=A0`5Y1@=A1`=A0P=A105Y1P5Y20=A005Y10=B70=B6P=B7@=B
M7`=B7P=C;@=C;`5Z<P=C:P=C;P=B6@=C:0=C<0=C:@=C<`=C;0=D7`1N.@=D
M705[1P5[2`=D6@=D6P5[9P=E00=E0@5[:`1N4`=E8@=E80]M,0=F*P4G908N
M)P8N)@0K1`8[<@4P-08[=08[=`\X009.3@9.4`5"7P97?`97>@97?097>P5)
M905)8P5)9`9B)@9B)`<H2`5080<H20<H2@9B)058(P58)`58(@<S)0<S)@5>
M-P5>-@]<701=/@1=/P="<0="<P1=0`="<@5I1@5M5`=/?`=4>@=9*P=9*@=?
M3@=E8P0H(P8N*`0H)`8T3P8T4`4K00\M104P-@8[=P8[=@4P-P9$3P4\*09.
M4P9.4@\_*@\_*P9.4098(P98(01`7P98(@97?@]%.@1')`508@9B)P9B*`18
M80<[5@]<7@1=00="=`=)<`=4>P=<9`4G9@8N*08N*@8N*P4K0P8T400K100K
M1P4K108T4P4K1`\H:P8T4@4K0@4K1@8[?04P/`0O<08\(08\)04P/P8\)@8\
M)P0O<`8[>04P0`8[>P4P.`8\(@8[?`8\(P8[?@4P.P8[>@8[>`4P.@\R4`8\
M)`8\*`8\*0\M2`\M20\R4@0U*`4\,@0U*P0Z?`4U1@0U*09$6`4U1P4U2@4U
M1`4U104U0P9$609$6@4U0@9$4P9$509$5`9$409$4`9$5P9$4@\M1@\X104U
M2`9$5@4U204\,09.6P9.604\+@9.5P4\+P4\,P0Z?@9.6`9.5`0Z?09.5@4\
M,`4\+04\*P5"9`4\*@\X1`\_+@9.509.6@9.7`4\+`\X0P5":@5"8@5"9@1`
M905":P5"8P5"9P1`8P5"905":098+P1`9`98*@98*`98,`5":`5"8`98)`98
M)P98+0\_+`\_+0\_+P\_,`]%.P98)@98,098)098*05"80]%/@1',`1'+`9B
M+09B,P1'*05)9@5):01'*`5):`4\-`9B-`5):@9B*P9B*09B*@9B,@9B,05)
M9P9B+P5):P9B,`9B+`1',P9B-09B+@],-`],-@],-P1'+P]%/`]%/P509@<H
M5`1-0050:0<H5P1',@<H5@50901-.`<H50<S*`509P<H6@<H2P1-101-.P1-
M/0<H4P1-1`1-0P508P<H6`<H4@<H3`509`<H3P50:`<H40<H4`<H30],-0]2
M+0<H3@<H6058+`58*P<S*P58)P58*@<S)P1340<S*0135`<[8@58*058*`<S
M*@133@<S+`<S+P133058)0<S,`58)@<S+@]2+`<S+05>/@5>/P<[5P5>.P<[
M70<[9`189@5>.`5>.05>/05>/`<[7P<[6P<[8P=">P<[7`<H6P<[7@<[8`5>
M0`<[6`<[6@5>.@]79P]7:`]7:0]7:@="=01=10="?`="?@5D6P5D5P="?01=
M2P5D5`5D505D7P1=301=0@=">@5D4P1=1P1=3`5D70=">0="=P5D401=0P5>
M0@5D4@=">`=#(P="=@5D605D6@5>005D7`5D7@5D6`]<8`=)=@5I205I2@1A
M*0=)>P=)?`5I1P5I2`=)<@=)<P=)=0=)>0=)>@=)=`=)>`1A*P=)=P=#(0]@
M:P]@;`]C=@=/?05M6`=0)@5M6P5Q-`5M501D10=0(P5M5@=0(@=4?`=/?@5M
M60=)<05M6@5M7`=0)`]F-`=0(05M70=5(@=5)`5Q-@1G-@=5)@=5)05Q-0=4
M?@=5(01G-P=5(P=9,0=4?0]F,P1I00=9+@1I0`1I/P5T-P=9+`=9+0=9,`=9
M+P5X+@]I;P=?40=?4`=?3P5Y2P=A2`=A1P=A1@=B805Z-P=B8@=B8`=D7P=C
M<P=C<@=D7@5[?@=E9`=F+`5\2P=F304D=@8N+`0K2`4P000O=`8\*@9$6P\X
M1@\_,0\_,@98,@1'-`9B-@9B-P9B.`],.`],.0<H7`],.@]2,`<S,0<S,@]2
M+P<[90]@;0]@;@5I2P=0)P=5)P4G9P8N+00O=P4P0@\R4P4U304U3@9$7`9$
M704U4`4U2P\X1P\X20\X2P0U,@0U-@4U3`4U3P9.7P0[)09.8@9.804\-@9.
M7@0[)`9.7098-@5";05";P5";@98,P98-P5"<`]%0`]%00]%0@98-09B.05)
M<05);@5)<@1'-P9B.@],.P],/`5);P9B.P5)<`1-20<H7P50;`1-2P50:P<H
M8P50;098-`<H8@50:@50;@]2,0<H8`<H7@<H70<H8058,`58+P58+@135P<S
M-`58-`<[9P136`137@137058,058-0<S,P58+058,P]7:P]7;`]7;0<[9@5D
M8`5>105>1`<[:@<[:0<[:P<[:`]<80]<8@5D8@1=401=3P=#)`5D80]@;P]@
M<`]@<0=#)0=)?0=)?@5M7P=0*0=0*`]F-05M7@]H2P]H3`=5*`1I0P5T.01I
M0@]I<`]I<05X+P=?4P]K9`=?4@5Y305Y3`=A201M(05Z=`1N.P5\1`=F5`8N
M+@8N+P8T5`4K2`0O>`8\+`0O>08\*P9$9P0U.P4U4P4U4@9$7P9$8P0U-P9$
M9`4U409$8`\X30\X3@\X3P0U/`9$9@9$7@9$8@9$909$804\-P0[)@9.9`9.
M9P4\.`9.8P9.9@9.:09.900[)P0[*`9.:`\_,P5"<P5"<05"<@98.`9B/@5)
M=01'.09B0`5)<P5)=`9B/09B009B/`9B/P<H9@50=0<H9P50=`50<`50;P1-
M4`1-4@1-30<H:01-5`50<@<H:`<H:@50<0<H9`<H9050<P<S.`<S-P137P58
M-@138P58.058.P138`<S-@<S-058-P58.`58.@<S.05>1@<[;0<[<P<[;`5>
M2@5>20<[;@<S.@5>2`<[;P<[<`<[<018;`<[=`<[<@5>1P=#)P=#*`1=4@=#
M)@=#*01A-05I3`1A,@1A,P=*(0=*(@=*(P=*)`1A-@=0*@5Q-P=5*05T.@1I
M1`=<905X,`=B8P1M8`=D8`=D805[:0=E0P4C)P4C*`8N,`8\,P0P(00O>P0O
M>@0P(@4P0P8\,`8\,08\+P8\,@8\+@0U0`9$:@9$<P0U/@9$;P4U7`4U609$
M<00U0@4U5`0U1@9$>04U509$=P9$:P9$>`4U6`9$=`9$=09$;@9$>@\X4`\X
M40\X4P\X5`\X50\X5@9$<@9$:09$:`9$=@9$;`4U6@9.=`0[,@0[+@4\.P9.
M;P9.;@9.<09.:@0[+09.>`0[.`0[.04\/`9.;09.=@9.<`9.=P0[-P4\.04\
M.@\_-`\_-0\_-@\_-P\_.`\_.0\_.@\_/`9.<@9.=09.;`9.>09.<P5"=01`
M:`1`:@981@5"=@4\/05">01`<01`<`980`982P98/098201`:01`:P5"?`5"
M=`1`<P980P98/`981P980@98/P1`<@5">@982`5">`5"=P981`]%0P]%10]%
M1@982@5">P98.098.P1`;P98.@981098/@9B3@1'/P5)>@1'.P5)>`5)>P1'
M/@1'2`9B0@9B3`1'009B4P1'1`9B3P1'1P9B1@5)>09B409B101'209B4`9B
M1`5)=@5)=P],/0],/@],/P],0`],0@],0P],1`],109B2`1'2P9B2@5"?09B
M2P9B309B0P9B4@9B20<I(051*@<H:P50>@51(@<H<0<H=`<I(@<H?`<H<`51
M)P1-5P51*051(P50>P50?@<H>`51)`1-7051)@1-8@<I)`<H=P<H;P50>`50
M?`<H?0<H;051)050?050=P50>050=@]2,@]2,P]2-`]2-0]2-P]2.0]2.@<H
M=@<H=0<H;`<H<@]2.`51(0<H>P<H;@51*`<I(P<H?@<H>@<H<P<S1@580`13
M<0<S4@13:`139013;`<S20<S40<S0P58/0<S0@58/`<S/`13<`139P<S1013
M;P<S/013;@<S1P<S3@139@<S4`<S/@13:0<S.P<S4P<S0`<S/P<S2`<S2@58
M/P<S3`13;0<S1`58/@]7;@]7;P]7<`]7<0]7<@]7<P]7=`]7=0]7=@]7=P]7
M>`<S5`<S00<S2P18;@5>4@5>40<[?018;P5>5`18<0<[>018;05>305>4P5>
M3@<[=@<\)018<@=#*@5>3P<\(0<[=P5>5@<\)P<[?`<[>`5>4`18=`<[>P<[
M?@<\(@<\(P18<P5>2P<\)@5>3`<\)`<[=0]<8P]<9`]<90]<9@]<9P]<:`]<
M:0]<:@]<:P<\*`<\*0<[>@1=7@1=5@=#-P1=6`=#-05D:`=#.@=#*P1=8`5D
M9@58001=605D9P=#.`=#,@5D9`1=4P=#.P1=505D901=70=#.0=#+P=#,P=*
M*@=#,`1=7`=#-`=#,0=#/`=#+`=#+0]@<@]@=0=#-@1=7P=#+@5I305I3P=*
M+P1A/@=*+`=*+@1A0P1A.05I4`1A00=*-`1A0@5I3@1A/P=*)@=**0=#/0=*
M*`=*-0=0,P=*,P1A/`5M8`=*)P]C>`]C>0]C>@1A1`=**P=0-0=*,`=*,0=*
M+0=*,@1A.`]@=`1D2@1D2P5M8@5M80=0+05M8P=0+P1D20=0*P5I4P=0,@=0
M+@=0-`=0-@=0+`=0,`]F-@]F-P]F.`]F.0=0.`=0-P=0.0=5*@1G0@=5-`=5
M+0=5,P1G.`=5+@5Q/0=5+`=5+P1G/`5Q.@5Q.01G0P=9.P=9-01G.@5Q/`5Q
M.P=5,0=5*P=5,`5Q.`=5-05T.P5T/05T0`5V2P1I1P=9.01I2@5T/P1I205T
M/@=9-P=90`=5-@5T/`=9-@=9.@=9/P1I1@=9/@]I<@]I<P]I=`=9/`=9/01J
M?01J?@=<9@5V3@5V305X,0=<:`=<:0=<:@]J=`]J=0=<9P=90@=?5P=?6`=?
M501L)P=?5@=?6@]K90]K9@=?5`=?60=?6P1M(P=A2P5Y3@=A3`]L.@]L.P=A
M2@5Z=0=B90=B9`5Z.01M?@=C=`=D8@1N/`=D1`=E1`=F4`4D=P0P)`4P1`4P
M100U2`0U200U1P9$>P0[.@5"?@5#(0983`1'3051+`1-8P51+051*P580@<S
M5@<S50<\*@5>5P=#/@=*-@=*.05I5`=*-P5I50=*.`=0.@=*.@5Q/@5Z=@=E
M=P8T508\-08\-`\X5P0[.P4\/@9.>P\_/05#(@1`=09;7P1'4`9B5`1'40<I
M*`<I)P<I)051+P51+@<I)@]2.P580P13=`<S5P581`<L5@5>6@<\+05>6`<\
M+`5>60<\*P5D:01=8P=#0`1=8@5>6P=*/`5I5P=*/0=#00=#0@5I5@5M9@5M
M905M9P]F.@5M9`]C>P5Q/P5T00]J=@]J=P5X,@5Y3P5Z=P=E108E5`4C*04K
M2@4P2`4P1P8\-P8\-@9$?@9$?`4U809%(09$?00[/`9.?`0[/04\0`4\/P9.
M?@4\009/(P9.?0\R501`=P5#)01`=@983@983P5#)P5#(P5#)@98309/(@5#
M)`5#*`9B509B5@1'4P1'4@9B605)?05)?`9B6P9B6@9B5P9B6`51,@1-9@<I
M*0<I*P51,051,P<I+0<I+`5)?@51,`<I*@5*(0<I+@]2/`581P582`581@<S
M6013=@<S6@<S7`<S6P5810<S6`5>705>7@5>7P5>7`<\,`<\+@<\+P1=905D
M:@5D:P=#0P=#1`=#101A1P5I6`5820=*/@1A205M:P5M:`=0.P5M:@5M:01G
M1@5Q0`=5-P=5.`=90P=<;`=91`=910=<;0=<;@5T0@=?7`=A30=?705Y4`5Z
M.@=E1@=F0P\H;`4K2P8\.`\R5@4U9`4U8P0U3P4U8@0U3@9%)09%(P9/)04\
M0@4\1@4\1`4\2`4\109/*`9/)@4\1P4\0P9/)P9/)`\_/@1`?`1`?01`>@98
M4@5#*P98405#*@1`>01`>P984P]%1P5#*09B809B7`5*)05*(P5*(@9B7P5*
M)`9B7@9B8`],2`9B709B8@],2051-051-`1-:051-P51-@51.`1-:@<I+P<I
M,`1-:P<I,0<S9`582P<S7@<S8`<S8013>`582@<S8@583`<S7P]7>@<S70<S
M8P18>05>8P<\,05>8@18>`5>8`5>9`5>80]<;`=#1@1=9P=#1P1=9@5D;`=*
M/P5D;05I6P=*0`5I6@=*0P=0/0=*0@5I605M;05M;`=0/`5Q0@5M;@5Q00=5
M.0=91@=<<`=<;P5Z>`4K3`0K2@8T5@\M2@0P)@8\.04P204P2@\R5P\R6`8\
M.@9%*@9%+`9%)P9%*`9%)@9%*P4U90\X60\X6@\X6P\X7`\X70\X7@\X7P\X
M8`9%+00U4P9%*00U4@9/*P0[0`4\204\2P9/+@9/+`9/+0985P4\2@\_/P\_
M00\_0@\_0P\_1`\_109/+P9/*@4\301!(@985`9860985@5#,`5#+`987@98
M505#+P5#,05#,@986`988`988@5#,P987P]%2`]%20]%2@]%2P]%3`]%30]%
M3@9880\_0`986P5#+@]&-`9B901'505*)@9B9`9B9@9B;`9B8P9B:05*)P1'
M5P],30],3@],3P],40],4`],3`9B:P9870<I,P<I-05**`1-;P<I-`51.@1-
M<`51.P<I.0<I.`<I,@]2/0]2/@]2/P<I-P],2P<S:@583@<S9P<S9@583P<S
M:P<S;@13?`<S:`58309B:`]4,@]7>P]7?`]7?0]7?@]8(0]8(@<S;0<S;`<S
M90<S:0584`<\,@5>905;+05>9P584@5>9@18>P<\.`<\-`<\-@<\-P<\-0]<
M;@]<<`]<;P=#2P5D<P=#3@5D;P=#20=#2@=#405D<05D;@5D<@=#30=#3`]@
M=@]@=P]@>`]@>0]@>P]@?`=#2`=#4`5D<`=*1P=*2P5I705D=`=*2@=#3P5I
M7`1A2P=*2`5I7@=*30=*3`5I8`=*1`=*20=*1@]C?`]C?0]C?@]D(0=*3@=*
M105I7P1D405M<`1D4`5M;P=0/@=00`]F.P]F/`]F/0]F/@]F/P=0/P5Q0P1G
M1P5Q1`5Q10]H3@]H3P=5.P=91P5T105T1`]I=@]I=P]I>`=92@=92`=920]H
M30=<<01K(@5T0P=<<@]J>`=<<P=?7@=?8`=?7P=B9@8N,08T5P8T6`4U9@\X
M809/,`0[1`988P]%3P5**@],4@<I.@585`584P]8(P<S;P5>:05>:@5>:`]<
M<05D=0=#4P=*4`=*3P5Q1@=<=`8N,@8N,P8T60\M2P\M30\M3@\M3P\M4`0K
M2P4P308\/@8\/04P3@8\/`0P*0\R60\R6@\R6P\R7`\R704U;09%,`4U9P0U
M5P4U:@4U;P4U;@0U6`9%+@9%+P4U:P4U:`\X8P\X9`\X90\X9@\X:`\X:0\X
M8@4U;`4U:0\X9P4\404\4`4\5`4\3P9/-`9/,05#.04\4P4\3@9/,P0[1@4\
M50989`9/-0\_1P\_2`\_20\_2@\_2P\_3`\_3P\_4`\_409/,@\_3@989@5#
M-@1!(P98:`1!)05#.P5#-05#/05#-P1!)`98:@98:05#.@]%4`]%40]%4@]%
M4P]%5`]%50]%5@]%5P9890989P9B;0\_309B;@1'7`5*+`5*,`9B<@5**P5*
M+@5*,09B<09B;P5*,P1'705*+P9B=@5*+09B<P],4P],5`],50],5@],5P],
M6`],609B<`510@51/`1-<@51/P51/@51/0510`<I/P511@510P<I005100<I
M/`<I0`<I/@9B=`<I0@<S<@5110511`]20`]200<I0P<I.P]8+014(P14)`14
M*`<S=`586014(014(@14)P<S=014)0<S<0<S<`586`586@<S=@]8)`]8)@]8
M)P]8*`]8*0]8*@]8*P]8+`]8+@<S>`<S=P586P585@585P5>;P5><019(@5>
M<`19)`19(05><@18?@5>;`19(P5>;@5>:P<\.@5><P]8)0]<<@]<<P]<=`]<
M=0]<=@<\.05D>05D?`1=:P=#5P=#5@5D=@5D>@5D>`5D=P5D?05D?@=#6P=#
M6@5D>P]@?0=#6`=#50=#60=#5`58705I8@5I9@5I:`1A3@1A3`5I8P5I9P5I
M905I80=*4@5I:05I9`]D(P]D)`]D)0=*40=*4P1D4@1D5`1D6`1D5P5M<0=0
M00=00P5M<@=00@]F0`]F00]F0@1G205Q2`5Q20=5/P=5/0=5/`=5/@5Q1P5T
M1@5T201I305T2`5T1P]I>05V3P5V4`]J>0=92P=<=0=<=@5X,P5X-`5X-01M
M)@=A3@5Z>05[208N-08N-`8T6P4K30\M408T6@8\000P*P8\0@8\0`4P4`4P
M3P8\/P8\0P0U7P9%,P0U6@4U<P9%-P4U=P9%.@4U<04U=09%/`9%/04U=`9%
M.P9%,@9%-@\X:@9%,09%-09%.04U=@4U<`9%-`4\8`4\5P4\6`4\6P9/.P4\
M5@9/.`0[3@4\704\604\804\6@9/.098>04\8@\_5`9/-P\_4@9/.@4\7@5#
M005#/P98<05#0`5#0@98=`98<`5#1P5#1098;@98;05#/@98;P98<@98=@5#
M2@98;`98=P5#0P5#3`5#2`98<P5#205#1@98=05*-0]%6098>`98:P9C(@5*
M0P1'8`5*-P5*/P5*-@513@5*.P9B=P9B>P5*0@5*/`5*.05*0`5*005*/05#
M1`5*.`5*1`9B?@5*1@9B>05*1P],6@],6P9B>`9B>@9B?09C(09B?`5*.@<I
M1@1->@513`511P512@513P<I10<I201-?`<I301->P512P51301.)`514051
M4@1'8P<I3P5120<I2P]20@]20P]21`]210<I2`<I3`<I1P<I2@514`515`51
M505*10<T(0588`5*2`58:014*@<S>@588P<S?@<T(P<S?`587P<S>P<T)051
M4P<T)@589P58:`587@5880<S?05890589`<T)`14*P589@14+`]8,0]8,@<T
M(@5>>@5>?05>=0<\0`5>=@5>?`5>>`19*0<\/@=#9P<\0P5>?@19+@<\.P<\
M0@<\1`5>>019)P<\00<T)P<\/P19+P]<=P<\/0]<>05>=P5>=`=#8@1=<`=#
M9@1=;P5E(05E(@5E+05E)@1=<05E+`5E*`=#7P5I<`=#90=#7`5E+@=#7@5E
M)`=#805E(P5E*01?,P1==@5E)0]@?@]A(0]A(@]A(P]A)`]A)0=#:P5E)P=#
M8`=#:0=#:`=#:@=#705E*P=#8P<\/`5E+P5I:@=*905I;P5I<0=*:`5I=`=*
M6P5E*@5I;@=*6`5I;05I<@1A50=*5`1=<P=*60=#9`=*7@5I<P=*6@=*9@=*
M50=*7`5I:P5I;`=*80=*8@=*8P=*7P5I=@5I=0=*8`=*70=*9P=*5@=*9`1A
M4P1D605M?05M=P=01`5M>P5M=@5M>0=02`=01@1D7`5M<P1D70=01P5M>`5M
M=05M=`=020]F0P]F1`]F10]F1@]F1P=010=02@=02P5M?`5M?@5M>@1G3@=5
M0@1G3P5Q2P=500=51`1G301G2P5Q3`=50P=50`5Q2@]H40]H4@5T2@=510=9
M3`5T305T3P5T3@5T3`=9305T40=93@]I>@=93P5T4`5V5`5V4@5V50=<>0=<
M>`5V4P5V401L*P=?805X-P5X-@1L*@5X.`=?8@=A3P=?8P=A4@1M*`=A5`=B
M9P=A4P=A40=A4`]K9P5Z/`5Z.P5Z/0=C=@5[2@=D8P5[:@]M*`=E90]M,P8C
M.08C.@8E504P4@8\1`4P404U>@4U>04U>`9%/@9%009%0`9%0@9%/P9%0P9%
M1`0U8`\X:P4\909//P4\9`9/009//@4\9@\_50\_5@\_5P\_6`9//09/0`98
M?05#3098>@98?@99(0]%6@]%6P]%7`98>P98?`99(@5*2@9C(P9C)`5*209C
M)09C)@],7`],70],7@<I40515@1.)0]21@]22`<I4`58:@14,058:P<T*`<\
M1@]8-`]8-@<\2`<\1P<\105?(0]<>@]<>P5E,`=#;`]A)@]A)P=*;`=*;0=*
M:@]D)@]D)P=*:P=*:01D7@=030]F2`]F20=03@=51@5Q30=51P=52`=520=9
M4`]I?`5V5@5Y408T7`4K3@8T7@\M4@\M5`8\104P5`8\1P\R7P\R8`8\1@4P
M4P\R7@4U>P9%3@9%309%1@0U9`4V(@4V(09%2@4U?09%1P9%3`9%2P4U?`4U
M?@\X;09%2`9%200U909/1@9/1P4\<`4\;@9/109/1`9/0@4V(P4\;04\:`4\
M:P4\:@9/0P4\:04\<04\;`4\;P99(P99*`5#4P99)@99*05#401!*P5#4@5#
M3P99)P5#3@]%70]%7@]%7P99)01!+05#5`9C+09C+P5*4`1':`9C*`9C*P5*
M309C+`9C)P9C,`5*2P5*3@9C,09C+@],7P],8`],80],8P5*3P5*3`<I609C
M*@518`<I5P<I7@<I8@<I5@5160<I6@<I50<I7`516`516P517@1.+`9C*0<I
M6`<I70<I6P5170517P<I4@515P<I5`<I8P]220]22@]22P]23`<I4P<I7P<I
M8`<I80517`516@<T*058<P<T+P58=`<T+058<`<T*P<T-`58;@58<058;0<T
M-0<T,`<T-@58;`<T,P]8-P]8.0]8.@<T+`<T+@<T*@]8.`14-058;P<\2@<\
M4@5?)0<\30<\3`<\2P<\4P19,P<\4`19-`<\405?(@5?*P19-@5?*`5?)P<\
M5`5?)`5?*@<\20]<?`]<?0<\3@<\3P5?)@5?(P5?*01=>0=#<`1>(05E,@5E
M-`]A*`]A*0]A*@=#;P=#<@=#<0=#;@=#;05E,05E,P5I>`=*;@=*<0=*;P=*
M<`5I>@1A6@1A6P5I>05I=P5I>P=*<@]D*`=*=`1D8@5N)05N(P=04P5N)`5N
M(@=0405N(0]F2@=04@=04`=03P5N)@=05`1G4P5Q3@1G5`=53`=52P=52@=9
M5@1I4`=94@=9401I40=95P=94P=95`=950=<?@==(05V5P=<>P=<>@=<?`=<
M?05V605V6`5X/`5X.P5X.@=?9P=?90=?9`5X.0=?9@5Y4P5Y4@5Z/@5Z/P=B
M:`5Z>@=D9`=B:0=C=P5[:P=E9@8I*P8N-@8\2`9%3P4V)04V)`1!+@99*@]%
M805*40],90],9@5*4@<I9`<I90<I9@518@<T-P58=0<T.`]8.P5?+05?+`]<
M?@]=(0]=(@]=(P5?+@5E-P5E-@=#<P=*=01A7`=*=@]F2P=050]H5`=96`=?
M:`=E1P=E9P8I+`8N-P99+099+`99*P]230<S(01A70=5308E608E6`8E5P0D
M?@8I+00E)`8\208I+@\E,P\E-`8\2@8I+P4D>`8\2P9%4`4G:@4G:P4G<`8N
M.`8N/04G;P0H)04G<04G;00H*`8N.P\H;0\H;P\H<`\H<P\H=`\H=08N.@8N
M/P4G;@4G:`8N/`4G;`8N.08N/@4K3P4K5@4K4@8T7P4K408T8@4K504K4P0K
M3P0K404K4`8T9`8T8P\M50\M5@\M5P\M6`\M600K4@8T908T809*1P4K5P4K
M5`8\5`8\6`4P6P8\4P4P5@4P6@0P,04P5P4P608\4@8\3`8\5@0P,@8\5P8\
M305#508\504P6`8\4`8\3@4P7`4V)P4V)@8\3P9%6P4V+`0U:@9%7`4V*P8\
M404V*09%5P9%6@\X<`\X<0\X<@9%5@9%5`9%509%4@9%709%6`9%4P4V*@0U
M9P9%604V+04V*`\X;P9%404\=@4\<@4\>`4\=P0[5@9/4P0[6@0[6`4\>09/
M4@<I9P9/309/3`9/4`9/3P0[6P9/209/2P\_8@9/409/5`9/509/2@\_60\_
M6@\_6P\_7`\_70\_7P\_8`\_804\=09/3@4\=`4\<P0[609/5@990`99-`99
M/099,`1!,01!,`99+@5#6099,0990099.P99/P99-P99-0990P990@4\>@1!
M,@99,P99/@]%8@]%8P]%9`]%90]%9@]%9P]%:`]%:0]%:@]%:P]%;`99,@99
M-@99/`99.099.`99.@99+P5#6`5#5P5#5@9C-09C-`9C-P9C,@9C.@5*5`9C
M-@9C.`9C/`5*4P5*5@9C,P9C.P<\50],:0],:@],;`],;0],;@],;P],<`],
M<0],<@9C.0<\5@<\5P<\6`5*50<I;@<I;`<I<@<I:0<I:P1.+P519`1.,`51
M:`51901.-`<I<`]23@]23P]24`]240]24@51;0<I:@<I;P<I=`<I=0<I<0<I
M<P=#=`<I:`=#=0<I;051:0519P51;`519@51:@51:P518P<T1@58?`58>P58
M>0<T0058=P<T10<T/@<T1P14-@<T0@<T1`<T.0<T2@=*=P<T/`<T0`<T3`]8
M/`]8/0]8/@<T/0]8/P<L6@<T2`<T.P<T.@<T0P<T2P58>`58?058>@<T/P58
M=@5?+P19.@<\8`5?,P<\705?-`<\6P=05P<T20<\8@<\7@5?,@5?-0]=)`]=
M)@]=)P]=*`<\60<\7`<\7P<\8P]=)05?-@5?-P5?,05?,`<\6@5E/0=#?`1>
M(@=#>@5E.@=#>`]A*P]A+`]A+0=$(0=#?@5E.0=#?0=#=@=#>05E/`5E.P5E
M.`=#>P=+(0=+(@=*?@]D*@]D*P]D+0]D+@=*>0=*>@=*?0=*>P=*?`=*>`5J
M(05I?@]D+`=06@5N*0=0605N)P]F3`=06`5N*`==(@1G50=53P5Q40=54`=5
M3@]H50]H5@]H5P]H6`5Q3P5Q4`5I?0=5405Q4@5T4@1K)0=96P=96@=960==
M(P==)0==)`=B:@=?:@=?:05X/0=A50=B:P=E:`8I,`4A?`4C+`4C*P4C+04C
M*@0C,08E6@8E7`0C,P0E)P4D>00E)@0E*`0E)08I,P0E*@4D>@0U<08I,@\E
M-0\E-@\E-P\X<P\X=09%809%7P9%8`8I,00E*00H+@9%7@0H*@0H+00H+`8T
M:00H+P4G<@4G<P9/6`8N0P\H=@\H>`\H>0\H?`9/6@8N008N0@8N0`\H=P\H
M>P9/5P9/604G=`4K6@4K604K6`0K5P0K504K7P1!,P4K6P\M6@]%;@991099
M1`991@8T;`8T9@8T9P8T:`8T:P8T:@4K7@4K7`4K704P804P700P-@8\6P4P
M904P9@4P7@4P8P4P7P0P-08\700P-P8\7P9C/09C/P9C0`8\7`8\7@8\6@4P
M8@4P9`4P8`4P9P9C/@8\60\R8@\R8P\R9`51;@1.-@0U;P4V,04V,`4V-04V
M+@4V,@0U;09%9@4V-`<I>@<I>09%:`\R80\X=@]25`<I=@<I=P<I>P<I>`9%
M8P9%909%9`9%8@\S/`9%9P4V+P4V,P4P:`0[7P4](P4\?@4](@0[704])`9/
M9`4](05#9P4\?04\?`9/8@9/6P0[7`\_8P\_9`\_90]800<T3@9/709/7`9/
M7@9/7P9/8`9/80\_9@9/8P<T304\>P<\9`5#6P5#8`5#8P5#7@5#701!-09C
M005#7`5#8@5#7P5#9`5#9@1!-P5#9099205#6@]%;P992`992P5#801';P5*
M705*7`5*605*6`5*8P5*7P5*6P9C1@9C0P9C0@5*805*8@=$(@=$)`=$(P=$
M)09C105*5P1'<@9C1`5E/@5*6@5*7@5*9`1..`=+(P51<@<J(01.-P51<P1.
M.059*`51;P51<`<I?@<J(@1..@]24P]250]25@=+)@=+)`<J(P<J)0<J)@<J
M)`<I?`<I?051=`<T4`51<0=+)05N*@59)059)@=07`14.`<T3P59(059)`<T
M4@59(@59(P14.0<T40]80`=070=06P5N*P<\90<\:05?.`19.P5?.0=54@=5
M4P=55`<\9P<\:@<\9@5?.P5?.@=550<\:`5E0`=$)@=$)P5E005J)05E1`=$
M*0=$*`5E0@5E0P=97`5E/P=$*@=+*`=$*P5J)`=+)P5J(P=+*@=+*01A8`59
M)P5J(@1D9`5N+`=07P=080=07@=08`1G5@]H60=55@=55P=970=56`]H6@==
M)@=?:P=?;`5[2P=C>`0P.0\R908\8`4V.`4V-P9%<@9%;@4V.00U=@9%;`9%
M<P9%:00U=P4V.@9%<`9%;P9%:@9%:P\X=P9%<00U>09%;09%=`9/:P4])04]
M)@0[909/:05#:@0[8@0[8P9/:@9/9@9/900[809/9P9/:`\_:`\_:0\_:@\_
M:P9/;`5#:05#;`5#:`993@99305#:P9C2@5*9@5*90],<P],=`],=0],=P9C
M209C2`],>`9C1P<J*`51>`<J+`51>051=0<J,`51=@<J+P<J+@<J+0<J*0<J
M)P51=P],=@]26`]260<J*@<J*P<J,@<J,0<T5@<T5059*0<T6`59+`<T6@14
M00<T7P14/@14/P<T7@59*@<T5P<T70<T7`59*P]80@]80P<T60<T6P<T4P<T
M8`5?005?/P5?0`5?0P190`<\;`5?0@19/@<\;@5?/@<\=`5?1`<\;0<\<P]=
M*@]=*P]=+`<\;P<\<0<\<@5?/05E1@5E1P5E20=$,P=$+P1>(P=$+`5E2`1>
M)@5E2@<\=01>)0=$,@5E2P=$-0=$-@=$+0]A+@=$,0=$+@5E3`=$,`=++P=+
M+`5J+@5J*P5J)P5J*@5J*05J+P5J+`5J*`5J+0=++0=++@=+,`=+*P=$-`5J
M,`5J)@=08@5N,05N+@5N+P5N+05N,`=08P=09`]F3@=090=09P=09@1G601G
M5P1G6`5Q4P=56@]H6P=560=97@=97P=98@5T4P=980=98`]I?0==)P==*05V
M6@==*P==*@5V6P==*`]J>@5X/P1L+P=?;0=?;@5X/@=B;`5Z>P=C>@=C>0=D
M9@=D90=E>`=E>08T;@4])P4V.P9C2P9C3`51>@<J-`<J,P59+0<T805?10]=
M+0=$-P]F3P]H7`5T5`4V/`8\809%=09/;@4]*04]*`]%<`9C30<J-05?1@]A
M+P5E30]H705Q5`=56P8\9`\R9@8\8@4V/09%=@9%=P\X>`9/<P9/=`9/=09/
M<09/<@9/>`9/=@9/<`9/>0\_;`\_;0\_;@\_;P\_<@\_=`\_<09/=P\_<`1!
M1P5#;@1!101!1`994P993P]%<0]%=0]%=@]%=P]%>`99509940994@]%>099
M5`994`]%=`5*9P5*:`9C4@5*:0],:`],>0],>P],?`],?0]-(0]-(P]-)`]-
M)0]-*`]-*09C3@1'>@9C4`9C40]-*@9C5`],>@9C50]-*P]-)@],?@<J.@1.
M0@51?@<J00<J.P<J0`<J.051?0<J0P<J1`<J/051>P<J-P]26P]270]27P]2
M8`]28P]29`]290]29P]2:`]2:0]2:@]2;`]2;0<J0@<J/`<J/P<J10]27@<J
M-@51?`]28@]29@]26@59-`59-P59,@141P59+@59,`<T90<T9`<T:P<T:0<T
M9P59-@141`<T8@<T:@<T:`59+P<T9@]27`59,P]81`]81@]81P]820]82@]8
M2P]830]83@]83P]840]84P]85`]85@]85P]86@]87`]870]87@]88`]880]8
M8P]89`]84`]84@]87P]810]86`59.`59,05?2`5?20<\>0190P5?3`5?2P<\
M?`59-05?1P<\>@5?2@5?3P<\?@<])`<](0<])0]=+P]=,`]=-`]=-0]=-@]=
M-P]=.@]=.P]=/`]=/0]=/P]=0`]=0@]=0P]=1`]=10]=1@]=1P]=2`]=20]=
M2P]=3@]=3P<\?0<](@<\>`<](P192`]=2@]=.`]=,P]=,05?3@5?30]=+@5E
M401>+01>+@5E4@1>*`1>*@=$.`5E4`5E3@5J,0=$.@5E4P1>,`=$0`=$/P5E
M5`5E50=$00]A,0]A,@]A-`]A-@]A-P]A.`]A.@]A/`]A/0]A/@]A0`]A00]A
M0@]A1`]A10]A1@=$.P=$/`=$/@=$/0]A,`]A.0]A-0]?701A:P=+,P=+-P5J
M,@=+-`5J-`=+,@=+.@=+-@=+.0=+.P]D,0]D,@]D,P]D-0]D-@]D.`]D.0]D
M.@]D.P]D/`]D/0]D/P]D0`]D00]D0@]D0P]D1`]D10=+/`=+-0=+.`1A:@=+
M,05E5@]D/@1D:`=0;0=0;@5N.`=0<@5N,P1D:@5N-@5N,@=0<`=0:`=0:05N
M-P1D;@=0<05N-`]F4`]F40]F4P]F5`]F50]F5@]F6`]F60]F6@]F6P]F70]F
M7P]F8`]F80]F8@]F8P]F9`]F9@]F:`]F:@]F:P]F;`]F;0]F;@]F;P=0;`=0
M;P]F4@]F7`]F9P=0:@=58@1G7@=59P=580=57`1G8`1G70=58`=58P=5:0=5
M7@]H7@]H7P]H8`]H80]H8@]H8P]H9`]H90]H9@]H9P]H:`]H:0]H:P]H;`]H
M;0]H;@]H;P=57P=59`=590=59@=570]H:@5T5P=9:P=9:@==,`=99@=99`]I
M?@]J(0]J(@]J(P]J)`]J)0]J)@]J)P]J*`]J*0]J*@]J*P=98P=9905T5@5V
M7@1K*`5V7`]K+P==+P==+0=9:0==+`]J?`]J?0]K(P]K)`]K)0]K)@]K*0]K
M*@]K*P]K+`]K+0]K+@==+@==,0]K(0]J?@]K)P5X0`=?<`=?<0=?<@=?;P=?
M<P]K:`]K:0]K:@]K:P]K;`1M8P=A5P=A6`]K;0]L/`]L/0=A5@=B<@=B;0=B
M;@=B=`=B<`=B;P5Z0`=B<P=B<0=B=0]L4@]L4P]L5`]L50]L5@]L5P]L6`]L
M0`5Z005Z?`=C?0=C>P]L;P=C?`]M(P=D:`]M(0=D9P=D:0]M(@]L/@=E2`=E
M20]M*05\(0]M-0]M.`]M.08N1`8I-`4K8`4V/P9%>P4V/@4V0`9%>@\X>09%
M>09%>`4]*@4]*P0[:`9/>@9/>P\_=09960996`1!2@995@995P]%>@5#<`5#
M;P5*:@1'?`9C5@9C5P5*:P52(052(P59.052(@52)`52)0]89059.P<T;@59
M.@<])@<T;0<T<`<T;`<]*0192@5?4`192P<]*@<]*`<])P=$0P5E6`=$0@5E
M5P5J.`5J-@5J-05J-P5N.0=0<P=0=`1G9`=5:@=9;0=9;@=9;`5V805V8`5X
M00=?=`=B=@=D:@4K804P:@4P:P4P:0\R9P8\9@4V0@4V00\X>@\X>P9%?`4]
M,P4],04]+P0[:@4],`0[;`,_;04]+`4]+04]+@9/?@90(04],@9/?`\_>`\_
M>0\_>@\_>P\_?`\_?0]`(09/?00[:01!3`997@1!4@1!301!2P]%?@99705#
M=`5#<05#<P5#<@996P1!401!3P997`996@]%?0]&(05*<P5*;P5*<01'?@5*
M;01((05*=`9C6@5*<`5*=01'?05*<@5*=@9C609C6P9C7`5*;`<J2`52+052
M*`<J3052*@52)P<J3@1.2052+`52*0<J3`]2;@]2;P]2<0<J1P<J20<J2@<J
M2P52)@52*P52+@]2<`144`143059/0590`<T<@59/`59/@59/P<T=0<T=P<T
M>0]89@]89P]8:`<T=`<T>`<T=@143@194P19405?5`<]*P5?405?4P5?505?
M4@<]+0194`<]+`193`<]+@]=4`<]+P<],`<],05E7P5E7@5E6@1>,P=$1`5E
M6P5E805E8`=$1@5E705E605E7`]A1P]A2`]A20]A3`]A2P=$10=$1P5J.0=+
M/@=+/P1A;05J.@=+/01A;@]D1@]D1P]D2`]D20]D2@1D<`5N/P5N.@5N/05N
M/`5N/@5N0`1D<@=0>`5J.P=0=0]F<`]F<0=0=@5N.P=0=P5Q6@5N001G905Q
M605Q5P]H<`]H<0]H<P]H=`]H=05Q7`5Q6`5T6`=5:P]J+P=9;P]J+`]J+0]J
M+@]J,`]J,0]K,`]K,0]K,@==,@5X0@]K;@]K;P=?=@=?=05Y5`1M*01M*@=A
M60=B=P=B>`5Z?0]M*@8N104B(@4A?@0B(P4B(P0B(@4B(04C+@0C-`8E704D
M?00E+`0E+04D?@4D?`\E.@\E.P\E/`\E/0\E/@\E/P4G=08N1P4G=@4G>`4G
M>00H,`4G=P8N1@8N2`\H?0\H?@4K8@8T<`8T<P0K7`4K908T<09C708T=08T
M=@8T=P8T<@4K8P8T>`\M6P\M7`\M708T=`8T;P8\:04P;P4K9@8\:`4P;`4P
M;@8\;@8\:P8\;P4P;08\:@8\;08\;`\R:`\R:0\R:@\R:P\R;`\R;0\R;@4V
M0P9&*`9&(00U?@0V(@0V(04V1`9&(P9&)`9&*P9&*@9C7@9&)@9&(@9&*09&
M)P<T>P9&)0\X?`\X?0\X?@\Y(0\Y(@\Y(P\Y)`\Y)0\Y)@\Y)P4].`4]/04]
M.04].@4]/`90)090(P4]-`4]-04]-P90)`90*0<]-`90)P4].P90*`90)@]`
M(@]`(P<],@4]-@99:@5#>P5#>`998@99:0999P5#?`5#>05#=P9C7P998P99
M905#?05#>@999@=$20999`=$2`5#=@997P99:P998`5#=09980]&(@]&(P]&
M)`]&)0]&)@]&)P]&*`]&*099:`99;`<],P9C9`9C8@9C9@1()P1()@52+P1(
M*`1(*05*>`9C8P9C8`1()05*>05*>@9C909C9P=+00]-+@]-+P]-,`]-,0]-
M,@]-,P9C805*=P52-@52-`52-0<J5052.`52,@52,0<J3P52,P52-P52,`=0
M>@<J4P<J40<J4`<J4@]2<@]2<P]2=`]2=0]2=@]2=P<J5@5900590@145`<T
M?`591`590P<T?@=0>0]8:0]8:@]8:P]8;`5J/`<T?05?5@5?5P<]-@<]-P<]
M-05T60]=40]=4@]=4P]=5`5E8@=$3`1>-`=$2@=$2P]A30]A3@]A3P]A4`5J
M/0=+0P=5;`=+10]D3`5X0P=+0@=+1`=?=P]F<@]F<P=1<@5Q70=5;@=5;0=B
M>0=B>@=9<`==20=?>`5Z?@5[(0=F-P=F*`99;01.2P<J5P]2>0]2>`5910<U
M(0195@=$30=$3@5J/@=0>P8\<`8\<08\<@9&+`4V100V(P9&+@9&+09&,`9&
M+P0[<`90+`0[;@90*@99<P90,`90+@90*P0[<00[;P90+P90+099>P5#?@99
M;@99<099=P99=099>@99<@99<`99=`99>099>`99;P99=@9C=`9C<@5*>P9C
M:P9C;`9C=@9C:`9C=P9C<`1(*@9C=09C;P5*?`9C<09C:05*?01(*P9C:@]-
M-`]--09C<P9C>`9C;0<J70<J6P<J9`<J7P<J7`52.@<J7@<J9@<J8@<J8`<J
M80<J8P<J6@<J6`52.0<J90<J9P195P1450591P<U*0<U)`<U+P<U(@<U+0<U
M*`<U)0<U+`<U*@<U)@591@<U,`145@<U*P<U,P<U)P<J60<U-`<U,0<U(P<U
M,@]8;0<U+@]2>@1960<]/0<].P<]10<]/`<]/@<]20<].@<]0@<].0<].`<]
M/P5?6`<]1P<]00<]0`<]0P<]2`<U-@]=50]=5P<]1`<]1@=$4`=$5@=$4@=$
M4P=$3P5E8P=$5P=$505E9`=$40=$5`=+2@=+1P=+2P=+2`5J/P=+3@1A;P5J
M0`=+1@=+3`=+301A<`=+20=+3P=1(P=1)P=0?0=1*@=1)`=1*P=1*`=0?`5N
M0@=1)0=1)@5N0P=1(@]F=`=0?@=1+`=1*0=5=`1G:`=5<@=5;P=5=@=5<`=5
M=0=5<P=5=P=1(0]H=@=5<0=9<0=9<@1I5P=9=0=9=@=9=`]J,@=9<P==.`==
M.0==.@1K*P==-P==,P==-`==-0==-@=??`=?>@=?>P=?>0=A6@]L00=C?@=D
M:P=F0`\M7@4P<`\R<`9&,@9&,P0V)09&,0\Y*`\Y*04]0`4]/@4]004]/P0[
M<P90,P0[<@90,@]`)0]`)P]`)@1!6`5$)05$(@5$(05$)`5$(P99?`]&*P]&
M+`]&+05$)@5+(@1(,`5+(P5+(05*?@1(+`1(+P9C?01(,@9C?`9C?@]--P]-
M.`9C>@9C>0<J:@<J:05210520`520052/P52/@520P52/0145P52/`<J:P<J
M;`]&*@]2>P]2?`]2?0]2?@]3(0<J:`521`520@5?60<U.P146P593@592P14
M6@<U.`5930592@<U.@5920<U.0<U-P592`<U/`]8;@]8;P]8<0]8<@]8<P]8
M=`]8=0]8<`]59`593`197`196@196P5?6@19805?7`197@<]2@5E:`<]2P<]
M305?6P]=60<]3`<]3@]=6@5?705E;`5E;P=$7P=$8P5E:0=$7@5E9@=$90=$
M8@1>-P5E905E9P=$80=$6@=$705E;@=$6P]A40=$9`=$60=$7`5E:P5E;0]=
M6`5E:@5J1P5J005J105J0@5J0P1A<@5J1@5J1`5J201A<0=+4`=+50=+405J
M2`=+4P]D3@=+5P=+5@=+5`=+4@=+6`=1+@1D=`=1-@1D=@5N1`1G;01D>`=1
M-`=1,P5N101D>@1D=P1D>0=1+P=1,0=1,@]F=0=1-0=1-P=1,`=1+01G:@1G
M:0=5>`5Q7@5Q7P1G:P1G;`=5>@5Q8`5Q80=5?0=5>0=5?@=5>P5T7`5T7P1I
M60=9>`5T70=9>0=9>@5T6@5T7@5T6P=9=P5V8@==.P==/`]K,P5V8P5X1`1L
M,@1L,0=??0=??@=@(0]K<`1M+`5Y5@1M*P5Y50=A6P5Y5P5Z1`=B>P5Z0P=B
M?`]L60=C(P5Z0@=D;`1N/@=E2P=E2@=E3`5[;`=F+0=F3@=F401N7`0V)@90
M-`]&+@]&+P]&,`99?01(-@<L1`<U/05:=`=$9@]D3P5Q8@]K<08\=`8N208\
M<P0V)P9&-`0V*0\Y+090-04]0@0[=090-P90-@]`*`]`*09:(099?@]-.P1.
M30<J;@<J;0<U/@=1.`=1.090.090.@90.`1!601!6P5$*`5$)P9:(P9:(@9D
M(@5+)01(.09D(05+)`]-/`9D(P1.3@521@522`521P<J<`<J;P]8=P594`59
M3P595`5940594@594P]8=@<U/P<]3P5?7P5?8`5?8@5?80]=6P<]405E<@=$
M9P5E<`5E<01>.05J2P5J2@5N1P5N1@=-4`=1.@5L1@5Q9`=6(@5Q9@5Q90]H
M>0=6(0=6)`=6(P=9>P=9?`==/05V9`]K-`=@(@5Z10=D(0=D;@=D;0\Y+@4]
M0P0[>`90.P5$+`5$*P9:)@9:*05$*@9:)P5$*09:)09:*P9:*@1!7`1!7@]&
M,05+)P1(/`5+)@9D)P9D)05+*`5+*01(/@5++`5+*@5++05+*P9D*01(/P9D
M*`9D)`9D)@<J<P5220<J=P<J=@1.40<J>0522@1.4@<J=01.4P52301.4`52
M3`523@<J=`522P<J>`<J<@<U1`5950596`149@147@1490595@595P<U0P<U
M1P<U0`<U00<U10<U1@<]6`<]6@5?8P5?:0199@5?90<]4P199P<U0@5?;0<]
M5P1990<]605?9P5?:@<]505?:P<]6P<U2`5?:`<]5`<]7`]=7`<]4@5?;`5?
M9@1>1`5E?`5E=`1>.@5E=@5F(@=$:@=$:`1>/P5E=P1>0`=$;0=$<`5F(0=$
M;P1>/05F(P=$<0=$<@=$;@]A4P]A5`5?9`=$;`=$:P5E>`5F)`=$:05E=05E
M>@5E>05E?01A>@5J405J5`5J3P1A>05J30=+6@5J50=+8P5J3@1A>`=+801A
M=@=+7@1A=0=+8@5J4`=+8`]D4`]D4@]D4P=+6P=+7`5J4P5J4@=+605J3`1E
M)`5N3@1D?05N3P5N2@=1.P5N2`=1/01E(05N3`1E(@1E)05N30=100=1/`]F
M>`=1/@=10P=10`5N2P=1/P5N4`1E)@=10@5Q;0=6*`1G;P=6*@=6*P5Q:@5Q
M:P5Q;`5Q9P5Q:`=6*0]F=P5T8`=:)@=9?01I705T80=:)0=:(P=9?@=:)`5T
M8P5T9`=:(0=:(@5T905V905V:`5V9@==/@5V:05V9P==00==/P==0@==0`5X
M1@5Y6`=@(P5X105X1P=A7@=A7`=A705Z1@=B?@=C(@5Y60=C(0=B?05[(@=D
M<`=D;P5[3`=E:05\-0=F+@=F.0=F.`5\3`4]1`1!8`1!8@9:+`5$+09D*P5+
M+P5+,05++@5+,`9D*@]-/05+,@1.50524`1.5`1.5@<J>P<J>@<J?`<J?0<J
M?@523P52405960<U20<U2@597`5970596P<U2P596@19:0<]7@5?;@<]7P19
M;`19:@5?;P5?<`]=70<]70<]8`=$=@=$<P1>1@=$=`<]805F)0=$>`=$=0=+
M9`=+9@=+:0=+90=+:`=+9P=11`5J5@5J5P=110=11@1E*`]F>05N4@5N405Q
M;@5Q<`5Q<@1G=`=6+`5Q;P5Q<0=:)P1I7P5T9@=:*`=:*05T9P==0P==1@==
M10==1`1L-0=A7P5Z1P=D)`=D(@=D(P5[305[;05\(@5$+@9:+0524@<U3`19
M;0<]8@=+;`=12`1E*P5Q<P=11P=6+0=:*@==2`==1P=A8`]`+`5$,`5$+P5+
M,P1(105+-`526@<K(0525`525P<K(@5250525@5260524P14:P526`]8>059
M7@<U30<]8P5?<05?<@5F)@5F)P5F*`1B(05J6`5J60=120=12@5N5`5N4P5N
M50=6+@5Q=`5F*05T:`5T:01I80]J,P==2@1L-@5[(P5\/P8T>P9&-04V1@4]
M2@4]2`4]204]1@0[?04]100[?`90/`0[>@1!;`5$.@1!:P5$,05$.09:+P1!
M:05+.P5$-P1!9@1!9P1!:@9:,@5$-@5$,@9:,`9:,09:+@]&,P5$,P5$.`5+
M/09D,09D,@5+-P5+1`5+.`1(201(2`5+.@5+-@1(3P5+0@5+.0<K*P5+0P9D
M-09D,P9D+@5+/`5+00]-/@9D+05+0`9D+`9D-@5+-09D+P9D-`52701.6P<K
M)0<K,`527`526P1.6`<K)`<K*@1(2@<K+@527@1.7@<K+0<K*0<U3P<K+`]3
M(P]3)`<K)P<K*`<K+P<K,0<K(P<K)@527P14;`598014;@59:0<U6`59:`59
M9@<U60<U5P5990598P<U6P<U4`59:@598@59:P599`599P14<0<U3@598`<U
M6@14<@<U5@<U7`]-0`]8>@]8?`]8?0]9(0]9(@]9(P<U4@<U4P<U5`<U5059
M;`597P]8?@59;019=019<019;@<]905?=P19>05?>`19=`5?=@5?<P5?=019
M;P5?>P<]:@19<@<];`5?=`<]9P19>`<]:P]=7@]=7P]=8`]=80]=8@]=8P<]
M9`<]9@5?>05?>@<]:`<];05F*@1>2@5F,`5F+@1B)`5F+05F*P=$>P5F+`1>
M2`5F,05F+P=$?`]A50]A5@]A5P]A6`=$>0=$>@=+=@5J70=+<`=+;05J7@1B
M+@=+<@5J7`5N5@5J6P5J6@=+=`=+;P1B*@=+;@=+=0=+<0]D5`]D50=+=P=+
M<P1E+@1E+05N6P5N60=13@5N6@1E,@=1301E,P5N6`=12P=13P]F>@1E-`=1
M4`=13`5N5P=03`5Q=05Q=@=6+P5Q>`=6.`=:,01G>@1G>`=6,P=6,0=6-@5Q
M=P5Q>05Q>@=6,`=6-`]H>@]H>P]H?`=6-P=6-0=:,`5T;`5T:P=:+0=:+P5T
M:@]J-`=:*P=:+@=:+`==4@==40==3P5V;`5V;01K+@5V:@==301K+P==3@]K
M-0==4`==3`==2P1L.`=@)`5V:P1L-P]K<@=@)01M+@5Y6@5Z2`=C)`5Z20=C
M)0=C)@1N(P=D)0=E309&-@90/P0\(090/04]2P]`+@90/@5$.P5$0`1!;P5$
M/05$/@9:-`9:-@5$/`1!<`9:-093,P5$/P9:-P1(6`5+2`1(505+1P5+1@5+
M101(4P9D-P1(4@9D.P9D.09D.`1.7P528@1.8@<K-`<K,P<K,@5280<K-0]3
M)0]3)@59;P59=P59<`<U70<U8`59;@59<P59=@<U7P<U8059=`59=0<U7@]9
M)059<@59<0<]<01:)05@)05@)@19>P5??`<]<`1:)`5F,@5@(@1:(P5??@5@
M(05@)`5??05@(P<];@]=9`]=90<]<@<];P1>4P=%(@=%)`5F-P=%)@5F-`5F
M.`1>5`5F.@1B,05F-0=%)05F-@5F.05F,P]A60=%*`=%(P=%(0=%)P=$?05J
M7P1B,P1B-`1B-05J8`=+>0]D5@]D5P=+>`=+>@=+>P=+?`5N7@5N805N8`1E
M-05N7`1E-P5N7P]F>P5N8@5N701E.`=60`1G?01H(05Q>P=6.05Q?`=6/`=6
M.@]H?0=6/P=600=60@=6/0=6/@=6.P=:,@]J-0=:,P==4P5X201L.P=@)@=@
M)P5Y6P=A805Y7`1M+P1M9@5Z2@5[)`=D)@]M)`5\1P=F508\=05`.0<K-@=+
M?05J80=60P1I9`5T;08T?`8T?08U(@8T?@4P<08\=@8\>`4]3`4V2@4V1P9&
M.@9&.`4V209&.09&.P900`4V2`9000901@0\(@4]30901`90100\)@4]3@9:
M.`4]3P900@]`+P900P0\(P9:0@9:.05$0@5$1`5$005$1P1!=@5$0P9D0P5$
M109:/`9:.P9D/01!<P9:.@9D/@9:/@5$2`9:00528P]&-P9:0`9:/P9D/`1!
M>`5$1@9D/P<K-P9D1`5+305+209D105+2@1(6@9D0@5+2P<K.09D00]&-@]3
M*`<K.@1.:P<K0`1.:@52:0529`59>01.:`529@52:P52:`1.;`52:@<K/`52
M90<K.P<]<P529P<K/@<K/0]3)P59>`<K/P5:(P1:)@5:)`14>P<U9@<U:@5@
M)P59>P<U:059?@<U9P59?`<U;P14>0<U:P<U<`5:)0<U:`<U8P59>@<U90<U
M9`<U;`5@*0<U;@<]=0<U8@5:(@<U;059?0]9)@]9)P]9*`]9*05:(0<]=`5@
M*`5@-`<]=P5@+05@+P5@,P5@*P<]=@5@,@5@-01:*P5@-@<]>`<]?0=%*@<]
M>@5@*@=%*P<^(05@+@<]>0<]?@]=9@]=9P<]>P5@,`<]?`=%+P5F/P5F.P1>
M5@1>7`5@.`1>705F/05@-P5F/`=%+@=%+0=+?@1>7@5F/@=,(@=15`=%+`=%
M*0=%,0]A6@]A6P=,)0=,(01>50=%,@=%,`5J9`=,(P5J8@1B.P1E/0=14P5J
M:05J9@5J:`5J:@=1401B-P5J9P5@.05J8P=14@1B.0=16`=,)`=15P1B.@]D
M6`]D605J90=15@5J:P1E/@=150=160=17P=61`5Q?0=18`5N901E/P5Q?@5N
M9`=17@=18@5N8P=,)P=180=16P=17`=170=610=18P=16@5R*`5R(@=61@1H
M)05R)`5R(0=61P5R*P=62`5R*@5R(P5R)P5R)0=6205R)@5R*0]H?@1I9@5T
M;@5T;P=:-P==5`=:-@5T<`=:-0]J-P=:-`5V;@==5@5V;P5V<`5X2@==505X
M2P5X3`1L/`=@*`=@*@=@*05Y70=D)P5[)08\>09&/`9D1@<K009D2`9D1P52
M;`15)`15)0<^(@<^(P<U<0<U<P<U<@=,*0=,*`=%,P=-<P=19`=@*P1N)@\R
M<01!?`9:0P5'5`9D209D2@]-00]3*09D2P<K0@]3*@]9*@<U=`]=:`<^)`=%
M-@5F005F0`5F0@=%-0=%-`5J;`1B/01B/@=,*@=190]F?`5R+`]I(0=62@==
M5P5Z2P4V2P4V3`4]4`902`]`,0901P5$209:109:1`9:1P9:1@5+409D309D
M3@5+4`1(809D3`9D4@5+3P<K0P]-0@]-0P]-1`]-10<K1@9D3P9D405+4@<K
M2@52<@<K3@<K1P5:,@52=`52=P52;052<`52;@52=0<K1`52=@<K2`52<P<K
M2P<K2052;P<K10<K3`52<0]3*P]3+`]3+0<K30<U>@15+`<U>05:+P15*@15
M)P15*P15*`<U=05:*015*05:,`5:+0<V)`5:,P5:)P5:,05:-`5:*P<U?`<U
M>P<V)@<V(0<U>`<V(P5:*@<V(@]9+`5:*`<U?0<U?@<V)P<V)0]9*P<U=@<U
M=P5@.@<^+`5@.P<^)@1:+P<^)P<^)05@/`1:+`<^*@<^*P5+4P<^*`5@/@5@
M/0]=:0]=:@=%/`5F3`5F2P5F1P1>9`5F205F2`1>805F105F3@1>;01>:01>
M:@1>9@5F3P5F0P1>;`=%.P=%.@=%-P5F2@]A70]A7@]A8`1>:P]A7`=%.`5F
M1`=%.05F305J;05J<P5J;P1B0P=,,05F4`=,+`5F1@5J<05J<`5J=`=,*P5J
M<@5J=@1B0@5J=P=,,@=,-`5J=0=,,P=,+0=,+@=,+P]D6P]D7`]D70=,,`-7
M-@=,-01E10=1:@=1:05N;@5N:05N:P5N:`1E0@5N<`]F?01E0P1E1`1E2`5N
M<05N<@5N9P=1:`1H)@5N:@5N;P5N;`=1:P=1;P=1<`=1<0=1;0=1;`]F?@]G
M(0=19P=1;@=2)P=19@5R+P5R+@5R,01H)P5R,@5R,`1H+`=630=63`=63@=6
M2P]I(@=63P=64`5T>`=:/05R-`=:00=:.`5T<0=:.P5R,P5T=`5T=P5T<P=:
M0`1I;`5T=0=:.0=:.@=:/`]J.`]J.0]J.@5T<@5T>0=:/P==7P==705V<05X
M3@==7`==605V<@==6@==7@==6P==8`]K.`]K.0==6`5X3P=@,0=@-`5X30=@
M,P=@-@=@-0=@+P=@,`=@+`=@,@5Y8@=A8P5Y8P5Y7P1M,05Y8`=A8@5Y7@5Y
M801M,@=A9`5Z3`5Z301N)P=D*0=D*`1N0`=D<@=D<P=D<0=E3@5\(P=E:@=E
M>@=E>P=F1`4]400\)P9:209:2@9:2`9:2P1(8P1(905+509D6`5+5`1(9`9D
M5@9D4P9D5`9D509D5P1.<@1.<052>@52>0<K4@<V+`52>`52>P1.=P<K4`<K
M5`<K401.>`<K4P5:-@5:-015,P<V*P<K3P<V*@<V*0<^+@1:-`<^,@1:,@<^
M,P5@/P<^,0<^+0<^+P<^,`5F60=%/@1>;P=%/05F5P=%/P5F4@5J>`5F505F
M4P5F5@5F6`<^-`5F5`=,.P5J>@5J>0=,.@=,-P5J?`5J?05J>P=,/0=,/@=,
M.0=,.`=,/`=,-@1E2@5N=05N=`5N<P=1<P=1=`=1=01H+P5R-@=65P1H+@5R
M-05R-P=64P=65`5R.`=650]I(P=65@=64@1I;0=:0@1I<`=:0P1I;P=:1`==
M90==9@5V<P1K-@5V=01K-P==8@5V=`==9P==80==8P==9`1L/P5X4`1M-`=A
M90]K.@=C)P5Z3@=C*`=D*@=D=`5[;@1"(P1(9@5&9`5+5@9D6@]-1@]-1P]-
M2`9D60<K5@]3+@]3+P<V+@<V+0]9+0]9+@1:-@5@0`]=:P]=;`=%0`]A80]A
M8@=,/P]D7P5N=@]G(@]G(P]G)`]G)01H,0=66`=:10==:`==:0==:@=@-P]K
M<P=A9@=A9P=C*0=D*P1N*`=E?`9020902@9:309:3`]&.@]`:01(:`5+6`9D
M8`9D7P9D709D809D6P9D7`5+5P5+6@52?@<K5P<K6@1.?@<K6`53)`1/(@<K
M6P53(P1.?`1.?052?`1.>@52?053(@53(0<K7`<K60]3,`]3,0]3,@]3,P<V
M+P15-P<V,05:.@<V,`15.015-`15.P5:-P5:.015.@15.`<V,P5:.`]9+P]9
M,`]9,0]9,P<V,@1:.@1:/`<^.@5@005@1`5@0@<^.`5@105@1@5@0P<^-01:
M.0<^-@]=;0]=;@]=;P<^-P<^.0<^.P=%0@5F7@1><05F7`5F8`5F7P=%1`5F
M80=,0`=%0P1><@5F6@1>>`5F6P]A8P]A905F70=%00]A9`1B30=,0P=,1P5J
M?@5K(05K(P1B4`=,2`=,1@=,005K)`5K(@=,10=,0@1B2P=,1`]D8`]D80]D
M8P5N?`=1=@5N=P5N>P5N>@5N>01E4`1E3`5N?@5N>`1E2P=1=P=1>`=1>P=1
M?`]G)@]G)P]G*`5N?05R.P5R/@5R.@=6601H,@1H-`5R.01H,P5R/0=66@5R
M/`=67@]I)`=66P=67`5U(05T?`=:1@5U(@5T?@5T>P5U)05U)`5U(P5T?05U
M)@=6701I<P=:1P=:2`]J.P]J/`5V=P1K.`1K.05V=@==;`==;0==:P]K.P1L
M0`=@.`5X401L1`1L0@5Y90=A:`5Y9`1M-@]L0@]L0P=A:05Z3P=C*@=C*P=D
M+`1N*05[)@]L<@=D=P=D=@5[3@1N5`8C/08C/`5$2P5+6P5+7`9D8@<K70<V
M-`<^/`=%101>>0=1?@=67P5R0`=:20=@.@=@.05X4P5[3P<K7@1/(P15/`=%
M1@=2(0=680=68`=:2@==;@]L<P5[4`1")`9:3@9D9`9D8P<K7P<V.`15/@5:
M.P<V-@<V-015/0<V-P5@1P<^/01>>@=%2`=%20=%1P=,205K)0=,2@1E40=2
M)`=2(P=2(@=2)0=68@1H-0=69`5R0@=68P=690=69@5U)P=:3`==<0==<@5V
M>`1I=01K.@==<`5V>0==;P==<P1L1@1L10===`=@.P=A:P=A;`5Z4`=C+`=C
M+0=C+@1N*@=D+0=D>0=D>`=D>@=E3P5\)`1N405\+0=E?0=F2@=F2P902P4]
M4P9:4@5$3@9:401")@5$3`9:4`5$301")09:3P\Y,`\Y+P9:4P5+7P5+8`5+
M805+7@5+705+8@9D:`9D909D:0]-20]-2@]-2P9D:P9D9@9D;@9D;`9D;09D
M:@9D9P1/)P53*0<K80<K8`53*`53*P5:0053*@1/)@<K8P53)0]3-`]3-0]3
M-@53)P<K8@53)@5:/`<V.@5:105:0P<V.0150`5:1`<V.P]9-`5:/@5:/05:
M/P5:0@<V/`5:0`1:/05@205@3`5@4`1:/@<^/@5@2`5@2@5@3P5@30<^0`<^
M00<^0P]=<`]=<0]=<@5@3@<^/P<^0@5@2P5F8P=%2P1>>P5F:0=%3@5F9P5F
M90=%3P=%3`]A9P=%2@=%405F8@=%30=%4`5F9@5K)@5K*0=,2P5K)P=,3`=,
M30]D9`]D90]D9@]D9P5F9`5K*`=2*P1E4@=2*@5O(0=2*0=2*`5O(@=2)@]G
M*05R1`5R1@5R2`1H-P=69P=6:`]I)05R105R0P=6:05R1P5U*@1B40=:4`1I
M>`5U*`=:3@1I>05U*P]J/05U+`5U*01I>@]G*@=:305V>P5V>@]I)@5X5`5X
M501L1P=@/P=@/@=@0`=@/05Y9P5Y9@]L1`=C+P1N*P=D+@=D+P1N005[405[
M;P5\)05\0`0P0P1"*@1")P9:501"*`9:5@5$3P]&.P9D;P5+901(;`5+8P]-
M3`]-305+9@1/+P1/,P1/,01/+0<K:`53,053,`<K90<K9`53+@1/.`53,P53
M+`53+0<K;`<K9@1/-@53,@]3-P]3.@]3/0<K:P<K9P<K:01/+@]3.053+P5:
M2`5:1@<V/05:20151@1:1@5:3@5:301520<V0P<V/@<V00<V0`5:3`<V1`]9
M-@]9-P]9.0]9.@5:2P<V0@]9-05:1P<V/P5@5@1:2`5@5P5@5`5@4@1:1P<^
M2P5@50<^1@<^30<^101:2P<^3`5@6@5@6`<^1`1:2@]&/`]=<P]==`]==0]=
M=P]=>0<^2`5@6P5@4P<^2@5@405@605F=P5F=`5F<`5F:P=%4P1?*`5F;0=%
M4@5F:@5F<05F=05F<@5F;P5F;`=%5`]A:`]A:0]A:@]A:P]A;`]A;0]A;@]A
M;P]A<0]A<P=%50<^1P5F=@5F<P=,6P=,6`1B7@=,4@5K+01B4@5K+P=,3P=,
M401B7P5F>`1B8P5K,@1B6P=,3@1B6@1B90=,6@=,4P=,601B6`=,505K-@5K
M+@=,4`5K-`]D;@]D:`]D:@]D;`]D;P]D<`]D<05K,`=,5`=,5P1B4P5K-P5K
M*@]D:05K+`]A<`=,5@5O)P=2+@5O)@5K.`5O*0=2+`1E6`5O*P=2+P=2+05O
M*`1E5@5O)`=2,@1E7@5O)05O(P1E8`=2,`5O+`=2-`]G*P]G+`]G+0]G+P]G
M,`]G,0]G,@]G+@5O*@]G-`5R2@1H/P5R3P5R4P5W(P5R205R4@1H.`=6<05R
M3`=6<@5R5P=6;05R5`5R30=6<P=6=0=6:@=6=`5R5@=6;@=6;P]I*`]I*0]I
M*P]I+`]I+0]I+@]I+P]I,`]I,0]I,@=6:P=6;`5R50=6<`5R4`=:5`=:4@5U
M,@1J(@5U+@5U+P=:6@=:5P5U,`=:7`=:605U-`=:5@=:6P=:4P=:50=:40=:
M7@]J00]J0@]J0P]J0`=:7P5U,P=:6`=:705U,05V?@==>`5W(@1K/@1K/P5V
M?`===P1E7`=@1@===0=>(@===@5V?0=>(0==?`5W(0==>0]K/0]K/P==>@==
M?0==?@==>P]K/`=@0P5X7`5X8`5X6@=@001L3P1L3`5X605X801L2P5X7P5X
M7@5X5P=@2P=@1P5X6`]K=0]K>`=@2`=@0@=@1`=@105X70=@2@=@20=A<P5Y
M:`1M.`5Y:0=A;@=@>@=A<0=A;P5Y:P=A<@=A<`]L10]L1@5Y:@=A;0=C-0=C
M,`=C,@=C,P=C-`5Z405Z4@]L6@]L6P]L7`]L70=C,05[*`5[)P=D,`5[*0]L
M=`=D,05[*@=D,@=D?@5[4P5[4@5[50=D?`=E(0=D>P5[5`=D?0]L=05[<P5[
M<@5[<05[<`=E4`5\)@]M*P]M+`5\)P=E:P5\+@5\-P=F+P5\-@]3/`]=>`]K
M/@903`]`,P90301"*P9:5P5$405$4@9:7`9:6`9:605$4`9:6@9:6P9D<`5+
M:@9D<05+:01(;@1(;P9D<@9D<P9D=`1(<`5+:`]-3P]-4`]-405+9P1/10<K
M<@<K?0<K;P<K<P<K>053-P53.P53/053.0<K=@<K?`53/P53-`1//0530053
M/@53-01//@530@<K>@1//`<K=01/0P1/.@530P1/1@<K<`<K>P]30`<K;@<K
M=P<K>`53-@53.@530`<K<0<K=`53/`<V2P5:5`5:5@5:405:3P153`5:4P5:
M605:4@<V5P<V4@5:5P155@<V5`5:6`<V4`5:50<V4P<V3`<V10<V3@]9/0]9
M/@]9/P]90`<V30<V3P<V6`<V5@<V1P<V2`<V50154P1540903@<V205:4`<V
M1@]6,P<^401:3`5@7@5@:0<^5`1:4P5@9P<^505@705@80<^3@5@9`5@:P5@
M8`5@8@1:5`<^5P5@7`5@8P1:6`<^3P1:6P5@;`<^6`<^4P5@:`5@:@]=>@]=
M>P]=?`]=?0]>(0]>(@]>(P]>)0<^4`5@7P1:6@<^5@5@905@9@<^4@1:5P=%
M6P5@;0=%7P5F?05G)05G)P1?+@5G*@5F>@5G(05F?@5F>P=%70=%6`1?+0=%
M7@5F?`5G*P1?,`=%9P5G(@=%9`=%7`5G*`=%80=%8@=%9@5G)`=%605G(P=%
M:`=%5@=%8`]A=`]A=0=%5P5G*0=%8P5K.0=,705K.@=,8@5K/@5K2@5K0`=,
M:@=,9`5K.P=,:`=,:P=,8P5K3`5K/05K2P1B:P5K0@5K10=,8`=,7@5K2`5K
M1`=,7`=,9@=,;`5K001B;0=,:05K1@]D=`]D=@]D=P=,805K1P=,;P5K20=%
M:0=,90=,9P=,;05K0P=,;@=,7P1B:05O.`5O,`=2.@1E905O/@=20P5O,@5O
M0@1B<`=2-@5O+P1E8P5O,01E;@1E:`5O,P5O+05O-P5O1`5O.01E;01E9@5O
M.@5O/`5O0`1E9P5O+@5O.P5O-@5O/P=2/P=2.P=20`=2-0=2-P5O/05O-05O
M-`5O0P=2.`]G-P=2/@=2/0=2.0=21`=200=2/`]G.`5O00=%6@5R7@=6>05R
M9@=6?@5R705R8`5R6P5R905R9`=7(0=6?0=6>@5R:`=7)P=7)@=7)`5R7`5R
M805O105R6@5R8@=7(@=6?`5R:05R:@]I-`5R7P=7(P=6=P=7*`=6=@=6>P]I
M,P5R6`=6>`5R60]G-@5U0@5U/01J)`1J+05U/`1J*`5U0P5U.05O1@5U1`5U
M0`5U/P1J*P=:8@=:;`=::@=:<`1J*@=::P=:;@5U.P1J*0=::05U-P=::`5U
M.`5U1@5R9P=:<05U00=:;P=:9P=7)0]J1`]J10]J1@]J1P]J2`5U/@=:9@=:
M9`=:80=:8P5U.@=>*P=>)P=>,05W,P=>+P5W+@5W*01K0P=>,@=>-@5W)05W
M,`5W*@5W*`5W+P=>+`5W)P5W)@5W.`5W*P1K201K0@=>-05W,0=>,`=>,P5W
M+0=:905W-0=:;0=>-`5W-@=>+0]K0`=>)`=>)@=>+@=>*0=>*`5W,@=>*@=>
M)01K00]K>@=>-P=@305X9P5X:05X;05X905W-P5X:`=@3@5X:@5X:P=@3P=@
M4`=@5`5X;`=@4P=@3`=@405X8P5X9@5X8@]K>0=@4@1L505X9`1L4P5Y<05Y
M;05Y<`=A=@1M.P5Y;@5Y;`1M/`=A=`5Y;P=A>`=A=0=A=P1M/@5Z6`=C.05Z
M5@1M:P5Z6@5Z605Z505Z5P1M:@=C.`5Z5`=C.P5Z6P=C/0]L7@=C.@=C-@=C
M/`5[+@=D-`=D-@5[+P5[+`5[*P5[,05[,`5[+0=D-P]L=@1N+@=D,P=D-05[
M5@=E(@=E4P=E)`=E)@=E(P=E)P5[5P=E)01N0@5[=`=E5`=E505[=0=E4@=E
M5@=E40=E;0=E;`5\*05\*`]M,@5\+P=F(0=E?@5\.`=F,`5\.0=F.@5\00]M
M-P5\2`=F101(<01(<@531`<L(@<L(0<K?@5:6@5:7`<V6@<V6P]900<V605G
M+`<^601B<0=,<`5K30=,<0=21@5O2`5O20=21P5O1P=220=22`1H10=7*P=7
M*@5R:P=:<P=:<@1K3`=>.`=>.05W.0=@501L5P5Y<@1M/P=C/@5[,@9:70]&
M/05+;`]-4@<L*`5310<L)P<L)@<L)`531@<L)0531P<L*0<L(P<V705:70]9
M0@]90P]91`5@;P5@<@5@<`1:7`5@<P5@<0<^6P<^6@<^7@<^70]>)@5@;@=%
M;@5G,05G+@5G+0=%:P=%;0=%:@5G,`=%;`]A>`]A>0]A>@5G+P5K3P5K3@5K
M401B<P=,<P5K4`=,<@5H0`=22P1B=`1E;P=,=`]G.0=22@=23`5O2@1H1P=7
M+`=7+01H1@]I-05U1P1J+@]J205W.@5W/`5W.P=>.@=>.P=@5@1L6`=@5P]K
M>P5Y=05Y=`5X;@1M0`1M;`]L1P=E*`=E5P5\1@=F1P9:7P9:7@5$4P]&/P1(
M=09D=0]-4P532P532@1/3P5320532`<L*P<L+P<L*@1/3@<L+`533`<L+@<L
M+0<V80<V7P<V7@<V8P156P<V8@9'4P]9105:7@<V8`5@=`5@=0<^8`<^80]>
M*`<^8@<^7P=%<`5G,@=%<@5G,P5G-0=%<P5G-`]A>P=%<0=%;P1B>@1B>`=,
M>0=,>P=,=05K5`5K4@=,>@5K505K4P=,>`1B>P=,=P=,=@5O2P=24P=24@5O
M3`=24`1E<`=23P5O3@5O30=240]G.@=23@=2305R;`=7+P5R;P=7,`5R;@=7
M,0=7+@5R;05U2P5U3`=:=`5U205U3@=:>P=:=@=:=P=:?`=:>05U2@=:=0=:
M>`=:>@5W/P1K3P5W/@5W0`5W/05X;P5X<05X<`=@60=>/`1L60=@6`1M;0=C
M/P=D.0=D.`5[6`=E*01N4@5\,`\I(0]&/@]30@]>)P5+<`5+;@5+;P533@1/
M4`5330<L,`5:80<V9`5:7P5:8`]91@5@>`5@=@]>*05@=P5G-@=,?`5K5@=,
M?01E<P=7,@5R<`=:?@1K4`=;5@=>/01K405\,0]-5`<L,@5:8@5:9`5:8P5@
M>@5G.`5@>05G.05G-P5K5P1C(@]D>01E=01E=`5O4`5O3P1E=P=25`=250=2
M5@]G.P=25P5R<P5R<@5R<0=7,P=7-`5U3P1J+P1J,`=;(P=;(@=;(0=>/@5X
M<@=@6@5X<P=A>05Y=@=F)P1(=@533P1/40<V:`<V9@5:9@5:905:9P5@?@<^
M9`5@?`<^8P5@>P1:7@5@?0<^90<^9@5G.P5G.@1E>`5O405O4P5R=`=7-@=7
M-0]I-@5U4`1K5`5W0@5W001K4P=C0`=A>@1M;@5[6@=E*@5[609D=@5$5`9D
M>`9D=P<L-`1/501/5`534`<L-0<L-@<V:@5::@5::`5::0<V:0<V:P<V;`1:
M8`<^:`5A(0]>*@<^9P5G/@5G/`=%=`5K6`5A(@5G/P5K6@5K605K6P5K705K
M7`=-(0=,?@5O5@5O5P=26P5O6P5O605O50=26`1E?@1E>P=27`5O6@1E>@=2
M6@]G/`=260=7.`1H4P1H405R>`1H4`5R>P=7-P5R=05R>05R=P1H5`5R=@1H
M501J-`=7.0=7.@5R>@5U401J,P1J-0=;*@=;)P=;)@1J,@=;*0=;*`5U4@=;
M)05W1P=>005W1@5W1`5W105W0P5W2`=>/P5X=@5X=P=@701L7`1L8`5X=0=@
M7`5X=`1L7P1L7@1L70=>0`=@6P5Y>`5Y>05Y>@5Y=P1M10=A>P=A?`1M1@5Z
M7`=D.@=E*P1N,`=D.P5[,P1N+P5[6P5[7`=E+`1N2@5[=@=E;@5\2@=F4@=%
M=01F(@5R?`1H5P5W209D>0<L.`<L-P5A)`<V;01:80<^:0<^:@=%>`5G0@=%
M>0=%=P=%=@1?00=-)`=-)0<^:P=-(P=27@=27P=2705R?0=7.P1J-@=;+`=;
M,0=;,@=;+@=;,`=;+0=;*P=;+P5W2@=>0@5X>`5Y>P5Z701M1P=C005[-`=C
M0@=E+0903P<V;@<V;P5::P=&3P=E+@5:;`5A)0<^;05G0P=%>@5G1`]A?0=-
M)P5K8`=-)@5K7@5K7P1C)01F(P=28`1J.01H6`=7/`=7/05U4P=;-`=;-05U
M501J.`=;,P5U5`=>0P=@7@5X>0=@7P5Y?`=C0P5[-05[=P<L.05:;0<^;@5:
M;@5A*`5A*@5A*P5A*05A)P<^<`5A)@<^;P5A+`1:8@=%?`=-+`5G1P5G2`5G
M1@5G10=%>P=-*@5K805K8P5K8@=-+0=-+@=-*0=28@=29`=28P5O705O7@=-
M*P=2905O7`=2805S(05R?@=7/@5U5P=;-@5U6`5U605U5@1J.@=>1`5W2P1K
M60=>2`1K5P1K6@=>1P=>1@=>105X?01L8P5X>P5X>@=@8`=A?@=A?01M205Y
M?05[-@5[>05[>`=E;P=F(@1/5P<V<`<V<0<^<@<^<05G20=%?@=&(0=%?05K
M9`5K90=29@5O7P5O8`=2:`1H6P5S(@=7/P=70`5S(P5S)`=;-P5W3`=>205X
M?`]K?@=@805Y?@5Z(0=C1@5Z7@=C10=D/`1N4P5\,@]`-`159`1:90=&(@1C
M*`=-+P5M5P1F)`1J.P]I-P5Z(P5Z(@=B(0=E+P5A+@<^<P=&)01?1P=&)`=-
M,`5K9@1C*@=-,0=--`=-,@=-,P=--0=--@5K9P=2:P5O8P5O8@1F*`=2:01F
M*@=2;01F*0=2;@=2:@1(>`=2;`=71@5S*@5S)P=70P=70@1H7@5S*`1H7P1H
M70=71`5S)05S*P=710=71P5S*0=7005S)@=;.`1J/@5U7`5U6P5U7@=;0`=;
M/P5U7P=;.@5U8`1J/P=;.05U6@=;.P=;/0=;/@=;/`5U705W3P5W3@1K7@1K
M8@1K8P1K7P1K8`5W4`=>3@=>3`1K70=>2@=>2P=>3P1K9`1L9P5X?@=@9P1L
M:`=@905Y(0=B(P1L90=@8P=@9@=@9`=@8@=@:`5Y(@1M3@1M2@=B)05Z)@1M
M4`1M305Z)`=B)P1M3P=B)`=B)@=B*`=B*0=B(@5Z)0=C2`5Z8`=C1P5Z8@5Z
M7P5Z80=D/@1N,@=D/05[-P5[.05[.`=D0`=D00=D/P1N1@=E,@5[70=E,0=E
M,`=E60=E<0=E<@5\*@=E<`=E<P5\,P=F)`=F(P5\.P=F,@5\.@=F,0=F/0=F
M/`5\10=F00=F2`5\3@5\305K:`=--P1C+`=2<`=2;P=.)`5O9`=72`]G/0=;
M0@=;00=;0P=;1`5W405\40<V<@<^=`=&)@=7205O901F*P5O9P5O9@1F+`=2
M<P=2<0]G/@=2<@5S+`5S+@=72P5S+P5K:@5S+0=4*@=72@=-.0=-.`5[7@=A
M*05[.@5W4@=D0@]M+05\0@\I)@5S,`=B*P=B*@5Z9`5Z8P=C2@=C205[.P1N
M1P=F)01N5@=F3`8I-@8A,08A(08E9@8E<@0E/08N80\M:`8]-0906P0\,`9:
M<@]9308C4@,D4@,G4P]G0`,G5`8]/`=-/@8A4`,B>P8C60,A3P8U1`0A/P8B
M/`,D00<V>@4A*08A.`\C-P8I8P8N=@9&9P-`0P\B*08O)08U6`0V3`0A+P8B
M1@,B)08B20,C*08O.`9&=`8J(P8O/08]608]6@,Z)@\A,P,D*08A808F0P4Q
M,08B6P4A8`,C/`0C7`8F3@0C6P8J/`,P(P8U?@0P=@8]?`9'*@9'+`9',`9'
M,09',P0\4`9;6P91-@9;60<A8`<L90,A?`8D,P8V-08^+`8^*P,T<`0V=@91
M2@<A=@=&/@\C6P915P4C8@8D.P917@9'5@8B9P\J*P8V3`8V30\N;08^5`8^
M4`9'8091:0]'1@-:,P=&408D2`0Q,`]!*P9<(@-:-@=@;08G(08V9P8D2P0A
M-`4H<P9'>P0A-0\F8@,L0`8P3@9(*P9(-0-`?@92,P9</08G-@9<20\A7P9(
M-P8W+`9(/`<M4P<M50=@;@4I)P8_1@8_10,U7P920`5%708A=`8G2@8K+P8P
M=`\J708K.0<M8P5S0`,L408_7@4M2`,U908G7P\D,P4D.`8Q-@8Q,`\J9P0I
M2@9(?`9(>`-&<`92;`929@9=)@9=)`1#40<M:0<M>0<B>P-48`1;+`='*`,F
M)P9`(P4B;@8K8P8K8`8Q3P\K*P8W<0,V*`9`-@9`*P9)2@9),`]!7P<C,`9=
M.`5&+`<C+0]/)01*)P<X.0]><`0M1@9)5P]:-@,V0`8X-@]!<@93/`5&00\K
M.`8Q;09`5P9)>`9=6P8L(P4F2@0R/@9`6`4_9@0D1P8H+@\D400F:`,M-08X
M2@,Q7`0M7`8X4`4R?@,\.@937@4_<0-!;@9=:`<C<@]4=`<N:@1?=@=8(P8E
M(P9*/P<C>`=><@](>093=P0M90\U=`9*308L0@](>P8E+@\D708L6P8L40,M
M4@8R.08R0@0J)00M<`8Y+08X=`8Y(0\P6P,V=09*909*8P0^,P9420943P]"
M=`9>/@<D3P<D6`]/:0<O0@]55@1670=.*`=38`=36`8L8`8L708R2`0X:`]#
M+P9460]0/0]56`5[>P-5109!809!8P9!:@9>7@8R8@9+0@='=08B)@\D>`8M
M)`\L.0\Q*`9+1P]#9`1$;@=`8P]C)`9"(0,]/P8R>00J1`4S909+5@0^;`9"
M,@]*+P=3>P8M.@4S<0]6/`8M108M/08S/08S,04O)@\L5P8Z+08Z+@9"2`9+
M>@]07P<P2@8E/P8M1@-#,P95:P<E>P<Y;0\H/`8S2@\]8`1+8`<F)P8Z0P9"
M9P1%7P12(0<P9@9?=0<F/@<F/`<P<P]*>P9@(P]1(P<F30=!/`5L?0<Q+0<Z
M,P1<60=!1`,N5@8S9@-(:@]1-P<F:@<F:01D)@=B309,<@<Z1@\^,@<Z20=(
M;0=?/`9-(P]7)P0K)@<G*`]7*`9@705(=`]<+08H>P0G:`8M:0,S4`4[4`9-
M2`]$:`]+5P]+5@1,5@18+00T5P9-7@-$)09A)0,G*@8E4@8I)P\H7`8I*`8N
M(@8N(P8T1`8N)`8[4@\R.@0T<P9$*P0T=`9#=@9$.P0Z9@9$/@9$/`9$/09.
M.P9A/@9A3P]19`1,>0<G80<G;0<R1`]71P<Z;P]@70="/`=47@1G*P8T1P1`
M3P<[.`-;)@8[<00Z=09.1@1&?`1-,P]2)`<H+@]1?0="8`="7P-;+01D/P13
M3`8E4P4P/@98+@98+`]%/0<[80\X2@5Z.`8\+00U10\_.P9B1P<S3P=9008I
M*@984`987`-@?`8\.P<S>0<S<P\_4P-$;0<I1`8T700P+`<T,014-P<\808E
M6P0U<@991P992@<\:P]%<P9C4P9C3P142@]F7@=0:P]L/P9C6`<T>@<T<0]A
M2@90(@9C;@<U-0-6>`5?7@<]4`]8>`=+7P1E*@=+:P4]1P5$-09:,P9D,`19
M=@9D.@8\=P9:/015(P1>8`9D4`<^*0<K50]9,@=1>@=:8`1:60=%901?-P1B
M;@=2105U-@5U-0]L=P<^7`9&/@1H3P9:8`0H-`-<+P5340=-*`1(=P=>30``
M``````````````!YUO__B=;__YG6__^IUO__N=;^_\C6___8UO__Z-;___C6
M__\(U^__%]?__R?7__\WU__?1M?__U;7__]FU___=M?__X;7__^6U___IM?_
M_[;7___&U___UM?__^;7___VU___!MCO_Q78__\EV/O_--C__T38[_]3V/__
M8]C__W/8__^#V/\_````````````````````````````````F&"]BZ)@%0>H
M8"]RL6!@"+1@RCF\8.P(PF#VZLU@U^#68/RQX&"\7^M@/=/U8/_V`V%<B@IA
M=\,48?,D'&%?>2=A]/\T8?[N06$?=4MAMP-38;F?7F'ZXVEAO_YW87%`?&'_
MUHEA!#",8?BSEF'U'Z%A_(^L81'_MF'_#\)AEL#(8?O_UV'C_^1AA_?O8?__
M_V'P_PMB=PD38OY_(6+._RYB_QTZ8E9`/V+]?TUB_T]:8O[_:6)_*')BKO]_
M8O__CV*!^YABGQ&@8@/^J6+_WK=B$?_!8G_!RV*$W]1B_P_@8OS_[F+_3_MB
MCM`"8\__$&.?]1QCUP0C8Y[_,&/1#3=C07]`8^2-2&/^S51C;_Q@8S?P:6..
MOW1CT.]^8\SNB&-[/9-C^<^?8Q\OJ6-_O[=C7/O"8ZRYRV.S[-5CVR'=8]_?
MZV/MO_ACIX\"9/IS#61>;1=D7^TC9/WS,&3O+CMD,[1#9/_64&3/2EEDUC]D
M9/]_<V2^?X!DYO6+9/[\F&3Q?Z1DWOFP9+_ZO63O]<IDP;_49(^_X&2'[^MD
M[^_Y9,?I`V7&[PYEZO\;99__*66?XS1E_P]`9>'_3&7W^UIEQ!)?9?^_;F5O
M`75E__^%93\_D64&[YIEO^>G90+@JV7__[ME'S'#9?#_SV6/^-EE_O_H9?^?
M]F7`_P!F*_P*9O_I%V:-^"!FS]PK9M_[.6;>,4)F_L--9D?_668W^V5F]\]R
M9OP#>F;_H85FWY^29OO_H6;>]ZYF_\^\9KO_RF:[S]9FO]_D9C_]\69[U_UF
M/]X)9T]^%&=N_B!G_VTM9^TQ-F=^_T1G?SQ/9_-P6&<7Q6!GF]]L9W__>V?\
M/X=G[^N49UW_H6>M\*IG]R^V9Y_\PF?&_\YGW?_<9Q__Z6?0__1G?O\":'7L
M#&@I_A9HAU,>:+W&*&CU'S-H&YX\:/?%1VB+_5)H[O]@:/Z_;FB__GQH__^,
M:.O_FFA_V:9H_N^T:/]_PVC__=)HOP_=:$;_Z&C_?_=H^ED!:6@`!&DP_PYI
M_W\=:?[_+&EE@3)I`4`T:?__1&G_^U-I+_Y?:?_;;6F)`'!I`.YV:?__AFG_
M?Y5I`/B::?_/J&F3C[%I"`"R:0``LFG._[]I___/:0\$U&G^_^-I)P3H::4"
M[6D``.UI``#M:8!_]6F__0-J__\3:O[_(FJ`_RMJ_WDX:A$P/&I`(#YJ`&!`
M:N^/3&K__UQJ_]]K:O]/>&H`@'EJ__^):@@`BFH4`(QJ``",:@#PD&KS_YYJ
M__^N:D/`LVK__\-J?U7.:@P"T6H``-%J``#1:@`PTVK]_^)J?__Q:G\?_6K`
M_P=KXX0.:P$`#VO@_QIK__\J:_]`,VL`_#EK__]):PT`3&L``$QK`+Y2:_[[
M8&OO@&AK/SMS:P``<VL`C'9K__^&:_\3D6O`?YIK``"::P"@G&O__ZQKA`"N
M:WP'MFO^?\1K"0#&:_Z/TFL#`-1KD/?=:PI@X6M'_^UK:,[U:P\8^VN/(P-L
M_=\1;-I_'6S_"2=L'P0M;/_R.FR=_D9L\K]2;#QT6FR*TV)L%C1H;`2O;VS_
M$'AL[A!_;/__CVSX7YIL^Q&C;/!_KFSP_[IL?WG&;(G_T6S_`=ILPO_E;.V7
M\&SP_OMLW_L);?^'%6TZ`!EM\_\G;?_\-6W_0#YMX01#;8#?2VW[_UIMK_]H
M;;\`;VT`[G5M_X%_;?]'BVT[Z)1M?R^@;?]?KFV$A[1M%M^^;5\YR&W`!\UM
MQ'_7;4W^XFT;@>AMOS_U;0`V^6V_#@-NV!X+;G^_&6Z6CR)NH.\K;O>Q-F[A
M?D!N8'Q';F[_5&[?WV)NWO]P;E.M>6Z^]X9N//Z1;MWCG&Y*$:%N//.K;F__
MN6Z1_\1N=_K0;O6GVVY]"N-N_;_Q;I+W^V[A-0-O!?\-;\?_&F_CGR5OPUDM
M;SF--6\__T-O^&].;^W_7&\G_F=OGWYS;___@V_^NY!OZ_^>;W_AJ6__M+5O
M@O^_;_\/RV_D_]=O_U_E;QO_\6_?_P!PP?\+</]'%W!R_B)P__\R<)_@.W`_
M241PO_Y2</7X77#_(6=P++]Q</^^?W`A_XEP__*6</POH7#^/ZYP^'^Z<+;!
MPG#O^]!P-_S;<!+NXW"_]?!PQ[GZ<.0_!'%^WQ%QU]8<<>_G*7'_>39Q3O]"
M<<=N3''XVE9QKN5@<3^B:7$A\W%Q_/E]<<+WAW$-_I%Q\PV:<?_GJ'$;T*]Q
M_?^^<5/XQW'_P]-Q/\K=<?_W['$?_/=Q?\\$<MF-#7*_?QMRT/4D<O]_,W+\
M_4!R#?9)<H_X4W+YM%UR7J]H<HW7<G(;[GQR9GV&<F_FD7(CCYER..*@<@_`
MIG(AXJQRP@"O<A.(M')\YKYR5?O)<N_WUW+\'>%RG'[K<O<S]G)]_@-SP?4,
M<Q_X%G._+R)S_WTP<Y?^/'/_7TIS_O]9<\OW97-_3W%S]*=[<_O!A7/#.8US
MEL&4<W?YH'/N^ZUS^KNY<^^9Q'/#S<US^G_:<]A/XW,+5NIS_/_X<__O!W05
M_A%T"_L;=/^2)G3__S9T_^=$=/^!3G0$5U1T_]]C=/\7;W1@_WET3ZR"=!0`
MA'2\_Y%T[7^>=$#]IG04)JMT$OBR=/_^P73_*,MTHO_6=/_WY73W0^]T`'ST
M=/\_`G7@APEU0?00=?]W'G4Y_2EU^_`T=2$E.77E?T5U,_]1==S"677'>&)U
MPI]K=7*Y='6O_X)UC^N-=?]'F74?LZ-U'X*J=="*L'7_$;IU_9_'=?SWU'4_
M_N%USZWL=?_E^75OW@5V]O\3=E_X'G;__RYVF_TZ=O]O2';R_51V^=U@=O\(
M:7;_]WAV!.Y_=O_.C'9/[YAV9_ND=KCOKW8/GKAV%-"]=O[[RW;#_-5VUW_B
M=OFO[G;]__UVM_\+=X?^%G<_,1]W_/\M=W_].W=A_T9W__]6=U>077?_7FIW
M_?MX=W_UA7?_'Y)W_O"==_\UJ7?^K+1WY_G`=]VKRW?^>]AW[;_E=WK]\7=^
MY/MW]?\)>-W9%'C/SR!XVW0J>`^W-'C]+T!XQ]],>.,#4WC\!UQXT-]F>/]_
M=7C_O8-X?..->/^SFGB]WZ=XWS^T>/]?PGA>K\UX[^/9>)^7Y'CS__)X]_\!
M>?WK#GG]CQIY_?$F>2W^,7G_=S]YW_].>0/U5GG_+V-Y^_EP>8GA=WG__X=Y
MG_R3>=M>GGD>YZAYC_^U>?T^P7G]+\UYBG_7>;_YY'G_7_)Y)H[Y>?__"7I_
M9!-ZR8T;>O_]*GK_?SEZP/]#>D]!2GK__UIZ__]J>H/^='I_@'QZ`0Q_>O[_
MCGK__YYZ_W^M>H'_MWK__\=ZSXS0>KC_W'K__^QZ___\>K_@!GO_9Q-[!"`5
M>X+V'7O_]RQ[__\\>\__2GL?#%%[`#!3>]_?87O__W%[`?QX>__7AGL#4(I[
M_O^9>__/IWO_0[)[]O_`>QCAQGL`L,E[_O_8>_]`X7O_`.E[`O[Q>W__`'P'
M_PM\Q?@4?/_?(WSO`RQ\\/\X?']\1'P:_$U\G_U:?/+[9GP'_W%\XLMZ?'G^
MAGS?WY1\P(^;?,]_J'Q^F;)\]1^]?/CGR'SP?]-\/\[>?'NVZ7R4?_-\\FG\
M?&XC!'UE>PY]?P`5??S_(WW_\"]]GP(V??#]07W%?TQ]$`!-??3_6GW__VI]
MR?]V??]/@WT$G(A]__^8??]_IWW\_[5]7P6]?0``O7W>_\M]__?:?9_!XWW_
M__-]7Q'[?0``^WT(_@-^__\3?O__(W[_'S!^`/\X?O]_1WZM($U^`(!.?O_?
M77[?WVM^__][?F<!@7X"`()^^7^/?O_KG7Y_!Z=^_O^V?O]?Q'X#`,9^``#&
M?O]_U7[__^5^&^7N?O___GX)``!_`(`!?___$7__/Q]_P/\I?R,`+'^`^S1_
M_S]"?_`O2W_`_U5__\-A?W\#:G_X_W=_G_^%?Q>HC'_[AY=_!_">?[\.J'_\
MG[1_8\>]?^=WR7_W1]1_'N7=?_-LYW_C]O)_WF[]?^#_"(`S\1&`K_4=@$"L
M(H#_CR^`O^D[@//W2(#]A%&`_;M>@!W^:8"Y_W:`^G>"@,!OBH#_RY>`.W^C
M@/SCKH!'WKB`=V7"@/_]T8#Z--J`SMWE@*?W\8"_6OR`^KT(@7>6$H$ZRAJ!
M_^TH@6:_,X%/O3Z!6_M*@<;_5H&H^V"!%]]K@9/G=8'737^!]]N,@==?F(%/
M_*.!__^S@9Y_OX%Z#L>!_'_4@<D+VX'\_^F!0?CP@3\$]X'\WP2"3_P/@I^A
M&((`@!F"\T<C@N!_+8(?!32"_A]`@O@_2X(!_%*"7H!8@G/N8X+[P6V"7R5V
M@C"_?X+YP8B"*/R0@OR%F8*XX:&"R).H@OR_M8*/>;^"V)'&@E[[TH+_6-V"
M^!?F@C8^[X*=G_J".W(#@WZ_$(/O#QN#]_\J@Z/_-H-/:T"#B_],@X__68/_
M!V2#X?]P@Q^`=H/^_X6#/^V1@P;CF(/_@Z.#__^S@_^_PH/`G\J#___:@___
MZH.#__6#__\%A/__%81^`!N$`/@@A/[_+X3_?SZ$#_I(A/__6(3_GV:$CP1L
MA"D`;X1X_WN$]_^*A`X`C83Q_YJ$__^JA+D-LH2AZ+F$]__(A/__V(0/B-Z$
M_O_MA'\*]H00`/>$?_@#A?__$X7W_R*%?X<MA?__/87__TV%0X53A0!85H7_
MOV6%_^%QA?__@87XD8F%`):-A?[_G(7_?ZN%H/^UA?]:P87"&L>%___7A?C_
MY(7EF.R%]/_YA0?_!(8/D0N&?7\8AO[?)H81_B^&XW\[AJ#_189Y]E"&'UE9
MAJUO9(;>'6Z&__Y]AI__BX;/]YB&/ZRBAG__L8;OX[V&_YO*AO__VH:__^F&
MMW?UAC]R_X;VW@N'O_\:A_\[)X?M+S*'//\^A[X/2(?P]U.']H%;A^:_9X?_
M_G:'?^"`A___D(?_^Y^'Z_^MA\?_NH=_@\2'_BO/A_C[VX?_X^B'/[_UA]_<
M`8AM^0R(_YH8B/OV)8CO^S.(XS`ZB$_'1(C^NU&($?=:B'__:8C_W':(_O^%
MB"__DHBW_I^(/_2JB.]_N(C^_\>(!__2B+__X8B8_^R('S[VB.3_`HGNNPZ)
M]/\;B8?_)XE'?C&)7]P\B1]]1XG&VU&)L=]<B7_?:HE[S'2)]`-[B=_+AXD_
MX)")H_^<B?W_JXDW_+:)_R_#B?C_T(G_`-B)_O_GB7?@\(G__P"*_U\.BOS_
M'(K_?RN*5!,QBHK_/(K__TR*?_];BGX`88H@P&2*__]TBO^O@HK6`HB*8/B/
MBO__GXK__Z^*`P"QBOS_OXK?=LN*`.S0BO__X(K^_^^*`_#UBO__!8O_EQ*+
M5X`8BP"T'(O__RR+__\\BP>`0(O__U"+_Z]>BP\`8HL@B&6+^-]QB___@8O_
M_Y&+>2"7B_#_HXO__[.+#W^^BX$`P(OB_\R+___<BQ\`X8O^__"+\TGYBP*`
M^XO__PN,_\(6C/\W(XR!]"J,_O\YC/__28S_Q%2,__]DC&Z`:HS_[WF,%_R#
MC+\'C8P(OI2,]WNAC.#"IXS[_[:,7Q_!C/@ORXSN?-:,!B_=C%]OZ8R?^_:,
M?>\#C??E#XW`OQB-%_`@C8/_*XW_KSF-!X@^C?_@28W__UF-9PE@C>S_;8T'
M_G>-_P>"C0*BAHW^_I2-`/Z;C?__JXW_&[>-(("YC?3_QHW?^-*-___BC?^7
M[XT+!/.-BO_^C7_X"H[__QJ.?S\GC@#A*X[Y/S>.Q/]"CO_?48XT$%6.P.5<
MCO__;(Z_P7:.__^&CK_OE(X!XIF.\?^FCO'_LXZGP+J.Q+_$CH__T8YOS-N.
MW?#ECH4!Z8[_]_B.1_\$CXE0"8_>6!*/Z'T<CS^')H_U]C*/X_T^C]YY28__
MU%6/OQ%>C_U7:H\_`W*/+>M\C^O_BH__[YF/_WZGC^[_M8_[?\./_?_2CY]\
MW8^W_^N/@A_RC^__`9#ZO0V0.?,7D//_)9#_^#*0'?\^D!VV1Y"_^520URU>
MD+\/:9`<_W20?T-^D`'_AY!__Y:0!/^?D".(I)#^BJZ07^ZZD+V[QI#7/M&0
M7HG9D/__Z9!/L/&0_]\`D7O1"I'__QJ1=X$BD8#^*I$OL#*1!<,XD?O_1Y&W
M]E.1_S]AD7PM:I&`Y&^1__=^D?,;B)$@_I"1_V":D8/SHY'_?[*1?[Z_D2C^
MR)'_=]:1SX?@D?\/[)$K;_:1C[L!DMW/#9*U'Q>2?/DBD@_]+9(_G3B2YA]"
MDOC_3Y+P'UB2\#]BDO+[;I(K`'*2__^"DG?YCI(?\)>2__^GDM_"L9+]_+Z2
M!?S&DO^_U9+Y/^&2`/CFDC]_\Y+_"_Z2_/\,D_C_&9,W^".3__@PDX'_.I-]
M?T>3\/=2DW\W7I/QG6B3>/]TD_]]@I.>^XZ3QS^9DU_WII/QWK&3?_"\D[_Y
MR9/O%]23&?[>D^'OZ9-9/_.3QN_^DR\_"92+>Q.4^>\@E-_<+)2<<C24^64^
ME*/J1Y0__U64?_]DE`'X:I3EQW24^/^!E$MPB)3XZ9*4_S^@E(OXJ93G[[:4
M(;^_E/R-R903_M.43-[<E+]9YY3O\_24\\\`E9__#I6/.1>5DO\BE?\O+Y6`
M_SB5?QY#E?C_4)4_/UR5P`!>E?__;I7[?WR5(0!^E8#[AI7__Y:5_N.BE17^
MK)7__[R5?*+$E0#XR97_G]>56PK>E?/_[)7_/_J5P@/_E8#_");_(Q.6X'\=
MEB[!));^!RZ6_S@YEL>W1):_OU*6AW9;ELYW9I97[W*6\Y=]EH&^A98(_XZ6
M('N5EO\]HI9<>:N6Z<^VEN>_PY:G7\Z6_(;7EM[OY);SW_&6?KG\EG>V!Y?_
MVQ67?]\CE_O_,I?;GSZ7^?5*E_O?6)?S<V.7[M=OE[]O?)?\$X67\A^/E_P_
MFY?]_ZJ7_WNXE[@"O9?^_\R7$W[5EXC_WY?O?^V73S+UE^#[_Y?__P^8?QP9
MF&D`'9CX_BF8?_\XF!-/0)@PP$28[?]2F/\?7YC\!VB8@/EOF/__?YC__X^8
M?`"4F/'_H9CW1ZR8(0"NF(#]MIC__\:8'R?/F`'^UY@_O^28`8CGF/__]YCQ
M_`*9#N<+F6?\%IE?GB&9N,8IF;__.)GO_T>9_?Y5F?T78)GR'VJ9?_]YF0?"
M?YF2]XF9!YR0F?]XG)D;`*"9ZG^LF3\>MIG^-<&9\__/F9]_W)D,TN*9??_P
MF=>__9E44`*:D/\,FG\^&)K#_"*:__PPFO\@.9H"_$":_P=+FOW_6IH-_V6:
M_P=PFNC[>YK[Q8::XS^1FO__H9K\GZV:@/^VFG_<PIJ;^LV:?P+5FDSKWIH.
M_.>:ELWPFGIC^9I@?@&;4'@'FP/_$9L4_AJ;\#\DFQ#Y*YN''S2;"/\]F_\7
M29O`#T^;_P-9F^_]9YL0_W";'\!WF[^_A9N^GY&;OLR;F^F>I9N?_[.;NKV^
MFWU]RIO\_]B;>-[BFW\#ZYN$__6;!X+ZF_[_"9R@X`Z<_U\<G/P#))R`[2N<
M__\[G/\!1)P&`$:<_O93G.L?7IP0O&2<__]TG'D">IR#_82<?G^1G(!@E)SS
MOZ&</P"GG,C7L)SA_[R<OT#$G.]<SYS^U]R<G&_FG//_])R._P"=GT\+G?]_
M&IW`_R2=__TSG0OX.YWWYTB=9_]5G>"$6IW]_VF=)?!PG?^_?YT/Y(>=_P61
MG0Y\F9W_N::=#]VPG?T;NYW_?\J=?MO6G=__Y9T_C_"=\_?]G6_X")X(YP^>
M1_\;GN?A)9[[_S2>O_`_GO_N39Y^_%F>__MHGO\/=)[__X2>__V3GH/_GIX_
M\*B>_W^WGOWOQ9[@_]">1P#4GO__Y)[___2>__<#GV3Z#)___QR?__\LG___
M/)_W\$>?__]7GU\"7I_H_VJ?\_]XG^?_AI__WY6?_S^CG\'_KI___[Z?___.
MG_^'VI___^J?&.#OG____Y_W[PV@\'\8H`GP'J#__RZ@?R\ZH,#]0Z#__U.@
M^`]<H/#_:*#_\W:@\_^$H!__D:#W\9V@J<^GH-,3KZ#NN[N@^W_)H.[_UZ!G
M].&@URGJH/S_^*#P"_^@@/\(H9__%J%?$1ZA_O\MH7\>.*'P_T2A#X!)H?_S
M5Z$/_V.A]P%KH>#_=J'OCH&AXV^,H>CPE*'?_Z.A]_>QH5]^O:'__\VA_0W7
MH?C_Y*'OD^^APO_ZH?_W":+_`A*B_/\@HO_P+*+_`#2B6/\_HO]_3J+R_UNB
M$P!>HO_[;:*__WRBQ_^)HK,`CJ+Z_YRB__NKHOT!LZ+_![ZB`/[%HO\?TJ+\
M?]^B!O#EHO__]:(_X/ZBOQ4(H^C_%*-__R.C__@PH_^>/:-_^$FC/]]6H_K?
M8Z.O'VZCW_]]H^L`@Z,``(.C[/N/HW_?G:.WVZFC[^ZVH_W^Q*.\V\^CC^O:
MH__SZ*.?[_6C>/#]H_0_"*3'_Q6DG_DAI+_[+Z1OYCJD__I(I!]_5*3^W6&D
MS_UNI/?]?*3F]XBD!?Z1I.DOFZ3P)Z.D_(JLI)N?MZ3J_\2DX_?0I(^OVZ3U
M?^BD_7_VI/M?`Z7\]Q"E[W\>I='_*J4__SBE_Q]%I7__5*7X_6"E?[YMI7WW
M>J7.?86E&]",I=]GF*5Q_Z2ELW^PI7_ZO:6__<NE?[_9I:_SY:6__?.E_WT!
MIN?_#Z;F_QRF/7\HIO\?-:;\GT&F?_)-IO\G6:;_AV6F_Y]SIOY#?:;_[XRF
M/^F7I@W_HJ;\[:ZF_R^[IO^9QZ:'_].F_Y_AIO]S[J8>__JF_W\)I_PO%*<^
MP!NG_?\JI_M^-Z?8`CRGW/U(I_^?5J?_%V*G:.YKIP*`;:?__WVG__^-I__]
MG*>S"J.GX/ZMI_^_O*?G/\BG`P#*IS"[TJ?_ON"G&0#CI___\Z?_U@"H,1L'
MJ(#?#ZCO\1NHOQDEJ``_*ZCW_SJH+_5%J/,_4:CPOURH`+]CJ.._;ZA/_'JH
M$WJ"J/[_D:A]])RH=>^HJ/X?M*C\GK^H]M_,J+_KV:CG:^2H_/_RJ/_7`*GK
M_PZIO_X<J7__*ZGWUSBI^Z1"J?]M3ZE[VUNI^_]JJ?VW=ZG?]82I]_20J9C_
MFZD8\Z.I_Q^PJ?9_O:GP;\>I_C_4J;#^WJG'X>>I_]WUJ;=^`:K]OP^JW_\>
MJO_[+:KY_SNJ__Y*JK__6:K_"V2J\#]NJ@3[=JK__X:J__^6J@__HJK__[*J
MJ/^]JO__S:I^_]NJ?__JJA__]ZK__P>K_VL4JX+\'*O__RRKO_\[J__?2JO_
M_UJK_1]FJ_C_<ZO__X.K_Y>0J\$@E*O__Z2K__^TJ_]_PZO__].KI__@J___
M\*L!^/:K__\&K/]_%:P'X!NL_O\JK/__.JSW_TFL_P]5K`#_7:S__VVL__]]
MK+_OBZP+!(^L_[^>K-__K:S__[VLW__,K/\'UZS`_^&L___QK!Y%^*R$X/VL
MU_\+K?__&ZW__RNM__\[K?\_2:T`_U&M__]AK?__<:W__'^M)P*$K1;^CJW_
M_YZM_]^MK?__O:W_7\NMXO_7K?__YZV5B.VM@O3TK?__!*Y__Q.N_P,=KO__
M+:X__CJN]R!"KO`O2Z[__UNNO_]JKO^_>:[R_X:N__^6K@'XG*Y__ZNN__^[
MKKH#PJ[__]*N_\/>KO__[J[_W_VN`?X%K__J$J___R*O#W\MK\#_-Z___T>O
MW_]6K\?'8*_??6VOZN]YK_]_B*_Y'Y.O?OR?K_XOJZ^_\;>O_S_%KS[XSZ_+
M:]FO[_7FK[G_\Z_Q_P"P__\0L./9&K#__RJP^?@UL._A0+#__U"P__M?L,.?
M:;``_W&P__N`L(/_B[`)`(VP^O^;L/^_JK#?/[>P\*_!L```P;#^_]"P___@
ML/__\+`?__VPG\4'L7[_%;'__R6Q__\UL3_P/[%?%TFQ`/]1L??_8+'__W"Q
M^.]\L7H`@;'Q_XZQ__>=L?__K;$?_[JQ7L'"L?_]T;'^#]RQ_/_JL0#?\;'_
M_P&R_A@*LO[_&;+?P2.R/^$MLO_=.[+_)$6R_O]4LO?Y8;+_P6RR__=[LO7]
MB++^_Y>RD+^@LOQ_K;+?_[RR]__+LN[_V;+^C^6R?^_SLD_V_K+__PZS^7P9
ML___*;,'_S2SO_]#LZS"2K/__UJSYW]GL_K_=;/_]X2S">")L___F;/_'Z:S
M#_^RL_\MOK,FX,2S__K2LX?AVK/_O^FS_P_ULPS\_;/__PVTQ_$7M/WZ)+3&
M_S"T[S\]M(SW1[3WSU2TRN]?M)[_;+3?VGBT[_^'M`]OD;0O^)NT>?FFM.\I
ML+3__\"TCN_+M'_GV+1\=^.T_^GPM+[__K3_XPNU_U\9M2[_);7S?S*U^/L^
MM?_Y3+7/WEBUQOQBM1<U:K7J/W6U?N^"M;O_D+7'OYRUA/ZEM?__M;7_3,"U
M=O_-M?__W;7S#>:U___VM?^/`[9_?A"VV?\=MO__+;;]_CNV0_]&MO__5K;^
M_V6V__]UMM?_@[;__Y.V_X:>MO^)J;;]_[BV___(MF7ET;;]_^"V[[[MMK__
M_+9_^`BW?_\7MW__)K>__S6WE_]"M__?4;=_[U^W+/MIM^\]=;='_H"W.9^*
MM^_NE[>;_Z2W^SZPMW]CN[>K_\BW]?_6M__GY+?___2W/_\"N/_9#[C__Q^X
MO_TMN/_W/+C_PD>X__]7N-_^9;CG_W.X[E]_N/[PBKCQYY6X>SV@N.__K[BW
M_[VXXS?'N/G_U;CWY^*X['_NN(__^[C_!06Y_]\4N9_^(;G_UBZY__L]N27X
M1;G__U6Y\D=>N?_I:[G^\WBYR4-_N0!_AKF;\(^Y_".8N=#_H[G=[["Y___`
MN>S_S;G_W]RY_K_JN?_8]KE_OP2Z_\(/NO__'[KO_RZZ__\^NG;^2KK__UJZ
M_[]INMC_=;H_Z8"Z__^0NG__G[IS'ZFZ?R*RNOS_P+I=P,>Z_O_6NDD"VKKX
M_^>Z_W_VNL(`^;K__PF[/UX4NPT`%[OH_R.[__DQNPKX.+O__TB[_X%2NP,`
M5+O\_V*[_U%MNPB`;[OI_WR[_P^(N_X_E;L``)6[8-V=N___K;O_![B[=@"]
MN___S;OS'=>[P/W@NS\8Z+O^G?2[T&?\N_#O![P?/!"\.*T8O#O_);P7_C"\
M-_\]O`W_2+RQ"T^\_,%8O`^>8;Q;Y&J\_2MUO)^>@+S^_X^\T="6O/\?H[S`
M_ZV\=Q*UO/[OP[Q`OLJ\___:O/]YY[SO__:\WX<!O:G_#;W?BQB]OS\EO6\3
M+KWV_SR]_U-(O>+/4KU^XUV]7Y]IO7]G=;T&N'N]L_^(O1>_D[UG>IV]_Z^K
MO1]/M;W_O\2]O_#/O?O_WKWX+.:]_?_UO0WP_+V_;PF^_"L3OO#_'[[_[RZ^
M*<@TOO_^0[[>_U&^!P!4OOZO8;Y;_&R^_\=YOG\Q@[[*_X^^^>.:OCO\I;[[
MW[.^'_B]OKW#Q[[N_]6^PS_?OK_W[;X+_O>^SW\$O^6S#K__QQN_O]<HO]GK
M,[_G?T"__*Y+O_[_6K\E_62_?[YQO]K_?K]_WHN_^_^:O_OYI[]O_;2__Y_"
MO__ES[_]_]Z_F_[JO[OI];_O_0/`^^$.P+_R&L#^WRC`P\\RP.O_0,`_X4K`
M\]]7P-_98\#W_W+`Y_U_P/]YC,#T0)+`P'^;P";XH\#[/:_`#?ZYP/]AQ,#[
M_]/`=P[<P/^_Z\!OYO;`_T@`P?N_#L'+[QK!W_\IP:?W-<'O;T+!;S=-P=#'
M5<$=_F#!_P-JP?3G=<%O2G[!=/R(P5_RD\$)_9S!G\&EP?[_M,%H&KK!\O_'
MP7_@T<'_?^#!_R#IP2#2[L'_?_W!`/`!PO_Y#\(?$A;"(!8:PO[_*<+?@#'"
M__]!PL$P1L)`V$O"?P-4PL#_7L+_*VK"./!QPM^O?L+XQXC"_W^7PI!"F\+I
M_ZC"A.^QPO]0N\(9@+_"O,S(PO^)T\*`^]O"T/_FPI?&[\)/X/?"`5S\PB/^
M!L/W]Q3#%=,<PT\Y)<,``"7#@/\NP_0+-L/XAC[#SS]*P[CM5,/GXU_#7%UH
MPS_>=,/K_X+#KS^.P_W_G<,WX*7#_Z.QPR'_N\/K@</#\[_0P_\0V</T_^;#
MK0+LP____,-$]`/$__`/Q-]#&<3^/B7$O/HPQ-X-.<2/&4'$`(!"Q/]]4,0?
M^EO$+P%AQ/[?;\0K_WO$C^"#Q.__DL1__)_$#X"DQ/__M,0R@+C$___(Q'_]
MUL1#A=S$___LQ'_]^L3_^PG%0?P1Q7O@&L7_\";%_[,SQ>]=/\5^OTS%[Z]9
MQ?X_9L7_SW3%_/^"Q7_[D,7_1YS%__^LQ7_FN,7__\C%O__7Q?/_Y<7S__/%
MY_\!QO_[$,:?.QO&Y7\GQOPW,L;\'3S&_G=)QJS_5<;O%V#&_W]OQLNO>L;P
M]X7&&R*+QL#_E<;_:J'&@/^JQO_.M\8-X+W&_S_+QL;PT\;_`]W&_HWHQG#J
M\,;OI?O&GU\'Q[[_%<?;_R/'[]<PQ_CW/,=.OD;'__E4QW][8<>_?V_'4NYX
MQ_Y?A<<`_XW'/PN6Q___IL=@_J_'C9.WQ___Q\<_Z-''___AQW_W[\?Y__W'
M_RP(R,?_%<C/SB#(_\XMR/[_/,CPST;(OL-0R+?_7LB^?VO(\O]XR.__A\CK
MSY/(_\^AR'__L,CW#[O(OK['R/C?T\C_?>'(]][NR.\_^\C__PO)_U\9R?]_
M*,G_GS;)__]&R=?L4<G__V')?W]OR7KC><G__XG)_WV7R?__I\D9_K')_[.^
MR?G_S,EE_]C)_^_GR7_Z],G^U0#*V_P,R@F^%,K^4Q_*_7\MRO(_.,KX[T3*
M#_]0RO\-6\KJ_VC*__9VRO_@@<K__Y'*?T><RM[^J<H2`*O*UC2SRO__P\KL
M?\_*&?_:RO^OZ,IC__3*S^C^RO__#LL*_A?+__\GR_W\-,L$L#C+__](RV<"
M3LN`[U;+_UMCRS?S;LO__W[+P\:&R_]_E<ND])W+_[^LR_@KM<OXY;_+TP'%
MRP``Q<OC'L[+?!S6RX7>W\OW=^S+/VWWR[)G`,RO_P[,7O,9S/__*<SKX#+,
M__]"S+]W3\SG_UW,G^%GS/__=\S3@G[,S?^+S/]_FLR+Z*+,__^RS-]=OLP4
M^,7,'PS,S/__W,SSVN?,_S'RS,C__<S]SPK-<0\2S3\`&,T``!C-```8S>;X
M(LW?\"W-_^4ZS4_^1LVH_U'-3^!9S7]C9,U__G+-OQ]^S?]OC,W,VY;-?]ZC
MS:/WKLW__[[-F[;(S1N.T,W__^#-QP/GS?^_]LV/_P/.[^4/SO]O'<Z`_R;.
M_SLSSL#_/<[/PT?._W=5SOC_8LY3^&O.\2-SSC^-?<[^_HO.__*8SO__J,[^
MTK/.N__!SM^_S\[_N]W.O^?JSO_]^<[S?P;/[M\3STGZ',_W^RK/?[\XS__W
M1\_G]U3/R>]?SW_[;<]?[WK/WZV&S[?]D\_["YW/__^MS_L3M\__?\;/?DS/
MS_W_WL_#O^G/#/CPS__W_\]_4`C0L/\3T/__(]"%GRS0I2$RT`#6-]#__T?0
MQU]2T`0!5-#^_V/0?^!MT'\>>-``Z'S0_W^+T.`OD]!`_YS0_PVGT'0!K-#\
M?[G0Q_'#T.-_S]`^^-G0'_'CT"O][M#+?_K0ZP``T0&B!-'_^Q/1_QX?T?__
M+]'_GSW1__A*T?]_6='^$6+1@[]LT?[O>M'_/XC1_[65T0'_GM'__Z[1_W^]
MT87[Q]'__]?1N^_DT2HDZ='P__71__\%TO\]$M+5AAK22/XCTO_^,M*?63S2
M"?Y%TO_[5-+_?V/2?I1LT@+`;]+__W_2_S^-TO(DE-("_YW2__^MTEX&M-+^
M-;_2`_#%TO^?T]+Z?M_2#?_JTO3/]=*WOP+3`0`#T\#_#=/;XQC3[Y4CT]_[
M,=/[6SW3X[U(T_[_5]/XZV+3]W]PTZ[\>].=_8?3[G^4T_<]H--]\:O3'_FV
MT__ZQ--__=+3___BTWW_\-/?X/K3_?P'U/_]%M1];B'4WG\NU'I_.M3R\434
MW_]3U)W_8-3^^V[4\PUWU!R#?=0??XG4_'^6U.K_H]2?P*O4/YFUU'__Q-2/
M_M#4,<_9U%O>Y-3__?/4MO/^U/_[#=5W[1G5]SDDU?S?,=7K_3[57_],U9[_
M6=62_V35XN]OU>_Y?-7_#8?5_L>3U?EXG=7V_JK5-_^WU?^_QM7D_]+5,^S;
MU?^9Y]7W=_35U?\!UL__#];/_QW6^%8FUOV[,]9?>S_6[OM,UN'Y5M;[_V76
M7^]RUG\````````````,8```#&````Q@```,8.?_&F`??B5@]_XS8'\//F``
M`#Y@```^8```/F```#Y@```^8```/F```#Y@```^8```/F!Z_TM@__];8/__
M:V#_EWA@_O^'8/\_E6```)5@``"58```E6```)5@``"58```E6```)5@``"5
M8",`"V````M@```+8``!````````````````````````````````ZP`/__<`
M-V#^`/X#!P$```<!```'`0``!P$```<!```'`0``!P$```<!```'`0``!P$`
M``<!```'`0``!P$`"`@!X/\3`?__(P'_`RT!```M`0``+0$``"T!```M`0``
M+0$``"T!```M`0``+0$``"T!```M`0``+0$``"T!```M`0``+0$``"T!```M
M`0``+0$``"T!```M`0``+0$``"T!```M`0``+0$(`"X!```N`0``+@$``"X!
M```N`0``+@$``"X!```N`0``+@$``"X!```N`0``+@$``"X!```N`0#`,`$`
M<#,!`@`T`0``-`$00#8!)@`Y`0``.0$``#D!<Q`_`4`000$2>TD!7U]5`3[^
M80&+_VT!^,!T`?O^@@'_?Y$!_OZ?`?._K`']_[L!O-_'`?O]U0&?\^$!_G_O
M`?_\_0&O=PD"__<8`O__*`+__S@"]]]&`O_^50+O'V$"_X%K`O^!=0+_#X$"
M\/^-`O\_FP+Y'Z8"_#^R`G_XO@+G/\H">_[7`O^_Y@+?C_("O^\``R]^"P._
M_QH#_U\H`[_^-@/]]4,#_W]2`___8@,^YFP#_W][`^;_B`/_?Y<#_O^F`^]_
MM`/_W\,#___3`[_UX`/_^^\#_?[]`_?_#`3_GQH$_Y\H!/Z_-@3__D4$N_]3
M!-__8@3EOVX$?_]]!/?_C`3_/YH$Y^>F!/;_M`3_W\,$___3!.WOX`3___`$
M?___!/__#P7KUQL%?7TG!?_[-@4?_T,%?;A-!>?\607^_V@%__YW!?_7A07_
MSY,%__^C!7_\L`7_^[\%__?.!?_^W07__>P%___\!?7_"@;_?QD&_$<C!O[_
M,@;^_T$&__]1!O_^8`;_YVX&__]^!OE_BP;]?YD&_[^H!O_^MP:W^\0&;O3.
M!G_[W`;SW^D&/^ST!K__`P?SW@\'_S\=!_[_+`>]?SD'[_Y'!W^;4P>>'UT'
M/O]J!P?_=0<'_X`'__F.!___G@?Z_ZP'_Y>Y!___R0?Y_]<'?_SD!__/\@?_
M_P((]^\0"/__(`C__B\(__\_"/3?2PC_O5D(?_]H"/__>`C^_X<(_[V5"/]_
MI`C__;,(S__!"/!_S`CX_]D(_\?F"/]_]0CC_P()__D0"7_\'0G_XRH)__\Z
M"?_O20GS\50)_MUA"?O_<`D]WGL)_^^*"?^/EPE_^:0)^=NP"3__O@G__\X)
M___>">]_[`G__OL)__\+"O_X&`K^_R<*O]\U"O_]1`K[?U(*OZ=>"I]_:PK^
MYG<*C_F""N?_D`KV_IT*__^M"O__O0K__\T*WW_;"N__Z@K___H*M^\'"___
M%PO__R<+__\W"\'_0@O^_U$+[O]?"_[_;@O__WX+_^^-"__?G`N?_ZH+__^Z
M"_[_R0N__]@+_?OF"___]@O_]P4,__\5#/_^)`S?_S,,A_\_#/Y_30S_?EL,
M_^]J#/_[>0P_OX8,]_^5#,_]H@S__;$,_W_`#/_SS@S__]X,/^_K#/__^PS_
MOPH-[_\9#>_[)PW__S<-__]'#>=_5`W__V0-__]T#?_\@@W__Y(-?_^A#?__
ML0WO_\`-___0#?_OWPW__^\-^__^#?__#@X?_QL._]\J#O__.@[__TH.__=9
M#O__:0[__WD./P!_#OS_C0[__YT._O^L#O__O`[__\P._[?:#M_OZ`[___@.
M__\(#__?%P__GR4/__\U#[__1`___U0/__MC#___<P___X,/O_^2#_^]H`]_
MOJT/?_^\#_W]R@__/]@/_S_F#_[_]0^/_P(0_^0.$/_W'1#__RT0__\]$/__
M31#__UT0^_]L$/[_>Q#W_XH0O_^9$/__J1#__[D0_^_($/^_UQ#__^<0O__V
M$/_?!1'W]Q,1__\C$?^W,1'__T$1^_]0$?_#7!'W_VL1__=Z$;_WB!'__Y@1
MW_^G$>_OM1'__\41___5$??_Y!'___01__\$$O__%!+__R02!_PM$O?_/!+_
M_TP2__5:$O__:A+_[WD2_P^%$O[_E!+__Z02^_^S$O__PQ+__],2___C$OO_
M\A+_[P$3O_\0$___(!/_^R\3__\_$___3Q/__U\3_?=M$_A_>1-__H<3]_^6
M$__[I1/__;03^__#$[__TA/W_^$3_O_P$___`!3W_0X4^_\=%'__+!3_[SL4
M__]+%/\!5!2`_UT4__=L%/_]>Q0^/H44_GZ2%/__HA3_U:\4__^_%/__SQ3_
M^]X4___N%/___A3OOPP5__\<%?__+!7__SP5__],%?]_6Q7_^VH5__]Z%?__
MBA7__YH5__^J%?__NA7__\H5___:%?__ZA7___H5_W\)%O_O&!;_^R<6__\W
M%O__1Q;__U<6__]G%O__=Q;'_X06__^4%O_]HQ;_][(6?__!%O__T1;_O^`6
MM__N%O___A;__PX7__L=%^__+!=__SL7_QY'%^#_4A>__V$7__]Q%___@1?_
M_Y$7__V@%___L!<'_+D7__[(%___V!?__^@7___X%___"!C__Q@8__\H&/__
M.!C_GT88.P!+&```2Q@``$L8``!+&```2QB__UH8]\-E&%_O<AAONWX8[^N+
M&-[WF!@,!YT8.L*D&/_[LQC^^\$8?_G.&-]6V1C__^D8\?_V&/_#`AG__Q(9
M__\B&?\_,!D$\S<9__]'&?__5QG__V<9W_]V&?__AAG__Y89__^F&0_(K1G_
M_[T9___-&?__W1F_TN@9___X&?__"!K__Q@:__\H&O^3-!K__T0:__]4&O__
M9!K_/W(:__^"&O__DAI/_)T:__^M&O__O1K__\T:___=&OO_[!K___P:__\,
M&___'!O__RP;__\\&___3!O_?UL;[M-F&_W_=1O_XX(;?S^/&__WGAO__ZX;
M__^^&S]UR1O_9]8;_]_E&__Q\AO_SP`<_W\/'/K_'1S\_RL<__\['/W_2AS_
M?UD<__]I'/G_=QS[_X8<__>5'/_[I!S__[0<___$'/O_TQS__^,<O[_Q'/__
M`1W__Q$=O_\@'?OW+AW__SX=W<]*'=S_5QWS_V4=_V]S'3__@1W]_H\=__^?
M'?^_KAW__[X=;__,'?__W!W__^P=___\'1/D`Q[__Q,>__\C'O__,QY_U3\>
M__]/'O__7Q[__V\>041S'O__@Q[__Y,>__^C'O\/KQ[#_[L>___+'O__VQ[_
M_^L>?PWU'N[\`1___Q$?__\A'___,1]_C#L?__]+'___6Q__QV@?U_]V'___
MAA__^Y4?Q?^A'___L1___\$?_\?.'___WA__[^T?___]'___#2#A_QD@__\I
M(/^_.""?_T8@^_]5(,^_8B"__W$@__V`(+__CR!_^)L@__^K(/^+MR#^_\8@
M___6((_]XB#___(@_U\`(?#_#"'__QPAO_@H(?__."'__T@A__]8(9W_92'_
M_W4A__^%(;W_DR'__Z,A_[^R(?[_P2'__]$A__W@(?__\"&__/TA_^<+(G__
M&B+?VR<BO_XU(G__1"+_OU,B__]C(O_Q<"+Y_WXBO_^-(O__G2+__ZTB?_Z[
M(O__RR+_\=@B___H(O__^"+__P@C__\8(___*",?_C0C__]$(___5"/K_V(C
M__]R(___@B/__Y(CK_^@(___L"/__\`C_]_/(___WR/__^\CZ__](___#23Y
M_QLD__\K)/__.R3__TLDO_]:)/__:B3_O7@D_]^')/__ER3__Z<D_?^V)/S[
MPR3_W](D__WA)/__\23__P$E_^</)?O_'B7_SRPE/[\Y)>O_1R7S_U4E__]E
M);__="6[?X$E\_^/);_RFR7__ZLE_P^W)</_PR7__],E9O_?)?__[R7#__LE
M__\+)O_?&B;__RHF__\Z)O_*1B;__U8FO_]E)O__=2;__X4F__^5)O__I2;?
M_[0F___$)O]+T";_[]\FWW_M)O[O^R8__PDG_><6)__])2?__S4G__]%)___
M52>__V0GY3]O)___?R?_[XXG__^>)___KB?O_[TG___-)__]W">__^LG_OOY
M)___"2C?_Q@H_W\G*/_^-BC_]T4H__]5*-__9"C__W0H__^$*+__DRC__Z,H
M__^S*/__PRB!_\TH___=*/__[2C_(_@H__\(*?__&"G__R@I/]`Q*?__02G_
M_U$I_T==*?__;2G__WTI__^-*?]'F2G__ZDI__^Y*?__R2FO_]<I___G*?__
M]RG]_P8J__\6*O__)BK__S8J__]&*O__5BK__V8J__]V*NG_@RK__Y,J[_^B
M*K_WL"I__[\J___/*O__WRKO_^XJG__\*O_A""O__Q@K__\H*_]_-ROX_T0K
M__]4*___9"O__W0K$_Q]*___C2O__YTK_XJH*PK_LBO__\(K___2*_\_X"OQ
M_^TK___]*___#2S__QTL__\M+$?D-2S__T4L__]5+/__92S_1W$LR/]\+/__
MC"S__YPL__^L+,OZMRS__\<L___7+/__YRSO__8L__\&+?__%BU?^B(M__\R
M+?^?0"W__U`M__]@+?__<"W[_W\M__^/+?__GRW__Z\M__>^+?_]S2W_G]LM
MOW_I+??_^"W__0<N__\7+O[_)B[?_S4N__]%+G_^4R[__V,N__]S+O__@R[_
M'Y`N__^@+H?_K"[__[PN___,+O/_VB[__^HN?__Y+O__"2___QDO__\I+___
M.2__UT<O__]7+___9R___78O_O^%+_7_DR___Z,O9_RN+___OB___\XO___>
M+U[0YB____8O__\&,/__%C#__R8P_]\U,',`.C#__THP__]:,/__:C#__WHP
M_T>&,`#XBS#__YLP_]^J,/__NC#__\HP_R/5,/K_XS#___,P__\#,?__$S'_
M_R,Q_UDO,:#>-S'__T<Q__]7,?__9S'__W<Q_[^&,6WTD#'__Z`Q__^P,?__
MP#'__]`Q_P/:,?[_Z3'___DQ__\),O__&3+_/R<R_/\U,O__13+__U4R__]E
M,L?E;S+__W\R__^/,O_]GC+__ZXR__V],O__S3+O_]PR?__K,M__^C+_?PDS
M__\9,___*3/__SDS__]),___63/_[V@S?_]W,_/[A#/__Y0S_?^C,_O_LC/?
M?;\S_[_.,___WC-_O^PS?__[,_O]"33?VQ8T?_XD-/__-#3O_T,T__]3-/__
M8S3__W,T#_Q]-/__C33__YTT__^M-/__O30_@L4T___5-/__Y33___4T__\%
M-3\`"S7`_Q4U__\E-?__-37__T4U_P]1-2#\6#7__V@U__]X-?__B#7__Y@U
M__^H-?^?MC6D_\$U___1-?__X37___$U__\!-O__$3;_?R`V5>\K-O__.S;_
M_TLV__];-O__:S;_/WDV2/N"-O__DC;__Z(V__^R-O__PC;__](V?]??-O__
M[S;___\V__\/-___'S?_YRTW__\]-___33?__UTW^?]K-___>S?__8HW__^:
M-___JC?__[HW___*-_\_V#?^_^<W_]_V-___!CC^_Q4X_X\B./__,CC_ST`X
M\?]-./__73@_Q&8X__]V./__ACB/_I(X__^B./^OL#C^_[\XW__../__WCCW
M_^TX___]./__#3G__QTY__\M.?__/3G__TTY__]=.3__:SG__WLY__^+.?__
MFSEU_Z@Y_]^W.?_OQCG__]8YW__E.?_[]#G__P0Z_O\3.G_^(3K__C`Z_[\_
M.O\_33KX_UHZ]_]I.O]_>#K\_X8Z__V5.O__I3K__[4ZY]_".O__TCK__^(Z
M__'O.O^__CK\_PP[__\<._W_*SO__SL[^/](._\_5CO\_V0[__]T.W__@SO_
M_Y,[__^C.___LSM__\([_[_1.___X3O___$[__\!//__$3S[_R`\?_\O//CO
M.SS?_TH\__U9//__:3S/[W8\W_^%//O_E#S^_:(\Y_^P//O?OCP_?\L\_`_5
M//__Y3S__/,\O_\"/?_P#CW__QX]C_\K/7_^.3W_\T<]_S]5/?_?9#W_GW(]
MM_=_/?_[CCW__YX]_?^M/?__O3WY_\L]_W_:/?S_Z#W___@]__\(/O_/%C[_
M_R8^_^\U/O__13[__U4^_/]C/O__<S[__X,^O_^2/O/_H#[__[`^___`/O_V
MSC[__]X^__?M/O]__#[\_PH_/^L6/___)C__(3`__/\^/Q_Q2#___U@_0_]C
M/___<S__]X(___^2/Y__H#___[`_?_V^/___SC_?_]T_]__L/[__^S___PM`
MY_<80/>_)D#__S9`_W]%0/_^5$#?_V-`__]S0/__@T#__Y-`__^C0/__LT#_
M?\)`[Y_/0/__WT#__^]`Y__]0/__#4'W_QQ!^9\H0??_-T%__T9!_Y]40?_/
M8D&?WV]!__]_0??_CD&_OYQ!__^L0?__O$%S_\E!W__80?__Z$'_J_5!__\%
M0O_#$4+__R%"_PLL0O[_.T+_^TI"/_!40O__9$+_?W-"\?^`0O\_CD+__YY"
M__^N0C?_NT+__\M"_?_:0OW_Z4+___E"_?\(0___&$/[?R9#_O\U0__;0T/_
M_U-#__]C0__^<D/__X)#__V10___H4/__[%#/_^_0___ST/__]]#___O0___
M_T-__PY$__\>1/_S+$3__SQ$__],1/__7$3/_VI$__]Z1/__BD2?_YA$__^H
M1/_^MT3__\=$__/51/__Y41___1$__\$1??_$T7^?R%%```A10``(44``"%%
M```A10``(44``"%%```A10``(44``"%%P/\K1?O].46W^T9%__]61>__947]
M_W1%_W^#1?_[DD7__Z)%__^R1?_XOT7__\]%___?1?__[T7___]%>_\-1O__
M'4;[QRE&[_\X1OO]1D;__U9&]O]D1O__=$;^_X-&_P^/1OS_G4;__ZU&?^"W
M1O__QT;_!])&\/_>1O__[D83_OA&__\(1S_Y%$?__R1'_Z<Q1___04?]_U!'
MS_]>1[__;4?__WU']^^+1___FT?__ZM'O_^Z1W__R4?WO]='_+?C1__?\D?O
MWP!(_O\/2/[['4C[_BM(?_\Z2/__2DC__UI(/P9B2/__<DC__X)(__^22/]_
MH4C%_ZU(__^]2/__S4C__]U(_P'F2`P`Z$C___A(__\(2?__&$G__RA)@>(N
M2?__/DG__TY)__]>2?__;DG__WY)_\F*20K^DTG__Z-)__^S2?__PTG__]-)
M___C25_A[4G___U)__\-2O__'4K__RU*_TTY2I;_14K__U5*__]E2O__=4K_
M_X5*/^F02O__H$K__[!*___`2NO_SDK__]Y*___N2O^?_$K__PQ+__\<2_?_
M*TO__SM+__]+2___6TOK_VE+__]Y2_[_B$OO?Y9+__^F2___MDO_?\5+\/_1
M2___X4O_Y^]+____2_^?#4S__QU,_W\L3.#_-TS__T=,?_]63/__9DS__W9,
M__2#3/__DTS__Z-,_S^Q3/[_P$S__]!,/_[=3/__[4S_?_Q,_O\+3?__&TW_
M_RM-__\[3?__2TW__UM-__]K3?__>TWO_XI-S^^73?__ITV?_[5-___%3?\?
MTDW^_^%-!_[K3?__^TW#_P=.__\73N__)D[_SS1.__]$3N__4TY?_V%.W_]P
M3O_^?T[__X]._O^>3O__KD[__[Y.___.3@$`ST[\O]Q._W_K3O__^T[]_PI/
M__L93___*4_W_SA/__](3_]_5T___V=/__]W3__YA4___Y5/_[^D3___M$__
M_\1/__O33___XT____-/__\#4/__$U#]_R)0__\R4/__0E#_]U%0__]A4/O_
M<%#_?W]0__^/4```CU```(]0``"/4```CU```(]0``"/4```CU```(]0``"/
M4(#_F%#__ZA0__^X4/^_QU#__]=0___G4/__]U#__P=1__\74?^_)E'__S91
M__]&4?__5E'__V91_Q]S40``<U$``'-1``!S40``<U'P^WY1W_^-4?__G5'_
M_ZU1__^]4?W^RU'O_]I1_[_I4=__^%$?]`)2_Z\04O__(%+_3RU2__\]4O__
M35+[_UQ2__]L4O\?>5+^?X=2_^>54O__I5+?][-2W_[!4O__T5+S_]]2___O
M4O_O_E+__PY3__\>4___+E/_[SU3__]-4S\`4U,``%-3``!34P#X6%/_]693
M_]MT4___A%/_DY!3__^@4_/_KE/_^[U3___-4S__VU/__>I3___Z4S__"%3?
M_Q=4__\G5/__-U3_WT94_^]55/_S8U3_?W)4]/]_5#__C53__IQ4__^L5/__
MO%3__\Q4___<5/O_ZU3_E_A4O_\'5?T?$U7__R-5?_\R5>__057__E!5__I>
M5?O_;57]_WQ5_^.)5?__F57__ZE5_^BU5?__Q57__]55___E5?__]57]_P16
M__\45O__)%;__S16__]$5O__5%;__V16__]T5O__A%;__Y16__^D5O__M%;_
MO\-6[?_15O__X5;___%6__\!5___$5?__R%7__\Q5__[0%?__U!7__]@5___
M<%?^_W]7__^/5___GU>]_ZU7__^]5_W_S%?W_]M7___K5___^U<?``!8````
M6````%@```!8````6````%@```!8````6````%@```!8````6````%@```!8
M````6````%B`?PA8__L76/__)UC_^S98__]&6/]_55C__V58_P!M6"``;E@`
M`&Y8`'!Q6/__@5B?_X]8'_R:6/__JE@?_+58__O$6/__U%C^_^-8___S6/__
M`UG__Q-9__\C6?[_,EGWOT!9_?]/6?__7UG_WVY9__]^6?\OBUGG_YE9W_^H
M6?W_MUF__\99^/_36?]_XEG___)9__\"6O__$EH_X!M:__\K6O__.UK__TM:
M_^]:6O__:EK__WI:__^*6O__FEH?`)]:``"?6@``GUH`^Z9:[_^U6M\_PEH`
MN,9:_K[36O__XUK_7_%:__\!6___$5O__R%;__\Q6___05L#`$-;``!#6P``
M0UO`_TU;__]=6___;5O?_WQ;__^,6___G%O[_ZM;__^[6_/_R5O__MA;___H
M6___^%O__PA<_P\47```%%P``!1<```47`#_'%S__RQ<W^<Y7/__25S__UE<
M__]I7/__>5SW_XA<__^87+__IUQ__[9<_[_%7/__U5S__N1<___T7'__`UW_
M_Q-=Z_\A7?^_,%W\_SY=__].7=G_6UW__VM=__AX7?__B%W^_Y==__^G7?_C
MM%W_\<%=_@_,70``S%T``,Q=``#,70``S%T``,Q=``#,7>#_UUW^_^9=_[_U
M7?__!5[_YQ->__\C7K_^,5[__T%>W_]07O__8%[_'VU>__]]7O_WC%[__YQ>
MO_^K7O__NU[__\M>___;7O__ZU[_?_I>``#Z7@``^EX``/I>``#Z7@``^E[@
MO@-?__\37___(U___S-?__A`7__]3U___U]?_?EL7___?%__QXE?__^97_W_
MJ%___[A?___(7_W_UU_[_^9?_W_U7P#@^%__<P5@/P``````````````````
M`````````'H`__^*`/__F@`"`)L```";````FP```)L`_P.E`/`_KP```*\`
M``"O````KP```*\```"O````KP```*\```"O``40L@`1$;8`$!"X`!`0N@``
M`+H``4"\``+DP0`/`,4`_O_4`#``U@`#`-@`###<`,#(X0```.$`/`#E````
MY0!@`N@```#H````Z````.@`!P`````````````````[````.P!8,T(`8`!$
M`"1(2````$@```!(````2````$@```!(````2````$@```!(````2````$@`
M``!(````2``H`DL```!+````2P```$L```!+````2P#_`U4`_P-?````7P#/
M`V<```!G````9P```&<```!G````9P```&<```!G`"#$:P`!3G``,!!S````
M<P`$`'0`PP!X````>````'@```!X`"``>0``@``````````````````````&
M````!@````8````&````!@````8````&````!@````8````&````!@````8`
M```&`(`."@```@L````+````"P````L````+````"P````L````+````"P``
M``L````+````"P#^_QH`^P,C`/[_,@#[`P``````````````````````````
M`````````````````````````````````````````````(```0"#``0````$
M`(``!0````4`@`#];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL
M_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6S];/UL_6QF
M&V@;YQL_'/ULIAP/'3X>)!]E'YL??QW+(',A<2%K(?0A(B(@(I(BNB*1(K`B
M62.*(P\D$B03)$<DFR0`)4TET2;3)F<G5RAW*-4H=2F.*:4IMBF_*64JS2KM
M*I0KFBNZ*R4M4"VC+F`O9"^V+P,PMC`:,25&(2CB,@(SI#.L,Q`T!C1>-%HT
M+#4I-2TV=S9Z-LHVYC;U-@TW#C?<-]TW]C<>.&,XI3D/.HHZA#J+.GPZ3#M(
M.TD[G3N9._@[+CPM/%P\S$6_/.H\Y3P1/1(]/STY/3L]/3UW/74]=CUQ/98]
MDSVT/=T]WCT./A$E&#Y'/T@_[S\20#M`I$"-0+1`<T)W0KQ"&40;1#U$4T14
M1%A$MT381.Y$(D5-189%F46C1;Q%IT8W1UE'T$<O2#)(0DA.2&A(J4CM2-!)
M!TK3261*0$O];$%,8TR[3!$S)3-(3A!/8D\23R%0'E#B4-Y0X5!S4=11]5$W
M4D52<E)*4ZE3I5/U4S144%2'5%15A%4#5U)8V%@,61A9L%F\6M5:JEN<7/UL
M7%TK7B%><U[T7O5>/U]"7X9?OE^\7[U?\5_R7^]?(F`C8"1@9V!F8)=ASF'G
M83MC36/D9$)E'6>89_UL26E),'$JA2K3+0YE`DP>1/UL_6PH(7(ANB'P(>XA
MN"*Y(L0B4TRP7@`````````````````````````````````T````-0```#8`
M```W````.````#D````Z````.P```#P````]````/@```#\```!`````00``
M`$(```!#````1````$4```!&````1P```$@```!)````2@```$L```!,````
M30```$X```!/````4````%$```!2````4P```%0```!5````5@```%<```!8
M````60```%H```!;````7````%T```!>````7P```&````!A````8@```&,`
M``!D````90```&8```!G````:````&D```!J````:P```&P```!M````;@``
M`&\```!P````<0```'(```!S````=````'4```!V````=P```'@```!Y````
M>@```'L```!\````?0```'X```!_````@````($```""````@P```(0```"%
M````A@```(<```"(````B0```(H```"+````C````(T```".````CP```)``
M``"1````D@```),```"4````E0```)8```"7````F````)D```":````FP``
M`)P```"=````G@```)\```#_``````(```$"```"`@``!0(```8"```+`@``
M#0(``!,"```6`@``%P(``!T"```C`@``)0(``#`"```U`@``/`(``$`"``!*
M`@``40(``%D"``!<`@``90(``(P"``"9`@``^`(``/D"``#Z`@`H&C8:/QJ%
M&@4:!!J"'98=.!]I'[8?*AJ'&DD:XAU&&H\:O!J^&F8=XQT$'IP>1!\")0HE
M@"?;*7HJ?RKT*E`K42MA*QUB"VUC&F(:HQJ%'<4:SQK.&LP:A!V&'1>%Q0#D
M'04>GAZ='OT>`!\Z'SD!1A]='X8?MQ]5`<P?6P'.'R$CH@,`*@PK-RXX+C0Q
M-3'@,28*C3^7&N`:,@"I;N<:,P#F&C0`H@(Q`+``V"*+'8P=F1WE'5"%"Q[<
M`!X"!!\#'P<?*H4>'U\?;1^)'[H?T!]E`?8?]Q_Y'V0!]!\=`B8")",$)1@E
M,B4P)30EC@)U)4H#@B?Y)Q0HBP.F`Z0#I0.G`R\$,@2!*H,J#2M2*]0$RBO'
M*SDNQ05/+N<Q+S-Z-SDXN@BY"#<X1#A%.(P_DD%V0I-<DERS%+H5(1H@&B(:
M:!J)&I@:^1KO&CL`/`#X&@8;`QO\&NX:%ALY`"@;'!L'&QH;^AH7&TH=L@!R
M'16%M!VS';(=QP#H'2L`%!X/'A4>&!ZH'BR%2Q]/'SL!4!]$`8L?0@&^'UP!
MTA\6(/\?9P$`(&8!!2`3(!4@.X4?`N,B-2,V(S$C,B/N)`4E5!J/`C8ED`*H
M`J0">B6C`H8E/0-,`X8G4RL8*(P#/2AX**@#K0.O`T9W@"@I!`@J-@1Q!'`$
M;P3U*@XKJ02J!/L$TRO:*_P$VRNN!0\N72Y?+F<N5RY0:\,&ZS'J,3`'-S-!
M!S(S-C,B-\XWC`A8.%$X=S@\.+L(6CB&?%,X;SQR/&X\-86A"7,\L3ZR/J@*
MCS^J"JL*E@P\1<(-C4R.3),0>TZ4$'%9N5N67)I<NQ4D&G$:&X6<&D4;2ALY
M&S<;0P`R&T(;0@!$&TL;1`!`&S4;,1M1'0Z%4!U.';,`MP"='<@`M1VX'>P=
M(QXG'B8>'QXK'B`>M!ZS'A@!)1\['W0?1P%&`44!:P%I`4T@<@%Q`3H@;`%O
M`40@3"`C(!H@,B!+("$@<P$T($D@4"`B(#\@42!:("\@=@'I(O(B\R+O(NTB
M["+F(D@C)P)$(S\C/"-3(U8C,`)?(T,C6"-7(RD"*@(O`D8C+`(](RT"0B-4
M(U4C\23R)/`D"R6F:O$B/263`I0EC"6M`IPEK`*K`I\EJ0*;):X"B26:):H"
MB#%.`XTG4`/^)_\G_2<K*+(#A"B.*)PHM0.V`X4H]2D)*CD$.P0+*G($DBJ0
M*@,KK`0>*V,K"`7G*_XKYBO<*\XK`P7\*]\K["OV*]=Y\BOP*_DK"P43+J\%
MLH4[+CPN@B[.!<L%S`5X+HLNS06>+J4NFRZ<+IDNC2Z%+ITN=2Z`!J\&TP;V
M,=4&U`;7!O4R6S-"!U0S4C-$!U@S1#-*,V$SQ@A_.)$XGCC`"&XX?#B?.'4X
MO@A6.*(X>3C*"*$XQ`BJ.*`XP@AY/'<\?CRD"74\>SQD/BD*NSZ\/L<^N3Z^
M/K8^8`I>"I@_K0JN"JP*5PN308!"W0N#0L!"P4(.#)<,]$/U0R<-S$;-1OI(
MGTR13)=,E$R5$(9.C$Z/AI5.F!!L4IT1M5N^6\=;BA3!6ZE<I%RU%+84MQ2H
M7"=B)F(K8C-B-&(I8CT:*`"=&I,;BAM-`$D`;1N.&Z`;HANA&Y\;HQL);W(;
M40",&U8=#X41A9`=RP#*`,P`[1W^'2\>['$\'C0>.1ZY'K4>OQY5'ST!=A]Z
M'Y,?2`'!'\(?U1^%('@!7R"3((D@>2#^:H\@:2!M('H!E"!J((H@=P'](OLB
M^"(A`OPB]B)E(X$C8R-G(S$";B-X(W\C,P(T`O,D2R5,)<$"L`*T`JTEN`+$
M);P"PB6P);\"M0*Q`KT"OR6[`LDEN"6L);,"M@*Z`K<EUR6W`F`G0`.6)YXG
ME">?)YTG4@,`*!DHD`.1`TDH2BB^`[LHP2C``\$#N0.Y*)XHM"BZ*/8I$RH2
M*G<J>028*GL$F2J=*O@JH`3Y*BD`!BLA*ZX$)2M5*\T$RP39!(0K@RLP+`<L
M#`4V+`$%!04"!>DK/2P(+!,%$06Z+K(NY`6W+N0NIR[:!=4%TP75+N$NW2ZF
M+L$NQ2[`+M\NX"[>+M8%B3&T!J8QNC'9!O\QV`87,A@R`3+^,3,'##-(!VLS
MEC.",XHS1P>C,TL'HC./,TH'^3.`,R8W)S=H-VDW6@B!-[0WT3>."+0('#C-
M",P(SPC+",X(ESAL.-\XT@CJ.-$(Y#C8.+(XSCC(.*8)BSR(/)`\CSRJ"8<\
MB3R-/($\J`F,/!,*&@I`/AT*'@IE/F8^:#YE"F8*S3[3/ML^9`K//J<_HS^>
M/[`*KS^S"K4*JC^</QD+0D%$03M!04$_>)M!GD%U"\1%PT7&12L-+`W'12T-
MRD4N@,,-ST9V2'1(_TC\2+H`4`]92ZA,TP_0#[!,W`^S3-(/I$RV3*=,K$S;
M#Z9,9Q\.3L1./D^<3J40GQ":$)P0HA"J3IL0R4ZC$)T0IDZR3H@1&A*-%,Q;
MV5O*6]A;SUNW7+@4K5RY7#=BPQ5!8CYBMF)18V-C5QIY&K(:L!JO&K$:TAO5
M&UT`OANX&[`;L1O(&UH`5P#&&\P;Y1OC&[0;:AVX`)\=P@#!'<\`PAW#'44>
M2![G`.D`3QY2$.@`Q1[*'L0>)Q]8'WT?2@'=']P?VA_9'[D@@`'0(+0@RB"'
M`:,@VB"D((0!LB">()\@M2""`8$!S2"#`<P@(@(`(ZPCD2..(XTCDB.A(Y`C
MIB.H(SL"G".6(Z<C.@(X`CD"-@+U)(4""24()50(4B6:`L0"WR7%`NLE[R7P
M)=4E#28$)ODE`B;X)>(EV27G)6HG5`-5`ZLG5@,;*"\HE@,\,I4#E`/$`]$H
MW"CF*.$HS2AZA>(HW2CE*/LI^BD>*D0$H2I]!'X$_"K[*B\KL@2V!&8KF87<
M!-\$7"PH!4XL42P9!1`%(RPQ+'PL4BPL!6`L2BQA+!L%&"["!>\%XP7E!>H%
MY@7N!1\O%R_J+B$O!"\%+^@%,3%$,4`QA09",;XQX`8I,ALRW08C,BPR&C(P
M,CLR'C(W,C@RX08.,U$'50?H,]8S4@?',[PS4C2_,]4S_C-C3_LSWX6Q,P$T
M!30`--<SG@PJ-VLW4@A>"&`(7PCA-Y((U@@C.?\X%#D%.1,Y!CDA.=X(%3FO
M./0X`CE%.?Z%)CG9"$0YW0@D.:4\K`FC/+`)HCR[/*`\JCRO":X)J#RV/+(\
MISRM":L)N3PN/A8*/#XP"FT^,PHQ"N<^[3YN"NP^Y3[B/K$*Q#^]/\\_R3_!
M/]`_MPK./^U`ZT`:"^]`24%0049!2D%9"TU!ID%Z"W@+>PNH0=X+[`O'0O]"
M'@S]0N9#"D2;#`1$"T0'1)T,%40(1/T,TT741=!%UT5\1I0-DPU]1H-&@D;&
M#=1&U4;31M!&TD;^1OQ&=TA\2'M(N`YJAK<.N0Y3#S-_4@]1#X]+TTSC#\M,
MTDSB#PE-XDS?3,9,8Q`D3O=.V$[=3JH0IA#X3OQ.J!"I$.E.JQ#N3JP0T$X.
M3^)."T_]3GD==E*>$7A2GQ&@$752?5(/$D)49E0<$HQ5!5:N$@96L!*?6-03
M\5OG6^E;[UO"7+Q<NQ3&7,!<P13"%,U<R5R^%,1<Y12!8<85[&@R'/D;'1S_
M&P0<\!L#'"X2`AS\&_(;)!P('#8<+AQE`!`<.!PY'/T;5AS[&Z,=IAVA'=$`
MT`#''<D=8!YD'ED>91YG'E<>8Q[N`%,>[P#/'AX!SA[0'M$>S!Y+`4T!5@$-
M(?0@D@$3(>\@]2#Y(`(A`"&3`9`!&"'P(/8@0867`1DA(P(%(\DC/P*W(\TC
M0P)"`D0"OB.[(T4"VR/((\0CQ2/1(\HCP"/9`MX"(28J)L\"'2;-`@LFW0+.
M`M,"U@(B)MP"T0(D)M`"%"8Q)M4"+R8:)A(FU`+;`B8F+G9#`[PGNR>W)P4H
M!BA2*%,HS0/1`_HHZRC*`_,H]2CI*.\HU`,J*C`J+BHL*B\JKRJI*H8$_2HR
M*XXKDRN/*T\LF2PS!7XL-P5T+$LL<RQU+"H%'P56+*DLBRRF+#D%DRRN+)XL
MIRQ%+O(%^`4N+_<%4B\P+ULO]`49+QLO\04Q+UTO-R\U+U,O]05<+S\O2S&'
M!FD/BS&V!IHQ4#)&,DXR0#+I!DLR2#+K!F`R1#)-,C0'-S0D-&('7`<;-#8T
M8`<L-!DT5C1'-#XT'C3AA14T(C0G-%DT6#15-#`T(S0N-RLW,#=L-V$(BS=_
M".DWZC?E-VLYY0CF"',Y5SGI"/,(73E6.8\Y6SD<.9HYFSF9.>X(@3EQ.>T(
M[`AR.5PYECG$/-L\S#S0/.,\WSRS"=8\[CS5/+4))PHU"C8*>CYQ"O4^`C^X
M"L(*XC_L/]4_^3_?/^8_R`K`"L$*Q`KD/^$_\T`?"QP+'0M-"U9!54%805=!
M7D'#08<+@@NT07T+L4'?"P`,RT+,0BI#(`P60P]#(@PD##]#*T,.0R1#(0PA
M0QA#W4.D#*4,)$0V1`$-6$5910,-8D7:1=E%-PWA1>5%Z$7;13@-XD7P19D-
MF`V7#<D-VD;=1L<-VT;<1MD-VPT-1PM'%$>.2(9(>PZ'2(-(BTA\#KT.O`[#
M#B1)P0Z_#L0.)4EB2Y-+F4N72WX/?P_$2\9+"DRT#[,/0$P\3#M,]DS_3.Y,
M!$T#30=-@X;F#_=,61!:$"U.9!`G3BE.'T]73[00N1"W$+40(4_!$+$0&$]8
M3[,0NA",$8L1C1&$4I]2FU*)4J92DE*/4J!23U1X5'I4;E1[5(14<U1X$G<2
M#58+5AE6LA+6$]!:1122%)44^5L)7`A<QA3>7%%=YQ3H%-M=WUW>7=9=X%V%
M86!B66++%59BS17Q%;UB(A<A`$(<61QO`$0<9AQ2'%0<<1Q0''L<?!Q8''``
M9`!Y'&P<>!RH'=$=SQUH'G8>U!XM`:`?Q!]8`5@A3"%H(:8!22&D`9\!72$I
M(:YS5"%3(:,!6B&@`3HA/R$K(>HC2@+O(T<"2`+=(_XC587>(^8C20+H(_\C
M`R3W)*8T'R6>`ELE725>)3=UZ`(K)NP".R;M`N8"828Z)FXF2R9K)NL"YP)%
M)DXF:"8])G$F/R9O)G4FZ0)S)BPF6294)D\F8R9<`UT#R"=@`\,G6P-;*&$H
MF0,A*0HI"2G8`RPI""G:`]T#*BD5*>`#$"D3*>4#+RD8*=<#XRDY*C4J.BHR
M*DX$C`2(!(V%NRJZ*C0K.2O.!)R%Y03F!)@L,@70+$`%1P5,!=<LJBPU!:$L
MI"PP!>XL0P7G+$T%Z"S>++<%\P5^+XLO`@8+!GDOAB^3+P0&<R]J+[J%;"\(
M!G\O_`6R+[HO_P4`!F8O="^+!EHQC09.,4TQC3&.,:TQR@;',<HQRP;),<N%
MXS%7,O,&8S)G,AHS&3,6,S8':@>>-+8TF#1S-&L'FC2.-+<TVS2E-&PTP32$
M-'$':`>5-'HTF31R![@TN31P-"X(-3=B")`WNS?M-Y@(M0CK",$YPSG..?L(
M^`BM.00Z]0BY.0@)YSD'A@@Z!CH*"0HZL#D&"?@Y##K]"+$Y^@@".@<Z"3H!
M.A<Z_SD2.KH)N0D#/0<]`3WU//$\"#WR/`\]NPG^/!@*0`H]"AH_$#\./P)`
M\S_-"LD*^S_+"LH*S@H;02-!84%H05X+9T'309$+C`N00N$+`@S50M="UD(P
M0RL,)D,J#$!#%`H>0ZT,HPRK#$=$KPQ+1%%$3T1"1$9$!`UN16Q%\D5$#?%%
M]47S1?E%/0U'#9P-FD:31I%&X4;@#>0-(4<<1Q9'%T<V1Q]'@`Z32)E(FDB<
M2,H.24G4#C1)-TG2#BU)RPY,2<X.TPY(240/2`\[2T4/@0^&#X4/"$P:3*,/
M'4RU#TE,14Q$3)M(^@_Y#RI-+DW[#_(/,4WO#QI--$T735L09A#.$!U/<4^$
M3X!/<D^A3[0!>4^13\@0GT^M3]$0Q1`C3](0A4^<3[=/6%):4H\15U*R4J<1
MKE*E$:01$1)%5)Q4E%2C5(]4I52I5*94BE2@5)!4DE615915M1(F5C)6*%:T
M$KT2'%:[$BM6(%:Y$BE6PA*^$KH2(58Z6+<&6UA86'Q86!.F6*Y8K5AE69L3
M?EF<$WQ9?UEZ6;U9VA/>$\!9NUFM6J]:UEI-%$841Q1+%$P4V5I(%)D4$EP.
M7"5<FQ037.Y<SA2K7/=<ZQ19751=\EWP7>5=]ET<%8P5AV'1%5IBUA73%6YB
MU!70%=45>6(+%N%DYF3&%\1JTFJ`&B0`@1J/')<<B!R)''0`>@"!'&`=9'##
M`$(JTQW4`-4`TAW6'7,>^P!P'O<`,@$SA:@?IA_%'Y<AWB&Z`;\!EB&T(<<!
MA2&W`9LAH"&Y`5DAPP&&(;T!T`&O(7HAP0&^`<T!GB'+`:DA#R,.(QHD3P(?
M)%,"/"08)#XD)B15`CHD9'0B)%$"^R1C)60EGP*H)J,F@B:()J$FA2:8)OX"
MF2;[`HDF@2:6)H`F\0+U`I$F[P($`P,#]`+/)O,"`@/W`OH"_0+N`H<FH";P
M`GDF\@*&)JLFJB:D)HTF?B9$`]4G8@-W`\D)'BA?*%XH1"D^*>@#2"D<*>\#
M6RE-*>8#[0-7*><#4RE/*>L#.RE&*2T$501&*D<J4P1(*L`JO2J_*I`$$2N^
M!#XK.RN]!#HKSP30!.P$IRM+!>HL2`4'+2(M#"U5!5$%LRS6+-(L3@7C+.4L
MZ2QK!5X%$2W]+&`%9P4>+2`M(2T>+K@%XB_>+^8O%`8/!@<&$P;X+Q<&_B_!
M+[\O]R_1+U\Q8#%A,9H&N`;1,?<&^`9],FLR?S+]!O4&<S*!,FTR:3+Z!C@'
M'C/M-(<'@`>(!WD'`S5\!_XTY30>-0(U@P>%!PDURC0`->6%`348->(TSS1[
M!RXUQ33_-(8''#7#-#0(;S=5"&XW:`B^-YP(]#<M./P(MCEU.AXZ&@D8.A<)
M2#H;"4\Z$PE".FHZ<#K^.04)!PEM.AP)>SI^.EDZ$0E7.A8)@#I0.A4)*3IV
M.BHZ3#HJ/<L)-3TL/3<]'3W%"<().#W-"30]*STS/2<])#W*"2T],CZ#/H(^
MASX&/R0_.#\J/RP_*S^#"B\_*#\70-8*U0H90#A`T0H?0!1`/$#W/QQ`%4`8
M0#E`^4`D032&4@M?"VY!;4%Q08Y!E0OE09T+F`N>"Y8+E$*S0@,,V4(O#$A#
M24-#0S$,,PQ"0]]#M`QC1'9$L`Q?1&9$9D5Q10@-!PUV181%=47_10=&3@T.
M1@E&4`U2#:$-HPVE#<P-YT;B1E5'[PWJ#4-'5T=L1T)'4T?M#4%'A0Z$#J=(
MH$BF2*1(=$G;#EE)V0Y@25=);$E^261)UPY:25U)V@[>#M@.=DE-275)U0[3
M2]9+G`^=#V!,3DQ%33M-_@](34)-24U`311-04T'$.]-]DT#3FH0[4_G$-I/
M&%#23PA0XA``4-\0X1#E$!=01D\44--/!5`?4`)0%E#-3^9/D1%=4M52X5*T
M$;`1M1&N$>Y21U1&5"T2+!*[5"L2OU2T5"D2M51_$II50U;)$LL26E;%$L82
MRA(U5CA60E9)5EU62U8]5M(2T!(M$S438%A>6']8?EB#6&P3L5B'69T3H!.(
M68-9HA.?$X99BUF"6<I9TEGK$^(3U%G)6;!:-A0R%%`4\EKD6O-:ZEI/%/U:
M4A2=6RM<*ER>%"A<*5PL7*`4G!0Z7#!<-UP[7-$4"EWO%/`4\13^72!>'14+
M7A\5&%XB7AX5&UX(7B`5#EX37HX5D1658=V#D!77%8QB>V)_8H%BV16"8O05
M]A5@`?45\Q7N8NUB#!;L8E]C;V-1%FUCIA:G%J@6)Q<D%R47\&0J%W07QQ>I
M9N<7[1?@9K<:+@![`,P<O!Q\`*H<N1Q]`*L<PQS-''X=?AYY'OT`(X7A'N`>
MYQZ`'ZL?JA^I'^`?ZB':`=<AU@';`<$A%2-;`FPD7`)<)%`D821J)&DD5B1@
M)&8D7R0C)68E:"4&`PL#SB8-`\4FPR8*`Q,#T"80`Q(#"0,(`Q$##P-T)W8G
MW"?7)]HGVR=G`R`H;2EF*?8#9"EN*7Z%8"E"*UHK;BMD!6P%,"TZ+2HM0RT9
M+3$M;04]+7H%=04-!@@P,C`X,!X&,3`;!ADP*@81,!\&(@8I,!TP)08G!BD&
M/#`D!D8P1S`H!B8&.C`',",&:S&?!G`Q;3&Q!N0QDS(#!P<'#`<&!X\R!`<)
M!Y(R!0>.,@@'1C66!YP'GP>;!Y@'F0>4!S$UC0>C!SXUDP=\-4,UD@=S->B%
M536.!XP'A35--5`U1S5G-38U9#5A-9H'?35$-T`W<3=S-YPW:@AM"(0(P3>@
M"/HW,3@R.!T))@FX.J@Z,PF1.KLZ.`F:.C`)*`FI.B<)*@FU.FPZZ#HQ"=TZ
MVCKF.JPZ-`DN"3L)V3KC.NDZVSHI"6\]T@G8"4@]SPE*/6L]V0E//5<]=#W.
M"=,)T`E%/5$];3VA!U$^4#Y./D<*03^+"BX_1C_4"B=`W@I(0%-`/4#?"EU`
M5D#7"AY`1T!#0%A`24#A"DQ`14`^0"\+`4$>06(+8PMZ0>Y!`D*70IA"X@L$
M#$,,74-D0U-#6$."1)!$BD2^#'I$?42Z#(M$>$2\#$Z&C42(1))$@41^18-%
M#0T.#1$-@$4/#1(-50T/1ED-6PT=1E<-H4:D1LX-Z4;J1OX-8D=K1_P-7D?U
M#7E'^0WZ#6]':$>(#HD.KDB*#H<.BPZP2.8.D$GM#HI)Y0Z+29E)E4G@#H=)
M>$F728E)F$GA#EL/7`^C2X\/BP^-#]U+5TRY#V--:DUL30\0&1`3$%U-=4T8
M$%]-%A!]36U-4Q"-AD%.3U"$4/80?U#U$$A0*E![4')09%`N4%Q04U#W$$%0
MR%#P$&)0@%`^4(-0<5#Y$$I055!84)(1E1&6$?Q2_5(54[D1%E/_4KT1N!$2
M$EA4SU3@5(`2@1*:$I@2YU5J5H!6U!)O5F56VA)X5GU6B%;6$ML29%9^5MP2
M9U9C6(A8<1/-6'(3R5BH$^U9\!/;AO$3_1,X%#<4.12Q6E444Q0$6YY;H%M#
M7$9<2%Q%7$!<3%S5%+T4#%T3715=]11K76==75Y57C5>(1597B]>/%Z/7EQ>
M:EYB7E]>:UYN7CM>1%Y!7IIADA698=X5VQ7:%8]BWQ668OD5^!7Z%?1B_&(.
M%E5C0Q9Y8U864Q:>%NYC]6.I%@MD^A;S9#$7,!?W9/]D]60R%^QD\60I%RX7
MFF5V%^)F/6==9^AHI1CK:.]H[FB!:A1KT!S9'-P<V!R,`.$<ZQR+`(D`]!SB
M'-X<C0"&`-<`]!T$`0<!`P'M'NH>(@$R'U$!KA^P'V$!^R$#(@LBZ0$'(N4!
M^"'D`2@B'B+C`1@B$2)1(@4B%R.2)&4"C"1C`G@DA"1S)*TDER25)'<D<B26
M)(TD$"6,`FPE&@/G)A4#Y"8@`R$#[R8F(AP#&P/P)GLI_@.#*00$`02+*8PI
M``1X*5(J;023!-`JSRJA!+,KM"MV!7D%<@5[+8,%;RV!+3PM0BTX+3,MIH5@
M+6DM?2V&+2PN*"XX!DPP,`97,'PP-`8Z!E4P8C!Q,&HP5C`[,($P-09/,'XP
M9#`_!D`&,@8Q!C8&<3&Z>@\'I3*:,IPR$`>F,@T'I#*/-<4UR#62-;(UJ0>T
M!ZP'XS7`-=8UT36?-:(UTC6X!ZX'\WOA-=4UG36S![H'F#4_"'0WH3<\"?`Z
M\SI""4`)&SL,.QT[-#LH.Q<[/@E$.T([!#L1._HZ2CN1/8X]X0F+/8T]?SV,
M/7X]?#V#/>8)B#W@"14*E#Z3"E4_4S]//U0_;$!E0&9`84!K0&A`=D#G"F!`
M#WYT0`9!#D*M"P="K@OC"[E"]0NW0N)"!@QT0W=#=D-U0T\,>$-Q0U0,>D-;
M/7M#ID2N1+A$RPSC#,D,L42O1!,-B46'114-80TI1F8-*D9D#2U&+$9@#3)&
M8PWL1O!&@4>>1X-'"@Z21P0.HT>?1Y-'!PZ&1[A(MTB-#H\.D`Z2#NP.R$FV
M26R&T4GG#JA)JTGR#K-)S4GN#L])I$GO#DP/04MO2W%+7@]?#W8/=`]R#Y`/
M(TQ;3+X/84Q?3(%-)A`E$(1-$TYT$$I.3$[]$`41`1&]4)50"1&24,-0#!&6
M4*50M5"S4*-0Y%#84-50#1&W4*U0VE"34#93P!'%$<D1/5,K4T=3.5/5$453
M'5-!$O]4ZE0S$O54.A(`5>U4`U7I5$`20A+J5>@2FU:.5J)6Y!*<5I16D%:I
M5JQ6YQ*?5N82X1*=5CD39UA<$W43T%C66-18F%F:69=9KA.P$_H3"UH(6@%:
MM%JS6EL4H5NB6Z446ERB%&%<7US;%-H4)5U[779=?%TD%8E>]EZQ7JU>DEZ!
M7H1>)A6N7I!>GEZ8%985FA6B8:=AEQ7A%>`5XQ7B%:!BG6*?8M!B^Q718A(6
M%!998T469&-<%ET6N!899+H6%&059!ID`Q<U%S87.1<&92T7^&0!97H7OF6\
M9;=EMF7`97@7N&5[%WP7?A?$97T7OV7)%]IFY&;I9NAFZF;E9O,7)F<:&!D8
M0&<?&*88IQBH&*L8J1@N&;UJ7AF5`),`D@`.'98`]QR7`/P<#1T!'=H=V1W;
M'88>CA[N'C,?L1_U`4<B+2)4(NH!2R)2(C$B1")6(E`B*R+S`4TB-R)/(J(D
MMR1I`K(D:P*J)+4DL"1L`K0DI"2G)&@")B7^)B@#!"<F`_PF)0,&)PHG^B8-
M)P`G#B=K`P\$"`21*0P$CRF0*9@II"F;*:,IEBGD*5HJ8`1B!%XJF`2X*U<M
M7"VF+94MB"V*!:,MCRV$!60M?P59+7@M@@6%+8<MGBV6!8D%F"V<+8T%O`4O
M+H`PFS".,(TPE##&,$0&J#"#,#P&N3"&,+0PKS"1,$X&JC"A,*<PMC*S,A0'
MO#*L,A4'K3(.-LX''#8:-N`'P@<+-K\'[S4,-O`U(C;$!]@USP<2-OHUR`<J
M-LP'$#;-!\<'*3;Y->HU+#8D-K<8Z352-T\W4S=#"+8($#ME.W4[40E*"4T)
M5@G0.U,)7#L].W$[60F1.PL[>3N!.X\[3@E9.W0[[@FN/>P)HSVM/>L)[PFK
M/:8]HCWM"?(>5SY5/ID^2S]Z0/(*[PKQ"HQ`A$#M"O`*@D"30'M`[@H)01L8
M4`MF"X0"N`OV"XI#5PR00UX,QD331,!$TD3'1,)$&0V?19U%GD5P#4%&;@TX
M1CI&0D9R#78-/D:P1JY'LT<2#A\.OT<1#A8.S4<9#K)')`X4#B4.E0Z6#I,.
ME`[$2,U(PDC&2,-(R4C'2*`.^$G[#NU)XDG\#@`/^`[<20)*`4KY#M9)!`_D
M2?Y)`P\`2OQ)_4GS#O5)_TGZ#NM)Y4EX2ZY+YTN_#V5,:DQF3&A,:TR43:%-
MDDV639-->1`0$0%1%!'X4`X1]5`:$011&1$A$2,1'Q$;40-1,U$T4>U0)1$K
M$351%A$%42(1&Q'.$<\1?5/+$=$1S!%Q4Q<27%3F5`]5&U51$JE5I57N5;%6
M[1+,5LY6]!*W5O$2M5;I5K16^!*S5L%6KU;*5M!6+Q->$UT3CEAV$W<3Z5C;
M6'X3ZUBD6;83HEF=6;,3_!,#%``4*EHH6@H4`A2X6K9:N5JW6B);*ULG6QE;
MI%N'%+-;IA1Q7&I<J13>%(A=C%V_7KA>OE[<7N5>+A4M%=1>UEXP%=I>[5[S
M7MM>*Q6Y7N)>ZUZO89X5LF&S89\5Y17D%:-BI6+]%?P5%Q89%@IC&!:'8XEC
MC&/O8RID(F2_%A]D/!<996L7RF7:98,7@1>`%]YER&7@9<H7MF:U9LX7]&;V
M%VMG:6=R9V-G.1@-::X8`6D,:;48^&BS&+08_F@":81J(AFK:JIJ'1T6'9D`
M*QT>'1L=D!Z4'A0?B7("`F<B`0)[(J$"7R)A(OT!<P)T`G`"=@)U`G("PR3*
M)+LDP"3$)`$E'R<8)Q$G%2<I`Q(G'"<J`R(G>2>F*18$LRFK*>HJF01;*],$
M]02W+<XMN2V]+<\MP"V9+9<ME`6[+=`MQ"TQ+E8&TS#`,%D&6`95!E(&W##1
M,,@P5P;5,,,R&P<<![\RQ3(9!\TRP3(&,S\')#-C-D(V4C;;!T,V,S;B!VPV
M5S;7!TPV;C;>!^4'Y`?F!]8'-S;?!W$V2C8V-MP'4S;:!T4V<#;3!]`'7#98
M-U<WA@B'"*T(MPA8"6H)NSMB"6$)OCMI"6P)90FU.],[GSMF";<[]3NW/?4)
MNSWT"=$]]PFZ/?@)MCW,/?L)_`G3/9M`]0KX"I9`HD"=0`I!#D$\"X%!+$(W
M0C9".T+%"Z%"8@QC#)A#9PR60V8,V0S;#-9$ZT38#-Q$&PVE1:E%-&131D5&
M>0U/1GT-O4:[1O%&+`XW#NQ'[4<P#IH.TT@`%N%(!0\92@</"0\*#R=*)DIY
M#\(/;DRO33@0-Q"M32$0JDT83EX0/1$W$4`1;U%,41T10E$S$5Q1<%%?4341
M6E%+43]1BE/8$8M3H5..4]P1WA&94UY47U0D5:=5ZE;]5OE6XU;E5OH2^Q+L
M5CT3.Q,_$U\3\EA_$^]8A!.F6;P3%!0/%#M:0UH.%#):,5LP6V`4+5L\6Z=;
MI5NK%*P4JA0W795=CET$%99="!5%7PI?,Q4T%?U>%U\<7P=?,5\R7RQ?,%\#
M7P5?HA7"8:05N&&E%<%AIQ6F%><5JV*W8O\5_A458Q1C'18<%@QC%V-G%I-C
ME!;28\46R!8V9#%D,V0\9"YD.F3)%CUDQQ:U9")E(V4@91QE'65L%Z!EBA?O
M9>AEZV6(%X<7AA?A9>9ESQ?0%_AF]68<&",8@V>49X1G21B+9X]G0QB,9T@8
MB6='&(YG1A@_&$08)&D/:;X8$VD*:<(8NAB\&,88*FD::<@8)VD6:2%I(QF%
M:JQJQFK%:M=J4VN=`"@=)QW?'20!-1^S'P<"BB)](HDB>0+-)-`D>`(K)S,G
M*2<U)S$G-R<V*+XI&02Y*1P$NRD8!.(MVRW=+=PMVBVOA=DMO05=!M\P6@9>
M!N$P7`;N,%L&M3'4,M4R(0?0,M$RSC+7,B`',@=]-HHV\@>G-O4'F3:"-H@V
M[@?L!X8VZ@>8-ITV[0?S!X\V]@>J-D@(73=)"`HX=0G7.]8[Y3MO"7L)<PG9
M.]H[ZCMP"?8[.7UX">,]_@GI/0`*ZSWO/?,]ZCT!"B&&50I6"IT*<3_Y"JY`
M_PJS0/T*K$!#"T$+@T%%0DY"1$*C0J5"ID.D0V\,J4.O0XH,Y0SF#/!$^$3Q
M1'\-24:U#;8-NPW"1O)&\T;Z1T`.]D?\1QA("$@22)T.G`[;2-I(#P\1#PT/
M+$I-2A0/$P]&2_9+*TQT3+A-R$V"$(,031&249-13Q%_4:M1EU%,$5$1K%'N
M$>@1RQC.4^L1S5/B$>81P5.Q4\=3[!%`55D2/U4Y55T20U57$EL25A*K5?X2
M'U<)5PQ7`!,!$T!80A.66&`3]ECW6!T41EI/6CX4:11E%#U;05MF7WA?75]I
M7W1??5]N7W)?<U]B7TA?4U]?7VA?.!5_7VM?KA7$8:T5KV*M8K)B`A8?%AIC
M&V,B%B`6]89L%IMCGV-H%FT6;A:@%LX6T!;1%LL60&32%D=DTQ:W9"`73A=+
M%W(7<!>B99(7CQ<`9O-ED!<WA/5EV1?5%[UF`&<"9_H7-&=)9Y]G2QBC9\UG
MF6>=9]`8SA@Y:<\81&G$&,P8-6G2&#49KVH#"B\=G@"O`(YK#`*?(ILBGB*6
M(I0BH")\`CLG,`,Q`SHGP2E-*UTK\RVA!9X%:`9A!O8PY3#J,.<P!3%E!ODP
M9@9J!JL&JS;M-K(VL#:U-KXVP3;(-OD'P#:\-K$VQ#:_-E@(B@@(/`,\_3L0
M/`(\$SP$"OH]`#ZY0+Q``@M;0E%"3T+K0KA#>0RY0\%#P$.^0PM%ZPP'10I%
M"$7I#`U%!D451:]%(`TA#8$-]49-#ED.+DA8#AM(T8$:2"1(I0ZI#N9(XT@:
M#QD/74I/2F9*6TI'2[1+E@^8#Y</^DLN3-^"R`_.34,011`93E(15Q',4;)1
M51&[4<%15A%8$?(1Z5/N4_!3UE,.5-I32%5*54Y5356Q5;!5LU4'$SA7,E<(
M$RU7"A,T5QL/*5=T6&$38A,#6<(3QA.I65A:'A0E%+]:P5I*6ZQ;L!2)7#U=
M/%VI7:!?/1607SX5DU^+7ZU?NU^X7T85116<7]AAUV$#%B86)Q9=8ZECVF.8
M%JT6U1;:%E1DV1959$MDW18_9+ED%1<6%Q<7(1<X939E0&5,%SME.66D9987
MF!<(9@QFFQ<09O\7!V<E&-)G3QC"9[MGS&?+9U885!A-:6-I3FG8&%!I56G7
M&%YI)AF0:K)JL6HX&<IJ`FLG:R9KBAFO(N`DW"0T`SDG-0-JA7PG\R=PA:$#
M:RC$*0LQ"#$*,6P&;0;<,2D'*@?A,M\RSC;4-N,VUS;B-@`("`@&"`4(V#;5
M-M(VL0B("1X\+#PE//,[!#X(/A4^"0K$0,E`QT#(0*E"QD/%0QA%&D4@12(-
M9D9D1FI&U0UA#ET.8@Y/#F`.-4@T2*H.(@]L2B$/;DIQ2D80U$W631I.8DYE
M3G9.VU'646(1YU%@$601]%&VAOU3U5,'5/81#U3X4\&&&1*'59$2M57U50T3
M/U=#5TQ791,+66M::%IP6G5:=UH_%,-:2Q7I7^I?RU_%7\9?2!7M7]-?4A7E
M7TH5417;7^M?X%_!7U`53!7=8>X5!!8&%BT6+A8O%GL6>!9W%K)CM&.Q8[5C
M\F.B%J$6XQ969!H7&1=7%T1EGA<F9A]F&&8A9A=FW1<)9P48*!C%9]]G8!CC
M9V88Z6?N9V<8:!AF:7IIWAAN:9%I@VEV:7YI;6GA&)5JXVII&7<9`VL$:QF'
M%VNF`#8=I0`V'Q0"0B<V`S@#1"=&)WXGRBG(*<PI\"IP!H4QY3+G,BL'$0@*
M"/0V#0CI-A8($`@)"`X(>@@]/(P)-CR1"18^"@H2/@\^%SX1/@L^"`H+"LU`
MT$#,0,Y`T4`'"XE!\@QO1DM(1$A52*X.)`\F#R</?TIQ5YD/+TQZ3'M,?$Q?
M$6H1<1'\41!2`E)L$6\1[E$#4F@1#5(34@A2#U(85!)4`1)H$F=5956[56E7
M8E<3$VY7%A-A5Q@39%=-5U%8B1/($X-:QEJ$%!]@5!4$8!=@"&`%8%85\U\>
M8`)@&F`;8"=@'&!:%;5B!18'%C-C,18T8S%CN&.Z8Z,6_&/K%AP7PV1:%TUE
M6Q<O9J87JA>E%\EFX1?(9L1F*F<X9U!G*A@*:/MG!&C\9_YG<AAO&',8`FCV
M9QMH^6<5:!!H_V<`:`QH:QCF&)5II6GI&.P8Z!CP&)AJP6J,&5IK9!V[(A4"
MYB1))_<G<0,F!-`IQ@3"*Z@%$3%S!O\V_C;]-A4(`3>8"9<)2SQ-/$<\TT!H
M0F="UPN`#-%#,$4R12Y%B`V=:\E&R$9I#E9(44AK#BD/*`^%2HE*CDJ$2E\0
M:DXK4B]2*%)T$192%5(=4AI4`A)J$I02O%5U5WQ7BA,161)97%N[7605]%]>
M%6$5+6!E%685Y&(W8S9C9V.^8[UCXF-H9&9DR&3*9,=DW&1?%T]EJ64\9J\7
M.V;.9@T8%&=39WP8+FAZ&!]H=AAY&'T8=QBP:;UI]ACQ&*YIQ&E[:@L,*1F>
M:F\9!6N:&6EKH6O'(ATC2B?3*6D$<BL"+JL%-2XG,1XQ'S$L!RT'!S<&-Q<(
MF@E4/!P^(#[X1FX.74A82"P/DDI.2\H/>!$&$B=4!Q*!5X-7(!-$6%,3SA-Z
M%'D40F!-8%1@3F!K%4-@9Q5M%3QC0&/`8X46L!;S%F,76F519K87W6:"&'\8
M.&B&&$5H.FB$&#5H_!C]&/H8\6J'&9-KFAX:`AD"05+7*74&*#$:"!L(&0A3
M/%D\G`DA/A`*;T(W1;5%8DA>2/5(>Q%\$3U2"!(M5(E5C5>'5Y!7&EF96D$4
MXQ1R%5]@<Q5H%59@86!;8%I@7&!E8#4606.(%IT6;F1L9&UD=0ZJ95QF6&;>
M9H\83VA1:(X84V@%&009_QC\:3EKGAD^'50!TB*!`D\G%#?Z#')&<T8R#W`2
M;A*15]:&?!2_7745;&!T%7<5YF)%8S<6R&/D8UUENA<A9Q$8+&=79Y(8F1A=
M:&%H96@(:@H9*ADK&409>1E%:ZH`2`,%+N\R&S<=-R4^)#YM2+0.0E))4@T2
M>%6*59=75!.;6!Q9,!2B6@D6.!8V%HL6]Q9F%[T7'AAL:)88;V@-&0YJ<QD(
M:QUKHVL[`SP#8"L<-Z`)^PS];/-(@1&;5Z=:Q%UX%7I@C19S%V%F8V;79G9H
MIAFE:ZT%9SP1"JL^2E)]59U74UAE6WM@.1;-9-UDOQ<P9Q9J#QFG&;49W`LQ
M%.=B&&JB:J@9?&LE#9Y*A&#!%QQJD`UQ2,ICEA)_%!`9HVH*%GMHEVL2&3H6
M4&,[%@````````````````````````````````!.64X!3@-.0TY=3H9.C$ZZ
M3C]195%K4>!1`%(!4IM2%5-!4UQ3R%,)3@M."$X*3BM..$[A445.2$Y?3EY.
MCDZA3D!1`U+Z4D-3R5/C4Q]7ZU@562=9<UE06U%;4UOX6P]<(EPX7'%<W5WE
M7?%=\EWS7?Y=<E[^7@M?$U]-8A%.$$X-3BU.,$XY3DM..5R(3I%.E4Z23I1.
MHD[!3L!.PT[&3L=.S4[*3LM.Q$Y#44%19U%M46Y1;%&74?91!E('4@A2^U+^
M4O]2%E,Y4TA31U-%4UY3A%/+4\I3S5/L6"E9*UDJ62U95%L17"1<.EQO7/1=
M>U[_7A1?%5_#7PAB-F)+8DYB+V6'99=EI&6Y9>5E\&8(9RAG(&MB:WEKRVO4
M:]MK#VPT;&MP*G(V<CMR1W)9<EMRK'*+<QE.%DX53A1.&$X[3DU.3TY.3N5.
MV$[43M5.UD[73N-.Y$[93MY.15%$48E1BE&L4?E1^E'X40I2H%*?4@53!E,7
M4QU3WTY*4TE385-@4V]3;E.[4^]3Y%/S4^Q3[E/I4^A3_%/X4_53ZU/F4^I3
M\E/Q4_!3Y5/M4_M3VU;:5A99+EDQ6719=EE56X-;/%SH7>==YET"7@-><UY\
M7@%?&%\77\5?"F)38E1B4F)18J5EYF4N9RQG*F<K9RUG8VO-:Q%L$&PX;$%L
M0&P^;*]RA'.)<]QTYG08=1]U*'4I=3!U,74R=3-UBW5]=JYVOW;N=MMWXG?S
M=SIYOGET>LMZ'DX?3E).4TYI3IE.I$ZF3J5._TX)3QE/"D\53PU/$$\13P]/
M\D[V3OM.\$[S3OU.`4\+3TE11U%&44A1:%%Q48U1L%$74A%2$E(.4A92HU((
M4R%3(%-P4W%3"50/5`Q4"E005`%4"U0$5!%4#50(5`-4#E0&5!)4X%;>5MU6
M,U<P5RA7+5<L5R]7*5<961I9-UDX6819>%F#67U9>5F"68%95UM86X=;B%N%
M6XE;^EL67'E<WET&7G9>=%X/7QM?V5_67PYB#&(-8A!B8V);8EAB-F7I9>AE
M[&7M9?)F\V8)9SUG-&<Q9S5G(6MD:WMK%FQ=;%=L66Q?;&!L4&Q5;&%L6VQ-
M;$YL<'!?<EUR?G;Y>G-\^'PV?XI_O7\!@`.`#(`2@#.`?X")@(N`C(#C@>J!
M\X'\@0R"&X(?@FZ"<H)^@FN&0(A,B&.(?XDAEC).J$Y-3T]/1T]73UY/-$];
M3U5/,$]03U%//4\Z3SA/0T]43SQ/1D]C3UQ/8$\O3TY/-D]93UU/2$]:3TQ1
M2U%-4751ME&W4252)%(I4BI2*%*K4JE2JE*L4B-3<U-U4QU4+50>5#Y4)E1.
M5"=41E1#5#-42%1"5!M4*51*5#E4.U0X5"Y4-50V5"!4/%1`5#%4*U0?5"Q4
MZE;P5N16ZU9*5U%70%=-5T=73E<^5U!73U<[5^]8/EF=69)9J%F>6:-9F5F6
M68U9I%F368I9I5E=6UQ;6EM;6XQ;BUN/6RQ<0%Q!7#]</ER07)%<E%R,7.M=
M#%Z/7H=>BE[W7@1?'U]D7V)?=U]Y7]A?S%_77\U?\5_K7_A?ZE\28A%BA&*7
M8I9B@&)V8HEB;6**8GQB?F)Y8G-BDF)O8IAB;F*58I-BD6*&8CEE.V4X9?%E
M]&9?9TYG3V=09U%G7&=69UYG26=&9V!G4V=79V5KSVM";%YLF6R!;(ALB6R%
M;)ML:FQZ;)!L<&R,;&ALEFR2;'UL@VQR;'YL=&R&;'9LC6R4;)AL@FQV<'QP
M?7!X<&)R87)@<L1RPG*6<RQU*W4W=3AU@G;O=N-WP7G`>;]Y=GK[?%5_EH"3
M@)V`F(";@)J`LH!O@I*"BX*-@HN)THD`BC>,1HQ5C)V,9(UPC;.-JX[*CIN/
ML(_"C\:/Q8_$C^%=D9"BD*J0II"CD$F1QI',D3*6+I8QEBJ6+)8F3E9.<TZ+
M3IM.GDZK3JQ.;T^=3XU/<T]_3VQ/FT^+3X9/@T]P3W5/B$]I3WM/ED]^3X]/
MD4]Z3U114E%546E1=U%V47A1O5']43M2.%(W4CI2,%(N4C9205*^4KM24E-4
M4U-345-F4W=3>%-Y4]93U%/74W-4=5265'A4E52`5'M4=U2$5))4AE1\5)!4
M<51V5(Q4FE1B5&A4BU1]5(Y4^E:#5W=7:E=I5V%79E=D5WQ7'%E)64=92%E$
M6519OEF[6=19N5FN6=%9QEG06<U9RUG36<I9KUFS6=)9Q5E?6V1;8UN76YI;
MF%N<6YE;FUL:7$A<15Q&7+=<H5RX7*E<JURQ7+-<&%X:7A9>%5X;7A%>>%Z:
M7I=>G%Z57I9>]EXF7R=?*5^`7X%??U]\7]U?X%_]7_5?_U\/8!1@+V`U8!9@
M*F`58"%@)V`I8"M@&V`68A5B/V(^8D!B?V+)8LQBQ&*_8L)BN6+28MMBJV+3
M8M1BRV+(8JABO6*\8M!BV6+'8LUBM6+:8K%BV&+68M=BQF*L8LYB/F6G9;QE
M^F449A-F#&8&9@)F#F8`9@]F%68*9@=F#6<+9VUGBV>59W%GG&=S9W=GAV>=
M9Y=G;V=P9W]GB6=^9Y!G=6>:9Y-G?&=J9W)G(VMF:V=K?VL3;!MLXVSH;/-L
ML6S,;.5LLVR];+YLO&SB;*MLU6S3;+ALQ&RY;,%LKFS7;,5L\6R_;+MLX6S;
M;,ILK&SO;-QLUFS@;)5PCG"2<(IPF7`L<BUR.')(<F=R:7+`<LYRV7+7<M!R
MJ7.H<Y]SJW.E<SUUG769=9IUA';"=O)V]';E=_UW/GE`>4%YR7G(>7IZ>7KZ
M>OY\5'^,?XM_!8"Z@*6`HH"Q@*&`JX"I@+2`JH"O@.6!_H$-@K."G8*9@JV"
MO8*?@KF"L8*L@J6"KX*X@J."L(*^@K>"3H9QAAU2:(C+CLZ/U(_1C[60N)"Q
MD+:0QY'1D7>5@)4<ED"6/Y8[ED260I:YENB64I=>EY].K4ZN3N%/M4^O3[]/
MX$_13\]/W4_#3[9/V$_?3\I/UT^N3]!/Q$_"3]I/SD_>3[=/5U&249%1H%%.
M4D-22E)-4DQ22U)'4L=2R5+#4L%2#5-74WM3FE/;4ZQ4P%2H5,Y4R52X5*94
MLU3'5,)4O52J5,%4Q%3(5*]4JU2Q5+M4J52G5+]4_U:"5XM7H%>C5Z)7SE>N
M5Y-755E164]93EE06=Q9V%G_6>-9Z%D#6N59ZEG:6>99`5K[66E;HUNF6Z1;
MHENE6P%<3EQ/7$U<2US97-)<]UT=7B5>'UY]7J!>IE[Z7@A?+5]E7XA?A5^*
M7XM?AU^,7XE?$F`=8"!@)6`.8"A@36!P8&A@8F!&8$-@;&!K8&I@9&!!8MQB
M%F,)8_QB[6(!8^YB_6('8_%B]V+O8NQB_F+T8A%C`F,_945EJV6]9>)E)68M
M9B!F)V8O9A]F*&8Q9B1F]V;_9]-G\6?49]!G[&>V9Z]G]6?I9^]GQ&?19[1G
MVF?E9[AGSV?>9_-GL&?99^)GW6?29VIK@VN&:[5KTFO7:Q]LR6P+;3)M*FU!
M;25M#&TQ;1YM%VT[;3UM/FTV;1MM]6PY;2=M.&TI;2YM-6T.;2MMJW"Z<+-P
MK'"O<*UPN'"N<*1P,')R<F]R='+I<N!RX7*W<\ISNW.R<\USP'.S<QIU+75/
M=4QU3G5+=:MUI'6E=:)UHW5X=H9VAW:(=LAVQG;#=L5V`7?Y=OAV"7<+=_YV
M_'8'=]QW`G@4>`QX#7A&>4EY2'E'>;EYNGG1>=)YRWE_>H%Z_WK]>GU\`GT%
M?0!]"7T'?01]!GTX?XY_OW\0@`V`$8`V@-:`Y8#:@,.`Q(#,@.&`VX#.@-Z`
MY(#=@/2!(H+G@@.#!8/C@MN"YH($@^6"`H,)@]*"UX+Q@@&#W(+4@M&"WH+3
M@M^"[X(&@U"&>89[AGJ&38AKB(&)U(D(B@**`XJ>C*",=(USC;2-S8[,CO"/
MYH_BC^J/Y8_MC^N/Y(_HC\J0SI#!D,.02Y%*D<V1@I50EDN63)9-EF*7:9?+
ME^V7\Y<!F*B8VYC?F):9F9E83K-.#%`-4"-0[T\F4"50^$\I4!90!E`\4!]0
M&E`24!%0^D\`4!10*%#Q3R%0"U`94!A0\T_N3RU0*E#^3RM0"5!\4:11I5&B
M4<U1S%'&4<M15E)<4E126U)=4BI3?U.?4YU3WU/H5!!5`54W5?Q4Y53R5`95
M^E045>E4[53A5`E5[E3J5.94)U4'5?U4#U4#5P17PE?45\M7PU<)6`]95UE8
M65I9$5H86AQ:'UH;6A-:[%D@6B-:*5HE6@Q:"5IK6UA<L%NS6[9;M%NN6[5;
MN5NX6P1<45Q57%!<[5S]7/M<ZESH7/!<]EP!7?1<[ETM7BM>JUZM7J=>,5^2
M7Y%?D%]98&-@96!08%5@;6!I8&]@A&"?8)I@C6"48(Q@A6"68$=B\V((8_]B
M3F,^8R]C56-"8T9C3V-)8SIC4&,]8RIC*V,H8TUC3&-(94EEF67!9<5E0F9)
M9D]F0V929DQF169!9OAF%&<59Q=G(6@X:$AH1FA3:#EH0FA4:"EHLV@7:$QH
M46@]:/1G4&A`:#QH0V@J:$5H$V@8:$%HBFN):[=K(VPG;"AL)FPD;/!L:FV5
M;8AMAVUF;7AM=VU9;9-M;&V);6YM6FUT;6EMC&V*;7EMA6UE;91MRG#8<.1P
MV7#(<,]P.7)Y<OQR^7+]<OAR]W*&<^US"73N<^!SZG/><U1U775<=5IU676^
M=<5UQW6R=;-UO76\=;EUPG6X=8MVL';*=LUVSG8I=Q]W('<H=^EW,'@G>#AX
M'7@T>#=X)7@M>"!X'W@R>%5Y4'E@>5]Y5GE>>5UY5WE:>>1YXWGG>=]YYGGI
M>=AYA'J(>MEZ!GL1>XE\(7T7?0M]"GT@?2)]%'T0?15]&GT<?0U]&7T;?3I_
M7W^4?\5_P7\&@`2`&(`5@!F`%X`]@#^`\8`"@?"`!8'M@/2`!H'X@/.`"(']
M@`J!_(#O@.V![($`@A""*H(K@BB"+(*[@BN#4H-4@TJ#.(-0@TF#-8,T@T^#
M,H,Y@S:#%X-`@S&#*(-#@U2&BH:JAI.&I(:IAHR&HX:<AG"(=XB!B(*(?8AY
MB!B*$(H.B@R*%8H*BA>*$XH6B@^*$8I(C'J,>8RAC**,=XVLCM*.U([/CK&/
M`9`&D/>/`)#ZC_2/`Y#]CP60^(^5D.&0W9#BD%*139%,D=B1W9'7D=R1V9&#
ME6*68Y9AEEN6799DEEB67I:[EN*8K)FHFMB:)9LRFSR;?DYZ4'U07%!'4$-0
M3%!:4$E095!V4$Y055!U4'10=U!/4`]0;U!M4%Q1E5'P46I2;U+24ME2V%+5
M4A!3#U,94S]30%,^4\-3_&9&56I59E5$55Y5855#54I5,55654]5554O5615
M.%4N55Q5+%5C53-5055750A7"U<)5]]7!5@*6`98X%?D5_I7`E@U6/=7^5<@
M66)9-EI!6DE:9EIJ6D!:/%IB6EI:1EI*6G!;QUO%6\1;PEN_6\9;"5P(7`=<
M8%Q<7%U<!UT&70Y=&UT672)=$5TI711=&5TD72==%UWB73A>-EXS7C=>MUZX
M7K9>M5Z^7C5?-U]77VQ?:5]K7Y=?F5^>7YA?H5^@7YQ??V"C8(E@H&"H8,M@
MM&#F8+U@Q6"[8+5@W&"\8-A@U6#&8-]@N&#:8,=@&F(;8DABH&.G8W)CEF.B
M8Z5C=V-G8YACJF-Q8ZECB6.#8YMC:V.H8X1CB&.98Z%CK&.28X]C@&-[8VEC
M:&-Z8UUE5F5195EE5V5?54]E6&55951EG&6;9:QESV7+9<QESF5=9EIF9&9H
M9F9F7F;Y9M=2&V>!:*]HHFB3:+5H?VAV:+%HIVB7:+!H@VC$:*UHAFB%:)1H
MG6BH:)]HH6B":#)KNFOK:^QK*VR.;;QM\VW9;;)MX6W,;>1M^VWZ;05NQVW+
M;:]MT6VN;=YM^6VX;?=M]6W%;=)M&FZU;=IMZVW8;>IM\6WN;>AMQFW$;:IM
M[&V_;>9M^7`)<0IQ_7#O<#UR?7*!<AQS&W,6<Q-S&7.'<P5T"G0#=`9T_G,-
M=.!T]G3W=!QU(G5E=69U8G5P=8]UU'75=;5URG7-=8YVU';2=MMV-W<^=SQW
M-G<X=SIW:WA#>$YX97EH>6UY^WF2>I5Z('LH>QM[+'LF>QE['GLN>Y)\EWR5
M?$9]0WUQ?2Y].7T\?4!],'TS?41]+WU"?3)],7T]?YY_FG_,?\Y_TG\<@$J`
M1H`O@1:!(X$K@2F!,($D@0*"-8(W@C:".8*.@YZ#F(-X@Z*#EH.]@ZN#DH.*
M@Y.#B8.@@W>#>X-\@X:#IX-5AFI?QX;`AK:&Q(:UAL:&RX:QAJ^&R893B)Z(
MB(BKB)*(EHB-B(N(DXF/B2J*'8HCBB6*,8HMBA^*&XHBBDF,6HRIC*R,JXRH
MC*J,IXQGC6:-OHVZC=N.WXX9D`V0&I`7D".0'Y`=D!"0%9`>D""0#Y`BD!:0
M&Y`4D.B0[9#]D%>1SI'UD>:1XY'GD>V1Z9&)E6J6=99SEGB6<)9TEG:6=Y9L
MEL"6ZI;IEN!ZWWH"F`.86IOEG'6>?YZEGKN>HE"-4(50F5"14(!0EE"84)I0
M`&?Q47)2=%)U4FE2WE+=4MM26E.E4WM5@%6G57Q5BE6=59A5@E6<5:I5E%6'
M58M5@U6S5:Y5GU4^5;)5FE6[5:Q5L55^58E5JU6950U7+U@J6#18)%@P6#%8
M(5@=6"!8^5CZ6&!9=UJ:6G]:DEJ;6J=:<UMQ6]);S%O36]!;"EP+7#%<3%U0
M731=1UW]745>/5Y`7D->?E[*7L%>PE[$7CQ?;5^I7ZI?J%_18.%@LF"V8.!@
M'&$C8?I@%6'P8/M@]&!H8?%@#F'V8`EA`&$281]B26*C8XQCSV/`8^ECR6/&
M8\UCTF/C8]!CX6/68^UC[F-V8_1CZF/;8U)DVF/Y8UYE9F5B96-ED6609:]E
M;F9P9G1F=F9O9I%F>F9^9G=F_F;_9A]G'6?Z:-5HX&C8:-=H!6G?:/5H[FCG
M:/EHTFCR:.-HRVC-:`UI$FD.:<EHVFAN:?MH/FLZ:SUKF&N6:[QK[VLN;"]L
M+&PO;CAN5&XA;C)N9VY*;B!N)6XC;AMN6VY8;B1N5FYN;BUN)FYO;C1N36XZ
M;BQN0VX=;CYNRVZ);AEN3FYC;D1N<FYI;E]N&7$:<29Q,'$A<39Q;G$<<4QR
MA'*`<C9S)7,T<RES.G0J=#-T(G0E=#5T-G0T="]T&W0F="AT)74F=6MU:G7B
M==MUXW79==AUWG7@=7MV?':6=I-VM';<=D]W[7==>&QX;W@->@AZ"WH%>@!Z
MF'J7>I9ZY7KC>DE[5GM&>U![4GM4>TU[2WM/>U%[GWRE?%Y]4'UH?55]*WUN
M?7)]87UF?6)]<'US?815U'_5?PN`4H"%@%6!5(%+@5&!3H$Y@4:!/H%,@5.!
M=($2@AR"Z8,#A/B##83@@\6#"X3!@^^#\8/T@U>$"H3P@PR$S(/]@_*#RH,X
MA`Z$!(3<@P>$U(/?@UN&WX;9ANV&U(;;AN2&T(;>AE>(P8C"B+&(@XF6B3N*
M8(I5BEZ*/(I!BE2*6XI0BD:*-(HZBC:*5HIAC(*,KXR\C+.,O8S!C+N,P(RT
MC+>,MHR_C+B,BHV%C8&-SHW=C<N-VHW1C<R-VXW&C?N.^([\CIR/+I`UD#&0
M.)`RD#:0`I'UD`F1_I!CD661SY$4DA62(Y()DAZ2#9(0D@>2$9*4E8^5BY61
ME9.5DI6.E8J6CI:+EGV6A9:&EHV6<I:$EL&6Q9;$EL:6QY;OEO*6S)<%F`:8
M")CGF.J8[YCIF/*8[9BNF:V9PY[-GM&>@DZM4+50LE"S4,50OE"L4+=0NU"O
M4,=0?U)W4GU2WU+F4N12XE+C4B]3WU7H5=-5YE7.5=Q5QU715>-5Y%7O5=I5
MX57%5<95Y57)51)7$U=>6%%86%A76%I85%AK6$Q8;5A*6&)84EA+6&=9P5K)
M6LQ:OEJ]6KQ:LUK"6K)::5UO74Q>>5[)7LA>$E]97ZQ?KE\:80]A2&$?8?-@
M&V'Y8`%A"&%.84QA1&%-83YA-&$G80UA!F$W82%B(F(39#YD'F0J9"UD/60L
M9`]D'&049`UD-F069!=D!F1L99]EL&679HEFAV:(9I9FA&:89HUF`V>4:6UI
M6FEW:6!I5&EU:3!I@FE*:6AI:VE>:5-I>6F&:5UI8VE;:4=K<FO`:[]KTVO]
M:Z)NKV[3;K9NPFZ0;IUNQV[%;J5NF&Z\;KINJV[1;I9NG&[$;M1NJFZG;K1N
M3G%9<6EQ9'%)<6=Q7'%L<69Q3'%E<5YQ1G%H<59Q.G)2<C=S17,_<SYS;W1:
M=%5T7W1>=$%T/W19=%MT7'1V=7AU`';P=0%V\G7Q=?IU_W7T=?-UWG;?=EMW
M:W=F=UYW8W=Y=VIW;'=<=V5W:'=B=^YWCGBP>)=XF'B,>(EX?'B1>)-X?WAZ
M>7]Y@7DLA+UY''H:>B!Z%'H?>AYZGWJ@>G=[P'M@>VY[9WNQ?+-\M7R3?7E]
MD7V!?8]]6WUN?VE_:G]R?ZE_J'^D?U:`6("&@(2`<8%P@7B!98%N@7.!:X%Y
M@7J!9H$%@D>"@H1WA#V$,81UA&:$:X1)A&R$6X0\A#6$881CA&F$;81&A%Z&
M7(9?AOF&$X<(AP>'`(?^AON&`H<#AP:'"H=9B-^(U(C9B-R(V(C=B.&(RHC5
MB-*(G(GCB6N*<HISBF:*:8IPBH>*?(ICBJ"*<8J%BFV*8HINBFR*>8I[BCZ*
M:(IBC(J,B8S*C,>,R(S$C+*,PXS"C,6,X8W?C>B-[XWSC?J-ZHWDC>:-LHX#
MCPF/_HX*CY^/LH]+D$J04Y!"D%20/)!5D%"01Y!/D$Z039!1D#Z009`2D1>1
M;)%JD6F1R9$WDE>2.)(]DD"2/I);DDN29))1DC2229)-DD62.9(_DEJ2F)68
MEI26E9;-ELN6R9;*EO>6^Y;YEO:65I=TEW:7$)@1F!.8"I@2F`R8_)CTF/V8
M_IBSF;&9M)GAFNF<@IX.GQ.?()_G4.Y0Y5#64.U0VE#54,]0T5#Q4,Y0Z5!B
M4?-1@U*"4C%3K5/^50!6&U875OU5%%8&5@E6#58.5O=5%E8?5@A6$%;V51A7
M%E=U6'Y8@UB36(I8>5B%6'U8_5@E62)9)%EJ66E9X5KF6NE:UUK66MA:XUIU
M6]Y;YUOA6^5;YEOH6^);Y%O?6PU<8ER$78==6UYC7E5>5UY47M->UEX*7T9?
M<%^Y7T=A/V%+87=A8F%C85]A6F%8875A*F*'9%AD5&2D9'AD7V1Z9%%D9V0T
M9&UD>V1R9:%EUV769:)FJ&:=9IQIJ&F5:<%IKFG3:<MIFVFW:;MIJVFT:=!I
MS6FM:<QIIFG#::-I26M,:S-L,V\4;_YN$V_T;BEO/F\@;RQO#V\";R)O_V[O
M;@9O,6\X;S)O(V\5;RMO+V^(;RIO[&X!;_)NS&[W;I1QF7%]<8IQA'&2<3YR
MDG*6<D1S4'-D=&-T:G1P=&UT!'61=2=V#78+=@EV$W;A=N-VA'=]=W]W87?!
M>)]XIWBS>*EXHWB.>8]YC7DN>C%ZJGJI>NUZ[WJA>Y5[BWMU>Y=[G7N4>X][
MN'N'>X1[N7R]?+Y\NWVP?9Q]O7V^?:!]RGVT?;)]L7VZ?:)]OWVU?;A]K7W2
M?<=]K'UP?^!_X7_??UZ`6H"'@%"!@(&/@8B!BH%_@8*!YX'Z@0>"%((>@DN"
MR82_A,:$Q(29A)Z$LH2<A,N$N(3`A-.$D(2\A-&$RH0_AQR'.X<BAR6'-(<8
MAU6'-X<IA_.(`HGTB/F(^(C]B.B(&HGOB*:*C(J>BJ.*C8JABI.*I(JJBJ6*
MJ(J8BI&*FHJGBFJ,C8R,C-.,T8S2C&N-F8V5C?R-%(\2CQ6/$X^CCV"06)!<
MD&.069!>D&*079!;D!F1&)$>D761>)%WD721>)*LDH"2A9*8DI:2>Y*3DIR2
MJ))\DI&2H96HE:F5HY6EE:25F9:<EIN6S);2E@"7?)>%E_:7%Y@8F*^8L9@#
MF069#)D)F<&9KYJPFN::09M"F_2<]ISSG+R>.Y]*GP11`%'[4/50^5`"40A1
M"5$%4=Q1AU*(4HE2C5**4O!2LE,N5CM6.58R5C]6-%8I5E-63E975G16-E8O
M5C!6@%B?6)Y8LUB<6*Y8J5BF6&U9"5O[6@M;]5H,6PA;[EOL6^E;ZUMD7&5<
MG5V476)>7UYA7N)>VE[?7MU>XU[@7DA?<5^W7[5?=F%G86YA76%588)A?&%P
M86MA?F&G89!AJV&.8:QAFF&D891AKF$N8FED;V1Y9)YDLF2(9)!DL&2E9)-D
ME62I9))DKF2M9*MDFF2L9)EDHF2S9'5E=V5X9:YFJV:T9K%F(VH?:NAI`6H>
M:AEJ_6DA:A-J"FKS:0)J!6KM:1%J4&M.:Z1KQ6O&:S]O?&^$;U%O9F]4;X9O
M;6];;WAO;F^.;WIO<&]D;Y=O6&_5;F]O8&]?;Y]QK'&Q<:AQ5G*;<DYS5W-I
M=(MT@W1^=(!T?W4@=BEV'W8D=B9V(78B=IIVNG;D=HYWAW>,=Y%WBW?+>,5X
MNGC*>+YXU7B\>-!X/WH\>D!Z/7HW>CMZKWJN>JU[L7O$>[1[QGO'>\%[H'O,
M>\I\X'WT?>]]^WW8?>Q]W7WH?>-]VGW>?>E]GGW9??)]^7UU?W=_KW_I?R:`
MFX&<@9V!H(&:@9B!%X4]A1J%[H0LA2V%$X41A2.%(844A>R$)87_A`:%@H=T
MAW:'8(=FAWB':(=9AU>'3(=3AUN(78@0B0>)$HD3B16)"HF\BM**QXK$BI6*
MRXKXBK**R8K"BK^*L(K6BLV*MHJYBMN*3(Q.C&R,X(S>C.:,Y(SLC.V,XHSC
MC-R,ZHSAC&V-GXVCC2N.$(X=CB*.#XXICA^.(8X>CKJ.'8\;CQ^/*8\FCRJ/
M'(\>CR6/:9!ND&B0;9!WD#"1+9$GD3&1AY&)D8N1@Y'%DKN2MY+JDN22P9*S
MDKR2TI+'DO"2LI*ME;&5!)<&EP>7"9=@EXV7BY>/ER&8*Y@<F+.8"ID3F1*9
M&)G=F="9WYG;F=&9U9G2F=F9MYKNFN^:)YM%FT2;=YMOFP:="9T#G:F>OI[.
MGJA84I\241A1%%$04151@%&J4=U1D5*34O-2659K5GE6:59D5GA6:E9H5F56
M<59O5FQ68E9V5L%8OEC'6,58;ED=6S1;>%OP6PY<2E^R89%AJ6&*8<UAMF&^
M8<IAR&$P8L5DP63+9+MDO&3:9,1DQV3"9,UDOV329-1DOF1T9<9FR6:Y9L1F
MQV:X9CUJ.&HZ:EEJ:VI8:CEJ1&IB:F%J2VI':C5J7VI(:EEK=VL%;,)OL6^A
M;\-OI&_!;Z=OLV_`;[EOMF^F;Z!OM&^^<<EQT''2<<AQU7&Y<<YQV7'<<<-Q
MQ'%H<YQTHW28=)]TGG3B=`QU#74T=CAV.G;G=N5VH'>>=Y]WI7?H>-IX['CG
M>*9Y37I.>D9Z3'I+>KIZV7L1?,E[Y'O;>^%[Z7OF>]5\UGP*?A%^"'X;?B-^
M'GX=?@E^$'YY?[)_\'_Q?^Y_*("S@:F!J('[@0B"6()9@DJ%685(A6B%:85#
MA4F%;85JA5Z%@X>?AYZ'HH>-AV&(*HDRB26)*XDAB:J)IHGFBOJ*ZXKQB@"+
MW(KGBNZ*_HH!BP*+]XKMBO.*]HK\BFN,;8R3C/2,1(XQCC2.0HXYCC6..X\O
MCSB/,X^HCZ:/=9!TD'B0<I!\D'J0-)&2D2"3-I/XDC.3+Y,BD_R2*Y,$DQJ3
M$),FDR&3%9,NDQF3NY6GEJB6JI;5E@Z7$9<6EPV7$Y</EUN77)=FEYB7,)@X
MF#N8-Y@MF#F8))@0F2B9'ID;F2&9&IGMF>*9\9FXFKR:^YKMFBB;D9L5G2.=
M)ITHG1*=&YW8GM2>C9^<GRI1'U$A43)1]5*.5H!6D%:%5H=6CU;56--8T5C.
M6#!;*ELD6WI;-UQH7+Q=NEV]7;A=:UY,7[U?R6'"8<=AYF'+83)B-&+.9,ID
MV&3@9/!DYF3L9/%DXF3M9()E@V799M9F@&J4:H1JHFJ<:MMJHVI^:I=JD&J@
M:EQKKFO::PALV&_Q;]]OX&_;;^1OZV_O;X!O[&_A;^EOU6_N;_!OYW'?<>YQ
MYG'E<>UQ[''T<>!Q-7)&<G!S<G.I=+!TIG2H=$9V0G9,=NIVLW>J=[!WK'>G
M=ZUW[W?W>/IX]'CO>`%YIWFJ>5=ZOWH'?`U\_GOW>PQ\X'O@?-Q\WGSB?-]\
MV7S=?"Y^/GY&?C=^,GY#?BM^/7XQ?D5^07XT?CE^2'XU?C]^+WY$?_-__']Q
M@'*`<(!O@'.`QH'#@;J!PH'`@;^!O8')@;Z!Z($)@G&"JH6$A7Z%G(61A92%
MKX6;A8>%J(6*A::%9X;`A]&'LX?2A\:'JX>[A[J'R(?+ASN)-HE$B3B)/8FL
MB0Z+%XL9BQN+"HL@BQV+!(L0BT&,/XQSC/J,_8S\C/B,^XRHC4F.2XY(CDJ.
M1(\^CT*/18\_CW^0?9"$D(&0@I"`D#F1HY&>D9R139."DRB3=9-*DV632Y,8
MDWZ3;)-;DW"36I-4D\J5RY7,E<B5QI6QEKB6UI8<EQZ7H)?3ET:8MI@UF0&:
M_YFNFZN;JINMFSN=/YV+GL^>WI[<GMV>VYX^GTN?XE.55JY6V5C86#A;7E_C
M83-B]&3R9/YD!F7Z9/MD]V2W9=QF)F>S:JQJPVJ[:KAJPFJN:J]J7VMX:Z]K
M"7`+</YO!G#Z;Q%P#W#[<?QQ_G'X<7=S=7.G=+]T%756=EAV4G:]=[]WNW>\
M=PYYKGEA>F)Z8'K$>L5Z*WPG?"I\'GPC?"%\YWQ4?E5^7GY:?F%^4GY9?DA_
M^7_[?W>`=H#-@<^!"H+/A:F%S870A<F%L(6ZA;F%[X?LA_*'X(>&B;*)](DH
MBSF++(LKBU",!8U9CF..9HYDCE^.58[`CDF/38^'D(.0B)"KD:R1T)&4DXJ3
MEI.BD[.3KI.LD["3F).:DY>3U)76E="5U97BEMR6V9;;EMZ6))>CEZ:7K9?Y
METV83YA,F$Z84YBZF#Z9/YD]F2Z9I9D.FL&:`YL&FT^;3IM-F\J;R9O]F\B;
MP)M1G5V=8)W@GA6?+)\S4:56J%;>6-]8XECU6Y"?[%[R8?=A]F'U80!E#V7@
M9MUFY6K=:MIJTVH;<!]P*'`:<!UP%7`8<`9R#7)8<J)R>'-Z<[UTRG3C=(=U
MAG5?=F%VQW<9>;%Y:WII>CY\/WPX?#U\-WQ`?&M^;7YY?FE^:GYS?H5_MG^Y
M?[A_V('IA=V%ZH75A>2%Y87WA?N'!8@-B/F'_H=@B5^)5HE>B4&+7(M8BTF+
M6HM.BT^+1HM9BPB-"HU\CG*.AXYVCFR.>HYTCE2/3H^MCXJ0BY"QD:Z1X9/1
MD]^3PY/(D]R3W9/6D^*3S9/8D^23UY/HD]R5M);CEBJ7)Y=AE]R7^Y=>F%B8
M6YB\F$6929D6FAF:#9OHF^>;UIO;FXF=89URG6J=;)V2GI>>DYZTGOA2MU:V
M5K16O%;D6$!;0UM]6_9;R5WX8?IA&&4491EEYF8G9^QJ/G`P<#)P$')[<\]T
M8G9E=B9Y*GDL>2MYQWKV>DQ\0WQ-?.]\\'RNCWU^?'Z"?DQ_`(#:@6:"^X7Y
MA1&&^H4&A@N&!X8*AA2(%8ADB;J)^(EPBVR+9HMOBU^+:XL/C0V-B8Z!CH6.
M@HZTD<N1&)0#E/V3X94PE\284IE1F:B9*YHPFC>:-9H3G`V<>9ZUGNB>+Y]?
MGV.?89\W43A1P5;`5L)6%%EL7,U=_&'^81UE'&659>EF^VH$:_IJLFM,<!MR
MIW+6=-1T:7;3=U!\CWZ,?KQ_%X8MAAJ&(X@BB"&('XAJB6R)O8ETBW>+?8L3
MC8J.C8Z+CE^/KX^ZD2Z4,Y0UE#J4.)0RE"N4XI4XESF7,I?_EV>899A7F46:
M0YI`FCZ:SYI4FU&;+9PEG*^=M)W"G;B=G9[OGAF?7)]FGV>?/%$[4<A6RE;)
M5G];U%W274Y?_V$D90IK86M1<%AP@'/D=(IU;G9L=K-Y8'Q??'Z`?8#?@7*)
M;XG\B8"+%HT7C9&.DXYACTB11)11E%*4/9<^E\.7P9=KF%6959I-FM*:&IM)
MG#&</IP[G-.=UYTTGVR?:I^4G\Q6UET`8B-E*V4J9>QF$&O:=,IZ9'QC?&5\
MDWZ6?I1^XH$XAC^&,8B*BY"0CY!CE&"49)1HEV^87)E:FEN:5YK3FM2:T9I4
MG%><5ISEG9^>])[15NE8+&5><'%V<G;7=U!_B'\VB#F(8HB3BY*+EHMW@AN-
MP)%JE$*72)=$E\:7<)A?FB*;6)M?G/F=^IU\GGV>!Y]WGW*?\UX6:V-P;'QN
M?#N(P(FACL&1<I1PE'&87IG6FB.;S)YD<-IWFHMWE,F78IIEFIQ^G(NJCL61
M?91^E'R4=YQXG/>>5(Q_E!J>*')JFC&;&YX>GG)\````````````````````
M)`$D`B0#)`0D!20&)`<D""0))`HD"R0,)`TD#B0/)!`D$202)!,D%"05)!8D
M%R08)!DD&B0;)!PD'20>)!\D(20`````````````````````````````````
M````````,`S_`3`",`[_^S`;_QK_'_\!_S#^)B`E(%#^4?Y2_K<`5/Y5_E;^
M5_XQ_A0@,OX3(/W__?_]__W_"/\)_S7^-OY;_UW_-_XX_A0P%3`Y_CK^$#`1
M,#O^//X*,`LP/?X^_@@P"3`__D#^##`-,$'^0OX.,`\P0_Y$_EG^6OY;_ES^
M7?Y>_A@@&2`<(!T@'3`>,#(@-2`#_P;_"O\[(*<``S#+)<\ELR6R)<XE!B8%
M)L<EQB6A):`EO26\):,R!2$^(/W_/__]_TG^2OY-_D[^2_Y,_E_^8/YA_@O_
M#?_7`/<`L0`:(AS_'O\=_V8B9R)@(AXB4B)A(F+^8_YD_F;^9?X\(BDB*B*E
M(B`B'R*_(M(ST3,K(BXB-2(T(D`F0B9!)@DFD2&3(9(AD"&6(9<AF2&8(18@
M7/\/_SS_%2)H_@3_Y?\2,.#_X?\%_R#_`R$)(6G^:OYK_M4SG#.=,YXSSC.A
M,XXSCS/$,[``65%;45Y175%A46-1YU7I=,Y\@26")8,EA"6%)88EAR6()8\E
MCB6-)8PEBR6*)8DE/"4T)2PE)"4<)90E`"4")94E#"40)10E&"5M)6XE<"5O
M)5`E7B5J)6$EXB7C)>4EY"5Q)7(E<R7]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?\0_Q'_$O\3_Q3_%?\6_Q?_
M&/\9_V`A82%B(6,A9"%E(68A9R%H(6DA(3`B,",P)#`E,"8P)S`H,"DP_?]$
M4_W_(?\B_R/_)/\E_R;_)_\H_RG_*O\K_RS_+?\N_R__,/\Q_S+_,_\T_S7_
M-O\W_SC_.?\Z_T'_0O]#_T3_1?]&_T?_2/])_TK_2_],_TW_3O]/_U#_4?]2
M_U/_5/]5_U;_5_]8_UG_6O^1`Y(#DP.4`Y4#E@.7`Y@#F0.:`YL#G`.=`YX#
MGP.@`Z$#HP.D`Z4#I@.G`Z@#J0.Q`[(#LP.T`[4#M@.W`[@#N0.Z`[L#O`.]
M`[X#OP/``\$#PP/$`\4#Q@/'`\@#R0,%,08Q!S$(,0DQ"C$+,0PQ#3$.,0\Q
M$#$1,1(Q$S$4,14Q%C$7,1@Q&3$:,1LQ'#$=,1XQ'S$@,2$Q(C$C,20Q)3$F
M,2<Q*#$I,=D"R0+*`L<"RP+]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M8"1A)&(D8R1D)&4D9B1G)&@D:21T)'4D=B1W)'@D>21Z)'LD?"1])'`A<2%R
M(7,A="%U(78A=R%X(7DA````````````````````````````````0DY<3O51
M&E."4P=.#$Y'3HU.UU9N7'-?#TZ'40Y.+DZ33L).R4[(3IA1_%)L4[E3(%<#
M62Q9$%S_7>%ELVO,:Q1L/W(Q3CQ.Z$[<3NE.X4[=3MI.#%()4AQ33%,B5R-7
M%UDO68%;A%L27#M<=%QS7`1>@%Z"7LE?"6)08A5L-FQ#;#]L.VRN<K!RBG.X
M>8J`'I8.3QA/+$_U3A1/\4X`3_=."$\=3P)/!4\B3Q-/!$_T3A)/L5$34A!2
MIE(B4Q]335.*4P=4X5;?5BY7*E<T5SQ9@%E\6859>UE^67=9?UE66Q5<)5Q\
M7'I<>UQ^7-]==5Z$7@)?&E]T7]5?U%_/7UQB7F)D8F%B9F)B8EEB8&):8F5B
M-V7O9>YE/F<Y9SAG.V<Z9S]G/&<S9QAL1FQ2;%QL3VQ*;%1L2VQ,;'%P7G*T
M<K5RCG,J=7]V=7I1?WB"?(*`@GV"?X)-AGZ)F9"7D)B0FY"4D"*6))8@EB.6
M5D\[3V)/24]33V1//D]G3U)/7T]!3UA/+4\S3S]/84^/4;E1'%(>4B%2K5*N
M4@E38U-R4XY3CU,P5#=4*E145$54&50<5"54&%0]5$]4050H5"141U3N5N=6
MY59!5T573%=)5TM74E<&64!9IEF86:!9EUF.6:)9D%F/6:=9H5F.6Y);*%PJ
M7(U<CUR(7(M<B5R27(I<AER37)5<X%T*7@Y>BUZ)7HQ>B%Z-7@5?'5]X7W9?
MTE_17]!?[5_H7^Y?\U_A7^1?XU_Z7^]?]U_[7P!@]%\Z8H-BC&*.8H]BE&*'
M8G%B>V)Z8G!B@6*(8G=B?6)R8G1B\&7T9?-E\F7U945G1V=99U5G3&=(9UUG
M36=:9TMGT&L9;!IL>&QG;&MLA&R+;(]L<6QO;&ELFFQM;(=LE6R<;&9L<VQE
M;'MLCFQT<'IP8W*_<KURPW+&<L%RNG+%<I5SEW.3<Y1SDG,Z=3EUE'65=8%V
M/7DT@)6`F8"0@)*`G("0@H^"A8*.@I&"DX**@H."A()XC,F/OX^?D*&0I9">
MD*>0H)`PEBB6+Y8MEC-.F$]\3X5/?4^`3X=/=D]T3XE/A$]W3TQ/ET]J3YI/
M>4^!3WA/D$^<3Y1/GD^23X)/E4]K3VY/GE&\4;Y1-5(R4C-21E(Q4KQ2"E,+
M4SQ3DE.44X=4?U2!5)%4@E2(5&M4>E1^5&54;%1T5&94C51O5&%48%285&-4
M9U1D5/=6^59O5W)7;5=K5W%7<%=V5X!7=5=[5W-7=%=B5VA7?5<,6459M5FZ
M6<]9SEFR6<Q9P5FV6;Q9PUG66;%9O5G`6<A9M%G'66);95N36Y5;1%Q'7*Y<
MI%R@7+5<KURH7*Q<GURC7*U<HERJ7*=<G5RE7+9<L%RF7!=>%%X97BA?(E\C
M7R1?5%^"7WY??5_>7^5?+6`F8!E@,F`+8#1@"F`78#-@&F`>8"Q@(F`-8!!@
M+F`38!%@#&`)8!Q@%&(]8JUBM&+18KYBJF*V8LIBKF*S8J]BNV*I8K!BN&(]
M9:AENV4)9OQE!&829@AF^V4#9@MF#68%9OUE$6809O9F"F>%9VQGCF>29W9G
M>V>89X9GA&=T9XUGC&=Z9Y]GD6>99X-G?6>!9WAG>6>49R5K@&M^:]YK'6R3
M;.QLZVSN;-ELMFS4;*ULYVRW;-!LPFRZ;,-LQFSM;/)LTFS=;+1LBFR=;(!L
MWFS`;#!MS6S';+!L^6S/;.ELT6R4<)APA7"3<(9PA'"1<)9P@G":<(-P:G+6
M<LMRV'+)<MQRTG+4<MIRS'+1<J1SH7.M<Z9SHG.@<ZQSG7/==.AT/W5`=3YU
MC'68=:]V\W;Q=O!V]7;X=_QW^7?[=_IW]W=">3]YQ7EX>GMZ^WIU?/U\-8"/
M@*Z`HX"X@+6`K8`@@J""P(*K@IJ"F(*;@K6"IX*N@KR"GH*Z@K2"J(*A@JF"
MPH*D@L."MH*B@G"&;X9MAFZ&5HS2C\N/TX_-C]:/U8_7C[*0M)"OD+.0L)`Y
MECV6/)8ZED.6S4_%3]-/LD_)3\M/P4_43]Q/V4^[3[-/VT_'3]9/ND_`3[E/
M[$]$4DE2P%+"4CU3?%.74Y93F5.84[I4H52M5*54SU3#5`V#MU2N5-94ME3%
M5,94H%1P5+Q4HE2^5')4WE2P5+57GE>?5Z17C%>75YU7FU>45YA7CU>95Z57
MFE>55_18#5E36>%9WEGN60!:\5G=6?I9_5G\6?99Y%GR6?=9VUGI6?-9]5G@
M6?Y9]%GM6:A;3%S07-A<S%S77,M<VUS>7-I<R5S'7,I<UES37-1<SUS(7,9<
MSES?7/A<^5TA7B)>(UX@7B1>L%ZD7J)>FUZC7J5>!U\N7U9?AE\W8#E@5&!R
M8%Y@16!38$=@26!;8$Q@0&!"8%]@)&!$8%A@9F!N8$)B0V+/8@UC"V/U8@YC
M`V/K8OEB#V,,8_AB]F(`8Q-C%&/Z8A5C^V+P8D%E0V6J9;]E-F8A9C)F-68<
M9B9F(F8S9BMF.F8=9C1F.68N9@]G$&?!9_)GR&>Z9]QGNV?X9]AGP&>W9\5G
MZV?D9]]GM6?-9[-G]V?V9^YGXV?"9[EGSF?G9_!GLF?\9\9G[6?,9ZYGYF?;
M9_IGR6?*9\-GZF?+9RAK@FN$:[9KUFO8:^!K(&PA;"AM-&TM;1]M/&T_;1)M
M"FW:;#-M!&T9;3IM&FT1;0!M'6U";0%M&&TW;0-M#VU`;0=M(&TL;0AM(FT)
M;1!MMW"?<+YPL7"P<*%PM'"U<*EP07))<DIR;')P<G-R;G+*<N1RZ'+K<M]R
MZG+F<N-RA7/,<\)SR'/%<[ESMG.U<[1SZW._<\=SOG/#<\9SN'/+<^QT[G0N
M=4=U2'6G=:IU>7;$=@AW`W<$=P5W"G?W=OMV^G;G=^AW!G@1>!)X!7@0>`]X
M#G@)>`-X$WA*>4QY2WE%>41YU7G-><]YUGG.>8!Z?GK1>@![`7MZ?'A\>7Q_
M?(!\@7P#?0A]`7U8?Y%_C7^^?P>`#H`/@!2`-X#8@,>`X(#1@,B`PH#0@,6`
MXX#9@-R`RH#5@,F`SX#7@.:`S8#_@2&"E(+9@OZ"^8('@^B"`(/5@CJ#ZX+6
M@O2"[(+A@O*"]8(,@_N"]H+P@NJ"Y(+@@OJ"\X+M@G>&=(9\AG.&08A.B&>(
M:HAIB-.)!(H'BG*-XX_AC^Z/X(_QD+V0OY#5D,60OI#'D,N0R)#4D=.15)9/
MEE&64Y9*EDZ6'E`%4`=0$U`B4#!0&U#U3_1/,U`W4"Q0]D_W3Q=0'%`@4"=0
M-5`O4#%0#E!:4911DU'*4<11Q5'(4<Y185):4E)27E)?4E528E+-4@Y3GE,F
M5>)4%U425>=4\U3D5!I5_U0$50A5ZU015055\50*5?M4]U3X5.!4#E4#50M5
M`5<"5\Q7,EC55])7NE?&5[U7O%>X5[97OU?'5]!7N5?!5PY92ED96A9:+5HN
M6A5:#UH76@I:'EHS6FQ;IUNM6ZQ;`UQ67%1<[%S_7.Y<\5SW7`!=^5PI7BA>
MJ%ZN7JI>K%XS7S!?9U]=8%I@9V!!8*)@B&"`8))@@6"=8(-@E6";8)=@AV"<
M8(Y@&6)&8O)B$&-68RQC1&-%8S9C0V/D8SEC2V-*8SQC*6-!8S1C6&-48UEC
M+6-'8S-C6F-18SAC5V-`8TAC2F5&9<9EPV7$9<)E2F9?9D=F46829Q-G'V@:
M:$EH,F@S:#MH2VA/:!9H,6@<:#5H*V@M:"]H3FA$:#1H'6@2:!1H)F@H:"YH
M36@Z:"5H(&@L:R]K+6LQ:S1K;6N"@(AKYFOD:^AKXVOB:^=K)6QZ;6-M9&UV
M;0UM86V2;5AM8FUM;6]MD6V-;>]M?VV&;5YM9VU@;9=M<&U\;5]M@FV8;2]M
M:&V+;7YM@&V$;19M@VU[;7UM=6V0;=QPTW#1<-UPRW`Y?^)PUW#2<-YPX'#4
M<,UPQ7#&<,=PVG#.<.%P0G)X<G=R=G(`<_IR]'+^<O9R\W+[<@%STW/9<^5S
MUG.\<^=SXW/I<]QSTG/;<]1SW7/:<]=SV'/H<]YTWW3T=/5T(75;=5]UL'7!
M=;MUQ'7`=;]UMG6Z=8IVR78==QMW$'<3=Q)W(W<1=Q5W&7<:=R)W)W<C>"QX
M(G@U>"]X*'@N>"MX(7@I>#-X*G@Q>%1Y6WE/>5QY4WE2>5%YZWGL>>!Y[GGM
M>>IYW'G>>=UYAGJ)>H5ZBWJ,>HIZAWK8>A![!'L3>P5[#WL(>PI[#GL)>Q)[
MA'R1?(I\C'R(?(U\A7P>?1U]$7T.?1A]%GT3?1]]$GT/?0Q]7']A?UY_8']=
M?UM_EG^2?\-_PG_`?Q:`/H`Y@/J`\H#Y@/6``8'[@`"!`8(O@B6",X,M@T2#
M&8-1@R6#5H,_@T&#)H,<@R*#0H-.@QN#*H,(@SR#38,6@R2#((,W@R^#*8-'
M@T6#3(-3@QZ#+(-+@R>#2(-3AE*&HH:HAI:&C8:1AIZ&AX:7AH:&BX::AH6&
MI8:9AJ&&IX:5AIB&CH:=AI"&E(9#B$2(;8AUB':(<HB`B'&(?XAOB(.(?HAT
MB'R($HI'C%>,>XRDC*.,=HUXC;6-MXVVC=&.TX[^C_6/`I#_C_N/!)#\C_:/
MUI#@D-F0VI#CD-^0Y9#8D-N0UY#<D.204)%.D4^1U9'BD=J17)9?EKR6XYC?
MFB^;?TYP4&I085!>4&!04U!+4%U0<E!(4$U005!;4$I08E`54$507U!I4&M0
M8U!D4$900%!N4'-05U!14-!1:U)M4FQ2;E+64M-2+5.<4W55=E4\54U54%4T
M52I5455B5395-54P55)5154,53)5955.53E52%4M53M50%5+50I7!U?[5Q18
MXE?V5]Q7]%<`6.U7_5<(6/A7"UCS5\]7!UCN5^-7\E?E5^Q7X5<.6/Q7$%CG
M5P%8#%CQ5^E7\%<-6`187%E@6EA:55IG6EY:.%HU6FU:4%I?6F5:;%I36F1:
M5UI#6EU:4EI$6EM:2%J.6CY:35HY6DQ:<%II6D=:45I66D):7%IR6VY;P5O`
M6UE<'ET+71U=&ET@70Q=*%T-729=)5T/73!=$ETC71]=+ET^7C1>L5ZT7KE>
MLEZS7C9?.%^;7Y9?GU^*8)!@AF"^8+!@NF#38-1@SV#D8-E@W6#(8+%@VV"W
M8,I@OV##8,U@P&`R8V5CBF."8WUCO6.>8ZUCG6.78ZMCCF-O8X=CD&-N8Z]C
M=6.<8VUCKF-\8Z1C.V.?8WACA6.!8Y%CC6-P8U-ES65E9F%F6V999EQF8F88
M9WEHAVB0:)QH;6AN:*YHJVA6:6]HHVBL:*EH=6AT:+)HCVAW:))H?&AK:')H
MJFB`:'%H?FB;:)9HBVB@:(EHI&AX:'MHD6B,:(IH?6@V:S-K-VLX:Y%KCVN-
M:XYKC&LJ;,!MJVVT;;-M=&ZL;>EMXFVW;?9MU&T`;LAMX&W?;=9MOFWE;=QM
MW6W;;?1MRFV];>UM\&VZ;=5MPFW/;<EMT&WR;=-M_6W7;<UMXVV[;?IP#7'W
M<!=Q]'`,<?!P!''S<!!Q_'#_<`9Q$W$`<?AP]G`+<0)Q#G%^<GMR?')_<AUS
M%W,'<Q%S&',*<PAS_W(/<QYSB'/V<_AS]7,$=`%T_7,'=`!T^G/\<_]S#'0+
M=/1S"'1D=6-USG72=<]URW7,==%UT'6/=HEVTW8Y=R]W+7<Q=S)W-'<S=SUW
M)7<[=S5W2'A2>$EX37A*>$QX)GA%>%!X9'EG>6EY:GEC>6MY87F[>?IY^'GV
M>?=YCWJ4>I!Z-7L[>S1[)7LP>R)[)'LS>QA[*GL=>S%[*WLM>R][,GLX>QI[
M(WN4?)A\EGRC?#5]/7TX?39].GU%?2Q]*7U!?4=]/GT_?4I].WTH?6-_E7^<
M?YU_FW_*?\M_S7_0?]%_QW_/?\E_'X`>@!N`1X!#@$B`&($E@1F!&X$M@1^!
M+($>@2&!%8$G@1V!(H$1@CB",X(Z@C2",H)T@I"#HX.H@XV#>H-S@Z2#=(./
M@X&#E8.9@W6#E(.I@WV#@X.,@YV#FX.J@XN#?H.E@Z^#B(.7@["#?X.F@X>#
MKH-V@UF&5H:_AK>&PH;!AL6&NH:PALB&N8:SAKB&S(:TAKN&O(;#AKV&OH92
MB(F(E8BHB**(JHB:B)&(H8B?B)B(IXB9B)N(EXBDB*R(C(B3B(Z(@HG6B=F)
MU8DPBB>*+(H>BCF,.XQ<C%V,?8REC'V->XUYC;R-PHVYC;^-P8W8CMZ.W8[<
MCM>.X([ACB20"Y`1D!R0#)`AD.^0ZI#PD/20\I#SD-20ZY#LD.F05I%8D5J1
M4Y%5D>R1])'QD?.1^)'DD?F1ZI'KD?>1Z)'ND7J5AI6(E7R6;99KEG&6;Y:_
MEFJ7!)CEF)>9FU"54)10GE"+4*-0@U",4(Y0G5!H4)Q0DE""4(=07U'441)3
M$5.D4Z=3D56H5:55K55W5456HE6358A5CU6U58%5HU625:15?56,5:95?U65
M5:%5CE4,5RE8-U@96!Y8)U@C6"A8]5=(6"58'%@;6#-8/U@V6"Y8.5@X6"U8
M+%@[6&%9KUJ46I]:>EJB6IY:>%JF6GQ:I5JL6I5:KEHW6H1:BEJ76H-:BUJI
M6GM:?5J,6IQ:CUJ36IU:ZEO-6\M;U%O16\I;SEL,7#!<-UU#76M=05U+73]=
M-5U174Y=55TS73I=4ET]73%=65U"73E=25TX73Q=,ETV74!=15U$7D%>6%^F
M7Z5?JU_)8+E@S&#B8,Y@Q&`48?)@"F$6805A]6`38?A@_&#^8,%@`V$881UA
M$&'_8`1A"V%*8I1CL6.P8\YCY6/H8^]CPV.=9/-CRF/@8_9CU6/R8_5C863?
M8[YCW6/<8\1CV&/38\)CQV/,8\MCR&/P8]=CV6,R96=E:F5D95QE:&5E98QE
MG66>9:YET&7297QF;&9[9H!F<69Y9FIF<F8!9PQITV@$:=QH*FGL:.IH\6@/
M:=9H]VCK:.1H]F@3:1!I\VCA:`=IS&@(:7!IM&@1:>]HQF@4:?AHT&C]:/QH
MZ&@+:0II%VG.:,AHW6C>:.9H]&C1:`9IU&CI:!5I)6G':#EK.VL_:SQKE&N7
M:YEKE6N]:_!K\FOS:S!L_&U&;D=N'VY);HAN/&X];D5N8FXK;C]N06Y=;G-N
M'&XS;DMN0&Y1;CMN`VXN;EYN:&Y<;F%N,6XH;F!N<6YK;CEN(FXP;E-N96XG
M;GAN9&YW;E5N>6Y2;F9N-6XV;EIN('$><2]Q^W`N<3%Q(W$E<2)Q,G$?<2AQ
M.G$;<4MR6G*(<HERAG*%<HMR$G,+<S!S(G,Q<S-S)W,R<RUS)G,C<S5S#',N
M="QT,'0K=!9T&G0A="UT,70D="-T'70I="!T,G3[="]U;W5L=>=UVG7A=>9U
MW77?=>1UUW65=I)VVG9&=T=W1'=-=T5W2G=.=TMW3'?>=^QW8'AD>&5X7'AM
M>'%X:GAN>'!X:7AH>%YX8GAT>7-Y<GEP>0)Z"GH#>@QZ!'J9>N9ZY'I*>T=[
M1'M(>TQ[3GM`>UA[17NB?)Y\J'RA?%A];WUC?5-]5GUG?6I]3WUM?5Q]:WU2
M?51]:7U1?5]]3GT^?S]_97]F?Z)_H'^A?]=_48!/@%"`_H#4@$.!2H%2@4^!
M1X$]@4V!.H'F@>Z!]X'X@?F!!((\@CV"/X)U@CN#SX/Y@R.$P(/H@Q*$YX/D
M@_R#]H,0A,:#R(/K@^.#OX,!A-V#Y8/8@_^#X8/+@\Z#UH/U@\F#"80/A-Z#
M$80&A,*#\X/5@_J#QX/1@^J#$X2:@\.#[(/N@\2#^X/7@^*#&X3;@_Z#V(;B
MAN:&TX;CAMJ&ZH;=ANN&W(;LANF&UX;HAM&&2(A6B%6(NHC7B+F(N(C`B+Z(
MMHB\B+>(O8BRB`&)R8B5B9B)EXG=B=J)VXE.BDV*.8I9BD"*5XI8BD2*18I2
MBDB*48I*BDR*3XI?C(&,@(RZC+Z,L(RYC+6,A(V`C8F-V(W3C<V-QXW6C=R-
MSXW5C=F-R(W7C<6-[X[WCOJ.^8[FCNZ.Y8[UCN>.Z([VCNN.\8[LCO2.Z8XM
MD#20+Y`&D2R1!)'_D/R0")'YD/N0`9$`D0>1!9$#D6&19)%?D6*18)$!D@J2
M)9(#DAJ2)I(/D@R2`)(2DO^1_9$&D@22)Y("DAR2))(9DA>2!9(6DGN5C96,
ME9"5AY9^EHB6B9:#EH"6PI;(EL.6\9;PEFR7<)=NEP>8J9CKF.:<^9Z#3H1.
MMDZ]4+]0QE"N4,10RE"T4,A0PE"P4,%0NE"Q4,M0R5"V4+A0UU%Z4GA2>U)\
M4L-5VU7,5=!5RU7*5=U5P%745<15Z56_5=)5C57/5=55XE765<A5\E7-5=E5
MPE445U-8:%AD6$]835A)6&]855A.6%U865AE6%M8/5AC6'%8_%C'6L1:RUJZ
M6KA:L5JU6K!:OUK(6KM:QEJW6L!:REJT6K9:S5JY6I!:UEO86]E;'UPS7'%=
M8UU*765=<EUL75Y=:%UG76)=\%U/7DY>2EY-7DM>Q5[,7L9>RU['7D!?KU^M
M7_=@26%*82MA16$V83)A+F%&82]A3V$I84!A(&)HD2-B)6(D8L5C\6/K8Q!D
M$F0)9"!D)&0S9$-D'V059!AD.60W9")D(V0,9"9D,&0H9$%D-60O9`ID&F1`
M9"5D)V0+9.=C&V0N9"%D#F1O99)ETV6&9HQFE6:09HMFBF:99I1F>&8@9V9I
M7VDX:4YI8FEQ:3]I16EJ:3EI0FE7:5EI>FE(:4EI-6EL:3-I/6EE:?!H>&DT
M:6EI0&EO:41I=FE8:4%I=&E,:3MI2VDW:5QI3VE1:3)I4FDO:7MI/&E&:T5K
M0VM":TAK06N;:_MK_&OY:_=K^&N;;M9NR&Z/;L!NGVZ3;I1NH&ZQ;KENQF[2
M;KUNP6Z>;LENMVZP;LUNIF[/;K)NOF[#;MQNV&Z9;I)NCFZ-;J1NH6Z_;K-N
MT&[*;I=NKFZC;D=Q5'%2<6-Q8'%!<5UQ8G%R<7AQ:G%A<4)Q6'%#<4MQ<'%?
M<5!Q4W%$<4UQ6G%/<HURC'*1<I!RCG(\<T)S.W,Z<T!S2G-)<T1T2G1+=%)T
M4717=$!T3W10=$YT0G1&=$UT5'3A=/]T_G3]=!UU>75W=8-I[W4/=@-V]W7^
M=?QU^77X=1!V^W7V=>UU]77]=9EVM7;==E5W7W=@=U)W5G=:=VEW9W=4=UEW
M;7?@=X=XFGB4>(]XA'B5>(5XAGBA>(-X>7B9>(!XEGA[>'QY@GE]>7EY$7H8
M>AEZ$GH7>A5Z(GH3>AMZ$'JC>J)ZGGKK>F9[9'MM>W1[:7MR>V5[<WMQ>W![
M87MX>W9[8WNR?+1\KWR(?89]@'V-?7]]A7UZ?8Y]>WV#?7Q]C'V4?81]?7V2
M?6U_:W]G?VA_;'^F?Z5_IW_;?]Q_(8!D@6"!=X%<@6F!6X%B@7*!(6=>@7:!
M9X%O@42!88$=@DF"1()`@D*"18+QA#^$5H1VA'F$CX2-A&6$481`A(:$9X0P
MA$V$?81:A%F$=(1SA%V$!X5>A#>$.H0TA'J$0X1XA#*$180IA-F#2X0OA$*$
M+81?A'"$.81.A$R$4H1OA,6$CH0[A$>$-H0SA&B$?H1$A"N$8(14A&Z$4(0+
MAP2']X8,A_J&UH;UADV'^(8.APF'`8?VA@V'!8?6B,N(S8C.B-Z(VXC:B,R(
MT(B%B9N)WXGEB>2)X8G@B>*)W(GFB7:*AHI_BF&*/XIWBH**A(IUBH.*@8IT
MBGJ*/(Q+C$J,98QDC&:,AHR$C(6,S(QHC6F-D8V,C8Z-CXV-C9.-E(V0C9*-
M\(W@C>R-\8WNC="-Z8WCC>*-YXWRC>N-](T&C_^.`8\`CP6/!X\(CP*/"X]2
MD#^01)!)D#V0$)$-D0^1$9$6D121"Y$.D6Z1;Y%(DE*2,)(ZDF:2,Y)EDEZ2
M@Y(NDDJ21I)MDFR23Y)@DF>2;Y(VDF&2<)(QDE228Y)0DG*23I)3DDR25I(R
MDI^5G)6>E9N5DI:3EI&6EY;.EOJ6_9;XEO66<Y=WEWB7<I</F`V8#IBLF/:8
M^9BOF;*9L)FUF:V:JYI;F^J<[9SGG(">_9[F4-10UU#H4/-0VU#J4-U0Y%#3
M4.Q0\%#O4.-0X%#848!2@5+I4NM2,%.L4R=6%58,5A)6_%4/5AQ6`5835@)6
M^E4=5@16_U7Y58E8?%B06)A8AEB!6']8=%B+6'I8AUB16(Y8=EB"6(A8>UB4
M6(]8_EAK6=Q:[EKE6M5:ZEK:6NU:ZUKS6N):X%K;6NQ:WEK=6ME:Z%K?6G=;
MX%OC6V-<@EV`77U=AEUZ78%==UV*78E=B%U^77Q=C5UY77]=6%Y97E->V%[1
M7M=>SE[<7M5>V5[27M1>1%]#7V]?ME\L82AA06%>87%A<V%285-A<F%L88!A
M=&%487IA6V%E83MA:F%A859A*6(G8BMB*V1-9%MD761T9'9D<F1S9'UD=61F
M9*9D3F2"9%YD7&1+9%-D8&109']D/V1L9&MD661E9'=D<V6@9:%FH&:?9@5G
M!&<B9[%IMFG)::!ISFF6:;!IK&F\:9%IF6F.::=IC6FI:;YIKVF_:<1IO6FD
M:=1IN6G*:9IISVFS:9-IJFFA:9YIV6F7:9!IPFFU::5IQFE*:TUK2VN>:Y]K
MH&O#:\1K_FO.;O5N\6X#;R5O^&XW;_MN+F\);TYO&6\:;R=O&&\[;Q)O[6X*
M;S9O<V_Y;NYN+6]`;S!O/&\U;^MN!V\.;T-O!6_];O9N.6\<;_QN.F\?;PUO
M'F\(;R%OAW&0<8EQ@'&%<8)QCW%[<89Q@7&7<41R4W*7<I5RDW)#<TUS47-,
M<V)T<W1Q='5T<G1G=&YT`'4"=0-U?760=19V"'8,=A5V$78*=A1VN':!=WQW
MA7>"=VYW@'=O=WYW@W>R>*IXM'BM>*AX?GBK>)YXI7B@>*QXHGBD>)AYBGF+
M>99YE7F4>9-YEWF(>9)YD'DK>DIZ,'HO>BAZ)GJH>JMZK'KN>HA[G'N*>Y%[
MD'N6>XU[C'N;>XY[A7N8>X12F7ND>X)[NWR_?+Q\NGRG?;=]PGVC?:I]P7W`
M?<5]G7W.?<1]QGW+?<Q]KWVY?99]O'V??:9]KGVI?:%]R7US?^)_XW_E?]Y_
M)(!=@%R`B8&&@8.!AX&-@8R!BX$5@I>$I(2AA)^$NH3.A,*$K(2NA*N$N82T
MA,&$S82JA)J$L830A)V$IX2[A**$E(3'A,R$FX2IA*^$J(36A)B$MH3/A*"$
MUX34A-*$VX2PA)&$888SAR.'*(=KAT"'+H<>AR&'&8<;AT.'+(=!ASZ'1H<@
MAS*'*H<MASR'$H<ZAS&'-8="AR:')X<XAR2'&H<PAQ&']XCGB/&(\HCZB/Z(
M[HC\B/:(^XCPB.R(ZXB=B:&)GXF>B>F)ZXGHB:N*F8J+BI**CXJ6BCV,:(QI
MC-6,SXS7C):-"8X"CO^-#8[]C0J.`XX'C@:.!8[^C0".!(X0CQ&/#H\-CR.1
M')$@D2*1'Y$=D1J1))$AD1N1>I%RD7F1<Y&EDJ22=I*;DGJ2H)*4DJJ2C9*F
MDIJ2JY)YDI>2?Y*CDNZ2CI*"DI62HI)]DHB2H9**DH:2C)*9DJ>2?I*'DJF2
MG9*+DBV2GI:AEO^66)=]EWJ7?I>#EX"7@I=[EX27@9=_E\Z7S9<6F*V8KI@"
MF0"9!YF=F9R9PYFYF;N9NIG"F;V9QYFQFN.:YYH^FS^;8)MAFU^;\9SRG/6<
MIY[_4`-1,%'X4`91!U'V4/Y0"U$,4?U0"E&+4HQ2\5+O4DA60E9,5C56059*
M5DE61E985EI60%8S5CU6+%8^5CA6*E8Z5AI7JUB=6+%8H%BC6*]8K%BE6*%8
M_UC_6O1:_5KW6O9:`UOX6@);^5H!6P=;!5L/6V=<F5V779]=DEVB79-=E5V@
M79Q=H5V:79Y=:5Y=7F!>7%[S?=M>WE[A7DE?LE^+88-A>6&Q8;!AHF&)89MA
MDV&O8:UAGV&28:IAH6&-869ALV$M8FYD<&269*!DA6279)QDCV2+9(IDC&2C
M9)]D:&2Q9)AD=F5Z97EE>V6R9;-EM6:P9JEFLF:W9JIFKV8`:@9J%VKE:?AI
M%6KQ:>1I(&K_:>QIXFD;:AUJ_FDG:O)I[FD4:O=IYVE`:@AJYFG[:0UJ_&GK
M:0EJ!&H8:B5J#VKV:29J!VKT:19J46NE:Z-KHFNF:P%L`&S_:P)L06\F;WYO
MAV_&;Y)OC6^);XQO8F]/;X5O6F^6;W9O;&^";U5O<F]2;U!O5V^4;Y-O76\`
M;V%O:V]];V=OD&]3;XMO:6]_;Y5O8V]W;VIO>V^R<:]QFW&P<:!QFG&I<;5Q
MG7&E<9YQI'&A<:IQG'&G<;-QF'*:<EAS4G-><U]S8'-=<UMS87-:<UES8G.'
M=(ETBG2&=(%T?72%=(AT?'1Y=`AU!W5^=25V'G89=AUV''8C=AIV*'8;=IQV
MG7:>=IMVC7>/=XEWB'?->+MXSWC,>-%XSGC4>,AXPWC$>,EXFGFA>:!YG'FB
M>9MY=FLY>K)ZM'JS>K=[RWN^>ZQ[SGNO>[E[RGNU>\5\R'S,?,M\]WW;?>I]
MYWW7?>%]`W[Z?>9]]GWQ??!][GW??79_K'^P?ZU_[7_K?^I_['_F?^A_9(!G
M@*.!GX&>@96!HH&9@9>!%H)/@E."4H)0@DZ"48(DA3N%#X4`A2F%#H4)A0V%
M'X4*A2>%'(7[A"N%^H0(A0R%](0JA?*$%87WA.N$\X3\A!*%ZH3IA!:%_H0H
MA1V%+H4"A?V$'H7VA#&%)H7GA.B$\(3OA/F$&(4@A3"%"X49A2^%8H96AV.'
M9(=WA^&'<X=8AU2'6X=2AV&'6H=1AUZ';8=JAU"'3H=?AUV';X=LAWJ';H=<
MAV6'3X=[AW6'8H=GAVF'6H@%B0R)%(D+B1>)&(D9B0:)%HD1B0Z)"8FBB:2)
MHXGMB?")[(G/BL:*N(K3BM&*U(K5BKN*UXJ^BL"*Q8K8BL.*NHJ]BMF*/HQ-
MC(^,Y8S?C-F,Z(S:C-V,YXR@C9R-H8V;C2".(XXECB2.+HX5CAN.%HX1CAF.
M)HXGCA2.$HX8CA..'(X7CAJ.+(\DCQB/&H\@CR./%H\7CW.0<)!OD&>0:Y`O
MD2N1*9$JD3*1)I$ND861AI&*D8&1@I&$D8"1T)+#DL22P)+9DK:2SY+QDM^2
MV)+IDM>2W9+,DN^2PI+HDLJ2R)+.DN:2S9+5DLF2X)+>DN>2T9+3DK62X9(E
MD\:2M))\E:R5JY6NE;"5I):BEM.6!9<(EP*76I>*EXZ7B)?0E\^7'I@=F":8
M*9@HF""8&Y@GF+*8")GZF!&9%)D6F1>9%9G<F<V9SYG3F=29SIG)F=:9V)G+
MF=>9S)FSFNR:ZYKSFO*:\9I&FT.;9YMTFW&;9IMVFW6;<)MHFV2;;)O\G/J<
M_9S_G/><!YT`G?F<^YP(G06=!)V#GM.>#Y\0GQQ1$U$741I1$5'>4313X5-P
M5F!6;E9S5F968U9M5G)67E9W5AQ7&U?(6+U8R5B_6+I8PEB\6,98%UL96QM;
M(5L46Q-;$%L66RA;&EL@6QY;[UNL7;%=J5VG7;5=L%VN7:I=J%VR7:U=KUVT
M76=>:%YF7F]>Z5[G7N9>Z%[E7DM?O%^[7YUAJ&&68<5AM&'&8<%AS&&Z8;]A
MN&&,8==DUF309,]DR62]9(EDPV3;9/-DV60S97]E?&6B9<AFOF;`9LIFRV;/
M9KUFNV:Z9LQF(V<T:F9J26IG:C)J:&H^:EUJ;6IV:EMJ46HH:EIJ.VH_:D%J
M:FID:E!J3VI4:F]J:6I@:CQJ7FI6:E5J36I.:D9J56M4:U9KIVNJ:ZMKR&O'
M:P1L`VP&;*UORV^C;\=OO&_.;\AO7F_$;[UOGF_*;ZAO!'"E;ZYONF^L;ZIO
MSV^_;[AOHF_);ZMOS6^O;[)OL&_%<<)QOW&X<=9QP''!<<MQU''*<<=QSW&]
M<=AQO''&<=IQVW&=<IYR:7-F<V=S;'-E<VMS:G-_=)ITH'24=))TE72A=`MU
M@'4O=BUV,78]=C-V/'8U=C)V,':[=N9VFG>==Z%WG'>;=Z)WHW>5=YEWEW?=
M>.EXY7CJ>-YXXWC;>.%XXGCM>-]XX'BD>41Z2'I'>K9ZN'JU>K%ZMWK>>^-[
MYWO=>]5[Y7O:>^A[^7O4>^I[XGO<>^M[V'O?>])\U'S7?-!\T7P2?B%^%WX,
M?A]^('X3?@Y^''X5?AI^(GX+?@]^%GX-?A1^)7XD?D-_>W]\?WI_L7_O?RJ`
M*8!L@+&!IH&N@;F!M8&K@;"!K(&T@;*!MX&G@?*!58)6@E>"5H5%A6N%3853
MA6&%6(5`A4:%9(5!A6*%1(51A4>%8X4^A5N%<85.A6Z%=855A6>%8(6,A6:%
M7854A66%;(5CAF6&9(:DAYN'CX>7AY.'DH>(AX&'EH>8AWF'AX>CAX6'D(>1
MAYV'A(>4AYR'FH>)AQZ))HDPB2V)+HDGB3&)(HDIB2.)+XDLB1^)\8G@BN**
M\HKTBO6*W8H4B^2*WXKPBLB*WHKABNB*_XKOBON*D8R2C)",]8SNC/&,\(SS
MC&R-;HVEC:>-,XX^CCB.0(Y%CC:./(X]CD&.,(X_CKV.-H\NCS6/,H\YCS>/
M-(]VD'F0>Y"&D/J0,Y$UD3:1DY&0D9&1C9&/D2>3'I,(DQ^3!I,/DWJ3.),\
MDQN3(Y,2DP&31I,MDPZ3#9/+DAV3^I(3D_F2]Y(TDP*3))/_DBF3.9,UDRJ3
M%),,DPN3_I()DP"3^Y(6D[R5S96^E;F5NI6VE;^5M96]E:F6U)8+EQ*7$)>9
MEY>7E)?PE_B7-9@OF#*8))D?F2>9*9F>F>Z9[)GEF>29\)GCF>J9Z9GGF;F:
MOYJTFKN:]IKZFOF:]YHSFX";A9N'FWR;?IM[FX*;DYN2FY";>IN5FWV;B)LE
MG1>=()T>G12=*9T=G1B=(IT0G1F='YV(GH:>AYZNGJV>U9[6GOJ>$I\]GR91
M)5$B4211(%$I4?12DU:,5HU6AE:$5H-6?E:"5G]6@5;66-18SUC26"U;)5LR
M6R-;+%LG6R9;+ULN6WM;\5OR6[==;%YJ7KY?PV&U8;QAYV'@8>5AY&'H8=YA
M[V3I9.-DZV3D9.AD@66`9;9EVF729HUJEFJ!:J5JB6J?:IMJH6J>:H=JDVJ.
M:I5J@VJH:J1JD6I_:J9JFFJ%:HQJDFI;:ZUK"6S,;ZEO]&_4;^-OW&_M;^=O
MYF_>;_)OW6_B;^AOX7'Q<>AQ\G'D<?!QXG%S<VYS;W.7=+)TJW20=*ITK72Q
M=*5TKW00=1%U$G4/=81U0W9(=DEV1W:D=NEVM7>K=[)WMW>V=[1WL7>H=_!W
M\WC]>`)Y^WC\>/]X\G@%>?EX_G@$>:MYJ'E<>EMZ5GI8>E1Z6GJ^>L!ZP7H%
M?`]\\GL`?/][^WL.?/1["WSS>P)\"7P#?`%\^'O]>P9\\'OQ>Q!\"GSH?"U^
M/'Y"?C-^2)@X?BI^27Y`?D=^*7Y,?C!^.WXV?D1^.GY%?W]_?G]]?_1_\G\L
M@+N!Q(',@<J!Q8''@;R!Z8%;@EJ"7(*#A8"%CX6GA96%H(6+A:.%>X6DA9J%
MGH5WA7R%B86AA7J%>(57A8Z%EH6&A8V%F86=A8&%HH6"A8B%A85YA7:%F(60
MA9^%:(:^AZJ'K8?%A["'K(>YA[6'O(>NA\F'PX?"A\R'MX>OA\2'RH>TA[:'
MOX>XA[V'WH>RAS6),XD\B3Z)08E2B3>)0HFMB:^)KHGRB?.)'HL8BQ:+$8L%
MBPN+(HL/BQ*+%8L'BPV+"(L&BQR+$XL:BT^,<(QRC'&,;XR5C)2,^8QOC4Z.
M38Y3CE".3(Y'CD./0(^%D'Z0.)&:D:*1FY&9D9^1H9&=D:"1H9.#DZ^39)-6
MDT>3?)-8DUR3=I-)DU"349-@DVV3CY-,DVJ3>9-7DU634I-/DW&3=Y-[DV&3
M7I-CDV>33I-9D\>5P)7)E<.5Q96WE:Z6L):LEB"7'Y<8EQV7&9>:EZ&7G)>>
MEYV7U9?4E_&709A$F$J829A%F$.8)9DKF2R9*IDSF3*9+YDMF3&9,)F8F:.9
MH9D"FOJ9])GWF?F9^)GVF?N9_9G^F?R9`YJ^FOZ:_9H!F_R:2)N:FZB;GIN;
MFZ:;H9NEFZ2;AINBFZ";KYLSG4&=9YTVG2Z=+YTQG3B=,)U%G4*=0YT^G3>=
M0)T]G?5_+9V*GHF>C9ZPGLB>VI[[GO^>))\CGR*?5)^@GS%1+5$N49A6G%:7
M5II6G5:95G!9/%MI7&I<P%UM7FY>V&'?8>UA[F'Q8>IA\&'K8=9AZ6'_9`1E
M_63X9`%E`V7\9)1EVV7:9MMFV&;%:KEJO6KA:L9JNFJV:K=JQVJT:JUJ7FO)
M:PML!W`,<`UP`7`%<!1P#G#_;P!P^V\F</QO]V\*<`%R_W'Y<0-R_7%V<[AT
MP'2U=,%TOG2V=+MTPG04=1-U7'9D=EEV4'93=E=V6G:F=KUV[';"=[IW#'D3
M>11Y"7D0>1)Y$7FM>:QY7WH<?"E\&7P@?!]\+7P=?"9\*'PB?"5\,'Q<?E!^
M5GYC?EA^8GY??E%^8'Y7?E-^M7^S?_=_^']U@-&!TH'0@5^"7H*TA<:%P(7#
MA<*%LX6UA;V%QX7$A;^%RX7.A<B%Q86QA;:%TH4DAKB%MX6^A6F&YX?FA^*'
MVX?KA^J'Y8??A_.'Y(?4A]R'TX?MA]B'XX?7A]F'`8CTA^B'W8=3B4N)3XE,
MB4:)4(E1B4F)*HLGBR.+,XLPBS6+1XLOBSR+/HLQBR6+-XLFBS:++HLDBSN+
M/8LZBT*,=8R9C)B,EXS^C`2-`HT`C5R.8HY@CE>.5HY>CF6.9XY;CEJ.88Y=
MCFF.5(Y&CT>/2(]+CRB1.I$[D3Z1J)&ED:>1KY&JD;63C).2D[>3FY.=DXF3
MIY..DZJ3GI.FDY63B).9DY^3@).-D[&3D9.RDZ23J).TDZ.3TI73E=&5LY;7
MEMJ6PEW?EMB6W98CER*7)9>LEZZ7J)>KEZ27JI>BEZ67UY?9E]:7V)?ZEU"8
M49A2F+B809D\F3J9#YH+F@F:#9H$FA&:"IH%F@>:!IK`FMR:")L$FP6;*9LU
MFTJ;3)M+F\>;QIO#F[^;P9NUF[B;TYNVF\2;N9N]FUR=4YU/G4J=6YU+G5F=
M5IU,G5>=4IU4G5^=6)U:G8Z>C)[?G@&?`)\6GR6?*Y\JGRF?*)],GU6?-%$U
M4992]U*T4ZM6K5:F5J=6JE:L5MI8W5C;6!)9/5L^6S];PUUP7K]?^V$'91!E
M#64)90QE#F6$9=YEW67>9N=JX&K,:M%JV6K+:M]JW&K0:NMJSVK-:MYJ8&NP
M:PQL&7`G<"!P%G`K<"%P(G`C<"EP%W`D<!QP#'(*<@=R`G(%<J5RIG*D<J-R
MH7++=,5TMW3#=!9U8';)=\IWQ'?Q=QUY&WDA>1QY%WD>>;!Y9WIH>C-\/'PY
M?"Q\.WSL?.I\=GYU?GA^<'YW?F]^>GYR?G1^:'Y+?TI_@W^&?[=__7_^?WB`
MUX'5@0N"9()A@F."ZX7QA>V%V87AA>B%VH77A>R%\H7XA=B%WX7CA=R%T87P
MA>:%[X7>A>*%`(CZAP.(]H?WAPF(#(@+B`:(_(<(B/^'"H@"B&*)6HE;B5>)
M88E<B5B)78E9B8B)MXFVB?:)4(M(BTJ+0(M3BU:+5(M+BU6+48M"BU*+5XM#
MC'>,=HR:C`:-!XT)C:R-JHVMC:N-;8YXCG..:HYOCGN.PHY2CU&/3X]0CU./
MM(]`D3^1L)&MD=Z3QY//D\*3VI/0D_F3[)/,D]F3J9/FD\J3U)/ND^.3U9/$
MD\Z3P)/2DZ63YY-]E=J5VY7AEBF7*Y<LERB7)I>SE[>7MI?=E]Z7WY=<F%F8
M79A7F+^8O9B[F+Z82)E'F4.9IIFGF1J:%9HEFAV:))H;FB*:()HGFB.:'IH<
MFA2:PIH+FPJ;#IL,FS>;ZIOKF^";WIODF^:;XIOPF]2;UYOLF]R;V9OEF]6;
MX9O:FW>=@9V*G82=B)UQG8"=>)V&G8N=C)U]G6N==)UUG7"=:9V%G7.=>YV"
MG6^=>9U_G8>=:)V4GI&>P)[\GBV?0)]!GTV?5I]7GUB?-U.R5K56LU;C6$5;
MQEW'7>Y>[U[`7\%?^6$7919E%6439=]EZ&;C9N1F\VKP:NIJZ&KY:O%J[FKO
M:CQP-7`O<#=P-'`Q<$)P.'`_<#IP.7`J<$!P.W`S<$%P$W(4<JAR?7-\<[IT
MJW:J=KYV[7;,=\YWSW?-=_)W)7DC>2=Y*'DD>2EYLGEN>FQZ;7KW>DE\2'Q*
M?$=\17SN?'M^?GZ!?H!^NG__?WF`VX'9@6B":8(BAO^%`8;^A1N&`(;VA02&
M"88%A@R&_849B!"($8@7B!.(%HACB6:)N8GWB6"+:HM=BVB+8XMEBV>+;8NN
MC8:.B(Z$CEF/5H]7CU6/6(]:CXV00Y%!D;>1M9&RD;.1"Y03E/N3()0/E!24
M_I,5E!"4*)09E`V4]9,`E/>3!Y0.E!:4$I3ZDPF4^),\E`J4_Y/\DPR4]I,1
ME`:4WI7@E=^5+I<OE[F7NY?]E_Z78)ABF&.87YC!F,*84)E.F5F93)E+F5.9
M,IHTFC&:+)HJFC::*9HNFCB:+9K'FLJ:QIH0FQ*;$9L+G`B<]YL%G!*<^)M`
MG`><#IP&G!><%)P)G)^=F9VDG9V=DIV8G9"=FYV@G92=G)VJG9>=H9V:G:*=
MJ)V>G:.=OYVIG9:=IIVGG9F>FYZ:GN6>Y)[GGN:>,)\NGUN?8)]>GUV?69^1
MGSI1.5&84I=2PU:]5KY62%M'6\M=SUWQ7OUA&V4":_QJ`VOX:@!K0W!$<$IP
M2'!)<$5P1G`=<AIR&7)^<Q=U:G;0=RUY,7DO>51\4WSR?(I^AWZ(?HM^AGZ-
M?DU_NW\P@-V!&(8JAB:&'X8CAAR&&88GABZ&(88@ABF&'H8EABF('8@;B""(
M)(@<B"N(2HAMB6F);HEKB?J)>8MXBT6+>HM[BQ"-%(VOC8Z.C(Y>CUN/78]&
MD42119&YD3^4.Y0VE"F4/90PE#F4*I0WE"R40)0QE.65Y)7CE367.I>_E^&7
M9)C)F,:8P)A8F5:9.9H]FD::1)I"FD&:.IH_FLV:%9L7FQB;%ILZFU*;*YP=
MG!R<+)PCG"B<*9PDG"&<MYVVG;R=P9W'G<J=SYV^G<6=PYV[G;6=SIVYG;J=
MK)W(G;&=K9W,G;.=S9VRG7J>G)[KGNZ>[9X;GQB?&I\QGTZ?99]DGY*?N4[&
M5L56RU9Q64M;3%O57=%=\EXA92!E)F4B90MK"&L):PUL57!6<%=P4G`><A]R
MJ7)_<]ATU739=-=T;7:M=C5YM'EP>G%Z5WQ<?%E\6WQ:?/1\\7R1?D]_AW_>
M@6N"-(8UAC.&+(8RAC:&+(@HB":(*H@EB'&)OXF^B?N)?HN$BX*+AHN%BW^+
M%8V5CI2.FHZ2CI".EHZ7CF"/8H]'D4R44)1*E$N43Y1'E$642)1)E$:4/Y?C
MEVJ8:9C+F%296YE.FE.:5)I,FD^:2)I*FDF:4II0FM":&9LKFSN;5IM5FT:<
M2)P_G$2<.9PSG$&</)PWG#2<,IP]G#:<VYW2G=Z=VIW+G="=W)W1G=^=Z9W9
MG=B=UIWUG=6=W9VVGO">-9\SGS*?0I]KGY6?HI\]49E2Z%CG6')935O872^(
M3U\!8@-B!&(I925EEF7K9A%K$FL/:\IK6W!:<")R@G.!<X-S<';4=V=\9GR5
M?FR".H9`ACF&/(8QACN&/H8PB#*(+H@SB':)=(ESB?Z)C(N.BXN+B(M%C!F-
MF(YDCV./O)%BE%647917E%Z4Q)?%EP"85II9FAZ;'YL@FU*<6)Q0G$J<39Q+
MG%6<69Q,G$Z<^YWWG>^=XYWKG?B=Y)WVG>&=[IWFG?*=\)WBG>R=])WSG>B=
M[9W"GM">\I[SG@:?')\XGS>?-I]#GT^?<9]PGVZ?;Y_35LU63EMM7"UE[6;N
M9A-K7W!A<%UP8'`C<MMTY735=SAYMWFV>6I\EWZ)?VV"0X8XB#>(-8A+B)2+
ME8N>CI^.H(Z=CKZ1O9'"D6N4:)1IE.661I=#ET>7QY?EEUZ:U9I9FV.<9YQF
MG&*<7IQ@G`*>_IT'G@.>!IX%G@">`9X)GO^=_9T$GJ">'I]&GW2?=9]VG]16
M+F6X91AK&6L7:QIK8G`F<JIRV'?9=SEY:7QK?/9\FGZ8?IM^F7[@@>&!1H9'
MADB&>8EZB7R)>XG_B9B+F8NECJ2.HXYNE&V4;Y1QE'.429=RF%^9:)QNG&V<
M"YX-GA">#YX2GA&>H9[UG@F?1Y]XGWN?>I]YGQY79G!O?#R(LHVFCL.1=)1X
ME':4=91@FBZ;=)QSG'&<=9P4GA.>]IX*GZ2?:'!E</=\:H8^B#V(/XB>BYR,
MJ8[)CDN7<YATF,R889FKF62:9IIGFB2;%9X7GDB?!V(>:R=R3(:HCH*4@)2!
ME&F::)H9GDN&GXN#E'F<MYYU=FN:>IP=GFEP:G`I<J2>?I])GYB?````_J0`
M`````````````````````````````,SL`-X``````-(`````````````````
M````````````````\@``````````````````````````````````````J:JK
MK*VNK["QLK,`M;:W`+FZN[R]OK_`P<(`Q,7&Q\C)RLL`S<[/`-$`T]0`UM?8
MV=K;W```W^#AX@#DY>;GZ.GJZP#M[N\`\0#S]`#V]_CY^OO\``#_``##XP``
M`````````````-#P````````````````````````````````````````````
M`````````````````````````````````````````+BH````````````````
M````````````````````````````````M```````````````````````````
M`````````````````````````-7U`````````````````-W]````````````
M``````````````````"@`*$`H@"C`*0`I0"F`*<`4P&I`*H`JP"L`*T`K@"O
M`+``L0"R`+,`>`&U`+8`MP!2`;D`N@"[`+P`O0"^`+\`P`#!`,(``@'$`,4`
MQ@#'`,@`R0#*`,L```/-`,X`SP`0`=$`"0/3`-0`H`'6`-<`V`#9`-H`VP#<
M`*\!`P/?`.``X0#B``,!Y`#E`.8`YP#H`.D`Z@#K``$#[0#N`.\`$0'Q`",#
M\P#T`*$!]@#W`/@`^0#Z`/L`_`"P`:L@_P````"6EP```)&2``"3E`````"5
M````A0````````````"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_
MP,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:`````-_@X>+CY.7FY^CIZNOL
M[>[O\/'R\_3U]O?X^?K[`````*P@_?_]__W__?\F(/W__?_]__W__?_]__W_
M_?_]__W__?\8(!D@'"`=("(@$R`4(/W__?_]__W__?_]__W__?^@``$.`@X#
M#@0.!0X&#@<."`X)#@H."PX,#@T.#@X/#A`.$0X2#A,.%`X5#A8.%PX8#AD.
M&@X;#AP.'0X>#A\.(`XA#B(.(PXD#B4.)@XG#B@.*0XJ#BL.+`XM#BX.+PXP
M#C$.,@XS#C0.-0XV#C<..`XY#CH._?_]__W__?\_#D`.00Y"#D,.1`Y%#D8.
M1PY(#DD.2@Y+#DP.30Y.#D\.4`Y1#E(.4PY4#E4.5@Y7#E@.60Y:#EL._?_]
M__W__?__`/P```#^``````#]`````````````````````````$@.`0X"#@,.
M!`X%#@8.!PX(#@D."@X+#@P.#0X.#@\.$`X1#A(.$PX4#A4.%@X7#A@.&0X:
M#AL.'`X=#AX.'PX@#B$.(@XC#B0.)0XF#B<.*`XI#BH.*PXL#BT.+@XO#C`.
M,0XR#C,.-`XU#C8.-PXX#CD..@Y)#DH.2PZL(#\.0`Y!#D(.0PY$#D4.1@Y'
M#D@.20Y*#DL.3`Y-#DX.3PY0#E$.4@Y3#E0.50Y6#E<.6`Y9#EH.6PZB`*P`
MI@"@``"AH@"DI::GJ*FJJZP`KJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(
MR<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O`/'R`/3U
M]O?X^?K[_`#^_P``````````````````````````````````````````````
M`````````````````*/S````````H````````/T``````*T`````````````
M`````````````````````*```00"!)`$!`0%!`8$!P0(!`D$"@0+!`P$K0`.
M!`\$$`01!!($$P04!!4$%@07!!@$&00:!!L$'`0=!!X$'P0@!"$$(@0C!"0$
M)00F!"<$*`0I!"H$*P0L!"T$+@0O!#`$,00R!#,$-`0U!#8$-P0X!#D$.@0[
M!#P$/00^!#\$0`1!!$($0P1$!$4$1@1'!$@$201*!$L$3`1-!$X$3P06(5$$
M4@21!%0$5016!%<$6`19!%H$6P1<!*<`7@1?!`"'``````"4`)``D0"2`),`
M`-P`W0```(``E:8``-X``*<``````*@```"I````J@```*L```"N````````
M``````"O````N@```+P```"]`````````-@``+[`VP"9FIL``-\```#S````
M]````/4```#[````_`#^``#]````E@"8EP#WG/B=^9[ZGP````````"%A(.&
MHZ*AI?8```"+`(H```````````"-````C````(X```"/``````````````"L
M``````````````````"[````OP#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76UP#9
MV@``````X.'BX^3EYN?HZ>KK[.WN[_#Q\@````````````````"PL;*SM+6V
MM[BY````````````````````````````````````````B```````````````
M````````````````H````*0``````````*T`````````````````````````
M`````````````````````````````($`````````````````````````````
M````````````@@````````````````````"(_M<`]P#V^/7X]/CW^''^B`"@
M)0(E`"40)0PE%"48)7G^>_Y]_G_^=_Z*_O#^\_[R_L[^S_[0_O;^^/[Z_OS^
MH`#Z^/GX^/BD`/OXB_Z1_I?^F_Z?_J/^#`:M`*?^L_Y@!F$&8@9C!F0&909F
M!F<&:`9I!K?^&P:[_K_^ROX?!LO^(08B!B,&)`8E!B8&)P8H!BD&*@8K!BP&
M+08N!B\&,`8Q!C(&,P8T!C4&-@8W!L?^.08Z!LS^@OZ$_H[^T_Y`!D$&0@9#
M!D0&109&!D<&2`9)!DH&2P9,!DT&3@9/!E`&4092!M?^V_[?_OSX]?[W_OG^
M^_[C_N?^[/[I_OW_T/````````````````````````````````````#>_@"H
MJ:JKK*VN`+"QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/`-'2T]35
MUM?8V=K;W-T`W^#AXN/DY>;GZ.GJZ^SM[N\`\?+S]/7V]_CY^OO\_0#_````
M``````!A`?$`\@#S`/0`]0#V`/<`^`#Y`/H`^P#\`/T`?@'_`&`!T0#2`-,`
MU`#5`-8`UP#8`-D`V@#;`-P`W0!]`=\`H`"A`*(`HP"D`*4`I@"G`*@`J0"J
M`*L`K`"M`*X`/B#$`+,```````````#:````OP```,````#9````PP``````
M``"T`````````,(`````````P0````````#%````````````````````````
M`,VZ``#)``"[``#(``"\``#,``"Y``#+``#*``#.````````````````````
M`````-\```#<````VP``````````L+&R````````````````_@``````````
M``````````````````````````````"`@8*#A(6&AXB)BHN,C8Z/D)&2DY25
MEI>8F9H``````/\`O9S/OMWU^;@`KJKPJ>[X\?W\[^;T^O?[`*^LJ_,`````
M``````````````````````````">````````````````````````````````
M`````````/8``````````-`%T072!=,%U`75!=8%UP78!=D%V@7;!=P%W07>
M!=\%X`7A!>(%XP7D!>4%Y@7G!>@%Z07J!?W_HP#]_]<`_?_]__W__?_]__W_
M_?_]__W__?^N`*P`O0"\`/W_JP"[`)$EDB63)0(E)"7]__W__?^I`&,E4257
M)5TEH@"E`!`E%"4T)2PE'"4`)3PE_?_]_UHE5"5I)68E8"50)6PEI`#]__W_
M_?_]__W__?_]__W__?\8)0PEB"6$):8`_?^`)?W__?_]__W__?_]_[4`_?_]
M__W__?_]__W__?^O`+0`K0"Q`!<@O@"V`*<`]P"X`+``J`"W`+D`LP"R`*`E
MH`#]_?W]`_T%!OW]"@L,#0X/$/W]_13]_?W]_?W]_?W]_?\``0(#!`4&!P@)
M"@L,#0X/$/\1$A,4%187&!D:&_____\``0(#!`7__P8'"`D*"___#`T.#Q`1
M__\2$Q05____``$"`P0%!@<("0H+#`T.#Q`1$A/______________P`!`@,$
M!08'"`D*"PP-#@\0$1(3%!46%Q@9("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W
M.#E`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ
M:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+``$"`P0%!@<("0H+
M#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#%T=79W>'EZ
M>WQ]?G^`@8*#A(6&AXB)BHN,C925EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRM
MM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,T``0(#!`4&!P@)"@L,#0X/$!$2
M$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_
M0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@86)CIJ>HJ:JKK*VN
MK["QLK.TM;:WN+FZN[R]OK_&QP`!`@,$!08'"`D*"PP-#@\0$1(3%!46%QX?
M("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,
M34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY
M>GM\?7Y_@(&"@X2%``$"`P0%!@<("0H+#`T.#Q`1$A,4%5A96EM<75Y?8&%B
M8V1E9F=H:6IK;&UN;W!Q>'EZ>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&8F9J;
MG)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(
MR<K+S,T``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G
M*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D>*BXR-CH^0D9*3E)66
MEYB9FIN<G9Z?H*&BHZJKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#RLO,S0`!
M`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN
M+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;
M7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAYO+V^O\#!``$"`P0%!@<(
M"0H+#`T.#Q`1$A,:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,SH[/#T^/T!!
M0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN
M;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#A(6&AXB)BHL``0(#!`4&!P@)"@L,#0X/
M$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*VYO<'%R<W1U=G=X>7I[?'U^
M?X"!@H.$A8:'CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>NK["QLK.TM;:W
MN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S0`!`@,$!08'"`D*"PP-#@\0$1(3%!46
M%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#
M1$5&1TA)2DM,34Y/4%%24U155E=865I;7%V@H:*CI*6FIZBIJJNLK:ZOL+&R
ML[2UMK>XN<#!PL/$Q<;'``$"`P0%!@<("0H+#`T.#Q`1&!D:&QP='A\@(2(C
M)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]0
M45)35%565UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]
M?G^`@8*#A(4``0(#!`4&!P@)"@L,#0X/4E-455976%E:6UQ=7E]@86)C9&5F
M9VAI:FMR<W1U=G=X>7I[?'U^?X"!@H.$A8:'B(F*BY*3E)66EYB9FIN<G9Z?
MH*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,
MS0`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK
M+"TN+S`Q,C,T-38W.#DZ.SP]/C]`082%AH>(B8J+C(V.CY"1DI.4E9:7F)F:
MFYR=I*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+W$Q<;'R,G*R\S-``$"`P0%
M!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R
M,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?
M8&%B8V1E9F=H:6IK;&UN;W!Q<G.VM[BYNKN\O;Z_P,$``0(#!`4&!P@)"@L,
M#105%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM-#4V-S@Y.CL\/3X_0$%"0T1%
M1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R
M<W1U=G=X>7I[?'U^?X"!@H.$A8:'B(F*BP`!`@,$!08'"`D*"PP-#@\0$1(3
M%!46%Q@9&AL<'1X?("$B(R0E:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&(
MB8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:BIJJNLK:ZOL+&RL[2UMK>XN;J[
MO+V^O\#!PL/$Q<;'R,G*R\S-``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:
M&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'
M2$E*2TQ-3D]045)35%565YJ;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SNKN\
MO;Z_P,'"P\3%QL<``0(#!`4&!P@)"@L2$Q05%A<8&1H;'!T>'R`A(B,D)28G
M*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-4
M55976%E:6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'U^?X"!
M@H.$A0`!`@,$!08'"`E,34Y/4%%24U155E=865I;7%U>7V!A8F-D96QM;F]P
M<7)S='5V=WAY>GM\?7Y_@(&"@X2%C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*C
MI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-``$"
M`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO
M,#$R,S0U-C<X.3H[?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>>GZ"AHJ.D
MI::GJ*FJJZRMKJ^PL;*SM+6VM[Z_P,'"P\3%QL?(R<K+S,T``0(#!`4&!P@)
M"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V
M-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@86)C
M9&5F9VAI:FML;;"QLK.TM;:WN+FZN[R]OK_`P0`!`@,$!08'#@\0$1(3%!46
M%Q@9&AL<'1X?("$B(R0E)B<N+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)
M2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V
M=WAY>GM\?7Y_@(&"@X2%AH>(B8J+``$"`P0%!@<("0H+#`T.#Q`1$A,4%187
M&!D:&QP='A]B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>X*#A(6&AXB)BHN,
MC8Z/D)&2DY25EI>8F9J;HJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_
MP,'"P\3%QL?(R<K+S,T``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>
M'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+
M3$U.3U!1E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VTM;:WN+FZN[R]OK_`
MP<+#Q,7&QP`!`@,$!0P-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK
M+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=8
M65I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%
M``$"`T9'2$E*2TQ-3D]045)35%565UA96EM<75Y?9F=H:6IK;&UN;W!Q<G-T
M=79W>'EZ>WQ]?G^&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::G
MJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,T``0(#!`4&
M!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S
M-#5X>7I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9B9FIN<G9Z?H*&BHZ2EIJ>H
MJ:JKK*VNK["QN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S0`!`@,$!08'"`D*"PP-
M#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ
M.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D969G
MJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!``$("0H+#`T.#Q`1$A,4%187&!D:
M&QP='A\@(2@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-
M3D]045)35%565UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ
M>WQ]?G^`@8*#A(6&AXB)BHL``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&5Q=
M7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U?'U^?X"!@H.$A8:'B(F*BXR-CH^0
MD9*3E)6<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#
MQ,7&Q\C)RLO,S0`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B
M(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DN.CY"1
MDI.4E9:7F)F:FYR=GI^@H:*CI*6FIZZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$
MQ<;'``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I
M*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%56
M5UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]P,$``0(#
M!`4&!P@)"@L,#0X/$!$2$Q05%A<>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V
M-SX_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@86)C9&5F9VAI
M:FML;6YO<'%R<W1U=G=X>7I[?'U^?X"!@H.$A8:'B(F*BP`!`@,$!08'"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+W)S='5V=WAY
M>GM\?7Y_@(&"@X2%AH>(B8J+DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNR
ML[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-``$"`P0%!@<("0H+#`T.#Q`1
M$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^
M/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8&&DI::GJ*FJJZRM
MKJ^PL;*SM+6VM[BYNKN\O<3%QL<``0(#!`4&!P@)"@L,#0X/$!$2$Q05'!T>
M'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+
M3$U.3U!14E-455976%E:6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X
M>7I[?'U^?X"!@H.$A0`!`@,$!08'"`D*"PP-#@\0$1(35E=865I;7%U>7V!A
M8F-D969G:&EJ:VQM;F]V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY:7F)F:
MFYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'
MR,G*R\S-``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F
M)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$18B)BHN,C8Z/D)&2DY25
MEI>8F9J;G)V>GZ"AJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'(R<K+S,T`
M`0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM
M+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:
M6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G>ZN[R]OK_`P0`!`@,$!08'
M"`D*"PP-#@\0$1@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q.#DZ.SP]/C]`
M04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ:VQM
M;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+``$"`P0%!@<("0H+#`T.
M#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I;&UN;W!Q<G-T=79W>'EZ>WQ]
M?G^`@8*#A(6,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI:RMKJ^PL;*SM+6V
MM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,T``0(#!`4&!P@)"@L,#0X/$!$2$Q05
M%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"
M0T1%1D=(24I+3$U.3U!14E-455976%E:6YZ?H*&BHZ2EIJ>HJ:JKK*VNK["Q
MLK.TM;:WOK_`P<+#Q,7&QP`!`@,$!08'"`D*"PP-#@\6%Q@9&AL<'1X?("$B
M(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/
M4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\
M?7Y_@(&"@X2%``$"`P0%!@<("0H+#`U045)35%565UA96EM<75Y?8&%B8V1E
M9F=H:7!Q<G-T=79W>'EZ>WQ]?G^`@8*#A(6&AXB)D)&2DY25EI>8F9J;G)V>
MGZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+
MS,T``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ
M*RPM+B\P,3(S-#4V-S@Y.CL\/3X_08'-@9N"8X/I@[>$A85'AM.&H8=IB.^(
MO8F+BDV+V8NGC&^-]8W#CI&/4Y#?D*V1=9+[DLF3EY19E>65LY:!ET.8SYB=
MF66:ZYJYFX><29W5G:.>:Y_QG[^@``````````!L^`D``,$,`.Y/%P#\["(`
M_M<O`._N/`#__TP`;/I6`(3A7`#N3V<`_&AP`/[$>@#M[H8`7_^4`&QJG`"4
MSZ4`KD^O`/WNO`#^S<@`S^[4`$_]X`#N_NT`]<_Y`(9'``'Y[`L!_L\8`>__
M)P%__S8![/Y"`?3O3@'N_UP!_VQH`?S4<@'O_X$!__^1`6SZFP&4BZ(!KD^L
M`=SLM@'^Q,`!S^_-`?__W0'__^T!_X_Z`>Y/!0+\[!`"_]8=`N_N*@)_WC<"
M_O]&`O_/5`+J3UX"\?QI`O[/=@+/_X0"__V3`N[^H`+<[ZP"__^\`O_LR0)^
ME-("[^_@`O_\[@+L_OH"[.\&`^[/$@/__B$#__\Q`\^J.P-'W44#__]5`__/
M8P/N3VX#_6AX`_@$?@/%[H@#3_R3`^S^GP/>_ZT#__^]`__DR0/RQ-$#Q^[<
M`T_\YP/L_O,#S.[]`_[_#`3_[!D$^M0C!./N+@3__CT$__]-!/_O7`3N3V<$
M_^QT!/[5@`3/YHL$3_V7!/[_I@3O[[0$___$!/_NT@3^_-\$S^_L!,_]^03L
M^`,%E.L,!>[_&@7_["<%^M0Q!8L&-P5'<#X%[/Y*!<3O5`7__V0%__]T!?__
MA`6/)HP%3[66!>S^H@7$[ZP%[O^Z!?SNQ@7__]8%SZ;@!4[5Z07N_O8%_^\%
M!O__%0;^[B(&_O0N!N__/0;__TT&[/Y9!M3O9`;__W0&_OZ"!O_?D0;O[IX&
M7_VK!N[^N`;>S\0&ID_-!OW^VP;__^L&S^;V!D_X``?L_@P'Q,<4!^Y/'P?\
M_RT'__\]!___30?__UT'[/)G!\3';P?N3WH'_/Z'!__OE@?__Z8'__^V!^S^
MP@??[]`'[__?!__^[@?___X'[_X,"/__'`C__RP(_\\Z".[G1@C]_U4(__]E
M".__=`C__X0([OZ1"-S_G@C__ZX(_VRZ"/[TQ@CO[M,(S__A".[^[@C4S_@(
M[D\#"3CL"PG^Q!4)S_XB"7_],`G__T`)_\].">Y/60E\[&,)_M1N"<_N>@E/
M_(4)[O^3"?7/GPGN3ZH)_>ZW"?_?Q@G__]8)__[E">[^\@G4[_T)[E\)"OWL
M%0K^U"`*[_\O"O_^/@K^_TT*_\];"NYO9PK][',*_M1^"L_NB@I/F9,*__^C
M"O_/L0KN3[P*_2S&"OB4S@K%[M@*3_CB"OS^[PK?__X*__\."__L&POZE"0+
MQ^XO"T_\.@OL_D8+1^]1"___80O_Y&T+^M1W"^_^A0O__),+__^C"__OL@ON
M7[X+_>[+"_[UV`N/AN`+3UWJ"^[^]POU[P0,__\4#/_N(@S^_S$,[^X^#&__
M3`SN_ED,]O]G#/__=PS_;(,,^D2+#`T&D`Q/W9L,[/ZG#,3-KPS^W[T,___-
M#/__W0S/IN<,3_GR#&S^_0S$SP8-[E\2#=SN'0W__RT-C^XX#4_]1`WN_U(-
M[^]@#?__<`W^['P-_OR)#>_^EPW__Z<-;/BP#=3IN0WO_\@-_O[6#?__Y@W/
M[O(-__T!#N[^#@[6SQD.[D\D#O__-`[__T0.SZY/#D_Q60[L^F0.Q,=L#NY/
M=P[\_(,.__Z2#O__H@[__[(.;/Z]#L;OR`[__]@._?SE#O_$\`[__P`/__\0
M#^S^'`_<_RD/__\Y#___20___UD/[_]H#___>`_^_X</W\^4#^YOH`_]_Z\/
M__^_#___SP___]\/___O#__O_@___PX0_>X;$/[\*!#__S@0__]($.S^5!#4
M3UT0AD]E$-SL;Q#^Q'D0S^Z%$$_]D1#N_IX0W@^H$"9/L!"\[+H0_L3$$,_N
MT!!/_-L0[O[H$-^/]!"N3_X0W>P)$?[?%Q'O[B01;_XQ$>[^/A'TSTD1[D]4
M$?UL7Q'^5&D1Z?]V$?_^A1'L_I$1WL^=$>Y/J!']_+41_M;!$<_.S!%/_=@1
M___H$?_/]A'F1_\1O>0)$O[,%!+'[A\2S_PK$O__.Q+?_TH2__]:$O_L9Q+Z
MS'$2[^Y^$O__CA+__YX2__^N$O[_O1+_;,D2^MS4$L_^X1+__O`2_O__$N_O
M#1/NSQD3__XH$___.!//[D03S_U1$_[_8!/O[VX3__]^$__NC!/__YP3__^L
M$__]NQ/L>L43_._2$^[OWQ/_[.P3_M3W$\^(_Q-'G`<4[/X3%,3/'!1N3R84
M7>XQ%/[]/Q3/A$<4#ZA.%.S^6A34CV,4+@]K%!SN=!3^Y'\4SXZ)%$;UDA3L
M_IX4Q,^G%/YOM!3][,`4_M3+%,_NUQ1/_>,4[/CM%-3/]Q3NSP,5_.P.%?[<
M&A7/[B853_TR%>S^/A54ST<5[DM1%0'N6!7^]F45SXYO%4>X=Q4L^H`5A,^(
M%>Y/DQ7\K)T5_MZJ%>_NMQ7__\<5[/K2%93/VQ7N3^85_>[S%?[,_A7O_PT6
M__\=%NSZ*!84QR\6[U\\%AT``````````````````````````````0(#!`4&
M!P@)"@L,#0X/$!$2$Q05%A<8&2`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y
M0$%"0T1%1D=(24I+``$"`P0%!@<("0H+#`T.#Q`1$A.TM;:WN+FZN[R]OK_`
MP<+#Q,7&Q\C)RLO,S=35UM?8V=K;W-W>W^#AXN/DY0`!`@,$!08'#@\0$1(3
M%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"W.S]#1TM/4U=;7V-G:V]S=WM_@
MX>+CY.4``0@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A*"DJ*RPM+B\P,3(S
M-#4V-S@Y.CL\/3X_0$%"0T1%1D?HZ>KK``$"`P0%!@<("0H+#`T.#Q`1$A,4
M%1P='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U/#T^/T!!0D-$149'2$E*2P`!
M`@,$!08'"`D*"PP-#@^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R=#1TM/4
MU=;7V-G:V]S=WM_@X>+CY.4``0(#"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A
M(B,D)28G*"G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^KK``$"`P0%!@<(
M"0H+#`T.#Q`1$A,4%187'A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[
M/#W>W^#AXN/DY0`!`@,$!08'"`D*"PP-#@\0$1@9&AL<'1X?("$B(R0E)B<H
M*2HK+"TN+S`Q.#DZ.SP]/C]`04)#1$5&1TA)2DL``0(#!`4&!P@)"@NLK:ZO
ML+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<S-SL_0T=+3U-76U]C9VMO<W=[?X.'B
MX^3E``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A_`P<+#Q,7&Q\C)
MRLO,S<[/T-'2T]35UM?8V>#AXN/DY0`!`@,$!08'"`D*"PP-#@\0$1(3&AL<
M'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#G:V]S=WM_@X>+CY.4``0(#
M!`4&!P@)"@L,#105%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM-#4V-S@Y.CL\
M/3X_0$%"0T1%1D=(24I+``$"`P0%!@>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]
MOK_`P<C)RLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AZ.GJZP`!`@,$!08'"`D*
M"PP-#@\0$1(3%!46%Q@9&AN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=S=
MWM_@X>+CY.4``0(#!`4&!P@)"@L,#0X/%A<8&1H;'!T>'R`A(B,D)28G*"DJ
M*RPM+B\P,3(S-#76U]C9VMO<W=[?X.'BX^3E``$"`P0%!@<("1`1$A,4%187
M&!D:&QP='A\@(2(C)"4F)R@I,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*
M2P`!`@.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O<3%QL?(R<K+S,W.S]#1
MTM/4U=;7V-G:V]S=Y.7FY^CIZNL``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A>X
MN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=C9VMO<W=[?X.'BX^3E``$"`P0%
M!@<("0H+$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#'2T]35UM?8
MV=K;W-W>W^#AXN/DY0`!`@,$!0P-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E
M+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DL``0(#!`4&!P@)"@L,
M#0X/$!$2$Q05%A<8&2`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y0$%"0T1%
M1D=(24I+``$"`P0%!@<("0H+#`T.#Q`1$A.TM;:WN+FZN[R]OK_`P<+#Q,7&
MQ\C)RLO,S=35UM?8V=K;W-W>W^#AXN/DY0`!`@,$!08'#@\0$1(3%!46%Q@9
M&AL<'1X?("$B(R0E)B<H*2HK+"W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.4`
M`0@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A*"DJ*RPM+B\P,3(S-#4V-S@Y
M.CL\/3X_0$%"0T1%1D?HZ>KK``$"`P0%!@<("0H+#`T.#Q`1$A,4%1P='A\@
M(2(C)"4F)R@I*BLL+2XO,#$R,S0U/#T^/T!!0D-$149'2$E*2P`!`@,$!08'
M"`D*"PP-#@^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R=#1TM/4U=;7V-G:
MV]S=WM_@X>+CY.4``0(#"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G
M*"G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^KK``$"`P0%!@<("0H+#`T.
M#Q`1$A,4%187'A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#W>W^#A
MXN/DY0`!`@,$!08'"`D*"PP-#@\0$1@9&AL<'1X?("$B(R0E)B<H*2HK+"TN
M+S`Q.#DZ.SP]/C]`04)#1$5&1TA)2DL``0(#!`4&!P@)"@NLK:ZOL+&RL[2U
MMK>XN;J[O+V^O\#!PL/$Q<S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3E``$"
M`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A_`P<+#Q,7&Q\C)RLO,S<[/
MT-'2T]35UM?8V>#AXN/DY0`!`@,$!08'"`D*"PP-#@\0$1(3&AL<'1X?("$B
M(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#G:V]S=WM_@X>+CY.4``0(#!`4&!P@)
M"@L,#105%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM-#4V-S@Y.CL\/3X_0$%"
M0T1%1D=(24I+``$"`P0%!@>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<C)
MRLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AZ.GJZP`!`@,$!08'"`D*"PP-#@\0
M$1(3%!46%Q@9&AN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=S=WM_@X>+C
MY.4``0(#!`4&!P@)"@L,#0X/%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P
M,3(S-#76U]C9VMO<W=[?X.'BX^3E``$"`P0%!@<("1`1$A,4%187&!D:&QP=
M'A\@(2(C)"4F)R@I,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2P`!`@.D
MI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O<3%QL?(R<K+S,W.S]#1TM/4U=;7
MV-G:V]S=Y.7FY^CIZNL``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A>XN;J[O+V^
MO\#!PL/$Q<;'R,G*R\S-SL_0T=C9VMO<W=[?X.'BX^3E``$"`P0%!@<("0H+
M$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#'2T]35UM?8V=K;W-W>
MW^#AXN/DY0`!`@,$!0P-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E+"TN+S`Q
M,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DL``0(#!`4&!P@)"@L,#0X/$!$2
M$Q05%A<8&2`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y0$%"0T1%1D=(24I+
M``$"`P0%!@<("0H+#`T.#Q`1$A.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,
MS=35UM?8V=K;W-W>W^#AXN/DY0`!`@,$!08'#@\0$1(3%!46%Q@9&AL<'1X?
M("$B(R0E)B<H*2HK+"W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.4``0@)"@L,
M#0X/$!$2$Q05%A<8&1H;'!T>'R`A*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_
M0$%"0T1%1D?HZ>KK``$"`P0%!@<("0H+#`T.#Q`1$A,4%1P='A\@(2(C)"4F
M)R@I*BLL+2XO,#$R,S0U/#T^/T!!0D-$149'2$E*2P`!`@,$!08'"`D*"PP-
M#@^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R=#1TM/4U=;7V-G:V]S=WM_@
MX>+CY.4``0(#"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"G*R\S-
MSL_0T=+3U-76U]C9VML`````````````0:&-H7.B6:-%I)&D=Z5CIDFGE:>!
MJ&>I3:J9JH6K:ZQ1K9VMB:YOKU6P0;&-L7.R6;-%M)&T=[5CMDFWE;>!N&>Y
M3;J9NH6[:[Q1O9V]B;YOOU7`0<&-P7/"6<-%Q)'$=\4`````````````````
M````````````````````````````````````````````````````````````
M``````````````````#@_@H`_\\8`._N)0!/_3$`[/\^`-_/2P".3U0`_?YB
M`/_O<0#O_X``__^0`.S^G`#T[Z@`[N^U`/_LP@#^U,T`___=`/__[0!L^O<`
ME,G^`&I/!P'\[!(!_L0<`>_^*@'__3D!__])`?_/5P'N3V(!_/YO`?_??@'O
M_XT!__Z<`?__K`'_S[H![D_%`?7\T0'^[]\![__N`?_^_0'N_@H"_/\8`O__
M*`+][#0"_MQ``N__3P+__%T"__]M`O_O?`+__XP"__Z;`O__JP+O_[H";_W'
M`O__UP+_S^4"[L_Q`GFL^@+^A`,#S^X/`T_\&@.N_B8#WO\T`___1`/_[%$#
M_L1;`\_N9P-/_7,#[O^!`^_OCP/^_YX#_>RJ`_[4M0/O[L(#__W1`___X0/_
M[_`#[D_[`_W^"03__A@$S^XD!$_],`3^_S\$[^]-!/[_7`3_[FH$_M1U!._N
M@@3O_9`$[/Z<!-3_J`3__[@$_VS$!/S4S@3/[MH$3_WF!.S^\@3$S_L$__\+
M!?W_&@7__RH%S^8U!4_\0`7L_DP%U.]7!>Y/8@7\_F\%__]_!<_NBP5/_9<%
M[/ZC!=[OL`7__\`%_?[.!?[_W07O_^P%___\!>S^"`;4[Q,&[O\A!OW^+P;_
MWSX&S^Y*!D_]5@;N_F,&_L]P!N[/?`;]_XL&__^;!L_NIP9/_;,&[/R^!L3/
MQP;N3](&_/[?!O_?[@;___X&__\.!^SZ&0?$SR('[D\M!_WN.@?_[TD'[_Y7
M!___9P?L_G,'U.M]!_[_C`?__IL'__^K!^_^N0=__<<'_O_6!__/Y`?N3^\'
M_?[]!__O#`CO_QL(__\K".S^-PC<[T,([N]0"/UL6PCZ]&8([^YS",__@0CL
M_HT(U(^6"*Y/H`C<[*H(_L2T",__P@C__]((___B"/_/\`CN3_L(_.P&"?[4
M$0GO[AX)S_PJ"?[^.`GUST0)[D]/"?W^70G_WVP)__]\"?__C`GN_YH)_^^I
M">Y?M0G_;,$)^M3+">__V@G__>D)___Y"?_O"`KN;Q0*_^XB"O[6+@KO[CL*
M3_]("O__6`K_SV8*[D]Q"OWL?0K>U(<*S^Z3"D_\G@K^_ZT*W_^\"O__S`K_
M[-D*^M3C"L_N[PI/_?L*[/X'"\3O$0ONWQX+_^PK"][4-0O-[D`+?_U."^S_
M6PO7SV<+[E]S"_WN@`O^]8T+S^Z9"VW]I0ON_K(+WL^^"^[_S`O][-@+_M3C
M"\_N[PMO_?P++/P%#-3M#PSNSQL,_>PG#/[4,@P/````````````````````
M``````````$#!`D*"PP-%AP='R`A(R0E)B<H*2PP,3(S-#4X.3L\/3]`04)#
M1$5&1TA*3$U.3U!14U155UA96UQ=7E]@86)C9&5F9VAI:FML;7!Q<W1W>7I[
M?'V`A88``0($!08("0H+#`T.$146%Q@9&AX@(20E)B<H*2HM,3(S-38X.3H\
M/3Y`04)#1$5&1TE+3$U.3U!14E566%E<7F!A96=J:VQM;G%R='5V>'I[?'U^
M@8.%A@`!`@,%!@<)"@L-#@\0$1(3%!87&AL<'1X?(B,E)B<I*BLL+2XO,C0V
M-S@Y.CL]/C]!0D-%1D=(24I+3$Y045)35%565UI;75YC9&5F:FQO<'%R<W9W
M>7I[``$"`P0%!@<("0H-#@\0$1(4%187&!D:&QP='A\@(2(C)"4G*"DJ*RPM
M+C$R-#4V.#DZ.SP]/D%#1$5&1TA)2DQ-3E!14E155E=865I;7%U>7V!A8F-D
M968``0,$"`D*"PP-$!(4%187&!D;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S
M-#4X.3L\/T%"0T1%2$I-3D]155=865M=7E]@861H:6IL;7!Q<W1U=WAY>GM\
M?0`$!08'"`D,#0X/$!$3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q
M,C,T-38W.#DZ.SP]/C]`045'2$E+3$U.3U!15%A96EM<76!A8V1E9F=H:6IK
M``$#!`8("0H+#`T/$!$3%!47&!D:&QP='A\@(R0E)B@I*RPM+B\P,3(S-#4V
M-S@Y.CL\/3X_0$%"0T1%2$E+34]045)35%586EY?8&%D969G:&EK;&UN;W``
M`0(#!`<("0H+#`\0$1(3%!46%Q@9&AL<'1X?("$C)"4F)R@J*RPN+S`R,S0U
M-C<X.SP]/T!!0D-$1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@8V1F9P`"
M`P0%!@<+#1`1$A,4%A<8&1H;'!X?("$B(R0E)B<H*RPM+B\P,S0V-S@Z.SP]
M/C]`0T1&1TA)2DM,3D]04E-45E=865I;7%]@86)C9&5F9VAJ:VQM;F]P``$"
M`P0%!@<("0H+#`T.#Q`1$A,6%QD;'1\@(2(F*"HK+"XO,#$R,S0U-C<X.3H[
M/#T^/T!!0D-$149'2$E*2TY/45)355976%E:6UY@8F-D969G:VUN<W0``0(%
M"PT1$A05%A@9&AL<'1XA)28G*"DJ+2XP,3(T-38W.#DZ/#T^/T%"0T1%1D=(
M24I+3$U.3U!14E-455976%E:6UQ=7E]@86)E:&EJ;&]P<7)U>7I[?``$!0<(
M"0L,#0X/$!$4&!D:&QP=("$C)"4G*"DJ*RPM,#$T-3<X.3L\/3]`04)#1$5&
M1TA)2DM,34Y/4%%24U156%E;7%U?86)C9&5H:FQM;F]S='5W>'E[``$"`P0%
M!@<("0L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+S`Q,S0U
M-S@Y.CL\/4!"0T1%1D=(24Q-3U!14U155E=865I<7F!A8F-D96@``@,&!P@)
M"@L,#Q$3%!46%Q@:&QP='A\@(2(C)"4F)R@I*BLL+B\P,3(S-#8W.#DZ.SP]
M/C]`04)#1$5&1TA)2DM,34Y/4%)35%976%I;7%U>7V!C9&5F9P`!`@,$!P@)
M"@L,#@\0$1(3%!<8&1L<'1X?(",D)B<H+"TN+S`S-3@Y.CP^/T!"0T1&1TA)
M2DM,34Y/4%%24U155E=86UQ>7V!B9&5F9VAK;6]P<7)T>'I[``$"!@P-#A(3
M%187&1H;'!T>'R(F)R@I*BLM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(
M24I+3$U.3U!14E-455976%E:6UQ=7E]@86)C9VEJ;7!Q<G,``@0&!PD,#0\0
M$1,4%187&!D<("$B(R0E)R@I*RPM+S`Q,C,T-38W.#D\/3X_0$%#1$5'2$E*
M2TQ-3D]045)35%565UA96EM<76!A8V1G:6ML;7!R='9X>0`!`@0%!@@)"@L,
M#0X/$!$2$Q05%A<8&1H<'1X?("$B(R0E)B<H*2HK+"TN,#$R,S0U-C@Y.CP]
M/D!!0D-$149)2TQ-3D]045)455976%E:6UQ=7E]@86)C``$"`P0%!@<("0H-
M#A`1$A05%A<8&1H='R$B(R0E)B@I*BLL+2XO,#$R,S0U-C<X.3H\/3X_0$%"
M1$5&1TA)2DM,34Y/4%%24U155E=96EM<75Y@86)D968``0(#!`4&!PD+#0X/
M$!$2%!46&!D:'!T>'R`A(B0E)B<I*BLL+2XQ,C0U.#H[/#T^04-%1D=(24I,
M34Y/4%%24U155E=865I;7%U>7V!A8F-D969I:FQM<``!`@,$!0@-#@\0$105
M%Q@9&QP='A\@(20H*2HK+#`Q,S0U-S@Y.CL\/4!$149'2$E*2TQ-3D]045)3
M5%565UA96EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q``$"`P0%!@<("0H+#`T.
M#Q(3%187&1P='A\B)B<H*2HN+S$R,S4V-S@Y.CL^0D-$149'24I+3$U.3U!1
M4E-455976%E:6UU>7V!A8F-D969G:&EJ:VQM;F\``0(#!`4&!P@)"@L,#0X/
M$A,5%A<9&AL<'1X?("$B(R0F)R@I*BLM+B\P,3(S-38W.#DZ.SP]/C]`04)#
M1$5&1TE*2TQ-3D]045)35%565UA96EM<75Y?8``!`@0%!@@)"@L,#0X/$!$2
M$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CT^0$%"
M1$5&1TA)3$U.3U%24U155E=865I;7%U>7V!A``$"`P0%!@<("0H+#`T.#Q`2
M$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPN+S`R,S0V-S@Y.CL\/T!!0T1%
M1D=(24I+3$U.3U!14E-455976%E:6UQ=7E\``0(#!`<("@L.#Q`1$A,4%QD:
M&QP='A\@(B,D)B<H*BLL+2XO,#,T-38W.#DZ.SP^/T!"0T1&1TA)2DM,3U%3
M5%565UA;7%Y?8&)C9&5F9VAK<'%R=WAZ>P`"`P0%!@<("P\0$1(3%!<8&AL<
M'1X?("$B(R0E)B<I*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+
M3$]04E-45E=865I;7%]C9&5F9VML;F]P``$"`P0%!@D+#0X/$!$2%188&1H<
M'1X?("$B)2DJ*RPM+C`Q,C0U-C<X.3H[/#T^/T%#1$5&1TA)2DU.4%%25%56
M5UA96EU?86)C9&5F:&EJ;&UN;W!Q<G,``0(#!`4&!PD*"PP-#@\0$1(3%!46
M%Q@9&AL<'1X?("$B)"4F)R@I*BPM+C`Q,C0U-C<X.3H]/T%"0T1%1DA)2DQ-
M3E!14E-4559765M=7E]@86)E9FAI:@`!`@,$!08)"PT.#Q`1$A05%A<8&1H;
M'!T>'R`A(B,D)28H*2HK+"TN,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*
M34Y045)455976%E:7%U?86)C9&5F``$#!`4'"`D*"PP-$!(4%187&!D<'1\@
M(2,D)28G*"DL+C$R-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%455=8
M65M<75Y?8&%D9FAI:FML;7!Q<WD``0(#!@@+#`X2$Q46%QD:&QP='A\B)R@I
M*BLN+S`Q,C,U-C<X.3H[/#T^/T!"0T1%1D=(24I+3$U.3U!14E-455976%E:
M6UQ=7E]@86)C9F=I:FMM;W!Q<@`#!0@)"@L/$!(3%!87&!D:&QP?(R0E)B<H
M*RPN+S`R,S0U-C<X.3H[/T%"0T1&1TA)2DM,34Y/4%%24U155E=865I;7%U>
M7V!C9F=H:FQM;F]P<W5W>'EZ``$#!`4'"`D*"PP-#@\0$1(3%!48&1H;'!T>
M'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.SP]/T!!0T1%1D=(24I,3E!1
M4E-455=865M<75]@86)C9&4``@0%!@<("0H+#Q$2%Q@9&AL>("(C)"8I*BLM
M+B\Q,C,T-38W.#H\/3X_0$%"0T5&1TA)2DM,34Y/4%%24U155E=865I;7%U>
M7V%B8V5F9VEJ:VQM;F]P<0`!`@,$!08'"`D+#`T/$!$3%!46%Q@9&QP>'R`A
M(B,D)2<H*2LL+2\P,3(S-#4W.#H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)3
M5%565UA96EM<76!A8V1G``$"`P0'"PT/$!87'1X?(",E)R@I*RPO,#(S-#8W
M.#DZ.SP_0T1%1TA+3$Y/4%%24U155E=865M<75Y?8&%B8V1E9F=H:6IK;&UN
M;W!Q<G-T=79W>'EZ>WP``0(#!@<)"@T/$!$2$Q88&QP='A\B(R4F*2HK+"TN
M+S(V-S@Y.CL^/T%"0T5&1TA)2DM,3E)35%9765I;75Y?8&%B8V1E9F=H:6IK
M;&UN;W!Q<G-W>7I[?0`!`@,$!0@*#`T.#Q`1$Q05%Q@9&AL<'1X?("$B(R0E
M)R@I*BLL+2\P,3(S-#4V-S@Y.CL\/3X_0$%#1$5&1TA)3$U/4%%35%565UA9
M7%U>7V!A8F-D96=H``(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&QP>'R0E)B<H
M*RTO,#$T-C<X.3H[/#X_0$%"0T1%1D=(2DM,34Y/4%)35%565UA96EM<75Y?
M8&%B8V1E9F=H:6H``00%!P@)"PP-#@\0$1(3%!46&!D:&QP='R`A(R0E)R@I
M*BLL+2\P,C0U-C<X.3P]/T!!0T1%1D=(24Q.3U!14E-455976%E:6UQ=7E]@
M86)C9&5F9VAI:@`!`@,$!08)"@P-#A`2$Q05%AD;'R`A(B4F*"DJ+"XO,#$R
M-3DZ.SP]04)$149(24I+3$U.45565UA96EU>7V!A8F-D969G:&EJ;&UN;W!Q
M<G-T=79W>'EZ``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&AL='B$B(R0E)B<I
M*BXO,#$R,S4V-S@Y.CL\/3X_0$%"0T1%1D=(2DM,34Y/4E-455976%E:6UQ=
M7E]B9F=H:6H``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!\@(B,D)B<H
M*2HK+"\P,3,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=8
M65I;7%U>7P`!`@,$!08'"`D*"PP-#@\0$A,4%187&!D:&QP='A\@(2(C)"4F
M)R@I*BLL+B\P,3(S-#4V-S@Y.CL\/3X_0$%#1$5&1TA+3$Y/4%)35%565UA:
M6UU?8&%B``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F
M)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)3
M5%576%D``0(#!`4&!P@)"@L,#0X/$!(3%!46%QD:&QT>'R$B(R0E)B<J*RPM
M+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U)3559765I;7%U>
M7V)D9@`!`@,$!PH+$!$2$Q07&QP='R`C)"8G*"HK+"TN+S`S-S@Y.CL\/T!"
M0T1&1TA)2DM,3U%35%565UA:6UQ>7V!B8V1E9F=H:FML;6]P<7)S='I[?H&"
M@X2'``$"`P4("0L,#0\0$1(3%!48'!T>'R`A)"4G*"DK+"TN+S`Q-#@Y.CL\
M/3]`04-$14=(24I+3$U.3U!14E155E=865U?8&%C969G:&EL;G!Q<G1U>'E[
M?'T``0(#!`4&!P@)"@L-#@\0$1(4%188&1H<'1X?("$B)"4H*2HK+"TN,#$R
M-#4V.#DZ.SP]/D%#1$5&1TA)2DU.4%%25%565UA96EU?86)C9&5F:6IL;7!Q
M<@`!`@,&"`H,#Q$2$Q05%A<8&1H;'!T>'R`A(B,E)B<H*2HK+B\Q,C,U-C<X
M.3H[/3X_0$)#1$5&1TI+34Y/45)35%565UI<7E]@86)C9F=H:6IK;6YO<'%R
M``(#!0<("0H+#`\0$A,4%Q@9&AL<'R$C)"4F)R@I*BLL+2XO,#$R,S0U-C<X
M.3H[/#T^/T!!0D-$1TA*2TY/4%%24U=96UQ=7F!C9F=H:FML;6YO<'-T=W@`
M`0(&!PD*"PT.#Q`1$A,6%QH;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#8W
M.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=:6UU>7V%C9&5F9P`!
M!`4&!P@)"PP-#Q`1$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S
M-#4V-S@Y.CL\/3X_0$%"0T1%1TA)2DM,34Y/4%%24U155E=865I;7%U@``(#
M!@@)"@L,#Q`1$Q05%A<8&QP>'R`A(B,D)28G*"DJ*RPN+S`Q,C,T-C<X.3H[
M/#T^/T!!0D-$149'2$I+3$U.3U!24U165UA:6UQ=7E]@8V1E9F=H:6H``0,$
M!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'2`A(R0E)R@I*BLL+3`Q,C0U-C<X
M.3L\/3X_0$%"0T1%1D=(24I+3$U/4%%24U155UA96EM<75Y?8&%B8P`!`@,$
M!08'"`D*"PP-#Q`1$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S
M-#4V-S@Y.CL\/3Y`04)#1$5(24M,34]14E-46%E:6UQ=7E]@86-D``(#!`8'
M"`D*"PP.#Q`1$A,4%187&!L<'A\@(B,D)28G*"LM+S`Q,C,T-S@\0$%"0T=+
M3$U04U165UA:6UQ=7E]@8V=H:6IK;&]P<G-T=G=Y>GM\?X&#A(4``P0%!P@)
M"PP-#@\0$1(4%187&!D:&QP=("$D*2HK+"TU-SD\/3]`04-$149'2$E,3E!1
M4E-455E;7%U?8F-D96QM;G-T=7=X>7M\?7Y_@(&$AXB)BHN,C0`!`P0%"0L,
M$!(4%A<8&1P='R`A(R0E)B<H*2PP,3(S-#4X.3L\/3X_0$%"0T1%1TA*3$U.
M3U!15%576%E;7%U>7V!A9&9H:6IK;&UP<7-T=7=X>7I[?'V```(#!`4&!PH+
M#0X/$Q05%A<:'!X?("$B(R8G*2HK+2XO,#$R,S8W.CL\/3X_0D-%1D=)2DM,
M34Y/4E-45E=865I;7E]A8F-E9F=H:6IK;G!R<W1U=G=Z>WT``0,$!08'"`D,
M#A`2$Q05&!D;'!T?("$B(R4H*C,T-3<X.3L\/3X_0$%#1$9'2$E*2TQ-4%%3
M5%596EM<8&5F9VEL;6]S=79W>'E\@8*#A(6(B8N,C8^0D0`!`@,&"@L,#0X/
M$A,5%QD:&QP='A\A(B,D)B<H*2HK+2XO,3(S-38W.#DZ.SP]/C]`04)#1$5&
M1TI+34Y/45-455976EQ?8&%B8V9G:6IK;6YO<'%R<W9X``$"`P0%!P@)"PP-
M#Q`1$A,4%1@9'!T>'R`A(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]0$%#
M1$5'24I+3$U04E976%Q=7E]@86-D969G:&EJ;&YP<7("K(VL%*V1K?JM>J[F
MKE>OOZ\PL*6P(K&>L0>R;[+PLF:SX;-%M*VT'K60M0"V8;;#MB.WG[<1N(6X
M\;A:N=2Y1[K"NBB[FKL#O("\_KQGO=*]/;ZXOB._@[_FOT#`I\`RP;'!),*7
MPA##>L/;PT;$JL0/Q9;%)L:HQB;'N,<RR``!`@0%!@<("0H+#`T.#Q`1$A,4
M%189&AL<'1X@(2(D)28H*2HK+"TN,0`"`P0%!@<*"PT.#Q`1$A,4%187&!D:
M&QP>'R`A(B,F)RDJ*R\P,3(S-@`"`P0%!@<)"@L,#0X/$!$2$Q05%A<8&1H;
M'1X?("$B(R4F)R@I*BLL+0`!`@,$!08'"`D*"PP-#@\0$105%Q@9&QP='A\@
M(20F)R@I*BLL+2\P,0`!`@0%!@<("0H,#0X/$!$2$Q05%AD:'!T>("$B(R0E
M)BDK+2XO,#$R,P`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AT>("$D)B<H
M*2HM+S(S-@`!`P4'"`H+#`T0%!46%Q@9'!T?("$C)"4F)R@I+#`Q,C,T-3<X
M.3L\/0`!`@,$!08'"`D*"PP.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I
M*@`!`@,$!P@*"PP.#Q`1$A,4%QL<'1X?("(C)"4F)R@I*BLL+2XO,#$R,P`!
M`P0%!@<("@L,#0X/$!$2$Q05%A<8&1H;'!X?("$B(R0E)B<H*2HK+``!`@,$
M!08'"`D*"PP-#@\0$1(3%A<9&AL='A\@(2(C)B@J+"TN+S(S-``!`@0%!@<(
M"0H+#`T.$!$2$Q05%A@9&AL<'1X?("$B(R0E)B<H*2HL+0`!`@,$!@<("@L,
M#@\0$1(3%!<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+@`!`@,$!08("0H+#`T0
M$1,4%1<8&1H;'!T@(2(D)28G*"DK+"TN+S`Q,@`!`@,$!08'"`D*#0X/$!$2
M$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*P`!`@0%!@<("0H+#`T.#Q`1$A,4
M%187&!D:&QP='B`A(B,D)28G*"DJ*P`!`@,$!08'"`D*"PP-#A`1$A,4%187
M&!D:&QP='B`A(R4F)R@I*BLL+0`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@;
M'!X?("(C)"4F)R@K+"TP,0`!!08("@P-#@\0$1(5&AL<'1XA(B0E)B@I*BLL
M+2XQ-38W.#DZ/#T^0``"`P0%!@<("@L,#0\0$1(3%!46%Q@9&AL<'1X?("$B
M(R0E)B<H*2HK+``!`@,&!PD*"PT.#Q`1$A,6&AL<'1X?(B,E)B<I*BLL+2XO
M,C0V-S@Y.@`"`P0&!P@)"@L,#0X/$!$2$Q06%Q@9&AL<'A\@(B,D)28G*"DJ
M*RPM+@`!`@0%!@<("0P-#Q`1$Q05%A<8&1P>("$B(R0E)R@I*RPM+S`Q,C,T
M-0`!`@,$!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)RDJ*P`!
M`@0%!@<("0H-#Q$2$Q05%A@9&AL<'1X?("$B(R0E)B@I*BLL+2XO,``!!`4'
M"`D+#`T.#Q`1%!88&1H;'!T?("$B(R0E)B<H*2HK+"TN+S`Q,P`!`@,$!0<(
M"0L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(R0E)R@I*RPM+@`!`@4'"0H+#`T.
M$!$2%!46&!D:&QP='B`A(B,E)B<H*2HM+C`Q,C0U-@`!`@,&"`H+#`T.#Q`1
M$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLN+P`!!08'"`D*#0\1$A,4%189
M&AP='B`A(B,D)28I*RTN+S`Q,C4V.#DZ/``!`@,$!0@,#0X/$!$4%187&!D:
M&QP='A\@(2(C)"4F*"DJ*RPM+B\P,0`!`@,$!08'"`D*"PP-#@\0$1(3%!46
M%QH;'1XA(B,D)28G*BXO,#$R,P`!`P0%!P@)"@L,#1`2%!46%Q@9&QP='R`A
M(R0E)B<H*2PP,3(S-#4W.``!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@;'!X?
M("(C)"4F)R@K+2\P,0`!`@4&"`D*#`T.#Q`1$A05%A<9&AL<'1X@(2(C)"4F
M)R@I*BLL+2XO,``!`@0%!@<("0L,#0X/$!$3%!46%Q@9&AL<'1X?("$B(R0E
M)R@I*BLL+0`!`@,$!08'"`D*"PP-#@\0$1(3%A<9&AL='A\@(2(C)B@J*RPM
M+B\Q,@`"`P0&!P@)"@L,#0X/$!$3%!46%Q@:&QP='A\@(2(C)"4F)R@I*BLL
M+0`!`@,$!0@)"PP-#Q`1$A,4%1@:'!T>'R`A(R0E)R@I*RPM+B\P,3,T-0`!
M`@,$!08'"@L-#@\1$A,4%187&AL<'A\@(2(C)"4F)R@I*BLL+2XO,``!`@,$
M!08'"`D*"PP-#A$2%!46&!D:&QP='B$C)28G*"DJ+2XP,3(U-@`!`@,&"@L,
M#0X/$A,5%A<9&AL<'1X?(B8G*"DJ*RTN+S`Q,C,T-38W.``!`@,$!08'"0H+
M#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*@`!`P0%!PD*"PP-$!05
M%A<8&1P='R`A(R0E)B<H*2PN,#$R,S0U-S@Y.P`!`@,$!08'"`D*"PP-#Q`1
M$A,4%1<8&1L<'1X?("$B(R0E)B<H*2HK+``!`@,$!P@*"PP.#Q`1$A,4%QD;
M'!T>("(C)"8G*"DJ*RPM+B\P,3(S-``!`@,$!08'"0H+#`T.#Q`1$A,4%187
M&!D:&QP='A\@(2(C)28G*2HK+``!`@,$!08'"`D+#0X/$!$2%!46%Q@9&AL<
M'1X?("$B(R0E)B<H*2HK+``!!`4'"`D+#`T.#Q`1%!88&1H;'!T?("$B(R0E
M)B<H*2HK+"TN+S`Q,P`!`@,$!0<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@
M(20E)R@I*RPM+@`!`@4&!PD*"PP-#A`1$A05%A@9&AL<'1X@(2(C)28G*"DJ
M+2XP,30V-P`!`@4'"`D*"PP-#A`1$A05%A@9&AL<'1XA(B,D)28G*"DJ+2XP
M,3(T-0`!`@,$!PD+#`T.#Q`4%A<8&AP='A\@(R<H*2LL+S`R,S0V-S@Y.CL\
M/P`!`@,$!0@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*P`!
M`@,$!08'"`D*"PP-#@\0$105%Q@9&QP='A\@(20H*2HK+"TP,3,T-0`!`@,$
M!08)"PT.#Q`1$A05%A@9&AP='A\@(2(E)BDJ*RPM+C`Q,C,T-0`"`P0%!@<(
M"0L-#@\0$1(3%!<8&AL<'A\@(2(C)"<I*RPM+B\P,C,T-0`!`@,$!08'"`D*
M"PP-#@\1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*@`!`@,$!08'"0H+#0X/
M$!$2$Q05%A<8&1H;'!T>'R`A(B,E)B<I*BLM+@`!`@,$!0<)"@L,#0X/$!,4
M%A<:'!T>'R`C)2<H*2HK+"XO,#$R,S0U-@`!`@,$!08'"`D*#`T.#Q`1$A,4
M%187&!D:&QP='A\@(2(C)"4F)R@I*@`!`@0%!@@)"@P-#@\0$1(4%1<8&1H;
M'!T>("$B)"4F*"DJ*RPM+C`Q,P`!`@,$!0<("0L,#0\0$1(3%!48&AL<'1X?
M("$B(R0E)B<H*2HK+"TN+P`!`@,$!08'"`D*"PP-$!$3%!47&!D:&QP=("(D
M)28G*"DL+2\P,3,T-0`"`P8("@L,#0X/$A,5%A<9&AL<'1X?(B8G*"DJ*RTN
M+S`Q,C,T-38W.``!`@,$!08'"0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C
M)"4F)R@I*@`!`P0%!PD*"PP-$!(4%187&!D<'1\@(2,D)28G*"DL+C`Q,C,T
M-3@Y.P`!`P0%!@<("0P0$1(3%!47&!D;'!T?("$B(R0E)B@I*BLL+2XO,#$T
M-0`!`@0%!@<)"@T/$1(3%189&AP='B`A(B,D)28G*"DK+2XO,#$R-38X.0`!
M`@,$!08'"`D*"PT/$!$2$Q07&!H;'!X?("$B(R0E)RDK+"TN+S`R,P`"`P0&
M!P@)"@L,#0\1$A,4%187&!L<'A\@(B,D)2<H*BLM+S`Q,C,T-@`!`P0%!P@)
M"@L,#0\0$1(4%187&!D<'1\@(2,D)28G*"DJ*RPM+C`Q,@`!`@4&"`D*#`T.
M#Q`1$A47&1H;'!T>(2(D)28H*2HK+"TN,#$S-38W.``!!`4'#`T.#Q`1%!88
M&1H<'1\@(2,D)2<H*2HK+"TP,3(T-38W.#D\/0`!`@0%!@<("0H-#Q$2$Q05
M%@````````````"ER-C($,D^R7')I<G>R1S*1\I[RJC*W<H+RSK+;<N9R\7+
M\\LES&?,E,S/S/[,-,UAS9+-QLWUS2S.7<Z:SLS.`L\[SVW/GL_,S__/+M!D
MT)70S-`%T3+1;M&;T=#1_=$JTE[2C=+%TOO2/M-JTZ'3U],-U#C49]2>U,G4
M_M0NU635G=7*U0;6/=9WUJO6XM85UT[7C=?]_P``````````1J)'HD2BL:%8
MHM.A4*'1H=*AOJ.\H[VCOZ.[HT2C1:-&HT>C2*-)HTJC2Z-,HTVC3J-/HU"C
M4:-2HU.C5*-5HU:C5Z-8HUFC6J-;HURC7:->HU^C8*-AHV*C8Z-DHV6C9J-G
MHVBC::-JHVNC;*-MHVZC;Z-PHW&C<J-SH[/'L<>RQ[3'M<>VQ[?'N,>YQ[K'
MN\>\Q[W'OL>_Q\#'P<?"Q\/'Q,?%Q\;'Q\?(Q\G'RL?+Q\S'S<?/Q]#'T<?2
MQ]/'U,?5Q];'U\?8Q]G'VL?;Q]S'W<?>Q]_'X,?AQ^+'X\?DQ^7'YL?GQ^C'
MSL=6H5BAI:&FH:>AJ*%%H4RA2Z&LH:NAL*'"H4JBP:%+HKFBNJ*[HKRBO:*^
MHK^BP*+!HL*B]J'TH?>A]:'XH?FA^Z'ZH=2AVZ'HH>>A_:'\H>2AY:'LH>VA
M[Z'NH>.AW*':H=VAV*'9H>:AZ:'IQ^K'Z\?LQ^W'[L?OQ_#'\<?RQ_/'],?U
MQ_;']\?XQ_G'^L?[Q_S'=Z)XHGJB>Z)\HGVB=:)THG.B<J)QHJ2BI:*GHJ:B
M?J*AHJ.BHJ*LHJVBKJ)BHF.B9*)EHF:B9Z)HHFFB<*)OHFZB;:)LHFNB:J)V
MHGFBO:&\H;:AM:&_H;ZANZ&ZH;.AMZ&TH:BBJ:*KHJJBN:&XH?.A\*'RH?&A
M0*%"H4.ALJ&DQG&A<J%MH6ZA=:%VH7FA>J%IH6JA1:)EH6:AJ:&JH<.BQ*+%
MHL:BQZ+(HLFBRJ++HJ7&IL:GQJC&J<:JQJO&K,:MQJ[&K\:PQK'&LL:SQK3&
MM<:VQK?&N,:YQKK&N\:\QKW&OL:_QL#&P<;"QL/&Q,;%QL;&Q\;(QLG&RL;+
MQLS&S<;.QL_&T,;1QM+&T\;4QM7&UL;7QMC&V<;:QMO&W,;=QM[&W\;@QN'&
MXL;CQN3&Y<;FQN?&Z,;IQNK&Z\;LQNW&[L;OQO#&\<;RQO/&],;UQO;&]\:B
MQJ/&^,;YQOK&^\;\QOW&_L9`QT''0L=#QT3'1<=&QT?'2,=)QTK'2\=,QTW'
M3L=/QU#'4<=2QU/'5,=5QU;'5\=8QUG'6L=;QUS'7<=>QU_'8,=AQV+'8\=D
MQV7'9L=GQVC':<=JQVO';,=MQV[';\=PQW''<L=SQW3'=<=VQW?'>,=YQWK'
M>\=\QWW'?L>AQZ+'H\>DQZ7'IL>GQZC'J<>JQZO'K,>MQZ['K\>PQZ'&=*-U
MHW:C=Z-XHWFC>J-[HWRC?:-^HZ&CHJ.CHZ2CI:.FHZ>CJ*.IHZJCJZ.LHZVC
MKJ.OH["CL:.RH[.CM*.UH[:CMZ.XH[FCNJ/`H56B5J)0HE&B4J)4HE>B4Z+K
MH>JA3Z)`I$*D0Z1%R5:D5*17I%6D1LFCI$_)3<FBI*&D0J5!I4"E0Z7^I."E
MX:7#J%BDI*10R:6D8\GJIK'+6:2FI$2E9,E`R42D6Z1'R5RDIZ1%I4>E1J7B
MI>.EQ*B\K4&D0<E%I%ZD7:3DI<6HKK!+U,.VL=RRW$:DJ:3&J$>D2,E?I*JD
MK*11R:VDJZ3EI<>HR*A%JV"DKJ3FI>BEYZ7KILFHRJA&JT>KO:VSW-;V2*2P
MI*^D4LFQI+>DLJ2SI%3)4\FUI+:DM*1*I4NE3*5-I4FE4*5JR6;):<E1I6&E
M:,E.I4^E2*5ER6?)]:6PR?*E]J6ZR:[)\Z6RR?2E]Z7II;')^*6UR;G)MLFS
MR>JE[*7YI>ZEJ\GQI>^E\*6[R;C)K\GMI:S)ZZ6TR;?)K<EFRD*G]*9GRO&F
M1*?YIOBF6\K\IO>F8,IHRF3*^J;]INZF1Z==RKW+[*9#I^VF]:;VIF+*7LK[
MIO.F6LKOIF7*1:=(I_*F0*=&I_"F8\I!IVG*7,K^IE_*8<K8J+_+R\O0J,S+
MRZC5J,ZHN<O6J+C+O,O#R\'+WJC9J+/+M<O;J,^HMLO"R\G+U*B[R[3+TZBW
MR]>HNLO2J,VHW*C$R]VHR,O&R\K+VJB^R[++P,O1J,7+S*C'RU:K2JO@S>C-
M2:M1JUVK[LWLS>?-2ZOMS>/-6:M0JUBKWLWJS>'-5*OBS=W-6ZM.JU>K3:O?
MS>3-Z\U5JU*KYLU:J^G-Y<U/JURK4ZM,JTBK[\W7K<&MT:W6K=#0S]#4T-70
MQ*W-K=JMSJW)T,>MRM#<K=.MOJV_K=W0O[#,K<NMR]#/K5O4QJW6T-6MU*W*
MK<[0U]#(T,FMV-#2K<S0P*W#K<*MV=#0K<6MV:W;K=/0V*W;T,W0W-#1T-K0
MTM#(K6/45]2SL%S48M2RL%74MK!9U%+4M+!6U+FPOK!GU%'4NK!FU+6P6-2Q
ML%/43]1=U%#43M1:U&#48=2WL%O87M1-U%_4P;!DU,"P3-14U&74O+"[L+BP
MO;"OL+"PR+->V%?8Q;-?V%786-C$LUG8Q[-=V%/84MC)L\JSQK/+LU'87-A:
MV%38P[-6V,JVQ+:WW,VVO=S`W,:VQ[:ZW,6VP]S+ML3<O]S,MK3<R;:UW+[<
MO-RXW,BVMMS.MKO<PMRYW,'<MKFSN;2Y^>#QX+*YK[GRX+&Y]>#WX/[@_>#X
MX*ZY\."LN?/@M[GVX/K@L+FMN?S@^^"UN?3@^+OLY.GD^;OWN_#D[>3FY/:[
M^KOGY/6[_;OJY.OD^[O\N_'D[N3OY*J^^.BGOO7HJ;ZKOO;HJ+[WZ/3H=L"]
M['?`N^R\[+KLN>R^['7`N.^Y[^CDM^]XP%_#Z_'L\=?$V,3!]<#U;,5KQ=#W
M2:1AI+FDN*13I5*E_*7[I?VE^J5*ITFG2Z?@J-^HX:A>JUFBWM!:HL*P7*);
MHF#87:*XN5ZB2J2ZI/ZEXJA+I+VDNZ2\I$"F3*?DJ..HY:C=K:R^3LE4I56E
M0:9JRF"K7ZO@T-_0P["^I%7)S<MAJ^"MWJW?K:V^5J5"IKS)3:=.IVO*SLOF
MJ,_+XM#CT..MY-#AT.2MXJWAK>70:-1AV,7<0.'^NZZ^^>A,I%JDQ+#-L[FY
M0LF_I%FE5Z58I>>H3:1.I&*DP*3!I,*DOLE:I6O)1J:_R42F1::]R4>F0Z9L
MRNRJ;<INRE"G3Z=3IU&G4J?MJ.RHU,O1R]++T,ONJ.JHZ:CKJ.BH[ZACJ_#-
MT\MHJ_'-9*MGJV:K9:MBJ^C0YZWKT.6MY]#HK>:MZ:WIT.K0YM#LT-&SQ;!I
MU&O4:M1LU,:PSK//L]"ST+;'W,;<R-S)W-&VS[9!X4+AN[FZN5KC0+Q!O$*\
M1+SRY//D0[ROOK"^[?'#]<+UT?=/I%RE6Z5(IL#)5:=6IU2G5Z=ORG#*\:C5
MR_"H\LULJ_/-:ZMIJVJK[=#'L&[4RK!MU.6QR;#(L-2ST[/2L]*VU;;6MM2V
MT[9#X43A]>1%O/3DL;Z_['G`[O%5Q&.DPZ16R<2DQ:1=I5ZE2:9QRM;+U\MM
MJ^[0S+#+L&/88MA0I,:D7Z7-L$/);,E@I<+)2Z9*IL')6*?JK6_4U[9%X;RY
M^NC]\\>DV,OTS="PSK#/L%&D9*3-HLJDR:3(I&.E8J5MR</)]:CRJ/2H\ZAN
MJ]6S4J3+I&6E9*5RRO:H5\EGI6:E3*9-IG/*6:=:I_>H^*CYJ&^K]<WKK43)
MS*3$R73*=<K9R]K+]\WVS?G-^,UPJW#4[:WOT.RM9-C6LV781N&]N4:\[_%8
MR6BET;!3I&6DSJ3-I,^D^ZCZJ/RH<:ONK?OH3\)FI&JE>:5TI6^E;J5UI7.E
M;*5ZI6VE::5XI7>E=J5KI7*E<:5[I7"E4Z99IE6F6Z;%R5BF3J91IE2F4*97
MIEJF3Z92IE:F7*9^RGO*9Z=\RENG7:=UIW"GI<I]RE^G8:>DRFBG>,ITIW:G
M7*=MIW;*<Z=DIVZG;Z=WRFRG:J=KIW&GH<I>IW*GH\IFIV.G>LIBIZ;*9:=I
MIV"GHLIYRNO+ZLM/J>W+[\ODR^?+[LM0J>'+Y<OIRTG.2ZE-SOVHYLO^J$RI
M1:E!J>++1*E)J5*IX\O<RT.IW<O?RT:I2*G;R^#+4:E-J>C+4ZE*J=[+1ZE"
MJ4"I[,M.J4C.^\U+SOW->*NHJW2KIZM]JZ2K<JO\S4/.HZM/SJ6K>:M%SD+.
M=ZOZS::K2LY\JTS.J:MSJWZK>ZM`SJ&K1LY'SGJKHJMVJW6K_LU$SD[.1-'[
MK?'0]M#TK4"N]-#OK?FM_JW[T/JM_:W^T/6M]=!"T4/1]ZU!T?.M0Z[XT/&M
M1M'YT/W0]JU"KOK0_*U`T4?1H=1%T42N\*W\T//0^*WRT/?0\-!!KG?4Y+"G
MU.*PW[!\U-NPHM3FL';4>]1ZU/*MX;"EU*C4<]3HLZG4Y[#9L-:P?M33L*;4
MVK"JU'34I-3=L'74>-1]U-ZPW+#HL..PU[#2L=BP>=3EL."PH]35L-2P<=1R
MU&K8U[/:LW78[K-XV-BS<=C>L^2SO;7BLV[8[[/;L^.S=MC7W'O8;]AFV'/8
M;=CALWG8W;/QL^JSW[/<L^>S>MALV'+8=-AHV'?8V;-GV."S\+/LLVG8YK/M
ML^FSY;-PV.NSU=S1W.#<RMS3W.6VYK;>MMS<Z+;/W,[<S-S>W-RVV-S-W-^V
MUMS:MM+<V=S;W-_<X[;+W-VVT-S8MN2VVMS@MN&VY[;;ME^BV;;4W.*VW=S-
MN<BY5>%1X4OAPKF^N53AO[E.X5#A4^'$N<NYQ;E)X<:YQ[E,X<RY2N%/X<.Y
M2.')N<&YP+E-X5+ARKE'X4V\1^5$Y4>\4[Q4O$J\0N5,O/GD4KQ&Y4F\2.5(
MO$/E1>5+O$'E^N3WY&O8_>3VY/SD^^3XY$^\3KQ0O/[DLKY`Y47I_>B^OD+I
MMKZZOD'IN;ZUOKB^L[Z]OD/I_NB\OOSHN[Y$Z4#I4;R_OD;IM[ZTOL;LR.Q[
MP,GLQ^S%[,3L?<##['[`P>S"['K`H<!\P,#L4,*\[[KOO^^][[OOON]@P_+Q
M\_%6Q/3Q\/'U\?'Q4<+^\T'T6<1`]%C$5\1:Q,7UQO7:Q-G$V\3$]=CVU_9M
MQ6_%;L79]LC%IOCQQ:7X[OA)R7VE?*5?IEZFQ\E=IL;)>:>IRJC*=Z=ZIZ?*
M>*?PR_'+5*FJJTC12=%%KD:NK-3IL.NPJ]3JL'S8\K/IMNJVX=S/N<ZY2>5(
MZ4?I:_EGI%G);LEOR6*F9J;)R62F8Z;(R66F8:9@ILK)IJ>CIWVGJLJKRJ&G
MK<I[IZ[*K,I^IZ*GI:>DIWRGK\I9J?[+6ZE:J4#,6*E7J?7+],ORR_?+]LOS
MR_S+_<OZR_C+5JG[RURI0<SYRZNK5:FLJU3.6LZRJUC.7LY5SEG.6\Y=SE?.
M5LY1SE+.K:NOJZZK4\Y<SK&K4,Y3T5+15]%.T5'14-%4T5C11ZY*KD_15=%)
MKDK1L*NZU%;13=%(KDS1L=3LL/"PP=2OU+W4\;"_U,74R=3`U+34O-3*U,C4
MOM2YU++4IMBPU/6PM]3VL/*PK=3#U+74L]3&U/.PS-3ML.^PN]2VU$NN[K"X
MU,?4R]3"U,34KM2AV*K8J=CZLZ+8^[/YLZ38]K.HV*/8I=A]V/2SLMBQV*[8
M\[/WL_BS2]&KV/6S]+"MV'[8L-BOV+/8[]RLV*?8Y]STMO>V\K;FW.K<Y=SL
MMO:VXMSPMNG<[K;MMNS<[[;NW.O<Z[;UMO#<Y-SMW./<\;;SMNC<\=Q=X="Y
M8^'5N5_A9N%7X=>YT;E<X56\6^%DX=*YUKE:X6#A9>%6X=2Y7N%BX6CA6.%A
MX=.Y9^%9X5F\2^57O%:\3>52Y4[E4>5<O*6^6[Q*Y5#E6KQ/Y4SE6+Q-Z4_I
M2NG!ODSIP+Y.Z<.^4.G"ODGI2^FEP,SLI,#-[*/`R^RBP,KL4\)2PO;Q^/'W
M\6'#8L-CPT+T6\33]]+W\L5HI-"DIZ=?SORS_;/RW-BY:>%3Y5K)L,I"S&#.
M6=%,KOGQW,1II'ZE<,EGIFBF7:GWL-JYV[G9N6JDT:33I-*D6\G4I*&E<<FB
MI6FF:J;+R:BGL<IAJ4/,7ZE@J5ZI6M&VJ[6KMZNTJV'.8JFSJTVN3JY/KLW4
M_K.TV/BP^+;=N=RY:N%=O,2^P._:]M3W:Z2CI:2ET<ELIF^FS\G-R6ZFT,G2
MR<S)<:9PIFVF:Z;.R;.GL*>VRKG*N,JJI[*GKZ>URK/*KJ>IIZRGM,J[RK?*
MK:>QI[2GLLJZRJNG9ZEOJ4_,2,QPJ5/,1,Q+S&:I1<QDJ4S,4,QCJ5',2LQ-
MS'*I::E4S%+,;JELJ4G,:ZE'S$;,:JEHJ7&I;:EEJ4[,N:O`JV_.N*MGSF/.
M<\YBSKNK;,Z^J\&KO*MPSK^K5JYVSF3.9LYMSG'.=<YRSFO.;LYHSL.K:LYI
MSG3.NJMESL*KO:M<KF+16ZY@T5"N5:Y?T5S18=%1KEO15*Y2KF/14ZY7KEBN
M6JY9KEW17M%DT=34^;#"V-/4YM1`L>34_K#ZL.W4W=3@U$.QZM3BU/NP1+'G
MU.74UM3KU-_4VM30U.S4W-3/U$*QX=3NU-[4TM37U,[40;';U-C4_+#1U.G4
M_;#9U-74Z-1`M+O8N-C)V+W8RMA"M,;8P]C$V,?8R]CCU,W81]U#M,[8MMC`
MV,780;1$M,S8S]BZV+?8N=B^V+S81;3(V+_8P=BUV/K<^-Q"MT"W0]WYW$3=
M0-WWW$;=]MS]W/ZV_;;\MOO<0=WYMD&W]-S^W//<_-SZMD+=]=S[MD7=;N'B
MN>&YX[EZX7#A=N%KX7GA>.%\X77AWKETX>2Y;>'?N7OAX+EOX7+A=^%QX6SA
M<^%5Y6&\6.57Y5KE7.5?O%;E5.5=Y5OE6>5?Y5[E8[Q>O&"\8KQ@Y5?I5NE5
MZ5CI4>E2Z5KI4^G%OESI6^E4Z='LJ,#/[-3LT^Q9Z:?`TNS.[-;LU>RFP-#L
MQKY4PL'O^O'[\?SQ7,1=Q$/TR/7']=OVW/;5]Z?X;*1MI&ZDU:2EI=/)<J9S
MIK>GN*>VI[6G<ZE5S'6I=*E6S,2K7:YET?#41;%'M._41K3EN7WAQ[ZIP-?L
M7L1PQ7+)IJ5SR7:F=*9UIG>FNJ>YI[S*NZ>]RE?,6,QVJ7BI>JEWJ7NI>:G(
MJ\6KQZO)J\:K9M%WSFC19]%CKE^N8*YBKF2N8:YFKF6N2K'RU/'42;%(L4>Q
M2[%&L=78TMA)M-'8UMA+M-382+1*M-/82-U)W4K=YKGNN7[AZ+GLN:'A[;GI
MN>JYY[GKN6:\T-AGO&6\9+Q=Z<B^V.S9[&3#7\1OI'BFRJMIT6>N3K%-L4RQ
M3+1-M-?8[[G)OG"D7,G6I'3)U,EYIGRI2]UQI->DU<F^RK_*O*?8V$ZT3-VJ
MP'*DJ*38I'7)IZ7`I[^GO:>^IUG,?JFAJ5K,?:G.JWC.S:O+J\RK:JYHKFO1
M::YJT5ZN\]10L5&Q3['PN:+A:+QIO&'EJ\#"[\/OW<2H^$O)V:1SI'?)=LEZ
MIM?)V,G6R=G)Q\K"RL3*QLK#RL2GP,K!RL&GPJ?%RLC*PZ?)RFC,8LQ=S*.I
M9<QCS%S,:<QLS&?,8,REJ6;,IJEAS&3,6\Q?S&O,IZFHJ5[,:LRBJ:2IJ\ZD
MSJK.H\ZESGW.>\ZLSJG.><[0JZ?.J,ZFSGS.>L[/JZ+.?LZASJW.;ZYNKFS1
M:ZYNT7"N;]%SKG&N<-&NSG+1;:YLKFW1<=%RKE.Q4K'UU/G4^]14L?[46+%!
MU5JQ5K%>L5NQ]]15L?;4]-1#U?C45[%"U5RQ_=3\U%VQ^M19L4350-7GV.[8
MX]A1M-_8[]C9V.S8ZMCDV.W8YMC>V/#8W-CIV-K8\=A2M.O83]W=V$^TX=A0
MM.#8Y=CBV.C84]U6W4[=4-U5W53=0[?;V%+=1+=-W5'=J>&PX:?AKN&EX:WA
ML>&DX:CAH^'QN:;A\KFLX:OAJN&OX67E9^5KO&CE8^5BY6SE:N5JO&WE9.5I
MY6OE9N5AZ6;I8.EEZ5[I:.EDZ6GI8^E?Z6?I:NEBZ=KLK\"MP*S`KL#$[W+Q
M_?%$]$7T8,3)]=[$RO7>]G+%<<7=]LG%UO=TI'NFVLG*RK6H7[%UI*JEJ:6H
MI<6G=*Y7W7:D=Z1XI-JDT:NOSE.T>:1=R:NEK*5XR7RFR\K&I\S*KJENS*RI
MJZEMS*FI;\RJJ:VITJO4J[/.L,ZQSK+.M,[3JW31<]%VKG6N8K%&U6&Q8[%@
ML56T1=56M//85[3RV%2T6MU<W46W6]U9W5C=M.'WN?6Y]KFRX;/A\[EQY6_E
M;;QPY6Z\;+STN6WI:^ELZ6[EW.RPP-OLQ>_&[V[I_O%ZI*VE?J;;R7VFKZE&
MM]NDKJ75JUBT><EZR=S)R*?0RL[*R:?-RL_*T<K'I[.IM*FQJ;"IN,ZRJ=:K
MM\ZYSK;.NL[7JWFN==%WT7>N>-%XKG;1M<Y'U4K52]5(U6>Q9K%DL66Q2=5H
ML5JT6[1<M%W=7]UAW4BW1[=9M&#=7MVXX;;AO.'XN;WANN'YN;?AM>&[X7"\
M<^6YX7*\=.5QO'2\=>5OO'.\<^EQZ7#I<NEOZ6;#1O1'],OUW_95QK6IRJ?8
MJWNDW*2OI=W)RZ?2RKO.V:OZN7RDH:9)MWVDW:3>I+&EL*7>R:*FT\K,IW',
M<LQSS+:IMZEPS+BIVJN\SGK1>JYYT6FQ3-5JL4W57;1BW;_AON'[N76\=N7*
MOG3IL<!SQ=CW=,R]SFNQ]-A*MU7"SJ?-I]NK>]%ML4.S;K%LL5ZTP.'\N7:\
M3,G?R=7*SZ?4RM"GO*EWS';,NZFYJ;JI=<S=J[[.X*O<J^*KWJO?J^&K?:Y\
MKGNN3]5OL7*Q<+%.U76Q<;%0U72Q<['VV/788;1?M&"T]]A+MV3=3+=CW7?E
M>+S!X7>\_;G>['7ILL#=[$#R2/1)]-^DLJ5[R=*GU*?BR=C*U\K6RN')X,FD
MIM.GT:>CIKVI>,R^J=W*W\K>RGG,VLK8I]:GV<K;RN'*U:?<RN7*P*GBRM>G
MX,KCRK^IP:GDRJ_,HLQ^S*[,J<SGJ\*IJLRMS..KK,S#J<BIQJFCS'S,I<S-
MJ;#,Y*NFS.6KR:FHS,W.YJM[S,JIZ*O+J<>IS*FGS'K,J\S$J7W,I,RAS,6I
MO\[`SLK.H='+SNZKSL[$SNVKQL['SLG.Z:NCKL7.P<ZDKL_.?JY]T<C.?-'#
MSLS.[*NAKO*KHJ[0SG[1ZZNFKO&K\*OOJZ6NT<ZGKNJKPLYVL:31IM&HT:BN
MKJY3U:S1H]%XL5'5K:ZKKJ[14M6ET:RNJ=&OKJO1JJZJT:W1I]&IKGFQHM%W
ML7JQ5=5>U62T?+&CL66T8-6JL?G85M6BL:6Q?K%4U6+59=5)V6/5_=BAL:BQ
MK+%=U?C88=5[L?K89-7\V%G58K17U5C5I[&FL5O5J[%?U:2Q7-6IL6:T8[3[
MV%K5?;%KM&^T0-E1MVVT1-EQM&7=1ME3MVFT;+1'V4C93MESM%2W2ME/V4/9
M7K=5MW*T0=E0V5VW<+1.MTW9=+1%V?[8:K1"V4O93;=2MV>T3-E0MVBT7+?#
MX7#=:-W"X6S=;MUKW5NW:MU?M]+A6K=`NG'=Q.%8MVG=;=W^N4^W9MUGW4&Z
M5[=9MU:W;]W(X<GASN%]O-7A1[I&NM#A?+S%X46ZU.%#ND2ZT>&JY7J\;K33
MX:.\R^%[O**\QN'*X<?AS>%(NGF\0KIZY<_AH;RDO,SA?KQYY7[ESKYXY:/I
MJ>6HO*:\S+ZFY:+EK+QXZ:J\H>5VZ:7EJ.5]Y:N\I;QWZ<V^I^6GO*F\I.6M
MO*/E?.5[Y<N^J^5ZZ>#LT+ZBZ7[IX>S1OJ'I?.FTP-_L>>E[Z;7`T[ZSP-*^
MM\!]Z<^^S^_'[^?LR._C[%;"Y>SD[+;`XNSF[-#OS._.[\GORN_-[\OO9\-J
MPVG#:,-AQ$KT8L1!\M_$S/7@Q'3%RL79]]KWV_>Z^>"D?,FSI::FIZ:EIJBF
MVJ?9I[',SZG.J:_1K;&NL76T<MU@MV&W=-UVW77=U^'6X4FZV.&LY:Z\U+ZX
MP%?"N<#AI.;*LLS1J="ITJGSJ]+.T\ZPT;"NK[%VM%'9XJ1^I..D?<FWI;:E
MM*6UI:NFZ<GKR:JFX\GDR>K)YLGHR:FFY<GLR>?)X:?JI^BG\,KMRO7*YJ?V
MRM^G\\KEI^_*[LKCI_3*Y*?3J=ZG\<KGRMNG[J?LRO+*X*?BI^C*Z<KJRNVG
MYZ?LI^O*ZZ?=I]RGZ:?AJ;[,M\S<J>^IL\RZS+S,O\SJJ;O,M,SHJ;C,P,S9
MJ;W,XZGBJ;;,UZG8J=:I[JGFJ>"IU*FYS-^IU:GGJ?"IU,[DJ;7,VJG=J=ZI
M[*GMJ>NIY:GIJ=NI]*O:SD&L^*OZJT"LYL[]J['1L:Y#K-?.W\[^J][.V\[C
MSN7.]ZO[JT*LLZ[@SOFK1:S9SORKLJ[VJ];.W<[5SMC.W,ZRT42LX<[BSN3.
M]:O!KK[1OZ[`KK31Q-&VKF;5QM'`T;?1R=&ZT;RN?=6]T;ZNM:[+T;_1N*ZX
MT;71MM&YKL71S-&[KKS1N]'#KL*NM*ZZKKVNR-'"T;>NL]'*T<'1P]''T6?5
MM['+L<JQO[%YU775<M6FU;JQLK%WU:BTMK&AU<RQR;%[U6K5R+&CU6G5O;'!
ML:+5<]7"L;RQ:-5XM*75<=7'L735I-7&L5+9L[%OU;BQP[&^L7C5;M5LU7[5
ML+'$L;2Q=[1\U;6QL;'`L;NQN;%PU<6Q;=5ZU7;55-E3V6O59-EZM&K96=EG
MV7?=?;1KV6[9?+1<V6W9;-E^M%79>;2CM*&T:=E?V:6T<-EHV7'9K;2KM&;9
M9=ECV5W9I+2BM+G15MFWW5?9>[2JM'G=IK2GM%C9;]EXW6#96]FIM&'97MFN
MM'"W?-VQW;;=JMULM[O=:;=ZW7O=8K=KMZ3=;K=OMZ7=LMVXW6JW9+>CW7W=
MNMVHW:G=?MVTW:O=M=VMW66WV>%HMV:WN=VPW:S=H=U3NJ_=;;>GW:;=9[=C
MM^[AL]VNW:+=Z>':X>7A[.%1NJRTZN%,NDNZ\>';X>CAW.'GX4^ZZ^%BV?+A
MX^%2NKKEK[SPX>_A5+JMY;"\KN7?X>#AW>'BX=[A\^%.NK&\4+I5NN'A[>'F
MX;'E2KJTO*KIMN6UY;?EM.6UO+N\N+RYO*_ELN6\Y<&\O[RSY5K9LKRYY;#E
MPKRXY4VZM[SDX;J\OKS`O+V\O+RVO+OEL[S#O-B^V;ZIZ>*^W[[6OMV^J^G;
MOM6^W+ZHZ;O`U[[>OKK`I^FFZ>"^X;ZEZ:3IO,"NZ=J^K.F]P,+`ZNSL[+_`
M[>SI[.OLP,##P.CLOL#!P%G"K>E8PE["U.]<PEW"U^_3[UK"T>]KP]7OUN_2
M[UO"0O)%\D;R1/)'\FS#0_).]&3$3?1,]$OT8\1EQ,WUXL3AQ.'VX/;C]LO%
M=<7=]^+VW/?-Q<S%\\6I^._XY*1RV:_IK*;WRO&G[Z?PI\',\:E&K.?.Z,Y'
MK,[1Q*[%KLW1T['/L:?5UK'5L<ZQT;'4L="Q=MG-L:^TL;2RM'79>-FPM'/9
M=]ETV7&WO-U6NO3AX[[$O+WEQ;S&O+_EON7`Y;'IL.GO[.[LQ,#%P$CRY:1Y
MV;2TL[2]W=COX\3>]^:DQJ[8L=>Q>ME[V7*W]>%7NK+IYZ2XI?*IPLSISDBL
MV;%\V;6T<[?!Y<+E\.Q?PO#XZ*3#S/.I2:SJSL>NTM'0T='1R*[/T=NQW+&H
MU=VQVK%]V7[9OMU9NEBZ\>S9[TKR2?)/]%[)2JSII+FEKJ:MIJ^FL*;NR>W)
M^,KRI_O*^LKYROS*]*G)S,7,SLS[J?FIRLS&S,W,^*E`JLC,Q,S^J<O,]ZG,
MS/JI_*G0S,_,Q\SVJ?6I_:GOSO7.4*Q-K.S.\<Y3K$NL\,Y.K%&L\\Y,K/C.
M3ZQ2K.W.\L[VSN[.Z\[WSO3.T*[)KLRNSZ[5T<JNT]'.KLNNUM'-KJS5W[&K
MU:W5WK'CL=31JM6NU>"QJ=7BL>&QI]FBV;:TNK2WM*79J-FXM+FTOK3'W:;9
MO+2CV:'9O;2DV7FWO]UVMW>W=;?$W</=P-U[M\+=N[3&W<'=>+=TMWJWQ=U<
MNOCA]^'VX5JZ6[K%Y<CER+S'O,GEQ.7*O,;ER;S#Y<?EZ;[FOKOINNFYZ;3I
MM>GGON2^Z+ZSZ>6^MNFWZ;SIN.GR[,?`W._&P-KOV^]@PF[#2_)MPU'T4O1F
MQ%#TY,3?]\[%JOBK^.JDL::RIO.GT<Q4K-&NY+'2L+^TP+3,LZG9?+?ZX?GA
MZZ2SIM+,0JI!JOG.^L[7T=C1TJ[3KM2NK]7FL<*TP;3(W7K?^^&]Z6'"9\3L
MI+REO:6[I;ZENJ6VIO;)M::WIO')\,GSR?+)]<FTIN_)],G]ROVG_LI#R_RG
M1\M"RT7+]:?VI_>G^*=`J$'+^J=!J$#+1LOYIT3+^Z?TI_ZG5ZK4S$.J3:I.
MJD:J6*I(JMS,4ZK7S$FJYLSGS-_,V,Q6JN3,4:I/JN7,X\S;S-/,VLQ*JE"J
M1*K>S-W,U<Q2JN',ULQ5JNC,1:I,JMG,XLQ4JD>J2ZK@S%O/7*QIK%;/3,]B
MK$K/6ZQ%SV6L4L_^SD'/1,_[SE'/8<]@K$;/6,_]SE_/8,]CSUK/2\]3SV:L
M6:QAK&VL5JQ8K$//:JQCK%W/0,]LK&>L2<]KK%#/2,]DK%S/5,]>K&+/1\]:
MK%G/3\]?K%7/5ZS\SFBLXZY=K$[/3<]"SU[/5\]5K.S1ZJ[MT>'1WZ[KKMK1
MX]'KT=G1]-'5KO/1[M'OT=VNZ*[ET>;1\-'GT>+1W-'=T>K1Y-'6KMJN\M'>
MT>:NXJ[EKNRNVZ[GKNG1Z:[8KM>NV]'?T>"N\='HT>#1Y*[AKMFNW*[$U;35
MM=6YU<C5Q=6^U;W5[;'!U=#5L-71U</5U=7)U>RQQ]7GL?RQ\K'VL?6QL=7.
MU=35S-73U<#5LM72U<+5ZK'WL<O5\+'*U;/5^+'ZL<W5^['IL;K5S]7OL?FQ
MO-7&U;?5N]7TL;;5Z+'QL>ZQO]7>KL#9Z['SL</9V=G.V=:TT;2]V=*TS=G&
MV=/9SK2KV=79Q+2SV<>TQK37M*W9S]G0V<FTQ;2[V="TMMG1V<RTR=G6V;#9
MM=FOV<NTPMG>W;'9S[2ZV=+9RK2WV;39Q=G-M,.TV;3(V<?9K-G(M-39O-F^
MV<O9RMFJV=.TU;2RV;G9P=G4M+C9Q-G7V<S9V-FNV?+=IK?PW=O=X-W9W>S=
MR]W2W>K=]-W<W<_=XMWGW=/=Y-W0W=?=V-VHM^O=Z=W,W>[=[]WQW:RWI+>X
MU=3=YMW5W:&WL;?MW:^WJ[?*W:.WS=VPM]W=R=VIM^'=T=VJM]K=?K?8M./=
MO]G.W>C=I;?EW:*WW]VMM];=\]VGM\;>KK=*XDCB7N)&XECB?;=?ND+B7>)'
MXE7B9+I=NEOB0.):XF^Z4>)AXFVZ2>)>NDOB6>)GND3B:[IANDWB0^+\X5?B
M:+I@XOWA9;I3XF:Z1>)0XDSB3N)@NE_B;KI/XF+B_N%4XF.Z;+IJND'B5N)I
MNF*Z4N)<XM7ET>7-Y>'EWN7-O.7EU.78O-OET.7:Y=6\[N7KY=WESN7BY>3E
MT;S8Y=/ERN7.O-:\Y^77O,OE[>7@Y>;EU+SCY>KEV;S3O-SES^7OY<SEZ.70
MO-;EU^7/O,R\TN72O,N\Z>7LY=GERNG"Z;[I]K[KOO"^[+[,Z=?IZK[$Z<WI
MW^7.Z?&^W>GUOOB^P.GTOMOIW.G2Z='IR>G3Z=KIV>GOONV^R^G(Z<7IV.GW
MOM;I\[[ROM#IO^G!Z</IU>G/Z>Z^QNG4Z<?IS\!%[<C`]>Q![<K`2.W\[/?L
M2>WS[/[LT<!$[4KM_>S)P$#M].S0P$?M^>S,P/OL^.S2P/KLR\#.P$/M]NQ&
M[4+M8\+G[VC":<)BPN;OX^_D[V;"WN_B[V7"W^]GPF3"W>_A[^7O4?).\E?R
M5O)4\D_R<L-0\G'#S<!3\G##6/)2\DWRX.]OPTSR5O15]%7R:,19]%KT5/18
M]%/TT?57].?$Y<3/]=+USO70]>;$Y?;F]G;%Y/;B]\_%X/?A]ZSX5L;S^/'X
M\OCT^+OY[:2XIEFJZ<QDS_71]]'VT?C1_;'7U?G1UM78U=G5VMG;M-O9W=G<
MM-JTW-GZW?C=]]WVW?7=LK?YW7"Z8^)EXG&Z9.+;O-J\\.7?Z=[IX.GYODOM
MT\#H[VK"6?)WQ>ZDOZ6YID*H6JI;JFZL^M&SM]'F^KYKPN^DNJ;KS%RJZLQE
MSV^L9L]PK/S1[J[MKM[5W-7=U=O5VM7>V>'9WK3?V=VTX-G[W6;B9^)HXO/E
M\N7<O/'E].7AZ>+IX^E,[=3`;,):\NC$7\EQK&?/[Z[^L=^TXMFUM[2W:>)J
MXMV\WKSEZ>3IZ>_C]_"D8,G`I4.H2,MRK+:W\:1HSW.L:<_5P/*D[,QJST+2
M0=+^T?W10])`TD"R0;+@M./9Y-GEV4'>0MY`WOW=_MVWMVOB]^7VY?7E^.7G
MZ>;I^[[HZ=;`3>WJ[UORY_;SI,*EP:5=JF')?LF[IO?)2<M*RUZJ[<QTK&O/
M;,_PKO2N1-+SKO&N\J[?U4*RX[3AM.*TYMERNO2DH<G#I:3)QJ6CR<6EQ*5$
MJ*+)^,G\R?[)0,K%IL:F^\G!IOG)_<G"IKVFOJ;$IOK)O*9%J+^FP*;#IEO+
M6<M,RU&H4\M,J$W+5<M2RT^H4<M6J%K+6*A:J$O+3:A<RU2H5ZA%S4>H7JA5
MJ$[+2JA9J%;+2*A)J$/-3\M0J%NH7<M0RTZH4ZCNS%RH5\M2J%VH1JA4RTNH
M6,M$S6JJ>JKUS'&J2\UBJF6J0LWSS/?,;:IOJOK,=JIHJF:J9ZIUJD?-<*KY
MS/O,;JISJOS,2LUUK'FJ8ZI)S4W-^,Q/S4#-;*KTS&NJ?:IRJO+,=<]XJGRJ
M0<U&S7ZJ=ZIIJE^J9*KVS&"J3LWPS._,_<SQS'NJ]:YTJO[,8:JFK$S-?,^A
MSZ3/=\^GSZK/K,]TSW:L>ZQ)TJVLI<^MSWO/<\]DTGZLHL]XSWK/I:Q]SWVL
M<,^HSZO/>JRHK&W/JJQXK*ZLJ<]OSZNL7M)(S7RL=ZQVSV[/K*RDK*//J:RG
MK'G/H:QQSZ*LHZQRSZ;/>:Q^STS2_:Y#KU726])7TDK23=)&TD?22J_ZKE;2
M7])%K_:N0*].TD*O3])9TD2O:-)(TORN^ZY(KT729M):TF?28=)3TF+27-)E
MTF/22:]4TOFN^*Y!KT>O8-)&KU'20[)ITE#22]+^KDNO]ZY8TEW29;+AU>75
M4K)0LD>RX]7BU5NRZ-55LOK51]9$LO?5\-5GLN#5_-5DLEBR8[).LNS5_M7V
MU4^R2;)%UOW50-91LEFR0M;JU?O5[]5$UEZR1K)<LO35\M7SU5.R[M7MU4BR
MY]5&UDJR\=5HLF*RYM5?LEVR9K+XU6&R4M+YU6"R0=9%LO755[+IU5:R5+),
MLDNRY]E#UNO5_-E-LD&U6K+NM/;9_+3JV>NTY[1)VNVT\;3LM/6T3=I$VO'9
M^K3TM/W9Y+1*VD/:Z+3WV?>T5=I6VN6T2-KYM/O9[=GNV?VT\MGYV?/9^[1$
MM>_9Z-GIV>O9ZK3XV?BT0K7ZV5/:2]KFM%':\K3PM%?:[[1!VO39_ME'M47:
M0MKPV4.U3]I,VE3:Z;1`VD:U1]KSM/:T1MI%M?79Y-50VD[:4MKLV4"U8=Y@
MWD;>O;=?WDG>2M['MVC>PK=>WD/>R+>^MU+>2-Y+WF/>N+=JWF+>P;=7WLRW
MR[?%MVG>N;=5WDS>6=YEWLVWN[=4WDW>Q+?#MU#>6MYDWD?>4=Z\MUO>R;?`
MMT[>O[=%WE/>9][^M+"Z5MYLXEC>9M[&MT_>NK?*M_"\1-Y=WES>JN*MNGWB
MI.*BNF[BK[IWNFWBL.*QNG'BH^)SXK/BK^)UNJ&Z4^:NNGVZ;^*NXJ.ZJ^*X
MXG7B?N*VXJSB?+I\XG:Z=+JHNGKB=^)XXK+BM^*UXGJZN>)^NJ>Z<.+ZY7GB
M>+JLNJFZ>[JEXG3BJKJGXJ2ZIKISNJGBH>)RXJ6ZL>*TXGOBJ.)YNM^\IN+Y
MY:WB=N)$YD[FXKQ-YEGFY+Q+YD_F[[Q&YN>\4N;PZ?.\\KQ4YD/F7N;MO..\
M5^9;YF#F5>9)YN:\Z;SQO.R\3.:BXDCF7^;HO.N\8>;@O%;F^^5<YM_`2N;A
MO$7FY;S\Y:NZ0>9:YD+F0.;JO%CF_N51YE#F7>9'YNZ\\^E)O_Z^0.KKZ4&_
M]^E(OT._]>E/[?OI0NKZZ>GI^.E$ZD;J_;Y%ZD2_2K]'O_[I1K_YZ>WI\NG]
MZ46_0K_\OD"_\>G]Y>SI[^E!ZO3IZNE.[4/J[NG\Z5'MX\#7P-O`4^U9[5?M
MV<#:P.'`6NU2[=S`5NU5[5OMXL#=P.#`5.WDP-[`Y<#8P%CM4.WW[W'"]._V
M[V_"\N_S[^[O]NGO[W#"Z^]MPOCO;L+L[^WO\>]SPG+"\.]XPU_R9?)YPUSR
M=L-SPV?R=\-TPU[R8?)B\F/R9O+U[UWR=<-D\FCR8/)=]&K$8/1KQ&CT7_1<
M]%[T8O1E]&3T9_1;]&G$8_1F]&GT8?33]=3UV/79]=;UU_75]>G$>,7K]NCV
MZ?;J]GG%Y??D]Z_X],6M^+#XKOCU^%?&9<:C^6SYHOG0^='Y]:3'ID'*7LM?
MJ&*H7\M@J&&H6,U:S57-4LU4S:2JHJI6S:.J4\U0S:&J5\U1S:6J6<VOS[//
MMZRVSZ^LLJRTK+:LLZRRS['/L:RTS[7/KL^UK+"LL,]WTGC2>=)0KTRO;M)V
MTGO24:]LTG+2:])UTG'23:]/KWK2:M)MTG/2=-)\TG#23J]MLD[64-9,UEC6
M2M97UFFR2-9;VE+6;+)3UE;66M9/UE36:K)KLEG63=9)UEO64=95UDO62+5)
MM67:3[59VF+:6-I,M6#:7MI?VDJU8]I<VEK:2[5=VF':3;5DVG#>=]YYWJ'>
MVK=KWM*W>M[7MZ+>SK=]WFW>?MYLWMRW>-[/MZ/>U+=QWMFW?-YOWG;><MYN
MWM&WV+?6M].WV[?0MW7>U;=.M7O><]YTWL'BM+J]XL/BO^*VNK[BPN*ZXKSB
MM;K`XKOBM[JRNL3BL[IGYF3F<.9JYFSF]+QFYF[F;>9KYG'F][QHYF_F];QC
MYF7F]KQBYG+F:>9*ZE&_5>I3ZDN_2>I,ZDWJ2.I5OU:_1^I6ZE'J3[],OU#J
M3NI2OU+J3;].OT_J4+]+ZE3J4[]7ZECJ5+_GP.[`7.UB[6#MZL#IP.;`7NWL
MP.O`Z,!A[5WM7^WMP'?"^^]TPG7"_>]VPOKO^>]L\OSO;?)ZPVOR:O)I\GO#
M;,1J]&OTW/7;]>K$VO7L]NWVYO>Q^/;XO/EYQL;Y]J2FJJ>JN*SOP/>DJ*I2
MK]VW^*1NLKBZ8LFWSWW2Q>+PP/FDJ:JXS[G/9MI0M:3>WK?&XOB\?,/ZI&?:
M^Z3)ID+*R*9EJ&2H8ZA@RZJJJZI;S;K/O<^ZK+O/N:R\S[NLHM*ATG[24Z]=
MUE[6;[)<UE_64K5PLE&U:]IJVFC::=ILVJ;>I=ZIWJC>I]ZYNLGBR.*ZNL?B
M<^9TYOF\6>I:ZG+R?<-Q\G#R;O)O\NO$;/3N]O?X_*2ER<>EILE#RD3*9LMB
MRV'+K*IERV>H8\MFJ&?+9,M?S;[/7<UDS:VJL*IES6'-8LU<S:^J7LVNJF/-
M8,W"S[VLOJS%S[_/Q,_`S[RLP\_!SZC2I=*GTEBO5Z]5KZ32J=)4KU:OIM)G
MUJ/2JM)BUF;69=9NVGG::-9CUFW:=+)SLF'69-9ULG*R<;)@UFG6<-IWVE2U
M=MISVE:U==IOVG':=-IRVE6U>-I3M=^WK=ZLWJK>XK?AMZ[>J][*XKNZX+>P
MWJ_>S>++XOJ\O+K,XG;F^[QUYG[F?>9[YGKF=^9XYGGF?.:AYE_J7.I=ZE>_
M6^IAZF#J7NID[67M\<#RP&/M><+^[WC"?L.APVW$;O1M]-WU[_9ZQ>CWY_?I
M]\BEQL]9KW:R:M;)I:?)_:1%RFS+:LMKRVC+:*AIRVW-LZIKS6?-:LUFS;6J
M:<VRJK&JM*ILS6C-PJS%K,[/S<_,S[^LU<_+S\&LK]+2S]#/Q*S(S]//RL_4
MS]'/R<_`K-;/Q\_#K+32J]*VTJ[2N=*ZTJS2N-*UTK/2M])?KUVOL=*MTK#2
MN]*RTEZOS\]:KURO>-9MUFO6;-9SUG36<-9[LG76<M9OUGFR;M9WLGJR<=9Y
MUENO>+)WUG;6?+)^VJ':8+6GVJG:HMI:M:;:I=I;M6&U8K6HVEBU?=I[VJ/:
M>MI?M7S:I-JJVEFU7K5<M5VU5[7IM[?>Z+>[WK'>O-ZRWK/>O=ZZWKC>N=ZU
MWK3>OM[EM[;>ZK?DM^NW[+?GM^:WSN*^NKVZT^+\O+^ZP;K4XN.WP+K0XM+B
MS^+1XJOFJN:GYD"]8NI!O:;F_KRHYJ7FHN:IYJ/FI.;]O&GM9NIEZF?J9NU:
MOV/J6+]<OUN_9.IHZEF_;>WUP'K"]L#SP&KM:.UK[6[M],!L[6?M0O!%\'7R
M0/!O]$;PHL-$\'O"0?!#\$?P=O)T\J/#<_)NQ.W$\?;LQ//V\/;R]M#%LOC*
MI6[-O-*]TGVRO]Y=OZ3#>\6S^,NE;\U@HM?/V,^^TK_2?K*ALJO:PM[!WL#>
MU>+6XM?BPKJMYJSF:>I>OU^_<NUO[7#M<>U)\$CP?,)W\M[US*7&K**RP][-
MI<#2H[)CM62USJ7/I4;*:JAIJ,>LV<^LVM"ET:72I=.E:ZALJ&[+;<NVJG+-
M<,UQS=K/V\_+K,FLRJS(K&"O9*]CK\'28J]AK\+2IK)[UGK6I+*ELF:U9;6N
MVJW:I[+MM\7>[K?$WMCBKN9"O6KJ<^VFPZ7#?,74I7/-J++9XL.Z;\MPRW3-
MN*JYJK>JSZS0K,VLSJS<S]W/S*S#TFBO::^KLLG2;J]LK\K2Q=)KKVJO9:_(
MTL?2Q-)MK\;29J]GKZRRH=:BUJVR?-9^UJ36H]9]UJFRJK*VVFNU:K6PVFBU
ML]ILM;3:;;6QVF>U:;6UVK+:K]K2WL?>\+?SM_*W][?VM]/>T=[*WL[>S=[T
MM]#>S-[4WLO>];?OM_&WR=[;XL>ZW^+&NMSBQ;K(WL_>WN+(NN#BW>+:XK'F
MM>:WYK/FLN:PYD6]0[U(O4F]M.9&O:_F1[W$NK;F1+ULZFOJ<^IMZG+J;^I@
MOW'J8;]BOW#J;NKXP'3M]\!W[77M=NWYP$WPH<).\'W"3_!^PDSP4/!*\*?#
M>/*HPV_$2_!PQ.[$W_5^Q?3V?<7J]_7%]L7,^=&LWL]NM6^UU:7*ID?*<<MM
MJ+JJTJS3K-2LIM;+TF^OKK*EUKC:<;6WVG"UU=Y*O;OFN.:YYKKF>.U1\''T
M</3U]M:E=<UPKW*UUM[AXDN]=.I2\'+TUZ6[JM>LW\_8K-:LU:S,TG&O<J]S
MK["RI]:OLKG:L;)SM=?>^+?YM\FZRKI,O62_=>ICOWGM^L!3\'/TV*5NJ'C-
M=\V\JG;-O:IYS>7/VZS:K.?/YL_?K-ZLV:SAS^+/X\_@K.#/W*SDS]VLS]+3
MTM'2T-+4TM72UM+.TLW2=:]VK]?2TM*PUMC2=Z]TKZK6J=:KUJS6KM:MUK+6
MM;*RLK:RJ-:WLK'6M+*OUK.RO-J^VKK:N]J_VL':PMJ]VL#:=+7;WN#>V-[<
MWN'>W=[ZMT.X_;?9WMK>SKI&N/ZW1+C\M]_>1;C>WD&X^[="N.+>YN+HXD"X
MX^+,NNGBS;KGXN+BY>+JXLNZY.).O;_FON91O4^]O.9-O;WF4+U]ZJ'J?NIV
MZGKJ>>IWZF:_9[]EOWCJ>^I\ZFB_0,&C[?S`>^W^P$'!_<"B[7SM^\"A[7KM
M?NU][57PI,*EPJ+"H\)4\'ORJ<-Y\GKR=/1W]'7T=O3@]>_$Z_>T^/?%^/CY
M^&;&V:7AK,/:X][:I6^HOJKHS^G/>*_$VG6U1[A"P:3M?/)X]-NEH<UZS7S-
M?LU]S7O-OZKBK/+/[<_JS_'/Y*SEK/#/[\_NS^O/[,_SS^.L?*^DKZ.OX=+;
MTMG2H:^YUGJOWM+BTN32X-+:TJ*OW]+=TGFOY=*EK^/2?:_<TGZO>Z^YLKK6
ML]:UUK?6N-:VUKJRN]:TULC:=K70VL7:T=K&VL?:S]K.VLO:N+)WM<G:S-IX
MM<W:RMKNWO+>3KCPXE&X\-[MWNC>ZM[KWN3>3;A,N$BXY]Y/N%"XYM[IWO'>
M2KA+N._>Y=[RXM"Z].+LWO;BU+KWXO/BT;KOXM.Z[.+QXO7B[N))N.OBTKKM
MXE2]P>98O5:]S[K(YLGF4[W'YLKF5;U2O</FP.;%YL+F6;W$YL;F5[UJOZCJ
MHNJFZJSJK>JIZJKJI^JDZFR_:;^CZJ7J:[^KZD;!JNVE[47!0\&L[43!J.VI
M[:;MK>U6\$?!I^VN[:OM6O!7\*;"6_!=\%SP6/!9\*/RJL-^\J+R??*D\J'R
M>O1]]'GT<<1[]'ST?O1RQ'3$<\3A]>/UXO7V]K7X^OC<I7++P*JCS<&JPJJB
MS?C/]\_FK.FLZ*SGK/3/]L_US^C2IZ_LTNO2ZM+FTJ:OJJ^MKZZOY]+ITJRO
MJZ^IKZBOPM;`UKS6N[*]UKRROM:_UL'6O;+5VM3:T]K2VO;>4KCSWO7>4[A4
MN/3>0>/YXOKBU[K5NM:Z0^-"X_[B_>+\XOOB0./XXLOFT.;.YLWFS.;/YJ[J
M;;](P;#M2<&O[5_P7O"GPJ7RJ\.A]*'%]_:W^+;XJ,GJK.NLP]96N-VE<JAQ
MJ'"HI,W$JL.J[JSZS_W/^\_LK.VL^<_\S[6O\]+UTO32LJ_OTK"OKZ^SK[&O
MM*_RTNW2[M+QTO#2QM;'UL76Q-:^LGVUUMK8VMK:?+5ZM=?:>[79VGFU0=_W
MWOK>_MY:N/S>^][XWOG>6+A`WU>X7+A;N%FX_=Y)XTCC1./8ND?C1N/9NEZ]
MTN9?O5N]7;U:O5R]K^IPO['JL.I%XW*_<;]NOV^_M>VS[4K!M.VV[;+ML>U@
M\*K"J,*IPJ;RI_*MPZS#H_2D]*+T^/;Y]MZE2,ISJ*7-QJK%JJ;-0-#OK/[/
M\*RVK_C2]M+\TK>O]]+[TOG2^M+(ULK6O[+)UL"RHK6AM7ZUV]I$WUVX7KA#
MWT+?2N/;NMJZ2^-,XV&]8+VUZM/FU>;4YK3JLNJVZK/J<[^W[4O!N.VY[:O"
MK,)UQ-'%WZ5!T/W2N*^ZL[FSI+7=VJ.UW-I%W]RZ3>/=NG;$I?3+IL>JI\WR
MK/&L0M!#T$#30M.YKT331]-%TT;30]/^TKJO2--!T]/6QK+<UL.RU=;'LL&R
MT-;=UM'6SM;%LL*RU-;7UL2RV-;(LMG6S];6UMK6TM;-ULO6V];?VN3:X-KF
MVJ>US-;AVJ6UWMJLM>+:J[7CVJVUJ+6NM:FUJK6FM>7:8;A0WU/?1]],WT;?
M8[A*WTC?8KA/WT[?2]]-WTG?X;I2WU^X4=]=X^BZ6./GND[C4./@NE7C5.-7
MX^6Z4N-1X^2ZW[I3X^*Z6>-;XU;C3^/CNFF]WKI<X]GF8KW;YF.]9;W>YM;F
MYKK<YMCF8+AHO62]9KUGO7:_W>;7YFJ]VN;`ZKOJQ>ITO[WJ>+_#ZKKJM^K&
MZE'!>;_"ZKCJ=[^\ZGN_N>J^ZGJ_P>K$ZLOMS.V\[</MP>U/P<CMO^J_[<GM
M3L&^[;WMQ^W$[<;MNNW*[4S!Q>W.[<+M4,%-P<#MN^W-[76_8_!A\&?PL,)E
M\&3PLL)J\+'":_!H\*[":?!B\*_"K<*K\F;P;/"H\K+#L,.J\JSRJ?*QPZ[#
MK\.SPWC$JO2I]*?TIO2H]'?$><3PQ.7UY/7Z]OSV_O;]]OOVH\6BQ=/%TL74
MQ>WW[/?[^+CX_/A8QEG&;?E^QLRFJ,U%T$;01-#SK$?02-!)T$G33]--T[NO
M2]-,TT[32M/)LM[6R[+@ULJRW];HVJ^UZMKGVN'6L+7IVE;?9+A4WV6X5=]F
MN.FZ8>->XV#CZKKKNE_CW^;@YFN]XN;AYF&BRNK+ZL?JR.I\OWV_R>I7P5/!
M6,%4P5;!4L%5P;/"S^VN\JWRJ_1ZQ'O$0??F]4#W_?BD^<VF=*BIS<BJ]JQ,
MT/2L2M#YK/6L^JSXK$O0]ZR_K[ZO6M/'KU/36=/#KU+36--6T\*OQ*]5T[VO
M5-/(K\6OR:_&KU'34--7T\"OO*_!K_#6Z=:UM>C6S[+6LM.RV;+8LM2RXM;E
MUN36T++FUN_6T;+CUNS6[=;2LNK6U[+-LM6RY];,LNO6[M;[VO+:LK7YVO;:
M[MKWVK2U[]KKVFRX]-JQM?K:N+6ZM>W:N;7PVK.U^-KQVO7:\]JVM>S:N[7.
MLK>UO+5HN%W?7]]AWV7?6]]9WVJX8-]DWUS?6-]7WV+?6M]>WVNX:;AFWV>X
M8]]RX^ZZ:N-XO73C\;IXX_>Z9>-UXV+C=^-FX_ZZ^[IVXW#C[;KUNO2Z\[KY
MNF/C^KIQX_:Z[+ISX^^Z\+KXNFCC9^-DXVSC:>-MX_VZ>>/RNF[C;^-KX_RZ
MY^9PO7F]=;WDYG*]=KWPYFR]Z.9TO>OFYN9SO7>]Y>9QO>_F;KWNYNWF>KUR
MY6V][.;CYGN]ZN9OO>GFHK^GOWZ_V.K/ZMOJT^K9ZJB_H;_,ZM+JW.K5ZMKJ
MSNK6ZJ._U.JFOZ6_T.K1ZLWJU^JDO][JW>K:[=;M7\'0[5G!:<'<[6'!7<'3
M[63!9\'>[5S!U>UEP>#MW>W1[6#!6L%HP=CM8\'2[5[!W^UBP5O!V>UFP=?M
MV^UN\'3PN<)W\+3"M<)O\';P<?"ZPK?";?"VPG/P=?"XPG+P</"X\K?#N,.T
MP[7#M/*R\K;RNL.W\K#RK_*S\K'RML.U\JST?L1]Q*WTK_2N]*'$Z_7H]>GU
MY_7J]?+$[/7QQ$+WU<77Q>[WUL6Y^$#Y0OG^^$'Y;,;.IONL;]+*K]JR_-K]
MVM_J:L'A[;O"NO*Y\J+$[?5#]_C%2<K)JG6H3=!@TUO37]-=T\NO7M-<T_'6
M_MI`VVG?:M]NN&^X:-]KWV??;;A`NW"X>N-\O?'F?;VIO^+JX.KAZN3MX^WB
M[;ORN<.\\D3W^<6Z^,^FRZK*JD_0_*Q.T&+3S*_RUF'3W++UUO/6]-;;LD+;
M0]M!VW.X;=]LWV[?<KAQN/+F].9^O?/FX^JJOWGP>/"[P[WRO<.\P[#T[O7S
MQ-"F4-#]K&73SJ]DTV/3S:_[UOW6]M;WUMVR^-;>LOS6^=;ZUM^ROK6_M43;
M;]]PWW[C0[M!NT*[>^-\XWWC^>;ZYJ&]]^;VYOCF]>:MO^3JJ[^LO^;M:\'E
M[:CO>O![\+S"O<)LP;[RO_*Q]*/$T:;2IOZLS*K/KU'0P+73ID&M4M!3T$"M
M0JW4IE30T:]FT].OT*_2KT'7X+)`U_[6<=^AXZ*]KK_FZN7JY^WO]=6F<\NJ
MS4.M5=!HT]2O9]/5KT/7XK)"UT37X;)&VT?;1=O!M72X=;A%NZ/CHN-$N_OF
M_.;GZG#!;\%MP6[!<<%\\+_"OL+`\K+TI<6DQ=:F^]%WN,*U=KA&N]>FJ<G8
MIMFFJ\UVRW?+=ZATRW:H>:AURWNH>JAXRWBHT:K/JJW-SJK3JM6JTJJPS:S-
MUJK0JGRHU*JOS:[-S:I;T$>M2*U=T%?06M!CT&'02:UGT$RM9-!<T%G02=MB
MT$2M9=!6T%_01JU+K6#03ZU-K5C02JU>T$ZM1:UFT-JOXZ_8K]:O:M/>K]NO
M;-/=KVO3:=-NT^*OX*](VV_3;=/7K]FOW*_?K^&O3M?DLD771]=(UU#73-=*
MUTW74=?ELNFR1M=/U^>RYK)+UTG7X[+HLLBU4=M/V\JU2MNAW\FU3MM+V\6U
MR[50V\>U3=M'N\:U3-O,M<2UP[5WWW7?>]]SWZ+?>-]RWWNXH[A]WW;??KA\
MN'[?>;AXN'G??;C-M7S?=-]ZN*&XHKA,NTB[3;NFXZ7CI^-*NZ3C2[NJXZGC
MJ.-)NT'G1.>HO4/GI[VCO:2]I;U`Y_[FIKU"Y_WFZ>KSZK&_L+_MZN_JZNKN
MZNCJ\>JOO_#J[.KRZNOJ=,'H[>[M>,%ZP7?!=L%UP7/!Z>WL[7+![>UYP>OM
MZNW`PL'"H?!]\'[PPO+!\K[#M/2DQ+/T\/5%]Z;%0_E$^=C%VJ;7JE+;3KM[
MP>_MVZ;EK^2O4]OTZMRF4*U4VU7;5MM/N[*_W:;8JFC0YJ]PT^JR5]NDN%"[
ML[]\P<+"M?3>IMFJYZ]2U\ZU4;NKXT7GWZ;/M:/?4KO@IK'-:=!1K7+3ZJ_H
MK^FOZZ]QTU?75-=6U^NR[;+LLE/7[K)5UUC;6=M:VZ;?I]^EWZC?I;BDWU.[
M2N=&YTGG2^=(YT?G]>KVZO?JM+^UO_'M\.WR[:/PHO#$\L7RP_*EQ+;TM_1&
M]^_WN_CAIGVH?<'BIEC76]M!QDK*2\I-RN.F3LI,RJ++H\M[RZ'+H:BBJ'S+
M>LMYRWW+?JA^RVK0MLW<JK7-M\W;JKS-WZJRS<#-QLWFJL/-XZJYS;_-P<VT
MS>*JW:JZS>2JYZKAJMJJOLVXS<7-Z:KEJN"JO<WLK[O-WJKHJK/-PLW$S6*M
M7*UDK6&M<=!TT%VM:]!6K6"M8ZUEK:+0=]!5K:'06:U7K5*M;]!^T'/0=M"E
MT&:M?=!>K7C0I-!UT'G0?-!MT*/0>]!LT'#07ZU:K5.M6*U4K6>M;M"ETUNM
M>M!!SJC3^J]VTZ/3?=.RTZK3?M.ITWC3?-.UT_VOK=.DT^VOL]-TTZS3_*_W
MKW/3]:_TK_FOJ]/QK_BO<M!<VZ;3>M/[KWO3H=/^KW73K].NT[;3\Z_PK[33
ML-.GTZ+3]J_RKW?3[J^QT^^O>=->UV#79==YU_RR\K)=U_VR_K)HUV_7===B
MUVG70+-WUW+7^K+XLF[7:M=<U^^R8==9U_>R^;)FUV/7]+)SU_&R9-=ZUVS7
M:]?PLONR\[):UU_7<-=VUT&S6]=GUVW7]K)XUW'7=-?ULFS;8-O7M7W;I]NJ
MV]6U:-NCVVG;=]OBM7/;W[5TVUW;I-OHM:';==NLVW#;R-^OV^:U;MMZV^FU
MU+5RVZW;:]MDVV_;8]MAV]"UI=MJVZC;J=O8M=VUV;7AM7[;VK5VVV;;TK5>
MVZ+;J]MEV^"UL-MQVVW;T;7EM7S;Y[5XV]RUUK7>M=.UY+5YVV?;>]MBVZ;;
MKMM?V\??W=]5N,S?RM^UWZFXQ=_9W\'?L;C8W[_?X[7/W\#?UM^PN*BXJM^R
MW\O?P]_<W\;?MKC7WZVXR=_1W[;?T-_AW['?TM_?WZO?V[6YW[C?K[B\W[[?
MS=_>W[*XL[BPWZNXM-_:W[2XK+BNN+6XX-_3W\[?N]^ZWZJXK-^GN,3?K=_"
MW[??V]^FN+/?K]_5WZ[?8+O3X\+CK./*XUB[N^/%XUN[ON-9NZ_CS>.NX\'C
MK>._X\CCQN.ZX[7CL^.TX\?CTN.\XUJ[M^/+XUV[MN.PX\#C8;M5NUZ[N..R
MXU>[U-]6N\/C5+MCNUR[Q..YX['CS..]XV*[T.-?N\_CR>/.X]'C<^=TYV?G
M9N=BY[2]K+UVYW7GJ=]?YV/G7>=PYV'G=^=:YUCG9.=NYVGGMKU/YVWGM[V]
MWUOG4N=5YWOG7.=3YU'G3N>PO67GK[VSO6#G:.>IO7CG?.>KO5?G:^=OYU3G
M>>>RO;&]3.>UO7+G5N=JYU#G7N=9YZV]KKULYWWG>N=QYTWGJKU)ZT#K0^N[
MOT7K^>I!ZT?KN+^\O[:_^^I,ZT;K_.I5ZT_K^.I&[O[JM[]*ZU3KO[]1Z_WJ
M1.M(ZT+K5NM3ZU#KN;^ZO[Z_^NI7Z[V_3>M+ZT[K4^Y`[D7N4NY$[OOM0>ZB
MP?3M3>Y/[O/MH<%1[DGNJ,%0[D+NJL'Y[5+K2NY'[O7M5>ZDP:7!]^U([E3N
M2^[][:?!H\%,[O[M5N[X[4/N3N[Z[?SMR\+V[:G!Q,)^P:;!R,*S\*GPI/"J
M\+3PN/"W\,K"R<*K\+GPKO"F\*CPI_"M\++PI?"L\+'PQ\*O\,7"L/##PL;"
MU?*U\,+#S?+1\LGRS/+4\L##V?+2\LKRVO+3\L/#Q,/7\LORO\/!P\;RSO+(
M\MCRUO+'\L_ROO3%P]#RI\2IQ*;$P_2[]+GTO?2Z]+_TP?2JQ*S$P/2MQ*O$
MPO2HQ/3$\?7W]?;$O/3V]?WU]/7[]?KUN/3U];;P_O7S]?CU_/7R]4KW]<3Y
M]?3W2_=)]T?W2/=,]]G%\O?P]_7W\_?V]]K%\?>\^$7Y1OE'^<?YO?E/RNJJ
M:*VXT[?30+!"LWS7>]?JM;BXM[BYN-3C?N=8ZUKK6>NKP5?NNO"E^>2FR<W*
MS<C-Q\WKJJG0I]"FT&FM:ZUJK:C0Q-/!T[_30;#"TT:PO-/+T\W3O=-#L,[3
MR=.[T\#3RM/&T\/32+#,T[[3Q].YTT>P1+#%T\C3NM-%L$*P3+.EUTNSJ->K
MUTBS1K-^UZG7I]>DUZS7K=>OU[#7?==%LZ+7H=>NUT>SH]=)LT2SIM=-LTJS
MJM?QM;_;M-ONM>??O=NQV^RUMMOOM;K;N-ORM>NULMNUV_"UL]N^V[S;M]NY
MV[O;[;7HW^[?Y-_JW[JXYM_`N+^XOKCMW\&XPKCCW_#?P[B]N+RX[-_$N.+?
MY=_OW^O?]./IX[NX:KO=X_+CWN-EN]OCY./<XV>[UN/QXVB[[N/OX]?C;;OF
MX^#CY^/:X_/CZ^/EX]7C:;OLXVR[\./JXV:[Z./BXV2[V>/AX^WCW^/CX\&]
MZ=^RY[OGL>>MYZKGPKVHYVN[H>?`O:?GO[VLYZGGN>>TYZ[GL^>[O:OGON>B
MYZ/GNN>\O;_GOKW`Y[#GV..VYZ_GN.>UYZ;GN;V]Y[J]I.>]O63KM^>\YV'K
MN+W`OVOK9^MEZV#K;^O$OUSK:.MIZU_K7NMLZV+K7>MCZV[K6^MMZVKKPK_!
MO\._9NO+\%GNL<%=[EKN8>YG[ESN<.ZNP6KN7^YK[F;N;>Y>[K/!LL%@[F[N
M6.YL[JS!9.YC[FCN6^ZPP;3!8NYI[K7!9>ZMP:_!Q_#%\,SPR?#-\+[PQO#1
M\&_NPO#/PJ7GO?#*\,3PP?"\\+OPT/#`\+_PS<+(\,S"SL+#\,_PWO+?\LG#
MW/+&P^3RRL/F\MORSO#H\MWRQ\/C\N7RX/+G\N+RX?+(P\7TQO3(]*[$K\3)
M],?TQ/1"]D7V0?;ZQ$/V^<3XQ/?$1/91]T_W3O=`]E#W1O9-]_GWU_?W]]O%
M^/?Z][_X^L6^^+WX^\5:QF[YI_FF^:CYY::JT,_3T-/`VT?VP/CFIFRMJ]"Q
MUTZSPMO!V_.UQ;C!Y\.]Q+W%O_S%YZ:LT.VJKM"MT&VMT=/8TTFPUM/4T]O3
MTM/3TTJP3K#<TTVPVM/7T]732[!,L-G34+.RUU6SPM=4L\37N-=2L\/7L]=3
ML[_7N]>]U[?7OM=/L[K7N=>UU\#7O->TU[;74;/!U_:US=O)V\O;QMO%V\/;
MRMO,V\C;Q]OTM?6US]O-N/+?^-_SW_3?^=_/N,>XSKCQW\3;RKC(N/??]M_)
MN,NX]=_&N,RX]N-TNT+D0>3[XW:[0.3WX_CC;KMPN_WC]>-RNW&[^>/^X_SC
M<[OZX\[;;[O"Y\GGQKW-Y\J]Q>?#Y\SGQ;W+Y\>]R+W$Y\F]RN?&Y\?GR.=U
MNW#K?.O*OW?K>>O(OW'K=>MXZ\:_R;][ZW/K=.MZZW+K=NO'OW+N<>ZWP7?N
MN<&VP7/NNL%T[G7N>.ZXP=;PV?#3\-7PU/#7\-CP=N[2\,W#[/+O\O'RZO+K
M\N[R\/+.P\S#R\/M\NGRRO2PQ,OT2?;[Q$OV_,1(]DKVJ,52]Z?%_??\]_OW
M2/E)^4OY2OE0RNBF;JW%U_>U^M_0PO+RHZA7LU:ST-OXM=+;T=O[W]"X0^1&
MY$7D1.3.Y]#GS^?,O\N_N\%Y[GON>N[1PO3R\_+,]+'$_<14]U/W6\:DJ*_0
M;ZW(U\;7Q]?4V]7;0^#3V_S?0>!`X$+@T;C^W_W?1.!)Y$?D2.33Y]'GTN=]
MZWSN?>[2PO7RS?2RQ$SV5?>IQ?[W3/FEJ'&M<JVPT+'0<*U4L%*P4;!8L%"P
M6;#=TU:P4[!7L%6P3[!?LUFSS-=>LV"S6K-;L\K76+/+UUVSR==<LT2V1K;8
MVT6V^;7]M>2X2>#:V_ZUW=O>VT.VX-OBV^/;U]O6V^3;0K;AV]_;0+;[M4>V
MV]O<V]G;0;;\M?JU2.#?N-JXU;CEN-:XTKCAN-ZXX+C7N-RXT[C4N%#@3>!%
MX$K@XKA1X..XV;A'X$_@2^!.X$S@W;A&X-BX3.1XNWN[3N2ENTWD?;O/O4_D
MI+M+Y*:[>;O;N'R[>KM^NZ*[=[NGNZ.[H;M*Y-:]TKW9O=;GVKWBY]OGR[WC
MY]WGU;W>Y]2]X>?.O=_GU>?-O:KKT[W0O=B]U.?8Y\R]U^?9Y]KGU[W<Y^#G
MY.?;O=*_I>NKZZCK?NNLZZ'KI^O-O]._K>O/O]F_U+^OZZGKT+^BZ]J_H^ND
MZ]N_V+_1O<Z_L.O<O]6_KNO1O]:_U[_#P:3NK>ZJ[JSNP,&E[JONO,&G[L3!
MH^ZH[J_NINNI[J+NO<&A[K[!L.Z_P:[NPL%^[L'!IN[<\.KPY?#G\-OPT\+:
M\-;"U<+I\.'PWO#D\-WPW_#H\.;PU,+M\.OPXO#L\./P^?+/PT'S3_;6P^#P
M]_+2P_CR_?+4P]7#]O)`\T+S^O+\\O[R^_)#\]'#U\/3P]##T/2WQ,[TTO33
M]+7$U/31],_TN,2TQ-7TML2SQ/[$0,5.]DWV4/91]D'%5O=;]ZK%6/=7]UKW
M6?=#^-S%0OA`^$'X_L7]Q<'XPOA`QDWY3OEGQFW&J?G(^::HS=?.UU+@4.3E
MY\;!Q<'N\$3S1/BGJ-[36K!ALU3@4^#<O>;GW;VQ[M?"=L:HJ,O-W]-BL\_7
MT-?EVTBVYKA6X%7@5^!1Y%+DJ+O=O]Z]WK^U[K+NM.ZS[L?![_!&\T7SI,M<
ML%NPX-/1U^?;YMM)MEG@6N!8X.BXY[BJNZF[Y^>SZ['KLNO?O[?NMN[R\/'P
M\/!'\ZKYJ:ASK72M7;!>L.+3X=/2UVBS9K-CLV>S9;-DLTJVZMOMN$RV4;;L
MVU.V4K95MNO;Z-M/MDNV3;;IVU2V4+9.MN^X[KCLN/"XZKCKN.FX6^!4Y*R[
MK;NKNU/D5>3JY^SGY[WMY^"]Z>??O>F]Y;WFO>*]Z.?AO>[GZ^?HO>.]Y+VU
MZ[?KMNNXZ^"_M.O+P;CNR,',P<K!R<'S\/;P]?#T\-C"2/-)\]C#2O/9P[K$
MN<12]D+%4_9<]ZO%K,5%^$+&JJAJLVFS7.!=X*Z[N>OJO;KKN>ZKJ++0=JUU
MK>/37[#DT]77U-?3U^[;6+;MVU>V[]M6ME_@8N!@X&'@9>!>X&;@8^!DX+"[
M5N2ON_+G\.?KO>_G\>?LO;OKO.O-P4SS3O-+\TWSUO14]F_YK*AWK>73Y]/F
MT]C7;+/6UVNSV=?:U]?7^]M@MO/;^=M;MEZV\MM9MO;;;.!=MO';]]OTV_K;
M\-OXVURV7[;UVUJV\KAHX/&X;^!NX/BX^;APX/.X;>#WN'+@:>!KX/2X9^!J
MX''@];ASX/:XL;M;Y&'D6>1BY%CD7>1CY&#D7^1>Y%?D7.1:Y/&][KW[YT'H
M0^A`Z/CG^N=%Z$+H_.=&Z/GG1.COO?6]\[WSY_2]\+WTY_;G]>?]Y_[G\KWM
MO??GQNOBO[WKX[_FO\+KO^OEO\/KQ.N^Z\?KP.O%Z^2_X;_!Z[_NT,'.P='!
MS\&^[KONNNZ][KSN1?'>POOP^O#9PD'Q0/'W\$/Q_/#=POGP0O'X\-K"W,+]
M\-O"_O!$\5+SWL-/\U/SV\-1\^##W<-0\]_#5//:P[S$OL39]+W$U_3<P]CT
MN\1#Q47%5O9$Q57V8?>MQ6#WKL5>]UWW8O=C]T;X7_?&^,/XQ/C%^%S&4?E0
M^4_Y</F^^:OY;L:MJ&"P^KCVO<CKW\)5\ZSYKJCNJGFM>*UCL.C38;#ITV*P
MW]?;UVVSWM?=U]S7;K/@U^'70]Q!W$7<1MQ,W$C<2MQ"W/S;2=Q+W$3<1]S]
MVV*V0-S^VV&V8[;]N'7@=^!VX'O@^[AXX'3@>>!ZX/RX_KA\X&?D9N1DY&7D
ML[NUN[*[M+M-Z$[H2>A*Z/B]_;WWO?Z]^;U+Z$SH2.A`OON]^KW\O4?HRNOH
MO\SKZK_/Z\OKR>O.Z^F_S>OGO]/!UL'![M3!P.[2P=7!1O%'\4CQX,))\>'"
MXL-8\UGS5_-6\UKSX</=]-OTW/3>]-KTW_18]EGV5_9&Q63WK\5E]TCX1_BO
MJ&2V0+FVN^R_Z[_CPWS$1\6PJ&2P0;E;\Z;+L:BTJ+.HLJBER\W-S\WOJO&J
MS,W.S?"JT<W0S=+-MM"TT'RML]"CK7ZM>ZVDK7VMHJVAK;70>JUJL.O3\=-G
ML&ZP:;#NT_#3;+#JT^W3:+!EL.S3:[#OTVVP9K#CU^;7<+-ZLW:SY-=^LW>S
M?+-RLV^S<;-]L^77=;-XLW2S>;/GUWNS<[/BUTW<9;9/W&>V:;9.W&:V:K9H
MMD>YH^!/N7[@4+E%N:'@2KFBX$.Y0KE-N4RY2[E)N4ZY?>!$N4:Y2+FXN[N[
MO[NYN[Z[O+NWN[V[NKM2Z$.^0;Y3Z$2^0KY1Z%#H\+]/Z.Z_[;_0ZT6^[[_1
MZ_*_TNOQO]C!P^[7P=S!VL';P>/"V<'"[M/KXL+DPN3#Y</@]-[%W<6VJ%7*
M;[!2RE/*4<I4RJK+I\NLRZC+MZBZJ*G+N:BKR[BHU<W7S?2JT\W6S=3-\JKU
MJO.JN-"\T+G0IZVHK;O0O="_T*6MOM"FK>[7NM#RT_O3^=/TT_73^M/\TW&P
M]]/STW"P<K#VT_W3^-.AL_'7Z=?OU_#7HK/HU^K7M]#LU^W7Z]=LME;<U.M7
MW%3<H[-NME/<6=Q8W&NV7-Q2W%O<4-Q:W%7<;;:JX*7@J^"FX*3@I^!1N:G@
MJ.!2N<&[P+MNY''D:>1MY,*[;.1JY'#D:^1HY&_D6>A(ODKQ5NA7Z%7H4=Q'
MOEKH5.A&ODF^6.C5Z_._UNO7Z\3NW<%+\4SQ3?%=\USSXO3A]%OV7/9:]F;W
ML,6[J*JMJ:UUL'2P0-1!U/[3<[#UU_;7\M>DL_/7]-=?W&'<7=Q@W&^V7MQP
MMG/=5;E4N5.YK."MX'/D=>3&N\.[Q;O$NW3D<N1AZ%[H7^A-OF#H6^A<Z$J^
M2[Y=Z$R^V^O<Z]GKVNOTO]CKR.[%[L?NX,'+[M_!R>[,[LKNQN[>P4_Q4/%.
M\5+QY<+FPE_SY\-1\5[SYL/E].;TO\3D]./T7?9(Q4GXR/C'^$/&7<;)^''Y
M;\:\J/:J5KG`Q+VHJZVELW&VY\+WJL'0P-!"U'BP=K!ZL$34>;!WL$/4J+/\
MUZ>SJ;-"V*NS_M=`V/?7JK-#V/G7^M?XUZ:S0=C[U_W7;=QLW&K<8MQQW&7<
M;]QVW&[<>;9UMF/<:=QWMFC<>+9ZMFO<<K9SMG?<==QTW&;<<MQVMG2V<]QD
MW&?<<-RZY+?@L.##X,S@L^!AN<#@5[E9N66YL>!:N5RY9KE;N62YN>"NX&*Y
MN.!>N<K@8[G(X+S@QN!@N:_@R>#$X,O@6+EGN5VYM>"]X,'@Q>!?N;3@LN"^
MX+O@NN"_X,+@Q^!XY,>[I.1ZY,R[T+NMY+7DIN3(NZKDMN#)N['DMN2NY+#D
MN>2RY'[DJ>31N\V[?.2KY,N[I>3*N[/DHN1YY,Z[N.1[Y*_DK.2GY'?D=N2A
MY+3DS[NWY'WDH^12OEJ^5;ZDZ*'H9^A0OD^^5KYEZ%2^<>ACZ&3H3KZCZ%B^
M=.AYZ'/H[NMOZ'?H=>AHZ&+H?>A7OG[H>.AMZ&OH9NANZ'OH:NAZZ*+H4[YV
MZ'SH<NALZ%&^J.1PZ%F^:>CTZ_>_\^OPZT3L^[]![/CK0^SIZ_;K_;_AZ]_K
M0NQ`[/[K[>OLZ^+K0,#HZ_+K_>M#P$7LZ,%%P/Z_YNOOZ][KX.OUOT+`^K_G
MZ_?K\>M!P-WKX\'YZ_SK_+_KZT3`^;_XO_7K^^OVO^3K^NOEZ^KKTN[7[N7!
MY\'=[N'![.[C[MCNV>[B[N[!X>[1[N#NU.[M[NW!Z\'5[NCNVN[G[NGNT.[F
MP>KNWN[JP=ON[,'D[N3!UN[E[M_NX^OF[M/NZ<'K[N+!SNY@\5GQZ<)4\6/Q
M6_'<[F7Q5?'HPE_QZL+RPO#"8?'QPE?Q6/%=\6+QS>[KPFKQ9_%K\5[Q6O%H
M\6KS7/'NPNW"S^[OPF3Q9O'LPFGQ4_%6\7/S8_/KPW'S8?/LPVSS://QPW+S
M8O-E\^G#=/-M\W#S[\/TP_+#:?-D\^W#[L-@\^K#Z,/PPV_S\\-K\W7S]<-G
M\V[S\_1"]?7T_/1F\_KTZ?1`]</$[?3^]/3TPL1$]?;T^_3]].?T0?7R]/?T
MZ_3O]$/U^?3H].ST[O3X],'$\?3J]/#T8?9F]D_%:/9)Q63V:O9.Q4K%2\5@
M]F?V3<5E]DS%7_9C]F+V7O9I]K'%;?=P]VSW;O=O]VGW:O=G]VOW:/>RQ;/%
M2_A-^$SX3OC@Q4KXW\7AQ<OXS/A$QLKX4_E2^53Y7\95^5[&5OER^77Y=/EH
MQG/Y<L9PQG'&=\;`^<'YO_G)^?BJ1-AXW*7H=O/YJJRM>[!%V$;8K+-]MGK<
M>=RCMGRV>]Q^MJ*VH;9[MFBYT.#.X,_@S>#2N]6[U[O6N].[U+NGZ*;H6[ZH
MZ*GH7+Y-[$OL\^Y)[$KL1L!&[$[L2.Q,[._N\>[R[O/![N[RP?#N[\'PP?'!
M1^SUPF[Q;/%M\?/"]L+TPG?S>//VPT7U1_5&]<3$4,5M]FSV:_;ZJJK)6,KI
MIE;*6<I7RJ[+P:C"J+#+OZBORZW+P*B^J-C-V\W]JMK-V<W\JONJ0*O<S?ZJ
MQM"NK:^ML*W'T,/0K:W$T,70PM"DL*&P1=2BL*6P1M1^L'RP?;"CL*VS2=BU
MLTC82]BQLTK8J[:OL[*SKK.SL[2SL+-'V*>V?=RCW*+<K+:HMJFV?-Q^W*'<
MI+:FMJJVI;;3X-'@TN!JN6NYU.!IN=B[VKO9N[ODO.2KZ*KH1\!(P$_L2<#V
M[O3N]>[TP6_Q]\/UP4&KIK!'U$S8MK.MMJ3<IMROMJZVL+:QMJ7<;KEON6VY
MV[MLN=7@W+NLZ%#L2L#VP7#Q=/'YPG'Q^L+XPG7Q^\)S\7GS]\+XP\WX0JNX
ML[>SLK:HW*?<L[;9X'.Y<+G8X'*YUN!QN=?@O>3=NZ_H7;ZMZ%Z^7[ZNZ&"^
M4>Q.P$O`4,!3[$S`4NQ/P$W`^>[[[O?!^N[XP?CN]^YW\7;Q_,)X\7[S^L-]
M\WKS^<-[\WSS2/5)]<7$4\5N]E'%4L5O]K3%M<5Q]T7&S_A'QL[XT/A&QE?Y
MK?E#JW2YON2PZ%'`4L!$JV&^^\.QK5/`XL6RK4W8J=RKW*K<W>#:X'6Y=KG;
MX-S@P.3%Y-Z[O^3!Y,CDP^3'Y,3DPN3&Y-^[L^BQZ&.^8KZRZ&2^5NQ5[%3`
M5.S\[O[N0>]`[_G!_>ZA\?W"??&B\?[">_%^\7SQ>?%`PWKQH?.C\Z+S2O5+
M]7#VM\6VQ4_X4/A(QM'X:<:SK;2VRN3)Y+7HM.CZP4/O0N^E\:/QIO&D\?S#
MI/.E\Z;S<?9R]]+XM*U7[$3OM:W@NUCL0<.G\?W#3/5-]53%4?BVK;NSO+-.
MV+6VMK:LW+>V>KE\N=_@X.#>X'>Y>+E[N7FYR^3AN^*[O.AGOK?HMNB[Z&6^
M6\"XZ+WHNNBYZ&:^6<!:[%7`6^Q9[%C`5L!:P%?`1>]*[T;O2>_[P=3M2.]'
M[T3#0L-%PT/#J/&I\:KQ1L.J\T#$J/-!Q*?SJ?/^PU'U3O5/]5#U<O96Q57%
M=/=S][C%X\5)QF#&6/FN^:_YMZVMW.'@S.3-Y..[Y+N^Z&B^_,&K\4?#K?-"
MQ*SSKO.K\W7V4O53]<;$=/9S]G7WL/FXK;FMI[!(U$_8N+:[MKFVKMR]MKJV
MO+9^N>+@X^#`Z'VYH;FBN<_DSN3EN^:[T.2_Z.B[:;[GNUS`P>AKOFJ^PNC%
MZ,/HQ.ALOF'`7\!>P%WL8,!<[$OO7NQ=P%_L3N],[TWO4N]+PU'O5.]3[U#O
M3^_]P:[QK?%*PTC#2<.L\;'S0\2P\Z_S1,18]5?U5?54]<C$Q\19]7;WN<5W
M]E?%=O96]7?WY,5AQEGYL?FZK5#85>^[K=+DT>1@[%?O5N],P[+SL_/)Q++Y
MJ+"_MKZVY.#FX*2YY>"CN:6YY^#4Y-;DU>38Y.F[U^33Y-GDS.C/Z-'HQ^C+
MZ,CH;KYQOG.^R>C*Z'*^S>C0Z,[H=+YPOL;H;;YOOF/`9NQD[&/L:>QH[&?L
M8NQBP&'L9>QDP%KO7N];[UWO7.]9[U_O8N]@[V'O0,+^P5CO8^^S\;;QN/&W
M\;'QM?&P\;+Q3<.O\;3QP/.U\T7$1L2T\[GSO_.W\[[SN_.Z\[WSN/.V\[SS
M8/5>]<K$7?5C]6'UR\1<]5KU6_7-Q%_US,1B]7CV?O9Y]EO%H?9:Q7WV?/99
MQ7OV6,5Z]GWWH?=^]WOWN\5X]WSWH_>B]WGW>O>ZQ5+XY\53^.7%YL73^$K&
M=OEJQK/Y:\:T^;7YP_G"^7K&S?FIL.G@Z.#JN^N[VN32Z&SL=;YEP&KL;>QF
MP&3O:^RY\4[#P?-F]63U9?6B]ES%I/?JQ;S%Z,7IQ=3X8L:JL+KQ2=2FN=OD
M[+O<Y-3HT^AHP':^=[[7Z-;HU>AN[''L<.QO[&?`:.]F[V7O9^]/P[SQO?%0
MP[OQP_/"\\7S1\3$\V?U:?5H]:/VIO:D]J7VI?>]Q53X5?A6^$O&8\:V^:NP
M>+YIP+[QIO?$^4K4>\:LL'+LO_'&\Z?VI_>ML-WDWN3MN^Z[V>AZOGF^V.AI
M[\#QPO'!\5/#4L-1PU[%J/9=Q:GWJ/=,QM7XO;/JX.'DW^3@Y.+HW>C:Z.'H
MX^A\ON#HW.C;Z-_HWNA[OGWL>.QV[*'L=^QS['GL=.QR[W7LHNQ\[&K`>^QZ
M['[L:N]M[VSO=.]O[W/O<>]P[V[O:^]#PD+"1,)!PG7OR/'+\<GQS?'.\<;Q
M6,/'\<7QS/'$\</Q5\-5PU3#RO'/\]7S2L30\]/SU_-+Q-+SRO/)\];SS?/+
M\]3SS/-)Q$C$Q_/(\]'SSO-L]6_U5L-M]7/U<?5K]7;U:O7/Q'+U;O7.Q'7U
M=/6K]JKVL?:M]K#V8,6N]J_VJ?:L]E_%O\6T]Z_WL_>V][+WKO?!Q;'WM??`
MQ:SW</6P]ZWWJO>K][[%6OA<^%_X6_A@^%GX5_CKQ5WX[<7LQ5CX7OC:^$W&
MV_C9^-;XV/C7^%KY7/E;^7GY>/EW^7KY<\9TQLKYSOF^LZ_<[>"GN>O@[.#B
MY./D\;OON^3D\+OHZ.OHY>CLZ.3HYNCGZ.KHH;[OZ.[H?;[IZ.WH?KZL[&_`
MI^QKP*3LJNRM['#`J>RF[*[LI>RK[&S`H^QMP&[`J.RI[WKO>^]^[WSO=N]Y
M[Z7O?>]%PJ?OI.]&PJ;O=^^B[Z/OH>_2\=3QU_'1\5G#V?'0\=KQUO'8\=SQ
MU?'=\=/QS_%:P]OQ6\--Q'CO\?/H\T_$Y/-0Q.WSY_/=\T[$ZO/E\^;SV//?
M\^[SZ_/C\^_SWO/9\^SSV_/I\^#S\//<\TS$VO/A\^+S??5[]:+UKO6E]7SU
M>/6G]7[UH_5Z]:KU=_6A]:;UJ/6K]7GUK_6P]:GUK?6D]<'VQ/9AQ</VR/;&
M]F+%O?:S]K+V9,6_]L#VO/:T]KGVK/6U]F/%N_:Z]K;VPO:W]KOWQ?;']K[V
MN/:\][[WN/?"Q<7WP_?#Q<+WP?>Z][?WO??&][GWO_=I^&[X9/AG^.[%:_AR
M^,#W9?AO^'/X:OAC^&WX;/AQ^'#XQ/=H^&+X9OA.QD_&8?CF^-WXY?CB^./X
MW/C?^.?XX?C@^-[XY/A=^5[Y8/E?^6+Y8?E\^7OYM_FX^<7Y>,9\QL_Y?<:_
ML]#$R?90QE'&P+/NX*BY\.BP[+'LK^RK[ZKO1\+?\:SOWO'S\U'$4\3R\U+$
ML?6S];+URO9EQ>_%Z/AC^=+YP;/EY**^L^RR[*WO5,31Q,?WR_G"L_*[H[[T
M\W3XP+:N[V3&P;:DODC"=?C"MO'H<L"T[+7L<<"O[TS"2L)+PDG"X/%<P[7U
MM/6W];;UTL3+]LWVS/9FQ<CW=OAW^/#%9/E]^77&L-RV[+#O]?/OX+'OXO'A
M\7CX4L9E^7[YJ;GRZ//HM^RJN5W#X_'/]F?%T/;.]GGXZ?BKN;3OL^^R[^3Q
MZ/'G\>;QY?%>P_;SN?73Q+CUT?;+]\KWQ,7)]WSX>_AZ^/.[N.Q-PO?S^//,
M]WWXZOAF^;GYU/GTNT["Z?'Y\]+V?OBFOK7OZO'Z\_OS_/.^];KU:,6]];SU
MU,2[]=;$U<34]M/V:<5JQ<;%S??%Q:/XI/BB^*'X5,;K^.SX[?A3QF?Y:OEI
M^6CYT_ESP&7#O_75]L?%SO?5^73`MN_/]Z'Y2LG\W4JA5Z%9H5NA7Z%@H6.A
M9*%GH6BA:Z%LH6^A<*%SH72A=Z%XH7NA?*'&H<>ARJ'+H<BAR:%<H4VA3Z%1
MH5*A4Z%4H7VA?J&AH:*AHZ&DH<RAS:'.H=ZAWZ'@H>&AXJ%,HDVB3J))H:VA
M0Z)(HJZA7:%>H:^ASZ%!H="A1*%!HJ^BL**QHK*BLZ*THK6BMJ*WHKBB1Z%&
MH=6AUZ'6H4BA2:+/HM"BT:+2HM.BU*+5HM:BUZ+8HMFBVJ+;HMRBW:+>HM^B
MX*+AHN*BXZ+DHN6BYJ+GHNBB0J+$H>FBZJ+KHNRB[:+NHN^B\*+QHO*B\Z+T
MHO6B]J+WHOBB^:+ZHONB_*+]HOZB0*-!HT*C0Z-AH56A8J%.H0``````````
M`````````````/TT``#]-```_30``/TT^_\,-1_^&#7U_B4U?PXO-0``+S4`
M`"\U```O-0``+S4``"\U```O-0``+S4``"\U```O-7K_/#7__TPU__]<-?^7
M:37^_W@U_S^&-1``^S0`,/8!B_\"`G/#"P)`:`\"#QL7`JSI(`),\RD"``(J
M`@C`+0)<>38"/LH_`G9Y20)(!DT"WR]9`O#W9`(Z`VH"_ZAU`C?O@0(_(XH"
M!+".`EG]F0+*\Z,"__^S`I_>OP+Y_\T"_ZO:`O=]YP(`P.D"[([R`K_N_P+;
M_PT#`]`2`_I%&P/A^B4#_M\S`^^_00.K$$<#Z_]5`ZK\7P,_[VP#_21U`ZUX
M?@-V?XH##/"0`__MG@/VSZH#^BRS`_GWP`-KZ\L#_1_7`[^5X@-W9NP#O[_Z
M`_L[!@2T_A$$KGL<!.(1(@2!IB@$OD$P!#44-@3#<CX$<'U'!)%Q3@0#`%`$
M:R=9!,M78P3/<&P$,D=S!.\-?03:?H@$=/R2!`;^FP2TO:4$GS^Q!,J+N01)
M?L($`%C%!(\BS`3LZ]<$7(K>!+O=Z@1@[_,$Y[;^!`^D!063\@X%NS<9!9Y4
M(05+T"@%KYLS!13$.`74]T,%L#!(!10*3`4(+U(%T(A7!7[_904O&6T%VO]Z
M!0?[A`7Q?Y`%ZWN<!>_%IP40`*@%_YFT!?_]PP77><X%9P75!>?_XP7+_>\%
M_\/[!4!`_07W;PH&CKT4!OK?(0:7!"<&P/0N!O];.P9[[4<&Y]!0!GX$5P;@
M^%\&G_]M!CZW>`;^?84&+HB+!OW_F@9_OJ<&_H.Q!L3VN@97\\4&_;C0!H#6
MU@9][^,&9U?M!HA'\P9]_P$'W\,,!__P&`>I-R$'X'TJ!_QP,P=O/S\'FNQ(
M![-,4`>!AE4'GC]@!US=:@<-]W0'&4AY!Z/^A`<'`(<'5J^1!_\XG`<-F*('
MN.^M!SU`LP=@M[L'SMC$!S60R@>_<M4'_S_C!_=_\0<1>O@'N_<%"/^K$@@`
M_QH(OF\F"#RI+@AR_CD([\]&"!OQ3PAKVUH("O1A".;#:@A^[W<(G)N`"!#V
MAPA(\(T(]!:5"+7^H0B"4:8(L<>O"+L5N`B';L$(W_O/"#_DV0C-8^((_\'M
M"'Y^^0CK_08)7WT2"7MW'@G^_"L)"Y8R">K;/0DI8D,)Z%-+"=\W5PGO_64)
M]39O"8&]=PD8W'X)O?R*">32D@G__Z()US^N">#_N0EO?\8)^*O0":Z;V@G9
M;N0)^_7Q"17Q^0FI>0(*^[T/"CQ:%PJOK2(*NMLM"JP?-@K\<4`*>8-("O=\
M5`I?PUX*_]]M"F<%=`J:_X`*9X2'"C05C0J+WY@*\_FD"G,SK0J]][H*&E["
M"D"_R@H_H-(*___B"NL!Z0K`W_(*W<_^"@!U`PO3JPT+P_@6"];N(0O]0RL+
M_[<Y"Z]>1`LG0DH+K)M3"X;V7`O7)V8+O/9Q"X?W?`NW-88+S:J/"W;AF`OG
M2:$+G^*K"UQ4L@ORK[T+/RO'"]AAS@L[_-D+N+OC"\__\0M]>_T+E;\(#.`<
M#@S]?1L,_T,F#/9?,@S^_T$,[]--#,[$50RVC5X,O*UH#-QC<0SK$7D,6=^$
M#-`CB@RTOI0,V_.@#.<?JPS'V[8,8__"#.3ZS`PKLM0,]V/?##OMZ@RZK?0,
M`?[\#/]^"@WW_QD-O`(?#?\R*@TY[S4-_/]##06`1@W[=U,-];Q>#0T!8@WW
M_W$-^_^`#3J_BPU7`)`-_]^?#7OOK`U]O;@-B-O`#=3(QPWS_]4-?.W@#>Y=
MZPW_5O<-#7X`#E^L"@Z6_Q8.?]4B#NX_+@Y`P3(.^6\^#N?_3`Z;=U<.=XYA
M#K]N;0Y=Y'8.SV^"#A]?C0Y_X)<.W_ZE#MO7L0[^`;D.`/_!#GO[S@[4_]H.
MWQ_F#@#XZP[___L.C_L'#WL`#0\`OQ0/7'\?#___+P_S!S@/H.M`#^<]2P^_
M]UD/U_MF#[__=0\#8'D/_?^(#^V_E0^[[Z(/?P*J#T#^L@_]W;\/__W.#_GB
MV`\+:-X/'_OJ#^/[]@_]KP,0I)\,$.WW&1!]>B00#_@M$+[N.1#5#T(07;M-
M$)_]6A#;\F40^3MP$'_^?A#,ZX@0:H>0$/ISFQ#\E:40_)^Q$)\0N!#W^L40
MM]W1$,V[W!!^^.<0S>SQ$&;S^Q`_/`41_?\4$3^P'1'WZ2D1?@8Q$:Z6.A$&
M_D,1=M5-$==?61'1/V,1\Z-M$0?/=A&W;X(1T9^,$41_E1%9>Y\1W=.J$3NO
MM1&]J;\1SWW+$3K_UQ'@^^$1Z_;M$0&T\A'__P(2^GH-$K^W&A(`P!P2_0\G
M$G__-A(?_T,2_/Y0$O^57!(``%P2W+5F$F/O<1(^/WP2?_N*$AL`CA(`Z)(2
M]ON?$N^>JQ+?N+82G__$$C\`RA+0>],2__7A$MO?[A+_/_P2\/T'$[\`#A,@
MA!$3O;L=$S??*1/>_S<3;?]$$_,/3A-,8%,3^UY?$_O_;A/[^GL37OZ'$QD"
MBQ/T>943WOFA$_>GK1/ZZ[D3ZP'`$S3_RQ/3Z]83<^_B$]>O[A-`P/$3NW+[
M$__<"!1_\104V"\=%.RX)A0+_C`4H]TZ%`L?0A0=CTL4ST=5%"NQ713>_VL4
M[G]X%'/:@A3_)(P4Q,N4%%WWH!3RRZH4_>RV%.VTP!3YO\T4W4W7%-V9X12-
M^^P4?[OY%'NO!17[W1(56<D:%4_\)16U^C`5XZ\[%5]M1A7__U85?3]B%0!X
M9A7;_W05_[:!%?]^CQ6O^YP5+P*B%9O_KQ7'[[L5I?_'%?__UQ4'`-H5`,??
M%?_W[A7Q__L5_7\)%K\!$18`W!86O/TB%O6_+Q;__S\6?_].%O\^6Q8I`%X6
M`+YD%O_Y<A9__X$6^VZ-%G[]FA;_RZ<6G@.N%@#CLQ;=^\`6_\S,%M_VV1;_
M_^D6?Q'R%@#X]Q;V^P07[^<1%SS7&Q?O_BD7[]\W%PO`/!>_[4D7W_Y7%\W]
M8Q?U>V\7_4!W%___AQ=?MY,7W_^B%S#YJA??^[@7E]S"%_/^SQ?RO]L7WX_G
M%[_?]1=_%P`8YNT+&'\/%AA3-1X8?$0E&'Z'+Q@2^C<8NT5`&.#M21B>=U08
M%X!9&-F_91A5?F\8B=YX&&_!@1A'!(88WGJ1&%WWG1C_5ZH8!2FO&/>&N1B5
M_L08LY?.&"_SV1C_S^<8=9_R&/=Q_1@7^P@9[C01&1GN&AG,-R,98>\M&=:?
M.!E,[T(9C]9,&=W[61ES>V09[VUP&?[7?1DQI(,9?UZ/&=>7FAE;#Z,9V/^O
M&8.=MQG.>\(9["+)&?_<UAD]=N`9A^_K&>??^!GM_04:_T\2&OR@&AIW.R4:
M_-LQ&NT]/!K<?T@:J6]2&G#U6QK[/V@:0"QL&G__>QI_A(0:5^R.&K?>FAJ<
MYJ,:+_*M&NL/MQJUU<$:ZZ_-&N?MV1HOC.$:\/_M&G]3^!KPZ``;G;D*&_^U
M%QMF_R,;C^<N&X'9-1L0OCP;?)Q%&\'C31O1G%4;,R==&[P,9!MM_W$;M_Q]
M&[?OBAO?H),;__^C&PN_K1M[_KH;_Z/&&S\UT!O,$]<;S9?A&S=VZQLG^_8;
MUL\!'&Q^"QQ0[!(<,>T;''QG)1P<_"X<^O8Z'+]?1QRZ#U`<+ZY:'*VC8QS^
M?W$<\/Q[''3>A1SO_Y0<`/*9'+_[IQRB_K$<KSV\'/^\R1R4]M(<N5_='*WS
MZ!R//_,<;/+\'!^@`QWO_Q(=OP$:'2AW(AT%<"<=-?\S'0/:.AWYTD0=^L=/
M';\_7!T=7&0=.O]P'3/L>1VOMX4=G/Z0'392EQV?>J(=^K^O'2+GMQWWG\0=
M__S2';LOW1T=MN8=!NWN'?T=^1W7?04>W^\3'B/K'!YF\24>V7XP'L`--1X]
M/3\>O]]-'D7)5!Z#NEP>T7UF'M"=;AZ'>W@><\^#'O.?CQ[UPYD>#=^C'O[%
MKAZS#+4>`H.Y'GGHPA[`KLD><\?3'@]OW1Y]_>H>/PGR'O'__QY7`04?^V(/
M'_\!&!^T_2,?\SLN'Q.P-!^R0SL?TUY%'S#_3Q__#UL?G^MG'^_^=1\#\GP?
M[S^)'XG[DQ^I-YP?F9ZE'_G>L1\LI[D?,S?"'_;!RQ\N@=$?/O[='R!=XQ_W
M\N\?A=7W']=I`2#__Q$@__\A(`?;*B!O_S@@_\1#('_93R#.[UL@#[YE('OQ
M<"!>\'D@S_:%(+?_DR#W7I\@A.^H(,O7LR#?#KT@"/_&(/_\U"`_[N`@___P
M(/\3^R#_UPDA#Z\3(?U_(2''O2PA^A\W(0``-R$``#<A```W(0``-R$``#<A
M```W(0``-R$``#<A```W(4#G/B$XO4<A,_E1(>M_7B'M_FLAZ']V(79\@"'W
MLXPA[_^;(:_^J"&WV+(A;__`(;_[SB'[^-HA]]OG(5(7[B'YXO@AR(7^(4=U
M!R*0D`LB[^,7(O2>(2)M/RPB+NXV(C8%/"*\]T@B\W]5(GN@72(_?VHB9P5Q
M(F#K>2*^NH0B`6:)(MC\DR(_6)PB]\JG(M^'LB+-O[XBH/_((LU;TB*__N`B
M_;;L(J?O^"+O=P4CG-\0([<_'"-W^"<C)YTP(_RW/".URD4C[]]3(UK[7B.V
M\6@C.>QQ(Q_O?2._^XLC^W^9(PT`G"/^VJ@C^[VU(W].P"/_,\PCP%K2(_6_
MWR/^G^PCO__[(U\``20```$D^/T-),K_&23];R8D_<\S)`&@-B3_WT4D\OM1
M)+_?7R1__VXDVOYZ)`\(?R0(NH4D_[^4)/UZH"37[JPDZ_NY)/EGQ"1$X,DD
MD__5))??X217G^PD]_[Z)-\(`B6`WPHEW_X8)<7_)"7^]S(E^_]!)0-H1B7[
M9U(E^FM=)?]_;"7B7W8E__^&)7/_DR7?AYXE^^>K)?WKN"6G]\0E?K_1)<?O
MW27S'N<E@M_P)?]V_25^WPHFR7D3)GW:'B:^[RLFFQXT)N!\/";[=TDFOH=3
M)OO_8B;_&VXFV_]\)EP_AB;@3XXF_W^=)@Y?IB;_=[0FO]W!)D_PRB;__]HF
M___J)O@/\R:^H_TFW_T+)QS\%"?]_R,G?1\N)Y[[.B?_O4@GW-Y3)V\_7R?[
MNFLG?]]Y)^_[AR<;?9$G["Z:)XZOI"?W\K`G#WNZ)^[/QB>6'<XGQG?8)P=^
MX2?U_^\G@MGV)]]_!"CF7@XH_\<;*.[^*"CO>30H5IH\*,__2BA?_E<H7MYB
M*&Z):BCH^70H7O1^*,3FAB@!`(<H?+Z2*'\[GBC?W:LHG=6U*._IP2BL-,@H
M4][2*'/UW2CW2^@H3WOS*/^>`"G^N`LI;D<4*?L-'BE%_RDI_:LU*?[[0RG7
MZ4XI_]U<*??M:2G_?W@I_=V%*>M^D2GGSYTI_[>K*>F]MBF1[\`I=5W**7S7
MU2D``-4I``#5*0``U2D``-4I``#5*0``U2D``-4I``#5*0``U2F`^MPI[O_J
M*?&T\REVO_\I[R\+*G>V%BJ_=R,JOY\P*OW_/RJ_E4HJKO95*O]U8BH[?VXJ
M]:=Y*OD*@2H``($J``"!*@``@2H``($JT/N+*MTKE2HS]I\J?YJJ*JO]MBK\
MUL$JYOG,*NN_V2K?W^<J'_3Q*OVF_"K__PPK_TH7*WOS(RNW?S`K^?X]*_^V
M2BM<'5(K]G]?*__E;"M['W<K!"1Z*P6^@BN>^8TKX]N8*_+?I"OO;[$K__W`
M*WG6RBO\R]4K_>OB*__O\2L?`/8K``#V*P``]BL`F/DK2.'_*Q>`!"QT:@PL
M_@`3+']M'RSQ_2LL?[@V+//^0RP?X$LL=O%5+);N7RP_>VLLC>MU+/W_A"S_
MK9$LL\N;+.^$I"Q_X:\LJDVW+/"_PBP_O\\L/_[<+/_KZBS7__@LW_\'+7_/
M%"W[_R,M[84L+3_7."V\!T`M_ZY-+0_^6"VO_64MOW9Q+>_Z?BV[-XDMW'^5
M+;JCGBW_MJLM]U:V+?A@O2W?Y\HM8?_5+=],WRW[L.DM1?_T+>U]`"[Z/PPN
M_Q\9+OP8(2[__S$NK^,\+M/'1BZ#WU`N5_M<+GWO:2[_[W@N>!-_+L#^B"[W
M7Y4NNS2>+N->J"X-][(N]N^_+O[7S"Z_`-,NG?7>+O?W["[>4?4NX/\`+\G^
M"R]_`Q0O`5\;+^^_*2_QGS0OIV`[+QWO1B__\5,O#P!7+P``5R\``%<O``!7
M+P``5R\``%<O``!7+P``5R\``%<O``!7+P``5R\``%<O``!7+P``5R\``%<O
M@#Q<+TW[9R\?V7$O.GM[+^/^AR_I/Y(O?]R>+S\`I"\``*0O``"D+P!0IB\?
M];$O![ZZ+QW\Q"\;^<XO'KS7+_]QXR_Y;^\OOEOZ+Y97`S`;FPPP_W\;,/S_
M*3`NAS$PYZ\],/7K23!/\U0P_=]B,"7G:S#<"W,P1%UZ,$=7@S#=_9`P/^V<
M,)!WI#!_?;$PR(JW,/KZPS#Y\\\P*B#3,$OOWC#_]>PPSWGW,-.K`3&E"P@Q
M>O<4,8_[(#&]CBHQ'P`O,0``+S$``"\Q`/,U,4[]0#%7&D@Q`(A*,:RN4S%4
M=ELQK1=D,?_-<3&R_WTQ+_2',:I;D#'_VYXQ`@"?,0``GS$``)\QP'.F,>KY
ML3$_+KLQCOK%,?^[TS&\=MTQT__J,?[N]S%R?@$RO7X-,O?G&C)_]R@R_<XT
M,O4//C(``#XR```^,@``/C(`J4(RF]M-,L>D53)_D5\RROAH,LY^<S)Z?7XR
MY\>),KW+E#*NW)XR?OVK,G:/M3+3D;TR\WS(,N4!SC(O3-8R=^WB,F"CZ#+;
M!_$R^%[[,O<=!C.!(0HSX&L2,YPP&#,Z.R$SWOHM,U-_.#/UPT(SS6%*,[H'
M4C,``%(S``!2,P``4C,``%(S``!2,P``4C/@)E@S_KYE,_D#;3.UZW@S;>."
M,\OIC#,OG)4SWK^B,X.?JS._J[<S]Q_#,]7_T#/?M]TS_M_K,Z[]]S/O_P8T
M?OL3-/WO(33_JBTTOVXY-```.30``#DT```Y-```.30``#DT(+8_-,U_2S2>
MOE8TLV)>-/%89C0-\6XT>_U[-/'IA33]OI(TP\::-&U?I30]_[(T_VF^-,__
MS#3T^]@T^]SD-/=/\#0`(/$T-Q'X-!4```````````````````````````#\
M`"__"0$W8!`!_@,9`0``&0'^_R@!__\X`?__2`'__U@!__]H`0]@;@'^_WT!
M__^-`?__G0'__ZT!__^]`7]`Q0'@_]`!___@`?\#Z@$``.H!``#J`0``Z@$`
M`.H!``#J`0``Z@$``.H!``#J`0``Z@$``.H!``#J`0``Z@$``.H!``#J`0``
MZ@$``.H!``#J`0``Z@$``.H!``#J`0``Z@$``.H!``#J`0@`ZP$``.L!``#K
M`0``ZP$``.L!``#K`0``ZP$``.L!``#K`0``ZP$``.L!``#K`0``ZP$``.L!
M`,#M`0!P\`$"`/$!``#Q`1!`\P$F````````````K````*P```"L````K```
M`*P```"L````K`#_`[8`\#_`````P````,````#`````P````,````#`````
MP````,``!1##`!$1QP`0$,D`$!#+````RP`!0,T``N32``\`U@#^_^4`,`#G
M``,`Z0`,,.T`P,CR````\@`\`/8```#V`&`"^0```/D```#Y````^0`'````
M`````````````'8```!V`!@S?`!D`'\`)$B#````@P```(,```"#````@P``
M`(,```"#````@P```(,```"#````@P```(,```"#`"@"A@```(8```"&````
MA@```(8```"&`/\#D````)````"0`,\#F````)@```"8````F````)@```"8
M````F````)@``,2;`"E.H@`P$*4```"E``0`I@##`*H```"J````J@```*H`
M(`"K``"```````````````````````D````)````"0````D````)````"0``
M``D````)````"0````D````)````"0````D`@`X-```"#@````X````.````
M#@````X````.````#@````X````.````#@````X````.`/[_'0#[`R8`_O\U
M`/L#/@```#X````^````/@`"`#\`\!](`/C_50#__V4`__]U``(`````````
M``````````````````````````````````````````````````````````"L
M``0`@P`'````!P"```@````(`(``V,99B%>(78A;B&:(88A?B&J(:(AOB&V(
MIXASB'&(=XAUB/O(>XAYB**(5HAGB%J(;(A<B&Z(<(C\R%Z(=(CZR'B(6(AI
MB'*(8(AVB'J(?(A]B'Z(H8CVR&N(^,CWR*B(_LCYR/7(_<C9QOG'\\?TQ_7'
M]L?WQ_C'^L?[Q_S'_<?^QT#(0<A"R$/(1,A%R$;(1\A(R$G(2LA+R$S(3<A.
MR$_(4,A1R%+(4\A4R%7(5LA7R%C(6<A:R%S(7<A>R%_(8,AAR&+(8\ADR&7(
M9LAGR&C(:<AJR&O(;,AMR&[(;\APR''(<LASR'3(=<A;R&.(I(AEB*:(TLC3
MR+7&ML:WQKC&N<:ZQKO&O,:]QK[&=\AXR';(H<:BQJ/&I,:EQJ;&I\:HQJG&
MJL:KQJS&K<:NQJ_&L,:QQK+&L\:TQOGY^/GF^>_YW?GH^?'YW_GL^?7YX_GN
M^??YY?GI^?+YX/GK^?3YXOGG^?#YWOGM^?;YY/GJ^?/YX?GZ^?OY_?G\^>;&
MULC7R-C(V<C:R-O(W,C=R-[(W\C@R.'(XLCCR.3(Y<CFR.?(Z,CIR.K(Z\CL
MR.W([LCOR/#(\<C-QN#&X<;BQN?&Z,;IQNK&Z\;LQNW&[L;OQO#&\<;RQO/&
M],;UQO;&]\;XQOG&^L;[QOS&_<;^QD#'0<="QT/'1,=%QT;'1\=(QTG'2L=+
MQTS'3<=.QT_'4,=1QU+'4\=4QU7'5L=7QUC'6<=:QUO'7,==QU['7\=@QV''
M8L=CQV3'9<=FQV?':,=IQVK':\=LQVW';L=OQW#'<<=RQW/'=,=UQW;'=\=X
MQWG'>L?4R-7(W,;=QGO'?,=]QW['H<>BQZ/'I,>EQZ;'I\>HQZG'JL>KQZS'
MK<>NQZ_'L,>QQ[+'L\>TQ[7'ML>WQ[C'N<>ZQ[O'O,>]Q[['O\?`Q\''PL?#
MQ\3'Q<?&Q\?'R,?)Q\K'R\?,Q\W'SL?/Q]#'T<?2Q]/'U,?5Q];'U\?8Q]G'
MVL?;Q]S'W<?>Q]_'X,?AQ^+'X\?DQ^7'YL?GQ^C'Z<?JQ^O'[,?MQ^['[\?P
MQ_''\L?CQMK&V\;1R'>2WY;5B<V3WYMH^MJ)68_;B5V/W(GWEMJ*W(O;EU.>
MJIWJFVZ*R(OHB>J)</OMB=V4[HFTGM.*VY+;E/F)>OO[B?R>_(F_B?Z)YHE&
MG>Z=?J!HH.F8:(O]C;Z+V9_KBM>?:HM<G+&+7OOSG="@9OSIDNR:JX](^D6.
M;YS>GN^)Z9:[GMZ4N)ZZEV7[UI6[G-J718]]^UB19/Y6F$V;6Y/'E>>769/U
MD;B7HOVV^_J25Y.FB[G[L)?$_:&<\I'YD?&/19=3F'C^P?M1DJV=;/UK^L*;
M>YI@BTN3O9JWD;25Q?[PGF2-:9)GC>K[[_MHC>N30OQFD<WZW9/,BVV-;HVH
MEJ;\;XUPC63\8)!TC<.7T(ITDKZ;R)RZG'B-N9Y:E;212(I]C7V*PHI*_:&-
MT8JT_$>+I)/:GE&*IHW%GL3\>*"UE,+\:XJKC>CZK8U)_,&3;Y"PC7Z4^I!Y
ME+*-[OQ[F;2-MXVSD;N-NHV\C4203/WDD^"34_W#C;B;\/OID_:3Q8W*C<R-
M7?VUDV']^)Q2DNB@I9S6C<"7WJ#2EZ7ZH_W;C:^.M9%)_=']ZXW&E\[]_)!9
M_-:6Q9?OC=>7\(VFEK_[\XU)E/6-<IAKCOWZ4(_,G67\;IFAE&./VJ!3DNG]
MM9UYF%V=8XUIEG"?:OS'BM>)3?[=GOO^O)C,^K"59)1OD[F4[)7ND<.8]I7]
MC\689I=N_MV7TI)AE\N8\)5=E^.1S)AIE,V8SIC\E:.48I:V_F.4T)C1F'64
MX/IRE-:8\(K9F-N8W9BHF&V*^XJNBLG[Y)CFF.B838I7DM^5K*#KF.R8])BX
MBN>>O)31_,:<?I[^F.C]0)G)E-.41IG`D-&4<Y7"DTB92YE5CDZ9_HY9CNR4
M[Y1TCU691)56F5F96YE%^K>00Y?-E<F74/VYCL:59YFYBOR-=HI1G7.93YUZ
MF625H9FEF:>9[8ZMF6Z4<(_0^K.94Z!<EGK]_I>]DOV79(_W_&*5S9=DGDR2
MR8Z\F:6=5(]\CZ*.>H^NE\B6PYG6D+Z<=H]PE$O[ROW'COF@J8_'F=>0WY[.
MF;J/ZX_/F<*/R9+<E[.5>9RRE=N/XYMZGNZ;WIGZ^N6>4HKAF6>*M8NLBNF9
MROO>E]&5]9E*_*F;W/M6_J2>29W;E<6)^)EDEE60U)9\ETV6X9=(FDF:??ZJ
MD%":1Y/8CLF059J\D%B:N(O5D$&66II<FL*7NXJJF_608)I%D6.:MHO/_&N6
M;II/D4:7YJ#7DG66U).[D7F6<)IXELV12IQOH&J@7Y&EG[J)S9YYFLZ=<YVY
MEKR6T9RWB>Z>0_O)GM/[KI%XG7N=LYZRGM:=3YG.B<"+Q)_4B[_&^8M&B<#&
MY?I[R,:+5YS[FM")SXG!QM&)XHE^DKJ=PL;X^\>+:Y+2B<^?J9W3B>*99Y*D
MDDZ)3XEXDK:1U(G2GZ>2HI5NDNJ6;Y*CDE")5_IFF-:)LIBKDMZ6K))NG_*.
M;)_8B5GZJ))CD7.?K9+IFZF2JI+9B5;]J)^ADN.0IJ"KE'+\Q)>NDF?ZHI)I
M^FB248EO^G'Z4HE:E,/&W8FBR,3&4IY3B56>NI+%QGWZJ/IHFD?Z?OJ[DK;]
MHOJC^J3ZM)NF^M^)V_VI^E2)J_IZ_.")3Y]]R.&)L/K-G^>@L?JFB?J>LOJT
M^L22;Y^PBZR?XXG3F^2)M?K5GU6)Q9)6B;/ZMOJW^MR>Q/MQG[KZQY+&QDR:
MY8E]GZF@Q/K'QE>)JOI8B>.+88OQFK>>R,;1^M+ZNI[4^MGZV_K@G/?[^OOG
MB7J@W/K=^NF)R<;B^NN)X_K(D-J268GUG%J)Y_JBG^KZ[?JMCUG[[_KOENR=
MRIUM_>R)1/OBG<">5IYYG\>:]/JAF/CZ\(E'GO>=TY_*FO&)^?I:CO*)\XE=
MDE&+X)+TB=2?>8KUB:>7NI-8GO:)5Y[WB4&*^(GQ^OJ)0ON_^J/[]_I.GMR4
MVI7XG6J?MXI&^T:*1_M(D=Z24XOVG=J;?IW]B>290Y[IG5*/]9WPG>>9O8OO
MG;>?T)WKGZF-SYWAF.6=R)U/^^N=5/M5^Z*:UHI?FO6>MX_2FFJ>Z)Z_B\*1
M8IU@DEZ2P9'%BJ.7;(M^C52<O9W%G%N)7/M;^U?[QYA:^^Z<XI*GE-2;9/MV
M^V#[Y9G"FON1<Z!RG\R?I9CHDKR;\Y;GDF?\?8OTF_>>P9YOF?&608Y*E>:7
M]9;FDD*?9_NIF>;Z:?OEEWV6;/NBF;N:99I.E&[[WYGCF%22>Y:OBJ^+O9[F
MGF_[X8Y]FWZ<V?GJDG+[<?M<B?"8\I9T^\&+78G>B5Z)RL9"_GO[7XE@B<V;
MTYU,F%*7PY6VF[F:LY=TG_&2WY>F^ZO[=YA4F,6559VR^WZ50I?FE/62_9*B
M^U&<Z91<F/"23)1KD7B+XI1/F+7[<9)EDUN84)B\E_.20)--F'*5[_W!_;K[
MZY)S_+>7M/NGD$&7])*\^W>5XIYXC]SY<I:UGDN6^J!UE=J09Y.D_M^05)-A
MB;2+P)U(CL7[Q_O+QGGZ9Y[2^V*)8XE]_&N?S/NN_M'[=?O4^];[V/M=BTR3
MXIK)B]O[R9]$G^V8W?ORC62)\OU-D^?[\J!HF%B?<XW>^]_[X_NHC>3[=9QX
MF&"-Y?MAC6*-H:!`G*V8ZI[KG.#[49]EC?&<6/QFC526Z/O,QLZ?_/ODFG6?
M\?MIC4^33I/T^\[&P_MEB6J-4Y/[G?W[69!`_$'\0_QADT;\8I-KC4S\N)70
MQLJ+>IC1QE'\5/RO^FR-8?I7_'";4:#+BVZ3U?RI_&'\9HG+^MKY>I/@H&N3
M:_S<H&B4;?QQC63]NIG0FF&:Y:!;H*R60)?QGGZ?<HUV_*F6;J"J_,W[=/QT
MH'&@>?Q\_%"<>9-XD]V@=8UVC723=XVE_*+\PY!YH'F-_(MVH,V+6I_TG[J?
M>HU%GK"3=:!&FZ[\L/Q1^GN-?(W6GJR36Y^IDWR@LOS!BK2?K/Q,GL6/K9/#
MG:*-2IVV_*.-2YY-GJ2-_8JU_,/\LI.EC:&3QHI;BDV)U/YXBJN3IXU%GU:*
MO_S`_.:.I(I#B?.3J_RBGL>=TL;.B\7\R_RSD\K\R?RLC<;[9XG-_/.<T/R[
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MF<^@;8^^F?2.<H_DE;^90I*E^\"9M/UWC\&9N?I`CT3ZPIE<C\29Q9E[CZ./
MQIG-EL>6I8^[^G"5:)-^CZJ/4*#3D%:5N(_(F:^/R9EYE4F?RIG+F7J5U9VP
MCWKZ7Y[-F<F@VYK&H+2/UZ#'H$.@M8^RCV&@7IZVC^B?LIQ\E<>?NX^\C^R/
MP(]JD^2+?)RAE>S^HY7!CU*@T)G#C\2/I)7&CV">V/FEE;.<T9GQ_M*9PIS3
MF:>5J96FE5V<XIC)C\*@RH_4F;F@6)O-C]2@SH_EBWF)T(^VE=:9Y977F;65
MRJ#]GUB@UH_8F=./Y8_IC]F9?))%G-Z/WX]+H.*/S*#CC^2/Q)O\FTR6]IKG
MC^B/YXMZB7N)VIGMC\"5RZ!(GMN9\X_YC\&53J#<F62@]X^PB4B@^X_VC]R=
MW9GHB\&2UI_2H$"0Q(K@F?"?\Y^_G?:?R)5:GN.92HKQGZ>*YIGWG^V?7(JN
MG<F52)#HF4F0L9!*D.J9T9OKF>R9[9GNF4R039#+E>*7S)5XGWR)?8E^B5V9
M6IM0D%20UL:HFN^9Z_ZCG:&=0YE%F7V=\)GQF?*98)VCH%N0VYYYG?.98I!5
MG_F;99#@EKZ8:)!LD-B5:I"RGZZ?L)^MB6Z0<9Y*GMR?JXFXGW"08XO<E7&0
M7OQ)B5N6II35CW.>=9#WF?F98Y:YE=24^OQWD*N039WZF>.2NY=XD/N9X)?<
MEJB<<I=`E/*2_9G\F=?Y2I;8EOZ92Y!!^D":6Y=!FMV1_)-"FD.:699$FE&0
MOY2BD*N<=I=5_$7^J)1%FDOZX9W9EG27]?WEDD66VI&CD%^@KY"_ETR1>I;>
MD4::L/YYEVR46)AFDON31YI)ETB72I/BG&22WY%Y^]>60Y/+_7K^VY&OE]V5
M2)-+FD7\39J\D>*0M)#AE4Z:3YI`_D/^W991FJ>6L)!.G$.4NHY2FL'\Z8NO
MG/V+O)JXFJZ:IYI3FG2=ZHOKB[*0Z97HE>:5M9!4FK.0YY50B^R+5IK[BU>:
MJJ"FG\R969RUF;Z0KY_RE;^0P9#D_L20QY#DDE*?VY!FH-*0U)!;FOV5Q(O>
MD.2<X9!&GE&66/OFD%"6YY#HD%V:>I]<FWR?4OSID.J07IIVG^N0[)#NB^Z0
MQI'RD+S\=(I7EN^<WY_WD/:07IOXD/F0:OKOB^"?0I%BFFF51)%#D4&1\(M@
MEO&+]IE)D4J12Y%DFK^*9IIGFFF::II2EDV19I9[GVN:;*!GEFR:;9KRBVJ6
MZOQLEL21=Y;TF6^:JY_!CE654I%3D561795QEFV<<Y94D7&:5I%MEE>5QHG'
MB6J*5XOAGU^;7:!;D5R17I%<GU>?99]RFF"17I]AD62109]ID6B1=)JREG6:
MI?WIGKJ+;9%@H-Z?PY^UEF>@LY9VFM65RIYWFGB:<)%OD:.?<9&QEF.?9Y^Y
MBWJ:5HO:FK"6?IK>G:V6KI:AGE">KY;TBZ2?O9;TEKB6H?JGD5Z@?9I(B;&>
MVYV_E7.*_IYZD7N1HYK"EG>?I)JEFJ&1N(ESD:::O8FYB7V1NY;RG_6+J9I4
MG^.?[9ZJD:N1<*!MGZR1K9']H.*?KY%!GJJ:L)&KFJR:2IJRD?:+K9JVB:^:
ML)JQFJ&:N9&ZD;Z10:"WB\"1LYK#D?R@[I]IG\B1R9'FC<N1R(GXBZJ-W9]#
M^ECZ6_IM^GCZKOJ\^O;Z^_K\^FC[<_NW^[[[POO+^\[[S_OU^U;\6OQC_&[\
M</QW_'O\M_SC_/3\]?Q`_5C]6_UC_6?]:_UT_:3]I_VR_=#]U?W9_?;]1OY.
M_ES^9_YM_G[^I?ZO_K?^PO[0_MG^VO[>_M_^[OY`CE2.7XYTCK..TH[3CM>.
MVH[ECN>.[X[QCD:/38]?CV&/9X]SCWF/I(^FCZB/VH_JC_R/0I!%D%R079!>
MD&F0H9"XD-B0W9#TD':1?)&BD:B1J9'GD>J1])'WD?Z11I)5DEF26Y)ADF62
M?9*EDK62SI+VDOF29)-RDWZ3JI.]D\"3SI/7D]Z3091&E%^48)2DE+:4R)3@
ME.24]91!E4653)59E5Z5895TE7N5K)6ZE>"5XY7NE>^5\Y7WE4*60Y9'EE.6
M6I9HEF^6=)9VEK:6OI:_EL26QI;.EO"6^);ZEDN73I=LEVV7=Y>AEZ*7I9>F
MEZV7L9?*E^.7Y)?KE_&7]Y=!F%V8=)A[F'R8HIBFF*F8JIBLF+&8P)CZF'R:
MM)JUFK::NIJ^FK^:P)K!FL2:Q9K&FLB:R9K+FLR:SIK/FM&:TYK4FM6:UIK7
MFMB:W)K>FM^:X9KCFN6:YIKJFNN:[9KNFN^:\)KTFO6:]YKXFOF:^IK]FOZ:
M0)M!FT*;0YM$FT6;2)M+FT^;4)M1FU*;4YM5FU:;69M;FUV;8)MBFV.;9)MF
MFV>;:)MIFVJ;:YMLFVV;;IMOFW.;=)MUFWF;>INBFZ6;IINKFZV;KINPF[*;
MLYNZF[N;O9N_F\";P9O'F\B;R9O+F\Z;SYO2F]:;UYO8F]N;X)OBF^2;Z)OK
MF^V;\9OSF_>;^IO]F_Z;0YQ$G$><2YQ,G%:<6)Q>G&.<99QGG&F<;IQPG'&<
M<YQTG':<>)QZG'V<HYRDG*:<IYRJG*V<L)RTG+6<N9S#G,2<RIS.G-2<U9S6
MG-><WYSAG.:<ZISMG/J<_IQ`G4&=0IU#G42=19U'G4N=3IU0G5*=4YU4G5:=
M6)U9G5R=7IU?G6.=99UFG6>=:)UIG6N=;)UNG6^=<9UUG7>=>IVBG:R=L)VS
MG<V=U)WMG?J=_IU`GD^>49Y;GG">?)ZEGJJ>K9Z\GL*>T)[3GN">[)[YGD:?
M1Y]*GTV?4)^SG[Z?T9_LGZ2@L:#LH/>@^Z#^H$"(08A"B$.(1(A%B$:(1XA(
MB$F(2HA+B$R(38A.B$^(4(A1B%*(4XA4B%6(8HADB*.(I8BIB*J(08FRB;N)
MOHG*B<V)0(I$BD6*3(I0BE.*5XI=BEZ*7XI@BF6*:(IIBFR*<(IQBG**>HI[
MBJ&*HHJCBJ6*JHJMBK"*LHJTBK6*MHJ\BKV*P(K)BLR*SXK2BM2*V(K9BMR*
MWXK@BN&*XHKEBN:*Z(KMBO.*](KWBDB+2XM-BTZ+3XM9BZJ+JXNMBZZ+LHO"
MB\.+Q8O6B]N+WHOAB^*+YHOMB_.+^HO^C7G(>LA\R'[(H<BCR*3(T,C/R.3&
MY<;-R,[(_OEUDW:32)7&CO:@K?QRDD?\WY2DF.>4RY![DMB47_Q4^MJ6>9)T
M^G62^XU)BM^2?)MC^F#Z;9)B^FN7:OU4_7.2V)>[GT*3=I)E^FR2;OK`DK^2
MOI*SBG670/IV^M#[>_K,B4+ZO))<E+6;IYBDE_V0PY+0FU"5QI)&E<+ZPYYF
MG%.0P9?I^F*2X9+&^G+ZS)+YG4.*IHK-FN[ZS)M\G5^9]OO%GUF*:XMDBO**
M^(K8G=:4_OJG^T.+1(M4GLJ*J)YCDMV:98MOBWZ+0X_0DKZ=WOS]G6:+<(MU
MB^2*I(OOBO:*=I[CGK&<=YYDBV>+X)I*B_&*UXJKH.Z*_HI8BJ.+IXO7G7V>
MIYZKGGF+>HM^BD2>YYI\BG&+Z9I.^_F*8YY)B\Z*;HM:BGN+?(OZBG*+J(NN
MGG*>7_NZD/:>[9?SFNZ@?)9%DVZ85OI+_,>7RYQ`DNB<_9'HEVK[=(O(_4&2
MH9;SCM;ZQYS7^J'[Q8ZD^_J1V_ZKET>1L?O2E&'^SOKMDO.1QI-:D^^2R/I'
MF&:359CFED.?JI_:E.Z2K_S[^_F.]I&VG*W[3IA$C_V6:9?4E4N8JONOG<6=
M\9&QCJF7K/NX_+#[TOS+DZR+5:"^E>F.^)*^EVR1JI3&G;67N)+OD:;^8)=8
MDW:5K(_LD;272I=)^WB5O)/6D5635I-1F/B/P/ORD]"08Y.ED>V@49.H_E"3
M3/KWDJW^U?MYGMG[IZ!>D\N)4Y_A^^+[=)#F^[>;1YM;_/V<[/NHF]6*<_I9
M_>W[J9RHBL.;3IO0E5^0[I=._,:>4/QS_5[Z6:!U^J*<<)-QDW>3[_YMDUW\
M_(I!^VN>XY3BCDV<HY;#BJJ6:/QMB^F*H?QLDW#^J/SI_.J*JY:G_,N*5YNE
MDZ.30HM0E[./18M&BWN3L9-'BGR399NODZ.>[/IWB['\N_RHD^R7POUGD<S\
MMI/DD.60\I[*D[R+SY/;_-S\YOSGEMC\V?RF_?&5Z9SD_*^4=_K,DUJ0OY-1
M^[F3U_ZWD]F3NY/:DZ.8T9!P^OS\0(M[H.*3UORFDU^3\I?XCD>/M)+MD=*6
M1OU/CTF57/I+_=.6]:!#DOJ7V9WTETV2U9[)G%B2R(ZTE.&3WY/P_.R3]I?/
MEFG]4I-N_7SZ^I-\D+>=Z:!.^J']=)Z_G\N>N9NYE]*>4Y>DEKZ/V918D'G]
M>_WZCMF>U)>[D+S]QOU(DL&=N9*FDDN/MI+8GEZ47YC.E$J2</UGE.R-2)3!
M^O><OOU^_/F3Z_K#^M.7^95(G&J.V*#7_4K[KYM+E,G]K(Y:DKW\V9+=DKJ6
MVOW>_=/]UOW<_=W]_I"A_MB<;9Y\_6'[8/Y2F$^6;I%MF&284Y3L_7C[6IC0
MDV*83Y=2E-*1ZI=K^[&1\_W+DK&;[/QKF%&7<9CSGNB13/MJDOC]89CMDT27
MX9%IF&**59QWCN:3HI.SE'V39IY9E%B45/ZEE.V5?OWK^WW];Y=AE,&?UY52
M^FB?YYO._.B62?I-E?B>2?[.D7&7L?WRG+B30Y!9E]>49OY]E&_\]XY\E,V2
MLI=E_GZ66)=WF\^1U9:S_*Z31IQ;E=&1])3M_/K]R/QB_OR1:_[Y_<?\3I&X
MG&>7HI1UF*R7TY'KCFJ77I;YG_B5HO[FCZ2=:)?LCKV46Y3VG*?ZV9M=^E:6
M8I>ZE$^@V)*[E,^0991,G[Z>;?O*E<*=^)=SE'242XI5BFF+=HOXH-^8M?[[
MEON;SIY[GL[^_)W/_J6+[(K@_*V4U?ZLE&^*J8O+G>?\R)/PD>"/[9#<F\>3
M29+AEN&/Y9O`E,.3Q9-YD'N7?I#F_KB=<)*HE;F80)&^_%>1W_KFFT2.3YST
M_MR32HZYG4Z.Y93PFU&5NXOPE&2.ZI1;CO*;R9ULCG6/<8Y@CMC]4I54E;N=
M0Y7^DO*4\93JH-*=^)%BE*2;K8[0EE>7=XJUCFV@MHY6ET"5\Z"^E-_]O)W^
ME,".PXY)ELR08)Q+E<R.Y(Y)G%Z+7)79CK2=7Y+;CE27U)YHE<.@89Q?G$W\
M:9['_L;^99'GG%2*;)Q=_FJ5;97PCO:.VOM,BW7]W9OU^FJ/3H]5^D&<7))F
M^V6.29BH^T*8^Y?*D%N<39=+G[6?TI.J_4"81I%GF%KZJ?O]_*O]O9%,C\F6
M58^N^V^5\*!OE*S]RY96H%Z/;(^CCK/[4_RS_6N/RI9OGL6@>/Q"CEJ/PI"E
MCF&03Y)SD[7]S/Z]^T.8Q9:\B4N22ICQH/N>TIRGCUS\19A&D/K^8)5(GT>2
M^Y!QE:R<KH]]E;:7O:"]C[^/:9.GF^K^X9M!B[:=ZZ"CFZ&+R(],B6"8QY18
MBZN5JI76D]&/U9G(^]>/TH]DD+:8O9C<C_;^V8_SE_B;;)[RC^Z/;I[OC_2/
M]8_"E6J8SY=!D-N<8HM.BF:*^YS\G.6<<XMABJ*+\IW*CDZ0]9]/D/[[8Y!7
MD&:0Y?QBD6>0H8^BCTB=T_JYD&N05_Y5_G.0[YOPG."1V)%&EF"34_K3G$#[
MXHU"E%:099A*^J^56I=)DT>7]*!XE\^/8/S<D6&6[))=D]Z._I9/_=Z5L)A`
MH+V7?9?UEZR;VOK"DGN0_I-[E+[Z0_W&D*20J)"IE*F0?9"Z_<23[?ZKG>.@
M2):IBL6;799?EU^6;I9=^[&=H_ZRG:Z5H_RBH%6609.ME=61>I?\_4>._9.E
MD*R0KI#BE6:4N)'LG*V0XXKJE=F1]97TE7+^>I*L_L61S9#^E5F1S)?.D/W^
M6YU@_<^<X)#SD/"0MY5+CEB6SYYDG5"1P9RGD^^@49'!EJ3\:IU.DEV1;9U:
MD<"<:I&FGK26<I'(GE6+<IW,GG21=Y'`EK&/MY9XD7?[=9&CD7F1I)&FD5*0
M1:#=G$")>)1UGD>@2/Q2G/V.\(\`````61(``%D2``!9$@``61(``%D2`0!:
M$@``6A(``%H2``!:$@``6A(0`%L2``!;$@``6Q(`(%P2``!<$@``7!(``%P2
M``!<$@``7!(``%P2``!<$@``7!(``%P2``!<$@``7!(``%P2$`!=$@``71(`
M`%T2``!=$A````````````!7$@``5Q(``%<2``!7$@``5Q(``%<2``!7$@``
M5Q(``%<2``!7$@``5Q(``%<2``!7$D``6!(``%@2``!8$@``6!(``%@2``!8
M$@``6!(``%@2``!8$@``6!(``%@2``!8$@``6!(``%@2``(`````````````
M`````````````#L2($`]$@``/1(``#T2```]$@``/1(``#T2```]$@``/1(`
M`#T2```]$@``/1(``#T2```]$B``/A(``#X2```^$@``/A(``#X2```^$@``
M/A(``#X2```^$@``/A(``#X2```^$@``/A(`(#\2```_$@``/Q(``#\2```_
M$@``/Q(``#\2```_$@``/Q(`0$`2``!`$@``0!(``$`2`!!!$@``01(``$$2
M``!!$@``01(``$$2``!!$@``01(``$$2``!!$@``01(`($(2``!"$@``0A(`
M`$(2``%#$@``0Q(``$,2``!#$@`01!(``$02"`!%$@``11(``$42``!%$@``
M11(``$42"`!&$@$`1Q(``$<2``!'$@``1Q(``$<2``!'$@``1Q(``$<2@`!(
M$@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2
M``!($@``2!(``$@2``!($@``2!(``$@2``!($@(`21((04P2``!,$@``3!((
M`$T2``!-$@``31(!`$X2``!.$@``3A(``$X2#`!0$@``4!(``%`2``!0$@"`
M41(``%$2``!1$@``41(``%$2`0!2$@@`4Q(``%,2``!3$@``4Q(``%,2``!3
M$@"`5!(``%02!`!5$@``51(`@%82``!6$@``5A(``%82``!6$@``5A(``%82
M``!6$@``5A(``%82``!6$@``5A(``%82``(`````````````````````````
M`#(2```R$@``,A(``#(2```R$@``,A*``#,2```S$@``,Q(``#,2```S$A``
M-!(``#02```T$@``-!(`!#42```U$B@`-Q(``#<2`(`X$@``.!(``#@2`"`Y
M$@`$.A(``#H2```Z$@`@````````````````````````````````*Q(``"L2
M`"`L$@``+!((`"T2``$N$@``+A(``"X2```N$@``+A(``"X2```N$@``+A(`
M`"X2``8P$@``,!(``#`2```P$@``,!(``#`2```P$@``,!(``#`2```P$@``
M,!(``#`2`$`Q$@``,1(``#$2```Q$@``,1(``@`````@$@``(!(``"`2```@
M$@``(!(``"`2```@$@``(!(``"`2``@A$@``(1(`@"(2`P`D$@``)!(``"02
M,``F$@``)A(`("<2`0`H$@``*!(``"@2```H$@``*!(``"@2```H$@``*!(`
M$"D2``$J$@``*A(``"H2```J$@`(`````,$1$`#"$0``PA$`",,1``##$0``
MPQ$``,,1``##$0``PQ$``,,1``##$0``PQ$``,,1``##$0``PQ$``,,1``##
M$0``PQ$``,,1``##$0@`Q!$``\81``#&$0`0QQ$`0,@1``+)$0``R1$`#<P1
M`!#-$0$`SA$`4-`1$@#2$0`>UA$`@-<10`#8$2`"VA$``-H1\`_B$0`&Y!$`
M`.01``#D$0X`YQ$`'.H1``#J$0``ZA%`&.T1`,#O$2\`]!$``/01`!#U$0``
M]1$&N/L1``#[$0!0_1$!`/X1>!`#$@```Q(`@`02`#('$@``!Q(```<2)``)
M$H`&#!*`'Q(2`(`3$@``$Q(`(!02"`@6$@$"&!(``!@2```8$@``&!(``!@2
M```8$@``&!(``!@2```8$@`@&1(``!D2```9$@``&1(``!D2```9$@``&1(0
M`!H2```:$@``&A(``!H2```:$@``&A(``!H2```:$@``&A(``!H2```:$@``
M&A(``!H2```:$@``&A(``!H20``;$@``&Q(``!L28``=$@``'1(``!T2```=
M$@``'1(,`!\2```?$@`"``````````"D$00"IA$``*81``"F$0``IA$``*81
M``"F$0``IA$``*81``"F$0``IA$``*81`&"H$0``J!$``*@1``*I$1``JA$`
M`*H1``"J$0!`JQ$``*L1``"K$0``JQ$`@*P1``"L$0``K!$``*P1``"L$0``
MK!$``*P1``"L$0``K!$``*P1@`"M$0``K1$``*T1``"M$0``K1%``*X1``"N
M$0``KA$``*X1``"N$0``KA$``*X1`""O$0``KQ$$`+`1``"P$0``L!$``+`1
M``"P$0`$L1$``+$1``"Q$2``LA$`(+,1``"S$0``LQ$``+,1``"S$0``LQ$`
M`+,1``"S$0``LQ$``+,1!`"T$0``M!$``+01``"T$0``M!$``+01``"T$00`
MM1$``+41``"U$0``M1$``+41``"U$0``M1$``+41``"U$0``M1$``+41`#"W
M$0``MQ$``+<1`!"X$0``N!$``+@1``"X$0``N!$``+@1``"X$0``N!$``+@1
M$`"Y$0$(NQ$``+L1(`"\$0`(O1$``+T1``"]$0``O1$``+T1``"]$0``O1$`
M#+\1``"_$0``OQ$``<`10```````R`\``,@/``#(#P``R`\``,@/``#(#P``
MR`\``,@/``#(#P``R`\``,@/``#(#P``R`\``,@/``C)#P!`R@\``,H/``#*
M#P``R@\``,H/``#*#P``R@\`!,L/``#+#P``RP\``,L/``#+#P``RP\``,L/
M``#+#P``RP\``,L/``#+#P``RP\``,L/``#+#P``RP\``,L/``#+#P``RP\`
M`,L/``#+#P`.S@\``,X/@`#/#X`#T@\``-(/``#2#P#PU@\``-8/``#6#P``
MU@\``-8/``#6#P`(UP\``-</``#7#P``UP\``-</``#7#\`_WP\``-\/``#?
M#P``WP\``>`/``#@#P``X`\`\.0/`P#F#P``Y@\``.8/``#F#P``Y@\`#^H/
M``#J#P``Z@\`@.L/``#K#P``ZP\``.L/@!_Q#P``\0\``/$/``#Q#R``\@\"
M`/,/``#S#P``\P\`@/0/!P#W#P``]P\``/</@`#X#P$`^0\``/D/`/C^#P$`
M_P\``/\/`@``$````!``/@40```%$(``!A````80```&$``X"1````D0```)
M$```"1```@H0```*$```"A````H0$``+$```"Q````L0`(`,$!$`#A#@D!,0
M```3$``$%!```!00```4$#@`%Q```!<0```7$```%Q`$`!@0`!`9$```&1``
M"!H0```:$```&A``"!L00`(=$```'1#``2`0```@$```(!`@`"$0```A$``&
M(Q```",0```C$``$)!```"00``0E$```)1```"40``$F$```)A`\`"H0```J
M$``0*Q!`$"T0```M$``@+A`"`"\0```O$``",!`$`3(0```R$```,A```#(0
M8``T$```-!``##80```V$```-A"``3@0```X$```.!```CD0`$`Z$`@`.Q``
M`#L0```[$```.Q```#L0`@`\$```/!```#P0```\$```/!```3T0```]$```
M/1```#T0```]$```/1```#T0```]$```/1```#T0```]$``$/A```#X0```^
M$```/A`@`#\0```_$```/Q"``$`0``!`$```0!```$`0$`!!$```01```$$0
M0`!"$```0A`@`$,0``!#$```0Q```$,0``!#$```0Q``@$00``!$$```1!``
M`$00``!$$```1!```$00``!$$```1!```$00"`!%$```11```$40``!%$```
M11```$40``!%$```11```$40``!%$```11```$40``!%$`B`1Q`#$$H0P`)-
M$`"`3A`(P%$0!P!4$```5!`,`%80<(!:$`#_8A```&(0@#AF$(`/:Q```&L0
M`,!M$`@`;A#``W(0``!R$```<A#^!WP0`$!]$`#`?Q`#`($0X`"$$(`'B!``
M`(@0>`",$/``D!`.')80@`"7$`*`F1`$`)H0``":$```FA```)H0``":$```
MFA```)H0``":$`!`FQ```)L0``";$```FQ```)L0``";$```FQ```)L0``";
M$"``G!```IT0``"=$```G1```)T0``"=$```G1```)T0``"=$```G1``P)\0
M``"?$```GQ```)\0``*@$```H!```*`00`"A$```H1```*$0``"A$```H1``
M`*$0``"A$```H1```*$0``"A$```H1```:(0``"B$```HA``#*00``"D$```
MI!```*00``"D$```I!```*00`0"E$```I1```*40``"E$```I1```*40``"E
M$```I1```*40``"E$```I1``0*80``"F$```IA```*80``"F$``0IQ```*<0
M``"G$`0`J!"`!*H0``*K$```JQ`$`*P0``"L$```K!```*P0``"L$```K!``
M`*P0``"L$```K!```*P0``"L$```K!```*P0`""M$```K1```*T0``"M$```
MK1```*T0``"M$```K1```*T0``"M$```K1```:X0``"N$```KA``8+`0``"P
M$```L!```+`0``"P$```L!```+`0R`"S$```LQ```+,0``"S$`,`M1```+40
M``"U$```M1```+40``"U$```M1```+40``"U$```M1"``+80``&W$```MQ``
M`+<0``"W$`H`N1```+D0``"Y$```N1```+D0``"Y$```N1```+D0``"Y$```
MN1```+D0``"Y$```N1```+D0``"Y$```N1```+D0(("[$`$`O!```+P0``"\
M$`!0OA```+X0``"^$```OA```+X0``"^$```OA```+X0``"^$```OA```+X0
M``"^$```OA```+X0``"^$``XP1!@`,,0``##$!*`QA```,80``#&$``"QQ``
M`,<0(`C)$`$`RA```,H0``#*$```RA```,H0(`#+$```RQ`"`,P0``#,$```
MS!`(`,T0``#-$```S1```,T0``#-$```S1```,T00`#.$$``SQ``(-`0(`#1
M$```T1```-$0``#1$```T1`$`-(0``#2$```TA```-(0``#2$(``TQ```-,0
M`P#5$```U1```-40``#5$```U1```-40``#5$(``UA```-80!`#7$```UQ``
M`-<0``#7$```UQ```-<0``#7$`(`V!```-@0``#8$```V!```-@0``#8$```
MV!!``-D0``#9$```V1```-D0``#9$``0VA```-H0``#:$```VA```-H0``#:
M$```VA```-H0``#:$```VA```-H0``#:$```VA```-H0``#:$``0VQ``0-P0
M``#<$```W!```-P0``+=$```W1```-T0``#=$```W1```-T0``#=$```W1``
M`-T0$`#>$```WA```-X0``#>$!@`X!!``.$0``#A$```X1```.$00@#C$```
MXQ```.,0``#C$``$Y!```.00(`#E$```Y1```.40``#E$```Y1```.40`P#G
M$```YQ```.<0`$#H$```Z!```.@0`0#I$```Z1`(`.H0``#J$```ZA```.H0
M``#J$```ZA```.H0``#J$```ZA```.H0``#J$```ZA``0.L0``#K$```ZQ``
M`.L0``#K$```ZQ```.L0``#K$`X`[A```.X00`#O$``0\!```/`0@`'R$```
M\A```/(0``#R$```\A```/(0``#R$``(\Q```/,0``#S$```\Q```/,0``#S
M$```\Q```/,0``#S$```\Q`&`/40``#U$```]1```/40``+V$```]A```/80
M``#V$!``]Q```/<0``#W$```]Q`P`/D0``#Y$```^1```/D0``#Y$```^1``
M`/D0``#Y$`(`^A```/H0``#Z$``>_A```/X0``#^$```_A```/X0`&``$0``
M`!$````1`"`!$0```1$```$1```!$0```1$```$1```!$0```1$``0(1`@`#
M$0```Q$```,1```#$0```Q$```,1```#$0$`!!$```01```$$0``!!$```01
M```$$0``!!$```01`@`%$0``!1$```41```%$0``!1$```41`$`&$0``!A$`
M``81```&$0``!A$```81!P`)$0``"1$```D1```)$0``"1$```D1```)$0`"
M"A$``0L1```+$0``"Q$```L1```+$0``"Q$```L1```+$00`#!$```P1```,
M$0``#!$```P1```,$00`#1$```T1```-$0`@#A$```X1```.$0``#A$```X1
M```.$0``#A$```X10``/$0``#Q$```\1```/$0``#Q$```\1```/$0``#Q$`
M@!`1`@`1$0``$1$``!$1``$2$0``$A$``!(1```2$0``$A$``!(1`@`3$0``
M$Q$``!,1```3$0``$Q$``!,1```3$1@`%1$`$!81```6$0``%A$``!81```6
M$0``%A$``!81```6$0``%A$`0!<1`$`8$0``&!$``1D1"``:$0``&A$``!H1
M```:$0``&A$``!H1```:$0!`&Q$"`!P1```<$0``'!$``!P1```<$0``'!$`
M`!P1```<$0``'!$``1T1(``>$0``'A$``!X1```>$00$(!$``"`1```@$0!`
M(1$``"$1!``B$08`)!$``"01```D$0``)!$``"01```D$0``)!$``"01```D
M$0``)!$``"01``0E$0``)1$``281```F$0``)A$/`"H1```J$0``*A$``"H1
MP``L$0``+!$(`"T1```M$0``+1$``"T1@``N$0``+A$``"X1`@`O$0``+Q$`
M`"\1```O$0``+Q$`P#$1!P`T$0``-!$``#01@"$W$0$`.!$``#@1```X$0``
M.!$``#@1```X$?P'01$``$$1``!!$0``01$``$$1``!!$0``01$``$$1_P!)
M$0``21$``$D1`!!*$0`,3!$!`$T1(`!.$0``3A$``$X1``!.$3P`4A$``%(1
M`$!3$80`51$0`%81``!6$0``5A$``%81``!6$?\`7A$``%X1``!>$0``7A$`
M`%X10`!?$0``7Q$``%\1``!?$0``7Q$8`&$1``!A$0"`8A$"`&,1``!C$0``
M8Q$`P&41``!E$0``91$`0&81``!F$0``9A$``&81``!F$0P`:!$``&@1``!H
M$0``:!$``&@1`.!K$0``:Q$`(&P1``!L$0``;!$``6T1`!)O$0``;Q'``'$1
M``!Q$0``<1$``'$1,`!S$2``=!$``'01``!T$0``=!$``'01``!T$0``=!$`
M`'01``!T$0``=!$`"'41``!U$0``=1$``'41``!U$0``=1$``'41``!U$0``
M=1$``'41``!U$0``=1$``'410`!V$0``=A$``'81``!V$0``=A$``'81``!V
M$0``=A$``'81``!V$0``=A$`!'<1``!W$0``=Q$``'<1``!W$0``=Q$``'<1
M``!W$0``=Q$$`'@1``!X$0``>!$``'@1``!X$0``>!%0`'H1``!Z$0``>A$`
M`'H1``!Z$0``>A$``'H1``!Z$0``>A$``'H1``!Z$0``>A$``'H1``!Z$0``
M>A$``'H1``!Z$0``>A$``'H1``!Z$0``>A$``'H1$0!\$0!@?A$`$'\1``!_
M$0``?Q$$`H$1``"!$>``A!$``(01``"$$0``A!$0`(41``"%$0``A1$``(41
M``"%$0``A1$``(41`("&$0``AA$``(818`"($0(`B1$`0(H1``"*$0``BA$P
M`(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``
MC!$``(P1``",$0``C!$!`(T1``"-$0``C1$``(T1``"-$0``C1$``(T1``"-
M$0``C1$``(T1``"-$1``CA$``(X1``".$0``CA&``(\1``"/$0``CQ$``(\1
M``"/$0``CQ$``(\1``"/$0``CQ$``(\1`$"0$0``D!$``)`1``"0$0``D!$`
M`I$1``"1$0``D1$``)$1``"1$0``D1$`8),1``"3$0``DQ$``),1$`"4$0``
ME!$``941``"5$0`'F!$``)@1``"8$0``F!$``)@1``"8$0``F!$``)@1``"8
M$0``F!$``)@1``"8$1``F1$``)D1!`":$0``FA$``)H1``":$0``FA$``)H1
M``":$0``FA$``)H1``":$0``FA$``)H1``":$0``FA$``)H1``":$0``FA$`
M@)L1``";$0``FQ$8`)T1``"=$0@`GA$`@)\1``&@$0``H!$`(*$1``"A$0`0
MHA$``*(1``"B$0``HA$``*(1``"B$0``HA$`H````````````````"`.```@
M#@``(`X``"`.`$`A#D!`(PX``",.``$D#@``)`X``"0.```D#@``)`X``"0.
M```D#@``)`X`0"4.```E#@``)0X``28.```F#@``)@X``"8.```F#@``)@X`
M`"8.```F#@``)@X`""<.```G#@(`*`X0`"D.```I#@``*0X``"D.$``J#@``
M*@X``"H.```J#@`(*PX``"L.,``M#@``+0X`0B\.`0`P#@"`,0X!`#(.```R
M#B``,PX``#,.``0T#@``-`X@`#4.```U#N(`.0X``#D.```Y#@#`.PX!`#P.
M```\#H``/0X@`#X.``I`#@``0`X``$`.(!!"#@``0@X8@$4.``!%#@``10X`
M`$4.``!%#B``1@X``$8.@`!'#@8`20X(`$H.``!*#@``2@X``$H.``!*#@!0
M3`X``$P.``!,#@``3`X``$P.@`!-#@``30X``$T.``!-#@!`3@X``$X.(`!/
M#@@`4`X``%`.`8!2#@$(5`X``%0.``!4#@(&5PX``%<.`0!8#@``6`X``%@.
M``!8#@``6`X``%@.``!8#@``6`X``%@.``!8#@``6`X``%@.``!8#@!`60X`
M`%D.``!9#@``60X``%D.``!9#@``60X``EH.``!:#@``6@X``%H.``!:#@``
M6@X``%H.``!:#@``6@X``%H.``!:#@`06PX``%L.``!;#@``6PX``%L."`!<
M#@``7`X``%P.``!<#@``7`X``%P.``!<#@``7`X``%P.``!<#D``70X``%T.
M``!=#@``70X0`%X.``!>#@`"7PX``%\.``!?#@``7PX``%\.``!?#@``7PX`
M`%\.``!?#@``7PX"`&`.``!@#@``8`X``&`.`0!A#@``80X``&$.``!A#@``
M80X``&$.$`!B#@``8@X``&(.``!B#@``8@X``&(.``!B#@``8@X``&(.``!B
M#@``8@X``&(.``!B#@"`8PX``&,.``%D#@``9`Y``&4.``!E#@0`9@X`@&<.
M``!G#@``9PX!`&@.``!H#@X`:PX(`&P.``!L#H`!;@X``&X.`!!O#@``;PX`
M`&\.`(!P#G@`=`X``'0.``!T#@``=`X``'0.``!T#@``=`[`<WL.``![#@``
M>PX`P'T.``!]#@``?0Z``'X.``!^#@``?@X``'X.``!^#@``?@X`YH,.0R"'
M#@``APX``(<.``"'#@``APX`((@.X`^/#@``CPX``(\.`!R2#D``DPX``),.
M``"3#@``DPX`#Y<.``"7#@``EPX`8)D.`PB<#@``G`X``)P.``"<#@``G`X`
M()T.``"=#@`@G@YP`*$.``"A#@``H0X`/*4.``"E#@``I0X`8*<.``"G#@``
MIPX``*<.``"G#@"`J`[@":T.``"M#@``K0X``*T.$`"N#H,#LPX``+,.``"S
M#G``M@X``+8.``"V#@``M@X`(+<.``&X#@``N`X``+@.``"X#H$`N@X``+H.
M``"Z#@``N@X``+H.``*[#@``NPX``+L.``"[#@``NPX``+L.``"[#@"`O`X`
M`+P.``"\#@`0O0X``+T.``"]#@`"O@X!`+\.``"_#@``OPX(`,`.`$#!#CP`
MQ0X``,4.``#%#@`$Q@X``,8.``#&#@``Q@X``,8.``#&#@`0QPX``,<.``#'
M#F``R0X``,D.`"#*#@!`RPX``,L.``#+#@``RPX``,L.``#+#C0`S@X``,X.
M``#.#@``S@Z``,\.``#/#D``T`X``-`.``#0#@`!T0X`(-(.``#2#@``T@X`
M`-(.``#2#@``T@X``-(.``#2#@``T@X``-(.0`#3#@``TPX``-,.``#3#@``
MTPX``-,.``#3#@`$U`X(`-4.``#5#@!`U@X``-8.``#6#@(`UPX``-<.``#7
M#@0`V`X``-@.``#8#@<`VPXH`-T.P`'@#@!<Y`X``.0.`0#E#D``Y@X`'.D.
M``#I#H``Z@X`\.X.&P#R#@``\@X``/(.``#R#CX`]PX``/<.`![[#@``^PY@
M'P(/```"#P```@\`!P4/``P'#R``"`\`0`D/'@`-#P`(#@\X`!$/`,`3#P<`
M%@\`P!@/```8#\`#'`\``!P/``0=#S@`(`\G`"0/@``E#P`()@\0`"</```G
M#P``)P\`$"@/``$I#T``*@\``"H/```J#P``*@\`""L/```K#P@`+`\``"P/
M```L#P``+`\``"P/``@M#P``+0\``"T/```M#P``+0\``"T/```M#P``+0\`
M`"T/```M#P``+0\``"T/```M#P``+0\``"T/```M#Q``+@\``"X/```N#P``
M+@\``"X/```N#P``+@\``"X/```N#P``+@\``"X/```N#P``+@\``"X/```N
M#P``+@\``"X/```N#P``+@\``"X/```N#P``+@\D`#`/```P#P``,`\``#`/
M```P#P``,`\``#`/```P#P``,`\``#`/0``Q#P``,0\``#$/```Q#P``,0\`
M`#$/```Q#P`$,@\`!#,/`@`T#P``-`\``C4/```U#P``-0\``#4/@``V#P``
M-@\``#8/```V#P``-@\``C</```W#Q`!.0\``#D/```Y#R``.@\``#H/```Z
M#P``.@\``#H/```Z#P``.@\``#H/```Z#P`$.P\``#L/```[#P``.P\"`#P/
M```\#P``/`\``#P/```\#P``/`\``#P/```\#P``/`\``#P/``(]#P``/0\`
M`#T/```]#P``/0\`!#X/```^#P``/@^``#\/```_#P``/P\`$$`/``!`#P``
M0`\`!$$/``!!#P``00\``$$/``!!#P@$0P\``$,/``!##P(`1`\``$0/"`!%
M#P``10\``$4/``!%#P``10\``$4/``!%#P``10\``$4/``!%#P``10\`$$8/
M``!&#P``1@\``$8/``!&#P``1@\``$8/``!&#P``1@\``$8/``!&#R(`2`\`
M`$@/``!(#P``2`\``$@/``!(#P``2`\``$@/``!(#P`@20\``$D/`0!*#P``
M2@\``$H/``!*#P``2@\``$H/``!*#P``2@\``$H/(`!+#P(`3`\`"$T/``!-
M#P``30\``$T/``!-#P``30\``$T/``!-#P``30\("$\/``!/#P$`4`\``%`/
M``!0#P``4`\``%`/`"!1#P``40\`@%(/`$!3#P``4P\``%,/``!3#P``4P\`
M`%,/`!A5#P`(5@\``%8/``!6#P``5@\``5</``!7#P``5P]``5D/``!9#P``
M60\``%D/``!9#P``60]P`%P/``!<#P"(7@\``%X/``!>#P``7@\``%X/``!>
M#R``7P\"`&`/``!@#P``8`\P`&(/``!B#P``8@\``&(/``!B#P@`8P\``&,/
M``!C#P``8P\``&,/`(!D#P$`90\``&4/``!E#P``90\`(&8/``!F#P(`9P\`
M`&</``!G#X``:`\``&@/``!H#P``:`\``FD/``!I#P``:0\`"&H/``!J#P$`
M:P\``&L/``!K#P``:P\``&L/``!K#P``:P\``&L/``!K#P``:P\``&L/``!K
M#P``:P\``&L/``!K#P``:P\``&L/``!K#P``:P\``&L/`(!L#R``;0\``&T/
M``!M#P``;0\``&T/!`!N#P``;@\``&X/``!N#P`$;P\``&\/``!O#P``;P\`
M`&\/``!O#P!`<`\``'`/``!P#P``<`\``'`/``!P#\``<@\``'(/``!R#R(`
M=`\``'0/``!T#P``=`\`"'4/`@!V#P``=@]``'</``!W#P``=P\``'</@`%Y
M#P``>0\``'D/``!Y#P``>0\``'D/@`!Z#P``>@\``'H/``!Z#QD`?0\``'T/
M``!]#P``?0\``'T/``!]#P`@?@\``'X/``!^#T``?P\``'\/``!_#P``?P\`
M`8`/``"`#P``@`\``(`/``"`#P``@`\``(`/``"`#P``@`\``(`/``"`#P``
M@`\``(`/``"`#P``@`\``(`/``"`#P``@`\``(`/``"`#P``@`\``(`/``"`
M#P@`@0\``($/``"!#P``@0\``($/``"!#P`(@@\``((/``""#P!@A`\`0(4/
M``"%#P``A0^`$(</``"'#P`$B`\``(@/``"(#P@`B0\``(D/``")#P`@B@\`
M`(H/``"*#P``B@\``(H/!`"+#P``BP\P`(T/``"-#P`#CP\``(\/``"/#X`#
MD@\``)(/``"2#R"`E`\>`)@/``"8#P``F`\$`)D/``"9#P`&FP\``)L/`#B>
M#P``G@\``)X/!`"?#P,`H0\``*$/`02C#P``HP\``*,/``"C#P``HP\``*,/
M``"C#P``HP\``*,/``"C#P``HP\0`*0/``"D#P``I`]``*4/,$"H#P$`J0\`
M`*D/``"I#P``J0\``*D/`0"J#P``J@\$`*L/``"K#P``JP\``*L/``"K#P``
MJP\``*L/(`"L#P``K`\``*P/``"L#P``K`\!`*T/``"M#P`$K@\``*X/``"N
M#P``K@\@$K$/``"Q#P``L0\`X+0/``"T#P``M`\``+0/`0"U#P``M0\``+4/
M`!"V#P$`MP\``+</``"W#X``N`\``+@/``"X#T`@N@\`!+L/``"[#P"`O`\`
M0+T/``"]#P``O0\``+T/`8"_#P"`P`\``,`/``#`#T``P0\``,$/`@#"#P``
MP@\$`,,/`!#$#P0`Q0_@````````````&0Z$`!L.```;#@``&PX`*!T.```=
M#@``'0X``!T.```=#@``'0X``!T.```=#@``'0X``!T.```=#A0@`````*,-
M^/^P#?\!N0V@`+L-``"[#5`,OPT``+\-``"_#0``OPT``+\-``"_#0(`P`T`
M`,`-``#`#0``P`T``,`-`1+##0`)Q0T``,4-``#%#0`@Q@T&(LH-$3S0#63B
MUPV`<=P-(:GB#8,)YPV0I.P-F#SS#0O!^0T$`/H-I`/_#0@```X````.````
M#FP$!0X`+`@.`$`)#DA&#@X@"!`.!``1#@``$0X``!$.```1#@``$0X``!$.
M```1#@``$0X``!$.```1#@``$0X``!$.```1#@``$0X``!$.```1#@``$0X`
M`!$.```1#@``$0X!`!(.```2#@``$@X``!(.```2#@``$@X``!(.```2#@``
M$@X``!(.```2#@``$@X``!(.```2#@``$@X``!(.```2#@``$@X``!(.8&T`
M````Z0L(`.H+``GL"P`@[0L``>X+`!#O"P`$\`L``/`+``#P"P``\`L0!O,+
M``#S"P``\PL@`/0+`0#U"P``]0L$(O@+0`;["P``^PL``/L+`0#\"P``_`L1
M(/\+``4!#"(``PP`@`0,```$#```!`P`"`4,`#`'#(``"`P`@`D,!$0,#`0(
M#@P`$A`,@``1#```$0P@1!0,```4#``(%0P`!!8,!``7#`$(&0P"`!H,A``<
M#`("'@P0`!\,!!@B#`,`)`P!`"4,`@`F#"``)PP!`"@,(``I#```*0P$`"H,
M```J#$8"+@Q00#$,`0`R#!`(-`P`H#8,(``W#((`.0P5`#P,```\#```/`Q`
M`#T,0``^#``A0`P!`$$,@`-$#!``10P`!$8,``!&#`(`1PP``$<,0@!)#``@
M2@P``$H,``!*#```2@P`0$L,$,%/#```3PP``$\,``!/#``@4`P!)%,,$`A5
M#`!$5PQ!!%H,``!:#`0!7`P``5T,``!=#`(`7@P``%X,`!)@#```8`P``&`,
M0`!A#!``8@P!!&0,`"!E#`%`9PR`0&D,``!I#```:0PA`&L,`,!M#```;0P`
M`&T,`@!N#`@`;PP@`'`,`"!Q#`(`<@P$('0,`@%V#"`D>0P``'D,@0![#$``
M?`P0`'T,``!]#``D?PP`(X(,`AB%#`$0APP(`(@,`J&,#```C`P`((T,8"B1
M#"``D@P``)(,@("4#`(`E0P2`)<,``"7#`P@F@Q@!IX,(@"@#`!`H0P``*$,
M@(&D#"`(I@P0`*<,``"G#`$`J`R`P*L,B"RP#`0`L0P"`+(,``"R#```L@P`
M"+,,``"S#```LPP``+,,``"S#```LPP``+,,``"S#```LPP``+,,``"S#```
MLPP``+,,``"S#``"M`P`@+4,(YZ]#-O6R`R/5M$,8X_:##W_YPPDON\,J73W
M#/_C!`T89`D-:`T/#:R#%@W+Q!X-"14C#2F**0UD3"\-#*`S#2!4-PVAK3\-
M$IM&#21&2PT`@TX-"!Y3#5"(5PT$@%D-^(MB#=0U:@V-OG0-+4I[#1!`?0TD
M`'\-`("`#4``@0T`@((-`!"##0,`A0T%$(@-``"(#0(@B@T0$HT-``B.#0*`
MD`T$@)(-``B3#0`!E`TP29D-``"9#0``F0T``)D-`(":#0`$FPT`()P-``"<
M#0`!G0T``)T-``"=#0``G0T``)T-`"">#0`$GPT``)\-``"?#0``GPT@`*`-
MD0``````````````````````D0$``)$!``"1`0``D0$@`)(!`1"4`0``E`$0
M`)4!"&29`0``F0%(`)L!(("=`0`0G@$"`:`!`("A`1``H@$`"*,!0`"D`0``
MI`$``*0!`$"E`0``I0$*`*<!`B"I`84!K0$0`*X!@`&P`2(@LP$`@+0!HD2Y
M`40HO0$``+T!#DC"`0`"PP$`!<4!""#'`2!"R@&`0\X!`(#/`0``SP$`!-`!
M`@#1`0`$T@$@%-4!(Q+:`;H!X`%8(.0!9@#H`2``Z0$*)>X!`!#O`2PP]`$-
M!/@!"0#Z`0``^@$$@/P!``#\`0``_`&``/T!`0#^`0!"``(````"`````@``
M``($"0,"`(`$`@`"!0(!(`<"0`$)`@``"0(```D""``*`@``"@(```H"```*
M`@$`"P(```L""!`-`@(`#@(```X"``0/`@`!$`(0`!$"@``2`@2`%`(`(!4"
M```5`@@`%@(``!8"`089`@0*'`(2`!X"``$?`@``'P(`$"`")!`C`@!))@)*
M`"D"@`$K`@`&+0(0`"X"``@O`H10,P+``#4"```U`@``-0*``#8"``@W`@`@
M.`(``#@"`$`Y`@$`.@(%"#T"`$`^`@`"/P($"$$"``)"`@0`0P(``40"`0!%
M`@8820(!`$H"0`),`@(`30(`4$\"%`!1`H`@4P(`$%0"'`!7`@`@6`(B`5L"
M``!;`@``6P(``%L"$`!<`@``7`(``%P"``!<`@``7`(``%P"``!<`@`H7@)"
M$&$"`(AC`@``8P(``&,"""!E`@``90($"&<"0%!J`@*`;`($AG`"("!R`B"$
M=0("`'8"("!X`A"`>@+`,'X""`B``H`)@P*(,(<"0`"(`@``B`(``(@"``"(
M`@D!BP(@`(P"``",`A``C0(``(T"``"-`@`GD0("@90"A!28`L-$G@*&"J,"
M&92I`E%`K0(``*T"``"M`@``K0(``*T""`.P`@@`L0(`$+("``"R`@@`LP(`
M`+,"``"S`@$`M`*`$+8"(""X`@`&N@(0`+L"`""\`@``O`(``KT"(`"^`H@`
MP`(DA,0"``#$`@``Q`(``,0"``'%`@"(QP(``<@"`('*`@``R@(`!,L"&$+/
M`@``SP(``,\"!`#0`@``T`(``-`"@%#3`@"`U`(``-0"`0#5`@``U0($`-8"
M$(39`@`(V@(`@-L"``+<`@``W`("`-T"``#=`@``W0(!`-X"``#>`@$$X`(`
M!.$"`!#B`A``XP(``.,"(!+F`@``Y@(``.8"``#F`A`8Z0(``.D"``#I`@`(
MZ@(``.H"``#J`@``Z@(`0.L"``#K`@``ZP*``.P"``#L`@`$[0("`.X"`(+P
M`@`@\0($`/("!@#T`@@`]0(@(/<"``#W`@``]P(``/<"``#W`@`$^`(`@/D"
M`(#Z`@4`_`*!`/X"(4`!`P"@`P,0'@@#$``)`Q@*#0-`(`\#@$`1`PBH%0,(
M`!8#)A`:`P0$'`.``!T#(``>`P``'@,``!X#```>`P``'@,``!X#``(?`P``
M'P-`@"$#H``C`P``(P,``",#```C`P`()`,``"0#``0E`P$`)@,``"8#```F
M`P``)@,`@"<#`0`H`P``*`,@`"D#```I`P@!*P,``"L#```K`P!`+`,``"P#
M```L`P`0+0,``"T#``$N`T``+P-``#`#```P`R``,0,`(#(#$``S`P$(-0,`
M`#4#```U`X``-@,``#8#`"`W`P``-P,"`#@#```X`P`(.0,`8#L#```[`P``
M.P,!(#T#`"`^`P@$0`-``$$#`D!#`R`D1@,@4$D#(`!*`PH`3`,@!$X#!`!/
M`P`"4`,``%`#@@!2`P``4@,``%(#`(!3`Z``50,``%4#`(!6`P`@5P,0`%@#
M(`!9`P``60,``%D#``!9`P``60,``%D#0`!:`P``6@,0`5P#``!<`P(`70,0
M`%X#`(!?`P``7P,``F`#`!!A`X``8@,``&(#``!B`P"`8P,%2&<#`$!H`\D@
M;0,``&T#`&!O`P$`<`,``'`#``!P`P``<`.00',#``!S`P``<P,`2'4#``!U
M`P`(=@,`('<#`"!X`P``>`,``'@#$$!Z`X$`?`,`('T#``!]`P(@?P,``'\#
M``*``P$`@0,``($#$`""`P``@@,``((#``""`P``@@,``((#`A"$`P``A`,`
M`(0#``"$`P``A`,``(0#``"$`Q``A0,`%(<#$A6,`\"@D`,``I$#``R3`P`$
ME`,``94#HP*:`P`%G`,!`)T#@)BA`P!`H@,``*(#`$RE`P`!I@,(`*<#``2H
M`P`#J@.$`JT#)`BP`P``L`,``+`#!`"Q`P`$L@,``+(#!`FU`P$@MP,`$;D#
M``"Y`S``NP,$(KX#"`'``P``P`,`0,$#$`#"`P``P@-``<0#0!#&`P``Q@,"
M`<@#`0#)`T``R@,``,H#`"#+`P&"S@,"`,\#$!#1`P)@U`,``-0#``C5`P``
MU0,``-4#0`#6`P$$V`,0`MH#1`'=`T`4X`.`">,#/`'H`XB"[`,.B/$#%"#T
M`Q!0]P,D"/H#`(#[`\$`_@,0$``$````!(`"`@0!`00$"`(&!`"`!P01!`H$
M$@$-!"`"#P0@$!$$`P`3!`,`%00``A8$`@`7!```%P2`$!D$#`D=!`1`'P0`
MH"$$D"(E!!!@*`0``"@$"``I!$5/,01!`#,$)A`W!`<'/00!`#X$P$!!!```
M0018!$4$"H!(!`0`200`*$L$``!+!``F3@0``$X$((!0!)A05008`%<$%`):
M!``X700!!%\$"(!A!```800$(&,$"$%F!"@):@0`@&L$@`)M!`@@;P0`"G$$
M#@)U!$``=@0!`'<$``)X!!$6?00"`'X$@$&!!``4@P0C"(<$(`"(!`)`B@0O
M()`$@`"1!`B@E`05()@$`@"9!``<G`0`#I\$!,"B!!*`I00"@J@$``"H!$``
MJ00$H*P$`B"N!`$`KP0@(+$$``"Q!`2`LP1,`+8$D(BZ!(``NP0`Q+X$`"7!
M!`$0PP2"!,8$$$C)!!`!RP2`8,X$0(#0!`!`T00(`-($!`#3!$0`U00`!-8$
MD0#9!`"0VP0`$MT$#`#?!```WP0`!N$$@`3C!&$(YP0`".@$`!#I!`$`Z@0-
M".X$M`3S!`*`]00``/4$%`#W!```]P0``/<$(`#X!"``^00``OH$$(3]!``0
M_@2!`0$%$`(#!0`"!`4`B`8%`0,)!00H#`4$``T%DAP3!0`@%`4@`!4%$`(7
M!0I)'`4"0A\%1@$C!4(")@4#""D%```I!0C`+`4(`"T%$``N!05$,@4`(#,%
M`H`U!0`(-@4``#8%4H0[!0``.P5`(3X%4!!!!04`0P4!X$<%``1(!0``2`4(
M`$D%H`!+!0``2P4(@$T%(`!.!1A04@4)`%0%``!4!0`&5@4(0%@%``!8!0``
M6`4@`%D%`%9=!0``704`!%X%!@!@!0(`804@@F0%``!D!0``9`4A`6<%`)!I
M!0!`:@5``6P%P`AO!0``;P41`'$%($AT!0``=`40"'8%0`)X!0(`>06`"'L%
M``![!2``?`4`"GX%!`!_!0!`@`4``(`%!`&"!0!`@P4``(,%`(2%!4@`AP4`
M`(<%``"'!0`@B`4`((D%`0"*!0``B@40&X\%`'"2!0``D@4@`),%``24!0`@
ME04#$)@%"@":!00(G`4(`)T%``"=!9``GP4"!*$%$`"B!0"(I`4``*0%``"D
M!0``I`4``*0%"`"E!0((IP4`!*@%!`"I!0``J06@0*P%``"L!0!`K060`*\%
M"`"P!0``L`6`0+(%B`.V!0`@MP6`$+D%``*Z!0``N@4!(+P%!`"]!0$2P`41
M@,,%`"#$!8(`Q@4@$\H%``#*!8`"S`4!@,X%"031!00`T@4``-(%``#2!0``
MT@4`$-,%@`+5!0`0U@4``-8%``'7!0``UP4D`-D%`2#;!5``W04``-T%*`#?
M!2"`X04@`.(%``#B!0``X@4``>,%`$#D!:(`YP4``.<%``#G!1`0Z04`@NL%
M``CL!0``[`4``.P%``+M!0(`[@4"0/`%1`#R!0!9]@6``/<%``#W!0``]P4$
M#?L%``#[!0`$_`4``/P%`A#^!0`@_P4"```&`(`!!E```P8!``0&""`&!J($
M"@8```H&``0+!@+`#@8```X&,0`1!@`@$@8`@!,&`"@5!@``%09@`QD&```9
M!@``&08@0!L&```;!A(`'08)`!\&`(`@!@``(`8`02(&"``C!@$`)`80"2<&
MB``I!H@(+`8(("X&($`P!@0$,@80(#0&2(`W!@!@.08``#D&```Y!@(`.@8$
M4#T&0$`_!B``0`9``$$&$`!"!@``0@:&`$4&``!%!@"`1@8``$8&$1!)!@*`
M2P8``$L&P`!-!@``308`0D\&'R!5!@%(6`8$`%D&P$!<!H`$7@9@(&$&(`!B
M!@``8@80`60&``%E!D``9@9`(FD&*`1L!@``;`8``&P&``!L!@\"<08`#70&
M`!!U!D!`=P9(`'D&(`!Z!I(`?08,`'\&(02"!@"!A`8$`(4&!`"&!@$`AP9B
M`(H&`@*,!@`&C@8(&)$&`!23!@`XE@8(`)<&(!"9!HP`G`8@`)T&$@2@!@2$
MHP8`(J4&@`BG!B9`JP8`!ZX&$`&P!@``L`9``+$&(`"R!@`@LP8``+,&(`"T
M!@``M`:$`+8&`("W!A`$N08"`+H&``"Z!@``N@8``+H&`@"[!@`0O`8"!+X&
M``2_!@``OP8`$,`&``#`!J(FQ@8``L<&``7)!@!`R@8@@LT&``#-!@"`S@8$
MA-$&!`#2!@!(U`8`@-4&``36!@``U@9D`-D&``#9!E``VP8``-L&`$#<!H`8
MWP8``-\&!@#A!@*`XP9``.0&,`#F!@("Z`8``.@&``#H!@``Z`8``.@&%(3L
M!B`![@8`!O`&``#P!@"`\08!`O,&``#S!D`0]09`"/<&``3X!@``^`8@"?L&
M``#[!@`N_P8$`P('``0#!Q`8!@?```@'$``)!Q`@"P<0``P'0!`.!P``#@<0
M`A`'`@02!P"@%`<``!0'($@7!P``%P<(!AH'```:!T`!'`<(`!T'`$`>!P`0
M'P<``!\'``@@!Q$0(P>`D"8'(,(J!P**+@<``"X'Z0`S!P`Z-P<1$#H'88`^
M!P``/@<B0$$'(`!"!P`@0P<`&D8'.$A+!R&$3P<"`%`'``A1!^I460<`45P'
M0`%>!PP@80>0!&0'``!D!P(@9@<`"&<'8`!I!P#";`?@`&\'$$AR!P``<@<!
M`','H1!W!T``>`<``'@'A(![!Q"`?0<`('X'!`!_!P`@@`<``(`'!`"!!P``
M@0<4`(,'`0"$!P!=B0<``XL'`H&.!P``C@<``(X'$@"0!P"`D0<`490'@`26
M!P``E@<`PID'(0";!U:`H`>("J0'``"D![;2K0<``*T'@!.Q!Z@#M@=((+D'
M(1F^!U`$P0<$,,0'``K&!Q``QP<0`,@'`!'*!PD`S`>``,T'!P'1!R!`TP<`
M0M4'``#5!S`(V`=$)-P'*@#?!X%@XP<$!.4'"&#H!P1`Z@<``.H'$@#L!P@!
M[@<`$.\'``#O!P``[P>$`/$'``#Q!P`0\@<`"/,'`>#W!Q(`^0?`@/P'6`0`
M"`````@!``$((@`#"(``!`@`$`4(0``&"```!@@```8(`-`)"`!`"@A0"`T(
M```-"`D`#P@``1`(```0"(0-%0@``!4("`$7"`"`&`@`0AH(*`@="```'0A`
M`!X($$`@"``!(0@`420(```D"``R)PB4""L(&@`N"$``+P@`!#`(`B$S"```
M,P@`@#0(0@,X"(``.0B,`3T(`$`^"",`00A``$((``!""`!`0PA<&$D(``!)
M"``#2P@$`$P(`D!.",D`4@@"HE8((`)8"```6`A0$%L($`!<"`0`70@2`%\(
M0`!@"```8`@`(&$(`$1C""@"9@@``&8((`!G"``@:`@(`&D(`@!J"```:@@!
M&&T(#(-R"`@\=PB$!GL(`$!\"``8?@@0@(`(@`*""``"@P@,`(4((`"&"`20
MB0@`"(H(``"*"`0`BP@,`(T(!`"."`"`CP@!`)`(``"0"``4D@@``)(()`B5
M"```E0@@`)8(%`"8"$(@FP@`()P($5BA"$A`I`@`$*4(P%"I"``!J@B$(JX(
M"`2P"$`@L@@H$K8(``"V"```M@@@`+<(``"W"``@N`@`)+H(``"Z"```N@@`
M`KL(@`"\"!`)OP@(`,`(`*#""!D0Q@@P`,@((&#+"(``S`@``,P(@`#-"```
MS0@``,T(``#-"*!`T`@`@-$(`$#2"`2`U`@0$-8(``37"("`V0@`@-H(``#:
M"```V@A``-L(``#;"```VPB``-P(@T+A"`P`XP@``.,(`@'E"`"`Y@B(`.@(
M"$#J"!``ZP@``.L(`"#L"(``[0@`!.X(!`'P"``@\0@AP/4(`ACX"```^`@0
M"/H(3@#^"```_@@!`/\(`(``"8```0G`,`4)0``&"0``!@D`$@@)0``)"8A2
M#@F4!!()``03"90`%@D$`1@)0`8;"0`@'`D`$!T)$``>"0@`'PD@!"$)0``B
M"0(!)`D``"0)$(`F"4``)PD``"<)``4I"4`B+`D`0"T)```M"1``+@DD`#`)
M0`XT"8``-0D``#4)0`0W"0``-PD0A#H)`0$\"01`/@F`L$()``A#"0`E1@D`
M`$8)`"!'"0``1PF``$@)3(!,"0``3`D@`$T)`A!/"0`04`D`0E()`"!3"0@`
M5`D`(%4)``!5"2``5@E0$5H)4T!?"0!`8`D`!6()*!%F"10`:`D&@&L)`0%M
M"4P`<`D(('()`&!T"0``=`D`1'8)-@!Z"0`!>PDH`'T)`0!^"0``?@D8`8$)
M!!B$"00$A@D`@(<)"0")"0``B0D``(D)``")"0``B0D"`(H)``"*"0%`C`D`
M$(T)!""/"5$`D@D`@90)``"4"20`E@D``)8)`!"7"01`F0D``)D)!`":"0$@
MG`D$`)T)``"="0``G0D`@)X)``">"0``G@D``)X)``&?"0``GPD``)\)``"?
M"0``GPD#(*()0!BE"0``I0D@`J<)`@"H"0)`J@E`!*P)`$"M"2``K@D0@+`)
M``&Q"8`@LPD``+,)9("W"0!`N`DQ0+P)``"\"9``O@D`$+\)`4#!"3"`Q`F@
M@,<)``#'"4``R`D@@,H)`0#+"0``RPD0`,P)``#,"8@@SPD0`-`)(`#1"8``
MT@F!!M8)$@#8":`"VPD`$-P)0@#>"0``W@F``-\)``#?"0``WPD`$.`)``KB
M"0`AY`D``N4)``#E"8``Y@D`0.<)``#G"1$0Z@D`@NP)$`#M"0``[0D`!.X)
M``3O"0``[PD`$/`)`(#Q"0`@\@D`@/,)"##V"0!`]PD$`OD)``#Y"0(`^@D!
M"/P)`0#]"0!`_@D``/X)``#^"00`_PD``/\)``#_"0``_PD``/\)``#_"0``
M_PD"```*````"@````H````*`(@""@`@`PH```,*`"`$"E`(!PH`"@D*A``+
M"@@8#@H&,1,*```3"@``$PH``!,*```3"@``$PH`!!0*!``5"@``%0I``A<*
M```7"@D`&0H0`!H*```:"@``&@H"0!P*```<"@`E'PH`!"`*0(`B"@``(@H`
M`2,*HD`G"@$`*`H``"@*@"`J"D$0+0H(0"\*``0P"A0@,PH$`#0*```T"@`"
M-0H`(#8*`0`W"@($.0H`$#H*P$`]"@``/0H``#T*"``^"B$`0`KH7TH*`A1-
M"@$$3PH``$\*``)0"@`!40H$`%(*``!2"H@`5`H`$%4*0`!6"A(060H``%D*
M``!9"@``60H`05L*``A<"A``70H``%T*``!="@``70H``%T*``!="@``70H`
M`%T*``!="@)280J``&(*01!E"@!09PH``&<*``)H"D`(:@H0`&L*0(!M"B``
M;@H`1'`*`$%R"@@`<PH`#78*(!!X"A(`>@H@H7X*!$B!"H``@@H2@H8*``"&
M"@!`APH"QHP*``","A`(C@HH&)(*7""7"H@`F0H``)D*`!":"@,`G`H_`:,*
M`("D"D1+J@H8(:X*\@"S"@$0M0H!(+<*`*F["D`(O0H("+\*`0#`"@L`PPH2
M`<8*@"C)"O`@S@H`0,\*#"#2"A`)U0J@$-@*``K:"B``VPH`@-P*!`#="@``
MW0H*`-\*`!#@"@``X`I``.$*``#A"@``X0H`(.(*``#B"H``XPH``.,*``#C
M"@"!Y0H@`.8*P`+I"L4$[@H``.X*``#N"@``[@H``>\*$`#P"@``\`H`(/$*
M``#Q"@@!\PHB`/4*0`#V"@`"]PH`"/@*`H#Z"D``^PHH`/T*0"#_"@``_PH`
M`/\*``#_"A````L(``$+``@""P(``PM"``4+`P`'"X*@"PL`(`P+`@`-"X`"
M#PL`B!$+```1"Q9E&`L%`1L+!``<"T%`'PLD`"$+```A"S"`)`L(0"8+&``H
M"X`(*@L``"H+0!`L"R``+0L``"T+```M"P``+0N0`C`+B$4U"P!0-PM#$#L+
M(@`]"P!`/@L`$D`+``!`"X`+1`L%)$@+`"!)"PP`2PL``$L+``!+"P`(3`L0
M!$X+`!%0"S``4@L`!%,+0@!5"R``5@L`$%<+`8!9"T*`7`L`&%X+``!>"P`1
M8`L($&(+``!B"P"`8PL``&,+``!C"T0D9PL``&<+@`!H"P4`:@L0@&P+!()O
M"Q``<`L`)'(+$`)T"P$`=0L!`'8+``)W"P"`>`L*Z'X+@*"!"P``@0L!`((+
M`("#"P`@A`L`(H8+$H")"P04C`LAB)`+08"3"R`$E0L@@)<+"""9"P``F0L$
M&)P+``"<"P``G`L``)P+``"<"P``G`L``)P+``"<"P``G`L$$)X+0`"?"P(`
MH`L0`J(+$$*E"P%`IPL`8*D+`%"K"P@`K`L(`*T+(`BO"P`@L`L1`K,+$`"T
M"P``M`L`$+4+`%2X"P"1NPL``+L+``"["P``NPL``+L+``"["P`(O`LR`+\+
M84'$"T2=RPL"H,X+T@#2"P``T@L$`-,+`D'6"P0!V`N``-D+P`#;"P`"W`LP
M`-X+"03A"P0"XPL`@.0+`$#E"P"2Z`L@`)`!``"0`0``D`$``)`!`@``````
MP````,````#`````P````,````#`````P````,````#``-$UR``@,,L`H%30
M`$!0TP!`M-@`P$#;``@`W````-P```#<````W````-P`"`#=````W0```-T`
M``#=````W0```-T```#=````W0```-T```#=````W0```-T```#=`.``X```
M`.````#@````X`#^_^\`____`/__#P'__Q\!__\O`0]X-P'^_T8!__]6`?__
M9@'__W8!__^&`7]POP```+\```"_````OP``(`````````````````````"*
M````B@```(H```"*````B@```(H```"*`/\#E`#P/YX```">````G@```)X`
M``">````G@```)X```">````G@```)X```">````G@```)X```">`/__K@#_
M_[X``0![````>P!``'P``@!]````?0```'T```!]````?0#_`X<```"'````
MAP```(<```.)````B0```(D`@```````=P```'<```!W````=P```'<```!W
M````=P```'<```!W````=P```'<```!W``#`>0`#`#4``@`V`/__1@#__U8`
M__]F`/__=@`"````````````````````````````````````````````````
M``````````````````````````````````````$!`````0`#!P8`#``(``,W
M#P`,%Q4``P`7``P,&P``"!P````<```X'P`(`"````@A````(0```"$````A
M````(0```"$``&`C`%<5*P```"L````K````*P```"L````K````*P```"L`
M$P@O``($,0`@`#(`"`0T````-````#0````T`$``````````````````0DY<
M3O51&E."4P=.#$Y'3HU.UU8,^FY<<U\/3H=1#DXN3I-.PD[)3LA.F%'\4FQ3
MN5,@5P-9+%D07/]=X66S:\QK%&P_<C%./$[H3MQ.Z4[A3MU.VDX,4AQ33%,B
M5R-7%UDO68%;A%L27#M<=%QS7`1>@%Z"7LE?"6)08A5L-FQ#;#]L.VRN<K!R
MBG.X>8J`'I8.3QA/+$_U3A1/\4X`3_=."$\=3P)/!4\B3Q-/!$_T3A)/L5$3
M4@E2$%*F4B)3'U--4XI3!U3A5M]6+E<J5S17/%F`67Q9A5E[67Y9=UE_659;
M%5PE7'Q<>EQ[7'Y<WUUU7H1>`E\:7W1?U5_47\]?7&)>8F1B86)F8F)B66)@
M8EIB96+O9>YE/F<Y9SAG.V<Z9S]G/&<S9QAL1FQ2;%QL3VQ*;%1L2VQ,;'%P
M7G*T<K5RCG,J=7]V=7I1?WB"?(*`@GV"?X)-AGZ)F9"7D)B0FY"4D"*6))8@
MEB.65D\[3V)/24]33V1//D]G3U)/7T]!3UA/+4\S3S]/84^/4;E1'%(>4B%2
MK5*N4@E38U-R4XY3CU,P5#=4*E145$54&50<5"54&%0]5$]4050H5"141U3N
M5N=6Y59!5T573%=)5TM74E<&64!9IEF86:!9EUF.6:)9D%F/6:=9H5F.6Y);
M*%PJ7(U<CUR(7(M<B5R27(I<AER37)5<X%T*7@Y>BUZ)7HQ>B%Z-7@5?'5]X
M7W9?TE_17]!?[5_H7^Y?\U_A7^1?XU_Z7^]?]U_[7P!@]%\Z8H-BC&*.8H]B
ME&*'8G%B>V)Z8G!B@6*(8G=B?6)R8G1B-V7P9?1E\V7R9?5E16='9UEG56=,
M9TAG76=-9UIG2V?0:QEL&FQX;&=L:VR$;(MLCVQQ;&]L:6R:;&ULAVR5;)QL
M9FQS;&5L>VR.;'1P>G!C<K]RO7+#<L9RP7*Z<L5RE7.7<Y-SE'.2<SIU.764
M=95U@78]>32`E8"9@)"`DH"<@)""CX*%@HZ"D8*3@HJ"@X*$@GB,R8^_CY^0
MH9"ED)Z0IY"@D#"6*)8OEBV6,TZ83WQ/A4]]3X!/AT]V3W1/B4^$3W=/3$^7
M3VI/FD]Y3X%/>$^03YQ/E$^>3Y)/@D^53VM/;D^>4;Q1OE$U4C)2,U)&4C%2
MO%(*4PM3/%.24Y13AU1_5(%4D52"5(A4:U1Z5'Y4951L5'149E2-5&]4851@
M5)A48U1G5&14]U;Y5F]7<E=M5VM7<5=P5W97@%=U5WM7<U=T5V)7:%=]5PQ9
M15FU6;I9SUG.6;)9S%G!6;99O%G#6=99L5F]6<!9R%FT6<=98EME6Y-;E5M$
M7$=<KERD7*!<M5RO7*A<K%R?7*-<K5RB7*I<IUR=7*5<MERP7*9<%UX47AE>
M*%\B7R-?)%]47X)??E]]7]Y?Y5\M8"9@&6`R8`M@-&`*8!=@,V`:8!Y@+&`B
M8`U@$&`N8!-@$6`,8`E@'&`48CUBK6*T8M%BOF*J8K9BRF*N8K-BKV*[8JEB
ML&*X8CUEJ&6[90EF_&4$9A)F"&;[90-F"V8-9@5F_6419A!F]F8*9X5G;&>.
M9Y)G=F=[9YAGAF>$9W1GC6>,9WIGGV>19YEG@V=]9X%G>&=Y9Y1G)6N`:WYK
MWFL=;)-L[&SK;.YLV6RV;-1LK6SG;+=LT&S";+ILPVS&;.UL\FS2;-ULM&R*
M;)UL@&S>;,!L,&W-;,=LL&SY;,]LZ6S1;)1PF'"%<)-PAG"$<)%PEG""<)IP
M@W!J<M9RRW+8<LERW'+2<M1RVG+,<M%RI'.A<ZUSIG.B<Z!SK'.=<]UTZ'0_
M=4!U/G6,=9AUKW;S=O%V\';U=OAW_'?Y=_MW^G?W=T)Y/WG%>7AZ>WK[>G5\
M_7PU@(^`KH"C@+B`M8"M@"""H(+`@JN"FH*8@IN"M8*G@JZ"O(*>@KJ"M(*H
M@J&"J8+"@J2"PX*V@J*"<(9OAFV&;H96C-*/RX_3C\V/UH_5C]>/LI"TD*^0
MLY"PD#F6/98\ECJ60Y;-3\5/TT^R3\E/RT_!3]1/W$_93[M/LT_;3\=/UD^Z
M3\!/N4_L3T1225+`4L)2/5-\4Y=3EE.94YA3NE2A5*U4I53/5,-4#8.W5*Y4
MUE2V5,54QE2@5'!4O%2B5+Y4<E3>5+!4M5>>5Y]7I%>,5Y=7G5>;5Y17F%>/
M5YE7I5>:5Y57]%@-65-9X5G>6>Y9`%KQ6=U9^EG]6?Q9]EGD6?)9]UG;6>E9
M\UGU6>!9_EGT6>U9J%M,7-!<V%S,7-=<RUS;7-Y<VES)7,=<RES67--<U%S/
M7,A<QES.7-]<^%SY72%>(EXC7B!>)%ZP7J1>HEZ;7J->I5X'7RY?5E^&7S=@
M.6!48')@7F!%8%-@1V!)8%M@3&!`8$)@7V`D8$1@6&!F8&Y@0F)#8L]B#6,+
M8_5B#F,#8^MB^6(/8PQC^&+V8@!C$V,48_IB%6/[8O!B065#9:IEOV4V9B%F
M,F8U9AQF)F8B9C-F*V8Z9AUF-&8Y9BYF#V<09\%G\F?(9[IGW&>[9_AGV&?`
M9[=GQ6?K9^1GWV>U9\UGLV?W9_9G[F?C9\)GN6?.9^=G\&>R9_QGQF?M9\QG
MKF?F9]MG^F?)9\IGPV?J9\MG*&N":X1KMFO6:]AKX&L@;"%L*&TT;2UM'VT\
M;3]M$FT*;=IL,VT$;1EM.FT:;1%M`&T=;4)M`6T8;3=M`VT/;4!M!VT@;2QM
M"&TB;0EM$&VW<)]POG"Q<+!PH7"T<+5PJ7!!<DER2G)L<G!R<W)N<LIRY'+H
M<NMRWW+J<N9RXW*%<\QSPG/(<\5SN7.V<[5SM'/K<[]SQW.^<\-SQG.X<\MS
M['3N="YU1W5(=:=UJG5Y=L1V"'<#=P1W!7<*=_=V^W;Z=N=WZ'<&>!%X$G@%
M>!!X#W@.>`EX`W@3>$IY3'E+>45Y1'G5><UYSWG6><YY@'I^>M%Z`'L!>WI\
M>'QY?']\@'R!?`-]"'T!?5A_D7^-?[Y_!X`.@`^`%(`W@-B`QX#@@-&`R(#"
M@-"`Q8#C@-F`W(#*@-6`R8#/@->`YH#-@/^!(8*4@MF"_H+Y@@>#Z((`@]6"
M.H/K@M:"](+L@N&"\H+U@@R#^X+V@O""ZH+D@N""^H+S@NV"=X9TAGR&<X9!
MB$Z(9XAJB&F(TXD$B@>*<HWCC^&/[H_@C_&0O9"_D-60Q9"^D,>0RY#(D-21
MTY%4ED^64993EDJ63I8>4`50!U`34")0,%`;4/5/]$\S4#=0+%#V3_=/%U`<
M4"!0)U`U4"]0,5`.4%I1E%&34<I1Q%'%4<A1SE%A4EI24E)>4E]255)B4LU2
M#E.>4R95XE0751)5YU3S5.14&E7_5`15"%7K5!%5!57Q5`I5^U3W5/A4X%0.
M50-5"U4!5P)7S%<R6-57TE>Z5\97O5>\5[A7ME>_5\=7T%>Y5\%7#EE*61E:
M%EHM6BY:%5H/6A=:"EH>6C-:;%NG6ZU;K%L#7%9<5%SL7/]<[ESQ7/=<`%WY
M7"E>*%ZH7JY>JEZL7C-?,%]G7UU@6F!G8$%@HF"(8(!@DF"!8)U@@V"58)M@
MEV"'8)Q@CF`98D9B\F(08U9C+&-$8T5C-F-#8^1C.6-+8TIC/&,I8T%C-&-8
M8U1C66,M8T=C,V-:8U%C.&-78T!C2&-*949EQF7#9<1EPF5*9E]F1V919A)G
M$V<?:!IH26@R:#-H.VA+:$]H%F@Q:!QH-6@K:"UH+VA.:$1H-&@=:!)H%&@F
M:"AH+FA-:#IH)6@@:"QK+VLM:S%K-&MM:X*`B&OF:^1KZ&OC:^)KYVLE;'IM
M8VUD;79M#6UA;9)M6&UB;6UM;VV1;8UM[VU_;89M7FUG;6!MEVUP;7QM7VV"
M;9AM+VUH;8MM?FV`;81M%FV#;7MM?6UU;9!MW'#3<-%PW7#+<#E_XG#7<-)P
MWG#@<-1PS7#%<,9PQW#:<,YPX7!"<GAR=W)V<@!S^G+T<OYR]G+S<OMR`7/3
M<]ESY7/6<[QSYW/C<^ESW'/2<]MSU'/=<]ISUW/8<^ASWG3?=/1T]70A=5MU
M7W6P=<%UNW7$=<!UOW6V=;IUBG;)=AUW&W<0=Q-W$G<C=Q%W%7<9=QIW(G<G
M=R-X+'@B>#5X+W@H>"YX*W@A>"EX,W@J>#%X5'E;>4]Y7'E3>5)Y47GK>>QY
MX'GN>>UYZGG<>=YYW7F&>HEZA7J+>HQZBGJ'>MAZ$'L$>Q-[!7L/>PA["GL.
M>PE[$GN$?)%\BGR,?(A\C7R%?!Y]'7T1?0Y]&'T6?1-]'WT2?0]]#'U<?V%_
M7G]@?UU_6W^6?Y)_PW_"?\!_%H`^@#F`^H#R@/F`]8`!@?N``($!@B^")8(S
M@RV#1(,9@U&#)8-6@S^#08,F@QR#(H-"@TZ#&X,J@PB#/(--@Q:#)(,@@S>#
M+X,I@T>#18-,@U.#'H,L@TN#)X-(@U.&4H:BAJB&EH:-AI&&GH:'AI>&AH:+
MAIJ&A8:EAIF&H8:GAI6&F(:.AIV&D(:4AD.(1(AMB'6(=HARB("(<8A_B&^(
M@XA^B'2(?(@2BD>,5XQ[C*2,HXQVC7B-M8VWC;:-T8[3COZ/]8\"D/^/^X\$
MD/R/]H_6D."0V9#:D..0WY#ED-B0VY#7D-R0Y)!0D4Z13Y'5D>*1VI%<EE^6
MO);CF-^:+YM_3G!0:E!A4%Y08%!34$M075!R4$A035!!4%M02E!B4!5015!?
M4&E0:U!C4&101E!`4&Y0<U!74%%0T%%K4FU2;%)N4M92TU(M4YQ3=55V53Q5
M35505315*E5156)5-E4U53!54E5%50Q5,E5E54Y5.55(52U5.U5`54M5"E<'
M5_M7%%CB5_97W%?T5P!8[5?]5PA8^%<+6/-7SU<'6.Y7XU?R5^57[%?A5PY8
M_%<06.=7`5@,6/%7Z5?P5PU8!%A<66!:6%I56F=:7EHX6C5:;5I06E]:95IL
M6E-:9%I76D-:75I26D1:6UI(6HY:/EI-6CE:3%IP6FE:1UI16E9:0EI<6G);
M;EO!6\!;65P>70M='5T:72!=#%TH70U=)ETE70]=,%T272-='UTN73Y>-%ZQ
M7K1>N5ZR7K->-E\X7YM?EE^?7XI@D&"&8+Y@L&"Z8--@U&#/8.1@V6#=8,A@
ML6#;8+=@RF"_8,-@S6#`8#)C96.*8X)C?6.]8YYCK6.=8Y=CJV..8V]CAV.0
M8VYCKV-U8YQC;6.N8WQCI&,[8Y]C>&.%8X%CD6.-8W!C4V7-965F869;9EEF
M7&9B9AAG>6B':)!HG&AM:&YHKFBK:%9I;VBC:*QHJ6AU:'1HLFB/:'=HDFA\
M:&MH<FBJ:(!H<6A^:)MHEFB+:*!HB6BD:'AH>VB1:(QHBFA]:#9K,VLW:SAK
MD6N/:XUKCFN,:RILP&VK;;1MLVUT;JQMZ6WB;;=M]FW4;0!NR&W@;=]MUFV^
M;>5MW&W=;=MM]&W*;;UM[6WP;;IMU6W";<]MR6W0;?)MTVW];==MS6WC;;MM
M^G`-<?=P%W'T<`QQ\'`$<?-P$''\</]P!G$3<0!Q^'#V<`MQ`G$.<7YR>W)\
M<G]R'7,7<P=S$7,8<PIS"'/_<@]S'G.(<_9S^'/U<P1T`73]<P=T`'3Z<_QS
M_W,,=`MT]',(=&1U8W7.==)USW7+=<QUT770=8]VB7;3=CEW+W<M=S%W,G<T
M=S-W/7<E=SMW-7=(>%)X27A->$IX3'@F>$5X4'AD>6=Y:7EJ>6-Y:WEA>;MY
M^GGX>?9Y]WF/>I1ZD'HU>T=[-'LE>S![(GLD>S-[&'LJ>QU[,7LK>RU[+WLR
M>SA[&GLC>Y1\F'R6?*-\-7T]?3A]-GTZ?45]+'TI?4%]1WT^?3]]2GT[?2A]
M8W^5?YQ_G7^;?\I_RW_-?]!_T7_'?\]_R7\?@!Z`&X!'@$.`2(`8@26!&8$;
M@2V!'X$L@1Z!(8$5@2>!'8$B@1&".((S@CJ"-((R@G2"D(.C@ZB#C8-Z@W.#
MI(-T@X^#@8.5@YF#=8.4@ZF#?8.#@XR#G8.;@ZJ#BX-^@Z6#KX.(@Y>#L(-_
M@Z:#AX.N@W:#FH-9AE:&OX:WAL*&P8;%AKJ&L(;(AKF&LX:XALR&M(:[AKR&
MPX:]AKZ&4HB)B)6(J(BBB*J(FHB1B*&(GXB8B*>(F8B;B)>(I(BLB(R(DXB.
MB(*)UHG9B=6),(HGBBR*'HHYC#N,7(Q=C'V,I8Q]C7N->8V\C<*-N8V_C<&-
MV([>CMV.W([7CN".X8XDD`N0$9`<D`R0(9#OD.J0\)#TD/*0\Y#4D.N0[)#I
MD%:16)%:D5.159'LD?21\9'SD?B1Y)'YD>J1ZY'WD>B1[I%ZE8:5B)5\EFV6
M:Y9QEF^6OY9JEP28Y9B7F9M0E5"44)Y0BU"C4(-0C%".4)U0:%"<4))0@E"'
M4%]1U%$24Q%3I%.G4Y%5J%6E5:U5=U5%5J)5DU6(58]5M56!5:-5DE6D57U5
MC%6F57]5E56A58Y5#%<I6#=8&5@>6"=8(U@H6/572%@E6!Q8&U@S6#]8-E@N
M6#E8.%@M6"Q8.UAA6:]:E%J?6GI:HEJ>6GA:IEI\6J5:K%J56JY:-UJ$6HI:
MEUJ#6HM:J5I[6GU:C%J<6H]:DUJ=6NI;S5O+6]1;T5O*6\Y;#%PP7#==0UUK
M74%=2UT_735=45U.755=,UTZ75)=/5TQ75E=0ETY74E=.%T\73)=-EU`745=
M1%Y!7EA?IE^E7ZM?R6"Y8,Q@XF#.8,1@%&'R8`IA%F$%8?5@$V'X8/Q@_F#!
M8`-A&&$=81!A_V`$80MA2F*48[%CL&/.8^5CZ&/O8\-CG63S8\ICX&/V8]5C
M\F/U8V%DWV.^8]UCW&/$8]ACTV/"8\=CS&/+8\AC\&/78]EC,F5G96IE9&5<
M96AE966,99UEGF6N9=!ETF5\9FQF>V:`9G%F>69J9G)F`6<,:=-H!&G<:"II
M[&CJ:/%H#VG6:/=HZVCD:/9H$VD0:?-HX6@':<QH"&EP:;1H$6GO:,9H%&GX
M:-!H_6C\:.AH"VD*:1=ISFC(:-UHWFCF:/1HT6@&:=1HZ6@5:25IQV@Y:SMK
M/VL\:Y1KEVN9:Y5KO6OP:_)K\VLP;/QM1FY';A]N26Z(;CQN/6Y%;F)N*VX_
M;D%N76YS;AQN,VY+;D!N46X[;@-N+FY>;FAN7&YA;C%N*&Y@;G%N:VXY;B)N
M,&Y3;F5N)VYX;F1N=VY5;GEN4FYF;C5N-FY:;B!Q'G$O<?MP+G$Q<2-Q)7$B
M<3)Q'W$H<3IQ&W%+<EIRB'*)<H9RA7*+<A)S"W,P<R)S,7,S<R=S,G,M<R9S
M(W,U<PQS+G0L=#!T*W06=!IT(70M=#%T)'0C=!UT*70@=#)T^W0O=6]U;'7G
M==IUX77F==UUWW7D===UE7:2=MIV1G='=T1W37=%=TIW3G=+=TQWWG?L=V!X
M9'AE>%QX;7AQ>&IX;GAP>&EX:'A>>&)X='ES>7)Y<'D">@IZ`WH,>@1ZF7KF
M>N1Z2GL[>T1[2'M,>TY[0'M8>T5[HGR>?*A\H7Q8?6]]8WU3?59]9WUJ?4]]
M;7U<?6M]4GU4?6E]47U??4Y]/G\_?V5_9G^B?Z!_H7_7?U&`3X!0@/Z`U(!#
M@4J!4H%/@4>!/8%-@3J!YH'N@?>!^('Y@02"/((]@C^"=8([@\^#^8,CA,"#
MZ(,2A.>#Y(/\@_:#$(3&@\B#ZX/C@[^#`83=@^6#V(/_@^&#RX/.@]:#]8/)
M@PF$#X3>@Q&$!H3"@_.#U8/Z@\>#T8/J@Q.$PX/L@^Z#Q(/[@]>#XH,;A-N#
M_H/8AN*&YH;3AN.&VH;JAMV&ZX;<ANR&Z8;7ANB&T89(B%:(58BZB->(N8BX
MB,"(OHBVB+R(MXB]B+*(`8G)B)6)F(F7B=V)VHG;B4Z*38HYBEF*0(I7BEB*
M1(I%BE**2(I1BDJ*3(I/BE^,@8R`C+J,OHRPC+F,M8R$C8"-B8W8C=.-S8W'
MC=:-W(W/C=6-V8W(C=>-Q8WOCO>.^H[YCN:.[H[ECO6.YX[HCO:.ZX[QCNR.
M]([ICBV0-)`OD`:1+)$$D?^0_)`(D?F0^Y`!D0"1!Y$%D0.189%DD5^18I%@
MD0&2"I(ED@.2&I(FD@^2#)(`DA*2_Y']D0:2!)(GD@*2')(DDAF2%Y(%DA:2
M>Y6-E8R5D)6'EGZ6B):)EH.6@);"ELB6PY;QEO"6;)=PEVZ7!YBIF.N8YISY
MGH-.A$ZV3KU0OU#&4*Y0Q%#*4+10R%#"4+!0P5"Z4+%0RU#)4+90N%#747I2
M>%)[4GQ2PU7;5<Q5T%7+5<I5W57`5=15Q%7I5;]5TE6-5<]5U57B5=95R%7R
M5<U5V57"51174UAH6&183UA-6$E8;UA56$Y875A96&586U@]6&-8<5C\6,=:
MQ%K+6KI:N%JQ6K5:L%J_6LA:NUK&6K=:P%K*6K1:MEK-6KE:D%K66]A;V5L?
M7#-<<5UC74I=95UR76Q=7EUH76==8EWP74]>3EY*7DU>2U[%7LQ>QE[+7L=>
M0%^O7ZU?]V!)84IA*V%%839A,F$N849A+V%/82EA0&$@8FB1(V(E8B1BQ6/Q
M8^MC$&029`ED(&0D9#-D0V0?9!5D&&0Y9#=D(F0C9`QD)F0P9"AD060U9"]D
M"F0:9$!D)60G9`MDYV,;9"YD(60.9&]EDF73989FC&:59I!FBV:*9IEFE&9X
M9B!G9FE?:3AI3FEB:7%I/VE%:6II.6E":5=I66EZ:4AI26DU:6QI,VD]:65I
M\&AX:31I:6E`:6]I1&EV:5AI06ET:4QI.VE+:3=I7&E/:5%I,FE2:2]I>VD\
M:49K16M#:T)K2&M!:YMK#?K[:_QK^6OW:_AKFV[6;LANCV[`;I]NDVZ4;J!N
ML6ZY;L9NTFZ];L%NGF[);K=NL&[-;J9NSVZR;KYNPV[<;MANF6Z2;HYNC6ZD
M;J%NOVZS;M!NRFZ7;JYNHVY'<51Q4G%C<6!Q07%=<6)Q<G%X<6IQ87%"<5AQ
M0W%+<7!Q7W%0<5-Q1'%-<5IQ3W*-<HQRD7*0<HYR/'-"<SMS.G-`<TIS27-$
M=$IT2W12=%%T5W1`=$]T4'1.=$)T1G1-=%1TX73_=/YT_70==7EU=W6#:>]U
M#W8#=O=U_G7\=?EU^'40=OMU]G7M=?5U_769=K5VW795=U]W8'=2=U9W6G=I
M=V=W5'=9=VUWX'>'>)IXE'B/>(1XE7B%>(9XH7B#>'EXF7B`>)9X>WA\>8)Y
M?7EY>1%Z&'H9>A)Z%WH5>B)Z$WH;>A!ZHWJB>IYZZWIF>V1[;7MT>VE[<GME
M>W-[<7MP>V%[>'MV>V-[LGRT?*]\B'V&?8!]C7U_?85]>GV.?7M]@WU\?8Q]
ME'V$?7U]DGUM?VM_9W]H?VQ_IG^E?Z=_VW_<?R&`9(%@@7>!7(%I@5N!8H%R
M@2%G7H%V@6>!;X%$@6&!'8))@D2"0()"@D6"\80_A%:$=H1YA(^$C81EA%&$
M0(2&A&>$,(1-A'V$6H19A'2$<X1=A`>%7H0WA#J$-(1ZA$.$>(0RA$6$*839
M@TN$+X1"A"V$7X1PA#F$3H1,A%*$;X3%A(Z$.X1'A#:$,X1HA'Z$1(0KA&"$
M5(1NA%"$"X<$A_>&#(?ZAM:&]89-A_B&#H<)AP&']H8-AP6'UHC+B,V(SHC>
MB-N(VHC,B-"(A8F;B=^)Y8GDB>&)X(GBB=R)YHEVBH:*?XIABC^*=XJ"BH2*
M=8J#BH&*=(IZBCR,2XQ*C&6,9(QFC(:,A(R%C,R,:(UIC9&-C(V.C8^-C8V3
MC92-D(V2C?"-X(WLC?&-[HW0C>F-XXWBC>>-\HWKC?2-!H__C@&/`(\%CP>/
M"(\"CPN/4I`_D$2029`]D!"1#9$/D1&1%I$4D0N1#I%ND6^12))2DC"2.I)F
MDC.299)>DH.2+I)*DD:2;9)LDD^28))GDF^2-I)ADG"2,9)4DF.24))RDDZ2
M4Y),DE:2,I*?E9R5GI6;E9*6DY:1EI>6SI;ZEOV6^);UEG.7=Y=XEW*7#Y@-
MF`Z8K)CVF/F8KYFRF;"9M9FMFJN:6YOJG.V<YYR`GOV>YE#44-=0Z%#S4-M0
MZE#=4.10TU#L4/!0[U#C4.!0V%&`4H%2Z5+K4C!3K%,G5A56#%825OQ5#U8<
M5@%6$U8"5OI5'58$5O]5^56)6'Q8D%B86(98@5A_6'18BUAZ6(=8D5B.6'98
M@EB(6'M8E%B/6/Y8:UG<6NY:Y5K56NI:VEKM6NM:\UKB6N!:VUKL6MY:W5K9
M6NA:WUIW6^!;XUMC7()=@%U]789=>EV!77==BEV)78A=?EU\78U=>5U_75A>
M65Y37MA>T5[77LY>W%[57ME>TE[47D1?0U]O7[9?+&$H84%A7F%Q87-A4F%3
M87)A;&&`871A5&%Z85MA96$[86IA86%682EB)V(K8BMD361;9%UD=&1V9')D
M<V1]9'5D9F2F9$YD@F1>9%QD2V139&!D4&1_9#]D;&1K9%ED961W9'-EH&6A
M9J!FGV8%9P1G(F>Q:;9IR6F@:<YIEFFP::QIO&F1:9EICFFG:8UIJ6F^::]I
MOVG$:;UII&G4:;EIRFF::<]ILVF3::IIH6F>:=EIEVF0:<)IM6FE:<9I2FM-
M:TMKGFN?:Z!KPVO$:_YKSF[U;O%N`V\E;_AN-V_[;BYO"6].;QEO&F\G;QAO
M.V\2;^UN"F\V;W-O^6[N;BUO0&\P;SQO-6_K;@=O#F]#;P5O_6[V;CEO'&_\
M;CIO'V\-;QYO"&\A;X=QD'&)<8!QA7&"<8]Q>W&&<8%QEW%$<E-REW*5<I-R
M0W--<U%S3'-B='-T<71U=')T9W1N=`!U`G4#=7UUD'46=@AV#'85=A%V"G84
M=KAV@7=\=X5W@G=N=X!W;W=^=X-WLGBJ>+1XK7BH>'YXJWB>>*5XH'BL>*)X
MI'B8>8IYBWF6>95YE'F3>9=YB'F2>9!Y*WI*>C!Z+WHH>B9ZJ'JK>JQZ[GJ(
M>YQ[BGN1>Y![EGN->XQ[FWN.>X5[F'N$4IE[I'N">[M\OWR\?+I\IWVW?<)]
MHWVJ?<%]P'W%?9U]SGW$?<9]RWW,?:]]N7V6?;Q]GWVF?:Y]J7VA?<E]<W_B
M?^-_Y7_>?R2`78!<@(F!AH&#@8>!C8&,@8N!%8*7A*2$H82?A+J$SH3"A*R$
MKH2KA+F$M(3!A,V$JH2:A+&$T(2=A*>$NX2BA)2$QX3,A)N$J82OA*B$UH28
MA+:$SX2@A->$U(32A-N$L(21A&&&,X<CARB':X=`ARZ''H<AAQF'&X=#ARR'
M08<^AT:'((<RARJ'+8<\AQ*'.H<QAS6'0H<FAR>'.(<DAQJ',(<1A_>(YXCQ
MB/*(^HC^B.Z(_(CVB/N(\(CLB.N(G8FAB9^)GHGIB>N)Z(FKBIF*BXJ2BH^*
MEHH]C&B,:8S5C,^,UXR6C0F.`H[_C0V._8T*C@..!XX&C@6._HT`C@2.$(\1
MCPZ/#8\CD1R1()$BD1^1'9$:D221(9$;D7J1<I%YD7.1I9*DDG:2FY)ZDJ"2
ME)*JDHV2II*:DJN2>9*7DG^2HY+NDHZ2@I*5DJ*2?9*(DJ&2BI*&DHR2F9*G
MDGZ2AY*IDIV2BY(MDIZ6H9;_EEB7?9=ZEWZ7@Y>`EX*7>Y>$EX&7?Y?.E\V7
M%IBMF*Z8`ID`F0>9G9F<F<.9N9F[F;J9PIF]F<>9L9KCFN>:/IL_FV";89M?
MF_&<\ISUG*>>_U`#43!1^%`&40=1]E#^4`M1#%']4`I1BU*,4O%2[U)(5D)6
M3%8U5D%62E9)5D966%9:5D!6,U8]5BQ6/E8X5BI6.E8:5ZM8G5BQ6*!8HUBO
M6*Q8I5BA6/]8_UKT6OU:]UKV6@-;^%H"6_E:`5L'6P5;#UMG7)E=EUV?79)=
MHEV3795=H%V<7:%=FEV>76E>75Y@7EQ>\WW;7MY>X5Y)7[)?BV&#87EAL6&P
M8:)AB6&;89-AKV&M89]ADF&J8:%AC6%F8;-A+6)N9'!DEF2@9(5DEV2<9(]D
MBV2*9(QDHV2?9&ADL6289'9E>F5Y97MELF6S9;5FL&:I9K)FMV:J9J]F`&H&
M:A=JY6GX:15J\6GD:2!J_VGL:>)I&VH=:OYI)VKR:>YI%&KW:>=I0&H(:N9I
M^VD-:OQIZVD):@1J&&HE:@]J]FDF:@=J]&D6:E%KI6NC:Z)KIFL!;`!L_VL"
M;$%O)F]^;X=OQF^2;XUOB6^,;V)O3V^%;UIOEF]V;VQO@F]5;W)O4F]0;U=O
ME&^3;UUO`&]A;VMO?6]G;Y!O4V^+;VEO?V^5;V-O=V]J;WMOLG&O<9MQL'&@
M<9IQJ7&U<9UQI7&><:1QH7&J<9QQIW&S<9ARFG)8<U)S7G-?<V!S77-;<V%S
M6G-9<V)SAW2)=(ITAG2!='UTA72(='QT>70(=0=U?G4E=AYV&78==AQV(W8:
M=BAV&W:<=IUVGG:;=HUWCW>)=XAWS7B[>,]XS'C1>,YXU'C(>,-XQ'C)>)IY
MH7F@>9QYHGF;>79K.7JR>K1ZLWJW>\M[OGNL>\Y[KWNY>\I[M7O%?,A\S'S+
M?/=]VWWJ?>=]UWWA?0-^^GWF??9]\7WP?>Y]WWUV?ZQ_L'^M?^U_ZW_J?^Q_
MYG_H?V2`9X"C@9^!GH&5@:*!F8&7@1:"3X)3@E*"4().@E&")(4[A0^%`(4I
MA0Z%"84-A1^%"H4GA1R%^X0KA?J$"(4,A?2$*H7RA!6%]X3KA/.$_(02A>J$
MZ806A?Z$*(4=A2Z%`H7]A!Z%]H0QA2:%YX3HA/"$[X3YA!B%((4PA0N%&84O
MA6*&5H=CAV2'=X?AAW.'6(=4AUN'4H=AAUJ'48=>AVV':H=0ATZ'7X==AV^'
M;(=ZAVZ'7(=EAT^'>X=UAV*'9X=IAUJ(!8D,B12)"XD7B1B)&8D&B1:)$8D.
MB0F)HHFDB:.)[8GPB>R)SXK&BKB*TXK1BM2*U8J[BM>*OHK`BL6*V(K#BKJ*
MO8K9BCZ,38R/C.6,WXS9C.B,VHS=C.>,H(V<C:&-FXT@CB..)8XDCBZ.%8X;
MCA:.$8X9CB:.)XX4CA*.&(X3CAR.%XX:CBR/)(\8CQJ/((\CCQ:/%X]SD'"0
M;Y!GD&N0+Y$KD2F1*I$RD2:1+I&%D8:1BI&!D8*1A)&`D="2PY+$DL"2V9*V
MDL^2\9+?DMB2Z9+7DMV2S)+ODL*2Z)+*DLB2SI+FDLV2U9+)DN"2WI+GDM&2
MTY*UDN&2QI*TDGR5K)6KE:Z5L)6DEJ*6TY8%EPB7`I=:EXJ7CI>(E]"7SY<>
MF!V8)I@IF"B8()@;F">8LI@(F?J8$9D4F1:9%YD5F=R9S9G/F=.9U)G.F<F9
MUIG8F<N9UYG,F;.:[)KKFO.:\IKQFD:;0YMGFW2;<9MFFW:;=9MPFVB;9)ML
MF_R<^IS]G/^<]YP'G0"=^9S[G`B=!9T$G8.>TYX/GQ"?'%$341=1&E$14=Y1
M-%/A4W!68%9N5G-69E9C5FU6<E9>5G=6'%<;5\A8O5C)6+]8NEC"6+Q8QE@7
M6QE;&ULA6Q1;$UL06Q9;*%L:6R!;'EOO6ZQ=L5VI7:==M5VP7:Y=JEVH7;)=
MK5VO7;1=9UYH7F9>;U[I7N=>YE[H7N5>2U^\7YUAJ&&68<5AM&'&8<%AS&&Z
M8;]AN&&,8==DUF309,]DR62]9(EDPV3;9/-DV60S97]E?&6B9<AFOF;`9LIF
MRV;/9KUFNV:Z9LQF(V<T:F9J26IG:C)J:&H^:EUJ;6IV:EMJ46HH:EIJ.VH_
M:D%J:FID:E!J3VI4:F]J:6I@:CQJ7FI6:E5J36I.:D9J56M4:U9KIVNJ:ZMK
MR&O':P1L`VP&;*UORV^C;\=OO&_.;\AO7F_$;[UOGF_*;ZAO!'"E;ZYONF^L
M;ZIOSV^_;[AOHF_);ZMOS6^O;[)OL&_%<<)QOW&X<=9QP''!<<MQU''*<<=Q
MSW&]<=AQO''&<=IQVW&=<IYR:7-F<V=S;'-E<VMS:G-_=)ITH'24=))TE72A
M=`MU@'4O=BUV,78]=C-V/'8U=C)V,':[=N9VFG>==Z%WG'>;=Z)WHW>5=YEW
MEW?=>.EXY7CJ>-YXXWC;>.%XXGCM>-]XX'BD>41Z2'I'>K9ZN'JU>K%ZMWK>
M>^-[YWO=>]5[Y7O:>^A[^7O4>^I[XGO<>^M[V'O?>])\U'S7?-!\T7P2?B%^
M%WX,?A]^('X3?@Y^''X5?AI^(GX+?@]^%GX-?A1^)7XD?D-_>W]\?WI_L7_O
M?RJ`*8!L@+&!IH&N@;F!M8&K@;"!K(&T@;*!MX&G@?*!58)6@E>"5H5%A6N%
M3853A6&%6(5`A4:%9(5!A6*%1(51A4>%8X4^A5N%<85.A6Z%=855A6>%8(6,
MA6:%7854A66%;(5CAF6&9(:;AX^'EX>3AY*'B(>!AY:'F(=YAX>'HX>%AY"'
MD8>=AX2'E(><AYJ'B8<>B2:),(DMB2Z))XDQB2*)*8DCB2^)+(D?B?&)X(KB
MBO**](KUBMV*%(ODBM^*\(K(BMZ*X8KHBO^*[XK[BI&,DHR0C/6,[HSQC/",
M\XQLC6Z-I8VGC3../HXXCD".18XVCCR./8Y!CC"./XZ]CC:/+H\UCS*/.8\W
MCS2/=I!YD'N0AI#ZD#.1-9$VD9.1D)&1D8V1CY$GDQZ3"),?DP:3#Y-ZDSB3
M/),;DR.3$I,!DT:3+9,.DPV3RY(=D_J2)9,3D_F2]Y(TDP*3))/_DBF3.9,U
MDRJ3%),,DPN3_I()DP"3^Y(6D[R5S96^E;F5NI6VE;^5M96]E:F6U)8+EQ*7
M$)>9EY>7E)?PE_B7-9@OF#*8))D?F2>9*9F>F>Z9[)GEF>29\)GCF>J9Z9GG
MF;F:OYJTFKN:]IKZFOF:]YHSFX";A9N'FWR;?IM[FX*;DYN2FY";>IN5FWV;
MB)LEG1>=()T>G12=*9T=G1B=(IT0G1F='YV(GH:>AYZNGJV>U9[6GOJ>$I\]
MGR91)5$B4211(%$I4?12DU:,5HU6AE:$5H-6?E:"5G]6@5;66-18SUC26"U;
M)5LR6R-;+%LG6R9;+ULN6WM;\5OR6[==;%YJ7KY?NU_#8;5AO&'G8>!AY6'D
M8>AAWF'O9.EDXV3K9.1DZ&2!98!EMF7:9=)FC6J6:H%JI6J):I]JFVJA:IYJ
MAVJ3:HYJE6J#:JAJI&J1:G]JIFJ::H5JC&J2:EMKK6L);,QOJ6_T;]1OXV_<
M;^UOYV_F;]YO\F_=;^)OZ&_A<?%QZ''R<>1Q\''B<7-S;G-O<Y=TLG2K=)!T
MJG2M=+%TI72O=!!U$742=0]UA'5#=DAV279'=J1VZ7:U=ZMWLG>W=[9WM'>Q
M=ZAW\'?S>/UX`GG[>/QX\G@%>?EX_G@$>:MYJ'E<>EMZ5GI8>E1Z6GJ^>L!Z
MP7H%?`]\\GL`?/][^WL.?/1["WSS>P)\"7P#?`%\^'O]>P9\\'OQ>Q!\"GSH
M?"U^/'Y"?C-^2)@X?BI^27Y`?D=^*7Y,?C!^.WXV?D1^.GY%?W]_?G]]?_1_
M\G\L@+N!Q(',@<J!Q8''@;R!Z8%;@EJ"7(*#A8"%CX6GA96%H(6+A:.%>X6D
MA9J%GH5WA7R%B86AA7J%>(57A8Z%EH6&A8V%F86=A8&%HH6"A8B%A85YA7:%
MF(60A9^%:(:^AZJ'K8?%A["'K(>YA[6'O(>NA\F'PX?"A\R'MX>OA\2'RH>T
MA[:'OX>XA[V'WH>RAS6),XD\B3Z)08E2B3>)0HFMB:^)KHGRB?.)'HL8BQ:+
M$8L%BPN+(HL/BQ*+%8L'BPV+"(L&BQR+$XL:BT^,<(QRC'&,;XR5C)2,^8QO
MC4Z.38Y3CE".3(Y'CD./0(^%D'Z0.)&:D:*1FY&9D9^1H9&=D:"1H9.#DZ^3
M9)-6DT>3?)-8DUR3=I-)DU"349-@DVV3CY-,DVJ3>9-7DU634I-/DW&3=Y-[
MDV&37I-CDV>3@)-.DUF3QY7`E<F5PY7%E;>5KI:PEJR6()<?EQB7'9<9EYJ7
MH9><EYZ7G9?5E]27\9=!F$282IA)F$680Y@EF2N9+)DJF3.9,IDOF2V9,9DP
MF9B9HYFAF0*:^IGTF?>9^9GXF?:9^YG]F?Z9_)D#FKZ:_IK]F@&;_)I(FYJ;
MJ)N>FYN;IINAFZ6;I)N&FZ*;H)NOFS.=09UGG3:=+ITOG3&=.)TPG46=0IU#
MG3Z=-YU`G3V=]7\MG8J>B9Z-GK">R)[:GON>_YXDGR.?(I]4GZ"?,5$M42Y1
MF%:<5I=6FE:=5IE6<%D\6VE<:ES`76U>;E[88=]A[6'N8?%AZF'P8>MAUF'I
M8?]D!&7]9/AD`64#9?QDE&7;9=IFVV;89L5JN6J]:N%JQFJZ:K9JMVK':K1J
MK6I>:\EK"VP'<`QP#7`!<`5P%'`.</]O`'#[;R9P_&_W;PIP`7+_<?EQ`W+]
M<79SN'3`=+5TP72^=+9TNW3"=!1U$W5<=F1V6790=E-V5W9:=J9VO7;L=L)W
MNG?_>`QY$WD4>0EY$'D2>1%YK7FL>5]Z''PI?!E\('P??"U\'7PF?"A\(GPE
M?#!\7'Y0?E9^8WY8?F)^7WY1?F!^5WY3?K5_LW_W?_A_=8#1@=*!T(%?@EZ"
MM(7&A<"%PX7"A;.%M86]A<>%Q(6_A<N%SH7(A<6%L86VA=*%)(:XA;>%OH5I
MAN>'YH?BA]N'ZX?JA^6'WX?SA^2'U(?<A].'[8?8A^.'I(?7A]F'`8CTA^B'
MW8=3B4N)3XE,B4:)4(E1B4F)*HLGBR.+,XLPBS6+1XLOBSR+/HLQBR6+-XLF
MBS:++HLDBSN+/8LZBT*,=8R9C)B,EXS^C`2-`HT`C5R.8HY@CE>.5HY>CF6.
M9XY;CEJ.88Y=CFF.5(Y&CT>/2(]+CRB1.I$[D3Z1J)&ED:>1KY&JD;63C).2
MD[>3FY.=DXF3IY..DZJ3GI.FDY63B).9DY^3C9.QDY&3LI.DDZB3M).CDZ63
MTI73E=&5LY;7EMJ6PEW?EMB6W98CER*7)9>LEZZ7J)>KEZ27JI>BEZ67UY?9
ME]:7V)?ZEU"849A2F+B809D\F3J9#YH+F@F:#9H$FA&:"IH%F@>:!IK`FMR:
M")L$FP6;*9LUFTJ;3)M+F\>;QIO#F[^;P9NUF[B;TYNVF\2;N9N]FUR=4YU/
MG4J=6YU+G5F=5IU,G5>=4IU4G5^=6)U:G8Z>C)[?G@&?`)\6GR6?*Y\JGRF?
M*)],GU6?-%$U4992]U*T4ZM6K5:F5J=6JE:L5MI8W5C;6!)9/5L^6S];PUUP
M7K]?^V$'91!E#64)90QE#F6$9=YEW67>9N=JX&K,:M%JV6K+:M]JW&K0:NMJ
MSVK-:MYJ8&NP:PQL&7`G<"!P%G`K<"%P(G`C<"EP%W`D<!QP*G`,<@IR!W("
M<@5RI7*F<J1RHW*A<LMTQ72W=,-T%G5@=LEWRG?$=_%W'7D;>2%Y''D7>1YY
ML'EG>FAZ,WP\?#E\+'P[?.Q\ZGQV?G5^>'YP?G=^;WYZ?G)^='YH?DM_2G^#
M?X9_MW_]?_Y_>(#7@=6!9()A@F."ZX7QA>V%V87AA>B%VH77A>R%\H7XA=B%
MWX7CA=R%T87PA>:%[X7>A>*%`(CZAP.(]H?WAPF(#(@+B`:(_(<(B/^'"H@"
MB&*)6HE;B5>)88E<B5B)78E9B8B)MXFVB?:)4(M(BTJ+0(M3BU:+5(M+BU6+
M48M"BU*+5XM#C'>,=HR:C`:-!XT)C:R-JHVMC:N-;8YXCG..:HYOCGN.PHY2
MCU&/3X]0CU./M(]`D3^1L)&MD=Z3QY//D\*3VI/0D_F3[)/,D]F3J9/FD\J3
MU)/ND^.3U9/$D\Z3P)/2D^>3?97:E=N5X98IERN7+)<HER:7LY>WE[:7W9?>
ME]^77)A9F%V85YB_F+V8NYB^F$B91YE#F::9IYD:FA6:)9H=FB2:&YHBFB":
M)YHCFAZ:')H4FL*:"YL*FPZ;#)LWF^J;ZYO@F]Z;Y)OFF^*;\)O4F]>;[)O<
MF]F;Y9O5F^&;VIMWG8&=BIV$G8B=<9V`G7B=AIV+G8R=?9UKG72==9UPG6F=
MA9USG7N=@IUOG7F=?YV'G6B=E)Z1GL">_)XMGT"?09]-GU:?5Y]8GS=3LE:U
M5K-6XUA%6\9=QUWN7N]>P%_!7_EA%V46915E$V7?9>AFXV;D9O-J\&KJ:NAJ
M^6KQ:NYJ[VH\<#5P+W`W<#1P,7!"<#AP/W`Z<#EP0'`[<#-P07`3<A1RJ')]
M<WQSNG2K=JIVOG;M=LQWSG?/=\UW\G<E>2-Y)WDH>21Y*7FR>6YZ;'IM>O=Z
M27Q(?$I\1WQ%?.Y\>WY^?H%^@'ZZ?_]_>8#;@=F!"X)H@FF"(H;_A0&&_H4;
MA@"&]H4$A@F&!88,AOV%&8@0B!&(%X@3B!:(8XEFB;F)]XE@BVJ+78MHBV.+
M98MGBVV+KHV&CHB.A(Y9CU:/5X]5CUB/6H^-D$.109&WD;61LI&SD0N4$Y3[
MDR"4#Y04E/Z3%900E"B4&90-E/63`)3WDP>4#I06E!*4^I,)E/B3"I3_D_R3
M#)3VDQ&4!I3>E>"5WY4NER^7N9>[E_V7_I=@F&*88YA?F,&8PIA0F4Z969E,
MF4N94YDRFC2:,9HLFBJ:-IHIFBZ:.)HMFL>:RIK&FA";$IL1FPN<")SWFP6<
M$ISXFT"<!YP.G`:<%YP4G`F<GYV9G:2=G9V2G9B=D)V;G:"=E)V<G:J=EYVA
MG9J=HIVHG9Z=HYV_G:F=EIVFG:>=F9Z;GIJ>Y9[DGN>>YIXPGRZ?6Y]@GUZ?
M79]9GY&?.E$Y49A2EU+#5KU6OE9(6T=;RUW/7?%>_6$;90)K_&H#:_AJ`&M#
M<$1P2G!(<$EP17!&<!UR&G(9<GYS%W5J=M!W+7DQ>2]Y5'Q3?/)\BGZ'?HA^
MBWZ&?HU^37^[?S"`W8$8ABJ&)H8?AB.&'(89AB>&+H8AAB"&*88>AB6&*8@=
MB!N(((@DB!R(*XA*B&V):8ENB6N)^HEYBWB+18MZBWN+$(T4C:^-CHZ,CEZ/
M6X]=CT:11)%%D;F1/Y0[E#:4*90]E#R4,)0YE"J4-Y0LE$"4,93EE>25XY4U
MESJ7OY?AEV28R9C&F,"86)E6F3F:/9I&FD2:0II!FCJ:/YK-FA6;%YL8FQ:;
M.IM2FRN<'9P<G"R<(YPHG"F<))PAG+>=MIV\G<&=QYW*G<^=OIW%G<.=NYVU
MG<Z=N9VZG:R=R)VQG:V=S)VSG<V=LIUZGIR>ZY[NGNV>&Y\8GQJ?,9].GV6?
M9)^2G[E.QE;%5LM6<5E+6TQ;U5W17?)>(64@929E(F4+:PAK"6L-;%5P5G!7
M<%)P'G(?<JER?W/8=-5TV737=&UVK78U>;1Y<'IQ>E=\7'Q9?%M\6GST?/%\
MD7Y/?X=_WH%K@C2&-88SABR&,H8VABR(*(@FB"J()8AQB;^)OHG[B7Z+A(N"
MBX:+A8M_BQ6-E8Z4CIJ.DHZ0CI:.EXY@CV*/1Y%,E%"42I1+E$^41Y1%E$B4
M291&E#^7XY=JF&F8RYA4F5N93II3FE2:3)I/FDB:2II)FE*:4)K0FAF;*YL[
MFU:;59M&G$B</YQ$G#F<,YQ!G#R<-YPTG#*</9PVG-N=TIW>G=J=RYW0G=R=
MT9W?G>F=V9W8G=:=]9W5G=V=MI[PGC6?,Y\RGT*?:Y^5GZ*?/5&94NA8YUAR
M64U;V%TOB$]?`6(#8@1B*64E999EZV81:Q)K#VO*:UMP6G`B<H)S@7.#<W!V
MU'=G?&9\E7YL@CJ&0(8YACR&,88[ACZ&,(@RB"Z(,XAVB72)<XG^B8R+CHN+
MBXB+18P9C9B.9(]CC[R18I15E%V45Y1>E,27Q9<`F%::69H>FQ^;()M2G%B<
M4)Q*G$V<2YQ5G%F<3)Q.G/N=]YWOG>.=ZYWXG>2=]IWAG>Z=YIWRG?"=XIWL
MG?2=\YWHG>V=PI[0GO*>\YX&GQR?.)\WGS:?0Y]/GW&?<)]NGV^?TU;-5DY;
M;5PM9>UF[F83:U]P87!=<&!P(W+;=.5TU7<X>;=YMGEJ?)=^B7]M@D.&.(@W
MB#6(2XB4BY6+GHZ?CJ".G8Z^D;V1PI%KE&B4:93EED:70Y='E\>7Y9=>FM6:
M69MCG&><9IQBG%Z<8)P"GOZ=!YX#G@:>!9X`G@&>"9[_G?V=!)Z@GAZ?1I]T
MGW6?=I_45BYEN&48:QEK%VL::V)P)G*J<MAWV7<Y>6E\:WSV?)I^F'Z;?IE^
MX('A@4:&1X9(AGF)>HE\B7N)_XF8BYF+I8ZDCJ..;I1ME&^4<91SE$F7<IA?
MF6B<;IQMG`N>#9X0G@^>$IX1GJ&>]9X)GT>?>)][GWJ?>9\>5V9P;WP\B+*-
MIH[#D724>)1VE'648)ITG'.<<9QUG!2>$Y[VG@J?I)]H<&5P]WQJACZ(/8@_
MB)Z+G(RICLF.2Y=SF'28S)AAF:N99)IFFF>:))L5GA>>2)\'8AYK)W),AJB.
M@I2`E(&4:9IHFBZ;&9XI<DN&GXN#E'F<MYYU=FN:>IP=GFEP:G"DGGZ?29^8
MGP`````````````````````````````````P#/\!,`(P#O\B(!O_&O\?_P'_
M,/XF("4@4/YD_U+^MP!4_E7^5OY7_ES_$R`Q_A0@,_[]_S3^3_X(_PG_-?XV
M_EO_7?\W_CC^%#`5,#G^.OX0,!$P._X\_@HP"S`]_C[^"#`),#_^0/X,,`TP
M0?Y"_@XP#S!#_D3^6?Y:_EO^7/Y=_E[^&"`9(!P@'2`=,!XP-2`R(`/_!O\*
M_SL@IP`#,,LESR6S);(ESB4&)@4FQR7&):$EH"6]);PEHS(%(3X@_?\___W_
M2?Y*_DW^3OY+_DS^7_Y@_F'^"_\-_]<`]P"Q`!HB'/\>_QW_9B)G(F`B'B)2
M(F$B8OYC_F3^9?YF_CPB*2(J(J4B("(?(K\BTC/1,RLB+B(U(C0B0"9")D$F
M"2:1(9,AD"&2(98AER&9(9@A)2(C(OW__?\/_SS_!/^E`!(PH@"C``7_(/\#
M(0DA:?YJ_FO^U3.<,YTSGC/.,Z$SCC./,\0SL`!945M17E%=46%18U'G5>ET
MSGR!)8(E@R6$)84EAB6')8@ECR6.)8TEC"6+)8HEB24\)30E+"4D)1PEE"4`
M)0(EE24,)1`E%"48)6TE;B5P)6\E4"5>)6HE827B)>,EY27D)7$E<B5S)1#_
M$?\2_Q/_%/\5_Q;_%_\8_QG_8"%A(6(A8R%D(64A9B%G(6@A:2$A,"(P(S`D
M,"4P)C`G,"@P*3#]_T13_?\A_R+_(_\D_R7_)O\G_RC_*?\J_RO_+/\M_R[_
M+_\P_S'_,O\S_S3_-?\V_S?_./\Y_SK_0?]"_T/_1/]%_T;_1_](_TG_2O]+
M_TS_3?]._T__4/]1_U+_4_]4_U7_5O]7_UC_6?]:_Y$#D@.3`Y0#E0.6`Y<#
MF`.9`YH#FP.<`YT#G@.?`Z`#H0.C`Z0#I0.F`Z<#J`.I`[$#L@.S`[0#M0.V
M`[<#N`.Y`[H#NP.\`[T#O@._`\`#P0/#`\0#Q0/&`\<#R`/)`P4Q!C$',0@Q
M"3$*,0LQ##$-,0XQ#S$0,1$Q$C$3,10Q%3$6,1<Q&#$9,1HQ&S$<,1TQ'C$?
M,2`Q(3$B,2,Q)#$E,28Q)S$H,2DQV0+)`LH"QP++`OW__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]_P!.64X!3@-.0TY=3H9.C$ZZ3C]195%K
M4>!1`%(!4IM2%5-!4UQ3R%,)3@M."$X*3BM..$[A445.2$Y?3EY.CDZA3D!1
M`U+Z4D-3R5/C4Q]7ZU@562=9<UE06U%;4UOX6P]<(EPX7'%<W5WE7?%=\EWS
M7?Y=<E[^7@M?$U]-8A%.$$X-3BU.,$XY3DM..5R(3I%.E4Z23I1.HD[!3L!.
MPT[&3L=.S4[*3LM.Q$Y#44%19U%M46Y1;%&74?91!E('4@A2^U+^4O]2%E,Y
M4TA31U-%4UY3A%/+4\I3S5/L6"E9*UDJ62U95%L17"1<.EQO7/1=>U[_7A1?
M%5_#7PAB-F)+8DYB+V6'99=EI&6Y9>5E\&8(9RAG(&MB:WEKRVO4:]MK#VPT
M;&MP*G(V<CMR1W)9<EMRK'*+<QE.%DX53A1.&$X[3DU.3TY.3N5.V$[43M5.
MUD[73N-.Y$[93MY.15%$48E1BE&L4?E1^E'X40I2H%*?4@53!E,74QU3WTY*
M4TE385-@4V]3;E.[4^]3Y%/S4^Q3[E/I4^A3_%/X4_53ZU/F4^I3\E/Q4_!3
MY5/M4_M3VU;:5A99+EDQ6719=EE56X-;/%SH7>==YET"7@-><UY\7@%?&%\7
M7\5?"F)38E1B4F)18J5EYF4N9RQG*F<K9RUG8VO-:Q%L$&PX;$%L0&P^;*]R
MA'.)<]QTYG08=1]U*'4I=3!U,74R=3-UBW5]=JYVOW;N=MMWXG?S=SIYOGET
M>LMZ'DX?3E).4TYI3IE.I$ZF3J5._TX)3QE/"D\53PU/$$\13P]/\D[V3OM.
M\$[S3OU.`4\+3TE11U%&44A1:%%Q48U1L%$74A%2$E(.4A92HU((4R%3(%-P
M4W%3"50/5`Q4"E005`%4"U0$5!%4#50(5`-4#E0&5!)4X%;>5MU6,U<P5RA7
M+5<L5R]7*5<961I9-UDX6819>%F#67U9>5F"68%95UM86X=;B%N%6XE;^EL6
M7'E<WET&7G9>=%X/7QM?V5_67PYB#&(-8A!B8V);8EAB-F7I9>AE[&7M9?)F
M\V8)9SUG-&<Q9S5G(6MD:WMK%FQ=;%=L66Q?;&!L4&Q5;&%L6VQ-;$YL<'!?
M<EUR?G;Y>G-\^'PV?XI_O7\!@`.`#(`2@#.`?X")@(N`C(#C@>J!\X'\@0R"
M&X(?@FZ"<H)^@FN&0(A,B&.(?XDAEC).J$Y-3T]/1T]73UY/-$];3U5/,$]0
M3U%//4\Z3SA/0T]43SQ/1D]C3UQ/8$\O3TY/-D]93UU/2$]:3TQ12U%-4751
MME&W4252)%(I4BI2*%*K4JE2JE*L4B-3<U-U4QU4+50>5#Y4)E1.5"=41E1#
M5#-42%1"5!M4*51*5#E4.U0X5"Y4-50V5"!4/%1`5#%4*U0?5"Q4ZE;P5N16
MZU9*5U%70%=-5T=73E<^5U!73U<[5^]8/EF=69)9J%F>6:-9F5F668U9I%F3
M68I9I5E=6UQ;6EM;6XQ;BUN/6RQ<0%Q!7#]</ER07)%<E%R,7.M=#%Z/7H=>
MBE[W7@1?'U]D7V)?=U]Y7]A?S%_77\U?\5_K7_A?ZE\28A%BA&*78I9B@&)V
M8HEB;6**8GQB?F)Y8G-BDF)O8IAB;F*58I-BD6*&8CEE.V4X9?%E]&9?9TYG
M3V=09U%G7&=69UYG26=&9V!G4V=79V5KSVM";%YLF6R!;(ALB6R%;)ML:FQZ
M;)!L<&R,;&ALEFR2;'UL@VQR;'YL=&R&;'9LC6R4;)AL@FQV<'QP?7!X<&)R
M87)@<L1RPG*6<RQU*W4W=3AU@G;O=N-WP7G`>;]Y=GK[?%5_EH"3@)V`F(";
M@)J`LH!O@I*"BX*-@HN)THD`BC>,1HQ5C)V,9(UPC;.-JX[*CIN/L(_"C\:/
MQ8_$C^%=D9"BD*J0II"CD$F1QI',D3*6+I8QEBJ6+)8F3E9.<TZ+3IM.GDZK
M3JQ.;T^=3XU/<T]_3VQ/FT^+3X9/@T]P3W5/B$]I3WM/ED]^3X]/D4]Z3U11
M4E%546E1=U%V47A1O5']43M2.%(W4CI2,%(N4C9205*^4KM24E-44U-345-F
M4W=3>%-Y4]93U%/74W-4=5265'A4E52`5'M4=U2$5))4AE1\5)!4<51V5(Q4
MFE1B5&A4BU1]5(Y4^E:#5W=7:E=I5V%79E=D5WQ7'%E)64=92%E$6519OEF[
M6=19N5FN6=%9QEG06<U9RUG36<I9KUFS6=)9Q5E?6V1;8UN76YI;F%N<6YE;
MFUL:7$A<15Q&7+=<H5RX7*E<JURQ7+-<&%X:7A9>%5X;7A%>>%Z:7I=>G%Z5
M7I9>]EXF7R=?*5^`7X%??U]\7]U?X%_]7_5?_U\/8!1@+V`U8!9@*F`58"%@
M)V`I8"M@&V`68A5B/V(^8D!B?V+)8LQBQ&*_8L)BN6+28MMBJV+38M1BRV+(
M8JABO6*\8M!BV6+'8LUBM6+:8K%BV&+68M=BQF*L8LYB/F6G9;QE^F449A-F
M#&8&9@)F#F8`9@]F%68*9@=F#6<+9VUGBV>59W%GG&=S9W=GAV>=9Y=G;V=P
M9W]GB6=^9Y!G=6>:9Y-G?&=J9W)G(VMF:V=K?VL3;!MLXVSH;/-LL6S,;.5L
MLVR];+YLO&SB;*MLU6S3;+ALQ&RY;,%LKFS7;,5L\6R_;+MLX6S;;,ILK&SO
M;-QLUFS@;)5PCG"2<(IPF7`L<BUR.')(<F=R:7+`<LYRV7+7<M!RJ7.H<Y]S
MJW.E<SUUG769=9IUA';"=O)V]';E=_UW/GE`>4%YR7G(>7IZ>7KZ>OY\5'^,
M?XM_!8"Z@*6`HH"Q@*&`JX"I@+2`JH"O@.6!_H$-@K."G8*9@JV"O8*?@KF"
ML8*L@J6"KX*X@J."L(*^@K>"3H9QAAU2:(C+CLZ/U(_1C[60N)"QD+:0QY'1
MD7>5@)4<ED"6/Y8[ED260I:YENB64I=>EY].K4ZN3N%/M4^O3[]/X$_13\]/
MW4_#3[9/V$_?3\I/UT^N3]!/Q$_"3]I/SD_>3[=/5U&249%1H%%.4D-22E)-
M4DQ22U)'4L=2R5+#4L%2#5-74WM3FE/;4ZQ4P%2H5,Y4R52X5*94LU3'5,)4
MO52J5,%4Q%3(5*]4JU2Q5+M4J52G5+]4_U:"5XM7H%>C5Z)7SE>N5Y-755E1
M64]93EE06=Q9V%G_6>-9Z%D#6N59ZEG:6>99`5K[66E;HUNF6Z1;HENE6P%<
M3EQ/7$U<2US97-)<]UT=7B5>'UY]7J!>IE[Z7@A?+5]E7XA?A5^*7XM?AU^,
M7XE?$F`=8"!@)6`.8"A@36!P8&A@8F!&8$-@;&!K8&I@9&!!8MQB%F,)8_QB
M[6(!8^YB_6('8_%B]V+O8NQB_F+T8A%C`F,_945EJV6]9>)E)68M9B!F)V8O
M9A]F*&8Q9B1F]V;_9]-G\6?49]!G[&>V9Z]G]6?I9^]GQ&?19[1GVF?E9[AG
MSV?>9_-GL&?99^)GW6?29VIK@VN&:[5KTFO7:Q]LR6P+;3)M*FU!;25M#&TQ
M;1YM%VT[;3UM/FTV;1MM]6PY;2=M.&TI;2YM-6T.;2MMJW"Z<+-PK'"O<*UP
MN'"N<*1P,')R<F]R='+I<N!RX7*W<\ISNW.R<\USP'.S<QIU+75/=4QU3G5+
M=:MUI'6E=:)UHW5X=H9VAW:(=LAVQG;#=L5V`7?Y=OAV"7<+=_YV_'8'=]QW
M`G@4>`QX#7A&>4EY2'E'>;EYNGG1>=)YRWE_>H%Z_WK]>GU\`GT%?0!]"7T'
M?01]!GTX?XY_OW\$@!"`#8`1@#:`UH#E@-J`PX#$@,R`X8#;@,Z`WH#D@-V`
M]($B@N>"`X,%@^."VX+F@@2#Y8("@PF#TH+7@O&"`8/<@M2"T8+>@M."WX+O
M@@:#4(9YAGN&>H9-B&N(@8G4B0B*`HH#BIZ,H(QTC7.-M(W-CLR.\(_FC^*/
MZH_EC^V/ZX_DC^B/RI#.D,&0PY!+D4J1S9&"E5"62Y9,EDV68I=IE\N7[9?S
MEP&8J)C;F-^8EIF9F5A.LTX,4`U0(U#O3R90)5#X3RE0%E`&4#Q0'U`:4!)0
M$5#Z3P!0%%`H4/%/(5`+4!E0&%#S3^Y/+5`J4/Y/*U`)4'Q1I%&E4:)1S5',
M4<91RU%64EQ25%);4EU2*E-_4Y]3G5/?4^A4$%4!53=5_%3E5/)4!E7Z5!15
MZ53M5.%4"57N5.I4YE0G50=5_50/50-7!%?"5]17RU?#5PE8#UE765A96ED1
M6AA:'%H?6AM:$UKL62!:(UHI6B5:#%H)6FM;6%RP6[-;MENT6ZY;M5NY6[A;
M!%Q17%5<4%SM7/U<^USJ7.A<\%SV7`%=]%SN72U>*UZK7JU>IUXQ7Y)?D5^0
M7UE@8V!E8%!@56!M8&E@;V"$8)]@FF"-8)1@C&"%8)9@1V+S8@AC_V).8SYC
M+V-58T)C1F-/8TEC.F-08SUC*F,K8RAC36-,8TAE26699<%EQ65"9DEF3V9#
M9E)F3&9%9D%F^&849Q5G%V<A:#AH2&A&:%-H.6A":%1H*6BS:!=H3&A1:#UH
M]&=0:$!H/&A#:"IH16@3:!AH06B*:XEKMVLC;"=L*&PF;"1L\&QJ;95MB&V'
M;69M>&UW;5EMDVUL;8EM;FU:;71M:6V,;8IM>6V%;65ME&W*<-APY'#9<,AP
MSW`Y<GER_'+Y<OUR^'+W<H9S[7,)=.YSX'/J<]YS5'5==5QU6G59=;YUQ77'
M=;)ULW6]=;QUN77"=;AUBW:P=LIVS7;.=BEW'W<@=RAWZ7<P>"=X.'@=>#1X
M-W@E>"UX('@?>#)X57E0>6!Y7WE6>5YY77E7>5IYY'GC>>=YWWGF>>EYV'F$
M>HAZV7H&>Q%[B7PA?1=]"WT*?2!](GT4?1!]%7T:?1Q]#7T9?1M].G]??Y1_
MQ7_!?P:`&(`5@!F`%X`]@#^`\8`"@?"`!8'M@/2`!H'X@/.`"(']@`J!_(#O
M@.V![($`@A""*H(K@BB"+(*[@BN#4H-4@TJ#.(-0@TF#-8,T@T^#,H,Y@S:#
M%X-`@S&#*(-#@U2&BH:JAI.&I(:IAHR&HX:<AG"(=XB!B(*(?8AYB!B*$(H.
MB@R*%8H*BA>*$XH6B@^*$8I(C'J,>8RAC**,=XVLCM*.U([/CK&/`9`&D/>/
M`)#ZC_2/`Y#]CP60^(^5D.&0W9#BD%*139%,D=B1W9'7D=R1V9&#E6*68Y9A
MEEN6799DEEB67I:[EN*8K)FHFMB:)9LRFSR;?DYZ4'U07%!'4$-03%!:4$E0
M95!V4$Y055!U4'10=U!/4`]0;U!M4%Q1E5'P46I2;U+24ME2V%+54A!3#U,9
M4S]30%,^4\-3_&9&56I59E5$55Y5855#54I5,55654]5554O5615.%4N55Q5
M+%5C53-5055750A7"U<)5]]7!5@*6`98X%?D5_I7`E@U6/=7^5<@66)9-EI!
M6DE:9EIJ6D!:/%IB6EI:1EI*6G!;QUO%6\1;PEN_6\9;"5P(7`=<8%Q<7%U<
M!UT&70Y=&UT672)=$5TI711=&5TD72==%UWB73A>-EXS7C=>MUZX7K9>M5Z^
M7C5?-U]77VQ?:5]K7Y=?F5^>7YA?H5^@7YQ??V"C8(E@H&"H8,M@M&#F8+U@
MQ6"[8+5@W&"\8-A@U6#&8-]@N&#:8,=@&F(;8DABH&.G8W)CEF.B8Z5C=V-G
M8YACJF-Q8ZECB6.#8YMC:V.H8X1CB&.98Z%CK&.28X]C@&-[8VEC:&-Z8UUE
M5F5195EE5V5?54]E6&55951EG&6;9:QESV7+9<QESF5=9EIF9&9H9F9F7F;Y
M9M=2&V>!:*]HHFB3:+5H?VAV:+%HIVB7:+!H@VC$:*UHAFB%:)1HG6BH:)]H
MH6B":#)KNFOK:^QK*VR.;;QM\VW9;;)MX6W,;>1M^VWZ;05NQVW+;:]MT6VN
M;=YM^6VX;?=M]6W%;=)M&FZU;=IMZVW8;>IM\6WN;>AMQFW$;:IM[&V_;>9M
M^7`)<0IQ_7#O<#UR?7*!<AQS&W,6<Q-S&7.'<P5T"G0#=`9T_G,-=.!T]G3W
M=!QU(G5E=69U8G5P=8]UU'75=;5URG7-=8YVU';2=MMV-W<^=SQW-G<X=SIW
M:WA#>$YX97EH>6UY^WF2>I5Z('LH>QM[+'LF>QE['GLN>Y)\EWR5?$9]0WUQ
M?2Y].7T\?4!],'TS?41]+WU"?3)],7T]?YY_FG_,?\Y_TG\<@$J`1H`O@1:!
M(X$K@2F!,($D@0*"-8(W@C:".8*.@YZ#F(-X@Z*#EH.]@ZN#DH.*@Y.#B8.@
M@W>#>X-\@X:#IX-5AFI?QX;`AK:&Q(:UAL:&RX:QAJ^&R893B)Z(B(BKB)*(
MEHB-B(N(DXF/B2J*'8HCBB6*,8HMBA^*&XHBBDF,6HRIC*R,JXRHC*J,IXQG
MC6:-OHVZC=N.WXX9D`V0&I`7D".0'Y`=D!"0%9`>D""0#Y`BD!:0&Y`4D.B0
M[9#]D%>1SI'UD>:1XY'GD>V1Z9&)E6J6=99SEGB6<)9TEG:6=Y9LEL"6ZI;I
MEN!ZWWH"F`.86IOEG'6>?YZEGKN>HE"-4(50F5"14(!0EE"84)I0`&?Q47)2
M=%)U4FE2WE+=4MM26E.E4WM5@%6G57Q5BE6=59A5@E6<5:I5E%6'58M5@U6S
M5:Y5GU4^5;)5FE6[5:Q5L55^58E5JU6950U7+U@J6#18)%@P6#%8(5@=6"!8
M^5CZ6&!9=UJ:6G]:DEJ;6J=:<UMQ6]);S%O36]!;"EP+7#%<3%U0731=1UW]
M745>/5Y`7D->?E[*7L%>PE[$7CQ?;5^I7ZI?J%_18.%@LF"V8.!@'&$C8?I@
M%6'P8/M@]&!H8?%@#F'V8`EA`&$281]B26*C8XQCSV/`8^ECR6/&8\UCTF/C
M8]!CX6/68^UC[F-V8_1CZF/;8U)DVF/Y8UYE9F5B96-ED6609:]E;F9P9G1F
M=F9O9I%F>F9^9G=F_F;_9A]G'6?Z:-5HX&C8:-=H!6G?:/5H[FCG:/EHTFCR
M:.-HRVC-:`UI$FD.:<EHVFAN:?MH/FLZ:SUKF&N6:[QK[VLN;"]L+&PO;CAN
M5&XA;C)N9VY*;B!N)6XC;AMN6VY8;B1N5FYN;BUN)FYO;C1N36XZ;BQN0VX=
M;CYNRVZ);AEN3FYC;D1N<FYI;E]N&7$:<29Q,'$A<39Q;G$<<4QRA'*`<C9S
M)7,T<RES.G0J=#-T(G0E=#5T-G0T="]T&W0F="AT)74F=6MU:G7B==MUXW79
M==AUWG7@=7MV?':6=I-VM';<=D]W[7==>&QX;W@->@AZ"WH%>@!ZF'J7>I9Z
MY7KC>DE[5GM&>U![4GM4>TU[2WM/>U%[GWRE?%Y]4'UH?55]*WUN?7)]87UF
M?6)]<'US?815U'_5?PN`4H"%@%6!5(%+@5&!3H$Y@4:!/H%,@5.!=($2@AR"
MZ8,#A/B##83@@\6#"X3!@^^#\8/T@U>$"H3P@PR$S(/]@_*#RH,XA`Z$!(3<
M@P>$U(/?@UN&WX;9ANV&U(;;AN2&T(;>AE>(P8C"B+&(@XF6B3N*8(I5BEZ*
M/(I!BE2*6XI0BD:*-(HZBC:*5HIAC(*,KXR\C+.,O8S!C+N,P(RTC+>,MHR_
MC+B,BHV%C8&-SHW=C<N-VHW1C<R-VXW&C?N.^([\CIR/+I`UD#&0.)`RD#:0
M`I'UD`F1_I!CD661SY$4DA62(Y()DAZ2#9(0D@>2$9*4E8^5BY61E9.5DI6.
ME8J6CI:+EGV6A9:&EHV6<I:$EL&6Q9;$EL:6QY;OEO*6S)<%F`:8")CGF.J8
M[YCIF/*8[9BNF:V9PY[-GM&>@DZM4+50LE"S4,50OE"L4+=0NU"O4,=0?U)W
M4GU2WU+F4N12XE+C4B]3WU7H5=-5YE7.5=Q5QU715>-5Y%7O5=I5X57%5<95
MY57)51)7$U=>6%%86%A76%I85%AK6$Q8;5A*6&)84EA+6&=9P5K)6LQ:OEJ]
M6KQ:LUK"6K)::5UO74Q>>5[)7LA>$E]97ZQ?KE\:80]A2&$?8?-@&V'Y8`%A
M"&%.84QA1&%-83YA-&$G80UA!F$W82%B(F(39#YD'F0J9"UD/60L9`]D'&04
M9`UD-F069!=D!F1L99]EL&679HEFAV:(9I9FA&:89HUF`V>4:6UI6FEW:6!I
M5&EU:3!I@FE*:6AI:VE>:5-I>6F&:5UI8VE;:4=K<FO`:[]KTVO]:Z)NKV[3
M;K9NPFZ0;IUNQV[%;J5NF&Z\;KINJV[1;I9NG&[$;M1NJFZG;K1N3G%9<6EQ
M9'%)<6=Q7'%L<69Q3'%E<5YQ1G%H<59Q.G)2<C=S17,_<SYS;W1:=%5T7W1>
M=$%T/W19=%MT7'1V=7AU`';P=0%V\G7Q=?IU_W7T=?-UWG;?=EMW:W=F=UYW
M8W=Y=VIW;'=<=V5W:'=B=^YWCGBP>)=XF'B,>(EX?'B1>)-X?WAZ>7]Y@7DL
MA+UY''H:>B!Z%'H?>AYZGWJ@>G=[P'M@>VY[9WNQ?+-\M7R3?7E]D7V!?8]]
M6WUN?VE_:G]R?ZE_J'^D?U:`6("&@(2`<8%P@7B!98%N@7.!:X%Y@7J!9H$%
M@D>"@H1WA#V$,81UA&:$:X1)A&R$6X0\A#6$881CA&F$;81&A%Z&7(9?AOF&
M$X<(AP>'`(?^AON&`H<#AP:'"H=9B-^(U(C9B-R(V(C=B.&(RHC5B-*(G(GC
MB6N*<HISBF:*:8IPBH>*?(ICBJ"*<8J%BFV*8HINBFR*>8I[BCZ*:(IBC(J,
MB8S*C,>,R(S$C+*,PXS"C,6,X8W?C>B-[XWSC?J-ZHWDC>:-LHX#CPF/_HX*
MCY^/LH]+D$J04Y!"D%20/)!5D%"01Y!/D$Z039!1D#Z009`2D1>1;)%JD6F1
MR9$WDE>2.)(]DD"2/I);DDN29))1DC2229)-DD62.9(_DEJ2F)68EI26E9;-
MELN6R9;*EO>6^Y;YEO:65I=TEW:7$)@1F!.8"I@2F`R8_)CTF/V8_IBSF;&9
MM)GAFNF<@IX.GQ.?()_G4.Y0Y5#64.U0VE#54,]0T5#Q4,Y0Z5!B4?-1@U*"
M4C%3K5/^50!6&U875OU5%%8&5@E6#58.5O=5%E8?5@A6$%;V51A7%E=U6'Y8
M@UB36(I8>5B%6'U8_5@E62)9)%EJ66E9X5KF6NE:UUK66MA:XUIU6]Y;YUOA
M6^5;YEOH6^);Y%O?6PU<8ER$78==6UYC7E5>5UY47M->UEX*7T9?<%^Y7T=A
M/V%+87=A8F%C85]A6F%8875A*F*'9%AD5&2D9'AD7V1Z9%%D9V0T9&UD>V1R
M9:%EUV769:)FJ&:=9IQIJ&F5:<%IKFG3:<MIFVFW:;MIJVFT:=!IS6FM:<QI
MIFG#::-I26M,:S-L,V\4;_YN$V_T;BEO/F\@;RQO#V\";R)O_V[O;@9O,6\X
M;S)O(V\5;RMO+V^(;RIO[&X!;_)NS&[W;I1QF7%]<8IQA'&2<3YRDG*6<D1S
M4'-D=&-T:G1P=&UT!'61=2=V#78+=@EV$W;A=N-VA'=]=W]W87?!>)]XIWBS
M>*EXHWB.>8]YC7DN>C%ZJGJI>NUZ[WJA>Y5[BWMU>Y=[G7N4>X][N'N'>X1[
MN7R]?+Y\NWVP?9Q]O7V^?:!]RGVT?;)]L7VZ?:)]OWVU?;A]K7W2?<=]K'UP
M?^!_X7_??UZ`6H"'@%"!@(&/@8B!BH%_@8*!YX'Z@0>"%((>@DN"R82_A,:$
MQ(29A)Z$LH2<A,N$N(3`A-.$D(2\A-&$RH0_AQR'.X<BAR6'-(<8AU6'-X<I
MA_.(`HGTB/F(^(C]B.B(&HGOB*:*C(J>BJ.*C8JABI.*I(JJBJ6*J(J8BI&*
MFHJGBFJ,C8R,C-.,T8S2C&N-F8V5C?R-%(\2CQ6/$X^CCV"06)!<D&.069!>
MD&*079!;D!F1&)$>D761>)%WD721>)*`DH62F)*6DGN2DY*<DJB2?)*1DJ&5
MJ)6IE:.5I96DE9F6G):;ELR6TI8`EWR7A9?VEQ>8&)BOF+&8`YD%F0R9"9G!
MF:^:L)KFFD&;0IOTG/:<\YR\GCN?2I\$40!1^U#U4/E0`E$(40E1!5'<48=2
MB%*)4HU2BE+P4K)3+E8[5CE6,E8_5C16*5935DY65U9T5C96+U8P5H!8GUB>
M6+-8G%BN6*E8IEAM60E;^UH+6_5:#%L(6^Y;[%OI6^M;9%QE7)U=E%UB7E]>
M85[B7MI>WU[=7N->X%Y(7W%?MU^U7W9A9V%N85UA56&"87QA<&%K87YAIV&0
M8:MACF&L89IAI&&48:YA+F)I9&]D>62>9+)DB&209+!DI6239)5DJ6229*YD
MK62K9)IDK&299*)DLV1U97=E>&6N9JMFM&:Q9B-J'VKH:0%J'FH9:OUI(6H3
M:@IJ\VD":@5J[6D1:E!K3FND:\5KQFL_;WQOA&]1;V9O5&^&;VUO6V]X;VYO
MCF]Z;W!O9&^7;UAOU6YO;V!O7V^?<:QQL7&H<59RFW).<U=S:72+=(-T?G2`
M=']U('8I=A]V)'8F=B%V(G::=KIVY':.=X=WC'>1=XMWRWC%>+IXRGB^>-5X
MO'C0>#]Z/'I`>CUZ-WH[>J]ZKGJM>[%[Q'NT>\9[QWO!>Z![S'O*?.!]]'WO
M??M]V'WL?=U]Z'WC?=I]WGWI?9Y]V7WR??E]=7]W?Z]_Z7\F@)N!G(&=@:"!
MFH&8@1>%/84:A>Z$+(4MA1.%$84CA2&%%(7LA"6%_X0&A8*'=(=VAV"'9H=X
MAVB'68=7ATR'4X=;B%V($(D'B1*)$XD5B0J)O(K2BL>*Q(J5BLN*^(JRBLF*
MPHJ_BK"*UHK-BK:*N8K;BDR,3HQLC.",WHSFC.2,[(SMC.*,XXS<C.J,X8QM
MC9^-HXTKCA".'8XBC@^.*8X?CB&.'HZZCAV/&X\?CRF/)H\JCQR/'H\ECVF0
M;I!HD&V0=Y`PD2V1)Y$QD8>1B9&+D8.1Q9*[DK>2ZI*LDN22P9*SDKR2TI+'
MDO"2LI*ME;&5!)<&EP>7"9=@EXV7BY>/ER&8*Y@<F+.8"ID3F1*9&)G=F="9
MWYG;F=&9U9G2F=F9MYKNFN^:)YM%FT2;=YMOFP:="9T#G:F>OI[.GJA84I\2
M41A1%%$04151@%&J4=U1D5*34O-2659K5GE6:59D5GA6:E9H5F56<59O5FQ6
M8E9V5L%8OEC'6,58;ED=6S1;>%OP6PY<2E^R89%AJ6&*8<UAMF&^8<IAR&$P
M8L5DP63+9+MDO&3:9,1DQV3"9,UDOV329-1DOF1T9<9FR6:Y9L1FQV:X9CUJ
M.&HZ:EEJ:VI8:CEJ1&IB:F%J2VI':C5J7VI(:EEK=VL%;,)OL6^A;\-OI&_!
M;Z=OLV_`;[EOMF^F;Z!OM&^^<<EQT''2<<AQU7&Y<<YQV7'<<<-QQ'%H<YQT
MHW28=)]TGG3B=`QU#74T=CAV.G;G=N5VH'>>=Y]WI7?H>-IX['CG>*9Y37I.
M>D9Z3'I+>KIZV7L1?,E[Y'O;>^%[Z7OF>]5\UGP*?A%^"'X;?B-^'GX=?@E^
M$'YY?[)_\'_Q?^Y_*("S@:F!J('[@0B"6()9@DJ%685(A6B%:85#A4F%;85J
MA5Z%@X>?AYZ'HH>-AV&(*HDRB26)*XDAB:J)IHGFBOJ*ZXKQB@"+W(KGBNZ*
M_HH!BP*+]XKMBO.*]HK\BFN,;8R3C/2,1(XQCC2.0HXYCC6..X\OCSB/,X^H
MCZ:/=9!TD'B0<I!\D'J0-)&2D2"3-I/XDC.3+Y,BD_R2*Y,$DQJ3$),FDR&3
M%9,NDQF3NY6GEJB6JI;5E@Z7$9<6EPV7$Y</EUN77)=FEYB7,)@XF#N8-Y@M
MF#F8))@0F2B9'ID;F2&9&IGMF>*9\9FXFKR:^YKMFBB;D9L5G2.=)ITHG1*=
M&YW8GM2>C9^<GRI1'U$A43)1]5*.5H!6D%:%5H=6CU;56--8T5C.6#!;*ELD
M6WI;-UQH7+Q=NEV]7;A=:UY,7[U?R6'"8<=AYF'+83)B-&+.9,IDV&3@9/!D
MYF3L9/%DXF3M9()E@V799M9F@&J4:H1JHFJ<:MMJHVI^:I=JD&J@:EQKKFO:
M:PALV&_Q;]]OX&_;;^1OZV_O;X!O[&_A;^EOU6_N;_!OYW'?<>YQYG'E<>UQ
M[''T<>!Q-7)&<G!S<G.I=+!TIG2H=$9V0G9,=NIVLW>J=[!WK'>G=ZUW[W?W
M>/IX]'CO>`%YIWFJ>5=ZOWH'?`U\_GOW>PQ\X'O@?-Q\WGSB?-]\V7S=?"Y^
M/GY&?C=^,GY#?BM^/7XQ?D5^07XT?CE^2'XU?C]^+WY$?_-__']Q@'*`<(!O
M@'.`QH'#@;J!PH'`@;^!O8')@;Z!Z($)@G&"JH6$A7Z%G(61A92%KX6;A8>%
MJ(6*A6>&P(?1A[.'TH?&AZN'NX>ZA\B'RX<[B3:)1(DXB3V)K(D.BQ>+&8L;
MBPJ+((L=BP2+$(M!C#^,<XSZC/V,_(SXC/N,J(U)CDN.2(Y*CD2//H]"CT6/
M/X]_D'V0A)"!D(*0@)`YD:.1GI&<D4V3@I,HDW632I-EDTN3&)-^DVR36Y-P
MDUJ35)/*E<N5S)7(E<:5L9:XEM:6')<>EZ"7TY=&F+:8-9D!FO^9KINKFZJ;
MK9L[G3^=BY[/GMZ>W)[=GMN>/I]+G^)3E5:N5ME8V%@X6UU?XV$S8O1D\F3^
M9`9E^F3[9/=DMV7<9B9GLVJL:L-JNVJX:L)JKFJO:E]K>&NO:PEP"W#^;P9P
M^F\1<`]P^W'\<?YQ^'%W<W5SIW2_=!5U5G98=E)VO7>_=[MWO'<.>:YY87IB
M>F!ZQ'K%>BM\)WPJ?!Y\(WPA?.=\5'Y5?EY^6GYA?E)^67Y(?_E_^W]W@':`
MS8'/@0J"SX6IA<V%T(7)A;"%NH6YA::%[X?LA_*'X(>&B;*)](DHBSF++(LK
MBU",!8U9CF..9HYDCE^.58[`CDF/38^'D(.0B)"KD:R1T)&4DXJ3EI.BD[.3
MKI.LD["3F).:DY>3U)76E="5U97BEMR6V9;;EMZ6))>CEZ:7K9?YETV83YA,
MF$Z84YBZF#Z9/YD]F2Z9I9D.FL&:`YL&FT^;3IM-F\J;R9O]F\B;P)M1G5V=
M8)W@GA6?+)\S4:56WEC?6.)8]5N0G^Q>\F'W8?9A]6$`90]EX&;=9N5JW6K:
M:M-J&W`?<"AP&G`=<!5P&'`&<@UR6'*B<GAS>G.]=,ITXW2'=89U7W9A=L=W
M&7FQ>6MZ:7H^?#]\.'P]?#=\0'QK?FU^>7YI?FI^A7]S?K9_N7^X?]B!Z87=
MA>J%U87DA>6%]X7[AP6(#8CYA_Z'8(E?B5:)7HE!BUR+6(M)BUJ+3HM/BT:+
M68L(C0J-?(YRCH>.=HYLCGJ.=(Y4CTZ/K8^*D(N0L9&ND>&3T9/?D\.3R)/<
MD]V3UI/BD\V3V)/DD]>3Z)/<E;26XY8JER>789?<E_N77IA8F%N8O)A%F4F9
M%IH9F@V;Z)OGF]:;VYN)G6&=<IUJG6R=DIZ7GI.>M)[X4JA6MU:V5K16O%;D
M6$!;0UM]6_9;R5WX8?IA&&4491EEYF8G9^QJ/G`P<#)P$')[<\]T8G9E=B9Y
M*GDL>2MYQWKV>DQ\0WQ-?.]\\'RNCWU^?'Z"?DQ_`(#:@6:"^X7YA1&&^H4&
MA@N&!X8*AA2(%8ADB;J)^(EPBVR+9HMOBU^+:XL/C0V-B8Z!CH6.@HZTD<N1
M&)0#E/V3X94PE\284IE1F:B9*YHPFC>:-9H3G`V<>9ZUGNB>+Y]?GV.?89\W
M43A1P5;`5L)6%%EL7,U=_&'^81UE'&659>EF^VH$:_IJLFM,<!MRIW+6=-1T
M:7;3=U!\CWZ,?KQ_%X8MAAJ&(X@BB"&('XAJB6R)O8ETBW>+?8L3C8J.C8Z+
MCE^/KX^ZD2Z4,Y0UE#J4.)0RE"N4XI4XESF7,I?_EV>899A7F46:0YI`FCZ:
MSYI4FU&;+9PEG*^=M)W"G;B=G9[OGAF?7)]FGV>?/%$[4<A6RE;)5G];U%W2
M74Y?_V$D90IK86M1<%AP@'/D=(IU;G9L=K-Y8'Q??'Z`?8#?@7*);XG\B8"+
M%HT7C9&.DXYACTB11)11E%*4/9<^E\.7P9=KF%6959I-FM*:&IM)G#&</IP[
MG-.=UYTTGVR?:I^4G\Q6UET`8B-E*V4J9>QF$&O:=,IZ9'QC?&5\DWZ6?I1^
MXH$XAC^&,8B*BY"0CY!CE&"49)1HEV^87)E:FEN:5YK3FM2:T9I4G%><5ISE
MG9^>])[15NE8+&5><'%V<G;7=U!_B'\VB#F(8HB3BY*+EHMW@AN-P)%JE$*7
M2)=$E\:7<)A?FB*;6)M?G/F=^IU\GGV>!Y]WGW*?\UX6:V-P;'QN?#N(P(FA
MCL&1<I1PE'&87IG6FB.;S)YD<-IWFHMWE,F78IIEFIQ^G(NJCL61?91^E'R4
M=YQXG/>>5(Q_E!J>*')JFC&;&YX>GG)\_C"=,)XP!3!!,$(P0S!$,$4P1C!'
M,$@P23!*,$LP3#!-,$XP3S!0,%$P4C!3,%0P53!6,%<P6#!9,%HP6S!<,%TP
M7C!?,&`P83!B,&,P9#!E,&8P9S!H,&DP:C!K,&PP;3!N,&\P<#!Q,'(P<S!T
M,'4P=C!W,'@P>3!Z,'LP?#!],'XP?S"`,($P@C"#,(0PA3"&,(<PB#"),(HP
MBS",,(TPCC"/,)`PD3"2,),PH3"B,*,PI#"E,*8PIS"H,*DPJC"K,*PPK3"N
M,*\PL#"Q,+(PLS"T,+4PMC"W,+@PN3"Z,+LPO#"],+XPOS#`,,$PPC##,,0P
MQ3#&,,<PR##),,HPRS#,,,TPSC#/,-`PT3#2,-,PU##5,-8PUS#8,-DPVC#;
M,-PPW3#>,-\PX##A,.(PXS#D,.4PYC#G,.@PZ3#J,.LP[##M,.XP[S#P,/$P
M\C#S,/0P]3#V,!0$%00!!!8$%P08!!D$&@0;!!P$(P0D!"4$)@0G!"@$*00J
M!"L$+`0M!"X$+P0P!#$$,@0S!#0$-011!#8$-P0X!#D$.@0[!#P$/00^!#\$
M0`1!!$($0P1$!$4$1@1'!$@$201*!$L$3`1-!$X$3P1@)&$D8B1C)&0D921F
M)&<D:"1I)'0D=21V)'<D>"1Y)'HD>R1\)'TD``````````````````"]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!`4IY8P]:>RH2,B=.NBQ4!&8$5P1@!&P$8P1:!&D$7012!&0$501>!&H$
M8018!&<$6P13!&4$5@1?!&L$8@19!&@$7`11!%`$;01N!'`$;P2M@4>&FV/?
MA@-PS%8U%6]%=2,)"8*UI-T$9)N5;E0(J[Q)!#F?-'.U:MW@@[/+!9!K(1AP
MR"$IS1MP0*CQMM.;O8&^A&0QP(2'A%M`7X6]@<$B.@?.(BQI`PJ652UPQX4@
M(S2F*B/_B3R9)83PFXZ&\Z0X<$(MO5BSAMFJ<B-X(W1MB2./(Y$C7`^3(^:V
M<R.B(P(EK2--5?XZ3'`[,<LCYB/\(W4D%R14)'DDA2253<)6H"1-5UIPO8&>
MW@DG64!`K92(K*WS)+V!XHF+/N:2VSE510HR*A&,"ZB274,B%RTE-"4KW#XE
MO8&6D=.19DE3)5O>8"5K)6XE)T6ROMD1'$6!)84E"3X)(+XIF25K#8^)H"6K
MK6.BMB5WBM,E^4'K)A<X&S\M)E/+E'`=)T\F9"8F&IEPFG`T$`V+?-W8G`<G
M+1_O)9=%1B=I)[V!EY3ZK=(7];%S./2-]R>-.$JE9#AM.`TH#RAQ2K$H1VB^
M)<`HKRBM*";?XPA/CP8I9:\N/@M"`BEQ"7[,IBG%<,,IU)`CL>8IM;<<*FHJ
M(0B@*IPJT'"[*K\M`RG0Z#BPDV1A"-\J9CJ#"=D__I'D*Q,G4I*%5HDK#HN!
MS"K-G).9*[N3<I-FS3$_Z).5DKDK!<YK+",LI@GR<+V!R`E6+.5%DRQAS_EP
M!1#1E/()_7!#,)`D-BU(-SPM#M6$$MT:!G&5+2`S"7$*<:6&LRU=+5`?Q2T$
MEM,M3D74+666*,L)+ET;12ZI+J\N2R\YEW>7T"[8+@8OI)=Z+I<O?%3M"D&U
MB9BSF0=4]@J"#NXO2CR]@3HP,''3BF8E=R"]@6@E,9/)+[0PPMJY,+LP8`N\
M,/XYVV3-,`&#5.N>#2X;.I#Z,(C)$)N]@7&;(S%]:"[.,C$`9%!Q9S%V+]\/
M5'$JF+C0J)R68MZ#Z=WQ,44X77$C#$<0^0A0*?2=\4K`$%XRO8%S,FAQS[5J
M<21&H2)@+"0SI%4",W%QDLY!,[0C=7%',VHM=ZU?GI,S7=\=Y9`S\@N`G\&>
MXS$<,]XV2S68@H4T,).5-(VB+#4?MM<,^#6X-8]QO).]@0I!MJ+4:$RN7;ZA
M-J4V.V4F#?HU%PT--Y9`:+9CMD4W+3<?-WZC=3>`M7<=D3=8$^F3H#>C-Y\Q
M@*;8-[>DN*0$.&2D9:0+./6+)S@FNS,XO8&[<?&DM-N(I-.[14GWGF1JPCA<
ML6&VZPVZ.P*JO8$G.2(YS''-<9<Y:1?B.=`__&+!.6:F8,T=.M=QH3O+.Y_>
M,SN#.@VHP3K`.K(/P0Q\J$`.;#DA.PK>?!7V.E@[80X)A>-44"*Y.^]Q:ID%
M//)Q73RS#G$YB#Q<XLT.W3SZ<9XR]3PT/?YQ-4!;JO6$`G(`"N$EFJJA/;RL
MG#WW/8N;"W)1RQH^IE,Y/KRK11>]JV2O3+5`M0FKI0EK#QER0VRYI!QR#U'W
M.27-8<VKS58_'#_\/X1`O[4G<C+.LU8TSX<CO8&]@:Y5X=Z]@2^LTT5"K4Q+
MSS]1+$NC>$'-"1U!,*QZ0!>1_:W5%[!DQ$#<0,X/]$!%<KL/'T$$KU-!2G(5
MK_FM(,).<O^NGR,6KQ>O`*]=Q<M!_D$G0@%"3$)50E9"7T*$$V@0-$,60S>P
MJT+%0D@LRD*]@5PN);'/0B)D:W*L0AJR9[9BMCI#J-\]0HY#`F650]$J`V6D
M0P%D>G*N0\!#M+5].M5#UT/5$()RS3F]0`)$O8&K1..TJ]QM&X3<J$2N1$]%
M*D60<J[*247)1:*OIY)DMN,WA0GWM<VUFW)W195%PSIFMKE%H7)7$;V!K9[@
M13+AQT5D1?9%.57L1?`)]$6Q9.P[`D;3&[)R'Z^YMD_?!BVW<EZ42$9(E8Y&
MO8&>1EGARY67+<%R163-1LI&YT;N1@*ZA!')<@Y'W44>1S1'@D>L1]%'ST?O
M1_9'U'(02&]3N`K1R<[)(4@E2#=(3$A?S^)5G;K]NN)RGDBF2,!(;S9@N]A(
M;*4O2>MR['*!DG1)O8'P<O%RBCHO2D=*4TIE9ZY*(+U72K1*,4K,TKA@Q%GK
MW@!S7)P&2T!:PCH`2Q>_'4LYUKQ**4NJ/^;0*!%&2PWB5$L`````O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!(`0A!"($(P0D!"4$)@0G
M!"@$*00T!#4$-@0W!#@$.00Z!#L$/`0]!'`#<0-R`W,#=`-U`W8#=P-X`WD#
M]A__'T4@8"!"(U8C:R.Y)/@D*25V)<HJ0"V;+W,%/S"]@1`Q(3'T-KV!$D>]
M@;5@O8$H`,8!?09^!AT&'@:]@;V!A06&!8<%?`9[@7V!O03!!<(%PP7$!<4%
MQ@7'!<@%R07*!<L%S`7-!<X%SP70!=$%T@73!=0%U076!=<%V`79!=H%VP7<
M!=T%W@7?!>`%X07B!>,%Y`7E!>8%YP7H!>D%Z@7K!>P%[07N!>\%\`7Q!?(%
M\P7T!?4%]@7W!?@%^07Z!?L%_`7]!?X%_P4`!@$&`@8#!@0&!08&!@<&"`8)
M!@H&"P8,!@T&#@8/!A`&$082!A,&(08B!B,&)`8E!B8&)P8H!BD&*@8K!BP&
M+08N!B\&,`8Q!C(&,P8T!C4&-@8W!C@&.08Z!CL&/`8]!CX&/P9`!D$&0@9#
M!D0&109&!D<&2`9)!DH&2P9,!DT&3@9/!E`&4092!E,&5`95!E8&5P98!ED&
M6@9;!EP&709>!E\&8`9A!F(&8P9D!F4&9@9G!F@&:09J!FL&;`9M!FX&;P9P
M!G$&<@9S!G0&=09V!A`"$0(2`A,"%`(5`@$"%@(7`A@"&0(:`AL"'`(=`AX"
M'P(@`B$"(@(C`B0")0(F`B<"*`(I`BH"*P(L`BT"+@(O`C`",0(R`C,"-`(U
M`E$"-@(W`C@".0(Z`CL"/`(]`CX"/P)``D$"0@)#`D0"10)&`D<"2`))`DH"
M2P),`DT"3@)/`N<#N`.Y`R6!)H$:("B!PB,J@2N!2",M@2Z!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&B@:2!1X%"@;$&%@,A`QL&'`;`
M!,0$Q@3'!,@$R@3,!,T$U03<!-T$Y03G!.H$[`3N!/8$_`3^!`8%"@4,!0T%
M#P46!1<%'@4C!;V!O8&]@8,!4`%;`50!=0'3`'@`RP"*`6H!````````````
M````````````O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@?XN""\6+WP0SPID+WDOX`KX
M"@(P?3#E,$,QR`O4"_\+#0R7,OTRI2Y)#'<S>3./,W@,[#-0-*4TV#2X#'$H
MPPRB-;LUQS4:-@L-@#;5+N$GWV]7#48W?0V_-Q,XL@U2..(-UC@"#F0YP#D8
M#@HZ1#HR#C$..P[).@,[W$,D.U\[13M\#I8[G0XE/#0\,3Q"/*P.63RR#FL\
M=3R4/+8\03V!/:H]-3YJ/DL/PC[&/N8^03]O#V0_<3^5/Y@_J3\&0(#=.T!B
M0%I`OV]H0&E`I$"T0,8/`:T!03Y!Z@_U#S=#62X*$*Q!$1#00=1![T'_00E"
M981!%K$(\(`1<WXID\Z^0N"^#@EB.ZG?-"W)2V&_6>/E2_U+[+\[3#!,0DQ#
M3%%#)7-*%%I,74QJ3&\4<B9!P8M,U4RI3#!S_L$B3>],'%7TP'_,4$VA51)-
MO8&PK2T0I<$25GI-O8&U3<'!Q$T#3D5S)DX].#BS24Y'3F9.]$US3G5.O8'G
M3YT7!,[=3I;.#48)3RM/M4(S3[V!%Z[IPV1/DP]U3[F394]B<[V!H<3:Q.Y/
M$E"K%2QEIT_`4,%0QU"V2M#%H6H741'&(U$ADBB"W!>FJ8,7.MIZ4<G&O8&(
M49U1O8&O48%S@G.[4;Q1X5&&<PD<YL>)<VC(Y3@G4@C>AU*:4G`J-IT_/MC&
ME'.G-I9SF%,>E!,\I;;5MOH6J5.><]+*H'.Y(7V18E;B5`K+Y[5PIS.3^*LJ
M5-LZU.M;%,M64%2:5):+=).!";1SFJ?[4V)4F%1+K&/-NW.7RPZH/Q"=5*PG
M!56+%V7-+%6]@5-5/@>4SA<\VE96!P+.S7/85<]S\553$&079SS*5=5SV$J]
M@9;+-\X#SEY6O8$152`7$U9D5N%SP!3`P<,7M%:R+.=SIQ?S5I87?SE65^7;
M^]L!5_!S0E?R<XW0]'/J%VA7"`EBE+<EVM&^5[%8>.@N6>>@\5@:64]9(2BL
M5Q8ZCQB%6899H-*YJZ32GEG<6=L8]%GU68$U!5KW2(_3QUK*6KV!O8'G6OQ:
MY=TG6Z34O=7<6Q-)OF+06UG5:4PZUB9TDQDXUOQ"3%Q?7#"\I;Q_7(Q<C5SI
M6[JVT%S;7.];-G25&(]9FUT4UT_7%.SE"1/7UEU8UWW7$EX#7M"4VUW<01%>
M2'10$;V!J5X"V$UTRK4\#E!TS-!G3*U?ME_#7Y1C&6`M8&7:DMJE8,-CW^D0
MB;-@JAN>W3W;NZNX,"*E^6!G=&AT:72EFD`,E\XW83S;OM5A86S;R]NH871T
MQ&%FW*YAO8$G8K`-:6*$8BQ.\]R)E\YB7SX!8R)C^;R]@8;>VZK,WAN]BG3L
M8RMDH=ZKWP]"@RRBWJ7>Y1L$8ZS?^=^_WS-D&V6\7T5F9F;F9&!F=D$Y%:%T
M6-Q\CRZL7QS</3MG5F?L$V-GE<Z:,W9G=4J@WGUGC"4A'+C,M(.0QJ_AY>$1
MM]64RJ7Q9X)7]F>/'+T7!1C!=/5!`2W;9[V!QG07:`HMJ^(?:.5DD"*WH[RC
M26A?:'%H?FB`:))HH&ALO*YHG$7SXKV!M6C=XMUT$1WT:/-H"VDF:<X--='1
M#S"''*]&OHII=VF(:8=I/QTGS9.2<">A::9IK&DX9/EI:;:R'1?DQ>2U:LQJ
M^VK0:AAK9;Z$";'AU>6@:Z)KA>6T:TX>U&OM:\#;]"'T:RC*@PM]HQ!L`&Q^
MY@4L(Y1.;`NPPFR_;,QL*.<4;C?H$ND>=6'HH^A?Z;YMPVTD=4YN2#H$;BAU
M$^F@Z?N4L^EY;2YU+W70;M5NWF[B;G0?ZF[O;B2Q`6\@#J4,G0_R('X*Z]]"
M;TAOUAWD9&+-5V^]@7EO7RA**(5O>&J+X;)H_U6B;ZEO7$S.;Y9#_AVUM?NU
M]T(XM@BQD;8>19K?NI0?2S[=MN`I9+-D!-ZL8T%DBV0LW7FRET-K$?)(PTM0
M0FUUN+'^0G!U(T)^E-FG1Q%%E"^\N)/B";N2>G6A"323?75+P^,)@)(;*66V
MOI"$=8:0-I&#5N:HO8'558MU)=$QK)R\NZP2T'07+JE=Y>;.N3GS"=4.9Q`L
M*IIUT#G7$G^IGG5+KJ!U(<R+)EXH,<A2**9UJ(F-BX9DJG5<9+@@ZR+9"O:Q
M?""EA;^$"R%*(9&]*"SK@@N%60Q*A%2%]0;I(`"$,^&U@QI<PG58((TBS2)B
M(<,@R'5*K`(A[B$L(D$BC"&E(1@BO"*]@;V!O8&]@?8_U:?8=7^L,C]$E$FL
M:".#(^"&71?CA=*%T85Z7ES>3H<9)&0D,XBA)+V!^A@,0TRQ((KLM?%UD3N=
MB[V!7A$91I1%UD481<X=_+9-KI`E1`B/0XFN=">%A(TFQHG=*!UCM&<F9)TI
M32D_*?X(BRI9+`;>NI(OD]"2["MX*T]C/BR/+-(K&7:SE2&4'':U"<4^PT7A
M*\/"02R7WU.%H&0,1@.0A4+R&\ADN]U]9&`*WBU>+AXP"#!6E3R5;JJ-,`\M
MPY3$E,$)8)2=";Z2DPFJ4@?>^I;RIFC=S##.,.>41G8K+/N2!"U45[W2H%D^
M,F">:YR;,3@1+YP^G%1V,\^`,_Z!!H);G%DS6#,U,ENAQZ$4M&!V,3:ELVJ@
MZ0PBH-"FJN3XHO<T:G9V-O$TD34CMB>B9#1AH?LU*S<R.[0.CJ-MI<FU:Z7-
M)J"EF91]=HXX2:6`=J`-$!3$O.+>S[R\DIN\);QN2@.DZI/TI"0'CG9"I(FP
M3C@DS2LXTQWP-W#4EW8C.)*EH:7>-S*_D0N>=ORI60[BJ7ZF4$96#D\Y:K-V
M.MXYA`Y^/",+%:I'LO,[$CR)/,4\TI31-E@Z##R7#CH\%SV`K=JJ8&2R8ZK?
MB]Y)8\!VG-TG964_BT#%=KV!/ZT/$(0__*W]*XH_!RKD/L))NT+:L#:P<4+0
M0P=$%$2/M&6T.2/DMNN&^D6XK-YVWW97M:'#AA$Q$1^WX]_UK&<R<Q%,1KQ%
M1V2W11\7JLW1%P-'XQ%9N(:XV!'51O-'ANK9#>A%C-[KM<ZUNPU-$(ZV?Q$!
M=S.UNF+R*`)DH]XDE)\B8;LGN_A(\J2.2(](^TC7L\&I'@T3=[A%&T8_$?JV
M![=($]:V+L7'8\&\GDD-2@A*4DI01=E*P=,E=XX3O8$65B5+[3NZK+I+=$ON
M$Z:2LA/U8G%+#(O,M=F#NJLNDU<(*R<P"&H)%(,]=V),&2PUG4%W',#-*YN#
M<$KJ*P;!?DQY%-U-[4V1%//`_,+FPDU..;92=PY._$TN3G(\7$^'3U-/SE"A
MQ=S$77<73\+"ZA1A=U:(ECD.@@^HA"F2QFAWHK5=4:=,[(=IP$/"C$R.PJ9J
MA5<C:]P[=7>B##>VK<??:GIW`%;GT'UW:A>W4H(61E*)4L)2],B#:<+*XE/E
M4]'*TU5GS5!76]%&+/\3D'?K+&&4I"R8E.!7:%B7=VU9(M+"*ZY9!2''6?]9
M)EJE6HU:P[V46@74!-2F=YG?7-^YW2T1(U9U&4\9L@I]6UQ;".,-,>MBM'>4
M-ZE"1$(%E*UMGUWI79S76BM#2;`K[A64"2I?IU_)MS!@2F!T%1@^.T&AFAL;
M^4`+0)J3J6QU"6^UNV&]@3$GAAM[8L1D"][B$MIWYV3=W]UW959K6UEF9V97
M9E9F=.#%14(1/[7H=^EW9Q'EI$]G[7?FX.7@3!'Q=[BVKJV21>M%?!$!:+#A
M!SJ='/MW_'>]@2AD2=T`>._>?L9Z8]$LJ5R\&WE%VZ];:#%H^&D,>($OA=_R
MMM]H6N.V8Q-XI6)`%Q#?I[8DWYQI!=Z`$>IBI1N45?MI#6HA>'T06VJO'6IJ
M'&LEWRAX3SSA:KXL[VHM>-`=+WA\:OT=UQT]9#(J`I#B*?BU:)'$25^=N*N%
M.OT/&&7G"Q`SP9UKG\<R#VT3;3MM]6S0;#]LCVSMYE]L37A^Z&%M[A[$KEAN
M\!Y,;55X5GASZ._DY6T]5EMXG\]=>#Q7LQ=DS43.L,V@52Y797@7JB3$8DO<
MIX"HK1L>MN(/FV1^8PAD_X,Y2C=C#66D(0`'9&&=O+U)U$DV2LM)%Y.)I(&U
M6@DR(5I!64&]@9Y!U"6'>'LILRI**59MERFT0F\'CWAK0Y%X%[J]@763"=[,
M,HXLRRL\%4BR[`F[';S=>V1X9):4H7CR5<#,I'BZL.:@@;%4*[>K@<@H3]O$
M9,3YM<NUNMVE8V)%:1$T1B/?7Y1A$?.VF#QS17M%5A%^MM2VF9.FMN>$PGC#
M>,A%5K4E0K:U1&-F11]D/H;Q8\UXUMU&9*??%;VU&T+>ZT+5>-9X9"@:A]EX
MVGC")D1+NI-^3X*2D+;A>*X7P63*">5X[;5P*W^40Y1$TF$LH@E;JW`)'V,Y
M+$'>(I0T9$T/=(G6'$H,M"+I#\P/7)#U0GL5_GB//^3A:Q<7/\_7YT%O/E8/
MK:TMK((_C$#O#S6%T49\"8@'`!E:$?$:A"LN8[X;06`7>1AYTBF(*98)TI!^
M0B*Q'WDCH["/_9IY.B<[)7DEIW36'ZE#WA:J*WD?N-H[[:BWS+Y57Q=.%R;-
M-'F"S)[/ET#)T+U4^I)M58#,$]";DTDK0BQSDR$L,2S%E+RO[0FO*_R2APD.
M0U!D6CAEL"XLZRM0>>L[N:RVTQNRBK"=0AFPH=UP(2C-@BZ.LLW7?;',.Q:P
M!)`F0K-"J;$E$)\^9WF/MN5/JROO+G,0'#%N>6]Y)$^F544F<WG`I52#/BEW
M>1F'91)Z>7MY@T%]>3`O#T533AG>@GF((6=134201/35N$2Y1#:^P43(1"D1
M&-9L875#D7EA17932A&,2%$18CZ]*)E%GD6?16(1<!%T$7H14T:.$=,1PD;M
M1O)&#4?\$4A'7$=`$LU'5Q+T1UP2^D?<N0A#XR?`6BDJG1+#2+D2(3G%$IL(
M&$GJ$N\2'BX^24M)LBJ823E"G$DH$[E)QTG12>9)R%7+>;-*PSFR2H,3B1,1
M2QE+NV"&2[Q@YQ,13#(4/$SY4T043TQ;3$\4X1_B3.Q,^TR239M-X!3Z%/M-
M'$X,%3A.%!5M3I-@0$+/BD]/5$]03WU/+E$T41]$%Q:@4:51N4RN4;%1U%%,
M$'0I($(W4FE2;1:,4JI$CE*24N!&E%*!%OD-UE+94MI2DQ;Z*?Q2!%.E%A-3
MK18E4Z\I05-D4]13#Q<F5/932E185']4,!?75"EG2CN%575"Y%6C,@A6A!<^
M5F%6>%:05KA6TE:[%^]6\%8@5_<7LE?25_)7+U@%9\M8AAB7&.Y9/UID6H=:
MT5KGU&E;>%O46_1;45W47?)='%X8&A\JPUYM&JX@.E^8)Q0I<5^U)[!?MQK.
M7^)?Y%_M7_)?MV#!8,I@S&`S881J+1N@:=-BGAOH8AAC*V-Q8VYC?V.C8ZMC
MLV.T8[UC`V1$9&UDQ1O1&_]NUV3!)-UD[63^9.H;%&4Y9>UE8F8G'+1F\V9E
M'&`YI!P`:+4<<FB":!0H)!VH,GEI61VQ:00JSFG9:70CW&GW:0)J'6HB:K`=
MA6K='?QJSVL#3"EL06R=;+%LM&RM'N!L+PHI>HEM^FP^;Q`HTVW];0!N/&ZV
M9;9@NV[L;O%N_6X&;YQE(F\Q;SAO2$R$;S]Z0'I!>MHZ@V5L*T5Z`"J!97D*
M27I*>DMZ3'H7*?-"3WI0>E%Z*B93>E1Z7B96>E=Z4XI9>EIZIS)<>CHH7GI?
M>F!Z87IB>F-Z%3OO;.589WJ.BVEZ:GJMC&QZX"UN>LLO<'IQ>K:-WCB[C75Z
M=GH'"7AZ>7IZ>GMZ)"4M5N./?WJ`>L%<@GJ#>H1ZA7HX(#M"B'J)>HIZBWJ,
M>HUZCGJ/>H,TU9>2>AA#%3J5>JD[B`E\FIEZFGJ;>IQZG7I]5)]ZH'K5G^5:
MHWJ@8*5Z>&BG>@=I?6NJ>KV!K'JM>JYZR*&P>K%ZLGJS>K1ZM7JV>K=ZN'JY
M>G$Q"#A_.+UZOGJ_>KV!^K6]@<-ZQ'J]@8:$=2K..-@ZRGH7TZ+#S7K.>K[2
MVIA0&_@<TWI:WM5ZUGK[K=AZ5K':>MMZDB,1AU\KJ)=^#C^KXGKC>D@IY7I;
M#.=ZZ'KI>B(*`YJ>7`[?O8'O>O!Z\7J)0_-Z>(HE*_9Z]WJYA]I?^GI/)/\H
M\4+^>O]Z`'OGMGPG`WMNO%++O8$S!PA[\M(*>Y@9#'NFO,>^?[40>R8BNP<3
M>[V!%7O\&0C=+L`9>T;!&WMA*=%"O8$?>Y+65F$B>QJZHEPE>R9[&R_WR[V!
M*GLK>RI<-K8N>Z^M$L<`'C)[,WM;G25EX;Y5,^<KC>N]@7DHX;(]>RH@/WL6
M9T\_O<S8"+=:17MNR9'&7LF]@4I[PDQ,>]&(3GN]@5![Q4N]@7K*YFI5>Q\)
M5WM8>P-+6GM;>^PN77N]@5][4!EA>[M&I5ED>W8JW`D-G&A[:7L4#VM[;'M!
M8[J9;WOP8Z;1<GOY/5]E=7MXC&=9-5IY>WI[<9,X0&JV?GMD#'D)O8&]@;\7
M=C@MYF3D@UJ(>XE[EBA?$\J180QOJ8][A9`M0^94DWMHXKV!]QYOT&O=F7N:
M>YM[G'LZK\-,_DH)V#5!'^K#.Z1[8B6F>W]D]CD=:"_9JWLURJV0[Z2O>T4O
M\-^R>]4HXV@)W6LOR+5^-Y4[DB7EMD&MT0[V.+][M-CNV&&8PWO$>\5[QGO'
M>\A[R7N*",M[*MQZ&Z8USWN(215CTGMR%M1[7Q;6>]=[V'NX*]I[O8'<>]U[
MO8$0XN![=Q#B>^-[T&`/1$LHYWOIX^E[ZGOK>^Q[[7LJY>][\'N.Y?)[\WL?
M4/5[X^?D'@=F^7LB0_M[D1\28?Y[G!^<BKY@@2>Z8`1\N6#3MHD7_T_60'$\
MJB"D!^S>#GSZ"8!?M9,2?"S?6=\5?"_(:Q`5T_>J=;V6OUH@P<*8Q7\H[8L.
M7RTM2*P>N)XUO8&VDSN4\#;M)XK!VB71NT80+WR]'N(GWB?)4!C#-2LV?+!8
MW!\JC0F+^JB74IYM&%Z[1P5MSD<Y205D\B7(4G=4Y2>R4IA5/5*J)^)*`RC6
M)4]\C@C%)[$GL3CBV>T(M$:P)WHG5R8R)T&*7'R0,,BZ]HM@?&%\ZV[:3IXG
MM8U=-"UH5";-779#-F*\-7DUOC4I)W!\,FUR?%HCGP=GBV<C#2;>)M,FYD<M
M7WQ\,4<V4D19QE@'6C93G%4!CFP7A$1&M%`MBU23R3LH-)WOUF.O,]>0SI%\
M,&(9C\AB/*OIZBR,>8SF0V*6SAE"NIU\*XUZ$QUMWS9@HG,;I'R\YBR-BHN]
M@:E\+8V]@:Q\QXXC0PY0D&W:'\0?-PC-+'(^)R5L"9P,/25E";M\6BINMZU3
M"R9J*<%\N8B]@1(-99OT1&SG21^M;#ZK\.>;'BFZGN//?-Q5MJO2?//(8*GN
M-*5.MZPLK.H,"&&,)/00.@EI&-]\P$>P+#:,^DDV&F<J/Q,\*$ML-"_41^M\
MQ6XA'[V!NPK9,MJCLK&]@1THJ8]G*:.U^'ST(V[0;0B]@;QMUDWY:YXI+),3
M+I,V!'T%?231[5<(?2+-(K<+?;V!OB,.?4XOPV<1E\%N3&&?3,)KD2XC32@T
M]32_:T]-ZFO^3;V!PDT&3M5L?$W):[V!VVQ^M9IO,R>#+;TAV&ZR(2`DAA"1
M)"<I%B)W*](OB&CK;5Q@*29T:`!J>FCL)/`R[#J:)<IL0FU['@%G0#MF(L9&
M+9.::C,DO8$98D%G'&*]@1%B3WT_-2/-BCS1)TYB^D9%-#R%ST3P35I]/:N]
M@5FU5DA=;.H?U(H^58)9O8$*+H`[O8$Z*=\CM2^.(/$];7WY(%PFFB9:)()>
MO@B]@;,(O8$2/3QBY6]7;.YH=&EZ:^ANQ&[Z0I1,O8&Z/5A9^%"]@>`GB'UW
M7Y-OO8'47D]?7&X!7T(T?=HH7W5?4TRWMKY+6$JJ/J=;AT<:WF9OCCX664-'
M\NG320#K#%YB1/%$;5R"1'%&ZUW[MF]7>C'@63<7O8'[D\7-O8&^6]N;O8&]
M,N='EVN$;2YD3VPU6;V!O8'W7:Q$X6=P;)8(,D1''M%-"FK9Q!DS1![6;CTS
MO8$?*2\S9C3Y,[V!'`VB,VHE=:8D-<(YD@@7+X+?VF#=?;V!F2*&EH9*\B3X
M9KN,Y1*]@7Y)O8%"3NI]6DZM2^91XU'-3H5&<D;46II3S#CB44;2VU%P1H-2
MI$C)6@S)TT:1SNE8#EE(4\Q8B5NM78-<JTAX1EI6]0AR.Z9>O8'I6KV!>3\!
M6=&M9T9;$/9"9#)<,U$/O8$W,KV!\5#MWKV!J3*^'>`CV`X'JQ?#%M,E?@25
M_H_#Y)S-;="!+BW%S]VWJ&Z",'Z.N>(7WRPT?I!OYFXW?@``````````````
M`````````````````(````#```````$``$`!``#``0``0`(``(`"``#``@``
M``0``$`$``"`'@``P!X````A``!`(0``@"$``,`A``!`)```0"4````G``"`
M+@``P"X````O````,```0#```(`P``#`,````#(````T``!`-```@#0``,`T
M````-0``0#4``(`U``#`-0```#8``$`V``"`-@``P#8````W``!`-P``@#<`
M`,`W````.```0#@``(`X``#`.````#D``$`Y``"`.0``P#D````Z``!`.@``
M@#H``,`Z````.P``0#L``(`[``#`.P```#P``$`\``#`/````#T``$`]``"`
M/0``P#T````^``!`/@``@#X``,`^````/P``0#\``(`_``#`/P```$```$!`
M``"`0```P$````!!``!`00``@$$``,!!````0@``0$(``(!"``#`0@```$,`
M`$!#``"`0P``P$,```!$``!`1```@$0``,!$````10``0$4``(!%``#`10``
M`$8``$!&``"`1@``P$8```!'``!`1P``@$<``,!'````2```0$@``(!(``#`
M2````$D``$!)``"`20``P$D```!*``"`2@``P$H```!+``!`2P``@$L``,!+
M````3```0$P``(!,``#`3````$T``(!-````3@``0$X``(!.``#`3@```$\`
M`$!/``"`3P``P$\```!0``!`4```@%```,!0````40``0%$``(!1``#`40``
M`%(``$!2``"`4@``P%(```!3``!`4P``@%,``,!3````5```0%0``(!4``#`
M5````%4``$!5``"`50``P%4```!6``!`5@``@%8``,!6````5P``0%<``(!7
M``#`5P```%@``$!8``"`6```P%@```!9``!`60``@%D``,!9````6@``0%H`
M`(!:``#`6@```%L``$!;``"`6P``P%L```!<``!`7```@%P``,!<````70``
M0%T``(!=``#`70```%X``$!>``"`7@``P%X```!?``!`7P``@%\``,!?````
M8```0&```(!@``#`8````&$``$!A``"`80``P&$```!B``!`8@``@&(``,!B
M````8P``0&,``(!C``#`8P```&0``$!D``"`9```P&0```!E``!`90``@&4`
M`,!E````9@``0&8``(!F``#`9@```&<``$!G``"`9P``P&<```!H``!`:```
M@&@``,!H````:0``0&D``(!I``#`:0```&H``$!J``"`:@``P&H```!K``!`
M:P``@&L``,!K````;```0&P``(!L``#`;````&T``$!M``"`;0```&X``$!N
M``"`;@``P&X```!O``!`;P``@&\``,!O````<```0'```(!P``#`<````'$`
M`$!Q``"`<0``P'$```!R``!`<@``@'(``,!R````<P``0',``(!S``#`<P``
M`'0``$!T``"`=```P'0```!U``!`=0``@'4``,!U````=@``0'8``(!V``#`
M=@```'<``$!W``"`=P``P'<```!X``!`>```@'@``,!X````>0``0'D``(!Y
M``#`>0```'H``$!Z``"`>@``P'H```![``!`>P``@'L``,![````?```0'P`
M`(!\``#`?````'T``$!]``"`?0``P'T```!^``!`?@``@'X``,!^````?P``
M0'\``(!_``#`?P```(```$"```"`@```P(````"!``!`@0``@($``,"!````
M@@``0((``(""``#`@@```(,``$"#``"`@P``P(,```"$``!`A```@(0``,"$
M````A0``0(4``,"%````A@``0(8``("&``#`A@```(<``$"'``"`AP``P(<`
M``"(``!`B```@(@``,"(````B0``0(D``(")``#`B0```(H``$"*``"`B@``
MP(H```"+``!`BP``@(L``,"+``!`C```@(P``,",````C0``0(T``("-``#`
MC0```(X``$".``"`C@``P(X```"/``!`CP``@(\``,"/````D```0)```("0
M``#`D```0)$``("1``#`D0```)(``$"2``"`D@``P)(```"3``!`DP``@),`
M`,"3````E```0)0``("4``#`E````)4``$"5``"`E0``P)4```"6``!`E@``
M@)8``,"6````EP``0)<``("7``#`EP```)@``$"8``"`F```P)@```"9``!`
MF0``@)D``,"9````F@``0)H``(":``#`F@```)L``$";``"`FP``P)L```"<
M``!`G````)T``$"=``"`G0``P)T```">``!`G@``@)X``,">````GP``0)\`
M`("?````X```0.```(#@``#`X````.$``$#A``"`X0``P.$```#B``!`X@``
M@.(``,#B````XP``0.,``(#C``#`XP```.0``$#D``"`Y```P.0```#E``!`
MY0``@.4``,#E````Y@``0.8``(#F``#`Y@```.<``$#G``"`YP``P.<```#H
M``!`Z```@.@``,#H````Z0``0.D``(#I``#`Z0``@.H``,#J````ZP``0.L`
M`(#K``#`ZP```.P``$#L``"`[```P.P```#M``!`[0``@.T``,#M````[@``
M0.X``(#N````\P``0/,``(#S``#`\P```/0``$#T``"`]```P/0```#U``!`
M]0``@/8``,#W````_P``P/\``````@!```(`P``"```!`@"``0(`P`$"```"
M`@!``@(`@`("`,`"`@```P(`0`,"`(`#`@#``P(```0"`$`$`@"`!`(`P`0"
M`$`%`@"`!0(`P`4"```&`@``!P(`0`<"```(`@!`"`(```D"`$`)`@``"@(`
M0`H"`(`*`@"`"P(`P`L"```,`@!`#`(`@`P"`,`,`@!`#0(`@`T"```.`@!`
M#@(`@`X"`,`.`@``#P(`@`\"`,`/`@``$`(`0!`"`(`0`@#`$`(``!$"`$`1
M`@"`$0(`P!$"`$`2`@"`$@(`P!("```3`@"`$P(`P!,"`$`4`@"`%`(`P!0"
M`(`5`@``%@(`0!8"`(`6`@#`%@(``!<"`$`7`@"`%P(`P!<"```8`@!`&`(`
M@!@"`,`8`@``&0(`0!D"`(`9`@#`&0(`0!H"`$`;`@"`'`(`0!T"`(`=`@#`
M'0(``!X"`(`>`@#`'@(`0!\"`(`?`@!`(`(`@"`"`,`@`@``(0(`0"$"`(`A
M`@#`(0(`0"("```C`@"`(P(`P","`$`D`@"`)`(``"4"`(`E`@``)@(`0"8"
M`(`F`@#`)@(``"<"`$`G`@"`)P(``"@"`$`H`@"`*`(`P"@"```I`@!`*0(`
M@"D"`,`J`@``*P(`0"L"`,`K`@``+`(`0"P"`(`L`@#`+`(``"T"`$`M`@"`
M+0(``"X"`$`N`@#`+P(`0#`"`(`P`@#`,`(``#$"`(`Q`@#`,0(``#("`$`R
M`@"`,@(`P#("```S`@"`,P(`P#,"```T`@!`-`(`P#0"```U`@!`-0(`@#4"
M`,`U`@``-@(`0#8"`(`V`@#`-@(``#<"`$`W`@"`-P(`P#<"`,`Z`@!`.P(`
M@#P"`,`\`@!`/0(`@#T"`,`]`@``/@(`@#X"`,`^`@``/P(`0#\"`(`_`@#`
M/P(``$`"`$!``@"`0`(`P$`"``!!`@!`00(`@$$"`,!!`@``0@(`0$("`(!"
M`@#`0@(``$,"`$!#`@"`0P(`P$,"``!$`@!`1`(`@$0"`,!$`@``10(`0$4"
M``!&`@!`1@(`@$8"`,!&`@``1P(`@$<"``!(`@#`2`(``$D"`$!)`@"`20(`
MP$D"``!*`@!`2@(`@$H"`,!*`@!`2P(`P$L"``!,`@"`3`(`P$P"``!-`@"`
M30(`P$T"`$!.`@``3P(`0$\"`(!/`@#`3P(`@%`"`$!1`@#`40(``%("`,!2
M`@``4P(``%0"`$!4`@!`50(`@%4"`,!5`@``5@(`0%8"`(!6`@#`5@(``%<"
M`$!7`@#`5P(`0%@"`,!8`@!`60(`@%D"`(!:`@#`6@(`0%L"`(!;`@#`6P(`
M`%P"`$!<`@#`7`(``%T"`$!=`@``7@(`@%X"`,!>`@!`7P(`P%\"``!@`@!`
M8`(`@&`"``!A`@!`80(`@&$"`,!A`@!`8@(`P&("`$!C`@"`8P(``&0"`(!D
M`@``90(`0&4"`(!E`@``9@(`@&8"`,!F`@!`9P(`@&<"`,!G`@!`:`(`@&@"
M``!I`@"`:0(`P&D"``!J`@!`:@(``&L"`$!K`@"`:P(`P&L"``!L`@!`;`(`
M@&P"`,!L`@``;0(`@&T"`,!M`@``;@(`0&X"`(!N`@#`;@(``&\"`$!O`@"`
M;P(`P&\"``!P`@!`<`(`@'`"`,!P`@``<0(`0'$"``!R`@#`<@(`@',"``!T
M`@"`=`(`P'4"``!V`@!`=@(`@'8"``!W`@!`=P(`@'<"`$!X`@``>0(`0'D"
M``!Z`@!`>@(`@'H"`,!Z`@``>P(`P'L"``!\`@``?0(`0'T"`(!]`@#`?0(`
M0'X"``"``@"`@`(`P(`"``"!`@!`@0(``(("`$""`@#`@@(``(,"`$"#`@``
MA`(`@(0"``"%`@!`A0(`P(4"``"&`@"`A@(`P(8"``"(`@``B0(`0(D"`(")
M`@#`B0(``(H"`$"*`@"`B@(`P(H"``"+`@!`BP(`@(L"`,"+`@``C`(`P(P"
M``"-`@``C@(`0(X"`(".`@#`C@(`@)`"`,"0`@``D0(`@)$"`,"1`@``E`(`
M0)0"`,"4`@"`E0(`P)4"`$"8`@"`F`(`P)@"``"9`@!`F0(`@)D"``";`@#`
MFP(`@)P"``"=`@!`G0(``)X"`$">`@"`G@(`P)X"``"?`@"`GP(`P*`"``"A
M`@!`H0(`@*$"`,"A`@``H@(`@*("`,"B`@"`HP(`P*4"`("F`@!`^`(`@/@"
M`,#X`@"`^0(`P/D"``````````````````````````````````````!#?D1^
M17Y&?D=^2'Y)?DI^2WY,?DU^3GY/?E!^47Y2?E-^5'Y5?E9^5WY8?H``00`-
M`4``D@!)`)H`2`#,`%,`$0%2`&5^O@)G?L`"2@"!`&$`#@%@`%$!DP!I`)L`
M:`"K`&T`$`%L`,T`<P`2`7(`ZP!Z`!0!>0`6`1@!&@$<`7P`A'Z_`H9^P0)J
M`&$!BGZ+?KV!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]
M@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!
MO8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@;V!O8&]@6GJX7Z]
M@<HVO8&]@?T?74".;9]BO8&]@;7343;:(.@@:"$6(S0C7".D(V$D:"3[)`XE
MD268):(HL"K$*L<J\BKT*B8M7BU?+5HN1C#[,4DWOCG$.24Z#C\\0K5&)%`L
M4#I01U!/4%]0AE"W4/I33U3O5`9;_EPB769@9V!N8)%%?$Y-3P8[24SG([V!
MO8&]@;V!3&(X2AYB/%*]@0M>=E(P?[V!O8$?4@=O#1\);DQN?AXY?\[/2FX\
M?X$(O8$:0+Y3F4:]@9$;+&M/:]EO!TM(?PJ7T(9+?^0?02!`($<@?R"K(/<@
M#`=](<@0PR%((CT'4P=E!T8CQ2J;([PCQ2-)(#DD4"3G)(<(:241"'`E$PB"
M)>,E+0@R"$$)4R9C)G0F>2:0)J\FV";C)N@F6`C_)F4(?PB7)X4(?7_E)KV!
M0HJ!?X)_4">&H:P,@81&7_BXB7_3$G[8^DB-?_0,51J0?W+**KF=-I1_](S5
MBC2.339^7YI_FW^<?YU_EMF3LKV!!HNB?ZG8=!JE?Z9_<FLG#:E_;1+&!X>[
MK7^N?Z]_KFW5:+V!619EQ'0VHR:W?[A_MXV[#*^-O'^]?[Y_JC;`?T.*:%_A
MF0S?Q7^]@8L:R']Z$C,JRW^]@<U_/(;/?]!_T7\Y)SL3.A:]@?0<UW_8?RI3
MM6G;?SDUO@RUG<!>82@\-L,0O8'D?XF+SY_G?[V!"([J?U(,Q@SM?S@([W\'
MF1(HL8SS?_1_?`?]/?=_O8&]@?I_^W_\?_U_#>#ZBP"``8`340.``YXYG[L(
M([L(@,V,*HP3$K",!XL.@`^`O8$KC!*`"(L`CGV.>1+6G/(U[8QTIOG2CJ`^
MBS^+$:$5H=@,(H`'CJZ,)8!0RR>`*(`I@&IFC"9$5'DGO8&#Y^9L=FO>TS.`
MP$+M4FQ2W"URQ[125PH?)7W8=F)ZC(^+]XM[C)T(*[G)"-:*;RCUG0F.D(OX
MB[B-B(Y'V=60^8M0N62B%"Q=C5Z--8XVCEPID8M4T\W9]8S[B_ZZPPGVC,".
MF+MB@&.`^I-E@&:`62HH)-H(:H`R32@M@!IL'6=O9QS?;$ULM,`]I+LGL@A)
M*.@?PBIZ@'N`$6A]@!L@>R#^!^,M$3&$,;H+##3U-CH]]3WZ/>Q!JT/L'RU$
MCH#24+M*>4[34).`@0>]@9:`@E$`4IF`FH`=):19`5N>@.!<'5Y%93AF/V:H
M9J6`IF@U:8YIGFDC:JN`/&U?;@1O+SW<;_<?LH#=9O<S8F4`````````````
M`````````````````````/GY^/GF^>_YW?GH^?'YW_GL^?7YX_GN^??YY?GI
M^?+YX/GK^?3YXOGG^?#YWOGM^?;YY/GJ^?/YX?GZ^?OY_?G\^?[YV?G<^=KY
MUOG;^=CYU_D``````````````````"@````H````*````"@````H````*```
M`"@````H````*````"@````H````*````@`````````````````````G````
M)P```"<````G````)P```"<````G````)P```"<````G````)P```"<````G
M``"`````````````````)@```"8````F````)@```"8````F````)@```"8`
M```F````)@```"8`@````````````````````````````"4````E````)0``
M`"4````E````)0```"4````E````)0`"`"0````D````)````"0````D````
M)``$```````C````(P```",````C````(P```",````C````(P```",````C
M````(P```",````C````(P```",````C```$(@```"(````B````(@```"(`
M```B````(@```"(````B````(@```"(````B```(````````````````````
M``````````````````````````````#__Q``__\@``$`(0```"$`"```````
M````````````````````````````,`S_`3`",`[_)R`;_QK_'_\!_S#^)B`E
M(%#^4?Y2_K<`5/Y5_E;^5_Y<_Q,@,?X4(#/^="4T_D_^"/\)_S7^-OY;_UW_
M-_XX_A0P%3`Y_CK^$#`1,#O^//X*,`LP/?X^_@@P"3`__D#^##`-,$'^0OX.
M,`\P0_Y$_EG^6OY;_ES^7?Y>_A@@&2`<(!T@'3`>,#4@,B`#_P;_"O\[(*<`
M`S#+)<\ELR6R)<XE!B8%)L<EQB6A):`EO26\):,R!2&O`./_/__-`DG^2OY-
M_D[^2_Y,_E_^8/YA_@O_#?_7`/<`L0`:(AS_'O\=_V8B9R)@(AXB4B)A(F+^
M8_YD_F7^9OY>_RDB*B*E(B`B'R*_(M(ST3,K(BXB-2(T(D`F0B:5(IDBD2&3
M(9`ADB&6(9<AF2&8(24B(R(/_SS_%2)H_@3_Y?\2,.#_X?\%_R#_`R$)(6G^
M:OYK_M4SG#.=,YXSSC.A,XXSCS/$,[``65%;45Y175%A46-1YU7I=,Y\@26"
M)8,EA"6%)88EAR6()8\ECB6-)8PEBR6*)8DE/"4T)2PE)"4<)90E`"4")94E
M#"40)10E&"5M)6XE<"5O)5`E7B5J)6$EXB7C)>4EY"5Q)7(E<R40_Q'_$O\3
M_Q3_%?\6_Q?_&/\9_V`A82%B(6,A9"%E(68A9R%H(6DA(3`B,",P)#`E,"8P
M)S`H,"DP05-$4T53(?\B_R/_)/\E_R;_)_\H_RG_*O\K_RS_+?\N_R__,/\Q
M_S+_,_\T_S7_-O\W_SC_.?\Z_T'_0O]#_T3_1?]&_T?_2/])_TK_2_],_TW_
M3O]/_U#_4?]2_U/_5/]5_U;_````````````````@7BYDL^(NUA28*=\^EI4
M)68E5R5@)6PE8R5:)6DE7252)60E525>)6HE8258)6<E6R53)64E5B5?)6LE
M8B59)6@E7"51)5`E;25N)7`E;R63)0```````````````````#0````U````
M-@```#<````X````.0```#H````[````/````#T````^````/P```$````!!
M````0@```$,```!$````10```$8```!'````2````$D```!*````2P```$P`
M``!-````4````%$```!2````4P```%8```!8````60```%L```!<````70``
M`%X```!?````80```&0```!E````9@```&D```!J````:P```&\```!P````
M<0```'(```!S````=````'4```!V````=P```'@```!Y````>@```'L```!\
M````?0```'X```!_````@````($```""````A````(4```"&````AP```(@`
M``")````B@```(L```",````C0```(X```"/````D````)$```"2````DP``
M`)0```"5````E@```)<```"8````F0```)H```";````G````)T```">````
MGP```/\``````@```P(```0"```%`@``!@(```<"```(`@``"0(```H"```+
M`@``#@(```\"```0`@``$0(``!("```3`@``%`(``!4"```6`@``&`(``!D"
M```:`@``&P(``!P"```>`@``'P(``"$"```B`@``(P(``"0"```E`@``)P(`
M`"@"```I`@``*@(``"P"```M`@``+@(``"\"```P`@``,0(``#("```S`@``
M-0(``#8"```W`@``.`(``#D"```Z`@``.P(``#P"```^`@``/P(``$`"``!!
M`@``0P(``$0"``!%`@``1@(``$@"``!)`@``2@(``$L"``!,`@``30(``$X"
M``!/`@``4`(``%("``!3`@``50(``%8"``!7`@``6`(``%D"``!:`@``6P(`
M`%P"``!=`@``7@(``%\"``!@`@``80(``&("``!C`@``9`(``&4"``!F`@``
M9P(``&@"``!I`@``:@(``&P"``!M`@``;@(``&\"``!P`@``<0(``'("``!S
M`@``=`(``'4"``!V`@``=P(``'@"``!Y`@``>@(``'L"``!\`@``?0(``'X"
M``!_`@``@`(``($"``""`@``@P(``(0"``"%`@``A@(``(<"``"(`@``B0(`
M`(H"``"+`@``C`(``(T"``".`@``CP(``)`"``"1`@``D@(``),"``"4`@``
ME0(``)8"``"7`@``F`(``)D"``":`@``FP(``)P"``"=`@``G@(``)\"``"@
M`@``H0(``*("``"C`@``I`(``*4"``"F`@``^`(``/D"``#Z`@!;MFJV$1!H
MMAL0$A`.$!40:#\0$(&V%Q!&0$-`<!#M$.>Z[A#FNM&Z$;N!0="ZV;H*N_00
MVKK=NLBZXKKINLNZ?$',NL&Z:D'>NHA!\A#X$/,04;L2N_H0X+HKN[3VV,#1
MP!!$TL#-P!]$MA&W$3W!#T3*P+H1R\"\$=?`],,[$M-%+Q*'Q(O$@\0W$ID2
MQ<?2Q\;'T\?9$M@2UQ+PQ\W'S,?<Q];'-A/FR4'*/\J'2<7*P,K&RK[*O\K&
M27`38\O3S-K,U<RE$Z83J1/N$U04[M!7%/S0%-*A%"/3(M,PT[74TQ0XU=04
M/]77%,Q-;4YP3O<4]A3Y%/@46$]"3VA/:4]HUV?70T]EUT=/BA5UVO?:\]KV
MVI05`-N3%?_:]=J=4MT5W!7W%<]3DMX&X$(6!^!KX%06;.!5%I/ACQ:4X?14
MM!:S%F+B8^()55_B9.);XEGB^Q;]%J3CK..K5?P6M>0L%R\7KN0K%\7D,Q<T
M%_M5.^:L5ZY7JE?H%[_H*^J$ZH#J3>M/ZUQ83.N2[5T9TAJ%`(@`KE]Y7XX`
MA`!Q7]\:LU^#`"Q?=U\O8<-C`@'-8P8!!0')8_X``0$``<YCI62@9/YD666:
M9N<!&1[D:-=HW&CF`>=H[0'B`>L!Y6CH`>P!"AXD`IH?%&YB`O%M80)@`F0"
MBP*V;VYP;'"!<$)Q&0,6`Q@#(@,:<1T#%P,>`R=Q)7$7<1QQ/7$@<6D#:@.!
M<VP#>@.*`PEUQG7$=9P#Q77]`_D#[W;_`]]VWG;N=O5V[';\`]UVA2/[`P($
M7P16)%X$701<!")X4222!)=YE7F4!)4$T02I>_$$4WRQ)59\57QW!6\%XWWB
M?8<%?05\!7X%A06+!88%@`7]7:E]>`6K]3-^"GZZ!5F`,P:\@2T&Q(''@<:!
M-P9:)V,GN(':@2X&MX'`@3T&S8&@!KR$JX2C!H:%FRE:AZ,I#@>>*4.(M@>L
MB:L'K0>F![Z)N"JJ![HJL0>KB:@'KP>P!Z<'L@>=!Z4'M0<^=,<JURKYC$$(
M\XSWC'`L18Y(CG((G2QO"'$(1(Z%"*^.L8ZD"*4(I@C/CZ@(RX_-CZ,(4)#L
MD1J2%BTD+=B10PG0D=&1/0E%"7N1TI%$"=21YY'?D=Z112W9D<^1#97C"7DO
M_5W?">0)>B_E"3B55#`B"DH*J9A)"D0*2PJ'"HD*D@J1"I`*C@H^F4:9[9HP
M]A(+$`L1"VR<,@LT"S<+,PLV"S4+90NLG7PS>S/)GA(TL`L2GZ\+J@O]G@&?
M$9^K"XF?!9_^G@N?()\$GXB@\PL"H?0+`Z&V-.`T"`Q.#%4,2PPIHCNB30QS
M-0:B4@QR-4P,<#50#%,,`Z)1#'BC>:-]HXD,?Z.5#,P,R`S.##*DR@P`I)TV
M(J3-#*FE7`UG#6D-90UB#02G)S@U.%GVJ@VXJ)NIT@VB.0,.#`Z2J@D.!@X%
M#HDYCZH+#@@.F*JE.:ZJC@Z=K;8ZZ`Y)KU"O1J_J#DZOI3O#.U6OZ0[K#F2O
M\`XXL4L/JSUS#W4/D@^1#Y,/)3ZG#Z8/J`^J#_ZSJ0]9/KL/O`^Z#[T/)Q"%
M/Z:V)!`>$!\0'1`@$",0*1`B$)RVF;8<$(X_*!"UMJ.VH+:GMINVW[CAN'$0
M<Q!R$$VY`A'SNV^[:;O^$+Y!:[MXNX>["!&%NX*[D+L'$001@+MGNP`1_!!A
MNT01D[OQ$/*[AKNF0081S;_$O\81PQ'!$<(1#\'$$<<1#<&_$=(1<\'*$;KV
M"L$O1`C!$\$3$OC#,!(^$CD2J\2HQ#P2/Q*EQ#02/1+#Q*3$.!+4Q+K$\<6@
M1H(2/\:#$NK&FQ+WQ^`2W1+ZQ_7'WA+^Q^,2Y1(`R)='XA("R/O'!\C?$AK(
M+A.XR3<3.!/IR>O)4,I/RHM)ALMB`8[+E!.3$ZL3K1/PS/O,]1/W$T+.]A/X
M$X7.^Q/Y$U@46A0%T5D4#TR%%*04V!39%$O5W13(%&/5^A3[%'5/)Q6?3RH5
M)169UR@5@=H7VQ#;$MNF4I45FE/ZW//<\MSUW/;<N]W"W:?>#Q81%JC>H]X0
M%JK>%183%E=4W-]'%D86#^!9%EL6>>!>%G_@A>!:%I$6DA:0%I,6&^+W5+X6
M=^)VXICBO!:[%K<6N19ZX@$7_A:\X[KC`A>VX_\6L%6TXP`7S^0W%SH7;Q=W
M%WD7QE9[YL@7'.@AZ!WHP.CR%__H\1?P%V)85NLT&*'MHNVF[5;P5_`L&2T9
M`?'M\1SW\O/Z&KA?D0#`7Y0`MU_A7\0`"@'H8X4<LF12`:YF60%O`GYI\@'T
M`4,>=FGQ`3P>EFEJ`B!N(6XC;BEN=W!1<20#5G$C`XAQ67%5<2<#EW*8<FT#
M[2%N`V\#H7.C<S4BGP,*!`8$#@0*=PT$!00]=PQW"P00!"X$/7@Y>+!YLGFN
M>98$EP3$!$<EQ00@>]($;GQM?&I\@04R?HX%D`6/!3E^D065!9,%HWUM)G]^
M-7X]?O1_]7\[!D@&2((H@D8&1P8G@C*"+(),!BZ"2@90!D,&(X(Q@L7U20:F
M!J4&I`;)A(F%N0:[A<X&SP83!Y>(DX@HBL8'Q0?*!]D'P0<8BCN*]2HGBB2*
M&XHQBLL')HJCBC^*(HH9B@,K08HKBF4K0@@,C74L=`AS"$Z.N8[ZCNF/Z(_D
MCXHM5BU2"5^279)2DE`)=))+"4:23`EM":J2F"U*DEF22Y)/"6@M\`E0E30P
M13!-"DP*T)A/"DX*4`K,F%PQE@I6,62999F7"I4*F`I<F16;[`KK"A,+%`LX
M"SH+.0MYG&@+9PO%G;B=+)^^"[P+-Y\UGS&?NPLOG[H+*Y^Y"[<++9\JG\$+
ME:#W"SZB8`Q'HD6B60Q<#%H,6`Q2HEL,<*)0HEBB4:(]HET,0:(,HCRBAJ.#
MHXFC\Z/4#-,,OS;2#+TV+:37#-$,Y#;5#,6E5?9M#6\--#AU#6P-=`U#IW,-
M-Z=%IS8XK`WEJ*:IVZH0#MJJYJJZ.;PY#P[(.2,.PSD=#K8Y#@[XJNFJ%0["
M.1,.Z*KVJAL.Q3DB#B8.YZJ].;`Y(0X<#A<.U:H:#KLYTZW'K=&MF0[#K9<.
M@*^8K_T.A*_V#OX.]0[_#O<.EZ^#KX&O`0\$/(RO0K&KLG</H[*FLERS:;-G
MLZL/B[2HM,`/V+8Q$"X0B?;<MBP0X+;EMC(0+Q`K$"T0,Q`8N!FX\3]7$%P0
M>Q!?N5ZY>A`"O")"$Q$>$1<1(!$J$1$1%1$/$1@1.$(2O#:\+!$R0JCV$$(C
MO`.\'!$`O"D11KQAO!(13T*7$83!<D1KP6+!5L%JP5+!5<'4$=`1?$1AP;OV
M6,%WP=,1%!+7Q$8211+>Q$,2W\0-1D022!+1Q$<2XL3AQ-W$"$9)$H422\:$
M$D[&G1+\QIX2H!+ZQIP2^\:?$O[&]Q+J$C'([Q+I$O,2\!+K$CC([!+R$O42
M[A(ZR+O).A-+$UG*2A-,$]O*W\KBRGD3>Q-X$Y[+H<NU$Q#-M!.W$YY*"13^
M$P@4!Q1VSG_.?<X&%`04!13_$PL4@LY7T#L4711<%%\47A0H3"[1(4R#%(O3
MC=.G%&9-;$V0TZ@4[-1OU6O5<=5XU?9-X!3?%/X4_!3_%/T4K=<L%>Q/ND_C
M3[U/G14OV[12>-U`%OC?&>!?%IO@E."7X)G@IN&DX:?AT525XL`6(U60XL$6
MQA:;XL3C!!<%%\;C"U8^%ST70!<_%^/D0A??Y-WDY^2$%X(7?Q>%%RWH+.C,
M%[)7RQ?-%S3H..C;5QWI]1<:Z1OI%.GP5Q?I(>H@&"$8JNJAZC<8/AAS6#T8
M;EACZWGK8.ME6&+K/!AAZS@8:EAPZVU8:NL[&,CML!C%[;[MPNVM&+(8N!@+
M6L?MKQBP[<KM&AEV6R`9(1DP&:A;+QD-\0?QEO'O\5\98!D>\AWR$5R0\^M?
MB@`9&YP`[E^:`.]?[%_Z8PP!"P$-`9(<!&73:?X!T6GZ:?\!^P'\`0D"R&D`
M`M5I=1[-:=)I^VDJ;(AN86YQ`F-N8FYO(%=>R'&8<2L#P7,_=T%W%`01!!($
M4GAC!%YX;@2:!,=YFP1P>B=[R`1Q>[![]@1"?D-^I2:,!9<%H@6@)E=^G7Z)
M@HV"BX*`@I*"BH+(@E0&CX*3@I&"J`;RA-Z$J0;(A;0HV"C"*1@'%P<=!Z>'
MH8<Q!XR*?XK8!]4'>XJ5BIF*X0>.BM0'VHJ*BIR*XP=^BD0(10@:C56.=@AU
M"&".J"R("*H(^X^K"*P(_8]7"8,M8`E="6L)T))C"6<)Q9)>"=*2$9/%+<TO
M^0GS":V5I)6IE;"5G97V"9B7G#!1"E,*4@J2F9L*BIF<"HV9EIGW"IDRCS*1
M,D6;2YL/G!:<.PN*G#X+/0O)G6D+R)W*G62?PPO$"\<+79]CGSDTQ@LN-,@+
MB)\ZH#F@GS2@-.8+^`L7H9.A!PR5H60,:`QVHI0U90RN-8"B>Z)I#$BBJ**(
MHHNCBJ.,H_RCV@S@#.8V6*3>#%&D5:13I!P-'0T:#=RE>PUZ#7P-7*=X#7<-
M9:=:]K$-[JBR#;`-\*B\./*H-@XUJRX.(JO6.2"K-`XMJRBK)JL\JRH..*LS
M#BT.+PXQ#BL.,@XJJS4.&JLPJ^.J&:OIK>>MSSK6K\2O"`^'KP8/QZ_9KQ@\
MWZ]-#V$/"K(!LK&R>`_!LI0/E0]VLPVT#K3!#\,/;3X'MSD0";<6MSH0.Q`U
M$#80#K<\$)`_!K<>N$JX6!!\$'T0C1",$*:\D;P[$3\1N+R6O#(1+1'%O"\1
M.1$N$3H1"KTV$3$1/A$X$5)"-!&RO$$1M[RTO(F\C;PP$8>\PKR<O)*\0Q'*
MO%!"BKS@OY@1YK_EOZ!$I<&SP89$VA'7$;7!K\&51+#!S,&,1*+!OL'&P:S!
MKL$8$F!%P_8(Q07%4A(H1O[$3A(@1@#%3Q)0$F3&:,:H1H82AQ*)$FK&:<8-
MQQ+'HA*C$@_'H1)GR'G(<LAFR'S(^1+]$FC(A<AVR'3(<<ADR#X3/!/XR4T3
M;,I.$^O*@1.#$X(3N,N`$X@3+<TNS2C-*<TQS;D3+\TJS3I+I,ZWSK_.$10-
M%!`4$Q1CT#P48A1C%&?1OM/@]I75G-4#%085`A4!%7'6<M8%%6_6E$X14/'7
M-U`V%>C7-15#4.KVH16C%4G;9-N@%4C;ZA6F4^@5+-WAW>_=P-XA%AL6U][4
MWDD62!:MX)548A9A%F068!9C%J[@K."65&86K!:K%B?BKN+#%K#BQ!8E5<#B
MQ.((%PD7"A<&%P<701<'Y447_>1#%T07)E8T5D<7!/<;YASF<1>RYK3FM^:Q
MYK/FKN:+%]07TQ?1%[I7TA<_Z#;I]Q?X%S'I.^DUZ3KI-^DBZC;J,NHB&,#J
M11A!&(%80!B*6(7K?UA"&(GKP1C%&.'MNQBY&+T8R1@*[A%:">Z_&,<8Z.W#
M&"09,1DS&1CQ,ADT&5(981G96WH9@AD\7,7S(QL-8`Q@(6`L&Q9B#F0/`94<
M%V0C`24!2&H&`@@"B!Y5:DEJ3&J+'D]J/6IZ`G<"BFZH;HIP+@/+<2\#U7'4
M>!L$$P1<=W5W9@1A>&4$EG#W!(I\T'[A)M<F27[/?IP%UH)_@E,&TH+/@@:%
M"86Z!J,H(@?3*0:+\8H$BXLK^HKTBNL'W0?YBN\'BXH#BT<(1@BBC7@(K"R)
M"`R0"Y!H"78)=`EY"223>@EW"13V<0DEDW()]I7_"?N5!0HRE_N75`KRF/.8
MG@J?"G0QG)ERF_H*=)M$"S\+0`N&G$(+CIR0G%$+S9SWG-:=A)^5GXJ?0#3*
M"Y>?033."\D+H*"AH"*AIJ&DH0D,Z#1L#&X,<`QM#&L,<0QR#*^BL**]HHP,
MY`QVI.$,>Z1YI/8VYPP`-^(,'PWNI?&E?@V4IX`-63A5.)&GN0VW#;@-$*FZ
M#?0XKZG3#3\.!#I%#D$.%3I"#D,..PXX#GNK=ZLZ#O4Y@*O&JSP.?*N0JSX.
MHZM]J[VKG@Z?#J$.$ZZ;#A(/$;!$L`VP&`\,#Q2R8@^XLGH/M[*#LZX/KP\4
MM*T/'+3$#\</Q@_%#]2TU;3!/T`00[="MS\001"*]D&W3KA_$(>YAA"!$(`0
MCA!*$3F]1Q&/O2J]2Q%&$4X1?4(KO:5"4+U($6Z]11$[O5.]7[TOO3"].+U,
MO?&_VQ'G$>01!\(6PN$1%,+I$?O!Y1'@$>,1^,$0PAW"_\$+P@3"ZA'^P?_#
M.D94$E@27!(CQ542BQ*,$J82I1(JQZ#(F,B<R/\2GLBFR+7(L,@P$T`301/Y
MRO7*AA/2R[\3O1-0S4[-2\U2S4W-OA,9%.3.'!3:SAL4%Q08%%%+W\[HSCT4
M:A1F%'#1<M%G%'?1:!2M%*X4YM.JU=84"16,UIA.B=8,%0H5,M@[%3H5A%"!
M4'K8;U">VJ#:<-NO%:H5JQ5NVV;;L15EVZP5[!5_W>#=`1;_W?;>]][UWB,6
M_-XD%AX6^=Y*%F46:A;*X,/@QN!I%KCAO>&5%KSA!>+@XNGB0E7?XNSBS!;E
MXM[B`/?/%O#BX^(/%^SC#A<+%Q`7#1<,%_+C[^/IX_OD1A=(%S=621<WY=[F
MD1>.%]KFV!?6%TOHVA=)Z-<7U>C_5_D74NE'Z?P72.G,ZM#JJ5A*&*=83ABS
M6*Q8L%B&ZZ?KH^N<6+;KK>L3[CQ:'%HZ6M,8S1C1&!?N(NXR6C1:2>XF[@SW
M/.XH[JCPQUO[\6(9,O+6\DCS@QD_7,;SDAF?`*``)6`F8"1@,V!P82<!D&<+
M`I5JH6J2:H]JGVJ6:IAJG6J@:HT"EW#K<7`#AW?K)#)[F@6?!9T%V'[[?@9_
MFP71?M4FL/5@!F0&:09C!F<&8@;V@@2#_H("*/^"]X(8A:P&%(7-A2"&WH<F
M!R,')0=%BU.+^`=+BU6+08OW!_L'^@=<BU2+<8[0CK`(KPA3D"F3?I-^"7F3
M?0F`"7"3:I-_"88)A9-DDQ(N>).!"3*6)Y8OEB0*6`I7"J`*NIG^"G&;C)L5
M"QJ<1PM&"YB<Y)UK"VP+A3-4-,*?S`NZGU4TR)_+"Z<TJ#3Y"[FAN*&EH>*B
M>`QZ#'4,V:)V#'<,K*+=HNH,[@SM#)VD[`P/-Q&F`Z:$#84-@PWNI[P-O0W4
M#:2KV*O=J]ZK50[GJU`.3`Y(#M2K4P[.JU<.5`Y.#DH.40[QJ].K20Y+#F,.
MRJOIJZ<.I@ZD#AJN0:YH]N0ZY3H]L$"P93Q./!</0[`6#S^P/+!C#R&R(+*"
M/<:R>P]\#]&RRK*.LY&SL`\M/N.TB+="$'"W1!"=N)VYD;F8N9FYB!"/$%,1
M6Q&_O5D1KKVQO<R]!+[*0A:^S;U4$;Q"X+W+O=2]R;W_OYD1_;]7PE+"4,)%
MPDW"\1%3PN\1@L)$PL[#S\/2PP+$3\58Q6(20\5C$E+%8!)A$E\22<53Q4W%
MC1*$QHX2@\8RQ^+("1/DR-/(!1/5R-W(`Q,&$^S(YLC2R/K(VL@Q$P;*!,I/
M$WO*!,L"RV83_TG$$V#-PQ/!$\43!\\%SPS/(11:SQ\4(A0:SR<4(!2*T6T4
M;!1K%&\4<!2,T0G4IM:F3JS6J=9"%8O8ME",V$050!6(V(G8/Q63V*M0BQ6#
MVT_=)18H%B#?(50VX.+@=19R%N[@;Q;GX.G@=A9Q%J=4W^"7%L?AUQ8)X]86
M`>/8%MP6VQ;4%CY5$Q<1%Q07!>0,Y'CE7>51%U`74Q=4%U(77N5@Y6?E;1<%
M]_3FE1>9%_'FFA?ZYI,7EQ?XYOGF">?]YO?FW!=9Z/T78.EHZ?X7`!@"&`$8
M`QAJZ13J/NKDZB<8)A@D&$P8O%A0&%484QBW6%(8TNM7&+Y86!C6&%CN4.[4
M&%SNVAC9&!G/8EK5&.08#O?<&!L9CULW&3892QG+6V89=AG?\GX9?1E_&809
MBQG9\Y09H0`1`69E$`*I'N%J[VKH:C-L$R#^<3(#]"'O<^QS['6<=R`$F7=P
M>&YXG01!>^PF[R8"?P%_I04;@".#)8,D@R:#,X,O@X^%5H@""/X'`0C6*P,(
M_P>9BP0([?5*"-F.APFWDX0)MI.%"0DP5)97EGJ660IY,8Z;QC*0F[F;!`M)
M"T@+[YUM"](+TPOBG]$+UI_8G]J?WI_G"PH,PS4(HP2C"J,+HP*C\`RJI,&D
M'S?7I]FG93C>I]JGO@V_#2JIQC@Z.C&L-CHKK"RL*:PNK%X.)ZPHK%L.7ZPP
MK"2LZSJK#CJNK`XYKD"N@+"$L!\/'0]UL':P'`]\L!X/>+";L'ZP6K%D#RRR
MA#V<LT>WBK=($$<0)[A*OEX181$GON!"\T(NOB:^",#W$;W"EL+T$?@1'D6^
MPH["=,5D$H#%DA*/$I`2M$:3$J@2/,<]QZD2.L="Q_E&),D&R41(#A,5R0\3
M`LD,R0L3",D*R07)',D0$U$3@LI0$X;*8Q,#S'O-QQ-ZS7%+)!0F%&Y+@,]Y
M2UC/Q$MT%',4<A2JT:O1-M)*TK$4C$W6U0X5$140%0\5$A5)%<E03Q5-%0/9
MS]A5%9_;HMLJWB_>1-]`WRP6*Q81X0_A>18-X0?A`^%Z%K!4F1::%C7BKA:O
M%@3CY!;A%MX6YA;?%B;CYQ;B%N`6'N/E%EI5#N08%QWD'N0?Y%87B.5&5HWE
MD>6`Y6X75.95YIT7H!><%R7G&N>A%Z(7GQ??%]X7PU?J%XCI!AAZZ008#UB`
MZ1[K_.LE[%\8]%CZ6%P8"^Q>&`;L!.S=6%D8^>L`[&0871AB&`+L91@'[.U8
M6QCO6+7NW1B'[M\8D^X/]^(8ONYF\"<9Q_#/\)9;.AD\&3WQ.1D\\4?Q/1D[
M&;-;3!G#\6@9XEL;\X`9A1G)\Y49W?.6&9/TCUP]8*0`$@&Q'B4"YFY!(3<#
M]W.P=ZYW_5UH!&<$G@2??)Y\,'^J!4]_J06D!2=_47]Q!F\&48-4@U:#)X6M
M!B2%]BL,"/(K"PCLB\2+#PAY"/B3]I/WD^V3C0F/"?23[Y.."0P*?Y:BEGZ6
MI@K%F:,*I`JE"H@S;@OQG_*?^@LOH7P,?@Q[#'T,(Z,IHXT,]`SS#!NFZZ>)
M#>JG,ZG`#6.L90Z2K&6LK0XE#Z"P</9>L<D/JK=*$*FW9T")$)R^9A%P$9*^
M;1%I$6<1AKYR$0Y#;A&#OIP1_!']$002_Q'"]OX1`!+.PF82:1*3Q:H2JQ(7
M$R[))\DHR1437D@2$PY*&,P6S(W-RA..S<D3RQ.0S8_-@<\I%"@4BL^,SXW0
M0!1U%'84LM&(%-G5MDY7%0%1#=E?%1/9'5%8%5L5&]DO4:S;LQ6SV^\57M\P
M%F#?:-]CWVG?9]]!%DL6*.%]%B[A,.%\%B;A,>%!X>!4VN';5/KV"^)A533C
M,^/H%NH6Z18YXSOC0.,PY!L7,N0WY%472E99%U@7@>6?Y:?EI!>C%T3G1^=(
MYSWG,U>G%TGGX!>`Z*#IG>D(&`H8"1B<Z4?J!^MQ&`]9;!A)[!%91.P#60%9
M;AC?[!993.S]74_LX!CN&,'NZQBY[LONS^[$[I-:ZACO&.<8RN[#[M#P4?%(
M&4D9J/''\<;Q31G*\0+R51E=\EKR:AEL&5GR:QG,\ASSS/.8&9D9EQGH\^SS
MZO.M]+#T7V!88%=@6QV39Q8".VN_'C1K\FXY`_US'74E!,XC!'I(>UA_3X-T
M!FZ#<H.N!BZ%_(OTBS:0#I22"90)%)25"1F4#0JFEB4*R9O`F\R;&YRJG*B<
M`Z#5"]8+K#3H"S6A?PS2-?4,]@SW#-FD)`V-#8H-/ZD]J6P.9@YJ#HNL9PYM
M#F@.4CIHK(JL6*Y7KLZPO+#`L,&PO["KL%^Q90^FLYH/*;2Q#TL031!,$$X0
MN+=S$741W;[6OK'VU;[GOMB^[,(#$@##!\/]PO'"_\*JQ;#%2,D>$U/)<TA-
MR1D3'!,:$QT3=DA#R5#)0Q-2$XS*)\R5$YG-S!.QSRL4L,^JSZS/*A3'2W<4
MR-'*T4+4X-7GUNC6YM83%105-%%;V5;9715:V6`5/E%B%;C:Q=NR%?`52-Y]
MWWS?@=^"WV+?3!9%X8(6O%2!%IL6X^&D%NX6[!90X^T63^/P%N\6.>0=%SKD
M8!=>%UT7P>5.YV[GL1>K%ZP7K1=QYZX7C.B)Z.(7Y>BSZ;;IM.E-ZCE8$^MX
M["I9>Q@F67@8=1@G67+L\ACT&/,8P%K)6G7PVO#7\#\9/AE`&4X95QE9&5@9
M%O=I\F?R;AEF\F_R<?+L6\_R(_.!&889I?./&?[S^_/]\VA<FQFQ&;,9;6LZ
M`P5T('4G!,AWR7=J!*P%)X88"!Z,-HU,"#V4E@G7F4H+K9P`GH$,.J.##/D,
M^`PFIHX-CPW!#;>LMJS`K'`.FZQQ#MBP*@\M#WT/,CXQ/L"W3Q"_M[^YD!`@
MO]"^#K]Y$1V_'K\5OQ2_'L,LPP42N<6XQ;;%GL:<QDW'_49NR6#)(1-DR6+)
MY;`R$Z/-S1//$]+1U=&.3185%16U%0@65=XR%I/?,Q8T%CP65N'"5.GAG!9%
MXO06\A9\Y&(7T^5A%V07M1=+5[07CN>7Z.,7F^B9Z!Q8#AC/Z1M86>HL&"L8
M(.LCZRKKA1B!&'X8@QB`&+#L0EDO[]1:^QCW&#+O0^\_[SGO^!@P[]WPVO';
M\5H9A/)_\G+R@/+N\G@9*O,B\W'SS?.=&9P9#_08]&I@J0"_`-`>SQX,=-HC
MIGQW!G8&-X6[!NHIXHZ;";R6#PI;"M6;3`MO"]D+$J""#$NC0:.AH^RD=`YR
M#M2LV*S9K',.VJQLKFVNL0XN#^>PZ[#LL&*Q3@\KM`VUS;?#N3^_/+\^OSV_
M.K\XOT3#1<,+$DC#4,-L$HE(>,EYR8L3/LS0$RT45-3D%'$5N=E846\57]Z'
M%J46<N-UXQX791>Y%[<7N!?D%Z/HI>C<Z=WI6NJ,&(D8BAC;[-SLBQBK[X3O
M=N\!&?X8YUH#&089@^_J6O%:?_`=&4,9<_&M\;#Q3QD/\@SR6QEP&7GSB!EW
M\WKSB1E$7#+T)_0J]"ST;5PH]"GT./0O9'MK#739(]9WU7>A@TR,G@F?":<*
M2PO;"]H+P*#6-8X,=@[TK#`/+P_PL&8//[)^$5W#<L-BPSI%9L-U1F\2B,G1
M$R\4Z,_DS[(4&!47%?_6=A6OWZ[?3Q:)%O+A2.*!XW[C]18?%U+D[^5=5^47
MK>CFZ1`8[>D/&.GI8>I@ZC/K+Q@P&&19"^T([9,8E!@'[0<9"1D(&<KO"QG&
M[PI;A/#K\'WQ4!EQ&9ORHO*A\J#RG/)[&7P9@/-S7$#TH1DY]#STH!FB&<ID
M&P*):X("/(5`C6.4:93I"U.CA`SA-1>H&J@`K;,.-`\S#X`1;\.KQJT2D<E$
M$U43L<W2$^_/\=ORV[??M=^*%H;C6N1G%\;GR^?F%[+H$QCSZ2U8)^V7&`Q;
MU>_8[PP9[.^'\/+P1AE<&709<AFM\K#R_?(?7(?S2O2D&:,93O1)]%'T3?2T
M&7)@-@$6=&V,08VR"'&4=)06"W`Z=PY\KG\1BK]6QWT4>5'ZV4I4C!9;Y&@7
MOA<5&/7O\._S\'_Q$_)U&:49&72%?["#=Y3_I'@.-0^=/((1A[^#$8N_<1*>
MR7X4CA:/XV!6:1<YYM3G\>@"ZFOJ0.N:&)L8$/"^\KGRD!ED])Y<Z9N0OX81
MA1$<P`X2DL.NQJ/)&17)W\`7V.=$ZR3P^%LZ7'U<</33]`T,%AC#\JD9JAF%
M#"&MRKF<PW/JAO'!\PGJEES5],(7,1@1&:L9G!C4WP`T````-0```#8````W
M````.````#D````Z````.P```#P````]````/@```#\```!`````00```$(`
M``!#````1````$4```!&````1P```$@```!)````2@```$L```!.````3P``
M`%````!1````4@```%,```!4````50```%8```!7````6````%D```!:````
M6P```%P```!=````7@```%\```!@````80```&(```!C````90```&8```!G
M````:````&D```!K````;````&T```!N````<````'$```!R````<P```'0`
M``!U````=@```'<```!X````>0```'H```![````?````'T```!_````@```
M`($```""````@P```(0```"&````B````(D```"*````C````(X```"/````
MD````)$```"2````E0```)8```"7````F@```/\``````@```0(```("```#
M`@``!`(```4"```&`@``!P(```@"```)`@``"@(```L"```,`@``#0(```X"
M```1`@``$@(``!,"```5`@``%@(``!<"```9`@``&@(``!L"```<`@``'0(`
M`!X"```?`@``(`(``"$"```B`@``(P(``"0"```E`@``)@(``"<"```I`@``
M*@(``"L"```L`@``+@(``"\"```P`@``,0(``#("```S`@``-`(``#4"```X
M`@``.0(``#H"```[`@``/`(``#T"```^`@``00(``$("``!%`@``1@(``$<"
M``!(`@``20(``$H"``!+`@``3`(``$T"``!/`@``4`(``%$"``!3`@``5`(`
M`%8"``!7`@``60(``%H"``!;`@``7@(``%\"``!@`@``8@(``&,"``!D`@``
M90(``&8"``!G`@``:`(``&D"``!J`@``:P(``&P"``!Q`@``<@(``'4"``!V
M`@``=P(``'@"``!Y`@``>P(``'P"``!]`@``?@(``'\"``""`@``A`(``(4"
M``"&`@``AP(``(@"``",`@``C@(``(\"``"0`@``D0(``)("``"4`@``E0(`
M`)8"``":`@``G0(``/@"``#Y`@``^@(``````````````````````(9:0!A!
M&%H8Z'4"&"D8#ELG8`(</@'<)SQ?=6`HT4(=:AU2)3QO==%XT<0I3"RM.1(8
M+QB6&-`80AN#&QG1I6"J8`]C#F2#';@=G&6;93QJ*"/"<2,F`2@`*;2'N`AL
M-RLYB!MY2+91%QAE6@P`LELP`.(8VQAW7D)?K1LS8/<;V@"O8#9B$P$;'8@=
MAQTB9<\=_1UC`><=W""C:=D@)2$G(3,C$R8E<B1R=292=HEWOWK$!<,%\2^U
MATRB4D44QQ+'`0"C6J):41AJ&+9;#!FU6[1;_A@;&<);N%LZ`'E>JP!S&PA?
MCAMZ7[9?O6"W8+Q@W0#$8,E@I1P5`:<<I!PP8X-CA6,29#1DO1WD9-YD*F4"
M'J]EM&6S9;%E*R$;(S4CWFRG`J4"N&VP;:8"PF_]61<F?`,J<G`F?2:I`^EU
MZ2=7=C0$-02V=]=WWG>H!!DI'"EU*<)ZJWO_!,@ICW['!<8%R`5M?[6"T`;1
M!L"'OX=9"+F+'(T2-+T(@(Z$D861*`JS.225J0J0.C8\3*K,#_:Q@4BX47##
MM!1UPQ?'(Q@6`"P`\5LN&=I;3QNY7[H;WP#@`"(<SF#28-!@%P%#8J\<L!RQ
M'$UB-&,O`=EC9!T89-,=.&5J`==E<`%M`=QERV769=AE;@'193[1/-'292L"
M*`)9:OU9/R/E;.9LD@+H;(LCO6V1(Y4COFU);S\#S6^*)4\#=`-><=!Q?0,&
M<[<#HP.P`[$#AR:K`WQS<7/O=3H$-P0-*#@$0`2-=[=WCBB?!#-Y?WEZ*?)[
M!`4)!08%_00*!0<%*G^+?\H%@W^*?Y`LR06.?YHLMH(\+CHN?P:8+MB$T@96
MA=*'93#;T4,'PH>'BH&*PHN\BR.-P0B3CL4(HPF-D8Z1*@I?"CN5395="C25
M,97REO"6%PL5FBB;<0MR"R6<YYT/#.F=%Z#"0)$-;*F`J4NJL@_/#\X/GD;>
MK_NOZT=1L(E(EA`!L@*RED@%LH=(`[*7$%'!P%&+%,-14\%ZPWC#=L-YPX_#
M?,-X51O'',<E5I*/=1AT&"Y;+%LM``Q<F1D+7%``2P`%7$\`3``%T7$94QN_
M&\)?PU_`&TA@[AM&8.0`XP#J8.$`ZV#B`.Y@/1P9`;T<#!W88AZ:WV/>8T$!
M-T5/9,`=7@$-9@AF>0$)9FX>@QX29F5F7AY='GXA>2&):GHA;"&$:IYJBVHR
M`H<A8FP=(Y0"1B.7`OEL0R/W;)8"F`(&;=UML@+9;=]MXFVY`F$E9B7Q6I`E
M=0-_`WX#*2:/`S]R/G(+<[T#LB:#<[L#O`.&<\`F?'8]!#X$=`3W=WH$=@1X
M!'4$^W<[>:\$L`3'!,P$^7O*>Q8%_WL2!1T%"7P#?!4%#P44!1\JXBD0?)I^
MGWZP!;\%P`6'?](%V06W@GH&"(/Y@H$&@@;T@A8O^2[:!E>MB##6AYLPWM%N
M,)XPU(<B"!\(D(J-BB$()#-@B\Z+SXM<"'TST8M]"(T(CPCF-,J.RS30"+>.
MV`BRCKN.N8ZU-*<)GI&7-[*1FS<2"F^3K),O"B.4:SDN"BP*7`ILE=4Y,I5>
ME6(*9PJT"ON6*9F]F1^:0SQ!>1V:G#PQFR^;Z@M#G?L+09T4#/6=$PP2#!`,
M$0SRG88,Y#Z8#!Z@5*(J#5:B*:,GHRBCSD&U#GFI?JFVJ[>K$T;6#]@/MT;9
M#]0/UP^!TKE&_5E-K>1'_4</2&`0";$(L9X0H1`>LAJR([(5LAFR%K*_2,I(
M%+(8LL%(H!`?M=VVW[9IP=!1_5ELP;D4D\.N4I7#E,.1PY?#,,?!%<(5.%88
MTQP`,5Q>`+P960!<`#9<7P#I&;T9XAE8&\E?RE_.`!AA$F$981!A%F'&'%]B
MR!S?8A=C*!T\8RD=ZF/I8QQD6&1D9/-D7P&79H4!6F999H8!CF:T(;QJJ2&'
M`@UM_&P,;0=N"F[*`@)NPP(F;@AN'6["`F@E3F]!`^UO[F_O;X`#@0-0<DQR
MDP.2`T]RQ0/4<_U9L'-&!$$$101"!#\$I78)>(($@01_!*4$*RFS!+4$\WG7
M>8TIV@3<>ML$#048*@X%"WP>!24%)@4<!2$%5RI(*B<%&@4Z?`U\$7PX*B!\
M`7PD!3=\H]%Q*JI^P07A!>=_Z'\2+>L%]7_B!=<%Z04U@.9_"BWX?R,M\7^$
M!A2#%8,)@[4&O`;<!MX&WP9[A2HO?H5FAV>'"HA4!^`POC!3!R0()0@I,R@(
M)PB<BF*+X8O>B]^+Z8N+".2.]X[<"$,UZH[VCA*/`=*F-[()P#?9D2\Y7Y,;
M"G.3,@IQ.3^4>)5K"GV5;`IM"A*7N0JZ"@D+"@LOF>H[&PLPF=N9(#Q8"RF:
M6@LVTD";=PL]FSZ;>0NI/#B;A3U(G.L+T)S]"_P+!CX5#!@,]CT6#!<,&0P`
M/AL,#IX)G@(^!YZ'#%^?8)^<#"J@F@PIH/\,_@Q-H3$-+@TP#3(-;*+]62\-
M9Z*5#98-.:,THUFDQ0UZ#B.I0@^"J50/@ZFHJ56J^:KXJORJ^JH)1GK2GP^@
M#Z(/X`]TK>$/:ZUQK=\/=JT.L6(081`0L0^QIQ`XLCFR.K+:2#>R/K(*28D1
MG+0JM3JU*[4HM:JV#[<=$A"WYK@J$R6]CK[3$T(40Q2+P9$4C,&:P9`4OQ2S
MP[P4LL/`%,<5Q1555D3'4E8U&%A;IUPT&@$:8UP*&F8`:EQE7&M<K0#M7ME?
M.V$R85@<-6$Q83YA0V$V86UB'0'D8C$!*QWT8TP!:61K9)4!D0&4`;]FPV:N
M9H\![!ZQ9A4?_AZ[9J]FL&;C'A8?0`+O:D$"[6K3(?!JDVPT;2MM62,G)-@"
MT@+:`B@D$"37`@XD0@-7`P1P`W`"<*\E!7"Z);$E`'!T<7@#@@.7`V5R8W+)
M`]=SR`/6`\P#Z'/0`]MSV'/.`\<#_"8)=,\#RP/R)OXFY7/G<_@G/W9'!,!V
M2`2Y=KIV@P2%!(0$('A/>2PIN`2\!)%ZD'KN>O-Z['KQ>NMZ\GKT>NUZ07Q(
M?$5\,04T!38%@BI_?(M\(P4[?$Y\.@61*H\J?'RT!;4%[07L!=@%\'\V@#^`
M0X`Q@#2`1H#V!><%+X##@GP&>P8V@X@&1RY,+B&#R-&*+G.$O@;FA.<&Y0;N
M!N$P2C$_B%D'7@=KB%H'/S%A!U@'6P>],'&(7P?BT2H(+0BPBB,(*P@L"/.+
M?@CUT9,(F0AAC5^-LPCG".H(*(\>CRF/`M+KCF:/M`GVD<DW%PI@DW>3NY,A
M"KR3.`HW"G0*<PIU"J*5LI6>E78*>`HZESB7NCH,"R`+'@M-FEL+7II<"Q>;
M@PO&/(`+@0M^"X@+A0N)"W\+C@MDFV>;A`NW/(P]69R-/=J<[@OM"_X+49W_
M"U6=.YXTGB,,-YX7/C&>'#X?##^>69X4/F&?CPR0#%B@8J!0H*`,4:"F#)\,
M1J"G#*$,+:$"#38-2*-1HTJC3Z-0HTFC8Z3(#6:D8*38#0Q"W0W<#?&DUPT'
MI=H-N@Z;IZ.GG:>^#L(.NP[`#JFGIZ>DIR-$NJ?!=R:I0P]5#Y2IDZE7#V@/
MF$6010>K#:L"JPRK":L(JQ.KH0_2JSI&/JP\K&>MGJWJ#ZVMYP_9K4*MHZV@
MK>@/Z0]\K02P5!!8L&"PR;#(L"9(91`<L1JQBA!TLK`0;K)OLGFRO!`N27>R
M54D:2;@0/4E\LK(0<+(P2;T0>K*"LHH144NA$42UHA%#M8A+1;45$B6W'[<@
M$G,2Z+B.38U-";FWN;FY9+ICN@E.%$ZQ$F*Z9;HK$ZR[11,JO9<3F!.6OM43
MPK_>TI,4EA0'4I04JL&PP<<4Q134P\W#UL/$%/#$>56$5<X5RA7,%5=6R16Z
M5OU92]!B6VX`MUQG&JQ<JUQQ`,%<NP#3`.A?:6%=85]A\P#M`/4`9&%B8?$`
M\@#V`"`!^6(H`>YB&!TL'5D=JV.L8ZIC:!U^'89D>F2A'2AGH0%;'ZH!J0$Q
M9[4!I0&H`4(?IP%''RUG0]$]'RMG,F=@'^LA*6LF:U-K30(S:S1KG6R<`E\C
M06WJ`N4"D6YI;F\E(G!>`S1P;=$N<88#A`/T<5HF*'39`QQTW@,1="1T%73;
M`Q9T5'0C=/]U,03/=M!V2P3.=DD$2@1,!,=W7'B*!#9XB02+!$-XNP2B*9TI
MY`0J>P%[HRD+>P][.P4N!3X%1@53!=]\1`72?#\%0@5/!<U\4@5*!<(JVWQ:
M!:4J207/?!PLP'X=+`,&@8""@(J`J(",@)4MFBT!!@8&^P7Y!8Z`!0;Z!8N`
MIBV6@/X%S(!]!HP&3X-*@U`NC@9+@SV#4BY$@TF#GH3SA,@N]83P!O(&LX58
M+_$&Y@;EA;:%V-&(,8:(;P=M!VD'MHB%B&X'JX@O"#`(8P@-C(N,C(RX,X`(
MN3.:")0(E@B5")<(<HWT"/X(CX\!"7F/`@EWC_D(D(^(CX"/GH_V"/<(@H\T
MCXF/_PB%CWZ/>H^FCPLVM8_TD;\)O`D%."F2)I(JDKX)P`E^DSL*.0I;E&&4
M8)0\"IN5%#H$.L.5?0K-E7\*>@I\"@4Z?@H5.@TZ@`J_"L,*5)=9E\P*#@L-
M"_68)@LD"R4+(PLA"RD+:9IEFH\+C0M\FXL+D@N`FY`+99SO"_`+WYQ@G0$,
M7ITN#"T,+CXH#"D,+`R/GF&>6IY!/H@,9Y^2#)$,ZCZ[GT0_J0RL#*X,J@P&
M#04-2@T^#3P-.PV;HD(-00U##:FB10UFHYH-FPV?#9X-<J1VI!2EW@WB#>8-
M#Z4I0N,-)T+?#4&F1J:=0TNF0Z9^#LD.S`[&I]$.QZ?0#LZGSP[(#LFGS0[+
MI\6G20]'#U@/:P]L#VH/::J`#X(/A`_(18,/'JNZJ[8/4JQ1K%.LGZW;K29'
M\0_CK?8/\P_P#QQ'UZWIK2A']0_T#_</WJW<K3RPB])5$"*Q,K$CL8L0RQ#"
M$-2RR+*\LLH0S!#-LL<0R1!P2;ZRQA!`L]:RPQ""2;VRK$FZLL00P+*;TIW2
MP;*FM*6TJ+2I$:U+J!&F$5^U<+5JM66U9[5OM8>URDM13#VW0[<B$D"W)A(D
M$B42G4PJ$G02&+EY$I!->A(9N<&YV$W739<2O+G(N2Y.<;J\$FZZLQ)XNK\2
MMQ+-TGJZL;NON["[-!-&$T@364^HO*:\5A-G$TB]1;UH$YD3FA.@OJ2^V!/4
MO]L3W!/=$]<3TK\BP$D42A3:4+?`S,`S4N;!&%*:%,C!S13*%/3#RQ3MP\\4
M?L/CTLP4ZA3M%/G$_<3I%`?%&A7O4XT5TA5XQWK'><>*R/(5>\G5RNG*/1;K
MRCX6^!8C%]E8M!AL6Z`:D!IU`(8:A!KZ7(H:=@!S`)\:H1H879,:O0#V7]4;
MBF&)8?D`?V&(8?H`@V&$89AA8V&'82$!)]$I`?5B4&,X`4X!AV2*9&5EMV?!
M9\=GR`&\`<5GRV>0']%GNP'"`<`!N&?*9\H!WF?)`<YGN`$0(1<B:&M.`FMK
M1")0`BLB:FM%(F9K=VN6:VYK5M&*`E=M92-6;9QNGF[\`OD"H6YC`T)PSR5&
M<#YP,W&'`X@#^G&:`Y=RFW*J<E8G<W1\=.D#AG3J`U0G4`3S=O!V5@12!$\$
M5`11!.QVKWB.!(\$9'AH>%IY/2D?>R5[[03K!*0IQGS6?,-\8@4L?5T%+GU>
M?3-]805E!5P%+7U&?5\%P7PZ?<Q^G8"#@/:`["T6!@H&^(`.!A(&_H#S@!$&
MZX#Z@!`&!X'\@`D&^BT5!M0M<H-S@W2#D0:5!I,&D@:/!E^#8(.JA#2%]@:T
MA?L&\(5U+_D&#8;SA0^&'#!]!\F(>@=_!\6(>`?7B,R(V3'GB'`'@@?!B(0'
MZ(@S",N*,@@V",B*>HM6"'F+?HMG"!N,90AD"&8('XP9C($(@@B#")X(B8WQ
M,YT(BXT/"1()"9#^CP"0$`D8"0N0%`D9"3<V_5E*D'TVAC;("<0)Q@EYDL<)
MPPELDIF2&])BDA23&0H<"LB3UY,,E$$*<)1""D,*<93?E>25@@KGE8$*E`J$
M"I"7T@H/"R(+3)DG"RH+^CLH"T^98`M]FGZ:?)IR/(V:&9N;"YP+P)N3"Y0+
MW#R@"YD+MINA"ZB;\0OKG.><;YW'GC8,GYXW##\,/`S$GC0,.0P[##4,,`PR
M##@,/@PZ#)N>EY[%GFN?SI^V#&<_L:"NH+"@LPP)#7=`/J*UHKJB3`VRHK2B
M4PU-#5$-3PV;07>CH@V&HWNCS0U^I"ZEYPTOI?`--Z7I#>P-,J7H#>X-`@XV
MI3FE-:5<IH(.@PZ&#GNF8:;NI^NG[Z<@J"I$941*#S"I6@]D1;ZI;@]GJGRJ
M<`]O#R2KB@^'#X@/*:OOJR!&MP_]#R!'#:X%$#Q'"!`#$`(0!!`Y!PD0_P]D
MKC]'%:[\#P$0"A#P1_5':Q!L$#6Q-K$TL3>Q1[,KL]X00;-#L]L00K/=$.,0
M,K/@$-D0V!#D$$2S2K/:$.\0H-(52KY)5+-NLU*SUQ"S$;L1Y4NR$=)+K1&2
MM:\1N-+@2[^U%A(H$B,2LTQ!MVFW9;=U$GX2?!(BN1VYTKG:N=NYSA+-$L\2
M4TZDNIZZ-TY'3EQ.G;K$$LP2R!+'$JVZIKJGNK.[X+LUO#>\6A-J$TJ]:Q-M
M$V\37KZ>$\"^I!.C$^03Z!/I$^`3XQ/YO^H3X1/M$S04-111%/!0\,&=%//!
M&\+RP?O!',03Q-`4#\3N%!;%$<42Q?(4#L4=5(@59\;RQMK&CQ7<QM@5E,B;
MR)+(FLB(R8;)/Q;ORE(6:U=>RU`66,RQ%E;,5,SY%IO-ELZDSB87*!>:SA+/
M@`#`&H$`:UU^`'\`-UT\70K1]UZ^`&9?U@"I8:YAK6'(8:5AL&&58N4<)6,T
M`9EDKQUT97!E;V5!:%1HU0'8`4!H.&C4`=@?V0%2:#IH5VA*T5EH$2%G(K1K
MP&M=`D,B7@)9`G5K6@*@`F!M1VT%`_!N!P/O;@X##`/L;H-O10.$;X]O9`-A
M<&4#:7#=)68#8G")`^P#\0-P)VHG\`/X`W0G7R>N=&$G<R>R=/(#]`,+=U@$
M$'<-=UH$6017!%L$4"A_>(%XI@3"!,$$/RD+>DY[[P2P*>I]17UH!34K+2MS
M!6X%=`4"*V8%*'U=?=Q^N04F+-1^#`9D@6B!(`9B@1T&88$<!F:!(08:!AD&
M\H!I@6>!?@::@YN#A8.<@YT&I(.>!IP&;BZ9@X:#D(.!A*Z$L2[4+LT&.(4+
M!PH'A2\[B8\'<C*5!Y`'D0=,B3HRN0='B36)EP>>!S.)BP>"B4").P@Z"#P(
M/0@Y"#X(:PAL"#:,#HVB"*$(GPBMC:J-%Y`M"6>0-@DK"7*0-PD*TF&0L)"M
M-B4)+PDL"6Z09)`R"8R09I"5-FN07Y!TD&60NY*^DM4)N9+4"=8)[Y+1"4,Y
MVI-&"H\YD)3IE8P*B@J("A&6#9;ME2&6W0J!E[&7`9DM"UZ98IDN"RP+*PLP
M"UN93@N6FI.:9`MA"Y*:=3PYTG`+I@ND"\2;QYO#FZ@+H@O(FZ<+[#RE"\J;
MJ0O%F\^;W)M\G`&=/0S3GMR>1`Q%#$8,U)Y7/LR>1PQ(#$(,UI[;GD$,U9[9
MGY0,W9_<G^"?S*#`#+@,P0S"#+L,O0R_#+D,MPS2H,<,TZ`,#0L->T`0#8VA
M70TA05H-6`U6#=BB5`T60;RBJ`VG#<\-T`V*I.A!BZ2-I-$-ZPU3I?L-:D)9
MI?T-^`WW#0`.5J57I?8-7T)SIANHWPXAJ!:H&*CB#N0.1*B"1":HXPXVJ5D/
M<0^.#XP/.JND#_2K5484$&*N````````````````````````````````````
M```T````-0```#8````W````.````#D````Z````.P```#P````]````/@``
M`#\```!`````00```$(```!#````1````$4```!&````1P```$@```!)````
M2@```$L```!,````30```%(```!9````7@```%\```!A````8P```&0```!K
M````<@```',```!U````=@```'D```!Z````>P```'P```"#````A@```(<`
M``"(````B0```(H```",````C@```)0```"5````EP```)D```";````G```
M`)T```">````_P`````"```!`@```@(```,"```$`@``!0(```8"```'`@``
M"`(```D"```*`@``"P(```P"```-`@``#@(```\"```0`@``$0(``!("```3
M`@``%`(``!4"```6`@``%P(``!@"```9`@``&@(``!L"```<`@``'0(``!X"
M```?`@``(`(``"$"```B`@``(P(``"0"```E`@``)@(``"<"```H`@``*0(`
M`"H"```K`@``+`(``"T"```N`@``+P(``#`"```Q`@``,@(``#,"```T`@``
M-0(``#8"```W`@``.`(``#D"```Z`@``.P(``#P"```]`@``/@(``#\"``!`
M`@``00(``$("``!#`@``1`(``$4"``!&`@``1P(``$@"``!)`@``2@(``$L"
M``!,`@``30(``$X"``!/`@``4`(``%$"``!2`@``4P(``%0"``!5`@``5@(`
M`%<"``!8`@``60(``%H"``!;`@``7`(``%T"``!>`@``7P(``&`"``!A`@``
M8@(``&,"``!D`@``90(``&8"``!G`@``:`(``&D"``!J`@``:P(``&P"``!M
M`@``;@(``&\"``!P`@``<0(``'("``!S`@``=`(``'4"``!V`@``=P(``'@"
M``!Y`@``>@(``'L"``!\`@``?0(``'X"``!_`@``@`(``($"``""`@``@P(`
M`(0"``"%`@``A@(``(<"``"(`@``B0(``(H"``"+`@``C`(``(T"``".`@``
MCP(``)`"``"1`@``D@(``),"``"4`@``E0(``)8"``"7`@``F`(``)D"``":
M`@``FP(``)P"``"=`@``G@(``)\"``"@`@``H0(``*("``"C`@``I`(``*4"
M``"F`@``^`(``/D"``#Z`@````````````````#1.\L[R3L,/``[ASL-/`\\
M'>*87M([$3Q^.]-%4E#^5ZE@0G0).]8[W3_</P)`<T!V0:=!J$$S0\Q##44L
M11M&6@$=1IE&/DTM6"]8F5ZS;K9T&W;O?^F#%#N4.^$[!D!*0$1`,4%Z0:U!
MKD&Q03A#-T-]1'Y$+44R12-&)D8ZXJ!&J%$_5+Q4Q%8[6!E;&%NS7*I>OE^L
M8"5E9F5K94-TM73L=79WO`@4@=Q0'((=@M"?$J'SI6G!N141R17)$,D3R:0[
MI3O0/+H\RSQ[0(9!NT&Z0<-!N4'`0=X`.4,[0T%#T4//0])#+D1N1(Q$B$0U
M14,!.D4[13A%.44N1BQ&R$:U1JU&L$:K1K-,J4R[4;E16E;-5BM7!5BL`ZH#
M45A+6.I:[5HV6V);5EM56V1;6%L''-I<V%RM7JM>P%_#7[-@MV"Z8,L=_@3'
M8+5@CF1S96QE=&6TXG)E<66"97!E/VRZ;KANMW0C@B&"*X(F@B*")8CDBQ6/
MY)\SH2JA,J$IH?NE6[1<M"BW;\%MP6O!;L$6R2([%CQ(/-@\`#U!`(`_Y#^T
M`.<_#$!30+=`Z$710>5!V$'60=I!V4'50>9!U$'3041#UD/70Q-$_3IP1))$
MVT3:1$%%0T4S1O9&U$;=1M!&!$?91MM&!4?31N%&@$UW38%-@DV#35SB85!@
M4-A1UE'7406!351(5-96SU;95MA6/5>S`U186UA<6+0#65A86%I855A66()8
M\%H<6VI;:5MQ6V=;;%MN6WE;BURX7.=<Z%SD7.9<Y5SP7(->MUZ[7KE>Q5Y3
M7\1?QE_+7\A@G^+)8-M@E&2598AEC67L:>YI\6DN;$EL7V[1;LMNA7,="$IT
M1W1+=+MTQ'1\"`)V@G>1=X]WDG>/?)%\M'R2?/1_JH`U@C>"/8(\@B^",(+X
M@^^#)H95"R:()XA!BL:*QXKKB^B+ZHL:CQF/)@TCE"24)9DUH32A!Z4=K>&R
MJ[9@OW?!?<&\%1[)&LD=R6L[+3Q,/"H]2@`5/2P]!CT(/0H]3@!60(1`R0#&
M0/5!"4+X0>A!^T'I0?9!MQJX&E)#MAJZ&E1#44,Y1#I$F$1.17L!-D<,1Q!'
M,D<11QA''$<:1QE'"T</1QU'(4<31QM'%4<@`M%,R$R-3;5-B0*5`OA0X%'A
M4;X"WE'^4=Q1`5+]40!2UU365-E495;25MQ6X5;>5D)72U?#`XY8D5B+6)!8
MB%B)6(18JEB-6X];?5M_6WM;@%M^6X-;@5N&6XI;O5R^7'<$]%SS7`)=]ESU
M7/)<!%T]7L9>B5_47]9?TE_Z8`9A#&$*80]A+V74!;=EOF6\9>)E!FKW:0=J
M]FDU=E]L96QD;&%L6FQ=;-?BUV[5;MYNX6[@;MEN3`?:;M]N]FX#;R`(DW.+
M<Y%SDG.*<XESCW-6=%ETRG3,=%L(T'3-=-9TRW2#=8)U!G8J=BQV*W8I=KUW
MLW>^=\!WM7>V=YU\GWP@@2T*'H$<@3*!'X$K@2&!)H$D@1V!)X%;@EF"@()5
M@E""6H)6@F."4H)8@F,*.8+Y@RB&&`N\AM:&!8<@AW0+,XA&BD**0XI'BLN*
M0HM%B_V+](OYB_J+7HX=CR@-6))5DE>56)79E=R5VY4GF86:AYJ*FHN=3YXP
MH"^@:*%)H=H/2*$_H4NA7*%&H4"A#:4;IAVF%Z:D$"*FI[`(L0:S?;^.%&._
M9+]_OVN_?+]HOV6_:K^8P9G!KL$KR2W),<DNR2_);3LQ/"T].3TX/5L`.CTU
M/6(]ZC_K/Q5`S$#(0,U`VT#+0!%")D)B0UY#84-!1#]$=41E=$E&ZT0:15=%
M:T>I1U1'8D>J1UA'<D=C1W-'BT>,1UQ'44<61V!'84=>1UU'9$=31U]'6T=N
M1U5'4D=H1]),UDS33+A-NTWK3>A-MDWJ3>=-Z4V14!!1#E$/40M2`U(K4@E2
M*%(L4B52)U(/4NE4[%13`R=6<U;B5N96=N)A5U%7$E@.6*U8KUBQ6--8E%N2
M6Y!;G5N36Y5;F%N76X`$BN('70M="%W97M5>UU_?7]T$WE_C7^)?W@1'82(%
M/6$X841E.F6X92IF`&;S9?)EZV7Z9>UE[&7_9?ME!A].9N]E]V40:A%J#&H+
M:MUK,&S;!GIL=VPH;B=N96X.;PMO06\3;P]O$F\P;Z!SHW.><Y=SH7.=<YMS
M8W3C=.1TYG3G=-UTA2'L=.5T\70[=CEV.G8\=CUV1W8_=D1V2'=)=V!WXW?I
M=_!WV@C;"/)W[7?L=^9W%GC7"+Q\OGS`?.!\`(`"@/Y_7H"S@+>`.H$Y@3Z!
M.($]@4^!;H)?@H&"@H)Q@GN">8)W@G.";X*7@GZ"_(,1A#*$,800A.R%ZX4L
MABV&VH8NARR'*H<SATN'&(A"B#N(/XA!B$.(/(A,BDJ*28I6BL^*1XM(BT:+
M&XP1C!2,'8P7C!Z,"XP<C!*,%HP-C!6,$XP8C!H,K(Y$CRR/18]FDFZ299)H
MDH22.)0[E#J4/Y3?E=V5WI7BE=8-+)DOF8^:D)J,FI.:)9V(G:>=]YZ[GSB@
M.:`WH!2A;J%[H=X/;*%_H7BA>J%OH>4/_J-(IDNF0:9)ICNF+:WCL!JQ#;$3
ML1&Q'+%R$K6SKQ(IMZ&W)+B[NJ&]@[^-OX>_A;^*OZ._B;^$OZ*_L<&PP:_!
MML')P<K!R,&TP5G'R<=!R4S)Q!5%R5K)N3N4/6X]HCUG/6,`HSUV/6P]9#VE
M/3`]ICUI/:0]D#]?0&!`VD#80-U`[`!90EM"6D(Y0C1"1$(S0CQ"6$)J0F]#
M<D-P0W%#;D/P0^M#241,1/5$($5J17)%2T9=1E!'^4?Z1_M'(TBW1R)(M4?$
M1[1'[T>8`<U'\$>X1\M'\4>Z1P-(^$>V1[Q'LT<A2/='PD>^1\E'O4?.1[E'
MQT?*1\Q')DCD3.!,\$SL321.&$XO3B5.*%`B4&I05SR44))0G%`B43!1'5$C
M4352,U(O4DU2,5);4EI2,E)<4EE275)I5&U4,EU8`PI5(%4?50U5Z%;L5G=7
M<%=Q5_A8UEC96-Y8U5CA6-,#XEC=6.!8#ED(6=Q8"ED,6;1;L5NV6[Q;'5TD
M71E=&UTB71I='%TA7>9>Y%[G7NI>X@2;XO!?]5_O7T)A;F$\89=AC&&!87%A
MSF&Z87IA?F%4!7)ANV$O!7-A@F&V!;IDN&1+94AE*V;T92QF0F9(9D1F168\
M9C=F,V9!9C)FAV8G:B-J+6H?:BQJ*&IU:W1KYVLR;#%LF6R6;)ALG6R2;)1L
ME6R7;+FA-0<1;SMO>6]";T-O70=X;ZQS*0BQ<[1SLW.O<ZISLG-H=/)T_G3X
M=/ET_W3U=/=T_70`=8AU;G9==F-V8'9A=S=X<7@C>")X'W@E>/U\$7TC??!\
M[WP.@`R`NH`?"E*!58%3@52!48%8@;""GX)R"J&"FH*^@J""-X0+"_&%\H4T
MAC>&-8:,7M^&3(=.AV2'8X<VAUB(:(A;B%^(68AEB&"(7HC5BM:*3HM2BS6,
M.8Q8C$&,5XPXC#V,,HQ$C$3C8XYBCKB.L(ZQCDV/8X]PCTN/3X].CU./1X^B
M#%2/4H]9CWZ/*Y$ND7^2?I*!DH.21Y14E$V43)1+E%>4995DE6&58I7PE?.5
M^97TE?65[Y7XE?R5]Y7]E1>6-)DVF3B9KYJNFJR:HIHHG<)IG)VSG9"=!I\$
MGPN?!9]`H$^@JZ&=H;BALJ'2H<^AHJ'L#Z6AJ:&GH="A`J3/I-"D%J49I76F
M<::1IG*FCJ9MIHBF<Z:[$(&F=J9[IG^FD*9XIDNM2*U;K5&M/:U`K4:M3:T[
MK4JM0:T^K4ZMK+#FL.FP*;$A$C.Q+K$>L1\2Q>,BL2>QY[(+LV:TK;:NMC@P
M*[<JMRRX+;B1$Y83C[F3N<:ZQ;H5O1.]L;VIO<XQJ+^KO[Z_K+^IOZ:_P;_,
MP='!T\'DP<O!X<'2P>/!S\'0P>7!#L+,Q\K'R\=<R6')7<E9R7?+A-%!._T[
M&CQC/+8]LCWI/><]UCTP/NP]W3WH/;`]M3WA/9@_F3^\`)-`Y4#8`&!"7D+T
M`'M#\4/S0W]%..)71EA&.4BG2#5(8$A12&)(0D@\2$-(JTBI2+1(>4AJ2#M(
MJD@S2#=()TBH2'!(+T@V2+5(,$@Z2#A(L4BL2"Y(=4BP2/=,`$WQ3/-,8$YA
M3C).+4Y*3BI.9U"B4*-0GE"D4$11,E&;4IA2F5*:4F928E)K4F*`9U([52-5
M*55^5O-6A0/U5H,#@%=^5WQ7?U=]5X%7)5DI61=98UEG6659*EEH62999%D;
M66)9:5G^6D1;0ENW6]);U%O76]Q;T5O56\U;V%N:7$)=-5U8731=/%T[73Y=
M/5U:74%=.%U%73-=)EZZ!/=>[U[P7NY>G5\&8!%@"&`"8`I@!V"188YAA6'H
M81=BU&%I!<1AU6%%!=AA@&'>84)BQV2_9(UFB6:09IIFR&:29J%FA&97:D=J
M=VHZ:E!J0FI#:J-J=VNR;.)LO6QT;H)ON&]L![ION6^[;X=OY.*#;[=O0SO.
M<[IS<W0)=0IU"W4'=05U#G67=7=V>W9Z=G1V>7:&>/5XI7B=>+YXEGCA>*1X
MH7CV>`0)C7B+>'AXF'@*>5U])WU??<"`P8!M@5Z!BH%B@62!.@K`@LJ"T8)Y
M"L>"SH()(\6"-H17A'>$]H7WA56&1(8^AD*&4H;AA@B':(=GAUT+-^-^B).(
M>8B!B'V(>XB4B(H+9HK9BN"*/N-?BU^,7HQHC"<,B(QJC&R,9HQGC(F,8(R%
MC"H^:(ZYCKJ.OHYOCX"/=(^!CWJ/G(]SCX*/?X^GCWF/>(]]CZB/?(]HD4Z1
MGI)&#4`-F)(_#862G)+%DIJ2:)1EE&>4891@E)T-RPU[E>$-&98.EC&6$I80
MEA66/Y8=EAZ639E(F4690IE)F4J91YE_#DR9S9K5FL2:RIK#FD8/*9VTG6V>
M9IYJGA6?TY_LGU6@&A#6H=BA4:+@H0.B!*+:H>JA`J+3H>2AY:$[I&:D+*4A
MI2:EU*75I=FEU:;KIL6FTQ`GI_"FN:88I^ZFT!"WIKNF[Z:XIM^FVJ;CILFF
M[*:DK(X1HZQ>K6&M8JUCK8ZM::UKK86MC:UDK6VM3+%)L4>Q2+%"L46Q6[%=
ML4:Q$[,:LPZS#[,;LQ*SP[.^L[VS>;1\M,,2MA*`M'6TF[0O+W2TP!*X$D%;
ME%\PMZ>WI;>DMSJX6[F?N:BYL[FAN:>YLKF=N:.YHKGONMFZV1/5NMVZVKKN
MNM>Z&KT9O1B]L[V_O;N]P+VYO;B]U;T1OQ"_P[_"O^F_S;_EO\J_Q[_HO_'!
M#,+OP>[!\\$-PO;!\,'L%/7"],+XPO["$<0BQ$+$7,=:QUW'T<?0QW7)>\F)
MRDW/B=&2T8S1B-%GTVC3(3[R/0D^^#WP/?,]]3W[/?<][ST+/J(_]4#S0/1`
M\D"806A"@$*%0HY"CT+T/89"I$*&0XE#AT.%0]P:B$/_169&S`'#2*(!Q$@[
M2>=(^$C[2+8!ODC&2,4!Q@'\2,!(,TG)2/Y(VDC,2+M(_4C?2,U(PDC(2#))
M+4G22#%)TT@N2<](_TP)3?Q,<DZJ3JM.ITY[3G9.J$ZL3H,"(1NJ4`-%K%"M
M4*M04%%84=U2^`*N4J)2JU+C4J]2X%+D4O8"IU*J4N)2X5+?4JU2Y5+14JQ2
MU5*C4I]2>51V5$-5/55'5415/U5;57]6FE><5YL#'EB(66I9=EER67!9?EEL
M66]9=5EW67A9BEEY6919`5L%7/%;[EOO6P1</QSZ6P=<]%OU6YQ<;5UI769=
M8EU&78T$95U=75Y=7UV.7@)?!E\$7P-?8E\G8"%@(&`D8"E@,6`C8")@W&%-
M8N5ATV'N8>9A5@4V8D!B/V,]8D1B6P5?8BEB26**8BIBAV),8C%B2&(K8CMB
M06+)831B4V(U8D=B.&+19-)D465595)E4V6/9O1F1V<-9QQG^V899_=F^6;U
M9NEF"F?N9@MG_68&9P)G%F<89_!FU&EF:FIJ=6IV:H!J;6J6!FEJ9VIH:EUJ
MI&O^:_UK[&SI;"%MZVSG;/)L(&UZ;BUP+G#*;R]PR&]^!\MOPV^$;])OQF^!
M!\]OU6_4;]UO*W"C<-MO+'`3<#4(T7/,<]5SR7//<])S>W1\="-U'74<=1YU
M(G4D=2!U&'4A=8AVBG:4=H]VCG:0=IL(IW9D=P`)&'D4>1UY!7G_>!MY&GD9
M>0-Y#GE'>01Y6GD'>2!Y:GUF?7I]97VO?<V`SX#1@,Z`7X%W@72!B(%U@8F!
M<H'&@NJ"X(('@^:"Y8+=@N."VH*NA'Z$?81_A-,*V83ZA?N%3894AE&&4(:8
MB)6(G8C!B)J(FXB?"YR(UXBDB):(H(@QBNF*;HN:C*6,E(RFC)F,BXR8C)&,
MC(RAC*.,QHQOCFV.:HYLCG&.;H[?CJR/JH^Q#+6/K8^RC[./JX^VC\>/QH]L
MD7"1LY)+#8R4@92#E'V4A920E**4C92/E'Z4BI1_E':4AY1XE("5@I6!E8.5
M6I8TEBR6*I9`EBV6,Y8KEDN6/R@\EEJ9=YE@F?J:^9K\FM8.]9KHF@F;YYKF
MFNF:,ITLG;V=O)UZGGZ>>9Z)#R.?,)\HG]2?SJ7QG_"?8*!EH*BA"J(;HA*B
M!Z)/H@ZB4J(6H@`04Z)4HH3C5J)MI'*D+Z4JI]P08Z>$IZ^G1:=PIU:G%J<]
MISBG;Z=WIRZG,:=,IU^G=:<YISJG+*<MIS^G+Z<PISZGT"J0$;*LMZV/K;$1
MEJV>K9>ME:VEK9BMYRNCK9JMK:VFK;:MF:VOK:RMJA&?K92MZ[!OL6VQ?K%L
ML6&Q8[%KL5ZQ/K%DL:VQ?1(@L]&SU;.NM*^TG[2HM,JTX;8YMSBW.[>MM[6W
MK[>QMZZWM+>PMTNX4;A,N&D38+B^N;FYM[FVN:$3O;FXN<&Y][KSNO2Z^[K]
MNO6ZYQ/ZNA2[[!/RNORZ`+O?$RN]*;TNO3,4U[W;O=F]V+WFO=:]T;WGO="]
MW+WMOQK`&<`6P.R_[[_NO_2_+\`PPAG"&,(1PA;"$L(0PA3"#,,-PQ#$*<0H
MQ&7'9L?>Q]_'X,?9Q]O'V,?CQ]?'ILFGR;_)J,F?R:')HLFMR:/)H,F#RX7+
M@LN$R^[,7<V2SE7/4\_\XU'/4L]0SYW0A]&7T9O1G=%ITQ'5[A=ZUS(81&W&
M.T`^+CYH/BT^-#XR/FD^,3YJ/CX^;SYU/O8_($`H0&=`^T#^0/Q`_4#_0/I`
MK$*O0K%"_`"_0KY"IT*J0I1#DT.90RH!^D-61")%D46210A&!D;62#=)2TG.
M2=!).4ED2<])1DEF259)0TE*25A)94E:25M)54E024Q)S4E124=)TP%326))
MS$G7`7])34D*30Q-#TV[3KE.ZTZN3L%.ZDZ^3K].NDZW3K-.Z4YN4*]0LU"R
M4&A1:5%J4=Y2ZU(14^U2Z5+W4O12ZE(24^A2$U..5(948U5E59E6PE>N5[!7
MK5>T6=%9K5GS`[U9MUFK6:]9P5FU60]<#EP<7!-<"EP>7!1<&ES+7(==DUV1
M!(1=A5V278!=*UYC7@I?P`1F7S1@,V!-8(EB5V(7'DIB8P4Y8C]BD&*/8K)B
MGV*58J%BG&*.8J!BKF*68LIBK&)P!:9BEV*38K8^UF3@9-AD5F5N9WYG=&=W
M9X!G>F=K9U]G=F>P9V-GDFJ":IUJE&J#:HMJA&I7:X1KM6L);.9L`@<E;5%M
M/F[:XH5N/W!"<#AP.G!.<$5P.7`W<$1PY^*D<#UP07#?<]YSRG/I<^)SX'.)
M=(=T,G4S=:QU^74-=KEV7GEJ>34)@7EI>:QY@'EU>7%Y=GEO>;9]`WZ_?0%^
MLGW$?=N`W(#8@'+1M8&H@8^!GH&.@=Z"XH(@@QV#&H,9@RN#&(,0@PZ#)(,?
M@Q.#-8.#A.`*UX0"A@.&7(9?AL>&FH>7AZ.']XC&B,R(UHC-B/F(V8C8B)H+
MT8C.B-6(HPO4B/B(>HIYBG^*\XKUBO:*](KWB@4,>8N<C-^,]8S_C-&,VHS/
MC,V,WHS8C*UUX(S^C)Z,=8YSCG*.V([0C]:/UX_*C\V/BI&)D8N1TY+:DLZ2
MTI)>#=22UY+5DON2S9+ZDM:2I@V;E)Z4G92DE)^4I92HE(^5C)65E6"6599<
MEF^6499AEJ>67I9BEE26;I92EEB6;99?EFR64)9=EHZ6<IEXF769=IE\F7Z9
M?9D5FQ2;'9L<FR.;5YO(G5T/R9W%G8>>BIZ4GCF?0)\^GSB?UI^X#W>@>*!]
MH-VA7J)WHM2B9J)?HG.B<J*7HEJBEJ)=HF6B<*)UHG2B7*)@HC00;:)!I#RE
M/J5O$$FEY*8,J!6H#JC4I\>G%*C;IU^H[:<)J,^G_Z<:J/6G[J?EIPVHWZ?L
MI]>G+*C-I^.G`*CKI_VG#Z@MJ%"H_J?$I^&G^:>[K+RLE!&3$;JLT*W6K<ZM
MX:W5K<^MTZT4+-2MM;"0L:&Q@;&%L6ZQB+&"L8:QC[&)L8"QA+'1+2FS*[,J
MLS"SXK/CL^&SU;3$M,FTX+3?M,NTW;3HM-2T'+6UMK:VY;9%MTFW0+=&MT2W
M2K?)M\2WPK=HN,LP@KAKN&>X;+AMN'&XDA/7N=*YV;FJ$[RYW;G6N:<3V+D@
MNQ:[&+L5NQF[)[M0NQV[++L<NRF[*[LDN^\3*+LYO?*]\+WM,>V][[WJO0&^
MO+]<P%O`6L`FP$/",\(ZPC?"-L(\PC3"2L([PC7"/<)`PC["%\(FPR3#$,,V
MPR7#(A5FQ'_'>L?[Q_W'_,?ZQ];)TLG(R<+)Q\G-R<')QLG,R:'*E<N4RY?+
MELN3RZ'+"<T(S6?-9<UBS6'-E\X!SQG/&,]<SV?/;,^U%OWC9L]ASV[/7<]:
MSZ+0J="ET*;0LM"CT*S1JM&OT:O1L='&T:W1N=%PTW47#->!UX/7?M=1V)G:
ME-J5VO[=&-\%/'(^@@"9/JT_!D'"0LM"U4+20LQ"UT+%0LI"[!JB0Z-#H4/H
M&J9#I$/_0P!$-0$&125%GT5_1NI)ZTG>21A*X$GH2=])\4GL21I*YDGA25U*
M=SL>2O`!@$H731U/]T[O3NY.[4[U3AY/O5#_DKY0;5%V44Q3&5-(4QY32E-)
M4R93E52%57Y5EU5]54)6GE8,5PM7#E?/5]A9X%GH6>E9XEGA6=I9XUG96?!9
MYUGD62-<,5PS7`Q<X*0F7"1<,EPG7"%<,%RB7,Q<EEV/XIA=G%V;76M>$E\4
M7UI@5&!18%Y@6&#P!%E@FF+R8JUB(&/Q8O!B\V+T8NEB_F(N8^ABYV+_8O5B
MY63G9.9DZ61896QGV6<^!LMG.0:^9[5GT6?"9[9GTV?"XMIIH@:N:J$&K&JI
M:KIJIVJS:KUJL6H.;!%L#VQ2;6IM5&U5;5-M5VW0XEMM6&U9;3L'N'"U<+]P
MP7"[<+<'PW"M<*APKG"J<-!PL7"\<+=PL'#Z</MPN7`'=/QS_W/R<_AS]'-7
M"'`(KG4/=A!VP=7'=L9VSG:G"-QVU7G3>2!ZXGGQ>=MYZGGK>>%Y_WG6>>!Y
MUWGE>50)&WX0?@]^#GXY?@I^%'X,?B.`6H#B@).!L(&K@;V!L8&-@:V!JH&L
M@;R!R8%'@V*#0(-$@S^#0X,]@V"#7X,Z@T*#7H-=@[R$X(3NA.N$#84)A@R&
M:89TAF>&,0LG)*V'_X@6B0B)"8D`B?R($XD4B0J)/M,IB1>).XG[B+\+#HGD
M"PB+&XT:C1F-`HU*#!>-!XT3C0F-"HT2C:J-.(U[CGR.>H[JCNN.[X[PC@F0
M`I`!D"N0!Y#/#"B0^X\JD/Z/!)`ID`J0C";"D9$FII$4#<9J!U<*D_V2!I,-
MDPF3"Y,`DP63/9/5E+^4NI3'E)B5FI4-#J26G):=EJ*6EI:5EJ66JI:MEIJ6
MHY:7EI"6KY:-E@$.J);NEJ.9F9FAF9R9I)G+F5:;2)M9FTJ;7)OQ#D^;39M=
MFSJ=XYWAG=Z=EYZ:GDB?2I],GTZ?3Y]+GTV?1Y]1G]J?^9_\G_N?_9_XG_J?
MBJ".H(B@B:"-H)"@?N,<HJNBI**HHJVBGZ*:HK"BI:+5HJ*BLJ*=HJ&B%:1"
MI'.DA*3=I%RE3*5V$$NE9Z>HJ'^HC:B+J/>HJ:CTJ)JHC*B5J'ZH=Z@*$0,1
M<:C]J(BHF:AMJ-2HD:A]J&.H=:CYJ(ZH=*C9J&:H^JCUJ&`KP:S)K`.N+*XT
MKA>N":X$K@:N&JX.KB>N!:X'KAFN%*X,KAVN(JXCKKNPO+"ZL*FQM;&LL:JQ
MK[&WL342-A(]LT6S2+,\LSZS[+/ML^FS"K4+M?BT!+7VM/FT4[=2MV"W8[?.
MM\VWT+?,MX>XC;B=N',38[GTN?&Y_[GUN?RY\KGVN;$3^KFO$RZ[1;M#NU&[
M3+MSNT>[2[M/N_031+M-NTZ[2KM!NU*[G[M4NUF[HKM+O4B]#;X?O@B^#KX=
MO@2^&+\;OV;`8L"#P&?`8L)/PD["9\)3PDW"3,)HPE'"W!18PEO"4,)JPCG#
M.,."Q(3$AL2`QX;')<@1R)D5#L@5R`_(&,@-R!/(%L@9R`C*]\G[R?S)M,J^
MRL'*ILNERZ++I,L2S0[->LUXS7W-?LV!S8/-@,V"S9O.F<Z<SIK.H<X:SQS/
MBL]YSW//=<]\SWC/8,^#SW#/MA:]%H?/A,][SW[/=,^YT+C0M]"UT,S1SM'1
MT00UR]&;-7[3>M-WTXS3X=,@U1[5PM4/U@#6]!<0U@W7#M>.UXW7BM>+UXS7
MC]=7V#485=A;V*S:I]J@VI[:JAB-W1\9D]Z4WI+>@3S6/L,^Y#[B/@D_OS[(
M/L<^M3^R/PQ!"T$*005!TT+F0NE"\$+J0N="L4.S0[1#L$-<1%U$7D3`1*]%
M4`&&1H-&A$9<2G!*C$I[2F9*>4IC2L5*:TIM2G)*:4IU2HE*QDJE2N<^:DJ7
M2EI/7$]93R1/)4\P3UA/,4]V4,%0A5%]4653AU-24U13BE-04X933U-H4YU4
MH%6Z5;U5N%6F5GL#WE?85]%7$UH)!`Y:&UHZ6@<$'%H26A9:&EI(3TM<-UPV
M7#A<.EQ)7#Q<2ERQ7<)=M5W$7;9='E\?7Z]?:V!O8))BY&(L8^]BA!Y/8U)C
M4&,Z8S=C1V-D8T!C/&-%8T%C\V2[!<%GM&=+!BIH(F@I:$T&/F@\:#!HQVK5
M:M9JTVK.:LAJ7&M?:V)KP@:]:[]K7&VV;1H'G6U_;1('E&V!;4=N1FX\!Y1N
M=7$:<2IQ,G$7<2-Q=''#!W9Q+G$E<2!Q<7$6<7!Q+'$O<1]Q9''`!PAT%'0*
M=`MT3W59=51U476V=>QV[7;J=NYY6GIS>F5Z87I5>FMZ9'I;>DQZ;WJ$>G!Z
M77Y7?F9^4WZ8?I=^*(#K@.J`Z(#L@.^`T8'*@9\BSX'-@<Z!<(-G@W.#;8-V
M@WF#:H.+@W*#<8-N@WJ#%H4YA3N%$(:6AGN&?(9]AKZ'7(DXB3F)+HDTB3*)
M6XDSB3R)Y0L.BP^+$(N'BUN-4XU?#%R-/XU9C4J-1(U,C4"-7XU>C4Z-5(U#
MC8>-@HZ%CC&01Y`ND"^02)`TD!@-GT`RDS:3,Y,QDT"309/=E-*4V92M#=^4
MVY38E-.4WI3@E-24UY3:E*>5_I;=ED"7XI8>#M:6WI;OEB<.ZY;JEN26T988
M#NR6^I;9EO.6X9;<EN66WY;4EB`.!9?6F=69T)G(F<29R9G-F=*9S)G*F:";
MDIOT#@(/BYNAFY6;B)N&FXV;A9N1FXF;HIOPG?.=])WOG0:>HIY>GV.?8)];
MGWN?6)]9GUV?!:`&H`*@`Z`$H**@IZ"FH*2@K*"IH.>B`:/?HMFBXZ(/HQJD
M1:1(I'NDA:2&I/ZD_Z1DI7&E<J5AI6*E;*5@I5VE8Z5GI0&I*JDPJ0:I?:DB
MJ;FI"JD0J8^H@*D3J2ZI&*D7J1JI%*E'J6.I.*DD$7^I(:DWJ3&I&ZFEJ6RJ
MTZR(KFZN7*YTKE2N@ZYP+&6N8*YPKF^N;:YRKFRN=JYUKEFNQZ[!L/FPX['G
ML=:QS[':L>FQTK%5LT^S3;-1LU:S^;/XLP:T`[0)M/>S];-'M46U/K5&M2FU
M-+4_M42U-;5:M2JU,[4WM4.U.;4PM5VU,K4GM;VVNK:\MO&V\+9AMURW6+==
MM]JWV;?=M]RWWK=]$Z"XHK@/NA.Z$KH1NA2Z&;H.NA>Z(;H@NA:Z>+LW,8>[
M>;N`NW>[@;M&NWJ[G+N#NX2[K;N=NYZ[5;TVOBN^)[Y&OBR^1;XSOBV^-+XB
MOF04'[^SP(S`C\"OP*W`CL"LP+#`L<"NP)G`Z\%TPG7"CL)MPG#"C,)/PU'#
M6,-,PT[#%<2^Q-O$L\2NQ(?'BL>(QXO'C,=$R"W(*L@QR"S(1<@PR"G(1LCT
MR13*$,H/RA+*"\H,R@K*$\H.RMG*T,H#-,'+O\N]R[S+NLN[R]'+OLO0R[G+
M&LT<S1O-D<V6S9_-G,V:S9W-K<ZESJ[.`\\FSR#/(\\DSR'/*,\ESQ[/E,^3
MSX_/FL^MS\(6RM#%T+O1X='JT>31[='FT>#1Z-'ET1K3E-.6TY[3E=.ATX[3
MF].2TY?3F=.3TS+5+]4NU3/5'-8>UA'6(-8?UAG6%M:LU[G7L]>FUZ+7J=>G
MUVS8;=AIV(#89MAEV''8:]B]VL':T]JVVJP8N=K4VK?:V]JXVL#:O-K5VK_:
MP]K)VEC=D-V5W9?="=X(W@;>!=X0WI?>E=[NWA_?&N1+5HX\Z#[P/O0^!C_M
M/IL`Z3X`/[@_;4`$0P%#`T,"0_8:)@%B1+I%$T;>2M=*Y$K.2N-*W4HZ2]M*
MUDK@2M1*RTKA2LE*WTH\2_Q*STIY3W9/>$^'49Q3L5/!4YI3DE.O#<)3EE/`
M4Y%3E5.B5,-5P%7"58I&L%865T9:2EH^6D5:0EH5!%M:1%H$6R)[55Q77%%<
M3EQ:7,9=PUV<!,5=S%UQ7B9?LE]Z8(1@>V!T8XQC46-(8XUCDF.88Y-CL&-.
M8Y9CEV.<8\IC,VB#:(1HFFB,:,P@F6C@:>1J^&KM:O-J]&KU:OUJ&6R>;<1M
MGVV;;I]NFFZJ<9UQDG&B<:]QZW&@<:%QE'&8<8]QAW&$<:EQ?'$8=%]U8G5A
M=<!U%7;\=OEVR'K)>MYZRGKB>F0);@D$>\QZW7KD>M-ZQWK&>E\)-WO8?NY^
MLGZC?K-^[7[X?C&`6X!F@&F`EH";@/>`\X#T@/6`XH'G@>6!Z8'F@>.!=(-_
M@X^#D(.7@Z.#CH.8@XR#0H5$A6F%0X5HA?8*C8:(AHN&B8;,AQ^(@(E>B6>)
M:(EEB4HE=(EIB6&)8HELB9.)AHF=BIN*&XL6BQF+%(L8BQ6+F8N8BUV-B8UZ
MC7V-2XUS#'B-?XUWC7Z->8VKC7R-=(UUC:>-C8Y.D&:089!-D$^0W0Q4D'R0
MVI'>D=B1W9'?D6:38I-?DV238Y-@DXB3:I-GDX>3/Y-LDVZ3K9/QE/24]I3U
ME/B4^Y3LE.^4[92Y)_>4^93]E+&5-I<;ES*70I=-EQ^7(9<<ES&7+I='ESN7
M09<8ESF7'9<GER.7URCNF>B9Y9GOF>29[)GPF=>;V)O4F\J;TIO+F].;YIOB
MFTF=2)W_G0F>L)ZOGGR?>)]ZGW*?>9]^GPR@"Z#-H+Z@O*"_H,"@O:`XHPBC
M!:,[HQ"C#*,-HP2C.J,3HS>C.:,?I$ND[J1UI7BE?*5TI7:EZJ7KI?NH&:FG
MJ8RIW*F8J;ZIGJD/JI^IW:F3J;NIMJF0J:&IO:G>J3JI(JJ7J92IPZF.J:BI
MF:FMJ9NIHJDAJJRI#JHQJN&LWJS?K-RLW:SLK.>L::ZXKJ&NJ*ZZKL*NIJZD
MKJ.NJZZ\KK>NOZZMKK&NRJ[$KKFNR+#&L,>P"K(-LONQ`[("LORQ^;'XL6ZS
M8[-BLV&S:[.($F^S9K-LLPZT%;06M!"T%[01M&ZU;+6'M8.U8[7<M<"V][;Z
MMG"W:K=HMVFWA+?LM^>W[K>ZN+*XM;C+N`M#T+AMN6RYNQ-%ND:Z-+HLNC6Z
M1+JZ$W:ZL;NJNZ&[LKL2%*:[M;NTN[B[K[NPNZ.[8KUDO5:^4;Y/OFB^3+Y0
MOF$42+Y*OB&_X\"YP-[`M\#AP+;`M<#?P.$4E\*:PIO"F,*2PI/"U\)SPFO#
M=,-XPVW#&,3IQ/7$ZL0NQ>?$_L3EQ#;%\,3FQ"S%B<>5QY/'3<A*R$_(4,A+
MR"K**\HORB[*?,KMRN+*X,O<R]K+ULOTR]G+U<LBS2'-),TES2;-(\VJS:_-
ML,VKS:_.M\ZUSK+.L\XKS]C/PL^OS[S/N,^^S[?/M,^_S[//L<^[S[W/UL_=
MS]C0T]#5T./0XM#9T-[0W]#:T-30\]'BT0W2`=(%TAK2`](?TA;2^M'\T0K2
MGS6\T\K3MM/'T[_3B1>YTXP7L-.XT[W3D=.[T[[3/M4]U3C6/=8YUC/6,]>[
MU\;7Q=?'U\O7J-?(U[[7P=>]UX+8GMB!V(38C3:6V([8B-B'V.#:#=O?VN3:
MXMK=VNS:WMKGVNK:X]I<W7<Y7=V<W1W>G=Z>WIO>M=ZYWK;>\][RWO3>)M\G
MWR7?!N`+X#K@/.`*/PL_OS_]/QA!W\R0CIY!_$(00P]##4.Y0[=#ND,*1$%+
MBTM&2U-+XDL_2WQ*2TM.2XI+1TN33\ZXC$^O3\E/QE#(4)%1SU/44\Y3W574
M54E:8UI=6AH$9UJ[6F!:@%I?7&!<VEW27=U=CF"(8&Q@GF/)8Z1CF`798])C
MVF/=8\YC_&,496!EUVC+:,UHU6CG:0!K"FL/:P)K`6L=;,IMRVW-;4]NG&Z`
M<0UR`G+Q!P=R]W'X<?UQ)'+[<3ER.G(B=*DA:G5M=71U#G??>BM[XWHF>RI[
M(WLU>TI[_7X`?QY__WZ>@/J`\8&5@ZB#IH-NA8.%;86/AFH+WX?5A^"'TX?8
MAXR)2R64B9:)A8F/B:F)CHF0B;B)PXF[B:6*HHJB):.*M8NLBZB+K8VXC;2-
MKHVVC840P8V_C9*.`(\!CW60<I!XD'"0?I!]D'^0[Y%MDXZ3CY.*DXV3E9.+
MDXR3L).3D_R4%94.E1B5$94-E;N5LY4Y#J&7FI>$EZ"7AI>=EZJ7>)>-EXJ7
MII=ZEY>7B)>.EST.1`YVEX&7A9=UEZB7CY>1EZ*7G)>)EW^7EI=YEY^7IY=&
M#H>7FY>EEXN7R9?_F0.:`)H"F@2:!9KFF1^:%)P.#PR<#YP9G`N<$YS5FQ`/
M')Q0G4Z=$IZYGH6?B)^0GQ.@T*#1H-*@UZ#6H.6@1J-KHT6C/Z,^HSX0:J-H
MHTRC(Z0BI)>DD:2UE9BDG*2)I800BZ6*I8VECJ6(I4ZJ1*HWJG6J5*IVJC2J
M:ZHRJE>J4JI%JDD1L:E+JD>J,ZI`JCRJ0ZI/JE6J0:JRJL"J-*_YKAFO#:_Z
MKAZO'Z\.KT"O"*_?$1.O3*_P$<RPR[`DLB6R/;(@LB>R)K(=LAZR,K)LLEFR
MBA)ZLWFS&[0NM".T(+0?M+:UN;6AM:.UJ+6OM9JUF;6BM9VU`A.KM<FV_K8`
MM_RV![=UMW*W<[=TM_JW_+?XM_:W^[?-N-&XS[ATN7*Y<[E4NE&ZP!-3NDFZ
M3+I*ND^Z5KH`O-6[U[O_N]F[X[O3NQ44V+O4N]Z[<;UTOHB^?[YKOH>^>;YX
MOHF^@+YVOBF_*+\OO^7`!,$#P?#`Z,#JP/'``<$"P:G"J\*WPK;"XA2@PX[#
MAL.'PX7#B\.(PY##&L0TQ#?%+\4PQ3G%-,4SQ87%A,4ZQ9_':<ALR&K(9\AK
MR#_*0,H+R]++^,L!S/K+%LSVXRS-+<TOS2[-P<WUS<3-WLW,S=+-PLW-S<_-
MW<W(S;K.OLZ_SB[/,,_GS^[/Z,_FS^+/Y,_[S_S/ZL_MT/;0\]#TT/'0]]#U
MT.K0Z]``TBS2$M(]TC/231<PTD#2,=)7TDH7-=(RTBW2-M(XTF+27]**TM;3
MV-/=T^33X]--U=?52M9,UE#62]9.UD_6.=?2U\W7T]?AU\[7U=?=U]37S]?+
MV*;8PMBEV*G8HMBDV+#8S-BOV+_8)-L:VQ3;.ML@VQO;(=LEVQ[;/]M`VQC;
M+-L5VRW;']LIVTO;L]VEW:?=J]VFW:K=(MXCWJ'>H]Z@WKW>NM[ZWOC>_-[V
MWC3?0]]C&=3?#>!#X$'@/>!`X#[@/^!&X),9U.`U/S8_,C\Z/\@_-D`>01U!
M'T$<0QU#($,.`<!#FDN32]U+"@*C2ZE+G$N;2PT"ETNQ3\I/LT_-3^I3[E/O
M4]]54%:[5HA:B5J,6H5:7EJ46I5::UQJ7&E<XUWQ73=?,U^18(]@EV#48]YC
MTV/@8T-D"V3_8P1D!V3Y:/IH^VCX:!)K$&L?;-]MXVU2;JEN97*'<D)R4G),
M<I]Q`7)(<D]R?G)-<EAR1W)><DER3G)=<EIRAG)1<BETIG2G='!U;W73==)U
M*'<;=QIW''<A=S)[9GM]>W-[?WME>X![87MU>VY[9WMQ>VQ[8WMB>X-[LGN!
M>V][:WN">XI[*7\P?S%_EX``@?^`MH.U@\.#C848AIR&FH:9AK>)Q(G&B<>)
MO(G`B<6)S8G!B;Z)IXJXBB.+=`SHC=Z-XXWOC=R-Y(WAC>6-E8Z4CI..CHZ8
MD)R0F9"@D)Z0!)+3D[23NY.WD[B3O9.VD[F3M9,BE2&5PY6\E?^7Y9?WE]*7
M`)C;E_"7XI?-EU8.X9?RE]R7S)?6E_.7^I?VE^R7ZI?CE]"76@Z5E]67])?+
ME]J7R)??E_67SY?'E]>7))JC#AR:(9H>FAB:&YJH#D:<2YQ(G$><9YQ4G!6>
M(I[%GBF>QYZ-GQN@(*#BH.>@Z*#AH'*C>Z-THW&C>:-UHY"C=Z-]HT^D4*2C
MI**D]*24I9JEFZ6GI9>EE:62I9REEJ6VJKBJL*H8J\6JM:K"J@:K&:NYJA6K
MUJJLJCP1QJJSJL.JRJK/JKVJSJH4J[JJ&JO!JKNJFQ&:$0&M_*Q:KU2O8:]<
MKU6O2J]+KU&O::]KK_$L9J]8KUVO9Z]6KXBO9*].KU>R6K)1LDJR2[)>$D>R
M;[)JLFNR1K)MLE2R;K),LGBSAK."LZ<2X;7EM=NUWK77M0.W?+=^MP6X![CF
MN.&X^[CEN.>XW[C_N':Y8[IFNF6Z7KIDNFNZ7[IGNFBZ"+P)O!>\%;P;O`N\
M*+P.O!B\4[Q%O`V\"KP3O$J\>;VAOHV^HKZ0OFX4,;\POQ_!&<$,P1[!'<$'
MP6;"Q<*ZPKW"PL+#PK_"#16APZ+#J,.CPZK#K\.YPS?$C\5#%8[%A\6*Q9+%
ME\6?Q07&J<>GQXK(@LB%R(O(B<B!R(#(A\B&R$W*',L?RR','<PBS/[+&\PZ
MS#?,%\PXS";,&,PTS37-,LUS%N'-_<WCS>C-^<W_S?[-=!;@S0#.<!;LS>3-
M[\WZS<K.,<\RSS3/0<\`T`;0"-`%T`/0"]`"T`K0\-`3T0K1#]$1T0C1"]$2
MT0W16])CTF'2:-):TD[33=-0T_S3$M3UTQ[4\-/ST_+3`=3OT^[3%M3VT_O3
M'-3;%UW58-5FU5_58=5;U6+55]5IUFO68=9WUE_68]9BUF76[]?BUP#8Z-?R
MU^?7*1CEU]78T-C:V-/841C9V,_8UMC8V/78SMC7V/38S=@!V;HV4MM5VUK;
M3=M4VU/;7MMGVV7;3MO;&$_;8=MNVU';6]MCW;?=MMW#W;O=M=TNWC#>,]XQ
MWJ3>P=Z[WK[>`-__WD#?91D_WT3?9!EG&=O?#^`1X$[@3>!+X$S@E>`[/T4_
M1#\^/SP_/S_,/\X_(D$C09]!Q4/$0^E+F4L1`N9+YTOW2])/,P/]4PQ4"U3M
M5R$$(@2;6@I;;UQU7/)=^%T^7R1D#F069!AD$&0Q9$1DI@4I9"]D2V0V9*,%
M-&D`:2MI(&LA:QYK'6OU;?)M]FV0<IURG'*2<I1RT7*3<K=REW*P<I]RR7(M
M="QT=W4L=\![N7M3?T"``H+[@:$*BX6NA:N%H8;-W>J'W8G<B=F)JXJLBJV*
MLHHLBRN+PHL`C@V.!H[_C0..`8X0C@^.!8Z8CI>.EHZ9CJR0JY`2DMB3WY/6
MDRV5,I4_F"^8)I@ZF#F87PX[F#68*I@AF#B8-Y@TF%P.(I@VF$2819H[FC::
M0IIZG(:<BYQ_G(&<*I[5GI^?G9\FH/2@]:`5HXZCCZ,FI*>DKZ2MI:REJZ6J
MI2^K(:LCJZ.K2:LZJTBK+:LEJRFK,JLTJR2K+*M+JSNK(*LHJYBO]1&7KP0M
MG:^HK]6P=[)XLG*R<[("LSNT_K4+MO^U![81$PP3,+;-ML^V$+<*MX.W%;@.
MN`RX`KG^N`6Y%;D(N7^Z=[I\NH*Z?KIXNGVZ>;J!NDN\8[QDO%:\5+Q.O!"\
M3[Q7O%Z\4;QJO&F\K;ZDOJR^J;ZNODP_4,$UP3+!V,+1PL_"OL+5P\'#QL/#
MP\+#P,/%P\?#O\/$P]3#D,72Q4X5U,6OQZ['LL>MQYS(H,BVR#W*5LJ"RBC+
M*\L\S#[,/\Q"S#W,0<P[S$G,0\PYS3C-(LX(S@S.!LX3S@3.(,X=S@7."L[6
MSM?.-L\WSR/0(M`@T!K0'=`<T2#1=]%_THO2?=*9TH32B=*%TH/2AM*>TE/3
M%]24%QG4(-0?U"/4&-0AU"G4)-0FU%[5;]5NU735<M5SU7W6?M:%UG_6A-9$
MU_77^-<#V/;7*-EC&#G9^]@.V?W8']EA&`/9V#80V5H8#=DGV4'9<MMXVX#;
MXQB%VWO;?#A]VY';B-NJVXW;B=N5VYO;C-N>VWS;AMN$VVC=Q=W$W<G=QMU"
MWD7>0=Y$WJ;>PMY"WTG?2-]*WTS?2]\7X!C@%>!2X%3@4^":X)O@W.#DX)'A
MKQFZX5$_6S_//P5N$TP53!1,(TP3`A%,$DR``O!/FU$25!94%U2U5/17L5IY
M7/]=_%W[73]?1%^=8#)D3&0K9%ID'V4!:2UI)VE9:5II36E8:2-K)6LK:_]M
MKF[+<LIRT'+.<LQRV'+&<M)RSW+(<A=VL!G$>T#-Z7OR>_Q[ZGOK>_U[>']W
M?W-_GG]Y?Z*``X$$@@6"SH._A?:)]XDQBS"+R8O'BQR.*(X:CAZ.&XX?CK^0
MNY"\D,"0&I+OD^R3Z9/PD_Z3-)5JF)68;)ARF&>88)AKF%Z8;YAFF$8I8IA=
MF%R89>-0FI^<(P^>G*:<-9XXGC:>.I[<GGRCJZ-)$*BCIZ,KI"RD**0K1*FD
MJJ2KI/BDL:7PI>^EJ*N+JY2KGJN/JXBK?JN!JS"KFZN"JY"KA:M_JZFKWJL-
MK?H1SZ_+K]BOW:_3K]"OU:_6K]:PDK*5LLO@C;*;LIVRC[*>LJ:REK.2LQ:V
M*K8IMBRV%;<2MQ&W$[>(MXNWBK>'MQ>X%K@:N!FY%[F1NI2ZB[R0O(^\AKR#
MO(Z\A[RHO(6\IKR"O*>\N;ZWOK2^MKZSOL:^/,%`P3C!D<*FPMK"VL/8P]G#
MV\/7PQ;&$L8?QED5%,8:QA#&L\>NR,'(L,BOR+'(K<BRR,3(/,L_RV',9LP\
MS3O-+,Y^%BK./LXOSC+.)\XISD#.W\[>SCS/.\\^SR'01M`\T#;0.-`UT#'1
M-M$MT3/1+]$NT371K-*ITJ;2J!=,U$/40=1/U$+44=2I%T#44-1%U$K42]2#
MU8+5@=7@U9C6G]:;UIK6F=:6UJ[6GM8)V`W83ME*V4W90-D^V4C90MEBV479
M4=G&V]#;P-NWV\+;O-O%V]S;V]O2V\?;MMO)V\S;T=O-V]K;NMO3V\[;]MN]
MV]W;R-L-W#7<<=UNW6_=UMU,WD_>5-Y3WLG>R-X#WU09!-]6&5??4M]3WVT9
M5M]<WU7?9.!=X%[@HN"CX(X9Y^#FX)CAK.&OX:[A63^I0"I#QT-!3#=,-4PS
M3#E,,DS_3P%0^$\;5!E4OU:\6KY:O5I]7$9?1U^D8"%E8F6&:7(&+VLQ:Q0(
M^'+U<OER\G+Z<O-R%'/]<@]S#G,!<S=T-70T=#%T>G5[=3=W*WS[>Q9\$WR3
M"1%\#WP;?#A\I'\)@@>""X+3@]&#V(,=AJF&T(85K0**!8H!B@"*+HXPCB^.
M,8[2D-.0`I1`E4*5.Y7.E9B8CYB4F)&8;PZZF)"8AIB:F(R8DYB'F(B8EYB-
MF)R8O9@\FEF:L`[1G+N<OIQ=G>*>!:&ZHRX!]*.RI/FDMZ6VI8FK^:O9J^BK
MU*O;J^*KWZO1J^FKZJL3K1&M^J_XK_2O^Z\.L`*P#["0LJVRJ;)(M%JV3[9.
MME6V5+9*MM6V&+>-MQVX&;@FN2BY*[E]N:"ZFKJ;NK6\K;RRO)2]R;Y.P4_!
M1,%2P>G#.<1I%7XSQ\C3R,;(P\BT%=+(9LI_S(#,A,R%S./,319!S43-0\U.
MSD_.@Q9)SDK.2\Y#SN#.Y<[ASN;.XLX,ST#/2=!*T%303-!5T%;0.]$]T:32
MJ-+#TK_2R-+"TLK2S-+)TK[2S=+'TL727=.P%VS4:]1PU&W4;]2)U(34C=6*
MU8[5D=6UUK'6K]:YUK?6L-8,&!?7&!A/UQG8$-@8V!'8'-@2V';9<=D@-WK9
M?]DB-W/9J]D>-W?9=-E^V9O9A-E\V2G<*]P.W`#<"]S^V_K;%]S_VPS<#]SU
M&`+<`=S\VTG<!MP2W!/<>-U;WF+>7]Y=WJO>U=[4WM/>!]]LWW#?;M]HWVW?
M=]]JW\[?[-]IX&C@IN"IX*K@`.$-X?C@_.`*X??@`>&VX;OAM^&YX<KA:3\E
M05E,!U`)4")4!U8$5@]N^%?'6M%:?EP(7DI?F.*Y7XAID6F$:7-IB6F%:3-K
M$VX=<Q]S'',@<QIS&W,Y=*]TY74\=S=\.GR[?PX*$((-@J^&$8?8"PV*#(H+
MBM2+/8X^CCN.0XY`CD:.$8_=D-^0ZI!*D@:4P9BYF,:8N)B[F,B8Q9B_F,>8
MQ)AEFF>:UYS;G-2<UISHG@JAO:6^I1JL#:P/K!NL$*P1K!.L&*T@L!^P([`=
ML#>P);`DL"JP)[`SL"BP-+"ZLG`NG;-,M%RV:K9=MF6V8[9>MAFWE[<_N3.Y
M,KFANJ6ZI+JBNL&\+!3'O,2\QKS%O-2\RKQ3P?'#(<1N%;?&DL;4R$3*F,R;
MS)',E<R:S)+,4\Y7SH867,Y=SF3.ZL[MSD+/0\]DT&'08-!]T=32U=+9TH?4
MF=2,U(K4C]2S%XO4@M2;U.L7R-;$ULS6Q];#UL;6R];*ULG6S=93UR'8*=@=
MV"38*-A#-['9LMFUV=;9K]G*V;C9$N01Y$7<1]PTW&[<0MPQW"[<5MPXW#?<
M2]PMW#/<-MS@.$C<W-U"&6;>;=YCWF3>01EGWMG>"]]^WXO?)N`LX"G@;^!K
MX&W@;N`<X1'A$.$DX1+A%>$7X:P9;S^K0"Y#R4.61H5,H%$K5`U>-FO].B\'
M+@>Q;DIS-W,\<SAS.G,^<TES30A["(!U?W7C=3]W4GQ.?$I\2WS5?]B%((:S
MAK&&L(87BMF+28X3C^V0ZY#ND`J4"Y1*E=68UYC>F-R8[IAPFK(.V9S7GLNC
MQZ/\I#NL.:Q+K$.L0*Q&K$VP0[!'L$NP5;!2L%^V(A-\MGNVJ+JINMZ\U[S=
MO-:\V+R;O>"^Z+[FOOC#^\.[QEDRN,9P%<''P,>DS*O,3<UESF?.:LYFSFG.
M<]"`T&_0<=#DTN;2Y]*@U*34HM6GU:35WM;;UEC77-<OV"[8W=GDV=C9Y]G:
MV779E1AYW(#<?]Q\W'7<>]R"W``9B=QTW'W<>MR&W*C<<MP"&8O<D=RSW('<
M@MWAW>/=XMUVWG3><MYUW@[?#=^4WY+?D]^1WX_?E=_0W_??=N"OX)\9)N$E
MX2WAH.'#X=<_S$5Y3'I,%5#;6H5<<&1[9*5IGVD7;K)N.7-`<TYS/G3H=>=U
M9GQA?-I_%(+?@QB*.8LZBS"2,I(.E$R5Z)CQF.N8[)ATFG.:\9Q"GCZ>09XL
MH-*CNZ18K%>L5JQ:K'T18;!HL&6P7[!DL%ZP6[!GL,.RHK-3M'VV(+>NNJ^Z
ML+KGO.:\Z;SQONN^ZK[IOF/!`L3^P][&PL?FR%W*K<QUSG+.=\[V%E'1Z-+M
MTN[2N=2AU+;4KM7HUA(8'M<QV#+8D1@.VA+:"=H%VI`8`]H?V@W:#-H$V@K:
MPMR_W,G<LMS!W*_<M-RPW+;<M]R[W+'<\-UXWGK>>=[DWN;>G]^=WYC?F=_Y
MWS#@@N"!X+/@?^`ZX3[A2.&&3#94$U8B5]U:IV!]9'D&'&YE<V!S9W-."!IV
MXX4TDAB44I7\F'F:>)IVFOJ<^)PMH-:CO:2_I+ZD1*QPK&*L;JQNL'RP=+!X
ML'"P>;!QL,RRI[.FLY.V(;><MYV]]+[SOO#(N,RVS+W,<\Z"SH?05M%9T?;2
MR=3%U,?4RM3"U,34\M;PUCO8.M@FVBC:--HMVM?<TMS6W-S<T]S1W(;='AGO
MW>[=Z-ZLWZG?JM^KW_O?,^"(X+;@M^#0X,_@3^%9X4SA&%;@6FES<WQR?.B%
M^Y`<E`F9"ID(F7V:?YIGG7JL>ZS1LLOCG;:=M_R\^[S]O/6^]KX/QQW'Q\S!
MS+_,5,U_SO7.BM",T%S19=//U-#4N-7ZUF;70-I!VG(W]]SSW._<]-SMW/+<
M\=SYW+3?_-^\X%[A6^%?X5WAS^'.X3I4X5H57A1>>'QY?.9_N(8BBOZ0VZ,&
MI<BEB:R&L*VSF;;8MB.W([BUNOF^!\0>Q_O(<LISRH?.2<]=T?C2`]=.VDW:
M4-I5V@G=!]T,W0/=!MT+W0K=B=V[W__?-N"+X&;A:>%GX<+ATN'B6B@$B&1;
M;G9S?7RF@%J.%YG<HX^LE+"5L+:Z!+WNPHK.^<X'UQ_7*M=%V%S:6]IAVEW:
M&-T?W8/>%M\4W[_?P-]SX<#A%U")9!Z4'Y14E1B9!9V5K)BPF[!9M`B]`;_.
MS/K.OM5'V&K::=IHVF?:)=THW<3?-^"-X(S@D1D@XR*9@IK9LCC'^\[AU'+7
M2-ALVG#:,=TPW7GA(YGXHW37<]HTW8?>LM["X'WAY5J,SG?:==HXW3K=@^&!
MX8!\F:R'$4K/2M@\W<CA!)&OLXGA^MUAT3_=DZS)W]ZRD<Z.X8WAF*S%I*7A
M```````````````T````-0```#8````W````.````#D````Z````.P```#P`
M```]````/@```#\```!`````00```$(```!#````1````$4```!&````1P``
M`$@```!)````2@```$L```!1````4P```%4```!:````6P```%T```!>````
M80```&4```!H````;@```'(```!S````>````'H```!_````@````($```""
M````B````(D```"*````C0```(\```"2````EP```/\``````@```0(```("
M```#`@``!`(```4"```&`@``!P(```@"```)`@``"@(```L"```,`@``#0(`
M``X"```/`@``$0(``!("```3`@``%`(``!4"```6`@``%P(``!@"```9`@``
M&@(``!L"```<`@``'0(``!X"```?`@``(`(``"$"```B`@``(P(``"0"```E
M`@``)@(``"<"```H`@``*0(``"H"```K`@``+`(``"T"```N`@``+P(``#`"
M```Q`@``,@(``#,"```T`@``-0(``#8"```X`@``.0(``#H"```[`@``/`(`
M`#T"```^`@``/P(``$$"``!"`@``0P(``$0"``!%`@``1@(``$<"``!(`@``
M20(``$H"``!+`@``3`(``$T"``!.`@``3P(``%`"``!1`@``4@(``%,"``!4
M`@``50(``%8"``!7`@``6`(``%D"``!:`@``6P(``%X"``!?`@``8`(``&("
M``!C`@``9`(``&4"``!F`@``9P(``&@"``!I`@``:@(``&L"``!L`@``;0(`
M`&X"``!Q`@``<@(``',"``!U`@``=@(``'<"``!X`@``>0(``'H"``![`@``
M?`(``'T"``!^`@``?P(``(`"``""`@``@P(``(0"``"%`@``A@(``(<"``"(
M`@``B0(``(P"``"-`@``C@(``(\"``"0`@``D0(``)("``"3`@``E`(``)4"
M``"6`@``F`(``)H"``";`@``G`(``)T"``"?`@``H`(``*("``"C`@``I`(`
M`*4"``#X`@``^0(``/H"```````````````````````"R6(S!0"(,]`SSS,>
M-!\T(#0./"P\83,$,P4S`S,$``')?3.-,Z,TI#3;-P`X'LFC.3([/P'4/=4]
M(TXL57I5`S@',P@SCS.<,]4S$C03-!0T(32H-*8T=C<!.#TX%,D^."DY=SEX
M.:8YJ3FL.30[!#A[/!`]+SG7/1P^'SX:/C;)'CZ>/IH^H$.A0])'TT>Y2QU-
M54W_3N=1*@014A-2$E*O4[%3D,DM57M5G56:5:<$GU6@59Q5O5;Z!*I7;&*1
M8G1M:G4IR@6&:X]JC^`S$C,``'\SH#.9,Y4SGC/?,]XSKS2M-+`TWS=#.$$X
M2#AU.!K),CE[.7DYLSG;`*<^LCFP.;0Y*<G-.\X[*\D0/(`\TSPP/9@S+STQ
M/=H]V3TG/B@^(3XE/J8^HCZA/J0^.<FJ/J4^HSYD,S]$1$0;1U-'A$>&1]5'
M8,D^2T!+RDW)329.`$\Q3SQ/,$\S3S)/.$\T4E-25%*T4[)3+U6E5:=5I%6H
M5:E5HE6C5:95@5:`5JU7)%QE7&A<:5P\8SMC765$:H)Q\71K=1MWZWBZ>]-[
M$WTBB?27#ZL0JP<X"\$*P1DS&C,8,V8S@C.H,^4SYS/D,Q4T(S0D-$,TPS2\
M-+LT.`"W-+DTSS0-R7HW>S?A-^`W"3A-.!;)2SAY.+$X-CDU.3<Y.#E_.8`Y
M@3E3EGXYS3F_.;XYPCFX.<$Y,"`Q/"\\;SR"/#H!ASR&/(T\E#S7/-0\V#P6
M/10]+CTV/3<][E'@/>4]WSTK/BD^+3XO/K<^R3[!/LH^LCZL/JX^LD.H0[!#
MIT-1R5)$2D161U5'7T=>1XA'7<G=1^)'X4??1^!'KTBQ2+I(14M#2[U+R$ML
MR;Y+OTMTR5E-*4XL3B].+4XN3@1/`D\!3T!/2D\_3T]/04].3^M1[%&L,UM2
M8U):4EE2W%/;4]E3X%/=4R`SL%6Q5;)5ME515E)64%:$5LD$@U;#5[A7N5>R
M5Y!;)EPI7&Y<0&,^8T%C7F6[9;QEN67OR8!I3PA%:KIJO6I6;55M=6UW;8%M
M^LF#;8MMA&V&<8-QBW%M=19V*'?J>-1[`WP5?3U_/G\6A$S*!H9-AR*/<X]M
MCVZ/L9%.."V3S0_YE5*6`)C\E_J7DA#WE_B7D,K$RB>F$:NN,U"M3ZU-K7&O
MXLIRKQBU1#TA,V<SKS.P,RDS%S0B-`/))3,H-/\TV33;--XT\C3^-/0TW31%
M``3)`37<-'TW@3=^-W\WY3</.+4`"CBV``LX43A2.%`XN#@].3XY/#F'.=<Y
MVSG/.>`Y3#M".]0[$3P4/!4\$CPS/#4\-P%Q/#`!D3R3/)4\W#Q"/4`]IH/F
M/8]$,CXWR3$^]3[-/MX^U3[:/NX^[#[//LX^/<G,/O,^P4/$0\9#M$/#0[A#
MNT.W0[Q#OT/'0[Y#8$1=1'9$;$1U1%M$<41S1&%$6D1B1')$7T181!Y'6$>+
M1XI']$?P1])(S4C.2+Q(T$A&2T=+/@--`U$#SDO/2\Q+RTMRR6!-7TU=3=1-
M.DXX3CQ.-DX(3WY/7D]N3U-/<$]73UU/8T]Z3WE/DT^!R1U2:%)S4G129E)O
M4G52>E)P4FU295**4^U3Z5/C4^]3<P3J4S%5D<DX52"8-54Z58%5@%6X5<%5
MNE6(5L]6RE;'5L56R%;05LE6NU>V5[U7G<FT5\%7T5?25\Q7U%?+5\Y7U5?8
M5Y5;DUN96Y9;O@6)7)1<D5R/7(1<EUR&7(5<C%SR8.U@[V#98D9C1V-+8U!C
M2F-.8TQC2&-C96%E8F5@9<-EQ67!9=!EW,F":1X(AFF$:4QJ2&JX:K]JP6K&
M:L5JQVK`:L-J[6L#;")L(6R?;9!MGFW("*!ME&V5;:%MPPC'")IQD''R=/-T
M;G6K=:EU&G88=AMV8'=,=T)W,W<_=SYW.'=#=T9W-G?N>/5X]'A6"QM\0`$K
M?2E]*GTN?3^`YH"G@ZB#&(0(AE"'4X=6BE6*;X]_C[.1.I,XDS>3-I-4.(#*
MW97\E?J5,Y8$F`>8")@&F`F8D<J3RAZ=TLH+K4.M4JU8K5ZM:*^-KX*O>Z]8
ML[T5`,DL,RXS"T@M,VDSLC.V,ZDS[3,9-$\T%C4#-0XU!#4'-1`U)S4H-0TU
M*34/-2(U$36%-X0W@S>*-X8W$#A8.%HX##K$.,4X1SE).4HY2SF[4XTYBSD'
M.@8Z(,GO.?`Y[3GY.0(ZYSGT.?<Y\3E3.U4[&@':.]D[+`$X/)D\HCR</)H\
MFSSE/.,\X3S@/.(\Y#S],N@\+\D3/58]2SU*/4T]3#U)`>H]Z3WK/>P].CX\
M/CD^.SX4/PX_-3\*/S\_.#]\`4X_%S\_R1X_MD/.0\I#RT/,0\E#M$2L1(A$
MAD2,1)-$BD2D1(=$I42F1(5$HT2.1!]'8T>-1_I'^T<)2/Y'_T<"2`1(_4<%
M2/E(]TC;2-I(44M02U=+XDO82]I+W$L@31]-:4W=34!.04Y#3@U/#$^'3ZE/
MDD^%3[\#C$^B3X]/BD^Z`XU/\5$W4HM2AU*"4HY3O%/X4_I3ZU/Y4_Q3!50;
M51U5'E62R3Q5/E6$5<A5R5735<=5TE555I;)C%:*5M56TU;8!-A6T%?N5_%7
M^U?35^Q7S5<56"98#E@G6"I8`%@$6"A8"%@46)M;L@6A6YU;H%N>6Z);G%LR
M7#1<DUR67)!<M%RU7+;)MES"7+7)NER27/M@!6'S8/Y@_6!==?I@0V*58I1B
MQ`9O8W-C7&-;8V9C=&-C8V=C8&-B8W%C<F->8R-E)F5D9=;)\F4!9MUEW&7;
M9?-E_6789?AE^V6#:8QICFE):E1J4FI.:EAJ46I5:E-J5VI0:D]J36K2:M-J
MR6K4:N]K^,FQ,P5L!&PN;"UL16U;;5IM66V=;8YMO&W=;;IM_<G8;<MMV6W:
M;<1MN&V_;=MMP6W\R<5M&<JQ<:]Q&,KW=/9T^'10=5%U<75P=;!UKW6N=:UU
M)78L=B)V,W8T=BL*.G=`=VAW80ID=UQW5W=3=T]W47=4=V9WW2.R"@UY"'DK
MROIXZGHJ>[M[U7O7>Z1/\#.U,P9\*'PB?"%\5E8C?,U#,'TT?<E_RG_(?SW*
M1(#S@$'*^(#\@/:`^X#W@`"!`H%`RDW*)(0-ABD-8H<PB2N)*HF2#2V)VHHH
MC(:-=X]\CU"03I#RD+*1SI'/D>61!V8UDC&2$Y,KDRR319-@DT&36)-'DUN3
M4)."RE^32I-6DT.31)-1D_V5-)8UEE26598,EPN7"I?YES68))@3F!R8:9@E
MF"&8E<J6RIC*()VIGZB?WI\)H`J@"Z#CH0>BLJ*SHEVC6*B&J(>HN:FXJ0RM
M1*UFK8"M=:UMK7ZM9ZV!K7>MJ*^BKZ6OFZ]7LP^U,K4LM3.UY[AN,[<S]C/R
M,_,S%S@P-%0T4S12-3TU/#4T-3,U5#4O-5@`534_-3<U5C5A-5@U!LD[-3(U
M+C4^-3LSC#>--Q,X%C@2.%LXBCC7.,XX4#E1.4\YCCF/.?(Y(<DH.AHZ)3H=
M.A0Z(#H?.ALZ%SH5.APZ$SHER6`['`%F.^,[WCO@.^$[&CP;/!@\'#P9/$(\
M0#P^/$0\=#Q#/"W)\CP;/1D]'CTPR5X]9CU=/5H]7SU@/5L]7#U9/?`]\3U#
M/D`^0CY!/C\^5S]I/V\_JS]Q/Y,_5C^0/VT_;#]P/V8_9S_70[5#VT/80]5#
MU$.Z1+=$OD2Y1#<"X$3=1-Y$&'G81+U$VT0=1R5'(4D,22E)+4D;20Y)'TD$
M21Q)!4D&22!)#4DJ22-)$4E<2V9+6TM/2UY+74OQ2^I+]$OK2_!+^DO[2RA-
M+$UK32I-:DUO3=M-X$W1?^--Y4WG34U.54Y43E-.4DY.3F!.P%,/3Q%/$T_&
M3[-/QT_23[A/K$^N3\]/Q4][R<Q/JT_)3[E/^U'X4?=1^5$@4CM2.5*>4II2
MJE*K4J]2EE*I4J92D5)#!*Y2GU*L4J!2DE.14[]3%U0*5`Q42E5&5315155#
M5415D\F'5895BE7:5=A5M`08.#0TUE745516659:5E=6X`3=5NE6X%8%6!)8
M$U@'6!98(U@"6*')2E@V6$!85EA#6*#)2UA&6#Y825BG6[9;IENH6ZQ;J5NK
M6SA<-UPY7$%</ES`7+M<OUR]7/Y<'EWN7/Q<M\GY7`9=Y%SI7.5<`UW]7$E=
MOF`*82:&&&$-80]A#F$@87%BF6+B8M]BWF)X8WECY`9\8WUCA&.+8XICTLF)
M8RQE*65L900A"68(9@QF#6809B8(GVF8::)IFFG5:N)J\&KJ:NMJ[6KH:N!J
MA6N&:_!K1E!%;#AL/FQ";$!L1VU<;5YMM&W";11NY6T5;A%N_\GN;>=M]6WT
M;>AM`6[O;?%M`,K;<;]QVG''<=UQ&LKK<>%QP7&]<0=U_70!=0IU`W5R=71U
M=76R=;%UM'5,=D)V0'9)=CQV379*=CMV87=T=R;*?W=Z=XAW?'=O"G!W#WDH
M>1-Y*GGM>N]Z+GO!>]U[1SXM?"M\-7PO?#%\-'PURC!\.GTY?3=]2WU4?4U]
M47U'?2=_4']-?TY_5'_2?\Y_2X!)@`6!#X$9@4/*!H$,@2F!!($(@26!'`P#
M@2>!$($*@4+*79BJ@ZN#J8-!A#J$/(0KA$F$%88`#1:&4\HQADIM/(=\AVV'
M:H=CAVN'>X=DAWJ':8=OAS>)-8D\B3:)/8D^B>&*X(HMC"N,C8V2C;8.CHUK
MRI&-EHU[CWB/@8^6CZ./E8^7CU204I#UD`"1^Y#TD/:0Z)'JD3Z3/9,[DX"3
MY`^(DX&3@I/.DX.3=Y-YDW.3;9-PDXV3=9.,DVJ3D9.)DXZ3W$3_E5F6QY82
MEQ27$Y?+ET*8K1`]F/\J0)A$F&*80Y@_F$68/)B7RD:81YBSRIZ<G9PLG2F=
M+YTNG3"=X9_BGPZ@&:`2H+2BVJ4FIUFH6JB(J,"INJF@J]W*HJN&K>POG:V(
MK8^MCJV;K<&OPZ_$KY:OQZ_&K[^OPQ0/LE6U0K5&M4NU0[53M4BU2;5*M4ZU
MWGN1.4N[@+V!O8.]BC6"O4)5(CQP,W$SO#,83[XSNC/X,S<T-33\/58T631>
M-&TUD362-6@U9C5S-6<`EC6+-8PUEC?N-QPX&C@9.!LX73A>.!C)W#CB.%(Y
MDCDP.E(Z0CI!.D4Z-SI`.C\Z/3HX.CHZ23IK.W@[>3LFR6P[Z3OF.^4[ZCOG
M.^@['SQ+/$H\4SQV/*,\I#SV//,\^3SW//P\'3UM/7$];#UN/7`];SUG/6@]
M^CWY/4X^WAE-/D\^2CY,/I8!0LGN/[(_P#_!/_0_R#_%/\8_K3_B0^I#XT/A
M0_=$`4421?9$\40?1>Y$4LGS1!5%%D471?A$&47R1/1$]403109%)D<D1UI'
MR&"71Y5'FD<?2/L]*4@@2&+)8\E,23!).$D]25%)3TE*231)-DDP&VI+:$L<
M3`Y,'DQ9`PE,"$P33`%,#TP43`9,!TRR''/)=@-Y3>I-[4WI3>Y-:$YD3F=.
M<DYB3G1.>4X93Q=/%4\63^9/I(_N3](#WT_D3]I/ZD_M3^-/Z4_]45<Y(5+&
M4KA2RU*%R;U2M5*[4K]2OE*R4L%2PE*94\93+%0M5"54'E0?5"-44%5.54U5
M4E7I5>Q5Z%585EQ66U:/5G)J]E8`5_Q6^%;J5OY6]U;]5G!88EA$6"`%35A,
M6#]89E@U6"D%-%B-6(18.`6&6(E8AUB#6'58>5BO6+!8MUN[6[E;1EQ'7$5<
MZESV7&A=.5VYR3U=.UU-73!=2ET^74!=3%U'73A=4ETZ75-=Q&#!8!QA'6$J
M81YA+V$B82YA)6&)!K`&2F)+8G9BOP;H8N]BZ6+%!NIBS,GJ!IMCGF.38Z=C
MG&.@8YICJV.^8ZEC+65N941F/68Z9FAF/&9J9N#).&9E9CEF;68V9N/)/F9^
M9C=FF6FI::UIIVFH:69J:6IM:F=J:VIJ:NYJ`6L#:_1J^VHW"/9J_&KT:PAL
M"FP);&UL8FQ!;%YL7&SS;29NY`@Y;@3*;&XK;BYN.VY>;OMN)VXD;FEN,&X%
MRF)N.&XU;BIN+&YH;C%N+VXM;CIN-FX#RB%N/&X@;F1N/F[H"/=Q$G+Q<?5Q
M(G+R<=]Q%7(6<GIU=G6^=2`*O74)=@AV5W:C=[]WN'>O=YQWI7=R=W5WG7>9
M=[EW3GDY>3MY-7D\>55Y\'KS>O1Z.WL\>SI[-GL'?.L_57Q0?$]\4GQ6?+TS
M,GQC?6M]9GU7?5U]A@MM?6%]:7U:?5Q]8GTJ?RE_6']:?]=_VW_<?]U_V']4
M@%N`7(!3@$^`5H!0@%J`:X`V@5.!.H$\@3Z!28%`@4;*1\ID@V6#M8.V@[*#
M2(1*A'*$:81:A$R$+(8PADN&289"AD2&2H9/AI*'5\J7AX"'@H>&AU.)7HE2
MB5N)3HEMBFZ*^HKVBON*,XP]C#>,/HPUC)J-JXVFC;"-F8V@C9Z-J(VAC:J-
MK8V[C9R-I8VS,R>/C8^.CX^/DH]6#Y&/K8]7D%B07I!=D%R06Y!G#PJ1`Y$.
MD;B139(_DD>22Y)*DCV2."A!DDR2@2ABDVF389/1#ZJ3II.LD[V3NY.DD[J3
MFI/K#Z&3P9/@E0J6`Y8&ECF6.I8VEEN67Y9>EF>6899BEEV6RI;,ELZ6&)<=
MEQ^7()<7EQ67'Y@GF":8$%"+F*Z8BIB9RI*8B9B'F+80CYB$F(.8C)B3F(V8
MF)A]F'Z8TIB`F)F8K)Q0G56=0IT_G3R=HQ%,G4F=5YU8G4^=7)U'G;?*JY\0
M$J^?K9_HG^>?,*`FH"^@**`KH!V@+:`@H"J@+*`UH"&@(Z`DH#:@-Z#IH;JB
MN*+,RFVC:J-HHVFC:Z-AH]REVZ4MIBRFHJ8KIS*GU\J4J)*HD*C)J<2IP:G#
MJ<VI%*NGJZ^KJJL-K52M6ZUAK:ZMLZW`K<2MOZW+K:VMIZVDK;VMKZVRK:6M
MYZ_@K\ZOWJ_5K]^OV:_RL".R0+(;%3ZRAQ7/LU0^6[58M6*U7[5GM6.U7K5@
MM86VAK:'MNBXYKAQO86]`LN&O1"^^#R_,V$^_C/\,SDT831@-.(UZC7C-;0U
MKC6^-;@UJ#6J-:DULS75-:TUN36[-;$UPC4(R>LUNC72-=0U\3<=.!+)8CB,
M..8XYSA:.5@Y63F6.9<Y83IG.G$Z93I].GXZ?3N$.WP[?CM_.X`[[SOT.QX\
M3CS[//H\_3PQR3+)>3U\/7T]A#U[/7@]5P%>/EH^7#Y9/E4^8SY6/E\^8#Y;
M/DI`94"S0"Q`=T`]0%)`84`J0#Y`-$`I0+)`K4!`0%-`1,D_0$%`<D#V0_5#
M]$/R0_E#)T54155%+D54R5/)+$4X13E%,45/17-%,$4K15%%+$=;1UQ':$=L
M1VM':4>?1SA(/$@Z2#5(G0(Y2#9(.TA@26%)8TED291)DTE>26A):DEE26;)
MD$E?27))9<D\3"=,)$PF3"5,7P,H3#9,,4TP331-@4U]38)-@$UY`],U\DUF
M3HQ.>TZ#3I@#CDYZ3I).D4Z"3AM/'$\G4"%0W`,K'4-0WP,84'M0&E!+4$I0
M35!/4!E0-5`34%)0%%`>4"Q0(%`B4!)0'U``4B-20%)#4N12VU+J4MU2S%+9
M4NA2]E+C4M-2VE+64N=2.E0_5$!42%195#=41%2,R8O)550Y5%15555655=5
M6%5958U5\E7X5?55]E7\5?Y5\57]55Y6EE:75IQ6FU:55IK)&E<)5P17#E<<
M5QA7#5<05PQ7`U=[6*98=UB(6'18VEAV6'A8BEB/6'U8D%CM6-E8T%@:6==8
MXECA6,58X%C*6"59S%BSR<9;P5M-7$M=9%V579E=O,F47:)=KEV>7:==AEW]
M!:1=D5V37;O)B%W-8,I@/V%`849A06%%85AA.V%(84YB4F)/8GMB>F*@8I]B
M^V+W8KACN6.[8[=C]`:Z8^\&VF.U8[]CO&/`8]/)V<EU97EE=F4U9D!FP&:!
M9JUFKV:L9H]FJ&:J9JEFB&9_9H!FO&:N:;MIO6DQ"'AJ=&H,:Q%K"&L&:Q!K
MCVN0:XUKCFN6:Y5K"VP,;'QL<VQU;'9L?6QX;'%L2VU.;3-N,FX#"9%NYV[I
M;J)NE&Z';J-NW6Y[;H-N@6[?;GQNY&[B;I-N?6Z_;IMNCFZ?;@D)C&Y_;IQN
MA&Y";N9N47)*<F1R)7(O<BYR*W(H<C)R+7(Q<CER+')A<A%U$'42=5-U575[
M=8%U?75\=<)UQ74BRL1U(\IK=FAV/@I<=EUV:G8DRG9\=G=W"L1WRW?(=]1W
MU7?)=]=W>PIX>5IY6WE<>59Y6'EQ>=260'LSRC][0WM!>^)[X'OC>V9\<WQL
M?'%\:GQM?&Y\:WR,?7=].LI_?8E]>GV%?7A]BGV&?2Q_9W];?^5_X7]A@&F`
M:H!E@6V!8X&&@5R!8H%(RGF!:8%P@7:!78&'@6Z!<8%\@7.!6X%K@;^#P8.]
M@\F#O(/"@\"#DH2IA(^$=H1[A'6$I(1DACV'KX<Z#5C*G8>9A[&'8XEBB62)
M:8F@#76*<XIQBG2*#(L6B^4-$8L?BQJ+#8L;BQ.+3HQ5C%",?0[2C=.-T8WQ
MC=R-R(W,C="-SXW?C2N/+H\MCYV/GH^?CZF/H(^8CZ&/JX^OCVZ07Y!:D&T/
M99!HD'*0%Y$6D1B1&9$:D2*1&Y$<D;Z1[I%:DE"26))4DE>25I(5DYN3DY.2
MDW*3F).9D]^3^`_5DU@IU)/SD_23YY/AD^:3ZY/LD]LU4!`-E@R6+TUHEF66
M:Y9IEM&6TY8GERB7:!!G$"27UY?*F,>8GLK8F.&8QICXF,.8])@7F>J8RYB&
MF,28V9@9F<*8XIC/$-Z8[9B<RLT0'9G=F-N8Z)CIF+^8X)C1F-R8SI@>F<R8
M\ICSF)_*HLJCRJ'*JYRJG*><J9R(G76=8)ULG7.=JQ%NG72==IUHG7>=AIWJ
MGU&@4*!8H$V@3Z!.H%R@4J!$H$J@2Z#JH1"B$:+-HK^BQ*+0HLZBP*+"HL^B
MR:*[HI>CDJ-OHWZCFJ/!$H:C<Z,D+7>CCZ-PHX&C@J.9HWVC?Z-[HX>CLJ4O
MIC2F+J8RID<3JJ97$ZFF.*<VIS>G1Z<SISFG-:=$IZ6HIJB>J..IWZG3J?&I
MY*G@J=:IPR[FJ=BIWJG;J=RI&ZL?JQVK'*L>JR"K(:M.%+:KO*O&J\>KNJN^
MJ[VKM:NTJP^M8JWKK=FMY*W7K=BMUJW.K=VMYZW2K<6MR:W;K9*OBJ^+KXFO
M"+`#L`:P!;#UKPNP^Z_\L`&Q`K'ZL`BQ][``L?^P!K'VL/NP"K$ELD.R1+)D
MLV*S7K-;L]:S<C/",W>U@K5\M7VUAK6!M82U=K6#M7^U?K6(MHVVB[:1MH^V
M?+=YMWJWZKA,NYF\T36+O8V]BKV.O1&^5E05RW0SPS/$,QLT7S1J-&DT:S0,
M-O8U[34I-OXU\347-O\U[C7]-1PV_#4`-B`V=P#Y-6<V"#:>-_,W)3@G.!\X
M93AC.)0XESCQ.%\Y8CGR&&`Y(LF,.H(ZD#J+.HTZ@3J=.HX[CSN2.R,\4CPN
MR0`]`3T"/1\]C#V)/8L]B#V-/8\]A9``/@4^`3YH/FX^9SYU/K8:1<G70$;)
M2#/40-A`1\E(R;I`2<G;0+]`-4&\0-E`Q`'=0`!!U4`P0;U`W$#]0_Y#!T07
M=6]%:45P16=%J46519!%;$6717%%4@)T16U%CD4O1QO&J4=.2%_)6DA(2%5(
M3$A)2$](2DC62:!)J4EGR9U)U$FD2:A)IDGF27U+=TMZ2T%,24Q93$5,2$Q`
M3(Y-E4V03?=-^$WV3?M-GDZ=3IE.=\FC3JE.F$Z@3I9.E$Z53I].H4XA3QU/
M'T]M4'S)FE"24'I0?5"A4)U0F5!K4&Y0?<E%4H3)^U+K4O)2^5*&R?A2[5(!
M4_=2!E.;4\I3:P3#'FM4;%1T5&=46U1@5'948U1A5"A56U5>56!5755<5?15
M`%8(5@=6`58%5F168U:>5J!6H5:?5B97+5<H5QU7[%CC6.M8%EG(6!N3Z5CD
M6"19T5A!!=U8PEC+6,=8YUA0!>I82UFER6!9?5D^6:3)4EE.63Q9,EDP62-9
MREO+6\E;R%O-6YA=H%V?79Q=HUV77;[)\5T)7@->ZEU%7NU=!5X:7A5>`5[L
M70Y>%UY"7A)>$%[O7?]=`%X,7@]>!%X(7A1>0UZ]R1M>$5X37L]@SF!O86YA
M>F%P861A7F%L8<G)6V%A865A?V*`8GQBIV*F8J%BP`:H8J-BHF*M8J5B`6/_
M8OQB`&,U8^YC[V/V8^ACZF/C8Q]D_`;D8_IC\6/[8]3)/64\97D`>&5W90L0
MT6;'9M]FT&;@9M9FV&869PYGV68/9Q%GS6:)9LYF%&?:9A)GTV;"9N%FZ6;J
M9MYF%6?9:=9IS6G0:=-I\,F":H5J?VI]:H%J@VJ$:J"M*&L/:Q=K&FLE:_?)
MFVN9:Y)LC&R5;(ULHVR3;)%LVVZ9;IIN"&],;PUO`6].;P)O36\A;_QN"<J*
M;@C*E6X1;Q)O1F\<;TEO#&\>"1-O%F_];@]O'V\P<FYR:W*;<GMR8W*7<FUR
MG'*8<F]R9W)I<A5U8W6&=8IUAW6(=85UB77*=<=URW7,=<EU#7:#=H1V>':"
M=G-V>7:,=M!WSW?2=]EWS'?K=_UW['?H=_AW^G<GRH4*X7?[=^=X+LJE>9%Y
MIGE\>9)YHGF@>?QZ_GI7>U-[6'OG>XY\.,J#?(M\A'R7"Z)]MWVI?:5]GWVJ
M?9=]H7V>?:M]F7VC?3!_,G\O?W!_;']O?^A_[G_J?VV`=H!P@'&`;(#K@;6!
MEH&0@8V!2<JB@;"!DH&@@9.!PX&.@;:!G8&5@;.!I(%P@]2#DPS/@W`TE(1A
M)<"$M(3!A+(,O82OA'>&>(9KAFV&;H9RAF^&<8:K8HR&/X>VA[>'!B:[A[B'
MG#JYAP$FBXEZB82)B(F1B7F)CHF`B8*)?(FD#82*?XKR#3N+<8L]BS"+\0T^
MBSB+7HQDC($.78QMC$^,8HQ?C.R-\HWTC?>-]HT'CNV-ZHWPC?B-\XW<#G+*
M,8\OC[:/KH^JC[^/S(_'CX.9@)![D'^0?9"#D'C*1I$MD261)I$LD3>1,9$S
MD3*1)Y$JD2Z1+Y'`D7&289)BDF:2&)/%D\.3Q)/"DZZ3$)0(E!^4.I0[E#:4
M#)0&E"J45Y10E""4A<HLE"&4"Y09E#64&)0/E!.4590YE!J4#!`7E.25Z96+
M=1"6$I8_EFZ6&'6,RM:6U9;7E@(^;1`QES"7.I>%F&N82)E+F3>9>YELF869
M99DVF8:9-)EHF5J96)ERF6J9TY@\F3.9.YE-F4^9?)FPF5N959EDF6N94YGF
M$%>97IEMF369:9E9F6:94)E1F5R979J'F7B929E.F?&8<YF(F<^8I,JQG+.<
MG)VDG9"=N)V@G9V=J)VIG;G*L9V3G9N=HIVAG;"=IYVSGTDKM)_QG^V?[)]H
MH'6@:J!BH&>@8*!WH%^@>:`CHB&B'**9+!^B'J+6HM.BV:+7HM2BW*+8HJ.C
MT1*^HZFCH:.@HZNCHJ.ZH\*CG*.[HZJCK*.EH\&C+!/BI3:F/:8ZIF%62*8\
MIK>FK*:SIK:FLJ9N$UVG2:=.IT^G3:=<IUVHNZC.J+^HNJC#J.43!JKXJ?ZI
M$ZKVJ>83-*LMJRJK-:LLJ]2KVJO3J]*KSJO/JY\4_:T+KOZM^*WWK1>N^JWY
MK0"N]:WQK0.N!:X<KJROFJ^MKZ"O&[`EL"2P)K`GL"BP*K`:L"ZP%;`5L12Q
M%[$8L0^Q$[$+L2*Q>D4FLA\P4;)-LDZR2K)+LDRR4+)BLD^R4K)HLVFSY;/P
ML^&SXK/RRJ6UJ;6DM:^UK+6NM:JUE;:9MI.VG;:8MIRVE[8-%HFWA[?7N.VX
M\;CPN`6Y`[D$N5^Y5[N<O*&\FKR/O9.]GKVCO9B]F;V5O6Z^:K[TO_>_><&/
MPY'#"\0"R(0S!#2`-"\V/S8[-F(V1#8S-E\V*S8)R3DV-C9(-C4V;#98-CHV
MJ#?T-RDXFC@`.;LZO3JW.K(Z^`"H.JLZICJ\.I<[ECOX.Q,943PS`;4\M#RV
M/#P!MSP%/2,]E3V8/4\!E#V3/0<^<SYQ/G(^>#Y?06I!9T%K06E!CD%)08!!
MW`%$08]!14%,R4]!8T$V04A!7$&306%!8$%.05Y!/T&D0>`::$$+1!%$#40.
M1,)%5\FP1<-%R$5E1==%O46X1;9%QT6\1;%%KT5;R35',$==1W8^;T>P1U[)
MM$=<2%U("$KN20M*\DG]2?%)$$IHR11*BTN,2X5+>DQL3&!,9TQF3&I,7TQM
M3&A,9$PZ33M-.4T"3@1.`TZT3K-.NTZL3K9.L4ZO3K5.ODZR3B1/ME"Y4*Q0
ML%#74+M0_E#+4'_)]0.S4+Y0S5"\4+I0QU`64QM3%U,54Y]3CLF"5(-4CE1J
M5(E4E%2&5)!48E6050Q6#U;#!*56IU:F5J16-5<X5S970U='5S=70UFB65%9
M<EEM62]95%EN6559-UE/65!9.1^>6:C)LUFG67$%^5F16:?)MEG=69E9WUO5
M6_5W*%Y`7G%>F%Z57F5>>%Y_7F!>?%Z67FI>>5YS7G)>>UYP7M5@UV"/88EA
MGF&'8:!AC6&(87]AC&&385EBL+RQ8O2!KV*R8@AC"F,V8S=CS\D!!S9D*61*
M9"9D*&0D9"ID2&1$981EC&7$9MQFAV=39W]G,6=19TMG4F>`9Z5G@6=#9S1G
M-F<R9TAG26<\9TUG2F?FR8IG1F<^9X-G4&>T9_!IY&GC:>5IYFGG:>%I[VGH
M:=UI`VJ(:B9K%FL[:R]K.6LT:_3)-6LQ:SAK@3ZJ:Z-KI&N@:Z%KJ6NE:Z]L
ML6RK;*YLL&RS;*QLJ6RR;*ALM&S";$]M9FT>;Q5O$&]_;WYO8&_,;[)O8F^-
M;XYO=V]\;X]O76]M;V-OKV^0;WUO>F\&;PO*:&^T;WAOL6_7(@S*00GH<NER
MP'+7">IRMW*Z<K5R'<JT<KQRQG*X<KURPG)-<_!RQW+!<L-R\7+L<N()''4@
M=5AU975D=8QUC779=>!U$':4=I)VEG:5=K]VH'9%"O1W]G?<=STD%G@5>!QX
M#W@L>!1X)7@7>!)X'GB`>:AYKWG6>>)YM'FS>;!YLGFA>6![9GMA>TY[77MC
M>^9[[WOL>YA\IWR4?)5\D7R=?)E\FWR<?!U]''W0?>!]RWW;?=I]PGW3?>5]
M?7][?_]_\@OY?W>`?(!X@'N`>H#2@<N!R8'.@>2!RH'0@:5A20S9@>Z!W8$`
M@N&!WH/B@]J#SH1/RL^$VH31A-2$[83+A-6$\82<AHB&08?0A_>'SX?1A]N'
MWH?XA]R'V8>@B;*)H8FJB:F)J0VFB9R)M8FGB8Z*D(J1BH6+6XMPBV2+9XMC
MBW>+:(MEBVJ+>(MFBXB,GHQTC'J,>8R+C'^,$XX>CA>.&HXBCD..&8X?CB>.
M$HXDCB6.7C8UCS2/T8_$C\J/QH_+C\V/XH^)D(N0AI"(D(V0.Y$\D3V1]9%Y
MDG62@I)_DH62=I)\DGZ2>Y*`DGJ22%?+#QV3]I/WD_F38Y1LE&Z4%)0-$&>4
M;Y1IE':4E91QE&&4>)1KE(64A)04EG:6MHEUEG26XI8_ET27/9='ETB7VY?<
ME]V7Y9CFF,*9+IH=FOB9\)GVF<69QIG\F5*:+YH0FO.9TIGJF=R9&YK[F<.9
M%IH'FLF9V)DPFA.:,9KZF?*9XYK5F0&:\9D<FM:9")H+FA>:()K*F3*:!9KD
MF<Z9,YH"FAF:'IK3F?>9Z)D?FO29V)J_G+Z<O9S<G=V=JYW)G<B=WYW9G=N=
MS)W@G>^=\YVNG0&>MY^YG[:?N)_VG_.?]9_RGY&@G:";H)*@C:">H(R@,1+'
MRI6@QLJ*H(Z@G*#OH2VB4J(UHBBB+J+EHNJC\:/KH]BCT*/SH]NCSJ/5$MJC
MUZ/AH_*CR*/9H]ZCT:/GH\^CMZ5'ID*F0Z;3RL.FP:;'IF2G:J=FIU"G;J=E
MI^QI?Z?5RIJG::=RIV^G?:=PIV"HPJCGJ-&HZZC4J-RHVZ@WJB6J'ZH>JB&J
M&ZH7JB*J*JH:JBVJ(ZHFJC:J_ZDZJT"K0JLXJSNK/*M#J^BK5A3YJ^NK\:OI
MJ^RK%:U'K4:M1:TDKE:N(:XGKDVN,:X>KBRN3ZXKKE.N4:Y4KBFN4*X?KC*N
M*JX=KBBN+JXMKKRONZ^]K^3*1[!!L.7*2;#T%"ZQ)[%JLGNR<[)ULFFR>;)R
MLG:S=[-TLW.S`K3^LP&T^;/TL].UU;78M<.URK70M<NUSK7%M>:UQ+7`M=2U
MZ+5VMJ*VKK:HMJ.VI[:6MJFVI;:OMJ2VJ[:JMJ:VH+:8M]NX]KCUN`RY"KEU
M,6BY8[EFN5@69+EJN6FYE;H"NVJ[7KMHNVF[9;O^RJ>\KKRHO+.\G+VIO;:]
ML[VRO0/+N+W`O;^]NKVHO3R^<KYQOG6^<[X7OQ6_%K\;O_J_^;\LP87!@L%_
MP7W!B,'S<D["4,*3PY?#F,.;PYS#EL.+Q?W%_,47RXMJ"#0'-',VHC:O-H(V
M>S9T-K`V=C:Y-IXVL3:A-K(V;C8+R8<`>#9Z-H,VFC;X-S$X:3AH.)PX!#F9
M.<<ZQCK<.L0ZV#K4.M\ZT3K0.M8ZSSJM.Z\[ISO].UL\6CP'/9T]FSVK/:0]
MG#V>/:4]JCVF/0X^?CY\/NY!U4'I04)!XD$C0ME!U$'C015"[T'P0=9!W4'V
M01Q"V$';0=I![4$11A5$&$0:1!]$%D1-R1E$2\GP10E&&T;GI?9%]$6U11!&
M\D451O-%^$4Y1SM'-D<.1G)'=$>Y1[='N$=R2&M('4HW2B)*0TI-2CA*6TIY
M2AM*\TF12WM,E$QOR99,?TR/3(1,?$R.3)!,F$R#3(!,DTR"3/TR/4U!3:%-
MGTT*3@U.R$[)3L=.S4XE3[%0W%"`R>50]%"_4-M0ZE#R4/H#\5#M4.90`E*"
MR253&%,?4R!3SU.=5)E4J%1H56959U6151-6%58=5A96&59K5FA6:E9M5FE6
MJE975U)74%=?5V=73U?R!%M77%==5Q]:G5FQ6;!9E%G#6:]9J%G<69A9Q%FD
M6:M9JEFE62%:ZUGF6?=9^%G\6?I9X%FJR?99J<GA6>Q;XEOD6_E;;UY,:[M>
MX5X`7]A>+P;67N)>PUZS7M)>P<G.7M!>U5ZY7KI>SUZ]7MM@JF&M8;AAMF&U
M8:]AM&&W8:AAN6&^88)BO&*X8K9BN6+!!A!C)V1I9'!D5F1K9'ID;&1M9-7)
MP92-99!EMF<0:!)HNF>]9P5HPF<':/5GZ<FO9_1G]V?X9Q%H]FGU:?MI`6H`
M:@)J_FGZ:?UI0`@W:TEK2VM&:T=KLVNR:[!KMVL1;,QLWVS3;-5LVVS%;,AL
MR6SB;,ILT6S2;-UL;&]S;R%P\&\?<#MP(G`C<.AOW6\_"1MP[6\.RO)O1@G<
M;^EO'7#:;^9O$W,5<Q9S/',+<QQS.G,]<YIS'7,)<PAS.W,B=29U)74D=9LV
MCW60=>9UXW7E=1%V)<JN=KYVM':S=J]VD7;"=K9VLG97>#MX6'A1>$%X.7B/
M"EEX17AA>.AX^GGJ>>]Y\GGP>0A[<'MJ>W-[:'O(>_)[>SZN?*M\M7RO?+)\
MMGRP?!Y]`WX&?A]^K`L/?@)^&7X8?B)^%7X'?@U^)'X,?AY^B7^*?PJ`"X`'
M@`2`"8"$@(.`&((4@@6"%H(.@A&""((+@A6"A8`W@BJ"#8(/@GZ#=H-W@^R#
M_(0(A?^$`X40A06%!H7ZA,>&P(;#AJ>&J(:KAL&&JH;(AD.'`H@.B`&(_H<#
MB&@-(H@AB`>("(@,B,J)O(F^B;V)7,J[B;F)JPW%B9F*:XN3BY2+J8N@BZ:+
M8<JKBYZ+FXN1BYF+MHRXC)J,D0Z8C)N,LXRBC*I4H(R?C%N.<(Y4CG&.98Y1
MCIV.88Y:CG2.3(Y+CEZ.6(Y3CE*..X\YC]:/YX_7C]B/V8_:C]N/W(_@C^2/
MW8_UC_&/F)"=D)F04)%)D>0G8I'7D0&2]Y%]RHR2G)*(*!^3'I,]E#^4$919
ME#Z46)0`E9Z4MI2JE*^4K)0P$,"4J900/NZ5=Y9YEGJ6?99_EH.6>)9^EN26
MYI;EEET03I=9EW40CLI/ETJ7XY?>E^*7=)FLF6&98IEVF7J9>9E@F62:@9O?
MFH2:BIJ2FGF:WIJ8FFR:X9JERGR:<IJ!FN":99K_$&J:EYJJFM.:JYINFJR:
M=II[FJV:ILJ4FM>:<)K5FO&:>IIHFI::"Q%SFJZ:W9K:FJ^:L)K;FF*:^)K"
MG,><R)S%G,.<QIS>G<@1$9X5GBB>(9XMGE&>*YX6GB2>-9X?GA*>$)Z`GCN>
M*9XJGAN>&)X@GC^>')XFG@N>OI_$G[V?^I_[G[&@LJ"PH+F@IJ"]H+:@N*"T
MH+.@IZ"NH+R@\J'SH?2A.Z)`HD:B\*+NHNBB\:+KHN^B_*,@I`FD!J0#I,_*
M&:0DI!ND':3]HQZD]*,!I`BD!:0CI/^CZJ5-IDZF5J97IE&F5:94ILNFU*;1
MIL^FTJ;*IM:FBZ>(IX6GB:>;3+NGC*=T$YFGBJ?LJ.^H^:@)J?BH\Z@`J1VI
MK!/]J$BJ7*I5JEZJ2:ICJF"J4ZIBJD"J2:M*JTRK3:L*K`:L+ZPAK`>L":P"
MK!:L`ZP+K`^L8*YHKEZN7:YCKE^N9*YXKF&N::YEKMJOYJ_;K]RO.;!7L%6P
M9;!AL%2P1;%!L3ZQ-[$2LA.R++*6LNG*G+*=LH6RZ,J?LJ.R@K.#L^[*';04
MM!^T(+1'M8"UR;7YM0:V\+7XM>^U_;7QM?ZUN+;`ML.VM;:VMLFV\\J]MKJV
MO[:SML:VLK:\MK>VN;;(MK6WL[<6%JRWJ;>MMQ&Y#;D6N8FY?+F+N7NYB+F$
MN9VZF+J(NX:[@KN+N__*<;MRNX&[C+N`NXF[N[S!O+Z\`<N]O,&]M+VWO<B]
M.Q?3O="]L+W*O<V]%;X9OA>^/[Y`OD2^?+YXOGF^B+X&RXF^?;XCOR2_)K\B
MOR>_'[_)O\._"L`+P`3`[Q<#P`'`"<`/P2[!+<&1P9G!GL&0P93!G<&8P9O!
MG,&:P53"G<.?PZ/#I,.EPP+&%\<;QQG'T<<W1P``````````````````````
M```````````T````-0```#8````W````.````#D````Z````.P```#P````]
M````/@```#\```!`````00```$(```!#````1````$4```!&````1P```$@`
M``!)````2@```$L```!,````30```%8```!8````80```&0```!G````<0``
M`'8```!\````?P```($```"&````C0```(\```"3````E0```)H```#_````
M``(```$"```#`@``!`(```4"```&`@``!P(```@"```)`@``"@(```L"```/
M`@``$`(``!$"```2`@``%`(``!4"```6`@``&`(``!D"```:`@``&P(``!P"
M```=`@``'P(``"`"```A`@``(@(``","```D`@``)0(``"<"```H`@``*0(`
M`"H"```L`@``+0(``"X"```O`@``,`(``#$"```R`@``,P(``#4"```V`@``
M-P(``#@"```Y`@``.@(``#L"```\`@``/@(``#\"``!``@``00(``$,"``!$
M`@``10(``$8"``!'`@``2`(``$D"``!*`@``2P(``$P"``!-`@``3@(``$\"
M``!0`@``4@(``%,"``!4`@``50(``%8"``!7`@``6`(``%D"``!:`@``6P(`
M`%P"``!=`@``7@(``%\"``!@`@``80(``&("``!C`@``9`(``&4"``!F`@``
M9P(``&@"``!I`@``:@(``&T"``!N`@``;P(``'`"``!Q`@``<@(``',"``!T
M`@``=0(``'8"``!W`@``>`(``'D"``!Z`@``>P(``'P"``!]`@``?@(``'\"
M``"``@``@0(``(("``"#`@``A`(``(4"``"&`@``AP(``(@"``")`@``B@(`
M`(L"``",`@``C0(``(X"``"/`@``D`(``)$"``"2`@``DP(``)0"``"5`@``
ME@(``)<"``"8`@``F0(``)H"``";`@``G`(``)T"``">`@``GP(``*`"``"A
M`@``H@(``*,"``"D`@``I0(``*8"``#X`@``^0(``/H"````````````52N"
M+(DLARR^+;TMRBW4+;PMQ"W!+<(MURUP+;HMXRV[+;$NMBZP+FPO#3`',/$Q
M]3'M,>\QZS'L,>XQ!S+$,P@TLS2M-+`T$36*+(,V>C:"-F@V<3:P-J\V]@%L
M-F\V8C9E-H$V?S9D-G,V;C9G-G0V?39X-H4VJC:(-J8V3L.*-H0V51HD.2(Y
M(SDR.ELZ3SIG`B8Z/CI".D<Z(CJ;,$HZ'SI).BLZ,SI8PRHZ*#H].SP[OSMY
M/(`\?#QZ/'@\@CU</5H]2SU\/7\]'SV)/8L]5SU^/7T]4SV?/[P_I3^&/]P_
MI#^V/Z(_M#](0$9`IT`401)!$4'A0=!!)D(H0BE"+T,-0R5#%$,\0PM#$4,P
M0QA#&4,V0Q=#$$,50P-$*41,1#]%/D4T14)%-47S,<U%T4721:U&ND;!1KM&
MM$:\1FQ'DD<A2"1(&5^M2*Y(JTBL2'!)=DEQ27=)?QSL2AQ+^TKN2N)+_4H>
M2SM+2DNNPY(%?4M62T1+2TOZ3.A,^$S_3/=,]DS^3`=-74W43L/#R$[%3L##
MR4Y-3R!/-D\U3XA/)4\A3R9/108_3SM/)$]#3TY/3T]$3T!/04\Y3RM/W5#>
M4,U1RU';4=A1V5'24<I1T5'44?E1T%%>4EU2BE(44X-4A%2;5()4?51\5)E4
M?E2:5)54>U2&5$A5DE6R5D)7<E<55S!70U=;5QU7<U<M5\D'(5<<5^K#*5<>
M5S-7$%H.6O'##5H16A):%UH)6@]:F%J46I9:F5J56I=:4%M26TU;5UM36U9;
MN%L27/%<\%SN7.]<Y5SK7.=<\ESF7/=<"5UK76I=>5[-7N]>Y%[C7FQ?9U]B
M7UA?:5^K7U=?K5]47ZY?=E])7T5?3U\/Q%!??5]$7V9?2%^C7U%?4U\0Q&!?
M1U]>7X5?K%]M7W5?J%]5"4-?3E]<7U9?;E]C7VI?5F(28EQB6&)58GYBJ&(1
M8EEB6F)G8E1B6V+P8BED+&0J9"=D9V1H9)-DE62:9.YD\63M9.EDRV7?9=ME
M/&=.9VQG>V=\9X-G:V=F9V-GH&>%9VAGHF?L:.@*YV@0:1AI.FD::3AI06D;
M:11I'&D=:1)J#6H':GYJ?VJY-(!J>FKS:KEKNVNZ:[UKMVN_:R%L.FT];39M
M26V!;;8+/VU-;3YMO0LP;4]M-VZ8;IEN$6\-;XAOBF\<<%5P5G!B<%=P0G`0
M<$UP6G!F<$9P?DM/</F`AW&$<?1Q]7'R<?=Q17-0Q$ES-7/]<C!S0W-&<]8,
M,W/&=%;$U'38C>!TIS9$=9@M5'8^=C5V.G9Q#31V.79&=EIV6W8\=MQWUG?0
M=U[$K'A=Q*5X]'DD>N!Y_7GR>?QY`GKQ>?]YTGG8>=-Y^7ECQ.UY]WGP>==Y
M"7KU><)\Q7S/?)@.P7S&?-1\SGR;?IE^CWZW?H)^DWZT?L%^D'Z:?I1^G'ZU
M?F_$;L2??HY^GGX\@$>`08#K@.R`[8#N@-^`\H`-@0Z!ABRI@:2!I8%?@EJ"
M9H)H@FJ"9()E@L&"V()[Q-F""8.J@Z.#N8/B=Z6#JX,@A(F%BX7;A>2%[X7B
MA>F%\(7SA=V%'H8=AT:'?(>`AX&'@H>'AXB'BH>,A^>'ZX?JAVB(:XAIB&:(
M:HAEB.6(Y(CFB!B))(I(BB^*?HJ)B1Z*28HFB@F*-(HMBDJ*%8JIQ#.**(HG
MBB"**XHIBFJ*"XH.BAR*_XFJQ#6*$8I+BDR*'XH/BCF*:(H=B@B*#(H-BF**
MKXHRBBR*9(H$BA:*38H'BJZ*U(W1C=6-T(UQCUV/6X]ZC[W$?X]YCV>/GH^4
MCV2/7H^!CUJ/5X]\CYB/9H]^CX*/:(]?CV./EX_-$5./>X]]CWB/!I#`D<*1
MPY'<DN:2[)+RDNB2ZY+JDN62X)+0DMB2U9+3DN22\Y+;DB^3^9-=E%N43)18
ME&"44Y10E`>5")7TE/:4!)7]E`65*)96ED*67)8]EB^6*Y98EF&6+)91EE"6
M/)8VEO828)9;EBZ60)9?EB:6+99>ECN6[Y?SE^Z7[9=:F&*86YA?F%Z89)C@
MF.&8Y9BEF9N9GYF<F7H3JIFDF:.99YHFFQJ;N!,<FQ6;&YL8FQZ;)9O<Q'N<
M=9R3G(^<?)R;G(B<D9Q^G`$4AIQ;GE2>-9]`GS>?*9\FGR.?,)\@GRB?,I\J
MGS&?))]!GT*?0Y\EGSB?'*`=H!Z@]J"EH8FAG:&*H8>AJZ&&H9ZADZ&AH8BA
MHZ&?H:"A_Z(`HP*C^*+WH@&CAZ.)HW:C;J-WHX*CA:.#HX2C5Z1+I%:D7:1@
MI$VD5:14I%.D4*1CI&*D%Z46I2VEV:6_I2\5LJ6LI;"ESZ6XI3$5TZ6QI:^E
MSJ6TI;>EU:6<%3BI**D_J4"I0:DSJ2NI+JD1JQBK%ZL9JQ:KYA4-JR:K>:O8
MJ_.KUZO,J\^KRZO1J\ZKU*O5J].KUJO-J]JKTJO>J\RLN*RWK,*LPZSZK?FM
M'ZX=KH)BIJZ0KIZNF*Z3KI*NI:Z5KJFOJ*^JKZNOK*\?L"*PJK"6L)&PJ["B
ML*2PG;"7L'VPG["<L)FPIK"2L*>PR;'(L<>QR[%TLLFR.!?2LMNRZ[+ILN^R
M[K+YLMZR%K1%M'^TF+2?M(:TD+2:M)VTC;2<M*"TI[2/M$&V-;8WMC"V.K8V
MM@C%RK82MQ6W(K<3MQBW(;<0N""X+[BEN*.XMKBKN&BY9[EON7>Y9+EXN3H8
M=KENN;$8T+NSN\N[UKNQN[2[U[O&N[J[T;O2N[6[Q+O,N[N[LKM;OEJ^6;Z9
MOI2^EKZ3OI&^C[Z8O@R_"K\.OQ*_$;\+OYJ_1QFTOU$9',`@P"'`T\#2P#C!
M_2K/:QTLDBR/+(PLZBVY+FXOH"_=K1(P%S!M,`4R^S'],08R`#+_,?XQMC(%
M,P<SO#2[-(LUAS7[E^<VYC;B-M.AV3;*-A(W$#?<-M`VBS83-Q!-VC9/P_TV
MY3;,-CDWQS;8-F`Z9#J&.EXZ9CI?.G<Z@CJ6.CX[>3MZ.X@\B3R,/.!B>SR&
M/)0]ESVW/;4]N#V3/;(]M#V9/<,]G3V;/:,]1P.?/IX^HSZ@/J$^Q3_&/[X_
MQ#^_/TQ`2D"Q0!5!%T$001A!X$'?02="0T-(0QU#4$-80T=#5$-30T!#54,7
M!%I#<$A;14U%5D5/18?#646(PU1%4T501;-&;D>C!&]'DT<I2"5(*$AO2+A4
ME\.S2'E)?DE\28-)K,,`2S1+94LV2Z=+64M82S%+8DLX2W-+/DM52U1+E4NM
MPZ5+E$N:2YM+F4N?2U-+$DT*30E-#$T+30Y-#4T(33A/.D\W3SU/+4^"3Y5/
MAT^=3[5/@4_'3YM/F$^43X9/D$\T3XY/A4^F3Y9/ZE'?4;U4]U'K4>!1Z%'A
M4>E1[E'E4>Q18U+&4L)2P5+`4L-2&%.N5*-4Q52@5+14I50>!Z14J%2F5*A7
MC5>"5YY7B5>#5Y%7IE>:5Y!7A5=]5^S#FU>E5_!7EE>(5]97V%>&5Z17EU<<
M6AE:GEJ?6IU:G%I=6UY;<UMC6[Y;P5N\6[];NUN]6Q-<%%SX7/I<!EW^7%%=
M"V#Q7ZE?U5_<7\M?\E]?8-M?UE_97]%?SU_87^!?U%_S7P5@SE_T7Q+$VE\.
M8`9@UU_-7P=@X5\(8+YB[V+98MIBUQ^@8M]BGF*_8J]BIV*J8O1BKF*U8KAB
MVV+`8K=BHF+=8J%BI6*T8J9BJV*L8I]BL6+\8BYD,&299/AD]F3T9>MEX67D
M975G:6>:"IEGGF>49Y-GD6<9:1=I26E':4AI4FE`:6-I1FE?:0YJA6J':LMJ
MS&K):LMKYT$@;%]M8&UJ;79M<VUQ;69MP@MK;7EM>VT\;IYNG&X<;QYO(6^6
M;Z%OMF^@;Y1OEV^!<(9PP'"*<$O$A7"5<$EP@G"$<'A+D'"Q</YQ^W%0<U9S
M6G-,<]P,5W/A=-ETVW3T=$5U1W5T=FMV:'9I=GEV6\2`=H%V879P=F]V<W9=
M=OIWLPWS=PIX%WA?Q+!X/GI&>D]Z1'II>C-Z+WI.>CIZ*WJI>E!Z17HW>B5Z
M+'H_>C1Z*7H>>CUZ[7QFQ/-\ZGSK?,Q^SG[0?N-^X'[1?MQ^W7[P?MM^Y7[Q
M?LE^Z'[G?LA^WG[-?L5^QG[D?L-^^X#\@/Z``X$`@?V`!8$3@:>!M(%P@G2"
M<8)U@GV"<X+$@L."WH+=@A&##X,0@\.#PH/*@\&#(X2QA22&$88EA@J&'X8@
MAA2&*(8#AA*&"X87AA%-28>)AY"'CX>6AY6'DX?MA_"'WF*%B'>(>HB$B'F(
M?8A[B.V([(CVB9N)G8H1B\2*R(K?BK^*LXJZBA"+!HN(BIJ*X(K,BK6*X8J\
MBL:*"XNDBI6*HXKBBLV*XXJKBLN*CXJKQ*F*)(ODBA*+Y8IGBZJ*H(KFBL&*
MYXH-BX:*L(J+BNB*R8H9B\"*#(OIBNJ*[8WCC>2-Z(W2C>*-9B3/C]&/PX_)
MC^J/M(_<C[V/YH_(C^R/LH^IC]./P(_IC]6/V1'%C]T1RX_0C]*/Y(_HC\V/
MMH^JC]2/2:#!C]V/SH_)D<J1_9+9DO^2!)/ZD@:3%9,1DP>3"Y/\D_V3;91E
ME!25$Y4,E0N5&)4BE7V6;Y9UEGN6@)9_EI:6;99KEH:6<Y9BEG>6@99IEH*6
MEY:$EOP2>);0Q'J6:I9EEGZ6E);"E\&7^9=QF&N8;9AOF&Z8\ICHF.^8Z9CJ
MF.V8\YCFF,F9M)FSF;F9RIFQF;:9QYG$F;>9;YHSFS*;'YO9Q"N;,)LVFT*;
M09O8Q*6<JYRIG+.<IYR@G-*<J)RVG*R<KISFG&6>1Y]CGTV?7Y]+GV"?29]3
MG]_$.B97GTZ?4I]4GR"@(J#!H=>AU:'$H="ANZ'BH<NAN*&_H=BAP*&ZH;2A
MO*'4H>VAPJ'9H<RA+Z,CHY:CC:.>HYFC@Z0'%6JD::1UI&RD@*1NI(&D=Z1V
MI'.D<*2$I!FE\J4])^REZZ7VI>^E]*7NI?.E[:6;J)BHE*AZ.IJH\,1,J:@5
M5ZE1J6*I4JE<J5.I[\2%JBVK/JLPJWVKYJOVJ^2KZ:OLJ_*KZ*OCJ^NK\*OJ
MJ^>K_:OEJ^ZK]:OYJ_&K]*OTQ!&LWJS8K-VLVZS3K.&LWJW\K2BNMZZXKL>N
MLJZIKKFNO*ZSKM&NL*^QK[:O!+`LL,&PGK"ZL,H6T;#3L-2PU;#%L+:PLK"U
ML,.PN;#&L-:QX+';L=>QW;$5LPRS#[,.L_ZR!+,+LP*S_[((LQ"S%[,3LP:S
M";,DM":T);1(M+6TTK35M,2TK[2MM,&TP+3,M,VTP[3(M,6TNK30M,*TSK2-
M%T.V0K9`MC&VS[;.MC"W-+<RMT.W/+<1N#6X-+@WN#&XO[B\N,*XR;B#N8NY
MH+F-N8RYFKF*N9&Y\;L/O`&\![P,O,`8W+ONN_>[\KOXN^N[RACFN^V[Z;L(
MO`"\Y;O\NV&^7KY?OB49F[X6OQ6_(+\4OQJ_%[^<OTH9\;]3&?"_*,`DP"K`
M*\#5P`3!!<&1P9+!IL()+"(N&BX.+ALN""ZS;QS#G3`2,AXRNS*_,KPR"#,)
M,V,SR#,H6(XUC35#-TTW;3="-U(W43=I-U`W5C=L-T0W13=K-P4":#=7-RXY
M,3DM.8LZLCJ-.J,ZI#J0.HDZCCJ2.GL[D#R//.D]S3W%/=`]R3W1/<<]TCU?
M/>$]S#W&/>0]J3[3/]H_TC_;/TU`3D`<0>A!;$-?0V9#9$-X0V5#;4-A0WI#
M!T1F16A%8D731M1&T4;<1G-'<D<M2"Q(+TAR2+1(B4G-2Z9+HDN@2T9+H4M7
MAJ-+L4O;2_9+W$O62Q--G$^73]A/Y$_43^5/VT_03]I/S$_<3^U/TT_13\Y/
MV4_=3\;#YE#E4.E0_U'^40Y2C%+*4LM2&E/75,]4T%3)5,Q4TU2D5:-5@5<F
M6/-7)UCR5_]7]5?\5PY8\`?V5P!8(U@%6"58"%A06"5:(%HC6B%:H5II6VQ;
M:%MK6\Q;S5L070U="ET6711=4ETH8"Y@+&!-8$E@,6`P8#-@+6`V8#Y@+V`G
M8#1@3&#^8A)C'V,78_5B%6/W8@(*?4/Z8OEB2V.<9)UD(PKP9?9E[V6=9YIG
MIV>O9ZIG9&F&:75I<&F$:6MIA6EL:1=JE&J3:M)KUVO4:Z9MIVV<;8MMC6V8
M;;EMFVV=;9EMJ&V1;8=MFFVF;A]OIV^Q;[)OMV_0<+-PM7#$<,-PO'"R<+IP
MNW#"<,UPOG"W<(]Q`W($<G%S=W-T<XMS>G-1Q(QS<W/_=/MT_73P=/-T_'3R
M=))VGG:N=I9V%'@2>!-X%G@/>+9XO7B,>JYZK'JK>IEZDGJ[>IYZ?GJO>KQZ
MF'H!?0E]!GUGQ`=]"'W/?@Y_,G\5#Q)_%G\7?QM_%7\Q?QA_&G\0?PI_"7]/
M@'/$#X$0@77$*($1@1:!%X$"@;N!NH'#@;R!BH*$@H:"X((7@QB#'H,5@].#
MVH/9@^:%](7AA6F&0(98AFR&388AAYF'\8=H7X:(6XM<BW>++(NMQ%B+9(MA
MBTB+EXM9BRF+8HLNBVB+D(LZBSV+7HM&BVF+98L^BTF+5HOABWB+>8MFBTJ+
M-8MZBY*+8(LVBU&+0HM=$3^+>XM=BY2+:HNUQ/*-NX\;D!J0,Y`7D`J0%9`2
MD`&0+9#]CR.0!9`1D`"0')`UD"Z0-I"_-"^0#)`)D#&0_(\/D!B0`I``DA^3
M-Y-:$CB3*Y,NDR&3,),IDS&3R<0!DRR3(I/_DW>49Y1_E'V4>Y1^E!Z5')4A
ME2:5)Y4IE2R5'94KE;^6I):JEJZ6GY;0EK&6K9:;EK*6J9:SEK26NI:EEK>6
MK);+EL^6QI<!F/^7_9=WF'B8=ICWF,R9A1/4F=>9U9G6F=.979M5F^"<2)WN
MG-N<YYS6G.6<X9S=G.*<<)YFGF^>;IZ!GVF?;I]MGVR?A)^%GW&?<Y]JGV^?
M>Y]JH7RA?:&!H?JA!:+KH?NAZ:'OH?RAYZ'AQ.ZA_:$RHZ>CM:.QH[FCJ*.S
MH^;$BJ21I(VDF:0+%9JDFZ22I(^DJZ3;:SD5=:8QICBF-Q4UIFFF.Z8]IFRF
M>:8\ICZFEZBEJ**HG:BAJ&BI;ZEMJ7*I=:EWJ7FIM:KJJJNJ0ZM!JT*K":P(
MK`:L`:P#K`"L!*P*K`ZL#:P'K`^L%*P"K!6L#*P0K`6L_:S_K`2M`*T)K2NN
M]\0QKMNNQ:[3KLZN:Q;)KK^NRZ[`KM"NU*[!K[FONZ_#K\FO![`ML/BPX;#Z
ML.^P_;#-%NNP\;#ML/ZP^+$#LNZQZ+$!LNRR(K,4LS2S+[,YLT&S/+-)LUBS
M.K-"LS^S(K0CM$JTW+39M-NTXK0'Q=^TX+37M$^V1K93ME6V3K9*MDRV8[91
MMU.W6+=-MUJW2;==MQ*X/+C1N-^XUKC8N."XV;BQN:RYJKGNN;VY31C#N:BY
MKKFKN1V\)[PXO!*\2+PKO!:\&;P]O".\*KQDOJV^K+X4Q;&^K[XLOR2_);\H
MO_F_][_]O_Z_.<`SP-?`V,#DP*$Z#L$[P43!0L&4P9/!U<&GPC$N(RXH+B<N
MQBZC+R$P&S(0`<$RPS(J,VDS)S2V-Z<WI#>F-Y`WGC>4-Z@WI3>B-Y$W>P*\
M.KTZM#JP.N0Z13M+.WX[?SM].\,[_#WW/?`][3WQ/?@]Z3_K01T$D$.-0X9#
MD4.*0PA$4$3J1N9&XD;G1NU&X48T2'9(=4AS2+5(D$F22>%+WTO52_)+_DL3
M3"Y,&4T(4/4=!5`)4`90`U#]3_Q/`E!"4!I2$5(54A92S%+/4M!2(E,>4R%3
MY50G!U15[U1355%5K55G6&A8I%AW6(E81%B+6'E86UA#6%=82EA\6$98>UA6
M6*A:=EMR6]9;V%O16R)=(%TC71Y=;EVC8'=@IF!M8*)@?&"$8&A@=&"&8*5@
M>V!Z8&E@<F!V8$IC-V,J8RUC1F,H8R9C0F,L8SAC*V,S8T5C.63Y9?IEN&>W
M9[MGN6>T9V]IAVF/::)IHVDQQ)MJG6K.:L\+O6V_;9)MS0OO;<EMI&ZH;JIN
M*&\D;R5O)F^I;[IOOF^\;\!O\'#?<.!P[7#;</MPN7#:<.MP['":<Y]SFW.7
M<Z%S#W4%=4AU@@V\=KIVOW@!>^AZ[WKD>N9Z`GOK>N!Z[7K9>F3$%'ON>E(.
M$WOY>OAZ)7UIQ!E]('U#?3]]17],?TE_3W]!?SY_37]2?TI_3G]S?T)_47]5
M?U!_;'_]*FI_4W]H?U6`5H`<@1V!@"(>@2.!'X'A@<V!RX',@<B!R8&;@I2"
MDH*6@I."E8*/@AV#(H,A@^F#[X/@@^:#Y(,IABR&=H:#AGB&/(9#8WJ&41#R
MAIZ'FX>:A_:']8>EB).(I(B"BL>*MXL=C.*+UXOCB^2+O(O3BUH16HO2BRV+
MK\3$B]"+Y8L%C`>,YHL;C.>+V(N^BQ>,M(O9B^B+K8NOB\B+Z8OJB_Z-^XT`
MCG*0<)!&D%F07I!(D$^0<9!@D%^0;I!SD,#$O\1'D&V0;Y"!D&R0>)"#D$F0
M:)!TD&.0:I"%AF608I#(D-"1U)'1D0.20I-CDU:36Y-5DU"3+9-$DTB319."
MDV428I.%E(V4-I4OE3&5-Y6GEMF6\);REOV6Z);KENZ6X);IENV6UI;XEM26
MWY;GEMB6XY;OE@^7RI=&.P68#)@-F'^8@)B!F`&9`YGRF>*9XYG>F>F9Z)G@
MF0&:]9GDF0$E=YITFV^;8IMAFVV;<YMJFVF;$ITMG12=#YTIG1:=`YU&G5R=
M$9T&G=R<*YTJG2R=)YUZGIR?F9^5GXN?F)^6GS*@I*&JH1NBKQ0-HARB"J(@
MH@BB&J(3HA&B7:-?HUZC8*.[H[RCP:/`H\BCSJ.GI+*DMJ2EI+JDM:2MI*2D
MTZ2PI+&D':6-ID$5D::VIK>FO::\II:FE*:@IJBHIJB$J9:IB*F:J=&JSZI0
MJU&K3JN`JX&K&ZP7K""L&:P:K"&L'JP8K!VL*18MK22M)ZTNK26M'*T9K2H6
M(ZT?K1JM*ZT>K>"M,Z[FKORNY:[XKO:NZJ[RKNVNZZ[PKO&NQJ_(K\ZOQ:^6
M%LNO$[$4L0>Q#+$:LA(7%[(&LA:R![(0L@FR&;(5LFZS.[,^LVRS9;-DLUFS
M?+-PLWFS++12M%&T3+0`M1"U$[7_M/ZT[;1:MEBV7+;:MGBW7K=GMV2W$[@C
MN$&X/[A`N.VXX[CJN/"XYKCIN/&X[KC4N=&YW+GLN6F\;;Q7O&:\^;Q*O&"\
M5KQ9O$R\:KQBO&.\<+Q?O`W%9+Q=O&B\G[RZOKB^O+ZYOK2^.[\MOSB_+[\R
MOT'`R\#>P-W`VL#<P!#!3\%)P9C!EL&7P<?!G"S:P=C!J,(*+)TLRRXX+SDO
MIB\C,B(R(3+.,Y(UD37L-^`W[3<(..4W[C?D-^LWXS?J-PHX6</1.N,ZU#K0
M.MDZ?@+A&]HZTSI,.TT[?#N`.\P[_ST(/@C!`3YKPP`^[3_S/^X_\3_P/]X_
M44""0ZE#F$.=0YI#GD.?0Z9#IT,)1"]$<45M17)%[T;P1CM(.4@\2#A(_6HZ
M2'A(>4AW2)A)G$F929I)$4P*3/U+#TP93`-,%4P,3`E,$DPT3"I,"$PM3"A,
ML<,L3"9,,TRG!1I-'DT'4"Q0,E`H4#%0*5`P4"I01%`N4-%2)%/W5/14\U3X
M5+58EEB86)58D5BR6)Y865BC6)I8FU@@#X-_VEO?6Q9<'UTM72Y=*UVX8+M@
MOV"Z8-5@XV#!8+Y@O6"T8,)@H6"'8-=@RF"U8-I@V6"S8-A@9V-Q8V)C7&-H
M8U)C5F,).$(NH&0`9OYE_V7+9RC$RF>I9\AGM&FL::IIJ6D.:^EK[6OR:^MK
M[FOH;=MMUVWC;>5M[FW5;;-N+6_!;\-O#'$.<0=Q%W$)<19QFG&<<;1SMW.S
M<TX[$W44=>9VW';H=N5V+G@L>"MXS7@]>S)[+7M%>SY[4'LE>U-[(WLW?3A]
M1WT]?3Y]27U*?1U]Z2&E?XQ_C7^)?Y9_A7^/?W=_CG^"?XI_B'][?Y=_?7]Y
M?UF`)($M@2Z!*X%VQ-J!V('6@8>"H((H@R6#'X/S@_>#]H,KAEN&2(;+(UR&
M;8:=AIF&C(:1AIN&FH:<AI6&C8:6AJ6&*H>AAZ2'K8>IB*Z(L(@-C&.+<8M1
MC%2,*HQ$C%6,F8PYC#^,/HQ/C$V,-8Q`C#&,U8LKC#.,08Q6C$R,1HP\C$6,
M0XP]C'",5XPXC%B,91$WC`>.!HX)CJN0D)"3D+R0J9">D+^0JI"1D*20FI"G
MD*&0G)"BD)N0GY"4D(^0\(Z2D)60I9"FD`22G)-YDWJ3?I-[DW&3@9-_DWR3
M?9-UDW:3CI2/E#Z5/Y5`E4&5!!,-EQ>7$)<.E^J6'9<#ER*7!)<`ER"7(9<C
MEQ.7"9<1E\N7SI?0E\R7U)?;.@F8"YB%F`:9#9ED$Q29#YD)FA2:"YK\F02:
M"IH`FOV9!YH&FA&:>9IXFHB;@)N+FUF=89UUG2,459U;G5^=4IUBG7*=79UH
MG7&=99UFG6>==IU,G6"==)U0G8J>@9Z&GG^>@)ZEGZ>?J)^FGZ^?E7^QGS6@
M.:##H3"B*J(KHBVB+J(LHB.B(:(BHFRC@:./HX"CT*/-H]6CU*/1I+ZDRZ3.
MI+VDT*0$I]6FT*;3IONFV*;1IOVFV:;6IN:F^::AJ9VIGJG9*/^J7ZM7JV"K
M6:LLK"6L)ZPPK"2L)JPMK"ZL*:PQK$6M1ZU2K4JM4*U&K4^M3JU3K2&O":\:
MKQNO%7$0K_G$%*\.KQ*O"Z_/K]*OT*_4K].OT:\8-?O$";`<L2>Q);$;L2FQ
M'[$PL22Q*+$9L2^Q)+(ALB6R)K(GLG:R9K-ULVFS?K./LW2S$(ZMLRNT*K18
MM"*U';4KM2RU+;4SM1NU)[4JM2BU.[5^MG&V>;9XMG"V;;9]MG6V=K;>MF:W
M@[>'MWNWB;>&MX*W?+>!MT.X1;CWN/FX^K@%NOZY#[K_N?JY";H@N@RZ/+HB
MNOBY"KH(NO>YCKQWO(N\M+R*O)J\>;R#O'^\H;R/O*.\@;R4O'Z\@KR0O*6\
MK;R=O&>^:;[+OLB^T;Y`OTN_2;]&OSZ_0[\_OZ6_I[].P$W`FTGEP.'`XL`6
MP13!&\59P5'!7\%*P5?!6,'*P=O!WL'@P>'!W\'BP>/!DL*_PK[""RQ2+DXN
MN0`3PZ<O)C(G,L8R"S-J,W@S&C@6.!DX%S@;.!@X(#@W.>PZ@3L]K@\^K3[[
M/U)`KT.W0[)#>$6L10!'_D8"1_U&`T=`2$-(0DBW2*))`$PU3$%,!4Q3+E!,
M3DQ33%-04%!74%]055#J4"92,+0J4BA2+%(M4M12!U5855E5Q5C-6,=8Z%A+
M"#):E\+>6S)=R#05Q/%@\&#L8`EA^6#U8/Y@=&.!8WQC=6.)8X)CEV.&8WUC
MDV.<8W9C@&-%9*$P`V;)9\UGT&>M:<5IHFKL:_9K\VOS;?IM^6WU;?1M^&VV
M;K1N,F_-;\AOSF_*;RIQ(7$=<;USOG/"<_$,R7,?=?%V[7;R=N!V]W8P>#=X
M,7@V>,AX;7MI>WU[87MP>W%[<WMV>W5[>'MY>V1[;GM1?4]](GVO?ZI_HW^=
M?YQ_H7^V?ZQ_HG^G?[!_J7_#?S&!,H$S@32!-X$\@=F!W8'>@=^!X(&E@JJ"
MHH*C@@2$`X3^@RB$KX:MAJ:&K(>EA["'L8<!B+*(THCQB-&+1XS)C*>,R(R5
MC(Z,D8Q]C.Z,C8R,C+",EHQ"C'R,L8RRC(2,G8RAC)B,LXPBC'N,BHS.C(",
MEXRTC+6,FHR?C).,$HX+C@Z.HY#,D-R0X9#>D-*0VY#9D->0U)#)D.N0VI#1
MD`21RI#BD->1C).9DZ*3EI.4DY^39Q*.DP.4E)23E$25+Y<UERN7,I<MES:7
M%!,QEQ*7,Y<?ES270)<_ET&7TY>)F!B9$)D:FB6:'IJ2FY6;DYN$G9J=B9V-
MG8B=D9V;G9R=2+&.GI*>Q9_!G[B?OI^UG\>?/*")%.RA/Z(YHC>BH:.4HZ"C
MWJ/;H]^CW*/6I-RDW:3@I..DX:08IQFG4Z?LQ$2G#J</IT>G%Z<=IQ&GM*BV
MJ+>IOJG"J;2I,:L5JX.K.ZPVK$*L4*Q`K#2L.*P]K#ZL-:PZK$:L-ZPYK$6L
M=ZU=K6JM=JUKK6RM9:UDK7&M7ZURK?ZM_ZT^KBNO-J\MKSFO/Z\[KS.O0J\Z
MK]6OV*_9KPVP"K`YL#JP/;%%L3JQ-[$^L4*QA[.,LX*S:[.@LYJSD+..LZ&S
MO;.RL[6SM[.JLZ*SI;.NLZNSO+,RM%JT9+5<M4VU/[4^M5*U6+57M5ZU4[54
MM5:U9:N$MH6VAK:7MZ&WHK<+&`K%H[>FMQ<8%;@DN$JX2;A(N$NX#KEBM0NY
M"KD(N0:Y0[I'NC^Z1KI0NFT82[IP&%*ZU[R_O-B\X+SGO+B\U;SOO.:\Y+S4
MO-:\ZKSM&+N\Z;P0Q6V^<+YSOG*^U+[.OM6^6K]8OU*_4+]5OTZ_3;_+O\R_
MS;_1OUC`8\!>P%3`6\#IP.?`Z,`=P6?!6L%<P5O!8<&AP8T9I,'IP>_!Y<'U
MP>O![<&6PI7"L\*UPK'"IP!-+B0P*S+/,\DT-C@Q.%0X.C@X.#DY.#GT.O,Z
M]CK\.O4Z\3J</!@^&C[\/_X_`T!30"M"QD/!0WM%!D=)2+A(HTE23$U,7TQ>
M3&%,(TV,4&]0=5!T4'%0<%!L4"93"%4''O!8[UC[6!!9#%GV6/Y8?%OA6SA=
M;UT8815A'&$0835A%\0781UA)F$H82EA*F$:81;$!T>K8ZQCH6.N8Z-CIV-(
M9`1E_65:"@AFTF?&:;YI'&JF:J=JJVH`:_MK_&OY:P%L!FX$;CS$-&\V<3)Q
M0G$M<35QV',C=2!U`7<`=P-WO,(\>$%X-7C)>(Y[GGN9>[1[JGN?>Y9[G7O#
M>W1[JWNO#F-]6WU:?<5_Q'_/?\A_I'^]?]-_8(`[@>.!YX&H@JR"J8(J@PB$
M"82YAL&(PHBXB.&,ZXSEC/J,Y(P+C=>,[XS@C.R,^XRPQ-.,YHS\C..,SXS:
MC-R,THRDC&L1%XX6CO*0_)`8D?:0_I#SD/>0`9'YD`:1]9`0D=^0`Y$(D=B1
M!9*7D[.3KI.ODZ>3L9.HDZR3JY,$E)J42I5"EUB72Y=%ETF73)=9EU:7&Q-&
MET276Y=IEXZ8CY@>F;R&+YJ>FYV;GYN<F[2=KIVKG;.=KYW"G9.>E9Z6GI>>
MSY_.G\N?2Z!&HD.B1:)1HJZCKZ.PH[BCXJ/CH^:C[:3JI#JE6:>$IU^G?*=<
MIUBG5:==IWZG@*>#IU>G8Q5>I[JHU:E8JVBK9ZM*K$RL4JQ)K$ZL1ZQ-K$NL
M3ZQ^K8>M@ZV)K<IIAJV(K4>N0JY)KDBN@!:$%G\61*]1KT:O1Z_DKP^P/[!+
ML5>Q4K'Q%E&Q6+%>L5.Q7;%-L3RR/[)&LCZR1+)%LD&R.+)"LD.R>K*CL[JS
MP+/$L\:SR[-AM'JU<[5RM72U@+6!M4<IE;:/MI"VDK:4MHNVYK:RM[BWO;>^
MM\ZWNK<6N":X);A,N%"X3KA1N%*X%+D5N1NY@KJ9NIJZ?;J%NH:ZG+IYNGNZ
M@+J#NH&Z'KT;O2J]^[P%O2"]$;T$O?V\`[T0O1B]"KU.O0F]![T<O1P9=[YV
MOMB^V;YAOUR_7K]@OZJ_UK_8OPG`",!KP&7`<\!TP.W`),$EP6K!I\&HP0O"
M^L'YP?_!!,+VP07"F<*KPKW"N,*H`&0N6BYR+WHSE35?.&$X7CA:.%PX73AN
M.%<X6#@".PL["#M1.R4^*#XC/B$^)#XI/@9`"D#*0\Q#RT//0W]%?$7610E'
M"T=V1WU(I4E;3%Q,74QE3&U0@E"#4(=0E5"*4-92*%,-52Y9[L,M62%9&5D[
M6CQ:.EI^6SM=1V$Y831A-F%&83MA06%%8<!CQ&.Z8[UCOF.C9`QFV6?-::YJ
M_VLD;+MNO&XV;]5OTV_6;SQQ/W'><^-S)W4I=8L-!7<'=PQWT'B^>[Q[T'O"
M>[5[R7MF?2L/U7_B?]Q_XW_:?\)_Z'_I@:^"K8*N@@N$P8:VA[F'P(BEC"B-
M(HTIC1B-'XT<C1*-*HUZ$2&-*XT7C?",%HTCC2N1)I$]D2*1.I$QD3*15)$A
MD361"1(ND3"1+Y$VD=J1V9&[D[R3MY/"D[V3LI-M$D1QT7M2EVN79Y<?$V&7
M;)=1EW27=Y=OEVV7:)?1Q(27D)B2F).8'YDQFCB:.9HWFJN;PYW(G<N=SYV8
MGM2?TY_8G]F?W9_1G]:?/J!8HE>B5:+$H^2C[J3OI/.D\J3PI*NGFJ>OIY>G
M:A5L%;^GE*>3I[ZHNZB\J-FI;*M3K%2L6ZQ8K%:L5ZR?K92MEJV7K4JN2ZY5
MKUJO7J]?KUFO6Z]8KU2OZ*_KK^RO$[!FL6NQ8K%IL6.Q7[%.L4BR2K+CL]NS
MV+/6LX:UD+61M8BUE+6#M;(7G+6-M86UF+::MIRVY[;%M]"WT;<9N">X'1A4
MN"VY(KDM&!^YO;JNNKNZK;J\NKFZM+K+NK>ZL[JZNK:ZS;J^NLFZ"\5?O3N]
M8;U<O8J]6KU-O4:]1+T]O4"]/+V,O4&]3+T^O4J]?+YZOF6_;K]IOVJ_;[]L
MOW"_:+]KOT49K+_>O]V_W+_%8XS`@\""P(C`A<"!P/7`[\#TP/+`]L#SP/#`
M\<`KP2?!*,%LP:[!#L(;PA;"'\(BPB#"(<(4PA/"G<*<PI["G\)K+L@R>#AV
M.'`X<3@*.RP^$4=^2%=,9DQI3&=,:$QQ3&],KK^+4)90-5(Z4FM2%E5#6499
M/UD[63U9L5JR6N1;0%U=85%A36%,85MAU&/28\ICR&/08\EC262D9!)F#V81
M9MMGW6?<9]1I(6JR:@1L`FP1;A9N$&Z^;AJ.3'%*<?)S\7,J=2QU+W4Q=1%W
M$G=+>-M[UGO=>^)[Y'O@>]][XWMN?7%]Z7_J?V.`ZX'J@;V&NX;&ALR&R(;/
M8\F&RH;/AM"&NH?[AP.(Q(A)C5.--HU*C4&-3HT9C4V-18U,C4>-2(U/C3>-
M0HU*D4:1"A))D4^149%,D0P2!I)1E7J7@Y=^EW^7@)>U:I&8E)B5F"&9()D]
MFD":1IJ$FJR;K9LN%-J=V9WBG^&?XY_DG]Z?WY]!HEFB7*):HNBC]J3\I/>D
M^J3YI,2GOJ?2I[VGE:?4I^2I8:QBK&.L9*Q@K%RL7:Q>K*6MIJU,KFBO;J]Q
MKVNO;Z_NK_&O\*_OKQ6P%+!NJT>P?+%ZL72Q=K%NL7BQ;;%LL4ZRU[/JL^6S
M9+2SM:.UI;6GM:*UG[6FM9ZUJ+6IMJ:VJK:KMJ"VH;:HMNBVZ;;JMN2WW[?@
MMRBX7;A;N%:X5[A?N&*XX;KCNMZZV;KHNO*Z]KKFNO2Z];KENN*ZC1B6O:J]
ME[UPO:&]G;VIO6^]?KV4O9J]<[V'O7&]=[V(O8V]A;UXO:V]@+Z!ON6^Y[Y\
MOZ^_X;^6P*/`D,#XP"[!=<%^P7W!>\%XP;#!-,(VPC#"'<4NPC?"SC27-9@U
M?#A^.'TX?S@/.Z0\,3XN/B\^,CXL0M1#W$/80PY$@T6$11)'<DQ\3'Y,IE"@
M4)Y0HE`J4QA535E865M9%'?RP^9;9&%H86!A8F'78TMDX&<B:@5L&6X:;L-N
MV&_<;T]Q]W/T<_AS$W=0>/![Z7OO>^U[ZGOX>P5\\GMR?3$/^7_S?_9_\G_W
M?V:`98!`@7?$T8;3A@2(68U@C5N-78U>C6F-7(UAC6J-7XU.D5R18)%CD=N1
MRI/)D\B3I92CE(Z7AY>)EX67AI>/EXJ7D)>8F)N81YI)FDB:Y9WJG>V=\)_O
MG_*?[)]`H&"B7Z+KH^RC`*4!I>*GWZ?@I^&GXZ?#J.NIZJEAJW&K:ZQHK&FL
M9ZRPK;&MLJU1KG2O?[&$L5.R5++PL_2S\;,WM+^UO!>[%[VUOK6WM<"UNK6X
MM;RUN[7KMN>W';@<N&.X2T@XN3:Y-+DWN0:['+L"NQV['KO@NA&[&+LANR"[
M$+N]O:Z]M;VXO;F]OKW$O;R]NKV#ONJ^[+Y^OWN_Y;^GP)[`FL`OP3'!@\&U
MP4;"0<)#PCW"0L([PD?":S/0,XXX$4!QPXG#3$@K4T]97EEC66M9/UKI6VUA
M:V%J82J[X&/=8^%CWF/<8TUD%F;C9^5IY&D=;DMUP<).>-9X_7L'?/Y[`WP+
M?/][>GUW??M_0X'M@;R'WV,%B,:(Q8ATC7.-<HUXC7.1>I$<;G:1=9%WD<^3
MSI/-DZB4F)>2EY27FIBTF^N=])WSG>Z=\IWPG62B!:C[I_RG\ZELK+JM>:]^
MKWBO]*\6L%>RR+7#M<ZUL[;MMNZV\;?XMQ089+AEN#6[*;LLNS&[*[LNNR6[
MVKW@O=2]X;W=O>>_$L"NP*_`AL&%P='!6,(_PE+"2\)3PE#"5L)7PLW"R\(Q
M,C`RT3,<`I(XD#B/.),XD3AR`Q-'?TBL4'!AY6,C:B1J"&P';!]N(&XA;N%O
M5'%7<55Q^G,X=8:--W53>'Y]>WUQQ/U__']&@3*'QXAQC8.-;XU^C7V-@8U\
MC8J1?I&`D7V1?Y&"D=23T)/2DU65FY>:ETZ:\9WXG_V?7J)FH@6E"J@+J`ZH
M#:@1J`FH$*@,J!*HQ*CWJ?BI:JMKJ\"MPJV%KX"OA*^!K\2MB[&-L8ZQM[:Y
MMN^V^[?_MV>X:+AIN#^Y/+M,NSV[/KL_NSN[_[T.&?:][KW\O?B]`;[ZO8B^
M@+\1P/[``,$UP3QOO<&[P5S"6L+1PM#""S1S63D^&D#C0X=%=T=X1[%0:EET
M6>M;>V&E9.1G"VP.;`QL.740?!%\%GR!?8!]_G\!@`"`1X'O@8B-BY&-D8>1
MA9&/D821B)&.D8R1UY/6DY^7B$4#GOZ?[Z,)I0BE(*@DJ!^H<*Q6KO>O^*_V
MKY"Q7K+WL]:UU;6[MO"V`;ALN$&Y0KE/NU.[6+L2O@2^$[X%O@V^@K^!O[7`
MNL"^P67"8\)NPFK";,+$PFPSI9<20$U('U5W67A91%U\8>MCZF/L8Z=D&68C
M;G0@`70<?`.`2(':AI&-DHV6D9>1D9&3D=B3U9-7E5B5HI<%GOJ?#*4*I2ZH
M*:@OJ,6H<JS(K5JN6:Z)KXBOV[79M=JUO+;L%P:X!;AON&VX<+A@NUZ[8[M:
MNU^[&;X=OAN^(KX<OAZ^][Z$OQ7`N,#!P`'!"L'2P77"=,)RPM`T&T`01'E'
M[6.Y:B1NQ6X#=$J!]X;!A\*'E(V9D9J16I6HER68GIA!H#*H,ZC+K<JMS*V3
ML>"U<;AKNRN^*;X:OB:^)[XJOOB^/6]VPA@[>EE_87D.\(&:C9:-GI&=D=R1
MVI,+G@*@0J!GHHNOXK5QNR^^+K[&P([!>\)WPGC"?,)\60>`EXW9EPVE#J7C
MM>2U\[9UN#>^-;Z/P8#"?\+4PK10[+]UJQ!L:8"DD=N3T:V-KW:[.;Z$PH+"
MTC3N8Q%LA'UTJX^OCJ\[OLLRB,*&PEQ5I'%UK(O"&3N?F.6U0+X2;/N^C,*E
M<7>X>+C6PM^3TJT:.ZF7TZW*P,2'L91DL@``````````````-````#4````V
M````-P```#@````Y````.@```#L````\````/0```#X````_````0````$$`
M``!#````1````$4```!&````1P```$@```!)````2@```$P```!/````40``
M`%(```!3````5````%4```!6````5P```%@```!:````6P```%P```!>````
M7P```&(```!E````9@```&<```!H````:0```&H```!K````;````&X```!O
M````<````'$```!S````=````'4```!V````=P```'@```!Y````>@```'L`
M``!\````?0```'\```""````@P```(8```"'````B0```(H```".````CP``
M`)````"2````DP```)0```"5````E@```)L```"<````G0```)X```"?````
M^@```/\``````@```0(```("```#`@``!`(```4"```&`@``!P(```@"```)
M`@``"@(```L"```,`@``#0(```X"```/`@``$`(``!$"```2`@``$P(``!0"
M```5`@``%@(``!<"```8`@``&0(``!H"```;`@``'`(``!T"```>`@``'P(`
M`"`"```A`@``(@(``","```D`@``)0(``"8"```G`@``*`(``"D"```J`@``
M*P(``"P"```M`@``+@(``"\"```P`@``,0(``#("```S`@``-`(``#4"```V
M`@``-P(``#@"```Y`@``.@(``#L"```\`@``/0(``#X"```_`@``0`(``$$"
M``!"`@``0P(``$0"``!%`@``1@(``$<"``!(`@``20(``$H"``!+`@``3`(`
M`$T"``!.`@``3P(``%`"``!1`@``4@(``%,"``!4`@``50(``%8"``!7`@``
M6`(``%D"``!:`@``6P(``%P"``!=`@``7@(``%\"``!@`@``80(``&("``!C
M`@``9`(``&4"``!F`@``9P(``&@"``!I`@``:@(``&L"``!L`@``;0(``&X"
M``!O`@``<`(``'$"``!R`@``<P(``'0"``!U`@``=@(``'<"``!X`@``>0(`
M`'H"``![`@``?`(``'T"``!^`@``?P(``(`"``"!`@``@@(``(,"``"$`@``
MA0(``(8"``"'`@``B`(``(D"``"*`@``BP(``(P"``"-`@``C@(``(\"``"0
M`@``D0(``)("``"3`@``E`(``)4"``"6`@``EP(``)@"``"9`@``F@(``)L"
M``"<`@``G0(``)X"``"?`@``H`(``*$"``"B`@``HP(``*0"``"E`@``I@(`
M`/@"``#Y`@``^@(``````````````````E.,4]13I5224Y-3V%/94Z=4*UDL
M62U9,%DN6:M9`1HM7&U<-/H/7?U2G5ZB9-1H5F[#;A1S_5(:F@]3$%.:4YM3
M_5*L5#8`EU-&6$\.=EAW6*Y8.EE]6<5NJ%[]4OH:065"9=AHV6BJ::MI0FQ!
M;)E0QF[]4C5P-G`W<(/Z3;;]4K5T%W:"=[:&22URCUR8J)BW1>-H!@#]4N93
M1%1%5"D7/@#$5,54QE3'5,A4R53*5-14?5ARM;)8M%B"6<=9R%G]4CQ;/5L^
M6S];)/K36T=43AH]7>)=N%ZY7L)>NE[&7KM>K61,94UE_5*R:;-IM&FU:<-L
MQ&S%;,9LQVS]4LYN,&]'<$AP@2)<<_U27W,8=AEV?G80)+!X=7UH)79]08-"
MA/U2O89"*$`HZA@>CA^.AX]B+7B/B)2)E(J4%YD5F?U2_5*1,N6C":D[JD^J
M_5(NN2^Y_[W]O?Z]NT6\1?U2(U/J4RI4251*5$M4WU3@5.%4XE3!6.-4Y%3E
M5,!8YE3W5/U2YU3H5.E4ZE3K5`Y8@%B!6+I8NUB\6+U8/UE`68A9'_I&6_U2
M1UM(6S9<<ER67$==YUTT7C5>-EXW7N->Y%[E7NM>=0'F7N=>Z%[]4OU2N63H
M';ID6QYC961E_5)E9?U29F5\96=E6OI9:.EHZFCK:.QH[6CN:.]HOVG+:<-I
MU6G$:<5ITVG&:<=IR&G):<II2FS]4M%L86XW;_U29'!F<)DB9W!H<&EPER)S
M<&IP:W!B*/U2<G,\!+ET''8V=KQVOG:_=L!VAW?<>-UX]7C>>-]XGOK@>.%X
MXG@L?2U]I"6I?9Q]G7V>?9]]H'VA?:)]_5*C?:1]IWU"@Y.#483]4E*$1(13
MA"*&QH;'ALF&W?K*AF8HR(8DCB6.)H[]4B>.*([]4EB/^_JGCXB/B8^ECZB/
MJ8^JCZN/K(^MCZ,M>8_]4I24E926E*4)_5*7E'\PF)1.F$^8&9G]4D&:*OOW
MFP2?&9\7GT"C[*,;IQRG]C8.J5*JV*TFL72U_5)UM<:\"[X,O@V^#KX/OA"^
MR$59UUK7@]F$V879_5+U2B#A(>$BX2/A).$IX?13_5*/:%%4JQ<751A56U49
M51I54P`;51Q5'54>51]5(%4A58M7B%<M(H58A[7'6$Q935G\6?U9_EG_6?U2
M_5)66U=;6%M96]Q;W5MS7)U<H5R>7)]<H%SF7%%=4ET]7B)?G!LC7R1?)5\F
M7R=?*%\I7RI?*U_]4D!?+%\M7RY?+U\P7]!DJ&64995EEF6799AEG&6;9?U2
MH66@99EEFF6G98@>9&C]4@!I`6G]4OU2Y6GI:?MI_&GJ:>MI[&GM:>YI[VGZ
M:?!I\6GR:?-I]&E2;%-L5&Q5;%AL5FS]4MULWFSC;-]LX&PB;B-N:&[?;JP`
M1&^4<)5PEG"7<)APF7!Y^IIPFW"=<)YPGW"@</-R\G(?<XASCW20=/U2_73^
M=/]T`'4!=1IY_5+C>.1XY7CF>.=XZWCH>.EXZG@=>:1\HWS4?<9]QWW(?<E]
MRGW+?<Q]S7W>!<Y]PR6X@;F!NH%N@]N#W(-HA&F$:H1KA&R$;81NA!DG)(8E
MAOU2`(?EAOF&YX;HANF&_H;JANN&[(9)!^V&H2CNAJ8H[X;]4A>'\(;QAI2+
M6XQ<C%V,+XZ1"#".,8XRCC..S(_-C\Z/KH^OC["/TPC/C]"/T8_2C]./_5+4
MCZD)II2GE*B4L)2IE*J4JY2LE*V4^Y?\E_U2+9DNF5"9+YDPF66:YIL,G`*<
M`YP$G`6<!IS]4L">))\EGQ:@,J`@IR&G(J<CI_XV):<9J22I&JD;J1RI':E2
M^QZI6JI;JERJ7:I>JC&L_5(IL?U2B+*)LHFU5SU6MM&WYK<RN#.X4KE3N=4.
M5+E5N?U2_5(IOBJ^*[XLOBV^DOLNOB^^,+XQOC*^,[[%/C2^F\0CQ23%_5(E
MQ2?%%LF@SV_7WT5PUW'7W$6,$W+7<]=TUYS9JMF=V9[9F0RKV9_9->$XX8WV
M-5,V4^ZMM%/)^3)4551$54551E5'5>072%5)5?U22E5+54Q5355.54]54%51
M59FUT5C]4M)8TUC46-58(5HB6B-::%MI6VI;XEM%7.Q<[5SN7.]<_5)B76-=
M]%UO4T1>15YY7QL<>E][7WQ??5]^7W]?@%^(`?U2@5^"7X-?A%^%7X9?AU^/
M7XA?B5_%9<9EJA['9<AER67*9<MES&6K'LUESF7C9<]ET&719=)ETV7$9=1E
MU67692!H(6@::1)I%&D5:19I&6D7:1AIR0)A^OU2$FH3:A1J%6H6:A=J&&H9
M:F%L8FQC;/5LJ2'V;/=L^&PI;A<%76]7;UAO66]:;UMONW#1<+QPO7#?N]!P
MOG"_<,!PP7#"<,-PQ'!LOJ%SHG.C<Y-T#74/=0YU$'41=1)UE?KE=R]Y_5)7
M>3!Y:'DK>3%Y6'FB^C)Y67G]4EIY,WE;>5QY77D>>:Y\KWP[?3Q]/7T'?@A^
M"7X*?@M^#'X-?@Y^#WX0?B)^$7X2?A-^%'X5?A9^%WX8?KCZ_5)&@T>#2(/A
M@X&$@X1U7_U2A82&A"J&T?HKAFN&&(<9AQJ'_5(;AQR''8<>AQ^'((<AAR*'
M(X<1*22')8<FAR>'*(<IARJ'[XQ)CDJ.2XY,CDV.3HY/CE".48Y2CE..5(Y:
MCE6.7X\"D`.0!)`%D-6/!I`'D-:/")`)D`J0"Y#7CPR0#9#(E,F4RI3+E,R4
MS93.E,^4T)31E-*44333E-24U936E->4XI38E`28!9@&F/U20YE$F82:CYJ%
MFH::+YP:G!N<')R]"AV<'IP?G""<(9PBG"S[(YPDG`Z<)9PKG"R<"YSNG?U2
MPY[8GMF>.)\YGSJ?.Y]3-#R?/9\^GS^?0)](H$R@**)1HE*B3*,CI$7[)*0Q
MIS*G,Z<8-S2G-:<VIT"G-Z?]4CBG/:<XJ3FI.JD[J3RI3*ESJG2J,PUUJG:J
M>:I!K$*L0ZQ;K?U2USFFBURMY:WFK>>MZ*WMK3"Q?CLQL92R4;;]MOZVZ;?]
M4K.YA+F4N?U2G+G]4H6Y`+PWO%>\5+YHOE6^7+Y6OE>^6+Y9OEJ^6[XTQ7Y`
M-<7]4CG%-L4WQ3C%Y<A9R?U2.LD[R2C0B=']4HK1B]&,T8W1O-*CU403I-63
MUY37E=>6UY?7N=E/X5#A4>%VX_U2^U.#4SA4751Q5?U2=U5X50?ZPU5Y57I5
M>U5\57)5?56@57Y5?U6`58%5@E6#59Y5A%6%5895AU6(59-7E%>55^]7\%?]
M4HU8CUB06)%8DEC>6.%84UEF&4I:2UI,6E%:35I(6G1;=5L@7"%<I5RF7'-=
M=%U07E%>4EY37MM?W%\@'-U?WE__7_U2_5+?7^!?(1SA7^)?XU_D7^5?YE_G
M7^A?Z5_J7P=F"&8)9@IF"V8,9@UFUQX:9@YF#V809AQF)VAF:)AHF6@S:21I
M)6DF:?U2X0(^:F3Z/VI7:D!J06I8:D)J0VI$:D5J1FKB`D=J:VQL;!!M$6V^
M(75N[VYJ;VMO_5)L;VUO;F_O</!P\7#R</-P]'#U</]P]G`"<?=P(G/$<\-S
M*'5\!"!V)78B=B-VZW;C!/EW^G>9>9IYFWEC>?U27GE?>6!YG'EA>9UY5'Y5
M?E9^5WY8?EE^6GX9?FI^6WY<?EU^9G[]4EY^7WX:?F!^87[]4F)^&WYC?A"W
M$;=,@YN#ZX/L@^V#[H.CA*B$IH3L!B^&,(8QAC*&,X9/AU&'4H=]AU.'5(=5
MAU:'5X=8AUF'6H=;AUR'5RE=AUZ'7X=OAV"'88=BAV.'<H=DA_U2;H>UBV6.
M9HYGCFB.:8YJCFN.;(X.D$.0_5(/D$2019!&D$>02)!)D!"02I!+D$R039#?
M"$Z03Y!0D%&04I!3D%2059!6D%>06)!9D%J0'9!;D%R079`&^_U2_I3_E`"5
M`94"E0.5!)4%E0:5!Y48E0B5"97SE`J5"Y4;E0R5#94.E0^5$)4/F&&8>9C!
MFJR:K9I#G$2<19Q&G$><2)Q)G&2<2IQ+G$R<39S'"BW[.9Y7GUB?69]?GUJ?
M:J`KHEVB7J)?HOU28*)AHEBC6:-*I$ND3*1-I$ZD5Z>SIK2F;J=;IURG_5)=
MIUZG_5)LISVI5*D^J56I5JD_J5>I6*E9J5JI6ZE<J8BJB:K]4EBL6:Q:K/U2
M9ZUHK6FM:JW]4FNM;*W^K?^M`*X!K@*N`ZX$K@6N.;$ZL3NQ/+']4OU2LK*S
MLK2RM;*VLK>RN+(\/:*U8;9BMA2W_5+KMT*X2+C]4D.X3KA$N$6XM+FUN?U2
M_5+]4K:Y_5+ANP6\_5)S/IJ^_5*;OIR^G;Z>OI^^FON@OJ&^HKZUOJ.^I+[]
M4J6^IKZGOJB^K[ZIOJJ^J[ZLOJV^L[[]4J#$5L4TR2<1/,D,R_U2/L^CSS#0
M,="7T9C1F=&:T9O1LM6KU:S5_-GHV>G9ZMGQVC_<SM]MX6[A;^%PX7'A<N%S
MX;Y+>.,ZZV=4^B=D5&54!U;$5<55QE7'5<A5R57E5<I5RU7]4LQ5S57.5<]5
MT%675YI7FU?J6.Q8[5CW6.Y8[UA;65Q975EM6FY:_5)O6H%;@EM/7*U<"MI^
M76E>5&!58%9@5V"K`5A@66!:8%M@7&!=8/U2_5)>8%]@.V8V9CQF/68^9C]F
M0&9!9D)F2P)#9D1F168W9OU2_5)&9D=F2&9)9BUHI6@]:3]I;FSG:G5J=FIW
M:GAJ>6IZ:GMJ?&J.:GUJ?FIR(']J@&J!:H)J@VJ$:H5JAFJ':HAJB6J*:HMJ
MC&IO;'!L<6QR;"IM*VTL;2UM+FTO;3!M,6V#;H1OA6^3;_U2AF^';XAOB6^*
M;XMO-G$X<3EQ.G'B`SMQ/'$]<3YQ/W']4D!Q07%"<=YSWW/@<^%S2G5+=4QU
M375.=4]U4'4G=OEV^G;[=IAWF7>:=_U2'GB>>?=YGWF@>?!Y^'GY>:%YHGFC
M>:1YI7GZ>?MY_'G]>?YY'WK_>0!ZC'H!>L)\PWS]4M-\3GVO?K!^L7ZR?K-^
MQGZT?OU2M7ZV?K=^N'ZY?KI^NWZ\?KU^OGZ_?L%^P'["?L-^48)2@E."5()5
M@EJ#4(-1@WB#^(/Y@\:$RX3,A,V$SH3/A-"$T832A-.$U(35A/U2-X8XAG.&
MD(>1A[^'DH>3AY2'E8>6AY>'F(>9A[TIFH>;AYR'G8>>AY^'H(>AAZ*'HX>D
MAZ6'_5*FAZ>'OXO`B\&+PHO#B\2+Q8O&BW6,0XT2C9^-D8WV^I*-DXV4C7Z.
M?XZ`CH&.@HY,CV./P)#!D,*0.I7#D,20Q9#&D!4NQY#]4LB0<Y#)D,J0RY#,
MD,V0#@G]4OU2SI#/D-"0T9#2D-.0U)#5D#N5/)4]E3Z5_5(_E4"5095"E4.5
MP0E$E465695&E4>52)7]4DF5$YB"F(.89IEGF66<$S-FG-D*=9QTG&><;9QV
MG&B<:9QJG&N<3YQLG/B=19[X,T:>Y)Z%GV^?<)^"H(.@A*"+H"VB:*)IHG>B
M9*)JHOU2\J+BHF.C9*-EHV:C/3IGHVBCV#7]4G*D?:1IIH2GAJ>'IXBGGJ?]
M4HFGBJ>6IXNGC*>-IWFI@ZEZJ5VI>ZG]4I^J2`V@JJ&JHJK\.&JL:ZQLK&VL
M;JQXK?U2>:U\K2&N(JXCKB2N.3HEKB:N4;%2L5:Q_5)+/.&R_5+]4M:RU[+8
MLMFRM;5LMF^V<+:\M[VW[;=;N%RX7;A>N(:YA[GMN?U2[KG]4@Z\#[S]4BV]
M*KTNO<R]^;[ZOON^_+ZY/_V^&[_^OO^^`+\!OP*_`[\AOP2_!;\&OP>_"+\)
MOPJ_"[\,OPV_#K\/OQ"_$;\2OQ._%+\5OWO%?,5]Q7[%ST!_Q8#%9L6!Q8+%
M@\6RR/U2?\ERR5K)Z\H5R_U2%LO*^Q?+_5+%R\;+Q\N(S(G,_5**S(O,C,R-
MS-_._5([T#S0/=`^T#_00-!!T$+07-&OT:G1JM&KT:S1M=&MT:[1XM(DU:Y$
MQ-7]4NK7T]?4U]77AMG]4H?9_=D%VTG<7]_3W]7?BN&+X8SAC>&.X8_AD.&1
MX9+AD^%]XW[CZTO]4OU2[.1;Y8?OAN_]4D931U,"5&U4;E1O5`U6#E8/5A!6
M$5825A-6%%:?5Z!7H5>C5R%8(EA\AI58EEAA66=9D5J26I-:E%J*6XM;]ULD
M7+!<L5R.701>:EYK7FQ>;5[H8`QAZ6#J8`UA_5+K8.Q@[6#N8.]@\&#Q8/)@
M%F'S8`1A'6'T8/5@]F#W8+`<`F4#901EFF9\9L5F?69^9G]F@&:!9D`?0A^"
M9H-FA&:%9H9FAV:N:$UIL&K<:K9JMVJX:KEJNFJ[:MMJO&J]:KYJ_5*_:L!J
MP6K":L-JSFH!`]EJQ&K%:MIJQFK':LAJR6K*:GYL>VQ.;4]M4&U1;5)M4VU4
M;55MCV[\;J9OIV^H;R-PBW']4HQQC7&.<8]QI'&96"1S1G-'<TAS_7/^<_U2
M;G5\=6]U<'5Q=7)U*78J=E]VHG<P>"MX87H">@-Z!'H%>@9Z!WK]4@AZ"7IB
M>@IZ"WH,>@UZ#GIC>B=Z#WK]4AMZ9'H0>A%Z@7H2>F5Z$WK.?"E_Q'XJ?_U2
M*W\L?RU_+G\O?S!_,7\R?S-_-'_]4C5_-G_C?C=_.'\Y?SI_.W]-?SQ_/7\^
M?_U2T('1@56#`H0$A/R$!X7]A/Z$_5+_A`"%"(4!A0*%-84#A02%_5([AHF&
M@8:"AC.ZZX?LA_U2[8?NA^^'_5+PA_&'\H<K*O.'%BKTA_6'2U/VA_>'^(?Y
MA_J'^X?\A_V'_H?_AP"(&RH!B`*(`X@$B`6(!H@'B"<J"(@)B`J("X@,B`V(
MUXO8BRF-G(WXC9B.I(Z9CIJ.FXZ7CIR.]2R=COU2GHZ?CF6/UI`@"3*1,Y$T
MD8(N-9$VD3>1UY#]4MB0.)$YD3J1.Y$\D3V1/I$_D4"1V9!!D4*1(0E#D421
M>BY\E7V5?I5_E8"5@96"E?U2@Y6$E865AI6EE8>5B)6)E8J5BY6,E8V5CI7]
M4OU2CY7]4I"5D962E9.5E)65E?U2*3&6E5:85YCAF`Z9#YEZF7N9BYGRFO.:
MDYR4G)6<EIR7G*V<F)RKG'N<F9R:G)N<A9R<G)V<V@K]4JR<>9R>G*2<_9WK
MGNJ>CY^0GX:?AY^(GZR@K:#LHG.C=*/]4JJDJZ2LI-&FUZ:YI[JGNZ>\IXZI
MCZF0J7RID:F2J9.IE*E4^YJIE:F6J9>IO:K'JKZJ_5*_JOU2DZQ>;8:MAZV(
MK8FM0:Y"KD.N1*Y%KD:N2JY'KDBN2:YKL6:Q_5)GL:L[:+&L._U2_;+^LO^R
M`+,!LP*S`[,$LP6S!K,SM<*UT+5T^Y6VEK8UMS:W9[AHN&FX:KARN&NX;+AM
MN&ZX;[@BNOU2_5(CND&Z)+HENB:Z)[HHNBFZM[G]4OU2_5+:O,^]VKV)O[>_
MBK^+OU[`C+_]4HV_CK^/OY"_D;^2OY._E+^VOY6_EK^7O_<__5*8OYF_FK_J
M#_U2F[^]OYR_G;^>OY^_P+^@OZ&_HK^COZ2_I;^FOZ>_J+^IOZJ__5*TQ+7$
MML2YQ;K%N\61Q;S%[LCOR);)E\ESR9C)F<GMRN[*WLNPS+',LLRSS+3,M<RV
MS,[[M\SCSKG/5=!^T%;05]!8T%G06M#]4L31Q='&T<?1R-')T>[1S]'*T<O1
MS-$)T]K[`],OU3#5,=4RU0[8#]@0V!'8$MC]4A/8%-@5V/_7']H@VB':+=K]
M4AO;'-L=VQ[;4]Q4W%7<5MQDW%G<5]S]4EC<:]^)%/U2Y]_HW^G?ZM_KW^S?
MEDKMW['AM.']4HKCC>.,X_+D\^3]4@AT%^>R%9_HH.G]4FWK?8.0\L3X3%-T
M5'54=E1)5DI62U9,5DU63E9/5E!645925E-65%955E96I%>I5RI8*UBS6L%:
MF%O[6_Q;O%R670I>_5*B8?U2@6&"88-AA&&%889AAV&(88EABF&+88QA\1R-
M8=%A%&7)9LIFRV;][<QFS6;.9L]FT&;19M)FTV;49M5F<6A-4V)I#FO^:O]J
M`&O]4@%K`FL#:Q5K!&L%:_U2AVR);&YM;VUP;7%M;OIR;7-M=&V=;KAON6^Z
M;\)QPW'5<<1QP''%<<9QBG6+=8QU9':,KD$D#7>H=SMX/'@]>#YX/WA`>&9Z
MRWJW>KAZN7JZ>F=ZNWIH>FEZ:GJ\>OU2VWR!?X)_@W^$?X5_AG^'?XA_B7^_
M^HI_BW_]4HQ_C7^.?X]_D'^A?Y%_UH&?@EB#A8,+A`R$-X4XA<[Z.84ZA3N%
M/(4]A3Z%0(5!A4*%_5)#A8J&BX:0B%F(6XA<B%V(7HB**E^(8(AAB&*(8XAD
MB).(98AFB&>(:(AIB&J(:XB5B&R(;8ANB&^(C"IPB'&(<HASB'2(=8AVB'>(
M>(AYB(`J>HA_*GN(J8A\B/&+ZXN*C#V-IHVGC;J._5*[CKR.O8Z1D9*1DY&4
MD961EI&7D=J0F)&9D9J1_5+]4IN1G)&=D9Z1GY&@D;^1H9&BD:.1I)&ED::1
MIY%;D0W[J)'+E?U2V@G,E4^6S97.E<^53I;0E=&5TI7]4M.5U)75E=:5UY78
ME=F5^I7:E=N5'/O<E?U2_5+=E=Z5WY7@E>&5XI7CE>25Y97;">:5YY6.F)B9
MF9G]4@J;_5(FFR>;O9S?G.(*OIS>G+^<P)S!G,*<GYS#G,2<Q9S&G,><XPK(
MG,F<XYS*G,N<S)S-G,Z<SYS0G-&<TIS3G"_[U)P$GF6>[IZ@GZ&?W:#>H(.B
M^J)_HX"CZ*3II.JDIHCAIOU2VZ?<I]VGWJ??I^"GX:?BI^.GY*?EI^:GG#?G
MI["IF*FQJ9FILJFSJ;2IM:FVJ;>IN*FYJ>*JXZKDJN6JYJKGJNBJZ:JMK,^L
MKJROK+"LL:R2K9.ME*UYKGLZ>JY[KGRN?:Y^KG^N@*Z!KH*N@ZZ$KI>QA+&%
ML8FQAK&'L2RS+;,NLR^S,+,QLS*S,[,TLS6S-K,WL]*U1+<`N(.XA+B&^WJZ
M>[I\NGVZ?KK]4G^ZA[J`ND.]-,!)$C7`-L`WP#C`.<`ZP#O`/,`]P#[`/\!`
MP$'`0L!#P$3`1<!&P$?`2,!)P$K`_5)+P$S`3<!.P.?%Z,7IQ>K%Z\7LQ>W%
M[L7WR)K)S<G(^Z/)SLDQRS++,\ODS/U2Y<SFS,C/=-!UT';0=]!XT'G0>M!A
MT=_1X-'AT>+1X]'DT>71YM'S$C'3/=4^U3_5]-7UU?;5_5(7UT'80MA#V$38
M1=A&V$?82-A)V$K82]C21KK91-HJW&W<=$?G^W[<;MQOW'#<<=QVW'G?H$K]
M4@3@^-\%X-KAV^'<X=WAWN'?X>#AX>'%XYKCF^.<X]CDV>3:Y&[E5Q5KYX/0
M_5+6Z;WI_5(NA?SM4_"W\(SUCO;_]793!E1^5(16A5:&5H=6B%:G5HE6BE:+
M5HQ6C5:.5H]6HU:05I%6DE:35JQ6E%:55I96JE>K5YY8J1@(60E9:%EI66I9
MFEG96MI:VUJH6P%<*%QW7+U<OEQ@8J!=HET/7H5>_F'_80!B`6(68@)B`V($
M8@5B!F('8@AB(F()8@IB"V(,8A1B*6)N80UB#F(/8A!B$6(28A-B&V4<91UE
M$V?_9@!G`6<"9P-G!&<*9P5G!F<'9PAG.FAS:&]I<&EQ:5)3_5*:;6!K:?HK
M:R1K+&LM:RYK+VLP:S%K,FLS:S1K-6M%:S9KDFR3;(AMB6V*;8MM/V[]4LIO
M]G'W<?AQ^7$K=/U2I'3.=/U2GG6?=:!UH76B=:-UI'6E=:9U&'=@>&%X8GAC
M>&1XO7J^>@M[OWK`>OU2#'N->@U[#GM>>P][$'O!>A%[_5+">NI\ZWSC?^1_
MY7_F?^=_DG]*@/U2Z'_I?^I_`8#K?^Q_[W_M?^Y_\'_Q?_)_\W_T?_5_]G_W
M?_A_^7_^?_I_^W_\?V.%9(5EA6:%9X5HA0N)#8F\!PZ)#XFD!Q2)U(C5B-:(
MUXC8B-F(VHC;B-R(W8C>B-^(X(CAB.*(XXCDB.6(YHCGB.B(Z8CJB.N([(CL
MB>V([HCOB`")\(@$C/U2!8SS^K6-^?K6CM>.V([9CJF1`)(!D@*2`Y($D@62
M!I(_D@>2")()D@J2MI$+D@R2_5+]4@V2_5(.D@^2$)(1DA*2-9(3DA22JI']
M4L&2%9(6DA>2'I8?EB"6(9;]4B*6(Y:5,226)98FEB>6*)8IEBJ6*Y8'EBR6
M+98NEN@)_5(OEC"62)8QEC*6F#$SEOU2-)8UEC:669B1F.>8N)FYF;J9NYG(
MF4V;B9M0FRB;^YS\G/V<_IS_G'@S`)T!G0*=Y)SEG`.=!)T%G0:=!YT3G0B=
M"9WFG`J="YT,G0N>])X*G[&?':$[^XNBC**/HHVBCJ(&HX:C(J4CI22E):4F
MI2>E**7QIKDW(Z@2J/U2$Z@4J!6H%J@7J!BH&:A+J!JH&Z@<J/U2':@>J!^H
M(*C*J:QURZG,J<VISJG]4L^I$*L1JQ*K$ZL4JP^K%:L6JQ>K,SD8J\:LGZV@
MK:2MH:VUKK:NMZZXKKFNNJ[0KL:NNZZ\KKVNOJZ_KL"NP:["KF#[I[&HL:FQ
MJK&KL:RQO+&ML:ZQP#NOL;"QL;'!.[2QLK%FLV>S:+-ILVJS:[-LLVVS;K-O
ML_U2/K4_M4"UZ+52MU.W5+=5MY&XDKB3N)2XE;B6N)>XF+C]4IFXFKB;N+>Z
MN+JYNOU2NKJ[NKVZ_5*\NHC[A_OKN^R[%KQ$O..\6+U3O52]X+VQP++`L\#J
MP/U2M,#PP+7`ML"WP+C`N<"ZP+O`O,"]P+[`O\#`P,'`PL##P/U2Q,#%P,;`
M_,#'P,C`R<#*P,O`S,"$P<W`SL#/P-#`T<#2P,K$R\0VQC?&G\8XQCG&.L9$
M0;[)\,F_R<#)]\KXROK*0\M$RP_-$,T1S1+-K4,3S13-%<T6S?U2_5+3S]?/
M_5*PT)C0D-"1T)+0E]"3T&31`=("T@/2!-(%T@;2!]):TUO33M5/U5#5&=8:
MUAO6_5(<UOU2&=<:UX83BMQNV&_89$9PV''8<MASV'38==AVV#K;.]L\VUK;
M/=M"VXO<H-R,W(W<CMRKW(_<=T>0W)'<DMRJW*]'D]R4W)[<J-S]4OU2`.(!
MX@+B`^($X@7BQ.+%XOU2KN.RX_U2_5+WY!/EGN:%YX"FR.=!ZX'K@NN#ZX3K
MQ.W%[<;ME>^6[Y?O6/!9\/U2J?*J\JORCO4#]K/V@EY34X-4A%2%5,Q6S5;.
M5L]6T%;]4M%6TE;:5K-7M%?]4A-9#EEK60-<85S!7,)<M5U`5)ABF6*:8IMB
MG&*=8IYBGV+N8J!BH6*&8B5E-&<U9U%G+6=BEE1G4F=M`C9G-V<X9SEG.F<[
M9VAG/&=N`G=HEH5^:7]I:6MJ:VMK;&MM:VYK;VM=:W!KA6MQ:W)K<VMT:W5K
M=FN$:W=K@VN:;*=MJ&VI;:IMJVVL;;=MK6VN;?U216[3;]1OU6_6;]=O)G(G
M<BAR_5(I<BIR!7-D(]!TMW7]4KAUN74B=R-W<WAT>(][$GL3>Q1[%7L6>Q=[
M&'MA>V9[9WL9>VA[&GMI>P1]!7W]4@9]_7Q0@%&`4H!3@%2`58!C@,3Z5H!7
M@%B`68!:@%N`_5)<@%V`7H!?@->"_5)@@V&#%X0YA(^%R(60A9&%F(:9AD2)
M18E&B5F)[HDK*T>)2(G]4DF)2HE+B4R)38E.B4^)4(E1B5*)4XE4B56)5HD5
MC)J,6(W\C?V-AI*'DHB2B9**DHN2C)+]4A^3C9*.DH^2D)*1DI*2DY(1^Y22
ME9+*D1B2_5*6DI>2F)*9DIJ2FY*<DIV2GI*?DD8O_5*@DJ&2FB^WDOU2EI9H
MEFF6C)9JEFN6;)9MEFZ6;Y9_EH26<)9QEH66<I9SEG26=99VEOU2=Y9XEGF6
M>I9[EGR6'ON4F-69*9LKG2R=+9TNG2^=,)T^G3&=,ITSG32=-9T1GE,+P)]"
MH4.A1*%%H4:AC*.-HXZCCZ.0HY&C8Z5DI66E_5)*^_U2]J8VJ#>H+*@XJ#FH
M_5(ZJ..IXJGUJ4>K_5)(JTFK2JM+JTRKJ*VIK:JM_5(+KP:O<Z\,KPVO#J\/
MKQ"O_5(1KV+[$J\4KQ6O%J_]4A.O%Z_9L=JQV[']4MRQIK.GLZBSJ;.JLZNS
M_5)M^ZRSK;.NL_U2_5*OL["SL;-$M46U][7XM6NW;+=AMQ*XK[BPN+&XLKBS
MN+2XM;BVN"*YZKKKNNRZ[;H]#^V[&[Q'O.B\T+WGO>B]Z;U.P4_!4,%RP5'!
M4L&G^R804\%4P57!5L%7P7?!6,%9P5K!6\%<P6[!7<$G$/U27L$H$%_!_5+7
MQ(G&BL;]4K[[B\:,QHW&CL:\^X_&_5*:QI#&D<:2QI/&$LKQR?U2_LK[RE?+
M2<U*S4O-3,W]4DW-6<U.S4_-],YESZ;0I]"HT"+2(]*+TXS3C=..TUC5_5)9
MU3O6/-8]UC[62->4V)78EMB7V)C8?=K^V7[:?]K]4EO;7-ODW,'<_=S"W-;<
MP]S$W/U2W-S%W,;<Q]SAW,C<R=S*W,O<\D?,W,W<->`VX$?@-^`;XASB'>(>
MXA_B(.)[XGKB_N+&X\?CR./)X\KC_5*@YZ'GS.C-Z/'IU^E"ZT;KH^NEZZ;K
MR^W,[2;N)^XH[BGNKN^O[[#O<_#]4GSP=/#]4H#R=?!Y3/U2S_+]4H_V<%F%
M4Y=6]E;W5OA6^E;[5KI7NU>\5[U7-%@U6*)8%%D166Y9;UD(6[A;"5V]7;Y=
MB%[^8GH=_V(`8P%C`F,#8P1C!6,&8_U2!V,(8PEC"F,+8PQC#6,.8P]C_5+]
M4OU2+&5K9_U2;&>'9VUG>&B+::1KI6NF:Z=KOFNH:ZEKJFN-:ZMKK&N_:_U2
M+`.M:ZYKI&RE;,=MR&W);;S0RFW+;<QMS6W.;1EOYF],<DUR3G(&<_U2S77.
M=<]UT'5<)(%X@G@S6&I[:WNR>VQ[;7O,>ZY[LWN1>_U2;GNT>V][R8"G@*B`
MJ8"J@*N`K("M@*Z`KX"P@&"`L8#A@>."]H+9)J^%L(6QA;J%LH6SA4R&_5*@
MAJ&&L(FQB;*)LXFTB>OZM8FVB;>)N(FYB;J)<BN[B;R)O8F^B;^)WXG`B<&)
MPHG#B<2)>"O]4L6)QHG'B<B)R8G*B3R*RXG,B<V)SHG/B=")T8E:+!V,'HQD
MC66-Q8W&C<>-_XW_C@"/`8\"C_627)/VDO>2L)+XDOF279-0D_J2^Y*BDOR2
M_9+^DO^2$_L`DQ_[P9;"EL.6Q);%EL:6QY;(ELF6RI;+EN_CUY;,ELV6SI8B
ME\^6T);]4M&6TI;IEM.6U);5ECB8.V-]FV]8H9M3G52=^PI5G3R=5IW]4F:=
M_`I7G5B=69U:G5N=9YU<G?U2_5)JG5V=/9U>G66=X9_-GQ'S;Z%PH1JCFJ.;
MHYRCGJ.?HS_[CJ7]4OVF_5)>J%^H8*AEJ&>H:*AIJ/U2:JB/J&NH;*AMJ/>I
M^*GYJ>2I^JFQJW6K=JO_K`"M`:T"K0.MKJVMK5&O4J_]4E.O5*]5KU:O5Z]8
MKUFO6J];KURO7:]>KU^O8*]AKV*O8Z]DKTRO9J_QL?*Q\K/SL_2S];/VL_>S
M^+/YL_JS3+5+M1NVSK:SMG^W>?M\^QJXQ+C%N,:XQ[C(N,FX_5(9NQR[&KM,
MO(Z\?KWKP>S![<'NP>_!\,'QP=C!V<':P=O!\L'SP?3!!\+]4JS[_5+UP17"
M_5+VP??!^,'YP?K!^\'\P?W!_L&GPO_!`,(!P@+"`\($P@7"Z<3JQ.O$WL;?
MQOU2X,;AQN+&X\8^RC_*0,I!RG'+<LMSRXC-B<V*S8O-C,V-S8[-C\V0S9'-
MDLW]4O'/OM"_T,#0P=#"T,/0;M$WTE?2.-(YTCK2.](\TCW2/M(GTC_2_5+]
M4L#3P=.^1&?5_5)HU5C69=99UEK6)-?-V,[8S]C2V)_:(MI]VW[;_]PEW0#=
M`=T[2`+=`]T$W2A1!=T&W0?=%MT(W1?="=T*W4!("]T,W2G=.D@-W?U2#MT0
MW1'='=T2W1/=_5(4W17=C=]4X%7@5N`SXC3B->(VXOKBX^/FX^WCY^/HX^GC
MZN/KXR?E(.7X^RKGR>?]4LKGR^?9Y\SGS>?.Y_U2X>@;ZASJ'>H>ZD?KT>O)
MZ]#MT>T_[D#N0>X)_$+NQ.^;\)+PD_"63)3PE?#]4OU2\_+T\O7R]O)@]9[U
MH/6A]1SVG_964Q)7'U<55Q97%U<,^AA7PE?#5\17H5@;61Q9<5D36Q=>CUY?
M8V!CK&/]4OU286-B8V-C9&-E8_U2F6>:9YMGG&>=9YYGGV>@9]IKVVO<:]UK
MWFO?:]5MUFW7;=AMX&VT;OU2;G)O<G!R8W3]4M5UUG77==AU,'>U>[9[P7OW
M>Z`%RWOH>_U2Z7NW>Q5]YH#G@.B`Z8#J@.N`ROH+@PR#9(/4A=6%UH78A:6&
M6U,/BA"*_5(1BA**$XH4BA6*%HH7BAB*&8H:BB^*&XH<BC^*'8H>BBR*'XHD
MC*2,I8Q1M?Z-$8\2CQ./5(]>DR&3/Y-`DT&30I-#DT23()-%D_U21I.PDT>3
M5Y,!D[&36I-(DP27!9?U,4^74)<&EP>7")<)EPJ7"Y<,EPV7#I</EQ"7$9<S
MF#28-9C\F/V8L)NQF[*;LYL!"WN=?)U]G7Z=?YV`G8&=@IWYGMJ?H:']4OU2
MK:.NH_U2R*7)I<JE@JB#J(2HA:B&J(>HB*B)J(JH_5('J@BJ`:H)J@*J"JH+
MJ@RJIZN8JYFKFJN;JYRK4#F=JQJMLJVPK[&O%#NRK[.OM*^UK[:OP*^WK[BO
MN:^ZKQVP#+(-L@ZR-;(/LA"R$;(2LB*T([0DM/U2);0FM">T*+0IM"JT*[0L
MM"VT+K12M5.U&;:_MHNWC+<CN"2X\;C8N'_[3KM/NU6[4+M1NU*[4[L"NU2[
M\;LDO-&]?,)]PG["?\*`PI_"@<*"PH/"A,*%PH;"A\*(PIO"B<**PHO"C,+]
M4J'"C<*.PO/$],3UQ"3')<<FQR?'*,<IQRK'_5(KQ\W(`<F->'#*@,N!R\#-
MP<W"S</-Q,W%S<;-Q\W(S?[/_5+9T-S0VM!UT5C26=):TEO27-+LTQH3\]-R
MU7/5@M:#UBK7*]<LURW7]M@`V??8^-CYV/U2E-N5VY;;&]R&W4S=3=V#W?U2
M@MU.W4_=4-U1W8'=ATA2W5/=5-U5W?U25MU7W85(6-U;W5S=7=U>W5_=8-UA
MW7S=8MT\%/U28]UDW7/@1>)&XD?B3.(2X_U2$^,YY`/D#>0PY=7EP.;RY_/G
M].?UY_;G]^?ZZ/OH1>I&ZDGKY^OHZ]CMV>U5[E;N5^[:[]OOW.^X\+GPNO"Q
M3+OPB?*\\##S,?,R\S/S_5(T\S7S-O-'3C?SLO60]B;VHO8X]_U2+E?]4B]7
M,%<J5RM7R5<W6"!9<ED?6V5<RES`7<%=PEVW8[ACN6.Z8[MC_5+]4KQCO6.^
M8_)CM6>W9[AGWV.Y9]5GNF>[9TIH\FOS:_1K^FOU:P)LXFWC;8YRBW+D=>MU
MY74U=Y-XZGOK>_U2['OM>Q=\[GOO>_![#H$/@1"!&8$8@1&!$H$3@<?Z%($5
M@6L&%H%E@^J%ZX7LA>V%_5+NA:R&PHIIBH&*:HIKBFR*;8INBF^*<(KT!W&*
M<HISBHR*=(IUBG:*)(\JCXZ3KY./DY"3D9/]4I*3DY.4DY63EI.7DYB3F9.:
MDYN3G),YESN7.I<\ESV7/I<_EW"70)=!E\";P9NDG9>=I9V8G9F=FIW]4IN=
MIIV<G9V=GIV?G<[=R)V@G1F>#9^_H^FEZJ6BJ*.HI*BEJ*:H%:H7JK^KP*O!
MJ\*KPZO$J\6K#6PCK;ZM`[`$L`6P!K`'L`BP";`*L`NP#+`@L`VP#K`/L/U2
M)K(GLBBR7;1>M%^T8+1AM&*T8[1DM&6T5[7/MM"VF;>:M^JXZ[CLN'Z[?[N`
MN_U2_5*!NX*[\[LEO)^\H+SSO`"]Z\+LPNW"[L+OPOU27!#PPO'"\L+SPO3"
M]<+YPOK"^\+\POW"_L+_P@##KOL!PP+#`\6&QWG'_5)ZQWO'?,>$QWW'?L=_
MQX;*A\H`RP'+B,N)RXK+]<W]4B7.]LWKT.S0[=#NT(<2[]#PT&S2(=0BU"/4
M)-0EU";4>]5\U9'6DM:3U@[9#]D0V;/;-MS&W:'=HMVY2*/=S-VDW:7=IMW+
MW:?=_5*HW:G=JMW]4JO=K-VMW;](KMVOW;#=C."-X([@\?N2X(_@4N)3XE3B
M5>(IY/U2\^7TY0WH#N@/Z!#H%.EQZG+J#^P$[`;L_5('[-SMW>UM[GGN;N[]
M4NSOW?#>\-_PX/#A\.+PX_#D\#KQY?#/3.;P:_-L\TZ79$Z]];[UO_4T]K]/
M$OA`5T%7`F0#9`1D!60&9-=GS&>8:09L!VRO;+!LZFWR;:)RHW*D<G9T]77V
M=?=U_5([?"5\.GP\?#U\/GPW@3B!.8$Z@3N!/($]@3Z!/X%+@?U20($B@V>#
MTX/ZA?U2O(K]4OU2I8H'"+:*_5*FBKN*IXJHBJF*JHJKBJR*OXJMBJZ*KXHN
MC`".G9.>D\N3S)/-D\Z3SY/]4I^3T)/1D]*3TY/4D_U2_5)=EUZ77Y=@EP4+
MNIV\G08+M9V]G;:=MYVXG:B=,OO^GOR>X:'$H\6C%*:NJ*^HL*BQJ+FHYZM&
ML/U21[!(L$FP'K`?L$JP2[!,L$VP3K#]4D:R2[*0M)&T_5*2M).TE+1;M?*X
M^+CYN)2[I+N7NYB[*;RNO*^]6<-:P_U26\-<PUW#7L-?PV##8<.JPF+#8\-D
MPV7#9L-GPVC#:<-JPVO#;,-MPV[#;\/]4K+'L\>TQ_D0M<>VQ[?'N,>YQ[K'
MN\>(RKA"&<X:SAO.%L\,T0W1#M$/T?U2@]*$TH72@]6$U;#6_5(FV2?9-MDH
MV2G9_5+]4N?=Z-WIW5,4ZMWKW?U2[-WMW>[=[]WPW?'=#-[RW?/=]-WUW?;=
M]]WXW:/@I."EX*;@I^#]4ESB_5)+Y.'D%>;]4A;F%^8LZ"WH(NDCZ9;JE^K]
M4B[L,.PQ[/U2W^V+[HSN_5*-[OSO_>_^[__O%_$M\1CQ\TP9\?U2$O$:\1OQ
M'/%I%OU2E_/E%ICSF?/]4L3V3U?-5\=='&0=9!YDYV?I9^IGZV<5;/%O\F^V
M<J!X2GP@?6"!88%!@6*!`X8$AMF*VHK;BMR*W8K]4MZ*WXK@BN&*XHH2"..*
M_5(QCP64!I0'E'*7BI>+EXB7_5*,EXV7CI>/EY"70IA#F/U2P9W"G<.=Q)W+
MHR*F_5+]4L.HQ*C%J,:H'JHEJO.K]*O]4O6K.*U(K<JM3SMZL'NP5;)6LK&T
MLK2SM/U2M+2UM*2W`+D!N0*YK+O]4K.\ML.WP[C#N<.ZP[O#O,.]P[[#O\/`
MP\'#PL/#P\3#Q</&P\?#X\?DQ^7'YL?GQ_U2M<JARI7+.\X\SCW./LX4SR#1
M(=$BT2/1)-&6TI?2F-*4U)74EM27U)C4C]60U;S6.]<]V?U2W]L>W"/>)-Y)
MWB7>)MXGWBC>)4DIWBK>+MXOWD[>,-[K^S'>,MXSWC3>-=XVWOU2-]Y0WCC>
M_5(YWCK>.]X\WCW>/MZXX+G@8N)CXD'C;>3]4E+F-^;;YC_H-.E;ZT;L6NQ;
M[.'MXNWC[>3MI^ZH[JGN#_`K\%;Q5_%8\5[Q6?%:\5OQ7/']4FCQ_5(L].+S
M\_/2]5;VSO9A]YOYM/E<5Q#ZTE=Q6'-9+%N47OU2/V1`9/EG^F?]9_MG'&P=
M;/]M`&[W;_Z?_5*V=U1\=X%Y@7J!>X%I@P*+`XL$BP6+!HL'BPB+"8L*BPN+
M-8O]4CF/'I0?E""4(93]4B*4(Y0DE"R4LY>UE[:7MY>XE]"=^I\'HKVBUZ/2
MH]NHUJA=5T.MSZVCL*2PI;"FL*>PJ+"IL%VR7K+)M,JTR[3,M`:Y![G]4L6[
M];NTO+B\M;S]PW<0_L/_PP#$`<0"Q`/$"<0$Q`7$!L0'Q!'($L@3R!3(%<AW
M0IC+F<L\T2W1+M']4KO4O-1X$SW71]E(V4G92MGAVN?:Z]L@W#C<8MYGWFC>
M:=YJWFO>;=YNWF_><-YQWG+>C]YSWG3>==YVWG?>R>#*X.9*R^#,X,W@4>/]
M4OU21>59Z%KH6^A`Z<_J7NM[[)/MO.X6\##P_5*-\8[Q+TV/\9#QD?&2\9/Q
ME/&5\9;Q(_04]-OU"O?.^&97:%=G5]-78V0$:)YI)FPJ;&Q\9'R/@9"!-(,.
MAB6+)HLGB_U2*(L,+/U2*8LJBRN++(L^CT*40Y0SE,&7PI?#E]:=UYWAJ.*H
M*ZK1K<RPS;#.L,^PWK3?M."TX;3VNRS$_5)4Q"W$+L1!R$+(Q\J@RZ'+<,YQ
MSG+._5(TT371-M&FTLS4_5*9U?3;F]Z>WI_>H-ZAWJ+>H]ZDWJ7>IMZGWJC>
MV^#<X-W@U^#>X-_@6>-&YV7H2>G]4MWJE>R6[)?LU.[6[B;P1TV(%LCQQ?'&
M\<?Q4?12]%/T5/15]-[U_5)M5]57<F2N=`]V:WQM?&Y\>'R8@9F!FH%$BUR+
M18L!CEB4691:E/U2V9?6E]J=WYW;G0.@[Z@V.#.JTJWAL&^R9+4.N5#$4<12
MQ%;(5\A8R/U2@<Z"SAW/'L]#T:K2_=O]4L;>Q][9WM?>_5+(WLG>RM[+WMK>
M_5+,WLW>SM[/WM#>T=Z\WN'@XN#CX*GD3N5WZ/U2_5*L[*WLMNWE[OCQZO&-
M\NOQE?1N5]A7@V2C:3!L#VYY?'I\IX&H@:F!JH$9AE"+48M2BQ4L:(M3BU2+
MXIO<G16L%JQ/K?6P]K#WL/2TS+</N6;$9\3]4FC$I,N+SHS.^M3FWNW>[M[O
MWO#>_M[GX.C@L^3DY(/H[.W]4A;R_5+]4A?RP_2L].WU_5+]4K3X_5**9(MD
M-&P4;M]RNW=_?(%\K8&N@6*+;HO]4FZ4_5(7FN:=$)\9K/U2$+GRO7;$=\25
MSI;.`-\!WS'?[?L<WVWC].[U[CWP,O(S\O3U_5)S5S=L_5)QBP^Q_5(.L1&Y
MA<04WQ7?%M\7WQC?&=\:W\/D0O)#\D3R2/+[]*5IN&RR@3V#<HOGE^B76:8Z
MJA2Q_[3`O(W$A!".Q/U2(M_]4OU2!.\I[U'R9O(.]1/\_5*;9)QD%G:&?(=\
M_5(LWS#?*-]?Z?U2?I09L0K5-M_\X&WR;O+&^;4:>XL&M9_(,O4-U8M\.]_]
M4CWU/-\]WP```````````````````````````````````````$"H0:A"J%RI
M0ZA$J$6H1JA'J$BH6:E)J$JH2ZA,J$VH3JA/J%"H4:A2J)*H4ZA4J%6H5JA7
MJ%BH6:A:J%NH7*A=J%ZH7ZA@J&&H8JACJ&2H9:AFJ&>H:*AIJ&JH:ZALJ&VH
M;JAOJ'"H<:ARJ'.H=*AUJ':H=ZAXJ'FH>JA[J'RH?:A^J("H@:B"J(.HA*B%
MJ(:HAZB(J(FHBJB+J(RHC:B.J(^HD*B1J&6IEJF3J)2HE:A`J4&I0JE#J42I
M1:E&J4>I2*EAJ6*I9JEGJ6"I8ZEDJ5JI2:E*J4NI3*E-J4ZI3ZE0J5&I4JE3
MJ52I0(%!@4*!0X%$@46!1H%'@4B!28%*@4N!3(%-@4Z!3X%0@5&!4H%3@52!
M58%6@5>!6(%9@5J!6X%<@5V!7H%?@6"!88%B@6.!9(%E@6:!9X%H@6F!:H%K
M@6R!;8%N@6^!<(%Q@7*!<X%T@76!=H%W@7B!>8%Z@7N!?(%]@7Z!@(&!@8*!
M@X&$@86!AH&'@8B!B8&*@8N!C(&-@8Z!CX&0@9&!DH&3@92!E8&6@9>!F(&9
M@9J!FX&<@9V!GH&?@:"!H8&B@:.!I(&E@::!IX&H@:F!JH&K@:R!K8&N@:^!
ML(&Q@;*!LX&T@;6!MH&W@;B!N8&Z@;N!O(&]@;Z!OX'`@<&!PH'#@<2!Q8'&
M@<>!R(')@<J!RX',@<V!SH'/@="!T8'2@=.!U('5@=:!UX'8@=F!VH';@=R!
MW8'>@=^!X('A@>*!XX'D@>6!YH'G@>B!Z8'J@>N![('M@>Z![X'P@?&!\H'S
M@?2!]8'V@?>!^('Y@?J!^X'\@?V!_H%`@D&"0H)#@D2"18)&@D>"2())@DJ"
M2X),@DV"3H)/@E""48)2@E."5()5@E:"5X)8@EF"6H);@ER"78)>@E^"8()A
M@F*"8X)D@F6"9H)G@FB":8)J@FN";()M@FZ";X)P@G&"<H)S@G2"=8)V@G>"
M>()Y@GJ">X)\@GV"?H*`@H&"@H*#@H2"A8*&@H>"B(*)@HJ"BX*,@HV"CH*/
M@I""D8*2@I."E(*5@I:"EX*8@IF"FH*;@IR"G8*>@I^"H(*A@J*"HX*D@J6"
MIH*G@JB"J8*J@JN"K(*M@JZ"KX*P@K&"LH*S@K2"M8*V@K>"N(*Y@KJ"NX*\
M@KV"OH*_@L""P8+"@L."Q(+%@L:"QX+(@LF"RH++@LR"S8+.@L^"T(+1@M*"
MTX+4@M6"UH+7@MB"V8+:@MN"W(+=@MZ"WX+@@N&"XH+C@N2"Y8+F@N>"Z(+I
M@NJ"ZX+L@NV"[H+O@O""\8+R@O."](+U@O:"]X+X@OF"^H+[@OR"_8+^@D"#
M08-"@T.#1(-%@T:#1X-(@TF#2H-+@TR#38-.@T^#4(-1@U*#4X-4@U6#5H-7
M@UB#68-:@UN#7(-=@UZ#7X-@@V&#8H-C@V2#98-F@V>#:(-I@VJ#:X-L@VV#
M;H-O@W"#<8-R@W.#=(-U@W:#=X-X@WF#>H-[@WR#?8-^@X"#@8."@X.#A(.%
M@X:#AX.(@XF#BH.+@XR#C8..@X^#D(.1@Y*#DX.4@Y6#EH.7@YB#F8.:@YN#
MG(.=@YZ#GX.@@Z&#HH.C@Z2#I8.F@Z>#J(.I@ZJ#JX.L@ZV#KH.O@["#L8.R
M@[.#M(.U@[:#MX.X@[F#NH.[@[R#O8.^@[^#P(/!@\*#PX/$@\6#QH/'@\B#
MR8/*@\N#S(/-@\Z#SX/0@]&#TH/3@]2#U8/6@]>#V(/9@]J#VX/<@]V#WH/?
M@^"#X8/B@^.#Y(/E@^:#YX/H@^F#ZH/K@^R#[8/N@^^#\(/Q@_*#\X/T@_6#
M]H/W@_B#^8/Z@_N#_(/]@_Z#0(1!A$*$0X1$A$6$1H1'A$B$281*A$N$3(1-
MA$Z$3X10A%&$4H13A%2$5816A%>$6(19A%J$6X1<A%V$7H1?A&"$881BA&.$
M9(1EA&:$9X1HA&F$:H1KA&R$;81NA&^$<(1QA'*$<X1TA'6$=H1WA'B$>81Z
MA'N$?(1]A'Z$@(2!A(*$@X2$A(6$AH2'A(B$B82*A(N$C(2-A(Z$CX20A)&$
MDH23A)2$E826A)>$F(29A)J$FX2<A)V$GH2?A*"$H82BA*.$I(2EA*:$IX2H
MA*F$JH2KA*R$K82NA*^$L(2QA+*$LX2TA+6$MH2WA+B$N82ZA+N$O(2]A+Z$
MOX3`A,&$PH3#A,2$Q83&A,>$R(3)A,J$RX3,A,V$SH3/A-"$T832A-.$U(35
MA-:$UX38A-F$VH3;A-R$W83>A-^$X(3AA.*$XX3DA.6$YH3GA.B$Z83JA.N$
M[(3MA.Z$[X3PA/&$\H3SA/2$]83VA/>$^(3YA/J$^X3\A/V$_H1`A4&%0H5#
MA42%185&A4>%2(5)A4J%2X5,A4V%3H5/A5"%4852A5.%5(55A5:%5X58A5F%
M6H5;A5R%785>A5^%8(5AA6*%8X5DA66%9H5GA6B%:85JA6N%;(5MA6Z%;X5P
MA7&%<H5SA72%=85VA7>%>(5YA7J%>X5\A7V%?H6`A8&%@H6#A82%A86&A8>%
MB(6)A8J%BX6,A8V%CH6/A9"%D862A9.%E(65A9:%EX68A9F%FH6;A9R%G86>
MA9^%H(6AA:*%HX6DA:6%IH6GA:B%J86JA:N%K(6MA:Z%KX6PA;&%LH6SA;2%
MM86VA;>%N(6YA;J%NX6\A;V%OH6_A<"%P87"A<.%Q(7%A<:%QX7(A<F%RH7+
MA<R%S87.A<^%T(71A=*%TX74A=6%UH77A=B%V87:A=N%W(7=A=Z%WX7@A>&%
MXH7CA>2%Y87FA>>%Z(7IA>J%ZX7LA>V%[H7OA?"%\87RA?.%](7UA?:%]X7X
MA?F%^H7[A?R%_87^A4"&089"AD.&1(9%AD:&1X9(ADF&2H9+ADR&389.AD^&
M4(91AE*&4X94AE6&5H97AEB&689:AEN&7(9=AEZ&7X9@AF&&8H9CAF2&989F
MAF>&:(9IAFJ&:X9LAFV&;H9OAG"&<89RAG.&=(9UAG:&=X9XAGF&>H9[AGR&
M?89^AH"&@8:"AH.&A(:%AH:&AX:(AHF&BH:+AHR&C8:.AH^&D(:1AI*&DX:4
MAI6&EH:7AIB&F8::AIN&G(:=AIZ&GX:@AJ&&HH:CAJ2&I8:FAJ>&J(:IAJJ&
MJX:LAJV&KH:OAK"&L8:RAK.&M(:UAK:&MX:XAKF&NH:[AKR&O8:^AK^&P(;!
MAL*&PX;$AL6&QH;'ALB&R8;*ALN&S(;-ALZ&SX;0AM&&TH;3AM2&U8;6AM>&
MV(;9AMJ&VX;<AMV&WH;?AN"&X8;BAN.&Y(;EAN:&YX;HANF&ZH;KANR&[8;N
MAN^&\(;QAO*&\X;TAO6&]H;WAOB&^8;ZAON&_(;]AOZ&0(=!AT*'0X=$AT6'
M1H='ATB'28=*ATN'3(=-ATZ'3X=0AU&'4H=3AU2'58=6AU>'6(=9AUJ'6X=<
MAUV'7H=?AV"'88=BAV.'9(=EAV:'9X=HAVF':H=KAVR';8=NAV^'<(=QAW*'
M<X=TAW6'=H=WAWB'>8=ZAWN'?(=]AWZ'@(>!AX*'@X>$AX6'AH>'AXB'B8>*
MAXN'C(>-AXZ'CX>0AY&'DH>3AY2'E8>6AY>'F(>9AYJ'FX><AYV'GH>?AZ"'
MH8>BAZ.'I(>EAZ:'IX>HAZF'JH>KAZR'K8>NAZ^'L(>QA[*'LX>TA[6'MH>W
MA[B'N8>ZA[N'O(>]A[Z'OX?`A\&'PH?#A\2'Q8?&A\>'R(?)A\J'RX?,A\V'
MSH?/A]"'T8?2A].'U(?5A]:'UX?8A]F'VH?;A]R'W8?>A]^'X(?AA^*'XX?D
MA^6'YH?GA^B'Z8?JA^N'[(?MA^Z'[X?PA_&'\H?SA_2']8?VA_>'^(?YA_J'
M^X?\A_V'_H=`B$&(0HA#B$2(18A&B$>(2(A)B$J(2XA,B$V(3HA/B%"(48A2
MB%.(5(A5B%:(5XA8B%F(6HA;B%R(78A>B%^(8(AAB&*(8XADB&6(9HAGB&B(
M:8AJB&N(;(AMB&Z(;XAPB'&(<HASB'2(=8AVB'>(>(AYB'J(>XA\B'V(?HB`
MB(&(@HB#B(2(A8B&B(>(B(B)B(J(BXB,B(V(CHB/B)"(D8B2B).(E(B5B):(
MEXB8B)F(FHB;B)R(G8B>B)^(H(BAB**(HXBDB*6(IHBGB*B(J8BJB*N(K(BM
MB*Z(KXBPB+&(LHBSB+2(M8BVB+>(N(BYB+J(NXB\B+V(OHB_B,"(P8C"B,.(
MQ(C%B,:(QXC(B,F(RHC+B,R(S8C.B,^(T(C1B-*(TXC4B-6(UHC7B-B(V8C:
MB-N(W(C=B-Z(WXC@B.&(XHCCB.2(Y8CFB.>(Z(CIB.J(ZXCLB.V([HCOB/"(
M\8CRB/.(](CUB/:(]XCXB/F(^HC[B/R(_8C^B$")08E"B4.)1(E%B4:)1XE(
MB4F)2HE+B4R)38E.B4^)4(E1B5*)4XE4B56)5HE7B5B)68E:B5N)7(E=B5Z)
M7XE@B6&)8HECB62)98EFB6>):(EIB6J):XELB6V);HEOB7")<8ERB7.)=(EU
MB7:)=XEXB7F)>HE[B7R)?8E^B8")@8F"B8.)A(F%B8:)AXF(B8F)BHF+B8R)
MC8F.B8^)D(F1B9*)DXF4B96)EHF7B9B)F8F:B9N)G(F=B9Z)GXF@B:&)HHFC
MB:2)I8FFB:>)J(FIB:J)JXFLB:V)KHFOB;")L8FRB;.)M(FUB;:)MXFXB;F)
MNHF[B;R)O8F^B;^)P(G!B<*)PXG$B<6)QHG'B<B)R8G*B<N)S(G-B<Z)SXG0
MB=&)THG3B=2)U8G6B=>)V(G9B=J)VXG<B=V)WHG?B>")X8GBB>.)Y(GEB>:)
MYXGHB>F)ZHGKB>R)[8GNB>^)\(GQB?*)\XGTB?6)]HGWB?B)^8GZB?N)_(G]
MB?Z)0(I!BD**0XI$BD6*1HI'BDB*28I*BDN*3(I-BDZ*3XI0BE&*4HI3BE2*
M58I6BE>*6(I9BEJ*6XI<BEV*7HI?BF"*88IBBF.*9(IEBF:*9XIHBFF*:HIK
MBFR*;8INBF^*<(IQBG**<XITBG6*=HIWBGB*>8IZBGN*?(I]BGZ*@(J!BH**
M@XJ$BH6*AHJ'BHB*B8J*BHN*C(J-BHZ*CXJ0BI&*DHJ3BI2*E8J6BI>*F(J9
MBIJ*FXJ<BIV*GHJ?BJ"*H8JBBJ.*I(JEBJ:*IXJHBJF*JHJKBJR*K8JNBJ^*
ML(JQBK**LXJTBK6*MHJWBKB*N8JZBKN*O(J]BKZ*OXK`BL&*PHK#BL2*Q8K&
MBL>*R(K)BLJ*RXK,BLV*SHK/BM"*T8K2BM.*U(K5BM:*UXK8BMF*VHK;BMR*
MW8K>BM^*X(KABN**XXKDBN6*YHKGBNB*Z8KJBNN*[(KMBNZ*[XKPBO&*\HKS
MBO2*]8KVBO>*^(KYBOJ*^XK\BOV*_HI`BT&+0HM#BT2+18M&BT>+2(M)BTJ+
M2XM,BTV+3HM/BU"+48M2BU.+5(M5BU:+5XM8BUF+6HM;BUR+78M>BU^+8(MA
MBV*+8XMDBV6+9HMGBVB+:8MJBVN+;(MMBVZ+;XMPBW&+<HMSBW2+=8MVBW>+
M>(MYBWJ+>XM\BWV+?HN`BX&+@HN#BX2+A8N&BX>+B(N)BXJ+BXN,BXV+CHN/
MBY"+D8N2BY.+E(N5BY:+EXN8BYF+FHN;BYR+G8N>BY^+H(NABZ*+HXNDBZ6+
MIHNGBZB+J8NJBZN+K(NMBZZ+KXNPB[&+LHNSB[2+M8NVB[>+N(NYB[J+NXN\
MB[V+OHN_B\"+P8O"B\.+Q(O%B\:+QXO(B\F+RHO+B\R+S8O.B\^+T(O1B]*+
MTXO4B]6+UHO7B]B+V8O:B]N+W(O=B]Z+WXO@B^&+XHOCB^2+Y8OFB^>+Z(OI
MB^J+ZXOLB^V+[HOOB_"+\8ORB_.+](OUB_:+]XOXB_F+^HO[B_R+_8O^BT",
M08Q"C$.,1(Q%C$:,1XQ(C$F,2HQ+C$R,38Q.C$^,4(Q1C%*,4XQ4C%6,5HQ7
MC%B,68Q:C%N,7(Q=C%Z,7XQ@C&&,8HQCC&2,98QFC&>,:(QIC&J,:XQLC&V,
M;HQOC'",<8QRC'.,=(QUC':,=XQXC'F,>HQ[C'R,?8Q^C(",@8R"C(.,A(R%
MC(:,AXR(C(F,BHR+C(R,C8R.C(^,D(R1C)*,DXR4C)6,EHR7C)B,F8R:C)N,
MG(R=C)Z,GXR@C*&,HHRCC*2,I8RFC*>,J(RIC*J,JXRLC*V,KHROC+",L8RR
MC+.,M(RUC+:,MXRXC+F,NHR[C+R,O8R^C+^,P(S!C,*,PXS$C,6,QHS'C,B,
MR8S*C,N,S(S-C,Z,SXS0C-&,THS3C-2,U8S6C->,V(S9C-J,VXS<C-V,WHS?
MC.",X8SBC..,Y(SEC.:,YXSHC.F,ZHSKC.R,[8SNC.^,\(SQC/*,\XSTC/6,
M]HSWC/B,^8SZC/N,_(S]C/Z,0(U!C4*-0XU$C46-1HU'C4B-28U*C4N-3(U-
MC4Z-3XU0C5&-4HU3C52-58U6C5>-6(U9C5J-6XU<C5V-7HU?C6"-88UBC6.-
M9(UEC6:-9XUHC6F-:HUKC6R-;8UNC6^-<(UQC7*-<XUTC76-=HUWC7B->8UZ
MC7N-?(U]C7Z-@(V!C8*-@XV$C86-AHV'C8B-B8V*C8N-C(V-C8Z-CXV0C9&-
MDHV3C92-E8V6C9>-F(V9C9J-FXV<C9V-GHV?C:"-H8VBC:.-I(VEC::-IXVH
MC:F-JHVKC:R-K8VNC:^-L(VQC;*-LXVTC;6-MHVWC;B-N8VZC;N-O(V]C;Z-
MOXW`C<&-PHW#C<2-Q8W&C<>-R(W)C<J-RXW,C<V-SHW/C="-T8W2C=.-U(W5
MC=:-UXW8C=F-VHW;C=R-W8W>C=^-X(WAC>*-XXWDC>6-YHWGC>B-Z8WJC>N-
M[(WMC>Z-[XWPC?&-\HWSC?2-]8WVC?>-^(WYC?J-^XW\C?V-_HU`CD&.0HY#
MCD2.18Y&CD>.2(Y)CDJ.2XY,CDV.3HY/CE".48Y2CE..5(Y5CE:.5XY8CEF.
M6HY;CER.78Y>CE^.8(YACF*.8XYDCF6.9HYGCFB.:8YJCFN.;(YMCFZ.;XYP
MCG&.<HYSCG2.=8YVCG>.>(YYCGJ.>XY\CGV.?HZ`CH&.@HZ#CH2.A8Z&CH>.
MB(Z)CHJ.BXZ,CHV.CHZ/CI".D8Z2CI..E(Z5CI:.EXZ8CIF.FHZ;CIR.G8Z>
MCI^.H(ZACJ*.HXZDCJ6.IHZGCJB.J8ZJCJN.K(ZMCJZ.KXZPCK&.LHZSCK2.
MM8ZVCK>.N(ZYCKJ.NXZ\CKV.OHZ_CL".P8["CL..Q([%CL:.QX[(CLF.RH[+
MCLR.S8[.CL^.T([1CM*.TX[4CM6.UH[7CMB.V8[:CMN.W([=CMZ.WX[@CN&.
MXH[CCN2.Y8[FCN>.Z([ICNJ.ZX[LCNV.[H[OCO".\8[RCO..]([UCO:.]X[X
MCOF.^H[[COR._8[^CD"/08]"CT./1(]%CT:/1X](CTF/2H]+CTR/38].CT^/
M4(]1CU*/4X]4CU6/5H]7CUB/68]:CUN/7(]=CUZ/7X]@CV&/8H]CCV2/98]F
MCV>/:(]ICVJ/:X]LCVV/;H]OCW"/<8]RCW./=(]UCW:/=X]XCWF/>H][CWR/
M?8]^CX"/@8^"CX./A(^%CX:/AX^(CXF/BH^+CXR/C8^.CX^/D(^1CY*/DX^4
MCY6/EH^7CYB/F8^:CYN/G(^=CYZ/GX^@CZ&/HH^CCZ2/I8^FCZ>/J(^ICZJ/
MJX^LCZV/KH^OC["/L8^RC[./M(^UC[:/MX^XC[F/NH^[C[R/O8^^C[^/P(_!
MC\*/PX_$C\6/QH_'C\B/R8_*C\N/S(_-C\Z/SX_0C]&/TH_3C]2/U8_6C]>/
MV(_9C]J/VX_<C]V/WH_?C^"/X8_BC^./Y(_EC^:/YX_HC^F/ZH_KC^R/[8_N
MC^^/\(_QC_*/\X_TC_6/]H_WC_B/^8_ZC_N/_(_]C_Z/0)!!D$*00Y!$D$60
M1I!'D$B029!*D$N03)!-D$Z03Y!0D%&04I!3D%2059!6D%>06)!9D%J06Y!<
MD%V07I!?D&"089!BD&.09)!ED&:09Y!HD&F0:I!KD&R0;9!ND&^0<)!QD'*0
M<Y!TD'60=I!WD'B0>9!ZD'N0?)!]D'Z0@)"!D(*0@Y"$D(60AI"'D(B0B9"*
MD(N0C)"-D(Z0CY"0D)&0DI"3D)20E9"6D)>0F)"9D)J0FY"<D)V0GI"?D*"0
MH9"BD*.0I)"ED*:0IY"HD*F0JI"KD*R0K9"ND*^0L)"QD+*0LY"TD+60MI"W
MD+B0N9"ZD+N0O)"]D+Z0OY#`D,&0PI##D,20Q9#&D,>0R)#)D,J0RY#,D,V0
MSI#/D-"0T9#2D-.0U)#5D-:0UY#8D-F0VI#;D-R0W9#>D-^0X)#AD.*0XY#D
MD.60YI#GD.B0Z9#JD.N0[)#MD.Z0[Y#PD/&0\I#SD/20]9#VD/>0^)#YD/J0
M^Y#\D/V0_I!`D4&10I%#D42119%&D4>12)%)D4J12Y%,D4V13I%/D5"149%2
MD5.15)%5D5:15Y%8D5F16I%;D5R179%>D5^18)%AD6*18Y%DD6619I%GD6B1
M:9%JD6N1;)%MD6Z1;Y%PD7&1<I%SD721=9%VD7>1>)%YD7J1>Y%\D7V1?I&`
MD8&1@I&#D821A9&&D8>1B)&)D8J1BY&,D8V1CI&/D9"1D9&2D9.1E)&5D9:1
MEY&8D9F1FI&;D9R1G9&>D9^1H)&AD:*1HY&DD:61II&GD:B1J9&JD:N1K)&M
MD:Z1KY&PD;&1LI&SD;21M9&VD;>1N)&YD;J1NY&\D;V1OI&_D<"1P9'"D<.1
MQ)'%D<:1QY'(D<F1RI'+D<R1S9'.D<^1T)'1D=*1TY'4D=61UI'7D=B1V9':
MD=N1W)'=D=Z1WY'@D>&1XI'CD>21Y9'FD>>1Z)'ID>J1ZY'LD>V1[I'OD?"1
M\9'RD?.1])'UD?:1]Y'XD?F1^I'[D?R1_9'^D4"209)"DD.21))%DD:21Y)(
MDDF22I)+DDR239).DD^24))1DE*24Y)4DE625I)7DEB269):DEN27))=DEZ2
M7Y)@DF&28I)CDF2299)FDF>2:))IDFJ2:Y)LDFV2;I)ODG"2<9)RDG.2=))U
MDG:2=Y)XDGF2>I)[DGR2?9)^DH"2@9*"DH.2A)*%DH:2AY*(DHF2BI*+DHR2
MC9*.DH^2D)*1DI*2DY*4DI62EI*7DIB2F9*:DIN2G)*=DIZ2GY*@DJ&2HI*C
MDJ22I9*FDJ>2J)*IDJJ2JY*LDJV2KI*ODK"2L9*RDK.2M)*UDK:2MY*XDKF2
MNI*[DKR2O9*^DK^2P)+!DL*2PY+$DL62QI+'DLB2R9+*DLN2S)+-DLZ2SY+0
MDM&2TI+3DM22U9+6DM>2V)+9DMJ2VY+<DMV2WI+?DN"2X9+BDN.2Y)+EDN:2
MYY+HDNF2ZI+KDNR2[9+NDN^2\)+QDO*2\Y+TDO62]I+WDOB2^9+ZDON2_)+]
MDOZ20)-!DT*30Y-$DT631I-'DTB329-*DTN33)--DTZ33Y-0DU&34I-3DU23
M59-6DU>36)-9DUJ36Y-<DUV37I-?DV"389-BDV.39)-EDV:39Y-HDVF3:I-K
MDVR3;9-NDV^3<)-QDW*3<Y-TDW63=I-WDWB3>9-ZDWN3?)-]DWZ3@).!DX*3
M@Y.$DX63AI.'DXB3B9.*DXN3C).-DXZ3CY.0DY&3DI.3DY23E9.6DY>3F).9
MDYJ3FY.<DYV3GI.?DZ"3H9.BDZ.3I).EDZ:3IY.HDZF3JI.KDZR3K9.NDZ^3
ML).QD[*3LY.TD[63MI.WD[B3N9.ZD[N3O).]D[Z3OY/`D\&3PI/#D\23Q9/&
MD\>3R)/)D\J3RY/,D\V3SI//D]"3T9/2D].3U)/5D]:3UY/8D]F3VI/;D]R3
MW9/>D]^3X)/AD^*3XY/DD^63YI/GD^B3Z9/JD^N3[)/MD^Z3[Y/PD_&3\I/S
MD_23]9/VD_>3^)/YD_J3^Y/\D_V3_I-`E$&40I1#E$24191&E$>42)1)E$J4
M2Y1,E$V43I1/E%"44912E%.45)15E%:45Y18E%F46I1;E%R4791>E%^48)1A
ME&*48Y1DE&649I1GE&B4:91JE&N4;)1ME&Z4;Y1PE'&4<I1SE'24=91VE'>4
M>)1YE'J4>Y1\E'V4?I2`E(&4@I2#E(24A92&E(>4B)2)E(J4BY2,E(V4CI2/
ME)"4D922E).4E)25E):4EY28E)F4FI2;E)R4G92>E)^4H)2AE**4HY2DE*64
MII2GE*B4J92JE*N4K)2ME*Z4KY2PE+&4LI2SE+24M92VE+>4N)2YE+J4NY2\
ME+V4OI2_E,"4P93"E,.4Q)3%E,:4QY3(E,F4RI3+E,R4S93.E,^4T)31E-*4
MTY34E-64UI37E-B4V93:E-N4W)3=E-Z4WY3@E.&4XI3CE.24Y93FE.>4Z)3I
ME.J4ZY3LE.V4[I3OE/"4\93RE/.4])3UE/:4]Y3XE/F4^I3[E/R4_93^E$"5
M095"E4.51)5%E4:51Y5(E4F52I5+E4R5395.E4^54)51E5*54Y54E5655I57
ME5B5695:E5N57)5=E5Z57Y5@E6&58I5CE625995FE6>5:)5IE6J5:Y5LE6V5
M;I5OE7"5<95RE7.5=)5UE7:5=Y5XE7F5>I5[E7R5?95^E8"5@96"E8.5A)6%
ME8:5AY6(E8F5BI6+E8R5C96.E8^5D)61E9*5DY64E965EI67E9B5F96:E9N5
MG)6=E9Z5GY6@E:&5HI6CE:25I96FE:>5J)6IE:J5JY6LE:V5KI6OE;"5L96R
ME;.5M)6UE;:5MY6XE;F5NI6[E;R5O96^E;^5P)7!E<*5PY7$E<65QI7'E<B5
MR97*E<N5S)7-E<Z5SY70E=&5TI73E=25U976E=>5V)79E=J5VY7<E=V5WI7?
ME>"5X97BE>.5Y)7EE>:5YY7HE>F5ZI7KE>R5[97NE>^5\)7QE?*5\Y7TE?65
M]I7WE?B5^97ZE?N5_)7]E?Z50)9!ED*60Y9$ED661I9'EDB6299*EDN63)9-
MEDZ63Y90EE&64I93EE265996EE>66)99EEJ66Y9<EEV67I9?EF"6899BEF.6
M9)9EEF:69Y9HEFF6:I9KEFR6;99NEF^6<)9QEG*6<Y9TEG66=I9WEGB6>99Z
MEGN6?)9]EGZ6@):!EH*6@Y:$EH66AI:'EHB6B9:*EHN6C):-EHZ6CY:0EI&6
MDI:3EI26E9:6EI>6F):9EIJ6FY:<EIV6GI:?EJ"6H9:BEJ.6I):EEJ:6IY:H
MEJF6JI:KEJR6K9:NEJ^6L):QEK*6LY:TEK66MI:WEKB6N9:ZEKN6O):]EKZ6
MOY;`EL&6PI;#EL26Q9;&EL>6R);)ELJ6RY;,ELV6SI;/EM"6T9;2EM.6U);5
MEM:6UY;8EMF6VI;;EMR6W9;>EM^6X);AEN*6XY;DEN66YI;GENB6Z9;JENN6
M[);MENZ6[Y;PEO&6\I;SEO26]9;VEO>6^);YEOJ6^Y;\EOV6_I9`ET&70I=#
MET2719=&ET>72)=)ETJ72Y=,ETV73I=/EU"749=2EU.75)=5EU:75Y=8EUF7
M6I=;EUR779=>EU^78)=AEV*78Y=DEV679I=GEVB7:9=JEVN7;)=MEVZ7;Y=P
MEW&7<I=SEW27=9=VEW>7>)=YEWJ7>Y=\EWV7?I>`EX&7@I>#EX27A9>&EX>7
MB)>)EXJ7BY>,EXV7CI>/EY"7D9>2EY.7E)>5EY:7EY>8EYF7FI>;EYR7G9>>
MEY^7H)>AEZ*7HY>DEZ67II>GEZB7J9>JEZN7K)>MEZZ7KY>PE[&7LI>SE[27
MM9>VE[>7N)>YE[J7NY>\E[V7OI>_E\"7P9?"E\.7Q)?%E\:7QY?(E\F7RI?+
ME\R7S9?.E\^7T)?1E]*7TY?4E]67UI?7E]B7V9?:E]N7W)?=E]Z7WY?@E^&7
MXI?CE^27Y9?FE^>7Z)?IE^J7ZY?LE^V7[I?OE_"7\9?RE_.7])?UE_:7]Y?X
ME_F7^I?[E_R7_9?^ET"809A"F$.81)A%F$:81YA(F$F82IA+F$R839A.F$^8
M4)A1F%*84YA4F%685IA7F%B869A:F%N87)A=F%Z87YA@F&&88IACF&2899AF
MF&>8:)AIF&J8:YALF&V8;IAOF'"8<9ARF'.8=)AUF':8=YAXF'F8>IA[F'R8
M?9A^F("8@9B"F(.8A)B%F(:8AYB(F(F8BIB+F(R8C9B.F(^8D)B1F)*8DYB4
MF)68EIB7F)B8F9B:F)N8G)B=F)Z8GYB@F*&8HIBCF*28I9BFF*>8J)BIF*J8
MJYBLF*V8KIBOF+"8L9BRF+.8M)BUF+:8MYBXF+F8NIB[F+R8O9B^F+^8P)C!
MF,*8PYC$F,68QIC'F,B8R9C*F,N8S)C-F,Z8SYC0F-&8TIC3F-28U9C6F->8
MV)C9F-J8VYC<F-V8WIC?F."8X9CBF..8Y)CEF.:8YYCHF.F8ZICKF.R8[9CN
MF.^8\)CQF/*8\YCTF/68]ICWF/B8^9CZF/N8_)C]F/Z80)E!F4*90YE$F469
M1IE'F4B929E*F4N93)E-F4Z93YE0F5&94IE3F52959E6F5>96)E9F5J96YE<
MF5V97IE?F6"989EBF6.99)EEF6:99YEHF6F9:IEKF6R9;9ENF6^9<)EQF7*9
M<YETF769=IEWF7B9>9EZF7N9?)E]F7Z9@)F!F8*9@YF$F869AIF'F8B9B9F*
MF8N9C)F-F8Z9CYF0F9&9DIF3F929E9F6F9>9F)F9F9J9FYF<F9V9GIF?F:"9
MH9FBF:.9I)FEF::9IYFHF:F9JIFKF:R9K9FNF:^9L)FQF;*9LYFTF;69MIFW
MF;B9N9FZF;N9O)F]F;Z9OYG`F<&9PIG#F<29Q9G&F<>9R)G)F<J9RYG,F<V9
MSIG/F="9T9G2F=.9U)G5F=:9UYG8F=F9VIG;F=R9W9G>F=^9X)GAF>*9XYGD
MF>69YIGGF>B9Z9GJF>N9[)GMF>Z9[YGPF?&9\IGSF?29]9GVF?>9^)GYF?J9
M^YG\F?V9_IE`FD&:0II#FD2:19I&FD>:2)I)FDJ:2YI,FDV:3II/FE":49I2
MFE.:5)I5FE::5YI8FEF:6II;FER:79I>FE^:8)IAFF*:8YIDFF6:9IIGFFB:
M:9IJFFN:;)IMFFZ:;YIPFG&:<IISFG2:=9IVFG>:>)IYFGJ:>YI\FGV:?IJ`
MFH&:@IJ#FH2:A9J&FH>:B)J)FHJ:BYJ,FHV:CIJ/FI":D9J2FI.:E)J5FI::
MEYJ8FIF:FIJ;FIR:G9J>FI^:H)JAFJ*:HYJDFJ6:IIJGFJB:J9JJFJN:K)JM
MFJZ:KYJPFK&:LIJSFK2:M9JVFK>:N)JYFKJ:NYJ\FKV:OIJ_FL":P9K"FL.:
MQ)K%FL::QYK(FLF:RIK+FLR:S9K.FL^:T)K1FM*:TYK4FM6:UIK7FMB:V9K:
MFMN:W)K=FMZ:WYK@FN&:XIKCFN2:Y9KFFN>:Z)KIFNJ:ZYKLFNV:[IKOFO":
M\9KRFO.:])KUFO::]YKXFOF:^IK[FOR:_9K^FD";09M"FT.;1)M%FT:;1YM(
MFTF;2IM+FTR;39M.FT^;4)M1FU*;4YM4FU6;5IM7FUB;69M:FUN;7)M=FUZ;
M7YM@FV&;8IMCFV2;99MFFV>;:)MIFVJ;:YMLFVV;;IMOFW";<9MRFW.;=)MU
MFW:;=YMXFWF;>IM[FWR;?9M^FX";@9N"FX.;A)N%FX:;AYN(FXF;BIN+FXR;
MC9N.FX^;D)N1FY*;DYN4FY6;EIN7FYB;F9N:FYN;G)N=FYZ;GYN@FZ&;HINC
MFZ2;I9NFFZ>;J)NIFZJ;JYNLFZV;KINOF[";L9NRF[.;M)NUF[:;MYNXF[F;
MNIN[F[R;O9N^F[^;P)O!F\*;PYO$F\6;QIO'F\B;R9O*F\N;S)O-F\Z;SYO0
MF]&;TIO3F]2;U9O6F]>;V)O9F]J;VYO<F]V;WIO?F^";X9OBF^.;Y)OEF^:;
MYYOHF^F;ZIOKF^R;[9ONF^^;\)OQF_*;\YOTF_6;]IOWF_B;^9OZF_N;_)O]
MF_Z;0)Q!G$*<0YQ$G$6<1IQ'G$B<29Q*G$N<3)Q-G$Z<3YQ0G%&<4IQ3G%2<
M59Q6G%><6)Q9G%J<6YQ<G%V<7IQ?G&"<89QBG&.<9)QEG&:<9YQHG&F<:IQK
MG&R<;9QNG&^<<)QQG'*<<YQTG'6<=IQWG'B<>9QZG'N<?)Q]G'Z<@)R!G(*<
M@YR$G(6<AIR'G(B<B9R*G(N<C)R-G(Z<CYR0G)&<DIR3G)2<E9R6G)><F)R9
MG)J<FYR<G)V<GIR?G*"<H9RBG*.<I)REG*:<IYRHG*F<JIRKG*R<K9RNG*^<
ML)RQG+*<LYRTG+6<MIRWG+B<N9RZG+N<O)R]G+Z<OYS`G,&<PIS#G,2<Q9S&
MG,><R)S)G,J<RYS,G,V<SIS/G-"<T9S2G-.<U)S5G-:<UYS8G-F<VIS;G-R<
MW9S>G-^<X)SAG.*<XYSDG.6<YISGG.B<Z9SJG.N<[)SMG.Z<[YSPG/&<\ISS
MG/2<]9SVG/><^)SYG/J<^YS\G/V<_IQ`G4&=0IU#G42=19U&G4>=2)U)G4J=
M2YU,G4V=3IU/G5"=49U2G5.=5)U5G5:=5YU8G5F=6IU;G5R=79U>G5^=8)UA
MG6*=8YUDG66=9IUGG6B=:9UJG6N=;)UMG6Z=;YUPG7&=<IUSG72==9UVG7>=
M>)UYG7J=>YU\G7V=?IV`G8&=@IV#G82=A9V&G8>=B)V)G8J=BYV,G8V=CIV/
MG9"=D9V2G9.=E)V5G9:=EYV8G9F=FIV;G9R=G9V>G9^=H)VAG:*=HYVDG:6=
MIIVGG:B=J9VJG:N=K)VMG:Z=KYVPG;&=LIVSG;2=M9VVG;>=N)VYG;J=NYV\
MG;V=OIV_G<"=P9W"G<.=Q)W%G<:=QYW(G<F=RIW+G<R=S9W.G<^=T)W1G=*=
MTYW4G=6=UIW7G=B=V9W:G=N=W)W=G=Z=WYW@G>&=XIWCG>2=Y9WFG>>=Z)WI
MG>J=ZYWLG>V=[IWOG?"=\9WRG?.=])WUG?:=]YWXG?F=^IW[G?R=_9W^G4">
M09Y"GD.>1)Y%GD:>1YY(GDF>2IY+GDR>39Y.GD^>4)Y1GE*>4YY4GE6>5IY7
MGEB>69Y:GEN>7)Y=GEZ>7YY@GF&>8IYCGF2>99YFGF>>:)YIGFJ>:YYLGFV>
M;IYOGG"><9YRGG.>=)YUGG:>=YYXGGF>>IY[GGR>?9Y^GH">@9Z"GH.>A)Z%
MGH:>AYZ(GHF>BIZ+GHR>C9Z.GH^>D)Z1GI*>DYZ4GI6>EIZ7GIB>F9Z:GIN>
MG)Z=GIZ>GYZ@GJ&>HIZCGJ2>I9ZFGJ>>J)ZIGJJ>JYZLGJV>KIZOGK">L9ZR
MGK.>M)ZUGK:>MYZXGKF>NIZ[GKR>O9Z^GK^>P)[!GL*>PY[$GL6>QI['GLB>
MR9[*GLN>S)[-GLZ>SY[0GM&>TI[3GM2>U9[6GM>>V)[9GMJ>VY[<GMV>WI[?
MGN">X9[BGN.>Y)[EGN:>YY[HGNF>ZI[KGNR>[9[NGN^>\)[QGO*>\Y[TGO6>
M]I[WGOB>^9[ZGON>_)[]GOZ>0)]!GT*?0Y]$GT6?1I]'GTB?29]*GTN?3)]-
MGTZ?3Y]0GU&?4I]3GU2?59]6GU>?6)]9GUJ?6Y]<GUV?7I]?GV"?89]BGV.?
M9)]EGV:?9Y]HGVF?:I]KGVR?;9]NGV^?<)]QGW*?<Y]TGW6?=I]WGWB?>9]Z
MGWN??)]]GWZ?@)^!GX*?@Y^$GX6?AI^'GXB?B9^*GXN?C)^-GXZ?CY^0GY&?
MDI^3GY2?E9^6GY>?F)^9GYJ?FY^<GYV?GI^?GZ"?H9^BGZ.?I)^EGZ:?IY^H
MGZF?JI^KGZR?K9^NGZ^?L)^QG[*?LY^TG[6?MI^WG[B?N9^ZG[N?O)^]G[Z?
MOY_`G\&?PI_#G\2?Q9_&G\>?R)_)G\J?RY_,G\V?SI_/G]"?T9_2G].?U)_5
MG]:?UY_8G]F?VI_;G]R?W9_>G]^?X)_AG^*?XY_DG^6?YI_GG^B?Z9_JG^N?
M[)_MG^Z?[Y_PG_&?\I_SG_2?]9_VG_>?^)_YG_J?^Y_\G_V?_I]`H$&@0J!#
MH$2@1:!&H$>@2*!)H$J@2Z!,H$V@3J!/H%"@4:!2H%.@5*!5H%:@5Z!8H%F@
M6J!;H%R@7:!>H%^@8*!AH&*@8Z!DH&6@9J!GH&B@::!JH&N@;*!MH&Z@;Z!P
MH'&@<J!SH'2@=:!VH'>@>*!YH'J@>Z!\H'V@?J"`H(&@@J"#H(2@A:"&H(>@
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MOYZ_G[^@OT#`0<!"P$/`1,!%P$;`1\!(P$G`2L!+P$S`3<!.P$_`4,!1P%+`
M4\!4P%7`5L!7P%C`6<!:P%O`7,!=P%[`7\!@P&'`8L!CP&3`9<!FP&?`:,!I
MP&K`:\!LP&W`;L!OP'#`<<!RP'/`=,!UP';`=\!XP'G`>L![P'S`?<!^P(#`
M@<""P(/`A,"%P(;`A\"(P(G`BL"+P(S`C<".P(_`D,"1P)+`D\"4P)7`EL"7
MP)C`F<":P)O`G,"=P)[`G\"@P$#!0<%"P4/!1,%%P4;!1\%(P4G!2L%+P4S!
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MJ76I=JEWJ7BI>:EZJ7NI?*E]J7ZI@*F!J8*I@ZF$J86IAJF'J8BI5JE7J0``
M````````````````QC<``,8W``#&-P``QC<!`,<W`/[.-_?^W#=_#^<W``#G
M-P``YS<``.<W``#G-P``YS<``.<W``#G-P``YS<``.<W``#G-P``YS<``.<W
M``#G-P``YS<``.<W``#G-P``YS<``.<W``#G-P``YS<``.<W``#G-P``YS<4
M``````"Q-P``L3<``+$W`!"R-P``LC<``+(W``"R-P``LC<``K,W``"S-R``
MM#<``+0W``"T-P``M#<``+0W@`"U-P(`MC<`\+HW&H&_-YL#````````````
M``````````````!V`'2`>P"$@'X`2\*%`*H0B@!7!)``H@R5`+S]H0#TOZT`
MOP2U`,%RO``(A+\`TW/)``"1S``%'-$`Q>+9`!)7X`#]&>H`?##Q``IS^`"J
MR@`!MQ\+`50`#@%&;18!IB<>`>=4)P%MUS(!%B@W`=]_10''.T\!?`I6`;48
M70'UNF@!_T]U`>MH?@&=B(4!_ZN2`7<NG`'?ZZD!W^^W`3\WP@'>WLX!___>
M`5?LZ`'[\_4!_W\$`K_[$@(_CQT"U_<J`C_W-P+[_T8"_?]5`O]_9`*$U&H"
MC>MT`MN&?0($Q($"V,R)`AOED@+*9YL"$,>A`BYEJ0+]U[8"[%?``I9`Q0(P
MFLL".=#2`NZ4VP(V4.$"\,OJ`JRO]`)=>?X"^U\+`_G^&`/V%R(#\,`H`_$_
M,P-W]3\#NGY*`^__60/^.60#GEYN`Q[9=P.TNX$#_S&,`U4XDP,1*YD#(#6>
M`T1ZI0.+Q:T#WUJX`Y.\P0._=\X#^<#6`RUTW@.&`.$#$,3E`Z4(Z@,0%^\#
M-`3S`\FD^@.V\@0$`N0)!*O^%001QAL$JB<C!(K1*@0G0"\$Y58X!"@,/`1`
M"3\$'YA'!/-+400]?5P$[/=H!&(K;P1T+W@$I?F"!)[OC@0-BY4$'Z:>!&!P
MHP3M3*P$?_^[!%65PP3/S<X$H4_6!(5BW`13G^8$_"SO!/\V^P1GSP8%J74/
M!?^/'`5O["<%Z^`P!;WG/`6?/T@%]_]7!?=_905_[W,%__N"!6\3BP7HUY4%
MS!F<!:?XI@7_;[0%]PB\!?:QQ@5Z"\X%?`/5!:Q0VP4WY^8%@^?O!?/W_`4@
ME0$&Z_X.!O,W&0;+6"$&[E\M!N_8.`8ZUT(&W;U.!NS[6@;>_V@&[\]U!NV^
M@0;?YXX&_[^=!M3]J`;S.;(&__S`!O_OSP;=_]T&W?_K!N^G]P:V_0,':U\.
M!X]I%P=/$1X';>@G!VDT+@<-^C<'VO]$!Z?<3@<AVE4',[U?!\<P9@?[M7('
MO_-_!V#*A0?7[I$'_W6>!P7LI0?U;K`'UOV\!ZGOQP>^^=,'W_OA!WO[[@</
M>_@'__\("/OS%0C_^R0(T[XO"/GM.PBK[D8(M/50"/W_7PC__6X(/_]\"/__
MC`AK_YD(_O^H"$1`JPB#Z;,(U-N]"$1DP@A7@,@(@///"(8<U0@+[]\(\A_I
M",V^]`C^8/T(K7D'"8W*#PE+[QH)[0`@"=@P)@G<O3$)E#\Z"?UY1@GYSE$)
M+.!7"?/%80E57FH)[?=W"?O]A0F-VHX)_O><"3._IPFOM[,)+YV]">^?R@E_
MX]8)_];C"?]E[PGO__X)^_\-"O_=&PK__RL*?_\Z"M_?2`K_EU4*&31;"F&?
M9`J1;FP*C,!Q"C^??0I]QH<*R^^3"L^WGPKY_ZT*HT*S"BYSO`H$*<`*'M_+
M"A>\U`K_^>(*L??M"O_Z^PHO.P4+X'(,"U5V%0L>61T+_>DI"_[_.`L2WD`+
MJ<E("W3E40M(X%8+6NQ?"_V::@M?SW8+ATU^"SC<A@MLDXX+W1:7"X`;G`N+
MQ:0+''"J"]]GM@OQU\$+VMG+"V-`T`NV0-8+Y\WA"ZM3Z@NV1O(+Z>;\"Y_S
M"`S=2A$,/@07#*;Y(0R\'"D,WWLV#";W0`S_?T\,_ZI;#-W?:`Q[_G4,7O^"
M#/^WD`SOWYX,?^RJ#'^_N`S[\L0,Z?_1#+__X`S??^X,OP+V#!AR_`S)JP4-
M9Q\/#72$%0WA]A\--P$E#;8M+@WN^3H-$7)`#<CF2`W=15$-"XA6#2)@6@T3
M#%\-)0]F#7F\<`V]$WD-P')_#?O9BPV3!9$-WC^=#7&=I@T]\[$->BBX#;K^
MQ`U2B,D-9JK1#:\=VPVZO^<-]-GQ#:M>^PW89P0.YJ<.#KS+&`[O6R0.#?HM
M#NN^.0Y_W48.__A3#DO_7PZ9O6D.[XUT#E[J?@[:GXD.>KZ4#JO_H0[__[$.
M_OV_#OO^S0[?-]D.CS3A#M]L[`Z=E?4.L^<`#VK_#`]_YQD/=&4A#TU5*0_^
MS34/A2<\#SO_20\:#$X///M9#[(K80_'76L/7EYU#XVO?P_U9XH/`WN2#ZT^
MG`\NNZ8/:^^R#SW?O@]_OLL/[[W8#___Z`__Q?0/O_T"$&(M"1#^T!,03E<<
M$+]")1#-VS`0LBPW$+0O0!#<6$@04B]0$&WU6Q!>BF,04U)J$!;^=!#E?X`0
MX(B%$-IMCQ#D7YD07B"?$#7?JA#]^;<0<XR_$("HPQ#$_\X0`/33$"__X!"5
M?^L0=__Y$#M>`Q'6_Q`1^M4;$=OZ)Q'VOS01W.D^$=V721'Z?U81[M]C$>Y=
M;A'[_WT1;YN($;:WDQ%][)X1*MRF$<_FL1%_UKT1;??)$?VKU1'N=^$1_M_O
M$?M?_!'_^PL2?WX8$OUZ)!+=GS`2;_\^$O[T2A+=_U@2_>UE$NZ_<A)\_W\2
M_N6+$O__FQ+__ZL2__^[$O__RQ+__]L2___K$O__^Q)@_P43>[D0$S?M&Q/_
M_2H3`_LS$__E0!,AT483L_-1$_W[7Q-'?VH3V5=T$P/U?!/]<X@3U]V4$Q]?
MGQ.$<*03*3BJ$\K>M!,X^;T33@?$$^SXSA.JG=<3D6S>$^9UZ!,%D>T3\03S
M$\_I_A,&MP84T#(,%!2"$!1MIQH4>[$D%%^S+Q31A384%1([%.&I0Q2V.4P4
M;^Y8%-NL8A3%%VH4)#!N%-M^>A0.YX,4O9R-%*RGEA1UY:`4WXNK%"S;M!3$
M5;L4Z_K'%.>?TQ2G=MT4_[?K%/\_^127?005_FX0%5M[&Q4ITR,5>7<N%44[
M-A6(_#X5[_U,%;M]6!7'_V45[E%N%;6_>A4_UX85_ZZ3%;N?GQ7KZJH5[XRT
M%?_OPQ5]_]$5M_W>%?K]ZQ7YO_@5_#\$%O__%!;__R06_?,Q%O?_0!;?_4X6
M_V]<%O^_:Q;_1W<6GBZ`%MZYBQ:+S906_P>?%G7$IQ;P^K$6_W2]%B]$Q!9_
MW=$6__G?%I;XZ!:_?_86O/\#%]^K#Q?_KQT7+[XH%_/:,Q?O>T`7[WQ,%_[N
M61?7_687][]T%\__@A=>OXX7__V=%[__K!?_W[L7_^K(%QQ4SA=_SMH7NU7D
M%SD][1?;.?<7[%,`&/M_#AC_3QL8+OPE&.&>+AAZO3D8_`Q!&&#B1QCUNU,8
M%X=;&-FA8QAM/&P8_]][&'K_B!C^3Y08_[^C&&^UKAB]=[H8^S7%&'+SSQCZ
M6-@8_+WD&%[=[QC[__X8EWD(&?[S%1F;JAX9AN\H&?W_-QE?(3\9_]].&3Z_
M6AETMV09_J]Q&7_\?AG_^XT9__^=&?NOJAFB/[,9+W^_&>]?S!GU:-49WT3>
M&5"RY!G>)NT9[^'X&9_[!1KK?!`:MW<<&BE9(QK$)RH:P(PO&D/8-AJ+MC\:
M(_)'&NQM41K4ZUL:7G1D&HK1:QK&+G,:]L]_&J^OBQKW=Y@:_Y:D&BNVK1JU
M_;D:[[_'&NE_TQJ;&ML:*';B&M\_[QKIK/@:;=0!&_]Y#ANZ7!<;'^HA&W3_
M+1O\\SD;D>9!&_\=31O.CU<;^7]D&UKI;1O65W<;_]^&&W_GDQM3A9H;MQZD
M&_C-KALI2K0;%\V]&VZ@Q!M>K\\;&M_9&_^#Y!M_[_(;?XW]&W5B!1Q5_Q$<
MX+T:'-WQ)1S._3$<_^X_'&O[2QS=_UD<][]G'.__=ASOHX$<O/R,'#<#DQQ:
M7IP<?_JI',Q[LQS_^\(<?__1'/>1VQRTU>0<V7[O'"=5]QS^U@,=LI<,'6^[
M&!WV_R8==T4O';__/AU]_TP=__]<'2YX9!VDWFT=&4YT'9[.?AWW?XP=__>;
M';\]IQV67[$=_UF]':=RQAW-M=`=CJ+7'?6JX1U?9>L=J-+R'?J__QU9M0@>
MWM\5'D[/'QXYP"4>[?XR'CWO/A[UV4D>G;M4'GVO8!Y_9VP>OW]Z'C_[AQ[_
M?I4>_-^B'O__LA[__\(>Y\?-'O_]W!Y9#N,>R[ON'O&-]QY=R@`?'VT*'_Y^
M%Q__]B4?__LT'___1!]Z=T\?__]?'___;Q___W\?_[^.'W__G1___ZT?__^]
M'[^_RQ___]L?___K'___^Q___PL@__\;(/__*R#__SL@__]+(/_W6B!]_V@@
M__]X(/__B"#__Y@@^_^G(/]WM2``0+8@$!BY(```N2!``+H@$!"\(``"O2``
M!+X@`4#`(```P""`^L<@R__4($QZW"#YN.8@Z;WQ(/VK_2#O&P@A;7\4(?I,
M'2'=JR@ASWXT(9R]/B'TYTDAA,=0(0KL5R$:^%\A%59F(;/#;R'K^GLA__F)
M(?U_ER$FY9\AMT*G(<@1K"%I"[,AH(^Z(3^!PB%-0,<AH,K-(;L9UB&@NMTA
M_V_K(;F^]B&_X@$BQ/D*(EZ=%"+L`1HB^GHE(OW&,"*W^CPB]_-)(K#K4B+_
M_V(B=\MM(N>G>"*(SX`BZB>)(O%"D"($M)4B;W6@(O]ZK2+_/KHBXAG!(NL2
MR2)Y3-$BC0#5(F2<W")M`N(B02;G(H1W[R)M]?HB`2S^(DWC!R-_1A$CA>@8
M(S9](B/H(RDC!``J(W_&-2.?O4$C\Z9+(_[P5B,@R%HC7&MC(Z].;2/<^7@C
M^-R"(Z4'B2/]SI4C#_Z@(_W.K".__[LC?>'%(_7%SR.5^MDC>Z3B(W_M[R/]
M?_TCZU@&).W9$22T7QLDEN\F)/YO,R3_[T(D=7M-)/WG6B1_P&,D]_AO)+^]
M?"3O_HHDZ[&4)$]_H"3_YZXD[SJY)'[]QB3]?=,DUN_?)._][23_=_LDW_\*
M);W_&"5__28E_^XT)?\?027LNTPE^Z=8)?T!8"7XPVDEU\]U)6=H?26,^X<E
M+C&.)>PTEB7OG:(EX+RJ)7+8LB53JKHET;W$)6TWSB5_K-DE=_WF)<:_\26N
MA_HET]8$)G=_$2;_1APFU]LH)K[S-";Q]T`FWKM,)O^]6B;W^V@FE_=T)OG_
M@B;[[8\FSL^:)F_]IR;!I*TF>A^W)LG6P":[[\TFZ]?9)GWOYB:9O?`FRWSZ
M)L/^!2?DK`TG^_L;)_+Q)2?=\S$GKO\^)^W_3"?_/UHGO_]I)_]W=R>U_X0G
M__^4)___I"?__[0G"2"W)[BKP">7=\LG]__:)W[_Z"?___@G__\(*/^_%RC_
M_B8H__\V*/__1BC__54H__EC*/?_<BC__X(H__^2*/__HBC__[(H___"*/__
MTBA__^$H___Q*+__`"G__Q`I__\@*?__,"F_[SXI__].*?__7BG__VXI`!!O
M*0((<2F``'(I`0!S*0`$="D``'0I``)U*0!`=BD``'8I`/]^*3WMB2G?^Y<I
M^?.C*??XKRG;Z;HI[_[(*?__V"G__^@I___X*?__""K__Q@J__\H*O__."K_
M'T4J`0!&*@``1BH``$8JAH!**B#742H&_ULJS?-F*NU_<RKW_X(JQ2J)*J<G
MDBH]$YHJYV*C*E?0JRK?:;8J[Q_"*O,IRRK=V=8J:/#=*OG]ZBJ_3?4JJF__
M*EU_"RONKQ<K_V<D*_O[,BO_OT$K__]1*___82O__W$K__^!*___D2O__Z$K
M__^Q*___P2O__]$K/P38*P``V"L!$-HK!"#<*_?TZ"N\G?(K2;[[*\0$_RN+
MD`4L=MP/+(!1$RPH$Q@LN!\A+)^F*RQI7S4L</8^+-.>2"S/7U0L\O9?+%75
M:"RQ*W`LA+!U+$T[?BQTQX<L.5:/+.^>FRSK_ZDL_[VW+/-_Q"S]_=(LMP'9
M+'J;XRS!*>DL"!SM+%_%]RSX\P(M\QL,+<_[&2U_"2(M_>\P+?__0"W__U`M
M__]@+?__<"W__X`M__^0+?__H"W__[`M___`+>__SRW_O]XM___N+?^__2W_
M_PTN__X<+O__+"[__SPN__],+O__7"[__VPN__]\+O^_BR[__YLN__^K+O_[
MNB[__\HN_W_9+O__Z2[___DN__\)+__[&"^__R<O__\W+___1R___U<O__]G
M+___=R__OX8O__^6+___IB__][4O___%+Q\`RB]"`<TO``#-+P``S2^`@,\O
M&`32+T``TR\`"-0O``#4+P`0U2^!`-<O""#9+P@)W"\@!-XO`4#@+[!_ZB__
M__HO__\*,/__&C#__RHP__\Z,/__2C#_$%,P`(!4,(``53`(25DP^;ME,(%'
M:S`*Q'`PSG=[,&GH@S`+_XXPGU:8,&[LHC!__[$PMHVZ,`P-OS#;_\TP_GC8
M,#>]XS`L'.DPMZ_U,/_;`S'ZO`XQ__\>,;.U*#'8_3,QI^\_,=_73#'I_E@Q
M]E=C,>O_<3'__X$Q__^1,3_!FC&7_Z<Q__^W,?__QS'__]<Q___G,?__]S'_
M_P<R__\7,A\`'#(`2!XR)`(A,@C_*C+__SHR_[]),M$X4#)__EXR__]N,O_?
M?3+^_XPR_[^;,O__JS+__[LRS__),E<`SC((2],R#%+8,@#\WC+?_NPR___\
M,O__##/__QPS__\L,___/#/__TPS__]<,___;#/__WPS__^,,___G#/_#Z@S
M!`"I,PABK3,P`K`S0/ZX,SSJP3/8Y\LS]7[7,[U7XC/_]?`S]W[],_=_"S3W
M?QDT^^<F-$%<+#3M_SHT__]*-/__6C3__VHT__]Z-/__BC3__YHT__^J-/__
MNC3__\HT___:-/__ZC3___HT__\*-?__&C7__RHU__\Z-?__2C7_;U@U&99?
M-<@C934`E&@U`,)K-0<#<#4&#'0U^_^#-?__DS7__Z,U__^S-?__PS7__],U
M___C-?__\S7__P,V__\3-O__(S;__S,V__]#-O__4S;__V,V__]S-O__@S;_
M_Y,V__^C-O]_LC:00+4V$1BY-@$@NS9=HL,V)\#)-O0_U#9[]N`V\U_L-K__
M^S;OE@8W[QT1-^U&&C=:>2,W_Z4O-_^7/#=V_4@W^F]4-W^57S?O_VXW_/]\
M-___C#?_?YLW!N"@-_]QK#<^````````````````````````````:0```&D`
M``!I````:0`"`&H```!J````:@```&H```!J````:@```&H`"`!K````:P``
M`&L```!K````:P```&L```!K````:P```&L```!K````:P```&L```!K````
M:P``P&T``'!P``(`<0```'$`$$!S`"8```````````!4`,``5@`$8%D`_@-B
M````8@```&(```!B````8@```&(```!B``!X9@```&8```!F````9@```&8`
M``!F``!P%P```!<````7````%P```!<````7`/__)P#__S<`#P`[`/[_2@`X
M`$T```!-```P3P```$\```!/`#P`4P```%,```(`````````````````````
M`````````````````P````,`*0`&`"``!P`@``@````(````"`````@````(
M````"`````@````(````"`````@````(````"`````@`(`(*````"@`"``L`
M```+````"P````L````+````"P````L`P`,/````#P````\````/````#P``
M``\````/````#P`@@!$`"``2````$@```!(`!``3`,``%0```!4````5`"``
M%@```!8``(``````````````````````````````````````````````````
M````````````````````````````````````````#`(```(`````````````
M\J8``/2F]:;@IN&F\*;QIN*FXZ;NIN^FYJ;GIN2FY:;HINFFZJ;KI@``````
M`````````````````````````+NH````````````````````````````````
M````````P*@```````````````````````````````````````````````"]
MJ````````+ZH``````````````````````````"8_IG^FOZ;_IS^G?Z>_@``
M````````````````````````````````EOX`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"3_I3^E?Z7_I+^````````````````````````````
M``````````````````````"%_@``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"&_@````"'_@``````````
MB/Z)_@``BOZ+_@``````````````````````````````````````````````
M``````"-_@```````(S^````````````````````````````````````````
M``````````````````"/_H[^````````````````````````````````@OX`
M`````````````````````````````````````````(/^````````````````
M``````````````````"`_@````````````"!_@``````````````````````
M````??X`````````````````````````````````````````````````````
M?/X``````````````````````````'C^``````````!W_@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````>OX`````````````````
M````````````````````````````8OYE_@``````````````````````````
M``````````!C_@````````````````````````````````````!<_@``````
M``````````````````````!;_@``````````````````````````````````
M``````````````````!6_@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````5?X```````````````````````````````"*J8NIC*F-
MJ8ZICZF0J9&IDJF3J92IE:D`````````````4/X`````5/X```````!7_@``
M``!8_EW^``````````````````````````!>_@``````````````````````
M`````````````````&O^`````&[^````````<?X``````````'/^`````'3^
M=?X```````!Y_@````````````````````````````````````"$_@``````
M``````"``($`@P"%`(8`AP")`(P`C@"0`)$`DP"4`)4`E@"7`)@`F0":`)L`
MG`"=`)X`GP"@`*$`H@"C`*0`I0"F`*<`J`"K`*P`O0#$`-4`W`#=`!T!'@$?
M`2,!)0$G`2D!*@$L`2T!+@$O`3`!,0$R`3,!-`%``4H!3@%2`5,!5`%5`58!
M5P%;`5P!70%B`6,!9P%H`6D!:@%K`6T!<0%S`70!=0%V`7<!>`&"`:H!]@$:
M`BD"+`(N`C`",@(T`C4"-P([`CT"/@(_`D`"00)"`D,"10)&`D<"2`))`DH"
M3`)-`DX"6@)>`G$"<P)\`GT"T`+4`BH#+0-2`UP#70->`V`#8P-D`V4#9@-H
M`VD#:@-K`VP#;0-N`V\#<`-R`W,#=`-U`W8#=P-X`WD#>@-[`WP#?0-^`W\#
M@`.!`X(#@P.$`X4#A@.'`XD#BP.,`XT#CP.0`Y4#G`.=`T-55V5895EE6F5;
M95QE8&5A96-E9&5G96EE;&5N98!EBF6.99QEH&7^901F````````````````
M`````````````````````(``HP"E`*8`J0"O`+(`M@"X`-8`V`#?`.(`YP#K
M`.L`[@#Q`/0`]@#X`/@`^P#[`/T```$"`1(!%`$:`1P!*@$L`4,!10%'`4D!
M3`%.`6H!;`'-`<\!SP'1`=$!TP'3`=4!U0'7`=<!V0'9`=L!VP'=`?@!^@%0
M`E("8`)B`L8"R`+(`LP"V`+:`I`#H@.B`ZH#L`/"`\(#R@,`!`($#P10!%`$
M4@0/(!$@$B`7(!<@&B`;(!X@)"`G("\@,2`Q(#0@-"`V(#H@/""K(*T@`B$$
M(00A!B$((0HA%2$7(2`A(B%?(6PA;R%Z(8\AE"&5(9HA!R()(@XB$"(0(A(B
M%"(6(ADB&R(<(B$B(B(D(B0B)B(F(BPB+2(O(C,B."(\(CXB1R))(DLB32)1
M(E,B7R)B(F,B:")M(G`BE"*6(I@BFB*D(J8BOB+`(A$C$R-?)&HD<R2<)/\D
M3"5/)70E@"60)9(EEB6?):(EL26T);LEOB7%)<@ERB7,)<TET"7A)>8E!"8'
M)@@F"B8_)D$F029#)H`N@BZ#+H4NARZ)+HHNC2Z6+I@NIBZH+JDNJRZM+J\N
MLBZT+K4NN"ZZ+KPNR2[++N\O_"__+P0P!#`8,!PP'S`@,"HP/3`_,$`PE#":
M,)\PH##W,/LP_S`$,2HQ'S(J,C`R,C*B,J0RC3.0,YLSGS.@,Z(SPS/%,\TS
MSS/0,],SU#/6,T8T2#1R-'0TG36?-0TV#S89-ALV%SD9.6TY;SG..=$YWCG@
M.7(Z=#I-.T\[;3QO/-\\X3Q50%=`7D%@039#.$.K0ZU#L$.R0]Q#WD/51-=$
M2T9-1F!&8D8B1R1'*$<J1WM'?4>,1XY'1DE(27E)>TE\27Y)@4F$281)ATF:
M29Q)GDF@2;5)N$EV3'A,GDRD3!)-&DVM3:]-_TVFG__79>@K^2WY>/EZ^93Y
MEOGF^>CY\/GR^0OZ$/H0^A+Z$OH5^A?Z&?H>^B+Z(OHE^B;Z*OHO_C+^,OY%
M_DC^4_Y3_EC^6/YG_F?^;/X`_U__W__F____40+]_T0!2`']_V$"````````
M````````-?XV_CG^.OX__D#^/?X^_D'^0OY#_D3^_?_]_SO^//XW_CC^,?[]
M_S/^-/X```````````````````````````).!$X%3@9.#TX23A=.'TX@3B%.
M(TXF3BE.+DXO3C%.,TXU3C=./$Y`3D%.0DY$3D9.2DY13E5.5TY:3EM.8DYC
M3F1.94YG3FA.:DYK3FQ.;4YN3F].<DYT3G5.=DYW3GA.>4YZ3GM.?$Y]3G].
M@$Z!3H).@TZ$3H5.ATZ*3I!.EDZ73IE.G$Z=3IY.HTZJ3J].L$ZQ3K1.MDZW
M3KA.N4Z\3KU.OD[(3LQ.ST[03M).VD[;3MQ.X$[B3N9.YT[I3NU.[D[O3O%.
M]$[X3OE.^D[\3OY.`$\"3P-/!$\%3P9/!T\(3PM/#$\23Q-/%$\53Q9/'$\=
M3R%/(T\H3RE/+$\M3RY/,4\S3S5/-T\Y3SM//D\_3T!/04]"3T1/14]'3TA/
M24]*3TM/3$]23U1/5D]A3V)/9D]H3VI/:T]M3VY/<4]R3W5/=T]X3WE/>D]]
M3X!/@4^"3X5/AD^'3XI/C$^.3Y!/DD^33Y5/ED^83YE/FD^<3YY/GT^A3Z)/
MI$^K3ZU/L$^Q3[)/LT^T3[9/MT^X3[E/ND^[3[Q/O4^^3\!/P4_"3\9/QT_(
M3\E/RT_,3\U/TD_33]1/U4_63]E/VT_@3^)/Y$_E3^=/ZT_L3_!/\D_T3_5/
M]D_W3_E/^T_\3_U/_T\`4`%0`E`#4`10!5`&4`=0"%`)4`I0"U`.4!!0$5`3
M4!50%E`74!M0'5`>4"!0(E`C4"10)U`K4"]0,%`Q4#)0,U`T4#50-E`W4#A0
M.5`[4#U0/U!`4$%00E!$4$501E!)4$I02U!-4%!045!24%-05%!64%=06%!9
M4%M075!>4%]08%!A4&)08U!D4&909U!H4&E0:E!K4&U0;E!O4'!0<5!R4'-0
M=%!U4'A0>5!Z4'Q0?5"!4()0@U"$4(90AU")4(I0BU",4(Y0CU"04)%0DE"3
M4)10E5"64)=0F%"94)I0FU"<4)U0GE"?4*!0H5"B4*10IE"J4*M0K5"N4*]0
ML%"Q4+-0M%"U4+90MU"X4+E0O%"]4+Y0OU#`4,%0PE##4,10Q5#&4,=0R%#)
M4,I0RU#,4,U0SE#04-%0TE#34-10U5#74-A0V5#;4-Q0W5#>4-]0X%#A4.)0
MXU#D4.50Z%#I4.I0ZU#O4/!0\5#R4/10]E#W4/A0^5#Z4/Q0_5#^4/]0`%$!
M40)1`U$$4051"%$)40I1#%$-40Y1#U$041%1$U$44151%E$741A1&5$:41M1
M'%$=41Y1'U$@42)1(U$D4251)E$G42A1*5$J42M1+%$M42Y1+U$P43%1,E$S
M4311-5$V43=1.%$Y43I1.U$\43U1/E%"44=12E%,44Y13U%045)14U%745A1
M65%;45U17E%?46!185%C46119E%G46E1:E%O47)1>E%^47]1@U&$4891AU&*
M48M1CE&/49!1D5&34911F%&:49U1GE&?4:%1HU&F4:=1J%&I4:I1K5&N4;11
MN%&Y4;I1OE&_4<%1PE'#4<51R%'*4<U1SE'04=)1TU'44=51UE'74=A1V5':
M4=Q1WE'?4>)1XU'E4>91YU'H4>E1ZE'L4>Y1\5'R4?11]U'^4012!5()4@M2
M#%(/4A!2$U(44A52'%(>4A]2(5(B4B-2)5(F4B=2*E(L4B]2,5(R4C12-5(\
M4CY21%)%4D921U)(4DE22U).4D]24E)34E525U)84EE26E);4EU27U)@4F)2
M8U)D4F92:%)K4FQ2;5)N4G!2<5)S4G12=5)V4G=2>%)Y4GI2>U)\4GY2@%*#
M4H12A5*&4H=2B5**4HM2C%*-4HY2CU*14I)2E%*54I92EU*84IE2FE*<4J12
MI5*F4J=2KE*O4K!2M%*U4K92MU*X4KE2NE*[4KQ2O5+`4L%2PE+$4L52QE+(
M4LI2S%+-4LY2SU+14M-2U%+54M=2V5+:4MM2W%+=4MY2X%+A4N)2XU+E4N92
MYU+H4NE2ZE+K4NQ2[5+N4N]2\5+R4O-2]%+U4O92]U+X4OM2_%+]4@%3`E,#
M4P13!U,)4PI3"U,,4PY3$5,24Q-3%%,84QM3'%,>4Q]3(E,D4R53)U,H4RE3
M*U,L4RU3+U,P4S%3,E,S4S13-5,V4S=3.%,\4SU30%-"4T131E-+4TQ335-0
M4U136%-94UM375-E4VA3:E-L4VU3<E-V4WE3>U-\4WU3?E.`4X%3@U.'4XA3
MBE..4X]3D%.14Y)3DU.44Y93EU.94YM3G%.>4Z!3H5.D4Z=3JE.K4ZQ3K5.O
M4[!3L5.R4[-3M%.U4[=3N%.Y4[I3O%.]4[Y3P%/#4\13Q5/&4\=3SE//4]!3
MTE/34]53VE/<4]U3WE/A4^)3YU/T4_I3_E/_4P!4`E0%5`=4"U045!A4&50:
M5!Q4(E0D5"54*E0P5#-4-E0W5#I4/50_5$%40E1$5$541U1)5$Q4351.5$]4
M451:5%U47E1?5&!4851C5&549U1I5&I4:U1L5&U4;E1O5'!4=%1Y5'I4?E1_
M5(%4@U2%5(=4B%2)5(I4C5215)-4EU285)Q4GE2?5*!4H52B5*54KE2P5+)4
MM52V5+=4N52Z5+Q4OE3#5,54RE3+5-94V%3;5.!4X53B5.-4Y%3K5.Q4[U3P
M5/%4]%3U5/94]U3X5/E4^U3^5`!5`E4#5015!54(50I5"U4,50U5#E4251-5
M%54651=5&%4951I5'%4=51Y5'U4A5255)E4H52E5*U4M53)5-%4U5395.%4Y
M53I5.U4]54!50E5%54=52%5+54Q5355.54]5455255-55%5755A5655:55M5
M755>55]58%5B56-5:%5I56M5;U5P57%5<E5S5715>55Z57U5?U6%5895C%6-
M58Y5D%6259-5E56659=5FE6;59Y5H%6A5:)5HU6D5:55IE6H5:E5JE6K5:Q5
MK56N5:]5L%6R5;15ME6X5;I5O%6_5<!5P57"5<-5QE7'5<A5RE7+5<Y5SU70
M5=55UU785=E5VE7;5=Y5X%7B5>=5Z57M5>Y5\%7Q5?15]E7X5?E5^E7[5?Q5
M_U4"5@-6!%8%5@96!U8*5@M6#5805A%6$E835A16%5865A=6&58:5AQ6'58@
M5B%6(E8E5B96*%8I5BI6*U8N5B]6,%8S5C56-U8X5CI6/%8]5CY60%9!5D)6
M0U9$5D561E9'5DA6259*5DM63U905E%64E935E565E9:5EM6759>5E]68%9A
M5F-6959F5F=6;59N5F]6<%9R5G-6=%9U5G=6>%9Y5GI6?59^5G]6@%:!5H)6
M@U:$5H=6B%:)5HI6BU:,5HU6D%:15I)6E%:55I96EU:85IE6FE:;5IQ6G5:>
M5I]6H%:A5J)6I%:E5J96IU:H5JE6JE:K5JQ6K5:N5K!6L5:R5K-6M%:U5K96
MN%:Y5KI6NU:]5KY6OU;`5L%6PE;#5L16Q5;&5L=6R%;)5LM6S%;-5LY6SU;0
M5M%6TE;35M56UE;85ME6W%;C5N56YE;G5NA6Z5;J5NQ6[E;O5O)6\U;V5O=6
M^%;[5OQ6`%<!5P)7!5<'5PM7#%<-5PY7#U<05Q%7$E<35Q17%5<65Q=7&%<9
M5QI7&U<=5QY7(%<A5R)7)%<E5R97)U<K5S%7,E<T5S57-E<W5SA7/%<]5S]7
M05=#5T1715=&5TA725=+5U)74U=45U575E=85UE78E=C5V579U=L5VY7<%=Q
M5W)7=%=U5WA7>5=Z5WU7?E=_5X!7@5>'5XA7B5>*5XU7CE>/5Y!7D5>45Y57
MEE>75YA7F5>:5YQ7G5>>5Y]7I5>H5ZI7K%>O5[!7L5>S5[57ME>W5[E7NE>[
M5[Q7O5>^5[]7P%?!5\17Q5?&5\=7R%?)5\I7S%?-5]!7T5?35]97UU?;5]Q7
MWE?A5^)7XU?E5^97YU?H5^E7ZE?K5^Q7[E?P5_%7\E?S5_57]E?W5_M7_%?^
M5_]7`5@#6`18!5@(6`E8"E@,6`Y8#U@06!)8$U@46!98%U@86!I8&U@<6!U8
M'U@B6"-8)5@F6"=8*%@I6"M8+%@M6"Y8+U@Q6#)8,U@T6#98-U@X6#E8.E@[
M6#Q8/5@^6#]80%A!6$)80UA%6$981UA(6$E82EA+6$Y83UA06%)84UA56%98
M5UA96%I86UA<6%U87UA@6&%88EAC6&189EAG6&A8:5AJ6&U8;EAO6'!8<5AR
M6'-8=%AU6'98=UAX6'E8>EA[6'Q8?5A_6()8A%B&6(=8B%B*6(M8C%B-6(Y8
MCUB06)%8E%B56)98EUB86)M8G%B=6*!8H5BB6*-8I%BE6*98IUBJ6*M8K%BM
M6*Y8KUBP6+%8LEBS6+18M5BV6+=8N%BY6+I8NUB]6+Y8OUC`6,)8PUC$6,98
MQUC(6,E8REC+6,Q8S5C.6,]8T%C26--8U%C66-=8V%C96-I8VUC<6-U8WEC?
M6.!8X5CB6.-8Y5CF6.=8Z%CI6.I8[5CO6/%8\ECT6/58]UCX6/I8^UC\6/U8
M_EC_6`!9`5D#6059!ED(60E9"ED+60Q9#ED061%9$ED361=9&%D;61U9'ED@
M62%9(EDC6299*%DL63!9,EDS6359-ED[63U9/ED_64!90UE%64992EE,64U9
M4%E265-965E;65Q975E>65]985EC66199EEG66A9:5EJ66M9;%EM66Y9;UEP
M67%9<EEU67=9>EE[67Q9?EE_68!9A5F)68M9C%F.68]9D%F16919E5F869I9
MFUF<69U9GUF@6:%9HEFF6:=9K%FM6;!9L5FS6;19M5FV6;=9N%FZ6;Q9O5F_
M6<!9P5G"6<-9Q%G%6<=9R%G)6<Q9S5G.6<]9U5G66=E9VUG>6=]9X%GA6>)9
MY%GF6>=9Z5GJ6>M9[5GN6>]9\%GQ6?)9\UGT6?59]EGW6?A9^EG\6?U9_ED`
M6@):"EH+6@U:#EH/6A!:$EH46A5:%EH76AE:&EH;6AU:'EHA6B):)%HF6B=:
M*%HJ6BM:+%HM6BY:+UHP6C-:-5HW6CA:.5HZ6CM:/5H^6C]:05I"6D-:1%I%
M6D=:2%I+6DQ:35I.6D]:4%I16E):4UI46E9:5UI86EE:6UI<6EU:7EI?6F!:
M85IC6F1:95IF6FA::5IK6FQ:;5IN6F]:<%IQ6G):<UIX6GE:>UI\6GU:?EJ`
M6H%:@EJ#6H1:A5J&6H=:B%J)6HI:BUJ,6HU:CEJ/6I!:D5J36I1:E5J66I=:
MF%J96IQ:G5J>6I]:H%JA6J):HUJD6J5:IEJG6JA:J5JK6JQ:K5JN6J]:L%JQ
M6K1:MEJW6KE:NEJ[6KQ:O5J_6L!:PUK$6L5:QEK'6LA:REK+6LU:SEK/6M!:
MT5K36M5:UUK96MI:VUK=6MY:WUKB6N1:Y5KG6NA:ZEKL6NU:[EKO6O!:\EKS
M6O1:]5KV6O=:^%KY6OI:^UK\6OU:_EK_6@!;`5L"6P-;!%L%6P9;!UL(6PI;
M"UL,6PU;#EL/6Q!;$5L26Q-;%%L56QA;&5L:6QM;'%L=6QY;'UL@6R%;(ELC
M6R1;)5LF6R=;*%LI6RI;*ULL6RU;+ELO6S!;,5LS6S5;-ELX6SE;.EL[6SQ;
M/5L^6S];05M"6T-;1%M%6T9;1UM(6TE;2EM+6TQ;35M.6T];4EM66UY;8%MA
M6V=;:%MK6VU;;EMO6W);=%MV6W=;>%MY6WM;?%M^6W];@EN&6XI;C5N.6Y!;
MD5N26Y1;EEN?6Z=;J%NI6ZQ;K5NN6Z];L5NR6[=;NEN[6[Q;P%O!6\-;R%O)
M6\I;RUO-6\Y;SUO16]1;U5O66]=;V%O96]I;VUO<6^!;XEOC6^9;YUOI6^I;
MZUOL6^U;[UOQ6_);\UOT6_5;]EOW6_U;_EL`7`)<`UP%7`=<"%P+7`Q<#5P.
M7!!<$EP37!=<&5P;7!Y<'UP@7"%<(UPF7"A<*5PJ7"M<+5PN7"]<,%PR7#-<
M-5PV7#=<0UQ$7$9<1UQ,7$U<4EQ37%1<5EQ77%A<6EQ;7%Q<75Q?7&)<9%QG
M7&A<:5QJ7&M<;%QM7'!<<EQS7'1<=5QV7'=<>%Q[7'Q<?5Q^7(!<@UR$7(5<
MAER'7(E<BER+7(Y<CUR27)-<E5R=7)Y<GUR@7*%<I%RE7*9<IURH7*I<KERO
M7+!<LERT7+9<N5RZ7+M<O%R^7,!<PES#7,5<QES'7,A<R5S*7,Q<S5S.7,]<
MT%S17--<U%S57-9<UUS87-I<VUS<7-U<WES?7.!<XESC7.=<Z5SK7.Q<[ESO
M7/%<\ESS7/1<]5SV7/=<^%SY7/I<_%S]7/Y<_UP`70%=!%T%70A="5T*70M=
M#%T-70]=$%T171)=$UT571==&%T971I='%T=71]=(%TA72)=(UTE72A=*ETK
M72Q=+UTP73%=,ETS735=-ETW73A=.5TZ73M=/%T_74!=05U"74-=1%U%749=
M2%U)74U=3EU/75!=45U275-=5%U5759=5UU975I=7%U>75]=8%UA76)=8UUD
M765=9EUG76A=:EUM76Y=<%UQ77)=<UUU779==UUX77E=>EU[77Q=?5U^77]=
M@%V!78-=A%V%789=AUV(78E=BEV+78Q=C5V.78]=D%V179)=DUV4795=EEV7
M79A=FEV;79Q=GEV?7:!=H5VB7:-=I%VE7:9=IUVH7:E=JEVK7:Q=K5VN7:]=
ML%VQ7;)=LUVT7;5=MEVX7;E=NEV[7;Q=O5V^7;]=P%W!7<)=PUW$7<9=QUW(
M7<E=REW+7<Q=SEW/7=!=T5W27=-=U%W57=9=UUW87=E=VEW<7=]=X%WC7>1=
MZEWL7>U=\%WU7?9=^%WY7?I=^UW\7?]=`%X$7@=>"5X*7@M>#5X.7A)>$UX7
M7AY>'UX@7B%>(EXC7B1>)5XH7BE>*EXK7BQ>+UXP7C)>,UXT7C5>-EXY7CI>
M/EX_7D!>05Y#7D9>1UY(7DE>2EY+7DU>3EY/7E!>45Y27E->5EY77EA>65Y:
M7EQ>75Y?7F!>8UYD7F5>9EYG7FA>:5YJ7FM>;%YM7FY>;UYP7G%>=5YW7GE>
M?EZ!7H)>@UZ%7HA>B5Z,7HU>CEZ27IA>FUZ=7J%>HEZC7J1>J%ZI7JI>JUZL
M7JY>KUZP7K%>LEZT7KI>NUZ\7KU>OU[`7L%>PE[#7L1>Q5[&7L=>R%[+7LQ>
MS5[.7L]>T%[47M5>UU[87ME>VE[<7MU>WE[?7N!>X5[B7N->Y%[E7N9>YU[I
M7NM>[%[M7NY>[U[P7O%>\E[S7O5>^%[Y7OM>_%[]7@5?!E\'7PE?#%\-7PY?
M$%\27Q1?%E\97QI?'%\=7QY?(5\B7R-?)%\H7RM?+%\N7S!?,E\S7S1?-5\V
M7S=?.%\[7SU?/E\_7T%?0E]#7T1?15]&7T=?2%])7TI?2U],7TU?3E]/7U%?
M5%]97UI?6U]<7UY?7U]@7V-?95]G7VA?:U]N7V]?<E]T7W5?=E]X7WI??5]^
M7W]?@U^&7XU?CE^/7Y%?DU^47Y9?FE^;7YU?GE^?7Z!?HE^C7Z1?I5^F7Z=?
MJ5^K7ZQ?KU^P7[%?LE^S7[1?ME^X7[E?NE^[7[Y?OU_`7\%?PE_'7\A?RE_+
M7\Y?TU_47]5?VE_;7]Q?WE_?7^)?XU_E7^9?Z%_I7^Q?[U_P7_)?\U_T7_9?
M]U_Y7_I?_%\'8`A@"6`+8`Q@$&`18!-@%V`88!I@'F`?8")@(V`D8"Q@+6`N
M8#!@,6`R8#-@-&`V8#=@.&`Y8#I@/6`^8$!@1&!%8$9@1V!(8$E@2F!,8$Y@
M3V!18%-@5&!68%=@6&!;8%Q@7F!?8&!@86!E8&9@;F!Q8')@=&!U8'=@?F"`
M8(%@@F"%8(9@AV"(8(I@BV".8(]@D&"18)-@E6"78)A@F6"<8)Y@H6"B8*1@
MI6"G8*E@JF"N8+!@LV"U8+9@MV"Y8+I@O6"^8+]@P&#!8,)@PV#$8,=@R&#)
M8,Q@S6#.8,]@T&#28--@U&#68-=@V6#;8-Y@X6#B8.-@Y&#E8.I@\6#R8/5@
M]V#X8/M@_&#]8/Y@_V`"80-A!&$%80=A"F$+80QA$&$181)A$V$4819A%V$8
M81EA&V$<81UA'F$A82)A)6$H82EA*F$L82UA+F$O83!A,6$R83-A-&$U839A
M-V$X83EA.F$[83QA/6$^84!A06%"84-A1&%%849A1V%)84MA36%/85!A4F%3
M851A5F%785AA66%:85MA7&%>85]A8&%A86-A9&%E869A:6%J86MA;&%M86YA
M;V%Q87)A<V%T879A>&%Y87IA>V%\87UA?F%_88!A@6&"88-AA&&%889AAV&(
M88EABF&,88UACV&089%ADF&3895AEF&789AAF6&:89MAG&&>89]AH&&A8:)A
MHV&D8:5AIF&J8:MAK6&N8:]AL&&Q8;)ALV&T8;5AMF&X8;EANF&[8;QAO6&_
M8<!AP6'#8<1AQ6'&8<=AR6',8<UASF'/8=!ATV'58=9AUV'88=EAVF';8=QA
MW6'>8=]AX&'A8>)AXV'D8>5AYV'H8>EAZF'K8>QA[6'N8>]A\&'Q8?)A\V'T
M8?9A]V'X8?EA^F'[8?QA_6'^80!B`6("8@-B!&(%8@=B"6(38A1B&6(<8AUB
M'F(@8B-B)F(G8BAB*6(K8BUB+V(P8C%B,F(U8C9B.&(Y8CIB.V(\8D)B1&)%
M8D9B2F)/8E!B56)68E=B66):8EQB76)>8E]B8&)A8F)B9&)E8FAB<6)R8G1B
M=6)W8GAB>F)[8GUB@6*"8H-BA6*&8H=BB&*+8HQBC6*.8H]BD&*48IEBG&*=
M8IYBHV*F8J=BJ6*J8JUBKF*O8K!BLF*S8K1BMF*W8KABNF*^8L!BP6+#8LMB
MSV+18M5BW6+>8N!BX6+D8NIBZV+P8O)B]6+X8OEB^F+[8@!C`V,$8P5C!F,*
M8PMC#&,-8P]C$&,28Q-C%&,58Q=C&&,98QQC)F,G8REC+&,M8RYC,&,Q8S-C
M-&,U8S9C-V,X8SMC/&,^8S]C0&-!8T1C1V-(8TIC46-28U-C5&-68U=C6&-9
M8UIC6V-<8UUC8&-D8V5C9F-H8VIC:V-L8V]C<&-R8W-C=&-U8WAC>6-\8WUC
M?F-_8X%C@V.$8X5CAF.+8XUCD6.38Y1CE6.78YECFF.;8YQCG6.>8Y]CH6.D
M8Z9CJV.O8[%CLF.U8[9CN6.[8[UCOV/`8\%CPF/#8\5CQV/(8\ICRV/,8]%C
MTV/48]5CUV/88]ECVF/;8]QCW6/?8^)CY&/E8^9CYV/H8^MC[&/N8^]C\&/Q
M8_-C]6/W8_EC^F/[8_QC_F,#9`1D!F0'9`AD"60*9`UD#F019!)D%6069!=D
M&&099!ID'60?9")D(V0D9"5D)V0H9"ED*V0N9"]D,&0Q9#)D,V0U9#9D-V0X
M9#ED.V0\9#YD0&1"9$-D261+9$QD361.9$]D4&119%-D56169%=D661:9%MD
M7&1=9%]D8&1A9&)D8V1D9&5D9F1H9&ID:V1L9&YD;V1P9'%D<F1S9'1D=61V
M9'=D>V1\9'UD?F1_9(!D@62#9(9DB&2)9(IDBV2,9(UDCF2/9)!DDV249)=D
MF&2:9)MDG&2=9)]DH&2A9*)DHV2E9*9DIV2H9*IDJV2O9+%DLF2S9+1DMF2Y
M9+MDO62^9+]DP63#9,1DQF3'9,ADR63*9,MDS&3/9-%DTV349-5DUF399-ID
MVV3<9-UDWV3@9.%DXV3E9.=DZ&3I9.IDZV3L9.UD[F3O9/!D\63R9/-D]&3U
M9/9D]V3X9/ED^F3[9/QD_63^9/]D`64"90-E!&4%909E!V4(90IE"V4,90UE
M#F4/91!E$643911E%64691=E&64:91ME'&4=91YE'V4@92%E(F4C921E)F4G
M92AE*64J92QE+64P93%E,F4S93=E.F4\93UE0&5!94)E0V5$949E1V5*94ME
M365.95!E4F53951E5V5895IE7&5?96!E865D965E9V5H96EE:F5M96YE;V5Q
M97-E=65V97AE>65Z97ME?&5]97YE?V6`98%E@F6#981EA66&98AEB66*98UE
MCF6/99)EE&65999EF&6:99UEGF6@9:)EHV6F9:AEJF6L9:YEL66R9;-EM&6U
M9;9EMV6X9;IENV6^9;]EP&7"9<=ER&7)9<IES6709=%ETV749=5EV&799=IE
MVV7<9=UEWF7?9>%EXV7D9>IEZV7R9?-E]&7U9?AE^67[9?QE_67^9?]E`68$
M9@5F!V8(9@EF"V8-9A!F$6829A9F%V889AIF&V8<9AYF(68B9B-F)&8F9BEF
M*F8K9BQF+F8P9C)F,V8W9CAF.68Z9CMF/68_9D!F0F9$9D5F1F9'9DAF269*
M9DUF3F909E%F6&999EMF7&9=9EYF8&9B9F-F969G9FEF:F9K9FQF;69Q9G)F
M<V9U9GAF>69[9GQF?69_9H!F@6:#9H5FAF:(9HEFBF:+9HUFCF:/9I!FDF:3
M9I1FE6:89IEFFF:;9IQFGF:?9J!FH6:B9J-FI&:E9J9FJ6:J9JMFK&:M9J]F
ML&:Q9K)FLV:U9K9FMV:X9KIFNV:\9KUFOV;`9L%FPF;#9L1FQ6;&9L=FR&;)
M9LIFRV;,9LUFSF;/9M!FT6;29M-FU&;59M9FUV;89MIFWF;?9N!FX6;B9N-F
MY&;E9N=FZ&;J9NMF[&;M9NYF[V;Q9O5F]F;X9OIF^V;]9@%G`F<#9P1G!6<&
M9P=G#&<.9P]G$6<29Q-G%F<89QEG&F<<9QYG(&<A9R)G(V<D9R5G)V<I9RYG
M,&<R9S-G-F<W9SAG.6<[9SQG/F<_9T%G1&=%9T=G2F=+9TUG4F=49U5G5V=8
M9UEG6F=;9UUG8F=C9V1G9F=G9VMG;&=N9W%G=&=V9WAG>6=Z9WMG?6>`9X)G
M@V>%9X9GB&>*9XQGC6>.9X]GD6>29Y-GE&>69YEGFV>?9Z!GH6>D9Z9GJ6>L
M9ZYGL6>R9[1GN6>Z9[MGO&>]9[YGOV?`9\)GQ6?&9\=GR&?)9\IGRV?,9\UG
MSF?59]9GUV?;9]]GX6?C9^1GYF?G9^AGZF?K9^UG[F?R9_5G]F?W9_AG^6?Z
M9_MG_&?^9P%H`F@#:`1H!F@-:!!H$F@4:!5H&&@9:!IH&V@<:!YH'V@@:")H
M(V@D:"5H)F@G:"AH*V@L:"UH+F@O:#!H,6@T:#5H-F@Z:#MH/VA':$MH36A/
M:%)H5FA7:%AH66A::%MH7&A=:%YH7VAJ:&QH;6AN:&]H<&AQ:')H<VAU:'AH
M>6AZ:'MH?&A]:'YH?VB`:()HA&B':(AHB6B*:(MHC&B-:(YHD&B1:))HE&B5
M:)9HF&B9:)IHFVB<:)UHGFB?:*!HH6BC:*1HI6BI:*IHJVBL:*YHL6BR:+1H
MMFBW:+AHN6BZ:+MHO&B]:+YHOVC!:,-HQ&C%:,9HQVC(:,IHS&C.:,]HT&C1
M:--HU&C6:-=HV6C;:-QHW6C>:-]HX6CB:.1HY6CF:.=HZ&CI:.IHZVCL:.UH
M[VCR:/-H]&CV:/=H^&C[:/UH_FC_:`!I`FD#:01I!FD':0AI"6D*:0QI#VD1
M:1-I%&D5:19I%VD8:1EI&FD;:1QI'6D>:2%I(FDC:25I)FDG:2AI*6DJ:2MI
M+&DN:2]I,6DR:3-I-6DV:3=I.&DZ:3MI/&D^:4!I06E#:41I16E&:4=I2&E)
M:4II2VE,:4UI3FE/:5!I46E2:5-I56E6:5AI66E;:5QI7VEA:6)I9&EE:6=I
M:&EI:6II;&EM:6]I<&ER:7-I=&EU:79I>FE[:7UI?FE_:8%I@VF%:8IIBVF,
M:8YICVF0:9%IDFF3:99IEVF9:9IIG6F>:9]IH&FA::)IHVFD::5IIFFI::II
MK&FN::]IL&FR:;-IM6FV:;AIN6FZ:;QIO6F^:;]IP&G":<-IQ&G%:<9IQVG(
M:<EIRVG-:<]IT6G2:=-IU6G6:==IV&G9:=IIW&G=:=YIX6GB:>-IY&GE:>9I
MYVGH:>EIZFGK:>QI[FGO:?!I\6GS:?1I]6GV:?=I^&GY:?II^VG\:?YI`&H!
M:@)J`VH$:@5J!FH':@AJ"6H+:@QJ#6H.:@]J$&H1:A)J$VH4:A5J%FH9:AIJ
M&VH<:AUJ'FH@:B)J(VHD:B5J)FHG:BEJ*VHL:BUJ+FHP:C)J,VHT:C9J-VHX
M:CEJ.FH[:CQJ/VI`:D%J0FI#:D5J1FI(:DEJ2FI+:DQJ36I.:D]J46I2:E-J
M5&I5:E9J5VI::EQJ76I>:E]J8&IB:F-J9&IF:F=J:&II:FIJ:VIL:FUJ;FIO
M:G!J<FIS:G1J=6IV:G=J>&IZ:GMJ?6I^:G]J@6J":H-JA6J&:H=JB&J):HIJ
MBVJ,:HUJCVJ2:I-JE&J5:I9JF&J9:IIJFVJ<:IUJGFJ?:J%JHFJC:J1JI6JF
M:J=JJ&JJ:JUJKFJO:K!JL6JR:K-JM&JU:K9JMVJX:KEJNFJ[:KQJO6J^:K]J
MP&K!:L)JPVK$:L5JQFK':LAJR6K*:LMJS&K-:LYJSVK0:M%JTFK3:M1JU6K6
M:M=JV&K9:MIJVVK<:MUJWFK?:N!JX6KB:N-JY&KE:N9JYVKH:NEJZFKK:NQJ
M[6KN:N]J\&KQ:O)J\VKT:O5J]FKW:OAJ^6KZ:OMJ_&K]:OYJ_VH`:P%K`FL#
M:P1K!6L&:P=K"&L):PIK"VL,:PUK#FL/:Q!K$6L2:Q-K%&L5:Q9K%VL8:QEK
M&FL;:QQK'6L>:Q]K)6LF:RAK*6LJ:RMK+&LM:RYK+VLP:S%K,VLT:S5K-FLX
M:SMK/&L]:S]K0&M!:T)K1&M%:TAK2FM+:TUK3FM/:U!K46M2:U-K5&M5:U9K
M5VM8:UIK6VM<:UUK7FM?:V!K86MH:VEK:VML:VUK;FMO:W!K<6MR:W-K=&MU
M:W9K=VMX:WIK?6M^:W]K@&N%:XAKC&N.:X]KD&N1:Y1KE6N7:YAKF6N<:YUK
MGFN?:Z!KHFNC:Z1KI6NF:Z=KJ&NI:ZMKK&NM:ZYKKVNP:[%KLFNV:[AKN6NZ
M:[MKO&N]:[YKP&O#:\1KQFO':\AKR6O*:\QKSFO0:]%KV&O::]QKW6O>:]]K
MX&OB:^-KY&OE:^9KYVOH:^EK[&OM:^YK\&OQ:_)K]&OV:_=K^&OZ:_MK_&O^
M:_]K`&P!;`)L`VP$;`AL"6P*;`ML#&P.;!)L%VP<;!UL'FP@;"-L)6PK;"QL
M+6PQ;#-L-FPW;#EL.FP[;#QL/FP_;$-L1&Q%;$AL2VQ,;$UL3FQ/;%%L4FQ3
M;%9L6&Q9;%IL8FQC;&5L9FQG;&ML;&QM;&YL;VQQ;'-L=6QW;'AL>FQ[;'QL
M?VR`;(1LAVR*;(MLC6R.;)%LDFR5;)9LEVR8;)ILG&R=;)YLH&RB;*ALK&RO
M;+!LM&RU;+9LMVRZ;,!LP6S";,-LQFS';,ALRVS-;,YLSVS1;-)LV&S9;-IL
MW&S=;-]LY&SF;.=LZ6SL;.UL\FST;/EL_VP`;0)M`VT%;09M"&T);0IM#6T/
M;1!M$6T3;11M%6T6;1AM'&T=;1]M(&TA;2)M(VTD;29M*&TI;2QM+6TO;3!M
M-&TV;3=M.&TZ;3]M0&U";41M26U,;5!M56U6;5=M6&U;;5UM7VUA;6)M9&UE
M;6=M:&UK;6QM;6UP;7%M<FUS;75M=FUY;7IM>VU];7YM?VV`;8%M@VV$;89M
MAVV*;8MMC6V/;9!MDFV6;9=MF&V9;9IMG&VB;:5MK&VM;;!ML6VS;;1MMFVW
M;;EMNFV[;;QMO6V^;<%MPFW#;<AMR6W*;<UMSFW/;=!MTFW3;=1MU6W7;=IM
MVVW<;=]MXFWC;>5MYVWH;>EMZFWM;>]M\&WR;?1M]6WV;?AM^FW];?YM_VT`
M;@%N`FX#;@1N!FX';@AN"6X+;@]N$FX3;A5N&&X9;AMN'&X>;A]N(FXF;B=N
M*&XJ;BQN+FXP;C%N,VXU;C9N-VXY;CMN/&X];CYN/VY`;D%N0FY%;D9N1VY(
M;DEN2FY+;DQN3VY0;E%N4FY5;E=N66Y:;EQN76Y>;F!N86YB;F-N9&YE;F9N
M9VYH;FEN:FYL;FUN;VYP;G%N<FYS;G1N=6YV;G=N>&YY;GIN>VY\;GUN@&Z!
M;H)NA&Z';HANBFZ+;HQNC6Z.;I%NDFZ3;I1NE6Z6;I=NF6Z:;IMNG6Z>;J!N
MH6ZC;J1NIFZH;JENJVZL;JUNKFZP;K-NM6ZX;KENO&Z^;K]NP&[#;L1NQ6[&
M;LANR6[*;LQNS6[.;M!NTF[6;MANV6[;;MQNW6[C;N=NZF[K;NQN[6[N;N]N
M\&[Q;O)N\V[U;O9N]V[X;OIN^V[\;OUN_F[_;@!O`6\#;P1O!6\';PAO"F\+
M;PQO#6\.;Q!O$6\2;Q9O%V\8;QEO&F\;;QQO'6\>;Q]O(6\B;R-O)6\F;R=O
M*&\L;RYO,&\R;S1O-6\W;SAO.6\Z;SMO/&\];S]O0&]!;T)O0V]$;T5O2&])
M;TIO3&].;T]O4&]1;U)O4V]4;U5O5F]7;UEO6F];;UUO7V]@;V%O8V]D;V5O
M9V]H;VEO:F]K;VQO;V]P;W%O<V]U;W9O=V]Y;WMO?6]^;W]O@&^!;X)O@V^%
M;X9OAV^*;XMOCV^0;Y%ODF^3;Y1OE6^6;Y=OF&^9;YIOFV^=;YYOGV^@;Z)O
MHV^D;Z5OIF^H;ZEOJF^K;ZQOK6^N;Z]OL&^Q;[)OM&^U;[=ON&^Z;[MOO&^]
M;[YOOV_!;\-OQ&_%;\9OQV_(;\IORV_,;\UOSF_/;]!OTV_4;]5OUF_7;]AO
MV6_:;]MOW&_=;]]OXF_C;^1OY6_F;^=OZ&_I;^IOZV_L;^UO\&_Q;_)O\V_T
M;_5O]F_W;_AO^6_Z;_MO_&_];_YO_V\`<`%P`G`#<`1P!7`&<`=P"'`)<`IP
M"W`,<`UP#G`/<!!P$G`3<!1P%7`6<!=P&'`9<!QP'7`><!]P('`A<")P)'`E
M<"9P)W`H<"EP*G`K<"QP+7`N<"]P,'`Q<#)P,W`T<#9P-W`X<#IP.W`\<#UP
M/G`_<$!P07!"<$-P1'!%<$9P1W!(<$EP2G!+<$UP3G!0<%%P4G!3<%1P57!6
M<%=P6'!9<%IP6W!<<%UP7W!@<&%P8G!C<&1P97!F<&=P:'!I<&IP;G!Q<')P
M<W!T<'=P>7!Z<'MP?7"!<()P@W"$<(9PAW"(<(MPC'"-<(]PD'"1<)-PEW"8
M<)IPFW"><)]PH'"A<*)PHW"D<*5PIG"G<*APJ7"J<+!PLG"T<+5PMG"Z<+YP
MOW#$<,5PQG#'<,EPRW#,<,UPSG#/<-!PT7#2<--PU'#5<-9PUW#:<-QPW7#>
M<.!PX7#B<.-PY7#J<.YP\'#Q</)P\W#T</5P]G#X</IP^W#\</YP_W``<0%Q
M`G$#<01Q!7$&<0=Q"'$+<0QQ#7$.<0]Q$7$2<11Q%W$;<1QQ'7$><1]Q('$A
M<2)Q(W$D<25Q)W$H<2EQ*G$K<2QQ+7$N<3)Q,W$T<35Q-W$X<3EQ.G$[<3QQ
M/7$^<3]Q0'%!<4)Q0W%$<49Q1W%(<4EQ2W%-<4]Q4'%1<5)Q4W%4<55Q5G%7
M<5AQ67%:<5MQ77%?<6!Q87%B<6-Q97%I<6IQ:W%L<6UQ;W%P<7%Q='%U<79Q
M=W%Y<7MQ?'%^<7]Q@'&!<8)Q@W&%<89QAW&(<8EQBW&,<8UQCG&0<9%QDG&3
M<95QEG&7<9IQFW&<<9UQGG&A<:)QHW&D<:5QIG&G<:EQJG&K<:UQKG&O<;!Q
ML7&R<;1QMG&W<;AQNG&[<;QQO7&^<;]QP''!<<)QQ''%<<9QQW'(<<EQRG'+
M<<QQS7'/<=!QT7'2<=-QUG'7<=AQV7':<=MQW''=<=YQWW'A<>)QXW'D<>9Q
MZ''I<>IQZW'L<>UQ[W'P<?%Q\G'S<?1Q]7'V<?=Q^''Z<?MQ_'']<?YQ_W$`
M<@%R`G(#<@1R!7('<@AR"7(*<@MR#'(-<@YR#W(0<A%R$G(3<A1R%7(6<A=R
M&'(9<AIR&W(<<AYR'W(@<B%R(G(C<B1R)7(F<B=R*7(K<BUR+G(O<C)R,W(T
M<CIR/'(^<D!R07)"<D-R1')%<D9R27)*<DMR3G)/<E!R47)3<E1R57)7<EAR
M6G)<<EYR8')C<F1R97)H<FIR:W)L<FUR<')Q<G-R=')V<G=R>')[<GQR?7*"
M<H-RA7*&<H=RB'*)<HQRCG*0<I%RDW*4<I5REG*7<IARF7*:<IMRG'*=<IYR
MH'*A<J)RHW*D<J5RIG*G<JARJ7*J<JMRKG*Q<K)RLW*U<KIRNW*\<KUROG*_
M<L!RQ7+&<L=RR7+*<LMRS'+/<M%RTW+4<M5RUG+8<MIRVW+*`LL"V0(3(!4@
M)2`U(`4A"2&6(9<AF"&9(14B'R(C(E(B9B)G(K\B4"51)5(E4R54)54E5B57
M)5@E625:)5LE7"5=)5XE7R5@)6$E8B5C)60E925F)6<E:"5I)6HE:R5L)6TE
M;B5O)7`E<25R)7,E@26")8,EA"6%)88EAR6()8DEBB6+)8PEC26.)8\EDR64
M)94EO"6])>(EXR7D)>4E"2:5(A(P'3`>,/W__?_]__W__?_]__W__?_]__W_
M_?\A,"(P(S`D,"4P)C`G,"@P*3"C,HXSCS.<,YTSGC.A,\0SSC/1,](SU3,P
M_N+_Y/_]_R$A,3+]_Q`@_?_]__W__#";,)PP_3#^,`8PG3">,$G^2OY+_DS^
M3?Y._D_^4/Y1_E+^5/Y5_E;^5_Y9_EK^6_Y<_EW^7OY?_F#^8?YB_F/^9/YE
M_F;^:/YI_FK^:_[]__W__?_]__W__?_]__W__?_]__W__?_]_P<P_?_]__W_
M_?_]__W__?_]__W__?_<<MURWW+B<N-RY'+E<N9RYW+J<NMR]7+V<OER_7+^
M<O]R`',"<P1S!7,&<P=S"',)<PMS#',-<P]S$',1<Q)S%',8<QES&G,?<R!S
M(W,D<R9S)W,H<RUS+W,P<S)S,W,U<S9S.G,[<SQS/7-`<T%S0G-#<T1S17-&
M<T=S2'-)<TIS2W-,<TYS3W-1<U-S5'-5<U9S6'-9<UIS6W-<<UUS7G-?<V%S
M8G-C<V1S97-F<V=S:'-I<VIS:W-N<W!S<7-R<W-S='-U<W9S=W-X<WES>G-[
M<WQS?7-_<X!S@7."<X-SA7.&<XASBG.,<XUSCW.0<Y)SDW.4<Y5SEW.8<YES
MFG.<<YUSGG.@<Z%SHW.D<Z5SIG.G<ZASJG.L<ZUSL7.T<[5SMG.X<[ESO'.]
M<[YSOW/!<\-SQ'/%<\9SQW/+<\QSSG/2<]-SU'/5<]9SUW/8<]ISVW/<<]US
MWW/A<^)SXW/D<^9SZ'/J<^MS['/N<^]S\'/Q<_-S]'/U<_9S]W/X<_ES^G/[
M<_QS_7/^<_]S`'0!=`)T!'0'=`AT"W0,=`UT#G01=!)T$W04=!5T%G07=!AT
M&70<=!UT'G0?="!T(70C="1T)W0I="MT+70O=#%T,G0W=#AT.70Z=#MT/70^
M=#]T0'1"=$-T1'1%=$9T1W1(=$ET2G1+=$QT371.=$]T4'11=%)T4W14=%9T
M6'1==&!T871B=&-T9'1E=&9T9W1H=&ET:G1K=&QT;G1O='%T<G1S='1T=71X
M='ET>G1[='QT?71_=()TA'2%=(9TB'2)=(ITC'2-=(]TD722=)-TE'25=)9T
MEW28=)ETFG2;=)UTGW2@=*%THG2C=*1TI72F=*ITJW2L=*UTKG2O=+!TL72R
M=+-TM'2U=+9TMW2X=+ETNW2\=+UTOG2_=,!TP73"=,-TQ'3%=,9TQW3(=,ET
MRG3+=,QTS73.=,]TT'31=--TU'35=-9TUW38=-ETVG3;=-UTWW3A=.5TYW3H
M=.ETZG3K=.QT[73P=/%T\G3S=/5T^'3Y=/IT^W3\=/UT_G0`=0%U`G4#=05U
M!G4'=0AU"74*=0MU#'4.=1!U$G44=15U%G47=1MU'74>=2!U(74B=2-U)'4F
M=2=U*G4N=31U-G4Y=3QU/74_=4%U0G5#=41U1G5'=4EU2G5-=5!U4752=5-U
M5756=5=U6'5==5YU7W5@=6%U8G5C=61U9W5H=6EU:W5L=6UU;G5O=7!U<75S
M=75U=G5W=7IU>W5\=7UU?G6`=8%U@G6$=85UAW6(=8EUBG6,=8UUCG60=9-U
ME768=9MUG'6>=:)UIG6G=:AUJ76J=:UUMG6W=;IUNW6_=<!UP77&=<MUS'7.
M=<]UT'71==-UUW79==IUW'7===]UX'7A=>5UZ77L=>UU[G7O=?)U\W7U=?9U
M]W7X=?IU^W7]=?YU`G8$=@9V!W8(=@EV"W8-=@YV#W81=A)V$W84=A9V&G8<
M=AUV'G8A=B-V)W8H=BQV+G8O=C%V,G8V=C=V.78Z=CMV/79!=D)V1'9%=D9V
M1W9(=DEV2G9+=DYV3W90=E%V4G93=E5V5W98=EEV6G9;=EUV7W9@=F%V8G9D
M=F5V9G9G=FAV:79J=FQV;79N=G!V<79R=G-V='9U=G9V=W9Y=GIV?'9_=H!V
M@7:#=H5VB7:*=HQVC7:/=I!VDG:4=I5VEW:8=IIVFW:<=IUVGG:?=J!VH7:B
M=J-VI7:F=J=VJ':I=JIVJW:L=JUVKW:P=K-VM7:V=K=VN':Y=KIVNW:\=KUV
MOG;`=L%VPW;$=L=VR7;+=LQVTW;5=MEVVG;<=MUVWG;@=N%VXG;C=N1VYG;G
M=NAVZ7;J=NMV[';M=O!V\W;U=O9V]W;Z=OMV_7;_=@!W`G<#=P5W!G<*=PQW
M#G</=Q!W$7<2=Q-W%'<5=Q9W%W<8=QMW''<==QYW(7<C=R1W)7<G=RIW*W<L
M=RYW,'<Q=S)W,W<T=SEW.W<]=SYW/W="=T1W17=&=TAW27=*=TMW3'=-=TYW
M3W=2=U-W5'=5=U9W5W=8=UEW7'===UYW7W=@=V1W9W=I=VIW;7=N=V]W<'=Q
M=W)W<W=T=W5W=G=W=WAW>G=[=WQW@7>"=X-WAG>'=XAWB7>*=XMWCW>0=Y-W
ME'>5=Y9WEW>8=YEWFG>;=YQWG7>>=Z%WHW>D=Z9WJ'>K=ZUWKG>O=[%WLG>T
M=[9WMW>X=[EWNG>\=[YWP'?!=\)WPW?$=\5WQG?'=\AWR7?*=\MWS'?.=\]W
MT'?1=])WTW?4=]5WUG?8=]EWVG?==]YWWW?@=^%WY'?F=^AWZG?O=_!W\7?R
M=_1W]7?W=_EW^G?[=_QW`W@$>`5X!G@'>`AX"G@+>`YX#W@0>!-X%7@9>!MX
M'G@@>"%X(G@D>"AX*G@K>"YX+W@Q>#)X,W@U>#9X/7@_>$%X0GA#>$1X1GA(
M>$EX2GA+>$UX3WA1>%-X5'A8>%EX6GA;>%QX7GA?>&!X87AB>&-X9'AE>&9X
M9WAH>&EX;WAP>'%X<GAS>'1X=7AV>'AX>7AZ>'MX?7A^>']X@'B!>()X@WB$
M>(5XAGB(>(IXBWB/>)!XDGB4>)5XEGB9>)UXGGB@>*)XI'BF>*AXJ7BJ>*MX
MK'BM>*YXKWBU>+9XMWBX>+IXNWB\>+UXOWC`>,)XPWC$>,9XQWC(>,QXS7C.
M>,]XT7C2>--XUGC7>-AXVGC;>-QXW7C>>-]XX'CA>.)XXWCD>.5XYGCG>.EX
MZGCK>.UX[GCO>/!X\7CS>/5X]GCX>/EX^WC\>/UX_GC_>`!Y`GD#>01Y!GD'
M>0AY"7D*>0MY#'D->0YY#WD0>1%Y$GD4>15Y%GD7>1AY&7D:>1MY''D=>1]Y
M('DA>2)Y(WDE>29Y)WDH>2EY*GDK>2QY+7DN>2]Y,'DQ>3)Y,WDU>39Y-WDX
M>3EY/7D_>4)Y0WE$>45Y1WE*>4MY3'E->4YY3WE0>5%Y4GE4>55Y6'E9>6%Y
M8WED>69Y:7EJ>6MY;'EN>7!Y<7ER>7-Y='EU>79Y>7E[>7QY?7E^>7]Y@GF#
M>89YAWF(>8EYBWF,>8UYCGF0>9%YDGF3>91YE7F6>9=YF'F9>9MYG'F=>9YY
MGWF@>:%YHGFC>:1YI7FF>:AYJ7FJ>:MYK'FM>:YYKWFP>;%YLGFT>;5YMGFW
M>;AYO'F_><)YQ'G%><=YR'G*><QYSGG/>=!YTWG4>=9YUWG9>=IYVWG<>=UY
MWGG@>>%YXGGE>>AYZGGL>>YY\7GR>?-Y]'GU>?9Y]WGY>?IY_'G^>?]Y`7H$
M>@5Z!WH(>@EZ"GH,>@]Z$'H1>A)Z$WH5>A9Z&'H9>AMZ''H=>A]Z(7HB>B1Z
M)7HF>B=Z*'HI>BIZ*WHL>BUZ+GHO>C!Z,7HR>C1Z-7HV>CAZ.GH^>D!Z07I"
M>D-Z1'I%>D=Z2'I)>DIZ2WI,>DUZ3GI/>E!Z4GI3>E1Z57I6>EAZ67I:>EMZ
M7'I=>EYZ7WI@>F%Z8GIC>F1Z97IF>F=Z:'II>FIZ:WIL>FUZ;GIO>G%Z<GIS
M>G5Z>WI\>GUZ?GJ">H5ZAWJ)>HIZBWJ,>HYZCWJ0>I-ZE'J9>IIZFWJ>>J%Z
MHGJC>J1ZIWJI>JIZJWJN>J]ZL'JQ>K)ZM'JU>K9ZMWJX>KEZNGJ[>KQZO7J^
M>L!ZP7K">L-ZQ'K%>L9ZQWK(>LEZRGK,>LUZSGK/>M!ZT7K2>M-ZU'K5>M=Z
MV'K:>MMZW'K=>N%ZXGKD>N=ZZ'KI>NIZZWKL>NYZ\'KQ>O)Z\WKT>O5Z]GKW
M>OAZ^WK\>OYZ`'L!>P)[!7L'>PE[#'L->PY[$'L2>Q-[%GL7>QA[&GL<>QU[
M'WLA>R)[(WLG>RE[+7LO>S![,GLT>S5[-GLW>SE[.WL]>S][0'M!>T)[0WM$
M>T9[2'M*>TU[3GM3>U5[5WM9>UQ[7GM?>V%[8WMD>V5[9GMG>VA[:7MJ>VM[
M;'MM>V][<'MS>W1[=GMX>WI[?'M]>W][@7N">X-[A'N&>X=[B'N)>XI[BWN,
M>XY[CWN1>Y)[DWN6>YA[F7N:>YM[GGN?>Z![HWND>Z5[KGNO>[![LGNS>[5[
MMGNW>[E[NGN[>[Q[O7N^>[][P'O">\-[Q'O%>\A[R7O*>\M[S7O.>\][T'O2
M>]1[U7O6>]=[V'O;>]Q[WGO?>^![XGOC>^1[YWOH>^E[ZWOL>^U[[WOP>_)[
M\WOT>_5[]GOX>_E[^GO[>_U[_WL`?`%\`GP#?`1\!7P&?`A\"7P*?`U\#GP0
M?!%\$GP3?!1\%7P7?!A\&7P:?!M\''P=?!Y\('PA?")\(WPD?"5\*'PI?"M\
M+'PM?"Y\+WPP?#%\,GPS?#1\-7PV?#=\.7PZ?#M\/'P]?#Y\0GQ#?$1\17Q&
M?$=\2'Q)?$I\2WQ,?$Y\3WQ0?%%\4GQ3?%1\57Q6?%=\6'Q9?%I\6WQ<?%U\
M7GQ??&!\87QB?&-\9'QE?&9\9WQH?&E\:GQK?&Q\;7QN?&]\<'QQ?')\=7QV
M?'=\>'QY?'I\?GQ_?(!\@7R"?(-\A'R%?(9\AWR(?(I\BWR,?(U\CGR/?)!\
MDWR4?)9\F7R:?)M\H'RA?*-\IGRG?*A\J7RK?*Q\K7RO?+!\M'RU?+9\MWRX
M?+I\NWR_?,!\PGS#?,1\QGS)?,M\SGS/?-!\T7S2?--\U'S8?-I\VWS=?-Y\
MX7SB?.-\Y'SE?.9\YWSI?.I\ZWSL?.U\[GSP?/%\\GSS?/1\]7SV?/=\^7SZ
M?/Q\_7S^?/]\`'T!?0)]`WT$?05]!GT'?0A]"7T+?0Q]#7T.?0]]$'T1?1)]
M$WT4?15]%GT7?1A]&7T:?1M]''T=?1Y]'WTA?2-])'TE?29]*'TI?2I]+'TM
M?2Y],'TQ?3)],WTT?35]-GTW?3A].7TZ?3M]/'T]?3Y]/WU`?4%]0GU#?41]
M17U&?4=]2'U)?4I]2WU,?4U]3GU/?5!]47U2?5-]5'U5?59]5WU8?5E]6GU;
M?5Q]77U>?5]]8'UA?6)]8WUD?65]9GUG?6A]:7UJ?6M];'UM?6]]<'UQ?7)]
M<WUT?75]=GUX?7E]>GU[?7Q]?7U^?7]]@'V!?8)]@WV$?85]AGV'?8A]B7V*
M?8M]C'V-?8Y]CWV0?9%]DGV3?91]E7V6?9=]F'V9?9I]FWV<?9U]GGV??:!]
MH7VB?:-]I'VE?:=]J'VI?:I]JWVL?:U]KWVP?;%]LGVS?;1]M7VV?;=]N'VY
M?;I]NWV\?;U]OGV_?<!]P7W"?<-]Q'W%?<9]QWW(?<E]RGW+?<Q]S7W.?<]]
MT'W1?=)]TWW4?=5]UGW7?=A]V7W:?=M]W'W=?=Y]WWW@?>%]XGWC?>1]Y7WF
M?>=]Z'WI?>I]ZWWL?>U][GWO??!]\7WR??-]]'WU??9]]WWX??E]^GW[??Q]
M_7W^??]]`'X!?@)^`WX$?@5^!GX'?@A^"7X*?@M^#'X-?@Y^#WX0?A%^$GX3
M?A1^%7X6?A=^&'X9?AI^&WX<?AU^'GX??B!^(7XB?B-^)'XE?B9^)WXH?BE^
M*GXK?BQ^+7XN?B]^,'XQ?C)^,WXT?C5^-GXW?CA^.7XZ?CQ^/7X^?C]^0'Y"
M?D-^1'Y%?D9^2'Y)?DI^2WY,?DU^3GY/?E!^47Y2?E-^5'Y5?E9^5WY8?EE^
M6GY;?EQ^77Y>?E]^8'YA?F)^8WYD?F5^9GYG?FA^:7YJ?FM^;'YM?FY^;WYP
M?G%^<GYS?G1^=7YV?G=^>'YY?GI^>WY\?GU^?GY_?H!^@7Z#?H1^A7Z&?H=^
MB'Z)?HI^BWZ,?HU^CGZ/?I!^D7Z2?I-^E'Z5?I9^EWZ8?IE^FGZ<?IU^GGZN
M?K1^NWZ\?M9^Y'[L?OE^"G\0?QY_-W\Y?SM_/'\]?SY_/W]`?T%_0W]&?T=_
M2'])?TI_2W],?TU_3G]/?U)_4W]6?UE_6W]<?UU_7G]@?V-_9']E?V9_9W]K
M?VQ_;7]O?W!_<W]U?W9_=W]X?WI_>W]\?WU_?W^`?X)_@W^$?X5_AG^'?XA_
MB7^+?XU_CW^0?Y%_DG^3?Y5_EG^7?YA_F7^;?YQ_H'^B?Z-_I7^F?ZA_J7^J
M?ZM_K'^M?ZY_L7^S?[1_M7^V?[=_NG^[?[Y_P'_"?\-_Q'_&?\=_R'_)?\M_
MS7_/?]!_T7_2?]-_UG_7?]E_VG_;?]Q_W7_>?^)_XW_D?^=_Z'_J?^M_['_M
M?^]_\G_T?_5_]G_W?_A_^7_Z?_U__G__?P*`!X`(@`F`"H`.@`^`$8`3@!J`
M&X`=@!Z`'X`A@".`)(`K@"R`+8`N@"^`,(`R@#2`.8`Z@#R`/H!`@$&`1(!%
M@$>`2(!)@$Z`3X!0@%&`4X!5@%:`5X!9@%N`7(!=@%Z`7X!@@&&`8H!C@&2`
M98!F@&>`:(!K@&R`;8!N@&^`<(!R@'.`=(!U@':`=X!X@'F`>H![@'R`?8!^
M@(&`@H"%@(B`BH"-@(Z`CX"0@)&`DH"4@)6`EX"9@)Z`HX"F@*>`J("L@+"`
MLX"U@+:`N("Y@+N`Q8#'@,B`R8#*@,N`SX#0@-&`TH#3@-2`U8#8@-^`X(#B
M@..`YH#N@/6`]X#Y@/N`_H#_@`"!`8$#@02!!8$'@0B!"X$,@16!%X$9@1N!
M'($=@1^!(($A@2*!(X$D@26!)H$G@2B!*8$J@2N!+8$N@3"!,X$T@36!-X$Y
M@3J!.X$\@3V!/X%`@4&!0H%#@42!18%'@4F!38%.@4^!4H%6@5>!6(%;@5R!
M78%>@5^!88%B@6.!9(%F@6B!:H%K@6R!;X%R@7.!=8%V@7>!>(&!@8.!A(&%
M@8:!AX&)@8N!C(&-@8Z!D(&2@9.!E(&5@9:!EX&9@9J!GH&?@:"!H8&B@:2!
MI8&G@:F!JX&L@:V!KH&O@;"!L8&R@;2!M8&V@;>!N(&Y@;R!O8&^@;^!Q('%
M@<>!R(')@<N!S8'.@<^!T('1@=*!TX'4@=6!UH'7@=B!V8':@=N!W('=@=Z!
MWX'@@>&!XH'D@>6!YH'H@>F!ZX'N@>^!\('Q@?*!]8'V@?>!^('Y@?J!_8'_
M@0."!X((@@F""H(+@@Z"#X(1@A."%8(6@A>"&((9@AJ"'8(@@B2")8(F@B>"
M*8(N@C*".H(\@CV"/X)`@D&"0H)#@D6"1H)(@DJ"3()-@DZ"4()1@E*"4X)4
M@E6"5H)7@EF"6X)<@EV"7H)@@F&"8H)C@F2"98)F@F>":8)J@FN";()M@G&"
M=8)V@G>">()[@GR"@(*!@H."A8*&@H>"B8*,@I""DX*4@I6"EH*:@IN"GH*@
M@J*"HX*G@K*"M8*V@KJ"NX*\@K^"P(+"@L."Q8+&@LF"T(+6@MF"VH+=@N*"
MYX+H@NF"ZH+L@NV"[H+P@O*"\X+U@O:"^(+Z@OR"_8+^@O^"`(,*@PN##8,0
M@Q*#$X,6@QB#&8,=@QZ#'X,@@R&#(H,C@R2#)8,F@RF#*H,N@S"#,H,W@SN#
M/8,^@S^#08-"@T2#18-(@TJ#2X-,@TV#3H-3@U6#5H-7@UB#68-=@V*#<(-Q
M@W*#<X-T@W6#=H-Y@WJ#?H-_@X"#@8."@X.#A(.'@XB#BH.+@XR#C8./@Y"#
MD8.4@Y6#EH.7@YF#FH.=@Y^#H8.B@Z.#I(.E@Z:#IX.L@ZV#KH.O@[6#NX.^
M@[^#PH/#@\2#QH/(@\F#RX/-@\Z#T(/1@]*#TX/5@]>#V8/:@]N#WH/B@^.#
MY(/F@^>#Z(/K@^R#[8/N@^^#\X/T@_6#]H/W@_J#^X/\@_Z#_X,`A`*$!80'
MA`B$"80*A!"$$H03A!2$%806A!>$&80:A!N$'H0?A""$(80BA".$*80JA"N$
M+(0MA"Z$+X0PA#*$,X0TA#6$-H0WA#F$.H0[A#Z$/X1`A$&$0H1#A$2$181'
MA$B$281*A$N$3(1-A$Z$3X10A%*$4X14A%6$5H18A%V$7H1?A&"$8H1DA&6$
M9H1GA&B$:H1NA&^$<(1RA'2$=X1YA'N$?(1]A'Z$?X2`A(&$@X2$A(6$AH2*
MA(V$CX20A)&$DH23A)2$E826A)B$FH2;A)V$GH2?A*"$HH2CA*2$I82FA*>$
MJ(2IA*J$JX2LA*V$KH2PA+&$LX2UA+:$MX2[A+R$OH3`A,*$PX3%A,:$QX3(
MA,N$S(3.A,^$TH34A-6$UX38A-F$VH3;A-R$WH3AA.*$Y(3GA.B$Z83JA.N$
M[83NA.^$\83RA/.$](3UA/:$]X3XA/F$^H3[A/V$_H0`A0&%`H4#A02%!84&
MA0>%"(4)A0J%"X4-A0Z%#X40A1*%%(45A1:%&(49A1N%'(4=A1Z%((4BA2.%
M)(4EA2:%)X4HA2F%*H4MA2Z%+X4PA3&%,H4SA32%-84VA3Z%/X5`A4&%0H5$
MA46%1H5'A4N%3(5-A4Z%3X50A5&%4H53A52%5857A5B%6H5;A5R%785?A6"%
M885BA6.%985FA6>%:85JA6N%;(5MA6Z%;X5PA7&%<X5UA7:%=X5XA7R%?85_
MA8"%@86"A8.%AH6(A8F%BH6+A8R%C86.A9"%D862A9.%E(65A9:%EX68A9F%
MFH6=A9Z%GX6@A:&%HH6CA:6%IH6GA:F%JX6LA:V%L86RA;.%M(6UA;:%N(6Z
MA;N%O(6]A;Z%OX7`A<*%PX7$A<6%QH7'A<B%RH7+A<R%S87.A=&%TH74A=:%
MUX78A=F%VH7;A=V%WH7?A>"%X87BA>.%Y87FA>>%Z(7JA>N%[(7MA>Z%[X7P
MA?&%\H7SA?2%]87VA?>%^(7YA?J%_(7]A?Z%`(8!A@*&`X8$A@:&!X8(A@F&
M"H8+A@R&#88.A@^&$(82AA.&%(85AA>&&(89AAJ&&X8<AAV&'H8?AB"&(88B
MAB.&)(8EAB:&*(8JABN&+(8MABZ&+X8PAC&&,H8SAC2&-88VAC>&.88ZACN&
M/88^AC^&0(9!AD*&0X9$AD6&1H9'ADB&289*ADN&3(92AE.&5896AE>&6(99
MAEN&7(9=AE^&8(9AAF.&9(9EAF:&9X9HAFF&:H9MAF^&<(9RAG.&=(9UAG:&
M=X9XAH.&A(:%AH:&AX:(AHF&CH:/AI"&D8:2AI2&EH:7AIB&F8::AIN&GH:?
MAJ"&H8:BAJ6&IH:KAJV&KH:RAK.&MX:XAKF&NX:\AKV&OH:_AL&&PH;#AL6&
MR(;,ALV&TH;3AM6&UH;7AMJ&W(;=AN"&X8;BAN.&Y8;FAN>&Z(;JANN&[(;O
MAO6&]H;WAOJ&^X;\AOV&_X8!AP2'!8<&APN'#(<.AP^'$(<1AQ2'%H<9AQN'
M'8<?AR"')(<FAR>'*(<JARN'+(<MAR^',(<RAS.'-8<VASB'.8<ZASR'/8=`
MAT&'0H=#AT2'18=&ATJ'2X=-AT^'4(=1AU*'5(=5AU:'6(=:AUN'7(==AUZ'
M7X=AAV*'9H=GAVB':8=JAVN';(=MAV^'<8=RAW.'=8=WAWB'>8=ZAW^'@(>!
MAX2'AH>'AXF'BH>,AXZ'CX>0AY&'DH>4AY6'EH>8AYF'FH>;AYR'G8>>AZ"'
MH8>BAZ.'I(>EAZ:'IX>IAZJ'KH>PA[&'LH>TA[:'MX>XA[F'NX>\A[Z'OX?!
MA\*'PX?$A\6'QX?(A\F'S(?-A\Z'SX?0A]2'U8?6A]>'V(?9A]J'W(?=A]Z'
MWX?AA^*'XX?DA^:'YX?HA^F'ZX?LA^V'[X?PA_&'\H?SA_2']8?VA_>'^(?Z
MA_N'_(?]A_^'`(@!B`*(!(@%B`:(!X@(B`F("X@,B`V(#H@/B!"($8@2B!2(
M%X@8B!F(&H@<B!V('H@?B""((X@DB"6()H@GB"B(*8@JB"N(+(@MB"Z(+X@P
MB#&(,X@TB#6(-H@WB#B(.H@[B#V(/H@_B$&(0HA#B$:(1XA(B$F(2HA+B$Z(
M3XA0B%&(4HA3B%6(5HA8B%J(6XA<B%V(7HA?B&"(9HAGB&J(;8AOB'&(<XAT
MB'6(=HAXB'F(>HA[B'R(@(B#B(:(AXB)B(J(C(B.B(^(D(B1B).(E(B5B)>(
MF(B9B)J(FXB=B)Z(GXB@B*&(HXBEB*:(IXBHB*F(JHBLB*Z(KXBPB+*(LXBT
MB+6(MHBXB+F(NHB[B+V(OHB_B,"(PXC$B,>(R(C*B,N(S(C-B,^(T(C1B-.(
MUHC7B-J(VXC<B-V(WHC@B.&(YHCGB.F(ZHCKB.R([8CNB.^(\HCUB/:(]XCZ
MB/N(_8C_B`")`8D#B02)!8D&B0>)"(D)B0N)#(D-B0Z)#XD1B12)%8D6B1>)
M&(D<B1V)'HD?B2")(HDCB22))HDGB2B)*8DLB2V)+HDOB3&),HDSB36)-XDX
MB3F).HD[B3R)/8D^B3^)0(E"B4.)18E&B4>)2(E)B4J)2XE,B4V)3HE/B5")
M48E2B5.)5(E5B5:)5XE8B5F)6HE;B5R)78E@B6&)8HECB62)98EGB6B):8EJ
MB6N);(EMB6Z);XEPB7&)<HESB72)=8EVB7>)>(EYB7J)?(E]B7Z)@(F"B82)
MA8F'B8B)B8F*B8N)C(F-B8Z)CXF0B9&)DHF3B92)E8F6B9>)F(F9B9J)FXF<
MB9V)GHF?B:")H8FBB:.)I(FEB::)IXFHB:F)JHFKB:R)K8FNB:^)L(FQB;*)
MLXFTB;6)MHFWB;B)N8FZB;N)O(F]B;Z)OXG`B<.)S8G3B=2)U8G7B=B)V8G;
MB=V)WXG@B>&)XHGDB>>)Z(GIB>J)[(GMB>Z)\(GQB?*)](GUB?:)]XGXB?F)
M^HG[B?R)_8G^B?^)`8H"B@.*!(H%B@:*"(H)B@J*"XH,B@V*#HH/BA"*$8H2
MBA.*%(H5BA:*%XH8BAF*&HH;BAR*'8H>BA^*((HABB**(XHDBB6*)HHGBBB*
M*8HJBBN*+(HMBBZ*+XHPBC&*,HHSBC2*-8HVBC>*.(HYBCJ*.XH\BCV*/XI`
MBD&*0HI#BD2*18I&BD>*28I*BDN*3(I-BDZ*3XI0BE&*4HI3BE2*58I6BE>*
M6(I9BEJ*6XI<BEV*7HI?BF"*88IBBF.*9(IEBF:*9XIHBFF*:HIKBFR*;8IN
MBF^*<(IQBG**<XITBG6*=HIWBGB*>HI[BGR*?8I^BG^*@(J!BH**@XJ$BH6*
MAHJ'BHB*BXJ,BHV*CHJ/BI"*D8J2BI2*E8J6BI>*F(J9BIJ*FXJ<BIV*GHJ?
MBJ"*H8JBBJ.*I(JEBJ:*IXJHBJF*JHJKBJR*K8JNBJ^*L(JQBK**LXJTBK6*
MMHJWBKB*N8JZBKN*O(J]BKZ*OXK`BL&*PHK#BL2*Q8K&BL>*R(K)BLJ*RXK,
MBLV*SHK/BM"*T8K2BM.*U(K5BM:*UXK8BMF*VHK;BMR*W8K>BM^*X(KABN**
MXXKDBN6*YHKGBNB*Z8KJBNN*[(KMBNZ*[XKPBO&*\HKSBO2*]8KVBO>*^(KY
MBOJ*^XK\BOV*_HK_B@"+`8L"BP.+!(L%BP:+"(L)BPJ+"XL,BPV+#HL/BQ"+
M$8L2BQ.+%(L5BQ:+%XL8BQF+&HL;BQR+'8L>BQ^+((LABR*+(XLDBR6+)XLH
MBRF+*HLKBRR++8LNBR^+,(LQBS*+,XLTBS6+-HLWBSB+.8LZBSN+/(L]BSZ+
M/XM`BT&+0HM#BT2+18M&BT>+2(M)BTJ+2XM,BTV+3HM/BU"+48M2BU.+5(M5
MBU:+5XM8BUF+6HM;BUR+78M>BU^+8(MABV*+8XMDBV6+9XMHBVF+:HMKBVV+
M;HMOBW"+<8MRBW.+=(MUBW:+=XMXBWF+>HM[BWR+?8M^BW^+@(N!BX*+@XN$
MBX6+AHN'BXB+B8N*BXN+C(N-BXZ+CXN0BY&+DHN3BY2+E8N6BY>+F(N9BYJ+
MFXN<BYV+GHN?BZR+L8N[B\>+T(OJBPF,'HPXC#F,.HP[C#R,/8P^C#^,0(Q"
MC$.,1(Q%C$B,2HQ+C$V,3HQ/C%",48Q2C%.,5(Q6C%>,6(Q9C%N,7(Q=C%Z,
M7XQ@C&.,9(QEC&:,9XQHC&F,;(QMC&Z,;XQPC'&,<HQTC'6,=HQWC'N,?(Q]
MC'Z,?XR`C(&,@XR$C(:,AXR(C(N,C8R.C(^,D(R1C)*,DXR5C):,EXR9C)J,
MFXR<C)V,GHR?C*",H8RBC*.,I(REC*:,IXRHC*F,JHRKC*R,K8RNC*^,L(RQ
MC+*,LXRTC+6,MHRWC+B,N8RZC+N,O(R]C+Z,OXS`C,&,PHS#C,2,Q8S&C,>,
MR(S)C,J,RXS,C,V,SHS/C-",T8S2C-.,U(S5C-:,UXS8C-F,VHS;C-R,W8S>
MC-^,X(SAC.*,XXSDC.6,YHSGC.B,Z8SJC.N,[(SMC.Z,[XSPC/&,\HSSC/2,
M]8SVC/>,^(SYC/J,^XS\C/V,_HS_C`"-`8T"C0.-!(T%C0:-!XT(C0F-"HT+
MC0R-#8T.C0^-$(T1C1*-$XT4C16-%HT7C1B-&8T:C1N-'(T@C5&-4HU7C5^-
M98UHC6F-:HULC6Z-;XUQC7*->(UYC7J->XU\C7V-?HU_C8"-@HV#C8:-AXV(
MC8F-C(V-C8Z-CXV0C9*-DXV5C9:-EXV8C9F-FHV;C9R-G8V>C:"-H8VBC:2-
MI8VFC:>-J(VIC:J-JXVLC:V-KHVOC;"-LHVVC;>-N8V[C;V-P(W!C<*-Q8W'
MC<B-R8W*C<V-T(W2C=.-U(W5C=B-V8W<C>"-X8WBC>6-YHWGC>F-[8WNC?"-
M\8WRC?2-]HW\C?Z-_XT`C@&.`HX#C@2.!HX'C@B."XX-C@Z.$(X1CA*.$XX5
MCA:.%XX8CAF.&HX;CAR.((XACB2.)8XFCB>.*(XKCBV.,(XRCC..-(XVCC>.
M.(X[CCR./HX_CD..18Y&CDR.38Y.CD^.4(Y3CE2.58Y6CE>.6(Y:CEN.7(Y=
MCEZ.7XY@CF&.8HYCCF2.98YGCFB.:HYKCFZ.<8YSCG6.=XYXCGF.>HY[CGV.
M?HZ`CH*.@XZ$CH:.B(Z)CHJ.BXZ,CHV.CHZ1CI*.DXZ5CI:.EXZ8CIF.FHZ;
MCIV.GXZ@CJ&.HHZCCJ2.I8ZFCJ>.J(ZICJJ.K8ZNCK".L8ZSCK2.M8ZVCK>.
MN(ZYCKN.O(Z]CKZ.OX[`CL&.PH[#CL2.Q8[&CL>.R([)CLJ.RX[,CLV.SX[0
MCM&.TH[3CM2.U8[6CM>.V([9CMJ.VX[<CMV.WH[?CN".X8[BCN..Y([ECN:.
MYX[HCNF.ZH[KCNR.[8[NCN^.\([QCO*.\X[TCO6.]H[WCOB.^8[ZCON._([]
MCOZ._XX`CP&/`H\#CP2/!8\&CP>/"(\)CPJ/"X\,CPV/#H\/CQ"/$8\2CQ./
M%(\5CQ:/%X\8CQF/&H\;CQR/'8\>CQ^/((\ACR*/(X\DCR6/)H\GCRB/*8\J
MCRN/+(\MCRZ/+X\PCS&/,H\SCS2/-8\VCS>/.(\YCSJ/.X\\CSV//H\_CT"/
M08]"CT./1(]%CT:/1X](CTF/2H]+CTR/38].CT^/4(]1CU*/4X]4CU6/5H]7
MCUB/68]:CUN/7(]=CUZ/7X]@CV&/8H]CCV2/98]JCX"/C(^2CYV/H(^ACZ*/
MI(^ECZ:/IX^JCZR/K8^NCZ^/LH^SC[2/M8^WC[B/NH^[C[R/OX_`C\./QH_)
MC\J/RX_,C\V/SX_2C]:/UX_:C^"/X8_CC^>/[(_OC_&/\H_TC_6/]H_ZC_N/
M_(_^C_^/!Y`(D`R0#I`3D!60&)`9D!R0(Y`DD"60)Y`HD"F0*I`KD"R0,)`Q
MD#*0,Y`TD#>0.9`ZD#V0/Y!`D$.019!&D$B029!*D$N03)!.D%2059!6D%F0
M6I!<D%V07I!?D&"089!DD&:09Y!ID&J0:Y!LD&^0<)!QD'*0<Y!VD'>0>)!Y
MD'J0>Y!\D'Z0@9"$D(60AI"'D(F0BI",D(V0CI"/D)"0DI"4D):0F)":D)R0
MGI"?D*"0I)"ED*>0J)"ID*N0K9"RD+>0O)"]D+^0P)#"D,.0QI#(D,F0RY#,
MD,V0TI#4D-60UI#8D-F0VI#>D-^0X)#CD.20Y9#ID.J0[)#ND/"0\9#RD/.0
M]9#VD/>0^9#ZD/N0_)#_D`"1`9$#D061!I$'D0B1"9$*D0N1#)$-D0Z1#Y$0
MD1&1$I$3D121%9$6D1>1&)$:D1N1')$=D1^1()$AD221)9$FD2>1*)$ID2J1
M*Y$LD2V1+I$PD3*1,Y$TD361-I$WD3B1.I$[D3R1/9$^D3^10)%!D4*11)%%
MD4>12)%1D5.15)%5D5:16)%9D5N17)%?D6"19I%GD6B1:Y%MD7.1>I%[D7R1
M@)&!D8*1@Y&$D8:1B)&*D8Z1CY&3D921E9&6D9>1F)&9D9R1G9&>D9^1H)&A
MD:21I9&FD:>1J)&ID:N1K)&PD;&1LI&SD;:1MY&XD;F1NY&\D;V1OI&_D<"1
MP9'"D<.1Q)'%D<:1R)'+D="1TI'3D=21U9'6D=>1V)'9D=J1VY'=D=Z1WY'@
MD>&1XI'CD>21Y9'FD>>1Z)'ID>J1ZY'LD>V1[I'OD?"1\9'RD?.1])'UD?:1
M]Y'XD?F1^I'[D?R1_9'^D?^1`)(!D@*2`Y($D@62!I('D@B2"9(*D@N2#)(-
MD@Z2#Y(0DA&2$I(3DA22%9(6DA>2&)(9DAJ2&Y(<DAV2'I(?DB"2(9(BDB.2
M))(EDB:2)Y(HDBF2*I(KDBR2+9(NDB^2,)(QDC*2,Y(TDC62-I(WDCB2.9(Z
MDCN2/)(]DCZ2/Y)`DD&20I)#DD2219)&DD>22)))DDJ22Y),DDV23I)/DE"2
M49)2DE.25))5DE:25Y)8DEF26I);DER279)>DE^28))ADF*28Y)DDF629I)G
MDFB2:9)JDFN2;))MDFZ2;Y)PDG&2<I)SDG62=I)WDGB2>9)ZDGN2?))]DGZ2
M?Y*`DH&2@I*#DH22A9*&DH>2B)*)DHJ2BY*,DHV2CY*0DI&2DI*3DI22E9*6
MDI>2F)*9DIJ2FY*<DIV2GI*?DJ"2H9*BDJ.2I)*EDJ:2IY*HDJF2JI*KDJR2
MK9*ODK"2L9*RDK.2M)*UDK:2MY*XDKF2NI*[DKR2O9*^DK^2P)+!DL*2PY+$
MDL62QI+'DLF2RI++DLR2S9+.DL^2T)+1DM*2TY+4DM62UI+7DMB2V9+:DMN2
MW)+=DMZ2WY+@DN&2XI+CDN22Y9+FDN>2Z)+IDNJ2ZY+LDNV2[I+ODO"2\9+R
MDO.2])+UDO:2]Y+XDOF2^I+[DOR2_9+^DO^2`),!DP*3`Y,$DP63!I,'DPB3
M"9,*DPN3#),-DPZ3#Y,0DQ&3$I,3DQ23%9,6DQ>3&),9DQJ3&Y,<DQV3'I,?
MDR"3(9,BDR.3)),EDR:3)Y,HDRF3*I,KDRR3+9,NDR^3,),QDS*3,Y,TDS63
M-I,WDSB3.9,ZDSN3/),]DS^30)-!DT*30Y-$DT631I-'DTB329-*DTN33)--
MDTZ33Y-0DU&34I-3DU2359-6DU>36)-9DUJ36Y-<DUV37I-?DV"389-BDV.3
M9)-EDV:39Y-HDVF3:Y-LDVV3;I-ODW"3<9-RDW.3=)-UDW:3=Y-XDWF3>I-[
MDWR3?9-^DW^3@).!DX*3@Y.$DX63AI.'DXB3B9.*DXN3C).-DXZ3D).1DY*3
MDY.4DY63EI.7DYB3F9.:DYN3G).=DYZ3GY.@DZ&3HI.CDZ23I9.FDZ>3J).I
MDZJ3JY.LDZV3KI.OD["3L9.RD[.3M).UD[:3MY.XD[F3NI.[D[R3O9.^D[^3
MP)/!D\*3PY/$D\63QI/'D\B3R9/+D\R3S9/.D\^3T)/1D]*3TY/4D]63UY/8
MD]F3VI/;D]R3W9/>D]^3X)/AD^*3XY/DD^63YI/GD^B3Z9/JD^N3[)/MD^Z3
M[Y/PD_&3\I/SD_23]9/VD_>3^)/YD_J3^Y/\D_V3_I/_DP"4`90"E`.4!)0%
ME`:4!Y0(E`F4"I0+E`R4#90.E`^4$)01E!*4$Y04E!64%I07E!B4&90:E!N4
M')0=E!Z4'Y0@E"&4(I0CE"24)90FE">4*)0IE"J4*Y0LE"V4+I0OE#"4,90R
ME#.4-)0UE#:4-Y0XE#F4.I0[E#R4/90_E$"4091"E$.41)1%E$:41Y1(E$F4
M2I1+E$R4391.E$^44)11E%*44Y14E%645I17E%B4691:E%N47)1=E%Z47Y1@
ME&&48I1CE&24991FE&>4:)1IE&J4;)1ME&Z4;Y1PE'&4<I1SE'24=91VE'>4
M>)1YE'J4>Y1\E'V4?I1_E("4@92"E(.4A)21E):4F)3'E,^4TY34E-J4YI3[
ME!R5()4GE3.5/95#E4B52Y55E5J58)5NE725=95WE7B5>95ZE7N5?)5]E7Z5
M@)6!E8*5@Y6$E865AI6'E8B5B96*E8N5C)6-E8Z5CY60E9&5DI63E925E966
ME9>5F)69E9J5FY6<E9V5GI6?E:"5H96BE:.5I)6EE::5IY6HE:F5JI6KE:R5
MK96NE:^5L)6QE;*5LY6TE;65MI6WE;B5N96ZE;N5O)6]E;Z5OY7`E<&5PI7#
ME<25Q97&E<>5R)7)E<J5RY7,E<V5SI7/E="5T972E=.5U)75E=:5UY78E=F5
MVI7;E=R5W97>E=^5X)7AE>*5XY7DE>65YI7GE>R5_Y4'EA.6&)8;EAZ6()8C
MEB26)98FEB>6*)8IEBN6+)8MEB^6,)8WECB6.98ZECZ6099#EDJ63I9/EE&6
M4I93EE:65Y98EEF66I9<EEV67I9@EF.6999FEFN6;99NEF^6<)9QEG.6>)9Y
MEGJ6>Y9\EGV6?I9_EH"6@9:"EH.6A):'EHF6BI:,EHZ6D9:2EI.6E9:6EIJ6
MFY:=EIZ6GY:@EJ&6HI:CEJ26I9:FEJB6J9:JEJN6K):MEJZ6KY:QEK*6M):U
MEK>6N):ZEKN6OY;"EL.6R);*ELN6T);1EM.6U);6EM>6V);9EMJ6VY;<EMV6
MWI;?EN&6XI;CEN26Y9;FEN>6ZY;LENV6[I;PEO&6\I;TEO66^);ZEON6_);]
MEO^6`I<#EP67"I<+EPR7$)<1EQ*7%)<5EQ>7&)<9EQJ7&Y<=EQ^7()<AER*7
M(Y<DER67)I<GERB7*9<KERR7+I<OES&7,Y<TES67-I<WESJ7.Y<\ESV7/Y=`
MET&70I=#ET2719=&ET>72)=)ETJ72Y=,ETV73I=/EU"749=4EU675Y=8EUJ7
M7)==EU^78Y=DEV:79Y=HEVJ7:Y=LEVV7;I=OEW"7<9=REW67=Y=XEWF7>I=[
MEWV7?I=_EX"7@9>"EX.7A)>&EX>7B)>)EXJ7C)>.EX^7D)>3EY67EI>7EYF7
MFI>;EYR7G9>>EY^7H9>BEZ27I9>FEZ>7J)>IEZJ7K)>NE["7L9>SE[67MI>W
ME[B7N9>ZE[N7O)>]E[Z7OY?`E\&7PI?#E\27Q9?&E\>7R)?)E\J7RY?,E\V7
MSI?/E]"7T9?2E].7U)?5E]:7UY?8E]F7VI?;E]R7W9?>E]^7X)?AE^*7XY?D
ME^67Z)?NE^^7\)?QE_*7])?WE_B7^9?ZE_N7_)?]E_Z7_Y<`F`&8`I@#F`28
M!9@&F`>8")@)F`J8"Y@,F`V8#I@/F!"8$9@2F!.8%)@5F!:8%Y@8F!F8&I@;
MF!R8'9@>F!^8()@AF"*8(Y@DF"68)I@GF"B8*9@JF"N8+)@MF"Z8+Y@PF#&8
M,I@SF#28-9@VF#>8.)@YF#J8.Y@\F#V8/I@_F$"809A"F$.81)A%F$:81YA(
MF$F82IA+F$R839A.F$^84)A1F%*84YA4F%685IA7F%B869A:F%N87)A=F%Z8
M7YA@F&&88IACF&2899AFF&>8:)AIF&J8:YALF&V8;IAOF'"8<9ARF'.8=)B+
MF(Z8DIB5F)F8HYBHF*F8JIBKF*R8K9BNF*^8L)BQF+*8LYBTF+68MIBWF+B8
MN9BZF+N8O)B]F+Z8OYC`F,&8PIC#F,28Q9C&F,>8R)C)F,J8RYC,F,V8SYC0
MF-28UIC7F-N8W)C=F."8X9CBF..8Y)CEF.:8Z9CJF.N8[)CMF.Z8[YCPF/&8
M\ICSF/28]9CVF/>8^)CYF/J8^YC\F/V8_IC_F`"9`9D"F0.9!)D%F0:9!YD(
MF0F9"ID+F0R9#ID/F1&9$ID3F129%9D6F1>9&)D9F1J9&YD<F1V9'ID?F2"9
M(9DBF2.9))DEF2:9)YDHF2F9*IDKF2R9+9DOF3"9,9DRF3.9-)DUF3:9-YDX
MF3F9.ID[F3R9/9D^F3^90)E!F4*90YE$F4691IE'F4B929E*F4N93)E-F4Z9
M3YE0F5&94IE3F5:95YE8F5F96IE;F5R979E>F5^98)EAF6*99)EFF7.9>)EY
MF7N9?IF"F8.9B9F,F8Z9FIF;F9R9G9F>F9^9H)FAF:*9HYFDF::9IYFIF:J9
MJYFLF:V9KIFOF;"9L9FRF;.9M)FUF;:9MYFXF;F9NIF[F;R9O9F^F;^9P)G!
MF<*9PYG$F<69QIG'F<B9R9G*F<N9S)G-F<Z9SYG0F=&9TIG3F=29U9G6F=>9
MV)G9F=J9VYG<F=V9WIG?F>"9X9GBF>.9Y)GEF>:9YYGHF>F9ZIGKF>R9[9GN
MF>^9\)GQF?*9\YGTF?69]IGWF?B9^9GZF?N9_)G]F?Z9_YD`F@&:`IH#F@2:
M!9H&F@>:")H)F@J:"YH,F@V:#IH/FA":$9H2FA.:%)H5FA::%YH8FAF:&IH;
MFAR:'9H>FA^:()HAFB*:(YHDFB6:)IHGFBB:*9HJFBN:+)HMFBZ:+YHPFC&:
M,IHSFC2:-9HVFC>:.)HYFCJ:.YH\FCV:/IH_FD":09I"FD.:1)I%FD::1YI(
MFDF:2II+FDR:39I.FD^:4)I1FE*:4YI4FE6:5II7FEB:69I:FEN:7)I=FEZ:
M7YI@FF&:8IICFF2:99IFFF>::)IIFFJ::YIRFH.:B9J-FHZ:E)J5FIF:IIJI
MFJJ:JYJLFJV:KIJOFK*:LYJTFK6:N9J[FKV:OIJ_FL.:Q)K&FL>:R)K)FLJ:
MS9K.FL^:T)K2FM2:U9K6FM>:V9K:FMN:W)K=FMZ:X)KBFN.:Y)KEFN>:Z)KI
MFNJ:[)KNFO":\9KRFO.:])KUFO::]YKXFOJ:_)K]FOZ:_YH`FP&;`IL$FP6;
M!IL'FPF;"IL+FPR;#9L.FQ";$9L2FQ2;%9L6FQ>;&)L9FQJ;&YL<FQV;'IL@
MFR&;(ILDFR6;)ILGFRB;*9LJFRN;+)LMFRZ;,)LQFS.;-)LUFS:;-YLXFSF;
M.IL]FSZ;/YM`FT:;2IM+FTR;3IM0FU*;4YM5FU:;5YM8FUF;6IM;FUR;79M>
MFU^;8)MAFV*;8YMDFV6;9IMGFVB;:9MJFVN;;)MMFVZ;;YMPFW&;<IMSFW2;
M=9MVFW>;>)MYFWJ;>YM\FWV;?IM_FX";@9N"FX.;A)N%FX:;AYN(FXF;BIN+
MFXR;C9N.FX^;D)N1FY*;DYN4FY6;EIN7FYB;F9N:FYN;G)N=FYZ;GYN@FZ&;
MHINCFZ2;I9NFFZ>;J)NIFZJ;JYNLFZV;KINOF[";L9NRF[.;M)NUF[:;MYNX
MF[F;NIN[F[R;O9N^F[^;P)O!F\*;PYO$F\6;QIO'F\B;R9O*F\N;S)O-F\Z;
MSYO0F]&;TIO3F]2;U9O6F]>;V)O9F]J;VYO<F]V;WIO?F^";X9OBF^.;Y)OE
MF^:;YYOHF^F;ZIOKF^R;[9ONF^^;\)OQF_*;\YOTF_6;]IOWF_B;^9OZF_N;
M_)O]F_Z;_YL`G`&<`IP#G`2<!9P&G`><")P)G`J<"YP,G`V<#IP/G!"<$9P2
MG!.<%)P5G!:<%YP8G!F<&IP;G!R<'9P>G!^<()PAG"*<(YPDG"6<)IPGG"B<
M*9PJG"N<+)PMG"Z<+YPPG#&<,IPSG#2<-9PVG#><.)PYG#J<.YP\G#V</IP_
MG$"<09Q"G$.<1)Q%G$:<1YQ(G$F<2IQ+G$R<39Q.G$^<4)Q1G%*<4YQ4G%6<
M5IQ7G%B<69Q:G%N<7)Q=G%Z<7YQ@G&&<8IQCG&2<99QFG&><:)QIG&J<:YQL
MG&V<;IQOG'"<<9QRG'.<=)QUG':<=YQXG'F<>IQ[G'V<?IR`G(.<A)R)G(J<
MC)R/G).<EIR7G)B<F9R=G*J<K)ROG+F<OIR_G,"<P9S"G,B<R9S1G-*<VIS;
MG."<X9SCG.2<Y9SFG.><Z)SIG.J<ZYSLG.V<[ISOG/"<\9SRG/.<])SUG/:<
M]YSXG/F<^IS[G/R<_9S^G/^<`)T!G0*=`YT$G06=!IT'G0B="9T*G0N=#)T-
MG0Z=#YT0G1&=$IT3G12=%9T6G1>=&)T9G1J=&YT<G1V='IT?G2"=(9TBG2.=
M))TEG2:=)YTHG2F=*ITKG2R=+9TNG2^=,)TQG3*=,YTTG36=-ITWG3B=.9TZ
MG3N=/)T]G3Z=/YU`G4&=0IU#G42=19U&G4>=2)U)G4J=2YU,G4V=3IU/G5"=
M49U2G5.=5)U5G5:=5YU8G5F=6IU;G5R=79U>G5^=8)UAG6*=8YUDG66=9IUG
MG6B=:9UJG6N=;)UMG6Z=;YUPG7&=<IUSG72==9UVG7>=>)UYG7J=>YU\G7V=
M?IU_G8"=@9V"G8.=A)V%G8:=AYV(G8F=BIV+G8R=C9V.G8^=D)V1G9*=DYV4
MG96=EIV7G9B=F9V:G9N=G)V=G9Z=GYV@G:&=HIVCG:2=I9VFG:>=J)VIG:J=
MJYVLG:V=KIVOG;"=L9VRG;.=M)VUG;:=MYVXG;F=NIV[G;R=O9V^G;^=P)W!
MG<*=PYW$G<6=QIW'G<B=R9W*G<N=S)W-G<Z=SYW0G=&=TIW3G=2=U9W6G=>=
MV)W9G=J=VYW<G=V=WIW?G>"=X9WBG>.=Y)WEG>:=YYWHG>F=ZIWKG>R=[9WN
MG>^=\)WQG?*=\YWTG?6=]IWWG?B=^9WZG?N=_)W]G?Z=_YT`G@&>`IX#G@2>
M!9X&G@>>")X)G@J>"YX,G@V>#IX/GA">$9X2GA.>%)X5GA:>%YX8GAF>&IX;
MGAR>'9X>GB2>)YXNGC">-)X[GCR>0)Y-GE">4IY3GE2>5IY9GEV>7YY@GF&>
M8IYEGFZ>;YYRGG2>=9YVGG>>>)YYGGJ>>YY\GGV>@)Z!GH.>A)Z%GH:>B9Z*
MGHR>C9Z.GH^>D)Z1GI2>E9Z6GI>>F)Z9GIJ>FYZ<GIZ>H)ZAGJ*>HYZDGJ6>
MIYZHGJF>JIZKGJR>K9ZNGJ^>L)ZQGK*>LYZUGK:>MYZYGKJ>O)Z_GL">P9["
MGL.>Q9[&GL>>R)[*GLN>S)[0GM*>TY[5GM:>UY[9GMJ>WI[AGN.>Y)[FGNB>
MZY[LGNV>[I[PGO&>\I[SGO2>]9[VGO>>^)[ZGOV>_YX`GP&?`I\#GP2?!9\&
MGP>?")\)GPJ?#)\/GQ&?$I\4GQ6?%I\8GQJ?&Y\<GQV?'I\?GR&?(Y\DGR6?
M)I\GGRB?*9\JGRN?+9\NGS"?,9\RGS.?-)\UGS:?.)\ZGSR?/Y]`GT&?0I]#
MGT6?1I]'GTB?29]*GTN?3)]-GTZ?3Y]2GU.?5)]5GU:?5Y]8GUF?6I];GUR?
M79]>GU^?8)]AGV*?8Y]DGV6?9I]GGVB?:9]JGVN?;)]MGVZ?;Y]PGW&?<I]S
MGW2?=9]VGW>?>)]YGWJ?>Y]\GWV??I^!GX*?C9^.GX^?D)^1GY*?DY^4GY6?
MEI^7GYB?G)^=GYZ?H9^BGZ.?I)^EGRSY>?F5^>?Y\?D,^@WZ#OH/^A'Z$_H4
M^ACZ'_H@^B'Z(_HD^B?Z*/HI^OW__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W_@2[]__W__?^$+G,T1S2(+HLN_?^>-1HV#C:,+I<N;CD8.?W_SSG?
M.7,ZT#G]__W_3CMN/.`\IR[]__W_JBY60%]!KBXW0[,NMBZW+OW_L4.L0[LN
MW4/61&%&3$;]_R-'*4=\1XU'RBY'27I)?4F"28-)A4F&29])FTFW2;9)_?_]
M_Z-,GTR@3*%,=TRB3!--%$T5319-%TT831E-KDT^,/`O\2_R+_,O]"_U+_8O
M]R_X+_DO^B_[+P`````````````C`"0`)0`F`"P`+0`Q`#(`4`!1`%@`60!>
M`%\`7P!@`&,`9`!F`&<`9P!H`&@`:0!L`&T`?0!^`(0`A0"3`)0`JP"L`*X`
MKP"R`+,`SP#0`#$!,@$R`3,!,P$T`30!-0$U`38!-@$W`3<!.`$X`3D!5`%5
M`:L!K`&Z`;L!'P(@`B`"(0(M`BX"Y`+E`N4"Y@+L`NT"[0+N`B0#)0,R`S,#
M,P,T`_$>\A[S'O0>]![U'O8>]Q[]'OX>!A\''P<?"!\('PD?#1\.'WT??A_3
M']0?U!_5']<?V!_C'^0?[1_N'RL@+"`O(#`@12!&($<@2""U(+8@NR"\(+P@
MO2"_(,`@PR#$(,4@QB#'(,@@R"#)(,D@RB#+(,P@T"#1(-4@UB#?(.`@XB#C
M(.<@Z"#T(/4@]B#W(/P@_2`A(2(A)"$E(2\A,"%((4DAFB&;(><BZ"+Q(O(B
M52-6(UDC6B-F(V<C:2-J(W,C=".#(X0CBR.,(Y,CE".6(Y<CF".9(ZHCJR/)
M(\HCRR/,(P$D`B0")`,D0"Q!+$(L0RQ%+$8L1RQ(+%$L4BQ@+&$L8BQC+&4L
M9BQI+&HL:RQL+&XL;RQ\+'TLH2VB+:4MIBVF+:<MJRVL+:TMKBW!+<(MPRW$
M+<HMRRW,+<TMT2W2+=<MV"W-+LXNU"[5+D4O1B\O,#`P.S`\,#TP/C!?,&`P
M:#!I,&HP:S!L,&TPW3#>,`@Q"3$R,C,RH3*B,JPRK3*I-:HU_C7_-5XV7S9L
M-FTV_S8`-]DWVC?X./DX:3EJ.=X\WSSF/><]O3^^/S%`,D`U0#9`8$!A0%A!
M64'-0LY"X4+B0J)#HT.G0ZA#^4/Z0PE$"D3"1<-%]$7U1?9%]T7Z1?M%^T7\
M10]&$$821A-&*$8I1N=(Z$@.20])?4E^21%*$DIB2F-*O((.@]23U9,@E"&4
M.Y0\E(R4C925E):4KY2PE+"4L92QE+*4M)2UE+J4NY2[E+R4O92^E,.8Q)C$
MF,68R)C)F,F8RIC*F,N8RYC,F&"989GAF>*9^YD`````````````````````
M``````````!9^EKZ2OI+^DSZ3?I.^D_Z4/I1^E+Z4_I`^D'Z0OI#^D3Z1?I&
M^D?Z2/I)^I2'E8>8AY>'FX><AY*'DX=;^I"'D8>6AYF'0(=!AT*'0X=$AT6'
M1H='ATB'28=*ATN'3(=-ATZ'3X=0AU&'4H=3AX"'@8=8^HN'C(>%AX:'AX>(
MAXF'98=IAV"'8X=AAVN':H=DAVR'9H=NAU^';8=BAV>':(=^AX^'CH>-AW*'
M<X=OAW"'<8=UAW2'@X=H^FGZ:OIK^FSZ;?IN^G#Z;_IR^G'Z8?IS^G;Z=_IU
M^G3Z>OIX^GGZ>_I]^GSZ?OJ`^H'Z@OJ#^H3ZA?J&^G?[A_J(^HGZBOJ+^HSZ
MC?J.^H_ZDOJ1^I/ZE/J5^I;ZE_J8^IKZF?J=^I[ZG_J@^J'ZHOJC^J3ZI?JF
M^J?ZJ?JJ^JOZK/JM^J[ZK_JR^K#ZL_JT^K7ZMOJW^KCZ9_JY^KKZN_J\^KWZ
MOOK`^K_ZPOK#^L'ZQ?K$^L;ZQ_K(^LGZROK+^LSZS?K.^M'ZS_K3^M3ZTOIC
M^M#ZUOK7^M7ZV?K:^MOZW/K=^M[Z9OK?^N'ZXOKD^N7ZYOKC^F3ZY_KI^NOZ
M[/KM^N_Z[OKP^O'Z\OKS^O3Z]?KV^OCZ]_KY^OKZ_/K[^D#[0?M"^T3[0_M%
M^TC[1OM)^T?[2OM+^TS[3?M.^T_[4/M1^U+[8OI4^U/[5OM7^U7[6?M:^UO[
M7/M=^U_[8/MA^V3[8OMC^V;[9?MG^VG[:/MJ^VO[;/MM^V[[J/IO^W#[<_MQ
M^W+[=/MV^WC[>?MZ^WO[?/N!^X/[A/N%^X?[B/N*^XO[C?N,^X[[C_M<^I#[
MD?N3^Y3[E?N6^Y?[F/N9^V#ZFON;^YS[GONA^Z+[7?JC^Z3[I?NF^Z?[J/NJ
M^ZO[K/NM^Z[[K_NP^[+[M?NV^[C[N?N[^[K[O/N_^\#[O?N^^\'[P_O"^\K[
MQ/O&^\7[Q_O)^\C[R_O-^\[[7_K,^]+[UOO4^]#[T?O5^\_[9?K9^]S[WOO=
M^]O[V/O7^U[ZX/O?^^'[XOOC^^3[Y?OF^^?[Z/OK^^S[[?ON^^_[\/OQ^_+[
M\_OT^_7[^/OZ^_O[_/M`_$+\0?Q#_$3\1?Q&_$C\1_Q*_$O\X/KI^Y#ZF_J<
M^K'ZV/KH^NKZ6/M>^W7[??M^^X#[@ON&^XG[DON=^Y_[H/NI^['[L_NT^[?[
MT_O:^^K[]OOW^_G[2?Q7^E;Z5/I5^@``````````````````Q0&$`,<!``#'
M`0``QP$``,<!``#'`0``QP$``,<!``#'`0``QP$``,<!``#'`0``QP$``,<!
M``#'`10``````*,!``"C`0``HP$``J0!``"D`0``I`$``*0!``"D`0``I`$`
M`*0!``"D`0``I`$``*0!``"D`0`0I0$``*4!``"E`0#`IP'__[<!_S\`````
M`````````````````````%4!``!5`0``50$``%4!``!5`0``50$``%4!@`!6
M`0``5@$``%8!``!6`0``5@$``%8!``!6`0!`5P$``%<!``!7`0``5P$@`%@!
M@`!9`0``60$``%D!``!9`0``60$``%D!``!9`0``60$``%D!``!9`0``60&`
M1%P!,&!@`0``8`%`!&(!`0!C`0``8P$`%F8!`4!H`0(":@&``&L!@`%M`0`!
M;@$``&X!@`!O`0``;P$``&\!J0)T`8$`=@$`BGD!!`!Z`0!@?`$B`'X!``!^
M`0`!?P&``(`!``"``0$`@0$``($!``"!`1``@@$``((!0`"#`0!`A`$``(0!
M``&%`0``A0$``(4!``"%`0(`A@$@`8@!``"(`0``B`$``(@!``"(`0``B`$`
M`(@!``"(`0``B`$``(@!``"(`0``B`$``(@!``"(`0``B`$``(@!``"(`0``
MB`$``(@!``"(`0``B`$$`(D!``")`0``B0$``(D!``")`0``B0$``(D!``")
M`0``B0$``(D!``")`0``B0$``(D!``")`0``B0$``(D!`""*`0"`BP$``(L!
M``"+`0``BP$``(L!``"+`0``BP$``(L!``"+`0@(C0$(H)`!(@"2`0``D@$`
M`)(!``"2`0``D@$``)(!``"2`0``D@$``)(!``"2`0``D@$``)(!``"2`0``
MD@$``)(!``"2`8``DP$@`)0!``"4`0``E`$``)0!``"4`0``E`$``)0!``"4
M`0``E`$``)0!``"4`0``E`&``)4!``"5`0``E0$``)4!``"5`0``E0$``)4!
M`$"6`0``E@$``)8!``"6`0``E@$``)8!``"6`0``E@$``)8!``"6`0``E@$`
M0)<!``"7`0``EP$``)<!``"7`0``EP$``)<!``"7`0``EP$`$ID!``"9`0``
MF0$``)D!``"9`0``F0$``)D!``"9`0``F0$``)D!)`";`0"`G`$``)P!``"<
M`0((G@$``)X!``">`0``G@$``)X!`0"?`0``GP$``)\!``"?`0``GP$``)\!
M``"?`0``GP$``)\!``"?`0``GP$``)\!``"?`0``GP$``)\!``"?`0``GP$`
M`)\!``"?`0``GP$``)\!``"?`0`(H`$!`*$!``"A`0``H0$``*$!``"A`0``
MH0$``*$!``"A`0``H0$``*$!``*B`0``H@$``*(!``"B`0``H@$``*(!``"B
M`0``H@$``*(!``"B`0``H@$``*(!`@```````````$0!@`!%`0``10$``$4!
M``!%`0``10$``$4!``!%`0``10$``$4!``!%`0``10$``$4!``!%`0``10$`
M`$4!(`!&`0``1@$`$$<!``!'`0``1P$``$<!``!'`0``1P$``$<!``!'`0``
M1P$``$<!``!'`0``1P$``$<!``!'`0``1P$``$<!!`!(`0``2`&``$D!``!)
M`0``20$``$D!``)*`0``2@$``$H!@`!+`0!`3`$``$P!`(!-`0``30%``$X!
M``!.`0``3@$``$X!``!.`0``3@$(`$\!``!/`0"`4`$``%`!``!0`0``4`$`
M`%`!``!0`0``4`$``%`!``!0`0``4`$``%`!``!0`0``4`$``%`!``!0`0``
M4`$``%`!``!0`0``4`$``%`!``!0`0``4`$``%`!``!0`1$`4@$``%(!!`!3
M`0``4P$``%,!``!3`0``4P$``%,!0`!4`0``5`$``%0!``!4`0``5`$``%0!
M``!4`0``5`$``%0!``!4`0``5`$``%0!``!4`0``5`$``%0!``!4`0``5`$`
M`%0!``!4`0``5`$``%0!`(`````````````````X`0(`.0$``#D!```Y`0``
M.0$``#D!```Y`00`.@$`@#L!```[`0``.P$``#L!```[`8``/`$``#P!```\
M`4``/0$``#T!```]`0``/0$``#T!``$^`0``/@$``#X!```^`0``/@$``#X!
M```^`1``/P$``#\!`!!``0``0`$``$`!``!``0``0`$``$`!``!``0``0`$(
M`D(!``A#`0``0P$``$,!``!#`0``0P$!```````````````````````O`0``
M+P$``"\!```O`0``+P$``3`!`!`Q`0``,0$``#$!```Q`0``,0$!`#(!@``S
M`0``,P%``#0!```T`0``-`$``#0!```T`0``-`$``#0!```T`00`-0$``#4!
M```U`0`$-@$``#8!```V`0``-@$``#8!```V`0``-@$``#8!```V`0``-@$`
M`#8!```V`8``-P$``#<!```W`0``-P$``#<!```W`0(`````````````````
M``````````"H````J````*@``@"I`!``J@`@`*L```"K`(``K````*P```"L
M````K````*P`@`"M````K0``0*X```"N````K@```*X```"N````K@```*X`
M``"N```@KP```*\```"O`"`$L0```+$```"Q````L0```+$`($"S````LP`$
M`+0```"T``(`M0`!`+8`@0"X````N````+@```"X````N````+@```&Y````
MN0```+D```"Y````N0```+D```"Y````N0`(`+H```"Z````N@```+H```"Z
M````N@```+H```"Z````N@!``+L```"[````NP```+L```"[````NP```+L`
M``"[````NP```+L```"[````NP```+L```"[````NP```+L```"[````NP``
M`+L```"[````NP`@`+P```"\````O````+P```"\````O````+P``0"]````
MO0```+T``""^````O@```+X``$"_````OP```+\```"_````OP```+\```"_
M````OP``0,````#`````P````,````#`````P````,````#`````P````,``
M``#`````P``!`L(`($#$`!!`Q@`"",@```#(`(`"R@`@`,L`"`#,````S```
M`LT``0#.``2`T````-````#0````T```#-(``$#3````TP```-,```#3````
MTP```-,`0`#4````U````-0```#4````U```"-4``0#6````U@```-8```#6
M``(`UP```-<```#7````UP`0`-@`!`#9````V0```-D```#9````V0```-D`
M``#9``"!VP```-L```#;````VP```-L```#;````VP```-L```#;````VP``
M`=P```#<````W````=T```#=````W0```-T```#=``0`W@```-X```#>````
MW@```-X``0#?`$``X````.````CA``A`XP```.,```#C````XP```.,```#C
M````XP`4`.4```#E````Y0```.4```#E````Y0```.4```#E````Y0```.4`
M``#E````Y0```.4```#E````Y0!``.8```#F````Y@```.8```#F````Y@``
M@.<```#G```0Z```@.D```#I`$``Z@```.H```#J````Z@```.H```3K````
MZP```.L`$`#L````[````.P```#L````[````.P``(#M````[0"``.X`0`#O
M```0\````/```(#Q````\0```/$`!!'T````]````/0`@`#U```2]P```/<`
M`!#X````^````/@```#X````^````/@``(#Y````^0```/D```#Y````^0``
M`/D```#Y````^0```/D```#Y````^0```/D```#Y```!^@```/H```#Z`"``
M^P```/L```#[````^P`@`/P`H`#^````_@```?\```#_````_P```/\```#_
M````_P`@```!`````0`(`0$`"`(!```"`0```@$```(!```"`1"`!`$```0!
M```$`0``!`'```8!`!`'`0``!P$```<!```'`0``!P$```<!```'`0(`"`$`
M``@!```(`0!`"0$```D!```)`0``"0$```D!```)`0``"0$```D!```)`0``
M"0$```D!```)`0)`"P$```L!```+`0``"P$```L!```+`0``"P$0``P!```,
M`0``#`$```P!```,`8``#0$```T!```-`0``#0$`(`X!``(/`40`$0$(`!(!
M(``3`8``%`$``!0!0$88`0``&`$``!@!```8`00`&0$``!D!``(:`0"`&P$`
M`!L!```;`0``&P$``!L!```;`0``&P$"`!P!```<`0"`'0$``!T!```=`0``
M'0$`@!X!```>`0``'@$``!X!```>`0``'@$``!X!```>`0``'@$``!X!```>
M`0``'@$``!X!```>`0``'@$``!X!```>`0``'@$$`!\!`%@B`4``(P$``",!
M```C`0``(P$``",!```C`0``(P$``",!```C`0``(P%``"0!```D`0``)`$`
M`"0!```D`0``)`$``"0!```D`0``)`$``"0!```D`0``)`$``"0!```D`0(`
M)0$``"4!`$`F`0``)@$0`"<!``0H`0``*`$``"@!```H`0``*`$``"@!```H
M`0``*`$``"@!```H`0``*`$``"@!`0`I`0``*0$``"D!```I`0``*0$``"D!
M$`@K`0``*P$``"L!```K`0``*P$``"L!```K`0``*P$``"L!```K`0``*P$`
M`"L!```K`0``*P$``"L!```K`0``*P$``"L!```K`0``*P$"`"P!@`@N`0``
M+@$``"X!```N`0``+@$``"X!```N`0``+@$``"X!```N`0``+@$`0```````
M`````````````````````````)D```"9````F0```)D```"9````F0!``)H`
M``":````F@```)H```":````F@```)H``0";```!G```$)T```"=````G0``
M0)X```">````G@```)X```">````G@```)X```">````G@!``)\```2@````
MH````*````"@`"``H0```*$```"A`(``H@```*(`!`"C``@`I```(*4```"E
M````I0```*4```"E```#IP```*<``0```````````(L```"+````BP```(L`
M``"+````BP```HP`(`"-````C0```(T```"-```0C@```(X`@`&0````D```
M`)````"0````D````)````"0````D````)````"0````D````)````"0``!`
MD0```)$`!`"2````D@```)(```"2````D@``"),```"3````DP```),```"3
M``@HE@`(`)<```"7````EP```)<`$`"8```$`````````````````````%T`
M``!=````70```5X```!>````7@```%X```!>````7@```%X```!>````7@``
M`%X```!>````7@`"`%\``!!@``D`8@```&(```!B```"8P```&,`0`!D````
M9````&0```1E`!0$:````&@```!H```B:@```&H```!J``"`:P```&L``$!L
M``0`;0```&T`10!P````<````'```0!Q````<0`0`'(```!R````<@```'(`
M``%S````<P`0`'0```!T````=````'0```!T```$=0```'4`$`!V````=@``
M`'8``"!W````=P``0'@```!X````>```$'D```!Y````>0`@`'H```!Z````
M>@```'H```!Z````>@```'H```!Z```0>P!`@'T```!]``$`?@``"'\```!_
M````?P"!`($```"!`!``@@```((```""````@@```((`!`"#````@P`(`(0`
M``"$``0`A0```(4``""&````A@```(8```"&````A@```(8```"&````A@``
M`(8```"&````A@``!(<``!"(```"B0```(D```")````B0```(D``("*````
MB@```(H```"*````B@```(H```"*````B@```(H`0```````````````````
M````````````````````.0```#D````Y````.0`&`CP````\````/````#P`
M```\````/````#P`\`%!````00```$$```!!````00```$$`""!#`!`!10#,
M"$H`0`A,```F3P""`%$```!1``!X50``P%<``'!:``(`6P```%L`$"`W````
M-P``H``````C````(P```",````C````(P```",````C`/__,P`/````````
M`$```0`"``(````"`````@````(`_P,,`/\#%@```!8````6````%@```!8`
M```6````%@```!8````6````%@`"A!D``4X>`"``'P```!\`!``@``(`(0``
M`"$````A````(0`@`"(``(``````````````````````<"%Q(7(A<R%T(74A
M=B%W(7@A>2%@(6$A8B%C(60A92%F(6<A:"%I(>+_Y/\'_P+_,3(6(2$A-2**
M?AR)2).(DMR$R4^[<#%FR&CYDOMF15\H3N%._$X`3P-/.4]63Y)/BD^:3Y1/
MS4]`4")0_T\>4$90<%!"4)10]%#84$I19%&=4;Y1[%$54IQ2IE+`4MM2`%,'
M4R13<E.34[)3W5,.^IQ4BE2I5/]4AE595V57K%?(5\=7#_H0^IY8LE@+65-9
M6UE=66-9I%FZ659;P%LO==A;[%L>7*9<NESU7"==4UT1^D)=;5VX7;E=T%TA
M7S1?9U^W7]Y?76"%8(I@WF#58"!A\F`183=A,&&881-BIF+U8V!DG63.9$YE
M`&859CMF"68N9AYF)&9E9E=F6682^G-FF6:@9K)FOV;Z9@YG*?EF9[MG4FC`
M9P%H1&C/:!/Z:&D4^IAIXFDP:FMJ1FIS:GYJXFKD:M9K/VQ<;(9L;VS:;`1M
MAVUO;99MK&W/;?AM\FW\;3EN7&XG;CQNOVZ(;[5O]6\%<`=P*'"%<*MP#W$$
M<5QQ1G%'<17ZP7'^<;%ROG(D<Q;Z=W.]<\ESUG/C<])S!W3U<R9T*G0I="YT
M8G2)=)]T`75O=8)VG':>=IMVIG87^D9WKU(A>$YX9'AZ>#!Y&/H9^AKZE'D;
M^IMYT7KG>ASZZWJ>>QWZ2'U<?;=]H'W6?5)^1W^A?Q[Z`8-B@W^#QX/V@TB$
MM(13A5F%:X4?^K"%(/HA^@>(]8@2BC>*>8JGBKZ*WXHB^O:*4XM_B_",](P2
MC7:-(_K/CB3Z)?IGD-Z0)OH5D2>1VI'7D=Z1[9'ND>21Y9$&DA"2"I(ZDD"2
M/)).DEF249(YDF>2IY)WDGB2YY+7DMF2T)(G^M62X)+3DB63(9/[DBCZ'I/_
MDAV3`I-PDU>3I)/&D]Z3^),QE$642)22E=SY*?J=EJ^6,Y<[ET.739=/EU&7
M59=7F&68*OHK^B>9+/J>F4Z:V9K<FG6;<IN/F[&;NYL`G'"=:YTM^AF>T9X`
M``````````````````````````````"*?AR)2).(DMR$R4^[<#%FR&CYDOMF
M15\H3N%._$X`3P-/.4]63Y)/BD^:3Y1/S4]`4")0_T\>4$90<%!"4)10]%#8
M4$I19%&=4;Y1[%$54IQ2IE+`4MM2`%,'4R13<E.34[)3W5,.^IQ4BE2I5/]4
MAE595V57K%?(5\=7#_H0^IY8LE@+65-96UE=66-9I%FZ659;P%LO==A;[%L>
M7*9<NESU7"==4UT1^D)=;5VX7;E=T%TA7S1?9U^W7]Y?76"%8(I@WF#58"!A
M\F`183=A,&&881-BIF+U8V!DG63.9$YE`&859CMF"68N9AYF)&9E9E=F6682
M^G-FF6:@9K)FOV;Z9@YG*?EF9[MG4FC`9P%H1&C/:!/Z:&D4^IAIXFDP:FMJ
M1FIS:GYJXFKD:M9K/VQ<;(9L;VS:;`1MAVUO;99MK&W/;?AM\FW\;3EN7&XG
M;CQNOVZ(;[5O]6\%<`=P*'"%<*MP#W$$<5QQ1G%'<17ZP7'^<;%ROG(D<Q;Z
M=W.]<\ESUG/C<])S!W3U<R9T*G0I="YT8G2)=)]T`75O=8)VG':>=IMVIG87
M^D9WKU(A>$YX9'AZ>#!Y&/H9^AKZE'D;^IMYT7KG>ASZZWJ>>QWZ2'U<?;=]
MH'W6?5)^1W^A?Q[Z`8-B@W^#QX/V@TB$M(13A5F%:X4?^K"%(/HA^@>(]8@2
MBC>*>8JGBKZ*WXHB^O:*4XM_B_",](P2C7:-(_K/CB3Z)?IGD-Z0)OH5D2>1
MVI'7D=Z1[9'ND>21Y9$&DA"2"I(ZDD"2/)).DEF249(YDF>2IY)WDGB2YY+7
MDMF2T)(G^M62X)+3DB63(9/[DBCZ'I/_DAV3`I-PDU>3I)/&D]Z3^),QE$64
M2)22E=SY*?J=EJ^6,Y<[ET.739=/EU&759=7F&68*OHK^B>9+/J>F4Z:V9K<
MFG6;<IN/F[&;NYL`G'"=:YTM^AF>T9[]__W_<"%Q(7(A<R%T(74A=B%W(7@A
M>2'B_^3_!_\"_P````````````````````!@)&$D8B1C)&0D921F)&<D:"1I
M)&HD:R1L)&TD;B1O)'`D<21R)',D8"%A(6(A8R%D(64A9B%G(6@A:2']_TDS
M%#,B,TTS&#,G,P,S-C-1,U<S#3,F,R,S*S-*,SLSG#.=,YXSCC./,\0SH3/]
M__W__?_]__W__?_]__W_>S,=,!\P%B'-,R$AI#*E,J8RIS*H,C$R,C(Y,GXS
M?3-\,U(B82(K(BXB$2(:(J4B("(?(K\B-2(I(BHB```````````N(C0B5R$G
M(2,H*2%G(D8A/B%W*7@I)2)2(B0A+")V*2PH>2AV*'HH+R(A*"(H/R$J*"TH
M+"DA*2,I0"$J*2TI(BDD*"0I)2DF*"8I)RDH*"@I*2@I*3`I+R@O*2LH*RDN
M*"XI)R(P(B@B*R(J(BTB*2)!)4(E0R5$)44E1B5')4@E225*)4LE3"5-)4XE
M3R50)5$E4B53)50E5256)5<E6"5A)6(E8R5D)64E9B5G)6@E:25J)6LE;"5M
M)6XE;R5P)7$E<B5S)70E=25V)7<E>"4G+"$L(BPC+"0L)2PF+"@L*2PJ+"LL
M+"PM+"XL+RPP+#$L,BPS+#0L-2PV+#<L."PY+#HL.RP\+#TL/BP_+$`L02Q1
M+%(L4RQ4+%4L5BQ8+%DL6BQ;+%PL72Q>+%\L8"QA+&(L8RQD+&4L9BQG+&@L
M:2QJ+&LL;"QM+&XL;RQP+'$L5RPJ(2XA+R$P(3$A4R)4(B4A)B$V(D<A2"%8
M(7DI>BE[*7PI?2E^*68B22$U(B0G8")E(F(B62=*(7<H>"A[*'PH?2A^*#`E
M,24R)3,E-"4U)38E-R4X)3DE(24B)2,E)"4E)28E)R4H)2DE*B5G(6@A9B%I
M(6HA52)8(E8B62)7(B$B(B(C(E,A)")4(70A=2$S(C(B;B%P(40A4"$K(7PA
M?2%[(7HA<B%S(3$B12%Q(2TA;R%6(4$A52%"(4,A;"%M(7@A>2%V(7<A02)1
M(5(A9RAH*&DH:BAK*&PH;2AN*&\H<"AQ*'(H<RAT*'4H9REH*6DI:BEK*6PI
M;2EN*6\I<"EQ*7(I<RET*74I32E.*4\I4"E1*5(I4RE4*54I5BE7*5@I62E:
M*5LI7"E=*5XI7RE@*6$I8BEC*60I92EF*4TH3BA/*%`H42A2*%,H5"A5*%8H
M5RA8*%DH6BA;*%PH72A>*%\H8"AA*&(H8RAD*&4H9B@A)BPF(B8M)B,F2"9'
M)BXF)"9")D$F+R8F)D8F128Q)B4F1"9#)C`F)R8\)DDF2B8W)DLF3"8R)BDF
M/B9-)DXF.29/)E`F-"8H)E$F4B8X)CTF4R94)C,F*B95)E8F.B8_)E<F6"8U
M)BLF629:)CLF6R9<)D`F729>)E\F8"9A)F(F8R9D)C8F1B)A(6`A0R)'(D@B
M2R)*(DDB3")C(6(A.B(Y(F4A9"$X(C<B7R%>(4(B6R%=(5PA1")%(EHA62%/
M(DXB4")1(D\A3B$\(CTB0"([(CXB/R)-(ELB7")=(EHB(2$B(2,A*"$T(34A
M-B$W(3@A.2$Z(3LA/"$](6LA,B$S(2$J(BHC*B0J)2HF*B<J*"HI*BHJ*RHL
M*BTJ+BHO*C`J,2HR*C,J-"HU*C8J-RHX*CDJ.BH[*CPJ/2H^*C\J0"I!*D(J
M0RI$*D4J1BI'*D@J22I**DLJ3"I-*DXJ3RI0*E$J4BI3*E0J52I6*E<J6"I9
M*EHJ6RI<*ETJ7BI?*F`J82IB*F,J9"IE*F8J9RIH*FDJ:BIK*FPJ;2IN*F\J
M<"IQ*G(J<RHA*R(K(RLD*R4K)BLG*R@K*2LJ*RLK+"LM*RXK+RLP*S$K,BLS
M*S0K-2LV*S<K."LY*SHK.RL\*STK/BL_*T`K02M"*T,K1"M%*T8K1RM(*TDK
M2BM+*TPK32M.*T\K4"M1*U(K4RM4*U4K5BM7*U@K62M:*ULK7"M=*UXK7RM@
M*V$K8BMC*V0K92MF*V<K:"MI*VHK:RML*VTK;BMO*W`K<2MR*W,K="MU*W8K
M(20B)",D)"0E)"8D)R0H)"DD*B0K)"PD+20N)"\D,"0Q)#(D,R0T)#4D-B0W
M)#@D.20Z)#LD/"0])#XD/R1`)$$D0B1#)$0D121&)$<D2"1))$HD2R1,)$TD
M3B1/)%`D4212)%,D5"15)%8D5R18)%DD6B1;)%PD721>)%\D8"1A)&(D8R1D
M)&4D9B1G)&@D:21J)&LD;"1M)&XD;R1P)'$D<B1S)'0D=21V)'<D>"1Y)'HD
M>R1\)'TD?B0Q*3(I,RDT*34I-BDW*3@I.2DZ*3LI/"D]*3XI/RE`*4$I0BE#
M*40I12E&*4<I2"E)*4HI2RE,*5\B,2@R*#,H-"@U*#8H-R@X*#DH.B@[*#PH
M/2@^*#\H0"A!*$(H0RA$*$4H1BA'*$@H22A**$LH3"A>(DDG2B=+)TPG32<Z
M)SLG7"==)UXG-B<W)S@G5"=5)U8G5R=8)R$G(B<C)R4G*R<L)RTG+B<O)S`G
M,2<R)S,G-"<G)R@G*2<J)STG/B=E)V8G9R=H)V$G8B=C)S\G0"=!)T(G0R=$
M)T4G1B=')T@G3B=/)U`G42=2)U,G6B=;)V,B;"<F)V`G;R=A(CPG;2<U)SDG
M:B=K)U\G9")D)VXG:2=I;$MO4G8R6%MM,E\^7SMY=%QD=29S8%TF87A.,%PJ
M8VEQ>DTO?"%3*W%19RQ2>4Y]<3]>.GLY>5).*V-@:WI.=TLE96%*3%1A:F-<
M+5]K2R]5=59X94!>(VQ-:2=J=FD[>VEG3&]F4$%>+&1,6'%Y7TXD>C)F>WH]
M>DA,36]552)346PG9%)L,79[3E%0/TLD;2AM0EYB=EQM=5PY8$Y4-71;4S56
M)&QF9&IQ;$M`2W)L:E!R>25L7U!J9VM045QI6TQ]5UMA6C967V-#7D1>(4IL
M;B-3-VY/>$AJ.&XL<25Q3FD\>7EE:FQ674)M)7@Z95A;(DI-46UN:VQ%7F!C
M24II<DY5-G9"3D=6-&,M<6)J0E<G<VI-;FLR625]579B535X=4PU=2UD:V=5
M<3MP-6E)3%5Z5&%65T%<1EYO>F%C<V%V7'Q.1%MQ>&1<;V4Q7%956G-!2T-;
M>EEN4SAZ)GUO:R9T2DPH<UMS)ULW=F9/<G!:2U)G0U=P=EYH)F5G92-*)TQ)
M:C9X)7HN<4YO;4LP=D]O3VE>=U-.=UPH6WA+(5]A74IU-FEL9VYN<',_7TM,
M05!2=#I@0%]@3E)<:GUV5DIJ:6@L8U!S)$IX6T=><&M6<6)E3$Q[2V-J05]M
M5E!I.6YC55-1<&4T:$-K*FI\>G9U/'!4?3M@0TXZ4#IW<UA-=RYD7U1G4'UL
M+E)O;E=59&HB>&M-/U<Q>VQ-,EQL4'U.<&Y"3&U0=V5\<R)N,UET6#=I+DXB
M67%83U0G95)5*58B=%=Q6%4]<%!74%1/5VIK:WUM6T5\0DM5?4AT:FAS=5YY
M;U-3;$)=-V]49TI*>UE]>BI6>'1W=RQ<5U<B7SY.<%,D<&QA9T]+<REM/DIO
M=$YV>UX[4#=5<6XH='A<)TM.6F9@)6UR;GE<7'E<<W)X>71Q?#Q0>5LQ5WQ+
M)7!]2W15;4TE2BM60E`^<#U2)$PV>DU,>EI/=CAI=5A.3$U7451M:6M*8EDR
M?2UC3%8T62=A4VY#4#-]9%5H3T-M,E!^3BA:4'A6?5%X4GA37&)=>7M!735C
M76U$3B%+8UU=?"]Y>U(A3RAD-G1^;"YC;6=!?6):,UAD76]P<79P>G513UI4
M7"9</V]/3EE@5EE4;$MJ/THP56E/;7%/3'AD;6185R=]*VHR=G!//7ET9EM+
M47-1:2ES8%!2:6-:4F(B=G1A9%I59S]U(D\O32-/,$U^<2-0+V$C>"9*.W=J
M<DA>4VE)7EY]0$IJ>4Y15&Y25"-9*'U95TYW/GI63W!786M%>'I<0UU?>6]G
M97TC=GQ9*7UN9V554&\Q32)W,G$Q<3)-*UHG2F)C/'LD63IN4WAZ>R1/>UQC
M=BIM(7)A3B9Z8'E6;&YD(7EO>VMY(VXL:BA*>G16379\2714>"9X2EY&<EI7
M4%-%6&9J77-:9&1V<G9"7WU9=DPZ4R]D87DF<%-+/&!*='I4*GUB>3=T0GTP
M?&Q]8DH]?6=J0U]246).)%,K?6!?1W)P9VY0*G-+7CAV=6$S<2-W*4HE3T1?
M,&$_<"1V-F-&>F]0;7U$77=\/V8M7C]Z<65$;252;GTV=79A3%Y>?%=L74TW
M5C--57A896I/4$],:BYJ+6IQ4R533W<D;B10(G)P4"-R>'<S4"E;.U-L2B9Q
M54MG=UY-)'=`>%U34$PF3W-V=V%<4WYZ)WI9:R=/+VIO9#EI6'%86')@-&9\
M7'%S4&-[<D9;<5!R4%Q/45,Q3%AW*$L\:SYD7'1"7"=P0&9M2FMH:&5#7%YM
M<E-W3%1.*V=#2S%A,G=S4U)30'5=7W-N<6<T?4AR4G-T;E-B44QJ7SII5UE-
M=7)Q1WIX64)4979%77)G7VU+2GI;-6@F4S5]27EB9#U[)%=%3E5.9E8]94U>
M<VQ@;6QL/GMK7WAA/GES4"I@8FA48GU2*&5365Y3.'0\=WU<;&AG9'=C*&QQ
M>G)E=%`O4F5<)5`T<3%\>$Q&75%Z7W<H>G5N3EYS9RQW1&MA;2M@1UTS4C]2
M3$H_>WUE95U-6'1L=5!M:%)06%EF=BI;8'=96"-T7711;S59*VTW8SMN-$US
M8$UJ=6QN:"E++W%-2BEL:W)O?7-Y0698;"QM3FI?:$]>)E)T9U910F9C8S!D
M-%@E=EYS)5=H=T9H9GMF77Y<6E@L6C!J.&,J2GEA,6IL<FYZ56YT>6Q2>WMP
M?3U@8TY&>"Y>15\^92UM:GIN329M+FUM<"%=+VUX?&M8>4PU32EZ76%58D]M
M(EU*>6AJ;65K4U1I>F%,9&1A1VA;3E5<-7=S?'-P+TXU<5)O2&AQ:U1+/F!X
M8VEJ,GQT8&!/)6XJ>D-F,F$K2F1C.VE68G)S5FXR:G9066Q+6BA/(UU;6$YY
M56E18SQ2+%A,<WM-5G9U9V]H>6,[4G-S>V-07C!.=U99<4%U1%P[=5%>9EQ2
M7F)M=FY/:FYP?&-?4W13,V$T85-T1E]6:2M;)G8Y8T5K*70V37E2+5IC4E%/
M7$MZ3%U/*6@[8SIC6F!W;C-<=5,F5S5V6U=586I4(U]??7=05&TJ2UMD>V$B
M2V!3/V1`>SY:360Y5D!O?&$Y=D=?,61G7&A<5GIV4UIQ<GI]8D]5>%!?34MU
M<&0K2T17?F):72Y:;DHY52%C8V@K<RE/=U-Q5&1.<FAU92YG.E9L7T!D9&@U
M6%QD.70V<5YB-6%O32=Q94Y=2V-9+'-Y4"ML4UYI=W5Y7F%N2SQC5GAN6W%]
M-G=>=&UR65LH<'UA5%XL8&-M85-(7S99+'U3;T%D:W@L6T9\+5@Z=E];4U-'
M>$Y*07@T4C1<.7I/2C-\:FIK:GI09&UG74E?;5\\;D%O4DPD74I?>%,H<3=-
M5&]=9&Y?+$L\:6QJ2U\_>2]61E4J3RE.>%8W<7AN65E?<TAX1DYF569T1695
M;V]+7WPG7&=627A28SUC84]`<%IL5UUP>RQL*7!7>D%[0%(P965M+4LP>25W
M+DLO6C98)U,R>T1]+6PA>VEE;FET<W-X07`O7C!X8',O9RU;-68H>5A=66A6
M;V)37V)@?$A7+7UO7U-,>5-P5$=;55YT<%!5665'?%9<8&(P6B-S;%-+=$5]
M?6,Q>7M06VP\=21R3EA/6'=U878W4FQ[2%UH9$%25W@[5E9>/7<N;&%0=6`S
M:E9.)4QV;&%B/F-(?'!-=GEP7S]E/TYA?#!M47T[=D]Y6FM!2CA2<4U38V9]
M;69Z8RIP4'EB?"=X96%Y;G9G;6HT?$)U7%=U<&A=;5-\=3]:>TQZ4R1T5V]#
M5&-[;7LM8&YJ,WM"9&=V75),7TE\*65V8#-V?F%P2V]J<&I`6C1X<FM#9%=I
M<61O2E=.2GQA<T1+96-%2S1J/6E)5UMK,6U#3#YW2WQT>#=94W-4<V1W47<W
M6#%.0DHT>T9+=G!G55!J5$PO2RIT+VE#=5AI:5US<7M5.UY[='-]<GTF=TE=
M4U0H3$%:54QD64IZ8V4\4W!*1%!02BMZ:VMX9V595U$D<WM48WQ8>E5S*T]S
M:WQ55%-\3699>6(A8E1K=V`R9'Q,9'LK=#U0<4HX;T!7>FYT?6-30GMH52Y;
M-F$W>#]@0WMJ72)B)FYH=G5V2EUB4"9=:UUY9"]C?%!\=#Q,:G=D97%?87=W
M>3EO6'@I>5EX/6Y&6&-D3G5976=9.5)#565:4%I945A.7DLL='M::79S:"Q/
M<'!]=$A;0$Y48T]1=7%R36M/.$TF8UI1)7(F<DYD>U,I<4ER6&])9CA8<WHU
M<R1X<U%(9EIX:5Q77E]+;$]?='11.E)R7S=A(V)\4V9M25MZ9%Y/4$Y3575S
M+G=(;W--3W5S94)P44IQ:B906EDK<&=K0&4U?$1D*4Q&?35J*F4Z7U]A45HX
M871H?5,D8DIR9EHS=TU]-G-7;D1U)%@G<CA9.5E);TY62W<N7W5H-5)54TQT
M?%IH66MW274\<U):-5,V:$]6.G1)=RI,0W!63%-0/5-[6V!+9%-W=CI537-A
M2W1K+70J?&QW=FAG6DQW065N8'U59DXK?#M5*'(E8CE-<FI'2W1-+UM9;SI-
M>7QS7V=.0EHM3WEG*'AB<W)*)%]$5%=,0F4[35IO6&XG729B0&`P5DIX>GQ^
M63!>;%UH6F!4>59735A>>')69$50+G0H745M5G-97F9C*%,P6UIE/V,Q6VE5
M06!;;VEP,E=]4&E9?E!M;"E3*7)$<&)B;VE1>5EI6FA#6D1:151Z9V!-,&,R
M6T1[8W,E66=[2UU44#9F+F!:?35<>&`Q9W!U7%A&;3EA0&-`>7!I6UED<S9<
M:61%<$%C3'Q-?$MR3')/9%MQ67HX<75]>6![9S=\9'Q%>V=C.5AX=D5<6$PO
M8&=T7&]\3UUO*G(^?2Q*.WU'?3)G46IT7VQ17F1#9299/$UE<U5M.EEG;35[
M;'AG8%E,1E0E9W55/E-[?')D=5]X:&UX1TYV?5AH6$U69UI,8TIV7T=P1G`Z
M6'1Q<'1,=65\16IS:EM=5UQ]7GER1U506$AP(5$B4519:%9*63%:1UAB7$YS
M='4Y<5-::G9U3RY]4DHT7UU7.GHG;CUU=7AH;6%4(U%687AY2EMY2U147%D^
M;FUW;E)F87EW;5U;:#-;=U$P8&)45W9Y5UU8?4TK<CU-0G@L<BU*+DHN3T)C
M-UQ:6SM9<TI3=GAF=6IV:GEV+T]32B]*,%(Z<3-70V-]<UI>6UY>;V-B>VYW
M7TI7:$Y;6SMQ<6DW>D90*TPH;GI+>7E]3'Y34&1N<E5435\X?%!137)2=U1*
M655>6%E-*6X\=EM,27!\?$EH?G1\9UY77%XL<'Y,84TZ86];,EHE43A<=E@D
M46)-:EQW<$IP/E!<75945E-0;2%--5]X7R%4,DY*:'5K56-0=2%U)UDK94MF
M<75%92-Y6V!K=G%+:EDB=5%7>%%X:GEJ,UI?;V]Q=F4_;F1B/U`L>E%U,V<^
M:4YR-%M.?&Y=-&<T5S1W/DUI6C!/67=F<UE.*DY(2R=02W!'4$5D8%M:52=7
M0&YV>%)U:6T\649E(W546B=B?'M<<71*>FAI3GAI96(Y4')4)E%.7W1\*E,L
M3&!O96554'Q;9GQ^2VIM,5YC>2)4=D]05FI5;G%+>B%E,55M3VMM,E4\56)]
M+7-;?3!I)U%C?3-.9'U.>C!*)W<Q3R)F-GPM<F%O+G-&7&M98&@H8795?4]=
M7E%9:F1/<C]W9F(H8E9C46UY:3%6,EYH8"M37&LO7T-*?&Y#?79K,D]L63U9
M7U@X5#YK;UUP77%=<ET^649[,T]];BMD15IL6"A1*6(\7C5G<%MB;W!Q-$]Q
M6S%@)5]2>7UG(V9Q>S!++G)G35QH5V=`=V-0(5H]3"E13%U^8RI1*F@V:GIY
M3&98=D=42UE264M3=U@I6GAU7EXO<BEX2%A!;D%Y<UUZ:CUV.V$_351T369/
M?")[7&`[=%5:,GER>W9;7UYR6UQX;G=H:WI2/'%:>FI:1EI!=S9G1V4L5D=<
M*6$J8B955U10<GMJ76!S>SUQ9V)7?4A.-VI`?&=];W<U5SIO77$S7DMH77A'
M>TA57U<I73%I+7I9=G1Z*GAN9EQ,/&%O8#]I?7Q.9E=A3V9Q='-D>V1D>6-O
M;D\^=C)@?GPK47I72'M78B-4>'`H5V=A/U-D;T578FMG?")D:&)09FA[:'1T
M93QT570V7SE\0FYU2F5O8DLD5&!>?5I&9#YH7F`T=E)J>WE"8&1*-V=]:EU9
M-%HJ;FE[2ULU6CYQ+%-)>T]?0%-78V9O4'Q`:5-U7&PW=SAJ>5%(7#EJ7G$V
M5S5/*%EN;"I=(DTN:#UA47)!:7Q2-5MG<WY847PR;2]T(WM!?"MN)51R=%EN
M2GMC33M86V5W>%1V*5=)2U%F3'`N6%-Y?E4\6#!R*V)H<T)O;&TX9WY:/DQ\
M<FM:6&)6;5%6,V!2?$AK05--<'=/4FU85$E<<5<[7R5S370_<3%X>FE+>U5*
M5'E*=TA6:'P]<WYN?F="4S93+4QZ=C)66%)89R5C.6<M<$Q[(6LF5$U[/55?
M<7MV-%YK54AE)'LY5&%>(V0W5VYX-5Y25E5Y.F=5:W=59V\^82YZ:59N5CMG
M2VPS531.)7MN82AW3GL]6'U[:7PV3T=M+&Y=3"=V>F8D=5Q],VU)3FAO/V%;
M>F-+*7<F>SE<0'%(;4-O+59.?2%H='LG579Q4V9>3#)X:UPV?6IE8'%,6TU=
M2%1M625U>V949DA](58_?5-\(6\\9VY1569R:3!?8%@Z?"]]3G!A6TEE-&U#
M8%AC>VDH:C=])WM":7=]66)L7")H<&9X?7E]/W8G9U=F<U1)5'I6<E=`86);
M6&8]9T]P/G,L8C=U<&`X?6AC)U1\:%)Z;WA35C154'!P=S-N.FI3:DEM*UTL
M92%]4%\S;%%?;6TX>'IW*WA@=#I4,V1::39>/UE`66]63%DJ6F5?97<R3'E?
M8%<[5'I],TQS6U)?2DY:;F1D3WLW3T-N:DXM8F%7=7I)52QX66=I<VU81&-Q
M<&5H>F!$;EY9(FLC:T)\.VHK:&)>;VTC:'%//%1J?#YG<GPT5BYB-U-,>EQZ
M-6UC82QH76AI;SUT.$];:2Q11UI):TQH-UX\5F5377I66C%*2%HF7S-Y4G)$
M2DM.=4TP?2A507%I8DI<-&Q`>BA[*%!L6FY9>V!J;UYZ1&`Y3TI58E<O8CA7
M36A:=B)O6F)\=E![+5%D32Y1;5Q.:'EP-4Y\9GM75E!U77%W?79W6VI[7&E!
M67)U16!4:D)Y/&I%4E%[0&<E:WI?(F,Y5T-I?6@O:%-R*7LE6$M52%`O46-7
M1F`B5G!M<U=4?%=:7TQ4<C!18$Q]6S]S47`[?#!B)69;8EY?1V!O<F%,:E9"
M9S9.0'-^35)[>'A[=S]H-V@V;3I<-$QW<3AH=DHD9%9T9E\G7V=?06%$:4M<
M16DC;R9K(TMI8WM1)&]K;S10(TUF:"5O3%-M6CI757)E=6]9-'E454]]8UMA
M<39L?GM74S%1,4LR43)+0G%A=#5Y0V%"87=K*%]*2SEF7G@J>7=*-VTX4U9R
M651%;G!R,DH[7'AQ-VQ*94!V77UC5&),5'=E5T-3)EA!=G9=0$U<94ME1&$P
M:#!T:G-N6CM7,6(J5WM67V162BAK?EM"=CMO?51(8#EH)F\D3714(5M<6UU;
M7&Y+2U5\:TY!35-[*WE4=2E976E-6TY=0V=,;&QY3$M\8"A44VUO6%=R>$IO
M6E1635EN6$%R4U]P6FIB?6!X6"]W-EI72EAR>5A?>F]/0EE2<%%D-W-@>FQO
M,F(]5$Y98G0I5$)-6F=9<BI9/E@M7&MB?%9Y2EI45W0A3#I/.'5#66A016-X
M:S%R.T\M4V%H;$XT8&->=UTR<G9S6W9^5U]X<G<I4%IF)G4\5V-,6V9=73-1
M;6]>5G1D;V%X74]H94HA7#5@+'PM?"=8.&TV6W!6+W,E37%:*%AD3#116$IR
M6B=U*'4F9FQ5>%5S6D9C9%YE7C51-E$W43-R7FE3<#1R5'!D2U1[9G5J8V9>
M5%]Y>"YP.%%?5E=0(7QN;UA<7VE=97M]26!)5BI43&5@:5A0(GP^5#-B9UX\
M7#92574A3BEU>5UZ755P7W9:<FMD<7(Y;'Q]*F%92F]O*G5Y;"UX0G)#=E)7
M(GE6<'IP8'9S:4-R*U0S2B9-0TU:34]91'9=;D1G-&)B7UMG,6@N?$UE:WH\
M3V)/=DUP;SYT350X<R%I<G)K<U=P5T]?3T!H06AC3R)I*E!!<RM09%0\;R%8
M7UE7<SU<94QQ;6)Q6U0U8F9*+E-F3%-Q9W5:2FY[16%I7UYN0G<B6"Q=+W`]
M5BMA-GEU5$E0)V]L8FI;3$YH=55W35-^<S50?F![7UUF)&A-2RAO-&Y86CE1
M*5\P<T1,-TXI;U5?5VU&;CUO5GQT6RIO.7AI=5EC1F$_5&A>:G!"<R]36TI7
M?%AM1V%8=#-6+5T^54-Q7VYK5EET9E<W6GM=3UTC6%E:6'!$;UAA5'%R;5M5
M7%5$<U=+-F)Q;U5[6%-075EP,TM=52=-+%`Z441Q,V5U>V%I8'T\?"):(UHA
M4F]2;6)I7EQ.-7)D4%%=2&$W6V-?.6U%<4]S*U<L86MC1VY)87I*>W!A>EIP
M9TQT6C],;4XI56)Z95!6:U]L?%]6=VI>-$L^;S5,/4]R;S=B:$Q\<&!61G$X
M8BMK-4M16$YT=W-&5SM1*G=*;5-7>EA%=DQ1?%U]7V5Y2F!]<C!3<W1)6EYF
M.GA0:'M856HC5D9V6W)\9#)H6EI<<E9[,FDM;F-Z;EQJ=6!F?7`L5T5U8&YE
M6UY=<%DC:7EQ1')+8"1I.6(Q8VM\*$TV3%MP.F8I34-S66$K;T5G:6!%<T!4
M/U4N77QY0$PB93A.4EA6>2IQ44Y'=FM;?E]A6'-W9U=^5#Q13V4V2SA:1$T^
M5CIB6$],8'EK?7UH5UA+8FDZ:$=C36Q.;#]6)V-67VA]86XH=GU=.WA1:%=Y
M;DY/;"5I559%33IM/5$^3SML,5)I3$19?&D^43QL+64P=VI,1%-`5GU6(6$]
M7BEV)%HD5D9U(F%&:45R:71L5E-K/6Q<8FM>7'`_:TY7/U$K=7UY7$I&339R
M?ETW3#A;:5!=3D!K(GU+>%9J,'%.6T-W3ULD2V!X5WM*:R%@34Y<5%A]=E(W
M<G9Z*G9W>F98,712:$5*:TQN8CMB+7=A>&QS(5Y]9&QC+UTP73=+4V@C86!2
M?G`F:7)+<VU97$U@6G<Y6RY,6UI'33%=+U@C8V].<W(S>$Y@?75L:T53;'Q;
M4FM4(EYF93!P1%5T;6UC0FAU;7Q7.VTK=CAR2'9F4UUR/T\L:T!/*&9I?4%/
M7V!L7B)@/W1O8G%91W$X2WYY.EMU6FQV7%ID>D]@,ETI9G-O;7-Z:V9Y74I>
M55Y*9%]]9BQU=61C:4MM9$]36#-=;%0Y<C=?3DM8>UE04EUT=UQG)60C?#M;
M.G)]:4I05G5%631D)VT]:GYF1'<M=6!9-$IB>$)//FPT94A-2&Y(9TE--WEH
M<7)9=5LU2D9925@K63QM5%A:7#QB;7Q@;'Y21VDJ9G!B.WHN=2I[>VP_;%A\
M951#>6)N:5=V;6U>;$QN8U1H>'HT735D,%A56&IT.4YA5E)/-E`B3FYS>'-,
M7$M0)'Q*3517(UY@9$EN76)^=2Q4455P6$-X5VI7=3]80'TM:RI5*&=*;F=*
M8WA=5%AJ67MW;35E+5!Q<3UB2&-562I?/%MD>'IQ-F5O<UI[8&$L66MU-F!(
M:4]+26-N7CYB;UPE5G%B?E8A64!86UP];3A?)6HM5WES>&U'=4IA8VM><DQX
M66I&4V9;+W5P3GYI-GMR8G)/.7=S64MA75HY6GMK.4MY;6!@0'0\?3%?;V,C
M8#E],7!+33YM0%5P8WIM9&EM55UG=E0W96=;/V)+;G1777`K3EYG5E9,83-H
M;F4B7%!@-54A55M[2WES2R5T2'I75F5I7'M0?79[)5H]6V)L=TU><$EV;UXQ
M4VY\0VA(<7%.;7ET<C9D.75P7'%C)6@[<B1>3%II2EIC67Q::D1Y)&-=>TIO
M1&A,55=K+5DK>UE3(E5>=G9:46`H:7EU+WI\:VI@,F-%56-Q;E5,35EM05AL
M>FMQ/'IB9F5Z>F(V2C=D6VIZ=2Q[0T]]:WIX.5]Q8212>W5:4%M0/FHQ63=*
M9U-E>#)30&)?<F5-+'E-32YN+E9J5V!G+FM93TU<>VUP7FM7)5Y77U!;45LC
M53)P7%QH2F9X3EQ<:E);,VE;=RAC+E=A8#I+465<4$%52E@I8R1@*6E'4UU<
M+G@X3"Y0<EA*8R],+511=DQ01DI"53I.1THP>EA?.G5K971O-5TJ37)C=WM0
M=SI]87U^=D!116@X9&AA04QM4CY;8F!)>DUA.$I@<DEQ<5Y?<$1X3&YR7DEG
M<V)A9TMC3&-X3RQO?GTE?#%Z65]28%IT2G$C3CQR8VPE8"MW+VM>921A*TUT
M629H3DUI86]\8V!!8B1.)EY^:UUK8'!;='1B2%-K=#5N6'5?5656,&MC=$UC
M='0R>G5O7THQ:S]M27TF9"1Y,W!L96=11UE79%UJ=U0Z6DU:3'E:83];14Q0
M;#M+<UXJ:4A98VX]5T1/35`F?'MQ4GU!45MC25-/7&U,)UX[9B%L.4Q>>V)G
M050H7$)B6'-395ES1G-;32Q-0WQG5$)1)7E5:$YC2E1:7U][8V=[>$]C,'5G
M6$E9+WAV;S9=+VYX33A>)WQ\=S%W.TXA=$UN+F%#;'Y//WAB6&A3*%YD=$)L
M=5E%>5-=<59\;'!\0&TY2F1N87(Y7G)6=%Y;7U-;9WIC6$%T-UUU<BY4<U8X
M745/7U\^<B%V2VM\<4=S:V!\;5MA96YU7E-Z2W$O4#E=0U$Q=49J87`L=EEU
M:W`Z73]R17<B6W9R.DIU=V5+9FY38"5.6%8O5$EI3E-"=&9+(7$R:R)Q,VLT
M<'1+,%0R<S=[;'5G;C)T;75S3V)P3FY,<3AE=5=S8V5/1D\S<UAD>4]:3TUZ
M8V9B<FYU.TI<8W).658P;F5T0EA07&Y,8%5*=DI]5EA/="96/EQ46T=7?G)-
M<4-B7EQ?7"UO*V9=>3]J+F]0='-.+&9>3GE5=&-033A5?7<I7'9>*EQC<C1I
M7%)F:79C2F=.4'=:/$IH;EY:=W)[8B9,.UII;EIU7'=J84%.,50Q?3UF+7MG
M>$YA8G=O=4=/,E1O3&A43VY7=R9@059<86-P9'%Q7"=6=71.<61R,%!O;#IY
M-6MM5$1B9VDT:R%J/'@F3D9Y6GPS5#E37FHK:6%A3U-V=$!J3V$Z3&IN9'`T
M<VY40')E<4-T5&`V:R%7:$LM>2UI9%@S>D5B/7Q$;#%8*UPD56EK.VA76"Y[
M85%`6SYU=UY[2D9W2$]085!N=&ET3DU56T\[72Q.:&DT5$=D6W5!>BE>>%1W
M;S-3-VMX;UQU3&U56T]Q4'$R=2Y9+%5&8B-]97LK7W5B+78S=35P)6%==2)L
M?6TT=3A[(UM*5EE+5&5Z<SAK-V!L5VQQ+V5A56U745%R87EO/%U<=F5P1'1I
M:7MS;U0B3'YW/%]-:S=00E8M:"]O)4MI2VAZ1DQG9D=J)%M)3WQB>F]>:TAU
M7E158#!O1V(O66=Y96=*3U%A2&)[;WEZ<EPG8&AX:DL\2V)67G5?=39N=F)*
M4WQO1%$Q;T517E!A63A@44TY<TQG*%8G3C542&0T4SEK=4M==B-Q1TQ*:7!A
M8'4O>U%+8'ME<G!L;'!K;DMI<$PO5R%S=7PD<59@,F]1="%W47%\2GU*3DY(
M<SIS?FTF6FQ@37A22TYK6'E9>6!*2EHF2TA*;GEL6S%0;U5S9B)G661A9$1\
M;WET3V9W/$Y%="-</5U&="%X5FA!6V9P.61M=BYY/ETP5VA8/4M:>4YX<'EM
M8#-C,W1":F9R-G!66V1K9W)55S94:'E!5U5E:FE,5VE326);?"U-,$PB:G9D
M0%`W<"%N=E=*8DMB3WI?:TM6-'1-;5)D*6HZ9")S4DU+=F9Q06T\:%%N9W!,
M8BID875:;6Y7<5%K:6QI9&`G6E1=(VI#5G167UHS;TUB?6]H<D5O9V=]5TYG
M7%]'>799+%]:5B1<.'!Z57=D1%9L='YO(7`J7CQ:?%A4>F5L*'QF;$M8.7M3
M9'E-4T]J2E1//7A'=%]J6WDW5&5K4F$D:D)Z87MM>B)P<4PC>G=B3F)U:6MA
M:&=7:'A:2U1V=T56:51Z>G),77<Z7BA..7!^9$ED5&1#:C1O/E=B>U---6]I
M>B9Y/5]'=WUX?'@K7FA;76-B84914'9F:WE:1VQX7FEX7F-U3D-Z5V5(;$ES
M.V0N9C9O/UP]3D-83U!Z3TIS5V!'42YI/6A$>D]B17HX>6!<,'LI6%]E)WEN
M=DQV>&)Q;&!:4G%,4DM//4H_76]V>5XT>BU59W$^7D!<2%%)43YX=DMY5&)U
M4V%I6'YX3$\D?79.4'IS3#YF+G9P54I1/GQQ56E--7I08G=T5$TC9R5;46(B
M5V-W)FHA4%I.:WLF6UY;95A@:BI88&5;5D9O:GA59'=.6&!O5VUT9DUT3&-U
M2F1A7$AY/WPG:$18/DLN7'=7:'!`74U/<UPP66EF/&1$:FQD961X>SM,/61<
M37=97UU.;5!9(V5->2Y-3D\O=E-];6M<5B1E-E5=5FEY)&=C5DM19%9R57I>
M>%=J6%5/?5@K6$M]7'PH8'-567TC3'E9:E-U=4=O6E,]6BAH+UPC<%5-*6`L
M7CIP,6XR;DUV4FY&5F5@.W-A94MD(U="6WY*3T\A,"(P(S`D,"4P)C`G,"@P
M*3`J,"LP+#`M,"XP+S`P,#$P,C`S,#0P-3`V,#<P.#`Y,#HP.S`\,#TP/C`_
M,$`P03!",$,P1#!%,$8P1S!(,$DP2C!+,$PP33!.,$\P4#!1,%(P4S!4,%4P
M5C!7,%@P63!:,%LP7#!=,%XP7S!@,&$P8C!C,&0P93!F,&<P:#!I,&HP:S!L
M,&TP;C!O,'`P<3!R,',P=#!U,'8P=S!X,'DP>C![,'PP?3!^,"$Q(C$C,20Q
M)3$F,2<Q*#$I,2HQ*S$L,2TQ+C$O,3`Q,3$R,3,Q-#$U,38Q-S$X,3DQ.C$[
M,3PQ/3$^,3\Q0#%!,4(Q0S%$,44Q1C%',4@Q23%*,4LQ3#%-,4XQ3S%0,5$Q
M4C%3,50Q53%6,5<Q6#%9,5HQ6S%<,5TQ7C%?,6`Q83%B,6,Q9#%E,68Q9S%H
M,6DQ:C%K,6PQ;3%N,6\Q<#%Q,7(Q<S%T,74Q=C%W,7@Q>3%Z,7LQ?#%],7XQ
M(3(B,B,R)#(E,B8R)S(H,BDR*C(K,BPR+3(N,B\R,#(Q,C(R,S(T,C4R-C(W
M,C@R.3(Z,CLR/#(],CXR/S)`,D$R0C)#,D0R13)&,D<R2#)),DHR2S),,DTR
M3C)/,E`R43)2,E,R5#)5,E8R5S)8,EDR6C);,EPR73)>,E\R8#)A,F(R8S)D
M,F4R9C)G,F@R:3)J,FLR;#)M,FXR;S)P,G$R<C)S,G0R=3)V,G<R>#)Y,GHR
M>S)\,GTR?C(A,R(S(S,D,R4S)C,G,R@S*3,J,RLS+#,M,RXS+S,P,S$S,C,S
M,S0S-3,V,S<S.#,Y,SHS.S,\,STS/C,_,T`S03-",T,S1#-%,T8S1S-(,TDS
M2C-+,TPS33-.,T\S4#-1,U(S4S-4,U4S5C-7,U@S63-:,ULS7#-=,UXS7S-@
M,V$S8C-C,V0S93-F,V<S:#-I,VHS:S-L,VTS;C-O,W`S<3-R,W,S=#-U,W8S
M=S-X,WDS>C-[,WPS?3-^,R$T(C0C-"0T)30F-"<T*#0I-"HT*S0L-"TT+C0O
M-#`T,30R-#,T-#0U-#8T-S0X-#DT.C0[-#PT/30^-#\T0#1!-$(T0S1$-$4T
M1C1'-$@T231*-$LT3#1--$XT3S10-%$T4C13-%0T5316-%<T6#19-%HT6S1<
M-%TT7C1?-&`T831B-&,T9#1E-&8T9S1H-&DT:C1K-&PT;31N-&\T<#1Q-'(T
M<S1T-'4T=C1W-'@T>31Z-'LT?#1]-'XT(34B-2,U)#4E-28U)S4H-2DU*C4K
M-2PU+34N-2\U,#4Q-3(U,S4T-34U-C4W-3@U.34Z-3LU/#4]-3XU/S5`-4$U
M0C5#-40U135&-4<U2#5)-4HU2S5,-4TU3C5/-5`U4352-5,U5#55-58U5S58
M-5DU6C5;-5PU735>-5\U8#5A-6(U8S5D-64U9C5G-6@U:35J-6LU;#5M-6XU
M;S5P-7$U<C5S-70U=35V-7<U>#5Y-7HU>S5\-7TU?C4A-B(V(S8D-B4V)C8G
M-B@V*38J-BLV+#8M-BXV+S8P-C$V,C8S-C0V-38V-C<V.#8Y-CHV.S8\-CTV
M/C8_-D`V039"-D,V1#9%-D8V1S9(-DDV2C9+-DPV339.-D\V4#91-E(V4S94
M-E4V5C97-E@V639:-ELV7#9=-EXV7S9@-F$V8C9C-F0V939F-F<V:#9I-FHV
M:S9L-FTV;C9O-G`V<39R-G,V=#9U-G8V=S9X-GDV>C9[-GPV?39^-B$W(C<C
M-R0W)3<F-R<W*#<I-RHW*S<L-RTW+C<O-S`W,3<R-S,W-#<U-S8W-S<X-SDW
M.C<[-SPW/3<^-S\W0#=!-T(W0S=$-T4W1C='-T@W23=*-TLW3#=--TXW3S=0
M-U$W4C=3-U0W53=6-U<W6#=9-UHW6S=<-UTW7C=?-V`W83=B-V,W9#=E-V8W
M9S=H-VDW:C=K-VPW;3=N-V\W<#=Q-W(W<S=T-W4W=C=W-W@W>3=Z-WLW?#=]
M-WXW(3@B.",X)#@E."8X)S@H."DX*C@K."PX+3@N."\X,#@Q.#(X,S@T.#4X
M-C@W.#@X.3@Z.#LX/#@].#XX/SA`.$$X0CA#.$0X13A&.$<X2#A).$HX2SA,
M.$TX3CA/.%`X43A2.%,X5#A5.%8X5SA8.%DX6CA;.%PX73A>.%\X8#AA.&(X
M8SAD.&4X9CAG.&@X:3AJ.&LX;#AM.&XX;SAP.'$X<CAS.'0X=3AV.'<X>#AY
M.'HX>SA\.'TX?C@A.2(Y(SDD.24Y)CDG.2@Y*3DJ.2LY+#DM.2XY+SDP.3$Y
M,CDS.30Y-3DV.3<Y.#DY.3HY.SD\.3TY/CD_.4`Y03E".4,Y1#E%.48Y1SE(
M.4DY2CE+.4PY33E..4\Y4#E1.5(Y4SE4.54Y5CE7.5@Y63E:.5LY7#E=.5XY
M7SE@.6$Y8CEC.60Y93EF.6<Y:#EI.6HY:SEL.6TY;CEO.7`Y<3ER.7,Y=#EU
M.78Y=SEX.7DY>CE[.7PY?3E^.2$Z(CHC.B0Z)3HF.B<Z*#HI.BHZ*SHL.BTZ
M+CHO.C`Z,3HR.C,Z-#HU.C8Z-SHX.CDZ.CH[.CPZ/3H^.C\Z0#I!.D(Z0SI$
M.D4Z1CI'.D@Z23I*.DLZ3#I-.DXZ3SI0.E$Z4CI3.E0Z53I6.E<Z6#I9.EHZ
M6SI<.ETZ7CI?.F`Z83IB.F,Z9#IE.F8Z9SIH.FDZ:CIK.FPZ;3IN.F\Z<#IQ
M.G(Z<SIT.G4Z=CIW.G@Z>3IZ.GLZ?#I].GXZ(3LB.R,[)#LE.R8[)SLH.RD[
M*CLK.RP[+3LN.R\[,#LQ.S([,SLT.S4[-CLW.S@[.3LZ.SL[/#L].SX[/SM`
M.T$[0CM#.T0[13M&.T<[2#M).TH[2SM,.TT[3CM/.U`[43M2.U,[5#M5.U8[
M5SM8.UD[6CM;.UP[73M>.U\[8#MA.V([8SMD.V4[9CMG.V@[:3MJ.VL[;#MM
M.VX[;SMP.W$[<CMS.W0[=3MV.W<[>#MY.WH[>SM\.WT[?CLA/"(\(SPD/"4\
M)CPG/"@\*3PJ/"L\+#PM/"X\+SPP/#$\,CPS/#0\-3PV/#<\.#PY/#H\.SP\
M/#T\/CP_/$`\03Q"/$,\1#Q%/$8\1SQ(/$D\2CQ+/$P\33Q./$\\4#Q1/%(\
M4SQ4/%4\5CQ7/%@\63Q:/%L\7#Q=/%X\7SQ@/&$\8CQC/&0\93QF/&<\:#QI
M/&H\:SQL/&T\;CQO/'`\<3QR/',\=#QU/'8\=SQX/'D\>CQ[/'P\?3Q^/"$]
M(CTC/20])3TF/2<]*#TI/2H]*STL/2T]+CTO/3`],3TR/3,]-#TU/38]-STX
M/3D].CT[/3P]/3T^/3\]0#U!/4(]0SU$/44]1CU'/4@]23U*/4L]3#U-/4X]
M3SU0/5$]4CU3/50]53U6/5<]6#U9/5H]6SU</5T]7CU?/6`]83UB/6,]9#UE
M/68]9SUH/6D]:CUK/6P];3UN/6\]<#UQ/7(]<SUT/74]=CUW/7@]>3UZ/7L]
M?#U]/7X](3XB/B,^)#XE/B8^)SXH/BD^*CXK/BP^+3XN/B\^,#XQ/C(^,SXT
M/C4^-CXW/C@^.3XZ/CL^/#X]/CX^/SY`/D$^0CY#/D0^13Y&/D<^2#Y)/DH^
M2SY,/DT^3CY//E`^43Y2/E,^5#Y5/E8^5SY8/ED^6CY;/EP^73Y>/E\^8#YA
M/F(^8SYD/F4^9CYG/F@^:3YJ/FL^;#YM/FX^;SYP/G$^<CYS/G0^=3YV/G<^
M>#YY/GH^>SY\/GT^?CXA/R(_(S\D/R4_)C\G/R@_*3\J/RL_+#\M/RX_+S\P
M/S$_,C\S/S0_-3\V/S<_.#\Y/SH_.S\\/ST_/C\_/T`_03]"/T,_1#]%/T8_
M1S](/TD_2C]+/TP_33]./T\_4#]1/U(_4S]4/U4_5C]7/U@_63]:/UL_7#]=
M/UX_7S]@/V$_8C]C/V0_93]F/V<_:#]I/VH_:S]L/VT_;C]O/W`_<3]R/W,_
M=#]U/W8_=S]X/WD_>C][/WP_?3]^/R%`(D`C0"1`)4`F0"=`*$`I0"I`*T`L
M0"U`+D`O0#!`,4`R0#-`-$`U0#9`-T`X0#E`.D`[0#Q`/4`^0#]`0$!!0$)`
M0T!$0$5`1D!'0$A`24!*0$M`3$!-0$Y`3T!00%%`4D!30%1`54!60%=`6$!9
M0%I`6T!<0%U`7D!?0&!`84!B0&-`9$!E0&9`9T!H0&E`:D!K0&Q`;4!N0&]`
M<$!Q0')`<T!T0'5`=D!W0'A`>4!Z0'M`?$!]0'Y`(4$B02-!)$$E029!)T$H
M02E!*D$K02Q!+4$N02]!,$$Q03)!,T$T035!-D$W03A!.4$Z03M!/$$]03Y!
M/T%`04%!0D%#041!14%&04=!2$%)04I!2T%,04U!3D%/05!!44%205-!5$%5
M059!5T%805E!6D%;05Q!74%>05]!8$%A06)!8T%D065!9D%G06A!:4%J06M!
M;$%M06Y!;T%P07%!<D%S071!=4%V07=!>$%Y07I!>T%\07U!?D$A0B)"(T(D
M0B5")D(G0BA"*4(J0BM"+$(M0BY"+T(P0C%",D(S0C1"-4(V0C=".$(Y0CI"
M.T(\0CU"/D(_0D!"04)"0D-"1$)%0D9"1T)(0DE"2D)+0DQ"34).0D]"4$)1
M0E)"4T)40E5"5D)70EA"64):0EM"7$)=0EY"7T)@0F%"8D)C0F1"94)F0F="
M:$)I0FI":T)L0FU";D)O0G!"<4)R0G-"=$)U0G9"=T)X0GE">D)[0GQ"?4)^
M0B%#(D,C0R1#)4,F0R=#*$,I0RI#*T,L0RU#+D,O0S!#,4,R0S-#-$,U0S9#
M-T,X0SE#.D,[0SQ#/4,^0S]#0$-!0T)#0T-$0T5#1D-'0TA#24-*0TM#3$--
M0TY#3T-00U%#4D-30U1#54-60U=#6$-90UI#6T-<0UU#7D-?0V!#84-B0V-#
M9$-E0V9#9T-H0VE#:D-K0VQ#;4-N0V]#<$-Q0W)#<T-T0W5#=D-W0WA#>4-Z
M0WM#?$-]0WY#(40B1"-$)$0E1"9$)T0H1"E$*D0K1"Q$+40N1"]$,$0Q1#)$
M,T0T1#5$-D0W1#A$.40Z1#M$/$0]1#Y$/T1`1$%$0D1#1$1$141&1$=$2$1)
M1$I$2T1,1$U$3D1/1%!$44121%-$5$151%9$5T181%E$6D1;1%Q$741>1%]$
M8$1A1&)$8T1D1&5$9D1G1&A$:41J1&M$;$1M1&Y$;T1P1'%$<D1S1'1$=41V
M1'=$>$1Y1'I$>T1\1'U$?D0A12)%(T4D125%)D4G12A%*44J12M%+$4M12Y%
M+T4P13%%,D4S131%-44V13=%.$4Y13I%.T4\13U%/D4_14!%045"14-%1$5%
M149%1T5(14E%2D5+14Q%345.14]%4$5115)%4T54155%5D5715A%645:15M%
M7$5=15Y%7T5@16%%8D5C161%945F16=%:$5I16I%:T5L16U%;D5O17!%<45R
M17-%=$5U179%=T5X17E%>D5[17Q%?45^12%&(D8C1B1&)48F1B=&*$8I1BI&
M*T8L1BU&+D8O1C!&,48R1C-&-$8U1C9&-T8X1CE&.D8[1CQ&/48^1C]&0$9!
M1D)&0T9$1D5&1D9'1DA&249*1DM&3$9-1DY&3T901E%&4D931E1&54961E=&
M6$991EI&6T9<1EU&7D9?1F!&849B1F-&9$9E1F9&9T9H1FE&:D9K1FQ&;49N
M1F]&<$9Q1G)&<T9T1G5&=D9W1GA&>49Z1GM&?$9]1GY&(4<B1R-')$<E1R9'
M)T<H1RE'*D<K1RQ'+4<N1R]',$<Q1S)',T<T1S5'-D<W1SA'.4<Z1SM'/$<]
M1SY'/T=`1T%'0D=#1T1'14=&1T='2$=)1TI'2T=,1TU'3D=/1U!'44=21U-'
M5$=51U9'5T=81UE'6D=;1UQ'74=>1U]'8$=A1V)'8T=D1V5'9D=G1VA':4=J
M1VM';$=M1VY';T=P1W%'<D=S1W1'=4=V1W='>$=Y1WI'>T=\1WU'?D<A2")(
M(T@D2"5()D@G2"A(*4@J2"M(+$@M2"Y(+T@P2#%(,D@S2#1(-4@V2#=(.$@Y
M2#I(.T@\2#U(/D@_2$!(04A"2$-(1$A%2$9(1TA(2$E(2DA+2$Q(34A.2$](
M4$A12%)(4TA42%5(5DA72%A(64A:2%M(7$A=2%Y(7TA@2&%(8DAC2&1(94AF
M2&=(:$AI2&I(:TAL2&U(;DAO2'!(<4AR2'-(=$AU2'9(=TAX2'E(>DA[2'Q(
M?4A^2%!+5DMG2T]-:$TM3GM/(E`X4%!075!445516%%;45Q175%>45]18%%B
M46-19%%E4691:%%I46I1:U%M46]1<%%R4791>E%\47U1?E$B4B-2)U(H4BE2
M*E(K4BU2,E(^4D)20U)$4D921U)(4DE22E)+4DU23E)/4E!245)24E-25%)5
M4E925U)94EI27E)?4F%28E)D4F529E)G4FA2:5)J4FM2<%)Q4G)2<U)T4G52
M=U)X4F94?%0E52M5+E4X5DU62U=D5T5;9%LE7"5=55UT77Q>?EXS7V%?:%]Q
M8"UA;6%U8R%D*60N93%E,F4Y93ME/&5$94YE4&52959E>F5[97QE?F4A9B1F
M)V8M9B]F,&8Q9C-F-V8X9CQF1&9&9D=F2F929E9F669<9E]F869D9F5F9F9H
M9FIF:V9L9F]F<69R9G5F=F9W9GEF(6<F9REG*F<L9RUG,&<_9T%G1F='9TMG
M36=/9U!G4V=?9V1G9F=W9V=H:&AP:'%H=VAY:'MH?F@G:2QI3&EW:4%J96IT
M:G=J?&I^:B1K)VLI:RIK.FL[:SUK06M":T9K1VM,:T]K4&M1:U)K6&LF;"=L
M*FPO;#!L,6PR;#5L.&PZ;$!L06Q%;$9L26Q*;%5L76Q>;&%L9&QG;&AL=VQX
M;'IL(6TB;2-M;FU;;CUR>G(Q<R=T;G1T=G9V.'=(=U-W6WAP>"%Z(GIF>BE\
M(2,B(R,C)",E(R8C)R,H(RDC*B,K(RPC+2,N(R\C,",Q(S(C,R,T(S4C-B,W
M(S@C.2,Z(SLC/",](SXC/R-`(T$C0B-#(T0C12-&(T<C2"-)(THC2R-,(TTC
M3B-/(U`C42-2(U,C5"-5(U8C5R-8(UDC6B-;(RPA72->(U\C8"-A(V(C8R-D
M(V4C9B-G(V@C:2-J(VLC;"-M(VXC;R-P(W$C<B-S(W0C=2-V(W<C>"-Y(WHC
M>R-\(WTC)B)+(4PA?B%^(TTA7",`````````````````````````````````
M````OA_^_\T?___='___[1____T?__\-(/]_'"```!P@```<(```'"```!P@
M```<(```'"```!P@```<(&\``````+(>___"'O__TA[__^(>___R'O__`A__
M_Q(?__\B'___,A___T(?__]2'___8A___W(?__^"'___DA___Z(?__^R'_\/
M`````````````````````````````````````(05DP>+%?\^F!41L)T5`Q.B
M%0$HI140$:@5``"H%9,%KA5['K@5$;"]%0.7Q!4!.\H5$A'.%:``T!63E=@5
M:S#?%5&PY14"$>@5`3+L%3`1\!6P`O05$0'W%0HP^Q5YN`06!A,)%@$P#!80
M``T6@``.%A,!$A8+$!86$0`8%@"3'!8#*R(6$``C%@``(Q:3!2D6:W0R%E&P
M.!8C$SX6`3M$%C`01Q8``$<6``!'%@!P2A81L$\6`Q-4%@`I5Q80$5H6@"%=
M%@$`7A8`,&`6%;!F%@X#:Q8!,&X6,`!P%@`"<181`706(Q!X%@``>!8`$WL6
M@6N"%A`0A!8``X86$P&*%A,0CA81,)(6``&3%@``DQ8P59D6N"*?%@``GQ8`
M,*$6$;"F%@*7K!8'^[86.A&\%K`#P183`<46(0#'%@``QQ8`&\L6#3O3%C@1
MV!:P`]T6$P'A%C,1YQ8!`.@6`!/K%@4K\18<$?86``'W%@``]Q8`$/@6$;#]
M%@`3`!<!*@07,!D)%[`"#1<!``X7$!`0%P``$!<`$1(7`0,5%S`0&!<P`AL7
M$P<A%VL4*!<1`"H7`!,M%P4K,Q=T^3T7N(]&%Q,!2A<[$%`7``!0%P``4!<`
M`%`7<-E8%[!*7A<3`6(7.Q!H%Q$`:A<#$6X7``!N%S!9=!>Q*GL7$0%^%P`0
M?Q<``'\7`1&"%P$+AA<0`(<7``"'%Q,!BQ<K$)`7``"0%P$!DA<`(),7$!&6
M%Z`"F1<1`9P7(3"@%UFPIQ<"`:D7``"I%S`9KA>P![07$P&X%SLXP!<1L,47
M`P#'%P``QQ<``,<7``#'%Q,-S1<[.-47$;#:%P,!W1<`$-X7``#>%P``WA<3
M`>(7(!#D%Q``Y1<``>87``#F%Q`!Z!<``.@7``#H%P`PZA<1&.X7`@#O%P``
M[Q<0`/`7``#P%Q$!\Q<C`/87``#V%P"3^A<!"_X7$!$!&#```Q@1`088*S`,
M&!&P$1C'$QD8`3L?&#`!(AB``B08```D&``P)A@1L"L8@Q,Q&`$K-A@P$3H8
ML`,_&!$`01@*,$48$;!*&`(131@`($X8``!.&``!3Q@1`5(8*Q!7&!&@6Q@"
M$U\8`2MD&!``91@``688`0!G&``P:1@1D&T8`A-Q&`$K=A@P$7H8L&:!&```
M@1@`,(,8$;"(&`+3CA@':Y88.A&<&+`'HA@#`:48(`"F&```IA@`$ZD8!6NP
M&#@1M1BP`[H8$P&^&+@0PQ@``,,8`!O'&`4KS1@0`<\8``/1&```T1@`$-(8
M$:#6&`(1V1@!"MP8<'GD&+"BZA@1`>T8"A#P&```\!@`$?(8`0#S&!`1]AB0
M`/@8$0'[&`D`_1@``/T8`),!&06["1GR^109L"(9&1,!'1D[,B49`2`G&0``
M)QD``"<9,%DM&;`&,AF3`3<9.S`^&1&@0ADC$4<9``!'&7`13!FP`E`9$0!2
M&1`05!D``%09`1-8&0$#6QD0`5T9``!=&9,'9!DK%FL9$`!L&0$!;AD``&X9
M,!%R&0`"<QD1`789*3![&1&P@!D``(`9``"`&3!1A1FP#HL9$P60&3LXF!D1
ML)T9`P.A&0`!HAD``*(9``"B&9,!IQDY$*P9``"L&0(#KQD`.[09``"T&0``
MM!D3`;@9(P"[&0``NQD``+L9``"[&1``O!D``+P9`0"]&2`PP!D1D,09`@#%
M&0``Q1D``,49``#%&0``Q1D`$,89``#&&0(1R1D!`\P9``#,&0``S!D3`=`9
M*[#7&7FPWQDC$^49`3OK&3`1[QFP`O,9$0'V&2'P_!G9L`0:0Q,*&@$[$!HP
M$10:L`,9&A$!'!H@<"`:4;`F&B(3*QH!("T:$!$P&I`!,QH1`38:"S`[&A&P
M0!H"DT4:`:M+&A8`3AH``4\:$P%3&B$P5QH1L%P:`@-?&@$I8QHP,6@:L`)L
M&@``;!H`,&X:&;AU&D(;>QH!,X`:.!&%&C`#B1H``(D:(`"*&@``BAH`$XT:
M!3.3&A`1EAH``)8:``"6&@``EAH!`)<:`).;&@4CH!HP`:,:``&D&@$`I1H0
M$*<:$3"K&@`!K!H``*P:,!&P&C`"LQH!`+0:$!"V&@``MAH`$;@:``"X&@``
MN!H``KD:$X6_&@,0PAH1$,4:`!/(&@$KS1HP=]4:N&/=&A,!X1H[,.@:D;#N
M&J(1\QH!`O4:,'O]&O!7!AL3`0H;*W`1&]'P&1OC$2`;`1LE&S!Q*QNY"C(;
M$P$V&SLP/1L!D$`;`A-$&P$K21LP$4T;L`)1&Q,'5QLK,%T;$3!A&P,39AL!
M(VH;,!%N&[`"<AL3`78;JS!]&Q&T@QO^$8P;`0F/&S!QE1NX1YT;TP6D&WLP
MK!L1L+$;`U.W&P$ANAL0$;T;``"]&Q,%PAMK,,D;$;#.&P(1T1L!,]8;$`#7
M&P``UQL3!=P;ZSCE&Q"@Z!L"`>H;`##L&Q`1[QNP`O,;$P#V&R`P^1MQL``<
M`@$"'``0`QP0``0<```$'!,!"!P+$`P<$1`/'``3$AP!*Q<<```7'```%QR3
M!1T<:S8F')6P+1P#$S(<`3LX'!`!.AP``CL<```['``P/1P1L$(<`P%%'``@
M1AP0`$<<``%('```2!P`,$H<$;!/'`H#4QP!$%4<$`!6'``!5QP1`5H<`P!<
M'```7!P"$V`<`2-D'!``91P``V<<``!G'``0:!P``&@<``%I'```:1P0`&H<
MD`)M'```;1P`,&\<$3!S'(93>AP!>X$<,!&%'+`#BAQ1`8X<(0"0'```D!P`
M$Y,<`3N9'#`1G1RP`J$<$0"C'!`0I1P!`*8<`A.J'`$KKQP0$;(<``*S'```
MLQP`$+0<$;"Y'`(!NQP``;P<,!'`'+`"Q!P!`,4<$!#''`$`R!P`$<H<`2O/
M'!`1TAP0`M0<$P'8'"L`W!P``-P<`)/@'`,KYAPP$>H<L`+N'!,!\AP[,/D<
M``#Y'`(`^AP``/H<,!G_'+`#!!T3`0@=*Q`-'1&P$AT#`14=```5'3`1&1VP
M`AT=$P$A'2$0)!T``"0=`@$F'0$`)QT0`"@=```H'1,!+!TK$#$=$0`S'0(!
M-1T`(#8=,!$Z';`"/AT1`4$=`3!$'1$P2!T"`$D=``!)'3`131VP`E$=$P-6
M'3LP71T1L&(=`P%E'0`@9AT``&8=``!F'1,%:QT[,'(=$;!W'0(1>AT`$'L=
M$`%]'0``?1T3`8$=*Q2''0$`B!T``8D=``")'1`!BQV``HT=`0".'0`PD!T1
ML)4=`@&7'0`0F!T0`)D=``"9'1,!G1TC$*$=$1"D'0*3J1T%"ZX=$!&Q'3``
MLQT3`;<=*W"^'5&PQ!TC$\H=`3O0'3``TAT``-(=``#2'0`PU!T1L-D=`Q/>
M'0$KXQT0$>8=,`/J'0$![!T*,/`=$;#U'0(!]QT`(/@=``#X'0``^!T1`/H=
M`!#['1&@_QT`DP,>!2L)'A``"AX``@L>```+'@`0#!X1D!`>`!$2'@$I%AX0
M$1D>L``<'@``'!X`,!X>$;`C'@(3)QXA*RT>,!$Q'K`#-AX!`#<>(``X'@``
M.!X`$SL>!2M!'C`111ZP`DD>$P%-'CL04QX1(%8>`!-9'B$K7QXR$60>@`)F
M'A,`:1XH,&T>$:!Q'@(1=!X!"G<>,!%['I("?QX1`8(>(3"&'A$`B!X"$XP>
M`2N1'C`1E1Z0`I@>TP.?'BL2I1X1,*D>`A.M'@$K````````````````````
M````````````>`.++X$#<D.(`P`@B0,$"XT#+.B4`T#CF@,`*)P#R$"@`T19
MI@,W2:X#=GFX`T`$N@.3+,$#\*/)`S@`S`/%"-$#`N[8`P,`V@,`@-L#4#7A
M`\CAZ`,C'N\#`(+Q`TG$]P-:K0`$0BD%!`#`!P1@@`H$'$80!)JD%P0#P!L$
M*@4@!$0J)01&UBT$VCTW!``(.`2(@ST$(!1`!"``001P`44$(2!(!`(#2P0`
M,$T$K$!2!""&5@1B1%L$H"!>!`"*8013`F8$!(!H!`($:@2$%&X$^WM[!`00
M?02D?X<$XA&-!$$DD02D`)0$(128!,`@FP10.J$$`'"D!`(`I01#)ZP$R46S
M!((@M@0P1KL$P0_"!(@\R`10*,P$`H;0!"2@U`2((]D$!HC=!!D.XP0`0.0$
MJB+J!&3K\P0<`/8$*,W]!""A`07A`@8%"X0+!0""#06;)Q8%GE0>!4&!(@6S
MH"D%$``J!0B%+@5A(#(%``@S!0@O.070"#T%/KY(!0\!3048]U8%`ZA;!4$*
M7P4(6V4%!`5H!0(`:04`!6L%*CAQ!4%0=04!`'8%$!EZ!0@A?043`X(%``""
M!2)AAP4$!(D%T$"-!0$0CP4`@)`%(D"3!5"`E@5(0)D%"`":!0`0FP71!J$%
M`#>F!8!>K`4``*P%H`"N!1"4L@48`+0%`&"V!4`"N`60`+H%`("[!50`O@4`
M`+X%"`"_!0`)P040`,(%0`##!0``PP4@4,8%$!#(!0`DR@4"3,X%`0#/!0$&
MT@48*=<%3('<!0`AW@4!".`%A63F!0,`Z`521.T%(1#P!00)\P4(`/0%#0#W
M!0``]P6(2?P%`(#]!0$`_@61%@0&90<+!@!`#`:2A!$&,P06!@",&0:211\&
M%@`B!B!2)@8H`BD&"-`M!@!#,`8(3#0&HD`X!BK#/P80F$,&`"Y'!@"`2`9P
M%DX&A&Y5!H)`6`:0PUX&LP1D!H5\;`88(7`&'`1T!L@">`8@$7L&`$I^!D@*
M@@8;-HH&0%6/!@")D@8*`)0&`IF9!B$"G`9`$)X&0@*A!@`$H@9$`*0&``"D
M!@``I`8$#*<&$`"H!@``J`86$JT&``"M!D("L`8``+`&(!JT!D``M08`!+8&
M``"V!@D`N`:SM<(&&`K&!B,5S`:@F],&Z!_<!GQ0XP9Y@^L&_1#S!IW`^@;V
MVP8'8`4*!Y+O%`="`A<'$`$9!P+?(0=A:2@'(@@K!S60,0<"`C,'```S!P,`
M-0<"&CD'JD5`!P$`00<``D('`8%%!U$H2@>`8$T'T@)2!X`"5`<``%0'`!A6
M!P$`5P<`DEH'``!:!X`(7`<`(%T'!01@!P`U9`<`(&4'1&!I!^9)<0>>8'@'
M3!!\!T(J@0<@*(0'2*&)![$0C@<@@)`'#@"3!YQ[G0>0A*$'H!2E!\$HJ@?@
M0:\'!`>S!TF,N0<-$+T'R`S"!Q*$Q@>ZB<X'P`+1!R(4U0<`5=D'P`K=!\0^
MY0>#DNL'HQSR!X=#^0<#1_\'H"(#""@P!PC``PL(`0@-"""@$`@`@!$(1#`5
M"*.%'`@``!P(#B`@""4B)0@\MR\(`0`P""`R-`A0C#D(F0`]"%TQ10B@`$<(
M`I1+"`,`30A+#E0(0N-;""",7PB``&`(D=!F")0=;0@HHW,(G$EZ",%@?P@&
M1(,($P>)")!:CPA$1),(B`^9"```F0A``)H(Q)6A"(%UJ`A'A*X(`D2Q"%/`
MMPB#*[X("`'`"`!`P0A"DL8($0;*"*8)T`@`"-$((C+6"(2SW0C=&^<(`/#K
M"(K`\`B"`O,(`@#T"`"(]@@`;/H(`)+]""$`_PB`00()A(P'"0@3"PE$"0\)
MIP<7"0``%PE1@!L)00P?"0)@(@G0`"4)`*`G"=`0*PD$,"X)`$0P"0``,`D`
M`3$)`8(T"0`'-PD``3@)#D0]"3!H0@D%"$4)LF1,"10%4`GF$%8)%$1:"1$`
M7`D`(5X)")QC"<#+:@D@X6\)PD!S"4PP>`FT07X)K!"#"8.:B@FRF)$)@3*6
M"2*8FPF$`)T):3.E"1*\K`G`UK,).\"Z":&AP`E3#,8)'HK-"0#JT@GPR]L)
MV`7A"9!#Y@G#(>P)!4CP"1Q*]@G0`OH)0#+^"4$```J=UPL*"2L1"K#H&`K`
M?2`*4B0E"D#"*0I+T#`*`*`R"JO(.@J`BCX*J31%"@"`1@K)04P*$(!."A\D
M50H`DE@*>TA@"@``8`K,`&0*!H1H"@`S;`H/07(*&P!V"@`@=PI`@'D*(H!\
M"IB@@0J&H8<*:P","C`JD0JDA9<*@4&;"@0&G@HA8*(*!`"C"H``I`H!H*<*
M``2H"KA&KPH/Z;@*H`.\"@``O`H@&+\*H$#""A`(Q`H*.,D*`0#*"@`%S`H`
MJ,\*!`31"HK"UPH*`-D*("?>"A`)X0H,@^8*`@CH"@``Z`H18NT*@!#O"@P`
M\0H("/,*#`#U"@@,^`H``/@*0`CZ"A`4_0I$`/\*"P`""P1D!@O`4`H+`8`,
M"WX$$PN$B1@+6`8="T!!(`L`P"(+I)0H"V*H+@O<"34+`!@W"P``-PL`@3D+
M"@`["P@`/`N004`+!T!$"Z'D2PL!)4\+1615"^X170M]#F8+`$AH"PC[<`L6
M%G8+J`AZ"R[)@@L)`(0+`!B&"X)*BPN@!H\+9&N7"P(`F`L`%IL+2%:A"Y"#
MI@N@<ZT+*@"P"P"`L0LD`+,+^8B["P)'P`L"3<4+J@_-"P``S0N`CM(+>[C<
M"U1UY`L8).@+0-GN"X#(\@L,!/4+``#U"T&P^@LDC/\+0@0"##1:"0P:``P,
M`(`-#!#!$0Q&@!4,,@`8#`T8'0P&@2$,`@`B#)+-*@P48"X,`70S#!)A.`R1
M`#L,F,!`#`I"1`P/!$D,((1,#!.:4PP"0%4,8HI;#"+]9`R(@6@,@$!J#``0
M:PP#(6\,"`AQ#`$Q=0P@1'@,!`=\#!*X@@R(`X8,`(F)#`"CC0P``(T,`B*0
M#!`2DPP`1I8,0@"8#$$`F@R`5I\,05*D#/!2JPP`(*P,$(:P#!2"M`P$$+8,
M`D:Z#`I#OPPU@,0,X&#)#`#8S0Q!`,\,`0C1#``TU`QE;-P,P1'A#`2KYPR&
M`NL,!"+N#`,`\`P``/`,A)#T#```]`P50/@,@0+[#`("_0P`,P$-``0"#4`X
M!@T@#@H-P,`.#3``$`V%`!,-``45#24-&PW02B$-T($F#8`B*0T,`BP-!;8S
M#4!B-PUY)C\-@&)##>H"20T("$L-9]U6#7F%7@T;"&,-H-YK#36'<PT`0'0-
MC`IY#0#1?0VJ!8,-):*)#4"$C`T0%9`-34"5#8``E@T2`)@-(HV>#6@9I`V/
M!:L-@)"N#1HZM0UDA+H-887`#<#,Q@T"(,@-(`C*#2YSTPVD(-<--`O=#00`
MW@T5%.,-`2#E#0""YPU7`.P-``CM#010\`U$`/(-$A+V#05Y_0W00`$."0`#
M#@!`!`X`A`8.3`4+#D38$0Z:0!8.%%$;#A(+(`X`0"$.`0(C#H`5)PX!("D.
M``@J#DH(+@X`PC$.``@R#@)`-`X@,#<."9@\#@``/`Z`&#\.+.)&#@@`1PX$
M`$@.!`!)#N`030X4`$\.((!1#@`@4@X`F%4.`!!6#H)P6PZ"`%T.B`)@#@`<
M8PXB3&@.`0!I#@"1;`X@"&X.`D!P#D``<0X`''0.`$1V#H,#>P[!?(,.(2&'
M#@"$B0X"X(T.`@".#L!$D@X*XI@.`PZ=#B:!H@[0`J8.``BG#B$IK`Z0EK(.
M`4"T#L*XNPY!8L`.@`#!#@8*Q0Y1ILP.$@'/#BR!U`X`QM@.``39#K`,W@Z`
MHN(.*:3H#D"&[`X`@.T.`DKQ#D$P]0X``O8.0+K\#E<``0\!4`0/("`&#X"(
M"0^P)`X/`B`0#Q(!$P_3`AD/!``:#Q$"'0\``!T/@``>#P1`(`^"#"0/`.`G
M#P@P*@\``"H/$1`M#P@`+@\(`C`/I($U#Z!`.`\.0CT/``0^#T#`00^!`$,/
M`$A%#_4M3P^1#U8/!]A=#RD&8@]\`&</`4!I#T9%;P].@G4/`,!W#P@0>0\%
M,'T/-NV'#X`,B@]`98\/"Y.6#Q`(F`\`!IH/(.B?#PK(I`^"8*@/R@"L#S1`
ML`\"+K4/`1*X#P20NP](&<`/``#`#P``P`\``,`/``#`#P``P`\``,`/``#`
M#P``P`\``,`/0`7##P`0Q`\Q`,</`$S*#Z4"SP\@5=0/$$37#Q`#V@\$(]X/
M(E3C#S2`YP\#"NL/`1+N#VL2]0^A`?D/`"#Z#TB@_@](!`$00$4%$`"`!A"-
MX`T0\!H4$$`H%Q`FAAT0%@0A$!A0)1``3"@0,@`K$!(A+Q#D!340``TX$`B*
M/!``0CX0`$A`$#,`1!!@"$<0`X=-$`&%41``-%00"0%7$"CD71!%(&$0`(%C
M$*@E:1`87&\0H#5U$`38>A`"''X0X`*"$*$`A1```H804,"*$$9!CQ``:)(0
M!*:7$&#RGA"*NZ<0``"G$+;(KQ#B`+,0`F"V$#X"O!"``+T0`(G`$'(#QA"!
MALL0!@#-$```S1"("-`0`$;3$$!!UA`$#MH0`"#;$"(6X!!($.,0`(KF$!<B
M[!`8=/(0``#R$``2]!`"(?<0``+X$(`(^A!*F``1(`0"$0```A$1$@81`@`'
M$029#!%5*A,1`@05$0!0%Q$0$!D1```9$9I%(!$JL"81`*`H$0I"+!$(`BX1
M""<S$0``,Q&0@#81$@@Y$4"'/A$!!$`1`N)%$2`P2!$P!DP1@(Q0$<0$5!'`
M!%<1`"!8$0"`61$`0%H1,=AA$8``8A$``F,1`!1E$0@`9A$8`FD1``!I$8`(
M:Q$0BF\1$"!Q$0!`<A$-`781`!5Y$0``>1$``'D1`$!Z$:"`?1%``7\14`&"
M$00@A!$`@(41!`"&$0@$B!$0`(D1``")$0&0C!$$2I`1(`"1$0"`DA$,`)01
M0@B7$4$PFQ&,*J$1#@FF$87`JQ$&*;`1Q$"T$0`(M1$0`+81!H"Y$3"ROQ$"
M`<$1."'&$8``QQ$-`\P1(`3.$4`)T1$2`-,1`(#4$1`$UA$$@-@1RHC>$4@`
MX!$"!N,1!"3F$0$`YQ$$`.@1"`#I$1`!ZQ$-5?(1R*GY$2@D_1%2#`(2```"
M$C%(!Q)-8@X2+P(4$J`P&!(H01P2>P4D$@72*A*4J#`21!@T$L)L.Q+"14$2
M%T!&$M$N3A(!&5(2"`)4$@+"6!(`%5L20)!>$I$@8A(!!&02301I$@``:1(`
M`&D2``!I$@``:1(``&D2``!I$@``:1(``&D2``!I$H"`:Q)"%7`2(`1R$@(,
M=1(`!G<2!!1Z$@!@?!*'GX82V;F0$I\%F!(*5)T2722D$A`XJ!*P):X22`"P
M$@``L!(``+`2``"P$@``L!)0"+,2F0"W$B`$N1(``KH2"`&\$@A$OQ)`F,,2
M`"C%$@J!R1((`,H2`(3,$@%`SA(`!,\2(0#1$I0'UQ(`@MD2`0#:$E``W!*"
M).`2``#@$@`<XQ(``.,2`3SH$@2`ZA(`".L2`$GN$B@"\1(\^/H2P(;_$@C+
M!1,P8@H3`*`,$P0`#1,```T3```-$P`8#Q-(H103!P`7$R1`&A,2`!P30"P@
M$X4B)1-OJ2\3L^8Y$P]`/A,F4403AFQ+$SMR5!,+XEL3I+5C$Y^%;!,B`F\3
M3(5U$R,!>1,"!'L3`$!\$P(A?Q,@(($3!`""$R0"A1.`((<3!`"($P!^CA,$
M`(\3!!:3$Z`!EA.`*IH3!!"<$P#8H!,R`*,3@?JK$X,QL1.(!+03(`"U$P`@
MMA.'0+L3``"[$Q"$OA,A`L$3@$C$$W0`R!,``,@3*0#+$TH1T!,``-`3R`+4
M$P"0UA,$`-<3$`39$P`1VQ,0`-P3`<7A$U?)ZA,``.H3`"WN$Q`(\!,`0/$3
M(%#T$P`0]1-0!/@3B##\$P$`_1,(`/X3`D``%!(``A1```,4$``$%``!!10@
M"`<4(`$)%!``"A0&"`T4```-%`"@#Q0```\4```/%```#Q0```\4```/%```
M#Q0```\4```/%```#Q0```\4```/%```#Q0```\4```/%```#Q2``!`4"8H5
M%!X!&A0X(1\4`A@B%(`$)!1P$"@4!@`J%```*A0``"H4`!`K%`)$+A0$B#$4
M%3@W%`'X/10<!$$4Z2%(%&!L3A0P&U04B`58%(((6Q3S>F848!IK%`R'<13%
M"G<4P0!Z%$I2@!2``($4!2*%%!0!B!1"4(P4!B*0%)`$DQ0`J)84``"6%`$I
MFA0``)H40`B<%`@0GA0``)X42(BB%&\5JQ2/`;$4`""R%`$+MA1`<+H4$$6^
M%*"(PA0``,(4``#"%```PA0`@<04`@#%%)``QQ0`F,H4!N#/%!!PTQ0(%M<4
M"4';%`$!W10``-T4(#KB%)8`YA0``.84``#F%```YA1`(ND4(''N%!H"\A0"
M`/,4)Z+Z%``@^Q0"@/T4`L$!%0`"`A4`"`,5P0`&%2D@"A6@C`\5)`83%0``
M$Q4``!,5```3%0`!%!4``145```5%1@!&!4@0!H5```:%0``&A4`!!L5@`0=
M%0(0'Q4^@"45$`0G%0"`*!4``"@5`$`I%0*`*Q4`2"T5```M%0`"+A5``"\5
M$`$Q%0``,14`(#(5)0`U%2``-A4$"#@5@`(Z%8``.Q4``#L5```[%0``.Q4`
M`#L5```[%0``.Q4``#L5```[%:`"/A58`$$5``)"%0`(0Q5``445``A&%0``
M1A4"($@5`Q!+%00`3!4``$P5``!,%0""3A40`$\5$`!0%8``414``%$5!`=5
M%0``514`1%<5``!7%0``5Q4``%<5``!7%0``5Q4@HEL5``!;%8R@8!4@`&$5
M,$AE%0A@:!4266X5``%O%1``<!6`07,5"`!T%0$`=14`"'85`$QY%02`>Q6"
M%'\5@`"`%0`@@14A$````````````````````````````````-8!#__B`3L`
MYP$``.<!``#G`?[_]@'__P8"__\6`O__)@+__S8"#P`Z`O[_20+__UD"__]I
M`O__>0+__XD"?P"0`@``D`(``)`"``"0`O[_GP+__Z\"__^_`O__SP+__]\"
M_W_N`@``[@(``.X"``#N`@``[@(``.X"``#N`@``[@+___X"_Q\+`P``"P,`
M``L#```+`P``"P/__QL#_X\H`P``*`,``"@#```H`P``*`,``"@#```H`P``
M*`,``"@#```H`P``*`,``"@#```H`P``*`,``"@#```H`P``*`,?_S4#__]%
M`___50/__V4#_X=Q`TDY``````````"K````JP`@,[``8P"T``T(N````+@`
M``"X````N``0@+H`'@"^````O@``$+\```"_````OP```+\```"_````OP`(
M`L$`2`##`$8(QP```,<```#'`!AXS0#_`]<`_P/A````X0#_`^L```#K````
MZP```.L`%`#M````[0```.T`C8GT``)D^`"A7P$!,#`%`0``!0$$``8!,PP,
M`0``#`',`!`!``(1`2``$@$``!(!```2`0``$@$``!(!```2`0``$@$$`!,!
M```3`0``$P$``!,!```3`0``$P$``!,!```3`0``$P$``!,!```3`0``$P$`
M`!,!```3`0``$P$``!,!```3`0``$P$``!,!```3`0``$P'_?R(!\/\N`0<`
M,0$`\#4!__]%`3\`2P$``$L!__];`?\#90$``&4!#_!M`?__?0'__XT!__^=
M`?\/J0$``*D!``"I`0``J0$``*D!!`"J`?L#LP',,+D!P\G!`0,`PP$``,,!
M``##`6#`QP$`4,D!``#)`0``R0$%`,L!``#+`;LW````````````````````
M`````````````````````````````````````````))E!P#?]Q4`0``6`('!
M&P!``!P`@4$@````(``"`"$`P``C``Z!*``'#BX`#``P`,``,@```#(````R
M````,@```#(````R````,@```#(````R````,@```#(````R````,@```#(`
M```R````,@```#(````R````,@```#(````R````,@"``#,``2\Y````.0``
M`#D````Y````.0```#D````Y````.0```#D````Y````.0```#D`_O](`/L#
M40#^_V``^P-I````:0```&D```!I``(`:@#__WH`__^*`/__F@#__ZH``@``
M`````````#U/<T]'4/E0H%+O4W54Y50)5L%:MEN'9K9GMV?O9TQKPG/"=3QZ
MVX($@U>(B(@VBLB,SXW[CN:/U9D[4G13!%1J8&1AO&O/<QJ!NHG2B:.5@T\*
M4KY8>%GF67)>>5['8<!C1F?L9W]HEV].=@MW]7@(>O]Z(7R=@&Z"<8+KBI.5
M:TZ=5?=F-&ZC>.UZ6X00B4Z'J)?84DY7*EA,71]AOF$A8F)ET6=$:AMN&'6S
M=>-VL'<Z?:^04912E)6?(U.L7#)UVX!`DIB56U((6-Q9H5P77;=>.E]*7W=A
M7VQZ=89UX'QS?;%]C']4@2&"D85!B1N+_))-ED><RT[W3@M0\5%/6#=A/F%H
M83EEZFD1;Z5UAG;6=H=[I8++A`#YIY.+E8!5HEM15P'YLWRY?[61*%"[4T5<
MZ%W28FYCVF3G9"!NK'!;>=V-'HX"^7V019+XDGY.]DYE4/Y=^EX&85=I<8%4
MAD>.=9,KFEY.D5!P9T!H"5&-4I)2HFJ\=Q"2U)ZK4B]@\H](4*EA[6/*9#QH
MA&K`;XB!H8F4E@58?7*L<@1U>7UM?JF`BXETBV.049V)8GIL5&]0?3I_(XI\
M44IAG7L9BU>2C).L3M-/'E"^4`91P5+-4G]3<%>#6)I>D5]V8:QASF1L96]F
MNV;T9I=HAVV%</%PGW2E=,ITV75L>.QXWWKV>D5]DWT5@#^`&X&6@V:+%8\5
MD.&3`Y@XF%J:Z)O"3U-5.EA166-;1ERX8!)B0FBP:.AHJFY,=7AVSG@]>OM\
M:WY\?@B*H8H_C(Z6Q)WD4^E32E1Q5/I6T5ED6SM<JU[W8C=E165R9:!FKV?!
M:;UL_'60=GYW/WJ4?P.`H8"/@>:"_8+P@\&%,8BTB*6*`_F<CRZ3QY9GF-B:
M$Y_M5)ME\F:/:$!Z-XQ@G?!69%<1709FL6C-:/YN*'2>B.2;:&P$^:B:FT]L
M47%1GU)46^5=4&!M8/%BIV,[9=ES>GJCAJ*,CY<R3N%;"&*<9]QTT7G3@X>*
MLHKHC4Z02Y-&F-->Z&G_A>V0!?F@49A;[%MC8?IH/FM,<"]TV'2A>U!_Q8/`
MB:N,W)4HF2Y276#L8@*0BD])42%3V5CC7N!F.&V:<,)RUG-0>_&`6Y1F4YMC
M:W]63H!02EC>6"I@)V'08M!I09N/6QA]L8!?CZ1.T5"L5*Q5#%N@7>==*F5.
M92%H2VKA<HYV[W=>??E_H(%.A=^&`X].C\J0`YE5FJN;&$Y%3EU.QT[Q3W=1
M_E)`4^-3Y5..5!16=5>B5\=;AUW07OQAV&)19;AGZ6?+:5!KQFOL:T)LG6YX
M<-=REG,#=+]WZ7=V>G]]"8#\@06""H+?@F*(,XO\C,".$9"QD&22MI+2F46:
MZ9S7G9R?"U=`7,J#H)>KE[2>&U28>J1_V8C-CN&0`%A(7)ACGWJN6Q-?>7JN
M>HZ"K(XF4#A2^%)W4PA7\V)R8PIKPVTW=Z535W-HA7:.U94Z9\-J<&]MBLR.
M2YD&^7=F>&NTC#R;!_GK4RU73EG&8_MIZG-%>+IZQ7K^?'6$CXESC360J)7[
M4D=71W5@>\R#'I((^5AJ2U%+4H=2'V+8:'5IF9;%4*12Y%+#8:1E.6C_:7YT
M2WNY@NN#LHDYB]&/29D)^<I.EUG29!%FCFHT=(%YO7FI@GZ(?XA?B0KY)I,+
M3\I3)6!Q8G)L&GUF?9A.8E'<=Z^``4\.3W91@%'<56A6.U?Z5_Q7%%E'69-9
MQ%N07`Y=\5U^7LQ?@&+79>-E'F<?9UYGRVC$:%]J.FLC;'UL@FS';9AS)G0J
M=()THW1X=7]U@7CO>$%Y1WE(>7IYE7L`?;I]B'\&@"V`C(`8BD^+2(QWC2&3
M))/BF%&9#IH/FF6:DI[*?79/"53N8E1HT9&K53I1"_D,^1Q:YF$-^<]B_V(.
M^0_Y$/D1^1+Y$_FCD!3Y%?D6^1?Y&/G^BAGY&OD;^1SYEF8=^59Q'OD?^>.6
M(/E/8WIC5U,A^8]G8&ES;B+Y-W4C^23Y)?D-?2;Y)_ERB,I6&%HH^2GY*ODK
M^2SY0TXM^6=12%GP9Q"`+OES671>FF3*>?5?;&#(8GMCYUO76ZI2+_ET62E?
M$F`P^3'Y,OE9=#/Y-/DU^3;Y-_DX^=&9.?DZ^3OY//D]^3[Y/_E`^4'Y0OE#
M^<-O1/E%^;^!LH_Q8$;Y1_EF@4CY2?D_7$KY2_E,^4WY3OE/^5#Y4?GI6B6*
M>V<0?5+Y4_E4^57Y5OE7^?V`6/E9^3Q<Y6P_4[IN&EDV@SE.MDY&3ZY5&%?'
M6%9?MV7F98!JM6M-;NUW[WH>?-Y]RX:2B#*16Y.[9+YO>G.X=5205E5-5[IA
MU&3'9N%M6VYM;[EO\'5#@+V!086#B<>*6HL?DY-L4W54>P^.79`050)86%AB
M7@=BGF3@:'9UUGRSA^B>XTZ(5VY7)UD-7+%<-EZ%7S1BX62S<_J!BXBXC(J6
MVYZ%6[=?LV`24`!2,%(65S585U@.7&!<]ER+7:9>DE^\8!%CB6,79$-H^6C"
M:MAM(6[4;N1O_G'<=GEWL7D[>@2$J8GMC/.-2(X#D!204Y#]D$V3=I;<E])K
M!G!8<J)R:'-C=[]YY'N;?H"+J5C'8&9E_66^9HQL'G')<5J,$YAM3H%ZW4ZL
M4<U1U5(,5*=A<6=0:-]H'FU\;[QULW?E>O2`8X2%DEQ1EV5<9Y-GV'7'>G.#
M6OE&C!>0+9AO7,"!FH)!D&^0#9*77YU=66K(<7MV27ODA02+)Y$PFH=5]F%;
M^6EVA7\_AKJ'^(B/D%SY&VW9<-YS87T]A%WY:I'QF5[Y@DYU4P1K$FL^<!MR
M+88>GDQ2HX]07>5D+&46:^MO0WR<?LV%9(F]B<EBV($?B,I>%V=J;?QR!71O
M=(*'WI"&3PU=H%\*A+=1H&-E=:Y.!E!I4<E1@6@1:JY\L7SG?&^"THH;C\^1
MMD\W4?520E3L7FYA/F+%9=IJ_F\J>=R%(XBME6*::IJ7GLZ>FU+&9G=K'7`K
M>6*/0I>080!B(V4C;TEQB73T?6^`[H0FCR.02I.]41=2HU(,;<APPHC)7H)E
MKFO";SY\=7/D3C9/^59?^;I<NET<8+)S+7N:?\Y_1H`>D#22]I9(EQB889^+
M3Z=OKGFTD;>6WE)@^8ADQ&33:EYO&'`0<N=V`8`&AER&[XT%CS*7;YOZG76>
MC'A_>:!]R8,$DW^>DY[6BM]8!%\G9R=PSW1@?'Z`(5$H<&)RRGC"C-J,](SW
MEH9.VE#N6]9>F67.<4)VK7=*@/R$?)`GFXV?V%A!6F)<$VK:;0]O.W8O?3=^
M'H4XB>232Y:)4M)E\V>T:4%MG&X/<`ET8'19=21V:W@LBUZ8;5$N8GB6ED\K
M4!E=ZFVX?2J/BU]$81=H8?F&EM)2BX#<4<Q17FD<>KY]\8-UEMI/*5*84P]4
M#E5E7*=@3F>H:&QM@7+X<@9T@W1B^>)U;'QY?[A_B8//B.&(S)'0D>*6R9L=
M5'YOT'&8=/J%JHZCEE><GYZ79\MM,W3H@1:7+'C+>B![DGQI9&IT\G6\>.AX
MK)E4F[N>WEM57B!OG(&K@XB0!TY-4RE:TEU.7V)A/6-I9OQF_VXK;V-PGG<L
MA!.%.X@3CT69.YP<5;EB*V>K;`F#:HEZEZ%.A%G87]E?&V>R?51_DH(K@[V#
M'H^9D,M7N5F26M!;)V::9X5HSVMD<75_MXSCC(&019L(@8J,3)9`FJ6>7UL3
M;!MS\G;?=@R$JE&3B4U1E5')4LEHE&P$=R!WOWWL?6*7M9[%;A&%I5$-5'U4
M#F:=9B=IGVZ_=I%W%X/"A)^':9&8DO2<@HBN3Y)1WU+&63U>56%X9'EDKF;0
M9R%JS6O;:U]R87)!=#AWVW<7@+R"!8,`BRB+C(PH9Y!L9W+N=F9W1GJIG7]K
MDFPB629GF81O4Y-8F5G?7L]C-&9S9SIN*W/7>M>"*)/94NM=KF'+80IBQV*K
M9.!E66EF:\MK(7'W<UUU1GX>@@*#:H6CBK^,)Y=AG:A8V)X14`Y2.U1/58=E
M=FP*?0M]7H"*AH"5[Y;_4I5L:7)S5)I:/EQ+74Q?KE\J9[9H8VD\;D1N"7=S
M?(Y_AX4.B_>/89?TGK=<MF`-8:MA3V7[9?QE$6SO;)]SR7/A?925QEL<AQ"+
M75):4\UB#V2R9#1G.&K*;,!SGG24>Y5\&WZ*@3:"A(7KC_F6P9DT3TI3S5/;
M4\QB+&0`99%EPVGN;%AO[7-4=2)VY';\=M!X^W@L>49]+(+@A]2/$ICOF,-2
MU&*E9"1N46]\=LN-L9%BDNZ:0YLC4(U02E>H62A<1UYW7S]B/F6Y9<%E"6:+
M9YQIPF[%>"%]JH"`@2N"LX*AA(R&*HH7BZ:0,I:0GPU0\T]C^?E7F%_<8I)C
M;V=#;AEQPW;,@-J`](CUB!F)X(PICTV1:I8O3W!/&U[/9R)H?79^=D2;85X*
M:FEQU'%J=63Y07Y#A>F%W)@03T][<'^EE>%1!EZU:#YL3FS;;*]RQ'L#@]5L
M.G3[4(A2P5C89)=JIW16=J=X%X;BE3F79?E>4P%?BHNHCZ^/BI`E4J5W29P(
MGQE.`E!U45M<=UX>9CIFQ&?%:+-P`77%=<EYW7HGCR"9")K=3R%8,5CV6VYF
M96L1;7IN?6_D<RMUZ8/<B!.)7(L4CP]/U5`04UQ3DUNI7PUGCWEY@2^#%(4'
MB8:).8\[CZ69$IPL9W9.^$])60%<[USP7&=CTFC]<*)Q*W0K?NR$`H<BD-*2
M\YP-3MA.[T^%4%92;U(F5)!4X%<K669:6EMU6\Q;G%YF^79B=V6G96YMI6XV
M<B9[/WPV?U"!48&:@4""F8*I@P.*H(SFC/N,=(VZC>B0W)$<ED26V9GGG!=3
M!E(I5'16LUA466Y9_U^D86YB$&9^;!IQQG:)?-Y\&WVL@L&,\)9G^5M/%U]_
M7\)B*5T+9]IH?'A#?FR=%4Z94!53*E-14X-98EJ'7K)@BF%)8GEBD&6'9Z=I
MU&O6:]=KV&NX;&CY-73Z=1)XD7C5>=AY@WS+?>%_I8`^@<*!\H,:A^B(N8IL
MB[N,&9%>E]N8.Y^L5BI;;%^,9;-JKVM<;?%O%7!=<JUSIXS3C#N8D6$W;%B`
M`9I-3HM.FT[53CI//$]_3]]/_U#R4_A3!E7C5=M6ZUAB61%:ZUOZ6P1<\UTK
M7IE?'6!H8YQEKV7V9_MGK6A[:YELUVPC;@EP17,">#YY0'E@><%YZ7L7?7)]
MAH`-@HZ#T83'AM^(4(I>BAV+W(QFC:V/JI#\F-^9G9Y*4FGY%&=J^9A0*E)Q
M7&-E56S*<R-UG767>YR$>)$PEW=.DF2Z:UYQJ84)3FOY26?N:!=NGX(8A6N(
M]V.!;Q*2KY@*3K=0SU`?4495JE475D!;&5S@7#A>BEZ@7L)>\V!1:&%J6&X]
M<D!RP'+X=F5YL7O4?_.(](ESBF&,WHP<EUY8O73]C,=5;/EA>B)]<H)R<A]U
M)75M^1E[A5C[6+Q=CUZV7I!?56"28G]C36619MEF^&86:/)H@')>=&Y[;GW6
M?7)_Y8`2@J^%?XF3BAV0Y)+-GB"?%5EM62U>W&`49G-FD&=0;,5M7V_S=ZEX
MQH3+D2N3V4[*4$A1A%4+6Z-;1V)^9<ME,FY]<0%T1'2'=+]T;':J>=I]57ZH
M?WJ!LX$Y@AJ&[(=UBN.->)"1DB6439FNFVA345Q4:<1L*6TK;@R"FX4[B2V*
MJHKJEF>?85*Y9K)KEG[^APV-@Y5=EAUEB6WN<6[YSE?36:Q;)V#Z8!!B'V9?
M9BES^7/;=@%W;'M6@'*`98&@BI*1%D[B4G)K%VT%>CE[,'UO^;",[%,O5E%8
MM5L/7!%<XEU`8H-C%&0M9K-HO&R(;:]N'W"D<-)Q)G6/=8YU&781>^![*WP@
M?3E]+(5MA0>&-(H-D&&0M9"WDO:7-YK73VQ<7V>1;9]\C'X6BQ:-'Y!K6_U=
M#63`A%R0X9B'<XM;FF!^9]YM'XJFB@&0#)@W4G#Y47".>):3<(C7D>Y/UU/]
M5=I6@E?]6,):B%NK7,!<)5X!80UB2V*(8QQD-F5X93EJBFLT;!EM,6_G<>ER
M>','=+)T)G9A=\!Y5WKJ>KE\CWVL?6%^GG\I@3&#D(3:A.J%EHBPBI"+.(]"
MD(.0;)&6DKF2BY:GEJB6UI8`EPB8EIG3FAJ;U%-^6!E9<%N_6]%M6F^?<2%T
MN72%@/V#X5V'7ZI?0F#L91)H;VE3:HEK-6WS;>-S_G:L=TU[%'TC@1R"0(/T
MA&.%8HK$BH>1'I,&F+29#&)3B/"/99('72==:5U?=)V!:(?5;_YBTG\VB7*)
M'DY83N=0W5)'4W]B!V9I?@6(7I:-3QE3-E;+6:1:.%Q.7$U<`EX17T-@O64O
M9D)FOF?T9QQSXG<Z><5_E(3-A):)9HIIBN&*58QZC/17U%L/7V]@[6(-:99K
M7&Z$<=)[58=8B_Z.WYC^F#A/@4_A3WM4(%JX6SQAL&5H9OQQ,W5>>3-]3H'C
M@9B#JH7.A0.'"HJKCIN/<?G%CS%9I%OF6XE@Z5L+7,-?@6QR^?%M"W`:=:^"
M]HK`3D%3<_G9E@]LGD[$3U)17E4E6NA<$6)9<KV"JH/^AEF('8H_EL66$YD)
MG5V="EBS7+U=1%[A8!5AX6,":B5N`I%4DTZ8$)QWGXE;N%P)8T]F2&@\=\&6
MC9=4F)^;H64!B\N.O)4U5:E<UEVU7I=F3';T@\>5TUB\8LYR*)WP3BY9#V`[
M9H-KYWDFG9-3P%3#5Q9=&V'69J]MC7A^@IB61)>$4WQBEF.R;0I^2X%-F/MJ
M3'^OG1J>7TX[4+91'%GY8/9C,&DZ<C:`=/G.D3%?=?EV^01]Y8)OA+N$Y86-
MCG?Y;T]X^7GYY%A#6UE@VF,896UEF&9Z^4II(VH+;0%P;''2=0UVLWEP>GOY
MBG]\^42)??F3B\"1?99^^0J9!%>A7[QE`6\`=J9YGHJMF5J;;)\$4;9AD6*-
M:L:!0U`P6&9?"7$`BOJ*?%L6AOI//%&T5D19J6/Y;:I=;6F&48A.64]_^8#Y
M@?F"68+Y@_E?:UULA/FU=!9YA?D'@D6".8,_CUV/AOD8F8?YB/F)^:9.BOG?
M5WE?$V:+^8SYJW5Y?F^+C?D&D%N:I58G6/A9'UJT6X[Y]EZ/^9#Y4&,[8Y'Y
M/6F';+]LCFV3;?5M%&^2^=]P-G%9<9/YPW'5<93Y3WAO>)7Y=7OC?9;Y+WZ7
M^4V(WXZ8^9GYFOE;DIOY]IR<^9WYGOF%8(5MG_FQ<:#YH?FQE:U3HOFC^:3Y
MTV>E^8YP,'$P=':"TH*F^;N5Y9I]GL1FI_G!<4F$J/FI^4M8JOFK^;A=<5^L
M^2!FCF9Y::YI.&SS;#9N06_:;QMP+W!0<=]Q<'.M^5MTKOG4=,AV3GJ3?J_Y
ML/GQ@F"*SH^Q^4B3LOD9E[/YM/E"3BI0M?D(4N%3\V9M;,IO"G-_=V)ZKH+=
MA0*&MOG4B&.*?8MKC+?YLY*X^1.7$)B43@U/R4^R4$A3/E0S5-I58EBZ6&=9
M&UKD6Y]@N?G*859E_V5D9J=H6FRS;\]PK'%2<WU["(>DBC*<!Y]+7(-L1'.)
M<SJ2JVYE=!]V:7H5?@J&0%'%6,%D[G05=7!VP7^5D,V65)DF;N9TJ7JJ>N6!
MV89XAQN*25J,6YM;H6@`:6-MJ7,3="QTEWCI?>M_&(%5@9Z#3(PNEA&8\&:`
M7_IEB6=J;(MS+5`#6FIK[G<666Q=S5TE<T]UNOF[^>50^5$O6"U9EEG:6>5;
MO/F]^:)=UV(69)-D_F2^^=QFO_E(:L#Y_W%D=,'YB'JO>D=^7GX`@'"!POGO
MAX&)((M9D,/Y@)!2F7YA,FMT;1]^)8FQC]%/K5"74<=2QU>)6+E;N%Y"895I
MC&UG;K9NE'%B="AU+'5S@#B#R80*CI23WI/$^8Y.44]V4"I1R%/+4_-3AUO3
M6R1<&F&"8?1E6W*7<T!TPG90>9%YN7D&?;U_BX+5A5Z&PH]'D/60ZI&%ENB6
MZ9;64F=?[64Q9B]H7'$V>L&0"IB13L7Y4FJ>:Y!OB7$8@+B"4X5+D)66\I;[
MEQJ%,9N03HIQQ)9#49]3X5035Q)7HU>;6L1:PULH8#]A]&.%;#EM<FZ0;C!R
M/W-7=-&"@8A%CV"0QOEBEEB8&YT(9XJ-7I)-3TE0WE!Q4PU7U%D!6@E<<&&0
M9BUN,G)+=.]]PX`.A&:$/X5?AUN(&(D"BU60RY=/FW-.D4\246I1Q_DO5:E5
M>ENE6WQ>?5Z^7J!@WV`(80EAQ&,X90EGR/G49]IGR?EA:6)IN6PG;<KY.&[+
M^>%O-G,W<\SY7'0Q=<WY4G;.^<_YK7W^@3B$U8B8BMN*[8HPCD*.2I`^D'J0
M29')D6Z3T/G1^0E8TOG3:XF`LH#3^=3Y05%K63E<U?G6^61OIW/D@`>-U_D7
MDH^5V/G9^=KYV_E_@`YB''!H?8V'W/F@5VE@1V&W:[Z*@)*QEEE.'U3K;2V%
M<);SE^Z8UF/C;)&0W5')8;J!^9V=3QI0`%&<6P]A_V'L9`5IQ6N1=>-WJ7]D
M@H^%^X=CB+R*<(NKD8Q.Y4X*3]WYWODW6>A9W_GR71M?6U\A8.#YX?GB^>/Y
M/G+E<^3Y<'7-=>7Y^WGF^0R`,X"$@.&"48/G^>CYO8RSC(>0Z?GJ^?28#)GK
M^>SY-W#*=LI_S'_\?QJ+ND[!3@-2<%/M^;U4X%;[6<5;%5_-7VYN[OGO^6I]
M-8/P^9.&C8KQ^6V7=Y?R^?/Y`$Y:3WY/^5CE9:)N.)"PD[F9^T[L6(I9V5E!
M8/3Y]?D4>O;Y3X/#C&511%/W^?CY^?G-3FE255N_@M1..E*H5,E9_UE06U=;
M7%MC8$AARVZ9<&YQAG/W=+5UP7@K?06`ZH$H@Q>%R87NBL>,S)9<3_I2O%:K
M92AF?'"X<#5RO7V-@DR1P)9RG7%;YVB8:WIOWG:17*MF6V^T>RI\-HC<E@A.
MUTX@4S18NUCO6&Q9!UPS7H1>-5^,8[)F5F<?:J-J#&L_;T9R^OE0<XMTX'JG
M?'B!WX'G@8J#;(0CA92%SX7=B!.-K)%WE9R6C5')5"A7L%M-8E!G/6B3:#UN
MTVY]<"%^P8BAC`F/2Y].GRURCWO-BAJ31T].3S)1@%30695>M6)U9VYI%VJN
M;!INV7(J<[UUN'LU?>>"^8-7A/>%6XJOC(>.&9"XD,Z67Y_C4@I4X5K"6UAD
M=67T;L1R^_F$=DUZ&WM-?#Y^WW][@RN+RHQDC>&-7X[JC_F/:9#1DT-/>D^S
M4&A1>%%-4FI285A\6&!9"%Q57-M>FV`P8A-HOVL(;+%O3G$@=#!U.'51=7)V
M3'N+>ZU[QGN/?FZ*/H])CS^2DY(BDRN4^Y9:F&N8'ID'4BIBF&)9;61VRGK`
M>W9]8%.^7)=>.&^Y<)A\$9>.F]Z>I6-Z9':'`4Z53JU.7%!U4$A4PUF:6T!>
MK5[W7H%?Q6`Z8S]E=&7,979F>&;^9VAIB6IC:T!LP&WH;1]N7FX><*%PCG/]
M<SIU6W>'>(YY"WI]>KY\CGU'@@**ZHJ>C"V12I'8D6:2S)(@DP:75I=<EP*8
M#I\V4I%2?%4D6!U>'U^,8-!CKVC?;VUY+'O-@;J%_8CXBD2.C9%DEIN6/9=,
MF$J?SD]&4<M1J5(R5A1?:U^J8\UDZ65!9OIF^68=9YUHUVC]:15O;F]G<>5Q
M*G*J=#IW5GE:>=]Y('J5>I=\WWQ$?7!^AX#[A:2&5(J_BIF-@8X@D&V0XY$[
MEM66Y9S/90=\LXW#DUA;"EQ24]EB'7,G4)=;GE^P8&MAU6C9;2YT+GI"?9Q]
M,7YK@2J.-8Y^DQB44$]05^9=IUXK8VI_.TY/3X]/6E#=6<2`:E1H5/Y53UF9
M6]Y=VEY=9C%G\6<J:.AL,FU*;HUOMW#@<X=U3'P"?2Q]HGT?@MN&.XJ%BG"-
MBHXSCS&03I%2D424T)GY>J5\RD\!4<91R%?O6_M<668]:EIMEF[L;PQQ;W7C
M>B*((9!UD,N6_YD!@RU.\DY&B,V1?5/;:FMI06QZA)Y8CF'^9N]BW7`1=<=U
M4GZXA$F+"(U+3NI3JU0P5T!7UU\!8P=C;V0O9>AE>F:=9[-G8FM@;)IL+&_E
M=R5X27E7>1E]HH`"@?.!G8*W@AB'C(K\^02-OHURD/1V&7HW>E1^=X`'5=15
M=5@O8R)D269+9FUHFVF$:R5ML6[-<VATH71;=;EUX78>=XMWYGD)?AU^^X$O
MA9>(.HK1C.N.L(\RD*V38Y9SE@>7A$_Q4^I9R5H97DYHQG2^=>EYDGJC@>V&
MZHS,C>V/GV459_WY]U=7;]U]+X_VD\:6M5_R881O%$Z83Q]0R5/?56]=[ETA
M:V1KRWB:>_[Y28[*CFZ026,^9$!WA'HODW^4:I^P9*]OYG&H=-ITQ'H2?()^
MLGR8?IJ+"HU]E!"93)DY4M];YF0M9RY][5##4WE86&%98?IAK&79>I*+EHL)
M4"%0=5(Q53Q:X%YP7S1A7F4,9C9FHF;-:<1N,F\6<R%VDWHY@5F"UH.\A+50
M\%?`6^A;:5^A8R9XM7W<@R&%QY'UD8I1]6=6>ZR,Q%&[6;U@588<4/_Y5%(Z
M7'UA&F+38O)DI67,;B!V"H%@CE^6NY;?3D-3F%4I6=U=Q63);/IME'-_>AN"
MIH7DC!".=Y#GD>&5(9;&E_A1\E2&5;E?I&2(;[1]'X]-CS64R5`67+YL^VT;
M=;MW/7QD?'F*PHH>6+Y9%EYW8U)RBG5K=]R*O(P2C_->=&;X;7V`P8/+BE&7
MUIL`^D-2_V:5;>]NX'WFBBZ07I#4FAU2?U+H5)1AA&+;8J)H$FE::35JDG`F
M<5UX`7D.>=)Y#7J6@'B"U8))@TF%@HR%C6*1BY&ND<-/T5;M<==W`(?XB?A;
MUE]19ZB0XE-:6/5;I&"!86!D/7YP@"6%@Y*N9*Q0%%T`9YQ8O6*H8PYI>&D>
M:FMNNG;+>;N"*83/BJB-_8\2D4N1G)$0DQB3FI/;EC::#9P13EQU77GZ>E%[
MR7LN?L2$68YTCOB.$)`E9C]I0W3Z42YGW)Y%4>!?EFSRAUV(=XBT8+6!`X0%
MC=93.50T5C9:,5R*<.!_6H`&@>V!HXV)D5^:\IUT4,1.H%/[8"QN9%R(3R10
MY%797%]>96"4:+MLQ&V^<=1U]'5A=AIZ27K'??M];G_T@:F&'(_)EK.94I]'
M4L52[9BJB0-.TF<&;[5/XEN59XAL>&T;="=XW9%\D\2'Y'DQ>NM?UDZD5#Y5
MKEBE6?!@4V+68C9G56DU@D"6L9G=F2Q04U-$57Q7`?I88@+ZXF1K9MUGP6_O
M;R)T.'07BCB4450&5F972%^:84YK6'"M<+M]E8IJ62N!HF,(=SV`JHQ46"UD
MNVF56Q%>;VX#^FF%3%'P4RI9(&!+889K<&SP;!Y[SH#4@L:-L)"QF`3ZQV2D
M;Y%D!&5.41!4'U<.BE]A=F@%^MMU4GMQ?1J0!EC,:7^!*HD`D#F8>%!76:Q9
ME6(/D"J;76%Y<M:585=&6O1=BF*M9/ID=V?B;#YM+'(V=#1X=W^M@MN-%Y@D
M4D)7?V=(<N-TJ8RFCQ&2*I9K4>U33&-I3P15EF!799ML?VU,<OUR%WJ'B9V,
M;5^.;_EPJ($.8;]/3U!!8D=RQWOH?>E_39"MEQF:MHQJ5W->L&<-A%6*(%06
M6V->XEX*7X-ENH`]A8F56Y9(3P53#5,/4X94^E0#5P->%F";8K%B56,&^N%L
M9FVQ=3)XWH`O@=Z"882RA(V($HD+D.J2_9B1FT5>M&;=9A%P!G('^O5/?5)J
M7U-A4V<9:@)OXG1H>6B(>8S'F,280YK!5!]Z4VGWBDJ,J)BNF7Q?JV*R=:YV
MJXA_D$*6.5,\7\5?S&S,<V)UBW5&>_Z"G9E/3CR0"TY53Z93#UG(7C!FLVQ5
M='>#9H?`C%"0'I<5G-%8>%M0AA2+M)W26VA@C6#Q95=L(F^C;QIP57_P?Y&5
MDI50EM.7<E)$C_U1*U2X5&-5BE6[:K5MV'UF@IR2=Y9YG@A4R%32=N2&I)74
ME5R6HDX)3^Y9YEKW75)@EV)M9T%HAFPO;CA_FX`J@@CZ"?H%F*5.55"S5)-7
M6EEI6[-;R&%W:7=M(W#YA^.)<HKGBH*0[9FXFKY2.&@64'A>3V='@TR(JTX1
M5*Y6YG,5D?^7"9E7F9F94U:?6%N&,8JR8?9J>W/2CD=KJI97FE59`')KC6F7
MU$_T7"9?^&%;9NMLJW"$<[ES_G,I=TUW0WUB?2-^-X)2B`KZXHQ)DF^845MT
M>D"(`9C,6N!/5%,^6?U</F-Y;?ER!8$'@:*#SY(PF*A.1%$14HM78E_";,YN
M!7!0<*]PDG'I<VET2H.BAV&(")"BD*.3J)EN45=?X&!G8;-F685*CJ^1BY=.
M3I).?%356/I8?5FU7"=?-F)(8@IF9V;K:VEMSVU6;OANE&_@;^EO77#0<B5T
M6G3@=)-V7'G*?!Y^X8"F@FN$OX1.AE^&=(=WBVJ,K),`F&68T6`68G>16EH/
M9O=M/FX_=$*;_5_:8`][Q%087UYLTVPJ;=AP!7UYA@R*.YT64XQ4!5LZ:FMP
M=76->;YYL8+O@W&*08NHC'27"_KT9"MENGB[>&MZ.$Z:55!9IEM[7J-@VV-A
M:V5F4V@9;F5QL'0(?820:9HEG#MMT6X^<T&,RI7P44Q>J%]-8/9@,&%,84-F
M1&:E:<%L7V[);F)O3'&<=(=VP7LG?%*#5X=1D(V6PYXO4]Y6^UZ*7V)@E&#W
M869F`V><:NYMKF]P<&IS:GZ^@32#U(:HBL2,@U)R<Y9;:VH$E.Y4AE9=6TAE
MA67)9I]HC6W&;3MRM(!UD4V:KT\94)I3#E0\5(E5Q54_7HQ?/6=F<=US!9#;
M4O-29%C.6`1QCW'[<;"%$XJ(9JB%IU6$9DIQ,81)4YE5P6M97[U?[F.)9D=Q
M\8H=C[Z>$4\Z9,MP9G5GAF1@3HOXG4=1]E$(4S9M^(#1GA5F(VN8<-5U`U1Y
M7`=]%HH@:SUK1FLX5'!@/6W5?PB"UE#>49Q5:U;-5NQ9"5L,7IEAF&$Q8EYF
MYF:9<;EQNG&G<J=Y`'JR?W"*``````````````````````"L`:P$K`>L"*P)
MK`JL$*P1K!*L$ZP4K!6L%JP7K!FL&JP;K!RL':P@K"2L+*PMK"^L,*PQK#BL
M.:P\K$"L2ZQ-K%2L6*Q<K'"L<:QTK'>L>*QZK("L@:R#K(2LA:R&K(FLBJR+
MK(RLD*R4K)RLG:R?K*"LH:RHK*FLJJRLK*^LL*RXK+FLNZR\K+VLP:S$K,BL
MS*S5K->LX*SAK.2LYZSHK.JL[*SOK/"L\:SSK/6L]JS\K/VL`*T$K0:M#*T-
MK0^M$:T8K1RM(*TIK2RM+:TTK36M.*T\K42M1:U'K4FM4*U4K5BM8:UCK6RM
M;:UPK7.M=*UUK7:M>ZU\K7VM?ZV!K8*MB*V)K8RMD*V<K9VMI*VWK<"MP:W$
MK<BMT*W1K=.MW*W@K>2M^*WYK?RM_ZT`K@&N"*X)K@NN#:X4KC"N,:XTKC>N
M.*XZKD"N0:Y#KD6N1JY*KDRN3:Y.KE"N5*Y6KERN7:Y?KF"N8:YEKFBN::YL
MKG"N>*YYKGNN?*Y]KH2NA:Z,KKRNO:Z^KL"NQ*[,KLVNSZ[0KM&NV*[9KMRN
MZ*[KKNVN]*[XKORN!Z\(KPVO$*\LKRVO,*\RKS2O/*\]KS^O0:]"KT.O2*])
MKU"O7*]=KV2O9:]YKX"OA*^(KY"OD:^5KYRON*^YK[ROP*_'K\BOR:_+K\VO
MSJ_4K]ROZ*_IK_"O\:_TK_BO`+`!L`2P#+`0L!2P'+`=L"BP1+!%L$BP2K!,
ML$ZP4[!4L%6P5[!9L%VP?+!]L("PA+",L(VPC["1L)BPF;":L)RPG["@L*&P
MHK"HL*FPJ["LL*VPKK"OL+&PL["TL+6PN+"\L,2PQ;#'L,BPR;#0L-&PU+#8
ML."PY;`(L0FQ"[$,L1"Q$K$3L1BQ&;$;L1RQ';$CL22Q);$HL2RQ-+$UL3>Q
M.+$YL4"Q0;%$L4BQ4+%1L52Q5;%8L5RQ8+%XL7FQ?+&`L8*QB+&)L8NQC;&2
ML9.QE+&8L9RQJ+',L="QU+'<L=VQW['HL>FQ[+'PL?FQ^[']L02R!;((L@NR
M#+(4LA6R%[(9LB"R-+(\LEBR7+)@LFBR:;)TLG6R?+*$LH6RB;*0LI&RE+*8
MLIFRFK*@LJ&RH[*ELJ:RJK*LLK"RM++(LLFRS++0LM*RV++9LMNRW;+BLN2R
MY;+FLNBRZ[+LLNVR[K+OLO.R]++ULO>R^++YLOJR^[+_L@"S`;,$LPBS$+,1
MLQ.S%+,5LQRS5+-5LU:S6+-;LURS7K-?LV2S9;-GLVFS:[-NLW"S<;-TLWBS
M@+.!LX.SA+.%LXRSD+.4LZ"SH;.HLZRSQ+/%L\BSR[/,L\ZST+/4L]6SU[/9
ML]NSW;/@L^2SZ+/\LQ"T&+0<M""T*+0IM"NT-+10M%&T5+18M&"T8;1CM&6T
M;+2`M(BTG;2DM*BTK+2UM+>TN;3`M,2TR+30M-6TW+3=M."TX[3DM.:T[+3M
MM.^T\;3XM!2U%;48M1NU'+4DM26U)[4HM2FU*K4PM3&U-+4XM4"U0;5#M42U
M1;5+M4RU3;50M52U7+5=M5^U8+5AM:"UH;6DM:BUJK6KM;"UL;6SM;2UM;6[
MM;RUO;7`M<2US+7-M<^UT+71M=BU[+40MA&V%+88MB6V++8TMDBV9+9HMIRV
MG;:@MJ2VJ[:LMK&VU+;PMO2V^+8`MP&W!;<HMRFW++<OMS"W.+<YMSNW1+=(
MMTRW5+=5MV"W9+=HMW"W<;=SMW6W?+=]MX"WA+>,MXVWC[>0MY&WDK>6MY>W
MF+>9MYRWH+>HMZFWJ[>LMZVWM+>UM[BWQ[?)M^RW[;?PM_2W_+?]M_^W`+@!
MN`>X"+@)N`RX$+@8N!FX&[@=N"2X);@HN"RX-+@UN#>X.+@YN$"X1+A1N%.X
M7+A=N&"X9+ALN&VX;[AQN'BX?+B-N*BXL+BTN+BXP+C!N,.XQ;C,N-"XU+C=
MN-^XX;CHN.FX[+CPN/BX^;C[N/VX!+D8N2"Y/+D]N4"Y1+E,N4^Y4;E8N5FY
M7+E@N6BY:;EKN6VY=+EUN7BY?+F$N86YA[F)N8JYC;F.N:RYK;FPN;2YO+F]
MN;^YP;G(N<FYS+G.N<^YT+G1N=*YV+G9N=NYW;G>N>&YX[GDN>6YZ+GLN?2Y
M];GWN?BY^;GZN0"Z`;H(NA6Z.+HYNCRZ0+I"NDBZ2;I+NDVZ3KI3NE2Z5;I8
MNERZ9+IENF>Z:+IING"Z<;ITNGBZ@[J$NH6ZA[J,NJBZJ;JKNJRZL+JRNKBZ
MN;J[NKVZQ+K(NMBZV;K\N@"[!+L-NP^[$;L8NQR[(+LINRN[-+LUNS:[.+L[
MNSR[/;L^NT2[1;M'NTF[3;M/NU"[5+M8NV&[8[MLNXB[C+N0NZ2[J+NLN[2[
MM[O`N\2[R+O0N].[^+OYN_R[_[L`O`*\"+P)O`N\#+P-O`^\$;P4O!6\%KP7
MO!B\&[P<O!V\'KP?O"2\);PGO"F\+;PPO#&\-+PXO$"\0;Q#O$2\1;Q)O$R\
M3;Q0O%V\A+R%O(B\B[R,O(Z\E+R5O)>\F;R:O*"\H;RDO*>\J+RPO+&\L[RT
MO+6\O+R]O,"\Q+S-O,^\T+S1O-6\V+S<O/2\];SVO/B\_+P$O06]![T)O1"]
M%+TDO2R]0+U(O4F]3+U0O5B]6;UDO6B]@+V!O82]A[V(O8F]BKV0O9&]D[V5
MO9F]FKV<O:2]L+VXO=2]U;W8O=R]Z;WPO?2]^+T`O@.^!;X,O@V^$+X4OAR^
M';X?OD2^1;Y(ODR^3KY4OE6^5[Y9OEJ^6[Y@OF&^9+YHOFJ^<+YQOG.^=+YU
MOGN^?+Y]OH"^A+Z,OHV^C[Z0OI&^F+Z9OJB^T+[1OM2^U[[8ON"^X[[DON6^
M[+X!OPB_";\8OQF_&[\<OQV_0+]!OT2_2+]0OU&_5;^4O["_Q;_,O\V_T+_4
MO]R_W[_AOSS`4<!8P%S`8,!HP&G`D,"1P)3`F,"@P*'`H\"EP*S`K<"OP+#`
ML\"TP+7`ML"\P+W`O\#`P,'`Q<#(P,G`S,#0P-C`V<#;P-S`W<#DP.7`Z,#L
MP/3`]<#WP/G``,$$P0C!$,$5P1S!'<$>P1_!(,$CP23!)L$GP2S!+<$OP3#!
M,<$VP3C!.<$\P4#!2,%)P4O!3,%-P53!5<%8P5S!9,%EP6?!:,%IP7#!=,%X
MP87!C,&-P8[!D,&4P9;!G,&=P9_!H<&EP:C!J<&LP;#!O<'$P<C!S,'4P=?!
MV,'@P>3!Z,'PP?'!\\'\P?W!`,($P@S"#<(/PA'"&,(9PAS"'\(@PBC"*<(K
MPBW"+\(QPC+"-,)(PE#"4<)4PEC"8,)EPFS";<)PPG3"?,)]PG_"@<*(PHG"
MD,*8PIO"G<*DPJ7"J,*LPJW"M,*UPK?"N<+<PMW"X,+CPN3"Z\+LPNW"[\+Q
MPO;"^,+YPOO"_,(`PPC#"<,,PPW#$\,4PQ7#&,,<PR3#)<,HPRG#1<-HPVG#
M;,-PPW+#>,-YPWS#?<.$PXC#C,/`P]C#V</<P]_#X,/BP^C#Z</MP_3#]</X
MPPC$$,0DQ"S$,,0TQ#S$/<1(Q&3$9<1HQ&S$=,1UQ'G$@,24Q)S$N,2\Q.G$
M\,3QQ/3$^,3ZQ/_$`,4!Q0S%$,44Q1S%*,4IQ2S%,,4XQ3G%.\4]Q43%1<5(
MQ4G%2L5,Q4W%3L53Q53%5<57Q5C%6<5=Q5[%8,5AQ63%:,5PQ7'%<\5TQ77%
M?,5]Q8#%A,6'Q8S%C<6/Q9'%E<67Q9C%G,6@Q:G%M,6UQ;C%N<6[Q;S%O<6^
MQ<3%Q<7&Q<?%R,7)Q<K%S,7.Q=#%T<74Q=C%X,7AQ>/%Y<7LQ>W%[L7PQ?3%
M]L7WQ?S%_<7^Q?_%`,8!Q@7&!L8'Q@C&#,80QAC&&<8;QAS&),8EQBC&+,8M
MQB[&,,8SQC3&-<8WQCG&.\9`QD'&1,9(QE#&4<93QE3&5<9<QEW&8,9LQF_&
M<<9XQGG&?,:`QHC&B<:+QHW&E,:5QIC&G,:DQJ7&I\:IQK#&L<:TQKC&N<:Z
MQL#&P<;#QL7&S,;-QM#&U,;<QMW&X,;AQNC&Z<;LQO#&^,;YQOW&!,<%QPC'
M#,<4QQ7'%\<9QR#'(<<DQRC',,<QQS/'-<<WQSS'/<=`QT3'2L=,QTW'3\=1
MQU+'4\=4QU7'5L=7QUC'7,=@QVC':\=TQW7'>,=\QWW'?L>#QX3'A<>'QXC'
MB<>*QX['D,>1QY3'EL>7QYC'FL>@QZ''H\>DQZ7'IL>LQZW'L,>TQ[S'O<>_
MQ\#'P<?(Q\G'S,?.Q]#'V,?=Q^3'Z,?LQP#(`<@$R`C("L@0R!'($\@5R!;(
M',@=R"#(),@LR"W(+\@QR#C(/,A`R$C(2<A,R$W(5,APR''(=,AXR'K(@,B!
MR(/(A<B&R(?(B\B,R(W(E,B=R)_(H<BHR+S(O<C$R,C(S,C4R-7(U\C9R.#(
MX<CDR/7(_,C]R`#)!,D%R0;)#,D-R0_)$<D8R2S)-,E0R5')5,E8R6#)8<EC
MR6S)<,ETR7S)B,F)R8S)D,F8R9G)F\F=R<#)P<G$R<?)R,G*R=#)T<G3R=7)
MULG9R=K)W,G=R>#)XLGDR>?)[,GMR>_)\,GQR?C)^<G\R0#*",H)R@O*#,H-
MRA3*&,HIRDS*3<I0RE3*7,I=RE_*8,IARFC*?<J$RIC*O,J]RL#*Q,K,RLW*
MS\K1RM/*V,K9RN#*[,KTR@C+$,L4RQC+(,LART'+2,M)RTS+4,M8RUG+7<MD
MRWC+><N<R[C+U,ODR^?+Z<L,S`W,$,P4S!S,'<PAS"+,)\PHS"G,+,PNS##,
M.,PYS#O,/,P]S#[,1,Q%S$C,3,Q4S%7,5\Q8S%G,8,QDS&;,:,QPS'7,F,R9
MS)S,H,RHS*G,J\RLS*W,M,RUS+C,O,S$S,7,Q\S)S-#,U,SDS.S,\,P!S0C-
M"<T,S1#-&,T9S1O-'<TDS2C-+,TYS5S-8,UDS6S-;<UOS7'->,V(S93-E<V8
MS9S-I,VES:?-J<VPS<3-S,W0S>C-[,WPS?C-^<W[S?W-!,X(S@S.%,X9SB#.
M(<XDSBC.,,XQSC/.-<Y8SEG.7,Y?SF#.8<YHSFG.:\YMSG3.=<YXSGS.A,Z%
MSH?.B<Z0SI'.E,Z8SJ#.H<ZCSJ3.I<ZLSJW.P<[DSN7.Z,[KSNS.],[USO?.
M^,[YS@#/`<\$SPC/$,\1SQ//%<\<SR#/),\LSRW/+\\PSS'/.,]4SU7/6,]<
MSV3/9<]GSVG/<,]QSW3/>,^`SX7/C,^ASZC/L,_$S^#/X<_DS^C/\,_QS_//
M]<_\SP#0!-`1T!C0+=`TT#70.-`\T$301=!'T$G04-!4T%C08-!LT&W0<-!T
MT'S0?="!T*30I="HT*S0M-"UT+?0N=#`T,'0Q-#(T,G0T-#1T-/0U-#5T-S0
MW=#@T.30[-#MT._0\-#QT/C0#=$PT3'1--$XT3K10-%!T4/11-%%T4S13=%0
MT5317-%=T5_18=%HT6S1?-&$T8C1H-&AT:31J-&PT;'1L]&UT;K1O-'`T=C1
M]-'XT0?2"=(0TBS2+=(PTC32/-(]TC_20=)(TES29-*`TH'2A-*(TI#2D=*5
MTIS2H-*DTJS2L=*XTKG2O-*_TL#2PM+(TLG2R]+4TMC2W-+DTN72\-+QTO32
M^-(`TP'3`],%TPS3#=,.TQ#3%-,6TQS3'=,?TR#3(=,ETRC3*=,LTS#3.-,Y
MTSO3/-,]TT331=-\TWW3@-.$TXS3C=./TY#3D=.8TYG3G-.@TZC3J=.KTZW3
MM-.XT[S3Q-/%T\C3R=/0T]C3X=/CT^S3[=/PT_33_-/]T__3`=0(U!W40-1$
MU%S48-1DU&W4;]1XU'G4?-1_U(#4@M2(U(G4B]2-U)34J=3,U-#4U-3<U-_4
MZ-3LU/#4^-3[U/W4!-4(U0S5%-45U1?5/-4]U4#51-5,U4W53]51U5C56=5<
MU6#59=5HU6G5:]5MU735==5XU7S5A-6%U8?5B-6)U9#5I=7(U<G5S-70U=+5
MV-79U=O5W=7DU>75Z-7LU?35]=7WU?G5`-8!U@36"-80UA'6$]84UA76'-8@
MUB36+=8XUCG6/-9`UD762-9)UDO63=91UE365=98UES69]9IUG#6<=9TUH/6
MA=:,UHW6D-:4UIW6G]:AUJC6K-:PUKG6N];$UL76R-;,UM'6U-;7UMG6X-;D
MUNC6\-;UUOS6_=8`UP37$=<8UQG7'-<@URC7*=<KURW7--<UUSC7/-=$UT?7
M2==0UU'75-=6UU?76-=9UV#78==CUV77:==LUW#7=-=\UWW7@=>(UXG7C->0
MUYC7F=>;UYW7```````P`3`",+<`)2`F(*@``S"M`!4@)2(\_SPB&"`9(!P@
M'2`4,!4P"#`),`HP"S`,,`TP#C`/,!`P$3"Q`-<`]P!@(F0B92(>(C0BL``R
M(#,@`R$K(>#_X?_E_T(F0"8@(J4B$B,"(@<B82)2(J<`.R`&)@4FRR7/)<XE
MQR7&):$EH"6S);(EO26\)9(AD"&1(9,AE"$3,&HB:R(:(CTB'2(U(BLB+"((
M(@LBAB*'(H(B@R(J(BDB)R(H(N+_TB'4(0`B`R*T`%[_QP+8`MT"V@+9`K@`
MVP*A`+\`T`(N(A$B#R*D``DA,"#!)<`EMR6V)60F8"9A)F4F9R9C)IDBR"6C
M)=`ET262):0EI26H):<EIB6I)6@F#R8.)APF'B:V`"`@(2"5(9<AF2&6(9@A
M;29I)FHF;"9_,APR%B'',R(APC/8,R$AK""N`/W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?\!_P+_`_\$_P7_!O\'_PC_
M"?\*_PO_#/\-_P[_#_\0_Q'_$O\3_Q3_%?\6_Q?_&/\9_QK_&_\<_QW_'O\?
M_R#_(?\B_R/_)/\E_R;_)_\H_RG_*O\K_RS_+?\N_R__,/\Q_S+_,_\T_S7_
M-O\W_SC_.?\Z_SO_YO\]_S[_/_]`_T'_0O]#_T3_1?]&_T?_2/])_TK_2_],
M_TW_3O]/_U#_4?]2_U/_5/]5_U;_5_]8_UG_6O];_US_7?_C_S$Q,C$S,30Q
M-3$V,3<Q.#$Y,3HQ.S$\,3TQ/C$_,4`Q03%",4,Q1#%%,48Q1S%(,4DQ2C%+
M,4PQ33%.,4\Q4#%1,5(Q4S%4,54Q5C%7,5@Q63%:,5LQ7#%=,5XQ7S%@,6$Q
M8C%C,60Q93%F,6<Q:#%I,6HQ:S%L,6TQ;C%O,7`Q<3%R,7,Q=#%U,78Q=S%X
M,7DQ>C%[,7PQ?3%^,7\Q@#&!,8(Q@S&$,84QAC&',8@QB3&*,8LQC#&-,8XQ
M<"%Q(7(A<R%T(74A=B%W(7@A>2']__W__?_]__W_8"%A(6(A8R%D(64A9B%G
M(6@A:2']__W__?_]__W__?_]_Y$#D@.3`Y0#E0.6`Y<#F`.9`YH#FP.<`YT#
MG@.?`Z`#H0.C`Z0#I0.F`Z<#J`.I`_W__?_]__W__?_]__W__?^Q`[(#LP.T
M`[4#M@.W`[@#N0.Z`[L#O`.]`[X#OP/``\$#PP/$`\4#Q@/'`\@#R0/]__W_
M_?_]__W__?\`)0(E#"40)1@E%"4<)2PE)"4T)3PE`24#)0\E$R4;)1<E(R4S
M)2LE.R5+)2`E+R4H)3<E/R4=)3`E)24X)4(E$B41)1HE&246)14E#B4-)1XE
M'R4A)2(E)B4G)2DE*B4M)2XE,24R)34E-B4Y)3HE/24^)4`E025#)40E125&
M)4<E2"5))4HE_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]_Y4SEC.7,Q,AF#/$,Z,SI#.E,Z8SF3.:,YLSG#.=
M,YXSGS.@,Z$SHC/*,XTSCC./,\\SB#.),\@SIS.H,[`SL3.R,[,SM#.U,[8S
MMS.X,[DS@#.!,X(S@S.$,[HSNS.\,[TSOC._,Y`SD3.2,Y,SE#,F(<`SP3.*
M,XLSC#/6,\4SK3.N,Z\SVS.I,ZHSJS.L,]TST#/3,\,SR3/<,\8S_?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W_Q@#0`*H`)@']_S(!_?\_`4$!V`!2
M`;H`W@!F`4H!_?]@,F$R8C)C,F0R93)F,F<R:#)I,FHR:S)L,FTR;C)O,G`R
M<3)R,G,R=#)U,G8R=S)X,GDR>C)[,M`DT232)-,DU"35)-8DUR38)-DDVB3;
M)-PDW23>)-\DX"3A).(DXR3D).4DYB3G).@DZ21@)&$D8B1C)&0D921F)&<D
M:"1I)&HD:R1L)&TD;B2]`%,A5"&\`+X`6R%<(5TA7B'F`!$!\``G`3$!,P$X
M`4`!0@'X`%,!WP#^`&<!2P%)`0`R`3(",@,R!#(%,@8R!S((,@DR"C(+,@PR
M#3(.,@\R$#(1,A(R$S(4,A4R%C(7,A@R&3(:,ALRG"2=))XDGR2@)*$DHB2C
M)*0DI22F)*<DJ"2I)*HDJR2L)*TDKB2O)+`DL22R)+,DM"2U)'0D=21V)'<D
M>"1Y)'HD>R1\)'TD?B1_)(`D@22")+D`L@"S`'0@?R"!(((@@R"$($$P0C!#
M,$0P13!&,$<P2#!),$HP2S!,,$TP3C!/,%`P43!2,%,P5#!5,%8P5S!8,%DP
M6C!;,%PP73!>,%\P8#!A,&(P8S!D,&4P9C!G,&@P:3!J,&LP;#!M,&XP;S!P
M,'$P<C!S,'0P=3!V,'<P>#!Y,'HP>S!\,'TP?C!_,(`P@3"",(,PA#"%,(8P
MAS"(,(DPBC"+,(PPC3".,(\PD#"1,)(PDS#]__W__?_]__W__?_]__W__?_]
M__W_H3"B,*,PI#"E,*8PIS"H,*DPJC"K,*PPK3"N,*\PL#"Q,+(PLS"T,+4P
MMC"W,+@PN3"Z,+LPO#"],+XPOS#`,,$PPC##,,0PQ3#&,,<PR##),,HPRS#,
M,,TPSC#/,-`PT3#2,-,PU##5,-8PUS#8,-DPVC#;,-PPW3#>,-\PX##A,.(P
MXS#D,.4PYC#G,.@PZ3#J,.LP[##M,.XP[S#P,/$P\C#S,/0P]3#V,/W__?_]
M__W__?_]__W__?\0!!$$$@03!!0$%00!!!8$%P08!!D$&@0;!!P$'00>!!\$
M(`0A!"($(P0D!"4$)@0G!"@$*00J!"L$+`0M!"X$+P3]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?\P!#$$,@0S!#0$-011!#8$-P0X!#D$.@0[!#P$
M/00^!#\$0`1!!$($0P1$!$4$1@1'!$@$201*!$L$3`1-!$X$3P0`````````
M````*"LF*SHK+"LJ*S`K+BLT*S(K.2LE*R<K*2L]*SXK+2LQ*RLK+RLS*S4K
M-BLW*S@K/RLB*SLK/"LD*R,K(2ME+R$O(B\C+R0O)2\F+R<O*"\I+RHO*R\L
M+TPO32].+T\O4"]1+U(O4R]4+U4O5B]7+U@O62]:+ULO7"]=+UXO7R]@+V$O
M8B]C+V0O+2\N+R\O,"\Q+S(O,R\T+S4O-B\W+S@O.2\Z+SLO/"\]+SXO/R]`
M+T$O0B]#+T0O12]&+T<O2"])+THO2R\A>G8L(WI\+SAZ(BPN>BQZ(RXD+BUZ
M)2XC+"]Z,7HP>B8N/GHR>C-Z-GHD+#5Z-'HW>GDL*"XG+B4L>BPK>BEZ*GHK
M+CEZ*BX\>CUZ6WX_>GLL0'I!>D)Z0WI3+41Z*2XH>B$N(2Q%>D9Z8'IA>F)Z
M9'I]+&-Z?2\X+%XM.2PZ+#LL97IF>EMZ9WIH>FEZ2'I'>ETM+2XO+BXN2WI*
M>DEZ3'I->C`N4'II+U%Z3WI.>E)Z5GIH+U-Z5'I5>C$L5WHR+C$N,RY9>EAZ
M-"Y:>B9[.GHE>EQZ77I>>F8M/RPV>T`L/BY!+#\N.7LW>T`N.'LZ>SM[9RU!
M+CQ[/7L^>UE^/WLS>S)[82U?>C4N-'LY+FYZ;WIQ>G!Z<GHZ+G-Z='IU>BY\
M=GIX>G=Z<"]Z>F,M9"UY>CPL>WI\>GUZ(7M^>B)[(WME+6(M:GIK>FQZ;7HO
M+"I[6RTK>S0L-BXW+C@N-7L]+C)\/"X[+B5[97Q:+6A\9GQG?&E\:GQ:+BXL
M1RQD?$@L2'Q'?$E\-2Q+?$I\3'Q-?&\O3GQ&?$]\47Q0?%$N4BXV+%)\-GPW
M?&DM8WQ.+2=[?BTY?#I\<"T[?#Q\/GP]?$TN/WQR+4%\0'QQ+5-\5'PB>F-[
M3RQE>T@N9'MF>V=[:GMK>VA[;'M)+F][:7MP>VU[;RUQ>WE^='MV>WE[<GMW
M>THN;GMU>W-[;2UX>R)\?'LC?'Y[(7Q[>WU[4GU:?"1\>GLE?"9\)WPI?$LN
M*'QN+2I\*WPL?%`L6BQ5+C%\4BP[>E,N<RUJ+VM\;'QO?&U\6RY4+2<L;GQP
M?')\*2QQ?"@L=7QW?&LO>7QT?'9\52US?'A\>GQ^?'M\(7U]?'Q\7"XB?58M
M)'TJ+%<M)7U=+B=]*'TC?29]*RQ>+BI]*7TL?6PO+7TL+#A\*WTN?3!]+WU8
M+5\N8"XM+#%],GU9+35]-'TS?39]5RY;?&HM7'QB?%@N77Q>?%]\62YT+U$L
M8'Q&+&PM87PH>RE[-RQ$?$5\<R]7+#TL+7Q,+GI^+WPP?$(N1WM(>THL27M+
M>TQ[2GM->U![0RY$+DY[5'M5>T][4WM2>T8N47M++%=[5GM%+EE[6'M'+EQ[
M6GM;>UU[3"Q@>UY[7WM-+&%[3BPT?#5\5WUU+"1Z:RU0?7<O47UK?6HN>"]L
M?6U];GUT+6PN6GU;?51]57UV+59]2GU?+$M]3'U-?74M3GU/?75]0'T_?6,N
M0GU!?4-]9"Y$?45]92Y&?68N1WUG+DA]82XW?3A].7UB+CI].WU)+#Q]/7T^
M?2(N6'UH+EE]:2YP?7%]<GUS?71];WUK+B5^)GYI+"=^>BTH?BE^*WYN+BU^
M*GXL?BY^;RY[+7`N>R]R+C,L;"Q4?E5^0BQ6?E=^0RQR+T0L6'YQ+W<N)'Y3
M?39^=BYJ+%-^:RQV?2-^,WQX+%0N62Q5?%9\=B]U+R]^<RXW?CE^.'X[?CQ^
M.GY`?C]^/GX]?D)^07YT+D5^0WY$?D9^1WXR+&`M7RU*?DA^2WYN+TE^=2Y,
M?FTO37Y/?DY^47Y2?B=Z>WU\?6@L?7UX+5@L?GTA?B)^>2TD>S!^7"PQ?ETL
M,GXS?C1^7BPU?GHO3RY0+GPL<7XN>TE]=RQR?G-^='YU?G9^=WY<?EY^77YP
M?BPN0GQ.+D-\52Q:?E]^>"Y@?F%^;BQM+&)^>2YP+&\L?"U3+%0L;GY<+6-^
M9'YF+V5^9WYF?FA^;WYI?FM^)BQJ?E`M;'YM?GXO?7Y^?B$M(BU^+",M)"TE
M+6`L)BU\+B@M*2TJ+2<M*RTL+6$L8BPM+2XM?2TL>RU[+WLP>S`L,7MG+U!^
M>'YZ+CXM<2P_+4`M0BU!+6)[=WUX?6TN=RUY?7I]5WQ;+%A\5BY9?$,M1"U%
M+48M1RU(+4DM2BT^+$LM0'M!>T)[0WM$>V@M17M%+$9[3"U-+7DO5BQR+"\M
M,"TQ+3(M,RTT+34M-BUQ+C<M."TY+3HM.RT\+3TM8RQ<?5U]7GU??60L8'UE
M+&%]8GUC?61]97UF+&<L9GUG?6A]:7UJ?4\M42TF>GLN4BUS+'0L>WY\?D`K
M:P,``&L#``!K`P``:P,``&L#@````````````````````````````$X#``!.
M`P``3@.00%$#$0!3`P$@50-=(EP#)X!A`Q``8@,!`&,#`@!D`P``9`,``&0#
M``!D`P``9`,"`&4#``!E`P`09@,$`&<#``AH`P``:`,"`&D#``!I`P``:0,`
M`&D#!@``````````````````````````````````````]0(``/4"``#U`@``
M]0(``/4"``#U`@``]0(``/4"``#U`@``]0)"`?@"``#X`@``^`*`@/H"&`3]
M`D``_@(`"/\"``#_`@`0``.!``(#""`$`P@`!0,`!`8#`4`(`S``"@,```H#
M```*`P``"@,```H#```*`P``"@,`$`L#`(`,`X``#0,("1`#```0`P``$`,`
M`!`#`$`1`P``$0,``!$#```1`P``$0,``!$#```1`P``$0,``1(#```2`P``
M$@,$`!,#```3`P``$P,``!,#```3`Q``%`,``!0#`047`P``%P,``!<#`D$:
M`P``&@,``!H#```:`P`!&P,``!L#```;`P``&P,``!L#```;`P``&P,``!L#
M```;`P``&P,`2!T#)`(@`P@`(0,``"$#`(`B`]$`)@,``"8#```F`P``)@,`
M`"8#```F`P``)@,``"8#```F`U``*`,`2RP##%`P`P``,`,``#`#```P`P``
M,`,``#`#```P`P``,`,``#`#```P`P``,`,``#`#```P`P``,`,``#`#!``Q
M`PAB-0,P`C@#0``Y`P``.0,``#D#```Y`P``.0,``#D#```Y`P$!.P,@`#P#
M0``]`T``/@,``#X#```^`P``/@,``#X#```^`P``/@,``#X#```^`P``/@,`
M`#X#```^`P``/@,``#X#```^`P``/@,``#X#```^`P``/@,``#X#$01!`\@C
M1P,``$<#`(!(`P,`2@,$"$P#"0``````9P(``&<"``!G`@``9P(``&<"$`!H
M`@``:`(``&@"``!H`@``:`(``&@"`$!I`A`8;`(``&P"0`!M`A`0;P(``G`"
M``1Q`@%`<P(``',"``!S`@`@=`(``'0"``!T`@`@=0(``'4"`@!V`@``=@(`
M`'8"`0!W`@`&>0(`@'H"``!Z`@``>@(``'H"``!Z`@$`>P(``'L"``![`@``
M>P(``'L"``![`@``>P(``'L"``![`@``>P(0`'P"``!\`@!`?0(``'T"``!]
M`@`"?@(`@'\"``!_`@0!@0(``($"``"!`@``@0(``($"``"!`@``@0(``($"
M`@""`@``@@(``(("``""`D`!A`(``(0"``2%`@``A0(``(4"``"%`@`!A@((
M`(<"``"'`H``B`(`$(D"``")`@``B0(``(D"`$"*`@$`BP((((T"``"-`@``
MC0(P`(\"`""0`@``D`(``)`"``"0`@`"D0)``)("``"2`@``D@("`),"``"3
M`@!0E0(``)4"``26`@`"EP(``I@"``"8`@@`F0(!`)H"``":`@``F@(`P)P"
M``&=`@``G0)$@*`"``"@`@`$H0*``*("``"B`@``H@(``*("$`"C`@``HP(`
M`*,"``"C`@$`I`(``*0"``"D`@0`I0((`:<"``"G`@``IP(!`*@"``"H`@``
MJ`(``*@"``"H`@``J`(``*@"!`"I`@``J0(``*D""`"J`@``J@(``*H"``"J
M`@``J@(``*H"``"J`@``J@(@0*P"``"L`@``K`(``*P"``"L`@`!K0(``*T"
M``"M`@$`K@(``*X""`"O`@``KP(`@+`"``"P`@0`L0(``+$"``BR`@``L@(`
M(+,"``"S`@``LP($`+0"``"T`@``M`)``+4"@`"V`@"$N`(``+@"`0&Z`@``
MN@(``+H"``"Z`@``N@(``+H"0`"[`@``NP(``+L"(`"\`@``O`)``+T"`0"^
M`@``O@(``+X"``"^`@@@P`(0`,$"``#!`@(`P@(``,("``3#`@``PP(``,,"
M``##`@"`Q`(``,0"``#$`@``Q`(``,0"``#$`@``Q`(``,0"``#$`@``Q`(`
M`,0"``#$`@``Q`(``,0"``#$`@``Q`(``,0"``#$`@``Q`(``,0"``#$`@`0
MQ0("",<"@`#(`@``R`(`!,D"``#)`@`"R@(`0,L"``#+`@``RP(``,L"``#+
M`@!AS@(``,X"0`#/`@``SP(``,\"``#/`@``SP(``,\"``#/`@``SP(``,\"
M``#/`@$`T`(``-`"``#0`H:`U`(`!-4"``#5`@``U0(``-4"``#5`@``U0(`
M`-4"``#5`@``U0(``-4"``#5`D``U@+"`-D"0`#:`B``VP()$-X"!`#?`@``
MWP(``-\"``#?`@`@X`(``.`"``#@`@``X`(``.`"``#@`@``X`(``.`"``#@
M`@``X`(``.`"``#@`@``X`(``.`"`0#A`@0`X@(``.("(`#C`@``XP(``.,"
M``#C`@`$Y`(``.0"``#D`@``Y`(``.0"``#D`@``Y`(``.0"``#D`@``Y`(`
M`>4"`0'G`@`@Z`((`>H"``3K`A``[`(`@.T"`!#N`@`5\0(!`/("``#R`@0`
M\P(``/,"``#S`@``\P(``/,"``#S`@``\P(``/,"0`#T`@``]`(``/0"``#T
M`@``]`(``/0"``#T`@``]`(``/0"``#T`@``]`(``/0"``#T`@``]`(``/0"
M``#T`D``````````````````9```@&4```!E`$``9@```&8`!`!G````9P``
M`&<```!G`"``:````&@```!H`$`!:@```&H```!J````:@```&H`"`AL`"``
M;0`*`&\``$AQ````<0```'$``@AS```$=````'0```!T``0`=0`0`'8```!V
M````=@``"'<`8`!Y````>0``0'H`!`![`!``?````'P```!\````?``$`'T`
M``!]``8`?P`0`(````"``(`@@@```((```""``$`@P```(,```"#````@P``
M`(,```"#````@P```(,```"#`("`A0```(4``$&'````AP`(`(@```"(````
MB````(@```"(````B```$(D`!`"*`"``BP```(L```"+````BP```(L```&,
M````C```&H\``""0```$D0```)$`B`"3```$E```$)4```"5````E0```)4`
M``"5````E0```)4```"5``$`E@```)8``$"7`,``F0```)D```"9````F0``
M`)D```"9````F0```)D```"9````F0```)D```"9````F0```)D`(`":````
MF@```)H```":````F@```)H```":```@FP```)L`0`"<```@G0"``)X``("?
M`!$`H0!``*(```"B`!``HP```*,```"C````HP```*,```"C````HP```*,`
M``"C````HP`!`*0```"D````I````*0`$`"E```4IP``(*@```"H````J```
M`*@```"H`(``J0```*D``0*K````JP```*L```"K````JP``$*P``8"N`(``
MKP`@Q+,```"S``)`M0``$+8```"V```(MP`@`+@`"%*\````O````+P``#"^
M`&P!PP`(),8```#&``(`QP`0`<D`(`#*````R@```,H```#*````R@```,H`
M``'+`$``S``!`,T``!#.````S@`!`,\`"`#0```@T0```-$```#1````T0``
M`-$`"`#2````T@``0-,``$#4```@U0```-4`!`#6````U@```-8```#6``!`
MUP`@`-@`"!#:`!``VP!`0-T``&#?````WP`0`.````3A```$X@```.(```#B
M```(XP```.,```#C``@`Y`!``.4```#E````Y0```.4```#E`(`0YP```.<`
M``#G````YP```.<```#G`"``Z````.@```3I``$`Z@```.H``"#K````ZP`4
M$.X```#N``!`[P```?````#P`(@`\@`(`/,`B`#U``*`]P`Q$/L``H;_````
M_P```/\``$```0`$`0$```$!```!`2```@$,``0!```$`0``!`$$`@8!0``'
M`0``!P$```<!``@(`8``"0$"`0L!```+`0``"P$```L!``0,`0``#`$```P!
M```,`1``#0$`$`X!``D0`0``$`$``!`!```0`8!P%`$``!0!!``5`0``%0$`
M`!4!`(`6`8`!&`$``!@!```8`0``&`$`D!H!```:`0``&@$``!H!```:`0``
M&@$``!H!@``;`0``&P$``!L!```;`0``&P$``!L!```;`0``&P$``!L!`$`<
M`0$`'0&``!X!"`(@`0``(`$``"`!```@`1``(0$``"$!```A`0``(0$(`"(!
M(``C`0``(P$``",!```C`0``(P$``",!```C`0``(P$``",!```C`0``(P$`
M`",!```C`0``(P%@!"8!```F`0,`*`$``"@!"``I`1``*@$``"H!```J`0@`
M*P$``"L!$``L`0``+`$``"P!`!`M`4``+@$`$"\!```O`0``+P$``"\!```O
M`0``+P$``"\!`(`P`0(`,0$``#$!```Q`0``,0$`0#(!```R`00`,P&$`#4!
M```U`0``-0$``#4!```U`8`@-P$``#<!```W`0``-P$``#<!```W`0``-P$`
M(#@!```X`0``.`$``#@!```X`0``.`$``#@!`!`Y`0`".@$``#H!`(`[`0`@
M/`$$`3X!```^`00`/P$``#\!```_`0`)00&``D,!``!#`0``0P$`($0!``!$
M`0!`10&$$$@!"`!)`0!H3`$``$P!``!,`0``3`$``$P!``!,`0``3`$``$P!
M``!,`0@!3@$``$X!`(!/`2``4`$``%`!@`!1`0`(4@$``%(!`()4`0``5`$`
M`%0!``%5`0``50$`0%8!``!6`0``5@$$@%@!``!8`0``6`$`"%D!``!9`0"4
M7`$``%P!``!<`0``7`$!`%T!`I!@`0(`80$+`&0!`!EG`0`):0$``&D!"B!L
M`0`(;0$@`&X!`0!O`0""<0$$@G0!``!T`0@`=0%``'8!``!V`0!0>`$@`'D!
M`!1[`2``?`$`0'T!``A^`0(`?P$``'\!``!_`0``?P$``'\!0`"``0``@`$`
M`(`!0`"!`0``@0$P`(,!``"#`0``@P$``(,!``"#`0``@P$``(,!``"#`0`!
MA`$``(0!$`"%`0``A0$``(4!``"%`2``A@$(`(<!``"'`0``AP$`!(@!``"(
M`0``B`$``(@!`"")`2``B@$`P(P!``",`0``C`&`((X!``".`9``D`%`!9,!
M``&4`2``E0%(`)<!`!"8`0``F`$``)@!``"8`0(`F0$``YL!$`6>`1`"H`$A
M"*,!,@"F`0``I@$``*8!``"F`00@J`$0`*D!``"I`0``J0$``*D!``"I`0``
MJ0$`"*H!``"J`0``J@$``*H!`#"L`8``K0$$`*X!@D"Q`0`$L@%!`+0!(`"U
M`0@"MP$``;@!@`R[`0``NP$``+L!``"[`4``O`&``+T!``"]`4"`OP$``+\!
M(`#``00`P0$0",,!(`#$`1`0Q@$``,8!``#&`0`0QP$``,<!`##)`1``R@$`
M`,H!`!#+`0``RP$``,L!``#+`0`$S`$``,P!`$'.`0``S@$``,X!``#.`0`P
MT`$``-`!`@32`0`0TP$`$-0!`4#6`0``U@$``-8!``#6`0``U@$``-8!``#6
M`0``U@$``-8!``#6`0",V0$``-D!``#9`0"`V@$``-H!`(#;`0``VP$``-L!
M!@#=`0`$W@$(`-\!@`#@`8``X0$``.$!``'B`0``X@$``N,!`"#D`00`Y0$`
M`.4!0`#F`1``YP$``.<!``3H`0``Z`$``.@!``#H`0``Z`$``.@!,`;L`6$`
M[P$"`/`!``#P`4``\0$(1/0!023X`8!`^@$@`/L!$(C^`80```(4``("$``#
M`@0`!`("`08"0`$(`@"!"@(!!`P"!``-`@``#0(``0X"```.`@`(#P((`!`"
M```0`D($$P(``!,"```3`@(`%`(0D!<"```7`@``%P(``!<"!``8`@``&`(`
M`!@"```8`@$`&0((`!H"$`$<`@`@'0(``!T"```=`@``'0($`!X"```>`D"`
M(`(``"`"`$`A`@``(0(``"$"```A`@`@(@)`%"4"``@F`@`$)P(`""@"`!`I
M`@``*0(``"D"```I`@``*0(``"D"0`@K`@``*P(`*"T"```M`@``+0(`0"X"
M```N`@`8,`)``#$"```Q`@4`,P(``#,"`@`T`@`&-@(``#8"(``W`@``-P(0
M`#@"```X`D``.0(``#D"`!`Z`@(`.P(``#L""``\`@``/`(``#P"""`^`HA$
M0@(!`$,"``!#`@0010(``$4"``%&`A$`2`(``4D"``!)`@``20(``$D"`$!*
M`@``2@)``$L"``!+`@``2P(0`$P"`$!-`@``30(``$T"($!/`@``3P((`%`"
M`$%2`@``4@("$%0"``!4`@``5`(``%0"``!4`@``5`(``%0"`$16`@`05P(`
M`%<"`(!8`H``60((`%H"``!:`@``6@(``%H"``!:`@"`6P(%`%T""`)?`B``
M8`(!`&$"`0!B`@``8@(!(&0"``!D`@``9`(``&0"``!D`D`09@(``&8"``!F
M`@``9@(``&8"(``@````(````"`````@````(````"`````@````(````"``
M```@````(````"`````@`/\/+````"P````L````+````"P````L````+```
M`"P````L``#_-`#__T0``0!%````10```$4```!%````10```$4```!%`/__
M50#_?Q\````?````'P```!\`@```````````````````````&P```!L````;
M````&P``@!P````<````'````!P````<````'````!P````<````'````!P`
M```<````'````!P````<````'````!P````<````'````!P````<``$`'0``
M`!T````=````'0`#```````````````````````9````&0```!D````9````
M&0```!D````9````&0```!D````9````&0``$!H``@``````````````````
M````````````````````````````````````````````````````````````
M```````````````````````W!0`,%@H````*``@(#```"`T````-`!`A$```
M`!````@1````$0```!$````1````$0```!$````1`%45&````!@```(/3C]G
M0DXJ=2Q9X9Y2AAQ3AU&/4?!0"T\C3P-/84]Z3VM/ZT_U3S10(E#V3W)0MDZN
M41!9VFLL4C)2M$^84KM2O%+-4MI2]U+&4\=3<%=L5[%7GU>>5[Y7S%<.6`Q8
M]5<)6#Q80UA%6$98/5A36(A8A%CX6*U60%E366U9*ERE5!U5-E5O54U5FE:<
M5O=6$%<95Q=>(5XH7FI>=%Q\7*A<GES#7--<XUSG7/]<!%T`71I=#%U.75I=
MA5V379)=PEW)75*(KU\&6:AE07)"<KQ>RU[LE?^5&HH'EA.6&Y:L6Z=;75PB
M7^Y9?%J66G-:GEJM6MI:ZEH;6U9;<IJ#FHF:C9J.FI6:IIJ5<YESH'.Q<Z5S
MIG/6<_!S_7/C<R1T#G0'=/9S^G,R="]T1'1"='%T>'1B=(9TGW2@=)ATLG3H
MET5GGV=[9\AG[F=+:*!H$F@?:&IHO&C[:&]HL6C!:.MH$VG1:!%ITVCL:"MI
MZ&B^:6EI0&EO:5]I8FDU:5EIO&G%:=IIW&D+:N5I9FJ6:K1JW7+Q7!1S.G.5
M:V=?_H#[=`-U7&5I929O^&7[90EF/69B9EYF;&:-9HMF48U7C6-R=W*Q8V%B
M8&*#8N1BPV(<8R9CKV/^8R)D$F3M9!-G&&=8@=&!SYC4F->8EFF8<-QP^G`,
M<1QQRW$?<MUPG65&8A=@QV#38+!@V6`483]L9VR$;)IL;6RH;,9LM6Q);3AM
M$6TZ;2AM4&TT;55M86VB;65M6VUD;;1MFFY<;G)NH&Z';HYNR6[#;C=OV&[J
M;E9O=6]?;[1OO&\4<`UP#'`\<$-Y1WE*>5!Y<GF8>:!YI'G\=_MW(G@@>$%X
M6GAU>+9XX7@S>5^*^W8;=RQWAG>K=ZUW9'5O=8-I?7_==N9V['8A=?YY1'I_
M=IYV)YXNGC">-)Y-GE*>4YY4GE:>69YAGF*>99YOGG2>HG4$=@AV'7;1>H5Z
MCGJC>KAZOGK>=S"`BYB.F)F8HYB#A@6'6(?/A^*'"XC4@$U_2GM.>W][DWOO
M>PE\\'L5?`-\('PZ@H:(JHC`B,B()HEVB9%_@X*\@J>"$X/^@@"#78-%@T2#
M'8.F@YF#_H,:A/R#*80YA*B$SX2?A,*$]X1PA;.%HH78EKB%X(7:?ZY^M'Z\
M?M9^"G]#6VJ-15)HC&Z,;8P6CB:.)XY0CIB0H)"]D,B0PY#:D/^0&I$,D2"1
M0I&UC^20AHSQB;&+NXO'B^J+"8P>C`*7T&@&<X&?@I_&DI&4````````````
M``````````````"Q'ZP#L!]P'Q,!Z0`;`>@`*P'M`-`![`!-`?,`T@'R`&L!
M^@#4`?D`U@'8`=H!W`'\`.H`L0,_'D0!2`'Y`4?__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]_[Y3N$X^3QY0QU`8D9ALW&S#;%UNIF[K;J5O
M96&D7AB62%A3A/5\!U^48GUD6G)T5:150%:$5A]=R7*,F=Y9_5E>6KM^Y'[Y
M?IF:SW%%8DIB?'F:<RMTB'2J=-AT9V>U:LIQHVN`CY*/7XTVFZARHX=2@3AK
MT)B7B*^(58D*=]J46I5@E22>0)Y0GEV>8)X.AUQ[V7_O?T1^18XVCF*.7(YX
MET:;*Y]!GR9U)DZLBRF!D5#-4+E2U(E75<>4EI28E,^4TY34E.:4,Y4<E2"5
M)Y4]E4.5;I5TE8"<A)R*G).<EIR7G)B<F9R_G,"<P9S2G-N<X)SCG'"7>I>A
MEZZ7J)=DF6:9>)EYF7N9?IF"F8.9CID0FQB;HF6`GAR1D9X2G_-2EFQ$;1MN
M9VZ";^QOKF#(7OJ/?U>&59Z$8(0%7`M>$5T97=9=LUFN6I2:CV6><%%U_W$=
M:1%JOV@'9HYF<V8E;%)VBW?J=I68@(<MB(=[4'RMCG65PF604[AY%4\A3SM/
MHD^D4))0"E/#4:A1((V'5YI7E5?K5UU86EAQ6)58,%P,7PU?#E]R7,=<K%]H
M7U]?$EIE6H1:Q%J4<^IS[G,W=!5T5'299VQH^&C^:>)R9V92C<.)S8DG9'=D
M'6P_@51KUIAZ</%P('%388=LK6V!;K5NE&^;;SUY3GD&>%EXE'C<>`-Y%GI>
M>N!UW'IV=I*8\GLP?%U\G9RL?'B"T8/JA,!_'G\ACE..5)<,G_N4_?_]_\`R
MP3+",L,RQ#+%,L8RQS+(,LDRRC++,N`SX3/B,^,SY#/E,^8SYS/H,^DSZC/K
M,^PS[3/N,^\S\#/Q,_(S\S/T,_4S]C/W,_@S^3/Z,_LS_#/],_XS6#-9,UHS
M6S-<,UTS7C-?,V`S83-B,V,S9#-E,V8S9S-H,VDS:C-K,VPS;3-N,V\S<#,W
M,*B07I9"6`-8/FPI;>=N-(7&A#QC!5T0?^Q^AW(N<1B"%H)L=?-U)9N`B:9\
MA4YP5<:1``````````````````````````!H(6PA)R%C(4`A02$D*"(H*"@F
M*#HH+"@J*#`H+BA"(30H,B@Y*"$H)2@G*"DH+2@Q*",H*R@O*#,H-2@V*#<H
M."@F(24A(28B)B,F)"8E)B8F)R8H)BDF*B8K)BPF+28N)B\F,"8Q)C(F,R8T
M)C4F-B8W)C@F029")D,F1"9%)D8F1R9()DDF2B9+)DPF329.)D\F4"91)E(F
M4R94)E4F5B97)E@F)R<A)R(G(R<D)R4G)B<H)RDG*B<K)RPG+2<N)R\G,"<Q
M)S(G,R<T)S4G-B<W)S@G.2<Z)SLG/"<])SXG/R=`)T$G42=2)U,G5"=5)U8G
M6"=9)UHG6R=<)UTG7B=?)V`G82=B)V,G9"=E)V8G9R=H)VDG:B=K)VPG;2=N
M)V\G<"=Q)U<G*B$L(2XA+R$P(3$A+2%K(60A92%Y(68A;2%Q(G(B<R)T(G4B
M=B)W(G@B>2)Z(GLB?")[(7PA>B%](4HA1R%&(4PA6"%>(4\A3B%$(44A22%(
M(5(A4R%@(5\A0R%+(5<A5B%5(5DA5"%<(5TA6B%;(5$A32%0(5DB6B);(EPB
M72)>(E\B8")A(F(B12)&(D<B2"))(DHB2R),(DTB3B)/(E`B42)2(E,B5")5
M(E8B5R)8(C$B,B(S(C0B-2(V(C<B."(Y(CHB.R(\(CTB/B(_(D`B02)"(D,B
M1"(D*24I)BDG*2@I*2DJ*2LI+"DM*2XI+RDP*3$I,BDS*30I-2DV*3<I."DY
M*3HI.RD\*3TI/BD_*4`I02E"*4,I1"E%*48I1RE(*4DI2BE+*4PI32E.*4\I
M4"E1*5(I4RE4*54I5BE7*5@I62E:*5LI7"E=*5XI7RE@*6$I8BEC*60I92EF
M*6<I:"EI*6HI:REL*6TI;BEO*78A=2%X(7<A="%S(7`A<B%Q(6\A;B%B(6$A
M(2$B(2,A*"$I(30A-2$V(3<A."$Y(3HA.R$^(3\A?B$R(3,A/"$](2$D(B0C
M)"0D)20F)"<D*"0I)"HD*R0L)"TD+B0O)#`D,20R)#,D-"0U)#8D-R0X)#DD
M.B0[)#PD/20^)#\D0"1!)$(D0R1$)$4D1B1')$@D221*)$LD3"1-)$XD3R10
M)%$D4B13)%0D5216)%<D6"19)%HD6R1<)%TD7B1?)&`D821B)&,D9"1E)&8D
M9R1H)&DD:B1K)&PD;21N)&\D<"1Q)'(D<R0A)2(E(R4D)24E)B4G)2@E*24J
M)2LE+"4M)2XE+R4P)3$E,B4S)30E-24V)3<E."4Y)3HE.R4\)3TE/B4_)4`E
M025")4,E1"5%)48E1R5()4DE2B5+)4PE325.)4\E4"51)5(E4R54)54E5B57
M)5@E625:)5LE7"5=)5XE7R5@)6$E8B5C)60E925F)6<E:"5I)6HE:R5L)6TE
M;B5O)7`E<25R)7,E="5U)78E)"%%*$8H1RA(*$DH2BA+*$PH32A.*$\H4"A1
M*%(H4RA4*%4H5BA7*%@H62A:*%LH7"A=*%XH7RA@*&$H8BAC*&0H92AF*&<H
M:"AI*&4B9B)G(F@B:2)J(FLB;")M(FXB.U(A-E]&<DU)57U(3TE"3R)8.S)K
M4R18<S,H5U)')UA`2G!'>S$U4E0T*S8_2RE8*C8]04]1)4DM6'8X/E%<8U!6
M83<N-%E!/%AH320U*DYW5G9`63XO6$M$0SXQ6#1#95(N5EI.)U5U.B8W5D`Y
M1E)%1T=4.4LS4E(_6$4^<D8R4C!/9T]I2D!8<D)20FE(+$=+06A3>55"2GXV
M(5A:4W<_1E0E.T%894XN/BA81U$I4#U8;UEV33H_.STE.F!2>C)@.C9$;4\I
M/B1-04%71W%9=%E+2&E86E(R2DI(;%AJ6$98=CU-1G`S:UAQ/6D]5$A3-%A"
M5C)05TM*>TM,538X24]:67!8*D=N6'HT;D%44FU81U)O6$=#=E%95G)8=5A^
M/%L\3DA=-T(W<T9X6$%2:4X_/'PW)3==4%I615-O.V$[<5@A23!.*S1S6$M)
M=EA70G=8,4YY6"XR0#DC66DP9D%L245+1DLD66@U*S4[3DTU(5=T5U-394Q.
M.B)97%E@4WU8<#=W5WY8>E@A66-$-E-T6%U9>UAE15!`<%%;,%$\)EDE62Q9
M+EDK63E**5DV5EXS*%E]0$Q**EDG63!9,38I.4!20$]"0D0];%5@,DA':S\M
M62]9:DYN.E9'8S%9-&TV-%DA/UY93D=^0#A95TM]-S59-UDC,6%3.5E%4#99
M,5DR62E!,UES/%Y0*3AC/CU9.EDS,$)91%DV,3]9.35S/DA,<CI04D-9:#TK
M,T59:SY&63M97T0^64%90%DN53568T=(65D\2ED\64M9*T9)6797(TTA/4Q9
M/$4U34U91UDE,WX_-3A\0'@P=C1.64]9(C1065\T03!1635)<4]2645!5EDN
M25595%E765M+*3TG1E-96%E9665(7$!Y-B-82E0J5%909#-754A/8CE+/V)#
M4C9#36Y9<%DS-34V)#YK2"M(2S`K.7E!8ED\0#(Y6#E+4'@Q9$9?/F0U2%=X
M468\7DH]/&999UA:1%0X/4AA,EE4,$-A0R):7T@T4'P^*45:.2-:*50D6GM9
M+#9K-WDQ?%EE,W8^=C\Q4F1`,S9^67U9.SY@1CQ7(5HY07(U:$%U/%4T74%]
M1#@\,C=O-VQ9/D8M/TL[2C5)6U=0.4T\,'8S=SM*6R\Z9%0V-7,U5EA02%8W
M4$=76"\_.UM86$Q0+CL^:U!!=4%R5%4X-#1U,SY)4$5917M`<#%96$XY/35:
M6$96(DLO2#))3#1,/W0Y6UA<6&<V03QJ3'=/75@P1U`Y(SU>3$I&8%A>6%]8
M?C!G/B-*=#PQ.&XX8EA+/6188UA\16589E@F03!(;#`F.5,\<4X]6U-!+S9Z
M5BQ%63T^6S];>$`B/DU`0%M&2BHR0E-C0RM10EM50$-;,3\\1%I'1%MH65=)
M-#EP3DA4?#!2-%E0:5E+7FM9,%@O.S$Q5S-.6%%4,SUO/SM/4%A+-U%8)49X
M1SU24EAD1"Y*)T<F6'U)9TY<.VLP*CLM4#`Q9%<_5R4U=$)/1"DR-S)E,3)?
M/%4H/RQ"55@Q0E185$Y@6D!.-%@N0R%3(TXT/#1(44)M/C9085ID1R<S<C9\
M3'I`=T`Y46%11UA>,F5`<3I(6"U484])6$I80T]X,T<^2UA,6R5(6$]^2$XR
M5E-F,C`\45,K2S0W(C=E2B%(7$ID,7!0445%6WXU6C]%.60^;4$V7S5?.U90
M/5E52#`C-DD_*$PS7S=*4E-/6#9213H^2SY,-U]P-31?=5-4,W<X.E]/.BH\
M=34L37M#<SIT0$)-<D\X7T5/0$(Y7W!"?3Y?04Q-=U)--T%?1%]Q-TDP5C94
M-RPZ?4Q4/S%+=$8H5D5?8DXS,WQ.-31'3G`Z84X]44!?=#1*,V8X.U]%1#Q?
M/5\^7SM%/U]"7S%40U\Z1UA.6$1*7T]?7%9)7UI?-DY'.DY?2%]>16M)=#I\
M0U<^1E]-7UA%)E5-.DP^/5-`.&161U\^.2<_?$%+7TQ?4%];7V5?5U]67TE7
M8U]D7VME)U)27RD_6U1(/U1?3$]=7TI17E\G,#=&4U]E.E\V6TU^.5547U]L
M3R4P9U]17T9155]87UE?7%\I.V!?85]B7V9?:%\T4V<X-D5J7UI)*$%$1%X_
M>$]<56Y?.#)?.FQ?05MD471+/30F,'%?1DQR7VU?:5]K7V]?<%\].W-?=%\C
M.UM**$XG8"HS)F`A8'Y?64U\7WI?4#]$5TQ)>%\A,'U?>U\B8"A@2#<A1C9)
M,D!U7SY%1%AY7W9$(V`D8"5@)5`T8&1,,6`F/R]@.4XK8$9)+D`N8&TZ,#HI
M8'9?,V`X8"TT.6`R3T@Z,&!Z4"Q@>U1W7V=%+6!W4S9@-V!$8&%0/&!)8$I@
M/F`J8"1)06`R8$A*0V`U8$M.0TM-8$9@0F!+8#I@/V!`8$5@1V!(8$Q@.V!4
M2U5@5F!28%!@3CQ18$(X15AJ4&]"3V`]8%1@4V!78%Q@6&!V5C`S;%<[2UI@
M>TY9.F%@76`M4F)@6V!98%]@8&!>8&1@=T8L6&M49F!)2F5@03AG8&A@:6!C
M8#\Z9TQJ8'E/:V!"2$`]4D1L8&U@=$=$2VY@6#LV6')2;V!%35HV<6`P5"=`
M430G3G!@<F!,.7HY/$US8%1&=&`R5"9(=F!U8'=@04TE2EI45UM96UA;9SE<
M6UU;6#5:6UM;(3-?6W@[-U9@6WD^.S=06RY,,C\U.WA74S]I/V$\,TQ>6U,P
M:TY8-SE70D8D0#E,9UMA6SI&8UMH6W=%:EMI6T`_9EME6SDT+$`B0F);9%M-
M4&U;74!R6V(V<UM26S@Y*U1L6U$_<%M16V8U:UME/VY;<5MY6R$Y(S!Q0D<S
M;UMX6U)&=%MU6W=;=EM^6W)3.C)]6R1<>UMZ6WQ;8$5Y.R-<)5Q#3%$V0%TA
M7")<-4=I-B=<)EPI7"0Q3#4P/U]10C8H7'I+<VM<2WY+04Q[2"I<;DPK7%-;
M+UPL7#,^>THM7$I).40]1RY<=E1F4"M$53946UHQ55M66SXZ0$@_2DE(,U=Y
M24<_>#H\4CIB)C0X,30X1$]G629/8DUM66`V.5([.3EB-V)S-&Q,*TQR-S)8
M:U$[.B=*-TU$4F0_4#QA-D5>1EX\6UE19D9.1&XW7#=\/V!7=48\,4A>,3U7
M3$I>25YL-5U)0C`N12M%3$1I/'U+0SIY96=(>F5]33%7/CAH0E%(>V5*-DL\
M?5$A9FY#)&9^925F5TU!-WQE?64C9EU$*&8G9D-#7D8J9C=$(F8\2F,]0SDF
M9E50+TXI9C!F)E(J/2UF+V910$Q2)SPQ9G922U=^35Y-)D(K9BQF/STN9C-F
M,F8V9CAF;T1(1&H^;TDW9G`V9$-I4S1F-68B2#UF.69%1G%-.V8\9FD[/F8Z
M9C=`)%,_9G1)0V9$9G90/4-$0T)F069'9C%/=&M*9D5F7CPI234\4T](9DEF
M3F909E%F2V95-4QF3V9;1$9F36929E1F4V959GA95F979E-7769>9E<_4%16
M5V8T;TM:9D-83E<B4$]#7V8^/$(Y6V8G42(Z3T(K6&M*;F5<9G4W9DAU1#)E
M?D1\2S-E+%5N4UA*,C!.2VI-:CHU931E6E=9.696*#9P34M2)C$U2F@S<TE-
M/WM04DHV94([7$\L.5=4)CIG47Q/4CPW95U(;3]V,5Y+13Q$/'I27$-</SLX
M0D,N.B)47D<O1&PR43D[94A!+U4\93YE9S14-D)+,%$\-5E*8C=D22L]/DYP
M5R%064E[-EAF8CP^,U!)668B,TQ>2%--7B)23EY-/D]>+$I\4E\S:F5A1"$^
M,DYR1%8^*$9C,E,^?$=K3&P]74XZ2D%&;&4\4#E5;65T2D!-14)O941"<&5X
M94U-/4E94BAA;%-J2W%&+&$G82EA*F$O86TR*V%:."UA+F$P83HU,6$S83AA
M4E$V835A:T$W84!4,F$Z838P-&%Y/SEA.V$^83QA158_3SUA/V%-0FLV>%--
M1V4W?CY`84%A1V%G,VE&7C1"44AA1F%%84-A0F%`,3A51&%+84QA2F%Z;U-A
M4F$V1TEA3F%0851A46%-84]A56%685=A6&%:85MA(4Y=9R@T758R43(S)#ES
M5TE'7CXN.5=.;C)/6SH\45)(2TTP;T]C66T]4C%02CPR)TLK-R9*(T]X8$I5
M>V!Z8$%%>TPQ07E@8U8O,D166S5X-"%6+T]O,'Q@(6$C,WU@?F`Q0UU#(F%Y
M-T\[(V$[1"1A)6$F83$T23@]1FI$(C)24%MG0SM74T138SE/8B]7;$=3,3(T
M46)R4"Y"4&)B/R935S528FHU;4-]."XX4T5/-U1B4V)(-GE7)4U88E9B?$HU
M/SE356)78BY!2$!;8EIB*D!.05QB76)>8DA;4U$B32@]0UXE6"H_35ML4GI&
M*D5$7E<Q+E\]2C%?+3E]4B4X:SI:,UPU15560U)/(3MS97)E=&5D375(+S4_
M1W9E,&QF96DY,34\0FAE9V5I94U2:F%.4"Y-95%*,FLQ<C%M14-5,%-<85UA
M6U(Y,TLQ>4UW55YA-CY]-%]A7#I@83([24)A86Q0/4UB84,U1T5C861A>5-E
M82U19F$B3F=A0C5H854[1%!@8E@Q9%)A8DD\3$AC8GYL?6PO7V)B/E9\329#
M0V-25F=B:&)'4VQB;#]M8F5B0#-N1&YB0U!V.FEB7C<S.RQ,2TMD8F9B:F)K
M8G=B=&)U5'-B+45Z54)%0#)O8G)B+T$\2R$U>6(Q/'%B5%`Y5'5B5CEV8E-'
M<&)<5R%M>&(E;7YB44HU05`[5C]C.B%+)FTC;2)M5CLG;710)&U>.G<V(6,R
M-G%,)SDB3R%'4C]Q-GIB>V)]8GQB540B8T%3)V-$1R1/*6,W.BAC6CLC8R1C
M*F,F8W).1E,\.T-4>D0H;7Q0)6-U0RUC+S$R8T(\+&,_-6E',&,J/F]-<SMH
M3"]C,6,G3RYC*4Y=.VLU93Y2,DTS.3$K8U$R+#5?.6@V:T\W8TP[1TA*4#AC
M;C,I;7I39%,J;3EC8E(U8UY34#@S8S9C7S<T8R)`.F,X5$@T.V-%.W=)94D]
M1"MM?4);.RX_/TX\8S8_;S%W5#YC+6T_8RDZ+&T]8T!C-CHN-CA00S`N;2]M
M04!!8S-%0F,R7#!M:CAL3B=J9U!Y2E9(-T]),U).9#U>8W([*&H]55U&*6HJ
M:BQJ*VHN:BUJ6#TO:CY"031W-"<[9FQE;#\W>4MB,6=L2$EH;&EL5DI07D4R
M>E1+1D<P<C132%!-.#];/R1'-%8I0%%>*$EO421%9S`V,T5(8C!V-WI%<S92
M55`S/#PM,W$^43!64F-*)5<V338V.3];52<X5T527ED_54)`1R0[*#%J17M%
M)TPG,58U*$137CI1:3-R0W<W=%8C-7`R-$1I1"U`5%YH,$1%8$%5.5P^6$U.
M,$]-5EY0/CY755Y055TP8D0C0G`\-5,Y0"%%)C)Q5"A`0TI77GQ5,#DM2"E+
M65X]/S1&)U<P2D-$5C-2.3A6?&HT,&8_=$Q:33]63D).3B),+E!31#(U6%YU
M53<\4SLD,#)%;#1Q57UJ6EXF36Q-9DY<7C%-)D`]5UM>1C`T.E-)<T1H/C8R
M3$!P2W$\.SLW-75%9EYC7ET^7UXW-%T]8%YM1$9/8#5>-EI*=#5E7D9585Y-
M3'Y&144T4G(^4T(]3#@S4SU8/T9-6E%K-&1>75YG7GYJ,$)B7D!6)S5T,FA>
M<EYM7G%>8$AA5V]>:$-A3&4R/E)N7FM>54XG-"L_/CY2/6E>+E1>7FI>/T!L
M7G,R:3@G0D$]=5YX7BLR)#1J-"9)=EY12V,X=UYZ7GE>0DQA,&XT.F4O4&LR
M(6MT7F-)<UY:,"%2=S$O3'!>)$LJ57M>730F1'U>?D,A1"%?3$%\7F\^,D9%
M,W9(.DM^7B1?,E<W,T-!2T<E,FDT*U=L1")?(U\E7S,Z)E]>0$-)63)F1R=?
M7$<H7R)K4TLJ7RE?03)*12M?7%1!2"Q?<#XM7R=6-VHV:U5*?%A$."4Y13=^
M54HY)U!-=%`U=$-(/C=K/3!,/3)!5C$H,U(X(DE8-CAK-#Y]2D-'>U5S-T1.
M*U5S,3-L7S`U;#<V3T%Z=3%095533F\]8C,K.#95/6U/-CE+0E`]-S9L*4I4
M13EL.&Q#0C=L?5`Z;#ML95<\;#UL;$9>3D@\54@I-4D^/%9G5"Y1<5`X:CEJ
M.FHU.C%*=3]Z34!J.C`^:B5`.VI],G=#:#M74G1./VH\:D-J1U`S4SHT04-R
M5U%51TI%:D1J1VI&:F=65$]+:DX[>CU.24QJ.4E^3TIJ3E1-:D]J;4U):DYJ
M;DY>.S\S548P/GI.9T<G/E!J1U9`05U446H^3U)J;DHO134P5&I3:E]T.D0I
M,5]E56IO2E9J5VI81EAJ66H[5'I'-U)\.$)J7#)\0GA49DQN5T)44%-#:W-%
M?C=4:S=+7FM*0'M-+S-:1GQK/D0T3BE$/C%]5'5*;%931F0V>CM@4#%)4U0H
M2$LX/F@\23MH;D!34$0R930\:$A5138]:'A*7#AU3#1`;E$_:$)H/#HM,5P]
M/6I#:$9H2VA,:$E+93`K/#DY06AW34IH=DYM559!1&@V0WLY)E9(:&!*9E1`
M:$5H1V@Y1V,W26A=/U)H5VA5:%P\3SQ;:%YH6FAZ,5@P,T1,.&)&/DAA2$]H
M5&A6:'$Y6&AU5WM$7&AI,E%H;3Q"/TUH>59X07$R7VA!2EEH)%5J,3M53FA0
M:#`V4VA=:#A`=THH2UQ&=4!I:"-0<FAJ5F!H86AY44LZ>3AQ.%14;VAN:&QH
M<#E23&9H)DYR/S@P<6AP:$!79&@I32-).#M;/6IH8FAC:&5H-35G:$5':VAM
M:#`]+E=X:'5H,$UV:#I!:&@W0W`P=&AW:",Y4DE.0V!.9D!S2UU,-5!A2G-H
M;#QY:%Y#949W.70P6%<L/&]%1$PF:2U)(FEB0$,_?FA7.7MH)&E.4B-I,E8U
M5R=I-SU\:'UH(6E632Q2,FDI:2HT.S0K:2A0)6E^,RQI8T`J:3EI.&DN:7IH
M*&DL/S%I.FDE0B]I13@M:5Q3-&DU:3=I1VE&0$5I,&D[:7$P/&DE53YI/VE!
M:7%!-D@]:4)I0VDS:39I,3M`:7<\1&E&:4II3FE;,DAI+C=+:4QI054C1%AI
M83I):2-35&E7:5!I3VE!1U)I66E(,U-I<$]-:7<S5FE::31,+4]5:5QI6VE>
M:5%I76E?:4I#-T=.-#8[0%`C;#=%>U,D;"5L6T9N/R9L)VPJ4#A':#@H;#E6
M?55+-#TR9$YG1F%-=31`2U\\8FEC:6I196EY-&1I,U%B2E`R:&EF:6=I,U9I
M:6II:VEL:2]L.45.-G-2;C59.S%L8U)C3CA$/T,^-CE82#%/,5$Q?D50,2M#
M,54D:T$Z.DPE:R=K*&LF:REK*VLJ:RQK3THU6'%#)4-X1BUK2D0N:R]K,&M5
M-WHW,6MB1S-K)#IU43$P,FLT:RHU2$)H1S5K+DM?8T!36UDA32U6<T=@66,[
M.CIB8RM/8&-'23DZ-%%A8VI(+SDM/5@S6TY`3&AC:6-T32U,,SQJ8VMC6E![
M1EHW7T=*4E9.9&-L8W))03-G8V-&96,S;69C,TEF134Y.T-C8SU%)$%90E<R
M;6,F.RU$<&-:/GMC=6-3.E`W35-.5E-503DT55A1.5!V1RI(-#):0VYC?&-O
M8R@W=V-T8SHW(D5V8UU%*#)\1F!$(E=A0'EC>F-]8RE,<V,^4T,Q-&UQ8W)C
M>&,Z4$-&<U1^8V`])V0F9'-1(V0I9'=(-$\H9"YD94(T-G(](F1I.BID+&1]
M-EY6,F0M9"%D;CM=32)'245W021D,T<L/3T])61'5V(R*V1#/"]D:SLP9"A%
M,61C52,_.F0W9#MD/6161D8Z2T`A.#1D(50C.GX]/&0_37E$>T]F23]344\S
M9#AD.61I3$Y,5$`U9#!!-F103D$[4S5S2"<]1U4L22(X2F1,9$11.E(M.E0Z
M0V1M-4U70&1]3S]D7$%*3&=*5T143$AD1V1!9$1D+3594T9D>5)C-#0[;DD^
M-&P[35%M3#5M94<H5$MD55="9"4]161F4TED>$D^9&53?D=)-GQ4,S)79$).
M360\3ELX5F1*/TY3;$-(15AD1$U/9%1D561^.F9//U529%!D3F1E32I*(T`F
M/5-D2#AG9#146V1O06ED9U)?9&!D*D]=2UID461E9%Q(8V1G1&)D861\,VAD
M835,5V9D+#M25T],>&MD9'8Y35999%QD>D)>9$M"1$!00G4Q,DQ.-6]D+T9A
M1G5D*4)L0%U1;F0N1&UD=F1T9'Y"761P9'Y*1%5Q9'I1:V1L9')D*TY+13%'
M.D)J9$I!-DPQ,WMD<V1Z9'UD?&1.,SHS=V1Y9'AD;$4]0&A4(F5$,"1E(V4D
M/"5E(65^9'0Q*&4I929E)V4J95E&*V4M92QE+V4N96`Y,&4Q97`[86QP0T8U
M4CMI06Y41#Y&5U944S(^;$%J+T(V-%=1-#,R2#L_0&Q+5C]L06Q%;&8^/TQ:
M13P^1FQ^,41L*%5C-4)L-D%C,T-L.$M#0'Y,4D%(;&8Z4T!R5DQ1/C\S-U5)
M1VQB.TQ,?3U(2"E/:4UK16DW25$X.DEL2FQ`.TML8FPZ,5DW.3U,;&9136P[
M2%%L4VQ-.V4\3VPW23I#8VQ555!L<U92;$YL5&Q5;#])*$]<4"Q16TA6;'5.
M;$I:;%EL/C!7;%AL9&P\2$=!7&Q@45ML;U1=;$9;7FPL,5]L8&PF5T!%/&LN
M,'0^.#@O4E8P>34S6"Q+76,L1F8P1D4Y:SIK.VM`42-%<FHR1#5$3D!S:D%$
M;TYP:G1J?$DC1UA,?DYU:G9J+$]G0'=J/S9X:GEJ>FI[:G%J+DAK83@W;&%M
M8317;F%O84Q3<6%Q/W!A4C4W,7-A<F%\.G1A-SE1/GQ$73I&/75A=V%`-D%/
M*$IV87A5?%-X87QA>6%Z86I`?F$A8D=`>V%]825B5$$C8BAB?C(B8DU#0C(G
M8B9B)&(I8BMB25!M5BA#+&)73RYB;SI@:2UB*F(K.S-4,&(O8F%I,6(R8C-B
M(4PT8C5B?E!*0G%3=4U@9V%G03YJ0F1G8V=F335#8F<W.U9/84%I9VAG=&<C
M,FIG9F=L9VMG.DED565G*3=G9VYG<V=I5FUG<F=Q9V`P=6=R1T5`;4!P07!G
M=F=V2R)H(6A!5WIG>6=[9W=G?F=]9WQG54%91WU%0T5M1R-H)F@E:"=H=SIX
M9R1H<$@J22EH93E^42AH*F@M:"YH)T$O:#!H+&@T:"MH,6@U:#)H,V@W:#9H
M3SDL<"UP,$9J,#](7TU-3C%J,FH_1DDT,VIG57E=-&HU:C9J2C@P7W5)<$QZ
M27M)0U,F2R8X+G!",3AE;TQ)4U<\:DEG-5!$:34N;BT[7F<O;BDS,FXQ;F<]
M,&XW3D]%=$%.6S-N<U!40FA&+#<T;FLS>SLU;EQG-FXN/6)Q:$I)4EIP6W!<
M<$9!;3A./EYP,45=<'%18'!,,&H]7U)?<"\T:#=F<&5P(T9A<&)P0S1C<&Y5
M6TQ2/C(\:'!G<&1P(3(B5CA3-SXL2&IP=U%,5ELZ:7`[-C1-)D8A06MP;G!M
M<'!P;'`^.V]P-4QR<%4S5#%S<'1P=G!A-'%P=W!Z<'AP=7!]<'EP?'!^<"%Q
M04XD<2-Q=D%[<%U*<31Q,3%,)G$G<2QQ3E4I<3-((G$K<2AQ)7$J<2DP+7$O
M<3%Q,'$N<2)1,G$S<6\Y1S57,%DP;51$-50]2CLG<%XX*'`H,"EP;DTJ<"MP
M)$9E5F1Q97%S0UM3459H12]39E)!;CLP-55.46`\4#IX/T<X035,12)*2T-"
M;C]$(C9L;21#,59@3V]M3D5<-B%*;6UP;7%M/$,T/VYM=&UR;6957T-S;79M
M(U4C475M4$-W;70_;#YX;7=,6U%%5W95?&U[;7EM>FU];28^+TLA;CTV(FY`
M1'YM7CU',D,V)6XZ6"-N)FYI0W(S)VXD;CE/*&YW0BEN*FXK7C-&1D=U5DDU
M,DLK;BM-+&XP52UN1'9'6R,T+$-F<3A*4U(J5G)O6#Y#/7-O3#8K,"]*-FTW
M;7E.+S=S/SAM:T(P23EM=D8S/SQM>$5042E7.FT[;6)1/VU`;41M2&U&;4YM
M:%5);4=M/FUI149&:4E25$%M0FU#;45M>4`A-&@Y4&U1;4IM3VUX3C9+3&U-
M;75/4FUR03)32VTW2&\\<$56;6\U-4(M,&E++C%4;6M-8C55;5-M5VUZ-5AM
M66U<;4PQ=D5N/%IM/$QJ,EMM:T1%-'4P7VU:0&@T345=;40_7FTE1&!M86UC
M;5=!1SLX/6)M9&UF;65M9VT^2FIL<4!G26ML;D9L;&U&;6QP;&97<VQQ;&YL
M;VPC5W%);DMT;')L:4]V;#%&0#QU;#LU=CMW;'=9>ST[0GAL>6PC.'IL>VQ\
M;&U3+EAK0%U'3#IC4#U+.DU1.'PQ;T=65D8_:T-U;UA#8E=W;U,S6$=M44A6
M>&]V;WT[1C-5/4928#LA3WQO>V]Y;TPS5$DP2WYO7C!)5GUO;3-5=DA.(G`A
M<#XU6CQ\.V4X0D0C<&M+)G`H43\^;D<V<3=Q53\I-#AQ.TU41RU5.7$Z<4]'
M)%)/5CMQ43TP-#T^7#113E\_/7%Z/SQQ/W$^<4!Q07%^02)!>DH^53H^.3Y"
M52(_+TTU<5\]2S9Q5D-S1'--.$9S1W-*,$5S27-Q2TMS)E!*,4AS3W-1-5=S
M4G-4<U-S>S<_,4YS2G-:-5!S47-5<TUS8SQ]059S6G-,<T@U;CU<<R0W<#]^
M5C)-<#1?,EAS67,X25US7G-A<U]S8W-B<UMS:C]O,V!S*4=R/&MS/SED<RTR
M?CMC2VUS:7-<.6YS97-F<VIS84)L<V]S:'-]/&1/<'-G<W)S+5<J1G-S<7,H
M0ETX=7-T<ULT=G-W<WAS.D!I0'%%>W-Z<U@T?G-Y<WQS?7,A="-T23LB="1T
M/C(F="5T+CQ70V%98$!,=%%76S=.="-!2496-#-54'1/=%%T6DM2=$%48%9@
M-SA!.T%3="P^8C14=%5T*SY6=%MT5W1:='TZ6'19=&(X1TQ<=%HR4T-C5#<_
M770T16ET-4])3EA+=TMT/4]76T!U4&IT:W1L=&-W,3=M=&M7;G1Y9D`^>F9L
M.GMF2T]\9CQ4-CQ]9GYF33Q22#-.(6<_-")G-$E9.$E$75=:0E<W/59&3D0W
M)D4C9U]/)&<E9R9G-T%I5W!).$\O5E56)V=M,"AG*6=<26]2+3XJ9W,P7DAA
M/2MG1D@L9V8[>#@D42UG9T)X/DH],TTN9R]G;CYE4&=+4$Q,/#!G*#QW4#%G
M>%`R9S-G0C0T9S5G?DDL3F!#-V=!,7$S.&<Y9UM70%4Z9TQ".E<[9SQG/6=J
M/&5#0D`^9S]G*3Q`9T%G-F=0-D)G0V=$9SH[7C5&0F`Q16<U5$9G/SA(9T=G
M;#=)9W@R2F=+9TQG36=.9T]G4&<G4W5+46=29U-G5&=)255G5F=79UAG66=)
M/5IG/G-7.#%(/W-`<T%S7CEX36A8,3I>0C=N(S<Y;CAN53`[;E95;U=#5CUN
M<$H\;CYN0&X_;G)1/$=`0V$X9T%&=%]01W1;3SI(2'1)=$IT2W1Z67XX<65P
M4V!T3$YA,S1Q;E)A=&A/8G1,1U0U9#1D=&-T971F=&=T,CH_,&AT+3=M4BM2
M3T`\/R-K7U5(:G-Q>#8C2TU$9W%H<7LX:7%$.D544C!J<6MQ;'%M<6YQ;W%Q
M<7!Q545R<7HV='$N4D=>2DM<,R(U(CET1'5Q=G%$07M!,%9W<7AQ*D$X1EL^
M>7%/-'IQ,FTQ;6!+7E)!2UA58DA?0"$\06LD4&)61S98.$!K3C@_:R8S23DK
M5G0W2C=G/#XW1FM':SDP3S]%:WU32&M):TXW0FM$:W9)5U9-53)03VLX3E!K
M*#4S,5)K)4Q615-K46M?14YK)$I5:WLP>CHW6&-Q2FM+:TQK36M6:T!F66MH
M/TA25VM<:VPX6&LZ/5A0-S!=:UQ$+%9@-'9".3Q::UMK8%1J1E1$7VLG1759
M,3)D:T4]8FMC:RPX44UE:V%K,T$B1G-,9FLP0#A29VLO."TX:&L[1W--:FMK
M:VUK2%!R:VYK<6MY2'Q1;&MI:SDX64]E1&]K<&M:3$A-<C!V:W5K,C)@.'=K
M;#%%3"1$)4]Y:R)L<D5Z:T5)7V)^:TY-(6Q;,3=37%)]:WMK/#,P:E17*W1T
M,T%60E9I54H^)W0H4BAT*70J=$L^7U-@26%)0G-F2G),-F(T2VA.6U8M="YT
M+W0R=#TZ,W1C,#!T,70B/54R-G0W=&8V,#)/3S1T+#0U=#AT.70G33IT.W0\
M=%)+/70^=#]T7G0\06@\*TE>475E,UQ54C1<+#`U7%H].5Q"6#=<<U-623I<
M-EP[7")#/%Q%7#U<7TXE5D]<35Q27&8]*T(X7$M<3EP^7%(W13!'7#Y005PH
M.SPW3%Q&7#]<6T<_44!<2EQ07"U.0EQ#7$A<25Q4,E%<54LW5%M<7UPF3&9<
M9T-<7$$_65QZ,#8Y95Q37$1<5EQT2&`_.TD],2)36EQ57#M&7EQ"5R]#-C=1
M1RE#8EQ87&M<5%Q=7"4^5UQ@7&-<9%QX7&%<(EUG7&L\1#0C0V<R>EQR7&]<
M?%QN7'!2:#)72&-(>UQM7'=<=5PC/G1<73)S7'8\:%Q$.W-`5#QI7&I<<5QV
M7'E<-#592&<[?EQ]7"M3(5TC725=<5(D729=)UTI4DDZ*5TV73%=-%TP74Y&
M<D`O26Q<+ETW77!<+UTX72Q=.5TS72U=*D0H73-`*T$J72M=,EUQ.S5=*%,Z
M73M=)T-273Q=45T].54^>CY*.DI=15T_74LR0UU+720R55T^75!&4%U476)!
M1C=.74]=1%T]74U=44Q)74)=2$,\1BY.3%U(74%=1EU<0BE3*E-3771/>$AF
M74==8%UD0F%=5UUX5EE=6%UP.%9=3T8M-F)=>3IA5&==4#1:77L_8UU?75U=
M635;75Q=7ETO/61=95UU74E#8DMR76%8449T7715<UUP76Q=;UUH76Y06$AN
M76E=:EUR2VU=33$V0#L\<5UW779=:UUN17M=)%XC7GA=;T-[0F%5-4Y]74PR
M:$1?2CY'>EU\77Y=(EXJ,$XQ+%XF7C8];T@A7B5>*5XH7B=>+5Y,5#->*EXN
M7EE`(3$V7C%>,EXF435>+UXP7CU0-%YM2CE>.%XW7CM>93U8,FI#.EXZ13Q>
M64PJ-V54/5X_7B)$05X^7D!>.E5"7BYR(CLR0C!%1T(O<FE075,]:V8S,'(Q
M<BU*9SHS<C5R-')D2SI/,G(T2D]2;$)#3CAR=C`W<CYR3S)!43IR/')I5#MR
M-G(_<CUR.7)'<D1R1G)*<D)R0')%<GM607)Y1U])2')&.3`U0W))<E!R5G)7
M.U5R7$UK5E)R5')R.$MR3G)Y0EU53')-<D]R4W)9<CQ3:C9Q2F0W5W)8<EIR
M77);<EQR45%1<DE-3TXI5F-R6T-@<B]`;')><F%R:')B<F=R9G)I<E]R9')J
M<BQ397)U,G)R*U!U<D@[>7)P<G9R>')Z<G-R<7)[.GLU;W)W<FUR;G)K<B9S
M(W,B<W1R6DA[<B5S>$-]<B=S*7,D<WQR*W,J<UU"+G,P<R%S,7,L<R]S?G(M
M<S)S-',H<S-S-7,W4#AS>5DY<S=S9$@V<SIS.W-`-$-N/',]<RI1+'1&4%!0
M7%%.3U8]0U%B.FEA0E)"<3DR;3%#<4!)1#-R625+1'%45D5Q0'1&<2Q41W%`
M,$%T0G1\-%M%.TQD4&!-2'%S63LQ+D\D.$IQ2W%#,E%!,%=)<4QQ3G%V66%2
M(U1#=#E(1'1-<4]Q8S]0<51Q5G%1<5%)845C0GPY4W%5<5,Y6W%6.GTP67%8
M<5)Q6G%7<6Q(2DU=<3UE7'%><5]Q94]%=',]8'%A<7=.*E)[<3(X>SQ;.68Y
M64-32FAJ0$!U/FEJ:FIK:FQJ;6IN:F]J1SU[=7UU?G5\=6(](78E-")V(W8R
M;%11:EDD=CIN,E5^4UQ,1$I`925V+SXI1B5:1CPI-CPX3T@E/"9:)UI63$-(
M*%I]1C51:5(V44<\,CUD.RE:*EI(42M:;5!O-EM"3TMM-VA)0S=W/B16+%HM
M6D!&9U<V2BE57TMO52Y:7U9*-#!:+UIK4C%:,EHS6E1*-%HK2C5:-EI/,V]6
M-UHP.RXU.%HY6FXY+U%H4CI:0SAJ3V\R.UH\6FL]7$YO4SU:<TX^6E5393L_
M6C5+4$M`6FM';E9!6C5%039"6DPW3C]#6D1:+4M%6G<U1EI"03M71UHX3&I2
M,41(6GTU43M)6C-02EI+6CU.3%I-6DY:=S)16D]::%%06E5#4EI36E1:55H[
M4"52>3!66BM'5UIW/2%#6%I96GU#-TQ:6EM:/D!71EQ:75HT1UY:7UI(.6T[
M.39X='ET8TTY=6!K<T\_.T`Z)519871U*C%R,G5U=W51.G9U,D-Y=7AU-#%J
M53HX,3E&,G!434]<,$M5=3M*5C<W,$PV1F$Q.CE\5F$Y(3=Z/%IJ6VIY3',Y
M7&I[-#-#43=8.EUJ=%1>:E8\7SM?:EY!.$)?5$I78&IA:F1J8FIC:EY),SA$
M-F5J:DI-24TT66)B169J-4`X5V=J+%=\2%-835A>5'E41$DN4U,X8#-B279T
M53IW=%]7<70P.%153SAP1D,S<G0L,SU4=T=T='-T2TPD2'5T8U<_14!U.W5#
M=4)U.E9!=3Y41'5,=4\P>#5)=4IU7$5%=49U1W5+=6`^2'5Z.%!U4W5G/W(Y
M/'5-=3=">$QY/$YU3W51=64V4G55=3UU5'4[4VPS)$Q6=5=U83Y8=5],6W5(
M,EE7675:=5QU8G5@=5]U775A=5YU9'5E=6-,/V4X-6-U:'4C3&9U9W4^=40Q
M/W5%-60R;'5I=5<V;75J=6MU6C1J5&YU>3-O=7%U<'5R=7-U;4DJ.7M'8S9)
M3"9J-3-^5&PY>5!M:2I7;FE60FU(9#IO:7!I<6EA5G)I<VEU:71I=FEW:6%'
M>&E85'EI3CUZ:7MI3SU\:2@X/D%]:3(Q5#MU.7YI(6HB:B-J>#<M/&1*3F`O
M5#U/-U4D:EY5)6I!4#PY1S19,3%`9C%G,6@Q/3-H2$%E7S%)06\T*$=84WE&
M.%%].75"+5-+5'P]0F4U-T-E.3MB57@]-E0E3BQ!63-V3$9E1&5(94IE1V5/
M-4A&?#5%979*26540T4Q(SPW5TM-34M*2E-,3&5+969$(5$W44UE4&4X37!6
M3V5=-3Y-464Z-BA-9#E%2E$S64ML5%)E:C=.955E?C1695-E5&5=4E]"1C%B
M4UTV;$M79793:3%T-EIE6&5994`U15)<95YE764R1R-26V5B5%I58&5Q5V%E
M7#%[46)E9&5C965E6%)+-5]G=5IX6G9:=UIZ6D]01T1N,#!0>5I*4RHZ(EMQ
M1WQ:>UI;27U:(5M>5WY:6D$E6W13)ULD6RA;/#U)0"-;)ELC5BE;+5LN6RQ;
M0CHD/RM;*EM'5#\R+UMY.3!;.S,F-3PV,5MU-C);23$T6S-;-5LW6S9;.%LY
M6SI;3U-Z='5'0U=D17QT?71[=$8^;U!3-TU4*DPB=2%U*#I^=%9+)'520&HS
M*DTE=2-U-#TH=2EU33TX0V$_84LJ=29U)W5P1"QU/#1M5U<T*W4N=2UU+W51
M4%%#*4@P=3%U,G4S=31U-74W=39U.'5),E1334IO0%A6,%(_07`]*CAX/$9V
M1W9(=DEV2G9,=DMV:7=-=DYV1&Y%;D9N:U4D-DAN1VY);DIN)4=+;DQN,#=V
M-4UN3VY.;D8X4&Y1;E)N6S8N,U-61D0U,58X4VY4;C]454=[/EE.,SE6;E5N
M6&Y7;B5%66Y:;BY'6VXO1UQN)S)=;EYN7VY@;F%N:E=B;F-N6#QD;DM3>DPL
M,F5!96XF1RU#9FYG;FAN:6YJ;FMN;&YM;FYN;VYP;G%N<FYT;G-N=6XM34%"
M=FYW;GAN(55Y;C-/>FY[;GQN?6XA;WYN(F]U.'I#(V\D;T(]/U)Y,B5O)F\G
M;WA2*&]]5BEO3$8J;RMO-$$L;WI/>$LN;RUO>C-X.2]O,&]B4#%O,F]F-S]0
M,V\T;S5O<4A@3#9O-V\X;SEO.F]@53MO;30J0SQO/6\^;S]O?4Y`;V!".#0V
M5W4]1T]#;T%O0F]$;R<V?#QB/DQ#16]&;T=O3V](;TEO2F]"1W%O339+;TQO
M36]&-CY#3F]0;U%O4F]R55-O=T14;WA$56]6;V0X=S!7;UAO66]:;UMO7&]=
M;UYO-3YA;U]O8&]B;V-O34%D;V5O9F]G;VAO:6]J;VMO;&]80&UO+4%N;V]O
M<&]B3R0S14-%8T%)1F-5,4I.,S1R2$=C4$](8V0\26-*8T9#(E561&LY14Y+
M8W9#3&,G-W,X4CI-8TYC1%1/8U!C2U%18U)C4V-48U9156-[,CM`5F,K0%=C
M6&-98UIC6V,W.&):4S9D6F-:9EIN2&5:0#=T4752<U57/6A7:%IG6B(P4TUI
M6CTX2CP]0B1"0C-J6BI",$0U/5Y/:UI"25TQ;%HX-CI4?3-M6DE454]C16Y:
M;UIP6FI!54Q=3V=3(4)Q6F5+<EIF2WY2=#AS6B\P-D]/56U+=%I$8R5!/W9`
M=D%V440X2&-16U!%42\\33ET;T8T.E-"=GLS0W9Q-45V:E,G=BE1*78H=F-!
M5T`B,6U.:%`K=G9/*G9P52QV.4-T.RYV+79>1%A!*DL\3R]V,'8Q=C9"5#!Y
M13)V8$<F=C@^,CYE-4<W/S]20V9#3%AO.'D])5%0,#!W,7<L4#`P,G<S=S1W
M2D=//C=W-G=>,35W.'<Y=R1.34@K.CAH.6@Z:$(^=%)/5%A),U(E-FI'?'%N
M3S-+:U!O9V=-2SE9-GUQ9#!,2WYQ)%0M0FQ!1$8Q/B%R53PB<B-R)')#4C5&
M1TTE<C%313]B3"9R)W)546XV*'(I<E\U*G(K<GPR+'(M<B=(9S<I;"IL*VPL
M;"Y&+6PN;$DW,THX8D]W4'=-,E%W4W=2=SMB(CP\8CUB/F(_8D!B06(Y-WM2
M)#U.2B4Q1TM"8GPV1$A#8D@]?3%$8G8V16)91$9B6D]=.4=B(4!(8G8R26)S
M04IB2V)X0DQB36).8E=*.%AE66-/)7`P7&U")E1433%16S-]1S4R/T)@9CM*
M869B9E0^8V8D5U5-969=/&1F9F9G9FY"/CUH9F9")SII9FIF4C-I424_:V9O
M1FQF;69N9BU&;V8G27!F<69R9CEE<V9T9F)"=69V9FA6=V9X9D<Y.W<Z=SYW
M/'<A.C]W0'="=T%W1'=#=T5W1G='=VA+7SA4=U5W5G=8=UIW5W=;=UEW5U=<
M=UUW7G=?=V!W2ULJ6'=E;3E]/VH[27='1DAW2G=,=TMW37<Z3DYW)T1C4T]V
M,T)0=E%V4G93=E1V5G8K,5=V6'99=EIV6W9<=EUV7G9*3U]V8'9A=F)V8W9D
M=G!`979F=F=V:'9I=FIV:W9L=FUV;G9O=G!V<79R=G-V='8H/G5V=G9W=GAV
M>DAY=GIV>W9\=GUV?G8A=R)W(W<D=R5W)G<G=RAW;C$I=RIW*W<L=RUW6T$N
M=R]W<40O<"8\,'!Y0SA%.U$Q<#)P,W`T<#5P/%%L43=P-G`G5%)-.'`Z<#EP
M.W`\<&LX/7!H.CYP/W!I/D!P;#9!<$)P0W!$<#5(17!&<$=P=$5(<$EP2G`]
M=TMP3'!-<$YP3W!7.E!P47!2<%-P5'!5<%9P6'`E4U=P67`Z=3E"9'=E=V9W
M9W=H=S1":G=K=W-"<'1O=&E"87=B=T8[9%ER2FA`)'!:.BU'+$1L=VUW;G=P
M=V]W<7=T=W-W<G=U=W9W:6UJ;6MM/'8]=CYV)C8^6$0Y.U@Q7'-*=W=X=WEW
M>W=Z=T<Q?'=]=WYW:T8T;%TS,W8T=F1!-78V=C=V.'8Y=CIV(T@[=GI!*#EH
M;6HY7UDA(R(C(R-G(24C)B,G(R@C*2,J(RLC+",M(RXC+R,P(S$C,B,S(S0C
M-2,V(S<C.",Y(SHC.R,\(STC/B,_(T`C02-"(T,C1"-%(T8C1R-((TDC2B-+
M(TPC32-.(T\C4"-1(U(C4R-4(U4C5B-7(U@C62-:(ULC7"-=(UXC7R-@(V$C
M8B-C(V0C92-F(V<C:"-I(VHC:R-L(VTC;B-O(W`C<2-R(W,C="-U(W8C=R-X
M(WDC>B-[(WPC?2,K(6DA:B%^(R0C`````````````````````````````+,<
M_O_"'/__TAS__^(<___R'/__`AW_?Q$=```1'0``$1T``!$=```1'0``$1T`
M`!$=```1'0``$1TK```````K'```*QP`@"P<;[\Y'.[G11S^WU,<HEU;'-@_
M91P+P&H<A`EN'`R@<AQ``',<$&EX'!#B?1P2N80<I8:+'`!:CQP`:)(<B0*6
M'`60FAR`:I\<$`"@'`,`HAP``*(<`("C'/D?KAP`CK(<`0``````````````
M`````````````$@"BW]3`GM_8`*T/6D"5>]T`JC[?@)=\XD"0P*-`@M`D0)`
M^YD"/HVB`O=[KP(LC+4"_V["`OKCS0(Z'=4"[:C>`@+FY`*#S^T"]8SV`E4U
M_@)(X`,#J_\0`[F2&`-9V"`#&*LG`Y(H+`/IUS<#((`Y`SC$/P.#]4@#2N=1
M`PI%5@,`L%D#%)=@`V)W:0,`5&P#B-%R`R`4=0,@$'<#P,A\`R$A@`,``(`#
MJ!.&`P0,B0,`@(H#0`2,`\!PD0,H")0#P`B7`P0`F`,"`)D#`(":`WLKI`-R
M%*H#)'FQ`_L[O0,G,\4#Y!K,`S68TP/O.-T#T9KE`P(HZ`,3J.X#:;_Y`\]E
M`P3&+PP$$6L3!,FO'00/-"0$4U`J!**&,`0$H#,$!@$V!`GH/`0//T8$#L!+
M!(@*3P1%@50$$`!5!`'&6@1AH6`$X29G!$M$;00`SG($JL=[!.[4A03?RI`$
MNX69!'0ZH00@I:8$;$.M!$"(L`0&/[@$THO`!'G_S03O.]D$6O?D!._H[P3+
M^_L$-EL$!4D-"@7]&Q4%5`$9!>XY(P55V"L%=2XT!=B_/P4:J48%U_-2!;_V
M7P7@9V<%#+1M!<*"<@43"'8%G=1_!8O0A@5:!HP%81"0!?)TF07@6:`%GX^K
M!1*SL@6``+,%JFJ[!3`RP`5>L,@%>IW2!:Q@V`4#T]\%`,GC!9@PZ`56BN\%
M`'#R!9`3]P44'_X%0A@"!F#`!@8(``<&"(`)!H`0"P8`!`P&D.P3!A<H&08S
MYB(&6`<H!@"0*@8(]S(&"4XX!H7T0`:#_$D&4Z]3!L@86`9\&%\&#`AB!M]J
M;084`7`&#,AU!C2G?081H($&$">&!L4HC`8B0I`&$P24!B$`E@80,)D&$D&=
M!B`8H`8`0*$&*P*F!@S&K`8``ZX&`!"O!B(`L08B`+,&$%BW!DD"NP:4H,`&
M<);'!K#NT`:2%]<&ELO@!O(%YP8E`.H&6"/P!MXE^0;,0O\&.,\(!P1*#`=`
M#`\'GS49!R@1'0<`BB`'^A,I!PJ1+@<I`C('5A`W!T$&.P<@!#T'A`1`!_"$
M1@<``$8'!`Q)!P`$2@<L04\'!A)3!U016`=+"EX'`@!?!P`"8`?``&('``!B
M!Y0`90<!`&8'N[]S!WP6>P<K)($'NYN,!ZA_E@=_#)\'>>.I!_00KP<-X+4'
M,D&Z!P&?P0=2AL<'<C7/![00U`<2_]X')\_H!R-"[0=KP/0'`H;X!P8Q_0?3
M'P<(##H-"*JA%`@2"!<(!`(9"'(E(`@!""((S$`G"%!(*PC08C$($&`T"(`<
M.`@`*3L(`)H_"!``0`@$`$$(`")#"```0PB``$0(("!&"`!H20CFRU,(GF!:
M"&Z18@AS/VT(P&!Q"((Y=P@T$'L(,$A_"`8`@0A<O8L(T8R2"/O6G@CA(*,(
MZ$.J"``&K`A."+$(``6S"-#$N0@?C<((JHG)".&FT0@"%M4(`0#6".TAW@A6
M-N8(BQKM"+<?^`BE$_\(`F4$":`P"`EXLA`)QR,8"9-L(`DBZ2<)?^0R"70Z
M.@GCCT0)()A("0XH30DE)E,)G+]>"4F_:`D8,FT)5*QT"4FY?`D6&8()8`R&
M"2*UC0G!^Y<)60:="4/CI0D@A*@)V0BN"0"`KPD`5;,)(B"V"80!N0FA`+P)
M`$B^"1`@P`F`$\0)@$#&"00-R@D6`,T)0`#."2"`T`E`_=@)YXWB"394Z0F8
MX.\)BWOY"1X)_PG(_@D*2=(0"A$&%`KNC1X*-QDF"B*Z+0KT=S@*W9]$"NSS
M3PK:\%@*AD->"D+L90H_C6\*!"9S"FSZ?0HAP($*CF*("L(,C0J%UY8*10&:
M"JUWI0J95:T*4.*S"D5`MPH+)KT*5*'#"B>8R@H96-`*0S36"A"DV@KR!>$*
M%$'E"H`BZ`H`!^L*M`#O"F9"]0H0<OH*H14`"R5@!0N%00H+5``-"P``#0L!
M`@\+!`$1"R#(%0MPRQT+(),B"V)J*0M,&"X+E0`R"X`8-0N+FCT+LJI%"P$R
M20MZV%(+Q`!5"^7S8`O#!&4+3=1M"SBB<PNAH7D+<E!_"PJ8A`O\A(P+4L&2
M"]%$F`N4$)P+PB"@"X!!HPL00J8+``"F"P`ZJ@M``JP+G=*U"P$ONPNQJ,(+
M0+W)"S(DS@M-T]<+2]#>"R.GY@NMT.X+D@KS"Z%U^PNLK00,Z0$*#!J`#@P?
M=QD,)9(?#!N@)0RAWR\,RB`T#`(&-PR,<S\,?U=+##L`4`S_"UL,T`!>#&J`
M8PR(`&4,Q*%K#"D`;@P%*G,,)`5W#`E`>@PC%H`,(FB%#`6`B`P1((L,$:*0
M#`0`D0R09)8,24B;#((3H`S5(Z@,,!FM#(`IL0R2"+4,`E2Y#!&(O0P!(+\,
M!*#"#``$PPR`@<8,`H7*#")@S@R0`-`,`0O4#"(`U@P"$MD,$4#<#(,`WPP!
M&N,,``#C#```XPP``.,,``#C#```XPP``.,,``#C#)\`Z0R$1NX,R!+S#``"
M]`S\!/L,`!K^#-XN"`U,#`T-`@0/#;B`%`TFJ!H-_`HB#0*,)@TH(BH-X*`O
M#7N/.@W6QT0--2%*#<<&40VQ^%H-$P=@#55B9PUNDW`-&8IV#?IN@0T.^XL-
M,!:0#?E(F`TOS:(-ZWVN#9)8M`V$3KH-H$R_#2YZR`WJ[=,-'E;;#4G&X@V0
M$>8-)%/L#3KH]`W;SP`.)($$#O$8"PY"8Q$.4U@8#HH:'@X@=",.TR0J#CNJ
M,PX4!3<.&&`[#EB)00X`2$,.`,!%#FB"2@X!D4X.I(13#M8L6PZ&B&`.NL1H
M#G<#<`X0`G(.1()V#C@`>0X1KH`.2D"$#L`HB`X`48L.1&"/#A05E`X0<YH.
M`!";#H(`G0Y(`J`.!0*C#@9`I@X#P*H.``"J#@``J@X"#*T."`"N#B`"L`X`
MD+(.`$"S#@"XMPYAT;X.(4;##G0RR@X`^,\.BCO7#@\%W0X`B^$.T+OJ#H`B
M[0X`!N\.:0?V#D"`^`Y#`/L.(%3_#@!0`0_0008/#"4+#Q"$#@\0@Q(/`1$5
M#R@"&`\(0!H/,``<#Z%`(`\``B$/0``B#P`@(P\`%28/XZLP#X`Q-`]$JCH/
MQL)!#R3&1P\3K$X/!(!0#P"P4P_1`UD/'F%@#X5"90\#\VT/GQUW#PI$>P_H
M>(,/)EZ+#Y+#D@\`(),/A0"6#P&PF@\`0)L/D$J@#T*(I`\$RJD/C0RO#P6G
MM@\#0KH/H2*_#P0`P`]HAL8/`0S)#V15T`]Y$-8/`@#7#Z#>WP\`(.`/P4#D
M#XM(Z@\!4.T/@`/P#P`$\0\``/$/!%#T#UW`^P_0@/\/$*`"$`J7"1`@NQ`0
MKTT:$"'9(1`0'B808`0I$!2#+A!(B#(0UJ8[$#O81!`_<T\0O"=8$'1)7Q#<
M#6<0$Y)M$"L4<Q"ABWH0=2Z#$#G1BQ`),(\04%"3$`B(EA``:9H0U$FA$$H"
MI1`00*<0%H"K$&3ELQ#7B;P0(,"_$!93QA"2*\T0`(;0$$6CUQ#@%=T0BP#A
M$`,,Y1!N&>T0`.+Q$#%P]Q`&@/H0I18!$2FH!Q$`(`@1@!@+$:QZ%!%(X1H1
M!S(@$=:U*A'H,C$1D5\Z$:%0/Q'E($41`'Q*$8`03!&`<E$1BIU9$:H`71$?
M0F01(@YI$3$";1$`$6\1E`1S$2(`=1$(0'<1$`!X$1!<?1%#`X(1R/R+$:6A
MDA&`!941,X2;$0`$G!&``)T1"&ZC$4LJJA$F@:\1V*JW$0$INQ%-:,(1D$3&
M$0D`R!&(NL\10`#0$8(`TA$``-(1T8?:$5LAX1'FL>H183'P$0B`\A$`"/,1
M0,+W$6F@_1$`I@$26(T($C)*#A)Q71<2"E4=$J":(Q)7+2P2!4`O$J9*-A(A
M(#D2L3`_$L8_21(2`4P2PA!0$@HF51)B1%H2@E!>$H"88A)`@&02P`1G$@"!
M:1(#(&P2``!L$@``;!(8.'$2``)R$J;Q>Q(T1(`2#G*'$J(UCA+@DI02`8&7
M$@`)F1(`!)H2``":$H6(GQ(``)\2``"?$@``GQ(`0*`2@`"A$@``H1(``*$2
M0$"C$@``HQ(``*,2``"C$@``HQ(``*,2``"C$@``HQ(``*,2``BD$H(`IA(`
M`*82``"F$@``IA($`*<2`(BI$O^_N!+OY\42___5$K__Y!+O[_(2__T!$__[
M$!/^OQX3__\N$W\%-Q,T`#H3LX5"$P9'2!,60DT3`E11$Q#D5A.2@%H3!;-A
M$R)49A,P@6H38T)P$PL8=1-[.'X3]1.'$^4'CQ/JJ9@33#R?$Q0%HQ,`!J43
M`H"G$]D:KQ-(O;<3-^["$Y;TRQ-?<-03P'[<$[*_YQ-?-?$31.;X$U]%`10`
MD`,41D$(%$`=#10[!A04H6(:%!/^)!0%A2D4`CDN%$@%,A0(##443Q0\%```
M/!2(-$$4&%A&%'<P3A05V%44#KU>%/M+:120BFX4`(5Q%`#!=!0=YGT4%.V%
M%(:SC11R_YD4FV.B%)+]K!2^V;<4>XB_%)(*Q!3^T]`4LAS7%("YW11Z%^84
MR8+L%!?<]13[_P05@#D)%6!"#14,61,5`0\8%=\W)!6CE"L54+$Q%2,&-A4'
M(SP56OA%%0(Q217P`4X5`C%2%4``4Q6"'ED5"CI?%6H%916$6VP5@!)O%0*`
M<144IW@5$B9]%4N@@Q5I$(@5`9"+%0`0C!6*A)$5`AB4%8`_FQ4(!Y\50$*B
M%1`!I!443JH5L("N%0`8L!40Q;45@0*X%0*"NQ4I$+\5$`+!%0"(PQ4@`,05
M0@#&%8`"R!4`$<H5`.#-%1-$TA4$6-85`O[>%0<\Y14H,.D5F)?Q%7,$]Q71
MS@`6$\L(%A!B#!8?0Q06C2<<%JQ5)!8N0BH6DL@P%H!3-1:(`C@6.4`]%E%X
M1!8L*4H6B(!-%@"Y4A8H)%8600Q:%@X(7A8A1&(6`$)D%@@$9A9H"&H6!@!L
M%@02;Q8Q,'06D`)W%CY;@1:%X(<6-BF.%D00D184*)46@A"8%F9"GA8T@Z06
M/`&I%AM3L18$!+,6#0ZY%B(,O191`,`6$@#"%@#`Q!9``,46`(C'%DH`RA8`
M`,H6``#*%@``RA;VW]<61U3>%FB(XQ8(`.06@0#F%@``YA8``.86`$#G%@`!
MZ!8``.@6``#H%@`"Z18`!NL6"`#L%@``[!8``.P6``#L%@``[!8``.P6``#L
M%H``[18``.T60`#N%@``[A8``.X6``#N%D`0\!8``/`6``#P%@``\!;_[_\6
M_?<-%W__'!?^_RL7__LZ%___2A?__5D7_[]H%___>!?_`(`7PA*%%R`$AQ<&
M#(L7"`>/%R06E!<0`987``"6%P``EA<``)87``"6%P``EA<``)87``"6%P#@
MF1?^_Z@7__^X%___R!=Y?]07WRC=%_D`XQ<R#.@7$H#K%P@`[!<ZU?476-C\
M%\+L!!@8G0L8J"\3&""6&!@0X!P8#-8C&"(F*!B7#S$8!@(T&$"R.1A5D#\8
MHH!#&!%01Q@`F$H8!`1,&`!`31@``$T8``!-&```31@``$T8``!-&```31@`
M`$T8``!-&```31C`^U88__]F&/[O=!C[WX(8"`N&&$-BC!BV09,8._N?&'1O
MJ1B)(Z\8?ZZ[&-?LQAA'X,T88%G3&):@V1B/">`8+&'F&#"@ZA@-">\8JBKV
M&$[4_AA[3PD9LL00&8LX%QG&J1\9$&$C&10`)1D`0B<9#(`J&0("+!E(_C49
MA60[&3[611GWXU$9H#I7&0<,7!D,Y&(9,`1E&8#V;!D"$&X9``!N&0``;AD`
M`&X9``!N&0``;AD``&X9``!N&0``;AD``&X9$`!O&0!`<!D``'`9`$!Q&0``
M<1D``7(9``!R&0``<AD``'(9``!R&0``<AD``'(9`$!S&0``<QD``',9``1T
M&0``=!D`@'49``!U&0``=1D``'49``1V&4``=QD``'<9``!W&0``=QD``'<9
M``!W&0!`>!D``'@9``!X&0`(>1D``'D9X/^$&;W^D1G__Z$9__^Q&7]_OQGG
M^\P9O__;&?_WZAG___H9_^\)&G[_%QKWWR4:]_8R&M_[0!K^OTX:3X!4&@``
M5!H``%0:``!4&@``5!H``%0:``!4&@#O6QK_?VH:?_]Y&O>VA1H&1(D:?KB3
M&O4[GAHQB*,:EA>K&O0`L!I@J;8:D1.\&H``O1I)<L0:\_+/&B0`T1H!A]8:
MR$+;&M/CY1I(4.D:`"3K&@5#\!H``/`:3$KV&B<"^QI8$/\:("@"&Q8!!AL)
MJ`L;%``-&P``#1L```T;P#X4&V@`%QL``!<;```7&P``%QL``!<;```7&P``
M%QL``!<;X/\B&_^W,!O;_3T;]P!$&P``1!L`0$4;+L=.&X`!4!L``%`;`"!1
M&P$`4AL`0%,;``!3&P``4QLP`%4;J/]@&_>T:QOSK78;_P.`&R`!@AL``((;
M``""&P``@AL``((;``""&P``@AL``((;``""&P``@AL``((;``""&P#PAAO[
M_Y4;]YVA&\_]KAN_`;8;PQ6]&R<8PQL*@<<;0JC,&P`*SAL(@=$;"(#3&PB`
MU1L$&-@;OJ/B&Q(`Y!L``.0;``#D&P``Y!L``.0;``#D&P``Y!L``.0;``#D
M&P``Y!L``.0;``#D&P``Y!L``.0;``#D&P``Y!L``.0;``#D&P"0YAOF:>\;
M-]SY&_]K!AS_/1,<^/P>'/GS*AP$``````!;`2__:`'[`&\!``!O`0``;P'^
M_WX!__^.`?__G@'__ZX!__^^`0\`P@'^_]$!___A`?__\0'__P$"__\1`G\(
M&0+@_R0"__\T`O\#/@(``#X"```^`@``/@(``#X"```^`@``/@(``#X"```^
M`@``/@(``#X"```^`@``/@(``#X"```^`@``/@+_`P``````````````````
M````````E0```)4`8#.;`$``G``-"*````"@````H````*````"@````H```
M`*````"@````H````*````"@````H````*``"`"A`$``H@```*(```"B````
MH@```*(`_P^N````K@```*X`#P"R````L@```+(```"R````L@```+(```"R
M``"!M``"9+@`H4_``/`@Q0``$<<```#'`#/`S0```,T```#-```"S@`@`,\`
M``#/````SP```,\```#/````SP```,\`!`#0````T````-````#0````T```
M`-````#0````T````-````#0````T````-````#0````T````-````#0````
MT````-````#0````T````-``_P/:`/#_Y@#___8`_P\"`0```@$```(!```"
M`0```@$```(!```"`?__$@'__R(!__\R`?__0@'_#TX!``!.`0``3@$``$X!
M``!.`0``3@$#`%`!#`!2`<#(5P$``%<!``!7`0``5P%@`%D!``!9`0``60$`
M`%D!!0``````````````````````````````````````````````````````
M``````````````````"0`0,``P`%````!0"```8``S<-`(P6$P`"`!0`"`@6
M```(%P```!<``"`8````&```"!D````9````&0```!D````9````&0``0!H`
M514A````(0```"$````A````(0```"$````A````(0```"$````A````(0``
M`"$````A````(0```"$`@`(C````(P```",````C````(P```",````C````
M(P```",````C````(P```",````C`/[_,@#[`SL`_O]*`/L#4P```%,```!3
M````4P`"`%0`__]D`/__=`#__X0`__^4``(```````````!*53^6PU<H8\Y4
M"57`5)%V3'8\A>YW?H*->#%RF):-ERALB5OZ3PECEV:X7/J`2&BN@`)FSG;Y
M459EK''Q?X2(LE!E6<IALV^M@DQC4F+M4R=4!GMK4:1U]%W48LN-=I>*8AF`
M75<XEV)_.')]=L]G?G9&9'!/)8W<8A=ZD67M<RQD<V(L@H&8?V=(<FYBS&(T
M3^-T2E.>4LI^II`N7H9HG&F`@=%^TFC%>(R&496-4"2,WH+>@`53$HEE4H2%
M^9;=3R%8<9F=6[%BI6*T9GF,C9P&<F]GD7BR8%%3%U.(C\R`'8VAE`U0R'('
M6>M@&7&KB%19[X(L9RA[*5WW?BUU]6QFCOB//)`[G]1K&9$4>WQ?IWC6A#V%
MU6O9:]9K`5Z'7OEU[95=90I?Q5^?C\%8PH%_D%N6K9>YCQ9_+(U!8K]/V%->
M4ZB/J8^KCTV0!VAJ7YB!:(C6G(MA*U(J=FQ?C&72;^ANOEM(9'51L%'$9QE.
MR7E\F;-PQ75V7KMSX(.M9.ABM93B;%I3PU(/9,*4E'LO3QM>-H(6@8J!)&[*
M;'.:56-<4_I498C@5PU.`UYE:S]\Z)`68.9D''/!B%!G36(BC6QW*8['D6E?
MW(,AA1"9PE.5AHMK[6#H8']PS8(Q@M-.IVS/A<UDV7S]:?EF28.54U9[IT^,
M44MM0EQMCM)CR5,L@S:#Y6>T>#UDWUN47.Y=YXO&8O1G>HP`9+IC28>+F1>,
M('_RE*=.$):DF`QF%G,Z5QU<.%Y_E7]0H(""4UYE174Q52%0A8V$8IZ4'6<R
M5FYOXETU5))P9H]O8J1DHV-[7XAO])#C@;"/&%QH9O%?B6Q(EH&-;(B19/!Y
MSE=9:A!B2%183@MZZ6"$;]J+?V(>D(N:Y'D#5/1U`6,94V!LWX\;7W":.X!_
MGXA/.EQDC<5_I66]<$51LE%KA@==H%N]8FR1='4,CB!Z`6%Y>\=.^'Z%=Q%.
M[8$=4OI1<6JH4X>.!)7/EL%N9)9::4!XJ%#7=Q!DYHD$6>-CW5U_>CUI($\Y
M@IA5,DZN=9=Z8EZ*7N^5&U(Y5(IP=F,DE8)7)68_:8>1!U7S;:]^(H@S8O!^
MM74H@\%XS):>CTAA]W3-BV1K.E)0C2%K:H!QA/%6!E/.3AM.T5&7?(N1!WS#
M3W^.X7N<>F=D%%VL4`:!`7:Y?.QMX']19UA;^%O+>*YD$V2J8RMC&94M9+Z/
M5'LI=E-B)UE&5'EKHU`T8B9>AFOC3C>-BXB%7RZ0(&`]@,5B.4Y54_B0N&/&
M@.9E+FQ&3^Y@X6W>BSE?RX937R%C6E%A@V-H`%)C8TB.$E";7'=Y_%LP4CMZ
MO&!3D-=VMU^77X1V;(YO<'MV27NJ=_-1DY`D6$Y/]&[JCTQE&WO$<J1MWW_A
M6K5BE5XP5X*$+'L=7A]?$I`4?Z"8@F/';IAXN7!X45N7JU<U=4-/.'677N9@
M8%G`;;]KB7C\4]66RU$!4HEC"E23E`.,S(TY<I]X=H?MCPV,X%,!3N]V[E.)
ME':8#I\ME9I;HHLB3AQ.K%%CA,)AJ%(+:)=/:V"[41YM7%&68I=E899&C!>0
MV'7]D&-WTFN*<NQR^XLU6'EW3(U<9T"5FH"F7B%NDEGO>NUW.Y6U:ZUE#G\&
M6%%1'Y;Y6ZE8*%1RCF9E?YCD5IV4_G9!D(=CQE0:63I9FU>RCC5G^HTU@D%2
M\&`56/Z&Z%Q%GL1/G9BYBR5:=F"$4WQB3Y`"D7^9:6`,@#]1,X`47'69,6V,
M3C"-T5-:?T][$$]/3@"6U6S0<^F%!EYJ=?M_"FK^=Y*407[A4>9PS5/4CP.#
M*8VO<FV9VVQ*5[."N66J@#]B,I:H6?].OXNZ?CYE\H->EV%5WIBE@"I3_8L@
M5+J`GUZX;#F-K():D2E4&VP&4K=^7U<:<7YLB7Q+6?U._U\D8:I\,$X!7*MG
M`H?P7`N5SIBO=?UP(I"O41U_O8M)6>116T\F5"M9=V6D@'5;=F+"8I"/15X?
M;"9[#T_83PUG;FVJ;8]YL8@77RMUFF*%C^]/W)&G92^!48&<7E"!=(UO4H:)
M2XT-6850V$X<EC9R>8$?C<Q;HXM$EH=9&G^05'96#E;EBSEE@FF9E-9VB6YR
M7AAU1F?19_]ZG8!VC1]AQGEB96.-B%$:4J*4.'^;@+)^EUPO;F!GV7N+=MB:
MCX&4?]5\'F10E3]Z2E3E5$QK`60(8CV>\X"9=7)2:9=;A#QHY(8!EI26[)0J
M3@14V7XY:-^-%8#T9II>N7_"5S^`EVCE73MEGU)M8)J?FT^LCFQ1JUL37^E=
M7FSQ8B&-<5&IE/Y2GVS?@M=RHE>$9RV-'UF<C\>#E52->S!/O6QD6]%9$Y_D
M4\J&J)HWC*&`165^F/I6QY8N4MQT4%+A6P)C`HE63M!B*F#Z:'-1F%N@4<*)
MH7N&F5!_[V!,<"^-25%_7AN0<'3$B2U717A27Y^?^I5HCSR;X8MX=D)HW&?J
MC36-/5**C]INS6@%E>V0_5:<9_F(QX_(5+B::5MW;29LI4ZS6X>:8Y&H8:^0
MZ9<K5+5MTEO]48I557_P?[QD36/Q9;YAC6`*<5=L26PO66UG*H+56(Y6:HSK
M:]V0?5D7@/=3:6UU5)U5=X//@SAHOGF,5%5/"%32=HF,`I:S;+AM:XT0B62>
M.HT_5M&>U76(7^!R:&#\5*A.*FIAB%)@<(_$5-AP>88_GBIMCUL87Z)^B56O
M3S1S/%2:4QE0#E1\5$Y._5]:=/98:X3A@'2'T'+*?%9N)U].ABQ5I&*23JIL
M-V*Q@M=43E,^<]%N.W424A93W8O0:8I?`&#N;4]7(FNO<U-HV(\3?V)CHV`D
M5>IU8HP5<:-MIEM[7E*#3&'$GOIX5X<G?(=V\%'V8$QQ0V9,7DU@#HQP<"5C
MB8^]7V)@U(;>5L%KE&!G84E3X&!F9C^-_7D:3^EP1VRSB_*+V'YD@P]F6EI"
MFU%M]VU!C#MM&4]K<+>#%F+18`V7)XUX>?M1/E?Z5SIG>'4]>N]YE7N,@&69
M^8_`;Z6+(9[L6>E^"7\)5(%GV&B1CTU\QI;*4R5@OG5R;'-3R5JG?B1CX%$*
M@?%=WX2`8H!18UL.3VUY0E*X8$YMQ%O"6Z&+L(OB9<Q?19:36>=^JGX)5K=G
M.5ES3[9;H%):@XJ8/HTR=;Z41U`\>O=.MF=^FL%:?&O1=EI7%EPZ>_253G%\
M4:F`<()X601_)X/`:.QGL7AW>.-B86.`>^U/:E+/45"#VVETDO6-,8W!B2Z5
MK7OV3F50,()14F^9$&Z%;J=M^E[U4-Q9!EQ&;5]LAG6+A&AH5EFRBR!3<9%-
MEDF%$FD!>29Q]H"D3LJ01VV$F@=:O%8%9/"4ZW>E3QJ!X7+2B7J9-'_>?G]2
M665UD7^/@X_K4Y9Z[6.E8X9V^'E7B#:6*F*K4H*"5&AP9W=C:W?M>@%MTW[C
MB=!9$F+)A:6"3'4?4,M.I77KBTI<_EU+>Z1ET9'*3B5M7XDG?2:5Q4XHC-N/
M<Y=+9H%YT8_L<'AM/5RR4D:#8E$.@UMW=F:XG*Q.RF"^?+-\SWZ53F:+;V:(
MF%F7@UAL95R5A%_)=5:7WWK>>L!1KW"8>NIC=GJ@?I9S[9=%3GAP74Y2D:E3
M467G9?R!!8*.5#%<FG6@E]ABV7*]=45<>9K*@T!<@%3I=SY.KFQ:@-)B;F/H
M77=1W8T>CB^5\4_E4^=@K'!G4E!C0YX?6B90-W=W4^)^A60K98EBF&,44#5R
MR8FS4<"+W7Y'5\R#IY2;41M4^US*3^-Z6FWAD(^:@%665&%3KU0`7^EC=VGO
M46AA"E(J6-A23E<->`MWMUYW8>!\6V*78J).E7`#@/=BY'!@EW=7VX+O9_5H
MU7B7F-%Y\UBS5.]3-&Y+43M2HEO^BZ^`0U6F5W-@45<M5'IZ4&!46Z=CH&+C
M4V-BQUNO9^U4GWKF@G>1DU[DB#A9KE<.8^B-[X!75W=[J4_K7[U;/FLA4U![
MPG)&:/]W-G?W9;51CT[4=K]<I7IUA$Y909N`4(B9)V&#;F17!F9&8_!6[&)I
M8M->%):#5\EBAU4AATJ!HX]F5;&#96=6C=V$:EH/:.9B[GL1EG!1G&\PC/UC
MR(G2809_PG#E;@5TE&G\<LI>SI`79VIM7F.S4F)R`8!L3^59:I'9<)UMTE)0
M3O>6;95^A<IX+WTA49)7PF2+@'M\ZFSQ:%YIMU&84ZAH@7+.GO%[^'*[>1-O
M!G1.9\R1I)P\>8F#5(,/5!=H/4Z)4[%2/GB&4RE2B%"+3]!/XG7+>I)\I6RV
MEIM2@W3I5.E/5("R@]Z/<)7)7AQ@GVT87EME.('^E$M@O'##?JY\R5&!:+%\
M;X(D3H:/SY%^9JY.!8RI9$J`VE"7=<YQY5N]CV9OADZ"9&.5UEZ991=2PHC(
M<*-2#G,S=)=G]W@6ES1.NY#>G,MMVU%!C1U4SF*R<_&#]I:$G\.4-D^:?\Q1
M=7!UEJU<AICF4^1.G&X)=+1I:WB/F5EU&%(D=D%M\V=M49F?2X"95#Q[OWJ&
MEH17XF)'EGQI!%H"9--[#V]+EJ:"8E.%F)!>B7"S8V133X:!G).>C'@RE^^-
M0HU_GEYOA'E57T:6+F)TFA54W92C3\5E95QA7!5_488O;(M?AW/D;O]^YEP;
M8VI;YFYU4W%.H&-E=:%B;H\F3]%.IFRV?KJ+'82ZAU=_.Y`CE:E[H9KXB#V$
M&VV&FMQ^B%F[GIMS`7B"AFR:@IH;5A=4RU=P3J:>5E/(CPF!DG>2F>Z&X6X3
MA?QF8F$K;RF,DH(K@_)V$VS97[V#*W,%@QJ5VVO;=\:4;U,"@Y)1/5Z,C#B-
M2$ZK<YIGA6AVD0F79'&A;`EWDEI!E<]KCG\G9M!;N5F:6NB5]Y7L3@R$F82L
M:M]V,)4;<Z9H7ULO=YJ189?<?/>/'(PE7W-\V'G%B<QL'(?&6T)>R6@@=_5^
ME5%-4<E2*5H%?V*7UX+/8X1WT(72>3INF5Z961&%;7`1;+]BOW9/9:]@_94.
M9I^'(Y[ME`U4?50LC'AD>601AB%JG('H>&ED5)NY8BMGJX.H6-B>JVP@;]Y;
M3)8+C%]RT&?'8F%RJ4[&6<UKDUBN9E5>WU)582AG[G9F=V=R1GK_8NI44%2@
ME*.0'%JS?A9L0TYV61"`2%E74S=UOI;*5B!C$8%\8/F5UFUB5(&9A5'I6OV`
MKED3ERI0Y6P\7-]B8$\_4WN!!I"Z;BN%R&)T7KYXM61[8_5?&%I_D1^>/UQ/
M8T*`?5MN54J5396%;:A@X&?><MU1@5OG8MYL6W)M8JZ4O7X3@5-MG%$$7W19
MJE(28'-9EF90AI]U*F/F8>]\^HOF5"=K)9ZT:]6%551V4*1L:E6TC2QR%5X5
M8#9TS6*28TQRF%]#;CYM`&58;]AVT'C\=E1U)%+;4U-.GE[!92J`UH";8H94
M*%*N<(V(T8WA;'A4VH#Y5_2(5(UJEDV1:4^;;+=5QG8P>*AB^7".;VU?[(3:
M:'QX]WNH@0MG3YYG8[!X;U<2>#F7>6*K8HA2-737:V15/H&R=:YV.5/>=?M0
M05QLB\=[3U!'<I>:V)@";^)T:'F'9*5W_&*1F"N-P518@%).:E?Y@@V$<U[M
M4?9TQ(M/7&%7_&R'F$9:-'A$F^N/E7Q64E%B^I3&3H:#883I@[*$U%<T9P-7
M;F9F;3&,W681<!]G.FL6:!IBNUD#3L11!F_29X]L=E'+:$=99VMF=0Y=$(%0
MG]=E2'E!>9&:=XV"7%Y.`4\O5%%9#'AH5A1LQ(\#7WULXVRKBY!C<&`];75R
M9F*.E,640U/!CWY[WTXFC'Y.U)ZQE+.435)<;V.016TTC!%83%T@:TEKJF=;
M5%2!C'^96#>%.E^B8D=J.95R981@96BG=U1.J$_G79B7K&38?^U<ST^->@=2
M!(,43B]@@WJFE+5/LD[F>31TY%*Y@M)DO7G=6X%L4I=[CR)L/E!_4P5NSF1T
M9C!LQ6!WF/>+AEX\='=ZRWD83K&0`W1";-I62Y'%;(N-.E/&AO)FKXY(7'&:
M(&[64S9:BY^CC;M3"%>GF$-GFY');&A1RG7S8JQR.%*=4CI_E'`X=G132IZW
M:6YXP);9B*1_-G'#<8E1TV?D=.18&&6W5JF+=IEP8M5^^6#M<.Q8P4ZZ3LU?
MYY?[3J2+`U**6:M^5&+-3N5E#F(X@\F$8X.-AY1QMFZY6])^EU')8]1GB8`Y
M@Q6($E%Z6X)9L8]S3EUL95$EB6^/+I9*A5YT$)7PE:9MY8(Q7Y)D$FTHA&Z!
MPYQ>6%N-"4[!4QY/8V51:--5)TX49)J::V+"6E]T<H*I;>YHYU".@P)X0&<Y
M4IELL7Z[4&557G%;>U)FRG/K@DEG<5P@4GUQ:XCJE566Q61AC;.!A%55;$=B
M+G^26"1/1E5/C4QF"DX:7/.(HFA.8PUZYW"-@OI2]I<17.A4M9#-?F)92HW'
MA@R"#8)FC41D!%Q188EM/GF^BS=X,W5[5#A/JX[Q;2!:Q7Y>>8ALH5MV6AIU
MOH!.81=N\%@?=25U<G)'4_-^`7?;=FE2W(`C5PA>,5GN<KUE?V[7BSA<<89!
M4_-W_F+V9<!.WYB`AIY;QHOR4^)W?T].7'::RUD/7SIYZU@63O]GBT[M8I.*
M'9"_4B]FW%5L5@*0U4Z-3\J1<)D/;`)>0V"D6\:)U8LV94MBEIF(6_];B&,N
M5==3)G9]42R%HF>S:(IKDF*3C]13$H+1;8]U9DY.C7!;GW&OA9%FV69R?P"'
MS9X@GUY<+V?PCQ%H7V<-8M9ZA5BV7G!E,6]58#=2#8!49'"(*74%7A-H]&(<
ME\Q3/7(!C#1L87<.>BY4K'=ZF!R"](M5>!1GP7"O995D-E8=8,%Y^%,=3GMK
MAH#Z6^-5VU8Z3SQ/<IGS77YG.(`"8(*8`9"+6[R+]8L<9%B"WF3]5<^"99'7
M3R!]'Y"??/-045BO;K];R8N#@'B1G(27>WV&BY:/EN5^TYJ.>(%<5WI"D*>6
M7WE96U]C"WO1A*UH!E4I?Q!T(GT!E4!B3%C63H-;>5E46&US'F-+C@^.SH#4
M@JQB\%/P;%Z1*ED!8'!L35=*9"J-*W;I;EM7@&KP=6UO+8P(C&97[VN2B+-X
MHF/Y4ZUP9&Q86"ID`EC@:)N!$%76?!A0NH[,;9^-ZW"/8YMMU&[F?@2$0V@#
MD-AM=I:HBU=9>7+DA7Z!O'6*BJ]H5%(BCA&5T&.8F$2.?%533_]FCU;58)5M
M0U))7"E9^VUK6#!U''5L8!2"1H$18V%GXH\Z=_.--(W!E!9>A5,L5,-P0&SW
M7EQ0K4ZM7CIC1X(:D%!H;I&S=PQ4W)1D7^5Z=FA%8U)[WW[;=7=0E6(T60^0
M^%'#>8%Z_E:27Q20@FU@7!]7$%1444UNXE:H8Y.8?X$5ARJ)`)`>5&]<P('6
M8EAB,8$UGD"6;II\FBUII5G38CY5%F/'5-F&/&T#6N9TG(AJ:Q993(PO7WYN
MJ7-]F#A.]W",6Y=X/6-:9I9VRV";6TE:!TY5@6ILBW.A3HEG47^`7_IE&V?8
M7X19`5K-7:Y?<5/FE]V/16CT5B]5WV`Z3DUO]'['@@Z$U%D?3RI//ERL?BIG
M&H5S5$]UPX""54^;34\M;A.,"5QP86M3'W8I;HJ&AV7[E;E^.U0S>@I][I7A
M5<%_[G0=8Q>'H6V=>A%BH65G4^%C@VSK75Q4J)1,3F%L[(M+7.!EG(*G:#Y4
M-%3+:V9KE$Y"8TA3'H(-3ZY/7E<*8OZ69&9I<O]2H5*?8.^+%&:9<9!G?XE2
M>/UW<&8[5CA4(95Z<@!Z;V`,7HE@G8$56=Q@A''O<*IN4&R`<H1JK8@M7F!.
MLUJ<5>.4%VW[?)F6#V+&?HYW?H8C4QZ7EH^'9N%<H$_M<@M.IE,/61-4@&,H
ME4A1V4Z<G*1^N%0DC52(-X+RE8YM)E_,6CYF:9:P<RYSOU-Z@869H7^J6W>6
M4):_?OAVHE-VE9F9L7M$B5AN84[4?V5YYHOS8,U4JTYYF/==86K/4!%488PG
MA%UX!)=*4NY4HU8`E8AMM5O&;5-F#UQ=6R%HEH!X51%[2&54:9M.1VM.AXN7
M3U,?8SIDJI"<9<&`$(R94;!H>%/YA\AAQ&S[;"*,45RJA:^"#)4C:YN/L&7[
M7\-?X4]%B!]F98$I<_I@=%$14HM78E^BD$R(DI%X7D]G)V#36411]E'X@`A3
M>6S$EHIQ$4_N3YY_/6?%50B5P'F6B.-^GU@,8@"76H885GN8D%^XB\2$5Y'9
M4^UECUY<=61@;GU_6NI^[7YICZ=5HUNL8,MEA',)D&-V*7?:?G27FX5F6W1Z
MZI9`B,M2CW&J7^QEXHO[6V^:X5V):UMLK8NOBPJ0Q8^+4[QB)IXMGD!4*TZ]
M@EERG(8675F(KVW%EM%4FDZVBPEQO50)EM]P^6W0=B5.%'@2AZE<]EX`BIR8
M#I:.<+]L1%FI8SQW38@4;W.",%C5<8Q3&GC!E@%59E\P<;1;&HR,FH-K+EDO
MGN=Y:&=L8F]/H76*?PMM,Y8G;/!.TG5[43=H/F^`D'"!EEEV=$=D)UQED)%Z
M(XS:6:Q4`()O@X&)`(`P:4Y6-H`W<LZ1ME%?3G68EF,:3O93\V9+@1Q9LFT`
M3OE8.U/68_&4G4\*3V.(D)@W65>0^WGJ3O"`D76";)Q;Z%E=7P5I@88:4/)=
M64[C=^5.>H*18A-FD9!Y7+].>5_&@3B0A("K=:9.U(@/8<5KQE])3LIVHF[C
MBZZ+"HS1BP)?_'_,?\Y^-8-K@^!6MVOSES26^UD?5/:4ZVW%6VZ9.5P57Y"6
M<%/Q@C%J=%IPGI1>*'^Y@R2$)81G@T>'SH]BC<AV<5^6F&QX(&;?5.5B8T_#
M@<AUN%[-E@J.^8:/5/-LC&TX;']@QU(H=7U>&$^@8.=?)%PQ=:Z0P)2Y<KEL
M.&Y)D0EGRU/S4U%/R9'QB\A3?%["C^1MCD["=H9I7H8:80:"64_>3SZ0?)P)
M81UN%&Z%EHA.,5KHE@Y.?URY>8=;[8N]?XESWU>+@L&0`51'D+M5ZERA7PAA
M,FOQ<K*`B8IT;=-;U8B$F&N,;9HSG@INI%%#4:-7@8B?4_1CE8_M5EA4!E<_
M<Y!N&'_<C]&"/V$H8&*6\&:F?HJ-PXVEE+-<I'P(9Z9@!988@)%.YY``4VB6
M05'0CW2%79%59O6755L=4SAX0F<]:,E4?G"P6WV/C5$H5[%4$F6"9EZ-0XT/
M@6R$;9#??/]1^X6C9^EEH6^DAH&.:E8@D()V=G#E<2.-Z6(94OUL/(T.8)Y8
MCF'^9F"-3F*S52-N+6=GC^&4^)4H=P5HJ&F+5$U.N'#(BUADBV6%6X1Z.E#H
M6[MWX6MYBIA\OFS/=JEEEX\M755<.(8(:&!3&&+9>EMN_7X?:N!Z<%\S;R!?
MC&.H;59G"$X07B:-UT[`@#1VG);;8BUF?F*\;'6-9W%I?T91AX#L4VZ0F&+R
M5/"&F8\%@!>5%X79CUEMS7.?91]W!'4G>/N!'HV(E*9/E6>Y=<J+!Y<O8T>5
M-9:XA"-C07>!7_!RB4X48'1E[V)C:S]E)U['==&0P8N=@IUG+V4Q5!B'Y7>B
M@`*!06Q+3L=^3(#T=@UIEFMG8CQ0A$]`5P=C8FN^C>I3Z&6X?M=?&F.W8_.!
M](%N?QQ>V5PV4GIFZ7D:>BB-F7#4==YNNVR2>BU.Q7;@7Y^4=XC(?LUYOX#-
MD?).%T\?@FA4WETR;<R+I7QTCYB`&EZ25+%VF5L\9J2:X',J:-N&,6<J<_B+
MVXL0D/EZVW!N<<1BJ7<Q5CM.5X3Q9ZE2P(8NC?B447M/3^AL77E[FI-B*G+]
M8A-.%GALC[!D6HW&>VEHA%[%B(99GF3N6+9R#FDEE?V/6(U@5P!_!HS&44EC
MV6)34TQH(G0!@TR11%5`=WQP2FUY4:A41(W_6<MNQ&U<6RM]U$Y]?--N4%OJ
M@0UN5UL#F]5H*HZ76_Q^.V"U?KF0<(U/6<UCWWFSC5)3SV56><6+.Y;$?KN4
M@GXT5HF1`&=J?PI<=9`H9N9=4$_>9UI07$]05Z=>_?_]__W__?_]_XU.#$Y`
M41!._UY%4Q5.F$X>3C*;;%MI5BA.NGD_3A531TXM63MR;E,0;-]6Y("7F=-K
M?G<7GS9.GTX0GUQ.:4Z33HB"6UML50]6Q$Z-4YU3HU.E4ZY399==C1I3]5,F
M4RY3/E-<C6938U,"4@A2#E(M4C-2/U)`4DQ27E)A4EQ2KX1]4H)2@5*04I-2
M@E%4?[M.PT[)3L).Z$[A3NM.WDX;3_-.(D]D3_5.)4\G3PE/*T]>3V=/.&5:
M3UU/7T]73S)//4]V3W1/D4^)3X-/CT]^3WM/JD]\3ZQ/E$_F3^A/ZD_%3]I/
MXT_<3]%/WT_X3RE03%#S3RQ0#U`N4"U0_D\<4`Q0)5`H4'Y00U!54$A03E!L
M4'M0I5"G4*E0NE#64`91[5#L4.90[E`'40M1W4X];%A/94_.3Z"?1FQT?&Y1
M_5W)GIB9@5$46?E2#5,'BA!3ZU$96551H$Y64;-.;HBDB+5.%('2B(!Y-%L#
MB+A_JU&Q4;U1O%''4991HE&E4:"+IHNGBZJ+M(NUB[>+PHO#B\N+SXO.B]*+
MTXO4B]:+V(O9B]R+WXO@B^2+Z(OIB^Z+\(OSB_:+^8O\B_^+`(P"C`2,!XP,
MC`^,$8P2C!2,%8P6C!F,&XP8C!V,'XP@C"&,)8PGC"J,*XPNC"^,,HPSC#6,
M-HQI4WI3'98BEB&6,98JECV6/)9"EDF65)9?EF>6;)9REG26B):-EI>6L):7
MD)N0G9"9D*R0H9"TD+.0MI"ZD+B0L)#/D,60OI#0D,20QY#3D.:0XI#<D->0
MVY#KD.^0_I`$D2*1'I$CD3&1+Y$YD4.11I$-4D)9HE*L4JU2OE+_5-!2UE+P
M4M]3[G'-=_1>]5'\42^;ME,!7UIU[UU,5ZE7H5=^6+Q8Q5C16"E7+%<J5S-7
M.5<N5R]77%<[5T)7:5>%5VM7AE=\5WM7:%=M5W97<U>M5Z17C%>R5\]7IU>T
M5Y-7H%?55]A7VE?95])7N%?T5^]7^%?D5]U7"U@-6/U7[5<`6!Y8&5A$6"!8
M95AL6(%8B5B:6(!8J)D9G_]A>8)]@G^"CX**@JB"A(*.@I&"EX*9@JN"N(*^
M@K""R(+*@N."F(*W@JZ"RX+,@L&"J8*T@J&"JH*?@L2"SH*D@N&""8/W@N2"
M#X,'@]R"](+2@MB"#(/[@M."$8,:@P:#%(,5@^""U8(<@U&#6X-<@PB#DH,\
M@S2#,8.;@UZ#+X-/@T>#0X-?@T"#%X-@@RV#.H,S@V:#98-H@QN#:8-L@VJ#
M;8-N@["#>(.S@[2#H(.J@Y.#G(.%@WR#MH.I@WV#N(-[@YB#GH.H@[J#O(/!
M@P&$Y8/8@P=8&(0+A-V#_8/6@QR$.(01A`:$U(/?@P^$`X3X@_F#ZH/%@\"#
M)H3P@^&#7(11A%J$681SA(>$B(1ZA(F$>(0\A$:$:81VA(R$CH0QA&V$P83-
MA-"$YH2]A-.$RH2_A+J$X(2AA+F$M(27A.6$XX0,A0UU.(7PA#F%'X4ZA5:%
M.X7_A/R$685(A6B%9(5>A7J%HG=#A7*%>X6DA:B%AX6/A7F%KH6<A86%N86W
MA;"%TX7!A=R%_X4GA@6&*886ACR&_EX(7SQ905DW@%596EE860]3(EPE7"Q<
M-%Q,8FIBGV*[8LIBVF+78NYB(F/V8CEC2V-#8ZUC]F-Q8WICCF.T8VUCK&.*
M8VECKF.\8_)C^&/@8_]CQ&/>8\YC4F3&8[YC161!9`MD&V0@9`QD)F0A9%YD
MA&1M9)9D>F2W9+ADF62Z9,!DT&379.1DXF0)925E+F4+7])?&7417U]3\5/]
M4^E3Z%/[4Q)4%E0&5$M44E135%145E1#5"%45U195"-4,E2"5)14=U1Q5&14
MFE2;5(14=E1F5)U4T%2M5,)4M%325*=4IE335-14<E2C5-54NU2_5,Q4V53:
M5-Q4J52J5*14W53/5-Y4&U7G5"!5_5045?-4(E4C50]5$54G52I59U6/5;55
M255M54%5554_55!5/%4W5595=55V57=5,U4P55Q5BU7258-5L56Y58A5@56?
M57Y5UE6157M5WU6]5;Y5E%695>I5]U7)51]6T57K5>Q5U%7F5=U5Q%7O5>55
M\E7S5<Q5S57H5?55Y%64CQY6"%8,5@%6)%8C5OY5`%8G5BU66%8Y5E=6+%9-
M5F)6659<5DQ65%:&5F16<59K5GM6?%:%5I-6KU;45M=6W5;A5O56ZU;Y5O]6
M!%<*5PE7'%</7AE>%%X17C%>.UX\7C=>1%Y47EM>7EYA7HQ<>ER-7)!<EER(
M7)A<F5R17)I<G%RU7*)<O5RL7*M<L5RC7,%<MUS$7-)<Y%S+7.5<`ET#72==
M)ETN721='ET&71M=6%T^731=/5UL75M=;UU=76M=2UU*76E==%V"79E=G5US
MC+==Q5US7W=?@E^'7XE?C%^57YE?G%^H7ZU?M5^\7V*(85^M<K!RM'*W<KAR
MPW+!<LYRS7+2<NAR[W+I<O)R]'+W<@%S\W(#<_IR^W(7<Q-S(7,*<QYS'7,5
M<R)S.7,E<RQS.',Q<U!S37-7<V!S;'-O<WYS&X(E6>>8)%D"66.99YEHF6F9
M:IEKF6R9=)EWF7V9@)F$F8>9BIF-F9"9D9F3F929E9F`7I%>BUZ67J5>H%ZY
M7K5>OEZS7E.-TE[17MM>Z%[J7KJ!Q%_)7]9?SU\#8.Y?!&#A7^1?_E\%8`9@
MZE_M7_A?&6`U8"9@&V`/8`U@*6`K8`I@/V`A8'A@>6![8'I@0F!J8'U@EF":
M8*U@G6"#8))@C&";8.Q@NV"Q8-U@V&#&8-I@M&`@829A%6$C8?1@`&$.82MA
M2F%U8:QAE&&G8;=AU&'U8=U?LY;IE>N5\97SE?65]I7\E?Z5`Y8$E@:6")8*
ME@N6#)8-E@^6$I85EA:6%Y89EAJ6+$X_<A5B-6Q4;%QL2FRC;(5LD&R4;(QL
M:&QI;'1L=FR&;*ELT&S4;*UL]VSX;/%LUVRR;.!LUFSZ;.ML[FRQ;--L[VS^
M;#EM)VT,;4-M2&T';01M&6T.;2MM36TN;35M&FU/;5)M5&TS;9%M;VV>;:!M
M7FV3;91M7&U@;7QM8VT:;L=MQ6W>;0YNOVW@;1%NYFW=;=EM%FZK;0QNKFTK
M;FYN3FYK;K)N7VZ&;E-N5&XR;B5N1&[?;K%NF&[@;BUOXFZE;J=NO6Z[;K=N
MUVZT;L]NCV[";I]N8F]&;T=O)&\5;_EN+V\V;TMO=&\J;PEO*6^);XUOC&]X
M;W)O?&]Z;]%OR6^G;[EOMF_";^%O[F_>;^!O[V\:<"-P&W`Y<#5P3W!><(!;
MA%N56Y-;I5NX6R]UGIHT9.1;[ELPB?!;1XX'B[:/TX_5C^6/[H_DC^F/YH_S
MC^B/!9`$D`N0)I`1D`V0%I`AD#60-I`MD"^01)!1D%*04)!HD%B08I!;D+EF
M=)!]D(*0B)"#D(N04%]77U9?6%\[7*M44%Q97'%;8UQF7+Q_*E\I7RU?=((\
M7SN;;ER!68-9C5FI6:I9HUF76<I9JUF>6:19TEFR6:]9UUF^605:!EK=60A:
MXUG86?E9#%H)6C):-%H16B-:$UI`6F=:2EI56CQ:8EIU6NR`JEJ;6G=:>EJ^
M6NM:LEK26M1:N%K@6N-:\5K66N9:V%K<6@E;%UL66S);-UM`6Q5<'%Q:6V5;
M<UM16U-;8EMUFG>:>)IZFG^:?9J`FH&:A9J(FHJ:D)J2FI.:EIJ8FIN:G)J=
MFI^:H)JBFJ.:I9JGFI]^H7ZC?J5^J'ZI?JU^L'Z^?L!^P7["?LE^RW[,?M!^
MU'[7?MM^X'[A?NA^ZW[N?N]^\7[R?@U_]G[Z?OM^_GX!?P)_`W\'?PA_"W\,
M?P]_$7\2?Q=_&7\<?QM_'W\A?R)_(W\D?R5_)G\G?RI_*W\L?RU_+W\P?S%_
M,G\S?S5_>EY_==M=/G65D(YSD7.N<Z)SGW//<\)ST7.W<[-SP'/)<\ASY7/9
M<WR8"G3I<^=SWG.Z<_)S#W0J=%MT)G0E="AT,'0N="QT&W0:=$%T7'17=%5T
M671W=&UT?G2<=(YT@'2!=(=TBW2>=*ATJ720=*=TTG2Z=.J7ZY?LETQG4V=>
M9TAG:6>E9X=G:F=S9YAGIV=U9ZAGGF>M9XMG=V=\9_!G"6C89PIHZ6>P9PQH
MV6>U9]IGLV?=9P!HPV>X9^)G#FC!9_UG,F@S:&!H86A.:&)H1&AD:(-H'6A5
M:&9H06AG:$!H/FA*:$EH*6BU:(]H=&AW:)-H:VC":&YI_&@?:2!I^6@D:?!H
M"VD!:5=IXV@0:7%I.6E@:4)I76F$:6MI@&F8:7AI-&G,:8=IB&G.:8EI9FEC
M:7EIFVFG:;MIJVFM:=1IL6G!:<IIWVF5:>!IC6G_:2]J[6D7:AAJ96KR:41J
M/FJ@:E!J6VHU:HYJ>6H]:BAJ6&I\:I%JD&JI:I=JJVHW<U)S@6N":X=KA&N2
M:Y-KC6N::YMKH6NJ:VN/;8]QCW*/<X]UCW:/>(]WCWF/>H]\CWZ/@8^"CX2/
MAX^+CXV/CH^/CYB/FH_.C@MB%V(;8A]B(F(A8B5B)&(L8N>![W3T=/]T#W41
M=1-U-&7N9>]E\&4*9AEF<F<#9A5F`&:%</=F'68T9C%F-F8U9@:`7V949D%F
M3V969F%F5V9W9H1FC&:G9IUFOF;;9MQFYF;I9C*-,XTVC3N-/8U`C46-1HU(
MC4F-1XU-C56-68W'B<J)RXG,B<Z)SXG0B=&);G*?<EUR9G)O<GYR?W*$<HMR
MC7*/<I)R"&,R8[!C/V389`2`ZFOS:_UK]6OY:P5L!VP&;`UL%6P8;!EL&FPA
M;"EL)&PJ;#)L-65596ME37)2<E9R,')BAA92GX"<@).`O(`*9[V`L8"K@*V`
MM("W@.>`Z(#I@.J`VX#"@,2`V8#-@->`$&?=@.N`\8#T@.V`#8$.@?*`_(`5
M9Q*!6HPV@1Z!+($8@3*!2(%,@5.!=(%9@5J!<8%@@6F!?(%]@6V!9X%-6+5:
MB(&"@9&!U6ZC@:J!S($F9\J!NX'!@::!)&LW:SEK0VM&:UEKT9C2F-.8U9C9
MF-J8LVM`7\)K\XF095&?DV6\9<9EQ&7#9<QESF729=9E@'"<<)9PG7"[<,!P
MMW"K<+%PZ'#*<!!Q$W$6<2]Q,7%S<5QQ:'%%<7)Q2G%X<7IQF'&S<;5QJ'&@
M<>!QU''G<?EQ'7(H<FQP&'%F<;EQ/F(]8D-B2&))8CMY0'E&>4EY6WE<>5-Y
M6GEB>5=Y8'EO>6=Y>GF%>8IYFGFG>;-YT5_07SQ@76!:8&=@06!98&-@JV`&
M80UA76&I89UARV'1809B@(!_@)-L]FS\;?9W^'<`>`EX%W@8>!%XJV4M>!QX
M'7@Y>#IX.W@?>#QX)7@L>"-X*7A.>&UX5GA7>"9X4'A'>$QX:GB;>)-XFGB'
M>)QXH7BC>+)XN7BE>-1XV7C)>.QX\G@%>?1X$WDD>1YY-'F;G_F>^Y[\GO%V
M!'<-=_EV!W<(=QIW(G<9=RUW)G<U=SAW4'=1=T=W0W=:=VAW8G=E=W]WC7=]
M=X!WC'>1=Y]WH'>P=[5WO7<Z=4!U3G5+=4AU6W5R=7EU@W58?V%_7W](BFA_
M=']Q?WE_@7]^?\UVY78RB(64AI2'E(N4BI2,E(V4CY20E)24EY25E)J4FY2<
ME*.4I)2KE*J4K92LE*^4L)2RE+24MI2WE+B4N92ZE+R4O92_E,24R)3)E,J4
MRY3,E,V4SI30E-&4TI35E-:4UY39E-B4VY3>E-^4X)3BE.24Y93GE.B4ZI3I
ME.N4[I3OE/.4])3UE/>4^93\E/V4_Y0#E0*5!I4'E0F5"I4-E0Z5#Y42E1.5
M%)45E1:5&)4;E1V5'I4?E2*5*I4KE2F5+)4QE3*5-)4VE3>5.)4\E3Z5/Y5"
ME3651)5%E4:5295,E4Z53Y52E5.55)56E5>56)59E5N57I5?E5V5895BE625
M995FE6>5:)5IE6J5:Y5LE6^5<95RE7.5.I7G=^QWR9;5>>UYXWGK>09Z1UT#
M>@)Z'GH4>CEZ-WI1>L^>I9EP>HAVCG:3=IEVI';>=.!T+'4@GB*>*)XIGBJ>
M*YXLGC*>,9XVGCB>-YXYGCJ>/IY!GD*>1)Y&GD>>2)Y)GDN>3)Y.GE&>59Y7
MGEJ>6YY<GEZ>8YYFGF>>:)YIGFJ>:YYLGG&>;9YSGI)UE'66=:!UG76L=:-U
MLW6T=;AUQ'6Q=;!UPW7"==9US77C=>AUYG7D=>MUYW4#=O%U_'7_=1!V`'8%
M=@QV%W8*=B5V&'85=AEV&W8\=B)V('9`=BUV,'8_=C5V0W8^=C-V379>=E1V
M7'96=FMV;W;*?^9Z>'IY>H!ZAGJ(>I5ZIGJ@>JQZJ'JM>K-Z9(AIB'*(?8A_
MB(*(HHC&B+>(O(C)B.*(SHCCB.6(\8@:B?R(Z(C^B/"((8D9B1.)&XD*B32)
M*XDVB4&)9HE[B8MUY8"R=K1VW'<2@!2`%H`<@""`(H`E@":`)X`I@"B`,8`+
M@#6`0X!&@$V`4H!I@'&`@XEXF("8@YB)F(R8C9B/F)28FIB;F)Z8GYBAF**8
MI9BFF$V&5(9LAFZ&?X9ZAGR&>X:HAHV&BX:LAIV&IX:CAJJ&DX:IAK:&Q(:U
MALZ&L(:ZAK&&KX;)AL^&M(;IAO&&\H;MAO.&T(83A]Z&](;?AMB&T88#AP>'
M^(8(APJ'#8<)AR.'.X<>AR6'+H<:ASZ'2(<TAS&'*8<WAS^'@H<BAWV'?H=[
MAV"'<(=,AVZ'BX=3AV.'?(=DAUF'98>3AZ^'J(?2A\:'B(>%AZV'EX>#AZN'
MY8>LA[6'LX?+A].'O8?1A\"'RH?;A^J'X(?NAQ:($XC^APJ(&X@AB#F(/(@V
M?T)_1']%?Q""^GK]>@A[`WL$>Q5["GLK>P][1WLX>RI[&7LN>S%[('LE>R1[
M,WL^>QY[6'M:>T5[=7M,>UU[8'MN>WM[8GMR>W%[D'NF>Z=[N'NL>YU[J'N%
M>ZI[G'NB>ZM[M'O1>\%[S'O=>]I[Y7OF>^I[#'S^>_Q[#WP6?`M\'WPJ?"9\
M.'Q!?$!\_H$!@@*"!(+L@42((8(B@B."+8(O@BB"*X(X@CN",X(T@CZ"1())
M@DN"3X):@E^":()^B(6(B(C8B-^(7HF=?Y]_IW^O?[!_LG]\?$EED7R=?)Q\
MGGRB?+)\O'R]?,%\QWS,?,U\R'S%?-=\Z'QN@JAFOW_.?]5_Y7_A?^9_Z7_N
M?_-_^'QW?:9]KGU'?IM^N)ZTGG.-A(V4C9&-L8UGC6V-1XQ)C$J14)%.D4^1
M9)%BD6&1<)%ID6^1?9%^D7*1=)%YD8R1A9&0D8V1D9&BD:.1JI&MD:Z1KY&U
MD;21NI%5C'Z>N(WKC06.68YICK6-OXV\C;J-Q(W6C=>-VHW>C<Z-SXW;C<:-
M[(WWC?B-XXWYC?N-Y(T)COV-%(X=CA^.+(XNCB..+XXZCD"..8XUCCV.,8Y)
MCD&.0HY1CE*.2HYPCG:.?(YOCG2.A8Z/CI2.D(Z<CIZ.>(R"C(J,A8R8C)2,
MFV76B=Z)VHG<B>6)ZXGOB3Z*)HM3E^F6\Y;OE@:7`9<(EP^7#I<JERV7,)<^
MEX"?@Y^%GX:?AY^(GXF?BI^,G_Z>"Y\-G[F6O):]ELZ6TI:_=^"6CI*NDLB2
M/I-JD\J3CY,^E&N4?YR"G(6<AIR'G(B<(WJ+G(Z<D)R1G)*<E)R5G)J<FYR>
MG)^<H)RAG**<HYREG*:<IYRHG*F<JYRMG*Z<L)RQG+*<LYRTG+6<MIRWG+J<
MNYR\G+V<Q)S%G,:<QYS*G,N<S)S-G,Z<SYS0G-.<U)S5G-><V)S9G-R<W9S?
MG.*<?)>%EY&7DI>4EZ^7JY>CE[*7M)>QFK":MYI8GK::NIJ\FL&:P)K%FL*:
MRYK,FM&:19M#FT>;29M(FTV;49OHF`V9+IE5F529WYKAFN::[YKKFON:[9KY
MF@B;#YL3FQ^;(YN]GKZ>.WZ"GH>>B)Z+GI*>UI.=GI^>VY[<GMV>X)[?GN*>
MZ9[GGN6>ZI[OGB*?+)\OGSF?-Y\]GSZ?1)\`,`$P`C#[,,D"QP*H``,P!3`5
M(%[_%B`F(!@@&2`<(!T@%#`5,`@P"3`*,`LP##`-,`XP#S`6,!<P$#`1,+$`
MUP#W`#8B)R(H(A$B#R(J(BDB""(W(AHBI2(E(B`B$B.9(BLB+B)A(DPB2"(]
M(ATB8")N(F\B9")E(AXB-2(T(D(F0":P`#(@,R`#(03_I`#@_^'_,""G`!8A
M!B8%)LLESR7.)<<EQB6A):`ELR6R)3L@DB&0(9$ADR$3,/W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W_B"2))(HDBR2,)(TDCB2/))`DD222)),D
ME"25))8DER28))DDFB2;)'0D=21V)'<D>"1Y)'HD>R1\)'TD?B1_)(`D@22"
M)(,DA"2%)(8DAR1@)&$D8B1C)&0D921F)&<D:"1I)/W__?\@,B$R(C(C,B0R
M)3(F,B<R*#(I,OW__?]@(6$A8B%C(60A92%F(6<A:"%I(6HA:R']__W_`?\"
M_P/_Y?\%_P;_!_\(_PG_"O\+_PS_#?\._P__$/\1_Q+_$_\4_Q7_%O\7_QC_
M&?\:_QO_'/\=_Q[_'_\@_R'_(O\C_R3_)?\F_R?_*/\I_RK_*_\L_RW_+O\O
M_S#_,?\R_S/_-/\U_S;_-_\X_SG_.O\[_SS_/?\^_S__0/]!_T+_0_]$_T7_
M1O]'_TC_2?]*_TO_3/]-_T[_3_]0_U'_4O]3_U3_5?]6_U?_6/]9_UK_6_]<
M_UW_X_]!,$(P0S!$,$4P1C!',$@P23!*,$LP3#!-,$XP3S!0,%$P4C!3,%0P
M53!6,%<P6#!9,%HP6S!<,%TP7C!?,&`P83!B,&,P9#!E,&8P9S!H,&DP:C!K
M,&PP;3!N,&\P<#!Q,'(P<S!T,'4P=C!W,'@P>3!Z,'LP?#!],'XP?S"`,($P
M@C"#,(0PA3"&,(<PB#"),(HPBS",,(TPCC"/,)`PD3"2,),P_?_]__W__?_]
M__W__?_]__W__?_]_Z$PHC"C,*0PI3"F,*<PJ#"I,*HPJS"L,*TPKC"O,+`P
ML3"R,+,PM#"U,+8PMS"X,+DPNC"[,+PPO3"^,+\PP##!,,(PPS#$,,4PQC#'
M,,@PR3#*,,LPS##-,,XPSS#0,-$PTC#3,-0PU3#6,-<PV##9,-HPVS#<,-TP
MWC#?,.`PX3#B,.,PY##E,.8PYS#H,.DPZC#K,.PP[3#N,.\P\##Q,/(P\S#T
M,/4P]C#]__W__?_]__W__?_]__W_D0.2`Y,#E`.5`Y8#EP.8`YD#F@.;`YP#
MG0.>`Y\#H`.A`Z,#I`.E`Z8#IP.H`ZD#_?_]__W__?_]__W__?_]_[$#L@.S
M`[0#M0.V`[<#N`.Y`[H#NP.\`[T#O@._`\`#P0/#`\0#Q0/&`\<#R`/)`_W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?\0!!$$$@03!!0$%00!!!8$
M%P08!!D$&@0;!!P$'00>!!\$(`0A!"($(P0D!"4$)@0G!"@$*00J!"L$+`0M
M!"X$+P3]__W__?_]__W__?_]__W__?_]__W__?_]__W__?\P!#$$,@0S!#0$
M-011!#8$-P0X!#D$.@0[!#P$/00^!#\$0`1!!$($0P1$!$4$1@1'!$@$201*
M!$L$3`1-!$X$3P3]__W__?_]__W__?_]__W__?_]__W__?_]_P$!X0#.`>``
M$P'I`!L!Z``K`>T`T`'L`$T!\P#2`?(`:P'Z`-0!^0#6`=@!V@'<`?P`Z@#]
M__W__?_]__W__?_]__W__?_]_P4Q!C$',0@Q"3$*,0LQ##$-,0XQ#S$0,1$Q
M$C$3,10Q%3$6,1<Q&#$9,1HQ&S$<,1TQ'C$?,2`Q(3$B,2,Q)#$E,28Q)S$H
M,2DQ_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W_`"4!)0(E`R4$)04E!B4')0@E"24*)0LE#"4-)0XE#R40)1$E$B43
M)10E%246)1<E&"49)1HE&R4<)1TE'B4?)2`E(24B)2,E)"4E)28E)R4H)2DE
M*B4K)2PE+24N)2\E,"4Q)3(E,R4T)34E-B4W)3@E.24Z)3LE/"4])3XE/R5`
M)4$E0B5#)40E125&)4<E2"5))4HE2R4``$(B<")#(FTB;")N(C0B,2)K(D0B
M(BHA*B0J*BHC*BDJ(2DN*C(J,2HT*C,J0"H_*D(J02I0*E(J42I4*E@J4RHL
M*6,J8BIE*F0J<BHP*4XI(BLA*R0K*BLC*RDK02DN*S(K,2LT*S,K0"L_*T(K
M02M#*5`K4BM1*U0K6"M3*TPI8RMB*V4K9"MR*U`I<RLG*B<K)2HE*R@J*"LK
M*BLK+"HL*R\J+RLM*BTK,"HP*R(I0BDW*C<K-BHV*S@J."LU*C4K.BHZ*SLJ
M.RL]*CTK/"H^*CXK)"E$*4<J1RM%*D4K1BI&*T0J12DF*48I2"I(*TDJ22M'
M*4HJ2BM,*DPK2RI+*RDI22DH*4@I32I-*T\J3RM.*DXK2BDK*4LI5RI7*U8J
M5BLM*4TI62I9*ULJ6RM:*EHK7"I<*UTJ72M?*E\K7BI>*V$J82M@*F`K+RE/
M*6PJ;"MI*FDK9BIF*VLJ:RMH*F@K:BIJ*W$J<2MT*G0K<RIU*G4K=RIW*W8J
M=BLF*B8K0RI#*U4J52MG*F<K<"IP*VTJ;2MO*F\K;BIN*SDK,"(O(C(B-B(U
M(C,B."(Y(F$F8B9C)F0F9R9I)FPF=B9E)FHF<29R)G,F="9[)G@F=29Z)G<F
M>29\)D(G0R=$)T4G1B=')T@G22=*)TLG3"=-)TXG<B=S)W0G=2=V)W<G>"=Y
M)WHG>R=\)WTG?B=Q(F\B(3`B,",P)#`E,"8P)S`H,"DP*C`K,"PP+3`N,"\P
M,#`Q,#(P,S`T,#4P-C`W,#@P.3`Z,#LP/#`],#XP/S!`,$$P0C!#,$0P13!&
M,$<P2#!),$HP2S!,,$TP3C!/,%`P43!2,%,P5#!5,%8P5S!8,%DP6C!;,%PP
M73!>,&`P83!B,&,P9#!E,&8P9S!H,&DP:C!K,&PP;3!N,&\P<#!?,'$P<C!S
M,'0P=3!V,'<P>#!Y,'HP>S!\,'TP?C`A,2(Q(S$D,24Q)C$G,2@Q*3$J,2LQ
M+#$M,2XQ+S$P,3$Q,C$S,30Q-3$V,3<Q.#$Y,3HQ.S$\,3TQ/C$_,4`Q03%"
M,4,Q1#%%,48Q1S%(,4DQ2C%+,4PQ33%.,4\Q4#%1,5(Q4S%4,54Q5C%7,5@Q
M63%:,5LQ7#%=,5XQ=C%?,6`Q83%B,6,Q9#%E,68Q9S%H,6DQ:C%K,6PQ;3%N
M,6\Q<#%Q,7(Q<S%T,74Q=S%X,7DQ>C%[,7PQ?3%^,2$R(C(C,B0R)3(F,B<R
M*#(I,BHR*S(L,BTR+C(O,C`R,3(R,C,R-#(U,C8R-S(X,CDR.C([,CPR/3(^
M,C\R0#)!,D(R0S)$,D4R43)&,D<R2#)),DHR2S),,DTR3C)/,E`R4C)3,E0R
M53)6,E<R6#)9,EHR6S)<,ETR7C)?,F`R83)B,F,R9#)E,F8R9S)H,FDR:C)K
M,FPR;3)N,F\R<#)Q,G(R<S)T,G4R=C)W,G@R>3)Z,GLR?#)],GXR(3,B,R,S
M)#,E,R8S)S,H,RDS*C,K,RPS+3,N,R\S,#,Q,S(S,S,T,S4S-C,W,S@S.3,Z
M,SLS/#,],SXS/S-`,T$S0C-#,T0S13-&,T<S2#-),THS2S-,,TTS3C-/,U`S
M43-2,U,S5#-5,U8S5S-8,UDS6C-;,UPS73->,U\S8#-A,V(S8S-D,V4S9C-G
M,V@S:3-J,VLS;#-M,VXS;S-P,W$S<C-S,W0S=3-V,W<S>#-Y,WHS>S-\,WTS
M?C,A-"(T(S0D-"4T)C0G-"@T*30J-"LT+#0M-"XT+S0P-#$T,C0S-#0T-30V
M-#@T-S0Y-#HT.S0\-#TT/C0_-$`T031"-$,T1#1%-$8T1S1(-$DT2C1+-$PT
M331.-$\T4#11-%(T4S14-%4T5C17-%@T631:-%LT7#1=-%XT7S1@-&$T8C1C
M-&0T931F-&<T:#1I-&HT:S1L-&TT;C1O-'`T<31R-',T=#1U-'8T=S1X-'DT
M>C1[-'PT?31^-"$U(C4C-20U)34F-2<U*#4I-2HU*S4L-2TU+C4O-3`U,34R
M-3,U-#4U-38U-S4X-3DU.C4[-3PU/34^-3\U0#5!-4(U0S5$-44U1C5'-4@U
M235*-4LU3#5--4XU3S50-5$U4C53-50U5356-5<U6#59-5HU6S5<-5TU7C5?
M-6`U835B-6,U9#5E-68U9S5H-6DU:C5K-6PU;35N-6\U<#5Q-7(U<S5T-74U
M=C5W-7@U>35Z-7LU?#5]-7XU(38B-B,V)#8E-B8V)S8H-BDV*C8K-BPV+38N
M-B\V,#8Q-C(V,S8T-C4V-C8W-C@V.38Z-CLV/#8]-CXV/S9`-D$V0C9#-D0V
M139&-D<V2#9)-DHV2S9,-DTV3C9/-E`V4392-E,V5#95-E8V5S98-EDV6C9;
M-EPV739>-E\V8#9A-F(V8S9D-F4V9C9G-F@V:39J-FLV;#9M-G`V<39N-F\V
M<C9S-G0V=39V-G<V>#9Y-GHV>S9]-GXV?#8A-R(W(S<D-R4W)C<G-R@W*3<J
M-RLW+#<M-RXW+S<P-S$W,C<S-S0W-3<V-S<W.#<Y-SHW.S<\-STW/C<_-T`W
M03="-T,W1#=%-T8W1S=(-TDW2C=+-TPW33=.-T\W4#=1-U(W4S=4-U4W5C=7
M-V`W6#=9-UHW6S=<-UTW7C=?-V$W8C=C-V0W93=F-V<W:#=I-VHW:S=L-VTW
M?C=N-V\W<#=Q-W(W<S=T-W4W=C=W-W@W>3=Z-WLW?#=]-R$X(C@C."0X)3@F
M."<X*#@I."HX*S@L."TX+C@O.#`X,3@R.#,X-#@U.#8X-S@X.#DX.C@[.#PX
M/3@^.#\X0#A!.$(X0SA$.$4X1CA'.$@X23A*.$LX3#A-.$XX4#A1.$\X4CA3
M.%0X53A6.%<X6#A9.%HX6SA<.%TX7CA?.&`X83AB.&,X9#AE.&<X:#AI.&HX
M:SAL.&TX;CAO.'`X<3AR.',X=#AU.'8X=SAX.'DX>CA[.'PX?3A^."$Y(CDC
M.20Y)3DF.2<Y*#DI.2HY*SDL.2TY+CDO.3`Y,3DR.3,Y-#DU.38Y-SDX.3DY
M.CD[.3PY/3D^.3\Y0#E!.4(Y0SE$.44Y1CE'.4@Y23E*.4LY3#E-.4XY3SE0
M.5$Y4CE3.50Y53E6.5<Y6#E9.5HY6SE<.5TY7CE?.6`Y83EB.6,Y9#EE.68Y
M9SEH.6DY:CEK.6PY;3EN.6\Y<#EQ.7(Y<SET.74Y=CEW.7@Y>3EZ.7LY?#E]
M.7XY(3HB.B,Z)#HE.B8Z)SHH.BDZ*CHK.BPZ+3HN.B\Z,#HQ.C,Z-#HU.C8Z
M-SHX.C(Z.3HZ.CLZ/#H].CXZ/SI`.D$Z0CI#.D0Z13I&.D<Z2#I).DHZ2SI,
M.DTZ3CI/.E`Z43I2.E,Z5#I5.E8Z5SI8.EDZ6CI;.EPZ73I>.E\Z8#IA.F(Z
M8SID.F4Z9CIG.F@Z:3IJ.FLZ;#IM.FXZ;SIP.G$Z<CIS.G0Z=3IV.G<Z>#IY
M.GHZ>SI\.GTZ?CHA.R([(SLD.R4[)CLG.R@[*3LJ.RL[+#LM.RX[+SLP.S$[
M,CLS.S0[-3LV.S<[.#LY.SH[.SL].SP[/CL_.T`[03M".T,[1#M%.T<[2#M)
M.TH[1CM+.TP[33M..T\[4#M1.U([4SM7.U4[5#M6.U@[63M:.UL[7#M=.UX[
M7SM@.V$[8CMC.V0[93MF.V<[:#MI.VH[:SML.VT[;CMO.W`[<3MR.W1F<SMT
M.W4[=CMW.W@[>CMY.WL[?#M].WX[(3PB/",\)#PE/"8\)SPH/"D\*CPK/"P\
M+CPM/"\\,#PQ/#0\,CPS/#4\-CPW/#@\.3PZ/#L\/#P]/#X\/SQ`/$$\0CQ#
M/$0\13Q&/$<\2#Q)/$H\2SQ,/$T\3CQ//%`\4CQ1/%,\5#Q5/%8\5SQ8/%D\
M6CQ;/%P\73Q>/%\\8#QA/&(\8SQD/&4\9CQG/&@\:3QJ/&L\;#QM/&X\;SQP
M/'$\<CQS/'0\=3QV/'<\>#QY/'H\>SQ\/'T\?CPA/2(](STD/24])CTG/2@]
M*3TJ/2L]+#TM/2X]+STR/3`],3TS/30]-3TV/3<].#TY/3H].ST\/3T]/CT_
M/4`]03U"/4,]1#U%/48]1SU(/4D]2CU+/4P]33U./4\]4#U1/5(]4SU4/54]
M5CU7/5@]63U:/5L]7#U=/5X]7SU@/6$]8CUC/60]93UF/6<]:#UI/6H]:SUL
M/6T];CUO/7`]<3UR/7,]=#UU/78]=SUX/7D]>CU[/7P]?3U^/2$^(CXC/B0^
M)3XF/B<^*#XI/BH^*SXL/BT^+CXO/C`^,3XR/C,^-#XU/C8^-SXX/CD^.CX[
M/CP^/3X^/C\^0#Y!/D(^0SY$/D4^1CY'/D@^23Y*/DL^3#Y-/DX^3SY0/E$^
M4CY3/E0^53Y6/E<^6#Y9/EH^6SY</ET^7CY?/F`^83YB/F,^9#YE/F8^9SYH
M/FD^:CYK/FP^;3YN/F\^<#YQ/G(^<SYT/G4^=CYW/G@^>3YZ/GL^?CY\/GT^
M(3\B/R,_)#\E/R8_)S\H/RD_*C\K/RP_+3\N/R\_,#\Q/S(_,S\T/S4_-C\W
M/S@_.3\Z/SL_/#\]/SX_/S]`/T$_0C]#/T0_13]&/T<_2#])/TH_2S],/TT_
M3C]//U`_43]2/U,_5#]5/U8_5S]8/UD_6C];/UP_73]>/U\_8#]A/V(_8S]D
M/V4_9C]G/V@_:3]J/VL_;#]M/VX_;S]P/W$_<C]S/W0_=3]V/W<_>#]Y/WH_
M>S]\/WT_?C\A0")`(T`D0"5`)D`G0"A`*4`J0"M`+$`M0"Y`+T`P0#%`,D`S
M0#1`-4`V0#=`.$`Y0#I`.T`\0#U`/D`_0$!`04!"0$-`1$!%0$9`1T!(0$E`
M2D!+0$Q`34!.0$]`4$!10%)`4T!40%5`5D!70%A`64!:0%M`7$!=0%Y`7T!@
M0&%`8D!C0&1`94!F0&=`:$!I0&I`:T!L0&U`;D!O0'!`<4!R0'-`=$!U0'9`
M=T!X0'E`>D![0'Q`?4!^0"%!(D$C021!)4$F02=!*$$I02I!*T$L02U!+D$O
M03!!,4$R03-!-$$U039!-T$X03E!.D$[03Q!/4$^03]!0$%!04)!0T%$045!
M1D%'04A!24%*04M!3$%-04Y!3T%005%!4D%3051!54%605=!6$%905I!6T%<
M05U!7D%?06!!84%B06-!9$%E069!9T%H06E!:D%K06Q!;4%N06]!<$%Q07)!
M<T%T075!=D%W07A!>4%Z07M!?$%]07Y!(4(B0B-")$(E0B9")T(H0BE"*D(K
M0BQ"+4(N0C!"+T(Q0C)",T(T0C5"-T(V0CA".4(Z0CM"/$(]0CY"0$)!0D)"
M1$)%0D="2$))0DI"3$)#0D9"2T)-0DY"3T)00E%"4D)30E1"54)60E="6$)9
M0EI"6T)<0EU"7D)?0F!"84)B0F-"9$)E0F9"9T)H0FE":D)K0FQ";4(_0FY"
M;T)P0G%"<D)S0G1"=4)V0G=">$)Y0GI">T)\0GU"?D(A0R)#(T,D0R5#)D,G
M0RA#*4,J0RM#+$,M0RY#+T,P0S%#,D,S0S1#-4,V0S=#.4,Z0SM#/$,]0SY#
M/T-`0T%#0D-#0T1#14-&0T=#2$,X0TI#2T-,0TU#3T-.0U!#44-20U-#5$-5
M0U9#5T-80UE#6D-;0TE#7$-=0UY#7T-@0V%#8D-C0V1#94-F0V=#:$-I0VI#
M:T-L0VU#;D-O0W!#<4-R0W-#=$-U0W9#=T-X0WE#>D-[0WQ#?4-^0R%$(D0C
M1"1$)40F1"=$*$0I1"I$*T0L1"U$+D0O1#!$,40R1#-$-$0U1#9$-T0X1#E$
M.D0[1#Q$/40^1#]$0$1!1$)$0T1$1$5$1D1'1$A$241*1$M$3$1-1$Y$3T10
M1%%$4D131%1$54161%=$6$191%I$6T1<1%U$7D1?1&!$841B1&-$9$1E1&9$
M9T1H1&E$:D1K1&Q$;41N1&]$<$1Q1')$<T1T1'5$=D1W1'A$>41Z1'M$?$1]
M1'Y$(44B12-%)$4E129%)T4H12E%*D4K12Q%+44N12]%,$4Q13)%,T4T135%
M-D4W13A%.44Z13M%/$4]13Y%/T5`14%%0D5#141%145&14=%2$5)14I%2T5-
M14Q%3D5/15!%445215-%5$55159%5T5815E%6D5;15Q%745>15]%8$5A16)%
M8T5D165%9D5G16A%:45J16M%;$5M16Y%;T5P17%%<D5S171%=45V17=%>$5Y
M17I%>T5\17U%?D4A1B)&(T8D1B5&)D8G1BA&*48J1BM&+$8M1BY&+T8P1C%&
M,D8S1C1&-48V1C=&.$8Y1CI&.T8\1CU&/D8_1D!&049"1D-&1$9%1D9&1T9(
M1DE&2D9+1DQ&349.1D]&4$911E)&4T941E5&5D971EA&649:1EM&7$9=1EY&
M7T9@1C9'849B1F-&9$9E1F9&9T9H1FE&:D9K1FQ&;49N1F]&<$9Q1G)&<T9T
M1G5&=D9W1GA&>49Z1GM&?$9]1GY&(4<B1R-')$<E1R9')T<H1RE'*D<K1RQ'
M+4<N1R]',$<Q1S)',T<T1S5'-T<X1SE'.D<[1SQ'/4<^1S]'0$=!1T)'0T=$
M1T5'1D='1TA'24=*1TM'3$=-1TY'3T=01U%'4D=31U1'54=61U='6$=91UI'
M6T=<1UU'7D=?1V!'84=B1V-'9$=E1V9'9T=H1VE':D=K1VQ';4=N1V]'<$=Q
M1W)'<T=T1W5'=D=W1WA'>4=Z1WM'?$=]1WY'(4@B2"-()$@E2"9()T@H2"E(
M*D@K2"Q(+4@N2"](,$@Q2#)(,T@T2#5(-D@W2#A(.4@Z2#M(/$@]2#Y(/TA`
M2$%(0DA#2$1(14A&2$=(2$A)2$I(2TA,2%-(34A.2$](4$A12%)(5$A52%9(
M5TA82%E(6DA;2%Q(74A>2%](8$AA2&)(8TAD2&5(9DAG2&A(:4AJ2&M(;$AM
M2&Y(;TAP2'%(<DAS2'1(=4AV2'=(>$AY2'I(>TA\2'U(?D@A22))(TDD225)
M)DDG22A)*4DJ22M)+$DM22Y)+TDP23%),DDS231)-4DV23=).$DY23I).TD\
M24%)/4D^23])0$E"24-)1$E%249)1TE(24E)2DE+24Q)34E.24])4$E125))
M4TE4255)5DE725A)64E:25M)7$E=25Y)7TE@26%)8DEC261)94EF26=):$EI
M26I):TEL26U);DEO27!)<4ER27-)=$EU279)=TEX27E)>DE[27Q)?4E^22%*
M(DHC2B1*)4HF2B=**$HI2BI**THL2BU*+DHO2C!*,4HR2C-*-$HU2C9*-THX
M2CE*.DH[2CQ*/4H^2C]*0$I!2D)*0TI$2D5*1DI'2DA*24I*2DM*3$I-2DY*
M3TI02E%*4DI32E1*54I62E=*6$I92EI*6TI<2EU*7DI?2F!*84IB2F-*9$IE
M2F9*9TIH2FE*:DIK2FQ*;4IN2F]*<$IQ2G)*<TIT2G5*=DIW2GA*>4IZ2GM*
M?$I]2GY*(4LB2R-+)$LE2R9+)TLH2RE+*DLK2RQ++4LN2R]+,$LQ2S)+,TLT
M2S5+-DLW2SA+.4LZ2SM+/$L]2SY+/TM`2T%+0DM#2T1+14M&2T=+2$M)2TI+
M2TM,2TU+3DM/2U!+44M22U-+5$M52U9+5TM82UE+6DM;2UQ+74M>2U]+8$MA
M2V)+8TMD2V5+9DMG2VA+:4MJ2VM+;$MM2VY+;TMP2W%+<DMS2W1+=4MV2W=+
M>$MY2WI+>TM\2WU+?DLA3"),(TPD3"5,)DPG3"A,*4PJ3"M,+$PM3"Y,+TPP
M3#%,,DPS3#1,-4PV3#=,.$PY3#I,.TP\3#U,/DP_3$!,04Q"3$-,1$Q%3$9,
M1TQ(3$E,2DQ+3$Q,34Q.3$],4$Q13%),4TQ43%5,5DQ73%A,64Q:3%M,7$Q=
M3%Y,7TQ@3&%,8DQC3&1,94QF3&=,:$QI3&I,:TQL3&U,;DQO3'!,<4QR3'-,
M=$QU3'9,=TQX3'E,>DQ[3'Q,?4Q^3"%-(DTC321-)4TF32=-*$TI32I-*TTL
M32U-+DTO33!-,4TR33---$TU339--TTX33E-.DT[33Q-/4T^33]-0$U!34)-
M0TU$345-1DU'34A-24U*34M-3$U-34Y-3TU035%-4DU3351-54U635=-6$U9
M35I-6TU<35U-7DU?36!-84UB36--9$UE369-9TUH36E-:DUK36Q-;4UN36]-
M<$UQ37)-<TUT375-=DUW37A->4UZ37M-?$U]37Y-(4XB3B1.)4XF3B=.*$XI
M3B-.*DXK3BQ.+4XN3B].,$XQ3C).,TXT3C5.-DXW3CA..4XZ3CM./$X]3CY.
M/TY`3D%.0DY#3D1.14Y&3D=.2$Y)3DI.2TY,3DU.3DY/3E!.44Y23E-.5$Y5
M3E9.5TY83EE.6DY;3EQ.74Y>3E].8$YA3F).8TYD3F5.9DYG3FA.:4YJ3FM.
M;$YM3FY.;TYP3G%.<DYS3G1.=4YV3G=.>$YY3GI.>TY\3GU.?DXA3R)/(T\D
M3R5/)D\G3RA/*4\J3RM/+$\M3RY/+T\P3S%/,D\S3S1/-4\V3S=/.$\Y3SI/
M.T\\3SU//D\_3T!/04]"3T-/1$]%3T9/1T](3TE/2D]+3TQ/34].3T]/4$]1
M3U)/4T]43U5/5D]73UA/64]:3UM/7$]=3UY/7T]@3V%/8D]C3V1/94]F3V=/
M:$]I3VI/:T]L3VU/;D]O3W!/<4]R3W1/=4]V3W-/=T]X3WE/>D][3WQ/?4]^
M3R%0(E`C4"10)5`F4"=0*%`I4"I0*U`L4"Y0+U`P4#%0+5`R4#-0-%`U4#=0
M.%`Y4#I0.U`V4#Q0/5`^4#]00%!!4$)00U!$4$501E!'4$A025!*4$M03%!-
M4$Y03U!04%%04E!34%1055!64%=06%!94%I06U!<4%U07E!?4&!085!B4&-0
M9%!E4&909U!H4&E0:E!K4&Q0;5!N4&]0<%!Q4')0<U!T4'50=E!W4'A0>5!Z
M4'M0?%!]4'Y0(5$B42-1)%$E4291)U$H42E1*E$K42Q1+5$N42]1,%$Q43)1
M,U$T4351-E$W43A1.5$Z43M1/%$]43Y1/U%`44%10E%#441115%&44=12%%)
M44I12U%,44U13E%/45!145%245-15%%545915U%845E16E%;45Q175%>45]1
M8%%A46)18U%D46519E%G46A1:5%J46M1;%%M46Y1;U%P47%1<E%S4711=5%V
M47=1>%%Y47I1>U%\47U1?E$A4B)2(U(D4B52)E(G4BA2*5(J4BM2+%(M4BY2
M+U(P4C%2,E(S4C12-5(V4C=2.%(Y4CI2.U(\4CU2/E(_4D!205)"4D-21%)%
M4D921U)(4DE22E)+4DQ235).4D]24%)14E)24U)44E525E)74EA265):4EM2
M7%)=4EY27U)@4F%28E)C4F1295)F4F=2:%)I4FI2:U)L4FU2;E)O4G!2<5)R
M4G-2=%)V4G=2>%)U4GE2>E)[4GQ2?5)^4B%3(E,C4R13)5,F4R=3*%,I4RI3
M*U,L4RU3+E,O4S!3,5,R4S-3-%,U4S93-U,X4SE3.E,[4SQ3/5,^4S]30%-!
M4T)30U-$4T531E-'4TA325-*4TM33%--4TY33U-04U%34E-34U1355-64U=3
M6%-94UI36U-<4UU37E-?4V!385-B4V-39%-E4V939U-H4VE3:E-K4VQ3;5-N
M4V]3<%-Q4W)3<U-T4W53=E-W4WA3>5-Z4WM3?%-]4WY3(50B5"-4)%0E5"94
M)U0H5"E4*E0K5"Q4+50N5"]4,%0Q5#)4-%0U5#94-U0X5#E4.E0[5#Q4/50^
M5#-4/U1`5$%40E1#5$14151&5$=42%1)5$I42U1,5$U43E1/5%!445125%-4
M5%155%945U185%E46E1;5%Q4751>5%]48%1A5&)48U1D5&549E1G5&A4:51J
M5&Q4:U1M5&Y4;U1P5'%4<E1S5'14=51V5'=4>%1Y5'I4>U1\5'U4?E0A52)5
M(U4D5255)E4G52A5*54J52M5+%4M52Y5+U4P53%5,E4S5315-54V53=5.%4Y
M53I5.U4\53U5/E4_54!5055"54-51%5%54951U5(54E52E5+54Q5355.54]5
M4%5155)54U5455555E5755A5655:55M57%5=55Y57U5@56%58E5C5615955F
M56=5:%5I56I5:U5L56U5;E5O57!5<55R57-5=%5U5795=U5X57E5>E5[57Q5
M?55^52%6(E8C5B16)58F5B=6*%8I5BI6*U8L5BU6+E8O5C!6,58R5C-6-%8U
M5C96-U8X5CE6.E8[5CQ6/58^5C]60%9!5D)60U9$5D561U9(5DE62E9+5D96
M3%9-5DY63U905E%64E935E165E975EA655995EI66U9<5EU67E9?5F!6859B
M5F-69%9E5F969U9H5FE6:E9K5FQ6;59N5F]6<%9Q5G)6<U9T5G56=E9W5GA6
M>59Z5GM6?%9]5GY6(5<B5R-7)%<E5R97)U<H5RE7*E<K5RQ7+5<N5R]7,%<Q
M5S)7,U<T5S57-E<W5SA7.5<Z5SM7/%<]5SY7/U=`5T%70E=#5T1715=&5T=7
M2%=)5TI72U=,5TU73E=/5U!745=25U-75%=55U975U=85UE76E=;5UQ775=>
M5U]78%=A5V)79%=E5V979U=H5VE7:E=K5VQ7;5=N5V]7<%=Q5W)7<U=T5W57
M=E=W5WA7>5<^6&-7>E=[5WQ7?5=^5R%8(E@C6"18)5@F6"=8*%@I6"I8*U@L
M6"U8+E@O6#!8,5@R6#-83%@T6#58-E@W6#A8.5@Z6#M8/%@]6#]80%A!6$)8
M0UA$6$581EA'6$A825A*6$M835A.6$]84%A16%)84UA46%585EA76%A865A:
M6%M87%A=6%Y87UA@6&%88EAC6&1895AF6&=8:%AI6&I8:UAL6&U8;EAO6'!8
M<5AR6'-8=%AU6'98=UAX6'E8>EA[6'Q8?5A^6"%9(EDC6219)5DF62=9*%DJ
M62M9+%DM62Y9+UDP63%9,EDS6319-5DV63=9.%DY63I9.UD\62E9/5D^63]9
M0%E!64)90UE$64591EE'64A925E*64M93%E-64Y93UE065%94EE3651955E6
M65=96%E965I96UE<65U97EE?66!985EB66-99%EE6699=%EG66A9:5EJ66M9
M;%EM66Y9;UEP67%9<EES6759=EEW67A9>5EZ67M9?%E]67Y9(5HB6B-:)%HE
M6B9:)UHH6BE:*EHK6BQ:+5HN6B]:,%HQ6C):,UHT6C5:-EIF.#=:.%HY6CI:
M.UH\6CU:/EH_6D!:05I"6D-:1%I%6D9:1UI(6DE:2EI+6FU:3%I-6DY:3UI0
M6E%:4EI36E1:55I66E=:6%I96EI:6UI<6EU:7EI?6F!:85IB6F-:9%IE6F9:
M9UIH6FE::EIK6FQ:;EIO6G!:<5IR6G-:=%IU6G9:=UIX6GE:>EI[6GQ:?5I^
M6B%;(ELC6R1;)5LF6R=;*%LI6RI;*ULL6RU;+ELO6S!;,5LR6S-;-%LU6S9;
M-ULX6SE;.EL[6SQ;/5L^6S];0%M!6T);0UM$6T5;1EM'6TA;25M*6TM;3%M-
M6TY;3UM06U%;4EM36U1;55M66U=;6%M96UI;6UM<6UU;7EM?6V!;85MB6V-;
M9%ME6V9;9UMH6VE;:EMK6VQ;;5MN6W!;<5MR6W-;;UMT6W5;=EMW6WA;>5MZ
M6WM;?%M]6WY;(5PB7"-<)%PE7"9<)UPH7"E<*EPK7"Q<+5PN7"]<,%PQ7#)<
M,UPT7#5<-EPW7#A<.5PZ7#M</%P]7#Y</UQ`7$%<0EQ#7$1<15Q&7$=<2%Q)
M7$I<2UQ,7$U<3EQ/7%!<45Q27%-<5%Q57%9<5UQ87%E<6EQ;7%Q<75Q>7%]<
M8%QA7&)<8UQD7&5<9EQG7&A<:5QJ7&M<;%QM7&Y<;UQP7'%<<EQS7'1<=5QV
M7'=<>%QY7'I<>UQ\7'U<?EPA72)=(UTD725=)ETG72A=*5TJ72M=+%TM72Y=
M+UTP73%=,ETS731=-5TV73==.%TY73I=.UT\73U=/ET_74!=05U"74-=1%U%
M749=1UU(74E=2EU+74Q=35U.74]=4%U175)=4UU4755=5EU775A=65U:75M=
M7%U=75Y=7UU@76%=8EUC761=95UF76==:%UI76I=:UUL76U=;EUO77!=<5UR
M77-==%UU779==UUX77E=>EU[77Q=?5U^72%>(EXC7B1>)5XF7B=>*%XI7BI>
M*UXL7BU>+EXO7C!>,5XR7C->-%XU7C9>-UXX7CE>/UXZ7CM>/%X]7CY>0%Y!
M7D)>0UY$7D5>1EY'7DA>25Y.7DI>2UY,7DU>3UY07E%>4EY37E1>55Y67E=>
M6%Y97EI>6UY<7EU>7EY?7F!>85YB7F->9%YE7F9>9UYH7FE>:EYK7FQ>;5YN
M7F]><EYP7G%><UYT7G5>=EYW7GA>>5YZ7GM>?%Y]7GY>(5\B7R-?)%\E7R9?
M)U\H7RE?*E\K7RQ?+5\N7R]?,%\R7S%?,U\T7S5?-E\W7SA?.5\Z7SM?/%\]
M7SY?/U]`7T%?0E]#7T1?15]&7T=?2%])7TI?2U],7TU?3E]/7U!?45]27U-?
M5%]57U9?5U]87UE?6E];7UQ?75]O7UY?7U]@7V%?8E]C7V1?95]F7V=?:%]I
M7VI?:U]L7VU?;E]P7W%?<E]S7W1?=5]V7W=?>%]Y7WI?>U]\7WU??E\A8")@
M(V`D8"5@)F`G8"A@*6`J8"M@+&`M8"Y@+V`P8#%@,F`S8#1@-6`V8#=@.&`Y
M8#I@.V`\8#U@/F`_8$!@06!"8$-@1&!%8$9@1V!(8$E@2F!+8$Q@36!.8$]@
M4&!18%)@4V!48%5@5F!78%A@66!:8%M@7&!=8&1@7F!?8&!@86!B8&-@96!F
M8&=@:&!I8&I@:V!L8&U@;F!O8'!@<6!R8'-@=&!U8'9@=V!X8'E@>F![8'Q@
M?6!^8"%A(F$C821A)6$F82=A*&$I82IA*V$L82UA+F$O83!A,6$R83-A-&$U
M839A-V$X83EA.F$[83QA/6$^83]A0&%!84)A0V%$845A1F%'84AA26%*84MA
M3&%-84YA3V%085%A4F%4855A5F%385=A6&%985IA6V%<85UA7F%?86!A86%B
M86-A9&%E869A9V%H86EA:F%K86QA;6%N86]A<&%Q87)A<V%T875A=F%W87AA
M>6%Z87MA?6%^82%B(F(C8B1B?&$M8B5B)F(G8BAB*6(J8BMB+&(O8C!B,6(R
M8BYB,V(T8C5B-F(W8CAB.6(Z8CMB/&(]8CYB/V)`8D%B0F)#8D5B1F)$8D=B
M2&))8DIB2V),8DUB3F)/8E!B46)28E-B5&)58E9B5V)88EEB6F);8EQB76)>
M8E]B8&)A8F)B8V)D8F5B9F)G8FAB:6)J8FMB;&)M8FYB;V)P8G%B<F)S8G1B
M=6)V8G=B>&)Y8GIB>V)\8GUB?F(A8R)C(V,D8R5C)F,G8RAC*6,J8RMC+&,M
M8RYC+V,P8S%C,F,S8S1C-6,V8S=C.&,Y8SIC.V,\8SUC/F,_8T!C06-"8T-C
M1&-%8T9C1V-(8TEC2F-+8TQC36-.8T]C4&-18U)C4V-48U5C5F-78UAC66-:
M8UMC7&-=8UYC7V-@8V%C8F-C8V1C96-F8V=C:&-I8VIC:V-L8VUC;F-O8W!C
M<6-R8W-C=&-U8W9C=V-X8WEC>F-[8WQC?6-^8R%D(F0C9"1D)60F9"=D*&0I
M9"ID*V0L9"UD+F0O9#!D,60R9#-D-&0U9#9D-V0X9#ED.F0[9#QD/60^9#]D
M0&1!9$)D0V1$9$5D1F1'9$AD261*9$MD3&1-9$YD3V109%%D4F139%1D5616
M9%=D6&199%ID6V1<9%UD7F1?9&!D861B9&-D9&1E9&9D9V1H9&ED:F1K9&QD
M;61N9&]D<&1Q9')D<V1T9'5D=F1W9'AD>61Z9'MD?&1]9'YD(64B92-E)&4E
M929E)V4H92EE*F4K92QE+64N92]E,&4Q93)E,V4T935E.V4V93=E.&4Y93IE
M/&4]93YE/V5`94%E0F5#941E165&94=E2&5)94IE2V5,94UE3V5094YE4652
M95-E5&55959E5V5895EE6F5;95QE765>95]E8&5A96)E8V5D965E9F5H96=E
M:65J96ME;&5M96YE;V5P97%E<F5S971E=65V97=E>&5Y97IE?&5[97UE?F4A
M9B)F(V8D9B5F)F8G9BAF*68J9BMF+&8M9BYF+V8P9C%F,F8S9C1F-68V9C=F
M.&8Y9CIF.V8\9CUF/F8_9D!F069"9D-F1&9%9D9F1V9(9DEF2F9+9DQF369.
M9D]F4&919E)F4V949E5F5F979EAF669:9EMF7&9=9EYF7V9@9F%F8F9C9F1F
M969F9F=F:&9I9FIF:V9L9FUF;F9O9G!F<69R9G-F=69V9G=F>&9Y9GIF>V9\
M9GUF?F8A9R)G(V<D9R5G)F<G9RAG*6<J9RMG+&<M9RYG+V<P9S%G,F<S9S1G
M-6<V9S=G.&<Y9SIG.V<\9SUG/F<_9T!G06="9T-G1&=%9T9G1V=(9TEG2F=+
M9TQG36=.9T]G4&=19U)G4V=49U5G5F=79UAG66=:9UMG7&==9UYG7V=@9V%G
M8F=C9V1G96=F9VIG9V=H9VEG:V=L9VUG;F=O9W!G<6=R9W-G=&=V9W=G>&=Y
M9W5G>F=[9WQG?6<H:'YG(6@B:"-H)&@E:"9H)V@I:"IH*V@L:"UH+F@O:#!H
M,6@R:#-H-&@U:#9H-V@X:#EH.F@[:#QH/6@^:#]H0&A!:$)H0VA$:$5H1FA'
M:$AH26A*:$MH3&A-:$YH3VA0:%%H4FA3:%1H56A6:%=H6&A9:%IH6VA<:%UH
M7FA?:&!H86AB:&-H9&AE:&9H9VAH:&EH:FAK:&QH;6AN:&]H<&AQ:')H<VAT
M:'5H=FAW:'AH>6AZ:'MH?&A]:'YH(6DB:2-I)&DE:29I)VDH:2EI*FDK:2QI
M+6DN:2]I,&DQ:3)I,VDT:35I-FDW:3AI.6DZ:3MI/&D]:3YI/VE`:4%I0FE#
M:41I16E&:4=I2&E):4II3&E-:4MI3FE/:5!I46E2:5-I5&E5:59I5VE8:5EI
M6FE;:5QI76E>:5]I8&EA:6)I8VED:65I9FEG:6AI:6EJ:6MI;&EM:6YI;VEP
M:7%I<FES:71I=6EV:7=I>&EY:7II>VE\:7UI?FDA:B)J(VHD:B5J)FHG:BAJ
M*6HJ:BMJ+&HM:BYJ+VHP:C%J,FHS:C1J-6HV:C=J.&HY:CIJ.VH\:CUJ/FH_
M:D!J06I":D-J1&I%:D9J1VI(:DEJ2FI+:DQJ36I.:D]J4&I1:E)J4VI4:E5J
M5FI7:EAJ66I::EMJ7&I=:EYJ7VI@:F%J8FIC:F1J96IF:F=J:&II:FIJ:VIL
M:FUJ;FIO:G!J<6IR:G-J=&IU:G9J=VIX:GEJ>FI[:GQJ?6I^:B%K(FLC:R1K
M)6LF:R=K*&LI:RIK*VLL:RUK+FLO:S!K,6LR:S-K-&LU:S9K-VLX:SEK.FL[
M:SQK/6L^:S]K0&M!:T)K0VM$:T5K1FM':TAK26M0:TIK2VM,:TUK4FM.:T]K
M46M3:U1K56M6:U=K6&M9:UIK6VM<:UYK76M?:V!K86MB:V-K9&ME:V9K9VMH
M:VEK:FMK:VUK;FMO:VQK<&MQ:W)K<VMT:W9K=6MW:WAK>6MZ:WMK?&M]:WYK
M(6PB;"-L)&PE;"9L)VPH;"EL*FPK;"QL+6PN;"]L,&PQ;#)L,VPT;#5L-FPW
M;#AL.6PZ;#ML/&P];#YL/VQ`;$%L0FQ#;$1L16Q&;$=L2&Q);$IL2VQ,;$YL
M3VQ-;%!L46Q2;%-L5&Q5;%9L5VQ8;%EL6FQ;;%QL76Q>;%]L8&QA;&)L8VQD
M;&5L9FQG;&AL:6QJ;&ML;&QM;&YL;VQP;'%L<FQS;'1L=6QV;'=L>&QY;'IL
M>VQ\;'UL?FPA;2)M(VTD;25M)FTG;2AM*6TJ;2MM+&TM;2YM+VTP;3%M,FTS
M;31M-6TV;3=M.&TY;3IM.VT\;3UM/FT_;4!M06U";4-M1&U%;49M1VU(;4EM
M2FU+;4QM36U.;4]M4&U1;5)M4VU4;55M5FU7;5AM66U:;5MM7&U=;5YM7VU@
M;6%M8FUC;3<BLA<``+(7``"R%P``LA<``+(7``"R%P!````)`300#0$$@`\!
M&,D5`2$`%P&3`!L!`A0>`0@#(0$P@B4!`"`F`<`@*0$`@"H!``(K`0@`+`$!
M#"\!!X$T`2K@.@$-&4`!Y`)%`0!`1@&J2DT!!1M3`52!6`$)5%T!@F=D`396
M;`&=QG4!``!U`81Z?`%CNX8!!!"(`04`B@$%L(\!DU26`8EYG@&$0*$!+0BF
M`6=4K@&.@K0!S22[`0,`O0%:Q,0!7=C-`0>$T@$!)M8!F5#<`1FQXP%4@^D!
M1D3N`<AY]@&!>OT!B+$#`CH#"0($A`P"J($1`E``$P(`0!0"&$@8`@`A&@(*
M(!T"`-4B`@2!)0(N02L")$`N`IP`,@(F`#4";`$Z`@0!/`(F$$`"(`)"`J"5
M2`)#0$P"@`-/`B445`+H%5L"\(!@`L$M9P)1D6T"4AAR`B(7>`+3`'T""1R"
M`@K9B0*@.Y`")7"6`@08F0(`"IL"*C"@`@1"HP*(0:<"&"*K`A*,L`*T);<"
M(8"Z`BQDP`+!`,,"(`#$`@0`Q0((!,<"@H7,`C(`SP*8H-0"`$#5`M1JW0(0
M@-\"*B/E`F*0Z@+"9O$"@H[W`D!D^P(``/L"`93_`D#0`P,C<PL#(``,`P`,
M#@-D.!0#@B89`P--'P-3`",#`(`D`T;!*@.>`"\#&"`R`P2`-`-*6CL#CDE"
M`P0"1`-`@$8#(.5,`P<"4`,`$%$#J;I:`UNJ8P,00&4#3Z)M`R8`<`,P&74#
M(.9[`\`[@@.*0(8#(+Z-`P&RD@/R*9H#P@"=`X84H@,B+*<#/=:Q`QC@M@-@
M,+H#!`"[`Z3IPP.[7LX#"A#1`[#VV@."$]\#`"'A`X"1Y0,@8.@#TB+N`V'A
M]0,8,_L#`,C^`\$@`@0$@@4$`+()!"&`#`22`1`$`)$3!(.W'`11("`$1P(E
M!`80*`0482T$520S!`8"-@0(`#<$8!@[!!P@/P0:@40$:8!)!$@`2P0,ZE($
M"JA7!&0:700`6&`$I(!D!)#@:02)%&X$&B5T!`3@>`28P'T$E@"!!!%PA@0,
M0(D$F"6/!`$`D`2P$94$(4"8!*@@G`2`3*`$``BA!$G2J`2%$*P$+HVT!%"!
MN`0`%+H$(42^!&`@P00#`<0$@"K(!"(@RP00`<T$`AC0!$1`TP0`P=8$`/#:
M!%)$WP1;`.0$`+/I!(84[@0#H/($P`?W!`&`^002(/P$`!#]!(#```5(6@8%
M90`*!0``"@4`%@T%C",3!3$\&@6`A1X%!*`A!4T$)@4T!"H%``HL!80@+P4`
M0#`%%@`S!4(@-@4$`#<%V`@\!1*B005,!48%(H)*!1<D4`4!QE4%"@59!3R*
M8`6!"&,%%0-H!8A(;`4!`V\%$0)R!0`#=`6!('<%-(%\!0%!?P4D0((%``J$
M!4-9BP4`?9$%`0"2!0%(E04``)4%-!6;!0K@H`5`6*0%-E"J!2`(K`4``*P%
MQ$&Q!0`RM`4>6;P%4:C"!;$@QP41"<L%F8#0!31EUP4`HMH%0##=!928XP4#
M`>8%D`OK!1]`\04&]_H%3!3_!8`D`@:8A0@&$"`*!B@`#`:!$Q$&TB`6!H(`
M&`8"P!L&1$4@!BIA)@8T`2H&@T@O!A3/-P8P:CT&)``_!B0Q1`:$%$@&WU)2
M!@0,50;C`EL&8@)?!@!`8`8!$&(&!)EG!ALH;0:,L70&(25Y!@`3?`8'P($&
M(/"&!J:RC@8``(X&F@"2!B@0E0:-"IL&`"*=!EP0H@97%*D&$*"L!@@DKP8`
MX+(&`0"S!D`!M0;(Q+L&$$"]!F`$P`8`!,$&%##%!A@LR@9)`<X&`";1!F`2
MU09>3-T&'`GB!F`PY@8RL>T&E`3Q!C%&]P90X/P&`"#]!B)!`0<Z$`8'(10*
M!RP##P<`!A$'%4$6!S6&'0<AH"$'`(@C!QZ\+`<+(#`'&"@T!Z"`-P<#JSX'
M2A%#!PC@1P<07DT'HP!1!S`F5@>AB%L'$H=A!UC*:`=$0FP'`C1P!X@"<P<5
M@'<'@0AZ!P`D?`<B!'\')"&#!TE`AP<<@(L'!$./!U&!E`<``)0'-<*;!Q$C
MH`=F8*8'7EZP!XL"M0=A5+L'@AO!!P,<Q@>HV\\'`3C3!P6>V@<1(-T')HCB
M!PW1Z0<0B.P'`%GP!P`,\@>@0/4'"!+X!P4`^@<(0/P'H!$`"#`@`PA`4`8(
M4`@)"!+`#0A*"Q,(```3""<X&@@M`R`(A!(D"$(`)@C%`BL(```K"!"B+PB`
ML30("X@Y"#`4/0BD"4((`,A%""<>30A4`5$(0!55""I&6P@$"%T(()%A"$LR
M:`@@/6X(8SAU"$`&>`C+`'T(``!]""H)@@@D0H8(@`B("'@3CP@'C)4(`2"7
M"$0!F@ABJ:$(@!6E""`!IPC"`*H(),"N""I`L@@+@+8((B2Z"!$!O0B5R,0(
M8$;)"&<(SPB0!-(("D#5",H*VP@"Z.`(((CC"!/@Z0A`$^T(<3#S")`0]@@'
M,/L(S((!"8-(!@D0F0L)8(@/"4`D$@E$(18)@4@:"2%@'@DD`"`)@(@C"0US
M*PD!8S`)&!(T"4`$-@G*0#L)@H(_"31B10D%@DD)P%%."6B,5`D`K%@)%!I=
M"8"H80E0"V8)X`)J";"1<`D``'`)%0!S"42@=PE7%'X)@5J$"10`A@F0Q(L)
M"@2."<#!DPD"DI<)``"7"8#`F@FB@)X)`1"@"80`H@G6`:@)`!2J"9"BKPD0
MQ;0)0*BX"26"O0E1$,$)$0##"0!`Q`F$`,8)1!K+"3"+T0F><-D)#`'<"0@H
MWPD`(.`)"`+B"8%@Y@D*B.H)B^7S"0``\PD`:/8)`"KY"1`U_@E`#0(*0*8'
M"DD8#`H`@`T*CF85"@81&0H`8!L*B#DA"EV$*`KAP2\*81`S"J`%-PH`1#D*
M``,["B$R0`KA($4*@`!&"@F`20J0$DT*&$]4"C!@6`HP4%P*8$!?"F(`8@KP
M"6@*$`AJ"I,`;@H`!&\*>A%V"A``=PH`!'@*^)B`"@!`@0H!J(4*`P&("N(,
MC@J%5)0*`0&6"@`"EPJA$)L*!`R>"@6`H0H-A*8*$QBK"D@6L`H``+`*`$&R
M"H$#M@J(I+L*$(B^"A`#P0HNP,<*:53."@G)U`J"F=H*$&+>"@@(X`H`8>,*
M$D#F"H(2Z@I@@>X*(`#O"AA,]`JT*/H*#$/_"I01!`LF+`H+""`,"T7A$PO!
MVAL+@A(?"VM`)0NIT2T+92PT"Z"R.@M@FD`+3")%"\H"2@NPKE(+DP17"P(,
M6@M0_V0+`P)G"]DH;@N&('(+Q&EY"P8`>POC@H(+!Y>*"TO/E`LFBIH+`!.=
M"PG-I`L0C:D+$)RN"T``KPO$`+(+DX:Y"T#BO@N)0<,+A<#("P*`R@L"?M$+
M(@#3"RT2V0L4`-L+$(3>"U/0Y0N`D.@+D]#O"P("\0N=E?H+;'H##&@B"`PL
M%P\,.PX7#"""&@PPX!\,$@`A#"(P)0P@N"H,_24T#``@-0PB6CL,$`(]#$$1
M00Q#$D8,041*#+0640P$X58,<&)<#&3D8PS$T&D,E11O#!TD=0P1,'D,<(1^
M#(3$@PPB0(8,"`*(#";"C@Q1%),,$PF8#&!BG0P"()\,#F"D#*$`IPR84:T,
M!%"P#!M%MPP`1+D,`(2[#!#AP`P2,<4,#ZC,#(!3T0QLB-<,4P3<#,R,XPQ!
M$.8,`=3K#*$B\`PRJ/8,<(S\#!(9`0V`"@0-!%H)#0`8"PUZ&1,-`HL8#1()
M'`V4A2(-4&0G#24L+0T"$3`-C!8V#2)(.@V"J#\-,0=%#;`12@U@LE`-H215
M#2!!6`UE#%X-$T!B#0D090TH&FH-0%)N#0((<`T`&W0-$FAY#8``>@T0@'P-
MB.Z$#1.@B0V#0(T-(`".#5&FE0V,`)@-$$*;#4-(H`TAD*0-93RL#20%L`W0
M#K8-``6X#317P`U>VLH-``K,#6$1T0U:!M<-0`39#2Y^XPV*8ND-!3+N#<"`
M\0T00/,-00#U#<&<_`V0HP(.N"8)#D`*#`X@``T.B(,2#DY@&`Y()!P.`G`@
M#H,A)0Z*-BP.H`0O#@&--`YN.3T.PF!"#L`$10[(`DD.?'!1#H`"4PYD+%D.
M8@9>#@$!8`ZC,&8.@;%L#DB`;PZP0',.!8%W#B;(?0X(08`.PB2%#B)EBPX`
M`(L.``"+#@``BPX``(L.``"+#@``BPX``(L.``"+#@``BPX`^)`.F("4#@PX
MF0YZ()\.`N"C#@&HIP[#$*P.1B2Q#A"0M`X)P;D.`(B[#BC1P0X$Y,8.@.7,
M#EK@TPY14-@.L5;@#A$`X@X``.(.42#F#B(`Z`X"0>L.`%#M#L`(\`X``_(.
M`*'U#K0!^@X!8/T.348$#P@(!@_`40L/D1`/#R$4$P^@%!</A``9#X.C(`^`
M`"$/<D@G#T%)+`\$0"X/%`@Q#RC,-P^@:#P/$AA`#V>C20\)@$P/&"91#P8!
M5`\4!%</>,A>#T(080^)(&4/$*AI#YM&<0]2#7</FT>`#Y74B`]``(D/(02,
M#Q6EDP_`8)</@PV=#P#HH0\&<*8/B32L#YQ@L@_Z`+@/``"X#P&AO`]5(,$/
M-#O)#\`RS@\`P-`/@8+4#Q,@V`\`!=H/0!/>#T*$X@\B`N4/`(#F#P`"YP^@
MI>T/1A?T#[$$^0]9,0`0(@`"$"Q`!A!`APL0$F00$(61%A`($!@0@(0;$(<L
M(A",4"<0`5`J$+R,,A!<@#<00(`Y$$_R0Q`7B$D0`*Y.$&*:51`(H5D0I2!>
M$-#Q9A"$3&L0`(5N$$$A<A!(D'80,6![$`=+@A""`H400#6*$$<`CA#,(Y40
M'Y*=$.`$H1``(:,00A6H$,(AK1"Z@[40*P"Y$*84OQ"I`,,0`#3&$+#(S!`9
MPM(0"L'7$`9VWA`I(.(0`"'D$#*`Z!`&".L0^!OT$*E#^Q")<`$1(L`%$0)'
M"A%@EA`1'"P6$0J%&Q%*#B$1'=\L$0!A+Q$E%#01*D\\$6*50Q$1`D81`@I)
M$0$`2A$`G4\1`052$0!D51$!?%L1#DA@$8"`8A&C`&810N!K$6`7<1'!`741
M)T9\$66"@A&$'(<1#DB,$2D\DQ$`(I41,9B;$2$`G1'Q$*,1``"C$?`!J!$@
M*JP12J*R$;"`MA$V0+L159C"$:!@QA&I8LT1R#'3$:(`UA'@SMX128CC$<6"
MZ1&`PNT1R$CR$4@']Q&ZH/X1`!#_$7&0!1)@#`D2`M`-$@`@#A*!$!$2?"$8
M$AQ"'1(((!\20%,D$C*H*A(PT"\2```O$@``+Q(``"\2```O$@``+Q(``"\2
M```O$@``+Q(``"\2`&,S$J"*.!*:*T`26"-&$FA(2Q+`"$X2#1I4$A``51(`
M!E<28(I<$F`B8!("D602I<%K$@H";A*$"'$2``!Q$@``<1(``'$2``!Q$B!2
M=1(`@'82%"%Z$B/`?Q)!F(02I!J*$N%%D1*R`I82L!":$A<@GQ)R"*024@"G
M$L\`K1+*([02`^BZ$A!XOQ(&LL42`P[*$@P"S1(E;-02A&+9$B@,W1*;@.,2
M$A#F$@!AZ1*#!NX2A8'S$L%!^!*K<0$3\`0&$XN`"Q,^81,3(``4$P``%!,`
M`!03`"`5$W,`&A-@01X30RPD$RT`*!,902T38D@R$Q01-A,`"3@3`+<^$YB`
M0A,8$$43`"A'$\002Q,1`DX3(%E3$Z$+61,G`%T376!D$[@1:A.DLW(3((AU
M$U'`>A-Q(8`3T56($ZW"D!/2-I@3B(&<$X@.H1.2(*43$`ZI$VI$KQ,Z0;43
M0G&[$T^XQ!,L`,<3F$;-$S#VU1.#*ML3\Q;D$TTQZQ-XP?(3:5?[$\WD!!0"
M,PD4H\,1%.&[&Q0`9R`4A((D%+&)*Q1$O3,4[WD_%*FS2!2K45`4`8I4%`4A
M6!0R\%\4L@9E%-@`:12``VP4IT5T%+"F>Q1;I(,4!ZV+%"1)D!1:"Y<4<`2;
M%/(^I10(TJH4Q`"M%(`OLQ06X[L4X("_%`#`P10>J,@4*!7-%""2T10*Z=@4
M!@#:%!@`W!0``-P4``#<%```W!0``-P4``#<%```W!0``-P4``#<%```W!0`
M`-P4``#<%```W!0``-P4``#<%`!#WQ00<>04`.#G%$(:[!10I/$40`OU%`_F
M_A11``$5```!%0```14`8`,5=!`(%8HW$!4"`!$5U`$6%0)`&!40V!T5'@(B
M%4*D)Q5PPBT5"`0O%0`$,!4$Y385`((X%0($.A4L`CX5`"Q!%0X!114*`$<5
M"L1,%:`-416(1%45R*E<%0$"7A7@QF45!%!H%6;7<A6R=GL5DVN$%1.`B!62
M!8T5@&21%5!2EA5IR)T5+4"B%9`$I17.!JP5;!2R%0``LA4``+(5``"R%0!H
MM161C;P5)!'`%0``P!7J!,852`#(%80!RQ7BG-,5Q`C7%3X>X!7#8><5$-ON
M%0$`[Q4``.\5``#O%0"H\A5``/,5)Z;[%0@"_1485@,6@!P'%C%B#18<&!(6
M0T`6%IU@'19H`2$6DEPH%E(@+!8``"P6```L%@``+!8``"P6`-0P%G3*.!9*
M03T6Y1A$%K$22A8LIE$6/WM=%D4:8Q9!*&<6N"9N%@`9<1;@2'86:GV`%JB#
MAA;QKI`6$625%L`2F1:'V:(6@D&F%H&AJQ:@C+`6B*>W%@6(NQ9"5\(6S`?)
M%N(@SA8ZQM866?G@%@A/YA:E".L6``#K%@``ZQ8``.L6``#K%@``ZQ8``.L6
M0`#L%H0"[Q8$"/$6@G'W%@"`^!8=-/\6K`0$%QB`!Q<L#@T7P5@3%UAD&1?L
M`1\7`E0C%R*2*!>(!BP7\,0S%Z%*.1<90#T7A$1!%V<R21<``$D7``!)%P``
M21<``$D7``!)%P`<3!>]P%070$E8%Q#171<Y`&$70`ED%R"`9A>0<&L7)X%Q
M%PR"=1?7CG\71(R$%Y:VC1?Z`),7Z&6;%P#CH!<K)*87`("G%]=`KA<N``<!
M```'`4``"`$$````````````````````````````````````````````````
M````````````````````4L8'``"%"@#__QH`?O\H`/__.`!__T<`__]7`,__
M90#WSW(`__^"`/\_D`#__Z``__^P`/]_OP```+\```"_````OP```+\``.#"
M`/\?SP```,\`(`#0````T````-````#0````T````-````#0````T````-``
M``#0````T````-````#0`(``T0``+]8```#6````U@```-8```#6````U@``
M`-8```#6````U@```-8```#6`'#7WP`!`.```/SF``$`YP`$?.T```#M````
M[0```.T`_-_Z````^@```/H```#Z````^@#\WP```````````DX$3@5.#$X2
M3A].(TXD3BA.*TXN3B].,$XU3D!.04Y$3D=.44Y:3EQ.8TYH3FE.=$YU3GE.
M?TZ-3I9.ETZ=3J].N4[#3M!.VD[;3N!.X4[B3NA.[T[Q3O-.]4[]3OY._TX`
M3P)/`T\(3PM/#$\23Q5/%D\73QE/+D\Q3V!/,T\U3S=/.4\[3SY/0$]"3TA/
M24]+3TQ/4D]43U9/6$]?3V-/:D]L3VY/<4]W3WA/>4]Z3WU/?D^!3X)/A$^%
M3XE/BD^,3XY/D$^23Y-/E$^73YE/FD^>3Y]/LD^W3[E/NT^\3[U/OD_`3\%/
MQ4_&3\A/R4_+3\Q/S4_/3])/W$_@3^)/\$_R3_Q/_4__3P!0`5`$4`=0"E`,
M4`Y0$%`34!=0&%`;4!Q0'5`>4")0)U`N4#!0,E`S4#500%!!4$)015!&4$I0
M3%!.4%%04E!34%=065!?4&!08E!C4&909U!J4&U0<%!Q4#M0@5"#4(10AE"*
M4(Y0CU"04))0DU"44)90FU"<4)Y0GU"@4*%0HE"J4*]0L%"Y4+I0O5#`4,-0
MQ%#'4,Q0SE#04--0U%#84-Q0W5#?4.)0Y%#F4.A0Z5#O4/%0]E#Z4/Y0`U$&
M40=1"%$+40Q1#5$.4?)0$%$741E1&U$<41U1'E$C42=1*%$L42U1+U$Q43-1
M-%$U43A1.5%"44I13U%345515U%845]19%%F47Y1@U&$48M1CE&849U1H5&C
M4:U1N%&Z4;Q1OE&_4<)1R%'/4=%1TE'34=51V%'>4>)1Y5'N4?)1\U'T4?=1
M`5("4@52$E(34A52%E(84B)2*%(Q4C)2-5(\4D5225)54E=26%):4EQ27U)@
M4F%29E)N4G=2>%)Y4H!2@E*%4HI2C%*34I52EE*74IA2FE*<4J12I5*F4J=2
MKU*P4K92MU*X4KI2NU*]4L!2Q%+&4LA2S%+/4M%2U%+64MM2W%+A4N52Z%+I
M4NI2[%+P4O%2]%+V4O=2`%,#4PI3"U,,4Q%3$U,84QM3'%,>4Q]3)5,G4RA3
M*5,K4RQ3+5,P4S)3-5,\4SU3/E-"4TQ32U-94UM385-C4V53;%-M4W)3>5-^
M4X-3AU.(4XY3DU.44YE3G5.A4Z13JE.K4Z]3LE.T4[53MU.X4[I3O5/`4\53
MSU/24]-3U5/:4]U3WE/@4^93YU/U4P)4$U0:5"%4)U0H5"I4+U0Q5#14-51#
M5$141U1-5$]47E1B5&149E1G5&E4:U1M5&Y4=%1_5(%4@U2%5(A4B52-5)%4
ME5265)Q4GU2A5*94IU2I5*I4K52N5+%4MU2Y5+I4NU2_5,94RE3-5,Y4X%3J
M5.Q4[U3V5/Q4_E3_5`!5`54%50A5"54,50U5#E4552I5*U4R5355-E4[53Q5
M/55!54=5255*54U54%5155A56E5;55Y58%5A56159E5_58%5@E6&58A5CE6/
M59%5DE635915EU6C5:15K56R5;]5P57#5<95R57+5<Q5SE715=)5TU775=A5
MVU7>5>)5Z57V5?]5!58(5@I6#58.5@]6$%815A)6&58L5C!6,U8U5C=6.58[
M5CQ6/58_5D!6059#5D161E9)5DM6359/5E167E9@5F%68E9C5F96:59M5F]6
M<59R5G56A%:%5HA6BU:,5I56F5::5IU6GE:?5J96IU:H5JE6JU:L5JU6L5:S
M5K=6OE;%5LE6RE;+5L]6T%;,5LU6V5;<5MU6WU;A5N16Y5;F5N=6Z%;Q5NM6
M[5;V5O=6`5<"5P=7"E<,5Q%7%5<:5QM7'5<@5R)7(U<D5R57*5<J5RQ7+E<O
M5S-7-%<]5SY7/U=%5T973%=-5U)78E=E5V=7:%=K5VU7;E=O5W!7<5=S5W17
M=5=W5WE7>E=[5WQ7?E>!5X-7C%>45Y=7F5>:5YQ7G5>>5Y]7H5>55Z=7J%>I
M5ZQ7N%>]5\=7R%?,5\]7U5?=5]Y7Y%?F5^=7Z5?M5_!7]5?V5_A7_5?^5_]7
M`U@$6`A8"5CA5PQ8#5@;6!Y8'U@@6"98)U@M6#)8.5@_6$E83%A-6$]84%A5
M6%]885AD6&=8:%AX6'Q8?UB`6(%8AUB(6(E8BEB,6(U8CUB06)18EEB=6*!8
MH5BB6*98J5BQ6+)8Q%B\6,)8R%C-6,Y8T%C26-18UEC:6-U8X5CB6.E8\U@%
M6099"UD,61)9$UD464&&'5DA62-9)%DH62]9,%DS6359-ED_64-91EE265-9
M65E;65U97EE?66%98UEK66U9;UER6759=EEY67M9?%F+68Q9CEF26959EUF?
M6:19IUFM6:Y9KUFP6;-9MUFZ6;Q9P5G#6<19R%G*6<U9TEG=6=Y9WUGC6>19
MYUGN6>]9\5GR6?19]UD`6@1:#%H-6@Y:$EH36AY:(UHD6B=:*%HJ6BU:,%I$
M6D5:1UI(6DQ:4%I56EY:8UIE6F=:;5IW6GI:>UI^6HM:D%J36I9:F5J<6IY:
MGUJ@6J):IUJL6K%:LEJS6K5:N%JZ6KM:OUK$6L9:R%K/6MI:W%K@6N5:ZEKN
M6O5:]EK]6@!;`5L(6Q=;-%L96QM;'5LA6R5;+5LX6T%;2UM,6U);5EM>6VA;
M;EMO6WQ;?5M^6W];@5N$6X9;BEN.6Y!;D5N36Y1;EENH6ZE;K%NM6Z];L5NR
M6[=;NEN\6\!;P5O-6\];UEO76]A;V5O:6^!;[UOQ6_1;_5L,7!=<'EP?7"-<
M)EPI7"M<+%PN7#!<,EPU7#9<65Q:7%Q<8EQC7&=<:%QI7&U<<%QT7'5<>EQ[
M7'Q<?5R'7(A<BER/7))<G5R?7*!<HERC7*9<JERR7+1<M5RZ7,E<RUS27-U<
MUUSN7/%<\EST7`%=!ET-71)=*UTC721=)ETG73%=-%TY73U=/UU"74-=1EU(
M755=45U974I=7UU@76%=8EUD76I=;5UP77E=>EU^77]=@5V#78A=BEV279-=
ME%V579E=FUV?7:!=IUVK7;!=M%VX7;E=PUW'7<M=T%W.7=A=V5W@7>1=Z5WX
M7?E=`%X'7@U>$EX47A5>&%X?7B!>+EXH7C)>-5X^7DM>4%Y)7E%>5EY87EM>
M7%Y>7FA>:EYK7FQ>;5YN7G!>@%Z+7HY>HEZD7J5>J%ZJ7JQ>L5ZS7KU>OEZ_
M7L9>S%[+7LY>T5[27M1>U5[<7MY>Y5[K7@)?!E\'7PA?#E\97QQ?'5\A7R)?
M(U\D7RA?*U\L7RY?,%\T7S9?.U\]7S]?0%]$7T5?1U]-7U!?5%]87UM?8%]C
M7V1?9U]O7W)?=%]U7WA?>E]]7WY?B5^-7X]?EE^<7YU?HE^G7ZM?I%^L7Z]?
ML%^Q7[A?Q%_'7\A?R5_+7]!?T5_27]-?U%_>7^%?XE_H7^E?ZE_L7^U?[E_O
M7_)?\U_V7_I?_%\'8`I@#6`38!1@%V`88!I@'V`D8"U@,V`U8$!@1V!(8$E@
M3&!18%1@5F!78%U@86!G8'%@?F!_8()@AF"(8(I@CF"18)-@E6"88)U@GF"B
M8*1@I6"H8+!@L6"W8+M@OF#"8,1@R&#)8,I@RV#.8,]@U&#58-E@VV#=8-Y@
MXF#E8/)@]6#X8/Q@_6`"80=A"F$,81!A$6$281-A%&$681=A&6$<81YA(F$J
M82MA,&$Q835A-F$W83EA06%%849A26%>86!A;&%R87AA>V%\87]A@&&!88-A
MA&&+88UADF&389=AF&&<89UAGV&@8:5AJ&&J8:UAN&&Y8;QAP&'!8<)ASF'/
M8=5AW&'=8=YAWV'A8>)AYV'I8>5A[&'M8>]A`6(#8@1B!V(38A5B'&(@8B)B
M(V(G8BEB*V(Y8CUB0F)#8D1B1F),8E!B46)28E1B5F):8EQB9&)M8F]B<V)Z
M8GUBC6*.8H]BD&*F8JABLV*V8K=BNF*^8K]BQ&+.8M5BUF+:8NIB\F+T8OQB
M_6(#8P1C"F,+8PUC$&,38Q9C&&,I8RIC+6,U8S9C.6,\8T%C0F-#8T1C1F-*
M8TMC3F-28U-C5&-88UMC96-F8VQC;6-Q8W1C=6-X8WQC?6-_8X)CA&.'8XIC
MD&.48Y5CF6.:8YYCI&.F8ZUCKF.O8[UCP6/%8\ACSF/18]-CU&/58]QCX&/E
M8^IC[&/R8_-C]6/X8_EC"60*9!!D$F049!AD'F0@9")D)&0E9"ED*F0O9#!D
M-60]9#]D2V1/9%%D4F139%1D6F1;9%QD761?9&!D861C9&UD<V1T9'MD?62%
M9(=DCV209)%DF&299)MDG62?9*%DHV2F9*ADK&2S9+UDOF2_9,1DR63*9,MD
MS&3.9-!DT6359-=DY&3E9.EDZF3M9/!D]63W9/MD_V0!901E"&4)90IE#V43
M911E%F4991ME'F4?92)E)F4I92YE,64Z93QE/65#94=E265095)E5&5?96!E
M9V5K97IE?66!985EBF62995EF&6=9:!EHV6F9:YELF6S9;1EOV7"9<AER67.
M9=!EU&769=AEWV7P9?)E]&7U9?EE_F7_90!F!&8(9@EF#6819A)F%6869AUF
M'F8A9B)F(V8D9B9F*68J9BMF+&8N9C!F,68S9CEF-V9`9D5F1F9*9DQF469.
M9E=F6&999EMF7&9@9F%F^V9J9FMF;&9^9G-F=69_9G=F>&9Y9GMF@&9\9HMF
MC&:-9I!FDF:99IIFFV:<9I]FH&:D9JUFL6:R9K5FNV:_9L!FPF;#9LAFS&;.
M9L]FU&;;9M]FZ&;K9NQF[F;Z9@5G!V<.9Q-G&6<<9R!G(F<S9SYG16='9TAG
M3&=49U5G76=F9VQG;F=T9W9G>V>!9X1GCF>/9Y%GDV>69YAGF6>;9[!GL6>R
M9[5GNV>\9[UG^6?`9\)GPV?%9\AGR6?29]=GV6?<9^%GYF?P9_)G]F?W9U)H
M%&@9:!UH'V@H:"=H+&@M:"]H,&@Q:#-H.V@_:$1H16A*:$QH56A7:%AH6VAK
M:&YH;VAP:'%H<FAU:'EH>FA[:'QH@FB$:(9HB&B6:)AHFFB<:*%HHVBE:*EH
MJFBN:+)HNVC%:,AHS&C/:-!HT6C3:-9HV6C<:-UHY6CH:.IHZVCL:.UH\&CQ
M:/5H]FC[:/QH_6@&:0EI"FD0:1%I$VD6:1=I,6DS:35I.&D[:4)I16E):4YI
M5VE;:6-I9&EE:69I:&EI:6QI<&EQ:7)I>FE[:7]I@&F-:9)IEFF8::%II6FF
M::AIJVFM::]IMVFX:;IIO&G%:<AIT6G6:==IXFGE:>YI[VGQ:?-I]6G^:0!J
M`6H#:@]J$6H5:AIJ'6H@:B1J*&HP:C)J-&HW:CMJ/FH_:D5J1FI):DIJ3FI0
M:E%J4FI5:E9J6VID:F=J:FIQ:G-J?FJ!:H-JAFJ':HEJBVJ1:IMJG6J>:I]J
MI6JK:J]JL&JQ:K1JO6J^:K]JQFK):LAJS&K0:M1JU6K6:MQJW6KD:N=J[&KP
M:O%J\FK\:OUJ`FL#:P9K!VL):P]K$&L1:Q=K&VL>:R1K*&LK:RQK+VLU:S9K
M.VL_:T9K2FM-:U)K5FM8:UUK8&MG:VMK;FMP:W5K?6M^:X)KA6N7:YMKGVN@
M:Z)KHVNH:ZEKK&NM:ZYKL&NX:[EKO6N^:\-KQ&O):\QKUFO::^%KXVOF:^=K
M[FOQ:_=K^6O_:P)L!&P%;`EL#6P.;!!L$FP9;!]L)FPG;"AL+&PN;#-L-6PV
M;#IL.VP_;$IL2VQ-;$]L4FQ4;%EL6VQ<;&ML;6QO;'1L=FQX;'EL>VR%;(9L
MAVR);)1LE6R7;)ALG&R?;+!LLFRT;,)LQFS-;,]LT&S1;-)LU&S6;-ILW&S@
M;.=LZ6SK;.QL[FSR;/1L!&T';0IM#FT/;1%M$VT:;29M)VTH;6=L+FTO;3%M
M.6T\;3]M5VU>;5]M86UE;6=M;VUP;7QM@FV';9%MDFV4;99MEVV8;:IMK&VT
M;;=MN6V];;]MQ&W(;<IMSFW/;=9MVVW=;=]MX&WB;>5MZ6WO;?!M]&WV;?QM
M`&X$;AYN(FXG;C)N-FXY;CMN/&Y$;D5N2&Y);DMN3VY1;E)N4VY4;E=N7&Y=
M;EYN8FYC;FAN<VY[;GUNC6Z3;IENH&ZG;JUNKFZQ;K-NNVZ_;L!NP6[#;L=N
MR&[*;LUNSF[/;NMN[6[N;OEN^V[];@1O"&\*;PQO#6\6;QAO&F\;;R9O*6\J
M;R]O,&\S;S9O.V\\;RUO3V]1;U)O4V]7;UEO6F]=;UYO86]B;VAO;&]];WYO
M@V^';XAOBV^,;XUOD&^2;Y-OE&^6;YIOGV^@;Z5OIF^G;ZAOKF^O;[!OM6^V
M;[QOQ6_';\AORF_:;]YOZ&_I;_!O]6_Y;_QO_6\`<`5P!G`'<`UP%W`@<"-P
M+W`T<#=P.7`\<$-P1'!(<$EP2G!+<%1P57!=<%YP3G!D<&5P;'!N<'5P=G!^
M<(%PA7"&<)1PE7"6<)=PF'";<*1PJW"P<+%PM'"W<,IPT7#3<-1PU7#6<-AP
MW'#D</IP`W$$<05Q!G$'<0MQ#'$/<1YQ('$K<2UQ+W$P<3%Q.'%!<45Q1G%'
M<4IQ2W%0<5)Q5W%:<5QQ7G%@<6AQ>7&`<85QAW&,<9)QFG&;<:!QHG&O<;!Q
MLG&S<;IQOW'`<<%QQ''+<<QQTW'6<=EQVG'<<?AQ_G$`<@=R"'()<A-R%W(:
M<AUR'W(D<BMR+W(T<CAR.7)!<D)R0W)%<DYR3W)0<E-R57)6<EIR7')><F!R
M8W)H<FMR;G)O<G%R=W)X<GMR?')_<H1RB7*-<HYRDW*;<JARK7*N<K%RM'*^
M<L%RQW+)<LQRU7+6<MARWW+E<O-R]'+Z<OMR_G("<P1S!7,'<PMS#7,2<Q-S
M&',9<QYS(G,D<R=S*',L<S%S,G,U<SIS.W,]<T-S37-0<U)S5G-8<UUS7G-?
M<V!S9G-G<VES:W-L<VYS;W-Q<W=S>7-\<X!S@7.#<X5SAG..<Y!SDW.5<Y=S
MF'.<<YYSGW.@<Z)SI7.F<ZISJW.M<[5SMW.Y<[QSO7._<\5SQG/)<\MSS'//
M<])STW/6<]ESW7/A<^-SYG/G<^ES]'/U<_=S^7/Z<_MS_7/_<P!T`70$=`=T
M"G01=!IT&W0D="9T*'0I="IT*W0L="UT+G0O=#!T,70Y=$!T0W1$=$9T1W1+
M=$UT4712=%=T771B=&9T9W1H=&MT;71N='%T<G2`=(%TA72&=(=TB72/=)!T
MD722=)ATF72:=)QTGW2@=*%THW2F=*ATJ72J=*MTKG2O=+%TLG2U=+ETNW2_
M=,ATR73,=-!TTW38=-ITVW3>=-]TY'3H=.ITZW3O=/1T^G3[=/QT_W0&=1)U
M%G47=2!U(74D=2=U*74J=2]U-G4Y=3UU/G4_=4!U0W5'=4AU3G50=5)U5W5>
M=5]U875O=7%U>75Z=7MU?'5]=7YU@76%=9!UDG63=95UF76<=:)UI'6T=;IU
MOW7`=<%UQ'7&=<QUSG7/===UW'7?=>!UX77D=>=U['7N=>]U\77Y=0!V`G8#
M=@1V!W8(=@IV#'8/=A)V$W85=A9V&78;=AQV'78>=B-V)78F=BEV+78R=C-V
M-78X=CEV.G8\=DIV0'9!=D-V1'9%=DEV2W95=EEV7W9D=F5V;79N=F]V<79T
M=H%VA7:,=HUVE7:;=IQVG7:?=J!VHG:C=J1VI7:F=J=VJ':J=JUVO7;!=L5V
MR7;+=LQVSG;4=MEVX';F=NAV[';P=O%V]G;Y=OQV`'<&=PIW#G<2=Q1W%7<7
M=QEW&G<<=R)W*'<M=RYW+W<T=S5W-G<Y=SUW/G="=T5W1G=*=TUW3G=/=U)W
M5G=7=UQW7G=?=V!W8G=D=V=W:G=L=W!W<G=S=W1W>G=]=X!WA'>,=XUWE'>5
M=Y9WFG>?=Z)WIW>J=ZYWKW>Q=[5WOG?#=\EWT7?2=]5WV7?>=]]WX'?D=^9W
MZG?L=_!W\7?T=_AW^W<%>`9X"7@->`YX$7@=>"%X(G@C>"UX+G@P>#5X-WA#
M>$1X1WA(>$QX3GA2>%QX7GA@>&%X8WAD>&AX:GAN>'IX?GB*>(]XE'B8>*%X
MG7B>>)]XI'BH>*QXK7BP>+%XLGBS>+MXO7B_>,=XR'C)>,QXSGC2>--XU7C6
M>.1XVWC?>.!XX7CF>.IX\GCS>`!Y]GCW>/IX^WC_>`9Y#'D0>1IY''D>>1]Y
M('DE>2=Y*7DM>3%Y-'DU>3MY/7D_>41Y17E&>4IY2WE/>5%Y5'E8>5MY7'EG
M>6EY:WER>7EY>WE\>7YYBWF,>9%YDWF4>95YEGF8>9MYG'FA>:AYJ7FK>:]Y
ML7FT>;AYNWG"><1YQWG(><IYSWG4>=9YVGG=>=YYX'GB>>5YZGGK>>UY\7GX
M>?QY`GH#>@=Z"7H*>@QZ$7H5>AMZ'GHA>B=Z*WHM>B]Z,'HT>C5Z.'HY>CIZ
M1'I%>D=Z2'I,>E5Z5GI9>EQZ77I?>F!Z97IG>FIZ;7IU>GAZ?GJ`>H)ZA7J&
M>HIZBWJ0>I%ZE'J>>J!ZHWJL>K-ZM7JY>KMZO'K&>LEZS'K.>M%ZVWKH>NEZ
MZWKL>O%Z]'K[>OUZ_GH'>Q1['WLC>R=[*7LJ>RM[+7LN>R][,'LQ>S1[/7L_
M>T![07M'>TY[57M@>V1[9GMI>VI[;7MO>W)[<WMW>X1[B7N.>Y![D7N6>YM[
MGGN@>Z5[K'NO>[![LGNU>[9[NGN[>[Q[O7O">\5[R'O*>]1[UGO7>]E[VGO;
M>^A[ZGOR>_1[]7OX>_E[^GO\>_Y[`7P"?`-\!'P&?`E\"WP,?`Y\#WP9?!M\
M('PE?"9\*'PL?#%\,WPT?#9\.7PZ?$9\2GQ5?%%\4GQ3?%E\6GQ;?%Q\77Q>
M?&%\8WQG?&E\;7QN?'!\<GQY?'Q\?7R&?(=\CWR4?)Y\H'RF?+!\MGRW?+I\
MNWR\?+]\Q'S'?,A\R7S-?,]\TWS4?-5\UWS9?-I\W7SF?.E\ZWSU?`-]!WT(
M?0E]#WT1?1)]$WT6?1U]'GTC?29]*GTM?3%]/'T]?3Y]0'U!?4=]2'U-?5%]
M4WU7?5E]6GU<?5U]97UG?6I]<'UX?7I]>WU_?8%]@GV#?85]AGV(?8M]C'V-
M?9%]EGV7?9U]GGVF?:=]JGVS?;9]MWVY?<)]PWW$?<5]QGW,?<U]SGW7?=E]
M`'[B?>5]YGWJ?>M][7WQ??5]]GWY??I]"'X0?A%^%7X7?AQ^'7X@?B=^*'XL
M?BU^+WXS?C9^/WY$?D5^1WY.?E!^4GY8?E]^87YB?F5^:WYN?F]^<WYX?GY^
M@7Z&?H=^BGZ-?I%^E7Z8?II^G7Z>?CQ_.W\]?SY_/W]#?T1_1W]/?U)_4W];
M?UQ_77]A?V-_9']E?V9_;7]Q?WU_?G]_?X!_BW^-?X]_D'^1?Y9_EW^<?Z%_
MHG^F?ZI_K7^T?[Q_OW_`?\-_R'_.?\]_VW_??^-_Y7_H?^Q_[G_O?_)_^G_]
M?_Y__W\'@`B`"H`-@`Z`#X`1@!.`%(`6@!V`'H`?@""`)(`F@"R`+H`P@#2`
M-8`W@#F`.H`\@#Z`0(!$@&"`9(!F@&V`<8!U@(&`B(".@)R`GH"F@*>`JX"X
M@+F`R(#-@,^`TH#4@-6`UX#8@."`[8#N@/"`\H#S@/:`^8#Z@/Z``X$+@1:!
M%X$8@1R!'H$@@22!)X$L@3"!-8$Z@3R!18%'@4J!3(%2@5>!8(%A@6>!:(%I
M@6V!;X%W@8&!D(&$@86!AH&+@8Z!EH&8@9N!GH&B@:Z!LH&T@;N!RX'#@<6!
MRH'.@<^!U8'7@=N!W8'>@>&!Y('K@>R!\('Q@?*!]8'V@?B!^8']@?^!`((#
M@@^"$X(4@AF"&H(=@B&"(H(H@C*"-((Z@D."1()%@D:"2X).@D^"48)6@ER"
M8()C@F>";8)T@GN"?8)_@H""@8*#@H2"AX*)@HJ"CH*1@I2"EH*8@IJ"FX*@
M@J&"HX*D@J>"J(*I@JJ"KH*P@K*"M(*W@KJ"O(*^@K^"QH+0@M6"VH+@@N*"
MY(+H@NJ"[8+O@O:"]X+]@OZ"`(,!@P>#"(,*@PN#5(,;@QV#'H,?@R&#(H,L
M@RV#+H,P@S.#-X,Z@SR#/8-"@T.#1(-'@TV#3H-1@U6#5H-7@W"#>(-]@W^#
M@(."@X2#AH.-@Y*#E(.5@YB#F8.;@YR#G8.F@Z>#J8.L@[Z#OX/`@\>#R8//
M@]"#T8/4@]V#4X/H@^J#]H/X@_F#_(,!A`:$"H0/A!&$%809A*V#+X0YA$6$
M1X1(A$J$381/A%&$4H16A%B$681:A%R$8(1DA&6$9X1JA'"$<X1TA':$>(1\
MA'V$@82%A)*$DX25A)Z$IH2HA*F$JH2OA+&$M(2ZA+V$OH3`A,*$QX3(A,R$
MSX33A-R$YX3JA.^$\(3QA/*$]X0RA?J$^X3]A`*%`X4'A0R%#H40A1R%'H4B
MA2.%)(4EA2>%*H4KA2^%,X4TA3:%/X5&A4^%4(51A5*%4X56A5F%7(5=A5Z%
M7X5@A6&%8H5DA6N%;X5YA7J%>X5]A7^%@86%A8:%B86+A8R%CX63A9B%G86?
MA:"%HH6EA:>%M(6VA;>%N(6\A;V%OH6_A<*%QX7*A<N%SH6MA=B%VH7?A>"%
MYH7HA>V%\X7VA?R%_X4`A@2&!88-A@Z&$(81AA*&&(89AAN&'H8AAB>&*88V
MACB&.H8\ACV&0(9"AD:&4H93AE:&5X98AEF&789@AF&&8H9CAF2&:89LAF^&
M=89VAG>&>H:-AI&&EH:8AIJ&G(:AAJ:&IX:HAJV&L8:SAK2&M8:WAKB&N8:_
MAL"&P8;#AL6&T8;2AM6&UX;:AMR&X(;CAN6&YX:(AOJ&_(;]A@2'!8<'APN'
M#H</AQ"'$X<4AQF''H<?AR&'(X<HARZ'+X<QAS*'.8<ZASR'/8<^AT"'0X=%
MATV'6(==AV&'9(=EAV^'<8=RAWN'@X>$AX6'AH>'AXB'B8>+AXR'D(>3AY6'
MEX>8AYF'GH>@AZ.'IX>LAZV'KH>QA[6'OH>_A\&'R(?)A\J'SH?5A]:'V8?:
MA]R'WX?BA^.'Y(?JA^N'[8?QA_.'^(?ZA_^'`8@#B`:("8@*B`N($(@9B!*(
M$X@4B!B(&H@;B!R('H@?B"B(+8@NB#"(,H@UB#J(/(A!B$.(18A(B$F(2HA+
MB$Z(48A5B%:(6(A:B%R(7XA@B&2(:8AQB'F(>XB`B)B(FHB;B)R(GXB@B*B(
MJHBZB+V(OHC`B,J(RXC,B,V(SHC1B-*(TXC;B-Z(YXCOB/"(\8CUB/>(`8D&
MB0V)#HD/B16)%HD8B1F)&HD<B2"))HDGB2B),(DQB3*)-8DYB3J)/HE`B4*)
M18E&B4F)3XE2B5>)6HE;B5R)88EBB6.):XENB7")<XEUB7J)>XE\B7V)B8F-
MB9")E(F5B9N)G(F?B:")I8FPB;2)M8FVB;>)O(G4B=6)UHG7B=B)Y8GIB>N)
M[8GQB?.)]HGYB?V)_XD$B@6*!XH/BA&*$HH4BA6*'HH@BB**)(HFBBN*+(HO
MBC6*-XH]BCZ*0(I#BD6*1XI)BDV*3HI3BE:*5XI8BER*78IABF6*9XIUBG:*
M=XIYBGJ*>XI^BG^*@(J#BH:*BXJ/BI"*DHJ6BI>*F8J?BJ>*J8JNBJ^*LXJV
MBK>*NXJ^BL.*QHK(BLF*RHK1BM.*U(K5BM>*W8K?BNR*\(KTBO6*]HK\BO^*
M!8L&BPN+$8L<BQZ+'XL*BRV+,(LWBSR+0HM#BT2+18M&BTB+4HM3BU2+68M-
MBUZ+8XMMBW:+>(MYBWR+?HN!BX2+A8N+BXV+CXN4BY6+G(N>BY^+.(PYC#V,
M/HQ%C$>,28Q+C$^,48Q3C%2,5XQ8C%N,78Q9C&.,9(QFC&B,:8QMC'.,=8QV
MC'N,?HR&C(>,BXR0C)*,DXR9C)N,G(RDC+F,NHS%C,:,R8S+C,^,UHS5C-F,
MW8SAC.B,[(SOC/",\HSUC/>,^(S^C/^,`8T#C0F-$HT7C1N-98UIC6R-;HU_
MC8*-A(V(C8V-D(V1C96-GHV?C:"-IHVKC:R-KXVRC;6-MXVYC;N-P(W%C<:-
MQXW(C<J-SHW1C=2-U8W7C=F-Y(WEC>>-[(WPC;R-\8WRC?2-_8T!C@2.!8X&
MC@N.$8X4CA:.((XACB*.(XXFCB>.,8XSCC:.-XXXCCF./8Y`CD&.2XY-CDZ.
M3XY4CEN.7(Y=CEZ.88YBCFF.;(YMCF^.<(YQCGF.>HY[CH*.@XZ)CI".DHZ5
MCIJ.FXZ=CIZ.HHZGCJF.K8ZNCK..M8ZZCKN.P([!CL..Q(['CL^.T8[4CMR.
MZ([NCO".\8[WCOF.^H[MC@"/`H\'CPB/#X\0CQ:/%X\8CQZ/((\ACR./)8\G
MCRB/+(\MCRZ/-(\UCS:/-X\ZCT"/08]#CT>/3X]1CU*/4X]4CU6/6(]=CUZ/
M98^=CZ"/H8^DCZ6/IH^UC[:/N(^^C\"/P8_&C\J/RX_-C]"/TH_3C]6/X(_C
MC^2/Z(_NC_&/]8_VC_N/_H\"D`20")`,D!B0&Y`HD"F0+Y`JD"R0+9`SD#20
M-Y`_D$.01)!,D%N079!BD&:09Y!LD'"0=)!YD(60B)"+D(R0CI"0D)60EY"8
MD)F0FY"@D*&0HI"ED+"0LI"SD+20MI"]D,R0OI##D,20Q9#'D,B0U9#7D-B0
MV9#<D-V0WY#ED-*0]I#KD.^0\)#TD/Z0_Y``D021!9$&D0B1#9$0D121%I$7
MD1B1&I$<D1Z1()$ED2*1(Y$GD2F1+I$OD3&1-)$VD3>1.9$ZD3R1/9%#D4>1
M2)%/D5.15Y%9D5J16Y%AD6219Y%MD721>9%ZD7N1@9&#D861AI&*D8Z1D9&3
MD921E9&8D9Z1H9&FD:B1K)&MD:Z1L)&QD;*1LY&VD;N1O)&]D;^1PI'#D<61
MTY'4D=>1V9':D=Z1Y)'ED>F1ZI'LD>V1[I'OD?"1\9'WD?F1^Y']D0"2`9($
MD@62!I('D@F2"I(,DA"2$I(3DA:2&)(<DAV2(Y(DDB62)I(HDBZ2+Y(PDC.2
M-9(VDCB2.9(ZDCR2/I)`DD*20Y)&DD>22I)-DDZ23Y)1DEB269)<DEV28))A
MDF629Y)HDFF2;I)ODG"2=9)VDG>2>))YDGN2?))]DG^2B)*)DHJ2C9*.DI*2
MEY*9DI^2H)*DDJ62IY*HDJN2KY*RDK:2N)*ZDKN2O)*]DK^2P)+!DL*2PY+%
MDL:2QY+(DLN2S)+-DLZ2T)+3DM62UY+8DMF2W)+=DM^2X)+ADN.2Y9+GDNB2
M[)+NDO"2^9+[DO^2`),"DPB3#9,1DQ23%9,<DQV3'I,?DR&3)),EDR>3*9,J
MDS.3-),VDS>31Y-(DTF34)-1DU*359-7DUB36I->DV2399-GDVF3:I-MDV^3
M<)-QDW.3=)-VDWJ3?9-_DX"3@9."DXB3BI.+DXV3CY.2DY63F).;DYZ3H9.C
MDZ23II.HDZN3M).UD[:3NI.ID\&3Q)/%D\:3QY/)D\J3RY/,D\V3TY/9D]R3
MWI/?D^*3YI/GD_F3]Y/XD_J3^Y/]DP&4`I0$E`B4"90-E`Z4#Y05E!:4%Y0?
ME"Z4+Y0QE#*4,Y0TE#N4/Y0]E$.4191(E$J43)15E%F47)1?E&&48Y1HE&N4
M;91NE&^4<91RE(24@Y1XE7F5?I6$E8B5C)6-E8Z5G96>E9^5H96FE:F5JY6L
ME;25MI6ZE;V5OY7&E<B5R97+E="5T972E=.5V97:E=V5WI7?E>"5Y)7FE1V6
M'I8BEB26)98FEBR6,98SEC>6.)8YECJ6/)8]ED&64I94EE:65Y98EF&6;I9T
MEGN6?)9^EG^6@9:"EH.6A):)EI&6EI::EIV6GY:DEJ66II:IEJZ6KY:SEKJ6
MRI;2EK)=V);:EMV6WI;?ENF6[Y;QEOJ6`I<#EP67"9<:EQN7'9<AER*7(Y<H
MES&7,Y=!ET.72I=.ET^759=7EUB76I=;EV.79Y=JEVZ7<Y=VEW>7>)=[EWV7
M?Y>`EXF7E9>6EY>7F9>:EYZ7GY>BEZR7KI>QE[*7M9>VE[B7N9>ZE[R7OI>_
ME\&7Q)?%E\>7R9?*E\R7S9?.E]"7T9?4E]>7V)?9E]V7WI?@E]N7X9?DE^^7
M\9?TE_>7^)?ZEP>8"I@9F`V8#I@4F!:8')@>F""8(Y@FF"N8+I@OF#"8,I@S
MF#68)9@^F$281YA*F%&84IA3F%:85YA9F%J88IACF&689IAJF&R8JYBMF*Z8
ML)BTF+>8N)BZF+N8OYC"F,68R)C,F.&8XYCEF.:8YYCJF/.8]I@"F0>9")D1
MF169%ID7F1J9&YD<F1^9(IDFF2>9*YDQF3*9,YDTF369.9DZF3N9/)E`F4&9
M1IE'F4B939E.F5296)E9F5N97)E>F5^98)F;F9V9GYFFF;"9L9FRF;69N9FZ
MF;V9OYG#F<F9TYG4F=F9VIG<F=Z9YYGJF>N9[)GPF?29]9GYF?V9_ID"F@.:
M!)H+F@R:$)H1FA::'IH@FB*:(YHDFB>:+9HNFC.:-9HVFCB:1YI!FD2:2II+
MFDR:3II1FE2:5II=FJJ:K)JNFJ^:LIJTFK6:MIJYFKN:OIJ_FL&:PYK&FLB:
MSIK0FM*:U9K6FM>:VYK<FN":Y)KEFN>:Z9KLFO*:\YKUFOF:^IK]FO^:`)L!
MFP*;`YL$FP6;")L)FPN;#)L-FPZ;$)L2FQ:;&9L;FQR;()LFFRN;+9LSFS2;
M-9LWFSF;.IL]FTB;2YM,FU6;5IM7FUN;7IMAFV.;99MFFVB;:IMKFVR;;9MN
MFW.;=9MWFWB;>9M_FX";A)N%FX:;AYN)FXJ;BYN-FX^;D)N4FYJ;G9N>FZ:;
MIYNIFZR;L)NQF[*;MYNXF[N;O)N^F[^;P9O'F\B;SIO0F]>;V)O=F]^;Y9OG
MF^J;ZYOOF_.;]YOXF_F;^IO]F_^;`)P"G`N<#YP1G!:<&)P9G!J<')P>G"*<
M(YPFG"><*)PIG"J<,9PUG#:<-YP]G$&<0YQ$G$6<29Q*G$Z<3YQ0G%.<5)Q6
MG%B<6YQ=G%Z<7YQCG&F<:IQ<G&N<:)QNG'"<<IQUG'><>YSFG/*<]YSYG`N=
M`IT1G1>=&)T<G1V='ITOG3"=,ITSG32=.IT\G46=/9U"G4.=1YU*G5.=5)U?
MG6.=8IUEG6F=:IUKG7"==IUWG7N=?)U^G8.=A)V&G8J=C9V.G9*=DYV5G9:=
MEYV8G:&=JIVLG:Z=L9VUG;F=O)V_G<.=QYW)G<J=U)W5G=:=UYW:G=Z=WYW@
MG>6=YYWIG>N=[IWPG?.=])W^G0J>`IX'G@Z>$)X1GA*>%9X6GAF>')X=GGJ>
M>YY\GH">@IZ#GH2>A9Z'GHZ>CYZ6GIB>FYZ>GJ2>J)ZLGJZ>KYZPGK.>M)ZU
MGL:>R)[+GM6>WY[DGN>>[)[MGNZ>\)[QGO*>]9[XGO^>`I\#GPF?#Y\0GQ&?
M$I\4GQ:?%Y\9GQJ?&Y\?GR*?)I\JGRN?+Y\QGS*?-)\WGSF?.I\\GSV?/Y]!
MGT.?1)]%GT:?1Y]3GU6?5I]7GUB?6I]=GUZ?:)]IGVV?;I]OGW"?<9]SGW6?
M>I]]GX^?D)^1GY*?E)^6GY>?GI^AGZ*?HY^EGP``````````````````Q@`0
M`?W_)@']_S(!_?]!`3\!_?]*`=@`4@']_V8!W@#]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]_^8`$0'P`"<!,0$S`3@!0@%``4D!2P'X`%,!WP!G
M`?X`_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_!`,``Q`#"``(!S0$``00!Q0##``8!"`$,`<<`"@$.`<D`R`#+`,H`
M&@$6`1(!&`']_QP!'@$B`2`!)`'-`,P`SP#.`,\!,`$J`2X!*`$T`38!.0$]
M`3L!0P%'`44!T0#3`-(`U@#4`-$!4`%,`=4`5`%8`58!6@%<`6`!7@%D`6(!
MV@#9`-P`VP!L`=,!<`%J`7(!;@%H`=<!VP'9`=4!=`'=`'@!=@%Y`7T!>P']
M__W__?_]__W__?_]_^$`X`#D`.(``P'.`0$!!0'E`.,`!P$)`0T!YP`+`0\!
MZ0#H`.L`Z@`;`1<!$P$9`?4!'0$?`?W_(0$E`>T`[`#O`.X`T`']_RL!+P$I
M`34!-P$Z`3X!/`%$`4@!1@'Q`/,`\@#V`/0`T@%1`4T!]0!5`5D!5P%;`5T!
M80%?`64!8P'Z`/D`_`#[`&T!U`%Q`6L!<P%O`6D!V`'<`=H!U@%U`?T`_P!W
M`7H!?@%\`0``````````````````````````````````_?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?^&`X@#B0.*`ZH#_?^,`_W_C@.K
M`_W_CP/]__W__?_]_ZP#K0.N`Z\#R@.0`\P#P@/-`\L#L`/.`_W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?\"!`,$!`0%!`8$!P0(!`D$"@0+!`P$#@0/!/W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?]2!%,$5`15!%8$5P18!%D$6@1;!%P$
M7@1?!```````````_?_]__W__?_]__W__?_]__W__?_]__W__?_]_]@"QP*X
M`-D"W0*O`-L"V@)>_X0#A0/]__W__?_]__W__?_]__W_H0"F`+\`_?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]_[H`J@"I`*X`(B&D`!8A````````
M````````````````````````````````<2%R(7@A+R%,(FLA7B$M(7DB7R%@
M(2$F(B8C)B0F)28F)B<F*"8I)BHF*R8L)BTF+B8O)C`F,28R)C,F-"8U)C8F
M-R8X)D$F0B9#)D0F129&)D<F2"9))DHF2R9,)DTF3B9/)E`F4292)E,F5"95
M)E8F5R98)B<G(2<B)R,G)"<E)R8G*"<I)RHG*R<L)RTG+B<O)S`G,2<R)S,G
M-"<U)S8G-R<X)SDG.B<[)SPG/2<^)S\G0"=!)U$G4B=3)U0G52=6)U@G62=:
M)ULG7"==)UXG7R=@)V$G8B=C)V0G92=F)V<G:"=I)VHG:R=L)VTG;B=O)W`G
M<2=7)SXA/2%"(48A1R%((4DA=R)X(D4A1"%S(FPA;2$H(FXA<B(K(BPB*B(M
M(DTB3B)/(E\B4")@(CHB.R)=(64B9R)G(5PB2B)+(D$B0")I(FHB:"%H(F8B
M8B)B(6$B92%F(6,B9"(^(C\B/"(](ETB7B(A*"PH(B@M*",H+B@D*"\H)B@Q
M*"4H,"@G*#PH-R@R*"DH/B@Y*#0H*"@X*#TH,R@J*#HH/R@U*"LH.RA`*#8H
M(R(B(B4B)"(G(B8B(2)^(7LA?2%\(7XB>B%Y(6HA:2%V(G4B="(A(2(A(R$W
M(3DA.B$[(5(A4R%4(54A5B%7(5@A62%:(5LA*2(N(DPA32%!(2$D(B0C)"0D
M)20F)"<D*"0I)"HD*R0L)"TD+B0O)#`D,20R)#,D-"0U)#8D-R0X)#DD.B0[
M)#PD/20^)#\D0"1!)$(D0R1$)$4D1B1')$@D221*)$LD3"1-)$XD3R10)%$D
M4B13)%0D5216)%<D6"19)%HD6R1<)%TD7B1?)&`D821B)&,D9"1E)&8D9R1H
M)&DD:B1K)&PD;21N)&\D<"1Q)'(D<R0K(2PA-2$V(2$E(B4C)20E)24F)2<E
M*"4I)2HE*R4L)2TE+B4O)3`E,24R)3,E-"4U)38E-R4X)3DE.B4[)3PE/24^
M)3\E0"5!)4(E0R5$)44E1B5')4@E225*)4LE3"5-)4XE3R50)5$E4B53)50E
M5256)5<E6"59)5HE6R5<)5TE7B5?)6`E825B)6,E9"5E)68E9R5H)6DE:B5K
M)6PE;25N)6\E<"5Q)7(E<R5T)74E=B4F(3PA,R$T(6PP>D,W/'Q+9CXP.V4^
M/#)423]-(E`O,6XS(U`D0$)25C4Z2F<^/DY"2B109D,E4'HV)E!=-#!#9SPG
M4"A0*5`U1U<U-T=C1D,X,TM):2I0:#XK4#4R939P.&E,)E9P37U&)30U-2Q0
M+5`[3CU-:$$O4'8[<T8R4#XQ7SA>.&8P2T]*3S,Z(3`S4#10-5`T2S90<CAG
M,')+?#5]-7XU8D0\3C=0.%`Y4$T_.CU./SY0/%`]4%@U(SIP,CM0.E`I2D8[
M13L^0C]054EG0#@A0%!"4&5"84Y*,$%0/C)$-F=#;S=#4"1':S1$4$LP8#AL
M-'I),DA9-7$R9U!!16Q'1E`\2&).+3]'.W<[0#)11")#2E!,,&-$.STT.B1-
M3D(_,DE0/DU%4$=0;CI(4"154%!34%%00C([2DM03U!S.$@[)C144$Q08TYX
M.TU04E!54$Y0(39-,"(V03(E57E+;DET."\_-TY82C@W)4)D,E,]65!>4%Q0
M5U`O0EI075!;4%U*6%`N/W-+7U!@4"0];5!01S9):%!P2C8R;%!F4&]04D%$
M.%Q'1V!N4%U%8U!V.'4X85!:/&E0;TI-0V50<3=B4&I09%!13FM004]F-G`W
M<%!Q4'503C!02G10<U!W4'909$1R-WA013PF0F5$=C9Y4#8U>E!\4#5+9C<Q
M.W=(>U!%.D--?E`C47U01#I]/3DW)%%/-B%1(E$O1GQ!(S9-2R51/4XF42E1
M)U%.02A1*E$L42M12$HW-2Y1+U$O,BU1=#PR43%1,%%64#-1?CTT425-64PV
M4351.%$W43E1.E%T,#4X.S<\/7M#)#9H0'<X;CD\44A,1D5Y.SM1/5%>174S
M/E%^1C1!0%%!42Q(>#@[3T)1)C8\2C9"<38U17,W0U%$46)&7S%'47TZ1E%&
M.DA1;F9)44%+2E%+44Q1:3Y,/"<T3U%-43U,3E%:25!145%245]%5E%44551
M4U%C.E=1:DQD3EA1*$!945H]6E%\0S].8$5%4EM1)71%-EQ17DMH/7Q"7E%D
M1E]18%$N,V%1)S9,1GHQ4#TA2&)1845//V-1+$I:0"(T*31D4691.C=E47-.
M:3T]2$Q*9U%X36A1:5%^16I1*4!^.G0W:U%).V\Y9D1M42=";SIN46]1,$%L
M47%1-DMD.7!1=3=>.FU'=%%R47M):CY[460S=5%S44]!=U%V440S8#=\42U.
M>%%]47I1>5%/3GDX0S)T3G4]6$5E.2)2(U)E3BM/)5)Z."12+S,F4E9+/$0F
M35E*)U)5<#!&*%(J-#-,(3XI4F=*+5(J0"I24#8K4BLT+C<N4B]2,%(Q4EL\
M>SA>3&A,=T9Q2C)2,U(U4C=2-E(X4CTR3$M\.CE264$B/BDV.E);2#M2/%(]
M4CY2)$EH-F4P/T8_4CT]:4!!4D!2(SYA.$-2/DA$4EQ(-$)N0B@V;D8Q0VY'
M3DM&4FI`-3='4DA2+#%U,&TT*$)1-7%-2U(W,DI2*C9,4G%,35)23GPX-CA.
M4E!23U)?/SDQ7C%14E)2-SA34FXU,CM44G1+-3I:-2=-4$$_2'T\1SUH/'4\
M=CU`2%=20S%107TX13AG-EM2(4-^0BLV)#Y<4EI21#)F0C@\2SLF,7`S9CE*
M.UU27E))-48S9SE(-5]$)3$Q1CY,(3EY34=%?C@O-V=28S9*2UU(9E)>-&%2
M8E)D4F526S5A/RU*8U)?4F,X8%(D3W)*:$1B.'`Y:%)=1FQ2?CQV/&]2;5(C
M3&I2<U)N4G%21C@_3')2=%)V4G`Z0D]K4FE2=5)P4GA2(U-Z4GY2(5-[4CY3
M:3HQ,WE2)5-V,"13)3!*22)3?%)W4GU22#HF4W<P+U,G4RA3)3YI2RU3+%,O
M12Y3*U,T,38Z,#\I4V)%*E,B,#13(TTG/CI3.5,P4T-",5-O0C93)CXS4V1,
M/#<W4SA3-5,[4S)305-&4T)3/5-'4S%!25,B.3]3?4-#4SQ3+31N-&4S1%-`
M4W8W2E-(4U-!2C4L-D53=#9$,4Y33%,G5%%32U-/4TU33#M04U-36%-64U53
M,D-%,E)35%,H/C,Q5U->,F)3?#Y>4UQ375-?4STQ.4%94UI3>C-A4V\T9%-@
M4V-3+DI51CA(9E-E4T4S9U-J4VE3:%,Y1VM3;%-N4VU3<%-S4W%3;U-R4W13
M=5-V4W=3>%-%47P\33MS,G@P1$-Y4R0Z3S!>/WI31SAQ.7Q3>U-@2GU3(51^
M4R)4(U1W-V`Q)%0F5"54*%1:12E4-3!?.CTW3T,J5"M4+50N5&0Z438W2RQ4
M+U1!.B,Y,U0E.C-#,%1:1#148C\R5#54/S<V5#=4)#E`,SE4.E0[5#A4,50\
M5#U49$MK/C]40%0^5$)4.$=H,%9)0U1]/CD\74=P-&LZ64LR1G@W3T)!5$14
M1$)%5$942%1I1"XT(71A,7-*;#Y(168Z3E0]2EU.=#)*5#I!351C14E%9$4Y
M2$U$23I)5'8Q-D5+5$=44#]/5$X]+3905&A*?4%&1%)43TM35%A4+TI75%%4
M5%165"8Z24I95$5#=3)M/EM46E1H.5Q47E1=5&!4551B5&%47U1..U$_5$%C
M5#Q`;3!D1UM$951D5&949U1H5&E444IJ5$8R:U0\33`S25)(/3]";%1K3#1,
M;E1G0C=%0$)726]4<%1[,3H\<510,')4<U1B,7$T8$9T2G=454%V5$`W6TMU
M5&5%>51X5'M4>E1\,7Q4*3Y^5"5#?50S2G<]6T4A524Y(E4A1UY(44PE1RM5
M.#5%32],+%8C529514(X2TI%)U5E2THZ*CXH55`[3SLY,$@X*T!1,"Q5+54J
M53@Q+S0I545,,4DH,'DP43M2,",P,E4P53Q,,U4Q52]5,3\N55I*9#@W53A5
M*SXT52Q/3$<V52<Z.55823I5-54[3%Y'.U4R23Q50%4]54<R/U4[/#Y5>3=,
M54550E5D0T%50U5$54951U5R-$E52%5*56X^355<1$4Q2U5.54]54E5055%5
M4CM3528Y5%5Z.SA"555655H[)SE23"@U23A755@S6%4Y0EE5(U9:55M57%5>
M55]58%5P0B<Q:3Q",%=!,#0U/"@Y9D4A/3$T:$-J1#@P.35U2D(\4C5K0#P\
M*$UA55PU2SHR,V,Q+#Y(,F)51DU)/60\8U5S-%)&*4QD565564EG52@T=S9F
M53(T,C]K52$[23)J56A5;%5I52M'35PS/VU50$YN57!5?D-O52-`>SM00G<\
M=4EL0$T\<54M/G)5<U53,#I"4C]T53-&+CXO/G55;4`P/G95=U5@3'A51C8B
M/7E5>E5</"P_=$94/WA((D=)-GM5;S5\57XV3T8P,E,[?54B5B%6?39^53A%
M,$)+14@\6$%Z3216)5961C,[)U8H5BE6=#0J5BM6+#([060T+58H3%)"63,O
M5C%67S0N5C!6,U8R5C16-58]1BXV93(V5CM6.59W2G9*9T4X5E0]-U9R/SQ6
M:CI"5D-6/58S,SY61U9&5D56059`5D16>$I+5DA62E9R34E6/U9S/TQ6-SI-
M5DY645905D]6:$4Z5E=64U925E1655985F9.65965EI68#1;5EU67%9>5E]6
M;D`C/60]8T$I.3@Z*CEP-6!6.3I*.&%6)DQ#1V)6*SDL-"=#4C94.UM)04AC
M5G4T9E8A1&569%9G5FM$8S]5.TI`4T(B-2)$:%9I5F\^.4ML5FM6:E9]27-6
M6DMM5F]6:TMN5G!6*$AQ5CY*<E8S-#]*+T=T5G56+#DT-'96.#A$32E-=C1X
M5B-$+3DQ/E](,CYX/6Q$>4HY12XY7$EY5EE%0CI+.&U$0S!N/2\Y1TUZ5GM6
M44=\5G=.+4]^5GU61S,A5R17)5<C5T!),SXG5R97(E<H5RE7*E<M5RM7+%<N
M5V0Q;D0O5WHW=C(V1S!7>T9;2C%7+D\R5T!*-5<A4#%0,#QU1C97734D1'HP
M-U<F2C`Y4$-O1&],.3A,.#A7.5<_5V4\)40O-CI7*TE&0SM7/%<P-CU7/E=`
M5W9%05="5T-7-%<S5T1703<G24PZ-TDF1$M)15<T/D8Q1E='5W),8$A*5WTQ
M+$!)5TA70C=40DY73%=+5R=.93AY/4U73$4^/4!&45=05T]74E=F.%-7?$E;
M/517>4A!1B=$,$555RLU-#\L27<T)D=65U8[.DL[2WXQ6U=I0UA7=S(M6%I7
M,$=95U=7>CE=5V-7:5=A5UQ%9E==26!795=G3E<[54)>5UXU:%<M0&4Q8E=X
M,F=7,39D5VI7;%=V5W17<5=P5WA.<E<R-C$Y>CUY5VM7;U=?5WHR<U=U5U%#
M*#HX,FU7>%=W5S,V*4)F,T,W;E=Z5WU7(5@]/"=8<$1[5R58>3(C6"18?E<B
M6&<X*DTU-%DQ)E@Z1RTP84A<5RQ8,%AE3"E8:44N6'`^+UA71D=/*U@Q6'LY
M2T!4,"I8*%A:07Q7-#M&0CU86T$X6#58-EAF/#E8/%@W6"4].E@T6'Q,>TP^
M6#]853`S6'(V)C`V-#M80UA"6$=82%A&6$E805A%6$I82UA`6'P[1%A60C(Y
M,E@U/UA8:4I.6$]84%A76%98?4LW-%1813<T,U%8.$Y36%8P55A,6%)865A$
M-TU874TK35Q88%A^07E.85A>6%M86EA?6#!*-$9&-V)875AC6'LW,3)K6#@T
M:5AJ6"DZ:%AF6&58;%AD6&Y8>S)P6&]8*$1S6'%89UA\-W)8=EAU6'=8=%AX
M6'E8>EAJ2GQ8>U@_/2Y`9C)\,GU8/S!,0'Y80VPA66$W(EEO0"-9)%DZ-259
M)EDG65="33AA3#Q+:CTH67!`/6YB2&H\33HI64=")TIQ0BQ9*EDM62M9+EDQ
M2C<P7DEC2"]9,EDU/CLU,%DW638^,5E$1UY-,UDT63A9:D4U63,Y7D!&631(
M<D)D2"U:>DIQ1'5+.UDA,FI#1%DT0SY915E`64=90UE"66]'/%E],CI9<35S
M0C99.5DT.5M`-SY!65)'<C5(,V<S(3])64Y92EE]-T]9(CMI.28]/5E].TQ9
M6#M-640P2%DI1',U-#9+62<P0SHV/W)$5$A165Y!*D(K.U)95%E066%*/41<
M07M*3CQ@65]9>#]^-UE9.3YH1C%'5UE=07@\7%DX/E996UE31U59(3==,UU9
M*TY..C5#6EE<0#4Y9#]F,3Q!6%E%-4<W3T1>65]!85EC63=":5ED669904ES
M1&=9+$U(33DT+C!E66)9>#1G,6A924UL63M"<UEM66I9<5E366Y9<EE"2&M%
M:UEO64@W<3I=0'=9)D5T66!+=5EV64Y,(D!B-WU9-3MZ67E9,D<U1C%%>UE\
M66])14<C.W%`4$M),R5:?EE*32=:(UHD6F!!(EH_629:(5HK6BQ:)T4N6B0[
M*5H\-2]:*%HS6C):,5HT6C9:<3XU6CE:-UHX6G!9.UHZ6GA9/%HP6ED[/5H^
M6D!:/UI!6GXR-CE\2B]`3CA#6D9:4DE?-45:1%I41T=:-39)6DA:.C0V.UA&
M23=T/TI:,$`H15])2UI,6DU:.$I=549`3$E8.F5(0TA-14%.3UI0/%!:-C!4
M-DU`8$E16D([1T-;.S<_4EI]2G<Q7#M56E-:5EHY3E1:>T!76C)"6%IZ-%I:
M65I;6EQ:>S1\1C9#;#5=.V%!7#TP,%U:(C)A6C<Y8%HK.CH^7UH[/D!,*CI7
M,$Y`9EHQ0$<Q53UF2W(Z/#XG0&5:8UID6FM#)EMJ6GX[.#EH6FE:.#]G6B\[
M;%IK6G!:<5IM6B(S;EIO6E5(84E*-W):,D`]/E)#1S9S6G=:2S)T6G9:=5IK
M/4A#13!X6GE:*D1Q3D,[:TH]2R);>UI^6GU:>EHA6UY&?%HC6VP])%M+37A'
M)5LG6RA;*5M*-D@Q.3DJ6RM;<3UB05A2/D$]05A"1SIR4&XW+4U^2GY)+%MS
M.C]$+5LO3SY+*T0N6WPT+ULP6UI,)$QV2UQ+)3LR6VL\44LT6S=;-EMY-&`U
M,ULU6SA;>3][34DP8#H\0ET\<SX[6TY%.5LK0CI;<CY=3#Q;/5MH34);.CE5
M1S];;$5>6F):3S5'1T%;/CY$2$=;>D@^6T1;0UM/0&U+4TYG2TPR7CM(3T9;
M=3]%6T!;3SA,6TI;33)(6TY;5%M(0D%*5ELB255;<$<_2SLT=T!`/5-$+DU1
M6U!;4EM/6U=;35M+6U-;25ML0WA,1CQT.CHZ;TM!,TY$2D9),7)`-$`J-UE;
M.SE\,UM;=#-A6UY;<T!+,RPZ2C-/.EQ;93=+-VU%6EM&,%U;7UM--BPW/#1+
M-6);>3IQ2S<[8ULP26];,S)D6W5;95M"3FQ;7T=T6V=;-#!I6SPY:UMJ6V9;
M<5L_/FU4:#A\36A;=$0C,RTZ8%MP6V$S;EMR6VY%?C0R7$E,=UM]-'Y;0$LA
M7"-<)UQY6RI#;T4K7'Q;*%PB7#D_+%PS0"I</3103W9;)EQ8,'A;.DQ]6R(_
M1T1S6R5<>C\O7'$S(3@Q7'I;,%PI7'M;+5PN7#]<3D8D7#M</5Q81$Q-=DDX
M7$I"/EP_035<0EQ!7&]&0%QJ1D1<-UQ(-CI<73U@1SQ<2S8T7#9<,UPP3UHS
M.5Q#7#4S9SI=,51<,4]77#H_5EQ57%)<1EQC7$5<6%Q07$M<2%Q)7%%<(G1.
M7#TY2$1D04Q<1UQ*7$U-:DM/7%E<85Q:7&=<95Q@7%]<4$1E05U<6UQB7&A<
M=4AN7&E<;%QF7'1#.$E<7&1<0#Y/3'A<:UPB.",R7S-37$$^<%QW7'D\<C,N
M0VU<<EQV7#8V3#5T7"$U2T9S7'5<;UQQ7&`S24-\7'I<:3AY7"%=6%M[7'U<
M?EPL72A=;5LG729=(UUJ7"5=)%TJ729/+5U[-BE=*UTG2"Y=,ETO77--,%U>
M7#-=-%TU,39=9S<A/%4V)#)?33A=-UTZ73TU5C8^-#U=/%T^74XR-T,_73\T
M05U`74)=0UU$75\[-4`A.G!)8DI$3W4[4#IR3D5=1EU@.T==2%U*74E=6$M>
M/6P\1#M+74U=(S],74Y=3UU075%=4EU475-=55TE,DI#5ETF.TPS5UU"14Q4
M(S5875E=;$IH2T=&6EUF2'M(4TQ;75U=7%U?75Y=85UA.S%,8EUC720U9%UF
M765=93\Y24HQ14AU1$$]835&2"X\:%U`-'@Q<D9G73XY4T-I77%=:EU!0F(U
M<EUH-R4U<%UN76M=8$U`1%E&;%UT77-=(S<M,CLZ;5UO75=+=$)W2WQ=?5U/
M,BA*?4PA7B,\0CYX77Y=:#$W-G5=>EUT0'%'9TAW72%+>5TD7B)>>UTB2TA'
M8S4E16U#)5XC7EE"=EU+,4Y-,%XO7G9`+%YL339&)EY%1$PQ/SDI7B<]+EXM
M7BA>*UYH,RI>24<N3G0^=4`V7C1>34DQ7C->.C%`.3)//3-B26%-)#,[/S5>
M.EY#/C!--UXR7CA>7DYS14)&-C-5,3Y>05Y#3F1-2%Y"7C]>5$Y%7DH]1UY,
M7G%%2EY$7CA#2UY`7D9>35Y\,$->3EX\/U\])4HN.CM>25XZ139`:3-1.D0^
M/5Y"/4PW/%Y27FT].CAA7EM>=#5/159>7UXO,#(Q.3)87BQ"3UY17D$Y8EY=
M7E5>7%XK3%I>7EY0.$4^.4-47B]-5UY07G)%4UY97E%//CQ^2V->+DAO7CLX
M8#UE7B].0CER7FXP<%YD7FI>;%Y/36=>+D5I7G%>:UY'3&9>(CQ^7FHS:%YM
M7FY>;$):0G9>?%YZ7BE%(U]W7GA>8%YY-3I)/SQW.3-/=%XB7VDQ9D%Y1T$T
M>DXA3%)$>UY]7C)!(5]Y7G->0S1I-R]?*E]X0&,S83TS7RQ?+$0I7UE$3%\F
M7R5?+E\H7R=?+5\A0"1?,%\Q7T(T-E\U7S=?.E]#131?.%]C-WE",E\[1SE?
M/E\\7S]?0E\[7VHY*$<Y7G1-/5]!7W5"0%\K7VEO15])7T=?0U]$7TA?1E].
M24Y?2U]*7TU?5$9/7W5#;4(E0%!?4E]17W5>4U]G1E1?4#)T124S9#5>/%(Z
M)T]F/VHQ5E]57UE?.D-<7U=?6U]:7T!%63!U3EY?*#%@7U]?75]87R-+8E]A
M7VLQ9%\R2F-?-4Q'/C-!1CY[3FI?>4!F7VM?;#%I7V%'95]H7T@^44AL7U$\
M>D!O7V=?)S=M7U!-<%\F=$\]<5]R7RY'=%]U7S-'=45W7WE?54YV7WA?;3%S
M7UM3>E]G03@[?%][7R0_65)]7R%@;E]^7R)@>D<C8"1@)6`F8%Y$*&`G8"E@
M*F!?/&-);$PK8"Q@5D$D/"U@+F`O8%)*1T@P8%='+40Q8&<R;35&3#9,-#(T
M3U)+*DHW0#)@0T8C.#-@5#HU8#1@-F`W8#A@/C4Y8#I@)#A(2#Q@=3X[8#@V
M/6`_8#Y@0&!1.$%@:39`07TY0V!$8$)@;3Q(1CDV1F`L0T5@-4]B1TE@2V!(
M8%1,2F!,8$1.4&!/8'9#+4<E.$Y@36`Q33)-46!N,78Y8CM28%-@56!#/5=@
M5F!88$TS6F!98%Q@6V`\."A.3#8F,FHV831H3EY@8&!A8%$R76`Y.T%$7V!D
M8&X\8F`^-TE(8V!^8&E@/3AE-69@?4TP3G9":&!J8%9.5S9\2$I':V!M8'!@
M;&!O8&HX33%Q8'`_;F!<3G1@)'1R8'5@9V!S8#PZ=F!W8'Y->&!Y8&5@>F!$
M-"4\>V!\8'U@.S$A83M)(F$D-"-A)&$E82=A*&$F85-)*F$I82QA*V$M82YA
M,&$O87DY,F$Q844T4S\\13-A.$`Z.WDQ-&%136-*-6%$13--0SD]/TM#-%(N
M1&@R-F$W83QA.F$Y84):)C,X85HP*DA*2#%./6$[85Q#)D`K2"U)/V$L3DTW
M0&$^859(06%"85LP=CY'841A;49#828U2F%%849A26%(825)0D%!03\U2V%,
M84UA3V%.858Q5V%H2%%A4V%583X_5F%484`\4&%284))23Y985AA6F$F/"\Z
M=T5;84M$76$A3EQA:4%B861A96%40V-A8&%>85]A86%H869A9V%I86MA;&%M
M86YA:F%P86]A<6%%3G1A<F%S86(T?DQ*2G9A=6%W87AA?&%Y87IA>V%]87YA
M(6(B8B-B+TA0121B<D<T225B)F(J12<S1#DG8BAB*6(I.RMB*F(L8BUB:4@N
M8B]B:7,P8C%B,F(N.S-B5D=?2TXQ5S$T8C9B-6)P13E`.5TW8D%,.&)&-%=(
M.6(Z8CMB7$Q53#Y$:D$]8F(]2CY`8C]B/F)]2$<T*3A&8D-B/S\R3$)B1&)%
M8D%B1V)(8B]$8S1E0TEB2F)-8F<_1$9.8E-+2V),8E%B4&)/8E-B4F)48E9B
M56)-2E8]1DY78C=&6&)98EUB6V)<8EIB7F)?8F!B86(W3&)B<$QC8DY#:D=K
M-CM#9&(Z-E!`96(].F9B9V(F.%4Z:6)6158Z3C4D2TM'5T5<.6MB2SXR3D4Y
M)S@C2&UB;V)K.&YB=D1Q8C<S;&)J2#`Q;#I23W!B<F)+2EE`=&)U8G-B3C-[
M8GIB)SQ\8G=B?6)X8EA(=F)Y8B)C(6-A2WYB:S`D8R-C3#XE8T-!)V,F8RAC
M:&)J8BIC*6,H/&E.4CPK8S<W0#4G-6,[-$TQ8S!C1$$M8R]C2SU`/RYC+&,J
M1TT^/$E7.GA%,F,S8TEC6#8]3S5!-&-2,G=$(4HU8WHU-F,X8SEC*4<Z8SMC
M/&-9-E,R148H/60[/6,I/4HR0TD^8VM(14%!8T)C:4=!/S]C84-`8TX^7#`I
M-4-C>$1$8T=`+4PC245C1F-50T=.2&-'8V\\2F-P,$UC2V-4,DXW3&-&.7(Y
M9DI.8U1+4&-10$\Q.C(L,$]C46-28W<^4V-/,U5C:C=F-59C=3978WQ`349@
M0'4Z6&-B0VM!6F-<8UEC6V,B-UUC)C=G-5)-7V-@8RXQ8V-V,V)C86-E8UYC
M9F,I3F=C:&-T5&IC:6-K8VQC-4YM8V]P3SYN8V]C5STX1G!C*$-Q8SQ#<F,E
M-C]174,S/$@T<V,B9'9C:#5U8R1D=&-0/GAC>6,K17IC7C-:/V1)?&-H0G=C
M>V-]8WLZ)F0N229(>45:-B5D(V0U2'YC7D-[17I%=CHX9"AD*F0M9"YD*V0L
M9"ED)V0A9$]*53(U9#)D-V0V9'-')TP[.S!D.60T9#-D+V0Q9$DT/4-]0")(
M/F0D2&%`.V1/2#]D4TI;0SID/&0]9$!D1#Q&1D5D1&1!9#9/2F1.9$MD1V1(
M9$UD0F154DED0V1,9%)D2C1/9%!D46149%-D=DA59'Q.;4I:9%=D5F120%ED
M6V189%]D7&1=9$9D7F1@9&%D1DIB9&),3C8I-V-D-$IH/S!,9&0S3G1'1D$T
M1TT]0#!I9&=D960A-%$^:F1H9&9D;F1M9&QD:V1O9'!D.D!Q9'-D<F12.#A!
M=61\171D=F0U2FQ!1SEW9$A.>61Z9'MD?&1E.WUD3S=J-2HU(65S3$@Y?F0D
M969,/$<S26,](V53/$DY9CMI-39*(F5'04)+=SIG.UU$)V5?3EDZ*&5"/RIE
M4CXP.BEE*CT^.$A!)64K929E4#<N93)E:S<M939E2CEM33PP,V5K-3!E,65]
M12]E+&4H,V1`*#@X935E-V4T95$W,T(Y96Y!1F5"93QE0&5Z/%TP.V5#94=E
M2SE63%9$/65%93IE/D,_93TP2DP^95LV;$AM05!.;SUN94AE?D!$94EE2V5Y
M1$YE2F542DLT2TQ>,$UE?4Y,96\Q;$9/959E4&5795-E>T=*/%5E4F5895%E
M1#TE2TP]5&5@95QE7V5=96%E6V5!95-`2TA>95EE(4%2-RL])3\V061E9F5G
M96-E965:96)E:F5I97I+*S=H96QE:V5O97%E/#MM97)E<V5T97IE.T5V975E
M=V5X97EE>V5\94PT?65^92%F(F8C9B1F)68F9BAF)V8I9BIF*V8N9BQF+69A
M.E,W5D,S2'`]34=M2"]F;5@P9C)F94TQ9C1F,V93335F?D@V9CEF.&8W9CIF
M,C<B04$U/F8[9CQF/V9`9CUF*3$G,D)F0V9$9F)-+#U&9D5F:3]'9DAF269E
M-$TT2F9+9EU+8TU433=/33E.9E0\369/9BD\44)09DPY5TQ19E)F4V949E5F
M*CQM3%=F/T-69EEF6&9:9CM`6V9<9CE*769O05YF7V9^3F)F869@9C!$8V8F
M/V1F968X3V9F9V9I9FAF)4AY1CY/*4AK9E,^*DEL9FIF3C14.&@[;D@J.$-+
M;V9M9DXY3SEI,&@Z64=?,'1F0$-81UM"=F9R9G5F<&9S9B9+53A],'%F>&9Y
M9CE&.S8F9SU':3L\-DA`1D\N3'=F5$!3-7IF?&9[9GUF)D,^1S%$(V<B9WYF
M53]E225G)&=0.5-/-6<I9RIG<#PH9W@Y)V<K9S)$(DHC05Q"+V<P9RQG+6<N
M9U$Y-F<R9V9);$LH23%G-&<S9T1+-V<X9S=!.6<[9S]G/&<Z9S]'/6<^9S(R
M16=`9T%G0F<A0D1G0V=&9T=G2&=#/VDR26=73BL\+3UJ.U=#2F=+9S$Q3&=-
M9TYG3V=09STV*EI19V5`4F=+/%-G,%!49UY*7#0D05@]<4DN/55G4CE69TQ(
M9&=89TE"=4<_.%=G)4%99WI$6V=:9UUG7&=>9V!G7V=/-&%G8F=C9S$Z24YE
M9R<_<#%F9V=G:&=R,&EG:F=G24<\;&<I,S(P:V=N9TY'1#]6,B=+73=<-FUG
M:C(C-'$Q<F=J3EU"1$E^9U<R?&=Z9W%G;V=P9V,\;#9W0U%&43%T9W-G>6=U
M9WAG4$QW9U@R?3-[9WUG5#<C:"QH+6@K,#1H<3`K:"IH)6@D:")H(6AC0WM"
M)V@F:"EH<$%5-T$Q*&A3.7%!.F@[:%DR+C(X:"YH-F@]:#=H-6AV9S-H+VA0
M-#%H/&@R:#YH,&A\1VE-.6A/:$=H>S]&-5TV0FA;,E0^16A:.E%%2FAN2D%H
M6C)6."E)2V@_:$AH4FA#:$1H.D9):$9H*$M,:&`P0&A.:$UH:T=4:%]H?C-B
M:%!H56AN35YH54TJ3GA#:S-R261H(48Q,%UH66AR05-H6VA@:"Q'*C!8:&%H
M>$E<:%=H53XO/2P\6$Q'26=H<&A::'<S>#YE:&IH<T%F:&UH7T-N:%9-8V@X
M,VEH;&@L3&]H:&AK:"E+(4]S:'IH<FA#/%%H3DHB3'EH>&AT:'5H-C%W:'%H
M541V:'XP(D)#2GMH(6E92'YH5CY)/"-I/C8D:7E)?6A6:'QH3T\B1G-)*VDQ
M:3)I)6EV1R]I)VDI:3-I*&DL:7(Q948M:3!I)FDF02II)SM%/S`W=$QY3'(]
M-VDU:4Y/-&EU339I.&DY:3QI.FDC1CMI34@N:7,]/6E":71!06DB:4-I24$^
M:4!I/VDQ72)=16E$:79-/&)&:4=I2&E7.%0U2FE=474U.DYS-DMI3&EN0TUI
M>D8Z,&,R4FE3:4YI/3M/:4)'4&E1:5MI56E8:51I5FE7:5@\66E!0U8W0C-<
M:3\S86E=:6!I.DA>:5]I2$E:2&)I?4)L:6AI:S)F:2I+9VED:65I:FEM:6MI
M:6EC:5A#=&DJ3')I<VEN:7!I<6EO:69`.4]X:7EI(6HJ/WMI?FEV:75I(FI<
M,GQI(VI]:7II,T1W:6A')VH[329J)6HN:BAJ,&IF33-J*FHK:B]J,FHQ:BEJ
M+&H]:C9J-&HU:CIJ.VHJ,T(U.6HD:CAJ/&HW:CYJ0&H_:D)J06I::49J0VI$
M:D5J1VIL-TEJ2&HP/50Y)UY*:E$].3-+:E(Q5SY,:E4Y36IA,#U)3FIJ/U5J
M4FIO0U-J4&I>-D]J5FHV-UY"7&I8:C5"5VI::E%J6VI=:F](66I>:F!J4SA4
M:D$P7VI;.G9.86IB:G5!(DYC:C5-9&IE:F1*9FI`.B-.:VIL:E@^:FIG36=J
M:6H]0'X_:&IM:B-*;VIN:FPS*TMP:GQJ<FIS:G1J=6IY:GIJ>&IV:G%J=VI[
M:C=P*#)^:E\V?6HB:R%K)&LC:R5K,3TF:R=K*&L^0%=-*6LD2D9'*FLK:RLX
M+#4L:VL[04<M:U`S+FLP:W=-+VM&/S%K,FLS:U$T-&LU:S9K-VM1,SAK.6LZ
M:W(R*#\[:SQK/6M`.'M$/FM7-U8_06LD1D!K,3<_:W="+35":T-K63YM-T1K
M+$M?0'8U=4Q*045K1S]P0UH^1FM):TIK/CI"0DAK6SX^24=K;#M3,4YK6#=N
M.VT[34]-:TQK)T%--4-/.C-</DMK4&M1:T]K6#A`36\[)T=4:T!`0D,V35=K
M;#@_0%-K6&MM.%5K5FM2:V)`248O0UTR<$A#-31$6VM9:TQ#04!2-%IK6S]*
M3D!/7&MG:S5$9FMC:VMK9&M@:WQ$7VM=:R%-<#MA:UYK96MT/4$X>D)%2UHQ
M8C`E1FEK:&MF1FUK8FML:VYK+#AJ:U8Y53QO:UA-<FMU:W-K-4EP:V`V=&MV
M:WIK=VMY:WAK>VLQ/'UK?&MH22%L63=^:R)L(VQ$-4%F>3XD;&XX)6PF;#X[
M3EHG;"AL,CTI;"IL*VPL;"UL*T,N;#!L+VPF1C%L+4LR;#-L-&PU;%I&73XV
M;&LY+E`W;#AL/TDY;$%L.FP\;#ML/6Q&2SYL/VQ`;$)L+3-G1&E)8CI7.4])
M7S).2$5L4S150$1L26QY0V-,1VQ(;"XU2FQC1U]"<4@]149L1TML,DQL*$]"
M1$5/<3M+;#%"7&PH07A&4$E/;#\[<CM>/F5'+3A.;$UL:DE!/%)%46Q2;%@Y
M4&Q3;%1L5FPC0E5L9C18;%=L66Q;;%UL7FQ60$\\7VQ2,V!L=D%A;&)L:TDO
M-6-L-D1;,61L<3QV/RU"9VQF;&5L;6QK;&AL:FQI;&QL=S5P;%=`<6Q9.&YL
M;VPI3S=$*4%R;'5L<VQT;%E-)T9X;'9L=VQY;"EM?&Q];'ML>FQ]1"%M)6TB
M;7YL(VTD;2MM)FU80"AM*FTG;2UM,STL;2YM+VTR;3%M,&TT;3-M=DPV;35M
M-VTX;3IM.6U(/SMM;38\;3YM/VU`;3UM06U6/$)M,#4S-RXX0VUP1CY%1&U'
M;30\1FU%;5HW2&U3,TIM7#I);5)M3&U.;65*2VU-;5%M3VTQ-5!M4VU:1UA.
M-#U4;2)-5FU5;5EM04U8;6TS5VU<;5MM6FTR15UM7FU?;6PY)3=@;6%M8FU)
M/V-M+3QD;65M(5)^469M<&5G;21#*S]`1VAM54I41'XY*4,J,7A+5S]>-V$V
M5DII;6MM:FU@,G9&;&UW1S-%;6U2/6]M0DQ^;7%M<FU)1&!"=T$H1G!M535Y
M;79M)6XI1F!#<VU^1%-%=&UX;6`_9T=,1$)`=VTN0B1"=6TI,")/>FUA0C4]
M2C]\;7MM;S!];2]))VY;1FL_64-X-B9N-TT_,5=*83(A;B)N(VXD;CM&(T-C
M,"AN*6XC=#U"*FYS,4Q!+SA:32MN+$5X05<\+&XO;F4]+6XK02I!9#!+3C%N
M<D@S;C)N,&YD8U0T;FTU;C1N-FXX36%&+DLW;ED\.&XY;CIN(45J,%DY.D\^
M;C0W.VX\;G1)5#,Y33\V5$4_;D!N06XB14-N0FY31D1N-CU@/%M'<4-R/&P_
M16Y&;ET_1VY(;DEN;TTW/4MN2FY:.7,Y0#M.;F8]36Y,;FE";SA#0#!(.3U/
M;E\^4FY0;E%N5&Y3;GH^56Y6;E=N4$A3.F$\6&Y9;B1.13UN3$Q.6FYB-EMN
M(T5>;G@S2S]<;EUN8$152WPV8&YA;E]N8VY?1D,S9VYD;F9N8FY/;V5N:TY:
M.&]N-$5J;FUN:VYP;G%N:6YV;G0Q:&XM2&QN8#Y;.4A+9#9&/3Q&+4%T;FYN
M<VY#3#A$=6YR;BQ!>6YX;G=N+TM[/7IN7TI4,49)<D-X-7QN73DL.WMN;3]N
M/R%O(V][/B)O)&]3-D5)8CPC3WYN>#H_3R9O)6\G;WUN:49515=$+&]#0RAO
M*6\M-RMO,#@J;V$^>3,P;S\Z>4%*1#LS+F\O;T-$+6\Q;S=O.F\Y;RU%,F\S
M;S9O.&]`-CMO-6\T;S]O0&]!;SYO/6]B/BI&/&]%;T-O1&]";WA"1F]';TEO
M531(;WI,5&]*;TUO2V],;TYO4&]1;U)O56]3;U9O6&]7;SE$9TQ9;RY!6F]$
M2EMO*S,\,5<T5C1<;UUO7F]?;V!O6#15,UXY-DAB;V%O8V]<,69O96]D;V=O
M:F]',&AO;&]K;VYO;6]O;RY&<&]Q;W-O<F]L271O=6]E.G9O=V])2TM!)#!+
M0GAO;4E[;WEO7SEZ;T(X14I];R%P?F\B<"$Q6#]\/5DT(W!F1R5P(C$D<$1$
M34XK1GQO)DXQ.%M->38T3B@W8D(A9R9P+#-O/U8S*'`I<"=P9#==.F,^(S%9
M3BMP+FXJ<"YP+'`M<"]P,'!L3C%P,G!)0#M(?3]G-#I-;3(X/5LX-7`T<',[
M-G`S<"@[.G`M:E92=S\X<"5.<48K,6-`-CPW2D`Q;4YK33MP145[/#QP/7!,
M/SYP;DXY<$!P0G!!<#]P0W!$<'I!8C)%<#A,1G!'<"I/,5M(<$EP2G!.<$MP
M3'!-<$]P1$!W3$5`4'!S2%%P4W-,3%)P4W!4<%<S5G!9/U=P)#=8<%QP6G!;
M<',S67!=<%YP2#!?<&!P9#YA<$<U9'!C<&)P<6M<2F5P9G!G<&AP:7!J<%HT
M:W!L<"-';G`[,G%P<'`D,4$V1THZ1"(Z8#EG/5P_<W!R<$)-:#122%Q&?#].
M3ELW=G!U<$M++$90,7=P='!126I->'!Y<'MP:D);,UPS>G!I-#(X:C0_16!.
M7#A\<'UP?G`A<2-Q(G%W221Q)7$F<2=Q*7$H<2IQ=$A,9BD_,C4K<2QQ+%([
M75-(>S`[,'0[,$M^/BUQ7TPN<5Q-0C%!.R]Q;C(P<3%Q,W$T<39Q,G$U<5LT
M-W$X<3EQ.G$[<3UQ/'$_<4)Q/G%`<4%Q0W%"-G,\1'%%<6$Y1G$^,T]'1W%(
M<5I#:T9)<7U'3$)8,6XV;S9S0TYQ<#9O,DUQ2W%,<4IQ6'%/<5!Q47%2<51Q
M4W%9/55Q5W$S-59Q>T$S.%EQ34):<2U&6W%@<5YQ77%?<5QQ8G%A<61Q0S9C
M<65Q9G%H<6=Q:7%K<6IQ?#EL<6UQ/#-N<6]Q<3]P<7%Q<G%S<6(Y='%U<79Q
M=W%X<3%(>G$F27MQ>7%]<7QQ?G$A<B)R(W(D<B5R)G(G<BAR*7(J<BMR+'(M
M<BYR-5TO<GAD-#4A,S(Z,7(P<B5,,W(T<C)R-7)B2S9R>S4E3S=R.7(^,#IR
M*THX<CMR/'(]<CYR/W)N2RT[>CHO04!R0W)!<D1R<3A"<D5R1G)'<DMR*CMD
M0DQR27)(<DIR7S=0<D]R3G(S,%IR5G)7<E-R67)5<F(S3$]8<E1R4G)1<EQR
M7W)><EUR24E;<G,P8')B<F\S37(W,61R8W)A<BU#<$M:3F5R9G)G<FAR:7([
M1&IR-TAO<FMR;'(Q2T1,4$9P<G%R/D9N<FUR*C)Y<GAR=3%V<G5R<W)[,W)R
M,CPI,F,Y?')[<GIR=W)]<GYR)7,D<R9S+3$A<R)S=#DY3"-S,DLK<R=S+',I
M<RAS7#<M<RYS+W,J<W1R,'-A1#1S-7,S<S)S.',Q<S9S-W,Z<SES/',]<SYS
M24\[<VM";3H_<T!S07-"<T-S-#A$<T5S+SQ&<T=S2'-)<TQS2G,\3TMS;TY-
M<UM.3G-^1T]S47-2<U!S;3E-3&-+=U9@77M+*S)4<U`U57-6<U=S=3E8<U1@
M6TQC0EES6W-:<UQS77-><U]S8'-A<V)S8W-D<V5S9G-G<VAS)$5=.&IS34%K
M<VQS(4EM<VYS-V-:;&UP;W-P<W)S<W-T<W!.<7-U<W9S>'-W<WIS>W-Y<S9.
M?'-]<U1C?G,J(70A<"%S(74A2B%+(78A7"$D(24A/R$P(S$C,B,S(S0C-2,V
M(S<C.",Y(R<A*"%C(6$A9"$I(7<A02-"(T,C1"-%(T8C1R-((TDC2B-+(TPC
M32-.(T\C4"-1(U(C4R-4(U4C5B-7(U@C62-:(TXA0"%/(3`A,B$N(6$C8B-C
M(V0C92-F(V<C:"-I(VHC:R-L(VTC;B-O(W`C<2-R(W,C="-U(W8C=R-X(WDC
M>B-0(4,A42$Q(6\A``"#&GK?CQK__Y\:__^O&O__OQK__\\:_S_=&@``W1H`
M`-T:``#=&@``W1H``-T:``#=&@``W1H``-T:*```````KP&+;[D!\T/"`4(D
MQ@%&F\X!+.C5`>#CW0$$`-X!"D#A`65?ZP$VV_4!=WD``DD$!`+7[`\"\.,8
M`CA@'0+%""("`N8H`@,T+0(`@"X"434U`LC@.P*K?D8"`()(`FF83P)(J54"
M0BE:`@/H8`)@@&,"'$1H`I.M<0(ZP'<":$5]`F"J@P)6AHH">C^5`D`"EP*(
M@YP"812A`B`0HP)T(:D"(2"L`@('L`(`,+("O$"X`B2FO@)B1,,"J&#(`B`*
MRP(7`M`"=(77`@($V0*$G-\"^WOL`A44\0(D?_H"XA$``V6V"0/O`A$#=1\;
M`_\@)`-P.BL#0#@O`\,F-@-C9S\#V4U(`Y(@3`.P1E(#R0]:`YB\8@-02&8#
M.(9L`S^@=`.((WD#%HA^`PD^A0,R4HL#JB*1`Z3CF0/=`)\#+,>G`V:AK@/A
M)K4#"X2Z`PJ/P0/K)\L#GE74`T'"V0.[B>(#%`#D`T"%Z`-A8^\#20CS`PQ_
M_`/0B@($/O\/!,\%%P0:_R($`Z@G!$%Z+@1`>S4$14<\!`*`/@0`!4`$ZSA)
M!%'84`0%`%($-)E9!`QQ7P27`V8$``%G!&9C;P0$)'($T(!V!%$`>00`P'L$
M"D.`!'&0A@3(,(L$"`",!`!8CP29#I8$`/>=!(!?I`1!`*8$L`"I!!"4K008
M`*\$@&*S!$`"M030";H$`(*\!%8!P00$4,0$`0C&!!`=RP00!<X$P833!!``
MU`0E0-@$4!#;!`]!X02*3>@$"4#K!`VF\@09J_H$3)$`!<`A!`6!"0@%A<0.
M!0,`$`52!A4%`(`6!00+&@4(`!L%'00@!0D`(@5)2"<%7)`M!0D`+P60%C0%
M90PZ!2`B/042A$$%,R1'!0,,2P661U,%!`I6!25"6P4H`%T%B)!A!0!)9`4(
M3VH%HA1O!:K3>`4PV'X%ASZ'!02&BP5A'Y,%I'Z<!89!H060PZ<%LP6N!:57
MMP48(;L%'B3!!4@JQ@4H$<H%!$K.!4`*T04;%M@%8`W=!4"(X`4*`N,%`I7H
M!2&"[`5@$.\%0P+S!0`$]`5$%/@%`(#Y!0``^04$#/P%``#\!0!P_P4&&@0&
MP0`'!DH""P8`#`T&`!H0!D``$08$%!0&14`8!BD`&P:SO28&>`HL!BL%,@:I
MNSP&H+]%!GQ`2P9Y@U,&_!);!AWH8P;V2VT&:<5U!O;O@@9*!(8&%2&+!@+_
ME`9C[9X&*T"C!C/0J@9"`JT&`!"N!A,`L08"&[8&REF^!J``P`8``L$&`Z?(
M!D$LS0:`2-`&\H_:!@0"W`8``-P&`%C?!@40X@8`DN4&2`#G!I08[`8!(.X&
M!%#Q!H`T]08`,O@&3&C^!NI)!@>^:`\'3!@4!T(N&@<@J!X'R2$D![E0*P>P
M@"\''@`S!WS_0`>:A$8'X!1+!\$H4`?@`50'#H=;!TFL8@</$VD'V]UU!QJ^
M?@?[B8@'X**.!Z)1E`<"59D'RC*@!T8^J`>+DJ\'OQVZ!X]#P@<#9\D'&#+.
M!R@PT@?`,]@'$0C;!R.IX@<`P.0'93KL!^./]@<"!/@'3BS_!R6&!0@]OQ$(
MH0`4"!HZ&PC4C"((R08H"'PQ,`C@`#,("I4Y"(L!/@C;#D<(2^-0""",5`B"
M$5@($/!=")1]9@@HIVT(K,EU"/M`?0B$1($(4P:'")!:C0A$1)$(R#^:"`$`
MFPA(`)T(U/6G"`%WK@A7[+@(0L2]"!V)Q`B#:\P(*$G1"`E!U0A"TML('0;A
M"/Y9[`@`&.X((CKT".2W_@B?.PD)`_`/">K`%@F&$QP)`H(?"8")(PD`Y"<)
M`+(K":$0+PF`2S0)Q`PY"0G30`E$B44)KQ]0"31(50E9@EL)10Q@"0I"9`E0
M!&<)0*!J"<@0;@E`,7()4$1V"01`>`D``7D)@()\"4`%?PD(`8$)+$2&"3!J
MC`D%&I$)IB"6"10%F@G/D*()5F2I"2$`JPD`,:X)&)RT"?#+O0D@H<$)XF/)
M"4P0S0FU`=,)C%/:"8.:X0FRN.D)@3+N"7J8]@F$"OH)YS,$"@(,!PK,U`\*
M&)`3"J&A&0IPD!X*'HHE"@3@*0K4PS$*400U"II#/`K"(4$*1$A%"A!32@J2
M`DX*0#93"D$"5@J]\V(*":MI"O#H<0K`?7D*TJ6!"D+"A@I+THX*/Z27"J_0
MH`J@&J4*H32K"D>"L0K8`[<*4L2]"AMEQ0J4TLP*.LC3"AP`U@K(0-H*!@[?
M"A0SY0I/8>T*&[+U"H@`]PK0P/P**J`!"YBH!PO%H0X+:Q86"U`N'`NTA2,+
MB\`I"P0&+`LS^38+!!X["VX%0@M1HD@+``1)"SAV40L'[%D+N'-B"P9$9@LR
M&&L+@4!N"Q;(=`N*?'P+"6.""X`IA@L$JHL+)!R0"YS*F`L.3I\+8">E"Y`)
MJ0L`@ZP+1@"O"P2!L@L18+8+@1"Y"PU4OPL("<(+#@#%"PK,RPL`!<T+``S/
M"S`$T@M$H-8+BP#:"X1GX0N(4N8+&8KL"UZ&]`L8B_H+62X"#&!!!@P0C`H,
MOIP4#&%H&@P<B2`,`)@C#`@`)`P`@28,F@@K#!@`+0R003$,!T`U#*'D/`P%
M!4`,#61&#`XQ3`Q-#E,,!DA7#`K_80PR%F<,J"IM#"Z%=`P+`'<,`!AY#(3*
M?PP@#H,,;&F+##(`C@P`%I$,6%:8#)`#G`P@4:`,*!JE#`"`I@PD$:H,X1BP
M#"9#M@Q27;X,J@[%#*`/RPPHKM(,>_K>#`!%X0P(9.4,0(GI#(#([0Q$P/$,
M!9#U#$&Q^PPDA/\,Q"0$#30:"@TZ8!`-`)`2#93!&`U&@AT-.@`A#0T8)@T&
MP2L-(@`M#1"9,@U0X#<-$14\#5=`0@V"`$0-&@1(#0H"2PU/`%`-,(E5#1/8
M7`U*1&$-`HIE#2+M;0W`$'`-!4!S#0`0=`T"`78-"(AY#0$Q?0T`1H`-!`*"
M#0#PA@T(!XH-`(F-#0"BD`T``)`-`B*3#0`"E`T0%I@-0@":#4`0G`T`4I\-
M8`*B#?12J@T`(*L-$(6O#3""LPT`$;4-`D*X#0A#O`VU@,(-X7#)#2":S@U`
M(-`-`0C2#0`UU@UE_.`-P1GF#02K[`V&`O`-%&+U#8<`^0U$`/L-A9``#D0"
M`PY<0`@.A0H-#@<R$PZ`,Q@.``09#L"X'PX@SB4.T,`J#C#`+@Z``"\."`4R
M#B4-.`Z0"CP.0``]#@`"/@X,"$$.!65'#@!`2`XA9$T.`D%0#F@"5`X``%0.
M)`!6#GR$70X"`%X.(-YE#AF&:PY)0&\."`AQ#@!`<@Z$`'0.`2!V#@"$>`X0
M$'H.S4*!#L<!APXX<(T.*M65#F@9FPZ/':0.4+ZL#A(^LP[U+KT.V8'$#L3.
MS`X2)-`.*`C3#BYSW`ZL).(.-$OI#@P"[`X=U/0.`BKX#@"`^0Z7`/X.$0@!
M#\01!@]$$0H/AA<1#T5]&@_922(/208G#P!`*`^1AR\/3"4U#\38/`^Z1$,/
M%$E(#Y(;3P\`R%(/<0)7#X`56P^!`%T/``Q?#VH)90\`PF@/`$AJ#P)`;`\A
M,'`/2;IX#X`@>@^`''X/K.*&#P@0B`\$$(H/-`"-#^$`D0\4A)4/(`"6#P`@
MEP\`F)H/%!"=#\)PHP^J!*@/B(:M#R!4L0]B#+8/$P2Z#X"1O@\0(,`/@D##
M#P8"Q@]`',H/`%3-#X,#T@_IY-L/)2'@#X"$XP\SY.L/`"#L#\!$\`\)YO</
M`PK[#R:!`!#:$@<0`0@)$`%I#A"0EQ40`4`7$(;X'Q!-XB<0@0`I$`X*+A!1
MIC40&@$Y$.R!0!``QD00081($+BM41`LMED0;Z1B$$&':!!4C6\0`DMT$&$1
M>1!H`GT08+N%$%<@BQ"@4(\0,P24$,"HF1"TMZ,0`B2F$!(!J1#3FK(0`""S
M$'$BN1#(`+P0@2"_$)Z`Q1"*#,H0@.'/$`FPU!!1@=D0,1#=$"A`X!`.*N80
MI8GM$+9I]A`.8OP0)40!$431!Q&%@`L15$T2$74L&A&Q'R,1!]@J$2V&,1%\
MV#H104@^$4Y!1!%N(DL1`()-$0B>4Q$,^%H1-^UE$8",:1$F=7$1$Y-X$10(
M>Q$R#H$1!,B%$4Y(BQ&F;I012BR:$7!FH1'`)J81`;JL$0S3LQ%=&+H1``"Z
M$0``NA$``+H1``"Z$0``NA$``+H1``"Z$0``NA$``+H10`6]$2!PP1$S@<<1
M@4_.$:4#U!'L5=T1$&3A$1C#YQ%$(^P18A3Q$30`]!%#"OD1"1K^$7L8!A*E
M$PT2`@$/$DBH%!)`!!821,4<$@:!(!+=XBH2\!HQ$D@M-Q(FMC\2%@1#$EA0
M2!)`;DX2,H!2$A(Q5Q+D!UX2``Q@$@B"8Q(*0F<20$AJ$CN`<!)@2'02$X=[
M$@V%@1(H-(82&0.+$BGEDQ)%(YD2"H>?$JDEIA(87*P2IG>V$L79OQ(`7L02
MZ`/*$H$`S!(`I]$25,W9$L9!WQ(`*.$2!*+E$F"XZQ(**_$2(`#R$I[:_!+J
M"`(3&@X($WQ"#Q/`$1,3"(D7$W8#'A,AAB,3!0$F$P``)A.H&"L3H$8P$TC$
M-1,%#3H3(B`]$R)40A-(D4<3`8I+$Y<H4A.8>%D3"`!:$P467Q,B,6030$)G
M$X`(:1-.^G,3H@9X$Q0(>Q,1DH`3`B""$P2;B!-2+H\30P:4$P!0EA,0D)D3
M00";$[J%HQ-",*<3(""I$PM/L1.@!;43"">Z$X!`O!.1!<$3DQK($U#?T1,`
M!M,3`J+7$R$PVQ,P!M\3@$[D$\0,Z1/(!.T3!*#P$P&`\A,`8/03,=3[$X`(
M_1,""@`4`!P#%"@`!108C@L400`-%-!J%!00RAD4$/(?%`!+(Q1-)RL4!A4P
M%"`",A20B#84`%HZ%*B"/Q1)14444(%)%`0@2Q0`@$P4!(A/%`@L4Q31"%@4
M!0!:%`&`7!3$2F(4(.!F%&(`:12.`&T40@IQ%%4P=Q2,:GX4#@F#%*7@BA0&
M*8\4Q$*4%!1(F!2S@)X4/H"D%#"SJQ0"`:T4''.U%)04NA0-8+\4(`S"%$`)
MQ10:,,H40,#-%%&DTQ24P-@4RHW@%,@%Y13"ENP4#*3Q%`$`\A0$-/84R`#Y
M%!`!^Q0-50(5R:D*%2@D#A5:'!450@$8%3=('Q5->B@5#Q`M%;0R-!4J13H5
M>S%#%0622!64N$\51%Q5%==H7A6*1605EU!K%=$N<Q5#&7D5"$)\%0+2@15`
MG8<50)B+%9<@D14)5)8530:<%0``G!4``)P5``"<%0``G!4``)P5``"<%0``
MG!4``)P5``"<%8"$GQ5"5:45(02H%08<K14`%[$5)':X%1!AO!6'_\@5W;G3
M%9]EW14*7.,5723J%0`\[A6PK?8560#Z%0``^A4``/H5``#Z%0``^A70*/\5
MFP`$%B($!Q8``@@6"`$*%@A$#18$F!$60*P6%@J-'!8HD"`6`(<D%@'@*!8`
M!"D6,0`L%I07,Q8A@C<6&0`Z%E00/A:R+$46&@))%@*<3A8#0%$68#U8%@2(
M6Q8,"%X6`'EC%B@6:!8\NG$60(9U%@C+>Q9T<H,6@)"&%AX`BA8``(H6``"*
M%@#8CA:(X906AYR<%C1`H!82!*,69*ZK%I$GLA9KZ+L6^^;'%H]`S19F4]46
MIN[?%G]3ZA8KX_,6Y+7\%I^&!1<"``872(4+%R(!#A<"1!$7``@2%Q8A%Q>@
M(!H7!``;%P0"'1<`(!X7!0`@%P!^)A=4`2H7+!8P%ZP!-1>$*CH7A1`^%Q2,
M0Q<P!4<7P_M2%T.Y6A?*`%X78)!B%P!@9!<R0&@7`!)J%Y"`;1<P"W(7@4QW
M%U0`>A<"0'P7*0!_%VH=AQ<`((@7@`**%P"`BQ<$`(P7$":0%PP5E1=`@)<7
M`0>;%TW9I!<D#*@7$"BK%U`8KQ<!4+(7(%"U%P`0MA?0!+H7@'"^%P$"P!<(
M`<(7PR'(%S(!S!<``,P7B`#.%QD'U!<""-878`7:%Q(`W!<.3.(7!03E%Z'P
M[!<"`.T7``#M%P``[1<``.T7``#M%P``[1<``.T7``#M%P``[1<``.T7``#M
M%P``[1<``.T7``#M%P``[1>``.X7C8[V%UH#_!>](008!%H)&(@T#AAP$1,8
M)@`6&```%A@``!88`!`7&`+%'!@$B!\8%;@F&`'X+!A\%#,8[24\&&#M1!BP
M&TL8B050&-<;6ACS>F488AIK&`P-<!C%"G88T>5_&$I2A1B0!(@8!6..&%0#
MDQA$4I@85RNA&!(6IAARJ*T8`1&P&$DIMA@8`+@82`F\&`@0OA@`8,`8;(C&
M&&Z1SAB/!=48$C#9&)`YWQA`^.48,$GJ&("([1@;`/$8``#Q&```\1@`A?08
M0@#V&%@`^1@`F/P8!.H"&11P!QDH%@P9'6$3&1-1&1D`8!L9)!H@&:<`)1D`
M`"49```E&0``)1G``RD9('$N&1@0,1ER`389)ZD^&01@01D&B489(L!*&0P"
M31D`"4\9@4!2&2T@5QF@C%P9-`YB&0``8AD``&(9``!B&0`A9!D!$6<9$8!J
M&1K!<!E,['@9D@A\&4``?1D`A8`9K,>)&088C1D^X)49$@69&0"`FAD0`)L9
M"$"=&<Z`HQD!;:D9$`*K&4&&L!E6"+49'@&Z&2<`OAE0-\49/0C+&3+@T1D%
M3M<9P`':&80$W1F!`-\90`'A&0``X1D``.$9``#A&0``X1D``.$9``#A&:`:
MYAE9`.H9R$/P&22(]!E('?H9`,C]&5(!`1H#<@<:$Y`,&@0$#AJ`@A$:``02
M&A"*%AH4#1L:5H`@&@@"(AI`H"4:!"<J&@``*AH`3"T:```M&@``+1H``"T:
M```M&@``+1H@HS(:`ADV&JZ@/1I@)D(:`-])&A#P3AH5>U<:(8%;&M`Z8AJ`
M064:*`!G&@,0:AH`2&P:`,QP&A2`<QK/%'L:Q`!^&@`@?QH@,((:`0``````
M`````````````````````.@`[__W`#\0_@```/X```#^`/[_#0'__QT!__\M
M`?__/0'__TT!#WA5`?[_9`'__W0!__^$`?__E`'__Z0!?WBU``^0NP"9.<,`
M.9G+`)F9TP`$"-4```#5````U0```-4```#5````U0`#`-<`###;`,#(X```
M`.```(#A````X0!@`.,```#C````XP```.,`!0#E````Y0``I`````!]````
M?0!A,X0`8P"(``T(C````(P```",````C````(P```",````C````(P```",
M````C````(P```",````C``(`(T```"-```(C@```(X```".````C@```(X`
M``".````C@`/`)(```"2````D@```)(`%`"4````E````)0`C0F:``1DG@"!
M'Z4`,""H````J``$`*D`PPRO````KP#,`+,```"S`"``M````+0```"T````
MM````+0```"T````M``$``````````````````````````````````L````+
M````"P````L````+````"P````L````+````"P````L`_O\:`/L#(P#^_S(`
M^P,[````.P```#L````[``(`/`#__TP`__]<`/__;`#__WP``@``````````
M`````````````````````````````````````````````````````````(P1
M!0!3``D````)`(``"@````H`@`"<3A95`UH_EL!4&V$H8_99(I!UA!R#4'JJ
M8.%C)6[M96:$IH+UFY-H)U>A97%BFUO067N&])AB?;Y]CIL68I]\MXB)6[5>
M"6.79DAHQY6-ET]GY4X*3TU/G4])4/)6-UG460%:"5S?8`]A<&$39@5ING!/
M=7!U^WFM?>]]PX`.A&.(`HM5D'J0.U.53J5.WU>R@,&0[W@`3O%8HFXXD#)Z
M*(.+@B^<05%P4[U4X53@5OM9%5_RF.MMY(`MA6*6<):@EON7"U3S4X=;SW"]
M?\*/Z)9O4UR=NGH13I-X_($F;AA6!%4=:QJ%.YSE6:E39FW<=(^50E:13DN0
M\I9/@PR9X5.V53!;<5\@9O-F!&@X;/-L*6U;=,AV3GHTF/&"6XA@BNV2LFVK
M=<IVQ9FF8`&+BHVRE8YIK5.&41)7,%A$6;1;]EXH8*EC]&._;!1OCG`4<5EQ
MU7$_<P%^=H+1@I>%8)!;DAN=:5B\95IL)77Y42Y995F`7]Q?O&+Z92IJ)VNT
M:XMSP7]6B2R=#IW$GJ%<EFQ[@P112URV8<:!=FAA<EE.^D]X4VE@*6Y/>O.7
M"TX64^Y.54\]3Z%/<T^@4N]3"58/6<%:MEOA6]%YAV:<9[9G3&NS;&MPPG.-
M>;YY/'J'>[&"VX($@W>#[X/3@V:'LHHI5JB,YH].D!Z7BH;$3^A<$6)9<CMU
MY8&]@OZ&P(S%EA.9U9G+3AI/XXG>5DI8REC[7NM?*F"48&)@T&$28M!B.65!
MFV9FL&AW;7!P3'6&=G5]I8+YAXN5CI:=C/%1OE(66;-4LUL676AA@FFO;8UX
MRX17B'**IY.XFFQMJ)G9AJ-7_V?.A@Z2@U*'5@14TU[A8KED/&@X:+MK<G.Z
M>&MZFHG2B6N-`X_MD*.5E)9IEV9;LUQ]:4V83IB;8R![*VI_:K9H#9Q?;W)2
MG55P8.QB.VT';M%N6X00B42/%$XYG/93&VDZ:H27*FA<4<-ZLH3<D8R36U8H
MG2)H!8,QA*5\"%+%@N9T?DZ#3Z!1TEL*4MA2YU+[79I5*ECF68Q;F%O;6W)>
M>5ZC8!]A8V&^8=MC8F719U-H^F@^:U-K5VPB;Y=O16^P=!AUXW8+=_]ZH7LA
M?.E]-G_P?YV`9H*>@[.)S(JKC(204923E9&5HI5EEM.7*)D8@CA.*U2X7,Q=
MJ7-,=CQWJ5SK?PN-P981F%286)@!3PY/<5.<56A6^E='60E;Q%N07`Q>?E[,
M7^YC.F?79>)E'V?+:,1H7VHP7L5K%VQ];']U2'EC6P!Z`'V]7X^)&(JTC'>-
MS(X=C^*8#IH\FX!.?5``49-9G%LO8H!B[&0Z:Z!RD75'>:E_^X>\BG"+K&/*
M@Z"7"50#5*M55&A8:G"*)WAU9\V>=%.B6QJ!4(8&D!A.14['3A%/RE,X5*Y;
M$U\E8%%E/6=";')LXVQX<`-T=GJN>@A[&GW^?&9]YV5;<KM315SH7=)BX&(9
M8R!N6H8QBMV-^)(!;Z9Y6INH3JM.K$Z;3Z!/T5!'4?9Z<5'V4513(5-_4^M3
MK%6#6.%<-U]*7R]@4&!M8!]C665+:L%LPG+M<N]W^(`%@0B"3H7WD.&3_Y=7
MF5J:\$[=42U<@69M:4!<\F9U:8ES4&B!?,50Y%)'5_Y=)I.D92-K/6LT=(%Y
MO7E+>\I]N8+,@W^(7XDYB]&/T9$?5("274XV4.53.E/7<I9SZ7?F@J^.QIG(
MF=*9=U$:85Z&L%5Z>G90TUM'D(66,D[;:N>145Q(7)ACGWJ3;'2788^J>HIQ
MB):"?!=H<'Y1:&R3\E(;5*N%$XJD?\V.X9!F4XB(07G"3[Y0$5)$45-5+5?J
M<XM745EB7X1?=6!V86=AJ6&R8SID;&5O9D)H$VYF=3UZ^WQ,?9E]2WYK?PZ#
M2H/-A@B*8XIFB_V.&IB/G;B"SH_HFX=2'V*#9,!OF99!:)%0(&MZ;%1O='I0
M?4"((XH(9_9..5`F4&50?%$X4F-2IU4/5P58S%KZ7K)A^&'S8G)C'&DI:GUR
MK'(N<Q1X;WAY?0QWJ8"+B1F+XHS2CF.0=9-ZEE68$YIXGD-1GU.S4WM>)E\;
M;I!NA'/^<T-]-X(`BOJ*4)9.3@M0Y%-\5/I6T5ED6_%=JUXG7SAB166O9U9N
MT'+*?+2(H8#A@/"#3H:'BNB--Y+'EF>8$Y^43I).#4](4TE4/E0O6HQ?H5^?
M8*=HCFI:=(%XGHJDBG>+D)%>3LF;I$Y\3Z]/&5`64$E1;%&?4KE2_E*:4^-3
M$50.5(E545>B5WU95%M=6X];Y5WG7?==>%Z#7II>MUX87U)@3&&78MABIV,[
M90)F0V;T9FUG(6B7:,MI7VPJ;6EM+VZ=;C)UAW9L>#]ZX'P%?1A]7GVQ?16`
M`X"O@+&`5(&/@2J"4H-,B&&(&XNBC/R,RI!UD7&2/WC\DJ25398%F)F9V)H[
MG5M2JU+W4PA4U5CW8N!O:HQ?C[F>2U$[4DI4_59`>G>18)W2GD1S"6]P@1%U
M_5_:8*B:VW*\CV1K`YC*3O!69%>^6%I::&#'80]F!F8Y:+%H]VW5=3I];H)"
MFYM.4$_)4P95;UWF7>Y=^V>9;'-T`GA0BI:3WXA05Z=>*V.U4*Q0C5$`9\E4
M7EB[6;!;:5]-8J%C/6AS:PAN?7#'D8!R%7@F>&UYCF4P?=R#P8@)CYN69%(H
M5U!G:G^AC+110E<JECI8BFFT@+)4#EW\5Y5X^IU<3TI2BU0^9"AF%&?U9X1Z
M5GLB?2^37&BMFSE[&5.*43=2WUOV8JYDYF0M9[IKJ871EI!VUIM,8P:3JYN_
M=E)F"4Z84,)3<5SH8))D8V5?:.9QRG,C=9=[@GZ5AH.+VXQXD1"9K&6K9HMK
MU4[43CI/?T\Z4OA3\E/C5=M6ZUC+6<E9_UE06TU<`EXK7M=?'6`'8R]E7%NO
M9;UEZ&6=9V)K>VL/;$5S27G!>?A\&7TK?:*``H'S@9:)7HIIBF:*C(KNBL>,
MW(S,EOR8;VN+3CQ/C4]045=;^EM(80%C0F8A:\MNNVP^<KUTU'7!>#IY#(`S
M@.J!E(2>CU!L?YX/7UB+*YWZ>OB.C5OKE@-.\5/W5S%9R5JD6XE@?VX&;[YU
MZHR?6P"%X'MR4/1GG8)A7$J%'GX.@IE1!%QH8V:-G&5N<3YY%WT%@!V+RHYN
MD,>&JI`?4/I2.EQ39WQP-7),D<B1*Y/E@L);,5_Y8#M.UE.(6TMB,6>*:^ER
MX',N>FN!HXU2D9:9$E'74VI4_UN(8SEJK'T`E]I6SE-H5)=;,5S>7>Y/`6'^
M8C)MP'G+>4)]37[2?^V!'X*0A$:(<HF0BW2.+X\QD$N1;)'&EIR1P$Y/3T51
M05.37PYBU&=!;`MN8W,F?LV1@Y+44QE9OUO1;5UY+GZ;?'Y8GW'Z45.(\(_*
M3_M<)6:L=^-Z'(+_F<91JE_L96]IB6OS;99N9&_^=A1]X5UUD(>1!ICF41U2
M0&*19MEF&FZV7M)]<G_X9J^%]X7XBJE2V5-S68]>D%]58.229):W4!]1W5(@
M4T=3[%/H5$95,5475FA9OED\6K5;!EP/7!%<&ER$7HI>X%YP7W]BA&+;8HQC
M=V,'9@QF+69V9GYGHF@?:C5JO&R(;0EN6&X\<29Q9W''=0%W77@!>65Y\'G@
M>A%[IWPY?9:`UH.+A$F%78CSB!^*/(I4BG.*88S>C*219I)^DQB4G):8EPI.
M"$X>3E=.EU%P4LY7-%C,6");.%[%8/YD86=69T1MMG)S=6-ZN(1RB[B1(),Q
M5O17_ICM8@UIEFOM<51^=X!R@N:)WYA5A[&/.UPX3^%/M4\'52!:W5OI6\-?
M3F$O8[!E2V;N:)MI>&WQ;3-UN74?=UYYYGDS?>.!KX*JA:J).HJKCIN/,I#=
MD0>7ND[!3@-2=5CL6`M<&G4]7$Z!"HK%CV.6;9<E>\^*")ABD?-6J%,7D#E4
M@E<E7JAC-&R*<&%WBWS@?W"(0I!4D1"3&)./EEYTQ)H'76E=<&6B9ZB-VY9N
M8TEG&6G%@Q>8P);^B(1O>F3X6Q9.+'!==2]FQ%$V4N)2TUF!7R=@$&(_971E
M'V9T9O)H%FAC:P5N<G(?==MVOGQ6@/!8_8A_B:"*DXK+BAV0DI%2EUF7B64.
M>@:!NY8M7MQ@&F*E911FD&?S=TUZ37P^?@J!K(QDC>&-7XZI>`=2V6*E8T)D
MF&(MBH-ZP'NLBNJ6=GT,@DF'V4Y(44-38%.C6P)<%ES=729B1V*P9!-H-&C)
M;$5M%VW39UQO3G%]<<ME?WJM>]I]2GZH?WJ!&X(Y@J:%;HK.C/6->)!WD*V2
MD9*#E:Z;35*$53AO-G%H485Y57ZS@<Y\3%916*A<JF/^9OUF6FG9<H]UCG4.
M>59YWWF7?"!]1'T'AC2*.Y9AD""?YU!U4LQ3XE,)4*I5[EA/63URBUMD7!U3
MXV#S8%QC@V,_8[MCS63I9?EFXUW-:?UI%6_E<8E.Z77X=I-ZWWS/?9Q]88!)
M@UB#;(2\A/N%Q8APC0&0;9"7DQR7$IK/4)=8CF'3@36%"(T@D,-/=%!'4G-3
M;V!)8U]G+&ZSC1^0UT]>7,J,SV6:?5)3EHAV4<-C6%MK6PI<#6119UR0UDX:
M62I9<&Q1BCY5%5BE6?!@4V+!9S6"56E`EL29*)I33P98_EL0@+%<+UZ%7R!@
M2V$T8O]F\&S>;LZ`?X'4@HN(N(P`D"Z0BI;;GMN;XT[P4R=9+'N-D4R8^9W=
M;B=P4U-$585;6&*>8M-BHFSO;R)T%XHXE,%O_HHX@^=1^(;J4^E31D]4D+"/
M:EDQ@?U=ZGJ_C]IH-XSX<DB</6JPBCE.6%,&5F97Q6*B8^9E3FOA;5MNK7#M
M=^]ZJGN[?3V`QH#+AI6*6Y/C5L=8/E^M999F@&JU:S=UQXHD4.5W,%<;7V5@
M>F9@;/1U&GIN?_2!&(=%D+.9R7M<=?EZ47O$A!"0Z7F2>C:#X5I`=RU.\DZ9
M6^!?O6(\9O%GZ&QKAG>(.XI.D?.2T)D7:B9P*G/G@E>$KXP!3D91RU&+5?5;
M%EXS7H%>%%\U7VM?M%_R81%CHF8=9VYO4G(Z=3IW=(`Y@7B!=H>_BMR*A8WS
MC9J2=Y4"F.6<Q5)78_1V%6>(;,USPXRNDW.6)6V<6`YIS&G]CYJ3VW4:D%I8
M`FBT8_MI0T\L;]AGNX\FA;1]5),_:7!O:E?W6"Q;+'TJ<@I4XY&TG:U.3D]<
M4'500U*>C$A4)%B:6QU>E5ZM7O=>'U^,8+5B.F/08Z]H0&R'>(YY"WK@?4>"
M`HKFBD2.$Y"XD"V1V)$.G^5L6&3B9'5E]&Z$=AM[:9#1D[IN\E2Y7Z1D38_M
MCT22>%%K6"E955R77OMMCWX<=;R,XHY;F+EP'4^_:[%O,'7[EDY1$%0U6%=8
MK%E@7))?EV5<9R%N>W;?@^V,%)#]D$V3)7@Z>*I2IEX?5W19$F`24%I1K%'-
M40!2$%546%A85UF56_9<BUV\8)5B+61Q9T-HO&C?:-=VV&UO;IMM;W#(<5-?
MV'5W>4E[5'M2>]9\<7TP4F.$:87DA0Z*!(M&C`^.`Y`/D!F4=I8MF#":V)7-
M4-52#%0"6`Y<IV&>9!YMLW?E>O2`!(13D(62X%P'G3]3EU^S7YQM>7)C=[]Y
MY'O2:^QRK8H#:&%J^%&!>C1I2ESVG.N"Q5M)D1YP>%9O7,=@9F6,;%J,09`3
MF%%4QV8-DDA9HY"%44U.ZE&9A0Z+6'!Z8TN38FFTF01^=W574V!IWX[CEEUL
MC$X\7!!?Z8\"4]&,B8!YAO]>Y65S3F51@ED_7.Z7^TZ*6<U?C8KA;[!Y8GGG
M6W&$*W.Q<71>]5][8YIDPW&8?$-._%Y+3MQ7HE:I8,-O#7W]@#.!OX&RCY>)
MI(;T78IBK62'B7=GXFP^;39T-'A&6G5_K8*LF?-/PU[=8I)C5V5O9\-V3'+,
M@+J`*8]-D0U0^5>26H5H<VED<?URMXSR6.",:I89D'^'Y'GG=RF$+T]E4EI3
MS6+/9\IL?7:4>Y5\-H*$A>N/W68@;P9R&WZK@\&9II[]4;%[<GBX>X>`2'OH
M:F%>C(!1=6!U:U%BDHQN>G:7D>J:$$]P?YQB3WNEE>F<>E996.2&O)8T3R12
M2E/-4]M3!EXL9)%E?V<^;$YL2'*O<NUS5'5!?BR"Z86IC,1[QI%I<1*8[Y@]
M8VEF:G7D=M!X0X7NABI345,F5(-9AUY\7[)@26)Y8JMBD&74:\QLLG6N=I%X
MV'G+?7=_I8"KB+F*NXQ_D%Z7VY@+:CA\F5`^7*Y?AV?8:S5T"7>.?SN?RF<7
M>CE3BW7MFF9?G8'Q@YB`/%_%7V)U1GL\D&=HZUF;6A!]?G8LB_5/:E\9:C=L
M`F_B=&AY:(A5BGF,WU[/8\5UTGG7@BB3\I*<A.V&+9S!5&Q?C&5<;15PIXS3
MC#N83V7V=`U.V$[@5RM99EK,6ZA1`UZ<7A9@=F)W9:=E;F9N;39R)GM0@9J!
MF8)<BZ",YHQTC1R61):N3ZMD9FL>@F&$:H7HD`%<4VFHF'J$5X4/3V]2J5]%
M7@UGCWEY@0>)AHGU;1=?56*X;,].:7*2FP92.U1T5K-8I&%N8AIQ;EF)?-Y\
M&WWPEH=E7H`93G5/=5%`6&-><UX*7\1G)DX]A8F56Y9S?`&8^U#!6%9VIW@E
M4J5W$86&>T]0"5E'<L=[Z'VZC]2/39"_3\E2*5H!7ZV7W4\7@NJ2`U=58VEK
M*W7<B!2/0GK?4I-856$*8JYFS6L_?.F#(U#X3P531E0Q6$E9G5OP7.]<*5V6
M7K%B9V,^9;EE"V?5;.%L^7`R>"M^WH"S@@R$[(0"AQ*)*HI*C*:0TI+]F/.<
M;)U/3J%.C5!64DI7J%D]7MA?V5\_8K1F&V?09])HDE$A?:J`J($`BXR,OXQ^
MDC*6(%0LF!=3U5!<4ZA8LF0T9V=R9G=&>N:1PU*A;(9K`%A,7E19+&?[?^%1
MQG9I9.AX5)N[GLM7N5DG9IIGSFOI5-EI55Z<@95GJIO^9U*<76BF3N-/R%.Y
M8BMGJVS$CZU/;7Z_G@=.8F&`;BMO$X5S5"IG19OS795[K%S&6QR'2F[1A!1Z
M"(&968U\$6P@=]E2(EDA<5]RVW<GEV&="VE_6AA:I5$-5'U4#F;?=O>/F)+T
MG.I977+%;DU1R6B_?>Q]8I>ZGGAD(6H"@X197UO;:QMS\G:R?1>`F80R42AG
MV9[N=F)G_U(%F21<.V)^?+",3U6V8`M]@)4!4U].ME$<63IR-H#.D25?XG>$
M4WE?!'VLA3.*C8Y6E_-GKH53E`EA"&&Y;%)V[8HXCR]544\J4<=2RU.E6WU>
MH&""8=9C"6?:9V=NC&TV<S=S,750>=6(F(I*D)&0]9#$EHV'%5F(3EE/#DZ)
MBC^/$)BM4'Q>EEFY6[A>VF/Z8\%DW&9*:=AI"VVV;I1Q*'6O>HI_`(!)A,F$
M@8DABPJ.99!]E@J9?F&18C)K@VQT;<Q__'_`;85_NH?XB&5GL8,\F/>6&VUA
M?3V$:I%Q3G534%T$:^MOS84MAJ>)*5(/5&5<3F>H:`9T@W3B=<^(X8C,D>*6
M>):+7X=SRWI.A*!C976)4D%MG&X)=%EU:WB2?(:6W'J-G[9/;F'%95R&ADZN
M3MI0(4[,4>Y;F66!:+QM'W-"=JUW''KG?&^"THI\D,^1=988F)M2T7TK4)A3
MEV?+;=!Q,W3H@2J/HY97G)^>8'1!6)EM+WU>F.1.-D^+3[=1L5*Z71Q@LG,\
M>=."-)*WEO:6"I>7GF*?IF9T:Q=2HU+(<,*(R5Y+8)!A(V])<3Y\]'UO@.Z$
M(Y`LDT)4;YO3:HEPPHSOC3*7M%)!6LI>!%\79WQIE&EJ;0]O8G+\<NU[`8!^
M@$N'SI!M49.>A'F+@#*3UHHM4(Q4<8IJ:\2,!X'18*!G\IV93IA.$)QKBL&%
M:(4`:7YNEWA5@?W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]__W_#%\03A5.*DXQ3C9./$X_3D).5DY83H).A4YKC(I.$H(-7XY.GDZ?
M3J!.HDZP3K-.MD[.3LU.Q$[&3L).UT[>3NU.WT[W3@E/6D\P3UM/74]73T=/
M=D^(3X]/F$][3VE/<$^13V]/AD^63QA1U$_?3\Y/V$_;3]%/VD_03^1/Y4\:
M4"A0%%`J4"50!5`<3_9/(5`I4"Q0_D_O3Q%0!E!#4$=0`V=54%!02%!:4%90
M;%!X4(!0FE"%4+10LE#)4,I0LU#"4-90WE#E4.U0XU#N4/E0]5`)40%1`E$6
M4151%%$:42%1.E$W43Q1.U$_44!14E%,45118E'X>FE1:E%N48!1@E'85HQ1
MB5&/49%1DU&54991I%&F4:)1J5&J4:M1LU&Q4;)1L%&U4;U1Q5')4=M1X%%5
MANE1[5'P4?51_E$$4@M2%%(.4B=2*E(N4C-2.5)/4D122U),4EY25%)J4G12
M:5)S4G]2?5*-4I12DE)Q4HA2D5*HCZ>/K%*M4KQ2M5+!4LU2UU+>4N-2YE+M
MF.!2\U+U4OA2^5(&4PA3.'4-4Q!3#U,54QI3(U,O4S%3,U,X4T!31E-%4Q=.
M25--4]917E-I4VY3&%E[4W=3@E.64Z!3IE.E4ZY3L%.V4\-3$GS9EM]3_&;N
M<>Y3Z%/M4_I3`50]5$!4+%0M5#Q4+E0V5"E4'51.5(]4=52.5%]4<51W5'!4
MDE1[5(!4=E2$5)!4AE3'5*)4N%2E5*Q4Q%3(5*A4JU3"5*14OE2\5-A4Y53F
M5`]5%%7]5.Y4[53Z5.)4.55`56-53%4N55Q5155655=5.%4S55U5F56`5:]4
MBE6?57M5?E6859Y5KE5\58-5J56'5:A5VE7%5=]5Q%7<5>15U%445O=5%E;^
M5?U5&U;Y54Y64%;?<316-E8R5CA6:U9D5B]6;%9J5H96@%:*5J!6E%:/5J56
MKE:V5K16PE:\5L%6PU;`5LA6SE;15M-6UU;N5OE6`%?_5@17"5<(5PM7#5<3
M5QA7%E?'51Q7)E<W5SA73E<[5T!73U=I5\!7B%=A5W]7B5>35Z!7LU>D5ZI7
ML%?#5\97U%?25]-7"EC65^-7"U@96!U8<E@A6&)82UAP6,!K4E@]6'E8A5BY
M6)]8JUBZ6-Y8NUBX6*Y8Q5C36-%8UUC96-A8Y5C<6.18WUCO6/I8^5C[6/Q8
M_5@"60I9$%D;6:9H)5DL62U9,EDX63Y9TGI565!93EE:65A98EE@66=9;%EI
M67A9@5F=65Y/JT^C6;)9QEGH6=Q9C5G96=I9)5H?6A%:'%H)6AI:0%IL6DE:
M-5HV6F)::EJ:6KQ:OEK+6L):O5KC6M=:YEKI6M9:^EK[6@Q;"UL66S);T%HJ
M6S9;/EM#6T5;0%M16U5;6EM;6V5;:5MP6W-;=5MX6XAE>EN`6X-;IENX6\-;
MQUO)6]1;T%OD6^9;XEO>6^5;ZUOP6_9;\UL%7`=<"%P-7!-<(%PB7"A<.%PY
M7$%<1EQ.7%-<4%Q/7'%;;%QN7&).=EQY7(Q<D5R47)M9JUR[7+9<O%RW7,5<
MOES'7-E<Z5S]7/I<[5R,7>I<"UT571==7%T?71M=$5T472)=&ET971A=3%U2
M74Y=2UUL77-==EV'781=@EVB79U=K%VN7;U=D%VW7;Q=R5W-7=-=TEW67=M=
MZUWR7?5="UX:7AE>$5X;7C9>-UY$7D->0%Y.7E=>5%Y?7F)>9%Y'7G5>=EYZ
M7KR>?UZ@7L%>PE[(7M!>SU[67N->W5[:7MM>XE[A7NA>Z5[L7O%>\U[P7O1>
M^%[^7@-?"5]=7UQ?"U\17Q9?*5\M7SA?05](7TQ?3E\O7U%?5E]77UE?85]M
M7W-?=U^#7X)??U^*7XA?D5^'7YY?F5^87Z!?J%^M7[Q?UE_[7^1?^%_Q7]U?
MLV#_7R%@8&`98!!@*6`.8#%@&V`58"M@)F`/8#I@6F!!8&I@=V!?8$I@1F!-
M8&-@0V!D8$)@;&!K8%E@@6"-8.=@@V":8(1@FV"68)=@DF"G8(M@X6"X8.!@
MTV"T8/!?O6#&8+5@V&!-815A!F'V8/=@`&'T8/I@`V$A8?M@\6`-80YA1V$^
M82AA)V%*83]A/&$L831A/6%"841A<V%W85AA66%:86MA=&%O865A<6%?85UA
M4V%U89EAEF&'8:QAE&&:88IAD6&K8:YAS&'*8<EA]V'(8<-AQF&Z8<MA>7_-
M8>9AXV'V8?IA]&'_8?UA_&'^80!B"&()8@UB#&(48AMB'F(A8BIB+F(P8C)B
M,V)!8DYB7F)C8EMB8&)H8GQB@F*)8GYBDF*38I9BU&*#8I1BUV+18KMBSV+_
M8L9BU&3(8MQBS&+*8L)BQV*;8LEB#&/N8O%B)V,"8PAC[V+U8E!C/F--8QQD
M3V.68XYC@&.K8W9CHV./8XECGV.U8VMC:6.^8^ECP&/&8^-CR6/28_9CQ&,6
M9#1D!F039"9D-F0=91=D*&0/9&=D;V1V9$YD*F659)-DI62I9(ADO&3:9-)D
MQ63'9+MDV&3"9/%DYV0)@N!DX62L8N-D[V0L9?9D]&3R9/ID`&7]9!AE'&4%
M921E(V4K931E-64W939E.&5+=4AE5F5594UE6&5>95UE<F5X98)E@V6*BYME
MGV6K9;=EPV7&9<%EQ&7,9=)EVV799>!EX67Q97)G"F8#9OME<V<U9C9F-&8<
M9D]F1&9)9D%F7F9=9F1F9V9H9E]F8F9P9H-FB&:.9HEFA&:89IUFP6:Y9LEF
MOF:\9L1FN&;69MIFX&8_9N9FZ6;P9O5F]V8/9Q9G'F<F9R=G.)<N9S]G-F=!
M9SAG-V=&9UYG8&=99V-G9&>)9W!GJ6=\9VIGC&>+9Z9GH6>%9[=G[V>T9^QG
MLV?I9[AGY&?>9]UGXF?N9[EGSF?&9^=GG&H>:$9H*6A`:$UH,FA.:+-H*VA9
M:&-H=VA_:)]HCVBM:)1HG6B;:(-HKFJY:'1HM6B@:+IH#VF-:'YH`6G*:`AI
MV&@B:29IX6@,:<UHU&CG:-5H-FD2:01IUVCC:"5I^6C@:.]H*&DJ:1II(VDA
M:<9H>6EW:5QI>&EK:51I?FEN:3EI=&D]:5EI,&EA:5YI76F!:6IILFFN:=!I
MOVG!:=-IOFG.:>A;RFG=:;MIPVFG:2YJD6F@:9QIE6FT:=YIZ&D":AMJ_VD*
M:_EI\FGG:05JL6D>:NUI%&KK:0IJ$FK!:B-J$VI$:@QJ<FHV:GAJ1VIB:EEJ
M9FI(:CAJ(FJ0:HUJH&J$:J)JHVJ7:A>&NVK#:L)JN&JS:JQJWFK1:M]JJFK:
M:NIJ^VH%:Q:&^FH2:Q9K,9L?:SAK-VO<=CEK[IA':T-K26M0:UEK5&M;:U]K
M86MX:WEK?VN`:X1K@VN-:YAKE6N>:Z1KJFNK:Z]KLFNQ:[-KMVN\:\9KRVO3
M:]]K[&OK:_-K[VN^G@AL$VP4;!ML)&PC;%YL56QB;&IL@FR-;)IL@6R;;'YL
M:&QS;))LD&S$;/%LTVR];-=LQ6S=;*YLL6R^;+ILVVSO;-ELZFP?;4V(-FTK
M;3UM.&T9;35M,VT2;0QM8VV3;61M6FUY;5EMCFV5;>1OA6WY;15N"FZU;<=M
MYFVX;<9M[&W>;<QMZ&W2;<5M^FW9;>1MU6WJ;>YM+6YN;BYN&6YR;E]N/FXC
M;FMN*VYV;DUN'VY#;CIN3FXD;O]N'6XX;H)NJFZ8;LENMV[3;KUNKV[$;K)N
MU&[5;H]NI6[";I]N06\1;TQP[&[X;OYN/V_R;C%O[VXR;\QN/F\3;_=NAF]Z
M;WAO@6^`;V]O6V_S;VUO@F]\;UAOCF^1;\)O9F^S;Z-OH6^D;[EOQF^J;]]O
MU6_L;]1OV&_Q;^YOVV\)<`MP^F\1<`%P#W#^;QMP&G!T;QUP&'`?<#!P/G`R
M<%%P8W"9<))PKW#Q<*QPN'"S<*YPWW#+<-UPV7`)<?UP''$9<65Q57&(<69Q
M8G%,<59Q;'&/<?MQA'&5<:AQK''7<;EQOG'2<<EQU''.<>!Q[''G<?5Q_''Y
M<?]Q#7(0<AMR*'(M<BQR,'(R<CMR/'(_<D!R1G)+<EAR=')^<H)R@7*'<I)R
MEG*B<J=RN7*R<L-RQG+$<LYRTG+B<N!RX7+Y<O=R#U`7<PIS'',6<QUS-',O
M<RES)7,^<TYS3W/8GE=S:G-H<W!S>'-U<WMS>G/(<[-SSG.[<\!SY7/N<]YS
MHG0%=&]T)73X<S)T.G15=#]T7W19=$%T7'1I='!T8W1J='9T?G2+=)YTIW3*
M=,]TU'3Q<^!TXW3G=.ET[G3R=/!T\73X=/=T!'4#=05U#'4.=0UU%743=1YU
M)G4L=3QU1'5-=4IU275;=49U6G5I=61U9W5K=6UU>'5V=89UAW5T=8IUB76"
M=91UFG6==:5UHW7"=;-UPW6U=;UUN'6\=;%US77*==)UV77C==YU_G7_=?QU
M`7;P=?IU\G7S=0MV#78)=A]V)W8@=B%V(G8D=C1V,'8[=D=V2'9&=EQV6'9A
M=F)V:'9I=FIV9W9L=G!V<G9V=GAV?':`=H-VB':+=HYVEG:3=IEVFG:P=K1V
MN':Y=KIVPG;-=M9VTG;>=N%VY7;G=NIV+X;[=@AW!W<$=REW)'<>=R5W)G<;
M=S=W.'='=UIW:'=K=UMW97=_=WYW>7>.=XMWD7>@=YYWL'>V=[EWOW>\=[UW
MNW?'=\UWUW?:=]QWXW?N=_QW#'@2>"9Y('@J>45XCGAT>(9X?'B:>(QXHWBU
M>*IXKWC1>,9XRWC4>+YXO'C%>,IX['CG>-IX_7CT>`=Y$GD1>1EY+'DK>4!Y
M8'E7>5]Y6GE5>5-Y>GE_>8IYG7FG>4N?JGFN>;-YN7FZ><EYU7GG>>QYX7GC
M>0AZ#7H8>AEZ('H?>H!Y,7H[>CYZ-WI#>E=Z27IA>F)Z:7J=GW!Z>7I]>HAZ
MEWJ5>IAZEGJI>LAZL'JV>L5ZQ'J_>H.0QWK*>LUZSWK5>M-ZV7K:>MUZX7KB
M>N9Z[7KP>@)[#WL*>P9[,WL8>QE['GLU>RA[-GM0>WI[!'M->PM[3'M%>W5[
M97MT>V=[<'MQ>VQ[;GN=>YA[GWN->YQ[FGN+>Y)[CWM=>YE[RWO!>\Q[SWNT
M>\9[W7OI>Q%\%'SF>^5[8'P`?`=\$WSS>_=[%WP-?/9[(WPG?"I\'WPW?"M\
M/7Q,?$-\5'Q/?$!\4'Q8?%]\9'Q6?&5\;'QU?(-\D'RD?*U\HGRK?*%\J'RS
M?+)\L7RN?+E\O7S`?,5\PGS8?-)\W'SB?#N;[WSR?/1\]GSZ?`9]`GT<?15]
M"GU%?4M]+GTR?3]]-7U&?7-]5GU.?7)]:'UN?4]]8WV3?8E]6WV/?7U]FWVZ
M?:Y]HWVU?<=]O7VK?3U^HGVO?=Q]N'V??;!]V'W=?>1]WGW[??)]X7T%?@I^
M(WXA?A)^,7X??@E^"WXB?D9^9GX[?C5^.7Y#?C=^,GXZ?F=^77Y6?EY^67Y:
M?GE^:GYI?GQ^>WZ#?M5]?7ZNCW]^B'Z)?HQ^DGZ0?I-^E'Z6?HY^FWZ<?CA_
M.G]%?TQ_37].?U!_47]5?U1_6']??V!_:']I?V=_>'^"?X9_@W^(?X=_C'^4
M?YY_G7^:?Z-_KW^R?[E_KG^V?[A_<8O%?\9_RG_5?]1_X7_F?^E_\W_Y?]R8
M!H`$@`N`$H`8@!F`'(`A@"B`/X`[@$J`1H!2@%B`6H!?@&*`:(!S@'*`<(!V
M@'F`?8!_@(2`AH"%@)N`DX":@*V`D%&L@-N`Y8#9@-V`Q(#:@-:`"8'O@/&`
M&X$I@2.!+X%+@8N61H$^@5.!48'\@'&!;H%E@6:!=(&#@8B!BH&`@8*!H(&5
M@:2!HX%?@9.!J8&P@;6!OH&X@;V!P('"@;J!R8'-@=&!V8'8@<B!VH'?@>"!
MYX'Z@?N!_H$!@@*"!8('@@J"#8(0@A:"*8(K@CB",X)`@EF"6()=@EJ"7X)D
M@F*":()J@FN"+H)Q@G>">()^@HV"DH*K@I^"NX*L@N&"XX+?@M*"](+S@OJ"
MDX,#@_N"^8+>@@:#W(()@]F"-8,T@Q:#,H,Q@T"#.8-0@T6#+X,K@Q>#&(.%
M@YJ#JH.?@Z*#EH,C@XZ#AX.*@WR#M8-S@W6#H(.)@ZB#](,3A.N#SH/]@P.$
MV(,+A,&#]X,'A."#\H,-A"*$((2]@SB$!H7[@VV$*H0\A%J%A(1WA&N$K81N
MA(*$:81&A"R$;X1YA#6$RH1BA+F$OX2?A-F$S82[A-J$T(3!A,:$UH2AA"&%
M_X3TA!>%&(4LA1^%%844A?R$0(5CA5B%2(5!A0*&2X55A8"%I(6(A9&%BH6H
MA6V%E(6;A>J%AX6<A7>%?H60A<F%NH7/A;F%T(75A=V%Y87<A?F%"H83A@N&
M_H7ZA0:&(H8:AC"&/X9-AE5.5(9?AF>&<8:3AJ.&J8:JAHN&C(:VAJ^&Q(;&
MAK"&R88CB*N&U(;>ANF&[(;?AMN&[X82AP:'"(<`AP.'^X81APF'#8?YA@J'
M-(<_AS>'.X<EARF'&H=@AU^'>(=,ATZ'=(=7AVB';H=9AU.'8X=JAP6(HH>?
MAX*'KX?+A[V'P(?0A]:6JX?$A[.'QX?&A[N'[X?RA^"'#X@-B/Z']H?WAPZ(
MTH<1B!:(%8@BB"&(,8@VB#F()X@[B$2(0HA2B%F(7HABB&N(@8A^B)Z(=8A]
MB+6(<HB"B)>(DHBNB)F(HHB-B*2(L(B_B+&(PXC$B-2(V(C9B-V(^8@"B?R(
M](CHB/*(!(D,B0J)$XE#B1Z))8DJB2N)08E$B3N)-HDXB4R)'8E@B5Z)9HED
MB6V):HEOB72)=XE^B8.)B(F*B9.)F(FAB:F)IHFLB:^)LHFZB;V)OXG`B=J)
MW(G=B>>)](GXB0.*%HH0B@R*&XH=BB6*-HI!BEN*4HI&BDB*?(IMBFR*8HJ%
MBH**A(JHBJ&*D8JEBJ:*FHJCBL2*S8K"BMJ*ZXKSBN>*Y(KQBA2+X(KBBO>*
MWHK;B@R+!XL:B^&*%HL0BQ>+((LSBZN7)HLKBSZ+*(M!BTR+3XM.BTF+5HM;
MBUJ+:XM?BVR+;XMTBWV+@(N,BXZ+DHN3BY:+F8N:BSJ,08P_C$B,3(Q.C%",
M58QBC&R,>(QZC(*,B8R%C(J,C8R.C)2,?(R8C!UBK8RJC+V,LHRSC*Z,MHS(
MC,&,Y(SCC-J,_8SZC/N,!(T%C0J-!XT/C0V-$(U.GQ.-S8P4C1:-9XUMC7&-
M<XV!C9F-PHV^C;J-SXW:C=:-S(W;C<N-ZHWKC=^-XXW\C0B."8[_C1V.'HX0
MCA^.0HXUCC".-(Y*CD>.28Y,CE".2(Y9CF2.8(XJCF..58YVCG*.?(Z!CH>.
MA8Z$CHN.BHZ3CI&.E(Z9CJJ.H8ZLCK".QHZQCKZ.Q8[(CLN.VX[CCOR.^X[K
MCOZ."H\%CQ6/$H\9CQ./'(\?CQN/#(\FCS./.X\YCT6/0H\^CTR/28]&CTZ/
M5X]<CV*/8X]DCYR/GX^CCZV/KX^WC]J/Y8_BC^J/[X^'D/2/!9#YC_J/$9`5
MD"&0#9`>D!:0"Y`GD#:0-9`YD/B/3Y!0D%&04I`.D$F0/I!6D%B07I!HD&^0
M=I"HEG*0@I!]D(&0@)"*D(F0CY"HD*^0L9"UD.*0Y)!(8MN0`I$2D1F1,I$P
MD4J15I%8D6.199%ID7.1<I&+D8F1@I&BD:N1KY&JD;61M)&ZD<"1P9')D<N1
MT)'6D=^1X9';D?R1]9'VD1Z2_Y$4DBR2%9(1DEZ25Y)%DDF29))(DI62/Y)+
MDE"2G)*6DI.2FY):DL^2N9*WDNF2#Y/ZDD23+I,9DR*3&I,CDSJ3-9,[DUR3
M8)-\DVZ35I.PDZR3K9.4D[F3UI/7D^B3Y9/8D\.3W9/0D\B3Y),:E!24$Y0#
ME`>4$)0VE"N4-90AE#J40912E$246Y1@E&*47I1JE"F2<)1UE'>4?91:E'R4
M?I2!E'^4@I6'E8J5E)66E9B5F96@E:B5IY6ME;R5NY6YE;Z5RI7V;\.5S97,
ME=65U)76E=R5X97EE>*5(98HEBZ6+Y9"EDR63Y9+EG>67)9>EEV67Y9FEG*6
M;):-EIB6E9:7EJJ6IY:QEK*6L):TEK:6N):YELZ6RY;)ELV638G<E@V7U9;Y
ME@27!I<(EQ.7#I<1EP^7%I<9ER27*I<PESF7/9<^ET271I=(ET*729=<EV"7
M9)=FEVB7TE)KEW&7>9>%EWR7@9=ZEX:7BY>/EY"7G)>HEZ:7HY>SE[27PY?&
ME\B7RY?<E^V73Y_RE]]Z]I?UEP^8#)@XF"28(9@WF#V81IA/F$N8:YAOF'"8
M<9ATF'.8JIBOF+&8MIC$F,.8QICIF.N8`YD)F1*9%)D8F2&9'9D>F229()DL
MF2Z9/9D^F4*929E%F5"92YE1F5*93)E5F9>9F)FEF:V9KIF\F=^9VYG=F=B9
MT9GMF>Z9\9GRF?N9^)D!F@^:!9KBF1F:*YHWFD6:0II`FD.:/II5FDV:6YI7
MFE^:8IIEFF2::9IKFFJ:K9JPFKR:P)K/FM&:TYK4FMZ:WYKBFN.:YIKOFNN:
M[IKTFO&:]YK[F@:;&)L:FQ^;(ILCFR6;)YLHFRF;*ILNFR^;,IM$FT.;3YM-
MFTZ;49M8FW2;DYN#FY&;EIN7FY^;H)NHF[2;P)O*F[F;QIO/F]&;TIOCF^*;
MY)O4F^&;.ISRF_&;\)L5G!2<"9P3G`R<!IP(G!*<"IP$G"Z<&YPEG"2<(9PP
MG$><,IQ&G#Z<6IQ@G&><=IQXG.><[)SPG`F=")WKG`.=!ITJG2:=KYTCG1^=
M1)T5G1*=09T_G3Z=1IU(G5V=7IUDG5&=4)U9G7*=B9V'G:N=;YUZG9J=I)VI
MG;*=Q)W!G;N=N)VZG<:=SYW"G=F=TYWXG>:=[9WOG?V=&IX;GAZ>=9YYGGV>
M@9Z(GHN>C)Z2GI6>D9Z=GJ6>J9ZXGJJ>K9YAE\R>SI[/GM">U)[<GMZ>W9[@
MGN6>Z)[OGO2>]I[WGOF>^Y[\GOV>!Y\(G[=V%9\AGRR?/I]*GU*?5)]CGU^?
M8)]AGV:?9Y]LGVJ?=Y]RGW:?E9^<GZ"?+UC':5F09'3<49EQ```````P`3`"
M,`S_#O_[,!K_&_\?_P'_FS"<,+0`0/^H`#[_X_\___TP_C"=,)XP`S#=3@4P
M!C`',/PP%2`0(`__//\<,!8@7/\F("4@&"`9(!P@'2`(_PG_%#`5,#O_/?];
M_UW_"#`),`HP"S`,,`TP#C`/,!`P$3`+_Q(BL0#7`/<`'?]@(AS_'O]F(F<B
M'B(T(D(F0":P`#(@,R`#(>7_!/^B`*,`!?\#_P;_"O\@_Z<`!B8%)LLESR7.
M)<<EQB6A):`ELR6R);TEO"4[(!(PDB&0(9$ADR$3,/W__?_]__W__?_]__W_
M_?_]__W__?\((@LBAB*'(H(B@R(J(BDB_?_]__W__?_]__W__?_]_R<B*"*L
M`-(AU"$`(@,B_?_]__W__?_]__W__?_]__W__?_]_R`BI2(2(P(B!R)A(E(B
M:B)K(AHB/2(=(C4B*R(L(OW__?_]__W__?_]__W_*R$P(&\F;29J)B`@(2"V
M`/W__?_]__W_[R7]__W__?_]__W__?_]__W__?_]__W__?_]__W__?\0_Q'_
M$O\3_Q3_%?\6_Q?_&/\9__W__?_]__W__?_]__W_(?\B_R/_)/\E_R;_)_\H
M_RG_*O\K_RS_+?\N_R__,/\Q_S+_,_\T_S7_-O\W_SC_.?\Z__W__?_]__W_
M_?_]_T'_0O]#_T3_1?]&_T?_2/])_TK_2_],_TW_3O]/_U#_4?]2_U/_5/]5
M_U;_5_]8_UG_6O_]__W__?_]_T$P0C!#,$0P13!&,$<P2#!),$HP2S!,,$TP
M3C!/,%`P43!2,%,P5#!5,%8P5S!8,%DP6C!;,%PP73!>,%\P8#!A,&(P8S!D
M,&4P9C!G,&@P:3!J,&LP;#!M,&XP;S!P,'$P<C!S,'0P=3!V,'<P>#!Y,'HP
M>S!\,'TP?C!_,(`P@3"",(,PA#"%,(8PAS"(,(DPBC"+,(PPC3".,(\PD#"1
M,)(PDS#]__W__?_]__W__?_]__W__?_]__W_H3"B,*,PI#"E,*8PIS"H,*DP
MJC"K,*PPK3"N,*\PL#"Q,+(PLS"T,+4PMC"W,+@PN3"Z,+LPO#"],+XPOS#`
M,,$PPC##,,0PQ3#&,,<PR##),,HPRS#,,,TPSC#/,-`PT3#2,-,PU##5,-8P
MUS#8,-DPVC#;,-PPW3#>,-\PX##A,.(PXS#D,.4PYC#G,.@PZ3#J,.LP[##M
M,.XP[S#P,/$P\C#S,/0P]3#V,/W__?_]__W__?_]__W__?^1`Y(#DP.4`Y4#
ME@.7`Y@#F0.:`YL#G`.=`YX#GP.@`Z$#HP.D`Z4#I@.G`Z@#J0/]__W__?_]
M__W__?_]__W_L0.R`[,#M`.U`[8#MP.X`[D#N@.[`[P#O0.^`[\#P`/!`\,#
MQ`/%`\8#QP/(`\D#_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]_Q`$
M$002!!,$%`05!`$$%@07!!@$&00:!!L$'`0=!!X$'P0@!"$$(@0C!"0$)00F
M!"<$*`0I!"H$*P0L!"T$+@0O!/W__?_]__W__?_]__W__?_]__W__?_]__W_
M_?_]_S`$,00R!#,$-`0U!%$$-@0W!#@$.00Z!#L$/`0]!#X$/P1`!$$$0@1#
M!$0$101&!$<$2`1)!$H$2P1,!$T$3@1/!/W__?_]__W__?_]__W__?_]__W_
M_?_]__W_`"4")0PE$"48)10E'"4L)20E-"4\)0$E`R4/)1,E&R47)2,E,R4K
M)3LE2R4@)2\E*"4W)3\E'24P)24E."5");"SLK&T````````````````````
M``````````"T`"`0P`!!`,$`01##`$$@R`!%`,D`11#,`$D`S0!)$-$`3B#2
M`$\`TP!/$-4`3R#9`%4`V@!5$-T`61#@`&$`X0!A$.,`82#H`&4`Z0!E$.P`
M:0#M`&D0\0!N(/(`;P#S`&\0]0!O(/D`=0#Z`'40_0!Y$`8!0Q`'`6,0*`%)
M("D!:2`Y`4P0.@%L$$,!3A!$`6X05`%2$%4!<A!:`5,06P%S$&@!52!I`74@
M>0%:$'H!>A#7`=P0V`'\$-L!W`#<`?P`]`%'$/4!9Q#X`4X`^0%N`/H!Q1#[
M`>40_`'&$/T!YA#^`=@0_P'X$-P"(""%`Z40!!Y"0`4>8D`('L<0"1[G$`P>
M1$`-'F1`)!Y(0"4>:$`N'L\0+Q[O$#`>2Q`Q'FL0,AY+0#,>:T`V'DQ`-QYL
M0#X>31`_'FT00AY-0$,>;4!&'DY`1QYN0$P>TR!-'O,@3A[6($\>]B!4'E`0
M51YP$%H>4D!;'G)`8AY30&,><T!L'E1`;1YT0'@>VB!Y'OH@?!Y6('T>=B!^
M'E9`?QYV0(`>5P"!'G<`@AY7$(,>=Q"('E=`B1YW0)(>6D"3'GI`H!Y!0*$>
M84"B'D$PHQYA,*0>PA"E'N(0IA["`*<>X@"H'L(PJ1[B,*H>PB"K'N(@K!["
M0*T>XD"N'@(1KQX#$;`>`@&Q'@,!LAX",;,>`S&T'@(AM1X#(;8>`D&W'@-!
MN!Y%0+D>94"Z'D4PNQYE,+P>12"]'F4@OA[*$+\>ZA#`'LH`P1[J`,(>RC##
M'NHPQ![*(,4>ZB#&'LI`QQ[J0,@>23#)'FDPRAY)0,L>:4#,'D]`S1YO0,X>
M3S#/'F\PT![4$-$>]!#2'M0`TQ[T`-0>U##5'O0PUA[4(-<>]"#8'M1`V1[T
M0-H>H!';'J$1W!Z@`=T>H0'>'J`QWQZA,>`>H"'A'J$AXAZ@0>,>H4'D'E5`
MY1YU0.8>53#G'G4PZ!ZO$>D>L!'J'J\!ZQZP`>P>KS'M'K`Q[AZO(>\>L"'P
M'J]!\1ZP0?(>60#S'GD`]!Y90/4>>4#V'EDP]QYY,/@>62#Y'GD@[1^H`.X?
MJ!``````````````````````````````````````A+F!ML3*P<?"R,/)ALO`
MOJ^[NKR_O87&B]&(SHG/VM7%TLW3V=2,UH[8D=Z6Y)/A_^C;Y>#F\.>7Z9OM
MF.J9ZYKLG.X"])[Q$?@$]07V!O<2^1/Z%_X4^Q7\````````L+,`L@``````
ML0````````````````````````````````"T````````````````````````
M`````````````*``````````````````````````````````````````@(.B
M@@````"'BJ,`C9``````DI6DE````)T!```6``"UN*FW`````,S0J@#7W0``
M``#?XZOB````[_,``/T`````H:@```````````````"GK@``````````````
M``````````````"/W```````````````````````````````````````````
M````````````````````````````````````````G_(`````````````````
M``````````````````````````````````````````````````````"EK```
M``````````````"FK0```````````````````$$`P`!%`,@`20#,`$X`^`%/
M`-(`50#9`%<`@!Y9`/(>80#@`&4`Z`!I`.P`;@#Y`6\`\@!U`/D`=P"!'GD`
M\QZH`.T?P@"F'LH`P![4`-(>W`#;`>(`IQ[J`,$>]`#3'OP`W`$"`;`>`P&Q
M'J`!W!ZA`=T>KP'J'K`!ZQY!`,$`0P`&`44`R0!'`/0!20#-`$L`,!Y,`#D!
M30`^'DX`0P%/`-,`4`!4'E(`5`%3`%H!50#:`%<`@AY9`-T`6@!Y`6$`X0!C
M``<!90#I`&<`]0%I`.T`:P`Q'FP`.@%M`#\>;@!$`6\`\P!P`%4><@!5`7,`
M6P%U`/H`=P"#'GD`_0!Z`'H!I0"%`Z@`[A_"`*0>Q0#Z`<8`_`''``@>R@"^
M'L\`+A[4`-`>V`#^`=P`UP'B`*4>Y0#[`>8`_0'G``D>Z@"_'N\`+Q[T`-$>
M^`#_`?P`V`$"`:X>`P&O'J`!VAZA`=L>KP'H'K`!Z1Y!`,,`10"\'DD`*`%.
M`-$`3P#5`%4`:`%6`'P>60#X'F$`XP!E`+T>:0`I`6X`\0!O`/4`=0!I`78`
M?1YY`/D>P@"J'LH`Q![3`$P>U`#6'M8`3A[:`'@>X@"K'NH`Q1[S`$T>]`#7
M'O8`3Q[Z`'D>`@&T'@,!M1Z@`>`>H0'A'J\![AZP`>\>00"B'D4`NAY)`,@>
M3P#.'E4`YAY9`/8>80"C'F4`NQYI`,D>;P#/'G4`YQYY`/<>P@"H'LH`PA[4
M`-0>X@"I'NH`PQ[T`-4>`@&R'@,!LQZ@`=X>H0'?'J\![!ZP`>T>00"@'D(`
M!!Y$``P>10"X'D@`)!Y)`,H>2P`R'DP`-AY-`$(>3@!&'D\`S!Y2`%H>4P!B
M'E0`;!Y5`.0>5@!^'E<`B!Y9`/0>6@"2'F$`H1YB``4>9``-'F4`N1YH`"4>
M:0#+'FL`,QYL`#<>;0!#'FX`1QYO`,T><@!;'G,`8QYT`&T>=0#E'G8`?QYW
M`(D>>0#U'GH`DQ["`*P>R@#&'M0`V![B`*T>Z@#''O0`V1X"`;8>`P&W'J`!
MXAZA`>,>KP'P'K`!\1X`````'P`````````\````'P```"(```!;````&```
M`'T````R````E0```````````````````````````````````,``HA[#`,$`
MH!ZV'JP>R`"Z'KP>R0"X'L8>S`#('B@!S0#*'M(`SA[5`-,`S![8'MP>WA[@
M'MH>XA[9`.8>:`&@``(!P@#*`-0`H`&O`1`!`P'B`.H`]`"A`;`!$0&P'@`#
M"0,#`P$#(P/@`*,>XP#A`*$>LAZQ'K,>M1ZO'K0>KAZF'J@>JAZD'L`>MQZG
M'JD>JQZE'JT>Z`#"'KL>O1[I`+D>P1[#'L4>OQ[''NP`R1[$'KX>TAXI`>T`
MRQ[R`-0>SQ[U`/,`S1[3'M4>UQ[1'MD>W1[?'N$>VQ[C'OD`UA[G'FD!^@#E
M'NL>[1[O'ND>\1[S'O<>^1[]`/4>T!X``-H`Y!X#`.H>[![N'@<`"``)``H`
M"P`,``T`#@`/`!``Z![P'O(>]A[X'MT`]!X`````````````````````@-7$
MY(2DA:6&I@;GAZ>!H8*B`L8%QX.CB:G+ZXBHBJJ+JXRLC:V.KIOOF+B:]YGV
MCZ^0L)&QDK*3M96^EK:7M[/>E/Z>^)S\NM&[U[S8_^:Y\9_/'MP4UAG;````
M````P,'"PP````#(R<H`S,T`````TM/4H````-G:``#=``#@X>+C`````.CI
MZ@#L[0````#R\_3U````^?H``/T`````Q>4```````````````#0\```````
M``````````````````````#.[@``````````````````````````````````
M````````````````````````````````````````````````G?L`````````
M````````````````````````````````````````````````````````````
M``"TO0````````````````"_WP```````````````````*`>KAZP'K8>I!ZF
M'J@>K!Z\'K@>OA[`'L(>Q![&'M`>TA[4'M8>V![B'MH>W![>'LH>SA[,'L@>
MYAYH`>0>\A[5`*\>L1ZW'J4>IQZI'JT>O1ZY'K\>P1[#'L4>QQ[1'M,>U1[7
M'N`>H`'9'MT>WQ[+'O`>Z![J'NP>H0';'J\!P`#!`,(`PP"B'@(!LQZU'L@`
MR0#*`+H>S`#-`"@!\QX0`>D>T@#3`-0`H1[W'NL>[1[9`-H`^1[U'MT`X1ZP
M`>``X0#B`.,`HQX#`>\>JQ[H`.D`Z@"['NP`[0`I`<D>$0'Q'O(`\P#T`/4`
MSQ[-'N4>^0#Z`&D!YQ[]`.,>[AX```$`LAX#``0`M!ZJ'@<`"``)``H`"P`,
M``T`#@`/`!``$0`2`!,`]AX5`!8`%P`8`/@>&@`;`!P`'0#T'A\``*&B`*,`
M`*2E`*<``*@```````"IJJNL`*VNK["QLK,`M+6V`+<`N```IKD`NKN_P,K!
MPL/$Q<;'R`#+R<P``-#1TM/4`-L`U=;7V-G:``#P\?+S]/7V]_CY``#=W@``
MH`#\````_@``````_0````````````````````````#0#M$.T@[3#M0.U0[6
M#M<.V`[9#OW__?^B`*P`I@#]_Z``@0Z"#H0.APZ(#JH.B@Z-#I0.E0Z6#I<.
MF0Z:#IL.G`Z=#IX.GPZA#J(.HPZE#J<.JPZM#JX._?_]__W_KPZP#K(.LPZT
M#K4.M@ZW#K@.N0Z\#K$.NPZ]#OW__?_]_\`.P0["#L,.Q`[(#LD.R@[+#LP.
MS0[&#OW_W`[=#JT@`*&B`*0``*>H`*H``*T```````"TM;:W`+FZN[R]OK\`
MP<+#`,4`QP``RLL`S<[/T-'2T]35UM?8V0#;W-T``.#AXN/D`.8`Z.GJZ^SM
M``#P\?+S]/7V]_CY``#\_0``H`"!#H(._?^$#OW__?^'#H@._?^*#OW__?^-
M#OW__?_]__W__?_]_Y0.E0Z6#I<._?^9#IH.FPZ<#IT.G@Z?#OW_H0ZB#J,.
M_?^E#OW_IP[]__W_J@ZK#OW_K0ZN#J\.L`ZQ#K(.LPZT#K4.M@ZW#K@.N0[]
M_[L.O`Z]#OW__?_`#L$.P@[##L0._?_&#OW_R`[)#LH.RP[,#LT._?_]_]`.
MT0[2#M,.U`[5#M8.UP[8#MD._?_]_]P.W0[]__W_````````N0``````````
M````F0````````````````````"6EP```)&2@@"3E(0`AH>5````A0``````
M`````(D``````````(N;`````````````````````````````+,`````````
M`````````.'B]^?DY?;ZZ>KK[.WN[_#R\_3UYNCC_OO]__GX_.#QP<+7Q\3%
MUMK)RLO,S<[/T-+3U-7&R,/>V]W?V=C<P-$`HP``````````````````````
M````````````````````````````````````````````````````````````
M``"#@0```````)"``````````````````````````````(R*``".C0``````
M`````````````````````````````````````````````````+6E````````
M`````**A``````````````````````````"D`*:G`+\`JZRMK@"PL;(```"V
MMP```+L`````FP23!!H@D@0>("8@("`A(/W_,""S!#D@L@2W!+8$_?^:!!@@
M&2`<(!T@(B`3(!0@_?\B(?W_.B#]__W__?_]__W_[P3N!%$$I`#C!*8`IP#]
M__W__?^K`*P`K0"N`/W_L`"Q`+(``03]_^($M@"W`/W_%B']_[L`_?_]__W_
MJ0!.!#`$,01&!#0$-01$!#,$100X!#D$.@0[!#P$/00^!#\$3P1`!$$$0@1#
M!#8$,@1,!$L$-P1(!$T$201'!$H$+@00!!$$)@04!!4$)`03!"4$&`09!!H$
M&P0<!!T$'@0?!"\$(`0A!"($(P06!!($+`0K!!<$*`0M!"D$)P0J!````):7
M````D9*"`).4A`"&AY4```"%````````````B0``````````BYL`````````
M``````````````````#`P<+#Q,7&R,G*R\S-S]#1TM/4UM?8V=K;W-W>W^#A
MX^3'SM7BY0``````````````````````````````````````````B```````
M`````````````````````)@``````(R<````````````````BIH`````````
M````````````````````GP````````````````````````````````"#````
M``````````````````````````````````"`@0``````````````C8Z/D```
M`````````````)V>`-`0T1#2$-,0U!#5$-80\1#7$-@0V1#:$-L0W!#R$-T0
MWA#?$.`0X1#B$/,0XQ#D$.40YA#G$.@0Z1#J$.L0[!#M$.X0]!#O$/`0]1``
M`````````````````````````(``@0`:()(!'B`F("`@(2#&`C`@8`$Y(%(!
MC0".`(\`D``8(!D@'"`=("(@$R`4(-P"(B%A`3H@4P&=`)X`>`$```"6EP``
M`)&2@@"3E(0`AH>5````A0```````````(D``````````(N;````````````
M````````````````````````B````````````````````````````)@`````
M`(R<````````````````BIH`````````````````````````````GP``````
M``````````````````````````"#````````````````````````````````
M``````"`@0``````````````C8Z/D````````````````)V>`(``@0`:()(!
M'B`F("`@(2#&`C`@8`$Y(%(!C0".`(\`D``8(!D@'"`=("(@$R`4(-P"(B%A
M`3H@4P&=`)X`>`$`````J```````````````````````K@````````````"R
MM+:XNKR^P,+$QLC*S,[0TM36V-K<WN#BY.;HZNSN\/+T]OCZ_````/ZPKZJQ
M``"SM;>YN[V_P</%Q\G+S<_1T]77V=O=W^'CY>?IZ^WO\?/U]_G[_:(`HZT`
M`````*``````````````IP```````````````````*8`````I:0J*ZNLJ2\`
M``````````````````````````````"@`/W_AP6)!2D`*`"[`*L`%"`N`%T%
M+``M`(H%)B!<!5L%7@4Q!6$%,@5B!3,%8P4T!60%-05E!38%9@4W!6<%.`5H
M!3D%:04Z!6H%.P5K!3P%;`4]!6T%/@5N!3\%;P5`!7`%005Q!4(%<@5#!7,%
M1`5T!44%=05&!78%1P5W!4@%>`5)!7D%2@5Z!4L%>P5,!7P%305]!4X%?@5/
M!7\%4`6`!5$%@052!8(%4P6#!50%A`55!84%5@6&!5H%_?\`KJ\`````````
M`````````````````````````````````+'0`````*FX`*JZN0"RL[<```"\
M````````````O0``````````K*T```````````"D````````````````````
M``##SP```,$```````````````#&Q\K.Q,T```#U````````````````````
MZ/@```````````````````#J^@``````````````````````````````````
M````````````````````````````````````````````````I@``````````
M````````````````````````````@*&BHZBEM:?(H..KO@"PQ0#1R<S"G;:T
MR\#KN]+3U+^!@H.$A8;AAXB)BHN,C8Z/D)&2DY25EI[IEYB9FIN<^]76U]C9
MVO';W-W>W^#BY.7FY^SM[N_PG_GR\_3V]_S]H`#``,$`P@##`,0`Q0#'`,@`
MR0#*`,L`S`#-`,X`SP#0`-$`T@#3`-0`U0#6`-D`V@#;`-P`W0#>`+4`UP#W
M`*D`H0"B`*,`1""E`)(!IP"D`!D@'""K`#D@.B`!^P+[K@`3("`@(2"W`*8`
MM@`B(!H@'B`=(+L`)B`P(*P`OP"Y`,L"M`#&`MP"KP#8`MD"J`"R`-H"N`"S
M`-T"VP+'`A0@L0"\`+T`O@#@`.$`X@#C`.0`Y0#G`.@`Z0#J`.L`[`#&`.T`
MJ@#N`.\`\`#Q`$$!V`!2`;H`\@#S`/0`]0#V`.8`^0#Z`/L`,0'\`/T`0@'X
M`%,!WP#^`/\`_?_]_P```````*H`````J0````````````````````"L````
MZ^P`````````````````````````````[@``````````````````````````
M``````"^`````````````````*"XO[NZO`"]JP#Y^P```+"S_@``J//T\@``
M^OWW^/6YH>"BX=C0T[2CW*2EYN6FI^.VZ.??Z=H`TJWMKMNQ\-[(Q,#BS-37
MM<G%P<W9U='=Y+?*QL+JS@#6R\?#S[+Q[Z``P`#"`,@`R@#+`,X`SP"T`,L"
MQ@*H`-P"V0#;`*0@KP#=`/T`L`#'`.<`T0#Q`*$`OP"D`*,`I0"G`)(!H@#B
M`.H`]`#[`.$`Z0#S`/H`X`#H`/(`^0#D`.L`]@#\`,4`[@#8`,8`Y0#M`/@`
MY@#$`.P`U@#<`,D`[P#?`-0`P0##`.,`T`#P`,T`S`#3`-(`U0#U`&`!80':
M`'@!_P#>`/X`MP"U`+8`O@`4(+P`O0"J`+H`JP"@);L`L0#]_P````"2E)66
MEY.8B(.9B82:BH6;BX:<C(>/````````````W`````````#=W@```)V>``"-
MC@````"1````@@``H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!
MPL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9V@````#?X.'BX^3EYN?HZ>KK[.T`
M[_#Q\O/T]?;W^/D```````"@``````````#[`(```/H```````````````"!
M`````*L`NP`F((SXC_B2^)7XF/B+^([XD?B4^)?X'"`=()GX_?\B((3XB?B%
M^(;XA_B(^(KXC?B0^)/XEO@8(!D@_?^@``$.`@X##@0.!0X&#@<."`X)#@H.
M"PX,#@T.#@X/#A`.$0X2#A,.%`X5#A8.%PX8#AD.&@X;#AP.'0X>#A\.(`XA
M#B(.(PXD#B4.)@XG#B@.*0XJ#BL.+`XM#BX.+PXP#C$.,@XS#C0.-0XV#C<.
M.`XY#CH.__X+(!,@%"`_#D`.00Y"#D,.1`Y%#D8.1PY(#DD.2@Y+#DP.30XB
M(4\.4`Y1#E(.4PY4#E4.5@Y7#E@.60ZN`*D`_?_]__W__?\`````K```````
M````````````NP```+\`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=H`````
M`.#AXN/DY>;GZ.GJZ^SM[N_P\?(`````````````````L+&RL[2UMK>XN:4`
M`,```````````````/0`````\P````````#U`/D``````````/H```````#^
M``````````````#W`````````````/@`````````````BP``````````````
M````````````````_P``]@```````````````````````($`````````````
MC````````````````````)@``````````(```((`@P````````"$`````(4`
M`````(8```"(AXD`B@``C8^.D)$`DI25`)8`EYD`FIL`G9R>GP```,0`H`#'
M`,D`T0#6`-P`X0#@`.(`Y`"Z!JL`YP#I`.@`Z@#K`.T`)B#N`.\`\0#S`+L`
M]`#V`/<`^@#Y`/L`_`#]__W__?_]__W_:@;]__W__?_]__W__?\,!OW__?_]
M_V`&809B!F,&9`9E!F8&9P9H!FD&_?\;!OW__?_]_Q\&;08A!B(&(P8D!B4&
M)@8G!B@&*08J!BL&+`8M!BX&+P8P!C$&,@8S!C0&-08V!C<&.`8Y!CH&_?_]
M__W__?_]_T`&009"!D,&1`9%!D8&1P9(!DD&2@9+!DP&309.!D\&4`91!E(&
M?@9Y!H8&U0:D!J\&B`:1!OW__?_]_Y@&T@8`````````@0````````````#6
MUP```````````,@```````````````````````````#'`````````-#1````
MU-4``-+3P0````````#)``````````````````````#9V]K?S\W.S,O=`-S&
M``#8`````````````````````.#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY
M^@``````R@``````````````````````````````````````````````@```
M@@"#`````````(0`````A0``````A@```(B'B8N*C`"-CXZ0D9.2E)4`EIB7
MF9N:``"=G)Z?````Q``?^\<`R0#1`-8`W`#A`.``X@#D`.,`Y0#G`.D`Z`#J
M`.L`[0#L`.X`[P#Q`/,`\@#T`/8`]0#Z`/D`^P#\`/W__?_]__W__?_]_ZH@
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]_QX@_?_]__W__?^\!4O[-?LF(*``N`6W!;4%M@6T!1,@%"`<(!T@
M&"`9("K[*_N_!;`%L@6Q!;L%N07]_[,%T`71!=(%TP74!=4%U@77!=@%V07:
M!=L%W`7=!=X%WP7@!>$%X@7C!>0%Y07F!><%Z`7I!>H%_?_]__W__?_]_P``
MM@```,8``````````+@`MP``````````PP```+````````````````"Z````
M`````````````````````````````````,4`````````````````````````
M`````*T```"RLP````"J````O0``````````````````````````T-$```#4
MU>(`TM/C`*#@I0```,D```````````#D````````````````````````````
M`````````````````````/;_`````````````````````/GZ^_[W_0``````
M````VML`````````````````````W-T`````````````````````````````
M`````````````,[/`````````````-[?````````````````````````````
M````V0````````````````````````````````#$``````#*P:*C`+0`I*RI
MN\?"`*CXH;$``*NUIN'\`+S(````P,OGY<R`@:Z"Z8/FZ.WJZ^P`A/'N[\V%
M`*_T\O.&``"GB(>)BXJ,OHV/CI"1DY*4E0"6F)>9FYK6OYV<GI\``-C$`,4`
MQP#)`-$`U@#<`.$`X`#B`.0`XP#E`.<`Z0#H`.H`ZP#M`.P`[@#O`/$`\P#R
M`/0`]@#U`/H`^0#[`/P`(""P`*(`HP"G`"(@M@#?`*X`J0`B(;0`J`!@(L8`
MV``>(K$`9")E(J4`M0`"(A$B#R+``RLBJ@"Z`"8AY@#X`+\`H0"L`!HBD@%(
M(@8BJP"[`"8@H`#``,,`U0!2`5,!$R`4(!P@'2`8(!D@]P#*)?\`>`$>`1\!
M,`$Q`5X!7P$A(+<`&B`>(#`@P@#*`,$`RP#(`,T`S@#/`,P`TP#4`/W_T@#:
M`-L`V0#]_\8"W`*O`-@"V0+:`K@`W0+;`L<"Q0``````````````````````
M````````K0```+*S``````#0`-$``-35``#2TP``H`"6````R0``````````
M`)@``````````````````````````````````````````````(N'S:_.U]@`
MV0#:W_VPM:&BMK>XH[FZI+O!I<.FQ`"JQLN\S+Z_J[W`V]S=_N'BY^3E^NCU
MZ>OL[>[J[_#R]_/T^>;XX_;[_-[@\0``````````````````````R@``D@"T
MFZR,J0#'PIRH`*ZQ@H0``````($`R`"7````````@`````"#````````````
M````A0``````A@``IX@`B0"*``"-CXZ0D0``E)4`````F0":U@"=`)Z?````
MQ`"Y`+(`R0"S`-8`W`"%`^``X@#D`(0#J`#G`.D`Z`#J`.L`HP`B(>X`[P`B
M(+T`,"#T`/8`I@"M`/D`^P#\`"`@DP.4`Y@#FP.>`Z`#WP"N`*D`HP.J`Z<`
M8"*P`(<#D0.Q`&0B92*E`)(#E0.6`Y<#F0.:`YP#I@.K`Z@#J0.L`YT#K`"?
M`Z$#2"*D`ZL`NP`F(*``I0.G`X8#B`-3`1,@%2`<(!T@&"`9(/<`B0.*`XP#
MC@.M`ZX#KP/,`X\#S0.Q`[(#R`.T`[4#Q@.S`[<#N0.^`[H#NP.\`[T#OP/`
M`\X#P0/#`\0#N`/)`\(#QP/%`[8#R@/+`Y`#L`/]_P```````,8`````````
M````````````````PP```+``````````````````````````````````````
M`````````````````,4``````````````````````````````*T```"RLP``
M````````W```````````````J@``````````T-$```#4U0``TM/7`*``I0``
M`,D`````````````W:NNN,&GNK>\OLO-`-C:@(&"@X2%AH>(B8J+C(V.CY"1
MDI.4E9:7F)F:FYR=GI_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^
MWP#>K*^YS[2[P+V_S,X`V=L`````````````````````````````````````
M``````````````````````````"BM@``````````````````R@``H_\``*0`
MJ0#'P@"H`*&Q````M:8`````R``````0!!$$$@03!!0$%006!!<$&`09!!H$
M&P0<!!T$'@0?!"`$(00B!",$)`0E!"8$)P0H!"D$*@0K!"P$+00N!"\$(""P
M`)`$HP"G`"(@M@`&!*X`J0`B(0($4@1@(@,$4P0>(K$`9")E(E8$M0"1!`@$
M!`14!`<$5P0)!%D$"@1:!%@$!02L`!HBD@%((@8BJP"[`"8@H``+!%L$#`1<
M!%4$$R`4(!P@'2`8(!D@]P`>(`X$7@0/!%\$%B$!!%$$3P0P!#$$,@0S!#0$
M-00V!#<$.`0Y!#H$.P0\!#T$/@0_!$`$001"!$,$1`1%!$8$1P1(!$D$2@1+
M!$P$301.!*0```"V````Q@````````````````````````##````L```````
M````````````````````````````````````````````````Q0``````````
M````````````````````K0```+*S``````````#<``````````````"J````
M``````#0T0```-35``#2T]<`H`"E````R0````````````#=JZZXP:>ZM[R^
MR\T`V-J`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>G^#AXN/DY>;G
MZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[?`-ZLK[G/M+O`O;_,S@#9V\H`HJ/_
M``"D`*D`Q\(`J`"AL0```+6F`````,@`````$`01!!($$P04!!4$%@07!!@$
M&00:!!L$'`0=!!X$'P0@!"$$(@0C!"0$)00F!"<$*`0I!"H$*P0L!"T$+@0O
M!"`@L`"B`*,`IP`B(+8`!@2N`*D`(B$"!%($8"(#!%,$'B*Q`&0B92)6!+4`
M`B((!`0$5`0'!%<$"019!`H$6@18!`4$K``:(I(!2"(&(JL`NP`F(*``"P1;
M!`P$7`15!!,@%"`<(!T@&"`9(/<`'B`.!%X$#P1?!!8A`011!$\$,`0Q!#($
M,P0T!#4$-@0W!#@$.00Z!#L$/`0]!#X$/P1`!$$$0@1#!$0$101&!$<$2`1)
M!$H$2P1,!$T$3@2D````M@```,8``````````+@`MP``````````PP```+``
M``````````````"Z`````````````````````````````````````,4`````
M`````````````````````````*T```"RLP````"J````O0``````````````
M````````````T-$```#4U>(`TM/C`*#@I0```,D```````````#D````````
M``#<W0```````````-H``````````````````````/;_````````````````
M`````/GZ^_[W_0``RL&BH]NT`*2LJ;O'P@"H^*&Q``"KM:;A_`"\R````,#+
MY^7,@($`@NF#YNCMZNOL`(3Q[N_-A0``]/+SA@``IXB'B8N*C`"-CXZ0D9.2
ME)4`EIB7F9N:U@"=G)Z?``#8``"NO@``````````````````````````````
M`````````````````````````````/4`````````````````````````````
M`````````````,[/`````````````*^_``#>WP``````````````````````
M````V0````````````````````````````````#$`````````````````,0`
MQ0#'`,D`T0#6`-P`X0#@`.(`Y`#C`.4`YP#I`.@`Z@#K`.T`[`#N`.\`\0#S
M`/(`]`#V`/4`^@#Y`/L`_``@(+``H@"C`*<`(B"V`-\`K@"I`"(AM`"H`&`B
M`@%>`1XBL0!D(F4BI0"U``(B$2(/(L`#*R*J`+H`)B$#`5\!OP"A`*P`&B*2
M`4@B!B*K`+L`)B"@`,``PP#5`%(!4P$3(!0@'"`=(!@@&2#W`,HE_P!X`40@
MI``Y(#H@8@%C`2$@MP`:(!X@,"#"`,H`P0#+`,@`S0#.`,\`S`#3`-0`_?_2
M`-H`VP#9`#$!Q@+<`J\`V`+9`MH"N`#=`ML"QP(``+8```"T``````````"X
M`+<``````````,,```"P````````````````N@``````````````````````
M``````````````#%``````````````````````````````"M````LK,`````
MJ@```+T``````````````````````````.#1````U-7B`-+3XP"@`*4```#)
M````````````Y```````````W-T```````````#:````````````````````
M``#V_P```````````````````````/L`]P```,K!HJ/;``"DK-F[Q\(`J/BA
ML0``J[6FX?P`O-\```#`R^?ES("!WH+I@_WZ[>KK[`"$\>[OS84`K_3R\X8`
M`*>(AXF+BHS^C8^.D)&3DI25`):8EYF;FM:_G9R>GP```````````,;F````
M`,CH``#0\`````````````````````````````````````````#U````````
M``````````````````````````````````#.SP```````````````*FY````
M````````````````````````````````KKX`````````````````````````
MQ`````````````````#$`,4`QP#)`-$`U@#<`.$`X`#B`.0`XP#E`.<`Z0#H
M`.H`ZP#M`.P`[@#O`/$`\P#R`/0`]@#U`/H`^0#[`/P`(""P`*(`HP"G`"(@
MM@#?`*X`8`$B(;0`J`!@(GT!V``>(K$`9")E(@8BM0`"(A$B#R)A`2LBJ@"Z
M`"8A?@'X`+\`H0"L`!HBD@%((@8!JP`,`28@H`#``,,`U0!2`5,!$`$4(!P@
M'2`8(!D@]P#*)?W_J0!$(*0`.2`Z(,8`NP`3(+<`&B`>(#`@P@`'`<$`#0'(
M`,T`S@#/`,P`TP#4`!$!T@#:`-L`V0`Q`<8"W`*O`,`#RP#:`K@`R@#F`,<"
M``"V````Q@``````````N`"W``````````##````L````````````````+H`
M````````````````````````````````````Q0``````````````````````
M````````K0```+*S`````*H```"]``````````````````````````#0T0``
M`-35X@#2T^,```"E````R0```````````.0`````````````````````````
MV@``````````````````````]O\`````````````````````^?K[_O?]````
M]0``````````````````````````````````````````SL\`````````````
M``````````````````````````````````#9````````````````````````
M`````````,0``````````````````````````````````````,K!HJ/;M`"D
MK*F[Q\(`J/BAL0``J[6FX?P`O,@```#`R^?ES("!KH+I@^;H[>KK[-R$\>[O
MS84`K_3R\X:@WJ>(AXF+BHR^C8^.D)&3DI25W9:8EYF;FM:_G9R>G^#?V,0`
MQ0#'`,D`T0#6`-P`X0#@`.(`Y`#C`.4`YP#I`.@`Z@#K`.T`[`#N`.\`\0#S
M`/(`]`#V`/4`^@#Y`/L`_`#=`+``H@"C`*<`(B"V`-\`K@"I`"(AM`"H`&`B
MQ@#8`!XBL0!D(F4BI0"U``(B$2(/(L`#*R*J`+H`)B'F`/@`OP"A`*P`&B*2
M`4@B!B*K`+L`)B"@`,``PP#5`%(!4P$3(!0@'"`=(!@@&2#W`,HE_P!X`40@
MI`#0`/``W@#^`/T`MP`:(!X@,"#"`,H`P0#+`,@`S0#.`,\`S`#3`-0`_?_2
M`-H`VP#9`#$!Q@+<`J\`V`+9`MH"N`#=`ML"QP*M````LK,`````````````
M````````````````````````M@```,8`````````````MP``````````PP``
M````````T-$```#4U>(`TM/C`*``I0```,D```````````````````````#<
MW0```````````````````````````,H``*,```"DK*D`Q\(`J`"A``````"F
M`````,@``````.<``(``````@P```.H``````.[OS84```#R`(;X`*<`AP``
MB@````".````D@``````EYF;FM8``)P`G_D``(&"``"$B(R-`````(F+D9,`
M`)25``"6F**KG9X```````#^K@```````+&T``"OL````````+7Z`+V^N;J[
MO```_+C!Q+_`Q<L```#/V```S,X``-G:W^#;WN7F`````.'D``#HZ0````#M
M\```\?/T]?;W``````"/D/O]Z^P`Q````0$!R0`$`=8`W`#A``4!#`'D``T!
M!@$'`>D`>0%Z`0X![0`/`1(!$P$6`?,`%P'T`/8`]0#Z`!H!&P'\`"`@L``8
M`:,`IP`B(+8`WP"N`*D`(B$9`:@`8"(C`2X!+P$J`60B92(K`38!`B(1(D(!
M.P$\`3T!/@$Y`3H!10%&`4,!K``:(D0!1P$&(JL`NP`F(*``2`%0`=4`40%,
M`1,@%"`<(!T@&"`9(/<`RB5-`50!50%8`3D@.B!9`58!5P%@`1H@'B!A`5H!
M6P'!`&0!90'-`'T!?@%J`=,`U`!K`6X!V@!O`7`!<0%R`7,!W0#]`#<!>P%!
M`7P!(@''`@#>WP````````````````````````````````````````"V````
MQ@``````````N`"W``````````##````L````````````````+H`````````
M````````````````````````````Q0``````````````````````````````
MK0```+*S`````*H```"]``````````````````````````#0T0```-35X@#2
MT^,`H."E````R0```````````.0``````````-S=````````````V@``````
M````````````````]O\`````````````````````^?K[_O?]````]0``````
M````````````````````````````````````SL\`````````````````````
M``````````````````````````#9````````````````````````````````
M`,0``````````````````````````````````````,K!HJ/;M`"DK*F[Q\(`
MJ/BAL0``J[6FX?P`O,@```#`R^?ES("!KH+I@^;H[>KK[`"$\>[OS84`K_3R
M\X8``*>(AXF+BHR^C8^.D)&3DI25`):8EYF;FM:_G9R>GP``V,0`Q0#'`,D`
MT0#6`-P`X0#@`.(`Y`#C`.4`YP#I`.@`Z@#K`.T`[`#N`.\`\0#S`/(`]`#V
M`/4`^@#Y`/L`_``@(+``H@"C`*<`(B"V`-\`K@"I`"(AM`"H`&`BQ@#8`!XB
ML0!D(F4BI0"U``(B$2(/(L`#*R*J`+H`)B'F`/@`OP"A`*P`&B*2`4@B!B*K
M`+L`)B"@`,``PP#5`%(!4P$3(!0@'"`=(!@@&2#W`,HE_P!X`40@I``Y(#H@
M`?L"^R$@MP`:(!X@,"#"`,H`P0#+`,@`S0#.`,\`S`#3`-0`_?_2`-H`VP#9
M`#$!Q@+<`J\`V`+9`MH"N`#=`ML"QP+$`+,```````````#:````OP```,``
M``#9````PP````````"T`````````,(`````````P0````````#%````````
M`````````````````,VZU=;)N+>[U-/(OKV\QL?,M;:YT=++S]#*V-?.````
M`````````````````````-\```#<````VP```-T```#>L+&R````````````
M````_@``````````^?L`````````````````````````````\```\@``]```
M`````/8`@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6F
MIZBIJJNLK:ZOX.'BX^3EYN?HZ>KK[.WN[P#Q``#S``#U````````]P#_````
M_0``````````````^````````/H``````````)$EDB63)0(E)"5A)6(E5B55
M)6,E4257)5TE7"5;)1`E%"4T)2PE'"4`)3PE7B5?)5HE5"5I)68E8"50)6PE
M9R5H)60E9259)5@E4B53)6LE:B48)0PEB"6$)8PED"6`)4`$001"!$,$1`1%
M!$8$1P1(!$D$2@1+!$P$301.!$\$`011!`0$5`0'!%<$#@1>!+``&2*W`!HB
M%B&D`*`EH`#$`+,```````````#:````OP```,````#9````PP````````"T
M`````````,(`````````P0````````#%`````````````````````````,VZ
MU=;)N+>[U-/(OKV\QL?,M;:YT=++S]#*V-?.````````````````````````
M`-\```#<````VP```-T```#>L+&R````````````````_@``````````````
M````````````````````````````^?L```#L`````````````.\`````````
M``````````````````````````````#W````````````````````````````
M````\```\_(```````````````````````````#B`````.D`````````````
MY```Z```Z@````````#@``#K[@````````````#C``#EYP#M````````````
M_ZV;G`"=`````*:NJ@```/CQ_0``Y@#Z``"GKZRK`*@`````````````````
M`````*4`````````````````X0"@``````````````"A````I`"B````]@``
MHP``````T`71!=(%TP74!=4%U@77!=@%V07:!=L%W`7=!=X%WP7@!>$%X@7C
M!>0%Y07F!><%Z`7I!>H%H@"C`*4`IR"2`>$`[0#S`/H`\0#1`*H`N@"_`!`C
MK`"]`+P`H0"K`+L`D262)9,E`B4D)6$E8B56)54E8R51)5<E725<)5LE$"44
M)30E+"4<)0`E/"5>)5\E6B54)6DE9B5@)5`E;"5G)6@E9"5E)5DE6"52)5,E
M:R5J)1@E#"6()80EC"60)8`EL0/?`),#P`.C`\,#M0#$`Z8#F`.I`[0#'B+&
M`[4#*2)A(K$`92)D(B`C(2/W`$@BL``9(K<`&B)_(+(`H"6@`,SLWM+R````
M````````````````````````````````````EI<```"1DH(`DY2$`(:'E0``
M`(4```````````")``````````"+FP```````````````````````````,SL
M`-X``````-(`````````````````````````````````\@``````````````
M``````````````````````````````"(````````````````````````````
MF```````C)P```````````````````````````````````````````````"?
M`````````````````````````````````(,`````````````````U?4`````
M````````````W?T`````````````````````````````````````````P,'"
M`,3%QL?(R<K+`,W.SP#1`-/4`-;7V-G:V]P``-_@X>(`Y.7FY^CIZNL`[>[O
M`/$`\_0`]O?X^?K[_```_P``P^,```````````````#0\```````````````
M````K"#]_QH@D@$>("8@("`A(,8","#]_SD@4@']__W__?_]_Q@@&2`<(!T@
M(B`3(!0@W`(B(?W_.B!3`?W__?]X`:``H0"B`*,`I`"E`*8`IP"H`*D`J@"K
M`*P`K0"N`*\`L`"Q`+(`LP"T`+4`M@"W`+@`N0"Z`+L`O`"]`+X`OP#``,$`
MP@`"`<0`Q0#&`,<`R`#)`,H`RP```\T`S@#/`!`!T0`)`],`U`"@`=8`UP#8
M`-D`V@#;`-P`KP$#`]\`X`#A`.(``P'D`.4`Y@#G`.@`Z0#J`.L``0/M`.X`
M[P`1`?$`(P/S`/0`H0'V`/<`^`#Y`/H`^P#\`+`!JR#_`````):7````D9*"
M`).4A`"&AY4```"%````````````B0``````````BYL`````````````````
M````````````````````C@``````````````````````_P">`````*``HJ.D
M`*:GC:D`JZRMKIVPL;*SM+6VMX^Y`+N\O;X``````,3%KP``R0``````````
M`-,`U=;7J````-P``-\`````Y.6_``#I````````````\P#U]O>X````_```
M`,+B``#`X,/C`````,CH`````,?G``#+Z\;F``````````#,[````````,[N
M``#!X0```````,WM````S^\`````V?G1\=+R``````#4]```````````JKH`
M`-KZ`````-#P``````````#;^P```````-CX``````#*ZMW]WOX`K"#]_QH@
M_?\>("8@("`A(/W_,"#]_SD@_?^H`,<"N`#]_Q@@&2`<(!T@(B`3(!0@_?\B
M(?W_.B#]_Z\`VP+]_Z``_?^B`*,`I`#]_Z8`IP#8`*D`5@&K`*P`K0"N`,8`
ML`"Q`+(`LP"T`+4`M@"W`/@`N0!7`;L`O`"]`+X`Y@`$`2X!``$&`<0`Q0`8
M`1(!#`')`'D!%@$B`38!*@$[`6`!0P%%`=,`3`'5`-8`UP!R`4$!6@%J`=P`
M>P%]`=\`!0$O`0$!!P'D`.4`&0$3`0T!Z0!Z`1<!(P$W`2L!/`%A`40!1@'S
M`$T!]0#V`/<`<P%"`5L!:P'\`'P!?@'9`@````"=GOW^````EI<```"1DH(`
MDY2$`(:'E0```(4```````````")``````````"+FP``````````````````
M````H0``````````````````N@```+\`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35
MUMC9VML``````-S=WM_AX^3EYNSM\/'R\_7V^/H`````````````````````
M`````````````````````````````(H`````@0````````"-`(\`````````
M`)H```````".`````````````````````)@``````)``````````````GP``
M`*H``,``````````````````````_P``````````````````````````````
MC)P`````````````````````````````````````````````````````````
M`````````````````````````(,`````````````````````````````````
M`````*``HJ.DI::GJ*D`JZRMKJ^PL;*SM+6VM[BY`+N\O;X`````````````
M``````````````````#7``````````#@`.(`````Y^CIZNL``.[O`````/0`
M`/<`^0#[_````*P@?@8:()(!'B`F("`@(2#&`C`@>08Y(%(!A@:8!H@&KP88
M(!D@'"`=("(@$R`4(*D&(B&1!CH@4P$,(`T@N@:@``P&H@"C`*0`I0"F`*<`
MJ`"I`+X&JP"L`*T`K@"O`+``L0"R`+,`M`"U`+8`MP"X`+D`&P:[`+P`O0"^
M`!\&P08A!B(&(P8D!B4&)@8G!B@&*08J!BL&+`8M!BX&+P8P!C$&,@8S!C0&
M-08V!M<`-P8X!CD&.@9`!D$&0@9#!N``1`;B`$4&1@9'!D@&YP#H`.D`Z@#K
M`$D&2@;N`.\`2P9,!DT&3@;T`$\&4`;W`%$&^0!2!OL`_``.(`\@T@;$Q\C)
MS,_1T@```````````````````````````````!W[V04`_P``'_OR!0'_```J
M^^D%!O\``"O[Z04'_P``+/OI!00&```M^^D%!`<``"[[T`4!_P``+_O0!0+_
M```P^]`%!/\``#'[T04$_P``,OO2!03_```S^],%!/\``#3[U`4$_P``-?O5
M!03_```V^]8%!/\``#C[V`4$_P``.?O9!03_```Z^]H%!/\``#O[VP4$_P``
M//O<!03_```^^]X%!/\``$#[X`4$_P``0?OA!03_``!#^^,%!/\``$3[Y`4$
M_P``1OOF!03_``!'^^<%!/\``$C[Z`4$_P``2?OI!03_``!*^^H%!/\``$O[
MU04#_P``3/O1!07_``!-^]L%!?\``$[[Y`4%_P``````````````````````
M`````````/W^````EI<```"1DH(`DY2$`(:'E0```(4```````````")````
M``````"+FP````````````````#`P<+#Q,7&Q\C)`,O,S<[/T-'2TP``````
M`````````.#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^@``````U-76U]@`
M``````````````````````````````````````````"(````````````````
M````````````F````*"AHJ,`I::GJ*D`JZRMKJ^PL;*SM+6VM[BY`+N\O;Z_
M``````````````````````````````"J````````````````````````````
M`````````````+H``````````-D%'?O0!2[[\@4?^]`%+_O5!4O[T`4P^]$%
M,?O2!3+[TP4S^]0%-/O5!37[U@4V^]@%./O9!3G[V@4Z^]L%._O<!3S[W@4^
M^^`%0/OA!4'[XP5#^^0%1/OF!4;[YP5'^^@%2/OI!4G[Z@5*^RK[+/LK^RW[
MT05,^]L%3?OD!4[[Z04J^TG[+/OI!2O[2?LM^P`````````````````````!
M``````````(````!`````0````,````!````!````!@````%`````P```!T`
M```"````(`````(````B````K"#]_QH@D@$>("8@("`A(,8","#]_SD@_?_]
M__W__?_]_Q@@&2`<(!T@(B`3(!0@W`(B(?W_.B#]__W__?_]_Z``H0"B`*,`
MJB"E`*8`IP"H`*D`UP"K`*P`K0"N`*\`L`"Q`+(`LP"T`+4`M@"W`+@`N0#W
M`+L`O`"]`+X`OP"P!;$%L@6S!;0%M06V!;<%N`6Y!?W_NP6\!;T%O@6_!<`%
MP07"!<,%\`7Q!?(%\P7T!?W__?_]__W__?_]__W_T`71!=(%TP74!=4%U@77
M!=@%V07:!=L%W`7=!=X%WP7@!>$%X@7C!>0%Y07F!><%Z`7I!>H%_?_]_PX@
M#R#]_P```):7````D9*"`).4A`"&AY4```"%````````````B0``````````
MBYL```````````````````````````````````"(````````````````````
M````````F````````````-#P`````````````````````-W]````````````
M``````````````````````````````",G`````````````#>_HJ:````````
M`````````````````````)\`````````````````````````````````@P``
M`````-'2T]35UM?8V=K;W```W^#AXN/DY>;GZ.GJZ^SM[N\`\?+S]/7V]_CY
M^OO\``#_`````````````````````!\!\0#R`/,`]`#U`/8`]P#X`/D`^@#[
M`/P`,0%?`?\`'@'1`-(`TP#4`-4`U@#7`-@`V0#:`-L`W``P`5X!WP"L(/W_
M&B"2`1X@)B`@("$@Q@(P(&`!.2!2`?W__?_]__W_&"`9(!P@'2`B(!,@%"#<
M`B(A80$Z(%,!_?_]_W@!````EI>O``"1DH(`DY2$`(:'E0```(4`````````
M``")``````````"+FP````````````````````````````````"TH:(`N+FZ
M`+P`OK_`P<+#Q,7&Q\C)RLO,S<[/T-$`T]35UM?8V=K;W-W>W^#AXN/DY>;G
MZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?X``````````````````````*```*.D
MI::GJ*D`JZRMK@"PL;*S`+6VMP```+L`O0``K"#]_QH@D@$>("8@("`A(/W_
M,"#]_SD@_?_]__W__?_]_Q@@&2`<(!T@(B`3(!0@_?\B(?W_.B#]__W__?_]
M_Z``A0.&`Z,`I`"E`*8`IP"H`*D`_?^K`*P`K0"N`!4@L`"Q`+(`LP"$`[4`
MM@"W`(@#B0.*`[L`C`.]`(X#CP.0`Y$#D@.3`Y0#E0.6`Y<#F`.9`YH#FP.<
M`YT#G@.?`Z`#H0/]_Z,#I`.E`Z8#IP.H`ZD#J@.K`ZP#K0.N`Z\#L`.Q`[(#
MLP.T`[4#M@.W`[@#N0.Z`[L#O`.]`[X#OP/``\$#P@/#`\0#Q0/&`\<#R`/)
M`\H#RP/,`\T#S@/]_P```):7````D9*"`).4A`"&AY4```"%````````````
MB0``````````BYL```````````````````````````````````"(````````
M````````````````````F```````C)P```````````````"*F@``````````
M``````````````````"?`````(Z>`````````````````````````(,`````
M`````````````````````````````````*P@_?\:()(!'B`F("`@(2#&`C`@
M8`$Y(%(!_?]]`?W__?\8(!D@'"`=("(@$R`4(-P"(B%A`3H@4P']_WX!>`$`
M``"6EP```)&2@@"3E(0`AH>5````A0```````````(D``````````(N;````
M`````````````````````````*B`@:J]LJ^CBHR.C0"AC\#!PL/$Q<;'R,G*
MR\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W
M^/GZ^_S]_O\`N)"#NKZSO[R:G)Z=`**?````````````````````````````
M````````````````````````````````````I;0``````````````````*``
M``"D`*:G`*D`JZRMK@"PL0```+6VMP```+L``````@0#!!H@4P0>("8@("`A
M(*P@,"`)!#D@"@0,!`L$#P12!!@@&2`<(!T@(B`3(!0@_?\B(5D$.B!:!%P$
M6P1?!*``#@1>!`@$I`"0!*8`IP`!!*D`!`2K`*P`K0"N``<$L`"Q``8$5@21
M!+4`M@"W`%$$%B%4!+L`6`0%!%4$5P00!!$$$@03!!0$%006!!<$&`09!!H$
M&P0<!!T$'@0?!"`$(00B!",$)`0E!"8$)P0H!"D$*@0K!"P$+00N!"\$,`0Q
M!#($,P0T!#4$-@0W!#@$.00Z!#L$/`0]!#X$/P1`!$$$0@1#!$0$101&!$<$
M2`1)!$H$2P1,!$T$3@1/!````):7````D9*"`).4A`"&AY4```"%````````
M````B0``````````BYL`````````````````````````````````````H0``
M``````````````````"B_P"R`+T``*````"D`*:GJ*D`JZRMK@"PL0``M+6V
MM[@``+L``````,'"`,0``,<`R0#+`,W.`````-/4`-;7``#:`-S=`-\`X>(`
MY```YP#I`.L`[>X`````\_0`]O<``/H`_/T`````P^.EN<;F`````,CHS^_0
M\````````,KJS.P``````````````````````````````````````,7E``"\
MO@``H[/1\0``TO(`````````U?4``,#@``#8^(R<``"JNHJ:WOZ-G0``````
M````V?G;^P````````"/GZ^_CIX`K"#]_QH@_?\>("8@("`A(/W_,"!@`3D@
M6@%D`7T!>0']_Q@@&2`<(!T@(B`3(!0@_?\B(6$!.B!;`64!?@%Z`:``QP+8
M`D$!I``$`:8`IP"H`*D`7@&K`*P`K0"N`'L!L`"Q`-L"0@&T`+4`M@"W`+@`
M!0%?`;L`/0'=`CX!?`%4`<$`P@`"`<0`.0$&`<<`#`')`!@!RP`:`<T`S@`.
M`1`!0P%'`=,`U`!0`=8`UP!8`6X!V@!P`=P`W0!B`=\`50'A`.(``P'D`#H!
M!P'G``T!Z0`9`>L`&P'M`.X`#P$1`40!2`'S`/0`40'V`/<`60%O`?H`<0'\
M`/T`8P'9`H``@0```````````((```"#````A````(4```"&`````````(<`
M````````B`````````")`````````(H`````````````````````````H*&B
M`*4``*BIJJNL``"OL+&R`+4``+BYNKN\````````````````````````````
MBP```(P```"-````C@```(^0D9(```````````````"4`````````).;````
M``````````````````````````"5E@``````````````````````````````
M`````````````````````````````)<`````````````````````````````
M``````"8F0````````````````````````"S``"T`+:W````````O@#AXO?G
MY.7V^NGJZ^SM[N_P\O/T]>;HX_[[_?_Y^/S@\<'"U\?$Q=;:R<K+S,W.S]#2
MT]35QLC#WMO=W]G8W,#1`*,``*0`IJ<```````"N````````````````````
M`````````````````````````````````````````````+VM````````````
M``````":``````````"_````````G`"=`````)X`````````````````````
M````````````````````````````````````````````````````````````
M``"?````````````)0(E#"40)10E&"4<)20E+"4T)3PE@"6$)8@EC"60)9$E
MDB63)2`CH"49(AHB2")D(F4BH``A([``L@"W`/<`4"51)5(E4014!%0E5@17
M!%<E6"59)5HE6R61!%X$7B5?)6`E824!!`0$8R4&!`<$9B5G)6@E:25J)9`$
M#@2I`$X$,`0Q!$8$-`0U!$0$,P1%!#@$.00Z!#L$/`0]!#X$/P1/!$`$001"
M!$,$-@0R!$P$2P0W!$@$301)!$<$2@0N!!`$$00F!!0$%00D!!,$)008!!D$
M&@0;!!P$'00>!!\$+P0@!"$$(@0C!!8$$@0L!"L$%P0H!"T$*00G!"H$@`"!
M````````````@@```(,```"$````A0```(8`````````AP````````"(````
M`````(D`````````B@````````````````````````"@H:(`I0``J*FJJZP`
MKJ^PL;(`M0``N+FZN[P`O@````````````````````````"+````C````(T`
M``".````CY"1D@```````````````)0`````````DYL`````````````````
M`````````````)66````````````````````````````````````````````
M````````````````EP```````````````````````````````````)B9````
M`````````````````````+,``+0`MK<``````````.'B]^?DY?;ZZ>KK[.WN
M[_#R\_3UYNCC_OO]__GX_.#QP<+7Q\3%UMK)RLO,S<[/T-+3U-7&R,/>V]W?
MV=C<P-$`HP``I`"FIP``````````````````````````````````````````
M````````````````````````````````O:T``````````````````)H`````
M`````+\```````"<`)T`````G@``````````````````````````````````
M`````````````````````````````````````````````````)\`````````
M```E`B4,)1`E%"48)1PE)"4L)30E/"6`)80EB"6,)9`ED262)9,E(".@)1DB
M&B)((F0B92*@`"$CL`"R`+<`]P!0)5$E4B51!%0$5"56!%<$5R58)5DE6B5;
M)9$$725>)5\E8"5A)0$$!`1C)08$!P1F)6<E:"5I)6HED`1L):D`3@0P!#$$
M1@0T!#4$1`0S!$4$.`0Y!#H$.P0\!#T$/@0_!$\$0`1!!$($0P0V!#($3`1+
M!#<$2`1-!$D$1P1*!"X$$`01!"8$%`05!"0$$P0E!!@$&00:!!L$'`0=!!X$
M'P0O!"`$(00B!",$%@02!"P$*P07!"@$+00I!"<$*@2``($```````````""
M````@P```(0```"%````A@````````"'`````````(@`````````B0``````
M``"*`````````````````````````*"AHJ2EIJ>HJ:JKK*VNK["QLK2UMK>X
MN;J[O+V^`````````````````````````(L```",````C0```(X```"/D)&2
M````````````````E`````````"3FP``````````````````````````````
ME98`````````````````````````````````````````````````````````
M``"7````````````````````````````````````F)D`````````````````
M````````LP``````````````````X>+WY^3E]OKIZNOL[>[O\/+S]/7FZ./^
M^_W_^?C\X/'!PM?'Q,76VLG*R\S-SL_0TM/4U<;(P][;W=_9V-S`T0"C````
M``````````````":``````````"_````````G`"=`````)X`````````````
M````````````````````````````````````````````````````````````
M``````````"?````````````)0(E#"40)10E&"4<)20E+"4T)3PE@"6$)8@E
MC"60)9$EDB63)2`CH"49(AHB2")D(F4BH``A([``L@"W`/<`4"51)5(E4013
M)50E5256)5<E6"59)5HE6R5<)5TE7B5?)6`E824!!&(E8R5D)64E9B5G)6@E
M:25J)6LE;"6I`$X$,`0Q!$8$-`0U!$0$,P1%!#@$.00Z!#L$/`0]!#X$/P1/
M!$`$001"!$,$-@0R!$P$2P0W!$@$301)!$<$2@0N!!`$$00F!!0$%00D!!,$
M)008!!D$&@0;!!P$'00>!!\$+P0@!"$$(@0C!!8$$@0L!"L$%P0H!"T$*00G
M!"H$``````"UI0"JNM[^``````````````````````````"@````````IP"I
M`*L`K0``L+$`````MK<```"[`````,#!P@#$`,;'R,G*R\S-SL\``-+3U`#6
M``#9VMO<``#?X.'B`.0`YN?HZ>KK[.WN[P``\O/T`/8``/GZ^_P``/\``,/C
MH:+%Y0````"RN0``T/````````#=_0``````````````````````````````
M`````````````````````*.ST?$``````````````-7UO+T```````#7]P``
M``"FJ```````````````````V/@```````"^K*ZOO[2X`*``!`$%`4$!K"`>
M(&`!IP!A`:D`&`*K`'D!K0!Z`7L!L`"Q``P!0@%]`1T@M@"W`'X!#0$9`KL`
M4@%3`7@!?`'``,$`P@`"`<0`!@'&`,<`R`#)`,H`RP#,`,T`S@#/`!`!0P'2
M`-,`U`!0`=8`6@%P`=D`V@#;`-P`&`$:`M\`X`#A`.(``P'D``<!Y@#G`.@`
MZ0#J`.L`[`#M`.X`[P`1`40!\@#S`/0`40'V`%L!<0'Y`/H`^P#\`!D!&P+_
M````O+T```````````````"FJ`````````````````````````````"^````
M`+2X``````````````````````"@H:*C`*4`IP"IJJNLK:ZOL+&RLP"UMK<`
MN;J[````OZ``H0"B`*,`K""E`&`!IP!A`:D`J@"K`*P`K0"N`*\`L`"Q`+(`
MLP!]`;4`M@"W`'X!N0"Z`+L`4@%3`7@!OP```*R\````````````````````
M````````````````````H:(```````"FJP```````````````````````+"Q
M``````````````````````````````````````````"TM0``````````````
M````````````M[D``````````+N_``````````#7]P``````````````````
M````````J+BJNKV^````````T/#>_J\``````````````````````*2E````
M``````````````````````"RLP```````*```*,```"G`*D```"MK@``````
M``"V````````````P,'"P\3%QL?(R<K+S,W.SP#1TM/4U=8`V-G:V]S=`-_@
MX>+CY.7FY^CIZNOL[>[O`/'R\_3U]@#X^?K[_/T`_Z```AX#'J,`"@$+`0H>
MIP"`'JD`@AX+'O(>K0"N`'@!'AX?'B`!(0%`'D$>M@!6'H$>5QZ#'F`>\QZ$
M'H4>81[``,$`P@##`,0`Q0#&`,<`R`#)`,H`RP#,`,T`S@#/`'0!T0#2`-,`
MU`#5`-8`:A[8`-D`V@#;`-P`W0!V`=\`X`#A`.(`XP#D`.4`Y@#G`.@`Z0#J
M`.L`[`#M`.X`[P!U`?$`\@#S`/0`]0#V`&L>^`#Y`/H`^P#\`/T`=P'_``#_
M``"TH:4`````````````````````````````````H`"BHZ0`IJ<`J0"KK*VN
M`+"QLK,`M;:W`+D`N[R]O@``````Q,6O``#)````````````TP#5UM>H````
MW```WP````#DY;\``.D```````````#S`/7V][@```#\````PN(``,#@P^,`
M````R.@`````Q^<``,OKQN8``````````,SL````````SNX``,'A````````
MS>T```#/[P````#9^='QTO(``````-3T``````````"JN@``VOH`````T/``
M`````````-O[````````V/@``````,KJW?W>_@"@`!T@H@"C`*0`'B"F`*<`
MV`"I`%8!JP"L`*T`K@#&`+``L0"R`+,`'""U`+8`MP#X`+D`5P&[`+P`O0"^
M`.8`!`$N`0`!!@'$`,4`&`$2`0P!R0!Y`18!(@$V`2H!.P%@`4,!10'3`$P!
MU0#6`-<`<@%!`5H!:@'<`'L!?0'?``4!+P$!`0<!Y`#E`!D!$P$-`>D`>@$7
M`2,!-P$K`3P!80%$`48!\P!-`?4`]@#W`',!0@%;`6L!_`!\`7X!&2"@````
M````IP``````K0``L````````+<```````````#!PL/$Q<8``,D`RP#-SL_0
M``#3U-76`-@`VMO<W=[?`.'BX^3EY@``Z0#K`.WN[_```//T]?8`^`#Z^_S]
M_@#`X```H;$```````#(Z```J;FBL@``S.S*Z@``````````H[,`````I;6D
MM```Q^<```````"FMO\``*BX``````````#1\0```*^_TO(`````````````
M``````````"JN@````"KN]?WKKX```````#9^0```````````*R\`*``!`$2
M`2(!*@$H`38!IP`[`1`!8`%F`7T!K0!J`4H!L``%`1,!(P$K`2D!-P&W`#P!
M$0%A`6<!?@$5(&L!2P$``<$`P@##`,0`Q0#&`"X!#`')`!@!RP`6`<T`S@#/
M`-``10%,`=,`U`#5`-8`:`'8`'(!V@#;`-P`W0#>`-\``0'A`.(`XP#D`.4`
MY@`O`0T!Z0`9`>L`%P'M`.X`[P#P`$8!30'S`/0`]0#V`&D!^`!S`?H`^P#\
M`/T`_@`X`0```````-#P`````````````````````-W]````````````````
M``````````````````````````````````````````#>_@``````````````
M``````````````````#1TM/4U=;7V-G:V]P``-_@X>+CY.7FY^CIZNOL[>[O
M`/'R\_3U]O?X^?K[_```_P`````````````````````>`=$`T@#3`-0`U0#6
M`-<`V`#9`-H`VP#<`#`!7@'?`.``X0#B`.,`Y`#E`.8`YP#H`.D`Z@#K`.P`
M[0#N`.\`'P'Q`/(`\P#T`/4`]@#W`/@`^0#Z`/L`_``Q`5\!_P````````#]
M_@````````#?`````````````````````.#AXN/DY>;GZ.GJZ^SM[N_P\?+S
M]/7V]_CY^@``````H`"BHZ2EIJ>HJ0"KK*VNK["QLK.TM;:WN+D`N[R]O@``
M`````````````````````````````*H`````````````````````````````
M````````````N@``````````H`#]_Z(`HP"D`*4`I@"G`*@`J0#7`*L`K`"M
M`*X`KP"P`+$`L@"S`+0`M0"V`+<`N`"Y`/<`NP"\`+T`O@#]__W__?_]__W_
M_?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]__W__?_]
M__W__?_]__W_%R#0!=$%T@73!=0%U076!=<%V`79!=H%VP7<!=T%W@7?!>`%
MX07B!>,%Y`7E!>8%YP7H!>D%Z@7]__W_#B`/(/W_``````"O``"AH@``````
M````````````````````````````M+6V`+BYN@"\`+Z_P,'"P\3%QL?(R<K+
MS,W.S]#1`-/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X
M^?K[_/W^``````````````````````"@``"C``"FIZBI`*NLK0``L+&RLP``
M`+<```"[`+T``*``&"`9(*,`_?_]_Z8`IP"H`*D`_?^K`*P`K0#]_Q4@L`"Q
M`+(`LP"$`X4#A@.W`(@#B0.*`[L`C`.]`(X#CP.0`Y$#D@.3`Y0#E0.6`Y<#
MF`.9`YH#FP.<`YT#G@.?`Z`#H0/]_Z,#I`.E`Z8#IP.H`ZD#J@.K`ZP#K0.N
M`Z\#L`.Q`[(#LP.T`[4#M@.W`[@#N0.Z`[L#O`.]`[X#OP/``\$#P@/#`\0#
MQ0/&`\<#R`/)`\H#RP/,`\T#S@/]_P````"L``````````````````"[````
MOP#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9V@``````X.'BX^3EYN?HZ>KK
M[.WN[_#Q\@``````H````*0``````````*T``*``_?_]__W_I`#]__W__?_]
M__W__?_]_PP&K0#]__W__?_]__W__?_]__W__?_]__W__?_]_QL&_?_]__W_
M'P;]_R$&(@8C!B0&)08F!B<&*`8I!BH&*P8L!BT&+@8O!C`&,08R!C,&-`8U
M!C8&-P8X!CD&.@;]__W__?_]__W_0`9!!D(&0P9$!D4&1@9'!D@&209*!DL&
M3`9-!DX&3P90!E$&4@;]__W__?_]__W__?_]__W__?_]__W__?_]_P"AHJ.D
MI::GJ*FJJZP`KJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1
MTM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O`/'R\_3U]O?X^?K[_`#^
M_Z````````#]``````"M````````````````````````H``!!`($`P0$!`4$
M!@0'!`@$"00*!`L$#`2M``X$#P00!!$$$@03!!0$%006!!<$&`09!!H$&P0<
M!!T$'@0?!"`$(00B!",$)`0E!"8$)P0H!"D$*@0K!"P$+00N!"\$,`0Q!#($
M,P0T!#4$-@0W!#@$.00Z!#L$/`0]!#X$/P1`!$$$0@1#!$0$101&!$<$2`1)
M!$H$2P1,!$T$3@1/!!8A4012!%,$5`15!%8$5P18!%D$6@1;!%P$IP!>!%\$
M`````````+<``````````````````````/\`L@````"@````I```IZ@`````
MK0"OL````+0```"X``````````#!PL/$Q<8``,D`RP#-S@``````U-76U]@`
MVMO<``#?`.'BX^3EY@``Z0#K`.WN``````#T]?;W^`#Z^_P```#`X```H;$`
M``````#(Z```T/"JN@``S.S*Z@``````````J[L`````I;7/[P``Q^<`````
M``#3\Z(``*:V``````````#1\0```+V_TO(``````````*.S``````````"I
MN0````"LO-W]WOX```````#9^0```````````*Z^`*``!`$X`58!I``H`3L!
MIP"H`&`!$@$B`68!K0!]`:\`L``%`=L"5P&T`"D!/`''`K@`80$3`2,!9P%*
M`7X!2P$``<$`P@##`,0`Q0#&`"X!#`')`!@!RP`6`<T`S@`J`1`!10%,`38!
MU`#5`-8`UP#8`'(!V@#;`-P`:`%J`=\``0'A`.(`XP#D`.4`Y@`O`0T!Z0`9
M`>L`%P'M`.X`*P$1`48!30$W`?0`]0#V`/<`^`!S`?H`^P#\`&D!:P'9`J+_
M````````````````````````````````````````QN;%Y0``````````````
M``````#8^*N[U?4``*:VH;$``````````*FY``"LO```````````````````
M````````````````````````````````WOZJN@```````````````-W]````
M`````````````*^_``````````````"@``"CI```IZ@`````K0``L`"RL[2U
M`+>X`````+T``,#!P@#$``#'R,G*R\S-SL\`T=+3U`#6UP#9VMO<``#?X.'B
M`.0``.?HZ>KK[.WN[P#Q\O/T`/;W`/GZ^_P```"@`"8!V`*C`*0`_?\D`:<`
MJ``P`5X!'@$T`:T`_?][`;``)P&R`+,`M`"U`"4!MP"X`#$!7P$?`34!O0#]
M_WP!P`#!`,(`_?_$``H!"`''`,@`R0#*`,L`S`#-`,X`SP#]_]$`T@#3`-0`
M(`'6`-<`'`'9`-H`VP#<`&P!7`'?`.``X0#B`/W_Y``+`0D!YP#H`.D`Z@#K
M`.P`[0#N`.\`_?_Q`/(`\P#T`"$!]@#W`!T!^0#Z`/L`_`!M`5T!V0(`````
M````MP````````````````````"B_P"R`+T``*````"D``"GJ`````"M``"P
M````M````+@``````````,'"`,0``,<`R0#+`,W.`````-/4`-;7``#:`-S=
M`-\`X>(`Y```YP#I`.L`[>X`````\_0`]O<``/H`_/T`````P^.AL<;F````
M`,CHS^_0\````````,KJS.P`````````````````````````````````````
M`,7E``"EM0``H[/1\0``TO(`````````U?4``,#@``#8^*:V``"JNJFYWOZK
MNP``````````V?G;^P````````"LO*^_KKX`H``$`=@"00&D`#T!6@&G`*@`
M8`%>`60!>0&M`'T!>P&P``4!VP)"`;0`/@%;`<<"N`!A`5\!90%Z`=T"?@%\
M`50!P0#"``(!Q``Y`08!QP`,`<D`&`'+`!H!S0#.``X!$`%#`4<!TP#4`%`!
MU@#7`%@!;@':`'`!W`#=`&(!WP!5`>$`X@`#`>0`.@$'`><`#0'I`!D!ZP`;
M`>T`[@`/`1$!1`%(`?,`]`!1`?8`]P!9`6\!^@!Q`?P`_0!C`=D"``````"H
M_P/^__\'_O__!P`F``"!\_^'_O__!_[__P<`)@``__?______^____\_(GH%
M""!Z!0@/>@4(_GD%".IY!0C6>04(PGD%"`:B!0@TH04(-*$%"/RA!0CRH04(
M%Z(%"#2A!0@TH04(#:(%"#2A!0@TH04(Z*$%"#2A!0CAH04(9Z$%"#FF!0B>
MI@4(-*8%"*6F!0@TI@4(-*8%"#2F!0@TI@4(-*8%"*RF!0@TI@4(-*8%"#2F
M!0@TI@4(-*8%"#2F!0@TI@4(-*8%"#2F!0@TI@4(-*8%"#2F!0@TI@4(-*8%
M"#2F!0@TI@4(-*8%"#2F!0@TI@4(-*8%"#2F!0@TI@4(-*8%"#2F!0@TI@4(
MLZ8%",>]!0@NO@4(PKT%"#R^!0C"O04(PKT%",*]!0C"O04(PKT%"$.^!0C"
MO04(PKT%",*]!0C"O04(PKT%",*]!0C"O04(PKT%",*]!0C"O04(PKT%",*]
M!0C"O04(PKT%",*]!0C"O04(PKT%",*]!0C"O04(PKT%",*]!0C"O04(PKT%
M",*]!0C"O04(-;X%",WV!0C-]P4("/<%"#SW!0@H]@4(C_4%"._T!0C*6```
MRE@``(Q6``"+6```2/L%",3]!0@D_`4(H/X%"-S[!0A0^P4(%1<&"+@9!@A,
M&08(X!@&"'08!@C9%P8(]"D&",LL!@AQ+`8(!2P&"*PK!@A2*P8(^2H&"*0J
M!@CT*08(]"D&"/0I!@CT*08(]"D&"/0I!@CT*08((2H&"%UM!@AT;08('&T&
M"(AL!@B,:P8(C&L&",Q_!@C,?P8(`H`&"`*`!@@"@`8(^'\&"/A_!@CX?P8(
M`H`&"`*`!@@"@`8(^'\&"/A_!@CX?P8(S'\&"`*`!@@"@`8(^'\&"/A_!@@`
M``````````````````````````````!P`W`#<`-P`W`#<`-P`W`#<`-P`W`#
M<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P
M`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`,&`$4`<`,L``4`!@`2`#P`"0`(`#(`
M#@`-``\!<`-P`W`#<`-P`W`#:P"8``4`'0`'`"L`<``J``4`50%J``H`G@`(
M``4`!@!P`ST`)@!B`)@`P@!P`!X`"@`&`'`#<`-P`W`#/`!P`W`#<`-P`W`#
M<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P`W`#<`-P
M`W`#<`-P`W`#+((&"*N"!@BK@@8(G8(&"(^"!@B!@@8(<X(&"&6"!@A7@@8(
M28(&"#N"!@B6A`8(%84&"!6%!@@'A08(^80&".N$!@C=A`8(SX0&",&$!@BS
MA`8(I80&"*B&!@@GAP8()X<&"!F'!@@+AP8(_88&".^&!@CAA@8(TX8&",6&
M!@BWA@8(((D&"#R)!@A(B08(6(D&"`R)!@@``````````"\O5%)!3E-,250`
M+R])1TY/4D4``"4U,',@)34P<P``+W5S<B]H;VUE+V)U:6QD97(O<&)?=V]R
M:U]D:7(O<&QE<VLW+C4N-%]H;W1F:7@X7S<N-2XT+W!S82]L:6(O9&ES="]L
M:6(`+V1E=B]N=6QL`&1U<#)#=7-T;VT@9F%I;&5D`')E8614;U-T<FEN9R!F
M86EL960`9F]R:T5X96-V4&EP97,Z(&9O<FLH*2!F86EL960```!F;W)K17AE
M8W90:7!E<SH@97AE8W8H*2!F86EL960``&9O<FM%>&5C=E!I<&5S.B!S971E
M;G8H*2!F86QI960`9F]R:T5X96-V4&EP97,Z('-E='5I9"@I(&9A:6QE9`!F
M;W)K17AE8W9'971/=71%<G(Z('!I<&4H*2!F86EL960```!F;W)K17AE8W9'
M971/=71%<G(Z(&9C;G1L*$]?3D].0DQ/0TLI(&9A:6QE9`````!F;W)K17AE
M8W9'971/=71%<G(Z('-E;&5C="@I(&9A:6QE9`#0PB4(E_P8"'S\&`C0PB4(
MB/P8"/C")0A.,W!S83=%>$5R<F]R10!.,W!S83$W17A3>7-T96U%<G)O<D)A
M<V5%`````-#")0C`_!@(</P8"$XS<'-A,3-%>%-Y<W1E;45R<F]R24QI,3!%
M144`````T,(E".S\&`AP_!@(3C-P<V$Q,T5X4WES=&5M17)R;W))3&DS-45%
M10````#0PB4(&/T8"'#\&`A.,W!S83$S17A3>7-T96U%<G)O<DE,:31%144`
MT,(E"$#]&`AP_!@(3C-P<V$Q,T5X4WES=&5M17)R;W))3&DR145%`-#")0AH
M_1@(</P8"$XS<'-A,3-%>%-Y<W1E;45R<F]R24QI,45%10```````````%S]
M&`B$K`8(4*T&".RE!@@``````````'#\&`API`8(**4&".RE!@@`````````
M`'S\&`BXHP8($*0&"/BE!@@``````````#3]&`CDJ@8(L*L&".RE!@@`````
M``````S]&`A$J08($*H&".RE!@@``````````.#\&`BDIP8(<*@&".RE!@@`
M`````````+3\&`@$I@8(T*8&".RE!@@`````=&-P`$U94U%,7U1#4%]03U)4
M`')O;W0`3$]'3D%-10!53DM.3U=.7U5315(`+W1M<`!32$]7(%-,059%($A/
M4U13`%-(3U<@4TQ!5D4@4U1!5%53`'-H;W<@9&%T86)A<V5S`"!L:6ME("<`
M<VAO=R!T86)L97,`)2TJ+BIG`"4N*F8`8V]M;6ET`')O;&QB86-K`'-E="!A
M=71O8V]M;6ET/3$`<V5T(&%U=&]C;VUM:70],````!.R!@@QL@8(4[(&"!.R
M!@@QL@8(2[(&"$NR!@@QL@8($[(&"#&R!@@QL@8($[(&"#&R!@@QL@8(,;(&
M"#&R!@@QL@8(2[(&"#FR!@@QL@8($[(&"%SE!@BHY08(U.4&"/GE!@@<Y@8(
MJ>8&")KE!@B.Y@8(0^8&"%SE!@B.Y@8(>.8&"([F!@@`YP8(?.<&"(/G!@B+
MYP8(F.<&"-'G!@@\YP8(`.<&"+[G!@A`Z`8(7ND&")?I!@@RZ08((ND&"-+H
M!@B:Z`8(0.@&".3H!@CPZ08(3NH&""#J!@CCZ@8(>NH&"*#J!@CPZ08(^NL&
M",GJ!@CCZ@8(!^L&"&[K!@CZZP8((.H&"```@%\E,#AL>"4P.&QX`````(#_
M___/00```````#]`````````4$```/A!``"\0@``!$)5;FMN;W=N($UY4U%,
M(&5R<F]R`$-A;B=T(&-R96%T92!53DE8('-O8VME="`H)60I`$UY4U%,('-E
M<G9E<B!H87,@9V]N92!A=V%Y`%=R;VYG(&AO<W0@:6YF;P!,;V-A;&AO<W0@
M=FEA(%5.25@@<V]C:V5T`"4M+C$P,',@=FEA(%1#4"])4`!%<G)O<B!I;B!S
M97)V97(@:&%N9'-H86ME`$YA;65D('!I<&4Z("4M+C,R<P!%;6)E9&1E9"!S
M97)V97(`17)R;W(@;VX@4TA/5R!33$%612!35$%455,Z`$5R<F]R(&]N(%-(
M3U<@4TQ!5D4@2$]35%,Z`$5R<F]R(&-O;FYE8W1I;F<@=&\@<VQA=F4Z`$5R
M<F]R(&-O;FYE8W1I;F<@=&\@;6%S=&5R.@!34TP@8V]N;F5C=&EO;B!E<G)O
M<@!-86QF;W)M960@<&%C:V5T`$EN=F%L:60@=7-E(&]F(&YU;&P@<&]I;G1E
M<@!3=&%T96UE;G0@;F]T('!R97!A<F5D`$1A=&$@=')U;F-A=&5D`$EN=F%L
M:60@<&%R86UE=&5R(&YU;6)E<@!3:&%R960@;65M;W)Y.B`E+2XQ,#!S`%=R
M;VYG(&]R('5N:VYO=VX@<')O=&]C;VP`26YV86QI9"!C;VYN96-T:6]N(&AA
M;F1L90````!#86XG="!C;VYN96-T('1O(&QO8V%L($UY4U%,('-E<G9E<B!T
M:')O=6=H('-O8VME="`G)2TN,3`P<R<@*"5D*0```$-A;B=T(&-O;FYE8W0@
M=&\@37E344P@<V5R=F5R(&]N("<E+2XQ,#!S)R`H)60I`$-A;B=T(&-R96%T
M92!40U`O25`@<V]C:V5T("@E9"D`56YK;F]W;B!->5-13"!S97)V97(@:&]S
M="`G)2TN,3`P<R<@*"5D*0````!0<F]T;V-O;"!M:7-M871C:#L@<V5R=F5R
M('9E<G-I;VX@/2`E9"P@8VQI96YT('9E<G-I;VX@/2`E9`!->5-13"!C;&EE
M;G0@<F%N(&]U="!O9B!M96UO<GD``$QO<W0@8V]N;F5C=&EO;B!T;R!->5-1
M3"!S97)V97(@9'5R:6YG('%U97)Y`````$-O;6UA;F1S(&]U="!O9B!S>6YC
M.R!Y;W4@8V%N)W0@<G5N('1H:7,@8V]M;6%N9"!N;W<`````0V%N)W0@=V%I
M="!F;W(@;F%M960@<&EP92!T;R!H;W-T.B`E+2XV-',@('!I<&4Z("4M+C,R
M<R`H)6QU*0```$-A;B=T(&]P96X@;F%M960@<&EP92!T;R!H;W-T.B`E+2XV
M-',@('!I<&4Z("4M+C,R<R`H)6QU*0```$-A;B=T('-E="!S=&%T92!O9B!N
M86UE9"!P:7!E('1O(&AO<W0Z("4M+C8T<R`@<&EP93H@)2TN,S)S("@E;'4I
M````0V%N)W0@:6YI=&EA;&EZ92!C:&%R86-T97(@<V5T("4M+C,R<R`H<&%T
M:#H@)2TN,3`P<RD```!';W0@<&%C:V5T(&)I9V=E<B!T:&%N("=M87A?86QL
M;W=E9%]P86-K970G(&)Y=&5S````5&AI<R!C;&EE;G0@;&EB<F%R>2!I<R!L
M:6-E;G-E9"!O;FQY(&9O<B!U<V4@=VET:"!->5-13"!S97)V97)S(&AA=FEN
M9R`G)7,G(&QI8V5N<V4`3F\@9&%T82!S=7!P;&EE9"!F;W(@<&%R86UE=&5R
M<R!I;B!P<F5P87)E9"!S=&%T96UE;G0```!.;R!P87)A;65T97)S(&5X:7-T
M(&EN('1H92!S=&%T96UE;G0`````0V%N)W0@<V5N9"!L;VYG(&1A=&$@9F]R
M(&YO;BUS=')I;F<O;F]N+6)I;F%R>2!D871A('1Y<&5S("AP87)A;65T97(Z
M("5D*0```%5S:6YG('5N<W5P<&]R=&5D(&)U9F9E<B!T>7!E.B`E9"`@*'!A
M<F%M971E<CH@)60I``!#86XG="!O<&5N('-H87)E9"!M96UO<GD[(&-L:65N
M="!C;W5L9"!N;W0@8W)E871E(')E<75E<W0@979E;G0@*"5L=2D```!#86XG
M="!O<&5N('-H87)E9"!M96UO<GD[(&YO(&%N<W=E<B!E=F5N="!R96-E:79E
M9"!F<F]M('-E<G9E<B`H)6QU*0````!#86XG="!O<&5N('-H87)E9"!M96UO
M<GD[('-E<G9E<B!C;W5L9"!N;W0@86QL;V-A=&4@9FEL92!M87!P:6YG("@E
M;'4I``!#86XG="!O<&5N('-H87)E9"!M96UO<GD[('-E<G9E<B!C;W5L9"!N
M;W0@9V5T('!O:6YT97(@=&\@9FEL92!M87!P:6YG("@E;'4I`````$-A;B=T
M(&]P96X@<VAA<F5D(&UE;6]R>3L@8VQI96YT(&-O=6QD(&YO="!A;&QO8V%T
M92!F:6QE(&UA<'!I;F<@*"5L=2D``$-A;B=T(&]P96X@<VAA<F5D(&UE;6]R
M>3L@8VQI96YT(&-O=6QD(&YO="!G970@<&]I;G1E<B!T;R!F:6QE(&UA<'!I
M;F<@*"5L=2D`````0V%N)W0@;W!E;B!S:&%R960@;65M;W)Y.R!C;&EE;G0@
M8V]U;&0@;F]T(&-R96%T92`E<R!E=F5N="`H)6QU*0````!#86XG="!O<&5N
M('-H87)E9"!M96UO<GD[(&YO(&%N<W=E<B!F<F]M('-E<G9E<B`H)6QU*0``
M`$-A;B=T(&]P96X@<VAA<F5D(&UE;6]R>3L@8V%N;F]T('-E;F0@<F5Q=65S
M="!E=F5N="!T;R!S97)V97(@*"5L=2D`0V]N;F5C=&EO;B!U<VEN9R!O;&0@
M*'!R92TT+C$N,2D@875T:&5N=&EC871I;VX@<')O=&]C;VP@<F5F=7-E9"`H
M8VQI96YT(&]P=&EO;B`G<V5C=7)E7V%U=&@G(&5N86)L960I``!2;W<@<F5T
M<FEE=F%L('=A<R!C86YC96QE9"!B>2!M>7-Q;%]S=&UT7V-L;W-E*"D@8V%L
M;````$%T=&5M<'0@=&\@<F5A9"!C;VQU;6X@=VET:&]U="!P<FEO<B!R;W<@
M9F5T8V@``%!R97!A<F5D('-T871E;65N="!C;VYT86EN<R!N;R!M971A9&%T
M80!534%32P!534%32U]$25(`"E5S97(@=&EM92`E+C)F+"!3>7-T96T@=&EM
M92`E+C)F"DUA>&EM=6T@<F5S:61E;G0@<V5T('-I>F4@)6QD+"!);G1E9W)A
M;"!R97-I9&5N="!S970@<VEZ92`E;&0*3F]N+7!H>7-I8V%L('!A9V5F875L
M=',@)6QD+"!0:'ES:6-A;"!P86=E9F%U;'1S("5L9"P@4W=A<',@)6QD"D)L
M;V-K<R!I;B`E;&0@;W5T("5L9"P@365S<V%G97,@:6X@)6QD(&]U="`E;&0L
M(%-I9VYA;',@)6QD"E9O;'5N=&%R>2!C;VYT97AT('-W:71C:&5S("5L9"P@
M26YV;VQU;G1A<GD@8V]N=&5X="!S=VET8VAE<R`E;&0*``````#(0FYO;F4`
M<W1R:7!E9``P,3(S,#$R,#`R,C0U-3`Q,C8R,S`Q,#(P,@!&:6QE("<E<R<@
M;F]T(&9O=6YD("A%<G)C;V1E.B`E9"D```!#86XG="!C<F5A=&4O=W)I=&4@
M=&\@9FEL92`G)7,G("A%<G)C;V1E.B`E9"D```!%<G)O<B!R96%D:6YG(&9I
M;&4@)R5S)R`H17)R8V]D93H@)60I````17)R;W(@=W)I=&EN9R!F:6QE("<E
M<R<@*$5R<F-O9&4Z("5D*0```$5R<F]R(&]N(&-L;W-E(&]F("<E<R<@*$5R
M<F-O9&4Z("5D*0````!/=70@;V8@;65M;W)Y("A.965D960@)74@8GET97,I
M`$5R<F]R(&]N(&1E;&5T92!O9B`G)7,G("A%<G)C;V1E.B`E9"D```!%<G)O
M<B!O;B!R96YA;64@;V8@)R5S)R!T;R`G)7,G("A%<G)C;V1E.B`E9"D```!5
M;F5X<&5C=&5D(&5O9B!F;W5N9"!W:&5N(')E861I;F<@9FEL92`G)7,G("A%
M<G)C;V1E.B`E9"D```!#86XG="!U;FQO8VL@9FEL92`H17)R8V]D93H@)60I
M`$-A;B=T(')E860@9&ER(&]F("<E<R<@*$5R<F-O9&4Z("5D*0````!#86XG
M="!G970@<W1A="!O9B`G)7,G("A%<G)C;V1E.B`E9"D`````0V%N)W0@8VAA
M;F=E('-I>F4@;V8@9FEL92`H17)R8V]D93H@)60I`$-A;B=T(&]P96X@<W1R
M96%M(&9R;VT@:&%N9&QE("A%<G)C;V1E.B`E9"D`0V%N)W0@9V5T('=O<FMI
M;F<@9&ER8W1O<GD@*$5R<F-O9&4Z("5D*0````!#86XG="!C:&%N9V4@9&ER
M('1O("<E<R<@*$5R<F-O9&4Z("5D*0``)60@9FEL97,@86YD("5D('-T<F5A
M;7,@:7,@;&5F="!O<&5N"@```$1I<VL@:7,@9G5L;"!W<FET:6YG("<E<R<@
M*$5R<F-O9&4Z("5D*2X@5V%I=&EN9R!F;W(@<V]M96]N92!T;R!F<F5E('-P
M86-E+BXN(%)E=')Y(&EN("5D('-E8W,``$-A;B=T(&-R96%T92!D:7)E8W1O
M<GD@)R5S)R`H17)R8V]D93H@)60I````0VAA<F%C=&5R('-E="`G)7,G(&ES
M(&YO="!A(&-O;7!I;&5D(&-H87)A8W1E<B!S970@86YD(&ES(&YO="!S<&5C
M:69I960@:6X@=&AE("<E<R<@9FEL90````!/=70@;V8@<F5S;W5R8V5S('=H
M96X@;W!E;FEN9R!F:6QE("<E<R<@*$5R<F-O9&4Z("5D*0```$-A;B=T(')E
M860@=F%L=64@9F]R('-Y;6QI;FL@)R5S)R`H17)R;W(@)60I`````$-A;B=T
M(&-R96%T92!S>6UL:6YK("<E<R<@<&]I;G1I;F<@870@)R5S)R`H17)R;W(@
M)60I````17)R;W(@;VX@<F5A;'!A=&@H*2!O;B`G)7,G("A%<G)O<B`E9"D`
M`$-A;B=T('-Y;F,@9FEL92`G)7,G('1O(&1I<VL@*$5R<F-O9&4Z("5D*0``
M0V]L;&%T:6]N("<E<R<@:7,@;F]T(&$@8V]M<&EL960@8V]L;&%T:6]N(&%N
M9"!I<R!N;W0@<W!E8VEF:65D(&EN('1H92`G)7,G(&9I;&4`0V%N)W0@;&]C
M:R!F:6QE("A%<G)C;V1E.B`E9"D`5V%R;FEN9SH@)R5S)R!H860@)60@;&EN
M:W,`54Y+3D]73@!53D]014Y%1``N+@```"]U<W(O;&]C86PO<'-A+VUY<W%L
M+W-H87)E+VUY<W%L`&-H87)S971S+P`O=7-R+VQO8V%L+W!S82]M>7-Q;`!)
M;F1E>"YX;6P`=6-S,@`_``````$C16>)J\WO_MRZF'94,A#PX=+#F7F"6J'K
MV6[<O!N/UL%BRFQA=&EN,0!L871I;C%?8FEN`&QA=&EN,5]G97)M86XR7V-I
M`&QA=&EN,5]S=V5D:7-H7V-I`"AN=6QL*0!X;6PN=F5R<VEO;@!X;6PN96YC
M;V1I;F<`8VAA<G-E=',`8VAA<G-E=',N;6%X+6ED`&-H87)S971S+F-H87)S
M970`8VAA<G-E=',N8VAA<G-E="YP<FEM87)Y+6ED`&-H87)S971S+F-H87)S
M970N8FEN87)Y+6ED`&-H87)S971S+F-H87)S970N;F%M90!C:&%R<V5T<RYC
M:&%R<V5T+F9A;6EL>0!C:&%R<V5T<RYC:&%R<V5T+F1E<V-R:7!T:6]N`&-H
M87)S971S+F-H87)S970N86QI87,`8VAA<G-E=',N8VAA<G-E="YC='EP90!C
M:&%R<V5T<RYC:&%R<V5T+F-T>7!E+FUA<`!C:&%R<V5T<RYC:&%R<V5T+G5P
M<&5R`&-H87)S971S+F-H87)S970N=7!P97(N;6%P`&-H87)S971S+F-H87)S
M970N;&]W97(`8VAA<G-E=',N8VAA<G-E="YL;W=E<BYM87``8VAA<G-E=',N
M8VAA<G-E="YU;FEC;V1E`&-H87)S971S+F-H87)S970N=6YI8V]D92YM87``
M8VAA<G-E=',N8VAA<G-E="YC;VQL871I;VX`8VAA<G-E=',N8VAA<G-E="YC
M;VQL871I;VXN:60`)@`\/#P`("5S("5S`'!R:6UA<GD`8FEN87)Y`&-O;7!I
M;&5D``!C:&%R<V5T<RYC:&%R<V5T+F-O;&QA=&EO;BYN86UE`&-H87)S971S
M+F-H87)S970N8V]L;&%T:6]N+F]R9&5R`````&-H87)S971S+F-H87)S970N
M8V]L;&%T:6]N+F9L86<`8VAA<G-E=',N8VAA<G-E="YC;VQL871I;VXN;6%P
M``!C:&%R<V5T<RYC:&%R<V5T+F-O;&QA=&EO;BYR=6QE<RYR97-E=```8VAA
M<G-E=',N8VAA<G-E="YC;VQL871I;VXN<G5L97,N<```8VAA<G-E=',N8VAA
M<G-E="YC;VQL871I;VXN<G5L97,N<P``8VAA<G-E=',N8VAA<G-E="YC;VQL
M871I;VXN<G5L97,N=```F&`'")A@!P@R90<(`V4'")A@!PB88`<(SV0'")]D
M!PB88`<(F&`'"*)@!P@(9`<(<&,'"`]B!PAY80<(7F$'"#MA!P@V8P<(IV('
M"*=B!PBG8@<(IV('"&)I9S4`8FEG-5]B:6X`8FEG-5]C:&EN97-E7V-I`&QA
M=&EN,@!L871I;C)?8WIE8VA?8W,`8V@`#!DO+P!#:``,&3`P`$-(``P9,3$`
M!0H1$0`%"A(2```````````````"``````````````````````````````(`
M```````````````````C)"4F)R@I*BLL``````````,$_P<("0H+#0X/$!(3
M%!46%QD;'!T>'R`A`````````P3_!P@)"@L-#@\0$A,4%187&1L<'1X?("$`
M``````````````````````````````````````````````````,`$0`0&@``
M&AH;(@`B(@`#`!$`$!H``!H:&R(`(B(7`P,#`Q`&!@8("`@(#0T'!Q,3%!04
M%``8'!P<'"`;`!<#`P,#$`8&!@@("`@-#0<'$Q,4%!04`!@<'!P<(!L`````
M``````````````(``````````````````````````````@``````````````
M`````$9'2$E*2TQ-3D\``````````PG_#A$6%Q@:'1X?(R0G+"TN,34X/3X_
M0$(````````#"?\.$187&!H='A\C)"<L+2XQ-3@]/C]`0@``````````````
M````````````````````````````````````"``B`"$S```R-#9$`$-%``@`
M(@`A,P``,C0V1`!#12\$!0<&(`P-"Q(5%!,;'`\0)B4H*2LJ`#`Z.3P[03<`
M+P0%!P8@#`T+$A44$QL<#Q`F)2@I*RH`,#HY/#M!-P``````````````````
M`@`````````````````````````````"````````````````````BHN,C8Z/
MD)&2DP`````````$$/\:("HL+C,Y.SU%1TU765MA:6]Y>WU_@P````````,/
M_QD?*2LM,C@Z/$1&3%986F!H;GAZ?'Z"````````````````````````````
M```````````````````````.`$,`064``&-G:X<`A8D`#0!"`$!D``!B9FJ&
M`(2(708(#`H_%A@4(B@F)#4W'!Y+24]155,`7W-Q=W6!;0!<!0<+"3X5%Q,A
M)R4C-#8;'4I(3E!44@!><G!V=(!L``````"TM;:WN+FZN[P"OK_`P<+#Q,7&
MQ\C)RLO,S<[/T-'2TP*8FJO4JJF<H*&QL)6RE)V*BXR-CH^0D9*3F9:DKZ67
MJ`00_QH@*BPN,SD[/45'35=96V%I;WE[?7^#HI^CK*V;`P__&1\I*RTR.#H\
M1$9,5EA:8&AN>'I\?H*FGJ>NU;2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-
MSL_0T=+3U@[70]A!9=G:8V=KA]N%B=P-W4+>0&3?X&)F:H;AA(A=!@@,"C\6
M&!0B*"8D-3<<'DM)3U%54[-?<W%W=8%MXEP%!PL)/A47$R$G)2,T-AL=2DA.
M4%12XUYR<'9T@&SD`&5U8VMR`&5U8VMR7V)I;@!E=6-K<E]K;W)E86Y?8VD`
M8W`Q,C4P`&-P,3(U,%]C>F5C:%]C<P!U=&8X`'5T9CA?8FEN`'5T9CA?9V5N
M97)A;%]C:0!U8W,R7V)I;@!U8W,R7V=E;F5R86Q?8VD`9V(R,S$R`&=B,C,Q
M,E]B:6X`9V(R,S$R7V-H:6YE<V5?8VD`9V)K`&=B:U]B:6X`9V)K7V-H:6YE
M<V5?8VD`<VII<P!S:FES7V)I;@!S:FES7VIA<&%N97-E7V-I`'1I<S8R,`!T
M:7,V,C!?8FEN`'1I<S8R,%]T:&%I7V-I`'5J:7,`=6II<U]B:6X`=6II<U]J
M87!A;F5S95]C:0!U=&8X7W!E<G-I86Y?8VD`=71F.%]R;VUA;E]C:0!U=&8X
M7W-P86YI<V@R7V-I`'5T9CA?<VQO=F%K7V-I`'5T9CA?;&ET:'5A;FEA;E]C
M:0!U=&8X7V1A;FES:%]C:0!U=&8X7V-Z96-H7V-I`'5T9CA?='5R:VES:%]C
M:0!U=&8X7W-W961I<VA?8VD`=71F.%]S<&%N:7-H7V-I`'5T9CA?97-T;VYI
M86Y?8VD`=71F.%]P;VQI<VA?8VD`=71F.%]S;&]V96YI86Y?8VD`=71F.%]R
M;VUA;FEA;E]C:0!U=&8X7VQA='9I86Y?8VD`=71F.%]I8V5L86YD:6-?8VD`
M=71F.%]U;FEC;V1E7V-I`'5C<S)?<&5R<VEA;E]C:0!U8W,R7W)O;6%N7V-I
M`'5C<S)?<W!A;FES:#)?8VD`=6-S,E]S;&]V86M?8VD`=6-S,E]L:71H=6%N
M:6%N7V-I`'5C<S)?9&%N:7-H7V-I`'5C<S)?8WIE8VA?8VD`=6-S,E]T=7)K
M:7-H7V-I`'5C<S)?<W=E9&ES:%]C:0!U8W,R7W-P86YI<VA?8VD`=6-S,E]E
M<W1O;FEA;E]C:0!U8W,R7W!O;&ES:%]C:0!U8W,R7W-L;W9E;FEA;E]C:0!U
M8W,R7W)O;6%N:6%N7V-I`'5C<S)?;&%T=FEA;E]C:0!U8W,R7VEC96QA;F1I
M8U]C:0!U8W,R7W5N:6-O9&5?8VD`)B!E>'!E8W1E9``E<R!A="`G)7,G`%5N
M:VYO=VX@8VAA<F%C=&5R`"8@;W(@/"!E>'!E8W1E9`!C:&%R86-T97(@97AP
M96-T960`4VAO=6QD(&YE=F5R(&AA<'!E;@!4;V\@;6%N>2!R=6QE<P``````
M````````````````````)B!<=3`V-D0@/"!<=3`V-$4@/"!<=49%-S8@/"!<
M=49%-S<@/"!<=3`V-3`@/"!<=49%-T$@/"!<=49%-T(@/"!<=3`V-$8@/"!<
M=49%-S@@/"!<=49%-SD@/"!<=3`V-$(@/"!<=49%-S`@/"!<=49%-S$@/"!<
M=3`V-$0@/"!<=49%-S0@/"!<=3`V-$,@/"!<=49%-S(F(%QU1D4W1B`\(%QU
M,#8U,R`\(%QU,#8U-"`\(%QU,#8U-2`\(%QU,#8W,"8@7'4P-C8Y(#P@7'4P
M-C(R(#P@7'4P-C(W(#P@7'4P-C<Q(#P@7'4P-C(Q(#P@7'4P-C(S(#P@7'4P
M-C(U(#P@7'4P-C(T(#P@7'4P-C(V)B!<=3`V-#(@/"!<=3`V03D@/"!<=3`V
M-#,F(%QU,#8T."`\(%QU,#8T-R`\(%QU,#8R.2`\(%QU,#9#,"`\(%QU,#9#
M0R`\(%QU,#8T.2`\(%QU,#8T028@7'5&13@P(#P@7'5&13@Q(#P@7'5&13@R
M(#P@7'5&13A$(#P@7'5&13A%(#P@7'5&0C4P(#P@7'5&0C4Q(#P@7'5&13@P
M(#P@7'5&13@S(#P@7'5&13@T(#P@7'5&13@W(#P@7'5&13@X(#P@7'5&13@U
M(#P@7'5&13@V(#P@7'4P-C@Y(#P@7'4P-CA!)B!<=49%044@/"!<=49$1D,F
M(%QU1D5$."`\(%QU1D(X12`\(%QU1D(X1B`\(%QU1D(Y,"`\(%QU1D(Y,2`\
M(%QU1D5$.2`\(%QU1D5$02`\(%QU1D5$0B`\(%QU1D5$0R8@7'5&145%(#P@
M7'5&144Y(#P@7'5&145!(#P@7'5&145"(#P@7'5&145#(#P@7'5&13DS(#P@
M7'5&13DT(#P@7'5&0D$T(#P@7'5&0D$U(#P@7'5&0D9#(#P@7'5&0D9$(#P@
M7'5&0D9%(#P@7'5&0D9&(#P@7'5&145&(#P@7'5&148P(#P@7'5&148Q(#P@
M7'5&148R(#P@7'5&148S(#P@7'5&148T(#P@7'5&148U(#P@7'5&148V(#P@
M7'5&148W(#P@7'5&148X(#P@7'5&148Y(#P@7'5&149!(#P@7'5&149"(#P@
M7'5&149#```F($D@/#P@:B`\/#P@2B`F(%8@/#P@=2`\/#P@52``````````
M```````````````F0R`\("!C:"`\/#P@0V@@/#P\($-()DP@/"`@;&P@/#P\
M($QL(#P\/"!,3"9.(#P@7'4P,$8Q(#P\/"!<=3`P1#$F4B`\/"!R<B`\/#P@
M4G(@/#P\(%)2```````````F($$@/"!<=3`P130@/#P\(%QU,#!#-"8@0R`\
M(%QU,#$P1"`\/#P@7'4P,3!#)B!((#P@8V@@/#P\($-H(#P\/"!#2"8@3R`\
M(%QU,#!&-"`\/#P@7'4P,$0T)B!3(#P@7'4P,38Q(#P\/"!<=3`Q-C`F(%H@
M/"!<=3`Q-T4@/#P\(%QU,#$W1```````````````````````````````)B!#
M(#P\(&-H(#P\/"!#:"`\/#P@0T@\(%QU,#$P1"`\/#P@7'4P,3!#)B!%(#P\
M(%QU,#$Q.2`\/#P@7'4P,3$X(#P\(%QU,#$Q-R`\/#P@7'4P,3$V)B!)(#P\
M('D@/#P\(%DF(%,@(#P@7'4P,38Q(#P\/"!<=3`Q-C`F(%H@(#P@7'4P,3=%
M(#P\/"!<=3`Q-T0``````````````"8@62`\/"!<=3`P1D,@/#P\(%QU,#!$
M0R`\/"!<=3`Q-S$@/#P\(%QU,#$W,"8@6B`@/"!<=3`P138@/#P\(%QU,#!#
M-B`\/"!<=3`P130@/#P\(%QU,#!#-"`\(%QU,#!&."`\/#P@7'4P,$0X(#P\
M(%QU,#!&-B`\/#P@7'4P,$0V(#P\(%QU,#$U,2`\/#P@7'4P,34P(#P@7'4P
M,$4U(#P\/"!<=3`P0S4@/#P@86$@/#P\("!!82`\/#P@04$`````````````
M````````````````````````````)B!#(#P@7'4P,3!$(#P\/"!<=3`Q,$,@
M)B!((#P@("`@("!C:"`\/#P@("`@("!#:"`\/#P@0T@F(%(@/"!<=3`Q-3D@
M/#P\(%QU,#$U."8@4R`\(%QU,#$V,2`\/#P@7'4P,38P)B!:(#P@7'4P,3=%
M(#P\/"!<=3`Q-T0````F($,@/"!<=3`P13<@/#P\(%QU,#!#-R`F($<@/"!<
M=3`Q,48@/#P\(%QU,#$Q12`F($@@/"!<=3`Q,S$@/#P\(%QU,#`T.2`F($\@
M/"!<=3`P1C8@/#P\(%QU,#!$-B`F(%,@/"!<=3`Q-48@/#P\(%QU,#$U12`F
M(%4@/"!<=3`P1D,@/#P\(%QU,#!$0R``````````````````````)B!9(#P\
M7'4P,$9#(#P\/"!<=3`P1$,@)B!:(#P@7'4P,$4U(#P\/"!<=3`P0S4@/"!<
M=3`P130@/#P\(%QU,#!#-"`\/"!<=3`P138@/#P\(%QU,#!#-B`\(%QU,#!&
M-B`\/#P@7'4P,$0V(#P\(%QU,#!&."`\/#P@7'4P,$0X(``F($X@/"!<=3`P
M1C$@/#P\(%QU,#!$,2```````"8@4R`\(%QU,#$V,2`\/#P@7'4P,38P("`\
M(%QU,#`W02`\/#P@7'4P,#5!("`\(%QU,#$W12`\/#P@7'4P,3=$("8@5R`\
M(%QU,#!&-2`\/#P@7'4P,$0U(#P@7'4P,$4T(#P\/"!<=3`P0S0@/"!<=3`P
M1C8@/#P\(%QU,#!$-B`\(%QU,#!&0R`\/#P@7'4P,$1#(``````````````F
M($$@/"!<=3`Q,#4@/#P\(%QU,#$P-"`F($,@/"!<=3`Q,#<@/#P\(%QU,#$P
M-B`F($4@/"!<=3`Q,3D@/#P\(%QU,#$Q."`F($P@/"!<=3`Q-#(@/#P\(%QU
M,#$T,2`F($X@/"!<=3`Q-#0@/#P\(%QU,#$T,R`F($\@/"!<=3`P1C,@/#P\
M(%QU,#!$,R`F(%,@/"!<=3`Q-4(@/#P\(%QU,#$U02`F(%H@/"!<=3`Q-T$@
M/#P\(%QU,#$W.2`\(%QU,#$W0R`\/#P@7'4P,3="`````````````````"8@
M0R`\(%QU,#$P1"`\/#P@7'4P,3!#("8@4R`\(%QU,#$V,2`\/#P@7'4P,38P
M("8@6B`\(%QU,#$W12`\/#P@7'4P,3=$(```````````````````````````
M`````"8@02`\(%QU,#$P,R`\/#P@7'4P,3`R(#P@7'4P,$4R(#P\/"!<=3`P
M0S(@)B!)(#P@7'4P,$5%(#P\/"!<=3`P0T4@)B!3(#P@7'4P,C$Y(#P\/"!<
M=3`R,3@@/#P@7'4P,35&(#P\/"!<=3`Q-44@)B!4(#P@7'4P,C%"(#P\/"!<
M=3`R,4$@/#P@7'4P,38S(#P\/"!<=3`Q-C(@```F($,@/"!<=3`Q,$0@/#P\
M(%QU,#$P0R`F($<@/"!<=3`Q,C,@/#P\(%QU,#$R,B`F($D@/"!<=3`P-SD@
M/#P\(%QU,#`U.2`F($L@/"!<=3`Q,S<@/#P\(%QU,#$S-B`F($P@/"!<=3`Q
M,T,@/#P\(%QU,#$S0B`F($X@/"!<=3`Q-#8@/#P\(%QU,#$T-2`F(%(@/"!<
M=3`Q-3<@/#P\(%QU,#$U-B`F(%,@/"!<=3`Q-C$@/#P\(%QU,#$V,"`F(%H@
M/"!<=3`Q-T4@/#P\(%QU,#$W1"```````````"8@02`\(%QU,#!%,2`\/#P@
M7'4P,$,Q("8@1"`\(%QU,#!&,"`\/#P@7'4P,$0P("8@12`\(%QU,#!%.2`\
M/#P@7'4P,$,Y("8@22`\(%QU,#!%1"`\/#P@7'4P,$-$("8@3R`\(%QU,#!&
M,R`\/#P@7'4P,$0S("8@52`\(%QU,#!&02`\/#P@7'4P,$1!("8@62`\(%QU
M,#!&1"`\/#P@7'4P,$1$("8@6B`\(%QU,#!&12`\/#P@7'4P,$1%(#P@7'4P
M,$4V(#P\/"!<=3`P0S8@/#P@7'4P,$4T(#P\/"!<=3`P0S0@/"!<=3`P1C8@
M/#P\(%QU,#!$-B`\/"!<=3`P1C@@/#P\(%QU,#!$."`\(%QU,#!%-2`\/#P@
M7'4P,$,U(```````````````````````````````````/"$M+0`M+3X`/STO
M/#XA`#\G(CTO/#X@"0T*`%1%6%0`-CH@)7,@=6YE>'!E8W1E9"`H)S\G('=A
M;G1E9"D`4U1224Y'`$E$14Y4`$5/1@!#3TU-14Y4`"<_)P`G/B<`)STG`"<\
M)P`G+R<`)R$G`#4Z("5S('5N97AP96-T960@*"<^)R!W86YT960I````)SPO
M)7,^)R!U;F5X<&5C=&5D("@G/"\E<SXG('=A;G1E9"D`-#H@)7,@=6YE>'!E
M8W1E9"`H:61E;G0@;W(@<W1R:6YG('=A;G1E9"D````Q.B`E<R!U;F5X<&5C
M=&5D("AI9&5N="!W86YT960I`#,Z("5S('5N97AP96-T960@*&ED96YT(&]R
M("<O)R!W86YT960I```;*@@(;R<("&\G"`AO)P@(;R<("&\G"`AO)P@(;R<(
M"&\G"`AO)P@(;R<("&\G"`AO)P@(;R<("!$J"`AO)P@(;R<("&\G"`AO)P@(
M;R<("&\G"`AO)P@(;R<("&\G"`AO)P@(;R<("&\G"`@'*@@(_2D("/,I"`CI
M*0@(;R<("&\G"`AO)P@(WRD("&\G"`C5*0@(;R<("&\G"`AO)P@(RRD("&\G
M"`AO)P@(;R<("&\G"`AO)P@(;R<("&\G"`AO)P@(;R<(",$I"`BW*0@(9B@(
M"'`H"`AP*`@(<"@("'`H"`AP*`@(<"@("'`H"`AP*`@(<"@("'`H"`AP*`@(
M<"@("'`H"`A<*`@(<"@("'`H"`AP*`@(<"@("'`H"`AP*`@(<"@("'`H"`AP
M*`@(<"@("'`H"`AP*`@(4B@("$@H"`@^*`@(-"@("'`H"`AP*`@(<"@(""TH
M"`AP*`@()B@("'`H"`AP*`@(<"@("!\H"`AP*`@(<"@("'`H"`AP*`@(<"@(
M"'`H"`AP*`@(<"@("'`H"`B])P@(KR<("!$H"`@8*`@(&"@("!@H"`@8*`@(
M&"@("!@H"`@8*`@(&"@("!@H"`@8*`@(&"@("!@H"`@8*`@("B@("!@H"`@8
M*`@(&"@("!@H"`@8*`@(&"@("!@H"`@8*`@(&"@("!@H"`@8*`@(&"@("`,H
M"`C\)P@(]2<(".XG"`@8*`@(&"@("!@H"`CG)P@(&"@(".`G"`@8*`@(&"@(
M"!@H"`C9)P@(&"@("!@H"`@8*`@(&"@("!@H"`@8*`@(&"@("!@H"`@8*`@(
MTB<(",0G"`A4*0@(7BD("%XI"`A>*0@(7BD("%XI"`A>*0@(7BD("%XI"`A>
M*0@(7BD("%XI"`A>*0@(7BD("$HI"`A>*0@(7BD("%XI"`A>*0@(7BD("%XI
M"`A>*0@(7BD("%XI"`A>*0@(7BD("%XI"`A`*0@(VR@("-0H"`C-*`@(7BD(
M"%XI"`A>*0@(QB@("%XI"`B_*`@(7BD("%XI"`A>*0@(N"@("%XI"`A>*0@(
M7BD("%XI"`A>*0@(7BD("%XI"`A>*0@(7BD("+$H"`B@*`@(,BD("#DI"`@Y
M*0@(.2D("#DI"`@Y*0@(.2D("#DI"`@Y*0@(.2D("#DI"`@Y*0@(.2D("#DI
M"`@K*0@(.2D("#DI"`@Y*0@(.2D("#DI"`@Y*0@(.2D("#DI"`@Y*0@(.2D(
M"#DI"`@Y*0@()"D("!TI"`@6*0@(#RD("#DI"`@Y*0@(.2D("`@I"`@Y*0@(
M`2D("#DI"`@Y*0@(.2D("/HH"`@Y*0@(.2D("#DI"`@Y*0@(.2D("#DI"`@Y
M*0@(.2D("#DI"`CS*`@(XB@("%1#4`!33T-+150`4$E010!-14U/4ED`,#`P
M,#``2%DP,#``;W!T:6]N<P!C;VUP<F5S<P!P87-S=V]R9`!P:7!E`'5S97(`
M:6YI="UC;VUM86YD`&1A=&%B87-E`&1E8G5G`')E='5R;BUF;W5N9"UR;W=S
M`'-S;"UK97D`<W-L+6-E<G0`<W-L+6-A`'-S;"UC87!A=&@`8VAA<F%C=&5R
M+7-E=',M9&ER`&1E9F%U;'0M8VAA<F%C=&5R+7-E=`!I;G1E<F%C=&EV92UT
M:6UE;W5T`&-O;FYE8W0M=&EM96]U=`!D:7-A8FQE+6QO8V%L+6EN9FEL90!R
M97!L:6-A=&EO;BUP<F]B90!E;F%B;&4M<F5A9',M9G)O;2UM87-T97(`<F5P
M;"UP87)S92UQ=65R>0!S<VPM8VEP:&5R`&UA>"UA;&QO=V5D+7!A8VME=`!S
M:&%R960M;65M;W)Y+6)A<V4M;F%M90!M=6QT:2UR97-U;'1S`&UU;'1I+7-T
M871E;65N=',`;75L=&DM<75E<FEE<P!S96-U<F4M875T:`!C;&EE;G0`9#IT
M.F\L+W1M<"]C;&EE;G0N=')A8V4`;7D`35E344Q?4%=$`````%5N:VYO=VX@
M;W!T:6]N('1O('!R;W1O8V]L.B`E<PH`<38("'\Y"`A7.0@(13D("!TY"`CP
M-@@(]S8("/4X"`BH.`@(@#@("%@X"`@].`@(+S@("'$V"`AQ-@@(<38("'$V
M"`@/.`@([S<("-XW"`CW-@@(*#<("!<W"`A;-P@(33<("-`W"`AQ-@@(M#<(
M"'HW"`AQ-@@(:3<("*DY"`BI.0@(FSD("()F"`AM9@@(7&8("`EF"`CF90@(
MPV4("*!E"`A[90@(3&4("&]E"`AD90@(U68(",9F"`A`90@(N68("+EF"`BY
M9@@(H&8(")%F"`@E<R4P,F0Z)3`R9#HE,#)D`"4P-&0M)3`R9"TE,#)D`"4P
M-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D````['@(".QX"`CX>`@(#'D(
M"+QX"`A40U`O25`@*"5D*0`Q,C<N,"XP+C$`+V5T8R\`+W5S<B]L;V-A;"]P
M<V$O;7ES<6PO=F%R`'XO`"TM9&5F875L=',M9FEL93T`+2UD969A=6QT<RUE
M>'1R82UF:6QE/0`M+6YO+61E9F%U;'1S`"TM<')I;G0M9&5F875L=',`)7,@
M`&EN8VQU9&5D:7(`:6YC;'5D90```'=A<FYI;F<Z(%=O<FQD+7=R:71A8FQE
M(&-O;F9I9R!F:6QE("5S(&ES(&EG;F]R960*``!E<G)O<CH@5W)O;F<@9W)O
M=7`@9&5F:6YI=&EO;B!I;B!C;VYF:6<@9FEL93H@)7,@870@;&EN92`E9`H`
M````97)R;W(Z($9O=6YD(&]P=&EO;B!W:71H;W5T('!R96-E9&EN9R!G<F]U
M<"!I;B!C;VYF:6<@9FEL93H@)7,@870@;&EN93H@)60*`&5R<F]R.B!7<F]N
M9R`A:6YC;'5D92!D:7)E8W1I=F4@:6X@8V]N9FEG(&9I;&4Z("5S(&%T(&QI
M;F4@)60*``!E<G)O<CH@5W)O;F<@(6EN8VQU9&5D:7(@9&ER96-T:79E(&EN
M(&-O;F9I9R!F:6QE.B`E<R!A="!L:6YE("5D"@```$-O=6QD(&YO="!O<&5N
M(')E<75I<F5D(&1E9F%U;'1S(&9I;&4Z("5S"@``1F%T86P@97)R;W(@:6X@
M9&5F875L=',@:&%N9&QI;F<N(%!R;V=R86T@86)O<G1E9`H``"5S('=O=6QD
M(&AA=F4@8F5E;B!S=&%R=&5D('=I=&@@=&AE(&9O;&QO=VEN9R!A<F=U;65N
M=',Z"@````I$969A=6QT(&]P=&EO;G,@87)E(')E860@9G)O;2!T:&4@9F]L
M;&]W:6YG(&9I;&5S(&EN('1H92!G:79E;B!O<F1E<CH``%1H92!F;VQL;W=I
M;F<@9W)O=7!S(&%R92!R96%D.@``"E1H92!F;VQL;W=I;F<@;W!T:6]N<R!M
M87D@8F4@9VEV96X@87,@=&AE(&9I<G-T(&%R9W5M96YT.@HM+7!R:6YT+61E
M9F%U;'1S"5!R:6YT('1H92!P<F]G<F%M(&%R9W5M96YT(&QI<W0@86YD(&5X
M:70*+2UN;RUD969A=6QT<PD)1&]N)W0@<F5A9"!D969A=6QT(&]P=&EO;G,@
M9G)O;2!A;GD@;W!T:6]N<R!F:6QE"BTM9&5F875L=',M9FEL93TC"4]N;'D@
M<F5A9"!D969A=6QT(&]P=&EO;G,@9G)O;2!T:&4@9VEV96X@9FEL92`C"BTM
M9&5F875L=',M97AT<F$M9FEL93TC(%)E860@=&AI<R!F:6QE(&%F=&5R('1H
M92!G;&]B86P@9FEL97,@87)E(')E860``````"!!6Z-GX%G#_#]]PY0EK4FR
M5/_______^]_`````````````````````*"Y"`@`````-,`E"*&Y"`A`N@@(
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````D!``"`,^$!@#/A`0```$``(````0```!1&&0@81AD(
M````````````````````````````````)``9"#@`&0@H`AD(;`(9")P"&0B\
M`AD(5@`9".@"&0@D`QD(<0`9"($`&0B;`!D(K@`9"$0#&0AT`QD(R``9"*P#
M&0CL`QD(*`09"&P$&0BD!!D(VP`9".L`&0@'`1D((@$9"#T!&0A9`1D(;@$9
M"-@$&0A_`1D(FP$9""P%&0BR`1D(9`49",$!&0B,!1D(V`49"-H!&0@,!AD(
M5`89")P&&0CD!AD(-`<9"'P'&0C,!QD($`@9"$@(&0CQ`1D("P(9"(P(&0CT
M"!D(+`D9"%P)&0CT^A@(````````````````````````````````````````
M````````````````````````[!X'".P>!PAXIP0(N`H9"+T*&0@"````````
M````````````_____P```````````````````````````````/@/````````
MQ0H9"/C_````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````2!D(0```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/\!
M``"T`0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````X`H9"`0+&0@T
M"QD(7`L9"(0+&0BL"QD(S`L9"/0+&0CT^A@()`P9",T/&0A@#!D(@`P9"*@,
M&0C0#!D(^`P9""0-&0A0#1D(ZP\9"'@-&0B@#1D(``X9""P.&0B(#AD(P`X9
M"/`.&0@H#QD(4`\9"'P/&0@`````````````````````````````````````
M`````"!;&0@``````````#`Q,C,T-38W.#EA8F-D969G:&EJ:VQM;F]P<7)S
M='5V=WAY>@`````````````````````````````````````P,3(S-#4V-S@Y
M04)#1$5&1TA)2DM,34Y/4%%24U155E=865H`````````````````````````
M````````````+P``````````````$0```)00&0B;$!D(]/H8"`````!`5AD(
M0%49"$!4&0@```````````````"`91D(`````````````````0````$````!
M``````#_`,!3&0B`;!D(``````````"8>P<(/'8'"%1V!PA<=@<(<'8'"$AV
M!PA`5@<(=%8'"#1H!PA4:`<(=&@'")AH!PB\:0<(;'$'"#QR!P@D=@<(0&H'
M",!K!P@8;0<(1&\'""1Q!PCD>0<(O'4'"```````````````````````````
M`````````````0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D
M)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!1
M4E-455976%E:6UQ=7E]@04)#1$5&1TA)2DM,34Y/4%%24U155E=865I[?'U^
M?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JK
MK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8
MV=K;W-W>W\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76]]C9VMO<W=[_``$"`P0%
M!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R
M,S0U-C<X.3H[/#T^/T!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>EM<75Y?
M8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#A(6&AXB)BHN,
MC8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BY
MNKN\O;Z_X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;7^/GZ^_S]_M_@X>+CY.7F
MY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`@("`@("`@("`H*"@H*"`@("`@
M("`@("`@("`@("`@($@0$!`0$!`0$!`0$!`0$!"$A(2$A(2$A(2$$!`0$!`0
M$(&!@8&!@0$!`0$!`0$!`0$!`0$!`0$!`0$!$!`0$!`0@H*"@H*"`@("`@("
M`@("`@("`@("`@("`@(0$!`0(```````````````````````````````````
M````````2!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`1`!`0$!`0$!`@("`@("`@("`@("`@("`@("`@("
M`@("$`("`@("`@("`````````````````````````````````````````!\`
M`````````````$$```"4$!D(IA`9"/3Z&`@`````0%89"$!5&0A`5!D(`%@9
M"```````````@&49"`````````````````(````!`````0``````]P#`4QD(
MP%<9"`````"T5@<(@%<'"(!8!PCD=`<(;','"+QH!PB0=@<(]%@'"```````
M`````````````````````````````````0(#!`4&!P@)"@L,#0X/$!$2$Q05
M%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"
M0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@04)#1$5&1TA)2DM,34Y/
M4%%24U155E=865I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<
MG9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK]!04%!Q$%<0T5%
M145)24E)1$Y/3T]/UM?85555W%G>WT%!04'$05Q#145%14E)24E$3D]/3T_6
M]]A5557<6=Y9````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$4``````````````````````$4`
M`````$4``%,`````10``````````````````````10``````10``````````
M``````````````````````````````````````$"`P0%!@<("0H+#`T.#Q`1
M$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^
M/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8$%"0T1%1D=(24I+
M3$U.3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8
MF9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_04%!04%!
M7$-%145%24E)241.3T]/3T_7V%555559WE-!04%!04%<0T5%145)24E)1$Y/
M3T]/3_?8555555G>60@``````````````"$```"4$!D(N!`9"/3Z&`@`````
M0%89"$!5&0A`5!D(@%L9"```````````@&49"`````````````````$````!
M`````0``````_P#`4QD(@&@9"``!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9
M&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&
M1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$149'2$E*2TQ-3D]045)3
M5%565UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@
MH:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^OT%!04%<6UQ#145%14E)
M24E$3D]/3T]=U]A555596=[?04%!05Q;7$-%145%24E)241.3T]/3UWWV%55
M55E9WO^`9!D(@&,9"(!B&0@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(!A
M&0B`8!D(````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````)D`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"6
MEP```)&2@@"3E(0`AH>5````A0```````````(D``````````(N;````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"(````````````````````
M````````F```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(R<````````````
M````BIH`````````````````````````````GP````".G@``````````````
M``````````"#````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````!`@,$!08'"`D*"PP-#@\0
M$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]
M/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ
M:VQM;F]P<7)S='5V=WAY>GM\?7Y_````````````````````````````````
M``````````"@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$
MQ<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q
M\O/T]?;W^/GZ^_S]_O\```$``@`#``0`!0`&``<`"``)``H`"P`,``T`#@`/
M`!``$0`2`!,`%``5`!8`%P`8`!D`&@`;`!P`'0`>`!\`(``A`"(`(P`D`"4`
M)@`G`"@`*0`J`"L`+``M`"X`+P`P`#$`,@`S`#0`-0`V`#<`.``Y`#H`.P`\
M`#T`/@`_`$``00!"`$,`1`!%`$8`1P!(`$D`2@!+`$P`30!.`$\`4`!1`%(`
M4P!4`%4`5@!7`%@`60!:`%L`7`!=`%X`7P!@`&$`8@!C`&0`90!F`&<`:`!I
M`&H`:P!L`&T`;@!O`'``<0!R`',`=`!U`'8`=P!X`'D`>@![`'P`?0!^`'\`
MK"```!H@D@$>("8@("`A(,8","!@`3D@4@$``'T!`````!@@&2`<(!T@(B`3
M(!0@W`(B(6$!.B!3`0``?@%X`:``H0"B`*,`I`"E`*8`IP"H`*D`J@"K`*P`
MK0"N`*\`L`"Q`+(`LP"T`+4`M@"W`+@`N0"Z`+L`O`"]`+X`OP#``,$`P@##
M`,0`Q0#&`,<`R`#)`,H`RP#,`,T`S@#/`-``T0#2`-,`U`#5`-8`UP#8`-D`
MV@#;`-P`W0#>`-\`X`#A`.(`XP#D`.4`Y@#G`.@`Z0#J`.L`[`#M`.X`[P#P
M`/$`\@#S`/0`]0#V`/<`^`#Y`/H`^P#\`/T`_@#_``$```!B$!D(`0```-$0
M&0@!````W1`9"`$```#J$!D(`0```/,0&0@(`````Q$9"`\````4$1D($```
M`#`1&0@#````2Q$9"`0```!A$1D($0```'D1&0@!````EA$9"`$```"M$1D(
M#@```,01&0@!````WQ$9"`H```#V$1D(`0```!$2&0@+````*!(9"`$```!#
M$AD(#````%P2&0@)````>1(9"`8```#8$AD(`@```)02&0@%````^!(9"`<`
M```<$QD(#0```#P3&0@2````7!,9"!,```"$$QD(%````*@3&0@5````S!,9
M"`````````````````````"P>0<(%&<'"(AG!PB49@<(Y'0'"&QS!PB\:`<(
MD'8'"-AI!P@`````````````````````````````````````J'<'"`````"8
M>P<(/'8'"%1V!PA<=@<(<'8'"$AV!P@D:0<(6&D'"#1H!PA4:`<(=&@'")AH
M!PB\:0<(;'$'"#QR!P@D=@<(0&H'",!K!P@8;0<(1&\'""1Q!PCD>0<(O'4'
M"``````````````````````````````````````_```````````````Q````
MQQ(9",<2&0CT^A@(`````&!K&0A@:AD(8&H9"```````````````````````
M```````````````!`````0````$``````/\`X&D9"*!I&0@`````$'H'"%QZ
M!PB4?0<(Y'0'"#1\!PB`>P<(5'X'".A[!P@`````````````````````````
M``````````````````````"8>P<(/'8'"%1V!PA<=@<(<'8'"$AV!PBD>P<(
MQ'L'"'![!PAP>P<(>'L'"'A[!PB\:0<(;'$'"#QR!P@D=@<(0&H'",!K!P@8
M;0<(1&\'""1Q!PCD>0<(O'4'"```````````````````````````````````
M`````0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ
M*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-45597
M6%E:6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'U^?X"!@H.$
MA8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["Q
MLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;W-W>
MW^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_`"`@("`@("`@("@H
M*"@H("`@("`@("`@("`@("`@("`@2!`0$!`0$!`0$!`0$!`0$(2$A(2$A(2$
MA(00$!`0$!`0@8&!@8&!`0$!`0$!`0$!`0$!`0$!`0$!`0$0$!`0$!""@H*"
M@H("`@("`@("`@("`@("`@("`@("`A`0$!`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'H'")AZ!PCD>@<(]'T'".1T!P@T?`<(@'L'"%1^!PCH>P<(````
M`````````````````````````````````%0``````````````!$```!(%!D(
M3109"/3Z&`@`````H&\9"*!N&0B@;1D(````````````````````````````
M``````````$````!`````@``````_P`@;1D(8(PE"`````#@B`<(&(D'"-RL
M"`@DK0@(*(L'"'!V!PA(=@<(G(H'""R)!P@XIP@(E*<("/"G"`A`J`@(O&D'
M"&QQ!P@\<@<()'8'"$!J!PC`:P<(&&T'"$1O!P@D<0<(Y'D'"+QU!P@`````
M``````````````````````````````````$"`P0%!@<("0H+#`T.#Q`1$A,4
M%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!
M0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8$%"0T1%1D=(24I+3$U.
M3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;
MG)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(
MR<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U
M]O?X^?K[_/W^_P`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B
M(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`86)C9&5F9VAI:FML;6YO
M<'%R<W1U=G=X>7I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\
M?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBI
MJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76
MU]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O\`("`@
M("`@("`@*"@H*"@@("`@("`@("`@("`@("`@("!($!`0$!`0$!`0$!`0$!`0
MA(2$A(2$A(2$A!`0$!`0$!"!@8&!@8$!`0$!`0$!`0$!`0$!`0$!`0$!`1`0
M$!`0$(*"@H*"@@("`@("`@("`@("`@("`@("`@("$!`0$"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````!``````````````!A````2!09"%84&0CT^A@(````
M`*!O&0B@;AD(H&T9"&!Q&0@````````````````````````````````!````
M`0````(``````/\`(&T9""!Q&0@`````,'\'"%2`!PC8@0<(U(<'"#2I"`B0
MJ`@(S*T("-AI!P@```````````````````````````````````````$"`P0%
M!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R
M,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EQ=6UY?
M14%"0T1%1D=(24I+3$U.3U!14E-455976%E:>WQ]67^`@8*#A(6&AXB)BHN,
MC8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BY
MNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7F
MY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_TJA5Z$``%FA6Z%?H6"A8Z%DH6>A
M:*%KH6RA;Z%PH7.A=*%WH7BA>Z%\H0``````````QJ''H<JARZ'(H<FA7*%-
MH0``3Z$``%&A4J%3H52A``!]H7ZAH:&BH:.AI*',H<VASJ'>H=^AX*'AH>*A
M`````$RB3:).H@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!)H0``K:%#
MHDBBKJ$``%VA7J&OH<^A0:'0H42A0:*OHK"BL:*RHK.BM**UHK:BMZ*XHD>A
M1J'5H=>AUJ%(H4FBSZ+0HM&BTJ+3HM2BU:+6HM>BV*+9HMJBVZ+<HMVBWJ+?
MHN"BX:+BHN.BY*+EHN:BYZ+HH@``0J(`````Q*$``.FBZJ+KHNRB[:+NHN^B
M\*+QHO*B\Z+THO6B]J+WHOBB^:+ZHONB_*+]HOZB0*-!HT*C0Z-AH56A8J$`
M``````````````!.H0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#.HDK)_-WXJ@````!$V'C<I>AV\P````#YJ@``K*U[L`````!%V```1MBL
MLP``?;9ZW'G<H[9\MGO<?K:BMJ&V>[8```````!HN0````#0X,[@``#/X,W@
M``#2NP``U;O7N]:[`````-.[U+L``*?HINA;OJCH``"IZ%R^````````3>Q+
M[//N``!)[$KL1L!&[$[L2.Q,[._N`````/'N``#R[O/![N[RP?#N[\'PP?'!
M1^P`````]<)N\6SQ;?'SPO;"],(```````!W\WCS]L,``$7U1_5&]<3$4,5M
M]FSV:_8`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#ZJ@``JLD``%C*Z:96REG*5\H`````
M``"NRP``P:@``,*HL,N_J*_+K<O`J+ZH````````````````V,W;S?VJVLW9
MS0``_*K[J@``0*O<S?ZJ`````````````,;0KJVOK;"MQ]##T*VMQ-```,70
MPM````````"DL`````"AL$74HK"EL$;4``!^L'RP?;"CL`````````````"M
MLTG8M;-(V```2]BQLTK8J[:OL[*SKK.SL[2SL+,```````!'V*>V?=P``*/<
M`````*+<K+:HMJFV?-Q^W*'<I+:FM@``JK:EM@````#3X-'@TN!JN6NY``#4
MX&FYV+L``-J[V;L``+OD`````+SDJ^@``*KH`````$?`2,!/[$G```#V[@``
M].X``/7N],$``&_Q]\,```````#UP4&K``"FL$?4`````$S8MK.MMJ3<IMRO
MMJZVL+:QMJ7<;KEON6VYV[MLN=7@````````W+NLZ%#L2L#VP7#Q=/'YPG'Q
M^L+XPG7Q^\)S\0``>?/WPOC#``#-^`````!"J[BSM[,``````````+*VJ-RG
MW+.V`````-G@<[EPN=C@<KG6X'&Y``#7X```O>3=NP``K^@``%V^K>A>OE^^
MKNA@O@``4>P``$[`2\!0P%/L3,!2[$_``````$W```#Y[OON`````/?!^N[X
MP?CN]^X``'?Q=O'\PGCQ?O/ZPWWS>O/YPWOS?/,``$CU2?7%Q```4\4`````
M;O8`````4<52Q6_V`````+3%M<5Q]P````!%QL_X1\8``,[XT/A&QE?Y``"M
M^0```````````````$.K````````=+D``+[D``"PZ%'`4L```$2K``!AOOO#
ML:T```````!3P```XL6RK4W8``"IW```J]P``*K<``#=X-K@=;D``':YV^#<
MX```P.3%Y-Z[O^3!Y,CDP^3'Y,3DPN3&Y-^[`````+/H``"QZ&.^``!BOK+H
M9+X``````````%;L`````%7L5,!4[/SN``#^[D'O0.\``/G!_>ZA\?W"??&B
M\?["``![\0``?O%\\7GQ0,-Z\0``````````H?,`````H_.B\P``2O4``$OU
M````````</8``+?%``"VQ4_X4/A(QM'X``!IQ@``LZVTMLKDR>2UZ+3H````
M`/K!0^]"[Z7QH_&F\:3Q`````/S#I/.E\Z;S``!Q]@``<O<``-+X````````
M``````````"TK0````!7[$3O``"UK0````#@NP``6.Q!PZ?Q_<,``$SU3?54
MQ5'XMJV[L[RS3MBUMK:VK-RWM@``>KD``'RYW^#@X-[@=[EXN7NY>;D`````
MR^3AN^*[`````+SH9[ZWZ+;H``"[Z&6^`````%O```"XZ+WHNNBYZ```9KX`
M`%G```!:[%7```!;[`````!9[```6,!6P%K```!7P`````````````!%[P``
M2N]&[TGO^\$``-3M2.]'[P``1,-"PT7#0\.H\:GQJO%&PP```````*KS0,2H
M\P``0<2G\ZGS_L-1]4[U``!/]5#U<O96Q0``5<4``'3W<_>XQ0```````./%
M2<9@QECYKOFO^0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````+>MK=P`````X>#,Y,WDX[L``.2[ONAH
MO@````#\P0``J_$``$?#K?-"Q*SSKO.K\W7V4O53]0``QL0``'3V`````'/V
M``!U][#Y`````````````````````````````````````+BM````````N:T`
M````I[!(U```3]@``+BV``"[MKFVKMP``+VV``"ZM@````"\M@``?KD``.+@
M`````./@P.@``'VYH;FBN0``S^0``,[DY;L``.:[``#0Y+_HZ+MIO@``Y[L`
M``````!<P,'H:[YJOL+HQ>C#Z,3H;+X``&'`7\``````7L!=[```8,``````
M7.Q+[P``7NQ=P%_L3N],[TWO4N]+PU'O5.]3[U#O3^\``/W!``````````"N
M\0``K?%*PTC#2<,``*SQ``"Q\P``0\0``+#SK_-$Q```6/57]0``5?4``%3U
MR,3'Q%GU=O>YQ7?V5\5V]E;U``!W]^3%``!AQEGY``"Q^0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````NJU0V%7ONZT`````TN31Y&#L`````%?O``!6[P``3,.R\[/SR<0`````
MLOFHL+^VOK;DX.;@I+GEX*.YI;GGX````````-3DUN35Y```V.0```````#I
MN]?DT^0```````#9Y```S.@``,_HT>C'Z,OHR.ANOG&^<[[)Z,KH<K[-Z-#H
MSNATO@``<+[&Z&V^``!OO@````!CP&;L9.QC[```:>P``&CL9^P``&+L8L!A
M[```9>QDP`````!:[P``7N];[UWO7.]9[U_O8N]@[V'O0,(``/[!6.]C[[/Q
MMO&X\;?Q``"Q\;7QL/$``++Q3<.O\0``M/$`````P/.U\T7$`````$;$M/.Y
M\[_SM_.^\P``N_,``+KSO?.X\[;S``"\\P``8/5>]<K$7?5C]6'U``#+Q%SU
M6O4``%OUS<1?]<S$8O5X]G[V`````'GV6\6A]EK%??9\]EG%>_98Q7KV``!]
M]Z'W?O<``'OWN\5X]WSWH_<``*+W>?=Z][K%4OCGQ0``4_CEQ>;%`````-/X
M2L9V^0``:L8``+/Y:\:T^;7YP_G"^7K&S?D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"IL`````#IX```Z.```.J[Z[O:Y```TNAL[`````!UOF7`
M:NP``&WL9L```&3O:^RY\4[#P?,```````!F]63U`````&7U`````*+V``!<
MQ:3WZL6\Q>C%Z<74^&+&``"JL````````+KQ`````$G4``"FN0``V^0`````
M[+O<Y````````-3HT^AHP':^=[X``-?HUNC5Z`````!N[''L``!P[&_L9\!H
M[V;O9>\`````9^\``$_#O/&]\5##``"[\0``P_/"\\7S1\3$\P``9_5I]6CU
M`````*/VIO:D]J7VI?>]Q0```````%3X5?A6^```2\9CQK;YJ[```'B^:<"^
M\0``IO<`````Q/E*U```>\:LL'+L``"_\0``QO,`````I_:G]ZVP``#=Y-[D
M``#MN^Z[V>AZOGF^V.@``&GO``#`\<+QP?%3PU+#4<,``%[%J/8``%W%J?>H
M]P``3,;5^+VSZN````````#AY-_DX.0`````XN@``-WHVNCAZ````````./H
M`````'R^X.C<Z`````#;Z-_HWNA[O@````!]['CL=NRA['?L``!S[```>>P`
M````=.QR[W7LHNP``````````````````'SL:L![['KL``!^[```````````
M:N]M[P````!L[P``=.]O[W/O``!Q[W#O;N\``&OO``!#PD+"``!$PD'"=>\`
M````````````R/'+\0``R?'-\0```````,[Q``#&\5C#Q_$``,7QS/$``,3Q
MP_%7PU7#5,,`````````````````````RO'/\]7S2L30\P``T_/7\TO$TO,`
M`,KS``#)\];SS?,``,OSU//,\TG$2,0``,?SR//1\P```````,[S````````
M````````;/5O]0``````````5L,``````````````````&WU<_5Q]6OU=O4`
M`&KU``#/Q'+U````````;O7.Q'7U`````'3U``````````"K]JKV````````
ML?8``*WVL/9@Q0````"N]J_V``"I]JSV7\4```````"_Q;3WK_>S]P``MO>R
M]P``KO<``,'%L?>U]\#%K/=P];#W`````*WW``"J]P``J_>^Q5KX7/A?^%OX
M8/@``%GX``!7^```Z\5=^.W%[,58^%[X``````````#:^$W&V_@``-GXUO@`
M````V/C7^%KY``````````!<^5OY`````'GY``!X^7?Y>OD``'/&=,;*^<[Y
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"^LZ_<[>```*>YZ^``
M````[.````````#BY./D\;OON^3D\+OHZ```Z^CEZ.SHY.CFZ```Y^CJZ```
M``"AON_H[NA]ONGH[>A^O@```````````````*SL``!OP```I^QKP```I.RJ
M[*WL``!PP```J>RF[*[LI>P``*OL;,```*/L;<```&[`J.P```````"I[WKO
M>^]^[WSO``!V[P````!Y[Z7O?>\`````1<(``*?OI.]&PJ;O=^^B[Z/O``"A
M[P``````````TO'4\=?Q`````-'Q``!9P]GQT/':\0``UO'8\=SQU?'=\=/Q
MS_%:PP``V_%;PTW$`````````````'CO\?/H\T_$Y/-0Q`````#M\^?SW?-.
MQ.KSY?/F\P``V//?\^[S``#K\P``X_,``._SWO/9\^SS``#;\^GSX//P\]SS
M3,3:\^'SXO,```````!]]0``>_4``*+U``"N]:7U?/5X]:?U?O6C]7KUJO5W
M]:'UIO6H]:OU>?4``*_UL/6I]:WUI/4``,'VQ/8``&'%``##]LCVQO9BQ;WV
ML_:R]F3%O_;`]KSVM/8``+GVK/4``+7V8\6[]@``NO8``+;VPO8``+?VN_?%
M]L?VOO:X]KSWOO>X]\+%``#%]\/WP\7"]\'WNO>W][WWQO>Y][_W``!I^&[X
M9/AG^.[%:_@``'+XP/<``&7X;_AS^&KX8_AM^```;/AQ^'#XQ/=H^&+X9OA.
MQD_&8?@``.;XW?CE^.+XX_C<^-_XY_CA^.#XWO@``.3X``!=^0``7OD``&#Y
M7_EB^6'Y?/E[^;?Y``"X^0``Q?EXQGS&``#/^7W&````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````+^S````````T,3)]@``4,91Q@``P+/N
MX```J+GPZ`````"P[+'LK^RK[ZKO1\+?\:SOWO$`````\_-1Q%/$\O,`````
M4L0``+'UL_6R]<KV9<4``._%Z/AC^0````#2^<&S``#EY```HKX```````"S
M[++L``"M[P```````%3$T<3']\OY````````PK/RNP``H[X``/3S``!T^,"V
M``````````"N[P```````&3&P;:DODC"=?C"M@``\>ARP+3LM>P``''```"O
M[TS"2L)+PDG"X/%<PP```````+7UM/6W];;UTL0`````R_8``,WVS/9FQ<CW
M``!V^'?X\,5D^7WY=<8``+#<MNRP[_7S[^```+'OXO'A\0``````````>/A2
MQ@``9?E^^0```````*FY\NCSZ```M^RJN0``7</C\0``S_9GQ=#VSO9Y^```
MZ?@``*NY``"T[[/OLN_D\0````#H\>?QYO'E\5[#]O.Y]=/$N/71]LOWRO?$
MQ<GW?/A[^'KX`````/.[``"X[$W"``#W\_CSS/=]^`````#J^&;YN?G4^?2[
M3L+I\?GSTO9^^`````"FO@``M>_J\?KS^_/\\[[U``"Z]6C%O?6\]=3$N_76
MQ```U<34]M/V:<5JQ0````#&Q<WWQ<4``*/XI/BB^*'X5,8``.OX[/CM^%/&
M9_EJ^6GY:/D`````T_D`````````````````````````````````````<\``
M````9<._]=7V``#'Q<[W`````-7Y````````=,````````"V[P``S_<``*'Y
M`````$"D0J0``$.D````````1<E6I%2D5Z15I$;)HZ1/R4W)HJ2AI`````!"
MI4&E0*4``$.E_J0``````````."EX:4```````````````##J```````````
M6*0``*2D4,D``*6D8\GJIK'+``````````!9I*:D``!$I63)````````````
M`$#)1*0``%ND``!'R5RD`````*>D``!%I4>E1J4`````XJ7CI0````#$J```
MO*U!I`````!!R46D7J1=I````````````````````````.2E````````````
M````````````Q:@``````````````````````````*ZP2]0`````P[:QW++<
M``!&I```J:0`````QJA'I$C)7Z0`````JJ2LI%')K:2KI````````.6E``#'
MJ`````#(J$6K``!@I*ZD``#FI>BEYZ4``.NF`````,FHRJA&JT>K````````
M``"]K0````"SW`````#6]DBD`````````````+"DKZ12R;&DMZ0``+*DLZ14
MR5/)M:2VI```M*0```````````````!*I4NE3*5-I4FE4*5JR0``9LEIR5&E
M8:4``&C)``!.I4^E2*4`````9<EGR0```````````````/6EL,GRI?:ENLFN
MR?.ELLD```````#TI0``]Z4``.FEL<GXI;7)``"YR;;)`````+/)ZJ7LI?FE
M``#NI:O)\:7OI?"EN\FXR:_)[:4`````K,GKI0```````+3)``````````"W
MR0```````````````````````*W)9LH``$*G]*8`````9\KQI@``1*<``/FF
M``#XIEO*_*;WIF#*:,H``&3*``#ZI@````#]INZF1Z==R@````"]R^RF0Z?M
MIO6F]J9BRE[*^Z;SIEK*[Z9ERD6G2*?RID"G1J?PIF/*0:=IRES*_J9?R@``
M``!AR@``V*B_R\O+T*@``,S+RZC5J`````#.J+G+UJBXR[S+P\O!R]ZHV:BS
MR[7+VZC/J+;+PLO)R]2HN\NTR].HM\O7J+K+``#2J```S:@``-RHQ,O=J,C+
M``#&R\K+VJB^R[++``#`R]&HQ<O,J,?+````````````````````````````
M````````````5JM*JP````#@S>C-``!)JU&K7:L``.[-[,WGS0```````$NK
M[<WCS5FK4*M8J][-``#JS0``X<U4J^+-``#=S5NK3JM7JTVK``#?S>3-``#K
MS56K4JOFS5JKZ<WES4^K7*M3JTRK2*L``````````````````````````._-
M``#7K<&M``#1K0``UJW0T,_0U-#5T,2M``#-K0```````-JM``#.K0``````
M````R=#'K<K0``#<K0``TZV^K;^MW="_L```S*W+K<O0SZU;U,:MUM#5K=2M
MRJW.T-?0``#(T,FMV-#2K<S0P*T``,.MPJW9T-"MQ:W9K=NMT]#8K0``V]#-
MT-S0``#1T```VM```-+0``````````#(K0```````&/45]0``+.P``!<U&+4
MLK!5U+:P6=12U+2P5M2YL+ZP``!GU```4=0``+JP``!FU`````"UL%C4L;!3
MU$_47=10U$[46M1@U&'4M[``````6]A>U$W47]0``,&P9-3`L$S4``!4U&74
MO+"[L+BPO;``````K[``````L+``````R+,``%[85]@``,6S``!?V```````
M`%786-C$LUG8`````,>S7=@``%/84MC)LP``RK/&L\NS4=A<V%K85-@`````
M``##LU;8`````````````````````,JVQ+:WW,VVO=S`W,:VQ[:ZW,6VP]S+
MML3<``"_W,RV``"TW,FVM=P``+[<O-P``+C<R+:VW,ZVN]S"W+G<P=P`````
MMKFSN0``M+D``/G@\>"RN:^Y\N``````L;GUX```]^``````_N``````_>#X
MX*ZY\."LN?/@M[GVX```^N"PN:VY_.#[X+6Y``#TX```^+OLY```Z>3YNP``
M][L``/#D[>3FY/:[``#ZN^?D];O]N^KDZ^3[N_R[\>3NY._D````````JK[X
MZ*>^]>BIOJN^``#VZ*B^``#WZ```].@`````=L"]['?`N^P``+SLNNRY[```
M``"^['7``````+CON>\``.CDM^]XP%_#Z_'L\0``U\38Q,'UP/5LQ6O%T/<`
M`$FD8:2YI```N*13I5*E_*7[I?VE^J4``$JG2:=+IP``````````X*@``-^H
MX:@``%ZK``!9HM[06J+"L%RB6Z)@V```7:*XN5ZB``!*I```NJ3^I>*H``!+
MI+VDNZ2\I`````!`I@```````$RGY*CCJ.6H````````W:T```````"LO@``
M`````````````$[)``!4I56E`````$&F``!JR@``8*M?J^#0W]##L```OJ15
MR0````````````#-RP``8:L``."M``#>K=^M``````````"MO@``5J4`````
M``!"IKS)``````````!-ITZG``!KR@````#.R^:HS\L`````````````XM#C
MT..M``#DT```X=#DK>*MX:WET```:-0```````!AV`````#%W$#A````````
M_KNNOOGH``!,I%JD`````````````````````````````````````,2PS;,`
M`+FY``!"R;^D``!9I5>E6*4`````YZ@`````3:1.I```8J0`````P*3!I,*D
MOLE:I0``:\D``$:F``"_R42F1::]R0````!'ID.F``````````!LRNRJ;<H`
M````;LH`````4*=/IP````!3IU&G4J<```````#MJ```[*C4R]'+TLL``-#+
M[JCJJ.FH``#KJ.BH`````````````.^H``!CJ_#-``#3RVBK``#QS62K9ZMF
MJV6K8JL```````#HT```YZWKT.6M````````Y]#HK>:MZ:WIT.K0``#FT.S0
M````````````````T;/%L&G4:]1JU&S4QK``````SK,``,^ST+,``-"VQ]P`
M`,;<R-S)W-&V``#/MD'A0N&[N;JY6N,`````0+Q!O$*\1+SRY//D0[P`````
M``"OO@``L+X`````[?'#]<+UT?<``$^D````````7*5;I0````!(I@````#`
MR0````!5IU:G5*=7IV_*<,H```````````````````````````````#QJ-7+
M``#PJ```\LULJ_/-:ZL```````!IJP``:JL```````#MT```````````Q[!N
MU```RK!MU.6QR;#(L```U+,``-.STK/2M@````#5MM:VU+8``-.V`````$/A
M``!$X0```````/7D1;STY```L;Z_['G```#N\57$``!CI,.D5LD``,2DQ:0`
M````````````7:5>I0``2:9QRM;+U\L``&VK[M#,L,NP8]ABV`````!0I,:D
M7Z4``,VP0\D``&S)8*4``,+)2Z9*IL')6*<```````````````#JK0````!O
MU```U[9%X;RY`````/KH`````/WS``#'I`````#8R_3-T+#.L,^P4:0``&2D
MS:+*I```R:3(I&.E8J4``&W)P\D```````#UJ/*H]*CSJ`````!NJP````#5
MLP``4J0``,ND``!EI62E``!RR@````#VJ`````````````!7R0``9Z5FI4RF
M3:9SREFG``!:IP``]ZCXJ/FH``!OJ_7-`````.NM`````$3)``#,I```````
M``````#$R0```````'3*=<H`````V<L``-K+``#WS?;-^<WXS7"K``!PU.VM
M[]#LK0``````````9-C6LP``9=@``````````$;AO;D``````````$:\``#O
M\0``````````6,D``&BE``````````````````#1L```````````4Z1EI,ZD
MS:0``,^D````````````````^Z@``/JH_*@```````!QJP```````.ZM``#[
MZ$_"9J1JI7FE=*4``&^E;J5UI7.E;*5ZI6VE::5XI7>E=J5KI0``<J4`````
M<:4`````>Z5PI0``````````4Z8``%FF5:8``%NFQ<E8IDZF4:94IE"F5Z9:
MID^F4J96IERF`````````````'[*>\H``&>G?,I;IUVG=:=PIP```````*7*
M?<I?IV&GI,IHIWC*=*=VIURG;:<``';*<Z<``&2G``!NIV^G=\ILIVJG``!K
MIW&GH<I>IP``<J>CRF:G8Z<``'K*8J>FRF6G``!IIP```````&"GHLH`````
M`````'G*`````````````````````````````.O+ZLM/J>W+[\ODR^?+[LM0
MJ0````#AR^7+`````.G+2<Y+J4W._:CFR_ZH3*E%J4&I``#BRT2I2:E2J>/+
MW,M#J=W+W\L``$:I``!(J=O+X,L`````4:E-J>C+4ZD``$JIWLM'J0````!"
MJ4"I``#LRP``3JD`````````````2,[[S4O.`````/W->*NHJW2KIZM]JZ2K
M<JO\S4/.HZM/SJ6K``!YJP````!%SD+.=ZL``/K-IJM*SGRK3,ZIJW.K?JM[
MJT#.H:M&SD?.>JNBJW:K``````````!UJ_[-````````````````1,X`````
M`````````````$[.``!$T?NM\=```/;0]*U`KO30[ZWYK?ZM^]```/JM_:T`
M````_M#UK?70````````0M%#T0``]ZU!T?.M0ZX``/C0``#QK0``1M'YT/W0
M]JU"KOK0_*U`T4?1H=0``$711*[PK?S0\]```/BM`````/+0`````/?0````
M`````````````````````````/#00:X`````=]0``.2PI]3BL-^P?-3;L*+4
MYK!VU'O4>M3RK>&PI=0``*C4<]0``.BS``"IU.>P``#9L-:P?M33L```IM0`
M`-JPJM0``'34I-3=L'74>-1]U`````#>L-RPZ+```````````..P``#7L-*Q
M``#8L'G4Y;#@L*/4U;````````#4L```````````````````````````<=1R
MU&K8````````U[/:LW78[K-XV-BS<=C>L^2SO;4`````XK-NV.^SV[/CLW;8
MU]Q[V&_8``!FV'/8;=CALWG8`````-VS\;/JLP``W[/<LP``Y[,``'K8;-AR
MV'38:-AWV-FS9]@``."S\+/LLVG8YK,`````[;/IL^6S``!PV```````````
M``#KLP```````-7<T=P``.#<RMS3W.6VYK;>MMS<Z+;/W,[<S-S>W-RVV-S-
MW-^VUMS:MM+<V=S;W`````#?W..VR]S=MM#<``#8M@``Y+;:W."VX;;GMMNV
M7Z+9MM3<`````````````.*V`````-W<````````S;G(N0``5>%1X0``2^'"
MN;ZY5.&_N4[A4.$``%/A``#$N0``R[G%N0````!)X<:YQ[E,X<RY``!*X4_A
MP[E(X<FYP;D```````#`N4WA4N$``,JY``````````````````!'X0``3;Q'
MY0``1.4``$>\4[Q4O```2KQ"Y4R\^>12O```1N5)O$CE2+P``$/E1>5+O$'E
M^N3WY`````!KV/WD``#VY/SD^^0``/CD``!/O```````````3KP```````!0
MO/[DLKY`Y0```````$7I``#]Z```OKY"Z;:^NKY!Z0``N;ZUOKB^L[Z]OD/I
M_NB\OOSHN[Y$Z4#I4;P``+^^1NFWOK2^``````````#&[,CL>\#)[,?LQ>S$
M['W`P^Q^P```````````P>S"['K`H<!\P`````#`[```4,(``+SONN^_[[WO
M``"[[[[O``````````````````!@P_+Q\_%6Q```]/'P\?7Q\?%1P@``````
M`/[S0?19Q$#T6,17Q```````````6L3%]<;U``#:Q-G$V\3$]0``V/;7]@``
M;<5OQ6[%V?;(Q:;X````````\<4``*7X[O@`````2<D`````?:5\I0``7Z9>
MIL?)7:;&R0````!YIZG*``"HR@````!WIWJG`````*?*``!XIP``````````
M`````/#+``#QRU2I``````````"JJP``2-%)T46N1JX`````K-3IL.NPJ]3J
ML'S8\K,``````````.FVZK;AW```S[D``,ZY``!)Y4CI1^D``&OY9Z19R0``
M;LEOR0``````````8J9FILG)``!DIF.FR,EEIF&F`````&"FRLD`````````
M``````"FIP````"CIP``?:>JR@```````*O*``"AIP``K<I[IZ[*K,I^IZ*G
MI:>DIWRGK\H`````````````````````````````````````6:G^RP``6ZD`
M`%JI``!`S%BI5ZGURP``],L``/++]\OVR_/+_,O]R_K+^,M6J0```````/O+
M7*E!S`````#YRP``JZM5J0``````````````````K*M4S@````!:S@``````
M`+*K6,Y>S@``5<Y9SEO.7<Y7S@``5LY1SE+.K:L``*^KKJM3SES.````````
M`````````````+&K````````````````4,Y3T0``4M%7T4[1``!1T5#1``!4
MT0``6-%'KDJN`````$_15=$```````!)KDK1``"PJ[K45M$``$W1``!(KDS1
M````````````````L=0`````[+#PL,'4K]2]U/&PO]0``,74``#)U`````#`
MU+34O-0``,K4R-2^U+G4LM2FV+#4];"WU/:P\K"MU,/4M=0`````L]3&U/.P
M``#,U.VP[["[U+;42Z[NL+C4Q]3+U,+4``#$U````````*[4``````````"A
MV```JMBIV/JSHM@``/NS^;,``*38]K.HV```H]BEV'W8]+,``++8L=BNV/.S
M][/XLTO1J]CUL_2PK=A^V+#8K]@``+/8``#OW```K-@`````````````````
M````I]CGW/2V][;RMN;<ZMSEW```[+;VMN+<\+;IW```[K;MMNS<[[;NW```
MZ]SKM@```````/6V\-SDW.W<`````./<`````/&V``#SM@``Z-P``/'<````
M`%WAT+ECX0````#5N5_A9N%7X=>YT;E<X56\6^%DX=*Y``#6N5KA8.%EX5;A
MU+E>X0````!BX6CA6.%AX0``T[EGX0```````%GA````````6;Q+Y5>\5KQ-
MY5+E``!.Y0``4>5<O```I;Y;O```2N50Y0``6KQ/Y0``3.4``%B\````````
M````````3>D``$_I2NG!ODSI``#`OD[I`````,.^4.G"ODGI2^D`````````
M`*7`S.P``*3`S>RCP,OLHL#*[```4\)2PO;Q^/$``/?Q8<-BPP````!CPT+T
M6\0`````T_?2]_+%``!HI-"D`````*>G``````````!?S@``````````_+/]
MLP``\MS8N6GA4^4```````!:R0````"PR@````````````!"S&#.6=%,K@``
M``#Y\0``W,1II'ZE<,D``&>F:*8``%VI````````][```-JY``#;N=FY``!J
MI```T:33I-*D6\G4I*&E<<D``**E`````````````&FF:J8```````#+R0``
MJ*<``+'*````````8:E#S```7ZE@J5ZI6M$```````"VJ[6KMZNTJP``8<YB
MJ;.K``!-KDZN``!/K@``S=0```````#^L[38^+```````````/BV``#=N=RY
M:N$``%V\Q+X``,#OVO;4]VNDHZ4``*2ET<ELIF^F``#/R<W);J;0R=+)S,EQ
MIG"F;:9KIL[)``````````"SIP````"PI[;*N<JXR@``JJ>RIP````"OI[7*
ML\JNIP```````*FGK*<``+3*N\JWRJVGL:>TI[+*NLJKIP````````````!G
MJ6^I``!/S$C,<*E3S$3,2\P`````9JE%S&2I3,Q0S&.I``!1S$K,``!-S```
M<JEIJ53,4LP``&ZI;*E)S&NI1\Q&S&JI:*EQJ6VI9:D``$[,``"YJP``P*MO
MSKBK9\YCS@``<\YBS@``NZMLSKZKP:L``+RK<,Z_JP``5JYVSF3.`````&;.
M;<YQSG7.<LYKSF[.`````&C.PZMJSFG.=,ZZJV7.PJL``+VK````````````
M`%RN8M$``%NN`````&#1``!0K@``5:X``%_17-%AT5&N6]$``%2N4JX``&/1
M4ZY7K@````!8K@``6JX```````!9K@```````%W17M$``````````&31``#4
MU/FPPMC3U.;4`````$"Q``#DU```_K#ZL.W4W=3@U```0['JU.+4^[!$L0``
MY]3EU`````#6U.O4W]3:U```T-3LU-S4S]0``$*QX=3NU-[4TM37U,[4``!!
ML0``V]38U/RPT=0``.G4_;```-G4U=0`````Z-0```````````````!`M+O8
M``"XV,G8O=C*V```0K0```````#&V,/8`````````````,38Q]C+V```X]3-
MV$?=``!#M,[8MMC`V```Q=@`````0;1$M,S8S]BZV+?8`````+G8`````+[8
MO-A%M```R-@`````O]@``,'8M=CZW/C<0K=`MT/=^=Q$W4#=]]Q&W?;<_=S^
MMOVV_+;[W$'=^;9!MP``]-P``/[<\]S\W/JV0MWUW/NV1=T`````````````
M`````&[AXKGAN>.Y>N%PX7;A:^%YX7CA?.%UX=ZY=.'DN0``;>'?N0``>^'@
MN6_A<N%WX7'A;.$``````````'/A5>5AO%CE5^5:Y5SE``!?O```5N4``%3E
M``!=Y5OE6>4``%_E``!>Y6.\7KP``&"\8KP`````8.57Z0````!6Z57I``!8
MZ5'I``!2Z5KI4^D``,6^7.D``%OI5.D``-'LJ,#/[-3LT^Q9Z0``I\```-+L
MSNS6[-7LIL```-#L``#&O@```````%3"````````P>_Z\?OQ_/%<Q`````!=
MQ```0_0``,CUQ_4`````V_;<]M7WI_@``&RD;:0``&ZDU:2EI=/)<J9SI@``
MMZ>XI[:GM:<``'.I`````%7,=:ETJ5;,````````Q*L``%VN9=$``/#4``!%
ML4>T[]1&M```Y;D``'WAQ[X``*G`U^P``%[$``!PQ0``<LD``*:E<\EVI@``
M=*9UIG>F``"ZI[FG``"\RKNG`````+W*5\P``%C,``!VJ7BI>JEWJ7NI>:D`
M````````````R*O%J\>KR:O&JV;1=\X```````!HT6?18ZX``%^N`````&"N
M8JYDKF&N``!FKF6N`````````````$JQ\M3QU$FQ``!(L4>Q2[%&L0````#5
MV-+82;31V-;8``!+M-382+1*M-/8``!(W0``2=U*W0``````````YKGNN7[A
MZ+GLN:'A[;GIN>JYY[GKN6:\T-AGO&6\``!DO%WIR+[8[-GL`````&3#7\0`
M`&^D``!XI@```````````````,JK``!IT6>N`````$ZQ3;%,L4RT3;37V.^Y
MR;YPI%S)UJ1TR0````#4R7FF````````?*D``````````$O=`````'&D``#7
MI-7)`````+[*``"_R@``O*<```````#8V$ZT``!,W0```````*K`<J2HI-BD
M=<FGI0``P*>_I[VGOJ<`````6<Q^J:&I6LQ]J0````#.JWC.S:O+J\RK:JYH
MK@````!KT6FN:M$``%ZN\]0`````4+%1L0````!/L0``\+FBX6B\:;P``&'E
MJ\#"[\/O``#=Q*CX2\G9I```<Z0``'?)=LD``````````'JFU\G8R=;)``#9
MR0``````````````````Q\H``,+*Q,K&RL/*Q*?`R@``P<K!I\*GQ<K(RL.G
MR<H``````````````````&C,``!BS%W,HZEES&/,7,QIS&S,9\Q@S*6I9LRF
MJ6',9,Q;S%_,:\RGJ0``J*D``%[,:LRBJ:2I````````````````````````
M``````````"KSJ3.JLZCSJ7.?<Y[S@``K,ZISGG.``#0JZ?.J,X``*;.?,YZ
MSL^KHLY^S@````"ASJW.`````````````````````&^N``!NK@``;-%KKF[1
M``!PKF_1`````'.N``!QKG#1KLYRT0``;:X``&RN``!MT7'1<JX`````````
M`%.Q4K$```````#UU/G4^]14L?[4``!8L4'5``!:L0``5K%>L0``6['WU%6Q
M``#VU/340]7XU```5[%"U5RQ_=3\U%VQ^M19L0``````````1-4``$#5Y]CN
MV./84;3?V._8V=CLV.K8Y-@``.W8YM@``-[8\-C<V.G8VM@``/'8``!2M```
MZ]A/W=W83[0``.'8``!0M.#8Y=@`````XM@```````#HV```````````4]T`
M``````!6W4[=``!0W0``5=U4W4.W``#;V%+=`````$2W``!-W5'=````````
M``"IX0``L.&GX0``KN&EX:WAL>&DX:CAH^$``/&Y``"FX?*YK.&KX:KA````
M`*_A``````````!EY6?E:[QHY0``8^4``&+E;.4``&KE:KQMY63E:>5KY6;E
M``````````!AZ6;I8.EEZ0``7NEHZ63I:>ECZ5_I9^D``&KI8ND``-KLK\``
M`*W```"LP*[``````,3O``!R\?WQ`````$3T1?0``&#$``#)]0``WL0``,KU
M``#>]G+%``!QQ=WVR<4``-;W``````````!TI'NFVLG*RK6H7[$`````=:2J
MI:FEJ*4`````Q:<`````=*X``%?==J1WI'BDVJ0`````T:L``*_.````````
M4[1YI%W)`````*NEK*5XR0``?*8```````#+R@``QJ<``,S*`````*ZI````
M`&[,K*FKJ6W,J:EOS*JIK:D``-*K``#4J[/.L,ZQSK+.M,[3JP````!TT7/1
M``!VK@``=:X`````````````8K%&U0``8;%CL6"Q``````````!5M$75``!6
MM//8``!7M/+85+0``````````%K=7-U%MUO=6=U8W0```````+3A][GUN0``
M]KFRX;/A``#SN7'E;^4``&V\<.5NO&R\]+D`````;>EKZ6SI;N7<[+#`V^S%
M[\;O;NG^\0``>J2MI7ZFV\E]I@``KZE&MP``VZ2NI=6K6+0``'G)``!ZR0``
MW,D`````R*?0RL[*R:?-RL_*T<H``,>G`````````````+.IM*FQJ0````"P
MJ;C.LJD```````#6JP``M\ZYSK;.NL[7JWFN==$``'?1=ZYXT7BN=M$``+7.
M1]5*U4O52-5GL6:Q9+%EL4G5``````````!HL0````!:M%NT``!<M%W=7]UA
MW4BW1[=9M&#=7MT``+CA`````+;AO.'XN;WANN'YN;?AM>&[X7"\<^6YX7*\
M=.5QO'2\=>5OO'.\``!SZ7'I<.ERZ6_I`````&;#``!&]$?T``#+]=_V5<8`
M````M:G*IP````#8JP```````'NDW*0``*^EW<D``,NGTLH``+O.V:L``/JY
M?*0```````"AI@````!)MWVDW:3>I```L:6PI0``WLFBI@``T\H``,RG````
M`'',<LQSS```MJFWJ7#,N*D```````#:J[S.``!ZT7JN``!YT0``:;%,U6JQ
M3=4```````!=M````````&+=`````+_AON$``/NY``!UO';ERKYTZ;'```!S
MQ=CW``````````!TS```O<YKL?382K<```````!5P@``````````SJ<``,VG
MVZL``'O1``!ML4.S;K%LL5ZT``#`X?RY=KP``$S)W\D``-7*SZ?4RM"G````
M`+RI=\QVS+NIN:FZJ77,`````-VKOL[@J]RKXJO>J]^KX:L```````!]KGRN
M>ZX```````!/U6^Q<K%PL0``3M5UL0``<;%0U72Q<[$```````#VV/78``!A
MM%^T8+3WV$NW9-U,MV/=`````'?E`````'B\P>%WO```_;D``-[L=>FRP-WL
M0/)(]$GT``#?I```LJ4```````![R0````#2I]2G``#BR=C*U\K6R@``X<G@
MR:2FTZ?1IZ.F````````O:EXS```OJG=R@``W\K>RGG,`````-K*``#8I]:G
M``#9RMO*X<H``-6G``#<RN7*P*D``.+*UZ<``.#*X\H``+^I``#!J>3*````
M`````````````````*_,HLQ^S*[,J<SGJ\*IJLRMS..KK,S#J<BIQJFCS```
M?,RES,VIL,SDJZ;,``#EJ\FIJ,P``,W.YJM[S,JIZ*O+J<>IS*FGS'K,J\S$
MJ0````!]S*3,H<S%J0``O\X``,#.````````````````RLZAT<O.[JO.SL3.
M[:O&S@``Q\X`````R<[IJP````"CK@````#%SL'.I*X`````S\Y^KGW1R,X`
M`'S1P\[,S@````#LJZ&N\JNBKM#.?M'KJZ:N\:OPJ^^KI:[1SJ>NZJL``,+.
M````````````````````````````````=K&DT:;1``"HT:BNKJY3U:S1H]%X
ML5'5``"MKJNNKM$``%+5``"ET0``K*ZIT:^NJ]$`````JJZJT:W1I]$``*FN
M>;$``*+1=[$``````````'JQ``````````````````!5U5[59+0``'RQH[%E
MM&#5JK'YV%;5HK&EL7ZQ5-5BU6752=D``&/5_=BAL:BQK+%=U?C88=5[L?K8
M9-7\V%G5``!BM```5]58U:>Q`````*:Q6]6KL5_5I+%<U0``J;%FM&.T^]@`
M`%K5``!]L0```````````````````````&NT;[1`V5&W;;1$V7&T9=U&V5.W
M:;1LM$?9``!(V4[9<[14MP``2ME/V4/97K<``%6W<K1!V5#9``!=MW"T3K=-
MV0``=+1%V?[8:K1"V0``2]D``$VW4K=GM$S9``!0MP```````&BT````````
M7+?#X7#=``!HW<+A``!LW6[=`````&O=``!;MP``:MU?MP```````-+A````
M`%JW0+IQW<3A`````%BW:=UMW?ZY3[=FW6?=0;I7MUFW5K=OW0````#(X<GA
MSN%]O-7A``!'N@``1KK0X0``?+S%X46Z``#4X4.Z1+H``-'AJN5ZO&ZT``#3
MX:.\R^$``'N\``"BO,;ARN''X<WA2+IYO$*Z``!ZY<_A``"AO```I+P``,SA
M``!^O'GE`````````````'[ESKYXY:/IJ>6HO```IKS,OJ;EHN6LO```>.D`
M``````"JO*'E``!VZ0``I>4``*CE?>4``*N\`````*6\=^G-OJ?EI[RIO*3E
MK;RCY7SE>^7+OJOE>NG@[-"^``"BZ0``?ND``.'L``#1OJ'I``!\Z;3`W^P`
M`'GI>^FUP-.^L\#2OK?`?>G/O@````````````````````#/[P``Q^\`````
M````````Y^S([^/L`````%;"Y>SD[+;`XNSF[-#OS._.[P``R>_*[P``S>_+
M[V?#`````&K#:<-HPV'$2O1BQ$'RW\3,]>#$=,7*Q=GW``#:]]OW`````+KY
MX*1\R;.E``"FIJ>FI:8``*BFVJ?9IP``L<S/J<ZI`````*_1K;&NL0``````
M`'6T<MU@MV&W=-UVW77=``#7X0``UN%)NMCA``"LY:Z\``#4O@``N,!7PKG`
M``#AI````````.;*`````++,T:G0J=*I\ZO2SM/.`````+#1L*ZOL7:T4=GB
MI```?J3CI```?<FWI;:EM*6UI0```````*NFZ<GKR:JFX\D``.3)``#JR>;)
MZ,FIIN7)[,GGR0```````````````.&GZJ?HI_#*[<KURN:G]LH``-^G\\H`
M`.6G[\KNRN.G],KDI].IWJ?QR@``Y\K;IP``[J?LRO+*X*?BIP``Z,H``.G*
MZLH``.VGYZ?LI^O*ZZ?=I]RGZ:<`````````````````````````````````
M``````#AJ;[,M\S<J>^IL\RZS+S,O\SJJ0``N\RTS.BIN,P``,#,V:D``+W,
MXZGBJ;;,UZD`````V*D``-:I``#NJ>:IX*G4J;G,WZG5J>>I\*G4SN2IM<S:
MJ=VIWJD``.RI[:GKJ>6IZ:G;J?2K````````````````````````````````
M`````-K.0:SXJ_JK0*SFSOVKL=&QKD.LU\[?SOZKWL[;SN/.Y<[WJ_NK0JRS
MKN#.^:M%K-G.````````_*NRKO:K``#6SMW.U<[8SMS.LM%$K```X<[BSN3.
M]:L`````````````````````````````````````````````P:Z^T;^NP*ZT
MT<31``"VK@````!FU<;1P-$``+?1``#)T;K1O*Y]U;W1OJZUK@``R]&_T;BN
MN-&UT;;1N:[%T<S1NZZ\T;O1PZ["KK2NNJZ]KLC1`````,+1MZZST<K1P='#
MT<?1``````````````````````````!GU0``M['+L<JQ``"_L0``>=5UU7+5
MIM6ZL;*Q`````'?5J+2VL:'5``#,L<FQ>]5JU0````#(L:/5:=6]L<&QHM4`
M`'/5PK&\L6C5``!XM*75<=7'L735I-7&L0``4MD``+.Q;]6XL<.Q``"^L7C5
M;M5LU7[5L+'$L;2Q=[1\U;6Q``"QL<"QN[&YL7#5Q;%MU7K5=M54V5/9````
M`````````````````````````&O59-D``'JT``!JV5G99]EWW7VT:]ENV7RT
M7-EMV6S9?K15V7FTH[0``*&T:=D``%_9I;1PV6C9<=FMM*NT9MEEV0``8]E=
MV:2T``"BM+G15MD``+?=5]E[M*JT>=T``*:TI[18V6_9>-U@V5O9J;1AV5[9
M`````*ZT````````````````````````````````<+<`````?-VQW;;=JMUL
MM[O=:;=ZW0``>]UBMVNWI-UNMV^WI=T``++=N-UJMP``9+>CW7W=NMVHW:G=
M?MVTW:O=M=VMW0``9;?9X6BW9K>YW;#=K-T`````H=U3NJ_=;;>GW0``IMT`
M``````!GMV.W[N&SW:[=``"BW0``````````````````Z>$``-KAY>$``.SA
M4;JLM.KA3+H```````!+NO'A``#;X>CAW.'GX4^ZZ^%BV0```````/+AX^%2
MNKKEK[P``/#A[^%4NJWEL+RNY0``W^'@X=WAXN'>X?/A3KJQO%"Z5;H``.'A
M``#MX0````#FX0````"QY0``2KJTO*KIMN6UY;?E`````+3EM;P``+N\N+P`
M`+F\K^6RY;SEP;R_O```L^5:V;*\N>6PY0``PKRXY4VZM[SDX0````"ZO```
MOKS`O+V\O+P``+:\N^6SO,.\``````````````````#8OMF^J>GBOM^^``#6
MOMV^J^G;OM6^``#<O@``J.F[P->^``#>OKK`I^FFZ0``X+X``.&^``"EZ:3I
MO,"NZ=J^K.D``````````+W```#"P.KL[.P``+_```#M[.GL``#K[,#`P\``
M`.CLOL#!P%G"K>E8P@````!>PM3O``!<PEW"U^_3[UK"T>]KP]7O``#6[]+O
M``!;PD+R``!%\@````!&\D3R1_)LPT/R`````$[T9,1-]$ST2_1CQ&7$``#-
M]>+$X<0`````X?;@]N/VR\5UQ=WWXO8`````W/?-Q<S%\\6I^._XY*0`````
M<MFOZ0````"LIO?*\:?OIP``\*<``,',\:E&K```Y\X``.C.``!'K,[1``#$
MKL6NS=$``````````-.Q``#/L0``I]76L=6QSK'1L=2QT+$`````=MG-L:^T
M````````L;2RM'79>-FPM'/9=]D``'39``!QMP````"\W0````!6NO3AX[[$
MO+WEQ;S&O+_EON7`Y;'I`````+#I[^SN[,3`Q<!(\@````#EI```````````
M>=D```````"TM+.TO=T``-COX\3>]^:D``#&K@``V+'7L7K9>]ERM_7A5[JR
MZ0``YZ2XI0``\JG"S```Z<Y(K-FQ``!\V;6T<[<``,'EPN4`````\.Q?PO#X
MZ*0``,/,\ZE)K```ZLX``,>NTM'0T='1R*[/T0``````````V['<L:C5W;':
ML7W9``!^V;[=`````%FZ6+H`````\>S9[P``2O))\D_T``!>R4JL`````.FD
MN:4``*ZFK:8`````KZ:PIN[)[<GXRO*G^\KZROG*_,H``````````/2IR<S%
MS,[,`````/NI``#YJ<K,QLS-S/BI0*K(S,3,_JG+S/>IS,SZJ?RIT,S/S,?,
M]JGUJ?VI````````````````[\[US@``4*Q-K.S.\<X``%.L2ZSPSDZL4:P`
M````\\X``$RL^,Y/K```4JSMSO+.]L[NSNO.`````/?.],X`````````````
M``#0KLFNS*X``,^N``#5T0``RJ[3T0``SJX`````RZX``-;1S:X`````````
M``````"LU=^QJ]6MU=ZQX['4T0``JM6NU0``X+&IU>*Q``#AL0``I]D``*+9
M``"VM+JTM[2EV:C9``"XM```N;2^M,?=IMF\M*/9H=D``+VT``"DV0``````
M`'FW``"_W7:W=[=UM\3=P]W`W7NW`````,+=N[0`````QMW!W7BW=+=ZM\7=
M````````7+H``/CA]^'VX5JZ`````````````%NZQ>7(Y<B\`````,>\R>7$
MY<J\QN4``,F\P^4``,?EZ;[FOKOINND``+GIM.D``+7I````````Y[X``.2^
MZ+ZSZ>6^MNFWZ;SI`````+CI`````/+L````````Q\```-SOQL#:[]OO8,)N
MPTOR``!MPP````!1]%+T``!FQ```4/3DQ```W_?.Q:KXJ_@``.JD``"QIK*F
M\Z<``-',5*S1KN2Q`````-*P``"_M,"TS+.IV0``?+?ZX?GA`````.NDLZ;2
MS$*J``!!J@``^<[ZS@``U]'8T=*NTZX``-2NK]4`````YK$``,*T``#!M,C=
M>M_[X;WI`````&'"9\3LI```O*6]I;NEOJ6ZI0````"VI@``]LFUIK>F````
M`/')\,GSR?+)]<FTIN_)],D`````````````_<K]I_[*0\O\IP``1\M"RT7+
M]:?VI_>G^*<``$"H``!!R_JG0:@``$#+1LL``/FG1,O[I_2G_J<`````````
M``````````````!7J@``U,Q#J@``3:I.JD:J6*I(JMS,4ZK7S$FJYLSGS-_,
MV,Q6JN3,4:I/J@``Y<P``./,V\S3S-K,2JH``%"J``!$JM[,W<S5S```4JKA
MS-;,5:KHS$6J``!,JMG,XLQ4J@``1ZI+J@``X,P`````````````````````
M````````````````6\]<K&FL``!6STS/8JQ*SUNL1<]EK%+/_LY!SP``````
M````1,_[SE'/8<]@K$;/6,\``/W.7\]@SV//6L]+SU//9JQ9K&&L;:Q6K%BL
M````````0\]JK&.L7<]`SVRL9ZQ)SP````!KK%#/2,]DK%S/5,\``%ZL8L]'
MSUJL6<]/SU^L5<]7K/S.:*SCKEVL3L]-ST+/``!>SP``5\\`````5:P`````
M``````````````````````````````````````````#LT>JN[=$``.'1WZ[K
MK@``VM$``./1Z]$``-G1]-'5K@```````//1[M$``._1W:[HKN71``#FT?#1
MY]$``.+1W-'=T>K1Y-$`````UJ[:KO+1WM'FKN*N`````.6N[*[;KN>NZ='I
MKMBN``#7KMO1``#?T>"N\='HT>#1Y*[AK@``V:[<K@``````````````````
M````````````````````````````````````````Q-4``+35M=6YU0``R-7%
MU0``OM6]U>VQP=70U;#5``#1U</5U=7)U>RQQ]7GL?RQ\K$``/:Q];&QU0``
MSM74U<S5T]4`````P-6RU=+5PM7JL?>Q``#+U?"Q````````RM6SU?BQ``#Z
ML<W5^['IL;K5S]4`````[['YL;S5QM6WU;O5]+&VU>BQ\;'NL;_5WJ[`V>NQ
M`````````````````````````````````````/.Q``##V=G9SMG6M```T;2]
MV=*TS=D``,;9T]G.M*O9U=G$M+/9Q[3&M```U[0``*W9S]G0V<FTQ;2[V0``
MT+2VV0``T=G,M,G9UMFPV;79K]D``,NTPMG>W;'9S[2ZV=+9RK2WV;39Q=G-
MM,.TV;3(V<?9````````````````K-G(M-39O-F^V0``R]G*V:K9T[35M++9
MN=G!V=2TN-G$V=?9``#,V0``````````````````````````````````V-D`
M`````````*[9``````````#RW::W``#PW=O=X-W9W0``[-W+W=+=``#JW?3=
MW-T``,_=XMWGW=/=``#DW=#=`````-?=V-VHM^O=Z=T``,S=[MT``._=\=VL
MMZ2W``"XU=3=YMW5W:&WL;?MW:^WJ[?*W:.W``#-W;"W``#=W<G=``"IM^'=
MT=VJM]K=?K?8M./=O]G.W0````#HW:6WY=VBM]_=K;?6W?/=````````````
M````I[?&W@````"NMP```````````````$KB2.(``%[B1N(``%CB?;=?ND+B
M7>(``$?B5>)DNEVZ``!;X@``0.):X@``;[I1XF'B;;I)XEZZ2^)9XF>Z1.)K
MNF&Z3>)#XOSA``!7XFBZ8.+]X66Z``!3X@``9KI%XE#B3.).X@``8+I?XFZZ
M3^(``&+B`````/[A5.)CNFRZ:KI!XE;B:;H`````8KI2X@``````````7.(`
M````````````````````U>4``-'ES>7AY=[ES;P`````Y>74Y=B\V^4`````
MT.7:Y=6\[N4``.OEW>7.Y0````#BY>3ET;S8Y=/ERN7.O-:\``#GY=>\R^7M
MY>#EYN74O`````#CY0``ZN4``-F\``#3O-SES^7OY<SEZ.70O```UN4``-?E
MS[S,O-+ETKP``,N\``#IY>SEV>7*Z0```````````````````````,+I``"^
MZ?:^`````.N^\+[LOLSIU^GJOL3IS>G?Y<[I`````/&^``#=Z?6^^+[`Z0``
M]+X``-OIW.G2Z='IR>D`````T^G:Z=GI``#OONV^R^G(Z0``Q>G8Z?>^UNGS
MOO*^``#0Z0``O^G!Z</IU>G/Z>Z^``#&Z0``U.D```````````````#'Z0``
M````````````````S\!%[<C`]>P``$'MRL!([0``_.P``/?L`````$GM\^S^
M[```T<!$[4KM_>S)P$#M].S0P`````!'[?GLS,```/OL^.S2P/KLR\#.P$/M
M]NQ&[0``0NT```````!CPN?O:,)IP@```````&+"YN\``./OY.]FPM[OXN]E
MP@``W^\``````````&?"9,(``-WOX>_E[P```````%'R3O)7\@``5O)4\D_R
M``!RPP````````````!0\G'#S<!3\G##6/)2\DWRX.\```````!OPP``3/)6
M]```5?15\FC$``!9]%KT5/18]```4_0``````````-'U5_3GQ.7$S_4`````
M``#2]0``SO70]>;$````````Y?;F]G;%Y/8```````#B]\_%X/?A]ZSX````
M`%;&\_CQ^/+X]/@```````"[^0``[:2XI@``6:H``.G,`````&3/````````
M]='WT0``]M$``/C1_;'7U?G1``#6U=C5V=7:V=NTV]G=V=RTVK3<V0``^MWX
MW??=``#VW?7=LK?YW7"Z8^)EXG&Z9.+;O```VKSPY0````#?Z=[IX.D`````
M^;X``$OMT\```.CO:L)9\G?%[J2_I;FF0JA:JENJ`````&ZL`````/K1````
M``````"SMP```````-'F^KYKPN^D``"ZI@````#KS%RJZLP``&7/;ZQFSP``
M<*P``/S1[J[MK@``WM7<U=W5V]4``-K5`````-[9X=G>M-_9W;3@V0``^]T`
M````9N)GXFCB``#SY?+EW+SQY?3EX>D`````XNGCZ0``3.W4P&S"6O(``.C$
M7\D``'&L9\_OK@````#^L0``W[3BV0``M;>TMP````!IXFKBW;S>O.7IY.GI
M[^/W\*1@R<"E``!#J$C+``!RK+:W\:0``&C/<ZQISP``U<#RI`````#LS```
M:L\``$+20=+^T0``_=%#TD#2`````$"R0;(`````X+3CV0``Y-GEV0``````
M`$'>0MY`W@``_=W^W;>W:^+WY?;E]>7XY>?IYNG[ONCI``#6P$WM``#J[UOR
MY_8``/.DPJ7!I0``7:IAR7[)NZ8``/?)2<M*RUZJ``#MS```=*QKSVS/``#P
MKO2N1-+SKO&N\JX``-_50K+CM```X;3BM.;9`````'*Z]*0``*')``##I0``
M``"DR0````#&I:/)Q:7$I42HHLD`````^,D```````#\R?[)0,K%IL:F^\G!
MI@``^<D``/W)PJ8``+VF``"^I@``Q*;ZR;RF1:B_IL"FPZ8```````!;RUG+
M3,M1J%/+3*A-RP``5<L``%++3ZA1RU:H6LM8J```6J@``$O+``!-J%S+``!4
MJ%>H``!%S4>H7JA5J$[+2JA9J%;+2*A)J$/-3\M0J%NH7<M0RTZH``!3J.[,
M7*A7RU*H``!=J$:H5,M+J%C+1,T`````````````````````````````````
M`&JJ>JKUS'&J``!+S6*J``!EJD+-``#SS/?,;:IOJOK,=JIHJF:J9ZIUJD?-
M<*KYS/O,;JISJOS,2LT``'6L>:H``&.J2<T``$W-^,Q/S4#-;*KTS&NJ?:IR
MJ@``\LQUSWBJ?*I!S4;-``!^JG>J::I?J@``9*H``/;,8*I.S0``\,SOS/W,
M\<Q[JO6N=*K^S&&J``"FK````````$S-````````````````?,^ASP``I,]W
MSP````"GSZK/K,]TSW:L>ZQ)TJVLI<^MSWO/<\\```````!DTGZLHL]XSWK/
MI:P``'W/?:QPSZC/``"KSP````!ZK```J*QMSZJL>*RNK*G/;\^KK%[22,U\
MK'>L=L]NSZRLI*RCSZFLIZQYSZ&L<<^BK*.L<L^FSWFL?L\`````````````
M``````````````````````````````````````````!,TOVN0Z\```````!5
MTEO25])*TDW21M)'TDJO^JY6TE_21:_VK@``0*].TD*O3])9T@```````$2O
M:-)(TORN^ZY(KT729M):TF?28=)3TF+2``!<TF728]))KU32^:[XKD&O1Z]@
MTD:O4=)#L@``:=)0TDO2_JY+K_>N``!8TEW2````````````````````````
M`````````````````````&6RX=7EU0``4K)0L@````!'LN/5XM5;L@``Z-55
ML@``^M5'UD2R]]7PU6>RX-4``/S5``!DLEBR8[).LNS5_M7VU4^R2;)%U@``
M_=5`UE&R6;)"UNK5^]7OU4367K)&LERR]-7RU?/54[+NU>W52++GU4;62K+Q
MU6BR``!BLN;57[)=LF:R^-5ALE+2^=5@LD'61;+UU5>RZ=56L@``5+),LDNR
MY]E#U@````#KU0````#\V0``3;(`````````````````````````````````
M`````````````````$&U6K+NM/;9_+0``.K9Z[3GM$G:[;3QM.RT];1-VD3:
M`````/'9^K3TM/W9Y+1*VD/:Z+3WV?>T5=I6V@``Y;1(VOFT^]GMV>[9_;3R
MV?G9\]D``/NT1+7OV>C9Z=D``.O9ZK3XV0``^+1"M0````#ZV5/:2]KFM%':
M\K0``/"T``!7VN^T0=KTV?[91[5%VD+:\-E#M4_:3-I4VNFT0-I&M0``1]H`
M````\[3VM```1MI%M?79Y-4`````4-I.VE+:````````````````````````
M`````````````.S90+4```````!AWF#>1MZ]MP``7]Y)WDK>``#'MVC>PK=>
MW@``0][(M[ZW4MY(WDO>8]ZXMVK>8M[!MU?>S+<`````R[?%MP````!IWKFW
M5=Y,WEG>9=[-MP``N[=4W@``3=[$MP``P[=0WEK>9-Y'WE'>O+=;WLFWP+=.
MWK^W1=Y3WF?>_K2PNE;>;.)8WF;>QK=/WKJWRK?PO$3>``!=W@```````%S>
M`````````````````````````````````````*KBK;I]XJ3BHKH``&[BK[H`
M`'>Z;>*PXK&Z<>*CX@``<^*SXJ_B=;JANE/FKKI]NF_B``"NXJ.ZJ^*XXG7B
M?N(`````MN*LXGRZ`````'SB=KITNJBZ`````'KB=^)XX@``LN(``+?BM>)Z
MNKGB?KJGN@``<.+ZY7GB``!XNJRZJ;I[NJ7B=.*JNJ?BI+JFNG.Z``"IXJ'B
M<N*ENK'BM.)[XJCB``!YNM^\IN+YY0``K>(`````````````````````````
M`';B1.9.YN*\3>99YN2\2^8``$_F[[P``$;FY[P``%+F\.GSO/*\5.9#YE[F
M[;P``..\5^8``%OF8.95YDGFYKSIO/&\[+P``$SFHN(`````2.9?YNB\``#K
MO&'FX+Q6YOOE7.;?P```2N8``.&\1>;EO/SEJ[I!Y@``6N9"YD#FZKP``%CF
M``#^Y5'F4.9=YD?F[KP```````````````#SZ0``2;_^OD#JZ^E!O_?I2+]#
MO_7I3^W[Z4+J^NGIZ?CI1.I&ZOV^1>I$OTJ_``!'OP``_NE&O_GI``#MZ?+I
M``#]Z46_0K_\OD"_\>D``/WE[.GOZ4'J].GJZ4[M0^KNZ?SI``````````!1
M[>/``````-?``````-O`4^U9[5?MV<#:P.'`6NU2[=S```!6[57M6^WBP```
MW<#@P%3MY,#>P.7`V,!8[0``4.T`````]^\`````<<+T[_;O``!OPO+O\^_N
M[P````#VZ>_O<,+K[P``;<+X[V["[._M[_'O<\(``'+"`````/#O>,-?\F7R
M><-<\G;#<\-G\G?#``!TPU[R8?)B\F/R9O(``/7O7?)UPV3R:/)@\@``````
M`%WT:L1@]&O$:/1?]%ST``!>]&+T9?1D]&?T6_0``&G$8_1F]&GT8?33]=3U
MV/79]0``UO77]=7U``#IQ```````````>,7K]@````#H]NGVZO9YQ0``Y??D
M]P``K_CTQ:WXL/BN^/7X5\9EQJ/Y;/D``*+YT/G1^?6D``````````#'ID'*
M`````%[+``!?J```8J@``%_+``!@J&&H``````````!8S5K-5<U2S53-````
M````I*H```````"BJ@````!6S:.J4\U0S:&J5\T``%'-I:I9S0``````````
MK\\``+//`````+>L``````````"VSP``KZRRK+2LMJRSK++/L<\``+&LM,^U
MSP``KL^UK```L*P```````"PSP```````````````'?2>-)YTE"O``!,KV[2
M``!VTGO24:\``&S2<M)KTG72`````''23:]/KWK2``!JTFW2<](``'32?-)P
MT@``3J\``````````````````````````&VR3M8`````4-9,U@``6-9*UE?6
M:;)(UEO:4M9LL@``4]96U@``6M8``$_6``!4U@````!JLFNR6=9-UDG66]8`
M`%'6`````%76````````2]8``$BU2;5EVD^U``!9VF+:6-I,M6#:7MH``%_:
M2K4``&/:`````````````%S:6MI+M5W:8=H```````!-M0```````&3:````
M````````````<-YWWGG>H=X``-JW:]X``-*W``!ZWM>WHM[.MP``?=X``&W>
M?MYLW@``W+<``'C>S[>CW@``U+=QWMFW?-YOWG;><MYNWM&WV+?6M].WV[?0
MMW7>``#5MP``3K4``'O>``!SW@````````````!TW@````#!X@``M+H`````
MO>+#XK_B``"VNK[BPN*ZX@``O.*UN@``````````P.*[X@``M[H``+*Z````
M`,3B``"SNF?F9.9PYFKF;.;TO&;F;N8`````;>9KY@``<>;WO&CF;^8``/6\
M`````&/F9>;VO&+F<N8``&GF`````$KJ4;\`````5>I3ZDN_2>I,ZDWJ2.I5
MOU:_1^I6ZE'J3[],OU#J3NH`````4K]2ZDV_``!.OP``3^I0OTOJ``!4ZE._
M5^I8ZE2_`````.?`[L!<[6+M``!@[>K`Z<#FP%[M````````[,#KP.C```!A
M[5WM7^T``.W`````````=\+[[P``=,)UPOWO=L+Z[P``^>]L\OSO``!M\GK#
M:_(`````:O(``&GR>\,`````;,0`````:O1K]```````````W/7;]>K$``#:
M]>SV[?8`````YO>Q^`````#V^+SY><;&^?:D``"FJJ>J`````+BL````````
M``#OP/>D``"HJE*OW;?XI```;K*XNF+)``"WSWW2``#%X@``\,#YI*FJN,^Y
MSV;:4+4`````I-X`````WK?&X@````#XO```?,/ZI&?:^Z0``,FF0LK(IF6H
M9*ACJ&#+````````JJH``*NJ6\T``+K/``"]S[JLN\\``+FLO,^[K```HM*A
MTG[24Z\``%W67M9OLES67]92M7"R`````%&U:]IJV@``:-IIV@``;-JFWJ7>
MJ=X``*C>I]ZYNLGB``#(XKJZQ^)SY@``=.;YO```6>I:Z@````!R\GW#<?)P
M\F[R;_+KQ&ST[O;W^```_*0``*7)QZ6FR0```````$/*1,H``````````&;+
M`````&++``!ARZRJ9<MGJ&/+9JAGRV3+`````%_-OL]=S63-``"MJ@``L*IE
MS6'-``!BS0``7,VOJE[-KJICS0``8,T`````PL^]K+ZL``#%S[_/``#$SP``
MP,^\K,//P<\``````````````````*C2I=(``*?26*]7KU6OI-*ITE2O5J^F
MTF?6H]*JT@````````````!BUF;6``!EUF[:>=H`````:-8``&/6;=ITL@``
M``!SLF'69-9UL@``<K)QLF#6:=8```````!PVG?:``!4M7;:<]H``%:U````
M````==H`````;]IQVG3:<MI5M7C:4[7?MP````"MWJS>JMX``.*WX;>NW@``
MJ][*XKNZX+<```````"PWJ_>``#-XLOB^KP``+RZS.)VY@``````````^[QU
MYG[F?>9[Y@``>N9WYGCF>>9\YJ'F`````%_J7.I=ZE>_6^IAZF#J7NH``&3M
M9>WQP```\L!C[0``><+^[WC"?L,``*'#;<1N]&WTW?7O]GK%Z/?G]^GWR*7&
MSUFO=K)JULFEI\G]I`````!%R@```````&S+:LMKRVC+:*AIRP``````````
M``!MS0``LZIKS6?-:LT``&;-M:IIS0``LJJQJ@``M*ILS6C-``````````#"
MK,6LSL_-S\S/OZS5S\O/``#!K*_2``#2S]#/Q*P``,C/T\\``,K/U,_1S\G/
M``#`K-;/Q\_#K```````````M-*KTK;2``"NTKG2NM*LTKC2M=*STK?27Z\`
M`%VO`````+'2``"MT@``L-*[TK+27J_/SP``6J]<KP````````````!XUFW6
M:]8``&S6``!SU@``=-9PUGNR==9RUF_6``!YLF[6=[)ZLG'6>=9;KWBR=]9V
MUGRR`````````````````````'[:````````H=I@M0``I]H`````J=JBVEJU
MIMJEVENU8;4``&*UJ-I8M7W:>]JCVGK:7[5\VJ3:JMI9M5ZU7+5=M0``````
M`%>U``````````#IM[?>Z+>[W@``L=X``+S>````````LMZSW@``O=ZZWKC>
MN=ZUWK3>``"^WN6W``"VW@``ZK?DM^NW[+<``.>WYK<`````SN*^NKVZ````
M`-/B``#\O+^Z`````,&ZU.+CM\"ZT.+2XL_B``#1X@```````*OF`````*KF
MI^9`O6+J0;VFY@``_KP``*CFI>:BYJGFH^:DYOV\``````````!I[0``9NH`
M`&7J9^H``&;M6K\``&/J``!8OP``7+];OV3J:.H``%F_``!M[?7`>L+VP//`
M:NUH[0``:^T``&[M],!L[6?M`````$+P1?!U\D#P``!O]$;P``"BPT3P>\)!
M\$/P1_!V\@``=/(``````````*/#<_(```````!NQ```````````[<3Q]NS$
M\_;P]O+VT,6R^,JE;LV\TKW2?;*_WEV_I,-[Q;/XRZ4``&_-8*(`````U\\`
M`-C/`````````````+[2O])^LJ&R````````J]H``,+>P=[`WM7B``#6XM?B
MPKH`````K>:LY@````!IZEZ_7[\``'+M;^UP[7'M2?!(\'S"=_+>]<RE``#&
MK```HK+#W@``S:4``,#2H[(`````8[5DM0``SJ7/I4;*:JAIJ,>LV<^LVM"E
MT:72I=.E````````:ZALJ&[+;<L`````MJIRS7#-<<T```````````````#:
MS]O/`````,NLR:P``,JLR*P``````````&"O``````````!DKV.OP=)BKV&O
M``#"T@````"FLGO6>M:DLJ6R````````9K5EM:[:`````*W:I[(`````````
M````[;?%WNZWQ-X```````#8XJ[F0KUJZ@```````'/M``"FPZ7#`````'S%
MU*5SS0````"HLMGBP[H`````;\MPRP````!TS;BJN:H`````MZH`````````
M`,^LT*S-K,ZL``#<SP````#=S\RL``````````##T@``:*]IKP``J[+)T@``
M;J]LK\K2Q=)KKVJO9:_(TL?2Q-)MKP``QM)FKP``9Z\`````K+*AUJ+6K;)\
MUG[6I-:CUGW6``"ILJJR``"VVFNU:K6PVFBU``"SVFRUM-IMM;':9[5IM;7:
M``"RVJ_:`````````````-+>``#'WO"W\[?RM_>W]K?3WM'>RM[.WLW>]+?0
MWLS>U-[+WO6W[[?QMP``R=X``````````-OBQ[K?XL:ZW.+%N@``R-[/WM[B
M``#(NN#BW>+:X@````"QYK7FM^:SYK+FL.9%O4.]2+U)O;3F1KVOYD>]Q+JV
MYD2]````````;.H``&OJ<^IMZG+J;^I@OW'J`````&&_``!BOP``<.INZ@``
M````````^,!T[0````#WP'?M=>UV[0````#YP````````$WP``"APD[P````
M`'W"3_!^PDSP4/```$KP`````*?#>/*HPV_$``!+\'#$````````[L3?]0``
M?L7T]GW%``#J]_7%]L4`````S/D`````T:S>SP``;K5OM=6ERJ9'R@``<<MM
MJ```NJH``-*LTZS4K*;6R])OKP````"NLJ76`````+C:<;4``+?:<+4`````
MU=Y*O;OFN.:YYKKF`````````````'CM``!1\````````''T</0``/7VUJ5U
MS7"O````````<K76W@````#AX@``2[UTZ@``4O!R]->E`````+NJUZS?S]BL
MUJP``-6LS-)QKP````!RKW.O````````L+*GUJ^R`````````````+G:L;)S
MM=?>^+?YMP``R;H``,JZ3+UDOW7J8[\``'GM^L```%/P<_38I6ZH>,UWS;RJ
M=LV]JGG-``#ES]NLVJSGS^;/WZP``-ZL`````-FL``#AS^+/X\\``."LX,_<
MK.3/W:P``````````,_2T]+1TM#2``#4T@```````-72UM+.T@``S=(``'6O
M=J\``-?2TM(``+#6``#8TG>O=*\```````"JU@``J=8``*O6K-:NUJW6LM:U
MLK*RMK*HUK>RL=:TLJ_6L[(`````````````O-J^VKK:N]H`````O]K!VL+:
MO=K`VG2U`````-O>``#@WMC>W-X`````X=[=WOJW0[@``/VWV=[:WLZZ1KC^
MMP``1+C\M]_>1;C>WD&X^[="N.+>YN+HX@```````````````````````$"X
M`````./BS+KIXLVZY^+BXN7BZN++NN3B``!.O;_FON8``%&]3[V\YDV]O>8`
M`%"]````````?>H``*'J``!^ZG;J>NIYZG?J9K]GOV6_>.I[ZGSJ``!HOP``
M0,&C[0``_,![[?[`0<$`````_<"B[7SM^\"A[7KM?NU][0````!5\*3"I<*B
MP@``H\(`````5/```'OR`````*G#``!Y\GKR``!T]'?T=?1V].#U`````._$
MZ_>T^```]\7X^/GX9L;9I>&L``##V@``X]X``-JE;Z@``+ZJ``#HS^G/>*\`
M````Q-IUM4>X0L&D[7SR>/3;I0```````*'->LU\S7[-?<U[S;^J````````
M``#BK/+/``#MS^K/`````/'/`````.2LY:SPS^_/[L_KS^S/\\_CK```````
M``````````````!\KP``I*^CK^'2V]+9T@``H:^YUGJOWM+BTN32X-+:TJ*O
MW]+=TGFOY=*EK^/2?:_<T@``?J][KP``````````````````````````N;(`
M`+K6`````+/6M=:WU@``N-:VUKJR``"[U@``M-8`````````````````````
M``#(VG:UT-H``,7:``#1V@``QMK'V@````#/VL[:R]JXLG>UR=K,VGBUS=K*
MV@``````````````````[MX``/+>3K@``/#B4;CPW@````#MWNC>ZM[KWN3>
M``!-N`````!,N```2+CGW@``3[@``%"XYM[IWO'>2KA+N._>Y=X```````#R
MXM"Z].+LWO;BU+KWXO/B``#1NN_BT[KLXO'B]>+NX@````!)N```Z^+2NNWB
M`````````````%2]P>98O0``5KT`````S[H``,CFR>93O0````#'YLKF5;U2
MO</FP.;%YL+F6;W$Y@````#&YE>]``````````!JOZCJ``"BZJ;JK.JMZJGJ
MJNJGZ@``I.H``&R_:;^CZJ7J``!KOZOJ``!&P0````"J[:7M1<$`````0\$`
M`*SM1,&H[:GMINVM[5;P``!'P:?M``"N[:OM````````6O``````5_```*;"
M``!;\%WP7/!8\%GP`````*/R``"JPP``?O*B\GWRI/(`````H?(``'KT??1Y
M]''$>_1\]'[T<L1TQ'/$X?4``./U``#B]0```````/;V`````+7X^OC<I0``
M``!RR\"JH\W!JL*JHLT``/C/]\_FK.FLZ*SGK/3/]L_USP````#HTJ>O[-+K
MTNK2YM*FKZJOK:\`````KJ_GTNG2K*^KKZFOJ*_"U@``P-:\UKNR``"]UKRR
MOM:_UL'6``"]L@````#5V@``U-K3VM+:``````````#VWE*X``#SWO7>``!3
MN```5+CTW@````````````!!XP``^>+ZX@``U[K5NM:Z0^,``$+C_N+]XOSB
M^^)`X_CB``#+YM#FSN8```````#-YLSFS^8``*[J``!MOTC!L.T``$G!K^U?
M\%[PI\(``*7RJ\.A]*'%]_8``+?XMOBHR>JLZZS#U@``5KC=I7*H<:APJ```
M`````*3-`````,2JPZH``.ZL``#ZS_W/^\\``.RL[:P`````^<_\SP``M:\`
M``````#STO72]-*RK^_2`````+"OKZ\``+.OL:\``+2O\M+MTN[2\=+PT@``
M````````````````QM;'UL76``#$UKZR``````````!]M0``UMK8VMK:?+4`
M````>K4``-?:>[79VGFU`````$'?]][ZWO[>6KC\W@``^][XWOG>6+A`WU>X
M``!<N%NX6;@``/W>````````2>,``$CC`````$3C`````-BZ1^-&X]FZ````
M`````````%Z]``#2Y@``7[U;O5V]``!:O5R]````````K^H``'"_L>JPZ@``
M1>-ROW&_;K]OOP````````````"U[0``L^U*P;3M``"V[;+ML>T`````8/"J
MPJC"J<(``````````*;RI_*MPP``K,.C]*3THO0``/CV^?8`````WJ5(RG.H
M``"ES<:JQ:JFS0````!`T.^L_L_PK`````"VK_C2]M+\TK>O]]+[TOG2^M(`
M````R-;*U@``O[(``,G6P+*BM:&U?K7;V@``````````1-]=N%ZX``!#WT+?
M``````````!*X]NZVKI+XTSC``!AO6"]``"UZM/FU>;4YK3JLNJVZK/J``!S
MOP```````+?M2\&X[;GM`````*O"K,(``'7$`````-'%WZ4`````````````
M0=````````````````#]TKBO`````````````+JSN;,`````I+7=VJ.UW-H`
M`````````$7?``#<NDWCW;H```````````````!VQ*7T``#+IL>JI\T``/*L
M``#QK$+00]``````0--"T[FO``!$TT?31=,```````!&TT/3_M*ZKTC30=,`
M`````````-/6QK+<UL.R``#5UL>R``#!L@``T-;=UM'6SM;%L@``PK(``-36
MU];$LMC6R++9UL_6UM;:UM+6S=;+U@````#;U@````#?V@``````````Y-H`
M``````#@VN;:I[7,UN':I;7>VJRUXMJKM>/:K;6HM:ZUJ;4``*JU``"FM0``
MY=H``````````````````&&X4-\``%/?1]],WT;?8[@``$K?````````2-]B
MN```3]].WTO?3=])W^&Z4M]?N%'?````````````````````````7>,``.BZ
M6.,``.>Z3N,``%#CX+I5XU3C5^/ENE+C4>,`````Y+K?NE/CXKI9XUOC``!6
MXT_CX[H`````:;W>N@````!<XP``````````````````V>9BO0``V^8``&.]
M`````&6]WN8``-;FYKK<Y@``````````V.8``&"X:+T`````9+T``&:]9[T`
M`':_W>;7YFJ]``#:Y@````````````#`ZKOJ`````,7J=+^]ZGB_P^JZZK?J
MQNI1P7F_PNJXZG>_O.I[O[GJONIZO\'JQ.H``````````,OMS.V\[</MP>T`
M````3\'([;_J``"_[0``R>U.P;[MO>W'[<3MQNT``+KMRNU,P0``Q>W.[<+M
M4,%-P<#MN^W-[76_``````````````````!C\`````!A\&?PL,)E\&3PLL)J
M\+'"``!K\&CPKL)I\&+PK\*MPJOR9O``````;/``````J/(```````"RP[##
MJO(``*SRJ?*QPZ[#K\.SPP````!XQ```JO0``*GTI_2F]*CT``!WQ'G$````
M`/#$`````.7UY/4`````^O8``/SV_O;]]OOV`````*/%HL4`````T\72Q=3%
M[??L]P``^_BX^/SX6,8``%G&;?D`````?L;,I@``J,T`````1=!&T$30````
M`/.L``!'T$C02=``````2=-/TP````!-T[NO2],``$S33M,```````!*T\FR
M``#>ULNRX-;*LM_6`````````````.C:K[4``.K:Y]KAU@``L+4`````Z=H`
M``````````````!6WP``9+A4WV6X5=]FN````````.FZ8>->XV#CZKKKNE_C
M`````````````-_F`````.#F``!KO>+FX>8``&&B``#*ZLOJQ^H``,CJ?+]]
MO\GJ``!7P0````!3P5C!5,%6P5+!``!5P0``````````L\+/[0``KO(``*WR
M``"K]'K$>\1!]^;U``!`]P``_?BD^<VF`````'2H``"IS<BJ``#VK$S0]*Q*
MT/FL]:SZK/BL2]#WK+^OOJ]:T\>O4]-9T\.O4M-8TU;3PJ_$KU73O:]4T\BO
MQ:_)K\:O4=-0TU?3P*^\K\&O`````````````/#6Z=8``+6UZ-8``,^RUK+3
MLMFRV++4L@``XM;EU@``Y-;0LN;6[];1LN/6[-;MUM*RZM;7LLVRU;+GULRR
MZ]8`````[M8```````#[VO+:LK7YVO;:[MKWVK2U[]H``.O:`````&RX]-H`
M`+&U^MH``+BUNK7MV@````"YM?#:L[7XVO':]=H``//:MK7LVKNUSK*WM;RU
M`````````````&BX7=]?WV'?9=\``%O?6=]JN```8-]DWUS?6-\``%??````
M````8M]:WU[?:[@``&FX9M]GN&/?``!RXP````````````#NNFKC>+UTX_&Z
M>./WNF7C`````'7C8N,``'?C9N,``/ZZ^[IVXW#C[;KUNO2Z``#SNOFZ``!C
MX_JZ<>/VNNRZ<^/ONO"Z^+IHXV?C9.,``&SC:>-MX_VZ``!YX_*Z;N-OXP``
M:^,```````#\N@``````````Y^9PO7F]=;WDY@``<KUVO?#F;+WHY@``=+T`
M````Z^;FYG.]=[WEY@``<;T``._F;KWNYNWF>KURY6V]``#LYN/F``![O>KF
M;[T``````````````````.GF``````````"BOZ>_?K_8ZL_JV^K3ZMGJJ+^A
MO\SJTNK<ZM7JVNK.Z@````#6ZJ._U.JFOZ6_T.K1ZLWJU^JDO][JW>H`````
M``#:[=;M7\$``-#M6<%IP=SM8<%=P=/M9,%GP=[M7,'5[67!X.W=[='M8,%:
MP6C!V.UCP=+M7L'?[6+!6\'9[6;!U^T`````V^T```````!N\'3PN<)W\+3"
MM<)O\';P<?"ZPK?"``!M\```ML)S\'7PN,)R\'#P``````````"X\K?#N,.T
MPP``M<,``+3RLO(``+;RNL.W\K#RK_*S\K'RML.U\JST?L1]Q*WT``"O]*[T
MH<0```````#K]>CUZ?4``.?UZO7RQ.SU``#QQ```0O<``-7%U\7N]];%N?A`
M^4+Y_OA!^6S&````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MSJ8``/NL;]+*KP````#:LOS:_=H```````#?ZFK!X>T`````N\(``+KRN?*B
MQ.WU``!#]_C%2<H`````R:IUJ`````!-T`````!@TUO37]-=T\NO7M-<TP``
M\=8``/[:0-MIWVK?;KAON&C?:]]GWVVX``!`NP``<+AZXP``?+WQYGV]``"I
MO^+JX.KAZN3MX^WB[0```````+OR``"YP[SR1/?YQ;KXSZ;+JLJJ3]#\K```
M``!.T&+3``#,K_+68=,```````#<LO76\];TUMNR``!"VT/;0=L``'.X;=]L
MWV[?<KAQN`````#RYO3F``!^O?/FX^JJOWGP``!X\+O#O?*]P[S#L/3N]?/$
MT*90T/VL9=/.KV338],``,VO``#[U@``_=;VUO?6W;+XUMZR_-;YUOK6W[(`
M`+ZUO[4``$3;````````;]]PWP``?N-#NT&[0KM[XWSC``!]X_GF``#ZYJ&]
M]^;VYOCF]>:MO^3JJ[^LO^;M:\'E[:CO``!Z\'OPO,(``+W";,&^\K_RL?2C
MQ-&F``#2IOZLS*K/KU'0````````P+73ID&M4M!3T$"M0JW4I@``5-#1KV;3
MTZ_0K]*O``!!U^"R``!`U_[6``!QWP````"AXP``HKT``*Z_YNKEZ@``Y^T`
M``````#O]0````#5IG/+JLU#K570``!HTP```````-2O9]/5KP```````$/7
M`````.*R0M=$UP``X;(``````````$;;1]M%V\&U````````=+@``'6X``!%
MNP``H^.BXT2[`````````````/OF`````/SF``````````#GZ@````!PP6_!
M;<%NP7'!``!\\+_"OL+`\K+T````````I<6DQ=:F`````/O1``!WN,*U=KA&
MNP``UZ:IR=BFV:8`````J\UVRP``=\MWJ```=,MVJ```>:AURWNH>JAXRWBH
M````````T:K/JJW-``#.J@```````-.JU:K2J@``L,VLS=:J``#0JGRH``#4
MJJ_-`````*[-``#-J@``````````````````6]!'K4BM7=```%?06M!CT&'0
M``!)K6?03*UDT%S06=``````2=MBT$2M9=!6T%_01JU+K6#03ZU-K0``6-!*
MK0``7M!.K46M9M````````````````#:KP``XZ_8K]:O:M/>K]NO;-,`````
MW:]KTVG3;M/BK^"O2-L``&_3;=/7KP````#9K]RO``#?KP``X:\`````````
M`````````````````$[7Y+(``$771]<``$C7``!0UTS72M<``$W74=?ELNFR
M1M<``$_7``#GL@``YK)+UTG7``#CLNBR`````````````````````,BU4=L`
M````3]O*M0``````````2MNAWP``R;5.VP````!+V\6UR[50V\>U3=M'N\:U
M3-O,M<2UP[4`````````````=]]UWP``>]\``'/?HM]XWP``<M][N*.X?=\`
M`';?``!^N`````!\N'[?>;AXN'G??;C-M0``?-]TWWJXH;BBN```````````
M3+M(NP``3;NFXP````"EXZ?C2KNDXTN[JN.IXZCC``!)NP````````````!!
MYP``1.>HO4/GI[VCO:2]I;U`Y_[FIKT``$+G_>8`````Z>KSZK&_L+\``.WJ
M[^H``.KJ``#NZNCJ\>JOO_#J[.H``/+J``#KZG3!Z.WN[7C!>L%WP7;!``!U
MP7/!Z>WL[7+![>T``'G!Z^T``.KMP,(``,'"H?!]\'[P`````,+R``#!\K[#
MM/2DQ+/T``#P]47WIL5#^43YV,7:I@``UZI2VTZ[>\'O[=NF``#EK^2O4]L`
M``````#TZMRF4*T`````5-M5VU;;3[NRO]VF``#8JFC0YJ]PT^JR``!7VZ2X
M``!0N[._?,'"PK7TWJ;9J@````#GKU+7SK4``%&[J^-%YP``````````WZ;/
MM:/?4KO@IK'-:=!1K0````!RTP````#JKP``Z*_IK^NO`````''3`````%?7
M5-=6U^NR[;+LLE/7[K)5UP``6-M9VP``6MNFWP``I]\``*7?J-\``*6X``"D
MWP``4[L`````2N=&YTGG2^=(YT?G``#UZO;J]^JTO[6_\>WP[?+M``"C\*+P
M``#$\@``Q?+#\@``I<0``+;TM_0``$;W[_>[^.&F?:@``'W!XJ8``%C76]L`
M`$'&2LH```````!+RDW*XZ9.RDS*`````*++H\M[RP``````````H<NAJ```
MHJA\RWK+><M]RWZH?LMJT````````+;-W*JUS;?-``#;JKS-WZJRS<#-QLWF
MJL/-XZH``+G-O\W!S0``M,WBJMVJNLWDJN>JX:H``-JJOLVXS<7-Z:KEJN"J
MO<WLK[O-WJKHJ@``L\T``,+-Q,T`````````````````````````````````
M`&*M7*UDK6&M<=!TT%VM``!KT```5JU@K0``8ZUEK:+0=]```%6MH=!9K5>M
M4JUOT```?M!ST';0I=```&:M?=!>K7C0I-!UT'G0?-``````;="CT'O0````
M`&S0``!PT%^M6JU3K5BM5*UGK6[0I=-;K0````!ZT$'.````````````````
M`````*C3^J\``';3``"CTWW3``"RTP``JM,``'[3``"ITWC3?-.UT_VOK=.D
MT^VOL]-TTP``K-,``/RO]Z]ST_6O]*_YKZO3\:_XKW+07-NFTP````!ZT_NO
M>].AT_ZO==.OTP``KM.VT_.O\*^TT[#3I].BT_:O\J]WT^ZOL=/OKP``>=,`
M````````````````````````````````````````````````````````````
M`````````````%[78-=EUWG7_++RL@``7=?]LOZR:-=OUW77``!BUP``:=<`
M````0+-WUW+7^K+XLF[7:M=<U^^R8==9UP``][+YLF;78]?TLG/7\;)DUWK7
M;-<``&O7\+(``/NR``#SLEK77]=PUW;70;-;UV?7;=?VL@````!XUW'7=-<`
M``````````````````````````````#UL@``;-M@V]>U?=NGVZK;U;5HVZ/;
M:=MWV^*U<]O?M0``=-M=VP``I-L`````Z+6AVW7;K-MPV\C?``"OV^:U;MMZ
MV^FUU+5RVZW;:]MDVV_;``!CVV';T+6EVVK;J-L``*G;V+7=M=FUX;5^V]JU
M=MMFVP``TK5>VZ+;J]MEV^"UL-MQVP``;=L``-&UY;4``'S;Y[4``'C;W+76
MM=ZUT[7DM7G;9]M[VV+;IML``````````````````*[;````````````````
M``!?VP````````````#'WP``W=]5N,S?``#*W[7?J;C%W]G?P=^QN-C?O]_C
MM<_?P-_6W["XJ+@``*K?LM\``,O?P]_<W\;?MKC7WP``K;@``,G?T=^VW]#?
M``#AW['?TM\``-_?``"KW]NU``"YW[C?K[@``+S?OM_-W][?LK@``+.X``"P
MWZNXM-_:W[2X``"LN*ZXM;C@W]/?SM\`````N]^ZWZJXK-^GN,3?K=_"WP``
M``"WW]O?````````IK@```````"SWP```````````````*_?U=^NWV"[T^,`
M````PN,`````K./*XUB[N^/%XUN[ON-9NZ_CS>.NX\'C``"MXP````"_X\CC
MQN.ZX[7CL^,``+3CQ^/2X[SC6KL``+?C``#+XP``7;NVX[#CP.-ANP````!5
MNUZ[N..RXP``5[O4WU:[P^,``%2[8[M<N\3CN>.QX\SCO>-BN]#C7[O/XP``
MR>/.XP```````-'C`````````````````````````````'/G=.=GYV;G8N>T
MO0``K+UVYW7GJ=]?YV/G7><``'#G8><``'?G6N=8YV3G;N=IY[:]3^<``&WG
M````````M[V]WUOG4N=5YWOG7.=3YU'G3N<``+"]9>>OO;.]8.=HYZF]>.=\
MYZN]``!7YVOG;^=4YWGGLKT``+&]3.>UO7+G5N=JYU#G7N=9YZV]KKULYWWG
M>N=QYP```````````````````````$WG``"JO4GK``!`ZT/K``"[OT7K^>I!
MZT?KN+^\O[:_`````/OJ3.L`````1NL``/SJ5>M/Z_CJ1N[^ZK>_``!*ZP``
M5.N_OP``4>O]ZD3K2.M"ZU;K4^M0Z[F_NK^^O_KJ5^N]OTWK`````$OK````
M````3NM3[D#N1>Y2[D3N^^U![@``HL$``/3M3>Y/[O/MH<%1[DGNJ,%0[D+N
MJL'Y[5+K2NY'[O7M5>ZDP0````"EP??M2.X``%3N2^[][:?!H\%,[O[M5N[X
M[4/N3N[Z[?SM``#+PO;MJ<'$PG[!``````````"FP<C"L_```*GPI/"J\+3P
MN/"W\,K"R<(`````J_"Y\*[PIO```*CPI_"M\++PI?"L\+'PQ\(``*_P``#%
MPK#PP\+&PM7RM?``````PL,``,WRT?+)\LSR``#4\L##V?+2\@``RO+:\M/R
MP\/$P]?R``#+\K_#P</&\L[RR/(``-CRUO+'\L_R````````OO3%P]#RI\2I
MQ*;$``##]+OTN?2]]+KT`````+_TP?2JQ*S$``#`]*W$J\3"]```````````
MJ,0`````````````],3Q]??U]L2\]/;U``#]]?3U^_7Z];CT]?6V\/[U\_7X
M]0``_/7R]0``2O?UQ/GU`````/3W2_=)]T?W2/=,]P``V<7R]_#W]??S]P``
M]O?:Q?'W`````+SX`````$7Y1OE'^0````#'^;WY3\KJJ@``:*T``+C3M]-`
ML$*S?-<`````>]<``.JUN+@``+>XN;@``-3C?N=8ZUKK6>L``*O!5^ZZ\*7Y
MY*8``,G-RLW(S<?-ZZH``*G0I]``````IM```&FM:ZUJK:C0````````````
M`````````,33P=._TP````!!L,+31K"\T\O3``#-T[W3``!#L,[3R=.[T\#3
MRM/&T\/3``!(L,S3OM,`````Q].YTT>P1+#%TP``R-.ZTT6P0K``````````
M`$RSI==+LP``J->KUTBS1K-^UZG7I]>DUZS7K=>OU[#7?==%LZ+7H=>NUT>S
MH]=)LT2SIM=-LP``2K.JUP```````/&UO]L``+3;[K4``.??O=NQV^RUMMOO
MM;K;N-ORM>NU`````++;M=OPM0``L]L``+[;O-NWV[G;N]OMM0``````````
M````````Z-_NW^3?ZM^ZN.;?P+@`````O[@``+ZX[=_!N,*XX]_PW\.XO;B\
MN.S?Q+CBW^7?[]_KWP````#TX^GCN[@``````````&J[W>/RX][C9;L``-OC
M``#DX]SC9[O6X_'C:+ONX^_CU^-MN^;C``#@X^?CVN,``//CZ^/EX]7C:;OL
MXP``;+OPXP``ZN-FN^CC``#BXV2[V>/AX^WCW^,`````X^,`````````````
MP;WIW[+GN^>QYZWGJN?"O:CG:[NAY\"]I^>_O:SGJ>>YY[3GKN>SY[N]J^>^
MYZ+GH^>ZY[R]O^>^O<#GL.?8X[;GK^>XY[7G````````IN>YO;WGNKVDY[V]
M9.NWY[SG`````````````&'KN+W`OVOK9^L``&7K8.MOZP```````,2_``!<
MZVCK:>M?ZU[K;.L``&+K7>MCZP``;NM;ZVWK:NO"O\&_`````,._9NO+\```
M``````````!9[K'!7>Y:[F'N9^Y<[@``<.ZNP6KN7^YK[F;N;>Y>[K/!LL%@
M[F[N6.YL[JS!``!D[F/N:.Y;[K#!``"TP6+N:>ZUP67N``````````"MP:_!
MQ_#%\`````#,\,GPS?```+[PQO#1\&_NPO#/PJ7GO?#*\,3PP?"\\+OPT/``
M`,#PO_#-PLCP``#,P@````#.PL/PS_```-[RW_(``,G#W/+&P^3R``#*P^;R
MV_+.\.CRW?(``,?#X_(``.7RX/+G\N+RX?+(PP````#%],;T``#(]*[$K\3)
M],?T``#$]```0O9%]D'V``#ZQ$/V^<3XQ/?$1/91]T_W``!.]T#V4/=&]DWW
M``#Y]]?W]_?;Q?CW^O<``+_X^L6^^+WX^\4``%K&;OFG^:;YJ/GEIJK0``#/
MT]#3````````P-L``$?VP/CFIFRMJ]````````"QUTZS``#"V\';\[4``,6X
MP>?#O0``Q+T```````#%O_S%YZ8```````"LT.VJKM"MT&VM``#1TP``V--)
ML-;3U-,``-O3TM/3TTJP``!.L`````#<TTVPVM/7T]732[!,L-G3````````
M``!0L[+7``!5L\+75+/$UP````"XUU*SP]<``+/74[._U[O7O=>WU[[7````
M`$^SNM<``+G7M=<``,#7`````+S7M-<``+;74;/!UP``````````]K7-VP``
M`````,G;R]O&V\7;P]L``,K;S-O(VP``Q]OTM?6U````````````````S]O-
MN/+?^-_SW_3?``#YWP``S[@``,>XSKCQW\3;RKC(N/??]M_)N,NX]=_&N```
MS+@`````````````]N-TNP````!"Y$'D``#[XW:[0.3WX_CC;KMPNP``_>/U
MXW*[<;OYX_[C_.-SN_KC`````,[;;[L`````PN?)Y\:]``#-Y\J]Q>?#YP``
MS.<``,6]R^?'O<B]Q.?)O<KGQN?'Y\CG=;L```````!PZWSK``#*OW?K>>L`
M`,B_<>MUZP``>.O&O\F_>^MSZW3K>NMRZW;KQ[]R[@``<>ZWP7?NN<$`````
MML%S[KK!=.X`````=>YX[@``N,$``-;P`````-GP``#3\-7P`````-3PU_#8
M\';NTO``````S</L\N_R\?+J\NOR[O+P\L[#S,/+P^WRZ?+*]+#$``#+]```
M``!)]OO$2_;\Q$CV2O:HQ0``4O>GQ?WW_/<``/OW`````$CY2?E+^4KY``!0
MRNBF``!NK<77][4``/K?T,(``/+R`````*.H````````5[,```````!6LP``
MT-OXM=+;T=L`````^]_0N$/D1N1%Y```1.3.Y]#GS^<``,R_````````R[\`
M`+O!>>Y[[GKN`````-'"````````]/+S\@``S/2QQ`````#]Q%3W4_=;Q@``
M``````````````````````````````````````````"DJ*_0;ZW(U\;7````
M`,?7U-O5VT/@T]L``/S?0>!`X$+@T;C^W_W?1.```$GD1^0``$CDT^?1YP``
M``#2YWWK?.Y][M+"``#U\LWTLL0``$SV5?>IQ0``_O=,^:6H``!QK7*ML-``
M````L=!PK0``5+```%*P``!1L%BP4+!9L-W35K```%.P5[!5L$^P`````%^S
M``!9L\S77K,`````8+-:LP``6[,``,K7`````%BS``#+UUVS`````,G77+,`
M````1+8``$:V`````-C;1;;YM?VU``#DN$G@VMO^M0````#=V][;0[8``.#;
M``#BVP``X]O7V];;Y-M"MN';W]L``$"V^[5'MMO;W-O9VP``0;8`````_+4`
M`/JU2.#?N-JX`````-6X``#EN-:X``#2N.&XWKC@N```U[C<N-.XU+A0X$W@
M1>!*X```XKA1X..XV;@`````1^```$_@2^!.X$S@W;A&X-BX````````3.1X
MNWN[``!.Y```I;M-Y'V[``#/O4_D``"DNTODIKL```````!YNP``V[A\NP``
M>KM^NZ*[=[NGNZ.[``"ANTKD``````````#6O0``TKT```````#9O0``UN?:
MO>+GV^?+O>/GW>?5O=[G``#4O>'GSKW?Y]7GS;VJZ].]``#0O0``V+T``-3G
M``#8Y\R]U^?9Y]KGU[W<Y^#GY.<``-N]TK^EZZOKJ.M^ZZSKH>L``*?K``#-
MO]._K>L`````S[\``-F_U+^OZZGKT+^BZ]J_H^NDZ]N_V+_1O0``SK^PZ]R_
M``#5OZ[KT;_6O]>_``##P:3NK>ZJ[JSN``#`P:7N``"K[KS!I^[$P:/NJ.ZO
M[J;KJ>ZB[KW!H>Z^P;#NO\&N[L+!?NX``,'!``"F[MSPZO#E\.?PV_#3P@``
MVO#6PM7"``#I\.'PWO#D\```W?```-_PZ/#F\```U,+M\.OPXO#L\./P``#Y
M\L_#0?,`````3_;6P^#P]_+2P_CR_?(`````U,/5P_;R0/-"\_KR_/+^\OOR
M0_/1P]?#T\,``-##T/0``+?$SO0`````TO0``-/TM<34]-'T``#/]+C$M,35
M]```ML2SQ````````/[$`````$#%3O9-]E#V4?8``$'%5O=;]ZK%``!8]P``
M5_=:]UGW``!#^```W,5"^$#X``!!^````````/[%_<7!^,+X0,8``$WY3OEG
MQ@``;<8``*GYR/D`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````*:H
M``#-UP``SM=2X%#DY>?&P0``Q<'N\$3S``!$^*>HWM-:L&&S5.!3X-R]YN?=
MO;'NU\(```````!VQJBHR\W?TP````!BLP``S]?0UP``Y=L``$BVYK@``%;@
M5>!7X```4>12Y*B[W;_>O=Z_``"U[K+NM.ZS[L?!``#O\$;S1?.DRURP6[#@
MTP``T=<`````Y]OFVTFV``!9X%K@6.``````Z+CGN```JKNINP``Y^>SZ['K
MLNO?O[?NMNX``/+P\?#P\$?S``"J^:FH<ZT``'2M7;!>L.+3X=/2UP``:+-F
MLV.S9[-ELV2S`````$JVZML``.VX3+91MNS;4[92ME6VZ]OHVT^V2[9-MNG;
M5+90MDZV[[CNN.RX\+@``.JXZ[@``.FX``!;X`````!4Y```K+NMNZN[``!3
MY```5>0``.KG[.<``.>][>?@O>GGW[WIO>6]YKWBO>CGX;WNY^OG``#HO0``
MX[WDO;7K``"WZ[;K``"XZ^"_M.L`````R\&X[LC!S,'*P<G!\_```/;P``#U
M\```]/#8PDCS2?/8PTKSV<,`````NL0``+G$4O8`````0L53]ESWJ\6LQ0``
M1?@``$+&````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````JJ@``&JS:;-<X%W@``"NN[GKZKVZZ[GNJZ@``++0
M=JUUK0``X]-?L.33U=<``-37``#3UP````#NVUBV`````.W;5[8```````#O
MVU:V``!?X&+@8.!AX&7@7N!FX&/@9."PNU;D`````*^[``#RY_#G`````.N]
M[^?QYP``[+T``+OK``"\Z\W!``!,\T[S2_--\];T5/8`````;_FLJ'>MY=/G
MT^;3``#8UVRS``#6UP``:[/9UP``VM?7UP````#[VV"V\]OYVP````!;MEZV
M\MM9MO;;;.!=M@``\=L``/?;]-OZV_#;^-M<ME^V]=M:M@``\KAHX/&X;^!N
MX/BX``#YN'#@\[AMX/>X<N!IX```:^#TN&?@:N!QX/6X<^``````````````
M]K@``+&[6^1AY%GD8N0``%CD7>1CY&#D7^1>Y```5^1<Y`````!:Y```\;WN
MO?OG0>A#Z$#H^.?ZYT7H0NC\YT;H^>=$Z.^]];WSO?/G]+WPO?3G]N?UY_WG
M_N<``/*]``#MO0````#WYP``QNOBOP``O>OCO^:_PNL``+_KY;\`````P^O$
MZ[[KQ^O`Z\7KY+\``.&_P>L``+_NT,'.P='!S\&^[KONNNX``+WN`````+SN
M1?'>POOP^O```-G"0?%`\??P0_'\\-W"^?!"\?CPVL+<POWPV\+^\```1/%2
M\P``WL-/\P``4_,`````V\-1\^##``#=PP``4/,``-_#5//:PP``````````
MO,2^Q```V?2]Q-?TW,/8]+O$0\5%Q5;V1,55]@``8?>MQ6#WKL5>]UWW8O=C
M]T;X``!?]P````#&^,/XQ/C%^%S&``!1^5#Y3_EP^0``OOFK^6[&K:A@L```
M``````````#ZN```````````````````]KT`````R.L`````W\(``%7S````
M````````````K/FNJ.ZJ>:UXK0``8[```.C38;#ITV*P`````-_7V]<`````
M;;/>U]W7W-=NL^#7X=<```````!#W$'<1=Q&W$S<``!(W$K<``!"W/S;``!)
MW`````!+W$3<1]S]VV*V0-S^VV&V8[8``/VX=>!WX';@>^#[N```>.!TX'G@
M>N#\N/ZX?.```&?D9N0``&3D9>2SN[6[LKNTNTWH3NA)Z```2NCXO?V]][W^
MO?F]2^@`````3.A(Z$"^^[T`````^KW\O0``1^@``,KKZ+\`````S.OJO\_K
MR^O)Z\[KZ;_-ZP``Y[\`````T\'6P<'N``#4P<#NTL'5P4;Q1_%(\>#"``!)
M\0``X<+BPUCS6?-7\U;S6O/AP]WTV_3<]-[TVO3?]%CV``!9]E?V1L5D]Z_%
M9?=(^$?X````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````KZADM@````!`N0```````+:[````
M`.R_``#KOP``````````X\-\Q$?%L*ADL$&Y``!;\P``````````````````
M````````ILL`````L:@``+2HLZBRJ`````"ERP``S<T``,_-[ZH`````\:K,
MS<[-\*K1S=#-TLT`````````````````````MM"TT'RML]"CK7ZM>ZT``*2M
M``!]K:*M``"AK;70``!ZK0```````&JPZ]/QTV>P;K```&FP[M/PTVRPZM/M
MTVBP9;#LTVNP[]-ML&:P``````````#CU^;7<+,``'JS=K/DUP````!^LW>S
M?+-RLP``;[-QLWVSY==ULWBS=+-YL^?7>[-SL^+7````````````````````
M`$W<9;9/W```9[9IM@``3MQFMFJV``!HM@```````$>YH^!/N7[@``!0N46Y
M``"AX`````!*N0``HN!#N4*Y``!-N4RY2[E)N4ZY?>!$N4:Y2+D`````N+N[
MNP``O[NYN[Z[O+L``+>[``"]N[J[````````4NA#OD&^``!3Z```1+Y"OE'H
M4.@``/"_3^CNO^V_T.M%ON^_T>ORO]+K\;_8P</NU\'<P=K!V\'CPMG!PN[3
MZ^+"Y,(``.3#Y<,``.#T``#>Q=W%MJ@`````5<IOL```4LI3RE'*``!4R@``
M``"JRZ?+K,NHR[>HNJ@``*G+N:BKRP````"XJ```````````U<W7S?2JT\W6
MS=3-\JKUJ@``\ZH``````````+C0O-"YT```IZT``*BM``"[T```O="_T```
MI:V^T`````"FK0````````````#NU[K0\M/[T_G3]-/UT_K3_--QL```]]/S
MTW"P<K#VT_W3^-,`````H;/QU^G7[]?PUZ*S``#HU^K7M]#LU^W7Z]=LM@``
M`````%;<U.M7W%3<H[-NME/<6=Q8W&NV7-Q2W%O<4-Q:W%7<;;8``*K@``"E
MX*O@IN"DX*?@4;D``*G@``"HX%*YP;O`NV[D<>1IY&WDPKMLY&KD<.1KY&CD
M;^0``%GH2+Y*\5;H5^A5Z%'<1[Y:Z%3H1KY)OECHU>OSO];KU^L``,3NW<%+
M\4SQ`````$WQ7?-<\^+T``#A]%OV7/9:]F;WL,6[J*JMJ:UUL'2P0-1!U/[3
M``!SL/77``#VU_+7I+/SUP``]-<``````````%_<8=Q=W&#<;[9>W'"V````
M`'/=5;E4N0``4[D``*S@K>``````<^1UY,:[P[L``,6[Q+MTY'+D````````
M`````&'H7NA?Z$V^8.A;Z%SH2KX``$N^7>A,O@``V^L``-SKV>O:Z_2_V.L`
M````````````R.[%[L?NX,'+[M_!R>[,[LKNQN[>P0``3_$``%#Q3O$``%+Q
MY<+FPE_SY\-1\5[SYL/E].;TO\3D]```X_0``%WV2,4``$GXR/C'^```0\9=
MQLGX<?D``&_&O*CVJ@``5KD``,#$O:BKK:6S<;;GPO>J``#!T,#00M0``'BP
M=K!ZL$34``!YL'>P``````````!#U*BS_-<``*>SJ;-"V*NS_M=`V/?7JK-#
MV`````#YUP``^M?XUZ:S``!!V/O7_=<```````!MW```;-QJW&+<<=QEW&_<
M=MQNW'FV``!UMF/<``!IW'>V``!HW'BV>K9KW```<K9SMG?<==P``'3<9MP`
M`'+<``!VM@``````````=+9SW&3<9]QPW`````````````"ZY+?@``"PX,/@
MS."SX&&Y``#`X%>Y6;EEN;'@`````%JY7+EFN5NY``````````!DN;G@``"N
MX&*YN.!>N<K@8[G(X+S@QN!@N:_@R>#$X```R^!8N0````!GN5VY`````+7@
M``"]X,'@``#%X%^YM."RX+[@``````````"[X+K@``"_X,+@``#'X```````
M`'CD``#'NZ3D>N3,N]"[K>2UY*;DR+L``*KDMN```,F[L>2VY*[D``"PY+GD
MLN1^Y*GD`````-&[``#-NWSDJ^3+NZ7DRKNSY*+D>>3.N[CD`````'ODK^2L
MY*?D=^1VY*'DM.3/N[?D?>2CY%*^`````````````%J^5;ZDZ*'H9^A0O@``
M`````$^^5KX```````!EZ%2^<>ACZ&3H3KZCZ%B^=.AYZ'/H[NMOZ'?H=>AH
MZ&+H?>A7OG[H``!XZ```;>AKZ&;H````````;NA[Z&KH>NBBZ`````!3O@``
M=NA\Z'+H;.A1O@```````*CD<.A9OFGH`````````````/3K][_SZ_#K1.S[
MOP``0>SXZT/LZ>OVZP``_;\``.'K``#?ZT+L``!`[/[K[>OLZ^+K0,```.CK
M\NO]ZT/`1>P``.C!1<#^O^;K``#OZ][KX.OUOT+`^K_GZ_?K\>M!P-WKX\'Y
MZ_SK_+\``.OK1,#YOP```````/B_]>O[Z_:_``#DZ_KK`````.7K````````
M````````````````ZNO2[@``U^[EP>?!W>[AP>SNX^[8[MGNXNX``.[!X>[1
M[N#NU.[M[NW!Z\'5[@``Z.X``-KNY^X``.GNT.[FP0``ZNX`````WNX``.K!
MV^X`````[,'D[@```````.3!UN[E[@``W^[CZ^;NT^X``.G!``#K[@``XL'.
M[@``````````8/%9\>G"``!4\6/Q6_'<[@``9?%5\0``Z,)?\>K"\L+PPF'Q
M\<)7\0``6/%=\6+Q``#-[NO":O%G\6OQ7O%:\6CQ:O-<\0``[L(``.W"S^[O
MPF3Q9O'LPFGQ4_$``%;Q`````````````````````'/S``!C\^O#<?,`````
M8?/LPP``;/,``&CS\<-R\V+S9?/IPW3S``!M\W#S[\/TP_+#:?-D\P``[</N
MPV#SZL,``.C#\,-O\_/#``!K\W7S]<,```````!G\P``;O,`````````````
M``#S]$+U]?3\]&;S^O3I]$#UP\3M]/[T]/0`````PL0`````1/7V]```^_3]
M].?T0?7R]/?TZ_3O]$/U^?3H].ST[O3X]```P<3Q]````````````````.KT
M``````````````````#P]&'V9O9/Q6CV``!)Q0``9/9J]D[%2L4``$O%8/9G
M]DW%9?9,Q5_V8_9B]@``7O9I]@```````+'%;?=P]VSW;O=O]VGW:O=G]P``
M``!K]VCWLL6SQ0````!+^```3?@`````````````3/A.^```X,4``$KXW\7A
MQ0```````,OXS/A$QLKX``!3^5+Y5/E?QE7Y7L96^7+Y=?ET^6C&<_D`````
M``!RQG#&<<9WQL#YP?F_^<GY````````````````````````````````5:)6
MH@```````````````````````````````%"B4:)2H@````!4H@``````````
M````````````````````````````````````````````````````````````
M````````````````````5Z(```````````````````````!3H@````#KH>JA
M`````$^BP*$``````````````````$"A0J%#H;*A``"DQ@````!QH7*A;:%N
MH76A=J%YH7JA::%JH46B``!EH6:A``````````````````"IH:JA`````,.B
MQ*+%HL:BQZ+(HLFBRJ++H@``````````````````````````````````````
M``````````````````````"EQJ;&I\:HQJG&JL:KQJS&K<:NQJ_&L,:QQK+&
ML\:TQK7&ML:WQKC&N<:ZQKO&O,:]QK[&O\;`QL'&PL;#QL3&Q<;&QL?&R,;)
MQLK&R\;,QLW&SL;/QM#&T<;2QM/&U,;5QM;&U\;8QMG&VL;;QMS&W<;>QM_&
MX,;AQN+&X\;DQN7&YL;GQNC&Z<;JQNO&[,;MQN[&[\;PQO'&\L;SQO3&]<;V
MQO?&````````````````````````HL:CQ@````#XQOG&^L;[QOS&_<;^QD#'
M0<="QT/'1,=%QT;'1\=(QTG'2L=+QTS'3<=.QT_'4,=1QU+'4\=4QU7'5L=7
MQUC'6<=:QUO'7,==QU['7\=@QV''8L=CQV3'9<=FQV?':,=IQVK':\=LQVW'
M;L=OQW#'<<=RQW/'=,=UQW;'=\=XQWG'>L=[QWS'?<=^QZ''HL>CQZ3'I<>F
MQZ?'J,>IQZK'J\>LQZW'KL>OQ[#'``````````````````"AQ@``````````
M`````'2C=:-VHW>C>*-YHWJC>Z-\HWVC?J.AHZ*CHZ.DHZ6CIJ.GHZBCJ:.J
MHZNCK*.MHZZCKZ.PH[&CLJ.SH[2CM:.VH[>CN*.YH[JC````````````````
MZ<?JQ^O'[,?MQ^['[\?PQ_''\L<``````````````````````````//'],?U
MQ_;']\?XQ_G'^L?[Q_S'````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!WH@``>*(```````````````````````!ZH@```````'NB````````
M?*(```````!]H@```````'6B``````````````````!TH@``````````````
M````<Z(``````````````````'*B``````````````````!QH@``````````
M````````````````````````````````````````I*(`````````````````
M`````````````````*6B`````*>B`````````````````````*:B`````'ZB
MH:*CHJ*BK**MHJZB``````````````````````````````````!BHF.B9*)E
MHF:B9Z)HHFFB<*)OHFZB;:)LHFNB:J(``````````':B>:(`````````````
M`````````````+VAO*$`````````````````````````````````````````
M`+:AM:$`````````````````````OZ&^H0````````````````````"[H;JA
M````````LZ$`````MZ&TH0``````````````````````````````````````
M`````````*BBJ:*KHJJB````````````````````````````````````````
M``````````````````````````````````````````"YH;BA`````/.A````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````\*'RH?&A````````````````````````````````
M``!6H5BA````````I:&FH0````"GH:BA``````````!%H0````!,H4NA````
M`````````````````````````*RA`````*NA`````````````+"A`````,*A
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!*H@``P:$```````!+
MH@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"YHKJBNZ*\
MHKVBOJ*_HL"BP:+"H@``````````````````````````````````````````
M``````````````````````````````````````````````````````````#V
MH?2A]Z'UH0````#XH?FA^Z'ZH0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#4H0```````-NAZ*'GH0````#]H0``_*$```````#DH>6A[*$`````
M[:$`````````````[Z'NH0```````````````..A````````````````````
M````````````````````````````````````W*$`````````````````````
M`````````````-JAW:$``````````-BAV:$`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````.:A````````````````````````````````````````
M``````````````````````````#IH0```````+ZC``"\H[VCOZ,`````````
M`````````````````````````+NC````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1*-%HT:C1Z-(HTFC2J-+HTRC
M3:-.HT^C4*-1HU*C4Z-4HP``5:-6HU>C6*-9HUJC6Z,`````````````````
M`%RC7:->HU^C8*-AHV*C8Z-DHV6C9J-GHVBC::-JHVNC;*,``&VC;J-OHW"C
M<:-RHW.C````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"SQP``````````````````````
M`````````````````````````+''LL>TQ[7'ML>WQ[C'N<>ZQP``````````
M`````+O'O,>]Q[['O\?`Q\''PL?#Q\3'Q<?&Q\?'R,?)Q\K'R\?,Q\W'S\?0
MQ]''TL?3Q]3'U<?6Q]?'V,?9Q]K'V\?<Q]W'WL??Q^#'X<?BQ^/'Y,?EQ^;'
MY\?HQP``SL<`````````````1J)'H@``1*(``+&A````````````````````
M`%BBTZ$`````````````4*$`````````````````````````````````````
M`````````````````````````````````````````````-&A````````````
M````````````````````````````````````````````````````````````
M``````````#2H0``````````````````````````0DY<3O51&E."4P=.#$Y'
M3HU.UU8,^FY<<U\/3H=1#DXN3I-.PD[)3LA.F%'\4FQ3N5,@5P-9+%D07/]=
MX66S:\QK%&P_<C%./$[H3MQ.Z4[A3MU.VDX,4AQ33%,B5R-7%UDO68%;A%L2
M7#M<=%QS7`1>@%Z"7LE?"6)08A5L````````````````````````````````
M```````````````````````````````````````````````````````````V
M;$-L/VP[;*YRL'**<[AYBH`>E@Y/&$\L3_5.%$_Q3@!/]TX(3QU/`D\%3R)/
M$T\$3_1.$D^Q41-2"5(04J92(E,?4TU3BE,'5.%6WU8N5RI7-%<\68!9?%F%
M67M9?EEW67]95EL57"5<?%QZ7'M<?ES?775>A%X"7QI?=%_57]1?SU]<8EYB
M9&)A8F9B8F)98F!B6F)E8N]E[F4^9SEG.&<[9SIG/V<\9S-G&&Q&;%)L7&Q/
M;$IL5&Q+;```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!,;'%P7G*T<K5RCG,J=7]V=7I1?WB"?(*`@GV"?X)-AGZ)F9"7D)B0FY"4
MD"*6))8@EB.65D\[3V)/24]33V1//D]G3U)/7T]!3UA/+4\S3S]/84^/4;E1
M'%(>4B%2K5*N4@E38U-R4XY3CU,P5#=4*E145$54&50<5"54&%0`````````
M````````````````````````````````````````````````````````````
M`````````````````````#U43U1!5"A4)%1'5.Y6YU;E5D%715=,5TE72U=2
M5P990%FF69A9H%F768Y9HEF068]9IUFA68Y;DELH7"I<C5R/7(A<BUR)7))<
MBER&7)-<E5S@70I>#EZ+7HE>C%Z(7HU>!5\=7WA?=E_27]%?T%_M7^A?[E_S
M7^%?Y%_C7_I?[U_W7_M?`&#T7SIB@V*,8HYBCV*48H=B<6)[8GIB<&*!8HAB
M=V)]8G)B=&(W9?!E]&7S9?)E]65%9T=G````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````%EG56=,9TAG76=-9UIG2V?0:QEL&FQX;&=L
M:VR$;(MLCVQQ;&]L:6R:;&ULAVR5;)QL9FQS;&5L>VR.;'1P>G!C<K]RO7+#
M<L9RP7*Z<L5RE7.7<Y-SE'.2<SIU.764=95U@78]>32`E8"9@)"`DH"<@)""
MCX*%@HZ"D8*3@@``````````````````````````````````````````````
M````````````````````````````````````````````BH*#@H2">(S)C[^/
MGY"AD*60GI"GD*"0,)8HEB^6+98S3IA/?$^%3WU/@$^'3W9/=$^)3X1/=T],
M3Y=/:D^:3WE/@4]X3Y!/G$^43YY/DD^"3Y5/:T]N3YY1O%&^4352,E(S4D92
M,5*\4@I3"U,\4Y)3E%.'5']4@5215()4B%1K5'I4?E1E5&Q4=%1F5(U4;U1A
M5&!4F%1C5&=49%3W5OE6;U=R5VU7:U=Q5W!7=E>`5W57>U=S5W178E<`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````:%=]5PQ915FU
M6;I9SUG.6;)9S%G!6;99O%G#6=99L5F]6<!9R%FT6<=98EME6Y-;E5M$7$=<
MKERD7*!<M5RO7*A<K%R?7*-<K5RB7*I<IUR=7*5<MERP7*9<%UX47AE>*%\B
M7R-?)%]47X)??E]]7]Y?Y5\M8"9@&6`R8`M@````````````````````````
M````````````````````````````````````````````````````````````
M```````T8`I@%V`S8!I@'F`L8")@#6`08"Y@$V`18`Q@"6`<8!1B/6*M8K1B
MT6*^8JIBMF+*8JYBLV*O8KMBJ6*P8KAB/66H9;ME"6;\901F$F8(9OME`V8+
M9@UF!6;]91%F$&;V9@IGA6=L9XYGDF=V9WMGF&>&9X1G=&>-9XQG>F>?9Y%G
MF6>#9WUG@6=X9WEGE&<E:X!K?FO>:QULDVSL;.ML[FS9;+9LU&RM;.=LMVS0
M;,)LNFS#;,9L[6SR;```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#2;-ULM&R*;)UL@&S>;,!L,&W-;,=LL&SY;,]LZ6S1;)1PF'"%
M<)-PAG"$<)%PEG""<)IP@W!J<M9RRW+8<LERW'+2<M1RVG+,<M%RI'.A<ZUS
MIG.B<Z!SK'.=<]UTZ'0_=4!U/G6,=9AUKW;S=O%V\';U=OAW_'?Y=_MW^G<`
M````````````````````````````````````````````````````````````
M`````````````````````````````/=W0GD_><5Y>'I[>OMZ=7S]?#6`CX"N
M@*.`N("U@*V`((*@@L""JX*:@IB"FX*U@J>"KH*\@IZ"NH*T@JB"H8*I@L*"
MI(+#@K:"HH)PAF^&;89NAE:,TH_+C]./S8_6C]6/UX^RD+20KY"SD+"0.98]
MECR6.I9#ELU/Q4_33[)/R4_+3\%/U$_<3]E/NT^S3]M/QT_63[I/P$^Y3^Q/
M1%))4L!2PE(]4WQ3EU.64YE3F%.Z5*%4K52E5,]4````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````,-4#8.W5*Y4UE2V5,54QE2@5'!4
MO%2B5+Y4<E3>5+!4M5>>5Y]7I%>,5Y=7G5>;5Y17F%>/5YE7I5>:5Y57]%@-
M65-9X5G>6>Y9`%KQ6=U9^EG]6?Q9]EGD6?)9]UG;6>E9\UGU6>!9_EGT6>U9
MJ%M,7-!<V%S,7-=<RUS;7```````````````````````````````````````
M````````````````````````````````````````````````````WES:7,E<
MQUS*7-9<TUS47,]<R%S&7,Y<WUSX7/E=(5XB7B->(%XD7K!>I%ZB7IM>HUZE
M7@=?+E]67X9?-V`Y8%1@<F!>8$5@4V!'8$E@6V!,8$!@0F!?8"1@1&!88&9@
M;F!"8D-BSV(-8PMC]6(.8P-CZV+Y8@]C#&/X8O9B`&,38Q1C^F(58_MB\&)!
M94-EJF6_939F(68R9C5F'&8F9B)F,V8K9CIF'68T9CEF+F8/9Q!GP6?R9\AG
MNF<`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````W&>[
M9_AGV&?`9[=GQ6?K9^1GWV>U9\UGLV?W9_9G[F?C9\)GN6?.9^=G\&>R9_QG
MQF?M9\QGKF?F9]MG^F?)9\IGPV?J9\MG*&N":X1KMFO6:]AKX&L@;"%L*&TT
M;2UM'VT\;3]M$FT*;=IL,VT$;1EM.FT:;1%M`&T=;4)M````````````````
M````````````````````````````````````````````````````````````
M```````````````!;1AM-VT#;0]M0&T';2!M+&T(;2)M"6T0;;=PGW"^<+%P
ML'"A<+1PM7"I<$%R27)*<FQR<')S<FYRRG+D<NARZW+?<NIRYG+C<H5SS'/"
M<\ASQ7.Y<[9SM7.T<^MSOW/'<[YSPW/&<[ASRW/L=.YT+G5'=4AUIW6J=7EV
MQ'8(=P-W!'<%=PIW]W;[=OIVYW?H=P9X$7@2>`5X$'@/>`YX"7@#>!-X2GE,
M>4MY17E$>=5YS7G/>=9YSGF`>@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!^>M%Z`'L!>WI\>'QY?']\@'R!?`-]"'T!?5A_D7^-
M?[Y_!X`.@`^`%(`W@-B`QX#@@-&`R(#"@-"`Q8#C@-F`W(#*@-6`R8#/@->`
MYH#-@/^!(8*4@MF"_H+Y@@>#Z((`@]6".H/K@M:"](+L@N&"\H+U@@R#^X+V
M@O""ZH(`````````````````````````````````````````````````````
M`````````````````````````````````````.2"X(+Z@O."[8)WAG2&?(9S
MAD&(3HAGB&J(:8C3B02*!XIRC>./X8_NC^"/\9"]D+^0U9#%D+Z0QY#+D,B0
MU)'3D5263Y91EE.62I9.EAY0!5`'4!-0(E`P4!M0]4_T3S-0-U`L4/9/]T\7
M4!Q0(%`G4#50+U`Q4`Y06E&449-1RE'$4<51R%'.46%26E)24EY27U)54F)2
MS5(.4YY3)E7B5!=5$E7G5/-4Y%0:5?]4!%4(5>M4$54%5?%4````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````I5^U3W5/A4X%0.50-5
M"U4!5P)7S%<R6-57TE>Z5\97O5>\5[A7ME>_5\=7T%>Y5\%7#EE*61E:%EHM
M6BY:%5H/6A=:"EH>6C-:;%NG6ZU;K%L#7%9<5%SL7/]<[ESQ7/=<`%WY7"E>
M*%ZH7JY>JEZL7C-?,%]G7UU@6F!G8```````````````````````````````
M````````````````````````````````````````````````````````````
M06"B8(A@@&"28(%@G6"#8)5@FV"78(=@G&".8!EB1F+R8A!C5F,L8T1C16,V
M8T-CY&,Y8TMC2F,\8REC06,T8UAC5&-98RUC1V,S8UIC46,X8U=C0&-(8TIE
M1F7&9<-EQ&7"94IF7V9'9E%F$F<39Q]H&FA):#)H,V@[:$MH3V@6:#%H'&@U
M:"MH+6@O:$YH1&@T:!UH$F@4:"9H*&@N:$UH.F@E:"!H+&LO:RUK,6LT:VUK
M@H"(:^9KY&L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````Z&OC:^)KYVLE;'IM8VUD;79M#6UA;9)M6&UB;6UM;VV1;8UM[VU_;89M
M7FUG;6!MEVUP;7QM7VV";9AM+VUH;8MM?FV`;81M%FV#;7MM?6UU;9!MW'#3
M<-%PW7#+<#E_XG#7<-)PWG#@<-1PS7#%<,9PQW#:<,YPX7!"<GAR````````
M````````````````````````````````````````````````````````````
M``````````````````````!W<G9R`'/Z<O1R_G+V<O-R^W(!<]-SV7/E<]9S
MO'/G<^-SZ7/<<])SVW/4<]USVG/7<]ASZ'/>=-]T]'3U="%U6W5?=;!UP76[
M=<1UP'6_=;9UNG6*=LEV'7<;=Q!W$W<2=R-W$7<5=QEW&G<B=R=W(W@L>")X
M-7@O>"AX+G@K>"%X*7@S>"IX,7A4>5MY3WE<>5-Y4GE1>>MY['G@>>YY[7GJ
M>=QYWGG=>89ZB7J%>HMZC'J*>H=ZV'H0>P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````$>Q-[!7L/>PA["GL.>PE[$GN$?)%\BGR,
M?(A\C7R%?!Y]'7T1?0Y]&'T6?1-]'WT2?0]]#'U<?V%_7G]@?UU_6W^6?Y)_
MPW_"?\!_%H`^@#F`^H#R@/F`]8`!@?N``($!@B^")8(S@RV#1(,9@U&#)8-6
M@S^#08,F@QR#(H,`````````````````````````````````````````````
M`````````````````````````````````````````````$*#3H,;@RJ#"(,\
M@TV#%H,D@R"#-X,O@RF#1X-%@TR#4X,>@RR#2X,G@TB#4X92AJ*&J(:6AHV&
MD8:>AH>&EX:&AHN&FH:%AJ6&F8:AAJ>&E8:8AHZ&G8:0AI2&0XA$B&V(=8AV
MB'*(@(AQB'^(;XB#B'Z(=(A\B!**1XQ7C'N,I(RCC':->(VUC;>-MHW1CM..
M_H_UCP*0_X_[CP20_(_VC]:0X)#9D-J0XY#?D.60V)#;D->0W)#DD%"1````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$Z13Y'5D>*1
MVI%<EE^6O);CF-^:+YM_3G!0:E!A4%Y08%!34$M075!R4$A035!!4%M02E!B
M4!5015!?4&E0:U!C4&101E!`4&Y0<U!74%%0T%%K4FU2;%)N4M92TU(M4YQ3
M=55V53Q535505315*E5156)5-E4U53!54E5%50``````````````````````
M````````````````````````````````````````````````````````````
M````````#%4R56553E4Y54A5+54[54!52U4*5P=7^U<46.)7]E?<5_17`%CM
M5_U7"%CX5PM8\U?/5P=8[E?C5_)7Y5?L5^%7#EC\5Q!8YU<!6`Q8\5?I5_!7
M#5@$6%Q98%I86E5:9UI>6CA:-5IM6E!:7UIE6FQ:4UID6E=:0UI=6E):1%I;
M6DA:CEH^6DU:.5I,6G!::5I'6E%:5EI"6EQ:<EMN6\%;P%M97!Y="UT=71I=
M(%T,72A=#5TF725=#UT`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````,%T272-='UTN73Y>-%ZQ7K1>N5ZR7K->-E\X7YM?EE^?7XI@
MD&"&8+Y@L&"Z8--@U&#/8.1@V6#=8,A@L6#;8+=@RF"_8,-@S6#`8#)C96.*
M8X)C?6.]8YYCK6.=8Y=CJV..8V]CAV.08VYCKV-U8YQC;6.N8WQCI&,[8Y]C
M````````````````````````````````````````````````````````````
M``````````````````````````````!X8X5C@6.18XUC<&-39<UE969A9EMF
M669<9F)F&&=Y:(=HD&B<:&UH;FBN:*MH5FEO:*-HK&BI:'5H=&BR:(]H=VB2
M:'QH:VAR:*IH@&AQ:'YHFVB6:(MHH&B):*1H>&A[:)%HC&B*:'UH-FLS:S=K
M.&N1:X]KC6N.:XQK*FS`;:MMM&VS;71NK&WI;>)MMVWV;=1M`&[(;>!MWVW6
M;;YMY6W<;=UMVVWT;<IMO6WM;?!MNFW5;<)MSVW);0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#0;?)MTVW];==MS6WC;;MM^G`-
M<?=P%W'T<`QQ\'`$<?-P$''\</]P!G$3<0!Q^'#V<`MQ`G$.<7YR>W)\<G]R
M'7,7<P=S$7,8<PIS"'/_<@]S'G.(<_9S^'/U<P1T`73]<P=T`'3Z<_QS_W,,
M=`MT]',(=&1U8W7.==)USW4`````````````````````````````````````
M`````````````````````````````````````````````````````,MUS'71
M==!UCW:)=M-V.7<O=RUW,7<R=S1W,W<]=R5W.W<U=TAX4GA)>$UX2GA,>"9X
M17A0>&1Y9WEI>6IY8WEK>6%YNWGZ>?AY]GGW>8]ZE'J0>C5[1WLT>R5[,'LB
M>R1[,WL8>RI['7LQ>RM[+7LO>S)[.'L:>R-[E'R8?)9\HWPU?3U].'TV?3I]
M17TL?2E]07U'?3Y]/WU*?3M]*'UC?Y5_G'^=?YM_RG_+?\U_T'_1?\=_SW_)
M?Q^`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````!Z`
M&X!'@$.`2(`8@26!&8$;@2V!'X$L@1Z!(8$5@2>!'8$B@1&".((S@CJ"-((R
M@G2"D(.C@ZB#C8-Z@W.#I(-T@X^#@8.5@YF#=8.4@ZF#?8.#@XR#G8.;@ZJ#
MBX-^@Z6#KX.(@Y>#L(-_@Z:#AX.N@W:#FH-9AE:&OX:WA@``````````````
M````````````````````````````````````````````````````````````
M````````````````PH;!AL6&NH:PALB&N8:SAKB&S(:TAKN&O(;#AKV&OH92
MB(F(E8BHB**(JHB:B)&(H8B?B)B(IXB9B)N(EXBDB*R(C(B3B(Z(@HG6B=F)
MU8DPBB>*+(H>BCF,.XQ<C%V,?8REC'V->XUYC;R-PHVYC;^-P8W8CMZ.W8[<
MCM>.X([ACB20"Y`1D!R0#)`AD.^0ZI#PD/20\I#SD-20ZY#LD.F05I%8D5J1
M4Y%5D>R1])'QD?.1^)'DD?F1ZI$`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````ZY'WD>B1[I%ZE8:5B)5\EFV6:Y9QEF^6OY9JEP28
MY9B7F9M0E5"44)Y0BU"C4(-0C%".4)U0:%"<4))0@E"'4%]1U%$24Q%3I%.G
M4Y%5J%6E5:U5=U5%5J)5DU6(58]5M56!5:-5DE6D57U5C%6F57]5E56A58Y5
M#%<I6#=8````````````````````````````````````````````````````
M```````````````````````````````````````96!Y8)U@C6"A8]5=(6"58
M'%@;6#-8/U@V6"Y8.5@X6"U8+%@[6&%9KUJ46I]:>EJB6IY:>%JF6GQ:I5JL
M6I5:KEHW6H1:BEJ76H-:BUJI6GM:?5J,6IQ:CUJ36IU:ZEO-6\M;U%O16\I;
MSEL,7#!<-UU#76M=05U+73]=-5U174Y=55TS73I=4ET]73%=65U"73E=25TX
M73Q=,ETV74!=15U$7D%>6%^F7Z5?JU_)8+E@S&#B8,Y@Q&`480``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#R8`IA%F$%8?5@$V'X
M8/Q@_F#!8`-A&&$=81!A_V`$80MA2F*48[%CL&/.8^5CZ&/O8\-CG63S8\IC
MX&/V8]5C\F/U8V%DWV.^8]UCW&/$8]ACTV/"8\=CS&/+8\AC\&/78]EC,F5G
M96IE9&5<96AE966,99UEGF6N9=!ETF4`````````````````````````````
M````````````````````````````````````````````````````````````
M`'QF;&9[9H!F<69Y9FIF<F8!9PQITV@$:=QH*FGL:.IH\6@/:=9H]VCK:.1H
M]F@3:1!I\VCA:`=IS&@(:7!IM&@1:>]HQF@4:?AHT&C]:/QHZ&@+:0II%VG.
M:,AHW6C>:.9H]&C1:`9IU&CI:!5I)6G':#EK.VL_:SQKE&N7:YEKE6N]:_!K
M\FOS:S!L_&U&;D=N'VY);HAN/&X];D5N8FXK;C]N06Y=;G-N'&XS;DMN0&Y1
M;CMN`VXN;EYN````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````&AN7&YA;C%N*&Y@;G%N:VXY;B)N,&Y3;F5N)VYX;F1N=VY5;GEN4FYF
M;C5N-FY:;B!Q'G$O<?MP+G$Q<2-Q)7$B<3)Q'W$H<3IQ&W%+<EIRB'*)<H9R
MA7*+<A)S"W,P<R)S,7,S<R=S,G,M<R9S(W,U<PQS+G0L=#!T*W06=```````
M````````````````````````````````````````````````````````````
M````````````````````````&G0A="UT,70D="-T'70I="!T,G3[="]U;W5L
M=>=UVG7A=>9UW77?=>1UUW65=I)VVG9&=T=W1'=-=T5W2G=.=TMW3'?>=^QW
M8'AD>&5X7'AM>'%X:GAN>'!X:7AH>%YX8GAT>7-Y<GEP>0)Z"GH#>@QZ!'J9
M>N9ZY'I*>SM[1'M(>TQ[3GM`>UA[17NB?)Y\J'RA?%A];WUC?5-]5GUG?6I]
M3WUM?5Q]:WU2?51]:7U1?5]]3GT^?S]_97\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````9G^B?Z!_H7_7?U&`3X!0@/Z`U(!#@4J!
M4H%/@4>!/8%-@3J!YH'N@?>!^('Y@02"/((]@C^"=8([@\^#^8,CA,"#Z(,2
MA.>#Y(/\@_:#$(3&@\B#ZX/C@[^#`83=@^6#V(/_@^&#RX/.@]:#]8/)@PF$
M#X3>@Q&$!H3"@_.#````````````````````````````````````````````
M``````````````````````````````````````````````#5@_J#QX/1@^J#
M$X3#@^R#[H/$@_N#UX/B@QN$VX/^@]B&XH;FAM.&XX;:ANJ&W8;KAMR&[(;I
MAM>&Z(;1ADB(5HA5B+J(UXBYB+B(P(B^B+:(O(BWB+V(LH@!B<F(E8F8B9>)
MW8G:B=N)3HI-BCF*68I`BE>*6(I$BD6*4HI(BE&*2HI,BD^*7XR!C(",NHR^
MC+",N8RUC(2-@(V)C=B-TXW-C<>-UHW<C<^-U8W9C<B-UXW%C>^.]X[ZC@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#YCN:.[H[E
MCO6.YX[HCO:.ZX[QCNR.]([ICBV0-)`OD`:1+)$$D?^0_)`(D?F0^Y`!D0"1
M!Y$%D0.189%DD5^18I%@D0&2"I(ED@.2&I(FD@^2#)(`DA*2_Y']D0:2!)(G
MD@*2')(DDAF2%Y(%DA:2>Y6-E8R5D)6'EGZ6B)8`````````````````````
M````````````````````````````````````````````````````````````
M`````````(F6@Y:`EL*6R);#EO&6\)9LEW"7;I<'F*F8ZYCFG/F>@TZ$3K9.
MO5"_4,90KE#$4,I0M%#(4,)0L%#!4+I0L5#+4,E0ME"X4-=1>E)X4GM2?%+#
M5=M5S%705<M5RE7=5<!5U%7$5>E5OU7258U5SU755>)5UE7(5?)5S5795<)5
M%%=36&A89%A/6$U825AO6%583EA=6%E895A;6#U88UAQ6/Q8QUK$6LM:NEJX
M6K%:M5JP6K]:R%J[6L9:````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````+=:P%K*6K1:MEK-6KE:D%K66]A;V5L?7#-<<5UC74I=95UR
M76Q=7EUH76==8EWP74]>3EY*7DU>2U[%7LQ>QE[+7L=>0%^O7ZU?]V!)84IA
M*V%%839A,F$N849A+V%/82EA0&$@8FB1(V(E8B1BQ6/Q8^MC$&029`ED(&0D
M9```````````````````````````````````````````````````````````
M````````````````````````````````,V1#9!]D%6089#ED-V0B9"-D#&0F
M9#!D*&1!9#5D+V0*9!ID0&0E9"=D"V3G8QMD+F0A9`YD;V629=-EAF:,9I5F
MD&:+9HIFF6:49GAF(&=F:5]I.&E.:6)I<6D_:45I:FDY:4)I5VE9:7II2&E)
M:35I;&DS:3UI96GP:'AI-&EI:4!I;VE$:79I6&E!:71I3&D[:4MI-VE<:4]I
M46DR:5)I+VE[:3QI1FM%:T-K0FM(:T%KFVL-^OMK_&L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````^6OW:_AKFV[6;LANCV[`;I]N
MDVZ4;J!NL6ZY;L9NTFZ];L%NGF[);K=NL&[-;J9NSVZR;KYNPV[<;MANF6Z2
M;HYNC6ZD;J%NOVZS;M!NRFZ7;JYNHVY'<51Q4G%C<6!Q07%=<6)Q<G%X<6IQ
M87%"<5AQ0W%+<7!Q7W%0<5-Q````````````````````````````````````
M``````````````````````````````````````````````````````!$<4UQ
M6G%/<HURC'*1<I!RCG(\<T)S.W,Z<T!S2G-)<T1T2G1+=%)T4717=$!T3W10
M=$YT0G1&=$UT5'3A=/]T_G3]=!UU>75W=8-I[W4/=@-V]W7^=?QU^77X=1!V
M^W7V=>UU]77]=9EVM7;==E5W7W=@=U)W5G=:=VEW9W=4=UEW;7?@=X=XFGB4
M>(]XA'B5>(5XAGBA>(-X>7B9>(!XEGA[>'QY@GE]>7EY$7H8>AEZ$GH7>A5Z
M(GH3>@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````;
M>A!ZHWJB>IYZZWIF>V1[;7MT>VE[<GME>W-[<7MP>V%[>'MV>V-[LGRT?*]\
MB'V&?8!]C7U_?85]>GV.?7M]@WU\?8Q]E'V$?7U]DGUM?VM_9W]H?VQ_IG^E
M?Z=_VW_<?R&`9(%@@7>!7(%I@5N!8H%R@2%G7H%V@6>!;X$`````````````
M````````````````````````````````````````````````````````````
M`````````````````$2!88$=@DF"1()`@D*"18+QA#^$5H1VA'F$CX2-A&6$
M481`A(:$9X0PA$V$?81:A%F$=(1SA%V$!X5>A#>$.H0TA'J$0X1XA#*$180I
MA-F#2X0OA$*$+81?A'"$.81.A$R$4H1OA,6$CH0[A$>$-H0SA&B$?H1$A"N$
M8(14A&Z$4(0+AP2']X8,A_J&UH;UADV'^(8.APF'`8?VA@V'!8?6B,N(S8C.
MB-Z(VXC:B,R(T(B%B9N)WXGEB>2)````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````.&)X(GBB=R)YHEVBH:*?XIABC^*=XJ"BH2*=8J#
MBH&*=(IZBCR,2XQ*C&6,9(QFC(:,A(R%C,R,:(UIC9&-C(V.C8^-C8V3C92-
MD(V2C?"-X(WLC?&-[HW0C>F-XXWBC>>-\HWKC?2-!H__C@&/`(\%CP>/"(\"
MCPN/4I`_D```````````````````````````````````````````````````
M````````````````````````````````````````1)!)D#V0$)$-D0^1$9$6
MD121"Y$.D6Z1;Y%(DE*2,)(ZDF:2,Y)EDEZ2@Y(NDDJ21I)MDFR23Y)@DF>2
M;Y(VDF&2<)(QDE228Y)0DG*23I)3DDR25I(RDI^5G)6>E9N5DI:3EI&6EY;.
MEOJ6_9;XEO66<Y=WEWB7<I</F`V8#IBLF/:8^9BOF;*9L)FUF:V:JYI;F^J<
M[9SGG(">_9[F4-10UU#H4/-0VU#J4-U0Y%#34.Q0\%#O4.-0X%``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````V%&`4H%2Z5+K4C!3
MK%,G5A56#%825OQ5#U8<5@%6$U8"5OI5'58$5O]5^56)6'Q8D%B86(98@5A_
M6'18BUAZ6(=8D5B.6'98@EB(6'M8E%B/6/Y8:UG<6NY:Y5K56NI:VEKM6NM:
M\UKB6N!:VUKL6MY:W5K96NA:WUIW6^!;````````````````````````````
M````````````````````````````````````````````````````````````
M``#C6V-<@EV`77U=AEUZ78%==UV*78E=B%U^77Q=C5UY77]=6%Y97E->V%[1
M7M=>SE[<7M5>V5[27M1>1%]#7V]?ME\L82AA06%>87%A<V%285-A<F%L88!A
M=&%487IA6V%E83MA:F%A859A*6(G8BMB*V1-9%MD761T9'9D<F1S9'UD=61F
M9*9D3F2"9%YD7&1+9%-D8&109']D/V1L9&MD661E9'=D<V6@9:%FH&:?9@5G
M!&<B9[%IMFG):0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"@:<YIEFFP::QIO&F1:9EICFFG:8UIJ6F^::]IOVG$:;UII&G4:;EI
MRFF::<]ILVF3::IIH6F>:=EIEVF0:<)IM6FE:<9I2FM-:TMKGFN?:Z!KPVO$
M:_YKSF[U;O%N`V\E;_AN-V_[;BYO"6].;QEO&F\G;QAO.V\2;^UN"F\`````
M````````````````````````````````````````````````````````````
M`````````````````````````#9O<V_Y;NYN+6]`;S!O/&\U;^MN!V\.;T-O
M!6_];O9N.6\<;_QN.F\?;PUO'F\(;R%OAW&0<8EQ@'&%<8)QCW%[<89Q@7&7
M<41R4W*7<I5RDW)#<TUS47-,<V)T<W1Q='5T<G1G=&YT`'4"=0-U?760=19V
M"'8,=A5V$78*=A1VN':!=WQWA7>"=VYW@'=O=WYW@W>R>*IXM'BM>*AX?GBK
M>)YXI7B@>*QXHGBD>)AYBGF+>99YE7F4>9-Y````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````)=YB'F2>9!Y*WI*>C!Z+WHH>B9ZJ'JK
M>JQZ[GJ(>YQ[BGN1>Y![EGN->XQ[FWN.>X5[F'N$4IE[I'N">[M\OWR\?+I\
MIWVW?<)]HWVJ?<%]P'W%?9U]SGW$?<9]RWW,?:]]N7V6?;Q]GWVF?:Y]J7VA
M?<E]<W_B?^-_Y7_>?P``````````````````````````````````````````
M````````````````````````````````````````````````)(!=@%R`B8&&
M@8.!AX&-@8R!BX$5@I>$I(2AA)^$NH3.A,*$K(2NA*N$N82TA,&$S82JA)J$
ML830A)V$IX2[A**$E(3'A,R$FX2IA*^$J(36A)B$MH3/A*"$UX34A-*$VX2P
MA)&$888SAR.'*(=KAT"'+H<>AR&'&8<;AT.'+(=!ASZ'1H<@AS*'*H<MASR'
M$H<ZAS&'-8="AR:')X<XAR2'&H<PAQ&']XCGB/&(\HCZB/Z([HC\B/:(^X@`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````\(CLB.N(
MG8FAB9^)GHGIB>N)Z(FKBIF*BXJ2BH^*EHH]C&B,:8S5C,^,UXR6C0F.`H[_
MC0V._8T*C@..!XX&C@6._HT`C@2.$(\1CPZ/#8\CD1R1()$BD1^1'9$:D221
M(9$;D7J1<I%YD7.1I9*DDG:2FY)ZDJ"2E)*JDHV2````````````````````
M````````````````````````````````````````````````````````````
M``````````"FDIJ2JY)YDI>2?Y*CDNZ2CI*"DI62HI)]DHB2H9**DH:2C)*9
MDJ>2?I*'DJF2G9*+DBV2GI:AEO^66)=]EWJ7?I>#EX"7@I=[EX27@9=_E\Z7
MS9<6F*V8KI@"F0"9!YF=F9R9PYFYF;N9NIG"F;V9QYFQFN.:YYH^FS^;8)MA
MFU^;\9SRG/6<IY[_4`-1,%'X4`91!U'V4/Y0"U$,4?U0"E&+4HQ2\5+O4DA6
M0E9,5C56059*5DE61E985@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!:5D!6,U8]5BQ6/E8X5BI6.E8:5ZM8G5BQ6*!8HUBO6*Q8
MI5BA6/]8_UKT6OU:]UKV6@-;^%H"6_E:`5L'6P5;#UMG7)E=EUV?79)=HEV3
M795=H%V<7:%=FEV>76E>75Y@7EQ>\WW;7MY>X5Y)7[)?BV&#87EAL6&P8:)A
MB6$`````````````````````````````````````````````````````````
M`````````````````````````````````)MADV&O8:UAGV&28:IAH6&-869A
MLV$M8FYD<&269*!DA6279)QDCV2+9(IDC&2C9)]D:&2Q9)AD=F5Z97EE>V6R
M9;-EM6:P9JEFLF:W9JIFKV8`:@9J%VKE:?AI%6KQ:>1I(&K_:>QIXFD;:AUJ
M_FDG:O)I[FD4:O=IYVE`:@AJYFG[:0UJ_&GK:0EJ!&H8:B5J#VKV:29J!VKT
M:19J46NE:Z-KHFNF:P%L`&S_:P)L06\F;WYOAV_&;Y)O````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(UOB6^,;V)O3V^%;UIOEF]V
M;VQO@F]5;W)O4F]0;U=OE&^3;UUO`&]A;VMO?6]G;Y!O4V^+;VEO?V^5;V-O
M=V]J;WMOLG&O<9MQL'&@<9IQJ7&U<9UQI7&><:1QH7&J<9QQIW&S<9ARFG)8
M<U)S7G-?<V!S77-;<V%S6G-9<P``````````````````````````````````
M````````````````````````````````````````````````````````8G.'
M=(ETBG2&=(%T?72%=(AT?'1Y=`AU!W5^=25V'G89=AUV''8C=AIV*'8;=IQV
MG7:>=IMVC7>/=XEWB'?->+MXSWC,>-%XSGC4>,AXPWC$>,EXFGFA>:!YG'FB
M>9MY=FLY>K)ZM'JS>K=[RWN^>ZQ[SGNO>[E[RGNU>\5\R'S,?,M\]WW;?>I]
MYWW7?>%]`W[Z?>9]]GWQ??!][GW??79_K'^P?ZU_[7_K?^I_['_F?^A_9(!G
M@*.!GX$`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MGH&5@:*!F8&7@1:"3X)3@E*"4().@E&")(4[A0^%`(4IA0Z%"84-A1^%"H4G
MA1R%^X0KA?J$"(4,A?2$*H7RA!6%]X3KA/.$_(02A>J$Z806A?Z$*(4=A2Z%
M`H7]A!Z%]H0QA2:%YX3HA/"$[X3YA!B%((4PA0N%&84OA6*&````````````
M````````````````````````````````````````````````````````````
M``````````````````!6AV.'9(=WA^&'<X=8AU2'6X=2AV&'6H=1AUZ';8=J
MAU"'3H=?AUV';X=LAWJ';H=<AV6'3X=[AW6'8H=GAVF'6H@%B0R)%(D+B1>)
M&(D9B0:)%HD1B0Z)"8FBB:2)HXGMB?")[(G/BL:*N(K3BM&*U(K5BKN*UXJ^
MBL"*Q8K8BL.*NHJ]BMF*/HQ-C(^,Y8S?C-F,Z(S:C-V,YXR@C9R-H8V;C2".
M(XXECB2.+HX5CAN.%HX1CAF.)HXGC@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````4CA*.&(X3CAR.%XX:CBR/)(\8CQJ/((\CCQ:/
M%X]SD'"0;Y!GD&N0+Y$KD2F1*I$RD2:1+I&%D8:1BI&!D8*1A)&`D="2PY+$
MDL"2V9*VDL^2\9+?DMB2Z9+7DMV2S)+ODL*2Z)+*DLB2SI+FDLV2U9+)DN"2
MWI+GDM&2TY(`````````````````````````````````````````````````
M`````````````````````````````````````````+62X9+&DK22?)6LE:N5
MKI6PE:26HI;3E@67")<"EUJ7BI>.EXB7T)?/EQZ8'9@FF"F8*)@@F!N8)YBR
MF`B9^I@1F129%ID7F169W)G-F<^9TYG4F<Z9R9G6F=B9RYG7F<R9LYKLFNN:
M\YKRFO&:1IM#FV>;=)MQFV:;=IMUFW";:)MDFVR;_)SZG/V<_YSWG`>=`)WY
MG/N<")T%G02=@Y[3G@^?$)\<41-1%U$:41%1WE$T4^%3<%9@5FY6````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'-69E9C5FU6<E9>
M5G=6'%<;5\A8O5C)6+]8NEC"6+Q8QE@76QE;&ULA6Q1;$UL06Q9;*%L:6R!;
M'EOO6ZQ=L5VI7:==M5VP7:Y=JEVH7;)=K5VO7;1=9UYH7F9>;U[I7N=>YE[H
M7N5>2U^\7YUAJ&&68<5AM&'&8<%AS&&Z80``````````````````````````
M````````````````````````````````````````````````````````````
M````OV&X88QAUV369-!DSV3)9+UDB63#9-MD\V399#-E?V5\9:)ER&:^9L!F
MRF;+9L]FO6:[9KIFS&8C9S1J9FI):F=J,FIH:CYJ76IM:G9J6VI1:BAJ6FH[
M:C]J06IJ:F1J4&I/:E1J;VII:F!J/&I>:E9J56I-:DYJ1FI5:U1K5FNG:ZIK
MJVO(:\=K!&P#;`9LK6_+;Z-OQV^\;\YOR&]>;\1OO6^>;\IOJ&\$<*5OKF^Z
M;ZQOJF_/;[]ON&\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````HF_);ZMOS6^O;[)OL&_%<<)QOW&X<=9QP''!<<MQU''*<<=QSW&]
M<=AQO''&<=IQVW&=<IYR:7-F<V=S;'-E<VMS:G-_=)ITH'24=))TE72A=`MU
M@'4O=BUV,78]=C-V/'8U=C)V,':[=N9VFG>==Z%WG'>;=Z)WHW>5=YEW````
M````````````````````````````````````````````````````````````
M``````````````````````````"7=]UXZ7CE>.IXWGCC>-MXX7CB>.UXWWC@
M>*1Y1'I(>D=ZMGJX>K5ZL7JW>MY[XWOG>]U[U7OE>]I[Z'OY>]1[ZGOB>]Q[
MZWO8>]][TGS4?-=\T'S1?!)^(7X7?@Q^'WX@?A-^#GX<?A5^&GXB?@M^#WX6
M?@U^%'XE?B1^0W][?WQ_>G^Q?^]_*H`I@&R`L8&F@:Z!N8&U@:N!L(&L@;2!
MLH&W@:>!\H%5@E:"5X)6A46%:X5-A5.%8858A0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!`A4:%9(5!A6*%1(51A4>%8X4^A5N%
M<85.A6Z%=855A6>%8(6,A6:%7854A66%;(5CAF6&9(:;AX^'EX>3AY*'B(>!
MAY:'F(=YAX>'HX>%AY"'D8>=AX2'E(><AYJ'B8<>B2:),(DMB2Z))XDQB2*)
M*8DCB2^)+(D?B?&)X(H`````````````````````````````````````````
M`````````````````````````````````````````````````.**\HKTBO6*
MW8H4B^2*WXKPBLB*WHKABNB*_XKOBON*D8R2C)",]8SNC/&,\(SSC&R-;HVE
MC:>-,XX^CCB.0(Y%CC:./(X]CD&.,(X_CKV.-H\NCS6/,H\YCS>/-(]VD'F0
M>Y"&D/J0,Y$UD3:1DY&0D9&1C9&/D2>3'I,(DQ^3!I,/DWJ3.),\DQN3(Y,2
MDP&31I,MDPZ3#9/+DAV3^I(EDQ.3^9+WDC23`I,DD_^2*9,YDS63*I,4DPR3
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````N3_I()
MDP"3^Y(6D[R5S96^E;F5NI6VE;^5M96]E:F6U)8+EQ*7$)>9EY>7E)?PE_B7
M-9@OF#*8))D?F2>9*9F>F>Z9[)GEF>29\)GCF>J9Z9GGF;F:OYJTFKN:]IKZ
MFOF:]YHSFX";A9N'FWR;?IM[FX*;DYN2FY";>IN5FP``````````````````
M````````````````````````````````````````````````````````````
M````````````?9N(FR6=%YT@G1Z=%)TIG1V=&)TBG1"=&9T?G8B>AIZ'GJZ>
MK9[5GM:>^IX2GSV?)E$E42)1)%$@42E1]%*35HQ6C5:&5H16@U9^5H)6?U:!
M5M98U%C/6-)8+5LE6S);(ULL6R=;)ELO6RY;>UOQ6_);MUUL7FI>OE^[7\-A
MM6&\8>=AX&'E8>1AZ&'>8>]DZ63C9.MDY&3H9(%E@&6V9=IETF:-:I9J@6JE
M:HEJGVJ;:J%JGFJ':I-JCFH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````E6J#:JAJI&J1:G]JIFJ::H5JC&J2:EMKK6L);,QOJ6_T
M;]1OXV_<;^UOYV_F;]YO\F_=;^)OZ&_A<?%QZ''R<>1Q\''B<7-S;G-O<Y=T
MLG2K=)!TJG2M=+%TI72O=!!U$742=0]UA'5#=DAV279'=J1VZ7:U=ZMWLG>W
M=[9W````````````````````````````````````````````````````````
M``````````````````````````````````"T=[%WJ'?P=_-X_7@">?MX_'CR
M>`5Y^7C^>`1YJWFH>5QZ6WI6>EAZ5'I:>KYZP'K!>@5\#WSR>P!\_WO[>PY\
M]'L+?/-[`GP)?`-\`7SX>_U[!GSP>_%[$'P*?.A\+7X\?D)^,WY(F#A^*GY)
M?D!^1WXI?DQ^,'X[?C9^1'XZ?D5_?W]^?WU_]'_R?RR`NX'$@<R!RH'%@<>!
MO('I@5N"6H)<@H.%@(6/A:>%E86@A8N%HX5[A:2%FH6>A0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!WA7R%B86AA7J%>(57A8Z%
MEH6&A8V%F86=A8&%HH6"A8B%A85YA7:%F(60A9^%:(:^AZJ'K8?%A["'K(>Y
MA[6'O(>NA\F'PX?"A\R'MX>OA\2'RH>TA[:'OX>XA[V'WH>RAS6),XD\B3Z)
M08E2B3>)0HFMB:^)KHGRB?.)'HL`````````````````````````````````
M`````````````````````````````````````````````````````````!B+
M%HL1BP6+"XLBBP^+$HL5BP>+#8L(BP:+'(L3BQJ+3XQPC'*,<8QOC)6,E(SY
MC&^-3HY-CE..4(Y,CD>.0X]`CX60?I`XD9J1HI&;D9F1GY&AD9V1H)&ADX.3
MKY-DDU:31Y-\DUB37)-VDTF34)-1DV"3;9./DTR3:I-YDU>359-2DT^3<9-W
MDWN389->DV.39Y.`DTZ369/'E<"5R97#E<65MY6NEK"6K)8@EQ^7&)<=EQF7
MFI>AEYR7````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`)Z7G9?5E]27\9=!F$282IA)F$680Y@EF2N9+)DJF3.9,IDOF2V9,9DPF9B9
MHYFAF0*:^IGTF?>9^9GXF?:9^YG]F?Z9_)D#FKZ:_IK]F@&;_)I(FYJ;J)N>
MFYN;IINAFZ6;I)N&FZ*;H)NOFS.=09UGG3:=+ITOG3&=.)TPG0``````````
M````````````````````````````````````````````````````````````
M````````````````````19U"G4.=/ITWG4"=/9WU?RV=BIZ)GHV>L)[(GMJ>
M^Y[_GB2?(Y\BGU2?H)\Q42U1+E&85IQ6EU::5IU6F59P63Q;:5QJ7,!=;5YN
M7MAAWV'M8>YA\6'J8?!AZV'68>EA_V0$9?UD^&0!90-E_&249=MEVF;;9MAF
MQ6JY:KUJX6K&:KIJMFJW:L=JM&JM:EYKR6L+;`=P#'`-<`%P!7`4<`YP_V\`
M</MO)G#\;_=O"G`!<O]Q^7$#<OUQ=G,`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````N'3`=+5TP72^=+9TNW3"=!1U$W5<=F1V6790
M=E-V5W9:=J9VO7;L=L)WNG?_>`QY$WD4>0EY$'D2>1%YK7FL>5]Z''PI?!E\
M('P??"U\'7PF?"A\(GPE?#!\7'Y0?E9^8WY8?F)^7WY1?F!^5WY3?K5_LW_W
M?_A_=8#1@=*!````````````````````````````````````````````````
M``````````````````````````````````````````#0@5^"7H*TA<:%P(7#
MA<*%LX6UA;V%QX7$A;^%RX7.A<B%Q86QA;:%TH4DAKB%MX6^A6F&YX?FA^*'
MVX?KA^J'Y8??A_.'Y(?4A]R'TX?MA]B'XX>DA]>'V8<!B/2'Z(?=AU.)2XE/
MB4R)1HE0B5&)28DJBR>+(XLSBS"+-8M'BR^+/(L^BS&+)8LWBR:+-HLNBR2+
M.XL]BSJ+0HQUC)F,F(R7C/Z,!(T"C0"-7(YBCF".5XY6CEZ.98YGC@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!;CEJ.88Y=CFF.
M5(Y&CT>/2(]+CRB1.I$[D3Z1J)&ED:>1KY&JD;63C).2D[>3FY.=DXF3IY..
MDZJ3GI.FDY63B).9DY^3C9.QDY&3LI.DDZB3M).CDZ63TI73E=&5LY;7EMJ6
MPEW?EMB6W98CER*7)9>LEZZ7J)>KEZ27JI<`````````````````````````
M````````````````````````````````````````````````````````````
M`````**7I9?7E]F7UI?8E_J74)A1F%*8N)A!F3R9.ID/F@N:"9H-F@2:$9H*
MF@6:!YH&FL":W)H(FP2;!9LIFS6;2IM,FTN;QYO&F\.;OYO!F[6;N)O3F[:;
MQ)NYF[V;7)U3G4^=2IU;G4N=69U6G4R=5YU2G52=7YU8G5J=CIZ,GM^>`9\`
MGQ:?)9\KGRJ?*9\HGTR?59\T4351EE+W4K13JU:M5J96IU:J5JQ6VEC=6-M8
M$ED]6SY;/UO#77!>````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+]?^V$'91!E#64)90QE#F6$9=YEW67>9N=JX&K,:M%JV6K+:M]J
MW&K0:NMJSVK-:MYJ8&NP:PQL&7`G<"!P%G`K<"%P(G`C<"EP%W`D<!QP*G`,
M<@IR!W("<@5RI7*F<J1RHW*A<LMTQ72W=,-T%G5@=LEWRG?$=_%W'7D;>0``
M````````````````````````````````````````````````````````````
M````````````````````````````(7D<>1=Y'GFP>6=Z:'HS?#Q\.7PL?#M\
M['SJ?'9^=7YX?G!^=WYO?GI^<GYT?FA^2W]*?X-_AG^W?_U__G]X@->!U8%D
M@F&"8X+KA?&%[879A>&%Z(7:A=>%[(7RA?B%V(7?A>.%W(71A?"%YH7OA=Z%
MXH4`B/J'`XCVA_>'"8@,B`N(!HC\APB(_X<*B`*(8HE:B5N)5XEAB5R)6(E=
MB5F)B(FWB;:)]HE0BTB+2HM`BU.+5HM4BTN+58L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````48M"BU*+5XM#C'>,=HR:C`:-!XT)
MC:R-JHVMC:N-;8YXCG..:HYOCGN.PHY2CU&/3X]0CU./M(]`D3^1L)&MD=Z3
MQY//D\*3VI/0D_F3[)/,D]F3J9/FD\J3U)/ND^.3U9/$D\Z3P)/2D^>3?97:
ME=N5X98IERN7+)<HER:7````````````````````````````````````````
M``````````````````````````````````````````````````"SE[>7MI?=
ME]Z7WY=<F%F879A7F+^8O9B[F+Z82)E'F4.9IIFGF1J:%9HEFAV:))H;FB*:
M()HGFB.:'IH<FA2:PIH+FPJ;#IL,FS>;ZIOKF^";WIODF^:;XIOPF]2;UYOL
MF]R;V9OEF]6;X9O:FW>=@9V*G82=B)UQG8"=>)V&G8N=C)U]G6N==)UUG7"=
M:9V%G7.=>YV"G6^=>9U_G8>=:)V4GI&>P)[\GBV?0)]!GTV?5I]7GUB?-U.R
M5@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"U5K-6
MXUA%6\9=QUWN7N]>P%_!7_EA%V46915E$V7?9>AFXV;D9O-J\&KJ:NAJ^6KQ
M:NYJ[VH\<#5P+W`W<#1P,7!"<#AP/W`Z<#EP0'`[<#-P07`3<A1RJ')]<WQS
MNG2K=JIVOG;M=LQWSG?/=\UW\G<E>2-Y)WDH>21Y*7D`````````````````
M````````````````````````````````````````````````````````````
M`````````````+)Y;GIL>FUZ]WI)?$A\2GQ'?$5\[GQ[?GY^@7Z`?KI__W]Y
M@-N!V8$+@FB":8(BAO^%`8;^A1N&`(;VA02&"88%A@R&_849B!"($8@7B!.(
M%HACB6:)N8GWB6"+:HM=BVB+8XMEBV>+;8NNC8:.B(Z$CEF/5H]7CU6/6(]:
MCXV00Y%!D;>1M9&RD;.1"Y03E/N3()0/E!24_I,5E!"4*)09E`V4]9,`E/>3
M!Y0.E!:4$I3ZDPF4^),*E/^3````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/R3#)3VDQ&4!I3>E>"5WY4NER^7N9>[E_V7_I=@F&*8
M8YA?F,&8PIA0F4Z969E,F4N94YDRFC2:,9HLFBJ:-IHIFBZ:.)HMFL>:RIK&
MFA";$IL1FPN<")SWFP6<$ISXFT"<!YP.G`:<%YP4G`F<GYV9G:2=G9V2G9B=
MD)V;G0``````````````````````````````````````````````````````
M````````````````````````````````````H)V4G9R=JIV7G:&=FIVBG:B=
MGIVCG;^=J9V6G::=IYV9GIN>FI[EGN2>YY[FGC"?+I];GV"?7I]=GUF?D9\Z
M43E1F%*74L-6O5:^5DA;1UO+7<]=\5[]81ME`FO\:@-K^&H`:T-P1'!*<$AP
M27!%<$9P'7(:<AER?G,7=6IVT'<M>3%Y+WE4?%-\\GR*?H=^B'Z+?H9^C7Y-
M?[M_,(#=@1B&*H8FAA^&(X8<AAF&)X8NAB&&((8IAAZ&)88`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````*8@=B!N(((@DB!R(*XA*
MB&V):8ENB6N)^HEYBWB+18MZBWN+$(T4C:^-CHZ,CEZ/6X]=CT:11)%%D;F1
M/Y0[E#:4*90]E#R4,)0YE"J4-Y0LE$"4,93EE>25XY4UESJ7OY?AEV28R9C&
MF,"86)E6F3F:/9I&FD2:0II!FCJ:````````````````````````````````
M```````````````````````````````````````````````````````````_
MFLV:%9L7FQB;%ILZFU*;*YP=G!R<+)PCG"B<*9PDG"&<MYVVG;R=P9W'G<J=
MSYV^G<6=PYV[G;6=SIVYG;J=K)W(G;&=K9W,G;.=S9VRG7J>G)[KGNZ>[9X;
MGQB?&I\QGTZ?99]DGY*?N4[&5L56RU9Q64M;3%O57=%=\EXA92!E)F4B90MK
M"&L):PUL57!6<%=P4G`><A]RJ7)_<]ATU739=-=T;7:M=C5YM'EP>G%Z5WQ<
M?%E\6WQ:?```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#T?/%\D7Y/?X=_WH%K@C2&-88SABR&,H8VABR(*(@FB"J()8AQB;^)OHG[
MB7Z+A(N"BX:+A8M_BQ6-E8Z4CIJ.DHZ0CI:.EXY@CV*/1Y%,E%"42I1+E$^4
M1Y1%E$B4291&E#^7XY=JF&F8RYA4F5N93II3FE2:3)I/FDB:2IH`````````
M````````````````````````````````````````````````````````````
M`````````````````````$F:4II0FM":&9LKFSN;5IM5FT:<2)P_G$2<.9PS
MG$&</)PWG#2<,IP]G#:<VYW2G=Z=VIW+G="=W)W1G=^=Z9W9G=B=UIWUG=6=
MW9VVGO">-9\SGS*?0I]KGY6?HI\]49E2Z%CG6')935O872^(3U\!8@-B!&(I
M925EEF7K9A%K$FL/:\IK6W!:<")R@G.!<X-S<';4=V=\9GR5?FR".H9`ACF&
M/(8QACN&/H8PB#*(+H@SB':)=(ESB?Z)````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(R+CHN+BXB+18P9C9B.9(]CC[R18I15E%V4
M5Y1>E,27Q9<`F%::69H>FQ^;()M2G%B<4)Q*G$V<2YQ5G%F<3)Q.G/N=]YWO
MG>.=ZYWXG>2=]IWAG>Z=YIWRG?"=XIWLG?2=\YWHG>V=PI[0GO*>\YX&GQR?
M.)\WGS:?0Y]/GP``````````````````````````````````````````````
M````````````````````````````````````````````<9]PGVZ?;Y_35LU6
M3EMM7"UE[6;N9A-K7W!A<%UP8'`C<MMTY735=SAYMWFV>6I\EWZ)?VV"0X8X
MB#>(-8A+B)2+E8N>CI^.H(Z=CKZ1O9'"D6N4:)1IE.661I=#ET>7QY?EEUZ:
MU9I9FV.<9YQFG&*<7IQ@G`*>_IT'G@.>!IX%G@">`9X)GO^=_9T$GJ">'I]&
MGW2?=9]VG]16+F6X91AK&6L7:QIK8G`F<JIRV'?9=SEY:7QK?/9\FGX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````F'Z;?IE^X('A
M@4:&1X9(AGF)>HE\B7N)_XF8BYF+I8ZDCJ..;I1ME&^4<91SE$F7<IA?F6B<
M;IQMG`N>#9X0G@^>$IX1GJ&>]9X)GT>?>)][GWJ?>9\>5V9P;WP\B+*-IH[#
MD724>)1VE'648)ITG'.<<9QUG!2>$Y[VG@J?````````````````````````
M````````````````````````````````````````````````````````````
M``````"DGVAP97#W?&J&/H@]B#^(GHN<C*F.R8Y+EW.8=)C,F&&9JYEDFF::
M9YHDFQ6>%YY(GP=B'FLG<DR&J(Z"E("4@91IFFB:+IL9GBER2X:?BX.4>9RW
MGG5V:YIZG!V>:7!J<*2>?I])GYB?````````````````````````````,`S_
M`3`",`[_(B`;_QK_'_\!_S#^)B`E(%#^9/]2_K<`5/Y5_E;^5_Y<_Q,@,?X4
M(#/^_?\T_D_^"/\)_S7^-OY;_UW_-_XX_A0P%3`Y_CK^$#`1,#O^//X*,`LP
M/?X^_@@P"3`__D#^##`-,$'^0OX.,`\P0_Y$_EG^6OX`````````````````
M````````````````````````````````````````````````````````````
M`````````````%O^7/Y=_E[^&"`9(!P@'2`=,!XP-2`R(`/_!O\*_SL@IP`#
M,,LESR6S);(ESB4&)@4FQR7&):$EH"6]);PEHS(%(3X@_?\___W_2?Y*_DW^
M3OY+_DS^7_Y@_F'^"_\-_]<`]P"Q`!HB'/\>_QW_9B)G(F`B'B)2(F$B8OYC
M_F3^9?YF_CPB*2(J(J4B("(?(K\BTC/1,RLB+B(U(C0B0"9")D$F"2:1(9,A
MD"&2(98AER&9(9@A)2(C(OW_````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/W_#_\\_P3_I0`2,*(`HP`%_R#_`R$)(6G^:OYK_M4S
MG#.=,YXSSC.A,XXSCS/$,[``65%;45Y175%A46-1YU7I=,Y\@26")8,EA"6%
M)88EAR6()8\ECB6-)8PEBR6*)8DE/"4T)2PE)"4<)90E`"4")94E#"40)10E
M&"5M)0``````````````````````````````````````````````````````
M````````````````````````````````````;B5P)6\E4"5>)6HE827B)>,E
MY27D)7$E<B5S)1#_$?\2_Q/_%/\5_Q;_%_\8_QG_8"%A(6(A8R%D(64A9B%G
M(6@A:2$A,"(P(S`D,"4P)C`G,"@P*3#]_T13_?\A_R+_(_\D_R7_)O\G_RC_
M*?\J_RO_+/\M_R[_+_\P_S'_,O\S_S3_-?\V_S?_./\Y_SK_0?]"_T/_1/]%
M_T;_1_](_TG_2O]+_TS_3?]._T__4/]1_U+_4_]4_U7_5O\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````5_]8_UG_6O^1`Y(#DP.4
M`Y4#E@.7`Y@#F0.:`YL#G`.=`YX#GP.@`Z$#HP.D`Z4#I@.G`Z@#J0.Q`[(#
MLP.T`[4#M@.W`[@#N0.Z`[L#O`.]`[X#OP/``\$#PP/$`\4#Q@/'`\@#R0,%
M,08Q!S$(,0DQ"C$+,0PQ#3$.,0\Q````````````````````````````````
M```````````````````````````````````````````````````````````0
M,1$Q$C$3,10Q%3$6,1<Q&#$9,1HQ&S$<,1TQ'C$?,2`Q(3$B,2,Q)#$E,28Q
M)S$H,2DQV0+)`LH"QP++`@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````3EE.`4X#3D-.74Z&3HQ.NDX_4651:U'@40!2`5*;4A5305-<4\A3"4X+
M3@A."DXK3CA.X5%%3DA.7TY>3HY.H4Y`40-2^E)#4\E3XU,?5^M8%5DG67-9
M4%M16U-;^%L/7")<.%QQ7-U=Y5WQ7?)=\UW^77)>_EX+7Q-?36(`````````
M````````````````````````````````````````````````````````````
M`````````````````````!%.$$X-3BU.,$XY3DM..5R(3I%.E4Z23I1.HD[!
M3L!.PT[&3L=.S4[*3LM.Q$Y#44%19U%M46Y1;%&74?91!E('4@A2^U+^4O]2
M%E,Y4TA31U-%4UY3A%/+4\I3S5/L6"E9*UDJ62U95%L17"1<.EQO7/1=>U[_
M7A1?%5_#7PAB-F)+8DYB+V6'99=EI&6Y9>5E\&8(9RAG(&MB:WEKRVO4:]MK
M#VPT;&MP*G(V<CMR1W)9<EMRK'*+<QE.````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````!9.%4X43AA..TY-3D].3D[E3MA.U$[53M9.
MUT[C3N1.V4[>3D511%&)48I1K%'Y4?I1^%$*4J!2GU(%4P93%U,=4]].2E-)
M4V%38%-O4VY3NU/O4^13\U/L4^Y3Z5/H4_Q3^%/U4^M3YE/J4_)3\5/P4^53
M[5/[4]M6VE8660``````````````````````````````````````````````
M````````````````````````````````````````````+EDQ6719=EE56X-;
M/%SH7>==YET"7@-><UY\7@%?&%\77\5?"F)38E1B4F)18J5EYF4N9RQG*F<K
M9RUG8VO-:Q%L$&PX;$%L0&P^;*]RA'.)<]QTYG08=1]U*'4I=3!U,74R=3-U
MBW5]=JYVOW;N=MMWXG?S=SIYOGET>LMZ'DX?3E).4TYI3IE.I$ZF3J5._TX)
M3QE/"D\53PU/$$\13P]/\D[V3OM.\$[S3OU.`4\+3TE11U%&44A1:%$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````<5&-4;!1%U(1
M4A)2#E(64J-2"%,A4R!3<%-Q4PE4#U0,5`I4$%0!5`M4!%015`U4"%0#5`Y4
M!E025.!6WE;=5C-7,%<H5RU7+%<O5RE7&5D:63=9.%F$67A9@UE]67E9@EF!
M65=;6%N'6XA;A5N)6_I;%EQY7-Y=!EYV7G1>````````````````````````
M````````````````````````````````````````````````````````````
M```````/7QM?V5_67PYB#&(-8A!B8V);8EAB-F7I9>AE[&7M9?)F\V8)9SUG
M-&<Q9S5G(6MD:WMK%FQ=;%=L66Q?;&!L4&Q5;&%L6VQ-;$YL<'!?<EUR?G;Y
M>G-\^'PV?XI_O7\!@`.`#(`2@#.`?X")@(N`C(#C@>J!\X'\@0R"&X(?@FZ"
M<H)^@FN&0(A,B&.(?XDAEC).J$Y-3T]/1T]73UY/-$];3U5/,$]03U%//4\Z
M3SA/0T]43SQ/1D]C3P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!<3V!/+T].3S9/64]=3TA/6D],44M135%U4;91MU$E4B12*5(J
M4BA2JU*I4JI2K%(C4W-3=5,=5"U4'E0^5"943E0G5$940U0S5$A40E0;5"E4
M2E0Y5#M4.%0N5#54-E0@5#Q40%0Q5"M4'U0L5.I6\%;D5NM62E=15T!735<`
M````````````````````````````````````````````````````````````
M`````````````````````````````$=73E<^5U!73U<[5^]8/EF=69)9J%F>
M6:-9F5F668U9I%F368I9I5E=6UQ;6EM;6XQ;BUN/6RQ<0%Q!7#]</ER07)%<
ME%R,7.M=#%Z/7H=>BE[W7@1?'U]D7V)?=U]Y7]A?S%_77\U?\5_K7_A?ZE\2
M8A%BA&*78I9B@&)V8HEB;6**8GQB?F)Y8G-BDF)O8IAB;F*58I-BD6*&8CEE
M.V4X9?%E]&9?9TYG3V=09U%G7&=69UYG26=&9V!G````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````%-G5V=E:\]K0FQ>;)EL@6R(;(EL
MA6R;;&IL>FR0;'!LC&QH;)9LDFQ];(-L<FQ^;'1LAFQV;(ULE&R8;()L=G!\
M<'UP>'!B<F%R8'+$<L)REG,L=2MU-W4X=8)V[W;C=\%YP'F_>79Z^WQ5?Y:`
MDX"=@)B`FX":@+*`;X*2@@``````````````````````````````````````
M````````````````````````````````````````````````````BX*-@HN)
MTHD`BC>,1HQ5C)V,9(UPC;.-JX[*CIN/L(_"C\:/Q8_$C^%=D9"BD*J0II"C
MD$F1QI',D3*6+I8QEBJ6+)8F3E9.<TZ+3IM.GDZK3JQ.;T^=3XU/<T]_3VQ/
MFT^+3X9/@T]P3W5/B$]I3WM/ED]^3X]/D4]Z3U114E%546E1=U%V47A1O5']
M43M2.%(W4CI2,%(N4C9205*^4KM24E-44U-345-F4W=3>%-Y4]93U%/74W-4
M=50`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````EE1X
M5)54@%1[5'=4A%225(94?%205'%4=E2,5)I48E1H5(M4?52.5/I6@U=W5VI7
M:5=A5V979%=\5QQ925E'64A91%E46;Y9NUG46;E9KEG16<99T%G-6<M9TUG*
M6:]9LUG26<597UMD6V-;EUN:6YA;G%N96YM;&EQ(7$5<````````````````
M````````````````````````````````````````````````````````````
M``````````````!&7+=<H5RX7*E<JURQ7+-<&%X:7A9>%5X;7A%>>%Z:7I=>
MG%Z57I9>]EXF7R=?*5^`7X%??U]\7]U?X%_]7_5?_U\/8!1@+V`U8!9@*F`5
M8"%@)V`I8"M@&V`68A5B/V(^8D!B?V+)8LQBQ&*_8L)BN6+28MMBJV+38M1B
MRV+(8JABO6*\8M!BV6+'8LUBM6+:8K%BV&+68M=BQF*L8LYB/F6G9;QE^F44
M9A-F#&8&9@)F#F8`9@]F%68*9@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````'9@UG"V=M9XMGE6=Q9YQG<V=W9X=GG6>79V]G<&=_
M9XEG?F>09W5GFF>39WQG:F=R9R-K9FMG:W]K$VP;;.-LZ&SS;+%LS&SE;+-L
MO6R^;+QLXFRK;-5LTVRX;,1LN6S!;*YLUVS%;/%LOVR[;.%LVVS*;*QL[VS<
M;-9LX&P`````````````````````````````````````````````````````
M`````````````````````````````````````)5PCG"2<(IPF7`L<BUR.')(
M<F=R:7+`<LYRV7+7<M!RJ7.H<Y]SJW.E<SUUG769=9IUA';"=O)V]';E=_UW
M/GE`>4%YR7G(>7IZ>7KZ>OY\5'^,?XM_!8"Z@*6`HH"Q@*&`JX"I@+2`JH"O
M@.6!_H$-@K."G8*9@JV"O8*?@KF"L8*L@J6"KX*X@J."L(*^@K>"3H9QAAU2
M:(C+CLZ/U(_1C[60N)"QD+:0QY'1D7>5@)4<ED"6/Y8[ED26````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$*6N9;HEE*77I>?3JU.
MKD[A3[5/KT^_3^!/T4_/3]U/PT^V3]A/WT_*3]=/KD_03\1/PD_:3\Y/WD^W
M3U=1DE&14:!13E)#4DI235),4DM21U+'4LE2PU+!4@U35U-[4YI3VU.L5,!4
MJ%3.5,E4N%2F5+-4QU3"5+U4JE3!5```````````````````````````````
M````````````````````````````````````````````````````````````
MQ%3(5*]4JU2Q5+M4J52G5+]4_U:"5XM7H%>C5Z)7SE>N5Y-755E164]93EE0
M6=Q9V%G_6>-9Z%D#6N59ZEG:6>99`5K[66E;HUNF6Z1;HENE6P%<3EQ/7$U<
M2US97-)<]UT=7B5>'UY]7J!>IE[Z7@A?+5]E7XA?A5^*7XM?AU^,7XE?$F`=
M8"!@)6`.8"A@36!P8&A@8F!&8$-@;&!K8&I@9&!!8MQB%F,)8_QB[6(!8^YB
M_6('8_%B]V(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````[V+L8OYB]&(18P)C/V5%9:MEO67B925F+68@9B=F+V8?9BAF,68D9O=F
M_V?39_%GU&?09^QGMF>O9_5GZ6?O9\1GT6>T9]IGY6>X9\]GWF?S9[!GV6?B
M9]UGTF=J:X-KAFNU:])KUVL?;,EL"VTR;2IM06TE;0QM,6T>;1=M````````
M````````````````````````````````````````````````````````````
M```````````````````````[;3UM/FTV;1MM]6PY;2=M.&TI;2YM-6T.;2MM
MJW"Z<+-PK'"O<*UPN'"N<*1P,')R<F]R='+I<N!RX7*W<\ISNW.R<\USP'.S
M<QIU+75/=4QU3G5+=:MUI'6E=:)UHW5X=H9VAW:(=LAVQG;#=L5V`7?Y=OAV
M"7<+=_YV_'8'=]QW`G@4>`QX#7A&>4EY2'E'>;EYNGG1>=)YRWE_>H%Z_WK]
M>GU\`GT%?0!]"7T'?01]!GTX?XY_OW\$@```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````0@`V`$8`V@-:`Y8#:@,.`Q(#,@.&`VX#.
M@-Z`Y(#=@/2!(H+G@@.#!8/C@MN"YH($@^6"`H,)@]*"UX+Q@@&#W(+4@M&"
MWH+3@M^"[X(&@U"&>89[AGJ&38AKB(&)U(D(B@**`XJ>C*",=(USC;2-S8[,
MCO"/YH_BC^J/Y8\`````````````````````````````````````````````
M`````````````````````````````````````````````.V/ZX_DC^B/RI#.
MD,&0PY!+D4J1S9&"E5"62Y9,EDV68I=IE\N7[9?SEP&8J)C;F-^8EIF9F5A.
MLTX,4`U0(U#O3R90)5#X3RE0%E`&4#Q0'U`:4!)0$5#Z3P!0%%`H4/%/(5`+
M4!E0&%#S3^Y/+5`J4/Y/*U`)4'Q1I%&E4:)1S5',4<91RU%64EQ25%);4EU2
M*E-_4Y]3G5/?4^A4$%4!53=5_%3E5/)4!E7Z5!15Z53M5.%4"57N5.I4````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````.94)U4'5?U4
M#U4#5P17PE?45\M7PU<)6`]95UE865I9$5H86AQ:'UH;6A-:[%D@6B-:*5HE
M6@Q:"5IK6UA<L%NS6[9;M%NN6[5;N5NX6P1<45Q57%!<[5S]7/M<ZESH7/!<
M]EP!7?1<[ETM7BM>JUZM7J=>,5^27Y%?D%]98```````````````````````
M````````````````````````````````````````````````````````````
M````````8V!E8%!@56!M8&E@;V"$8)]@FF"-8)1@C&"%8)9@1V+S8@AC_V).
M8SYC+V-58T)C1F-/8TEC.F-08SUC*F,K8RAC36-,8TAE26699<%EQ65"9DEF
M3V9#9E)F3&9%9D%F^&849Q5G%V<A:#AH2&A&:%-H.6A":%1H*6BS:!=H3&A1
M:#UH]&=0:$!H/&A#:"IH16@3:!AH06B*:XEKMVLC;"=L*&PF;"1L\&QJ;95M
MB&V';69M>&UW;5EMDVT`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````;&V);6YM6FUT;6EMC&V*;7EMA6UE;91MRG#8<.1PV7#(<,]P
M.7)Y<OQR^7+]<OAR]W*&<^US"73N<^!SZG/><U1U775<=5IU676^=<5UQW6R
M=;-UO76\=;EUPG6X=8MVL';*=LUVSG8I=Q]W('<H=^EW,'@G>#AX'7@T>#=X
M````````````````````````````````````````````````````````````
M```````````````````````````````E>"UX('@?>#)X57E0>6!Y7WE6>5YY
M77E7>5IYY'GC>>=YWWGF>>EYV'F$>HAZV7H&>Q%[B7PA?1=]"WT*?2!](GT4
M?1!]%7T:?1Q]#7T9?1M].G]??Y1_Q7_!?P:`&(`5@!F`%X`]@#^`\8`"@?"`
M!8'M@/2`!H'X@/.`"(']@`J!_(#O@.V![($`@A""*H(K@BB"+(*[@BN#4H-4
M@TJ#.(-0@TF#-8,T@T^#,H,Y@S:#%X-`@S&#*(-#@P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!4AHJ&JH:3AJ2&J8:,AJ.&G(9P
MB'>(@8B"B'V(>8@8BA"*#HH,BA6*"HH7BA.*%HH/BA&*2(QZC'F,H8RBC'>-
MK([2CM2.SXZQCP&0!I#WCP"0^H_TCP.0_8\%D/B/E9#AD-V0XI!2D4V13)'8
MD=V1UY'<D=F1@Y5BEF.6898`````````````````````````````````````
M`````````````````````````````````````````````````````%N6799D
MEEB67I:[EN*8K)FHFMB:)9LRFSR;?DYZ4'U07%!'4$-03%!:4$E095!V4$Y0
M55!U4'10=U!/4`]0;U!M4%Q1E5'P46I2;U+24ME2V%+54A!3#U,94S]30%,^
M4\-3_&9&56I59E5$55Y5855#54I5,55654]5554O5615.%4N55Q5+%5C53-5
M055750A7"U<)5]]7!5@*6`98X%?D5_I7`E@U6/=7^5<@66)9-EI!6DE:9EIJ
M6D!:````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#Q:
M8EI:6D9:2EIP6\=;Q5O$6\);OUO&6PE<"%P'7&!<7%Q=7`==!ET.71M=%ETB
M71%=*5T471E=)%TG71==XETX7C9>,UXW7K=>N%ZV7K5>OEXU7S=?5U]L7VE?
M:U^77YE?GE^87Z%?H%^<7W]@HV")8*!@J&#+8+1@YF"]8```````````````
M````````````````````````````````````````````````````````````
M````````````````Q6"[8+5@W&"\8-A@U6#&8-]@N&#:8,=@&F(;8DABH&.G
M8W)CEF.B8Z5C=V-G8YACJF-Q8ZECB6.#8YMC:V.H8X1CB&.98Z%CK&.28X]C
M@&-[8VEC:&-Z8UUE5F5195EE5V5?54]E6&55951EG&6;9:QESV7+9<QESF5=
M9EIF9&9H9F9F7F;Y9M=2&V>!:*]HHFB3:+5H?VAV:+%HIVB7:+!H@VC$:*UH
MAFB%:)1HG6BH:)]HH6B":#)KNFL`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````ZVOL:RMLCFV\;?-MV6VR;>%MS&WD;?MM^FT%;L=M
MRVVO;=%MKFW>;?EMN&WW;?5MQ6W2;1INM6W:;>MMV&WJ;?%M[FWH;<9MQ&VJ
M;>QMOVWF;?EP"7$*<?UP[W`]<GUR@7(<<QMS%G,3<QESAW,%=`IT`W0&=/YS
M#73@=/9T````````````````````````````````````````````````````
M``````````````````````````````````````#W=!QU(G5E=69U8G5P=8]U
MU'75=;5URG7-=8YVU';2=MMV-W<^=SQW-G<X=SIW:WA#>$YX97EH>6UY^WF2
M>I5Z('LH>QM[+'LF>QE['GLN>Y)\EWR5?$9]0WUQ?2Y].7T\?4!],'TS?41]
M+WU"?3)],7T]?YY_FG_,?\Y_TG\<@$J`1H`O@1:!(X$K@2F!,($D@0*"-8(W
M@C:".8*.@YZ#F(-X@Z*#EH.]@ZN#DH.*@Y.#B8.@@W>#>X-\@P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"&@Z>#589J7\>&P(:V
MAL2&M8;&ALN&L8:OALF&4XB>B(B(JXB2B):(C8B+B).)CXDJBAV*(XHEBC&*
M+8H?BAN*(HI)C%J,J8RLC*N,J(RJC*>,9XUFC;Z-NHW;CM^.&9`-D!J0%Y`C
MD!^0'9`0D!60'I`@D`^0(I`6D!N0%)``````````````````````````````
M````````````````````````````````````````````````````````````
M`.B0[9#]D%>1SI'UD>:1XY'GD>V1Z9&)E6J6=99SEGB6<)9TEG:6=Y9LEL"6
MZI;IEN!ZWWH"F`.86IOEG'6>?YZEGKN>HE"-4(50F5"14(!0EE"84)I0`&?Q
M47)2=%)U4FE2WE+=4MM26E.E4WM5@%6G57Q5BE6=59A5@E6<5:I5E%6'58M5
M@U6S5:Y5GU4^5;)5FE6[5:Q5L55^58E5JU6950U7+U@J6#18)%@P6#%8(5@=
M6"!8^5CZ6&!9````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'=:FEI_6I):FUJG6G-;<5O26\Q;TUO06PI<"UPQ7$Q=4%TT74==_5U%
M7CU>0%Y#7GY>RE[!7L)>Q%X\7VU?J5^J7ZA?T6#A8+)@MF#@8!QA(V'Z8!5A
M\&#[8/1@:&'Q8`YA]F`)80!A$F$?8DEBHV.,8\]CP&/I8\ECQF/-8P``````
M````````````````````````````````````````````````````````````
M````````````````````````TF/C8]!CX6/68^UC[F-V8_1CZF/;8U)DVF/Y
M8UYE9F5B96-ED6609:]E;F9P9G1F=F9O9I%F>F9^9G=F_F;_9A]G'6?Z:-5H
MX&C8:-=H!6G?:/5H[FCG:/EHTFCR:.-HRVC-:`UI$FD.:<EHVFAN:?MH/FLZ
M:SUKF&N6:[QK[VLN;"]L+&PO;CAN5&XA;C)N9VY*;B!N)6XC;AMN6VY8;B1N
M5FYN;BUN)FYO;C1N36XZ;BQN0VX=;CYNRVX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B6X9;DYN8VY$;G)N:6Y?;AEQ&G$F<3!Q
M(7$V<6YQ''%,<H1R@'(V<R5S-',I<SIT*G0S=")T)70U=#9T-'0O=!MT)G0H
M="5U)G5K=6IUXG7;=>-UV778==YUX'5[=GQVEG:3=K1VW'9/=^UW77AL>&]X
M#7H(>@MZ!7H`>IAZ````````````````````````````````````````````
M``````````````````````````````````````````````"7>I9ZY7KC>DE[
M5GM&>U![4GM4>TU[2WM/>U%[GWRE?%Y]4'UH?55]*WUN?7)]87UF?6)]<'US
M?815U'_5?PN`4H"%@%6!5(%+@5&!3H$Y@4:!/H%,@5.!=($2@AR"Z8,#A/B#
M#83@@\6#"X3!@^^#\8/T@U>$"H3P@PR$S(/]@_*#RH,XA`Z$!(3<@P>$U(/?
M@UN&WX;9ANV&U(;;AN2&T(;>AE>(P8C"B+&(@XF6B3N*8(I5BEZ*/(I!B@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!4BEN*4(I&
MBC2*.HHVBE:*88R"C*^,O(RSC+V,P8R[C,",M(RWC+:,OXRXC(J-A8V!C<Z-
MW8W+C=J-T8W,C=N-QHW[COB._(Z<CRZ0-9`QD#B0,I`VD`*1]9`)D?Z08Y%E
MD<^1%)(5DB.2"9(>D@V2$)('DA&2E)6/E8N5D94`````````````````````
M````````````````````````````````````````````````````````````
M`````````).5DI6.E8J6CI:+EGV6A9:&EHV6<I:$EL&6Q9;$EL:6QY;OEO*6
MS)<%F`:8")CGF.J8[YCIF/*8[9BNF:V9PY[-GM&>@DZM4+50LE"S4,50OE"L
M4+=0NU"O4,=0?U)W4GU2WU+F4N12XE+C4B]3WU7H5=-5YE7.5=Q5QU715>-5
MY%7O5=I5X57%5<95Y57)51)7$U=>6%%86%A76%I85%AK6$Q8;5A*6&)84EA+
M6&=9P5K)6LQ:OEJ]6KQ:````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````+-:PEJR6FE=;UU,7GE>R5[(7A)?65^L7ZY?&F$/84AA'V'S
M8!MA^6`!80AA3F%,841A36$^831A)V$-809A-V$A8B)B$V0^9!YD*F0M9#UD
M+&0/9!QD%&0-9#9D%F079`9D;&6?9;!EEV:)9H=FB&:69H1FF&:-9@-GE&EM
M:0``````````````````````````````````````````````````````````
M````````````````````````````````6FEW:6!I5&EU:3!I@FE*:6AI:VE>
M:5-I>6F&:5UI8VE;:4=K<FO`:[]KTVO]:Z)NKV[3;K9NPFZ0;IUNQV[%;J5N
MF&Z\;KINJV[1;I9NG&[$;M1NJFZG;K1N3G%9<6EQ9'%)<6=Q7'%L<69Q3'%E
M<5YQ1G%H<59Q.G)2<C=S17,_<SYS;W1:=%5T7W1>=$%T/W19=%MT7'1V=7AU
M`';P=0%V\G7Q=?IU_W7T=?-UWG;?=EMW:W=F=UYW8W<`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````>7=J=VQW7'=E=VAW8G?N=XYX
ML'B7>)AXC'B)>'QXD7B3>']X>GE_>8%Y+(2]>1QZ&GH@>A1Z'WH>>I]ZH'IW
M>\![8'MN>V=[L7RS?+5\DWUY?9%]@7V/?5M];G]I?VI_<G^I?ZA_I']6@%B`
MAH"$@'&!<(%X@66!;H%S@6N!````````````````````````````````````
M``````````````````````````````````````````````````````!Y@7J!
M9H$%@D>"@H1WA#V$,81UA&:$:X1)A&R$6X0\A#6$881CA&F$;81&A%Z&7(9?
MAOF&$X<(AP>'`(?^AON&`H<#AP:'"H=9B-^(U(C9B-R(V(C=B.&(RHC5B-*(
MG(GCB6N*<HISBF:*:8IPBH>*?(ICBJ"*<8J%BFV*8HINBFR*>8I[BCZ*:(IB
MC(J,B8S*C,>,R(S$C+*,PXS"C,6,X8W?C>B-[XWSC?J-ZHWDC>:-LHX#CPF/
M_HX*CP``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"?
MC[*/2Y!*D%.00I!4D#R059!0D$>03Y!.D$V049`^D$&0$I$7D6R1:I%ID<F1
M-Y)7DCB2/9)`DCZ26Y)+DF2249(TDDF239)%DCF2/Y):DIB5F):4EI66S9;+
MELF6RI;WEON6^9;VEE:7=)=VEQ"8$9@3F`J8$I@,F/R8])@`````````````
M````````````````````````````````````````````````````````````
M`````````````````/V8_IBSF;&9M)GAFNF<@IX.GQ.?()_G4.Y0Y5#64.U0
MVE#54,]0T5#Q4,Y0Z5!B4?-1@U*"4C%3K5/^50!6&U875OU5%%8&5@E6#58.
M5O=5%E8?5@A6$%;V51A7%E=U6'Y8@UB36(I8>5B%6'U8_5@E62)9)%EJ66E9
MX5KF6NE:UUK66MA:XUIU6]Y;YUOA6^5;YEOH6^);Y%O?6PU<8ER$78==6UYC
M7E5>5UY47M->UEX*7T9?<%^Y7T=A````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#]A2V%W86)A8V%?85IA6&%U82IBAV189%1DI&1X
M9%]D>F119&=D-&1M9'MD<F6A9==EUF6B9JAFG6:<::AIE6G!::YITVG+:9MI
MMVF[::MIM&G0:<UIK6G,::9IPVFC:4EK3&LS;#-O%&_^;A-O]&XI;SYO(&\L
M;P]O`F\B;P``````````````````````````````````````````````````
M````````````````````````````````````````_V[O;@9O,6\X;S)O(V\5
M;RMO+V^(;RIO[&X!;_)NS&[W;I1QF7%]<8IQA'&2<3YRDG*6<D1S4'-D=&-T
M:G1P=&UT!'61=2=V#78+=@EV$W;A=N-VA'=]=W]W87?!>)]XIWBS>*EXHWB.
M>8]YC7DN>C%ZJGJI>NUZ[WJA>Y5[BWMU>Y=[G7N4>X][N'N'>X1[N7R]?+Y\
MNWVP?9Q]O7V^?:!]RGVT?;)]L7VZ?:)]OWVU?;A]K7W2?<=]K'T`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````<'_@?^%_WW]>@%J`
MAX!0@8"!CX&(@8J!?X&"@>>!^H$'@A2"'H)+@LF$OX3&A,2$F82>A+*$G(3+
MA+B$P(33A)"$O(31A,J$/X<<ASN'(H<EAS2'&(=5AS>'*8?SB`*)](CYB/B(
M_8CHB!J)[XBFBHR*GHJCBHV*H8J3BJ2*````````````````````````````
M````````````````````````````````````````````````````````````
M``"JBJ6*J(J8BI&*FHJGBFJ,C8R,C-.,T8S2C&N-F8V5C?R-%(\2CQ6/$X^C
MCV"06)!<D&.069!>D&*079!;D!F1&)$>D761>)%WD721>)*`DH62F)*6DGN2
MDY*<DJB2?)*1DJ&5J)6IE:.5I96DE9F6G):;ELR6TI8`EWR7A9?VEQ>8&)BO
MF+&8`YD%F0R9"9G!F:^:L)KFFD&;0IOTG/:<\YR\GCN?2I\$40!1^U#U4/E0
M`E$(40E1!5'<40``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"'4HA2B5*-4HI2\%*R4RY6.U8Y5C)6/U8T5BE64U9.5E=6=%8V5B]6
M,%:`6)]8GEBS6)Q8KEBI6*98;5D)6_M:"UOU6@Q;"%ON6^Q;Z5OK6V1<95R=
M791=8EY?7F%>XE[:7M]>W5[C7N!>2%]Q7[=?M5]V86=A;F%=855A@F$`````
M````````````````````````````````````````````````````````````
M`````````````````````````'QA<&%K87YAIV&08:MACF&L89IAI&&48:YA
M+F)I9&]D>62>9+)DB&209+!DI6239)5DJ6229*YDK62K9)IDK&299*)DLV1U
M97=E>&6N9JMFM&:Q9B-J'VKH:0%J'FH9:OUI(6H3:@IJ\VD":@5J[6D1:E!K
M3FND:\5KQFL_;WQOA&]1;V9O5&^&;VUO6V]X;VYOCF]Z;W!O9&^7;UAOU6YO
M;V!O7V^?<:QQL7&H<59RFW).<U=S:72+=(-T````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'YT@'1_=2!V*78?=B1V)G8A=B)VFG:Z
M=N1VCG>'=XQWD7>+=\MXQ7BZ>,IXOGC5>+QXT'@_>CQZ0'H]>C=Z.WJO>JYZ
MK7NQ>\1[M'O&>\=[P7N@>\Q[RGS@??1][WW[?=A]['W=?>A]XWW:?=Y]Z7V>
M?=E]\GWY?75_=W^O?P``````````````````````````````````````````
M````````````````````````````````````````````````Z7\F@)N!G(&=
M@:"!FH&8@1>%/84:A>Z$+(4MA1.%$84CA2&%%(7LA"6%_X0&A8*'=(=VAV"'
M9H=XAVB'68=7ATR'4X=;B%V($(D'B1*)$XD5B0J)O(K2BL>*Q(J5BLN*^(JR
MBLF*PHJ_BK"*UHK-BK:*N8K;BDR,3HQLC.",WHSFC.2,[(SMC.*,XXS<C.J,
MX8QMC9^-HXTKCA".'8XBC@^.*8X?CB&.'HZZCAV/&X\?CRF/)H\JCQR/'H\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````)8]ID&Z0
M:)!MD'>0,)$MD2>1,9&'D8F1BY&#D<62NY*WDNJ2K)+DDL&2LY*\DM*2QY+P
MDK*2K96QE027!I<'EPF78)>-EXN7CY<AF"N8')BSF`J9$YD2F1B9W9G0F=^9
MVYG1F=69TIG9F;>:[IKOFB>;19M$FW>;;YL&G0F=````````````````````
M````````````````````````````````````````````````````````````
M```````````#G:F>OI[.GJA84I\241A1%%$04151@%&J4=U1D5*34O-2659K
M5GE6:59D5GA6:E9H5F56<59O5FQ68E9V5L%8OEC'6,58;ED=6S1;>%OP6PY<
M2E^R89%AJ6&*8<UAMF&^8<IAR&$P8L5DP63+9+MDO&3:9,1DQV3"9,UDOV32
M9-1DOF1T9<9FR6:Y9L1FQV:X9CUJ.&HZ:EEJ:VI8:CEJ1&IB:F%J2VI':C5J
M7VI(:EEK=VL%;,)OL6^A;P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````##;Z1OP6^G;[-OP&^Y;[9OIF^@;[1OOG')<=!QTG'(<=5Q
MN7'.<=EQW''#<<1Q:'.<=*-TF'2?=)YTXG0,=0UU-'8X=CIVYW;E=J!WGG>?
M=Z5WZ'C:>.QXYWBF>4UZ3GI&>DQZ2WJZ>ME[$7S)>^1[VWOA>^E[YGO5?-9\
M"GX`````````````````````````````````````````````````````````
M`````````````````````````````````!%^"'X;?B-^'GX=?@E^$'YY?[)_
M\'_Q?^Y_*("S@:F!J('[@0B"6()9@DJ%685(A6B%:85#A4F%;85JA5Z%@X>?
MAYZ'HH>-AV&(*HDRB26)*XDAB:J)IHGFBOJ*ZXKQB@"+W(KGBNZ*_HH!BP*+
M]XKMBO.*]HK\BFN,;8R3C/2,1(XQCC2.0HXYCC6..X\OCSB/,X^HCZ:/=9!T
MD'B0<I!\D'J0-)&2D2"3-I/XDC.3+Y,BD_R2*Y,$DQJ3````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````!"3)I,ADQ63+I,9D[N5IY:H
MEJJ6U98.EQ&7%I<-EQ.7#Y=;EUR79I>8ES"8.)@[F#>8+9@YF"28$)DHF1Z9
M&YDAF1J9[9GBF?&9N)J\FON:[9HHFY&;%9TCG2:=*)T2G1N=V)[4GHV?G)\J
M41]1(5$R4?52CE:`5I!6A5:'5@``````````````````````````````````
M````````````````````````````````````````````````````````CU;5
M6--8T5C.6#!;*ELD6WI;-UQH7+Q=NEV]7;A=:UY,7[U?R6'"8<=AYF'+83)B
M-&+.9,IDV&3@9/!DYF3L9/%DXF3M9()E@V799M9F@&J4:H1JHFJ<:MMJHVI^
M:I=JD&J@:EQKKFO::PALV&_Q;]]OX&_;;^1OZV_O;X!O[&_A;^EOU6_N;_!O
MYW'?<>YQYG'E<>UQ[''T<>!Q-7)&<G!S<G.I=+!TIG2H=$9V0G9,=NIVLW>J
M=[!WK'<`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MIW>M=^]W]WCZ>/1X[W@!>:=YJGE7>K]Z!WP-?/Y[]WL,?.![X'S<?-Y\XGS?
M?-E\W7PN?CY^1GXW?C)^0WXK?CU^,7Y%?D%^-'XY?DA^-7X_?B]^1'_S?_Q_
M<8!R@'"`;X!S@,:!PX&Z@<*!P(&_@;V!R8&^@>B!"8)Q@JJ%````````````
M````````````````````````````````````````````````````````````
M``````````````````"$A7Z%G(61A92%KX6;A8>%J(6*A6>&P(?1A[.'TH?&
MAZN'NX>ZA\B'RX<[B3:)1(DXB3V)K(D.BQ>+&8L;BPJ+((L=BP2+$(M!C#^,
M<XSZC/V,_(SXC/N,J(U)CDN.2(Y*CD2//H]"CT6//X]_D'V0A)"!D(*0@)`Y
MD:.1GI&<D4V3@I,HDW632I-EDTN3&)-^DVR36Y-PDUJ35)/*E<N5S)7(E<:5
ML9:XEM:6')<>EZ"7TY=&F+:8-9D!F@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_F:Z;JYNJFZV;.YT_G8N>SY[>GMR>W9[;GCZ?
M2Y_B4Y56KE;96-A8.%M=7^-A,V+T9/)D_F0&9?ID^V3W9+=EW&8F9[-JK&K#
M:KMJN&K":JYJKVI?:WAKKVL)<`MP_F\&</IO$7`/</MQ_''^<?AQ=W-U<Z=T
MOW05=59V6'8`````````````````````````````````````````````````
M`````````````````````````````````````````%)VO7>_=[MWO'<.>:YY
M87IB>F!ZQ'K%>BM\)WPJ?!Y\(WPA?.=\5'Y5?EY^6GYA?E)^67Y(?_E_^W]W
M@':`S8'/@0J"SX6IA<V%T(7)A;"%NH6YA::%[X?LA_*'X(>&B;*)](DHBSF+
M+(LKBU",!8U9CF..9HYDCE^.58[`CDF/38^'D(.0B)"KD:R1T)&4DXJ3EI.B
MD[.3KI.LD["3F).:DY>3U)76E="5U97BEMR6V9;;EMZ6))>CEZ:7````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````*V7^9=-F$^83)A.
MF%.8NI@^F3^9/9DNF:69#IK!F@.;!IM/FTZ;39O*F\F;_9O(F\";49U=G6"=
MX)X5GRR?,U&E5MY8WUCB6/5;D)_L7O)A]V'V8?5A`&4/9>!FW6;E:MUJVFK3
M:AMP'W`H<!IP'7`5<!AP!G(-<EARHG)X<P``````````````````````````
M````````````````````````````````````````````````````````````
M````>G.]=,ITXW2'=89U7W9A=L=W&7FQ>6MZ:7H^?#]\.'P]?#=\0'QK?FU^
M>7YI?FI^A7]S?K9_N7^X?]B!Z87=A>J%U87DA>6%]X7[AP6(#8CYA_Z'8(E?
MB5:)7HE!BUR+6(M)BUJ+3HM/BT:+68L(C0J-?(YRCH>.=HYLCGJ.=(Y4CTZ/
MK8^*D(N0L9&ND>&3T9/?D\.3R)/<D]V3UI/BD\V3V)/DD]>3Z)/<E;26XY8J
MER>789?<E_N77I@`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````6)A;F+R819E)F1::&9H-F^B;YYO6F]N;B9UAG7*=:IULG9*>EYZ3
MGK2>^%*H5K=6ME:T5KQ6Y%A`6T-;?5OV6\E=^&'Z81AE%&499>9F)V?L:CYP
M,'`R<!!R>W//=&)V978F>2IY+'DK><=Z]GI,?$-\37SO?/!\KH]]?GQ^````
M````````````````````````````````````````````````````````````
M``````````````````````````""?DQ_`(#:@6:"^X7YA1&&^H4&A@N&!X8*
MAA2(%8ADB;J)^(EPBVR+9HMOBU^+:XL/C0V-B8Z!CH6.@HZTD<N1&)0#E/V3
MX94PE\284IE1F:B9*YHPFC>:-9H3G`V<>9ZUGNB>+Y]?GV.?89\W43A1P5;`
M5L)6%%EL7,U=_&'^81UE'&659>EF^VH$:_IJLFM,<!MRIW+6=-1T:7;3=U!\
MCWZ,?KQ_%X8MAAJ&(X@BB"&('XAJB6R)O8ETBP``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!WBWV+$XV*CHV.BXY?CZ^/NI$NE#.4
M-90ZE#B4,I0KE.*5.)<YES*7_Y=GF&685YE%FD.:0)H^FL^:5)M1FRV<)9RO
MG;2=PIVXG9V>[YX9GUR?9I]GGSQ1.U'(5LI6R59_6]1=TEU.7_]A)&4*:V%K
M47!8<(!SY'2*=6YV;'8`````````````````````````````````````````
M`````````````````````````````````````````````````+-Y8'Q??'Z`
M?8#?@7*);XG\B8"+%HT7C9&.DXYACTB11)11E%*4/9<^E\.7P9=KF%6959I-
MFM*:&IM)G#&</IP[G-.=UYTTGVR?:I^4G\Q6UET`8B-E*V4J9>QF$&O:=,IZ
M9'QC?&5\DWZ6?I1^XH$XAC^&,8B*BY"0CY!CE&"49)1HEV^87)E:FEN:5YK3
MFM2:T9I4G%><5ISEG9^>])[15NE8+&5><'%V<G;7=U!_B'\VB#F(8HB3BY*+
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````):+=X(;
MC<"1:I1"ETB71)?&EW"87YHBFUB;7YSYG?J=?)Y]G@>?=Y]RG_->%FMC<&Q\
M;GP[B,")H8[!D7*4<)1QF%Z9UIHCF\R>9'#:=YJ+=Y3)EV*:99J<?IR+JH[%
MD7V4?I1\E'><>)SWGE2,?Y0:GBAR:IHQFQN>'IYR?```````````````````
M````````````````````````````````````````````````````````````
M````````````_C"=,)XP!3!!,$(P0S!$,$4P1C!',$@P23!*,$LP3#!-,$XP
M3S!0,%$P4C!3,%0P53!6,%<P6#!9,%HP6S!<,%TP7C!?,&`P83!B,&,P9#!E
M,&8P9S!H,&DP:C!K,&PP;3!N,&\P<#!Q,'(P<S!T,'4P=C!W,'@P>3!Z,'LP
M?#!],'XP?S"`,($P@C"#,(0PA3"&,(<PB#"),(HPBS",,(TPCC"/,)`PD3"2
M,),PH3"B,*,PI#"E,*8PIS``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````J#"I,*HPJS"L,*TPKC"O,+`PL3"R,+,PM#"U,+8PMS"X
M,+DPNC"[,+PPO3"^,+\PP##!,,(PPS#$,,4PQC#',,@PR3#*,,LPS##-,,XP
MSS#0,-$PTC#3,-0PU3#6,-<PV##9,-HPVS#<,-TPWC#?,.`PX3#B,.,PY##E
M,.8P````````````````````````````````````````````````````````
M``````````````````````````````````#G,.@PZ3#J,.LP[##M,.XP[S#P
M,/$P\C#S,/0P]3#V,!0$%00!!!8$%P08!!D$&@0;!!P$(P0D!"4$)@0G!"@$
M*00J!"L$+`0M!"X$+P0P!#$$,@0S!#0$-011!#8$-P0X!#D$.@0[!#P$/00^
M!#\$0`1!!$($0P1$!$4$1@1'!$@$201*!$L$3`1-!$X$3P1@)&$D8B1C)&0D
M921F)&<D:"1I)'0D=21V)'<D>"1Y)'HD>R1\)'TD`````````@``````````
M````000``&84&0AM%!D(]/H8"`````#`W1H(P-P:",#;&@C`VAH(````````
M``#`V!H(`-<:"```````````!`````$````!`````````,!H&0C`UAH(````
M`(2+!PBDC@<(Z(X'"*R0!PAL<P<(O&@'")!V!PC8:0<(````````````````
M````````````````````````_0#`UQH(`@%^`4#7&@C'`MT"(-<:"```````
M````MP````````````````````"B_P"R`+T```````````##XZ&QQN8`````
MR.C/[]#P````````RNK,[```````````````````````````````````````
MQ>4``*6U``"CL]'Q``#2\@````````#5]0``P.```-CXIK8``*JZJ;G>_JN[
M``````````#9^=O[`````````*R\K[^NO@`````!`@,$!08'"`D*"PP-#@\0
M$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]
M/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D969G:&EJ
M:VQM;F]P<7)S='5V=WAY>GM\?7X`````````````````````````````````
M``````````"@````I```IZ@`````K0``L````+0```"X``````````#!P@#$
M``#'`,D`RP#-S@````#3U`#6UP``V@#<W0#?`.'B`.0``.<`Z0#K`.WN````
M`//T`/;W``#Z`/S]``````$``@`#``0`!0`&``<`"``)``H`"P`,``T`#@`/
M`!``$0`2`!,`%``5`!8`%P`8`!D`&@`;`!P`'0`>`!\`(``A`"(`(P`D`"4`
M)@`G`"@`*0`J`"L`+``M`"X`+P`P`#$`,@`S`#0`-0`V`#<`.``Y`#H`.P`\
M`#T`/@`_`$``00!"`$,`1`!%`$8`1P!(`$D`2@!+`$P`30!.`$\`4`!1`%(`
M4P!4`%4`5@!7`%@`60!:`%L`7`!=`%X`7P!@`&$`8@!C`&0`90!F`&<`:`!I
M`&H`:P!L`&T`;@!O`'``<0!R`',`=`!U`'8`=P!X`'D`>@![`'P`?0!^````
M````````````````````````````````````````````````````````````
M`````````````````````````*``!`'8`D$!I``]`5H!IP"H`&`!7@%D`7D!
MK0!]`7L!L``%`=L"0@&T`#X!6P''`K@`80%?`64!>@'=`GX!?`%4`<$`P@`"
M`<0`.0$&`<<`#`')`!@!RP`:`<T`S@`.`1`!0P%'`=,`U`!0`=8`UP!8`6X!
MV@!P`=P`W0!B`=\`50'A`.(``P'D`#H!!P'G``T!Z0`9`>L`&P'M`.X`#P$1
M`40!2`'S`/0`40'V`/<`60%O`?H`<0'\`/T`8P'9`@`!`@,$!08'"`D*"PP-
M#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ
M.SP]/C]`04=(3$Y35%566EM<8&%D:6IK;G)U>GM\?7^#A(6&AXA!1TA,3E-4
M559:6UQ@861I:FMN<G5Z>WQ]?XF*BXP``0(#!`4&!P@)"@L,#0X/$!$2$Q05
M%A<8&1H;'!T>'_]"_UW_7F____]P<7.`_X&"_T+_7?]>;___<'%S@/^!@FQ#
M1$5&7TE+2D]14E!95TW_8F-E9F=H_VUW=GAY?G3_;$-$149?24M*3U%24%E8
M3?]B8V5F9VC_;7=V>'E^=/\``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;
M'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(
M24I+3$U.3U!14E-455976%E:6UQ=7E]@04)#1$5&1TA)2DM,34Y/4%%24U15
M5E=865I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&B
MHZ2EIJ>HJ:JKK*VNK["@LJ*TI*6WN*FJJZR]KJ_`P<+#Q,7&Q\C)RLO,S<[/
MT-'2T]35UM?8V=K;W-W>W\#!PL/$Q<;'R,G*R\S-SL_PT=+3U-76]]C9VMO<
MW=[_``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I
M*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!A8F-D969G:&EJ:VQM;F]P<7)S='5V
M=WAY>EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]?G^`@8*#
MA(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>G[&ALZ.UMJ:GJ+FZN[RMOK^P
ML;*SM+6VM[BYNKN\O;Z_X.'BX^3EYN?HZ>KK[.WN[]#Q\O/T]?;7^/GZ^_S]
M_M_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`@("`@("`@("`H
M*"@H*"`@("`@("`@("`@("`@("`@($@0$!`0$!`0$!`0$!`0$!"$A(2$A(2$
MA(2$$!`0$!`0$(&!@8&!@0$!`0$!`0$!`0$!`0$!`0$!`0$!$!`0$!`0@H*"
M@H*"`@("`@("`@("`@("`@("`@("`@(0$!`0("`@("`@("`@*"@H*"@@("`@
M("`@("`@("`@("`@("!(`1`!$`$!$````0$!`1`!`1`"$`(0`@(0$`("`@(0
M`@(!`0$!`0$!`0$!`0$!`0$!$`$!`0$!`1`!`0$!`0$!$`("`@("`@("`@("
M`@("`@("`@("`@("$`("`@("`@(0````H!09"*05&0BH%AD(K!<9"```````
M`````````'T4&0B`%!D(A109"(@4&0B-%!D(D!09",V_"`B5%!D(U=<(")H4
M&0@```````````````````````````````!5```````````````1````K1@9
M"+,8&0CT^A@(``````#B&@@`X1H(`.`:"```````````````````````````
M```````````!`````0````(``````/\`@-\:"&",)0@`````9)$'"*"1!PC<
MK`@()*T("(BM"`AP=@<(2'8'"#R3!PC`D0<(.*<(")2G"`CPIP@(0*@("+QI
M!PAL<0<(/'('""1V!PA`:@<(P&L'"!AM!PA$;P<()'$'".1Y!PB\=0<(````
M```````````````````````````````````!`@,$!08'"`D*"PP-#@\0$1(3
M%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`
M04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$149'2$E*2TQ-
M3D]045)35%565UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:
MFYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'
MR,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T
M]?;W^/GZ^_S]_O\``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A
M(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0&%B8V1E9F=H:6IK;&UN
M;W!Q<G-T=79W>'EZ6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[
M?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>H
MJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35
MUM?8V=K;W-W>W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_`"`@
M("`@("`@("@H*"@H("`@("`@("`@("`@("`@("`@2!`0$!`0$!`0$!`0$!`0
M$(2$A(2$A(2$A(00$!`0$!`0@8&!@8&!`0$!`0$!`0$!`0$!`0$!`0$!`0$0
M$!`0$!""@H*"@H("`@("`@("`@("`@("`@("`@("`A`0$!`@$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$```````````````````````
M````````````````````$P``````````````(0```*T8&0B]&!D(]/H8"```
M````XAH(`.$:"`#@&@C`XQH(`````````````````````````````````0``
M``$````"``````#_`(#?&@B`XQH(`````!1G!PB(9P<(E&8'".1T!P@TJ0@(
MD*@(",RM"`C8:0<(```````````````````````````````````````!`@,$
M!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q
M,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>
M7V!!0D-$149'2$E*2TQ-3D]045)35%565UA96GM\?7Y_@(&"@X2%AH>(B8J+
MC(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>X
MN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3E
MYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O^AHZ*CHZ.DHZ6CIJ.GHZBCJ:.J
MHZNCK*.MHZZCKZ.PH[&CLJ.SH[2CM:.VH[>CN*.YH[JCNZ.\H[VCOJ._H\"C
MP:/"H\.CQ*/%H\:CQZ/(H\FCRJ/+H\RCS:/.H\^CT*/1H]*CTZ/4H]6CUJ/7
MH]BCV:/:H]NCK*'=H]ZCWZ/@H^&CXJ/CH^2CY:/FH^>CZ*/IH^JCZZ/LH^VC
M[J/OH_"C\:/RH_.C]*/UH_:C]Z/XH_FC^J/[H_RC_:.FH@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````,NAS*'^H?ZC``#-H=RC````````````
M``````````````#0R];+Y\O/S>C-K<[[SZ+0N-#0T-W0U-'5T=C1V]'<T=W1
MWM'?T>#1XM'CT>31Y='FT>C1Z='JT>O1[='OT?#1\M'VT?K1_-']T?[1HM*C
MTJ?2J-*ITJK2J]*MTK+2OM+"TL/2Q-+&TL?2R-+)TLK2R]+-TL[2S]+0TM'2
MTM+3TM32U=+6TM?2V=+:TM[2W]+ATN+2Y-+ETN;2Y]+HTNG2ZM+KTO#2\=+R
MTO/2]-+UTO?2^-+FU/S4I=6KU:[5N-;-ULO7Y-?%V^3;I=REW=7=]-W\WO[>
ML]_AW^C?\>"MX>WA]>.AY*GDKN6QY;+EN>6[Y;SEQ.7.Y=#ETN76Y?KE^^7\
MY?[EH>:DYJ?FK>:OYK#FL>:SYK?FN.:\YL3FQN;'YLKFTN;6YMGFW.;?YN'F
MY.;EYN;FZ.;JYNOF[.;OYO'F\N;UYO;F]^;YYJ'GIN>IYZKGK.>MY[#GO^?!
MY\;GQ^?+Y\WGS^?0Y]/GW^?DY^;G]^?GZ.CH\.CQZ/?H^>C[Z/[HI^FLZ<SI
M]^G!ZN7J].KWZOSJ_NJDZZ?KJ>NJZ[KKN^N]Z\'KPNO&Z\?KS.O/Z]#KT>O2
MZ]CKINRG[*KLK^RP[+'LLNRU[+CLNNS`[,'LQ>S&[,GLRNS5[-WLWNSA[.3L
MY^SH[/?L^.SZ[*'MHNVC[>[MV^Z]\OKRL?.G].[T]/;V]KCWR/?3]]OX\/BA
M^J+ZYOJI_```````````H;"BL$&!0H&CL$.!1(&DL*6PIK"GL$6!1H%'@4B!
M28&HL*FPJK"KL*RPK;"NL*^P2H&PL+&PLK"SL+2P2X%,@;6P38%.@4^!MK!0
M@5&!4H%3@52!58%6@;>PN+!7@;FPNK"[L%B!68%:@6&!8H%C@;RPO;!D@66!
MOK!F@6>!:(&_L&F!:H%K@6R!;8%N@6^!<(%Q@7*!P+!S@<&P=(%U@7:!=X%X
M@7F!PK!Z@8&!@H'#L(.!A(&%@<2PAH&'@8B!B8&*@8N!C(&-@8Z!CX&0@9&!
MDH&3@92!E8&6@9>!F('%L,:PF8&:@<>PFX&<@<BPR;"=@<JPGH&?@:"!H8&B
M@<NPS+"C@<VPSK#/L-"PI(&E@=&PTK#3L-2PIH&G@:B!U;"I@:J!JX'6L*R!
MK8&N@:^!L(&Q@;*!U[#8L+.!V;#:L-NPM(&U@;:!MX&X@;F!W+#=L-ZPNH'?
ML+N!O('@L.&PO8&^@;^!P('!@<*!PX'BL..PQ('DL.6PYK#%@<:!QX'GL,B!
MR8'HL,J!RX',@>FPS8'.@<^!ZK#0@=&!TH'3@=2!U8'6@=>!Z[#8@>RPV8':
M@=N!W('=@=Z!WX'@@>VP[K#A@>*![[#C@>2!\+#QL.6!\K#F@?.PYX'H@?2P
M];#VL.F!][#J@?BP^;#K@>R![8'N@>^!^K#[L/"!\8'\L/*!\X'T@?VP]8'^
ML/:!]X'X@?F!^H&AL:*Q^X&CL?R!I+']@?Z!08)"@D."1(*EL46"1H)'@J:Q
M2())@DJ"I[%+@DR"38).@D^"4()1@E*"J+%3@E2"J;&JL56"5H)7@EB"68):
M@JNQK+%A@F*"K;%C@F2"98*NL6:"9X)H@FF":H)K@FR"K[&PL6V"L;%N@K*Q
M;X)P@G&"<H)S@G2"L[%U@G:"=X*TL7B">8)Z@K6Q@8*"@H."A(*%@H:"AX*(
M@K:QB8*WL8J"BX*,@HV"CH*/@I""D8*XL;FQDH*3@KJQE(*5@KNQO+&]L;ZQ
MEH*7@IB"F8*_L<"QP;&:@L*QFX+#L<2QG(*=@IZ"GX*@@L6QQK&A@J*"Q[&C
M@J2"I8+(L::"IX*H@JF"JH*K@JR"K8*N@J^"L(+)L<JQL8*R@K."M(*U@K:"
MR[&W@KB"N8*Z@KN"O(*]@KZ"OX+`@L&"PH+#@L2"Q8+&@L>"R(+,L<F"RH++
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MAKF&X+/AL[J&NX;BL[R&O8:^AN.SOX;`AL&&PH;#AL2&Q8;DL^6SQH;'AN:S
MY[/(ALF&Z+/*ALN&S(;IL\V&SH;/ANJST(;1AM*&TX;4AM6&UH;7AMB&V8;:
MAMN&W(;=AMZ&WX;@AN&&XH;CAN2&Y8;FANNS[+/GANB&[;/IANJ&ZX;NL^R&
M[[/MANZ&[X;PAO&&\+/QL_*&\K/SAO.S](;UAO:&]X;TL_6S]K/XAOF&^H;W
ML_N&_(;]AOBS_H9!AT*'0X=$AT6'1H='ATB'28=*A_FS2X=,ATV'3H=/AU"'
M48=2AU.'5(=5AU:'5X=8AUF'6H=AAV*'8X=DAV6'9H=GAVB':8=JAVN';(=M
MAVZ';X=PAW&'<H=SA_JS=(=UAW:'^[-WAWB'>8?\LWJ'@8>"AX.'A(>%AX:'
M_;/^LX>'H;2(AXF'BH>+AXR'C8>.AX^'HK2CM)"'D8>DM)*'DX>4AZ6TE8>6
MAY>'F(>9AYJ'FX><AZ:TG8>GM)Z'J+2?AZ"'H8>BAZ.'I(>IM*JTI8>FAZNT
MIX>HAZRTK;2IAZJ'JX>LAZV'KH>OAZZTK[2PA["TL8>QM+*'LX>TA[6'MH>W
MA[*TN(>YA[J'NX>\A[V'OH>_A\"'P8?"A\.'Q(?%A\:'QX?(A\F'RH>SM,N'
MS(?-A\Z'SX?0A]&'M+32A].'U(?5A]:'UX?8A]F'VH?;A]R'W8?>A]^'X(?A
MA^*'XX?DA^6'YH?GA^B'Z8?JA^N'[(>UM.V'[H?OA[:T\(?QA_*'M[3SA_2'
M]8?VA_>'^(?YA[BTN;3ZA_N'_(?]A_Z'08A"B$.(1(A%B+JTN[1&B$>(2(A)
MB$J(2XB\M$R(38A.B$^(4(A1B%*(O;2^M%.(5(A5B+^T5HA7B%B(68A:B&&(
MP+3!M&*(8XC"M&2(98AFB,.TQ+3%M&>(:(AIB&J(:XC&M,>T;(C(M&V(R;3*
MM&Z(;XAPB,NT<8C,M'*(<XATB,VT=8AVB'>(SK1XB'F(>HB!B(*(@XB$B(6(
MAHB'B(B(B8B*B(N(C(B-B(Z(CXB0B,^TT+21B)*(T;23B)2(E8C2M):(T[27
MB)B(F8B:B)N(U+35M)R(UK2=B->TGHB?B*"(H8C8M**(V;3:M-NTHXC<M*2(
MI8C=M-ZTW[3@M.&TIHBGB*B(XK3CM.2TJ8CEM.:TY[3HM.FTJHBKB*R(ZK3K
MM.RTK8BNB.VTKXBPB+&([K2RB+.(M(BUB+:(MXBXB.^T\+2YB/&T\K3SM+J(
MNXB\B+V(OHB_B/2TP(C!B,*(PXC$B,6(QHC'B,B(R8C*B,N(S(C-B,Z(SXC0
MB-&(THC3B-2(U8C6B->(V(C9B-J(VXC<B-V(WHC?B."(X8CBB..(Y(CEB.:(
MYXCHB.F(ZHCKB.R([8CNB.^(\(CQB/*(\XCTB/6(]HCUM/:T][3WB/BT^(CY
MB/FT^K3ZB/NT_+3[B/R(_8C^B/VT_K1!B:&U0HFBM4.)H[5$B46)I+5&B:6U
MIK5'B4B)I[5)B4J)2XFHM4R)38E.B4^)4(E1B5*)J;6JM5.)J[6LM:VU5(E5
MB5:)5XE8B5F)KK5:B6&)8HFOM6.)9(EEB;"U9HEGB6B):8EJB6N);(EMB6Z)
M;XEPB;&ULK5QB7*)<XETB76)=HFSM7>)>(EYB;2U>HF!B8*)@XF$B86)AHF'
MB8B)B8F*B8N)C(F-B8Z)CXF0B9&)DHF3B92)E8F6B;6UMK67B9B)M[69B9J)
MN+6YM9N)NK6<B;NUG8F>B9^)O+6]M:")OK6AB;^UHHG`M:.)P;6DB:6)PK6F
MB:>)J(G#M:F)JHFKB<2UK(FMB:Z)KXFPB;&)LHFSB;2)M8FVB;>)N(FYB;J)
MNXF\B;V)OHG%M;^)P(G!B<*)PXG$B<6)QHG'B<B)R8G*B<N)S(G-B<Z)SXG0
MB=&)QK72B=.)U(G5B=:)UXG8B<>UV8G:B=N)R+7<B=V)WHG)M=^)X(GAB>*)
MXXGDB>6)RK7+M>:)S+7GB>B)Z8GJB>N)[(GMB>Z)S;7OB?")\8GRB?.)](GU
MB?:)]XGXB?F)^HG[B?R)_8G^B4&*0HI#BD2*18I&BD>*2(I)BDJ*2XK.M<^U
M3(I-BM"U3HI/BE"*T;51BE**4XI4BE6*5HI7BM*UT[58BM2U68K5M5J*88IB
MBF.*9(IEBM:U9HIGBFB*:8IJBFN*;(IMBFZ*;XIPBG&*<HISBG2*=8IVBG>*
M>(K7M7F*>HJ!BH**@XJ$BH6*V+6&BH>*B(J)BHJ*BXJ,BHV*CHJ/BI"*D8J2
MBI.*E(J5BI:*EXJ8BIF*V;6:BIN*G(J=BIZ*GXK:M:"*H8JBBMNUHXJDBJ6*
MW+6FBJ>*J(JIBJJ*JXJLBJV*W;6NBMZUKXK?M;"*L8JRBK.*M(JUBN"UMHJW
MBKB*X;6YBKJ*NXKBM;R*O8J^BK^*P(K!BL**X[7#BL2*Q8K&BN2UQXK(BLF*
MRHK+BLR*Y;7FM<V*SHKGM<^*T(KHM>FUT8KJM=**TXK4BM6*UHKKM>RUUXKM
MM=B*[K79BMJ*VXK<BMV*WHKOM=^*X(KABN**XXKDBN6*YHKGBNB*Z8KJBNN*
M[(KMBNZ*[XKPBO&*\HKSBO2*]8KVBO>*^(KYBO"U\;7ZBON*\K7\BOV*\[7T
MM?Z*08M"BT.+1(M%BT:+];7VM4>+][7XM?FU^K5(BTF+2HM+BTR+^[7\M4V+
M3HO]M4^+4(M1B_ZU4HM3BU2+58M6BU>+6(NAMJ*V68NCMJ2VI;9:BV&+8HMC
MBV2+IK:GMJBV98MFBZFV9XMHBVF+JK9JBVN+;(MMBVZ+;XMPBZNVK+9QBZVV
MKK:OMG*+<XMTBW6+=HMWBWB+>8MZBX&+@HN#BX2+A8N&BX>+B(N)BXJ+BXN,
MBXV+CHN/BY"+D8N2BY.+E(N5BY:+EXN8BYF+FHN;BYR+G8N>BY^+H(NABZ*+
MHXNDBZ6+IHNGBZB+J8NJBZN+K(NMBZZ+KXNPB[&+LHNSB[2+M8NPMK&VMHNW
MB[*VN(NYB[J+L[:[B[2VM;:\B[V+OHN_B[:VM[;`B[BVN;:ZML&+PHO#B\2+
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MGY"@D*&0MKBWN**0HY"XN*20N;BZN+NXO+B]N*60II"GD*B0J9"^N+^XJI#`
MN*N0P;C"N*R0K9##N*Z0Q+C%N,:XKY"PD,>XL9"RD+.0R+BTD+60MI"WD+B0
MN9"ZD,FXRKB[D,NXS+C-N,ZXO)"]D+Z0OY#`D,^XT+C!D,*0PY#$D,60QI#1
MN,>0R)#)D,J0RY#,D,V0SI#/D-"0T9#2D-*XTY#4D-60UI#7D-B0V9#:D-N0
MW)#=D-Z0WY#@D.&0XI#CD.20Y9#FD.>0Z)#ID.J0ZY#LD.V0[I#OD/"0\9#R
MD/.0])#3N-2X]9#VD-6X]Y#XD/F0UKCZD->X^Y#\D/V0_I!!D=BXV;A"D=JX
M0Y';N-RX1)%%D4:11Y'=N-ZXW[A(D4F1X+A*D4N13)'AN$V13I%/D5"149%2
MD5.1XKCCN%21Y+CEN.:X59%6D5>16)%9D5J1Y[CHN&&18I'IN&.19)%ED>JX
M9I%GD6B1:9%JD6N1;)%MD6Z1;Y'KN.RX[;APD>ZX<9%RD7.1=)'ON'61=I%W
MD7B1>9%ZD8&1@I&#D821A9&&D8>1B)&)D8J1BY&,D8V1CI&/D9"1D9&2D9.1
ME)&5D?"X\;B6D?*X\[B7D9B1F9'TN)J1];B;D9R1G9&>D9^1]KCWN*"1^+BA
MD?FXHI&CD:21I9&FD:>1^KBHD:F1JI'[N*N1K)&MD:Z1KY&PD;&1LI&SD;21
MM9&VD;>1N)&YD?RX_;BZD;N1O)&]D;Z1OY'`D<&1PI'#D<21Q9'&D<>1R)')
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MOYK`FL&:PIK#FL2:Q9K&FL>:R)K)FLJ:RYK,FLV:SIK/FM":T9K2FM.:U)K5
MFM::UYK8FMF:VIK;FMR:W9K>FL.]Q+W?FN":Q;WAFN*:QKW'O>.:Y)KEFN::
MYYKHFLB]R;W*O>F:R[WJFLR]ZYKLFNV:[IK-O>^:SKW/O?":T+W1O?&:\IKS
MFM*]])KUFO::]YKXFOF:^IK3O=2]^YK\FM6]UKW]FOZ:09M"FT.;U[W8O=F]
M1)M%F]J]1IM'FTB;V[U)FTJ;2YM,FTV;3IM/F]R]W;U0FU&;WKW?O5*;4YM4
MFU6;5IM7FUB;69M:FV&;8IMCFV2;99MFFV>;:)MIFVJ;:YMLFVV;;IMOFW";
M<9MRF^"]<YMTFW6;=IMWFWB;>9MZFX&;@IN#FX2;A9N&FX>;B)N)FXJ;BYN,
MFXV;CIN/FY";D9N2FY.;E)N5FY:;EYN8FYF;FIOAO>*]FYN<F^.]G9N>FY^;
MY+V@F^6]H9NBFZ.;I)NEF^:]Y[VFFZ>;Z+WIO:B;J9NJFZN;K)NMF^J]KINO
MF[";Z[VQF[*;LYOLO;2;M9NVF[>;N)NYF[J;NYN\F[V;OIN_F\";P9O"F\.;
MQ)O%F\:;QYO(F\F;RIO+F\R;S9O.F\^;T)O1F]*;TYO4F]6;UIO7F]B;V9O:
MF]N;W)O=F]Z;WYO@F^&;XIOCF^2;Y9OFF^V]YYOHF^F;ZIOKF^R;[9ONF^^;
M\)OQF_*;\YOTF_6;]IOWF_B;^9OZF_N;_)O]F^Z][[W^FT&<\+U"G$.<\;WR
MO42<\[U%G$:<1YQ(G$F<]+WUO4J<2YQ,G/:]39Q.G$^<4)Q1G%*<][WXO5.<
M5)SYO56<5IQ7G%B<69Q:G&&<8IQCG&2<99QFG&><:)QIG/J]:IQKG&R<;9QN
MG&^<<)S[O7&<<IQSG'2<=9QVG'><>)QYG'J<@9R"G(.<A)R%G(:<AYR(G(F<
M_+V*G(N<C)R-G(Z<CYR0G/V]D9R2G).<_KV4G)6<EIRAOI><F)R9G)J<FYR<
MG)V<HKZCOIZ<GYR@G*&<HIRCG*2<I9RFG*><I+ZHG*F<JIRKG*R<K9RNG*^<
ML)RQG+*<LYRTG+6<MIRWG+B<N9RZG+N<O)R]G+Z<OYS`G,&<PIREOJ:^PYS$
MG*>^Q9S&G,><J+[(G,F<RIS+G,R<S9S.G*F^JK[/G-"<T9RKOM*<TYS4G-6<
MUIS7G*R^V)S9G-J<VYS<G-V<WIS?G."<X9SBG..<Y)SEG.:<YYSHG.F<ZIRM
MONN<[)SMG.Z<[YSPG/&<KK[RG/.<])SUG/:<]YSXG/F<^IS[G/R<_9S^G$&=
M0IU#G42=19U&G4>=2)U)G4J=2YU,G4V=3IVOOD^=4)U1G;"^4IU3G52=59U6
MG5>=6)U9G5J=89UBG6.=9)UEG6:=9YUHG6F=:IUKG6R=;9UNG6^=<)UQG7*=
M<YUTG76==IUWG7B=>9UZG8&=@IV#G82=A9V&G8>=B)V)G;&^BIV+G8R=C9V.
MG8^=LKZSOI"=D9VTOI*=DYV4G;6^E9VVOI:=EYV8G9F=M[ZXOKF^FIV;G9R=
MG9V>G9^=H)VAG:*=HYVZOJ2=I9VFG;N^IYVHG:F=O+ZJG:N=K)VMG:Z=KYVP
MG;V^L9VRG;.=M)VUG;:=MYVXG;F=NIV[G;Z^O[Z\G;V=P+Z^G;^=P)W!OL&=
MPIW#G<2=Q9W&G<>=PK[#OLB=Q+[)G<6^RIW+G<R=S9W.G<^=QK['OM"=T9W(
MOLF^RK[2G<N^S+[-OM.=U)W5G=:=SK[/OM"^UYW1OM*^T[[8G=F=VIW4OM6^
MVYW6OM>^W)W=G=B^WIW?G>"=V;[AG>*=XYWDG>6=YIWGG=J^V[[HG=R^W;[>
MONF=ZIWKG>R=[9WNG=^^X+[OG?"=X;[QG?*=\YWBOO2=]9WCOO:=]YWXG?F=
MY+[EOOJ=YK[[G>>^_)W]G?Z=Z+Y!GNF^ZKY"GD.>1)[KOD6>1IY'GNR^2)Y)
MGDJ>2YY,GDV>3IY/GNV^4)Y1GE*>4YY4GE6>5IY7GEB>69[NON^^6IYAGO"^
M\;YBGO*^\[[TOO6^8YYDGF6>9IYGGO:^][[XOOF^^K[[OOR^:)[]OFF>_KYJ
MGJ&_HK]KGFR>H[]MGFZ>;YZDOW"><9YRGG.>=)YUGG:>I;^FOW>>I[]XGJB_
M>9YZGH&>@IZ#GH2>J;^JOZN_A9ZLOX:>AYZ(GJV_B9ZNOZ^_BIZ+GHR>C9ZP
MO[&_LK^SO[2_M;^.GH^>D)ZVO[>_N+^YOY&>DIZ3GKJ_E)Z5GI:>N[^7GIB>
MF9Z:GIN>G)Z=GKR_O;^>GKZ_O[^?GJ">H9ZBGJ.>I)ZEGL"_P;^FGJ>>PK^H
MGJF>JI[#O\2_Q;^KGL:_K)ZMGL>_R+_)OZZ>RK^OGLN_L)[,O[&>LIZSGK2>
MS;_.O[6>MI[/O[>>N)ZYGM"_NIZ[GKR>O9Z^GK^>P)[1O]*_P9[3O]2_U;_"
MGL.>Q)[%GL:>QY[6O]>_R)[)GMB_RI[+GLR>S9[.GL^>T)[1GM*>TY[4GMF_
MU9[6GMJ_UY[;O]B>V9[:GMN>W)[=GMR_W;_>GM^>WK_@GN&>XI[?O^.>Y)[E
MGN:>YY[HGNF>X+_AO^J>XK_KGN._[)[MGNZ>[Y[PGO&>Y+_EO_*>\Y[FO_2>
M]9[VGN>_]Y[XGOF>^I[[GOR>_9[HO^F__I[JOT&?Z[]"GT.?1)]%GT:?1Y_L
MO^V_2)])G^Z_2I]+GTR?[[_PO_&_39].GT^?4)]1G_*_\[]2G_2_4Y_UOU2?
M59]6GU>?6)]9G_:_][]:GV&?^+]BGV.?9)_YOV6?9I]GGVB?:9]JGVN?^K_[
MOVR?;9_\O_V_;I]OGW"?<9]RGW.?_K^AP'2?=9^BP':?=Y]XGZ/`>9]ZGX&?
M@I^#GX2?A9^DP*7`AI^'GXB?IL")GXJ?BY^,GXV?CI^GP*C`CY^0GZG`D9^2
MGY.?JL"4GY6?EI^7GYB?F9^:GZO`K,";GZW`G)^NP)V?GI^?GZ"?H9^BGZ_`
ML,"CGZ2?L<"EGZ:?IY^RP*B?J9^JGZN?K)^MGZZ?L\"TP*^?M<"PG[;`L9^W
MP+*?LY^TG[6?N,"YP+:?MY^ZP+B?N9^ZG[O`NY^\G[V?OI^_G[S`P)^]P+[`
MP9^_P,*?P,#!P,+`P\#$P,7`QL#'P,.?Q)_%G\C`QI_'G\B?R<#)G\J?RY_,
MG\V?SI_/G\K`T)_1G\O`TI_3G]2?U9_6G]>?V)_9G\S`S<#:G]N?SL#<G]V?
MWI_/P-#`T<#?G^"?X9_BG]+`T\#4P..?U<#6P-?`V,#DG^6?YI_9P.>?VL#;
MP.B?Z9_<P.J?W<#>P-_`ZY_@P.R?[9_NG^^?\)_AP.+`\9_CP.3`Y<#FP/*?
M\Y_TG_6?]I_GP.C`]Y_XG^G`^9_ZG_N?ZL#\G_V?_I]!H$*@0Z!$H.O`[,!%
MH.W`[L#OP$:@1Z!(H$F@2J!+H/#`\<!,H$V@\L!.H//`3Z#TP%"@4:!2H%.@
M5*!5H%:@]<!7H%B@6:!:H/;`8:!BH&.@9*!EH&:@]\!GH&B@::#XP&J@:Z!L
MH/G`;:!NH&^@<*!QH'*@<Z!TH'6@=J!WH'B@>:!ZH(&@@J"#H(2@A:#ZP/O`
MAJ"'H/S`B*")H(J@_<"+H/[`C*"-H(Z@CZ"0H*'!HL&1H*/!DJ"DP:7!DZ"4
MH)6@EJ"7H*;!I\&8H)F@J,&:H)N@G*"IP9V@GJ"?H*"@H:"BH*.@JL&KP:2@
MK,&EH*W!IJ"GH*B@J:"JH*N@KL&LH*V@KJ"OP:^@L*"QH+#!LJ"SH+2@M:"V
MH+>@N*"QP;+!N:"ZH+/!M,&[H+R@O:"^H+^@P*"UP<&@PJ##H,2@Q:#&H,>@
MR*#)H,J@RZ#,H,V@SJ#/H-"@T:#2H-.@U*#5H-:@UZ#8H-F@VJ#;H+;!M\'<
MH-V@N,'>H-^@X*"YP>&@NL'BH..@Y*#EH.:@N\&\P>>@O<'HH+[!O\'`P>F@
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MOY6_EK^]QY>_F+^9OYJ_F[^<OYV_OL>>OY^_O\>@O\#'0<!"P$/`1,!%P$;`
MP<='P$C`2<#"QTK`2\!,P,/'3<!.P$_`4,!1P%+`4\#$Q\7'5,#&QU7`5L!7
MP%C`6<!:P&'`8L!CP&3`9<!FP&?`:,!IP&K`:\!LP&W`;L!OP'#`<<!RP'/`
M=,!UP';`=\!XP'G`>L"!P(+`@\"$P,?'R,>%P(;`R<>'P(C`B<#*QXK`B\",
MP(W`CL"/P)#`R\?,QY'`S<>2P,['D\"4P)7`EL"7P)C`S\?0QYG`FL#1QYO`
MG,"=P-+'GL"?P*#`0<'3QT+!0\'4Q]7'1,'6QT7!U\=&P4?!2,%)P4K!2\'8
MQ]G'3,%-P=K'3L%/P5#!V\=1P5+!4\%4P57!5L%7P=S'W<=8P=['W\?@QUG!
M6L%AP6+!8\%DP>''9<%FP6?!:,%IP6K!:\%LP6W!;L%OP7#!<<%RP7/!=,%U
MP7;!=\%XP>+'><%ZP8'!@L&#P83!A<&&P8?!B,&)P8K!B\&,P8W!CL&/P9#!
MD<&2P9/!E,&5P9;!E\&8P9G!FL&;P9S!G<&>P9_!H,'CQ^3'0<)"PN7'0\)$
MPD7"YL=&PN?'1\)(PDG"2L)+PNC'Z<=,PNK'3<+KQT["3\)0PE'"4L)3PNS'
M[<=4PE7"[L=6PE?"6,+OQUG"6L)APF+"8\)DPF7"\,?QQV;"\L=GPO/':,)I
MPFK":\)LPFW"],?UQV[";\+VQW#"<<)RPO?'<\)TPG7"=L)WPGC"><+XQ_G'
M>L+ZQ_O'_,>!PH+"@\*$PH7"AL+]QX?"B,*)PO['BL*+PHS"H<B-PH["C\*0
MPI'"DL*3PI3"HLB5PI;"E\*8PIG"FL*;PIS"G<*>PJ/(I,B?PJ#"I<A!PT+#
M0\.FR$3#1<-&PT?#I\A(PTG#J,BIR$K#JLA+PZO(3,--PT[#K,A/PU##K<BN
MR%'#4L.OR%/#5,-5P[#(5L-7PUC#6<-:PV'#8L-CPV3#9<.QR&;#LLAGPVC#
M:<-JPVO#;,.SR+3(;<-NP[7(;\-PPW'#<L-SPW3#=<-VPW?#>,-YPWK#@<."
MP[;(@\.WR(3#A<.&PX?#B,.)P[C(N<B*PXO#NLB,PXW#CL.[R(_#D,.1PY+#
MD\.4PY7#EL.\R)?#O<B8P[[(F<.:PYO#G,.=PY[#O\B?PZ##0<3`R$+$0\1$
MQ,'(1<1&Q$?$2,1)Q$K$2\1,Q,+(3<3#R$[$3\10Q%'$4L13Q%3$5<3$R,7(
M5L17Q,;(6,19Q%K$Q\AAQ&+$8\1DQ,C(9<1FQ,G(9\1HQ,K(:<3+R&K$:\1L
MQ&W$;L1OQ,S(<,1QQ'+$S<ASQ'3$=<3.R';$=\1XQ'G$>L2!Q(+$S\B#Q(3$
MA<2&Q-#(A\2(Q(G$BL2+Q(S$T<C2R(W$CL33R(_$D,21Q-3(DL23Q)3$E<26
MQ)?$F,29Q)K$F\2<Q)W$U<B>Q)_$H,1!Q4+%0\76R-?(1,5%Q=C(1L5'Q4C%
MV<A)Q4K%2\5,Q4W%3L5/Q=K(V\A0Q=S(4<7=R%+%4\54Q57%5L57Q=[(W\A8
MQ5G%X,A:Q6'%8L7AR&/%9,5EQ6;%9\5HQ6G%XLAJQ6O%X\ALQ>3(;<5NQ6_%
M<,5QQ7+%Y<CFR'/%=,7GR'7%Z,CIR.K(Z\AVQ7?%>,5YQ7K%@<7LR.W(@L7N
MR(/%[\B$Q87%AL7PR(?%B,7QR(G%BL6+Q?+(C,6-Q8[%\\B/Q9#%D<62Q9/%
ME,65Q?3(]<B6Q9?%F,7VR)G%FL6;Q9S%G<6>Q??(^,B?Q:#%^<A!QD+&0\;Z
MR$3&1<9&QD?&2,9)QDK&^\C\R$O&_<A,QO[(3<9.QD_&4,91QE+&````````
M````````````````````````_NT`````````````````````IMH`````[.``
M````````````S?@``-++````````SNL``-CYV?G@RLK:````````ILL`````
M`````````````````````,C*[OGLVP````"QT```````````[]4```````#S
MY@```````````````````````*+GV>0``````````````````````````.'D
M`````,3\````````````````````````[_GTS^;W`````````````+S.````
M``````#%]*/<````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````O=T``````````,;T
M`````````````````````*'X````````UN@```````#!VP``````````````
M``````#F\````````+GD[?8``*[Y``"^W0```````````````+#7Z-B]RP``
M``#:^0``````````````````````````SOCP^>W@L^.S]`````#"ZN;RMO``
M````````````UML`````````````Y.L`````Y_(``-77MM3H^<'7````````
M``#5Y0``````````````````ZNG,UP```````.G3R>(``-O\K<T`````````
M````L,RBZ@````#VY,#0``"W\*'N````````````````]M<```````#*XLOB
M``#/^@```````````````-_K`````````````,O6````````M/0`````````
M`,WMTN0`````J>JZY*+STLT``,OV``#F\<'MO.C1[@```````````````.?P
MS.(`````JN0``.'UVNT`````````````[M?QT0``````````Z^GLZ>3@````
M``````"GVM3=``"CZ@```````,/6]-8``-_:``"S[P``````````S>(`````
M````````_>_H\@```````````````````````,7O``#GYP````#]UP````#.
MYP````#<WP``Q_D`````````````````````]MD`````````````````````
MK-\``-K6````````````````I-P```````"X\```````````^M4``/?D````
M````Q-8`````````````````````[/0``````````/[O`````````````*'P
M``"JW@````"\VOS8````````````````U/H```````#E[```````````````
M`*C\`````.;L`````,O8````````````````````````````````````````
M``"Y^P``T^0``/G-``````````````````````````````````````````#3
MSP``````````````````ZLH`````U,\``+WX````````````````````````
M````````````````````````````````````````Q_0``````````-_J````
M``````````````#;^0````````````````````"WU```````````````````
M````````````````````````````````````````Y>L`````TN$`````````
M`*3J````````POKA^^WZHO#QS```H_KWX@``SN(``/7I``#KX0```````.CG
MU^CXVLO4````````]O?%U@``````````````````````````````````````
M``````````````#IU`````#Z^@``````````````````\LS=]P``NMX`````
M`````````````````````*C.`````````````+GP_N3)Y`````````````#4
MY````````,/J``"T[P```````+[7````````````````XOL``-/-````````
MM>\```````#I^@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"F^0``````````````
M`+W?``#']P```````````````````````````````````````````````/WX
M`````/SX``````````````````````````````````````````````````"K
MWNC;`````-WC``#BX<;1``````````````````````````#0]N;K^=H`````
M`````,?L``````````````````#XWNGXWN,``````````/7.````````````
M`,/ZU^4``,CL````````R?,`````N^0``````````*[F`````````````+;O
M``"_W```````````````````O<X`````````````````````````````````
M`````````````````````````````````````````,/8````````S]```/K/
MRO/7X````````,?1KND``+WH`````,3Z````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````,_B`````,7Z````````N/D``````````````````.#<
M`````+#[````````J=C?Y:?Y`````.[V``#,]OCB``````````#Q[```````
M````````````X-H`````````````````````````````````````TO',TLO/
M`````+W*````````O]T```````#O]@``^=X`````````````````````````
M`````````+3Z````````K=4``````````````````````````````````.?Q
M``"^W@```````````````,#<`````````````,C1R=$`````````````````
M``````"^^`````````````````````````````````````````````#VRP``
M````````^=0`````````````XO73X0````````````````````#IV`````#^
M^```S,\``````````````````*3]``````````````````#VS@``T/H`````
M\\R^Y@```````*[V`````/#5`````,K1````````OOSQU0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````Z<T`````````````````````````````
M``````````"U^@``````````````````````````````````````````````
M``````````````````````#0XO?T````````U,T`````````````````````
M``````````"CYP````````````````````"EVP``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````T>(`````````````````````````
M``````"BUP````#C]P```````````````*;J````````````````````````
M``"AT```````````VL[K^Z;;WMOEV````````````````````````.#J````
M``````"JV`````````````#@Y0``````````````````````````````````
M``````````````````#;U@``````````````````````````````````````
M`````````````````````````````````````````,;O`````.KX````````
M``````````````````````````#5Y`````````````````````````````#W
MS@````#8X```````````````````````````````````````````````````
M``````````````````#OUP```````````````````````````````.WT````
M``````````````````````````````#FS0```````/3,````````````````
M````````````````````````````````````````````````````````````
M````````````````````X_4`````RN0``.'<`````,CY````````````````
M````````````````````````O_P```````````````````````````````"G
MZ`````````````````````#$V`````````````````````````````"^RP``
MKMP``````````````````````````````````/?7````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````Z/``
M`,#=``#-SP```````````````````````//<L-D``.GF````````````````
M````````````````````````````````O.0`````````````````````````
M````````````````````Q.H``````````````````````````.SD``#EY```
M`````````````````````````````````````````````/C[````````````
M````````````````````````````````````````````N\P`````````````
M````````````````O>0`````W,WWV0``````````````````````````W]T`
M````````````SNT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#0V0````````````"CY0``
M````````S?D```````````````````````````````````````"NS0``````
M`````````````````````````````````````````,[/````````````````
M`````````````````````````````````````````````````````*_V````
M`````````-/][>O<U@``````````````````````````````````````````
M````````````````````````````````````````I.4```````"VU0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#=U@```````.GY````
M````I.<``./6````````````````````````````````````````````````
MR]'DU@```````/+5`````````````/K>``#XUP````````````#JV```````
M``````````````````````````````#5S_W8`````````````*O8`````,O]
M``````````#<_````````````````````````*C@\]4`````V?T`````H\P`
M``````#YV0````#JT_7U``#'[P```````````````````````-K3````````
M`````````````````````+W:````````````````````````````````````
M````````````J.BOW`````````````"C\```````````U<T`````````````
M``````````````````"IX```````````````````````````````````````
M``````````````````````````````"LW@``````````````````````````
M``````````"Z\+'N`````++N````````S?8`````````````````````````
M``````#2[@``QM8`````````````Y>``````N_,``.'E````````````````
M``````````#+Y```````````````````````````````````````````````
M`````````*/7`````,+;``````````#^R@```````````````,_/````````
M``````````````````#I[,OO``#2]@```````++8V^VRW[[?N_D``/3<````
M````Y/4`````IO/@W:;A``#XSK#<``````````"JXP``````````````````
M``````````````````#I\0``````````^LT`````````````K_RATP``J_$`
M``````````````#1YZS2``#YS@````````````#]\0``O]ZZ^[GY````````
M````````TLX``*OCX.L```````#ZSO?+I>4`````````````````````````
M````X<H``,S4`````````````.'J`````./<K=\```````````````#KRP``
M`````*_5````````]=8``/CE`````,#>H^P``,WI``"GZO;IN_L``.GGS.\`
M````YM``````P=X`````K.0`````S-CQ^0``W\ZD^K+F``#[^@````"]^LC,
MS>_5U0``````````````````HM,```````#1[`````````````"GY-+L````
M`+'V`````/O.`````-'0O\L``*3M````````````````J.W"WN+VW.WUW+G@
M````````SM0``+7T````````V].UUJ3L``````````````````````````#F
MY```ZO$```````#LR\#+````````\NP`````````````ZM``````````````
M`````/+YI>S?T```ZN?KT-'<Z=O,_0``````````````````````````````
M``````````````````````````````````````````````#7VP``````````
MX=H``+;6``#?XP``P]X``,3>H<H`````````````[.X`````H].W[L_X````
M``````#(ZKCNK/&E\<[I````````O/D```````#YY>KLUMW"[0``````````
M`````````````````````*7X`````````````+KEV-L`````HLH`````S=$`
M``````#M[@```````.OLQ=X``.#C``#)RNGR``#.U0``MO8``,+.Q]8``+3C
M``"M\0``XNH``````````,+7``"G\P````#JS0``[NL`````````````````
M`````````````````````````++9I?T`````````````U?;BU0``````````
M``````````"U^`````#US+7UK>0``````````.OGU?$```````"[\`````"U
MZ0``R<S5^@````#4X0````#6UP````#!W```QM[O^N'C````````````````
M````````````````\^'VW```_,X``,3;``#Q^`````#DW```[^4`````````
M`````````+'<````````UM4`````VO,``,'+``##VP```````/K9[M,`````
M``"X^@````"F_>_K``"F]```RLRH\P``V_,``*?;M_8``.;/\O#:RP``TN?#
MU_#VWN@``````````````````````````````````*;E````````````````
M``#GY0```````*/*I\S)Z@````````````"V^`````````````"E^@``````
M````KO$``,[O`````````````````````.W+````````````````````````
M`````````````+#VS^_/Z0``WO<``````````````````-/.``````````#W
MW```````````````````J-L```````#XRP```````````````*'?X=T`````
M``````````````````````````````````````````#*];;I``````````#L
MY^[N``#P\P``O]\```````````````#+S````````````````,'0````````
MTO2ZX```````````P-\``.#.````````TMSJ_0```````/;6````````RNH`
M``````````````#IZ```K.,`````````````T/,`````````````````````
M````````I,H``/C;````````Q][PZ];Q`````.+E``#,S`````#[RP``````
M``````````````#CZ@```````````````````````````````,'?``#MU@``
M``````````````````#0Z0``````````````````N>X``````````./5````
M`-/1``#PY0```````+3HP^L``*KJ_/KV];SPU/V[X,/.``"ZT+KW\]C-]P``
M`````*[D````````````````````````W]0`````````````Y]``````_>P`
M`*[2[^[7U>3JHOCKS;_7L?L`````[,T```````"RW.S0_<[P[@```````,+,
M````````[=``````````````]^4```````#\\P````"B[@``````````L]D`
M````]-@``+?I`````````````````````*[.``````````"BV0``````````
M\=@``,_4````````````````````````I^72U0````````````"IU@``````
M`````````*+T``#7\0````#8U0``O?#0U]#4````````````````````````
M`````````````,_7ZNOK_0````#MVP``````````````````````````````
M``````#%_,++``````````#5_0``R/3JZ//U`````-[Y`````._3`````-/L
M`````,+=M^_4YP``RLH```````#[V0````#]^@````````````"JU@``````
M``````#X]````````````````/?WK-P```````#7UZ+?````````OLX``/#3
M`````````````*3P[.'GS\OSJ>V^R@``````````````````[_0```````#.
M]@````#[WKO0M]7Q[@```````````````*CT``#XW```````````I\L``,[:
M````````YN```````````````````*7M\NX``````````/G<`````-SY````
M`-SS``````````````````#R^```^?0```````#Q_````````+S0^=NQUP``
M`````/S+````````I?#]RP````````````````````#TU0```````.W-I<H`
M````J];"T```````````OO"]TJ3,````````````````````````````````
M````````````````MOH`````S<P``/K:``#/]@``N.D``/78````````SLP`
M`````````,W7`````-'4[>D``.O*XMD``++]``"MX\S6M-D`````I^'3[L/0
M`````````````````````````````````````+/]``#DU0````#HSP``P^VR
MT`````#^SJC:`````````````-#X`````-;]``````````#1^```TOC3W```
M````````XMWY^\'=``"UXP```````````````-WMQ,X``*'+````````````
M````X]T``````````-W\````````````````````````K_D`````````````
M^]*ASZCD``"V]/[L`````*[C[>?!_>+:`````+/8````````Y-WO\/'V\/H`
M````]=$`````S]H``-3<``"FW```O^\`````````````S\X``-G@````````
M````````UMG4[,OJ`````+_*L-4``.G/`````````````.WQ``#/S```````
M````^.0`````````````````````````````````````[>0``````````-C7
M``"G_0``````````J^JR]@``````````\,^]^0```````````````/3F````
M``````````````````````````````#;RP``````````````````T?,`````
M`````-'IJ?/@T-+I``#CV@```````````````-+B``"B]O3A````````Y-H`
M````````````U>>_]:+/K\VCSP```````+#-_O&CT*_AH_@``*;*N_?J\LC>
MT^D``````````,G>``````````````````````````#>_<#*````````ZOG.
MT=3N``#2U*/9J/W9U\[WOOH```````````````````````#6SP``\-<``.'K
MQ?@`````````````^MP`````P]T``-_Y``````````````````#OYP``````
M````Y?VC]@``_-FI_0``[N<```````#EU0````````````#0[P``L<T`````
M``````````"B]P``````````````````````````````````````````````
M````````````LO$``+'Q````````````````LLT``*O:``"GR@``````````
M``#BX[S[I-D`````NNX`````````````T_@`````````````^OL``*3/``#[
MW```````````````````````````````````````````````````X_8`````
M``"J[0````"A\N'.````````````````IOH``````````.#Y``````````#6
M[`````#NY*'Y`````._[````````Z_FC[@``````````````````````````
M``````````````````````````````````"LZ@```````*C*`````/KT````
M``````#6S?;\````````R?0``````````````````-3X````````````````
M````````IO@``,K>QO(```````````````#:UP``T-,`````````````````
M````````````Q=@`````````````````````````````````````````````
M``#FZ@``W?,```````#:Y`````````````````````#D]@````````````#R
M]@``PM\`````````````````````_=D```````#VS`````"ZTP``````````
M````````K^0``````````.'Y````````````````````````````````````
M````````````````````````````IO````````#3RP```````+S@``#*]/K4
M``"J_>+Y``````````````````````````````````"W],+]L/P``.S]XLH`
M``````````````````````"]_0``Y^K#W]+1XLX``*33````````````````
M``````````````````````````````````````````"K_0``X-\`````````
M``````````````````````#'\@````````````#PYP``[M``````JO,`````
M``#+WKCV````````````````````````````````````````````````````
M````````````]>&S\0``````````````````H_<`````J<H`````````````
M`````````````*7/`````,3?````````````````````````````````````
M`````````````````````````+#A`````+_P``"D]@``MN,`````````````
M````````````````````````````````````````````````````````````
M`,;Z`````````````````````````````````````````````````````._0
M`````.W]`````````````````````,3=````````````````````````````
M`````````````````/?\````````````````````````````````````````
M````````````````````````````````````````O^8```````````````"M
MW@``O_H`````````````\>4``````````````````,3M````````````````
M``````````````````"ET@````#N_0```````+;U````````````````````
M`/;AS-X`````WOP``-?L````````````````````````````````````````
MW<T`````````````````````M]:SS0````````````````````#5^-CE````
M````ZL\`````T,\``,SJ``````````"NZJWJ`````/'3``"ETP``````````
M`````,_W`````````````````````*3N``````````"DT`````"B\@``````
M````````````````````\-```````````*/R``#X]P``````````L]``````
MJ=L`````N]/LR@``IO'5RP``````````````````````````````````````
M`.?W`````-[-``"D]P```````,#X````````W=,``-#,``````````"FSP``
M`````````````//V`````````````/?A`````````````-S3`````/[Z````
M``````````````"G^@```````````````````````````````-GK``"GSZ_J
M````````````````````````````````````````````````````````````
M``````````````````````#OY````````+GIV/$`````V-@`````\N``````
M`````````````````````````````````````+3F_-P`````````````````
M``````````````````````#Q\P```````-#C`````/OR``#&V_'0``#RT```
M`````-S/``#1TP````"QS-CW``"HR[SKON0`````````````````````````
M`````````````````````````-ST`````,+<`````*?P`````,#F`````.W*
M``````````#KZ.CEP]P`````WNWRTP``````````]\P`````````````````
M``````````````````````#4SJOG````````P\L``+'A`````++W`````//3
MTM,``,#U````````W=\`````\^[QYP``M/T`````````````````````````
M`````````````````,CR````````TO,`````].X``-/B``````````#1S```
MZM\```````"ZZ0```````````````````````-?9````````````````````
M`,WU``#R\<?Z`````````````````````/C9PM0``````````.7V````````
M``#%W0```````````````/+GW^T`````R\H`````^ML```````"UZ```IM,`
M``````````````"U_0````#)^0``XN0``+W[`````*37Q<X``````````-7.
MYM8``````````+WE````````````````S=[S[`````#@[0``````````````
M`````````.SLOOOKWP``^.$`````````````````````````````````````
M````````OOD``````````//0JN#BZ`````#4XOW2``"HY0````````````#3
MV0``````````WM,``+CTO/?]W```[.CGY`````#WXP````````````"H[```
M`````````````/'Z`````````````/+E`````/30K]+EW```````````I="T
M\;'\^,P`````QMW1^@``W_<`````J/H`````````````]>X``,[>````````
M``#SYP````"L]\3KX>VKX,?=``````````"STK_2````````S,H`````````
M`+_[``````````#]Y>7=S=@`````````````].P`````````````````````
M]=``````[>C2T```V-D`````````````````````````````YO8`````JML`
M``````#@]P```````````````````````````````-G8``"C]`````#=]```
M````````T>\`````M=D`````J^T``+?C``````````"[[K3-``#SX,WJ````
M``````#U[.[H``"IRZ_Q`````````````````````,W*``"I[```Z_(``._]
M``#S^0```````````````````````,'F`````-CL````````K.T``,[J``#?
MZ```````````````````````````````````S]X```````````````"FT@``
M``#TY];1`````,+FX^,``````````+#D````````M-@`````````````````
M``````````````"E]@````````````#>\P``````````I=<``````````.CW
M`````,;H``````````````````````````````````````````#F^P``````
M````````````YMT```````#^W```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````VM@``````````````````*S:L.H`````````````
M````````N.,`````````````````````````````````````````````````
M`````````````````````````*K*^>$``+'J``````````#L\@````#N^@``
M``````````````````````````````````````````````````#5[@``````
M````]/D`````[-(`````````````````````````````````````````````
M``````````````````````````#[^P```````/#]``"]X./.````````````
M````````````QO@`````````````````````````````````````````````
M`````*[>````````````````````````````````````````````````````
M````Q=\`````ON4```````````````````````````````"M[>KZ`````.[-
MINT``*[M[?```*'=``"O[?C\``#KV````````/G,M<T``````````*GZ``#=
MX0``````````U>+/[0```````*+=`````,KY``#HZ@``[>4`````````````
M````````Z],``-3I^N',Y```Y.''Z`````#;S@```````-7<``"U]_/\\_"O
MSK7QTN_(Z/'K`````````````-3+ON#XX^GJLOP`````````````].```.#/
M``"E[@````"J^L/FLN&KR@``Y..[Z0````````````#6XO+S``#6[K+J]M#9
M[,O:J,\``````````*/=````````V]@``,[YU>G1XP````"\T@``````````
M`````*S8S/,``/O-UO8``/7G[^CYX[O2\_/[XP``T-ZPS@``]];9\0``````
M``````#!]<3<``"[]0``T=X```````````````#FW`````#2W@````#B[?;N
MS^KN\/SC``#?T_33L^$``+3A``````````#3]`````#&WP``````````````
M````````````UND```````"KVP````````````````````"F]@``````````
M`````+GCQ>NI]+;-^=(``*W:X]+1SP``````````W,OZS```W<\`````J>@`
M`+OCNN,`````VN````````#W[@````````````"SW```````````]=,``*;7
M``"U]MO7````````````````U>$`````ZM0``*/?``````````````````#?
M_0``````````````````````````````````````````````````````````
M]]#4[0```````````````````````````````````````*K+````````````
M``````#;Y```^^&BRP``````````X-,``+_D``#`^P``OMK-Y```N=8`````
M``#`[P``_.$`````````````````````````````````````````````````
M``````````````"Y]@```````````````,??``````````````````"QY```
M`````````````.?<Z-P```````#6^@``]M,``````````-KQ``#R^@``````
M`````````````````/WB`````````````,_5^-``````W\T`````R_4``/#D
MJ\L``,37``````````````````````````````````#^X@``VMT`````````
M````````````````````````````````````````````````````````````
M``````````````````"NVN[*````````N=4`````````````````````````
M``````````````````````````````````````"AXP````#CZ`````"K\P``
M``````````````````````````````````````````````````````````"I
MSP```````/?3`````````````````````````````````````````````/'4
M`````.3.``#RZ```````````````````]>4`````````````````````````
M`````````*[G``"ZU@``[-_`Y```````````````````````````````````
M`````.3H``````````"UV````````-SD````````````````N?2V\0````#>
MXK7A`````._-I_'ESMW+`````./9`````*SS`````/G0J^S3WNGW`````/7Y
M`````````````-[A[LL```````"\X];X`````.[;`````````````/']````
M``````"V]P``````````WO0`````[?(``-G;``"H\```````````````````
M_>$`````````````U-X``*S@`````````````./M`````.'3``#(WP``````
M````MMD``*S]T^\```````#!Y.OX``"LVP``````````QOP`````````````
M````````K=@```````````````````````"Z]@``W]O3T\?X````````````
M`````````````````````````,[*P?BTT@````"TW+GZS\H``+/\ZNKKZOK0
M`````````````.3M`````.?=`````,G?``````````#MWP````````````"\
M[@``P>\`````TLP``*3=````````RM\`````````````^-.H\0```````+?-
M``#4[P``````````````````W>3NWZS+O.D`````````````[.H```````#+
MWP````````````"_^:_6QM4`````````````JL\`````J<X`````^-8`````
M``"W\?CN````````V=G?\P``R/C&S@````````````````````#FU0``````
M`````````.;T`````,7FU>\`````[\O?_`````````````"GW`````#GU@``
M``````````#)^```````````TN,``+WC``#AS\#PVNP``-?=\/L`````K.P`
M``````"I\````````````````-?ZP?L``,#2``````````````````"PY0``
M`````.7M``````````"MRP``L/D`````````````````````````````I?<`
M`*[+``"OV@``MM@``````````````````*?3LOL``,3]``"M[```````````
M`````*'[````````Z>7NZ0``]//S^,'PK]ZP^`````#@\Z_G````````````
M`*W;``"UY@````"H^0````#8W=GHUN\```````#BTP``W^(`````X/S(UZW]
M````````[]_3S/G3``````````#PU,?;U=X``````````/3P``#0U=GE````
M````````````Q_S6W.#B````````L-H```````````````"C\P``[-,``,OT
M````````Q?T`````````````_>,``+'Y````````````````^]#;[```````
M``````````````"\]:3RSMC/V````````````````/?U````````````````
M``````````#A]@```````````````````````+?2``````````````````#L
M^P``R-T```````````````````````````````````````#HY`````#!T@``
M`````-?X`````````````+O6UMX`````O?>N[````````.'0``#UX+/J``#6
MS@``````````I<P`````````````````````````````````````````````
M]NSAXK[C````````````````````````R/P`````\,T``/;Y`````/#?````
M````O^4```````"_S@``````````X?RP[=']N_8`````S_G:Z\'*``"XTO'-
M``#3X^;]````````````````````````````````````````````````````
M`.WF````````^N,`````JO#0^0```````````````.+\``"G^````````.7A
M^>X```````#VY^WJ`````+3\PO4`````W-<`````````````````````]?``
M`.C=[=/\]0``O]H``/O,````````^M.D]```````````````````U^\``,/4
M````````````````````````X_L`````````````````````[?L``*W@````
M`.[JL_O"Y`````````````````````````````````````#G]MW2``#,WP``
M``#)_`````"IY?;@L_8`````````````_N$``````````/#+``#OZO#J````
M````P-JT^/+K`````````````,/D``````````#7Z?'D````````[\H`````
M`````````````-?.`````````````````````,K\````````X?,`````Q,L`
M`````````.7C``#%R[3J`````+WI``#)UP````#;Z['M``##S+[WR_P`````
M``````````#T^```M]D`````T_/4\P```````.3W``#1]P````"WV+'.PLH`
M````M/O&RP````#V\`````#GU0``T.H`````````````U,RORP``````````
M``"J]*_I`````,/UV.D``````````````````.G=````````\_$``/O5N]X`
M````^_0```````#S_?+]IO<```````````````````````#)W0````#3U```
MJ,P``,':U<P``.39````````ROH```````#CY0```````+S3````````\,H`
M`````````,30````````T,JK^NOK^.?EV0``````````````````````````
M``````````````````````````````````````````#7T0``````````````
M``````````````"D\P```````/O4X_S8^@``U?,``*O/`````//K_-4`````
M``````````#4T_S-``#FV0``^>*AXM3K``#WX++D_,P```````#D^P``````
M`*OT``````````"]T```\<H`````````````````````N.\```````#`UP``
M^N[T_0````#CTP``POL``````````````````.C5KMNVX;?X````````````
M`+_@P_OJW0``HN(``*;N`````````````.CV``````````#U]@``````````
M`````````````````````````````````````````````,K=`````.+0````
M``````"FW0````#KW0````#YY`````"OX_S0````````_/0``````````+S,
MZO<```````````````#DY?'?`````.'W``#W^;GO`````-CX````````````
M````````````````````````````J?D`````````````V?@```````"][@``
M`````,;8`````./DSO4``````````-G=``````````#GV;G2P]4`````Y=K0
MV@``V='8S@``WLNL]/O:``#I]O/HK,_P\```_?3(VP``````````````````
M`````````````````````,#.U.//T?7Q``#RS0``Z\\```````"XS0``````
M`````````*;CVM$``*7R`````````````*;R``#.Y```````````````````
M^],`````````````````````````````````````````````````````````
M`````````*GQ````````R?(``````````````````````````-COR>8``+C8
M\_H``````````````````````````+7S`````*3X`````//1R.8`````````
M`-KX`````````````````````````````````````````````.G<U]X`````
M````````W\L```````#LSP``````````W_0`````]-&ZT@```````/+?````
M````M^$``````````*/B_-,`````YNT`````````````R=L```````#ZY```
MWL\`````T,X``````````-/5]?.N]P````#([P``\\W/]?/EPO``````````
M``````````````````````````````````````````````#1R@```````/'J
M``"FT`````````````````````#:V:OP`````````````.?K````````P.6U
M_`````````````#$Y`````````````````````````````"IS,;]````````
M`````+7J``"JY;K?````````````````````````````````````````````
M````````````W^$``-':``````````"XX0``].C]TP``````````I.(`````
M````````RO(```````````````````````#FVK/W````````````````````
M````````````S?T```````"V\P``````````````````````````````````
M````````````````````````````````U^X``````````````````,3U````
M`````````````````*38`````````````*?R`````````````````````+C9
MN=G)[P``````````````````````````````````SM8`````````````````
M````R_>NW_7H````````````````M=(```````#5TP````````````#,]/S:
M`````````````.C9``#K]\GU``"\\P``TMH`````````````````````M=,`
M````````````MN@`````S]:Z]```R?<`````JLP`````P_#6S````````-/0
M``"]TP```````/O;``#@RP```````````````.33]_8`````NM7-\^'+````
M``````#TZP````````````"M]```JOP`````````````[/<```````#VZ```
MY]H```````#,]P``````````````````````````````````````````````
M````P>4``````````.[@`````````````/W5````````````````YLZK_+O5
M`````*CR````````````````I>*YS?+JQ\L``/3-`````*_;V>\`````````
M````NLT`````^?P``````````//?Y\["V@``K<\``````````/GGJ/@`````
M``````````#B\P```````/+*I-\`````Q-0`````````````U\S"Y0``````
M````N\T``-KOV.X``*?=IN(`````````````P.````````"PULKX``#Z_```
M_MD``````````+#>````````[-WHV@````````````#@U```^=8``-?-V-X`
M````^/(``-;D`````,70KO0``*C=````````Q>W6\P````#9WN;C````````
M````````J-,``+#;`````-KEO^,```````"QVP```````.G5````````````
M`,'@V^\`````Z?``````LM<``````````/W0`````````````````````.G9
M`````/[0``#M[*G3``"I\L3P`````.+B[^D```````#1^0````#9Z0``````
M``````#:Z,/:Q-K%U```^N<```````````````#@S;#C``"RV\3[``#C\P``
MI=GG^\O=U-```+;FKN#:_0````````````````````"UW/C@L><`````````
M`/#U``#<V,;M``````````"YX0``P./`^?#I`````-O9``#D\P```````+;<
MZ>0`````````````Q?#!X\S\S?P``````````,OR``#,\@```````,_D````
M````````````````````V_$``-GZ``"X\?7]^>```````````/OGM_SD_,7[
MY^.YV```^/8`````Q=S8S````````*_@Y_0``-SO_,_=[P``JO(`````````
M``````````````"^_0````"LRKO]Q_T``````````++G``#1ZO3?````````
M``#LT=[DP^4``````````*;9`````+S-``#E\P````````````````````#5
M[0````"ZV0```````.?MM?OL^```````````Y^```-G,`````,;4````````
M`````*7G``#UU;[3``#[_````````````````````````````````/+D````
M`/7?`````/CH[?@`````Q\X`````````````]OT`````````````````````
M``#8Z```V,W6Y]K,`````./*]M_'\,;P``"ZV```]/'P],SU`````.7\````
M``````#%ZO/J``#;W0``U]P```````````````#]WOGR``#'U0```````-#8
M``#(\*'1HM$```````````````#4V>C6RMD``+':Q]CBW,[S]/4`````N?$`
M````T]H``.KV````````]<\`````KOT`````````````````````TLH`````
MM-\``````````-W7NOJG[KWU``#U^`````#H[0````````````#AU```H]'6
MX0``````````````````````````````````^/D``,K;^<O4U```W-D``+[N
M``#M]P```````.[2`````.;A^?<``````````````````.W=``#;Z```L]L`
M``````#WT;#@`````.+4``#7]@``^=<`````W=@``/W-J_(`````````````
M````````````````````````````````O<W"^`````"L\@````"MRJ[*KL\`
M````````````PN,`````````````M]P``````````````````````````-K;
MN]GSRM/V^.;UZ@````````````#VZ@````#Y]@``````````````````````
M``````"OSP````#3R@````"ORK#2NO$``+/7P^/]\]K>``````````#;W@``
M``#>[P``````````````````````````````````````````````````X^+[
M[@````#WW\K7````````````````````````Z,[;VP``````````````````
MN_$``````````/'I`````````````````````+?ZQM``````J\RH[@````#Z
MR_GY_<S^TP``````````T.0`````````````[O(``-74S=\``+C\T-$`````
M``````````````````````````````````````````````````````````#-
M\@````````````````````#2]P````````````````````#4R@``V=4`````
M``#>V````````````````````````-G-````````J>Z\]@````#;S```````
M``````#)\```_/P``,GH_O0``````````/SGWM<``````````-S>``"L\/[,
MX<T``+KA``#OV[+:``````````````````````````````````"ET;C<````
M````]M@``*31``#BS0``````````ZMP`````]_```,KPOM```-S=````````
M``#6U-;3````````````````T.VAS0````````````"UWP```````/C?````
M````````````H=2RS@````````````#*Z```````````]>L`````````````
M`````-7CT/4```````"A]0``````````````````````````````````````
M``````````````"GV0````````````````````"KY0``````````````````
M`````````````,OF``#Q]0``````````````````````````Q>4`````````
M````````````H_G;X.OV``#QRP``ZMFB]0```````-'7``#XT?CJ^>JSV@``
M````````W^\`````[_$``/;EO^[DX@````````````"_T```K/K1];/G````
M````````````````````````````````````````````````````````````
M````````OND`````````````SO*TVP````````````````````#._```[MT`
M``````````````"TYP````````````"TUP```````````````+3W````````
M`````+[-``#IV@``````````````````L,_9]^;S`````-G.````````````
M`````````````````````````````````````````````````*K.``#(RP``
M````````````````````````````````````````I]```,OP``#'T`````#%
MY```````````````````X-L```````````````#:U0``I]<```````#`[@``
M]O@``````````-+UZ>T``+S9``#&Y0``````````````````````````````
M``````````````"C]0````#4VJ?B_/L`````W/$```````````````#TR@``
M`````/KH`````.G.````````````````^.GEX@``````````N=#RU```````
M``````"FT0``SM\```````````````````````#T_```````````````````
M``````````````````````````````````"JTP```````*S,``````````#@
M[P```````.7EU=``````````````````````_-L``````````.;\````````
M`````/[+ZNT```````````````````````````````````````"QW@``````
M````````````X_D```````````````"BU/;/````````````````````````
M````````````````T-8```````````````#JU>[Q````````````````````
M`````````````````````````````````````````````````,OZ````````
M``"AY0````````````````````"QU0````````````#MSP``Z^T`````````
M````LM4```````"\U0```````````````````````.+]K?,``-O]````````
M`````````````````````````````+#I``````````````````"GT0````#C
M_;/.``````````````````#D_<[Z``````````"PR@``I_<``+'/````````
M`````````````````````````````*+F``"V_*WRX>^N\\;<Z]D```````#@
MZ```````````````````J.$``````````/;5_<\`````W=X```````#1V0``
M`````.KDS_(``+_W`````.;BJ.(`````````````````````````````UN,`
M`-'M`````````````/GI````````````````````````````````````````
ML=:RW@````#HX`````"KTP``W.L`````K]\``,/*`````/SN``##_0``````
M`/;KLL\``````````.S9``"]V0``W]@`````N-2^Z^_=``#PW?'=\MT`````
MOMD```````````````````````````````````````#&^[//````````````
M````````````````````````````````````````````````````````````
M_>X```````````````"KY```Q=H``.S8````````````````````````````
M````````````J-$``````````````````````````````````````````*GB
M`````+S>M><`````````````\-L``.+O\/&TSP``````````````````````
M``````#QVP``L>```````````*7?``#2^0````#]YP````"CYO'[L,NN\@``
M````````````````Y\T``-SH`````-?G`````,#W``#CT````````*':````
M````O<P`````J=',W0````#^XZK1JN@``+;J^OG,YMCV````````Q]0`````
M``#+V0``TMG+T_?8J=KX]0````#>WJ_RJ?@`````````````````````````
M``````````````#(V`````#![@``````````P?D``````````//=^NH``+WV
MN^&_S=3TS>8``,_\HOL``-S@``````````"[]-7:``"R^0``````````````
M`/+[``#VVP``W]X```````#RVP````````````#<^.[WZ.L``/K2`````+SQ
M`````-KZ`````.K:QMK!]P````"VYP``````````````````````````````
M``````````````````````````````#'Y:S6``````````#'W```````````
M``"IX0``JN(``*;5`````-?4````````````````T/(``/OJ``#=X//[````
M``````````````"]\0````#GXM?]``#(SK?J``#`_```Y_WO]P````"UUP``
M``````````````````````````````````````````````````````````"Z
M[]WQ``"SW@```````````````,OH`````-WX`````,?[R-4``-_7``"IW0``
M``````````"QZ0````"M^MGV]/H`````````````JO@`````````````[N8`
M`-S,O.'OX`````"_Z?W\SN8`````U^$``,_F``#Q]```````````````````
M````````````````````````````````````````````````\^0`````^^0`
M````Y/D``````````````````````````./O`````.[/OO:RX/[\J]$`````
M``#ZUP```````,C[``#7X@```````````````*/4^/"HUP```````.?A````
M`+_3````````````````Y.\``,77XNL`````Y_P`````HN0``.CB``#0Y@``
MZ/OH]/3EO/35]```````````````````````````````````````````````
M`````````````````````````+;?``"Y_,+N]<H```````#E[^++I-0``.#>
M_=K&Y+[H``````````#>X+3VTNH``/OY`````,+@``#DR@``M^<``/WJ``#=
MV0``M-JJ[NG[``````````#+V[7:`````````````+[Q`````*S3````````
M`````````````,G[``#/WP````#`T]?C``#F[]#\``````````````````#`
MZ0```````-/U`````-SLM_<`````N.KYT0```````````````,C<````````
M````````````````````````````````````````````````N>H`````````
M````WO$`````````````MM>USP``J-D`````[NP`````JMT``````````*+-
MKN@```````"]X0``T?(``````````,'I````````_-(`````````````````
M`+7;``#G\_[8````````T?P``++MK_0``*/[`````,'\``"K[J74````````
M````````````````````````````````````````````````````````````
M`/+T``````````#9[@```````,K[`````````````./-N]@``-OE]_@`````
M``#4]@````````````````````"IUP``R<L`````T>;,\```````````````
M````````````KM@``-/Y_M4``````````````````+S8L/(``````````*OB
MZ/,`````````````PN\```````````````#L[0``N.<`````````````````
M``````````````````````#^V@````"^S`````#\\NO:``#8XM;M`````-'6
ML^``````TOP``,CK`````````````````````,'3S?```/?/````````````
M````````````TNT``-C4R=SQUP````"[WP````"E\P```````,WT````````
M``"_\;'X``#ZZ0```````,O[`````-7*````````````````````````````
M`-3YRO<`````R-8```````````````#H_+WS``#^[@``_N<`````````````
MPM,``````````+;3``"MS/KVLM;8T@```````````````-CG````````````
M``````````````"EXP``````````N><``````````*WPS/NAZP````"FU```
M````````S?L``+W5W_$`````^_8``+3>````````````````````````````
M````Z]4`````R.4```````"D^[G4`````.'>``"CY````````+?7``#N^```
M`````+7>`````-+6``#5^;KGU>OWU>?OON$```````"N^@```````.G6[M8`
M``````````````"[YP``````````````````R^P```````````````"SU0``
M````````````````````````````````M,X```````"E^^[A````````````
M````J/<``````````,[[`````````````+W8``````````````````#]^P``
M````````Z?P``````````````````+;/````````Q^VL[@``````````````
M````W<P``````````*?V````````^N8```````"D]0````````````#<_;/M
MR<X```````````````#H[P````"_X0```````````````-OZX\NI]P``IOL`
M``````"YW````````,#QR.W#[P``````````````````````````````````
M``"MU@````#._0```````*'H`````````````````````/3[I]4```````#V
M\0``T^8`````````````````````````````````````````````WLP`````
M`````````````++X````````Z]P```````````````"V_0``````````ZN4`
M````X/$```````````````````````````````#,V\W=````````R-0`````
M[=D``````````*7U````````````````````````^^8`````````````U.8`
M`````````````````````````````````````````,C]``"AUK_]``#3_```
MH>\``+SG`````````````.[1`````-7F`````/+I``"PWP````````````#@
MV+K\K_W.\```X=L`````R>4``+3M````````````````````````````````
M`````,/@````````````````V.,``````````/OIJ.H``````````+?]````
M`*?[``#"Z0``````````]_T`````````````V>(`````[-P`````````````
M``````````"BZ```````````\.8``````````````````/C]^?T```````"_
M]@````"GYP``U^8``````````//4R=0``````````/K6``#RUP``P.$``.+;
MV.8```````````````````````"]YP````````````#/\+[SK.(`````````
M````M_7PX````````````````````````````````+C]Z.,``*?4_.C2^@``
M``````````#O^````````````````````````-/6````````````````````
M``````"TU0````````````````````````````````````#0\```\/>S[@``
M``"ZZ@``T^H`````R>VKW0```````*SEH?T``-#?L^P``-'?````````````
M`.WMN/CZ]P```````*OX`````````````.#T`````````````+K4L^0``-KI
M``"VW@``O]D``,#9[]8``````````,S9``"JV@````````````````````#E
MWP```````````````.7W````````LLP`````^=_@UP``````````````````
M````````````````````````````````````````````````````````````
M``````"[U```````````^OT``````````+/,`````//;````````````````
M``````````````````````````#2WP``RLX``-KN````````````````````
M````Y.0``,_[````````````````M\\``,/N``````````````````#JS@``
M````````````````K>(`````````````````````````````````````X=?U
M^@````#)U:SX````````````````````````````````V><`````````````
M````````````````Z?,``````````.W8Q./Q\```````````````````Y>@`
M``````#ZX,3NWMD``````````````````````````*+KH^L`````````````
M``#"_+OJ``````````"KZ.+>``````````````````````````#O[0``H^@`
M`````````/'/``````````````````````````````````````````"\U```
MZOP`````````````ON<``/+\`````+36`````*[B``"WT\SZ````````````
M`````````-SZ``"U[>/A``"LZ```W>@`````Z>\`````````````O?0``+C/
MV^FLT0```````````````,?:``````````````````#)ZP``S.@```````"W
MW@``````````O-;ETP````````````#=^@```````````````-;:``"QR@``
M`````````````,C:IM\``+/YTO(``,3*````````````````R\X`````]<T`
M``````"P_:C5``#!\0````#IXLK<M.S`^@````"H^ZC0`````.S:````````
M````````````````[MD``/O@````````ZN_>^@````#$X```N<\``,K5XM>O
MX@``N-<```````````````````````#-Z```````````````````VO8`````
M`````*+OVN+\]@````#0^ZW1``#DS0``KM'MW,[H``#Y\+7._.8`````^]?6
MT/7=\?<``/WV``#WVP``````````ZOO<Z<'9``#R]<7@````````````````
MU.H```````````````````````#"^0``O.H``,72T?O`YZ7K``#ZWZ+CN=<`
M`,/I``#]Z*_H`````-/RJ?NEV```````````R]4`````````````````````
M````````````````R-````````"OT>/7````````QN```*+6``#P[0``````
M`````````````````````````//7````````U/P``-?:W\P``-3R``"PT0``
MX,P``/W;O_,``-'P`````````````+O\``"PX@````"EY@```````-OB````
M````WM\``,?@````````````````[_(```````#AS```````````ZM8`````
M`````,+G````````MLX``,#S``#^S0```````-+[``#X^/OW`````+_H````
M``````````````"WZ`````````````````````"V[0``````````````````
M`````+K<`````+3,````````````````````````````````]_$```````"X
MZ`````#VR@``I.36]````````.;?````````I]\``.??P>$``,3I`````,O<
MQ>D```````"C[Z;KH\OIXP```````/O1I.\``.OO````````````````````
M````````````M-```````````*/-`````.;H``"E[P``S-/MV@``````````
MNM<``-7RY?7OV0``````````M/D`````U-7/_0```````./;``````````#A
M\;;L``````````#^^]?3``"QT0``L<L``````````++1````````````````
MLLO"\0````#A]+7Y`````,/APN$``/?K````````````````````````````
M`*C?``````````````````#*RP````````````"YY@````````````#>^*KY
M]\H``+?M`````+C3UO(`````V=3%[O#R````````LLH`````N]P``/CQ````
M`````````+?L``````````#*Y0``P/;=_0````#CU.+,``#4]P``````````
M`````.77``````````````````````````````````##TP``IM@``,'V````
M`````````/;=``#`S0```````-SE````````````````````````````````
MR^4`````````````````````````````Q.$`````````````L.BP].KS[MH`
M`+O7``"QX@``````````````````````````````````````````````````
M``"JUP```````````````/O6````````````````````````W^0``-;*````
M````J.L```````#^VP``````````````````````````PO8`````N^\`````
M`````/W4`````,C@````````N>@``*;O`````````````*3-`````/34H=O<
MV]W;`````````````-SN``#+R]7\````````````````Z\X``,'-`````-/[
M````````````````````````````````````````````````````````````
M`````````*OY`````````````````````````````-3U``````````"IV0``
M``#=Z<W;`````,[=``##YP``S.P``````````````````.SY````````S,L`
M`````````/S@J-0``-/M[]@``-?R``#XRN_:`````-36````````````````
MS=D```````#NV```P?(```````#3WP```````/#:``#JX@````#]X`````#X
MV````````*_WMMH``-?*````````````````````````````````````````
M````````V/(``/G8`````````````````````-_Z````````````````````
M``````````````#OS\+9``#2\```T>0```````"W\P``````````````````
M`````````````.#Z``````````````````````````````````#L[P``````
M``````"RX@``O=0`````SMD``````````.+T````````````````````````
M``````````"IU```````````PLW:YP````````````````````````````#9
M\@````````````"JV0```````````````````````````````+[8````````
M````````K=P```````````````#KXOS6`````/G*`````-K4````````````
M``````#7]*',`````+K/````````````````````````````````````````
M`````````````````````+CU````````P]GHT`````````````#%X_CK``"Q
M\@```````+O/````````K=/AZ.S.````````M.``````````````````````
M````````````````X]X```````````````````````````````````````#W
MW0```````````````````````````````````````````````++R]O/;]@``
M````````_M<`````````````W_@``/+W````````````````````````````
M``````````````"IT````````````````````````-KF````````````````
M``````````````````"F]0``````````````````````````````````O-?C
MS`````#;Y@```````````````````````````````-W=``````````"ST0``
M``````````#M[P``````````WM;TY._A`````/C=`````````````,_H````
M`````````````````````````.7*````````H=P``+7@````````````````
M``````````````````````````"L_*W\I]@``````````+CM````````MML`
M`````````/#6K_,`````I<T``/':````````````````````````````````
M`````````````````````````````*C8````````Y,P`````M-$`````````
M````V,H`````````````\MH`````````````I_4`````````````````````
M``````````"H]0``````````````````IN8`````````````````````````
M`````````````````````````.S5^-7SV@``````````````````````````
M````````QN,```````#DW@``Y=ZUT0````````````"VT;?1L_(`````````
M``````#>Z0````````````#3\+3R`````-3PY,O4^^;UZN,``.;>````````
M``#4WP````#Y^```````````KO````````````````````````````````"X
MT0``````````W]8``-?0`````````````````````````````*'\[N_8W```
MW^D`````````````````````````````````````````````````````W>7[
M_0````#)X````````,G6`````*K4``#,Y0````````````#@Z0```````-C0
MHOR^U+/BY]X``````````````````+S<MM+5]0````````````"ASJGU````
M`/G=`````/K=````````````````U?```````````-_V``#:\NOD``#Q\@``
M``````````````````````````````````````````"Y[```````````_/T`
M`````````*KA`````-G*`````._O``"J]0```````````````/GL`````*WX
M``#"\L/V``#2UP````"B^=;P``````````````````````````````````#Z
M\`````#@]@``````````\^G#\@```````*O4L\JFS0``P\W:S0``````````
M``#/V0````#$]@```````-WNQ.<`````````````````````M.(`````````
M``````````````#BW]OG````````````````L>@``*[\``````````#-Y0``
M`````.OZ``"\SP````#BS_;-`````/#O``"^]```S=0`````N/,```````"A
MZ0```````````````````````/+RZ_,``-?P`````-?/````````````````
MW\\```````````````````````#`Z,'H````````X\^BZ0``````````````
M````````````JM````````````````````````#!\ZO0``#DU`````"\[Z'8
M`````````````````````````````-_9``#7\P```````+W<``#ES/'M````
M`.+Q``#;U```````````M>(`````YLH``*[3````````````````YLP`````
MT_'G]0``````````VLH```````````````````````````````````````#N
M^P``Q>$``````````````````.G?``#>[@````#"]P``HM@`````````````
MK-T`````````````K_"]U@````````````````````````````"KX0``````
M`````````````````````````+;Y`````/74``#)T*?O[.(``.K;S,[H]=7W
M``#-TP``_O,```````````````````````"UT```````````````````````
M``````#^X```^]\```````````````#=Y@``````````````````I.@`````
M``````````````````#-RP```````*CO````````M.X``````````-C:N=$`
M`*G?`````+#S`````,3,````````M\X`````````````````````````````
MJ>\```````#5WP````#7[0```````,;N``````````````````"][];\````
M`/3;``"J[[GX``#I]0````````````````````#9XP``````````````````
M````````````````QN$```````"_U```````````Z-X`````````````````
M````````````````````````````````````````````````````````````
MZO```````````````````````````,+S````````````````````````````
M`*_3`````-O*`````````````-?\`````-CMQ^$`````````````````````
M````````````````````````V/2SUJW=````````OM4`````````````````
M````P_'?[@```````````````````````````````````````````````.O6
M````````V?0``````````````````.;7````````````````M]H`````````
M``````````````````````````````#[W0````````````#/W0``````````
M``````````"CV`````#9V@``V/#$[P```````````````-CA````````````
M`-3Q``#R[0```````````````-O5`````-S5Q//7RP````````````"VX@``
M````````\>\`````````````````````````````U?L`````````````````
M````````````V-,``````````````````-#=V?"SRP```````````````-W5
M``````````````````````````````````````````````````"GS0````"L
MT```NM$``,3Q``"SY?7[X>G@_;S\``"BVJ/:``"AT@````#OT@```````.WB
M`````.G>W,ZU\N30T=T``````````,CAM]OCWP````````````````````"Y
M[<7Q``#/\ZO7K.$`````Z^,``,?N````````R>'ZR@``````````````````
M^_#A^MKPY\STV@```````````````````````+_,````````````````````
M``````````````#MS@````"IU>+Z````````Y=```-;K``#?[````````/S?
M`````-;WZMZTRP````"^[P````"US`````````````"]SP``````````````
M``````````````````````#R[[?B````````Z,P`````````````````````
M_/````````#@U@``QO$```````````````````````"XXJOK````````M<O1
MV```SO3W\P````#&UP``N]&J]P``RNW3U_K8``````````````````#%]@``
M``#,T?S=``````````````````````````#]WP``Y?D``,K@`````/WRL-,`
M`//TR=H``-[F``````````"Z^-#H`````/O8`````-7J``````````"CU@``
M`````````````,;V``````````````````````````````````#;\OSD````
M``````````````````````"RZ`````````````#:V@``W/+6^[+I``"M[@``
MX_H``````````````````.[<`````.KUX.8``/WP`````````````*S7````
M`````````,7UX.X`````Y=L``-[=`````/#9H^D`````````````````````
M`````/GQ``#$\LO@`````````````````````*3I`````+GB````````````
M``````"QX^O\J,T``+;,`````-OP`````````````````````+KF`````*G-
M`````````````,/S````````````````````````V>$`````J^\```````#%
MYP````#IX```Q?,`````P-2_U0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````*[=``#\^0``P,P`````````````````````````````````
M````````````HN4```````"XS@```````-+8UOD`````````````````````
M````````````````````````````````JO'1S@````#']@``Z]L``/[?````
M`.'8``#S]P``Y]<`````````````````````````````_M0`````O-$``,_E
M``"VRP``N-H`````````````Q,T`````````````OM8```````"ZX@``````
M``````#8SP```````,S@^>L`````````````````````_?T`````````````
MZ-?8RP```````.+I````````NN@```````#'XP``````````S>P``,[L``"_
MU@```````*?C``#6W^C]````````````````````````X>ZH]OW=````````
M``````````"[^```T>@``````````-?Y`````````````````````.[.````
M`,_L````````I>G5U@``Q<T``+KMO=$`````OL\`````N^P```````"QT@``
M````````Z<P``,39_.D`````````````````````````````````````````
M````````````OM$`````````````O.P`````K>4```````````````"P]P``
MZLP```````#$TP````#`U@```````/W6````````````````````````````
M`*'A``"]W@``J?8```````"DV@``````````````````````````````````
M````````I-;&]0``HN'&Z0```````,7R`````````````.GT[-;3ZP``````
M````O>S<XNO>W/```+_K``#.U[_1````````````````````````J_4`````
M`````/WY``#<R@```````,;-MO(`````_MT```````"WS+C;``````````#I
MT```W<[`ZP``HOT`````````````R_@`````````````````````UNJP\0``
M````````````````SML``,/W`````````````````````````````,_;I,L`
M````X/@`````U_L`````RNNAX`````````````````````````````#-S@``
M``#<U````````-C]``````````#VT@``````````M_(`````]OJJ]O?ZYM@`
M`+'T``````````````````````````````````#2Z```Q<KKS```````````
M````````[N(`````````````N^(``*WW````````X?@`````````````````
M``````#L\P``````````H=X```````````````````````````````#]Y```
M``#LXP``K]VPW0````"WR]/H````````````````````````````````````
M````H^'@T@``````````_O```````````*;I\LL```````````````#S[=G<
MS>```````````-KWN=L``````````````````*[,``#;V@``````````Q\T`
M`````````````````````````+'=``"OV*/C`````._.`````//R````````
M``"S^```````````````````````````SN```/WU``````````#LZP````#%
MT^S\V]+KU```HMX```````#FY0```````````````+#P````````````````
M``````````#$U0```````````````/3M````````[>,``,+H``#U[?S7``"[
M[0````"K]@````````````"X\LCV`````````````.;3W?*_SP``K.L`````
M``````````#`SP``J.;I_0``P<\``-_@[-X``````````*+@````````````
M`````````+_T[^(``/'9Q_$``+C+`````````````````````/[YNMOUV@``
M``````````````````#L]MS:Y/H``,_@````````````````LMT`````````
M`*GF``#S[P````````````````````````````````````````````#M\P``
M````````````````````````^NL``.;Y``````````````````#=RM[5``#>
MRN3?````````_>8``*SU`````````````/7D````````````````````````
M````````X^D``,OMY,\```````#3V````````````````+/=[-0`````N?(`
M`+??`````````````,[+V/L`````V=``````TMWT]]SGI>0``*/\``"[VP``
M`````+KR_>G*T```UO7%V;3D``"G[0``````````````````````````````
M``````````````"]ZO[F``#$]ZWU``#@V0```````+3*`````.+XPL\``+[L
M````````M.7(S<CN````````````````````````R.<`````````````````
M````````````R<VW^0````#H\?+9]=NURL;9````````R=@`````````````
M`````````````````````*O9````````````````````````````````````
M``````"\[0````#4V````````-K<``"\X@````#M_.#L_M(``,?IJN8`````
M``````````#PX@```````````````+OZ``"N]:K[``````````#[[```O^S8
M_```````````````````````````````````````````````````````````
M``````````````````````````#EU````````,/Y````````XNX`````````
M`````````````````````````.G7]NT```````#MW@``````````````````
M[,P``.[C`````````````-3H````````^/H```````````````"TW;7DL-@`
M````````````````````````````````````````````U=@```````#J]```
M`````+G.````````X=;2SP``MM````````````````"BS@````#N\P``````
M``````#X\P```````````````````````````````,S<``#+T````````*3\
MRLW4UZ/>``#@Y```````````R>X```````#=X@````````````#^]:S4````
M`````````-'5``#PV,/XU^H`````````````````````````````````````
M````````````````````````````````U_4`````O]@``````````,#]````
M````````````K>L``````````*K5`````````````````````````````*CG
M``````````````````````````````````#*[@```````.?*````````````
M`./X``#=U`````#8Z@``````````V?OW[0````"UY0````````````"MT```
M````````\?$`````````````````````````````````````````````````
M``````"]X@```````,CC``````````#5V0````"JWP``````````O-L`````
M`````````````````````````````````````.3X`````````````/KQ````
M`+;E[_,`````VOO@X0``K-D``.OU``"VX`````#(Z0``S\L``,GC````````
M[MX`````````````````````ON(`````````````````````````````````
M````````````[]P``*76`````````````/'B``````````````````#^U@``
M``````````````````````````````````````````````````"AV0``P-C;
MW`````"][;C?``"EZ@```````*W7`````/GS``#X[0``Q_4`````````````
M``#*X>/K``#>\@``````````````````````````````````S/@``-GJ``#&
MTP``YML`````````````K_4``````````/#.``````````#^Z0``````````
M``"V^P```````````````````````/+B``````````#RS[GW\]D`````R^$`
M`````````````````````````````````````````````````````````-W:
M`````+G:``````````````````#[ZP``N<L`````^>T```````````````#@
MX```````````````````````````P/0``+S]L=_OXP``````````H^"Y_0``
M`````````````````````+'P````````````````R\T`````````````````
M`+[M````````P-7PX_KM`````````````.3I````````````````[=7=YP``
M`````````````/;4M^4```````#GV[_B````````````````````````````
M````R^X`````]-?=\````````*O.`````-[G````````UM;,X0````"SZ```
M``````````````````````````#NY:+<`````-#@````````````````````
M````````````````````````````M=4`````````````````````````````
M````````````````H=4`````````````````````````````````````V_L`
M`,OY````````\\NE]`````````````#(^M?6``#EZ=S[````````````````
M``#0_0````````````````````````````````````````````#V^P``````
M````````````````````````````````````I=H``+W;````````````````
MXNP```````````````````````````````````````#WS=[P``````````#)
M]@``````````````````````````````````````````````````````````
M``````````````````#OW@```````+'3`````````````````````.[\````
M``````##Z```R/$```````#QS@``````````[?D`````````````````````
M]/(``````````````````````````````````````````+;D``"Y]0``\-SQ
MXP``````````I>@```````````````````````````````````````"[\@``
MI-X``,S:````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#IR@```````````````-KC``#9_```````````````
M````VNH```````````````#$^0``I.,`````````````````````````````
MW?L``,KO``#$Z````````````````````````,S5````````````````````
M``````#7ZP````````````````````````````````````````````"MV0``
M``"K^P``````````````````````````````````````````V=,`````````
M``````"BU0```````````````````````-[V````````````````````````
M````````````````````````````````````````````````]MH`````````
M````````````````````T>``````J.D`````^?4```````````````"O^@``
M_.L`````ZN````````````````"RXP``````````````````````````````
M````````````````````````````````````Q=4`````X_'NU0``````````
M````````````````````````S,T``````````-GM``````````#!V```````
M````[/H`````````````Z_$`````````````O/KBY@``````````Y?KZX@``
M`````+;*``"WY```V^H``/KU````````K/O#S_WK``````````#Z^`````"Y
MWP``````````\>$``*32``````````#[]0```````````````-K0V]```+[J
ML=D`````````````M\H`````Y],``.7X``````````"RTP```````,#BW_(`
M``````````````#ES0```````````````````````````````*SY````````
M`````````````,W-````````````````````````````````KNZNU@``````
M`````````````````````````.K7``````````#@YZ[K````````V<\`````
MS=S[[0``\-X``.O7````````````````I=X`````````````````````````
M`-??T-O1VP````"CU0``````````LO````````````````````````#<W```
M``````````````````#HR@``YOC.W```````````W.K2VP``````````````
M``````````````"SZ0``````````V_<`````````````````````````````
MJ.,``*[7`````.'@`````````````+K+`````-'E````````````````````
M`````````````````````````````````````````````````-S0````````
M``#!U0````````````#*V```````````````````J>,`````````````````
M``````````````"DX```J>D``,?3`````-W<KO@```````"XS````````*[0
M````````\M@`````RN,``````````````````````````*_,````````````
M``````"MU-'V``````````````````#,T```````````````````QLH`````
MPM4`````NLX`````````````````````````````````````````````Q\H`
M`````````````````````````````````````````+#Z````````````````
M``````````````````````````#8WP```````+KU``````````````````#K
MY0``].^UW0``````````JLT``/+C``#W^P``T/<``````````+K]`````.']
M_O;`T0````#%Z```N.0``.CA````````P<P``.W2``````````"^VP````#B
MX````````,GZ`````,WA``"XR@```````.#RR?$`````````````````````
M````````````````````````````````\=X```````#?\,3X````````````
M`,SN`````/+>``#)YP``\^+AYP````#+XP````#,XP```````/C/K.\``/[]
MI?RQ^MG?``#2X````````-KT`````````````````````````````,KQ``"C
MS@``````````O/+C[`````````````"EX```J_<`````K^L`````````````
MWN4``*3AJ\T``/39INC.S>GA``#O_```X^``````````````P>(``*3.````
M````````````IMX`````_NL``-WKX/``````V_0``/3B`````,C3````````
MZ_0``+7N``#8]0````#?U0```````.76``````````"PZ^/T``````````#-
MXP``````````]/2R^@````#U[]_*``"QZ[_M`````,G]``````````"FY*3Y
ML_```.SE````````Y]$``,?9U^3=Z@``]]0```````````````````````"Z
MV@``S=H```````#,^0``VN&_VP``Q<S0[+O+``#SW@````"JZ0``````````
M````````R-D`````X^Z]UP```````````````,3/`````````````,W0````
M``````````````"F_```````````````````^_$``````````-+]P=$`````
M````````````````V^,``,G3``#/W````````````````````````.W,````
M`````````*?>`````+OFH>P```````"YS`````#>^P````````````#BYP``
M``#!U````````````````````````*C<`````````````,+B``#8\]/E````
M`-GS````````QO,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#;S0``````````````````K,T``,/\``````````#GU```PM$`
M`*7Y``#5Z`````````````````````#.XP``````````RM0`````````````
M``#:WP````````````````````#?^^/G````````````````````````````
M``````#[^,_C``````````````````"P]0``````````````````Y]@``,G9
M``````````````````````````````````````````"O^/;O``"VW:_N^,T`
M`````````+C>I_S\]['WN\ZA]`````#-[J[A`````,/L_L\``+_XXMCHTP``
M``"HWN3TPNP``/79Q?G3W?'6_.SP_`````#`[;G*``#D[@``````````````
M`.'R``"YW@```````````````/+6``#TW@``V]\``-/;``#G^N/8P?0``+?=
M````````]?(`````KM0```````````````#SU@```````````````+C=Q<_?
MWP```````````````+[RH?8``,OK_/$``,?S`````.O@`````````````/SM
M`````-OA````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````.7N``#UW@``````````T_H`````
M`````,OQ`````*_0N=T`````P]$`````````````````````````````````
M`+'U``````````#&Z@````````````````````````````````````#A\```
M`````````````````````*SV``````````#9]0``````````````````````
M````Z_````````````````"ZW0```````+_R``````````````````#%]P``
M````````HMOV\@````"ZR@````````````````````````````#U]P``Y<L`
M``````#F[@``T^```````````*7.````````````````V-8```````"OU```
M````````````````````````````````````````````````````````R>D`
M`````````,[3PO0``````````````````````````````````.;+````````
M`````````````````````*'Q`````````````++K``````````"B\0``````
M`````````````````````````+/K``"T\`````#TR[#4LO.W^P``````````
M``````````````````````````#L]0````````````#G[K+T````````````
M``````````````````````````````````````#M]0``\\\`````````````
M`````````````.+P`````````````,[N`````,SQ`````+CE````````````
M````````````````````````````````````````````````````````````
M``#UU_/CY<\`````````````````````````````````````````````````
M`,;/````````````````````````L_/8Y/G/VL\``````````,WZ````````
M````````````````````````X^8`````````````````````````````XO(`
M``````````````````````````````#N]0````"[R@````#<XP``````````
M\LX``-G6````````L.X`````````````````````Y?3"V-#<[LP`````````
M````X-7*]LK]UMC/]````````````````*;6OMP``-3;Q]<``````````/[R
M````````S?$``````````,/BWMP``-_<`````*WOJ^8``````````-WYO^H`
M``````"N[P```````-#T\\X`````````````````````````````````````
MK.8``-[.`````/G5````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/3CT,T`````````
M``````"XU0````#]]P``J=P``````````/;>``"JW./RM.G<T@``````````
M`````````````````````````````.;I`````/;C````````````````````
M`,KG`````,[0`````/?:````````````````````````````````````````
M`````+S*````````Z.[>V@``]_(`````^^(``*;,``````````"[V@``Z>X`
M``````#:]0````#<]^KAP<ZQU```L?V]Y@``K?L`````Y_@``,[A``#B]^_U
MQ\\`````LM3OS```Z-0``,_NU_<`````IN#!UMSAX_#D\?'<I]8`````````
M`````````````````/7T`````,[QY/(`````L-``````[^P```````"Z^0``
MM>L`````[=3$X@``````````Y^D`````M.NAZ@``O/BFS@``QOG:_```L]2Y
MT][J````````J^D`````X>'/T_;T``#`ZL_A``"ZS`````````````#J[@``
M`````.3PM//NU`````#`\@````#E\0``P_34X```MNL``*'7Z,L``*WYK>GD
MV+/ZQ>*]_`````#$[+'8``"KW```````````I-4``.GK````````N^@`````
M``#7V`````````````````````"N^^'1`````,#;``"^]0``]]X`````````
M`/O*QO?(SP```````-#A`````-#N`````````````````````/3I````````
M`````````````/3.````````````````````````````````````````````
M``````#-U0````#;SP```````````````+O=``````````"LS@``````````
M````````Z.D``````````````````+34``````````#'Y```````````````
M`````````````````````````-OU`````,'Z````````J=X`````````````
M`````````````````````/C4`````````````/?O``````````"STP``````
M````````````````````````````````````````````````````M^OX[]SU
MS.W5V\_Q````````T/$```````````````````````````````````````"R
M]0```````````````*[9K-4``,;B`````````````````````*/]``#E^ZO?
M`````````````````````````````````````/7B``"M]@``L_4``+7P````
M``````"EX0```````````````````````-WU````````````````````````
M`````````````*+L_>T``+3UN/L``*/;`````,K6V<L`````````````````
M`````````-3E````````````````^O,``+CK``"WX.S7[/&OY>'5[=?1T0``
M``````````#RX?GO````````O-W<]@````````````#E\````````,3T````
M`.GI``````````````````````````#[\P``````````````````````````
M``````````````````````````````````#OU`````"BS/[WO-\`````````
M`,WK````````````````M]``````````````````````````````````````
M``````````````````#"U@````````````"MZ```````````K^^ERP``````
M````Z<L```````#H^@``````````````````````````````````QLP`````
M``#GY@````#'Z@```````*3;``#)S_SB^N\`````````````````````````
M`````````````````````````````````````````-[K`````,CU``#>U```
M``````````````````````````#5X```L.\`````Q^(``*_9````````Y_D`
M`````````````````````````````````````````````````````````.7G
M`````,K/T>$``,CB````````````````````````````````````````````
M````^^\`````^?H`````\MP`````````````````````````````````````
M````````I^``````````````Z/@`````````````````````````````````
M`.K+````````O,L``````````````````.+6````````````````````````
M`````-[U``````````````````#?]0``MNX```````#VXLK3_._$T;'O``#%
MT0``WM```.'9`````+C@`````-'-N?,`````````````````````````````
M``````````````````````````````````#,YP``J-:GS@``M=0`````````
M``````#(Y````````````````+33````````````````````````````````
M````````````````N>L```````````````#URP```````````````-WV``"C
M\0``````````````````````````````````Q\P``````````````````,KI
M``#PX0```````.#U`````````````````````*_[````````T<L`````````
M`.#[Y?(`````\.P`````````````````````````````````````````````
M``#L\```````````````````````````````````Z^X`````````````````
M``````````````#+Z0````#PS`````"OUP``````````````````````````
M``````````````````"A\P``````````````````````````````````]?P`
M`````````````````````````````````````````````````*3Q````````
M````````````````````````UN``````````````LN\`````````````````
M``````#1]`````"A]P````````````````````````````#1\0``````````
M`````````````````````/S*_<H`````````````````````SLX`````````
M````````````````````````````````````````````````````````````
M``````````````````#(\P``NO/)I\JGRZ?,I\VG````````NJ>[I]RGW:?>
MI[:GMZ>XI]2GU:?6I]>GV*>AIZ*GHZ>EIZNGK*>MIZZGKZ>PI[&GLJ>SI[2G
MIZ>HIZFGJJ>]I[ZGY:?FI^>GZ*?AI^*GXZ>_I\"GP:?"I\.GQ*?%I\:GQZ?(
MI\ZGSZ?0I]&GTJ?3I]JGVZ?CHNRGIJ?@I^^GX:*\I^VGM:<``````````+FG
MZJ<`````ZZ<`````WZ<``.2B`````.2G[J?IIP````"AH:*AHZ&HH0``````
M````M*&UH;:AMZ&XH;FANJ&[H;RAO:$``.NALJ&SH0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````H:JBJJ.JI*JEJJ:JIZJHJJFJ
MJJJKJJRJK:JNJJ^JL*JQJK*JLZJTJK6JMJJWJKBJN:JZJKNJO*J]JKZJOZK`
MJL&JPJK#JL2JQ:K&JL>JR*K)JLJJRZK,JLVJSJK/JM"JT:K2JM.JU*K5JM:J
MUZK8JMFJVJK;JMRJW:K>JM^JX*KAJN*JXZKDJN6JYJKGJNBJZ:KJJNNJ[*KM
MJNZJ[ZKPJO&J\JKSJ@``````````````````````````````````H:NBJZ.K
MI*NEJZ:KIZNHJZFKJJNKJZRKK:NNJZ^KL*NQJ[*KLZNTJ[6KMJNWJ[BKN:NZ
MJ[NKO*N]J[ZKOZO`J\&KPJO#J\2KQ:O&J\>KR*O)J\JKRZO,J\VKSJO/J]"K
MT:O2J].KU*O5J]:KUZO8J]FKVJO;J]RKW:O>J]^KX*OAJ^*KXZODJ^6KYJOG
MJ^BKZ:OJJ^NK[*OMJ^ZK[ZOPJ_&K\JOSJ_2K]:OVJP``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````H:2BI*.DI*2EI*:DIZ2HI*FDJJ2KI*RDK:2NI*^DL*2Q
MI+*DLZ2TI+6DMJ2WI+BDN:2ZI+NDO*2]I+ZDOZ3`I,&DPJ3#I,2DQ:3&I,>D
MR*3)I,JDRZ3,I,VDSJ3/I-"DT:32I-.DU*35I-:DUZ38I-FDVJ3;I-RDW:3>
MI-^DX*3AI.*DXZ3DI.6DYJ3GI.BDZ:3JI.ND[*3MI.ZD[Z3PI/&D\J3SI/2D
M]:3VI/>D^*3YI/JD^Z3\I/VD_J0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````L:FRJ;.IM*FUJ;:IMZFXJ;FINJF[J;RI
MO:F^J;^IP*G!J<*IPZG$J<6IQJG'J<BIR:G*J<NIS*G?H@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````L:BRJ+.HM*BUJ+:H
MMZBXJ+FHNJB[J+RHO:B^J+^HP*C!J,*HPZC$J,6HQJC'J,BHR:C*J,NHS*@`
M``````#>HN>HZ*CIJ.JHZZCLJ.VH[JCOJ/"H\:CRJ/.H]*CUJ```````````
M``#GJ>BIZ:GJJ>NI[*GMJ>ZI[ZGPJ?&I\JGSJ?2I]:D`````````````````
M`````````````````````````````````````````````````,VISJG/J="I
MT:G2J=.IU*G5J=:IUZG8J=FIVJG;J=RIW:G>J=^IX*GAJ>*IXZGDJ>6IYJD`
M````````````````````````````````````````````````````````````
M````````S:C.J,^HT*C1J-*HTZC4J-6HUJC7J-BHV:C:J-NHW*C=J-ZHWZC@
MJ.&HXJCCJ.2HY:CFJ```````````````````````````````````````````
M````````````````H::LIJ*FK:8`````````````````````HZ;(IL>FKJ:D
MIL*FP::OIJ:FQJ;%IK&FI:;$IL.FL*:GIKRFR:;*IK>FRZ;,IK*FJ::^ILVF
MSJ:YIL^FT*:TIJBFT:;2IKBFO:;3IM2FLZ:JIM6FUJ:ZIK^FUZ;8IK6FJZ;9
MIMJFNZ;;IMRFP*;=IMZFWZ;@IN&FXJ;CIN2FMJ8`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````,:B````````````
M``````````````````````#AH>"A``##HL>BR*++HLJBR:+,H@``````````
M``````````#CH>*A`````+JBN:(``````````.6AY*$`````N**WH@``````
M````WZ'>H<*B`````-NA`````-VAW*'$HL6B````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````VJ'9H0``
M````````````````SZ+.H@```````````````````````````````-"B``#1
MH@``````````````````````````````````````````````````````````
M`````````````````````````````,^A``#.H0``````````````````````
M``````````````````````````````````````````````````````"\HKVB
M``#`HKNBOJ(``+^BS:+;HMRB``#=HMJB`````*JA`````*ZAKZ$`````L*&Q
MH0````#3HM2B````````I:&FH0```````````````````````+:B``#'H<BA
M``````````````````#8H0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#YJ0``````
M````````````````````^JD``/NI_*G]J?ZI````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````R:$`````````````M:(```````````````````````"DIP``
M``#@H@``````````````````````````Y:+BH@```````-FG``````````#*
MH0``````````````````````````````````````````````````````````
M`````````````````````````````````````````````/>H^*@`````````
M``````#[J/RH_:C^J```L*6QI;*ELZ6TI;6EMJ6WI;BEN:4`````````````
M``"AI:*EHZ6DI:6EIJ6GI:BEJ:6JI0``````````````````````````````
M````````````````````````````YZ'HH>:AZ:'JH=6BV*+6HMFBUZ(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````H:(``**B````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"CH@``TZ&DH@```````-2A]*$`````]:$`
M``````"SH@``LJ(`````````````````````[J$`````\*'$H0``T*$`````
M`````*NA``#\H?VA^Z'ZH?*A\Z$``+&B`````````````,6A\:$`````````
M``````"MH>^A````````````````````````````````````````````````
M`````-:A``````````````````````````````````#!H=6A`````,*APZ$`
M`````````.RA[:$`````````````````````````````````````````````
M`````````````/BA^:$`````]J'WH0``````````````````````````````
M``````````````#!H@````````````````````````````#1H0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-*A`````*>B````````````
M`````````+"B``````````````````"HHJNBJJ*MH@``J:(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````P:7"I<.EQ*7%I<:E
MQZ7(I<FERJ7+I<RES:7.I<^ET*71I0``TJ73I=2EU:76I=>EV*4`````````
M`````````.&EXJ7CI>2EY:7FI>>EZ*7II>JEZZ7LI>VE[J7OI?"E\:4``/*E
M\Z7TI?6E]J7WI?BE````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"GK```````````````
M``````````````````````"AK**LHZRDK*6LIJRHK*FLJJRKK*RLK:RNK*^L
ML*RQK+*LLZRTK+6LMJRWK+BLN:RZK+NLO*R]K+ZLOZS`K,&LT:S2K-.LU*S5
MK-:LV*S9K-JLVZS<K-VLWJS?K."LX:SBK..LY*SEK.:LYZSHK.FLZJSKK.RL
M[:SNK.^L\*SQK```UZP`````````````KJ(`````M*(`````UZ&GH0``HZ@`
M````J:$`````QJ&^H?>I^*FEH@``TJ*DH:RB]JFLJ```^:CVJ/JHKZ(`````
M``````````"AJ````````````````````````**H````````````````OZ&J
MJ`````````````"MJ*RI````````````````H:D`````````````````````
M``"CJ0```````````````,"AJJD`````````````K:D`````````````````
M``````````````````````````````"BJ0``````````````````````````
M``````````````````````````"DJ*2I````````````````````````I:FF
MJ*:I``````````"GJ0```````````````*BHJ*FIJ*FI````````````````
ML*FOJ*^I````````````````JZBKJ0``````````````````````````````
M`````````````````*ZHKJD````````````````````````]3W-/1U#Y4*!2
M[U-U5.54"5;!6K9;AV:V9[=G[V=,:\)SPG4\>MN"!(-7B(B(-HK(C,^-^X[F
MC]69.U)T4P14:F!D8;QKSW,:@;J)THFCE8-/"E*^6'A9YEER7GE>QV'`8T9G
M[&=_:)=O3G8+=_5X"'K_>B%\G8!N@G&"ZXJ3E6M.G57W9C1NHWCM>EN$$(E.
MAZB7V%).5RI83%T?8;YA(6)B9=%G1&H;;AAULW7C=K!W.GVOD%&44I25GP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"-3K%PR==N`0)*8E5M2"%C<6:%<%UVW7CI?2E]W85]L>G6&=>!\
M<WVQ?8Q_5($A@I&%08D;B_R2399'G,M.]TX+4/%13U@W83YA:&$Y9>II$6^E
M=89VUG:'>Z6"RX0`^:>3BY6`5:);45<!^;-\N7^UD2A0NU-%7.A=TF)N8]ID
MYV0@;JQP6WG=C1Z.`OE]D$62^))^3O9.95#^7?I>!F%7:7&!5(9'CG63*YI>
M3I%0<&=`:`E1C5*24J)J````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````O'<0DM2>JU(O8/*/2%"I8>UCRF0\
M:(1JP&^(@:&)E)8%6'URK'($=7E];7ZI@(N)=(MCD%&=B6)Z;%1O4'TZ?R.*
M?%%*89U[&8M7DHR3K$[33QY0OE`&4<%2S5)_4W!7@UB:7I%?=F&L8<YD;&5O
M9KMF]&:7:(=MA7#Q<)]TI73*=-EU;'CL>-]Z]GI%?9-]%8`_@!N!EH-FBQ6/
M%9#ADP.8.)A:FNB;PD]353I845EC6T9<N&`28D)HL&@`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#H:*IN
M3'5X=LYX/7K[?&M^?'X(BJ&*/XR.EL2=Y%/I4TI4<53Z5M%99%L[7*M>]V(W
M945E<F6@9J]GP6F];/QUD'9^=S]ZE'\#@*&`CX'F@OV"\(/!A3&(M(BEB@/Y
MG(\ND\>69YC8FA.?[52;9?)FCVA`>C>,8)WP5F17$5T&9K%HS6C^;BATGHCD
MFVAL!/FHFIM/;%%Q49]25%OE75!@;6#Q8J=C.V79<WIZHX:BC(^7,D[A6PAB
MG&?<=```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-%YTX.'BK**Z(U.D$N31IC37NAI_X7MD`7YH%&86^Q;
M8V'Z:#YK3'`O=-ATH7M0?\6#P(FKC-R5*)DN4EU@[&("D(I/25$A4]E8XU[@
M9CAMFG#"<M9S4'OQ@%N49E.;8VM_5DZ`4$I8WE@J8"=AT&+0:4&;CUL8?;&`
M7X^D3M%0K%2L50Q;H%WG72IE3F4A:$MJX7*.=N]W7GWY?Z"!3H7?A@./3H_*
MD`.959JKFQA.14Y=3L=.\4]W4?Y2````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````0%/C4^53CE045G57HE?'
M6X==T%[\8=AB466X9^EGRVE0:\9K[&M";)UN>'#7<I9S`W2_=^EW=GI_?0F`
M_($%@@J"WX)BB#.+_(S`CA&0L9!DDK:2TIE%FNF<UYV<GPM70%S*@Z"7JY>T
MGAM4F'JD?]F(S8[AD`!82%R88Y]ZKEL37WEZKGJ.@JR.)E`X4OA2=U,(5_-B
M<F,*:\-M-W>E4U=S:(5VCM65.F?#:G!O;8K,CDN9!OEW9GAKM(P`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\FP?YZU,M5TY9QF/[:>IS17BZ>L5Z_GQUA(^)<XTUD*B5^U)'5T=U8'O,
M@QZ2"/E8:DM12U*'4A]BV&AU:9F6Q5"D4N12PV&D93EH_VE^=$M[N8+K@[*)
M.8O1CTF9"?G*3I=9TF019HYJ-'2!>;UYJ8)^B'^(7XD*^2:3"T_*4R5@<6)R
M;!I]9GV83F)1W'>O@`%/#D]V48!1W%5H5CM7^E?\5Q191UF36<1;D%P.7?%=
M?E[,7X!BUV7C90``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````!YG'V=>9\MHQ&A?:CIK(VQ];()LQVV8<R9T
M*G2"=*-T>'5_=8%X[WA!>4=Y2'EZ>95[`'VZ?8A_!H`M@(R`&(I/BTB,=XTA
MDR23XIA1F0Z:#YIEFI*>RGUV3PE4[F)4:-&1JU4Z40OY#/D<6N9A#?G/8O]B
M#OD/^1#Y$?D2^1/YHY`4^17Y%OD7^1CY_HH9^1KY&_D<^99F'?E6<1[Y'_GC
MEB#Y3V-Z8U=3(?F/9V!I<VXB^3=U(_DD^27Y````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````#7TF^2?Y<HC*
M5AA:*/DI^2KY*_DL^4-.+?EG44A9\&<0@"[Y<UET7IIDRGGU7VQ@R&)[8^=;
MUUNJ4B_Y=%DI7Q)@,/DQ^3+Y670S^33Y-?DV^3?Y./G1F3GY.OD[^3SY/?D^
M^3_Y0/E!^4+Y0_G#;T3Y1?F_@;*/\6!&^4?Y9H%(^4GY/UQ*^4OY3/E-^4[Y
M3_E0^5'YZ5HEBGMG$'U2^5/Y5/E5^5;Y5_G]@%CY6?D\7.5L/U.Z;AI9-H,`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````Y3K9.1D^N51A7QUA67[=EYF6`:K5K36[M=^]Z'GS>?<N&DH@R
MD5N3NV2^;WISN'54D%9535>Z8=1DQV;A;5MN;6^Y;_!U0X"]@4&%@XG'BEJ+
M'Y.3;%-U5'L/CEV0$%4"6%A88EX'8IYDX&AV==9\LX?HGN-.B%=N5R=9#5RQ
M7#9>A5\T8N%DLW/Z@8N(N(R*EMN>A5NW7[-@$E``4C!2%E<U6%=8#EQ@7/9<
MBUVF7I)?O&`18XEC%V1#:```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/EHPFK8;2%NU&[D;_YQW'9Y=[%Y
M.WH$A*F)[8SSC4B.`Y`4D%.0_9!-DW:6W)?2:P9P6'*B<FAS8W>_>>1[FWZ`
MBZE8QV!F9?UEOF:,;!YQR7%:C!.8;4Z!>MU.K%'-4=52#%2G87%G4&C?:!YM
M?&^\=;-WY7KT@&.$A9)<49=E7&>39]AUQWIS@UKY1HP7D"V8;US`@9J"09!O
MD`V2EU^=75EJR'%[=DE[Y(4$BR>1,)J'5?9A6_EI=H5_````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/X:Z
MA_B(CY!<^1MMV7#><V%]/81=^6J1\9E>^8).=5,$:Q)K/G`;<BV&'IY,4J./
M4%WE9"QE%FOK;T-\G'[-A62)O8G)8MB!'XC*7A=G:FW\<@5T;W2"A]Z0AD\-
M7:!?"H2W4:!C976N3@90:5')48%H$6JN?+%\YWQO@M**&X_/D;9/-U'U4D)4
M[%YN83YBQ67::OYO*GG<A2.(K95BFFJ:EY[.GIM2QF9W:QUP*WEBCT*7D&$`
M8B-E(V\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!)<8ET]'UO@.Z$)H\CD$J3O5$74J-2#&W(<,*(R5Z"
M9:YKPF\^?'5SY$XV3_E67_FZ7+I='&"R<RU[FG_.?T:`'I`TDO:62)<8F&&?
MBT^G;ZYYM)&WEMY28/F(9,1DTVI>;QAP$'+G=@&`!H9<AN^-!8\REV^;^IUU
MGHQX?WF@?<F#!)-_GI.>UHK?6`1?)V<G<,]T8'Q^@"%1*'!B<LIXPHS:C/2,
M]Y:&3MI0[EO67IEESG%"=JUW2H#\A```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'R0)YN-G]A805IB7!-J
MVFT/;SMV+WTW?AZ%.(GDDTN6B5+29?-GM&E!;9QN#W`)=&!T674D=FMX+(M>
MF&U1+F)XEI9/*U`97>IMN'TJCXM?1&$7:&'YAI;24HN`W%',45YI''J^??&#
M=9;:3RE2F%,/5`Y595RG8$YGJ&AL;8%R^'(&=(-T8OGB=6Q\>7^X?XF#SXCA
MB,R1T)'BELF;'51^;]!QF'3ZA:J.HY97G)^>EV?+;3-TZ($6ERQX````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````RWH@>Y)\:61J=/)UO'CH>*R95)N[GMY;55X@;YR!JX.(D`=.35,I6M)=
M3E]B83UC:6;\9O]N*V]C<)YW+(03A3N($X]%F3N<'%6Y8BMGJVP)@VJ)>I>A
M3H19V%_97QMGLGU4?Y*"*X.]@QZ/F9#+5[E9DEK06R=FFF>%:,]K9'%U?[>,
MXXR!D$6;"(&*C$R60)JEGE];$VP;<_)VWW8,A*I1DXE-4951R5+):)1L!'<@
M=[]]['UBE[6>Q6X`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````1A:51#51]5`YFG68G:9]NOW:1=Q>#PH2?
MAVF1F)+TG(*(KD^24=]2QED]7E5A>&1Y9*YFT&<A:LUKVVM?<F%R070X=]MW
M%X"\@@6#`(LHBXR,*&>0;&=R[G9F=T9ZJ9U_:Y)L(EDF9YF$;U.36)E9WU[/
M8S1F<V<Z;BMSUWK7@BB3V5+K7:YARV$*8L=BJV3@95EI9FO+:R%Q]W-==49^
M'H("@VJ%HXJ_C">789VH6-B>$5`.4CM43U6'90``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'9L"GT+?5Z`
MBH:`E>^6_U*5;&ER<U2:6CY<2UU,7ZY?*F>V:&-I/&Y$;@EW<WR.?X>%#HOW
MCV&7])ZW7+9@#6&K84]E^V7\91%L[VR?<\ESX7V4E<9;'(<0BUU26E/-8@]D
MLF0T9SAJRFS`<YYTE'N5?!M^BH$V@H2%ZX_YEL&9-$]*4\U3VU/,8BQD`&61
M9<-I[FQ8;^US5'4B=N1V_';0>/MX+'E&?2R"X(?4CQ*8[YC#4M1BI60D;E%O
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````?';+C;&18I+NFD.;(U"-4$I7J%DH7$=>=U\_8CYEN67!90EF
MBV><:<)NQ7@A?:J`@($K@K."H82,ABJ*%XNFD#*6D)\-4/-/8_GY5YA?W&*2
M8V]G0VX9<<-VS(#:@/2(]8@9B>",*8]-D6J6+T]P3QM>SV<B:'UV?G9$FV%>
M"FII<=1Q:G5D^4%^0X7IA=R8$$]/>W!_I97A409>M6@^;$YLVVRO<L1[`X/5
M;#IT^U"(4L%8V&27:J=T5G8`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"G>!>&XI4YEV7Y7E,!7XJ+J(^O
MCXJ0)5*E=TF<")\93@)0=5%;7'=>'F8Z9L1GQ6BS<`%UQ77)>=UZ)X\@F0B:
MW4\A6#%8]EMN9F5K$6UZ;GUOY',K=>F#W(@3B5R+%(\/3]50$%-<4Y-;J5\-
M9X]Y>8$O@Q2%!XF&B3F/.X^EF1*<+&=V3OA/25D!7.]<\%QG8])H_7"B<2MT
M*W[LA`*'(I#2DO.<#4[83N]/A5!64F]2)E205.!7*UEF6@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````%I;
M=5O,6YQ>9OEV8G=EIV5N;:5N-G(F>S]\-G]0@5&!FH%`@IF"J8,#BJ",YHS[
MC'2-NHWHD-R1')9$EMF9YYP74P92*51T5K-85%EN6?]?I&%N8A!F?FP:<<9V
MB7S>?!M]K(+!C/"69_E;3Q=??U_"8BE="V?::'QX0WYLG15.F5`54RI345.#
M66):AUZR8(IA26)Y8I!EAV>G:=1KUFO7:]AKN&QH^35T^G42>)%XU7G8>8-\
MRWWA?Z6`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/H'"@?*#&H?HB+F*;(N[C!F17I?;F#N?K%8J6VQ?
MC&6S:J]K7&WQ;Q5P77*M<Z>,TXP[F)%A-VQ8@`&:34Z+3IM.U4XZ3SQ/?T_?
M3_]0\E/X4P95XU7;5NM88ED16NM;^EL$7/-=*UZ97QU@:&.<9:]E]F?[9ZUH
M>VN9;-=L(VX)<$5S`G@^>4!Y8'G!>>E[%WUR?8:`#8*.@]&$QX;?B%"*7HH=
MB]R,9HVMCZJ0_)C?F9V>2E)I^11G:OD`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"84"I2<5QC955LRG,C
M=9UUEWN<A'B1,)=W3I)DNFM><:F%"4YK^4EG[F@7;I^"&(5KB/=C@6\2DJ^8
M"DZW4,]0'U%&5:I5%U9`6QE<X%PX7HI>H%["7O-@46AA:EAN/7)`<L!R^'9E
M>;%[U'_SB/2)<XIAC-Z,')=>6+UT_8S'56SY87HB?7*"<G(?=25U;?D9>X58
M^UB\78]>MEZ07U5@DF)_8TUED6;99OAF%FCR:(!R7G1N>VY]UGUR?P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````.6`$H*OA7^)DXH=D.22S9X@GQ59;5DM7MQ@%&9S9I!G4&S%;5]O\W>I
M>,:$RY$KD]E.RE!(4815"UNC6T=B?F7+93)N?7$!=$1TAW2_=&QVJGG:?55^
MJ']Z@;.!.8(:ANR'=8KCC7B0D9(EE$V9KIMH4U%<5&G$;"EM*VX,@IN%.XDM
MBJJ*ZI9GGV%2N6:R:Y9^_H<-C8.5798=98EM[G%N^<Y7TUFL6R=@^F`08A]F
M7V8I<_ESVW8!=VQ[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````5H!R@&6!H(J2D19.XE)R:Q=M!7HY>S!]
M;_FPC.Q3+U916+5;#UP17.)=0&*#8Q1D+6:S:+QLB&VO;A]PI'#2<29UCW6.
M=1EV$7O@>RM\('TY?2R%;84'AC2*#9!AD+60MY+VES>:UT]L7%]GD6V??(Q^
M%HL6C1^0:UO]70UDP(1<D.&8AW.+6YI@?F?>;1^*IHH!D`R8-U)P^5%PCGB6
MDW"(UY'N3]=3_57:5H)7_5C"6HA;JUS`7"5>`6$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````-8DMBB&,<
M9#9E>&4Y:HIK-&P9;3%OYW'I<GAS!W2R="9V87?`>5=ZZGJY?(]]K'UA?IY_
M*8$Q@Y"$VH3JA9:(L(J0BSB/0I"#D&R1EI*YDHN6IY:HEM:6`)<(F):9TYH:
MF]13?E@967!;OUO1;5IOGW$A=+ETA8#]@^%=AU^J7T)@[&42:&]I4VJ):S5M
M\VWC<_YVK'=->Q1](X$<@D"#](1CA6**Q(J'D1Z3!IBTF0QB4XCPCV62!UTG
M70``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&E=7W2=@6B'U6_^8M)_-HERB1Y.6$[G4-U21U-_8@=F:7X%
MB%Z6C4\94S96RUFD6CA<3EQ-7`)>$5]#8+UE+V9"9KYG]&<<<^)W.GG%?Y2$
MS826B6:*:8KABE6,>HST5]1;#U]O8.UB#6F6:UQNA''2>U6'6(O^CM^8_I@X
M3X%/X4][5"!:N%L\8;!E:&;\<3-U7GDS?4Z!XX&8@ZJ%SH4#APJ*JXZ;CW'Y
MQ8\Q6:1;YEN)8.E;"US#7X%L````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````<OGQ;0MP&G6O@O:*P$Y!4W/Y
MV98/;)Y.Q$]245Y5)5KH7!%B67*]@JJ#_H99B!V*/Y;%EA.9"9U=G0I8LUR]
M741>X6`58>%C`FHE;@*15)-.F!"<=Y^)6[A<"6-/9DAH/'?!EHV75)B?FZ%E
M`8O+CKR5-56I7-9=M5Z79DQV](/'E=-8O&+.<BB=\$XN60]@.V:#:^=Y)IV3
M4\!4PU<671MAUF:O;8UX?H*8ED27A%-\8I9CLFT*?DN!39@`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#[
M:DQ_KYT:GE]..U"V41Q9^6#V8S!I.G(V@'3YSI$Q7W7Y=OD$?>6";X2[A.6%
MC8YW^6]/>/EY^>180UM98-IC&&5M99AF>OE*:2-J"VT!<&QQTG4-=K-Y<'I[
M^8I_?/E$B7WYDXO`D7V6?OD*F017H5^\90%O`':F>9Z*K9E:FVR?!%&V89%B
MC6K&@4-0,%AF7PEQ`(KZBGQ;%H;Z3SQ1M%9$6:EC^6VJ76UIAE&(3EE/?_F`
M^8'Y@EF"^0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(/Y7VM=;(3YM706>87Y!X)%@CF#/X]=CX;Y&)F'
M^8CYB?FF3HKYWU=Y7Q-FB_F,^:MU>7YOBXWY!I!;FJ56)UCX61]:M%N.^?9>
MC_F0^5!C.V.1^3UIAVR_;(YMDVWU;11ODOG?<#9Q67&3^<-QU7&4^4]X;WB5
M^75[XWV6^2]^E_E-B-^.F/F9^9KY6Y*;^?:<G/F=^9[YA6"%;9_YL7&@^:'Y
ML96M4Z+YH_FD^=-GI?F.<#!Q,'1V@M*"````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````IOF[E>6:?9[$9J?Y
MP7%)A*CYJ?E+6*KYJ_FX77%?K/D@9HYF>6FN:3AL\VPV;D%OVF\;<"]P4''?
M<7!SK?E;=*[YU'3(=DYZDWZO^;#Y\8)@BLZ/L?E(D[+Y&9>S^;3Y0DXJ4+7Y
M"%+A4_-F;6S*;PIS?W=B>JZ"W84"AK;YU(ACBGV+:XRW^;.2N/D3EQ"8E$X-
M3\E/LE!(4SY4,U3:56)8NEAG61M:Y%N?8+GYRF%69?]E9&:G:%ILLV\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#/<*QQ4G-]>PB'I(HRG`>?2UR#;$1SB7,ZDJMN970?=FEZ%7X*AD!1
MQ5C!9.YT%75P=L%_E9#-EE29)F[F=*EZJGKE@=F&>(<;BDE:C%N;6Z%H`&EC
M;:ES$W0L=)=XZ7WK?QB!58&>@TR,+I81F/!F@%_Z98EG:FR+<RU0`UIJ:^YW
M%EEL7<U=)7-/=;KYN_GE4/E1+U@M6999VEGE6[SYO?FB7==B%F239/YDOOG<
M9K_Y2&K`^?]Q9'3!^0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(AZKWI'?EY^`(!P@<+Y[X>!B2"+69##
M^8"04IE^83)K=&T??B6)L8_13ZU0EU''4L=7B5BY6[A>0F&5:8QM9VZV;I1Q
M8G0H=2QU<X`X@\F$"HZ4D]Z3Q/F.3E%/=E`J4<A3RU/S4X=;TULD7!IA@F'T
M95MREW-`=,)V4'F1>;EY!GV]?XN"U85>AL*/1Y#UD.J1A9;HENF6UE)G7^UE
M,68O:%QQ-GK!D`J8D4[%^5)JGFN0;XEQ&("X@E.%````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````2Y"5EO*6
M^Y<:A3&;D$Z*<<260U&?4^%4$U<25Z-7FUK$6L-;*&`_8?1CA6PY;7)ND&XP
M<C]S5W31@H&(18]@D,;Y8I98F!N="&>*C5Z234])4-Y0<5,-5]19`5H)7'!A
MD&8M;C)R2W3O?<.`#H1FA#^%7X=;B!B)`HM5D,N73YMS3I%/$E%J4<?Y+U6I
M57I;I5M\7GU>OEZ@8-]@"&$)8<1C.&4)9\CYU&?:9\GY86EB:;EL)VW*^3AN
MR_D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#A;S9S-W/,^5QT,77-^5)VSOG/^:U]_H$XA-6(F(K;BNV*
M,(Y"CDJ0/I!ZD$F1R9%ND]#YT?D)6-+YTVN)@+*`T_G4^4%1:UDY7-7YUOED
M;Z=SY(`'C=?Y%Y*/E=CYV?G:^=OY?X`.8AQP:'V-A]SYH%=I8$=AMVN^BH"2
ML9993A]4ZVTMA7"6\Y?NF-9CXVR1D-U1R6&Z@?F=G4\:4`!1G%L/8?]A[&0%
M:<5KD77C=ZE_9(*/A?N'8XB\B@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'"+JY&,3N5."D_=^=[Y-UGH
M6=_Y\ET;7UM?(6#@^>'YXOGC^3YRY7/D^7!US77E^?MYYOD,@#.`A(#A@E&#
MY_GH^;V,LXR'D.GYZOGTF`R9Z_GL^3=PRG;*?\Q__'\:B[I.P4X#4G!3[?F]
M5.!6^UG%6Q5?S5]N;N[Y[_EJ?36#\/F3AHV*\?EMEW>7\OGS^0!.6D]^3_E8
MY66B;CB0L).YF?M.[%B*6=E906#T^?7Y%'KV^4^#PXQE4413````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M]_GX^?GYS4YI4E5;OX+43CI2J%3)6?]94%M76UQ;8V!(8<MNF7!N<89S]W2U
M=<%X*WT%@.J!*(,7A<F%[HK'C,R67$_Z4KQ6JV4H9GQPN'`U<KU]C8),D<"6
M<IUQ6^=HF&MZ;]YVD5RK9EMOM'LJ?#:(W)8(3M=.(%,T6+M8[UAL60=<,UZ$
M7C5?C&.R9E9G'VJC:@QK/V]&<OKY4'.+=.!ZIWQX@=^!YX&*@VR$(X64A<^%
MW8@3C:R1=Y4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"<EHU1R50H5[!;36)09SUHDV@];M-N?7`A?L&(
MH8P)CTN?3I\M<H][S8H:DT=/3D\R48!4T%F57K5B=6=N:1=JKFP:;MER*G.]
M=;A[-7WG@OF#5X3WA5N*KXR'CAF0N)#.EE^?XU(*5.%:PEM89'5E]&[$<OOY
MA'9->AM[37P^?M]_>X,KB\J,9(WAC5^.ZH_YCVF0T9-#3WI/LU!H47A135)J
M4F%8?%A@60A<55S;7IM@,&(3:+]K"&RQ;P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$YQ('0P=3AU475R
M=DQ[BWNM>\9[CWYNBCZ/28\_DI.2(I,KE/N66IAKF!Z9!U(J8IAB66UD=LIZ
MP'MV?6!3OER77CAON7"8?!&7CIO>GJ5C>F1VAP%.E4ZM3EQ0=5!(5,-9FEM`
M7JU>]UZ!7\5@.F,_971ES&5V9GAF_F=H:8EJ8VM`;,!MZ&T?;EYN'G"A<(YS
M_7,Z=5MWAWB.>0MZ?7J^?(Y]1X("BNJ*GHPMD4J1V)%FDLR2(),&EU:7````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````7)<"F`Z?-E*14GQ5)%@=7A]?C&#08Z]HWV]M>2Q[S8&ZA?V(^(I$
MCHV19):;ECV73)A*G\Y/1E'+4:E2,E847VM?JF/-9.EE06;Z9OEF'6>=:-=H
M_6D5;VYO9W'E<2IRJG0Z=U9Y6GG?>2!ZE7J7?-]\1'UP?H>`^X6DAE2*OXJ9
MC8&.()!MD..1.Y;5EN6<SV4'?+.-PY-86PI<4E/98AUS)U"76YY?L&!K8=5H
MV6TN="YZ0GV<?3%^:X$`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````JCC6.?I,8E%!/4%?F7:=>*V-J?SM.
M3T^/3UI0W5G$@&I4:%3^54]9F5O>7=I>768Q9_%G*FCH;#)M2FZ-;[=PX'.'
M=4Q\`GTL?:)]'X+;ACN*A8IPC8J.,X\QD$Z14I%$E-"9^7JE?,I/`5'&4<A7
M[UO[7%EF/6I:;99N[&\,<6]UXWHBB"&0=9#+EO^9`8,M3O).1HC-D7U3VVIK
M:4%L>H2>6(YA_F;O8MUP$77'=5)^N(1)BPB-2T[J4P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````*M4,%=`
M5]=?`6,'8V]D+V7H97IFG6>S9V)K8&R:;"QOY7<E>$EY5WD9?:*``H'S@9V"
MMX(8AXR*_/D$C;Z-<I#T=AEZ-WI4?G>`!U745758+V,B9$EF2V9M:)MIA&LE
M;;%NS7-H=*%T6W6Y=>%V'G>+=^9Y"7X=?ON!+X67B#J*T8SKCK"/,I"MDV.6
M<Y8'EX1/\5/J6<E:&5Y.:,9TOG7I>9)ZHX'MANJ,S(WMCY]E%6?]^?=75V_=
M?2^/````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````]I/&EK5?\F&$;Q1.F$\?4,E3WU5O7>Y=(6MD:\MXFGO^
M^4F.RHYND$EC/F1`=X1Z+Y-_E&J?L&2O;^9QJ'3:=,1Z$GR"?K)\F'Z:BPJ-
M?900F4R9.5+?6^9D+6<N?>U0PU-Y6%AA66'Z8:QEV7J2BY:+"5`A4'52,54\
M6N!><%\T85YE#&8V9J)FS6G$;C)O%G,A=I-Z.8%9@M:#O(2U4/!7P%OH6VE?
MH6,F>+5]W(,AA<>1]9&*4?5G5GL`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"LC,11NUF]8%6&'%#_^512
M.EQ]81IBTV+R9*5ES&X@=@J!8(Y?EKN6WTY#4YA5*5G=7<5DR6SZ;91S?WH;
M@J:%Y(P0CG>0YY'AE2&6QI?X4?)4AE6Y7Z1DB&^T?1^/38\UE,E0%ER^;/MM
M&W6[=SU\9'QYBL**'EB^619>=V-2<HIU:W?<BKR,$H_S7G1F^&U]@,&#RXI1
ME]:;`/I#4O]FE6WO;N!]YHHND%Z0U)H=4G]2Z%24881BVV*B:```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`!)I6FDU:I)P)G%=>`%Y#GG2>0UZEH!X@M6"28-)A8*,A8UBD8N1KI'#3]%6
M[7'7=P"'^(GX6]9?46>HD.)36ECU6Z1@@6%@9#U^<(`EA8.2KF2L4!1=`&><
M6+UBJ&,.:7AI'FIK;KIVRWF[@BF$SXJHC?V/$I%+D9R1$),8DYJ3VY8VF@V<
M$4Y<=5UY^GI1>\E[+G[$A%F.=([XCA"0)68_:4-T^E$N9]R>15'@7Y9L\H==
MB'>(M&"U@0.$````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````!8W64SE4-%8V6C%<BG#@?UJ`!H'M@:.-B9%?
MFO*==%#$3J!3^V`L;F1<B$\D4.15V5Q?7F5@E&B[;,1MOG'4=?1U878:>DEZ
MQWW[?6Y_](&IAAR/R9:SF5*?1U+%4NV8JHD#3M)G!F^U3^);E6>(;'AM&W0G
M>-V1?)/$A^1Y,7KK7]9.I%0^5:Y8I5GP8%-BUF(V9U5I-8)`EK&9W9DL4%-3
M1%5\5P'Z6&("^N)D:V;=9\%O[V\B=#AT%XH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````XE%%4!E9F5TA?
MFF%.:UAPK7"[?96*:EDK@:)C"'<]@*J,5%@M9+MIE5L17F]N`_IIA4Q1\%,J
M62!@2V&&:W!L\&P>>\Z`U(+&C;"0L9@$^L=DI&^19`1E3E$05!]7#HI?879H
M!?K;=5)[<7T:D`98S&E_@2J)`)`YF'A05UFL695B#Y`JFUUA>7+6E6%71EKT
M78IBK63Z9'=GXFP^;2QR-G0T>'=_K8+;C1>8)%)"5W]G2'+C=*F,IH\1D@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"J6:U'M4TQC:4\$599@5V6;;']M3'+]<A=ZAXF=C&U?CF_Y<*B!
M#F&_3T]006)'<L=[Z'WI?TV0K9<9FK:,:E=S7K!G#815BB!4%EMC7N)>"E^#
M9;J`/86)E5N62$\%4PU3#U.&5/I4`U<#7A9@FV*Q8E5C!OKA;&9ML74R>-Z`
M+X'>@F&$LH2-B!*)"Y#JDOV8D9M%7K1FW681<`9R!_KU3WU2:E]385-G&6H"
M;^)T:'EHB'F,QYC$F$.:````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````P50?>E-I]XI*C*B8KIE\7ZMBLG6N
M=JN(?Y!"ECE3/%_%7\QLS'-B=8MU1GO^@IV93TX\D`M.54^F4P]9R%XP9K-L
M571W@V:'P(Q0D!Z7%9S16'A;4(84B[2=TEMH8(U@\657;")OHV\:<%5_\'^1
ME9*54);3EW)21(_]42M4N%1C58I5NVJU;=A]9H*<DG>6>9X(5,A4TG;DAJ25
MU)5<EJ)."4_N6>9:]UU28)=B;6=!:(9L+VXX?YN`*H(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````(^@GZ
M!9BE3E50LU235UI9:5NS6\AA=VEW;2-P^8?CB7**YXJ"D.V9N)J^4CAH%E!X
M7D]G1X-,B*M.$52N5N9S%9'_EPF95YF9F5-6GUA;AC&*LF'V:GMSTHY':ZJ6
M5YI560!R:XUIE]1/]%PF7_AA6V;K;*MPA'.Y<_YS*7=-=T-]8GTC?C>"4H@*
M^N*,29)OF%%;='I`B`&8S%K@3U13/EG]7#YC>6WY<@6!!X&B@\^2,)BH3D11
M$5*+5P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````&)?PFS.;@5P4'"O<))QZ7-I=$J#HH=AB`B0HI"CDZB9
M;E%77^!@9V&S9EF%2HZOD8N73DZ23GQ4U5CZ6'U9M5PG7S9B2&(*9F=FZVMI
M;<]M5F[X;I1OX&_I;UUPT'(E=%ITX'23=EQYRGP>?N&`IH)KA+^$3H9?AG2'
M=XMJC*R3`)AEF-%@%F)WD5I:#V;W;3YN/W1"F_U?VF`/>\14&%]>;--L*FW8
M<`5]>88,BCN=%E.,5`5;.FIK<'5U````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````C7F^>;&"[X-QBD&+J(QT
MEPOZ]&0K9;IXNWAK>CA.FE506:9;>UZC8-MC86ME9E-H&6YE<;!T"'V$D&F:
M)9P[;=%N/G-!C,J5\%%,7JA?36#V8#!A3&%#9D1FI6G!;%]NR6YB;TQQG'2'
M=L%[)WQ2@U>'49"-EL.>+U/>5OM>BE]B8)1@]V%F9@-GG&KN;:YO<'!J<VI^
MOH$T@]2&J(K$C(-2<G.66VMJ!)3N5(9675M(985ER6:?:(UMQFT`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```[<K2`=9%-FJ]/&5":4PY4/%2)5<55/UZ,7SUG9G'=<P60VU+S4F18SE@$
M<8]Q^W&PA1.*B&:HA:=5A&9*<3&$25.95<%K65^]7^YCB69'<?&*'8^^GA%/
M.F3+<&9U9X9D8$Z+^)U'4?91"%,V;?B`T9X59B-KF'#5=0-4>5P'?1:*(&L]
M:T9K.%1P8#UMU7\(@M90WE&<56M6S5;L60E;#%Z989AA,6)>9N9FF7&Y<;IQ
MIW*G>0!ZLG]PB@`````"K`.L!:P&K`NL#*P-K`ZL#ZP8K!ZL'ZPAK"*L(ZPE
MK":L)ZPHK"FL*JPKK"ZL,JPSK#2L````````````````-:PVK#>L.JP[K#VL
M/JP_K$&L0JQ#K$2L1:Q&K$>L2*Q)K$JL3*Q.K$^L4*Q1K%*L4ZQ5K```````
M`````````%:L5ZQ9K%JL6ZQ=K%ZL7ZQ@K&&L8JQCK&2L9:QFK&>L:*QIK&JL
M:ZQLK&VL;JQOK'*L<ZQUK':L>:Q[K'RL?:Q^K'^L@JR'K(BLC:R.K(^LD:R2
MK).LE:R6K)>LF*R9K)JLFZR>K**LHZRDK*6LIJRGK*NLK:RNK+&LLJRSK+2L
MM:RVK+>LNJR^K+^LP*S"K,.LQ:S&K,>LR:S*K,NLS:S.K,^LT*S1K-*LTZS4
MK-:LV*S9K-JLVZS<K-VLWJS?K.*LXZSEK.:LZ:SKK.VL[JSRK/2L]ZSXK/FL
M^JS[K/ZL_ZP!K0*M`ZT%K0>M"*T)K0JM"ZT.K1"M$JT3K0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````!2M%:T6K1>M&:T:K1NM
M':T>K1^M(:TBK2.M)*TEK2:M)ZTHK2JM*ZTNK2^M,*TQK3*M,ZT`````````
M```````VK3>M.:TZK3NM/:T^K3^M0*U!K4*M0ZU&K4BM2JU+K4RM3:U.K4^M
M4:U2K5.M5:U6K5>M````````````````6:U:K5NM7*U=K5ZM7ZU@K6*M9*UE
MK6:M9ZUHK6FM:JUKK6ZM;ZUQK7*M=ZUXK7FM>JU^K8"M@ZV$K86MAJV'K8JM
MBZV-K8ZMCZV1K9*MDZV4K96MEJV7K9BMF:V:K9NMGJV?K:"MH:VBK:.MI:VF
MK:>MJ*VIK:JMJZVLK:VMKJVOK;"ML:VRK;.MM*VUK;:MN*VYK;JMNZV\K;VM
MOJV_K<*MPZW%K<:MQZW)K<JMRZW,K<VMSJW/K=*MU*W5K=:MUZW8K=FMVJW;
MK=VMWJW?K>&MXJWCK>6MYJWGK>BMZ:WJK>NM[*WMK>ZM[ZWPK?&M\JWSK?2M
M]:WVK?>M````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````^JW[K?VM_JT"K@.N!*X%K@:N!ZX*K@RN#JX/KA"N$:X2KA.N%:X6KA>N
M&*X9KAJN&ZX<K@```````````````!VN'JX?KB"N(:XBKB.N)*XEKB:N)ZXH
MKBFN*JXKKBRN+:XNKB^N,JXSKC6N-JXYKCNN/*X````````````````]KCZN
M/ZY"KD2N1ZY(KDFN2ZY/KE&N4JY3KE6N5ZY8KEFN6JY;KEZN8JYCKF2N9JYG
MKFJN:ZYMKFZN;ZYQKG*N<ZYTKG6N=JYWKGJN?JY_KH"N@:Z"KH.NAJZ'KHBN
MB:Z*KHNNC:Z.KH^ND*Z1KI*NDZZ4KI6NEJZ7KIBNF:Z:KINNG*Z=KIZNGZZ@
MKJ&NHJZCKJ2NI:ZFKJ>NJ*ZIKJJNJZZLKJVNKJZOKK"NL:ZRKK.NM*ZUKK:N
MMZZXKKFNNJZ[KK^NP:["KL.NQ:[&KL>NR*[)KLJNRZ[.KM*NTZ[4KM6NUJ[7
MKMJNVZ[=KMZNWZ[@KN&NXJ[CKN2NY:X`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#FKN>NZ:[JKNRN[J[OKO"N\:[RKO.N]:[V
MKO>N^:[ZKONN_:[^KO^N`*\!KP*O`Z\$KP6O````````````````!J\)KPJO
M"Z\,KPZO#Z\1KQ*O$Z\4KQ6O%J\7KQBO&:\:KQNO'*\=KQZO'Z\@KR&O(J\C
MKP```````````````"2O):\FKR>O**\IKRJO*Z\NKR^O,:\SKS6O-J\WKSBO
M.:\ZKSNO/J]`KT2O1:]&KT>O2J]+KTRO3:].KT^O4:]2KU.O5*]5KU:O5Z]8
MKUFO6J];KUZO7Z]@KV&O8J]CKV:O9Z]HKVFO:J]KKVRO;:]NKV^O<*]QKW*O
M<Z]TKW6O=J]WKWBO>J][KWRO?:]^KW^O@:^"KX.OA:^&KX>OB:^*KXNOC*^-
MKXZOCZ^2KY.OE*^6KY>OF*^9KYJOFZ^=KYZOGZ^@KZ&OHJ^CKZ2OI:^FKZ>O
MJ*^IKZJOJZ^LKZVOKJ^OK["OL:^RK[.OM*^UK[:OMZ^ZK[NOO:^^KP``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````+^OP:_"K\.O
MQ*_%K\:ORJ_,K\^OT*_1K]*OTZ_5K]:OUZ_8K]FOVJ_;K]VOWJ_?K^"OX:\`
M``````````````#BK^.OY*_EK^:OYZ_JK^NO[*_MK^ZO[Z_RK_.O]:_VK_>O
M^:_ZK_NO_*_]K_ZO_Z\"L`.P````````````````!;`&L`>P"+`)L`JP"[`-
ML`ZP#[`1L!*P$[`5L!:P%[`8L!FP&K`;L!ZP'[`@L"&P(K`CL"2P);`FL">P
M*;`JL"NP++`ML"ZP+[`PL#&P,K`SL#2P-;`VL#>P.+`YL#JP.[`\L#VP/K`_
ML$"P0;!"L$.P1K!'L$FP2[!-L$^P4+!1L%*P5K!8L%JP6[!<L%ZP7[!@L&&P
M8K!CL&2P9;!FL&>P:+!IL&JP:[!LL&VP;K!OL'"P<;!RL'.P=+!UL':P=[!X
ML'FP>K![L'ZP?["!L(*P@["%L(:PA["(L(FPBK"+L(ZPD+"2L).PE+"5L):P
ME[";L)VPGK"CL*2P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````I;"FL*>PJK"PL+*PMK"WL+FPNK"[L+VPOK"_L,"PP;#"L,.P
MQK#*L,NPS+#-L,ZPS[#2L````````````````-.PU;#6L->PV;#:L-NPW+#=
ML-ZPW[#AL.*PX[#DL.:PY[#HL.FPZK#KL.RP[;#NL.^P\+``````````````
M``#QL/*P\[#TL/6P]K#WL/BP^;#ZL/NP_+#]L/ZP_[``L0&Q`K$#L02Q!;$&
ML0>Q"K$-L0ZQ#[$1L12Q%;$6L1>Q&K$>L1^Q(+$AL2*Q)K$GL2FQ*K$KL2VQ
M+K$OL3"Q,;$RL3.Q-K$ZL3NQ/+$]L3ZQ/[%"L4.Q1;%&L4>Q2;%*L4NQ3+%-
ML4ZQ3[%2L5.Q5K%7L5FQ6K%;L5VQ7K%?L6&Q8K%CL62Q9;%FL6>Q:+%IL6JQ
M:[%LL6VQ;K%OL7"Q<;%RL7.Q=+%UL7:Q=[%ZL7NQ?;%^L7^Q@;&#L82QA;&&
ML8>QBK&,L8ZQC[&0L9&QE;&6L9>QF;&:L9NQG;$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````">L9^QH+&AL:*QH[&DL:6QIK&G
ML:FQJK&KL:RQK;&NL:^QL+&QL;*QL[&TL;6QMK&WL;BQ````````````````
MN;&ZL;NQO+&]L;ZQO['`L<&QPK'#L<2QQ;'&L<>QR+')L<JQR['-L<ZQS['1
ML=*QT['5L0```````````````-:QU['8L=FQVK';L=ZQX+'AL>*QX['DL>6Q
MYK'GL>JQZ['ML>ZQ[['QL?*Q\['TL?6Q]K'WL?BQ^K'\L?ZQ_[$`L@&R`K(#
ML@:R![()L@JR#;(.L@^R$+(1LA*R$[(6LABR&K(;LARR';(>LA^R(;(BLB.R
M)+(ELB:R)[(HLBFR*K(KLBRR+;(NLB^R,+(QLC*R,[(ULC:R-[(XLCFR.K([
MLCVR/K(_LD"R0;)"LD.R1+)%LD:R1[)(LDFR2K)+LDRR3;).LD^R4+)1LE*R
M4[)4LE6R5K)7LEFR6K);LEVR7K)?LF&R8K)CLF2R9;)FLF>R:K)KLFRR;;)N
ML@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````&^R
M<+)QLG*R<[)VLG>R>+)YLGJR>[)]LGZR?[*`LH&R@K*#LH:RA[*(LHJRB[*,
MLHVRCK(```````````````"/LI*RD[*5LI:RE[*;LIRRG;*>LI^RHK*DLJ>R
MJ+*ILJNRK;*NLJ^RL;*RLK.RM;*VLK>R````````````````N+*YLKJRN[*\
MLKVROK*_LL"RP;+"LL.RQ++%LL:RQ[+*LLNRS;+.LL^RT;+3LM2RU;+6LM>R
MVK+<LMZRW[+@LN&RX[+GLNFRZK+PLO&R\K+VLORR_;+^L@*S`[,%LP:S![,)
MLPJS"[,,LPVS#K,/LQ*S%K,7LQBS&;,:LQNS';,>LQ^S(+,ALR*S([,DLR6S
M)K,GLRBS*;,JLRNS++,MLRZS+[,PLS&S,K,SLS2S-;,VLS>S.+,YLSJS.[,\
MLSVS/K,_LT"S0;-"LT.S1+-%LT:S1[-(LTFS2K-+LTRS3;-.LT^S4+-1LU*S
M4[-7LUFS6K-=LV"S8;-BLV.S````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````9K-HLVJS;+-MLV^S<K-SLW6S=K-WLWFS>K-[LWRS
M?;-^LW^S@K.&LX>SB+.)LXJSB[.-LP```````````````(ZSC[.1LY*SD[.5
MLY:SE[.8LYFSFK.;LYRSG;.>LY^SHK.CLZ2SI;.FLZ>SJ;.JLZNSK;,`````
M``````````"NLZ^SL+.QL[*SL[.TL[6SMK.WL[BSN;.ZL[NSO+.]L[ZSO[/`
ML\&SPK/#L\:SQ[/)L\JSS;//L]&STK/3L]:SV+/:L]RSWK/?L^&SXK/CL^6S
MYK/GL^FSZK/KL^RS[;/NL^^S\+/QL_*S\[/TL_6S]K/WL_BS^;/ZL_NS_;/^
ML_^S`+0!M`*T`[0$M`6T!K0'M`BT";0*M`NT#+0-M`ZT#[01M!*T$[04M!6T
M%K07M!FT&K0;M!VT'K0?M"&T(K0CM"2T);0FM">T*K0LM"VT+K0OM#"T,;0R
MM#.T-;0VM#>T.+0YM#JT.[0\M#VT/K0_M$"T0;1"M$.T1+0`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!%M$:T1[1(M$FT2K1+
MM$RT3;1.M$^T4K13M%6T5K17M%FT6K1;M%RT7;1>M%^T8K1DM&:T````````
M````````9[1HM&FT:K1KM&VT;K1OM'"T<;1RM'.T=+1UM':T=[1XM'FT>K1[
MM'RT?;1^M'^T@;2"M````````````````(.TA+2%M(:TA[2)M(JTB[2,M(VT
MCK2/M)"TD;22M).TE+25M):TE[28M)FTFK2;M)RTGK2?M*"TH;2BM*.TI;2F
MM*>TJ;2JM*NTK;2NM*^TL+2QM+*TL[2TM+:TN+2ZM+NTO+2]M+ZTO[3!M,*T
MP[3%M,:TQ[3)M,JTR[3,M,VTSK3/M-&TTK33M-2TUK37M-BTV;3:M-NTWK3?
MM.&TXK3EM.>TZ+3IM.JTZ[3NM/"T\K3SM/2T];3VM/>T^;3ZM/NT_+3]M/ZT
M_[0`M0&U`K4#M02U!;4&M0>U"+4)M0JU"[4,M0VU#K4/M1"U$;42M1.U%K47
MM1FU&K4=M0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````!ZU'[4@M2&U(K4CM2:U*[4LM2VU+K4OM3*U,[4UM3:U-[4YM3JU.[4\
MM3VU/K4_M4*U1K4```````````````!'M4BU2;5*M4ZU3[51M5*U4[55M5:U
M5[58M5FU6K5;M5ZU8K5CM62U9;5FM6>U:+5IM6JU````````````````:[5L
MM6VU;K5OM7"U<;5RM7.U=+5UM7:U=[5XM7FU>K5[M7RU?;5^M7^U@+6!M8*U
M@[6$M86UAK6'M8BUB;6*M8NUC+6-M8ZUC[60M9&UDK63M92UE;66M9>UF+69
MM9JUF[6<M9VUGK6?M:*UH[6EM::UI[6IM:RUK;6NM:^ULK6VM;>UN+6YM;JU
MOK6_M<&UPK7#M<6UQK7'M<BUR;7*M<NUSK72M=.UU+75M=:UU[79M=JUV[7<
MM=VUWK7?M>"UX;7BM>.UY+7EM>:UY[7HM>FUZK7KM>VU[K7OM?"U\;7RM?.U
M]+7UM?:U][7XM?FU^K7[M?RU_;7^M?^U````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````+8!M@*V`[8$M@6V!K8'M@BV";8*M@NV
M#+8-M@ZV#[82MA.V%;86MA>V&;8:MANV'+8=M@```````````````!ZV'[8@
MMB&V(K8CMB2V)K8GMBBV*;8JMBNV+;8NMB^V,+8QMC*V,[8UMC:V-[8XMCFV
M.K8````````````````[MCRV/;8^MC^V0+9!MD*V0[9$MD6V1K9'MDFV2K9+
MMDRV3;9.MD^V4+91ME*V4[94ME6V5K97MEBV6;9:MENV7+9=MEZV7[9@MF&V
M8K9CMF6V9K9GMFFV:K9KMFRV;;9NMF^V<+9QMG*V<[9TMG6V=K9WMGBV>;9Z
MMGNV?+9]MGZV?[:`MH&V@K:#MH2VA;:&MH>VB+:)MHJVB[:,MHVVCK:/MI"V
MD;:2MI.VE+:5MI:VE[:8MIFVFK:;MIZVG[:AMJ*VH[:EMJ:VI[:HMJFVJK:M
MMJZVK[:PMK*VL[:TMK6VMK:WMKBVN;:ZMKNVO+:]MKZVO[;`ML&VPK8`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````##ML2VQ;;&
MML>VR+;)MLJVR[;,MLVVSK;/MM"VT;;2MM.VU;;6MM>VV+;9MMJVV[;<MMVV
M````````````````WK;?MN"VX;;BMN.VY+;EMN:VY[;HMNFVZK;KMNRV[;;N
MMN^V\;;RMO.V];;VMO>V^;;ZM@```````````````/NV_+;]MOZV_[8"MP.W
M!+<&MP>W"+<)MPJW"[<,MPVW#K</MQ"W$;<2MQ.W%+<5MQ:W%[<8MQFW&K<;
MMQRW';<>MQ^W(+<AMR*W([<DMR6W)K<GMRJW*[<MMRZW,;<RMS.W-+<UMS:W
M-[<ZMSRW/;<^MS^W0+=!MT*W0[=%MT:W1[=)MTJW2[=-MTZW3[=0MU&W4K=3
MMU:W5[=8MUFW6K=;MURW7;=>MU^W8;=BMV.W9;=FMV>W:;=JMVNW;+=MMVZW
M;[=RMW2W=K=WMWBW>;=ZMWNW?K=_MX&W@K>#MX6WAK>'MXBWB;>*MXNWCK>3
MMY2WE;>:MYNWG;>>MP``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````)^WH;>BMZ.WI+>EMZ:WI[>JMZZWK[>PM[&WLK>SM[:WM[>Y
MM[JWN[>\M[VWOK>_M\"WP;<```````````````#"M\.WQ+?%M\:WR+?*M\NW
MS+?-M\ZWS[?0M]&WTK?3M]2WU;?6M]>WV+?9M]JWV[?<M]VW````````````
M````WK??M^"WX;?BM^.WY+?EM^:WY[?HM^FWZK?KM^ZW[[?QM_*W\[?UM_:W
M][?XM_FW^K?[M_ZW`K@#N`2X!;@&N`JX"[@-N`ZX#[@1N!*X$[@4N!6X%K@7
MN!JX'+@>N!^X(+@AN"*X([@FN">X*;@JN"NX+;@NN"^X,+@QN#*X,[@VN#JX
M.[@\N#VX/K@_N$&X0KA#N$6X1KA'N$BX2;A*N$NX3+A-N$ZX3[A0N%*X5+A5
MN%:X5[A8N%FX6KA;N%ZX7[AAN&*X8[AEN&:X9[AHN&FX:KAKN&ZX<+ARN'.X
M=+AUN':X=[AYN'JX>[A]N'ZX?[B`N(&X@KB#N(2X````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````A;B&N(>XB+B)N(JXB[B,N(ZX
MC[B0N)&XDKB3N)2XE;B6N)>XF+B9N)JXF[B<N)VXGKB?N```````````````
M`*"XH;BBN*.XI+BEN*:XI[BIN*JXJ[BLN*VXKKBON+&XLKBSN+6XMKBWN+FX
MNKB[N+RXO;@```````````````"^N+^XPKC$N,:XQ[C(N,FXRKC+N,VXSKC/
MN-&XTKC3N-6XUKC7N-BXV;C:N-NXW+C>N."XXKCCN.2XY;CFN.>XZKCKN.VX
M[KCON/&X\KCSN/2X];CVN/>X^KC\N/ZX_[@`N0&Y`KD#N06Y!KD'N0BY";D*
MN0NY#+D-N0ZY#[D0N1&Y$KD3N12Y%;D6N1>Y&;D:N1NY'+D=N1ZY'[DAN2*Y
M([DDN26Y)KDGN2BY*;DJN2NY++DMN2ZY+[DPN3&Y,KDSN32Y-;DVN3>Y.+DY
MN3JY.[D^N3^Y0;E"N4.Y1;E&N4>Y2+E)N4JY2[E-N4ZY4+E2N5.Y5+E5N5:Y
M5[D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!:
MN5NY7;E>N5^Y8;EBN6.Y9+EEN6:Y9[EJN6RY;KEON7"Y<;ERN7.Y=KEWN7FY
M>KE[N7VY````````````````?KE_N8"Y@;F"N8.YAKF(N8NYC+F/N9"YD;F2
MN9.YE+F5N9:YE[F8N9FYFKF;N9RYG;F>N0```````````````)^YH+FAN:*Y
MH[FDN:6YIKFGN:BYJ;FJN:NYKKFON;&YLKFSN;6YMKFWN;BYN;FZN;NYOKG`
MN<*YP[G$N<6YQKG'N<JYR[G-N=.YU+G5N=:YU[G:N=RYW[G@N>*YYKGGN>FY
MZKGKN>VY[KGON?"Y\;GRN?.Y]KG[N?RY_;G^N?^Y`KH#N@2Z!;H&N@>Z";H*
MN@NZ#+H-N@ZZ#[H0NA&Z$KH3NA2Z%KH7NABZ&;H:NANZ'+H=NAZZ'[H@NB&Z
M(KHCNB2Z);HFNB>Z*+HINBJZ*[HLNBVZ+KHONC"Z,;HRNC.Z-+HUNC:Z-[HZ
MNCNZ/;H^NC^Z0;I#ND2Z1;I&N@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$>Z2KI,ND^Z4+I1NE*Z5KI7NEFZ6KI;NEVZ7KI?
MNF"Z8;IBNF.Z9KIJNFNZ;+IMNFZZ;[H```````````````!RNG.Z=;IVNG>Z
M>;IZNGNZ?+I]NGZZ?[J`NH&Z@KJ&NHBZB;J*NHNZC;J.NH^ZD+J1NI*Z````
M````````````D[J4NI6ZEKJ7NIBZF;J:NINZG+J=NIZZG[J@NJ&ZHKJCNJ2Z
MI;JFNJ>ZJKJMNJZZK[JQNK.ZM+JUNK:ZM[JZNKRZOKJ_NL"ZP;K"NL.ZQ;K&
MNL>ZR;K*NLNZS+K-NLZZS[K0NM&ZTKK3NM2ZU;K6NM>ZVKK;NMRZW;K>NM^Z
MX+KANN*ZX[KDNN6ZYKKGNNBZZ;KJNNNZ[+KMNNZZ[[KPNO&Z\KKSNO2Z];KV
MNO>Z^+KYNOJZ^[K]NOZZ_[H!NP*[`[L%NP:[![L(NPF["KL+NPR[#KL0NQ*[
M$[L4NQ6[%KL7NQF[&KL;NQV['KL?NR&[(KLCNR2[);LFNR>[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````*+LJNRR[+;LNNR^[
M,+LQNS*[,[LWNSF[.KL_NT"[0;M"NT.[1KM(NTJ[2[M,NTZ[4;M2NP``````
M`````````%.[5;M6NU>[6;M:NUN[7+M=NUZ[7[M@NV*[9+MENV:[9[MHNVF[
M:KMKNVV[;KMONW"[<;L```````````````!RNW.[=+MUNW:[=[MXNWF[>KM[
MNWR[?;M^NW^[@+N!NX*[@[N$NX6[AKN'NXF[BKN+NXV[CKN/NY&[DKN3NY2[
ME;N6NY>[F+N9NYJ[F[N<NYV[GKN?NZ"[H;NBNZ.[I;NFNZ>[J;NJNZN[K;NN
MNZ^[L+NQN[*[L[NUN[:[N+NYN[J[N[N\N[V[OKN_N\&[PKO#N\6[QKO'N\F[
MRKO+N\R[S;O.N\^[T;O2N]2[U;O6N]>[V+O9N]J[V[O<N]V[WKO?N^"[X;OB
MN^.[Y+OEN^:[Y[OHN^F[ZKOKN^R[[;ONN^^[\+OQN_*[\[OTN_6[]KOWN_J[
M^[O]N_Z[`;P`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````#O`2\!;P&O`>\"KP.O!"\$KP3O!F\&KP@O"&\(KPCO":\*+PJO"N\
M++PNO"^\,KPSO#6\````````````````-KPWO#F\.KP[O#R\/;P^O#^\0KQ&
MO$>\2+Q*O$N\3KQ/O%&\4KQ3O%2\5;Q6O%>\6+Q9O````````````````%J\
M6[Q<O%Z\7[Q@O&&\8KQCO&2\9;QFO&>\:+QIO&J\:[QLO&V\;KQOO'"\<;QR
MO'.\=+QUO':\=[QXO'F\>KQ[O'R\?;Q^O'^\@+R!O(*\@[R&O(>\B;R*O(V\
MC[R0O)&\DKR3O):\F+R;O)R\G;R>O)^\HKRCO*6\IKRIO*J\J[RLO*V\KKRO
MO+*\MKRWO+B\N;RZO+N\OKR_O,&\PKS#O,6\QKS'O,B\R;S*O,N\S+S.O-*\
MT[S4O-:\U[S9O-J\V[S=O-Z\W[S@O.&\XKSCO.2\Y;SFO.>\Z+SIO.J\Z[SL
MO.V\[KSOO/"\\;SRO/.\][SYO/J\^[S]O```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/Z\_[P`O0&]`KT#O0:]"+T*O0N]#+T-
MO0Z]#[T1O1*]$[T5O1:]%[T8O1F]&KT;O1R]';T````````````````>O1^]
M(+TAO2*]([TEO2:])[THO2F]*KTKO2V]+KTOO3"],;TRO3.]-+TUO3:]-[TX
MO3F]````````````````.KT[O3R]/;T^O3^]0;U"O4.]1+U%O4:]1[U*O4N]
M3;U.O4^]4;U2O5.]5+U5O5:]5[U:O5N]7+U=O5Z]7[U@O6&]8KUCO66]9KUG
MO6F]:KUKO6R];;UNO6^]<+UQO7*]<[UTO76]=KUWO7B]>;UZO7N]?+U]O7Z]
M?[V"O8.]A;V&O8N]C+V-O8Z]C[V2O92]EKV7O9B]F[V=O9Z]G[V@O:&]HKVC
MO:6]IKVGO:B]J;VJO:N]K+VMO:Z]K[VQO;*]L[VTO;6]MKVWO;F]NKV[O;R]
MO;V^O;^]P+W!O<*]P[W$O<6]QKW'O<B]R;W*O<N]S+W-O<Z]S[W0O=&]````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````TKW3O=:]
MU[W9O=J]V[W=O=Z]W[W@O>&]XKWCO>2]Y;WFO>>]Z+WJO>N][+WMO>Z][[WQ
MO0```````````````/*]\[WUO?:]][WYO?J]^[W\O?V]_KW_O0&^`KX$O@:^
M![X(O@F^"KX+O@Z^#[X1OA*^$[X````````````````5OA:^%[X8OAF^&KX;
MOAZ^(+XAOB*^([XDOB6^)KXGOBB^*;XJOBN^++XMOBZ^+[XPOC&^,KXSOC2^
M-;XVOC>^.+XYOCJ^.[X\OCV^/KX_OD"^0;Y"OD.^1KY'ODF^2KY+ODV^3[Y0
MOE&^4KY3OE:^6+Y<OEV^7KY?OF*^8[YEOF:^9[YIOFN^;+YMOFZ^;[YROG:^
M=[YXOGF^>KY^OG^^@;Z"OH.^A;Z&OH>^B+Z)OHJ^B[Z.OI*^D[Z4OI6^EKZ7
MOIJ^F[Z<OIV^GKZ?OJ"^H;ZBOJ.^I+ZEOJ:^I[ZIOJJ^J[ZLOJV^KKZOOK"^
ML;ZROK.^M+ZUOK:^M[X`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"XOKF^NKZ[OKR^O;Z^OK^^P+[!OL*^P[[$OL6^QK['OLB^
MR;[*OLN^S+[-OLZ^S[[2OM.^````````````````U;[6OMF^VK[;OMR^W;[>
MOM^^X;[BON:^Y[[HONF^ZK[KONV^[K[OOO"^\;[ROO.^]+[UO@``````````
M`````/:^][[XOOF^^K[[OOR^_;[^OO^^`+\"OP._!+\%OP:_![\*OPN_#+\-
MOPZ_#[\0OQ&_$K\3OQ2_%;\6OQ>_&K\>OQ^_(+\AOR*_([\DOR6_)K\GORB_
M*;\JORN_++\MORZ_+[\POS&_,K\SOS2_-;\VOS>_.+\YOSJ_.[\\OSV_/K\_
MOT*_0[]%OT:_1[])OTJ_2[],OTV_3K]/OU*_4[]4OU:_5[]8OUF_6K];OUR_
M7;]>OU^_8+]AOV*_8[]DOV6_9K]GOVB_:;]JOVN_;+]MOVZ_;[]POW&_<K]S
MOW2_=;]VOW>_>+]YOWJ_>[]\OWV_?K]_OX"_@;^"OP``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(._A+^%OX:_A[^(OXF_BK^+
MOXR_C;^.OX^_D+^1OY*_D[^5OY:_E[^8OYF_FK^;OYR_G;\`````````````
M``">OY^_H+^AOZ*_H[^DOZ6_IK^GOZB_J;^JOZN_K+^MOZZ_K[^QO[*_L[^T
MO[6_MK^WO[B_````````````````N;^ZO[N_O+^]O[Z_O[_`O\&_PK_#O\2_
MQK_'O\B_R;_*O\N_SK_/O]&_TK_3O]6_UK_7O]B_V;_:O]N_W;_>O^"_XK_C
MO^2_Y;_FO^>_Z+_IO^J_Z[_LO^V_[K_OO_"_\;_RO_._]+_UO_:_][_XO_F_
M^K_[O_R__;_^O_^_`,`!P`+``\`$P`7`!L`'P`C`"<`*P`O`#,`-P`[`#\`0
MP!'`$L`3P!3`%<`6P!?`&,`9P!K`&\`<P!W`'L`?P"#`(<`BP"/`),`EP";`
M)\`HP"G`*L`KP"S`+<`NP"_`,,`QP#+`,\`TP#7`-L`WP#C`.<`ZP#O`/<`^
MP#_`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M0,!!P$+`0\!$P$7`1L!'P$C`2<!*P$O`3,!-P$[`3\!0P%+`4\!4P%7`5L!7
MP%G`6L!;P````````````````%W`7L!?P&'`8L!CP&3`9<!FP&?`:L!KP&S`
M;<!NP&_`<,!QP'+`<\!TP'7`=L!WP'C`><````````````````!ZP'O`?,!]
MP'[`?\"`P('`@L"#P(3`A<"&P(?`B,")P(K`B\",P(W`CL"/P)+`D\"5P);`
ME\"9P)K`F\"<P)W`GL"?P*+`I,"FP*?`J,"IP*K`J\"NP+'`LL"WP+C`N<"Z
MP+O`OL#"P,/`Q,#&P,?`RL#+P,W`SL#/P-'`TL#3P-3`U<#6P-?`VL#>P-_`
MX,#AP.+`X\#FP.?`Z<#JP.O`[<#NP._`\,#QP/+`\\#VP/C`^L#[P/S`_<#^
MP/_``<$"P0/!!<$&P0?!"<$*P0O!#,$-P0[!#\$1P1+!$\$4P1;!%\$8P1G!
M&L$;P2'!(L$EP2C!*<$JP2O!+L$`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````RP3/!-,$UP3?!.L$[P3W!/L$_P4'!0L%#P43!
M1<%&P4?!2L%.P4_!4,%1P5+!4\%6P5?!````````````````6<%:P5O!7<%>
MP5_!8,%AP6+!8\%FP6K!:\%LP6W!;L%OP7'!<L%SP77!=L%WP7G!>L%[P0``
M`````````````'S!?<%^P7_!@,&!P8+!@\&$P8;!A\&(P8G!BL&+P8_!D<&2
MP9/!E<&7P9C!F<&:P9O!GL&@P:+!H\&DP:;!I\&JP:O!K<&NP:_!L<&RP;/!
MM,&UP;;!M\&XP;G!NL&[P;S!OL&_P<#!P<'"P</!Q<'&P<?!R<'*P<O!S<'.
MP<_!T,'1P=+!T\'5P=;!V<':P=O!W,'=P=[!W\'AP>+!X\'EP>;!Y\'IP>K!
MZ\'LP>W![L'OP?+!],'UP?;!]\'XP?G!^L'[P?[!_\$!P@+"`\(%P@;"!\((
MP@G""L(+P@["$,(2PA/"%,(5PA;"%\(:PAO"'<(>PB'"(L(CP@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"3")<(FPB?"*L(L
MPB[",,(SPC7"-L(WPCC".<(ZPCO"/,(]PC["/\)`PD'"0L)#PD3"1<(`````
M``````````!&PD?"2<)*PDO"3,)-PD["3\)2PE/"5<)6PE?"6<):PEO"7,)=
MPE["7\)APF+"8\)DPF;"````````````````9\)HPFG":L)KPF[";\)QPG+"
M<\)UPG;"=\)XPGG">L)[PG["@,*"PH/"A,*%PH;"A\**PHO"C,*-PH["C\*1
MPI+"D\*4PI7"EL*7PIG"FL*<PI["G\*@PJ'"HL*CPJ;"I\*IPJK"J\*NPJ_"
ML,*QPK+"L\*VPKC"NL*[PKS"O<*^PK_"P,+!PL+"P\+$PL7"QL+'PLC"R<+*
MPLO"S,+-PL["S\+0PM'"TL+3PM3"U<+6PM?"V,+9PMK"V\+>PM_"X<+BPN7"
MYL+GPNC"Z<+JPN["\,+RPO/"],+UPO?"^L+]PO["_\(!PP+#`\,$PP7#!L,'
MPPK#"\,.PP_#````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````$,,1PQ+#%L,7PQG#&L,;PQW#'L,?PR##(<,BPR/#)L,GPRK#*\,L
MPRW#+L,OPS##,<,RPP```````````````#/#-,,UPS;#-\,XPSG#.L,[PSS#
M/<,^PS_#0,-!PT+#0\-$PT;#1\-(PTG#2L-+PTS#3<,```````````````!.
MPT_#4,-1PU+#4\-4PU7#5L-7PUC#6<-:PUO#7,-=PU[#7\-@PV'#8L-CPV3#
M9<-FPV?#:L-KPVW#;L-OPW'#<\-TPW7#=L-WPWK#>\-^PW_#@,.!PX+#@\.%
MPX;#A\.)PXK#B\.-PX[#C\.0PY'#DL.3PY3#E<.6PY?#F,.9PYK#F\.<PYW#
MGL.?PZ##H<.BPZ/#I,.EPZ;#I\.HPZG#JL.KPZS#K<.NPZ_#L,.QP[+#L\.T
MP[7#ML.WP[C#N<.ZP[O#O,.]P[[#O\/!P\+#P\/$P\7#QL/'P\C#R</*P\O#
MS,/-P\[#S\/0P]'#TL/3P]3#U</6P]?#VL,`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#;P]W#WL/AP^/#Y,/EP^;#Y\/JP^O#
M[,/NP^_#\,/QP_+#\\/VP_?#^</ZP_O#_,/]P_[#````````````````_\,`
MQ`'$`L0#Q`3$!<0&Q`?$"<0*Q`O$#,0-Q`[$#\01Q!+$$\04Q!7$%L07Q!C$
M&<0:Q````````````````!O$',0=Q![$'\0@Q"'$(L0CQ"7$)L0GQ"C$*<0J
MQ"O$+<0NQ"_$,<0RQ#/$-<0VQ#?$.,0YQ#K$.\0^Q#_$0,1!Q$+$0\1$Q$7$
M1L1'Q$G$2L1+Q$S$3<1.Q$_$4,11Q%+$4\14Q%7$5L17Q%C$6<1:Q%O$7,1=
MQ%[$7\1@Q&'$8L1CQ&;$9\1IQ&K$:\1MQ&[$;\1PQ''$<L1SQ';$=\1XQ'K$
M>\1\Q'W$?L1_Q('$@L2#Q(3$A<2&Q(?$B,2)Q(K$B\2,Q(W$CL2/Q)#$D<22
MQ)/$E<26Q)?$F,29Q)K$F\2=Q)[$G\2@Q*'$HL2CQ*3$I<2FQ*?$J,2IQ```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````*K$J\2L
MQ*W$KL2OQ+#$L<2RQ+/$M,2UQ+;$M\2YQ+K$N\2]Q+[$O\3`Q,'$PL3#Q,3$
MQ<0```````````````#&Q,?$R,3)Q,K$R\3,Q,W$SL3/Q-#$T<32Q-/$U,35
MQ-;$U\38Q-G$VL3;Q-S$W<3>Q-_$````````````````X,3AQ.+$X\3DQ.7$
MYL3GQ.C$ZL3KQ.S$[<3NQ._$\L3SQ/7$]L3WQ/G$^\3\Q/W$_L0"Q0/%!,4%
MQ0;%!\4(Q0G%"L4+Q0W%#L4/Q1'%$L43Q17%%L47Q1C%&<4:Q1O%'<4>Q1_%
M(,4AQ2+%(\4DQ27%)L4GQ2K%*\4MQ2[%+\4QQ3+%,\4TQ37%-L4WQ3K%/,4^
MQ3_%0,5!Q4+%0\5&Q4?%2\5/Q5#%4<52Q5;%6L5;Q5S%7\5BQ6/%9<5FQ6?%
M:<5JQ6O%;,5MQ6[%;\5RQ7;%=\5XQ7G%>L5[Q7[%?\6!Q8+%@\6%Q8;%B,6)
MQ8K%B\6.Q9#%DL63Q93%````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````EL69Q9K%F\6=Q9[%G\6AQ:+%H\6DQ:7%IL6GQ:C%JL6K
MQ:S%K<6NQ:_%L,6QQ;+%L\6VQ0```````````````+?%NL6_Q<#%P<7"Q</%
MR\7-Q<_%TL73Q=7%UL77Q=G%VL7;Q=S%W<7>Q=_%XL7DQ>;%Y\4`````````
M``````#HQ>G%ZL7KQ>_%\<7RQ?/%]<7XQ?G%^L7[Q0+&`\8$Q@G&"L8+Q@W&
M#L8/QA'&$L83QA3&%<86QA?&&L8=QA[&'\8@QB'&(L8CQB;&)\8IQBK&*\8O
MQC'&,L8VQCC&.L8\QCW&/L8_QD+&0\9%QD;&1\9)QDK&2\9,QDW&3L9/QE+&
M5L97QEC&6<9:QEO&7L9?QF'&8L9CQF3&9<9FQF?&:,9IQFK&:\9MQF[&<,9R
MQG/&=,9UQG;&=\9ZQGO&?<9^QG_&@<:"QH/&A,:%QH;&A\:*QHS&CL:/QI#&
MD<:2QI/&EL:7QIG&FL:;QIW&GL:?QJ#&H<:BQJ/&IL8`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"HQJK&J\:LQJW&KL:OQK+&
ML\:UQK;&M\:[QKS&O<:^QK_&PL;$QL;&Q\;(QLG&RL;+QL[&````````````
M````S\;1QM+&T\;5QM;&U\;8QMG&VL;;QM[&W\;BQN/&Y,;EQN;&Y\;JQNO&
M[<;NQN_&\<;RQ@```````````````//&],;UQO;&]\;ZQOO&_,;^QO_&`,<!
MQP+'`\<&QP?'"<<*QPO'#<<.QP_'$,<1QQ+'$\<6QQC'&L<;QQS''<<>QQ_'
M(L<CQR7')L<GQRG'*L<KQRS'+<<NQR_',L<TQS;'.,<YQSK'.\<^QS_'0<="
MQT/'1<=&QT?'2,=)QTO'3L=0QUG'6L=;QUW'7L=?QV''8L=CQV3'9<=FQV?'
M:<=JQVS';<=NQV_'<,=QQW+'<\=VQW?'><=ZQWO'?\>`QX''@L>&QXO'C,>-
MQX_'DL>3QY7'F<>;QYS'G<>>QY_'HL>GQZC'J<>JQZO'KL>OQ[''LL>SQ[7'
MML>WQP``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`+C'N<>ZQ[O'OL?"Q\/'Q,?%Q\;'Q\?*Q\O'S<?/Q]''TL?3Q]3'U<?6Q]?'
MV<?:Q]O'W,<```````````````#>Q]_'X,?AQ^+'X\?EQ^;'Y\?IQ^K'Z\?M
MQ^['[\?PQ_''\L?SQ_3']<?VQ_?'^,?YQ_K'````````````````^\?\Q_W'
M_L?_QP+(`\@%R`;(!\@)R`O(#,@-R`[(#\@2R!3(%\@8R!G(&L@;R![('\@A
MR"+((\@ER";()\@HR"G(*L@KR"[(,,@RR#/(-,@UR#;(-\@YR#K(.\@]R#[(
M/\A!R$+(0\A$R$7(1LA'R$K(2\A.R$_(4,A1R%+(4\A5R%;(5\A8R%G(6LA;
MR%S(7<A>R%_(8,AAR&+(8\ADR&7(9LAGR&C(:<AJR&O(;,AMR&[(;\ARR'/(
M=<AVR'?(><A[R'S(?<A^R'_(@LB$R(C(B<B*R([(C\B0R)'(DLB3R)7(ELB7
MR)C(F<B:R)O(G,B>R*#(HLBCR*3(````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````I<BFR*?(J<BJR*O(K,BMR*[(K\BPR+'(LLBS
MR+3(M<BVR+?(N,BYR+K(N\B^R+_(P,C!R````````````````,+(P\C%R,;(
MQ\C)R,K(R\C-R,[(S\C0R-'(TLC3R-;(V,C:R-O(W,C=R-[(W\CBR./(Y<@`
M``````````````#FR.?(Z,CIR.K(Z\CLR.W([LCOR/#(\<CRR//(],CVR/?(
M^,CYR/K(^\C^R/_(`<D"R0/)!\D(R0G)"LD+R0[)`#`!,`(PMP`E("8@J``#
M,*T`%2`E(CS_/"(8(!D@'"`=(!0P%3`(,`DP"C`+,`PP#3`.,`\P$#`1,+$`
MUP#W`&`B9")E(AXB-"*P`#(@,R`#(2LAX/_A_^7_0B9`)B`BI2(2(P(B!R)A
M(E(BIP`[(`8F!2;+)<\ESB7')<8EH26@);,ELB6]);PEDB&0(9$ADR&4(1,P
M:B)K(AHB/2(=(C4B*R(L(@@B"R*&(H<B@B*#(BHB*2(G(B@BXO\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````0R1+)$\D4R17)
M%LD7R1G)&LD;R1S)'<D>R1_)(,DAR2+)(\DDR27))LDGR2C)*<DJR2O)````
M````````````+<DNR2_),,DQR3+),\DUR3;)-\DXR3G).LD[R3S)/<D^R3_)
M0,E!R4+)0\E$R47)1LE'R0```````````````$C)2<E*R4O)3,E-R4[)3\E2
MR5/)5<E6R5?)6<E:R5O)7,E=R5[)7\EBR63)9<EFR6?):,EIR6K):\EMR6[)
M;\G2(=0A`"(#(K0`7O_'`M@"W0+:`MD"N`#;`J$`OP#0`BXB$2(/(J0`"2$P
M(,$EP"6W);8E9"9@)F$F929G)F,FF2+():,ET"71)9(EI"6E):@EIR6F):DE
M:"8/)@XF'"8>)K8`("`A()4AER&9(98AF"%M)FDF:B9L)G\R'#(6(<<S(B'"
M,]@S(2$`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'')<LESR77)=LEWR7C)><EZR7O)?<E^R7_)@,F!R8+)@\F$R87)
MALF'R8K)B\F-R8[)C\D```````````````"1R9+)D\F4R97)ELF7R9K)G,F>
MR9_)H,FAR:+)H\FDR:7)ILFGR:C)J<FJR:O)K,FMR:[)````````````````
MK\FPR;')LLFSR;3)M<FVR;?)N,FYR;K)N\F\R;W)OLF_R<+)P\G%R<;)R<G+
MR<S)S<G.R<_)TLG4R=?)V,G;R0'_`O\#_P3_!?\&_P?_"/\)_PK_"_\,_PW_
M#O\/_Q#_$?\2_Q/_%/\5_Q;_%_\8_QG_&O\;_QS_'?\>_Q__(/\A_R+_(_\D
M_R7_)O\G_RC_*?\J_RO_+/\M_R[_+_\P_S'_,O\S_S3_-?\V_S?_./\Y_SK_
M.__F_SW_/O\__T#_0?]"_T/_1/]%_T;_1_](_TG_2O]+_TS_3?]._T__4/]1
M_U+_4_]4_U7_5O]7_UC_6?]:_UO_7/]=_^/_````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WLG?R>')X\GER>;)Z,GIR>K)Z\GN
MR?+)\\GTR?7)]LGWR?K)^\G]R?[)_\D!R@+*`\H$R@````````````````7*
M!LH'R@K*#LH/RA#*$<H2RA/*%<H6RA?*&<H:RAO*',H=RA[*'\H@RB'*(LHC
MRB3*)<H````````````````FRB?**,HJRBO*+,HMRB[*+\HPRC'*,LHSRC3*
M-<HVRC?*.,HYRCK*.\H\RCW*/LH_RD#*0<I"RD/*1,I%RD;*,3$R,3,Q-#$U
M,38Q-S$X,3DQ.C$[,3PQ/3$^,3\Q0#%!,4(Q0S%$,44Q1C%',4@Q23%*,4LQ
M3#%-,4XQ3S%0,5$Q4C%3,50Q53%6,5<Q6#%9,5HQ6S%<,5TQ7C%?,6`Q83%B
M,6,Q9#%E,68Q9S%H,6DQ:C%K,6PQ;3%N,6\Q<#%Q,7(Q<S%T,74Q=C%W,7@Q
M>3%Z,7LQ?#%],7XQ?S&`,8$Q@C&#,80QA3&&,8<QB#&),8HQBS&,,8TQCC$`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'RDC*
M2<I*RDO*3LI/RE'*4LI3RE7*5LI7REC*6<I:REO*7LIBRF/*9,IERF;*9\II
MRFK*````````````````:\ILRFW*;LIORG#*<<IRRG/*=,IURG;*=\IXRGG*
M>LI[RGS*?LI_RH#*@<J"RH/*A<J&R@```````````````(?*B,J)RHK*B\J,
MRHW*CLJ/RI#*D<J2RI/*E,J5RI;*E\J9RIK*F\J<RIW*GLJ?RJ#*H<JBRJ/*
MI,JERJ;*I\IP(7$A<B%S(70A=2%V(7<A>"%Y(0````````````!@(6$A8B%C
M(60A92%F(6<A:"%I(0``````````````````D0.2`Y,#E`.5`Y8#EP.8`YD#
MF@.;`YP#G0.>`Y\#H`.A`Z,#I`.E`Z8#IP.H`ZD#````````````````````
M`+$#L@.S`[0#M0.V`[<#N`.Y`[H#NP.\`[T#O@._`\`#P0/#`\0#Q0/&`\<#
MR`/)`P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````*C*J<JJRJO*K,JMRJ[*K\JPRK'*LLJSRK3*M<JVRK?*
MN,JYRKK*N\J^RK_*P<K"RL/*Q<H```````````````#&RL?*R,K)RLK*R\K.
MRM#*TLK4RM7*ULK7RMK*V\K<RMW*WLK?RN'*XLKCRN3*Y<KFRN?*````````
M````````Z,KIRNK*Z\KMRN[*[\KPRO'*\LKSRO7*]LKWROC*^<KZROO*_,K]
MRO[*_\H`RP'+`LL#RP3+!<L&RP?+"<L*RP`E`B4,)1`E&"44)1PE+"4D)30E
M/"4!)0,E#R43)1LE%R4C)3,E*R4[)4LE("4O)2@E-R4_)1TE,"4E)3@E0B42
M)1$E&B49)18E%24.)0TE'B4?)2$E(B4F)2<E*24J)2TE+B4Q)3(E-24V)3DE
M.B4])3XE0"5!)4,E1"5%)48E1R5()4DE2B4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````"\L,RPW+#LL/RQ'+$LL3
MRQ7+%LL7RQG+&LL;RQS+'<L>RQ_+(LLCRR3+)<LFRR?+*,LIRP``````````
M`````"K+*\LLRRW++LLORS#+,<LRRS/+-,LURS;+-\LXRSG+.LL[RSS+/<L^
MRS_+0,M"RT/+1,L```````````````!%RT;+1\M*RTO+3<M.RT_+4<M2RU/+
M5,M5RU;+5\M:RUO+7,M>RU_+8,MARV++8\MERV;+9\MHRVG+:LMKRVS+E3.6
M,Y<S$R&8,\0SHS.D,Z4SIC.9,YHSFS.<,YTSGC.?,Z`SH3.B,\HSC3..,X\S
MSS.(,XDSR#.G,Z@SL#.Q,[(SLS.T,[4SMC.W,[@SN3.`,X$S@C.#,X0SNC.[
M,[PSO3.^,[\SD#.1,Y(SDS.4,R8AP#/!,XHSBS.,,]8SQ3.M,ZXSKS/;,ZDS
MJC.K,ZPSW3/0,],SPS/),]PSQC,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!MRV[+;\MPRW'+<LMSRW3+=<MVRW?+>LM[RWS+?<M^RW_+@,N!RX++@\N$
MRX7+ALN'RXC+````````````````B<N*RXO+C,N-RX[+C\N0RY'+DLN3RY3+
ME<N6RY?+F,N9RYK+F\N=RY[+G\N@RZ'+HLNCRP```````````````*3+I<NF
MRZ?+J,NIRZK+J\NLRZW+KLNOR[#+L<NRR[/+M,NUR[;+M\NYR[K+N\N\R[W+
MOLN_R\#+P<O"R\/+Q,O&`-``J@`F`0``,@$``#\!00'8`%(!N@#>`&8!2@$`
M`&`R83)B,F,R9#)E,F8R9S)H,FDR:C)K,FPR;3)N,F\R<#)Q,G(R<S)T,G4R
M=C)W,G@R>3)Z,GLRT"31)-(DTR34)-4DUB37)-@DV23:)-LDW"3=)-XDWR3@
M).$DXB3C).0DY23F).<DZ"3I)&`D821B)&,D9"1E)&8D9R1H)&DD:B1K)&PD
M;21N)+T`4R%4(;P`O@!;(5PA72%>(0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````,7+QLO'R\C+R<O*R\O+S,O-R\[+S\O0R]'+
MTLO3R]7+ULO7R]C+V<O:R]O+W,O=R][+W\L```````````````#@R^'+XLOC
MR^7+YLOHR^K+Z\OLR^W+[LOOR_#+\<ORR_/+],OUR_;+]\OXR_G+^LO[R_S+
M````````````````_<O^R__+`,P!S`+,`\P$S`7,!LP'S`C,"<P*S`O,#LP/
MS!',$LP3S!7,%LP7S!C,&<P:S!O,'LP?S"#,(\PDS.8`$0'P`"<!,0$S`3@!
M0`%"`?@`4P'?`/X`9P%+`4D!`#(!,@(R`S($,@4R!C(',@@R"3(*,@LR##(-
M,@XR#S(0,A$R$C(3,A0R%3(6,A<R&#(9,AHR&S*<))TDGB2?)*`DH22B)*,D
MI"2E)*8DIR2H)*DDJB2K)*PDK22N)*\DL"2Q)+(DLR2T)+4D="1U)'8D=R1X
M)'DD>B1[)'PD?21^)'\D@"2!)((DN0"R`+,`="!_(($@@B"#((0@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````)<PFS"K,*\PM
MS"_,,<PRS#/,-,PUS#;,-\PZS#_,0,Q!S$+,0\Q&S$?,2<Q*S$O,3<Q.S```
M`````````````$_,4,Q1S%+,4\Q6S%K,6\Q<S%W,7LQ?S&',8LQCS&7,9\QI
MS&K,:\QLS&W,;LQOS'',<LP```````````````!SS'3,=LQWS'C,><QZS'O,
M?,Q]S'[,?\R`S(',@LR#S(3,A<R&S(?,B,R)S(K,B\R,S(W,CLR/S)#,D<R2
MS)/,03!",$,P1#!%,$8P1S!(,$DP2C!+,$PP33!.,$\P4#!1,%(P4S!4,%4P
M5C!7,%@P63!:,%LP7#!=,%XP7S!@,&$P8C!C,&0P93!F,&<P:#!I,&HP:S!L
M,&TP;C!O,'`P<3!R,',P=#!U,'8P=S!X,'DP>C![,'PP?3!^,'\P@#"!,((P
M@S"$,(4PAC"',(@PB3"*,(LPC#"-,(XPCS"0,)$PDC"3,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"4S)7,ELR7S)K,F\R=S)[,G\RAS*+,H\RDS*7,ILRGS*K,KLRO
MS+#,L<RRS+/,MLRWS+G,````````````````NLR[S+W,OLR_S,#,P<S"S,/,
MQLS(S,K,R\S,S,W,SLS/S-',TLS3S-7,ULS7S-C,V<S:S```````````````
M`-O,W,S=S-[,W\S@S.',XLSCS.7,YLSGS.C,Z<SJS.O,[<SNS._,\<SRS//,
M],SUS/;,]\SXS/G,^LS[S/S,_<RA,*(PHS"D,*4PIC"G,*@PJ3"J,*LPK#"M
M,*XPKS"P,+$PLC"S,+0PM3"V,+<PN#"Y,+HPNS"\,+TPOC"_,,`PP3#",,,P
MQ##%,,8PQS#(,,DPRC#+,,PPS3#.,,\PT##1,-(PTS#4,-4PUC#7,-@PV3#:
M,-LPW##=,-XPWS#@,.$PXC#C,.0PY3#F,.<PZ##I,.HPZS#L,.TP[C#O,/`P
M\3#R,/,P]##U,/8P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/[,_\P`S0+-`\T$S07-!LT'S0K-
M"\T-S0[-#\T1S1+-$\T4S17-%LT7S1K-',T>S1_-(,T````````````````A
MS2+-(\TES2;-)\TIS2K-*\TMS2[-+\TPS3'-,LTSS33--<TVS3?-.,TZS3O-
M/,T]S3[-````````````````/\U`S4'-0LU#S43-1<U&S4?-2,U)S4K-2\U,
MS4W-3LU/S5#-4<U2S5/-5,U5S5;-5\U8S5G-6LU;S5W-7LU?S1`$$002!!,$
M%`05!`$$%@07!!@$&00:!!L$'`0=!!X$'P0@!"$$(@0C!"0$)00F!"<$*`0I
M!"H$*P0L!"T$+@0O!````````````````````````````````````````#`$
M,00R!#,$-`0U!%$$-@0W!#@$.00Z!#L$/`0]!#X$/P1`!$$$0@1#!$0$101&
M!$<$2`1)!$H$2P1,!$T$3@1/!```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````8<UB
MS6/-9<UFS6?-:,UIS6K-:\UNS7#-<LUSS73-=<UVS7?-><UZS7O-?,U]S7[-
M?\V`S0```````````````('-@LV#S83-A<V&S8?-B<V*S8O-C,V-S8[-C\V0
MS9'-DLV3S9;-E\V9S9K-F\V=S9[-G\T```````````````"@S:'-HLVCS:;-
MJ,VJS:O-K,VMS:[-K\VQS;+-L\VTS;7-MLVWS;C-N<VZS;O-O,V]S;[-O\W`
MS<'-PLW#S<7-````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#&S<?-R,W)S<K-R\W-S<[-S\W1S=+-T\W4S=7-ULW7
MS=C-V<W:S=O-W,W=S=[-W\W@S>'-````````````````XLWCS>3-Y<WFS>?-
MZ<WJS>O-[<WNS>_-\<WRS?/-],WUS?;-]\WZS?S-_LW_S0#.`<X"S@``````
M``````````/.!<X&S@?."<X*S@O.#<X.S@_.$,X1SA+.$\X5SA;.%\X8SAK.
M&\X<SAW.'LX?SB+.(\XESB;.)\XISBK.*\X`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"S.+<XNSB_.,LXTSC;.
M-\XXSCG..LX[SCS./<X^SC_.0,Y!SD+.0\Y$SD7.1LY'SDC.2<X`````````
M``````!*SDO.3,Y-SD[.3\Y0SE'.4LY3SE3.5<Y6SE?.6LY;SEW.7LYBSF/.
M9,YESF;.9\YJSFS.````````````````;LYOSG#.<<YRSG/.=LYWSGG.>LY[
MSGW.?LY_SH#.@<Z"SH/.ALZ(SHK.B\Z,SHW.CLZ/SI+.D\Z5SI;.E\Z9S@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````FLZ;SIS.G<Z>SI_.HLZFSJ?.J,ZISJK.J\ZNSJ_.L,ZQSK+.L\ZTSK7.
MMLZWSKC.N<ZZS@```````````````+O.O,Z]SK[.O\[`SL+.P\[$SL7.QL['
MSLC.R<[*SLO.S,[-SL[.S\[0SM'.TL[3SM3.U<X```````````````#6SM?.
MV,[9SMK.V\[<SMW.WL[?SN#.X<[BSN/.YL[GSNG.ZL[MSN[.[\[PSO'.\L[S
MSO;.^L[[SOS._<[^SO_.`*P!K`2L!ZP(K`FL"JP0K!&L$JP3K!2L%:P6K!>L
M&:P:K!NL'*P=K""L)*PLK"VL+ZPPK#&L.*PYK#RL0*Q+K$VL5*Q8K%RL<*QQ
MK'2L=ZQXK'JL@*R!K(.LA*R%K(:LB:R*K(NLC*R0K)2LG*R=K)^LH*RAK*BL
MJ:RJK*RLKZRPK+BLN:R[K+RLO:S!K,2LR*S,K-6LUZS@K.&LY*SGK.BLZJSL
MK.^L\*SQK/.L]:SVK/RL_:P`K02M!JT`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````"SP//!<\&SP?/"<\*SPO/#,\-SP[/#\\2
MSQ3/%L\7SQC/&<\:SQO/'<\>SQ_/(<\BSR//````````````````)<\FSR?/
M*,\ISRK/*\\NSS+/,\\TSS7/-L\WSSG/.L\[SSS//<\^SS_/0,]!ST+/0\]$
MSP```````````````$7/1L]'STC/2<]*STO/3,]-ST[/3\]0SU'/4L]3SU;/
M5\]9SUK/6\]=SU[/7\]@SV'/8L]CSV;/:,]JSVO/;,\,K0VM#ZT1K1BM'*T@
MK2FM+*TMK32M-:TXK3RM1*U%K4>M2:U0K52M6*UAK6.M;*UMK7"M<ZUTK76M
M=JU[K7RM?:U_K8&M@JV(K8FMC*V0K9RMG:VDK;>MP*W!K<2MR*W0K=&MTZW<
MK>"MY*WXK?FM_*W_K0"N`:X(K@FN"ZX-KA2N,*XQKC2N-ZXXKCJN0*Y!KD.N
M1:Y&KDJN3*Y-KDZN4*Y4KE:N7*Y=KE^N8*YAKF6N:*YIKFRN<*YXK@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````&W/;L]OSW+/
M<\]USW;/=\]YSWK/>\]\SWW/?L]_SX'/@L^#SX3/AL^'SXC/B<^*SXO/C<\`
M``````````````".SX_/D,^1SY+/D\^4SY7/EL^7SYC/F<^:SYO/G,^=SY[/
MG\^@SZ+/H\^DSZ7/IL^GSZG/````````````````JL^KSZS/K<^NSZ_/L<^R
MS[//M,^US[;/M\^XS[G/NL^[S[S/O<^^S[_/P,_!S\+/P\_%S\;/Q\_(S\G/
MRL_+SWFN>ZY\KGVNA*Z%KHRNO*Z]KKZNP*[$KLRNS:[/KM"NT:[8KMFNW*[H
MKNNN[:[TKOBN_*X'KPBO#:\0KRRO+:\PKS*O-*\\KSVO/Z]!KT*O0Z](KTFO
M4*]<KUVO9*]EKWFO@*^$KXBOD*^1KY6OG*^XK[FOO*_`K\>OR*_)K\NOS:_.
MK]2OW*_HK^FO\*_QK_2O^*\`L`&P!+`,L!"P%+`<L!VP*+!$L$6P2+!*L$RP
M3K!3L%2P5;!7L%FP````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````S,_-S\[/S\_0S]'/TL_3S]3/U<_6S]?/V,_9S]K/V\_<S]W/
MWL_?S^+/X\_ES^;/Y\_ISP```````````````.K/Z\_LS^W/[L_OS_+/],_V
MS_?/^,_YS_K/^\_]S_[/_\\!T`+0`]`%T`;0!]`(T`G0"M``````````````
M```+T`S0#=`.T`_0$-`2T!/0%-`5T!;0%]`9T!K0&]`<T!W0'M`?T"#0(=`B
MT"/0)-`ET";0)]`HT"G0*M`KT"S07;!\L'VP@+"$L(RPC;"/L)&PF+"9L)JP
MG+"?L*"PH;"BL*BPJ;"KL*RPK;"NL*^PL;"SL+2PM;"XL+RPQ+#%L,>PR+#)
ML-"PT;#4L-BPX+#EL`BQ";$+L0RQ$+$2L1.Q&+$9L1NQ'+$=L2.Q)+$EL2BQ
M++$TL36Q-[$XL3FQ0+%!L42Q2+%0L5&Q5+%5L5BQ7+%@L7BQ>;%\L8"Q@K&(
ML8FQB[&-L9*QD[&4L9BQG+&HL<RQT+'4L=RQW;$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````NT"_0,-`QT#+0,]`VT#?0.=`Z
MT#O0/=`^T#_00-!!T$+00]!&T$C02M!+T$S03=!.T$_0````````````````
M4=!2T%/05=!6T%?06=!:T%O07-!=T%[07]!AT&+08]!DT&709M!GT&C0:=!J
MT&O0;M!OT````````````````''0<M!ST'70=M!WT'C0>=!ZT'O0?M!_T(#0
M@M"#T(30A="&T(?0B-")T(K0B]",T(W0CM"/T)#0D="2T)/0E-#?L>BQZ;'L
ML?"Q^;'[L?VQ!+(%L@BR"[(,LA2R%;(7LAFR(+(TLCRR6+)<LF"R:+)ILG2R
M=;)\LH2RA;*)LI"RD;*4LIBRF;*:LJ"RH;*CLJ6RIK*JLJRRL+*TLLBRR;+,
MLM"RTK+8LMFRV[+=LN*RY++ELN:RZ++KLNRR[;+NLN^R\[+TLO6R][+XLOFR
M^K+[LO^R`+,!LP2S"+,0LQ&S$[,4LQ6S'+-4LU6S5K-8LUNS7+->LU^S9+-E
MLP``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````)70
MEM"7T)C0F=":T)O0G-"=T)[0G]"@T*'0HM"CT*;0I]"IT*K0J]"MT*[0K]"P
MT+'0LM````````````````"ST+;0N-"ZT+O0O-"]T+[0O]#"T,/0Q=#&T,?0
MRM#+T,S0S=#.T,_0TM#6T-?0V-#9T-K0````````````````V]#>T-_0X=#B
MT./0Y=#FT.?0Z-#IT.K0Z]#NT/+0\]#TT/70]M#WT/G0^M#[T/S0_=#^T/_0
M`-$!T0+1`]$$T6>S:;-KLVZS<+-QLW2S>+.`LX&S@[.$LX6SC+.0LY2SH+.A
MLZBSK+/$L\6SR+/+L\RSSK/0L]2SU;/7L]FSV[/=L^"SY+/HL_RS$+08M!RT
M(+0HM"FT*[0TM%"T4;14M%BT8+1AM&.T9;1LM("TB+2=M*2TJ+2LM+6TM[2Y
MM,"TQ+3(M-"TU;3<M-VTX+3CM.2TYK3LM.VT[[3QM/BT%+45M1BU&[4<M22U
M);4GM2BU*;4JM3"U,;4TM3BU````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````!=$&T0?1"-$)T0K1"]$,T0[1#]$0T1'1$M$3T131
M%=$6T1?1&-$9T1K1&]$<T1W1'M$?T0```````````````"#1(=$BT2/1)-$E
MT2;1)]$HT2G1*M$KT2S1+=$NT2_1,M$ST371-M$WT3G1.]$\T3W1/M$`````
M```````````_T4+11M%'T4C12=%*T4O13M%/T5'14M%3T5715M%7T5C16=%:
MT5O17M%@T6+18]%DT6719M%GT6G1:M%KT6W10+5!M4.U1+5%M4NU3+5-M5"U
M5+5<M5VU7[5@M6&UH+6AM:2UJ+6JM:NUL+6QM;.UM+6UM;NUO+6]M<"UQ+7,
MM<VUS[70M=&UV+7LM1"V$;84MABV);8LMC2V2+9DMFBVG+:=MJ"VI+:KMJRV
ML;;4MO"V]+;XM@"W`;<%MRBW*;<LMR^W,+<XMSFW.[=$MTBW3+=4MU6W8+=D
MMVBW<+=QMW.W=;=\MWVW@+>$MXRWC;>/MY"WD;>2MY:WE[<`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!NT6_1<-%QT7+1<]%T
MT771=M%WT7C1>=%ZT7O1?=%^T7_1@-&!T8+1@]&%T8;1A]&)T8K1````````
M````````B]&,T8W1CM&/T9#1D=&2T9/1E-&5T9;1E]&8T9G1FM&;T9S1G=&>
MT9_1HM&CT:71IM&GT0```````````````*G1JM&KT:S1K=&NT:_1LM&TT;;1
MM]&XT;G1N]&]T;[1O]'!T<+1P]'$T<71QM''T<C1R='*T<O1S-'-T<[1S]&8
MMYFWG+>@MZBWJ;>KMZRWK;>TM[6WN+?'M\FW[+?MM_"W]+?\M_VW_[<`N`&X
M![@(N`FX#+@0N!BX&;@;N!VX)+@EN"BX++@TN#6X-[@XN#FX0+A$N%&X4[A<
MN%VX8+ADN&RX;;AON'&X>+A\N(VXJ+BPN+2XN+C`N,&XP[C%N,RXT+C4N-VX
MW[CAN.BXZ;CLN/"X^+CYN/NX_;@$N1BY(+D\N3VY0+E$N4RY3[E1N5BY6;E<
MN6"Y:+EIN0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-#1T='2T=/1U-'5T=;1U]'9T=K1V]'<T=W1WM'?T>#1X='BT>/1Y-'E
MT>;1Y]'HT>G1ZM$```````````````#KT>S1[='NT>_1\-'QT?+1\]'UT?;1
M]]'YT?K1^]'\T?W1_M'_T0#2`=("T@/2!-(%T@;2````````````````"-(*
MT@O2#-(-T@[2#](1TA+2$](4TA72%M(7TAC2&=(:TAO2'-(=TA[2'](@TB'2
M(M(CTB32)=(FTB?2*-(ITFNY;;ETN76Y>+E\N82YA;F'N8FYBKF-N8ZYK+FM
MN;"YM+F\N;VYO[G!N<BYR;G,N<ZYS[G0N=&YTKG8N=FYV[G=N=ZYX;GCN>2Y
MY;GHN>RY]+GUN?>Y^+GYN?JY`+H!N@BZ%;HXNCFZ/+I`ND*Z2+I)NDNZ3;I.
MNE.Z5+I5NEBZ7+IDNF6Z9[IHNFFZ<+IQNG2Z>+J#NH2ZA;J'NHRZJ+JINJNZ
MK+JPNK*ZN+JYNKNZO;K$NLBZV+K9NORZ````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````*M(KTB[2+](QTC+2,](UTC;2-](XTCG2
M.M([TC[20-)"TD/21-)%TD;21]))TDK22]),T@```````````````$W23M)/
MTE#24=)2TE/25-)5TE;25])8TEG26M);TEW27M)?TF#28=)BTF/29=)FTF?2
M:-(```````````````!ITFK2:])LTFW2;M)OTG#2<=)RTG/2=-)UTG;2=])X
MTGG2>M)[TGS2?=)^TG_2@M*#TH72AM*'THG2BM*+THS2`+L$NPV[#[L1NQB[
M'+L@NRF[*[LTNS6[-KLXNSN[/+L]NSZ[1+M%NT>[2;M-NT^[4+M4NUB[8;MC
MNVR[B+N,NY"[I+NHNZR[M+NWN\"[Q+O(N]"[T[OXN_F[_+O_NP"\`KP(O`F\
M"[P,O`V\#[P1O!2\%;P6O!>\&+P;O!R\';P>O!^\)+PEO">\*;PMO#"\,;PT
MO#B\0+Q!O$.\1+Q%O$F\3+Q-O%"\7;R$O(6\B+R+O(R\CKR4O)6\E[P`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"-TH[2C]*2
MTI/2E-*6TI?2F-*9TIK2F]*=TI[2G]*ATJ+2H]*ETJ;2I]*HTJG2JM*KTJW2
M````````````````KM*OTK#2LM*STK32M=*VTK?2NM*[TKW2OM+!TL/2Q-+%
MTL;2Q]+*TLS2S=+.TL_2T-+1T@```````````````-+2T]+5TM;2U]+9TMK2
MV]+=TM[2W]+@TN'2XM+CTN;2Y]+HTNG2ZM+KTNS2[=+NTN_2\M+STO72]M+W
MTOG2^M*9O)J\H+RAO*2\I[RHO+"\L;RSO+2\M;R\O+V\P+S$O,V\S[S0O-&\
MU;S8O-R\]+SUO/:\^+S\O`2]!;T'O0F]$+T4O22]++U`O4B]2;U,O5"]6+U9
MO62]:+V`O8&]A+V'O8B]B;V*O9"]D;V3O96]F;V:O9R]I+VPO;B]U+W5O=B]
MW+WIO?"]]+WXO0"^`[X%O@R^#;X0OA2^'+X=OA^^1+Y%ODB^3+Y.OE2^5;Y7
MOEF^6KY;OF"^8;YDO@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/O2_-+]TO[2_]("TP33!M,'TPC3"=,*TPO3#],1TQ+3$],5
MTQ?3&-,9TQK3&],>TR+3(],````````````````DTR;3)],JTRO3+=,NTR_3
M,=,RTS/3--,UTS;3-],ZTS[3/]-`TT'30M-#TT;31]-(TTG3````````````
M````2M-+TTS33=-.TT_34--1TU+34]-4TU735M-7TUC36=-:TUO37--=TU[3
M7]-@TV'38M-CTV339=-FTV?3:--ITVB^:KYPOG&^<[YTOG6^>[Y\OGV^@+Z$
MOHR^C;Z/OI"^D;Z8OIF^J+[0OM&^U+[7OMB^X+[CON2^Y;[LO@&_"+\)OQB_
M&;\;OQR_';]`OT&_1+](OU"_4;]5OY2_L+_%O\R_S;_0O]2_W+_?O^&_/,!1
MP%C`7,!@P&C`:<"0P)'`E,"8P*#`H<"CP*7`K,"MP*_`L,"SP+3`M<"VP+S`
MO<"_P,#`P<#%P,C`R<#,P-#`V,#9P-O`W,#=P.3`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````:M-KTVS3;=-NTV_3<--QTW+3
M<]-TTW73=M-WTWC3>=-ZTWO3?M-_TX'3@M.#TX73AM.'TP``````````````
M`(C3B=.*TXO3CM.2TY/3E-.5TY;3E].:TYO3G=.>TY_3H=.BTZ/3I-.ETZ;3
MI].JTZS3KM,```````````````"OT[#3L=.RT[/3M=.VT[?3N=.ZT[O3O=.^
MT[_3P-/!T\+3P]/&T\?3RM/+T\S3S=/.T\_3T=/2T]/3U-/5T];3Y<#HP.S`
M],#UP/?`^<``P03!",$0P17!',$=P1[!'\$@P2/!),$FP2?!+,$MP2_!,,$Q
MP3;!.,$YP3S!0,%(P4G!2\%,P4W!5,%5P5C!7,%DP67!9\%HP6G!<,%TP7C!
MA<&,P8W!CL&0P93!EL&<P9W!G\&AP:7!J,&IP:S!L,&]P<3!R,',P=3!U\'8
MP>#!Y,'HP?#!\<'SP?S!_<$`P@3"#,(-P@_"$<(8PAG"',(?PB#"*,(IPBO"
M+<(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#7
MT]G3VM/;T]S3W=/>T]_3X-/BT^33Y=/FT^?3Z-/IT^K3Z]/NT^_3\=/RT_/3
M]=/VT_?3````````````````^-/YT_K3^]/^TP#4`M0#U`34!=0&U`?4"=0*
MU`O4#-0-U`[4#]00U!'4$M03U!34%=06U````````````````!?4&-09U!K4
M&]0<U![4']0@U"'4(M0CU"34)=0FU"?4*-0IU"K4*]0LU"W4+M0OU##4,=0R
MU#/4--0UU#;4-]0OPC'",L(TPDC"4,)1PE3"6,)@PF7";,)MPG#"=,)\PGW"
M?\*!PHC"B<*0PIC"F\*=PJ3"I<*HPJS"K<*TPK7"M\*YPMS"W<+@PN/"Y,+K
MPNS"[<+OPO'"]L+XPOG"^\+\P@##",,)PPS##<,3PQ3#%<,8PQS#),,EPRC#
M*<-%PVC#:<-LPW##<L-XPWG#?,-]PX3#B,.,P\##V,/9P]S#W\/@P^+#Z,/I
MP^W#],/UP_C#",00Q"3$+,0PQ```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#C4.=0ZU#O4/-0]U#[4/]1!U$+40]1%U$;41]1(
MU$G42M1+U$S43=1.U$_44-11U%+44]0```````````````!4U%745M17U%C4
M6=1:U%O47=1>U%_48=1BU&/49=1FU&?4:-1IU&K4:]1LU&[4<-1QU'+4````
M````````````<]1TU'74=M1WU'K4>]1]U'[4@=2#U(34A=2&U(?4BM2,U([4
MC]20U)'4DM23U)74EM27U)C4F=2:U)O4G-2=U#3$/,0]Q$C$9,1EQ&C$;,1T
MQ'7$><2`Q)3$G,2XQ+S$Z<3PQ/'$],3XQ/K$_\0`Q0'%#,40Q13%',4HQ2G%
M+,4PQ3C%.<4[Q3W%1,5%Q4C%2<5*Q4S%3<5.Q5/%5,55Q5?%6,59Q5W%7L5@
MQ6'%9,5HQ7#%<<5SQ73%=<5\Q7W%@,6$Q8?%C,6-Q8_%D<65Q9?%F,6<Q:#%
MJ<6TQ;7%N,6YQ;O%O,6]Q;[%Q,7%Q<;%Q\7(Q<G%RL7,Q<[%````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````GM2?U*#4H=2BU*/4
MI-2EU*;4I]2HU*K4J]2LU*W4KM2OU+#4L=2RU+/4M-2UU+;4M]2XU```````
M`````````+G4NM2[U+S4O=2^U+_4P-3!U,+4P]3$U,74QM3'U,C4R=3*U,O4
MS=3.U,_4T=32U-/4U=0```````````````#6U-?4V-39U-K4V]3=U-[4X-3A
MU.+4X]3DU.74YM3GU.G4ZM3KU.W4[M3OU/'4\M3SU/34]=3VU/?4^=3ZU/S4
MT,71Q=3%V,7@Q>'%X\7EQ>S%[<7NQ?#%],7VQ??%_,7]Q?[%_\4`Q@'&!<8&
MQ@?&",8,QA#&&,89QAO&',8DQB7&*,8LQBW&+L8PQC/&-,8UQC?&.<8[QD#&
M0<9$QDC&4,91QE/&5,95QES&7<9@QFS&;\9QQGC&><9\QH#&B,:)QHO&C<:4
MQI7&F,:<QJ3&I<:GQJG&L,:QQK3&N,:YQKK&P,;!QL/&Q<;,QLW&T,;4QMS&
MW<;@QN'&Z,8`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#^U/_4`-4!U0+5`]4%U0;5!]4)U0K5"]4-U0[5#]40U1'5$M43U1;5
M&-49U1K5&]4<U1W5````````````````'M4?U2#5(=4BU2/5)-4EU2;5)]4H
MU2G5*M4KU2S5+=4NU2_5,-4QU3+5,]4TU375-M4WU0```````````````#C5
M.=4ZU3O5/M4_U4'50M5#U4751M5'U4C52=5*U4O53M50U5+54]54U5755M57
MU5K56]5=U5[57]5AU6+58]7IQNS&\,;XQOG&_<8$QP7'",<,QQ3'%<<7QQG'
M(,<AQR3'*,<PQS'',\<UQS?'/,<]QT#'1,=*QTS'3<=/QU''4L=3QU3'5<=6
MQU?'6,=<QV#':,=KQW3'=<=XQWS'?<=^QX/'A,>%QX?'B,>)QXK'CL>0QY''
ME,>6QY?'F,>:QZ#'H<>CQZ3'I<>FQZS'K<>PQ[3'O,>]Q[_'P,?!Q\C'R<?,
MQ\['T,?8Q]W'Y,?HQ^S'`,@!R`3(",@*R```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````&359M5GU6K5;-5NU6_5<-5QU7+5<]5V
MU7?5>=5ZU7O5?=5^U7_5@-6!U8+5@]6&U8K5B]4```````````````",U8W5
MCM6/U9'5DM63U935E=66U9?5F-69U9K5F]6<U9W5GM6?U:#5H=6BU:/5I-6F
MU:?5````````````````J-6IU:K5J]6LU:W5KM6OU;#5L=6RU;/5M-6UU;;5
MM]6XU;G5NM6[U;S5O=6^U;_5P-7!U<+5P]7$U<75QM7'U1#($<@3R!7(%L@<
MR!W((,@DR"S(+<@OR#'(.,@\R$#(2,A)R$S(3<A4R'#(<<ATR'C(>LB`R('(
M@\B%R(;(A\B+R(S(C<B4R)W(G\BAR*C(O,B]R,3(R,C,R-3(U<C7R-G(X,CA
MR.3(]<C\R/W(`,D$R07)!LD,R0W)#\D1R1C)+,DTR5#)4<E4R5C)8,EAR6/)
M;,EPR73)?,F(R8G)C,F0R9C)F<F;R9W)P,G!R<3)Q\G(R<K)T,G1R=/)````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````RM7+U<W5
MSM7/U='5T]74U=75UM77U=K5W-7>U=_5X-7AU>+5X]7FU>?5Z=7JU>O5[=7N
MU0```````````````._5\-7QU?+5\]7VU?C5^M7[U?S5_=7^U?_5`M8#U@76
M!M8'U@G6"M8+U@S6#=8.U@_6$M8````````````````6UA?6&-89UAK6&]8=
MUA[6']8AUB+6(]8EUB;6)]8HUBG6*M8KUBS6+M8OUC#6,=8RUC/6--8UUC;6
M-]8ZUCO6U<G6R=G)VLG<R=W)X,GBR>3)Y\GLR>W)[\GPR?')^,GYR?S)`,H(
MR@G*"\H,R@W*%,H8RBG*3,I-RE#*5,I<REW*7\I@RF'*:,I]RH3*F,J\RKW*
MP,K$RLS*S<K/RM'*T\K8RMG*X,KLRO3*",L0RQ3+&,L@RR'+0<M(RTG+3,M0
MRUC+6<M=RV3+>,MYRYS+N,O4R^3+Y\OIRPS,#<P0S!3,',P=S"',(LPGS"C,
M*<PLS"[,,,PXS#G,.\P`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````]UC[6/]9!UD+60]9$UD;61]9*UDS63M9/UE#64M93UE;6
M5]99UEK66]9=UE[67]9@UF'6````````````````8M9CUF369=9FUFC6:M9K
MUFS6;=9NUF_6<M9SUG76=M9WUGC6>=9ZUGO6?-9]UG[6?]:`U@``````````
M`````('6@M:$UH;6A]:(UHG6BM:+UH[6C]:1UI+6D]:5UI;6E]:8UIG6FM:;
MUIS6GM:@UJ+6H]:DUJ76IM:GUJG6JM8\S#W,/LQ$S$7,2,Q,S%3,5<Q7S%C,
M6<Q@S&3,9LQHS'#,=<R8S)G,G,R@S*C,J<RKS*S,K<RTS+7,N,R\S,3,Q<S'
MS,G,T,S4S.3,[,SPS`'-",T)S0S-$,T8S1G-&\T=S23-*,TLS3G-7,U@S63-
M;,UMS6_-<<UXS8C-E,V5S9C-G,VDS:7-I\VIS;#-Q,W,S=#-Z,WLS?#-^,WY
MS?O-_<T$S@C.#,X4SAG.(,XASB3.*,XPSC'.,\XUS@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````*O6K=:NUJ_6L=:RUK/6M-:U
MUK;6M]:XUKK6O-:]UK[6O];`UL'6PM;#UL;6Q];)ULK6R]8`````````````
M``#-UL[6S];0UM+6T];5UM;6V-;:UMO6W-;=UM[6W];AUN+6X];EUN;6Y];I
MUNK6Z];LUNW6````````````````[M;OUO'6\M;SUO36]M;WUOC6^=;ZUOO6
M_M;_U@'7`M<#UP77!M<'UPC7"=<*UPO7#-<-UP[7#]<0UQ+7$]<4UUC.6<Y<
MSE_.8,YASFC.:<YKSFW.=,YUSGC.?,Z$SH7.A\Z)SI#.D<Z4SIC.H,ZASJ/.
MI,ZESJS.K<[!SN3.Y<[HSNO.[,[TSO7.]\[XSOG.`,\!SP3/",\0SQ'/$\\5
MSQS/(,\DSRS/+<\OSS#/,<\XSU3/5<]8SUS/9,]ESV?/:<]PSW'/=,]XSX#/
MA<^,SZ'/J,^PS\3/X,_AS^3/Z,_PS_'/\\_US_S/`-`$T!'0&-`MT#30-=`X
MT#S0````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M%=<6UQ?7&M<;UQW7'M<?UR'7(M<CUR37)=<FUR?7*M<LUR[7+]<PUS'7,M<S
MUS;7-]<YUP```````````````#K7.]<]US[7/]=`UT'70M=#UT771M=(UTK7
M2]=,UTW73M=/UU+74]=5UUK76]=<UUW77M<```````````````!?UV+79-=F
MUV?7:-=JUVO7;==NUV_7<==RUW/7===VUW?7>-=YUWK7>]=^UW_7@->"UX/7
MA->%UX;7A]>*UXO71-!%T$?02=!0T%306-!@T&S0;=!PT'30?-!]T('0I-"E
MT*C0K-"TT+70M]"YT,#0P=#$T,C0R=#0T-'0T]#4T-70W-#=T.#0Y-#LT.W0
M[]#PT/'0^-`-T3#1,=$TT3C1.M%`T4'10]%$T4713-%-T5#15-%<T5W17]%A
MT6C1;-%\T831B-&@T:'1I-&HT;#1L=&ST;71NM&\T<#1V-'TT?C1!]()TA#2
M+-(MTC#2--(\TCW2/])!TDC27-(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"-UX[7C]>1UY+7D]>4UY77EM>7UYK7G->>UY_7
MH->AUZ+7H]<`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!DTH#2@=*$THC2D-*1TI72
MG-*@TJ32K-*QTKC2N=*\TK_2P-+"TLC2R=++TM32V-+<TN32Y=+PTO'2]-+X
MT@#3`=,#TP73#-,-TP[3$-,4TQ;3'-,=TQ_3(-,ATR73*-,ITRS3,-,XTSG3
M.],\TSW31--%TWS3?=.`TX33C-.-TX_3D-.1TYC3F=.<TZ#3J-.ITZO3K=.T
MT[C3O-/$T\73R-/)T]#3V-/AT^/3[-/MT_#3]-/\T_W3_],!U```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``C4'=1`U$347-1@U&34;=1OU'C4>=1\U'_4@-2"U(C4B=2+U(W4E-2IU,S4
MT-34U-S4W]3HU.S4\-3XU/O4_=0$U0C5#-44U175%]4\U3W50-5$U4S53=5/
MU5'56-59U5S58-5EU6C5:=5KU6W5=-5UU7C5?-6$U875A]6(U8G5D-6EU<C5
MR=7,U=#5TM78U=G5V]7=U>35Y=7HU>S5]-7UU??5^=4`U@'6!-8(UA#6$=83
MUA36%=8<UB#6````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````)-8MUCC6.=8\UD#61=9(UDG62]9-UE'65-95
MUEC67-9GUFG6<-9QUG36@]:%UHS6C=:0UI36G=:?UJ'6J-:LUK#6N=:[UL36
MQ=;(ULS6T=;4UM?6V=;@UN36Z-;PUO76_-;]U@#7!-<1UQC7&=<<UR#7*-<I
MURO7+=<TUS77.-<\UT371]=)UU#74==4UU;75]=8UUG78-=AUV/79==IUVS7
M<-=TUWS7?=>!UXC7B=>,UY#7F->9UYO7G=<`````(@``````````````000`
M`,T8&0C4&!D(]/H8"`````"`]!P(@/,<"(#R'`B`\1P(``````````"`[QP(
M`.T<"````````````@````$````!`````````,!H&0C`[!P(`````,B3!P@H
ME@<(;)8'"-R7!PAL<P<(O&@'")!V!PC8:0<(````````````````````````
M````````````````_0"`[AP(`@%^`0#N'`@3(*P@8.T<",<"W0(Q[1P((B$B
M(3#M'`@``````````)FA`````````````````````*+_`+(`O0``````````
M`````````````````````):7````D9*"`).4A`"&AY4```"%````````````
MB0``````````BYL`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(````````##XZ6Y
MQN8`````R.C/[]#P````````RNK,[```````````````````````````````
M````````Q>4``+R^``"CL]'Q``#2\@````````#5]0``P.```-CXC)P``*JZ
MBIK>_HV=``````````#9^=O[`````````(^?K[^.G@`````!`@,$!08'"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W
M.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A8F-D
M969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_````````````````````````
M``````````````````"@````I`"FIZBI`*NLK:X`L+$``+2UMK>X``"[````
M``#!P@#$``#'`,D`RP#-S@````#3U`#6UP``V@#<W0#?`.'B`.0``.<`Z0#K
M`.WN`````//T`/;W``#Z`/S]``````$``@`#``0`!0`&``<`"``)``H`"P`,
M``T`#@`/`!``$0`2`!,`%``5`!8`%P`8`!D`&@`;`!P`'0`>`!\`(``A`"(`
M(P`D`"4`)@`G`"@`*0`J`"L`+``M`"X`+P`P`#$`,@`S`#0`-0`V`#<`.``Y
M`#H`.P`\`#T`/@`_`$``00!"`$,`1`!%`$8`1P!(`$D`2@!+`$P`30!.`$\`
M4`!1`%(`4P!4`%4`5@!7`%@`60!:`%L`7`!=`%X`7P!@`&$`8@!C`&0`90!F
M`&<`:`!I`&H`:P!L`&T`;@!O`'``<0!R`',`=`!U`'8`=P!X`'D`>@![`'P`
M?0!^`'\`K"```!H@```>("8@("`A(```,"!@`3D@6@%D`7T!>0$``!@@&2`<
M(!T@(B`3(!0@```B(6$!.B!;`64!?@%Z`:``QP+8`D$!I``$`:8`IP"H`*D`
M7@&K`*P`K0"N`'L!L`"Q`-L"0@&T`+4`M@"W`+@`!0%?`;L`/0'=`CX!?`%4
M`<$`P@`"`<0`.0$&`<<`#`')`!@!RP`:`<T`S@`.`1`!0P%'`=,`U`!0`=8`
MUP!8`6X!V@!P`=P`W0!B`=\`50'A`.(``P'D`#H!!P'G``T!Z0`9`>L`&P'M
M`.X`#P$1`40!2`'S`/0`40'V`/<`60%O`?H`<0'\`/T`8P'9`@`!`@,$!08'
M"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T
M-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!A
M8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+C(V.
MCY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[
MO+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?H
MZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O\``0(#!`4&!P@)"@L,#0X/$!$2$Q05
M%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0$%"
M0T1%1D=(24I+3$U.3U!14E-455976%E:6UQ=7E]@04)#1$5&1TA)2DM,34Y/
M4%%24U155E=865I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9BIN,
MC8Z/H*&BHZ2EIJ>HJ:JKK*VNK["QLJ.TM;:WN*6JN[R]O*_`P<+#Q,7&Q\C)
MRLO,S<[/T-'2T]35UM?8V=K;W-W>I\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76
M]]C9VMO<W=[_``$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C
M)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!A8F-D969G:&EJ:VQM;F]P
M<7)S='5V=WAY>EM<75Y?8&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ>WQ]
M?G^`@8*#A(6&AXB)FHN<G9Z?D)&2DY25EI>8F9J;G)V>GZ"AHK.DN:;?J*FZ
MJZRMKK^PL;*SM+6VM[BYNKN^O;Z_X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;7
M^/GZ^_S]_M_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`@("`@
M("`@("`H*"@H*"`@("`@("`@("`@("`@("`@($@0$!`0$!`0$!`0$!`0$!"$
MA(2$A(2$A(2$$!`0$!`0$(&!@8&!@0$!`0$!`0$!`0$!`0$!`0$!`0$!$!`0
M$!`0@H*"@H*"`@("`@("`@("`@("`@("`@("`@(0$!`0("`@$"`0$!`0(!`!
M$`$!`0$@$!`0$!`0$"`0`A`"`@("2!`0`1`!$`$0$`$0$!`0`1`0$`(0$!`0
M$`("$`$0`@(!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`1`!`0$!`0$!`@("`@("
M`@("`@("`@("`@("`@("`@("$`("`@("`@(0````````````````````````
M`````````````````+:VMK:VMK:VMK:VMK:VMK:VMK:VMK:VMK:VMK:VMK:V
MH"$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`N6))\.IF9VCN:FNS
M;?+U<''@NO[[=G=X_9];7%U>7V`V8DGPZF9G:.YJ:[-M\O5P<>"Z_OMV=WC]
MGZ5\?7ZVMK:"MH2%AH>VB9J+NOZ>G[:1DI.4E9:7MIF:F[K^GI\@H:*SI*6F
MIZBYNJNLK:Z?L+&RL[2UMK>XN;J[L[VSG^"YN;FYL^[NR.KJZNKN[O#P\O+U
M]?7UU_C[^_O[_?[?X+FYN;FS[N[(ZNKJZN[N\/#R\O7U]?7W^/O[^_O]_O\`
M`````````````````````````````````````````"`A(B,D)28G*"DJ*RPM
M+B\P,3(S-#4V-S@Y.CL\/3X_0$%"0T1%1D=(24I+3$U.3U!14E-455976%E:
M6UQ=7E]@-D)#1$5&1TA)2DM,34Y/4%%24U155E=865JE?'U^````@@"$A8:'
M`(F*BU-4CEH`D9*3E)66EP"9BIM35(Y:(*&B3*2EIJ>H05.KK*VN6K"QLDRT
MM0"WN$%3NTR]3%I204%!04Q#0\A%145%24E$1$Y.3T]/3]?8555555E4WU)!
M04%!3$-#R$5%145)241$3DY/3T]/]]A55555653_?109"*T#``#-OP@(I@(`
M`(44&0BM`@``C109"*T!``#5UP@(I@$`````````````````````````````
M``````(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$"`O\"`@("`@("`@("`@("`@("`@("`@("`@$!`0$B(R0!
M)0$!`0$F`0$!`P,!!2<!`0$!`0$!*`$"`00$`@8"`0$'`1$!`0$!!0$!`0$#
M`0$!"`$!*0$!$@8!!0$&!`,#!0<)`P,%`0,)!P4#!0,%`P4#!0D'`0$%`PD'
M`P4!!`0&"`H$!`8"!`H(!@0&!`8$!@0&"@@!`@8$"@@$!@&!@8&!@8&!@8&!
M@8&!@8&!@8&!@8&!@8&!@8&!@8&!@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8
MF9J;G)V>GZ"AHJ2E_ZBIJJNLKJ^PL;*SM+6VM[F\O;Z_P,'"Q,7&Q\C)I*7_
MJ*FJJZRNK["QLK.TM;:WN;R]OK_`P<+*R\S-@8&!SH'/T-'2@=.ZU+F\P\*!
MU=;7V-G:VX'<NMVYO,/"@M[?L>"DX>+CY+GEYN?HPNGJZ['M[H'O\*2Y\;'R
ML<*WI*2DI+&FIJ>IJ:FIKJZHJ+.SM+2TM/.XO;V]O<&\N[>DI*2DL::FIZFI
MJ:FNKJBHL[.TM+2T]+B]O;V]P;SU4P``````````````D0```.08&0CI&!D(
M]/H8"`````!`_!P(0/L<"$#Z'`@`````````````````````````````````
M`````0````$````#``````#_``#^'`A@C"4(``$"`P0%!@<("0H+#`T.#Q`1
M$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^
M/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?8$%"0T1%1D=(24I+
M3$U.3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8
MF9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%
MQL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R
M\_3U]O?X^?K[_/W^_P`!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?
M("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`86)C9&5F9VAI:FML
M;6YO<'%R<W1U=G=X>7I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY
M>GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6F
MIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3
MU-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O\`
M("`@("`@("`@*"@H*"@@("`@("`@("`@("`@("`@("!($!`0$!`0$!`0$!`0
M$!`0A(2$A(2$A(2$A!`0$!`0$!"!@8&!@8$!`0$!`0$!`0$!`0$!`0$!`0$!
M`1`0$!`0$(*"@H*"@@("`@("`@("`@("`@("`@("`@("$!`0$"`#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#````````````````````
M```````````````````````A``````````````#A````Y!@9"/(8&0CT^A@(
M`````$#\'`A`^QP(0/H<"$#Z'`@````````````````````````````````!
M`````0````,``````/__`/X<",#]'`@`````(*0'"$2G!P@<K0<(4+`("/"L
M!PBXJ@<(S*T("`R>!P@`````````````````````````````````````````
M`.RN!PB@KP<(W*P(""2M"`B(K0@(<'8'")BU"`@8FP<(Y)L'"%B?!PB$H@<(
M?)P'"/2@!PB\:0<(;'$'"#QR!P@D=@<(0&H'",!K!P@8;0<(1&\'""1Q!PCD
M>0<(O'4'"`````````````````````````````````````"`/AT(@#@="(`R
M'0B`+!T(@"8="(`@'0@`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"`&AT(@!0="`````"`#AT(``````````"`
M"!T(````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"``AT(`/\`_P#_`?\!_P'_`O\"_P+_`_\#
M_P/_!/\$_P3_!?\%_P7_!O\&_P;_!_\'_P?_"/\(_PC_"?\)_PG_"O\*_PK_
M"_\+_PO_#/\,_PS_#?\-_PW_#O\._P[_#_\/_P__$/\0_Q#_$?\1_Q'_$O\2
M_Q+_$_\3_Q/_%/\4_Q3_%?\5_Q7_%O\6_Q;_%_\7_Q?_&/\8_QC_&?\9_QG_
M&O\:_QK_&_\;_QO_'/\<_QS_'?\=_QW_'O\>_Q[_'_\?_Q__(/\@_R#_(?]!
M_R'_(O]"_R+_(_]#_R/_)/]$_R3_)?]%_R7_)O]&_R;_)_]'_R?_*/](_RC_
M*?])_RG_*O]*_RK_*_]+_RO_+/],_RS_+?]-_RW_+O]._R[_+_]/_R__,/]0
M_S#_,?]1_S'_,O]2_S+_,_]3_S/_-/]4_S3_-?]5_S7_-O]6_S;_-_]7_S?_
M./]8_SC_.?]9_SG_.O]:_SK_._\[_SO_//\\_SS_/?\]_SW_/O\^_S[_/_\_
M_S__0/]`_T#_(?]!_R'_(O]"_R+_(_]#_R/_)/]$_R3_)?]%_R7_)O]&_R;_
M)_]'_R?_*/](_RC_*?])_RG_*O]*_RK_*_]+_RO_+/],_RS_+?]-_RW_+O].
M_R[_+_]/_R__,/]0_S#_,?]1_S'_,O]2_S+_,_]3_S/_-/]4_S3_-?]5_S7_
M-O]6_S;_-_]7_S?_./]8_SC_.?]9_SG_.O]:_SK_6_];_UO_7/]<_US_7?]=
M_UW_7O]>_U[_7_]?_U__8/]@_V#_8?]A_V'_8O]B_V+_8_]C_V/_9/]D_V3_
M9?]E_V7_9O]F_V;_9_]G_V?_:/]H_VC_:?]I_VG_:O]J_VK_:_]K_VO_;/]L
M_VS_;?]M_VW_;O]N_V[_;_]O_V__</]P_W#_<?]Q_W'_<O]R_W+_<_]S_W/_
M=/]T_W3_=?]U_W7_=O]V_W;_=_]W_W?_>/]X_WC_>?]Y_WG_>O]Z_WK_>_][
M_WO_?/]\_WS_??]]_WW_?O]^_W[_?_]__W__@/^`_X#_@?^!_X'_@O^"_X+_
M@_^#_X/_A/^$_X3_A?^%_X7_AO^&_X;_A_^'_X?_B/^(_XC_B?^)_XG_BO^*
M_XK_B_^+_XO_C/^,_XS_C?^-_XW_CO^._X[_C_^/_X__D/^0_Y#_D?^1_Y'_
MDO^2_Y+_D_^3_Y/_E/^4_Y3_E?^5_Y7_EO^6_Y;_E_^7_Y?_F/^8_YC_F?^9
M_YG_FO^:_YK_F_^;_YO_G/^<_YS_G?^=_YW_GO^>_Y[_G_^?_Y__H/^@_Z#_
MH?^A_Z'_HO^B_Z+_H_^C_Z/_I/^D_Z3_I?^E_Z7_IO^F_Z;_I_^G_Z?_J/^H
M_ZC_J?^I_ZG_JO^J_ZK_J_^K_ZO_K/^L_ZS_K?^M_ZW_KO^N_Z[_K_^O_Z__
ML/^P_[#_L?^Q_['_LO^R_[+_L_^S_[/_M/^T_[3_M?^U_[7_MO^V_[;_M_^W
M_[?_N/^X_[C_N?^Y_[G_NO^Z_[K_N_^[_[O_O/^\_[S_O?^]_[W_OO^^_[[_
MO_^__[__P/_`_\#_P?_!_\'_PO_"_\+_P__#_\/_Q/_$_\3_Q?_%_\7_QO_&
M_\;_Q__'_\?_R/_(_\C_R?_)_\G_RO_*_\K_R__+_\O_S/_,_\S_S?_-_\W_
MSO_._\[_S__/_\__T/_0_]#_T?_1_]'_TO_2_]+_T__3_]/_U/_4_]3_U?_5
M_]7_UO_6_];_U__7_]?_V/_8_]C_V?_9_]G_VO_:_]K_V__;_]O_W/_<_]S_
MW?_=_]W_WO_>_][_W__?_]__X/_@_^#_X?_A_^'_XO_B_^+_X__C_^/_Y/_D
M_^3_Y?_E_^7_YO_F_^;_Y__G_^?_Z/_H_^C_Z?_I_^G_ZO_J_^K_Z__K_^O_
M[/_L_^S_[?_M_^W_[O_N_^[_[__O_^__\/_P__#_\?_Q__'_\O_R__+_\__S
M__/_]/_T__3_]?_U__7_]O_V__;_]__W__?_^/_X__C_^?_Y__G_^O_Z__K_
M^__[__O__/_\__S__?_]__W__O_^__[_________`"0`)``D`20!)`$D`B0"
M)`(D`R0#)`,D!"0$)`0D!20%)`4D!B0&)`8D!R0')`<D""0()`@D"20))`DD
M"B0*)`HD"R0+)`LD#"0,)`PD#20-)`TD#B0.)`XD#R0/)`\D$"00)!`D$201
M)!$D$B02)!(D$R03)!,D%"04)!0D%205)!4D%B06)!8D%R07)!<D&"08)!@D
M&209)!DD&B0:)!HD&R0;)!LD'"0<)!PD'20=)!TD'B0>)!XD'R0?)!\D("0@
M)"`D(20A)"$D(B0B)"(D(R0C)",D)"0D)"0D)20E)"4D)B0F)"8D)R0G)"<D
M*"0H)"@D*20I)"DD*B0J)"HD*R0K)"LD+"0L)"PD+20M)"TD+B0N)"XD+R0O
M)"\D,"0P)#`D,20Q)#$D,B0R)#(D,R0S)#,D-"0T)#0D-20U)#4D-B0V)#8D
M-R0W)#<D."0X)#@D.20Y)#DD.B0Z)#HD.R0[)#LD/"0\)#PD/20])#TD/B0^
M)#XD/R0_)#\D0"1`)$`D021!)$$D0B1")$(D0R1#)$,D1"1$)$0D121%)$4D
M1B1&)$8D1R1')$<D2"1()$@D221))$DD2B1*)$HD2R1+)$LD3"1,)$PD321-
M)$TD3B1.)$XD3R1/)$\D4"10)%`D4211)%$D4B12)%(D4R13)%,D5"14)%0D
M5215)%4D5B16)%8D5R17)%<D6"18)%@D6219)%DD6B1:)%HD6R1;)%LD7"1<
M)%PD721=)%TD7B1>)%XD7R1?)%\D8"1@)&`D821A)&$D8B1B)&(D8R1C)&,D
M9"1D)&0D921E)&4D9B1F)&8D9R1G)&<D:"1H)&@D:21I)&DD:B1J)&HD:R1K
M)&LD;"1L)&PD;21M)&TD;B1N)&XD;R1O)&\D<"1P)'`D<21Q)'$D<B1R)'(D
M<R1S)',D="1T)'0D=21U)'4D=B1V)'8D=R1W)'<D>"1X)'@D>21Y)'DD>B1Z
M)'HD>R1[)'LD?"1\)'PD?21])'TD?B1^)'XD?R1_)'\D@"2`)(`D@22!)($D
M@B2")((D@R2#)(,DA"2$)(0DA22%)(4DAB2&)(8DAR2')(<DB"2()(@DB22)
M)(DDBB2*)(HDBR2+)(LDC"2,)(PDC22-)(TDCB2.)(XDCR2/)(\DD"20))`D
MD221))$DDB22))(DDR23)),DE"24))0DE225))4DEB26))8DER27))<DF"28
M))@DF229))DDFB2:))HDFR2;))LDG"2<))PDG22=))TDGB2>))XDGR2?))\D
MH"2@)*`DH22A)*$DHB2B)*(DHR2C)*,DI"2D)*0DI22E)*4DIB2F)*8DIR2G
M)*<DJ"2H)*@DJ22I)*DDJB2J)*HDJR2K)*LDK"2L)*PDK22M)*TDKB2N)*XD
MKR2O)*\DL"2P)+`DL22Q)+$DLB2R)+(DLR2S)+,DM"2T)+0DM22U)+4DMB30
M)+8DMR31)+<DN"32)+@DN233)+DDNB34)+HDNR35)+LDO"36)+PDO237)+TD
MOB38)+XDOR39)+\DP"3:),`DP23;),$DPB3<),(DPR3=),,DQ"3>),0DQ23?
M),4DQB3@),8DQR3A),<DR"3B),@DR23C),DDRB3D),HDRR3E),LDS"3F),PD
MS23G),TDSB3H),XDSR3I),\DMB30)+8DMR31)+<DN"32)+@DN233)+DDNB34
M)+HDNR35)+LDO"36)+PDO237)+TDOB38)+XDOR39)+\DP"3:),`DP23;),$D
MPB3<),(DPR3=),,DQ"3>),0DQ23?),4DQB3@),8DQR3A),<DR"3B),@DR23C
M),DDRB3D),HDRR3E),LDS"3F),PDS23G),TDSB3H),XDSR3I),\DZB3J).HD
MZR3K).LD["3L).PD[23M).TD[B3N).XD[R3O).\D\"3P)/`D\23Q)/$D\B3R
M)/(D\R3S)/,D]"3T)/0D]23U)/4D]B3V)/8D]R3W)/<D^"3X)/@D^23Y)/DD
M^B3Z)/HD^R3[)/LD_"3\)/PD_23])/TD_B3^)/XD_R3_)/\D`"$`(0`A`2$!
M(0$A`B$"(0(A`R$#(0,A!"$$(00A!2$%(04A!B$&(08A!R$'(0<A""$((0@A
M"2$)(0DA"B$*(0HA"R$+(0LA#"$,(0PA#2$-(0TA#B$.(0XA#R$/(0\A$"$0
M(1`A$2$1(1$A$B$2(1(A$R$3(1,A%"$4(10A%2$5(14A%B$6(18A%R$7(1<A
M&"$8(1@A&2$9(1DA&B$:(1HA&R$;(1LA'"$<(1PA'2$=(1TA'B$>(1XA'R$?
M(1\A("$@(2`A(2$A(2$A(B$B(2(A(R$C(2,A)"$D(20A)2$E(24A)B')`R8A
M)R$G(2<A*"$H(2@A*2$I(2DA*B%K`"HA*R'E`"LA+"$L(2PA+2$M(2TA+B$N
M(2XA+R$O(2\A,"$P(3`A,2$Q(3$A,B$R(3(A,R$S(3,A-"$T(30A-2$U(34A
M-B$V(38A-R$W(3<A."$X(3@A.2$Y(3DA.B$Z(3HA.R$[(3LA/"$\(3PA/2$]
M(3TA/B$^(3XA/R$_(3\A0"%`(4`A02%!(4$A0B%"(4(A0R%#(4,A1"%$(40A
M12%%(44A1B%&(48A1R%'(4<A2"%((4@A22%)(4DA2B%*(4HA2R%+(4LA3"%,
M(4PA32%-(4TA3B%.(4XA3R%/(4\A4"%0(5`A42%1(5$A4B%2(5(A4R%3(5,A
M5"%4(50A52%5(54A5B%6(58A5R%7(5<A6"%8(5@A62%9(5DA6B%:(5HA6R%;
M(5LA7"%<(5PA72%=(5TA7B%>(5XA7R%?(5\A8"%P(6`A82%Q(6$A8B%R(6(A
M8R%S(6,A9"%T(60A92%U(64A9B%V(68A9R%W(6<A:"%X(6@A:2%Y(6DA:B%Z
M(6HA:R%[(6LA;"%\(6PA;2%](6TA;B%^(6XA;R%_(6\A8"%P(6`A82%Q(6$A
M8B%R(6(A8R%S(6,A9"%T(60A92%U(64A9B%V(68A9R%W(6<A:"%X(6@A:2%Y
M(6DA:B%Z(6HA:R%[(6LA;"%\(6PA;2%](6TA;B%^(6XA;R%_(6\A@"&`(8`A
M@2&!(8$A@B&"(8(A@R&#(8,AA"&$(80AA2&%(84AAB&&(88AAR&'(8<AB"&(
M(8@AB2&)(8DABB&*(8HABR&+(8LAC"&,(8PAC2&-(8TACB&.(8XACR&/(8\A
MD"&0(9`AD2&1(9$ADB&2(9(ADR&3(9,AE"&4(90AE2&5(94AEB&6(98AER&7
M(9<AF"&8(9@AF2&9(9DAFB&:(9HAFR&;(9LAG"&<(9PAG2&=(9TAGB&>(9XA
MGR&?(9\AH"&@(:`AH2&A(:$AHB&B(:(AHR&C(:,AI"&D(:0AI2&E(:4AIB&F
M(:8AIR&G(:<AJ"&H(:@AJ2&I(:DAJB&J(:HAJR&K(:LAK"&L(:PAK2&M(:TA
MKB&N(:XAKR&O(:\AL"&P(;`AL2&Q(;$ALB&R(;(ALR&S(;,AM"&T(;0AM2&U
M(;4AMB&V(;8AMR&W(;<AN"&X(;@AN2&Y(;DANB&Z(;HANR&[(;LAO"&\(;PA
MO2&](;TAOB&^(;XAOR&_(;\AP"'`(<`AP2'!(<$APB'"(<(APR'#(<,AQ"'$
M(<0AQ2'%(<4AQB'&(<8AQR''(<<AR"'((<@AR2')(<DARB'*(<HARR'+(<LA
MS"',(<PAS2'-(<TASB'.(<XASR'/(<\AT"'0(=`AT2'1(=$ATB'2(=(ATR'3
M(=,AU"'4(=0AU2'5(=4AUB'6(=8AUR'7(=<AV"'8(=@AV2'9(=DAVB':(=HA
MVR';(=LAW"'<(=PAW2'=(=TAWB'>(=XAWR'?(=\AX"'@(>`AX2'A(>$AXB'B
M(>(AXR'C(>,AY"'D(>0AY2'E(>4AYB'F(>8AYR'G(><AZ"'H(>@AZ2'I(>DA
MZB'J(>HAZR'K(>LA["'L(>PA[2'M(>TA[B'N(>XA[R'O(>\A\"'P(?`A\2'Q
M(?$A\B'R(?(A\R'S(?,A]"'T(?0A]2'U(?4A]B'V(?8A]R'W(?<A^"'X(?@A
M^2'Y(?DA^B'Z(?HA^R'[(?LA_"'\(?PA_2'](?TA_B'^(?XA_R'_(?\A"!\`
M'Y$#"1\!'Y$#"A\"'Y$#"Q\#'Y$##!\$'Y$##1\%'Y$##A\&'Y$##Q\''Y$#
M"!\`'Y$#"1\!'Y$#"A\"'Y$#"Q\#'Y$##!\$'Y$##1\%'Y$##A\&'Y$##Q\'
M'Y$#&!\0'Y4#&1\1'Y4#&A\2'Y4#&Q\3'Y4#'!\4'Y4#'1\5'Y4#%A\6'Q8?
M%Q\7'Q<?&!\0'Y4#&1\1'Y4#&A\2'Y4#&Q\3'Y4#'!\4'Y4#'1\5'Y4#'A\>
M'QX?'Q\?'Q\?*!\@'Y<#*1\A'Y<#*A\B'Y<#*Q\C'Y<#+!\D'Y<#+1\E'Y<#
M+A\F'Y<#+Q\G'Y<#*!\@'Y<#*1\A'Y<#*A\B'Y<#*Q\C'Y<#+!\D'Y<#+1\E
M'Y<#+A\F'Y<#+Q\G'Y<#.!\P'YD#.1\Q'YD#.A\R'YD#.Q\S'YD#/!\T'YD#
M/1\U'YD#/A\V'YD#/Q\W'YD#.!\P'YD#.1\Q'YD#.A\R'YD#.Q\S'YD#/!\T
M'YD#/1\U'YD#/A\V'YD#/Q\W'YD#2!]`'Y\#21]!'Y\#2A]"'Y\#2Q]#'Y\#
M3!]$'Y\#31]%'Y\#1A]&'T8?1Q]''T<?2!]`'Y\#21]!'Y\#2A]"'Y\#2Q]#
M'Y\#3!]$'Y\#31]%'Y\#3A].'TX?3Q]/'T\?4!]0'Z4#61]1'Z4#4A]2'Z4#
M6Q]3'Z4#5!]4'Z4#71]5'Z4#5A]6'Z4#7Q]7'Z4#6!]8'U@?61]1'Z4#6A]:
M'UH?6Q]3'Z4#7!]<'UP?71]5'Z4#7A]>'UX?7Q]7'Z4#:!]@'ZD#:1]A'ZD#
M:A]B'ZD#:Q]C'ZD#;!]D'ZD#;1]E'ZD#;A]F'ZD#;Q]G'ZD#:!]@'ZD#:1]A
M'ZD#:A]B'ZD#:Q]C'ZD#;!]D'ZD#;1]E'ZD#;A]F'ZD#;Q]G'ZD#NA]P'Y$#
MNQ]Q'[L?R!]R'Y4#R1]S'\D?RA]T'Y<#RQ]U'\L?VA]V'YD#VQ]W']L?^!]X
M'Y\#^1]Y'_D?ZA]Z'Z4#ZQ]['^L?^A]\'ZD#^Q]]'_L??A]^'WX??Q]_'W\?
MB!^`'Y$#B1^!'Y$#BA^"'Y$#BQ^#'Y$#C!^$'Y$#C1^%'Y$#CA^&'Y$#CQ^'
M'Y$#B!^`'Y$#B1^!'Y$#BA^"'Y$#BQ^#'Y$#C!^$'Y$#C1^%'Y$#CA^&'Y$#
MCQ^''Y$#F!^0'Y<#F1^1'Y<#FA^2'Y<#FQ^3'Y<#G!^4'Y<#G1^5'Y<#GA^6
M'Y<#GQ^7'Y<#F!^0'Y<#F1^1'Y<#FA^2'Y<#FQ^3'Y<#G!^4'Y<#G1^5'Y<#
MGA^6'Y<#GQ^7'Y<#J!^@'ZD#J1^A'ZD#JA^B'ZD#JQ^C'ZD#K!^D'ZD#K1^E
M'ZD#KA^F'ZD#KQ^G'ZD#J!^@'ZD#J1^A'ZD#JA^B'ZD#JQ^C'ZD#K!^D'ZD#
MK1^E'ZD#KA^F'ZD#KQ^G'ZD#N!^P'Y$#N1^Q'Y$#LA^R'Y$#O!^S'Y$#M!^T
M'Y$#M1^U'[4?MA^V'Y$#MQ^W'Y$#N!^P'Y$#N1^Q'Y$#NA]P'Y$#NQ]Q'[L?
MO!^S'Y$#O1^]'[T?F0.^'YD#OQ^_'[\?P!_`'\`?P1_!'\$?PA_"'Y<#S!_#
M'Y<#Q!_$'Y<#Q1_%'\4?QA_&'Y<#QQ_''Y<#R!]R'Y4#R1]S'\D?RA]T'Y<#
MRQ]U'\L?S!_#'Y<#S1_-'\T?SA_.'\X?SQ_/'\\?V!_0'YD#V1_1'YD#TA_2
M'YD#TQ_3'],?U!_4']0?U1_5']4?UA_6'YD#UQ_7'YD#V!_0'YD#V1_1'YD#
MVA]V'YD#VQ]W']L?W!_<']P?W1_=']T?WA_>']X?WQ_?']\?Z!_@'Z4#Z1_A
M'Z4#XA_B'Z4#XQ_C'^,?Y!_D'Z$#[!_E'Z$#YA_F'Z4#YQ_G'Z4#Z!_@'Z4#
MZ1_A'Z4#ZA]Z'Z4#ZQ]['^L?[!_E'Z$#[1_M'^T?[A_N'^X?[Q_O'^\?\!_P
M'_`?\1_Q'_$?\A_R'ZD#_!_S'ZD#]!_T'ZD#]1_U'_4?]A_V'ZD#]Q_W'ZD#
M^!]X'Y\#^1]Y'_D?^A]\'ZD#^Q]]'_L?_!_S'ZD#_1_]'_T?_A_^'_X?_Q__
M'_\?`!X!'D$``!X!'D$``AX#'D(``AX#'D(`!!X%'D(`!!X%'D(`!AX''D(`
M!AX''D(`"!X)'D,`"!X)'D,`"AX+'D0`"AX+'D0`#!X-'D0`#!X-'D0`#AX/
M'D0`#AX/'D0`$!X1'D0`$!X1'D0`$AX3'D0`$AX3'D0`%!X5'D4`%!X5'D4`
M%AX7'D4`%AX7'D4`&!X9'D4`&!X9'D4`&AX;'D4`&AX;'D4`'!X='D4`'!X=
M'D4`'AX?'D8`'AX?'D8`(!XA'D<`(!XA'D<`(AXC'D@`(AXC'D@`)!XE'D@`
M)!XE'D@`)AXG'D@`)AXG'D@`*!XI'D@`*!XI'D@`*AXK'D@`*AXK'D@`+!XM
M'DD`+!XM'DD`+AXO'DD`+AXO'DD`,!XQ'DL`,!XQ'DL`,AXS'DL`,AXS'DL`
M-!XU'DL`-!XU'DL`-AXW'DP`-AXW'DP`.!XY'DP`.!XY'DP`.AX['DP`.AX[
M'DP`/!X]'DP`/!X]'DP`/AX_'DT`/AX_'DT`0!Y!'DT`0!Y!'DT`0AY#'DT`
M0AY#'DT`1!Y%'DX`1!Y%'DX`1AY''DX`1AY''DX`2!Y)'DX`2!Y)'DX`2AY+
M'DX`2AY+'DX`3!Y-'D\`3!Y-'D\`3AY/'D\`3AY/'D\`4!Y1'D\`4!Y1'D\`
M4AY3'D\`4AY3'D\`5!Y5'E``5!Y5'E``5AY7'E``5AY7'E``6!Y9'E(`6!Y9
M'E(`6AY;'E(`6AY;'E(`7!Y='E(`7!Y='E(`7AY?'E(`7AY?'E(`8!YA'E,`
M8!YA'E,`8AYC'E,`8AYC'E,`9!YE'E,`9!YE'E,`9AYG'E,`9AYG'E,`:!YI
M'E,`:!YI'E,`:AYK'E0`:AYK'E0`;!YM'E0`;!YM'E0`;AYO'E0`;AYO'E0`
M<!YQ'E0`<!YQ'E0`<AYS'E4`<AYS'E4`=!YU'E4`=!YU'E4`=AYW'E4`=AYW
M'E4`>!YY'E4`>!YY'E4`>AY['E4`>AY['E4`?!Y]'E8`?!Y]'E8`?AY_'E8`
M?AY_'E8`@!Z!'E<`@!Z!'E<`@AZ#'E<`@AZ#'E<`A!Z%'E<`A!Z%'E<`AAZ'
M'E<`AAZ''E<`B!Z)'E<`B!Z)'E<`BAZ+'E@`BAZ+'E@`C!Z-'E@`C!Z-'E@`
MCAZ/'ED`CAZ/'ED`D!Z1'EH`D!Z1'EH`DAZ3'EH`DAZ3'EH`E!Z5'EH`E!Z5
M'EH`EAZ6'D@`EQZ7'E0`F!Z8'E<`F1Z9'ED`FAZ:'IH>8!Z;'E,`G!Z<'IP>
MG1Z='IT>GAZ>'IX>GQZ?'I\>H!ZA'D$`H!ZA'D$`HAZC'D$`HAZC'D$`I!ZE
M'D$`I!ZE'D$`IAZG'D$`IAZG'D$`J!ZI'D$`J!ZI'D$`JAZK'D$`JAZK'D$`
MK!ZM'D$`K!ZM'D$`KAZO'D$`KAZO'D$`L!ZQ'D$`L!ZQ'D$`LAZS'D$`LAZS
M'D$`M!ZU'D$`M!ZU'D$`MAZW'D$`MAZW'D$`N!ZY'D4`N!ZY'D4`NAZ['D4`
MNAZ['D4`O!Z]'D4`O!Z]'D4`OAZ_'D4`OAZ_'D4`P![!'D4`P![!'D4`PA[#
M'D4`PA[#'D4`Q![%'D4`Q![%'D4`QA[''D4`QA[''D4`R![)'DD`R![)'DD`
MRA[+'DD`RA[+'DD`S![-'D\`S![-'D\`SA[/'D\`SA[/'D\`T![1'D\`T![1
M'D\`TA[3'D\`TA[3'D\`U![5'D\`U![5'D\`UA[7'D\`UA[7'D\`V![9'D\`
MV![9'D\`VA[;'D\`VA[;'D\`W![='D\`W![='D\`WA[?'D\`WA[?'D\`X![A
M'D\`X![A'D\`XA[C'D\`XA[C'D\`Y![E'E4`Y![E'E4`YA[G'E4`YA[G'E4`
MZ![I'E4`Z![I'E4`ZA[K'E4`ZA[K'E4`[![M'E4`[![M'E4`[A[O'E4`[A[O
M'E4`\![Q'E4`\![Q'E4`\A[S'ED`\A[S'ED`]![U'ED`]![U'ED`]A[W'ED`
M]A[W'ED`^![Y'ED`^![Y'ED`^A[Z'OH>^Q[['OL>_![\'OP>_1[]'OT>_A[^
M'OX>_Q[_'O\>``4`!0`%`04!!0$%`@4"!0(%`P4#!0,%!`4$!00%!04%!04%
M!@4&!08%!P4'!0<%"`4(!0@%"04)!0D%"@4*!0H%"P4+!0L%#`4,!0P%#04-
M!0T%#@4.!0X%#P4/!0\%$`40!1`%$041!1$%$@42!1(%$P43!1,%%`44!10%
M%045!14%%@46!18%%P47!1<%&`48!1@%&049!1D%&@4:!1H%&P4;!1L%'`4<
M!1P%'04=!1T%'@4>!1X%'P4?!1\%(`4@!2`%(04A!2$%(@4B!2(%(P4C!2,%
M)`4D!20%)04E!24%)@4F!28%)P4G!2<%*`4H!2@%*04I!2D%*@4J!2H%*P4K
M!2L%+`4L!2P%+04M!2T%+@4N!2X%+P4O!2\%,`4P!3`%,05A!3$%,@5B!3(%
M,P5C!3,%-`5D!30%-05E!34%-@5F!38%-P5G!3<%.`5H!3@%.05I!3D%.@5J
M!3H%.P5K!3L%/`5L!3P%/05M!3T%/@5N!3X%/P5O!3\%0`5P!4`%005Q!4$%
M0@5R!4(%0P5S!4,%1`5T!40%105U!44%1@5V!48%1P5W!4<%2`5X!4@%205Y
M!4D%2@5Z!4H%2P5[!4L%3`5\!4P%305]!4T%3@5^!4X%3P5_!4\%4`6`!5`%
M406!!5$%4@6"!5(%4P6#!5,%5`6$!50%506%!54%5@6&!58%5P57!5<%6`58
M!5@%6059!5D%6@5:!5H%6P5;!5L%7`5<!5P%705=!5T%7@5>!5X%7P5?!5\%
M8`5@!6`%,05A!3$%,@5B!3(%,P5C!3,%-`5D!30%-05E!34%-@5F!38%-P5G
M!3<%.`5H!3@%.05I!3D%.@5J!3H%.P5K!3L%/`5L!3P%/05M!3T%/@5N!3X%
M/P5O!3\%0`5P!4`%005Q!4$%0@5R!4(%0P5S!4,%1`5T!40%105U!44%1@5V
M!48%1P5W!4<%2`5X!4@%205Y!4D%2@5Z!4H%2P5[!4L%3`5\!4P%305]!4T%
M3@5^!4X%3P5_!4\%4`6`!5`%406!!5$%4@6"!5(%4P6#!5,%5`6$!50%506%
M!54%5@6&!58%AP6'!8<%B`6(!8@%B06)!8D%B@6*!8H%BP6+!8L%C`6,!8P%
MC06-!8T%C@6.!8X%CP6/!8\%D`60!9`%D061!9$%D@62!9(%DP63!9,%E`64
M!90%E065!94%E@66!98%EP67!9<%F`68!9@%F069!9D%F@6:!9H%FP6;!9L%
MG`6<!9P%G06=!9T%G@6>!9X%GP6?!9\%H`6@!:`%H06A!:$%H@6B!:(%HP6C
M!:,%I`6D!:0%I06E!:4%I@6F!:8%IP6G!:<%J`6H!:@%J06I!:D%J@6J!:H%
MJP6K!:L%K`6L!:P%K06M!:T%K@6N!:X%KP6O!:\%L`6P!;`%L06Q!;$%L@6R
M!;(%LP6S!;,%M`6T!;0%M06U!;4%M@6V!;8%MP6W!;<%N`6X!;@%N06Y!;D%
MN@6Z!;H%NP6[!;L%O`6\!;P%O06]!;T%O@6^!;X%OP6_!;\%P`7`!<`%P07!
M!<$%P@7"!<(%PP7#!<,%Q`7$!<0%Q07%!<4%Q@7&!<8%QP7'!<<%R`7(!<@%
MR07)!<D%R@7*!<H%RP7+!<L%S`7,!<P%S07-!<T%S@7.!<X%SP7/!<\%T`70
M!=`%T071!=$%T@72!=(%TP73!=,%U`74!=0%U075!=4%U@76!=8%UP77!=<%
MV`78!=@%V079!=D%V@7:!=H%VP7;!=L%W`7<!=P%W07=!=T%W@7>!=X%WP7?
M!=\%X`7@!>`%X07A!>$%X@7B!>(%XP7C!>,%Y`7D!>0%Y07E!>4%Y@7F!>8%
MYP7G!><%Z`7H!>@%Z07I!>D%Z@7J!>H%ZP7K!>L%[`7L!>P%[07M!>T%[@7N
M!>X%[P7O!>\%\`7P!?`%\07Q!?$%\@7R!?(%\P7S!?,%]`7T!?0%]07U!?4%
M]@7V!?8%]P7W!?<%^`7X!?@%^07Y!?D%^@7Z!?H%^P7[!?L%_`7\!?P%_07]
M!?T%_@7^!?X%_P7_!?\%``10!!4$`011!!4$`@12!`($`P13!!,$!`14!`0$
M!015!`4$!@16!`8$!P17!`8$"`18!`@$"019!`D$"@1:!`H$"P1;!`L$#`1<
M!!H$#01=!!@$#@1>!",$#P1?!`\$$`0P!!`$$00Q!!$$$@0R!!($$P0S!!,$
M%`0T!!0$%00U!!4$%@0V!!8$%P0W!!<$&`0X!!@$&00Y!!D$&@0Z!!H$&P0[
M!!L$'`0\!!P$'00]!!T$'@0^!!X$'P0_!!\$(`1`!"`$(01!!"$$(@1"!"($
M(P1#!",$)`1$!"0$)01%!"4$)@1&!"8$)P1'!"<$*`1(!"@$*01)!"D$*@1*
M!"H$*P1+!"L$+`1,!"P$+01-!"T$+@1.!"X$+P1/!"\$$`0P!!`$$00Q!!$$
M$@0R!!($$P0S!!,$%`0T!!0$%00U!!4$%@0V!!8$%P0W!!<$&`0X!!@$&00Y
M!!D$&@0Z!!H$&P0[!!L$'`0\!!P$'00]!!T$'@0^!!X$'P0_!!\$(`1`!"`$
M(01!!"$$(@1"!"($(P1#!",$)`1$!"0$)01%!"4$)@1&!"8$)P1'!"<$*`1(
M!"@$*01)!"D$*@1*!"H$*P1+!"L$+`1,!"P$+01-!"T$+@1.!"X$+P1/!"\$
M``10!!4$`011!!4$`@12!`($`P13!!,$!`14!`0$!015!`4$!@16!`8$!P17
M!`8$"`18!`@$"019!`D$"@1:!`H$"P1;!`L$#`1<!!H$#01=!!@$#@1>!",$
M#P1?!`\$8`1A!&`$8`1A!&`$8@1C!&($8@1C!&($9`1E!&0$9`1E!&0$9@1G
M!&8$9@1G!&8$:`1I!&@$:`1I!&@$:@1K!&H$:@1K!&H$;`1M!&P$;`1M!&P$
M;@1O!&X$;@1O!&X$<`1Q!'`$<`1Q!'`$<@1S!'($<@1S!'($=`1U!'0$=`1U
M!'0$=@1W!'0$=@1W!'0$>`1Y!'@$>`1Y!'@$>@1[!'H$>@1[!'H$?`1]!'P$
M?`1]!'P$?@1_!'X$?@1_!'X$@`2!!(`$@`2!!(`$@@2"!(($@P2#!(,$A`2$
M!(0$A02%!(4$A@2&!(8$AP2'!(<$B`2(!(@$B02)!(D$B@2*!(H$BP2+!(L$
MC`2-!(P$C`2-!(P$C@2/!(X$C@2/!(X$D`21!)`$D`21!)`$D@23!)($D@23
M!)($E`25!)0$E`25!)0$E@27!)8$E@27!)8$F`29!)@$F`29!)@$F@2;!)H$
MF@2;!)H$G`2=!)P$G`2=!)P$G@2?!)X$G@2?!)X$H`2A!*`$H`2A!*`$H@2C
M!*($H@2C!*($I`2E!*0$I`2E!*0$I@2G!*8$I@2G!*8$J`2I!*@$J`2I!*@$
MJ@2K!*H$J@2K!*H$K`2M!*P$K`2M!*P$K@2O!*X$K@2O!*X$L`2Q!+`$L`2Q
M!+`$L@2S!+($L@2S!+($M`2U!+0$M`2U!+0$M@2W!+8$M@2W!+8$N`2Y!+@$
MN`2Y!+@$N@2[!+H$N@2[!+H$O`2]!+P$O`2]!+P$O@2_!+X$O@2_!+X$P`3`
M!,`$P03"!!8$P03"!!8$PP3$!,,$PP3$!,,$Q03%!,4$Q@3&!,8$QP3(!,<$
MQP3(!,<$R03)!,D$R@3*!,H$RP3,!,L$RP3,!,L$S03-!,T$S@3.!,X$SP3/
M!,\$T`31!!`$T`31!!`$T@33!!`$T@33!!`$U`35!-0$U`35!-0$U@37!!4$
MU@37!!4$V`39!-@$V`39!-@$V@3;!-@$V@3;!-@$W`3=!!8$W`3=!!8$W@3?
M!!<$W@3?!!<$X`3A!.`$X`3A!.`$X@3C!!@$X@3C!!@$Y`3E!!@$Y`3E!!@$
MY@3G!!X$Y@3G!!X$Z`3I!.@$Z`3I!.@$Z@3K!.@$Z@3K!.@$[`3M!"T$[`3M
M!"T$[@3O!",$[@3O!",$\`3Q!",$\`3Q!",$\@3S!",$\@3S!",$]`3U!"<$
M]`3U!"<$]@3V!/8$]P3W!/<$^`3Y!"L$^`3Y!"L$^@3Z!/H$^P3[!/L$_`3\
M!/P$_03]!/T$_@3^!/X$_P3_!/\$``,``P`#`0,!`P$#`@,"`P(#`P,#`P,#
M!`,$`P0#!0,%`P4#!@,&`P8#!P,'`P<#"`,(`P@#"0,)`PD#"@,*`PH#"P,+
M`PL##`,,`PP##0,-`PT##@,.`PX##P,/`P\#$`,0`Q`#$0,1`Q$#$@,2`Q(#
M$P,3`Q,#%`,4`Q0#%0,5`Q4#%@,6`Q8#%P,7`Q<#&`,8`Q@#&0,9`QD#&@,:
M`QH#&P,;`QL#'`,<`QP#'0,=`QT#'@,>`QX#'P,?`Q\#(`,@`R`#(0,A`R$#
M(@,B`R(#(P,C`R,#)`,D`R0#)0,E`R4#)@,F`R8#)P,G`R<#*`,H`R@#*0,I
M`RD#*@,J`RH#*P,K`RL#+`,L`RP#+0,M`RT#+@,N`RX#+P,O`R\#,`,P`S`#
M,0,Q`S$#,@,R`S(#,P,S`S,#-`,T`S0#-0,U`S4#-@,V`S8#-P,W`S<#.`,X
M`S@#.0,Y`SD#.@,Z`SH#.P,[`SL#/`,\`SP#/0,]`ST#/@,^`SX#/P,_`S\#
M0`-``T`#00-!`T$#0@-"`T(#0P-#`T,#1`-$`T0#F0-%`YD#1@-&`T8#1P-'
M`T<#2`-(`T@#20-)`TD#2@-*`TH#2P-+`TL#3`-,`TP#30--`TT#3@-.`TX#
M3P-/`T\#4`-0`U`#40-1`U$#4@-2`U(#4P-3`U,#5`-4`U0#50-5`U4#5@-6
M`U8#5P-7`U<#6`-8`U@#60-9`UD#6@-:`UH#6P-;`UL#7`-<`UP#70-=`UT#
M7@->`UX#7P-?`U\#8`-@`V`#80-A`V$#8@-B`V(#8P-C`V,#9`-D`V0#90-E
M`V4#9@-F`V8#9P-G`V<#:`-H`V@#:0-I`VD#:@-J`VH#:P-K`VL#;`-L`VP#
M;0-M`VT#;@-N`VX#;P-O`V\#<`-P`W`#<0-Q`W$#<@-R`W(#<P-S`W,#=`-T
M`W0#=0-U`W4#=@-V`W8#=P-W`W<#>`-X`W@#>0-Y`WD#>@-Z`WH#>P-[`WL#
M?`-\`WP#?0-]`WT#?@-^`WX#?P-_`W\#@`.``X`#@0.!`X$#@@."`X(#@P.#
M`X,#A`.$`X0#A0.%`X4#A@.L`Y$#AP.'`X<#B`.M`Y4#B0.N`Y<#B@.O`YD#
MBP.+`XL#C`/,`Y\#C0.-`XT#C@/-`Z4#CP/.`ZD#D`.0`YD#D0.Q`Y$#D@.R
M`Y(#DP.S`Y,#E`.T`Y0#E0.U`Y4#E@.V`Y8#EP.W`Y<#F`.X`Y@#F0.Y`YD#
MF@.Z`YH#FP.[`YL#G`.\`YP#G0.]`YT#G@.^`YX#GP._`Y\#H`/``Z`#H0/!
M`Z$#H@.B`Z(#HP/#`Z,#I`/$`Z0#I0/%`Z4#I@/&`Z8#IP/'`Z<#J`/(`Z@#
MJ0/)`ZD#J@/*`YD#JP/+`Z4#A@.L`Y$#B`.M`Y4#B0.N`Y<#B@.O`YD#L`.P
M`Z4#D0.Q`Y$#D@.R`Y(#DP.S`Y,#E`.T`Y0#E0.U`Y4#E@.V`Y8#EP.W`Y<#
MF`.X`Y@#F0.Y`YD#F@.Z`YH#FP.[`YL#G`.\`YP#G0.]`YT#G@.^`YX#GP._
M`Y\#H`/``Z`#H0/!`Z$#HP/"`Z,#HP/#`Z,#I`/$`Z0#I0/%`Z4#I@/&`Z8#
MIP/'`Z<#J`/(`Z@#J0/)`ZD#J@/*`YD#JP/+`Z4#C`/,`Y\#C@/-`Z4#CP/.
M`ZD#SP//`\\#D@/0`Y(#F`/1`Y@#T@/2`](#TP/3`](#U`/4`](#I@/5`Z8#
MH`/6`Z`#UP/7`]<#V`/8`]@#V0/9`]D#V@/;`]H#V@/;`]H#W`/=`]P#W`/=
M`]P#W@/?`]X#W@/?`]X#X`/A`^`#X`/A`^`#X@/C`^(#X@/C`^(#Y`/E`^0#
MY`/E`^0#Y@/G`^8#Y@/G`^8#Z`/I`^@#Z`/I`^@#Z@/K`^H#Z@/K`^H#[`/M
M`^P#[`/M`^P#[@/O`^X#[@/O`^X#F@/P`YH#H0/Q`Z$#HP/R`Z,#\P/S`_,#
M]`/T`_0#]0/U`_4#]@/V`_8#]P/W`_<#^`/X`_@#^0/Y`_D#^@/Z`_H#^P/[
M`_L#_`/\`_P#_0/]`_T#_@/^`_X#_P/_`_\#``(!`D$```(!`D$``@(#`D$`
M`@(#`D$`!`(%`D4`!`(%`D4`!@('`D4`!@('`D4`"`()`DD`"`()`DD`"@(+
M`DD`"@(+`DD`#`(-`D\`#`(-`D\`#@(/`D\`#@(/`D\`$`(1`E(`$`(1`E(`
M$@(3`E(`$@(3`E(`%`(5`E4`%`(5`E4`%@(7`E4`%@(7`E4`&`(9`E,`&`(9
M`E,`&@(;`E0`&@(;`E0`'`(=`AP"'`(=`AP"'@(?`D@`'@(?`D@`(`(@`B`"
M(0(A`B$"(@(C`B("(@(C`B(")`(E`B0")`(E`B0")@(G`D$`)@(G`D$`*`(I
M`D4`*`(I`D4`*@(K`D\`*@(K`D\`+`(M`D\`+`(M`D\`+@(O`D\`+@(O`D\`
M,`(Q`D\`,`(Q`D\`,@(S`ED`,@(S`ED`-`(T`C0"-0(U`C4"-@(V`C8"-P(W
M`C<".`(X`C@".0(Y`CD".@(Z`CH".P([`CL"/`(\`CP"/0(]`CT"/@(^`CX"
M/P(_`C\"0`)``D`"00)!`D$"0@)"`D("0P)#`D,"1`)$`D0"10)%`D4"1@)&
M`D8"1P)'`D<"2`)(`D@"20))`DD"2@)*`DH"2P)+`DL"3`),`DP"30)-`DT"
M3@).`DX"3P)/`D\"4`)0`E`"40)1`E$"4@)2`E("@0%3`H$!A@%4`H8!50)5
M`E4"B0%6`HD!B@%7`HH!6`)8`E@"CP%9`H\!6@):`EH"D`%;`I`!7`)<`EP"
M70)=`ET"7@)>`EX"7P)?`E\"DP%@`I,!80)A`F$"8@)B`F("E`%C`I0!9`)D
M`F0"90)E`F4"9@)F`F8"9P)G`F<"EP%H`I<!E@%I`I8!:@)J`FH":P)K`FL"
M;`)L`FP";0)M`FT";@)N`FX"G`%O`IP!<`)P`G`"<0)Q`G$"G0%R`IT!<P)S
M`G,"=`)T`G0"GP%U`I\!=@)V`G8"=P)W`G<">`)X`G@">0)Y`GD">@)Z`GH"
M>P)[`GL"?`)\`GP"?0)]`GT"?@)^`GX"?P)_`G\"I@&``J8!@0*!`H$"@@*"
M`H("J0&#`JD!A`*$`H0"A0*%`H4"A@*&`H8"AP*'`H<"K@&(`JX!B0*)`HD"
ML0&*`K$!L@&+`K(!C`*,`HP"C0*-`HT"C@*.`HX"CP*/`H\"D`*0`I`"D0*1
M`I$"MP&2`K<!DP*3`I,"E`*4`I0"E0*5`I4"E@*6`I8"EP*7`I<"F`*8`I@"
MF0*9`ID"F@*:`IH"FP*;`IL"G`*<`IP"G0*=`IT"G@*>`IX"GP*?`I\"H`*@
M`J`"H0*A`J$"H@*B`J("HP*C`J,"I`*D`J0"I0*E`J4"I@*F`J8"IP*G`J<"
MJ`*H`J@"J0*I`JD"J@*J`JH"JP*K`JL"K`*L`JP"K0*M`JT"K@*N`JX"KP*O
M`J\"L`*P`K`"L0*Q`K$"L@*R`K("LP*S`K,"M`*T`K0"M0*U`K4"M@*V`K8"
MMP*W`K<"N`*X`K@"N0*Y`KD"N@*Z`KH"NP*[`KL"O`*\`KP"O0*]`KT"O@*^
M`KX"OP*_`K\"P`+``L`"P0+!`L$"P@+"`L("PP+#`L,"Q`+$`L0"Q0+%`L4"
MQ@+&`L8"QP+'`L<"R`+(`L@"R0+)`LD"R@+*`LH"RP++`LL"S`+,`LP"S0+-
M`LT"S@+.`LX"SP+/`L\"T`+0`M`"T0+1`M$"T@+2`M("TP+3`M,"U`+4`M0"
MU0+5`M4"U@+6`M8"UP+7`M<"V`+8`M@"V0+9`MD"V@+:`MH"VP+;`ML"W`+<
M`MP"W0+=`MT"W@+>`MX"WP+?`M\"X`+@`N`"X0+A`N$"X@+B`N("XP+C`N,"
MY`+D`N0"Y0+E`N4"Y@+F`N8"YP+G`N<"Z`+H`N@"Z0+I`ND"Z@+J`NH"ZP+K
M`NL"[`+L`NP"[0+M`NT"[@+N`NX"[P+O`N\"\`+P`O`"\0+Q`O$"\@+R`O("
M\P+S`O,"]`+T`O0"]0+U`O4"]@+V`O8"]P+W`O<"^`+X`O@"^0+Y`OD"^@+Z
M`OH"^P+[`OL"_`+\`OP"_0+]`OT"_@+^`OX"_P+_`O\"``$!`4$```$!`4$`
M`@$#`4$``@$#`4$`!`$%`4$`!`$%`4$`!@$'`4,`!@$'`4,`"`$)`4,`"`$)
M`4,`"@$+`4,`"@$+`4,`#`$-`4,`#`$-`4,`#@$/`40`#@$/`40`$`$1`1`!
M$`$1`1`!$@$3`44`$@$3`44`%`$5`44`%`$5`44`%@$7`44`%@$7`44`&`$9
M`44`&`$9`44`&@$;`44`&@$;`44`'`$=`4<`'`$=`4<`'@$?`4<`'@$?`4<`
M(`$A`4<`(`$A`4<`(@$C`4<`(@$C`4<`)`$E`4@`)`$E`4@`)@$G`28!)@$G
M`28!*`$I`4D`*`$I`4D`*@$K`4D`*@$K`4D`+`$M`4D`+`$M`4D`+@$O`4D`
M+@$O`4D`,`%I`$D`20`Q`4D`,@$S`3(!,@$S`3(!-`$U`4H`-`$U`4H`-@$W
M`4L`-@$W`4L`.`$X`3@!.0$Z`4P`.0$Z`4P`.P$\`4P`.P$\`4P`/0$^`4P`
M/0$^`4P`/P%``3\!/P%``3\!00%"`4$!00%"`4$!0P%$`4X`0P%$`4X`10%&
M`4X`10%&`4X`1P%(`4X`1P%(`4X`20%)`4D!2@%+`4H!2@%+`4H!3`%-`4\`
M3`%-`4\`3@%/`4\`3@%/`4\`4`%1`4\`4`%1`4\`4@%3`5(!4@%3`5(!5`%5
M`5(`5`%5`5(`5@%7`5(`5@%7`5(`6`%9`5(`6`%9`5(`6@%;`5,`6@%;`5,`
M7`%=`5,`7`%=`5,`7@%?`5,`7@%?`5,`8`%A`5,`8`%A`5,`8@%C`50`8@%C
M`50`9`%E`50`9`%E`50`9@%G`68!9@%G`68!:`%I`54`:`%I`54`:@%K`54`
M:@%K`54`;`%M`54`;`%M`54`;@%O`54`;@%O`54`<`%Q`54`<`%Q`54`<@%S
M`54`<@%S`54`=`%U`5<`=`%U`5<`=@%W`5D`=@%W`5D`>`'_`%D`>0%Z`5H`
M>0%Z`5H`>P%\`5H`>P%\`5H`?0%^`5H`?0%^`5H`4P!_`5,`@`&``8`!@0%3
M`H$!@@&#`8(!@@&#`8(!A`&%`80!A`&%`80!A@%4`H8!AP&(`8<!AP&(`8<!
MB0%6`HD!B@%7`HH!BP&,`8L!BP&,`8L!C0&-`8T!C@'=`8X!CP%9`H\!D`%;
M`I`!D0&2`9$!D0&2`9$!DP%@`I,!E`%C`I0!]@&5`?8!E@%I`I8!EP%H`I<!
MF`&9`9@!F`&9`9@!F@&:`9H!FP&;`9L!G`%O`IP!G0%R`IT!G@&>`9X!GP%U
M`I\!H`&A`4\`H`&A`4\`H@&C`:(!H@&C`:(!I`&E`:0!I`&E`:0!I@&``J8!
MIP&H`:<!IP&H`:<!J0&#`JD!J@&J`:H!JP&K`:L!K`&M`:P!K`&M`:P!K@&(
M`JX!KP&P`54`KP&P`54`L0&*`K$!L@&+`K(!LP&T`;,!LP&T`;,!M0&V`;4!
MM0&V`;4!MP&2`K<!N`&Y`;@!N`&Y`;@!N@&Z`;H!NP&[`;L!O`&]`;P!O`&]
M`;P!O@&^`;X!]P&_`?<!P`'``<`!P0'!`<$!P@'"`<(!PP'#`<,!Q`'&`<0!
MQ`'&`<0!Q`'&`<0!QP')`<<!QP')`<<!QP')`<<!R@',`<H!R@',`<H!R@',
M`<H!S0'.`4$`S0'.`4$`SP'0`4D`SP'0`4D`T0'2`4\`T0'2`4\`TP'4`54`
MTP'4`54`U0'6`54`U0'6`54`UP'8`54`UP'8`54`V0':`54`V0':`54`VP'<
M`54`VP'<`54`C@'=`8X!W@'?`4$`W@'?`4$`X`'A`4$`X`'A`4$`X@'C`<8`
MX@'C`<8`Y`'E`>0!Y`'E`>0!Y@'G`4<`Y@'G`4<`Z`'I`4L`Z`'I`4L`Z@'K
M`4\`Z@'K`4\`[`'M`4\`[`'M`4\`[@'O`;<![@'O`;<!\`'P`4H`\0'S`?$!
M\0'S`?$!\0'S`?$!]`'U`4<`]`'U`4<`]@&5`?8!]P&_`?<!^`'Y`4X`^`'Y
M`4X`^@'[`4$`^@'[`4$`_`']`<8`_`']`<8`_@'_`=@`_@'_`=@`````````
M`0`!``$``@`"``(``P`#``,`!``$``0`!0`%``4`!@`&``8`!P`'``<`"``(
M``@`"0`)``D`"@`*``H`"P`+``L`#``,``P`#0`-``T`#@`.``X`#P`/``\`
M$``0`!``$0`1`!$`$@`2`!(`$P`3`!,`%``4`!0`%0`5`!4`%@`6`!8`%P`7
M`!<`&``8`!@`&0`9`!D`&@`:`!H`&P`;`!L`'``<`!P`'0`=`!T`'@`>`!X`
M'P`?`!\`(``@`"``(0`A`"$`(@`B`"(`(P`C`",`)``D`"0`)0`E`"4`)@`F
M`"8`)P`G`"<`*``H`"@`*0`I`"D`*@`J`"H`*P`K`"L`+``L`"P`+0`M`"T`
M+@`N`"X`+P`O`"\`,``P`#``,0`Q`#$`,@`R`#(`,P`S`#,`-``T`#0`-0`U
M`#4`-@`V`#8`-P`W`#<`.``X`#@`.0`Y`#D`.@`Z`#H`.P`[`#L`/``\`#P`
M/0`]`#T`/@`^`#X`/P`_`#\`0`!``$``00!A`$$`0@!B`$(`0P!C`$,`1`!D
M`$0`10!E`$4`1@!F`$8`1P!G`$<`2`!H`$@`20!I`$D`2@!J`$H`2P!K`$L`
M3`!L`$P`30!M`$T`3@!N`$X`3P!O`$\`4`!P`%``40!Q`%$`4@!R`%(`4P!S
M`%,`5`!T`%0`50!U`%4`5@!V`%8`5P!W`%<`6`!X`%@`60!Y`%D`6@!Z`%H`
M6P!;`%L`7`!<`%P`70!=`%T`7@!>`%X`7P!?`%\`8`!@`&``00!A`$$`0@!B
M`$(`0P!C`$,`1`!D`$0`10!E`$4`1@!F`$8`1P!G`$<`2`!H`$@`20!I`$D`
M2@!J`$H`2P!K`$L`3`!L`$P`30!M`$T`3@!N`$X`3P!O`$\`4`!P`%``40!Q
M`%$`4@!R`%(`4P!S`%,`5`!T`%0`50!U`%4`5@!V`%8`5P!W`%<`6`!X`%@`
M60!Y`%D`6@!Z`%H`>P![`'L`?`!\`'P`?0!]`'T`?@!^`'X`?P!_`'\`@`"`
M`(``@0"!`($`@@""`((`@P"#`(,`A`"$`(0`A0"%`(4`A@"&`(8`AP"'`(<`
MB`"(`(@`B0")`(D`B@"*`(H`BP"+`(L`C`",`(P`C0"-`(T`C@".`(X`CP"/
M`(\`D`"0`)``D0"1`)$`D@"2`)(`DP"3`),`E`"4`)0`E0"5`)4`E@"6`)8`
MEP"7`)<`F`"8`)@`F0"9`)D`F@":`)H`FP";`)L`G`"<`)P`G0"=`)T`G@">
M`)X`GP"?`)\`H`"@`*``H0"A`*$`H@"B`*(`HP"C`*,`I`"D`*0`I0"E`*4`
MI@"F`*8`IP"G`*<`J`"H`*@`J0"I`*D`J@"J`*H`JP"K`*L`K`"L`*P`K0"M
M`*T`K@"N`*X`KP"O`*\`L`"P`+``L0"Q`+$`L@"R`+(`LP"S`+,`M`"T`+0`
MG`.U`)P#M@"V`+8`MP"W`+<`N`"X`+@`N0"Y`+D`N@"Z`+H`NP"[`+L`O`"\
M`+P`O0"]`+T`O@"^`+X`OP"_`+\`P`#@`$$`P0#A`$$`P@#B`$$`PP#C`$$`
MQ`#D`$$`Q0#E`$$`Q@#F`,8`QP#G`$,`R`#H`$4`R0#I`$4`R@#J`$4`RP#K
M`$4`S`#L`$D`S0#M`$D`S@#N`$D`SP#O`$D`T`#P`-``T0#Q`$X`T@#R`$\`
MTP#S`$\`U`#T`$\`U0#U`$\`U@#V`$\`UP#7`-<`V`#X`-@`V0#Y`%4`V@#Z
M`%4`VP#[`%4`W`#\`%4`W0#]`%D`W@#^`-X`WP#?`-\`P`#@`$$`P0#A`$$`
MP@#B`$$`PP#C`$$`Q`#D`$$`Q0#E`$$`Q@#F`,8`QP#G`$,`R`#H`$4`R0#I
M`$4`R@#J`$4`RP#K`$4`S`#L`$D`S0#M`$D`S@#N`$D`SP#O`$D`T`#P`-``
MT0#Q`$X`T@#R`$\`TP#S`$\`U`#T`$\`U0#U`$\`U@#V`$\`]P#W`/<`V`#X
M`-@`V0#Y`%4`V@#Z`%4`VP#[`%4`W`#\`%4`W0#]`%D`W@#^`-X`>`'_`%D`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````6@``````````````D0```&80&0@"&1D(]/H8"`````"`1QT(@$8=
M"(!%'0@``````````````````````````````````````0````(````"````
M``#__T!)'0A`11T(`````'3'!P@LR`<(`,H'".1T!PA,QP<(W,@'",RM"`A@
MR@<(```````````````````````````````````````!`@,$!08'"`D*"PP-
M#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ
M.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$149'
M2$E*2TQ-3D]045)35%565UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4
ME9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!
MPL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN
M[_#Q\O/T]?;W^/GZ^_S]_O\``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;
M'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0&%B8V1E9F=H
M:6IK;&UN;W!Q<G-T=79W>'EZ6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U
M=G=X>7I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&B
MHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/
MT-'2T]35UM?8V=K;W-W>W^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\
M_?[_`"`@("`@("`@("@H*"@H("`@("`@("`@("`@("`@("`@2!`0$!`0$!`0
M$!`0$!`0$(2$A(2$A(2$A(00$!`0$!`0@8&!@8&!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$0$!`0$!""@H*"@H("`@("`@("`@("`@("`@("`@("`A`0$!`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(P``````````````X0```&80&0@+&1D(
M]/H8"`````"`1QT(@$8="(!%'0B`11T(````````````````````````````
M`````0````(````"``````#__T!)'0@`21T(`````,2Q!PC8L@<($+4'"*S*
M!P@@QP<([+,'",RM"`B@L`<(````````````````````````````````````
M``````"\M0<(R+4'"(S&!PB@Q@<(K,8'".S&!PB8M0@(U*\'"`2P!PA`L0<(
MO+$'"#"P!PA(L0<(U+4'"%3`!P@XP0<(R,8'"!RW!PC\N`<(P+H'"%B]!PB\
MOP<(<,('"$#,!P@``````````````````````````````````````0````H`
M``!D````Z`,``!`G``"@A@$`0$(/`("6F```X?4%````````````````````
M`````````````````%8``````````````!$````;&1D((AD9"/3Z&`@`````
MX$P=".!+'0C@2AT(``````````````````````````````````````$````!
M`````@``````_P!@2AT(8(PE"`````!XS`<(J,P'"-RL"`@DK0@(B*T("'!V
M!PA(=@<(',X'"+S,!P@XIP@(E*<("/"G"`A`J`@(O&D'"&QQ!P@\<@<()'8'
M"$!J!PC`:P<(&&T'"$1O!P@D<0<(Y'D'"+QU!P@`````````````````````
M``````````````````$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@
M(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-
M3D]045)35%565UA96EM<75Y?8$%"0T1%1D=(24I+3$U.3U!14E-455976%E:
M>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::G
MJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4
MU=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`!
M`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN
M+S`Q,C,T-38W.#DZ.SP]/C]`86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I;
M7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>(
MB8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2U
MMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'B
MX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O\`("`@("`@("`@*"@H*"@@
M("`@("`@("`@("`@("`@("!($!`0$!`0$!`0$!`0$!`0A(2$A(2$A(2$A!`0
M$!`0$!"!@8&!@8$!`0$!`0$!`0$!`0$!`0$!`0$!`1`0$!`0$(*"@H*"@@("
M`@("`@("`@("`@("`@("`@("$!`0$"``````````````````````````````
M```````````````#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#````````````````````````````````````````
M```8```````````````A````&QD9""T9&0CT^A@(`````.!,'0C@2QT(X$H=
M"*!.'0@````````````````````````````````!`````0````(``````/\`
M8$H="&!.'0@`````%&<'"(AG!PB49@<(Y'0'"#2I"`B0J`@(S*T("-AI!P@`
M``````````````````````````````````````$"`P0%!@<("0H+#`T.#Q`1
M$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^
M/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EQ=6UY?8$%"0T1%1D=(24I+
M3$U.3U!14E-455976%E:>WQ]67^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8
MF9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%
MQL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R
M\_3U]O?X^?K[_/W^_R$C(B,C(V<A)2,F(R<C*",I(RHC*R,L(RTC+B,O(S`C
M,2,R(S,C-",U(S8C-R,X(SDC.B,[(SPC/2,^(S\C0"-!(T(C0R-$(T4C1B-'
M(T@C22-*(TLC3"--(TXC3R-0(U$C4B-3(U0C52-6(U<C6"-9(UHC6R-<(UTC
M7B-?(V`C82-B(V,C9"-E(V8C9R-H(VDC:B-K(VPC;2-N(V\C<"-Q(W(C<R-T
M(W4C=B-W(W@C>2-Z(WLC?"-](RLA````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````:2%J(0``?B,``"0C`````````````````````````````'%$
M+W`F/#!P>4,``#A%.U$``#%P,G`S<#1P-7`\40``;%$``#=P-G`G5```4DTX
M<#IP.7`[<#QP`````&LX/7!H.@``/G`_<&D^0'!L-D%P0G!#<$1P-4A%<$9P
M``!'<'1%``!(<````````$EP``!*<#UW``!+<$QP37```$YP``````````!/
M<%<Z``!0<%%P4G!3<%1P57!6<%AP`````"535W```%EP````````````````
M```````````Z=3E"`````&1W``````````!E=V9W`````&=W````````````
M````:'<T0@```````````````````````&IW``!K=P```````````````'-"
M``````````````````````````````````!P=````````&]T`````&E"``!A
M=V)W`````````````$8[``````````!D60```````')*:$`D<```6CH`````
M+4<````````L1`````!L=VUW;G<``'!W;W<``'%W`````'1W``!S=P``<G=U
M=P``````````=G<```````````````````````!I;0``:FUK;0``/'8`````
M```````````````````````````]=@``/G8F-@``/E@`````1#D````````[
M6```,5P```````````````!S2@``=W<```````````````````````!X=P``
M``!Y=P``````````````````>W<``'IW``!',0``?'=]=P````````````!^
M=P````````````````````````````!K1C1L````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````73,S=@`````T=F1!-78V=C=V
M.'8Y=CIV(T@[=@```````````````````````````````'I!*#EH;0``````
M`&HY7UD`````````````````````````````````````8U,`````3W8``#-"
M4'8`````4792=E-V5'8`````5G8``"LQ5W8``%AV679:=@``6W9<=@``````
M````779>=DI/``!?=F!V879B=F-V9'9P0&5V9G9G=FAV:78``&IV``!K=FQV
M``!M=FYV;W9P=G%V<G9S=G1V*#X``'5V=G9W=GAV`````````````'I(>79Z
M=GMV?'8`````?79^=B%W(G<C=R1W)7<`````)G<G=RAW;C$I=RIW*W<`````
M+'<M=UM!+G<`````+W<````````````````````````[4B$V``!?1@``````
M`')-255]2$])0D\B6#LR:U,``"18<S,``"A74D<G6$!*``!P1WLQ-5)4-"LV
M/TLI6````````"HV```]04]1```E22U8``!V.#Y17&-05@````!A-P``+C0`
M`%E!```\6```:$TD-2I.=U8``'9`63XO6````````$M$``!#/@``,5@T0V52
M```N5EI.)U5U.B8W5D```#E&4D5'1P``5#D``$LS4E(`````/UA%/G)&,E(P
M3V=/``````````!I2@````!`6````````````````')"4D(``&E(````````
M```````````````````L1P``````````````````2T$``&A3>54``$)*?C8A
M6%I3=S\``$94)3M!6&5.+CX`````*%@``$=1*5`````````]6&]9=DTZ/P``
M.STE.F!2>C)@.C9$``!M3RD^)$U!00```````%='<5D``'19``````````!+
M2&E8````````6E(R2DI(;%AJ6$98=CU-1G`S``!K6'$]:3T``%1(4S0`````
M6$(``%8R4%=+2GM+3%4V.$E/````````6EEP6"I'``!N6```>C1N0512````
M`&U8``!'4F]81T,```````!V40``659R6```=5A^/%L\````````3D@``%TW
M``!"-P``<T8``````````````````'A805(`````:4X_/'PW)3==4```````
M``````!:5D53;SMA.W%8`````"%),$XK-```<U@``$M)=EA70G=8`````#%.
M>5@````````N,D`Y```C60``:3```&9!``!L20``14L``$9+)%D`````````
M````:#4`````*S4````````````````[3DTU(5=T5U-3``!E3```3CH``")9
M7%E@4WU8<#=W5WY8>E@A66-$`````#93=%A=60``>U@``&5%`````%!`````
M`'!16S``````43PF60``)5D``````````"Q9+ED``"M9.4H````````I6396
M````````7C,H60``?4```$Q*```J60``)UD`````,%D`````,38````````I
M.0``0%(`````0$\`````0D(``$0];%5@,DA':S\M60``+UD``&I.;CH`````
M````````5D<```````````````````````!C,0```````%DT;38T60``````
M````(3\```````!>64Y'?D`X60````````````!72WTW```U60``-UDC,6%3
M.5D``$50```V60`````Q60``,EDI03-9`````',\7E`I.```8SX``#U9````
M```````Z60``,S````````!"60``````````````````````````````````
M1%DV,0``/UD`````.34``',^````````2$QR.E!2``!#60````!H/0``*S,`
M``````!%66L^``!&63M97T0``#Y905E`60``````````````````````````
M```N50``-58``&-'``````````!(60```````%D\2ED````````\60``2UDK
M1@````````````!)60``````````=E<``"--`````````````````````"$]
M````````````````3%D````````````````````````\135-````````35D`
M````1UDE,WX_```````````U.`````!\0```````````>#``````````````
M``````````````````````````````````````````!V-```3ED``$]9(C10
M60````!?-`````````````!!,```````````````````45DU20``````````
M````````````````````````````````````````<4\```````````````!2
M60```````$5!`````````````````````````````%99+DD``````````%59
M5%E760``````````6TL``"D]`````````````"=&````````````````````
M``````!365A9````````65D```````````````!E2```````````````````
M``````````````````!<0```````````````````````````````````````
M``````````````````````````````````````!Y-B-82E0``"I45E!D,U=5
M``!(3V(Y``!+/P``8D,```````!2-@````!#36Y9<%D````````S-0``-38`
M````````````)#X`````:T@`````*T@`````2S`K.7E!8ED``#Q`,CD``%@Y
M2U!X,61&7SYD-4A7``!X468\7DH`````/3QF66=8`````%I$`````%0X/4@`
M````83)95```````````,$,`````84,B6E](```T4```?#XI10```````%HY
M```C6@``*50D6@````````````![62PV`````&LW>3%\664S=CX``'8_,5)D
M0````````#,V?EE]60`````[/@```````&!&```\5R%:```Y00``<C5H00``
M``!U/```530```````````````````````!=00``?40`````.#PR-P````!O
M-P```````````````&Q9```^1@``+3]+.P````!*-0``25M74```.4T\,'8S
M=SM*6R\Z``!D5#8U<S566%!(`````%8W4$=76```+S\`````.UM86`````!,
M4"X[````````/FM0075!<E15.#0T``!U,P`````^20```````%!%````````
M645[0```<#$``%E83CD``#TU`````%I8`````$96(DLO2#))3#1,/P``=#D`
M`%M87%AG-D$\:DP```````````````!W3P``75@P1P````!0.2,]`````%Y,
M``!*1@````````````!@6```7E@`````7U@```````!^,```9SX``"-*=#P`
M`````````#$X`````&XX``````````````````````````!B6```2ST``&18
M8U@`````````````?$4``````````````````&58`````&98````````````
M```````F00``,$AL,"8Y4SQQ3CU;4T$``````````"\V>E8L15D]/EL_6P``
M`````'A`(CY-0```````````````````````````0%M&2@```````"HR````
M````0E,``&-#```K40``````````0EL``%5`````````0UL``#$_````````
M````````/$0``````````%I'`````````````````````````````$1;````
M`````````````````&A95TD````````T.7!.2%0``````````'PP4C0``%E0
M``````````!I60``2UYK60``````````,%@O.S$Q``!7,TY8`````%%4````
M`#,];S\``#M/`````%!8````````2S<```````!16```````````````````
M````````)49X1SU2`````%)89$0``"Y*```G1P``)E@``'U)9TY<.VLP````
M````*CLM4```,#%D5S]7```E-71"3T0`````*3(``#<R``!E,3)?/%4H/RQ"
M55@Q0@``5%A43@``8%H``$!.`````#18+D,A4R-.```T/#1(44(``&T^-E``
M`&%:``````````!D1P`````G,P``<C9\3'I``````'=````Y46%11U@`````
M`````````````%XR`````&5```!Q.@````!(6```+50`````84])6```2EA#
M3P``>#-'/@``````````2U@``````````````````$Q;```````````E2```
M`````%A/``!^2$XR`````````````%939C(P/%%3*TLT-P```````"(W````
M`&5*```A2%Q*9#%P4```444```````!%6WXU`````%H_13ED/FU!```V7S5?
M.U90/5E52#`C-DD_*$PS7S=*4E,``$]8-E)%.CY+/DP``#=?<#4T7P``````
M`'53``!4,W<X```Z7P``3SHJ/'4U```L37M#<SIT0$)-<D\X7T5/``!`0CE?
M<$(```````!]/@``7T%,37=233=!7P``1%\`````<3=),%8V5#<``"PZ?4Q4
M/S%+=$8``"A615\``&).,S,`````?$XU-```1TYP.@``84X``#U1`````$!?
M`````'0T``!*,P``9C@[7P``````````140``#Q?/5\^7SM%/U]"7S%40U\`
M`#I'6$X`````````````6$0``$I?``!/7P``7%8`````````````````````
M25]:7S9.``!'.DY?2%]>10````!K270Z?$,`````5SX``$9?``!-7P``6$4`
M`````````"9533H``$P^/5-`.```9%8``$=?/CDG/P````!\04M?3%\``%!?
M`````````````%M?95\``%=?5E])5V-?9%]K92=24E\``"D_``!;5```2#]4
M7P```````$Q/`````%U?``!*40``7E\G,#=&4U\``&4Z``!?-EM-?CE55```
M``!?7VQ/)3!G7U%?1E%57UA?65]<7P``*3L``&!?85\``&)?9E]H7S13````
M`````````&<X-D5J7UI)*$%$1`````!>/WA/````````7%5N7P``````````
M`````#@R``!?.FQ?``!!6P``9%$``````````'1+/30``"8P````````````
M`'%?1DQR7P````!M7P```````````````&E?``````````!K7P``;U]P7ST[
M`````'-?`````'1?```C.P``6THH3B=@*C,``"9@````````(6``````````
M`'Y?``!937Q?``!Z7P``4#]$5P``3$D`````>%\A,`````````````!]7P``
M````````>U\B8``````````````H8```````````2#<`````(48V23)`=5\`
M````/D4``$18>5]V1````````````````"-@)&`E8"50`````#1@9$P``#%@
M```F/R]@.4XK8$9)`````"Y`+F!M.C`Z*6````````!V7P``,V``````.&``
M```````M-#E@`````#)/2#H``#!@``````````````````!Z4```````````
M`````````````"Q@``![5```=U\``&=%```M8```=U,``#9@-V``````````
M````1&!A4````````#Q@`````$E@2F`````````^8"I@)$E!8```,F``````
M````````2$I#8```-6```$M.``!#2TU@1F!"8```2V```#I@/V!`8`````!%
M8`````!'8$A@``!,8```.V``````````````5$M58```5F!28```````````
M`````%!@3CP`````46```$(X15@`````````````````````:E``````;T(`
M````3V`]8````````%1@4V``````5V```````````%Q@6&````````!V5C`S
M``!L5P``.TL`````6F```'M.````````63H`````````````````````````
M``````!A8%U@+5(`````````````8F``````6V!98%]@`````&!@````````
M`````%Y@``!D8````````'=&+%AK5&9@24H``````````&5@``````````!!
M.```````````9V!H8`````````````````````!I8&-@````````````````
M```_.F=,````````:F````````````````````````````````````````!Y
M3P````````````````````````````!K8```````````````````0D@`````
M`````$`]``````````````````````````````````!21```````````````
M`````````&Q@`````&U@`````'1'1$L``&Y@6#LV6')2;V!%30``6C8`````
M``````````!Q8```,%0`````)T!1-``````G3G!@````````<F!,.0````!Z
M.3Q-<V````````!41G1@```R5```)DAV8'5@````````````````````````
M`````````````````````'=@`````$%-````````)4H``````````%I45UM9
M6P``6%MG.5Q;75M8-0````!:6P````````````!;6R$S7UL`````>#L``#=6
M``!@6P``````````>3X`````.S<``%!;+DPR/S4[>%=3/P````````````!I
M/P````!A/#-,7EM3,&M.6#<Y5T)&`````"1````Y3```9UMA6SI&8UL``&A;
M``!W10```````&I;`````&E;0#\```````!F6V5;`````````````#DT+$`B
M0F);9%L``````````$U0;5L`````````````74!R6P``````````````````
M8C8``````````'-;4ELX.2M4;%L``%$_<%L``%%;``!F-0``:UME/P``````
M`&Y;``!Q6P```````'E;````````````````````````(3DC,```````````
M````````<4(`````1S-O6P````!X6P``4D9T6P````!U6W=;=EL`````?EL`
M`')3.C(```````!]6P`````````````````````D7```>UL``````````'I;
M````````?%M@17D[`````"-<`````"5<``!#3````````%$V0%T````````A
M7```(EP````````U1P```````&DV````````)UP``````````"9<```I7"0Q
M`````$PU`````````````#`_`````````````%]1``````````!"-@``````
M```````````````````````````````H7```````````````````>DMS:P``
M`````%Q+`````'Y+````````04P`````````````>T@````````````````J
M7`````````````!N3"M<````````````````````````````````````````
M`````%-;```O7"Q<```S/@``>TH````````M7`````````````````````!*
M23E$`````````````#U'+EP```````!V5&90`````````````````````"M$
M538```````````````````````````````````````````````!46P``````
M````6C$```````!56P````````````````````````````!66P```````#XZ
M`````````````````````````````````````$!(````````````````/TI)
M2```,U<``'E)`````$<_`````'@Z`````#Q2`````````````````````#IB
M```F-``````X,0`````````````T.```1$\``````````&=9)D]B30````!M
M66`V```Y4@`````[.0``````````.6(W8@``<S0``&Q,*TQR-P``,EAK43LZ
M```G2@`````W30````!$4F0_4#QA-@``15X``````````$9>/%L``%E1````
M`&9&3D1N-P``7#<`````?#]@5P``=48`````/#%(7C$]5TQ*7@``25X`````
M````````;#4``%U)`````$(P```````````````````````````````````N
M12M%``!,1```:3Q]2P```````$,Z````````>65G2'IE?4T``#%7/CAH0@``
M44@`````>V4``````````$HV2SP`````?5$A9@``;D,``````````"1F````
M``````!^925F5TT`````03=\97UE(V8`````740H9@`````G9@``````````
M`````$-#``!>1@`````J9@``````````````````-T0````````B9CQ*````
M``````!C/4,Y)F954"].`````"EF,&8``"92```J/2UF`````````````"]F
M``!10`````!,4@```````"<\````````````````````````````````,68`
M`'92````````2U<``'Y-``!>329"*V8L9C\]+F8S9@`````R9@``````````
M-F8``#AF``````````!O1````````$A$`````&H^;TD`````-V8``'`V````
M````9$,``````````````````&E3-&8``#5F```B2``````````````]9@``
M`````#EF`````````````$5&`````'%-.V8`````````````````````````
M`#QF``````````!I.P``````````````````/F8``````````#IF`````#=`
M````````````````````````)%,_9G1)0V8`````1&8``````````'90````
M````````````````````````````````````````````/4,`````````````
M`````$1#0F8`````````````````````````````````````068`````````
M`````````$=F,4\``'1K`````$IF`````````````$5F`````%X\*4D`````
M```````````U/`````!33P````````````!(9@``268``$YF``!09@``````
M`%%F````````2V95-0``3&8`````3V8`````6T0``$9F`````````````$UF
M````````````````````````````````````````````````````````````
M`%)F````````````````````````````````5&939@``````````````````
M``````````````````````````````````````````````````!59@``>%D`
M````5F8`````````````````````5V8`````````````````````````````
M``````````!35UUF``!>9E<_4%0``%979C1O2UIF0UA.5R)0``!/0P````!?
M9CX\0CE;9B=1`````"(Z3T(``"M8````````:TIN90``7&8``'4W````````
M``!F2`````!U1``````R97Y$``!\2S-E+%4``&Y36$HR,```3DMJ30````!J
M.@```````#5E```T90``6E=9.696*#9P34M2)C$U2@``:#-S24T_>U!22C9E
M0CL```````!<3RPY``````````!75``````F.F=1?$]2/```-V5=2```````
M`&T_=C%>2P````!%/```1#QZ4EQ#7#\``````````#LX````````0D,``"XZ
M(E0```````````````````````!>1R]$;#(``%$Y`````#ME2$$`````+U4`
M````````````/&4``#YE``````````````````!G-%0V0DLP43PU`````%E*
M``!B-P````!D20``*ST`````/DYP5P``````````(5```%E)`````'LV6&9B
M/```/C,``%!)``!99B(S``````````!,7@``2%--7@``(E(``````````$Y>
M``````````!-/@````!/7@```````"Q*?%)?,VIE840A/C).<D16/BA&8S(`
M````4SX`````?$=K3&P]74X`````.DI!1FQE/%`````````Y50```````&UE
M``````````!T2@``0$U%0@``;V4``$1"<&4``````````````````'AE34T`
M`#U)``````````````````!94BAA``````````!L4P``:DMQ1@``````````
M```L80```````"=A*6$`````*F$O80````!M,@``*V%:."UA+F$P83HU,6$`
M````````````,V$X80````````````!240``-F$U86M!````````-V$``$!4
M```R80``.F$V,```````````-&$``'D_```Y80`````[80``````````````
M`#YA````````````````/&$```````````````!%5@``````````````````
M/T\`````/6$_84U"``!K-@``>%,`````34<`````93<`````````````````
M`````````'X^````````````````0&%!80````!'86<S````````````````
M:48`````````````7C0``$)1``````````!(80````!&80````````````!%
M80``0V%"80``0#$````````X541A`````````````$MA````````````````
M`````$QA2F$`````````````````````>F\`````4V%2839'````````````
M`````````````````$EA`````$YA``!080``````````````````````````
M``!480``46%-80````!/80``````````56$`````````````````````````
M`````````%9A````````````````````````````````````````````````
M``````````!780```````%AA````````````````````````````````````
M``````````````````````````````!:80``````````````````````````
M````````6V$``````````````````"%.````````````````````````````
M``````!=9P``*#1=5@`````R43(S`````"0Y<U=)1UX^+CD``%=.`````&XR
M3UL``#H\45)(2TTP`````&]/`````````````&-9;3T`````4C%02CPR```G
M2RLW```F2@```````"-/`````'A@2E5[8`````!Z8$%%>TP``#%!>6!C5B\R
M1%9;-0````````````````````!X-"%6`````````````"]/;S``````?&``
M````````````(6$C,P````!]8'Y@,4,``````````%U#```B87DW````````
M````````3SL``````````````````"-A.T0`````````````)&$`````)6$`
M````)F$Q-````````````````````````````````````````$DX/49J1```
M(C(``%)0``!;9T,[5U-$4P``8SE/8@```````"]7``!L1U,Q`````#(T46(`
M``````!R4"Y"4&(``&(_)E-7-5)B:C4``&U#?3@``"XX``!314\W5&(`````
M`````%-B2#9Y5P`````````````E30````````````!88@``5F)\2C4_.5-5
M8@``````````5V(``````````````````````````"Y!2$``````````````
M``!;8EIB*D``````3D$``````````%QB````````````````````````````
M````76(``%YB````````````````````````2%L``%-1(DT`````*#T`````
M``!#7B58*C]-6VQ2>D8J10```````$1>``!7,2Y?````````/4H``#%?```M
M.0``?5(``"4X:SH`````6C,```````!<-455``````````!60U)/(3L``'-E
M<F4`````=&4``&1-``!U2```````````````````+S4_1P``=F4````````P
M;````````````````````````````````````````&9E``!I.3$U```\0FAE
M9V5I90``````````35(```````!J84Y0```N30``95$`````2C)K,0``<C%M
M10````!#53!3``!<80```````%UA``!;4@``.3-+,0```````'E-=U5>80``
M-CY]-```7V%<.F!A,CM)0F%A````````;%```#U-`````&)A``!#-4=%8V$`
M````9&$``````````'E3````````````````96$``"U1`````&9A(DX`````
M``````````!G80``0C4``````````&AA53L`````````````1%!@8E@Q9%(`
M````86(`````23Q,2```8V)^;'UL+U\```````!B8CY6?$TF0P```````$-C
M`````%)69V(`````:&(`````1U,`````;&)L/P``;6)E8@````!`,P``````
M`&Y$`````&YB`````$-0``!V.FEB7C<S.RQ,2TMD8F9B:F)K8@```````'=B
M`````'1B=51S8@`````M10``>E5"14`R`````&]B``!R8B]!/$L`````(35Y
M8@```````#$\<6)44#E4=6)6.79B````````4T<`````````````<&(`````
M````````7%<A;0````!X8@``)6U^8E%*```````````````````U00``4#L`
M````5C\``&,Z`````"%+````````)FTC;0`````B;0``````````5CLG;710
M`````"1M7CIW-B%C,C9Q3"<Y```B3R%'`````%(_`````'$V``!Z8GMB?6)\
M8E5$(F,``$%3````````)V-$1P``````````)$\`````*6,W.@``````````
M*&,``%H[```C8P```````"1C*F,``"9C``!R3D93`````#P[`````$-4``!Z
M1``````H;7Q0)6,``'5#```M8R\Q```R8P```````$(\`````"QC/S4`````
M````````````````:4<P8P```````"H^;TT`````````````<SL```````!H
M3``````O8P``,6,``"=/+F,``"E.73L`````````````:S5E/E(R33,``#DQ
M*V-1,BPU7SEH-@````!K3S=C``!,.P````!'2$I0`````````````#AC;C,`
M`````````"EM``!Z4V13````````*FTY8V)2`````````````#5C````````
M``!>4P``````````4#@S8P`````V8U\W```T8R)`````````.F,`````````
M`````````````````````````````````````````#A4````````````````
M`````$@T```[8P``13L``'=)`````&5)````````/40`````````````````
M`"MM``````````!]0@``````````6SLN/P``````````````````/TX`````
M`````#QC```V/P``````````````````````````````````````````````
M````;S$`````=U0`````````````/F,`````````````````````+6T`````
M```````````````````_8RDZ+&T`````/6,`````````````````````````
M`$!C````````````````-CH````````N-@`````````````X4```0S`N;0``
M```````````O;4%```!!8P``````````````````````````````````````
M```````S10````````````````````````````````````!"8P``````````
M`````````````#)<````````````````,&T``&HX``!L3B=J9U!Y2E9(-T])
M,U).9#T`````7F-R.RAJ/54``%U&*6H````````J:@``+&HK:@``+FHM:@``
M````````6#T``"]J```^0@``````````031W-``````G.P````````````!F
M;&5L/S=Y2V(Q``!G;````````$A):&QI;```5DI07D4R>E0`````2T9','(T
M4T@```````!030`````X/P``````````````````6S\`````)$<T5@``*4!1
M7BA);U$D16<P-C-%2`````!B,`````!V-P````!Z10````!S-@``4E50,SP\
M````````+3,``````````'$^43````````````````!64F-*)5<``#9--C8Y
M/UM5```G.%=%````````4EY9/U5"0$<``"0[*#$`````:D4`````>T4G3```
M````````)S$```````!6-0```````"A$``!37CI1:3,``')#`````'<W``!T
M5B,U<#(T1&E$+4!47@``:#!$16!!``!5.0``7#Y834XP``!/359>4#X^5U5>
M4%5=,`````!B1``````C0G`\```U4SE`(44F,G%4`````"A`0TI77GQ5```P
M.0``+4@I2P``65X]/P``````````-$8G5S!*0T0``%8S4CD``````````#A6
M?&HT,```````````9C\`````=$P``````````%I-````````/U9.0@``3DXB
M3"Y04T0R-5A>=54W/%,[`````"0P```R16PT````````<54`````?6H`````
M``````````!:7B9-`````&Q-``````````!F3EQ>```Q329``````#U7``!;
M7D8P-#I327-$:#X``````````#8R`````````````````````$Q`<$L``'$\
M.SLW-0```````'5%``!F7@```````&->73X`````7UX``````````#<T73T`
M````8%YM1```````````1D\``&`U``````````!>-EI*=#5E7@``1E4``&%>
M34Q^1@``144````````T4@``<CX``````````````````%-"```]3#@S``!3
M/0``6#]&35I1:S0``&1>75YG7@``?FH`````,$)B7@````!`5B<U``!T,@``
M:%X``')>`````````````&U>``!Q7@````!@2````````&%7;UYH0V%,``!E
M,@```````#Y2``````````````````!N7@``:UY53@``)S0`````````````
M*S\^/@````!2/0``````````:5X``"Y4``!>7@``:EX``````````#]```!L
M7G,R:3@G0@````!!/0````````````!U7GA>`````"LR)#0`````:C0F20``
M`````````````'9>44L``&,X``!W7GI>``````````!Y7@```````$),``!A
M,&XT````````````````.F4`````````````+U``````:S(``"%K``!T7@``
M``!C27->6C`A4G<Q```O3```````````````````<%X``"1+````````*E4`
M````````````>UX`````````````````````730``"9$````````?5X`````
M`````````````````````'Y#(40A7P``````````````````3$$``'Q>;SX`
M`#)&````````````````````````13-V2``````Z2WY>`````"1?````````
M```R5P`````````````W,P``````````0T$`````2T<E,FDT```K5P``````
M````;$0``")?(U\``"5?```S.@```````"9?``!>0`````!#20``````````
M````````63)F1P``)U\``%Q'```````````H7R)K`````````````%-+````
M````*E\``"E?``!!,@``````````````````````````````````````````
M````````````````````````2D4`````````````````````*U\`````````
M````````````7%0`````````````04@`````````````````````````````
M```L7P````````````!P/@`````M7R=6```````````W:C9K54H``'Q81#@`
M`"4Y`````$4W?E4`````````````2CD`````)U!-=`````!0-0````!T0P``
M2#X````````W:STP`````$P]```R00``5C$H,P```````%(X(DD`````6#8`
M`````````#AK-#X```````!]2@``0T<``'M5`````',W````````````````
M````````````````````````1$X````````K57,Q````````,VQ?,```-6P`
M```````W-@``3T$``'IU,5``````954``%-.`````&\]8C,``"LX```V50``
M/6T``$\V```Y2T)0`````````````````````#TW`````#9L*4H```````!4
M10``.6PX;$-"-VP``````````'U0.FP``#ML95<`````/&P````````];&Q&
M`````````````````````%Y.``!(/`````!52"DU23X\5F=4`````"Y1<5`X
M:CEJ.FHU.@``````````,4IU/P````!Z30````````````!`:@``.C`^:@``
M```E0````````#MJ``!],@``=T-H.P```````%=2=$X_:@```````#QJ````
M````0VH``$=0,U,``````````#HT``!!0W)7``````````!150``1TH``$5J
M`````$1J1VI&:@````````````!G5@``5$\`````2VH``$X[````````````
M``````!Z/4Y)`````$QJ`````#E)?D]*:DY436I/:@````!M30``````````
M26H``$YJ`````&Y.``!>.P``/S,`````````````548P/GI.````````9T<`
M`"<^4&H`````1U8```````!`00```````%U4``!1:@`````^3P``````````
M4FH``````````&Y*```````````O134P`````````````%1J````````````
M````````````4VI?=``````````````Z1``````````````I,0``````````
M7V4``````````%5J````````````````````````````````````````````
M`````````````````````````&]*``!6:E=J6$8`````````````````````
M6&H`````66H````````````````[5```>D<W4GPX`````$)J``!<,@````!\
M0@``>%1F3&Y7``````````````````!"5%!30VMS10``?C<`````5&L`````
M```W2UYK``!*0````````'M-```O,P``6D8```````````````!\:P``/D0`
M`#1.*40^,7U4``!U2@``;%8`````4T9D-@``````````>CL`````8%``````
M,4D``%-4*$@`````2S@``#YH/$D`````.V@``&Y`4U!$,F4T```\:`````!(
M50````````````!%-@``/6AX2EPX=4P````````T0`````!N43]H0F@`````
M/#H``"TQ7#T``#UJ0V@``$9H``!+:```````````3&@``$E+93```"L\````
M`#DY`````$%H``!W30``2F@``````````'9.``````````!M50``5D%$:```
M-D,``'LY)E9(:````````&!*9E0``$!H``!%:$=H```Y1V,W``!):```73]2
M:`````!7:```56A</$\\6V@`````````````````````7F@``%IH>C$`````
M`````````````````````%@P,T1,.&)&/DAA2````````$]H5&A6:```<3E8
M:'57``![1```7&@`````:3(```````!1:`````!M/`````!"/TUH>58``'A!
M<3(`````````````````````7V@``$%*66@``````````"15``!J,3M53FA0
M:#`V4V@``%UH.$```'=*```H2P````!<1G5``````````````&EH````````
M(U```````````````````')H:E8``````````````````&!H86@```````!Y
M44LZ>3@`````<3A45&]H``!N:&QH<#E23&9H)DYR/P``.#!Q:'!H``!`5P``
M9&@``"E-(TD``#@[6SUJ:```````````````````````````8FAC:&5H-35G
M:$5':VAM:#`]+E<``'AH`````````````````````'5H```P379H````````
M````````````````.D$``&AH```W0W`P`````````````````````'1H````
M````=V@````````C.0``````````````````````````4DD```````!.0V!.
M9D```````````'-+``!=3#50`````&%*``!S:```````````````````````
M````;#P``'EH````````````````7D,``&5&``!W.0``````````=#``````
M6%<`````+#P``&]%`````````````$1,`````"9I````````````````````
M```````M20``(FEB0````````$,_````````?FA7.0``>V@``````````"1I
M````````3E(`````````````(VD``#)6-5<``"=I```W/0``````````````
M`````````````````'QH?6@````````A:0````````````````````!630``
M```L4@```````#)I```````````I:0```````"HT```[-``````K:0``````
M```````````````````````````````````````H4``````E:0````!^,P``
M```L:6-````J:0`````Y:0`````X:0``````````+FD`````>F@`````*&D`
M````````````+#\Q:3II`````"5"````````+VD``$4X```M:0``7%,T:35I
M-VD```````!':0```````````````$9`16D`````,&D`````.VEQ,```````
M````````````````````/&DE50`````^:0``/VD```````!!:0````!Q00``
M```V2````````#UI`````````````$)I`````````````````````$-I```S
M:0``-FD``#$[````````0&D```````````````!W/````````$1I1FD`````
M``````````````````````````!*:0``````````3FD`````````````````
M`````````%LR``!(:0``````````````````````````+C<`````````````
M``````````````````!+:4QI````````````````054``"-$````````````
M````6&D``&$Z``````````!):0``(U,```````!4:0``````````````````
M5VE0:0````````````!/:0````!!1P````````````````````!2:0``````
M````````````66E(,P``4VD`````````````<$\```````!-:0``````````
M``````````````````!W,P``````````````````5FD`````6FD````````T
M3````````"U/````````````````````````56D``%QI6VD`````````````
M7FD`````````````````````46D`````````````````````76D``%]I2D,`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#='3C0V.T!0(VP`````-T4``````````````````````````'M3````
M```````D;```)6Q;1@```````&X_```````````F;``````G;"I0```X1P``
M``!H.````````````````````````````````"AL````````````````````
M`#E6?55+-#TR9$YG1@````!A30``````````````````````````````````
M``!U-```0$M?/```````````8FEC:6I196D``'DT9&D``#-18DI0,@``:&D`
M`````````&9I9VD`````,U8```````!I:6II`````````````&MI````````
M`````````````&QI`````````````````````"]L.45.-@``<U(`````````
M`````````&XU``!9.S%L`````&-2`````````````&-.```X1```/T,`````
M/C8Y6$@Q3S%1,7Y%``!0,0``*T,`````````````,54`````````````````
M````)&M!.@```````#I,````````)6L``"=K````````*&L````````F:P``
M````````````````*6LK:RIK`````````````"QK``!/2C58<4,``"5#>$8M
M:TI$```N:R]K,&M5-P```````'HW```Q:V)'```S:P``)#IU43$P,FLT:P``
M`````"HU2$)H1P``-6L``"Y+7V,`````0%,``````````%M9`````"%-+59S
M1P```````&!98SL``#HZ8F,`````````````*T\```````!@8T=)```Y.@``
M`````#1186-J2"\Y+3U8,UM.`````$!,````````:&-I8W1-````````````
M`"U,```S/```:F,``&MC`````%I0````````>T9:-P````!?1TI25DX``&1C
M;&,``'))03,`````9V,`````8T9E8P`````S;69C```````````S20``9D4`
M```````U.0``.T,``&-C/44D05E"5S(``&UC)CLM1```<&-:/@````![8W5C
M4SH``````````%`W35,``$Y64U5!.3156%$``````````#E0=D<````````J
M2#0R``!:0P```````&YC`````'QC;V,H-W=C=&,````````Z-P`````B10``
M=F-=12@R?$8``&!$`````")7``!A0'EC`````'IC?6,I3'-C```^4P``0S$T
M;7%C<F,``'AC.E!#1G-4?F,`````8#T`````)V0`````)F0```````!S42-D
M```I9````````'=(```````````T3P``*&0N9&5"`````#0V````````````
M````<CT``")D`````&DZ*F0`````+&0`````?39>5C)D```M9````````"%D
M``!N.UU-(D=)10````!W00``)&0``#-'+#T]/25D``!'5V(R```K9$,\+V0`
M`&L[,&0H13%D``````````!C52,_```Z9```-V0``#MD`````#UD`````%9&
M`````$8Z2T`````````A.#1D```````````A5``````C.GX]````````/&0`
M````````````/TT`````>40`````>T]F20`````_4P``44\`````,V0``#AD
M.61I3`````````````!.3```5$`U9#!!-F103@``03M3-0``<T@G/4=5+$DB
M.$ID`````$QD1%$`````.E(`````+3H`````5#H```````````````!#9&TU
M````````35=`9'U//V0```````!<04I,``````````!G2@``````````5T0`
M`%1,2&0```````!'9$%D``!$9"TU`````%E3``!&9```````````>5)C-```
M-#L`````;DD``#XT````````;#L``$U1``!M3#5M````````````````````
M`&5'```````````H5```2V155T)D```E/45D`````&93``!)9'A)`````#YD
M`````&53`````'Y'238``'Q4,S)79````````$).``!-9```/$X``%LX````
M`%9D``!*/P```````$Y3``!L0P````````````````````!(15AD````````
M`````````````$1-3V0``````````%1D560``'XZ``!F3P`````_50``````
M`%)D`````````````````````````````%!D`````$YD````````````````
M````````````````````````94TJ2@```````"-````F/5-D`````$@X````
M`````````&=D-%0``````````````````%MD````````;T$`````:60`````
M9U(`````7V0``&!D`````"I/``````````!=2P``6F119```960``%Q(8V0`
M````9T1B9```860```````!\,VAD``````````!A-0```````$Q7````````
M9F0``"P[``!25T],>&L``&1D`````'8Y````````35999%QD>D)>9```2T)$
M0%!"``!U,3),``````````````````````````!.-0``````````;V0`````
M````````````````+T8```````!A1@````!U9``````````````I0@``````
M`&Q`75%N9```````````````````````````+D0```````!M9```````````
M=F1T9'Y"``!=9```<&0``'Y*``!$50````!Q9```````````````````>E$`
M`````````````````&MD;&0```````!R9```*TX`````````````````````
M`````$M%````````,4<``#I"````````:F0```````!*00``````````````
M`#9,,3,```````![9```<V0```````!Z9```?60``'QD````````````````
M``!.,P```````#HS=V0`````>61X9&Q%````````````````````````````
M```````]0```````````:%0`````````````(F4`````````````````````
M````````1#``````)&4`````(V4````````````````D/```)64`````````
M```````A90``````````````````?F1T,0``````````````````````````
M```H90``*64F90```````````````````````````````"=E*F4`````````
M````````````````````````````````````````````````````````````
M``````````````````!91@`````````````````````K92UE````````````
M```````L90`````````````````````````````````````````````O90``
M`````"YE````````````````````````````````````````````````8#D`
M````,&4`````````````````````````````````````,64`````````````
M``````````````````!P.V%L<$,``$8U4CL``````````&E!;E0``$0^````
M````1E<``%944S(^;```````````06H````````O0C8T````````5U$`````
M```T,P``,D@[/T!L`````$M6`````#]L06P`````````````````````````
M`````````$5L9CX_3%I%/#X``$9L``!^,0```````$1L*%5C-0``0FPV06,S
M`````$-L.$M#0'Y,``````````!200``2&P`````````````````````````
M`````````&8Z4T```')6````````3%$``````````#X_```S-U5)1VQB.P``
M3$Q]/4A(```I3P``````````````````:4T``&M%````````:3<`````````
M````````````````````25$X.@````````````!);`````!*;```0#M+;```
M8FPZ,5DW`````````````````````````````#D]````````````````````
M`$QL9E%-;```````````.T@`````````````````````````````````````
M46P``````````%-L``!-.P``93P`````````````````````````````````
M`$]L```W20`````````````Z0P``8VQ555!L`````````````'-6````````
M4FQ.;```````````5&P``%5L`````#])````````````````*$\`````````
M````7%```````````"Q1``````````!;2````````%9L=4X`````````````
M;$I:;```````````````````66P````````^,````````````````%=L``!8
M;````````&1L````````````````````````/$@`````````````````````
M`````$=!`````````````%QL8%$``````````````````````````%ML````
M``````!O5```76P```````````````!&6P``````````````````````````
M7FP````````````````````````````````L,0``````````````````````
M````````````````````````````````````7VP`````````````````````
M`````&!L```F5P``0$4````````\:RXP````````=#XX."]25C!Y-0``,U@`
M`"Q+``!=8P``````````````````+$9F,````````$9%.6L``````````#IK
M````````.VL`````0%$``"-%``!R:@``,D0``#5$3D````````!S:D%$``!O
M3@``````````<&IT:@````!\20`````C1P```````%A,?DX```````!U:G9J
M+$]G0`````!W:@`````````````_-GAJ``!Y:@``>FH`````>VH`````````
M``````````````````````!Q:@```````````````````````````````"Y(
M:V$``#@W;&$```````!M80``-%=N86]A3%,``````````````````'%A<3]P
M85(U````````-S$``````````'-A<F$``'PZ``!T80``````````-SD``%$^
M``````````!\1```73I&/0```````````````'5A=V$`````0#9!3RA*=F%X
M57Q3>&%\87EA`````'IA:D```'YA(6)'0```````````>V$``'UA````````
M````````)6(```````!400``````````(V(``"AB?C(B8@```````$U#0C(G
M8B9B`````"1B*6(`````*V(```````!)4&U6*$,L8@``5T\`````+F(`````
M;SH`````8&DM8BIB```````````K.S-4````````````````````````````
M```````P8@`````O8@``86D``````````#%B`````````````````````#)B
M`````````````````````````````#-B(4P``#1B````````````````````
M`````````````````#5B`````````````'Y0`````$I"``!Q4P``=4T`````
M8&<`````86<``````````$$^``````````!J0@```````&1G`````&-G````
M````````````9DT``#5#`````&)G-SM63P``84%I9P```````&AG`````'1G
M(S(``````````&IG``!F9P````````````!L9VMG.DD`````9%4``&5G*3=G
M9P``````````````````;F<``````````'-G``!I5@``````````;6<``')G
M``!Q9P```````&`P``````````!U9P``````````````````````````````
M````````````<D<``$5`;4``````<$%P9P``````````=F=V2P``````````
M`````````````")H(6@```````````````!!5P````!Z9WEG``![9P``=V<`
M`'YG``!]9P``?&<`````54%91WU%0T4`````````````;4<``````````"-H
M```````````````````````````````````````````````````F:```)6@`
M`"=H=SIX9R1H``!P2"I)```````````````````````````````````I:```
M``!E.0````````````!^42AH````````````````*F@``"UH+F@``"=!````
M````+V@````````P:``````L:```-&@`````````````````````````````
M*V@``#%H`````````````````````#5H,F@S:```````````````````````
M````````````````````-V@`````````````````````````````````````
M````````````````````````-F@```````````````````````!/.0``+'``
M`"UP```P1FHP/T@``%]-``````````````````!-3C%J```````````R:@``
M/T9)-```````````````````,VH``````````&=5````````````````````
M`'E=```T:@``-6H``#9J``````````!*.#!?=4D``'!,`````'I)````````
M`````'M)`````$-3)DL``"8X+G!",0``.&5O3$E35SQJ20``9S4``%!$:34`
M`"YN+3L`````7F<``"]N```````````I,P`````R;@`````Q;F<]```P;C=.
M``````````!/10``````````=$%.6S-N<U``````````````````````5$)H
M1@```````"PW```````````````````T;@``:S,```````![.S5N````````
M`````%QG````````-FX`````+CT``````````&)Q````````:$H``$E26G``
M`%MP``!<<$9!``!M.$X^`````%YP```Q15UP<5$``&!P3#!J/0``````````
M``!?4E]P```O-&@W9G!E<"-&87!B<$,T`````&-P;E4`````6TQ2/C(\````
M````:'!G<&1P(3(``")6.%,W/BQ(`````&IP``````````!W40``3%9;.FEP
M```[-@`````T30`````F1@```````"%!:W!N<```;7!P<&QP```^.V]P````
M```````U3')P`````%4S``````````!4,0````!S<`````!T<'9P830``'%P
M``!W<```````````>G```'AP````````=7```````````'UP``!Y<'QP?G``
M`"%Q````````04XD<0``(W$``'9!>W!=2@````!Q-'$Q,4P``"9Q`````"=Q
M`````"QQ3E4I<0`````S2````````")Q```K<2AQ)7$`````*G$`````````
M````````````*3`M<0```````````````"]Q```Q<0`````````````P<0``
M+G$``````````")1```````````````````R<0```````#-Q````````````
M`````````&\Y`````$<U``!7,%DP````````;50``$0U``!4/4H[)W``````
M7C@`````*'``````*#```"EP`````&Y-`````"IP````````````````````
M```````K<````````````````````````"1&`````&569'$``&5Q````````
M``````````````````!S0P````!;4P````!15FA%```O4P``9E(`````06X[
M,#553E%@/%`Z``!X/P``1SA!-4Q%`````")*````````2T,`````````````
M0FX`````````````````````/T0B-@``;&TD0P``,58```````!@3V]M````
M`$Y%``!<-@`````A2@````!M;0````!P;7%M/$,``#0_``!N;0``````````
M``````````````````!T;7)M``````````!F55]#``!S;0```````'9M```C
M52-1````````=6T``%!#`````````````'=M=#]L/GAM``!W3```6U$`````
M``!%5W95``!\;0```````'MM`````````````````````'EM>FT`````````
M````````````?6TF/@`````````````O2R%N/38``")N0$0``'YM`````%X]
M1S(```````````````````````````````!#-@```````"5N.E@C;B9N````
M````:4-R,P```````````````"=N)&XY3P`````H;G="````````````````
M````````````````*6XJ;@``*UX`````,T8``$9'``!U5DDU```R2P``````
M`"MN`````"M-```L;@`````````````P50``+6X``$1V````````````````
M``````````````````!'6P```````````````````````",T````````+$-F
M<0`````````````X2E-2```J5@``<F\``%@^``!#/7-O3#8K,```````````
M+TH`````-FT``#=M``````````!Y3B\W<S\X;6M",$D````````````````Y
M;0````!V1C,_````````/&UX10``4%$``"E7.FT[;0``8E$``#]M0&T``$1M
M````````2&T``$9M3FUH50``26T`````1VT^;0````!I10```````$9&````
M`&E)4E1!;4)M0VU%;0``>4```"$T``````````!H.0``4&T``````````%%M
M``!*;0``3VT``'A.`````#9+3&U-;0````````````!U3P``````````````
M`````````````````%)M<D$R4TMM-T@`````````````````````;SP`````
M`````'!%``````````````````````````!6;0``;S4`````-4(M,&E+````
M`"XQ``!4;0```````&M-8C4``%5M4VU7;0````!Z-0``6&T``%EM``!<;0``
M3#$`````````````````````=D5N/%IM/$QJ,@``````````6VT`````````
M`&M$`````$4T````````=3````````!?;5I`:#0``````````$U%````````
M76U$/P```````%YM`````````````````````````````````````"5$````
M````8&T`````````````86T``&-M`````%=!`````$<[````````````````
M.#T```````!B;0``````````````````````````````````9&T`````````
M`````````````````&9M`````````````&5M````````````````````````
M````````````````9VT`````````````/DIJ;'%```!G20``:VQN1@``````
M````;&P``&U&;6P```````````````````````!P;`````!F5W-L`````'%L
M;FQO;"-7<4EN2W1L``!R;`````!I3P``=FPQ1@``````````0#P``'5L````
M```````````````[-78[``!W;`````````````!W67L]`````#M">&P`````
M`````'EL```````````C.```````````````````````````>FP`````````
M``````````````````````![;`````````````````````````````!\;```
M``````````!M4RY8:T```%U'3#H``&-0/4L``#I-`````%$X`````'PQ``!O
M1P``5E8```````!&/VM#`````'5O`````%A#````````````````8E<`````
M``!W;U,S``!81VU1``!(5@``>&\``'9O``!].T8S``````````````````!5
M/0````!&4@``8#L`````(4\``'QO>V\`````>6\``````````$PS``!423!+
M`````````````'YO`````%XP`````$E6````````?6\``&TS`````%5V````
M````````````````````````````````````2$X````````B<```(7```#XU
M6CQ\.P``93@```````````````!"1```````````````````````````(W``
M````````````:TL`````````````````````````````````````````````
M```````````````````F<````````"A1```_/FY'-G$W<54_```````````I
M-#AQ.TT``%1'+54``#EQ```Z<0``````````3T<````````D4D]6`````#MQ
M43TP-#T^````````7#113@``7S\]<0``````````>C\\<0``/W$````````^
M<4!Q`````````````$%Q`````````````````````````````'Y!````````
M`````````````````````")!``````````````````````````!Z2@`````^
M50``````````.CXY/D)5`````"(_```O335Q````````````````7ST``$LV
M````````````````````````<59#<P````!$<P``33@```````!&<T=S``!*
M,```17,``$ES<4L```````!+<P``)E``````2C%(<P```````$]S``!1-0``
M``!7<P``4G,```````!4<U-S>S<``#\Q``!.<TIS6C4``%!S`````%%S``!5
M<P``````````37,``&,\``!]00``5G,```````````````!:<P``3',``$@U
M``!N/5QS`````"0W<#]^5C)-``!P-```7S(``%AS``!9<SA)``!=<P````!>
M<P``87,`````````````````````````````7W,`````8W-B<P````!;<P``
M:C\``&\S``!@<P`````I1P``<CP``````````&MS```````````````````_
M.0````!D<P```````"TR?CL``&-+``````````!M<VES````````7#EN<P``
M`````&5S9G-J<V%";'-O<VAS?3P```````!D3P````!P<P```````&=S````
M`````````````````')S```````````M5RI&``````````!S<P``````````
M<7,``"A"`````````````%TX=7,`````=',```````!;-````````'9S=W,`
M``````!X<P```````#I``````&E``````````````'%%``````````![<P``
M>G,`````````````````````6#0```````!^<WES`````'QS````````````
M````?7,`````````````````````(70````````````````C=$D[`````")T
M```````````````````````````````````D=````````````````#XR)G0E
M=``````````````````````````````N/```````````````````````````
M````````````````````````````````````````````````````````````
M````````````5T-A60```````````````&!`3'115P``````````````````
M``````````!;-P``````````````````3G0C00````!)1@``5C0S50``````
M`%!T3W11=%I+`````%)T``!!5&!6``````````!@-P```````#A!`````#M!
M4W0L/@````````````!B-`````!4=%5T*SX`````5G0```````!;=```5W1:
M=```?3H``%AT670``````````````````&(X1TQ<=```6C(`````4T,`````
M8U0W/P``````````````````770````````````````T10``````````````
M``````!I=``````U3P````````````````````````````````````!)3@``
M`````````````````````````````````````````````````````%A+``!W
M2P``````````=#T```````!/5P```````%M`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'50`````````````````````&IT````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!K=```````
M````````````;'0`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````8W<`````````````,3<`````````````
M;70`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````&M7````````````````````
M````````````````````````````````````````````;G0```````!Y9D`^
M>F9L.GMF2T]\9CQ4-CQ]9GYF33Q22#-.(6<``#\T(F<T25DX240``%U76D)7
M-SU61DY$-P`````F12-G7T\D9R5G)F<W06E7<$DX3R]6558G9VTP*&<I9UQ)
M;U(M/BIG<S!>2&$]*V=&2```+&=F.W@X)%$M9V=">#Y*/3--+F<O9VX^95``
M`&=+4$Q,/#!G*#QW4#%G``!X4#)G,V="-#1G-6=^22Q.8$,W9T$Q<3,``#AG
M.6=;5T!5.F=,0CI7.V<\9SUG:CQE0T)`/F<_9RD\``!`9T%G-F=0-D)G``!#
M9T1G.CM>-49"8#%%9S541F<_.$AG1V=L-P``26=X,DIG2V=,9TUG3F=/9U!G
M)U-U2U%G4F=39U1G24E59U9G5V=89UEG23U:9SYS``!7.```,4@`````````
M`````````#]S``!`<T%S``````````````````````````!>.7A-`````&A8
M,3H``%Y"-VX``",W```````````Y;@``.&Y5,``````````````[;E95;U<`
M``````!#5@`````];G!*```\;@``````````/FX``````````$!N`````#]N
M`````````````````````')1```\1P``0$,`````````````83@`````````
M````9T$`````1G1?4$=T``!;3P`````Z2`````!(=```````````````````
M271*=```2W0`````````````>EE^.`````!Q97!3``!@=```3$X```````!A
M,P``````````-'$``&Y2``!A=`````````````!H3V)T`````$Q'````````
M````````5#5D-&1T````````8W1E=`````!F=```````````9W0``#(Z/S``
M`&AT```````````````````M-VU2````````*U)/0```/#\C:U]52&H`````
M`````'-Q>#8C2P````!-1```9W$``&AQ>SAI<40Z1512,`````!J<0``````
M`&MQ``!L<0````!M<6YQ;W%Q<7!Q544```````````````!R<0``>C8``'1Q
M+E)'7DI+`````%PS```B-0``(CD`````=$1U<0````!V<0```````$1!>T$P
M5G=Q``````````!X<0``*D$````````X1@``6SX`````````````````````
M````````````````>7%/-````````````````'IQ````````````````````
M```````````````R;3%M`````&!+7E(``$%+6%4``&)(``!?0"$\````````
M````````06L`````)%```&)6``!'-E@X0&M..```/VLF,TDY*U8``'0W2C<`
M``````!G/#XW1FL``$=K.3!//P``16M]4P``2&L`````26L`````3C<``$)K
M1&MV25=6354R4$]K.$Y0:P``*#4`````````````,S%2:R5,````````````
M``````!615-K``!1:U]%3FLD2E5K>S``````>CH`````-UAC<0``2FM+:TQK
M36M6:T!F66L``&@_2%)7:UQK;#A8:P``.CT``%A0```W,```76M<1```````
M````+%8```````!@-`````!V0CD\`````%IK6VM@5&I&5$1?:R=%=5D``#$R
M``!D:P``13T```````!B:P``````````````````````````````````8VL`
M````+#@``%%-96L```````!A:P``,T$`````````````(D8`````````````
M`````'-,``!F:P``,$`X4F=K````````+S@M.```:&L[1W--````````:FMK
M:P````````````!M:P``````````2%```')K``!N:P```````'%K>4@``'Q1
M;&L`````:6L``````````#DX64]E1&]K<&M:3$A-<C```'9K````````````
M`'5K```R,@``````````8#@``'=K````````````````;#$`````14PD1"5/
M`````````````'EK`````")L``!R10``>FL`````````````````````14D`
M``````````````!?8GYK``````````!.32%L6S$W4P````!<4@```````'UK
M``![:P``````````````````````````````````````````````````````
M````/#,````````P:@````!45P``*W1T,P````````````!!5D)6````````
M````````:55*/@``)W0``"A2*'0I=```*G1+/E]3`````````````&!)84D`
M````0G,``&9*``!R3````````````````#9B-$L``&A.6U8``"UT+G0O=```
M````````,G0``#TZ,W1C,#!T```Q="(]53(``#9T-W1F-C`R3T\T="PT```U
M=``````X=``````````````Y=``````G30``.G0``#MT````````/'0`````
M````````````````4DL``#UT```````````^=``````````````````````_
M=`````````````!>=#Q!:#P``"M)7E%U90``````````,UQ54@`````T7"PP
M-5P`````6CT``#E<````````0E@``#=<<U,``%9).EPV7```.UPB0P``````
M````/%Q%7#U<`````%].)58``$]<``!-7`````!27&8]*T(``#A<2UQ.7#Y<
M4C=%,$=</E!!7"@[```\-TQ<`````$9</UQ;1P```````#]10%P`````2EP`
M````4%P`````+4Y"7```0UQ(7$E<5#)17%5+```W5%M<7UPF3&9<``!G0UQ<
M`````$$_65P``'HP-CEE7%-<``!$7%9<=$A@/P``````````.TD````````]
M,0``(E,`````6EP`````55P``#M&``!>7`````````````!"5R]#-C=11RE#
M8EQ87&M<5%P`````75P``"4^5UP``&!<`````&-<9%P``'A<`````&%<(EUG
M7```````````````````````````:SQ$-``````C0V<R>EP``')<``!O7```
M?%QN7'!2:#(``%=(8TA[7```;5P```````!W7`````!U7``````C/G1<``!=
M,@````````````!S7'8\:%Q$.P``<T``````````````5#QI7&I<``!Q7'9<
M>5PT-0``64AG.WY<?5PK4R%=(UTE77%2)%TF72==*5(`````````````````
M`$DZ*5T`````-ETQ731=```````````````````P74Y&`````')`````````
M```O20```````&Q<+ET``````````#==`````'!<+UT``#A=```L70``````
M````````````.5TS72U=*D0``````````"A=,T`K02I=*UT``#)=<3LU72A3
M.ET``#M=)T,`````4ET\70```````%%=```].0````!5/@``>CX`````2CH`
M`````````$I=``!%70``/UT```````!+,D-=``!+720R55T````````^70``
M`````%!&4%T`````````````5%UB048W`````````````$Y=3UT```````!$
M70```````#U=``!-75%,``!)70``````````0EU(0SQ&+DY,70``2%T`````
M``````````!!70```````$9=7$(````````````````I4RI34UUT3WA(````
M`````````````````&9=````````````````1UT```````!@761"````````
M`````````````&%=``````````````````````````!770````````````!X
M5@``65U877`X5ET``````````$]&```M-@````````````!B70``>3IA5&==
M````````4#0``%I=``![/V-=``!?70``75T``````````````````%DU````
M``````!;75Q=7ET``"\]9%T``&5=`````````````````````'5=``!)0P``
M``!B2P``````````<ET``````````````````````````````````&%8````
M`%%&``!T70```````'15<UUP70````!L70``;UT``&A=`````&Y0````````
M``!82&Y=`````&E=`````&I=<DL``&U=`````$TQ````````````````-D``
M`#L\<5T`````=UT``'9=:UT`````````````;D4```````![70``````````
M```````````````````D7@`````C7@``````````````````````````````
M`'A=``````````!O0P``>T(```````!A50`````U3@``````````?5T``$PR
M````````````````````````:$1?2@``````````````````````````/D=Z
M77Q=?ETB7BHP3C$`````````````+%X``````````"9>-CUO2```````````
M```````````````````A7@`````E7@``````````*5X`````````````*%X`
M```````G7@```````````````````````"U>``!,5```````````,UXJ7BY>
M`````%E``````````````"$Q-EX``#%>```````````````````R7@``````
M```````````````````````F435>```````````````````O7@```````#!>
M```]4````````#1>;4HY7@```````````````#A>```W7@``````````````
M````.UX``````````````````&4]`````````````%@R:D,`````.EX``#I%
M````````````````/%X``````````````````%E,```````````J-P``````
M``````````````````````````````````````!E5````````#U>````````
M`````#]>`````````````````````````````")$``````````!!7@``````
M````````````````````````````````````/EX``$!>````````````````
M`````````````````````#I5````````0EX`````````````````````````
M`````````````````"YR(CLR0C!%1T(`````+W(`````````````:5``````
M``!=4P```````#UK`````````````````````&8S,'(``#%R`````"U*````
M``````````````!G.C-R-7(T<F1+.D\R<C1*3U)L0@``````````````````
M0TXX<G8P-W(`````````````/G(``$\R````````````````05$Z<@``````
M```````\<FE4`````#MR-G(_<CUR```Y<@````!'<D1R1G(`````2G)"<D!R
M````````17(`````````````>U8```````!!<@``>4=?20``2')&.3`U````
M`$-R27)0<E9R`````%<[````````57)<30``:U8`````4G)4<@``````````
M<C@``````````$MR````````3G)Y0@``755,<DUR3W)3<@```````%ER/%,`
M`````````&HV``!Q2@``9#=7<@```````%AR6G)=<EMR`````%QR````````
M``!145%R``!)30``3TXI5@``8W(``%M#``!@<@`````O0&QR7G(``&%R````
M````:'(``````````&)R`````&=R`````&9R`````&ER````````7W(`````
M9')J<@``````````````````+%-E<G4R`````')R```K4```````````=7(`
M``````!(.P``>7(```````````````!P<@````!V<GAR>G(`````````````
M````````<W(``'%R````````>SH``'LU``````````!O<G=R;7)N<@``````
M`&MR)G,``"-S`````")S`````'1R``!:2`````````````![<@```````"5S
M``````````````````!X0P````````````````````!]<@`````G<RES)',`
M`'QR````````*W,``"IS``````````!=0@`````N<P`````P<P``````````
M```A<P```````#%S+',`````````````+W-^<BUS```````````````````R
M<P``````````-',``````````"AS```````````S<P```````#5S````````
M```````````````````W4```````````.',``````````'E9````````````
M````.7,`````````````````````-W,``&1(-G,``````````#IS````````
M`````#MS0#0```````````````````````````````````````!#;@``````
M`````````#QS`````#US````````*E$````````L=$90````````````````
M4%!<40```````````````$Y/`````%8]``!#40``````````````````8CII
M84)20G$Y,@````!M,4-Q``!`240S``!R60``)4L``$1Q``````````!45@``
M``````````!%<4!T1G$``"Q41W$``$`P070`````0G0`````?#0``%M%````
M```````[3````````&10`````````````&!-`````````````$AQ``!S60``
M`````````````#LQ```N3P```````"0X`````````````$IQ``````````!+
M<0``````````0S)100`````P5TEQ`````$QQ``````````!.<0```````'99
M``!A4B-4`````$-T.4@`````````````1'0`````37%/<6,_4'$`````5'$`
M`````````````````%9Q47$``%%)844```````!C0GPY`````%-Q``!5<0``
M`````%,Y``````````````````!;<0````````````!6.@``?3!9<0``````
M``````!8<5)Q6G$`````````````5W$```````!L2```````````2DU=<0``
M````````/64```````!<<0``7G$``````````````````````````%]Q````
M`&5/````````````````````````````````````````````````````````
M``````````!%=',]````````````````8'$`````````````````````````
M````````````````````````````87$```````!W3@``*E(``'MQ`````#(X
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````![/%LY``!F.5E#4TIH:D!`=3YI
M:FIJ:VH``&QJ;6IN:F]J1ST```````![=0```````'UU``!^=0``?'4`````
M`````&(]```A=B4T```````````B=@```````"-V````````,FP`````````
M``````````````````````!440```````````````&I9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````)'8````````````````````````Z;@``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#)5````````````
M````````````````````````````?E-<3`````````````````````!$2@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````0&4`````````````````````````````````````````````````````
M```````````````````````````E=@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"\^`````````````"E&````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````)5I&/"DV
M/#A/2"4\)EHG6E9,0T@H6GU&```U46E2-E%'/```,CUD.RE:*EI(42M:;5!O
M-EM"``!/2VTW:$E#-W<^)%8L6BU:0$9G5S9*```I55]+;U4N6E]62C0P6B]:
M``!K4C%:,EHS6E1*-%HK2C5:-EI/,V]6-UHP.RXU.%HY6FXY+U%H4CI:0SAJ
M3V\R.UH\6@``:SU<3F]3/5IS3CY:55-E.S]:-4M02T!::T=N5D%:-45!-D):
M3#=./T-:1%HM2T5:=S5&6D)!.U='6CA,``!J4C%$2%I]-5$[25HS4$I:2UH]
M3DQ:35I.6G<R45I/6FA14%I50U):``!36E1:55H[4"52>3!66BM'5UIW/2%#
M6%I96GU#-TQ:6EM:/D!71EQ:75HT1UY:7UI(.0``````````````````````
M`&T[```````````Y-GAT``!Y=`````!C30`````````````````````Y=0``
M````````8&L```````````````!S3S\[``````````````````!`.B54````
M``````````````!980``````````='4J,7(R``````````````````!U=0``
M``!W=0```````%$Z=G4``#)#``````````````````!Y=0```````'AU````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````-#%J53HX```Q
M.48R<%1-3UPP2U5U.TI6-S<P3#9&83$Z.7Q683DA-WH\6FI;:GE,<SE<:GLT
M,T-1-U@Z76IT5%YJ5CQ?.U]J7D$X0E]42E=@:F%J9&IB:F-J7DDS.$0V96IJ
M2DU)330`````66)B169J-4```#A79VHL5WQ(4UA-6%Y4``!Y5$1)+E-3.&`S
M``!B279T````````53H``'=T`````%]7`````'%T,#A454\X<$8`````````
M``````````````!#,P````!R="PS```````````]5'='`````````````'1T
M`````'-T``````````````````````````!+3````````"1(````````````
M``````````````````````!U=```8U<_14!U`````#MU``!#=0``0G4``#I6
M074````````^5$1U``!,=0``````````3S!X-0``275*=0``7$4`````````
M`$5U1G4`````1W5+=0``8#Y(=7HX````````4'53=0```````&<_``!R.3QU
M374`````-T(```````!X3```>3P``$YU3W51=64V4G4``%5U````````````
M```````]=0```````%1U.U,``&PS`````"1,``````````!6=0``````````
M``````````!7=6$^6'4`````7TQ;=0````````````!(,EE7``!9=0``6G5<
M=0``8G4```````!@=0```````%]U774`````874`````7G5D=65U``!C3```
M```_93@U8W5H=2-,`````````````&9U9W4````````````````^=0``````
M`````````````````````````$0Q`````#]U`````$4U9#(``&QU:74``%<V
M``!M=0``:G4`````````````:W4`````6C0``&I4````````;G4``'DS````
M``````````````!O=7%U````````<'4``````````````````')U``!S=0``
M`````````````````````````````&U)*CD`````>T<`````8S8`````````
M`````````$E,````````````````````````````````````````````````
M```F:@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````-3-^5&PY>5``
M`&UI*E=N:59";4AD.F]I<&EQ:6%6<FES:75I=&EV:7=I84=X:5A4>6E./0``
M>FE[:4\]?&DH.#Y!?6DR,50[=3E^:0``(6HB:B-J>#<M/```9$I.8"]4/4\W
M521J7E4E:D%0/#D``$<T63$````````Q0```````````9C%G,0``:#$`````
M`````#TS:$@``````````$%E`````%\Q````````24%O-``````H1UA3``!Y
M1CA1``!].75"`````````````"U3``!+5'P]``!"934W0V4`````.3MB50``
M>#TV5"5.+$%9,P````!V3```1F5$94AE``!*94=E3S5(1@``?#5%90``=DH`
M````264```````!40T4Q(SP````````W5P````!+34U+2DI33$QE2V5F1```
M```A43=1364``%!E```X37!63V5=-0``/DT``%%E.C8`````*$UD.0``14I1
M,UE+;%1296HW````````3F4```````````````!597XT5F4`````````````
M4V5490``75(`````7T)&,0``8E,`````739L2P``5V4`````=E,`````````
M````:3$``'0V6F5895EE0#4```````!%4EQE`````%YE````````````````
M764R1P``(U(`````6V4``````````&)46E4`````````````8&5Q5P``````
M````````````864``%PQ>U$``&)E9&4``````````&-E`````&5E````````
M`````%A2``!+-0``7V<``'5:``!X6@``=EH``'=:````````>EI/4$=$````
M`&XP````````,%```'E:``!*4RHZ(EMQ1P``?%I[6EM)?5H``"%;7E=^6EI!
M`````"5;`````'13`````"=;)%L``"A;`````#P]````````24`C6R9;(U8`
M`"E;````````+5L````````N6RQ;0CH````````D/RM;````````*EM'5#\R
M`````"];``!Y.0``,%L``````````#LS````````)C4``````````#PV,5L`
M``````!U-@``,EL`````````````````````````````````````````````
M````````23$``````````#1;````````,ULU6P``````````````````````
M```````W6P``-EL``````````````````#A;````````````````````````
M.5L`````.EL`````3U-Z='5'0U=D17QT?71[=```1CX``````````&]0````
M`%,W`````$U4*DP`````(G4A=2@Z?G162P```````"1U4D```&HS```J325U
M(W4T/2AU```I=4T].$-A/V%+*G4````````F=2=U<$0`````````````+'4`
M`#PT``!M5P``5S0K=2YU`````"UU+W514```````````````````44,I2```
M`````````````#!U,74````````````````R=0`````S=31U-74`````````
M`#=U-G4``````````#AU````````````````````````````````23(``%13
M34H``&]`6%8P4C]!``!P/0``````````````````````````*C@`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'@\````````````````````````
M``````````````````````````````````````````!&=@``````````````
M````````````````````````````````````````````````````````````
M````````1W8`````````````````````````````````````````````````
M`````````````````$AV````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````278`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$IV````````````````````````````
M````````````````````````````````````````````````````````````
M````````3'8`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$MV````````````
M`````````````````&EW````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!-=@``
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!.=@``
M````````````````````````````````````````````````````````````
M````1&Y%;D9N:U4D-DAN1VY);DIN)4=+;DQN```P-W8U36Y/;@``3FX``$8X
M4&Y1;E)N6S8N,U-61D0U,58X4VY4;C]454=[/EE.,SE6;E5N6&Y7;B5%66Y:
M;BY'6VXO1UQN)S)=;EYN7VY@;F%N:E=B;F-N6#QD;DM3>DPL,F5!96XF1RU#
M``!F;F=N:&YI;FIN:VYL;@``;6YN;F]N`````'!N<6YR;G1N<VX``'5N+4U!
M0G9N=VYX;B%5>6XS3WIN>VX``'QN?6XA;WYN(F]U.'I#(V\D;T(]/U)Y,B5O
M)F\G;WA2*&]]5BEO3$8``"IO*V\T02QO>D]X2RYO+6]Z,W@Y+V\P;V)0,6\R
M;V8W/U`S;S1O-6]Q2&!,-F\W;SAO.6\Z;V!5.V]M-"I#/&\``#UO/F\_;P``
M?4Y`;V!".#0V5W4]``!'3T-O06]";T1O)S9\/&(^3$-%;T9O``!';T]O2&])
M;TIO0D=Q;TTV2V\``$QO36]&-CY#3F\``%!O46]2;W)5``!3;W=$``!4;WA$
M56]6;V0X=S!7;UAO66\``%IO6V]<;UUO``!>;S4^86]?;V!O``!B;V-O34%D
M;V5O9F]G;VAO:6]J;VMO;&]80```;6\M06YO;V]P;P````!B3P``````````
M```````````D,P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!%0T5C04E&
M8P``53%*3C,T<DA'8U!/2&-D/$EC2F-&0R)55D1K.45.2V-V0TQC```G-W,X
M4CI-8TYC1%1/8P``4&-+45%C4F-38U1C5E%58WLR.T!68P``*T!78UAC66,`
M`%IC6V,``#<X8EH``%,V``!D6F-:``````````````````!F6@```````&Y(
M`````&5:0#=T4752<U57/0``````````:%=H6F=:```B,%--``!I6@``/3A*
M/#U")$)",VI:```J0C!$-3T`````7D\```````!K6D))`````````````%TQ
M````````;%H``#@V.E0``'TS`````&U:25153V-%``!N6@````````````!O
M6@``<%IJ055,74\``````````````````````````````````&=3(4(``'%:
M`````&5+``!R6@``9DM^4@```````'0X`````'-:+S`V3P````!/50``````
M````````````````````;4L`````````````````````=%H`````1&,`````
M)4$`````/W8`````0'9!=E%$```X2&-1`````%M015$O/$TY``!T;P````!&
M-#I30G9[,P````!#=@````!Q-0``````````````````````````178`````
M`````````````&I3)W8I40``````````*78````````H=@````!C05=````B
M,0``````````;4X``&A0*W8`````=D\``"IV<%4L=CE#````````=#LN=BUV
M````````7D0`````6$$`````````````*DL``#Q/````````````````````
M`````````"]V`````#!V`````#%V```V0@````````````!4,'E%````````
M```R=@``````````````````````````````````````````````````8$<F
M=@`````X/@`````R/@``934`````1S<``#\_4D-F0P````!,6````````&\X
M````````````````````````>3TE40``4#``````````````,'<`````````
M````````````,7<`````````````+%```#`P````````,G<S=P``-'<`````
M``!*1P``````````````````3SX`````-W<``````````````````#9W``!>
M,0``-7<`````.'<``#EW````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````D3DU(```K.CAH.6@Z:$(^````````
M`````'12``!/5%A)````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````,U(E-FI'
M?'%N3S-+:U!O9V=-2SE9-GUQ9#!,2WYQ)%0M0FQ!1$8Q/B%R53P``")R(W(`
M`"1R0U(U1@``1TTE<@``,5-%/V),```F<B=R55%N-BAR*7)?-2IR*W(``'PR
M+'(M<B=(````````````````````````````````````````````````````
M`````````````````````````````````````````````````&<W`````"EL
M*FPK;```+&P`````+D8M;"YL````````23<S2@``````````````````.&)/
M=P``````````````````````````````````````````````````````````
M`````````````````````````````````````%!W`````$TR````````````
M````````````````````````````````````````````````````````````
M`````%%W````````````````````````````````````````````````````
M``````````````````````````````````````````````!3=U)W````````
M```````````````````````````[8@``(CP``#QB/6(^8C]B0&)!8CDW>U(D
M/4Y*)3%'2P``0F)\-D1(0V(`````2#T``'TQ1&(``'8V16)91`````!&8EI/
M73E'8B%```!(8G8R``!)8@``<T%*8DMB>$),8DUB3F)72CA895EC3P``````
M```````````````````````E<``````P7```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&U")E1433%16S-]1P``-3(_0F!F.TIA9F)F5#YC9B1754UE
M9ET\9&9F9F=F;D(``#X]:&9F0B<Z:68``&IF4C-I40`````E/VMF;T9L9FUF
M`````&YF+49O9@``)TEP9G%F<F8Y97-F=&9B0G5F=F9H5G=F``!X9D<Y````
M```````````````[=SIW```````````^=SQW(3H``#]W``!`=P```````$)W
M07=$=P````!#=P````````````!%=T9W``````````!'=P``:$L`````````
M`%\X````````````````5'<``%5W``````````!6=P``````````6'<``%IW
M``!7=P```````````````````````%MW``!9=P``````````````````5U<`
M`````````%QW````````````````77<```````!>=P``````````````````
M``````````!?=P```````&!W`````````````````````````````$M;````
M`"I8`````````````````````'=E;3D``````````'T_:CM)=T=&2'<``$IW
M3'=+=P```````$UW```Z3@``3G<`````)T1E(F8B9R)H(FDB:B)K(FPB;2)N
M(@``(2$B(2,A*"$``"DA`````#0A-2$V(3<A."$Y(3HA.R$^(3\A``!^(3(A
M,R$\(3TA````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"$D
M(B0C)"0D)20F)"<D*"0I)"HD*R0L)"TD+B0O)#`D,20R)#,D-"0U)#8D-R0X
M)#DD.B0[)#PD/20^)#\D0"1!)$(D0R1$)$4D1B1')$@D221*)$LD3"1-)$XD
M3R10)%$D4B13)%0D5216)%<D6"19)%HD6R1<)%TD7B1?)&`D821B)&,D9"1E
M)&8D9R1H)&DD:B1K)&PD;21N)&\D<"1Q)'(D<R0`````````````````````
M`````````````"$E(B4C)20E)24F)2<E*"4I)2HE*R4L)2TE+B4O)3`E,24R
M)3,E-"4U)38E-R4X)3DE.B4[)3PE/24^)3\E0"5!)4(E0R5$)44E1B5')4@E
M225*)4LE3"5-)4XE3R50)5$E4B53)50E5256)5<E6"59)5HE6R5<)5TE7B5?
M)6`E825B)6,E9"5E)68E9R5H)6DE:B5K)6PE;25N)6\E<"5Q)7(E<R5T)74E
M=B4``````````"0A````````````````````````12A&*$<H2"A)*$HH2RA,
M*$TH3BA/*%`H42A2*%,H5"A5*%8H5RA8*%DH6BA;*%PH72A>*%\H8"AA*&(H
M8RAD*&4H9BAG*&@H:2@```````````````!9(EHB6R)<(ETB7B)?(F`B82)B
M(@``````````````````````````12)&(D<B2"))(DHB2R),(DTB3B)/(E`B
M42)2(E,B5")5(E8B5R)8(C$B,B(S(C0B-2(V(C<B."(Y(CHB.R(\(CTB/B(_
M(D`B02)"(D,B1"(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"0I)2DF*2<I*"DI*2HI
M*RDL*2TI+BDO*3`I,2DR*3,I-"DU*38I-RDX*3DI.BD[*3PI/2D^*3\I0"E!
M*4(I0RE$*44I1BE'*4@I22E**4LI3"E-*4XI3RE0*5$I4BE3*50I52E6*5<I
M6"E9*5HI6RE<*5TI7BE?*6`I82EB*6,I9"EE*68I9REH*6DI:BEK*6PI;2EN
M*6\I````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=B%U(0``````
M````````````````````````````````````>"%W(0``````````````````
M`````````````````````````````'0A<R$```````!P(0````!R(7$A````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````&\A;B$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!B(0``
M82$``````````````````````````````````"HA+"$``"XA+R$`````,"$Q
M(0`````````````````````M(0```````````````````````&LA``!D(64A
M``````````````````!Y(0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````9B$`````````````````````````````````````````````
M``!M(0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````<2)R(G,B=")U(G8B=R)X(GDB>B)[(GPB````````
M````````````````````````````````````````````````````````````
M````````````````````````````>R%\(7HA?2$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````2B$`````````
M``````!'(0``1B$`````````````````````3"$`````6"%>(0``3R$`````
M`````$XA``!$(44A22%((5(A`````%,A`````````````&`A7R%#(4LA````
M`````````%<A``````````````````````````!6(0```````%4A````````
M``````````````````````````````````````````!9(50A`````%PA72$`
M````````````````````6B%;(0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!1(0````````````````````````````!-(0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````%`A`````"8A```E(0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(28B)B,F)"8E)B8F
M)R8H)BDF*B8K)BPF+28N)B\F,"8Q)@``,B8S)C0F-28V)C<F."8`````````
M`````````$$F0B9#)D0F129&)D<F2"9))DHF2R9,)DTF3B9/)E`F428``%(F
M4R94)E4F5B97)E@F````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````G)P``````````````
M```````````````````````A)R(G(R<D)R4G)B<H)RDG*B<K)RPG+2<N)R\G
M,"<Q)S(G,R<T)S4G-B<W)S@G.2<Z)SLG/"<])SXG/R=`)T$G42=2)U,G5"=5
M)U8G6"=9)UHG6R=<)UTG7B=?)V`G82=B)V,G9"=E)V8G9R=H)VDG:B=K)VPG
M;2=N)V\G<"=Q)P``5R<`````````````:"$`````;"$G(0``````````````
M````8R%`(0``````````````````````````````````````````````````
M````````````````````````````````````````````````02$`````````
M````````````)"@B*````````````````"@H)B@Z*```+"@J*```````````
M,"@N*````````$(A```T*#(H```Y*```````````(2@`````````````````
M````````````````````````````)2@``````````````````"<H````````
M````````````````````````````````*2@`````````````````````````
M````````````````````````````````````````````````````````````
M```M*```````````````````````````````````````````````````````
M```````````````````````Q*```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C*```*R@``"\H
M```S*```-2@``#8H```W*```."@``````````````````$I5/Y;#5RACSE0)
M5<!4D79,=CR%[G=^@HUX,7*8EHV7*&R)6_I/"6.79KA<^H!(:*Z``F;.=OE1
M5F6L<?%_A(BR4&59RF&S;ZV"3&-28NU3)U0&>VM1I'7T7=1BRXUVEXIB&8!=
M5SB78G\X<GUVSV=^=D9D<$\EC=QB%WJ19>US+&1S8BR"@9A_9TAR;F+,8C1/
MXW1*4YY2RGZFD"Y>AFB<:8"!T7[2:,5XC(91E8U0)(S>@MZ`!5,2B652````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````A(7YEMU/(5AQF9U;L6*E8K1F>8R-G`9R;V>1>+)@45,74XB/S(`=
MC:&4#5#(<@=9ZV`9<:N(5%GO@BQG*'LI7?=^+77U;&:.^(\\D#N?U&L9D11[
M?%^G>-:$/875:]EKUFL!7H=>^77ME5UE"E_%7Y^/P5C"@7^06Y:ME[F/%G\L
MC4%BOT_84UY3J(^ICZN/39`':&I?F(%HB-:<BV$K4BIV;%^,9=)OZ&Z^6TAD
M=5&P4<1G&4[)>7R9LW``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#%=79>NW/@@ZUDZ&*UE.)L6E/#4@]D
MPI24>R]/&UXV@A:!BH$D;LIL<YI58UQ3^E1EB.!7#4X#7F5K/WSHD!9@YF0<
M<\&(4&=-8B*-;'<ICL>1:5_<@R&%$)G"4Y6&BVOM8.A@?W#-@C&"TTZG;,^%
MS639?/UI^69)@Y535GNG3XQ12VU"7&V.TF/)4RR#-H/E9[1X/63?6Y1<[EWG
MB\9B]&=ZC`!DNF-)AXN9%XP@?_*4ITX0EJ28#&86<P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#I7'5PX
M7G^5?U"@@()37F5%=3%5(5"%C81BGI0=9S)6;F_B7354DG!FCV]BI&2C8WM?
MB&_TD..!L(\87&AF\5^);$B6@8ULB)%D\'G.5UEJ$&)(5%A."WKI8(1OVHM_
M8AZ0BYKD>0-4]'4!8QE38&S?CQM?<)H[@'^?B$\Z7&2-Q7^E9;UP15&R46N&
M!UV@6[UB;)%T=0R.('H!87E[QT[X?H5W$4[M@1U2^E%Q:JA3AXX$E<^6P6YD
MEEII````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````0'BH4-=W$&3FB019XV/=77]Z/6D@3SF"F%4R3JYUEWIB
M7HI>[Y4;4CE4BG!V8R25@E<E9C]IAY$'5?-MKWXBB#-B\'ZU=2B#P7C,EIZ/
M2&'W=,V+9&LZ4E"-(6MJ@'&$\58&4\Y.&T[149=\BY$'?,-/?X[A>YQZ9V04
M7:Q0!H$!=KE\[&W@?U%G6%OX6\MXKF039*IC*V,9E2UDOH]4>REV4V(G6494
M>6NC4#1B)EZ&:^-.-XV+B(5?+I``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````@8#V`Q6(Y3E53^)"X8\:`
MYF4N;$9/[F#A;=Z+.5_+AE-?(6-:46&#8V@`4F-C2(X24)M<=WG\6S!2.WJ\
M8%.0UW:W7Y=?A'9LCF]P>W9)>ZIW\U&3D"183D_T;NJ/3&4;>\1RI&W??^%:
MM6*57C!7@H0L>QU>'U\2D!1_H)B"8\=NF'BY<'A16Y>K5S5U0T\X=9=>YF!@
M6<!MOVN)>/Q3U9;+40%2B6,*5).4`XS,C3ERGWAVA^V/#8S@4P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``%.[W;N4XF4=I@.GRV5FENBBR).'$ZL46.$PF&H4@MHET]K8+M1'FU<499B
MEV5AED:,%Y#8=?V08W?2:XIR['+[BS58>7=,C5QG0)6:@*9>(6Z26>]Z[7<[
ME;5KK64.?P9845$?EOE;J5@H5'*.9F5_F.16G93^=D&0AV/&5!I9.EF;5[*.
M-6?ZC36"05+P8!58_H;H7$6>Q$^=F+F+)5IV8(13?&)/D`*1?YEI8`R`/U$S
M@!1<=9DQ;8Q.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````,(W14UI_3WL03T].`);5;-!SZ84&7FIU^W\*
M:OYWDI1!?N%1YG#-4]2/`X,IC:]R;9G;;$I7LX*Y9:J`/V(REJA9_TZ_B[I^
M/F7R@UZ7857>F*6`*E/]BR!4NH"?7KAL.8VL@EJ1*50;;`92MWY?5QIQ?FR)
M?$M9_4[_7R1AJGPP3@%<JV<"A_!<"Y7.F*]U_7`BD*]1'7^]BTE9Y%%;3R94
M*UEW9:2`=5MV8L)BD(]%7A]L)GL/3]A/#6<`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!N;:IMCWFQB!=?
M*W6:8H6/[T_<D:=E+X%1@9Q>4(%TC6]2AHE+C0U9A5#83AR6-G)Y@1^-S%NC
MBT26AUD:?Y!4=E8.5N6+.66":9F4UG:);G)>&'5&9]%G_WJ=@':-'V'&>6)E
M8XV(41I2HI0X?YN`LGZ77"]N8&?9>XMVV)J/@91_U7P>9%"5/WI*5.543&L!
M9`AB/9[S@)EU<E)IEUN$/&CDA@&6E);LE"I.!%39?CEHWXT5@/1FFEZY?P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````,)7/X"7:.5=.V6?4FU@FI^;3ZR.;%&K6Q-?Z5U>;/%B(8UQ4:F4
M_E*?;-^"UW*B5X1G+8T?69R/QX.55(U[,$^];&1;T5D3G^13RH:HFC>,H8!%
M97Z8^E;'EBY2W'104N%;`F,"B59.T&(J8/IH<U&86Z!1PHFA>X:94'_O8$QP
M+XU)47]>&Y!P=,2)+5=%>%)?GY_ZE6B//)OABWAV0FC<9^J--8T]4HJ/VF[-
M:`65[9#]5IQG^8C'C\A4````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````N)II6W=M)FRE3K-;AYICD:AAKY#I
MERM4M6W26_U1BE55?_!_O&1-8_%EOF&-8`IQ5VQ);"]9;6<J@M58CE9JC.MK
MW9!]61>`]U-I;754G55W@\^#.&B^>8Q454\(5-)VB8P"EK-LN&UKC1")9)XZ
MC3]6T9[5=8A?X')H8/Q4J$XJ:F&(4F!PC\14V'!YAC^>*FV/6QA?HGZ)5:]/
M-',\5)I3&5`.5'Q43D[]7UIT]EAKA.&`=(?0<LI\5FX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````G7TZ&
M+%6D8I).JFPW8K&"UU1.4SYST6X[=1)2%E/=B]!IBE\`8.YM3U<B:Z]S4VC8
MCQ-_8F.C8"15ZG5BC!5QHVVF6WM>4H-,8<2>^GA7AR=\AW;P4?9@3'%#9DQ>
M36`.C'!P)6.)C[U?8F#4AMY6P6N48&=A25/@8&9F/XW]>1I/Z7!';+.+\HO8
M?F2##V9:6D*;46WW;4&,.VT93VMPMX,68M%@#9<GC7AY^U$^5_I7.F=X=3UZ
M[WF5>P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(R`99GYC\!OI8LAGNQ9Z7X)?PE4@6?8:)&/37S&ELI3
M)6"^=7)L<U/)6J=^)&/@40J!\5W?A(!B@%%C6PY/;7E"4KA@3FW$6\);H8NP
MB^)ES%]%EI-9YWZJ?@E6MV<Y67-/MEN@4EJ#BI@^C3)UOI1'4#QZ]TZV9WZ:
MP5I\:]%V6E<67#I[])5.<7Q1J8!P@GA9!'\G@\!H[&>Q>'=XXV)A8X![[4]J
M4L]14(/;:722]8TQC<&)+I6M>_9.````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````95`P@E%2;YD0;H5NIVWZ
M7O50W%D&7$9M7VR&=8N$:&A66;*+(%-QD4V62842:0%Y)G'V@*1.RI!';82:
M!UJ\5@5D\)3K=Z5/&H'A<M*)>IDT?]Y^?U)99761?X^#C^M3EGKM8Z5CAG;X
M>5>(-I8J8JM2@H)4:'!G=V-K=^UZ`6W3?N.)T%D28LF%I8),=1]0RTZE=>N+
M2ES^74M[I&71D<I.)6U?B2=])I7%3BB,VX]SETMF@7G1C^QP>&T`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```]7+)21H-B40Z#6W=V9KB<K$[*8+Y\LWS/?I5.9HMO9HB869>#6&QE7)6$
M7\EU5I??>MYZP%&O<)AZZF-V>J!^EG/MET5.>'!=3E*1J5-19>=E_($%@HY4
M,5R:=:"7V&+9<KUU15QYFLJ#0%R`5.EW/DZN;%J`TF)N8^A==U'=C1Z.+Y7Q
M3^53YV"L<&=24&-#GA]:)E`W=W=3XGZ%9"MEB6*88Q10-7+)B;-1P(O=?D=7
MS(.GE)M1&U3[7```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````,I/XWI:;>&0CYJ`599485.O5`!?Z6-W:>]1
M:&$*4BI8V%).5PUX"W>W7G=AX'Q;8I=BHDZ5<`.`]V+D<&"7=U?;@N]G]6C5
M>)>8T7GS6+-4[U,T;DM1.U*B6_Z+KX!#5:97<V!15RU4>GI08%1;IV.@8N-3
M8V+'6Z]G[52?>N:"=Y&37N2(.%FN5PYCZ(WO@%=7=WNI3^M?O5L^:R%34'O"
M<D9H_W<V=_=EM5&/3M1VOURE>G6$3EE!FX!0````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B)DG88-N9%<&
M9D9C\%;L8FEBTUX4EH-7R6*'52&'2H&CCV95L8-E9U:-W81J6@]HYF+N>Q&6
M<%&<;S",_6/(B=)A!G_"<.5N!724:?QRRE[.D!=G:FU>8[-28G(!@&Q/Y5EJ
MD=EPG6W24E!.]Y9ME7Z%RG@O?2%1DE?"9(N`>WSJ;/%H7FFW49A3J&B!<LZ>
M\7OX<KMY$V\&=$YGS)&DG#QYB8-4@P]4%V@]3HE3L5(^>(93*5*(4(M/T$\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#B=<MZDGRE;+:6FU*#=.E4Z4]4@+*#WH]PE<E>'&"?;1A>6V4X
M@?Z42V"\<,-^KGS)48%HL7QO@B1.AH_/D7YFKDX%C*ED2H#:4)=USG'E6[V/
M9F^&3H)D8Y767IEE%U+"B,APHU(.<S-TEV?W>!:7-$Z[D-Z<RVW;44&-'53.
M8K)S\8/VEH2?PY0V3YI_S%%U<'66K5R&F.93Y$Z<;@ETM&EK>(^967484B1V
M06WS9VU1F9]+@)E4/'N_>@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(:6A%?B8D>6?&D$6@)DTWL/;TN6
MIH)B4X68D%Z)<+-C9%-/AH&<DYZ,>#*7[XU"C7^>7F^$>55?1I8N8G2:%53=
ME*-/Q65E7&%<%7]1AB]LBU^'<^1N_W[F7!MC:EOF;G53<4Z@8V5UH6)NCR9/
MT4ZF;+9^NHL=A+J'5W\[D".5J7NAFOB(/80;;8::W'Z(6;N>FW,!>(*&;)J"
MFAM6%U3+5W!.IIY64\B/"8&2=Y*9[H;A;A.%_&9B82MO````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````*8R2
M@BN#\G83;-E?O8,K<P6#&I7;:]MWQI1O4P*#DE$]7HR,.(U(3JMSFF>%:':1
M"9=D<:%L"7>26D&5SVN.?R=FT%NY69I:Z)7WE>Q.#(29A*QJWW8PE1MSIFA?
M6R]WFI%AE]Q\]X\<C"5?<WS8><6)S&P<A\9;0E[):"!W]7Z544U1R5(I6@5_
M8I?7@L]CA'?0A=)Y.FZ97IE9$85M<!%LOV*_=D]EKV#]E0YFGX<CGNV4#51]
M5"R,>&0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!Y9!&&(6J<@>AX:614F[EB*V>K@ZA8V)ZK;"!OWEM,
ME@N,7W+09\=B87*I3L99S6N36*YF55[?4E5A*&?N=F9W9W)&>O]BZE105*"4
MHY`<6K-^%FQ#3G99$(!(65=3-W6^ELI6(&,1@7Q@^976;6)4@9F%4>E:_8"N
M61.7*E#E;#Q<WV)@3S]3>X$&D+IN*X7(8G1>OGBU9'MC]5\86G^1'YX_7$]C
M0H!]6VY52I5-E85MJ&#@9]YRW5&!6P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````.=BWFQ;<FUBKI2]?A.!
M4VV<401?=%FJ4A)@<UF69E"&GW4J8^9A[WSZB^94)VLEGK1KU8555'90I&QJ
M5;2-+'(57A5@-G3-8I)C3'*87T-N/FT`95AOV';0>/QV5'4D4MM34TZ>7L%E
M*H#6@)MBAE0H4JYPC8C1C>%L>%3:@/E7](A4C6J639%I3YMLMU7&=C!XJ&+Y
M<(YO;5_LA-IH?'CW>ZB!"V=/GF=CL'AO5Q)X.9=Y8JMBB%(U=-=K````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````9%4^@;)UKG8Y4]YU^U!!7&R+QWM/4$=REYK8F`)OXG1H>8=DI7?\8I&8
M*XW!5%B`4DYJ5_F"#81S7NU1]G3$BT]<85?\;(>81EHT>$2;ZX^5?%9246+Z
ME,9.AH-AA.F#LH345S1G`U=N9F9M,8S=9A%P'V<Z:Q9H&F*[60-.Q%$&;])G
MCVQV4<MH1UEG:V9U#ET0@5"?UV5(>4%YD9IWC8)<7DX!3R]445D,>&A6%&S$
MCP-??6SC;*N+D&,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!P8#UM=7)F8HZ4Q91#4\&/?GO?3B:,?D[4
MGK&4LY1-4EQO8Y!%;32,$5A,72!K26NJ9UM45(&,?YE8-X4Z7Z)B1VHYE7)E
MA&!E:*=W5$ZH3^==F)>L9-A_[5S/3XUZ!U($@Q1.+V"#>J:4M4^R3N9Y-'3D
M4KF"TF2]>=U;@6Q2EWN/(FP^4']3!6[.9'1F,&S%8'>8]XN&7CQT=WK+>1A.
ML9`#=$)LVE9+D<5LBXTZ4\:&\F:OCDA<<9H@;@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-93-EJ+GZ.-
MNU,(5Z>80V>;D<EL:%'*=?-BK'(X4IU2.G^4<#AV=%-*GK=I;GC`EMF(I'\V
M<<-QB5'39^1TY%@89;=6J8MVF7!BU7[Y8.UP[%C!3KI.S5_GE_M.I(L#4HI9
MJWY48LU.Y64.8CB#R81C@XV'E'&V;KE;TGZ74<ECU&>)@#F#%8@247I;@EFQ
MCW-.76QE426);X\NEDJ%7G00E?"5IFWE@C%?DF02;2B$;H'#G%Y86XT)3L%3
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````'D]C95%HTU4G3A1DFIIK8L):7W1R@JEM[FCG4(Z#`GA`9SE2
MF6RQ?KM0955><5M[4F;*<^N"26=Q7"!2?7%KB.J559;%9&&-LX&$555L1V(N
M?Y)8)$]&54^-3&8*3AI<\XBB:$YC#7KG<(V"^E+VEQ%<Z%2UD,U^8EE*C<>&
M#((-@F:-1&0$7%%AB6T^>;Z+-W@S=7M4.$^KCO%M(%K%?EYYB&RA6W9:&G6^
M@$YA%V[P6!]U)75R<D=3\WX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````!=]MV:5+<@"-7"%XQ6>YRO65_
M;M>+.%QQAD%3\W?^8O9EP$[?F("&GEO&B_)3XG=_3TY<=IK+60]?.GGK6!9.
M_V>+3NUBDXH=D+]2+V;<56Q6`I#53HU/RI%PF0]L`EY#8*1;QHG5BS9E2V*6
MF8A;_UN(8RY5UU,F=GU1+(6B9[-HBFN28I./U%,2@M%MCW5F3DZ-<%N?<:^%
MD6;99G)_`(?-GB"?7EPO9_"/$6A?9PUBUGJ%6+9><&4Q;P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````%5@
M-U(-@%1D<(@I=05>$VCT8AR7S%,]<@&,-&QA=PYZ+E2L=WJ8'(+TBU5X%&?!
M<*]EE60V5AU@P7GX4QU.>VN&@/I;XU7;5CI//$]RF?-=?F<X@`)@@I@!D(M;
MO(OUBQQD6(+>9/U5SX)ED==/('T?D)]\\U!16*]NOUO)BX.`>)&<A)=[?8:+
MEH^6Y7[3FHYX@5Q7>D*0IY9?>5E;7V,+>]&$K6@&52E_$'0B?0&50&),6-9.
M@UMY6518````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````;7,>8TN.#X[.@-2"K&+P4_!L7I$J60%@<&Q-5TID
M*HTK=NEN6U>`:O!U;6\MC`B,9E?O:Y*(LWBB8_E3K7!D;%A8*F0"6.!HFX$0
M5=9\&%"ZCLQMGXWK<(]CFVW4;N9^!(1#:`.0V&UVEJB+5UEY<N2%?H&\=8J*
MKVA44B*.$9708YB81(Y\55-/_V:/5M5@E6U#4DE<*5G[;6M8,'4<=6Q@%()&
M@1%C86?BCSIW\XTTC<&4%EZ%4RQ4PW``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!`;/=>7%"M3JU>.F-'
M@AJ04&AND;-W#%3<E&1?Y7IV:$5C4GO??MMU=U"58C19#Y#X4<-Y@7K^5I)?
M%)"";6!<'U<05%1136[B5JACDYA_@16'*HD`D!Y4;US`@=9B6&(Q@36>0)9N
MFGR:+6FE6=-B/E468\=4V88\;0-:YG2<B&IK%EE,C"]??FZI<WV8.$[W<(Q;
MEW@]8UIFEG;+8)M;25H'3E6!:FR+<Z%.B6=1?X!?^F4;9]A?A%D!6@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````,U=KE]Q4^:7W8]%:/16+U7?8#I.36_T?L>"#H3461]/*D\^7*Q^*F<:
MA7-43W7#@()53YM-3RUN$XP)7'!A:U,?=BENBH:'9?N5N7X[5#-Z"GWNE>%5
MP7_N=!UC%X>A;9UZ$6*A96=3X6.#;.M=7%2HE$Q.86SLBTM<X&6<@J=H/E0T
M5,MK9FN43D)C2%,>@@U/KD]>5PIB_I9D9FER_U*A4I]@[XL49IEQD&=_B5)X
M_7=P9CM6.%0AE7IR````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'IO8`Q>B6"=@159W&"$<>]PJFY0;(!R
MA&JMB"U>8$ZS6IQ5XY07;?M\F98/8L9^CG=^AB-3'I>6CX=FX5R@3^UR"TZF
M4P]9$U2`8RB52%'93IR<I'ZX5"2-5(@W@O*5CFTF7\Q:/F9IEK!S+G._4WJ!
MA9FA?ZI;=Y90EK]^^':B4W:5F9FQ>T2)6&YA3M1_97GFB_-@S52K3GF8]UUA
M:L]0$51AC">$77@$ETI2[E2C5@"5B&VU6\9M4V8`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````/7%U;(6B6
M@'A5$7M(951IFTY':TZ'BY=/4Q]C.F2JD)QEP8`0C)E1L&AX4_F'R&'$;/ML
M(HQ17*J%KX(,E2-KFX^P9?M?PU_A3T6('V9E@2ES^F!T41%2BU=B7Z*03(B2
MD7A>3V<G8--91%'V4?B`"%-Y;,26BG$13^Y/GG\]9\55")7`>9:(XWZ?6`QB
M`)=:AAA6>YB07[B+Q(17D=E3[66/7EQU9&!N?7]:ZG[M?FF/IU6C6ZQ@RV6$
M<P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````F08W8I=]I^=)>;A69;='KJED"(RU*/<:I?[&7BB_M;;YKA
M78EK6VRMBZ^+"I#%CXM3O&(FGBV>0%0K3KV"67*<AA9=68BO;<66T52:3K:+
M"7&]5`F6WW#Y;=!V)4X4>!*'J5SV7@"*G)@.EHYPOVQ$6:EC/'=-B!1O<X(P
M6-5QC%,:>,&6`55F7S!QM%L:C(R:@VLN62^>YWEH9VQB;T^A=8I_"VTSEB=L
M\$[2=7M1-V@^;X"0<(&6679T````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1V0G7&60D7HCC-I9K%0`@F^#
M@8D`@#!I3E8V@#=RSI&V45].=9B68QI.]E/S9DN!'%FR;0!.^5@[4]9C\92=
M3PI/8XB0F#=95Y#[>>I.\("1=8)LG%OH65U?!6F!AAI0\EU93N-WY4YZ@I%B
M$V:1D'E<OTYY7\:!.)"$@*MUID[4B`]AQ6O&7TE.RG:B;N.+KHL*C-&+`E_\
M?\Q_SGXU@VN#X%:W:_.7-);[61]4]I3K;<5;;IDY7!5?D)8`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!P
M4_&",6IT6G">E%XH?[F#)(0EA&>#1X?.CV*-R'9Q7Y:8;'@@9M]4Y6)C3\.!
MR'6X7LV6"H[YAH]4\VR,;3AL?V#'4BAU?5X83Z!@YU\D7#%UKI#`E+ERN6PX
M;DF1"6?+4_-344_)D?&+R%-\7L*/Y&V.3L)VAFE>AAIA!H)93]Y//I!\G`EA
M'6X4;H66B$XQ6NB6#DY_7+EYAUOMB[U_B7/?5XN"P9`!5$>0NU7J7*%?"&$R
M:_%RLH")B@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'1MTUO5B(28:XQMFC.>"FZD44-1HU>!B)]3]&.5
MC^U66%0&5S]SD&X8?]R/T8(_82A@8I;P9J9^BHW#C:64LURD?`AGIF`%EAB`
MD4[GD`!3:)9!4="/=(5=D55F]9=56QU3.'A"9SUHR51^<+!;?8^-42A7L502
M98)F7HU#C0^!;(1MD-]\_U'[A:-GZ66A;Z2&@8YJ5B"0@G9V<.5Q(XWI8AE2
M_6P\C0Y@GEB.8?YF8(U.8K-5(VXM9V>/````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````X93XE2AW!6BH:8M4
M34ZX<,B+6&2+985;A'HZ4.A;NW?A:WF*F'R^;,]VJ667CRU=55PXA@AH8%,8
M8MEZ6V[]?A]JX'IP7S-O(%^,8ZAM5F<(3A!>)HW73L"`-':<EMMB+69^8KQL
M=8UG<6E_1E&'@.Q3;I"88O)4\(:9CP6`%Y47A=F/66W-<Y]E'W<$=2=X^X$>
MC8B4ID^59[EURHL'ER]C1Y4UEKB$(V-!=X%?\'*)3A1@=&7O8F-K/V4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````G7L=UT9#!BYV"G6<O93%4&(?E=Z*``H%!;$M.QWY,@/1V#6F6:V=B
M/%"$3T!7!V-B:[Z-ZE/H9;A^UU\:8[=C\X'T@6Y_'%[97#92>F;I>1IZ*(V9
M<-1UWFZ[;))Z+4[%=N!?GY1WB,A^S7F_@,V1\DX73Q^":%3>73)MS(NE?'2/
MF(`:7I)4L7:96SQFI)K@<RIHVX8Q9RIS^(O;BQ"0^7K;<&YQQ&*I=S%6.TY7
MA/%GJ5+`ABZ-^)11>P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$]/Z&Q=>7N:DV(J<OUB$TX6>&R/L&1:
MC<9[:6B$7L6(AEF>9.Y8MG(.:265_8]8C6!7`'\&C,9126/98E-33&@B=`&#
M3)%$54!W?'!*;7E1J%1$C?]9RV[$;5Q;*WW43GU\TVY06^J!#6Y76P.;U6@J
MCI=;_'X[8+5^N9!PC4]9S6/?>;.-4E//959YQ8L[EL1^NY2"?C16B9$`9VI_
M"EQUD"AFYEU03]YG6E!<3U!7IUX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````C4X,3D!1
M$$[_7D53%4Z83AY.,IML6VE6*$ZZ>3].%5-'3BU9.W)N4Q!LWU;D@)>9TVM^
M=Q>?-DZ?3A"?7$YI3I-.B();6VQ5#U;$3HU3G5.C4Z53KE-EEUV-&E/U4R93
M+E,^4UR-9E-C4P)2"%(.4BU2,U(_4D!23%)>4F%27%*OA'U2@E*!4I!2DU*"
M451_NT[#3LE.PD[H3N%.ZT[>3AM/\TXB3V1/]4XE3R=/"4\K3UY/9T\X95I/
M74\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!?3U=/,D\]3W9/=$^13XE/@T^/3WY/>T^J3WQ/K$^43^9/
MZ$_J3\5/VD_C3]Q/T4_?3_A/*5!,4/-/+%`/4"Y0+5#^3QQ0#%`E4"A0?E!#
M4%502%!.4&Q0>U"E4*=0J5"Z4-90!E'M4.Q0YE#N4`=1"U'=3CUL6$]E3\Y/
MH)]&;'1\;E']7<F>F)F!4119^5(-4P>*$%/K41E955&@3E91LTYNB*2(M4X4
M@=*(@'DT6P.(N'^K4;%1O5&\40``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````,=1EE&B4:51H(NFBZ>+JHNT
MB[6+MXO"B\.+RXO/B\Z+THO3B]2+UHO8B]F+W(O?B^"+Y(OHB^F+[HOPB_.+
M]HOYB_R+_XL`C`*,!(P'C`R,#XP1C!*,%(P5C!:,&8P;C!B,'8P?C"",(8PE
MC">,*HPKC"Z,+XPRC#.,-8PVC&E3>E,=EB*6(98QEBJ6/98\ED*62994EE^6
M9Y9LEG*6=):(EHV6EY:PEI>0FY"=D)F0K)"AD+20LY"VD+J0````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MN)"PD,^0Q9"^D-"0Q)#'D-.0YI#BD-R0UY#;D.N0[Y#^D`21(I$>D2.1,9$O
MD3F10Y%&D0U20EFB4JQ2K5*^4O]4T%+64O!2WU/N<<UW]%[U4?Q1+YNV4P%?
M6G7O74Q7J5>A5WY8O%C%6-%8*5<L5RI7,U<Y5RY7+U=<5SM70E=I5X57:U>&
M5WQ7>U=H5VU7=E=S5ZU7I%>,5[)7SU>G5[17DU>@5]57V%?:5]E7TE>X5_17
M[U?X5^17W5<`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````+6`U8_5?M5P!8'E@96$18(%AE6&Q8@5B)6)I8
M@%BHF1F?_V%Y@GV"?X*/@HJ"J(*$@HZ"D8*7@IF"JX*X@KZ"L(+(@LJ"XX*8
M@K>"KH++@LR"P8*I@K2"H8*J@I^"Q(+.@J2"X8()@_>"Y((/@P>#W(+T@M*"
MV((,@_N"TX(1@QJ#!H,4@Q6#X(+5@AR#48-;@UR#"(.2@SR#-(,Q@YN#7H,O
M@T^#1X-#@U^#0(,7@V"#+8,Z@S.#9H-E@P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````&B#&X-I@VR#:H-M
M@VZ#L(-X@[.#M(.@@ZJ#DX.<@X6#?(.V@ZF#?8.X@WN#F(.>@ZB#NH.\@\&#
M`83E@]B#!U@8A`N$W8/]@]:#'(0XA!&$!H34@]^##X0#A/B#^8/J@\6#P(,F
MA/"#X8-<A%&$6H19A'.$AX2(A'J$B81XA#R$1H1IA':$C(2.A#&$;83!A,V$
MT(3FA+V$TX3*A+^$NH3@A*&$N82TA)>$Y83CA`R%#74XA?"$.84?A3J%````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````5H4[A?^$_(19A4B%:(5DA5Z%>H6B=T.%<H5[A:2%J(6'A8^%>86N
MA9R%A86YA;>%L(73A<&%W(7_A2>&!88IAA:&/(;^7@A?/%E!63>`55E:65A9
M#U,B7"5<+%PT7$QB:F*?8KMBRF+:8M=B[F(B8_9B.6-+8T-CK6/V8W%C>F..
M8[1C;6.L8XIC:6.N8[QC\F/X8^!C_V/$8]YCSF-29,9COF-%9$%D"V0;9"!D
M#&0F9"%D7F2$9&UDEF0`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!Z9+=DN&299+IDP&309-=DY&3B9`EE
M)64N90M?TE\9=1%?7U/Q4_U3Z5/H4_M3$E065`942U125%-45%165$-4(517
M5%E4(U0R5()4E%1W5'%49%2:5)M4A%1V5&94G5305*U4PE2T5-)4IU2F5--4
MU%1R5*-4U52[5+]4S%395-I4W%2I5*I4I%3=5,]4WE0;5>=4(%7]5!15\U0B
M52-5#U4152=5*E5G58]5M55)56U5055553]54%4\50``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#=55E5U
M5795=U4S53!57%6+5=)5@U6Q5;E5B%6!59]5?E7659%5>U7?5;U5OE6459E5
MZE7W5<E5'U;15>M5[%745>95W57$5>]5Y57R5?-5S%7-5>A5]57D592/'E8(
M5@Q6`58D5B-6_E4`5B=6+5985CE65U8L5DU68E995EQ63%945H969%9Q5FM6
M>U9\5H56DU:O5M16UU;=5N%6]5;K5OE6_U8$5PI7"5<<5P]>&5X47A%>,5X[
M7CQ>````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````-UY$7E1>6UY>7F%>C%QZ7(U<D%R67(A<F%R97)%<FER<
M7+5<HER]7*Q<JURQ7*-<P5RW7,1<TESD7,M<Y5P"70-=)UTF72Y=)%T>709=
M&UU873Y=-%T]76Q=6UUO75U=:UU+74I=:5UT78)=F5V=77.,MUW%77-?=U^"
M7X=?B5^,7Y5?F5^<7ZA?K5^U7[Q?8HAA7ZURL'*T<K=RN'+#<L%RSG+-<M)R
MZ'+O<NER\G+T<O=R`7/S<@-S^G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#[<A=S$W,A<PIS'G,=<Q5S
M(G,Y<R5S+',X<S%S4'--<U=S8'-L<V]S?G,;@B59YY@D60)98YEGF6B9:9EJ
MF6N9;)ETF7>9?9F`F829AYF*F8V9D)F1F9.9E)F5F8!>D5Z+7I9>I5Z@7KE>
MM5Z^7K->4XW27M%>VU[H7NI>NH'$7\E?UE_/7P-@[E\$8.%?Y%_^7P5@!F#J
M7^U?^%\98#5@)F`;8`]@#6`I8"M@"F`_8"%@>&!Y8'M@>F!"8```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`&I@?6"68)I@K6"=8(-@DF",8)M@[&"[8+%@W6#88,9@VF"T8"!A)F$582-A
M]&``80YA*V%*875AK&&48:=AMV'48?5AW5^SENF5ZY7QE?.5]97VE?R5_I4#
ME@26!I8(E@J6"Y8,E@V6#Y82EA66%I87EAF6&I8L3C]R%6(U;%1L7&Q*;*-L
MA6R0;)1LC&QH;&EL=&QV;(9LJ6S0;-1LK6SW;/AL\6S7;+)LX&S6;/ILZVSN
M;+%LTVSO;/YL````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````.6TG;0QM0VU(;0=M!&T9;0YM*VU-;2YM-6T:
M;4]M4FU4;3-MD6UO;9YMH&U>;9-ME&U<;6!M?&UC;1INQVW%;=YM#FZ_;>!M
M$6[F;=UMV6T6;JMM#&ZN;2MN;FY.;FMNLFY?;H9N4VY4;C)N)6Y$;M]NL6Z8
M;N!N+6_B;J5NIVZ];KMNMV[7;K1NSVZ/;L)NGVYB;T9O1V\D;Q5O^6XO;S9O
M2V]T;RIO"6\I;XEOC6^,;WAO<F]\;WIOT6\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#);Z=ON6^V;\)O
MX6_N;]YOX&_O;QIP(W`;<#EP-7!/<%YP@%N$6Y5;DUNE6[A;+W6>FC1DY%ON
M6S")\%M'C@>+MH_3C]6/Y8_NC^2/Z8_FC_./Z(\%D`20"Y`FD!&0#9`6D"&0
M-9`VD"V0+Y!$D%&04I!0D&B06)!BD%N0N69TD'V0@I"(D(.0BY!07U=?5E]8
M7SM<JU107%E<<5MC7&9<O'\J7RE?+5]T@CQ?.YMN7(%9@UF-6:E9JEFC60``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````)=9REFK69Y9I%G26;)9KUG76;Y9!5H&6MU9"%KC6=A9^5D,6@E:
M,EHT6A%:(UH36D!:9UI*6E5:/%IB6G5:[("J6IM:=UIZ6KY:ZUJR6M):U%JX
M6N!:XUKQ6M9:YEK86MQ:"5L76Q9;,ELW6T!;%5P<7%I;95MS6U%;4UMB6W6:
M=YIXFGJ:?YI]FH":@9J%FHB:BIJ0FI*:DYJ6FIB:FYJ<FIV:GYJ@FJ*:HYJE
MFJ>:GWZA?J-^I7ZH?JE^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````K7ZP?KY^P'[!?L)^R7[+?LQ^T'[4
M?M=^VW[@?N%^Z'[K?NY^[W[Q?O)^#7_V?OI^^W[^?@%_`G\#?P=_"'\+?PQ_
M#W\1?Q)_%W\9?QQ_&W\??R%_(G\C?R1_)7\F?R=_*G\K?RQ_+7\O?S!_,7\R
M?S-_-7]Z7G]UVUT^=960CG.1<ZYSHG.?<\]SPG/1<[=SLW/`<\ESR'/E<]ES
M?)@*=.ESYW/><[IS\G,/="IT6W0F="5T*'0P="YT+'0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````;=!IT
M071<=%=T5719='=T;71^=)QTCG2`=(%TAW2+=)YTJ'2I=)!TIW32=+ITZI?K
ME^R73&=39UYG2&=I9Z5GAV=J9W-GF&>G9W5GJ&>>9ZUGBV=W9WQG\&<):-AG
M"FCI9[!G#&C99[5GVF>S9]UG`&C#9[AGXF<.:,%G_6<R:#-H8&AA:$YH8FA$
M:&1H@V@=:%5H9FA!:&=H0&@^:$IH26@I:+5HCVAT:'=HDVAK:,)H;FG\:!]I
M(&GY:```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"1I\&@+:0%I5VGC:!!I<6DY:6!I0FE=:81I:VF`:9AI
M>&DT:<QIAVF(:<YIB6EF:6-I>6F;::=INVFK::UIU&FQ:<%IRFG?:95IX&F-
M:?]I+VKM:1=J&&IE:O)I1&H^:J!J4&I;:C5JCFIY:CUJ*&I8:GQJD6J0:JEJ
MEVJK:C=S4G.!:X)KAVN$:Y)KDVN-:YIKFVNA:ZIK:X]MCW&/<H]SCW6/=H]X
MCW>/>8]ZCWR/?H^!CX*/A(^'CXN/````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````C8^.CX^/F(^:C\Z."V(7
M8AMB'V(B8B%B)6(D8BQBYX'O=/1T_W0/=1%U$W4T9>YE[V7P90IF&69R9P-F
M%68`9H5P]V8=9C1F,68V9C5F!H!?9E1F069/9E9F86979G=FA&:,9J=FG6:^
M9MMFW&;F9NEF,HTSC3:-.XT]C4"-18U&C4B-28U'C4V-58U9C<>)RHG+B<R)
MSHG/B=")T8EN<I]R77)F<F]R?G)_<H1RBW*-<H]RDG((8S)CL&,`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```_9-AD!(#J:_-K_6OU:_EK!6P';`9L#6P5;!AL&6P:;"%L*6PD;"IL,FPU
M955E:V5-<E)R5G(P<F*&%E*?@)R`DX"\@`IGO8"Q@*N`K8"T@+>`YX#H@.F`
MZH#;@,*`Q(#9@,V`UX`09]V`ZX#Q@/2`[8`-@0Z!\H#\@!5G$H%:C#:!'H$L
M@1B!,H%(@4R!4X%T@5F!6H%Q@6"!:8%\@7V!;8%G@4U8M5J(@8*!D8'5;J.!
MJH',@29GRH&[@0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````,&!IH$D:S=K.6M#:T9K66O1F-*8TYC5F-F8
MVIBS:T!?PFOSB9!E49^39;QEQF7$9<-ES&7.9=)EUF6`<)QPEG"=<+MPP'"W
M<*MPL7#H<,IP$'$3<19Q+W$Q<7-Q7'%H<45Q<G%*<7AQ>G&8<;-QM7&H<:!Q
MX''4<>=Q^7$=<BAR;'`8<69QN7$^8CUB0V)(8DEB.WE`>49Y27E;>5QY4WE:
M>6)Y5WE@>6]Y9WEZ>85YBGF:>:=YLWG17]!?````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/&!=8%I@9V!!
M8%E@8V"K8`9A#6%=8:EAG6'+8=%A!F*`@'^`DVSV;/QM]G?X=P!X"7@7>!AX
M$7BK92UX''@=>#EX.G@[>!]X/'@E>"QX(W@I>$YX;7A6>%=X)GA0>$=X3'AJ
M>)MXDWB:>(=XG'BA>*-XLGBY>*5XU'C9>,EX['CR>`5Y]'@3>21Y'GDT>9N?
M^9[[GOR>\78$=PUW^78'=PAW&G<B=QEW+7<F=S5W.'=0=U%W1W=#=UIW:'<`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!B=V5W?W>-=WUW@'>,=Y%WGW>@=[!WM7>]=SIU0'5.=4MU2'5;
M=7)U>76#=5A_87]??TB*:']T?W%_>7^!?WY_S7;E=C*(A92&E(>4BY2*E(R4
MC92/E)"4E)27E)64FI2;E)R4HY2DE*N4JI2ME*R4KY2PE+*4M)2VE+>4N)2Y
ME+J4O)2]E+^4Q)3(E,F4RI3+E,R4S93.E-"4T932E-64UI37E-F4V)3;E-Z4
MWY3@E.*4Y)3EE.>4Z)3JE```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````.F4ZY3NE.^4\Y3TE/64]Y3YE/R4
M_93_E`.5`I4&E0>5"94*E0V5#I4/E1*5$Y44E165%I48E1N5'94>E1^5(I4J
ME2N5*94LE3&5,I4TE3:5-Y4XE3R5/I4_E4*5-95$E4651I5)E4R53I5/E5*5
M4Y54E5:55Y58E5F56Y5>E5^5795AE6*59)5EE6:59Y5HE6F5:I5KE6R5;Y5Q
ME7*5<Y4ZE>=W['?)EM5Y[7GC>>MY!GI'70-Z`GH>>A1Z````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````.7HW
M>E%ZSYZEF7!ZB':.=I-VF7:D=MYTX'0L=2">(IXHGBF>*IXKGBR>,IXQGC:>
M.)XWGCF>.IX^GD&>0IY$GD:>1YY(GDF>2YY,GDZ>49Y5GE>>6IY;GER>7IYC
MGF:>9YYHGFF>:IYKGFR><9YMGG.>DG64=99UH'6==:QUHW6S=;1UN'7$=;%U
ML'7#=<)UUG7-=>-UZ'7F=>1UZW7G=0-V\77\=?]U$'8`=@5V#'87=@IV)788
M=A5V&78`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````;=CQV(G8@=D!V+78P=C]V-79#=CYV,W9-=EYV5'9<
M=E9V:W9O=LI_YGIX>GEZ@'J&>HAZE7JF>J!ZK'JH>JUZLWIDB&F(<HA]B'^(
M@HBBB,:(MXB\B,F(XHC.B..(Y8CQB!J)_(CHB/Z(\(@AB1F)$XD;B0J)-(DK
MB3:)08EFB7N)BW7E@+)VM';<=Q*`%(`6@!R`((`B@"6`)H`G@"F`*(`Q@`N`
M-8!#@$:`38!2@&F`<8"#B7B8@)B#F```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(F8C)B-F(^8E)B:F)N8
MGIB?F*&8HIBEF*:83894AFR&;H9_AGJ&?(9[AJB&C8:+AJR&G8:GAJ.&JH:3
MAJF&MH;$AK6&SH:PAKJ&L8:OALF&SX:TANF&\8;RANV&\X;0AA.'WH;TAM^&
MV(;1A@.'!X?XA@B'"H<-APF'(X<[AQZ')8<NAQJ'/H=(AS2',8<IAS>'/X>"
MAR*'?8=^AWN'8(=PATR';H>+AU.'8X=\AV2'68=EAY.'KX>HA]*'````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````QH>(AX6'K8>7AX.'JX?EAZR'M8>SA\N'TX>]A]&'P(?*A]N'ZH?@A^Z'
M%H@3B/Z'"H@;B"&(.8@\B#9_0G]$?T5_$(+Z>OUZ"'L#>P1[%7L*>RM[#WM'
M>SA[*GL9>RY[,7L@>R5[)'LS>SY['GM8>UI[17MU>TQ[77M@>VY[>WMB>W)[
M<7N0>Z9[IWNX>ZQ[G7NH>X5[JGN<>Z)[JWNT>]%[P7O,>]U[VGOE>^9[ZGL,
M?/Y[_'L/?!9\"WP`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````??"I\)GPX?$%\0'S^@0&"`H($@NR!1(@A
M@B*"(X(M@B^"*((K@CB".X(S@C2"/H)$@DF"2X)/@EJ"7X)H@GZ(A8B(B-B(
MWXA>B9U_GW^G?Z]_L'^R?WQ\2661?)U\G'R>?*)\LGR\?+U\P7S'?,Q\S7S(
M?,5\UWSH?&Z"J&:_?\Y_U7_E?^%_YG_I?^Y_\W_X?'=]IGVN?4=^FWZXGK2>
M<XV$C92-D8VQC6>-;8U'C$F,2I%0D4Z13Y%DD0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````&*189%PD6F1
M;Y%]D7Z1<I%TD7F1C)&%D9"1C9&1D:*1HY&JD:V1KI&OD;61M)&ZD56,?IZX
MC>N-!8Y9CFF.M8V_C;R-NHW$C=:-UXW:C=Z-SHW/C=N-QHWLC?>-^(WCC?F-
M^XWDC0F._8T4CAV.'XXLCBZ.(XXOCCJ.0(XYCC6./8XQCDF.08Y"CE&.4HY*
MCG".=HY\CF^.=(Z%CH^.E(Z0CIR.GHYXC(*,BHR%C)B,E(R;9=:)WHG:B=R)
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````Y8GKB>^)/HHFBU.7Z9;SEN^6!I<!EPB7#Y<.ERJ7+9<PESZ7
M@)^#GX6?AI^'GXB?B9^*GXR?_IX+GPV?N9:\EKV6SI;2EK]WX):.DJZ2R)(^
MDVJ3RI./DSZ4:Y1_G(*<A9R&G(><B)PC>HN<CIR0G)&<DIR4G)6<FIR;G)Z<
MGYR@G*&<HIRCG*6<IIRGG*B<J9RKG*V<KIRPG+&<LIRSG+2<M9RVG+><NIR[
MG+R<O9S$G,6<QIS'G,J<RYP`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#,G,V<SIS/G-"<TYS4G-6<UYS8
MG-F<W)S=G-^<XIQ\EX67D9>2EY27KY>KEZ.7LI>TE[&:L)JWFEB>MIJZFKR:
MP9K`FL6:PIK+FLR:T9I%FT.;1YM)FTB;39M1F^B8#9DNF5695)G?FN&:YIKO
MFNN:^YKMFOF:")L/FQ.;'YLCF[V>OIX[?H*>AYZ(GHN>DI[6DYV>GY[;GMR>
MW9[@GM^>XI[IGN>>Y9[JGN^>(I\LGR^?.9\WGSV?/I]$GP`````0!!$$$@03
M!!0$%00!!!8$%P08!!D$&@0;!!P$'00>!!\$(`0A!"($(P0D!"4$)@0G!"@$
M*00J!"L$+`0M!"X$+P0````````````````````````````````````````P
M!#$$,@0S!#0$-011!#8$-P0X!#D$.@0[!#P$/00^!#\$0`1!!$($0P1$!$4$
M1@1'!$@$201*!$L$3`1-!$X$3P0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````$!X0#.`>``$P'I`!L!Z``K`>T`T`'L`$T!\P#2`?(`:P'Z
M`-0!^0#6`=@!V@'<`?P`Z@````````````````````````````4Q!C$',0@Q
M"3$*,0LQ##$-,0XQ#S$0,1$Q$C$3,10Q%3$6,1<Q&#$9,1HQ&S$<,1TQ'C$?
M,2`Q(3$B,2,Q)#$E,28Q)S$H,2DQ````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"4!)0(E`R4$)04E
M!B4')0@E"24*)0LE#"4-)0XE#R40)1$E$B43)10E%246)1<E&"49)1HE&R4<
M)1TE'B4?)2`E(24B)2,E)"4E)28E)R4H)2DE*B4K)2PE+24N)2\E,"4Q)3(E
M,R4T)34E-B4W)3@E.24Z)3LE/"4])3XE/R5`)4$E0B5#)40E125&)4<E2"5)
M)4HE2R4````P`3`",/LPR0+'`J@``S`%,!4@7O\6("8@&"`9(!P@'2`4,!4P
M"#`),`HP"S`,,`TP#C`/,!8P%S`0,!$PL0#7`/<`-B(G(B@B$2(/(BHB*2((
M(C<B&B*E(B4B("(2(YDB*R(N(F$B3")((CTB'2)@(FXB;R)D(F4B'B(U(C0B
M0B9`)K``,B`S(`,A!/^D`.#_X?\P(*<`%B$&)@4FRR7/)<XEQR7&):$EH"6S
M);(E.R"2(9`AD2&3(1,P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"()(DDBB2+)(PDC22.)(\DD"21))(DDR24))4DEB27))@D
MF22:))LD="1U)'8D=R1X)'DD>B1[)'PD?21^)'\D@"2!)((D@R2$)(4DAB2'
M)&`D821B)&,D9"1E)&8D9R1H)&DD`````"`R(3(B,B,R)#(E,B8R)S(H,BDR
M`````&`A82%B(6,A9"%E(68A9R%H(6DA:B%K(0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````!_P+_
M`__E_P7_!O\'_PC_"?\*_PO_#/\-_P[_#_\0_Q'_$O\3_Q3_%?\6_Q?_&/\9
M_QK_&_\<_QW_'O\?_R#_(?\B_R/_)/\E_R;_)_\H_RG_*O\K_RS_+?\N_R__
M,/\Q_S+_,_\T_S7_-O\W_SC_.?\Z_SO_//\]_S[_/_]`_T'_0O]#_T3_1?]&
M_T?_2/])_TK_2_],_TW_3O]/_U#_4?]2_U/_5/]5_U;_5_]8_UG_6O];_US_
M7?_C_P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$$P0C!#,$0P13!&,$<P2#!),$HP2S!,,$TP3C!/,%`P
M43!2,%,P5#!5,%8P5S!8,%DP6C!;,%PP73!>,%\P8#!A,&(P8S!D,&4P9C!G
M,&@P:3!J,&LP;#!M,&XP;S!P,'$P<C!S,'0P=3!V,'<P>#!Y,'HP>S!\,'TP
M?C!_,(`P@3"",(,PA#"%,(8PAS"(,(DPBC"+,(PPC3".,(\PD#"1,)(PDS``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````H3"B,*,PI#"E,*8PIS"H
M,*DPJC"K,*PPK3"N,*\PL#"Q,+(PLS"T,+4PMC"W,+@PN3"Z,+LPO#"],+XP
MOS#`,,$PPC##,,0PQ3#&,,<PR##),,HPRS#,,,TPSC#/,-`PT3#2,-,PU##5
M,-8PUS#8,-DPVC#;,-PPW3#>,-\PX##A,.(PXS#D,.4PYC#G,.@PZ3#J,.LP
M[##M,.XP[S#P,/$P\C#S,/0P]3#V,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"1`Y(#DP.4`Y4#E@.7`Y@#F0.:`YL#G`.=`YX#GP.@`Z$#HP.D`Z4#I@.G
M`Z@#J0,`````````````````````L0.R`[,#M`.U`[8#MP.X`[D#N@.[`[P#
MO0.^`[\#P`/!`\,#Q`/%`\8#QP/(`\D#`````````````````````%<`````
M`````````!$````_&1D(0QD9"/3Z&`@`````X*(>"."A'@C@H!X(````````
M``````````````````````````````$````!`````@``````_P!@H!X(8(PE
M"`````"DU0<(W-4'"-RL"`@DK0@(B*T("'!V!PA(=@<(1-<'"/S5!P@XIP@(
ME*<("/"G"`A`J`@(O&D'"&QQ!P@\<@<()'8'"$!J!PC`:P<(&&T'"$1O!P@D
M<0<(Y'D'"+QU!P@```````````````````````````````````````$"`P0%
M!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R
M,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%565UA96EM<75Y?
M8$%"0T1%1D=(24I+3$U.3U!14E-455976%E:>WQ]?G^`@8*#A(6&AXB)BHN,
MC8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BY
MNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7F
MY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`!`@,$!08'"`D*"PP-#@\0$1(3
M%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`
M86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I;7%U>7V!A8F-D969G:&EJ:VQM
M;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:
MFYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'
MR,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T
M]?;W^/GZ^_S]_O\`("`@("`@("`@*"@H*"@@("`@("`@("`@("`@("`@("!(
M$!`0$!`0$!`0$!`0$!`0A(2$A(2$A(2$A!`0$!`0$!"!@8&!@8$!`0$!`0$!
M`0$!`0$!`0$!`0$!`1`0$!`0$(*"@H*"@@("`@("`@("`@("`@("`@("`@("
M$!`0$"`````````````````````````````````````````````#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#````
M```````````````````````````````````````<``````````````!A````
M/QD9"$L9&0CT^A@(`````."B'@C@H1X(X*`>"*"D'@@`````````````````
M```````````````!`````0````(``````/\`8*`>"&"D'@@`````--`'",C1
M!PBTTP<(F-0'"#2I"`B0J`@(S*T("-AI!P@`````````````````````````
M``````````````$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C
M)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]0
M45)35%565UA96EQ=6UY?8$%"0T1%1D=(24I+3$U.3U!14E-455976%E:>WQ]
M67^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJ
MJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7
MV-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_\TAQ3?<
M0MHLF"N_"A4Y20\9-&,F*$S?!JD?OQN<'@86KPBY4_861A_S$DY)OTE80<$?
M.!B]2O48Q`F,2F0_TA/"'PP7.1B1#P4Y+BV,(4$B#3Z3++TNJ0=<1G]'TB\F
M-^(L;S*G.@\1<`PM",E13A;T$T`I"2<F2LD@R2D<.69,>CI9.^\4#4=Z,1!'
M[@SC2,Y#)1_Q2%%,3`W[)7T09D!O&U`UMC\9!+X&OQ*N/`X1[4)@$$L8_A,,
M!S@)YPC'-ZPUGQ$Y"6HR"D&>2',2T0>Y/PH.(E)R+VE,V`Y!$(9!S$GY1'$;
M?`/M'M4O0@W-$GXN=0PB3CT)I#+#1OQ$`T\>0X,NERV:1,A%BU)O-%$%UB_1
M28(ZH$GW4`X7YBGY4G('<#2`!2=0W@L_2-Y/EP7R0I@TWCC%!$`:^1?$0Y04
M8!$Q+.`&'!C6&G`6Y33D"R5%(#CR/KL3MB-82246D4I0*\M%G0.;*!014BE:
M"/H)QD9?4B8V)1V'.OH,R3M$+O0>EQ_N"=U0#%7""OHH&B#0.?T]9#CW/A8'
M%RWV0\4^RTQ\0K1%/A:!(FA![4E=$U0FQ!ID'Z8RUC9Q+\%!G2NT0EQ%60X_
M";11MR-/.N4:3D0M'7T&"PL3$A9'&P7_3.5$(PK6"$=1Y`;6'W-(>`SO)88_
MN"/6!WU4OQ1_/8TY[RHJ/&0+/$6C+TXQ%11G'T$[9![8$6-11U14*:XZ_B3%
M&E8/.U0^!6E!]1\&+9L'ZAS12$$W73,62Z0)>#)<-E52F`LV0--,Z`80/<9'
M@A*=/`]!U1!&"9PXFB%?#C<((`7Y2-49K$CC3\,**D<13+Y%7$^["X83;P7*
M4:$KB1NM2:E$JT:1!_4/"PB94$P^(06J3FD>-T#I.MM1#3NI0M1-!S:)+EY.
MD!W/*84.>#R?%VX>XT&/-ZLR[2#8!Q$+RC8E!55$TTMW2%P\F3M(2%D1Z091
M'*!.A16R!\PDI4O>3G%4JB_!.C<+W$RD3ZI4LC=5"WH?4A?X3\DS,D=N#K=$
M)R@F!7DPW1Y")K`H$2I,,@)#7SQB2X(/3U.4-R<SH!_(/O14)3%N)`<),Q9A
M,?\-B`A00#D;`P=Z&D`+RSUI#?H=:1*10R<@[1`+)S$'MA4#0Y)#$RP&20H?
MCQQ),Y$2G5*)`[HVA4E4(6$NC@@^2H`-JB()'1D+`!X_-Z).R0>C!M`#`3RP
M"FH(\B.E+0\?MC(`*WM!-2X/-*8M^PC4)@LIU2+]!$Y-9`:O3@I2HSKS2XH7
M\S.7"<,E_#Q=0!4H^PJ:"&HUJ#FB&MLE@"FQ3J0NI#RM1]TD.BVD3DA%&1`:
M$)<^Z`@3$141P1Z#1PHY9SG^,B(5L1<U.(L/<00C%1`:MS]P+64F=TP-%UP]
M"3']&R=*;"I@-4)'8"H!"(L?RQ63'V\JD%)%%;M%O$J5(5-)+BLG.?4J9"!C
M(NXKAQ.71'XK"3PC%`<9%B_Y$@$L(C*:'-$ZN2IP/J@5:!_K,WD/%A2=2F4#
MGR79!S,LG%-D#%TZ;!`+'PTG"D+##WP1?1'K'P(+]5!T$KTLA%%U$GD2=2'U
M$\HPGB(@%ZDU2`L2&Z,REPP6&T,-<S_-(`,E^A++-,$.`BPM)R12AP95'E8>
M63>M"-`46POW(H$00!%:'N8+3A^'#XPI#$]Q3;`,#2)<"%P+L0P%)102L0B$
M,5T+/%0O%,D$6A#2,[$/+QWJ&R9'ZAIC$*4^,$'/%:$X-!W6#'8A7@LN"[@(
MICZQ*!0ERB]N-UDBQ156&6)/SU,&)GT@GR>5%@$>EA9,'4T=:CP4'%<=6!T+
M4IL(O516+$0EW%('1^X>,B)G1(51TTFH4EPL8R2L(%XB'$@]/TM$ERS!(EL>
MO28.(O8>;!0&+%0*-23,2P\BKR#3,Z`H>@=M"(@AHRM\#]E%D4$'2H1&Z$"D
M.&LDLBAZ,$4Y,QN2'?0=(37J0S-*]2!L$9H@,#Y^(#L-[BF)1HI&'2FV)58)
M:S4C-2!.JA_L!$@JD@73$]03QTF/+^X?QCR5%-`0!!77#-P?"A55+<X?4$F<
M'<$AKQAQ-'X16S/C!\0BNQC43'P6<1HU#3$C`B8')C@[Q`_G'[$T<4+;(81'
M?S3`1M<MHU09.7)"HC^C/VM$*`V*&_DY!!:Z0:5$4!X]2/HSZ#<["LQ%*34?
M(WX;UA#Q0<0V)D!54#47_D8Z#GI/,"]8`U@S[D:L43`J#CT$.-T]RU05$@P(
MGDV@)88.WA[B`X(6UT>O)0@)[R.P)6E'ID?'3?<4WB8*-LDT0R+&)-D/-E.K
M!ZP'KP>&`Q4-:3GB%2\$AS8=.;13>!SG.G\;;T!]-B<,S!4U-#<*#1`Z&,TK
M*"K^12)4F@SB2-$NSAHN2<`*L#.>'G,'G!!/&#]!YRQU1H8/G1AJ%$(A]RB3
M%(PJVS%"018>(TXX"GDXTS[+0,@0L3BC((LOSD"N*5,U/@XB.8Q2TCUW0M])
M^#&M,"E4N$7@2?1#S0S,-!X7\SX$,8D&`!,&2+X7^!:_#%,_&%5U!\`['T/D
M&OPQ01'+$'U"D5+1.4Q$E")P&<@\S!`!1KL6?B0</DY%14P=#\,M)T4*,9@7
MF4T;*`4Q-"JF5,L7?4-G)/,P<"8D!,\K$BE".QP3$!<R.DY,715>%6@$(A?Y
M268<8SXE0X<_`B5&-$$)\DX!1X@/WS$B#K0SA2H5%04]0B)F)EXD*3=%5/I`
MS$H#,AT1^S*\`PU/JPY?3(`]T2/406(#=2Z_4V`.-1@$1*Q#UCYK0=I`^@Z&
M%>(QXS%<#48_,%2-!7X,T1<"1^0Q8%!G)C!#&DO0%0)/OA9Q*7DM#P[N-!L\
M\11Y/+@#8@T33650;U)I"%\_!TVK3F5(I"O4&$Q.N!FY&2H;0E(-0$8WX$7:
M&6<0_RUS)A1-XS8$"B4SRT<Q#8XOL`>?2]X_7DO3+PX%\A3V3O(:'3U]2`(8
MS3($-Z9+@!A^1-DI.`@&%TPV2#\T&STO-$&O,OA3CB18/Y(<L#OP"[@V\Q3V
M+,DRP@7E`_PES52$4'<L43PC'GP*QAV)(6`\<#=H`UE$*2@41,(8>QK'%M4N
M!$,53_4(X##H#=$IWQBP$VD\YTBS-B0>6D0^&>$I7#5O)%U$/1LR(QE$B!>M
M*2HS&@LA/&P-U4:[$/54;1$+"C,:P@=4"T(,:@T[38(C!$(0,H87"":F130:
MWTJS1@4N9CJA1S%+Q@RT3Z!28RZ'&KQ$*Q[=370#L$NM(N=,A"_8#>]$-A"!
M#?!$,C"W2M-4-RXS#BLDX3OU&N="%DE?$$`P>%(;'!0?_`B-1H<J53U/*)@:
M0P?U2Q(NXDHD&=DJ2!AR4#(EK2<*%R\M/BSJ1\HE9"CU)U$L=PV8"9<P-##8
M0XDJH4*`$(TB;4>?"#]+(`^=(^,[,$2S"WL9!QM94QLN,420!STER`AQ".$E
M@$IO*<-._#HW&#]/X!R+3O92"20A+E(UVR<]&HU**"ZC/L,A;TV4'T<P)$[S
M"S\:G1#.%@X^;C[/%D8UU#70%NT[TA;$2L8:(Q=6*=,6-`L.0*!-WC1X(C8Q
MITVH32!'LSZ$/H4^ISY'*7\:3$HK*38I"$>2/OP]'3&8*)\B[!_Q3"TR+C*P
M4Y0-(3+?0E<W]"U=+&`<B5&`1M5)I#,[$C0BZCYA$I@%21]1#AX?V!L;"A\?
M%2]U/'8T8%'3%?8[C!]`2,$2G"@;-#X5748R!#`G_U)Y$[(8K5'=`_L,2"_C
M*^(;^A<0*<`+/0J22J(8#A`]4`T3*A9O2(<0=!9$""%(;41N.>(&61C1#&0A
MEPUP%[H##45^0Z($PQ))!/I)!TM"%])%90N',UX%S1$J-<Y+1B%('%L.6B2E
M(,H>75"Y)BX9>P>.'^5($`X81^\T7SO$,XP_:B!J*0-11R*0"E@/6CR<!PT+
M7P6;(780"$II49M3C3%K((4M%B)'([4MHQPQ%`E-UQ"J%?\DQ!'S1D@CS`,R
M.%<M9C[5"8P9M@4])K\63%/<!(M,5BI`'E4V_4CP%$I4C$S;&=X0>$CT!,4+
MFBH%"10_!S&E$E=2LA[/'C88-A1W"YTAOS#*)$%%TAG]#VD_"$:&0I8;IR)C
M2]E+>2$2._,X<ROJ0-X)?3XR-412IR6K+[D$V4X0$'`];T$?485&YU""`P45
M8$>?(9Q`N$3.)_\65"3V"*PO:`5Z";LHABC$+K(RJ"IX+*@^$3H]*%8&&`CO
M42!0J2&U#H<)<5$$',46]3(''W0.9@S81\L[0D^`,GI`AU,,,Y8WES=`!"<Q
MJR)F#VX1.C4R$)$,=0ZI.)(0E1`U/`,.J"Q,$N<9-CS'#`))(E-.'0\$Z#(0
M,RPB34H<,+8.?QWI2#P'.SP;)((@<1FD#70UNS*.1BPD9T**`^=&R0U7-A4?
MTR3L(F4H;D=#/&%`<AD7*!@H?C;+)0$GH`B61G-'OB12!'`_R#9K4R])YRD&
M4VY3T1AH(]48X45N(WLY1"HS$'XY0TEX%9X=H1*53S@&/CM%-3$GLPQ91<U$
M3"WJ0LQ-8BI6$-`SO"Y'%04R^RHG*X@)+4_A%5D4KSP*/'Q'?@4.&T5./1P@
M!`<1#`Y6+ZL@;D27#D%(K1EI(8A/1P4&&@(2Q`[/1E,%"`3I0/@PH$$-!),=
M`R9K$!E.E!U5.6L2]AKW!2PI2`DN#R\RPQ^6+E<(\$*E$<`;31@E#=`27Q_S
M%M=`)5+=+FL735(E3L<2^`G0(%U3N4?H+-U$/1)V$J0_Z`\S!+53*5`#+<Y-
M5CXA0^%)EQ!>+)P%(CB8$,`7N452$?A0Y"N5!-$2,B<C5&(U73<'2/4IZE-3
M(+HU<`^`&\`3X4,X&9,@0Q6?'*`<VBUB4<%0>4,F&"L6*R&/(KQ',BR^)G8O
MSA!'3$]')SCF.'46YS2L.EH8?T/L-\8)ID0U*ML2LRP3(J,+I`O^/2Q%&BU]
M3-<P:BV^42078%.X,,P^@$-&05!';$')051'?DR-.HDE_A]_4U0Q*D/`4UD/
MI"AO`YD0(RB**Q<,!C'_'YT'1B<%1*XYY3$D&HD3!T$(02T\Y1'F$5T]ABWP
M-&X?*Q]$,JP./D45&6<_OB.E2FE27BV*$U<IS0-)(\U*&4<`()8EF0XK0R\9
M4!F;#:U(+"V,-GX<33X63=\_:0X.-KTJ,@U>-GHS)1H107PR>`NU*XT3EQ[V
M#W9)6%+<&8PKI`,<2PE&01[@/PM1(303/;!$*S\^)G<J9C54.DDP=D!'/SP,
MUAAO'MT$F45./E,6GE1^2*I-Y#5--I0GP"H'+P($L"DJ(Y8ST5"K34(>Z#4F
M+"-+%#OH+;8\-2\\)%DMTP0Z,#1*+TTN1A4J/4FS(:I+MRU7%N$>.U,63Q07
MD2134!H9&QD*!&(VM2F',&\5=D$K,RX_UD^Y*SI#.T.`+(@F\"5:&5L6]`UT
M4:A%04E2&05",R.)-=Q'A0C)'<(JMA%O$0E#3DH8&"P>N!%8.6D[Z3(N)AE&
M\43K+6</3TJS!XL#WBTX+K$IN#VR"A8?U`NP3)4P_C4T-@@M/$<#/#=+O#($
M3I(K>P5?.$1%ORW%#\HGB4T?).M'="<0'M\M(2040T!+!SJF&@LU8"M")2TI
M=$?=4B,DRB#E4_Y$B#KN.T),1E.`.]`K&`Q%,N%&HBT"5!TE9D95!_TL%BY!
M2RXI!C;W,SX<(C:?2%1)2A^34^=251CC.&I)L3T+.<<)2C7_%/M#C$^\#5,X
M`QIK*V0BG@>M3G=-'S3^%YU0.ATQ+NH&C1FJ,_`X,BX"'T<NXU'=3-\$M2(S
M+G@@K3/#&/@X-"Y9.%5`F$2V(H`:52%?2HY)Z02#,Y$*Z@2:$@\I'!#G,#=3
MW!(4(J0=.5.L1MPY(Q#'#5(>*1$J$:PYR#<_++,F6D-;0U8CL#^P)BPJL3^R
M/[,_;4B($"8C0U+V$XL5O3[[$_P3=$)N!:0>9#W6#K<XO5"H1($MRD'+008J
M12BZ,$0]%Q*Q1`0I)`B]1(D@QR";)L@@]5+81*PM/#_N0FLEP!"O#58:WB>O
M-8=!/1<<.,T*)4GK384$H$C5`XE!6!["$#X2>#]K,G<QGQX)50I50DA4("D4
M7T;5,'<EG3UX-`$3"3\`,`8$W")Y-.TPGCTT)QT*KS`K"*$$&CY@1C0&PQ<1
M(IDISQ!^$_(.GR@+$1<1P1/:-&))KBSG.)X#`D"%&6DK4"7C&W(/`T!)3'X5
MOR9Q2+H=HA!O1%P'1S6`$D$M4R4(3(%#X36]#2XXR`EQ/N44;Q2Z0L5*T4Q;
M)*@A4D,K-8<*U#OC)DX9`2"_(_`K2B-+(Z=4JQ7T1CL46"E9*4<G6Q`$4<]*
M?0\F%P51.$`-,&L>J%1W(EH/T$KR4S-/W1F-3"I(AA)3-"M(%#VN2=Q1/CG?
M$!=3DB$6*8Y'OBHL%RL;NAGO/9M!CDQ+5.DC"");1UQ'/T!,5$D(8#OG(7LS
MFS%^/A$0\D'K0-H'?3SI-7,>9@.5)Z%!!#-8!8<.EC+:2P(NI@ST.)`VPSI4
M5*P=@B:T(;D(#0\<"#(/:CX^*-%/TD_F`^\'AS31,F<,T53$#<4-/D(P38`O
M[2?K0R4(!`=^,\H=.$=P).I/BB:+)M(>DQ#J5"D>^2".2,L=CTCZ(+5/4$IG
M1DDM$4D228A)#"YC0Z(;P40#(EP6?@X0!.)4\3__-<H-@B>*'NA,!T[\2B,V
MCQZ\)606]B?W)W=+*4(T(*$(D4L!(V]'3RT,-3<)5PPO*9$.D@X=+G5'=D>R
M1QTC=T>=(LT9(!\E"=(F0"(1,1(Q7C0X42I0:TG9'I0['C70+_02=TXD#_,M
M*!+J+HI1"1E4#?T,7RP"$V<L[TGP2;,P(S*D("<V]SD>.D,SD5"[.$LU"`U+
M%KLP'%#P'&@_"PU$-X\QW0^/&"Q1FD400!E*J`3`,/\.!A4(+[<\="N-'/(\
M,!HT4G$W5P;7%A=/S2RI!%,?O`CY4<88U`7@!1!0@"L1,WL(31('*ZL$LPK8
M*^D*B!YJ0_XCEASA!AL4R!O7/2Y/.1:&*H0S0Q#_1F0$H!Y>4]Q&YPL;/J5)
MME&6/;=1_4-R/GH6@R+V*BU,70?C!O,)P".+&[(ZV#GD,QA-RBO5.A`(KT,9
M$ML?YQ!`0,\GY$+6.N11@P?*,]\?X!\J*`I+%`V\*#5*Y`J&/F<Z[43+*PD)
M=T$=$CL652*N(ND%ZC(/)YPF9B@H'))+%4/E/;M+0R7G/9I&'`[L,$$:!"U"
M&F(2.R"%1]=.*$D]$<`V/A%'.=<.`ADB05`.GQU'!$PX]4^P/%H300X9"<)0
M8TFM(,TW<TUI'\4.]D^E'>`RIB^W!0LX+SS^'(@43!'#!5HB!1V2!A]$;0W(
M%H`=>!@Y*\P6;S\<(=(;G2AR&G,:B4F*291)Y4WF3:Y`O4?Z3/P)Q@[;2V(P
M%@JQ4R<_=!LF4KH_#0XU)P,3P#_"04`_[PF_46H?%@P^41D,6$+R&\M1^0MJ
M4L$CJD2Q'C4=0#E_'#L&CQ-!0+H$\T$.47TP(3WI#1)1C`9^"E,)D$B(&J\J
M'RBZ0P`%LC2;))4U-P_-$Y<UY1//21LYLT%I$11+YBO,0(Q!=1MX0J$>>3_U
M"_9,>#%V#`L\W#YL,KH:3$6^/_-"KR%5(.-)U@3G*V`O82*6!#\MPCVF%5L@
M`4Q6#F$^!$S5$GE"G07L2SM&^`O*!@`:=D;;+](YPT$:/,A+8"Q$(BDY?D*`
M)"<8QB*8+)11<$27/?,.F1=V%DPQ3411.K@8'#1#&E4*9$E/1>05&B=`"LHW
MVS3Q39,OX@UB&OY#,2K/2W1-XB_S30I-=#ZO'F%0&R>:%UXS13U\!ZDRS4'V
M*0I*(QCP"9)!#"5/)/H+"TJ*)5,MV!"401H,Y0T2">DJER4.%@D653%)(H$]
M6BGD09PAI!:V+2X0X1:N3WQ-S1[Y&^0F"TW:%_$T+CQ)/?PMI0NP&N=$NA"N
M.VU4I!S42^8-6"U?3@`/F@L#-!$()0:S&DU4%3TL!0I&X3^=%$)`N04+1KL9
MI2O52P8RL#>F2G4)>RHH,ALBA`-D,X]'7S9N5*XV'4LX-0<5-4X<.Z,Q@$C"
M.@D:F!N,%7D@7PNX+7]$>B$A4=Q+^@?31FXX*@>*(8M"RQK>2TM(J"7E-K@\
MKDKH118\8TXT+!\5'0Q^,,XLV!9I"L$'O`>Z!V@,%"S\3TD^"P02.A`6.S7W
M3N$?_B7;+L0Z"!\,2QLIM#>I/O@I4C(0./$S>PYU42LHOR!H,6,Q/$W+,(0F
M*PSR2W\*^E%*/JH)$3*)-+8O-P40-,P=90H))LXP-"."&N4)#DL/2V!"84)N
M#3<\E!!1$",[!B$:"!I$<1%J$G$DDB0\0Q4LC"9X0<,'^R!##)A#4CR5./@O
M44H*0V0N;PU3/%8?N#I)&X-`>!FB,YTS@R#[!RXB.$M22A$G"3=6(6@9C`,^
M1XHCZ$)M"K%,$4OT#"@KC@,(*R@0NS%9+/4C[2JT"@Q2LR[H"E!(1`<24NXB
MUB+V2_(2KB?9*^P)F1K.""`D:ADT1GLUT`@I')`@?!D6.%`F*RU$*Z4\'2%S
M4T(4Z$U\%)L<>@_[#I<';!Q.40TCZ$_2,HL4!ATQ39Y'E$+M3YI"G$*T-`,9
M!1G!$!XY/#UC*J@.P#=L2:I)D$<W-)PDH!%(-IY.%E#5#E=,;R(^%QTX+PCN
M/GD5B$'N#;`U,`AM,F$<;$P%!+E!BU&I4>\-?4?,(B\&[1_-0,L8[$VR,TTX
M&U%&3GH_9BW^,/\P,03\`P5/)D[+!I!1%"T/,:%(OU!83PA(M!>;+?!(4@K=
M+S\<R"IZ-`8+01S'3T0OW"QN,O0^901##EP@=R,=,CTR&1@J+A85E0P^"G%$
M!@@;&E4$N%%Y(W00=1!O+MY0EA08'G0/WBS`)EE/?RCT#M<@N"9`(!1')D/-
M3/@^'`?F%#<]S0DJ-S8BNRIP+O8?H2_K'&(WA39S1#4(HA+G'?<?YAIU/@`Q
M,D^^.ME(WB!^/WT'^%3U2)=/@"C2.OD^I`0R0*8_CC/_-_$KX2IB$[<-"4&F
M(/I-;%2"/64^2P6&-OU4$$%7,=`)\S9,*>PS,A1'#L<:D#&1.4@R2"<:1P91
M:";6%9\MZQK'1QY1H`?#!D<]BU0O(N8N.1XW+-44\"KD-LLOJ"[U'`Q1MA_V
M'&%')BU!&#@PXC^O-O$M03EO5.A0KD;@&3P&+$B\&9%'R52;10$BAAM*/9DC
MH2-V";@?>SXF&LT4DPH21+)$>C(Z"`D%>4CC/^T-W4!P5,X42Q6X,^HU,S67
M"HX[@COK-:TO[2&!2,(-45&*+I4C:S1<0P,?TROH$&H+;S?6.WY/"B^I);D\
MUQCE44H_QT+>0/,R<CVA4.D0HR[[-)!/<$$-.+XA[#6F-KH(H3NZ'WT*3@O9
M%J<2=@X,,MXZ*B:K"0@*$1:]*#\H<U38$QP9D4_V,JL\5QG\+'H=6!:+2^P#
M^U$&+ODIS0A;(L\*$3BJ/OL=>0A4,GX&JAV&2%(553(^&X$P820W$)5#5C:7
M%JY./TH]0ZT)2"V$&$$6R`S/+0XG(E$U&@(>S1OI!V,\3@T%!T<)QB`;1$X%
M;1/+4R\_&3&Y,S00/QD#'MT[2S,#00L=LDLV+8PHS%,>3QLQL`M1&XL-"C?<
M,TP>G"(\#8=$"TD3!(0@#$GW$/$J.BO.&P0\RPT>)$L@X$A4-AM)%TFH+?<:
MBQZU!CDNCQ0-4HD>A2-/+&0=CD37)B0\803N.E`H2BF*-0Y244CM)(P'J3E5
M#-0M:T->(<PEJB.I&7A+9R@9*%TR7C)C,O\C%D-"2[(J?0AY2U(,DD07.)4I
MM2I%*Q0*LDXP*24\XB63#D\_C@T2'B0DZ"6'%HL6+1NU1LXAH4GH$W0$[S"#
M#F(B!RR/0<P7"0@,"YH4VD4>'G`)FE!E$-=,:03;1680`"Z:#EP0&DH)(LU'
M+AM8/E9$:!`N2*M"$"QI`VH#,0[K4.4YCB:*-%I%MDD%'ILW!A[64V!*+R;Q
M!3@E8$1A1%M&?3&%,>,@F4^:3WL$ZDP%)&=`>SA['(`<WDPE'EH^JP_!2L(R
MFC3-3\-3QU/-4YLS]";74QX+"A#?4J8>;A=W+P5,V2R&,><OCR?>$MD1+A]"
M4*])U3<['1`1!%)R$6<P<Q&^3[$B=SN^3-,;]!OO&FE$E#WT.U,.C46N"!A(
MY#CH*^DKU#YS"V1!%@6&!%D>?#@0&=01B!8`1BL2I3.T&$M',4_5$64X72`C
M2,X&/4;P,,-0.2>6%V@L.0;01:T:>U0M.1$2'@^;0%0/;@//!M<#XB??(K(]
M[C@%&@-&!".0(N@=^1[!41\^?QC#$])#11=)(8)#1B.64LY!H#AB4&-021>=
M%X\_A#W$4]I4AE*"-Z$MYD'G,2!1&TK!`Y4_YB;<",4_043Z$3=&?4ED3BH:
MP47U*]-(EDNU.4A`VS-\*B`M_QPO2'D+ATBQ.S@Q_!U](704[D`4"0TRI!?9
M1[$E#QSJ*K9.OD2E%X$L!`R\+0)0@QI9%S!&.@N2)E0\5Q^",/4F8D)32A4<
M$QH6#0=)"$FW)3P\-SY%1!\273A,4(L784KL0QM%=C<('OX$@Q_E1X\#&$DY
M-@LKQ"6"">\B%P\8#\M("!OS*`,V_">6*3$I4S>F/+-'X%+@3=A)M1B..>P'
MACA`3\`'XT5T&O=*9C,X$B0P=00Z)_X1G#21+K,]4B3,5"(LT1G7/ELQ($M2
M5-8_.#Y9)'(D_2>=,,HY!CV6-1T$<1"Q#6XE.C2L'W\%O@GB"THV-C)M3"A!
MGT9_$254LS7Q/E0.+2KY"=E)U1/Z%%5)H!U;-Z4_Q1\N*E%"E$T-$E(/]4)T
M"X<Y2QGB1%,NP0JJ.N]-]1X>&T\JG@78`T`2YDG2$A4M$1GO1I0/]D1B2+<0
M/%!83M94?3A7#E4HJSH6+?E"CCI20MX5#A-I+/))\DCW2"XY]BV&!65)GBV1
M(\47!"^`$2Q2!`W!"U9(UA*+.>(WK3HH.!DMT$NY45I/6`U;%1,QW@,/$Q@'
MB1!X!8E/CSH(4V(O(SG?%48(ITC5'[XGDBJ`)=HUYTZL-LU+IT8`,I)0;4G'
M0^-0C"7\-HXAP@:@-5L$H37E!NU3GPK]2>D+,!W75!L1,!$!35@1%Q6J3XTE
MF4K^23,Y'1,I-FY)=2+_,]@V>D:*$&8+FBQ]3K<N%TMF'K\GX4^H1IDVFU`'
M!=\]>R-P'R('3`5I-M=!/B3!)X,26#'10#$A!10).TTT,$P<*)8O;U-A#@5&
M>C[U3D],L04F#B@735'!-2(%\1RU&9`_H2Y,'*$]]1L&1/PHNB(?"$,2L#J1
M.J$/IS.'2P,@:2/!4W0(.4!Q'PTEQ`;B0L(2SCS-4<(C^"6G4Q$E!S+6!ETI
M^PNM,IPQI@>!"&90!1+S+K8$M!K7">E.H24:31M-KQ6U%G\/-!3&/[D,B1&B
M">9/Z#%_39)''$W?-!Q*I#5=,:E3,A/'(XU4CE0R$EL)V#.*+98_K"B#%T0>
MHPI!("(@V`G^5,HRXT80,,53^U.:!JDO/P_T"MT(VBHP&?<<5!:'0M,-CA:;
M#D]1(#7;+&43UQ3,+Y$W=TDV.'@0EA-)0.D_@1Q35+,<?DD[0M1'F$>T'-],
MWA<705$PQ`5G2,$6GT6/-C!(HB-B1TD%*QH/([,>$"-9.HP2+3^,&\\L?2I_
M(MP8]#V;3!E,_@M(1DE(HU!2,`-)=!X$22<ZDDSJ/Z,J3#V2&W4>'C;D&:0D
M_#2T0PXY,3R>0$@XVPH5,(0<-DK33T$3K"YW*Y<521W$.[%(-3>Q3354*RP=
M.XX<B$A^'A(:'!2!,M(ILDWQ-?DX5%&C0/4][36"/)Q/7SJJ./(A^D&2%60Q
M7Q2&.PLONSRI%'L+K%!V+IX;3Q73,IDRJ2KM14`4K%,:/R@S6TB)#H4<\%'&
M#>XGVC9"0C\;*R:$&JU+MS+H%M\3X!.K/E@9'#=K#+,O.4R6'1\9Q!F8%@<N
M0$I/%+<A719>%OLI;%!G4Z8D5B1["04,'B5I1=TS$SH4/A06&D\D.[`DB2A@
M)G\K+B@K"24[]2%<!L,HNQ^&4&5/HSG\*=0L74BF/;0O)5,V-P0UOAP&#$`;
M.4=N1D<1MD9X4<Y4)0P[,>@Y61DZ([-0G#<,0G\+MPY.$4HL?$&"-2`GIB<P
M,YE#A#:.$=A/B20_3BPZ.!"P"8P\`2LL.P@A/3R)&DH;I2XP/T$N;S8Y/D=/
M41(1-&@U+QB',G$5R">4)%`48T*L.#94SS:K&XT/.Q]9'1T+\`RF.8,=%"<]
M+?E*D1IW-^-4,D:T"1T4+R#F5&)*/C&5$E(:I0T<'&X[T##I"?P*+E.2&JP;
MFQZ''%XY#!WL,ML-N$E\!KDZ^#>])>-*W#P&/),KOC&N/L8&^QHB'%PRJBT\
M+D=)9Q1E'1)+>2[H,Z1'OS&$*T]0G!:!"U@;%2/E,`@.Z@JS%)0K^$L44@X:
M7S+6)+4DJS:1*,4E5@P?*=PKGAK++O$H#U)4%,</PDW-)2,2V5/P.A8FLAWN
M"O8SQE)L*'%'TR7'4IH)D!X`$?LZ;!D8+EI-_B>N(]X=;$-J%DP@,D1W)T9+
MV!P`2R1,?DN]0VPN30>C"`8D3B`).AHXZ%0I#`XUM33F!^H?84V&*>4E6`PR
M*9`-(2%X1R4D#"3A4L,D9R54!#0M:$UZ)S<6=1DY,I!%&PD)"P0RAB'_2=\@
M@4+31;47*",Y)+LB.3I>`YQ%10JW,YXAO2*@(3D+P!6I2IU,%40)239!9#P,
M'\4NQQA//789J46&+V1"7D2M10Y","8?"V-*_A"U3+(+?AEW!W@'7B!S,B0*
M`C=&"@8W15)C.V0[LB4;3ZA,N"5E%K\05U!A+&(LHTB`.-1%Y2`F,DXT"CO5
M,QU*63[^2+D'M1H)#ZU03TZ?0,L*4#T-'[@WX$K,#N(?.R-=##T-\`^$'4LF
MMP;(#](<V1P)4^TS#$HK-P`B13-Z2-%&=1H\-3H;QBY1&@<02$DW1`46MRIM
M`Y8>!3"5"$TJ3BH",+<F11RM-L0L*3^I1C$1XC530QT@3S2B#[LN:B\C(%T0
M<`7#-GXJL3:=.3@_WQ?;.\4V[RBI+",E.C[X-;I/]S:[3PXKDB@<#\X@\3$=
M2'$ML`8I.`$RST'%,QU'7@],2#I.&E&_!I(-'#J=)*TMHQ%M%I,&+T^9*\`.
MZDU!"W0_IA'X#.\^*BH[-)\P,3(C021!E#[$'SE1C%$W,DL?3!]S-BHA41@5
M-3`&$10C4B@OTB#V&$TNRD7-12=.?D=5#?Y+"QGA&E`NC2IE*W8**2^#!8U1
M&"]\4WE.BB<&3W@2R2I\3O8^>B51*UM)21%E/4XZW2*5'_$?YTE"'"E26AH\
M!0A/S%+M2UH5MAB2+]\+'@H!.YX)A3H9('=&?CC4(`<3PAL(%E8-PTIA4O-(
M'1J?3LD)!$"D&"D=DCH8$2E%$1/[-I=1!4M(0=$AGBG'`S\]F2SB)#-)4ROI
M-/$P.42B1`,[QR)@,U<@M3!01;M1+!8>+"M!>S3S264?N3C/+[`(]Q[%)D<T
M,T`E%S8J"4P=!YP/8!@`2H9+%"0W%U0ETQ0[)H<+HQ(!2B$^:B1*''@*FA]#
M.Z,)>2^#0V@X=".E,$87*1_++60^4D0`/J,0U3Z.)1\ZDSKD)"`ZN`\O3B08
M0$5W.:8+#5!*(I$__3Y;#_M`!"`'.%@FL1K5.V(SY`VT((<5XA9*%VM2R"^>
M%]@(63'"$28*I2@>(.4D@U"\,(,]#4V'+:8H;BMR'THG6RFA-`Y-S2U3!KX8
M?4W#(\8SE3*:4?!*(P<_!7A-VT"--N<1>4T'(O8;"#C_-I(Q-S#:07M-$#:]
M&?@<ERY5-/`]AQ+\0!<]Y#\L-A((TQ>31V@862M3*AY+E$="&)TXORJ43KT:
M#2U^%ET*X1`_)@@R"3*>*F\]+@P10+$';!HG!\!%E!OS'+02'DH(2_$X11Z>
M4%T\DTR[!0TLOCAG/HHXUDLD((`/MC[V'58T:#SL)_`:HDTG+9H$-$SU-&-3
M=2:""#%#C`L`&/Q3!RI?2Y\CB!(E*!)`Q$)@2]HP!!^1%K([K4W_):](_"J=
M4]\)%3S:#$L_*Q7G-F!/]3AK*<`IZS^53J)!H$#.,A-/P3AG`S=.JDH7.[H[
MPCA?`R$O%0OL0-L'U"NF%*$7$1J,0BH.YE$H2W8>BA1(.R$>=QK62DH4`3J.
M"U=$)DUV11T9Q@58!O%1JQUI(G,XM3=X*^@#ARC]&/%+NPBU$:Q+JQ8**N8S
MHTP&'/M&*0E=0@<<0"CO)^,>VA8>#'91X1/F,B8>_PN1"ZP^W"[U/.A(/T)Y
M*X,\MC=7%P`F3#\Q"OD3KB]$5+8AFR\/4(D*[D7?&DL=-D=6"X4F<0PB/7T=
M'PR-2W(8^D3D.1(6(`Q7(^]%\E$],/P@*A[<,)\-A1J#'GE!Z2ZC&QI`*CN<
M,I5"ED*5.U(0%BR#-B8[L5`A##=*_%%M/R(\M$8U(]5(ASZ>-A<8X060"+PY
M.C'Q)AM`#S<(-^8)HQ];&<T=DR22#(48,A<\3M`GAAA'$Z87ZA<^0T\==3>7
M0@X$BBA(+K),$R>6.((-QQD?3\1$1$U9.6A&92<>*A!4LTN*&LH'22:X#A-)
MEAFT4!\J3PU52FH[/S"%(-X[GS/34V4NR181'X4O"S>M&X1`^@KD.[HZ##X,
M-_)2$"9>*]`XZ3F!*TDN<$MQ2PDK%Q^\,1T<U%0;0<$\_4JX2B40U0OX&O0S
M+219(74#'4"E!IT5C3)R2Z8&AB,B$MX'B"IF'5Y`JBF[3M8HOB7W2U)(D"BE
M.@52FTO&#\X_.QK.1!`O8#AF!I@(VBNO)\\<$3?K":`5J@8"&Y]#:"BZ,P(V
MSB6&'RQ$>TM6.V1`:QE_1L12^"?=(RD0N1'O&-XCJCEQ)WQ+7RLQ'$XF:!U#
M2P(G>4K6'*(('PUL-1H=`"28$18ZBTW>4YL2&#C9)`$D*`RS-+Q+CS)D$1DA
M_4=_2Y\VQ$XS*?-'/B5A*ZHW)CR/#1,>R0B!2[`7WE(R)`HD.2UQ/S<IOT9Q
M0P!((!0$2&Q-)!;R0_-#%QH[&$I3A4^;1$\*C4[Z,2I201)4+K%`$#'H2=XO
MA"$:+X4A02_!++$F)A;_1"<6*!8?!M(,MT+^4,Y2!B(M4!(3-@2C1*1$AB>C
M4TPO^CM$2`\^?S<%0`(:8U+I'=5%*A@8-;,98$5A151#QDHN0652=$@T.=D_
M(CY[1I).AR&[0C9&`%'T,$<:+Q9-"2$:;`EE&L<F)A.;'TX)-#'@/;M3`C[^
M%E,D9C?<15H*XS73&-Q!E#G_%X-&A2+F(`=$W4%P4TTA8@ZL1(T;F4']*,A'
M'R`=)T\CR1K8/N=!@PQ/04,8<"!F$Q5!_`NU$L$P!#2.-NA!!30%11]*PAT=
M33X4$3"-%<<_BSC!%=(WTS=R+=@4Y3]X"0,8(2-&4JQ"+!JV$D0F$47W'<<%
M(4ON4DI`H#Z#-_5!F2Z:+H8(,T><'Z$?TRIY0'1/`!\*-!\VOQF*$5HT93LQ
M2,XF2![X3L(5%DXB+4@Y=R90%80\-0D*$3('"QJ#1)%"I4$83N87!1C\03M.
M^RR%-PLTOTAZ*P0F:$MQ02`5VD?\,M8%708'#,0HOQPO*+4O2CM#2A4^_2!8
M5"`9ADG]47U`Q2=:%\<ND#6B'ULC6PQ(3\8<$$(10D1*7T1L"NL9P`@*2;=&
MX$>X1A,S6"'U#5,0/SC0'5(2;CI%3?8FI!_;-U,2N48J),,JK3Q62J4?ZRI8
M'UD?;4MD2FE&]B,7/,P'%T(_-794%R93&MA2;2?S/V5*C41-4),:XPR>+MT&
M.C8,&))&&1^V"MT-QT@-&"XD:08`-L8ECBR4-B`IJR/@`Y=&\")%.J,FU"5M
M*`\AK";O1RM"T43_)QQ)SP=X-0U.+R0J#(X*&A:2(%@)0RNG/#`DXE(F)'LG
M;DTU4/M032^A"1-`,!?^(-Q(M50T$5,+WR'+3@H/U#*N2^TR'"\B":L<30N>
M3'5/$0:P!#,'3PL[3,D/IPE,+JT?OCNT-28JP!$J%+M'?A07!9`Z2DR`%*\L
M10X?->PT/E0X*C@B1C(2)0@Q-13I/$$%]C2-"U8<C1+N(24@X@J20C$%I2FW
M'K<IQC9^0"0E.1`[/C$S&$+')<H/V2;X+FLP2@<L0IH*(T"%-9L*,`3!&V0(
MLE-Z%,4A#P>>&`Y'OTIJ$6U3SB).4K\LWR\;(%Q)"T4+/S<GX"^<+:1(0TQX
M1D0-$P??6>!9X5GB6>-9Y%GE6>99YUGH6>E9ZEGK6>Q9[5GN6>]9\%GQ6?)9
M\UGT6?59]EGW6?A9^5GZ6?M9_%G]6?Y9_UD`6@%:`EH#6@1:!5H&6@=:"%H)
M6@I:"UH,6@U:#EH/6A!:$5H26A-:%%H56A9:%UH86AE:&EH;6AQ:'5H>6A]:
M(%HA6B):(UHD6B5:)EHG6BA:*5HJ6BM:+%HM6BY:+UHP6C%:,EHS6C1:-5HV
M6C=:.%HY6CI:.UH\6CU:/EH+`"(`)0!(`48`2`!$`'8`?ET&`$(`2@!*`4L`
M3`!-`$X`;0!P`%@`6@!<`%X`8`!B`&0`9@!R`',`:`!J`(,`A`"%`)<`CP"0
M`(@`AP"2`)$`A@"8`(D`I0".`(P`IP!\`),`E`">`)L`F@"9`(H`G0"C`*0`
MGP"@`*\!E@"5`%,!4@%'`4\`4`"[`1(`0P%!`4(!2P%%`>L!3P%0`;``L@"Q
M`*\`K@"I`*@`JP"J`$P!N0"]`+<`NP!.`3]:0%I!6D):0UI$6D5:1EI'6DA:
M25I*6DM:3%I-6DY:3UI06E%:4EI36E1:55I66E=:6%I96EI:6UI<6EU:7EI?
M6F!:85IB6F-:9%IE6F9:9UIH6FE::EIK6FQ:;5IN6F]:<%IQ6G):<UIT6G5:
M=EIW6GA:>5IZ6GM:?%I]6GY:?UJ`6H%:@EJ#6H1:A5J&6H=:B%J)6HI:BUJ,
M6HU:CEJ/6I!:D5J26I-:E%J56I9:EUJ86IE:FEJ;6IQ:G5J>6ED!8`%G`6X!
M=0%\`8,!B@&1`9<!?UR`7(%<@ER#7(1<6`%?`68!;0%T`7L!@@&)`9`!E@&:
M`9T!H`&B`:0!I@&H`:H!K`&N`5<!7@%E`6P!<P%Z`8$!B`&/`94!F0&<`9\!
MH0&C`:4!IP&I`:L!K0%6`5T!9`%K`7(!>0&``8<!C@&4`85<AEPG23P1OS9\
M.EI!S"=(,1@$OQ_9.(=<B%Q:`6$!:`%O`78!?0&$`8L!D@&8`9L!G@&)7(I<
MGUJ@6J%:HEJC6J1:I5JF6J=:J%JI6JI:JUJL6JU:KEJO6K!:L5JR6K-:M%JU
M6K9:MUJX6KE:NEJ[6KQ:O5J^6K]:P%K!6L):PUK$6L5:QEK'6LA:R5K*6LM:
MS%K-6LY:SUK06M%:TEK36M1:U5K66M=:V%K96MI:VUK<6MU:WEK?6N!:X5KB
M6N-:Y%KE6N9:YUKH6NE:ZEKK6NQ:[5KN6N]:\%KQ6O):\UKT6O5:]EKW6OA:
M^5KZ6OM:_%K]6OY:#0`.`!``1`$4`!8``0`8`!L`'@!Y`"```P`D`"8`5`%5
M`5P!8P%J`7$!>`%_`88!C0$H`"L`?@"``((`+0`O`+`!MP&Y`;\!P0'(`<L!
MS@'0`=8!V`'=`>$!YP'L`?(!]`'V`?@!^@']`0@""@(,`@X"$`(P`#(`,P`T
M`#4`.0"Q`;@!N@'``<(!R0',`<\!T0'7`=D!W@'B`>@![0'S`?4!]P'Y`?L!
M_@$)`@L"#0(/`A$"/``^`$``10#_6@!;`5L"6P-;!%L%6P9;!UL(6PE;"EL+
M6PQ;#5L.6P];$%L16Q);$UL46Q5;%EL76QA;&5L:6QM;'%L=6QY;'UL@6R%;
M(ELC6R1;)5LF6R=;*%LI6RI;*ULL6RU;+ELO6S!;,5LR6S-;-%LU6S9;-ULX
M6SE;.EL[6SQ;/5L^6S];0%M!6T);0UM$6T5;1EM'6TA;25M*6TM;3%M-6TY;
M3UM06U%;4EM36U1;55M66U=;6%M96UI;6UM<6UU;7EN%`H<"B0*+`HT"CP*2
M`I0"E@*8`IL"G0*?`J$"HP*E`J@"J@*L`JX"L`*R`K0"M@*X`KH"O`*^`L`"
MP@+$`L8"R`+*`LP"S@+0`M("U`+6`M@"V@+<`MX"X`+B`N0"Y@+H`NH"[`+N
M`O`"\@+T`O8"^`+Z`OP"_@(``P(#!`,&`P@#"@,,`PX#$`,2`Q0#%@,8`QH#
M'`,>`R`#(@,D`R8#*`,J`RP#BUR,7(U<CER/7)!<D5R27)-<E%R57%];8%MA
M6V);8UMD6V5;9EMG6VA;:5MJ6VM;;%MM6VY;;UMP6W%;<EMS6W1;=5MV6W=;
M>%MY6WI;>UM\6WU;?EM_6X!;@5N"6X-;A%N%6X9;AUN(6XE;BEN+6XQ;C5N.
M6X];D%N16Y);DUN46Y5;EEN76YA;F5N:6YM;G%N=6YY;GUN@6Z%;HENC6Z1;
MI5NF6Z=;J%NI6ZI;JUNL6ZU;KENO6[!;L5NR6[-;M%NU6[9;MUNX6[E;NEN[
M6[Q;O5N^6X0"A@*(`HH"C`*.`I$"DP*5`I<"F@*<`IX"H`*B`J0"IP*I`JL"
MK0*O`K$"LP*U`K<"N0*[`KT"OP+!`L,"Q0+'`LD"RP+-`L\"T0+3`M4"UP+9
M`ML"W0+?`N$"XP+E`N<"Z0+K`NT"[P+Q`O,"]0+W`OD"^P+]`O\"`0,#`P4#
M!P,)`PL##0,/`Q$#$P,5`Q<#&0,;`QT#'P,A`R,#)0,G`RD#*P.0`ID"I@*6
M7)=<F%R97)I<FUR<7)U<OUO`6\%;PEO#6\1;Q5O&6\=;R%O)6\I;RUO,6\U;
MSEO/6]!;T5O26]-;U%O56]9;UUO86]E;VEO;6]Q;W5O>6]];X%OA6^);XUOD
M6^5;YEOG6^A;Z5OJ6^M;[%OM6^Y;[UOP6_%;\EOS6_1;]5OV6_=;^%OY6_I;
M^UO\6_U;_EO_6P!<`5P"7`-<!%P%7`9<!UP(7`E<"EP+7`Q<#5P.7`]<$%P1
M7!)<$UP47!5<%EP77!A<&5P:7!M<'%P=7!Y<$@(4`A8"&`(:`AP"'@(@`B("
M)`(F`B@"*@(L`BX",`(R`C0"-@(X`CH"/`(^`D`"GER?7*!<H5RB7*-<I%RE
M7!,"%0(7`AD"&P(=`A\"(0(C`B4")P(I`BL"+0(O`C$",P(U`C<".0([`CT"
M/P)!`J9<IURH7*E<JERK7*Q<&0`<`&X`<0!9`%L`70!?`&$`8P!E`&<`K5RN
M7&D`:P`]`$$`"`"O7%(`5P"P7+%<LERS7+1<M5RV7+=<N%P?7"!<(5PB7"-<
M)%PE7"9<)UPH7"E<*EPK7"Q<+5PN7"]<,%PQ7#)<,UPT7#5<-EPW7#A<.5PZ
M7#M</%P]7#Y</UQ`7$%<0EQ#7$1<15Q&7$=<2%Q)7$I<2UQ,7$U<3EQ/7%!<
M45Q27%-<5%Q57%9<5UQ87%E<6EQ;7%Q<75Q>7%]<8%QA7&)<8UQD7&5<9EQG
M7&A<:5QJ7&M<;%QM7&Y<;UQP7'%<<EQS7'1<=5QV7'=<>%QY7'I<>UQ\7'U<
M?EQ"`D0"1@)(`DH"3`).`E`"4@)4`E8"6`):`EP"7@)@`F("9`)F`F@":@)L
M`FX"<`)R`G0"=@)X`GH"?`)^`H`"@@*Y7+I<NUR\7+U<OER_7,!<P5S"7,-<
MQ%S%7,9<QUQ#`D4"1P))`DL"30)/`E$"4P)5`E<"60);`ET"7P)A`F,"90)G
M`FD":P)M`F\"<0)S`G4"=P)Y`GL"?0)_`H$"@P+(7,E<RES+7,Q<S5S.7,]<
MT%S17-)<TUS47$<`.@!)``4`!P!)`5$`O@'*`;X`N`"Z`+P`>P"+`(T`G`"A
M`*(`I@#%`,P`T0#2`-,`V0#:`-L`X0#B`.,`Z0#J`.L`]0#V`/<```$!`0(!
M"P$,`0T!%@$7`1@!*0$J`2L!U`#<`.P`Y``L`2T!+@$O`3,!-0$W`3D!.P$]
M`3\!/@$\`3H!.`$V`30!,`%``3$!,@&L`*T`LP"T`+4`M@!1`7H`30%T`'4`
MU5S67-=<V%S97-I<VUS<7-U<WES?7+4!L@&T`;,!QP'#`<8!Q`'5`=(!U`'3
M`?$![@'P`>\!`P+_`0("``('`@0"!@(%`@$"Q0&V`>!<Z0'J`>%<S0'B7.-<
MY%SE7"T#+@,O`S`#,0,R`S,#-`,U`S8#-P,X`SD#.@,[`SP#/0,^`S\#0`-!
M`T(#0P-$`T4#1@-'`T@#20-*`TL#3`--`TX#3P-0`U$#YESG7.A<Z5SJ7.M<
M[%SM7.Y<[USP7/%<\ESS7/1<]5SV7/=<^%SY7/I<6P%B`6D!<`%W`7X!A0&,
M`9,!)5'D`=H!Y@&]`=L!XP&\`=P!WP'@`>4!*0!&`4,`^US\`:]2_%P$`/U<
M_ES_7']="0`*`(!=@5UW`()=@UU3`%0`50!6`#8`-P`X`!\`(0`C`"H`)P`L
M``P`%P`:`#L`/P!L`&\`#P`5`!T`>``"`'T`@0!_`#$`$0`3`"X``%T!70)=
M`UT$705=!ET'70A="5T*70M=#%T```U=#ET/71!=$5T271-=%%T5719=%UT8
M71E=OP#``,8`QP#!`,(`R`#)`,,`Q`#*`,L`S0#.`,\`T`#5`-8`UP#8`-T`
MW@#?`.``Y0#F`.<`Z`#M`.X`[P#P`/$`\@#S`/0`^`#Y`/H`^P#\`/T`_@#_
M``,!!`$%`08!!P$(`0D!"@$.`0\!$`$1`1(!$P$4`14!&0$:`1L!'`$=`1X!
M'P$@`2$!(@$C`20!)0$F`2<!*`$:71M='%T=71Y='UT@72%=(ETC721=)5TF
M72==*%U](D]#AQG&%SY0@AO(1F,WTCL=/F4D-RK20;Q"'@7#45%'+#='%R\?
M\B[K$0A$:@23,50&"4O$(Z4<QC),(]!'?E3.40=1]T;*)BP(3U2M$XD2_4"C
M334+GSX>1WM$4AP-!A9,@TB#.RP'*"S9.L$IKTWS##--PSB%%\LR*DJD4-P'
MB1<9*I<=IRR)".H#811L#$\%X@77!>D9;0?R)O5%-C["2$(Z'$1_.340+1[$
M%,(@P0^+&J\B9$-E0SHN%@8951I5&U4<51U5'E4?52!5(54B52-5)%4E5295
M)U4H52E5*E4K52Q5+54N52]5,%4Q53)5,U4T5355-E4W53A5.54Z53M5/%4]
M53Y5/U5`54%50E5#5415155&54=52%5)54I52U5,54U53E5/55!5455255-5
M5%5555955U5855E56E5;55Q5755>55]58%5A56)58U5D56559E5G56A5:55J
M56M5;%5M56Y5;U5P57%5<E5S5715=55V5?D:>"X**]@F2BT\%H`Y:2C/.Z%#
M02MM-5`M@REN0](Q'R'(*^Y372C^.CDTN!.?)!X$4AA5#D,+ZA-O3-TQ<$P-
M"5<89D'3$J<>$4?=*K($\$W5($A.UB"<'$4-CC#$,O1)MP.V,!,3*$:X"S<5
M>1SC-[\+936"."HX\#NV5,`GI`6/4,L>&AXR'9`E,!;[0F92*$=Z12=(O44%
M.X@SR$JJ1MH$Y$.]0DP6>0K617HO@R1\#1A+MT"E$-$)$3UN07=5>%5Y57I5
M>U5\57U5?E5_58!5@56"58-5A%6%5895AU6(58E5BE6+58Q5C56.58]5D%61
M59)5DU645955EE6759A5F56:59M5G%6=59Y5GU6@5:%5HE6C5:15I56F5:=5
MJ%6I5:I5JU6L5:U5KE6O5;!5L56R5;-5M%6U5;95MU6X5;E5NE6[5;Q5O56^
M5;]5P%7!5<)5PU7$5<55QE7'5<A5R57*5<M5S%7-5<Y5SU705=%5TE735=15
M3$'."4XAERHC!0,^AD,."TP7+$961T-&?44G$]Y!2R>8)<X>K3N%$H$_L`Z1
M,,Y/`S?R*QY-R"/S*Z4X%$"%/1(+806H">H0W@AB!:TH^A7(#BD%QS*J4Y`S
M9A'0'MX/M!XM&N!,I2I\"Q%&'CT211,-$C;V*[8<2T!@-L`9@40O"P`=3E,3
M"44F_30"$/A&YAF=)\@X\S6S.XE(H4!T0:Y0"1]J2\,IO#R@)[,E0B21/=4R
MG0SV(#A0G@:@.?@(U5765==5V%795=I5VU7<5=U5WE7?5>!5X57B5>-5Y%7E
M5>95YU7H5>E5ZE7K5>Q5[57N5>]5\%7Q5?)5\U7T5?55]E7W5?A5^57Z5?M5
M_%7]5?Y5_U4`5@%6`E8#5@16!58&5@=6"%8)5@I6"U8,5@U6#E8/5A!6$582
M5A-6%%855A96%U885AE6&E8;5AQ6'58>5A]6(%8A5B)6(U8D5B56)E8G5BA6
M*58J5BM6+%8M5BY6+U8P5C%6,E9<(SQ3"`Q$2;0Q51_J3F$T[@,L)N,JX4I`
M&85`4T'V#8%%24^Z1J@TI@WW)I0F$C0M.U\66A^0$=,>IR=,&XP:6Q^0`^Q.
M@PT)'K@65CR4&ID9$#=P.WD]_0JV3!H?:BBI!K,YU53[(VQ"(QPS1F<V'$'B
M$[8DRP_/)152&C;M);Y.%#16/6@65#NO(P`H;BC5)3$D1TM&*[Y#%S0;%N`-
MQDZD&10''@=P4>DE:#G#0_\RB02'+]811@V]$N$K5#\S5C16-58V5C=6.%8Y
M5CI6.U8\5CU6/E8_5D!6059"5D-61%9%5D961U9(5DE62E9+5DQ6359.5D]6
M4%915E)64U945E565E975EA6659:5EM67%9=5EY67U9@5F%68E9C5F16959F
M5F=6:%9I5FI6:U9L5FU6;E9O5G!6<59R5G-6=%9U5G96=U9X5GE6>E9[5GQ6
M?59^5G]6@%:!5H)6@U:$5H56AE:'5HA6B5:*5HM6C%:-5HY6CU:05LX89DER
M!+4@\0@`"MDGG`T;*X)3PC`2!IQ2VB?*"RE+#C(X0T$H?`[(+CU3(2=]074-
M\T`[2Z=';#TN%_,(T3,O.+,(M`AJ-O,Z/3B9*+(2;D_X$J,P)@\6-?,JH`72
M'XD[BR>P+"M.%!/2%*D>%1-H/;$LXSQW'40_'Q,;+;0LM2P*"&L]Q1.K!<(,
MSU%#*0`O-4E1&91,E4RW+$\A#4J1)P(/4QE_#813J!WB"14)Z3ZQ)#\(J"<3
M#R0GAQVX"I%6DE:35I16E5:65I=6F%:95II6FU:<5IU6GE:?5J!6H5:B5J-6
MI%:E5J96IU:H5JE6JE:K5JQ6K5:N5J]6L%:Q5K)6LU:T5K56ME:W5KA6N5:Z
M5KM6O%:]5KY6OU;`5L%6PE;#5L16Q5;&5L=6R%;)5LI6RU;,5LU6SE;/5M!6
MT5;25M-6U%;55M96UU;85ME6VE;;5MQ6W5;>5M]6X%;A5N)6XU;D5N56YE;G
M5NA6Z5;J5NM6[%;M5NY60C`:#QL/71Y9#9@Y\U$"+80%*Q2$4N!"CD6."7E&
M@C&F0G<,I05\5%1&2%%4$9M1%A+Y'V<WLRWQ/!$^.AXZ0$H:'#Q;"M`J=Q\*
M1&@^/"H+1#8[%3%I$'DY*TI9!1Y0^Q6T*>DF_AN(/:<#8`K)!?<K$A#I(05'
M/@QQ.$A2]%$T38\2,TA\"7\^QA:[0,,9BB*O2@`A!T+P%45*4`M\&I4NB@XD
M4'4X1@Q72H)4\3H--^<.22A***`S3Q.7)C(S[U;P5O%6\E;S5O16]5;V5O=6
M^%;Y5OI6^U;\5OU6_E;_5@!7`5<"5P-7!%<%5P97!U<(5PE7"E<+5PQ7#5<.
M5P]7$%<15Q)7$U<45Q57%E<75QA7&5<:5QM7'%<=5QY7'U<@5R%7(E<C5R17
M)5<F5R=7*%<I5RI7*U<L5RU7+E<O5S!7,5<R5S-7-%<U5S97-U<X5SE7.E<[
M5SQ7/5<^5S]70%=!5T)70U=$5T571E='5TA725=*5TM73%>J)W,D1$,@$CX-
M#4L+&$5#\17U/W$N4TTA0+=+U"2_)<`Y=@T6)Q<GD08J'!$*4TA-'AE1BRK<
M)0H;X2-A&SI&E$L!2\!+)SR4#I<I.BD[*>\&\@8W!$H12Q%4,VT%\$YM*MXN
MX`L_)VHL@QO)+T<4IQ!0%[P%IPJP,FL#1$2G%Q0:J!<@3W0,J1=(1`U)JQ<+
M'I0#'D4/&M8E=C#V%S,>_Q-9+U<T-#5C3Y@5-R$X(9Y29T]H3]M/S`_>,5-+
M!@54`U,#7`-=`UD#6P-:`V0#;`-R`W$#>P.%`WT#@`.M`Z`#G`.[`\8#S@/%
M`\H#R0/3`]8#V0/;`^$#[0/Q`_\#!P0)!!($$00B!"4$'`0;!!\$)@07!",$
M&@0T!#P$101"!.4N1@11!$H$2`17!%H$6`1@!%D$9@1G!&L$>01V!'H$<P1W
M!'@$AP2(!)0$EP23!)\$D@21!)@$H`2C!*4$KP2Q!*T$M02^!+,$OP2T!+@$
MQP3(!,0$S@3T!BY0QQ?.%_4&BC]A3*\19Q-8--0-M"C03R`EY![P1;P<#"^N
M`V,HQD5Y4J<-LP.A%=<E$A34/_LQR4UI/>1$?T)]$NTK'RPP.2Q._R[7$7(J
M>T,U.0Q(`5&H2#`XYQKO#,A0XB+Z'VDXS2IK+`U3E%`V.?@.M"U`5#0)TP95
M*^8G)3X?#V,.9RTC+$1&Y5`H2'$L5E)L+*`J)C-1%Z49]`FH#+@@J!`(*HE#
MZD%U(X0WB3VV%FL_`25).0PTSR8/43T'U`38!-L$UP35!.X$[03Y!.\$]@3_
M!`4%"@4(!00%#P4K!1D%$04:!1P%$@45!2<%*`4?!3L%1@5%!4T%5`55!5T%
M9`5K!64%<05Z!7T%CP6)!84%V`7+!=T%E06I!:,%DP69!<@%E@6P!=4%E`70
M!><%\P7O!:@%&P8*!@X&(`8A!C8&-P8L!D4&1@9(!CX&3P9.!EX&=@:"!H$&
MB`:0!I<&F0:D!IL&E@:Q!L$&P`;0!L<&S`;2!M$&%B74(V8[O"`[,+<:M2A+
M%(=2I$RX&M`IY4(T13$:MQ:63IL+MQS4*I,8$T:2/?%%6Q$:0906+2OO0&PB
MH0U?"0TT@RQ>$B%/)E!82LT.7"*$+"TZ#0PR*`P*_BE@%L@9+CH90BHQ7CBU
M)E<)7AT.2?E%GRR9%E\=&4F5`YH:$AU04+$JQ@KX-D(NE$;*2/X:#RN5*Y@P
MEBO7)/$B'T:7*PL;<"@4*P$H'!8/*FY"J#RN(?=2B3,?33LZ%$\B(5`XY@;>
M!O,&_P8&!_`&^0;Q!B4'%P<K!R$'-`<-!Q$')`?^!C4')@<2!Q`':@=F!VD'
M:`>`!W`'<0=T!XD'?P=V!XL'D@>8!Y0'DP>5!Z$'I`>:!Y\'I0>G![0'J@>W
M![8'N`>_!\<'U`?7!]`'TP?E!^H'ZP?R!^T'^0<$"!,(`P@""`<((P@H"#D(
M+@A'"$@(10A0"$H(3PA9"%X(6PAA"&8(:`AV"'4(B@B$"'\(APBU"*P(M@C/
M"-4(V0B-&(1+;%(*'DI/Y$U0!#D/]C$F5(Y!6%!Q(BP4*@W9((,EUQ*R0+@0
ML"&84:L>E0;)$%E06SM5/\8>;2S['P--CBD0/](0MBSI4H8NIC!`)UHOHB3V
M!O8PYDOC(C<B\S2S4C(6V1`G,J@H.T!_`X=#5T>8+X0D9!C6,W)`(S,I"#DB
M+C7,"$,D1!B63`U$Q4*W!!THUTM#"5$)T4<R-VLCCA4J"#$9@RB%"9PNMCK(
M4SLBF4>%4TLBX`FD,7]4[C,"">T([PCF".X(Z0@!"08)#@D1"0\)'PD8"1P)
M)@DJ"2P))`DR"3,)/`E%"50)4`E*"54)6@ED"6<)8PEQ"64)9@EH"9$)C0FN
M"8\)Q0GH";T)OPG+"=D)U@GG"<()P`GQ"?()]@GW"0D*(`HE"AD*'`H8"AH*
M00H\"CH*-@I0"E@*3@I6"G,*=`J%"H8*CPJ5"JT*I`JO"J@*I@JI"IP*H0K$
M"KX*R`K."LP*YPK6"NP*V@KA"M<*U`KX"NHF-2$!!_@KN!P$&#4U^2372G)!
MI3%?*4<M8S9D1T,/&#\D2QXB44!!.J]0!!#+0J`-(#U<+70]#S)/$)`2/34-
M,\0I"Q4G.ZT0HB=J.HD\01GQ+R0C=CW.0FDQ"B9_0%).$Q":(_XND4A`4Y,(
M%#+P`YXOT2>.**PA5PN)";%*T"1F,!4R%C)M#%]4L0MD*5(;GC=T)$M/8!V=
M0D</N@X(!XA.%3,8#L`E81T:0A%0-#,3'4]-CU/P%R(B)$_N)/,*]0HC"Q0+
M%@L#"R8+*PLM"S@+,`LS"S\+0@M*"TP+<5-2"XP)60M@"V$+:`MN"V,+=0MZ
M"Y,+A@N*"X0+G@N@"Z<+N0O$"\T+S@O+"\D+Q@N^"]T+Y0OM"^,+#`S]"TD+
M\@OQ"Q4,+0PS#$4,1PPZ#%$,7`Q:#&D,8@QC#'P,A`R%#(`,APR/#)0,F0R?
M#*`,G`RW#+0,O`S##,H,VPS?#.P,[0SQ#/4,]@P:#0$-!0WW#`<-#@T"#1`-
MC![^"AU)036H#;E)^2_Z+[I,BC`8,I<#_2'3'%1-:#9=+]@+10=42-8I2$/R
M(K@DV"094M`EV"69$40U7B](2]TE`B@#*)`L"CH=%@<DC@=Y1\\U[4V_.\LI
MGD1C2'\Q4@4=$$]24%(Q2>HX2TR\4:`]?Q-J*SD[RRIG"/XHTDQ-00Y3>Q:^
M0DE1<!1Q%"$Z_AYK.,83:B-D#M(\L!4/%MQ45B>N*,`-;5&]!?<*+AHV3*M*
M`U3Q&J90V$U005U#`PTL#2<-)`TF#2T-2PU'#5(-8PU3#5X-7PU7#5T-80U[
M#8@-B0V8#9D-K`V^#<P-NPVY#;\-N`W.#=D-SPW5#=$-Z@WC#>P-^PWP#?$-
M_`T%#@`._@T3#@L.%@XA#B,.)PX=#B0.GT\L#D(.0`Y/#FT.90Y:#E(.70YL
M#HL.A`Z(#IP.F`Z6#KD.IPZA#J(.HPZF#JT.KPZN#K$.R@Z_#LX.PPZ^#MX.
MV0[:#MT.[0[L#@X/$@_P#OP."`\R2%)1/$FF*EHZ;PXN!;!0X$L(''44ACQ@
M.M,IW#N:$Q5&M3%034T;H#J4"'$-FA9Q.V`E9RX_*\T-R"4.3EU1QT[S)`LV
MK41?/I@U)U1#".E)]T+"+1XT91*7%RU.05$F'T)1_4R$(ID$XR^"+9,E"DSD
M+Q\'02?$+?M42E%@(-@:)C[14=D:U1>>2O13TE&C->L/$5-?+I`37!0T3R(Z
M;",'%#,?&#U\/B%'9RFW*+,5`%6@4[L$-AOG46\C^B0A#R@/(P\I#R\/,0]"
M#SH/-@]*#TX/3P]E#V@/;`]U#VX/<P]M#W8/B@^3#Y`/E@^:#YX/I0^)#[0/
MMP^]#]H/N0_<#^`/WP_F#^X/YP_I#^P/Y0_W#_H/!1#[#_P/_@\/$!L0%Q`8
M$#$0+1`[$"\02A!"$$D01A!+$&006!!5$&$0<Q![$'`0D!",$((0C1"+$*P0
MH1"K$)\0L1";$*`0T1"^$,40YA#<$-00"!$2$1$1+!$K$2\1+A$[$;`O"B>K
M5"A-12E&*3])DT(G!@D<0A/9!:TN21Y)4E54HT64"=8-1R8)5#U-]D7^46(4
MF17T-6L["386'+@AQ`?D*A!2"AS-*/<Z3AN/2]1`*32.(UE*\AEM,\\;)$0K
M,=,=K5,^/N=4#"ES.VDN$C>;&FDUM2Y538LP*QS"/M5`M@G_&O,B#BEM!A0W
MKE-&)5D,"D=;3"LX3Q^W2&8DJ4C2!-0&13_24AL>VPXQ05`62PN[2`Y$T@EG
M(F<-R5.@14(12!%5$5H141%0$5<181%E$741:!%K$701C!&!$8,1DQ%[$841
MGA&B$:D1JA&D$:@1IQ&]$;X1NQ',$<L1R1'*$=`1T1'3$=\1Z1'B$>01X!'X
M$0`2`1(+$A`2#!(.$A(2*A(U$B<2+!(F$BD2/!)($C\271)C$F`29!)G$F@2
M<1)[$GH2CA*!$HL2<A)\$H02I!*@$JD2K!*Q$K`2P!+&$LP2ZQ+4$ND2_!(%
M$SP3,1,0$R@3]A(,$P83]CKN%:M3`4%-/R)'#C222)-(MSTM"7<]Z`Z&()4F
M$D*I0?TB40LS4+XBOR*U"8H,F";]3F`,3C,5-*T/`4\:*'(S!`O@.'H3.C(*
M"UP8@S&`%X,X+A+)*\$T#U-")^@GYP9=!)DZ:1AX'^(.+$K?.70?Q32H,"$E
M2%,F"/<-DPQ@/X@?I"&)'Z$DHB\A"C(JSU)\/^H=.CNF,_%&?E.;37(7(0@'
M,*M)7`]J-\!"U%+Q+&$58S,++,H$#0A\+TPG'A,E$S<3,!/U$E@35Q-D$U\3
M8!-<$V,3:!-9$VL3@A.($ZH3E1-]$XP3=!-[$W(3F!-V$XX3<Q-W$W43EQ-X
M$[43M!.\$\X3W1/6$]<3V1/C$^03Z1/O$_`3ZQ,#%`@4`!0$%!X4(10D%"X4
M+10H%"<4)A0\%#T4411#%$843A1$%%(4711D%&,4:Q2"%(D4AQ1X%(44@Q1_
M%(84F12?%)L4H128%*,4P12\%+T4Q13'%,@4U!3/%-$4X!2!+BD3AQ$&%+`1
M#3EI*CLY`#0,+*`ICQ:"-"H*ITJ\2(X%?"/Q'8T[+38P&W<765+)(WX-%0CF
M$H`^%R5&)$(@_!4!'2\713[*0NE1V@D[.QY3`57Q/18(<Q3X$\DB.$ZZ+D-$
M`S'+(Y!4]2[;!<(4_CO@%61,O1Q(4/X8$U%*-XA2ORCK)E$A0Q-D3VX55C)2
M(6\+&0BL5%,'%D83!I`[8$/,,!9%XQC+..--?0L<*3A!:0]#.J4;>!X71=<J
MMQ'D%.@4ZA3T%/D4^!0`%0,5^Q0"%?84_A3U%!(5$Q44%1P5&Q4G%205)A4U
M%3050A4_%4$51A5I%6(55A5M%5456158%5<5E!5W%8D5@!5\%7T5IQ6I%:45
ML16\%;L5SA71%=45VA7<%=T5XQ7L%>45YQ7H%>85_17Y%1\6"A89%@<6(Q8X
M%C\6519&%D,63Q9"%D462A9N%GD6<A9W%HT6B1:3%HP6A1:G%J@6M!;$%KT6
MT1;@%NP6\!;W%CL+DA(H4W88:S,F-,(KN#)P%?PX0$[L%XT\!DZ9"I,V%E$-
M+KHR1D0,%38OXP_44^4*3S<I4]@R\R?''(<'E1KK!3(.#@P]1QXW7@P>,'0P
M5DVM/B)/4#>;%I!)(AG!"&TBT3#[3E,;0R@;"-,MI#M?#-$.I3NG)%(F)41&
M!X4K43>I#9TF0`UO$Q0=%RP^(QT-UQV1.W4D+43<*&$YIT[M,?<NP#$A,`T4
MC2#=*-<H<$>%#;PV,%,P%6`R'B9B.?L6^A;\%@47`A<$%P,7$A<6%QP7+1<;
M%RD7*Q<=%S@7-A=?%UX71!=!%UT70Q=+%S\7/!=I%V\7<Q>-%XP7AQ>"%Y,7
MDA><%Y07FQ>S%[87T!?6%\T7NA>_%[P7NQ?4%^(7R1?!%](7!Q@&&`@8^Q<6
M&!48&A@=&!X8(!@B&"$8+A@P&"@8/!@]&#\87QAG&%L84!A,&$X8CAB,&)`8
MG!BA&*88GQBQ&*X8LQC>&-`8VQC/&.48S1CD&-@8`B1`([],"4Z/%[M0!SQ8
M/1DNN0J72<HQ_SQ:4Z52>!'%.:12D#+A4P$]Y2AQ*-T<.S^`2V1-XR,&*',S
M)"8+)&@R$$X^4K<T)28>!@P0QE1')=8XB"F#2Q).XU-M38(1(SA:4"PXC2[(
M%W\MFPP;4#\RED^*!8L$E4$M-[$A#3:+!5T[R4I>4%8K$3P4&?,39B!R+)E2
M`PH+.VH8*3X.".@F9%->!&`D(!&#--L7CD,X$UDE`$[`*"@@K#%L!/]/S!CW
M&/D8"AD!&0P9!!DL&3<9-AD]&3P93!E*&4D931EE&6,98AED&6\9=!F#&8D9
M@AFF&;`9M!FO&;X9P1FV&;(9KAFJ&<\9TQG9&?$9[QGT&=09UAG?&>49!!H(
M&@$:!QH6&AP:*!HY&AH:2QH^&G8:3QJ!&E4::QIH&F8::1I8&F0:5QI9&F`:
M71JN&JP:KQJ^&KL:R!K3&M<:VQK:&N@:XAKN&OH:XQKL&A$;%QLH&Q@;-1M"
M&R4;.QOI%C(9S3:*/"D&KBN!5%$=)27&1.\2L"XX!9L5=T5;'&A3D3S0-FT2
MKAU,+-$VTC:T+FX*8B:R(E@'GAG#.2P<HD.P/AXNV247538.'R[!/3,D2SJO
M'_P4'%&Q'T1,YQM?")-2I4;B35T874R!%'T_NS6T0$@T[BSO4U<^5B[$$NL;
MD#F("^4OY%`N-V$8G%&%&S`2,$Z^-4H-S![:$7D,RA]^3B@$WQ+445\QE@IE
M&'].@T(J$ZY$-#C\!A)3PS0:&Q0;(!M+&Q`;'1LC&RD;,1MR&WD;D1N=&[0;
ME1MP&X$;AQMV&W@;EQMW&\0;O1O%&[X;`!S;&Q,<X!O6&_<;WQOS&^8;\1OP
M&]0;U1OD&]H;WAO9&^P;UQM9'$0</!Q`'$D<.QQD'&X<?!QW''T<BQR0'(@<
MBAR)'(P<F!RB')<<E1RF')D<M1RA')T<GAR4'*T<Z1SR'.@<"!WZ'.4<[!P"
M'><<[QSN'"L=2AU&'4,=+!TB'4<=4!TC'4TG$U/N-Q@41T@K$Q,_RE`,#0\+
MO#@R4BQ#N%2/'YL$HS1S+-DYV%3E(C`?PS5X%[1$<!ZV4J4*V!5?!.\@YB+:
M&.L+CAG9%+0\?$2((O(=^#3/$Z$I1T96!8I#,Q/&%"H^YC6\/:A*RR2U1+D@
MQQ,##T0^5CJG'<E#;1KP(`,=O2`*"M]`Z5`"*=L)6S2>.:X$1CX31)`9?#/K
M%'5%'SV`18)$;QB.0CD3X3U2.R(0<"/G$C<?&!E345Y'GQ^H$BX=,QTH'2<=
M-AT^'3$=)AU\'7,==!UV'7(=B1V1'8\=CAV-'9T=J1VA'<\=P!W2'<$=OQVV
M';<=NQV^';D=%"'O'>X=[!WB'>T=Y!W@'>8=!Q[E'?,='QXG'AP>'1X5'B`>
M0QXX'C<>.QY''C4>?1Y7'E,>'"!<'FP>=QZ`'F$>8AZ8'I4>HAZ['J,>J!ZN
M'IT>JAZM'J4>O1[1'K\>PAZ^'L0>UA[:'N`>UQ[?'O,>!A_Z'@4?\A[\'OL>
M_QOJ1:8U5E1>"7P0M"49*5XFK@H:->\WK3&>4Z\QFS^T,I-#?3D70-0\G#\W
M%,H_6P6(4Z,'ZA:&#&`IQ"?K,>E/W`6L"V`GCBMG,6@S=3U75*P6D53^00I4
M0D5K)N4>[A%K-OHK-4UT5(L1&BGR12I+S#>P,?=%MT/`'!\BED-D-H\K0QL&
M$(L*?0[[*UDJM$V_1.4$:SHG-!0&J!G<%`H,JBN`0)T35D!4/BT5PRN(1$@F
M651!!J\6LDHC/<85[Q[P'B<?.!\D'S4?,A\\'R$?+!\Y'S8?(Q]%'UX?41]0
M'X`??!]V'X0?8A]K'WL?<Q]L'V`?F!^='[<?KA^K'\<?R1_`'\8?OA_+']@?
MV1_/']`?W1_1']H?TQ\5(/`?\A_X'^\?]!\@(!@@.B`^(#T@/"![(%8@;2!1
M(%H@;R"`('<@8B!0(&P@7R!E()4@F2"4(*X@MB"B(+(@Q2`>(=$@XB#=(`HA
MW"#,(,\@VB`I(3,A+B$G(2@A1R$&4FE.KPF2"!<-ST*U3754JD64..X_W10B
M-VY+$A]:2HI3O2VJ!)H5#B^A4L@<O`L&-10Z;$[10FX,%QSY-;\\HQ-!3M50
M9113-N@8HT[X/)I#*SO64(-4P#P,&J@'[`6K$D@,+"6F.Z-':$*%5+,D5%.]
M,B$J>E$-*8@L:#`1)E!&=U14&W@W=#L>*5P%1DGJ-CLL]S+`&@Y#'AQ`-X=%
M7S511G@[&#--3P556E&A-],V_2973941GB8A">U49QU#(5`A2B%$(4PA82%@
M(6(AW"=H(6HA>R%O(7<AC2&1(8\AEB&8(:8ALB&U(;DAO2'$(;\AQR'/(=`A
MTR'8(=PAW2'>(>@A]R'T(>$A_B'_(00B"B(+(@PB$"(5(B4B*2(G(B@B-2(S
M(D4B4B)1(E,B5B)=(F`B92)S(G0B>B)^(HLB@"*)(HXBE2*7(IDBF"*@(J@B
MHB*A(K0BO"+`(L@BS2+A(MXBY"+;(MHB]B+Z(O@B^R(+(P,C$2,@(XTUPPAP
M-HA%G!I?&<)4($+Y,D).Y`R7.)\:+1P3-Q4=BAV?&1DS$0R\'@X>^P6<"'%*
M;2YY.W)*/3<\-C(<K`:?,@,D+C&81LLQP2_-2)$L\2231,54]"+Y2_M%N208
M0Z0($1YR**4(3$N9!WDU'$/05,=4JREO0B<DQ"11)E,8M37\4MQ0]0Z"0A]+
MT#QA3HM#90R@1,@2R1)2,?T&PS#F0T10.!0R2Q86[E1!/.$'&3+T0$1+NB1(
M/',H?3HB%#`C+",M(T0C12-F(W,C>"-V(X$C@"./(Y`CFR.D(Z`CIR.2([PC
MM2/5(^PCZ"/G(^8C]"/K(^0C\"/N(Q4D$R0<)!8D*"0I)#\D020Z)#TD-B10
M)%PD7R1B)&0D?"1])'\DD"2-)(PDHR29)*PDM"31),XDYB32),DDZR3@).,D
MX23W)/@D_20$)08E#B4J)2LE!R4()14E5B5-)4XE7B5+)0HEA25M)8LE;R5J
M)7$EDB5I)7`EGB5V)7XE434E.%\5ZE+\'_<J[RO7%1H]NB`T$SHXV17*4RE-
MP@-<$6$ZU"G&)TT$7A$N"89`XP4?'((*R2?#((8K45!]*2(P9AML&S0I3BO3
M#"5(+DPL3$02*0192((5Q3+,3D44#DH44WA)YS5--?0RD1F/0RY*34C6,H4R
MJ4S>%+M-EA%[-U82?#<T)G,N_3(=%7H*,1)B&%<*>@PL$\%"C"^3(^@OS2?5
M4:0T-T)]1.Y!`B)O&B<:#T1)-W`8>QW7#4LWHB5L)9HE="5])6@E'R51)>XE
M^27V)?(E'2;])?0E]27S)28F*"9!)CHF.28W)ELF5297)EPF4R9D)G(F=B9T
M)F\F<2:-)G\F@"9^)I,F@29])H@DKB:T)IDF@R:R)KHFS2;&)KLFR2;G)N`F
M^R;Y)N$FWR8$)^4F#"<<)QDG*R<\)U,G7B=?)T,G+"=/)SXG+B=$)S,G@">$
M)X,GAR>0)YPGDB>:)XXGB2>A)XTGO2?+)]TGZB??)^DG\B=F"A=&:PI:5*D_
M-AJ7&`D8:3`2)JTT]`/^)HTO3S/V`Z`:($;>#7LD.!4[%3D5^0Y;-AD1]`_<
M/>DO)PK/-$X<9R#<"F@IGQLC3S,H61N5)`,;^DMM&=I)BS,R3BL-8QAE4691
MRU!/"0E1,4Q7/YH](1$?1\4]&C>B%Z@XT"8Z'Y`%3`[;%KQ`\T7$,``,1`]%
M#_@]2"`+#/PB"R8,)O!`.",3)A@F#PR..,4ZXST_(Q,N>U%!#3TN5C-K'>0]
MYCWK)Q(H%"@1*"@H(2@\*$(H1BA$*%,H42A?*%(H5RB!*'TH?BB$*.(HMBA,
M*+DHH2BK*,PHKRB>*)HHPBCJ*/8H`"GX*/LH"2D!*0,I$RD7*1$I%"FS*!4I
M(RDD*2(I*"D]*3XI02E"*4LI4RE.*4TI4"E1*6DI="E\*7`I=2EX*7DI>BF0
M*:(IFBF=*9LIKRFS*;PIO2F^*;HIS2G:*=@IVRG>*>@IZ2GE*>HI_2GZ*?<I
M"2H<*A`J%RH8*@<H05"4.A@[2E#(23PT)"+]!WT4'@ZL&3D*MC5#-LU-,P@?
M%T(282\J+P-,5#7/0($Q`S"_0<!!)B+V#J8%.`09!YTT:CTH5/\10U&P+90O
M0E38$BA#LBQ]-.(A/PH+2"LO_0E111P1+!A#5$T6SPFT/7L,E"IT1'5$ZREV
M1"<NW$#20&1%=1\R3"48RR9H-P0^F"J+"VPX:ASH/)<@CAMC10)%_C[3"<8^
MHP]6+2PPB!7U)!U083M&'FDF&#I5!A(J*RHS*B\J\BHI*D$J22I1*E@J2RI,
M*F@J82IP*G$J>"J!*G,JBBJ0*H\JEBJJ*JXJI"J.*I,JFRK!*K@JNBK**L\J
MQRK.*MLJYRKN*ODJ'"L-*_TJ'2L:*R8K)2M8*S@K0"L[*S$K-"LO*TTK;"MH
M*V<K?"MM*W$KC2N)*XLKHBN:*YXKH"NG*ZTKM"NV*[<KQ"N^*\`KQRO&*]4K
MT2OB*P0L`"P*+`DL""P<+"\L'2PD+!LL-BPY+#TL7BE0,/(6^31L"V0-;"WZ
M+,0U;3BI"P<@@0\4,-86&$&G*F$V31!A"G<IU"YP#J@#6RW_.65.1U(3-H$^
M34#X'5<<`Q#*!?0(FC):/WHYASP>.X93.4J&)J`;&#"$1`8IR2[Y",4HW18N
M+R4+F1WL$CY3QBC.'9E+\"AO1AT(/#Z^+98FB0QA%B!$[CR1$7E1T1W(&(@,
M)$FX0U4[;!(O4U$-L")H+@LA(`NI(*DC,2;G/L$QC0RX!I-&8BT=0=Q.0RQ2
M+$0L12Q++$@L52Q8+%LL<"Q_+(DL9"QZ+'DL9BR<+)4LI"RM+*LLJBRL+*4L
MRRS3+,PLR"S2++HLO"S0+,(LURS=+.,L92WM+.8LZRSI+`$M_BS_+`LM"2T8
M+1,M'2TP+4`M5"U2+5TM7RUI+6LMY2QS+70M>BV1+8`M?BU[+9HMF2VR+;LM
ML2VY+3='P"W!+=$MT"W,+=DMW2W@+>,M[BWP+?DM%R[[+0HN"R[X+2DN+RXN
M+C8N*RZ@0VH&145@(ZPC/T=O*`D;@DZ4*;@TW4XU*98M@TX[,@Y!0!;\)CT6
MWQWZ&TD4R0J0*PXNGA1`'04/4%%F1?\[=T,T"#`UXDP814D@XQ\'10,XR!\=
M/%$Y8CQ#,40Q_Q5@&9,]S$*S#801X"X2/(81,@M;*%(GPD('-#0OD2(Z$_E.
MJA(9):!,1R0(/C8'W"T-(.X96U1"!M4L$0^/#\`$/@A;2M\'-"@;#7!&R$CY
M#88-[S*3*+I)LQML'00;S#$M+D4N2RY/+E4N4BY>+ETN6BYN+GTNA"Z(+HLN
MF"Z4+I,NH"ZR+K8NIBZY+L`NPR[!+M@NTB[3+MHNX2[?+N0NZR[L+N<N[B[Q
M+O0N\"[[+OHN`B\!+P4O#2\=+QXO%R\;+R<O,2\S+SXO0B]#+T<O1B]++TXO
M52]7+U\O8R]I+VTO:R]G+WLO="]S+X,OB"^5+Y$OER^W+Z<OL2^H+Z\ON2^Z
M+Z`OLB_'+\TOVB_A+_POUR_<+_`O$C`$,)4H="BH"`TZRARG,.Q'_$?X!YXD
MV3V;/;4=GR_023$(B"OF$_1,"!DY5%X:/SNF4=T^*T#W,;!`F37^$OU2+1G3
M(-T;_0/5"FXJT#5L%\!**DS;25,S*S!8#B`.?"7E2Q@%I$D"4YTM%0?-!G-%
MI4CX0E@8>T]3#^\.]2VW&)$J?SB]%:$%;$`+$^=3DE'H&_<+Y2UA1I<4A"7=
M-6L(:@G^3'L7.E3")DI!61!)%N@+1!4M%KT=>TSL4U810RI14@LP$S`&,/TO
M)S`M,#XP-3!#,$LP2#!&,%TP93!C,&\P>#"`,(,PB3"3,(\PFS"A,*(PKC"P
M,+TPJC"L,+DPJS"R,-0PUC#9,-\P]3#[,.XP]S#\,`XQ%C$+,1\Q(C$@,20Q
M,C$P,3$Q-3$S,3DQ1C%%,5PQ7C%0,58Q2S%',4\Q9C%-,4HQ>S&=,7PQ?C&4
M,8XQB#%T,:LQ@#%S,9HQX3'8,=0QUC':,?TQ_C$2,N\Q\S'T,?4Q^3'P,1LR
M.#+04H@9V1+"$]0,/@LH'QH1R`,@,R(*MS#''H$DU3E?4]4,"`A\3.H/-$`)
M)9T/W1*B-<I*?@=*3D4[R@EM"4M!B@;30>D4$%-O+&)3_%3Z/DDTF#MN":0O
M^"H]12H?0@DO(5-'M0Q(%[8,:!R[/PQ,5R[1-X1#V4!G'APMQ2R:/G4M0BKJ
M"V8.GC1=#XQ4E".I*'-`_2U-(R$QDTY;%.067"FB"FD+Y4_B*@\E\@2U,Z<@
MC#-(#CP>W!XD,_L[)#(E,CXR,#(\,D,R*C(S,DXR*S)),G<RB3)U,G8R<#*$
M,I@RDS*=,JHRK#*B,K,RPS*^,LPROS+B,N0RX3+Q,A(S"S,),P`S(C,S,QXS
M'S,[,TPS2C-&,T(S/S-$,U(S53-7,UHS7#-V,W4S=#.*,X\SE#.&,YHSD3.L
M,[,SO3._,[XSP#/!,\<SWC/7,]DSU#/B,^,SZC,&-/PS'308-!HT4#0]-#8T
M130_-(8T;32`-&XT@31W-'4THC36%#H9>3.B`\0_8`6%4J@<""=./&X]T@WZ
M&-<7=@OR"(H9&!+%(T4WBT=U2>0W^!OK%0\(S%`V/[0?LP412OHJ`@5;+SX/
M(C3J(>=#J#_93-I,D1-`)@Y&*"T4"/Y`F0L01`\&R2RE`V%+?2-^(WD=J"O_
M5!15H501-EE"`$FF`Z4TKAPU$Q@IKQR*+VL8;!B1&-)':3[_4]HS6BOB&3<X
MVA.:4D$=1$`H!^8_^QO_#[U(1SOZ-)]0MAK`..HC453`-,(TQS32-,HTW301
M->0T!S7H-.,T\C3K-!0U'34<-24U)#4G-2@U-S4Y-2\U+35,-4XU6C5>-6$U
M9#5P-78U=S5U-7HU?S6&-8LUCC6/-90UDS61-9XUN#6N-:HUJ#6R-;$US#7-
M-=(UV#7>->\UWS7Z-?(U[C7@-=PU!38/-@PV(38H-CTV,38U-B4V139$-D(V
M1S92-EHV6#9M-G@V=S9_-H`VB#:*-IHVFS:D-K(VM3:P-KDVOC;!-F9(?DVA
M*A5.VCE-4^T59S551B\C14`U3-HZK$K$.(\+]C@73J=0+C:K)28UL$VL)44@
M]T'8"K9%@CZ7)_,:G0ZQ,J)4^3"J#(!-W0HJ30DO(S'W+#Q"21(Y3I$VW0<U
M*X0[*2S;.I@G/4)E%4`DWA.[#(`\CRD21K!(DA9R5*D6%56C/1<(?2_M(SLX
M521:)^,.I#UJ*A,^UU*J`P$F`0S%,"0TYAZ2"X$>&$"Y/O$'/DTZ2BD@S`6(
M*(0'`%"O),DVRS;9-MLVXC;F-N@V\C;T-@4W^C;]-ALW'S<O-R@W(S<G-R0W
M)3<^-T,W2#=.-U(W9#>*-UHW5#=8-W(W7S=]-WXWFC>@-YTWD#>(-XPWF#>S
M-ZTWKS?"-\$WQC?)-[XWSS?.-]0WT#?@-]\WY3?F-^LWZ3?J-_$W\S?\-_DW
M_C<*.`XX!3@,.`8X`C@!.#$X&S@A.!XX'S@S."TX)#A'.$XX3SA6.&8X8SAO
M.&HX>CAW.(PX@3AV.),XYS(;*F5'82?\&UD&K18Y%RT.P2@2.+<W+@Z(1EL'
M>`ZK##XX3$;@&.\#7"LL*#52X3"5'7LK`@SJ+7T:P"#:2G,WK4K<%GD)'ADS
M-VHBM3*V*>0'&4\F)5=`IAN&,JLX`RO7+KT(G@YN-L\DJDPM,^,*0AG!'.(I
M/4[-!!],SBB!-?$0)#T($@$A'A(P-DX2.2,K.@9'JT6>$Z(-4D%J#VPZ(428
M0O`G:D[:-\(<ASMF)T=-T$*B.F8N&D9M3C]-FCBB.*,XA#B>.+`XKSBZ.+@X
MOSBT.*XXLCC8.-PXZ#C?.-LX[#CK..(XX3@#.00Y!SD,.0DY"#D:.1@Y$3D4
M.2\Y'SDK.5,Y.3DA.2PY1CE7.3(Y%CD@.40Y)CD2.1<Y*CDH.20Y)3EJ.6LY
M;SEM.7$Y=CEU.7(Y?#ET.:0YB#F2.8\YA#F?.88YFCF3.9DY@CFP.:\YLCF^
M.;8YOSFX.;LYMSFY.>U2RSG/.=,YS3G,.=0YXCG7.=XYXSE$0JH7C0.-&HX:
M&!S6"[5#JS_6*_PD@AW+!T`XZS(4)O,AO$WA#%(];3RW3X@["T.2$30/QT2<
M%;TY6AU_%ZHVBT;$2&X$)A"6,%Q`.RZU"MPI<#`7,NU.@`FV4#@1J2US2R8,
M)D2],5\1#1WX118C*P;J#H(K]R,8'Q,T;C-A0T9#+SOR*&Q*^D691&U*G"/5
M)"X>-`ZB40P%R4B++,D99P;O.D(\NCX6-#4SD$"P)Y8:S"YH%').Z`31)<$Y
MQ5+6.>\Y\3GT.?,Y]3GV.?TY^SD#.@`Z$#H7.ALZ)3HC.B8Z+SHH.BDZ,3HZ
M.C<Z-CI5.F@Z93I0.DPZ2CI).G@ZG#I^.ILZ>SJ`.H$ZBCIY.JDZOSJ\.LLZ
MRCK(.L<ZR3K7.N`Z[#H_.O(Z]#K].@8[!SL..QL[$SL6.P@[`#L".S<[/#L]
M.T`[3SM0.TX[6#MG.UH[<CMB.V@[7#M].XH[BSN@.YP[ECNB.ZP[JSNO.ZD[
MPSN\.[T[E![*.W<#)2<A1KLSX",Z/ZY!<39R-L4Q:RCY.L,^0"IU3M(P[$R5
M1BX<DA\B1B\T^CJH'[P26@=N-7I*;4-<334@-28V)O]*\#)%2_DG7#XU&0M.
M=2>;2+,J9Q<"(P0D,QRJ#24J\B2[)&$9G!);495`&R-N&3\E-1S;)',9A"EG
M&QPCYRCA'+TV`CW!)!LU.$2(2C@IYBJ%!E(Z`400"[\8ED6D#"\3G46%*/P8
MHQ?''74@^P1G1^Y/[T_^(J<&GD+N.<P[T3OE.^`[\3OX._<[\SL0/!,\"#P-
M/`P\&#P?/!D\(SP@/"@\/SPR/#@\-#PK/$L\3SQ,/&$\6SQ8/%D\9CQ\/'X\
M=SQZ/(L\=CR./)P\H3R>/*P\JCRS/+$\NCRR/-$\RSS*/,\\S#S@/.$\YCS]
M//,\\#ST/`@]!ST*/0D]%CTF/2@]$CTV/4L]4SU&/4(]/CT]/5L]7CUQ/6,]
M;3UF/8H]ACV8/9P]GSVY/;\]PSW(/=,]UCW:/=X]P@Y`-)\)LSC;(%M0^S=>
M3"$7+%300\,1TQ`J!$(*03*U0/5-]DTP(8DQ)#Z*,9Q-X"!(&HTSBS%44L8L
MO#]%$D82=!>#$U<U4"^)+0T-OC`H"F@@G"6+$W)//!4.,%$'+D/'#HL&U0:L
M3\D]BA5=2Z`4[`M,&CTJDA/,)CM),T.C)2!*QC!Q'OTW>4G(/W4L93-_%@DT
MAB041;4>7#1O',X^1`DP!5,7+4;J4&H37D-(),T%@4TW3'D>90VR#DT:V#WI
M/>T]ZCWK/?\]!CX0/B`^+3X]/A<^)SX9/B@^0CY!/D,^0#Y(/DL^4CY1/ET^
M7CY@/F(^;SYS/G@^=CYY/I$^DSZ9/IX^HCZX/KL^QS[//M`^RS[2/ML^YC[U
M/NT^_SX2/P8_!#\-/RP_*#\S/S4_03\^/TD_0C\_/U`_5C]>/V(_;C]E/VH_
M>S]_/W(_@#]W/YH_B#^)/Y@_CC^%/XT_H3^G/[0_N#^U/\$_O3^_/],_U3_1
M/]`_V#^W.@X@L3$V35,A8CIA*;4E#P_5/%@C,1=8%[T$_!%20#`0A4V[.YLR
M>3:-+5-`;"9?#^X0C@1Y#LL_NP=;*XL(I2.;&_D]@RJL19$K2Q[Z.!A&GT<5
M-N\_GQ.V3=@J@4!E-HI$KT(M2\PXC`IL/+Q27%0E/;=-!"NH(\`/*#1#0@1!
M&D[&-&M+?AU^!&\Z[@L50N5`%29_!/LUKALY089%8!>+27,%0QFW2>\/$"WN
M%^D84!K%*5U*P4!O2_D\-U+V/^@_US_[/P!`!T#]/PE`"T#Z/Q9`#$`L0#Q`
M+4`G0"A`*4`J0&E`>T!K0&U`;D!U0(]`:D!W0'1`<4!\0&A`I$"=0+9`K4"S
M0*]`RD#30-!`UD#C0.)`\4#V0`)!^$``009!&4$-01-!"T$I02=!+4$@025!
M+$$J03U!0T%'04%!0$$^065!64%J05M!=4%=06=!7D&$0:-!ET&-08)!@T&3
M09!!NT']0;Q!M4'?0;U!Y4$#0K=!^$'10>`'ICJX,:P]NC>!#M0HC$`14GX)
MJC0?,+=,8ATU**\S_DJ%'<1`)T0B*G%0B%"Y*<T6JR<0#"\E#2HH1/T(C"S/
M5'$Z+#3M/'Q1OB\,'JXTC@:?)H06:D+0&T)3_1%V)`TA#B'D2ID(V!U++2Y$
MHRR-"KQ&<CKK"K<)APUB):,WNTE='^4,&C+9"]E#$SBC,WU+<`C))3A/(T;9
M4BA/9D1'*M-$S3$$-AL=D!??4Y(>K0:Y%YP1VB21'K(C&2S:)>M!S$&X0=5!
M"$*Q0=9!^T';0?1!M$'I049".$(V0C1".D)70E9"4T)U0HI"<T)Z0JY"IT*Q
M0M9"S4+(0K5"LD*X0MU"XT+A0MY"_4(!0^]"[$(&0_%")$,C0R]#+4,@0R=#
M(D,V0U!#44-U0XU#<D.00XA#C$-Z0X5#>$-V0ZA#JT._0ZE#MD.Y0[!#ID/*
M0\A#Q4/40\]#S4/C0^)#[4/I0^!#Y4,)1`Q$'D3W0T]$*T011/]#_$,\1$!$
M:30@+G4H\@\U1,I2""A!)0DH/"_62"8P,2VD%4U+QCDP0KT'NC00-;X'!2J3
M'N-2KU/0&8\N9"]:4NTI1!%K(=XKI$*G(=--GS15)T5&VSDK/AXH-T/F&()`
MV@V!"H=`W`V94P$4=$Q=2=H2+Q)>'BY22`WW25)2K!Y%47=$535&42PA;@@?
M&E8U$3]_)_,$ND@25:P%[3=I(/P78T;)4'%)[2[W!@X.A!.F%L91UE%8-0-*
M^S[O+"@5049?4'XT/T1)1%%$2D141%-$4$1C1&)$9$1E1(M$:$1R1(!$:D1Y
M1&Q$>D261*M$H4321,-$G$2=1+9$IT3R1-]$ZD3C1.!$ZT3>1-M$`$4#10Q%
M$T4010]%"D4@12A%(T4B12%%-44Y13=%.D4X14=%1D5214E%3455159%6T5=
M16)%=$7G17Y%>$5\17M%IT6,1:1%ET6B19-%M46W1>M%WT7.1<=%R4771<]%
MY47B1=U%WD7_10=&`D8J1BM&)T8/33(K^`8`!T<*0PJ&(L(UIATW'70L;1X>
M$2HVM%)1%I]*9B$N11DW3B/I+=TY5!QM(UHEF"`X.*(4S5"3)P$<,4IK!V93
M)#I/-5<E@D5X"%(CTSS:35LG2`K?"*H*:B9N+^T1JA:;1[X/]5'I,:8QYQ8Q
M(F`Q3CU2.403B@J[1!`/62/X#X-%A$7;39L3ITRW/IU',AI3+S<-4$['.RX5
M9AGV-=Q-#RVF'U$(@`3>-NPM,TNY'FD9C"(-)B<ESC@U1CE&0$8_1E9&5T9>
M1EI&;49T1H%&AD:M1IU&H$:;1IY&G$;+1L1&P4;"1LI&Q4;:1MU&WD;@1MM&
MV4;M1NI&\D;U1OI&]D8$1P!'"4<,1RU')$<O1R='+$=51T5'4D=?1TI'0T=(
M1V9'6D=-1TQ'@4>)1XI'AD><1\-'S$?A1[A'OT?31\!'OD?.1\%'R4?%1PI(
M!4@.2`U(&4@42!M('D@52"1(%TA%2#Y(1DA#2%A(7$AJ2&A(84B*2`HI7DKN
M#LM$#T.-0'H&\P<9'!TWT`3D!5`3#AU54P\=BPRP&S\-B4Z4$4$'[D.[1HT&
M@S4,*O@C`P0E3YT6_P=U.VHN?`@S)H0-PCE7//T%_"-3$Z-1[#O$.5L_8SEB
M!)!$3@>;">(C!"A.0AI#""1X4"$-3R#(3M4X(!V%2@\D"T>V0:T2DQ.^$D\$
M]!=I&VX;)!WI%3H&Q$=2%N<@63!V*F\K<"O2*SPYFCIW",Y0\2!U*[T]!2;`
M2/91.2%`0H)(;$B%2'9(>TAP2*9(JTBX2+E(S$C22-1(V$C72.9(Y$CA2.U(
M^DCJ2.M([$C_2.](^T@F23A)+4DY23=),$DK22Q)@DE227Q)=$E/27!)A$E6
M25E)84F32;!)ITFI29Q)FTFB29U)Q4G72>5)W4G-2<%)UDEH2A9*+TKU2<M)
M,$HH2D%*Q$G`20)**4KK2<E)!$K<2<Y)9TH02NI)E4J62HY*FDJ72I!*DTJ^
M2M-*T4K.2NU*ZDKK2N]*AC?P/YE"C#VS3!TD^!#A#W\S/R\@'#`L=$M3%=8T
M\$\;'_(5^@UI'7XIUS34'")`%B'9-($I(B1A.#<.]Q6Z1X<]0C3)'C0,UU$[
M"8@;9@U)#E09_C2G%$LY@!:9'LP:7S0518XM1!O'*&9/[@4<1;LW#A464FI&
M(@LD0IA)YB@;(2Y"]D<R0DE'.P^`$T,T1#09'ND;K!',1MP.@A@V".(\E$5H
M'EH-OS7-1LM*C3<",OP^[AO.1MM*IA`S$AM'`TL52R]+&TL]2Q-+*TM92UI+
M6TM82VE+5$MV2U9+C$N*2Y=+E4N=2Z%+H$NV2Z)+I$NH2]]+W4O'2\E+T4O%
M2])+RTOD2^Y+Z$OO2^E+_$O]2P!,$$S_2P),%4PK3"=,)DP^3$!,4TQ,3#U,
M/TQ93&!,94QR3)Q,H4R:3*9,:DQV3)A,=4R03&),A$R(3&=,?TS*3,5,R$S.
M3,=,STS)3.Y,"$WS3/E,\$PA315-`$T9325-#$W\3/A,+$UD2,PZ6#C22NA$
MZ2`]1&@M<@D33)U14T7<$01%'0D).%A'G#:?4[]%$DH32@\[!0JW%SDXW!?F
M1<]0&5,M44@5-%2O3X\5E!/\'`8/5R=*#EI(1BT@+YM2&10A2FX@ODB/3Q4_
M>DG$-$50QS"_!5A%A30[!-P,N52U//!2QPMH4-A+PD6O1C)*"AK@%TPY3@A8
M1,8X'QA@"$P5@1;_-'@:>AY5&<D3RT/M/SPXJPJ##S8K."SL$"\:8T=41=L5
M1A$"31=-($T%34!-[TQV37I-<DV.395-G4V83:%-LTV239%-FDVN3:Q-I$W(
M3<]-V4W03=%-WTWA3?Y-_$WR3>Y-_4WG3?1-^4TQ3A].+DXA3DE.0TY73FM.
M74Y;3F=.5DYX3H5.A$Z13I!.CDZ83IE.G$Z=3JE.L$ZU3KA.S4[83MI.WT[@
M3N-.[D[F3N5.ZT[H3@!/^D[T3O%.[T[\3@I/!T\$3PE/-4\[3T1/14]!3U-/
M;$]=3U]/;4]O3^P&MCU_2<TDN%+*(I(B-4$+'/=1RC5`#%<DKA#2(@!""3YH
M#3,%C`A53#PB1S-],_(YJP/C3%M$X0FX'I1#-T&F0784SCIB!WX:?A\S.NQ0
M-#J_#S,9%@D9.H4>("*+-"(,/D1L.\P_/T,)$@T*WSM&2M\LW$KF#B\PT%.^
M"&`)F%,1'&HQ.3R+4UA`#R#G,VL/+U$<3Y)45S+14WDF4AT;"^9";"E:.'D&
M7!E4,*Q,%`^N15PP6CD;1ELYS1I=&7-/<4]\3XI/DD]73X1/BT^&3YM/F$^>
M3Z!/HD^E3[Q/J$^Q3ZM/IT_+3\A/U$_,3\I/\D_@3]U/WT_B3^=/Y$\#4/=/
M^T_]3_1/#E`,4!A0%%`74!I0%5`94"50'U`K4"Q0-E`W4#]01E!'4#I025`Y
M4%105E!<4&=0<%!Z4'M0A5!_4(%0CE"B4)50I5"64+50BE"+4(Q0P%#'4+Y0
M\%#A4.]0VU`04?U0"%'Y4/]0]E#Z4"-1'5$D42I1^1!;4G\.C$1+$STQ^CU;
M'>PQ2$T15$%39D*/&K1*KP-!0R,M?PFO$K]2-$CB1_,9'$:P%*XN;#&>+!1)
MB$`91?L\>E*?-^0P/",-&OP:D!1U2S<K1T2#*VE"[C)B"7Y&*CTP.\$$-0I:
M,F`YFAV^3<Q$*43"/)9(ETA84;M,:`8L##`E32Q.++PW<U`\+!8=)D^\5!LF
M-BC.!\TNN19'0MI3]0,4!.L>=%"52<D8LQTC*C$)9!=%&<4(KT5.3Q<W*5$K
M42A1)E$V43I1,U$W4551.U$]44M1-5$R43Q1:E%A46M1;%%>46117U&(4951
M@E&>48-1AE&.4:=1P%',4:51Q5'J4:]1M5&K4=Y1Q%'H4;)1L5'04=]1L%'3
M42%2+5(H4B]2,5(K4D!2/U)34DM23%)=4F!27%)B4EY2<%)_4H)2@U*-4I=2
MCE*24J)2L%*N4K=2IU*R4K%2JE+34LM2T5+O4NA2]%+Q4N92%5,'4_M2%E,#
M4QU3&%,E0FE/*A`Q44TM_2.V$)Q+$"%;&_=4#QY9!Z$:5U-3+#U/>4\`.38S
M1#P^3T`QF#@D1OY.1SR,#7L[%T->&S(>("9T+DM)>`._3U0:HQI[2GQ*I#=\
M-7PNH#(L$.H[)AE]4I$7F`-)2]H<74T?':H:SP]W4"9&Q4[<)&(XET#*".8E
MF4E+!GE0]T<#$;P*F4"]"L](J0A]-0)+#22<"91$(BZ`&<E.BDJ1#<9/`4C8
M#^P^K35+15=%F@5D4E4XF$7Z4@%3"U,%4RU3,E,S4S53.%-%4U%34%-24V%3
M7%-E4UM3<E-J4VQ3=U-X4W53B5-]4X!3EU.:4Z53HE.A4Z93QE.V4[U3OE/"
M4[-3N%/H4^E3\5/K4_U3\U/F4S%4Y%,@5#)4(50X5#]4-U1C5$Y47E1&5$A4
M:E1Z5(94FE2<5)U4GU2D5*54J52W5+%4LE2S5,A4Q%325.%4VU3=5.E4ZU3Z
M5`-5!%4-51-5!E4'51%5*5TJ72M=+%TM74(R9ABH0H\;<1@5%T48'$(=0J`F
M.A?0#PLHX#%;)?(-<@7G.9U#EA(:4B!2`D@#2`@+(QK?/A1*%4JI'"P$J1CC
M$-D*NQPJ(LH3=B#J$@%"GP;`4EP<5!(>0D('I4":&34.8%18$G-*RP,/,/(L
MZB\]%?0L4DQV+)TZDADK(N$7SP,B)8\MD07I3%T<H3Y**A]":4J,(-$*13Q_
M&20A$P604)=-@1.6!QX5YSP%2G87@C^0,.T:L1$>/`T6$D_840$+#QN`0=$3
MV"V@-M0ORA2\"9P4/"WV$*(6>$R$,'P%ZSY?2&M(-%$Y#OU$!DL((S)-313?
M/.52>AL.+<PK%1MR,4\K#@?^-I85+$\`.+(,B$?N(%XZ$$GC1[H1YC!Q%B<C
M(P8=3](5*4RM#<-)R4!('W`BAA9P(9XC(1N+-V8_FR)A,/0@"#/1&DM*BA_"
M/Y(U(@\+4)<DF#;&2;LLJS7&3"DPZT91/UQ!U`C2!\`A^%)#+F,AZDO22245
M0Q$:4T,YP`4%5$41D!9;,"0&X"D1#:8XYR(:$L8]>TDK"GDJ`1A"!;@H'B=Y
M&LL34S`&5((<[$4V3_D=S!/.3D4=+DO41NU0]C>@!J$&8#3W-T8+T$YT4M8C
MMT[O"V$)PS>-/6\OWQ1`0^\I4QUM.Z$393PC#"0,`5)%&R-0X@\3'_PKG`MN
M3N<$ET[8([L2Z`=6&ZTXD0-64Z835!6[-B=/H29N2F\$BPFM/Q-2D%-K!AY.
M5$]X#;].[4<M,:4W&#X%/Y@MKQ-[&S\104R3(I<AJ5+>294]90CA'5LNEBR=
M"H)'?R5!-$\ES$RD,,I+C#JS$J@RB3;O+J13C#F-*?=`B`5`/>H51B)C(&82
MAT=X1.\;VC]K5"(HGSR8!J(N7PKY05(?2!W%'=X?+SX41CH-%C[H/OHW-#*T
M5`A.3@P?#K)!T$9[&-\6P@@:(\,$'C$^&",3]Q+_.H,Z4#Z`1QL'HQ9U*J]$
M)RD",=<&;$N3*;<DO08&&;PF3D.O/X)+'!\A%4E#T4X$!M$/M#GT1_5'4T8@
M*!\4TTZ/3<$%<5*W$AM.X4$L/H]"J0FR"=)"DSR95(8ECC<"-*@S6$/W4^H@
MJ3,I"KH+D@D'#Q0.B4*P3_(@G!LM"M\*Q!5]1KX]>1`*%*,[00Q!0DM0(3OX
M2BL@5!T^-:T+<PS(**,-*C025"<]D#1O"OD9-S,:,R\>_TY:/3H1M$XO0>4A
MZR"$"<41^TU+!)8Q-S\B2D(=6"?1*GDBX0L>,AM3"2"O.F(K05(A+$%'5!Z!
M&(<WORY2(&0M>Q6R%SL..U!S-%=)PB+()-057QX8&B8X0!7F-"=1PQJZ14`S
M;13/(L1!B%2\4S5`@4Q4.+((7CMS"3@=?$;\2-H0$$T&1J,#9P[V4UHP0"R*
M#1`[0CER*VE0!!T\3RDS]R#=1[-/F0E/'M@><1.%02PR1Q^#!*0."%4#!21%
MOA.]4?<MBE1G"PHPW3_7&3U`14(:%_LSUR(G*B9!O!'(!MDO%`7N2,<]!B]R
M((LM@$D"'(X0CQ"Y4@`U-%/,0V(*9P7K47`<H@?>#"H@H3F(/A<+?Q\$+AA$
MA0>6#+DLHCG]'0HS*RM5';<Q!4%90(8>J!L(+A`@"2YB*<DH^R2>/P4UK51L
M,VLQ1`Q=5,XO%5&T3%00G0OB2X`.@4^*"1P_D#Q,$ZY4KRY4",D^VC+93XP.
M*SVQ&],GO$[T!80*V"BB)F\\'@TQ.VM")2,D''U1W#)^41(O850:)N%.U2W$
M/C(@$T,\4CP.]3MC'+-1JU*C(GM"A!E93H@EA4MN%,5!&1,),"P\C$>W(#1'
MV$KY3^(PE3>35'(GF1+3"JL9Y"F9-.<WO1>Z%!DKV$6%1.@ZRD05(>E*DC*3
M#1`)1SHM!D@%5#1*!<T04Q&Q.4@;L4L*&/P_(4%Y%-I0V"(J,%%)<R5U,80$
M[!,3**4.5"A+"3\."#]\+<`LW`,21_$.;P]Q(6$WOS=1+;\3PDK,">TXO!:"
M1L0FTDUH4;T#"4H,,-LM"0=,#!(A)B?(.QLS'#-\)CP0`A;G#`$&`@:.(%$S
M0!"Z"F(;?T$/3M8M@%'C)1U2\0H+$)A`#"@H)QM#FD`.)'(UUT0C+NL[O#2Z
M&U,,P%1P0AXC)2$I)R\--!(X/7H0"15+)*<UD2ES`T8;+"!-(DXBHD?$*KHA
MDC0W*)8D?A!_4>Y'.CW?#4]+:4T^"7!/>!8M(?=-`44)#01&K1'`-6DWT"*6
M.>$^=`D/#=L0\RR7,50J73;1(GLR1U-`&,`8I2^;/O4V"@UV(OX.I$KV)*@8
MI12I310JJ4M=)C`*\T0E,(1*]P>T'0`MY`\R,AL;=C]*1=DQIT/]$D='*4[_
M$MP;=27&$%@@_R^/470V=$/J"/0+A3.+0:4R>3%<-S(&_E)7(J-)92SN$X4P
MX2<U!,,L\Q]C->$S'PH*$S@GY"T$2V8J54O^,^LKX3>G,F=)?C6G!<,+/R`>
M/D4:K5+L/2$S&!.?-3M%ZC1?&J9&("S_,;P==PIU'9PI5TNF-.@B2PY9)Q(-
MWP/04+(1RR)*2)DO*@5G%6@542\<4P@VY!`]!(!2GU%\2.LA(TK(,TTYR#`B
M$1D5)B`B'C06NBA\(0$U<E*;3NQ1]3=X)CA-V3<=3*<9235K4)T_;!/,,W52
MD"UB)VY0ZT]Z)@Y4-QK-/ZX+[1:A(;5)N"^Y,K`6TBW-,/X5-05C*?8N829F
M-A<VKQLU2$)#/`LR#(`+L10B3$<8I3FD$Q-431.F0%`%VD^X3*=`HB%T%;A0
MU$)Q,LP4^![?*7\[7AB54IDA>07O./E`+TRD$)4J"TR4)7<^_$(A$T0[#4PE
M#N9$BS\[)!E+B0LQ'Y4QX$&T.ML>#"U:,3H$E3G:",0]A4R+&;(%+A.</F`-
M@0PN1Z!4F@VG')0_7$MC%4T7'#**$L4ULD/G/[<(>"$*,BXC6D+B$-X$XB[R
M/28H_"X-1E,<J%#%.%`V>RP)$2\%[4!\%YH;&B6\!+H</CI=)&9+*TT?._\J
MC`]>0BTF/PP?)[]-V2C9'2\)25.10,$:<49V4#`>\4]D!XLD61)V$0`GMA05
M-Z4AH!F]2;4;D5,H$5Y-;1U*&+TD@B_D)><E=B@J)_D,9U):)J)`R`O>5$`&
MIB/1"UA&G@1$!D<&@@3:"TD&2@9@+F(NUU"B"RE)SC6A$=TX239R".<36DR>
M24DQ5D_2/Y@^E%/+#&T7S`R>$"=23`FN+5,*:0D$4\<\##_--$8:>`]-3`4M
M:4EC'L,FR49($)D?#DQ*-%X.;1^L2:<T:R+]1:LFAAK61@(A;#;@5*<;`BN-
M$;8Q>1C(1$88\C]<2O)`[3KM!7X7!3PW-I!&9D-F%#,E!1NP-#,8FA$:+D<K
M$17Q2=0B\27!#.Y)R$'63D\O^TNO)KD3]Q-L.=PJI#Y9"5L3-0;^`V`>XQU[
M3OQ);2E((9`]VDAC`_`LQAO5%EP$`B`!,<@F>3(+%@$/7D\<1[8SD4S``PQ&
MZP8*(]9-FSD,$20+LAP].L]/JB[<-J,I)TMR4587@E"60?<EN3M)&H,5QB-`
M!;@,["!F!11,;5+_'A%-J`M(/=D,RDVI+IT-43N61RP*&SWR.*!0%TQB3N40
M\1;=#!5`'RV$2,H*TD;7.W$.+@K+31D[PBD3%@%05#F/!V<*(CM0$'H.+2@S
M"IX,C#58,CA&04V'2?(0D29<.?`IF!FX3_<\.1$7!AH&-"7#325,A2EE)>@]
MU3%6-VA,)#:$/\X2PB&4!MQ$2SB038X,W!JG!%D@FP52/\,B1Q:U.'(B:E"&
M1$XH]E1/#`P4QADQ,#9%U5/4&LI4."W"2>4\_@P_.6<'30H3&U\BK@V:)%5/
M4@-@2,\25A/42?(,<B7$$($%8P2Z%K$S[$IZ3E\AI4+-%84G4`\L+E<0/BWK
M2TTZQ2(?&U$X&1K`#+8F8$GX0Z(%MPLI%EL:7D4R2?DNI")R$.$;SBLL*X=/
M7"[)%)0LSBG["6@DXQ1%05M/JCOS3L=!$%4B&ZX2#D^G+K,KXB9+4S!0S3R\
M&'T,0C>]$\(7?!N@&"9%-4)6%I\N221.1\,)FP_Y*%X31$$X)&4<XA0:!X!"
MSC0Z1%,QPC-H4HE4L3"](X,M#TR&!ZI#(2"T2P(S-DF9*HLV)`67.=A,7$ZG
M&`8CK4.N0],Z>SPE+/!!1C83"P%4CU0!23-!LT,S3@,SITMZ*B<)Z!*J)CI3
M&1D&,Q,J!S/#10$.^06Q1MX%0T\90"Y1@BKM)C@-!2L/2?X'K"*3$@8KZR(R
M)KI.E@CT2U<;YT>>"+U.>AF>2UL-^P8]#S0DE27P.2<+_0[$#!XM$"4)(SX>
MP4LI([4?U#JC2EP*/QXD*(<B_T!J&I4SY`,1.[,/&B(!+K@770F>.Z045P-V
M+807@@YP`X$#/#KY%A(^!@I^+_0D[@=[,&(Q)DM:!>HZ%0YV*YPOQ""')A@Q
M*`LH'K@NF3--*"((\PU]%Q`?!2%"2;0V]"\S-HH'`1LM+?D_Y!P2+4\IRA@O
M)T9,T$S#,]5,N4W^/ZY1=2^;/)X*#T_4%BU"PD[>)8),C4?95%4J,`VD#YQ0
MGTWA$E\]'S+;,*P*H4ZK"U1,"TLF,=]4`!<<0,LH&B0Z1]<\UT\Z/(Q30T.U
M#U4\9#24"V].3Q'Z(>(ZQ0JB#'!.YTO:`Y1/KQUU,,0(6$TQ)>).24FQ'48\
MW3!K+GU*\$=^2N$M/S:["OA'>"=)*THKXBT)130>USA,*_Y',P8].60Y-27#
M'K,3J$FI)K0-+U`L#]@P3#0Y!)A09U$K!#\I81,'+=\.:S<\,PI`$D$6*B)0
M1A-P$7,;US$U,G8Q<C3L1G-#!`0>".4C(00-&04B40]B''E%_`PS%60JY2OB
M27$/%QZA1OQ0:22Y([$Z*T>L%3M$P!9((N$@Y36N2&$_FDX/0(],I0P[*/I3
MG"JG.+4ZRALA4/`F!`ZH!H])C0Y,"M(1.`S'1B)(HQBZ(U5"\`C>&7](%%$$
M'KLT53<3-3@TQ`,Z%KLI42Y'3K-"2B\/$MLUI2)S.7X[J@6Q((\E@$Q50\=*
M9B)%"R]4B!&&3#)!3A<S%)@Q.BK5-6@.F#J$0A=*8PB].)8^XD&.+D<R4C0Y
M'>LOW4CQ2D0$QA%W"3!%F0__34HRY1*"!_4LZ42I$/,@3!`J%?)*?3*-!*4V
MFC4@"5@N-A)-3K%)DC/L+\,6;1C42C0AX0XD2C-26T+;$]8UWAH4/,DAI4U@
M*'<MN4!J$`M4C"V#/DXY^2ML%?$A7"?8!LP+DQ4M!^TO+4V>.@)580<;3+,.
M@QRI4`\Y3SG*/7,@-3LT2>,6<BF(+?(W.PPS*]D82PA#0'A`GRI$+?Y/?1__
M((\FQ42/1GT9/0O@&H$[V4J!4=HX=#S>/G9"N37W3%$*7TG10_H&@TR\&CL(
MW#I"+&A%YQ[.-E-3,RTH,&!!;Q9)+U]%QD,J/Z$#UDRO!=H4YP/B'H\(PD00
M)SE+VD2P#9@,RPAB0:A1V2YU"F%!@R$,"5H+J#HN!DXN#AD%"Y`OSPQ52`M5
M?2T$$QH)Y$E:24<^)4<%"'(AHD9^,L<XQCM*1C%0]03C%]$%C3C@"O<X+@<?
M4V,*@$[J,"X^?S(]$Z%/:RI/,CX3K24!3NXO#TB<!`('>QXL%>$Y$5&X+*,M
M`RYR#E@<T2Q0/$DXLDE;.NDB9R$0!3$^,45S&/X=20HU$<,4V0;[.)TL]1;=
M2CHA<U*4"M5#,CY]+.@D/!LY3?1%G#7Y5/A1DC=H"E]",D4#->\OS#V]4I08
M+"R6(HM(!4,Y0VI%.R$\"(<DH1LN,"\V72M`2;!*-182(EI.'06].D`R^2)E
M(_M)03W<-&$S/T4#$@0)PS^@"KT8?PQ@3BLCX!``)8%3/3.Z!14[ES*K2U0?
M+#.`"AP+$B<A*WT].AKZ.41'`4!4&`,LQB'3.^LH9R.S'U$D$DW;"(5"N$"R
M&MT0T#0Q->07<STV-:HA:5,#+\`R&CKR,7\Z6`AW$I--OBR;*T009"MZ%3$&
MV$!Z%_\_H"3M$\XYX"=6*`E(B3J#$#8G92J8*3Q&&2\*/U88!2PB'\,#30\X
M3`<WUB&#,F,Z>"WD#EL7>S96.3TB8S0=1&]0A47;3@L]O0S'%8<8KTNI#P@I
MK2I,)*H_[D0^3C8%*#M"38T("CXZ!UP7<AQW&)L@E!)Z")\_`U)M.IP@1!GE
M3*@]ZB+24T@I,T6N,W0X,Q=)*=Y(Y@I13Q$@ET.O$#XJ&C$H)2,O?#;D"7<4
M727L/,4&)E/N4&L^QR?D5(@@"PF'3<D<.13I#MD\^@AE*2$B9R?U+\\H+B79
M,G`OJB#]*X89,$#!)D8<C5"42D0:K%+E&]%%7!K)/*-&HAV,)_@8I$9+-@0[
M24&[(PA`NE.6("`(I@300;PJL1GL4I$QV4&S.KH/J%,V,)(X%Q3Y$1L,5S@,
M%J<H_CFS1#!'IBOP'=@ZX1GD18DOJAQ&1A1!G2K51Y<S'"(/.$4J94LW,:HE
M3C;%.\H:Q05_16D3?SPM+R<LZ!EG2Q9$&"3P!\08I"G"&48FNU(^2;XH+T8)
M%.8Y:3IT-_`W-3Z1"-<CY52[+]$#]B^;0^5&>5/L)%8#3R+B.UXCP@^)0'`+
M%%07440%#RZ$5)4+/CQ&#[DQB#*-4T\;24WJ'@`672KA"(X]%D)*)MH\MQ6^
M#.HYMU#0*"`KT2@T&7L&MA/,(RTBQQ%Z01$MK#__&.L-#$,-0](:>R9C$>4J
M?R$22!D.3";+%F=#\0^+/AY`H#^G$Q@VLAO\$#XAN5`L/7A/(QDV2`D0U4*Y
M3#XBCSCV&5]`J!,T4$`(;S/1.$D8%R.Q+A8S2SM?)7`-MD\/)C8V*3'R!8X7
MV%-F%]!$>DL*3F\2K1=3!(<K;!:5#68K2$QK"48N4#)3,J1!B299,I49$1T0
M':$+#T=C098?"T]>22T10QQC'P`-I1@R+UX'525+-`)$0SU(-04CVS^W&:HH
M-@OC&5DTQD+K`TT5V#N9)P=#\R:'(,E$Q2MV.Y8CT1MG&K4^W5'+(9-1)!N:
M$(`(7$)_(-$(81^%+E(K+1.X!6--20DU.N$11D=?0?5,@@47,YD83SYX5)L9
M&DG_*V,=^0]<'7`Z&"/M&!U&?E"-'KI0&`8Z4A=4;47?2,4J_2YA`]`3BC*P
M*D$(Y@S"!-="'":T.XLAF$@>27HNYD`!-I8\M3O=,K041#IQ"T<'$R_)#'4%
MX#8Z%!A4.T$\2Q4:KCVR)X`ADCLZ-^,ZKC]I%/)0\U!-)&]*P4VC/!0N2$)>
M')(4QBF>(-`ZNU2V.[<[EQ*I0.$LE"BX.\XNL%2O/G%%&!921DTF@3D.*HTL
M?RGQ'B141!9*+FM,A#K.#'Y27C=9,Q-'AS6*.3@FN!V(,%T(4B6@,$,_*4.7
M.UP.,4"Y$&\?=P9J'M<(K@5^"(<N``353>X]FD%)%4$L.3"#`Y(P!PH<)35'
MXS)\,/<(K23Z3P9"F3?H!>TMLBD%.K<3LA/[$G\N^5-1'LL@Q@343HLZ?!.'
M5.Q)@"[O._I#.1E.,`LEF3$8(G93K@?B49]!#`2;)Y,W6P8##.Q/+QR[0T@Z
M6$R*4GL4=3_9(OX%DD"U)QL.U#9Y5)9)WB@_(MXR;PQP,?\(<#PD*KE+Q@B8
M$H<?;`;K.4LHB442#/HGP$YJ'?8'.27K0B="NR$5.FP%!U!A,K@)XRA&&;8;
M+S&D&M\RWC`#)Q8WBD6C0[D)02-U.K<G3BW[&88P>CN;$3@SXC0Y2'$\\$,7
M(=H=\%2D)G$S>"0K$/A$J$Y?&QP=/5()#NE&DTL6$!@A>RY9/4(QSCW//1-0
M-0^F-VXA'1TD$GP[EBB@(*<:7TTB)BA.V"^%.104GT0($X]2"1,'"_\,@B)Q
M%Z,=YQ0`1`\]3B?F,>@1RS>E%G<0>#G")QDUDC_U4QDBL4,9/<$K;AI7.CT&
M*16#4_0K`1_24$\V7A08)2U*N1R<!F0P&BJN)#HLZ3:)1)`F1D^!'9XR%#.7
M&<-47DA!&RH+CTZC2R4/&1LO0"T2ZBO8(.`AY">I#@8-\C#L*T<<,A$8%95%
M\$8K&'5(GRE40B(:)R:?,2)+GC'[&%`CE4<<#)<_W%,=,V4RX%.\)`4&T#VB
M&9%$;Q#O%KL)D2!:$N@,@4J9`VE4V$;K#BQ3-!B24V@;JRWW%PP;SS.N!DM+
M0R,^+K)%;AUO':$R5@@?4M\K126_)&H;OU3U(L0WQB^S(]0/1CJU"R$I=`8!
M!9<H2D.X(@TH!!%W*'`=$"10!^(<T$BJ",%#<1TS0B`6YP<D+MXD5`R^-"8O
MB2G!5#DIY$XF+B8AJ3SD4A$DH38?2"I%\00O13LJXD;94?Y"VTRG,>`(7`D&
M('\JGTS73<E"6BV(`X4\Z1[L&3!+<@P)##%&!%`H,<T'K#32*/@%P4[A0$]`
M9DZ]/(I!30;<,3((RBEY)0$PO"NB2'4VYASR"L$)]@OU0[\1XRX`4PHMNE&`
M4.,GU!^T,%@HMD+Y0P9,EE$T/S]1.R<V%40.@24./Z`)TB&")-]&@#7"49-0
M+A91,0$^>B/7'T\9*1AC&F4>)2FP()\#O$6N$:T5)!/D("Y4FSM))_8*1Q*[
M#ZXR0U#M425+ZAD,5#L'HCSW-6H%J2><&;`CIPCK".P(S!\!!`P/"2&M)D@K
MWRK,*?PY@3?I&N`J64>T!4\7M05L-VTARB%7!6X8@3;7-C1#1!VP'`XLJD(=
M.J8/=D]@+;)/FB_;0ETG/P;2!8(VYQ?O%:L4C!1=$1@+@QA9%A(L(3=Q(U@D
M[2CV/4PW+2`"3@-.OPC3-",GX@@Y-W(C.T?"0&A'^A"Y&DI-PT"(&,\$B1C5
M-+-(Q4"0!+`#'T"Y2H<C0#5V*6L+62;F%CP=:@X%("\,<#@A+6%/0R87))D;
MG#!$(",T`!!M"Y,)["A-"$,@24:B*F1+JU`&$MH[CSNZ1$P4:@Q@%$`ZG0;P
M-;I2N43H'N4R93'0"H@\OE+B&`L4!4[?,Q\_!R$O,YXSC2CL5`M"+B"Z3;(D
M:D<5)U<'4@@:3.D#8RPY#*XW?CU+3CPF<C`S#9,;L@942K<URA!<%>,A6BB9
M4?A)Q5"Z&(<E<D@X.<A1[32B*&10SBW)/_HCM@\(-=$O>CT5+N<[@2'Q%T(U
M6`OS%:P/[C'_(I@\]15Q,*TAHD*E&L<(^R^K#:$9Z3O'0,A`0!=S(;(/<!K9
M.Y09F"3[1,I)I%&/2A9(D@_#$'@X9B\E%$1.AU'^+YT)QQ!T-#T.?B<'/\D&
MA!").840%A%S%EQ,12%!,RM%A0N%$[E"@#>%.!0QWU!\0[H-:"\&2A\052F<
M2OT?;PFC*(<X5T.A2NM2*4C1-<-"B`K*1Z)*ATP2#MP__BT@$*H+`%0Q#,HH
M^"9P0),<P3)I',D;D!N3(?T-W!,''<].PBX])X$':0523T$P##&N$Y<C$!25
M%RD\6A0P3^%$*DZ*%L07K$YG*OM,`PFO+8<QGSCV2",)PD<@&F`')Q=]%@]&
M#B.'`RHLV3Z11L9(*D(W+3T%,3G@(FA)QU'P4\03_1[F4-(C430R&UX\G!-S
M".T;.4(H#J),414.']$T*AVM'9XP4"I_%6U!KA4O&W$@K!Q*,-4A7S.:.U8$
MOP,]'L@3ET<I&DY.G4&!/`,<PPWC`Y!"]$JG-H@U[B:\/@(.&C!3.SI-8D-+
M$J<M)!%0&\@-^TH'4A8H*$*Z)<$E_1=,41A*DS-+,H\93A6[(,48ATZM3+$*
M33ME%_T:!#H7%NT*BDZX2UH;(4+5)S8E)"UK1HQ.NQN\&^0LRA(!-\HL-Q(L
M+S1.9`H02+D#_BJT#IX-P1CE#M8L?0EW3V,G;3%V4GH8N4^U2BI3Y3YH)X4/
M-$NJ06XG;R=\&+I*J!16!W0JIBR"##T=PC:<.0H)Z2@\,;8T?S"R#?1"+`M5
M#Q='FTH7(C9.#3%9"O4=O`\+#SI,EDW>%NE-#$'9-<X931]9-@X\_1254^HL
M;DB4,N4G=P]E(5DH>AQG.)12#U6^%<10FS1$468?,19[#RE'IB*C-OT63S#B
M4%<KX#YS*:\,12^3/^\M-!\Q1_L1ETQ05$`//QTP#"DMJ2M9/^L0X#G="9A+
MJA0%*;,&]CS_49-/GA4,*^LV>3?Q*?(I4T[4)RDKJP:L09-`BR-)0G1*>0T$
M/6!-^R<@#;<;+R\[2"1`)4"C0C8<*BL5*\`DZB4-&WH#)1(C#0XH>2>;`YT2
M["7K!!`8$1@3&.X&O#-@/:I0K`GP,X(?A1]B/>P1K"OW!(\]J!HA22T/3`BQ
M',8U*0[M#YY!QS68,UDN]4J=-O@L?BRZ5)T$/$K!2-8\;01*'G084B_:!K-*
MK138/*D;K`,;&!H5(#+B/9I+3#NI/4Y&5")C!>8[$E`9)B(G;DS803I)1S?L
M1`U"4`:B-G0@W3IB!F,&@SE*%6L5[!@$$D<;\R-Q3'@O4BJI3RT?H"V6)[1)
M&D@N0$40^C+I.+D8"E,^1OD[^$@F2)A!*A?H*AX)ST?=&"=-[#\!$,L$$$80
M!LT^B"<=*KDW:$Y"2D9-CQ%O.VA#&B%A#$P&T`WI10]">"4/&8T?%AGJ$1,Y
MACKV0I%1?#02&183#E4P*T!1P@N74)D]H#&#"(U"SE-E0F\UY#Q*//4%B".T
M(\]$K`0-$2TT+C3R%U`SV"S+'!H.OB[#/.@[CT04+[<4_P6,(W(\.2B?%CDS
M649C&]X<BQW2".D,*!EO0VDRU0]</^,<$B0&0,@U11/5*B(UKA1:0$TS-!<7
M"8DC(#9S3A0X8D"U%'`$Q#PR%71.510`!F5`J1K2#UT_U@\:$\T?"$/`1!!#
M7!N&3J4DO"_Z&3I+=D["+[4#NTK<0RD9]$@P#^4S!R/H0RHZ$Q>>18%)H46U
M%<TZ(R.H,1X09QQA&I`NO3572#U4+#5-,@\LZSP3,B00A"KL*D$4\BWR3-`,
M8D:_*QP;$Q26#9%%0`E'$!5'MU,+!GX28A%^`Y$EYR=]3R,^1@Z8(P\_(!,M
M13DJOT(!,Z-/?@]"+<`4%D$+,B$0+05!#X8)@5)_'G<.2T8F!FU0KA;=-O(S
MJ30Z$`8.B!V-!Q`K3P>0(:!14A-P$X]%GRM8(CX0O2LI#9LX=4UO248[050!
M"ILLTR/Y'&L.G3OY1KHM>1<N38,_?`1.$"\..0TB+_HP@2=2"8$?Z23K%PXS
M\Q"P$%M`AQZ#(ULXC$F-2?DA%!!#!JDPZB3`/7,<53Z0&A0C=!QN*0L^LPF0
M2QQ.ZQAA%UP?OCZ_/I0PV2/`/AE4&E1R"T@/VB-`/&(76S+[(8P,IQ^`,Y%)
MMC8O/;,0_Q!K1^!`HR'#2T-3;$=I0PA%O$G>3>$VC@Z/#IL=`"/P)'DD=S!C
M/_0I30R<2*X7.C.Z%==&L$>K&M,(0#87*Z\&23L\,'HVZSH2(X`J]B$N+',P
ML0FK(?HFHA7;/9\%%S5G/:L1QE#T-YD_M#X7$S`4@16D)9I'%S`9)"TE51M,
M3\\7%1:A(,`>L1.?2=,P*%"H)I4^1`M@-]XJ8@B,+GD'#SQA((H$<C+!$<@A
ME0_=&D,$!$T"4805YB'H,%\'(`?X3<<L33RJ#C@Z.CE"1L([K06$+>8O8A#4
M(84D,Q$S3-0):QQ#+=M(I@G@#J!*="&U4@4^2P\[&?0T]!9P0YHP>"@8)R4N
M$C4'/IX?_3")2\)+[R1_$DP/PQ4_$ZU"U4]:!JDV/@0`/-,FR!5/1MPWBB!E
M!G,Z8T`X2)I(Y3J"(>TV=Q&V)TM"UB=L,&TPN2=O!G`&<0:F)G(&&#>>$G)%
M($C)3UPZC$B>)^,1>1'W$>4XK0<G&SP/E3H`/ZU/XC[)-2)-OB!>"O9*LQ&T
M$84[\TH@4X-)%E73!9H>OCS@!-(+U#V?.N$$4#F1$`<7RS6+/?\=<1S;!HU(
M,SXP-[L]"E$`-Y(*9SR^`RLV;23*(^H\.B)03U@E<A2J$+H,1"G#)VPA_1Q%
M)*LS"B!5`]`RJRY#!><-'2)3([05T!IL+Z@@,SP(5&DS?B%D.N\0/0C?.I,9
M8`-(*-<R'!*K*H4LK!2=(.`LHR='2EH<H@9A!FX\("I[*;5+KU1-1A<.EP@,
M(2PQCR@G$/DC/S%0#-LR!PX`&]M3<$I5"&X&-E)2.*D,[E&'!2I4;BRM.?\H
M+!OC$D0D[R&E-=,+UD-.2,$@-A&K)`)"!P=M+?408P=7(:H/*3NN3`E"E$B_
M&NX673E='8Y3W`:<0X@'%4ER#?(1!5"*0`$6^Q";+G%.[ACW&9<:S!R:&)(#
ME3PY$HY`GQ5"",\ZESQ(!U,4GT(]([,GY#K=/!])JD!0+)D\`"KZ!5M-<$7L
M'M4V0B-84Z<W<`IZ#7]*8!N$-;H)ED#=0\!/.A(+%Q8K^4=7+*L(WD.**<I.
M-2TX#_`^AA#*%ZHDQD&?#TLAY1:0%=-0$!P.-\DMJQ-Q-4@6ZQV@%_9!XS#W
M#A<9QDNP'W!-V03@4&`55P]<**`T_PE3.A\1VE&_%65%)BDI!Q,ED14D335#
M'#US0;@KJ0,+!9`+X1CP$,\+K"JG0<-(Q1PV2X=0TB>:)M8=Y!]23249VR@>
M%F,M)P\V'GLEB3>")0=,\1/D(4D-C4]8+PQ3*49+'`-'<TG@46PDG$&G##)#
M,3?64AL2LA5,0.%,8TPT#:,C.$J2&&\(1RB&'/8V!4DO!TH2-P>D+=\%/@>*
M/A<7\Q'-'+$#E@,20QU.6Q*,,/5$ORDC3:8251=S#AD_`3\O"K!&(5-647\O
M!D77-:@V44Z]0'-130WN*!Y,.`?C!/@@&S\]2H@T%S&,-)`?ZS`R4(9-G2^?
M4GP@)U."+A(@\B_53I$<9"?44/([HA-/2!`YY04=/QX_H3JD)]4I5S#;/`A2
M_#7Z/(0/C$;@-$$XD1\W$0@7/P?!4K9*IREW4G,-"1>L)S`@QCJ!,S\J:@J"
M+'T$I!OP&6`&DBF.2Z9/\2?Z2I@*@03;(VM*NPXS,)`.N30/2L`ZOD'],Y93
M(@:J2+4]IP_P(:5,AT9Z(.1,*DE3".PLO#7('LPJ'R]]#5`<A!0P(OHEW`DI
M)OL<>`;Y"DT]S@4+(%X0Q0PR!>($!RDH!O$C2@I]4/@R.S8E+_U&DD4R(9`,
MQ1[')"M4.@F7.L\:CR2@/-8N,"B8'7<NDBP$#RH/+@U1)S`NPA8W(_(#,#P/
M%XPQ=1=.)&,7C#X>1M$^6B&\$/4)'46D.MHH>E-\4A4X6#!A(]X\S2-B5",B
MPC'#,>A']!'N-NE'N!2T2*]!7S`3#&`PCC+U$?P9C#+5&L!,,CWA--E"9%09
M(QLV=#K*%2,_9Q;F.F0R[0D74K@GQ"_^/$Q"_`?-#_%'Q$V75.\VJ#?/,1M2
M"#KD*$U"@BD(4(\L%@2U!W,&%`R5-`8&'%)B3;%%1QD*!S([-D0%)_-//1"\
M)R4_)PB]#ML=T3WZ1XLIPD]R'MT7B$OL(507]!`_4Q`N\RG?-JP7/C:9,+`8
M=#(^-,,;;`@>&KX4]"HB$P@P=C960X$7L!X!%9</[DK^"1$79!78%YTE$DQ9
M-8Y/(#14)Z4)4$P(-&T<12WA45@ZA#3S/7\CH3'#'2U(5RIR.%)0V#=101LE
MW@H[$\\RRS.R,?]!-TWO$>L6RA8[2ADPIST"-6P_2B0?*WX+]34J+4@3$R/X
M(:`3X3JK3"!,,2AB-!4&6RJA,_,#"RI&*D,?ADHB20,_C3"F4O]'#RCU*`,]
MPD,Z'`XZ.2!00H$92"5U!M,UF$I1!@Y%>#-)5`P[#",&.CY`1D!'0)E,&A0E
M2M0#^`0T!;T+.3T/,YHBRC[M%%4PO$Q7.TL'+T1`+TP'HPQ4+*4F.B@S1-).
M.SV[!KDB>2A(%$@SS"$^,WHD^391(RL.W1%K15LU:PU:([0&31'S+V<143WZ
M!.8%7"I)$R41_36.-`T5A".]+S%3W3>G.U0]PB6V!E<]P"^[.K@IO4T40@X*
MCSPW+U\Y]1GU!VHPDCP;0N]#.5(&4/@Y7BJ_+YT:$2^B-P8;(BN="!\FW2M`
M)?,/O33%$BQ+]3/I0C<YS5)Y3(0;VP\F&^T<0%`M5!,9`33I,-@,B#@03SH5
MF266.J(]31P,!@(*:"*^!5E#74?W-`U1-B%*.3\4Z"[6-T)$[S,83V<S(U.2
M-H(R.3_:!38-3"*#31=$LE`V(^T9E1@O%0H2N27J!30*+CO;*XX/TR@($(,6
M&%%E5#`Z%QU_$/`8K2/.,2$FV%#%+]<IQS8"*@,J(#>S1=LF9C)G,C(MC2,_
M+KP&<S6@#Z@/82V*&*!"K@\[%Z\/L`^]'VI-:TWD1VX3]T1F%F94UR=I%KTW
MTBJI,:HQNA.E15%-P3YO,6XF_1-N,`,&T#&P1<<*M$?#3XI,M@V;-7P>+@1U
M&`(_,`[,&Z],LA!J,S<W:A?D/H8LNAY<.(\$N$T;,(LHOD#G&&(H@4[/$4\2
M^2PA3%XP22SO%]-"O`ZF3O@-5`??(Z-2<TQZ3'L*B$+Z+9(N,0ME-Z9)C`4P
M4HP$VQ&[%%XHU5(13^]!US=.0!XK<#GT!X,*$BMW,^8M3QQ=-#0W_`41#O(R
MGSN$'FL\$T+Z0E0K)P2;);H][$'^4\@'[":`5,PVEABE3M`+Q$44-FPTL!W+
M%`4<]DE0)^U!)%,'$@H=3##M%V9*8RMN4:XQZC&52.$-XA*3-+(?""#1)@=4
MLTXE+7Q0>!U$"BL/\A.84G)):A6/-!@7]R]I)R`_3@1E-,\P3A/P!2$<BT`3
M(,\.0`<C3+(6'3#&+1I%`CS\!*43@D^!('(5_CA@#Q@-S3N.'J<YK!C:0R81
ML@,@0$Y0PE(02]4FJ"D_/I)):DKM!F!`U!U\(F(6$4.R%$X:BB11$]DA;D5N
M$#\A,#VK*]XW@T^H.X(SO4QN+750LQ;N%/@Z54%G-'HW'#'*&:T]824[-SPW
MVB$1*^H)-R6;5")"XTM#.!M4QC'.,]M#;RV6"S`<TPX]#!<_`$,U+*%1VT?)
M..,)B3[G)%TC92_J&"D]Q44!%Y0\=R1E!S$>)D*/(&,EF48&.:P,/Q#X,V5&
M20R/!O`$P3OT'.`2R#)O4>02;3>E)18_51Q2!_P[(B,%,\\%7T/_0C<;Q!U?
M)@P<GPMG&3(*`E*?#CD'=U%6'14/*0M*4DH@;1"A#%8P%C81+@\O;C'O"A$A
M03&7$4L,VE(G)Z8(VB:^5-E$JE')#GPL9T6*+"`PTACH(+$W9A4$5'`SN16)
M4F(/SB/V$9,M=4IB(]\HY1_D"#X?9BES)Y54.B4C*V=4&%+*+0`9P4Q.#M(X
M13C+&3,]FQ@?1<E2L2-H5"4<'`8=!LP9#34Y3_<_^#_"3((+'#89#_T93R:H
M1S`T,308'7<%`1$Z2*P3MS;7'+!",C_Q&&4YE38E1JM`VQRO%SQ!.R_P-KHG
MR"D".=,X]A4>5``]T#N=2+D4Q$N1,M$QK$"6-DHX(R;Y`ZDD/!H:+#<<L#V6
M--\<1C@$*@@5(#L`4C-4Z3-Y'XE,IB6Z0/<]#1R!+_`133?E2GD#I$/=*9`)
M1B#,!*4]#53>2N9,KPL>09PKIDTD/W13C#NS(`P@IBF+(+<*^3,I*:A!N4Z@
M+!4$L2<Z!?1$&$S.$4P$R3#%+6$H]3J9$ZH8_3M:%H(>5$`C$0X<R!W70[)&
M[!0I)0XFPQS].*L]L18X-\49$AS-,VHGE%3Q$5\CXPBX%9(MQRW0#L\X%E1N
M$A8/_1`K-*D3^!D9!NPV3T)J-(`&.!PT'-M2C!TS-$13ODL)4+PA<T:#!F5-
MES3Q0PL'%!Z]1C,[_AGR5*LWK#=Z$:`6!R>^1KLK;4)/3\!#<!+X%:T8LR(Z
M3_$VQ$\/%*$6F3AF)0`)PB3'.9H#038Y'/Q%*AG).>LEW2:L*>`KO%#?0P81
M>B@B%DDE'4.U#<<;XSXM!.47'$Q_3S`'%C#7(30^-T^K&*DB@$\\(>%+NC%"
M.'0%_@@M/:A`]#\)-88=."_1')1`2D(G&0X4]P/$,<X[]!692*@D?P9R1@$J
M&"RZ2YX6J3?Q5&0EX`P12.(,+C/_*=`<%B`9-C$5.06V'E,^>R)U%4T.F!BO
M%/PA]@4X*"DRMR*Y!M,/UBH_!*!';28B1,\_$@K30]Y'U3W%/+U+4@94(UHJ
M736J/1H<%51L10HUO!^Z!J,9W"9'+#@:/"O+&STA\U(^*\DQ^`,9.`8G'`TA
M"SQ,V$)*290TS@\\)>`SQ0?2`U425DQ60;5'+T)F-!D7:D_!3P,6YRVS24`3
MKB6Y'VP'UD<;$\L..!NX$E$V^A/*.+D2+2SD!(1-5U$A&9PS[1)0$K]`Q!S-
M.$--RQ)I2`,A!"$P,'<9\5#F!-]'Y$8P4<@1NA+`0,HN&0V-%#(V:R?7*TH3
M(3_^*[LE*@8)4HX4B$W7"ZLT(T0/"G0-%""R2',5.%)+31-(3$WF1LT]34UX
M/35+%1`Z02<1R163`UE1YD<Q&"I$=1S6)L-2-T@N/7T8U2@X-J$LD12=-=4=
M;T5-5TY73U=05U%74E=35U1755=65U=76%=95UI76U=<5UU77E=?5V!785=B
M5V-79%=E5V979U=H5VE7:E=K5VQ7;5=N5V]7<%=Q5W)7<U=T5W57=E=W5WA7
M>5=Z5WM7?%=]5WY7?U>`5X%7@E>#5X17A5>&5X=7B%>)5XI7BU>,5XU7CE>/
M5Y!7D5>25Y-7E%>55Y97EU>85YE7FE>;5YQ7G5>>5Y]7H%>A5Z)7HU>D5Z57
MIE>G5ZA7J5>J5WM2$`JI*3(8R"V]$"HI=APF'(T^>1DQ/VX'5$&?(%E-20=;
M(5PA=@4C0ETA,2!L/CT?,3VT$+40TR*C%7Y!1#C<(PT>)"_@*",PJSE4$[0#
MW5/#+V@T8C(-!=0.X2A#-=4<,R"=/NA&BDW',3LE($E[4U`BEA!C(Y$XR#$_
M'W9*=TI`'QQ4SR-C#W$QEPOA%!<@$R%X2N]471OL.>TY<0JZ*QTVM@,R-#0]
M\A@U/0(13AY?*E43@PN./JE']1?%3:M7K%>M5ZY7KU>P5[%7LE>S5[17M5>V
M5[=7N%>Y5[I7NU>\5[U7OE>_5\!7P5?"5\-7Q%?%5\97QU?(5\E7RE?+5\Q7
MS5?.5\]7T%?15])7TU?45]57UE?75]A7V5?:5]M7W%?=5]Y7WU?@5^%7XE?C
M5^17Y5?F5^=7Z%?I5^I7ZU?L5^U7[E?O5_!7\5?R5_-7]%?U5_97]U?X5_E7
M^E?[5_Q7_5?^5_]7`%@!6`)8`U@$6`58!E@'6`A833!D([0J\Q@^2T<+L$$V
M(&0/X@?>$?082DO&31E#YT#4.`X8\`J:/-I"ES:[)[@;=A7<'),[:!?;"]P+
M@DK.2/)'9!O?)7L];B(,/0T]@TJ//L<I-$16%'P]@PFY&[$^B5#Z`[9(3$G/
M+G(*'E+8)[]+]"@'!@LZXE/#3%=!("'H2DD\=CK<'8=*2!D(!DY+-#O_&9T1
MW1VG)OM'6!3I'TM#3$.0/N,I\U1F35!+Z"BR/DU#;$:)2D0PR#F'*3%""5@*
M6`M8#%@-6`Y8#U@06!%8$E@36!18%5@66!=8&%@96!I8&U@<6!U8'E@?6"!8
M(5@B6"-8)%@E6"98)U@H6"E8*E@K6"Q8+5@N6"]8,%@Q6#)8,U@T6#58-E@W
M6#A8.5@Z6#M8/%@]6#Y8/UA`6$%80EA#6$1815A&6$=82%A)6$I82UA,6$U8
M3EA/6%!845A26%-85%A56%985UA86%E86EA;6%Q875A>6%]88%AA6&)88UAD
M6&589EB:26T;*T_$3,5/(TD\2$4P0"XK&4LK44L8*S@.$4YG3=\D;P=[*!(8
M$"@/.A1.4DLA%K\T2B4\*;8XU0<#1$4G9$8M&&Y23D%5(U$RVQ2"31H[Z!<E
M-$A*Y$"E)ZH;24I%29T9O4\3*PPZ@BC4'FPG&1U'0ZT,'ATA'7I'\$LU#%\&
M-@Q4+RM3SAP]*^M,M">!"4`A_R:4+>8?02%!'](EO$-R1U\<0BO@)0I01!_3
M,7PG>T<W#.PIZ1<V">X2KRMG6&A8:5AJ6&M8;%AM6&Y8;UAP6'%8<EAS6'18
M=5AV6'=8>%AY6'I8>UA\6'U8?EA_6(!8@5B"6(-8A%B%6(98AUB(6(E8BEB+
M6(Q8C5B.6(]8D%B16))8DUB46)58EEB76)A8F5B:6)M8G%B=6)Y8GUB@6*%8
MHEBC6*18I5BF6*=8J%BI6*I8JUBL6*U8KEBO6+!8L5BR6+-8M%BU6+98MUBX
M6+E8NEB[6+Q8O5B^6+]8P%C!6,)8PUC$6+`K\!)<+]0TD32B+/$2GD/0([(K
M%0J?$HTTL2M&+%HLEE2=+EP2V!G5'C8683U;/EX9[2)^&!<*%!A*2E`-FT+:
M/H<LBS*@#J5'QBJJ1PQ.C0U`1ZY'KT?T4-E0(@W&!TU)MBK<3[='UP]\*%\2
M$2S`34H,V#0P"4X_R%)<420K^P.$!B8_"08H"7TK,P\/5)4580]7$HQ-Y0A7
M%``(C4US/.\\NCDA$L9`0032#B(_.U*O-)`X_S@!.?L]-R!"'\58QEC'6,A8
MR5C*6,M8S%C-6,Y8SUC06-%8TEC36-18U5C66-=8V%C96-I8VUC<6-U8WEC?
M6.!8X5CB6.-8Y%CE6.98YUCH6.E8ZECK6.Q8[5CN6.]8\%CQ6/)8\UCT6/58
M]ECW6/A8^5CZ6/M8_%C]6/Y8_U@`60%9`ED#6019!5D&60=9"%D)60I9"UD,
M60U9#ED/61!9$5D261-9%%D56199%UD861E9&ED;61Q9'5D>61]9(%DA62)9
MPAHX(+%';3YW.J5#Q23%2*M!K4&+&-9$#QB+1?5`:T]R+CLMLS&=3R<<'51E
M&VL;2PJ5"98)\Q?\1N9*U$31!"E/9CD?5!,*JT=-(*\]=B=P)](*#S751.=*
M'"[H'[5(M`M43NU,_PJ^294M*D^V"\@T54ZV1]`N!1$?08M*K@R85)4.``L=
M'R-'V1?52O0G.2\/%3HOK$<%*`HH$!64(>H,?2?K#&,6-#2&!F(+^!<C(95$
M$TXW)%8F`A1<)>\F(UDD6259)EDG62A9*5DJ62M9+%DM62Y9+UDP63%9,EDS
M6319-5DV63=9.%DY63I9.UD\63U9/ED_64!905E"64-91%E%64991UE(64E9
M2EE+64Q935E.64]94%E165)94UE465595EE765A965E:65M97%E=65Y97UE@
M66%98EEC661995EF66=9:%EI66I9:UEL66U9;EEO67!9<5ER67-9=%EU6799
M=UEX67E9>EE[67Q9?5E^67]9@%F!0?0:`CH&3:(Q-A-'($PE=@-K%HDXF`]]
M&UQ$0T7!#2Y=+UTP73%=,ETS731=-5TV73==.%TY73I=.UT\73U=/ET_74!=
M05U"74-=1%U%749=1UU(74E=2EU+74Q=35U.74]=4%U175)=4UU4755=5EU7
M75A=65U:75M=7%U=75Y=7UU@76%=8EUC761=95UF76==:%UI76I=:UUL76U=
M;EUO77!=<5UR77-==%UU779==UUX77E=>EU[77Q=?5V!68)9@UF$6859AEF'
M68A9B5F*68M9C%F-68Y9CUF069%9DEF36919E5F669=9F%F969I9FUF<69U9
MGEF?6:!9H5FB6:-9I%FE6:99IUFH6:E9JEFK6:Q9K5FN6:]9L%FQ6;)9LUFT
M6;59MEFW6;A9N5FZ6;M9O%F]6;Y9OUG`6<%9PEG#6<19Q5G&6<=9R%G)6<I9
MRUG,6<U9SEG/6=!9T5G26=-9U%G56=99UUG86=E9VEG;6=Q9W5G>60``````
M`````````````````````````%6I\J8``/2F]:;@IN&F\*;QIN*FXZ;NIN^F
MYJ;GIN2FY:;HINFFZJ;KI@``````````:*EIJ6JI:ZELJ6VI;JEOJ7"I<:D`
M`'*I<ZETJ76I``!VJ7>I>*EYJ7JI>ZE\J7VI?JF`J8&I@JF#J82I``"%J8:I
MAZF(J0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"AHZ*CHZ/GH:6CIJ.G
MHZBCJ:.JHZNCK*.MHZZCKZ.PH[&CLJ.SH[2CM:.VH[>CN*.YH[JCNZ.\H[VC
MOJ._H\"CP:/"H\.CQ*/%H\:CQZ/(H\FCRJ/+H\RCS:/.H\^CT*/1H]*CTZ/4
MH]6CUJ/7H]BCV:/:H]NCW*/=H]ZCWZ/@H^&CXJ/CH^2CY:/FH^>CZ*/IH^JC
MZZ/LH^VC[J/OH_"C\:/RH_.C]*/UH_:C]Z/XH_FC^J/[H_RC_:.KH0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````.FAZJ%6J?ZC5ZFDHP``````
M````````````````````G/T`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````)W]````````````
M````````````````````````````````````````````````````````````
MGOT`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"?_0``````````````````
M`````*#]````````````````````````````````````````````````````
M`````````````````$#^0?Y"_D/^``!$_@``1?Y&_@```````$?^````````
M````````2/Y)_DK^``!+_DS^`````$W^3OY/_@````"[TJ&V0('?QD&!0H%#
M@?+-R=7]R,_)PL^BV+NRZ]-$@:38\[-%@:C7TL>GV,#*1H'PQ_NQM=+4M*NV
MO\NIV$>!2(%)@:JV2H&]P<_12X&ER:W83('VN+[1W./0UDV!3H'AMT^!KK10
M@=G!48&\V%*!Z,VDM:K.]]93@?;`V;ZOV%2!58%6@<O$5X'#OEB!L=BTP^72
M68&NUMK.I]7UNJ:WUL!:@;G&TL7'QUN!U+E<@<NSTM)=@5Z!O]C%OO+&LM*P
MS^?/7X%@@6&!8H'IRF.!9('`V&6!9H%G@6B!:8%J@?+"TL)K@>G(;(%M@6Z!
M;X%P@7&!<H%S@72!=8&LQW:!=X%X@7F!>H%[@7R!R\%]@>C3^=5^@<+*_K:A
MV-K3][^`@<;4I;O!V.7.KKZ!@8*!J-B#@<?1J="$@86!AH&]V._9]LVZOX>!
MN[VENN#2^K+@NK;$B('MSZF^I,W!P8F!BH&+@=?'\=F,@?39C8&.@8^!D('+
MR.G8D8&2@9.!VM*RRLK([-CJV,;8]KW-QO"SE('KV/&]Z;V5@=3(T[26@9>!
MV,*8@=:RT-?+ROO+S-6VN,G/F8&:@9N!VMGPV*K'G('NV)V!^K3NP=32GH&?
M@>W8H(''TN_8Q\.A@:*!HX'VT:2!V=;RV*6!]=C^O-N\IH&G@:B!SLBI@=VW
MJH'"MZN!\\:L@:V!KH&O@;"!L8&R@?C8P=*S@;2!Z<Z_O/RWI;?=T+6!MH&W
M@;B!N8':UL73[[OAN_'8NH&[@:')L,ZKM+R!\]B]@<O)]MC7PO?8OH&_@;'.
M^=C`@<&!PH&NLL"YPX&CV<2!Z;#%@>;!QH'LR<>!Q<O(@<;+I-G)@<J!RX',
M@<V!Z+7.@<^!J[70@=&!TH'3@=2!U8&[SLVUH=?TU]/3UH'ES->!SKK8@:+9
MW-G@T_W8\+?WU_[8^MBAV>/$V8':@;;3]-C=V=N!^]C<@>7%W8'>@=#`WX'@
M@?#1V[#A@>*!T;RFV>.!I=GD@>6!YH'G@:S9KMGH@:O9N<KI@>J!ZX&IV;;6
M[('M@>Z!WK.HV>^!_<#P@<S*\8&JV?*!I]GS@?2!L-GU@?:!L;;W@?B!^8&I
MN?J!P-+[@?R!P,_]@?Z!PL)`@L2][-7@LLC'Z[^MV4&"K]E"@NK.[KI#@D2"
M18)&@D>"UL=(@DF"2H)+@DR"38).@D^"4(+CL5&"4H)3@MFT[;:TV52"58)6
M@E>"H;]8@EF"6H+>V<['_L"XV5N"7()=@EZ"7X+7R_VW8(*UV6&"M]FCL>'3
MN=EB@L708X*VV62"98*QV6:"LMFIP;/99X)H@O.\WM"IN&F"X[YJ@KW9:X)L
M@FV";H*ZV6^"L[!P@G&"<H+"V7."=()U@G:"=X)X@GF">H)[@GR"?8)^@H""
MQ-FVL8&"O]F"@H."N;6$@O.^A8*&@H>"R,SRNM#2B(+#V8F"BH+HO8N"J[.,
M@HV"CH+%V>N^CX+&V;O9W\20@K[9P=G`V9&"DH*3@I2"E8*6@I>"F(*9@IJ"
MFX*NU9R"M=:=@N/'GH*?@J""H8+(V:*"HX*D@MF\RMFE@J:"IX*\V:B"R]FK
MQJF"JH*K@JR"K8+)V:Z"KX*P@K&"]M>R@J/-LX*T@K6"MH*W@KB"N8*Z@J&]
MNX*\@KV"OH*_@L""S-G!@L*"PX+$@L6"QH+'@LB"R8*\Q;7-RH++@LR"S=G-
M@LZ"Q]FEL_Z_SX+0@M&"TH*UN-."U(+\P-6"UH+7@MB"^+#9@MJ"VX+<@MV"
MWH+?@N""X8+B@N."Y(+E@N:"YX+H@NF"ZH+K@NR"[8+VM.Z"SMGO@L_9HK30
MV?""\8+?M/*"\X+T@O6"]H+!L/>"^(+Y@OJ"^X+\@OV"T=FUR?Z"0(-!@T*#
M0X-$@T6#1H-'@TB#28-*@TN#3(--@TZ#3X-0@U&#\<]2@U.#5(-5@U:#5X/2
MV5B#68-:@\7!6X-<@UV#7H-?@V"#88-B@V.#9(-E@];9KLEF@V>#:(-I@]79
MU-G7V6J#:X-L@VV#V\MN@ZF];X-P@W&#<H-S@Z?&=(-U@W:#=X-X@WF#>H-[
M@WR#?8/3V=C9?H.`@X&#V=F"@X.#A(.%@X:#AX/ER(B#B8.*@XN#C(.-@XZ#
MCX.0@Y&#DH.3@Y2#E8/<P):#EX.8@YF#FH.;@YR#G8.>@Y^#H(.A@Z*#HX.D
M@Z6#IH.G@ZB#J8.J@ZN#K(.M@ZZ#KX.P@[&#LH/YMJ/8RM2S@ZK4UM#DL]?5
MM(/(S^*YM8/+O[:#XL.W@[B#N8/2MKJ#NX/#S>[9\-F\@[V#OH.SM;^#M;;`
M@\&#PH/#@\2#I+[%@\:#Z\C'@\B#J\C)@\J#R["KN?G!XMG+@[S`LKG,@]BY
MR]#XL>3&W[[DM<C7S8/XT>:\WLK.@\^#O;SFV>?8T(/1@]K$TH/3@]2XO<C4
M@]6#X;+9U-:#UX/8@]F#L,/:@]N#X<.BVM_(W(.TT-V#_+ZIQ=Z#WX/@@]JY
MX8.CVN*#J=2DVN.#Y(/E@^:#YX/[V:RVZ(/I@^NW^;'\V>6S]K[J@_:_L=+D
MP.N#[(/M@[.V_MG]V>Z#[X.[OO"#\8/R@^#&\X.\UZ':](.YP?6#\K7HP?:#
M]X/UO/B#U;3Y@_J#^X/\@_V#_H-`A$&$0H3=P4.$_<1$A$6$N+RRMT:$1X3O
MMTB$281*A$N$3(1-A.S93H2^QD^$K;_+NU"$483*M5*$R=O7T%.$N<V\L/:S
M][O*VZ^Z5(3DU+:U\[76V-#(5816A-:WT,?7V%>$K[]8A%F$N]O8V%J$6X3,
MT*Z[7(1=A%Z$ONO0P?7!\M35N+2T7X3ULV"$882^R6*$8X1DA-#%981FA&>$
MV<7[P&B$\+%IA-G8SKEJA+VU:X1LA-K8;81NA,;6HLNOR++)S+3,OV^$]+EP
MA-O8W-CGML&\ZLQQA'*$<X1TA'6$=H3WSW>$W=BPQWB$>830N:.]>H1[A-[,
M?(3*QGV$?H2`A(&$@H3@V(.$WMB$A(6$W]B&A(>$B(3^L(F$Y[Z*A*/*]+R+
MA(R$C82.A+&XCX20A.ZXD822A).$E(25A):$EX28A)F$FH3BV)N$R[V<A.38
MX]B=A)Z$GX2@A*&$_,6BA*.$I(2EA*:$IX2HA.78J82JA.;8JX2LA*V$KH2O
MA+"$L82FP;*$L,CLL*:YT[SQSKW;T\&SA+2$M82VA*^V^M:LQ=F]OMN_V[>$
MN(2YA/C`HK[-P+J$NX2\A+V$OH2_A,"$P83"A,.$P-O&RL2$Q83&A*JRQX3(
MA,F$PM/*A./#RX2KT<R$S83.A,^$PMO0A-7`T832A-.$P]O4A+&_U836A->$
MV(39A-J$O,3;A-R$W83>A-K'WX3@A.&$XH3CA.2$Y83FA.>$Z(3IA,3;ZH3K
MA.R$[83NA.^$\(3QA.C9U\GRA/.$](2TN?#.R-3UA/:$]X3XA/RPTK3YA-G0
M^H3[A/R$_83IV?Z$R][KV4"%085"A4.%L-BON[&Q1(77L\[8185&A='41X5(
MA;.][[])A;O/2H5+A=#83(5-A4Z%R[=/A5"%4871V%*%4X54A56%5H57A5B%
M685:A5N%I<;XQ[W27(5=A=+8Y,1>A:[*7X6GQV"%IMAAA?W)Y\[<N^NP8H5C
MA62%JKNMT&6%L+'DU[_79H6EM?3"S\1GA6B%J;)IA;>R:H7EL;+?O-6HOZS"
MU=BQPFN%U-C4SFR%X-IMA<#.;H5OA;38KL.ATZ/.<(6TO+3(T<)QA>V^MM!R
MA>':<X5TA76%=H7DQW>%>(6GLWF%\K;\S/K`>H5[A??`?(6YT>'1Q]A]A7Z%
M@(6!A8*%@X6$A=ZRA86&A>7`AX7QNHB%B87(V(J%K=2+A8R%X<_)V(V%RMC#
MSXZ%^+/'OH^%D(61A9*%R]B3A92%E866A9>%F(69A<S;FH6;A9R%G86ER)Z%
MGX6@A=C/H87^R,ZRHH6CA:2%I86FA=;3YK*PO-'3J\NTMZ>%J(6IA:*WJH6K
MA>7*K(6AR-S*Y+'PT*V%T<6NA:^%L(7%V_ZUL86RA=J_Q;GDONW!LX6VW[7?
MN];0O=G5R+"CMLF_J,RSW[?*TM.TA<_8MM+%NK[+OLRUA;??\+6TW[:%MX6X
MA?73N874L_>XNH6ZW[N%S[JJO/6UO(6LS?O#\[KTP,+-\L^XW\7/O87`PKG?
M\,*^A;^%P(7]OL&%W\',S??2S;?!W\*%Q-_#A<2%\;?)L-:VU+?%A:RZ_<S4
MO['+],;&A:C6Q=_'A>+.L[/(A<F%_,ZUM,J%Q\[PNLN%X<[,A;W1S87.A<#?
MSX70A?2TT87*L]*%YKB[W].%U(75A=:%Q<37A;S?O=^^W[O%O]_"W['4P]_8
MA;K'V,[9A=J%VX7<A=V%V,3>A<K?WX7/W^"%W-;AA>*%XX7DA>6%YH7GA>B%
MR=_:W[;.Z87'NL[?R-_>Q>J%ZX7KR?2Z_,/LA>V%U[[NA<;?[X7-W_"%V,7Q
MA?*%\X7TA:;5S;KUA<R^O=/`N/:%Y-;WA<??OKFGO_B%^87\P<O?S-_ZA=#?
M^X7\A?V%_H5`AMO?Y=]!AM??UM_)U^/?Y-_KY:?2TM]"AJF_0X;;U$2&R+_4
MWT6&1H9'ALS/2(9)AMW?2H;*T4N&WM^GL+?&T]],AN6Z38;?MMO-_KG5U$Z&
M3X;?W^S/I;#GW]'?QM'5W]C?V=_<WU"&J;M1AN#?X=]2AN+?YM_HW[334X94
MAE6&5H97AN>XML7JW]K)J,'$Q%B&68;>O_C/6H9;AER&W-7NWUV&7H9?AF"&
M889BAKBR8X;?NNS?9(;!VV6&Y-%FAF>&:(9IAO3+O;1JAJ:P:X9LAFV&;H9O
MAO'?QLSRWW"&<8;MWW*&<X9TAG6&=H9WANG?>(9YAGJ&>X;KWWR&[]_PW[V[
M?89^AO/?@(:!AO3?@H:CNX.&V\JHSJ?@JK.$AJ;@A8:&AH>&H>"(AHF&BH:+
MAO[?C(;9S?S?C8;ZWXZ&T+_$UX^&S,F0AI&&^-^AL)*&DX:4AI6&EH;]WY>&
MF(:9AIJ&^]^BX)N&G(:=AIZ&GX:HX*"&H8:BAJ.&R+>DAJ6&H<:VR;+`]=^F
MAJ>&OL6HAL38^=_VQ*F&JH:KAJR&K8:NAJ/@I."EX*70KX:PAK3@Y,RQAK'@
MLH:FOZ_@N<ZKX,;)LX:TAJ[`KN#MNK"ZJ>"UAK:&MX;VW[B&L^"YAKJ&N."[
MAKR&O8:MM+G@OH:_AK+/R+K`AK#@P8;"AL.&Q(;%AL:&QX;ZT,B&R8;*ALN&
MS(;-ALZ&SX;0AJS@T8;[U-*&]]_3AN?%U(:MX-6&]]/6AK;@M^#7AMB&V8;:
MAMN&Q.#AT-R&W8;>AKS@WX;@ALG@RN#AAN*&XX:^X*K@I,G!X.2&LN#EAN:&
MYX;HANF&R,K#X.J&M>#KALO.[(;#R\W@QN#"X.V&R^#NAKK@O^#`X.^&\(;%
MX/&&\H;'X,C@\X;,X/2&N^#UAO:&]X;XAOF&U,O5X/J&UN#2X/N&_(;]AOZ&
M0(=!A]#@SKQ"AT.'T>!$A\*XQ=A%AT:'1X=(ATF'2H=+ATR'ZM!-ATZ'[\)/
MAU"'S^"]X%&'4H=3A]3@T^!4AU6'U^!6AU>'6(=9A]S@V.!:AUN'7(?VUK"S
M78?LUUZ'N\M?AV"'VN!AA_O.8H=CAV2'V;IEAV:'9X=HAVF':H=KAVR';8=N
MAV^'<(?AX-W@K=)QAW*'<X=TAW6'XN!VAW>'V^#9X-_@>(=YA^#@>H=[AWR'
M?8=^A][@@(?DX(&'@H>#A_?&K-CKU.;@R<J$AX6'AH>'A^7@B(>)AXJ'BX?!
MN(R'C8>.AX^'Y^#HX)"'D8>2AY.'E(>5AY:'EX?IX./@F(>9AYJ'FX><AYV'
MGH>_NN?,GX>@AZ&'ZN"BAZ.'I(>EAZ:'IX>HAZF'JH>KAZR'K8>NAZ^'L(?Y
MS[&'LH>SA[2'M8>VA[>'N(>YA[J'NX?KX+R'O8>^A[^'P(?!A\*'PLC#A\2'
MQ8?&A\"]QX?(A\F'RH?+A\R'S8?.A\^'T(?1A]*'TX?2Q-2'U8?6A]>'V(?9
MA]J'VX?<A^S@W8?>A^W@WX?@A_3'Q,OAA^[@V+NVV/+2[^#%S>*'VK;CA^2'
MY8?FA^>'Z(?QX.F'L-3JA^N'I\#1M.R'[8>GSO#@[H?OA_"'\N#,N?&'\H?Z
MN;S-\^#SA_2']8?4QO3@]H>RU/>'ILCVX/7@^(?YA_J'^X?\A_V'_H=`B$&(
M0HA#B$2(18A&B$>(2(A)B/?@2HA+B,'-3(A-B$Z(I<I/B%"(48A2B-K4U]O9
MVU.(V-OGN=S;W=O8M52(58C:VU:(5XA8B%F(6HC;VZ&SW]M;B%R(^+M=B+?6
M7HC@VU^(8(AAB&*(^;YCB&2(N[=EB-#;KLRRO[6[^-?3OV:(9XAHB&F(:HCI
MOVN(;(CAO+/,WMO3L.O.V+>YU\+&;8ANB*3`;XBYS'"(Y]OAV[K&X]MQB.C;
M<HCWQ7.(=(AUB.K;=HAWB.G;P+]XB'F(>HCFV^7;>XA\B'V(?HB`B+FTK,"B
MPN+;Y-N!B(*(@XB$B,W0[=N%B(:(AXB(B(F(W<#RVXJ(BXB,B(V(CHB/B)"(
MXK:1B)*(DXB4B//;TMNXN:O4[-N5B-&_\-N6B-';EXCFM9B(Z]OEOYF(FHB;
MB.[;G(CQVYV(GHB?B/G;H(BAB**(HXBDB*6(IHBGB*B(H;FCL*F(JHBKB*R(
MK8BNB*^(\<*PB+&(Q[/OV[*(LXCXV[2(TL;TV[6(MHCUV_?;]MNWB+B(_MNY
MB/+3NK*ZB+N(O(C]V[V(OHB_B,"(P8C"B,.(Q(BDW,6(^]O&B,>(R(C)B/K;
MRHC+B,R(_-O@Q?F[S8C.B*/<SXC0B*7<T8C#S-*(TXC4B-&VP-W5B-:(UXBA
MW-B(HMS9B-J(VXBUQ]R(W8C>B.FVWXC@B.&(I]SBB..(Y(CEB*;<YHBIW*2Q
MYXCHB,RUZ8CJB.N([(CMB+"_[HCOB/"(\8CRB-_1\XCTB/6(]HC"MO>(^(CY
MB/J(^XC\B/V(_HA`B4&)0HE#B42)18FHW$:)1XE(B4F)2HE+B4R)^LOSZTV)
M3HE/B=S+4(E1B?[+4HE3B52)P<Q5B5:)5XE8B5F)^\A:B5N)7(E=B5Z)7XFJ
MW&")88EBB6.)9(GNS*O<98EFB6>):(EIB6J):XELB6V);HEOB7")<8ERB7.)
M=(EUB=/;=HFOW*S<=XFSOGB)^\IYB7J)>XFMW'R)?8E^B8")@8F"B8.)A(G*
MR;G$A8F&B8>)B(F)B;W'KMR*B8N)C(GVU.;0C8F.B8^)D(F1B9*)DXF4B:O$
MU;:5B9:)EXF8B9F)FHF;B9R)G8F>B9^)H(FAB:*)HXFDB:6)IHG4VZ>)J(FI
MB:J)VK&KB:R)K8G5VZZ)KXFPB;&)LHFSB;2)M8FVB;>)N(G6V[F)NHF[B;ZZ
MO(F]B;Z)OXG`B<&)PHG#B<2)Q8G&B<>)R(G)B<#(RHG+B<R)S8G.B<^)O\K)
MR-")L]?1B?G)THG3B<>_U(G5B?BZUHG7B;S2V(G9B=J)VXG<B=V)WHG?B;KB
MX(FFM.&)XHFXL>.)Y(GEB>:)YXFTN.B)Q,_IB>J)ZXGLB>?9IL_BS>V)[HGM
MV>"V[XFYTO")\8F[N?*)\XGTB?6)N>*WXO:)\[3WB>S,J\SRM_B)LMCKT;NZ
M^8FGROJ)^XFWS?R)_8G$TN2_T+SAMOZ)Q=Y`BD&*0HI#BL;>O-M$BMG118I&
MBN;&SL3NMT>*W+=(BDF*_+_@UTJ*]<9+BDR*O+'(WK&]U\S*WDV*R=Y.BD^*
M4(I1BE**[+53BMW)5(I5BL*P5HI7BEB*68I:BEN*7(I=BEZ*7XI@BF&*8HJN
MQ:O%8XK,Q&2*Z;S]RV6*9HIGBL.Z:(IIBFJ*^>7GR/KE_<UKBK'7OKCHPFR*
MT<AMBFZ*^^5OBG"*<8IRBLJVR[QSBG2*_=&AYG6*[L-VBG>*>(IYBJ3F>HI[
MBGR*?8K^Y:7FU\U^BH"*P;?\Y?WEH^:!BH**W<2HYH.*A(JGYH6*AHJ'BHB*
MB8J*BL/#BXK>QHR*C8JJYHZ*CXJ0BI&*DHJ3BI2*M\25BI:*EXJBYKS*F(J9
MBIJ*FXKCO<.YIN;5T*_.G(J=BJGFL.:>BJ;2GXJJO:WFH(JABJ**HXJDBJ_F
MI8K1P*:*IXK,TJB*J8JJBJ>\JXJLBJV*KHJOBK"*L8JRBK.*M(JUBK:*L>:W
MBO;2N(JYBKJ*R]>[BO[-O(K>S:;"J^:LYK^]KN:SYKV*OHJRYK^*P(K!BL**
MMN;#BKCFQ(K%BL:*QXKOQ,B*R8K*BLC$RXK,BNJ^[\G-BLZ*M^;/BO"VT(K1
MBM**Y,/3BM2*U8K6BM>*V(K9BNG3M.;:BK7FVXJBR-R*W8K>BM^*X(J]YN&*
MXHKCBKGFY(KEBN:*YXKHBL7&Z8KJBO'-N^;KBNR*[8KNBN^*\(KQBO**\XKT
MBKSF]8KVBO>*^(KIN_F*^HK[BOR*_8K^BD"+ON9!BT*+0XM$B[KF18M&B[?`
M1XM(BTF+2HM+BTR+38M.BT^+I-._YO3)P^90BU&+Q.92BU.+5(M5B_;05HM7
MBUB+68M:BUN+7(M=BUZ+7XM@BV&+8HMCBV2+98MFBV>+O<-HBVF+:HMKBVR+
M;8MNB\3#PN9OBW"+<8MRBW.+=(MUBW:+=XMXBWF+>HM[BWR+P>9]BWZ+@(N!
MBX*+@XN$B\?FL<^%B_3KAHN'B\KFB(N)BXJ+BXN,B\7FC8N.B]Z\J<F/BY"+
MD8N2BY.+E(NUO)6+EHO3SY>+F(N9BYJ+FXO(YIR+R>:=B\[FGHO0YI^+H(NA
MB]'FHHNCBZ2+R^;5M:6+S.:FBZ>+S^:HBZF+V\2JB\;FJXNLBZV+KHNOB\WF
ML(NQB[*+LXNTB[6+MHNWB[B+N8NZB[N+O(N]B[Z+OXO`B\&+PHO#B\2+Q8O&
MB]+FQXO(B\F+RHO+B\R+S8O.B\^+T(O1B]*+U.;3YM.+U(O5B]:+UXO8B]F+
MVHO;B]R+W8O>B]^+X(OAB^*+XXODB^6+YHOGB^B+Z8OJB^N+[(O5YNV+^-GN
MB^^+UN;PB_&+\HOSB_2+]8OVB_>+U^;XB_F+^HO[B_R+_8O^BT",08Q"C$.,
M1(Q%C$:,1XS3U]WF2(S>YM>_T-1)C-;7YK3OR]KFP]C.UZ+02HS/PTN,3(S?
MYKZ\PKG;YJ?138Q.C**ZS\)/C*O84(Q1C%*,Z\KNY5.,W.94C/6W58Q6C%>,
M6(SFR%F,6HSUQ%N,7(RRY?[$78S\R[/EK-5>C.[3V,JRL%^,SLOJS6",88SJ
MNF*,8XQDC+7E98RTY6:,VM?9N>;6J+;PS<O2IK&URF>,Z+/SR<V_^]#2RK;E
MPKMHC&F,:HS<SZRY:XQLC&V,;HS7U&^,<(RFNN?1_,_2O'&,M^7=R'*,<XQT
MC.V_]K'>RW6,=HS%O'>,Q+SZTMS#W+]XC'F,>HQ[C+NX?(Q]C'Z,PL.`C*ZZ
MHM2!C(*,@XR$C(6,AHR'C(B,B8S>QZ_$[+**C-&YBXR,C+OER,&-C(Z,K]6/
MC)",D8R2C).,O.64C+[EE8R6C)>,F(R9C)J,FXSGM-2VPLNPT;RUG(R=C-G*
MGHSBMY^,H(SDR:&,J[VBC*.,OL[PUZ2,I8RFC*>,H="HC-G)J8RJC/NVV.;B
MO*N,OK.LC-#)K8S9YJ*SKHROC+",L8S,WK*,R-/-WK.,HM*TC+6,MHRWC,[>
MN(RYC+J,NXS-OKR,O8S/WKZ,OXS`C*S*_-+?L^KEX<2AOK+.\L36OJC&X[+!
MC,*,T[[#C,2,_,?KS.R]W<[%C,:,NLK!QNSEO-#'C,B,R8RYU<J,RXS,C.WE
MS8S.C,^,T(STRM&,P,W%PM*,[^73C,3"\.74C-6,UHS7C-B,V8S:C/CES<W;
MC+W)W(S=C-Z,WXS@C.&,XHS9TJCAXXSDC.6,YHSLT^>,ZLOQQNB,Z8SJC.N,
M[(RLX>V,[HSOC*?AJ>'PC/&,JN&OX?*,\XSMLO2,J^':N*WAKN&PX;JUL>'U
MC/:,]XSXC/F,L^&XX?J,^XS\C/V,_HS2T4"-MN&UX>O!08U"C4.-M^%$C<#4
M18VRX4:-NN&VL$>-2(U)C4J-M.%+C?F_3(VYX4V-3HV[X4^-4(U1C5*-4XU4
MC;[A58U6C5>-6(U9C5J-O.%;C5R-78U>C5^-8(W%UF&-8HUCC62-98UFC6>-
MO\]HC6F-O>&_X<W":HWKMFN-^--LC6V-S<=NC6^-Y;=PC7&-<HUSC72-=8UV
MC7>->(UYC?Z^>HU[C7R-?8U^C8"-P.'!X8&-@HW'X>>S@XV$C86-AHV'C8B-
MZ<:)C8J-BXV,C8V-WK2.C<+1CXV0C9&-DHW(X9.-E(W&X96-EHV7C9B-F8W%
MX9J-P^'"X9N-P+&<C9V-GHVXU<3AGXV@C:&-HHVCC<OAI(VEC::-IXVHC:F-
MJHVKC<SARN&LC:V-KHVOC;"-L8VRC;.-^N^TC;6-T^'2X;;'MHVWC;B-N8VZ
MC;N-O(V]C;Z-OXW`C<GAP8W"C<[APXW0X<2-Q8W&C<>-R(W)C<J-RXW,C<V-
MSHW4X<^-T>'-X="-T8W/X=*-TXW4C=6-U>'6C=>-V(W9C=J-VXW<C=V-WHW?
MC>"-X8WBC=;AXXWDC>6-YHWGC>B-Z8WJC>N-[(WMC>Z-[XWPC?&-\HWSC?2-
M]8WVC?>-^(W7X?F-^HW[C=CA_(W]C?Z-0(Y!CD*.0XY$CD6.1HY'CDB.28Y*
MCDN.3(Y-CDZ.3XY0CE&.4HY3CE2.58[:X5:.5XY8CEF.6HY;CER.78Y>CE^.
M8(YACF*.V^%CCF2.98YFCF>.:(YICJ'.:HYKCFR.;8YNCF^.<(YQCG*.<XYT
MCG6.=H[=YW>.J+3=UGB.>8ZRT;*S>HY[CJ2Y\]?)Q]Z^KKE\CM?.?8Y^CNZR
MS]N`CKJ\T=+(R\VP@8Z"CN_/@XZ$CH6.AHZ'CN/9[;V(CHF.TK'0RKRRBHZG
MRZNWBXZFRHR.C8Z.CJ//CXZ0COC@RM7[X)&.DH[ZX,'%^\R3CK'!^>#CUJ^R
MQ-;;M92.E8Z6CI>.F(Z9CIJ.FX[XM*'6G(Z=CIZ.GXZ@CJ_/[["ACJ*._."C
MCJ2.I8ZFCJ>.H>&CLZB.J8[]X/[@L<.JCJN.K(ZMCMW#KHZBX?FWKXZPCK&.
MLHZSCK2.S[NUCK:.MXZXCKF.NHZ[CJ/AN\2\CKV.OHZ_CL".I.'!CL*.I>'#
MCL2.IN&QM,6.QH['CLB.R8[*CLN.S([-CLZ.SX[0CM&.TH[3CLFXO<;JQ-2.
MHK+5CM+0UH[;Y\.[U]/$T]>.X[G/XMB.V8[:CJ_7VX[LQ].QW([=CK*TT>+>
MCM^.X([RT*["T.+ACN*_IM/7M=+BZK7BCNW#_;CCCJZXY([3Q<^WU.+ECN:.
MYX[HCM/BR+;YU^F.ZH[KCNR.[8ZES>Z.[X[PCO&.\H[8XO..UN+\RK6_N=/5
MXO2.]8[VCO>.U^+XCOF.^H[[COR._8[^CD"/08]"CZ[!R,!#CT2/18]&CT>/
M2(_;XMKBJL!)CTJ/SL%+CTR/38].C]SB3X]0CU&/4H]3CU2/58]6CU>/6(]9
MCUJ/W>);C][B7(]=CUZ/7X]@CV&/8H]CCV2/R-MEC]/1HLUFCV>/J+UHCVF/
M:H_#WJ78JK_-V^S2^L:JQ6N/;(]MC\3>;H_7L:[?;X]PCW&/O<IRC['?<X^M
MN72/_=)UCZ6XZ[IVCW>/VK-XCWF/>H_<M<75>X]\CWV/?H_6P]+/H;N`C_/E
M\N6!CX*/].6#C^3-A(_UR(6/AH^'CXB/B8^*CXN/K[6_QXR/]N6-CXZ/CX^P
M[)"/D8^2CY./E(^5CY:/EX^8CYF/FH^;CYR/G8^>C^;EGX_IN;&UH(^\PNCE
MY^7IY:&/HH^CCZ2/S=*ECZ:/IX_JX<[0J(^NS:F/Y=&JCZN/RK+KL:R/\K'M
MQ:V/KH_#U;#3KX_<X;"/L8^RC]WALX_;TK2/N;/+L;6/MH^WC_G-]]7>X;B/
MMK[]M+F/W^'<NN#ALKO)PN'ANH^[C[R/[-"]C[W-OH^_C^+AP(_#M<?%X^'!
MC\*/Y.'#C\2/Q8_&C_G3QX_(C\F/RH_+C\R/Y>'-CZW1SH_/C^;AHL[0C]&/
MTH_3C]2/U8_GX=:/PK77C]B/V8_:C^CAU;O;C]R/W8_>C]^/Q-#@XMBQY-+@
MC^&/X>+BC^./R;S,R.2/X^+^[/WLK]_EC^:/YX_BXK[6_,VFP^B/Z8_JC\/C
MZX_LC]+6Y^+MC^Z/Z.+OC_"/Q]/QC_*/[.+LO_./[>+EXO2/]8_`L_:/]X_X
MC^[$^8_ZC^[B^X_\C\/0_8_VNNGBWK>SNZS,R\ODXN;BZN+KXOZ/0)!!D/?B
M0I!#D/3B]=3SXD2019"MQ4:0^M7"Q<"R1Y!(D._B29#RXJ_!O,M*D$N0H;7Y
MXDR039!.D+&\\>+4T+G4]>+6N?;B3Y!0D%&0T\=2D%.05)!5D%:0\.)7D%B0
M69!:D%N0W->A[5R079#XXEZ0I>W^XM'*7Y!@D&&08I!CD&2099"UP6:0T+MG
MD&B0UK]ID..Z:I!KD*'+;)!MD&Z0INVC[6^0<)"B[7&0<I!SD'20UKNG[?30
M=9!VD*3MWKKWMJ'CLK;QS*>Y=Y"BSZ''>)!YD-*_>I![D/&V?)#ZXOOB_>+\
MXM7$HN-]D,'3?I"`D(&0I^/$QX*0@Y"$D(60I,^&D(>0J>.WNHB0B9"*D(N0
MJ..,D-J[C9"CXXZ0CY"0D*3CJN.1D*;CDI#RSL;3DY"4D+R[E9"6D,/4EY#Z
MQ)B0F9"H[?S0I>.:D/7#FY"MXZ^QG)"RXYV0GI"?D,*\H)"AD*SCO[6BD*.0
MI)"ED*:0IY"HD*F0Z<>PXZJ0JY"LD*J^[\VMD*Z0KY"PD+&0\[NRD+.0M)#H
MS+60MI"OX[>0L>.XD*?/KN.YD*G.W;NZD+N0O)"]D+Z0Z[7EOM*RS;._D+FQ
MJ^/1LJRUW[GHML"0P9#KS[?CPI#,N\.0Q)#'R,K0Q9#&D,>0R)#)D+CC[K/*
MD,N0S)#-D*GMSI#ZT^33SY#0D-&0JNVYX^+2TI#3D-20U9#6D+7CUY#8D-F0
MVI#>T]N0W)#=D-Z0T+BSX]^0X)"VX]^WX9"TXZ+`XI#CD.20NN/ED.:0YY#H
MD.F0ZI#KD.R0[9#ND.^0\)#QD/*0\Y#TD/60]I#WD+C4^)#YD/J0^Y#\D/V0
M_I!`D<BT09&[XT*1Q;M#D??)1)%%D>7)1I%'D4B1O<1)D4J12Y%,D4V13I%/
MD:OM4)%1D5*14Y']PE2159%6D5>1V[NNOUB169%:D5N17)%=D5Z1O\Y?D6"1
M89%BD;SC8Y&VOV2199%FD6>1:)%ID6J1:Y%LD6V1;I%OD7"1<9%RD7.1=)%U
MD7:1[[%WD7B1]]1YD7J1>Y%\D7V1ON-^D8"1@9&"D8.1A)&%D8:1K>V'D8B1
MB9&*D8N1C)&-D8Z1CY&_XZFZK.V0D9&1O>.2D9.1E)&5D9:1EY&8D9F1FI&;
MD<#CG)&=D9Z1GY&@D:&1MKJBD:.1I)&NMJ61II&GD:B1J9&XT*J1P["N[:N1
MK)&MD:Z1KY&O[<'`L)'!X[&1LI&SD;21M9&VD;>1N)&YD;J1NY&\D;V1OI&_
MD<"1P9&SQ<*1PY'$D<61QI''D<B1R9'*D<N1S)'-D<Z1SY'"X]"1T9'2D=.1
MU)'5D=:1UY'8D;+<V9':D=N1W)'=D=Z1L.W?D>JXX)'LSJ?JY]#YRM;(M\_)
ML]+.Y+WAD>*1WN/RNZCJO=7CD=W&J>KDD>61YI&JZN>1K.JKZNB1KNJMZNF1
MZI'KD>R1V+WMD:_J[I&^PN^1\)'QD?*1P;3WM/.1])&GN_61]I'WD?B1^9'F
M[.7LO[?YR^*Q^I'G[/N1_)']D<C)Z.SI[/Z1ULK0WL6R^M1`DD&2R\;'L/*T
MT\A"DD.21)+0S4621I*XOT>22)))DDJ22Y),DDV2V[].DD^2I,>TUE"2J<#1
MWJC)[]&DQ>>PMK/%R%&24I+BL%.25)+VMU625I+ZQ5>26)+SMEF2TM70L[R\
M6I);DER2K;-=DEZ27Y)@DO&^T;!ADF*28Y)DDF629I+6TN/*I==GDK;-MK:Y
MO]O5:)*GN-?%:9)JDFN2TM[9O]7"P,=LDJ2[J+%MDFZ2ZL5ODG"2^\6GS'&2
M<I)SDG22I[%UDG:2=Y+6M7B2>9)ZDJC$>Y+3WKK1Z;-\DO+#?9)^DO>W@)+T
MUJ.U\+*TQ.G$K<#4WH&2Z+#$Q>#!@I+5N8.2W+[8S<ZPA)+/S=;>T+Z^U]7>
MT-7=L(62AI+BQ(>2B)*CPO"\B9*UT[G`H<6FLO'4BI*+DJC`P\K7WOS5C)*P
MN8V2K<BIRXZ2V=Z]OX^2D)*1DI*2M,:GU[#*P\23DM:STKF4DI62EI*7DKC6
M_.JTL)B2F9*:DIN2YK^<DIV2],R>DI^2H)*ADMK-HI*CDJ22O];.PJ62SLZB
MS*[0T\2RM=C>]=6WO-.[II*GDJ2PJ)*RQ>RTJ9*JDJN2\=6LDJV2_>JNDJ^2
ML)*QDK*2LY+:WJ;-M)*UDNS-MI*WDKB2N9+FSMS>NI*QS:;`NY*\DKW7O9+;
MWL:PM+K3R?/$Z+Z^DK^2P)+!DK:RPI+#DL22Q9+&DL>2R)+)DLS`\,O*DO&\
MN[NWM<N2S)+-DO7%SI+FWL^2T)+1DN/>W;[2DM.2W][4DM62UI+7DK>TW;W8
MDMF2X-[MQ-J2VY+<DMV2QL_>DN"UWY+@DN&2XI+>MMK*]+7EWN.2QM7DDN'>
MS<S^QN62Q<7FDN>2Z)*TTNF2\K[JDNN2[)+MDNZ2[Y+PDM/"\9*]S+BS\I+3
MO?.2V+_&S=K1Z[3TDN3>W=[GWO62_NKVDO>2L,+BWOB2^9+`UJ>U^I+TLON2
MZ-[\DO+>_9+^DD"309-"D^W>0Y/QWD2319/@R$:31Y-(D^'7[][HP^',29/E
MLDJ32Y-,D[[239-.DT^34)-1DU*34Y/NWE23Z][5SE63I[16DU>36)-9DUJ3
MJ[^^OEN37)/2O5V37I-?DV"3Z=YADZ[48I/>WF.3ZMYDDV639I-GD[_`:)/L
MWO.RZ;BGPFF3:I/!O6N3;)-MDVZ3;Y/UWOC><)-QDZNRI+1RDW.3ZK2FR723
M=9-VDW>3>)-YD_;>T<MZD^.X>Y/WWOK>?)-]DWZ3@)/YWH&3@I.#D\+,A)/A
ML.ZTA9.&DX>3B).)DXJ3NN6+DXR3C9..DX^3K]"0DY&3Z[*2DZ'KDY/TWI23
ME9/CR?/>VK"ATO>QEI.OS)>3F).9DYJ3FY.<DYV3\-Z>DZ3+GY.@DZ&3JM6B
MDZ.3I).EDZ:3^]ZGDZB3J9.JDZN3K).MDZZ3W;2ODZ;$L).QD[*3_=ZSD[23
MM9.VD[>3N).YD[J3NY.\D_[#H<2AW[V3OI._D\"3P9/"D\.3S,'$D_S>[[[%
MD[+&QI/'D\B3R9/*D\N3S)/-D\Z3Q;/VR,^3T).ZR_[>T9/2DZ3?TY/4D]63
MUI.RU]>3V)/9D]J3VY.WL]R3W9/>D]^3P\'@D^&3R\>ELNFTXI.KU^.3Y)/E
MD^:3[,3GDZ+?H]_HDZ7?Z9.SNNJ3ZY/LDZ;?[9/>P.Z3[Y/#R?"3\9/RD_.3
M])/UD_:3V;+FQ_>3I]_XD]S'^9/ZD_N3_).HWZ+K_9/^DT"4091"E-/+0Y1$
ME$64JM]&E*G?1Y3!LDB4291*E$N43)1-E$Z43Y10E%&44I13E%245916E%>4
M6)19E%J46Y1<E%V47I1?E&"4RL5AE&*48Y1DE&649I1GE&B4J]]IE&J4:Y1L
ME&V4;I1OE'"4W-1QE'*4<Y1TE'64P<AVE'>4>)1YE'J4>Y1\E'V4?I2`E(&4
M@I2LWX.4A)2%E(:4AY3POHB4B92MWZ?6BI2+E(R4C92WZK;KU<J.E/S8Q+B/
ME*6YD)21E,6W_M62E).4E)25E):4RKF7E)B4I]#-])F4FI30M9N4G)3TPYV4
MR+Z>E)^4H)2WZ[VPH92BE,R]HY2RP:24UK&HLZ64II2GE-*XHLFHE*F4V+:J
ME*N4K)2ME+CKM+ZNE*^4L)3]RK&4P\>RE/O5LY2TE/.WM92VE+>4N)2YE+J4
MNY2\E+V4OI2_E,"4P93"E,.4Q,[$E,64QI2KU?.QQY3(E,F4L^S?L,J4M>S+
ME,R4S92WMLZ4S\'/E/KUL=#0E-&4Y=72E-/.TY34E.^]XK/5E*NXUI2VU=>4
MO>W8E,^VV92YR\+0VI3;E-R4W93>E-^4X)3AE+VWXI3CE+;LJ<KDE.64YI34
MQ>>4N>RX[,/"M^SHE.F4ZI3KE/W0NNSLE+OLY=?ME.Z4O.SOE/"4\92][.S&
M\I3SE/24]93VE/>4^)3YE-[.^I3(O/N4_)35R*FUR;Z\UN?4_93^E*[1\="X
MZKGJNNJUND"5095"E4.5L<KUOT25197ZS4:51Y5(E4F52I7`ZDN5NK"^ZDR5
M396EP$Z53Y50E;OJ497]LE*5]\/HNU.55)55E=?2],Z_ZE:55Y58E;SJ695:
ME5N5P^I<E<?0L]-=E5Z57Y5@E;JT897!P_+78I5CE6259971U6:5Q\IGE<7J
M:)5IE<3JQ^K&ZFJ5:Y5LE6V5;I7GUF^5U,]PE7&5R^IRE<Z[<Y5TE765=I5W
ME7B5>97ZO<[)>I5[E<SJ?)5]E;G)_L_*ZL[4S>K/ZGZ5@)7MS8&5@I6#E825
MR>J%E<[JAI6'E>[.B)7>NXF5O[.*E8N5C)6-E8Z5U<:POOK.CY60E9&5Y\>2
ME:>^T.J3E925Q]:5E9:5EY7`P9B5F96:E=W4FY71ZIR5G96^SYZ5GY6@E:&5
MTNJBE:.5I)6EE>[*II6GE:B5J96OQ;6PJI6KE:R5K96NE=3JKY6PE;&5LI6S
ME;25M96VE;>5T^K?]+B5N96ZE;N5O)6ZQ+V5OI6_E<"5P96IL<*5PY7$E<65
MW^7&E<>5R)7)E=7JRI7+E<R5S97.E<^5T)71E=*5TY74E=65UI77E=B5V97:
ME=N5W)7=E=Z5WY7@E>&5XI7CE>_*Y)76ZM?JV,;EE>:5YY7HE>F5ZI7KE>R5
MV.KME>Z5V>KOE?"5\97RE?.5])6[U/65^L>WTORX]I7WE<+J^)7<LOF5^I7\
MPON5^-3FS.[7_)7]E?Z50)9!ED*60Y;"U-#3P^OSQ426_K=%ED:6U.M'EDB6
M29:WR][K2I;*P$N63)9-EOO-3I:OLT^6VL90EE&64I93EE2659;\ZU:6OL17
MEK3.J<2^L?W46);UREF6[-9:EEN6T\;DMER6799>EE^6^KM@EF&6X-!BEF.6
ML<EDEM/4J,AEEF:6R[AGEK[HO,EHEFF6N^AJEN[`T]#$LN6T:Y:\Z&R6;9;(
MU6Z6;Y9PEG&6<I;%MG.6O>CXRMRX]<QTEG66=I:TP'>6>);NT;_HPNAYEGJ6
MO+I[EJVQW+U\EKWJP^A]EL;H?I;+Z("6@9:"EH.6S.B$ELG+Y;"%EJN\AI:'
MEKFYB):)EL'HBI;WS8N6RNB,EHV6CI:/EO;.D):1EI*6DY;MU926UL'$Z)66
MML.6EONYIM;(Z)>6F):9EN#*YM2:EL#HFY;%Z,?HG):YQ^.WG9;)Z)Z6W;_2
MZ)^6H);7Z*&6U>C<O,^\V^BBEJ.6I):EEJ:6IY:HEJF6WNBJEMKH^K&KEJR6
MK9:NEJ^6L):QEK*6LY:TEMBPL\3,N.+&OLCAR+66MI:WEL_HU.C6Z+B6\;G8
MZ/77N9;[Q+J6W.B[EKR6Z;*]EKZ6OY;1Z,"6P9;MO,*6PY;"O\WH^=;$EOC!
M\;+%EL:6QY;(ELF6RI;+ELR6W^C-EL'*V>C.EL^6T);1EJ35TI;JL;O5SNC0
MZ+"VT^C3EMWHN,#4EO?*U9:HR]:6UY;<QO7`V);9EMJ6VY;<ENGHW9;>EM^6
MH]#@EN&6XI;CEN26Y9;FEO+HZM;GENB6Z9;JENN6[);MEN#HX>CNEN^6\);Y
MT<NZ^;CQEO*6\;C4U._H\Y;NZ.SH\+G2S.;HIL[RO_26N+#QZ/#H]9;`U_:6
MY.CWEJG-H\GXEKB[V[WJZ/F6^I;[EOR6_9;^ED"709="ET.7XNCCZ.7HM;7G
MZ,7'Z^CMZ+"]KM=$E_CH19=&ET>72)=)ETJ72Y=,E_7H39>PS?;H3I=/EU"7
M49=2EU.75)=5EU:7NL%7E^CH6)>WP_"P69=:EUN77)==EUZ77Y=@E_3H89=B
MEV.7]^ADEV679I>CN6>7:)=IEVJ7:Y=LEVV7;I=OEW"7TLEQEW*7<Y?.P^#.
MYL!TEW67=I=WE_/+>)?=S+70>9=ZE^'*>Y?SZ'R7?9=^EX"7@9>"EX.7A)>%
MEX:7[+R'E_GHB)>)EXJ7BY>,EXV7WL..E^7&CY?WN9"7D9>2EY.7]+"4EY67
MV->6EY>7K+R8E^_%F9>:EYN7G)>=E\3,GI>?EZ;IH)>AEZ*7HY>DEZ67II>G
MEZB7J9>MR:J7HNGBP*N7K)>ME\._KI>OE["7_NC7N;&7^^BRE[.7M)>UEZ3I
MMI>WE[B7SM*YE[J7NY>\E[V7H^F^E[+6M=>_EZ?IP)>WO<&7PI?#E\27Q9?&
ME\>7R)?)E\J7RY?,E_SH_>C-E\Z7SY>AZ="7T9?2E].7U)?5E]:7UY?6S=B7
MV9>LTMJ7VY?<E[+IW9?>E]^7X)>IZ>&7XI?CEZJTY)>[M.67YI>KZ>>7Z)?I
ME^J7ZY?LE^V7[I?OE_"7\9?RE_.7])?UE_:7]Y>HT/B7^9>EZ?J7^Y?^L_R7
M_9>LZ>/`_I>JZ4"809BYZ4*80YBXZ42819A&F$>8KNE(F$F8^NA*F$N8J.E,
MF$V83IA/F%"8K+^QZ;KI49A2F*7"4YA4F%68K^E6F,6X5YBMZ5B8W-.TZ;7I
MM^E9F%J86YC'Z5R879A>F%^88)AAF,;`Q>EBF&.8L.EDF&68N^GQL&:89YAH
MF&F8:IAKF&R8;9ANF&^8O.FEU7"8<9B^Z7*8O^ESF'28=9C!Z7:8=YCQP7B8
M>9BVR'J8>YA\F+WI?9A^F("8@9B"F,+I@YB$F(68AIB'F(B8B9B*F,/IBYBS
MZ8R8MNF-F+&[CIB/F)"8P.F1F)*8DYB4F)68EICWO)>8F)B9F,3IQNF:F)N8
MG)B=F)Z8GYB@F*&8HIBCF*28I9C*Z::8IYBHF*F8SNFJF*N8K)BMF*Z8KYBP
MF+&8LIBSF-NRM)C(Z;68MIBWF+B8N9BZF+N8O)B]F+Z8KK>_F,"8P9C"F,.8
MQ)C%F,:8QYC(F,F8RIC+Z<SIRYC,F,V8SIC/F-"8P=71F*/$TIC3F-28U9C6
MF->8V.G8F.&ZV9C:F-N8W)C)Z=V8H]/>F-^8X)C4Z>&8XICCF.28Y9CFF.>8
MU^G0Z>B8Z9CJF.N8[)C/Z>V8[IC!Q^^8\)CQF/*8\YCTF/68]IC2Z?>8^)CY
MF/J8^YC\F/V8V>G(L_Z8T^E`F4&90IE#F429\,]%F4:91YG-Z4B929E*F4N9
M3)E-F4Z93YE0F5&94IGWLU.95)E5F5:95YE8F5F9UNE:F5N9VNE<F5V97IFT
MS%^98)EAF:W/8IECF62999EFF6>9:)EIF6J9U>EKF=SIV^ELF6V9;IEOF7"9
MWNEQF7*9<YETF769=IEWF7B9T>EYF7J9>YE\F7V9?IF`F8&9W>F"F=_IRL.#
MF829A9F&F8>9B)F)F8J9BYF,F8V9CIF/F9"9D9F2F9.9E)F5F9:9EYF8F9F9
MFIF;F9R9G9F>F9^9H)FAF:*9HYFDF:69IIFGF:B9J9FJF:N9K)FMF:Z9KYFP
MF;&9LIFSF;29M9FVF;>9N)FYF;J9NYF\F;V9OIF_F<"9P9G"F<.9Q)G%F<:9
MQYG(F<F9RIG+F<R9S9G.F<^9T)G1F=*9TYG4F=69UIG7F=B9V9G:F=N9W)G=
MF=Z9WYG@F>&9XIGCF>29Y9GFF>>9Z)GIF>J9ZYGLF>V9[IGOF?"9\9GRF?.9
M])GUF;?'SK2VN\#0H^SVF?>9M\7XF?F9^IG[F?R9_9G^F4":09I"FOO30YI$
MFD6:1IJD[$>:I>S;QDB:29I*FNZ_2YI,FDV:3IJF[$^:4)JG[*K049JXQU*:
M4YKHN%2:59I6FE>:6)I9FEJ:6YI<FEV:7II?FJCL8)IAFF*:8YIDFF6:9IIG
MFKG6_=7+M+VRY,[GQFB::9KAS6J::YILFFV:;IIOFG":<9IRFG.:=)IUFG::
M=YKUM'B:P,O?O'F:>II[FGR:XNGCZ>K1Y>E]FOFTY.E^FK/1XLK0LH":Z.F!
MFH*:@YJ$FN;IY^F%FH::L]:'FHB:B9KIZ>KIBIJ+FHR:C9J.FNOICYJ0FI&:
MDIJ3FI2:E9J6FNSIEYJ8FIF:FIJ;FIR:G9J>FJ_LN<7.MI^:\]*@FJ&:HIJC
MFJ2:I9JFFNZUIYK9N['LJ)JIFN/2JIJKFJR:K9JNFN/.KYJXQ+":O\.QFK*:
MOK:YV,BQS['1L?[%LYK0L;2:J\.UFK::MYJXFKF:L=6ZFKN:O)J]FKZ:OYK`
MFL&:I.O!NL*:PYK$FKK,Q9K&FL>:I>O(FJ?KR9K*FLN:J.O,FLV:SIJFZ\^:
MT)K1FM*:TYK4FM6:J>NKZZKKUIK7FMB:V9K:FJSKVYK/RK78\</<FJ7#^,:M
MZ\K$W9JNZZ_KL.O5M]Z:WYK@FOJWX9JQZ^+'XIJSZ^.:I+KUT;&PLNNTZ^2:
MY9KFFJJUR,+HQ^>:M>OHFJ[+W^/IFNJ:P-/KFNR:[9KNFMO9[YKPFJ'-K=;S
MQ_&:\IKSFN#9X[OTFKJZXN/UFO::]YKXFOF:J\_ZFON:_)K@X\?)_9JYNOZ:
M0)M!F[31X>/JR*^YK;W8L]O.0IM#F\#,1)M%FT:;Z./IX_3-1YM(FTF;2IM+
MFZW,3)NSO$V;ZN-.F^OC3YM0F]K049M2FU.;^\;:MU2;59O?Q\K2ULY6F^3C
M[.-7F_+)P;-8FUF;Y^-:FUN;X\;EXUR;79NS[>;C7IM?FV";89NSR6*;YL5C
MFV2;99NUN6:;N\-GF^/CO<6DP=G"U[)HF^WCIKNMQ&F;\./:OFJ;:YO[X_7C
MT[ILFVV;;IMOF]"WS=-PF\[6T]7!N;35V-%QFW*;<YMTF[G0]L=UFW:;=YNJ
MR+2R>)O:PWF;>IM[F^[C?)M]F_SC[^.HM_?C].-^FX";@9NZMX*;@YNBQ82;
M]N/=Q:BR_,:%F^#$AIN'FZ+7B)OAP/GCB9N*F_KC_>.IS//CBYN^TXR;P[&T
M[?'C\N.-F_CCNM##QO/4_N..FX^;X+V0FY&;I^22FY.;IN24FY6;EIOST:/D
MEYNIY)B;F9N:F_?(FYN<FYV;GINTSY^;J.2NY.7"H)NAF[2VHINCFZ2;I9NF
MFZ>;\KVHFZ+DJ9NJF^FZJN2KFZR;K.2MFZZ;_;;>UK+DKYNMY+";L9NRFZ'D
MLYONN]W-HL?)Q;2;M9OWP;:;I.2WF[/'K+V]O:7DN)O'U^*RN9NKY,.\K^2Z
MF^N[L.2HQ;'DNYN\F[V;OIOCU:._OYNZY,";M^3!F[ODPIO#F[WDQ)O%F];&
MQIO'F\:ZR\#(F\F;RINAN+3DRYO,F\V;SINAU,^;T)NCNOZ]T9O2F].;O.34
MF]6;UIO7F]B;O\W9F]J;^<3;F]R;^\_FR=V;WIN_T]^;T<_@F^&;L^3BF[CD
MN>3IS..;Y)OEF^:;YYO.S.B;U,"UY+#!MN30SNF;P;O3M>J;\\BGO<?5K,FB
MN,KDZYOLF\SDQ-'MF^Z;NM+OF_";K;KQF_*;U+KSF_2;]9OVF_>;^)O#Y.VU
M^9OZF_N;S=?`Y/W/O^3\F_V;_IO<P<K,0)Q!G$*<0YSGRD2<19Q&G$><U\1(
MG-3,R.1)G$J<2YS'Y,'D3)S$Y*VU39Q.G-G33YS&Y%"<49Q2G%.<^=+CM%2<
MM+M5G%:<[LE7G+ZT6)Q9G%J<[+M;G,W17)SMS+7M79Q>G%^<8)QAG&*<8YQD
MG.7'99QFG&><:)RHU&F<R^35U\+D:IREO<7D:YQLG.;3;9S)Y/C);IQOG+[D
M<)QQG.73<IQSG/['R;9TG/S4L[+7Y'6<=IQWG,+.>)S-Y'F<O,YZG-NX>YQ\
MG-;D?9S*OWZ<@)R!G,[3@ISLPX.<A)R%G(:<AYR(G(F<BIS(Q=CDBYR,G(V<
MCIR/G)"<D9R2G,3-S^23G)2<E9R6G-3DU>27G/ZZF)SFSYF<FIR_U9N<G)R=
MG-+DGIR?G*"<H9RBG*.<I)REG*:<IYRHG-#DJ9RJG,[DJYRLG*V<KIROG+"<
ML9RRG+.<M)RUG+:<MYRXG+F<Y<VJRKJ<NYR\G*/`O9RFO=/DOIR_G,BXP)S!
MG,*<PYS$G.?DM-3%G,:<QYS(G,F<RIS+G-ODS)S-G,Z<[\'/G-"<Z>31G-*<
MY]+3G-2<W^35G.#DUIS7G*K/V)S9G-J<VYS=R]R<VN31Y-V<Y>3>G-S(X^3?
MG."<Y\3BY.&<X>3BG..<Y)S\L^CDY9SFG.><Z)SAM>F<ZISKG,S7[)SMG.Z<
MYN3OG*R[\)S2U\_,^.OQG.3D\ISSG/:Y])SUG/:<S=;9Y-SD^L+>Y/><R\+$
MP-#"^)SUL;+,^9SZG/N<_)S]G/Z<0)U!G4*=0YW.M42=19U&G4>=[^1(G4F=
M2IU+G4R=39U.G4^=K\90G5&=4IWAQE.=5)WUY%6=5IU7G5B=69VIPEJ=6YU<
MG>S`W='NY%V=7IU?G6"=89UBG6.=9)UEG6:=KL1GG6B=:9WMY&J=:YULG6V=
M]N3TY/[";IW=Y&^=\.1PG?[*<9W$U7*=<YWQY'2==9UVG7>=>)UYG7J=^M%[
MG7R=?9U^G8"=@9V"G>OD[.2#G82=A9WRY(:=J\Z'G8B=B9V*G8N=C)V-G8Z=
MCYV0G<O%D9V2G9.=L<>4G;K"E9V6G9>=ZN28G9F=FIW*P9N=G)V=G9Z=GYV@
MG;;,L;.AG:*=HYW[Y*2=\^2EG::=IYWZY*B=_>2IG?SDJIVKG:R=K9VNG:^=
ML)W.L[&=LIVSG;JS]^2TG;6=^>3XY.S%MIVWG;B=N9VZG;N=O)V]G;Z=OYW`
MG<&=PIV]P,.=Q)W%G<:=Z-3'G<B=R9W*G<N=HN7,G<V=SIW/G="=T9W2G=.=
MU)W5G=:=Q+#7G=B=I.79G=J=H^7;G=R=W9W>G=^=X)VDO.&=I>7BG>.=Y)WE
MG>:=YYVAY>B=Z9WJG>N=[)WMG>Z=_N3TL>^=\)WQG?*=\YWTG?6=]IWWG?B=
M^9VHY?J=J>6FY?N=_)W]G?Z=0)Y!GD*>0YY$GD6>1IY'GJ?EJN5(GDF>2IY+
MGDR>39Y.GD^>4)Y1GE*>4YY4GE6>5IY7GEB>69Y:GEN>7)Y=GEZ>7YY@GF&>
M8IYCGF2>99YFGF>>:)[9QFF>:IYKGFR>;9YNGF^><)ZKY:WE<9YRGG.>=)YU
MGG:>=YZLY7B>>9YZGGN>?)Y]GGZ>@)Z!GH*>@YZ$GH6>AIZ'GHB>B9ZOY8J>
MBYZ,GJ[EC9Z.GH^>D)Z1GI*>DYZ4GI6>EIZ7GIB>F9Z:GIN>G)Z=GIZ>X+F?
MGJ">L.6AGJ*>HYZDGJ6>IIZGGJB>J9ZJGJN>K)ZMGJZ>L>6OGK">L9ZRGK.>
MM)ZUGK:>MYZXGKF>NI[PN^'L\,.[GL:UTKN\GKV>OIZ_GNG![M3`GL2^P9["
MGL.>QM?$GM;4T[*^[,6>QI['GLB>P>K)GLJ>RYZOPK:TS)[-GLZ>U]'/GM">
MT9ZTL]*>LLB[O\#LTY[4GLO6U9[6GK_LP>S7GMB>V9[:GMN>W)[=GMZ>WY[@
MGN&>XI[CGL7LYKZ_S-K%O+[DGL;LY9[^L>:>YY[HGL3LJ-7CM>F>PNRVP>.S
MZI[KGL/LN,O#P/[,[)[MGNZ>[Y[2P?">R.SQGO*>\Y[TGO6>]I[WGOB>^9[Z
MGON>_)[]GN:ZT\#^GO+60)]!GT*?S-%#GT2?19]&G[Z_1Y^SM]7)Q^SBNTB?
MS,S]O<C(29^ISTJ?2Y],GTV?3I]/GU"?Z<U1G^O%4I]3GU2?Z;=5GU:?5Y]8
MGUF?6I];GUR?79]>GU^?R=&XNF"?89]BGV.?9)_)[&6?9I_*[&>?P+O+[&B?
MXNRZL=FW:9]JGVN?;)]MGVZ?;Y]PGW&?<I]SG[F]=)]UGW:?=Y]XGWF?>I][
MG\SLYM'-['R??9]^GX"?N\B!GX*?@Y^$GX6?AI^'GXB?B9^*GXN?C)^-GXZ?
MT>R/GY"?D9^2G]/LDY_-NY2?Y;R5GY:?EY^8GYF?FI^;GYR?G9^>GY^?H)^A
MG\_LHI^WR:.?I)^EGZ:?IY^ZPZB?X^S5U=#LJ9^JGZN?K)^MG_/6KI^OG["?
MTNS.[+&?LI^SG[2?U.RUG]7LMI^WG[_)N)^YG[J?NY^\G[V?J,^^G[^?P)_!
MG\*?W-##G\2?Q9_&GZS1QY_(G\F?RI_;R,N?S)_-G];L]<[.G\^?T)_1G]*?
M[,K:[-.?U)_5G]:?UY_8G]F?V>S:G]N?W)^^L-V?WI_?G^"?X9_BG]?LXY_8
M[.2?Y9_FG^3LYY_HG^F?ZI_KG^R?[9_NG^^?O,CPG_&?\I_SG_2?]9_VG_>?
M^)_YG\?!^I_[G_R?_9_^G]SLX-%`H$&@0J!#H$2@1:!&H$>@2*!)H-OL2J!+
MH$R@3:#OU$Z@W>Q/H%"@4:!2H%.@5*#&VU6@5J!7H%B@6:!:H%N@7*!=H%Z@
MWNQ?H&"@8:!BH&.@9*!EH&:@9Z!HH&F@:J"LL6N@;*!MH&Z@;Z!PH'&@<J!S
MH'2@=:!VH'>@>*!YH'J@>Z!\H'V@?J"`H(&@W^R"H(.@A*"%H(:@AZ"(H(F@
MBJ"+H.#LC*"FUXV@P,6.H(^@D*"\ZZZPD:"2H).@]+ZXN*_2UK#YM92@L]B5
MH*S+EJ#=XY>@F*"9H)J@FZ"<H)V@K,;FL)Z@GZ"@H,;%N>NAH**@HZ"DH+KK
MI:"FH*>@N^NHH*F@P-&JH*/%JZ#RZJR@LL2MH+7$SL"NH*^@L*#SZL'$L:#O
MSK*@LZ"TH+6@\.KTZK:@MZ#\R;B@N:"CQ[J@NZ"\H-C,_LZ]H+Z@OZ#UZO;J
MK,_GP,"@P:#WZL*@PZ#$H,6@QJ"_MOCJQZ#YZLB@^NK)H,J@^^K+H,R@S:#.
MH,^@T*#1H-*@TZ#4H-6@UJ#QZM>@V*#9H-J@VZ#<H-V@WJ#?H."@X:#BH*[(
MZ^'CH+BW[.'DH.6@YJ#MX>>@M-?NX>_AS-/HH.F@ZJ#KH.R@[:#NH/'A\;_P
MX=*U[Z#PH/&@M['RH/.@]*#UH//A\N'VH/RZ]Z#TX?B@^:#ZH/N@M[G\H-&^
M_:#^H$"J0:K\Q$*JW;K&O4.J1*I%JD:J1ZI(JO7A]^%)JDJJP+;!SZC*]N'X
MU?S3^.'\X?GA2ZI,JOKAZL!-JO[AH>+'P$ZJ3ZI0JE&J^^%2JOWA4ZI4JE6J
M5JI7JEBJI>)9JEJJ6ZK4P5RJ7:I>JE^JH^)@JJCB_K*BXF&J8JICJLW#PK*G
MXJ;B9*IEJJ3BJ>)FJF>JJ^)HJFFJ:JK)T.W6J,.LXFNJU\]LJFVJKN)NJF^J
M[[IPJG&JX.FMXJKB<JISJG2J=:JKN[/4=JIWJGBJ>:IZJGNJ?*I]JGZJ@*J!
MJH*J@ZJPXH2JA:JOXH:JX>F'JHBJB:J*JK'BBZJ,JHVJCJJ/JI"JD:J2JK+B
MDZJ4JI6JEJJ7JIBJF:J:JINJG*J=JK/BH<R>JK3BGZJ@JD"K0:M"JT.K1*M%
MJT:K1ZM(JTFK2JM+J[7B3*M-JTZK3ZM0J_[04:M2J\K"4ZOQTU2K]<U5JU:K
MX.=7JUBKX>=9JUJK6ZM<J\&^7:M>JU^K8*OJPF&K8JMCJ^3G9*MEJ^/G9JMG
MJVBK::MJJVNKYLULJ[7#;:MNJ^+GM[O6SV^KX<'IYW"K<:MRJ^CG<ZMTJ_3G
MH[)UJW:K=ZMXJ^KG>:OFYWJK>ZM\JWVK?JOLY^OGNLF`JX&KY-6"J^7GJ;?G
MYX.KA*N%JX:KAZN(JXFK[N>*JXNKC*N-J_/GCJOIUH^KD*N1JY*K[>>3J_+G
ME*OQYY6KEJN7J^"PF*N9JYJKFZOUYYRKG:N>JY^KH*M`K$&L0JQ#K$2L1:Q&
MK$>L2*Q)K$JL\L=+K,7`[<!,K$VL\,'PYTZL3ZQ0K%&L]N?VRU*L4ZQ4K%6L
M5JQ7K%BL6:Q:K*+HH>A;K%RL7:Q>K%^L8*S!UV&L8JSZY_GG8ZS[YV2L]^=E
MK/[G9JS]YV>L_.=HK&FLU<'9Q_W%P\5JK&NL;*QMK&ZL[<=OK'"L<:QRK*/H
M<ZQTK'6L=JQWK'BL>:QZK'NL?*Q]K'ZL@*R!K(*L@ZR$K(6LAJRFZ(>LI>B(
MK*?H][KXYZ3HB:SPR*K)BJR+K(RLC:R.K(^LD*R1K)*LDZR4K)6LEJRIZ)>L
MF*SEN9FLFJR;K)RLG:S^T:CHGJR?K*"L0*U!K4*MJNA#K:WHKNA$K:?!1:U&
MK4>MK^A(K4FM2JVPZ$NM3*VLZ$VMM.A.K4^M4*U1K5*M4ZU4K56M5JU7K5BM
MJ^A9K;'H6JU;K5RM7:U>K5^M8*UAK;7HLNBSZ&*M8ZUDK66M9JUGK6BM::UJ
MK6NM;*UMK6ZM;ZUPK7&MM^ARK7.M=*UUK7:M=ZUXK7FM>JU[K7RM?:U^K8"M
M@:V"K8.MA*V%K8:MAZV(K8FMMNB*K8NMC*V-K8ZMCZV0K9&MDJW/N9.MK/"4
MK:WPE:VPQNJPO\B6K=_-EZV8K9FMFJV;K9RMG:W-SK'JGJV?K:"M0*ZRZD&N
MO\;)M$*N0ZY$KD6N1JY'KDBNL^I)KDJN2ZY,KN?53:Y.KD^N4*Y1KE*N4ZY4
MKOG=5:ZTZE:NM>I7KK;J6*Y9KEJN6Z[*N+#?]<E<KO#,7:Y>KOK)7ZY@KF&N
M8JYCKOO)9*YEKL/3ILMFKJ:XKO#"L6>NN.7OS,G3U[SJR6BNY[5IKM#$Z;5J
MKJ[NK;MKKFRNWN=MKJ_N;JYOKG"N<:ZILW*N<ZZR[G2N=:ZQ[N>]=JZP[K?.
M=ZYXKGFN>J[/Q7NN?*Y]KGZN],'.V[/N\]"`KH&N@JZ#KH2NA:Z&KH>NU,+H
MQHBNB:Z*KJRWBZZ,KHVNCJZ/KI"ND:ZT[I*NZ[.3KI2NE:[[N[7NEJZ7KIBN
MF:Z:KMSGFZZ<KIVNMNZ>KI^NKKV@KD"O0:]"K^+Q0Z]$KT6OZ,I&K\G2VO!'
MK]OP2*_<\,;!2:_MN,Z^2J]+K][P3*^QQ=WP\=%-K^#PS+#JO4ZO3Z]0KU&O
M4J_?TM_P4Z^OM.BWYO#E\*/&X?#B\,.T5*]5K^/P[M56KU>OV\S2OK*\6*]9
MKUJOZ/#G\.3PH;);KZ+6N-.WOJS(7*]=K^KP7J]?KV"O8:_WT6*OS-;;NNGP
M8Z^[MF2O9:^TS6:O9Z^FQFBO::]JKZ'!Z_#N\&NO[?#P\.SP;*^^N^_P;:]N
MKV^O<*^US/+P<:]RK]6S<Z]TKW6O=J_4L7>O>*_S\'FO>J_T\/;PX;1[K_'P
M?*_W\'VO?J^`KX&O^O""K_CP@Z^$KX6O]?"&KX>OB*^)K_WPBJ_Y\/SP_O"+
MKZ'QC*^-KXZOP<ZD\8^OH_&0K_;!^_#=RI&ODJ_QM/&QL<R3KZ;QE*^5KZ?Q
MEJ^7KZSQSM6I\9BOF:^SR)JOFZ^<KZ+QG:^K\:CQI?&>KY^OJO&@KT"P0;!"
ML$.P1+!%L$:PJ;"M\4>P2+!)L$JP2[!,L*_Q3;"Q\4ZP3[!0L%&P4K"P\5.P
MKO%4L%6P5K!7L*+16+!9L%JP6[!<L%VP7K"R\5^P8+!AL+/Q8K!CL&2P9;!F
ML&>P:+!IL.^Y:K!KL,>U;+#7L-FP;;!NL&^P[=1PL,2U<;#4O<J[I_!RL'.P
MWKATL'6PJ/!VL'>PJ+!XL*GP>;!ZL.[->[!\L*KP?;!^L("P@;""L(.PA+"%
ML(:PA["K\(BPB;"*L(NPC+"-L(ZPC["0L*3&D;"2L.76Y/&3L.7QE+"5L):P
ME["8L)FPFK";L)RPG;#SPYZPG[#;TZ"P0+'1UNC%0;&OTT*QYM)#L42QP>Z[
ML+75SM'@O-"Z1;'XOT:QQ[C!M<S%1[%(L:+*2;%*L4NQR\-,L4VQ3K%/L5"Q
MPNY1L5*Q4[%4L56Q5K%7L5BQO\2BMEFQ[.VDPUJQL=9;L5RQ7;'@S^_M7K%?
ML<[%8+'<MF&Q8K&ARF.Q9+'M[66Q9K'P[?'MO,-GL;2_:+'N[6FQ:K%KL6RQ
M;;%NL6^Q<+%QL7*Q<['T[?+M=+%UL7:Q=['FU=_#>+'S[7FQ>K%[L?;M?+&C
MU:/1?;%^L8"Q]>V!L=##@K&#L82QA;&&L??M]+_LOOCMA['WS(BQV]&)L8JQ
MB['%U_;5C+'\[8VQCK&/L?OMD+&1L9*QD[&4L96QEK&7L?GM^NV8L9FQFK&;
ML9RQG;&>L9^Q_>VFOJ"Q0+)!LD*R0[*ORZ'NO;9$LJ+NP,1%LO[M1K)'LMZ]
MQ[)(LDFR2K)+LDRR3;).LD^R4+)1LE*R4[+#ME2R5;)6LJ7NNMBC[J;N5[)8
MLEFRZ</RLUJR6[)<LEVR7K)?LJ?NI.ZYSV"R8;*H[O?"8K)CLF2R9;)FLF>R
M:+)ILFJR:[)LLFVRJ>ZJ[FZRJ]YOLG"RL\9QLL;'<K+UULFU<[*RRW2R=;)V
MLJON=[)XLJO->;*L[GJR>[)\LGVR?K*PU8"RK>Z!LL3V@K*#LH2RA;*&LH>R
MB+*)LHJRB[*,LHVRCK+'VX^RD+*1LI*RD[*4LI6REK*7LJ.TF+*9LIJRK,/F
M\9NRG+*=LIZRG[*XRM/2H+*JUD"S\N]!L]B^0K/#O?/OS+:KL$.S1+-%LT:S
MK\I'LTBSMNU)L[?M2K-+LTRS3;/YSJ^W\[^X[>O"L,E.LT^S4+-1LU*S4[.Y
M[52S5;/VQK._5K-7LUBSO.WXQ5FST-%:LZG7NNV[[5NSXM%<L[_MP.U=L\3M
M7K-?LV"SR.UAL\;MSNWHU6*SR>UCLV2SQ^V^[66S9K/IQ6>S:+-IL\;&:K-K
ML^G)TM3![<+MP^W%[6RS^<!MLZ&T;K-OLW"S<;/HN7*ST.USLW2S=;-VL]'M
M=[/*[7BSS^UYL_C.>K-[L[;+S.W-[7RS?;-^LX"S@;/USX*S@[.$LX6SAK.'
MLXBSB;.*LXNSC+.-L]+M\L&RT\OMM\B.LX^SD+.1LY*SD[.4LY6S[[R6LY>S
MF+.9L_#%FK.;LYRSG;.>LY^SH+-`M$&T0K36[4.T[[5$M$6TM<*ML.G+1K1'
MM*ZQ2+34[4FT2K1+M.O-XK5,M-7MT^W7[4VT3K3ZM4^TV.U0M-GM4;3<[5*T
MS+%3M%2T5;16M%>T6+19M%JT]L7NO-KMO,SJLENT7+1=M%ZTV^U?M&"T8;1B
MM.O$8[1DM,6T9;1FM&>T];!HM&FT:K3?[=K`Z+1KM&RT;;1NM,W%;[1PM'&T
MW>W$OW*T<[1TM-[M=;1VM'>T>+1YM'JT>[1\M'VT?K2`M(&T@K2#M*7$A+2%
MM(:TX.V'M(BTB;2*M(NTX>V,M./MC;2.M-?!C[20M,>[D;22M).TE+25M):T
MN+V7M)BTF;3B[9JTF[2<M)VTGK2?M*"T0+5!M4*U0[5$M46UY.U&M4>U2+5)
MM4JU2[5,M4VU3K5/M>;M4+51M5*U4[54M>7M5;56M5>U6+59M5JU6[5<M5VU
M7K5?M6"U8;5BM6.UY^UDM66U9K5GM6BUOLKJ[/'`:;7GR6JUZ^SNQFNU;+5M
MM6ZU[.QOM>W&[>QPM7&U<K5SM72U=;5VM7>U>+7P['FU>K7FU_/L>[5\M?'L
M[NSO[*/7\<GNR_3L?;7R['ZU@+7ISX&U]NRQQH*U@[6$M86UP+R&M?7LA[6(
MM8FUBK6+M8RUC;6[M?:[CK7W[(^UD+61M9*UD[7WV?N]E+65M;O"^.R6M9>U
MF+69M?GLFK6;M9RUG;6CN)ZUG[6@M4"V0;9"MD.V1+9%MD:V^NQ'MDBV2;9*
MMDNV3+9-MDZV3[90ME&V4K;[[%.V5+95ME:V5[98MEFV6K9;MERV7;;\[%ZV
M7[9@MF&V8K;MTZ[8Z\!CMMW'S+IDMN/0O<MEMKK-9K9GMM&X:+9IMORQ:K;O
MQVNVUM9LMFVV;K;&O^O#;[9PMO7O<;9RMMC#<[9TMG6V=K9WMGBVXM=YMGJV
M>[;W[].S?+;8Q^W1?;;(UGZV^.^`MO;O@;;]N\:S@K:#MH2VA;:&MH>VB+;5
MO8FVBK;&THNVX+N,MHVVH<^.MOSO^^^/MI"V^>^1MI*VD[:4MLRSE;;4R;#+
MEK:7MIBVF;::MO[OF[:<MMZPG;:>MLG6G[:@MD"W_>]!M^VS0K=#M]7V1+=%
MMT:W1[=(MTFW2K=+MTRW3;=.MT^W4+=1MU*WR,Y3MU2W5;>B\%:WH?!7M[ZU
MVKS\NUBWY;A9MUJW6[=<MUVW7K?"Q%^W8+=AMV*W8[=DMV6W9K=GMVBWH_!I
MMVJW:[=LMVVWZ\MNMV^W<+=QMW*W<[=TMW6W=K=WMWBW>;=ZMWNW?+=]MWZW
M@+>!MX*W@[>$MX6WAK>F\(>WB+>)MZC1BK>_ON['MO&W\=6_B[>,MXVWCK>I
MM+CQN\V/M]3'K=60M[GQD;>Z\9*WD[>4MY6WS\>6MY>WF+>DTL_6F;>:M[OQ
MT;VPM+V^F[><MYVWW+31SIZWW[^]\9^WH+=`N$&X^K^\\4*XO_%#N$2X1;B^
M\<#Q1KA'N$BX2;A*N,'Q2[A,N$VX3KA/N%"X4;A2N%.X5+A5N/[!5KA7N%BX
M6;A:N%NX7+A=N%ZX7[A@N*+!8;ABN&.X9+AEN&:X9[AHN&FX:KCZRFNX;+B^
MU6VX;KAON'"XNKZYOL+5<;ARN**_<[BOS;7Q=+AUN':X=[AXN'FXW[UZN,NV
M>[A\N'VX?KB`N(&X@KB#N(2X\=;#\X6XAKC$\X>XS;B(N(FXBKC&\\?SB[C*
ML(RXQ?.-N,GS\<N.N(^XD+C+\Y&XIM"2N).XRK'(\Y2XE;B6N,_SE[C1M9BX
MF;C7\YJXTO.;N)RXG;C4\]/S^[>>N+^QG[C.\\KSVK6@N-#S0+E!N='S0KG5
M\T.Y1+E%N4:YS?-'N>.\2+G]P4FYUO-*N4NY3+E-N4ZY3[G:\U"YS/-1N<BU
M4KGNO=SS4[E4N:2W\+_^UK+-5;GPM%:YW[)7N=CS6+G9\[C)6;G=\UJY6[G>
M\URYX?-=N5ZY7[E@N6&Y8KECN62Y9;EFN6>YW_-HN6FYX_/B\VJY:[G;\VRY
MZK]MN>^S;KG@\V^Y<+FIQW&Y\KQRN7.Y=+EUN>OS=KEWN7BY>;EZN7NY?+F_
MN7VY?KGD\X"Y@;F"N:VR_KN#N>/+A+F%N8:YA[GM\^GSB+F)N8JYW+GN\XNY
MC+F-N>7SYO/J\^'"[//O\^CS_;R.N8^YD+GDSY&YDKGP\Y.YE+F5N>?SEKF7
MN9BYF;F:N9NYG+F=N?+SGKF?N:"Y0+JMUZK&0;I"ND.Z1+KS\T6Z1KI'NDBZ
M\?-)NJC"2KI+NDRZ3;I.NMVX]?-/NE"Z]/-1NE*Z4[K;M%2Z5;I6NO;S]_-7
MNEBZ6;KX\UJZ6[I<NKK`7;I>NNG`7[I@NF&Z8KICNO'%9+IENF:Z9[K[\VBZ
M^O-INFJZ:[ILNFVZ;KIONG"ZV+1QNG*Z<[K^\_GS=+IUNOSS=KIWNGBZ>;IZ
MNGNZ_?-\NGVZ?KJ`NH&Z@KJ#NH2ZH?2%NH:ZA[J(NHFZBKJC],F[B[J,NJ+T
MC;J.NH^ZD+J1NI*ZD[J4NI6ZEKJ7NIBZF;JD])JZF[J<NIVZGKJ?NKZRIO2E
M]*"Z0+M!NT*[0[M$NT6[1KM'NTB[2;NNO$J[2[M,NTV[3KM/NU"[4;M2NU.[
M5+M5NU:[5[M8NUF[6KM;NUR[7;M>NU^[8+MANV*[8[MDNV6[9KMGNVB[:;MJ
MNVN[;+MMNVZ[U\/AV6^[<+MQNW*[<[MTN^#`S/31UW6[=KMWNWB[>;MZNWN[
M?+M]NWZ[@+O;MX&[@KN#NX2[A;N&NX>[SO2CP8B[B;O)QHJ[UK2SU8N[C+N-
MN]#TS_31]-K+CKN/N]+TD+O!U.#6D;N2NY.[E+O@MY6[EKN7N[C!F+N9N[O!
MT_2LOIJ[F[N<NYV[GKOBM)^[H+O4]-7TJ[Y`O$&\UO1"O$.\1+S;]$6\U_3:
M]$:\_;I'O-CTV?1(O$F\2KQ+O$R\3;Q.O.*XQ\S<]$^\VK)0O%&\T\-2O%.\
MX]2WOU2\5;Q6O%>\6+Q9O%J\W?1;O%R\7;Q>O%^\8+RTQ6&\8KQCO&2\9;QF
MO&>\:+SI]&F\:KRUSVN\;+QMO&Z\;[QPO'&\<KQSO'2\=;QVO'>\>+S)SGF\
M>KQ[O'R\?;Q^O("\@;R"O(.\A+R%O(:\A[R(O(F\BKR+O(R\C;R.O-C+C[SW
MRY"\D;R2O).\]+V4O)6\EKS/UY>\F+R9O-O`FKR;O)R\G;R>O)^\H+Q`O4&]
M0KU#O42]1;U&O4>]2+U)O4J]2[U,O4V]3KU/O5"]4;U2O5.]5+U5O5:]5[U8
MO5F]6KU;O5R]7;U>O5^]8+UAO6*]8[UDO66]9KUGO6B]:;UJO6N];+UMO6Z]
M;[UPO7&]<KUSO72]=;UVO?70=[UXO7F]>KU[O7R]?;U^O>KT@+V!O8*]@[V$
MO86]AKV'O8B]B;V*O8N]C+V-O8Z]C[V0O9&]DKV3O92]E;V6O9>]F+V9O9J]
MF[V<O9V]GKV?O:"]0+Y!OD*^0[Y$OD6^1KY'ODB^2;Y*ODN^3+[K]$V^3KY/
MOE"^4;Y2OE.^[/14OE6^5KY7OEB^6;Y:OEN^7+Y=OEZ^7[Y@OF&^8KYCOF2^
M9;YFOF>^:+YIOFJ^:[YLOFV^;KYOOG"^<;YROG.^=+YUOG:^=[YXOGF^>KY[
MOGR^?;Y^OH"^@;Z"OH.^A+Z%OH:^A[Z(OHF^BKZ+OHR^C;Z.OH^^D+Z1OI*^
MD[Z4OI6^EKZ7OIB^F;Z:OIN^G+Z=OIZ^G[Z@OD"_0;]"OT._1+]%OT:_1[](
MOTF_2K]+OTR_3;].OT^_4+]1OU*_4[]4OU6_5K]7OUB_6;]:OUN_7+]=OUZ_
M7[]@OV&_8K]COV2_9;]FOV>_:+]IOVJ_:[]LOVV_;K]OOW"_<;]ROW._=+]U
MOW:_=[]XOWF_>K][OWR_?;]^OX"_X_>!OX*_@[^$OX6_L;>&OX>_B+^)OXJ_
M[?2+OXR_C;^.OX^_D+^1OY*_D[^4OY6_EK^7OYB_F;^:OYN_G+^=OYZ_G[^@
MOT#`0<!"P$/`1,!%P$;`1\!(P$G`2L!+P$S`3<!.P$_`4,!1P%+`4\!4P%7`
M5L!7P%C`6<!:P%O`7,!=P%[`7\!@P&'`8L!CP.O79,!EP&;`9\!HP&G`:L!K
MP&S`;<!NP&_`<,!QP'+`<\!TP'7`=L!WP'C`><!ZP'O`[O1\P'W`?L#YYL"^
M^N;LNOOFR\_\YKS4MKS]YO[FS;S2R+/.H>>`P+^THN>TR=FXR<2!P-W7VL+7
MM[W6QL[$MX+`@\"FQ:/GW\^DYZ7GIN>WP>G7\,FXSZ_6U=:GY^VPJ.>IY]S)
M[]*MOJKG\[#>R.&]J^?&R(3`K.?FN_BXI-&MY^?"^+[*O;/-KN>OY^Z^Y="%
MP.?+T,S,O+#GJ+SWT+'GAL#XT++GL^?"M+3GM>?^R:S.X,.WY\&Q\;.'P+CG
MN>?;U\#5NN?,PKK7N^>\Y[WGZKSEP\+`ON>_YZF\B,#`Y\'GMN?0ML+GB<##
MY\3GNKO>M<;"X+'%Y[74QN>_N,CGQ^?LMXK`R>?XLLKGR^?,Y\WGSN?/Y]#G
MI]/UR]'GTN?3Y]3GR<G5Y];GU^?8Y]GGR;W:Y[[SB\#7N(S`L<B-P([`C\"0
MP)'`DL"3P+_SE,#`\\'SE<"6P)?`F,"9P)K`F\"<P)W`GL#>N?C-G\"@P.C8
ML;I`P=["M^Y!P:.W0L%#P43!1<&Y[D;!N.[5L$?!2,%)P4K!2\&[[M;5[]=,
MP4W!3L'#UD_!4,&][O#*4<&\[E+!4\%4P57!ONY6P5?!6,%9P<#N6L%;P;_N
M7,%=P5[!7\%@P6'!8L%CP?+19,&\QV7!P,-FP6?!:,%IP6K!X;AKP6S!;<%N
MP6_!Y\%PP7'!QO3?T,?T<L';SW/!=,&ZR'7!=L'(]'?!>,%YP7K!>\%\P7W!
MR?3*]'[!R_2`P8'!@L&#P83!^MG^N(7!AL'QY?#3A\'@](C!S,Z)P8K!B\'A
MLXS!C<&.P8_!M/&0P>[2D<'A])+!D\&4P97!EL'HS^+TE\&8P<S'F<&:P9O!
MG,&=P9[!U+7DM.3TG\&@P4#"X_3E]$'"0L+F]$/"1,)%PD;"Y_1'PK*ZO[!(
MPNCT2<)*PDO"3,)-PD["3\*MM^W24,)1PE+"J]+/P%/"O+^CZ]_5R.I4PE7"
M5L)7PO/Q^+:CRUC"6<+-Q%K"Y_%;PNCQ^[CI\<2ZQ=32L%S"7<+J\5["7\)@
MPNOQ8<+L\6+"8\+M\>[Q[_'Q\?#QU<5DPF7"9L)GPFC":<+R\6K"^K9KPO3Q
MKM+'WLK+;,)MPMRS;L*BM6_"HKEPPG'"],3U\7+"<\+V\73"=<)VPL3!^\&P
MUO?Q=\)XPGG">L+X\7O"JL%\PGW"?L*XQH#"V[Z!PH+"@\*$PH7"AL*'PHC"
MB<**PHO"C,*-PH["^?'/M(_"D,*1PI+"D\*4POKQE<*6PI?"F,*9PIK"F\*<
MPIW"GL*?PJ#"0,.R[;'M0<-"P^#+WM)#P\'+V-5$P^+(1</?P*&\1L-'PTC#
M2<-*PTO#P>M,PTW#I-!.P^+63\/'MMBXP.O.N%##O^NFL\FYJ]91P_2WRK=2
MPU/#5,/GO+ZWQNM5P\?KN;#/OU;#Q>O]TU?#R.M8PUG#R>M:PUO#SK=<P\+K
MQ.OVR=?6S=6RT,_KN,[0ZUW#J+5>PU_#8,-APV+#L['2ZZ7,8\-DPV7#9L-G
MPVC#:</6Q=/K:L/1Z]_%SNNDRM7K^[!KPVS#^KIMPV[#M]CC\6_#RNO+Z\SK
MS>O6Z\#FV>MPP^B_R-+7Z]SK[+C8ZW'#NKURP]C0<\.WL'3#W>O<Q'7#=L-W
MPWC#K-9YPWK#>\/@M'S#?</VPKF\?L.`P]KKV^O@U.K&U,3?ZZ?%]=F!P[&R
M@L/DZX/#Q;V$PX7#AL/BZX?#B,.)PXK#B\.,PXW#CL./PY##D<.2PY/#X^N4
MPY7#K+B6P]'-Y>N7PYC#F</AZYK#L\&;PYS#G<.>PY_#HL:@PT#$0<1"Q$/$
M1,1%Q//,1L3FZT?$L,"XTN?K2,1)Q$K$K[BMN$O$Z.N[Q_/-3,1-Q$[$ZNOK
MZT_$4,11Q%+$4\3MZU3$5<16Q%?$R-!8Q/+K6<3NZUK$6\1<Q/'K^<A=Q/S1
M[.M>Q%_$Z>M@Q&'$8L1CQ+FXV<_EQ._K\.O:S,C-\K!DQ/;K9<1FQ&?$:,1I
MQ/7K:L2RLFO$;,1MQ&[$X+AOQ/?K<,1QQ'+$<\1TQ'7$[+%VQ'?$Q<RDQ*7/
M>,1YQ'K$>\1\Q/GK?<1^Q*+L@,3RQ8'$^NN"Q(/$A,2%Q(;$A\2(Q(G$Q<F*
MQ(O$C,2-Q([$C\3?XO[KD,21Q)+$D\3.S:'LV[&WTY3$E<3<TI;$E\28Q/WK
MF<3[ZYK$F\2<Q)W$GL2?Q*#$0,5!Q4+%0\5$Q47%1L5'Q4C%2<5*Q4O%3,5-
MQ4[%O+-/Q5#%4<6PZE+%4\74UU3%J_3TLU7%5L57Q5C%6<7!UL+66L5;Q5S%
M7<5>Q5_%Z=7*OF#%I_1AQ:C2J/2I]&+%JO3+OM_38\5DQ67%9L5GQ>#)X<EH
MQ6G%PO-JQ>;*:\7RS&S%;<5NQ6_%<,5QQ;;BM,MRQ>C.V]9SQ:WTKO2O]'3%
M=<5VQ7?%LO1XQ;VZL_3CL+#T><6Q]**]U;)ZQ;;TM_3FMK"RS\^T]*RT>\6U
M]'S%?<6X]'[%@,6!Q8+%@\6Y](3%A<6GS8;%NO2'Q;OTB,6)Q8K%O/2+Q8S%
MC<6.Q8_%D,61Q9+%TLN3Q;WTE,65Q9;%E\6^])C%F<6:Q9O%G,6=Q9[%G\6_
M]*#%0,9!QD+&0\;>]+S!Z+Q$QJO)WM'UY47&1L9'QDC&L]S5TDG&2L:TW*RP
MM=Q+QDS&VKU-QKG<3L9/QE#&PMA1QK?<\]-2QM;)NMRVW%/&N]RBPU3&5<96
MQE?&O-S%W+W<6,99QM_.I=9:QL_<6\;-W%S&7<;2W.:]J\)>QKC<R]S.W+[<
MTK?%L,?<OM#!W*B[7\:\M\S<8,9AQL;<O]S;QV+&8\9DQK_1P-QEQF;&RMQG
MQFC&T-QIQFK&K<["W&O&P]S(W,G<U++1W-7+;,:WU-O<W]RFS.;<;<;GP]S<
M;L9OQL&_V=QPQOJPMKGEW-/<<<;$W-;<],C@OW+&<\9TQG7&N\EVQG?&>,:]
ML7G&HM-ZQGO&VMQ\QGW&U=Q^QKO&@,;>W('&@L:#QH3&A<;"UZ_#MK?1QZG#
MXMS8W.O<U-R&QH?&W=R(QJ6^U]R)QN#<BL:+QN/<Y-R,QOC<C<:.QN'<HMWG
MW(_&D,:1QI+&D\:4QI7&EL:7QIC&Z[S$M)G&FL:CP^>R^MR;QO+<G,;OW)W&
M_-SNW/#2Z+*>QM?(X\C[W)_&[=R@QD#'0<?WW$+'0\?UW$3'1<>COO3<1L?=
MLD?'2,=)QTK'2\?SW/:\Z-S$NTS'\\!-QT['3\=0QU''U+SIW.K<4L?QW/;<
M^=RTM5/'V<CGN_[<_=RKTZ'=H]VEW?'2I-VFW:?=J=)4QU7'5L=7QUC'6<=:
MQ\FZJ=U;QUS'MMVQW;3=7<=>QU_'8,=AQV+'8\>PW<[&9,=EQ_+`9L=GQVC'
M:<>OR6K':\=LQ^S<KMUMQV[';\=PQ[?=<<=RQ_#<K]USQ[C==,>LW77'=L=W
MQWC'><=ZQWO'N=VSW:W=JL1\QWW'?L>`QZC=L\"KP:K=J]V!Q[+=\;NUW:C3
MNMV"Q[O=I\.#QX3'TMV\W87'AL>'Q]'=B,>]N8G'BL?5OHO'^KZ,QXW'RKJ.
MQX_'D,>1Q\K=DL?%W9/'O]V4QY7'EL?+LL/=E\?+W:2RU=V8QYG'FL>^W9O'
MG,>=Q]#&T-V>QY_'H,=`R$'(U-WBP<:W0LA#R$3(1<A&R,[=S]U'R$C(2<C$
MW4K(2\A,R+W=3<C-W=',3LC)W4_(4,A1R%+(PMW(P[S&KL[,W5/(R-U4R%7(
M5LA7R%C(6<C!W5K(6\A<R,;=W,)=R%[(7\A@R&'(8LBITZK3T]WTS_C(8\AD
MR&7(9LAGR&C(:<AJR.;=:\ALR&W(;LAOR'#(Q]UQR'+(<\C@W>3"=,AUR';(
M=\AXR'G(>LA[R.'=?,A]R'[(@,B!R(+(@\B$R(7(ALC7W8?(B,B)R(K(B\CX
MUHS(V=W8W?"XUMV-R([(C\B0R,_&D<BMMI+(D\B4R)7(ELCBW9?(^;KAU.?=
MF,B9R)K(T+2;R-K=G,C[O^/=G<C?W9[(W=V?R*#(0,E!R4+)0\E$R=FU1<E&
MR4?)2,G;W=S=WMU)R:^]Y-U*R>7=2\E,R4W)3LE/R5#)4<E2R?7=4\G)PU3)
M5<GBRU;)5\E8R5G)\MU:R5O)7,E=R5[)7\E@R6')8LECR63)9<EFR>'89\EH
MR='&:<GTW6K):\ELR?35\]WPW6W);LGLW6_)[]UPR>C=<<ERR>[0<\ETR77)
M=LG8R.[==\EXR>G=><EZR>K=\LM[R>W=?,E]R<VQ?LF`R8')@LF#R83)ML"%
MR;N\\=V&R8?)]]V(R?;=Z]V)R8K)B\F,R8W)[L6.R8_)D,G[W9')DLF3R93)
ME<F6R9?)F,F9R9K)F\FDWIS)G<FCWI[)G\F@R4#*0<I"RD/*1,I%RD;*1\I(
MROC=2<I*RDO*3,KOPTW*^\).RD_*4,KAU5'*4LJUSE/*5,I5RE;*_=U7RLRR
M6,I9REK*6\I<REW*7LI?RF#*Z,3?RF'*8LICRF3*9<IFRF?*:,IIRFK*OL?Z
MW?S=_MVBWJJPSK%KRFS*;<INRF_*K-YPRG'*<LISRJ;>MKWOR'3*=<IVRG?*
M>,IYRGK*>\I\RGW*?LJAWH#*@<JEWH+*@\J$RH7*J=Z&RH?*B,J)RHK*J-Z+
MRHS*C<JGWH[*C\J0RI'*DLJ3RI3*E<J6RJW>E\K,U)C*F<J:RIO*L]ZJWJ[>
MG,J=RMG`GLJ?RJ#*0,M!RZ&QMMY"R['>0\M$RT7+1LM'RTC+2<NRWDK+2\M,
MRTW+3LM/RU#+4<M2RU/+5,NFT;7>5<M6RU?+6,M9RUK+6\NOWES+7<M>R[#>
M7\N]T&#+8<MBR[3>[<JYWF/+9,MERV;+9\MHR[C>:<NWWFK+:\MLRVW+;LMO
MRW#+N]YQRW++<\MTRW7+=LMWR^6]>,MYRWK+>\M\R]BRZL-]RW[+NMZ`R[K%
M@<N"RX/+A,N%RX;+O-Z'RXC+B<N*RXO+C,N-R]G,CLN/RY#+D<NJMY++D\N4
MRY7+ELN7RYC+F<N:RYO+G,N=RY[+G\N@RT#,0<SEU$+,0\Q$S+W>1<Q&S$?,
M2,Q)S+_>2LQ+S$S,3<Q.S$_,4,Q1S%+,4\Q4S*+$5<Q6S%?,6,S!WEG,6LQ;
MS%S,7<Q>S%_,8,QAS&+,8\QDS&7,9LQGS&C,OMYIS,#>:LQKS&S,;<QNS&_,
M<,QQS'+,<\QTS'7,=LQWS+K5>,QYS'K,PMY[S'S,?<Q^S(#,@<R"S(/,A,R%
MS(;,A\R(S(G,BLR+S*[RHKNRPK#%Q\*,S(W,K_*.S(_,D,R1S)+,Z="3S)3,
ME<S=TY;,E\R8S+WKF<R:S)O,G,R=S)[,G\R@S.:SL/)`S;'R0<U"S:W*0\U$
MS47-1LU'S4C-2<WGNK/RM?*T\N3+NL^R\K3*S]+LPDK-2\U,S4W-3LU/S5#-
MP\ZX\O:PM_)1S5+-4\U4S57-OO)6S<^R5\U8S5G-6LU;S5S-P=&Z\EW-7LU?
MS6#-8<V\\NG48LUCS;ORMO*_\KWR9,VY\F7-9LW'\L3RQO)GS6C-RO+"\L#R
M:<UJS6O-Q?)LS6W-;LUOS7#-^]9QS7+-<\W!\G3-^<??R77-R/+&N;"U=LUW
MS</RR?+0\M;R>,UYS=>[>LU[S7S-U?+<S7W-Z]9^S8#-TO+4\H'-@LV#S83-
M\KB%S8;-A\V(S<ORB<V*S8O-SO+YPHS-W=7,\LWRS_+3\HW-CLV/S=GRO-.0
MS9'-DLV3S>JVE,WQRI7-Y+?7\I;-E\V8S=CRVO+=\MORF<V:S=SRF\V<S9W-
MGLW1T='RG\W)S:#-S\ZIUD#.X_)!SMO#0L[@\D/.1,ZOP.SRWO)%SN'R1LY'
MSDC.Z/))SDK.2\Y,SN+R3<Y.SN?R3\Y0SN;R4<Y2SNGR4\Y4SE7.W_)6SE?.
MY/+J\EC.6<Y:SEO.7,Y=SE[.K-/E\O6R7\Y@SO+R8<ZKT&+.8\YDSF7.]?)F
MSF?.:,[(NVG.^?)JSFO.;,YMSF[.;\[P\G#.<<[V\OCR^O)RSG/.=,YUSG;.
M=\YXSGG.\_)ZSO'R>\Y\SGW.^[I^SONU@,Z!SH+.@\[O\O?R[?+N\H3.A<Z&
MSNORIO.'SJ/SB,Z)SJ+SBLZ+SO3RC,[:R(W.CLZ/SI#.D<[[\I+.D\Z4SJ7S
ME<Z6SI?.F,Z9SIK.F\[XPYS.G<Z>SI_.H,Y`ST'/0L_]\D//1,^G\ZGSI/-%
MS_SR1L]'STC/J_-)SZKS2L]+STS/3<_=PD[/3\^N\U#/4<^P\U+/4\]4SU7/
M5L^A\U?/6,]9S['SK/-:SUO/7,]=SU[/K_/^\JWS7\]@SV'/8L]CSV3/9<^R
M\V;/9\]HSVG/M/-JSVO/;,]MSZCS;L]OSW#/<<^S\W+/<\]TS[7S=<]VSW?/
M>,]YSWK/>\]\SWW/?L^WT(#/@<^"SX//N/.$SX7/AL^'S_G9B,^)SXK/B\^,
MSXW/N?..SX_/D,^1SY+/D\^4SY7/M_.6S^3(MO.7SYC/F<^:S[KSF\^<SYW/
MGL^?S[OSP+2@ST#00=!"T$/01-!%T$;01]!(T$G02M!+T$S03=##[D[03]!0
MT%'04M!3T+SS5-!5T+WS5M!7T%C0JM%9T%K06]"L],;07-!=T%[07]!@T&'0
MT-#<T6+08]!DT&709M!GT,[/:-!IT-:]:M##T6O0;-!MT&[0;]!PT''0XKKI
MX<+2PO&YLG+0<]#ML</Q=-#`R<2S==#RV7;0I<MWT,3Q>-!YT'K0>]#4UGS0
M?=!^T(#0@=#%\<#TQO&"T*S4Q_&#T,"PP?2$T(70PO2&T(?0_+2(T-O%B="*
MT(O0C-"[S(W0CM"/T.30D-"1T)+0D]"4T.#-E="6T)?0F-"9T,CQFM#SV9O0
MG-"=T)[0G]"@T+NQ0-&NST'10M%#T:2X1-%%T4;11]%(T<KQ2=%*T4O13-'+
M\4W13M%/T5#1P[+1P5'14M&PU\GQ4]%4T<SQ5=%6T5?16-'.\5G16M%;T?;9
M7-'ATJ/47=%>T</TN<A?T6#18=%BT6/1Q/1DT671S?'/\>._T/%FT6?1U/%H
MT6G1:M%KT6S1;=%NT=;QT?%OT=')X<5PT7'1<M'CPORY<]%TT=/Q=='5\7;1
M=]%XT=.Y>=%ZT7O1?-%]T7[1@-';\8'1@M&#T831A='6NH;1_;#9\8?1B-&)
MT8K1B]'8\=+QVO&,T8W1CM&/T9#1U_&1T9+1D]'LR)31E=&6T9?1RLW=\9C1
MF=&:T9O1O>6<T9W1GM'<\9_1WO&@T4#20=)"TD/21-)%TD;21])(TM_Q2=)*
MTN7/2]),TDW23M)/TE#24=)2TE/25-)5TE;25])8TEG26M);TES27=)>TE_2
M8-)ATF+28]+%]/.]9-)ETF;29])HTFG2X/%JTFO2;-)MTF[2;])PTG'2<M)S
MTG32==)VTG?2>-)YTGK2>])\TGW2X?%^TH#2@=+WSH+2JM*#TOOQA-*%TK*X
MAM*'THC2B=**THO2C-*-TH[2C]*0TI'2DM*3TI32E=*6TI?2F-*9TIK2F]*<
MTIW2GM*?TJ#20--!TT+30]-$TT731M-'TTC32=-*TTO33---TT[33]-0TU'3
M4M-3TU335=-6TU?36--9TUK36]-<TUW37M/[O-NY7]/FN=G#T\KHZL#`];[I
MZNKJZ^I@T^SJ[>KNZN_JQ[UATV+38]/[]6339=-FT_WU9]/^]6C3_/5ITVK3
M:]-LT^*];=.A]J6T;M-OTW#3<=.B]G+3<]-TTZ/V==-VTW?3LNQXTWG3>M-[
MTWS3?=-^TX#3@=."TX/3A-/4T873AM.'TXC3B=.*T^K9B].,TXW3CM./TY#3
MD=.2TY/3E-.5TY;3E].8TYG3FM.;TYS3G=.>TY_3H--`U$'40M1#U$341=1&
MU$?42-1)U$K42]1,U$W43M1/U%#44=12U%/45-15U%;45]18U%G46M1;U%S4
M7=1>U%_4I/9@U&'48M1CU&349=1FU&?4:-2Z[FG4:M1KU&S4;=1NU&_4<-1Q
MU'+4<]1TU'74=M1WU'C4>=1ZU'O4?-1]U'[4@-2!U(+4@]2$U(74AM2'U(C4
MB=2*U(O4C-2-U([4C]20U)'4DM23U)34E=26U)?4F-29U++5FM2;U)S4G=2>
MU)_4H-1`U4'50M5#U4351=5&U4?5_M/<S$C52=5*U4O53-5-U4[53]7$RE#5
M4=52U5/55-55U5;55]58U5G56M5;U5S57=5>U5_58-5AU6+58]5DU6759M5G
MU6C5:=5JU6O5;-5MU6[5;]5PU7'5<M5SU735==5VU7?5>-5YU7K5>]5\U7W5
M?M6`U8'5@M6#U835A=6&U8?5B-6)U8K5B]6,U8W5CM6/U9#5D=62U9/5E-65
MU9;5E]68U9G5FM6;U9S5G=6>U9_5H-5`UD'60M9#UD361=9&UD?62-9)UDK6
M2]9,UDW63M9/UE#64=92UE/65-95UE;65]98UEG66M9;UES67=9>UE_68-9A
MUF+6P.5CUF369=9FUF?6:-9IUFK6:]9LUFW6;M9OUG#6<=9RUG/6=-9UUG;6
M=]9XUGG6>M9[UGS6?=9^UH#6@=:E]H+6@]:$UH76AM:'UHC6B=:*UHO6C-:-
MUH[6C]:0UI'6DM:3UI36E=:6UI?6F-:9UIK6F]:<UIW6GM:?UJ#60-=!UT+7
M0]=$UT771M='UTC72==*UTO73-=-UT[73]=0UU'74M=3UU375==6UU?76-=9
MUUK76]=<UUW77M=?UZ^^8-=AUV+78]=DUZG&9==FUV?7:-=IUVK7:]=LUVW7
M;M=OUW#7<==RUW/7=-=UUW;7=]=XUWG7>M=[UWS7?==^UX#7@=>"UX/7A->%
MUX;7A]>(UXG7BM>+UXS7C=>.UX_7D->1UY+7D]>4UY77EM>7UYC7I=K&O*FV
MO+C/R*6\IMJGVM;,P\BHVOW&F=>UT>G2MM''O)K7LKWDNZG:JMK(T:O:[=#O
MMMO"F]?/R^VWZ,G#M_>^I-:LVJW:P,;GU[;*G->IU=_+[]6NVM_6RK2PVJ_:
MG=?KTK':LMJSVM3*M-JKRK7:MMK/L^_6M]JPNZZUN-JYVNZYK]'HTKK:P[CJ
MS^^RN]J\VI[7Z[W<SN_3O=KSSK[:U=/EN[_:M<O0R\#:Z\?NUL':M<7!ML+:
MS+?.O\/:Q-JMR\7:][7&VL+!N]?'VKC,G]?JTK'$R-K]M=&[R=JST,K:R]J]
MSLS:S=K.VO>RT=K/VNC1T-K5P]+:H-?3VM3:U=J[T*72^;#6VJO'U]KWO:'#
MV-K9VOW#M\S:VMO:OL#7QMS:W=JTQ][:W]K(N4#80=A"V$/81-A%V$;81]A(
MV.V[2=A*V$O83-BYMOCT3=CY]$[83]CCS5#84=A2V%/85-A5V%;85]BY]5C8
M6=A:V%O8X.M<V%W87MA?V&#88=CSS[^[8MACV&389=AFV&?8:-C`NJ74:=AJ
MV&O8;-AMV&[8;]C9X7#8<=ARV'/8]/6JL?*R=-AUV';8=]AXV'G8>MCU]7O8
M?-CW]7W8?MB`V-&Z]O6!V++#@MB#V(38A=B&V(?8B-CY]8G8BMB+V/CUC-B-
MV([8C]B0V)'8DMB3V)38E=B6V)?8F-B9V)K8F]B<V)W8GMB?V*#80-E!V4+9
M0]E$V4791ME'V4C92=E*V4O93-E-V4[93]E0V5'94ME3V5395=E6V5?96-E9
MV5K96]E<V5W97ME?V6#98=EBV6/99-EEV6;99]EHV6G9:MEKV6S9;=ENV6_9
M<-EQV7+9<]ETV779=MEWV7C9>=EZV7O9?-E]V7[9@-F!V8+9@]F$V879AMF'
MV8C9B=F*V8O9C-F-V8[9C]F0V9'9DMF3V939E=F6V9?9F-F9V9K9F]F<V9W9
MGMF?V:#90-I!VD+:0]I$VD7:1MI'VDC:2=I*VDO:3-I-VD[:M+'JU;JX3]JQ
MN<:R\-3-S]RPR]7UN\K6M[>PS+;&X;&ZN?S6X;FAM_J\VNK;ZOG,\[G<ZONT
ML\/1M]BZW>KTU-[JUKS?N]_JWL&XPM_4RM?@ZN'JY.KBZN/JWLFSN,2VY>KJ
MRLW)S;10VE':V>+BQ>;JM<!2VKC7Y^JLU_S(T]C-V-[44]KYU,3)KM/3N."S
M5-KBR?;T5=I6VE?:U;I8VO?T6=I:VM_76]I<VO'TL+C4U<^X\,9=VE[:7]I@
MVF':8MICVF3:9=K#LV;:9]KR]*RS:-IIVFK::]J]U/?';-IMVF[:;]IPVO3T
M<=IRVO/T<]ITVG7:=MIWVGC:>=IZVGO:?-K+S'W:?MJ`VJ3(@=J"VH/:A-J%
MVH;:A]J(VHG:BMJ+VHS:C=KU]([:X]>_Q<#UC]J0VKOUD=K#]9+:PO63VKK6
MP?64VI7:EMJ^U,3UE]K,]9C:F=J:VIO:S[#XM9S:R?7*]9W:W,6>VI_:H-I`
MV\7UQO5!VT+;Q_7+]4/;X+[(]?JX1-M%VT;;T/73]4?;2-M)V^>_2MORN;SU
MS?5+VTS;M\)-VT[;3]OXS%#;^;Q1V\[US_71]>6VTO52V]7U4]M4VU7;5MM7
MVUC;6=N]]5K;6]M<V]3UN]-=V^RS7MM?VZ3,8-MAVV+;8]O6]63;9=MFVV?;
M:-MIVVK;:]O7]>&^V/5LVVW;W\S;]6[;;]MPVW';<MO(LMG7<]O9]73;VO7<
M]77;XO5VVW?;>-O@]7G;>MM[V]_UW?5\VWW;X?5^VX#;WO7D]>7U@=OCS(+;
M@]N_Y;BUX_7H]:/,A-N%VX;;A]N(V^;UY_6)VXK;B]N,VXW;CMN^]8_;D-N1
MVY+;D]N4VY7;EMN7VYC;F=N:V\2QF]N<V[_UG=N>V\6UY+*?V^SUZ?6@V]>V
M0-SM]4'<ZO5"W$/<1-Q%W$;<Z_5'W$C<VK1)W.K42MQ+W$S<[O5-W/FS3MQ/
MW%#<4=Q2W%/<5-SO]?'U5=Q6W%?<\/58W%G<6MQ;W%S<7=Q>W/+U7]SS]6#<
M8=QBW&/<9-QEW&;<9]QHW&G<:MQKW.W)JKELW&W<^\=NW&_<X[9PW''<<MQS
MW'3<==QVW,G,=]QXW'G<>MQ[W'S<?=Q^W(#<@=R"W(/<A-R%W(;<A]R(W(G<
MBMRFZHO<C-R-W([<C]R0W)'<DMR3W)3<E=R6W)?<F-R9W)K<F]R<W)W<GMR?
MW*#<0-U!W4+=0]U$W47=1MU'W4C=2=U*W4O=3-U-W4[=3]U0W5'=4MU3W53=
M5=U6W5?=6-U9W5K=6]U<W5W=7MU?W6#=8=UBW6/=9-UEW6;=9]UHW6G=:MUK
MW6S=;=UNW6_=<-UQW7+=<]UTW77==MUWW7C=>=UZW7O=?-U]W7[=@-V!W8+=
M@]V$W87=AMV'W8C=B=V*W8O=C-V-W8[=C]V0W9'=DMV3W93=E=V6W9?=F-V9
MW9K=F]V<W9W=GMV?W:#=0-Y!WD+>0]Y$WD7>1MY'WDC>2=Y*WDO>3-Y-WD[>
M3]Y0WE'>4MY3WE3>5=Y6WE?>6-Y9WEK>6]Y<WEW>7MY?WF#>M;/^U.RY^=!A
MWNWIJM?NZ=;"[<CDNN_I\.GQZ>'6\NGSZ?7I].GVZ??IX<?XZ=C4^>G.O6+>
M^NG[Z<^]_.FHN+[!_>FRL=2[];G^Z6/>H>JBZJ/J^+>MO&3>Y,K.X*_4O<^W
MU:3JWM6EZL'0O+EEWL>TV;%FWF?>:-ZQP&G>:MYKWFS>YK'GL6W>Z+%NWF_>
M<-YQWKVSZ,ARWG/>=-YUWL'E=MYWWM^Q>-YYWGK>R<'OM'O>?-ZHQ]C3?=[Y
MQKC1?M[]N?7"@-Z!WH+>@]Z$WJW3A=[+U/R]AM["Y;6WP^6'WHC>N;OBU8G>
M^+VVU*7.K,'9LXK>B][VS(S>QN7$Y<CEC=[*Y<?ES[7(QH[>_+7%Y8_>]LJ0
MWI'>R>62WI/>E-[4P\6QH[R5WI;>E]ZWUYC>F=[+S<W+RLK3S,SER^7FQ)K>
MF]ZAT;?1S>6<WM#EG=ZXS?#6S^7=M9[>OLV?WM'ENK:@WD#?J,WDN4'?Q<K1
ML]G+[-32Y>JW0M]#WT3?SN5%WT;?1]](WTG?2M_5Y?ZTUN5+WTS?3=].WT_?
MT^74Y5#?W=)1WU+?W\+&L5/?XM-4WU7?W;;LRU;?U^57WUC?]M-9WUK?6]]<
MWUW?Z;%>W_2VVN78Y=GEP+5?WV#?8=_%TMSE8M]CW][E9-]EWV;?9]]HWVG?
MW>6RQVK?H])KWVS?V^5MWV[?;]]PW^+4VM5QWW+?<]]TWW7?X.7QUW;?=]]X
MWWG?>M][WWS?X>5]W]RQ^]%^W^+EY.6`WX'?@M^#W^/EA-^%W^7EAM^'WXC?
MB=^*W]C2B]_+M8S?W^>-W_7:CM_XVH_?]MJ0W_?:D=^2WY/?^MK/T,?$E-^5
MW^ZPEM^7WYC?L-"9W_G:FM_*TZJZHMOQQYO?_-K[VMO)_=J<WZ';WM?^VMK!
MG=^>WZ7;G]^@W_330.!!X*?;I-M"X*C;0^!$X+R]1>!&X$?@R<"CVZ;;H]9(
MX*G;2>!*X$O@K=M,X$W@3N"NVZS;PKI/X%#@4>"DOZO;4N!3X%3@JMO'U+^R
M5>!6X*_;5^#YN5C@L-M9X%K@6^!<X+NS7>!>X%_@IK5@X&'@8N!CX+RVL=MD
MX&7@9N#UMF?@LMMHX&G@:N!KX&S@;>!NX&_@<.!QX'+@<^!TX'7@=N!WX'C@
M>>!ZX'O@R;%\X'W@?N"`X+3;@>""X(/@L]NUVX3@A>"&X(?@B.")X(K@B^",
MX(W@CN"WVX_@MMN0X)'@DN"3X)3@E>"6X+C;E^"8X)G@FN";X)S@G>">X)_@
MN=N@X$#ANMM!X4+AS]/Z]/7'P]?DQ?ST_?3[]$/AQKY$X47A1N%'X>_02.%)
MX=.W2N%+X<W4JLQ,X4WAHO6A]:BZ_O36RT[A3^%0X:3UTL!1X>JS4N&JS:7U
MH_6TO:CU4^&I]<V]N,/AO^'+JO54X57A5N&F]:?U\,17X5CA6>%:X5OAK/5<
MX;RT7>'MUU[AU[2K]:[U7^%@X:WUK_71T&'A8N%CX63A9>%FX6?AT<.IR&CA
M:>%JX6OA;.%MX;#UL?5NX6_A<.%QX7+A<^&R]73A=>&S];3UM?5VX7?A>.%Y
MX;?UMO5ZX7OA?.%]X;CU?N&`X8'A@N&#X83AA>&&X8?AB.&)X8KAR;*+X=33
MS<J,X>_`V-:PTK_!C>'PO8[AC^&0X9'ADN&3X93AE>&6X9?AJKB8X9GAFN&;
MX9SAG>&>X9_AH.%`XD'B0N)#XD3B1>)&XD?B2.))XDKB2^),XDWB3N)/XE#B
M4>)2XE/B5.)5XE;B5^)8XEGB6N);XESB7>)>XE_B8.)AXF+B8^)DXF7B9N)G
MXFCB:>)JXFOB;.)MXF[B;^)PXG'B<N)SXG3B=>)VXG?B>.)YXGKB>^)\XGWB
M?N*`XH'B@N*#XH3BA>*&XH?BB.*)XHKBB^*,XHWBCN*/XI#BD>*2XI/BE.*5
MXI;BE^*8XIGBFN*;XISBG>*>XI_BH.)`XT'C0N-#XT3C1>-&XT?C2.-)XTKC
M2^-,XTWC3N-/XU#C4>-2XU/C5.-5XU;C5^-8XUGC6N-;XUSC7>->XU_C8.-A
MXV+C8^-DXV7C9N-GXVCC:>-JXVOC;.-MX_B\;N-OXW#C<>-RXW/C=.-UXW;C
M=^-XXWGC>N-[XWSC?>-^XX#C@>."XX/CA..%XX;CA^/&]HCCB>.*XXOCC..-
MXX[CC^.0XY'CDN.3XY3CE>.6XY?CF..9XYKCF^.<XYWCGN.?XZ#C0.1!Y$+D
M0^1$Y$7DQ_9&Y$?D2.1)Y$KD2^1,Y$WD3N1/Y%#D4>12Y%/D5.15Y%;D5^18
MY%GD6N1;Y%SD7>1>Y,CV7^1@Y&'D8N1CY&3D9>1FY&?D:.1IY&KD:^1LY&WD
M;N1OY'#D<>1RY'/D=.1UY';D=^1XY'GD>N1[Y'SD?>1^Y(#D@>2"Y(/DA.2%
MY(;DA^2(Y(GDBN2+Y(SDC>2.Y(_DD.21Y)+DD^24Y)7DEN27Y)CDF>2:Y)OD
MG.2=Y)[DG^2@Y$#E0>5"Y4/E1.5%Y4;E1^5(Y4GE2N5+Y4SE3>5.Y4_E4.51
MY5+E4^54Y57E5N57Y5CE6>5:Y5OE7.5=Y5[E7^5@Y6'E8N5CY63E9>5FY6?E
M:.5IY6KE:^5LY6WE;N5OY7#E<>5RY7/ER?9TY77E=N5WY7CE>>5ZY7OE?.5]
MY7[E@.6!Y8+E@^6$Y87EAN6'Y8CEB>6*Y8OEC.6-Y8[EC^60Y9'EDN63Y93E
ME>66Y9?EF.69Y9KEF^6<Y9WEGN6?Y<KVH.5`YD'F0N9#YD3F1>9&YD?F2.9)
MYDKF2^9,YDWF3N9/YE#F4>92YE/F5.95YE;F5^98YEGF6N9;YESF7>9>YE_F
M8.9AYF+FS/9CYF3F9>9FYF?F:.9IYFKF:^9LYFWF;N9OYG#F<>9RYG/F=.9U
MYG;F=^9XYGGF>N9[YGSF?>9^YH#F@>:"YH/FA.:%YH;FA^:(YHGFBN:+YHSF
MC>:.YH_FD.:1YI+FD^:4YI7FEN:7YICFF>::YIOFG.:=YLOVGN:?YJ#F0.=!
MYT+G0^=$YT7G1N='Y^GW2.=)YTKG2^=,YTWG3N=/YU#G4>=2YU/G5.=5YU;G
M5^=8YUGG6N=;YUSG7>=>YU_G8.=AYV+G8^=DYV7G9N=GYVCG:>=JYVOG;.=M
MYV[G;^=PYW'G<N=SYW3G=>=VYW?G>.=YYWKG>^=\YWWG?N>`YX'G@N>#YX3G
MA>>&YX?GB.>)YXKGB^>,YXWGCN>/YY#GD>>2YY/GE.>5YY;GE^>8YYGGFN>;
MYYSGG>>>YY_GH.=`Z$'H0NA#Z$3H1>A&Z$?H2.A)Z$KH2^A,Z$WH3NC-]D_H
M4.A1Z%+H4^A4Z%7H5NA7Z%CH6>A:Z%OH7.A=Z%[H7^A@Z&'H8NACZ&3H9>AF
MZ&?H:.AIZ&KH:^ALZ&WH;NAOZ'#H<>ARZ'/H=.AUZ';H=^AXZ'GH>NC.]GOH
M?.A]Z'[H@.B!Z(+H@^B$Z(7HANB'Z(CHB>B*Z(OHC.B-Z([HC^B0Z)'HDNB3
MZ)3HQ.[%[L;NZ]6DMLCNQ^[)[LKNI<?+[LSNE>BPM_:US>[/[I;HSNZ7Z,:X
MT.[1[M+NV[:NL]/6QL2UL=:XT^[4[K_4U<?[OMG.L[G6[M7NV.[7[J7%V>[:
M[J['V^ZOQ]SNI[+=[M[NW^[@[N'NZM?B[N/NV+SD[LO3^LRLLN7!Y>ZFQZW#
MF.CF[N?NZ.[I[NKNZ^[L[IGH[>[N[N_NFNB;Z/#N\>[R[O3N\^Z<Z/7NK<W!
MPO;N]^[X[J'5^>ZSS_KN^^Z=Z/SN_>ZA[_[NHN_UN/K#H^^D[\*]O]+YLJ7O
MIN^G[_C2J._]UJGOS,:>Z*KOJ^^TP:SO^L_XRZ[OK>_ZL_BYK^^P[^+0L>^R
M[^:WO]"S[[3OM>_QR.#,MN^W[[CON>^Z[^#5N^_MM*K#O.^?Z+WOON^_[Z#H
M_<[`[^#"N+2VU_6]0.G'S\/OP>_"[\3OI[;\O.*^S,/%[\;O0>G'[\_OR._)
M[\KOPL?Q[\VVR^]"Z<SOS>_&MK[#SN]#Z=#OT>_2[_+51.G3[_?$1>G4[_C$
MU>_6[^2X][#7[]COV>]&Z=KOV^_<[]WO1^G>[[6^X>_?[^#O2.GB[^/OS<'D
M[^7OYN_G[^COZ>_J[^OO[._8P$GI[>^MP>[O[^_P[TKI2^GBSTSI3>E.Z4_I
M4.E1Z5+I4^FDLU3I5>E6Z5?I6.E9Z5KI6^E<Z5WI7NE?Z6#I8>EBZ6/I9.EE
MZ6;I9^EHZ6GI:NEKZ6SI;>ENZ6_I<.EQZ7+I<^ETZ77I=NEWZ7CI>>EZZ7OI
M?.E]Z7[I@.F!Z8+I@^F$Z87IANF'Z8CIB>F*Z8OIC.F-Z8[IC^F0Z9'IDNF3
MZ93IE>F6Z9?IF.F9Z9KIF^F<Z9WIGNF?Z:#I0.I!ZD+J0^I$ZD7J1NI'ZDCJ
M2>I*ZDOJ3.I-ZD[J3^I0ZE'J4NI3ZE3J5>I6ZE?J6.I9ZEKJ6^K%P\7CP<G&
MXUSJU;'*SK.T\LC'X]#/R./DO,GCRN/&PZ+5UL3KN<7.R^/VP\SC7>JGM_.X
MTKK-X\[CQ-3/XU[JT./+T='CTN/3X]3CUM'5X_NRN\#6XU_JJ\#7X]CCV>-@
MZMKCV^-AZK>XXMIBZM.V8^KDVN/:9.IEZF;J9^IHZFGJ:NKFVFOJ;.IMZN[(
M;NIOZN7:P+?TT?72\]77O7#J<>IRZG/JZ-?HVN?:=.JBL-/-=>KIVG;JO;C*
MO+W"I,+"L^K:=^JJPK#$M;UXZGGJWL]ZZGOJ?.KKVL+)?>I^ZH#J@>J"ZMVQ
M@^J$ZH7J[-J&ZKBVNM2'ZOVSB.J)ZNW:R=35S^/%BNKNVHOJC.J-ZH[JC^KO
MVI#J\-KJP=7,W<^1ZI+JD^J4ZI7JENJ7ZICJF>J:ZIOJG.J=ZN?3H<*>ZO':
MG^J@ZN7+0.ORVD'KYLO^TD+K0^M$Z_2X1>M&Z_/:K["VST?K2.O/U4GK2NM+
MZTSK3>M.ZT_K4.M1ZU+K[<M3ZU3K5>M6ZU?K6.M9ZUKK]-I;ZUSKQ.-=ZU[K
MI<%?ZV#KO_9AZV+KP/;!]M'$8^NXR./19.MEZ]O0Q=&OO,VY9NOT[V?K:.O&
MM+K3PO;[LVGK:NO#]FOK;.OQM6WK;NMOZW#K<>MRZW/K=.MUZW;KQ?9WZWCK
M>>MZZWOK?.M]Z^K3I_:IT7[K@.N!ZX+KJ?:#ZX3KA>NH]H;KA^OCP=?`B.NB
ML8GKBNN+ZXSK[<Z-Z^C0J_:.ZX_K]L^0ZZKV\-6L]KG#D>N2ZY/K]+NN]JWV
ME.N5ZY;KWL27ZYCKV,&9ZYKKF^N<ZYWKJLN>Z[S/G^N@ZT#L0>Q"[$/L1.Q%
M[$;L1^Q([*_V2>Q*[+#V2^Q,[+'V3>RVPD[L3^Q0[%'L4NS4L/G%4^Q4[%7L
M5NRR]E?L6.Q9[%KL6^Q<[%WL7NQ?[&#L8>QB[&/L9.QE[&;L9^QH[&GLX,>F
M]FKL:^RXOFSL;>RROF[LY;5O['#LQ[=Q[+^_TL/FPW+L<^S,V'3L=>QV[.^X
M=^QX['GL>NQ[['SL?>Q^[(#L^;VET8'LT+""[(/LA.R%[(;LL/>'[(CLB>R*
M[(OLC.R-[([LL?>/[)#LD>R2[)/LK-"4[+"PE>R6[)?LLO>S]YCLM/>9[)KL
MF^S*QYSLG>R>[)_LH.Q`[4'MS[Y"[4/MM_=$[47M1NU'[4CM2>U*[;;W2^W>
ML4SMM?=-[4[MN/=/[;GW4.U1[5+M4^U4[57M5NU7[5CM6>U:[5OM7.U=[5[M
M7^U@[6'M8NUC[63M9>UF[6?M:.UI[6KM:^UL[6WM;NUO[7#M<>UR[7/M=.UU
M[7;M=^UX[7GM>NU[[7SM?>U^[8#M@>VDSLW(@NVKNKCHN>BZZ,*^@^V$[87M
MANV'[?32B.W/U-C)B>V*[8OMC.V-[8[MC^V0[9'MDNV3[93ME>V6[9?MF.V9
M[9KMF^V<[9WMGNV?[:#M0.Y![D+N0^Y$[D7N1NY'[DCN2>Y*[DON3.Y-[D[N
M3^Y0[E'N4NY3[E3N5>Y6[E?N6.Y9[EKN6^Y<[EWN7NY?[F#N8>YB[F/N9.YE
M[F;N9^YH[FGN:NYK[FSN;>YN[F_N<.YQ[G+N<^YT[G7N=NYW[GCN>>YZ[GON
M?.Y][G[N@.Z![H+N@^Z$[H7NANZ'[HCNB>Z*[HONC.Z-[H[NC^Z0[I'NDNZ3
M[I3NE>Z6[I?NF.Z9[IKNF^Z<[IWNGNZ?[J#N0.]![T+O0^]$[T7OL]*EMNK'
M_/'NS[/+Z]#OY^?-R[G9MOWQY+#,R_[QI-2MPNS!Q,:QOJ'RU;Q&[Z+RH_)'
M[Z3RP]*UQDCOQ\VE\DGOL=/%O^+,2N^F\J?RU='NMJCRJ?+?M:KRJ_)+[_RR
MK/*M\J?(3.]-[T[O3^]0[U'O4N]3[U3O5>]6[U?O6.]9[UKO6^]<[UWO7N]?
M[V#O8>]B[V/O9.]E[V;O9^]H[VGO:N]K[VSO;>]N[V_O<.]Q[^>W<N]S[ZGL
MJNRK['3OK.QU[W;OKL:M[*[L=^]X[WGOR;>SRGKO>^]\[WWO?N^`[X'ON.+/
M]X+O@^^$[X7OAN^'[XCOB>^*[XOOC.^-[X[OC^^0[Y'ODN^3[Y3OE>^6[Y?O
MF.^9[YKOF^^<[YWOGN^?[Z#O0/!!\$+P0_!$\-#W1?!&\,VR1_!(\$GP2O!+
M\$SP3?!.\$_P4/!1\%+P4_!4\%7P5O!7\%CP6?!:\%OP7/!=\%[P7_!@\&'P
M8O!C\-'W9/!E\&;P9_!H\&GP:O!K\&SP;?!N\&_P</!Q\'+P<_!T\'7P=O!W
M\'CP>?!Z\'OP?/!]\'[P@/"!\(+P@_"$\(7PAO"'\(CPB?#3]]+WBO"+\(SP
MC?".\(_PD/"1\)+PD_"4\)7PEO"[XI?PHKR8\+SBO>*^XK_BP.+!XKFW^]*D
MO<[*I;''RYGPPN+\ML3(P^*:\)OPR+V<\/VQQ.*=\/:VQ>+9Q)[PG_#&XMK/
MW;G'XJ'`H/#(XO:R0/')XD'Q\\'*XLOB^,+,XLWBSN+7RKC8Y=GCST+Q0_%$
M\47Q1O%'\4CQ2?%*\4OQ3/&E\$WQ3O&PW$_Q4/%1\5+Q4_%4\57Q5O%7\5CQ
M6?%:\5OQ7/%=\5[Q7_%@\6'Q8O%C\63Q9?%F\6?Q:/%I\6KQ:_%L\6WQ;O%O
M\7#Q<?%R\7/Q=/%U\7;Q=_%X\7GQ>O%[\7SQ??%^\8#Q@?&"\8/QA/&%\8;Q
MA_&(\8GQBO&+\8SQC?&.\8_QD/&1\9+QD_&4\97QEO&7\9CQF?&:\9OQG/&=
M\9[QG_&@\4#R0?)"\D/R1/)%\D;R1_)(\DGR2O)+\DSR3?).\D_R4/)1\E+R
M4_)4\E7R5O)7\ECR6?):\EOR7/)=\E[R7_)@\F'R8O)C\F3R9?)F\F?R:/)I
M\FKR:_)L\FWR;O)O\G#R<?)R\G/R=/)U\G;R=_)X\GGR>O)[\GSR??)^\H#R
M@?*"\H/RA/*%\H;RA_*(\HGRBO*+\HSRC?*.\H_RD/*1\I+RD_*4\I7REO*7
M\ICRF?*:\IORG/*=\I[RG_*@\D#S0?-"\T/S1/-%\T;S1_-(\TGS2O-+\TSS
M3?-.\T_S4/-1\^W"IM34S;'1V[/]QU+SM;*_PN#FN\KAYN+FU+[CYJ37U<WE
MYMV\Y.;FYN?F[L)3\[Z]Z.;FPJ>ZZ>94\^KFTK/IT57S5O.EO^OF[\;LYNWF
M5_-8\^[FK<;OYEGSI\GPYO'F\N:YY?/F].;BPO7F]N;HUO?F6O/XYL>Y6_-<
M\UWS7O-?\V#S8?.[][KW8O-C\V3S9?.^][SWH;IF\[_W9_/`]VCS:?-J\\+W
MP??$]VOS;//#]VWS;O-O\W#S<?/%]\;W<O-S\W3S=?/']W;SZ,MW\WCS>?-Z
M\]^X>_-\\WWS?O.`\X'SU/>"\]7W@_.$\X7SAO/6]X?SB/.)\XKSV/>+\]KW
MC//7]XWSCO./\Y#SD?.2\Y/SE/.5\]OWEO/9]Y?SF/.9\YKSF_.<\YWSU]>>
M\Y_SH/-`]-SW0?1"]$/T1/1%]$;TW?=']$CT2?3>]TKT2_1,]$WT3O1/]%#T
M4?12]%/T5/3?]U7T5O17].#W6/19]%KT6_1<]%WT7O1?]&#T8?1B],O;8_1D
M]*K89?1F]&?T:/1I]&KT:_1L]/?E[;EM]&[T;_1P]/V_ZKO)]\?&R/=Q],KW
MS/?+]W+T<_1T],WW=?2ZSG;TSO=W]'CTI\1Y]'KT>_1\]'WT?O2`]('T@O2#
M](3TA?2&](?TB/2)](KTB_2,](WTCO2/])#TD?22])/TE/25]);TE_28])GT
MFO2;])STG?2>])_TH/1`]4'U0O5#]43U1?5&]4?U2/5)]4KU2_5,]4WU3O5/
M]5#U4?52]5/U5/55]5;U5_58]5GU6O5;]5SU7?5>]5_U8/5A]6+U8_5D]67U
M9O5G]6CU:?5J]6OU;/5M]6[U;_5P]7'U<O5S]73U=?5V]7?U>/5Y]7KU>_5\
M]7WU?O6`]8'U@O6#]83UA?6&]8?UB/6)]8KUB_6,]8WUCO6/]9#UD?62]9/U
ME/65]9;UE_68]9GUFO6;]9SUG?6>]9_UH/5`]D'V0O9#]D3V1?9&]D?V2/9)
M]DKV2_9,]DWV3O9/]E#V4?92]E/V5/95]E;V5_98]EGV6O9;]ESV7?9>]E_V
M8/9A]F+V8_9D]F7V9O9G]FCV:?9J]FOV;/9M]F[V;_9P]G'V<O9S]G3V=?9V
M]G?V>/9Y]GKV>_9\]GWV?O:`]H'V@O:#]H3VA?:&]H?VB/:)]HKVB_:,]HWV
MCO:/]I#VD?:2]I/VE/:5]I;VE_:8]IGVFO:;]ISVG?:>]I_VH/9`]T'W0O=#
M]T3W1?=&]T?W2/=)]TKW2_=,]TWW3O=/]U#W4?=2]U/W5/=5]U;W5_=8]UGW
M6O=;]USW7?=>]U_W8/=A]V+W8_=D]V7W9O=G]VCW:?=J]VOW;/=M]V[W;_=P
M]W'W<O=S]W3W=?=V]W?W>/=Y]WKW>_=\]WWW?O>`]^/3@?>"]\_V@_>SPM#V
MA/>%]]'VTO;3]M3VAO>']];VB/>KL=?VB??8]MGVVO:*]]OVW/:+]XSWC?>.
M]]WVWO;*SX_WW_;@]N'VXO;C]N3V\,#E]N;VY_;H]NGVD/?J]I'WZ_;L]I+W
M[?;N]N_V\/;Q]O+V\_;T]JB^D_?U]O;V]_;X]I3WE?>6]Y?WF/?ZR/GV^O;[
M]OSVF?>:]_WV_O:A]Z+WH_>D]Z7WF_><]Z;WI_>H]^ZQJ?>J]ZOWG?>>]ZSW
MK??;P:[WG_>@]Z_W0/A!^$+X0_A$^$7X1OA'^$CX2?A*^$OX3/A-^$[X3_A0
M^%'X4OA3^%3X5?A6^%?X6/A9^%KX6_A<^%WX7OA?^&#X8?AB^&/X9/AE^&;X
M9_AH^&GX:OAK^&SX;?AN^&_X</AQ^'+X<_AT^'7X=OAW^'CX>?AZ^'OX?/A]
M^'[X@/B!^(+X@_B$^(7XAOB'^(CXB?B*^(OXC/B-^([XC_B0^)'XDOB3^)3X
ME?B6^)?XF/B9^)KXF_B<^)WXGOB?^*#X0/E!^4+Y0_E$^47Y1OE'^4CY2?E*
M^4OY3/E-^4[Y3_E0^5'Y4OE3^53Y5?E6^5?Y6/E9^5KY6_E<^5WY7OE?^6#Y
M8?EB^6/Y9/EE^6;Y9_EH^6GY:OEK^6SY;?EN^6_Y</EQ^7+Y<_ET^77Y=OEW
M^7CY>?EZ^7OY?/E]^7[Y@/F!^8+Y@_F$^87YAOF'^8CYB?F*^8OYC/F-^8[Y
MC_F0^9'YDOF3^93YE?F6^9?YF/F9^9KYF_F<^9WYGOF?^:#Y0/I!^D+Z0_I$
M^D7Z1OI'^DCZ2?I*^DOZ3/I-^D[Z3_I0^E'Z4OI3^E3Z5?I6^E?Z6/I9^EKZ
M6_I<^EWZ7OI?^F#Z8?IB^F/Z9/IE^F;Z9_IH^FGZ:OIK^FSZ;?IN^F_Z</IQ
M^G+Z<_IT^G7Z=OIW^GCZ>?IZ^GOZ?/I]^G[Z@/J!^H+Z@_J$^H7ZAOJ'^HCZ
MB?J*^HOZC/J-^H[ZC_J0^I'ZDOJ3^I3ZE?J6^I?ZF/J9^IKZF_J<^IWZGOJ?
M^J#Z0/M!^T+[0_M$^T7[1OM'^TC[2?M*^TO[3/M-^T[[3_M0^U'[4OM3^U3[
M5?M6^U?[6/M9^UK[6_OQQ*_PIKRP\/G#7/NXQ;O17?NQ\++PL_"T\+7PO-%>
M^^S17_NW\+;PI]1@^]+-N/"Z\+GPN_"\\&'[8OOKN+WPZ+IC^[[PO_#IOL#P
M[+;!\,+PP_#$\+7(Q?#&\&3[Q_#TQ67[R/!F^V?[:/O)\&G[RO"]]VK[R_#,
M\,WP:_O.\&S[;?MN^V_[S_#7NG#[T/#1\-+PT_#4\-7PUO#8\''[<ONET]?P
M<_O9\'3[=?MV^W?[>/MY^WK[>_M\^WW[NO6YPG[[@/OD]X'[@ON#^X3[Y??F
M]X7[AOOG]X?[B/N)^XK[B_N,^^CWM,*-^X[[C_N0^Y'[DON3^Y3[E?OJ]Y;[
MZ_>7^YC[F?N:^YO[G/OSPIW[GON?^Z#[0/Q!_$+\0_Q$_$7\1OQ'_$C\\/1)
M_$K\2_SO]$S\3?SIPD[\X??B]T_\4/Q1_%+\4_S&NU3\5?Q6_%?\Y-E8_%G\
M6OSRRNC`I/!;_-JZ7/Q=_*W'7OQ?_&#\K,1A_&+\[/?M]^[W8_SP]^_W9/SQ
M]V7\9OST]V?\\_=H_/+W]?=I_&K\:_QL_/;W;?QN_&_\</QQ_'+\<_QT_'7\
MZ>UV_.KMZ^UW_+SV>/QY_'K\>_Q\_'W\?OR`_('\@OR#_(3\O?:%_+[VIK:&
M_+[8A_R(_,2YB?R*_(O\N]B,_+'<C?R._(_\D/R1_)+\\\J3_/?WE/R5_);\
ME_R8_)G\FOR;_)S\^/>=_)[\^?>?_*#\0/U!_4+]0_U$_?OW1?WZ]T;]Q[%'
M_?SW_?=(_4G]2OU+_4S]_O=-_4[]3_U0_5']4OU3_53]5?U6_5?]Z\:T[%C]
M6?U:_5O]7/U=_5[]7_U@_6']8OUC_63]9?UF_6?]:/UI_6K]:_UL_6W];OUO
M_7#]<?UR_7/]=/UU_7;]=_UX_7G]>OU[_7S]??U^_8#]@?V"_8/]A/V%_=VS
ML_:&_8?]M/;DP;7VMO:W]KCVN?:Z]J/(N_:(_8G]BOV+_8S]C?V._8_]D/V1
M_9+]D_WZP:BYZ.V4_97]EOWJN=_9E_V8_9G]FOV;_0``````````````````
M````````2JE+J0```````````````````````````````$RI3:E.J0````!/
MJ0``````````````````````````````````````````````````````````
M````````````````````````````````4*D```````````````````````!1
MJ0````!2J5.I`````%2I`````````````````````.6BYJ+GHNBBZ:+JHNNB
M[*+MHNZB``````````````````!:J0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!)J0``````````````````````````
M`````*&AHJ&CH:BA``"IH66IEJFTH;6AMJ&WH;BAN:&ZH;NAOJ&_H9.H_J&R
MH;.AO*&]H0````````````"4J)6H`````$"I0:E"J4.I1*E%J4:I1ZE(J0``
M``````````````````````````````````````````````````````````"A
MI**DHZ2DI*6DIJ2GI*BDJ:2JI*NDK*2MI*ZDKZ2PI+&DLJ2SI+2DM:2VI+>D
MN*2YI+JDNZ2\I+VDOJ2_I,"DP:3"I,.DQ*3%I,:DQZ3(I,FDRJ3+I,RDS:3.
MI,^DT*31I-*DTZ34I-6DUJ37I-BDV:3:I-NDW*3=I-ZDWZ3@I.&DXJ3CI.2D
MY:3FI.>DZ*3II.JDZZ3LI.VD[J3OI/"D\:3RI/.D``````````````````!A
MJ6*I9JEGJ0````"AI:*EHZ6DI:6EIJ6GI:BEJ:6JI:NEK*6MI:ZEKZ6PI;&E
MLJ6SI;2EM:6VI;>EN*6YI;JENZ6\I;VEOJ6_I<"EP:7"I<.EQ*7%I<:EQZ7(
MI<FERJ7+I<RES:7.I<^ET*71I=*ETZ74I=6EUJ77I=BEV:7:I=NEW*7=I=ZE
MWZ7@I>&EXJ7CI>2EY:7FI>>EZ*7II>JEZZ7LI>VE[J7OI?"E\:7RI?.E]*7U
MI?:E`````````````&"I8ZEDJ0```````````````,6HQJC'J,BHR:C*J,NH
MS*C-J,ZHSZC0J-&HTJC3J-2HU:C6J->HV*C9J-JHVZC<J-VHWJC?J."HX:CB
MJ..HY*CEJ.:HYZCHJ.FH````````````````V:+:HMNBW*+=HMZBWZ+@HN&B
MXJ(``````````````````````````,6BQJ+'HLBBR:+*HLNBS*+-HLZBSZ+0
MHM&BTJ+3HM2BU:+6HM>BV**QHK*BLZ*THK6BMJ*WHKBBN:*ZHKNBO**]HKZB
MOZ+`HL&BPJ+#HL2B````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"DJ:6IIJFGJ:BIJ:FJ
MJ:NIK*FMJ:ZIKZFPJ;&ILJFSJ;2IM:FVJ;>IN*FYJ;JINZF\J;VIOJF_J<"I
MP:G"J<.IQ*G%J<:IQZG(J<FIRJG+J<RIS:G.J<^IT*G1J=*ITZG4J=6IUJG7
MJ=BIV:G:J=NIW*G=J=ZIWZG@J>&IXJGCJ>2IY:GFJ>>IZ*GIJ>JIZZGLJ>VI
M[JGOJ0``````````5*A5J%:H5ZA8J%FH6JA;J%RH7:A>J%^H8*AAJ&*H8ZAD
MJ&6H9JAGJ&BH::AJJ&NH;*AMJ&ZH;ZAPJ'&H<JASJ'2H=:AVJ'>H````````
M``````````````````````````!XJ'FH>JA[J'RH?:A^J("H@:B"J(.HA*B%
MJ(:HAZ@```````"(J(FHBJ@``````````````````````````/:A]:$`````
M`````````````````````````````````````/BA]Z$`````````````````
M````BZB,J`````````````````````#TH?.A````````\*$`````\J'QH0``
M`````````````````````````````````````````````(VHCJB/J)"H````
M````````````````````````````````````````````````````````````
M``````````````````#OH>ZA`````)&H````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````XJ$`
M`.&A``````````````````````````````````!<J0````!#J*JA1*BLH0``
MKJ&OH0````"PH;&A``````````````````!%J*VA````````````````````
M````ZZ$``.2AY:$``$:H`````````````/FA````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#FH0``1Z@```````!(J```````````````
M`````````````````.VA``````````````````````````!9J0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#QHO*B\Z+THO6B]J+WHOBB^:+Z
MHONB_*(``````````*&BHJ*CHJ2BI:*FHJ>BJ**IHJJB````````````````
M``````````````````````````````````````````#[H?RA^J']H0````!)
MJ$JH2ZA,J```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#*H0```````````````,>A``#&H0```````$VH``````````#,H0````#8
MH=ZA3JC/H0````!/J```SJ$``,2AQ:')H<BATJ$`````TZ$`````````````
MX*'?H<.ARZ$`````````````UZ$``````````````````````````-:A````
M````U:$`````````````4*@``````````````````````````````````-FA
MU*$`````W*'=H5&H4J@```````````````#:H=NA````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"2J````````-&A````````````````````````````
M`,VA````````````````````````````````````````````````````````
M``````````!3J```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````T*$`````
M`````````````````````````````.BA`````.RAIZ$`````````````````
M`..AP*$`````````````I*$`````````````````````````````````````
M`````````````````````````````````````````````,&A````````````
M`````````*2HHJ@```````````````"HJ*:HNJ@``*RHJJ@``````````+"H
MKJ@```````#"H0``M*BRJ```N:@``````````*&H````````````````````
M`````````````````````````*6H``````````````````"GJ```````````
M`````````````````````````````*FH````````````````````````````
M````````````````````````````````````O:@```````"^J```````````
MK:@`````````````````````````````````````````````````````````
M````````````````````L:@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````HZ@``*NH``"OJ```
MLZ@``+6H``"VJ```MZ@``+BH````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````+NH````````````````````````
M````````````````P*@`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````IJ$``*6A0*A!
MJ```````````````````````````````````0J@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"AIJ*FHZ:DIJ6F
MIJ:GIJBFJ::JIJNFK*:MIJZFKZ:PIK&F``"RIK.FM*:UIK:FMZ:XI@``````
M````````````P:;"IL.FQ*;%IL:FQZ;(ILFFRJ;+ILRFS:;.IL^FT*;1I@``
MTJ;3IM2FU:;6IM>FV*8`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````*>G````````````
M`````````````````````````*&GHJ>CIZ2GI:>FIZBGJ:>JIZNGK*>MIZZG
MKZ>PI[&GLJ>SI[2GM:>VI[>GN*>YI[JGNZ>\I[VGOJ>_I\"GP:?1I]*GTZ?4
MI]6GUJ?8I]FGVJ?;I]RGW:?>I]^GX*?AI^*GXZ?DI^6GYJ?GI^BGZ:?JI^NG
M[*?MI^ZG[Z?PI_&G``#7IP`````"3@1.!4X&3@].$DX73A].($XA3B-.)DXI
M3BY.+TXQ3C-.-4XW3CQ.0$Y!3D).1$Y&3DI.44Y53E=.6DY;3F).8TYD3F5.
M9TYH3FI.:TYL3FU.;DYO3G).=$YU3G9.=TYX3GE.>DY[3GQ.?4Y_3H!.@4Z"
M3H-.A$Z%3H=.BDX``)!.EDZ73IE.G$Z=3IY.HTZJ3J].L$ZQ3K1.MDZW3KA.
MN4Z\3KU.OD[(3LQ.ST[03M).VD[;3MQ.X$[B3N9.YT[I3NU.[D[O3O%.]$[X
M3OE.^D[\3OY.`$\"3P-/!$\%3P9/!T\(3PM/#$\23Q-/%$\53Q9/'$\=3R%/
M(T\H3RE/+$\M3RY/,4\S3S5/-T\Y3SM//D\_3T!/04]"3T1/14]'3TA/24]*
M3TM/3$]23U1/5D]A3V)/9D]H3VI/:T]M3VY/<4]R3W5/=T]X3WE/>D]]3X!/
M@4^"3X5/AD^'3XI/C$^.3Y!/DD^33Y5/ED^83YE/FD^<3YY/GT^A3Z)/````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````*1/JT^M3[!/
ML4^R3[-/M$^V3[=/N$^Y3[I/NT^\3[U/OD_`3\%/PD_&3\=/R$_)3\M/S$_-
M3])/TT_43]5/UD_93]M/X$_B3^1/Y4_G3^M/[$_P3_)/]$_U3_9/]T_Y3_M/
M_$_]3_]/`%`!4`)0`U`$4`50!E`'4`A0"5`*4```"U`.4!!0$5`34!50%E`7
M4!M0'5`>4"!0(E`C4"10)U`K4"]0,%`Q4#)0,U`T4#50-E`W4#A0.5`[4#U0
M/U!`4$%00E!$4$501E!)4$I02U!-4%!045!24%-05%!64%=06%!94%M075!>
M4%]08%!A4&)08U!D4&909U!H4&E0:E!K4&U0;E!O4'!0<5!R4'-0=%!U4'A0
M>5!Z4'Q0?5"!4()0@U"$4(90AU")4(I0BU",4(Y0CU"04)%0DE"34)10E5"6
M4)=0F%"94)I0FU"<4)U0GE"?4*!0H5"B4*10IE"J4*M0K5"N4*]0L%"Q4+-0
MM%"U4+90MU"X4+E0O%``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````O5"^4+]0P%#!4,)0PU#$4,50QE#'4,A0R5#*4,M0S%#-4,Y0
MT%#14-)0TU#44-50UU#84-E0VU#<4-U0WE#?4.!0X5#B4.-0Y%#E4.A0Z5#J
M4.M0[U#P4/%0\E#T4/90]U#X4/E0^E#\4/U0_E#_4`!1`5$"40-1!%$%40A1
M```)40I1#%$-40Y1#U$041%1$U$44151%E$741A1&5$:41M1'%$=41Y1'U$@
M42)1(U$D4251)E$G42A1*5$J42M1+%$M42Y1+U$P43%1,E$S4311-5$V43=1
M.%$Y43I1.U$\43U1/E%"44=12E%,44Y13U%045)14U%745A165%;45U17E%?
M46!185%C46119E%G46E1:E%O47)1>E%^47]1@U&$4891AU&*48M1CE&/49!1
MD5&34911F%&:49U1GE&?4:%1HU&F4:=1J%&I4:I1K5&N4;11N%&Y4;I1OE&_
M4<%1PE'#4<51R%'*4<U1SE'04=)1TU'44=51UE'740``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#84=E1VE'<4=Y1WU'B4>-1Y5'F
M4>=1Z%'I4>I1[%'N4?%1\E'T4?=1_E$$4@52"5(+4@Q2#U(04A-2%%(54AQ2
M'E(?4B%2(E(C4B52)E(G4BI2+%(O4C%2,E(T4C52/%(^4D1215)&4D=22%))
M4DM23E)/4E)24U)54E=26%(``%E26E);4EU27U)@4F)28U)D4F92:%)K4FQ2
M;5)N4G!2<5)S4G12=5)V4G=2>%)Y4GI2>U)\4GY2@%*#4H12A5*&4H=2B5**
M4HM2C%*-4HY2CU*14I)2E%*54I92EU*84IE2FE*<4J12I5*F4J=2KE*O4K!2
MM%*U4K92MU*X4KE2NE*[4KQ2O5+`4L%2PE+$4L52QE+(4LI2S%+-4LY2SU+1
M4M-2U%+54M=2V5+:4MM2W%+=4MY2X%+A4N)2XU+E4N92YU+H4NE2ZE+K4NQ2
M[5+N4N]2\5+R4O-2]%+U4O92]U+X4OM2_%+]4@%3`E,#4P13!U,)4PI3"U,,
M4PY3````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````!%3
M$E,34Q13&%,;4QQ3'E,?4R)3)%,E4R=3*%,I4RM3+%,M4R]3,%,Q4S)3,U,T
M4S53-E,W4SA3/%,]4T!30E-$4T932U-,4TU34%-44UA365-;4UU395-H4VI3
M;%-M4W)3=E-Y4WM3?%-]4WY3@%.!4X-3AU.(4XI3CE./4P``D%.14Y)3DU.4
M4Y93EU.94YM3G%.>4Z!3H5.D4Z=3JE.K4ZQ3K5.O4[!3L5.R4[-3M%.U4[=3
MN%.Y4[I3O%.]4[Y3P%/#4\13Q5/&4\=3SE//4]!3TE/34]53VE/<4]U3WE/A
M4^)3YU/T4_I3_E/_4P!4`E0%5`=4"U045!A4&50:5!Q4(E0D5"54*E0P5#-4
M-E0W5#I4/50_5$%40E1$5$541U1)5$Q4351.5$]4451:5%U47E1?5&!4851C
M5&549U1I5&I4:U1L5&U4;E1O5'!4=%1Y5'I4?E1_5(%4@U2%5(=4B%2)5(I4
MC5215)-4EU285)Q4GE2?5*!4H50`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````HE2E5*Y4L%2R5+54ME2W5+E4NE2\5+Y4PU3%5,I4
MRU365-A4VU3@5.%4XE3C5.14ZU3L5.]4\%3Q5/14]53V5/=4^%3Y5/M4_E0`
M50)5`U4$5055"%4*50M5#%4-50Y5$E435155%E4751A5&54:51Q5'54>51]5
M(54E5295```H52E5*U4M53)5-%4U5395.%4Y53I5.U4]54!50E5%54=52%5+
M54Q5355.54]5455255-55%5755A5655:55M5755>55]58%5B56-5:%5I56M5
M;U5P57%5<E5S5715>55Z57U5?U6%5895C%6-58Y5D%6259-5E56659=5FE6;
M59Y5H%6A5:)5HU6D5:55IE6H5:E5JE6K5:Q5K56N5:]5L%6R5;15ME6X5;I5
MO%6_5<!5P57"5<-5QE7'5<A5RE7+5<Y5SU705=55UU785=E5VE7;5=Y5X%7B
M5>=5Z57M5>Y5\%7Q5?15]E7X5?E5^E7[5?Q5_U4"5@-6!%8%5@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````&5@=6"E8+5@U6$%81
M5A)6$U845A56%E875AE6&E8<5AU6(%8A5B)6)58F5BA6*58J5BM6+E8O5C!6
M,U8U5C=6.%8Z5CQ6/58^5D!6059"5D-61%9%5D961U9(5DE62E9+5D]64%91
M5E)64U955E966E9;5EU67E9?5F!6858``&-6959F5F=6;59N5F]6<%9R5G-6
M=%9U5G=6>%9Y5GI6?59^5G]6@%:!5H)6@U:$5H=6B%:)5HI6BU:,5HU6D%:1
M5I)6E%:55I96EU:85IE6FE:;5IQ6G5:>5I]6H%:A5J)6I%:E5J96IU:H5JE6
MJE:K5JQ6K5:N5K!6L5:R5K-6M%:U5K96N%:Y5KI6NU:]5KY6OU;`5L%6PE;#
M5L16Q5;&5L=6R%;)5LM6S%;-5LY6SU;05M%6TE;35M56UE;85ME6W%;C5N56
MYE;G5NA6Z5;J5NQ6[E;O5O)6\U;V5O=6^%;[5OQ6`%<!5P)7!5<'5PM7#%<-
M5PY7#U<05Q%7````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````!)7$U<45Q57%E<75QA7&5<:5QM7'5<>5R!7(5<B5R17)5<F5R=7*U<Q
M5S)7-%<U5S97-U<X5SQ7/5<_5T%70U=$5T571E=(5TE72U=25U-75%=55U97
M6%=95V)78U=E5V=7;%=N5W!7<5=R5W17=5=X5WE7>E=]5WY7?U>`5P``@5>'
M5XA7B5>*5XU7CE>/5Y!7D5>45Y57EE>75YA7F5>:5YQ7G5>>5Y]7I5>H5ZI7
MK%>O5[!7L5>S5[57ME>W5[E7NE>[5[Q7O5>^5[]7P%?!5\17Q5?&5\=7R%?)
M5\I7S%?-5]!7T5?35]97UU?;5]Q7WE?A5^)7XU?E5^97YU?H5^E7ZE?K5^Q7
M[E?P5_%7\E?S5_57]E?W5_M7_%?^5_]7`5@#6`18!5@(6`E8"E@,6`Y8#U@0
M6!)8$U@46!98%U@86!I8&U@<6!U8'U@B6"-8)5@F6"=8*%@I6"M8+%@M6"Y8
M+U@Q6#)8,U@T6#98-U@X6#E8.E@[6#Q8/5@`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/E@_6$!805A"6$-815A&6$=82%A)6$I8
M2UA.6$]84%A26%-855A66%=865A:6%M87%A=6%]88%AA6&)88UAD6&989UAH
M6&E8:EAM6&Y8;UAP6'%8<EAS6'18=5AV6'=8>%AY6'I8>UA\6'U8?UB"6(18
MAEB'6(A8BEB+6(Q8``"-6(Y8CUB06)%8E%B56)98EUB86)M8G%B=6*!8H5BB
M6*-8I%BE6*98IUBJ6*M8K%BM6*Y8KUBP6+%8LEBS6+18M5BV6+=8N%BY6+I8
MNUB]6+Y8OUC`6,)8PUC$6,98QUC(6,E8REC+6,Q8S5C.6,]8T%C26--8U%C6
M6-=8V%C96-I8VUC<6-U8WEC?6.!8X5CB6.-8Y5CF6.=8Z%CI6.I8[5CO6/%8
M\ECT6/58]UCX6/I8^UC\6/U8_EC_6`!9`5D#6059!ED(60E9"ED+60Q9#ED0
M61%9$ED361=9&%D;61U9'ED@62%9(EDC6299*%DL63!9,EDS6359-ED[60``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````]63Y9/UE`
M64-915E&64I93%E-65!94EE365E96UE<65U97EE?66%98UED66999UEH66E9
M:EEK66Q9;5EN66]9<%EQ67)9=5EW67I9>UE\67Y9?UF`6859B5F+68Q9CEF/
M69!9D5F46959F%F:69M9G%F=69]9H%FA6:)9IED``*=9K%FM6;!9L5FS6;19
MM5FV6;=9N%FZ6;Q9O5F_6<!9P5G"6<-9Q%G%6<=9R%G)6<Q9S5G.6<]9U5G6
M6=E9VUG>6=]9X%GA6>)9Y%GF6>=9Z5GJ6>M9[5GN6>]9\%GQ6?)9\UGT6?59
M]EGW6?A9^EG\6?U9_ED`6@):"EH+6@U:#EH/6A!:$EH46A5:%EH76AE:&EH;
M6AU:'EHA6B):)%HF6B=:*%HJ6BM:+%HM6BY:+UHP6C-:-5HW6CA:.5HZ6CM:
M/5H^6C]:05I"6D-:1%I%6D=:2%I+6DQ:35I.6D]:4%I16E):4UI46E9:5UI8
M6EE:6UI<6EU:7EI?6F!:````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&%:8UID6F5:9EIH6FE::UIL6FU:;EIO6G!:<5IR6G-:>%IY
M6GM:?%I]6GY:@%J!6H):@UJ$6H5:AEJ'6HA:B5J*6HM:C%J-6HY:CUJ06I%:
MDUJ46I5:EEJ76IA:F5J<6IU:GEJ?6J!:H5JB6J-:I%JE6J9:IUJH6JE:JUJL
M6@``K5JN6J]:L%JQ6K1:MEJW6KE:NEJ[6KQ:O5J_6L!:PUK$6L5:QEK'6LA:
MREK+6LU:SEK/6M!:T5K36M5:UUK96MI:VUK=6MY:WUKB6N1:Y5KG6NA:ZEKL
M6NU:[EKO6O!:\EKS6O1:]5KV6O=:^%KY6OI:^UK\6OU:_EK_6@!;`5L"6P-;
M!%L%6P9;!UL(6PI;"UL,6PU;#EL/6Q!;$5L26Q-;%%L56QA;&5L:6QM;'%L=
M6QY;'UL@6R%;(ELC6R1;)5LF6R=;*%LI6RI;*ULL6RU;+ELO6S!;,5LS6S5;
M-ELX6SE;.EL[6SQ;/5L^6S];05M"6T-;1%M%6T9;1UL`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````2%M)6TI;2UM,6TU;3EM/6U);
M5EM>6V!;85MG6VA;:UMM6VY;;UMR6W1;=EMW6WA;>5M[6WQ;?EM_6X);AEN*
M6XU;CEN06Y%;DEN46Y9;GUNG6ZA;J5NL6ZU;KENO6[%;LENW6[I;NUN\6\!;
MP5O#6\A;R5O*6\M;S5O.6\];``#16]1;U5O66]=;V%O96]I;VUO<6^!;XEOC
M6^9;YUOI6^I;ZUOL6^U;[UOQ6_);\UOT6_5;]EOW6_U;_EL`7`)<`UP%7`=<
M"%P+7`Q<#5P.7!!<$EP37!=<&5P;7!Y<'UP@7"%<(UPF7"A<*5PJ7"M<+5PN
M7"]<,%PR7#-<-5PV7#=<0UQ$7$9<1UQ,7$U<4EQ37%1<5EQ77%A<6EQ;7%Q<
M75Q?7&)<9%QG7&A<:5QJ7&M<;%QM7'!<<EQS7'1<=5QV7'=<>%Q[7'Q<?5Q^
M7(!<@UR$7(5<AER'7(E<BER+7(Y<CUR27)-<E5R=7)Y<GUR@7*%<I%RE7*9<
MIURH7```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"J
M7*Y<KURP7+)<M%RV7+E<NER[7+Q<OES`7,)<PUS%7,9<QUS(7,E<RES,7,U<
MSES/7-!<T5S37-1<U5S67-=<V%S:7-M<W%S=7-Y<WUS@7.)<XUSG7.E<ZUSL
M7.Y<[USQ7/)<\UST7/5<]ESW7/A<^5SZ7/Q<_5S^7/]<`%T```%=!%T%70A=
M"5T*70M=#%T-70]=$%T171)=$UT571==&%T971I='%T=71]=(%TA72)=(UTE
M72A=*ETK72Q=+UTP73%=,ETS735=-ETW73A=.5TZ73M=/%T_74!=05U"74-=
M1%U%749=2%U)74U=3EU/75!=45U275-=5%U5759=5UU975I=7%U>75]=8%UA
M76)=8UUD765=9EUG76A=:EUM76Y=<%UQ77)=<UUU779==UUX77E=>EU[77Q=
M?5U^77]=@%V!78-=A%V%789=AUV(78E=BEV+78Q=C5V.78]=D%V179)=DUV4
M795=EEV779A=FEV;79Q=GEV?7:!=````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````*%=HEVC7:1=I5VF7:==J%VI7:I=JUVL7:U=KEVO
M7;!=L5VR7;-=M%VU7;9=N%VY7;I=NUV\7;U=OEV_7<!=P5W"7<-=Q%W&7<==
MR%W)7<I=RUW,7<Y=SUW07=%=TEW37=1=U5W67===V%W97=I=W%W?7>!=XUWD
M7>I=[%WM70``\%WU7?9=^%WY7?I=^UW\7?]=`%X$7@=>"5X*7@M>#5X.7A)>
M$UX77AY>'UX@7B%>(EXC7B1>)5XH7BE>*EXK7BQ>+UXP7C)>,UXT7C5>-EXY
M7CI>/EX_7D!>05Y#7D9>1UY(7DE>2EY+7DU>3EY/7E!>45Y27E->5EY77EA>
M65Y:7EQ>75Y?7F!>8UYD7F5>9EYG7FA>:5YJ7FM>;%YM7FY>;UYP7G%>=5YW
M7GE>?EZ!7H)>@UZ%7HA>B5Z,7HU>CEZ27IA>FUZ=7J%>HEZC7J1>J%ZI7JI>
MJUZL7JY>KUZP7K%>LEZT7KI>NUZ\7KU>OU[`7L%>PE[#7L1>Q5X`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````QE['7LA>RU[,7LU>
MSE[/7M!>U%[57M=>V%[97MI>W%[=7MY>WU[@7N%>XE[C7N1>Y5[F7N=>Z5[K
M7NQ>[5[N7N]>\%[Q7O)>\U[U7OA>^5[[7OQ>_5X%7P9?!U\)7PQ?#5\.7Q!?
M$E\47Q9?&5\:7QQ?'5\>7R%?(E\C7R1?```H7RM?+%\N7S!?,E\S7S1?-5\V
M7S=?.%\[7SU?/E\_7T%?0E]#7T1?15]&7T=?2%])7TI?2U],7TU?3E]/7U%?
M5%]97UI?6U]<7UY?7U]@7V-?95]G7VA?:U]N7V]?<E]T7W5?=E]X7WI??5]^
M7W]?@U^&7XU?CE^/7Y%?DU^47Y9?FE^;7YU?GE^?7Z!?HE^C7Z1?I5^F7Z=?
MJ5^K7ZQ?KU^P7[%?LE^S7[1?ME^X7[E?NE^[7[Y?OU_`7\%?PE_'7\A?RE_+
M7\Y?TU_47]5?VE_;7]Q?WE_?7^)?XU_E7^9?Z%_I7^Q?[U_P7_)?\U_T7_9?
M]U_Y7_I?_%\'8```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````(8`E@"V`,8!!@$6`38!=@&&`:8!Y@'V`B8"-@)&`L8"U@+F`P8#%@
M,F`S8#1@-F`W8#A@.6`Z8#U@/F!`8$1@16!&8$=@2&!)8$I@3&!.8$]@46!3
M8%1@5F!78%A@6V!<8%Y@7V!@8&%@96!F8&Y@<6!R8'1@=6!W8'Y@@&```(%@
M@F"%8(9@AV"(8(I@BV".8(]@D&"18)-@E6"78)A@F6"<8)Y@H6"B8*1@I6"G
M8*E@JF"N8+!@LV"U8+9@MV"Y8+I@O6"^8+]@P&#!8,)@PV#$8,=@R&#)8,Q@
MS6#.8,]@T&#28--@U&#68-=@V6#;8-Y@X6#B8.-@Y&#E8.I@\6#R8/5@]V#X
M8/M@_&#]8/Y@_V`"80-A!&$%80=A"F$+80QA$&$181)A$V$4819A%V$881EA
M&V$<81UA'F$A82)A)6$H82EA*F$L82UA+F$O83!A,6$R83-A-&$U839A-V$X
M83EA.F$[83QA/6$^84!A06%"84-A1&%%849A````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=A26%+84UA3V%085)A4V%4859A5V%8
M85EA6F%;85QA7F%?86!A86%C861A96%F86EA:F%K86QA;6%N86]A<6%R87-A
M=&%V87AA>6%Z87MA?&%]87YA?V&`88%A@F&#881AA6&&88=AB&&)88IAC&&-
M88]AD&&189)ADV&580``EF&789AAF6&:89MAG&&>89]AH&&A8:)AHV&D8:5A
MIF&J8:MAK6&N8:]AL&&Q8;)ALV&T8;5AMF&X8;EANF&[8;QAO6&_8<!AP6'#
M8<1AQ6'&8<=AR6',8<UASF'/8=!ATV'58=9AUV'88=EAVF';8=QAW6'>8=]A
MX&'A8>)AXV'D8>5AYV'H8>EAZF'K8>QA[6'N8>]A\&'Q8?)A\V'T8?9A]V'X
M8?EA^F'[8?QA_6'^80!B`6("8@-B!&(%8@=B"6(38A1B&6(<8AUB'F(@8B-B
M)F(G8BAB*6(K8BUB+V(P8C%B,F(U8C9B.&(Y8CIB.V(\8D)B1&)%8D9B2F(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````3V)08E5B
M5F)78EEB6F)<8EUB7F)?8F!B86)B8F1B96)H8G%B<F)T8G5B=V)X8GIB>V)]
M8H%B@F*#8H5BAF*'8HABBV*,8HUBCF*/8I!BE&*98IQBG6*>8J-BIF*G8JEB
MJF*M8JYBKV*P8K)BLV*T8K9BMV*X8KIBOF+`8L%B``##8LMBSV+18M5BW6+>
M8N!BX6+D8NIBZV+P8O)B]6+X8OEB^F+[8@!C`V,$8P5C!F,*8PMC#&,-8P]C
M$&,28Q-C%&,58Q=C&&,98QQC)F,G8REC+&,M8RYC,&,Q8S-C-&,U8S9C-V,X
M8SMC/&,^8S]C0&-!8T1C1V-(8TIC46-28U-C5&-68U=C6&-98UIC6V-<8UUC
M8&-D8V5C9F-H8VIC:V-L8V]C<&-R8W-C=&-U8WAC>6-\8WUC?F-_8X%C@V.$
M8X5CAF.+8XUCD6.38Y1CE6.78YECFF.;8YQCG6.>8Y]CH6.D8Z9CJV.O8[%C
MLF.U8[9CN6.[8[UCOV/`8P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#!8\)CPV/%8\=CR&/*8\MCS&/18]-CU&/58]=CV&/98]IC
MVV/<8]UCWV/B8^1CY6/F8^=CZ&/K8^QC[F/O8_!C\6/S8_5C]V/Y8_IC^V/\
M8_YC`V0$9`9D!V0(9`ED"F0-9`YD$6029!5D%F079!AD&60:9!UD'V0B9"-D
M)&0``"5D)V0H9"ED*V0N9"]D,&0Q9#)D,V0U9#9D-V0X9#ED.V0\9#YD0&1"
M9$-D261+9$QD361.9$]D4&119%-D56169%=D661:9%MD7&1=9%]D8&1A9&)D
M8V1D9&5D9F1H9&ID:V1L9&YD;V1P9'%D<F1S9'1D=61V9'=D>V1\9'UD?F1_
M9(!D@62#9(9DB&2)9(IDBV2,9(UDCF2/9)!DDV249)=DF&2:9)MDG&2=9)]D
MH&2A9*)DHV2E9*9DIV2H9*IDJV2O9+%DLF2S9+1DMF2Y9+MDO62^9+]DP63#
M9,1DQF3'9,ADR63*9,MDS&3/9-%DTV349-5DUF399-ID````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-MDW&3=9-]DX&3A9.-DY63G
M9.ADZ63J9.MD[&3M9.YD[V3P9/%D\F3S9/1D]63V9/=D^&3Y9/ID^V3\9/UD
M_F3_9`%E`F4#901E!64&90=E"&4*90ME#&4-90YE#V4091%E$V44915E%F47
M91EE&F4;91QE'64>91]E(&4A90``(F4C921E)F4G92AE*64J92QE+64P93%E
M,F4S93=E.F4\93UE0&5!94)E0V5$949E1V5*94ME365.95!E4F53951E5V58
M95IE7&5?96!E865D965E9V5H96EE:F5M96YE;V5Q97-E=65V97AE>65Z97ME
M?&5]97YE?V6`98%E@F6#981EA66&98AEB66*98UECF6/99)EE&65999EF&6:
M99UEGF6@9:)EHV6F9:AEJF6L9:YEL66R9;-EM&6U9;9EMV6X9;IENV6^9;]E
MP&7"9<=ER&7)9<IES6709=%ETV749=5EV&799=IEVV7<9=UEWF7?9>%EXV7D
M9>IEZV4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M\F7S9?1E]67X9?EE^V7\9?UE_F7_90%F!&8%9@=F"&8)9@MF#6809A%F$F86
M9A=F&&8:9AMF'&8>9B%F(F8C9B1F)F8I9BIF*V8L9BYF,&8R9C-F-V8X9CEF
M.F8[9CUF/V9`9D)F1&9%9D9F1V9(9DEF2F9-9DYF4&919EAF``!99EMF7&9=
M9EYF8&9B9F-F969G9FEF:F9K9FQF;69Q9G)F<V9U9GAF>69[9GQF?69_9H!F
M@6:#9H5FAF:(9HEFBF:+9HUFCF:/9I!FDF:39I1FE6:89IEFFF:;9IQFGF:?
M9J!FH6:B9J-FI&:E9J9FJ6:J9JMFK&:M9J]FL&:Q9K)FLV:U9K9FMV:X9KIF
MNV:\9KUFOV;`9L%FPF;#9L1FQ6;&9L=FR&;)9LIFRV;,9LUFSF;/9M!FT6;2
M9M-FU&;59M9FUV;89MIFWF;?9N!FX6;B9N-FY&;E9N=FZ&;J9NMF[&;M9NYF
M[V;Q9O5F]F;X9OIF^V;]9@%G`F<#9P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````$9P5G!F<'9PQG#F</9Q%G$F<39Q9G&&<99QIG
M'&<>9R!G(6<B9R-G)&<E9R=G*6<N9S!G,F<S9S9G-V<X9SEG.V<\9SYG/V=!
M9T1G16='9TIG2V=-9U)G5&=59U=G6&=99UIG6V==9V)G8V=D9V9G9V=K9VQG
M;F=Q9W1G=F<``'AG>6=Z9WMG?6>`9X)G@V>%9X9GB&>*9XQGC6>.9X]GD6>2
M9Y-GE&>69YEGFV>?9Z!GH6>D9Z9GJ6>L9ZYGL6>R9[1GN6>Z9[MGO&>]9[YG
MOV?`9\)GQ6?&9\=GR&?)9\IGRV?,9\UGSF?59]9GUV?;9]]GX6?C9^1GYF?G
M9^AGZF?K9^UG[F?R9_5G]F?W9_AG^6?Z9_MG_&?^9P%H`F@#:`1H!F@-:!!H
M$F@4:!5H&&@9:!IH&V@<:!YH'V@@:")H(V@D:"5H)F@G:"AH*V@L:"UH+F@O
M:#!H,6@T:#5H-F@Z:#MH/VA':$MH36A/:%)H5FA7:%AH66A::%MH````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````%QH76A>:%]H:FAL
M:&UH;FAO:'!H<6AR:'-H=6AX:'EH>FA[:'QH?6A^:']H@&B":(1HAVB(:(EH
MBFB+:(QHC6B.:)!HD6B2:)1HE6B6:)AHF6B::)MHG&B=:)YHGVB@:*%HHVBD
M:*5HJ6BJ:*MHK&BN:+%HLFBT:+9HMVBX:```N6BZ:+MHO&B]:+YHOVC!:,-H
MQ&C%:,9HQVC(:,IHS&C.:,]HT&C1:--HU&C6:-=HV6C;:-QHW6C>:-]HX6CB
M:.1HY6CF:.=HZ&CI:.IHZVCL:.UH[VCR:/-H]&CV:/=H^&C[:/UH_FC_:`!I
M`FD#:01I!FD':0AI"6D*:0QI#VD1:1-I%&D5:19I%VD8:1EI&FD;:1QI'6D>
M:2%I(FDC:25I)FDG:2AI*6DJ:2MI+&DN:2]I,6DR:3-I-6DV:3=I.&DZ:3MI
M/&D^:4!I06E#:41I16E&:4=I2&E):4II2VE,:4UI3FE/:5!I46E2:5-I56E6
M:5AI66E;:5QI7VD`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````86EB:61I96EG:6AI:6EJ:6QI;6EO:7!I<FES:71I=6EV:7II>VE]
M:7YI?VF!:8-IA6F*:8MIC&F.:8]ID&F1:9)IDVF6:9=IF6F::9UIGFF?::!I
MH6FB::-II&FE::9IJ6FJ::QIKFFO:;!ILFFS:;5IMFFX:;EINFF\:;UI``"^
M:;]IP&G":<-IQ&G%:<9IQVG(:<EIRVG-:<]IT6G2:=-IU6G6:==IV&G9:=II
MW&G=:=YIX6GB:>-IY&GE:>9IYVGH:>EIZFGK:>QI[FGO:?!I\6GS:?1I]6GV
M:?=I^&GY:?II^VG\:?YI`&H!:@)J`VH$:@5J!FH':@AJ"6H+:@QJ#6H.:@]J
M$&H1:A)J$VH4:A5J%FH9:AIJ&VH<:AUJ'FH@:B)J(VHD:B5J)FHG:BEJ*VHL
M:BUJ+FHP:C)J,VHT:C9J-VHX:CEJ.FH[:CQJ/VI`:D%J0FI#:D5J1FI(:DEJ
M2FI+:DQJ36I.:D]J46I2:E-J5&I5:E9J5VI::@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!<:EUJ7FI?:F!J8FIC:F1J9FIG:FAJ
M:6IJ:FMJ;&IM:FYJ;VIP:G)J<VIT:G5J=FIW:GAJ>FI[:GUJ?FI_:H%J@FJ#
M:H5JAFJ':HAJB6J*:HMJC&J-:H]JDFJ3:I1JE6J6:IAJF6J::IMJG&J=:IYJ
MGVJA:J)JHVJD:J5JIFH``*=JJ&JJ:JUJKFJO:K!JL6JR:K-JM&JU:K9JMVJX
M:KEJNFJ[:KQJO6J^:K]JP&K!:L)JPVK$:L5JQFK':LAJR6K*:LMJS&K-:LYJ
MSVK0:M%JTFK3:M1JU6K6:M=JV&K9:MIJVVK<:MUJWFK?:N!JX6KB:N-JY&KE
M:N9JYVKH:NEJZFKK:NQJ[6KN:N]J\&KQ:O)J\VKT:O5J]FKW:OAJ^6KZ:OMJ
M_&K]:OYJ_VH`:P%K`FL#:P1K!6L&:P=K"&L):PIK"VL,:PUK#FL/:Q!K$6L2
M:Q-K%&L5:Q9K%VL8:QEK&FL;:QQK'6L>:Q]K)6LF:RAK*6LJ:RMK+&LM:RYK
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"]K,&LQ
M:S-K-&LU:S9K.&L[:SQK/6L_:T!K06M":T1K16M(:TIK2VM-:TYK3VM0:U%K
M4FM3:U1K56M6:U=K6&M::UMK7&M=:UYK7VM@:V%K:&MI:VMK;&MM:VYK;VMP
M:W%K<FMS:W1K=6MV:W=K>&MZ:WUK?FM_:X!KA6N(:P``C&N.:X]KD&N1:Y1K
ME6N7:YAKF6N<:YUKGFN?:Z!KHFNC:Z1KI6NF:Z=KJ&NI:ZMKK&NM:ZYKKVNP
M:[%KLFNV:[AKN6NZ:[MKO&N]:[YKP&O#:\1KQFO':\AKR6O*:\QKSFO0:]%K
MV&O::]QKW6O>:]]KX&OB:^-KY&OE:^9KYVOH:^EK[&OM:^YK\&OQ:_)K]&OV
M:_=K^&OZ:_MK_&O^:_]K`&P!;`)L`VP$;`AL"6P*;`ML#&P.;!)L%VP<;!UL
M'FP@;"-L)6PK;"QL+6PQ;#-L-FPW;#EL.FP[;#QL/FP_;$-L1&Q%;$AL2VQ,
M;$UL3FQ/;%%L4FQ3;%9L6&P`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````66Q:;&)L8VQE;&9L9VQK;&QL;6QN;&]L<6QS;'5L=VQX
M;'IL>VQ\;']L@&R$;(=LBFR+;(ULCFR1;))LE6R6;)=LF&R:;)QLG6R>;*!L
MHFRH;*QLKVRP;+1LM6RV;+=LNFS`;,%LPFS#;,9LQVS(;,MLS6S.;,]LT6S2
M;-AL``#9;-ILW&S=;-]LY&SF;.=LZ6SL;.UL\FST;/EL_VP`;0)M`VT%;09M
M"&T);0IM#6T/;1!M$6T3;11M%6T6;1AM'&T=;1]M(&TA;2)M(VTD;29M*&TI
M;2QM+6TO;3!M-&TV;3=M.&TZ;3]M0&U";41M26U,;5!M56U6;5=M6&U;;5UM
M7VUA;6)M9&UE;6=M:&UK;6QM;6UP;7%M<FUS;75M=FUY;7IM>VU];7YM?VV`
M;8%M@VV$;89MAVV*;8MMC6V/;9!MDFV6;9=MF&V9;9IMG&VB;:5MK&VM;;!M
ML6VS;;1MMFVW;;EMNFV[;;QMO6V^;<%MPFW#;<AMR6W*;0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#-;<YMSVW0;=)MTVW4;=5M
MUVW:;=MMW&W?;>)MXVWE;>=MZ&WI;>IM[6WO;?!M\FWT;?5M]FWX;?IM_6W^
M;?]M`&X!;@)N`VX$;@9N!VX(;@EN"VX/;A)N$VX5;AAN&6X;;AQN'FX?;B)N
M)FXG;BAN*FXL;BYN,&XQ;C-N-6X``#9N-VXY;CMN/&X];CYN/VY`;D%N0FY%
M;D9N1VY(;DEN2FY+;DQN3VY0;E%N4FY5;E=N66Y:;EQN76Y>;F!N86YB;F-N
M9&YE;F9N9VYH;FEN:FYL;FUN;VYP;G%N<FYS;G1N=6YV;G=N>&YY;GIN>VY\
M;GUN@&Z!;H)NA&Z';HANBFZ+;HQNC6Z.;I%NDFZ3;I1NE6Z6;I=NF6Z:;IMN
MG6Z>;J!NH6ZC;J1NIFZH;JENJVZL;JUNKFZP;K-NM6ZX;KENO&Z^;K]NP&[#
M;L1NQ6[&;LANR6[*;LQNS6[.;M!NTF[6;MANV6[;;MQNW6[C;N=NZF[K;NQN
M[6[N;N]N````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`/!N\6[R;O-N]6[V;O=N^&[Z;OMN_&[];OYN_VX`;P%O`V\$;P5O!V\(;PIO
M"V\,;PUO#F\0;Q%O$F\6;Q=O&&\9;QIO&V\<;QUO'F\?;R%O(F\C;R5O)F\G
M;RAO+&\N;S!O,F\T;S5O-V\X;SEO.F\[;SQO/6\_;T!O06]";P``0V]$;T5O
M2&]);TIO3&].;T]O4&]1;U)O4V]4;U5O5F]7;UEO6F];;UUO7V]@;V%O8V]D
M;V5O9V]H;VEO:F]K;VQO;V]P;W%O<V]U;W9O=V]Y;WMO?6]^;W]O@&^!;X)O
M@V^%;X9OAV^*;XMOCV^0;Y%ODF^3;Y1OE6^6;Y=OF&^9;YIOFV^=;YYOGV^@
M;Z)OHV^D;Z5OIF^H;ZEOJF^K;ZQOK6^N;Z]OL&^Q;[)OM&^U;[=ON&^Z;[MO
MO&^];[YOOV_!;\-OQ&_%;\9OQV_(;\IORV_,;\UOSF_/;]!OTV_4;]5OUF_7
M;]AOV6_:;]MOW&_=;]]OXF_C;^1OY6\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````YF_G;^AOZ6_J;^MO[&_M;_!O\6_R;_-O]&_U
M;_9O]V_X;_EO^F_[;_QO_6_^;_]O`'`!<`)P`W`$<`5P!G`'<`AP"7`*<`MP
M#'`-<`YP#W`0<!)P$W`4<!5P%G`7<!AP&7`<<!UP'G`?<"!P(7`B<"1P)7`F
M<"=P*'`I<"IP```K<"QP+7`N<"]P,'`Q<#)P,W`T<#9P-W`X<#IP.W`\<#UP
M/G`_<$!P07!"<$-P1'!%<$9P1W!(<$EP2G!+<$UP3G!0<%%P4G!3<%1P57!6
M<%=P6'!9<%IP6W!<<%UP7W!@<&%P8G!C<&1P97!F<&=P:'!I<&IP;G!Q<')P
M<W!T<'=P>7!Z<'MP?7"!<()P@W"$<(9PAW"(<(MPC'"-<(]PD'"1<)-PEW"8
M<)IPFW"><)]PH'"A<*)PHW"D<*5PIG"G<*APJ7"J<+!PLG"T<+5PMG"Z<+YP
MOW#$<,5PQG#'<,EPRW#,<,UPSG#/<-!PT7#2<--PU'#5<-9PUW#:<```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#<<-UPWG#@<.%P
MXG#C<.5PZG#N</!P\7#R</-P]'#U</9P^'#Z</MP_'#^</]P`'$!<0)Q`W$$
M<05Q!G$'<0AQ"W$,<0UQ#G$/<1%Q$G$4<1=Q&W$<<1UQ'G$?<2!Q(7$B<2-Q
M)'$E<2=Q*'$I<2IQ*W$L<2UQ+G$R<3-Q-'$``#5Q-W$X<3EQ.G$[<3QQ/7$^
M<3]Q0'%!<4)Q0W%$<49Q1W%(<4EQ2W%-<4]Q4'%1<5)Q4W%4<55Q5G%7<5AQ
M67%:<5MQ77%?<6!Q87%B<6-Q97%I<6IQ:W%L<6UQ;W%P<7%Q='%U<79Q=W%Y
M<7MQ?'%^<7]Q@'&!<8)Q@W&%<89QAW&(<8EQBW&,<8UQCG&0<9%QDG&3<95Q
MEG&7<9IQFW&<<9UQGG&A<:)QHW&D<:5QIG&G<:EQJG&K<:UQKG&O<;!QL7&R
M<;1QMG&W<;AQNG&[<;QQO7&^<;]QP''!<<)QQ''%<<9QQW'(<<EQRG'+<<QQ
MS7'/<=!QT7'2<=-Q````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-9QUW'8<=EQVG';<=QQW7'><=]QX7'B<>-QY''F<>AQZ7'J<>MQ
M[''M<>]Q\''Q<?)Q\W'T<?5Q]G'W<?AQ^G'[<?QQ_7'^<?]Q`'(!<@)R`W($
M<@5R!W((<@ER"G(+<@QR#7(.<@]R$'(1<A)R$W(4<A5R%G(7<AAR&7(:<@``
M&W(<<AYR'W(@<B%R(G(C<B1R)7(F<B=R*7(K<BUR+G(O<C)R,W(T<CIR/'(^
M<D!R07)"<D-R1')%<D9R27)*<DMR3G)/<E!R47)3<E1R57)7<EAR6G)<<EYR
M8')C<F1R97)H<FIR:W)L<FUR<')Q<G-R=')V<G=R>')[<GQR?7*"<H-RA7*&
M<H=RB'*)<HQRCG*0<I%RDW*4<I5REG*7<IARF7*:<IMRG'*=<IYRH'*A<J)R
MHW*D<J5RIG*G<JARJ7*J<JMRKG*Q<K)RLW*U<KIRNW*\<KUROG*_<L!RQ7+&
M<L=RR7+*<LMRS'+/<M%RTW+4<M5RUG+8<MIRVW(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````,`$P`C"W
M`,D"QP*H``,P!3`4(%[_%B`F(!@@&2`<(!T@%#`5,`@P"3`*,`LP##`-,`XP
M#S`6,!<P$#`1,+$`UP#W`#8B)R(H(A$B#R(J(BDB""(W(AHBI2(E(B`B$B.9
M(BLB+B)A(DPB2"(](ATB8")N(F\B9")E(AXB-2(T(D(F0":P`#(@,R`#(03_
MI`#@_^'_,""G`!8A!B8%)LLESR7.)<<EQB6A):`ELR6R)3L@DB&0(9$ADR$3
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'`A<2%R(7,A="%U(78A=R%X(7DA````````````````B"2)
M)(HDBR2,)(TDCB2/))`DD222)),DE"25))8DER28))DDFB2;)'0D=21V)'<D
M>"1Y)'HD>R1\)'TD?B1_)(`D@22")(,DA"2%)(8DAR1@)&$D8B1C)&0D921F
M)&<D:"1I)``````@,B$R(C(C,B0R)3(F,B<R*#(I,@````!@(6$A8B%C(60A
M92%F(6<A:"%I(6HA:R$`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````?\"_P/_Y?\%_P;_!_\(_PG_
M"O\+_PS_#?\._P__$/\1_Q+_$_\4_Q7_%O\7_QC_&?\:_QO_'/\=_Q[_'_\@
M_R'_(O\C_R3_)?\F_R?_*/\I_RK_*_\L_RW_+O\O_S#_,?\R_S/_-/\U_S;_
M-_\X_SG_.O\[_SS_/?\^_S__0/]!_T+_0_]$_T7_1O]'_TC_2?]*_TO_3/]-
M_T[_3_]0_U'_4O]3_U3_5?]6_U?_6/]9_UK_6_]<_UW_X_\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!!
M,$(P0S!$,$4P1C!',$@P23!*,$LP3#!-,$XP3S!0,%$P4C!3,%0P53!6,%<P
M6#!9,%HP6S!<,%TP7C!?,&`P83!B,&,P9#!E,&8P9S!H,&DP:C!K,&PP;3!N
M,&\P<#!Q,'(P<S!T,'4P=C!W,'@P>3!Z,'LP?#!],'XP?S"`,($P@C"#,(0P
MA3"&,(<PB#"),(HPBS",,(TPCC"/,)`PD3"2,),P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````*$PHC"C,*0PI3"F,*<PJ#"I,*HPJS"L,*TPKC"O
M,+`PL3"R,+,PM#"U,+8PMS"X,+DPNC"[,+PPO3"^,+\PP##!,,(PPS#$,,4P
MQC#',,@PR3#*,,LPS##-,,XPSS#0,-$PTC#3,-0PU3#6,-<PV##9,-HPVS#<
M,-TPWC#?,.`PX3#B,.,PY##E,.8PYS#H,.DPZC#K,.PP[3#N,.\P\##Q,/(P
M\S#T,/4P]C``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````D0.2`Y,#E`.5`Y8#
MEP.8`YD#F@.;`YP#G0.>`Y\#H`.A`Z,#I`.E`Z8#IP.H`ZD#````````````
M`````````+$#L@.S`[0#M0.V`[<#N`.Y`[H#NP.\`[T#O@._`\`#P0/#`\0#
MQ0/&`\<#R`/)`P``````````````````-?XV_CG^.OX__D#^/?X^_D'^0OY#
M_D3^`````#O^//XW_CC^,?X``#/^-/X`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````0!!$$$@03!!0$%00!!!8$%P08!!D$&@0;!!P$'00>!!\$(`0A!"($
M(P0D!"4$)@0G!"@$*00J!"L$+`0M!"X$+P0`````````````````````````
M```````````````P!#$$,@0S!#0$-011!#8$-P0X!#D$.@0[!#P$/00^!#\$
M0`1!!$($0P1$!$4$1@1'!$@$201*!$L$3`1-!$X$3P0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#*`LL"V0(3(!4@)2`U(`4A"2&6(9<AF"&9(14B'R(C(E(B9B)G
M(K\B4"51)5(E4R54)54E5B57)5@E625:)5LE7"5=)5XE7R5@)6$E8B5C)60E
M925F)6<E:"5I)6HE:R5L)6TE;B5O)7`E<25R)7,E@26")8,EA"6%)88EAR4`
M`(@EB26*)8LEC"6-)8XECR63)90EE26\);TEXB7C)>0EY24))I4B$C`=,!XP
M``````````````````````````````$!X0#.`>``$P'I`!L!Z``K`>T`T`'L
M`$T!\P#2`?(`:P'Z`-0!^0#6`=@!V@'<`?P`Z@!1`@``1`%(`0``80(`````
M``````4Q!C$',0@Q"3$*,0LQ##$-,0XQ#S$0,1$Q$C$3,10Q%3$6,1<Q&#$9
M,1HQ&S$<,1TQ'C$?,2`Q(3$B,2,Q)#$E,28Q)S$H,2DQ````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"$P(C`C,"0P)3`F,"<P*#`I,*,R
MCC./,YPSG3.>,Z$SQ#/.,]$STC/5,S#^XO_D_P``(2$Q,@``$"````````#\
M,)LPG##],/XP!C"=,)XP2?Y*_DO^3/Y-_D[^3_Y0_E'^4OY4_E7^5OY7_EG^
M6OY;_ES^7?Y>_E_^8/YA_@``8OYC_F3^9?YF_FC^:?YJ_FO^````````````
M```````````````````````',```````````````````````````````````
M`"4!)0(E`R4$)04E!B4')0@E"24*)0LE#"4-)0XE#R40)1$E$B43)10E%246
M)1<E&"49)1HE&R4<)1TE'B4?)2`E(24B)2,E)"4E)28E)R4H)2DE*B4K)2PE
M+24N)2\E,"4Q)3(E,R4T)34E-B4W)3@E.24Z)3LE/"4])3XE/R5`)4$E0B5#
M)40E125&)4<E2"5))4HE2R4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````W'+=
M<M]RXG+C<N1RY7+F<N=RZG+K<O5R]G+Y<OUR_G+_<@!S`G,$<P5S!G,'<PAS
M"7,+<PQS#7,/<Q!S$7,2<Q1S&',9<QIS'W,@<R-S)',F<R=S*',M<R]S,',R
M<S-S-7,V<SIS.W,\<SUS0'-!<T)S0W-$<T5S1G-'<TAS``!)<TIS2W-,<TYS
M3W-1<U-S5'-5<U9S6'-9<UIS6W-<<UUS7G-?<V%S8G-C<V1S97-F<V=S:'-I
M<VIS:W-N<W!S<7,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!R<W-S='-U<W9S=W-X<WES>G-[<WQS?7-_<X!S@7."
M<X-SA7.&<XASBG.,<XUSCW.0<Y)SDW.4<Y5SEW.8<YESFG.<<YUSGG.@<Z%S
MHW.D<Z5SIG.G<ZASJG.L<ZUSL7.T<[5SMG.X<[ESO'.]<[YSOW/!<\-SQ'/%
M<\9SQW,``,MSS'/.<])STW/4<]5SUG/7<]ASVG/;<]QSW7/?<^%SXG/C<^1S
MYG/H<^ISZW/L<^YS[W/P<_%S\W/T<_5S]G/W<P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````/AS^7/Z<_MS_'/]<_YS
M_W,`=`%T`G0$=`=T"'0+=`QT#70.=!%T$G03=!1T%706=!=T&'09=!QT'70>
M=!]T('0A="-T)'0G="ET*W0M="]T,70R=#=T.'0Y=#IT.W0]=#YT/W1`=$)T
M0W1$=$5T1G1'=$AT271*=$MT3'1-=```3G1/=%!T4712=%-T5'16=%AT771@
M=&%T8G1C=&1T971F=&=T:'1I=&IT:W1L=&YT;W1Q=')T<W1T='5T>'1Y='IT
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````>W1\='UT?W2"=(1TA72&=(ATB72*=(QTC72/=)%TDG23=)1TE726=)=T
MF'29=)ITFW2==)]TH'2A=*)THW2D=*5TIG2J=*MTK'2M=*YTKW2P=+%TLG2S
M=+1TM72V=+=TN'2Y=+MTO'2]=+YTOW3`=,%TPG3#=,1TQ73&=,=T``#(=,ET
MRG3+=,QTS73.=,]TT'31=--TU'35=-9TUW38=-ETVG3;=-UTWW3A=.5TYW3H
M=.ETZG3K=.QT[73P=/%T\G0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#S=/5T^'3Y=/IT^W3\=/UT_G0`=0%U`G4#
M=05U!G4'=0AU"74*=0MU#'4.=1!U$G44=15U%G47=1MU'74>=2!U(74B=2-U
M)'4F=2=U*G4N=31U-G4Y=3QU/74_=4%U0G5#=41U1G5'=4EU2G5-=5!U4752
M=5-U5756=5=U6'4``%UU7G5?=6!U875B=6-U9'5G=6AU:75K=6QU;75N=6]U
M<'5Q=7-U=75V=7=U>G5[=7QU?75^=8!U@76"=81UA76'=0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(AUB76*=8QU
MC76.=9!UDW65=9AUFW6<=9YUHG6F=:=UJ'6I=:IUK76V=;=UNG6[=;]UP'7!
M=<9URW7,=<YUSW70==%UTW77==EUVG7<==UUWW7@=>%UY77I=>QU[77N=>]U
M\G7S=?5U]G7W=?AU^G7[=?UU_G4"=@1V!G8'=@``"'8)=@MV#78.=@]V$782
M=A-V%'86=AIV''8==AYV(78C=B=V*'8L=BYV+W8Q=C)V-G8W=CEV.G8[=CUV
M079"=D1V````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````179&=D=V2'9)=DIV2W9.=D]V4'91=E)V4W95=E=V6'99=EIV
M6W9==E]V8'9A=F)V9'9E=F9V9W9H=FEV:G9L=FUV;G9P=G%V<G9S=G1V=79V
M=G=V>79Z=GQV?W:`=H%V@W:%=HEVBG:,=HUVCW:0=I)VE':5=I=VF'::=IMV
M``"<=IUVGG:?=J!VH7:B=J-VI7:F=J=VJ':I=JIVJW:L=JUVKW:P=K-VM7:V
M=K=VN':Y=KIVNW:\=KUVOG;`=L%VPW9*53^6PU<H8\Y4"57`5)%V3'8\A>YW
M?H*->#%RF):-ERALB5OZ3PECEV:X7/J`2&BN@`)FSG;Y459EK''Q?X2(LE!E
M6<IALV^M@DQC4F+M4R=4!GMK4:1U]%W48LN-=I>*8AF`75<XEV)_.')]=L]G
M?G9&9'!/)8W<8A=ZD67M<RQD<V(L@H&8?V=(<FYBS&(T3^-T2E.>4LI^II`N
M7H9HG&F`@=%^TFC%>(R&496-4"2,WH+>@`53$HEE4@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#$=L=VR7;+=LQVTW;5=MEVVG;<
M=MUVWG;@=N%VXG;C=N1VYG;G=NAVZ7;J=NMV[';M=O!V\W;U=O9V]W;Z=OMV
M_7;_=@!W`G<#=P5W!G<*=PQW#G</=Q!W$7<2=Q-W%'<5=Q9W%W<8=QMW''<=
M=QYW(7<C=R1W)7<G=RIW*W<``"QW+G<P=S%W,G<S=S1W.7<[=SUW/G<_=T)W
M1'=%=T9W2'=)=TIW2W=,=TUW3G=/=U)W4W=4=U5W5G=7=UAW67=<=X2%^9;=
M3R%8<9F=6[%BI6*T9GF,C9P&<F]GD7BR8%%3%U.(C\R`'8VAE`U0R'('6>M@
M&7&KB%19[X(L9RA[*5WW?BUU]6QFCOB//)`[G]1K&9$4>WQ?IWC6A#V%U6O9
M:]9K`5Z'7OEU[95=90I?Q5^?C\%8PH%_D%N6K9>YCQ9_+(U!8K]/V%->4ZB/
MJ8^KCTV0!VAJ7YB!:(C6G(MA*U(J=FQ?C&72;^ANOEM(9'51L%'$9QE.R7E\
MF;-P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````%UW
M7G=?=V!W9'=G=VEW:G=M=VYW;W=P=W%W<G=S=W1W=7=V=W=W>'=Z=WMW?'>!
M=X)W@W>&=X=WB'>)=XIWBW>/=Y!WDW>4=Y5WEG>7=YAWF7>:=YMWG'>==YYW
MH7>C=Z1WIG>H=ZMWK7>N=Z]WL7>R=[1WMG>W=[AWN7>Z=P``O'>^=\!WP7?"
M=\-WQ'?%=\9WQW?(=\EWRG?+=\QWSG?/=]!WT7?2=]-WU'?5=]9WV'?9=]IW
MW7?>=]]WX'?A=^1WQ75V7KMSX(.M9.ABM93B;%I3PU(/9,*4E'LO3QM>-H(6
M@8J!)&[*;'.:56-<4_I498C@5PU.`UYE:S]\Z)`68.9D''/!B%!G36(BC6QW
M*8['D6E?W(,AA1"9PE.5AHMK[6#H8']PS8(Q@M-.IVS/A<UDV7S]:?EF28.5
M4U9[IT^,44MM0EQMCM)CR5,L@S:#Y6>T>#UDWUN47.Y=YXO&8O1G>HP`9+IC
M28>+F1>,('_RE*=.$):DF`QF%G,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````YG?H=^IW[W?P=_%W\G?T=_5W]W?Y=_IW^W?\=P-X
M!'@%>`9X!W@(>`IX"W@.>`]X$'@3>!5X&7@;>!YX('@A>")X)'@H>"IX*W@N
M>"]X,7@R>#-X-7@V>#UX/WA!>$)X0WA$>$9X2'A)>$IX2WA->$]X47A3>%1X
M6'A9>%IX``!;>%QX7GA?>&!X87AB>&-X9'AE>&9X9WAH>&EX;WAP>'%X<GAS
M>'1X=7AV>'AX>7AZ>'MX?7A^>']X@'B!>()X@W@Z5QU<.%Y_E7]0H(""4UYE
M174Q52%0A8V$8IZ4'6<R5FYOXETU5))P9H]O8J1DHV-[7XAO])#C@;"/&%QH
M9O%?B6Q(EH&-;(B19/!YSE=9:A!B2%183@MZZ6"$;]J+?V(>D(N:Y'D#5/1U
M`6,94V!LWX\;7W":.X!_GXA/.EQDC<5_I66]<$51LE%KA@==H%N]8FR1='4,
MCB!Z`6%Y>\=.^'Z%=Q%.[8$=4OI1<6JH4X>.!)7/EL%N9)9::0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"$>(5XAGB(>(IXBWB/
M>)!XDGB4>)5XEGB9>)UXGGB@>*)XI'BF>*AXJ7BJ>*MXK'BM>*YXKWBU>+9X
MMWBX>+IXNWB\>+UXOWC`>,)XPWC$>,9XQWC(>,QXS7C.>,]XT7C2>--XUGC7
M>-AXVGC;>-QXW7C>>-]XX'CA>.)XXW@``.1XY7CF>.=XZ7CJ>.MX[7CN>.]X
M\'CQ>/-X]7CV>/AX^7C[>/QX_7C^>/]X`'D">0-Y!'D&>0=Y"'D)>0IY"WD,
M>4!XJ%#7=Q!DYHD$6>-CW5U_>CUI($\Y@IA5,DZN=9=Z8EZ*7N^5&U(Y5(IP
M=F,DE8)7)68_:8>1!U7S;:]^(H@S8O!^M74H@\%XS):>CTAA]W3-BV1K.E)0
MC2%K:H!QA/%6!E/.3AM.T5&7?(N1!WS#3W^.X7N<>F=D%%VL4`:!`7:Y?.QM
MX']19UA;^%O+>*YD$V2J8RMC&94M9+Z/5'LI=E-B)UE&5'EKHU`T8B9>AFOC
M3C>-BXB%7RZ0````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````UY#GD/>1!Y$7D2>11Y%7D6>1=Y&'D9>1IY&WD<>1UY'WD@>2%Y(GDC
M>25Y)GDG>2AY*7DJ>2MY+'DM>2YY+WDP>3%Y,GDS>35Y-GDW>3AY.7D]>3]Y
M0GE#>41Y17E'>4IY2WE,>4UY3GE/>5!Y47E2>51Y57E8>5EY87EC>0``9'EF
M>6EY:GEK>6QY;GEP>7%Y<GES>71Y=7EV>7EY>WE\>7UY?GE_>8)Y@WF&>8=Y
MB'F)>8MYC'F->8YYD'F1>9)Y(&`]@,5B.4Y54_B0N&/&@.9E+FQ&3^Y@X6W>
MBSE?RX937R%C6E%A@V-H`%)C8TB.$E";7'=Y_%LP4CMZO&!3D-=VMU^77X1V
M;(YO<'MV27NJ=_-1DY`D6$Y/]&[JCTQE&WO$<J1MWW_A6K5BE5XP5X*$+'L=
M7A]?$I`4?Z"8@F/';IAXN7!X45N7JU<U=4-/.'677N9@8%G`;;]KB7C\4]66
MRU$!4HEC"E23E`.,S(TY<I]X=H?MCPV,X%,`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````DWF4>95YEGF7>9AYF7F;>9QYG7F>>9]Y
MH'FA>:)YHWFD>:5YIGFH>:EYJGFK>:QYK7FN>:]YL'FQ>;)YM'FU>;9YMWFX
M>;QYOWG"><1YQ7G'><AYRGG,><YYSWG0>=-YU'G6>==YV7G:>=MYW'G=>=YY
MX'GA>>)YY7GH>>IY``#L>>YY\7GR>?-Y]'GU>?9Y]WGY>?IY_'G^>?]Y`7H$
M>@5Z!WH(>@EZ"GH,>@]Z$'H1>A)Z$WH5>A9Z&'H9>AMZ''H!3N]V[E.)E':8
M#I\ME9I;HHLB3AQ.K%%CA,)AJ%(+:)=/:V"[41YM7%&68I=E899&C!>0V'7]
MD&-WTFN*<NQR^XLU6'EW3(U<9T"5FH"F7B%NDEGO>NUW.Y6U:ZUE#G\&6%%1
M'Y;Y6ZE8*%1RCF9E?YCD5IV4_G9!D(=CQE0:63I9FU>RCC5G^HTU@D%2\&`5
M6/Z&Z%Q%GL1/G9BYBR5:=F"$4WQB3Y`"D7^9:6`,@#]1,X`47'69,6V,3@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````=>A]Z(7HB
M>B1Z)7HF>B=Z*'HI>BIZ*WHL>BUZ+GHO>C!Z,7HR>C1Z-7HV>CAZ.GH^>D!Z
M07I">D-Z1'I%>D=Z2'I)>DIZ2WI,>DUZ3GI/>E!Z4GI3>E1Z57I6>EAZ67I:
M>EMZ7'I=>EYZ7WI@>F%Z8GIC>F1Z97IF>F=Z:'H``&EZ:GIK>FQZ;7IN>F]Z
M<7IR>G-Z=7I[>GQZ?7I^>H)ZA7J'>HEZBGJ+>HQZCGJ/>I!ZDWJ4>IEZFGJ;
M>IYZH7JB>C"-T5-:?T][$$]/3@"6U6S0<^F%!EYJ=?M_"FK^=Y*407[A4>9P
MS5/4CP.#*8VO<FV9VVQ*5[."N66J@#]B,I:H6?].OXNZ?CYE\H->EV%5WIBE
M@"I3_8L@5+J`GUZX;#F-K():D2E4&VP&4K=^7U<:<7YLB7Q+6?U._U\D8:I\
M,$X!7*MG`H?P7`N5SIBO=?UP(I"O41U_O8M)6>116T\F5"M9=V6D@'5;=F+"
M8I"/15X?;"9[#T_83PUG````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````*-ZI'JG>JEZJGJK>JYZKWJP>K%ZLGJT>K5ZMGJW>KAZN7JZ
M>KMZO'J]>KYZP'K!>L)ZPWK$>L5ZQGK'>LAZR7K*>LQZS7K.>L]ZT'K1>M)Z
MTWK4>M5ZUWK8>MIZVWK<>MUZX7KB>N1ZYWKH>NEZZGKK>NQZ[GKP>O%Z\GKS
M>@``]'KU>O9Z]WKX>OMZ_'K^>@![`7L">P5[!WL)>PQ[#7L.>Q![$GL3>Q9[
M%WL8>QI[''L=>Q][(7LB>R-[)WLI>RU[;FVJ;8]YL8@77RMUFF*%C^]/W)&G
M92^!48&<7E"!=(UO4H:)2XT-6850V$X<EC9R>8$?C<Q;HXM$EH=9&G^05'96
M#E;EBSEE@FF9E-9VB6YR7AAU1F?19_]ZG8!VC1]AQGEB96.-B%$:4J*4.'^;
M@+)^EUPO;F!GV7N+=MB:CX&4?]5\'F10E3]Z2E3E5$QK`60(8CV>\X"9=7)2
M:9=;A#QHY(8!EI26[)0J3@14V7XY:-^-%8#T9II>N7\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+WLP>S)[-'LU>S9[-WLY>SM[
M/7L_>T![07M">T-[1'M&>TA[2GM->TY[4WM5>U=[67M<>UY[7WMA>V-[9'ME
M>V9[9WMH>VE[:GMK>VQ[;7MO>W![<WMT>W9[>'MZ>WQ[?7M_>X%[@GN#>X1[
MAGN'>XA[B7N*>XM[C'N.>X][``"1>Y)[DWN6>YA[F7N:>YM[GGN?>Z![HWND
M>Z5[KGNO>[![LGNS>[5[MGNW>[E[NGN[>[Q[O7N^>[][P'O">\-[Q'O"5S^`
MEVCE73MEGU)M8)J?FT^LCFQ1JUL37^E=7FSQ8B&-<5&IE/Y2GVS?@M=RHE>$
M9RV-'UF<C\>#E52->S!/O6QD6]%9$Y_D4\J&J)HWC*&`165^F/I6QY8N4MQT
M4%+A6P)C`HE63M!B*F#Z:'-1F%N@4<*)H7N&F5!_[V!,<"^-25%_7AN0<'3$
MB2U717A27Y^?^I5HCSR;X8MX=D)HW&?JC36-/5**C]INS6@%E>V0_5:<9_F(
MQX_(5```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#%
M>\A[R7O*>\M[S7O.>\][T'O2>]1[U7O6>]=[V'O;>]Q[WGO?>^![XGOC>^1[
MYWOH>^E[ZWOL>^U[[WOP>_)[\WOT>_5[]GOX>_E[^GO[>_U[_WL`?`%\`GP#
M?`1\!7P&?`A\"7P*?`U\#GP0?!%\$GP3?!1\%7P7?!A\&7P``!I\&WP<?!U\
M'GP@?"%\(GPC?"1\)7PH?"E\*WPL?"U\+GPO?#!\,7PR?#-\-'PU?#9\-WPY
M?#I\.WP\?#U\/GQ"?+B::5MW;29LI4ZS6X>:8Y&H8:^0Z9<K5+5MTEO]48I5
M57_P?[QD36/Q9;YAC6`*<5=L26PO66UG*H+56(Y6:HSK:]V0?5D7@/=3:6UU
M5)U5=X//@SAHOGF,5%5/"%32=HF,`I:S;+AM:XT0B62>.HT_5M&>U76(7^!R
M:&#\5*A.*FIAB%)@<(_$5-AP>88_GBIMCUL87Z)^B56O3S1S/%2:4QE0#E1\
M5$Y._5]:=/98:X3A@'2'T'+*?%9N````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$-\1'Q%?$9\1WQ(?$E\2GQ+?$Q\3GQ/?%!\47Q2
M?%-\5'Q5?%9\5WQ8?%E\6GQ;?%Q\77Q>?%]\8'QA?&)\8WQD?&5\9GQG?&A\
M:7QJ?&M\;'QM?&Y\;WQP?'%\<GQU?'9\=WQX?'E\>GQ^?']\@'R!?()\@WR$
M?(5\AGR'?```B'R*?(M\C'R-?(Y\CWR0?)-\E'R6?)E\FGR;?*!\H7RC?*9\
MIWRH?*E\JWRL?*U\KWRP?+1\M7RV?+=\N'RZ?+M\)U].ABQ5I&*23JIL-V*Q
M@M=43E,^<]%N.W424A93W8O0:8I?`&#N;4]7(FNO<U-HV(\3?V)CHV`D5>IU
M8HP5<:-MIEM[7E*#3&'$GOIX5X<G?(=V\%'V8$QQ0V9,7DU@#HQP<"5CB8^]
M7V)@U(;>5L%KE&!G84E3X&!F9C^-_7D:3^EP1VRSB_*+V'YD@P]F6EI"FU%M
M]VU!C#MM&4]K<+>#%F+18`V7)XUX>?M1/E?Z5SIG>'4]>N]YE7L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````OWS`?,)\PWS$?,9\
MR7S+?,Y\SWS0?-%\TGS3?-1\V'S:?-M\W7S>?.%\XGSC?.1\Y7SF?.=\Z7SJ
M?.M\['SM?.Y\\'SQ?/)\\WST?/5\]GSW?/E\^GS\?/U\_GS_?`!]`7T"?0-]
M!'T%?09]!WT(?0E]"WT,?0U]#GT/?1!]```1?1)]$WT4?15]%GT7?1A]&7T:
M?1M]''T=?1Y]'WTA?2-])'TE?29]*'TI?2I]+'TM?2Y],'TQ?3)],WTT?35]
M-GV,@&69^8_`;Z6+(9[L6>E^"7\)5(%GV&B1CTU\QI;*4R5@OG5R;'-3R5JG
M?B1CX%$*@?%=WX2`8H!18UL.3VUY0E*X8$YMQ%O"6Z&+L(OB9<Q?19:36>=^
MJGX)5K=G.5ES3[9;H%):@XJ8/HTR=;Z41U`\>O=.MF=^FL%:?&O1=EI7%EPZ
M>_253G%\4:F`<()X601_)X/`:.QGL7AW>.-B86.`>^U/:E+/45"#VVETDO6-
M,8W!B2Z5K7OV3@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````W?3A].7TZ?3M]/'T]?3Y]/WU`?4%]0GU#?41]17U&?4=]2'U)?4I]
M2WU,?4U]3GU/?5!]47U2?5-]5'U5?59]5WU8?5E]6GU;?5Q]77U>?5]]8'UA
M?6)]8WUD?65]9GUG?6A]:7UJ?6M];'UM?6]]<'UQ?7)]<WUT?75]=GT``'A]
M>7UZ?7M]?'U]?7Y]?WV`?8%]@GV#?81]A7V&?8=]B'V)?8I]BWV,?8U]CGV/
M?9!]D7V2?9-]E'V5?99]EWV8?650,()14F^9$&Z%;J=M^E[U4-Q9!EQ&;5]L
MAG6+A&AH5EFRBR!3<9%-EDF%$FD!>29Q]H"D3LJ01VV$F@=:O%8%9/"4ZW>E
M3QJ!X7+2B7J9-'_>?G]2665UD7^/@X_K4Y9Z[6.E8X9V^'E7B#:6*F*K4H*"
M5&AP9W=C:W?M>@%MTW[CB=!9$F+)A:6"3'4?4,M.I77KBTI<_EU+>Z1ET9'*
M3B5M7XDG?2:5Q4XHC-N/<Y=+9H%YT8_L<'AM````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````)E]FGV;?9Q]G7V>?9]]H'VA?:)]HWVD
M?:5]IWVH?:E]JGVK?:Q]K7VO?;!]L7VR?;-]M'VU?;9]MWVX?;E]NGV[?;Q]
MO7V^?;]]P'W!?<)]PWW$?<5]QGW'?<A]R7W*?<M]S'W-?<Y]SWW0?=%]TGW3
M?=1]U7W6?==]V'W9?0``VGW;?=Q]W7W>?=]]X'WA?>)]XWWD?>5]YGWG?>A]
MZ7WJ?>M]['WM?>Y][WWP??%]\GWS??1]]7WV??=]^'WY??I]/5RR4D:#8E$.
M@UMW=F:XG*Q.RF"^?+-\SWZ53F:+;V:(F%F7@UAL95R5A%_)=5:7WWK>>L!1
MKW"8>NIC=GJ@?I9S[9=%3GAP74Y2D:E3467G9?R!!8*.5#%<FG6@E]ABV7*]
M=45<>9K*@T!<@%3I=SY.KFQ:@-)B;F/H77=1W8T>CB^5\4_E4^=@K'!G4E!C
M0YX?6B90-W=W4^)^A60K98EBF&,44#5RR8FS4<"+W7Y'5\R#IY2;41M4^UP`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````^WW\??U]
M_GW_?0!^`7X"?@-^!'X%?@9^!WX(?@E^"GX+?@Q^#7X.?@]^$'X1?A)^$WX4
M?A5^%GX7?AA^&7X:?AM^''X=?AY^'WX@?B%^(GXC?B1^)7XF?B=^*'XI?BI^
M*WXL?BU^+GXO?C!^,7XR?C-^-'XU?C9^-WXX?CE^```Z?CQ^/7X^?C]^0'Y"
M?D-^1'Y%?D9^2'Y)?DI^2WY,?DU^3GY/?E!^47Y2?E-^5'Y5?E9^5WY8?EE^
M6GY;?EQ^77[*3^-Z6FWAD(^:@%665&%3KU0`7^EC=VGO46AA"E(J6-A23E<-
M>`MWMUYW8>!\6V*78J).E7`#@/=BY'!@EW=7VX+O9_5HU7B7F-%Y\UBS5.]3
M-&Y+43M2HEO^BZ^`0U6F5W-@45<M5'IZ4&!46Z=CH&+C4V-BQUNO9^U4GWKF
M@G>1DU[DB#A9KE<.8^B-[X!75W=[J4_K7[U;/FLA4U![PG)&:/]W-G?W9;51
MCT[4=K]<I7IUA$Y909N`4```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!>?E]^8'YA?F)^8WYD?F5^9GYG?FA^:7YJ?FM^;'YM?FY^
M;WYP?G%^<GYS?G1^=7YV?G=^>'YY?GI^>WY\?GU^?GY_?H!^@7Z#?H1^A7Z&
M?H=^B'Z)?HI^BWZ,?HU^CGZ/?I!^D7Z2?I-^E'Z5?I9^EWZ8?IE^FGZ<?IU^
MGGX``*Y^M'Z[?KQ^UG[D?NQ^^7X*?Q!_'G\W?SE_.W\\?SU_/G\_?T!_07]#
M?T9_1W](?TE_2G]+?TQ_37].?T]_4G]3?XB9)V&#;F17!F9&8_!6[&)I8M->
M%):#5\EBAU4AATJ!HX]F5;&#96=6C=V$:EH/:.9B[GL1EG!1G&\PC/UCR(G2
M809_PG#E;@5TE&G\<LI>SI`79VIM7F.S4F)R`8!L3^59:I'9<)UMTE)03O>6
M;95^A<IX+WTA49)7PF2+@'M\ZFSQ:%YIMU&84ZAH@7+.GO%[^'*[>1-O!G1.
M9\R1I)P\>8F#5(,/5!=H/4Z)4[%2/GB&4RE2B%"+3]!/````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````%9_67];?UQ_77]>?V!_8W]D
M?V5_9G]G?VM_;']M?V]_<']S?W5_=G]W?WA_>G][?WQ_?7]_?X!_@G^#?X1_
MA7^&?X=_B'^)?XM_C7^/?Y!_D7^2?Y-_E7^6?Y=_F'^9?YM_G'^@?Z)_HW^E
M?Z9_J'^I?ZI_JW^L?ZU_KG^Q?P``LW^T?[5_MG^W?[I_NW^^?\!_PG_#?\1_
MQG_'?\A_R7_+?\U_SW_0?]%_TG_3?]9_UW_9?]I_VW_<?]U_WG_B?^-_XG7+
M>I)\I6RVEIM2@W3I5.E/5("R@]Z/<)7)7AQ@GVT87EME.('^E$M@O'##?JY\
MR5&!:+%\;X(D3H:/SY%^9JY.!8RI9$J`VE"7=<YQY5N]CV9OADZ"9&.5UEZ9
M91=2PHC(<*-2#G,S=)=G]W@6ES1.NY#>G,MMVU%!C1U4SF*R<_&#]I:$G\.4
M-D^:?\Q1=7!UEJU<AICF4^1.G&X)=+1I:WB/F5EU&%(D=D%M\V=M49F?2X"9
M5#Q[OWH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MY'_G?^A_ZG_K?^Q_[7_O?_)_]'_U?_9_]W_X?_E_^G_]?_Y__W\"@`>`"(`)
M@`J`#H`/@!&`$X`:@!N`'8`>@!^`(8`C@"2`*X`L@"V`+H`O@#"`,H`T@#F`
M.H`\@#Z`0(!!@$2`18!'@$B`28!.@$^`4(!1@%.`58!6@%>```!9@%N`7(!=
M@%Z`7X!@@&&`8H!C@&2`98!F@&>`:(!K@&R`;8!N@&^`<(!R@'.`=(!U@':`
M=X!X@'F`>H![@'R`?8"&EH17XF)'EGQI!%H"9--[#V]+EJ:"8E.%F)!>B7"S
M8V133X:!G).>C'@RE^^-0HU_GEYOA'E57T:6+F)TFA54W92C3\5E95QA7!5_
M488O;(M?AW/D;O]^YEP;8VI;YFYU4W%.H&-E=:%B;H\F3]%.IFRV?KJ+'82Z
MAU=_.Y`CE:E[H9KXB#V$&VV&FMQ^B%F[GIMS`7B"AFR:@IH;5A=4RU=P3J:>
M5E/(CPF!DG>2F>Z&X6X3A?QF8F$K;P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!^@(&`@H"%@(B`BH"-@(Z`CX"0@)&`DH"4@)6`
MEX"9@)Z`HX"F@*>`J("L@+"`LX"U@+:`N("Y@+N`Q8#'@,B`R8#*@,N`SX#0
M@-&`TH#3@-2`U8#8@-^`X(#B@..`YH#N@/6`]X#Y@/N`_H#_@`"!`8$#@02!
M!8$'@0B!"X$```R!%8$7@1F!&X$<@1V!'X$@@2&!(H$C@22!)8$F@2>!*($I
M@2J!*X$M@2Z!,($S@32!-8$W@3F!.H$[@3R!/8$_@2F,DH(K@_)V$VS97[V#
M*W,%@QJ5VVO;=\:4;U,"@Y)1/5Z,C#B-2$ZK<YIGA6AVD0F79'&A;`EWDEI!
ME<]KCG\G9M!;N5F:6NB5]Y7L3@R$F82L:M]V,)4;<Z9H7ULO=YJ189?<?/>/
M'(PE7W-\V'G%B<QL'(?&6T)>R6@@=_5^E5%-4<E2*5H%?V*7UX+/8X1WT(72
M>3INF5Z961&%;7`1;+]BOW9/9:]@_94.9I^'(Y[ME`U4?50LC'AD````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$"!08%"@4.!1(%%
M@4>!28%-@4Z!3X%2@5:!5X%8@5N!7(%=@5Z!7X%A@6*!8X%D@6:!:(%J@6N!
M;(%O@7*!<X%U@7:!=X%X@8&!@X&$@86!AH&'@8F!BX&,@8V!CH&0@9*!DX&4
M@96!EH&7@9F!FH&>@9^!H(&A@:*!I(&E@0``IX&I@:N!K(&M@:Z!KX&P@;&!
MLH&T@;6!MH&W@;B!N8&\@;V!OH&_@<2!Q8''@<B!R8'+@<V!SH'/@="!T8'2
M@=.!>601AB%JG('H>&ED5)NY8BMGJX.H6-B>JVP@;]Y;3)8+C%]RT&?'8F%R
MJ4[&6<UKDUBN9E5>WU)582AG[G9F=V=R1GK_8NI44%2@E*.0'%JS?A9L0TYV
M61"`2%E74S=UOI;*5B!C$8%\8/F5UFUB5(&9A5'I6OV`KED3ERI0Y6P\7-]B
M8$\_4WN!!I"Z;BN%R&)T7KYXM61[8_5?&%I_D1^>/UQ/8T*`?5MN54J5396%
M;:A@X&?><MU1@5L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````U('5@=:!UX'8@=F!VH';@=R!W8'>@=^!X('A@>*!Y('E@>:!Z('I
M@>N![H'O@?"!\8'R@?6!]H'W@?B!^8'Z@?V!_X$#@@>""(()@@J""X(.@@^"
M$8(3@A6"%H(7@AB"&8(:@AV"(((D@B6")H(G@BF"+H(R@CJ"/((]@C^"``!`
M@D&"0H)#@D6"1H)(@DJ"3()-@DZ"4()1@E*"4X)4@E6"5H)7@EF"6X)<@EV"
M7H)@@F&"8H)C@F2"98)F@F>":8+G8MYL6W)M8JZ4O7X3@5-MG%$$7W19JE(2
M8'-9EF90AI]U*F/F8>]\^HOF5"=K)9ZT:]6%551V4*1L:E6TC2QR%5X58#9T
MS6*28TQRF%]#;CYM`&58;]AVT'C\=E1U)%+;4U-.GE[!92J`UH";8H94*%*N
M<(V(T8WA;'A4VH#Y5_2(5(UJEDV1:4^;;+=5QG8P>*AB^7".;VU?[(3::'QX
M]WNH@0MG3YYG8[!X;U<2>#F7>6*K8HA2-737:P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!J@FN";()M@G&"=8)V@G>">()[@GR"
M@(*!@H."A8*&@H>"B8*,@I""DX*4@I6"EH*:@IN"GH*@@J*"HX*G@K*"M8*V
M@KJ"NX*\@K^"P(+"@L."Q8+&@LF"T(+6@MF"VH+=@N*"YX+H@NF"ZH+L@NV"
M[H+P@O*"\X+U@O:"^((``/J"_(+]@OZ"_X(`@PJ#"X,-@Q"#$H,3@Q:#&(,9
M@QV#'H,?@R"#(8,B@R.#)(,E@R:#*8,J@RZ#,(,R@S>#.X,]@V15/H&R=:YV
M.5/>=?M005QLB\=[3U!'<I>:V)@";^)T:'F'9*5W_&*1F"N-P518@%).:E?Y
M@@V$<U[M4?9TQ(M/7&%7_&R'F$9:-'A$F^N/E7Q64E%B^I3&3H:#883I@[*$
MU%<T9P-7;F9F;3&,W681<!]G.FL6:!IBNUD#3L11!F_29X]L=E'+:$=99VMF
M=0Y=$(%0G]=E2'E!>9&:=XV"7%Y.`4\O5%%9#'AH5A1LQ(\#7WULXVRKBY!C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#Z#/X-!
M@T*#1(-%@TB#2H-+@TR#38-.@U.#58-6@U>#6(-9@UV#8H-P@W&#<H-S@W2#
M=8-V@WF#>H-^@W^#@(.!@X*#@X.$@X>#B(.*@XN#C(.-@X^#D(.1@Y2#E8.6
M@Y>#F8.:@YV#GX.A@Z*#HX.D@Z6#IH.G@ZR#K8.N@P``KX.U@[N#OH._@\*#
MPX/$@\:#R(/)@\N#S8/.@]"#T8/2@].#U8/7@]F#VH/;@]Z#XH/C@^2#YH/G
M@^B#ZX/L@^V#<&`];75R9F*.E,640U/!CWY[WTXFC'Y.U)ZQE+.435)<;V.0
M16TTC!%83%T@:TEKJF=;5%2!C'^96#>%.E^B8D=J.95R981@96BG=U1.J$_G
M79B7K&38?^U<ST^->@=2!(,43B]@@WJFE+5/LD[F>31TY%*Y@M)DO7G=6X%L
M4I=[CR)L/E!_4P5NSF1T9C!LQ6!WF/>+AEX\='=ZRWD83K&0`W1";-I62Y'%
M;(N-.E/&AO)FKXY(7'&:(&X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````[H/O@_.#](/U@_:#]X/Z@_N#_(/^@_^#`(0"A`6$!X0(
MA`F$"H00A!*$$X04A!6$%H07A!F$&H0;A!Z$'X0@A"&$(H0CA"F$*H0KA"R$
M+80NA"^$,(0RA#.$-(0UA#:$-X0YA#J$.X0^A#^$0(1!A$*$0X1$A$6$1X1(
MA$F$``!*A$N$3(1-A$Z$3X10A%*$4X14A%6$5H18A%V$7H1?A&"$8H1DA&6$
M9H1GA&B$:H1NA&^$<(1RA'2$=X1YA'N$?(364S9:BY^CC;M3"%>GF$-GFY')
M;&A1RG7S8JQR.%*=4CI_E'`X=G132IZW:6YXP);9B*1_-G'#<8E1TV?D=.18
M&&6W5JF+=IEP8M5^^6#M<.Q8P4ZZ3LU?YY?[3J2+`U**6:M^5&+-3N5E#F(X
M@\F$8X.-AY1QMFZY6])^EU')8]1GB8`Y@Q6($E%Z6X)9L8]S3EUL95$EB6^/
M+I9*A5YT$)7PE:9MY8(Q7Y)D$FTHA&Z!PYQ>6%N-"4[!4P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!]A'Z$?X2`A(&$@X2$A(6$
MAH2*A(V$CX20A)&$DH23A)2$E826A)B$FH2;A)V$GH2?A*"$HH2CA*2$I82F
MA*>$J(2IA*J$JX2LA*V$KH2PA+&$LX2UA+:$MX2[A+R$OH3`A,*$PX3%A,:$
MQX3(A,N$S(3.A,^$TH34A-6$UX0``-B$V83:A-N$W(3>A.&$XH3DA.>$Z(3I
MA.J$ZX3MA.Z$[X3QA/*$\X3TA/6$]H3WA/B$^83ZA/N$_83^A`"%`84"A1Y/
M8V51:--5)TX49)J::V+"6E]T<H*I;>YHYU".@P)X0&<Y4IELL7Z[4&557G%;
M>U)FRG/K@DEG<5P@4GUQ:XCJE566Q61AC;.!A%55;$=B+G^26"1/1E5/C4QF
M"DX:7/.(HFA.8PUZYW"-@OI2]I<17.A4M9#-?F)92HW'A@R"#8)FC41D!%Q1
M88EM/GF^BS=X,W5[5#A/JX[Q;2!:Q7Y>>8ALH5MV6AIUOH!.81=N\%@?=25U
M<G)'4_-^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``.%!(4%A0:%!X4(A0F%"H4+A0V%#H4/A1"%$H44A16%%H48A1F%&X4<A1V%
M'H4@A2*%(X4DA26%)H4GA2B%*84JA2V%+H4OA3"%,84RA3.%-(4UA3:%/H4_
MA4"%085"A42%185&A4>%2X5,A4V%3H5/A5"%4852A5.%5(55A0``5X58A5J%
M6X5<A5V%7X5@A6&%8H5CA66%9H5GA6F%:H5KA6R%;85NA6^%<(5QA7.%=85V
MA7>%>(5\A7V%?X6`A8&%`7?;=FE2W(`C5PA>,5GN<KUE?V[7BSA<<89!4_-W
M_F+V9<!.WYB`AIY;QHOR4^)W?T].7'::RUD/7SIYZU@63O]GBT[M8I.*'9"_
M4B]FW%5L5@*0U4Z-3\J1<)D/;`)>0V"D6\:)U8LV94MBEIF(6_];B&,N5==3
M)G9]42R%HF>S:(IKDF*3C]13$H+1;8]U9DY.C7!;GW&OA9%FV69R?P"'S9X@
MGUY<+V?PCQ%H7V<-8M9ZA5BV7G!E,6\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````@H6#A8:%B(6)A8J%BX6,A8V%CH60A9&%DH63
MA92%E866A9>%F(69A9J%G86>A9^%H(6AA:*%HX6EA::%IX6IA:N%K(6MA;&%
MLH6SA;2%M86VA;B%NH6[A;R%O86^A;^%P(7"A<.%Q(7%A<:%QX7(A<J%RX7,
MA<V%SH71A=*%``#4A=:%UX78A=F%VH7;A=V%WH7?A>"%X87BA>.%Y87FA>>%
MZ(7JA>N%[(7MA>Z%[X7PA?&%\H7SA?2%]87VA?>%^(558#=2#8!49'"(*74%
M7A-H]&(<E\Q3/7(!C#1L87<.>BY4K'=ZF!R"](M5>!1GP7"O995D-E8=8,%Y
M^%,=3GMKAH#Z6^-5VU8Z3SQ/<IGS77YG.(`"8(*8`9"+6[R+]8L<9%B"WF3]
M5<^"99'73R!]'Y"??/-045BO;K];R8N#@'B1G(27>WV&BY:/EN5^TYJ.>(%<
M5WI"D*>67WE96U]C"WO1A*UH!E4I?Q!T(GT!E4!B3%C63H-;>5E46```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#YA?J%_(7]A?Z%
M`(8!A@*&`X8$A@:&!X8(A@F&"H8+A@R&#88.A@^&$(82AA.&%(85AA>&&(89
MAAJ&&X8<AAV&'H8?AB"&(88BAB.&)(8EAB:&*(8JABN&+(8MABZ&+X8PAC&&
M,H8SAC2&-88VAC>&.88ZACN&/88^AC^&0(8``$&&0H9#AD2&189&AD>&2(9)
MADJ&2X9,AE*&4X95AE:&5X98AEF&6X9<AEV&7X9@AF&&8X9DAF6&9H9GAFB&
M:89JAFUS'F-+C@^.SH#4@JQB\%/P;%Z1*ED!8'!L35=*9"J-*W;I;EM7@&KP
M=6UO+8P(C&97[VN2B+-XHF/Y4ZUP9&Q86"ID`EC@:)N!$%76?!A0NH[,;9^-
MZW"/8YMMU&[F?@2$0V@#D-AM=I:HBU=9>7+DA7Z!O'6*BJ]H5%(BCA&5T&.8
MF$2.?%533_]FCU;58)5M0U))7"E9^VUK6#!U''5L8!2"1H$18V%GXH\Z=_.-
M-(W!E!9>A5,L5,-P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````&V&;X9PAG*&<X9TAG6&=H9WAGB&@X:$AH6&AH:'AHB&B8:.AH^&
MD(:1AI*&E(:6AI>&F(:9AIJ&FX:>AI^&H(:AAJ*&I8:FAJN&K8:NAK*&LX:W
MAKB&N8:[AKR&O8:^AK^&P8;"AL.&Q8;(ALR&S8;2AM.&U8;6AM>&VH;<A@``
MW8;@AN&&XH;CAN6&YH;GANB&ZH;KANR&[X;UAO:&]X;ZAON&_(;]AO^&`8<$
MAP6'!H<+APR'#H</AQ"'$8<4AQ:'0&SW7EQ0K4ZM7CIC1X(:D%!H;I&S=PQ4
MW)1D7^5Z=FA%8U)[WW[;=7=0E6(T60^0^%'#>8%Z_E:27Q20@FU@7!]7$%14
M44UNXE:H8Y.8?X$5ARJ)`)`>5&]<P('68EAB,8$UGD"6;II\FBUII5G38CY5
M%F/'5-F&/&T#6N9TG(AJ:Q993(PO7WYNJ7-]F#A.]W",6Y=X/6-:9I9VRV";
M6TE:!TY5@6ILBW.A3HEG47^`7_IE&V?87X19`5H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````&8<;AQV''X<@AR2')H<GARB'*H<K
MARR'+8<OAS"',H<SAS6'-H<XASF'.H<\ASV'0(=!AT*'0X=$AT6'1H=*ATN'
M38=/AU"'48=2AU2'58=6AUB'6H=;AUR'78=>AU^'88=BAV:'9X=HAVF':H=K
MAVR';8=OAW&'<H=SAW6'``!WAWB'>8=ZAW^'@(>!AX2'AH>'AXF'BH>,AXZ'
MCX>0AY&'DH>4AY6'EH>8AYF'FH>;AYR'G8>>AZ"'H8>BAZ.'I(?-7:Y?<5/F
ME]V/16CT5B]5WV`Z3DUO]'['@@Z$U%D?3RI//ERL?BIG&H5S5$]UPX""54^;
M34\M;A.,"5QP86M3'W8I;HJ&AV7[E;E^.U0S>@I][I7A5<%_[G0=8Q>'H6V=
M>A%BH65G4^%C@VSK75Q4J)1,3F%L[(M+7.!EG(*G:#Y4-%3+:V9KE$Y"8TA3
M'H(-3ZY/7E<*8OZ69&9I<O]2H5*?8.^+%&:9<9!G?XE2>/UW<&8[5CA4(95Z
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"EAZ:'
MIX>IAZJ'KH>PA[&'LH>TA[:'MX>XA[F'NX>\A[Z'OX?!A\*'PX?$A\6'QX?(
MA\F'S(?-A\Z'SX?0A]2'U8?6A]>'V(?9A]J'W(?=A]Z'WX?AA^*'XX?DA^:'
MYX?HA^F'ZX?LA^V'[X?PA_&'\H?SA_2']8?VA_>'^(<``/J'^X?\A_V'_X<`
MB`&(`H@$B`6(!H@'B`B("8@+B`R(#8@.B`^($(@1B!*(%(@7B!B(&8@:B!R(
M'8@>B!^(((@CB`!Z;V`,7HE@G8$56=Q@A''O<*IN4&R`<H1JK8@M7F!.LUJ<
M5>.4%VW[?)F6#V+&?HYW?H8C4QZ7EH^'9N%<H$_M<@M.IE,/61-4@&,HE4A1
MV4Z<G*1^N%0DC52(-X+RE8YM)E_,6CYF:9:P<RYSOU-Z@869H7^J6W>64):_
M?OAVHE-VE9F9L7M$B5AN84[4?V5YYHOS8,U4JTYYF/==86K/4!%488PGA%UX
M!)=*4NY4HU8`E8AMM5O&;5-F````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"2()8@FB">(*(@IB"J(*X@LB"V(+H@OB#"(,8@SB#2(
M-8@VB#>(.(@ZB#N(/8@^B#^(08A"B$.(1HA'B$B(28A*B$N(3HA/B%"(48A2
MB%.(58A6B%B(6HA;B%R(78A>B%^(8(AFB&>(:HAMB&^(<8ASB'2(=8AVB'B(
M>8AZB```>XA\B("(@XB&B(>(B8B*B(R(CHB/B)"(D8B3B)2(E8B7B)B(F8B:
MB)N(G8B>B)^(H(BAB*.(I8BFB*>(J(BIB*J(#UQ=6R%HEH!X51%[2&54:9M.
M1VM.AXN73U,?8SIDJI"<9<&`$(R94;!H>%/YA\AAQ&S[;"*,45RJA:^"#)4C
M:YN/L&7[7\-?X4]%B!]F98$I<_I@=%$14HM78E^BD$R(DI%X7D]G)V#36411
M]E'X@`A3>6S$EHIQ$4_N3YY_/6?%50B5P'F6B.-^GU@,8@"76H885GN8D%^X
MB\2$5Y'94^UECUY<=61@;GU_6NI^[7YICZ=5HUNL8,MEA',`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````K(BNB*^(L(BRB+.(M(BU
MB+:(N(BYB+J(NXB]B+Z(OXC`B,.(Q(C'B,B(RHC+B,R(S8C/B-"(T8C3B-:(
MUXC:B-N(W(C=B-Z(X(CAB.:(YXCIB.J(ZXCLB.V([HCOB/*(]8CVB/>(^HC[
MB/V(_X@`B0&)`XD$B06)!HD'B0B)```)B0N)#(D-B0Z)#XD1B12)%8D6B1>)
M&(D<B1V)'HD?B2")(HDCB22))HDGB2B)*8DLB2V)+HDOB3&),HDSB36)-XD)
MD&-V*7?:?G27FX5F6W1ZZI9`B,M2CW&J7^QEXHO[6V^:X5V):UMLK8NOBPJ0
MQ8^+4[QB)IXMGD!4*TZ]@EERG(8675F(KVW%EM%4FDZVBPEQO50)EM]P^6W0
M=B5.%'@2AZE<]EX`BIR8#I:.<+]L1%FI8SQW38@4;W.",%C5<8Q3&GC!E@%5
M9E\P<;1;&HR,FH-K+EDOGN=Y:&=L8F]/H76*?PMM,Y8G;/!.TG5[43=H/F^`
MD'"!EEEV=```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```XB3F).HD[B3R)/8D^B3^)0(E"B4.)18E&B4>)2(E)B4J)2XE,B4V)3HE/
MB5")48E2B5.)5(E5B5:)5XE8B5F)6HE;B5R)78E@B6&)8HECB62)98EGB6B)
M:8EJB6N);(EMB6Z);XEPB7&)<HESB72)=8EVB7>)>(EYB7J)?(D``'V)?HF`
MB8*)A(F%B8>)B(F)B8J)BXF,B8V)CHF/B9")D8F2B9.)E(F5B9:)EXF8B9F)
MFHF;B9R)G8F>B9^)H(FAB4=D)UQED)%Z(XS:6:Q4`()O@X&)`(`P:4Y6-H`W
M<LZ1ME%?3G68EF,:3O93\V9+@1Q9LFT`3OE8.U/68_&4G4\*3V.(D)@W65>0
M^WGJ3O"`D76";)Q;Z%E=7P5I@88:4/)=64[C=^5.>H*18A-FD9!Y7+].>5_&
M@3B0A("K=:9.U(@/8<5KQE])3LIVHF[CBZZ+"HS1BP)?_'_,?\Y^-8-K@^!6
MMVOSES26^UD?5/:4ZVW%6VZ9.5P57Y"6````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````**)HXFDB:6)IHFGB:B)J8FJB:N)K(FMB:Z)
MKXFPB;&)LHFSB;2)M8FVB;>)N(FYB;J)NXF\B;V)OHF_B<")PXG-B=.)U(G5
MB=>)V(G9B=N)W8G?B>")X8GBB>2)YXGHB>F)ZHGLB>V)[HGPB?&)\HGTB?6)
M]HGWB?B)^8GZB0``^XG\B?V)_HG_B0&*`HH#B@2*!8H&B@B*"8H*B@N*#(H-
MB@Z*#XH0BA&*$HH3BA2*%8H6BA>*&(H9BAJ*&XH<BAV*<%/Q@C%J=%IPGI1>
M*'^Y@R2$)81G@T>'SH]BC<AV<5^6F&QX(&;?5.5B8T_#@<AUN%[-E@J.^8:/
M5/-LC&TX;']@QU(H=7U>&$^@8.=?)%PQ=:Z0P)2Y<KEL.&Y)D0EGRU/S4U%/
MR9'QB\A3?%["C^1MCD["=H9I7H8:80:"64_>3SZ0?)P)81UN%&Z%EHA.,5KH
ME@Y.?URY>8=;[8N]?XESWU>+@L&0`51'D+M5ZERA7PAA,FOQ<K*`B8H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````'HH?BB"*(8HB
MBB.*)(HEBB:*)XHHBBF**HHKBBR*+8HNBB^*,(HQBC**,XHTBC6*-HHWBCB*
M.8HZBCN*/(H]BC^*0(I!BD**0XI$BD6*1HI'BDF*2HI+BDR*38I.BD^*4(I1
MBE**4XI4BE6*5HI7BEB*68I:BEN*7(I=BEZ*``!?BF"*88IBBF.*9(IEBF:*
M9XIHBFF*:HIKBFR*;8INBF^*<(IQBG**<XITBG6*=HIWBGB*>HI[BGR*?8I^
MBG^*@(IT;=-;U8B$F&N,;9HSG@INI%%#4:-7@8B?4_1CE8_M5EA4!E<_<Y!N
M&'_<C]&"/V$H8&*6\&:F?HJ-PXVEE+-<I'P(9Z9@!988@)%.YY``4VB605'0
MCW2%79%59O6755L=4SAX0F<]:,E4?G"P6WV/C5$H5[%4$F6"9EZ-0XT/@6R$
M;9#??/]1^X6C9^EEH6^DAH&.:E8@D()V=G#E<2.-Z6(94OUL/(T.8)Y8CF'^
M9F"-3F*S52-N+6=GCP``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"!BH**@XJ$BH6*AHJ'BHB*BXJ,BHV*CHJ/BI"*D8J2BI2*E8J6
MBI>*F(J9BIJ*FXJ<BIV*GHJ?BJ"*H8JBBJ.*I(JEBJ:*IXJHBJF*JHJKBJR*
MK8JNBJ^*L(JQBK**LXJTBK6*MHJWBKB*N8JZBKN*O(J]BKZ*OXK`BL&*PHH`
M`,.*Q(K%BL:*QXK(BLF*RHK+BLR*S8K.BL^*T(K1BM**TXK4BM6*UHK7BMB*
MV8K:BMN*W(K=BMZ*WXK@BN&*XHKCBN&4^)4H=P5HJ&F+5$U.N'#(BUADBV6%
M6X1Z.E#H6[MWX6MYBIA\OFS/=JEEEX\M755<.(8(:&!3&&+9>EMN_7X?:N!Z
M<%\S;R!?C&.H;59G"$X07B:-UT[`@#1VG);;8BUF?F*\;'6-9W%I?T91AX#L
M4VZ0F&+R5/"&F8\%@!>5%X79CUEMS7.?91]W!'4G>/N!'HV(E*9/E6>Y=<J+
M!Y<O8T>5-9:XA"-C07>!7_!RB4X48'1E[V)C:S]E````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````.2*Y8KFBN>*Z(KIBNJ*ZXKLBNV*
M[HKOBO"*\8KRBO.*](KUBO:*]XKXBOF*^HK[BOR*_8K^BO^*`(L!BP*+`XL$
MBP6+!HL(BPF+"HL+BPR+#8L.BP^+$(L1BQ*+$XL4BQ6+%HL7BQB+&8L:BQN+
M'(L=BQZ+'XL@BR&+(HLCBP``)(LEBR>+*(LIBRJ+*XLLBRV++HLOBS"+,8LR
MBS.+-(LUBS:+-XLXBSF+.HL[BSR+/8L^BS^+0(M!BT*+0XM$BT6+)U['==&0
MP8N=@IUG+V4Q5!B'Y7>B@`*!06Q+3L=^3(#T=@UIEFMG8CQ0A$]`5P=C8FN^
MC>I3Z&6X?M=?&F.W8_.!](%N?QQ>V5PV4GIFZ7D:>BB-F7#4==YNNVR2>BU.
MQ7;@7Y^4=XC(?LUYOX#-D?).%T\?@FA4WETR;<R+I7QTCYB`&EZ25+%VF5L\
M9J2:X',J:-N&,6<J<_B+VXL0D/EZVW!N<<1BJ7<Q5CM.5X3Q9ZE2P(8NC?B4
M47L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1HM'
MBTB+28M*BTN+3(M-BTZ+3XM0BU&+4HM3BU2+58M6BU>+6(M9BUJ+6XM<BUV+
M7HM?BV"+88MBBV.+9(MEBV>+:(MIBVJ+:XMMBVZ+;XMPBW&+<HMSBW2+=8MV
MBW>+>(MYBWJ+>XM\BWV+?HM_BX"+@8N"BX.+A(N%BX:+``"'BXB+B8N*BXN+
MC(N-BXZ+CXN0BY&+DHN3BY2+E8N6BY>+F(N9BYJ+FXN<BYV+GHN?BZR+L8N[
MB\>+T(OJBPF,'HQ/3^AL77E[FI-B*G+]8A-.%GALC[!D6HW&>VEHA%[%B(99
MGF3N6+9R#FDEE?V/6(U@5P!_!HS&44ECV6)34TQH(G0!@TR11%5`=WQP2FUY
M4:A41(W_6<MNQ&U<6RM]U$Y]?--N4%OJ@0UN5UL#F]5H*HZ76_Q^.V"U?KF0
M<(U/6<UCWWFSC5)3SV56><6+.Y;$?KN4@GXT5HF1`&=J?PI<=9`H9N9=4$_>
M9UI07$]05Z=>````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````XC#F,.HP[C#R,/8P^C#^,0(Q"C$.,1(Q%C$B,2HQ+
MC$V,3HQ/C%",48Q2C%.,5(Q6C%>,6(Q9C%N,7(Q=C%Z,7XQ@C&.,9(QEC&:,
M9XQHC&F,;(QMC&Z,;XQPC'&,<HQTC'6,=HQWC'N,?(Q]C'Z,?XR`C(&,@XR$
MC(:,AXP``(B,BXR-C(Z,CXR0C)&,DHR3C)6,EHR7C)F,FHR;C)R,G8R>C)^,
MH(RAC**,HXRDC*6,IHRGC*B,J8RJC*N,K(RMC(U.#$Y`41!._UY%4Q5.F$X>
M3C*;;%MI5BA.NGD_3A531TXM63MR;E,0;-]6Y("7F=-K?G<7GS9.GTX0GUQ.
M:4Z33HB"6UML50]6Q$Z-4YU3HU.E4ZY399==C1I3]5,F4RY3/E-<C6938U,"
M4@A2#E(M4C-2/U)`4DQ27E)A4EQ2KX1]4H)2@5*04I-2@E%4?[M.PT[)3L).
MZ$[A3NM.WDX;3_-.(D]D3_5.)4\G3PE/*T]>3V=/.&5:3UU/````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````*Z,KXRPC+&,LHRSC+2,
MM8RVC+>,N(RYC+J,NXR\C+V,OHR_C,",P8S"C,.,Q(S%C,:,QXS(C,F,RHS+
MC,R,S8S.C,^,T(S1C-*,TXS4C-6,UHS7C-B,V8S:C-N,W(S=C-Z,WXS@C.&,
MXHSCC.2,Y8SFC.>,Z(SIC.J,ZXSLC```[8SNC.^,\(SQC/*,\XSTC/6,]HSW
MC/B,^8SZC/N,_(S]C/Z,_XP`C0&-`HT#C02-!8T&C0>-"(T)C0J-"XT,C0V-
M7T]73S)//4]V3W1/D4^)3X-/CT]^3WM/JD]\3ZQ/E$_F3^A/ZD_%3]I/XT_<
M3]%/WT_X3RE03%#S3RQ0#U`N4"U0_D\<4`Q0)5`H4'Y00U!54$A03E!L4'M0
MI5"G4*E0NE#64`91[5#L4.90[E`'40M1W4X];%A/94_.3Z"?1FQT?&Y1_5W)
MGIB9@5$46?E2#5,'BA!3ZU$96551H$Y64;-.;HBDB+5.%('2B(!Y-%L#B+A_
MJU&Q4;U1O%$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````#HT/C1"-$8T2C1.-%(T5C1:-%XT8C1F-&HT;C1R-((U1C5*-5XU?C66-
M:(UIC6J-;(UNC6^-<8URC7B->8UZC7N-?(U]C7Z-?XV`C8*-@XV&C8>-B(V)
MC8R-C8V.C8^-D(V2C9.-E8V6C9>-F(V9C9J-FXV<C9V-GHV@C:&-``"BC:2-
MI8VFC:>-J(VIC:J-JXVLC:V-KHVOC;"-LHVVC;>-N8V[C;V-P(W!C<*-Q8W'
MC<B-R8W*C<V-T(W2C=.-U(W'4991HE&E4:"+IHNGBZJ+M(NUB[>+PHO#B\N+
MSXO.B]*+TXO4B]:+V(O9B]R+WXO@B^2+Z(OIB^Z+\(OSB_:+^8O\B_^+`(P"
MC`2,!XP,C`^,$8P2C!2,%8P6C!F,&XP8C!V,'XP@C"&,)8PGC"J,*XPNC"^,
M,HPSC#6,-HQI4WI3'98BEB&6,98JECV6/)9"EDF65)9?EF>6;)9REG26B):-
MEI>6L):7D)N0G9"9D*R0H9"TD+.0MI"ZD```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#5C=B-V8W<C>"-X8WBC>6-YHWGC>F-[8WN
MC?"-\8WRC?2-]HW\C?Z-_XT`C@&.`HX#C@2.!HX'C@B."XX-C@Z.$(X1CA*.
M$XX5CA:.%XX8CAF.&HX;CAR.((XACB2.)8XFCB>.*(XKCBV.,(XRCC..-(XV
MCC>..(X[CCR./HX``#^.0XY%CD:.3(Y-CDZ.3XY0CE..5(Y5CE:.5XY8CEJ.
M6XY<CEV.7HY?CF".88YBCF..9(YECF>.:(YJCFN.;HYQCKB0L)#/D,60OI#0
MD,20QY#3D.:0XI#<D->0VY#KD.^0_I`$D2*1'I$CD3&1+Y$YD4.11I$-4D)9
MHE*L4JU2OE+_5-!2UE+P4M]3[G'-=_1>]5'\42^;ME,!7UIU[UU,5ZE7H5=^
M6+Q8Q5C16"E7+%<J5S-7.5<N5R]77%<[5T)7:5>%5VM7AE=\5WM7:%=M5W97
M<U>M5Z17C%>R5\]7IU>T5Y-7H%?55]A7VE?95])7N%?T5^]7^%?D5]U7````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'..=8YWCGB.
M>8YZCGN.?8Y^CH".@HZ#CH2.AHZ(CHF.BHZ+CHR.C8Z.CI&.DHZ3CI6.EHZ7
MCIB.F8Z:CIN.G8Z?CJ".H8ZBCJ..I(ZECJ:.IXZHCJF.JHZMCJZ.L(ZQCK..
MM(ZUCK:.MXZXCKF.NXZ\CKV.OHZ_CL".P8["C@``PX[$CL6.QH['CLB.R8[*
MCLN.S([-CL^.T([1CM*.TX[4CM6.UH[7CMB.V8[:CMN.W([=CMZ.WX[@CN&.
MXH[CCN2."U@-6/U7[5<`6!Y8&5A$6"!895AL6(%8B5B:6(!8J)D9G_]A>8)]
M@G^"CX**@JB"A(*.@I&"EX*9@JN"N(*^@K""R(+*@N."F(*W@JZ"RX+,@L&"
MJ8*T@J&"JH*?@L2"SH*D@N&""8/W@N2"#X,'@]R"](+2@MB"#(/[@M."$8,:
M@P:#%(,5@^""U8(<@U&#6X-<@PB#DH,\@S2#,8.;@UZ#+X-/@T>#0X-?@T"#
M%X-@@RV#.H,S@V:#98,`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````Y8[FCN>.Z([ICNJ.ZX[LCNV.[H[OCO".\8[RCO..]([UCO:.
M]X[XCOF.^H[[COR._8[^CO^.`(\!CP*/`X\$CP6/!H\'CPB/"8\*CPN/#(\-
MCPZ/#X\0CQ&/$H\3CQ2/%8\6CQ>/&(\9CQJ/&X\<CQV/'H\?CR"/(8\BCR./
M```DCR6/)H\GCRB/*8\JCRN/+(\MCRZ/+X\PCS&/,H\SCS2/-8\VCS>/.(\Y
MCSJ/.X\\CSV//H\_CT"/08]"CT./1(]H@QN#:8-L@VJ#;8-N@["#>(.S@[2#
MH(.J@Y.#G(.%@WR#MH.I@WV#N(-[@YB#GH.H@[J#O(/!@P&$Y8/8@P=8&(0+
MA-V#_8/6@QR$.(01A`:$U(/?@P^$`X3X@_F#ZH/%@\"#)H3P@^&#7(11A%J$
M681SA(>$B(1ZA(F$>(0\A$:$:81VA(R$CH0QA&V$P83-A-"$YH2]A-.$RH2_
MA+J$X(2AA+F$M(27A.6$XX0,A0UU.(7PA#F%'X4ZA0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!%CT:/1X](CTF/2H]+CTR/38].
MCT^/4(]1CU*/4X]4CU6/5H]7CUB/68]:CUN/7(]=CUZ/7X]@CV&/8H]CCV2/
M98]JCX"/C(^2CYV/H(^ACZ*/I(^ECZ:/IX^JCZR/K8^NCZ^/LH^SC[2/M8^W
MC[B/NH^[C[R/OX_`C\./QH\``,F/RH_+C\R/S8_/C]*/UH_7C]J/X(_AC^./
MYX_LC^^/\8_RC_2/]8_VC_J/^X_\C_Z/_X\'D`B0#)`.D!.0%9`8D%:%.X7_
MA/R$685(A6B%9(5>A7J%HG=#A7*%>X6DA:B%AX6/A7F%KH6<A86%N86WA;"%
MTX7!A=R%_X4GA@6&*886ACR&_EX(7SQ905DW@%596EE860]3(EPE7"Q<-%Q,
M8FIBGV*[8LIBVF+78NYB(F/V8CEC2V-#8ZUC]F-Q8WICCF.T8VUCK&.*8VEC
MKF.\8_)C^&/@8_]CQ&/>8\YC4F3&8[YC161!9`MD&V0@9`QD)F0A9%YDA&1M
M9)9D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````!F0
M')`CD"20)9`GD"B0*9`JD"N0+)`PD#&0,I`SD#20-Y`YD#J0/9`_D$"00Y!%
MD$:02)!)D$J02Y!,D$Z05)!5D%:069!:D%R079!>D%^08)!AD&209I!GD&F0
M:I!KD&R0;Y!PD'&0<I!SD':0=Y!XD'F0>I![D'R0?I"!D```A)"%D(:0AY")
MD(J0C)"-D(Z0CY"0D)*0E)"6D)B0FI"<D)Z0GY"@D*20I9"GD*B0J9"KD*V0
MLI"WD+R0O9"_D,"0>F2W9+ADF62Z9,!DT&379.1DXF0)925E+F4+7])?&741
M7U]3\5/]4^E3Z%/[4Q)4%E0&5$M44E135%145E1#5"%45U195"-4,E2"5)14
M=U1Q5&14FE2;5(14=E1F5)U4T%2M5,)4M%325*=4IE335-14<E2C5-54NU2_
M5,Q4V53:5-Q4J52J5*14W53/5-Y4&U7G5"!5_5045?-4(E4C50]5$54G52I5
M9U6/5;55255M54%5554_55!5/%4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````PI##D,:0R)#)D,N0S)#-D-*0U)#5D-:0V)#9D-J0
MWI#?D."0XY#DD.60Z9#JD.R0[I#PD/&0\I#SD/60]I#WD/F0^I#[D/R0_Y``
MD0&1`Y$%D0:1!Y$(D0F1"I$+D0R1#9$.D0^1$)$1D1*1$Y$4D161%I$7D1B1
M&I$;D1R1```=D1^1()$AD221)9$FD2>1*)$ID2J1*Y$LD2V1+I$PD3*1,Y$T
MD361-I$WD3B1.I$[D3R1/9$^D3^10)%!D4*11)$W5595=55V57=5,U4P55Q5
MBU7258-5L56Y58A5@56?57Y5UE6157M5WU6]5;Y5E%695>I5]U7)51]6T57K
M5>Q5U%7F5=U5Q%7O5>55\E7S5<Q5S57H5?55Y%64CQY6"%8,5@%6)%8C5OY5
M`%8G5BU66%8Y5E=6+%9-5F)6659<5DQ65%:&5F16<59K5GM6?%:%5I-6KU;4
M5M=6W5;A5O56ZU;Y5O]6!%<*5PE7'%</7AE>%%X17C%>.UX\7@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!%D4>12)%1D5.15)%5
MD5:16)%9D5N17)%?D6"19I%GD6B1:Y%MD7.1>I%[D7R1@)&!D8*1@Y&$D8:1
MB)&*D8Z1CY&3D921E9&6D9>1F)&9D9R1G9&>D9^1H)&AD:21I9&FD:>1J)&I
MD:N1K)&PD;&1LI&SD;:1MY&XD;F1NY$``+R1O9&^D;^1P)'!D<*1PY'$D<61
MQI'(D<N1T)'2D=.1U)'5D=:1UY'8D=F1VI';D=V1WI'?D>"1X9'BD>.1Y)'E
MD3=>1%Y47EM>7EYA7HQ<>ER-7)!<EER(7)A<F5R17)I<G%RU7*)<O5RL7*M<
ML5RC7,%<MUS$7-)<Y%S+7.5<`ET#72==)ETN721='ET&71M=6%T^731=/5UL
M75M=;UU=76M=2UU*76E==%V"79E=G5USC+==Q5US7W=?@E^'7XE?C%^57YE?
MG%^H7ZU?M5^\7V*(85^M<K!RM'*W<KARPW+!<LYRS7+2<NAR[W+I<O)R]'+W
M<@%S\W(#<_IR````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````.:1YY'HD>F1ZI'KD>R1[9'ND>^1\)'QD?*1\Y'TD?61]I'WD?B1^9'Z
MD?N1_)']D?Z1_Y$`D@&2`I(#D@22!9(&D@>2")()D@J2"Y(,D@V2#I(/DA"2
M$9(2DA.2%)(5DA:2%Y(8DAF2&I(;DAR2'9(>DA^2()(ADB*2(Y(DD@``)9(F
MDB>2*)(IDBJ2*Y(LDBV2+I(ODC"2,9(RDC.2-)(UDC:2-Y(XDCF2.I([DCR2
M/9(^DC^20))!DD*20Y)$DD62^W(7<Q-S(7,*<QYS'7,5<R)S.7,E<RQS.',Q
M<U!S37-7<V!S;'-O<WYS&X(E6>>8)%D"66.99YEHF6F9:IEKF6R9=)EWF7V9
M@)F$F8>9BIF-F9"9D9F3F929E9F`7I%>BUZ67J5>H%ZY7K5>OEZS7E.-TE[1
M7MM>Z%[J7KJ!Q%_)7]9?SU\#8.Y?!&#A7^1?_E\%8`9@ZE_M7_A?&6`U8"9@
M&V`/8`U@*6`K8`I@/V`A8'A@>6![8'I@0F``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1I)'DDB229)*DDN23))-DDZ23Y)0DE&2
M4I)3DE2259)6DE>26))9DEJ26Y)<DEV27I)?DF"289)BDF.29))EDF:29Y)H
MDFF2:I)KDFR2;9)NDF^2<))QDG*2<Y)UDG:2=Y)XDGF2>I)[DGR2?9)^DG^2
M@)*!DH*2@Y*$DH62``"&DH>2B)*)DHJ2BY*,DHV2CY*0DI&2DI*3DI22E9*6
MDI>2F)*9DIJ2FY*<DIV2GI*?DJ"2H9*BDJ.2I)*EDJ:2IY)J8'U@EF":8*U@
MG6"#8))@C&";8.Q@NV"Q8-U@V&#&8-I@M&`@829A%6$C8?1@`&$.82MA2F%U
M8:QAE&&G8;=AU&'U8=U?LY;IE>N5\97SE?65]I7\E?Z5`Y8$E@:6")8*E@N6
M#)8-E@^6$I85EA:6%Y89EAJ6+$X_<A5B-6Q4;%QL2FRC;(5LD&R4;(QL:&QI
M;'1L=FR&;*ELT&S4;*UL]VSX;/%LUVRR;.!LUFSZ;.ML[FRQ;--L[VS^;```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"HDJF2JI*K
MDJR2K9*ODK"2L9*RDK.2M)*UDK:2MY*XDKF2NI*[DKR2O9*^DK^2P)+!DL*2
MPY+$DL62QI+'DLF2RI++DLR2S9+.DL^2T)+1DM*2TY+4DM62UI+7DMB2V9+:
MDMN2W)+=DMZ2WY+@DN&2XI+CDN22Y9+FDN>2Z)(``.F2ZI+KDNR2[9+NDN^2
M\)+QDO*2\Y+TDO62]I+WDOB2^9+ZDON2_)+]DOZ2_Y(`DP&3`I,#DP23!9,&
MDP>3"),)DSEM)VT,;4-M2&T';01M&6T.;2MM36TN;35M&FU/;5)M5&TS;9%M
M;VV>;:!M7FV3;91M7&U@;7QM8VT:;L=MQ6W>;0YNOVW@;1%NYFW=;=EM%FZK
M;0QNKFTK;FYN3FYK;K)N7VZ&;E-N5&XR;B5N1&[?;K%NF&[@;BUOXFZE;J=N
MO6Z[;K=NUVZT;L]NCV[";I]N8F]&;T=O)&\5;_EN+V\V;TMO=&\J;PEO*6^)
M;XUOC&]X;W)O?&]Z;]%O````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````J3"Y,,DPV3#I,/DQ"3$9,2DQ.3%),5DQ:3%Y,8DQF3&I,;
MDQR3'9,>DQ^3(),ADR*3(Y,DDR63)I,GDRB3*9,JDRN3+),MDRZ3+Y,PDS&3
M,I,SDS23-9,VDS>3.),YDSJ3.Y,\DSV3/Y-`DT&30I-#DT2319-&DT>32)-)
MDP``2I-+DTR339-.DT^34)-1DU*34Y-4DU635I-7DUB369-:DUN37)-=DUZ3
M7Y-@DV&38I-CDV2399-FDV>3:)-IDVN3R6^G;[EOMF_";^%O[F_>;^!O[V\:
M<"-P&W`Y<#5P3W!><(!;A%N56Y-;I5NX6R]UGIHT9.1;[ELPB?!;1XX'B[:/
MTX_5C^6/[H_DC^F/YH_SC^B/!9`$D`N0)I`1D`V0%I`AD#60-I`MD"^01)!1
MD%*04)!HD%B08I!;D+EF=)!]D(*0B)"#D(N04%]77U9?6%\[7*M44%Q97'%;
M8UQF7+Q_*E\I7RU?=((\7SN;;ER!68-9C5FI6:I9HUD`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````;)-MDVZ3;Y-PDW&3<I-SDW23
M=9-VDW>3>)-YDWJ3>Y-\DWV3?I-_DX"3@9."DX.3A).%DX:3AY.(DXF3BI.+
MDXR3C9..DY"3D9.2DY.3E).5DY:3EY.8DYF3FI.;DYR3G9.>DY^3H).ADZ*3
MHY.DDZ63II.GDZB3J9.JDZN3``"LDZV3KI.OD["3L9.RD[.3M).UD[:3MY.X
MD[F3NI.[D[R3O9.^D[^3P)/!D\*3PY/$D\63QI/'D\B3R9/+D\R3S9.76<I9
MJUF>6:19TEFR6:]9UUF^605:!EK=60A:XUG86?E9#%H)6C):-%H16B-:$UI`
M6F=:2EI56CQ:8EIU6NR`JEJ;6G=:>EJ^6NM:LEK26M1:N%K@6N-:\5K66N9:
MV%K<6@E;%UL66S);-UM`6Q5<'%Q:6V5;<UM16U-;8EMUFG>:>)IZFG^:?9J`
MFH&:A9J(FHJ:D)J2FI.:EIJ8FIN:G)J=FI^:H)JBFJ.:I9JGFI]^H7ZC?J5^
MJ'ZI?@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#.
MD\^3T)/1D]*3TY/4D]63UY/8D]F3VI/;D]R3W9/>D]^3X)/AD^*3XY/DD^63
MYI/GD^B3Z9/JD^N3[)/MD^Z3[Y/PD_&3\I/SD_23]9/VD_>3^)/YD_J3^Y/\
MD_V3_I/_DP"4`90"E`.4!)0%E`:4!Y0(E`F4"I0+E`R4#90```Z4#Y00E!&4
M$I03E!24%906E!>4&)09E!J4&Y0<E!V4'I0?E""4(90BE".4))0EE":4)Y0H
ME"F4*I0KE"R4+90NE*U^L'Z^?L!^P7["?LE^RW[,?M!^U'[7?MM^X'[A?NA^
MZW[N?N]^\7[R?@U_]G[Z?OM^_GX!?P)_`W\'?PA_"W\,?P]_$7\2?Q=_&7\<
M?QM_'W\A?R)_(W\D?R5_)G\G?RI_*W\L?RU_+W\P?S%_,G\S?S5_>EY_==M=
M/G65D(YSD7.N<Z)SGW//<\)ST7.W<[-SP'/)<\ASY7/9<WR8"G3I<^=SWG.Z
M<_)S#W0J=%MT)G0E="AT,'0N="QT````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"^4,)0QE#*4,Y0TE#64-I0WE#B4.90ZE#N4/)0]
ME#^40)1!E$*40Y1$E$641I1'E$B4291*E$N43)1-E$Z43Y10E%&44I13E%24
M5916E%>46)19E%J46Y1<E%V47I1?E&"4891BE&.49)1EE&:49Y1HE&F4:I1L
ME&V4;I1OE```<)1QE'*4<Y1TE'64=I1WE'B4>91ZE'N4?)1]E'Z4?Y2`E(&4
M@I2#E(24D926E)B4QY3/E-.4U)3:E.:4^Y0<E2"5&W0:=$%T7'17=%5T671W
M=&UT?G2<=(YT@'2!=(=TBW2>=*ATJ720=*=TTG2Z=.J7ZY?LETQG4V=>9TAG
M:6>E9X=G:F=S9YAGIV=U9ZAGGF>M9XMG=V=\9_!G"6C89PIHZ6>P9PQHV6>U
M9]IGLV?=9P!HPV>X9^)G#FC!9_UG,F@S:&!H86A.:&)H1&AD:(-H'6A5:&9H
M06AG:$!H/FA*:$EH*6BU:(]H=&AW:)-H:VC":&YI_&@?:2!I^6@`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````)Y4SE3V50Y5(E4N5
M595:E6"5;I5TE765=Y5XE7F5>I5[E7R5?95^E8"5@96"E8.5A)6%E8:5AY6(
ME8F5BI6+E8R5C96.E8^5D)61E9*5DY64E965EI67E9B5F96:E9N5G)6=E9Z5
MGY6@E:&5HI6CE:25I96FE:>5J)6IE:J5``"KE:R5K96NE:^5L)6QE;*5LY6T
ME;65MI6WE;B5N96ZE;N5O)6]E;Z5OY7`E<&5PI7#E<25Q97&E<>5R)7)E<J5
MRY4D:?!H"VD!:5=IXV@0:7%I.6E@:4)I76F$:6MI@&F8:7AI-&G,:8=IB&G.
M:8EI9FEC:7EIFVFG:;MIJVFM:=1IL6G!:<IIWVF5:>!IC6G_:2]J[6D7:AAJ
M96KR:41J/FJ@:E!J6VHU:HYJ>6H]:BAJ6&I\:I%JD&JI:I=JJVHW<U)S@6N"
M:X=KA&N2:Y-KC6N::YMKH6NJ:VN/;8]QCW*/<X]UCW:/>(]WCWF/>H]\CWZ/
M@8^"CX2/AX^+CP``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#,E<V5SI7/E="5T972E=.5U)75E=:5UY78E=F5VI7;E=R5W97>E=^5
MX)7AE>*5XY7DE>65YI7GE>R5_Y4'EA.6&)8;EAZ6()8CEB26)98FEB>6*)8I
MEBN6+)8MEB^6,)8WECB6.98ZECZ6099#EDJ63I9/EE&64I93EE:65Y8``%B6
M699:EER6799>EF"68Y9EEF:6:Y9MEFZ6;Y9PEG&6<Y9XEGF6>I9[EGR6?99^
MEG^6@):!EH*6@Y:$EH>6B9:*EHV/CH^/CYB/FH_.C@MB%V(;8A]B(F(A8B5B
M)&(L8N>![W3T=/]T#W41=1-U-&7N9>]E\&4*9AEF<F<#9A5F`&:%</=F'68T
M9C%F-F8U9@:`7V949D%F3V969F%F5V9W9H1FC&:G9IUFOF;;9MQFYF;I9C*-
M,XTVC3N-/8U`C46-1HU(C4F-1XU-C56-68W'B<J)RXG,B<Z)SXG0B=&);G*?
M<EUR9G)O<GYR?W*$<HMRC7*/<I)R"&,R8[!C````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(R6CI:1EI*6DY:5EI:6FI:;EIV6GI:?
MEJ"6H9:BEJ.6I):EEJ:6J):IEJJ6JY:LEJV6KI:OEK&6LI:TEK66MY:XEKJ6
MNY:_EL*6PY;(ELJ6RY;0EM&6TY;4EM:6UY;8EMF6VI;;EMR6W9;>EM^6X9;B
MEN.6Y);EEN:6YY;KE@``[);MENZ6\);QEO*6]);UEOB6^I;[EOR6_9;_E@*7
M`Y<%EPJ7"Y<,EQ"7$9<2EQ27%9<7EQB7&9<:EQN7'9<?ER"7/V389`2`ZFOS
M:_UK]6OY:P5L!VP&;`UL%6P8;!EL&FPA;"EL)&PJ;#)L-65596ME37)2<E9R
M,')BAA92GX"<@).`O(`*9[V`L8"K@*V`M("W@.>`Z(#I@.J`VX#"@,2`V8#-
M@->`$&?=@.N`\8#T@.V`#8$.@?*`_(`59Q*!6HPV@1Z!+($8@3*!2(%,@5.!
M=(%9@5J!<8%@@6F!?(%]@6V!9X%-6+5:B(&"@9&!U6ZC@:J!S($F9\J!NX$`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(9<BER.7
M))<EER:7)Y<HERF7*Y<LERZ7+Y<QES.7-)<UES:7-Y<ZESN7/)<]ES^70)=!
MET*70Y=$ET671I='ETB729=*ETN73)=-ETZ73Y=0EU&75)=5EU>76)=:EUR7
M79=?EV.79)=FEV>7:)=JEVN7;)=MEVZ7;Y=PEW&7``!REW67=Y=XEWF7>I=[
MEWV7?I=_EX"7@9>"EX.7A)>&EX>7B)>)EXJ7C)>.EX^7D)>3EY67EI>7EYF7
MFI>;EYR7G9?!@::!)&LW:SEK0VM&:UEKT9C2F-.8U9C9F-J8LVM`7\)K\XF0
M95&?DV6\9<9EQ&7#9<QESF729=9E@'"<<)9PG7"[<,!PMW"K<+%PZ'#*<!!Q
M$W$6<2]Q,7%S<5QQ:'%%<7)Q2G%X<7IQF'&S<;5QJ'&@<>!QU''G<?EQ'7(H
M<FQP&'%F<;EQ/F(]8D-B2&))8CMY0'E&>4EY6WE<>5-Y6GEB>5=Y8'EO>6=Y
M>GF%>8IYFGFG>;-YT5_07P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````">EY^7H9>BEZ27I9>FEZ>7J)>IEZJ7K)>NE["7L9>SE[67
MMI>WE[B7N9>ZE[N7O)>]E[Z7OY?`E\&7PI?#E\27Q9?&E\>7R)?)E\J7RY?,
ME\V7SI?/E]"7T9?2E].7U)?5E]:7UY?8E]F7VI?;E]R7W9?>E]^7X)?AE^*7
MXY<``.27Y9?HE^Z7[Y?PE_&7\I?TE_>7^)?YE_J7^Y?\E_V7_I?_EP"8`9@"
MF`.8!)@%F`:8!Y@(F`F8"I@+F`R8#9@.F#Q@76!:8&=@06!98&-@JV`&80UA
M76&I89UARV'1809B@(!_@)-L]FS\;?9W^'<`>`EX%W@8>!%XJV4M>!QX'7@Y
M>#IX.W@?>#QX)7@L>"-X*7A.>&UX5GA7>"9X4'A'>$QX:GB;>)-XFGB'>)QX
MH7BC>+)XN7BE>-1XV7C)>.QX\G@%>?1X$WDD>1YY-'F;G_F>^Y[\GO%V!'<-
M=_EV!W<(=QIW(G<9=RUW)G<U=SAW4'=1=T=W0W=:=VAW````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````^8$)@1F!*8$Y@4F!68%I@7
MF!B8&9@:F!N8')@=F!Z8'Y@@F"&8(I@CF"28)9@FF">8*)@IF"J8*Y@LF"V8
M+I@OF#"8,9@RF#.8-)@UF#:8-Y@XF#F8.I@[F#R8/9@^F#^80)A!F$*80YA$
MF$681IA'F$B829A*F$N83)A-F```3IA/F%"849A2F%.85)A5F%:85YA8F%F8
M6IA;F%R879A>F%^88)AAF&*88YADF&689IAGF&B8:9AJF&N8;)AMF&Z88G=E
M=W]WC7=]=X!WC'>1=Y]WH'>P=[5WO7<Z=4!U3G5+=4AU6W5R=7EU@W58?V%_
M7W](BFA_=']Q?WE_@7]^?\UVY78RB(64AI2'E(N4BI2,E(V4CY20E)24EY25
ME)J4FY2<E*.4I)2KE*J4K92LE*^4L)2RE+24MI2WE+B4N92ZE+R4O92_E,24
MR)3)E,J4RY3,E,V4SI30E-&4TI35E-:4UY39E-B4VY3>E-^4X)3BE.24Y93G
ME.B4ZI0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M;YAPF'&8<IASF'28BYB.F)*8E9B9F*.8J)BIF*J8JYBLF*V8KIBOF+"8L9BR
MF+.8M)BUF+:8MYBXF+F8NIB[F+R8O9B^F+^8P)C!F,*8PYC$F,68QIC'F,B8
MR9C*F,N8S)C-F,^8T)C4F-:8UYC;F-R8W9C@F.&8XICCF.28``#EF.:8Z9CJ
MF.N8[)CMF.Z8[YCPF/&8\ICSF/28]9CVF/>8^)CYF/J8^YC\F/V8_IC_F`"9
M`9D"F0.9!)D%F0:9!YGIE.N4[I3OE/.4])3UE/>4^93\E/V4_Y0#E0*5!I4'
ME0F5"I4-E0Z5#Y42E1.5%)45E1:5&)4;E1V5'I4?E2*5*I4KE2F5+)4QE3*5
M-)4VE3>5.)4\E3Z5/Y5"E3651)5%E4:5295,E4Z53Y52E5.55)56E5>56)59
ME5N57I5?E5V5895BE625995FE6>5:)5IE6J5:Y5LE6^5<95RE7.5.I7G=^QW
MR9;5>>UYXWGK>09Z1UT#>@)Z'GH4>@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````(F0F9"ID+F0R9#ID/F1&9$ID3F129%9D6F1>9
M&)D9F1J9&YD<F1V9'ID?F2"9(9DBF2.9))DEF2:9)YDHF2F9*IDKF2R9+9DO
MF3"9,9DRF3.9-)DUF3:9-YDXF3F9.ID[F3R9/9D^F3^90)E!F4*90YE$F469
M1IE'F4B929D``$J92YE,F4V93IE/F5"949E2F5.95IE7F5B969E:F5N97)E=
MF5Z97YE@F6&98IEDF6:9<YEXF7F9>YE^F8*9@YF)F3EZ-WI1>L^>I9EP>HAV
MCG:3=IEVI';>=.!T+'4@GB*>*)XIGBJ>*YXLGC*>,9XVGCB>-YXYGCJ>/IY!
MGD*>1)Y&GD>>2)Y)GDN>3)Y.GE&>59Y7GEJ>6YY<GEZ>8YYFGF>>:)YIGFJ>
M:YYLGG&>;9YSGI)UE'66=:!UG76L=:-ULW6T=;AUQ'6Q=;!UPW7"==9US77C
M=>AUYG7D=>MUYW4#=O%U_'7_=1!V`'8%=@QV%W8*=B5V&'85=AEV````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(R9CIF:F9N9G)F=
MF9Z9GYF@F:&9HIFCF:29IIFGF:F9JIFKF:R9K9FNF:^9L)FQF;*9LYFTF;69
MMIFWF;B9N9FZF;N9O)F]F;Z9OYG`F<&9PIG#F<29Q9G&F<>9R)G)F<J9RYG,
MF<V9SIG/F="9T9G2F=.9U)G5F=:9UYG8F0``V9G:F=N9W)G=F=Z9WYG@F>&9
MXIGCF>29Y9GFF>>9Z)GIF>J9ZYGLF>V9[IGOF?"9\9GRF?.9])GUF?:9]YGX
MF?F9&W8\=B)V('9`=BUV,'8_=C5V0W8^=C-V379>=E1V7'96=FMV;W;*?^9Z
M>'IY>H!ZAGJ(>I5ZIGJ@>JQZJ'JM>K-Z9(AIB'*(?8A_B(*(HHC&B+>(O(C)
MB.*(SHCCB.6(\8@:B?R(Z(C^B/"((8D9B1.)&XD*B32)*XDVB4&)9HE[B8MU
MY8"R=K1VW'<2@!2`%H`<@""`(H`E@":`)X`I@"B`,8`+@#6`0X!&@$V`4H!I
M@'&`@XEXF("8@Y@`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````^IG[F?R9_9G^F?^9`)H!F@*:`YH$F@6:!IH'F@B:"9H*F@N:#)H-
MF@Z:#YH0FA&:$IH3FA2:%9H6FA>:&)H9FAJ:&YH<FAV:'IH?FB":(9HBFB.:
M))HEFB::)YHHFBF:*IHKFBR:+9HNFB^:,)HQFC*:,YHTFC6:-IHWFCB:```Y
MFCJ:.YH\FCV:/IH_FD":09I"FD.:1)I%FD::1YI(FDF:2II+FDR:39I.FD^:
M4)I1FE*:4YI4FE6:5II7FEB:69J)F(R8C9B/F)28FIB;F)Z8GYBAF**8I9BF
MF$V&5(9LAFZ&?X9ZAGR&>X:HAHV&BX:LAIV&IX:CAJJ&DX:IAK:&Q(:UALZ&
ML(:ZAK&&KX;)AL^&M(;IAO&&\H;MAO.&T(83A]Z&](;?AMB&T88#AP>'^(8(
MAPJ'#8<)AR.'.X<>AR6'+H<:ASZ'2(<TAS&'*8<WAS^'@H<BAWV'?H=[AV"'
M<(=,AVZ'BX=3AV.'?(=DAUF'98>3AZ^'J(?2AP``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!:FEN:7)I=FEZ:7YI@FF&:8IICFF2:
M99IFFF>::)IIFFJ::YIRFH.:B9J-FHZ:E)J5FIF:IIJIFJJ:JYJLFJV:KIJO
MFK*:LYJTFK6:N9J[FKV:OIJ_FL.:Q)K&FL>:R)K)FLJ:S9K.FL^:T)K2FM2:
MU9K6FM>:V9K:FMN:W)H``-V:WIK@FN*:XYKDFN6:YYKHFNF:ZIKLFNZ:\)KQ
MFO*:\YKTFO6:]IKWFOB:^IK\FOV:_IK_F@";`9L"FP2;!9L&F\:'B(>%AZV'
MEX>#AZN'Y8>LA[6'LX?+A].'O8?1A\"'RH?;A^J'X(?NAQ:($XC^APJ(&X@A
MB#F(/(@V?T)_1']%?Q""^GK]>@A[`WL$>Q5["GLK>P][1WLX>RI[&7LN>S%[
M('LE>R1[,WL^>QY[6'M:>T5[=7M,>UU[8'MN>WM[8GMR>W%[D'NF>Z=[N'NL
M>YU[J'N%>ZI[G'NB>ZM[M'O1>\%[S'O=>]I[Y7OF>^I[#'S^>_Q[#WP6?`M\
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````>;"9L*
MFPN;#)L-FPZ;$)L1FQ*;%)L5FQ:;%YL8FQF;&IL;FQR;'9L>FR";(9LBFR2;
M)9LFFR>;*)LIFRJ;*YLLFRV;+ILPFS&;,YLTFS6;-ILWFSB;.9LZFSV;/IL_
MFT";1IM*FTN;3)M.FU";4IM3FU6;5IM7FUB;69M:FP``6YM<FUV;7IM?FV";
M89MBFV.;9)MEFV:;9YMHFVF;:IMKFVR;;9MNFV^;<)MQFW*;<YMTFW6;=IMW
MFWB;>9MZFWN;'WPJ?"9\.'Q!?$!\_H$!@@*"!(+L@42((8(B@B."+8(O@BB"
M*X(X@CN",X(T@CZ"1())@DN"3X):@E^":()^B(6(B(C8B-^(7HF=?Y]_IW^O
M?[!_LG]\?$EED7R=?)Q\GGRB?+)\O'R]?,%\QWS,?,U\R'S%?-=\Z'QN@JAF
MOW_.?]5_Y7_A?^9_Z7_N?_-_^'QW?:9]KGU'?IM^N)ZTGG.-A(V4C9&-L8UG
MC6V-1XQ)C$J14)%.D4^19)$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````?)M]FWZ;?YN`FX&;@IN#FX2;A9N&FX>;B)N)FXJ;BYN,
MFXV;CIN/FY";D9N2FY.;E)N5FY:;EYN8FYF;FIN;FYR;G9N>FY^;H)NAFZ*;
MHYNDFZ6;IINGFZB;J9NJFZN;K)NMFZZ;KYNPF[&;LINSF[2;M9NVF[>;N)NY
MF[J;``"[F[R;O9N^F[^;P)O!F\*;PYO$F\6;QIO'F\B;R9O*F\N;S)O-F\Z;
MSYO0F]&;TIO3F]2;U9O6F]>;V)O9F]J;VYMBD6&1<)%ID6^1?9%^D7*1=)%Y
MD8R1A9&0D8V1D9&BD:.1JI&MD:Z1KY&UD;21NI%5C'Z>N(WKC06.68YICK6-
MOXV\C;J-Q(W6C=>-VHW>C<Z-SXW;C<:-[(WWC?B-XXWYC?N-Y(T)COV-%(X=
MCA^.+(XNCB..+XXZCD"..8XUCCV.,8Y)CD&.0HY1CE*.2HYPCG:.?(YOCG2.
MA8Z/CI2.D(Z<CIZ.>(R"C(J,A8R8C)2,FV76B=Z)VHG<B0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#<F]V;WIO?F^";X9OBF^.;
MY)OEF^:;YYOHF^F;ZIOKF^R;[9ONF^^;\)OQF_*;\YOTF_6;]IOWF_B;^9OZ
MF_N;_)O]F_Z;_YL`G`&<`IP#G`2<!9P&G`><")P)G`J<"YP,G`V<#IP/G!"<
M$9P2G!.<%)P5G!:<%YP8G!F<&IP``!N<')P=G!Z<'YP@G"&<(IPCG"2<)9PF
MG"><*)PIG"J<*YPLG"V<+IPOG#"<,9PRG#.<-)PUG#:<-YPXG#F<.IP[G.6)
MZXGOB3Z*)HM3E^F6\Y;OE@:7`9<(EP^7#I<JERV7,)<^EX"?@Y^%GX:?AY^(
MGXF?BI^,G_Z>"Y\-G[F6O):]ELZ6TI:_=^"6CI*NDLB2/I-JD\J3CY,^E&N4
M?YR"G(6<AIR'G(B<(WJ+G(Z<D)R1G)*<E)R5G)J<FYR>G)^<H)RAG**<HYRE
MG*:<IYRHG*F<JYRMG*Z<L)RQG+*<LYRTG+6<MIRWG+J<NYR\G+V<Q)S%G,:<
MQYS*G,N<````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#R</9P^G#^<0)Q!G$*<0YQ$G$6<1IQ'G$B<29Q*G$N<3)Q-G$Z<3YQ0G%&<
M4IQ3G%2<59Q6G%><6)Q9G%J<6YQ<G%V<7IQ?G&"<89QBG&.<9)QEG&:<9YQH
MG&F<:IQKG&R<;9QNG&^<<)QQG'*<<YQTG'6<=IQWG'B<>9QZG```>YQ]G'Z<
M@)R#G(2<B9R*G(R<CYR3G):<EYR8G)F<G9RJG*R<KYRYG+Z<OYS`G,&<PIS(
MG,F<T9S2G-J<VYS@G.&<S)S-G,Z<SYS0G-.<U)S5G-><V)S9G-R<W9S?G.*<
M?)>%EY&7DI>4EZ^7JY>CE[*7M)>QFK":MYI8GK::NIJ\FL&:P)K%FL*:RYK,
MFM&:19M#FT>;29M(FTV;49OHF`V9+IE5F529WYKAFN::[YKKFON:[9KYF@B;
M#YL3FQ^;(YN]GKZ>.WZ"GH>>B)Z+GI*>UI.=GI^>VY[<GMV>X)[?GN*>Z9[G
MGN6>ZI[OGB*?+)\OGSF?-Y\]GSZ?1)\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````XYSDG.6<YISGG.B<Z9SJG.N<[)SMG.Z<[YSP
MG/&<\ISSG/2<]9SVG/><^)SYG/J<^YS\G/V<_IS_G`"=`9T"G0.=!)T%G0:=
M!YT(G0F="IT+G0R=#9T.G0^=$)T1G1*=$YT4G16=%IT7G1B=&9T:G1N=')T=
MG1Z='YT@G2&=```BG2.=))TEG2:=)YTHG2F=*ITKG2R=+9TNG2^=,)TQG3*=
M,YTTG36=-ITWG3B=.9TZG3N=/)T]G3Z=/YU`G4&=0IT`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!#G42=19U&G4>=
M2)U)G4J=2YU,G4V=3IU/G5"=49U2G5.=5)U5G5:=5YU8G5F=6IU;G5R=79U>
MG5^=8)UAG6*=8YUDG66=9IUGG6B=:9UJG6N=;)UMG6Z=;YUPG7&=<IUSG72=
M=9UVG7>=>)UYG7J=>YU\G7V=?IU_G8"=@9T``(*=@YV$G86=AIV'G8B=B9V*
MG8N=C)V-G8Z=CYV0G9&=DIV3G92=E9V6G9>=F)V9G9J=FYV<G9V=GIV?G:"=
MH9VBG0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````*.=I)VEG::=IYVHG:F=JIVKG:R=K9VNG:^=L)VQG;*=LYVTG;6=
MMIVWG;B=N9VZG;N=O)V]G;Z=OYW`G<&=PIW#G<2=Q9W&G<>=R)W)G<J=RYW,
MG<V=SIW/G="=T9W2G=.=U)W5G=:=UYW8G=F=VIW;G=R=W9W>G=^=X)WAG0``
MXIWCG>2=Y9WFG>>=Z)WIG>J=ZYWLG>V=[IWOG?"=\9WRG?.=])WUG?:=]YWX
MG?F=^IW[G?R=_9W^G?^=`)X!G@*>````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````YX$G@6>!IX'G@B>"9X*G@N>#)X-
MG@Z>#YX0GA&>$IX3GA2>%9X6GA>>&)X9GAJ>&YX<GAV>'IXDGB>>+IXPGC2>
M.YX\GD">39Y0GE*>4YY4GE:>69Y=GE^>8)YAGF*>99YNGF^><IYTGG6>=IYW
MGGB>>9YZGGN>?)Y]GH">``"!GH.>A)Z%GH:>B9Z*GHR>C9Z.GH^>D)Z1GI2>
ME9Z6GI>>F)Z9GIJ>FYZ<GIZ>H)ZAGJ*>HYZDGJ6>IYZHGJF>JIX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"KGJR>
MK9ZNGJ^>L)ZQGK*>LYZUGK:>MYZYGKJ>O)Z_GL">P9["GL.>Q9[&GL>>R)[*
MGLN>S)[0GM*>TY[5GM:>UY[9GMJ>WI[AGN.>Y)[FGNB>ZY[LGNV>[I[PGO&>
M\I[SGO2>]9[VGO>>^)[ZGOV>_YX`GP&?`I\#GP2?!9\```:?!Y\(GPF?"I\,
MGP^?$9\2GQ2?%9\6GQB?&I\;GQR?'9\>GQ^?(9\CGR2?)9\FGR>?*)\IGRJ?
M*Y\MGRZ?,)\QGP``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#*?,Y\TGS6?-I\XGSJ?/)\_GT"?09]"GT.?19]&GT>?
M2)])GTJ?2Y],GTV?3I]/GU*?4Y]4GU6?5I]7GUB?69]:GUN?7)]=GUZ?7Y]@
MGV&?8I]CGV2?99]FGV>?:)]IGVJ?:Y]LGVV?;I]OGW"?<9]RGW.?=)]UGW:?
M=Y]XGP``>9]ZGWN??)]]GWZ?@9^"GXV?CI^/GY"?D9^2GY.?E)^5GY:?EY^8
MGYR?G9^>GZ&?HI^CGZ2?I9\L^7GYE?GG^?'Y````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````#/H-^@[Z#_H1^A/Z%/H8
M^A_Z(/HA^B/Z)/HG^BCZ*?I8```````````````1````6AD9"%\9&0CT^A@(
M`````"`<(0@@&R$((!HA"``````````````````````````````````````!
M`````0````(``````/\`H!DA"&",)0@`````N-<'"/S7!PC<K`@()*T("%#?
M!PAP=@<(&-\'"$C>!P@`W0<(-&@'"%1H!PAT:`<(F&@'"+QI!PAL<0<(/'('
M""1V!PA`:@<(P&L'"!AM!PA$;P<()'$'".1Y!PB\=0<(````````````````
M```````````````````````!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<
M'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)
M2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$149'2$E*2TQ-3D]045)35%56
M5UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*C
MI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0
MT=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]
M_O\``0(#!`4&!P@)"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ
M*RPM+B\P,3(S-#4V-S@Y.CL\/3X_0&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W
M>'EZ6UQ=7E]@86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'U^?X"!@H.$
MA8:'B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["Q
MLK.TM;:WN+FZN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;W-W>
MW^#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CY^OO\_?[_`"`@("`@("`@("@H
M*"@H("`@("`@("`@("`@("`@("`@2!`0$!`0$!`0$!`0$!`0$(2$A(2$A(2$
MA(00$!`0$!`0@8&!@8&!`0$!`0$!`0$!`0$!`0$!`0$!`0$0$!`0$!""@H*"
M@H("`@("`@("`@("`@("`@("`@("`A`0$!`@$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!``````````````````````````````````````
M````````#0``````````````80```%H9&0AH&1D(]/H8"``````@'"$((!LA
M""`:(0C@'2$(`````````````````````````````````0````$````"````
M``#_`*`9(0B@'2$(`````"#8!PA4V0<(\-H'"*3;!P@TJ0@(O&@'",RM"`C8
M:0<(```````````````````````````````````````!`@,$!08'"`D*"PP-
M#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ
M.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=865I;7%U>7V!!0D-$149'
M2$E*2TQ-3D]045)35%565UA96GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1DI.4
ME9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!
MPL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN
M[_#Q\O/T]?;W^/GZ^_S]_O])@0``E(&0@9.!E8$``&F!:H&6@7N!0X$``$2!
M7H%/@E""48)2@E."5()5@E:"5X)8@D:!1X&#@8&!A(%(@9>!8()A@F*"8X)D
M@F6"9H)G@FB":8)J@FN";()M@FZ";X)P@G&"<H)S@G2"=8)V@G>">()Y@FV!
M``!N@4^!48%-@8&"@H*#@H2"A8*&@H>"B(*)@HJ"BX*,@HV"CH*/@I""D8*2
M@I."E(*5@I:"EX*8@IF"FH)O@6*!<($```````"A`*(`HP"D`*4`I@"G`*@`
MJ0"J`*L`K`"M`*X`KP"P`+$`L@"S`+0`M0"V`+<`N`"Y`+H`NP"\`+T`O@"_
M`,``P0#"`,,`Q`#%`,8`QP#(`,D`R@#+`,P`S0#.`,\`T`#1`-(`TP#4`-4`
MU@#7`-@`V0#:`-L`W`#=`-X`WP``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````%"!``"/@0``````````````````````````
M``"WD@````````````````````#EE@``>.A-D0```````'GH``#"E7KH2HH`
M``````!;B0``U8H``-2*>^@``'SH``!]Z'[H````````````````@.@``-:*
M=(I]C;24``""Z('H``````````"#Z```````````>XD```````````````"&
MZ```A>B$Z```A^@``````````(KH````````Q8@`````B.@``(SHB^@`````
M``````````".Z(WHC^@``*R3````````D.@``````````)'HD^@`````DN@`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````",E0``````````E.@```````````````"5Z```
MXXT```````"6Z)?H`````&B6`````````````````````&J1````````HHC)
MD0``F.@``(V5````````````````F^B9Z'Z-``":Z,",````````````````
M``````````##E9WHG^B>Z*#H`````$")=Y"<C]>*H>@```````"&E```H^@`
M``````!!B0``HNC"D@``RY>IDYSHI)<``*^,`````'J7````````````````
M``#WB[*7``!'C```X)%`Y```I.A+BH^0``````````!UBJ;H``"GZ*7HA(P`
M`-N-X8\```````!"B0````#7EP```````*GHK.<``*CH`````````````*SH
MJNBKZ```K>@``*[HZI>OZ+#H``#'D+F4````````G9#EB@````!9E^N)5X_9
MC```L^@``++HDXZTZ+'H`````$>.````````N.BKY0````#4F0``EY"VZ```
M``````````"CE^^3``````````!*B0``X9"TC@``````````M94``%^)````
M````ZY>+EP``N>@``&23``````````#YC@```````+KH``"[Z&N0O.@``.R7
M`````+?HONC`Z```O^@``+WH`````,'H`````,+H`````)J1``#@B0``````
M``````##Z`````"VE@````#$Z`````````````#%Z```29@`````````````
M4)[&Z````````,?HR.@```````#,Z```R>@``,KH``#+Z,WH````````````
M`````````,*0````````]98`````PY``````SN@``/&4``#/Z'+JRI8``-#H
M``#1Z```TNAVB@``U.@``'B0````````U>@`````0XP``````````-;HVN@`
M`-CH``````````#9Z`````"3BM?HV^@``````````-SH``#&B```W>C>Z```
M````````````````XH\```````#?Z````````&:+`````.+H`````.'H``#@
MZ`````"1Y@``VI4`````````````X^CDZ```````````````````````````
M``````````#EZ`````#FZ```Y^@`````Z.@``````````````````-B*````
M`````````````````.GH````````````````````````````````````````
M``#JZ$*4````````[.BYB0``[^CNZ```````````0XD```````"_BP``Q96X
MDJ"-``"`C8>/``![D````````/'H`````/#H89?FBM"4VI,```````"<D,R7
M``!ZC````````````````/3H`````//H``````````````````!JEJJ3````
M````````````;XD`````]>CRZ`````!PE8J7]N@`````````````````````
M]^@``````````/GHZ)%ZBGN*^.@``````````.>*L(P`````Z(H`````7I,`
M````WI<`````````````````````VHP```````#ZZ````````/OH_.A`Z0``
M0NE!Z0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````)>5``!#Z0``````````1.D``$7I``````````!&
MZ0```````````````````````````````$CI1^D``$GI````````````````
M`````````````````````````````````````/*4RN,`````2)``````48L`
M``````````````!*Z0``2^D``*J96I_1E`````#YB```N8@`````````````
M`````)2.3Y;\CP``````````3.D``-V6````````3>E[EP``88D```````!@
MC@``3NGLB4_I````````4.D``````````%+I4^D``%7I4>D`````5.D`````
M``#9B@```````%;I``!7Z0````````````````````````````````````!8
MZ5GI````````6ND`````7.D```````!;Z0``7NEAZ0```````%WI7^E@Z0``
M``!BZ0``P(L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````\8YC
MZ63I@8T`````````````````````````````9>D`````78H```````!NE&;I
M9^D``````````'F2Z9,``````````````````&CI``````````"=E`````#*
MD7>)[(L``.V+``````````````````"3DFWI[HL`````[8D`````;.D`````
M:ND``&OI``!IZ0````!WZ0``````````````````````````;NEOZ0````!P
MZ7'I`````````````'/I`````'+I````````>(\``'3I````````=ND`````
M````````````````4HMUZ0````";D;&,`````````````'CI````````````
M`````````````````````````,N1`````'GI``````````"KDP``````````
M`````'KI````````````````@.D``'WI``!\Z7[I``![Z0``````````````
M````@ND``````````````````('I``"$Z0````#!BX/I````````A>D`````
MAND``(CIA^D```````")Z8OIBND`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"<C0``````````C.D`````C>D``````````````````%N*````````
MCND```````"/Z0```````)&0``````````````````````````"0Z0``D>D`
M`)+ID^D```````""C0````````````"4Z97I`````);IE^D`````F.D`````
M``"OE)KI``!%E9OIF>D``)WI`````)SI`````)[I````````G^D`````````
M`````````````````*#I````````````````````````````````````````
M`````*'I``"BZ0``````````H^D`````I.FEZ0``IND``*?IJ.FIZ:KI````
M````J^FLZ0``5)^MZ0````````````````````#VXE.+``````````!`BK"-
MK^FNZ:.6``````````````````"QZ;+IL.D``+/I`````(*6````````M.D`
M`)N+`````````````````````````````````````````````````````$28
M``````````"UZ0````````````````````````````````````"WZ0``````
M````````````````````O(@`````N.FIE;;I`````+GINND`````````````
M`````+OIO.D``````````````````+WI``".EDR.``#XC4Z1````````````
M`+[I``````````#!Z0```````````````+_I`````````````,+I`````.^,
MP.D``````````,/I``#$Z<7I``#)Z0``28X``````````.*1````````````
M`,KIQ^G&Z<CI````````?HP``````````````````,[IS>G,Z0````"QB```
M``````````````````````````````````#8Z0``U.D``-7IT>G7Z0``T^F"
MB@````!KF```UNG2Z=#IS^D`````````````VND`````````````W>D`````
MW.G;Z0``````````````````:)79Z?&(WND``.#I````````````````CXK+
MZ5:)`````.+I``````````````````#AZ=_I3)(`````````````````````
M``"0E@``````````V)<`````X^D`````````````Y.D```````````````#E
MZ0````````````````````````````````````#FZ0``Y^D`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"YD@``Z.D``+64``#MZ>GI````
M````ZND`````4);"E@``SI,```````````````````````````````#NZ0``
M``#OZ;R3[.GKZ0``````````J(D```````#WZ0````#VZ0````````````"5
MB0```````/3I````````\^D`````\>D``)N*``#PZ;".IXD`````````````
M````````````````````````@XT`````^NGYZ0``^.D`````]>D``/OI``#\
MZ0``````````````````1.I#Z@``````````````````1>H`````3(E`ZD'J
M``"4C;>6`````$+J``````````````````!1E@````!*Z@````!&Z@``````
M````````````2^H```````````````````````````````!(Z@``1^H`````
M````````>XP``````````````````````````$SJ````````````````````
M````3>H``````````$[J``!)Z@```````/+I`````$_J``#?D@```````%/J
M``!4ZE+J`````````````%'J5^H``%#J``!5Z@````````````````````!6
MZ@```````%GJ`````````````%CJ````````````````````````````````
M6^H```````````````!<Z@``7>H`````:)@`````````````6NKID>N-````
M`%[J````````````````````````````````````````````````````````
M``````````````````!?ZF#J`````&'J````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````&+J`````+*,8^H```````!DZ@``K8X``&7J````
M````````````9NH`````9^IHZ@``````````:^IIZEN8``!JZ@``[9<`````
M````````;.H``-F7`````````````&WJGI0`````;NIPZ@````!QZ@``````
M````````````````````;^J-C<N6@Y;UFP``@)^;E@``````````J8D`````
M`````````````'/J;XMTZG7J=NH``)6-``!WZ@```````-+@V98``.&1>.IZ
MZGGJ``![Z@``````````?.H`````?>H```````````````!^Z@``````````
M@.H``('J@NH``(/J``"$ZH7JANH```````````````````````"'ZHCJ````
M`````````$.3``````````#;C```BNH``````````````````````````&R1
MB^H``````````````````````````(SJ````````````````````````````
M`````````$"5`````(WJ`````````````````````````````([J5N(`````
MV.;KZ`````"/Z@``D.H``````````````````````````)+JD^J4ZNZ7D>H`
M````E>J6Z@````"8Z@``E^H`````````````FNH```````";ZIGJ````````
M````````````````````````````````````````````````M)<`````````
M`````````)SJ````````````````G>ISX@````">Z@```````````````.J(
MFI(``+6.````````G);DCT^.XX^ZB0``<Y5>EP``H)A.B0````".BJ&8HI#`
MF76+N)4``````````.6/`````+R7``````````#`E0```````**8`````(:2
M````````HYCXBP```````*28``#;BD^2``#ECJ68`````*:8`````*>85)0`
M`':+`````````````%:4``#AD\&,4I8`````````````:.6HF.:/J9BSB0``
M`````..+[HSGE@````"DFP````````````````````````````````````"0
MEP``^Y,``````````````````````````*.*``!4BP``JI@`````JYBYEP``
M7)>(D:V8EH[QDP``L)@`````78G=C```W(SDB`````!JF&F8``"QC9^(``"Q
MF+*8LYA3EK28``#PC.6(DI8``)R+`````)V+GHO@DKJ7``"UF`````"VF```
M``"WF````````&R0`````````````%F/;9"\F```NI@``+N8=XL`````H8WN
MB0``N9BXF*>5``````````!ECF2.O)&]F'25Y9````````!7@;Z8P)@`````
M``#CD=^7R(@``````````````````+^8O(D``,*+``"'D@```````(^,P9@`
M``````!#E`````````````#IB@``````````````````PIC)B`````#>C.J*
MFI6PE'B+`````````````````````.^)``#EF&"3````````````````````
M`````````````````````````(R4Q)@```````"ZE```X)<``$R0``!FC@``
MEXZ^B0````````````#/D@````!!DLB8`````````````,J(X9):C[*-0Y<`
M`,R1``"]B0``QY@``%V7PYC%F.R-QIA#FP``````````````````````````
MSI@`````````````T9C/F`````#`B0``N97)F```````````S9CQC`````!G
MC@```````*2*`````-*8``#*F`````#AEP``F(X``,N8``#0F```````````
MTY@``,R8`````)^+``#+B`````"@B[^)````````````````````````1)L`
M`)F6CI7RC`````````````!.D+67`````````````````````-:5`````%>,
MHY'BB0````````````!RCP```````->8``#<F-J8`````-68`````*V1V)@`
M`-N8V9@``-N5``#6F```39```).6W9C>F`````````````````````!#C^N8
M````````;Y0``%65YI@``.Z5``"TB0```````.J8````````````````Y)CM
MF`````!QD0``PHP``'N4``#%X```[)A\DP``X9@``/2,`````/.,WY@`````
M`````-B.``#GF```[95LDN.8D8P``."8Z)CBF,^7Z9A@F```````````````
M``````#DBP````"0C````````````````````````.Z8````````[YCSF,R(
M`````````````,Z5\I@``````````/&8]9@```````#TF```XI(`````````
M````````````DHP```````````````#VF`````````````##C@``I)'CDO2+
M``#WF```````````58L`````^)@``````````/J8``````````````````!4
ME@```````(:,````````````````4([UE/F8````````````````````````
M`````````````````````,.-8I<``````````/R80IG[F,*-``"=CP``````
M`````````%B,````````0YD`````S8L```````!`F4&9`````*V3``"<D0``
MH8L```````!LED29````````NY<```````!%F0``````````2)D``$:9``!M
MD0````````````!'F4F9````````````````2YD```````!*F0``QI4`````
M`````%:+39E.F0``K8D``````````$R9`````````````````````/*.``!1
MF5"93YD``-28``!2F0``````````GH\``%.9`````````````````````$27
M``````````````````#7E@``````````59D`````5)E7F5:9`````%B969GR
MB```LXQ:C%N/FY*BB^:0]8P``(Z-6YG&EF63``"9C@``6ID``%R9````````
M`````'V3``"5B@````````````!=F0````#\DP````!3D5^98)FJE/:,6IAA
MF0````"DBP```````+J5M)'OBU23````````DXP```````!BF0``8YD`````
MX)-^B0````!FF?N-``!EF<2-``!GF>SC:)E@EFF9``!JF6N9YX\``,J.````
M````````````I8H``&Z9``!LF;N6;9D``'F5;YEPF7&9?I,```````!UF7.9
M=)ERF>&-=IGHEN*7`````````````'>9````````````````II!XF7F/````
M`'F9``"<DKV7@),`````````````````````PYD``````````'J9H^K#BP``
M``![F7V6``````````"(C_J1``!]F>*3`````'Z9`````("938H```````"!
MF:6+``#*DYJ);X\`````GY2"F0``@9,`````;I"#F0``JI78D*"*``"GBH29
M`````(:9`````%F,`````(69`````/&7`````````````(F/````````````
M````NY3*E0``AYD``)B7B)D```````")F0``GI,`````BID`````IY#\C92,
MBYEHCH^-``````````````````#DDHV9`````*61`````.V-CIF/F4^1``",
MF0``````````D9D``%66``````````"$C0````"0F0``````````E8S<C8V4
M````````E)F2F0``````````FY7HCYN9A(J5F9.9;I$`````````````````
M`)>9``"6F0```````&.*````````@(R<F:N7````````F)D```````"=F9J9
M``"9F0```````````````,V7````````]XS!B0````#REP````````````"5
MCW>3A8V@F:&9````````XY<`````2IBCF0```````/B,`````**9``!.B@``
M``"DF0``=98``+J2``!%EP``UY4```````"EF0``````````T^@`````KI,`
M`*:9J(JQE@```````)^/IYGEE:N9``"HD*B9SHL``*F9J8H`````````````
M`````````````$V,K)D``*V9`````*Z9KYG9C@```````/F,W)8``.:6]9,`
M````[Y6PF0``L9D``````````+.9``"UF;29``````````"VF;N):Y8``/J-
MMYD`````>)$`````H(^GBP``N)D```````````````#9E```````````N9D`
M`+J9``"[F0``````````O)E#E>:+XX@```````"]D[V97(\``.>0``"_F;Z9
MH8_?C,&9O)0`````PID```````#:E+*1[)&FBP````#LDU"2``".E```;98`
M`,29``#HD`````````````!4C`````#%F0``````````QIE+B?.(ZXH``*:1
M<(N1EP``R9FUB0````#(F0```````*B+`````,J9``#OE@``````````````
M``````````````````````````````#+F0``T)<``/J,``````````"TC,R9
M``````````#.F<V9``!^D%B)````````?8G/F0``T)D`````M8P`````T9D`
M`````````(Z+````````````````48[2F0``````````E):SC7F+1I=OD;V4
M^XX`````````````9H\``.:.\XX``):/``"^E````````-69``!BB7"1^XS#
MC.6+`````-F90)+\D:F+HH_:F=B9PHGDD;:.:HY%B0````"0BH:-:8X``-N9
M````````````````W)D``&B+98H```````"'C6>+W9)$B:^3O)9`C9F79I/\
MC````````````````````````$Z,``#EF0``X8MIE@````````````#;E```
M``#DF0``W(K?F>"9XID``````````````````..9``!ZBX&0``"KE>&9W9GA
MC```WID``$.8````````\)4``.:2X(R0C0```````.:9`````-N3````````
M``````````````````````````#JF0````````````````````#\C@``](X`
M````````````[9GKF0``H98``.B9\9GLF0```````.^9Q(R]E@````#PF0``
M`````/*9``#TF0``````````[HUAF```Z9GGF?.9``#NF0``````````````
M`````````````````````````/:9``!"FOB9`````/R9`````$":^9D`````
M79H`````YXU0B@``````````]YD```````!$FO2(0YH``*.(:95!F@``^ID`
M````]9G[F<:-`````````````````````````````````````$6:````````
M`````````````/6(3IH`````1II'F@``HX^)E@```````$R:2YH```````!.
MDP``````````````````39H`````2IH```````````````!3B0``M(U/D```
M````````````````2)J"DP```````$F:``"@B```````````````````````
M``````````````````````````````````````!3FD*7``"ECP``69H`````
M`````%B:3YH``````````,&1``!0F@```````.V159JDCP````````````!2
MF@````#BE@```````%N,`````%::5YH``````````%2:6IH`````````````
M49H`````````````````````````````````````````````````````````
M````8)IEF@``89H``%R:`````&::4)$`````:)H``$&-7IJ=D@``````````
M`````````````````````&*:6YJKB@``[(J%BF.:7YH`````````````````
M`):,:9IGFG*1:8NJBP``9)H``/*+`````````````&.)````````````````
M``````````````````!MFFN:``"EF@``````````````````````````````
M`'":`````````````&J:``!NF@````!LF@```````&N.;YH`````````````
M``````````````````````````````````!RF@``=YH```````!UFG2:````
M``````````````!1D@````##B0``````````````````````````<9H``'.:
MIH]2B0````!VF@``````````````````````````````````W(D`````````
M````@IH``/J/?9H``'N:``!\F@``?IH```````````````````````!<B0``
M`````````````````````%B1``!XF@``>9H`````````````````````````
M`)J*`````````````````````(&:````````[8H``(2:@)J#F@``````````
M````````K)4```````#3DP``MI0`````````````AIH`````````````A9ID
MB@````"'F@``````````BIH``````````(F:````````````````````````
M`````(B:``!8E`````"+F@````````````````````",F@````````````".
MF@``C9H`````````````D)H```````"3FI&:CYJ2F@``````````E)H`````
M````````E9H`````EIH``)>:````````F)IDF0``^HYLC@````#QB0``]H@`
M````8Y(``````````````````````````)F:``"BC0``S8A]D```````````
M``":FL6,`````)&-``"<FIN:`````-Z5G9H```````"?FIZ:``"@F@``H9H`
M`)>,`````(")HIH`````I)H``*.:````````IIH`````>9,`````````````
M``"GFK.(W8T``````````%R,`````&Z2````````````````J)JIF@````"K
MF@``````````K)H``.*-``````````#/BP````!6E@```````*J:K9J_C4*-
M````````````````````````````````````````L9H`````HXT``%*2````
M`*Z:V)(`````````````````````````````````````````````````````
MLIH`````@I``````````````L)JSF@``7HP``````````````````+2:````
M````````````````````````````M9H``$.-7XJWF@````````````"XF@``
M``````````"YF@````"VF@```````````````````````````````*^:````
M`+J:`````+N:``````````"$E@````#ICP```````+V:OIJ\F@``P)H`````
M````````5Y0`````YHAUE0````#!F@``````````````````````````````
M````````````^X\`````MXX``'R4[HH``.F-````````>)8``+"3`````)B,
MS9$```````"_FL*:````````````````````````PI$```````##F@``````
M`,2:````````QIH`````YY(`````````````K(H``````````)_J@8GQE0``
M``#JCV>3``````````#DC0````#,F@````"[E=N7````````````````````
M`/*)R)H`````````````69'+F@``@Y,`````:).$D[>4RY(```````#'C0``
M`````,>:````````````````EHD``%63``````````#)F@``Q9H`````;Y``
M``````#-F@``````````;8\``````````*N+``#.F@``````````````````
M````````````````YI4```````"=D0``````````Q)(`````T)H`````````
M````````````;I8`````T9H`````UIH``````````*V5``````````#5FL^:
MTIK4F@````"DC0````#'E0```````->:``!DD@````#SB0``ZX\`````````
M`-F:``#8F@``B(T``-J:W)K;F@````#>F@``TYK@F@``````````WYK=F@``
M``````````!MCG"0``!SD>&:NI#KB(24``````````#9D@``XYKBFN2:Y9KF
MF@``````````YYH```````````````#/E>B:``````````#$B>F:````````
M``!;ET^*``#'F6>/O9'JFNF6`````````````+*6`````.R:``#ED0``5I.^
MD7:5[9KNFIN)`````+B.[YH``````````,Z(\)H`````````````\9H`````
M````````@HD`````[XK>D_*5``````````#UFG21])I?C`````!ZEO.:``"%
MD_>:``#VF@````````````#YF@``^)H`````G(D``/J:IX_\FD22``#[F@``
ML94``````````)>/>I,```````!`FP``````````1(T```````!!FT"4W)3/
ME@````````````!$E`````!*FP````````````!7BP````!DEP````"ME@``
MJIL``$*;`````````````$6;``##D0````!7E@```````&F3````````````
M`$:;````````````````A98``,B-`````*B/``````````````````!'FP``
M``!OC@``;HX``````````+>(QHP``*F0SX@``````````$N;3)L``$F;````
M`````````````````%>)K8H``$B;``##EE"5````````````````````````
M``"FB```````````]X@```````!PC@``T(@``*&(`````````````%&;````
M``````````````!/FP```````````````+J6``!2FP``4)L`````3IM0D```
M````````39L```````#8E0````````````#BC`````````````!6FU>;````
M`````````*F/````````4YM+F```````````:Y0`````59L`````````````
M`````````````````````````````*6-``````````````````!8FP``````
M`'>5````````69L``%2;````````````````````````````````````````
M````````N98```````````````````````````````````````````````!]
ME```````````````````6IM1E0``````````````````````````````````
M``````````````````````````````````````````````````!;FU^;7)L`
M````Q8E>FP```````````````+F.``!=FYF,````````:YL`````````````
M9)MAFP```````````````````````(22``!@FP````!BFP````!CFP``````
M````````````````````````````````````99MFFP``````````````````
M````````````````\(H``&B;9YL```````````````````````!IFP``````
M``````````````````````#LCP``````````````````;)L``-J2````````
M9(D``&J;````````;9L``````````````````&Z;``!QFP````!OFP``<)L`
M`````````````````````````'&.<IL`````18USFP``FHZVD0``=)MUFWF.
M1HT``-"6````````1XO'C':;=XH`````=YL``+>1``````````!XFZ&;``!Y
MFP``>IL`````>YL``'V;`````````````'Z;`````(";``#ND0``1HGGCL"(
M``!VD:Z*LXX``$>-`````````````(:3``!`CZ^*B)+HDK:(6(OSE0``P(X`
M````<8OID+J.1Y>!FP``````````````````>XL``,F-`````%&*@XFJC\:)
M``""FV67`````````````&B/`````.*.@YOQBM"3IY:$FP``A9L`````>)4`
M``````"'FP``IHKUBX:;````````````````L(H``%&0BYM`C@``QXF*FP``
MB)N,FXF;2I3+GE*0``"-FP````"^EP``CIL`````D)L``)Z2CYL``*&0``";
MC@```````,Z1]8X``)65ZI```,N.D9NKCY*;DYO1B+B1<9```)2;L9.LCP``
MK8\``)6;`````.N0````````KH\`````````````EIL``)>;``#>E@``````
M`)B;``````````#$BP```````$&/````````````````F9N:F]J.2Y#RDW.0
M]I1!E,>+FYL```````"/BYR;``#\BP``S9.NB0``<HZ=FZ";GYO[BP``GIL`
M`%>3`````````````````````*Z1``!JD\:.`````'>1FI<`````````````
M``"BFP``HYO4DP``4HX``````````*6;`````*:;````````````````````
M````````````````````````````IYL```````#RBJB;`````*F;````````
M````````````````````````JHD```````````````!:D>**``"KFZ:6````
M``````#0D0``>(H`````K9NOF]V*`````*R;KIL``+&;````````````````
ML)L``+*;`````````````````````````````````````````````+.;````
M````````````NY.LBP```````````````..)M)NYFP````"WFP``]97TE0``
M``````````"'DP```````+:;<X\``+6;````````````````````````DI``
M``````"ZFP````#HC0````#`FP````#!F[N;4HJ\F\6;Q)O#F[^;````````
MOIL`````PIL```````````````#VE0``````````````````````````````
M`````````````````````````````````````````````````````````,F;
MQIL``,B;``"2EP``QYL```````````````````````"]FP``````````````
M`````````````````).0`````,J;`````+6-````````RYL`````S)L`````
M````````````````````````SYL``,Z;`````,V;````````B).XFP``````
M`-6;````````````````````````````````T9L``````````-";````````
M````````````````TIL``-.;`````````````````````-:;`````.27``#7
MF]2;`````````````````````````````-B;`````-Z*V9L``````````-N;
MVIL`````W)L``````````-V;``#LD$*/`````(2/``"#D0``2(VVC4F-D(L`
M````WIL`````MXT`````R(S?FZ268I3@FP``2HT```````"JB@``1I+0BP``
M`````'..>I4`````OY0``````````.&;\XH``````````.2;``````````"?
MD@````#CF^*;Y9L``.F2``````````````````"#D`````````````!TC@``
MR)```-&108L`````H)(`````YIOGF^V/``````````!8E@````#JFP````#I
MF^B;G94``/&;``````````!YE@``ZYL`````````````[9N+E@``[)L`````
M`````````````.Z;``"FE.^;O)7PFP``````````````````````````````
M````L8J]E4Z4\IOSFP``2XVRBO2;MHQCETB7](KVFP``H9(``$R-KX\`````
MW90`````L(\``````````)B/`````````````.J2]Y58DP````!-C0``>Y4`
M``````#WFP````````````!XD\"-````````R8P``.N2````````````````
M``#!B(Z/3HUFEP````````````````````#XF_F;<)0``````````/J;]9=,
MF```````````_)O[FP````!FB@````!`G````````$.<1)P``$*<``!?E;&/
M1IQ%G$&<``````````!'G$B<`````$F<````````3)Q*G```2YQ-G```A(GL
MDDZ<``":C/2)590``$^<^9,``-F5``!0G$V8``````````!1G+Z55)R?F*^8
M``"NCO.359P``'R+HI+XB%:<I)5/C0````!OD@```````.V2````````````
M`.V6MXS*C```5YP```````!8G```7IP``...````````HY(``*V+69P`````
M``!*E0``99(`````6IP```````````````!;G```KHL``%R<``!=G`````!?
MG```EI,`````8)QAG```8IP`````4YQ2G````````&.<8(P```````!&E0``
M``#*C5:5I))JE62<`````+*/98D``&6<````````9IP``/"6`````-Z4````
M`&F<G8FJD&B<9YQAC-*1``!MG&N<``!JG*67XXP```````"9CVR<:Y-=CP``
M`````+Z3<)QOG```````````;IP``'&<Y(P```````````````!RG)R5>H\`
M````<YSWE```````````OY.ED@``````````3Y,`````=)Q*BP``````````
M``!3D```2Y4```````````````#UBD64`````````````````````'6<=8Y9
MEEJ6`````)Z)>IP`````B9(```````!WG````````````````/6)````````
M``"KG'F<````````3Y0`````>)P`````=IP``)J-``!\G```````````````
M``````````````````````"#G(F<@9P``'N3`````(:<?)4`````@)P``(6<
MY9=VC@````#3D7V<````````?8N(G*N0A8F"G/:)AYP```````"OBP``A)P`
M````````````````````BIP```````````````",G):<E)P`````D9P`````
M``"0G/:7``"2G`````"PBP``4(T`````FH\```````"9G(N<``````````"/
MG'Z<``#XB9.<E9QPD@````"FC;:)C9R8G)><L8L``*>1AHH``````````&*,
M``".G````````````````````````)J<``"=G)^<``````````"[C@``I9SN
MDIN<``````````"CG```]XD``*&<HIP`````GIR@G````````.6,29<`````
MLXH`````>(FDG```692KB```````````````````WY1[G*J<KISCE@``IYP`
M``````")DZR<``````````````````#NCZV<U9,`````````````````````
M``!FF```J9P``````````*^<``";C0``R9``````THBHG*:<``!YD0``````
M`)R<4XX``````````````````,21NYP``'J1MIP``+.<M)P``.2.MYRZG```
M````````M9Q$CP``N)P`````LIP``/J6^98```````"\G+V<TX@`````````
M````L9P``````````/"+I(@```````"TB@``N9P`````````````P9S`G```
M`````,6<``````````````````#&G```````````````````Q)S'G+^<PYP`
M````R)P``,F<`````+Z<G(X``,*<U)%1C;"<5)```````````-:<``#GE0``
M``#,G,V<SIP`````U9P``-2<`````)V6M8H``-*<``!DC%.*`````,^<````
M`+:7T9S4B-.<``#*G-"<UYQCC,N<````````````````?)<```````!*EP``
M````````VIP`````WIP```````">D0``]Y??G`````#<G```V9P`````V)S=
MG````````````````````````*Z5`````+*3``!EC```X)S;G```X9P`````
M``";C````````*^)````````Z9P```````"VB@``````````YYP`````Z)RG
MC>:<Y)SCG.J<XISLG`````#YB0``````````````````````````````````
M`````````````.Z<`````.V<`````````````````````````````*:2``#Q
MG```[YSEG)R,``#PG```])SSG/6<\ISVG```````````````````]YSXG.B5
M``#ZG/F<7H\``*R0Y(GZB0``^YP``+V(````````RI#\G```P>9`G8&,``!!
MG0``````````[9````````!"G0```````$.=68M$G0``19U&G=61````````
MRXP`````WY8```````!;EHJ/1YT`````````````[I"[Y^"4``#HC@``RXU(
MG0``````````Q9$``*65`````.^1`````$N=`````$F=``!,G0````!*G0``
M````````39T`````````````KY4`````M8@``````````'V5`````.&4````
M`$Z=``!1G;./6HL``$^=5IVTCP``````````4)UCE````````````````'V7
M4IU3G5>=BI-4G5*-W)``````99VRE```\)$`````````````````````````
M``````#BE*N=``````````#XE0```````.^2````````E98``%J=GXF*D@``
M````````8YT`````4Y)=G62=7YUFG6*=``!AG8^4``!;G?N)69V1B_&159T`
M````6)U3C=F0``"UCV"=<90`````DHMGB@``````````````````````````
MAXI`D&B=;9T``&F=``"=C```;IU!CHF-````````````````18]<G0``G8YK
MG0``````````=XYLG<*(`````&>=``````````"GD@``````````````````
MDXL`````````````LHL``````````````````&J=I8@`````P8T```````!5
MD```````````````````````````\)(`````TI1PG7V1````````````````
M````````J)$`````2HYQG0``<YUOG0``````````WY4``+N2``````````![
MD0``````````````````````````^97,CH"=``!^G0````"8D````````)Z,
M````````>)VWCP````#FDU"4``````````!VG0````!\D0``````````]HY[
MG0````"VCP``=9UZG0````!RE````````'2=``!`C`````!\B@```````'R=
MJ9?,C522>9T``-J0``!4C820AHE;D7>=9(L`````````````9HP``,V2?9T`
M````````````?I$`````@9T``(.=`````+61B9T``(2=`````(:=````````
M`````&"5\9(``(>=````````2Y<```````!GE[>*`````````````*R(``"%
MG0````````````""G0``````````]HH`````````````AXD``(B=````````
M:)<`````````````````````````````C)T```````````````"YD0``DYT`
M``````"-G0````"*G9&=``````````!RG0```````````````````````(Z=
M``"2G0```````,"4BY,```````````````"+G0``CYT```````!GC```````
M`.^-````````VY``````````````````````````````EYT`````````````
M``````````!%DP````````````````````````````````````"4G0``@)8`
M````````````E9T```````````````"6G0``S)8``*"0````````````````
M`````(*,``````````"=G0```````````````````````%2.FIT``)F=````
M``````!1E````````+.3`````````````%"3FYT```````"<G0``CY4``&24
M0HX``.^0``!OE@```````````````&B*``"CG9Z=``````````!IEZ6=````
M`*&=``"BG0````````````"`D0``````````H)T``%Z=````````I)T``)^=
M`````````````*F=JIU&DZR=`````$..IYT``````````%N+`````*V=``"F
MG;&=``"PG0``KYT```````"RG0````"TG>^/``"SG0``````````MYT`````
M``````````````````````````````````````````"UG0```````+:=D)T`
M````````````N9VXG0````````````"8G;J=KIT`````>(X``````````+N=
MO)V^G;V=OYW\B0``58T`````^I6MD`````````````#,C`````#!G0``````
M````Q)T``'&5``!^BP```````,.=PIUSE,6=LXL```````#'G<:=````````
MN(I5C@````#6DP````````````!HC````````)20``#(G0``KI!'DP``?I7)
MG0```````````````````````,J=RYT```````"VE7R;Q)``````:Y4``-:-
M``#CE,&4`````````````&R3``"_EP``S9W.C@````#.G0``M(@`````THO+
MD```@)4```````#/G6&.9I(``'J.5I````````````````#0G0``^Y4`````
MEXE[C@```````-.=``#1G=2=MY?2G0``````````^9#5G0````"PD0````#6
MG0``````````^(H``-B=``#7G0``````````V9W:G?F*`````/J359*,BWR.
M@9$`````>X^NB````````-N=`````````````````````*")WYT`````````
M``````!6C=Z=`````*F-N(\`````W9T``+F/``"^EJB-````````U8C,D```
M````````````````Y)T`````KY!FB0``````````=(\``(:6\(T`````````
M`+J/``"ED```````````XYWAG>*=`````````````(N2`````$6>``#HG9Z.
M5XWFG0``````````YYT``%>0````````Y9T`````3HX`````````````````
M`````````.J=Z9WNG0````#OG0``ZYT``$&*[)WMG=.4``````````"!E6F,
M\)T```````"PD```NX\```````!QD@```````````````,6+``#QG?6=````
M`,F)\IWTG0``````````\YT`````BX\``````````&>2PXCVG0``````````
M]YT``````````*B2````````[Y<``````````&*.`````.F5````````````
M`%R6````````09[YG0````#\G0``^YT`````^)T`````0)X`````W),``/J=
M````````````````````````````````0IX`````C(]#G@``:I>8E`````!$
MG@````````````!&G@````!'G@```````````````$B>``#(BV>)6(U)G@``
M2IZ1CX*1`````-:979%<D=:1Q8T`````\)@``````````(Z,3)<``/R5``">
ME0``2YX``````````/&-O9),GDZ8````````798``*F239[ZB@``````````
M`````$Z>3Y[8E@``HI:6EGN61(Y1G@````#IC@````!PE@``4YY6GE6>``#W
MB@````"`BP``4IX``%2>``````````!7G@````"9D```````````FY?'B-Z-
MNI$``-N.`````/&/`````%J>`````&V3``!8GJF169[PC]N66YY<GHB7````
M``````!AG@````!9C0``=)1>GHR3W)W@G0``;HL``&:4``````````!@G@``
MO(_"E`````````````!FG@``^)0``%V>``!CGF*>````````S9``````````
M`(V6``#1EP````"'E@``RHE]C@````!GF&6>E9````````!DG@````!?G@``
M``````````#-C````````&N>:9X``,N)9YYMGG.>``````````````````#&
MD0````"_E0``=9X```````!!E0```````'2>D)1>EKF*``#UD%^/````````
MT9(``$V7`````'">;YX```````!QG@``;IX`````=IX``&R>`````&J>``!R
MGFB>``",D@``]I;$CO*-`````````````+B-`````(^68(H`````S)+(DVB)
M`````````````````````````````````````/"0`````+*028P`````````
M``````!XG@````!:C9R*````````````````>IZ4BH&>````````````````
M?9X``/&0````````:HJJC0````!IBLV-`````'N>A8QJC(V3`````'F>``#$
MB```````````?)Y^G@``RXM+C```NHIJBP``````````@IX`````]XV1E@``
M5HX```````"#G@```````$^5````````````````````````````````CYX`
M`+&)A)X```````````````"5GH6>``#`EP``C)X``'Z4````````````````
M``"4G@``AYX```````"RB(F>`````%N-````````BYX``(J>``"&GI&>``"]
MCP```````.N:YHR<EP``````````B)X``/*20HJKC0``@)X``)">@8H`````
MCIZ2G@``CI,``````````````````/R*``"PG@````#'EI>>^XH``)Z>````
M``````!?E@``GYZAG@``I9Z9G@``29(``````````(^3J9Z<G@``IIX`````
M``"@G@```````````````%B0JIX`````L9````````````````"HGKN*````
M`````````&^8EIX`````I)[6B`````"8G@````"XEIV>09#%DI.>`````*.>
M````````````````FI"MGI&*GXP``````````*^>FIZNG@``IYZ;G@``JYX`
M`*R>`````````````+V>````````S),``**>`````+F>````````NYX``-:2
M``````````````````````````!KEP````````````````````"6E;:>R)$`
M``````"\GEZ1``"SGL">OYX``.V3OI[HDP``````````````````PIZUG@``
MQHNXGGR/````````@)2ZGLF+``"RGK2>L9X`````3YAYBK>>`````,&>5(H`
M`````````````````.6-````````?(D`````TIX`````4)C5G@``````````
M``!9D-2>````````TYX```````````````#0G@```````````````,2>````
M`.&>PYX``-:>````````````````SIX`````R9[&G@``QYX``,^>````````
MH.H`````S)Y<C<:2A)'*G@``Q9X`````R)X``````````&R7BI8```````#-
MGM>>`````````````````````-^>V)X`````Y9X``..>``````````#>G@``
M`````````````-V>``#.D@``A9$``-N>`````-F>`````.">``````````#F
MGO.4[)X`````````````YY[JGN2>`````)22``!7E0``VIX`````XIZ^CP``
MS9;VGNF>`````````````*",H8E^B@````#1G@```````````````+^/[IX`
M`/6>]XZ2B@````!-D@```````````````.N>`````/">])X`````M(L`````
M``````````````````````````!KB_*>`````````````$"+``#)D_&>````
M````\YX`````````````````````````````[9X`````````````[YX`````
M``````````"`BFB2````````^IX`````````````````````^)[GC```]YX`
M``````````````!`GP``````````=YX```````#YG@``^Y[\G@``````````
M`````$N?``!'GP``C9X``````````$:?``````````!%GP````!"GP``````
M``````#HGD2?0Y\``````````````````````````````````$F?``!%F```
M`````````````$R?^8L`````2)]*GP````````````````````"EE```39\`
M``````````````````````````````````````!1GTZ?````````````````
M`````).73Y\``````````-R>``````````````````!2GP```````%.?````
M````````````5(D``%6?AXR?C@``TXL```````"BB0``````````````````
M````````?I<``````````%>?5I]9GUR+`````-2+O(H``````````%R?````
M````6Y\``%V?`````,R)``!6D@``7I\`````O8I@GP``````````7Y\``&&?
M````````8I\``&.??HZSD)^-``"0E0````#@E6.8``````````"5C@``````
M`,Z-\)<```````!DGV6?``"`C@```````&:?9Y\`````:9]HGP``=Y8`````
M?8_JCF..``!JGP``````````````````;)]"D```:Y\`````````````;9\`
M````````````;I\`````````````;Y]PGP```````'&?``!SGW*?=)^CB6F2
M``!UGP````!%CFN*=I\`````89/*F@``````````0HMWGP``````````>)\`
M`.J5B)8```````#%DWF?Y)0```````#YE`````#1E@```````'J?````````
M`````````````````````'R?>Y\`````?I\```````!]GP``````````````
M``````````````````````````````````````"!GP```````````````(&.
M``"OE@``@I^#GP````!#BP```````(2?``````````````````"&GX6?````
M````````````````````````````````````A9``````6)5IB0``````````
M``##E```\Y)@CX&+`````````````````````````````,24``"LC@``````
M````B)\``+Z*`````)B)`````/"3AY]=C7*2``")GP````````````"1GP``
MBI\`````````````OY$``(*+DI\```````````````"(C`````!$BY"?````
M`(Z?BY^`EP``````````OI(```````#7DXR?`````)2?``"3GT*,`````*N)
M`````+F-C9^/GP````````````!VEO*1`````````````````````)>6````
M`)R?`````)V?``#-B0``````````II7[EI^?H8[`CYB?GI^(B0``M8L`````
ME9^:GP```````/*0D90``.64````````````````EY\``$"6``"9GP``HI\`
M`*"?``";GP```````$&69Y2#BP``1),`````C9(``*.?``````````"AG]>1
MEI\``&J)````````````````````````````````````````````````````
M`````````&V7KI\`````````````K9\``````````/20``"JGP``C)<`````
MM).DGP````````````##D@```````&N)7HVGGP```````````````$:/K)\`
M`*N?II\``*F?`````(B*``"HGVB4`````*R7`````/*/\Y``````````````
M`````````````````````````````````````+2?LI\``&R5````````````
M````KY^QGP``68D`````7XU1F```7(H``(*5`````````````(&7`````$.*
M6I"SGP````````````````````````````"XGP````#!CP```````$^7``"U
MGP``````````L)\``+:?````````W)<``).3P),`````````````````````
M``````````````````````````!5B@````!TB0````"\GP````"_GP``````
M`,&7````````A)<``````````,:?P)^]GP```````-*7PY\``````````&F/
MQ9\`````RI\`````D9/(GP``````````PI\`````5Y(`````R9\``+Z?``#$
MGP``RY_ZB,&?``#,GP````!;D```?H\``*.5``"LC0``N9_'GUF3````````
M````````````````M)```(F*SXW"C[N?88\``````````````````&N,``"Z
MGP```````-"?C8^XC```WY\``-F?E(MNDP``U)_=GZV(48D`````MXD``-:?
MJI'-G\^?8(T`````````````````````X)\``-N?````````TY\`````````
M`-J?````````````````J98`````V)_<GP``````````````````SHP``,./
M`````%B2````````TI\``````````````````$Z7````````U9\`````SI^2
MDP````#1GP```````->?``````````````````!PF+R.GI8``.&?````````
M````````````````K)0`````[9^YC`````````````"`CP``XY\```````"M
MEV&-``#PGP````#LB`````#NGP``````````XI\``````````.B?`````.J?
M````````;I?EGP````!-DP````#GGP``````````[Y\``.F?Q98```````#D
MGP``H([\GP``````````BHH``.:?ZY_LGP``````````````````ZI'8D0``
M````````````````````````````````])\`````^I\`````^)\``$B3````
M`$+@]9\`````````````]I_>GP``F8M9E0```````+V.`````)>-````````
M`````%*8``#RGP``0>")B8:1``````````````````````````"9E```OXKX
MEP``````````````````GY;0D@``````````^9_[GP````````````!1D0``
M``````````!`X/>?``#QGP```````,&*````````````````````````````
M`````````(F,````````3N``````2>#VD`````"#B@``````````@8\``%+@
M````````````````2^"JDDC@UY(```````!KX````````$7@``!$X```3>``
M``````!'X$;@3.```)^0``!#X```````````````````3^``````4.``````
M````````P(H```````````````````````!5X```5.!6X`````````````!9
MX````````````````&*3``!3X`````````````!7X````````````````(.,
M]Y%1X%J4`````%C@``````````````````````````````````!=X%O@````
M`%[@`````&'@````````6N"*C4>4`````+>?````````````````E)=<X```
M8.#SD0``7^```$K@`````(GH````````9.````````!HX`````!FX```````
M````````````8N```&/@````````9^```&7@````````;94`````;>```&K@
M:>```&S@TI-NX````````````````)62ZY$``````````*.0````````;^``
M`''@`````````````````````````````'#@````````````````````````
M``````````#SGP``````````<N````````````````#EDP``````````````
M````````````<^```````````````````,Z)````````E)-$B@``````````
M````````A(L```````#<CM"-`````````````````````````````$:8AI``
M``````"*B0```````'7@````````````````=.``````````````````````
M``````````````````````````!XX%F2>^!VX````````'K@``````````!Y
MX%^3UX@``````````````````````````````````/.7`````'W@````````
M1XD```````````````````````"`X````````'[@``!\X```````````````
M``````````````````````````````!WX```````````````````0I8`````
M``""X`````````````````````````````"!X```````````````````````
M````BXD``````````(3@L)4``(/@``````````"SE@``````````Q8\`````
M``````````````````````````````````!2D0````````````#$CP``````
M`````````````````````````/F7`````(K@``#WD````````````````(;@
MB^``````C(D`````````````````````B>```(&4A>"(X,:/``#/E`````",
MX```SXX`````````````````````````````````````^)``````````````
M``"/X````````(?@``!&C```````````C>```````````&^7D.````````"D
MZ@````````````!NCP````````````````````"1X````````)+@````````
M``!-E```````````````````E.```````````)7@``````````!2E```````
M````E9.7X```````````F>```-.7``"6X```F."-B0``D^``````````````
M`````'J:FN```````````(>15XZ<X```````````F^!#D->9````````````
M````G>````````"?X```CN">X`````"@X````````````````)J4````````
M````````H>``````HN```````````````````````````*/@````````````
M````````````````````I.```-R2``"FX*7@`````*?@``"HX`````#=CH.5
M````````ZI:IX*K@=9&BCJO@K.``````````````K>#0E<64`````*[@=I0`
M````````````JY(`````````````K^#EB0``C8L``,26``"TE@``LHE3F```
M````````<98``*B5`````````````````````+60``"PX```````````P9,`
M``````"AC+'@``#2C;/@LN```````````+3@````````````````````````
M``"UX````````+;@````````````````````````78L``+?@``````````"X
MX```````````HHP`````QI0`````NN````````#SCP````"YX```````````
M``````````"VB[O@O>```+S@``````````````````"^X```SXP``+_@````
M``````#GBP``7Y$``)V-``````````#!X,+@P.````````````````#KC@``
M``#&D[>+````````````````````````Q.!+DL/@`````%28@I0`````````
M``````````````````````#'X`````````````````````````````#)X,;@
M````````TI;(X,K@``#"EP````````````#.X````````,W@EI),E`````"C
MC,S@``````````#+X```4)=1EP```````````````,_@CHD``````````):-
M@HX`````````````````````T.#1X```````````````````T^``````````
M````````````````````8H\``````````-7@``#4X`````````````#6X```
M;(H`````V.``````U^```-K@V>``````````````````````NHP`````II<`
M`,J+``"DB0``````````````````````````Z(L`````````````````````
M``````````````````````````#?B@````````````````````#FE]S@````
M``````````````#>X```````````W^```,^)`````````````-O@``!8C@``
M``"_DMW@````````````````````````````````````````XN```.R.````
M``````#@X```````````78P`````QY3AX`````#\X````````````````.?@
M`````````````+N,``````````"%BP``Y."=EP````"NEP``````````````
M`````````````````````````````````````````````````/21`````.;@
M````````````````````````````````Z.#4E]6+^I1IE````````.G@````
M``````#KX```[N``````````````````````````````````````````````
M`````.K@````````[>#HC&R)[^```)"0[.#:EP````#RX*+J``````````#P
MX//@``````````#EX/'@`````+J-`````/3@``````````````````#UX```
M````````GI<``````````````````/;@````````````````````````````
M````````````````````]^````````#CX```````````^.``````````````
M````````PHH```````````````````````````````"CC@``````````````
M`````````````````/G@``````````#ZX```````````^^``````````````
M`````%J)````````0.$``%J50>$`````HHI"X0``0^$``````````$3A``!&
MX4?A1>$```````!RE4GA2.$``````````````````````````$OA2N%,X0``
M`````````````$WA3^%.X0````"9C0``4>$``%#A`````,.*``!RD```6Y,`
M`%+AMI````````!9C@``F8E3X0``<)<`````X954X0```````&.34I=BC5R0
M````````:I*RF0``K)+FB57A``````````````````!6X0``6^$`````6>%8
MX<"=18I7X0``V(@``*B4`````,B4``````````"OEUSA6N%[DJ20`````*F4
M``!,E0``7N&JEVR,7^$``%WAU)1@X0``8>$`````V8@`````](]FX0``8^'K
MDV+A````````````````18L`````:>$```````!DX67A``!HX6?A1)4`````
M89%@D0``7HL`````:N$`````````````:^$`````;.$`````````````;N$`
M`&WA`````````````'6)`````````````';AYI1PX0``<N$`````=.%=D```
M``!UX7/AOHX```````!OX7'A``!AE0``QX\`````>.$`````=^$`````````
M`'GA``"DCJV-`````)>3>N$``,F2`````'SA````````GY=[X0``````````
M``")D0```````````````(+A``"$X87A<Y(`````````````@^$``(#A``!]
MX7[A``"!X0``````````````````B.$``(;A``"'X0``````````````````
M``````````````````````````")X8OAC.&-X0``CN$`````BN$`````````
M````````````D.$```````"/X0```````````````)'A````````````````
MPY<```````"4X9+AD^$```````#@B@````````````#\E@```````,B5``"6
MX0```````)7A``````````"7X9CA``````````"<X9GAFN&;X0``G>$`````
M``">X0``G^$```````"@X0``H>$``*V4;Y.BX9*44Y4``*/A`````*3A29,`
M`$:*8XVEX0````"FX0````"GX0``2(X`````J>$`````J.$`````JN&KX0``
M````````````````````````````````````````````````YY0``*SA````
M````K>$`````B>JNX:_AL.$``````````$V.`````+'A=90`````?I8``&V)
M``!VB0````"RX0``````````M.$```````"SX9"3````````MY!8GP``M>&_
ME@``MN$``,2*U92WX0``N.$`````N>$```````#:E@```````-.6``"\D@``
M`````(J1`````+OA`````(*/`````,B/`````+[A`````+WAO.'[E```Q8JG
MC`````````````````````````````````````#$X0````#!X5Z0L)8`````
M``#`X<+AP^$`````O^$``````````````````````````````````,7AQN$`
M`*V2``#AB@```````(62````````````````Q^$`````````````````````
M``````````````````````````#(X<OA`````````````(>0``#"DP``S.%R
ME@``R>$`````RN$``````````````````````````````````,_A````````
M``#.X<WA`````````````````````````````-'A`````-#A`````-+A````
M````````````````````````````U.$``-/A``````````#+E0``````````
M`````'6/Q)<`````U>$`````M9,`````UN$`````U^$``-OAV>':X0``V.$`
M`````````````````-SA`````````````-WA````````````````````````
MWN$`````W^&UEN#A`````````````.Z6X>$``&V2``"*E```Z8L```````!:
MDN+AN(L```````#.D`````````````````````#CX0````````````"[C0``
M`````````````````````.3A`````````````.7A``"DC-.-````````````
M``````````````#GX0``````````=9/4C6V+````````````````````````
M``!#E@``:I0`````````````=I,``````````'N-`````````````.GA````
M`````````````````````````````````````````````````````````,F/
M``````````````````````````````````"PEV2-`````*6,`````*&4``#K
MX0``````````````````[>$``````````.F,``````````#LX?22````````
M``#OX5:*ZN$`````Z)0``$^)``#JC0``<9@`````[N$`````````````````
M````\.$```````#)E0``UY#RX0``````````\^$`````````````\>$`````
M`````&V*``#YX0``^.$`````I8X```````#ZX?7A````````^^'VX0``````
M````UI3TX0````#WX0````````````!!X@``````````````````````````
M`````$#B@98```````#\X0````#IB```````````0^(`````````````````
M````0N(```````#*CP````````````!$X@```````````````&*1`````$;B
M1>(```````````````!'X@```````````````````````````````.;A````
M````Z.%)XDCB``````````````````````````````````"FC@``YY<``-".
M``!*XE:,`````````````%^+1HN#C@```````````````%.7`````%#B``!/
MXF.13.(`````3N(`````:H]?D$WB2^(``$F4`````,N/`````%N5````````
M``#5C0```````````````````````)B3`````%'B``````````!2XFCBUHL`
M````7)A4D0``````````4^(`````T(GUDI^5````````````````````````
M``````````!4X@````````````````````":BU7B`````%?B````````6.(`
M`$B4`````%GB`````````````%KB6^(`````UXO1B<.31X^$C@``````````
M````````7.(``$B/`````````````,B)8I4`````7>(`````Z90`````````
M``````!DD0``8.(``&'BB90``&"07N(``(&2`````%_B````````S(\`````
M`````````````````````-J(``````````!(BP``````````````````8N(`
M````]I(``&/BQ9``````````````JY8`````0I5DXF7B=)(``,67`````&?B
M9N(``````````````````````````````````.V.`````&GB[H@`````````
M`&SB````````:N+2B6V,:^)EC9*-``#DE6WB`````'.6`````&_B````````
MSY!NB;B)JH@```````````````!NX@```````````````````````'#B<>+U
MCP````````````!RX@``;HH``````````'3B````````BHP``(:+`````'7B
M\XL`````=N(``/J0``#+DP``WI#SC0```````'?B````````````````````
M````@I*+D0``>>)[XGCB>N(```````````````!!C```````````````````
M`````'SB18P```````"'BW&7?N(`````````````@.(```````!-B0``````
M````@^(```````"6BH+B@>(``(7B?>(``(;BIY<``(?B``"(X@````#RFHKB
M``")X@```````(OBC.(``+.7C>(``.WHS8^.XH_B=H\``+:3D.(```````!'
MD@````"1X@``6Y*2X@````````````"CBP``7IE\DK&.``````````#&B@``
M``"3X@``H.(``);B``"(BP``E>*BX@```````)3B``#.CP``````````````
M`)CBF>(``$J3`````)KB``!]B@``````````>9"$E0``G.(```````#FD0``
M`````````````)?B``";XIWB`````/F-````````````````````````````
M`*3B394``*24F9,``-B+H^*AX@``LY2>XGV2FY,``)J3``#TC0``````````
M`````+;B``````````````````"FX@``J.(``````````*OB``"LX@``J>*J
MX@````"GXJ7B``````````"?X@````````````````````````````#-E=.)
M````````L^(``+#B``"UX@````"TX@``DY2EE@``6HZNXK?BLN(``+'BK>(`
M`*_B``#'B@````````````````````!<D@````#[D````````*"4`````+SB
M````````HI0``````````````````-^0N>(`````S90``+WBT94``'J2``"X
MXKKB`````+OB``````````````````````````````````"^X@````#"C@``
M`````,23P^+"X@````"_X@```````%68`````````````,CB`````,SBR>(`
M````````````````````Q>(```````````````#&X@````````````#+X@``
M`````,#BTYG'XL'B`````,KB``````````````````#0X@``R(H``,WB````
M````SN(`````S^+2X@````````````````````````````#1XO24````````
M``#3XOJ7ZY78X@````#5X@````````````````````#4XM"0``#7XMGB````
M````UN(``-WB``#:X@```````````````-OBQ.(```````#<XM[B````````
M````````W^(```````````````#$E0``X.(`````````````````````X)8`
M````S(M(C.'B`````````````+*5``"(D```KI8`````XN(``+&7`````)24
M``!ED5.4`````&R/````````OH@``.?BY>(``./BGXH``,^/Z.(`````YN(`
M`.3B[.(`````Z^+JXNGB`````````````.WB````````[N*XD```[^(``/'B
M`````/#B``````````#0C````````%>1````````\^(```````"<DP``\N(`
M``````#TX@``LY6,D6:-``#UX@``````````QI<``````````````````/?B
M`````/CB``#YX@``^N(``(6.``#[XFZ,`````(J+``!)BP``0.,``/&69XW\
MX@```````$/CY)8``%N4`````%*5````````@X]"XP``T8YHC8:.B8NTE4'C
M````````9I%AEO6-`````````````````````(>.VY(``$;CW9?7C0``1^-A
MD```2>,```````#0CZZ-``````````!(XP````!)C[R,9Y%$XTKC````````
M``!%XV^,``!-XU'CBXP`````````````3.,``````````%7C`````&F-````
M`(V7NHA2XP````"+BP``3^,`````````````4.,`````G9-.XTOC``!'BN*0
M`````*:,````````5^,`````````````````````````````5.,`````````
M````5N,```````!3XP````````````!PC+&16...D0````!EXP````!AXUOC
M``````````````````!?X_B.VXA:XV+C9N-JC=26``#4DESC`````&3C``!9
MXUV2``!>X[N(R)8``````````````````%WC`````-F+ZI0```````"-D0``
MSI>/CP````".XP````!GXP``_)```&/C:.-JXP``]Y)MXP````!IXP``````
M`-*5R8H`````R98`````W(@`````;.,``/N7````````````````:^,`````
M````````CXD`````ZI-NXP```````'7C;^-VXP```````````````'+C````
M`````````````````)N4`````,B.=.,``''C=^-PXP````!CCP``````````
M1)8`````:X\`````<^.`XP````![XP``?N,``'SC@>-ZXP``8./1D`````#)
ME```?>,`````>.,```````!`D7&,``!*CP```````````````$2059&$XP``
M``"&XX?C`````(/CA>,``````````````````'GC@N,``(KCB>,`````FI8`
M````2HP`````````````````````B.,``(SCB^./XP``D>,`````6XZ-XP``
M````````DN.3XP````"4XP``FN-:DY;C``"5XY?CF.,``)GC``````````";
MXYSC````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````RHH``)WC
M``">XP``````````````````````````G^,```````````````"@XZ'CHN,`
M`*/CI.,`````IN.EXP````"GXP```````````````*CCJ>,`````````````
M``"LXZKCJ^/?C7*,`````'62``"QE```D(\`````;)0``.N4K>/KG```````
M``````````````"NX[#C``"%EZ_CLN.QXP``<I<``+/C``#\E```````````
M``"TXP````````````"WXP````"VX[7C``````````"XXU&,````````09%@
MBP``````````O..YXP````"ZXP```````+WC``"^X[OC````````2(D`````
M``"EB0```````,#CP>,```````#"XP``@I<`````````````2X\``,3CP^,`
M`````````````````````````(F0Q>,``````````,;C`````,?C``#CB@``
M````````RXH`````R.,`````````````R>,``'R6@Y<```````!SEU:8``!L
MC<SCTH[+XP``````````S>.GC@```````,^1``#.XP````!KC0``U9;/X]#C
M`````-'C``````````#2XP```````````````-/C````````````````````
M``````"HC@````#KE@``````````U>,``%Z2``#4XP```````````````-?C
M````````UN,``````````````````-CC````````N9```-GC``#:XP``````
M`+>5V^,``(^1W.,`````````````W>,```````````````#\E^#C``#?X][C
MKI(``.'C19```.+C````````X^-7F.3C``````````#EX^?CYN.CE```]Y,`
M`%V8IY0```````````````#IXP````#1CP``294``.KCZ.,``,R*````````
MTHR(C@````#LE````````*B,8I8``.WCZ^,``&V-``!NC>>(``#FC0``````
M``````!XE`````````````````````#=B/+C``!?D@````````````!WE```
MV9$``````````````````/3C`````/#C\^/NXP``\>-%E@````#3C`````#[
MB._C````````````````````````]N,``/?C`````+>3````````N8L`````
M``!%Y%R4``````````")C@````"ZB\:099BLEO7CTI``````````````````
M``````````````````````!RB_CC``````````````````#ZXP``````````
M``#YXP````````````#[XP``19(``%V4`````````````*^2``````````!"
MY```````````````````0>0``````````/SC`````'20``"%E43D``!#Y&^-
M<I@```````````````````````!4Y`````````````!(Y$GD``````````#N
MC@````!'Y```F(U&Y`````!*Y````````+"2H)5"D0``````````VI%.Y```
M3^1+Y```````````3.0``$WD``````````!PC0```````%7D``!1Y```````
M````AI4``(R61Y4`````4.0`````4^12Y````````&.65N0`````````````
M``!7Y`````!6D0``6.0`````6N0``%[D`````%OD6>1>E%SD``!=Y```````
M`+")``!DY%_D````````8.0```````!AY```GY$``````````&/D8N1EY```
M````````9N1GY`````!BD```YXD``&CDU9<``*F.`````$R/````````````
M`(J.=I(`````````````:>1JY%")``!KY`````!LY&WD`````&[D``!OY+N+
MJ)UPY```XY!QY,F.``!RY```KI@```````!SY-R5VHH`````0Y%WCP``D95-
MCP```````````````````````'3D<8UUY,J4``"$Y```````````=^0``,>1
ME92]C';D1)$```````````````!XY````````````````/B2````````````
M``````````````````````````````!ZY'GD?.0`````>^0``'WD`````(#D
M``!^Y```S8H``('D``""Y(/D`````*^-QY<``(7D1I````````"0B8;DA^0`
M````````````B.0```````````````````````````````#PB```B>0`````
M`````(KD````````````````AY4```````#%C@``C.0`````````````2(JP
MB```````````B^2.Y&V4``!CD```U(D``$:6``````````!\C-J+``"-Y```
MZ(D``````````````````*&*`````````````````````````````)&)DN3H
ME]N1`````&.5``">Y```U8F<Y```FN21Y```C^0``)#D``#ACNJ+EY(`````
M``#/DP````````````!PB0``E.23Y```````````F>25Y)CD````````````
M````SI:7Y-:)G8J;Y`````"=Y```````````<XP``````````````````*'D
MJN2KY````````*F(````````````````LN0``````````.^(`````*GD````
M````J.0``*/DHN0``*#DG^2#D@``^9&EY````````````````*3D````````
M``"GY````````)"1=(P``````````&")IN0``'*-`````````````)&1````
M````````````````````````````````````````````````````````````
M`````+CD``"YY```UXD```````"LB;;D`````````````````````*SD``"T
MY```N^2UY````````+/D``````````"6Y`````"QY````````*WD````````
MSHJOY+KD``"PY`````````````"\Y```KN2<E`````````````")EP``````
M`+?D``````````````````#-Y````````,7D````````FY```````````&6+
M``#;BP``P.0``````````-F)`````-*/``##Y````````-B-`````'"3R.0`
M````````````````````[)4``+_D````````V(G4C$B5R>0``+WD`````,;D
M````````T.0``,'D`````````````,+DN),`````Q^0```````#$Y$>6RN3>
MB```````````ON0```````````````````````````````#,Y```R^0`````
M``````````"+E-+D``#=Y```````````GHH```````#@Y`````#.Y```````
M`-/DCI<`````````````````````W.0`````=)<``````````*B7````````
M`````````````)B2````````BXH`````````````DI7BY)^3`````*^(````
M`-OD``#7Y)*1T>39Y-[D``!+E````````*B(``#6Y```W^28E0``````````
M````````VN0``-7D````````````````TX\``````````$Z/````````JHX`
M`````````-:6`````&:5`````.7D``#NY```````````````````````````
M``#8Y```````````EXH`````````````]H_CY```Z.23D0````#DY```Z^0`
M````?I(``.SD`````'67X>17B@``Y^0`````ZN2JE@``````````[>0`````
MYN3IY`````````````````````````````````````````````!(E@``0)@`
M````````````\>0``````````````````/CD`````/#DP8X`````````````
MS^0``````````````````````````,R5``"@EO?D]N0``/+D\^0``%6)````
M``````#UY```[^0``````````-.2`````````````/3D_(@`````````````
M`````*"1``````````````````#!E0````#YY$#E``#7E```````````_.34
MC\>.0N4`````O(L```````````````!#Y0``F97[Y```U.0`````````````
M````````^N0``````````&Z8H).3E0````!*Y0``````````````````````
M`%#E````````````````4>4``$3E````````EI0`````3N5&Y0``2.4`````
M````````4N5'Y0````!+Y0````"2B0``XY,``$SE3^4`````````````````
M`$7E``!%D0``2>5&CF203XSRE@``]Y:2CP```````````````````````%;E
M5.4```````````````!MF```````````````````4^4```````"5EP``5>57
MY0``````````6.4```````````````!;Y5GE````````````````H9-:Y0``
M`````,N43>4```````````````````````````````"3CP``7.5AY921````
M`&#E````````0>4```````!BY6B1`````%WE7^4``````````````````%[E
M`````%"?09\`````9.4``````````````````&/E````````````````````
M``````"6EP``NN%EY0````````````````````````````````````!FY0``
M````````````````````````````````9^75C```<XL```````!IY7R9````
M``````"5BP``N)<``/&+:N4``````````````````&OE````````CI(`````
M````````;.4``````````````````/B3``"XB```````````````````````
M``````````````#AB7'E<N4```````````````!MY0``7(X`````````````
M`````````````````````&[E890``````````&_E<.5ZY0```````'3E=^4`
M````````````<^4``````````````````````````````````'7E``!VY=:.
M``!XY0``8)(``'6,88H`````````````>^4``````````%Z*``"!Y0````!\
MY8#E``````````"XE```````````?>4`````?N5GE=B4@N4`````````````
M````````^Y&,Y0``B.4`````Z8D``(;E``!)EH?E`````(3E``"%Y8KEC>4`
M````B^4```````")Y8/E`````````````'>2``"4Y0``J)8`````````````
M````````DN4```````"3Y0``````````````````````````CN4`````D.4`
M``````"1Y0```````(_E````````````````````````Y)```%B8F.4``)GE
M``````````"?Y0``29```)OE``">Y0````````````"6Y97E`````*#E````
M`-J)``"<Y0``H>4```````"=Y0````````````":Y0``L9(``)?E````````
M````````B)0`````I>4``````````````````````````%J7````````````
M`````````````````````````````````*3E`````*/E````````````````
M`````*SE````````IN4```````"NY0```````````````(:7L>4``*CE````
M`*GE````````K>4``+#EK^4```````"GY0``````````JN4``+OE````````
M``````````````````````````"TY0``````````````````````````````
M``````"RY0````"SY0```````+CEN>4``$F*``!ABP````"WY0``````````
M`````*+E``````````````````"VY;KEM>4``+SE````````ON6]Y0``````
M````````````````````P.6_Y7GE````````Q.4`````````````````````
M``#!Y0``````````PN4`````P^4``,7E``````````",C```Q^4``,;E``!/
MCP````````````!SC:6?``````````#(Y7"/````````6(H``,GE``!QB0``
MU8_*Y0````!TC<OEWX@``````````%R5`````,SE``````````"*D```T^4`
M````T.4``(^2`````````````-'ESN7<BP``S>74Y0````````````!5C```
M``#<D0``VN4``````````-;E````````LY'5Y0``V.4``````````,_E````
M````V>4``-OE````````````````[90`````U^4``-SEWN4`````T8S2Y0``
MOX@``````````````````-WE``#9C?27W^7@Y961````````````````````
M````H)<``````````.'E5)<`````XN7CY0````#BE>3E``"^C0``H9<`````
M``````````#IY0```````````````````````.KEUH_HY0```````(>7Y>4`
M````Y^6[D)Z0````````YN4``.OE`````*&5`````.WE``#LY0```````(R*
M``!*EN[E````````````````````````^N7PY0```````````````/'E````
M``````#RY?/E``````````````````````````#WY0``^.4`````]N4`````
M````````].4``._E]>4``````````````````/GEM>@`````````````````
M````IHD``````````````````/SEW8O[Y0```````$'F``!`Y@```````$/F
M`````$+F``!$Y@````!0CP``1>8`````1N8```````````````!'YKR0``!V
MEP``2.8`````HI5EE$GF``!*YJF,````````2XL```````!+Y@````"+CF"4
M3.8``&^*````````````````3>8``````````$_FEY<``$[F99```%#F````
M`%'F`````%+FSXH```````````````!3Y@````!4Y@``5>96Y@``````````
M``````````````````````````````````!PB@``````````````````5^8`
M`%CF6>8`````````````\(D`````1Y!:Y@``````````````````````````
M`````%OF````````7.8``````````````````+Z,``#YDEWF``````````!V
MC```=9```&#F``"BDP``7^8`````4(P`````7N;UD4R+`````&'F``!BY@``
MUX\```````"-C```8^8``````````$N6`````-V0````````EHL``/.6:9$`
M`&3F````````9I"0DMB/``````````!EY@``````````:.8``&GF````````
M``````````"\C<"19^8``-F/794`````````````9N8`````C(X``'*)``!M
MYG>,`````(Z.`````(V.``!LF&SF:^9&D0``;(MBF%F*VH\`````````````
M````````:N8`````````````;^8``'#F;N8``-:,``!?EP````"/CD:4````
M````<^8``+Z0``!AD@````!5EP``=N8```````#JC```O9!RY@``=^;KC'3F
M=>8``''F````````X)#'DP````!.D@``VXD```````````````#NE`````!B
MBP````"RD@````!ZY@``>.8`````:Y(```````"_D-"*>>8``'J0`````,B7
M````````7Y@```````![YH?FLY(``(;F``"#YHOFA.8``(#F``#ZDG[F````
M````?.8``$"7D(X`````@>8``'WF````````A>:4CP``OXP```````#XD0``
M9)9YB>"(``"CDP````")Y@``````````B.8``.23``"-Y@```````(+F``",
MYH[F``"JC(KF=8T``-..`````(_F=Y<``````````)+F``"5Y@````"3YE25
M````````````````D.8`````````````WHL``````````)3F`````);F````
M``````````````":Y@````"7Y@``F>:8Y@```````````````)OF``"OC@``
MG>:<YHB5`````)_F````````````````>(P``````````)[FH.8`````H>9C
MB[_C]X\``*+F`````.R,`````````````*/F`````*3F`````%V.````````
M````````S)T``*7F``"FY@``48\``*?FJ.8`````J>8`````JN:KY@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$J2`````*SF
M``````````"NY@``K>8``````````*23``"OY@``3)8``+#F``"QY@``LN8`
M`````````+/F``````````#8DP```````````````-N/M.8`````````````
M`````(N-K)BUY@````````````````````````````"VYEZ5M^8``+_F````
M`````````+CF`````+KF````````N>:[Y@``99:\YKWF`````````````+[F
M````````P.8``````````$R*Y9(``(F5X(UVC0``````````;I7=B<R4P^;1
MBM.0PN;'YIF2X98``,7FQN9-BP``R.:#E-V1`````.^47)/$Y@``9I;JB<KF
M1YC`DF28`````)&.R>8``*^1`````-KF1Y$`````]I,``&^5````````````
M````S>9>CI*.``#<CP``A90``*N,S.;+Y@``BI4```````"_C@````!QDP``
M`````````````````````````````,_FT.9WC<[F````````````````T>;2
MY@``U.:AD0``T^;DB@``UN8``-7FU^8`````V>;;Y@``W.8`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````U)```,V.W>8```````!QB@``WN8`````EI'?Y@``X.:+E0``
M``!.BP```````````````````````.'F````````M)(``````````'J)````
M`````````````````````````````````.+F````````````````````````
M[XX``````````):0``````````````````````````"KD0``````````````
M`.7F````````Y.8```````#CY@````````````````````#KYNGF`````.;F
M````````````````Z.8```````#GYNKF``"7BP``[N8``-60``#OY@``````
M````UXP``.SF[>8```````!(F````````+62``!(D0```````````````/#F
M`````//F`````````````````````/'F\N9XEP``````````I9/VY@``````
M`````````````````````````/3F]>;WY@``````````````````````````
M2.<`````````````^N8```````#[YOGF````````````````````````````
M````^.8``/N2`````$#G1.=!Y_SF``!"YP```````$/G``````````!*YP``
M`````$7G`````````````-:01^<`````2>=&YP``````````````````````
M````````````3.<``%*/``!+YP````````````!-YP``````````3N<`````
M4>=0YP``3^<`````4^=2YP``])8```````!5YP``5.=6YP``````````5^<`
M`````````````````%GG`````````````````````%CG9Y!:YP````#KBUOG
M7><```````````````````````````````!>YP```````````````%_G7.<`
M`&#G``#4CF'G3XM2C```````````K(P`````````````````````8N<`````
M``#NDP````!=DV/G``````````````````!FYP``````````````````````
M`````````+*.`````&7G9.=YC&?G``````````!RB@``:><```````#:C6CG
M``!QYP````````````!KYVWGXY5JYP```````&SG``!PYV[G4(L``&_G````
M````````````<N<`````>936EP``````````4X\```````!SYP``````````
M09=UYP``=.<`````>.=@EP````!WYP``C8IVYWOG`````'KG`````'GG49-\
MYP````````````````````!]YP``````````?N<`````C(T``$2,@.>!YX+G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````:)"#YP``JXZ$YP```````(7G````````GYF>
MF0``````````AN>0XX?G0Y)*D%^4``````````"(YP````#3E=*2GHT`````
M2)(`````28D``)B6=I``````````````````````?8P`````WXL`````U)4`
M````````````B><``````````````````(OG`````(KGWHD`````]).,YY>4
M``!2DP``C>=QCP```````(_G`````,"6GN>1YY+G`````,>2`````-Z1EY$`
M`*:3``"0YW2+``````````"9YP``EN>CYZ>3@)*3YP``_))RDY3GF.>`D```
MAY3*D@````#`D)?GK)&BD97GIXA!F````````)KG````````````````WY$`
M````5(]ID`````"<YYOG``#MB)WG`````$Z5``"EYP````#9DXN0`````'B2
M``#VBP``I.=6EUZ)``#5E=^)G^>@YZ'GHN>YDT*2X8BFYP``I^>AZ@````"[
MD0``J.<``).):Y$``*V,``!YEP````"IYTN3````````F)'5CJKG`````*WG
M`````(6/J^=*D4F1``#BB```R9>OYP``\)2QY[#GKN>$XM**`````([G``"S
MY[+G``````````"TYP``5Y<`````````````````````````````````````
M````````WY,`````398``+7G``#7C@``````````MN<``+?G````````N.<`
M````0),`````````````````````Z(@`````````````````````>(T`````
M``!9F````````````````````````````````+SG`````````````%.,N><`
M`+KG````````E)4``````````'.*``````````````````!8EP``O8L`````
M````````<Y,``````````+WG````````````````````````````````````
M````ON<```````````````"_YP``````````````````````````````````
M````````````````09,`````P><``,#G````````````````````````````
M``````````````````````````````#1D\+G58_>CGJ4D9(```````#PC@``
MC)```,/G``#$YP```````````````````````'R0Q><``,;G````````Q^>/
MEP``5H\`````````````R>?(YP``>8T``).-7XX`````````````````````
M``#,YP``````````AH\``,OG``#*YP``YY$`````[8P``,&0``````````"N
ME```````````6(\`````````````S><``-V/`````````````-#GSN<`````
M``#/YP``````````TN?1YP````#XCP``T^<`````````````U.?5YP``````
M````SI31C=^.UN<``-?GHI=DC^R6RI?8Y^"+``````````#9YP``0I,`````
MW.>8BFJ0``#:YP``V^<``-Z2`````'26^HL`````````````````````````
M`````````-[GW^<`````````````W><`````X><`````````````````````
M`````````````-V38HH`````Y><`````XN?DYP````````````````````#@
MYP``````````````````````````;N@`````X^<``````````````````.F7
M`````-B,``````````````````#MYP``````````4Y/HYP````#KY^GG``#N
MYP``````````[^<```````````````#GYP````#TYY2)`````.;G````````
MJY0``.KG``#>CP``````````````````````````>HT`````````````````
M``````````````!GE@``XHL`````98\``+J3````````````````````````
M`````$R1``#RYP``[.?QYP``P98``+:2\^?PYP``````````````````````
M````````````````````2Y$```````````````````````#WYP``]N<`````
M``````````````````````````````````````````````````#UYP````!.
ME@````````````````````````````````````````````";CP``````````
M^.?=E0````!SB0``````````9962D@``````````F(L``/KG``!\C0``````
M`````````````````$N.`````````````````````/GGC9``````````````
M`````(Z00.A"Z`````````````#YCP``0>A#Z`````#1BP``9)4`````X(Y"
MF```_.?VC0````!>F`````!%Z```````````1.A&Z```````````````````
M``#[YP```````````````.>3``!TDP```````````````-62``!+Z```````
M````8I)'Z````````$CH`````````````````````````````$R,``!*Z```
M`````````````*Z,````````````````2>@``-^/````````````````````
M``````````````"9B@``````````````````3^@``+V-F9$`````R)(`````
M``````````````````````````!:B@``````````3>A.Z,&2``!,Z```````
M``````````````!0Z````````````````````````%;H``````````!9Z```
M````````````````6.A,DP``````````4>A2Z%7H``````````!7Z```````
M`+Z+`````%KH5.@`````4^@`````````````````````````````````````
M````````````````````````````````7N@```````!?Z```````````````
M``````!@Z`````!=Z%SH````````X(^HDUOH````````````````9.@`````
M``````````````````!BZ````````````````````````&/H8>@``/:1``!E
MZ````````````````&;H`````&CH````````````````````````````````
MTXIGZ/B6````````````````<^AIZ`````!LZ```:N@``&OH````````````
M``````!MZ`````````````!OZ```````````<.@``''H``````````!TZ'+H
M=>AWZ```=N@`````````````````````````````````````0(%!@4*!5H$`
M`%B!68%:@7&!<H%S@72!=8%V@7>!>(%Y@7J!IX&L@6N!;($`````````````
M``!@@0``````````````````````````````````````````````````````
M`````````````````````````````````````````)^"H(*A@J*"HX*D@J6"
MIH*G@JB"J8*J@JN"K(*M@JZ"KX*P@K&"LH*S@K2"M8*V@K>"N(*Y@KJ"NX*\
M@KV"OH*_@L""P8+"@L."Q(+%@L:"QX+(@LF"RH++@LR"S8+.@L^"T(+1@M*"
MTX+4@M6"UH+7@MB"V8+:@MN"W(+=@MZ"WX+@@N&"XH+C@N2"Y8+F@N>"Z(+I
M@NJ"ZX+L@NV"[H+O@O""\8(``````````````````$J!2X%4@56!`````$"#
M08-"@T.#1(-%@T:#1X-(@TF#2H-+@TR#38-.@T^#4(-1@U*#4X-4@U6#5H-7
M@UB#68-:@UN#7(-=@UZ#7X-@@V&#8H-C@V2#98-F@V>#:(-I@VJ#:X-L@VV#
M;H-O@W"#<8-R@W.#=(-U@W:#=X-X@WF#>H-[@WR#?8-^@X"#@8."@X.#A(.%
M@X:#AX.(@XF#BH.+@XR#C8..@X^#D(.1@Y*#DX.4@Y6#EH,``````````$6!
M6X%2@5.!``"?A*J$H(2KA`````````````````````"AA`````"LA**$````
M`*V$I(0`````KX2CA`````"NA*6$NH0`````M80`````L(2GA+R$`````+>$
M`````+*$IH0`````MH2[A`````"QA*B$`````+B$O80`````LX2IA`````"Y
MA`````"^A`````````````````````"TA```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````*&!H($`````````````````````````````````````
M`````*.!HH$`````````````````````I8&D@0````````````````````"?
M@9Z!````````FX$`````G8&<@0``````````````````````````````````
M````````````````````````````````````````````````_($`````````
M``````````````````````````````````````````````":@9F!````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````BH$``(F!````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````]($`````\X$``/*!78$``````````%R!88$``&6!9H$`
M````9X%H@0````#U@?:!````````9(%C@0```````````````````````/&!
M``",@8V!``````````````````"F@0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````CH$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#P@0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````J8&J@:B!JX$`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````RX$``,R!````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#-@0``W8'.@0```````-Z!N($`
M````N8$```````````````!\@0``````````````````XX$`````Y8&'@0``
MVH$```````````````#(@<F!OX&^@>>!Z($``````````````````(B!YH$`
M`````````````````.2!````````````````````````````````````````
M`````````````."!``````````````````````````````````""@=^!````
M``````"%@8:!`````.&!XH$`````````````````````````````````````
M`````````````````````+R!O8$`````NH&[@0``````````````````````
M``````````````````````````````````````````````````````#;@0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-R!````````````
M``````````````````````"?@Z"#H8.B@Z.#I(.E@Z:#IX.H@ZF#JH.K@ZR#
MK8.N@Z^#``"P@[&#LH.S@[2#M8.V@P``````````````````OX/`@\&#PH/#
M@\2#Q8/&@\>#R(/)@\J#RX/,@\V#SH//@P``T(/1@]*#TX/4@]6#UH,`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$:$````````````````````````````````````
M`$"$081"A$.$1(1%A$>$2(1)A$J$2X1,A$V$3H1/A%"$4812A%.$5(15A%:$
M5X18A%F$6H1;A%R$781>A%^$8(1PA'&$<H1SA'2$=81WA'B$>81ZA'N$?(1]
MA'Z$@(2!A(*$@X2$A(6$AH2'A(B$B82*A(N$C(2-A(Z$CX20A)&$``!VA```
M`````````````````````````````````````%^!````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````D8&2@0```````)B!
M3H$```````#*@0```````(N!?8$`````3($``/>!````````````````````
M````````````````````````````````````````````````````````````
M`````'Z!````````````````````````````````````````````````````
M``````````````````````````````"`@0``````````/F\3;_=NAF]Z;WAO
M@6^`;V]O6V_S;VUO@F]\;UAOCF^1;\)O9F^S;Z-OH6^D;[EOQF^J;]]OU6_L
M;]1OV&_Q;^YOVV\)<`MP^F\1<`%P#W#^;QMP&G!T;QUP&'`?<#!P/G`R<%%P
M8W"9<))PKW#Q<*QPN'"S<*YPWW#+<-UP``#9<`EQ_7`<<1EQ97%5<8AQ9G%B
M<4QQ5G%L<8]Q^W&$<95QJ'&L<==QN7&^<=)QR7'4<<YQX''L<>=Q]7'\<?EQ
M_W$-<A!R&W(H<BUR+'(P<C)R.W(\<C]R0')&<DMR6')T<GYR@G*!<H=RDG*6
M<J)RIW*Y<K)RPW+&<L1RSG+2<N)RX'+A<OER]W(/4!=S"G,<<Q9S'7,T<R]S
M*7,E<SYS3G-/<]B>5W-J<VAS<'-X<W5S>W-Z<\ASLW/.<[MSP'/E<^YSWG.B
M=`5T;W0E=/AS,G0Z=%5T/W1?=%ET071<=&ET<'1C=&IT=G1^=(MTGG2G=,IT
MSW34=/%S````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#@=.-TYW3I=.YT\G3P=/%T^'3W=`1U`W4%=0QU#G4-=15U$W4>=29U
M+'4\=41U375*=4EU6W5&=5IU:75D=6=U:W5M=7AU=G6&=8=U='6*=8EU@G64
M=9IUG76E=:-UPG6S=<-UM76]=;AUO'6Q=<UURG72==EUXW7>=?YU_W4``/QU
M`7;P=?IU\G7S=0MV#78)=A]V)W8@=B%V(G8D=C1V,'8[=D=V2'9&=EQV6'9A
M=F)V:'9I=FIV9W9L=G!V<G9V=GAV?':`=H-VB':+=HYVEG:3=IEVFG:P=K1V
MN':Y=KIVPG;-=M9VTG;>=N%VY7;G=NIV+X;[=@AW!W<$=REW)'<>=R5W)G<;
M=S=W.'='=UIW:'=K=UMW97=_=WYW>7>.=XMWD7>@=YYWL'>V=[EWOW>\=[UW
MNW?'=\UWUW?:=]QWXW?N=_QW#'@2>"9Y('@J>45XCGAT>(9X?'B:>(QXHWBU
M>*IXKWC1>,9XRWC4>+YXO'C%>,IX['@`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````.=XVGC]>/1X!WD2>1%Y&7DL>2MY0'E@
M>5=Y7WE:>55Y4WEZ>7]YBGF=>:=Y2Y^J>:YYLWFY>;IYR7G5>>=Y['GA>>-Y
M"'H->AAZ&7H@>A]Z@'DQ>CMZ/GHW>D-Z5WI)>F%Z8GII>IV?<'IY>GUZB'J7
M>I5ZF'J6>JEZR'JP>@``MGK%>L1ZOWJ#D,=ZRGK->L]ZU7K3>MEZVGK=>N%Z
MXGKF>NUZ\'H">P]["GL&>S-[&'L9>QY[-7LH>S9[4'MZ>P1[37L+>TQ[17MU
M>V5[='MG>W![<7ML>VY[G7N8>Y][C7N<>YI[BWN2>X][77N9>\M[P7O,>\][
MM'O&>]U[Z7L1?!1\YGOE>V!\`'P'?!-\\WOW>Q=\#7SV>R-\)WPJ?!]\-WPK
M?#U\3'Q#?%1\3WQ`?%!\6'Q??&1\5GQE?&Q\=7R#?)!\I'RM?*)\JWRA?*A\
MLWRR?+%\KGRY?+U\P'S%?,)\V'S2?-Q\XGP[F^]\\GST?/9\^GP&?0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````GT<?15]
M"GU%?4M]+GTR?3]]-7U&?7-]5GU.?7)]:'UN?4]]8WV3?8E]6WV/?7U]FWVZ
M?:Y]HWVU?<=]O7VK?3U^HGVO?=Q]N'V??;!]V'W=?>1]WGW[??)]X7T%?@I^
M(WXA?A)^,7X??@E^"WXB?D9^9GX[?C5^.7Y#?C=^```R?CI^9WY=?E9^7GY9
M?EI^>7YJ?FE^?'Y[?H-^U7U]?JZ/?WZ(?HE^C'Z2?I!^DWZ4?I9^CGZ;?IQ^
M.'\Z?T5_3']-?TY_4']1?U5_5']8?U]_8']H?VE_9W]X?X)_AG^#?XA_AW^,
M?Y1_GG^=?YI_HW^O?[)_N7^N?[9_N']QB\5_QG_*?]5_U'_A?^9_Z7_S?_E_
MW)@&@`2`"X`2@!B`&8`<@"&`*(`_@#N`2H!&@%*`6(!:@%^`8H!H@'.`<H!P
M@':`>8!]@'^`A("&@(6`FX"3@)J`K8"04:R`VX#E@-F`W8#$@-J`UH`)@>^`
M\8`;@2F!(X$O@4N!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"+ED:!/H%3@5&!_(!Q@6Z!98%F@72!@X&(@8J!@(&"@:"!
ME8&D@:.!7X&3@:F!L(&U@;Z!N(&]@<"!PH&Z@<F!S8'1@=F!V('(@=J!WX'@
M@>>!^H'[@?Z!`8("@@6"!X(*@@V"$((6@BF"*X(X@C."0()9@EB"78):@E^"
M9((``&*":()J@FN"+H)Q@G>">()^@HV"DH*K@I^"NX*L@N&"XX+?@M*"](+S
M@OJ"DX,#@_N"^8+>@@:#W(()@]F"-8,T@Q:#,H,Q@T"#.8-0@T6#+X,K@Q>#
M&(.%@YJ#JH.?@Z*#EH,C@XZ#AX.*@WR#M8-S@W6#H(.)@ZB#](,3A.N#SH/]
M@P.$V(,+A,&#]X,'A."#\H,-A"*$((2]@SB$!H7[@VV$*H0\A%J%A(1WA&N$
MK81NA(*$:81&A"R$;X1YA#6$RH1BA+F$OX2?A-F$S82[A-J$T(3!A,:$UH2A
MA"&%_X3TA!>%&(4LA1^%%844A?R$0(5CA5B%2(4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$&%`H9+A56%@(6DA8B%D86*
MA:B%;864A9N%ZH6'A9R%=X5^A9"%R86ZA<^%N870A=6%W87EA=R%^84*AA.&
M"X;^A?J%!H8BAAJ&,(8_ADV&54Y4AE^&9X9QAI.&HX:IAJJ&BX:,AK:&KX;$
MAL:&L(;)AB.(JX;4AMZ&Z8;LA@``WX;;AN^&$H<&APB'`(<#A_N&$8<)APV'
M^88*AS2'/X<WASN')8<IAQJ'8(=?AWB'3(=.AW2'5X=HAVZ'68=3AV.':H<%
MB**'GX>"AZ^'RX>]A\"'T(?6EJN'Q(>SA\>'QH>[A^^'\H?@AP^(#8C^A_:'
M]X<.B-*'$8@6B!6((H@AB#&(-H@YB">(.XA$B$*(4HA9B%Z(8HAKB(&(?HB>
MB'6(?8BUB'*(@HB7B)*(KHB9B**(C8BDB+"(OXBQB,.(Q(C4B-B(V8C=B/F(
M`HG\B/2(Z(CRB`2)#(D*B1.)0XD>B26)*HDKB4&)1(D[B3:).(E,B1V)8(E>
MB0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M9HEDB6V):HEOB72)=XE^B8.)B(F*B9.)F(FAB:F)IHFLB:^)LHFZB;V)OXG`
MB=J)W(G=B>>)](GXB0.*%HH0B@R*&XH=BB6*-HI!BEN*4HI&BDB*?(IMBFR*
M8HJ%BH**A(JHBJ&*D8JEBJ:*FHJCBL2*S8K"BMJ*ZXKSBN>*``#DBO&*%(O@
MBN**]XK>BMN*#(L'BQJ+X8H6BQ"+%XL@BS.+JY<FBRN+/HLHBT&+3(M/BTZ+
M28M6BUN+6HMKBU^+;(MOBW2+?8N`BXR+CHN2BY.+EHN9BYJ+.HQ!C#^,2(Q,
MC$Z,4(Q5C&*,;(QXC'J,@HR)C(6,BHR-C(Z,E(Q\C)B,'6*MC*J,O8RRC+.,
MKHRVC,B,P8SDC..,VHS]C/J,^XP$C06-"HT'C0^-#8T0C4Z?$XW-C!2-%HUG
MC6V-<8USC8&-F8W"C;Z-NHW/C=J-UHW,C=N-RXWJC>N-WXWCC?R-"(X)CO^-
M'8X>CA".'XY"CC6.,(XTCDJ.````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'CDF.3(Y0CDB.68YDCF".*HYCCE6.=HYRCGR.
M@8Z'CH6.A(Z+CHJ.DXZ1CI2.F8ZJCJ&.K(ZPCL:.L8Z^CL6.R([+CMN.XX[\
MCON.ZX[^C@J/!8\5CQ*/&8\3CQR/'X\;CPR/)H\SCSN/.8]%CT*//H],CTF/
M1H].CU>/7(\``&*/8X]DCYR/GX^CCZV/KX^WC]J/Y8_BC^J/[X^'D/2/!9#Y
MC_J/$9`5D"&0#9`>D!:0"Y`GD#:0-9`YD/B/3Y!0D%&04I`.D$F0/I!6D%B0
M7I!HD&^0=I"HEG*0@I!]D(&0@)"*D(F0CY"HD*^0L9"UD.*0Y)!(8MN0`I$2
MD1F1,I$PD4J15I%8D6.199%ID7.1<I&+D8F1@I&BD:N1KY&JD;61M)&ZD<"1
MP9')D<N1T)'6D=^1X9';D?R1]9'VD1Z2_Y$4DBR2%9(1DEZ25Y)%DDF29))(
MDI62/Y)+DE"2G)*6DI.2FY):DL^2N9*WDNF2#Y/ZDD23+I,`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````!F3(I,:DR.3.I,U
MDSN37)-@DWR3;I-6D["3K).MDY23N9/6D]>3Z)/ED]B3PY/=D]"3R)/DDQJ4
M%)03E`.4!Y00E#:4*Y0UE"&4.I1!E%*41)1;E&"48I1>E&J4*9)PE'64=Y1]
ME%J4?)1^E(&4?Y2"E8>5BI64E9:5F)69E0``H)6HE:>5K96\E;N5N96^E<J5
M]F_#E<V5S)75E=25UI7<E>&5Y97BE2&6*)8NEB^60I9,ED^62Y9WEER67I9=
MEE^69I9REFR6C9:8EI66EY:JEJ>6L9:REK"6M):VEKB6N9;.ELN6R9;-EDV)
MW)8-E]66^98$EP:7")<3EPZ7$9</EQ:7&9<DERJ7,)<YESV7/I=$ET:72)="
METF77)=@EV279I=HE])2:Y=QEWF7A9=\EX&7>I>&EXN7CY>0EYR7J)>FEZ.7
MLY>TE\.7QI?(E\N7W)?MET^?\I??>O:7]9</F`R8.)@DF"&8-Y@]F$:83YA+
MF&N8;YAPF```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````<9ATF'.8JIBOF+&8MIC$F,.8QICIF.N8`YD)F1*9%)D8F2&9'9D>
MF229()DLF2Z9/9D^F4*929E%F5"92YE1F5*93)E5F9>9F)FEF:V9KIF\F=^9
MVYG=F=B9T9GMF>Z9\9GRF?N9^)D!F@^:!9KBF1F:*YHWFD6:0II`FD.:```^
MFE6:39I;FE>:7YIBFF6:9)IIFFN::IJMFK":O)K`FL^:T9K3FM2:WIK?FN*:
MXYKFFN^:ZYKNFO2:\9KWFON:!IL8FQJ;'YLBFR.;)9LGFRB;*9LJFRZ;+YLR
MFT2;0YM/FTV;3IM1FUB;=)N3FX.;D9N6FY>;GYN@FZB;M)O`F\J;N9O&F\^;
MT9O2F^.;XIODF]2;X9LZG/*;\9OPFQ6<%)P)G!.<#)P&G`B<$IP*G`2<+IP;
MG"6<))PAG#"<1YPRG$:</IQ:G&"<9YQVG'B<YYSLG/"<"9T(G>N<`YT&G2J=
M)IVOG2.='YU$G16=$IU!G3^=/IU&G4B=````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!=G5Z=9)U1G5"=69URG8F=AYVKG6^=
M>IV:G:2=J9VRG<2=P9V[G;B=NIW&G<^=PIW9G=.=^)WFG>V=[YW]G1J>&YX>
MGG6>>9Y]GH&>B)Z+GHR>DIZ5GI&>G9ZEGJF>N)ZJGJV>89?,GLZ>SY[0GM2>
MW)[>GMV>X)[EGNB>[YX``/2>]I[WGOF>^Y[\GOV>!Y\(G[=V%9\AGRR?/I]*
MGU*?5)]CGU^?8)]AGV:?9Y]LGVJ?=Y]RGW:?E9^<GZ"?+UC':5F09'3<49EQ
M`````````````````````````````)Q.%E4#6C^6P%0;82AC]EDBD'6$'(-0
M>JI@X6,E;NUE9H2F@O6;DV@G5Z%E<6*;6]!9>X;TF&)]OGV.FQ9BGWRWB(E;
MM5X)8Y=F2&C'E8V73V?E3@I/34^=3TE0\E8W6=19`5H)7-]@#V%P81-F!6FZ
M<$]U<'7[>:U][WW#@`Z$8X@"BU60>I`[4Y5.I4[?5[*`P9#O>`!.\5BB;CB0
M,GHH@XN"+YQ!47!3O53A5.!6^UD57_*8ZVWD@"V%````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!BEG"6H);[EPM4\U.'6\]P
MO7_"C^B6;U-<G;IZ$4Z3>/R!)FX85@15'6L:A3N<Y5FI4V9MW'2/E4)6D4Y+
MD/*63X,,F>%3ME4P6W%?(&;S9@1H.&SS;"EM6W3(=DYZ-)CQ@EN(8(KMDK)M
MJW7*=L69IF`!BXJ-LI6.::U3AE$``!)7,%A$6;1;]EXH8*EC]&._;!1OCG`4
M<5EQU7$_<P%^=H+1@I>%8)!;DAN=:5B\95IL)77Y42Y995F`7]Q?O&+Z92IJ
M)VNT:XMSP7]6B2R=#IW$GJ%<EFQ[@P112URV8<:!=FAA<EE.^D]X4VE@*6Y/
M>O.7"TX64^Y.54\]3Z%/<T^@4N]3"58/6<%:MEOA6]%YAV:<9[9G3&NS;&MP
MPG.->;YY/'J'>[&"VX($@W>#[X/3@V:'LHHI5JB,YH].D!Z7BH;$3^A<$6)9
M<CMUY8&]@OZ&P(S%EA.9U9G+3AI/XXG>5DI8REC[7NM?*F"48&)@T&$28M!B
M.64`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$&;9F:P:'=M<'!,=89V=7VE@OF'BY6.EIV,\5&^4A99LU2S6Q9=:&&"::]M
MC7C+A%>(<HJGD[B:;&VHF=F&HU?_9\Z&#I*#4H=6!%337N%BN60\:#AHNVMR
M<[IX:WJ:B=*):XT#C^V0HY64EFF79ENS7'UI39A.F)MC('LK:@``?VJV:`V<
M7V]R4IU5<&#L8CMM!V[1;EN$$(E$CQ1..9SV4QMI.FJ$ERIH7%'#>K*$W)&,
MDUM6*)TB:`6#,82E?`A2Q8+F='Y.@T^@4=);"E+84N=2^UV:52I8YEF,6YA;
MVUMR7GE>HV`?86-AOF';8V)ET6=3:/IH/FM3:U=L(F^7;T5OL'08=>-V"W?_
M>J%[(7SI?39_\'^=@&:"GH.SB<R*JXR$D%&4DY61E:*599;3ERB9&((X3BM4
MN%S,7:ES3'8\=ZE<ZW\+C<&6$9A4F%B8`4\.3W%3G%5H5OI71UD)6\1;D%P,
M7GY>S%_N8SIGUV7B91]GRVC$:```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````7VHP7L5K%VQ];']U2'EC6P!Z`'V]7X^)&(JT
MC'>-S(X=C^*8#IH\FX!.?5``49-9G%LO8H!B[&0Z:Z!RD75'>:E_^X>\BG"+
MK&/*@Z"7"50#5*M55&A8:G"*)WAU9\V>=%.B6QJ!4(8&D!A.14['3A%/RE,X
M5*Y;$U\E8%%E```]9T)L<FSC;'AP`W1V>JYZ"'L:??Y\9GWG95MRNU-%7.A=
MTF+@8AEC(&Y:AC&*W8WXD@%OIGE:FZA.JTZL3IM/H$_14$=1]GIQ4?915%,A
M4W]3ZU.L58-8X5PW7TI?+V!08&U@'V-994MJP6S"<NUR[W?X@`6!"().A?>0
MX9/_EU>96IKP3MU1+5R!9FUI0%SR9G5IB7-0:(%\Q5#D4D=7_ETFDZ1E(VL]
M:S1T@7F]>4M[RGVY@LR#?XA?B3F+T8_1D1]4@))=3C90Y5,Z4]=REG/I=^:"
MKX[&F<B9TIEW41IA7H:P57IZ=E#36T>0A98R3MMJYY%17$A<````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"88Y]ZDVQTEV&/
MJGJ*<8B6@GP7:'!^46ALD_)2&U2KA1.*I'_-CN&09E.(B$%YPD^^4!%21%%3
M52U7ZG.+5U%98E^$7W5@=F%G8:EALF,Z9&QE;V9":!-N9G4]>OM\3'V9?4M^
M:W\.@TJ#S88(BF.*9HO]CAJ8CYVX@LZ/Z)L``(=2'V*#9,!OF99!:)%0(&MZ
M;%1O='I0?4"((XH(9_9..5`F4&50?%$X4F-2IU4/5P58S%KZ7K)A^&'S8G)C
M'&DI:GURK'(N<Q1X;WAY?0QWJ8"+B1F+XHS2CF.0=9-ZEE68$YIXGD-1GU.S
M4WM>)E\;;I!NA'/^<T-]-X(`BOJ*4)9.3@M0Y%-\5/I6T5ED6_%=JUXG7SAB
M166O9U9NT'+*?+2(H8#A@/"#3H:'BNB--Y+'EF>8$Y^43I).#4](4TE4/E0O
M6HQ?H5^?8*=HCFI:=(%XGHJDBG>+D)%>3LF;I$Y\3Z]/&5`64$E1;%&?4KE2
M_E*:4^-3$50`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````Y4B5515Z)7?5E46UU;CUOE7>==]UUX7H->FEZW7AA?4F!,89=B
MV&*G8SME`F9#9O1F;6<A:)=HRVE?;"IM:6TO;IUN,G6'=FQX/WK@?`5]&'U>
M?;%]%8`#@*^`L8!4@8^!*H)2@TR(88@;BZ*,_(S*D'61<9(_>/R2I)5-E@``
M!9B9F=B:.YU;4JM2]U,(5-58]V+@;VJ,7X^YGDM1.U)*5/U60'IWD6"=TIY$
M<PEO<($1=?U?VF"HFMMRO(]D:P.8RD[P5F17OEA:6FA@QV$/9@9F.6BQ:/=M
MU74Z?6Z"0IN;3E!/R5,&56]=YEWN7?MGF6QS=`)X4(J6D]^(4%>G7BMCM5"L
M4(U1`&?)5%Y8NUFP6VE?36*A8SUH<VL(;GUPQY&`<A5X)GAM>8YE,'W<@\&(
M"8^;EF12*%=09VI_H8RT44)7*I8Z6(IIM("R5`Y=_%>5>/J=7$]*4HM4/F0H
M9A1G]6>$>E9[(GTODUQHK9LY>QE3BE$W4@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WUOV8JYDYF0M9[IKJ871EI!VUIM,
M8P:3JYN_=E)F"4Z84,)3<5SH8))D8V5?:.9QRG,C=9=[@GZ5AH.+VXQXD1"9
MK&6K9HMKU4[43CI/?T\Z4OA3\E/C5=M6ZUC+6<E9_UE06TU<`EXK7M=?'6`'
M8R]E7%NO9;UEZ&6=9V)K``![:P]L17-)><%Y^'P9?2M]HH`"@?.!EHE>BFF*
M9HJ,BNZ*QXS<C,R6_)AO:XM./$^-3U!15UOZ6TAA`6-"9B%KRVZ[;#YRO734
M=<%X.GD,@#.`ZH&4A)Z/4&Q_G@]?6(LKG?IZ^(Z-6^N6`T[Q4_=7,5G)6J1;
MB6!_;@9OOG7JC)];`(7@>W)0]&>=@F%<2H4>?@Z"F5$$7&AC9HV<96YQ/GD7
M?06`'8O*CFZ0QX:JD!]0^E(Z7%-G?'`U<DR1R)$KD^6"PELQ7_E@.T[64XA;
M2V(Q9XIKZ7+@<RYZ:X&CC5*1EID24==3:E3_6XAC.6JL?0"7VE;.4VA4````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"76S%<
MWEWN3P%A_F(R;<!YRWE"?4U^TG_M@1^"D(1&B'*)D(MTCB^/,9!+D6R1QI:<
MD<!.3T]%44%3DU\.8M1G06P+;F-S)G[-D8.2U%,96;];T6U=>2Y^FWQ^6)]Q
M^E%3B/"/RD_[7"5FK'?C>AR"_YG&4:I?[&5O:8EK\VT``)9N9&_^=A1]X5UU
MD(>1!ICF41U20&*19MEF&FZV7M)]<G_X9J^%]X7XBJE2V5-S68]>D%]58.22
M9):W4!]1W5(@4T=3[%/H5$95,5475FA9OED\6K5;!EP/7!%<&ER$7HI>X%YP
M7W]BA&+;8HQC=V,'9@QF+69V9GYGHF@?:C5JO&R(;0EN6&X\<29Q9W''=0%W
M77@!>65Y\'G@>A%[IWPY?9:`UH.+A$F%78CSB!^*/(I4BG.*88S>C*219I)^
MDQB4G):8EPI."$X>3E=.EU%P4LY7-%C,6");.%[%8/YD86=69T1MMG)S=6-Z
MN(1RB[B1(),Q5O17_I@`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````.UB#6F6:^UQ5'YW@'*"YHG?F%6'L8\[7#A/X4^U3P=5
M(%K=6^E;PU].82]CL&5+9NYHFVEX;?%M,W6Y=1]W7GGF>3-]XX&O@JJ%JHDZ
MBJN.FX\RD-V1!Y>Z3L%.`U)U6.Q8"UP:=3U<3H$*BL6/8Y9MER5[SXH(F&*1
M\U:H4P``%Y`Y5()7)5ZH8S1LBG!A=XM\X']PB$*05)$0DQB3CY9>=,2:!UUI
M77!EHF>HC=N6;F-)9QEIQ8,7F,"6_HB$;WID^%L63BQP774O9L11-E+B4M-9
M@5\G8!!B/V5T91]F=&;R:!9H8VL%;G)R'W7;=KY\5H#P6/V(?XF@BI.*RXH=
MD)*14I=9EXEE#GH&@;N6+5[<8!IBI6449I!G\W=->DU\/GX*@:R,9(WAC5^.
MJ7@'4MEBI6-"9)AB+8J#>L![K(KJEG9]#())A]E.2%%#4V!3HUL"7!9<W5TF
M8D=BL&03:#1HR6Q%;1=MTV=<;TYQ?7'+97]ZK7O:?0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````2GZH?WJ!&X(Y@J:%;HK.
MC/6->)!WD*V2D9*#E:Z;35*$53AO-G%H485Y57ZS@<Y\3%916*A<JF/^9OUF
M6FG9<H]UCG4.>59YWWF7?"!]1'T'AC2*.Y9AD""?YU!U4LQ3XE,)4*I5[EA/
M63URBUMD7!U3XV#S8%QC@V,_8[MC``#-9.EE^6;C7<UI_6D5;^5QB4[I=?AV
MDWK??,]]G'UA@$F#6(-LA+R$^X7%B'"-`9!MD)>3')<2FL]0EUB.8=.!-84(
MC2"0PT]T4$=2<U-O8$EC7V<L;K.-'Y#73UY<RHS/99I]4E.6B'91PV-86VM;
M"EP-9%%G7)#63AI9*EEP;%&*/E456*59\&!38L%G-8)5:4"6Q)DHFE-/!EC^
M6Q"`L5PO7H5?(&!+831B_V;P;-YNSH!_@=2"BXBXC`"0+I"*EMN>VYOC3O!3
M)UDL>XV13)CYG=UN)W!34T15A5M88IYBTV*B;.]O(G07BCB4P6_^BCB#YU'X
MANI3````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#I4T9/5)"PCVI9,8']7>IZOX_::#>,^')(G#UJL(HY3EA3!E9F5\5BHF/F
M94YKX6U;;JUP[7?O>JI[NWT]@,:`RX:5BEN3XU;'6#Y?K6669H!JM6LW=<>*
M)%#E=S!7&U]E8'IF8&ST=1IZ;G_T@1B'19"SF<E[7'7Y>E%[Q(0``!"0Z7F2
M>C:#X5I`=RU.\DZ96^!?O6(\9O%GZ&QKAG>(.XI.D?.2T)D7:B9P*G/G@E>$
MKXP!3D91RU&+5?5;%EXS7H%>%%\U7VM?M%_R81%CHF8=9VYO4G(Z=3IW=(`Y
M@7B!=H>_BMR*A8WSC9J2=Y4"F.6<Q5)78_1V%6>(;,USPXRNDW.6)6V<6`YI
MS&G]CYJ3VW4:D%I8`FBT8_MI0T\L;]AGNX\FA;1]5),_:7!O:E?W6"Q;+'TJ
M<@I4XY&TG:U.3D]<4'500U*>C$A4)%B:6QU>E5ZM7O=>'U^,8+5B.F/08Z]H
M0&R'>(YY"WK@?4>"`HKFBD2.$Y``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````+B0+9'8D0Z?Y6Q89.)D=67T;H1V&WMID-&3
MNF[R5+E?I&1-C^V/1))X46M8*5E57)=>^VV/?AQUO(SBCEN8N7`=3[]KL6\P
M=?N63E$05#585UBL66!<DE^795QG(6Y[=M^#[8P4D/V039,E>#IXJE*F7A]7
M=%D28!)06E&L40``S5$`4A!55%A86%=9E5OV7(M=O&"58BUD<6=#:+QHWVC7
M=MAM;VZ;;6]PR'%37]AU=WE)>U1[4GO6?'%],%)CA&F%Y(4.B@2+1HP/C@.0
M#Y`9E':6+9@PFMB5S5#54@Q4`E@.7*=AGF0>;;-WY7KT@`2$4Y"%DN!<!YT_
M4Y=?LU^<;7ER8W>_>>1[TFOL<JV*`VAA:OA1@7HT:4I<]ISK@L5;29$><'A6
M;US'8&9EC&Q:C$&0$YA15,=F#9)(6:.0A5%-3NI1F84.BUAP>F-+DV)IM)D$
M?G=U5U-@:=^.XY9=;(Q./%P07^F/`E/1C(F`>8;_7N5E<TYE40``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````@ED_7.Z7^TZ*
M6<U?C8KA;[!Y8GGG6W&$*W.Q<71>]5][8YIDPW&8?$-._%Y+3MQ7HE:I8,-O
M#7W]@#.!OX&RCY>)I(;T78IBK62'B7=GXFP^;39T-'A&6G5_K8*LF?-/PU[=
M8I)C5V5O9\-V3'+,@+J`*8]-D0U0^5>26H5H``!S:61Q_7*WC/)8X(QJEAF0
M?X?D>>=W*80O3V526E/-8L]GRFQ]=I1[E7PV@H2%ZX_=9B!O!G(;?JN#P9FF
MGOU1L7MR>+A[AX!(>^AJ85Z,@%%U8'5K46*2C&YZ=I>1ZIH03W!_G&)/>Z65
MZ9QZ5EE8Y(:\EC1/)%)*4\U3VU,&7BQDD65_9SYL3FQ(<J]R[7-4=4%^+(+I
MA:F,Q'O&D6EQ$ICOF#UC:69J=>1VT'A#A>Z&*E-14R94@UF'7GQ?LF!)8GEB
MJV*09=1KS&RR=:YVD7C8><M]=W^E@*N(N8J[C'^07I?;F`MJ.'R94#Y<KE^'
M9]AK-70)=XY_````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````[G\IG%WHY4XMU[9IF7YV!\8.8@#Q?Q5]B=49[/)!G:.M9FUH0
M?7YV+(OU3VI?&6HW;`)OXG1H>6B(58IYC-]>SV/%==)YUX(HD_*2G(3MABV<
MP51L7XQE7&T5<*>,TXP[F$]E]G0-3MA.X%<K669:S%NH40->G%X68'9B=V4`
M`*=E;F9N;39R)GM0@9J!F8)<BZ",YHQTC1R61):N3ZMD9FL>@F&$:H7HD`%<
M4VFHF'J$5X4/3V]2J5]%7@UGCWEY@0>)AHGU;1=?56*X;,].:7*2FP92.U1T
M5K-8I&%N8AIQ;EF)?-Y\&WWPEH=E7H`93G5/=5%`6&-><UX*7\1G)DX]A8F5
M6Y9S?`&8^U#!6%9VIW@E4J5W$86&>T]0"5E'<L=[Z'VZC]2/39"_3\E2*5H!
M7ZV7W4\7@NJ2`U=58VEK*W7<B!2/0GK?4I-856$*8JYFS6L_?.F#(U#X3P53
M1E0Q6$E9G5OP7.]<*5V67K%B9V,^9;EE"V<`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-5LX6SY<#)X*W[>@+."#(3LA`*'
M$HDJBDJ,II#2DOV8\YQLG4].H4Z-4%922E>H63U>V%_97S]BM&8;9]!GTFB2
M42%]JH"H@0"+C(R_C'Z2,I8@5"R8%U/54%Q3J%BR9#1G9W)F=T9ZYI'#4J%L
MAFL`6$Q>5%DL9_M_X5'&=@``:63H>%2;NY[+5[E9)V::9\YKZ539:55>G(&5
M9ZJ;_F=2G%UHID[C3\A3N6(K9ZMLQ(^M3VU^OYX'3F)A@&XK;Q.%<U0J9T6;
M\UV5>ZQ<QEL<ATINT804>@B!F5F-?!%L('?94B)9(7%?<MMW)Y=AG0MI?UH8
M6J51#51]5`YFWW;WCYB2])SJ65URQ6Y-4<EHOWWL?6*7NIYX9"%J`H.$65];
MVVL;<_)VLGT7@)F$,E$H9]F>[G9B9_]2!9DD7#MB?GRPC$]5MF`+?8"5`5-?
M3K91'%DZ<C:`SI$E7^)WA%-Y7P1]K(4SBHV.5I?S9ZZ%4Y0)80AAN6Q2=@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````[8HX
MCR]544\J4<=2RU.E6WU>H&""8=9C"6?:9V=NC&TV<S=S,750>=6(F(I*D)&0
M]9#$EHV'%5F(3EE/#DZ)BC^/$)BM4'Q>EEFY6[A>VF/Z8\%DW&9*:=AI"VVV
M;I1Q*'6O>HI_`(!)A,F$@8DABPJ.99!]E@J9?F&18C)K``"#;'1MS'_\?\!M
MA7^ZA_B(96>Q@SR8]Y8;;6%]/81JD7%.=5-0701KZV_-A2V&IXDI4@]495Q.
M9ZAH!G2#=.)USXCAB,R1XI9XEHM?AW/+>DZ$H&-E=8E206V<;@ET675K>))\
MAI;<>HV?MD]N8<5E7(:&3JY.VE`A3LQ1[EN998%HO&T?<T)VK7<<>N=\;X+2
MBGR0SY%UEAB8FU+1?2M0F%.79\MMT'$S=.B!*H^CEE><GYY@=$%8F6TO?5Z8
MY$XV3XM/MU&Q4KI='&"R<SQYTX(TDK>6]I8*EY>>8I^F9G1K%U*C4LAPPHC)
M7DM@D&$C;TEQ/GST?6^`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#NA".0+)-"5&^;TVJ)<,*,[XTRE[1205K*7@1?%V=\
M:91I:FT/;V)R_'+M>P&`?H!+A\Z0;5&3GH1YBX`RD]:*+5",5'&*:FO$C`>!
MT6"@9_*=F4Z83A"<:XK!A6B%`&E^;I=X58$`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````#%\03A5.*DXQ3C9./$X_3D).5DY8
M3H).A4YKC(I.$H(-7XY.GDZ?3J!.HDZP3K-.MD[.3LU.Q$[&3L).UT[>3NU.
MWT[W3@E/6D\P3UM/74]73T=/=D^(3X]/F$][3VE/<$^13V]/AD^63QA1U$_?
M3\Y/V$_;3]%/VD_03^1/Y4\:4"A0%%`J4"50!5`<3_9/(5`I4"Q0_D_O3Q%0
M!E!#4$=0`V=54%!02%!:4%90;%!X4(!0FE"%4+10LE``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````,E0RE"S4,)0UE#>4.50
M[5#C4.Y0^5#U4`E1`5$"4191%5$441I1(5$Z43=1/%$[43]10%%244Q15%%B
M4?AZ:5%J46Y1@%&"4=A6C%&)48]1D5&34951EE&D4:91HE&I4:I1JU&S4;%1
MLE&P4;51O5'%4<E1VU'@456&Z5'M40``\%'U4?Y1!%(+4A12#E(G4BI2+E(S
M4CE23U)$4DM23%)>4E12:E)T4FE2<U)_4GU2C5*44I)2<5*(4I%2J(^GCZQ2
MK5*\4K52P5+-4M=2WE+C4N92[9C@4O-2]5+X4OE2!E,(4SAU#5,04P]3%5,:
M4R-3+U,Q4S-3.%-`4T9315,73DE335/645Y3:5-N4QA9>U-W4X)3EE.@4Z93
MI5.N4[!3ME/#4Q)\V9;?4_QF[G'N4^A3[5/Z4P%4/51`5"Q4+50\5"Y4-E0I
M5!U43E2/5'54CE1?5'%4=U1P5))4>U2`5'94A%205(94QU2B5+A4I52L5,14
MR%2H5```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````JU3"5*14OE2\5-A4Y53F5`]5%%7]5.Y4[53Z5.)4.55`56-53%4N55Q5
M155655=5.%4S55U5F56`5:]4BE6?57M5?E6859Y5KE5\58-5J56'5:A5VE7%
M5=]5Q%7<5>15U%445O=5%E;^5?U5&U;Y54Y64%;?<316-E8R5CA6``!K5F16
M+U9L5FI6AE:`5HI6H%:45H]6I5:N5K96M%;"5KQ6P5;#5L!6R%;.5M%6TU;7
M5NY6^58`5_]6!%<)5PA7"U<-5Q-7&%<65\=5'%<F5S=7.%=.5SM70%=/5VE7
MP%>(5V%7?U>)5Y-7H%>S5Z17JE>P5\-7QE?45])7TU<*6-97XU<+6!E8'5AR
M6"%88EA+6'!8P&M26#U8>5B%6+E8GUBK6+I8WEB[6+A8KEC%6--8T5C76-E8
MV%CE6-Q8Y%C?6.]8^ECY6/M8_%C]6`)9"ED061M9IF@E62Q9+5DR63A9/EG2
M>E594%E.65I96%EB66!99UEL66E9````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!X68%9G5E>3ZM/HUFR6<99Z%G<68U9V5G:
M625:'UH16AQ:"5H:6D!:;%I)6C5:-EIB6FI:FEJ\6KY:RUK"6KU:XUK76N9:
MZ5K66OI:^UH,6PM;%ELR6]!:*ELV6SY;0UM%6T!;45M56UI;6UME6VE;<%MS
M6W5;>%N(97I;@%L``(-;IENX6\-;QUO)6]1;T%OD6^9;XEO>6^5;ZUOP6_9;
M\UL%7`=<"%P-7!-<(%PB7"A<.%PY7$%<1EQ.7%-<4%Q/7'%;;%QN7&).=EQY
M7(Q<D5R47)M9JUR[7+9<O%RW7,5<OES'7-E<Z5S]7/I<[5R,7>I<"UT571==
M7%T?71M=$5T472)=&ET971A=3%U274Y=2UUL77-==EV'781=@EVB79U=K%VN
M7;U=D%VW7;Q=R5W-7=-=TEW67=M=ZUWR7?5="UX:7AE>$5X;7C9>-UY$7D->
M0%Y.7E=>5%Y?7F)>9%Y'7G5>=EYZ7KR>?UZ@7L%>PE[(7M!>SUX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-9>XU[=7MI>
MVU[B7N%>Z%[I7NQ>\5[S7O!>]%[X7OY>`U\)7UU?7%\+7Q%?%E\I7RU?.%]!
M7TA?3%].7R]?45]67U=?65]A7VU?<U]W7X-?@E]_7XI?B%^17X=?GE^97YA?
MH%^H7ZU?O%_67_M?Y%_X7_%?W5^S8/]?(6!@8```&6`08"E@#F`Q8!M@%6`K
M8"9@#V`Z8%I@06!J8'=@7V!*8$9@36!C8$-@9&!"8&Q@:V!98(%@C6#G8(-@
MFF"$8)M@EF"78))@IV"+8.%@N&#@8--@M&#P7[U@QF"U8-A@36$5809A]F#W
M8`!A]&#Z8`-A(6'[8/%@#6$.84=A/F$H82=A2F$_83QA+&$T83UA0F%$87-A
M=V%885EA6F%K871A;V%E87%A7V%=85-A=6&9899AAV&L891AFF&*89%AJV&N
M8<QARF')8?=AR&'#8<9ANF'+87E_S6'F8>-A]F'Z8?1A_V']8?QA_F$`8@AB
M"6(-8@QB%&(;8@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````'F(A8BIB+F(P8C)B,V)!8DYB7F)C8EMB8&)H8GQB@F*)8GYB
MDF*38I9BU&*#8I1BUV+18KMBSV+_8L9BU&3(8MQBS&+*8L)BQV*;8LEB#&/N
M8O%B)V,"8PAC[V+U8E!C/F--8QQD3V.68XYC@&.K8W9CHV./8XECGV.U8VMC
M``!I8[YCZ6/`8\9CXV/)8])C]F/$8Q9D-&0&9!-D)F0V9!UE%V0H9`]D9V1O
M9'9D3F0J995DDV2E9*EDB&2\9-IDTF3%9,=DNV389,)D\63G9`F"X&3A9*QB
MXV3O9"QE]F3T9/)D^F0`9?UD&&4<905E)&4C92ME-&4U93=E-F4X94MU2&56
M955E365895YE765R97AE@F6#98J+FV6?9:MEMV7#9<9EP67$9<QETF7;9=EE
MX&7A9?%E<F<*9@-F^V5S9S5F-F8T9AQF3V9$9DEF069>9EUF9&9G9FAF7V9B
M9G!F@V:(9HYFB6:$9IAFG6;!9KEFR6:^9KQF````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#$9KAFUF;:9N!F/V;F9NEF\&;U
M9O=F#V<69QYG)F<G9SB7+F<_9S9G06<X9S=G1F=>9V!G66=C9V1GB6=P9ZEG
M?&=J9XQGBV>F9Z%GA6>W9^]GM&?L9[-GZ6>X9^1GWF?=9^)G[F>Y9\YGQF?G
M9YQJ'FA&:"EH0&A-:#)H3F@``+-H*VA9:&-H=VA_:)]HCVBM:)1HG6B;:(-H
MKFJY:'1HM6B@:+IH#VF-:'YH`6G*:`AIV&@B:29IX6@,:<UHU&CG:-5H-FD2
M:01IUVCC:"5I^6C@:.]H*&DJ:1II(VDA:<9H>6EW:5QI>&EK:51I?FEN:3EI
M=&D]:5EI,&EA:5YI76F!:6IILFFN:=!IOVG!:=-IOFG.:>A;RFG=:;MIPVFG
M:2YJD6F@:9QIE6FT:=YIZ&D":AMJ_VD*:_EI\FGG:05JL6D>:NUI%&KK:0IJ
M$FK!:B-J$VI$:@QJ<FHV:GAJ1VIB:EEJ9FI(:CAJ(FJ0:HUJH&J$:J)JHVH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````)=J
M%X:[:L-JPFJX:K-JK&K>:M%JWVJJ:MIJZFK[:@5K%H;Z:A)K%FLQFQ]K.&LW
M:]QV.6ONF$=K0VM):U!K66M4:UMK7VMA:WAK>6M_:X!KA&N#:XUKF&N5:YYK
MI&NJ:ZMKKVNR:[%KLVNW:[QKQFO+:]-KWVOL:^MK\VOO:P``OIX(;!-L%&P;
M;"1L(VQ>;%5L8FQJ;()LC6R:;(%LFVQ^;&AL<VR2;)!LQ&SQ;--LO6S7;,5L
MW6RN;+%LOFRZ;-ML[VS9;.IL'VU-B#9M*VT];3AM&6TU;3-M$FT,;6-MDVUD
M;5IM>6U9;8YME6WD;X5M^6T5;@INM6W';>9MN&W&;>QMWFW,;>AMTFW%;?IM
MV6WD;=5MZFWN;2UN;FXN;AEN<FY?;CYN(VYK;BMN=FY-;A]N0VXZ;DYN)&[_
M;AUN.&Z";JINF&[);K=NTVZ];J]NQ&ZR;M1NU6Z/;J5NPFZ?;D%O$6],<.QN
M^&[^;C]O\FXQ;^]N,F_,;@``````,`$P`C`,_P[_^S`:_QO_'_\!_YLPG#"T
M`$#_J``^_^/_/__],/XPG3">,`,PW4X%,`8P!S#\,!4@$"`/_UP`'#`6(%S_
M)B`E(!@@&2`<(!T@"/\)_Q0P%3`[_SW_6_]=_P@P"3`*,`LP##`-,`XP#S`0
M,!$P"_\2(K$`UP```/<`'?]@(AS_'O]F(F<B'B(T(D(F0":P`#(@,R`#(>7_
M!/^B`*,`!?\#_P;_"O\@_Z<`!B8%)LLESR7.)<<EQB6A):`ELR6R);TEO"4[
M(!(PDB&0(9$ADR$3,``````````````````````````````((@LBAB*'(H(B
M@R(J(BDB`````````````````````"<B*"*L`-(AU"$`(@,B````````````
M`````````````````"`BI2(2(P(B!R)A(E(B:B)K(AHB/2(=(C4B*R(L(@``
M````````````````*R$P(&\F;29J)B`@(2"V````````````[R4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````!#_$?\2_Q/_%/\5_Q;_%_\8_QG_````
M```````````````A_R+_(_\D_R7_)O\G_RC_*?\J_RO_+/\M_R[_+_\P_S'_
M,O\S_S3_-?\V_S?_./\Y_SK_``````````````````!!_T+_0_]$_T7_1O]'
M_TC_2?]*_TO_3/]-_T[_3_]0_U'_4O]3_U3_5?]6_U?_6/]9_UK_````````
M``!!,$(P0S!$,$4P1C!',$@P23!*,$LP3#!-,$XP3S!0,%$P4C!3,%0P53!6
M,%<P6#!9,%HP6S!<,%TP7C!?,&`P83!B,&,P9#!E,&8P9S!H,&DP:C!K,&PP
M;3!N,&\P<#!Q,'(P<S!T,'4P=C!W,'@P>3!Z,'LP?#!],'XP?S"`,($P@C"#
M,(0PA3"&,(<PB#"),(HPBS",,(TPCC"/,)`PD3"2,),P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````H3"B,*,PI#"E,*8PIS"H,*DPJC"K,*PPK3"N,*\PL#"Q,+(P
MLS"T,+4PMC"W,+@PN3"Z,+LPO#"],+XPOS#`,,$PPC##,,0PQ3#&,,<PR##)
M,,HPRS#,,,TPSC#/,-`PT3#2,-,PU##5,-8PUS#8,-DPVC#;,-PPW3#>,-\P
M``#@,.$PXC#C,.0PY3#F,.<PZ##I,.HPZS#L,.TP[C#O,/`P\3#R,/,P]##U
M,/8P`````````````````````)$#D@.3`Y0#E0.6`Y<#F`.9`YH#FP.<`YT#
MG@.?`Z`#H0.C`Z0#I0.F`Z<#J`.I`P````````````````````"Q`[(#LP.T
M`[4#M@.W`[@#N0.Z`[L#O`.]`[X#OP/``\$#PP/$`\4#Q@/'`\@#R0,`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````0!!$$$@03!!0$%00!!!8$%P08
M!!D$&@0;!!P$'00>!!\$(`0A!"($(P0D!"4$)@0G!"@$*00J!"L$+`0M!"X$
M+P0````````````````````````````````````````P!#$$,@0S!#0$-011
M!#8$-P0X!#D$.@0[!#P$/00``#X$/P1`!$$$0@1#!$0$101&!$<$2`1)!$H$
M2P1,!$T$3@1/!````````````````````````````````````"4")0PE$"48
M)10E'"4L)20E-"4\)0$E`R4/)1,E&R47)2,E,R4K)3LE2R4@)2\E*"4W)3\E
M'24P)24E."5")0``8?]B_V/_9/]E_V;_9_]H_VG_:O]K_VS_;?]N_V__</]Q
M_W+_<_]T_W7_=O]W_WC_>?]Z_WO_?/]]_W[_?_^`_X'_@O^#_X3_A?^&_X?_
MB/^)_XK_B_^,_XW_CO^/_Y#_D?^2_Y/_E/^5_Y;_E_^8_YG_FO^;_YS_G?^>
M_Y__``!9```````````````1````>1D9"(`9&0CT^A@(`````"`>(@@@'2((
M(!PB"``````````````````````````````````````!`````0````$`````
M````H!LB"(!L&0@``````````)A[!P@\=@<(5'8'"%QV!PAP=@<(2'8'"-CF
M!P@,YP<(-&@'"%1H!PAT:`<(F&@'"+QI!PAL<0<(/'('""1V!PA`:@<(P&L'
M"!AM!PA$;P<()'$'".1Y!PB\=0<(````````````````````````````````
M```````!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H
M*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U15
M5E=865I;7%U>7V!!0D-$149'2$E*2TQ-3D]045)35%565UA96GM\?7Y_@(&"
M@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZO
ML+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<
MW=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ^_S]_O\``0(#!`4&!P@)
M"@L,#0X/$!$2$Q05%A<8&1H;'!T>'R`A(B,D)28G*"DJ*RPM+B\P,3(S-#4V
M-S@Y.CL\/3X_0&%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ6UQ=7E]@86)C
M9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I[?'U^?X"!@H.$A8:'B(F*BXR-CH^0
MD9*3E)66EYB9FIN<G9Z?H*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]
MOK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;GZ.GJ
MZ^SM[N_P\?+S]/7V]_CY^OO\_?[_`"`@("`@("`@("@H*"@H("`@("`@("`@
M("`@("`@("`@2!`0$!`0$!`0$!`0$!`0$(2$A(2$A(2$A(00$!`0$!`0@8&!
M@8&!`0$!`0$!`0$!`0$!`0$!`0$!`0$0$!`0$!""@H*"@H("`@("`@("`@("
M`@("`@("`@("`A`0$!`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````$@``````
M````````80```'D9&0B+&1D(]/H8"``````@'B(((!TB""`<(@C@'R((````
M````````````````````````````!`````$````!`````````*`;(@B@'R((
M`````,#?!P@DX@<([.0'"`SF!PAL<P<(O&@'")!V!PC8:0<(````````````
M```````````````````````````!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9
M&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&
M1TA)2DM,34Y/4%%24U155E=865I<75M>7T5!0D-$149'2$E*2TQ-3D]045)3
M5%565UA96GM\?5E_@(&"@X2%AH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@
MH:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q<;'R,G*R\S-
MSL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GZ
M^_S]_O\`````````````````````!P`````````````````````````'````
M``````````````````````<`````````````````````````!P``````````
M```````````````'``````````````````````````<`````````````````
M````````!P`````````````````````````'````````````````````````
M``<`````````````````````````!P`````````````````````````'````
M``````````````````````<`````````````````````````!P``````````
M```````````````'``````````````````````````<`````````````````
M````````!P`````````````````````````'````````````````````````
M``<`````````````````````````!P`````````````````````````'````
M``````````````````````<`````````````````````````!P``````````
M```````````````'``````````````````````````<`````````````````
M````````!P`````````````````````````'````````````````````````
M``<`````````````````````````!P`````````````````````````'````
M``````````````````````<`````````````````````````!P``````````
M```````````````'```````````````&``````````<```````````````T`
M````````!P``````````````%P`````````'```````````````G````````
M``<``````````````"``````````!P``````````````*``````````'````
M```````````F``````````<``````````````!8`````````!P``````````
M````&``````````'```````````````=``````````<``````````````"0`
M````````!P``````````````*0`````````'```````````````*````````
M``<```````````````D`````````!P``````````````$``````````'````
M```````````/``````````<````%````!0````4````%````!P````8````%
M````!0````4````'````!P````4````%````!0````<````(````!0````4`
M```%````!P````D````%````!0````4````'````"@````4````%````!0``
M``<````+````!0````4````%````!P````P````%````!0````4````'````
M#0````4````%````!0````<````.````!0````4````%````!P``````````
M````#``````````'```````````````+``````````<``````````````"H`
M````````!P``````````````*P`````````'```````````````L````````
M``<```````````````X`````````!P``````````````'@`````````'````
M#P````4````%````!P````<````0````!0````4````'````!P```!$````%
M````!0````<````'````$@````4````%````!P````<````3````!0````4`
M```'````!P```!0````%````!0````<````'````%0````4````%````!P``
M``<````6````!0````4````'````!P```!<````%````!0````<````'````
M&`````4````%````!P````<````9````!0````4````'````!P```!H````%
M````!0````<````'````&P````4````%````!P````<````<````!0````4`
M```'````!P```!T````%````!0````<````'````'@````4````%````!P``
M``<````?````!0````4````'````!P```"`````%````!0````<````'````
M(0````4````%````!P````<````B````!0````4````'````!P```",````%
M````!0````<````'````)`````4````%````!P````<````E````!0````4`
M```'````!P```"8````%````!0````<````'````)P````4````%````!P``
M``<````H````!0````4````'````!P``````````````&0`````````'````
M```````````E``````````<``````````````!P`````````!P``````````
M````%``````````'```````````````(``````````<``````````````!,`
M````````!P````\````%````!0````8````'````$`````4````%````!@``
M``<````1````!0````4````&````!P```!(````%````!0````8````'````
M$P````4````%````!@````<````4````!0````4````&````!P```!4````%
M````!0````8````'````%@````4````%````!@````<````7````!0````4`
M```&````!P```!@````%````!0````8````'````&0````4````%````!@``
M``<````:````!0````4````&````!P```!L````%````!0````8````'````
M'`````4````%````!@````<````=````!0````4````&````!P```!X````%
M````!0````8````'````'P````4````%````!@````<````@````!0````4`
M```&````!P```"$````%````!0````8````'````(@````4````%````!@``
M``<````C````!0````4````&````!P```"0````%````!0````8````'````
M)0````4````%````!@````<````F````!0````4````&````!P```"<````%
M````!0````8````'````*`````4````%````!@````<``````````````!H`
M````````!P``````````````+0`````````'```````````````;````````
M``<``````````````!4`````````!P`````````````````````````'````
M``````````````````````<`````````````````````````!P``````````
M```````````````'``````````````````````````<`````````````````
M````````!P`````````````````````````'````````````````````````
M``<`````````````````````````!P`````````````````````````'````
M``````````````````````<`````````````````````````!P``````````
M```````````````'``````````````````````````<`````````````````
M````````!P`````````````````````````'````````````````````````
M``<`````````````````````````!P`````````````````````````'````
M``````````````````````<`````````````````````````!P``````````
M```````````````'``````````````````````````<`````````````````
M````````!P`````````````````````````'````````````````````````
M``<`````````````````````````!P`````````````````````````'````
M``````````````````````<`````````````````````````!P``````````
M```````````````'``````````````````````````<`````````````````
M````````!P``````````````!P`````````'````*0````4````%````!0``
M`!<````J````!0````4````%````%P```"L````%````!0````4````7````
M+`````4````%````!0```!<````M````!0````4````%````%P```"X````%
M````!0````4````7````+P````4````%````!0```!<````P````!0````4`
M```%````%P```#$````%````!0````4````7````,@````4````%````!0``
M`!<````S````!0````4````%````%P```#0````%````!0````4````7````
M-0````4````%````!0```!<````V````!0````4````%````%P```#<````%
M````!0````4````7````.`````4````%````!0```!<````Y````!0````4`
M```%````%P```#H````%````!0````4````7````.P````4````%````!0``
M`!<````\````!0````4````%````%P```#T````%````!0````4````7````
M/@````4````%````!0```!<````_````!0````4````%````%P```$`````%
M````!0````4````7````00````4````%````!0```!<```!"````!0````4`
M```%````%P```$,````%````!0````4````7````1`````4````%````!0``
M`!<```!%````!0````4````%````%P```$8````%````!0````4````7````
M1P````4````%````!0```!<```!(````!0````4````%````%P```$D````%
M````!0````4````7````2@````4````%````!0```!<```!+````!0````4`
M```%````%P```$P````%````!0````4````7````30````4````%````!0``
M`!<```!.````!0````4````%````%P```$\````%````!0````4````7````
M4`````4````%````!0```!<```!1````!0````4````%````%P```%(````%
M````!0````4````7````4P````4````%````!0```!<```!4````!0````4`
M```%````%P```%4````%````!0````4````7````5@````4````%````!0``
M`!<``````````````!$`````````!P```%@````%````!0````4```!'````
M60````4````%````!0```(8```!:````!0````4````%````1P```%L````%
M````!0````4```!'````7`````4````%````!0```(8```!=````!0````4`
M```%````A@```%X````%````!0````4```"&````7P````4````%````!0``
M`(8```!@````!0````4````%````"`$``&$````%````!0````4````(`0``
M``````@````%````!0````@`````````````````````````!P``````````
M```````````````'``````````````````````````<`````````````````
M````````!P``````````````'P`````````'````8@````4````%````!0``
M`"<```!C````!0````4````%````)P```&0````%````!0````4````G````
M90````4````%````!0```"<```!F````!0````4````%````)P```%H````%
M````!0````@```!'```````````````2``````````<@````````"@````4`
M```%````!B0````````+````!0````4````%,@````````P````%````!0``
M``4R````````#0````4````%````!3(````````.````!0````4````%,@``
M``````D````%````!0````4X``!7````!0````4````%````!@0````````'
M````!0````4````&!``````````````A``````````<````%````!@````4`
M```%````!T````8````&````!0````4````'0```!P````8````%````!0``
M``=````(````!@````4````%````!T````D````&````!0````4````'0```
M"@````8````%````!0````=````+````!@````4````%````!T````P````&
M````!0````4````'0```#0````8````%````!0````=````.````!@````4`
M```%````!T``````````````(@`````````'```````````````C````````
M``<`````````````````````````!P`````````````````````````'````
M``````````````````````<```#_````````````````````!P```.`Z(@@`
M````````````````````````````````````````````````````````````
M````````X#DB"```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````.`X(@@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_P```*&BHZ2EIJ>HJ:JKK*VNK["QLK.TM;:WN+FZN[R]
MOK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]35UM?8V=H`````W^#AXN/DY>;GZ.GJ
MZ^SM[N_P\?+S]/7V]_CY^OL`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```!`@,$!08'"`D*"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK
M+"TN+S`Q,C,T-38W.#DZ.SP]/C]`04)#1$5&1TA)2DM,34Y/4%%24U155E=8
M65I;7%U>7V!A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%
MAH>(B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI\`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````$``@`#``0`!0`&
M``<`"``)``H`"P`,``T`#@`/`!``$0`2`!,`%``5`!8`%P`8`!D`&@`;`!P`
M'0`>`!\`(``A`"(`(P`D`"4`)@`G`"@`*0`J`"L`+``M`"X`+P`P`#$`,@`S
M`#0`-0`V`#<`.``Y`#H`.P`\`#T`/@`_`$``00!"`$,`1`!%`$8`1P!(`$D`
M2@!+`$P`30!.`$\`4`!1`%(`4P!4`%4`5@!7`%@`60!:`%L`7`!=`%X`7P!@
M`&$`8@!C`&0`90!F`&<`:`!I`&H`:P!L`&T`;@!O`'``<0!R`',`=`!U`'8`
M=P!X`'D`>@![`'P`?0!^`'\`@`"!`((`@P"$`(4`A@"'`(@`B0"*`(L`C`"-
M`(X`CP"0`)$`D@"3`)0`E0"6`)<`F`"9`)H`FP"<`)T`G@"?`/W_`0X"#@,.
M!`X%#@8.!PX(#@D."@X+#@P.#0X.#@\.$`X1#A(.$PX4#A4.%@X7#A@.&0X:
M#AL.'`X=#AX.'PX@#B$.(@XC#B0.)0XF#B<.*`XI#BH.*PXL#BT.+@XO#C`.
M,0XR#C,.-`XU#C8.-PXX#CD..@[]__W__?_]_S\.0`Y!#D(.0PY$#D4.1@Y'
M#D@.20Y*#DL.3`Y-#DX.3PY0#E$.4@Y3#E0.50Y6#E<.6`Y9#EH.6P[]__W_
M_?_]_UL``````````````!$```":&1D(GQD9"/3Z&`@`````P$`B",`_(@C`
M/B((``````````````````````````````````````$````!`````P``````
M_P!`/B((8(PE"`````!,YP<([.<'"-RL"`@DK0@((.@'"'!V!PBHZ`<([.@'
M"'3Y!P@XIP@(E*<("/"G"`A`J`@(O&D'"&QQ!P@\<@<()'8'"$!J!PC`:P<(
M&&T'"$1O!P@D<0<(Y'D'"+QU!P@`````````````````````````````````
M``````$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:&QP='A\@(2(C)"4F)R@I
M*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'2$E*2TQ-3D]045)35%56
M5UA96EM<75Y?8$%"0T1%1D=(24I+3$U.3U!14E-455976%E:>WQ]?G^`@8*#
MA(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AHJ.DI::GJ*FJJZRMKJ^P
ML;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4U=;7V-G:V]S=
MWM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[_/W^_P`!`@,$!08'"`D*
M"PP-#@\0$1(3%!46%Q@9&AL<'1X?("$B(R0E)B<H*2HK+"TN+S`Q,C,T-38W
M.#DZ.SP]/C]`86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7I;7%U>7V!A8F-D
M969G:&EJ:VQM;F]P<7)S='5V=WAY>GM\?7Y_@(&"@X2%AH>(B8J+C(V.CY"1
MDI.4E9:7F)F:FYR=GI^@H:*CI*6FIZBIJJNLK:ZOL+&RL[2UMK>XN;J[O+V^
MO\#!PL/$Q<;'R,G*R\S-SL_0T=+3U-76U]C9VMO<W=[?X.'BX^3EYN?HZ>KK
M[.WN[_#Q\O/T]?;W^/GZ^_S]_O\`("`@("`@("`@*"@H*"@@("`@("`@("`@
M("`@("`@("!($!`0$!`0$!`0$!`0$!`0A(2$A(2$A(2$A!`0$!`0$!"!@8&!
M@8$!`0$!`0$!`0$!`0$!`0$!`0$!`1`0$!`0$(*"@H*"@@("`@("`@("`@("
M`@("`@("`@("$!`0$"```````````````````!`0````````````````````
M```0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0
M$!`0$!`0```````````````````````````````````````````,````````
M```````A````FAD9"*@9&0CT^A@(`````,!`(@C`/R((P#XB"(!"(@@`````
M```````````````````````````!`````0````,``````/\`0#XB"$!"(@@`
M````%&<'"(AG!PB49@<(Y'0'"#2I"`B0J`@(S*T("-AI!P@`````````````
M``````````````````````````$"`P0%!@<("0H+#`T.#Q`1$A,4%187&!D:
M&QP='A\@(2(C)"4F)R@I*BLL+2XO,#$R,S0U-C<X.3H[/#T^/T!!0D-$149'
M2$E*2TQ-3D]045)35%565UA96EM<75Y?8$%"0T1%1D=(24I+3$U.3U!14E-4
M55976%E:>WQ]?G^`@8*#A(6&AXB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"A
MHJ.DI::GJ*FJJZRMKJ^PL;*SM+6VM[BYNKN\O;Z_P,'"P\3%QL?(R<K+S,W.
MS]#1TM/4U=;7V-G:V]S=WM_@X>+CY.7FY^CIZNOL[>[O\/'R\_3U]O?X^?K[
M_/W^_S$A``!O(0``````````````````````````````````*B$``'0A<"%S
M(74A``!*(4LA=B%<(20A```E(3\A,",Q(S(C,R,T(S4C-B,W(S@C.2,G(2@A
M8R%A(60A*2%W(4$C0B-#(T0C12-&(T<C2"-)(THC2R-,(TTC3B-/(U`C42-2
M(U,C5"-5(U8C5R-8(UDC6B-.(0``3R$P(3(A+B%A(V(C8R-D(V4C9B-G(V@C
M:2-J(VLC;"-M(VXC;R-P(W$C<B-S(W0C=2-V(W<C>"-Y(WHC4"%#(5$A````
M````-DX``````````````````'QS````````````````?7-48P````!^<P``
M`````````````````````````````$-S`````#0X1',```````!%<P``+SP`
M`$9S````````````````1W,`````2'-)<P``````````3'-*<SQ/``!+<P``
M;TX`````````````37,``%M.`````````````$YS?D<`````3W-1<P````!2
M<P``````````````````````````4'-M.4U,8TMW5@``8%U[2P``````````
M*S(``````````````````%1S4#55<U9S5W,``'4Y``!8<P```````%1@6TP`
M`&-"67-;<UIS``!<<P``````````77,`````7G,```````````````!?<P``
M````````8',``&%S8G,``&-S``!D<V5S9G,```````````````````````!G
M<VAS`````````````"1%``````````!=.```:G,`````````````````````
M`````$U!:W,``````````````````````````&QS````````````````````
M`````````````````"%)`````&US`````````````````````````````&YS
M-V,`````6FQM<`````!O<P``<',``````````````````````````')S<W-T
M<W!.<7,`````=7-V<P````!X<P``=W,`````````````>G,```````![<WES
M0'-!<P````!"<P`````````````````````[1```:G(``#=(``!O<FMR````
M````;'(`````,4M$3```4$8```````````````````````````````!P<@``
M``!Q<CY&;G)M<@``````````*C(```````!Y<@````!X<@````````````!U
M,0```````'9R````````=7(`````<W(``'LS``!R<C(\*3(`````````````
M````````````````````````8SD`````?')[<@``>G(`````=W(``'UR``!^
M<@``````````````````)7,D<P``````````````````)G,`````+3$A<R)S
M``!T.3E,`````"-S```````````````````R2P`````K<P`````G<P``````
M````````````+',````````````````````````````````I<P``*',`````
M````````7#<``````````````````````````"US````````````````````
M````+G,``````````"]S```J<P```````'1R`````#!S``!A1````````#1S
M```U<S-S`````````````#)S.',``#%S```V<P`````````````````````W
M<P```````#IS`````````````#ES````````````````````````````````
M/',````````````````]<P``/G,`````24\`````````````.W-K0FTZ````
M`#]S```````````````````E3P``````````-W(`````````````````````
M````````````````.7(``````````````````````````#XP`````#IR*THX
M<@`````[<CQR```````````````````]<CYR```````````````````_<@``
M;DLM.P``>CHO00````````````!`<@``````````0W(```````````````!!
M<@````````````!$<@````!Q.$)R``````````!%<@``1G)'<@``2W(``"H[
M``````````!D0@````````````!,<DER2')*<@```````%\W````````````
M``````!0<D]R3G(`````,S``````````````````````````````````````
M6G(``%9R``!7<E-R67(``%5R8C,`````3$\``%AR5')2<E%R````````````
M`%QR`````````````%]R`````%YR77(``````````````````$E)6W)S,&!R
M``!B<@```````````````&\S37(W,0````!D<@``````````````````8W)A
M<BU#````````````````````````<$L``````````%I.`````&5R````````
M`````&9R````````````````9W(`````````````````````````````````
M````:'(``&ER````````````````?#D``````````&QQ`````&UQ````````
M```````````\,P```````&YQ````````;W$```````!Q/P``````````````
M````````````<'$``'%Q``!R<7-Q````````8CD`````````````='%U<0``
M``!V<7=Q`````'AQ````````,4AZ<0``)DE[<7EQ``!]<0````!\<0````!^
M<0```````"%R```````````````````````````B<@``````````````````
M```````````````````````````C<@``)'(``````````"5R`````"9R)W(`
M`"AR```I<BIR*W(L<@```````"UR+G(``#5=+W(`````````````````````
M>&0T-0``````````(3,R.C%R,'(E3```````````````````,W(T<C)R```U
M<@````!B2P```````#9R``![-0``````````````````````````````````
M<SQ$<45Q83D`````````````````````````````1G$`````/C,```````!/
M1T=Q2'$``````````%I#:T8``````````````````$EQ``````````!]1P``
M``!,0E@Q;C8``&\V``````````````````!S0TYQ<#8`````;S(`````37$`
M````2W$``$QQ``!*<0````!8<0``````````````````````````3W%0<0``
M``!1<5)Q`````````````%1Q`````%-Q````````63T``%5Q````````5W$`
M````````````````````,S56<0````![03,X`````````````%EQ````````
M`````````````````````````````$U"`````%IQ```````````M1@``````
M`````````%MQ````````````````8'$``%YQ``!=<5]Q``!<<0``````````
M````````8G$``````````````````&%Q``!D<0````!#-F-Q````````97$`
M````9G$``&AQ9W$```````!I<6MQ:G$``````````````````````````'1(
M3&8`````*3\`````,C4````````````````K<0``+'$``"Q2.UU32`````![
M,```.S```````````````````'0[,$M^/@``````````+7$``%],````````
M+G%<30``0C$```````!!.P``+W%N,C!Q````````,7$``````````#-Q-'$`
M`#9Q,G$`````-7$```````!;-````````#=Q```X<0``````````````````
M```````````````````Y<3IQ````````.W$`````/7$````````\<0``/W%"
M<0```````#YQ0'%!<0````!#<0``0C8```````!W20``)'$``````````"5Q
M```F<0``````````)W$````````````````````````````````I<2AQ```J
M<0``;$D``````````'1O````````````````=6\``&4Z````````=F]W;P``
M``!)2P````````````````````!+00```````"0P2T(``'AO``!M20``````
M`````````'MO>6]?.0``>F]".```````````````````````````14I];R%P
M?F\B<``````A,5@_?#U9-"-P````````9D<``"5P````````(C$``"1P1$0`
M`$U.*T9\;R9.```Q.`````!;30``````````````````>38T3@``*#<``&)"
M(6<``"9P+#-O/P``````````5C,H<```*7`G<&0W``!=.F,^````````(S$`
M````64X````````K<"YN```J<``````````````N<"QP+7```"]P```P<&Q.
M,7`R<```24`[2````````'T_9S0`````.DUM,C@]6S@``#5P```T<',[-G`S
M<``````H.P```````#IP+6H`````5E(``'<_.'``````````````)4YQ1@``
M````````*S$``&-`-CP``````````#=*``!`,0```````&U.:TT``#MP``!%
M10``````````>SP````````\<```/7!,/SYP``!N3@`````Y<$!P0G```$%P
M```_<`````!#<`````!$<`````!Z00``8C(`````````````17``````.$P`
M````1G``````````````1W```"I/`````````````#%;2'````````!)<$IP
M````````3G```$MP``!,<```37!/<`````````````````````!$0```````
M`'=,`````$5``````%!P``!S2```47!3<TQ,``!2<```4W```%1P5S,``%9P
M``!9/P```````%=P`````"0W``````````!8<%QP``!:<```````````6W``
M````<S-9<%UP``````````!><```2#```%]P8'```````````````````&0^
M````````87````````!'-0````!D<`````!C<```8G``````<6L``%Q*````
M`````````&5P9G``````````````````````````````````````9W``````
M:'```&EP`````&IP``````````````````!:-`````````````````````!K
M<```````````````````````````````````````````;'`C1P```````&YP
M.S(``'%P<'```````````"0Q````````038``$=*.D0B.@``8#EG/0``7#\`
M``````!S<`````!R<$)-:#122%Q&````````?#].3@``6S<`````````````
M``!V<`````!U<```````````````````2TLL1@```````````````%`Q````
M`'=P='``````44EJ37AP`````````````````````'EP``````````![<&I"
M6S-<,WIP``````````!I-#(X`````&HT`````#]%`````&!.````````````
M`````````%PX````````?'````````!]<'YP(7$``"-Q(G$`````````````
M`````#E$`````````````````````&=,``!9;RY!````````6F\``$1*6V\K
M,P```````#PQ``!7-```5C1<;P``76\``%YO7V\```````````````!@;P``
M6#15,UXY-D@``&)O86\``````````&-O``````````!<,0``````````````
M`&9O``!E;V1O``!G;P``````````:F\```````!',`````!H;P``;&]K;P``
M`````````````&YO;6]O;P``+D8```````!P;P``````````<6]S;P````!R
M;P``/V\```````!`;P````````````````````!!;P`````^;SUO````````
M8CXJ1CQO````````````````16\```````````````````````!#;P``````
M`````````````````$1O0F\``'A"``!&;P```````````````$=O`````$EO
M````````````````````````````````531(;WI,````````````````5&]*
M;P````!-;P``2V\``$QO``````````````````!.;P````````````!0;P``
M````````46\``%)O``````````!5;U-O5F]8;P``5V\``'=N`````"]+````
M`````````````````````````````````````````'L]``````````!Z;E]*
M`````%0Q``````````!&27)#``````````!X-0``?&X``%TY````````````
M````````````+#L`````````````````````>VYM/P``````````````````
M;C\A;R-O`````````````'L^```B;R1O`````%,V``!%20````!B/"-/``!^
M;G@Z`````#]/`````"9O```````````E;R=O`````````````````````'UN
M````````````````:48``%5%````````````````5T0``"QO``````````!#
M0RAO````````*6\`````````````````````````````+3<``"MO````````
M````````,#@````````````````J;P``83X`````````````````````````
M`````````'DS```````````````````P;P``/SIY00````!*1```````````
M`````````````````````#LS```````````N;R]O0T0``"UO````````````
M`````````#%O````````````````````````-V\``````````#IO````````
M```````````Y;RU%```````````R;S-O-F\``````````#AO````````0#8`
M````.V\U;P`````T;P```````````````%-&1&XV/6`\6T=Q0P```````'(\
M``!L/P``16X``$9N````````````````````````73]';@``2&X```````!)
M;F]-```W/0````````````!+;DIN``!:.0``<SE`.P``````````````````
M`````$YN``````````!F/0``36X``$QN``!I0@````!O.```0T``````````
M`#!(```````````Y/0````````````!/;@``7SX`````````````4FY0;@``
M`````%%N``````````!4;E-N`````'H^``!5;@````````````!6;E=N````
M``````!02%,Z83Q8;@``66XD3D4];DQ,3EIN8C8``````````%MN```C10``
M``!>;G@S2S\``%QN``!=;@``8$0`````54M\-@``````````````````````
M````````````8&YA;@````````````!?;@````!C;@``````````````````
M````````````````7T9#,P````!G;@````!D;F9N````````````````````
M`&)N``````````````````````````!/;P````!E;@``````````````````
M:TX`````6C@``````````````````&]N```````````T16IN`````&UN:VX`
M`'!N``````````!Q;@```````````````&EN`````'9N=#$`````:&X`````
M```M2```;&X``&`^``````````````````````````!;.0``````````````
M`````````````````$A+``!D-@````!&/0``/$8`````````````````````
M````````+4$``'1N``!N;G-N``!#3```.$1U;G)N````````````````````
M```````````````````````L00```````````````````````'EN``!X;@``
M`````````````````````````````````````$D_8VT``"T\9&T```````!E
M;0```````"%2?E$``````````&9M<&5G;21#*S]`1P``````````:&T`````
M54I41'XY`````"E#`````"HQ``!X2U<_`````````````````````%XW````
M`&$V`````%9*`````````````&EM``````````````````!K;0````!J;6`R
M`````'9&;&UW1P``,T4``&UM4CT```````!O;0````!"3'YM<6UR;0````!)
M1`````!@0G=!```H1@``<&U5-0``````````>6T``'9M)6XI1F!#<VT``'Y$
M4T5T;7AM8#\``&='3$0`````0D!W;2Y")$)U;2DP(D\```````!Z;0``````
M`````````&%"`````#4]2C\`````?&U[;0``;S!];0`````O20``)VX`````
M6T9K/P````!90P``>#8``"9N-TT_,0``5TIA,B%N(FXC;B1N.T8C0V,P*&X`
M`"EN(W0`````/4(``"IN``!S,4Q!```O.```6DT`````*VXL10```````'A!
M5SPL;@`````O;@````!E/2UN*T$J00``9#```$M.,6X``')(,VXR;C!N9&-4
M-`````!N;0``-6XT;@``````````-FX``#A-````````````````````````
M`````````````````````&%&`````"Y+```W;@``63P``````````#AN```Y
M;@```````#IN`````"%%`````````````````````&HP````````````````
M`````%DY````````.D\````````````````````````````````^;@``````
M```````T-SMN```\;@```````'1)``````````!4,P``````````````````
M.4T``#\V`````````````%1%```````````_;@``````````````````````
M`````````````````$!N````````````````06X`````````````````````
M`````````````````````````````")%`````$-N``!";@``````````````
M``````!60```3SQ?;````````%(S``!@;`````!V06%L``!B;&M)`````"\U
M````````````````````````8VP````````V1```````````6S$`````````
M````````````````````````````9&P```````````````````````!Q/```
M````````=C\``````````````````````````"U"````````````````9VP`
M``````!F;````````&5L`````````````````````&UL:VP`````:&P`````
M``````````!J;````````&EL;&P``'<U``!P;```5T```'%L``````````!9
M.```;FQO;````````"E/````````-T0``"E!````````````````<FP`````
M=6P`````````````````````<VQT;%E-```````````G1GAL````````````
M````````````````````=FQW;'EL```````````````````````````I;0``
M``````````!\;````````'UL>VP```````````````````````````````!Z
M;```?40`````(6TE;2)M?FP``"-M````````)&T``````````"MM````````
M)FT`````````````6$`H;0`````J;2=M````````````````````````````
M```````M;0``,ST``"QM`````````````"YM```````````O;0`````R;3%M
M```P;0`````T;3-M``!V3````````#9M```U;3=M```````````X;0``````
M````````````.FT`````````````````````.6U(/SMM`````&TV/&T^;0``
M`````````````````````````````#]M````````````````0&T];0``06T`
M`%8\0FTP-3,W```````````N.`````````````````````!#;0```````'!&
M`````#Y%1&T``````````````````$=M````````````````````````````
M````-#P`````1FU%;5HW2&T``````````%,S``!*;0```````%PZ26T``%)M
M`````````````$QM3FUE2DMM````````36T``%%M3VTQ-0``4&T`````````
M``````!3;0````!:1UA.```````````T/0```````%1M```````````B359M
M``!5;0````!9;4%-`````%AM``!M,U=M7&T`````6VT`````6FTR15UM````
M`````````````````%YM``````````!?;0````!L.0``)3=@;6%M8FT`````
M```````````````````````````````````K0P`````N;```````````,&P`
M`"]L```````````F1@``,6P``"U+```R;```,VP``#1L```````````U;```
M````````6D8```````````````!=/C9L``````````````````!K.2Y0-VP`
M````````````````````````````.&P_23EL``!!;``````````````Z;```
M```\;````````#ML/6P``$9+/FP_;`````````````!`;````````$)L````
M```````M,V=$``!I26(Z5SD``````````$])7S).2$5L4S150$1L26QY0V-,
M``!';$AL+C4``$IL8T=?0@````!Q2#U%1FP``$=+;#),;"A/0D1%3P````!Q
M.TML```Q0@````!<;"A!`````'A&``!020```````````````$]L/SMR.P``
M7CX``&5'```M.$YL36P``&I)````````03P`````4D4`````````````````
M``````````````!1;%)L6#E0;````````````````%-L5&P``%9L(T(``%5L
M9C0``%AL``!7;%EL`````%ML76P``%YL.F@``#MH``!9,@```````"XR.&@`
M````````````````````+F@``#9H```]:#=H````````-6@``````````'9G
M`````#-H````````+V@```````!0-#%H/&@``#)H`````````````#YH```P
M:'Q'`````````````&E-````````.6@``````````````````$]H````````
M1V@```````![/P``````````1C4``%TV``!":```````````6S(`````5#X`
M`$5H````````6CH`````445*:`````````````````````!N2@``06@`````
M``!:,E8X*4E+:```/V@`````2&@```````!2:```0V@`````````````1&@Z
M1@````!):````````$9H*$M,:&`P``````````!`:```````````````````
M`````````````$YH``!-:````````````````&M'5&@``%]H``````````!^
M,P```````&)H`````%!H````````56AN30````````````````````!>:```
M``!530``````````*DX`````````````````````>$,```````!K,P``````
M``````!R261H(48`````,3``````76@``%EH<D%3:%MH8&@``"Q'````````
M*C```%AH``!A:'A)``````````````````!<:```5V@```````````````!5
M/@``````````+ST````````L/```````````6$P`````1TD`````9V@``'!H
M`````````````````````````````%IH``````````!W,P````````````!X
M/F5H``!J:'-!`````&9H``!M:`````!?0P``;F@`````5DUC:#@S``!I:```
M``!L:"Q,``````````!O:`````!H:&MH````````````````````````````
M`````````````````"E+```A3P````````````!S:```````````````````
M>F@`````<FA#/`````````````!1:```````````````````````````3DH`
M`"),>6AX:```=&AU:```-C$``````````'=H``!Q:```````````540`````
M````````=FA^,```````````````````(D(``````````````````$-*````
M`'MH(6D``%E(``````````!^:%8^23PC:0`````^-@```````````````"1I
M``!Y27UH``!6:`````````````````````!\:```````````3T\B1G-)````
M`"MI````````````````````````,6D````````````````R:0``)6D`````
M``!V1P`````O:2=I```I:0`````````````S:2AI`````"QI`````'(Q``!E
M1@``+6DP:0``````````````````)FD``"9!```J:2<[13\P-W1,``!Y3'(]
M````````````````````````-VDU:0```````````````$Y/````````````
M```````T:0```````'5-```V:3AI```````````Y:0```````````````#QI
M.FD````````````````C1CMI````````34@N:0``````````````````````
M`````````',]```]:4)I=$$`````06D````````B:0```````$-I24$`````
M/FE`:0``````````````````/VD`````,5TB70````!%:0``````````````
M````1&D``````````````````````````'9-```\8D9I````````````````
M`````````````````````$=I``````````````````````````````````!(
M:5<X``!4-0```````$II75$``````````'4U```Z3@``<S9+:0``````````
M````````3&D```````!N0P````````````!-:0``````````````````>D8`
M`#HP`````````````````````````````````````&,R4FE3:0``````````
M`````$YI```].P``````````````````````````````````3VE"1P``````
M````4&E1:5MI````````56E8:0````````````!4:0``````````````````
M````````````````5FD``%=I6#P``%EI``!!0P``5C=",P````````````!<
M:0``````````/S,``&%I`````%UI8&D``````````#I(``````````!>:0``
M``!?:4A)6DAB:0````````````````````!]0FQI``!H:0````!K,@``9FD`
M`"I+9VD`````9&D``&5I:FEM:0````!K:0```````&EI8VD`````````````
M6$,``'1I```J3`````````````````````!R:0```````'-I````````````
M``````````````!N:0````!P:0```````'%I````````;VD`````````````
M``````````!F0```.4]X:0``>6D``````````"%J```J/P``>VD``'YI````
M`````````'9I=6D`````(FH`````7#(``'QI```C:@```````'UI````````
M`````'II```S1```=VD```````````````!H1P`````G:@``````````````
M````````````.TT`````````````````````````````````````````````
M)FH`````)6H`````````````````````+FH````````H:@```````#!J````
M````````````9DTS:@``*FH`````*VH````````O:@``,FHQ:@```````"EJ
M```````````L:@``/6H``````````````````````````````````#9J````
M`````````````````````````````````#1J`````#5J````````.FH[:@``
M*C,``$(U`````#EJ````````````````)&H``````````````````#AJ/&HW
M:@``/FH```````!`:C]J``````````````````````````!":D%J6FD`````
M``!&:@```````````````````````$-J``````````!$:@````!%:@``1VH`
M`````````&PW``!):@``2&H``#`]`````````````%0Y)UX``````````$IJ
M43T````````Y,P``2VH``%(Q``!7/DQJ`````%4Y36IA,```````````/4D`
M````3FH``````````&H_``!5:@````!2:@``;T,`````````````4VI0:EXV
M``!/:E9J`````````````#8W`````%Y"``!<:@``````````6&H````````U
M0E=J``!::@``````````46H```````!;:@``76H```````````````!O2```
M``!9:@``7FI@:@````!3.%1J``!!,```````````````````7VH``%LZ=DYA
M:F)J=4$````````````````````````B3@``````````8VHU30````!D:F5J
M`````&1*9FH``$`Z```C3@```````````````&MJ````````````````````
M````;&I8/FIJ````````9TUG:@````!I:CU`?C\```````!H:@``;6H`````
M(TH`````;VH``&YJ````````;#,``"M+<&H```````````````````````!\
M:G)J````````````````<VH``````````'1J=6H`````````````````````
M`````'EJ``!Z:@````!X:@````````````!V:@``<6IW:@``````````````
M````>VHW<``````````````````````H,@``````````````````?FI?-GUJ
M````````(FL``"%K````````)&L`````(VL``"5K`````#$]```F:P`````G
M:P```````````````"AK/D```%=-```I:P`````D2D9'*FL``"MK*S@`````
M```L-0```````"QK`````&L[04<M:P``4#,````````````````N:P``````
M````,&MW30``+VM&/P``,6L`````,FL`````,VM1-````````````````#1K
M`````#5K```V:S=K````````````````````````````````````````````
M`%$S```````````````````X:P``.6LZ:P````````````!R,@`````H/SMK
M````````````````````````````````/&L````````]:P``````````````
M````0#@``'M$/FL``````````%<W``!6/P``06L``"1&``!`:P`````Q-P``
M```_:W="+34`````0FL``$-K``!9/@```````&TW``!$:P``````````+$L`
M````7T````````!V-0``=4Q*00``16L```````!'/W!#6CX``````````$9K
M``````````!):P``2FL``````````````````#XZ0D)(:P``6SX^20``````
M``````!':P````!L.P``4S$``$YK6#<`````;CL`````;3L``$U/36M,:R=!
M``!--4-/.C-</@````````````````````!+:P````````````!0:P``46M/
M:P``6#@``$!-`````&\[)T<```````!4:P``0$```$)#`````#9-``!7:P``
M`````&PX```_0%-K``!8:VTX56M6:P``4FL```````!B0$E&`````"]#``!=
M,@```````````````'!(`````$,U`````#1$`````%MK``!9:P````!,0P``
M`````$%`4C1::P``6S\`````2DX```````!`3P```````%QK9VLU1```9FL`
M`&-K:VMD:P``8&L``'Q$7VL```````!=:P``(4UP.P````!A:P``7FL`````
M``!E:W0]``!!.````````'I"``!%2UHQ8C```"5&`````&EK``````````!H
M:P``9D8``&UK````````8FL``&QK;FL``"PX:FM6.0``53P`````;VM830``
M````````<FL``'5K`````'-K-4D```````````````!P:P````````````!@
M-@``````````=&L`````=FL``````````````````'IK`````'=K``!Y:WAK
M````````````````>VL``#$\``!]:WQK:$D`````(6P```````````````!9
M-P``````````?FLB;``````C;$0U069Y/@``)&P`````;C@`````````````
M)6P`````)FP`````/CL```````````````!.6@``)VP``"AL```R/0``*6PJ
M;``````K;``````L;"UL`````````````````````$PT``!]90``?F4`````
M`````````````````````"%F````````````````(F8C9B1F```E9B9F````
M`"AF)V8`````*68````````````````J9BMF````````````````+F8L9BUF
M83I3-P````!60P``,T@``'`]`````$U'``!M2"]F;5@`````````````````
M````,&8R9@``94TQ9C1F,V8``%--```U9@``?D@`````````````-F8`````
M````````.68`````.&8W9@``````````.F8R-P```````")!034`````````
M`#YF.V8`````/&8````````_9@``0&8]9@```````"DQ````````)S(`````
M``!"9D-F````````1&8``&)-`````````````"P]``!&9D5F````````````
M``````````````!I/T=F``````````!(9@````!)9@``930``````````$TT
M`````$IF`````````````$MF``!=2V--````````5$TW3P``33E.9E0\368`
M`````````$]F*3P```````!10@``4&8`````3#D``%=,46929@````!39@``
M````````5&8```````````````!59@``````````````````````````*CP`
M````;4P``````````%=F```_0P``5F8```````````````!99@```````%AF
M``````````````````!:9@```````#M```!;9@``7&8````````Y2EUF``!O
M05YF`````````````%]F````````````````?DYB9@``869@9C!$``!C9B8_
M``!D9@```````&5F.$]F9@``````````9V9I9FAF)4@``'E&```^3RE(````
M````````````:V8`````4SX``"I)``!L9FIF``!.-````````%0X:#L`````
M;D@````````J.$-+``!O9FUF``!..0``3SEI,```:#H`````````````64<`
M````````````````````7S!T9@``0$,`````````````6$<``%M"````````
M``````````!V9@````!R9G5F<&8``'-F)DL`````53@`````?3!Q9@``````
M`````````````````'AF``!Y9@`````Y1@```````#LV````````)F<]1P``
M````````:3L`````/#9(0$9/+DQW9E1`````````````````````````````
M````````````4S5Z9@``````````````````?&8`````````````>V8`````
M````````?68``"9#```^1P`````````````Q1```````````(V<`````````
M`````````")G``````````!^9@````!5/P``94DE9P``)&=0.5-/````````
M````````````````-6<`````````````*6<J9P``````````<#P`````*&<`
M`'@Y)V<`````*V<````````R1")*(T$``````````%Q"+V<``#!G+&<`````
M`````"UG```N9P``````````43D````````V9P``,F<``````````&9)``!L
M2RA)`````#%G`````#1G,V<```````!$2S=G````````````````.&<`````
M-T$``#EG`````#MG```_9P`````\9SIG/T<]9P``/F<````````R,@``16=`
M9P```````$%G````````0F<``"%"``````````!$9T-G1F<``````````$=G
M2&<`````0S\``&DR``!)9U=.```K/``````M/0````````````!J.U=#````
M`````````$IG2V<Q,0``3&<`````36=.9P````!/9P``4&<]-BI:46<``&5`
M4F=+/```4V<``#!0````````5&=>2EPT`````"1!6#T``'%)+CT`````````
M``````````````!59U(Y5F=,2```9&<``````````%AG``!)0G5'/SA79R5!
M````````````````66<```````````````!Z1```````````````````````
M````````````````````6V=:9UUG`````%QG``!>9P````!@9P``7V<``$\T
M``!A9P``8F=C9P`````Q.DE.``!E9R<_````````<#%F9V=G````````````
M`&AG````````````````````````````````<C```&EG``````````!J9P``
M`````````````&=)````````1SP``&QG`````````````"DS,C``````````
M`&MG;F=.1P``1#\``%8R```G2P``````````73=<-@``;6<``&HR````````
M```````````C-`````````````````````````````!Q,7)G:DY=0@````!$
M20``?F<``%<R?&<``'IG<6<``&]G``!P9P``8SQL-G=#````````448`````
M````````43$``'1G<V<``````````'EG=6=X9P```````````````%!,=V=8
M,GTS>V<`````?6<``````````%0W```````````````````C:"QH+6@`````
M```K,````````````````#1H``````````!Q,``````K:````````"IH```E
M:"1H```B:"%H8T,``'M")V@````````````````F:```````````*6@`````
M``!P054W``````````!!,2AH``!3.0````````````!Q00``````````````
M````````````````````2SX``````````````````````````````````#).
M13D`````)S@`````(T@``&UB``````````````````!O8@``````````:S@`
M`````````&YB=D0``````````'%B-S-L8@````!J2```,#$``&PZ``!23P``
M``!P8@````````````````````!R8@```````$M*``!90'1B``````````!U
M8@````````````!S8@``````````3C,``'MB``!Z8@`````G/````````'QB
M=V(```````!]8GAB``````````!82'9B`````'EB`````````````")C````
M````````````````````````````(6-A2P```````'YB`````&LP````````
M```D8P`````````````````````C8P```````$P^`````````````"5C````
M````````````0T$`````)V,F8P```````````````"AC````````````````
M````````````````:&(```````!J8BIC*6,`````````````````````````
M`````````"@\``!I3@``4CP``"MC-S<`````````````0#4G-6,[````````
M````````-$T`````,6,``#!C1$$M8P`````O8P````!+/4`_+F,L8P``*D<`
M````33X`````/$D``````````%<Z````````````````````````>$4`````
M,F,``````````#-C26-8-@`````]3S5!```````````T8P````!2,G=$(4H`
M`````````````````````````````````#5C`````````````````````'HU
M-F,`````.&,````````Y8P``*4<`````.F,`````````````.V,\8P````!9
M-E,R148H/60[```````````````````]8P``*3T`````````````2C)#20``
M```^8P````!K2````````````````$5!``!!8P``0F-I1P``03\_8P``84,`
M````0&,```````!./@``````````````````````````7#```````````"DU
M``````````````````!#8P````!X1```1&-'0``````````````M3``````C
M245C1F-50P``1TX`````2&-'8P``````````````````````````````````
M;SP`````2F-P,```````````36,```````!+8U0R3C=,8T8Y<CD``&9*3F,`
M````5$L`````4&,```````!10$\Q.C(L,````````````````$]C````````
M````````````````46-28W<^`````````````%-C``!/,P``````````56,`
M``````!J-P``9C4`````5F-U-@````!78P``?$```$U&``!@0'4Z````````
M6&,```````````````````````!B0VM!``!:8UQC66-;8P``````````````
M`"(W````````````````````````76,F-P```````&<U4DU?8P``````````
M``!@8P```````"XQ``````````!C8P```````'8S8F-A8P``96->8P``9F,I
M3@``9V,``&AC`````'14:F,``&EC````````:V-L8P``-4YM8P``;W!//FYC
M;V-7/0``.$9P8P```````"A#`````'%C```\0W)C`````````````"4V```_
M45U#,SP``````````$@T`````'-C```B9```=F,``&@U``!U8R1D````````
M=&,``%`^````````````````>&-Y8P``*T4`````>F,``%XS``````````!:
M/V1)``!\8P```````&A"````````````````=V,``'MC?6,`````>SH`````
M````````````````````````)F0N20``)DAY10``6C8E9"-D```U2'YC7D-[
M10``>D4``'8Z````````````````.&0``````````````````"AD```J9```
M````````+60``"YD```K9"QD`````"ED)V0``````````"%D````````````
M`````````````````$]*53(````````U9```,F0``#=D`````#9D``!S1R=,
M```[.S!D.60T9```,V0O9```,60``$DT`````````````````````#U#````
M`'U`````````(D@`````/F0````````D2```````````````````84`[9```
M``!/2```/V132@``6T,``#ID/&0`````/60`````````````````````````
M`````````$!D`````$0\````````1D9%9$1D`````$%D````````-D\`````
M````````2F0`````3F1+9`````````````````````!'9```````````````
M`$AD`````````````$UD````````0F154DED0V0`````3&0`````````````
M`````%)D``!*-```3V0```````!09`````!19%1D````````````````````
M`````````%-D=D@``````````%5D?$YM2EID`````%=D````````````````
M`````%9D4D```%ED6V0```````!89```7V0``%QD````````````````761&
M9````````%YD8&0```````````````!A9````````````````$9*``!B9```
M``````````````````!B3`````!.-BDW8V0`````````````-$H``&@_```P
M3`````!D9```,TX`````=$<``$9!-$<`````33T```````!`,```:61G9```
M960A-```43YJ9`````!H9```9F1N9`````!M9&QD:V0`````````````;V0`
M``````!P9#I```!Q9```<V0`````<F0``````````%(X````````.$$`````
M``!U9````````'Q%``!T9````````'9D```U2FQ!1SD``'=D``````````!(
M3@``````````````````>60`````>F0``'MD``!\9```93L``'UD3S<`````
M:C4``"HU```A90``<TQ(.7YD````````)&5F3```/$<`````,TD```````!C
M/2-E``!3/$DY9CMI-39*(F4```````!'04)+=SH`````````````````````
M9SM=1```)V5?3EDZ```H94(_```J90```````%(^,#H``````````"EE````
M`"H]/CA(025E*V4``````````"9E4#<``"YE,F5K-P`````````````M90``
M````````-F4`````2CD`````;4T\,#-E`````&LU```P90`````````````Q
M90````!]12]E+&4``"@S9$``````*#@````````X90``````````````````
M```````````U90`````````````W90```````#1E`````````````%$W,T(Y
M96Y!`````$9E`````$)E/&4``````````````````$!E>CQ=,#ME0V5'94LY
M5DP``%9$/64`````164``#IE/D,``#]E/3!*3```````````````````/F4`
M````6S9L2````````&U!``!03F\]`````&YE`````$AE``!^0```1&5)94ME
M``!Y1$YE`````$IE````````5$I+-`````!+3`````!>,`````!-90``?4X`
M``````````````!,90````````````!O,0````!L1D]E````````5F5095=E
M````````````````4V4`````````````````````>T<`````2CQ590``4F58
M95%E`````$0]```````````E2P````!,/0````!496!E`````%QE``!?90``
M765A95ME``!!95-``````$M(``!>90````!990```````"%!4C<``"L]````
M````````````)3\V061E`````&9E9V4`````8V5E90``````````````````
M6F5B90``:F5I90````!Z2P`````K-P````````````````````!H90``;&5K
M96]E``!Q90`````\.VUE``````````!R97-E`````'1E``!Z93M%=F4``'5E
M=V5X90``>64``````````'ME?&5V0@````!H8```````````````````````
M`````````&I@5DY7-GQ(2D<```````!K8```````````;6```'!@````````
M``````````````````````````````````````````!L8````````&]@:CA-
M,7%@``!P/VY@7$X`````=&`D=```````````<F!U8```````````9V!S8```
M```\.@````!V8```````````````````=V```````````'Y-````````````
M``````!X8````````````````````````````````````````````````'E@
M````````96```````````'I@`````````````````````$0T````````````
M````````````````````)3P```````````````````````````````![8```
M````````?&```````````'U@```````````````````[,0```````"%A```[
M22)A`````"0T(V$``"1A```````````E80``)V$H829A````````4TDJ82EA
M```````````````````````````L82MA+6$````````````````N83!A+V$`
M````>3D``#)A```Q80````!%-```4S\``#Q%```S83A`````````.CL``'DQ
M-&$``%%-`````&-*-6$```````!$13--0SD]/P```````$M#-%(``"Y$:#(V
M80``````````````````-V$``#QA`````#IA.6%"6B8S.&$``%HP```J2```
M``!*2```````````,4X]83MA7$,F0``````K2```+4D``#]A+$Y--T!A```^
M859(06$``$)A`````%LP`````'8^1V$``$1A;49#80```````````````"8U
M`````$IA````````16%&80``26%(825)`````$)!04$``#\U`````$MA````
M`````````$QA`````$UA`````````````$]A``!.80````````````!6,0``
M``````````!786A(46$``%-A`````%5A/C\`````5F%484`\````````4&%2
M80``0DD``$D^`````%EA`````%AA``````````!:80``)CPO.@````!W15MA
M``!+1`````!=80```````"%.7&$`````````````:4$```````````````!B
M80``9&%E851#`````````````&-A``!@80``7F%?80``86$`````````````
M`````&AA``!F80``9V$`````````````````````````````````````````
M````:6%K86QA;6$``&YA`````&IA`````````````````````'!A````````
M;V$```````````````!Q80```````````````$5.````````=&%R87-A````
M````8C0`````````````?DP```````!*2@``=F$```````!U80``````````
M=V%X80``````````?&%Y87IA>V$``'UA````````?F$``"%B````````(F(`
M`"-B```O2%!%)&)R1S1)```E8@`````F8BI%```G,T0Y)V(`````*&(`````
M*6(``"D[`````"MB`````"IB`````"QB+6(`````````````````````````
M`````````````````````````&E(```N8@```````"]B`````&ES,&(Q8C)B
M```````````N.P`````S8E9'`````%]+``!.,0``5S$`````-&(`````````
M`#9B````````-6)P10```````#E`.5T``#=B04P``#AB``!&-%=(.6(``#IB
M`````#MB````````7$P```````!53```/D0```````!J00`````]8@````!B
M/0````!*/@````!`8@`````_8CYB?4@``$<T*3@`````````````````````
M````````````````1F(`````0V(_/S),````````0F)$8D5B`````$%B````
M``````````````````````````````!'8DAB```O1```8S0```````!E0P``
M`````````````$EB````````````````````````````````````````````
M````2F)-8@````````````!G/P``1$8``$YB4TL``$MB`````$QB````````
M``````````````````````````!18@``````````4&)/8@``````````````
M``````````````!38@````!28@````!48@``````````````````````````
M`````%9B``!58@``````````34H```````````````!6/49.`````%=B````
M`#=&`````%AB`````%EB``!=8EMB7&(``%IB``````````````````!>8@``
M``````````!?8@```````````````````````&!B`````&%B-TQB8@``````
M``````!P3&-B``!.0P``:D<``&LV````````.T-D8CHV````````4$``````
M````````````````96(`````````````/3H```````````````````````!F
M8@````````````!G8@``)CA5.@``````````````````````````:6(`````
M`````%9%5CI.-0``````````````````````````)$L``$M'````````````
M`%=%``````````!<.0````````````!K8@``````````````````````````
M`````$Y-,%X`````````````+UX``````````'9````L7@``;$T`````-D8F
M7@````````````!%1````````$PQ/SDI7@```````````````"<]+EX``"U>
M*%X``"M>`````&@S```J7DE'`````"Y.`````'0^=4``````````````````
M`````````````````````````````````#9>-%X``$U)````````````````
M,5XS7@``.C$`````0#DR3P``/3,``&))`````````````&%-`````"0S.S\U
M7@`````````````````````````````Z7@````!#/@```````#!-```W7@``
M````````,EX``#A>````````7DX``'-%0D8`````````````````````````
M```````````````````````V,P````!5,0`````^7@````!!7@```````$-.
M````````9$T``````````$A>0EX_7@```````%1.15X``````````$H]1UX`
M````3%X`````<45*7@``````````1%X`````.$,`````2UX``$!>``!&7@``
M35Y\,$->``!.7@`````\/P``7ST``"5*```N.@``.UY)7CI%````````````
M````````````-D```&DS43I$/CU>0CT``````````````````$PW```\7@``
M`````%)>;3TZ.```85X``%M>=#5/10``5EY?7B\P,C$`````.3(``%A>+$)/
M7E%>03D`````````````````````8EX``%U>````````55X``````````%Q>
M````````````````*TP`````6EY>7@``````````````````4#@``$4^````
M`#E#````````5%X``````````````````"]-````````5UX`````4%YR10``
M``!37@```````%E>``````````````````!13SX\?DL``&->````````````
M````````````+D@`````;UX[.`````````````!@/0``95X````````O3D(Y
M``!R7@````!N,`````!P7@``````````9%X``````````&I>`````&Q>````
M````3TUG7@`````N10````!I7@``````````<5X``&M>1TP```````!F7@``
M(CQ^7@``````````:C,``&A>;5YN7@``````````````````;$):0@``````
M````````````````````````````=EX`````?%X`````>EX``"E%`````"-?
M=UX`````````````>%Y@7@``>34Z20```````#\\`````'<Y````````````
M`#-/``!T7@``(E]I,69!``````````````````````````!Y1P``031Z3@``
M````````````````(4Q21```````````>UY]7@`````````````R00``````
M```````A7WE>``!S7@```````$,T````````````````````````````````
M`````&DW````````+U\`````*E]X0`````!C,P``````````83T``#-?````
M````````````+%\L1"E?640```````!,7P```````"9?```E7P``+E\`````
M```H7R=?+5\``"%````D7P``````````````````,%\`````,5\`````````
M````0C0````````````````````````V7P``-5\W7P`````````````Z7P``
M`````````````$-%```T7P`````````````X7P```````````````&,W>4(R
M7SM'`````#E?```````````````````````````````````^7SQ?`````#]?
M`````$)?````````.U]J.2A'`````#E>````````````````=$T]7P``05]U
M0@``0%\``"M?`````&EO````````15\```````!)7P````!'7P``````````
M````````0U\``$1?````````2%\``$9?````````3DD`````3E\``$M?2E\`
M`$U?5$9/7P```````````````'5#;4(``````````"5`````````4%\``%)?
M`````````````````````````````%%?````````````````````````````
M``````!U7@``````````4U\```````````````!G1@``````````````````
M````````5%\``````````````````%`R````````=$4E,P``````````````
M````9#4```````!>/%(Z`````````````````````````````"=/9C\`````
M``!J,0```````%9?````````````````55\`````````````````````````
M``````````````````````!97SI#7%]77P```````%M?``````````!:7T!%
M63```````````````````````````````````'5.`````%Y?````````*#$`
M``````````````````````!@7P```````%]?``!=7P``````````````````
M``````````````````````````!87P``````````````````(TL```````!B
M7P````````````````````````````!A7P``````````````````````````
M:S$``````````&1?,DH``&-?```````````U3```````````1SX`````````
M```````````````````````````````S00````````````!&/@``````````
M`````````````````````'M.`````&I?``!Y0````````````````&9?:U\`
M````;#$`````````````````````:5\``&%'95]H7T@^``!12`````!L7P``
M43P`````````````````````````````````````>D````````````````!O
M7P```````&=?```G-P``````````;5\``````````%!-<%\````````F=```
M``````````!//0````````````````````!Q7P```````')?```````````N
M1P``````````````````=%\``````````'5?```````````S1P``````````
M=45W7P``````````>5\``%5.``!V7P``>%]M,0``<U\`````````````````
M`%M3>E\``````````&=!.#M\7P``````````>U\D/UE2````````````````
M?5\````````A8```;E]^7P`````B8````````````````'I'````````````
M````(V``````)&```````````````````````````"5@````````````````
M````````````````)F```%Y$```H8"=@`````"E@```J8`````!?/&-)````
M````;$PK8"Q@5D$D/"U@+F``````````````+V!22D=(`````#!@5T<`````
M````````+40`````````````,6!G,@``;34``$9,```V3```-#(T3P``````
M````4DL``"I*`````````````````````#=````R8```````````0T8`````
M```C.#-@``!4.C5@-&```````````#9@```````````````````````````W
M8````````#A@````````````````````````/C4``#E@```````````Z8```
M````````)#@`````2$@`````/&````````!U/@`````[8```````````````
M```````X-CU@/V```#Y@``````````````````!`8```43@``$%@````````
M``!I-@``0$$``'TY``````````!#8$1@0F````````````````!M/`````!(
M1CDV````````````````````````1F`L0T5@`````#5/8D<`````````````
M``````````````````!)8`````````````````````````````!+8$A@````
M````5$Q*8$Q@``!$3@````````````!08````````$]@=D,M1P`````E.$Y@
M``````````!-8```,4TR30```````````````%%@;C$``````````'8Y8CL`
M````````````````````4F!38```````````````````56``````````````
M````````````````0ST``````````%=@``!68`````````````!88```33,`
M````6F``````66```%Q@6V``````````````````````/#@`````*$X``$PV
M```F,@``````````````````````````:C8`````````````````````````
M``````````````````````!A-`````````````````````!H3EY@````````
M``````````!@8```````````86```%$R`````````````%U@```Y.P````!!
M1%]@````````````````````````````````````````9&```&X\````````
M``!B8```````````/C<`````24AC8`````!^8````````````````&E@````
M`````````#TX``````````!E-0``9F!]30`````P3@``85T`````````````
M``!A.P``,4P``&)=8UT`````)#4```````!D70``````````````````9EUE
M70```````````````````````````````````````&4_`````#E)2C$`````
M````````14@``'5$03UA-0````````````````````````````!&2```+CP`
M`````````&A=``!`-`````!X,0````!R1F==/CE30P``:5T`````````````
M<5T``&I=`````````````$%"``!B-7)=````````````````:#<`````)35P
M70````!N76M=8$T``````````$!$````````649L70````!T70``<UTC-P``
M```M,@`````[.FU=;UT`````````````5TMT0@````````````````````!W
M2P````!\70````!]70``3S(``````````"A*?4PA7B,\0CYX77Y=:#$``#<V
M`````'5=>ET```````!T0'%'``!G2````````````````'==```A2P``>5T`
M`"1>```B7@``>UT````````B2TA'8S4``"5%`````&U#```E7@``````````
M(UY90G9=``!+,0``````````2U9(5@``2E8``')-``!)5@``````````````
M`````````#]6````````````````````````````````<S\`````3%8`````
M-SH```````!-5@````!.5@````````````````````````````!15@``4%8`
M````3U8```````!H13I6````````5U8`````````````````````````````
M``!35@``````````4E8```````````````````````!45@``558`````````
M````````````6%8`````9DX``%E65E8`````````````````````````````
M6E8`````8#1;5@``````````759<5@````!>5@``````````7U8``&Y`(ST`
M````9#T``&-!```I.3@Z*CEP-0````!@5@`````Y.@````!*.&%6)DQ#1V)6
M```K.0```````"PT```G0U(V````````5#M;20````!!2```````````8U9U
M-```````````9E8``````````"%$`````&569%9G5@``:T0`````````````
M`````&,_`````````````%4[``!*0```4T(B-0`````B1`````!H5FE6;SX`
M`````````#E+`````&Q6`````&M6:E9]20``<U8``````````%I+``!M5@``
M``````````!O5FM+``!N5@``````````````````<%8``"A(<58^2G)6````
M```````````````````````````````S-#]*+T=T5G56```L.30T=E8X.$1-
M*4UV-'A6```C1```+3DQ/@````!?2``````R/@``````````>#T`````````
M````;$1Y2CE%`````"XY``!<20```````'E6`````````````%E%0CH`````
M``!+.```;40``````````````````$,P;CTO.4=-````````````````````
M`'I6>U911P``````````?%9W3BU/``````````!^5GU6`````$<S`````"%7
M````````)%<E5P``(U<``$!),SXG5R97(E<``````````"A7*5<`````*E<`
M```````M5RM7```L5RY7``!D,6Y$+U<``'HW=C(V1P``,%=[1@``6TH``#%7
M+D\``````````#)70$HU5R%0,5```#`\=48V5P``734D1'HP-U<F2C`Y````
M`%!#````````;T0`````````````;TPY.$PX```X5P```````#E7```_5P``
M93P````````E1```+S8Z5P```````"M)``!&0P`````[5P``````````````
M`#Q7```P-@``/5<``#Y7`````$!7``!V10````!!5T)7``!#5P`````T5S-7
M````````1%=!-P```````"=)`````$PZ-TDF1$M)15<`````-#Y&,0``1E<`
M``````!'5P``<DP`````8$@`````2E=],2Q`25=(5T(W5$(``$Y73%<``$M7
M)TYE.````````'D]35=,13X]````````0$915U!7``````````!/5P``4E=F
M.````````````````%-7?$E;/0````!45WE(``````````!!1B=$````````
M```P10````!55RLU`````````````#0_```L20```````````````'<T)D<`
M````````````````````5E=6.SI+.TL`````?C%;5P````!I0P```````%A7
M````````````````=S(``````````"U86E<````````P1P````!95P````!7
M5P``>CD``%U7`````````````````````````````````````&-7:5=A5P``
M7$4`````9E==20````!@5P``95=G3E<[`````%5"7E<```````!>-6A7+4!E
M,6)7>#)G5P```````#$V``!D5P````````````````````!J5P``````````
M`````&Q7=E=T5P````!Q5P```````'!7>$X``')7`````#(V```Q.0````!Z
M/0```````'E7:U<``````````&]77U<``'HR<U=U5U%#`````"@Z.#)M5WA7
M=U<S-@``*4)F,P``````````0S<``&Y7````````````````````````>E<`
M`'U7(5@``````````#T\```G6'!$>U<``````````"58``!Y,@``(U@D6```
M``!^5R)8````````9S@J30`````U-`````!9,298```Z1RTP````````````
M``````!A2%Q7+%@P6&5,```I6````````&E%+E@``````````````````'`^
M+UA71@```````````````````````$=/```K6```````````,5@``'LY``!+
M0`````!4,"I8*%@``%I!````````?%<T.P``````````````````1D(]6```
M6T$X6```-5@V6```9CPY6#Q8```````````W6"4]```Z6``````T6```?$Q[
M3````````#Y8/UA5,``````````````S6```````````<C8F,````````#8T
M```[6`````````````!#6$)8````````1U@``````````````````$A8````
M``````````````!&6$E805A%6`````!*6```2U@`````0%A\.P``1%A60C(Y
M,E@U/P``````````6%@``&E*`````$Y83UA06`````!76```5E@`````?4LW
M-```5%@``$4W-#,`````45@`````.$Y36%8P55@``$Q84EA96$0W35@`````
M``````````!=30```````"M-``````````!<6`````!@6````````'Y!``!Y
M3F%8`````%Y8``!;6`````!:6%]8````````````````````````,$H`````
M-$8``$8W``!B6%U8``!C6````````'LW````````,3(```````!K6```````
M`#@T``````````!I6`````!J6"DZ:%AF6&58;%AD6&Y8`````'LR````````
M````````````````````````````````````````<%@`````;U@`````````
M````````````````````*$0``'-8``!Q6&=8?#<``')8``!V6'58=UAT6'A8
M``````````````````!Y6'I8:DH``'Q8>U@_/0``+D!F,GPR``!]6```/S``
M``````!,0'Y8``!#;"%983<``")9``````````!O0````````"-9````````
M)%DZ-259```F62=95T(```````!-.`````!A3````````#Q+:CTH60``````
M``````!P0#UN8D@``&H\``!-.BE9``````````!'0@``)TH`````<4(`````
M+%D`````*ED``"U9`````"M9```````````N60`````````````Q2@`````W
M,```````````7DD`````8T@`````+UD``#)9-3X[-0``,%DW638^````````
M```Q641'````````````````7DTS6319.%EJ1359,SE>0`````!&631(``!R
M0@```````````````````````````````&1(+5H``````````'I*````````
M<40```````!U2P``.UDA,FI#``````````!$60`````T0SY915E`64=90UD`
M`$)9;T<``#Q9?3(Z67$U<T(V60`````Y630Y6T```#<^05E21P````!R-4@S
M``````````````````````````!G,R$_25E.60``2ED``'TW``!/62([:3D`
M```````````````F/3U9``!].TQ9``````````!8.TU91#``````2%D`````
M`````"E$``````````````````!S-0`````````````T-@``````````````
M````2UDG,`````!#.@```````#8_``````````````````````````!R1```
M``!42%%97D$````````````````````````J0@`````K.U)9``!465!9````
M``````!A2@``/40``````````%Q!``````````````````````````![2DX\
M8%D``%]9`````'@_````````?C<```````!963D^`````&A&,4<`````````
M`%=9`````%U!``````````!X/%Q9`````#@^``!665M9`````%-'````````
M55D``"$W`````%TS````````75DK3DXZ-4-:60``7$```#4Y9#]F,3Q!6%E%
M-0````````````!'-P``3T1>60````````````!?00````!A60``8UD`````
M-T)I60``9%D`````9ED`````````````04ES1```9UD````````L30``````
M`$A-.30`````````````+C```&59`````````````&)9``````````!X-```
M``````````!G,0``:%D```````!)30````````````````````````````!L
M60```````````````#M"``!S60```````&U9`````&I9<5D``````````%-9
M````````````````````````;ED``')9````````0DAK10``````````````
M`&M9``!O60```````$@W````````<3H```````!=0```````````````````
M``````````!W60```````````````````````"9%````````````````````
M`````````````````'19``!@2P````````````!U60```````````````'99
M``!.3```(D``````````````````````8C<``````````'U9````````````
M````````````-3MZ60``>5D``````````#)'````````-48`````````````
M,45[60```````'Q9``!O20``14<C.P``<4```%!+````````````````23,`
M`"5:?ED``````````$I-)UH`````(UH``"1:`````````````&!!````````
M```B6@``/UD````````F6@``(5H`````````````*UHL6B=%+EH`````)#LI
M6@``````````/#4`````+UH``"A:,UH``#):```Q6@```````#1:`````#9:
M<3X``#5:```````````Y6@``````````````````````````````````````
M`````````#=:````````.%IP60`````````````[6CI:`````````````'A9
M/%HP6@````!9.P``````````/5H^6D!:/UI!6GXR```V.0````!\2B]`````
M`````````$XX`````$-:``````````!&6@``4DD``%\U````````15I$6E1'
M1UHU-@```````$E:2%H````````Z-#8[`````%A&`````````````$DW````
M````=#\``$I:```P0"A%``!?24M:````````````````````````3%I-6@``
M`````#A*755&0`````!,20``6#H``&5(0T@`````````````344``$%.``!/
M6E`\`````%!:```V,`````!4-DU```!@20```````%%:0CM'0P``6SLW/P``
M`````````````%):``!]2@````!W,5P[````````55H``%-:5EHY3E1:````
M``````![0%=:`````#)"`````%A:``````````!Z-```6EH``%E:````````
M``!;6EQ:>S0`````?$8V0VPU73MA00````!</3`P````````75H`````````
M````````````(C)A6@```````````````#<Y8%H`````*SHZ/@````!?6@``
M.SX``$!,*CH```````!7,$Y```````````````````!F6@`````Q0$<Q````
M``````!5/0``9DMR.@``````````/#X``"=```````````!E6F-:9%H`````
M````````:T,`````)EL``&I:?CLX.6A:``````````!I6@``.#\```````!G
M6@`````O.P``````````````````````````;%IK6G!:`````'%:``!M6@``
M(C-N6F]:54@``````````&%)2C=R6@```````#)````]/@```````%)#````
M````````````1S8``'-:=UH`````2S)T6G9:``````````!U6@````!K/0``
M````````2$-%,'A:``````````!Y6@``````````*D0```````!Q3@``````
M````0SL`````:TH`````````````/4L````````B6WM:`````'Y:``!]6@``
M``!Z6@`````A6P````!>1@``?%H````````````````````````````````C
M6P````!L/21;``!+37A'`````"5;`````````````"=;`````"A;````````
M````````*5L``$HV2#$Y.2I;```K6W$]8D$`````6%(^03U!6$)'.@````!R
M4```````````;C<M30``?DH``'Y)```L6P``````````<SH_1"U;+T\`````
M```^2P``*T0N6WPT````````````````+ULP6UI,```D3'9+7$LE.S);````
M`&L\`````%%+```T6S=;-EL``'DT`````&`U```S6P``-5L``````````#A;
M`````'D_``````````![34DP8#H\0@``73P`````<SX`````.UL`````3D4`
M`#E;*T(Z6W(^74P\6SU;:$T``````````$);`````#HY``!51S];;$5>6F):
M``!/-0``1T<``````````$%;```^/D1(`````````````$=;``!Z2```/EL`
M`$1;0UL```````!/0```````````;4L``%-.`````&=+``!,,EX[`````$A/
M1EMU/P```````$5;`````$!;`````````````$\X````````3%M*6P``33)(
M6TY;5%L``````````````````$A"`````$%*``!66P```````"))````````
M55MP1S]+.S0``'=`0#T```````!31```+DT`````45M06P```````%);``!/
M6P````!76P``35L`````2UL``%-;25L``&Q#``!X3$8\=#H`````````````
M.CH`````;TM!,P````!.1$I&23$`````````````````````````````````
M````<D``````-$`J-P```````````````%E;`````#LY?#,`````````````
M``!;6W0S85L```````````````!>6P``<T````````!+,RPZ`````$HS3SH`
M````7%ME-TLW;44`````6EL``$8P``````````!=6U];``!--BPW```\-$LU
M``````````!B6P````!Y.G%+```W.P```````&-;````````,$D`````````
M``````````````````````!O6P``,S)D6P```````````````'5;95L``$).
M``!L6P``7T<``````````````````'1;``!G6P```````#0P:5L`````/#D`
M``````!K6P``:EL``&9;<5L``#\^````````;51H.'Q-``````````!H6P``
M=$0C,RTZ``!@6P``<%MA,P````!N6W);``!N10``````````````````?C0`
M`#)<`````$E,=UM]-```?EL``````````$!+```A7"-<```G7'E;```J0P``
M````````;T4K7'Q;```H7````````")<````````````````.3\L7``````S
M0````````````````"I</30`````````````4$]V6P`````F7%@P`````'A;
M`````#I,?5LB/T=$<UL`````)5P```````````````!Z/R]<<3,A.```````
M````,5QZ6S!<```I7'M;```M7```+EP`````````````/UP```````!.1@``
M)%P`````.UP````````]7```6$0``````````````````````````$Q-````
M`````````````````'9).%Q*0@```````#Y</T$``#5<0EQ!7```;T9`7&I&
M``````````````````!$7#=<``!(-CI<73T```````!@1SQ<2S8``#1<-EPS
M7``````P3UHS.5P`````0UPU,P``````````````````9SH```````!=,0``
M``!47``````Q3U=<`````````````#H_5EP```````!57```````````````
M`%)<````````````````1EP`````8UQ%7```6%P```````````````!07```
M``!+7$A<``!)7```45P````````B=`````!.7#TY2$1D04Q<``!'7`````!*
M7```````````34UJ2P```````$]<65P`````````````````````85Q:7```
M``!G7```95P``````````&!<````````````````7UP``%!$``!E00``75P`
M````6UP`````8EP``````````&A<=4AN7`````````````!I7&Q<9EP`````
M=$,``#A)``!<7`````!D7$`^``!/3'A<:UP`````````````(C@C,E\S````
M`%-<````````````````03YP7```=UQY/'(S`````"Y#````````````````
M;5P`````<EQV7``````V-@```````````````````````````````$PU=%P`
M````````````(34``$M&<UP```````!U7```````````````````````````
M``!O7`````````````!Q7````````````````&`S24,```````!\7```````
M``````````````!Z7&DX``!Y7````````````````"%=``````````!86P``
M`````'M<``!]7'Y<````````````````+%T``"A=``!M6P``````````)UT`
M`````````"9=`````"-=`````````````&I<)5TD70``````````````````
M````````````````*ET``"9/````````````````+5U[-@`````I72M=````
M`````````````````"=(```N70``````````````````````````````````
M`````#)=+UT`````````````````````<TTP70``````````7EP`````````
M`````````#-=````````-%T````````````````U,0``-EUG-R$\``!5-@``
M`````"0R``````````````````````````!?30``````````.%TW73I=/34`
M````5C8^-```````````/5T````````\70``/ET`````3C(``#=#```_70``
M```_-$%=``````````!`70``0ET```````!#70``1%U?.S5`(3H``'!)````
M`&)*1$\``````````'4[````````4#IR3@```````$5=1ET``&`[````````
M1UU(70````!*74E=``!82P````!>/6P\1#L``$M=``````````````````!-
M72,_``!,70````````````!.70````````````!/70````````````!075%=
M````````4ET``%1=4UU5724R2D,``%9=`````"8[3#-770````!"14Q4````
M```````C-5A=``````````!970``;$IH2P```````$=&6EUF2````````'M(
M`````%-,````````6UT`````````````````````````````75U<70````!?
M70```````%Y=```````````````````\54!5/54`````1S(_50``````````
M`````#L\```^57DW````````3%4`````````````155"50``````````````
M`````````&1#``!!50````!#50````!$50``````````````````````````
M````````````````1E5'50``````````````````````````````````<C0`
M`$E52%4```````````````````````!*50``````````````````````````
M``!N/@``````````````````354``%Q$````````13$``$M5````````3E4`
M`````````````````$]5``!250````!050``454`````````````````````
M`````%([4U4`````)CE450``>CLX0@``555655H[)SD``%),````````*#5)
M.%=56#,`````6%4``#E"``````````!952-6``!:50``6U4`````7%4``%Y5
M`````````````%]5`````&!5``!P0@``)S%I/$(P``!703`T-3P``"@Y````
M`````````&9%```A/3$T:$-J1#@P.35U2@``0CP`````4C5K0#P\*$UA50``
M````````````````7#4``$LZ`````#(S8S$L/D@R``!B549-````````````
M`$D]`````&0\8U5S-%)&*4QD50``954`````64D```````!G50``*#1W-F95
M````````````````,C0``#(_:U4A.P``23)J50``:%5L56E5*T=-7#,_``!M
M50````!`3@``;E4`````<%4``'Y#;U4``"-```![.P```````%!"=SP``'5)
M;$```$T\<54M/G)5<U53,#I"4C\``'15,T8N/@``+SX``'55`````&U`````
M````,#X`````````````=E4``'=5``!@3````````'A5``````````!&-@``
M`````"(]````````````````>55Z55P\+#]T1E0_>$@B1TDV>U4```````!O
M-7Q5``!^-@``3T8P,@``4SM]52)6(59]-@``?E4``#A%````````````````
M`````#!"``!+14@\`````%A!>DT````````````````D5@``)5961@``,SL`
M`````````"=6`````"A6````````````````````````````````````````
M````````*58```````!T-"I6`````"M6````````````````````````````
M````+#(````````````````[060T```M5BA,``````````!20@``63,`````
M+U8Q5E\T`````"Y6,%8``#-6````````````````,E8``#16````````````
M`````````````````````````````````#56````````````````/48N-@``
M`````````````&4R-E8[5@`````Y5@``=TIV2@````````````!G10``````
M`#A65#T``#=6````````````````````````<C\````````\5@````!J.@``
M``!"5@````!#5CU6,S,^5D=61E9%5D%6````````0%8`````1%8`````````
M``````!X2@`````T5`````!B/P`````````````R5#54```_-P``````````
M````````-E0````````````````````````````````W5```)#E`,SE4````
M`````````#I4`````````````#M4`````#A4````````````````````````
M````````,50`````/%0`````/50``````````&1+`````&L^````````/U1`
M5#Y4``!"5``````````````X1P````!H,%9)`````$-4````````````````
M``````````````````````````!]/@`````Y/```74=P-```:SH```````!9
M2P``,D8`````>#=/0@```````$%41%0```````````````````````!$0@``
M`````$54````````1E0```````!(5`````!I1``````````````N-```````
M````(71A,7-*`````&P^2$4``````````&8Z`````$Y4`````#U*74X`````
M````````````````=#)*5``````````````Z04U4``!C10````!)161%.4A-
M1````````$DZ````````250```````````````!V,0``-D4``````````$M4
M``!'5`````!0/P```````$]4``````````!./0``````````+38``%!4````
M``````````````````````````````!H2@```````'U!``````````!&1```
M``!25`````````````````````!/2P````!35`````!85```````````+TH`
M`````````%=445145%94`````"8Z`````$E*````````650``$5#`````'4R
M``!M/@``````````6U0``%I4``!H.0``7%1>5%U4`````&!4``!55&)4````
M``````!A5%]4`````````````$X[43\``%1!8U0\0&TP9$<``````````%M$
M``!E5&149E1G5&A4``````````!I5````````````````%%*:E0`````````
M`$8R:U0``````````#Q-,#,``$E22#T_0FQ4:TP`````````````-$P`````
M;E0``&="```W14!"5TEO5'!4>S$`````.CQQ5```````````4#!R5```````
M``````!S5`````````````!B,0````!Q-&!&=$H``````````'=454%V5$`W
M`````%M+=50``&5%>50``'A4`````````````'M4``!Z5`````!\,0``?%0I
M/GY4)4,``'U4```S2@``````````=SU;10```````"%5```````````E.0``
M`````")5(4=>2%%,`````````````"5'`````"M5`````````````#@U````
M`$5-`````"],```L5@``(U4`````````````)E4``$5"`````#A+````````
M2D4`````````````)U4```````````````!E2P``2CH`````*CX`````````
M`````````"A5`````%`[``!/.P``````````.3!(.```*T!1,```````````
M+%4M50``*E4`````````````````````.#$O-```*54``$5,,4D`````````
M`````````````````"@P``````````!Y,````````%$[``!2,```(S``````
M````````,E4``````````````````#!5````````````````/$P``#-5```Q
M50`````O53$_```````````N50```````%I*`````````````&0X````````
M`````#=5.%4`````````````*SX````````T52Q/``````````!,1P`````V
M50``````````````````````````````````````````)SH`````````````
M`````#E5````````6$D````````Z50``-54`````````````````````````
M```````````````````````[3```````````````````````````````````
M`````````````%Y'```````````````````[53))````````05-&4P``0E,`
M`#U3`````$=3,4$`````25,``"(Y/U-]0P``````````````````````````
M`````$-3/%,M-```;C1E,T130%,``````````````````'8W2E-(4U-!2C4L
M-@``15,``'0V`````````````$0Q````````````````````````````````
M``!.4TQ3```G5````````````````````````````````%%3````````````
M`$M3``!/4P````!-4P```````$P[4%,`````````````````````````````
M``````````````````!34P``6%,```````!64U53```````````````````R
M0P````!%,@``````````````````````````4E,``%13*#XS,0````!74P``
M````````````````````````````````7C(`````````````8E,``'P^7E,`
M`%Q3``!=4P``7U,````````````````````````],0``````````````````
M`````#E!``!94P``6E,``````````````````````````'HS````````````
M`````````&%3````````;S0``&138%-C4P``````````````````+DH`````
M``!51@``.$@`````````````9E,`````````````95-%,P````!G4P``````
M````:E,``````````&E3`````````````````````````````&A3```Y1P``
M``!K4P````````````````````!L4P````````````!N4P``;5,`````````
M````<%,```````!S4W%3;U-R4P``````````=%,`````````````=5,`````
M=E,``'=3````````>%-%40``?#Q-.P````!S,@``>#``````1$,`````````
M`````````````````'E3```D.@``3S!>/P````````````!Z4T<X`````'$Y
M``!\4WM3`````&!*?5,````````A5'Y3```B5```(U0``'<W`````&`Q)%0`
M````)E0``"54````````*%0`````6D4````````````````I5#4P7SH`````
M`````#TW`````$]#````````````````*E0K5``````M5```````````+E0`
M`&0Z``````````!1-@`````W2P```````"Q4+U1!.B,Y````````````````
M````````````````````````,U0`````)3H``#-#`````#!46D0T4R--```G
M/@``.E,``````````#E3,%,``````````$-"```Q4P```````&]"-E,F/@``
M```````````S4P````!D3````````#PW`````#=3.%,``````````#53.U,`
M````````````,E,``````````````````````````&PP>D,``#<\````````
M?$MF/C`[93X\,@``5$D_30``(E`O,0````!N,R-0)$!"4E8U.DH`````````
M`&<^`````#Y.``````````!"2@```````"10`````&9#````````)5!Z-@``
M`````"90``!=-#!#``!G/"=0`````"A0`````"E0-4<``%<U````````````
M`#='``!C1D,X,TL`````````````26DJ4&@^*U`U,@```````&4V<#AI3```
M```F5@````````````````````````````````````!P30``?48`````````
M`````````````````"4T```U-0``+%``````+5`[3@``/4UH02]0=CMS1@``
M,E``````/C%?.```7CAF,`````!+3TI/```S.B$P```S4#10-5`T2S90``!R
M.&<P<DL``'PU`````'TU?C5B1#Q.```W4``````X4``````Y4````````$T_
M`````````````#H]3C\^4```/%```#U06#4`````(SIP,@``.U`Z4"E*````
M``````!&.T4[/D(_4%5)9T`````````X(4!00E````````!E0F%.2C``````
M`````````````$%0/C(``$0V``!G0P```````&\W0U`````````D1P``````
M``````!K-```````````````````1%!+,`````!@.&PT>DDR2%DU````````
M`````````````'$R``!G4$%%````````````````````````````````````
M`````````&Q'1E`````````\2```8DX``"T_``!'.P``=SM`,@``````````
M``!11``````B0TI0`````````````$PP8T0[/30Z)$T``$Y"```_,@``25``
M`#Y-15!'4&XZ2%`D50``````````````````````````4%``````````````
M4U!14`````!",@``.TI+4```````````3U!S.`````!(.P```````"8T````
M`%10``!,4`````!C3@``>#L``$U0``!24```````````55```$Y0`````"$V
M``!-,``````B-D$R````````````````````````)54``'E+;DET.```````
M```````O/S=.`````````````````````%A*`````#@W)4)D,@``````````
M``!3/0```````%E0``!>4%Q0`````%=0`````"]"6E```%U06U```%U*``!8
M4```+C\``'-+7U!@4``````````````````````D/6U0````````4$<``#9)
M:%```'!*```V,@```````&Q0````````````````9E!O4`````!200``1#@`
M`%Q'``!'8```;E!=10``8U```'8X`````'4X85```````````%H\``!I4```
M;TI-0V50<3<``&)0:E!D4%%.:U!!3P````````````````````!F-@````!P
M-P```````````````````````'!0````````<5!U4$XP`````````````%!*
M=%```````````'-0=U````````!V4```9$0`````````````````````<C<`
M``````````````!X4`````````````!%/```)D)E1'8V``!Y4```````````
M-C4`````>E```````````'Q0```````````````````U2P```````&8W````
M````````````,3MW2'M0````````````````````````````````````````
M`````$4Z0TT``````````'Y0(U%]4$0Z``!]/0```````````````#DW````
M````)%$`````3S8````````A42)1`````"]&``!\00``(S8```````!-2R51
M````````/4X````````F40``````````*5$``"=1``!.00`````````````H
M42I1````````````````+%$````````K40``2$H``````````#<U+E$O40``
M+S(``````````"U1`````````````````````'0\```R43%1,%$``%90```S
M40``````````?CT``#11`````````````````````"5-````````````````
M``!93```````````-E$`````-5$X43=1`````#E1.E%T,```-3@[-SP]>T,D
M-FA`=S@``&XY/%%(3$9%``!Y.P``.U$``#U1`````````````%Y%``!U,P``
M```````````^40````!^1@`````T04!105$L2'@X.T]"40`````F-@``````
M`#Q*-D)Q-C5%````````<S<```````!#40``1%$`````8D9?,0````!'47TZ
M``!&448Z``!(46YF25%!2TI1``!+44Q1:3X``$P\````````````````)S0`
M`$]1``!-43U,3E$``%I)4%%145)17T4```````!6451155%346,Z5U%J3&1.
M`````````````%A1````````````````*$!945H]`````%I1``!\0S].8$4`
M````````````````````15(``````````%M1)71%-@````!<45Y+````````
M``!H/7Q"``!>461&`````%]1`````&!1+C,```````!A42<V``!,1GHQ4#T`
M````(4AB40``844`````3S]C40``+$I:0"(T```I-&11`````&91`````#HW
M`````&51`````'-.`````````````&D]````````````````/4A,2@``9U$`
M`'A-:%$```````!I40``?D4`````:E$`````*4!^.G0W:U%).V\Y````````
M``````````!F1&U1`````"="`````&\Z;E%O43!!``!L40``````````<5$`
M`#9+``````````!D.0````!P40``````````=3=>.FU'````````=%%R40``
M````````>TEJ/GM19#-U47-13T$``````````````````'=1``!V40``````
M`$0S````````8#=\42U.````````>%$```````!]47I1``!Y40``````````
M`````$].````````>3A#,@````!T3@````````````!U/5A%93DB4B-2````
M````94X`````*T\E4@```````'HX`````"12```O,P`````F4@``5DL``#Q$
M```F30``64H````````G4@``````````57``````,$8``"A2*C0S3```````
M`"$^*5)G2BU2```J0"I24#8``"M2*S0``````````````````````````"XW
M+E(``"]2`````#!2,5);/````````'LX7DP``&A,=T8`````<4HR4@``,U(`
M`````````#52```W4C92```````````X4CTR3$L``'PZ.5(`````64$`````
M(CXI-@``.E(```````````````!;2```````````.U(``#Q2```]4@``````
M````/E(D26@V93`````````_1C]2/3T``&E```!!4D!2(SYA.$-2/D@`````
M1%(```````!<2#1";D(H-@````!N1C%#``!N1P``3DL``$92``!J0```````
M```````U-P````!'4@``````````2%(L,74P;30``"A"435Q30``2U(W,@``
M``!*4@```````"HV`````$Q2``!Q3```````````````````````````````
M``````````````!-4@``4DX``'PX```````````V.$Y2``````````!04D]2
M``!?/SDQ````````7C%14@``4E(`````-S@`````4U(``````````&XU````
M````````````,CM44@``````````=$LU.EHU)TU003](?3P`````````````
M1ST``&@\=3P``'8]``!`2````````%=2``!#,5%!?3A%.&<V`````%M2(4-^
M0BLV)#Y<4EI21#)F0C@\2SLF,0````!P,V8Y2CL``%U2````````````````
M7E(``$DU1C,```````!G.4@U7T0E,3%&/DPA.7E-1T5^.```````````````
M`````````"\W``!G4@``8S9*2P````````````!=2`````!F4@``7C1A4F)2
M9%(``````````````````&52``!;-6$_```M2F-27U)C.```8%(``"1/````
M````<DH``&A$8CAP.0```````&A2`````%U&````````````````````````
M``````````!L4@````````````````````!^/```=CP`````````````;U)M
M4@``(TP``&I2<U)N4@```````'%21C@_3`````!R4@```````'12``!V4@``
M````````<#I"3P``:U)I4G52``!P4@``````````````````````````````
M`````````'A2```C4WI2`````'Y2`````"%3>U(`````/E,`````:3HQ,P``
M````````>5(````````E4W8P)%,``"4P2DDB4P``?%(`````=U)]4D@Z````
M`````````````````````````````````"93`````````````````````'<P
M+U,`````)U,H4P``)3YI2P```````"U3+%,````````O10``````````````
M````+E,`````*U,````````````````T,0``-CHP/P``````````````````
M*5-B10```````"I3```B,````````````````````````"$D(B0C)"0D)20F
M)"<D*"0I)"HD*R0L)"TD+B0O)#`D,20R)#,D-"0U)#8D-R0X)#DD.B0[)#PD
M/20^)#\D0"1!)$(D0R1$)$4D1B1')$@D221*)$LD3"1-)$XD3R10)%$D4B13
M)%0D5216)%<D6"19)%HD6R1<)%TD7B1?)&`D821B)&,D9"1E)&8D9R1H)&DD
M:B1K)&PD;21N)&\D<"1Q)'(D<R0``````````````````"LA+"$U(38A````
M`"$E(B4C)20E)24F)2<E*"4I)2HE*R4L)2TE+B4O)3`E,24R)3,E-"4U)38E
M-R4X)3DE.B4[)3PE/24^)3\E0"5!)4(E0R5$)44E1B5')4@E225*)4LE3"5-
M)4XE3R50)5$E4B53)50E5256)5<E6"59)5HE6R5<)5TE7B5?)6`E825B)6,E
M9"5E)68E9R5H)6DE:B5K)6PE;25N)6\E<"5Q)7(E<R5T)74E=B4`````````
M`"8A/"$S(30A`````"$A(B$C(3<A```Y(3HA.R%2(5,A5"%5(58A5R%8(5DA
M6B%;(2DB+B),(4TA````````````````02%V(@````!U(@``=")J(0``:2%Z
M(7DA?B(``````````````````",B(B(`````````````````````````````
M`````````````"4B)"(`````````````````````)R(F(@``````````````
M```````A(GXA````````>R$`````?2%\(2$H+"@B*"TH````````````````
M`````",H`````"XH)"@`````+R@F*``````Q*"4H`````#`H)R@\*``````W
M*``````R*"DH/B@`````.2@`````-"@H*``````X*#TH`````#,H*B@`````
M.B@_*``````U*"LH`````#LH`````$`H`````````````````````#8H7B)=
M(CXB/R(`````/"(](@```````````````````````````````&(B````````
M``````````````````````````!B(6$B``````````!E(68A`````&,B9"(`
M``````````````!/(@``7R)0(@```````&`B.B(`````.R(`````````````
M``!=(0``````````````````92(`````9R)G(0``7"(```````````````!*
M(DLB02)`(FDB:B(``````````````````&@A:"(``````````````````&8B
M32(``$XB*R(L(BHB+2)R(FXA````````````````````````/B$`````````
M`#TA0B$``$8A1R$`````2"%)(0````!W(G@B````````12%$(0``````````
M`````````````',B``!L(6TA```````````````````H(@``````````)R<`
M````````````````````````````````````(2<B)R,G)"<E)R8G*"<I)RHG
M*R<L)RTG+B<O)S`G,2<R)S,G-"<U)S8G-R<X)SDG.B<[)SPG/2<^)S\G0"=!
M)U$G4B=3)U0G52=6)U@G62=:)ULG7"==)UXG7R=@)V$G8B=C)V0G92=F)V<G
M:"=I)VHG:R=L)VTG;B=O)W`G<2<``%<G````````````````````````````
M````````````(28B)B,F)"8E)B8F)R8H)BDF*B8K)BPF+28N)B\F,"8Q)@``
M,B8S)C0F-28V)C<F."8``````````````````$$F0B9#)D0F129&)D<F2"9)
M)DHF2R9,)DTF3B9/)E`F428``%(F4R94)E4F5B97)E@F8"%?(0``````````
M``!Q(7(A````````>"$O(0```````$PB````````:R%>(0`````M(0``>2)`
M(0``````````````````````````66Q:;%ML````````7&P``%UL7FQ?;&!L
M``!A;````````````````&)L8VP```````````````!D;```96P`````9FP`
M````9VP`````````````:&P```````!I;````````&IL``!K;&QL;6P`````
M;FQO;'!L``````````````````````````````````````````!Q;```<FP`
M````<VP```````````````````````!T;````````````````````````'5L
M``````````!V;`````!W;```````````>&QY;'IL``![;'QL?6P`````?FP`
M````(6T````````````````B;0`````C;21M`````````````"5M````````
M`````"9M)VTH;2EM```J;0``*VTL;0``+6TN;2]M````````,&T`````,6T`
M```````R;0```````#-M-&T````````U;0``-FTW;0``.&T`````.6T``#IM
M.VT``#QM/6T``#YM```_;0``0&U!;4)M0VU$;0``````````````````````
M``````!%;0``1FU';4AM26T``$IM`````$MM3&T`````````````````````
M``!-;4YM````````3VU0;5%M4FU3;0``5&T``%5M``````````!6;0````!7
M;0````````````````````````````````````````````!8;5EM6FU;;0``
M7&T``%UM7FT```````````````!?;0````!@;6%M8FT``&-M``````````!9
M:P````````````````````````````!::P``````````6VL``%QK````````
M`````````````%YK`````````````````````%UK`````````````%]K````
M`````````&!K86L```````!B:V-K9&L`````````````````````````````
M`````````````&5K9FL``&=K:&MI:P````````````!J:P``:VMM:P``````
M````;FMO:P``;&L``'!K`````'%K`````````````````````')K<VL`````
M`````````````````````'1K`````'9K=6L``'=K````````>&MY:WIK````
M``````![:P````````````!\:WUK````````?FLA;```(FP``````````"-L
M)&P``"5L````````)FP`````)VPH;````````"EL*FP``"ML+&PM;"YL````
M`````````````````"]L`````````````````````#!L```Q;```,FP`````
M,VP````````T;````````#5L`````#9L`````#=L````````.&P````````Y
M;```.FP[;````````````````````````#QL/6P^;#]L`````$!L````````
M06Q";$-L``````````!$;```16P``$9L``!';`````!(;```26P`````2FQ+
M;````````````````````````$QL````````3FP``````````$]L`````$UL
M````````4&P``%%L4FQ3;`````!4;%5L`````%9L`````%=L6&P`````````
M````````````5FD``%=I``!8:5EI`````%II``!;:5QI76D`````7FD``%]I
M`````&!I86D``&)I``!C:0````!D:0``96D`````````````9FD``&=I``!H
M:0````!I:6II:VD```````!L:6UI````````;FD```````!O:7!I``!Q:0``
M<FD`````<VD`````````````=&EU:0``=FD```````!W:7AI`````'EI``!Z
M:7MI?&E]:7YI(6HB:@`````C:B1J```E:B9J)VHH:@``*6H``"IJ````````
M*VH`````+&H``"UJ+FH````````O:@`````````````P:@``````````,6H`
M`#)J`````````````#-J-&HU:@``-FH``#=J.&H`````.6H`````````````
M`````````````#IJ`````#MJ/&H`````````````````````/6H^:C]J````
M````0&H`````06H`````0FH``$-J``!$:D5J``!&:@``1VI(:DEJ2FI+:@``
M````````3&H``$UJ``!.:D]J4&H`````````````46I2:@```````%-J5&I5
M:E9J``!7:EAJ66H``%IJ``!;:EQJ````````76H`````````````7FH`````
M7VI@:@``````````````````86IB:@``8VH`````9&H```````!E:F9J9VH`
M`````````&AJ:6H`````:FIK:@``;&IM:@``;FH`````````````;VIP:@``
M``````````!Q:@``<FH```````````````!S:G1J``````````!U:@``=FH`
M````````````=VH``'AJ`````'EJ>FH```````![:@```````'QJ````````
M?6I^:B%K(FL`````(VL``"1K)6L``"9K`````````````````````"=K````
M````*&L``"EK```````````J:P``*VLL:RUK```N:P``+VL````````P:S%K
M`````#)K,VLT:S5K-FL````````````````W:P```````#AK.6LZ:P``````
M```````[:P```````#QK```]:SYK/VL```````!`:T%K````````0FM#:T1K
M`````$5K1FL``$=K``!(:P````!):U!K2FM+:TQK````````36L`````````
M`%)K3FM/:U%K`````%-K``!4:P``56L`````5FL``%=K````````6&L`````
M````````````````````````````````=V@``'AH``!Y:```````````````
M`'IH````````````````````````>VA\:'UH`````'YH````````(6DB:0``
M```C:0``)&D````````E:0`````````````F:0``````````````````````
M`"=I*&D``````````"EI*FD``"MI```L:0`````````````````````M:0``
M```N:2]I,&D````````Q:0```````#)I,VD````````T:0```````#5I-FD`
M```````W:3AI.6D````````````````Z:3MI````````/&D]:0``````````
M/FD``````````````````#]I``!`:0``06E":4-I`````$1I````````````
M`$5I1FD``````````$=I``!(:4EI``!*:0````````````````````!,:0``
M``!-:0````!+:0````!.:4]I4&D``%%I`````%)I`````%-I``!4:0``````
M`````````%5I``````````````````````````````````!(:```26@``$IH
M2VA,:`````!-:`````````````````````!.:`````!/:```````````````
M``````````````!0:```````````46A2:`````````````````````!3:```
M`````%1H56A6:`````!7:%AH66@`````6F@`````6V@```````!<:%UH````
M````7F@`````````````7VA@:&%H8FAC:````````&1H96AF:&=H````````
M:&AI:```````````:FAK:&QH``````````!M:&YH`````````````&]H````
M````<&AQ:```<FAS:```=&AU:'9H.F@``#MH/&@``#UH````````/F@`````
M/VA`:```06A":````````$-H`````$1H`````$5H`````$9H````````1V@`
M````````````````````````````````````1&9%9@```````$9F``!'9DAF
M268`````````````2F8``````````$MF``!,9@```````$UF3F9/9E!F``!1
M9E)F````````4V8``````````````````````````````````````````%1F
M``!59@``5F979EAF`````````````````````%EF````````````````````
M````````````6F8`````````````6V8```````````````!<9EUF``!>9E]F
M``!@9F%F8F9C9@``````````9&8``````````````````&5F``````````!F
M9@```````&=F`````&AF``!I9@``````````:F9K9FQF`````&UF````````
M``!N9F]F````````<&8```````````````!Q9@``````````````````````
M`````````````````')F``````````````````!S9@````````````!U9@``
M=F8`````=V9X9GEF````````````````````````>F8`````````````>V8`
M`'QF`````````````````````'UF``````````````````!^9B%G```B9P``
M`````"-G```````````````````````````````````````````D9R5G```F
M9P```````"=G*&<I9P``````````*F<`````````````````````*V<``"QG
M```````````````````````````````````M9P``+F<````````````````O
M9P```````#!G,6<`````````````,F<``#-G-&<``#5G-F<`````````````
M`````#=G````````.&<`````.6<````````Z9P``````````.V<`````/&<]
M9SYG`````#]G``!`9P``06="9P````````````````````!#9P``````````
M``````````````````!$9T5G1F<``$=G2&<```````!)9TIG`````$MG````
M````````````````````3&<``$UG`````$YG3V<`````4&=19P``4F=39U1G
M``!59P``5F=79P``6&<`````66=:9P``6V<``%QG76<``%YG7V=@9P``86=B
M9P````!C9P````!D9V5G9F<``&IG``!G9VAG``!I9VMG`````&QG````````
M``````````````````!M9P``;F<`````;V<`````<&=Q9P``<F<`````````
M``````````````````````!S9P````!T9P````!V9W=G`````````````'AG
M``!Y9P````!U9P````!Z9P``>V<``'QG`````'UG```H:'YG```````````A
M:``````B:"-H)&@``"5H)F@``"=H`````````````````````"EH````````
M`````"IH`````"MH`````"QH````````````````+6@N:"]H`````#!H,6@`
M`#)H,V@``````````````````#1H-6@``#9H-V@````````X:```.6A]97YE
M```````````A9@`````````````B9@```````"-F````````)&8E9B9F````
M`````````````````````````````````"=F*&8I9@``*F8``````````"MF
M`````"QF```M9BYF```````````````````O9@``,&8````````Q9@`````R
M9@``,V8````````````````T9@``-68V9@``-V8``````````#AF.68Z9CMF
M`````````````#QF/68`````/F8_9D!F068```````!"9@``0V8``"UA````
M`"YA+V$`````,&$Q83)A`````````````````````````````````````#-A
M-&$``#5A`````````````#9A```W83AA```````````Y80```````#IA.V$`
M`#QA`````#UA```^83]A``!`80``````````````````````````06$`````
M0F%#80```````$1A`````````````$5A`````$9A````````1V%(80``````
M````26$`````2F$```````!+80``3&$```````!-80```````$YA````````
M`````````````````````$]A`````%!A````````````````````````````
M````46%2851A``!5859A``!380```````%=A6&$`````66$`````````````
M`````%IA````````6V%<80``````````````````76$`````````````````
M````````````````````7F$``%]A``````````!@80```````&%A8F$`````
M`````&-A````````9&$```````!E80``````````9F$`````````````````
M````````````9V$`````:&$`````:6%J80``:V$``&QA``````````!M80``
M;F%O87!A``!Q80``````````<F%S871A`````'5A````````````````````
M``````!V80``=V%X87EA``!Z80```````````````'MA?6$``````````'YA
M(6(B8@``(V(D8@```````'QA`````````````"UB`````"5B```F8B=B*&(`
M````*6(J8@``*V(`````````````+&(`````````````+V(````````P8C%B
M````````,F(``"YB```````````````````S8C1B-6(````````V8C=B.&(`
M`#EB```````````Z8@`````[8@```````#QB```]8CYB/V(``$!B``!!8@``
M0F(``$-B``!%8D9B``!$8@``1V(``$AB``````````!)8DIB``!+8@````!,
M8@``36).8@``3V)08@``46)28@````````````!38@```````%1B56(`````
M``````````!68@```````%=B````````6&(``%EB6F);8@````````````!<
M8@````!=8@````!>8@````````````!?8@```````````````&!B````````
M``!A8F)B8V(`````````````9&(``&5B``!F8F=B````````:&(```````!I
M8@````!J8@``:V)L8FUB`````&YB`````````````&]B`````'!B````````
M``!Q8@``<F(```````!S8G1B=6(``'9B=V)X8GEB`````'IB``````````![
M8GQB?6(``'YB`````"%C(F,``"-C````````````````````````````````
M```D8R5C`````"9C```G8RAC````````*6,`````````````*F,K8P``````
M`"QC+6,``"YC+V,P8S%C,F,S8P`````````````T8P``-6,``#9C```W8P``
M```X8SEC`````#IC.V,\8SUC```^8S]C``!`8P```````$%C``!"8T-C````
M`$1C``!%8P```````$9C1V,`````````````2&-)8TIC2V,``$QC````````
M`````$UC3F-/8P````!08P``46-28P``4V-48U5C``!68P``5V,``%AC``!9
M8UIC`````%MC7&,`````76,`````7F-?8V!C``!A8P```````````````&)C
M8V,`````9&-E8P````!F8V=C````````:&,``&EC:F-K8P``````````;&-M
M8VYC``````````!O8W!C<6-R8W-C``!T8W5C=F,``'=C````````````````
M`````'AC>6-Z8P````![8WQC````````?6,``````````'YC```A9```````
M```````B9"-D````````)&0E9```)F0G9``````H9````````"ED`````"ID
M````````*V0``"QD```M9"YD+V0P9```,60R9#-D-&0U9```-F0W9#AD.60`
M````.F0[9#QD/60``#YD`````#]D``!`9```061"9$-D`````$1D160``$9D
M1V1(9```260``$ID``!+9$QD````````360``$YD``!/9```````````````
M``````!09```460```````!29%-D``!49`````````````!59```````````
M5F0```````!79`````!89%ED````````````````6F1;9%QD760``%YD````
M`%]D8&0``&%D``!B9&-D`````````````````````&1D960``&9D9V0`````
M``````````````````````````````````!H9&ED:F0```````````````!K
M9&QD;60`````;F0``&]D<&0``'%D````````<F0`````````````<V1T9```
M=60``'9D=V0`````>&0``'ED>F1[9```?&1]9```?F0````````A90`````B
M90``(V4D925E)F4`````````````)V4``"AE*64``"IE```K90`````L90``
M```M90`````N90`````O90`````P90`````Q90``,F4S90``-&4``#5E.V4`
M`#9E`````````````````````#=E.&4Y90```````#IE````````````````
M/&4`````/64^93]E0&4``$%E0F5#941E164`````````````1F4`````````
M````1V4`````2&4``$EE2F4`````2V4```````!,94UE````````````````
M````````````````````````3V5094YE465290``4V4```````!4955E``!6
M90```````%=E6&4```````!995IE6V4`````````````7&5=95YE````````
M``````````!?90````````````````````````````````````!@96%E``!B
M96-E9&5E90```````````````&9E``!H90``9V4```````!I90``:F4`````
M:V4``&QE``!M90````````````````````!N90```````&]E`````'!E````
M`'%E``!R90``<V4``````````'1E`````'5E``!V97=E>&4``'EE>F4`````
M`````````````````````````````````````'QE>V4`````````````````
M````1E\```````!'7P````!(7P``25\`````````````````````````````
M`````````````$I?`````$M?``!,7P```````$U?``````````!.7P````!/
M7U!?````````45\`````````````````````4E]37U1?`````````````%5?
M``````````!67U=?`````%A?`````%E?`````%I?``!;7P``7%\``%U?;U\`
M``````!>7P``````````7U]@7V%?8E\``&-?````````9%\`````95\`````
M9E]G7P``:%\``&E?``````````````````````````!J7VM?``!L7P``````
M````;5\```````!N7W!?<5\``')?`````````````````````'-?````````
M=%\`````=5]V7W=?``````````!X7P````````````!Y7P````!Z7P``>U\`
M``````````````````````!\7WU??E\A8``````B8"-@````````````````
M````````)&```"5@`````"9@)V`H8"E@````````*F``````*V`L8```````
M`````````````````"U@```N8"]@,&```````````#%@````````````````
M,F`S8#1@-6``````-F`W8````````````````#A@`````#E@.F```#M@/&`]
M8```````````````````/F`_8$!@````````````````06!"8```````````
M``!#8````````````````$1@``!%8`````!&8```````````1V!(8```26!*
M8````````$M@``````````!,8```36````````!.8$]@``````````!08```
M46```````````%)@4V```````````%1@56```%9@5V``````6&``````````
M`````````%E@``!:8`````!;8```````````````````7&``````````````
M````````````````76```````````&1@7F```%]@8&``````````````86``
M`&)@8V``````````````96```&9@``````````!G8&A@````````````````
M:6!J8`````````````!K8&Q@;6``````````````;F```&]@<&```'%@``!R
M8```<V!T8````````'5@=F!W8`````````````!X8'E@>F![8`````!\8```
M``````````!]8'Y@```A80```````")A```````````````````C80``)&$E
M829A)V$H80`````I80``````````*F$K80```````````````"QA````````
M````````````````````````````````*E\K7P``````````````````````
M````+%\M7P`````N7P``+U\````````P7P`````````````R7S%?`````#-?
M````````-%\````````U7P```````````````#9?````````-U\`````.%\Y
M7P``.E\`````.U\``#Q?/5\`````````````/E\_7P``0%\``$%?````````
M`````$)?`````````````````````$-?``````````!$7P```````$5?````
M``````````````````````````````!B7F->````````9%YE7@``````````
M`````&9>``!G7@``:%X``&E>````````:EX``&M>``!L7FU>`````&Y>;UYR
M7@``<%X``'%>`````````````'->=%X``'5>``!V7G=>````````>%X`````
M````````>5X``'I>>UX``````````'Q>`````'U>``````````````````!^
M7B%?````````(E\``````````"-?```D7R5?`````````````"9?```G7RA?
M```````````````````I7P```````#1=-5TV73==.%T`````````````````
M```````````````Y70```````#I=```[70``/%T````````]70``/ET`````
M/UT`````0%T```````!!70``0ET``````````$-=1%T``$5=````````````
M``````!&70``1UU(70``25U*70````````````````````!+70``3%T``$U=
M``!.70``3UT``````````%!=45T`````4ET`````````````4UT``%1=````
M`````````%5=5ET``%==`````%A=``!970``6ET``%M=````````7%U=70``
M````````7ET`````7UU@76%=````````8EUC70```````&1=````````95T`
M`&9=``````````````````````````````````!G76A=:5T``&I=:UUL70``
M``!M76Y=;UT`````<%T`````<5T``````````')=````````<UUT70``=5T`
M``````!V77==``!X70````````````!Y70``````````````````>ET``'M=
M``````````!\77U=````````?ET`````(5XB7@```````"->`````"1>````
M```````E7@`````F7@``)UXH7BE>````````````````*EX``"M>+%XM7@``
M+EX`````````````+UX``#!>````````````````````````````````,5X`
M```````R7@```````#->-%XU7@`````````````V7@`````W7@``````````
M```X7CE>````````/UXZ7@`````````````[7@``````````````````````
M````/%X``#U>/EX``````````````````````````````````$!>`````$%>
M````````````````0EX``````````$->`````````````$1>15Y&7D=>2%X`
M`$E>``````````!.7@``````````2EY+7DQ>``````````!-7@``````````
M3UX``````````%!>````````````````````````45X`````````````````
M````4EX``%->5%X`````55X``%9>`````%=>`````%A>65X`````````````
M6EX``%M>``!<7@``````````75Y>7@```````````````%]>``!@7F%>````
M```````Y7```.EP[7#Q<`````#U</EP``````````````````#]<``!`7```
M`````````````````````````````````````$%<`````$)<0UP``$1<````
M````````````````````15Q&7$=<2%Q)7`````!*7$M<3%P`````````````
M`````$U<`````$Y<`````````````````````$]<``````````````````!0
M7%%<4EP```````!37```5%P```````````````````````!57```````````
M5EP```````````````!77%A<65P`````````````6EQ;7```7%Q=7%Y<``!?
M7````````&!<`````````````&%<8EQC7```````````````````9%QE7&9<
M`````&=<````````:%QI7````````&I<``!K7```;%P`````;5QN7`````!O
M7`````````````!P7`````!Q7```````````<EP`````<UQT7'5<````````
M``!V7'=<>%P``````````````````'E<`````'I<``![7`````!\7```?5P`
M`````````'Y<(5TB72-=`````````````````````````````"1=````````
M)5T`````)ET````````G72A=`````````````"E=*ET`````*UTL70``````
M````+5T``````````````````````````"Y=````````+UTP73%=,ET`````
M`````#-=`````````````````````````````$U8````````````````````
M````3E@`````````````````````````````3U@``%!845@``%)8`````%-8
M``!46```55A66````````%=8``!86%E86E@``%M8````````7%@```````!=
M6%Y8``!?6`````!@6`````````````!A6`````!B6&-8``!D6```95@`````
M``!F6&=8````````:%@```````!I6```````````````````````````````
M`&I8:U@``&Q8`````````````````````&U8``````````````````!N6```
M;UAP6'%8``````````!R6```<U@`````=%@`````````````=5@`````=EAW
M6```>%@``'E8``````````!Z6'M8````````?%@`````?5@```````!^6```
M```````````````````A60``````````````````````````(ED`````(UD`
M`````````"19)5DF62=9```````````H60`````J62M9```L60``````````
M+5DN60```````"]9```````````P60``,5D``#)9````````````````````
M`````````#-9```T60```````#59-EDW63A9```Y60`````Z63M9````````
M/%D`````*5D]63Y9```_60````````````````````!`60``````````````
M`$%9`````````````````````$)90UE$64591ED`````1UD`````2%D`````
M25E*64M93%E-64Y93UD``%!9````````````````45D```````!260``````
M`````````````````%-95%E560``5ED``%=9``!860```````%E96ED`````
M6UD``%Q975D`````7ED```````!?60``````````8%D``````````&%9``!B
M66-9``!D60````!E60``9ED`````````````=%D```````````````!G60``
M:%EI66I9````````:UEL66U9;ED`````;UD``````````'!9`````'%9<ED`
M````<UD```````````````````````!U60``=ED``````````'=9>%D`````
M````````>5D``'I9``````````![60````````````!\60````!]60``````
M``````!^60`````A6B):````````(UHD6@``````````````````)5HF6@``
M)UHH6BE:`````````````"I:*UH``"Q:`````"U:`````"Y:````````````
M`"]:```P6@```````````````````````````````#%:```R6@``,UH``#1:
M-5H`````-EIF.#=:````````.%H`````````````````````````````.5HZ
M6@`````[6CQ:/5H^6@```````#]:`````$!:05I"6D-:1%H``````````$5:
M`````$9:`````$=:`````````````$A:25I*6@````!+6@``````````````
M````````````````````;5H``````````$Q:````````35H``````````$Y:
M``!/6@``4%H``%%:``````````!26@``````````4UI46E5:``````````!6
M6@```````%=:``!86EE:6EH``%M:7%I=6@````````````!>6E]:8%H``&%:
M``!B6@````````````````````````````!C6F1:`````&5:``!F6@````!G
M6@``:%H```````!I6@````!J6@``:UH``&Q:````````````````````````
M````````````````````````;EH``&]:<%H```````````````!Q6G):``!S
M6@```````'1:`````'5:=EIW6@````!X6GE:``````````!Z6@``````````
M>UI\6@``?5H``'Y:```````````A6P`````````````B6R-;```D6R5;````
M````````````)ELG6P``*%LI6RI;```K6P`````L6P``+5L`````````````
M`````"Y;```````````````````````````O6P``````````,%L````````Q
M6P`````R6S-;````````````````````````-%L``#5;-EL`````````````
M````````-UL``````````````````#A;.5LZ6SM;/%L]6SY;```_6T!;````
M````05L`````0EL``$-;``!$6T5;1EL``````````$=;``!(6P````!)6P``
M`````$I;``````````!+6TQ;35L`````3EL```````!/6P``````````````
M``````!06U%;``!26P```````````````%-;5%M56P```````%9;````````
M````````5UM86P````!96UI;``!;6P````!<6P````!=6UY;7UL`````````
M````8%MA6P``8EL```````!C6P``9%L``````````&5;``!F6P``````````
M9UL``&A;``!I6P````!J6P````!K6VQ;;5L``````````&Y;``!P6W%;<EL`
M``````!S6V];=%MU6W9;``!W6WA;`````````````````````'E;````````
M``!Z6WM;``!\6P``?5L`````?EL``````````"%<```B7```````````(UP`
M`"1<```E7``````F7"=<*%PI7``````J7``````K7````````"Q<+5P``"Y<
M```O7```,%P`````,5PR7````````#-<```````````T7```````````````
M````-5P``````````````````#9<```W7```````````.%P`````````````
M````````````````````````?5<``````````````````'Y7```````````A
M6```(E@C6```)%@``"58```F6````````````````"=8```````````H6```
M*5@J6``````K6"Q8```M6"Y8+U@`````````````````````,%@Q6```,E@`
M````,UA,6```````````````````````````````````````````-%@U6#98
M````````````````-U@``#A8`````````````#E8.E@[6``````\6```````
M```````````````]6```````````````````````````/U@``$!8````````
M`````````````````````$%8``!"6$-8`````$18``````````!%6```````
M````1E@```````!'6```````````2%@``$E8````````2E@```````!+6```
M`````````````&15````````954``&95````````````````9U4```````!H
M50```````&E5`````````````````````````````&I5````````````````
M:U4`````````````;%4``````````````````````````````````&U5``!N
M50``````````````````;U5P50```````'%5````````````````````````
M````````<E5S50````````````````````````````````````!T50``````
M````=54``'95`````'=5``!X57E5``!Z57M5``````````````````!\50``
M`````````````````````````````'U5?E4``"%6```B5B-6`````"16````
M`"56)E8````````G5@``````````*%8``````````````````"E6````````
M```````````````````J5BM6+%8````````M5@``+E8``"]6````````,%8`
M````,58``````````#)6````````,U8``````````#16```````````U5@``
M-E8`````````````````````-U8``#A6`````#E6```Z5@`````````````[
M5@``````````/%8`````````````````````/58^5@`````````````_5D!6
M058```````!"5@``0U8``````````````````$16````````````````````
M````158`````1U9(5DE6``````````!*5@````!+5@``1E8`````````````
M3%8``$U6`````$Y6`````$]6````````4%8`````````````````````````
M````458```````!25@``4U8```````````````!45@``````````````````
M5E8``%=6``````````!85E56`````%E66E8`````````````6U8``%Q6````
M````758``%Y67U8`````8%8`````858```````````````!B5F-6````````
M9%9E5F96`````&=6:%8``&E6:E8```````!K5@``;%9M5@````!N5@``````
M``````````````````````!O5@```````'!6<58``````````')6<U8`````
M=%8```````!U5G96`````````````'=6````````````````````````>%8`
M`'E6`````````````'I6`````````````````````'M6?%9]5GY6````````
M```A5P`````B5R-7```D5P``````````)5<`````````````)E<````````G
M5P`````H5P```````"E7`````````````"I7````````````````*U<`````
M```````````L5P``+5<``"Y7+U<P5P``,5<R5P`````S5P``-%<U5P``````
M`#97`````#=7`````#A7```Y5P``.E<``#M7/%<``````````#U7/E<``#]7
M0%<`````05="5T-71%<```````!%5P``1E<``$=7``!(5P````!)5P````!*
M5P``2U<``$Q735<```````````````!.5P```````````````````````$]7
M``````````!05P``````````45<`````````````4E<``%-7``!45P``````
M`%57``!65P````!75P``6%<```````````````!95UI7`````````````%M7
M7%<``%U77E<`````````````7U=@5P``85=B5P``````````````````````
M`````````````````&17``!E5V979U<``&A7:5<`````````````````````
M``!J5VM7;%<``&U7`````&Y7````````;U<`````<%<``'%7<E<`````````
M`'-7=%=U5P````!V5P````````````!W5WA7`````'E7```^6&-7>E=[5WQ7
M`````````````````````&Q4:U1M5&Y4;U0```````!P5'%4`````')4````
M``````````````!S5`````!T5'54``````````````````!V5'=4>%0`````
M``!Y5```>E1[5'Q4?50```````````````!^5````````"%5````````````
M`````````````````")5(U4D5255```````````````````````````F50``
M)U4``"A5*54J50``````````*U4L50``````````+54``````````"Y5+U4`
M```````P50```````#%5`````#)5````````````````,U4`````````````
M`````#15`````#55-E4`````-U4``````````#A5`````````````#E5.E4`
M````````````````````````````.U4````````\50```````#U5```^50``
M```_50```````$!5``!!54)5`````$-5``````````````````!$50````!%
M54951U4``````````````````$A5254``$I5`````$M53%5-50``3E4``$]5
M4%4``%%5````````````````4E535515554```````!650``5U4`````````
M````6%4``%E5``!:50```````%M57%4``%U5``!>55]5``!@50``854``&)5
M````````8U4````````````````\2@`````````````]2@``/DH`````````
M```````_2D!*04H```````````````````````!"2@```````$-*`````$1*
M`````$5*``!&2@``````````1TH```````````````!(2@```````$E*````
M``````!*2@```````$M*3$H``````````````````$U*3DI/2@``4$H`````
M````````````````44I22E-*`````%1*``!52E9*````````5TH``%A*``!9
M2@``6DH`````6TH``````````%Q*`````%U*`````%Y*7TH``&!*````````
M`````&%*8DH`````8TID2@````!E2@``````````9DH``````````&=*````
M````:$II2@``````````:DH``````````````````&M*````````````````
M````````````````;$H``````````&U*;DH`````;TH`````<$H`````````
M``````````````!Q2@````!R2@````````````!S2@``=$H`````=4H`````
M````````````````=DIW2@``>$H```````````````!Y2@````````````!Z
M2@``````````````````````````````````>TI\2@````````````!]2GY*
M`````"%+````````(DL``"-+)$L``"5+````````)DL``"=+```````````H
M2RE+```````````J2RM+```````````L2P```````"U+```N2P`````O2S!+
M````````,4L``````````#)+,TL`````-$L``````````#5+-DL``#=+````
M`````````#A+````````````````````````.4L`````.DL``#M+````````
M/$L``#U+```````````^2S]+0$M!2P````````````!"2T-+``!$2P``14M&
M2P``1TM(2P``24L`````````````2DL``$M+`````$Q+````````34M.2P``
M3TL``%!+44L``````````````````%)+``!32P````!42P``54L``%9+5TL`
M``````!82P``64M:2UM+``!<2P````!=2UY+````````7TM@2P``84L`````
M`````````````&)+``!C2P``9$L`````94MF2P``9TL`````````````:$MI
M2P````!J2P``:TML2P````!M2P````!N2V]+`````'!+`````'%+````````
M<DL```````!S2P``=$L`````=4MV2P``=TL`````````````````````````
M`'A+>4L``'I+``![2WQ+?4L``'Y+```A3"),(TP`````)$P`````)4P`````
M)DP````````````````G3``````````````````````H3"E,````````````
M`````````"I,```K3```+$PM3"Y,+TPP3#%,,DPS3#1,-4P`````````````
M`````#9,````````````````-TP`````.$PY3```.DP[3````````#Q,```]
M3````````#Y,/TP``````````$!,`````````````$%,``````````!"3```
M`````$-,1$Q%3`````!&3```1TQ(3`````!)3$I,````````````````````
M``````````````!+3$Q,````````34Q.3$],``!03`````````````!13%),
M4TQ43`````````````!53%9,5TP``%A,`````%E,6DQ;3```7$P`````74P`
M`%Y,7TQ@3&%,`````&),8TP``&1,94P`````9DP```````!G3```:$P`````
M``!I3`````````````````````!J3&M,`````&Q,````````;4P`````;DP`
M`````````&],``!P3'%,`````'),<TP``````````'1,````````=4P``'9,
M=TP```````!X3```````````>4P`````````````>DQ[3'Q,`````'U,````
M````````````?DP`````````````````````````````(4T````````B32--
M`````````````````````"1-)4T`````)DT`````)TT``"A-*4T`````````
M`"I-````````````````*TT`````+$T````````M32Y-+TTP30`````Q30``
M`````#)-,TT`````````````-$T``#5-```V30``````````-TT`````````
M```````X33E-```Z30``````````````````````````````````.TT``#Q-
M```````````````````]33Y-/TU`34%-0DT`````0TT```````!$30``````
M````````````````````14T``$9-1TT``$A-````````24T`````2DT`````
M````````2TT``$Q-````````````````````````````````````````34T`
M````````````3DT``````````$]-4$U130````!230``4TT`````````````
M5$T``%5-5DT``````````````````%=-``````````!830````!935I-6TT`
M````7$T`````74T``````````%Y-``!?36!-``!A30``````````````````
M8DT```````````````!C30``9$UE369-`````&=-:$T``&E-``!J30````!K
M30````!L36U-``!N36]-`````'!-``!Q37)-<TUT30``````````=4T``'9-
M=TT`````>$T```````!Y30``````````>DU[30``?$T`````?4U^32%.```B
M3@```````"1.)4X``"9.)TXH3@```````"E.(TXJ3@``````````````````
M`````"M.````````+$X`````````````+4X``````````"Y.+TX`````````
M`````````#!.,4XR3@``,TX`````-$X`````````````````````````````
M```U3@```````#9.````````````````-TXX3@``````````````````.4X`
M````````````.DX[3CQ.```]3CY.```_3D!.04Y"3D-.1$Y%3@``1DX`````
M1TX```````````````````````````````````````!(3@```````$E.````
M````2DX```````!+3@``3$Y-3@``3DX`````````````3TX``````````%!.
M````````````````44X`````````````4DX``%-.````````5$X```````!5
M3E9.``````````!73@````!83@````!93@```````%I.`````````````%M.
M````````7$X```````!=3@```````%Y.``!?3F!.``!A3@``8DYC3@``9$X`
M````````````94X`````````````9DX``````````&=.:$YI3@``````````
M:DYK3FQ.`````&U.````````;DYO3@```````'!.`````'%.<DX```````!S
M3@````!T3G5.=DX`````=TX```````!X3GE.``````````!Z3@``>TY\3GU.
M``!^3@``(4\`````(D\`````(T\``"1/````````)4\``"9/)T\H3P``````
M```````I3P`````J3P`````K3P```````"Q/```````````````````M3RY/
M````````````````+T\P3S%/````````,D\``````````#-/`````#1/````
M```````U3P`````V3P```````#=/.$\``#E/````````.D\`````````````
M````````.T\``````````#Q/`````````````#U/```````````````````^
M3S]/`````$!/````````04\``````````$)/0T]$3P```````$5/``!&3P``
M`````$=/``!(3P```````$E/2D\`````2T\```````!,3P````!-3P``````
M`````````````````$Y/3T\`````4$\```````!13U)/`````%-/````````
M`````````````````````%1/````````54]63U=/````````````````````
M````6$]93P``6D\``````````%M/``!<3P``````````````````````````
M``!=3UY/`````%]/8$\```````!A3P``8D\```````!C3P``````````````
M`````````&1/``!E3P``9D]G3P``:$]I3P```````&I/``!K3P```````&Q/
M`````````````````````````````&U/````````;D\`````````````````
M````````````;T\``````````'!/``````````!Q3P```````')/````````
M``!T3W5/=D\``'-/`````'=/````````>$\```````!Y3WI/`````'M/?$]]
M3WY/```````````````````A4```(E```"-0```````````````````D4"50
M)E``````)U```"A0````````*5`J4```*U`L4```````````+E`````````O
M4#!0,5``````+5```#)0````````,U```````````````````#10-5``````
M-U`X4``````Y4#I0````````.U`V4``````````````\4``````````````]
M4````````#Y0````````````````````````/U```$!0``!!4$)00U``````
M`````$10``!%4```1E````````!'4````````$A0`````$E02E``````````
M````2U```$Q0``!-4```````````3E!/4%!0````````45!24````````%-0
M``!44`````!54````````%90`````%=06%``````````````````````````
M`%E0``!:4```6U````````````````!<4````````````````%U0``!>4%]0
M``!@4````````````````````````````````&%08E```````````&-0``!D
M4&509E!G4```:%``````:5!J4```````````:U````````````````!L4&U0
M``!N4````````&]0``!P4`````!Q4````````')0`````'-0````````````
M````=%```'50`````'90=U```'A0``````````!Y4```````````>E```'M0
M````````?%``````?5!^4```(5$``")1`````"-1```````````D4251```F
M40```````"=1````````````````*%$````````I40`````````````J42M1
M````````+%$``"U1+E$``"]1```````````P40```````#%1````````````
M`#)1`````#-1`````#11`````````````#51````````-E$``#=1```X43E1
M````````.E$[40`````\43U1/E$````````````````````````_44!1``!!
M44)1````````0U$`````````````````````1%%%40````!&40````!'44A1
M``!)44I1``````````!+40``3%$`````35$`````3E$`````````````````
M`$]1`````%!1`````````````%%1``!240``4U$`````5%%540```````%91
M5U$``````````%A165$`````6E$```````````````````````!;40``7%$`
M````75$`````````````````````7E$```````````````!?40``8%$`````
M``!A40``8E%C40```````````````````````&11`````&51`````&91``!G
M40````!H40```````````````````````&E1````````````````````````
M````````:E%K40``;%%M40``````````;E$`````;U$```````````````!P
M40``<5%R40````````````````````!S40``````````````````````````
M`````'11``````````````````````````!U40```````'91````````=U$`
M`'A1>5%Z40``>U%\47U1?E$A4@`````B4@`````````````````````C4@``
M)%(E4B92`````````````"=2````````````````*%(````````````````I
M4@``````````````````````````*E(````````K4@``+%(`````+5(N4@``
M```O4@``,%(`````,5(R4@```````#-2````````````````````````````
M````-%(``````````#52```````````V4@``-U(X4@``````````.5(`````
M`````#I2`````#M2```\4@``````````/5(````````````````^4@`````_
M4D!2``!!4@````!"4D-2````````1%)%4D921U(``````````$A2`````$E2
M`````$I2``!+4@```````````````````````$Q2``!-4DY2``!/4E!245(`
M``````````````````````````````!24@``4U(``````````````````%12
M``!54E92`````%=26%)94@``6E(``%M2`````%Q275)>4E]2``!@4@````!A
M4@``8E)C4@``9%)E4@```````````````````````&92``!G4@``````````
M:%(``````````&E2:E(``&M2````````;%(``````````&U2``!N4F]2``!P
M4@````!Q4G)2`````````````````````````````'-2````````=%(`````
M``````````!V4G=2>%(``'52````````>5)Z4GM2?%)]4GY2`````"%3```B
M4P```````"-3```D4P```````"53)E,``"=3```H4P```````````````"E3
M`````"I3*U,`````````````````````+%,M4P``````````````````+E,`
M`````````"]3````````````````````````,%,``#%3`````````````#)3
M````````````````````````,U,`````````````-%,U4P`````V4S=3.%,`
M````.5,``````````#I3`````#M3/%,]4P```````#Y3```_4P```````$!3
M05-"4P``0U,``$1315,`````1E,`````````````````````1U,`````2%,`
M`$E3````````````````````````2E,`````````````````````````````
M`````$M3````````3%--4TY3`````````````$]3``!04U%34E,`````4U,`
M``````````````!44U53``````````!64P````!74P```````%A3`````%E3
M````````6E,``````````````````````````%M37%-=4P``7E-?4P``````
M``````!@4V%3``````````!B4P```````&-3``!D4P```````&53``!F4V=3
M``!H4VE3``````````````````!J4P``:U,`````;%,`````````````;5,`
M`````````````````&Y3``!O4W!3````````<5,``')3<U-T4P``=5-V4P``
M=U,`````>%-Y4WI3````````>U,``````````'Q3?5,`````````````?E,A
M5```````````````````(E0C5``````D5``````````````````````E5```
M```F5"=4```H5``````````````````````I5"I4*U0L5"U4````````````
M`"Y4+U0P5``````````````````````Q5```,E0`````````````````````
M-%0`````-50V5````````#=4.%0``#E4````````.E0````````[5#Q4````
M`#U4/E0`````````````,U0``````````````````#]4````````````````
M``!`5$%4````````0E0``$-4``````````!$5$54`````$94````````````
M````1U1(5````````$E42E0``$M4````````3%0`````350`````````````
M````````3E0``````````$]44%0``%%4````````````````4E0``%-4``!4
M5`````````````!55````````````````%94``!75%A4`````%E4````````
M`````%I4`````%M47%0```````!=5```````````7E0`````````````7U0`
M````8%0``````````&%48E0`````8U0`````9%0```````!E5````````&94
M`````&=4``!H5`````!I5&I4````````````````````````84D`````````
M````````````8DEC261)94EF20```````&=):$D`````:4D`````````````
M````````````````````````:DD``&M)``````````````````````````!L
M20``;4D``&Y);TEP20```````````````'%)`````````````````````'))
M````````<TET275)`````'9)=TD``````````'A)``!Y20``````````>DD`
M````>TD``'Q)``!]20``?DD``````````````````"%*````````````````
M```````````````````````````B2@```````````````"-*```````````D
M2@``)4H``````````"9*`````````````"=*```````````````````H2BE*
M```````````J2@``*TH````````````````````````````````L2BU*```N
M2B]*````````````````,$H``````````#%*,DHS2@`````T2@``````````
M`````#5*-DH````````````````W2@`````X2@`````Y2CI*```[2@``````
M````````````````````````````.T@``#Q(/4@`````````````````````
M`````#Y(```_2```0$@```````````````!!2````````$)(``!#2```1$A%
M2`````````````````````!&2```1T@``$A(24@`````````````````````
M`````$I(`````$M(3$@`````4T@``$U(3D@`````3T@`````4$@`````````
M`%%(4D@```````````````````````````````````````````````!42```
M54A62%=(````````6$@``%E(6D@`````6TA<2`````!=2%Y(````````````
M`%](````````8$@``````````````````````````````````````````&%(
M8D@``````````&-(````````9$AE2`````!F2&=(:$@`````:4@``&I(:TAL
M2```;4@```````!N2```````````;TAP2```````````<4AR2'-(=$@`````
M````````=4AV2'=(``````````!X2'E(`````````````'I(````````````
M`````````'M(``!\2'U(``!^2```````````````````````````````````
M`````"%)````````(DD````````````````````````C221)````````````
M````)4D``````````"9)````````)TD`````*$DI20`````J20``````````
M*TDL22U)`````````````"Y)````````````````````````+TD`````````
M````````````,$D`````,4D`````````````````````````````,DD`````
M`````#-)`````#1)```U20`````V20```````````````#=).$D````````Y
M23I).TD\20````!!20`````````````]23Y)```````````````````_24!)
M`````````````$))0TD```````````````!$20``14D```````````````!&
M24=)``````````````````!(20````!)20```````$I)2TD`````````````
M`````````````````````$Q)34E.24])4$D`````44D`````````````````
M````4DD```````````````!320``````````5$E520````!620````!720``
M`````````````````````````````````````````````%A)````````````
M````64D``%I)6TE<25U)``!>20```````%])``````````````````!@20``
M`````````````&E'````````:D<``````````&M'````````````````````
M``````!L1P```````&U'`````&Y'``!O1W!'``````````````````!Q1W)'
M`````'-'=$<``'5'````````=D<``'='>$=Y1WI'`````'M'``````````!\
M1WU'?D<````````A2")(```````````C2```````````````````````````
M)$@``````````````````"5(```F2```````````````````````````````
M`````````"=(`````````````"A(`````````````"E(````````````````
M*D@````````````````K2``````````````L2"U(`````"Y(```O2```````
M````````````,$@````````Q2#)(,T@``#1(````````-4@V2```-T@`````
M.$@Y2#I(`````````````````````````````````````#U'````````````
M````/D<_1P``0$<```````!!1P``0D<``````````````````$-'1$<`````
M````````````````````````14<`````````````1D<``````````$='````
M````````````````````2$=)1P``2D<``$M'3$=-1P``````````````````
M``````````````````````````!.1P``3T<``````````````````%!'````
M`%%'``!21P```````%-'``!41P``````````54<```````!61P``5T<`````
M``!81UE'````````````````6D<``````````%M'``!<1P``74=>1P``7T<`
M````8$<```````!A1P````````````!B1V-'````````9$<``&5'````````
M`````&9'````````9T<```````!H1P`````]1```/D0``#]$`````$!$````
M`$%$````````````````0D0`````0T0```````!$1```````````140`````
M````````````````1D0```````!'1```````````````````2$1)1$I$2T0`
M`$Q$340`````3D0```````!/1%!$440``````````````````%)$4T0`````
M``!41%5$````````````````````````````````5D0``````````%=$````
M````6$0``%E$`````````````````````%I$````````6T1<1```740`````
M7D0``%]$``!@1```````````````````841B1```8T0``&1$````````````
M`````````&5$`````&9$`````````````````````&=$``````````!H1&E$
M``````````````````````````!J1`````!K1`````````````````````!L
M1&U$``!N1```;T0``'!$`````````````````````'%$``!R1'-$``!T1```
M``````````````````````````!U1```=D0```````!W1```````````>$0`
M````>40`````>D0```````![1````````'Q$``````````````````!]1```
M?D0``"%%`````")%````````(T4`````)$4E10`````````````F12=%````
M`"A%*44````````J10``*T4L12U%`````"Y%+T4``````````#!%````````
M`````````````#%%`````#)%`````#-%````````````````-$4``#5%````
M```````````````````````V10`````W10``.$4`````.44Z10``.T4``#Q%
M`````````````#U%````````````````````````/D4``#]%0$5!10``````
M``````!"10````````````!#10```````$1%145&10````!'10``````````
M``````````!(14E%2D4```````````````!+10``345,10````!.10``````
M`$]%````````4$5115)%`````````````%-%5$4```````````````!510``
M``!610``````````5T4```````!815E%6D4```````````````````````!;
M15Q%``````````!=15Y%`````%]%8$4``&%%`````````````&)%8T5D10``
M``````````!E10```````&9%`````&=%`````````````&A%````````:44`
M````:D5K10````!L10````````````!M16Y%``````````!O10```````'!%
M````````````````<44```````!R10````!S10``````````=$4```````!U
M10``=D4``````````'=%`````'A%````````````````>44```````!Z10``
M``![10``?$4``````````'U%``````````````````!^12%&````````(D8`
M````(T8`````````````````````````````````````````````)$8`````
M```E1@```````"9&)T8``"A&*48``````````"I&*T8`````+$8M1BY&```O
M1@``````````````````,$8Q1@```````#)&,T8``````````#1&-48`````
M`````#9&`````#=&````````````````````````.$8````````Y1@``````
M`````````#I&```[1@`````\1CU&````````````````/D8`````/T8`````
M````````0$8``$%&`````````````$)&`````$-&``!$1D5&````````1D8`
M``````!'1DA&``!)1@``2D8```````````````!+1@````````````!,1@``
M`````````````$U&3D9/1@```````%!&``!11@``````````4D8``%-&5$8`
M``````!51E9&````````5T8``````````````````````````%A&648``%I&
M``!;1@````!<1@``748``````````%Y&``!?1F!&````````````````````
M```````V1P```````&%&``!B1@``8T8``````````&1&``!E1@``9D9G1@``
M:$8```````````````````````!I1FI&:T8``&Q&````````````````````
M``````!M1FY&``!O1G!&````````<48`````<D8`````````````````````
M`````````````````````'-&``!T1@``=48`````````````````````````
M`````````'9&````````=T8```````````````!X1@``>49Z1GM&?$8``'U&
M``!^1@```````"%'```B1P```````"-'````````````````)$<``"5'```F
M1R='```H1P```````"E'```J1P``````````````````````````````````
M`````"M'`````"Q'`````"U'````````+D<O1P``,$<``#%'````````````
M````,D<`````````````````````````````,T<T1S5'`````````````#='
M.$<``#E'```````````````````Z1P`````[1P`````\1P``2D,`````````
M`$M#````````3$,``$U#``````````````````!/0TY#````````4$-10P``
M4D-30U1#``!50P``````````````````5D,```````!70P``````````6$-9
M0P``````````6D,``%M#`````````````$E#`````%Q#``!=0UY#`````%]#
M````````````````````````````````````````8$,`````84-B0V-#9$-E
M0P````!F0P```````&=#:$-I0VI#`````````````&M#``!L0P``;4,``&Y#
M``````````````````````````````````!O0P``<$,``'%#``!R0P``````
M````<T,``'1#``!U0P```````'9#=T,```````!X0P```````'E#````````
M`````````````'I#````````````````````````>T,`````?$,```````!]
M0P````!^0R%$(D0``"-$`````"1$`````"5$`````"9$)T0`````````````
M`````"A$`````"E$```J1"M$+$0M1``````N1"]$````````,$0Q1```````
M````,D0S1#1$`````````````````````#5$`````#9$-T0`````````````
M.$0Y1```.D0`````.T0\1````````````````````````````````#%#,D,S
M0P`````T0P`````````````U0S9#-T,`````.4,``#I#.T,``#Q#`````#U#
M/D,`````````````````````/T,``````````$!#``!!0P````!"0P``````
M````0T,``````````$1#````````````````````````14,``$9#````````
M1T-(0P``.$,```````````````!)/P``2C\`````````````````````````
M`$L_`````$P_33\`````3C\```````!//U`_``````````!1/P``````````
M`````````````%(_````````````````4S]4/P```````%4_````````````
M````````````````````````````5C\``````````````````%<_``!8/P``
M````````````````63]:/P````````````!;/UP_`````````````%T_7C\`
M`%\_`````&`_`````&$_`````&(_``!C/P``````````````````````````
M````````````````9#]E/P````!F/P``````````````````9S]H/P````!I
M/P````!J/P``````````:S]L/VT_;C\``&\_````````<#]Q/P````!R/P``
M`````',_=#]U/P```````'8_`````'<_````````````````````````>#]Y
M/P````````````!Z/WL_````````?#\`````?3]^/P`````A0````````")`
M(T```"1``````"5````F0``````G0``````H0``````````````I0```````
M`"I`*T`````````L0"U`````````+D``````````````+T```#!`````````
M````````,4`R0#-````````````````````````````````````T0```````
M`#5`````````-D``````-T``````````````.$``````.4```#I`.T`\0```
M`````````````#U`````````/D```````````#]```````````!`0```04``
M````````````0D!#0```1$``````14!&0```````````````````````````
M`````````````$=`2$``````````````24```$I```!+0````````$Q`````
M`````````$U```!.0```3T```%!`44````````!20%-```````````!40%5`
M``````````!60```````````````````5T```%A`````````````````````
M`````````%E`````````6D```%M`7$!=0%Y``````````````%]`8$!A0&)`
M``!C0&1`94```&9`````````````````````````9T``````````````:$!I
M0````````````````&I```!K0```````````````````;$```&U`````````
M``````````!N0&]`<$````````````````!Q0')```!S0```=$```'5```!V
M0```=T``````>$```'E`````````>D````````````````![0```````````
M`````````````'Q`?4!^0```````````(4$``````````")!(T$D025!```F
M00``)T$H00```````"E!```J00```````````````````````````````"M!
M+$$````````M02Y!`````"]!`````#!!```````````Q00``,D$````````S
M00```````#1!```U00`````V00```````#=!.$$Y00``````````.D$`````
M```[03Q!```]00`````^00``/T$`````0$%!00````!"00```````$-!````
M`$1!``````````!%00````!&00````````````````````!'00``2$%)00``
M``````````!*00```````$M!``!,00```````````````$U!``!.00``3T$`
M`````````````````````````%!!44$```````````````!200```````%-!
M`````````````````````````````````````%1!`````%5!````````5D$`
M``````!700``````````6$$``````````````````%E!`````%I!`````%M!
M``````````!<00````!=00````!>00````!?00``````````````````8$$`
M``````!A06)!8T$``````````````````````````&1!`````&5!````````
M`````&9!9T$``````````&A!``!I00```````&I!``!K00``;$$`````````
M``````!M00``````````````````````````````````````````;D$``&]!
M``!P07%!````````<D$``````````'-!=$%U00```````'9!````````=T%X
M00```````'E!````````>D%[00````!\07U!````````````````?D$A0@``
M```B0B-")$(E0@``)D(`````)T(H0BE"*D(``"M"```L0BU"```N0@``````
M`#!"```O0@```````````````#%"```````````R0C-"````````-$(``#5"
M```W0@`````V0@`````````````X0CE".D(``#M"/$(````````]0CY"````
M`````````````````$!"04)"0@```````````````$1"``!%0@``1T)(0DE"
M``!*0DQ"``!#0D9"2T(``````````````````````````$U"3D)/0@````!0
M0@``44(```````````````!20E-"5$)50@````!60E="````````6$(`````
M````````````````64(```````!:0EM"`````%Q"`````````````%U"````
M````7D)?0@``8$)A0@``````````8D(```````!C0@``9$)E0@``````````
M9D(```````````````!G0@```````&A"`````````````````````&E"````
M`&I":T(``&Q"`````````````````````````````&U"/T(`````````````
M``````````!N0@``;T(```````````````!P0@``````````<4(`````````
M````<D(`````<T(```````!T0@``=4(`````````````````````````````
M`````````````'9"``````````````````````````!W0@``````````````
M`'A"``!Y0GI"````````>T(``````````````````'Q"?4(`````````````
M`````'Y"`````````````````````"%#`````````````")#```C0P``````
M```````D0P``)4,``````````"9#`````````````"=#`````"A#````````
M````````````````*4,J0P``*T,``"Q#`````"U#```N0R]#```P0P``````
M````````````````````4SX``%0^`````````````````````````````%4^
M`````````````%8^`````````````%<^`````%@^63X`````6CY;/EP^``!=
M/EX^````````````````7SX``&`^``````````!A/F(^````````8SYD/@``
M`````&4^9CX``&<^:#X``````````&D^`````&H^``!K/@````!L/@``````
M````````````````````;3YN/@````!O/@```````'`^<3YR/@``````````
M``````````````````!S/G0^`````````````'4^````````````````=CYW
M/G@^>3X``'H^>SX`````?CX``'P^``!]/@`````A/R(_```C/P``````````
M```````````````````````````````````D/P``)3\F/P`````G/P``````
M```````````````````````H/P``*3\````````````````J/P```````"L_
M```L/RT_````````+C\``"\_```P/P``````````````````````````````
M````,3\````````R/P``````````,S\T/S4_```V/P`````````````W/P``
M`````#@_.3\Z/P``.S\``#P_````````/3\``#X_```````````````````_
M/P````````````````````!`/P``03\```````!"/P```````````````$,_
M`````$0_````````````````````````````````````````13]&/T<_2#\`
M`````````````````````````````````%P\````````73Q>/%\\````````
M`````&`\``````````````````````````!A/`````!B/&,\````````9#QE
M/&8\9SP```````!H/`````!I/&H\``!K/```;#P```````!M/```;CP`````
M`````&\\``!P/```<3QR/````````',\=#P``'4\`````````````'8\````
M`'<\````````>#P```````!Y/`````!Z/```````````>SP`````?#Q]/```
M``!^/```````````````````(3T`````(CT``",])#T`````)3T``"8]````
M`"<]*#T``````````````````````````"D]````````*CT``"L]````````
M````````+#T`````````````+3TN/0``````````+ST``#(]`````#`]````
M````,3TS/0`````T/34]-CT````````````````W/0``````````````````
M```````````X/0`````Y/3H].ST``#P]```````````]/3X]/SU`/4$]````
M````````````````````0CT`````0SU$/0````````````!%/48]1ST``$@]
M23U*/4L]`````$P]33T`````3CT```````!//0``4#T`````````````````
M`````````%$]`````%(]`````%,]`````````````%0]53T`````5CU7/0``
M6#T``````````%D]``````````!:/0````````````````````!;/0``````
M``````!</0``73T``````````````````````````%X]````````````````
M7SU@/6$]`````&(]``````````!C/0````!D/0``93UF/0````````````!G
M/0```````&@]`````````````&D]````````````````````````:CT`````
M``````````````````````````!K/6P]`````&T]````````;CT``&\]``!P
M/0```````'$]`````'(]``!S/0``=#T`````=3T``````````'8]=ST`````
M``!X/0``>3UZ/0````![/0``````````````````?#U]/0````````````!^
M/0```````"$^`````"(^````````(SX``"0^````````)3XF/B<^*#X`````
M*3XJ/@``````````*SXL/@```````"T^```N/@``+SXP/@```````#$^````
M`#(^````````````````````````````````,SX`````-#X`````-3X`````
M```V/C<^```````````X/@``````````.3X`````.CX``#L^````````/#X]
M/CX^/SY`/@``03Y"/@``0SX`````1#X``$4^````````1CX`````````````
M`````$<^2#X``````````$D^2CX```````!+/DP^33X``$X^````````````
M``````!//@```````%`^43X`````4CX`````````````````````=SIX.@``
M>3H`````````````>CI[.@```````'PZ?3I^.@```````"$[`````"([````
M````(SLD.P``````````)3LF.R<[*#L````````````````````````I.RH[
M```K.P``````````+#L`````+3L``````````````````````````"X[```O
M.S`[```Q.S([`````#,[````````-#L``````````````````#4[```V.S<[
M```````````X.P`````````````````````````````````````Y.P``.CL`
M```````````````[.P``````````/3L`````````````/#L`````````````
M`````````````````````````````#X[`````#\[0#L``$$[````````````
M````````````````````0CL``````````$,[````````````````1#L`````
M`````$4[``````````````````````````````````````````!'.T@[``!)
M.TH[````````1CL`````````````2SL`````3#L``````````$T[````````
M3CL``$\[`````%`[43L`````4CL``%,[``!7.P```````````````%4[````
M````5#L```````!6.P````````````!8.UD[6CM;.P``7#L`````````````
M73L`````7CL`````7SL`````````````````````8#MA.P```````&([8SL`
M`&0[``!E.P``````````9CL``&<[``````````````````!H.VD[:CMK.P``
M`````&P[``!M.P```````&X[;SL```````````````!P.P```````'$[````
M``````!R.P``=&8``',[````````=#MU.P```````````````````````'8[
M````````=SL```````!X.P````!Z.P``>3L``````````````````'L[?#L`
M``````````````!].P```````'X[```````````A/```````````````````
M```````````````````B/",\````````````````)#P````````````````E
M/``````````````F/```````````)SP``"@\*3P`````*CP`````````````
M```K/"P\```````````````````N/``````````````M/````````"\\````
M`#`\`````````````````````#$\```````````````````````````T/```
M,CP``````````#,\-3P``````````#8\```W/``````X/#D\```Z/```````
M`````````````````#L\```\/#T\/CP_/$`\``!!/```````````````````
M`````````````````````$(\``````````````````````````!#/`````!$
M/```````````````````````````````````````````````````13P``$8\
M1SP`````2#P``$D\``!*/```````````2SP``$P\````````````````````
M````33Q./$\\````````````````4#P``````````%(\43P``%,\`````%0\
M53P``%8\5SP```````````````!8/```63P```````````````!:/```````
M``````!;/```````````````````````````````````934``&8U9S4`````
M``!H-0``:34`````````````:C5K-0``;#5M-6XU;S4`````<#4`````````
M````````````````````<35R-0````````````````````!S-0``````````
M=#4```````````````````````````````!U-0``=C4``'<U`````'@U````
M`'DU``!Z-7LU``!\-0````!]-7XU(38````````B-B,V`````"0V`````"4V
M````````)C8````````````````G-@``````````````````````````````
M`"@V`````````````````````"DV`````````````"HV`````"LV```L-@``
M```M-BXV+S8P-C$V,C8````````````````S-@``````````````````````
M`````````````````````````#0V````````-38`````-C8``#<V```X-@``
M.38``#HV.S8\-@``/38^-C\V``!`-D$V``!"-@````!#-@``1#8``$4V``!&
M-@``````````1S8```````````````````````!(-@``239*-DLV3#8`````
M338`````3C8```````!/-@``4#8``%$V4C8`````4S8`````````````````
M````````````````````5#95-@````!6-@````!7-E@V````````````````
M`````%DV````````6C9;-@````!<-ETV7C8```````````````!?-F`V839B
M-@``8S9D-F4V````````9C8``&<V````````:#8```````````````!I-@``
M`````````````&HV````````:S9L-FTV<#9Q-@``;C9O-@``````````````
M``````!R-@````!S-G0V``!U-@``=C8`````=S9X-GDV>C9[-@````!]-@``
M?C8```````!\-@``````````(3<B-P```````````````````````",W)#<`
M`````````"4W`````"8W```G-P``````````*#<````````I-P``````````
M*C<K-P``+#<`````+3<``"XW+S<P-S$W````````,C<S-P``-#<``#4W-C<`
M```````W-S@W`````````````````````#DW.C<[-P`````````````\-STW
M`````````````#XW/S<``````````$`W````````````````````````````
M````````````03<`````0C<``$,W1#<`````13<``$8W1S=(-TDW2C<``$LW
M3#=--P``3C<``$\W4#=1-U(W``!3-P````!4-P``53<`````````````````
M````5C<``````````````````%<W8#<``%@W``!9-UHW``!;-UPW73=>-P``
M7S<`````````````83=B-V,W`````&0W````````````````````````````
M`&4W``````````!F-P```````````````````````&<W:#<```````!I-P``
M``!J-P````````````!K-P``````````````````;#=M-P````!^-P````!N
M-P``;S=P-P``<3<```````!R-P````!S-P``````````=#=U-P``=C<`````
M`````'<W>#=Y-P```````'HW>S<```````!\-WTW`````"$X(C@`````````
M`````````````````````````",X`````"0X)3@F.``````````````G."@X
M`````````````"DX```````````J.````````````````"LX````````````
M`"PX````````````````````````+3@`````+C@O.```,#@Q.```````````
M,C@````````````````````````S.```-#@`````-3@`````-C@W.```````
M`````````````````````````````````#@X````````.3@`````.C@[.#PX
M`````````````#TX/C@_.$`X``!!.$(X``!#.$0X````````13@``$8X````
M````````````1S@`````2#A).$HX````````2S@`````3#@`````````````
M`````$TX3C@```````````````````````!0.`````````````!1.```3S@`
M``````!2.```````````4SA4.```53@``%8X``!7.```6#@```````!9.```
M``!:.````````%LX7#@```````````````!=.```````````````````````
M`%XX`````````````````````````````````````````````%\X8#@`````
M`````&$X8C@`````````````8SAD.&4X`````````````````````&<X````
M````:#@``&DX:C@```````!K.````````````````&PX;3@`````;C@``&\X
M<#@`````````````````````<3@```````!R.`````!S.```````````````
M``````````````!T.'4X`````````````'8X``!W.```>#AY.'HX``![.```
M?#@``````````````````'TX``!^.```(3D`````(CD`````(SDD.0`````E
M.0``)CDG.0`````````````````````````````````````H.2DY```J.0``
M`````"LY`````"PY```M.0``````````````````+CD``````````"\Y````
M`#`Y`````````````#$Y,CDS.30Y`````#4Y````````-CD`````-SD``#@Y
M```````````Y.0``.CD[.0```````#PY```].0`````^.0``````````/SD`
M`````````````````````````$`Y03E".0```````$,Y1#D`````13D`````
M``````````!&.4<Y``!(.4DY``!*.0````!+.0````````````````````!,
M.0```````$TY``````````````````!..4\Y4#D```````!1.5(Y````````
M``````````````````!3.0``````````5#E5.0````!6.5<Y``!8.0````!9
M.0````!:.0``````````````````````````````````````````````````
M6SE<.0``73E>.0```````%\Y````````8#D``````````&$Y````````````
M`````````&(Y``````````!C.0``9#D``&4Y`````````````&8Y````````
M````````````````9SD`````:#EI.0````!J.0``````````````````````
M`````````&LY``````````!L.0````!M.0````!N.0````!O.0````!P.0``
M<3ER.7,Y``!T.0``````````=3D``````````'8Y``````````!W.7@Y>3D`
M`'HY`````'LY``!\.7TY````````?CD``````````"$Z```B.@``(SH`````
M```````````D.@``````````````````````````)3H``"8Z````````)SH`
M`````````"@Z```````````I.@```````"HZ````````````````*SHL.@``
M`````````````"TZ`````"XZ+SH````````````````P.@``````````````
M```````````````````````Q.@``,SH``#0Z```U.@```````#8Z````````
M-SH``````````````````#@Z````````````````,CH````````Y.@``````
M```````````````Z.@```````````````````````#LZ/#H`````````````
M/3H````````^.@``````````````````/SH```````````````````````!`
M.@````````````!!.D(Z````````````````````````````````0SI$.D4Z
M1CH``$<Z`````$@Z``!).@```````$HZ````````2SH``$PZ33H``$XZ3SH`
M`%`Z`````````````````````````````````````````````%$Z4CH`````
M4SI4.@``53H``%8Z5SH``````````%@Z`````%DZ``!:.@```````%LZ7#H`
M````````````````````````````73H``%XZ````````````````7SI@.F$Z
M8CIC.@````````````!D.@````````````````````````````````````!E
M.@``9CH`````9SH`````````````````````:#H`````````````````````
M````````````````:3H``````````````````````````&HZ````````````
M````:SIL.@```````&TZ`````&XZ`````&\Z``!P.G$Z``!R.@``<SH``'0Z
M`````'4Z=CH`````````````````````3C5/-0```````````````%`U````
M`%$U4C4``````````%,U5#55-0```````%8U`````````````%<U``!8-5DU
M`````%HU`````%LU7#4```````````````!=-0``7C5?-0````!@-0``835B
M-0````!C-0``9#4```````!O,@``````````<#)Q,@```````````````'(R
M`````',R````````````````````````=#(``````````'4R````````=C(`
M`'<R````````````````````````>#(``````````````````````````'DR
M``!Z,@``>S(``'PR?3(`````?C(`````````````(3,````````````````B
M,P``(S,D,R4S```F,P`````G,P`````````````H,P```````"DS`````"HS
M`````````````````````"LS````````+#,M,RXS`````"\S````````````
M````````````,#,Q,P`````R,P```````````````````````````````#,S
M-#,``#4S-C,``#<S````````````````````````.#,`````````````.3,`
M````````````````````.C,[,P`````\,P```````````````#TS````````
M`````````````#XS````````/S,`````````````````````````````0#,`
M`$$S0C,``$,S``!$,P````!%,T8S1S,``````````$@S````````````````
M``!),P````````````````````!*,TLS3#,```````````````!-,P``3C,`
M````3S,``````````%`S``!1,P```````````````%(S``!3,U0S53-6,P``
M5S,``%@S``````````````````!9,UHS6S-<,P``````````````````73->
M,P````````````!?,V`S83,``&(S8S,``&0S`````&4S````````9C,``&<S
M``!H,P```````&DS`````&HS``!K,P````!L,P``;3,``````````&XS;S,`
M`````````'`S````````<3,`````<C-S,W0S``!U,P```````'8S=S,`````
M>#,``'DS>C,`````````````````````>S,`````?#,```````````````!]
M,WXS(30``````````"(T```C-```````````)#0`````)30F-```)S0H-```
M```````````I-```*C0K-"PT```M-"XT+S0`````,#0``#$T`````#(T````
M````````````,S0T-#4T````````-C0`````````````````````.#0W-```
M`````````````````````````````#DT```Z-``````````````[-```/#0`
M`#TT````````````````/C0_-```````````0#0```````````````!!-```
M````````0C0``````````$,T````````1#1%-`````````````!&-```````
M````1S1(-```````````230```````!*-````````$LT`````$PT````````
M`````$TT3C0```````!/-`````!0-```4312-```4S14-```530`````5C0`
M````5S0``````````%@T````````````````````````630`````6C1;-```
M7#0``````````%TT`````%XT7S0``&`T`````````````&$T8C0`````````
M`````````````````````````&,T````````````````````````````````
M9#0``````````````````````````````````````````&4T````````````
M````9C0```````````````!G-`````````````!H-&DT``!J-```````````
M:S0``&PT`````&TT;C0``````````````````````````````````&\T<#0`
M````<30`````````````<C0``',T````````````````````````````````
M`````'0T````````=30``'8T``!W-'@T``!Y-```>C0``'LT?#0`````````
M````?30``````````````````````````'XT```A-0``(C4``",U`````"0U
M)34````````F-0```````"<U````````*#4I-0`````````````J-0`````K
M-0``+#4``````````"TU+C4``"\U,#4`````,34R-0`````S-0``````````
M```T-0``-34V-3<U````````.#4````````````````Y-0```````#HU````
M`#LU/#4`````````````````````````````````````````````/34`````
M```````````````````^-0``/S4`````0#4```````````````!!-0``````
M``````!"-0``0S5$-44U1C4```````!'-0````!(-4DU`````$HU2S5,-0``
M`````````````$TU`````````````````````%TP`````%XP``!@,```83``
M`&(P``!C,```9#``````93```&8P``!G,`````````````!H,&DP``!J,&LP
M`````````````&PP``!M,```;C```&\P````````````````<#!?,`````!Q
M,````````````````'(P``!S,```=#``````=3``````````````=C!W,'@P
M>3``````>C![,`````!\,'TP``!^,"$Q````````(C$C,0``)#$``"4Q```F
M,0``)S$H,2DQ`````"HQ```K,2PQ````````+3$N,0``````````````````
M`````````````````````````````"\Q```````````P,0``,3$``#(Q,S$T
M,34Q```V,3<Q````````.#$Y,0``.C$[,0``/#$],3XQ```_,0````!`,0``
M`````````````````````$$Q````````0C$``$,Q````````````````````
M``````````````!$,0``13$```````````````````````!&,4<Q``!(,4DQ
M2C$`````2S$`````3#$`````33$``$XQ``!/,0``4#$`````43$```````!2
M,5,Q`````%0Q53%6,5<Q````````6#$``````````%DQ````````````````
M6C$``%LQ``!<,5TQ``!>,0````````````!V,0``````````7S%@,6$Q````
M`&(Q8S$```````!D,0``93$``&8Q`````&<Q:#%I,0```````&HQ``!K,0``
M``````````!L,6TQ``!N,6\Q`````'`Q<3$`````<C$`````<S$`````=#%U
M,0```````````````````````````````````````'<Q``!X,7DQ``!Z,0``
M`````'LQ````````?#%],7XQ```A,B(R(S(``"0R```````````E,B8R```G
M,B@R*3(J,BLR```````````````````L,@``````````+3(N,@``````````
M```````````O,C`R`````#$R`````#(R`````#,R-#(`````-3(`````````
M`#8R```W,@``.#(`````.3(Z,@```````#LR````````/#(],@``/C(`````
M/S(``$`R``!!,@``0C)#,@````````````!$,@``13)1,@```````$8R````
M````1S(```````!(,@``````````23(`````2C)+,DPR`````$TR3C)/,E`R
M``!2,@```````````````%,R``!4,@``53)6,E<R6#(``````````%DR````
M````6C);,@```````%PR73(``%XR``!?,@``8#)A,F(R`````&,R9#(`````
M````````````````93(``````````````````&8R``````````!G,@``````
M`&@R``!I,@``:C)K,@```````````````&PR``````````!M,@``;C(`````
M`````````````"$P```B,",P````````````````)#``````````````)3``
M```````````````````````````````F,````````"<P*#`````````I,```
M```J,``````K,"PP+3```````````"XP```````````````````````````O
M,#`P`````#$P`````#(P````````````````````````,S``````````````
M````````-#```#4P````````````````-C```````````#<P.#``````````
M`````````````````#DP.C`````````[,``````````````\,```````````
M````````````````````````/3``````````````````````/C`_,```````
M``````!`,`````````````````````````````````````````````!!,```
M`````````````````````$(P````````````````````````0S``````````
M``````````````````````!$,````````````````````````$4P1C``````
M`````$<P2#!),`````````````!*,````````````````$LP``!,,```33``
M`$XP``````````````````!/,%`P43!2,```4S!4,```````````53``````
M5C!7,`````````````!8,`````!9,%HP6S```%PP<2(`````````````````
M````````````;R)R)W,G="=U)W8G=R=X)WDG>B=[)WPG``!])WXG0B=#)T0G
M12=&)T<G2"=))THG2R=,)P``32=.)P``````````````````````````````
M`````````&4F:B9Q)G(F<R9T)GLF````````````````````````````````
M`````````````'@F``````````````````!U)GHF=R9Y)GPF."(Y(F$F``!B
M)F,F9"8``&<F``!I)FPF=B8`````````````````````````````````````
M,"(``````````````````````````````````````````"\B,B(V(C4B```S
M(CDK`````````````````````"8J)BM#*D,K52I5*V<J9RMP*G`K;2IM*V\J
M;RMN*FXK0B(`````<"(``$,B`````&TB;"(```````!N(C0B````````````
M`````````#$B``!K(@``````````1"(B*B$J)"HJ*B,J*2HA*2XJ,BHQ*C0J
M,RI`*C\J0BI!*@``4"I2*E$J5"I8*E,J```L*6,J8BIE*F0J<BHP*4XI(BLA
M*R0K*BLC*RDK02DN*S(K,2LT*S,K0"L_*T(K02M#*5`K4BM1*U0K6"M3*P``
M3"EC*V(K92MD*W(K4"ES*R<J)RLE*B4K*"HH*RLJ*RLL*BPK+RHO*RTJ+2LP
M*C`K(BE"*3<J-RL`````-BHV*S@J."LU*C4K.BHZ*SLJ.RL]*CTK/"H``#XJ
M/BLD*40I1RI'*T4J12L`````1BI&*T0J12DF*48I2"I(*TDJ22M'*4HJ2BM,
M*DPK2RI+*RDI22DH*4@I32I-*T\J3RM.*DXK2BDK*4LI5RI7*P````!6*E8K
M+2E-*5DJ62M;*ELK6BI:*UPJ7"M=*ETK7RI?*UXJ7BMA*F$K8"I@*R\I3REL
M*FPK:2II*V8J9BMK*FLK:"IH*VHJ:BMQ*G$K="IT*W,J=2IU*W<J=RMV*G8K
M-R(O6,=I69!D=-Q1F7$`````````````````````````````79U>G62=49U0
MG5F=<IV)G8>=JYUOG7J=FIVDG:F=LIW$G<&=NYVXG;J=QIW/G<*=V9W3G?B=
MYIWMG>^=_9T:GAN>'IYUGGF>?9Z!GHB>BYZ,GI*>E9Z1GIV>I9ZIGKB>JIZM
MGF&7S)[.GL^>T)[4GMR>WI[=GN">Y9[HGN^>])[VGO>>^9[[GOR>_9X'GPB?
MMW85GR&?+)\^GTJ?4I]4GV.?7Y]@GV&?9I]GGVR?:I]WGW*?=I^5GYR?H)\`
M````^YH&FQB;&IL?FR*;(YLEFR>;*)LIFRJ;+ILOFS*;1)M#FT^;39M.FU&;
M6)MTFY.;@YN1FY:;EYN?FZ";J)NTF\";RINYF\:;SYO1F]*;XYOBF^2;U)OA
MFSJ<\IOQF_";%9P4G`F<$YP,G`:<")P2G`J<!)PNG!N<)9PDG"&<,)Q'G#*<
M1IP^G%J<8)QGG':<>)SGG.R<\)P)G0B=ZYP#G0:=*ITFG:^=(YT?G42=%9T2
MG4&=/YT^G4:=2)T`````<9ATF'.8JIBOF+&8MIC$F,.8QICIF.N8`YD)F1*9
M%)D8F2&9'9D>F229()DLF2Z9/9D^F4*929E%F5"92YE1F5*93)E5F9>9F)FE
MF:V9KIF\F=^9VYG=F=B9T9GMF>Z9\9GRF?N9^)D!F@^:!9KBF1F:*YHWFD6:
M0II`FD.:/II5FDV:6YI7FE^:8IIEFF2::9IKFFJ:K9JPFKR:P)K/FM&:TYK4
MFMZ:WYKBFN.:YIKOFNN:[IKTFO&:]YH`````799?EF:6<I9LEHV6F):5EI>6
MJI:GEK&6LI:PEK26MI:XEKF6SI;+ELF6S99-B=R6#9?5EOF6!)<&EPB7$Y<.
MEQ&7#Y<6EQF7))<JES"7.9<]ESZ71)=&ETB70I=)EUR78)=DEV:7:)?24FN7
M<9=YEX67?)>!EWJ7AI>+EX^7D)><EZB7II>CE[.7M)?#E\:7R)?+E]R7[9=/
MG_*7WWKVE_67#Y@,F#B8))@AF#>8/9A&F$^82YAKF&^8<)@`````&9,BDQJ3
M(Y,ZDS63.Y-<DV"3?)-NDU:3L).LDZV3E).YD]:3UY/HD^63V)/#D]V3T)/(
MD^23&I04E!.4`Y0'E!"4-I0KE#64(90ZE$&44I1$E%N48)1BE%Z4:I0IDG"4
M=91WE'V46I1\E'Z4@91_E(*5AY6*E925EI68E9F5H)6HE:>5K96\E;N5N96^
ME<J5]F_#E<V5S)75E=25UI7<E>&5Y97BE2&6*)8NEB^60I9,ED^62Y9WEER6
M7I8`````3Y!0D%&04I`.D$F0/I!6D%B07I!HD&^0=I"HEG*0@I!]D(&0@)"*
MD(F0CY"HD*^0L9"UD.*0Y)!(8MN0`I$2D1F1,I$PD4J15I%8D6.199%ID7.1
M<I&+D8F1@I&BD:N1KY&JD;61M)&ZD<"1P9')D<N1T)'6D=^1X9';D?R1]9'V
MD1Z2_Y$4DBR2%9(1DEZ25Y)%DDF29))(DI62/Y)+DE"2G)*6DI.2FY):DL^2
MN9*WDNF2#Y/ZDD23+I,`````1XY)CDR.4(Y(CEF.9(Y@CBJ.8XY5CG:.<HY\
MCH&.AXZ%CH2.BXZ*CI..D8Z4CIF.JHZACJR.L([&CK&.OH[%CLB.RX[;CN..
M_([[CNN._HX*CP6/%8\2CQF/$X\<CQ^/&X\,CR:/,X\[CSF/18]"CSZ/3(])
MCT:/3H]7CUR/8H]CCV2/G(^?CZ./K8^OC[>/VH_EC^*/ZH_OCX>0](\%D/F/
M^H\1D!60(9`-D!Z0%I`+D">0-I`UD#F0^(\`````7XMLBV^+=(M]BX"+C(N.
MBY*+DXN6BYF+FHLZC$&,/XQ(C$R,3HQ0C%6,8HQLC'B,>HR"C(F,A8R*C(V,
MCHR4C'R,F(P=8JV,JHR]C+*,LXRNC+:,R(S!C.2,XXS:C/V,^HS[C`2-!8T*
MC0>-#XT-C1"-3I\3C<V,%(T6C6>-;8UQC7.-@8V9C<*-OHVZC<^-VHW6C<R-
MVXW+C>J-ZXW?C>.-_(T(C@F._XT=CAZ.$(X?CD*.-8XPCC2.2HX`````9HED
MB6V):HEOB72)=XE^B8.)B(F*B9.)F(FAB:F)IHFLB:^)LHFZB;V)OXG`B=J)
MW(G=B>>)](GXB0.*%HH0B@R*&XH=BB6*-HI!BEN*4HI&BDB*?(IMBFR*8HJ%
MBH**A(JHBJ&*D8JEBJ:*FHJCBL2*S8K"BMJ*ZXKSBN>*Y(KQBA2+X(KBBO>*
MWHK;B@R+!XL:B^&*%HL0BQ>+((LSBZN7)HLKBSZ+*(M!BTR+3XM.BTF+5HM;
MBUJ+:XL`````4X=CAVJ'!8BBAY^'@H>OA\N'O8?`A]"'UI:KA\2'LX?'A\:'
MNX?OA_*'X(</B`V(_H?VA_>'#HC2AQ&(%H@5B"*((8@QB#:(.8@GB#N(1(A"
MB%*(68A>B&*(:XB!B'Z(GHAUB'V(M8ARB(*(EXB2B*Z(F8BBB(V(I(BPB+^(
ML8C#B,2(U(C8B-F(W8CYB`*)_(CTB.B(\H@$B0R)"HD3B4.)'HDEB2J)*XE!
MB42).XDVB3B)3(D=B6")7HD`````084"ADN%586`A:2%B(61A8J%J(5MA92%
MFX7JA8>%G(5WA7Z%D(7)A;J%SX6YA="%U87=A>6%W(7YA0J&$X8+AOZ%^H4&
MAB*&&H8PAC^&38953E2&7X9GAG&&DX:CAJF&JH:+AHR&MH:OAL2&QH:PALF&
M(XBKAM2&WH;IANR&WX;;AN^&$H<&APB'`(<#A_N&$8<)APV'^88*AS2'/X<W
MASN')8<IAQJ'8(=?AWB'3(=.AW2'5X=HAVZ'68<`````-8,T@Q:#,H,Q@T"#
M.8-0@T6#+X,K@Q>#&(.%@YJ#JH.?@Z*#EH,C@XZ#AX.*@WR#M8-S@W6#H(.)
M@ZB#](,3A.N#SH/]@P.$V(,+A,&#]X,'A."#\H,-A"*$((2]@SB$!H7[@VV$
M*H0\A%J%A(1WA&N$K81NA(*$:81&A"R$;X1YA#6$RH1BA+F$OX2?A-F$S82[
MA-J$T(3!A,:$UH2AA"&%_X3TA!>%&(4LA1^%%844A?R$0(5CA5B%2(4`````
MBY9&@3Z!4X%1@?R`<8%N@66!9H%T@8.!B(&*@8"!@H&@@96!I(&C@5^!DX&I
M@;"!M8&^@;B!O8'`@<*!NH')@<V!T8'9@=B!R(':@=^!X('G@?J!^X'^@0&"
M`H(%@@>""H(-@A""%H(I@BN".((S@D""68)8@EV"6H)?@F2"8H)H@FJ":X(N
M@G&"=X)X@GZ"C8*2@JN"GX*[@JR"X8+C@M^"TH+T@O."^H*3@P.#^X+Y@MZ"
M!H/<@@F#V8(`````17],?TU_3G]0?U%_57]4?UA_7W]@?VA_:7]G?WA_@G^&
M?X-_B'^'?XQ_E'^>?YU_FG^C?Z]_LG^Y?ZY_MG^X?W&+Q7_&?\I_U7_4?^%_
MYG_I?_-_^7_<F`:`!(`+@!*`&(`9@!R`(8`H@#^`.X!*@$:`4H!8@%J`7X!B
M@&B`<X!R@'"`=H!Y@'V`?X"$@(:`A8";@).`FH"M@)!1K(#;@.6`V8#=@,2`
MVH#6@`F![X#Q@!N!*8$C@2^!2X$``````GT<?15]"GU%?4M]+GTR?3]]-7U&
M?7-]5GU.?7)]:'UN?4]]8WV3?8E]6WV/?7U]FWVZ?:Y]HWVU?<=]O7VK?3U^
MHGVO?=Q]N'V??;!]V'W=?>1]WGW[??)]X7T%?@I^(WXA?A)^,7X??@E^"WXB
M?D9^9GX[?C5^.7Y#?C=^,GXZ?F=^77Y6?EY^67Y:?GE^:GYI?GQ^>WZ#?M5]
M?7ZNCW]^B'Z)?HQ^DGZ0?I-^E'Z6?HY^FWZ<?CA_.G\`````>GL$>TU["WM,
M>T5[=7ME>W1[9WMP>W%[;'MN>YU[F'N?>XU[G'N:>XM[DGN/>UU[F7O+>\%[
MS'O/>[1[QGO=>^E[$7P4?.9[Y7M@?`!\!WP3?/-[]WL7?`U\]GLC?"=\*GP?
M?#=\*WP]?$Q\0WQ4?$]\0'Q0?%A\7WQD?%9\97QL?'5\@WR0?*1\K7RB?*M\
MH7RH?+-\LGRQ?*Y\N7R]?,!\Q7S"?-A\TGS<?.)\.YOO?/)\]'SV?/I\!GT`
M````YWC:>/UX]'@'>1)Y$7D9>2QY*WE`>6!Y5WE?>5IY57E3>7IY?WF*>9UY
MIWE+GZIYKGFS>;EYNGG)>=5YYWGL>>%YXWD(>@UZ&'H9>B!Z'WJ`>3%Z.WH^
M>C=Z0WI7>DEZ87IB>FEZG9]P>GEZ?7J(>I=ZE7J8>I9ZJ7K(>K!ZMGK%>L1Z
MOWJ#D,=ZRGK->L]ZU7K3>MEZVGK=>N%ZXGKF>NUZ\'H">P]["GL&>S-[&'L9
M>QY[-7LH>S9[4'L`````<G9V=GAV?':`=H-VB':+=HYVEG:3=IEVFG:P=K1V
MN':Y=KIVPG;-=M9VTG;>=N%VY7;G=NIV+X;[=@AW!W<$=REW)'<>=R5W)G<;
M=S=W.'='=UIW:'=K=UMW97=_=WYW>7>.=XMWD7>@=YYWL'>V=[EWOW>\=[UW
MNW?'=\UWUW?:=]QWXW?N=_QW#'@2>"9Y('@J>45XCGAT>(9X?'B:>(QXHWBU
M>*IXKWC1>,9XRWC4>+YXO'C%>,IX['@`````X'3C=.=TZ73N=/)T\'3Q=/AT
M]W0$=0-U!74,=0YU#745=1-U'G4F=2QU/'5$=4UU2G5)=5MU1G5:=6EU9'5G
M=6MU;75X=79UAG6'=71UBG6)=8)UE'6:=9UUI76C=<)ULW7#=;5UO76X=;QU
ML77-=<IUTG79=>-UWG7^=?]U_'4!=O!U^G7R=?-U"W8-=@EV'W8G=B!V(78B
M=B1V-'8P=CMV1W9(=D9V7'98=F%V8G9H=FEV:G9G=FQV<'8`````^7'_<0UR
M$'(;<BAR+7(L<C!R,G([<CQR/W)`<D9R2W)8<G1R?G*"<H%RAW*2<I9RHG*G
M<KERLG+#<L9RQ'+.<M)RXG+@<N%R^7+W<@]0%W,*<QQS%G,=<S1S+W,I<R5S
M/G-.<T]SV)Y7<VIS:'-P<WAS=7-[<WISR'.S<\YSNW/`<^5S[G/><Z)T!71O
M="5T^',R=#IT570_=%]T671!=%QT:71P=&-T:G1V='YTBW2>=*=TRG3/=-1T
M\7,`````/F\3;_=NAF]Z;WAO@6^`;V]O6V_S;VUO@F]\;UAOCF^1;\)O9F^S
M;Z-OH6^D;[EOQF^J;]]OU6_L;]1OV&_Q;^YOVV\)<`MP^F\1<`%P#W#^;QMP
M&G!T;QUP&'`?<#!P/G`R<%%P8W"9<))PKW#Q<*QPN'"S<*YPWW#+<-UPV7`)
M<?UP''$9<65Q57&(<69Q8G%,<59Q;'&/<?MQA'&5<:AQK''7<;EQOG'2<<EQ
MU''.<>!Q[''G<?5Q_'$`````NFS;;.]LV6SJ;!]M38@V;2MM/6TX;1EM-6TS
M;1)M#&UC;9-M9&U:;7EM66V.;95MY&^%;?EM%6X*;K5MQVWF;;AMQFWL;=YM
MS&WH;=)MQ6WZ;=EMY&W5;>IM[FTM;FYN+FX9;G)N7VX^;B-N:VXK;G9N36X?
M;D-N.FY.;B1N_VX=;CAN@FZJ;IANR6ZW;M-NO6ZO;L1NLF[4;M5NCVZE;L)N
MGVY!;Q%O3'#L;OAN_FX_;_)N,6_O;C)OS&X`````EVH7AKMJPVK":KAJLVJL
M:MYJT6K?:JIJVFKJ:OMJ!6L6AOIJ$FL6:S&;'VLX:S=KW'8Y:^Z81VM#:TEK
M4&M9:U1K6VM?:V%K>&MY:W]K@&N$:X-KC6N8:Y5KGFND:ZIKJVNO:[)KL6NS
M:[=KO&O&:\MKTVO?:^QKZVOS:^]KOIX(;!-L%&P;;"1L(VQ>;%5L8FQJ;()L
MC6R:;(%LFVQ^;&AL<VR2;)!LQ&SQ;--LO6S7;,5LW6RN;+%LOFP`````U&CG
M:-5H-FD2:01IUVCC:"5I^6C@:.]H*&DJ:1II(VDA:<9H>6EW:5QI>&EK:51I
M?FEN:3EI=&D]:5EI,&EA:5YI76F!:6IILFFN:=!IOVG!:=-IOFG.:>A;RFG=
M:;MIPVFG:2YJD6F@:9QIE6FT:=YIZ&D":AMJ_VD*:_EI\FGG:05JL6D>:NUI
M%&KK:0IJ$FK!:B-J$VI$:@QJ<FHV:GAJ1VIB:EEJ9FI(:CAJ(FJ0:HUJH&J$
M:J)JHVH`````Q&:X9M9FVF;@9C]FYF;I9O!F]6;W9@]G%F<>9R9G)V<XERYG
M/V<V9T%G.&<W9T9G7F=@9UEG8V=D9XEG<&>I9WQG:F>,9XMGIF>A9X5GMV?O
M9[1G[&>S9^EGN&?D9]YGW6?B9^YGN6?.9\9GYV><:AYH1F@I:$!H36@R:$YH
MLV@K:%EH8VAW:']HGVB/:*UHE&B=:)MH@VBN:KEH=&BU:*!HNF@/:8UH?F@!
M:<IH"&G8:")I)FGA:`QIS6@`````VF329,5DQV2[9-ADPF3Q9.=D"8+@9.%D
MK&+C9.]D+&7V9/1D\F3Z9`!E_60891QE!64D92-E*V4T935E-V4V93AE2W5(
M959E565-95AE7F5=97)E>&6"98-EBHN;99]EJV6W9<-EQF7!9<1ES&729=ME
MV67@9>%E\65R9PIF`V;[97-G-68V9C1F'&9/9D1F269!9EYF769D9F=F:&9?
M9F)F<&:#9HAFCF:)9H1FF&:=9L%FN6;)9KYFO&8`````'F(A8BIB+F(P8C)B
M,V)!8DYB7F)C8EMB8&)H8GQB@F*)8GYBDF*38I9BU&*#8I1BUV+18KMBSV+_
M8L9BU&3(8MQBS&+*8L)BQV*;8LEB#&/N8O%B)V,"8PAC[V+U8E!C/F--8QQD
M3V.68XYC@&.K8W9CHV./8XECGV.U8VMC:6.^8^ECP&/&8^-CR6/28_9CQ&,6
M9#1D!F039"9D-F0=91=D*&0/9&=D;V1V9$YD*F659)-DI62I9(ADO&0`````
MA&";8)9@EV"28*=@BV#A8+A@X&#38+1@\%^]8,9@M6#88$UA%6$&8?9@]V``
M8?1@^F`#82%A^V#Q8`UA#F%'83YA*&$G84IA/V$\82QA-&$]84)A1&%S87=A
M6&%985IA:V%T86]A96%Q85]A76%3875AF6&688=AK&&489IABF&18:MAKF',
M8<IAR6'W8<AAPV'&8;IARV%Y?\UAYF'C8?9A^F'T8?]A_6'\8?YA`&((8@EB
M#6(,8A1B&V(`````UE[C7MU>VE[;7N)>X5[H7NE>[%[Q7O->\%[T7OA>_EX#
M7PE?75]<7PM?$5\67RE?+5\X7T%?2%],7TY?+U]17U9?5U]97V%?;5]S7W=?
M@U^"7W]?BE^(7Y%?AU^>7YE?F%^@7ZA?K5^\7]9?^U_D7_A?\5_=7[-@_U\A
M8&!@&6`08"E@#F`Q8!M@%6`K8"9@#V`Z8%I@06!J8'=@7V!*8$9@36!C8$-@
M9&!"8&Q@:V!98(%@C6#G8(-@FF``````4%Q/7'%;;%QN7&).=EQY7(Q<D5R4
M7)M9JUR[7+9<O%RW7,5<OES'7-E<Z5S]7/I<[5R,7>I<"UT571==7%T?71M=
M$5T472)=&ET971A=3%U274Y=2UUL77-==EV'781=@EVB79U=K%VN7;U=D%VW
M7;Q=R5W-7=-=TEW67=M=ZUWR7?5="UX:7AE>$5X;7C9>-UY$7D->0%Y.7E=>
M5%Y?7F)>9%Y'7G5>=EYZ7KR>?UZ@7L%>PE[(7M!>SUX`````>%F!69U97D^K
M3Z-9LEG&6>A9W%F-6=E9VEDE6A]:$5H<6@E:&EI`6FQ:25HU6C9:8EIJ6II:
MO%J^6LM:PEJ]6N-:UUKF6NE:UEKZ6OM:#%L+6Q9;,EO06BI;-EL^6T-;15M`
M6U%;55M:6UM;95MI6W!;<UMU6WA;B&5Z6X!;@UNF6[A;PUO'6\E;U%O06^1;
MYEOB6]Y;Y5OK6_!;]EOS6P5<!UP(7`U<$UP@7")<*%PX7#E<05Q&7$Y<4UP`
M````"%<+5PU7$U<85Q97QU4<5R97-U<X5TY7.U=`5T]7:5?`5XA785=_5XE7
MDU>@5[-7I%>J5[!7PU?&5]17TE?35PI8UE?C5PM8&5@=6')8(5AB6$M8<%C`
M:U)8/5AY6(58N5B?6*M8NEC>6+M8N%BN6,58TUC16-=8V5C86.58W%CD6-]8
M[UCZ6/E8^UC\6/U8`ED*61!9&UFF:"59+%DM63)9.%D^6=)Z55E064Y96EE8
M66)98%EG66Q9:5D`````JU3"5*14OE2\5-A4Y53F5`]5%%7]5.Y4[53Z5.)4
M.55`56-53%4N55Q5155655=5.%4S55U5F56`5:]4BE6?57M5?E6859Y5KE5\
M58-5J56'5:A5VE7%5=]5Q%7<5>15U%445O=5%E;^5?U5&U;Y54Y64%;?<316
M-E8R5CA6:U9D5B]6;%9J5H96@%:*5J!6E%:/5J56KE:V5K16PE:\5L%6PU;`
M5LA6SE;15M-6UU;N5OE6`%?_5@17"5<`````IX^L4JU2O%*U4L%2S5+74MY2
MXU+F4NV8X%+S4O52^%+Y4@93"%,X=0U3$%,/4Q53&E,C4R]3,5,S4SA30%-&
M4T53%TY)4TU3UE%>4VE3;E,867M3=U."4Y93H%.F4Z53KE.P4[93PU,2?-F6
MWU/\9NYQ[E/H4^U3^E,!5#U40%0L5"U4/%0N5#94*50=5$Y4CU1U5(Y47U1Q
M5'=4<%225'M4@%1V5(14D%2&5,=4HE2X5*54K%3$5,A4J%0`````R5#*4+-0
MPE#64-Y0Y5#M4.-0[E#Y4/50"5$!40)1%E$54111&E$A43I1-U$\43M1/U%`
M45)13%%446)1^'II46I1;E&`48)1V%:,48E1CU&149-1E5&64:11IE&B4:E1
MJE&K4;-1L5&R4;!1M5&]4<51R5';4>!158;I4>U1\%'U4?Y1!%(+4A12#E(G
M4BI2+E(S4CE23U)$4DM23%)>4E12:E)T4FE2<U)_4GU2C5*44I)2<5*(4I%2
MJ(\`````#%\03A5.*DXQ3C9./$X_3D).5DY83H).A4YKC(I.$H(-7XY.GDZ?
M3J!.HDZP3K-.MD[.3LU.Q$[&3L).UT[>3NU.WT[W3@E/6D\P3UM/74]73T=/
M=D^(3X]/F$][3VE/<$^13V]/AD^63QA1U$_?3\Y/V$_;3]%/VD_03^1/Y4\:
M4"A0%%`J4"50!5`<3_9/(5`I4"Q0_D_O3Q%0!E!#4$=0`V=54%!02%!:4%90
M;%!X4(!0FE"%4+10LE``````[H0CD"R30E1OF]-JB7#"C.^-,I>T4D%:REX$
M7Q=G?&F4:6IM#V]B<OQR[7L!@'Z`2X?.D&U1DYZ$>8N`,I/6BBU0C%1QBFIK
MQ(P'@=%@H&?RG9E.F$X0G&N*P85HA0!I?FZ7>%6!````````````````````
M``````````````#B=<^(X8C,D>*6>):+7X=SRWI.A*!C976)4D%MG&X)=%EU
M:WB2?(:6W'J-G[9/;F'%95R&ADZN3MI0(4[,4>Y;F66!:+QM'W-"=JUW''KG
M?&^"THI\D,^1=988F)M2T7TK4)A3EV?+;=!Q,W3H@2J/HY97G)^>8'1!6)EM
M+WU>F.1.-D^+3[=1L5*Z71Q@LG,\>=."-)*WEO:6"I>7GF*?IF9T:Q=2HU+(
M<,*(R5Y+8)!A(V])<3Y\]'UO@`````#MBCB/+U513RI1QU++4Z5;?5Z@8()A
MUF,)9]IG9VZ,;39S-W,Q=5!YU8B8BDJ0D9#UD,26C8<568A.64\.3HF*/X\0
MF*U0?%Z66;E;N%[:8_ICP63<9DIIV&D+;;9NE'$H=:]ZBG\`@$F$R82!B2&+
M"HYED'V6"IE^89%B,FN#;'1MS'_\?\!MA7^ZA_B(96>Q@SR8]Y8;;6%]/81J
MD7%.=5-0701KZV_-A2V&IXDI4@]495Q.9ZAH!G2#=``````K;Q.%<U0J9T6;
M\UV5>ZQ<QEL<ATINT804>@B!F5F-?!%L('?94B)9(7%?<MMW)Y=AG0MI?UH8
M6J51#51]5`YFWW;WCYB2])SJ65URQ6Y-4<EHOWWL?6*7NIYX9"%J`H.$65];
MVVL;<_)VLGT7@)F$,E$H9]F>[G9B9_]2!9DD7#MB?GRPC$]5MF`+?8"5`5-?
M3K91'%DZ<C:`SI$E7^)WA%-Y7P1]K(4SBHV.5I?S9ZZ%4Y0)80AAN6Q2=@``
M``#5;.%L^7`R>"M^WH"S@@R$[(0"AQ*)*HI*C*:0TI+]F/.<;)U/3J%.C5!6
M4DI7J%D]7MA?V5\_8K1F&V?09])HDE$A?:J`J($`BXR,OXQ^DC*6(%0LF!=3
MU5!<4ZA8LF0T9V=R9G=&>N:1PU*A;(9K`%A,7E19+&?[?^%1QG9I9.AX5)N[
MGLM7N5DG9IIGSFOI5-EI55Z<@95GJIO^9U*<76BF3N-/R%.Y8BMGJVS$CZU/
M;7Z_G@=.8F&`;@````"/>7F!!XF&B?5M%U]58KALSTYI<I*;!E([5'16LUBD
M86YB&G%N68E\WGP;??"6AV5>@!E.=4]U44!88UYS7@I?Q&<F3CV%B95;EG-\
M`9C[4,%85G:G>"52I7<1A89[3U`)64=RQWOH?;J/U(]-D+]/R5(I6@%?K9?=
M3Q>"ZI(#5U5C:6LK==R(%(]">M]2DUA580IBKF;-:S]\Z8,C4/A/!5-&5#%8
M25F=6_!<[UPI799>L6)G8SYEN64+9P`````[G\IG%WHY4XMU[9IF7YV!\8.8
M@#Q?Q5]B=49[/)!G:.M9FUH0?7YV+(OU3VI?&6HW;`)OXG1H>6B(58IYC-]>
MSV/%==)YUX(HD_*2G(3MABV<P51L7XQE7&T5<*>,TXP[F$]E]G0-3MA.X%<K
M669:S%NH40->G%X68'9B=V6G96YF;FTV<B9[4(&:@9F"7(N@C.:,=(T<ED26
MKD^K9&9K'H)AA&J%Z)`!7%-IJ)AZA%>%#T]O4JE?15X-9P````#]4;%[<GBX
M>X>`2'OH:F%>C(!1=6!U:U%BDHQN>G:7D>J:$$]P?YQB3WNEE>F<>E996.2&
MO)8T3R122E/-4]M3!EXL9)%E?V<^;$YL2'*O<NUS5'5!?BR"Z86IC,1[QI%I
M<1*8[Y@]8VEF:G7D=M!X0X7NABI345,F5(-9AUY\7[)@26)Y8JMBD&74:\QL
MLG6N=I%XV'G+?7=_I8"KB+F*NXQ_D%Z7VY@+:CA\F5`^7*Y?AV?8:S5T"7>.
M?P````""63]<[I?[3HI9S5^-BN%OL'EB>>=;<80K<[%Q=%[U7WMCFF3#<9A\
M0T[\7DM.W%>B5JE@PV\-??V`,X&_@;*/EXFDAO1=BF*M9(>)=V?B;#YM-G0T
M>$9:=7^M@JR9\T_#7MUBDF-796]GPW9,<LR`NH`ICTV1#5#Y5Y):A6AS:61Q
M_7*WC/)8X(QJEAF0?X?D>>=W*80O3V526E/-8L]GRFQ]=I1[E7PV@H2%ZX_=
M9B!O!G(;?JN#P9FFG@````!CA&F%Y(4.B@2+1HP/C@.0#Y`9E':6+9@PFMB5
MS5#54@Q4`E@.7*=AGF0>;;-WY7KT@`2$4Y"%DN!<!YT_4Y=?LU^<;7ER8W>_
M>>1[TFOL<JV*`VAA:OA1@7HT:4I<]ISK@L5;29$><'A6;US'8&9EC&Q:C$&0
M$YA15,=F#9)(6:.0A5%-3NI1F84.BUAP>F-+DV)IM)D$?G=U5U-@:=^.XY9=
M;(Q./%P07^F/`E/1C(F`>8;_7N5E<TYE40````"XD"V1V)$.G^5L6&3B9'5E
M]&Z$=AM[:9#1D[IN\E2Y7Z1D38_MCT22>%%K6"E955R77OMMCWX<=;R,XHY;
MF+EP'4^_:[%O,'7[EDY1$%0U6%=8K%E@7))?EV5<9R%N>W;?@^V,%)#]D$V3
M)7@Z>*I2IEX?5W19$F`24%I1K%'-40!2$%546%A85UF56_9<BUV\8)5B+61Q
M9T-HO&C?:-=VV&UO;IMM;W#(<5-?V'5W>4E[5'M2>]9\<7TP4@`````67C->
M@5X47S5?:U^T7_)A$6.B9AUG;F]2<CIU.G=T@#F!>(%VA[^*W(J%C?.-FI)W
ME0*8Y9S%4E=C]'859XALS7/#C*Z3<Y8E;9Q8#FG,:?V/FI/;=1J06E@":+1C
M^VE#3RQOV&>[CR:%M'U4DS]I<&]J5_=8+%LL?2IR"E3CD;2=K4Y.3UQ0=5!#
M4IZ,2%0D6)I;'5Z57JU>]UX?7XQ@M6(Z8]!CKVA`;(=XCGD+>N!]1X("BN:*
M1(X3D`````#I4T9/5)"PCVI9,8']7>IZOX_::#>,^')(G#UJL(HY3EA3!E9F
M5\5BHF/F94YKX6U;;JUP[7?O>JI[NWT]@,:`RX:5BEN3XU;'6#Y?K6669H!J
MM6LW=<>*)%#E=S!7&U]E8'IF8&ST=1IZ;G_T@1B'19"SF<E[7'7Y>E%[Q(00
MD.EYDGHV@^%:0'<M3O).F5O@7[UB/&;Q9^AL:X9WB#N*3I'SDM"9%VHF<"IS
MYX)7A*^,`4Y&4<M1BU7U6P````#3@36%"(T@D,-/=%!'4G-3;V!)8U]G+&ZS
MC1^0UT]>7,J,SV6:?5)3EHAV4<-C6%MK6PI<#6119UR0UDX:62I9<&Q1BCY5
M%5BE6?!@4V+!9S6"56E`EL29*)I33P98_EL0@+%<+UZ%7R!@2V$T8O]F\&S>
M;LZ`?X'4@HN(N(P`D"Z0BI;;GMN;XT[P4R=9+'N-D4R8^9W=;B=P4U-$585;
M6&*>8M-BHFSO;R)T%XHXE,%O_HHX@^=1^(;J4P````!*?JA_>H$;@CF"IH5N
MBLZ,]8UXD'>0K9*1DH.5KIM-4H15.&\V<6A1A7E5?K.!SGQ,5E%8J%RJ8_YF
M_69::=ERCW6.=0YY5GG?>9=\('U$?0>&-(H[EF&0()_G4'52S%/B4PE0JE7N
M6$]9/7*+6V1<'5/C8/-@7&.#8S]CNV/-9.EE^6;C7<UI_6D5;^5QB4[I=?AV
MDWK??,]]G'UA@$F#6(-LA+R$^X7%B'"-`9!MD)>3')<2FL]0EUB.80````"$
M;WID^%L63BQP774O9L11-E+B4M-9@5\G8!!B/V5T91]F=&;R:!9H8VL%;G)R
M'W7;=KY\5H#P6/V(?XF@BI.*RXH=D)*14I=9EXEE#GH&@;N6+5[<8!IBI644
M9I!G\W=->DU\/GX*@:R,9(WAC5^.J7@'4MEBI6-"9)AB+8J#>L![K(KJEG9]
M#())A]E.2%%#4V!3HUL"7!9<W5TF8D=BL&03:#1HR6Q%;1=MTV=<;TYQ?7'+
M97]ZK7O:?0````#M8@UIEFOM<51^=X!R@N:)WYA5A[&/.UPX3^%/M4\'52!:
MW5OI6\-?3F$O8[!E2V;N:)MI>&WQ;3-UN74?=UYYYGDS?>.!KX*JA:J).HJK
MCIN/,I#=D0>7ND[!3@-2=5CL6`M<&G4]7$Z!"HK%CV.6;9<E>\^*")ABD?-6
MJ%,7D#E4@E<E7JAC-&R*<&%WBWS@?W"(0I!4D1"3&)./EEYTQ)H'76E=<&6B
M9ZB-VY9N8TEG&6G%@Q>8P);^B`````#=4B!31U/L4^A41E4Q51=6:%F^63Q:
MM5L&7`]<$5P:7(1>BE[@7G!??V*$8MMBC&-W8P=F#&8M9G9F?F>B:!]J-6J\
M;(AM"6Y8;CQQ)G%G<<=U`7==>`%Y97GP>>!Z$7NG?#E]EH#6@XN$285=B/.(
M'XH\BE2*<XIAC-Z,I)%FDGZ3&)2<EIB7"DX(3AY.5TZ747!2SE<T6,Q8(ELX
M7L5@_F1A9U9G1&VV<G-U8WJXA'*+N)$@DS%6]%?^F`````"76S%<WEWN3P%A
M_F(R;<!YRWE"?4U^TG_M@1^"D(1&B'*)D(MTCB^/,9!+D6R1QI:<D<!.3T]%
M44%3DU\.8M1G06P+;F-S)G[-D8.2U%,96;];T6U=>2Y^FWQ^6)]Q^E%3B/"/
MRD_[7"5FK'?C>AR"_YG&4:I?[&5O:8EK\VV6;F1O_G84?>%==9"'D0:8YE$=
M4D!BD6;99AINME[2?7)_^&:OA?>%^(JI4ME3<UF/7I!?56#DDF26MU`?40``
M```A:\MNNVP^<KUTU'7!>#IY#(`S@.J!E(2>CU!L?YX/7UB+*YWZ>OB.C5OK
ME@-.\5/W5S%9R5JD6XE@?VX&;[YUZHR?6P"%X'MR4/1GG8)A7$J%'GX.@IE1
M!%QH8V:-G&5N<3YY%WT%@!V+RHYND,>&JI`?4/I2.EQ39WQP-7),D<B1*Y/E
M@L);,5_Y8#M.UE.(6TMB,6>*:^ERX',N>FN!HXU2D9:9$E'74VI4_UN(8SEJ
MK'T`E]I6SE-H5`````#?6_9BKF3F9"UGNFNIA=&6D';6FTQC!I.KF[]V4F8)
M3IA0PE-Q7.A@DF1C95]HYG'*<R-UEWN"?I6&@XO;C'B1$)FL9:MFBVO53M1.
M.D]_3SI2^%/R4^-5VU;K6,M9R5G_65!;35P"7BM>UU\=8`=C+V5<6Z]EO67H
M99UG8FM[:P]L17-)><%Y^'P9?2M]HH`"@?.!EHE>BFF*9HJ,BNZ*QXS<C,R6
M_)AO:XM./$^-3U!15UOZ6TAA`6-"9@````!D:P.8RD[P5F17OEA:6FA@QV$/
M9@9F.6BQ:/=MU74Z?6Z"0IN;3E!/R5,&56]=YEWN7?MGF6QS=`)X4(J6D]^(
M4%>G7BMCM5"L4(U1`&?)5%Y8NUFP6VE?36*A8SUH<VL(;GUPQY&`<A5X)GAM
M>8YE,'W<@\&("8^;EF12*%=09VI_H8RT44)7*I8Z6(IIM("R5`Y=_%>5>/J=
M7$]*4HM4/F0H9A1G]6>$>E9[(GTODUQHK9LY>QE3BE$W4@`````.5(E545>B
M5WU95%M=6X];Y5WG7?==>%Z#7II>MUX87U)@3&&78MABIV,[90)F0V;T9FUG
M(6B7:,MI7VPJ;6EM+VZ=;C)UAW9L>#]ZX'P%?1A]7GVQ?16``X"O@+&`5(&/
M@2J"4H-,B&&(&XNBC/R,RI!UD7&2/WC\DJ25398%F)F9V)H[G5M2JU+W4PA4
MU5CW8N!O:HQ?C[F>2U$[4DI4_59`>G>18)W2GD1S"6]P@1%U_5_:8*B:VW*\
MCP`````<:2EJ?7*L<BYS%'AO>'E]#'>I@(N)&8OBC-*.8Y!UDWJ659@3FGB>
M0U&?4[-3>UXF7QMND&Z$<_YS0WTW@@"*^HI0EDY."U#D4WQ4^E;1661;\5VK
M7B=?.&)%9:]G5F[0<LI\M(BA@.&`\(-.AH>*Z(TWDL>69Y@3GY1.DDX-3TA3
M250^5"]:C%^A7Y]@IVB.:EIT@7B>BJ2*=XN0D5Y.R9ND3GQ/KT\94!9025%L
M49]2N5+^4II3XU,15`````"88Y]ZDVQTEV&/JGJ*<8B6@GP7:'!^46ALD_)2
M&U2KA1.*I'_-CN&09E.(B$%YPD^^4!%21%%352U7ZG.+5U%98E^$7W5@=F%G
M8:EALF,Z9&QE;V9":!-N9G4]>OM\3'V9?4M^:W\.@TJ#S88(BF.*9HO]CAJ8
MCYVX@LZ/Z)N'4A]B@V3`;YF606B14"!K>FQ4;W1Z4'U`B".*"&?V3CE0)E!E
M4'Q1.%)C4J=5#U<%6,Q:^EZR8?AA\V)R8P````";3Z!/T5!'4?9Z<5'V4513
M(5-_4^M3K%6#6.%<-U]*7R]@4&!M8!]C665+:L%LPG+M<N]W^(`%@0B"3H7W
MD.&3_Y=7F5J:\$[=42U<@69M:4!<\F9U:8ES4&B!?,50Y%)'5_Y=)I.D92-K
M/6LT=(%YO7E+>\I]N8+,@W^(7XDYB]&/T9$?5("274XV4.53.E/7<I9SZ7?F
M@J^.QIG(F=*9=U$:85Z&L%5Z>G90TUM'D(66,D[;:N>145Q(7`````!?:C!>
MQ6L7;'UL?W5(>6-;`'H`?;U?CXD8BK2,=XW,CAV/XI@.FCR;@$Y]4`!1DUF<
M6R]B@&+L9#IKH'*1=4=YJ7_[A[R*<(NL8\J#H)<)5`-4JU54:%AJ<(HG>'5G
MS9YT4Z);&H%0A@:0&$Y%3L=.$4_*4SA4KEL37R5@464]9T)L<FSC;'AP`W1V
M>JYZ"'L:??Y\9GWG95MRNU-%7.A=TF+@8AEC(&Y:AC&*W8WXD@%OIGE:FZA.
MJTZL3@````"E?`A2Q8+F='Y.@T^@4=);"E+84N=2^UV:52I8YEF,6YA;VUMR
M7GE>HV`?86-AOF';8V)ET6=3:/IH/FM3:U=L(F^7;T5OL'08=>-V"W?_>J%[
M(7SI?39_\'^=@&:"GH.SB<R*JXR$D%&4DY61E:*599;3ERB9&((X3BM4N%S,
M7:ES3'8\=ZE<ZW\+C<&6$9A4F%B8`4\.3W%3G%5H5OI71UD)6\1;D%P,7GY>
MS%_N8SIGUV7B91]GRVC$:`````!!FV9FL&AW;7!P3'6&=G5]I8+YAXN5CI:=
MC/%1OE(66;-4LUL676AA@FFO;8UXRX17B'**IY.XFFQMJ)G9AJ-7_V?.A@Z2
M@U*'5@14TU[A8KED/&@X:+MK<G.Z>&MZFHG2B6N-`X_MD*.5E)9IEV9;LUQ]
M:4V83IB;8R![*VI_:K9H#9Q?;W)2G55P8.QB.VT';M%N6X00B42/%$XYG/93
M&VDZ:H27*FA<4<-ZLH3<D8R36U8HG2)H!8,QA`````"\8OIE*FHG:[1KBW/!
M?U:)+)T.G<2>H5R6;'N#!%%+7+9AQH%V:&%R64[Z3WA3:6`I;D]Z\Y<+3A93
M[DY53SU/H4]S3Z!2[U,)5@]9P5JV6^%;T7F'9IQGMF=,:[-L:W#"<XUYOGD\
M>H=[L8+;@@2#=X/O@].#9H>RBBE6J(SFCTZ0'I>*AL1/Z%P18EER.W7E@;V"
M_H;`C,66$YG5F<M.&D_CB=Y62EC*6/M>ZU\J8)1@8F#081)BT&(Y90````!B
MEG"6H);[EPM4\U.'6\]PO7_"C^B6;U-<G;IZ$4Z3>/R!)FX85@15'6L:A3N<
MY5FI4V9MW'2/E4)6D4Y+D/*63X,,F>%3ME4P6W%?(&;S9@1H.&SS;"EM6W3(
M=DYZ-)CQ@EN(8(KMDK)MJW7*=L69IF`!BXJ-LI6.::U3AE$25S!81%FT6_9>
M*&"I8_1COVP4;XYP%'%9<=5Q/W,!?G:"T8*7A6"06Y(;G6E8O&5:;"5U^5$N
M6659@%_<7P````"<3A95`UH_EL!4&V$H8_99(I!UA!R#4'JJ8.%C)6[M96:$
MIH+UFY-H)U>A97%BFUO067N&])AB?;Y]CIL68I]\MXB)6[5>"6.79DAHQY6-
MET]GY4X*3TU/G4])4/)6-UG460%:"5S?8`]A<&$39@5ING!/=7!U^WFM?>]]
MPX`.A&.(`HM5D'J0.U.53J5.WU>R@,&0[W@`3O%8HFXXD#)Z*(.+@B^<05%P
M4[U4X53@5OM9%5_RF.MMY(`MA0``````)0(E#"40)1@E%"4<)2PE)"4T)3PE
M`24#)0\E$R4;)1<E(R4S)2LE.R5+)2`E+R4H)3<E/R4=)3`E)24X)4(E$`01
M!!($$P04!!4$`006!!<$&`09!!H$&P0<!!T$'@0?!"`$(00B!",$)`0E!"8$
M)P0H!"D$*@0K!"P$+00N!"\$````````````````````````````````````
M````,`0Q!#($,P0T!#4$400V!#<$.`0Y!#H$.P0\!#T$/@0_!$`$001"!$,$
M1`1%!$8$1P1(!$D$2@1+!$P$301.!$\$````````````````````````````
M````````````D0.2`Y,#E`.5`Y8#EP.8`YD#F@.;`YP#G0.>`Y\#H`.A`Z,#
MI`.E`Z8#IP.H`ZD#`````````````````````+$#L@.S`[0#M0.V`[<#N`.Y
M`[H#NP.\`[T#O@._`\`#P0/#`\0#Q0/&`\<#R`/)`P``````````````````
M``"A,*(PHS"D,*4PIC"G,*@PJ3"J,*LPK#"M,*XPKS"P,+$PLC"S,+0PM3"V
M,+<PN#"Y,+HPNS"\,+TPOC"_,,`PP3#",,,PQ##%,,8PQS#(,,DPRC#+,,PP
MS3#.,,\PT##1,-(PTS#4,-4PUC#7,-@PV3#:,-LPW##=,-XPWS#@,.$PXC#C
M,.0PY3#F,.<PZ##I,.HPZS#L,.TP[C#O,/`P\3#R,/,P]##U,/8P````````
M``````````````````!!,$(P0S!$,$4P1C!',$@P23!*,$LP3#!-,$XP3S!0
M,%$P4C!3,%0P53!6,%<P6#!9,%HP6S!<,%TP7C!?,&`P83!B,&,P9#!E,&8P
M9S!H,&DP:C!K,&PP;3!N,&\P<#!Q,'(P<S!T,'4P=C!W,'@P>3!Z,'LP?#!]
M,'XP?S"`,($P@C"#,(0PA3"&,(<PB#"),(HPBS",,(TPCC"/,)`PD3"2,),P
M```````````````````````````````````0_Q'_$O\3_Q3_%?\6_Q?_&/\9
M_P``````````````````(?\B_R/_)/\E_R;_)_\H_RG_*O\K_RS_+?\N_R__
M,/\Q_S+_,_\T_S7_-O\W_SC_.?\Z_P```````````````$'_0O]#_T3_1?]&
M_T?_2/])_TK_2_],_TW_3O]/_U#_4?]2_U/_5/]5_U;_5_]8_UG_6O\`````
M````````QB6A):`ELR6R);TEO"4[(!(PDB&0(9$ADR$3,```````````````
M```````````````((@LBAB*'(H(B@R(J(BDB`````````````````````"<B
M*"*L`-(AU"$`(@,B`````````````````````````````"`BI2(2(P(B!R)A
M(E(B:B)K(AHB/2(=(C4B*R(L(@``````````````````*R$P(&\F;29J)B`@
M(2"V````````````[R4``````#`!,`(P#/\.__LP&O\;_Q__`?^;,)PPM`!`
M_Z@`/O_C_S___3#^,)TPGC`#,-U.!3`&,`<P_#`5(!`@#_]<`!PP%B!<_R8@
M)2`8(!D@'"`=(`C_"?\4,!4P._\]_UO_7?\(,`DP"C`+,`PP#3`.,`\P$#`1
M,`O_$B*Q`-<`]P`=_V`B'/\>_V8B9R(>(C0B0B9`)K``,B`S(`,AY?\$_Z(`
MHP`%_P/_!O\*_R#_IP`&)@4FRR7/)<XEQR4````````!``(``P`$``4`!@`'
M``@`"0`*``L`#``-``X`#P`0`!$`$@`3`!0`%0`6`!<`&``9`!H`&P`<`!T`
M'@`?`"``(0`B`",`)``E`"8`)P`H`"D`*@`K`"P`+0`N`"\`,``Q`#(`,P`T
M`#4`-@`W`#@`.0`Z`#L`/``]`#X`/P!``$$`0@!#`$0`10!&`$<`2`!)`$H`
M2P!,`$T`3@!/`%``40!2`%,`5`!5`%8`5P!8`%D`6@!;`*4`70!>`%\`8`!A
M`&(`8P!D`&4`9@!G`&@`:0!J`&L`;`!M`&X`;P!P`'$`<@!S`'0`=0!V`'<`
M>`!Y`'H`>P!\`'T`/B``````````````````````````````````````````
M`````````````````````````````````````````````````&'_8O]C_V3_
M9?]F_V?_:/]I_VK_:_]L_VW_;O]O_W#_<?]R_W/_=/]U_W;_=_]X_WG_>O][
M_WS_??]^_W__@/^!_X+_@_^$_X7_AO^'_XC_B?^*_XO_C/^-_X[_C_^0_Y'_
MDO^3_Y3_E?^6_Y?_F/^9_YK_F_^<_YW_GO^?_P``````````````````````
M````````````````````````````````````````````````````````````
M``#XGO^>`I\#GPF?#Y\0GQ&?$I\4GQ:?%Y\9GQJ?&Y\?GR*?)I\JGRN?+Y\Q
MGS*?-)\WGSF?.I\\GSV?/Y]!GT.?1)]%GT:?1Y]3GU6?5I]7GUB?6I]=GUZ?
M:)]IGVV?;I]OGW"?<9]SGW6?>I]]GX^?D)^1GY*?E)^6GY>?GI^AGZ*?HY^E
MGP``````````````````````````````````?)U^G8.=A)V&G8J=C9V.G9*=
MDYV5G9:=EYV8G:&=JIVLG:Z=L9VUG;F=O)V_G<.=QYW)G<J=U)W5G=:=UYW:
MG=Z=WYW@G>6=YYWIG>N=[IWPG?.=])W^G0J>`IX'G@Z>$)X1GA*>%9X6GAF>
M')X=GGJ>>YY\GH">@IZ#GH2>A9Z'GHZ>CYZ6GIB>FYZ>GJ2>J)ZLGJZ>KYZP
MGK.>M)ZUGL:>R)[+GM6>WY[DGN>>[)[MGNZ>\)[QGO*>]9X`````^9OZF_V;
M_YL`G`*<"YP/G!&<%IP8G!F<&IP<G!Z<(IPCG":<)YPHG"F<*IPQG#6<-IPW
MG#V<09Q#G$2<19Q)G$J<3IQ/G%"<4YQ4G%:<6)Q;G%V<7IQ?G&.<:9QJG%R<
M:YQHG&Z<<)QRG'6<=YQ[G.:<\ISWG/F<"YT"G1&=%YT8G1R='9T>G2^=,)TR
MG3.=-)TZG3R=19T]G4*=0YU'G4J=4YU4G5^=8YUBG66=:9UJG6N=<)UVG7>=
M>YT`````!)L%FPB;"9L+FPR;#9L.FQ";$IL6FQF;&YL<FR";)ILKFRV;,YLT
MFS6;-YLYFSJ;/9M(FTN;3)M5FU:;5YM;FUZ;89MCFV6;9IMHFVJ;:YMLFVV;
M;IMSFW6;=YMXFWF;?YN`FX2;A9N&FX>;B9N*FXN;C9N/FY";E)N:FYV;GINF
MFZ>;J9NLF[";L9NRF[>;N)N[F[R;OIN_F\&;QYO(F\Z;T)O7F]B;W9O?F^6;
MYYOJF^N;[YOSF_>;^)L`````N9FZF;V9OYG#F<F9TYG4F=F9VIG<F=Z9YYGJ
MF>N9[)GPF?29]9GYF?V9_ID"F@.:!)H+F@R:$)H1FA::'IH@FB*:(YHDFB>:
M+9HNFC.:-9HVFCB:1YI!FD2:2II+FDR:3II1FE2:5II=FJJ:K)JNFJ^:LIJT
MFK6:MIJYFKN:OIJ_FL&:PYK&FLB:SIK0FM*:U9K6FM>:VYK<FN":Y)KEFN>:
MZ9KLFO*:\YKUFOF:^IK]FO^:`)L!FP*;`YL`````*Y@NF"^8,)@RF#.8-9@E
MF#Z81)A'F$J849A2F%.85IA7F%F86IABF&.899AFF&J8;)BKF*V8KIBPF+28
MMYBXF+J8NYB_F,*8Q9C(F,R8X9CCF.68YICGF.J8\YCVF`*9!YD(F1&9%9D6
MF1>9&ID;F1R9'YDBF2:9)YDKF3&9,IDSF329-9DYF3J9.YD\F4"909E&F4>9
M2)E-F4Z95)E8F5F96YE<F5Z97YE@F9N9G9F?F::9L)FQF;*9M9D``````Y<%
MEPF7&I<;EQV7(9<BER.7*)<QES.709=#ETJ73I=/EU675Y=8EUJ76Y=CEV>7
M:I=NEW.7=I=WEWB7>Y=]EW^7@)>)EY67EI>7EYF7FI>>EY^7HI>LEZZ7L9>R
ME[67MI>XE[F7NI>\E[Z7OY?!E\27Q9?'E\F7RI?,E\V7SI?0E]&7U)?7E]B7
MV9?=E]Z7X)?;E^&7Y)?OE_&7])?WE_B7^I<'F`J8&9@-F`Z8%)@6F!R8'I@@
MF".8)I@`````?I6$E8B5C)6-E8Z5G96>E9^5H96FE:F5JY6LE;25MI6ZE;V5
MOY7&E<B5R97+E="5T972E=.5V97:E=V5WI7?E>"5Y)7FE1V6'I8BEB26)98F
MEBR6,98SEC>6.)8YECJ6/)8]ED&64I94EE:65Y98EF&6;I9TEGN6?)9^EG^6
M@9:"EH.6A):)EI&6EI::EIV6GY:DEJ66II:IEJZ6KY:SEKJ6RI;2EK)=V);:
MEMV6WI;?ENF6[Y;QEOJ6`I<`````>I-]DW^3@).!DX*3B).*DXN3C9./DY*3
ME9.8DYN3GI.ADZ.3I).FDZB3JY.TD[63MI.ZDZF3P9/$D\63QI/'D\F3RI/+
MD\R3S9/3D]F3W)/>D]^3XI/FD^>3^9/WD_B3^I/[D_V3`90"E`24")0)E`V4
M#I0/E!64%I07E!^4+I0OE#&4,I0SE#24.Y0_E#V40Y1%E$B42I1,E%64691<
ME%^4891CE&B4:Y1ME&Z4;Y1QE'*4A)2#E'B5>94`````F9*?DJ"2I)*EDJ>2
MJ)*KDJ^2LI*VDKB2NI*[DKR2O9*_DL"2P9+"DL.2Q9+&DL>2R)++DLR2S9+.
MDM"2TY+5DM>2V)+9DMR2W9+?DN"2X9+CDN62YY+HDNR2[I+PDOF2^Y+_D@"3
M`I,(DPV3$9,4DQ63'),=DQZ3'Y,ADR23)9,GDRF3*I,SDS23-I,WDT>32)-)
MDU"349-2DU635Y-8DUJ37I-DDV639Y-IDVJ3;9-ODW"3<9-SDW23=I,`````
MPI'#D<61TY'4D=>1V9':D=Z1Y)'ED>F1ZI'LD>V1[I'OD?"1\9'WD?F1^Y']
MD0"2`9($D@62!I('D@F2"I(,DA"2$I(3DA:2&)(<DAV2(Y(DDB62)I(HDBZ2
M+Y(PDC.2-9(VDCB2.9(ZDCR2/I)`DD*20Y)&DD>22I)-DDZ23Y)1DEB269)<
MDEV28))ADF629Y)HDFF2;I)ODG"2=9)VDG>2>))YDGN2?))]DG^2B)*)DHJ2
MC9*.DI*2EY(`````Q)#%D,>0R)#5D->0V)#9D-R0W9#?D.60TI#VD.N0[Y#P
MD/20_I#_D`"1!)$%D0:1")$-D1"1%)$6D1>1&)$:D1R1'I$@D261(I$CD2>1
M*9$ND2^1,9$TD3:1-Y$YD3J1/)$]D4.11Y%(D4^14Y%7D5F16I%;D6&19)%G
MD6V1=)%YD7J1>Y&!D8.1A9&&D8J1CI&1D9.1E)&5D9B1GI&AD::1J)&LD:V1
MKI&PD;&1LI&SD;:1NY&\D;V1OY$`````0X]'CT^/48]2CU./5(]5CUB/78]>
MCV6/G8^@CZ&/I(^ECZ:/M8^VC[B/OH_`C\&/QH_*C\N/S8_0C]*/TX_5C^"/
MXX_DC^B/[H_QC_6/]H_[C_Z/`I`$D`B0#)`8D!N0*)`ID"^0*I`LD"V0,Y`T
MD#>0/Y!#D$203)!;D%V08I!FD&>0;)!PD'20>9"%D(B0BY",D(Z0D)"5D)>0
MF)"9D)N0H)"AD**0I9"PD+*0LY"TD+:0O9#,D+Z0PY``````(XXFCB>.,8XS
MCC:.-XXXCCF./8Y`CD&.2XY-CDZ.3XY4CEN.7(Y=CEZ.88YBCFF.;(YMCF^.
M<(YQCGF.>HY[CH*.@XZ)CI".DHZ5CIJ.FXZ=CIZ.HHZGCJF.K8ZNCK..M8ZZ
MCKN.P([!CL..Q(['CL^.T8[4CMR.Z([NCO".\8[WCOF.^H[MC@"/`H\'CPB/
M#X\0CQ:/%X\8CQZ/((\ACR./)8\GCRB/+(\MCRZ/-(\UCS:/-X\ZCT"/08\`
M````AXR+C)",DHR3C)F,FXR<C*2,N8RZC,6,QHS)C,N,SXS6C-6,V8S=C.&,
MZ(SLC.^,\(SRC/6,]XSXC/Z,_XP!C0.-"8T2C1>-&XUEC6F-;(UNC7^-@HV$
MC8B-C8V0C9&-E8V>C9^-H(VFC:N-K(VOC;*-M8VWC;F-NXW`C<6-QHW'C<B-
MRHW.C=&-U(W5C=>-V8WDC>6-YXWLC?"-O(WQC?*-](W]C0&.!(X%C@:."XX1
MCA2.%HX@CB&.(HX`````MHJWBKN*OHK#BL:*R(K)BLJ*T8K3BM2*U8K7BMV*
MWXKLBO"*](KUBO:*_(K_B@6+!HL+BQ&+'(L>BQ^+"HLMBS"+-XL\BT*+0XM$
MBT6+1HM(BU*+4XM4BUF+38M>BV.+;8MVBWB+>8M\BWZ+@8N$BX6+BXN-BX^+
ME(N5BYR+GHN?BSB,.8P]C#Z,18Q'C$F,2XQ/C%&,4XQ4C%>,6(Q;C%V,68QC
MC&2,9HQHC&F,;8QSC'6,=HQ[C'Z,AHP`````>XE\B7V)B8F-B9")E(F5B9N)
MG(F?B:")I8FPB;2)M8FVB;>)O(G4B=6)UHG7B=B)Y8GIB>N)[8GQB?.)]HGY
MB?V)_XD$B@6*!XH/BA&*$HH4BA6*'HH@BB**)(HFBBN*+(HOBC6*-XH]BCZ*
M0(I#BD6*1XI)BDV*3HI3BE:*5XI8BER*78IABF6*9XIUBG:*=XIYBGJ*>XI^
MBG^*@(J#BH:*BXJ/BI"*DHJ6BI>*F8J?BJ>*J8JNBJ^*LXH`````.H@\B$&(
M0XA%B$B(28A*B$N(3HA1B%6(5HA8B%J(7(A?B&"(9(AIB'&(>8A[B("(F(B:
MB)N(G(B?B*"(J(BJB+J(O8B^B,"(RHC+B,R(S8C.B-&(THC3B-N(WHCGB.^(
M\(CQB/6(]X@!B0:)#8D.B0^)%8D6B1B)&8D:B1R)((DFB2>)*(DPB3&),HDU
MB3F).HD^B4")0HE%B4:)28E/B5*)5XE:B5N)7(EAB6*)8XEKB6Z)<(ESB76)
M>HD`````*(<NAR^',8<RASF'.H<\ASV'/H=`AT.'18=-AUB'78=AAV2'98=O
MAW&'<H=[AX.'A(>%AX:'AX>(AXF'BX>,AY"'DX>5AY>'F(>9AYZ'H(>CAZ>'
MK(>MAZZ'L8>UA[Z'OX?!A\B'R8?*A\Z'U8?6A]F'VH?<A]^'XH?CA^2'ZH?K
MA^V'\8?SA_B'^H?_AP&(`X@&B`F("H@+B!"(&8@2B!.(%(@8B!J(&X@<B!Z(
M'X@HB"V(+H@PB#*(-8@`````_X4`A@2&!88-A@Z&$(81AA*&&(89AAN&'H8A
MAB>&*88VACB&.H8\ACV&0(9"AD:&4H93AE:&5X98AEF&789@AF&&8H9CAF2&
M:89LAF^&=89VAG>&>H:-AI&&EH:8AIJ&G(:AAJ:&IX:HAJV&L8:SAK2&M8:W
MAKB&N8:_AL"&P8;#AL6&T8;2AM6&UX;:AMR&X(;CAN6&YX:(AOJ&_(;]A@2'
M!8<'APN'#H</AQ"'$X<4AQF''H<?AR&'(X<`````W(3GA.J$[X3PA/&$\H3W
MA#*%^H3[A/V$`H4#A0>%#(4.A1"%'(4>A2*%(X4DA26%)X4JA2N%+X4SA32%
M-H4_A4:%3X50A5&%4H53A5:%685<A5V%7H5?A6"%885BA62%:X5OA7F%>H5[
MA7V%?X6!A86%AH6)A8N%C(6/A9.%F(6=A9^%H(6BA:6%IX6TA;:%MX6XA;R%
MO86^A;^%PH7'A<J%RX7.A:V%V(7:A=^%X(7FA>B%[87SA?:%_(4`````?8-_
M@X"#@H.$@X:#C8.2@Y2#E8.8@YF#FX.<@YV#IH.G@ZF#K(.^@[^#P(/'@\F#
MSX/0@]&#U(/=@U.#Z(/J@_:#^(/Y@_R#`80&A`J$#X01A!6$&82M@R^$.81%
MA$>$2(1*A$V$3X11A%*$5H18A%F$6H1<A&"$9(1EA&>$:H1PA'.$=(1VA'B$
M?(1]A(&$A822A).$E82>A*:$J(2IA*J$KX2QA+2$NH2]A+Z$P(3"A,>$R(3,
MA,^$TX0`````2X).@D^"48)6@ER"8()C@F>";8)T@GN"?8)_@H""@8*#@H2"
MAX*)@HJ"CH*1@I2"EH*8@IJ"FX*@@J&"HX*D@J>"J(*I@JJ"KH*P@K*"M(*W
M@KJ"O(*^@K^"QH+0@M6"VH+@@N*"Y(+H@NJ"[8+O@O:"]X+]@OZ"`(,!@P>#
M"(,*@PN#5(,;@QV#'H,?@R&#(H,L@RV#+H,P@S.#-X,Z@SR#/8-"@T.#1(-'
M@TV#3H-1@U6#5H-7@W"#>(,`````\(#R@/.`]H#Y@/J`_H`#@0N!%H$7@1B!
M'($>@2"!)($G@2R!,($U@3J!/(%%@4>!2H%,@5*!5X%@@6&!9X%H@6F!;8%O
M@7>!@8&0@82!A8&&@8N!CH&6@9B!FX&>@:*!KH&R@;2!NX'+@<.!Q8'*@<Z!
MSX'5@=>!VX'=@=Z!X8'D@>N![('P@?&!\H'U@?:!^('Y@?V!_X$`@@."#X(3
M@A2"&8(:@AV"(8(B@BB",H(T@CJ"0X)$@D6"1H(`````<7]]?WY_?W^`?XM_
MC7^/?Y!_D7^6?Y=_G'^A?Z)_IG^J?ZU_M'^\?[]_P'_#?\A_SG_/?]M_WW_C
M?^5_Z'_L?^Y_[W_R?_I__7_^?_]_!X`(@`J`#8`.@`^`$8`3@!2`%H`=@!Z`
M'X`@@"2`)H`L@"Z`,(`T@#6`-X`Y@#J`/(`^@$"`1(!@@&2`9H!M@'&`=8"!
M@(B`CH"<@)Z`IH"G@*N`N("Y@,B`S8#/@-*`U(#5@->`V(#@@.V`[H``````
MGGVF?:=]JGVS?;9]MWVY?<)]PWW$?<5]QGW,?<U]SGW7?=E]`'[B?>5]YGWJ
M?>M][7WQ??5]]GWY??I]"'X0?A%^%7X7?AQ^'7X@?B=^*'XL?BU^+WXS?C9^
M/WY$?D5^1WY.?E!^4GY8?E]^87YB?F5^:WYN?F]^<WYX?GY^@7Z&?H=^BGZ-
M?I%^E7Z8?II^G7Z>?CQ_.W\]?SY_/W]#?T1_1W]/?U)_4W];?UQ_77]A?V-_
M9']E?V9_;7\`````87QC?&=\:7QM?&Y\<'QR?'E\?'Q]?(9\AWR/?)1\GGR@
M?*9\L'RV?+=\NGR[?+Q\OWS$?,=\R'S)?,U\SWS3?-1\U7S7?-E\VGS=?.9\
MZ7SK?/5\`WT'?0A]"7T/?1%]$GT3?19]'7T>?2-])GTJ?2U],7T\?3U]/GU`
M?4%]1WU(?4U]47U3?5=]67U:?5Q]77UE?6=]:GUP?7A]>GU[?7]]@7V"?8-]
MA7V&?8A]BWV,?8U]D7V6?9=]G7T`````,7LT>SU[/WM`>T%[1WM.>U5[8'MD
M>V9[:7MJ>VU[;WMR>W-[=WN$>XE[CGN0>Y%[EGN;>YY[H'NE>ZQ[KWNP>[)[
MM7NV>[I[NWN\>[U[PGO%>\A[RGO4>]9[UWO9>]I[VWOH>^I[\GOT>_5[^'OY
M>_I[_'O^>P%\`GP#?`1\!GP)?`M\#'P.?`]\&7P;?"!\)7PF?"A\+'PQ?#-\
M-'PV?#E\.GQ&?$I\57Q1?%)\4WQ9?%I\6WQ<?%U\7GP`````X'GB>>5YZGGK
M>>UY\7GX>?QY`GH#>@=Z"7H*>@QZ$7H5>AMZ'GHA>B=Z*WHM>B]Z,'HT>C5Z
M.'HY>CIZ1'I%>D=Z2'I,>E5Z5GI9>EQZ77I?>F!Z97IG>FIZ;7IU>GAZ?GJ`
M>H)ZA7J&>HIZBWJ0>I%ZE'J>>J!ZHWJL>K-ZM7JY>KMZO'K&>LEZS'K.>M%Z
MVWKH>NEZZWKL>O%Z]'K[>OUZ_GH'>Q1['WLC>R=[*7LJ>RM[+7LN>R][,'L`
M````NWB]>+]XQWC(>,EXS'C.>-)XTWC5>-9XY'C;>-]XX'CA>.9XZGCR>/-X
M`'GV>/=X^GC[>/]X!GD,>1!Y&GD<>1YY'WD@>25Y)WDI>2UY,7DT>35Y.WD]
M>3]Y1'E%>49Y2GE+>4]Y47E4>5AY6WE<>6=Y:7EK>7)Y>7E[>7QY?GF+>8QY
MD7F3>91YE7F6>9AYFWF<>:%YJ'FI>:MYKWFQ>;1YN'F[><)YQ'G'><AYRGG/
M>=1YUGG:>=UYWGD`````9'=G=VIW;'=P=W)W<W=T=WIW?7>`=X1WC'>-=Y1W
ME7>6=YIWGW>B=Z=WJG>N=Z]WL7>U=[YWPW?)=]%WTG?5=]EWWG??=^!WY'?F
M=^IW['?P=_%W]'?X=_MW!7@&>`EX#7@.>!%X'7@A>")X(W@M>"YX,'@U>#=X
M0WA$>$=X2'A,>$YX4GA<>%YX8'AA>&-X9'AH>&IX;GAZ>'YXBGB/>)1XF'BA
M>)UXGGB?>*1XJ'BL>*UXL'BQ>+)XLW@`````.G8\=DIV0'9!=D-V1'9%=DEV
M2W95=EEV7W9D=F5V;79N=F]V<79T=H%VA7:,=HUVE7:;=IQVG7:?=J!VHG:C
M=J1VI7:F=J=VJ':J=JUVO7;!=L5VR7;+=LQVSG;4=MEVX';F=NAV[';P=O%V
M]G;Y=OQV`'<&=PIW#G<2=Q1W%7<7=QEW&G<<=R)W*'<M=RYW+W<T=S5W-G<Y
M=SUW/G="=T5W1G=*=TUW3G=/=U)W5G=7=UQW7G=?=V!W8G<`````$G46=1=U
M('4A=21U)W4I=2IU+W4V=3EU/74^=3]U0'5#=4=U2'5.=5!U4G57=5YU7W5A
M=6]U<75Y=7IU>W5\=7UU?G6!=85UD'62=9-UE769=9QUHG6D=;1UNG6_=<!U
MP77$=<9US'7.=<]UUW7<==]UX'7A=>1UYW7L=>YU[W7Q=?EU`'8"=@-V!'8'
M=@AV"G8,=@]V$G83=A5V%G89=AMV''8==AYV(W8E=B9V*78M=C)V,W8U=CAV
M.78`````_W,`=`%T!'0'=`IT$70:=!MT)'0F="AT*70J="MT+'0M="YT+W0P
M=#%T.71`=$-T1'1&=$=T2W1-=%%T4G17=%UT8G1F=&=T:'1K=&UT;G1Q=')T
M@'2!=(5TAG2'=(ETCW20=)%TDG28=)ETFG2<=)]TH'2A=*-TIG2H=*ETJG2K
M=*YTKW2Q=+)TM72Y=+MTOW3(=,ETS'30=--TV'3:=-MTWG3?=.1TZ'3J=.MT
M[W3T=/IT^W3\=/]T!G4`````_G("<P1S!7,'<PMS#7,2<Q-S&',9<QYS(G,D
M<R=S*',L<S%S,G,U<SIS.W,]<T-S37-0<U)S5G-8<UUS7G-?<V!S9G-G<VES
M:W-L<VYS;W-Q<W=S>7-\<X!S@7.#<X5SAG..<Y!SDW.5<Y=SF'.<<YYSGW.@
M<Z)SI7.F<ZISJW.M<[5SMW.Y<[QSO7._<\5SQG/)<\MSS'//<])STW/6<]ES
MW7/A<^-SYG/G<^ES]'/U<_=S^7/Z<_MS_7,`````:'%Y<8!QA7&'<8QQDG&:
M<9MQH'&B<:]QL'&R<;-QNG&_<<!QP7'$<<MQS''3<=9QV7':<=QQ^''^<0!R
M!W((<@ER$W(7<AIR'7(?<B1R*W(O<C1R.'(Y<D%R0G)#<D5R3G)/<E!R4W)5
M<E9R6G)<<EYR8')C<FAR:W)N<F]R<7)W<GAR>W)\<G]RA'*)<HURCG*3<IMR
MJ'*M<JYRL7*T<KYRP7+'<LERS'+5<M9RV'+?<N5R\W+T<OIR^W(`````VF_>
M;^AOZ6_P;_5O^6_\;_UO`'`%<`9P!W`-<!=P('`C<"]P-'`W<#EP/'!#<$1P
M2'!)<$IP2W!4<%5P77!><$YP9'!E<&QP;G!U<'9P?G"!<(5PAG"4<)5PEG"7
M<)APFW"D<*MPL'"Q<+1PMW#*<-%PTW#4<-5PUG#8<-QPY'#Z<`-Q!'$%<09Q
M!W$+<0QQ#W$><2!Q*W$M<2]Q,'$Q<3AQ07%%<49Q1W%*<4MQ4'%2<5=Q6G%<
M<5YQ8'$`````8FYC;FAN<VY[;GUNC6Z3;IENH&ZG;JUNKFZQ;K-NNVZ_;L!N
MP6[#;L=NR&[*;LUNSF[/;NMN[6[N;OEN^V[];@1O"&\*;PQO#6\6;QAO&F\;
M;R9O*6\J;R]O,&\S;S9O.V\\;RUO3V]1;U)O4V]7;UEO6F]=;UYO86]B;VAO
M;&]];WYO@V^';XAOBV^,;XUOD&^2;Y-OE&^6;YIOGV^@;Z5OIF^G;ZAOKF^O
M;[!OM6^V;[QOQ6_';\AORF\`````VFS<;.!LYVSI;.ML[&SN;/)L]&P$;0=M
M"FT.;0]M$6T3;1IM)FTG;2AM9VPN;2]M,6TY;3QM/VU7;5YM7VUA;65M9VUO
M;7!M?&V";8=MD6V2;91MEFV7;9AMJFVL;;1MMVVY;;UMOVW$;<AMRFW.;<]M
MUFW;;=UMWVW@;>)MY6WI;>]M\&WT;?9M_&T`;@1N'FXB;B=N,FXV;CEN.VX\
M;D1N16Y(;DEN2VY/;E%N4FY3;E1N5VY<;EUN7FX`````?FN":X5KEVN;:Y]K
MH&NB:Z-KJ&NI:ZQKK6NN:[!KN&NY:[UKOFO#:\1KR6O,:]9KVFOA:^-KYFOG
M:^YK\6OW:_EK_VL";`1L!6P);`UL#FP0;!)L&6P?;"9L)VPH;"QL+FPS;#5L
M-FPZ;#ML/VQ*;$ML36Q/;%)L5&Q9;%ML7&QK;&UL;VQT;'9L>&QY;'MLA6R&
M;(=LB6R4;)5LEVR8;)QLGVRP;+)LM&S";,9LS6S/;-!LT6S2;-1LUFP`````
M-&HW:CMJ/FH_:D5J1FI):DIJ3FI0:E%J4FI5:E9J6VID:F=J:FIQ:G-J?FJ!
M:H-JAFJ':HEJBVJ1:IMJG6J>:I]JI6JK:J]JL&JQ:K1JO6J^:K]JQFK):LAJ
MS&K0:M1JU6K6:MQJW6KD:N=J[&KP:O%J\FK\:OUJ`FL#:P9K!VL):P]K$&L1
M:Q=K&VL>:R1K*&LK:RQK+VLU:S9K.VL_:T9K2FM-:U)K5FM8:UUK8&MG:VMK
M;FMP:W5K?6L`````T&C1:--HUFC9:-QHW6CE:.AHZFCK:.QH[6CP:/%H]6CV
M:/MH_&C]:`9I"6D*:1!I$6D3:19I%VDQ:3-I-6DX:3MI0FE%:4EI3FE7:5MI
M8VED:65I9FEH:6EI;&EP:7%I<FEZ:7MI?VF`:8UIDFF6:9AIH6FE::9IJ&FK
M::UIKVFW:;AINFF\:<5IR&G1:=9IUVGB:>5I[FGO:?%I\VGU:?YI`&H!:@-J
M#VH1:A5J&FH=:B!J)&HH:C!J,FH`````9F=L9VYG=&=V9WMG@6>$9XYGCV>1
M9Y-GEF>89YEGFV>P9[%GLF>U9[MGO&>]9_EGP&?"9\-GQ6?(9\EGTF?79]EG
MW&?A9^9G\&?R9_9G]V=2:!1H&6@=:!]H*&@G:"QH+6@O:#!H,6@S:#MH/VA$
M:$5H2FA,:%5H5VA8:%MH:VAN:&]H<&AQ:')H=6AY:'IH>VA\:()HA&B&:(AH
MEFB8:)IHG&BA:*-HI6BI:*IHKFBR:+MHQ6C(:,QHSV@`````'F8A9B)F(V8D
M9B9F*68J9BMF+&8N9C!F,68S9CEF-V9`9D5F1F9*9DQF469.9E=F6&999EMF
M7&9@9F%F^V9J9FMF;&9^9G-F=69_9G=F>&9Y9GMF@&9\9HMFC&:-9I!FDF:9
M9IIFFV:<9I]FH&:D9JUFL6:R9K5FNV:_9L!FPF;#9LAFS&;.9L]FU&;;9M]F
MZ&;K9NQF[F;Z9@5G!V<.9Q-G&6<<9R!G(F<S9SYG16='9TAG3&=49U5G76<`
M````Q&3)9,IDRV3,9,YDT&319-5DUV3D9.5DZ63J9.UD\&3U9/=D^V3_9`%E
M!&4(90EE"F4/91-E%&4691EE&V4>91]E(F4F92EE+F4Q93IE/&4]94-E1V5)
M95!E4F5495]E8&5G96ME>F5]98%EA66*99)EE66899UEH&6C9:9EKF6R9;-E
MM&6_9<)ER&7)9<YET&749=9EV&7?9?!E\F7T9?5E^67^9?]E`&8$9@AF"68-
M9A%F$F859A9F'68`````>&-\8WUC?V."8X1CAV.*8Y!CE&.58YECFF.>8Z1C
MIF.M8ZYCKV.]8\%CQ6/(8\YCT6/38]1CU6/<8^!CY6/J8^QC\F/S8_5C^&/Y
M8PED"F009!)D%&089!YD(&0B9"1D)60I9"ID+V0P9#5D/60_9$MD3V119%)D
M4V149%ID6V1<9%UD7V1@9&%D8V1M9'-D=&1[9'UDA62'9(]DD&219)ADF62;
M9)UDGV2A9*-DIF2H9*QDLV2]9+YDOV0`````[&'M8>]A`6(#8@1B!V(38A5B
M'&(@8B)B(V(G8BEB*V(Y8CUB0F)#8D1B1F),8E!B46)28E1B5F):8EQB9&)M
M8F]B<V)Z8GUBC6*.8H]BD&*F8JABLV*V8K=BNF*^8K]BQ&+.8M5BUF+:8NIB
M\F+T8OQB_6(#8P1C"F,+8PUC$&,38Q9C&&,I8RIC+6,U8S9C.6,\8T%C0F-#
M8T1C1F-*8TMC3F-28U-C5&-88UMC96-F8VQC;6-Q8W1C=6,`````NV"^8,)@
MQ&#(8,E@RF#+8,Y@SV#48-5@V6#;8-U@WF#B8.5@\F#U8/A@_&#]8`)A!V$*
M80QA$&$181)A$V$4819A%V$981QA'F$B82IA*V$P83%A-6$V83=A.6%!845A
M1F%)85YA8&%L87)A>&%[87QA?V&`88%A@V&$88MAC6&289-AEV&889QAG6&?
M8:!AI6&H8:IAK6&X8;EAO&'`8<%APF'.8<]AU6'<8=UAWF'?8>%AXF'G8>EA
MY6$`````;U]R7W1?=5]X7WI??5]^7XE?C5^/7Y9?G%^=7Z)?IU^K7Z1?K%^O
M7[!?L5^X7\1?QU_(7\E?RU_07]%?TE_37]1?WE_A7^)?Z%_I7^I?[%_M7^Y?
M[U_R7_-?]E_Z7_Q?!V`*8`U@$V`48!=@&&`:8!]@)&`M8#-@-6!`8$=@2&!)
M8$Q@46!48%9@5V!=8&%@9V!Q8'Y@?V""8(9@B&"*8(Y@D6"38)5@F&"=8)Y@
MHF"D8*5@J&"P8+%@MV``````Z5WX7?E=`%X'7@U>$EX47A5>&%X?7B!>+EXH
M7C)>-5X^7DM>4%Y)7E%>5EY87EM>7%Y>7FA>:EYK7FQ>;5YN7G!>@%Z+7HY>
MHEZD7J5>J%ZJ7JQ>L5ZS7KU>OEZ_7L9>S%[+7LY>T5[27M1>U5[<7MY>Y5[K
M7@)?!E\'7PA?#E\97QQ?'5\A7R)?(U\D7RA?*U\L7RY?,%\T7S9?.U\]7S]?
M0%]$7T5?1U]-7U!?5%]87UM?8%]C7V1?9U\`````;5QP7'1<=5QZ7'M<?%Q]
M7(=<B%R*7(]<DER=7)]<H%RB7*-<IERJ7+)<M%RU7+I<R5S+7-)<W5S77.Y<
M\5SR7/1<`5T&70U=$ETK72-=)%TF72==,5TT73E=/5T_74)=0UU&74A=55U1
M75E=2EU?76!=85UB761=:EUM77!=>5UZ77Y=?UV!78-=B%V*79)=DUV4795=
MF5V;79]=H%VG7:M=L%VT7;A=N5W#7<==RUW07<Y=V%W97>!=Y%T`````Q%K&
M6LA:SUK:6MQ:X%KE6NI:[EKU6O9:_5H`6P%;"%L76S1;&5L;6QU;(5LE6RU;
M.%M!6TM;3%M26U9;7EMH6VY;;UM\6WU;?EM_6X%;A%N&6XI;CEN06Y%;DUN4
M6Y9;J%NI6ZQ;K5NO6[%;LENW6[I;O%O`6\%;S5O/6]9;UUO86]E;VEO@6^];
M\5OT6_U;#%P77!Y<'UPC7"9<*5PK7"Q<+EPP7#)<-5PV7%E<6EQ<7&)<8UQG
M7&A<:5P`````;UER6759=EEY67M9?%F+68Q9CEF26959EUF?6:19IUFM6:Y9
MKUFP6;-9MUFZ6;Q9P5G#6<19R%G*6<U9TEG=6=Y9WUGC6>19YUGN6>]9\5GR
M6?19]UD`6@1:#%H-6@Y:$EH36AY:(UHD6B=:*%HJ6BU:,%I$6D5:1UI(6DQ:
M4%I56EY:8UIE6F=:;5IW6GI:>UI^6HM:D%J36I9:F5J<6IY:GUJ@6J):IUJL
M6K%:LEJS6K5:N%JZ6KM:OUH`````#%@-6!M8'E@?6"!8)E@G6"U8,E@Y6#]8
M25A,6$U83UA06%587UAA6&189UAH6'A8?%A_6(!8@5B'6(A8B5B*6(Q8C5B/
M6)!8E%B66)U8H%BA6*)8IEBI6+%8LEC$6+Q8PEC(6,U8SEC06-)8U%C66-I8
MW5CA6.)8Z5CS6`59!ED+60Q9$ED36119088=62%9(UDD62A9+UDP63-9-5DV
M63]90UE&65)94UE965M975E>65]985EC66M9;5D`````]E;W5@%7`E<'5PI7
M#%<15Q57&E<;5QU7(%<B5R-7)%<E5RE7*E<L5RY7+U<S5S17/5<^5S]715=&
M5TQ735=25V)795=G5VA7:U=M5VY7;U=P5W%7<U=T5W57=U=Y5WI7>U=\5WY7
M@5>#5XQ7E%>75YE7FE><5YU7GE>?5Z%7E5>G5ZA7J5>L5[A7O5?'5\A7S%?/
M5]57W5?>5^17YE?G5^E7[5?P5_57]E?X5_U7_E?_5P-8!%@(6`E8X5<`````
MTU775=A5VU7>5>)5Z57V5?]5!58(5@I6#58.5@]6$%815A)6&58L5C!6,U8U
M5C=6.58[5CQ6/58_5D!6059#5D161E9)5DM6359/5E167E9@5F%68E9C5F96
M:59M5F]6<59R5G56A%:%5HA6BU:,5I56F5::5IU6GE:?5J96IU:H5JE6JU:L
M5JU6L5:S5K=6OE;%5LE6RE;+5L]6T%;,5LU6V5;<5MU6WU;A5N16Y5;F5N=6
MZ%;Q5NM6[58`````@52#5(54B%2)5(U4D5255)94G%2?5*%4IE2G5*E4JE2M
M5*Y4L52W5+E4NE2[5+]4QE3*5,U4SE3@5.I4[%3O5/94_%3^5/]4`%4!5055
M"%4)50Q5#54.5155*E4K53)5-54V53M5/%4]54%51U5)54I5355055%56%5:
M55M57E5@56%59%5F57]5@56"5895B%6.58]5D56259-5E%675:-5I%6M5;)5
MOU7!5<-5QE7)5<M5S%7.5=%5TE4`````#%,14Q-3&%,;4QQ3'E,?4R53)U,H
M4RE3*U,L4RU3,%,R4S53/%,]4SY30E-,4TM365-;4V%38U-E4VQ3;5-R4WE3
M?E.#4X=3B%..4Y-3E%.94YU3H5.D4ZI3JU.O4[)3M%.U4[=3N%.Z4[U3P%/%
M4\]3TE/34]53VE/=4]Y3X%/F4^=3]5,"5!-4&E0A5"=4*%0J5"]4,50T5#54
M0U1$5$=4351/5%Y48E1D5&949U1I5&M4;51N5'14?U0`````R%'/4=%1TE'3
M4=51V%'>4>)1Y5'N4?)1\U'T4?=1`5("4@52$E(34A52%E(84B)2*%(Q4C)2
M-5(\4D5225)54E=26%):4EQ27U)@4F%29E)N4G=2>%)Y4H!2@E*%4HI2C%*3
M4I52EE*74IA2FE*<4J12I5*F4J=2KU*P4K92MU*X4KI2NU*]4L!2Q%+&4LA2
MS%+/4M%2U%+64MM2W%+A4N52Z%+I4NI2[%+P4O%2]%+V4O=2`%,#4PI3"U,`
M````DE"34)10EE";4)Q0GE"?4*!0H5"B4*I0KU"P4+E0NE"]4,!0PU#$4,=0
MS%#.4-!0TU#44-A0W%#=4-]0XE#D4.90Z%#I4.]0\5#V4/I0_E`#4091!U$(
M40M1#%$-40Y1\E`041=1&5$;41Q1'5$>42-1)U$H42Q1+5$O43%1,U$T4351
M.%$Y44)12E%/45-155%745A17U%D4691?E&#4811BU&.49A1G5&A4:-1K5&X
M4;I1O%&^4;]1PE$`````A4^)3XI/C$^.3Y!/DD^33Y1/ET^93YI/GD^?3[)/
MMT^Y3[M/O$^]3[Y/P$_!3\5/QD_(3\E/RT_,3\U/ST_23]Q/X$_B3_!/\D_\
M3_U/_T\`4`%0!%`'4`I0#%`.4!!0$U`74!A0&U`<4!U0'E`B4"=0+E`P4#)0
M,U`U4$!005!"4$501E!*4$Q03E!14%)04U!74%E07U!@4&)08U!F4&=0:E!M
M4'!0<5`[4(%0@U"$4(90BE".4(]0D%```````DX$3@5.#$X23A].(TXD3BA.
M*TXN3B].,$XU3D!.04Y$3D=.44Y:3EQ.8TYH3FE.=$YU3GE.?TZ-3I9.ETZ=
M3J].N4[#3M!.VD[;3N!.X4[B3NA.[T[Q3O-.]4[]3OY._TX`3P)/`T\(3PM/
M#$\23Q5/%D\73QE/+D\Q3V!/,T\U3S=/.4\[3SY/0$]"3TA/24]+3TQ/4D]4
M3U9/6$]?3V-/:D]L3VY/<4]W3WA/>4]Z3WU/?D^!3X)/A$\`````X0#@`.0`
MX@`#`<X!`0$%`>4`XP`'`0D!#0'G``L!#P'I`.@`ZP#J`!L!%P$3`1D!]0$=
M`1\!```A`24![0#L`.\`[@#0`0``*P$O`2D!-0$W`3H!/@$\`40!2`%&`?$`
M\P#R`/8`]`#2`5$!30'U`%4!60%7`5L!70%A`5\!90%C`?H`^0#\`/L`;0'4
M`7$!:P%S`6\!:0'8`=P!V@'6`74!_0#_`'<!>@%^`7P!````````````````
M````````P0#``,0`P@`"`<T!``$$`<4`PP`&`0@!#`''``H!#@')`,@`RP#*
M`!H!%@$2`1@!```<`1X!(@$@`20!S0#,`,\`S@#/`3`!*@$N`2@!-`$V`3D!
M/0$[`4,!1P%%`=$`TP#2`-8`U`#1`5`!3`'5`%0!6`%6`5H!7`%@`5X!9`%B
M`=H`V0#<`-L`;`'3`7`!:@%R`6X!:`'7`=L!V0'5`70!W0!X`78!>0%]`7L!
M````````````````````````Q@`0`0``)@$``#(!``!!`3\!``!*`=@`4@$`
M`&8!W@```````````````````````````````````````````.8`$0'P`"<!
M,0$S`3@!0@%``4D!2P'X`%,!WP!G`?X`4@13!%0$5016!%<$6`19!%H$6P1<
M!%X$7P0"!`,$!`0%!`8$!P0(!`D$"@0+!`P$#@0/!````````````````(8#
MB`.)`XH#J@,``(P#``".`ZL#``"/`P``````````K`.M`ZX#KP/*`Y`#S`/"
M`\T#RP.P`\X#N@"J`*D`K@`B(:0`%B$`````````````````````````````
M`````-@"QP*X`-D"W0*O`-L"V@)^`(0#A0,`````````````````````H0"F
M`+\```````````````````````````#0``````````````#!````Y!@9"+D9
M&0CT^A@(8!P9"`#J(P@`````````````````````````````````````````
M```````(`````0````,````)`/__`/X<""#Q(P@`("`@("`@("`@*"@H*"@@
M("`@("`@("`@("`@("`@("!($!`0$!`0$!`0$!`0$!`0A(2$A(2$A(2$A!`0
M$!`0$!"!@8&!@8$!`0$!`0$!`0$!`0$!`0$!`0$!`1`0$!`0$(*"@H*"@@("
M`@("`@("`@("`@("`@("`@("$!`0$"`#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#`P,#
M`P,#`P,#`P,#`P,#`P,#````````````````````````````````````````
M``#/``````````````#!````Y!@9",D9&0CT^A@(L!\9"`#J(P@`````````
M```````````````````````````````````````(`````0````,````)`/__
M`/X<""#Q(PC.``````````````#!````Y!@9"-<9&0CT^A@(X!\9"`#J(P@`
M```````````````````````````````````````````````(`````0````,`
M```)`/__`/X<""#Q(PC-``````````````#!````Y!@9".@9&0CT^A@(0"`9
M"`#J(P@````````````````````````````````````````````````(````
M`0````,````)`/__`/X<""#Q(PC,``````````````#!````Y!@9"/<9&0CT
M^A@(X"`9"`#J(P@`````````````````````````````````````````````
M```(`````0````,````)`/__`/X<""#Q(PC+``````````````#!````Y!@9
M"`H:&0CT^A@(@"$9"`#J(P@`````````````````````````````````````
M```````````(`````0````,````)`/__`/X<""#Q(PC*``````````````#!
M````Y!@9"!D:&0CT^A@(8"(9"`#J(P@`````````````````````````````
M```````````````````(`````0````,````)`/__`/X<""#Q(PC)````````
M``````#!````Y!@9""<:&0CT^A@(X"(9"`#J(P@`````````````````````
M```````````````````````````(`````0````,````)`/__`/X<""#Q(PC(
M``````````````#!````Y!@9"#<:&0CT^A@(@",9"`#J(P@`````````````
M```````````````````````````````````(`````0````,````)`/__`/X<
M""#Q(PC'``````````````#!````Y!@9"$<:&0CT^A@(`R09"`#J(P@`````
M```````````````````````````````````````````(`````0````,````)
M`/__`/X<""#Q(PC&``````````````#!````Y!@9"%<:&0CT^A@(("09"`#J
M(P@````````````````````````````````````````````````(`````0``
M``,````)`/__`/X<""#Q(PC%``````````````#!````Y!@9"&@:&0CT^A@(
MP"09"`#J(P@````````````````````````````````````````````````(
M`````0````,````)`/__`/X<""#Q(PC$``````````````#!````Y!@9"'<:
M&0CT^A@(H"49"`#J(P@`````````````````````````````````````````
M```````(`````0````,````)`/__`/X<""#Q(PC#``````````````#!````
MY!@9"(D:&0CT^A@(`"89"`#J(P@`````````````````````````````````
M```````````````(`````0````,````)`/__`/X<""#Q(PC"````````````
M``#!````Y!@9")H:&0CT^A@(H"89"`#J(P@`````````````````````````
M```````````````````````(`````0````,````)`/__`/X<""#Q(PC!````
M``````````#!````Y!@9"*H:&0CT^A@(@"<9"`#J(P@`````````````````
M```````````````````````````````(`````0````,````)`/__`/X<""#Q
M(PC```````````````#!````Y!@9"+P:&0CT^A@(]/H8"`#J(P@`````````
M``#\(P@``````/@C"``````````````````````(`````0````,````)`/__
M`/X<""#Q(PA4#0@(^!<("'`8"`@X&0@(4+`("%0)"`@`````S*T("*`8"`@`
M````````````````````````````````````D```````````````P0```&80
M&0C,&AD(]/H8"&`<&0@`````````````````````````````````````````
M````````````"`````(````"````"0#__T!)'0C`]R,(CP``````````````
MP0```&80&0C<&AD(]/H8"+`?&0@`````````````````````````````````
M````````````````````"`````(````"````"0#__T!)'0C`]R,(C@``````
M````````P0```&80&0CJ&AD(]/H8".`?&0@`````````````````````````
M````````````````````````````"`````(````"````"0#__T!)'0C`]R,(
MC0``````````````P0```&80&0C[&AD(]/H8"$`@&0@`````````````````
M````````````````````````````````````"`````(````"````"0#__T!)
M'0C`]R,(C```````````````P0```&80&0@*&QD(]/H8".`@&0@`````````
M````````````````````````````````````````````"`````(````"````
M"0#__T!)'0C`]R,(BP``````````````P0```&80&0@=&QD(]/H8"(`A&0@`
M````````````````````````````````````````````````````"`````(`
M```"````"0#__T!)'0C`]R,(B@``````````````P0```&80&0@L&QD(]/H8
M"&`B&0@`````````````````````````````````````````````````````
M"`````(````"````"0#__T!)'0C`]R,(B0``````````````P0```&80&0@Z
M&QD(]/H8".`B&0@`````````````````````````````````````````````
M````````"`````(````"````"0#__T!)'0C`]R,(B```````````````P0``
M`&80&0A*&QD(]/H8"(`C&0@`````````````````````````````````````
M````````````````"`````(````"````"0#__T!)'0C`]R,(AP``````````
M````P0```&80&0A:&QD(]/H8"`,D&0@`````````````````````````````
M````````````````````````"`````(````"````"0#__T!)'0C`]R,(A@``
M````````````P0```&80&0AJ&QD(]/H8""`D&0@`````````````````````
M````````````````````````````````"`````(````"````"0#__T!)'0C`
M]R,(A0``````````````P0```&80&0A[&QD(]/H8",`D&0@`````````````
M````````````````````````````````````````"`````(````"````"0#_
M_T!)'0C`]R,(A```````````````P0```&80&0B*&QD(]/H8"*`E&0@`````
M````````````````````````````````````````````````"`````(````"
M````"0#__T!)'0C`]R,(@P``````````````P0```&80&0B<&QD(]/H8"``F
M&0@`````````````````````````````````````````````````````"```
M``(````"````"0#__T!)'0C`]R,(@@``````````````P0```&80&0BM&QD(
M]/H8"*`F&0@`````````````````````````````````````````````````
M````"`````(````"````"0#__T!)'0C`]R,(@0``````````````P0```&80
M&0B]&QD(]/H8"(`G&0@`````````````````````````````````````````
M````````````"`````(````"````"0#__T!)'0C`]R,(@```````````````
MP0```&80&0C/&QD(]/H8"/3Z&`@`````````````````_",(``````#X(P@`
M````````````````````"`````(````"````"0#__T!)'0C`]R,(5`T(",P9
M"`A$&@@(#!L("*S*!PA4"0@(`````,RM"`AT&@@(````````````````````
M``````````````````"!)0@`>R4(`'4E"`!M)0@`9R4(`&$E"`!;)0@`524(
M``````!/)0@`224(`$,E"``])0@`-R4(`#$E"``K)0@`)24(`!\E"``9)0@`
M$R4(``TE"``))0@``R4(`/TD"`#W)`@`\20(`````````````````.LD"`#E
M)`@`WR0(`-4D"`#+)`@`PR0(`+TD"`"S)`@`KR0(`*DD"`"C)`@`GR0(`)LD
M"`"1)`@`BR0(````````````A20(`'\D"`!Y)`@`<R0(`&,D"`!1)`@`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$LD"```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1R0(`$,D"``_)`@`.R0(`#4D"```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````O)`@`*20(`"$D"``;)`@`"20(``,D"`#]
M(P@$`P,$`P,#`P`#`P,#`P,#`P,#`P,"`P,#`P````,#`P4%!`,%`@,#`@(%
M`P```P,#`P@)``````````````````````````````````,`````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````@("`@,`````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#`P0#"0,#P?L`_P``40(`````
M?@(`````T@(`````#PX`````TP(`````SP(`````=P(`````B`(`````B0(`
M````R`(`````*`0`````+P(`````(0(`````70(`````S`(`````*0X`````
M*@X`````*PX`````+`X`````+0X`````+@X`````+PX`````,`X`````,0X`
M````,@X`````/0(`````.@(`````+`0`````+00`````+@0`````50(`````
MQP(`````,PX`````2@X`````8`X`````;0X`````BPX`````N0X`````P0X`
M````X0X`````^PX`````$`\`````(0\`````+@\`````6P\`````9`\`````
M@@\`````IP\`````M`\`````P`\`````Z@\``````A``````'Q``````1!``
M````41``````6A``````7A``````:A``````B@(`````S@(`````BP(`````
M#P(`````&P(`````#`(`````,PX`````2@X`````8`X`````;0X`````BPX`
M````N0X`````P0X`````X0X`````^PX`````$`\`````(0\`````+@\`````
M6P\`````9`\`````@@\`````IP\`````M`\`````P`\`````Z@\``````A``
M````'Q``````1!``````41``````6A``````7A``````:A``````C`(`````
M,`0`````C0(`````,P0`````F@(`````FP(`````9@(`````L@(`````LP(`
M````-P(`````+@(`````@!X`````4AX`````4QX`````5!X`````51X`````
M5AX`````=1X`````=AX`````=QX`````8QX`````"PX`````4AX`````4QX`
M````5!X`````51X`````5AX`````5QX`````6!X`````61X`````6AX`````
M6QX`````7!X`````71X`````7AX`````7QX`````8!X`````81X`````8AX`
M````8QX`````9!X`````91X`````9AX`````9QX`````:!X`````:1X`````
M:AX`````:QX`````;!X`````;1X`````;AX`````;QX`````<!X`````<1X`
M````<AX`````<QX`````=!X`````=1X`````=AX`````=QX`````>!X`````
M>1X`````>AX`````>QX`````?!X`````?1X`````@1X`````````````````
M````O1T`````8AT`````8QT``````AX`````9!T`````!!X`````!1X`````
M91T`````9AT`````9QT`````"!X`````"1X`````"AX`````"QX`````#!X`
M````#1X`````?!T`````:!T`````:1T`````:AT`````@QT`````:QT`````
M;!T`````;1T`````;AT`````;QT`````<!T`````<1T`````<AT`````<QT`
M````=!T`````P?N__P``P?O`_P``P?O!_P``OAT`````OQT`````P!T`````
MP1T`````PAT`````PQT`````P?O(_P``P?O)_P``Q!T`````Q1T`````QAT`
M````QQT`````R!T`````R1T`````P?O0_P``P?O1_P``RAT`````RQT`````
MS!T`````S1T`````SAT`````SQT`````P?O8_P``P?O9_P``T!T`````T1T`
M````TAT`````P?O=_P``P?O>_P``P?O?_P``#@X`````$`X`````+P0`````
M$`(`````,00`````$0X`````(`X`````P?OG_P``_@4`````K@,`````L`,`
M````KP,`````L0,`````G`8`````QP8`````P?OO_P``P?OP_P``P?OQ_P``
MP?OR_P``P?OS_P``P?OT_P``P?OU_P``P?OV_P``P?OW_P``P?OX_P``````
M````````````````````Q0T`````Q@T`````P?O^_P``P?O__P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MP?L0_@``P?L1_@``P?L2_@``P?L3_@``P?L4_@``P?L5_@``P?L6_@``P?L7
M_@``P?L8_@``P?L9_@``P?L:_@``P?L;_@``P?L<_@``P?L=_@``P?L>_@``
MP?L?_@``````````````````````````````````P?LD_@``P?LE_@``P?LF
M_@``P?LG_@``P?LH_@``P?LI_@``P?LJ_@``P?LK_@``P?LL_@``P?LM_@``
MP?LN_@``P?LO_@``70)=`@``*`(`````)P(`````&P(`````&P(`````B`(`
M````B0(`````C`(`````C0(`````N`(`````N0(`````M@(`````MP(`````
ML`(`````L0(`````K@(`````KP(`````L@(`````LP(`````M`(`````M0(`
M````.`(`````.0(`````B@(`````BP(`````$0(`````$0(`````$0(`````
M$0(`````&P(`````&P(`````&P(`````+P(`````-P(`````70(`````P?M3
M_@``.@(`````/0(`````50(`````40(`````*`(`````B`(`````B0(`````
MC`(`````C0(`````N`(`````N0(`````T@(`````SP(`````R`(`````*`0`
M````(0(`````+`0`````+@0`````+00`````P?MG_@``S@(`````#PX`````
MTP(`````QP(`````P?ML_@``P?MM_@``P?MN_@``P?MO_@``````````````
M````````````````````````````P?MU_@``````````````````````````
M````````````````````````````````````````````````````````1Q,`
M````2!,`````2!,`````21,`````21,`````3!,`````3!,`````31,`````
M31,`````3Q,`````3Q,`````3Q,`````3Q,`````4!,`````4!,`````4A,`
M````4A,`````4A,`````4A,`````5A,`````5A,`````5Q,`````5Q,`````
M5Q,`````5Q,`````6!,`````6!,`````6!,`````6!,`````7A,`````7A,`
M````7A,`````7A,`````9!,`````9!,`````9!,`````9!,`````91,`````
M91,`````91,`````91,`````:1,`````:1,`````:A,`````:A,`````=1,`
M````=1,`````=A,`````=A,`````@1,`````@1,`````@1,`````@1,`````
M@A,`````@A,`````@A,`````@A,`````AQ,`````AQ,`````AQ,`````AQ,`
M````B!,`````B!,`````B!,`````B!,`````C!,`````C!,`````C!,`````
MC!,`````C1,`````C1,`````C1,`````C1,`````CQ,`````CQ,`````CQ,`
M````CQ,`````D!,`````D!,`````D!,`````D!,`````DQ,`````DQ,`````
MDQ,`````DQ,`````FQ,`````FQ,`````FQ,`````FQ,`````GA,`````GA,`
M````GA,`````GA,`````JQ,`````JQ,`````JQ,`````JQ,`````L!,`````
ML!,`````L!,`````L!,`````L1,`````L1,`````L1,`````L1,`````MQ,`
M````MQ,`````MQ,`````MQ,`````O1,`````O1,`````QQ,`````QQ,`````
MR!,`````R!,`````R!,`````R!,`````JQ-($P``JQ-($P``JQ-)$P``JQ-)
M$P``JQ--$P``JQ--$P``JQ-0$P``JQ-0$P``P?O]_@``P?O^_@``````````
M9!/($P``````````````````7A/'$P``````````````````7A/($P``````
M````````````91/'$P``````````````````91/($P``````````````````
MAQ/'$P``````````````````AQ/($P``````````````````B!/'$P``````
M````````````B!/($P``````````````````@A->$P``````````````````
M@A-D$P``````````````````@A-E$P``````````````````@A.P$P``````
M````````````@A-U$P``````````````````@1-U$P``````````````````
MAQ-U$P``````````````````B!-U$P``````````````````C!/'$P``````
M````````````C!/($P``````````````````CQ/'$P``````````````````
MCQ/($P``````````````````D!/'$P``````````````````D!/($P``````
M````````````@1/'$P``````````````````@1/($P``````````````````
M@A/'$P``````````````````@A/($P``````````````````9!/'$P``````
M````````````9!/($P``````````````````7A/'$P``````````````````
M7A/($P``````````````````91/'$P``````````````````91/($P``````
M````````````AQ/'$P``````````````````AQ/($P``````````````````
MB!/'$P``````````````````B!/($P``````````````````@A->$P``````
M````````````@A-D$P``````````````````@A-E$P``````````````````
M@A.P$P``````````````````@A-U$P``````````````````@1-U$P``````
M````````````AQ-U$P``````````````````B!-U$P``````````````````
M@A->$P``````````````````@A-D$P``````````````````@A-E$P``````
M````````````@A.P$P``````````````````@1.W$P``````````````````
M@A.W$P``````````````````C!.P$P``````````````````@1->$P``````
M````````````@1-D$P``````````````````@1-E$P``````````````````
M@A->$P``````````````````@A-D$P``````````````````@A-E$P``````
M````````````C!.P$P``````````````````C1.P$P``````````````````
M4!,`````````````````````4!,`````````````````````P`(`````````
M````````````P0(`````````````````````P?M`_0``````````````````
MP?M!_0``````````````````P?M"_0``````````````````P?M#_0``````
M````````````P?M$_0``````````````````P?M%_0``````````````````
MP?M&_0``````````````````P?M'_0``````````````````P?M(_0``````
M````````````P?M)_0``````````````````P?M*_0``````````````````
MP?M+_0``````````````````P?M,_0``````````````````P?M-_0``````
M````````````P?M._0``````````````````P?M/_0``````````````````
M5Q->$[`3````````````````5Q-D$UX3````````````````5Q-D$UX3````
M````````````5Q-D$[`3````````````````5Q-E$[`3````````````````
M5Q.P$UX3````````````````5Q.P$V03````````````````5Q.P$V43````
M````````````7A.P$V03````````````````7A.P$V03````````````````
M9!.P$\@3````````````````9!.P$\<3````````````````@1-D$UX3````
M````````````@1->$V03````````````````@1->$\<3````````````````
M@1.P$V03````````````````@1.P$V03````````````````@1.P$UX3````
M````````````@1.P$[`3````````````````@1.P$[`3````````````````
MAQ-D$V03````````````````AQ-D$V03````````````````AQ.P$[`3````
M````````````@A-D$[`3````````````````@A-D$[`3````````````````
M@A->$\@3````````````````@A.P$V43````````````````@A.P$V43````
M````````````@A.P$[`3````````````````@A.P$[`3````````````````
MB!-D$\<3````````````````B!-E$[`3````````````````B!-E$[`3````
M````````````C!.P$V03````````````````C!.P$V03````````````````
MC!.P$[`3````````````````C!.P$\@3````````````````CQ->$[`3````
M````````````CQ.P$[`3````````````````CQ.P$[`3````````````````
MCQ.P$\<3````````````````D!.P$[`3````````````````D!.P$\@3````
M````````````D!.P$\<3````````````````DQ-E$[`3````````````````
MDQ-E$[`3````````````````FQ.P$V03````````````````FQ.P$[`3````
M````````````JQ-D$[`3````````````````JQ-D$\@3````````````````
MJQ-D$\<3````````````````JQ->$UX3````````````````JQ->$UX3````
M````````````JQ-E$[`3````````````````JQ-E$[`3````````````````
MJQ.P$V03````````````````JQ.P$V03````````````````L!-D$UX3````
M````````````L!-D$[`3````````````````L!-D$\@3````````````````
ML!->$V03````````````````L!->$[`3````````````````L!-E$UX3````
M````````````L!-E$[`3````````````````P?N0_0``````````````````
MP?N1_0``````````````````L!->$V43````````````````MQ.P$UX3````
M````````````MQ.P$[`3````````````````L1-D$[`3````````````````
ML1-D$\<3````````````````L1->$[`3````````````````L1->$[`3````
M````````````L1->$\<3````````````````L1.P$\@3````````````````
ML1.P$\<3````````````````R!.P$[`3````````````````R!.P$[`3````
M````````````4A-E$\@3````````````````5Q->$\@3````````````````
M5Q->$\<3````````````````5Q-E$\@3````````````````5Q-E$\<3````
M````````````5Q.P$\@3````````````````5Q.P$\<3````````````````
M7A.P$\@3````````````````7A-D$\<3````````````````7A.P$\<3````
M````````````@1-E$\<3````````````````AQ-D$\@3````````````````
M@A-D$\@3````````````````B!-D$\@3````````````````JQ->$\@3````
M````````````JQ.P$\@3````````````````R!-D$\@3````````````````
MR!->$\@3````````````````R!.P$\@3````````````````L!.P$\@3````
M````````````FQ.P$\@3````````````````L1-D$\@3````````````````
MFQ.P$V03````````````````JQ-D$[`3````````````````CQ.P$\@3````
M````````````GA.P$\@3````````````````L1->$V03````````````````
ML!-E$\@3````````````````JQ->$[`3````````````````GA.P$[`3````
M````````````JQ->$[`3````````````````L1->$V03````````````````
M7A-D$\@3````````````````9!->$\@3````````````````L!->$\@3````
M````````````DQ.P$\@3````````````````4A-D$\@3````````````````
MGA.P$[`3````````````````CQ->$[`3````````````````AQ.P$[`3````
M````````````@1-E$\@3````````````````L1->$\@3````````````````
MP?O(_0``````````````````P?O)_0``````````````````P?O*_0``````
M````````````P?O+_0``````````````````P?O,_0``````````````````
MP?O-_0``````````````````P?O._0``````````````````P?O/_0``````
M````````````P?O0_0``````````````````P?O1_0``````````````````
MP?O2_0``````````````````P?O3_0``````````````````P?O4_0``````
M````````````P?O5_0``````````````````P?O6_0``````````````````
MP?O7_0``````````````````P?O8_0``````````````````P?O9_0``````
M````````````P?O:_0``````````````````P?O;_0``````````````````
MP?O<_0``````````````````P?O=_0``````````````````P?O>_0``````
M````````````P?O?_0``````````````````P?O@_0``````````````````
MP?OA_0``````````````````P?OB_0``````````````````P?OC_0``````
M````````````P?OD_0``````````````````P?OE_0``````````````````
MP?OF_0``````````````````P?OG_0``````````````````P?OH_0``````
M````````````P?OI_0``````````````````P?OJ_0``````````````````
MP?OK_0``````````````````P?OL_0``````````````````P?OM_0``````
M````````````P?ON_0``````````````````P?OO_0``````````````````
MAQ.K$\X3````````````````FQ.K$\X3````````````````4!.K$ZL3MQ,`
M````````````4!.>$U(3=1,`````````````L!-D$[`3:1,`````````````
MAQ.K$X\3L!,`````````````=1.!$[T3JQ,`````````````CQ.K$\@3MQ,`
M````````````O1.!$ZL3L!,`````````````AQ.K$\<3````````````````
MP?OZ_0``````````````````7A.K$PD"7A.K$U`3JQ.W$P``=1/)$U`3JQ,`
M````````````3P,`````````````````````P?O^_0``````````````````
MP?O__0``````````````````3Q->$P``3Q-D$P``3Q.P$P``3Q/'$P``3Q/(
M$P``4A->$P``4A-D$P``4A-E$P``4A.P$P``4A/'$P``4A/($P``5Q->$P``
M5Q-D$P``5Q-E$P``5Q.P$P``5Q/'$P``5Q/($P``6!->$P``6!.P$P``6!/'
M$P``6!/($P``7A-D$P``7A.P$P``9!->$P``9!.P$P``91->$P``91-D$P``
M91.P$P``@1->$P``@1-D$P``@1-E$P``@1.P$P``AQ-D$P``AQ.P$P``B!->
M$P``B!-D$P``B!-E$P``B!.P$P``C!-D$P``C!.P$P``C1.P$P``CQ->$P``
MCQ.P$P``D!->$P``D!.P$P``DQ->$P``DQ-D$P``DQ-E$P``DQ.P$P``DQ/'
M$P``DQ/($P``FQ-D$P``FQ.P$P``FQ/'$P``FQ/($P``GA-0$P``GA->$P``
MGA-D$P``GA-E$P``GA.K$P``GA.P$P``GA/'$P``GA/($P``JQ->$P``JQ-D
M$P``JQ-E$P``JQ.P$P``JQ/'$P``JQ/($P``L!->$P``L!-D$P``L!-E$P``
ML!.P$P``L!/'$P``L!/($P``L1->$P``L1-D$P``L1-E$P``L1.P$P``L1/'
M$P``L1/($P``MQ->$P``MQ.P$P``MQ/'$P``MQ/($P``R!->$P``R!-D$P``
MR!-E$P``R!.P$P``R!/'$P``R!/($P``:A,`````=1,`````QQ,`````````
M````````````````````````````````````````````3Q-U$P``3Q-V$P``
M3Q.P$P``3Q.Q$P``3Q/'$P``3Q/($P``4A-U$P``4A-V$P``4A.P$P``4A.Q
M$P``4A/'$P``4A/($P``5Q-U$P``5Q-V$P``5Q.P$P``5Q.Q$P``5Q/'$P``
M5Q/($P``6!-U$P``6!-V$P``6!.P$P``6!.Q$P``6!/'$P``6!/($P``DQ/'
M$P``DQ/($P``FQ/'$P``FQ/($P``GA-0$P``GA.K$P``GA.P$P``GA/'$P``
MGA/($P``JQ.P$P``JQ/'$P``JQ/($P``L!-0$P``L!.P$P``L1-U$P``L1-V
M$P``L1.P$P``L1.Q$P``L1/'$P``L1/($P``QQ,`````R!-U$P``R!-V$P``
MR!.P$P``R!.Q$P``R!/'$P``R!/($P``3Q->$P``3Q-D$P``3Q-E$P``3Q.P
M$P``3Q.W$P``4A->$P``4A-D$P``4A-E$P``4A.P$P``4A.W$P``5Q->$P``
M5Q-D$P``5Q-E$P``5Q.P$P``5Q.W$P``6!.P$P``7A-D$P``7A.P$P``9!->
M$P``9!.P$P``91->$P``91.P$P``@1->$P``@1-D$P``@1-E$P``@1.P$P``
MAQ-D$P``AQ-E$P``AQ.P$P``B!->$P``B!-D$P``B!-E$P``B!.P$P``C!-D
M$P``C1.P$P``CQ->$P``CQ.P$P``D!->$P``D!.P$P``DQ->$P``DQ-D$P``
MDQ-E$P``DQ.P$P``FQ-D$P``FQ.P$P``GA->$P``GA-D$P``GA-E$P``GA.K
M$P``GA.P$P``JQ->$P``JQ-D$P``JQ-E$P``JQ.P$P``JQ.W$P``L!->$P``
ML!-D$P``L!-E$P``L!.P$P``L1->$P``L1-D$P``L1-E$P``L1.P$P``L1.W
M$P``MQ->$P``MQ.P$P``MQ,`````R!->$P``R!-D$P``R!-E$P``R!.P$P``
MR!.W$P``3Q.P$P``3Q.W$P``4A.P$P``4A.W$P``5Q.P$P``5Q.W$P``6!.P
M$P``6!.W$P``@1.P$P``@1.W$P``@A.P$P``@A.W$P``GA.K$P``GA.P$P``
MJQ.P$P``L1.P$P``L1.W$P``R!.P$P``R!.W$P``````````````````````
M````C!/'$P``C!/($P``CQ/'$P``CQ/($P``D!/'$P``D!/($P``@1/'$P``
M@1/($P``@A/'$P``@A/($P``9!/'$P``N0ZY#@````"Y#OL.`````+D.+@\`
M````N0ZY#OL.``"Y#KD.+@\``.H/`A``````Z@\"$`````#!^P?[`````,'[
M"/L`````P?L)^P````#!^PK[`````,'["_L`````P?L,^P````#!^PW[````
M`,'[#OL`````P?L/^P````#!^Q#[`````,'[$?L`````P?L2^P`````=$Q\3
M`````!T3#A,`````'1,4$P`````G$Q\3`````!T3%A,`````P?L8^P````#!
M^QG[`````,'[&OL`````P?L;^P````#!^QS[`````#H3````````````````
M```Z$SH3`````$`3````````,1,````````T$P```````#43````````.Q,`
M```````\$P```````#T3````````1!,```````!&$P```````"@$````````
M11,```````!%$P```````$43````````11,````````Q$P```````#$3````
M````,1,````````R$P```````#,3````````-!,````````U$P```````#83
M````````-Q,```````#!^S?[`````#D3````````.A,````````[$P``````
M`#L3````````/!,```````#!^SW[`````#T3````````P?L_^P`````^$P``
M`````#\3````````P?M"^P````!!$P```````$$3````````P?M%^P````!"
M$P```````$,3````````1!,```````!%$P```````$83````````-A,`````
M```R$P```````#L3````````01,````````Q$SP3`````$L3````````2Q,`
M``````!3$P```````%,3````````4Q,```````!3$P```````%03````````
M5!,```````!4$P```````%03````````51,```````!5$P```````%43````
M````51,```````!:$P```````%H3````````6A,```````!:$P```````%T3
M````````71,```````!=$P```````%T3````````61,```````!9$P``````
M`%D3````````61,```````"7$P```````)<3````````EQ,```````"7$P``
M`````)D3````````F1,```````"9$P```````)D3````````8!,```````!@
M$P```````&`3````````8!,```````!?$P```````%\3````````7Q,`````
M``!?$P```````&$3````````81,```````!A$P```````&$3````````8Q,`
M``````!C$P```````&,3````````8Q,```````!P$P```````'`3````````
M;Q,```````!O$P```````'$3````````<1,```````!K$P```````&L3````
M````?A,```````!^$P```````'<3````````=Q,```````"?$P```````)\3
M````````GQ,```````"?$P```````*43````````I1,```````"E$P``````
M`*43````````J1,```````"I$P```````*D3````````J1,```````"G$P``
M`````*<3````````IQ,```````"G$P```````+(3````````LA,```````"S
M$P```````+,3````````LQ,```````"S$P```````+P3````````O!,`````
M``"Y$P```````+D3````````N1,```````"Y$P```````+@3````````N!,`
M``````"X$P```````+@3````````SA,```````#.$P```````,X3````````
MSA,```````#!^[+[`````,'[L_L`````P?NT^P````#!^[7[`````,'[MOL`
M````P?NW^P````#!^[C[`````,'[N?L`````P?NZ^P````#!^[O[`````,'[
MO/L`````P?N]^P````#!^[[[`````,'[O_L`````P?O`^P````#!^\'[````
M`,'[POL`````P?O#^P````#!^\3[`````,'[Q?L`````P?O&^P````#!^\?[
M`````,'[R/L`````P?O)^P````#!^\K[`````,'[R_L`````P?O,^P````#!
M^\W[`````,'[SOL`````P?O/^P````#!^]#[`````,'[T?L`````P?O2^P``
M``"C$P```````*,3````````HQ,```````"C$P```````,$3````````P1,`
M``````#`$P```````,`3````````PA,```````#"$P```````,$31Q,`````
MQ1,```````#%$P```````+\3````````OQ,```````##$P```````,,3````
M````S!,```````#,$P```````,P3````````S!,```````#'$P```````,<3
M````````3Q-0$P````!/$U`3`````$\3O!,`````3Q.\$P````!/$[T3````
M`$\3O1,`````3Q/!$P````!/$\$3`````$\3P!,`````3Q/`$P````!/$\(3
M`````$\3PA,`````3Q/,$P````!/$\P3`````$\3S!,`````3Q/'$P````!/
M$\<3`````$\3QQ,`````R1,```````#)$P```````,D3````````R1,`````
M``!`^P?2``!`^Z;>``!`^]/B``!`^];\``!`^X7;``!`^Q[M``!`^[3F``!!
M^SN/``!!^TR(``!!^TV6``!!^XN)``!`^]/>``!`^T#1``!`^\#5``!!^P[Z
M``!!^P_Z``!`^UK8``!!^Q'Z``!`^W3F``!!^Q/Z``!!^Q3Z``!`^][1``!`
M^RKS``!`^\KV``!`^SSY``!`^U[Y``!`^V7Y``!`^X_Y``!!^U:7``!`^[[\
M``!`^[W_``!!^Q_Z``!!^Q*&``!!^R'Z``!!^_B*``!!^R/Z``!!^R3Z``!!
M^SB0``!!^_V0``!!^R?Z``!!^RCZ``!!^RGZ``!!^^^8``!!^_R8``!!^RB9
M``!!^[2=``#!^R[Z``#!^R_Z``!`^Z[/``!`^^?0``!`^TW1``!`^\G2``!`
M^^32``!`^U'3``!`^YW5``!`^P;6``!`^VC6``!`^T#8``!`^ZC8``!`^V3<
M``!`^V[<``!`^Y3@``!`^VCA``!`^X[A``!`^_+A``!`^T_E``!`^^+E``!`
M^Y'F``!`^X7H``!`^W?M``!`^QKN``!`^R+O``!`^V[Q``!`^ROR``!`^R+T
M``!`^Y'X``!`^S[Y``!`^TGY``!`^TCY``!`^U#Y``!`^U;Y``!`^UWY``!`
M^XWY``!`^X[Y``!`^T#Z``!`^X'Z``!`^\#[``!`^_3]``!`^PG^``!`^T'^
M``!`^W+_``!!^P6```!!^^V!``!!^WF"``!!^WF"``!!^U>$``!!^Q")``!!
M^Y:)``!!^P&+``!!^SF+``!!^].,``!!^PB-``!!^[:/``!!^SB0``!!^^.6
M``!!^_^7``!!^SN8``#!^VOZ``#!^VSZ``#!^VWZ``#!^V[Z``#!^V_Z``#!
M^W#Z``#!^W'Z``#!^W+Z``#!^W/Z``#!^W3Z``#!^W7Z``#!^W;Z``#!^W?Z
M``#!^WCZ``#!^WGZ``#!^WKZ``#!^WOZ``#!^WSZ``#!^WWZ``#!^W[Z``#!
M^W_Z``#!^X#Z``#!^X'Z``#!^X+Z``#!^X/Z``#!^X3Z``#!^X7Z``#!^X;Z
M``#!^X?Z``#!^XCZ``#!^XGZ``#!^XKZ``#!^XOZ``#!^XSZ``#!^XWZ``#!
M^X[Z``#!^X_Z``#!^Y#Z``#!^Y'Z``#!^Y+Z``#!^Y/Z``#!^Y3Z``#!^Y7Z
M``#!^Y;Z``#!^Y?Z``#!^YCZ``#!^YGZ``#!^YKZ``#!^YOZ``#!^YSZ``#!
M^YWZ``#!^Y[Z``#!^Y_Z``#!^Z#Z``#!^Z'Z``#!^Z+Z``#!^Z/Z``#!^Z3Z
M``#!^Z7Z``#!^Z;Z``#!^Z?Z``#!^ZCZ``#!^ZGZ``#!^ZKZ``#!^ZOZ``#!
M^ZSZ``#!^ZWZ``#!^Z[Z``#!^Z_Z``#!^[#Z``#!^['Z``#!^[+Z``#!^[/Z
M``#!^[3Z``#!^[7Z``#!^[;Z``#!^[?Z``#!^[CZ``#!^[GZ``#!^[KZ``#!
M^[OZ``#!^[SZ``#!^[WZ``#!^[[Z``#!^[_Z``#!^\#Z``#!^\'Z``#!^\+Z
M``#!^\/Z``#!^\3Z``#!^\7Z``#!^\;Z``#!^\?Z``#!^\CZ``#!^\GZ``#!
M^\KZ``#!^\OZ``#!^\SZ``#!^\WZ``#!^\[Z``#!^\_Z``#!^]#Z``#!^]'Z
M``#!^]+Z``#!^]/Z``#!^]3Z``#!^]7Z``#!^];Z``#!^]?Z``#!^]CZ``#!
M^]GZ``#!^]KZ``#!^]OZ``#!^]SZ``#!^]WZ``#!^][Z``#!^]_Z``#!^^#Z
M``#!^^'Z``#!^^+Z``#!^^/Z``#!^^3Z``#!^^7Z``#!^^;Z``#!^^?Z``#!
M^^CZ``#!^^GZ``#!^^KZ``#!^^OZ``#!^^SZ``#!^^WZ``#!^^[Z``#!^^_Z
M``#!^_#Z``#!^_'Z``#!^_+Z``#!^_/Z``#!^_3Z``#!^_7Z``#!^_;Z``#!
M^_?Z``#!^_CZ``#!^_GZ``#!^_KZ``#!^_OZ``#!^_SZ``#!^_WZ``#!^_[Z
M``#!^__Z``!!^TB,``!`^_3F``!!^\J.``!!^\B,``!`^]'N``!`^S+.``!`
M^^73``!!^YR?``!!^YR?``!`^U'9``!!^]&1``!`^X?5``!`^TC9``!`^_;A
M``!`^VGV``!`^X7_``!!^S^&``!!^[J'``!!^_B(``!!^X^0``!`^P+J``!`
M^QOM``!`^]GP``!`^][S``!!^SV$``!!^VJ1``!!^_&9``!`^X+.``!`^W73
M``!`^P3K``!`^QOR``!!^RV&``!!^QZ>``!`^U#=``!`^^OO``!!^\V%``!!
M^V2)``!`^\GB``!!^]B!``!!^Q^(``!`^\K>``!`^Q?G``!`^VKM``!`^_SR
M``!!^\Z0``!`^X;/``!`^[?1``!`^][2``!`^\3D``!`^]/J``!`^Q#R``!`
M^^?V``!!^P&```!!^P:&``!!^UR&``!!^^^-``!!^S*7``!!^V^;``!!^_J=
M``!`^XSX``!`^W_Y``!`^Z#]``!!^\F#``!!^P23``!!^W^>``!!^]:*``!`
M^]_8``!`^P3?``!`^V#\``!!^WZ```!`^V+R``!`^\KX``!!^\*,``!!^_>6
M``!`^]C8``!`^V+<``!`^Q/J``!`^]KM``!`^P_O``!`^R_]``!`^S?^``!!
M^TN6``!`^]+2``!!^XN```!`^]S1``!`^\S1``!`^QSZ``!`^[[]``!!^_&#
M``!!^W66``!!^X"+``!`^\_B``!`^P+J``!!^_Z*``!`^SG.``!`^^?;``!`
M^Q+@``!`^X?S``!`^W#U``!`^Q?3``!`^_OX``!`^[_/``!`^ZG?``!`^PW.
M``!`^\SL``!`^WCE``!`^R+]``!`^\/3``!`^U[8``!`^P'W``!!^TF$``!!
M^ZJ*``!`^[KK``!!^["/``!`^XCL``!`^_[B``!!^^6"``!`^Z#C``!`^V7U
M``!`^Z[.``!`^VG1``!`^\G1``!`^X'H``!`^^?\``!!^V^"``!!^]**``!!
M^\^1``!`^_72``!`^T+4``!`^W/9``!`^^S>``!`^\7E``!`^_[O``!`^RKY
M``!!^ZV5``!!^VJ:``!!^Y>>``!!^\Z>``!`^YO2``!`^\;F``!`^W?K``!!
M^V*/``!`^W3>``!`^Y#A``!`^P#B``!`^YKD``!`^R/O``!`^TGQ``!`^XGT
M``!`^\KY``!`^_3]``!!^V^```!!^R:/``!!^^Z$``!!^R.0``!!^TJ3``!`
M^Q?2``!`^Z/2``!`^[W4``!`^\CP``!!^\*(``!!^ZJ*``!`^\G>``!`^_7?
M``!`^WOC``!`^Z[K``!`^S[\``!`^W7S``!`^^3.``!`^_G6``!`^^?;``!`
M^[K=``!`^QS@``!`^[+S``!`^VGT``!`^YK_``!!^T:```!!^S22``!!^_:6
M``!!^TB7``!!^QB8``!`^XO/``!`^Z[Y``!!^[21``!!^[B6``!`^^'@``!`
M^X;.``!`^]K0``!`^^[;``!`^S_<``!`^YGE``!`^P+J``!`^\[Q``!`^T+V
M``!!^_R$``!!^WR0``!!^XV?``!`^XCF``!!^RZ6``!`^XG2``!`^WOG``!`
M^_/G``!`^T'M``!`^YSN``!`^PGT``!`^UGU``!`^VOX``!`^Q#]``!!^UZ8
M``!`^VW1``!`^R[B``!!^WB6``!`^RO0``!`^QG=``!`^^KM``!!^RJ/``!`
M^XO?``!`^T3A``!`^Q?H``!`^X?S``!!^X:6``!`^RG2``!`^P_4``!`^V7<
M``!`^Q/F``!`^T[G``!`^ZCH``!`^^7L``!`^P;T``!`^^+U``!`^WG_``!!
M^\^(``!!^^&(``!!^\R1``!!^^*6``!`^S_3``!`^[KN``!`^QW4``!`^]#Q
M``!`^YCT``!!^_J%``!!^Z.6``!!^U><``!!^Y^>``!`^Y?G``!`^\OM``!!
M^^B!``!`^\OZ``!`^R#[``!`^Y+\``!`^\#R``!`^YGP``!!^UB+``!`^\#.
M``!!^S:#``!`^SK2``"Q(@````"R(@````"S(@````"T(@````"U(@````"V
M(@````"W(@````"X(@````"Y(@````"Z(@````"[(@````"\(@````"](@``
M``"^(@````"_(@````#`(@````#!(@````#"(@````##(@````#$(@````#%
M(@````#&(@````#'(@````#((@````#)(@````#*(@````#+(@````#,(@``
M``#-(@````#.(@````#/(@````#0(@````#1(@````#2(@````#3(@````#4
M(@````#5(@````#6(@````#7(@````#8(@````#9(@````#:(@````#;(@``
M``#<(@````#=(@````#>(@````#?(@````#@(@````#A(@````#B(@````#C
M(@````#D(@````#E(@````#F(@````#G(@````#H(@````#I(@````#J(@``
M``#K(@````#L(@````#M(@````#N(@````#O(@````#P(@````#Q(@````#R
M(@````#S(@````#T(@````#U(@````#V(@````#W(@````#X(@````#Y(@``
M``#Z(@````#[(@````#\(@````#](@````#^(@````#_(@``````(P`````!
M(P`````"(P`````#(P`````$(P`````%(P`````&(P`````'(P`````((P``
M```)(P`````*(P`````+(P`````,(P`````-(P`````.(P`````/(P`````0
M(P`````1(P`````2(P`````3(P`````4(P`````5(P`````6(P`````7(P``
M```8(P`````9(P`````:(P`````;(P`````<(P`````=(P`````>(P`````?
M(P`````@(P`````A(P`````B(P`````C(P`````D(P`````E(P`````F(P``
M```G(P`````H(P`````I(P`````J(P`````K(P`````L(P`````M(P`````N
M(P`````O(P`````P(P`````Q(P`````R(P`````S(P`````T(P`````U(P``
M```V(P`````W(P`````X(P`````Y(P`````Z(P`````[(P`````\(P`````]
M(P````#!^XVD``#!^XZD``#!^X^D``#."P````#/"P````#0"P````#1"P``
M``#2"P````#3"P````#4"P````#5"P````#6"P````#7"P````#8"P````#9
M"P````#:"P````#;"P````#<"P````#="P````#>"P````#?"P````#@"P``
M``#A"P````#B"P````#C"P````#D"P````#E"P````#F"P````#G"P````#H
M"P````#I"P````#J"P````#K"P````#L"P````#M"P````#N"P````#O"P``
M``#P"P````#Q"P````#R"P````#S"P````#T"P````#U"P````#V"P````#W
M"P````#X"P````#Y"P````#Z"P````#["P````#\"P````#]"P````#^"P``
M``#_"P``````#``````!#``````"#``````##``````$#`````#!^\>D``#!
M^\BD``#!^\FD``#!^\JD``#!^\ND``#!^\RD``#!^\VD``#!^\ZD``#!^\^D
M``#!^]"D``#!^]&D``#!^]*D``#!^].D``#!^]2D``#!^]6D``#!^]:D``#!
M^]>D``#!^]BD``#!^]FD``#!^]JD``#!^]ND``#!^]RD``#!^]VD``#!^]ZD
M``#!^]^D``#!^^"D``#!^^&D``#!^^*D``#!^^.D``#!^^2D``#!^^6D``#!
M^^:D``#!^^>D``#!^^BD``#!^^FD``#!^^JD``#!^^ND``#!^^RD``#!^^VD
M``#!^^ZD``#!^^^D``#!^_"D``#!^_&D``#!^_*D``#!^_.D``#!^_2D``#!
M^_6D``#!^_:D``#!^_>D``#!^_BD``#!^_FD``#!^_JD``#!^_ND``#!^_RD
M``#!^_VD``#!^_ZD``#!^_^D``"Q(0``LB$``+,A``"T(0``M2$``+8A``"W
M(0``N"$``+DA``"Z(0``NR$``+PA``"](0``OB$``+\A``#`(0``P2$``,(A
M``##(0``Q"$``,4A``#&(0``QR$``,@A``#)(0``RB$``,LA``#,(0``S2$`
M`,XA``#/(0``T"$``-$A``#2(0``TR$``-0A``#5(0``UB$``-<A``#8(0``
MV2$``-HA``#;(0``W"$``-TA``#>(0``WR$``.`A``#A(0``XB$``.,A``#D
M(0``Y2$``.8A``#G(0``Z"$``.DA``#J(0``ZR$``.PA``#M(0``[B$``.\A
M``#P(0``\2$``/(A``#S(0``]"$``/4A``#V(0``]R$``/@A``#Y(0``^B$`
M`/LA``#\(0``_2$``/XA``#_(0```"(```$B```"(@```R(```0B```%(@``
M!B(```<B```((@``"2(```HB```+(@``#"(```TB```.(@``#R(``!`B```1
M(@``$B(``!,B```4(@``%2(``!8B```7(@``&"(``!DB```:(@``&R(``!PB
M```=(@``'B(``!\B```@(@``(2(``"(B```C(@``)"(``"4B```F(@``)R(`
M`"@B```I(@``*B(``"LB```L(@``+2(``"XB```O(@``,"(``#$B```R(@``
M,R(``#0B```U(@``-B(``#<B```X(@``.2(``#HB```[(@``/"(``#TB```^
M(@``/R(``$`B``!!(@``0B(``$,B``!$(@``12(``$8B``!'(@``2"(``$DB
M``!*(@``2R(``$PB``!-(@``3B(``$\B``!0(@``42(``%(B``!3(@``5"(`
M`%4B``!6(@``5R(``%@B``!9(@``6B(``%LB``!<(@``72(``%XB``!?(@``
M8"(``&$B``!B(@``8R(``&0B``!E(@``9B(``&<B``!H(@``:2(``&HB``!K
M(@``;"(``&TB``!N(@``;R(``'`B``!Q(@``<B(``',B``!T(@``=2(``'8B
M``!W(@``>"(``'DB``!Z(@``>R(``'PB``!](@``?B(``'\B``"`(@``@2(`
M`((B``"#(@``A"(``(4B``"&(@``AR(``(@B``")(@``BB(``(LB``",(@``
MC2(``(XB``"/(@``D"(``)$B``"2(@``DR(``)0B``"5(@``EB(``)<B``"8
M(@``F2(``)HB``";(@``G"(``)TB``">(@``GR(``*`B``"A(@``HB(``*,B
M``"D(@``I2(``*8B``"G(@``J"(``*DB``"J(@``JR(``*PB``"M(@``KB(`
M`*\B``"P(@``L2```+(@``"S(```M"```+4@``"V(```MR```+@@``"Y(```
MNB```+L@``"\(```O2```+X@``"_(```P"```,$@``#"(```PR```,0@``#%
M(```QB```,<@``#((```R2```,H@``#+(```S"```,T@``#.(```SR```-`@
M``#1(```TB```-,@``#4(```U2```-8@``#7(```V"```-D@``#:(```VR``
M`-P@``#=(```WB```-\@``#@(```X2```.(@``#C(```Y"```.4@``#F(```
MYR```.@@``#I(```ZB```.L@``#L(```[2```.X@``#O(```\"```/$@``#R
M(```\R```/0@``#U(```]B```/<@``#X(```^2```/H@``#[(```_"```/T@
M``#^(```_R`````A```!(0```B$```,A```$(0``!2$```8A```'(0``""$`
M``DA```*(0``"R$```PA```-(0``#B$```\A```0(0``$2$``!(A```3(0``
M%"$``!4A```6(0``%R$``!@A```9(0``&B$``!LA```<(0``'2$``!XA```?
M(0``("$``"$A```B(0``(R$``"0A```E(0``)B$``"<A```H(0``*2$``"HA
M```K(0``+"$``"TA```N(0``+R$``#`A```Q(0``,B$``#,A```T(0``-2$`
M`#8A```W(0``."$``#DA```Z(0``.R$``#PA```](0``/B$``#\A``!`(0``
M02$``$(A``!#(0``1"$``$4A``!&(0``1R$``$@A``!)(0``2B$``$LA``!,
M(0``32$``$XA``!/(0``4"$``%$A``!2(0``4R$``%0A``!5(0``5B$``%<A
M``!8(0``62$``%HA``!;(0``7"$``%TA``!>(0``7R$``&`A``!A(0``8B$`
M`&,A``!D(0``92$``&8A``!G(0``:"$``&DA``!J(0``:R$``&PA``!M(0``
M;B$``&\A``!P(0``<2$``'(A``!S(0``="$``'4A``!V(0``=R$``'@A``!Y
M(0``>B$``'LA``!\(0``?2$``'XA``!_(0``@"$``($A``""(0``@R$``(0A
M``"%(0``AB$``(<A``"((0``B2$``(HA``"+(0``C"$``(TA``".(0``CR$`
M`)`A``"1(0``DB$``),A``"4(0``E2$``)8A``"7(0``F"$``)DA``":(0``
MFR$``)PA``"=(0``GB$``)\A``"@(0``H2$``*(A``"C(0``I"$``*4A``"F
M(0``IR$``*@A``"I(0``JB$``*LA``"L(0``K2$``*XA``"O(0``L"$``+$?
M``"R'P``LQ\``+0?``"U'P``MA\``+<?``"X'P``N1\``+H?``"['P``O!\`
M`+T?``"^'P``OQ\``,`?``#!'P``PA\``,,?``#$'P``Q1\``,8?``#''P``
MR!\``,D?``#*'P``RQ\``,P?``#-'P``SA\``,\?``#0'P``T1\``-(?``#3
M'P``U!\``-4?``#6'P``UQ\``-@?``#9'P``VA\``-L?``#<'P``W1\``-X?
M``#?'P``X!\``.$?``#B'P``XQ\``.0?``#E'P``YA\``.<?``#H'P``Z1\`
M`.H?``#K'P``[!\``.T?``#N'P``[Q\``/`?``#Q'P``\A\``/,?``#T'P``
M]1\``/8?``#W'P``^!\``/D?``#Z'P``^Q\``/P?``#]'P``_A\``/\?````
M(````2````(@```#(```!"````4@```&(```!R````@@```)(```"B````L@
M```,(```#2````X@```/(```$"```!$@```2(```$R```!0@```5(```%B``
M`!<@```8(```&2```!H@```;(```'"```!T@```>(```'R```"`@```A(```
M(B```",@```D(```)2```"8@```G(```*"```"D@```J(```*R```"P@```M
M(```+B```"\@```P(```,2```#(@```S(```-"```#4@```V(```-R```#@@
M```Y(```.B```#L@```\(```/2```#X@```_(```0"```$$@``!"(```0R``
M`$0@``!%(```1B```$<@``!((```22```$H@``!+(```3"```$T@``!.(```
M3R```%`@``!1(```4B```%,@``!4(```52```%8@``!7(```6"```%D@``!:
M(```6R```%P@``!=(```7B```%\@``!@(```82```&(@``!C(```9"```&4@
M``!F(```9R```&@@``!I(```:B```&L@``!L(```;2```&X@``!O(```<"``
M`'$@``!R(```<R```'0@``!U(```=B```'<@``!X(```>2```'H@``![(```
M?"```'T@``!^(```?R```(`@``"!(```@B```(,@``"$(```A2```(8@``"'
M(```B"```(D@``"*(```BR```(P@``"-(```CB```(\@``"0(```D2```)(@
M``"3(```E"```)4@``"6(```ER```)@@``"9(```FB```)L@``"<(```G2``
M`)X@``"?(```H"```*$@``"B(```HR```*0@``"E(```IB```*<@``"H(```
MJ2```*H@``"K(```K"```*T@``"N(```KR```+`@``"Q'@``LAX``+,>``"T
M'@``M1X``+8>``"W'@``N!X``+D>``"Z'@``NQX``+P>``"]'@``OAX``+\>
M``#`'@``P1X``,(>``##'@``Q!X``,4>``#&'@``QQX``,@>``#)'@``RAX`
M`,L>``#,'@``S1X``,X>``#/'@``T!X``-$>``#2'@``TQX``-0>``#5'@``
MUAX``-<>``#8'@``V1X``-H>``#;'@``W!X``-T>``#>'@``WQX``.`>``#A
M'@``XAX``.,>``#D'@``Y1X``.8>``#G'@``Z!X``.D>``#J'@``ZQX``.P>
M``#M'@``[AX``.\>``#P'@``\1X``/(>``#S'@``]!X``/4>``#V'@``]QX`
M`/@>``#Y'@``^AX``/L>``#\'@``_1X``/X>``#_'@```!\```$?```"'P``
M`Q\```0?```%'P``!A\```<?```('P``"1\```H?```+'P``#!\```T?```.
M'P``#Q\``!`?```1'P``$A\``!,?```4'P``%1\``!8?```7'P``&!\``!D?
M```:'P``&Q\``!P?```='P``'A\``!\?```@'P``(1\``"(?```C'P``)!\`
M`"4?```F'P``)Q\``"@?```I'P``*A\``"L?```L'P``+1\``"X?```O'P``
M,!\``#$?```R'P``,Q\``#0?```U'P``-A\``#<?```X'P``.1\``#H?```[
M'P``/!\``#T?```^'P``/Q\``$`?``!!'P``0A\``$,?``!$'P``11\``$8?
M``!''P``2!\``$D?``!*'P``2Q\``$P?``!-'P``3A\``$\?``!0'P``41\`
M`%(?``!3'P``5!\``%4?``!6'P``5Q\``%@?``!9'P``6A\``%L?``!<'P``
M71\``%X?``!?'P``8!\``&$?``!B'P``8Q\``&0?``!E'P``9A\``&<?``!H
M'P``:1\``&H?``!K'P``;!\``&T?``!N'P``;Q\``'`?``!Q'P``<A\``',?
M``!T'P``=1\``'8?``!W'P``>!\``'D?``!Z'P``>Q\``'P?``!]'P``?A\`
M`'\?``"`'P``@1\``((?``"#'P``A!\``(4?``"&'P``AQ\``(@?``")'P``
MBA\``(L?``",'P``C1\``(X?``"/'P``D!\``)$?``"2'P``DQ\``)0?``"5
M'P``EA\``)<?``"8'P``F1\``)H?``";'P``G!\``)T?``">'P``GQ\``*`?
M``"A'P``HA\``*,?``"D'P``I1\``*8?``"G'P``J!\``*D?``"J'P``JQ\`
M`*P?``"M'P``KA\``*\?``"P'P``@/L`S0``@/L!S0``@/L"S0``@/L#S0``
M@/L$S0``@/L%S0``@/L&S0``@/L'S0``@/L(S0``@/L)S0``@/L*S0``@/L+
MS0``@/L,S0``@/L-S0``@/L.S0``@/L/S0``@/L0S0``@/L1S0``@/L2S0``
M@/L3S0``@/L4S0``@/L5S0``@/L6S0``@/L7S0``@/L8S0``@/L9S0``@/L:
MS0``@/L;S0``@/L<S0``@/L=S0``@/L>S0``@/L?S0``@/L@S0``@/LAS0``
M@/LBS0``@/LCS0``@/LDS0``@/LES0``@/LFS0``@/LGS0``@/LHS0``@/LI
MS0``@/LJS0``@/LKS0``@/LLS0``@/LMS0``@/LNS0``@/LOS0``@/LPS0``
M@/LQS0``@/LRS0``@/LSS0``@/LTS0``@/LUS0``@/LVS0``@/LWS0``@/LX
MS0``@/LYS0``@/LZS0``@/L[S0``@/L\S0``@/L]S0``@/L^S0``@/L_S0``
M@/M`S0``@/M!S0``@/M"S0``@/M#S0``@/M$S0``@/M%S0``@/M&S0``@/M'
MS0``@/M(S0``@/M)S0``@/M*S0``@/M+S0``@/M,S0``@/M-S0``@/M.S0``
M@/M/S0``@/M0S0``@/M1S0``@/M2S0``@/M3S0``@/M4S0``@/M5S0``@/M6
MS0``@/M7S0``@/M8S0``@/M9S0``@/M:S0``@/M;S0``@/M<S0``@/M=S0``
M@/M>S0``@/M?S0``@/M@S0``@/MAS0``@/MBS0``@/MCS0``@/MDS0``@/ME
MS0``@/MFS0``@/MGS0``@/MHS0``@/MIS0``@/MJS0``@/MKS0``@/MLS0``
M@/MMS0``@/MNS0``@/MOS0``@/MPS0``@/MQS0``@/MRS0``@/MSS0``@/MT
MS0``@/MUS0``@/MVS0``@/MWS0``@/MXS0``@/MYS0``@/MZS0``@/M[S0``
M@/M\S0``@/M]S0``@/M^S0``@/M_S0``@/N`S0``@/N!S0``@/N"S0``@/N#
MS0``@/N$S0``@/N%S0``@/N&S0``@/N'S0``@/N(S0``@/N)S0``@/N*S0``
M@/N+S0``@/N,S0``@/N-S0``@/N.S0``@/N/S0``@/N0S0``@/N1S0``@/N2
MS0``@/N3S0``@/N4S0``@/N5S0``@/N6S0``@/N7S0``@/N8S0``@/N9S0``
M@/N:S0``@/N;S0``@/N<S0``@/N=S0``@/N>S0``@/N?S0``@/N@S0``@/NA
MS0``@/NBS0``@/NCS0``@/NDS0``@/NES0``@/NFS0``@/NGS0``@/NHS0``
M@/NIS0``@/NJS0``@/NKS0``@/NLS0``@/NMS0``@/NNS0``@/NOS0``@/NP
MS0``@/NQS0``@/NRS0``@/NSS0``@/NTS0``@/NUS0``P/NVS0``P/NWS0``
MP/NXS0``P/NYS0``P/NZS0``P/N[S0``P/N\S0``P/N]S0``P/N^S0``P/N_
MS0``-PL`````.`L`````.0L`````.@L`````.PL`````/`L`````/0L`````
M/@L`````/PL`````0`L`````00L`````0@L`````0PL`````1`L`````10L`
M````1@L`````1PL`````2`L`````20L`````2@L`````2PL`````3`L`````
M30L`````3@L`````3PL`````4`L`````40L`````4@L`````4PL`````5`L`
M````50L`````5@L`````5PL`````6`L`````60L`````6@L`````6PL`````
M7`L`````70L`````7@L`````7PL`````8`L`````80L`````8@L`````8PL`
M````9`L`````90L`````9@L`````9PL`````:`L`````:0L`````:@L`````
M:PL`````;`L`````;0L`````;@L`````;PL`````<`L`````<0L`````<@L`
M````<PL`````=`L`````=0L`````=@L`````4AYK'@L.91X`````````````
M4AYZ'FT>4AX`````````````4AZ!'FX>4AX`````````````4AX+#GH>````
M````````````4QYG'H$>61X`````````````4QZ!'F(>````````````````
M5!Y6'H$>````````````````51Y>'ED>"PYE'@``````````51X+#E<>"PX`
M````````````5AZ!'EX>````````````````5AX+#G(>````````````````
M5QY3'GD>````````````````5QYX'F,>91X`````````````5QY\'GD>"PX`
M````````````5QY\'H$>````````````````5QZ!'G`>````````````````
M6!Y7'@``````````````````6!YG'@L.````````````````6!YV'GD>"PX`
M````````````6!YZ'F$>"PX`````````````6!Y\'@``````````````````
M6!Y\'ED>>!YR'@``````````6!Y\'G,>"PYE'GH>````````6!Y\'GT>8QYE
M'@``````````61YX'G(>````````````````61YX'G(>91Z!'@``````````
M61YZ'E\>4QY\'@``````````61Y\'@L.:1X`````````````6AX+#EX>````
M````````````6QYZ'F8>````````````````6QX+#F\>````````````````
M7!Y3'ED>>AX`````````````7!Z!'F(>"PYR'@``````````71YY'H$>61X`
M````````````7QZ!'F(>````````````````7QZ!'F4>````````````````
M81X+#EX>````````````````9!Y='@``````````````````91YZ'@``````
M````````````91Z!'@``````````````````9AYJ'@``````````````````
M:AYC'F4>````````````````:QY3'F,>````````````````:QX+#E\>@1YE
M'@``````````:QX+#F,>````````````````:QX+#GL>>AX`````````````
M;!Y2'EX>91YZ'@``````````;!Y9'GH>````````````````;!Y;'@``````
M````````````;!YZ'@``````````````````;1Y2'G@>8QYE'@``````````
M;1Y3'@L.91X`````````````;1YC'ET>51YZ'@``````````;1YX'H$>````
M````````````;AY9'F$>"PYZ'@``````````;AY@'@``````````````````
M;AYG'FP>````````````````;AYZ'F,>````````````````;AZ!'EX>````
M````````````;AX+#ET>````````````````;AX+#F$>````````````````
M;QY3'H$>91X`````````````;QYZ'F4>````````````````;QZ!'@``````
M````````````;QZ!'F4>````````````````;QX+#GH>````````````````
M;QX+#H$>````````````````<!Y3'ED>?!X`````````````<!Y3'GH>````
M````````````<!YC'FL>````````````````<!YZ'ED>````````````````
M<!Z!'ET>=QZ!'@``````````<1Y9'GP>@1X`````````````<1YY'@``````
M````````````<1YY'FL>"PYZ'@``````````<QY7'@``````````````````
M<QY7'F4>@1X`````````````<QX+#F4>>AX`````````````=1X+#F4>````
M````````````=1X+#GH>````````````````=AY2'H$>````````````````
M>1YC'F4>>AX`````````````>1YX'@``````````````````>AYL'@L.````
M````````````>AX+#FT>>AX`````````````>QYR'@``````````````````
M>QZ!'F4>6AZ!'@``````````?1YC'F4>````````````````*0Y`^[GP````
M````````````*@Y`^[GP````````````````*PY`^[GP````````````````
M+`Y`^[GP````````````````+0Y`^[GP````````````````+@Y`^[GP````
M````````````+PY`^[GP````````````````,`Y`^[GP````````````````
M,0Y`^[GP````````````````,@Y`^[GP````````````````*@XI#D#[N?``
M````````````*@XJ#D#[N?``````````````*@XK#D#[N?``````````````
M*@XL#D#[N?``````````````*@XM#D#[N?``````````````*@XN#D#[N?``
M````````````*@XO#D#[N?``````````````*@XP#D#[N?``````````````
M*@XQ#D#[N?``````````````*@XR#D#[N?``````````````*PXI#D#[N?``
M````````````*PXJ#D#[N?``````````````*PXK#D#[N?``````````````
M*PXL#D#[N?``````````````*PXM#D#[N?``````````````X0ZG#S,.````
M````````````;0XS#@``````````````````,PX?$```````````````````
M2@XS#L`/````````````````@@]$$```````````````````IP]@#@``````
M````````````;0Y;#P``````````````````;0Y;#RL.````````````````
M;0Y;#RP.````````````````^PX?$```````````````````0/MSWD#[$.(`
M````````````0/LMYD#[C-0`````````````0/LGV4#[8^L`````````````
M0/L.YD#[N^P`````````````0/LJZ$#[#]]`^QK/0/L^^0``IP\S#@``````
M````````````9`\S#@``````````````````^!`S#@``````````````````
M6P\S#@``````````````````(0\S#@``````````````````(0]*#@``````
M````````````6P]*#@``````````````````P0Y*#@``````````````````
M8`XS#BX/````````````````(0]@#C,.+@\`````````````IP^Y#@``````
M````````````9`^Y#@``````````````````^!"Y#@``````````````````
M^!#!#@``````````````````6P_!#@``````````````````(0_!#@``````
M````````````X0YJ$```````````````````(0_A#FH0````````````````
M6P_A#FH0````````````````P0[A#FH0`````````````````A#A#FH0````
M````````````^!`N#P``````````````````6P\N#P``````````````````
M;0XN#P``````````````````(0\N#P``````````````````N0Y;#P``````
M````````````9`];#P``````````````````^!!;#P``````````````````
M6P];#P``````````````````8`Y;#P``````````````````(0];#P``````
M````````````6P];#RL.````````````````8`Y;#RL.````````````````
M6P\K#@``````````````````(0];#RL.````````````````6P];#RP.````
M````````````8`Y;#RP.````````````````6P\L#@``````````````````
M(0];#RP.````````````````6P\W!.H/````````````````6P\W!.H/*PX`
M````````````IP\S#@``````````````````(0^G#S,.````````````````
M6P^G#S,.````````````````P0ZG#S,.````````````````P`\S#FT.````
M````````````P`\S#FT.-P3J#P``````````P`\S#FT.-P3J#RL.````````
MIP_J#P``````````````````9`_J#P``````````````````^!#J#P``````
M````````````6P_J#P``````````````````IP]$$```````````````````
M9`]$$```````````````````^!!$$```````````````````6P]$$```````
M````````````(0]$$```````````````````6P]$$```````````````````
MIP]1$```````````````````9`]1$```````````````````^!!1$```````
M````````````6P]1$```````````````````(0]1$```````````````````
M6P]1$```````````````````(0\)$0``````````````````6P\)$0``````
M````````````,PY=`EL/70(`````````````2@ZT#P``````````````````
M8`Y@#@``````````````````8`YM#@``````````````````8`XW!"$/P0X`
M````````````8`Z"#UT"````````````````;0Y*#@``````````````````
MP0Y>$```````````````````X0XS#@``````````````````X0ZG#P``````
M````````````^PYD#P``````````````````(0\A#P``````````````````
M(0];#P``````````````````(0\"$```````````````````+@];#P``````
M````````````+@]D#P``````````````````+@^"#\$.````````````````
M+@]:$```````````````````6P]*#@``````````````````6P_[#BX/````
M````````````6P^"#RX/````````````````IP_A#@``````````````````
MIP]=`EL/70(`````````````IP^G#UL/````````````````IP_`#P``````
M````````````Z@_`#P``````````````````Z@]$$```````````````````
M41!*#@``````````````````1!`W!%L/````````````````,PXW!%L/````
M````````````*@Y`^^7E````````````````*PY`^^7E````````````````
M+`Y`^^7E````````````````+0Y`^^7E````````````````+@Y`^^7E````
M````````````+PY`^^7E````````````````,`Y`^^7E````````````````
M,0Y`^^7E````````````````,@Y`^^7E````````````````*@XI#D#[Y>4`
M````````````*@XJ#D#[Y>4`````````````*@XK#D#[Y>4`````````````
M*@XL#D#[Y>4`````````````*@XM#D#[Y>4`````````````*@XN#D#[Y>4`
M````````````*@XO#D#[Y>4`````````````*@XP#D#[Y>4`````````````
M*@XQ#D#[Y>4`````````````*@XR#D#[Y>4`````````````*PXI#D#[Y>4`
M````````````*PXJ#D#[Y>4`````````````*PXK#D#[Y>4`````````````
M*PXL#D#[Y>4`````````````*PXM#D#[Y>4`````````````*PXN#D#[Y>4`
M````````````*PXO#D#[Y>4`````````````*PXP#D#[Y>4`````````````
M*PXQ#D#[Y>4`````````````*PXR#D#[Y>4`````````````+`XI#D#[Y>4`
M````````````+`XJ#D#[Y>4`````````````P0XS#BX/````````````````
MB`)B'8D"`````````````(@"9!V)`@````````````"(`F4=B0(`````````
M````B`)G'8D"`````````````(@":!V)`@````````````"(`FD=B0(`````
M````````B`)K'8D"`````````````(@";1V)`@````````````"(`FX=B0(`
M````````````B`)P'8D"`````````````(@"<1V)`@````````````"(`G(=
MB0(`````````````B`)S'8D"`````````````(@"=!V)`@````````````"(
M`F(=OAV)`@``````````B`)D';X=B0(``````````(@"91V^'8D"````````
M``"(`F<=OAV)`@``````````B`)H';X=B0(``````````(@":1V^'8D"````
M``````"(`FL=OAV)`@``````````B`)M';X=B0(``````````(@";AV^'8D"
M``````````"(`G`=OAV)`@``````````B`)Q';X=B0(``````````(@"<AV^
M'8D"``````````"(`G,=OAV)`@``````````B`)T';X=B0(``````````(@"
M;AW+'8D"``````````"(`FT=QAUN'<(=`QZ)`@``B`)M'<8==!W+'8D"````
M`,#['[(```````````````"(`D#[`,Z)`@``````````B`)`^XS.B0(`````
M`````(@"0/L)SHD"``````````"(`D#[V]:)`@``````````B`)`^Y3.B0(`
M`````````(@"0/MMT8D"``````````"(`D#[`\Z)`@``````````B`)`^VO1
MB0(``````````(@"0/M=SHD"``````````"(`D#[0=.)`@``````````B`)`
M^PCGB0(``````````(@"0/MK\(D"``````````"(`D#[-.R)`@``````````
MB`)`^RCGB0(``````````(@"0?O1D8D"``````````"(`D#[']>)`@``````
M````B`)`^^7EB0(``````````(@"0/LJZ(D"``````````"(`D#[">>)`@``
M````````B`)`^S[YB0(``````````(@"0/L-U(D"``````````"(`D#[>?*)
M`@``````````B`)!^Z&,B0(``````````(@"0/M=^8D"``````````"(`D#[
MM-*)`@``````````B`)`^^/.B0(``````````(@"0/M\U(D"``````````"(
M`D#[9MN)`@``````````B`)`^^/VB0(``````````(@"0/L!SXD"````````
M``"(`D'[QXR)`@``````````B`)`^U33B0(``````````(@"0/MM^8D"````
M``````"(`D#[$<^)`@``````````B`)!^^J!B0(``````````(@"0?OS@8D"
M``````````#`^T2R````````````````P/M%L@```````````````,#[1K(`
M``````````````#`^T>R````````````````P/M(L@```````````````,#[
M2;(```````````````#`^TJR````````````````P/M+L@``````````````
M`,#[3+(```````````````#`^TVR````````````````P/M.L@``````````
M`````,#[3[(```````````````"G#P(0BPX`````````````*PXJ#@``````
M`````````"L.*PX````````````````K#BP.````````````````*PXM#@``
M`````````````"L.+@X````````````````K#B\.````````````````*PXP
M#@```````````````"L.,0X````````````````K#C(.````````````````
M+`XI#@```````````````"P.*@X````````````````L#BL.````````````
M````+`XL#@```````````````"P.+0X````````````````L#BX.````````
M````````8AT``````````````````&0=``````````````````!E'0``````
M````````````9QT``````````````````&@=``````````````````!I'0``
M````````````````:QT``````````````````&T=``````````````````!N
M'0``````````````````<!T``````````````````'$=````````````````
M``!R'0``````````````````<QT``````````````````'0=````````````
M``````!B';X=````````````````9!V^'0```````````````&4=OAT`````
M``````````!G';X=````````````````:!V^'0```````````````&D=OAT`
M``````````````!K';X=````````````````;1V^'0```````````````&X=
MOAT```````````````!P';X=````````````````<1V^'0``````````````
M`'(=OAT```````````````!S';X=````````````````=!V^'0``````````
M`````'`=OAT/'F(=QAT```````!N'<L=;1W1'0``````````P/M^L@``````
M`````````,0-``````````````````!`^P#.````````````````0/N,S@``
M`````````````$#["<X```````````````!`^]O6````````````````0/N4
MS@```````````````$#[;=$```````````````!`^P/.````````````````
M0/MKT0```````````````$#[7<X```````````````!`^T'3````````````
M````0/L(YP```````````````$#[:_````````````````!`^S3L````````
M````````0/LHYP```````````````$'[T9$```````````````!`^Q_7````
M````````````0/OEY0```````````````$#[*N@```````````````!`^PGG
M````````````````0/L^^0```````````````$#[#=0```````````````!`
M^WGR````````````````0?NAC````````````````$#[7?D`````````````
M``!`^[32````````````````0/O8^0```````````````$#[-_4`````````
M``````!`^W/9````````````````0?MID````````````````$#[*M$`````
M``````````!`^W#3````````````````0/OH[````````````````$'[!9@`
M``````````````!`^Q'/````````````````0/N9T0```````````````$#[
M8^L```````````````!`^PK.````````````````0/LMS@``````````````
M`$#["\X```````````````!`^^;=````````````````0/OSTP``````````
M`````$#[.],```````````````!`^Y?;````````````````0/MFVP``````
M`````````$#[X_8```````````````!`^P'/````````````````0?O'C```
M`````````````$#[5-,```````````````!`^QS9````````````````+`XO
M#@```````````````"P.,`X````````````````L#C$.````````````````
M+`XR#@```````````````"T.*0X````````````````M#BH.````````````
M````+0XK#@```````````````"T.+`X````````````````M#BT.````````
M````````+0XN#@```````````````"T.+PX````````````````M#C`.````
M````````````+0XQ#@```````````````"T.,@X````````````````N#BD.
M````````````````*@Y`^PCG`````````````"L.0/L(YP`````````````L
M#D#[".<`````````````+0Y`^PCG`````````````"X.0/L(YP``````````
M```O#D#[".<`````````````,`Y`^PCG`````````````#$.0/L(YP``````
M```````R#D#[".<`````````````*@XI#D#[".<``````````"H.*@Y`^PCG
M```````````J#BL.0/L(YP``````````X0[!#@```````````````(L.P`_!
M#@````````````"+#D00````````````````+@\"$&T.`````````````%(>
M``````````````````!3'@``````````````````5!X`````````````````
M`%4>``````````````````!6'@``````````````````5QX`````````````
M`````%@>``````````````````!9'@``````````````````6AX`````````
M`````````%L>``````````````````!<'@``````````````````71X`````
M`````````````%X>``````````````````!?'@``````````````````8!X`
M`````````````````&$>``````````````````!B'@``````````````````
M8QX``````````````````&0>``````````````````!E'@``````````````
M````9AX``````````````````&<>``````````````````!H'@``````````
M````````:1X``````````````````&H>``````````````````!K'@``````
M````````````;!X``````````````````&T>``````````````````!N'@``
M````````````````;QX``````````````````'`>``````````````````!Q
M'@``````````````````<AX``````````````````',>````````````````
M``!T'@``````````````````=1X``````````````````'8>````````````
M``````!W'@``````````````````>!X``````````````````'D>````````
M``````````!Z'@``````````````````>QX``````````````````'P>````
M``````````````!]'@``````````````````?AX``````````````````'\>
M``````````````````"`'@``````````````````P/O_L@``````````````
M`,#[`+$``,#[`;$``,#[`K$``,#[`[$``,#[!+$``((>`````(,>`````(0>
M`````(4>`````(<>`````(@>`````(D>`````(H>`````(L>`````(P>````
M`(\>`````)`>`````)$>`````)(>`````)0>`````)4>`````)8>`````)<>
M`````)@>`````)D>`````)H>`````)L>`````)P>`````)X>`````)\>````
M`*$>`````*(>`````*,>`````*0>`````*4>`````*8>`````*<>`````*D>
M`````*T>`````*X>`````*\>`````+`>`````(8>`````(T>`````),>````
M`,#[+;$``,#[+K$``,#[+[$``,#[,+$``&(=`````&,=``````(>`````&0=
M``````0>``````4>`````&4=`````&8=`````&<=``````@>``````D>````
M``H>``````L>``````P>``````T>`````'P=`````&@=`````&D=`````&H=
M`````(,=`````&L=`````&P=`````&T=`````&X=`````&\=`````'`=````
M`'$=`````'(=`````',=`````'0=`````+X=`````+\=`````,`=`````,$=
M`````,(=`````,,=`````,0=`````,4=`````,8=`````,<=`````,@=````
M`,D=`````,H=`````,L=`````,P=`````,T=`````,X=`````,\=`````-`=
M`````-$=`````-(=`````+T=`````'8=`````'<=`````!\>`````"`>````
M`"0>`````"8>`````"L>`````"\>`````#$>`````'X=`````#4>`````#<>
M`````'\=`````(`=`````((=`````(0=`````(4=`````(D=`````(L=````
M`(T=`````(X=`````(\=`````)`=`````)$=`````)0=`````)@=`````*(=
M`````*D=`````*X=`````$D>`````$H>`````+D=`````+H=`````+L=````
M`.$=`````.(=`````.4=`````.X=`````.\=`````/$=`````/L=`````/X=
M`````,#[C[$``,(-`````,,-`````$#[`,X``$#[C,X``$#["<X``$#[V]8`
M`$#["LX``$#[+<X``$#["\X``$#[,O4``$#[6<X``$#[&<X``$#[`<X``$#[
M*=D``$#[,-<``$#[NLX``((>`````)@>`````)`>`````(L>`````*`>````
M`*`>`````)T>`````)P>`````*\>`````)L>`````*X>`````*\>`````*P>
M`````(X>`````*$>`````*,>`````*H>`````*L>`````*@>`````*X>````
M`(,>`````(@>`````(P>`````(\>`````,#[N+$``,#[N;$``,#[NK$``,#[
MN[$``,#[O+$``,#[O;$``,#[OK$``,#[O[$``,#[P+$``,#[P;$``,#[PK$`
M`,#[P[$``,#[Q+$``,#[Q;$``,#[QK$``,#[Q[$``,#[R+$``,#[R;$``,#[
MRK$``,#[R[$``,#[S+$``,#[S;$``,#[SK$``,#[S[$``,#[T+$``,#[T;$`
M`,#[TK$``,#[T[$``,#[U+$``,#[U;$``,#[UK$``,#[U[$``,#[V+$``,#[
MV;$``,#[VK$``,#[V[$``,#[W+$``,#[W;$``,#[WK$``,#[W[$``,#[X+$`
M`,#[X;$``,#[XK$``,#[X[$``,#[Y+$``,#[Y;$``,#[YK$``,#[Y[$``,#[
MZ+$``,#[Z;$``,#[ZK$``,#[Z[$``,#[[+$``,#[[;$``,#[[K$``,#[[[$`
M`%D>`````%T>`````%X>`````&4>`````&@>`````&L>`````&P>`````&T>
M`````&X>`````&\>`````'(>`````'@>`````'D>`````'H>`````'L>````
M`'P>``````D"`````#<"`````&8"`````.("`````+L-``````4.`````%T>
M<QX``"D.`````*X"`````*\"`````+`"`````+$"`````+("`````+,"````
M`+0"`````+4"`````+8"`````+<"`````+P-`````+T-`````+@"`````+D"
M`````+H"`````+L"`````+P"`````+T"`````+X"`````+\"`````"L"````
M`(,"`````(0"`````(4"`````+X-`````"H.`````"L.`````"P.`````"T.
M`````"X.`````"\.`````#`.`````#$.`````#(.````````````````````
M`````````````````````````````````"P"``````<.``````<.``````@.
M``````@.``````D.`````+P-`````+\-`````$#[0=,``$#[1-,``$#[1=,`
M``8.`````'`>7AX``.,"`````,`-`````,$-`````,#[0+```%(>`````%(>
M`````%,>`````%,>`````%0>`````%0>`````%4>`````%4>`````%8>````
M`%8>`````%<>`````%<>`````%@>`````%@>`````%D>`````%D>`````%H>
M`````%H>`````%L>`````%L>`````%P>`````%P>`````%T>`````%T>````
M`%X>`````%X>`````%\>`````%\>`````&`>`````&`>`````&$>`````&$>
M`````&(>`````&(>`````&,>`````&,>`````&,>`````&0>`````&0>````
M`&4>`````&4>`````&8>`````&<>`````&@>`````&D>`````&H>`````&L>
M`````&L>`````&L>`````&P>`````&P>`````&P>`````&T>`````&T>````
M`&T>`````&X>`````&X>`````&X>`````&\>`````&\>`````&\>`````'`>
M`````'$>`````'(>`````',>`````'0>`````'4>`````'4>`````'8>````
M`'8>`````'<>`````'<>`````'@>`````'D>`````'H>`````'L>`````'P>
M`````'T>`````'T>`````'X>`````'\>`````(`>`````($>`````%0>````
M`%<>`````%H>`````,#[E[```,#[F+```````````````````!X"`````!\"
M``````H.``````H.`````'<>>1X``"T"`````%(>`````%(>`````%,>````
M`%,>`````%0>`````%0>`````%4>`````%4>`````%8>`````%8>`````%<>
M`````%<>`````%@>`````%@>`````%D>`````%D>`````%H>`````%H>````
M`%L>`````%L>`````%P>`````%P>`````%T>`````%T>`````%X>`````%X>
M`````%\>`````%\>`````&`>`````&`>`````&$>`````&$>`````&(>````
M`&(>`````&,>`````&,>`````&,>`````&0>`````&0>`````&4>`````&4>
M`````&8>`````&<>`````&@>`````&D>`````&H>`````&L>`````&L>````
M`&L>`````&P>`````&P>`````&P>`````&T>`````&T>`````&T>`````&X>
M`````&X>`````&X>`````&\>`````&\>`````&\>`````'`>`````'$>````
M`'(>`````',>`````'0>`````'4>`````'4>`````'8>`````'8>`````'<>
M`````'<>`````'@>`````'D>`````'H>`````'L>`````'P>`````'T>````
M`'T>`````'X>`````'\>`````(`>`````($>`````%0>`````%<>`````%H>
M`````'T>`````'X>`````'\>`````(`>`````"X"``````L.``````P.````
M``P.`````%L>91X``$#[`,X``$#[*,X``$#[-LX``$#[/\X``$#[6<X``$#[
MA<X``$#[C,X``$#[H,X``$#[NLX``$#[/]$``$#[9=$``$#[:]$``$#[@M$`
M`$#[EM$``$#[J]$``$#[X-$``$#[]=$``$#[`-(``$#[F](``$#[^=(``$#[
M%=,``$#[&M,``$#[.-,``$#[0=,``$#[7-,``$#[:=,``$#[@M,``$#[MM,`
M`$#[R-,``$#[X],``$#[U]8``$#[']<``$#[Z]@``$#[`MD``$#["MD``$#[
M%=D``$#[)]D``$#[<]D``$#[4-L``$#[@-L``$#[^-L``$#[#]P``$#[(MP`
M`$#[.-P``$#[;MP``$#[<=P``$#[V]T``$#[Y=T``$#[\=T``$#[_MT``$#[
M<MX``$#[>MX``$#[?]X``$#[]-X``$#[_MX``$#["]\``$#[$]\``$#[4-\`
M`$#[8=\``$#[<]\``$#[P]\``$#[".(``$#[-N(``$#[2^(``$#[+^4``$#[
M-.4``$#[A^4``$#[E^4``$#[I.4``$#[N>4``$#[X.4``$#[Y>4``$#[\.8`
M`$#[".<``$#[*.<``$#[(.L``$#[8NL``$#[>>L``$#[L^L``$#[R^L``$#[
MU.L``$#[V^L``$#[#^P``$#[%.P``$#[-.P``$#[:_```$#[*O(``$#[-O(`
M`$#[._(``$#[/_(``$#[1_(``$#[6?(``$#[6_(``$#[K/(``$#[A/,``$#[
MB?,``$#[W/0``$#[YO0``$#[&/4``$#['_4``$#[*/4``$#[,/4``$#[B_4`
M`$#[DO4``$#[=O8``$#[??8``$#[KO8``$#[O_8``$#[[O8``$#[V_<``$#[
MXO<``$#[\_<``$#[.OD``$#[N/D``$#[OOD``$#[=/H``$#[R_H``$#[^?H`
M`$#[<_P``$#[^/P``$#[-O\``$#[4?\``$#[BO\``$#[O?\``$'[`8```$'[
M#(```$'[$H```$'[,X```$'[?X```$'[B8```$'[XX$``$'[ZH$``$'[\X$`
M`$'[_($``$'[#((``$'[&X(``$'['X(``$'[;H(``$'[<H(``$'[>((``$'[
M388``$'[:X8``$'[0(@``$'[3(@``$'[8X@``$'[?HD``$'[BXD``$'[THD`
M`$'[`(H``$'[-XP``$'[1HP``$'[58P``$'[>(P``$'[G8P``$'[9(T``$'[
M<(T``$'[LXT``$'[JXX``$'[RHX``$'[FX\``$'[L(\``$'[M8\``$'[D9``
M`$'[29$``$'[QI$``$'[S)$``$'[T9$``$'[=Y4``$'[@)4``$'[')8``$'[
MMI8``$'[N98``$'[Z)8``$'[49<``$'[7I<``$'[8I<``$'[:9<``$'[RY<`
M`$'[[9<``$'[\Y<``$'[`9@``$'[J)@``$'[VY@``$'[WY@``$'[EID``$'[
MF9D``$'[K)D``$'[J)H``$'[V)H``$'[WYH``$'[)9L``$'[+YL``$'[,IL`
M`$'[/)L``$'[6IL``$'[Y9P``$'[=9X``$'[?YX``$'[I9X``$'[NYX``$'[
MPYX``$'[S9X``$'[T9X``$'[^9X``$'[_9X``$'[#I\``$'[$Y\``$'[()\`
M`$'[.Y\``$'[2I\``$'[4I\``$'[C9\``$'[G)\``$'[H)\``,#[UJ\``,#[
MUZ\``,#[V*\``,#[V:\``,#[VJ\``,#[VZ\``,#[W*\``,#[W:\``,#[WJ\`
M`,#[WZ\``,#[X*\``,#[X:\``,#[XJ\``,#[XZ\``,#[Y*\``,#[Y:\``,#[
MYJ\``,#[YZ\``,#[Z*\``,#[Z:\``,#[ZJ\``,#[ZZ\``,#[[*\``,#[[:\`
M`,#[[J\``,#[[Z\``*\-`````+`-`````+$-`````+(-`````+,-`````+0-
M`````+4-`````+8-`````+<-`````+@-`````+D-`````+H-`````,#[_*\`
M`,#[_:\``,#[_J\``,#[_Z\``,#[`*X``,#[`:X``,#[`JX``,#[`ZX``,#[
M!*X``,#[!:X``,#[!JX``,#[!ZX``,#["*X``,#[":X``,#["JX``,#["ZX`
M`,#[#*X``,#[#:X``,#[#JX``,#[#ZX``,#[$*X``,#[$:X``,#[$JX``,#[
M$ZX``,#[%*X``,#[%:X``,#[%JX``,#[%ZX``,#[&*X``,#[&:X``,#[&JX`
M`,#[&ZX``,#['*X``,#[':X``,#['JX``,#['ZX``,#[(*X``,#[(:X``,#[
M(JX``,#[(ZX``,#[)*X``,#[):X``,#[)JX``,#[)ZX``,#[**X``,#[*:X`
M`,#[*JX``,#[*ZX``,#[+*X``,#[+:X``,#[+JX``,#[+ZX``,#[,*X``,#[
M,:X``,#[,JX``,#[,ZX``,#[-*X``,#[-:X``,#[-JX``,#[-ZX``,#[.*X`
M`,#[.:X``,#[.JX``,#[.ZX``,#[/*X``,#[/:X``,#[/JX``,#[/ZX``,#[
M0*X``,#[0:X``,#[0JX``,#[0ZX``,#[1*X``,#[1:X``,#[1JX``,#[1ZX`
M`,#[2*X``,#[2:X``,#[2JX``,#[2ZX``,#[3*X``,#[3:X``,#[3JX``,#[
M3ZX``,#[4*X``,#[4:X``,#[4JX``,#[4ZX``,#[5*X``,#[5:X``,#[5JX`
M`,#[5ZX``,#[6*X``,#[6:X``,#[6JX``,#[6ZX``,#[7*X``,#[7:X``,#[
M7JX``,#[7ZX``,#[8*X``,#[8:X``,#[8JX``,#[8ZX``,#[9*X``,#[9:X`
M`,#[9JX``,#[9ZX``,#[:*X``,#[::X``,#[:JX``,#[:ZX``,#[;*X``,#[
M;:X``,#[;JX``,#[;ZX``,#[<*X``,#[<:X``,#[<JX``,#[<ZX``,#[=*X`
M`,#[=:X``,#[=JX``,#[=ZX``,#[>*X``,#[>:X``,#[>JX``,#[>ZX``,#[
M?*X``,#[?:X``,#[?JX``,#[?ZX``$#[-LX``$#[@M,``$#[6\X``$#[6LX`
M`$#[6<X``$#[N\X``$#[@M$``$#[X-$``$#[`-(``$#[`M(``$#[7-,``$#[
M:=,``$#[#]P``$#[#]P``$#[(MP``$#[(]P``$#[(MP``$#[(]P``$#[\]T`
M`$#[>MX``$#[4=\``$#[4-\``$#[Q-\``$#[P]\``$#[3.(``$#[->4``,#[
MFJX``$#[X>4``$#[Y>4``$#[".<``$#[>NL``$#[S>L``$#[$>P``$#[->P`
M`$#[.NP``$#[;/```$#[*_(``$#[*_(``$#[+,X``$#[6_(``$#[K?(``$#[
MB_,``$#[B_4``$#[[O8``$#[.OD``$#[._D``$#[^?H``$#[^?P``$#[G_X`
M`$#[4_\``$#[4O\``$#[4_\``$#[4_\``$#[4O\``$#[BO\``$#[BO\``$#[
MB_\``$'[`H```$'[@(```$'[?X```$'[B8```$'[_($``$'[>8(``$'[>8(`
M`$'[>8(``$'[3H8``$'[9(@``$'[@(D``$'[?XD``$'[P8D``$'[THD``$'[
MTHD``$'[H(L``$'['8T``$'[LXT``$'[9H\``$'[MH\``$'[MH\``$'[MH\`
M`$'[D9```$'[A90``$'[=Y4``$'[>)4``$'[?Y4``$'[Z)4``$'[')8``$'[
M'98``$'[Z)8``$'[4I<``$'[YI<``$'[=9@``$'[SI@``$'[WI@``$'[WY@`
M`$'[X)@``$'[X)@``$'[8YD``$'[EID``$'[;)H``$'[J)H``$'[/)L``$'[
M?)P``$'['YX``$'[=9X``$'[IIX``$'[Q)X``$'[_IX``$'[2I\``$'[4)\`
M`$'[4I\``$'[?Y\``$'[C9\``$'[F9\``$'[G)\``$'[G)\``$'[GY\``,#[
M]*X``,#[]:X``,#[]JX``,#[]ZX``,#[^*X``,#[^:X``,#[^JX``,#[^ZX`
M`,#[_*X``,#[_:X``,#[_JX``,#[_ZX``!L*`````!P*`````!T*`````!X*
M`````!\*`````"`*`````"$*`````"(*`````",*`````"0*`````"4*````
M`"8*`````"<*`````"@*`````,#[#JL``,#[#ZL``,#[$*L``,#[$:L``,#[
M$JL``,#[$ZL``,#[%*L``,#[%:L``,#[%JL``,#[%ZL``,#[&*L``,#[&:L`
M`,#[&JL``,#[&ZL``,#['*L``,#[':L``,#['JL``,#['ZL``,#[(*L``,#[
M(:L``,#[(JL``,#[(ZL``,#[)*L``,#[):L``,#[)JL``,#[)ZL``,#[**L`
M`,#[*:L``,#[*JL``,#[*ZL``,#[+*L``,#[+:L``,#[+JL``,#[+ZL``,#[
M,*L``,#[,:L``,#[,JL``,#[,ZL``,#[-*L``,#[-:L``,#[-JL``,#[-ZL`
M`,#[.*L``,#[.:L``,#[.JL``,#[.ZL``,#[/*L``,#[/:L``,#[/JL``,#[
M/ZL``,#[0*L``,#[0:L``,#[0JL``,#[0ZL``,#[1*L``,#[1:L``,#[1JL`
M`,#[1ZL``,#[2*L``,#[2:L``,#[2JL``,#[2ZL``,#[3*L``,#[3:L``,#[
M3JL``,#[3ZL``,#[4*L``,#[4:L``,#[4JL``,#[4ZL``,#[5*L``,#[5:L`
M`,#[5JL``,#[5ZL``,#[6*L``,#[6:L``,#[6JL``,#[6ZL``,#[7*L``,#[
M7:L``,#[7JL``,#[7ZL``,#[8*L``,#[8:L``,#[8JL``,#[8ZL``,#[9*L`
M`,#[9:L``,#[9JL``,#[9ZL``,#[:*L``,#[::L``,#[:JL``,#[:ZL``,#[
M;*L``,#[;:L``,#[;JL``,#[;ZL``,#[<*L``,#[<:L``,#[<JL``,#[<ZL`
M`,#[=*L``,#[=:L``,#[=JL``,#[=ZL``,#[>*L``,#[>:L``,#[>JL``,#[
M>ZL``,#[?*L``,#[?:L``,#[?JL``,#[?ZL``,#[@*L``,#[@:L``,#[@JL`
M`,#[@ZL``,#[A*L``,#[A:L``,#[AJL``,#[AZL``,#[B*L``,#[B:L``,#[
MBJL``,#[BZL``,#[C*L``,#[C:L``,#[CJL``,#[CZL``,#[D*L``,#[D:L`
M`,#[DJL``,#[DZL``,#[E*L``,#[E:L``,#[EJL``,#[EZL``,#[F*L``,#[
MF:L``,#[FJL``,#[FZL``,#[G*L``,#[G:L``,#[GJL``,#[GZL``,#[H*L`
M`,#[H:L``,#[HJL``,#[HZL``,#[I*L``,#[I:L``,#[IJL``,#[IZL``,#[
MJ*L``,#[J:L``,#[JJL``,#[JZL``,#[K*L``,#[K:L``,#[KJL``,#[KZL`
M`,#[L*L``,#[L:L``,#[LJL``,#[LZL``,#[M*L``,#[M:L``,#[MJL``,#[
MMZL``,#[N*L``,#[N:L``,#[NJL``,#[NZL``,#[O*L``,#[O:L``,#[OJL`
M`,#[OZL``,#[P*L``,#[P:L``,#[PJL``,#[PZL``,#[Q*L``,#[Q:L``,#[
MQJL``,#[QZL``,#[R*L``,#[R:L``,#[RJL``,#[RZL``,#[S*L``,#[S:L`
M`,#[SJL``,#[SZL``,#[T*L``,#[T:L``,#[TJL``,#[TZL``,#[U*L``,#[
MU:L``,#[UJL``,#[UZL``,#[V*L``,#[V:L``,#[VJL``,#[VZL``,#[W*L`
M`,#[W:L``,#[WJL``,#[WZL``,#[X*L``,#[X:L``,#[XJL``,#[XZL``,#[
MY*L``,#[Y:L``,#[YJL``,#[YZL``,#[Z*L``,#[Z:L``,#[ZJL``,#[ZZL`
M`,#[[*L``,#[[:L``,#[[JL``,#[[ZL``,#[\*L``,#[\:L``,#[\JL``,#[
M\ZL``,#[]*L``,#[]:L``,#[]JL``,#[]ZL``,#[^*L``,#[^:L``,#[^JL`
M`,#[^ZL``,#[_*L``,#[_:L``,#[_JL``,#[_ZL``"`)```````````A"0``
M````````(@D``````````",)```````````D"0``````````)0D`````````
M`"8)```````````G"0``````````*`D``````````"D)```````````J"0``
M````````*PD``````````$L$2P1+!$L$```L"0``````````+0D`````````
M`"X)```````````O"0``````````,`D``````````#$)```````````R"0``
M````````,PD``````````#0)```````````U"0``````````-@D`````````
M`#<)```````````X"0``````````.0D``````````#H)```````````["0``
M````````/`D``````````#T)```````````^"0``````````/PD`````````
M`$`)``````````!!"0``````````0@D``````````$,)``````````!$"0``
M````````10D``````````$8)``````````!'"0``````````2`D`````````
M`$D)``````````!*"0``````````2PD``````````$P)``````````!-"0``
M````````3@D``````````$\)``````````!0"0``````````40D`````````
M`%()``````````!3"0``````````5`D``````````%4)``````````!6"0``
M````````5PD``````````%@)``````````!9"0``````````6@D`````````
M`%L)``````````!<"0``````````70D``````````%X)``````````!?"0``
M````````8`D``````````&$)``````````!B"0``````````8PD`````````
M`&0)``````````!E"0``````````9@D``````````&<)``````````!H"0``
M````````:0D``````````&H)``````````!K"0``````````;`D`````````
M`&T)``````````!N"0``````````;PD``````````'`)``````````!Q"0``
M````````<@D``````````',)``````````!T"0``````````=0D`````````
M`'8)``````````!W"0``````````>`D``````````'D)``````````!Z"0``
M````````>PD``````````'P)``````````!]"0``````````?@D`````````
M`'\)``````````"`"0``````````@0D``````````(()``````````"#"0``
M````````A`D``````````(4)``````````"&"0``````````APD`````````
M`(@)``````````")"0``````````B@D``````````(L)``````````","0``
M````````C0D``````````(X)``````````"/"0``````````D`D`````````
M`)$)``````````"2"0``````````/0(]`BT$`````"T$+00````````M!"T$
M+00`````DPD``````````)0)``````````"5"0``````````E@D`````````
M`)<)``````````"8"0``````````F0D``````````)H)``````````";"0``
M````````G`D``````````)T)``````````">"0``````````GPD`````````
M`*`)``````````"A"0``````````H@D``````````*,)``````````"D"0``
M````````I0D``````````*8)``````````"G"0``````````J`D`````````
M`*D)``````````"J"0``````````JPD``````````*P)``````````"M"0``
M````````K@D``````````*\)``````````"P"0``````````L0D`````````
M`+()``````````"S"0``````````M`D``````````+4)``````````"V"0``
M````````MPD``````````+@)``````````"Y"0``````````N@D`````````
M`+L)``````````"\"0``````````O0D``````````+X)``````````"_"0``
M````````P`D``````````,$)``````````#""0``````````PPD`````````
M`,0)``````````#%"0``````````Q@D``````````,<)``````````#("0``
M````````R0D``````````,H)``````````#+"0``````````S`D`````````
M`,T)``````````#."0``````````SPD``````````-`)``````````#1"0``
M````````T@D``````````-,)``````````#4"0``````````U0D`````````
M`-8)``````````#7"0``````````V`D``````````-D)``````````#:"0``
M````````VPD``````````-P)``````````#="0``````````W@D`````````
M`-\)``````````#@"0``````````X0D``````````.()``````````#C"0``
M````````Y`D``````````.4)``````````#F"0``````````YPD`````````
M`.@)``````````#I"0``````````Z@D``````````.L)``````````#L"0``
M````````[0D``````````.X)``````````#O"0``````````\`D`````````
M`/$)``````````#R"0``````````\PD``````````/0)``````````#U"0``
M````````]@D``````````/<)``````````#X"0``````````^`D`````````
M`/D)``````````#Z"0``````````^PD``````````/P)``````````#]"0``
M````````_@D``````````/\)````````````"@```````````0H`````````
M``(*```````````#"@``````````!`H```````````4*```````````&"@``
M````````!PH```````````@*```````````)"@``````````"@H`````````
M``L*```````````,"@``````````#0H```````````X*```````````/"@``
M````````$`H``````````!$*```````````2"@``````````$PH`````````
M`!0*```````````5"@``````````%@H``````````!<*```````````8"@``
M````````&0H``````````!H*```````````X"```.0@``#H(```["```/`@`
M`#T(```^"```/P@``$`(``!!"```0@@``$,(``!$"```10@``$8(``!'"```
M2`@``$D(``!*"```2P@``$P(``!-"```3@@``$\(``!0"```40@``%((``!3
M"```5`@``%4(``!6"```5P@``%@(``!9"```6@@``%L(``!<"```70@``%X(
M``!?"```8`@``&$(``!B"```8P@``&0(``!E"```9@@``&<(``!H"```:0@`
M`&H(``!K"```;`@``&T(``!N"```;P@``'`(``!Q"```<@@``',(``!T"```
M=0@``'8(``!W"```>`@``'D(``!Z"```>P@``'P(``!]"```?@@``'\(``"`
M"```@0@``(((``"#"```A`@``(4(``"&"```AP@``(@(``")"```B@@``(L(
M``","```C0@``(X(``"/"```D`@``)$(``"2"```DP@``)0(``"5"```E@@`
M`)<(``"8"```F0@``)H(``";"```G`@``)T(``">"```GP@``*`(``"A"```
MH@@``*,(``"D"```I0@``*8(``"G"```J`@``*D(``"J"```JP@``*P(``"M
M"```K@@``*\(``"P"```L0@``+((``"S"```M`@``+4(``"V"```MP@``+@(
M``"Y"```N@@``)@"``"9`@``F@(``)L"``"<`@``G0(``)X"``"?`@``H`(`
M`*$"``"B`@``HP(``*0"``"E`@``I@(``*<"``"H`@``J0(``*H"``"K`@``
MK`(``*T"``"["```O`@``+T(``"^"```OP@``,`(``#!"```P@@``,,(``#$
M"```Q0@``,8(``#'"```R`@``,D(``#*"```RP@``,P(``#-"```S@@``,\(
M``#0"```T0@``-((``#3"```U`@``-4(``#6"```UP@``-@(``#9"```V@@`
M`-L(``#<"```W0@``-X(``#?"```X`@``.$(``#B"```XP@``.0(``#E"```
MY@@``.<(``#H"```Z0@``.H(``#K"```[`@``.T(``#N"```[P@``/`(``#Q
M"```\@@``/,(``#T"```]0@``/8(``#W"```^`@``/D(``#Z"```^P@``/P(
M``#]"```_@@``/\(````"0```0D```()```#"0``!`D```4)```&"0``!PD`
M``@)```)"0``"@D```L)```,"0``#0D```X)```/"0``$`D``!$)```2"0``
M$PD``!0)```5"0``%@D``!<)```8"0``&0D``!H)```;"0``'`D``!T)``"6
M`@``EP(``!X)```?"0``*0H``"H*```K"@``+`H``"T*```N"@``+PH``#`*
M```Q"@``,@H``#,*```T"@``-0H``#8*```W"@``.`H``#D*```Z"@``.PH`
M`#P*```]"@``/@H``#\*``!`"@``00H``$(*``!#"@``1`H``$4*``!&"@``
M1PH``$@*``!)"@``2@H``$L*``!,"@``30H``$X*``!/"@``4`H``%$*``!2
M"@``4PH``%0*``!5"@``5@H``%<*``!8"@``60H``%H*``!;"@``7`H``%T*
M``!>"@``7PH``&`*``!A"@``8@H``&,*``!D"@``90H``&8*``!G"@``:`H`
M`&D*``!J"@``:PH``&P*``!M"@``;@H``&\*``!P"@``<0H``'(*``!S"@``
M=`H``'4*``!V"@``=PH``'@*``!Y"@``>@H``'L*``!\"@``?0H``'X*``!_
M"@``@`H``($*``"""@``@PH``(0*``"%"@``A@H``(<*``"("@``B0H``(H*
M``"+"@``C`H``(T*``"."@``CPH``)`*``"1"@``D@H``),*``"4"@``E0H`
M`)8*``"7"@``F`H``)D*``":"@``FPH``)P*``"="@``G@H``)\*``"@"@``
MH0H``*(*``"C"@``I`H``*4*``"F"@``IPH``*@*``"I"@``J@H``*L*``"L
M"@``K0H``*X*``"O"@``L`H``+$*``"R"@``LPH``+0*``"U"@``M@H``+<*
M``"X"@``N0H``+H*``"["@``O`H``+T*``"^"@``OPH``,`*``#!"@``P@H`
M`,,*``#$"@``Q0H``,8*``#'"@``R`H``,D*``#*"@``RPH``,P*``#-"@``
MS@H``,\*``#0"@``T0H``-(*``#3"@``U`H``-4*``#6"@``UPH``-@*``#9
M"@``V@H``-L*``#<"@``W0H``-X*``#?"@``X`H``.$*``#B"@``XPH``.0*
M``#E"@``Y@H``.<*``#H"@``Z0H``.H*``#K"@``[`H``.T*``#N"@``[PH`
M`/`*``#Q"@``\@H``/,*``#T"@``]0H``/8*``#W"@``^`H``/D*``#Z"@``
M^PH``/P*``#]"@``_@H``/\*````"P```0L```(+```#"P``!`L```4+```&
M"P``!PL```@+```)"P``"@L```L+```,"P``#0L```X+```/"P``$`L``!$+
M```2"P``$PL``!0+```5"P``%@L``!<+```8"P``&0L``!H+```;"P``'`L`
M`!T+```>"P``'PL``"`+```A"P``(@L``",+```D"P``)0L``"8+```G"P``
M*`L``,#[`*<``'P'`````'T'`````'X'`````'\'`````,#[!:<``(`'````
M`($'`````(('`````(,'`````,#["J<``,#["Z<``(0'`````(4'`````(8'
M`````(<'`````(@'`````(D'`````(H'`````(L'`````(P'`````(T'````
M`(X'`````(\'`````)`'`````)$'`````)('`````),'`````)0'`````)4'
M`````)8'`````)<'`````)@'`````)D'`````)H'`````)L'`````)P'````
M`)T'`````)X'`````)\'`````,#[**<``*`'`````*$'`````*('`````*,'
M`````*0'`````*4'`````*8'`````*<'`````*@'`````*D'`````*H'````
M`*L'`````*P'`````*T'`````*X'`````*\'`````+`'`````+$'`````+('
M`````+,'`````+0'`````+4'`````+8'`````+<'`````+@'`````+D'````
M`+H'`````+L'`````+P'`````+T'`````+X'`````+\'`````,`'`````,$'
M`````,('`````,#[3*<``,,'`````,#[3J<``,0'`````,4'`````,8'````
M`,<'`````,#[4Z<``,#[5*<``,#[5:<``,@'`````,#[5Z<``,D'`````,H'
M`````,L'`````,P'`````,T'`````,X'`````,\'`````,#[7Z<``,#[8*<`
M`-`'`````-$'`````-('`````-,'`````-0'`````-4'`````-8'`````-<'
M`````-@'`````-D'`````-H'`````-L'`````-P'`````-T'`````-X'````
M`-\'`````.`'`````.$'`````.('`````.,'`````.0'`````"H.`````"L.
M`````"P.`````"T.`````"X.`````"\.`````#`.`````#$.`````#(.````
M`"H.*0X``"H.`````"L.`````"P.`````"T.`````"X.`````"\.`````#`.
M`````#$.`````#(.`````"H.*0X``"H.`````"L.`````"P.`````"T.````
M`"X.`````"\.`````#`.`````#$.`````#(.`````"H.*0X``.4'`````,#[
ME:<``,#[EJ<``,#[EZ<``.8'`````.<'`````.@'`````.D'`````.H'````
M`.L'`````.P'`````.T'`````.X'`````.\'`````/`'`````/$'`````/('
M`````/,'`````/0'`````/4'`````/8'`````/<'`````/@'`````/D'````
M`/H'`````/L'`````/P'`````/T'`````,#[L*<``/X'`````/\'```````(
M``````$(``````((``````,(``````0(``````4(``````8(``````<(````
M``@(``````D(``````H(``````L(`````,#[OZ<``,#[P*<``,#[P:<``,#[
MPJ<``,#[PZ<``,#[Q*<``,#[Q:<``,#[QJ<``,#[QZ<``,#[R*<``,#[R:<`
M`,#[RJ<``,#[RZ<``,#[S*<``,#[S:<``,#[SJ<``,#[SZ<```P(``````T(
M``````X(``````\(`````!`(`````!$(`````!((`````!,(`````!0(````
M`!4(`````!8(`````!<(`````!@(`````!D(`````!H(`````!L(`````!P(
M`````!T(`````!X(`````!\(`````"`(`````"$(`````"((`````",(````
M`"0(`````"4(`````"8(`````"<(`````,#[[*<``,#[[:<``,#[[J<``,#[
M[Z<``"@(`````"D(`````"H(`````"L(`````"P(`````"T(`````"X(````
M`"\(`````#`(`````#$(`````#((`````#,(`````#0(`````#4(`````#8(
M`````#<(`````/P&`````/T&`````/X&`````/\&```````'``````$'````
M``('``````,'``````0'``````4'``````8'``````<'``````@'``````D'
M``````H'``````L'``````P'``````T'``````X'``````\'`````!`'````
M`!$'`````!('`````!,'`````,#[&*8``!0'`````!4'`````!8'`````!<'
M`````!@'`````!D'`````!H'`````!L'`````!P'`````!T'`````!X'````
M`!\'`````"`'`````"$'`````"('`````",'`````"0'`````"4'`````"8'
M`````"<'`````"@'`````"D'`````"H'`````"\+`````#`+`````#$+````
M`#(+`````#,+`````#0+`````#4+`````#8+`````"L'`````"P'`````"T'
M`````"X'`````"\'`````#`'`````#$'`````#('`````#,'`````#0'````
M`#4'`````#8'`````#<'`````#@'`````#D'`````#H'`````#L'`````#P'
M`````#T'`````#X'`````#\'`````$`'`````$$'`````$('`````$,'````
M`$0'`````$4'`````$8'`````$<'`````$@'`````$D'`````$H'`````$L'
M`````$P'`````$T'`````$X'`````$\'`````%`'`````%$'`````%('````
M`%,'`````%0'`````%4'`````%8'`````%<'`````%@'`````%D'`````%H'
M`````%L'`````%P'`````%T'`````%X'`````%\'`````"L-`````"P-````
M`"T-`````&`'`````&$'`````&('`````&,'`````&0'`````&4'`````&8'
M`````&<'`````&@'`````&D'`````&H'`````&L'`````&P'`````&T'````
M`,#[?J8``,#[?Z8``&X'`````&\'`````'`'`````'$'`````'('`````','
M`````'0'`````'4'`````'8'`````'<'`````"D+`````"H+`````"L+````
M`"P+`````"T+`````"X+`````'@'`````'D'`````,#[DJ8``,#[DZ8``,#[
ME*8``,#[E:8``,#[EJ8``,#[EZ8``,#[F*8``,#[F:8``,#[FJ8``,#[FZ8`
M`,#[G*8``,#[G:8``,#[GJ8``,#[GZ8``'H'`````'L'`````,#[HJ8``,#[
MHZ8``,#[I*8``,#[I:8``,#[IJ8``,#[IZ8``,#[J*8``,#[J:8``,#[JJ8`
M`,#[JZ8``,#[K*8``,#[K:8``,#[KJ8``,#[KZ8``,#[L*8``,#[L:8``,#[
MLJ8``,#[LZ8``,#[M*8``,#[M:8``,#[MJ8``,#[MZ8``,#[N*8``,#[N:8`
M`,#[NJ8``,#[NZ8``,#[O*8``,#[O:8``,#[OJ8``,#[OZ8``,#[P*8``,#[
MP:8``,#[PJ8``,#[PZ8``,#[Q*8``,#[Q:8``,#[QJ8``,#[QZ8``,#[R*8`
M`,#[R:8``,#[RJ8``,#[RZ8``,#[S*8``,#[S:8``,#[SJ8``,#[SZ8``,#[
MT*8``,#[T:8``,#[TJ8``,#[TZ8``,#[U*8``,#[U:8``,#[UJ8``,#[UZ8`
M`,#[V*8``,#[V:8``,#[VJ8``,#[VZ8``,#[W*8``,#[W:8``,#[WJ8``,#[
MWZ8``,#[X*8``,#[X:8``,#[XJ8``,#[XZ8``,#[Y*8``,#[Y:8``,#[YJ8`
M`,#[YZ8``,#[Z*8``,#[Z:8``,#[ZJ8``,#[ZZ8``,#[[*8``,#[[:8``,#[
M[J8``,#[[Z8``,#[\*8``,#[\:8``,#[\J8``,#[\Z8``,#[]*8``,#[]:8`
M`,#[]J8``,#[]Z8``,#[^*8``,#[^:8``,#[^J8``,#[^Z8``,#[_*8``,#[
M_:8``,#[_J8``,#[_Z8``/P%``#]!0``_@4``/\%````!@```08```(&```#
M!@``!`8```4&```&!@``!P8```@&```)!@``"@8```L&```,!@``#08```X&
M```/!@``$`8``!$&```2!@``$P8``!0&```5!@``%@8``!<&```8!@``&08`
M`!H&```;!@``'`8``!T&```>!@``'P8``"`&```A!@``(@8``",&```D!@``
M)08``"8&```G!@``*`8``"D&```J!@``*P8``"P&```M!@``+@8``"\&```P
M!@``,08``#(&```S!@``-`8``#4&```V!@``-P8``#@&```Y!@``.@8``#L&
M```\!@``/08``#X&```_!@``0`8``$$&``!"!@``0P8``$0&``!%!@``1@8`
M`$<&``!(!@``208``$H&``!+!@``3`8``$T&``!.!@``3P8``%`&``!1!@``
M4@8``%,&``!4!@``508``%8&``!7!@``6`8``%D&``!:!@``6P8``%P&``!=
M!@``7@8``%\&``!@!@``808``&(&``!C!@``9`8``&4&``!F!@``9P8``&@&
M``!I!@``:@8``&L&``!L!@``;08``&X&``!O!@``<`8``'$&``!R!@``<P8`
M`'0&``!U!@``=@8``'<&``!X!@``>08``'H&``![!@``?`8``'T&``!^!@``
M?P8``(`&``"!!@``@@8``(,&``"$!@``A08``(8&``"'!@``B`8``(D&``"*
M!@``BP8``(P&``"-!@``C@8``(\&``"0!@``D08``)(&``"3!@``E`8``)4&
M``"6!@``EP8``)@&``"9!@``F@8``)L&``"<!@``G08``)X&``"?!@``H`8`
M`*$&``"B!@``HP8``*0&``"E!@``I@8``*<&``"H!@``J08``*H&``"K!@``
MK`8``*T&``"N!@``KP8``+`&``"Q!@``L@8``+,&``"T!@``M08``+8&``"W
M!@``N`8``+D&``"Z!@``NP8``+P&``"]!@``O@8``+\&``#`!@``P08``,(&
M``##!@``Q`8``,4&``#&!@``QP8``,@&``#)!@``R@8``,L&``#,!@``S08`
M`,X&``#/!@``T`8``-$&``#2!@``TP8``-0&``#5!@``U@8``-<&``#8!@``
MV08``-H&``#;!@``W`8``-T&``#>!@``WP8``.`&``#A!@``X@8``.,&``#D
M!@``Y08``.8&``#G!@``Z`8``.D&``#J!@``ZP8``.P&``#M!@``[@8``.\&
M``#P!@``\08``/(&``#S!@``]`8``/4&``#V!@``]P8``/@&``#Y!@``^@8`
M`/L&``#*!0``````````RP4``````````,P%``````````#-!0``````````
MS@4``````````,\%``````````#0!0``````````T04``````````-(%````
M``````#3!0``````````U`4``````````-4%``````````#6!0``````````
MUP4``````````-@%``````````#9!0``````````V@4``````````-L%````
M``````#<!0``````````W04``````````-X%``````````#?!0``````````
MX`4``````````.$%``````````#B!0``````````XP4``````````.0%````
M``````#E!0``````````Y@4``````````.<%``````````#H!0``````````
MZ04``````````.H%``````````#K!0``````````[`4``````````.T%````
M``````#N!0``````````[P4``````````/`%``````````#`^R>D````````
MP/LHI````````,#[*:0```````#`^RJD````````P/LKI````````,#[+*0`
M``````#`^RVD````````P/LNI````````,#[+Z0```````#`^S"D````````
MP/LQI````````,#[,J0```````#`^S.D````````P/LTI````````,#[-:0`
M``````#`^S:D````````P/LWI````````,#[.*0```````#`^SFD````````
MP/LZI````````,#[.Z0```````#`^SRD````````P/L]I````````,#[/J0`
M``````#`^S^D````````\04``````````/(%``````````#S!0``````````
M]`4``````````/4%``````````#V!0``````````]P4``````````/@%````
M``````#Y!0``````````^@4``````````/L%``````````#`^TND````````
MP/M,I````````,#[3:0```````#`^TZD````````P/M/I````````,#[4*0`
M``````#`^U&D````````P/M2I````````,#[4Z0```````#`^U2D````````
MP/M5I````````,#[5J0```````#`^U>D````````P/M8I````````,#[6:0`
M``````#`^UJD````````P/M;I````````,#[7*0```````#`^UVD````````
MP/M>I````````,#[7Z0````````J#@``````````*PX``````````"P.````
M```````M#@``````````+@X``````````"\.```````````P#@``````````
M,0X``````````#(.```````````J#BD.````````*@XJ#@```````"H.*PX`
M```````J#BP.````````*@XM#@```````"H.+@X````````J#B\.````````
M*@XP#@```````"H.,0X````````J#C(.````````*PXI#@```````(@"*@Z)
M`@````"(`BL.B0(`````B`(L#HD"`````(@"+0Z)`@````"(`BX.B0(`````
MB`(O#HD"`````(@",`Z)`@````"(`C$.B0(`````B`(R#HD"`````(@"*@XI
M#HD"``"(`BH.*@Z)`@``B`(J#BL.B0(``(@"*@XL#HD"``"(`BH.+0Z)`@``
MB`(J#BX.B0(``(@"*@XO#HD"``"(`BH.,`Z)`@``B`(J#C$.B0(``(@"*@XR
M#HD"``"(`BL.*0Z)`@``*@Y=`@```````"L.70(````````L#ET"````````
M+0Y=`@```````"X.70(````````O#ET"````````,`Y=`@```````#$.70(`
M```````R#ET"````````*@XI#ET"`````"H.*@Y=`@`````J#BL.70(`````
M*@XL#ET"`````"H.+0Y=`@`````J#BX.70(`````*@XO#ET"`````"H.,`Y=
M`@`````J#C$.70(`````*@XR#ET"`````"L.*0Y=`@````"(`C,.B0(`````
MB`)*#HD"`````(@"8`Z)`@````"(`FT.B0(`````B`*+#HD"`````(@"N0Z)
M`@````"(`L$.B0(`````B`+A#HD"`````(@"^PZ)`@````"(`A`/B0(`````
MB`(A#XD"`````(@"+@^)`@````"(`EL/B0(`````B`)D#XD"`````(@"@@^)
M`@````"(`J</B0(`````B`*T#XD"`````(@"P`^)`@````"(`NH/B0(`````
MB`("$(D"`````(@"'Q")`@````"(`D00B0(`````B`)1$(D"`````(@"6A")
M`@````"(`EX0B0(`````B`)J$(D"`````#,.``````````!*#@``````````
M8`X``````````&T.``````````"+#@``````````N0X``````````,$.````
M``````#A#@``````````^PX``````````!`/```````````A#P``````````
M+@\``````````%L/``````````!D#P``````````@@\``````````*</````
M``````"T#P``````````P`\``````````.H/```````````"$```````````
M'Q```````````$00``````````!1$```````````6A```````````%X0````
M``````!J$```````````,PX``````````$H.``````````!@#@``````````
M;0X``````````(L.``````````"Y#@``````````P0X``````````.$.````
M``````#[#@``````````$`\``````````"$/```````````N#P``````````
M6P\``````````&0/``````````""#P``````````IP\``````````+0/````
M``````#`#P``````````Z@\```````````(0```````````?$```````````
M1!```````````%$0``````````!:$```````````7A```````````&H0````
M```````I#@``````````*@XJ#@```````"H.*PX````````J#BP.````````
M*@XM#@```````"H.+@X````````J#B\.````````*@XP#@```````"H.,0X`
M```````J#C(.````````*PXI#@```````"H.```````````K#@``````````
M+`X``````````"T.```````````N#@``````````+PX``````````#`.````
M```````Q#@``````````,@X``````````"H.*0X````````I#@``````````
M^P0`````_`0`````_00`````_@0`````_P0```````4``````04``````@4`
M`````P4`````!`4`````!04`````!@4`````!P4`````"`4`````"04`````
M"@4`````"P4`````#`4`````#04`````#@4`````#P4`````$`4`````$04`
M````$@4`````$P4`````%`4`````%04`````%@4`````%P4`````&`4`````
M&04`````&@4`````&P4`````'`4`````'04`````'@4`````'P4`````(`4`
M````(04`````(@4`````(P4`````K@(`````KP(`````)`4`````)04`````
M)@4`````)P4`````*`4`````*04`````*@4`````*P4`````+`4`````+04`
M````+@4`````+P4`````,`4`````,04`````,@4`````,P4`````-`4`````
M-04`````-@4`````-P4`````.`4`````.04`````.@4`````.P4`````/`4`
M````/04`````/@4`````/P4`````0`4`````004`````0@4`````0P4`````
M1`4`````104`````1@4`````1P4`````2`4`````204`````2@4`````2P4`
M````3`4`````304`````3@4`````3P4`````4`4`````404`````4@4`````
M4P4`````5`4`````504`````5@4`````5P4`````6`4`````604`````6@4`
M````6P4`````7`4`````704`````7@4`````7P4`````8`4`````804`````
M8@4`````8P4`````9`4`````904`````9@4`````9P4`````:`4`````:04`
M````:@4`````:P4`````;`4`````;04`````;@4`````;P4`````<`4`````
M<04`````<@4`````<P4`````=`4`````=04`````=@4`````=P4`````>`4`
M````>04`````>@4`````>P4`````?`4`````?04`````?@4`````?P4`````
M@`4`````@04`````@@4`````@P4`````A`4`````A04`````A@4`````AP4`
M````B`4`````B04`````B@4`````BP4`````C`4`````C04`````C@4`````
MCP4`````D`4`````D04`````D@4`````DP4`````E`4`````E04`````E@4`
M````EP4`````F`4`````F04`````F@4`````FP4`````G`4`````G04`````
MG@4`````GP4`````H`4`````H04`````H@4`````HP4`````I`4`````I04`
M````I@4`````IP4`````J`4`````J04`````J@4`````JP4`````K`4`````
MK04`````K@4`````KP4`````L`4`````L04`````L@4`````LP4`````M`4`
M````M04`````M@4`````MP4`````N`4`````N04`````N@4`````NP4`````
MO`4`````O04`````O@4`````OP4`````P`4`````P04`````P@4`````PP4`
M````Q`4`````Q04`````Q@4`````QP4`````R`4`````R04`````P/O1HP``
MP/O2HP``P/O3HP``P/O4HP``P/O5HP``P/O6HP``P/O7HP``P/O8HP``P/O9
MHP``P/O:HP``P/O;HP``P/O<HP``P/O=HP``P/O>HP``P/O?HP``P/O@HP``
MP/OAHP``P/OBHP``P/OCHP``P/ODHP``P/OEHP``P/OFHP``P/OGHP``P/OH
MHP``P/OIHP``P/OJHP``P/OKHP``P/OLHP``P/OMHP``P/ONHP``P/OOHP``
MP/OPHP``P/OQHP``P/ORHP``P/OSHP``P/OTHP``P/OUHP``P/OVHP``P/OW
MHP``P/OXHP``P/OYHP``P/OZHP``P/O[HP``P/O\HP``P/O]HP``P/O^HP``
MP/O_HP``&`0````````9!````````!H$````````&P0````````;!```````
M`!P$````````'00````````>!````````!\$````````'P0````````@!```
M`````"$$````````(00````````B!````````"0$````````)00````````F
M!````````"<$````````-`0````````U!````````#8$````````-P0`````
M```X!````````#D$````````.@0````````[!````````#P$````````/00`
M```````^!````````#\$````````0`0```````!!!````````$($````````
M0P0```````!$!````````$4$````````100```````!&!````````$8$````
M````1P0```````!(!````````$D$````````2@0```````!+!````````$L$
M2P0`````2P1+!$L$``!,!````````$P$3`0`````3`1,!$P$``!-!```````
M`$X$````````3P0```````!0!````````%$$````````4@0```````!3!```
M`````%0$````````500```````!6!````````%<$````````6`0```````!9
M!````````%H$````````6P0```````!<!````````%@$````````700`````
M``!>!````````%X$````````7P0```````!@!````````%\$````````800`
M``````!A!````````&($````````8P0```````!D!````````&4$````````
M9@0```````!G!````````&@$````````:00```````!J!````````&L$````
M````;`0```````!M!````````&X$````````;P0```````!P!````````'$$
M````````<@0```````!S!````````'0$````````=00```````!V!```````
M`'<$````````+00```````!X!````````'@$````````>00```````!Z!```
M`````'L$````````?`0```````!]!````````'X$````````?P0```````"`
M!````````($$````````@@0```````!E!````````"P$````````+@0`````
M``!Z!````````'L$````````@P0```````"$!````````(,$````````A`0`
M``````"%!````````(8$````````A00```````"&!````````(<$````````
MB`0```````")!````````(H$````````BP0```````",!````````(<$````
M````B`0```````"-!````````(X$````````C00```````".!````````(\$
M````````D`0```````"/!````````)`$````````D00```````"2!```````
M`),$````````E`0```````"5!````````)8$````````EP0```````"8!```
M`````)D$````````F@0```````";!````````)P$````````G00```````">
M!````````)\$````````H`0```````"A!````````*($````````HP0`````
M``"D!````````*4$````````I@0```````"G!````````*@$````````J00`
M``````"J!````````*L$````````K`0```````"M!````````*X$````````
MKP0```````"P!````````+$$````````L@0```````"I!````````*\$````
M````L`0```````"R!````````+,$````````M`0```````"U!````````+8$
M````````MP0```````"X!````````+D$````````N@0```````"[!```````
M`+P$````````O00```````"^!````````+\$````````P`0```````#!!```
M`````,($````````PP0```````#$!````````,4$````````Q@0```````#'
M!````````,@$````````R00```````#*!````````,L$````````S`0`````
M``#-!````````,X$````````SP0```````#0!````````-$$````````T@0`
M``````#3!````````-0$````````U00```````#6!````````-<$````````
MV`0```````#9!````````-H$````````VP0```````#<!````````-T$````
M````W@0```````#?!````````.`$````````X00```````#B!````````(D$
M````````B@0```````"8!````````)D$````````XP0```````#D!```````
M`.4$````````Y@0```````#G!````````.@$````````M00```````"V!```
M`````+<$````````N`0```````#I!````````.H$````````ZP0```````#L
M!````````.T$````````[@0```````#O!````````/`$````````\00`````
M``#R!````````/,$````````]`0```````#U!````````/8$````````]P0`
M``````#X!````````/D$````````^@0````````S#LP"8`X`````,P[,`NH/
M`````&`.``````````!*`V`.````````FP,``````````&`.S`*"#P````!@
M#LP"'Q``````F`X``````````)P#``````````!*`[D.````````P0X`````
M`````.$.``````````#A#@``````````X0X``````````.$.``````````#M
M#@``````````^PX``````````/L.```````````N#P``````````+@\`````
M`````)T#``````````!D#P``````````9`^"#P```````)X#``````````"?
M`P``````````IP\``````````+0/``````````#`#P``````````P`\`````
M`````,`/``````````"@`P``````````H0,``````````.H/6P\````````"
M$(L.+@\``````A!;#P```````*(#``````````!J$```````````HP,`````
M``````D1``````````"D`P``````````:A```````````*4#```````````A
M#P``````````,PX``````````$H.``````````!@#@``````````I@,`````
M`````(L.``````````"+#@``````````N0X``````````*<#``````````!;
M#P``````````@@\``````````#$3```````````R$P``````````,Q,`````
M`````#03``````````#[#@``````````J`,``````````+D.,PY:$`````#`
M^SRA````````ZA```````````.H0``````````#\$```````````)P0`````
M`````*D#``````````"J`P``````````JP,``````````*P#``````````!M
M#@``````````;0X``````````(L.``````````#[#@``````````$`\`````
M`````*T#``````````#0`@``````````P/M,H0```````,#[3:$```````#`
M^TZA````````P/M/H0```````,#[4*$```````#`^U&A````````P/M2H0``
M`````"H.S0(L#@`````K#LT"+`X`````*@[-`BX.`````"L.S0(N#@`````L
M#LT"+@X`````+0[-`BX.`````"H.S0(O#@`````N#LT"+PX`````*@[-`C$.
M`````"P.S0(Q#@`````N#LT",0X`````,`[-`C$.`````"H.S0(```````#[
M#@``````````^P[[#@```````/L.^P[[#@````#[#D00````````1!``````
M`````$00^PX```````!$$/L.^PX`````1!#[#OL.^PX``/L.6A````````!:
M$```````````6A#[#@```````%H0^P[[#@`````N#P``````````8`X`````
M`````&T.``````````!;#P``````````^PX``````````/L.^PX```````#[
M#OL.^PX`````^PY$$````````$00``````````!$$/L.````````1!#[#OL.
M`````$00^P[[#OL.``#[#EH0````````6A```````````%H0^PX```````!:
M$/L.^PX`````+@\``````````&`.``````````!M#@``````````6P\`````
M`````-<-``````````#8#0``````````V0T``````````-H-``````````#`
M^X2A````````P/N%H0```````,#[AJ$```````#`^X>A````````P/N(H0``
M`````,#[B:$```````#`^XJA````````P/N+H0```````,#[C*$```````#`
M^XVA````````P/N.H0```````,#[CZ$```````"N`P``````````L`,`````
M`````*\#``````````"Q`P``````````L@,``````````+,#``````````"T
M`P``````````M0,``````````+8#``````````"W`P``````````K@,`````
M`````*\#``````````"X`P``````````N0,``````````+H#``````````"[
M`P``````````O`,``````````+T#``````````"^`P``````````OP,`````
M`````,`#``````````#!`P``````````P@,``````````,,#``````````#$
M`P``````````Q0,``````````,8#``````````#'`P``````````R`,`````
M`````,D#``````````"R`P``````````R@,``````````,L#``````````#,
M`P``````````S0,``````````,X#``````````#/`P``````````T`,`````
M`````-$#``````````#2`P``````````TP,``````````-0#``````````#5
M`P``````````U@,``````````-<#``````````#8`P``````````V0,`````
M`````-H#``````````#;`P``````````W`,``````````-T#``````````#>
M`P``````````WP,``````````.`#``````````#A`P``````````X@,`````
M`````.,#``````````#D`P``````````Y0,``````````.8#``````````#G
M`P``````````Z`,``````````.P#``````````#J`P``````````Z`,`````
M`````.D#``````````#J`P``````````ZP,``````````.P#``````````#M
M`P``````````[@,``````````.\#``````````#P`P``````````\0,`````
M`````/(#``````````#S`P``````````]`,``````````/4#``````````#V
M`P``````````]P,``````````/@#``````````#Y`P``````````^@,`````
M`````/L#``````````#\`P``````````_0,``````````/X#``````````#_
M`P````````````0```````````$$```````````"!````````````P0`````
M``````0$```````````%!```````````!@0```````````<$```````````(
M!```````````"00```````````H$```````````+!```````````#`0`````
M``````T$```````````.!```````````#P0``````````!`$```````````1
M!```````````$@0``````````!,$```````````4!```````````%00`````
M`````!8$```````````7!```````````"0(```````````D"```````````)
M`@``````````"0(```````````D"```````````)`@``````````"0(`````
M``````D"```````````)`@``````````"0(```````````D"````````````
M````````````````````````````````````````````````````````````
M`````"4"```````````E`@``````````)@(``````````"<"```````````H
M`@``````````*0(``````````#($```````````<`@``````````>`(`````
M`````'D"``````````!Z`@``````````>P(``````````'\"``````````"`
M`@``````````@0(``````````(("``````````#8`@``````````V0(`````
M`````-H"``````````#;`@``````````70(``````````%T"70(```````!=
M`ET"70(`````W`(```````````<"```````````(`@``````````````````
M```````````````````````````````````````````````````````````)
M`@``````````U0(``````````-8"``````````#@`@``````````X`+@`@``
M`````.`"X`+@`@````#A`@``````````X0+A`@```````.$"X0+A`@````#D
M`@``````````?`(``````````'T"``````````#E`@``````````40)1`@``
M`````%P"```````````1`@``````````Y@(``````````.@"``````````#J
M`@``````````ZP(``````````-T"``````````#-`@``````````E`(`````
M`````)4"``````````!5`E4"````````50)1`@```````%$"50(```````#1
M`@``````````Q`(``````````-X"``````````#?`@``````````R0(`````
M`````#P"``````````#I`@``````````R@(``````````-<"```````````J
M`@``````````YP(``````````,#[5:````````#`^U:@````````X`+@`N`"
MX`(``,#[6*````````#`^UF@````````P/M:H````````,#[6Z````````#`
M^UR@````````P/M=H````````,#[7J`````````)`@``````````````````
M`````````````````````````````````````````````,#[9*````````#`
M^V6@````````P/MFH````````,#[9Z````````#`^VB@````````P/MIH```
M````````````````````````````````````````````````````````````
M`````````````````````````"D.``````````#[#@``````````P/MRH```
M`````,#[<Z`````````M#@``````````+@X``````````"\.```````````P
M#@``````````,0X``````````#(.```````````H!```````````-`0`````
M`````"T$``````````"(`@``````````B0(``````````&0/```````````I
M#@``````````*@X``````````"L.```````````L#@``````````+0X`````
M`````"X.```````````O#@``````````,`X``````````#$.```````````R
M#@``````````*`0``````````#0$```````````M!```````````B`(`````
M`````(D"``````````#`^X^@````````P/N0H````````,#[D:````````#`
M^Y*@````````P/N3H````````,#[E*````````#`^Y6@````````P/N6H```
M`````,#[EZ````````#`^YB@````````P/N9H````````,#[FJ````````#`
M^YN@````````P/N<H````````,#[G:````````#`^YZ@````````P/N?H```
M`````!@.```````````9#@``````````&@X``````````!L.```````````<
M#@``````````'0X``````````!X.```````````?#@``````````P`_J#P``
M`````"`.```````````A#@``````````(@X``````````",.```````````D
M#@``````````)0X``````````"8.```````````G#@``````````*`X`````
M`````,#[LJ````````#`^[.@````````P/NTH````````,#[M:````````#`
M^[:@````````P/NWH````````,#[N*````````#`^[F@````````P/NZH```
M`````,#[NZ````````#`^[R@````````P/N]H````````,#[OJ````````#`
M^[^@````````P/O`H````````,#[P:````````#`^\*@````````P/O#H```
M`````,#[Q*````````#`^\6@````````P/O&H````````,#[QZ````````#`
M^\B@````````P/O)H````````,#[RJ````````#`^\N@````````P/O,H```
M`````,#[S:````````#`^\Z@````````P/O/H```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````,#[ZZ````````#`
M^^R@````````P/OMH````````,#[[J````````#`^^^@````````P/OPH```
M`````,#[\:````````#`^_*@````````P/OSH````````,#[]*````````#`
M^_6@````````P/OVH````````,#[]Z````````#`^_B@````````P/OYH```
M`````,#[^J````````#`^_N@````````P/O\H````````,#[_:````````#`
M^_Z@````````P/O_H````````.@0`````.@0`````.@0`````.@0`````.@0
M`````.@0`````.@0`````.@0`````.@0`````.@0`````.@0`````.@0````
M`.@0`````.@0`````.@0`````.@0`````.T0`````.T0`````.T0`````.T0
M`````.T0`````.T0`````,#[%I\``,#[%Y\``.T0`````.T0`````.T0````
M`.T0`````.T0`````.T0`````,#['I\``,#['Y\``/$0`````/$0`````/$0
M`````/$0`````/$0`````/$0`````/$0`````/$0`````/$0`````/$0````
M`/$0`````/$0`````/$0`````/$0`````/$0`````/$0`````/,0`````/,0
M`````/,0`````/,0`````/,0`````/,0`````/,0`````/,0`````/,0````
M`/,0`````/,0`````/,0`````/,0`````/,0`````/,0`````/,0`````/L0
M`````/L0`````/L0`````/L0`````/L0`````/L0`````,#[1I\``,#[1Y\`
M`/L0`````/L0`````/L0`````/L0`````/L0`````/L0`````,#[3I\``,#[
M3Y\```01``````01``````01``````01``````01``````01``````01````
M``01`````,#[6)\```01`````,#[6I\```01`````,#[7)\```01`````,#[
M7I\```01``````D1``````D1``````D1``````D1``````D1``````D1````
M``D1``````D1``````D1``````D1``````D1``````D1``````D1``````D1
M``````D1``````D1`````.@0`````.@0`````.T0`````.T0`````/$0````
M`/$0`````/,0`````/,0`````/L0`````/L0``````01``````01``````D1
M``````D1`````,#[?I\``,#[?Y\``.@0`````.@0`````.@0`````.@0````
M`.@0`````.@0`````.@0`````.@0`````.@0`````.@0`````.@0`````.@0
M`````.@0`````.@0`````.@0`````.@0`````/$0`````/$0`````/$0````
M`/$0`````/$0`````/$0`````/$0`````/$0`````/$0`````/$0`````/$0
M`````/$0`````/$0`````/$0`````/$0`````/$0``````D1``````D1````
M``D1``````D1``````D1``````D1``````D1``````D1``````D1``````D1
M``````D1``````D1``````D1``````D1``````D1``````D1`````.@0````
M`.@0`````.@0`````.@0`````.@0`````,#[M9\``.@0`````.@0`````.@0
M`````.@0`````.@0`````.@0`````.@0`````!<"`````/,0`````!<"````
M`!T"`````!0"`````/$0`````/$0`````/$0`````,#[Q9\``/$0`````/$0
M`````.T0`````.T0`````/$0`````/$0`````/$0`````!<"`````!<"````
M`!<"`````/,0`````/,0`````/,0`````/,0`````,#[U)\``,#[U9\``/,0
M`````/,0`````/,0`````/,0`````/,0`````/,0`````,#[W)\``!@"````
M`!@"`````!@"``````01``````01``````01``````01```````1```````1
M``````01``````01``````01``````01``````01``````01```````1````
M`!0"`````!0"``````P"`````,#[\)\``,#[\9\```D1``````D1``````D1
M`````,#[]9\```D1``````D1`````/L0`````/L0``````D1``````D1````
M``D1``````T"`````!@"`````,#[_Y\``#,.`````#,.`````$H.`````$H.
M`````$H.`````$H.`````$H.`````$H.`````&`.`````&`.`````&T.````
M`&T.`````&T.`````&T.`````&T.`````&T.`````&T.`````&T.`````&T.
M`````&T.`````(L.`````(L.`````(L.`````(L.`````(L.`````(L.````
M`(L.`````(L.`````(L.`````(L.`````+D.`````+D.`````,$.`````,$.
M`````.$.`````.$.`````.$.`````.$.`````.$.`````.$.`````.$.````
M`.$.`````.$.`````.$.`````/L.`````/L.`````/L.`````/L.`````"$/
M`````"$/`````"$/`````"$/`````"$/`````"$/`````"X/`````"X/````
M`"X/`````"X/`````"X/`````"X/`````"X/`````"X/`````%L/`````%L/
M`````%L/`````%L/`````%L/`````%L/`````&0/`````&0/`````&0/````
M`&0/`````&0/`````&0/`````&0/`````&0/`````((/`````((/`````((/
M`````((/`````((/`````((/`````((/`````((/`````*</`````*</````
M`*</`````*</`````,`/`````,`/`````,`/`````,`/`````,`/`````,`/
M`````,`/`````,`/`````.H/`````.H/`````.H/`````.H/`````.H/````
M`.H/`````.H/`````.H/`````.H/`````.H/``````(0``````(0``````(0
M``````(0``````(0``````(0``````(0``````(0`````!\0`````!\0````
M`!\0`````!\0`````!\0`````!\0`````!\0`````!\0`````!\0`````!\0
M`````$00`````$00`````$00`````$00`````%$0`````%$0`````%$0````
M`%$0`````%$0`````%$0`````%$0`````%$0`````%$0`````%$0`````%H0
M`````%H0`````%H0`````%H0`````%X0`````%X0`````&H0`````&H0````
M`&H0`````&H0`````&H0`````&H0`````.$.``````(0`````%$0`````%X0
M`````#,.LQ```.H/`````,#[G)X``,#[G9X``,#[GIX``,#[GYX``#,.````
M`#,.`````#,.`````#,.`````#,.`````#,.`````#,.`````#,.`````#,.
M`````#,.`````#,.`````#,.`````#,.`````#,.`````#,.`````#,.````
M`#,.`````#,.`````#,.`````#,.`````#,.`````#,.`````#,.`````#,.
M`````(L.`````(L.`````(L.`````(L.`````(L.`````(L.`````(L.````
M`(L.`````(L.`````(L.`````(L.`````(L.`````(L.`````(L.`````(L.
M`````(L.`````/L.`````/L.`````/L.`````/L.`````((/`````((/````
M`((/`````((/`````((/`````((/`````((/`````((/`````((/`````((/
M`````((/`````((/`````((/`````((/`````((/`````((/`````((/````
M`((/`````((/`````((/`````((/`````((/`````((/`````((/`````!\0
M`````!\0`````!\0`````!\0`````!\0`````!\0`````!\0`````!\0````
M`!\0`````!\0`````!\0`````!\0`````!\0`````!\0`````%X0`````%X0
M`````%X0`````%X0`````%X0`````%X0`````%X0`````%X0`````,#[^IX`
M`,#[^YX``,#[_)X``,#[_9X``,#[_IX``,#[_YX``#<.`````#P.`````#T.
M`````%<.`````&0.`````'$.`````(H.`````(\.`````*@.``````</````
M`!0/`````"4/`````#H/`````%\/`````&T/`````(8/`````)8/`````(</
M`````)</`````)$/`````(P/`````*8/`````)@/`````)D/`````*L/````
M`,@/`````,T/``````80`````",0`````"00`````"40`````#L0`````$@0
M`````%40`````&X0`````(,0`````+H0`````+L0`````.L0`````/<0````
M`/T0``````$1``````@1`````+01`````#,.`````#@.`````$H.`````%8.
M`````&T.`````(L.`````)`.`````,$.`````.$.`````/L.`````!`/````
M`"$/`````"X/`````%L/`````&0/`````&P/`````((/`````*(/`````*</
M`````,`/``````(0`````!\0`````%$0`````#,.`````#X.`````$(.````
M`#T.`````$H.`````&T.`````(L.`````)0.`````)@.`````*@.`````,$.
M``````</`````"$/`````%L/`````'X/`````((/`````)(/`````)@/````
M`)D/`````*</``````(0`````!\0`````"00`````#<0`````$00`````+L0
M`````.D0`````.H0`````.P0``````41``````81`````/L.`````,`/````
M`!\0`````$00`````.D0`````.H0```````1``````41``````81`````"80
M`````,#[;)T``,#[;9T``,#[;IT``,#[;YT``,#[<)T``,#[<9T``,#[<IT`
M`,#[<YT``,#[=)T``,#[=9T``,#[=IT``,#[=YT``,#[>)T``,#[>9T``,#[
M>IT``,#[>YT``,#[?)T``,#[?9T``,#[?IT``,#[?YT``,#[@)T``,#[@9T`
M`,#[@IT``,#[@YT``,#[A)T``,#[A9T``,#[AIT``,#[AYT``,#[B)T``,#[
MB9T``,#[BIT``,#[BYT``,#[C)T``,#[C9T``,#[CIT``,#[CYT``,#[D)T`
M`,#[D9T``,#[DIT``,#[DYT``,#[E)T``,#[E9T``,#[EIT``,#[EYT``,#[
MF)T``,#[F9T``,#[FIT``,#[FYT``,#[G)T``,#[G9T``,#[GIT``,#[GYT`
M`,#[H)T``,#[H9T``,#[HIT``,#[HYT``,#[I)T``,#[I9T``,#[IIT``,#[
MIYT``,#[J)T``,#[J9T``,#[JIT``,#[JYT``,#[K)T``,#[K9T``,#[KIT`
M`,#[KYT``,#[L)T``,#[L9T``,#[LIT``,#[LYT``,#[M)T``,#[M9T``,#[
MMIT``,#[MYT``,#[N)T``,#[N9T``,#[NIT``,#[NYT``,#[O)T``,#[O9T`
M`,#[OIT``,#[OYT``,#[P)T``,#[P9T``,#[PIT``,#[PYT``,#[Q)T``,#[
MQ9T``,#[QIT``,#[QYT``,#[R)T``,#[R9T``,#[RIT``,#[RYT``,#[S)T`
M`,#[S9T``,#[SIT``,#[SYT``,#[T)T``,#[T9T``,#[TIT``,#[TYT``,#[
MU)T``,#[U9T``,#[UIT``,#[UYT``,#[V)T``,#[V9T``,#[VIT``,#[VYT`
M`,#[W)T``,#[W9T``,#[WIT``,#[WYT``,#[X)T``,#[X9T``,#[XIT``,#[
MXYT``,#[Y)T``,#[Y9T``,#[YIT``,#[YYT``,#[Z)T``,#[Z9T``,#[ZIT`
M`,#[ZYT``,#[[)T``,#[[9T``,#[[IT``,#[[YT``,#[\)T``,#[\9T``,#[
M\IT``,#[\YT``,#[])T``,#[]9T``,#[]IT``,#[]YT``,#[^)T``,#[^9T`
M`,#[^IT``,#[^YT``,#[_)T``,#[_9T``,#[_IT``,#[_YT``+`8`````+$8
M`````+(8`````+,8`````+08`````+48`````+88`````+<8`````+@8````
M`+D8`````+H8`````+L8`````+P8`````+T8`````+X8`````+\8`````,`8
M`````,$8`````,(8`````,,8`````,08`````,48`````,88`````,<8````
M`,@8`````,D8`````,H8`````,L8`````,P8`````,#['9D``,#['ID``,#[
M'YD``,T8`````,X8`````,\8`````-`8`````-$8`````-(8`````-,8````
M`-08`````-48`````-88`````-<8`````-@8`````,#[+)D``,#[+9D``,#[
M+ID``,#[+YD``-D8`````-H8`````-L8`````-P8`````-T8`````-X8````
M`-\8`````.`8`````.$8`````````````````````````````,#[/)D``,#[
M/9D``,#[/ID``,#[/YD```T#`````,#[09D``,#[0ID``,#[0YD``%0"````
M`%L"`````"D.`````"H.`````"L.`````"P.`````"T.`````"X.`````"\.
M`````#`.`````#$.`````#(.`````+09`````+49`````+89`````+<9````
M`+@9`````+D9`````+H9`````+L9`````+P9`````+T9`````+X9`````+\9
M`````,`9`````,$9`````,(9`````,,9`````,09`````,49`````,89````
M`,<9`````,@9`````,D9`````,H9`````,L9`````,P9`````,T9`````,X9
M`````,\9`````-`9`````-$9`````,#[;ID``,#[;YD``-(9`````-,9````
M`-09`````-49`````-89`````,#[=9D``,#[=ID``,#[=YD``,#[>)D``,#[
M>9D``,#[>ID``,#[>YD``,#[?)D``,#[?9D``,#[?ID``,#[?YD``,#[@)D`
M`,#[@9D``,#[@ID``,#[@YD``,#[A)D``,#[A9D``,#[AID``,#[AYD``,#[
MB)D``,#[B9D``,#[BID``,#[BYD``,#[C)D``,#[C9D``,#[CID``,#[CYD`
M`,#[D)D``,#[D9D``,#[DID``,#[DYD``,#[E)D``,#[E9D``,#[EID``,#[
MEYD``,#[F)D``,#[F9D``,#[FID``,#[FYD``,#[G)D``,#[G9D``,#[GID`
M`,#[GYD``,#[H)D``,#[H9D``,#[HID``,#[HYD``,#[I)D``,#[I9D``,#[
MIID``,#[IYD``,#[J)D``,#[J9D``,#[JID``,#[JYD``,#[K)D``,#[K9D`
M`,#[KID``,#[KYD``,#[L)D``,#[L9D``,#[LID``,#[LYD``,#[M)D``,#[
MM9D``,#[MID``,#[MYD``,#[N)D``,#[N9D``,#[NID``,#[NYD``,#[O)D`
M`,#[O9D``,#[OID``,#[OYD``,#[P)D``,#[P9D``,#[PID``,#[PYD``,#[
MQ)D``,#[Q9D``,#[QID``,#[QYD``,#[R)D``,#[R9D``,#[RID``,#[RYD`
M`,#[S)D``,#[S9D``,#[SID``,#[SYD``,#[T)D``,#[T9D``,#[TID``,#[
MTYD``,#[U)D``,#[U9D``,#[UID``,#[UYD``,#[V)D``,#[V9D``,#[VID`
M`,#[VYD``,#[W)D``,#[W9D``,#[WID``,#[WYD``'L#`````'P#`````'T#
M`````'X#`````'\#`````(`#`````($#`````((#`````(,#`````(0#````
M`(4#`````(8#`````(<#`````(@#`````(D#`````(H#`````(L#`````(P#
M`````(T#`````(X#`````(\#`````)`#`````)$#`````)(#`````),#````
M`)0#`````)4#`````)8#`````)<#`````)@#`````)D#`````)H#`````/@"
M`````%X"`````#4"`````&,"`````$H"`````$L"`````","`````"0"````
M`#8"`````&0"`````/D"`````````````````````````````````````,#[
M#Y@``"D.`````"H.`````"L.`````"P.`````"T.`````"X.`````"\.````
M`#`.`````#$.`````#(.`````,#[&I@``,#[&Y@``,#[')@``,#['9@``,#[
M'I@``,#['Y@``-\9`````.$9`````.09`````.H9`````.P9`````.\9````
M`/$9`````/09`````/49`````/89`````/L9`````/T9```````:``````(:
M``````<:``````D:``````H:``````L:`````!(:`````!4:`````!@:````
M`!T:`````"$:`````"0:`````"8:`````"@:`````"L:`````#`:`````#$:
M`````#0:`````#@:`````#L:`````#P:`````#T:`````#X:`````-X9````
M`.(9`````.49`````.L9`````.T9`````/`9`````/(9`````/<9`````/P9
M`````/X9``````$:``````,:``````@:`````!,:`````!8:`````!D:````
M`!X:`````#(:`````"(:`````"<:`````"P:`````#8:`````#D:`````#\:
M`````$`:`````!L:`````.,9`````.89`````.D9`````/,9`````.X9````
M`/@9`````"T:``````0:``````8:`````/\9``````P:`````!0:`````!<:
M`````!\:`````"D:`````#<:`````#H:`````#,:`````#4:`````$$:````
M`!H:`````",:`````.<9`````"X:`````"4:`````"H:`````"`:`````,#[
M>)@``,#[>9@``,#[>I@``,#[>Y@``,#[?)@``,#[?9@``,#[?I@``,#[?Y@`
M`-<9`````-@9`````-D9`````-H9`````-L9`````-P9`````-T9`````.`9
M`````.@9`````"\:`````/D9`````!P:`````$(:`````$0:`````$4:````
M`$<:`````$@:`````$L:`````$T:`````$X:`````%`:`````%(:`````%0:
M`````%4:`````$D:`````%,:``````4:`````/H9``````T:``````X:````
M`$,:`````$8:`````$H:`````$P:``````\:`````%$:`````!`:`````!$:
M`````%8:`````%<:`````$\:`````%@:`````,#[JI@``,#[JY@``,#[K)@`
M`,#[K9@``,#[KI@``,#[KY@``,#[L)@``,#[L9@``,#[LI@``,#[LY@``,#[
MM)@``,#[M9@``,#[MI@``,#[MY@``,#[N)@``,#[N9@``,#[NI@``,#[NY@`
M`,#[O)@``,#[O9@``,#[OI@``,#[OY@``,#[P)@``,#[P9@``,#[PI@``,#[
MPY@``,#[Q)@``,#[Q9@``,#[QI@``,#[QY@``,#[R)@``,#[R9@``,#[RI@`
M`,#[RY@``,#[S)@``,#[S9@``,#[SI@``,#[SY@``,#[T)@``,#[T9@``,#[
MTI@``,#[TY@``,#[U)@``,#[U9@``,#[UI@``,#[UY@``,#[V)@``,#[V9@`
M`,#[VI@``,#[VY@``,#[W)@``,#[W9@``,#[WI@``,#[WY@``,#[X)@``,#[
MX9@``,#[XI@``,#[XY@``,#[Y)@``,#[Y9@``,#[YI@``,#[YY@``,#[Z)@`
M`,#[Z9@``,#[ZI@``,#[ZY@``,#[[)@``,#[[9@``,#[[I@``,#[[Y@``,#[
M\)@``,#[\9@``,#[\I@``,#[\Y@``,#[])@``,#[]9@``,#[]I@``,#[]Y@`
M`,#[^)@``,#[^9@``,#[^I@``,#[^Y@``,#[_)@``,#[_9@``,#[_I@``,#[
M_Y@``.(8`````.,8`````.08`````.48`````.88`````.<8`````.@8````
M`.D8`````.H8`````.L8`````.P8`````.T8`````.X8`````,#[#9<``.\8
M`````/`8`````/$8`````/(8`````/,8`````/08`````/48`````,#[%9<`
M`,#[%I<``,#[%Y<``,#[&)<``,#[&9<``,#[&I<``,#[&Y<``,#[')<``,#[
M'9<``,#['I<``,#['Y<``/88`````/<8`````/@8`````/D8`````/H8````
M`/L8`````/P8`````/T8`````/X8`````/\8```````9``````$9``````(9
M``````,9``````09``````49``````89``````<9``````@9``````D9````
M``H9`````&H"`````&L"`````,#[-Y<``,#[.)<``,#[.9<``,#[.I<``,#[
M.Y<``,#[/)<``,#[/9<``,#[/I<``,#[/Y<```L9``````P9``````T9````
M``X9``````\9`````!`9`````!$9`````!(9`````!,9`````!09`````!49
M`````!89`````!<9`````!@9`````!D9`````!H9`````!L9`````!P9````
M`!T9`````!X9`````,#[5)<``,#[59<``,#[5I<``,#[5Y<``,#[6)<``,#[
M69<``,#[6I<``,#[6Y<``,#[7)<``,#[79<``,#[7I<``,#[7Y<``!\9````
M`"`9`````"$9`````"(9`````",9`````"09`````"49`````"89`````"<9
M`````"@9`````"D9`````"H9`````"L9`````,#[;9<``"P9`````"T9````
M`"X9`````,#[<9<``"\9`````#`9`````,#[=)<``,#[=9<``,#[=I<``,#[
M=Y<``,#[>)<``,#[>9<``,#[>I<``,#[>Y<``,#[?)<``,#[?9<``,#[?I<`
M`,#[?Y<``&P9`````&T9`````&X9`````&\9`````'`9`````'$9`````'(9
M`````',9`````'09`````'49`````'89`````'<9`````'@9`````'D9````
M`'H9`````'L9`````'P9`````'T9`````'X9`````'\9`````(`9`````($9
M`````((9`````(,9`````(09`````(49`````(89`````(<9`````(@9````
M`(D9`````(H9`````(L9`````(P9`````(T9`````(X9`````)`9`````)$9
M`````)(9`````),9`````)09`````)49`````)89`````)<9`````)@9````
M`)D9`````)H9`````)L9`````)P9`````)T9`````)X9`````)\9`````*`9
M`````*$9`````*(9`````*,9`````*09`````*49`````*89`````*<9````
M`*@9`````*D9`````*H9`````*L9`````*P9`````*T9`````*X9`````*\9
M`````+`9`````+$9`````+(9````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````+,9`````````````&X"`````&\"`````$T"`````!(#`````!,#````
M`!0#`````!4#`````!<.`````(\9`````````````,#[WI<``,#[WY<``"D.
M`````"H.`````"L.`````"P.`````"T.`````"X.`````"\.`````#`.````
M`#$.`````#(.`````,#[ZI<``,#[ZY<``,#[[)<``,#[[9<``,#[[I<``,#[
M[Y<``"D.`````"H.`````"L.`````"P.`````"T.`````"X.`````"\.````
M`#`.`````#$.`````#(.`````,#[^I<``,#[^Y<``,#[_)<``,#[_9<``,#[
M_I<``,#[_Y<``+4<`````+8<`````+<<`````+@<`````+D<`````+H<````
M`+L<`````+P<`````+T<`````+X<`````+\<`````,`<`````,$<`````,(<
M`````,,<`````,0<`````,4<`````,8<`````,<<`````,@<`````,D<````
M`,H<`````,L<`````,P<`````,T<`````,X<`````,\<`````-`<`````-$<
M`````-(<`````-,<`````-0<`````-4<`````-8<`````-<<`````-@<````
M`-D<`````-H<`````-L<`````-P<`````-T<`````-X<`````-\<`````.`<
M`````.$<`````.(<`````.,<`````.0<`````.4<`````.8<`````.<<````
M`.@<`````.D<`````.H<`````.L<`````.P<`````.T<`````.X<`````.\<
M`````/`<`````/$<`````/(<`````/,<`````/0<`````/4<`````/8<````
M`/<<`````/@<`````/D<`````/H<`````/L<`````/P<`````/T<`````/X<
M`````/\<```````=``````$=``````(=``````,=``````0=``````4=````
M``8=``````<=``````@=``````D=``````H=``````L=``````P=``````T=
M``````X=``````\=`````!`=`````!$=`````!(=`````!,=`````!0=````
M`!4=`````!8=`````!<=`````!@=`````!D=`````!H=`````!L=`````!P=
M`````!T=`````!X=`````!\=`````"`=`````"$=`````!8#`````&4"````
M`"H<`````#L<`````$0<`````$4<`````$8<`````$<<`````$@<`````$D<
M`````,#[=Y8``,#[>)8``,#[>98``,#[>I8``,#[>Y8``,#[?)8``,#[?98`
M`,#[?I8``,#[?Y8```H"`````"(=`````",=`````"0=`````"4=`````"8=
M`````"<=`````"@=`````"D=`````"H=`````"L=`````"P=`````"T=````
M`"X=`````"\=`````#`=`````#$=`````#(=`````#,=`````#0=`````#4=
M`````#8=`````#<=`````#@=`````#D=`````#H=`````#L=`````)("````
M`),"`````,#[G98``,#[GI8``,#[GY8``#P=`````#P=`````#T=`````%D=
M`````#T=`````#T=`````#X=`````#X=`````#\=`````#\=`````%<=````
M`%@=`````#\=`````#\=`````#\=`````$`=`````$$=`````$(=`````$,=
M`````$,=`````$,=`````$,=`````$,=`````$0=`````%P=`````$4=````
M`$8=`````$8=`````$8=`````$8=`````$<=`````$<=`````$<=`````$@=
M`````$@=`````$D=`````$D=`````$H=`````$H=`````$L=`````$P=````
M`$T=`````$X=`````$X=`````$X=`````$X=`````$X=`````$\=`````$\=
M`````$\=`````%`=`````%`=`````%`=`````$P=`````%$=`````%(=````
M`%(=`````%(=`````%,=`````%,=`````%0=`````%0=`````%4=`````%8=
M`````%H=`````%X=`````%\=`````%L=`````%T=`````&`=`````&$=````
M`&$=`````&$=`````$4=`````$X=`````$X"`````$\"`````%`"`````$H=
M4QT``%(=4AT``#X=/AT``,#[\98``,#[\I8``,#[\Y8``,#[])8``,#[]98`
M`,#[]I8``,#[]Y8``,#[^)8``,#[^98``,#[^I8``,#[^Y8``,#[_)8``,#[
M_98``,#[_I8``,#[_Y8``*T;``"N&P``KQL``+`;``"Q&P``LAL``+,;``"T
M&P``M1L``+8;``"W&P``N!L``+D;``"Z&P``NQL``+P;``"]&P``OAL``+\;
M``#`&P``P1L``,(;``##&P``Q!L``,4;``#&&P``QQL``,@;``#)&P``RAL`
M`,L;``#,&P``S1L``,X;``#/&P``T!L``-$;``#2&P``TQL``-0;``#5&P``
MUAL``-<;``#8&P``V1L``-H;``#;&P``W!L``-T;``#>&P``WQL``.`;``#A
M&P``XAL``.,;``#D&P``Y1L``.8;``#G&P``Z!L``.D;``#J&P``ZQL``.P;
M``#M&P``[AL``.\;``#P&P``\1L``/(;``#S&P``]!L``/4;``#V&P``]QL`
M`/@;``#Y&P``^AL``/L;``#\&P``_1L``/X;``#_&P```!P```$<```"'```
M`QP```0<```%'```!AP```<<```('```"1P```H<```+'```#!P```T<```.
M'```#QP``!`<```1'```$AP``!,<```4'```%1P``!8<```7'```&!P``!D<
M```:'```&QP``!P<```='```'AP``!\<```@'```(1P``"(<```C'```)!P`
M`"4<```F'```)QP``"@<``!;'```*1P``"L<```L'```+1P``"X<```O'```
M,!P``#$<```R'```,QP``#0<```U'```-AP``#<<```X'```.1P``#H<```\
M'```/1P``#X<```_'```0!P``$$<``!"'```0QP``$H<``!+'```3!P``$T<
M``!.'```3QP``%`<``!1'```4AP``%,<``!4'```51P``%8<``!7'```6!P`
M`%D<``!:'```7!P``%T<``!>'```7QP``&`<``!A'```8AP``&,<``!D'```
M91P``&8<``!G'```:!P``&D<``!J'```:QP``&P<``!M'```;AP``&\<``!P
M'```<1P``'(<``!S'```=!P``'4<``!V'```=QP``'@<``!Y'```>AP``'L<
M``!\'```?1P``'X<``!_'```@!P``($<``""'```@QP``(0<``"%'```AAP`
M`(<<``"('```B1P``(H<``"+'```C!P``(T<``".'```CQP``)`<``"1'```
MDAP``),<``"4'```E1P``)8<``"7'```F!P``)D<``":'```FQP``)P<``"=
M'```GAP``)\<``"@'```H1P``*(<``"C'```I!P``*4<``"F'```IQP``*@<
M``"I'```JAP``*L<``"L'```K1P``*X<``"O'```L!P``+$<``"R'```LQP`
M`+0<``#`^P"4``"N&@````"O&@````"P&@````"Q&@````"R&@````"S&@``
M``"T&@````"U&@````"V&@````"W&@````"X&@````"Y&@````"Z&@````"[
M&@````"\&@````"]&@````"^&@````"_&@````#`&@````#!&@````#"&@``
M``##&@````#$&@````#%&@````#&&@````#'&@````#(&@````#)&@````#*
M&@````#+&@````#,&@````#-&@````#.&@````#/&@````#0&@````#1&@``
M``#2&@````#3&@````#4&@````#5&@````#6&@````#7&@````#8&@````#9
M&@````#:&@````#;&@````#<&@````#=&@````#>&@````#?&@````#@&@``
M``#A&@````#B&@````#C&@````#D&@````#E&@````#F&@````#G&@````#H
M&@````#I&@````#J&@````#K&@````#L&@````#M&@````#N&@````#O&@``
M``#P&@````#Q&@````#R&@````#S&@````#T&@````#U&@````#V&@````#W
M&@````#X&@````#Y&@````#Z&@````#[&@````#\&@````#]&@````#^&@``
M``#_&@``````&P`````!&P`````"&P`````#&P`````$&P`````%&P`````&
M&P`````'&P`````(&P`````)&P`````*&P`````+&P`````,&P`````-&P``
M```.&P`````/&P`````0&P`````1&P`````2&P`````3&P`````4&P`````5
M&P`````6&P`````7&P`````8&P`````9&P`````:&P`````;&P`````<&P``
M```=&P`````>&P`````?&P`````@&P`````A&P`````B&P`````C&P`````D
M&P`````E&P`````F&P`````G&P`````H&P`````I&P`````J&P`````K&P``
M```L&P`````M&P`````N&P`````O&P`````P&P`````Q&P`````R&P`````S
M&P`````T&P`````U&P`````V&P`````W&P`````X&P`````Y&P`````Z&P``
M```[&P`````\&P`````]&P`````^&P`````_&P````!`&P````!!&P````!"
M&P````!#&P````!$&P````!%&P````!&&P````!'&P````!(&P````!)&P``
M``!*&P````!+&P````!,&P````!-&P````!.&P````!/&P````!0&P````!1
M&P````!2&P````!3&P````!4&P````!5&P````!6&P````!7&P````!8&P``
M``!9&P````!:&P````!;&P````!<&P````!=&P````!>&P````!?&P````!@
M&P````!A&P````!B&P````!C&P````!D&P````!E&P````!F&P````!G&P``
M``!H&P````!I&P````!J&P````!K&P````!L&P````!M&P````!N&P````!O
M&P````!P&P````!Q&P````!R&P````!S&P````!T&P````!U&P````!V&P``
M``!W&P````!X&P````!Y&P````!Z&P````![&P````!\&P````!]&P````!^
M&P````!_&P````"`&P````"!&P````""&P````"#&P````"$&P````"%&P``
M``"&&P````"'&P````"(&P````")&P````"*&P````"+&P````",&P````"-
M&P````".&P````"/&P````"0&P````"1&P````"2&P````"3&P````"4&P``
M``"5&P````"6&P````"7&P````"8&P````"9&P````":&P````";&P````"<
M&P````"=&P````">&P````"?&P````"@&P````"A&P````"B&P````"C&P``
M``"D&P````"E&P````"F&P````"G&P````"H&P````"I&P````"J&P````"K
M&P````"L&P`````$%0`````%%0`````&%0`````'%0`````(%0`````)%0``
M```*%0`````+%0`````,%0`````-%0`````.%0`````/%0`````0%0`````1
M%0`````2%0````#`^P^3```3%0````#`^Q&3```4%0`````5%0`````6%0``
M```7%0````#`^Q:3``#`^Q>3```8%0`````9%0`````:%0`````;%0`````<
M%0`````=%0`````>%0````#`^Q^3```?%0`````@%0`````A%0`````B%0``
M```C%0`````D%0`````E%0`````F%0`````G%0`````H%0`````I%0`````J
M%0`````K%0`````L%0`````M%0`````N%0`````O%0`````P%0`````Q%0``
M```R%0`````S%0`````T%0`````U%0`````V%0`````W%0`````X%0`````Y
M%0`````Z%0`````[%0`````\%0`````]%0`````^%0`````_%0````!`%0``
M``!!%0````!"%0````!#%0````!$%0````!%%0````#`^T>3``!&%0````!'
M%0````!(%0````!)%0````!*%0````!+%0````!,%0````!-%0````!.%0``
M``!/%0````!0%0````!1%0````!2%0````!3%0````!4%0````!5%0````!6
M%0````!7%0````!8%0````#`^UN3``#`^UR3``#`^UV3``#`^UZ3``#`^U^3
M``#`^V"3``!%`@````!B`@````!&`@````!'`@````!(`@````!)`@````!:
M`@````!R`@`````J#@`````K#@`````L#@`````M#@`````N#@`````O#@``
M```P#@`````Q#@`````R#@````#,#0````#-#0````#.#0````#/#0````#0
M#0````#1#0````#2#0````#3#0````#4#0````#5#0````#6#0````#`^WV3
M``#`^WZ3``#`^W^3``#`^X"3``#`^X&3``#`^X*3``#`^X.3``#`^X23``#`
M^X63``#`^X:3``#`^X>3``#`^XB3``#`^XF3``#`^XJ3``#`^XN3``#`^XR3
M``#`^XV3``#`^XZ3``#`^X^3``#`^Y"3``#`^Y&3``#`^Y*3``#`^Y.3``#`
M^Y23``#`^Y63``#`^Y:3``#`^Y>3``#`^YB3``#`^YF3``#`^YJ3``#`^YN3
M``#`^YR3``#`^YV3``#`^YZ3``#`^Y^3``!9&@````!:&@````!;&@````!<
M&@````!=&@````!>&@````!?&@````!@&@````!A&@````!B&@````!C&@``
M``!D&@````!E&@````!F&@````!G&@````!H&@````!I&@````!J&@````!K
M&@````!L&@````!M&@````!N&@````!O&@````!P&@````!Q&@````!R&@``
M``!S&@````!T&@````!U&@````!V&@````!W&@````!X&@````!Y&@````!Z
M&@````![&@````!\&@````!]&@````!^&@````!_&@````"`&@````"!&@``
M``""&@````"#&@````"$&@````"%&@````"&&@````"'&@````"(&@````")
M&@````"*&@````"+&@````",&@````"-&@````".&@````"/&@````"0&@``
M``"1&@````"2&@````"3&@````"4&@````"5&@````"6&@````"7&@````"8
M&@````"9&@````":&@````";&@````"<&@````"=&@````">&@````"?&@``
M``"@&@````"A&@````"B&@````"C&@````"D&@````"E&@````"F&@````"G
M&@````"H&@````"I&@````"J&@````"K&@````"L&@````"M&@````#`^_63
M``#`^_:3``#`^_>3``#`^_B3``#`^_F3``#`^_J3``#`^_N3``#`^_R3``#`
M^_V3``#`^_Z3``#`^_^3```<%``````=%``````>%``````?%``````@%```
M```A%``````B%`````#`^P>2```C%``````D%``````E%``````F%``````G
M%``````H%``````I%``````J%``````K%``````L%``````M%``````N%```
M```O%``````P%``````Q%``````R%``````S%``````T%``````U%``````V
M%``````W%``````X%``````Y%``````Z%``````[%``````\%``````]%```
M```^%``````_%`````!`%`````!!%`````!"%`````!#%`````!$%`````!%
M%`````!&%`````!'%`````!(%`````!)%`````!*%`````!+%`````!,%```
M``!-%`````!.%`````!/%`````!0%`````!1%`````!2%`````!3%`````!4
M%`````!5%`````!6%`````!7%`````!8%`````!9%`````!:%`````!;%```
M``!<%`````!=%`````!>%`````!?%`````!@%`````!A%`````#`^T>2``!B
M%`````#`^TF2``!C%`````!D%`````!E%`````!F%`````#`^TZ2``#`^T^2
M``!G%`````!H%`````!I%`````!J%`````!K%`````!L%`````!M%`````#`
M^U>2``!N%`````#`^UF2``!O%`````!P%`````!Q%`````!R%`````#`^UZ2
M``#`^U^2``!S%`````!T%`````!U%`````!V%`````!W%`````!X%`````!Y
M%`````!Z%`````![%`````!\%`````!]%`````!^%`````!_%`````"`%```
M``"!%`````""%`````"#%`````"$%`````"%%`````"&%`````"'%`````"(
M%`````")%`````"*%`````"+%`````",%`````"-%`````".%`````"/%```
M``"0%`````"1%`````"2%`````"3%`````"4%`````"5%`````"6%`````"7
M%`````"8%`````"9%`````#`^X>2``":%`````#`^XF2``";%`````"<%```
M``"=%`````">%`````#`^XZ2``#`^X^2``"?%`````"@%`````"A%`````"B
M%`````"C%`````"D%`````"E%`````"F%`````"G%`````"H%`````"I%```
M``"J%`````"K%`````"L%`````"M%`````"N%`````"O%`````"P%`````"Q
M%`````"R%`````"S%`````"T%`````"U%`````"V%`````"W%`````"X%```
M``"Y%`````"Z%`````"[%`````"\%`````"]%`````#`^Z^2``"^%`````#`
M^[&2``"_%`````#`%`````#!%`````#"%`````#`^[:2``#`^[>2``##%```
M``#$%`````#%%`````#&%`````#'%`````#(%`````#)%`````#`^[^2``#*
M%`````#`^\&2``#+%`````#,%`````#-%`````#.%`````#`^\:2``#`^\>2
M``#/%`````#0%`````#1%`````#2%`````#3%`````#4%`````#5%`````#`
M^\^2``#6%`````#7%`````#8%`````#9%`````#:%`````#;%`````#<%```
M``#`^]>2``#=%`````#>%`````#?%`````#@%`````#A%`````#B%`````#C
M%`````#D%`````#E%`````#F%`````#G%`````#H%`````#I%`````#J%```
M``#K%`````#L%`````#M%`````#N%`````#O%`````#P%`````#Q%`````#R
M%`````#S%`````#`^^^2``#T%`````#U%`````#V%`````#W%`````#X%```
M``#Y%`````#Z%`````#[%`````#\%`````#]%`````#^%`````#_%```````
M%0`````!%0`````"%0`````#%0````!B'0````!C'0````!D'0````!E'0``
M``!F'0````!G'0````!H'0````!I'0````!J'0````!K'0````!L'0````!M
M'0````!N'0````!O'0````!P'0````!Q'0````!R'0````!S'0````!T'0``
M``!U'0````!V'0````!W'0````!X'0````!Y'0````!Z'0````!['0````!\
M'0````!]'0````!^'0````!_'0````"`'0````"!'0````""'0````"#'0``
M``"$'0````"%'0````"&'0````"''0````"('0````")'0````"*'0````"+
M'0````",'0````"-'0````".'0````"/'0````"0'0````"1'0````"2'0``
M``"3'0````"4'0````"5'0````"6'0````"7'0````"8'0````"9'0````":
M'0````";'0````"<'0````"='0````">'0````"?'0````"@'0````"A'0``
M``"B'0````"C'0````"D'0````"E'0````"F'0````"G'0````"H'0````"I
M'0````"J'0````"K'0````"L'0````"M'0````"N'0````"O'0````"P'0``
M``"Q'0````"R'0````"S'0````"T'0````"U'0````"V'0````"W'0````"X
M'0````"Y'0````"Z'0````"['0````#`^UJ1``#`^UN1``#`^UR1``#`^UV1
M``#`^UZ1``"\'0````"]'0````"^'0````"_'0````#`'0````#!'0````#"
M'0````##'0````#$'0````#%'0````#&'0````#''0````#('0````#)'0``
M``#*'0````#+'0````#,'0````#-'0````#.'0````#/'0````#0'0````#1
M'0````#2'0````#3'0````#4'0````#5'0````#6'0````#7'0````#8'0``
M``#9'0````#:'0````#;'0````#<'0````#='0````#>'0````#?'0````#@
M'0````#A'0````#B'0````#C'0````#D'0````#E'0````#F'0````#G'0``
M``#H'0````#I'0````#J'0````#K'0````#L'0````#M'0````#N'0````#O
M'0````#P'0````#Q'0````#R'0````#S'0````#T'0````#U'0````#V'0``
M``#W'0````#X'0````#Y'0````#Z'0````#['0````#\'0````#]'0````#^
M'0````#_'0````#`^Z.1``#`^Z21``#`^Z61``#`^Z:1``#`^Z>1````'@``
M```!'@`````"'@`````#'@`````$'@`````%'@`````&'@`````''@`````(
M'@`````)'@`````*'@`````+'@`````,'@`````-'@`````.'@`````/'@``
M```0'@`````1'@`````2'@`````3'@`````4'@`````5'@`````6'@`````7
M'@`````8'@`````9'@`````:'@`````;'@`````<'@`````='@`````>'@``
M```?'@`````@'@`````A'@`````B'@`````C'@`````D'@`````E'@`````F
M'@`````G'@`````H'@`````I'@`````J'@`````K'@`````L'@`````M'@``
M```N'@`````O'@`````P'@`````Q'@`````R'@`````S'@`````T'@`````U
M'@`````V'@`````W'@`````X'@`````Y'@`````Z'@`````['@`````\'@``
M```]'@`````^'@`````_'@````!`'@````!!'@````!"'@````!#'@````!$
M'@````!%'@````!&'@````!''@````!('@````!)'@````!*'@````!+'@``
M``!,'@````!-'@````!.'@````!/'@````!0'@````!1'@````#`^_J1``#`
M^_N1``#`^_R1``#`^_V1``#`^_Z1``#`^_^1```Q&0`````R&0`````S&0``
M```T&0`````U&0`````V&0`````W&0`````X&0`````Y&0`````Z&0`````[
M&0`````\&0`````]&0`````^&0`````_&0````!`&0````!!&0````!"&0``
M``!#&0````!$&0````!%&0````!&&0````!'&0````!(&0````!)&0````!*
M&0````!+&0````!,&0````!-&0````!.&0````!1&0````!2&0````!3&0``
M``!4&0````#`^R*0``!5&0````!6&0````!7&0````!8&0````!9&0````#`
M^RB0``!:&0````!;&0````#`^RN0``!@&0````!A&0````!B&0````!C&0``
M``!D&0````!E&0````!F&0````#`^S.0``#`^S20``#`^S60````````````
M``````````````!K&0````#`^SJ0``#`^SN0``#`^SR0``#`^SV0``#`^SZ0
M``#`^S^0```I#@`````J#@`````K#@`````L#@`````M#@`````N#@`````O
M#@`````P#@`````Q#@`````R#@````!L`@````!M`@`````.`P`````/`P``
M```0`P`````1`P````!/&0````!0&0````!<&0````!=&0````!>&0````!?
M&0````!G&0````!H&0````!I&0````!J&0````#`^UJ0``#`^UN0``#`^UR0
M``#`^UV0``#`^UZ0``#`^U^0``#`^V"0``#`^V&0``#`^V*0``#`^V.0``#`
M^V20``#`^V60``#`^V:0``#`^V>0``#`^VB0``#`^VF0``#`^VJ0``#`^VN0
M``#`^VR0``#`^VV0``#`^VZ0``#`^V^0``#`^W"0``#`^W&0``#`^W*0``#`
M^W.0``#`^W20``#`^W60``#`^W:0``#`^W>0``#`^WB0``#`^WF0``#`^WJ0
M``#`^WN0``#`^WR0``#`^WV0``#`^WZ0``#`^W^0``#`^X"0``#`^X&0``#`
M^X*0``#`^X.0``#`^X20``#`^X60``#`^X:0``#`^X>0``#`^XB0``#`^XF0
M``#`^XJ0``#`^XN0``#`^XR0``#`^XV0``#`^XZ0``#`^X^0``#`^Y"0``#`
M^Y&0``#`^Y*0``#`^Y.0``#`^Y20``#`^Y60``#`^Y:0``#`^Y>0``#`^YB0
M``#`^YF0``#`^YJ0``#`^YN0``#`^YR0``#`^YV0``#`^YZ0``#`^Y^0``#A
M$@````#B$@````#C$@````#D$@````#E$@````#F$@````#G$@````#I$@``
M``#J$@````#K$@````#L$@````#M$@````#N$@````#P$@````#Q$@````#R
M$@````#S$@````#T$@````#U$@````#W$@````#X$@````#Y$@````#Z$@``
M``#[$@````#\$@````#]$@````#^$@````#_$@``````$P`````!$P`````"
M$P`````$$P`````%$P````#H$@````#O$@````#V$@`````#$P`````&$P``
M``#`^\:0``#`^\>0``#`^\B0``#`^\F0``#`^\J0``#`^\N0``#`^\R0``#`
M^\V0``#`^\Z0``#`^\^0``#A$@````#B$@````#C$@````#D$@````#E$@``
M``#F$@````#G$@````#I$@````#J$@````#K$@````#L$@````#M$@````#N
M$@````#P$@````#Q$@````#R$@````#S$@````#T$@````#U$@````#W$@``
M``#X$@````#Y$@````#Z$@````#[$@````#\$@````#]$@````#^$@````#_
M$@``````$P`````!$P`````"$P`````$$P`````%$P````#H$@````#O$@``
M``#V$@`````#$P`````&$P`````'$P`````($P`````)$P````#`^_F0``#`
M^_J0``!Q`@````#`^_R0``#`^_V0``#`^_Z0``#`^_^0``":&*T8``!:`P``
M``!;`P````!<`P````#^`@````#_`@```````P`````!`P`````"`P`````#
M`P`````$`P`````%`P`````%`P`````&`P`````'`P`````(`P`````)`P``
M```*`P`````+`P````!=`P````!,`@````!>`P````!?`P````!@`P``````
M``````````````!A`P````!B`P````!C`P````!D`P````!E`P````!F`P``
M```I#@`````J#@`````K#@`````L#@`````M#@`````N#@`````O#@`````P
M#@`````Q#@`````R#@`````J#@`````K#@`````L#@`````M#@`````N#@``
M```O#@`````P#@`````Q#@`````R#@`````I#@````!G`P````````````!H
M`P````````````!I`P````````````".`@````"/`@````"0`@````"1`@``
M``!J`P````!K`P````!6&`````!8&`````!:&`````!:&)D8``!<&`````!>
M&`````!@&`````!B&`````#`^TB/``!D&`````!F&`````!H&`````!J&```
M``!J&)D8``!L&`````!N&`````!P&`````!R&`````!R&)D8``!T&`````!V
M&`````!X&`````!Z&`````!Z&)D8``!\&`````!^&`````"`&`````""&```
M``""&)D8``"$&`````"&&`````"(&`````"*&`````",&`````".&`````"0
M&`````"2&`````"4&`````"6&`````"8&`````":&`````!6&)48``".&```
M``#`^VN/``#`^VR/``#`^VV/``#`^VZ/``#`^V^/``#`^W"/``"@&`````"A
M&`````"B&`````"E&`````"F&`````"G&`````"H&`````"I&`````"J&```
M``"K&`````"L&`````"M&`````"N&`````````````````````"C&`````"D
M&`````````````````````"O&``````,`P````````````````````"<&```
M``"=&`````">&`````"?&`````#`^XR/``#`^XV/``#`^XZ/``#`^X^/``!7
M&`````!9&`````!;&`````!;&)D8``!=&`````!?&`````!A&`````!C&```
M``#`^YB/``!E&`````!G&`````!I&`````!K&`````!K&)D8``!M&`````!O
M&`````!Q&`````!S&`````!S&)D8``!U&`````!W&`````!Y&`````![&```
M``![&)D8``!]&`````!_&`````"!&`````"#&`````"#&)D8``"%&`````"'
M&`````")&`````"+&`````"-&`````"/&`````"1&`````"3&`````"5&```
M``"7&`````"9&`````";&`````!7&)48``"%&`````"-&`````"/&`````#`
M^[V/``!L`P````!M`P````!N`P````!O`P````!P`P````!Q`P````!R`P``
M``!S`P````````````!T`P````!U`P````!V`P````!W`P````!X`P````!Y
M`P````#`^\V/``#`^\Z/``!Z`P````#`^]"/``#`^]&/``#`^]*/``#`^]./
M``#`^]2/``#`^]6/``#`^]:/``#`^]>/``#`^]B/``#`^]F/``#`^]J/``#`
M^]N/``#`^]R/``#`^]V/``#`^]Z/``#`^]^/``#`^^"/``#`^^&/``#`^^*/
M``#`^^./``#`^^2/``#`^^6/``#`^^:/``#`^^>/``#`^^B/``#`^^F/``#`
M^^J/``#`^^N/``#`^^R/``#`^^V/``#`^^Z/``#`^^^/``#`^_"/``#`^_&/
M``#`^_*/``#`^_./``#`^_2/``#`^_6/``#`^_:/``#`^_>/``#`^_B/``#`
M^_F/``#`^_J/``#`^_N/``#`^_R/``#`^_V/``#`^_Z/``#`^_^/``#`^P".
M``#D%P````#E%P````#F%P````#G%P````#H%P````#I%P````#J%P````#K
M%P````#L%P````#M%P````#N%P````#O%P````#P%P````#Q%P````#R%P``
M``#S%P````#T%P````#U%P````#V%P````#W%P````#X%P````#Y%P````#Z
M%P````#[%P````#\%P````#]%P````#^%P````#_%P``````&``````!&```
M```"&``````#&``````$&``````%&``````&&``````'&``````(&``````)
M&``````*&``````+&``````,&``````-&``````.&``````/&``````0&```
M```1&``````2&``````3&``````4&``````5&``````6&``````7&``````8
M&``````9&``````:&``````;&``````<&``````=&`````#`^SN.``#`^SR.
M``#`^SV.``#`^SZ.```6#@`````>&``````?&``````@&``````A&``````B
M&``````C&``````##@``````````````````````````````````````````
M```D&``````E&`````````````!9`P`````I#@`````J#@`````K#@`````L
M#@`````M#@`````N#@`````O#@`````P#@`````Q#@`````R#@````#\`@``
M``#]`@````#`^UR.``#`^UV.``#`^UZ.``#`^U^.``#`^V".``#`^V&.``#`
M^V*.``#`^V..``#`^V2.``#`^V6.``#`^V:.``#`^V>.``#`^VB.``#`^VF.
M``#`^VJ.``#`^VN.``#`^VR.``#`^VV.``#`^VZ.``#`^V^.``#`^W".``#`
M^W&.``#`^W*.``#`^W..``#`^W2.``#`^W6.``#`^W:.``#`^W>.``#`^WB.
M``#`^WF.``#`^WJ.``#`^WN.``#`^WR.``#`^WV.``#`^WZ.``#`^W^.``#`
M^X".```F&``````G&`````#`^X..```H&`````#`^X6.``#`^X:.```I&```
M```J&`````#`^XF.```K&`````#`^XN.``#`^XR.```L&`````#`^XZ.``#`
M^X^.``#`^Y".``#`^Y&.``#`^Y*.``#`^Y..```M&``````N&``````O&```
M```P&`````#`^YB.```Q&``````R&``````S&``````T&``````U&``````V
M&``````W&`````#`^Z".```X&``````Y&``````Z&`````#`^Z2.```[&```
M``#`^Z:.```\&`````#`^ZB.``#`^ZF.```]&``````^&`````#`^ZR.```_
M&`````!`&`````!!&`````!"&`````!#&`````!$&`````!%&`````!&&```
M``!'&`````!(&`````!)&`````!*&`````!+&`````#`^[J.``!,&`````!-
M&`````!.&`````#`^[Z.``#`^[^.``!/&`````!0&`````!1&`````!2&```
M``!3&`````#`^\6.```$#@````#`^\>.````````````````````````````
M``````!4&`````!5&`````#`^\Z.``#`^\^.```I#@`````J#@`````K#@``
M```L#@`````M#@`````N#@`````O#@`````P#@`````Q#@`````R#@````#`
M^]J.``#`^]N.```^&#$8```^&#@8``#`^]Z.``#`^]^.``#`^^".``#`^^&.
M``#`^^*.``#`^^..``#`^^2.``#`^^6.``#`^^:.``#`^^>.``#`^^B.``#`
M^^F.``#`^^J.``#`^^N.``#`^^R.``#`^^V.``#`^^Z.``#`^^^.``#`^_".
M``#`^_&.``#`^_*.``#`^_..``#`^_2.``#`^_6.``#`^_:.``#`^_>.``#`
M^_B.``#`^_F.``#`^_J.``#`^_N.``#`^_R.``#`^_V.``#`^_Z.``#`^_^.
M``#`^P"-``#`^P&-``````````````````#`^P2-``!5%P````!6%P````!7
M%P````!8%P````!9%P````!:%P````!;%P````!=%P````#`^PV-``!?%P``
M``!@%P````!A%P````#`^Q&-``!B%P````!C%P````!D%P````!E%P````!F
M%P````!G%P````!H%P````!I%P````!J%P````!K%P````!L%P````!M%P``
M``!N%P````!O%P````!P%P````!Q%P````!R%P````!S%P````!T%P````!U
M%P````!V%P````!W%P````!X%P````#`^RF-``!Y%P````!Z%P````![%P``
M``!\%P````!]%P````!^%P````!_%P````"`%P````"!%P````""%P````"#
M%P````"$%P````"%%P````"&%P````"'%P````"(%P````#`^SJ-``#`^SN-
M``#`^SR-``#`^SV-``")%P````"*%P````"+%P````",%P````"-%P````".
M%P````#`^T2-``#`^T6-``"/%P````"0%P````"1%P````#`^TF-``"2%P``
M``"3%P````"4%P````"5%P````#`^TZ-``#`^T^-``#`^U"-``#`^U&-``#`
M^U*-``#`^U.-``#`^U2-``#`^U6-``#`^U:-``"6%P````#`^UB-``#`^UF-
M``#`^UJ-``#`^UN-``#`^UR-``#`^UV-``#`^UZ-``#`^U^-``!<%P````!>
M%P````#`^V*-``#`^V.-``#`^V2-``#`^V6-```I#@`````J#@`````K#@``
M```L#@`````M#@`````N#@`````O#@`````P#@`````Q#@`````R#@````#`
M^W"-``#`^W&-``#`^W*-``#`^W.-``#`^W2-``#`^W6-``#`^W:-``#`^W>-
M``#`^WB-``#`^WF-``#`^WJ-``#`^WN-``#`^WR-``#`^WV-``#`^WZ-``#`
M^W^-``#`^X"-``#`^X&-``````````````````#`^X2-``"7%P````"8%P``
M``"9%P````":%P````";%P````"<%P````"=%P````">%P````"?%P````"@
M%P````"A%P````"B%P````"C%P````"D%P````"E%P````"F%P````"G%P``
M``"H%P````#`^Y>-``#`^YB-``#`^YF-``"I%P````"J%P````"K%P````"L
M%P````"M%P````"N%P````"O%P````"P%P````"Q%P````"R%P````"S%P``
M``"T%P````"U%P````"V%P````"W%P````"X%P````"Y%P````"Z%P````"[
M%P````"\%P````"]%P````"^%P````"_%P````#`%P````#`^[*-``#!%P``
M``#"%P````##%P````#$%P````#%%P````#&%P````#'%P````#(%P````#)
M%P````#`^[R-``#*%P````#`^[Z-``#`^[^-``#+%P````#,%P````#-%P``
M``#.%P````#/%P````#0%P````#1%P````#`^\>-``#`^\B-``#`^\F-``#2
M%P````#`^\N-``#`^\R-``#`^\V-``#`^\Z-``#3%P````#4%P````#5%P``
M``#6%P````#7%P````#8%P````#`^]6-``#9%P````#`^]>-``#:%P````#;
M%P````#<%P````#=%P````#>%P````#?%P````#@%P````#A%P````#`^^"-
M``#`^^&-``#`^^*-``#`^^.-``#`^^2-``#`^^6-``#`^^:-``#`^^>-``#`
M^^B-``#`^^F-``#`^^J-``#`^^N-``#`^^R-``#`^^V-``#`^^Z-``#`^^^-
M``#`^_"-``#`^_&-``#B%P````#C%P````#[`@````#`^_6-``#`^_:-``#`
M^_>-``#`^_B-``#`^_F-``#`^_J-``#`^_N-``#`^_R-``#`^_V-``#`^_Z-
M``#`^_^-``#`^P",``````````````````````````#`^P2,``#-%@````#.
M%@````#/%@````#0%@````#1%@````#2%@````#3%@````#5%@````#`^PV,
M``#7%@````#8%@````#9%@````#`^Q&,``#:%@````#;%@````#<%@````#=
M%@````#>%@````#?%@````#@%@````#A%@````#B%@````#C%@````#D%@``
M``#E%@````#F%@````#G%@````#H%@````#I%@````#J%@````#K%@````#L
M%@````#M%@````#N%@````#O%@````#P%@````#`^RF,``#Q%@````#R%@``
M``#S%@````#T%@````#U%@````#V%@````#W%@````#X%@````#Y%@````#Z
M%@````#`^S2,``#[%@````#\%@````#]%@````#^%@````#_%@````#`^SJ,
M``#`^SN,``#`^SR,``#`^SV,````%P`````!%P`````"%P`````#%P`````$
M%P`````%%P`````&%P````#`^T6,```'%P`````(%P`````)%P````#`^TF,
M```*%P`````+%P`````,%P`````-%P````#`^TZ,``#`^T^,``#`^U",``#`
M^U&,``#`^U*,``#`^U.,``#`^U2,```.%P`````/%P````#`^U>,``#`^UB,
M``#`^UF,``#`^UJ,``#`^UN,``#`^UR,``#`^UV,``#`^UZ,``#`^U^,``#4
M%@````#6%@````#`^V*,``#`^V.,``#`^V2,``#`^V6,```I#@`````J#@``
M```K#@`````L#@`````M#@`````N#@`````O#@`````P#@`````Q#@`````R
M#@````#`^W",``#`^W&,``#`^W*,``#`^W.,``#`^W2,``#`^W6,``#`^W:,
M``#`^W>,``#`^WB,``#`^WF,``#`^WJ,``#`^WN,``#`^WR,``#`^WV,``#`
M^WZ,``#`^W^,``#`^X",``#`^X&,``````````````````#`^X2,```0%P``
M```1%P`````2%P`````3%P`````4%P`````5%P`````6%P`````8%P````#`
M^XV,```:%P`````;%P`````<%P````#`^Y&,```=%P`````>%P`````?%P``
M```@%P`````A%P`````B%P`````C%P`````D%P`````E%P`````F%P`````G
M%P`````H%P`````I%P`````J%P`````K%P`````L%P`````M%P`````N%P``
M```O%P`````P%P`````Q%P`````R%P`````S%P````#`^ZF,```T%P`````U
M%P`````V%P`````W%P`````X%P`````Y%P`````Z%P`````[%P`````\%P``
M``!#%P````#`^[2,```]%P`````^%P`````_%P````!`%P````!!%P````#`
M^[J,``#`^[N,``````````!"%P````!%%P````!&%P````!'%P````!(%P``
M``!)%P````!*%P````!+%P````#`^\6,``!,%P````!-%P````!.%P````#`
M^\F,``!/%P````!0%P````!1%P````!2%P````#`^\Z,``#`^\^,``#`^]",
M``#`^]&,``#`^]*,``#`^].,``#`^]2,``!3%P````!4%P````#`^]>,``#`
M^]B,``#`^]F,``#`^]J,``#`^]N,``#`^]R,``#`^]V,``!$%P````#`^]^,
M```7%P`````9%P````#`^^*,``#`^^.,``#`^^2,``#`^^6,```I#@`````J
M#@`````K#@`````L#@`````M#@`````N#@`````O#@`````P#@`````Q#@``
M```R#@````#`^_",``#`^_&,``#`^_*,``#`^_.,``#`^_2,``#`^_6,``#`
M^_:,``#`^_>,``#`^_B,``#`^_F,``#`^_J,``#`^_N,``#`^_R,``#`^_V,
M``#`^_Z,``#`^_^,``#`^P"+``````````````````````````#`^P2+``!=
M%@````!>%@````!?%@````!@%@````!A%@````!B%@````!C%@````!E%@``
M``#`^PV+``#`^PZ+``!G%@````!H%@````#`^Q&+``#`^Q*+``!I%@````!J
M%@````!K%@````!L%@````!M%@````!N%@````!O%@````!P%@````!Q%@``
M``!R%@````!S%@````!T%@````!U%@````!V%@````!W%@````!X%@````!Y
M%@````!Z%@````![%@````!\%@````!]%@````!^%@````#`^RF+``!_%@``
M``"`%@````"!%@````""%@````"#%@````"$%@````"&%@````#`^S&+``"'
M%@````"(%@````#`^S2+``")%@````"+%@````",%@````"-%@````".%@``
M``#`^SJ+``#`^SN+``````````"/%@````"0%@````"1%@````"2%@````"3
M%@````"4%@````"5%@````#`^T2+``#`^T6+``#`^T:+``"6%@````"7%@``
M``#`^TF+``#`^TJ+``"8%@````"9%@````":%@````#`^TZ+``#`^T^+``#`
M^U"+``#`^U&+``#`^U*+``#`^U.+``#`^U2+``#`^U6+``";%@````"<%@``
M``#`^UB+``#`^UF+``#`^UJ+``#`^UN+``!W%@````!X%@````#`^UZ+``"%
M%@````!D%@````!F%@````#`^V*+``#`^V.+``#`^V2+``#`^V6+```I#@``
M```J#@`````K#@`````L#@`````M#@`````N#@`````O#@`````P#@`````Q
M#@`````R#@````!1`P````"*%@````#`^W*+``#`^W.+``#`^W2+``#`^W6+
M``#`^W:+``#`^W>+``#`^WB+``#`^WF+``#`^WJ+``#`^WN+``#`^WR+``#`
M^WV+``#`^WZ+``#`^W^+``#`^X"+``#`^X&+``````````"=%@````#`^X2+
M``">%@````"?%@````"@%@````"A%@````"B%@````"C%@````#`^XN+``#`
M^XR+``#`^XV+``"D%@````"E%@````"F%@````#`^Y&+``"G%@````"H%@``
M``"I%@````"J%@````#`^Y:+``#`^Y>+``#`^YB+``"K%@````"L%@````#`
M^YN+``"M%@````#`^YV+``"N%@````"O%@````#`^Z"+``#`^Z&+``#`^Z*+
M``"P%@````"Q%@````#`^Z6+``#`^Z:+``#`^Z>+``"R%@````"S%@````"T
M%@````#`^ZN+``#`^ZR+``#`^ZV+``"U%@````"V%@````"W%@````"X%@``
M``"Y%@````"Z%@````"[%@````"\%@````#`^[:+``"]%@````"^%@````"_
M%@````#`^[J+``#`^[N+``#`^[R+``#`^[V+``#`%@````#!%@````#"%@``
M``##%@````#$%@````#`^\.+``#`^\2+``#`^\6+``#%%@````#&%@````#'
M%@````#`^\F+``#(%@````#)%@````#*%@````#+%@````#`^\Z+``#`^\^+
M``#`^]"+``#`^]&+``#`^]*+``#`^].+``#`^]2+``#`^]6+``#`^]:+``#,
M%@````#`^]B+``#`^]F+``#`^]J+``#`^]N+``#`^]R+``#`^]V+``#`^]Z+
M``#`^]^+``#`^^"+``#`^^&+``#`^^*+``#`^^.+``#`^^2+``#`^^6+``#`
M^^:+```J#@`````K#@`````L#@`````M#@`````N#@`````O#@`````P#@``
M```Q#@`````R#@````#)#0````#*#0````#+#0````!2`P````!3`P````!4
M`P````!5`P````!6`P````!7`P`````5#@````!8`P````#`^_N+``#`^_R+
M``#`^_V+``#`^_Z+``#`^_^+``#`^P"*``````````````````````````#`
M^P2*``#G%0````#H%0````#L%0````#M%0````#D%0````#E%0````#`^PN*
M``#`^PR*``#`^PV*``#`^PZ*``#N%0````#I%0````#`^Q&*``#`^Q**``#F
M%0````#J%0````#Q%0````#R%0````#S%0````#T%0````#U%0````#V%0``
M``#W%0````#X%0````#Y%0````#Z%0````#[%0````#\%0````#]%0````#^
M%0````#_%0``````%@`````!%@`````"%@`````#%@`````$%@````#`^RF*
M```%%@`````&%@`````'%@`````(%@`````)%@`````*%@`````+%@````#`
M^S&*```,%@`````,%@````#`^S2*```-%@````#O%0````#`^S>*``#O%0``
M``#P%0````#`^SJ*``#`^SN*``````````#`^SV*```/%@`````0%@`````1
M%@`````2%@`````3%@````#`^T.*``#`^T2*``#`^T6*``#`^T:*```4%@``
M```5%@````#`^TF*``#`^TJ*```6%@`````7%@`````8%@````#`^TZ*``#`
M^T^*``#`^U"*``#`^U&*``#`^U**``#`^U.*``#`^U2*``#`^U6*``#`^U:*
M``#`^U>*``#`^UB*``#R%0````#S%0````#X%0`````.%@````#`^UV*```&
M%@````#`^U^*``#`^V"*``#`^V&*``#`^V**``#`^V.*``#`^V2*``#`^V6*
M```I#@`````J#@`````K#@`````L#@`````M#@`````N#@`````O#@`````P
M#@`````Q#@`````R#@````````````````````#K%0````#C%0````#B%0``
M``#`^W6*``#`^W:*``#`^W>*``#`^WB*``#`^WF*``#`^WJ*``#`^WN*``#`
M^WR*``#`^WV*``#`^WZ*``#`^W^*``#`^X"*````````````````````````
M``#`^X2*```:%@`````;%@`````<%@`````=%@`````>%@`````?%@`````@
M%@`````B%@`````D%@````#`^XZ*```E%@`````F%@`````G%@````#`^Y**
M```H%@`````I%@`````J%@`````K%@`````L%@`````M%@`````N%@`````O
M%@`````P%@`````Q%@`````R%@`````S%@`````T%@`````U%@`````V%@``
M```W%@`````X%@`````Y%@`````Z%@`````[%@`````\%@`````]%@````#`
M^ZF*```^%@`````_%@````!`%@````!!%@````!"%@````!#%@````!$%@``
M``#`^[&*``!%%@````!&%@````#`^[2*``!'%@````!(%@````!)%@````!*
M%@````!+%@````#`^[J*``#`^[N*``````````!,%@````!-%@````!.%@``
M``!/%@````!0%@````!1%@````!2%@````!3%@````!6%@````#`^\:*``!7
M%@````!8%@````!9%@````#`^\J*``!:%@````!;%@````!<%@````#`^\Z*
M``#`^\^*```9%@````#`^]&*``#`^]**``#`^].*``#`^]2*``#`^]6*``#`
M^]:*``#`^]>*``#`^]B*``#`^]F*``#`^]J*``#`^]N*``#`^]R*``#`^]V*
M``#`^]Z*``#`^]^*```A%@`````C%@````!4%@````!5%@````#`^^2*``#`
M^^6*```I#@`````J#@`````K#@`````L#@`````M#@`````N#@`````O#@``
M```P#@`````Q#@`````R#@````#`^_"*```4#@````#`^_**``#`^_.*``#`
M^_2*``#`^_6*``#`^_:*``#`^_>*``#`^_B*``#`^_F*``#`^_J*``#`^_N*
M``#`^_R*``#`^_V*``#`^_Z*``#`^_^*``#`^P")````````````````````
M``````!:%0````!;%0````!<%0````!=%0````!>%0````!?%0````!@%0``
M``!A%0````!C%0````!E%0````!F%0````!G%0````!H%0````!I%0````!J
M%0````!K%0````!L%0````!M%0````!N%0````!O%0````!P%0````!Q%0``
M``!R%0````!S%0````!T%0````!U%0````!V%0````!W%0````!X%0````!Y
M%0````!Z%0````![%0````!\%0````!]%0````!^%0````!_%0````"`%0``
M``"`%0````"!%0````""%0````"#%0````"$%0````"%%0````"&%0````"'
M%0````"'%0````"(%0````")%0````")%0````"*%0````"+%0````",%0``
M``"-%0````".%0````#`^SJ)``#`^SN)``````````"/%0````"0%0````"1
M%0````"2%0````"3%0````"4%0````"5%0````"6%0````"9%0````":%0``
M``";%0````"<%0````"=%0````">%0````"?%0````"@%0````"A%0````#`
M^TZ)``#`^T^)``!9%0````````````````````````````````````#`^U6)
M``#`^U:)``#`^U>)``!M%0````!N%0````!O%0````!T%0````!Y%0````!Z
M%0````""%0````"&%0````!B%0````!D%0````"7%0````"8%0````!H`@``
M``!I`@`````I#@`````J#@`````K#@`````L#@`````M#@`````N#@`````O
M#@`````P#@`````Q#@`````R#@````#Z`@````#`^W&)``#`^W*)``#`^W.)
M``#`^W2)``#`^W6)``#`^W:)``#`^W>)``#`^WB)``#`^WF)``#`^WJ)``#`
M^WN)``#`^WR)``#`^WV)``#`^WZ)``#`^W^)``#`^X")````````````````
M``````````#`^X2)``"B%0````"C%0````"D%0````"E%0````"F%0````"G
M%0````"H%0````"J%0````#`^XV)``#`^XZ)``"L%0````"M%0````#`^Y&)
M``#`^Y*)``"N%0````"O%0````"P%0````"Q%0````"R%0````"S%0````"T
M%0````"U%0````"V%0````"W%0````"X%0````"Y%0````"Z%0````"[%0``
M``"\%0````"]%0````"^%0````"_%0````#`%0````#!%0````#"%0````##
M%0````#`^ZF)``#$%0````#%%0````#&%0````#'%0````#(%0````#)%0``
M``#*%0````#`^[&)``#,%0````#`^[.)``#`^[2)``#`^[6)``#.%0````#/
M%0````#0%0````#1%0````#`^[J)``#`^[N)``````````#2%0````#3%0``
M``#4%0````#5%0````#6%0````#7%0````#8%0````#9%0````#`^\6)``#`
M^\:)``#<%0````#=%0````#`^\F)``#`^\J)``#>%0````#?%0````#@%0``
M``#`^\Z)``#`^\^)``#`^]")``#`^]&)``#`^]*)``#`^].)``#`^]2)``#`
M^]6)``#`^]:)``#A%0````#`^]B)``#`^]F)``#`^]J)``#`^]N)``"\%0``
M``"]%0````#`^]Z)``#)%0````"I%0````"K%0````#:%0````#;%0````#`
M^^2)``#`^^6)```I#@`````J#@`````K#@`````L#@`````M#@`````N#@``
M```O#@`````P#@`````Q#@`````R#@````#+%0````#-%0`````2#@`````3
M#@`````J#@`````K#@`````L#@`````M#@````#'#0````#(#0````!0`P``
M``#`^_N)``#`^_R)``#`^_V)``#`^_Z)``#`^_^)``!P`@````!@`@````!A
M`@`````_`@````!``@````!!`@````!"`@````!#`@````!$`@````!9`@``
M``#T`@````#U`@````#V`@````#W`@````#`^PZ'``````````#/$P``````
M``````#0$P````#1$P````#1$P````#3$P````#2$P````#4$P````#5$P``
M``#6$P````#8$P````#9$P````#9$P````#:$P````#;$P````#<$P````#>
M$P````#?$P````#@$P````#A$P````#A$P````#B$P````#C$P````#C$P``
M``#E$P````#F$P````#G$P````#H$P````#I$P````#0$P````#1$P````#3
M$P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#`^TN'``#`^TR'``#7
M$P````#=$P````#D$P````#`^U"'``#`^U&'``#`^U*'``#`^U.'``#`^U2'
M``#`^U6'``#`^U:'``#`^U>'``#`^UB'``#`^UF'``#`^UJ'``#`^UN'``#`
M^UR'``#`^UV'``#`^UZ'``#`^U^'``#`^V"'``#`^V&'``#`^V*'``#`^V.'
M``#`^V2'``#`^V6'``#`^V:'``#`^V>'``#`^VB'``#`^VF'``#`^VJ'``#`
M^VN'``#`^VR'``#`^VV'``#`^VZ'``#`^V^'``#`^W"'``#`^W&'``#`^W*'
M``#`^W.'``#`^W2'``#`^W6'``#`^W:'``#`^W>'``#`^WB'``#`^WF'``#`
M^WJ'``#`^WN'``#`^WR'``#`^WV'``#`^WZ'``#`^W^'``#J$P````#M$P``
M``#N$P````#O$P````#Q$P````#R$P````#S$P````#T$P````#W$P````#Y
M$P````#Z$P````#[$P````#]$P`````!%``````"%``````$%``````%%```
M```)%``````*%``````+%``````,%``````-%``````.%``````/%`````#^
M$P````#K$P````#L$P````#\$P````#P$P`````&%``````'%``````(%```
M``#_$P``````%`````#U$P````#V$P`````#%`````#X$P`````1%``````2
M%``````3%``````4%``````5%``````6%``````7%``````8%``````9%```
M```:%``````;%``````0%`````#`^[*'``#`^[.'``#`^[2'``#`^[6'``#`
M^[:'``#`^[>'``#`^[B'``#`^[F'``#`^[J'``#`^[N'``#`^[R'``#`^[V'
M``#`^[Z'``#`^[^'``#`^\"'``#`^\&'``#`^\*'``#`^\.'``#`^\2'``#`
M^\6'``#`^\:'``#`^\>'``#`^\B'``#`^\F'``#`^\J'``#`^\N'``#`^\R'
M``#`^\V'``#`^\Z'``#`^\^'``#`^]"'``#`^]&'``#`^]*'``#`^].'``#`
M^]2'``#`^]6'``#`^]:'``#`^]>'``#`^]B'``#`^]F'``#`^]J'``#`^]N'
M``#`^]R'``#`^]V'``#`^]Z'``#`^]^'``#`^^"'``#`^^&'``#`^^*'``#`
M^^.'``#`^^2'``#`^^6'``#`^^:'``#`^^>'``#`^^B'``#`^^F'``#`^^J'
M``#`^^N'``#`^^R'``#`^^V'``#`^^Z'``#`^^^'``#`^_"'``#`^_&'``#`
M^_*'``#`^_.'``#`^_2'``#`^_6'``#`^_:'``#`^_>'``#`^_B'``#`^_F'
M``#`^_J'``#`^_N'``#`^_R'``#`^_V'``#`^_Z'``#`^_^'````````````
M``````````````````````#`^P2&``#`^P6&``#`^P:&``#`^P>&``#`^PB&
M``#`^PF&``#`^PJ&``#`^PN&```Q`@`````R`@````!,`P````!-`P``````
M``````````````````````````````````````````````#`^Q:&``#`^Q>&
M``#`^QB&``#`^QF&``#`^QJ&```[`@````#`^QR&``#`^QV&``#`^QZ&``!8
M`@````#`^R"&``!'$P````!($P````!)$P````!,$P````!-$P````!/$P``
M``!0$P````!2$P````!6$P````!7$P````!8$P````!>$P````!D$P````!E
M$P````!I$P````!J$P````!U$P````!V$P````"!$P````""$P````"'$P``
M``"($P````",$P````"-$P````"/$P````"0$P````#`^SN&``#`^SR&``#`
M^SV&``#`^SZ&``#`^S^&```+`@````"3$P````";$P````">$P````"K$P``
M``"P$P````"Q$P````"W$P````"]$P````#'$P````#($P``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#`^UF&``#`^UJ&``#`
M^UN&``#`^UR&``#`^UV&``#`^UZ&``#`^U^&```I#@`````J#@`````K#@``
M```L#@`````M#@`````N#@`````O#@`````P#@`````Q#@`````R#@````#4
M`@`````S`@`````T`@````#+`@````!1$P````":$P````````````!+$P``
M``!*$P````!.$P````!'$P````!0$T<3``"]$T<3``#!$T<3``#($T<3``!9
M$P````!:$P````!3$P````!;$P````!<$P````!4$P````!=$P````!5$P``
M``!F$P````!G$P````!?$P````!@$P````!H$P````!A$P````!C$P````!K
M$P````!L$P````!M$P````!N$P````!O$P````!P$P````!Q$P````!R$P``
M``!S$P````!W$P````!X$P````!Y$P````!Z$P````![$P````!\$P````!]
M$P````!^$P````!_$P````"#$P````"$$P````"%$P````")$P````"*$P``
M``".$P````"1$P````"4$P````"5$P````"6$P````"7$P````"8$P````"9
M$P````"<$P````"=$P````"?$P````"@$P````"A$P````"B$P````"C$P``
M``"D$P````"E$P````"F$P````"G$P````"H$P````"I$P````"J$P````"L
M$P````"M$P````"N$P````"O$P````"V$P````"R$P````"S$P````"T$P``
M``"U$P````"X$P````!B$P````"\$P````"Y$P````"Y$P````"Z$P````"^
M$P````"_$P````#`$P````#!$P````#"$P````##$P````#$$P````#%$P``
M``#)$P````#*$P````#+$P````#&$P````#,$P````#-$P````#.$P````#.
M$P````!?`@````"\$P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"]$P````#($P````````````````````!.`P``
M``````````````````````````````````!T$P````"`$P`````I#@`````J
M#@`````K#@`````L#@`````M#@`````N#@`````O#@`````P#@`````Q#@``
M```R#@````"&$P````"+$P````"2$P````!'$P````"P$P````"[$P````!$
M$0````!$$0````!)$0````!)$0````!N$0````!N$0````![$0````![$0``
M``"]$0````"]$0````#>$0````#>$0`````'$@`````'$@`````0$@`````0
M$@````#`^Q"%``#`^Q&%``#`^Q*%``#`^Q.%``#`^Q2%``#`^Q6%``#`^Q:%
M``#`^Q>%``#`^QB%``#`^QF%``#`^QJ%``#`^QN%``#`^QR%``#`^QV%``#`
M^QZ%``#`^Q^%``#`^R"%``#`^R&%``#`^R*%``#`^R.%``#`^R2%``#`^R6%
M``#`^R:%``#`^R>%``#`^RB%``#`^RF%``#`^RJ%``#`^RN%``#`^RR%``#`
M^RV%``#`^RZ%``#`^R^%``#`^S"%```*$P`````+$P`````,$P`````-$P``
M```.$P`````/$P`````0$P`````1$P`````2$P`````3$P`````4$P`````5
M$P`````6$P`````7$P`````8$P`````9$P`````:$P`````;$P`````<$P``
M```=$P`````>$P`````?$P`````@$P`````A$P`````B$P`````C$P`````D
M$P`````E$P`````F$P`````G$P`````H$P`````I$P`````J$P`````K$P``
M```L$P`````M$P`````N$P`````O$P````#`^U>%``#`^UB%```P$P````#L
M`@````#M`@````!3`@`````P`@````!7`@````#N`@````#`^V"%```*$P``
M```+$P`````,$P`````-$P`````.$P`````/$P`````0$P`````1$P`````2
M$P`````3$P`````4$P`````5$P`````6$P`````7$P`````8$P`````9$P``
M```:$P`````;$P`````<$P`````=$P`````>$P`````?$P`````@$P`````A
M$P`````B$P`````C$P`````D$P`````E$P`````F$P`````G$P`````H$P``
M```I$P`````J$P`````K$P`````L$P`````M$P`````N$P`````O$P`````.
M$RL3``#`^XB%```^`@`````B`@````#`^XN%``#`^XR%``#`^XV%``#`^XZ%
M``#`^X^%``#`^Y"%````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#`^Z*%````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#`^[J%````````
M``````````````````#O`@````````````#P`@````````````````````#Q
M`@````````````#`^\6%``#`^\:%``#`^\>%``#`^\B%``#`^\F%``#`^\J%
M``#`^\N%``#`^\R%``#`^\V%``#`^\Z%``#`^\^%```Q$P`````R$P`````S
M$P`````T$P`````U$P`````V$P`````W$P`````X$P`````Y$P`````Z$P``
M```[$P`````[$P`````\$P`````]$P`````]$P`````^$P`````^$P`````_
M$P````!`$P````!!$P````!!$P````!"$P````!"$P````!#$P````!$$P``
M``!%$P````!&$P````#`^^N%``#`^^R%``#`^^V%``#`^^Z%``#`^^^%```V
M$S83```V$SH3```Z$SH3``#R`@````#S`@````#`^_6%``#`^_:%``#`^_>%
M``#`^_B%``#`^_F%``#`^_J%``#`^_N%``#`^_R%``#`^_V%``#`^_Z%``#`
M^_^%``!2$0````!2$0````!%$0````!*$0````!:$0````!S$0````"($0``
M``",$0````"4$0````"Y$0````#:$0`````5$@`````9$@````!\$0`````A
M$@````!]$@`````4$0`````L$0`````P$0`````T$0````!`$0````!2$0``
M``!>$0````!J$0````!\$0````"0$0````"8$0````"P$0````"^$0````#&
M$0````#?$0````#O$0````#[$0`````#$@`````,$@`````=$@`````Y$@``
M```]$@````!9$@````!A$@````"!$@````"%$@````")$@````"-$@````"5
M$@````"A$@````"I$@````"M$@`````4$0`````L$0`````P$0`````T$0``
M``!`$0````!2$0````!>$0````!J$0````!\$0````"0$0````"8$0````"P
M$0````"^$0````#&$0````#?$0````#O$0````#[$0`````#$@`````,$@``
M```=$@`````Y$@`````]$@````!9$@````!A$@````"!$@````"%$@````")
M$@````"-$@````"5$@````"A$@````"I$@````"M$@````!2$0````!2$0``
M``!%$0````!*$0````!:$0````!S$0````"($0````",$0````"4$0````"Y
M$0````#:$0`````5$@`````9$@````!\$0`````A$@````!]$@````!)$@``
M``!)$@````"=$@````"=$@````"Q$@````"Q$@````"U$@````"U$@````"]
M$@````"]$@````"Y$@````"Y$@````#!$@````#!$@````#%$@````#%$@``
M``#)$@````#)$@````#-$@````#-$@````#1$@````#1$@````#5$@````#5
M$@`````U$@`````U$@````!5$@````!5$@````!1$@````!1$@````!-$@``
M``!-$@````#W$0````#W$0````!+`P``````````````````````````````
M``````#`^X>$``````````````````"`$0````"`$0````"9$@````"9$@``
M``#_$0````#_$0`````T$0`````T$0`````X$0`````X$0`````\$0`````\
M$0````!F$0````!F$0````!.$0````!.$0````"<$0````"<$0````"L$0``
M``"L$0````"H$0````"H$0````"D$0````"D$0````#.$0````#.$0````#6
M$0````#6$0````#S$0````#S$0````#9$@````#9$@`````($@`````($@``
M```1$@`````1$@`````M$@`````M$@`````Q$@`````Q$@````!!$@````!!
M$@````!=$@````!=$@````!I$@````!I$@````!Q$@````!Q$@````!%$@``
M``!%$@````!U$@````!U$@````!Y$@````!Y$@````#=$@````!>$0````!>
M$0````"@$0````"@$0````"U$0````"U$0````#2$0````#2$0````#*$0``
M``#*$0````!M$@````!M$@````#"$0````#"$0````#`^\^$```8$0`````8
M$0`````<$0`````<$0`````H$0`````H$0````!6$0````!6$0`````@$0``
M```@$0`````D$0`````D$0````!B$0````!B$0````!O$0````!O$0````!W
M$0````!W$0````!\$0````!\$0````"$$0````"$$0````#C$0````#C$0``
M``#G$0````#G$0````#K$0````#K$0````"E$@````"E$@`````=$@`````=
M$@`````E$@`````E$@`````I$@`````I$@````!E$@````!E$@````#`^_:$
M``#`^_>$``"1$@````"1$@````#`^_J$``#`^_N$``#`^_R$``#`^_V$``#`
M^_Z$``#`^_^$````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````,#[6(,`
M````P/M9@P````#`^UJ#`````,#[6X,`````P/M<@P``````````````````
M```````````````````````````````````````````````````S#@``````
M`(L.````````^PX```````""#P```````!\0````````8`X```````!M#@``
M`````.$.````````6P\```````#`#P````````(0````````1!````````!:
M$````````,#[<(,`````P/MQ@P````#`^W*#`````,#[<X,`````%P,`````
M```8`P```````,#[=H,`````P/MW@P````#`^WB#`````,#[>8,`````\Q``
M``````#`^WN#`````,#[?(,`````P/M]@P`````Z`@```````,#[?X,`````
MP/N`@P````#`^X&#`````,#[@H,`````P/N#@P`````-`@```````!0"````
M````Z!````````!G`@```````.T0````````\1````````#S$````````,#[
MBX,`````^Q````````#`^XV#``````01````````"1$```````#S$```````
M`.@0````````Z1````````#J$````````.P0````````[1````````#P$```
M`````/$0````````\A````````#S$````````/40````````]A````````#X
M$````````/D0````````^A````````#[$````````/P0`````````!$`````
M``#`^Z*#``````(1`````````Q$````````$$0````````41````````!A$`
M```````'$0````````D1````````\Q`````````$$0```````.@0````````
M[1````````#Q$````````/,0````````!!$```````#H$````````.D0````
M````ZA````````#L$````````.T0````````\!````````#Q$````````/(0
M````````\Q````````#U$````````/80````````^!````````#Y$```````
M`/H0````````^Q````````#\$``````````1`````````A$````````"$0``
M``````,1````````!!$````````%$0````````81````````!Q$````````)
M$0```````/,0````````!!$```````#[$`````````01````````"1$`````
M``#`^\^#`````.D0````````\A`````````$$0````````01````````!!$`
M```````%$0```````/P0````````]1#H$/,0``#_$````````/\0````````
M[Q````````#O$````````.X0````````[A````````#^$````````/X0````
M````"A$````````*$0````````T1````````#1$````````.$0````````X1
M````````#Q$````````/$0```````!`1````````$!$````````1$0``````
M`!$1````````$A$````````2$0```````!,1````````$Q$```````#U$```
M```````1`````````A$```````#T$````````/(0````````[1`````````C
M!`````````L1````````"Q$````````"$0````````P1````````#!$`````
M``#`^_R#`````,#[_8,`````P/O^@P````#`^_^#`````#,.`````#,.````
M`#,.`````#,.`````(L.`````(L.`````(L.`````(L.`````/L.`````/L.
M`````/L.`````/L.`````((/`````((/`````((/`````((/`````,`/````
M`,`/`````,`/`````,`/`````!\0`````!\0`````!\0`````!\0`````.H/
M`````.H/``````(0``````(0`````)`0`````)`0`````.$.`````.$.````
M`'(/`````((.`````*(/`````*(/`````',0`````',0`````#,.`````#,.
M`````(L.`````(L.`````((/`````((/`````((/`````((/`````((/````
M`((/`````((/`````((/`````%X0`````%X0`````$L/`````'H/`````!<0
M`````,#[-X(``,#[.((``,#[.8(``,#[.H(``,#[.X(``,#[/((``,#[/8(`
M`,#[/H(``,#[/X(``,#[0((``,#[08(``,#[0H(``,#[0X(``,#[1((``,#[
M18(``,#[1H(``,#[1X(``,#[2((``,#[28(``,#[2H(``,#[2X(``,#[3((`
M`,#[38(``,#[3H(``,#[3X(``#X.`````$(.`````$8.`````%@.`````)(/
M`````&D.`````'8.`````'H.`````)P.`````)0.`````*`.`````)@.````
M`*0.`````*D.`````*T.`````!D/`````-$.`````,4.`````,D.`````-D.
M`````+4.`````"L0`````/$.`````/4.``````@/``````P/``````,/````
M`#\/`````$,/`````$</`````$\/`````#<0`````#P0`````&`/`````&X/
M`````'8/`````&@/`````)H/`````(@/`````)X/`````+`/`````,D/````
M`,X/`````-(/`````-8/`````-H/`````-X/`````.(/`````,0/`````.8/
M`````.X/`````/(/`````!T/`````/H/`````/X/`````!L0`````!,0````
M`"<0`````$`0`````$D0`````$T0`````%80`````%</`````&(0`````'<0
M`````'L0`````'\0`````(P0`````*P0`````+00`````,00`````-@0````
M`-P0`````$X.`````+$.`````-4.`````.4.`````!4/`````"H/`````#(/
M`````+@/`````+P0`````,`0`````&T.:A```&T.?Q```&T.>Q````(0Z@\`
M``(0\@\```(0:0X``+D.?@\``"X/Z@\``"X/:A```.`0`````.00`````"\0
M`````#,0`````.$.`````/$.`````!`/`````,`/`````,D/`````-(/````
M`.8/`````%$0`````%X0`````!<#`````!D#`````/D.`````+$0`````/H.
M`````+,0`````+@0`````+`0`````+D0`````!H#`````!L#`````!P#````
M`!T#`````!X#`````!\#`````"`#`````"$#`````"(#`````",#`````"0#
M`````"4#`````"8#`````"<#``````$.``````(.`````"@#`````"D#````
M`"H#`````"L#`````"P#`````"T#`````!("`````!,"`````!4"`````!H"
M``````X"`````!8"`````"X#`````"\#`````-D.`````"X/`````.H/````
M`%H0`````+00`````#`#`````#$#`````#(#`````#,#`````#0#`````#4#
M`````#8#`````#<#`````#@#`````+(0`````#D#`````#H#`````#L#````
M`#P#`````#T#`````#X#`````#\#`````$`#`````$$#`````$(#`````$,#
M`````$0#`````$4#`````$8#`````$<#`````$@#`````$D#`````#,.````
M`#,.`````#,.`````#,.`````#,.`````#,.`````&`.`````&`.`````&`.
M`````&`.`````&`.`````&`.`````&`.`````&`.`````&T.`````&T.````
M`'(.`````'(.`````(L.`````(L.`````(L.`````(L.`````(L.`````(L.
M`````(L.`````(L.`````(L.`````(L.`````,$.`````,$.`````,$.````
M`,$.`````,$.`````,$.`````,$.`````,$.`````.$.`````.$.`````.T.
M`````.T.`````/L.`````/L.`````/L.`````/L.`````/L.`````/L.````
M`/L.`````/L.`````/L.`````/\.`````/L.$`\``/L.$`\``!`/`````!`/
M`````"$/`````"$/`````+P/`````"X/`````"X/`````"X/`````"X/````
M`"X/`````"X/`````"X/9P(``"X/9P(``#8/`````#8/`````&0/`````&0/
M`````&0/`````&0/`````&0/`````&0/`````+$09`\``'X/`````'X/````
M`((/`````((/`````((/`````((/`````((/`````((/`````((/BPX``((/
MBPX``,`/`````,`/`````,`/`````,`/`````,`/`````,`/`````.H/````
M`.H/`````.H/`````.H/`````.H/`````.H/`````.H/`````.H/``````(0
M``````(0``````(0``````(0``````<0``````<0`````!\0`````!\0````
M`!\0`````!\0`````!\0`````!\0`````!\0`````!\0`````!\0`````!\0
M`````!\0`````!\0`````%$0`````%$0`````%X0`````%X0`````%X0````
M`&H0`````&H0`````&H0`````&H0`````&H0`````&H0`````.H/`````%(.
M`````%@.`````%P.`````%P.`````*@0`````*@0`````)(/`````&4.````
M`&4.`````'8.`````'H.`````'X.`````'X.`````&H041```)`.`````)0.
M`````)@.`````+T.`````+T.`````-$.`````-D.`````.D.``````P/````
M``@/`````"8/`````"8/`````#L/`````%,/`````#<0`````&X/`````'(/
M`````)H/`````((/`````((/`````-T.`````-T.`````*P/`````*P/````
M`,0/`````*`0`````*`0`````/(/`````/8/``````L0``````\0``````\0
M`````!,0`````!\0`````!\0`````$`0`````$D0`````&80`````&80````
M`&\0`````&\0`````'\0`````(00`````(00`````(@0`````)P0`````*00
M`````*00``````(0Z@\``)@0`````,@0`````,P0`````-`0`````-00````
M`&T.:A```&T.:A```&T.:A```"X/$`\``"X/$`\``"X/$`\``&0/$`\``&0/
M$`\``&0/$`\``#,.`````#,.`````/L.`````/L.`````((/`````((/````
M`!\0`````!\0`````!\0`````!\0`````!\0`````!\0`````!\0`````!\0
M`````!\0`````!\0`````)`.`````#,.`````#,.`````#,.`````#,.````
M`#@.`````#@.`````,T.`````,T.`````,$.`````,$.`````"$/`````"$/
M`````((/`````((/`````((/`````((/`````'\0`````'\0`````!`/````
M`&T.:A```&T.:A```&T.:A```,$.`````,$.`````.D.`````)@0`````&0/
M`````&0/`````#,.`````#,.`````#@.`````#@.`````(T/`````(T/````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````$"`````````@(````````#
M`@````````0"````````!0(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````)`@```````%$"````
M````?@(```````#2`@````````\.````````TP(```````#/`@```````'<"
M````````B`(```````")`@```````,@"````````*`0````````O`@``````
M`"$"````````70(```````#,`@```````"D.````````*@X````````K#@``
M`````"P.````````+0X````````N#@```````"\.````````,`X````````Q
M#@```````#(.````````/0(````````Z`@```````"P$````````+00`````
M```N!````````%4"````````QP(````````S#@```````$H.````````8`X`
M``````!M#@```````(L.````````N0X```````#!#@```````.$.````````
M^PX````````0#P```````"$/````````+@\```````!;#P```````&0/````
M````@@\```````"G#P```````+0/````````P`\```````#J#P````````(0
M````````'Q````````!$$````````%$0````````6A````````!>$```````
M`&H0````````B@(```````#.`@```````(L"````````#P(````````;`@``
M``````P"````````,PX```````!*#@```````&`.````````;0X```````"+
M#@```````+D.````````P0X```````#A#@```````/L.````````$`\`````
M```A#P```````"X/````````6P\```````!D#P```````((/````````IP\`
M``````"T#P```````,`/````````Z@\````````"$````````!\0````````
M1!````````!1$````````%H0````````7A````````!J$````````(P"````
M````,`0```````"-`@```````#,$````````````````````````````````
M````````````````````````````````````````!@(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````"0(```````!2`@````````X.````````
M$`X````````-#@```````!$.````````,00```````#"`@```````!0"````
M````Q0(````````S#@```````(8"````````+P0````````@`@```````,8"
M````````$`(```````!*`P```````"D$````````*PX````````L#@``````
M``T"````````^!````````##`@```````&<"````````&0(````````J#@``
M`````((/````````AP(````````J#LT"+0X``"H.S0(K#@``+`[-`BT.``!6
M`@```````#,.````````,PX````````S#@```````#,.````````,PX`````
M```S#@```````#@.````````8`X```````"+#@```````(L.````````BPX`
M``````"+#@```````/L.````````^PX```````#[#@```````/L.````````
MA@X```````!D#P```````((/````````@@\```````""#P```````((/````
M````@@\````````K!````````(T/````````'Q`````````?$````````!\0
M````````'Q````````!>$````````)00````````Z@_J#P`````S#@``````
M`#,.````````,PX````````S#@```````#,.````````,PX````````X#@``
M`````&`.````````BPX```````"+#@```````(L.````````BPX```````#[
M#@```````/L.````````^PX```````#[#@```````(8.````````9`\`````
M``""#P```````((/````````@@\```````""#P```````((/````````*@0`
M``````"-#P```````!\0````````'Q`````````?$````````!\0````````
M7A````````"4$````````%X0````````Z`0(""`%"`B(!@@(O`8("```````
M```````````````!````"@```&0```#H`P``$"<``*"&`0!`0@\`@):8``#A
M]04`````````````````````````````````````!````/3Z&`APB24(````
M`/@M&0C\+1D(`RX9"`@N&0@`````#RX9"!4N&0@`````````````````````
M`````+A&"`CD7@@((#X("`Q""`CL.0@(Z#0("%#%!@CDS08(P-8&"/SV!@B<
M]`8(`````$C(!@BX1@@(:+(&""$````;+AD(`(HE"```````````````````
M``````````````?!"`B4`!D((RX9""PN&0@U+AD(Q2X9"#HN&0@_+AD($.$(
M"$PN&0A5+AD(6RX9"&TN&0AU+AD(?BX9"(4N&0B0+AD(HRX9"+DN&0C-+AD(
MY2X9"-TN&0CR+AD(!"\9"!TO&0@N+QD(.2\9"`("&0A,+QD(9"\9"'(O&0B#
M+QD(D2\9"``````````````````````````````````````?'!\>'QX?'QX?
M'A\```````````````````````````$`````````"@````````!D````````
M`.@#````````$"<```````"@A@$``````$!"#P``````@):8````````X?4%
M``````#*FCL``````.0+5`(`````Z'9(%P`````0I=3H`````*!R3A@)````
M0'H0\UH```"`QJ1^C0,```#!;_*&(P```(I=>$5C`0``9*>SMN`-``#HB00C
MQXH``0(#!`4&_SH``````````````````````````````"HQ&0@P,1D(]/H8
M"$DQ&0@``````````#C@"`@`````````````\#\````````D0````````%E`
M``````!`CT```````(C#0```````:OA``````("$+D$`````T!)C00````"$
MUY=!`````&7-S4$`````````````````````````````\#\````@7Z`"0D",
MM7@=KQ5$ZHR@.5D^*4:E7,/Q*6,]2)ID?L4.&U%*1//"Y.3I8TP]Q]W6NBYW
M3E_[\%'O_(I0QUDI"0]KGU(``````````````````````````+2N"`@`KP@(
MC*\(".1T!P@,L@@([*\(",RM"`@$L`@(````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````H*$E"```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````H*`E"```````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````*"?)0@`````H)XE"`````"@G24(`````*"<
M)0@`````H)LE"`$``````````0`````````!``````````$``````````0``
M```````!``````````$``````````0`````````!``````````$`````````
M`0`````````!``````````$``````````0`````````!``````````$`````
M`````0`````````!``````````$``````````0`````````!``````````$`
M`````````0`````````!``````````$``````````0``````````````H)HE
M"`$``````````0`````````!``````````$``````````0`````````!````
M``````$``````````0`````````!``````````$``````````0`````````!
M``````````$``````````0`````````!``````````$``````````0``````
M```!``````````$``````````0`````````!``````````$``````````0``
M```````!``````````$``````````0`````````!``````````$`````````
M`0`````````!``````````$``````````0`````````!``````````$`````
M`````0`````````!``````````$``````````0`````````!``````````$`
M`````````0`````````!``````````$``````````0`````````!````````
M``$``````````0`````````!``````````$``````````0`````````!````
M``````$``````````0`````````!``````````$``````````0`````````!
M``````````$``````````0`````````!``````````$``````````0``````
M```!``````````$``````````0`````````!``````````$``````````0``
M```````!``````````$``````````0`````````!``````````$`````````
M`0`````````!``````````$``````````0`````````!``````````$`````
M`````0`````````!``````````````"@F24(`0`````````!``````````$`
M`````````0``````````````H)@E"```````````````````````````````
M`````````````````````````````````````````````0`````````!````
M``````$``````````0`````````!``````````$``````````0`````````!
M``````````$``````````0`````````!``````````$``````````0``````
M```!``````````$``````````0`````````!``````````$``````````0``
M```````!``````````$``````````0`````````!``````````$`````````
M`0`````````!``````````$``````````0`````````!``````````$`````
M`````0`````````!``````````$``````````0`````````!``````````$`
M`````````0`````````!``````````$``````````0`````````!````````
M``$``````````0``````````````H)<E"```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````$``````````````*"6)0@`````````````
M````````````````````````H)4E"`````"@E"4(``$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````!`0$!`0$!````````````
M````````````````````````````````````````````````````````````
M``````````````````````````$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!```!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0````$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$`````````
M````````````````````````````````````````````````````````````
M```````!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$`````````
M````````````````````````````````````````````````````````````
M``````````````````````````````$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`````````````````0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0````````$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$``````0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!````````````````````````````````````````````
M```````````````````````````````!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!```!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0```0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$```````````````````````````````````$!`0$!
M`0$!`0$!`0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!````````````````````
M```````````````````````````````````````````````````!`0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0```````0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````8``````````%Z4$P``7P(!@`8HP0(``P$!(@!'```
M`"````#XJ00(B@````0`````00X(A0)"#05.+A`D````0````(2J!`A1````
M!`````!!#@B%`D(-!4B#!(8#2BX0````.````&@```#8J@0(7P$```1$KR4(
M00X(A0)"#05&@P6&!(<#3BX0;RX422X03RX422X0`J8N!$@N$```)````*0`
M``"`L00(@0````1IKR4(00X(A0)"#05&@P6&!(<#5"X0`"P```#,````.*P$
M"$4#```$>:\E"$$."(4"0@T%1H,%A@2'`THN$&HN`$LN$````#@```#\````
M@*\$")H!```$X*\E"$$."(4"0@T%28,%A@2'`P*-+A`"D"X`5BX0:BX,4BX0
M12X`52X0`"`````X`0``'+$$"$0````$`````$$."(4"0@T%1X,#6RX0`"``
M``!<`0``T,8$"#$````$`````$$."(4"0@T%08,#6BX0`"0```"``0``*,<$
M"%0````$`````$$."(4"0@T%0H,$A@-4+A`````@````J`$```2R!`A5````
M!`````!!#@B%`D(-!42#`TLN$``D````S`$``*3)!`B!````!!BP)0A!#@B%
M`D(-!4:#!88$AP-4+A``+````/0!```HR@0(%`$```0HL"4(00X(A0)"#05&
M@P6&!(<#2RX0`G4N`%(N$```)````"0"```\RP0(A`$```0`````00X(A0)"
M#05&@P6&!(<#`KPN$"0```!,`@``P,P$"#8"```$`````$$."(4"0@T%1H,%
MA@2'`VTN$``D````=`(``/C.!`A)`0``!$RP)0A!#@B%`D(-!4:#!88$AP-.
M+A``)````)P"``!<L@0(!1(```1QL"4(00X(A0)"#05&@P6&!(<#32X0`"P`
M``#$`@``1-`$"!0!```$"+8E"$$."(4"0@T%1H,%A@2'`TLN$`)U+@!2+A``
M`"0```#T`@``6-$$"(0!```$`````$$."(4"0@T%1H,%A@2'`P*\+A`D````
M'`,``-S2!`@V`@``!`````!!#@B%`D(-!4:#!88$AP-M+A``)````$0#``!D
MQ`0(MP$```0LMB4(00X(A0)"#05&@P6&!(<#`D@N$!P```!L`P``',8$"&X`
M```$7K8E"$$."(4"0@T%9"X0)````(P#```4U00(9`````1JMB4(00X(A0)"
M#05&@P6&!(<#<2X0`"0```"T`P``>-4$"'`````$=K8E"$$."(4"0@T%1H,%
MA@2'`UXN$``D````W`,``.C5!`AD````!(*V)0A!#@B%`D(-!4:#!88$AP-Q
M+A``)`````0$``!,U@0(<`````2.MB4(00X(A0)"#05&@P6&!(<#7BX0`"0`
M```L!```!-<$"#L````$FK8E"$$."(4"0@T%0H,$A@-%+A`````<````5`0`
M`$#7!`@G````!`````!!#@B%`D(-!44N$"0```!T!```:-<$"#\````$JK8E
M"$$."(4"0@T%0H,$A@-%+A````!T````G`0``*C7!`@)!0``!`````!!#@B%
M`D(-!4F#!88$AP-C+A`";RX`6RX0`TH!+@!8+A`#!`$N!$@N$`)[+@A)+A!%
M+@1:+B!0+@1(+A!B+@1(+A!B+@1(+A!B+@1(+A!B+@1(+A!B+@1(+A!B+@14
M+A!2+B`@````%`4``+3<!`A$````!`````!!#@B%`D(-!4>#`ULN$``D````
M.`4``!C=!`AD````!-2V)0A!#@B%`D(-!4:#!88$AP-Q+A``)````&`%``!\
MW00(<`````3@MB4(00X(A0)"#05&@P6&!(<#9"X0`"0```"(!0``B/<$"#0`
M```$`````$$."(4"0@T%1(8#1H,$3"X0```@````L`4``!#>!`@@````!```
M``!!#@B%`D(-!42#`TLN$``@````U`4``##>!`@@````!`````!!#@B%`D(-
M!42#`TLN$``@````^`4``%#>!`@@````!`````!!#@B%`D(-!42#`TLN$``@
M````'`8``'#>!`@S````!.RV)0A!#@B%`D(-!42#`U`N$``@````0`8``*3>
M!`@S````!/BV)0A!#@B%`D(-!42#`U`N$``D````9`8``+SW!`C?````!```
M``!!#@B%`D(-!4:#!88$AP-K+A``)````(P&``#8W@0(*08```0$MR4(00X(
MA0)"#05)@P6&!(<#`D`N$"0```"T!@``!.4$""D&```$L[<E"$$."(4"0@T%
M28,%A@2'`P)`+A`D````W`8``##K!`@I!@``!&*X)0A!#@B%`D(-!4F#!88$
MAP,"0"X0)`````0'``!<\00(*08```01N24(00X(A0)"#05)@P6&!(<#`D`N
M$"0````L!P``G/@$"&0````$P+DE"$$."(4"0@T%1H,%A@2'`W$N$``D````
M5`<```#Y!`AP````!,RY)0A!#@B%`D(-!4:#!88$AP->+A``)````'P'``!P
M^00(9`````38N24(00X(A0)"#05&@P6&!(<#<2X0`"0```"D!P``U/D$"'``
M```$Y+DE"$$."(4"0@T%1H,%A@2'`UXN$``D````S`<``$3Z!`AD````!/"Y
M)0A!#@B%`D(-!4:#!88$AP-Q+A``)````/0'``"H^@0(<`````3\N24(00X(
MA0)"#05&@P6&!(<#7BX0`"0````<"```$)`&"#`````$`````$$."(4"0@T%
M0H,$A@-7+A`````L````1`@``$"0!@CV````!`BZ)0A!#@B%`D(-!4:#!88$
MAP-6+A`"12X(2BX0```P````=`@``#B1!@A2`0``!"NZ)0A!#@B%`D(-!4F#
M!88$AP-9+A`"1RX`;"X012X(2BX01````*@(``",D@8(_P(```10NB4(00X(
MA0)"#05&@P6&!(<#;RX08"X`5"X0`G(N`%`N$&4N"$HN$`)>+@A*+A`"OBX(
M2BX00````/`(``",E08(E@,```2FNB4(00X(A0)"#05)@P6&!(<#62X0`H4N
M(%$N$`*#+B`"@RX0`N\N`&(N$$4N"$HN$``D````-`D``!B;!@@$`0``!,RZ
M)0A!#@B%`D(-!4:#!88$AP-4+A``)````%P)```DF08(EP````0`````00X(
MA0)"#05C+B`"2RX07RX@`!P```"$"0``O)D&"!L````$`````$$."(4"0@T%
M42X@*````*0)``#8F08(M`````3JNB4(00X(A0)"#05&@P6&!(<#6RX@<"X0
M```<````T`D``(R:!@@E````!`:[)0A!#@B%`D(-!4XN$"````#P"0``M)H&
M"$0````$`````$$."(4"0@T%1X,#6RX0`"0````4"@``N*,&"%4````$%+LE
M"$$."(4"0@T%1H,%A@2'`TTN$``L````/`H``!"D!@A=````!"R[)0A!#@B%
M`D(-!4:#!88$AP--+A!:+@10+A`````D````;`H``'"D!@BW````!$2[)0A!
M#@B%`D(-!4:#!88$AP--+A``+````)0*```HI08(PP````1XNR4(00X(A0)"
M#05&@P6&!(<#32X0:RX$3RX0````)````,0*```$I@8(R0````2LNR4(00X(
MA0)"#05&@P6&!(<#32X0`"P```#L"@``T*8&"-,````$Z+LE"$$."(4"0@T%
M1H,%A@2'`TTN$&LN!$\N$````"0````<"P``I*<&",D````$)+PE"$$."(4"
M0@T%1H,%A@2'`TTN$``L````1`L``'"H!@C3````!&"\)0A!#@B%`D(-!4:#
M!88$AP--+A!K+@1/+A`````D````=`L``$2I!@C)````!)R\)0A!#@B%`D(-
M!4:#!88$AP--+A``+````)P+```0J@8(TP````38O"4(00X(A0)"#05&@P6&
M!(<#32X0:RX$3RX0````)````,P+``#DJ@8(R0````04O24(00X(A0)"#05&
M@P6&!(<#32X0`"P```#T"P``L*L&"-,````$4+TE"$$."(4"0@T%1H,%A@2'
M`TTN$&LN!$\N$````"0````D#```A*P&",D````$C+TE"$$."(4"0@T%1H,%
MA@2'`TTN$``D````3`P``!R<!@B:!P``!,B])0A!#@B%`D(-!4:#!88$AP-X
M+A``+````'0,``!0K08(TP````3LOB4(00X(A0)"#05&@P6&!(<#32X0:RX$
M3RX0`````````/__`2$7!=`!`#==M`$`R`$1``#B`06$`@"-`A^T`0"]`@70
M`0#__P$,'04``%H%>`!\!0``__\!8@E$``!<!?`"`)0!B@'$`P"B`@7R!`#7
M`@W$`P#\`@6D`P"$`P4``)0#!<0#`*@#$@``W@,%R`0`BP0%Q`,`N`0%I`,`
MY00%Q`,`D`4%P@,`P047Q`,`Z04%P`8`F08%\`(``/\`)0$:'20``%@%N`(!
MF0&Z`0``^P(%B@,`E0,%```!`````/C")0C__P$,'04``%H%>`!\!0``__\!
M#!T%``!:!7@`?`4``/\`(0$7%`4``"L%=`-:!0``B0$%D`$`FP$%```!``!]
M`````/__`2&.`04``*0!!=@!`.\!!0``_0$%P`(`I0(%P`(`Q`(%``#__P&1
M"Q8%Z!T`(P70'0`Z!=`=`$8%E1X`707P'0!J!=`=`'(%Z!T`AP$%F1X`EP$%
MJ!X`JP$%G1X`MP$%JAX`RP$%NAX`U0$%G1X`X`$%F1X`]0$%T!X`A0(%E!\`
MF0(%D!\`I0(%R!\`N0(%QA\`PP(%D!\`S@(%T!X`XP(%Q!\`\P(%PA\`AP,%
MGA\`DP,%FA\`IP,%F!\`L0,%GA\`O`,%Q!\`T0,%EA\`X0,%P!\`]0,%OA\`
M@00%O!\`E00%NA\`GP0%OA\`J@0%EA\`OP0%N!\`SP0%MA\`XP0%M!\`[P0%
MLA\`@P4%L!\`C04%M!\`F`4%N!\`K04%KA\`O04%K!\`T04%JA\`W04%J!\`
M\04%IA\`^P4%JA\`A@8%KA\`FP8%I!\`JP8%HA\`OP8%OB$`RP8%N2$`WP8%
MM"$`Z08%OB$`]`8%I!\`B0<%KR$`F0<%JB$`K0<%I2$`N0<%H"$`S0<%FR$`
MUP<%I2$`X@<%KR$`]P<%EB$`AP@%D2$`FP@%C"$`IP@%AR$`NP@%@B$`Q0@%
MC"$`T`@%EB$`Y0@%_2``]0@%^"``B0D%\R``E0D%[B``J0D%Z2``LPD%\R``
MO@D%_2``TPD%Y"``XPD%WR``]PD%VB``@PH%U2``EPH%T"``H0H%VB``K`H%
MY"``P0H%RR``T0H%QB``Y0H%P2``\0H%O"``A0L%MR``CPL%P2``F@L%RR``
MKPL%LB``OPL%K2``TPL%J"``WPL%HR``\PL%@"0`_0L%J"``B`P%LB``G0P%
M^R,`K0P%]B,`P0P%\2,`S0P%[",`X0P%YR,`ZPP%\2,`]@P%^R,`BPT%XB,`
MFPT%W2,`KPT%V",`NPT%TR,`SPT%SB,`V0T%V",`Y`T%XB,`^0T%R2,`B0X%
MQ",`G0X%OR,`J0X%NB,`O0X%M2,`QPX%OR,`T@X%R2,`YPX%L",`]PX%JR,`
MBP\%IB,`EP\%H2,`JP\%G",`M0\%IB,`P`\%L",`U0\%ER,`Y0\%DB,`^0\%
MC2,`A1`%B",`F1`%@R,`HQ`%C2,`KA`%ER,`PQ`%_B(`TQ`%^2(`YQ`%]"(`
M\Q`%[R(`AQ$%ZB(`D1$%]"(`G!$%_B(`L1$%Y2(`P1$%X"(`U1$%VR(`X1$%
MUB(`]1$%T2(`_Q$%VR(`BA(%Y2(`GQ(%S"(`KQ(%QR(`PQ(%PB(`SQ(%O2(`
MXQ(%N"(`[1(%PB(`^!(%S"(`C1,%LR(`G1,%KB(`L1,%J2(`O1,%I"(`T1,%
MGR(`VQ,%J2(`YA,%LR(`^Q,%FB(`BQ0%E2(`GQ0%D"(`JQ0%BR(`OQ0%AB(`
MR10%D"(`U!0%FB(`Z10%_R$`^103^B$`FA4%_R$`KQ4%]2$`OQ4%\"$`TQ4%
MZR$`WQ4%YB$`\Q4%X2$`_14%ZR$`B!8%]2$`G18%W"$`K18%UR$`P18%TB$`
MS18%S2$`X18%R"$`ZQ8%TB$`]A8%W"$`BQ<%PR$`FQ<%GB``KQ<%F2``NQ<%
MER``SQ<%DB``V1<%F2``Y!<%PR$`^1<%C2``B1@%BR``G1@%B2``J1@%AR``
MO1@%@B``QQ@%B2``TA@%C2``YQ@%_1\`]Q@%^Q\`BQD%^1\`EQD%]Q\`JQD%
M\A\`M1D%^1\`P!D%_1\`U1D%[1\`Y1D%ZQ\`^1D%Z1\`A1H%YQ\`F1H%XA\`
MHQH%Z1\`KAH%[1\`PQH%W1\`TQH%VQ\`YQH%V1\`\QH%UQ\`AQL%U1\`D1L%
MV1\`G!L%W1\`L1L%T!\`P1L%SA\`U1L%S!\`X1L%RA\`]1L%VQX`_QL%S!\`
MBAP%T!\`GQP%Z!T`KQP3G1X`T!P%Z!T`Y1P%T!X`]1P%D!\`B1T%H!\`E1T%
MFA\`J1T%VQX`LQT%H!\`OAT%T!X`XAT%``#6'@4```#_`"$!%Q0%```K!70#
M6@4``(D!!9`!`)L!!0```0``?0````#__P$N4:`!W`(`@`(%\@(`I0(%M0,`
MSP(%W`(`Y0(%K`,`[0(%``"+`P7<`@"P`P4``/__`0@G!64`:04``/__`0@Z
M!54`7P4``/__`0A&!6$`:P4``/__`0@Z!54`7P4``/__`0A&!6$`:P4``/__
M`0P*!0``%`4H`#8%``#__P$,"@4``!L%+``Z!0````#__P$(.@55`%\%``#_
M_P$(1@5A`&L%``#__P$(.@55`%\%``#__P$(1@5A`&L%``#__P$(%P4D`"X%
M``#__P$(%P4D`"X%``#__P&J`4P%\`,`806D`P!J!?0#`+D!!9@%`,(!!=0$
M`)L"!;<%`*D"!9D&`($#!9D)`+(#!:0$`.@#!0``C@0%E`8`L00%T`0`\@0%
ME`D`J@4%]`,`U04%WP4`[04%V`8`LP8%P`H`Z@8%U`0`G0=WMP4`G0@%M0L`
MV@@%\`,`[0@%H`D`J0D=MP4`XPD%Q0H`F0H%R@H`V`H%L`L`B0L%I`,`U@L%
MGPP`^@L%I`P`__\!J@%,!?`#`&$%I`,`:@7T`P"Y`068!0#"`074!`";`@6W
M!0"I`@69!@"!`P69"0"R`P6D!`#H`P4``(X$!90&`+$$!=`$`/($!90)`*H%
M!?0#`-4%!=\%`.T%!=@&`+,&!<`*`.H&!=0$`)T'=[<%`)T(!;4+`-H(!?`#
M`.T(!:`)`*D)';<%`.,)!<4*`)D*!<H*`-@*!;`+`(D+!:0#`-8+!9\,`/H+
M!:0,`/__`:H!3`7P`P!A!:0#`&H%]`,`N0$%F`4`P@$%U`0`FP(%MP4`J0(%
MF08`@0,%F0D`L@,%I`0`Z`,%``".!`64!@"Q!`70!`#R!`64"0"J!07T`P#5
M!07?!0#M!078!@"S!@7`"@#J!@74!`"=!W>W!0"="`6U"P#:"`7P`P#M"`6@
M"0"I"1VW!0#C"07%"@"9"@7*"@#8"@6P"P")"P6D`P#6"P6?#`#Z"P6D#`#_
M_P&J`4P%\`,`806D`P!J!?0#`+D!!9@%`,(!!=0$`)L"!;<%`*D"!9D&`($#
M!9D)`+(#!:0$`.@#!0``C@0%E`8`L00%T`0`\@0%E`D`J@4%]`,`U04%WP4`
M[04%V`8`LP8%P`H`Z@8%U`0`G0=WMP4`G0@%M0L`V@@%\`,`[0@%H`D`J0D=
MMP4`XPD%Q0H`F0H%R@H`V`H%L`L`B0L%I`,`U@L%GPP`^@L%I`P`__\!"#H%
M50!?!0``__\!"$8%80!K!0``__\!"#H%50!?!0``__\!"$8%80!K!0``__\!
M"#H%50!?!0``__\!"$8%80!K!0``__\!'Q\H``!?!;`!`&0/NP$`C0$%]`$`
MM@$%``#7`06P`0#__P$A)58``)@!!9H"`)T!#_@!`,T!!<X"`)4"!0``IP(%
MF@(`__\!4A+A`0``C@(%K`0`DP(/T`,`PP(%\04`]@(%J`0`^P(/\0,`J`,%
M^`4`[`,%``"-!`7J!0"^!`68!0##!`^?!0#S!`6H!`"_!07)!0#9!07C!0#_
M_P$B)9`%``#2!07,!@#7!0_7!@"'!@64!P#2!@4``/D&!<P&`/__`1H=!0``
M;P7``0"9`06W`0"[`1X``.(!!;<!`/__`1@D!40`5`4``&(%JP$`C0$%JP$`
MKP$%``#__P$($04<`"`%`````/\`$0$(%@4P`T<.``!_``!]`````````/\`
M$0$(%@4X`T\.``!_``!]`````````/\`+0$<%@5<`R<%0`=7!0``;06,`0V$
M`04``*P!!;$!`7\``'U_>P!]``!_?0!]``````#_`"T!'!8%:`,G!4@'8`4`
M`'D%F`$-D`$%``"X`06]`0%_``!]?WL`?0``?WT`?0``````_P`U`2(6!6`%
M)P5`"5@%``!Q!9`!#X@!!:P!`;4!!0``O@$%PP$#?P!_?0!]?WL`?0``?WT`
M?0``````_P`U`2(6!6@%)P5("6`%``!Y!9@!#Y`!!;0!`;T!!0``R`$%S0$#
M?P!_?0!]?WL`?0``?WT`?0``````_P`U`2(6!6`%)P5`"5@%``!Q!9`!#X@!
M!:P!`;4!!0``O@$%PP$#?P!_?0!]?WL`?0``?WT`?0``````_P`U`2(6!6@%
M)P5("6`%``!Y!9@!#Y`!!;0!`;T!!0``R`$%S0$#?P!_?0!]?WL`?0``?WT`
M?0``````_P`U`2(6!6`%)P5`"5@%``!Q!9`!#X@!!:P!`;4!!0``O@$%PP$#
M?P!_?0!]?WL`?0``?WT`?0``````_P`U`2(6!6@%)P5("6`%``!Y!9@!#Y`!
M!;0!`;T!!0``R`$%S0$#?P!_?0!]?WL`?0``?WT`?0``````_P`U`2(6!6`%
M)P5`"5@%``!Q!9`!#X@!!:P!`;4!!0``O@$%PP$#?P!_?0!]?WL`?0``?WT`
M?0``````_P`U`2(6!6@%)P5("6`%``!Y!9@!#Y`!!;0!`;T!!0``R`$%S0$#
M?P!_?0!]?WL`?0``?WT`?0``````_P`U`2(6!6`%)P5`"5@%``!Q!9`!#X@!
M!:P!`;4!!0``O@$%PP$#?P!_?0!]?WL`?0``?WT`?0``````_P"<`@&*`E@%
M\`$#:@7$#`..`07L"0.6`1KL"0/*`060#@/5`07$#`/K`06[#`&9`@4``+P"
M!<T,`\X"!;\*`_("!=P,`_X"&=P,`ZX#!:<.`[D#!;\*`^0#!0``B`0%\`$#
MF@0%_@H#O@0%]`P#R@09]`P#^@0%O@X#A04%_@H#R`4%T@P#V@4%O0L#_@4%
MC`T#B@89C`T#N@8%U0X#Q08%O0L#B`<%UPP#F@<%_`L#O@<%XPT#R@<9XPT#
M^@<%[`X#A0@%_`L#R`@%N@H#V@@%I`T#_@@%^PT#B@D9^PT#N@D%@P\#Q0D%
MI`T#BPH%F`H'SPH%W`H'C@L%FPL'S0L%V@L'C`P%F0P'M`T%P0T'?@``?0``
M?WT```!P_!@(``$``/\`-0$B%@5H!2<%2`E@!0``>068`0^0`06T`0&]`04`
M`,@!!<T!`W\`?WT`?7][`'T``']]`'T```````$````!`````0```,T````!
M````/@$```$```!K!0```0```'4%```!````K`4```P```!,GP0(#0```)"Y
M"`@$````*($$"`4```#`D`0(!@```/"%!`@*````&@@```L````0````%0``
M```````#````3,`E"`(```"P!```%````!$````7````G)H$"!$```!4F@0(
M$@```$@````3````"````/[__V\TF@0(____;P$```#P__]OVI@$"```````
M`````````````````````````````````````````````````````````/__
M__]@L00(C,8$"/C<!`CXF@8(`````/____]PL00(G,8$"`C=!`@(FP8(````
M```````HOR4(``````````!NGP0(?I\$"(Z?!`B>GP0(KI\$"+Z?!`C.GP0(
MWI\$".Z?!`C^GP0(#J`$"!Z@!`@NH`0(/J`$"$Z@!`A>H`0(;J`$"'Z@!`B.
MH`0(GJ`$"*Z@!`B^H`0(SJ`$"-Z@!`CNH`0(_J`$"`ZA!`@>H00(+J$$"#ZA
M!`A.H00(7J$$"&ZA!`A^H00(CJ$$")ZA!`BNH00(OJ$$",ZA!`C>H00([J$$
M"/ZA!`@.H@0('J($""ZB!`@^H@0(3J($"%ZB!`ANH@0(?J($"(ZB!`B>H@0(
MKJ($"+ZB!`C.H@0(WJ($".ZB!`C^H@0(#J,$"!ZC!`@NHP0(/J,$"$ZC!`A>
MHP0(;J,$"'ZC!`B.HP0(GJ,$"*ZC!`B^HP0(SJ,$"-ZC!`CNHP0(_J,$"`ZD
M!`@>I`0(+J0$"#ZD!`A.I`0(7J0$"&ZD!`A^I`0(CJ0$")ZD!`BNI`0(OJ0$
M",ZD!`C>I`0([J0$"/ZD!`@.I00('J4$""ZE!`@^I00(3J4$"%ZE!`ANI00(
M?J4$"(ZE!`B>I00(KJ4$"+ZE!`C.I00(WJ4$".ZE!`C^I00(#J8$"!ZF!`@N
MI@0(/J8$"$ZF!`A>I@0(;J8$"'ZF!`B.I@0(GJ8$"*ZF!`B^I@0(SJ8$"-ZF
M!`CNI@0(_J8$"`ZG!`@>IP0(+J<$"#ZG!`A.IP0(7J<$"&ZG!`A^IP0(CJ<$
M")ZG!`BNIP0(OJ<$",ZG!`C>IP0([J<$"/ZG!`@.J`0('J@$""ZH!`@^J`0(
M3J@$"%ZH!`ANJ`0(?J@$"(ZH!`B>J`0(KJ@$"+ZH!`@`````````````````
M`````$=#0SH@*$=.52D@8R`R+CDU+C0@,C`P,C`S,C`@6T9R965"4T1=``!'
M0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;
M1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'
M3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)3
M1%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N
M-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#
M0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&
M<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.
M52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$
M70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT
M+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#
M.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R
M965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5
M*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=
M``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N
M,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z
M("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E
M94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I
M(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T`
M`$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS
M(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@
M*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E
M0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@
M,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``
M1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@
M6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H
M1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"
M4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S
M+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'
M0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;
M1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'
M3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)3
M1%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N
M-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#
M0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&
M<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.
M52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$
M70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT
M+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#
M.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R
M965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5
M*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=
M``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N
M,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z
M("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E
M94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I
M(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T`
M`$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS
M(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@
M*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E
M0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@
M,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``
M1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@
M6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H
M1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"
M4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S
M+C0N,R!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'
M0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;
M1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'
M3E4I(#,N-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)3
M1%T``$=#0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N
M-"XS(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#
M0SH@*$=.52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&
M<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T``$=#0SH@*$=.
M52D@,RXT+C,@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XS(%M&<F5E0E-$
M70``1T-#.B`H1TY5*2`S+C0N,R!;1G)E94)31%T`"``````````!````,#$N
M,#$`````+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN8G-S`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F1A
M=&$`+F5H7V9R86UE`"YG8V-?97AC97!T7W1A8FQE`"YD>6YA;6EC`"YC=&]R
M<P`N9'1O<G,`+FIC<@`N9V]T`"YC;VUM96YT`"YN;W1E````````````````
M```````````````````````````````````````````+`````0````(```#T
M@`0(]````!D```````````````$`````````$P````<````"````$($$"!`!
M```8```````````````$`````````"$````%`````@```"B!!`@H`0``R`0`
M``0`````````!`````0````G````"P````(```#PA00(\`4``-`*```%````
M`0````0````0````+P````,````"````P)`$",`0```:"``````````````!
M`````````#<```#___]O`@```-J8!`C:&```6@$```0``````````@````(`
M``!$````_O__;P(````TF@0(-!H``"`````%`````0````0`````````4P``
M``D````"````5)H$"%0:``!(````!````!<````$````"````%P````)````
M`@```)R:!`B<&@``L`0```0````+````!`````@```!E`````0````8```!,
MGP0(3!\```L```````````````0`````````8`````$````&````6)\$"%@?
M``!P"0`````````````$````!````&L````!````!@```,BH!`C(*```R!`$
M````````````!`````````!Q`````0````8```"0N0@(D#D$``8`````````
M``````0`````````=P````$````"````H+D("*`Y!`"P>Q`````````````@
M`````````'\````!`````P```&!%&0A@M10`0%T,````````````(```````
M``"%`````0````(```"@HB4(H!(A`*0,``````````````0`````````CP``
M``$````"````1*\E"$0?(0#D#P`````````````$`````````*$````&````
M`P```"B_)0@H+R$`\`````4`````````!`````@```"J`````0````,````8
MP"4(&#`A`!@```````````````0`````````L0````$````#````,,`E"#`P
M(0`8```````````````$`````````+@````!`````P```$C`)0A(,"$`!```
M````````````!`````````"]`````0````,```!,P"4(3#`A`&0"````````
M``````0````$````5P````@````#````P,(E",`R(0!@]P`````````````@
M`````````,(````!``````````````#`,B$`B`L``````````````0``````
M``#+````!P``````````````2#XA`!0```````````````$``````````0``
M``,``````````````%P^(0#1```````````````!````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+W!L:6(O````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-#$W,S8S,#(Q`#`Q-#4T-0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M
M:6XO<&QI8B]C;61?;&]G:6YU<"YP:'``````````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-30V,C<`,3`T,3<S-C,P,C$`,#$W-3<Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B`@("!D:64H(E1H92!F:6QE(&-M9%]L;V=I;G5P+G!H<"!I<R!P87)T
M(&]F(%!L97-K(&1I<W1R:6)U=&EO;BX@270@8V%N;F]T(&)E(')U;B!O=71S
M:61E(&]F(%!L97-K(&5N=FER;VYM96YT+EQN(BD["B`@("!?7W!L97-K7VQO
M861E<E]P<F%G;6%?7R@G0B<I.PH_/@IVR(B+(.=/G3PHBGI+55WJ)>?.9Z<9
M[:0\P,'Z(B<G%Z@6.0WB?MOW0_IPLKON_`;*AUFL"Q8PNLMYIG)0&QME\4#^
M-3YR:!.IU0:M_S8)$U(KG9-VC`$`EY+`M94H&=5SLWI21Y/[65AR:VL:0[<K
MT8V?E&`8<!0$C/176V=?>*0[_93BT9U1S3-@.=FY1UN?*0PX<,YG6RP%-[5H
M\!+FJ@BQU.WN;`VJ-9B2C"A*B&K3+PTZG9R1DWOU^8$JD`VRQTQWU)G'/\27
M[IR$QP-8W86]>L0%(6K<"*?$MJZ^#7J'NBZCW2BQEJKZ@0VLI>;:+;J?4JM4
M\2CZS<O-+(ZZA1G+%K.ZNYXZ)L"N=:?G+76@?L!<#J_;I9*K]6FDC25_31!&
M0.#?C3WE-16PX<=H=\N[_.[NAK(8)5L\WO%,3PX$PYZ",PHK).\S>L_5C>I8
M8@QA"[\E,S0`L-)]/@+]Q+1&Q]#BV-I9[M*.,4A</CM+OV/2/L6`O$Z>@X8+
MG"PFX9_MU=&\"D7,TYHS9,_(EAM4L5MA'T]Y@>B,Z.N>'WY9*V68<)9;U@(T
M(?^"A<EU99:>C:5E]!MGUR.DE*ZH\Z;5_W_^8&''B0^5;SJ)^V,NE4W@3CA@
M?8.%='B,MYI(1?\$W=X3J*1MI&I=JZHTIWJ['V7672P?B6-C`K>Z%RO^E=J*
M-UQFDAAPA]V#62JK[9*2ZZU]YU<^8.HZ#]H=7_(DAV)!:1%^*;("'1$CM5\J
M+PF+1\!@YS/CHRE1K^EODH>OU:II.2AS%RU."6ZV6`U!R]YB^UPK"K=';F$`
MT@49>F4ZNS5]\A0LY/M1YD\EU;&HA'EYZ_I578TGI9=GD+@VG>`Z@M8&QCUG
M'/%>SF5^E@L"M9X"\B^I?"3Q;GR\`T+/9E1]OA-85-F'=]PN-:W?B(;16IZ?
M!5Y!I?-,P18Y:I#L!]C8HG`6=W-Q9$U_N^QN%R8=7SR`&"6JR/F-"\#VY=(P
MWQGO93H:,45>Q;)0"7?"7J(&9L9*T*KX@PMH2X7K50YT`F@=\;>K9U0-ESI&
MTM![`^?MU8]I&16@24-K*@5RR`$PX`DM9RFV5T^N,6N=DW0SN#^-<*G9W\)1
M_:E,KRE=5BF/CZIB$35-$##L*Y[RGY+?__7T$\*H=RY>-C+S!R^U1@K+=5(,
MWA:\POF7X$9A6]'+_NH5;L0W?(VA"5.K=)EU;SXP?G^AF?`^W0?B%HUWB=:P
M'X,.ER2-YV2QIRL2Y&BXVC9R?^>;00[A/C]]!VS6%[[(QJCUSR;+`:3X!:?L
M&@S-=>PFH7PY^!YIT?42&.5HPI(L'LN02ZX8__6)M0.GI3!IU/)-:DK@&+?Q
M.?"/TZ8K?+]:R=_PA>U1C3]EU:VY\M\R"6V@XN]'@%V0*7FV@(6YC%OW.`@Z
M/=H=2-923*JK?CK=<-0ZW/N\7TW0$F<B,4,*E8,K^696L3"]62JI"/$^J7SR
MZW\.D<`%B*ZQJ(1>ZDT%C,#.\?*F0K]M2`Y&YW(%R=RN+BZV-*E98V^KG3F8
M$L#:*4OM,R[X,ZN][0UXY\86*H20NJ$(5UQ:VS.-"JX)'!#3IU3JK$8G^.D/
M2L67&^R(.]S"<^9&D=GCNX\%.;H,P5"(J4B$:<^P\W6-<2@W$V.N\5JKB-L4
M!7-Q23.%X\Q63D'TD^I99LK#^)^S/K?V?YKJST[`8*R9I^RI0E3TD[K&J1;F
M?W3Y\.4Z:MZI=\"JX@2\1'E"<^L8[K<]3S9/=:U(Y3%2@*EBA6/Q`@]]GFK!
M7@B-%0\HGXQ0I&`N'L)<'_"?'=QX2NVAJ@1<6B-V%2$X0\;^^($`A3E?]IE7
MM;YUO4TE#3[PH]V._^O7?-$4!GV")Y#)OCL8]O:U3J?3NS!LD91`7@Q6^[SE
M%-JY#!V47:!_9TUM=+$G\4?2Y4_N;[.DA?FPU*_JW+C3[']B#`\VMG*\A?96
M.((]ZH"UT[P)VOHY8:RJ40.Y:A(+</?J5E>FHH"5!4/-*KG`VP^0DT[&;=>V
M2TP%A]V8[6\/E?670(NV0RM<^+11.)O[4>\MR>(CTIH.8Y2,(=MI:6Z1ZM3_
MAZ%4:<&/XH-Y,D=@!?&J\Q5CP<,62?:NJ;H>&)JLCXGU29U,&9@R]HXQ&!`F
MA5''1^4S'S2/G@D=F9K^)EW+J/^XK'99`SOC%=;ON7"XY*_1:0]:$M:;T%UE
M!=E;+6_XE_$IK$Z9*Y=L%P#)1\6CV!^?VRX$N]]D?=OE^I=6$V=0-_EY%"2H
M82!NSG%DAE(R'CZ+93U<C2B=*E&]854SGO_WO5\:!0\4MZS.*PE)_U)N9)W7
MP)W_,Y>7@&G4Q6?7-+R"CQ^Q3+7O*=E"]:,+%_]E3Q9QP`+1IU"(PD^#89:*
M]U,`FMC5[@N/*1P;#@I#J.ZY3K1WY9W"K%`#_+PPE8L-75ME6_H^<!TN6Y_Y
M;]1ZH[6-[9+70LA>_!%!&5U#`*F8-<F^T=37G65,`#&[1)[E0;&:$TJ2`-N>
M.WBN:^T3+ZFN8Y*$4#B(]-JS:V6,KUVHD2^F?!AD-:8,F`*^."(N*H\U:][8
MDKZ]U[YMQ@CUY)I^6MHUZ=_TDM?6S18J_H"S>"D/K<T6I5],'3Z7UN\*8*X.
M%J!#12O68CQ/XX7K-X$^I,-W%I0O'[:3``.IA4UP0MS[I.&FE0HQS9'*5IXP
M>67%'FQ39\HX/N9MWT\+?E66<EXAZ_2'<M#!T.""D08ZAO6IULE&CQRE+,,L
M%#EF><[>KP9S=^35"8>U9U.)<;)])#3;<\(R^+4UD,##IATIRNOLI2(TCV&2
M"9M).O&-V4?8'KN'/.%=]_-!LQH>)L+1O)\..Q'V%'#"EZG5\ZWG0BTQP*RF
MU_N7K(&1[VJ[0D3?-RVSGH)7&"268-5RP*L%A5<ANV6"?63V?)8<1ZFE/<>,
MJIIH)U$E#NA>1/_]QQW)'&0A.+:Y10D.^UK8C[ZG*74/)]1F56J?K@_:Q_<\
MWG$1I#V'*L3>)J2#]EG&.W%/*@8B5&H'KV&F)7#$?TL_FRL+`0Q5W+Z+DP%9
M79,S_#BBXHOT_<]]5'/1L#I$?FR4I+UJDO-?P>D\H:$Z($;E,WRBKCJ]N0%-
M?QQT^R2P'*?$7L$]/D`K"6_V>#LX1MP/NB>*_(V5SCQE\5B#"V>%![BR>R12
M![FMS?&_.?&@.](0`D$Y&!<;.26FFNI:_RO0$_G/%T5\)JCTPQUBPL%`5`3O
MXRHIJ]AWP@#_"99,JM[!1`@W4`2^V5OX)&PT-=?E`DT?DI<N_6XI<'^?TI;1
M_?2-6I=Y>%>+!VFK()6D!5RB3B?#A&//H>)3HOGU:ADGPB.5S<@><&LTTE39
M>.^,1"@VBC"VH$9<*2K^"XYB76N1$36HUS332N5I5KS7?JNW)5US/HB*L\\S
MB&55J23R1/:&UI&\;C2>-[JC^LWQN84&#^",PJ>.]GX12I3(-/28JP9UZ2&"
MV%&;]1HOF<\6,-78:OEO?%?B0<YW^9BG,UUN5Y.,L-S6VC:R'4U(-;5<P,+<
MHA3>:!735;8"D"@$M9)=WKX^U\JKR?WY@N9GR`P4[4F0R_&6L2::\(+'"SP;
M:UJ>A%##'?V*M+/*4D&LIM\CG<34]6G11Q>*3JQG"4/1DLE`%@G@J&P7,B9G
M=\50E`F9R"2I:O%8$^>WP#_RS;+"0[.G;<CC6"D%-18PBJ>"%Y$"IP`-]TWZ
MV]/E$+-R)J8URM:*[JZ.B5)F03DKM=8FP5[H:BW'+*=KCXN#R)*M;SQ*%WF6
M#%>"3?(@<3:DAAFU5/CD!5ZK272-[`XT5CCL+2;UNU&GEY`%N^).W.9)'BA.
M'K;D8P9A;NN'MNJS5*KKQ#DGS+L&1-30/1LL).@7L^CZH,2?>?R?O@0NP?'I
MFTX7"S\7I\-8-N#`[@I59:XNY0PB,4RF7W^3@L^[BD]97$!W]8&L=FJW)W#D
ME*CGIG:JG/T*:SI]%^'1IHN-!AL@#Q_TOD\[GGU=6P3HG?J3$=-7QR3]HJ4@
MJXTC0]$=;9$>DD:&4-!7[`[QV!%-C!<(!T>!6I-J[_2/?H0_K#-4F&1YIOF;
M7A`7YNA#'-<37?#(PVD-!@R:TM<=PE\?]P!?M6A@=F5,B:W8%^-8/%WV^W+U
M#?VX6>:@?!SLUM4QL3L:$O7R4(YEO7:Q(J(X+%_$`I*34GN>"1F@SAU)()*Q
M`PVWX\B<#C[I%E[CFO*=S6^S55O`MB6G/SR"K@R='8[P=>*Q74<:$\B1$U<M
MT=%G>!N3#%V[M,O0'Z2@UL+CX!'IZ4+`<Y%S"U3:60DXF2J"C<R;N\9A4U92
M_K*_+RO-A2JD6#=I8)F]//QPA$MK8N)NC>#'4Q7QCI([0.>:>I2@$SU2['WF
M')Q:Y`[UPS@(3L]0=1SK<3NN_%]Z<5EPF&KJ*RUEG"6Z%)>E@[,M8P"BN*QY
M'.O]YRX;*)ZE;5@Y&U3XA'7*1E$-O]X0GN.5.5B;&F=%I"+,O1-W&,7$](77
M@:.JK'*3;1IVQ[SZ`0B.@/$;!-.85'>0Z;<]-<#:65P_@ZWA!CJY-.]D,X)J
MQU?6_N5,MMHY1,*_*2R]/T^JC;Y]/3TS*LR\4JC$/OK!IFPYWA`^I,2,!L(.
MEXXE)LZTR`H^.Z6M:4$3291=Q.#AX_!S%$"6P+>OSDAAL2H(57^#WAK0U#C0
MQ"QGK)-R9@)^7P(NQ'>+T\0@W;.()_DM"WP=%R0FSRZA8%Y6'*2]DE&6*H-Q
M@,82DY&.S7)'Q4SC%682*?U-OYO]WGQ"T'*T.A&]JQTT>TT-0`XB-YR;<#1K
M)#B1R#<MQ06.F$CIALT1[PO#C>C-*RM0P?8&GRN-VM?6*[&[:V$EA31/&]OC
M2HZ>#>4*>J'O(;6[ANQ&AB`<_(PG<['AD^6?40M7$\V!/08P0E!-#G=W9\4!
MNL.O"2*J%\G$I5][U^7->-;*2OS>=Y1:)W'43=D$OO*.BEX=[)MGF.)B=M<?
M`U-LZ^$`&-?E&)'G`A1[1'4&'L`Z+*W!;LQA$VL08B0"Q3;*FURF#1(H+J/`
MC.@59>H9%WMMB"/8V";)^I>74W*N:;@\XF7FY6:0-E816VY7N>1QNZ2ZW`]V
MZ#QY-W3+120_*>G0A\Q1(^.8_"A(LD_L<:X6VJ5-]WB,!]Y-`*0.4JSHW3L)
M_2:HM#O&]-V=XEMJ*T<7]?TO;[M,LM=;^/Z3)YQ+W<^[NY\FITXR]HVM3#'0
M$6\HI?<IC(ZEO=']TV.HC1_*("X+Y\HYQ?K!B=CGC$:B(&'UG(=@2O5OOBEH
M\,N#.I+T^!IEWOMB.5(EY5829G5?T;;R$CT>#;A8"PN=?P$-XHO]I0+%#[Y;
M-U)@%L@UN)Z>8CE,^EQY<-]\>JF@#<09$/-&>;EUZ*C;F#SKIO$.R+5-[PGQ
MGY0^);(05Y;M)"YEL"/>]HPW((WE';6?WB8PXQ*^+G1_T_S6%^UW,IT.:,AO
MZD$IR6CA.D8C#5^?=#[HN0`U*P&HFFQOZPO0&)VD[C^HS4W!#OQ"@L//#4H@
M)#FWTNEC1[N5LGELU<+VX^]'9C8_4C46.ZCP;L.4;]>B"7JRRGIW.Y[G<`[7
M#_MX*N6,&?+=![P4K%<DY/?FE/8&@P&S*@Z^MN]IQKO.UBH/!6W#:JOGWT6&
MSN@D#)>W-"FECII#X?N$OLXN68/!,D'*U=L=X?W,4;OM'5(`T5A4=TA0O^2R
M#5OX3P>HS&11.EP&G;MU)LI94GY$3#X^*AO=Y!$?[C4]^J2Z</L!2PL71O4B
MNW]66WM,[U8>I(F/_>(/U[=D0@BL-G\>WJQ'-VTJ!5FVNIM/>BK:/UK=0PE[
MWV=GD0-CJ9Y(6+:+288Y`U$WF%_.?W\YU]/HRF5="U3<[2A;YY"6%&IJ_&R0
M7W-"C:X/MNFZ/SR\$R"%MJNFS\S3ZE6PG+!WZ`O_'Y\HVF@*\:9!PMN5MA]L
M1R[,PI'SOWSWE5(-"K]FQ%*EU21W7`3N\R8%*RGDD%B:-J.8*'?C2J%S77$7
M&^6<O^93M!JY!,3(8N)Z)D.?VC9-Z!/1+XQ*9L7K^]_!/1R>LV_%7:-O?\XR
M--G`^\J'>>EYQ`O-9IB'X!]79V9F`9T)<F,'OK-=]0*B+53/6N,(G?U4_G2"
MN=C:P#;$&37&W34?>[C;\DK84ST%R3</=?NK8$+9%7DS_'V/5KL;*QO[6Z:<
ME_$>VIHZ9K<;3XN8\%3W$I(?LWG3[HZH]CE^_JF&5G$1(0'.[".1UCH8?-VR
MU)KLI#3&_I&PG,[B304-'N^B9FP&C.HN3\%VK4E]_@(>0C"^Q7?W#._SO/I6
MZ)/"M]RMM"P.W85THO!#@=2FD.$-@U6_^MP'BV'ROYKNSY+%]@/=U9QCND"F
MZ!`T<T>4/7LUH)KU0'E+)TF:TN#M]A9JSK^B0K5\)&[]2M^82Q[PC9R=0HWD
MGDZE\BU*/<ZYD*K&$!8T)P>4F)[1-:^0,<7Y5?\LCNI%PRKF;LDF/-ERQSRU
MEC-EN7$W^2`M*9@O9&,P$V?T8]D?XZ#((:;3C^PZ9IST8]P(A=C?NNI2P7]R
M;+-TEMS?*0B>N8U.^2+AAK3$/"3*3,<_N3LEL+G(QJ8BSM!X7`"O=;68(R,'
M$7_%UW_'Q>%6@NOB39BE+=""V12-GBU4JP+:O4K:!RX(I6#MFIXC9Q4`D\>`
M*3=J6@>K]BB_Z]4)^<27K31]JC__R4O^$9ND>ZP(S"KX@IK'%;3:#S4S5_SE
M'-A,7+!Z)$C^,V`*.(T`8>0/+WLR&[$*%'F*X+=LD$LK?R\%4HR0Q<KI/40.
MHL1RE*KY;G[MQ(F049%UA"V./@&8QY$V[$H0+)<01')N85&9_%>:])=W'E"G
M3S<11:POD#4^"L-T\N]6B0ZDPDLM%8/:CZ[5::WUIA7-V1Q>LZ)'\F(08#-P
M9YOV*76_WZ\HS??)PU1GZ_:A\3/\GX^8C)GNVT)M_#6:/!H@V48\ELP0TMF?
M-)M!0M4-S?NM5.9:07D3GZ#9B:*'A\F"=A_^M/UKNOR.:][JD!9[8H;?)8\U
M9"-5!*-/6W?)^C:X^%TFP!;2W+4M[61?IL6U\`;:(NL&K-^=JETW1ARN_;R5
M\Z\.5+F0^3S8AC,P@"787IXEC'^&AT2J20T<=HT:JI;U?-+H=^+^Q0!%\B6.
M7,EVNIW^@6.TS`H[J`1:VM*3E61FUQPOJ7(2WJ$HHWSMQEZ'V/8%%W'K>834
M_\F'TXL8*AM&$LM@)(OL^49&;=S>=$5=-+3ZVEOCYAXU.N44M?:5I<@Z6W(`
M\:H3W?TS:'!ZB3YIC2>B-T:&'@_'C(%$HNNJW?@A((2@EULF5>5`YQ4/:.*6
MNJT_\?".2Y.2794@":NVJ9";L>1$%$^EXVL(H5M3<P`08>C!*Y%]UGOER#1/
MW/PG0_I<;HR"L%MD>-:LT@PH0&2>XH:6;G&)4,!GIUL;TYDPJBIYTUN)T6DN
M:_N)K/NY@[`(CVA;%'EL$Z].2ZL?^6#@.0'T6-0=KT'8HU3S8]Z&LMY?RY?Z
MD'9MYD#/I1"?06$$BZ<I$<>=-7(:,\:?XX+F:Z\B:]1$:*R=XFCPQ^TLQ1R,
M/Q>"!0K8]N"9C?./21HB9M4MI$Y*\[1-.AR:T.+"H`UM7(?M4$Y6R%9QX;?]
M"\B]E##R:<WAV4S\TC?^;,'9K[:/1F>`%0[VWW<"J\B-LC9![6$(_=W!A0S"
M)&2C2"[N)$8?-S_<)GESDX:5WUNZ*19@&&3]VS,78!;[-CZS95##8Y3O0X_7
MD[*_W,I@/Z(-GJSV!/\S_D&)]U".>)@VM1KIC\[F6F!M7I2]UH)OW#CZS'3E
M%7+I]?5IM1=/OF^)FV#(QG`V>Z`821C'UWFPP&CYVK0F);X2CV_4N7%P@ZR$
M7+``0U>FSJ#>;-:!EPX$R:ZL4]@1OI&G8MUF&#XD"1O9SJE]DZ9(TG3`R9EC
M>VYF8UQ--CPR1ISBK58/257U]SA$EY/XBB<-65=WSZHV1B3UW&S!H$D++=BW
M0J;IA@T;H]G0004W\F.(D1BGGOY$`?PX2EXR$LQ\4IM>&$)4/-:95_^=`@87
M\A.#'$N7P=,((OCW##$(N5Z]U;K)>\RT\QX0QAKS5//=3+GZ(%5Y!&M#E81<
M>9PALM:"*$V/"W?HL6,X_G2T`E"YA1=5R[.@4R;F@X:S!^5+X.?2C`KV<=I4
MW(E4C\G9X1<^ET`VN+QMSN:;5.^&=YYB$(%USXDZ`5T13;@TW5FR>*C$AF'R
M`BN"RH13:7EJNA&SE7?R7`51"5OZ_,Q89W0\T7L'.986W#[<O&,G4P.SG0E"
MK#"3O_M5@1[0L<7._=DZN=CA(NQOX/C^<TSWJ?=8Z%#]X<Z=5&L`GJDE\$K?
M1\\=C8T%8C]5+"'.]O5$J[F-#R[%@_9+61OO/#0C/<KG+7/9/EY=Y597=T>9
MZI`^QO2*URFA]_@*T4B37+I:1KI>TJJV8^Z$S=!M2B+S4E9H%N-=8`:+A'!!
MF`7^G@(XM@9;.<C#1!K9$!#\ZH"#P//B,C,=>\YO9#C^2&;[FWT,`%V0V]@Q
M[)^JTN;!(;A)W\N=H@0XK[XB],[\I.B?\K-_@XGP]WLPB&C)7,##U83]*^["
MNS]N&&DM$K3ZF[SIJPKO&&JUMPOLCV+&UVSJ-[M7SEBB_X6L5TTVQQT)<)F-
M,G/G6K)HLB^U5]&F#\HDI^<,QT<V+68]G767$A;O]:V7M=A'6=D8CN$PBLN(
MJ]CM$&05J&":4234*TAAEJE/CM3[A8+;*)YL.-B&@%@=[$__))^AM?^AQLFL
M8>2)[O=W\LD^N9")#<67_@;?PC-`HE+F-)%O"BL0%3,MST8`,FOU,%#EH4Z3
MKEQ)QZP1[L9G(4;D2V;Y'R'KH0<,+H1M$]23!%98-Q[8//"%E?/6R:FA`6O+
M"_;X?@KZ7:OPC=&VA`',Q"!-&=#JR(*5=<=MCHI"3KNA#T/R39)E*8^7N7_(
MGB\VUN]]LB?C/HC7NH*]H5%0^&#@I#T@NV:?VO&3K(<.>X.!BPF8-9<I2(0P
M.4>0MM:D@3F)4Q("+913O[2[D`[#3[5"V*(2K>/KB+Z36_(3/MT6&J5W7Q-I
MZHF^N==:$:(&U[R@5D4DD,<BZTA=P$\(M8<VY>RZAO@V=#+:P%6LS1SC6*7D
M?M4R$"&-=]$(BNF1;UU)>%>91Z@ZBT\(%#FS8V8'N69O%E)C,>]SSC_1\2T.
M,]9.LA(8D.3G<.L5S3_`3$H%$2R7D;IF3!,4I4L)G\$^GY4YGI-[>+WM04"V
M;@T8%,J0'5[H-W%;"#P<2YP6?Y^UC4$\S#/>:;E*G;3U3N'1J2L9X^K'HF>5
MRNQXXB6MI#='Z",1190BSYQP#!(M=M[[@?L2&L&QC6%8/\;JH^DTZ`.;..+C
MX&1!>)![_=Y^2(V[357C>Q^#WL+WP>IP`\(RYW7)K.[FIQQGA!>9$0-&5O+J
M.$FRPPS$'D6161;*>AJ['O'+,=,(W!A:*&E\@W,2HF-+N$RA.W.7])R+IZW2
M,P3<SAUQ:BB`OK!Y`L;V)0;\5H2'D,BR_(`>?[\<JQG9F2LN*OSH![F.L,,U
MMT"T[H^WIJQ+\!H<.")#/")V*@AQ$P@Q)/PZ_[OS%?B^^%`+X=V+IP6SE'/2
M45*K>`5)J+B=\9Q/=%F<+E3(OU/8=\3]A_B7RP?T;M'UVF<Q,5"CF&GZVV.0
M8W?W-8I,JL\C6<#K;$]`Q&3*'W)\4Q[XC=W%CF$OA)`WBB7/C+Y?3<.IV1:A
MVUU-XKU^C*DP8]FC^6P2N6F52,[KC<+7,S#ZUIL%EXWDO656X?H+O9H5A4E&
M6J!*^\$&H47]1D/+-.XSCBK0EI_-I,1Z@G;:N#B-2-?V#>$W#N;TQM"Z.8<\
MZW]D@>>0&=-H)?0/C7#Y,JPC$__(:R;>3^/H!ZR5:GPTX[+55N$]0;B84I,F
MNI_<0Y&X^.)TDXPDLW).(%W)9O>H]4]]9X;!%>44BC:%47VRM\[Q<W+ZBPPH
M<F@(N(26YB3O'-LB[__U`&5Z;$63P*BN93"QUP$;@^GC/O>S2/U]4SA`Q0"!
M%ZBP0N\!()$_I7'S7R9;)\HPOA8\W!`4X(D$"HS%F-)+!4T?=JF&])#Q/)L"
M65+U.H/STJ@D`]UE7"^.L3[V;P@108LT!K'4/`GVP-J2'H@^/3/0C&'S/A$F
MB\QN7@`5!FS';)_J=YM_H90]\IFT;]#D!*_[UV4/9C?R.+K^U*&[E)SY&U-W
M+.&5M4]8)\J\>'2,TWD']FEXP+]X;K)TTV*52(32:QH5(.]#\PM>,FH)JR%>
M/P\<(Z0Y#B<G5$\+W%"%?!$W5C,C[9W/%0;TG;$=W%8DN>;3#>2[@0-8/B12
M%;$8M$@713">'65'[5F*Z&7(:M2D='+YLH$&EHZ,3;'(ZB-Z'8,EXHI?ST7F
MM3[!>RTC@UV1W0108J*IS(`PQ#+0BO@E^R6^T3;!\,WD\ME@<G)N1E$==M27
M[,5#1R`>0Q-[IMOVM.*G?H_/.!S8IE3[-*OU(*@N%D43^=#.AS]$:I59?JE?
MV]T*;J>3'AV7--%S@.'A)F;[\("6USA'CE<,+4*ZX`?84EY;0-(649>&@K56
M=-*L+QXCZ:S?`RLNTC:H.+K/,1++63>RA-R1L]Y.A^7%6_><$3TO):1]%6=,
M`8%PJTVAK'_.KFU#^0LG8TW8FQHAXZ+OS:<F&(%W67R4K(%`)ZW<@(YV!NR9
M3FRC<%L<["^]YFEFBP.0_B?QLG?WT^=P]6WZ&9*?<X5)&/;\?04?:B8%Q14M
MHF3A#+>UPO6;S^.->W>98W(PAK.D>K-YS7I>,PYG_':PXC(C*10;)7.)9)4@
M]9UJ/%(7_@V&:"96WXM`<2*DP+S9GOALD]PX3D/`\9M1P#XIRHT%('\15JJL
M)X33H]F]F&SLT'/M$\GF22RZ[//<94-M8/EA!^$/VZ?V`_-UJ>?)D9IF?>1I
MN!"<A.1#;10WP?8\9VGIN%JKEE^;U\*/SWU3.Q$3$&^A3,>F^LB^APM#:P=1
M#>$Z,1^M85ZN;(F[OK^.&F(.I(+<<S3]K@NH00E"\OX-4M3\E/B#)WW!A;_.
M#4@!J[7::O<.GOHJ>A'9;.,#:2%.(O/2&35B.UA$3W*6)\6W);Y`U[X.<W4T
MP0VM8*_%XZ1I%UETT&#;90<0%VPA_F)VBU=M<0\,1N5;QLA*&,:%^D$)_6<3
MQX0KXZX#PS9:VU*SWE$-',IB&4Q<6#83E*0[J;.,N6-C5H)PN-2\S!^8\2`]
MN3J*JU7$0W2A(P,4%P+4,,>(`A.PCYB9V`AFV!_?D\8QP^*BH%-?NM[D5T)/
M^!\+[7)B?28F\NCPSQUSQ7TF*WM_(MA_M2=F,3@J4,.*;11F1JD<3%'4#\K>
MD`/3C>MR$:/BZ2U.[:MB;FOE('!;;4X^T=7Q_P#N1I9UQ1&\A+2"5]HWJ\5<
M&KIE,-LS,T?)OX*76^3I:SM^(>]/:;NG*5%ML@ARDS8=J?9!*$21LF@RC="T
MG[-S,\@WM%S^R?18O,8K9CN)O=;5819"'+^/S6IS<D(KD6O06PX<F]'5S]1-
M<<495A0CJ<*?K3)W%IW8/^G$S10O&.ZC_X5!J`&BDI'`'=\`D+4\*QM&+<_<
M=.KN+@F'TO+;7[Y@XV6,41X'#03P)35&E_]-`^N23SIQ=<+DIU"'C$MX7HRT
M:UI8,R+4>_$16$RUZXFLYL-(G1.5-<\Z`#.*T$L\R)=[[J1-=S\N4/WV'O@T
M+";/T3*%KC(XRR<67US($0LIH#6H^-MI"Q0S.NVJBVL?#NUUO9%IJ'/"@(WU
M2,[J%WGY8BQH$6OIV1ZLP/KQ,5J1Z#W/H8@=@?T#E,Y/@C_]5!JTA7XRVP5T
M\,9+^P"4/A"$8)HT\G4<?>5S=&#=S'N$>LJ];5?-@NQ&A?@>)$D@,X*7N4`Q
MUPXKL8?)G=Z0*W",P.P,""#Z^$+R1K=W)E&0NVGP>MA]F$U&K`EJ-VN3JB2R
MPS"SW,^Y"`*4S5VP64N"6.3>QBP;*P;K6\S?1<+;998-MM8E'?&P]D]C)L$.
M'4S;>@FW.UZOO73%J.'!D<U?=[S"QB4W#OA6"(885)*\Q8*$`),+Y_@<L5ZO
MZU88RG%ZI:V<FW-O)T9619.,4\BH:;@E&FG2EP`1ZB%"9:AT#Z6_!+J4?Z%1
M\=@)-'.`TP@H6RAP5.9OVI)<&1X77>X4@C]+VJ5Z&!Z*J*Q/XHX68V>5H'--
M6O>J1A8[`64PWQF(K-%:U@&3G6TFI23/W@-O(:"QLH7BL(:<%:P^6@G"%H2<
MW@9Y`+%4X?<FPR-?W>Q&.U[F`-2008XC8B,XJA%/V`\-XAI/\X'Y^!]V6Q!?
M^\M^&$4]3QD_^9MD+EJ%OFU0$2:?DPK0$84'L3TUN`^2:".N?:_-`-H?4?.>
M^BI\$/1^FWDJ.&-X`%F4\7S[?32"7<#]@R+#.1EBH2G`Q<^*`&9]&`#'D!(Y
M:/L<^*%EP0'>NVZO]`V+,^3%OV]1=NOG0K"%:N27RRKPN[XW8>"5-(]`2[_L
M9;#4Z[1IH8P#&==';HU<*/%:>2F`^KV<8Z0\GG,=A1:U#N?#26<BGI].2G8"
M"-'MGZL+3ARNFZ+LSYRT=$K\O$\3XKK&*,S;7<6D_KH$/C7`]8%7A@H.)I@W
M_88A[H42NXEH`;77U+K%G>.(*N4@:TGO?@^85M;\P\E2\NGH6PO5%W[\J1A1
MG_F=P`^&8ULZ=#PT8/+2Y5SX'=7J(YA-XK^7D1"Z]H71E>A+O(;1_@=Q!E*4
MHIX<.K>KX#8MP,:)VI0WHVB3(_.XX73FJ.@UJH=`*Z$*K/K$"F4*@3VAKR_K
M<1'Q&SW@$>Z&_[:Z>Q,.:&)BJ.,RP$25ND\&%)U/"5UP^^AK:J61=1O[CZS^
M:)M@KPV<ISET*M*SGBT<J253L!0KS+9F@=ZS"CHE3MOX)"$B<PN:.0EA8_$`
MO>Z>9FRUV,CXPF-$CHY3@=SD=DN\MA6H(+&-MK2=E,S#Y$"/N/ZH=*>F/7\O
M@+.J9Y@//ET39+[D&:C"`,M':56DUU'7LXUX&=FK/X5,(MTSB7U.5<M*F\N3
M03N6/?%9]7S.ZYBZM"QX["%CC3M?&4+"Z'B;!>%C"].O(2C669RS=Q/A^_K.
M]H+'^,1UF5GL.'0'*Z]/:"3T.L+`943CW*L.R.AI@P8:600>'IC(`M7%'GO(
M'HK+D.^IDG6=ETK0"DG^_KBOR],(U$I\(J4#KWI=(U0@7G`8-Y5I1"1Y*4/B
MS/05\7A!G2@";R29R+OID8P_U1X5)>1:2SXG9_[7[MOXA15BXNKR,8]'/\UM
M<84&K-S+H'!6#@X7\++G/:Z]AL2"A^1\?4%_Q]RC@@/@:SFXL,VO'#_D$W&S
M*#8(1MK&B>5H=,7VC-4NCBU@8_4>10Q>%:SX4P8>=SY(%I(M0['+3'\#:>PR
M9+YQ4#P,B)<F]+G9X1L_7IBO*&G9(E_#9#J-8RYD9"R>65E4!>X-VY34L;JT
M&LIBR'C$!TKMG)Q]V"?Q/KE!7GK<?DS3WF^&.XU.GGC"BD-XI"(71W9RM92B
M19.D,-&/)E\=D3X=V!.6.UH$A>5=/$/AQ1(4F`A.%M&:^_7R^#</&5A*>>H&
MI=?8CI;-RDG2WQRK'DV+VWH]T04\!UF\EIB-7XD4,"S,K\JZ!@^')`I@G?W'
M;%$I_5V%0:P7?K>+'I@28NOD5LZ<Z[NT7,:VPS#G3Q]1[G,$$`TB`@./E#1+
ME,8,.W<'=2*;A8'INWI2N:%H39.3D5ARJ$<7&N>WL#*_:5,-VT'2)-%QYEQ$
M$C!8(KC!,@0A)%,VU<#LR+"M*YP9LH,]+[@`#VN+[1>/(B5!O6+X(RYV@Y3Q
M0@?.+77>KV<\>C\N5L583V=.@9%\/70%O(&(I`)'"@&Q3>^S1<OG_]5*:_\W
M+P&#1)YF`.#>]F71)'\KEQ&TKS1?_MG\]NQ)0.9DUK"XDF11T<VQJVQDXH^6
M(1(B7-/?C*GQH`%0,KL)$(/YH0U_<F>4SZJ&X=@BD^)`X"*`Y"KBS?P\$MRV
M@0>S\`]WKSE?DCA9S>MT=DF2'IN[#TIW38DTVK=`G`F4=ECQ`;:V]&\D"/>5
M_3K3/4/7(LEBC^^0<;:':VM1$0QB`U<T/#P"G'.I3"AB9-V`)Z@3X`39YZI9
M^8P*QZV>&`8_"4J4G\!D,9$$Y>X>K7K*IMZ+[(B!+(ZO6T]H'_C@H'2(4AW!
M"^IY)C2WHO_<)5Y9,S_2PA,TQF<N6X'S[5IWA9M2D!9@V,6G_)!T\5O=BN^#
MZ":!I2M?JC#CKSZ[^V6?R6>&<`]S@+/YK*1RK(L?E`@=A5CC.MF90VMHSJ5L
M6)7'<VO:IS`DIN7EFP-$>FZSMR:Y8OU?-[D/:K\49$_`7?ZQU9229'-'<CZW
ML?3C*ZW7US7Z-;+@0Z"KGTR<L<\2/#]P:'`@96-H;R<\/R<[/SY+79>3&[A7
MZ.E"L1%B=L(A$IV]0]_MNA2-,C4O@;GWQ'\C5HH-..XKF[,Q>!44VD0ORPGQ
M+F^&R>GWU<5KR:_I0V=_*A:I]Z-'[\OE\J!SU(R>Q'7\Z%)63T:7[R=,56QK
MV0I&U8.F,VQ;7W:E^T0IO^QBI]:!S=@CTP%T'M?#'F6@%4B\-/(Q[:M]A2_B
M4`(ZG#Q05?8J_#OO5"A\8@73?V?=OV#6BAY:8.S833+#./85`I*:1I:N_W>B
MON(-$M<A3MC^Q\?FL66]38X[P?7%^32G&J-[KL@N`^`)\&3TNHK;-AT%!/S%
M42YC8SDE(184+?2++)<'63M<TV^P'9FUE:CK3TO"QO),:=*P6[P7L?5IY:)%
M<?5=]Y!W4(+2XHUZ-OP+F.OM8`<<KE[>'#54RZE*X<W7^B6H[)%O9WUL;B1=
M6H*AZ%G,(4Z*6T!JT^O'/=:D7CO#9JV0(Z=CO=C3TT@?M8"+JX'22K[DRK@!
MZF`@^%YH3$P-E)(6:?#8ZQ5C(=8U<$XQ%5E(%;&O_CG1_F*%C*Y)>@,!GL*C
M5+.!@6*J+T9Y2)[0'!LMAQ6S5=O:[].S(_+^)FVT-]%P#'1HJA'2%1_]"Z&>
M[R09=0F>F'ZD?ED7-Q*N9`U?%`<9A#Z/DHS8]2X;C@XN8AM<:P*(<#<;$>F]
M4C%VZ82?QO&+^#L,2"@CE]5.@4N"?5B?AEN].H-D^COZ@$N'>]%4ML=^K&!R
M;P-D/8;+WU5OT95:U(;G3KF=\1+](YX/:6IJ(**QT).C8>#(/)G?Z4-E_6HL
M<C%.%V8YJ=??/#"H?T1&U#WR5HAZ(08MR=*IEJ,X#)2>?$7P6Y#0#F_\YJ-S
M2PT$P(V'R3&I"YB<8AL&^91WR9OPG//VVC3$PY*&@S.89GSPG$A0M$/CT&T?
M!F\CS02C*K(J*,<W3USAMS2&8`-'>\B?3HL,YK'MN45%7"8=J-Z[/@?3JM?,
MP*4HHO3>L`8S[%*C$RCF.Y\D4J_-%L(_7;"6I&M>DO)L#BB>,?^L[^S-Y*9+
MW0I<H[`=SM:[8>?!G`,LOA^_2#/00]3%@L"GD#I:"KPRRX&IXRJ;906V.!V;
MRFE&_9%&"4/]V*L-Z!.A_$LB5S^@\Y?`2[/(YC+^(`_G=)='K"71&)9$_Q_\
MQU(<$_[F\V,.,STZS0"(,4,UTA2XM"H'G,@5U]A?)4/'4S/$T0,22VDG4/F$
MHU@O8*27&57_[X7%8'8+#E!OO]_>3$R0N>'&N,*#8(2J[Z;W^;3*CG#]^9;W
M&W`'P(7C19S9@"LX3+VVV=?"L.K7'^3C^^8PPJL.<]A())`.OY=>T;4SW*3^
MU8N[R62@R0N<#_V^U_VY*^YO?C_Q4-;^<),UF?O9:@KS]]6$\O2%#_F.1#M%
M8<A,:1'N.@)I#DVGZ"(@,O08<2FP8XY^3N2CO:7C+^29:L`=,5$+;C<\4#?!
M7"S0W6L;.Y%)(LNTEP(6)EU70')KT$#5#HUE3"?C9)]CJ+RY;^69EDO;@!6U
M`NZ';)A^LZ?T"Z2B7D`($%&&U2?%$V)BK2,B0F,G`SIX)OIDNH$P`?3T#7HA
MKGDZDG?NV#FSE,9'V6OLQP4S>_0552^O@I!TL@5B0.8)6R[Q..;'$$GQ&@>D
MZI9>M\W((CUU[:Z+-FB:A_>.>RI^^(!2F`";OFOK@QDT"5@&H),&3Q15K\V`
M-T->PW:&WLNI",OL\A&B&GM3][Y,3+8\=FR=@W/@(STXYVM"W;<F!N242=QH
M4BZM3("\H\,K:_1JQZ0`B&1&CN]7A;(T*1H\3H?RFLJ0L0BI[#[X<6Y54X3'
M`?C,[V[^VWDS]C#`X"55D`?_Y<$>PH#]E,;8=VY%=F<CF=<NW$.HG!$S+?RE
MG:\,YL8<'[V?9/S0P1`?O1)-]N$I46:MJJ#W;A'8VO]1'P;!JGO]\Q&ZBOQH
M"CK4<LDC/P^L*?MA.(9EM@Q\!-S_(3T[">P>^P&``C!<DK+D<W6/GN&YX2(%
ML).'9_1>*.7:^%<NSO43`V,G2>91_:G^K.&)H>1;^'#\CMAXIG4M/^E0+?<)
ME6ZATV_CYT$RBK4AN?-7W3(&_MY/'/HT<JH_H%5S<2(/V_MM5X]Z&=F\,G$X
MD-2W7[LQ\PP;"D"K7)2GT4GHY/23H$P*0IX1CZ'L1U9FL;XUNZRM5:Z@%&4A
M*=\8\5ML4F#XPJF'AU;?G#H-'Z+_815'-HONA/D]\=1KXFA*7N=FE[9XWMP<
M5;?NTXQ^X82.,A7NG*\[*_?HEYQ;0:F<)OJ78;5&P)M;MK?7!#/@29X^E@5?
MD)<SK'2A]*`[K":]9PC5QQF1?L%%^&UI-$>):M?+S'1KHYSLBHMK'R@/MN@T
M9G%93M-Y3\]JH-BV1QJ:=5NPW4"-<:KMEE_Q;I/4(Y[VPZV!I<:,&`\F+[TI
M5:6PR-N19^\,0]`/E<IN*\E'IJ9'3P-OG8H4GA!@,)`/Z&@2'8_/4EDFH9E3
MD1&+WGKF%!+;8N@I=%6--VD\32T,['()XI:WAJJ^^@I2[IFB@M)^K-Y&G`+I
MM#P\8\ODE$:[K!5<EBLRC(<?YSWDH.*5*3B6#]LB7I93L.S@S;,*X.;)W-?H
M^NZKG8ELY9$\UCROD,5X+^=<+LH0XW@TQ$.E1DX&-(5IX1!>5>>NGYMMDG%`
MH]F"$J:.:P0&VFQ@%N.5'236G5_&L..[\=\I^3R#$676J*G%#KK=HC`)Z_+]
MG]!NZ#U&M79`'L2F!VV=MUZ9V!P]#2]6$T7+4("%*&APPP>@5Z94ZLMN1S+N
M)I8BJ89\JWYA1")!DY&]+URURS#U;C,4IU`MSL6WV^^,"8>+C&TJ.:PN&ZZ5
MW-]<V*8M./;Y!>2D3;%1HB/RXLI^V0%R+"D<%YVE`[YFX0=37W@\>&%EK?:S
MF]<:9L+*MOBRS9='0(]C7=/3\@A&\+`!,`*>W.<_;Z2DWW;O!!T7WYEC:*2'
M2A(3$OI]Q?)(LSTLM3J.??;O(`*4+N;%#M8L[VJ]PPG?"^/C:O]W<M.AZ<$3
M/`C#S5WM>V6S^&X3;-8W%B]AB^3>U*_K$*`]79B;P-WERB'/I9YVZ8>#"0(*
MAQ$P[DI]5W7-.+W?OZ'<QDD68<3GY2D#>\D0VH2&:$,M8K>.-4TK-M@1/+S,
M3!T?3[\`F>:`V27UD2YHC4%F#O,G8O1J-_V.<\^"D/\BKBZ4RP:X+D>`+ED,
M55-N[KJ`EJL929/^K34YS\N2^?#U/4#36DMI2"<Z7"<.1I$XCJK,J`"3H]H^
M*-\<%$^YIB'D9BJ@&`ERVNX3&DV.`W=]A@_-DHZ.+3]N\536!^PDE1ND_M7\
M$347-M:CF[+DU'SB$-2A2`,N'?<[GI&7>\I2S>P*)9WN0Y9.\5?FV.L#"4"6
M:..@#`OR8C.K2*^*4-6]D9IKD&7X+P$6=!%0X4N??.@D91@_B9'D(7.)`[JF
M\5RVL"F?SP\ITD/-@G3R$)PIV/4N]L?KI-5H5#U%`;$N]4HY.602[N7&$2]/
MZAZHRZ-?<;.L98O^Y`-;:_@"3SUCT)S]V10E\_[J,9(\R=[W9\OB@5U2Q:ES
MPS>N<BC2!H^Z&!G9,S>B,4T@Y[#P\"]N)?<*@=6VX5+=SL\`JPIBSVRWB[I]
M:'*%!."H\%16]K5W"(WIK*#)`_:*<1T'`/76!PZ+C>(D9,$9TUGNZK*5,(%B
MP:=GY\*7IJF2D4!"]D41',R+.OFQ#H+*$XGCS^3"E87\^X:/#D#VGFW99W%T
MJ-GY7HU=YW*?$<SCZ%A4I1Q;]+Y/X;$[7<BBI;VK-2U[$X)5`[;ZL"%\'H@C
M87OCCL=RL"_<S@GB1WN>JC,C;3*3='0".H]2U/J%'--OJ:W'J^NW`@S79U;W
MV<$[2+8<7O6+9L4`D<J@A5TD:FJ,*T,4YRC=?`2F-ZJ%4QK"\GH88U.$OL0=
MC'OD8B;39FER2D<AQT^KW#HTU=A4#_E2!!MUKA=2")"$XOOZVPF57P"EYY85
MR3;":`E4ODG?"YI<!.Z?FO.BFS.@Z8CI4HZMDR=FIW`UEJK-6^!(I3>A9''C
M13"G9QB34`_'HS=N*@R'[3ZN\3OEX(R[)O'^@?[+92^!?/!:L"7+^%,)4HY>
M1`Q(]_I4D6J@ZU6FL"H,\41RA08I'9A9YC.K\P2SQ"\CFG\`DRD6*P4+;;IW
M6T+A$8SK)&!1I[_.JNL&@^&R6@!4;9`=/F225;T,GPE$"ZS"A"9L^4)@!MB.
MH8,]\>D2-`^$^EG._/I6T!,"LY-C+73902JS=NW2O&$W>L/C\)/E]'GQ$5=6
M+IADSZ]V0A21<3M.^HB]Y,LWUDNJ8\DA,%2*/S`(@R';(,30I/MBR"L'!!8=
M?))$`_1J2!G4)4?4GFN7+M&'T`YO.50;E2H4H6M4R5\A7V+/N!/:676G0H9V
M<Q>[%M^`;4`,%U\NVUN,"1RK)GI&+V8<JE&_80!/%U6.8U?F+F_(>O8QGS@X
M=KY5!=K"SA4'/WD%*#C7)+_M?$!!OXH5?U)[JNCHEZW1J"WJ0%N$S%`9WAJ!
M+'1@G!]AK6&)OKF:6>1*QV#ONVW971OI`*F+_.5MI=(4"EG$MM<Y=9LC7^=]
M9OW+S%QP>N$?^:/)!;RH_W7Q@G6@V[O6KJH?<S6I!C]P#,AM@J3WTY)JXF%Z
M?5-TX*"[$^'S<L[9B?SFI_&$INU)AP8VBN"AF0XD8#:?'HQ*+Q1(D;),5B:*
M#=N=L_AJIX/[.@2$_3RY-8<.\CH]K(U0L,7EW%S>KE"\B+'WN)U]@2P'*MIY
M#@FJ/Z+_(T9@<&=#_01B4/I"='&YO9Q2V_%E02GD[W$(-5^)RVZAB`%WU7LV
MM^G_K[<EII"9;+:P-[6%AEFC[QC:/-D'(1\C$WHTN\-*_G:E2^\)<=X;.KI\
M?S$:D:=/W>&,V9+_0:2O0\P8[380BAUNS3?Z5^`8V^YV[9:%`1QSD;SU;]U]
M(320G#FN]NL0,X0E9U5&VB$.W(!JT8(],\QX-4"_4X#E@56VO@W=!95G:6@=
MRNCEXS[W7H0>OQ?O$%``,:S0+]&-L,H+'"7B2,7L1`*QRM$F#7/+ML+;D<"#
MO8^X"I!2-^];L$=F;=P54==HQKE+$SP?'&D7Z*P?^)=%I;LCB6B"MR:Q>4W4
M)I.CD3&<N]A!-QLDT./&OYN-E.H.ES,XRZ0<UX\GT0,0.2OGR0E,%J\V/2]B
MQ0(O%EX->2EC<4K[Z+2?VS%)B%<[IA5>W[5""?W^3G`;[%5=QH]C"$AM+IQF
M6VFXX_[YZ&.=UH,EB0X:M":!=14@Y7DQS!DCY`VV(-2TL;Z-!=3;LS#_EJB*
M"J+RHP[@/-=#\*\6EI1=3-KX6:Z*)-3!SGIYJ3DP,8%>\21G>?\('G'17$40
MF%%!3ZR9>VL?)&PJEA:G%:ZTP?RC)2D%S>O"#)MSO\#UM*CR9H[UF\'YB-FZ
M`_`7+I**5#&JTG7?##GM_QZ^Z#C,UA7(5E2D;;70"*)WY\JOTJQ$5;T^IP>,
M,UL3%VQ1V&ZZ=EH8\86CKYR)0N#'6=>G;G?NC]\"/F@>0VVDV$$R`=[;RE%$
MRAPWC`;=J"G_T_9Q[3E[^67:REX5*+EQC/DV)))=#,,:YSH.J.F0UV?$4JRG
MO?1FG8G)L]('1-MW]ZPH+^^\#VQ5/3P&&6Y([\1F%=Q=DHW\T=Y`"/(G:WRK
M$TG'Y&2.K@<.,5$7]H9I3^/U"G2'S%J/SOQ=@4P-^1H?E-C".;D^W=@8M?MO
M%YR0Y5I&M$))FV"TTNGCXBY#]A/9#+2\\#&!Y+ILLQ.YM5>^_\PIO"VR";&1
M=$H:1#W6X)E,0BY-X.BT-P;GW@5@^KR=D42DR3$W!;&#DN'!WZ66S:*2N7BP
M(^/^W];$OF%EM&O;[=4G9"2ADY(*F?6Z"(=Y1%RSD@4GAD>;I"K!%#4:?LY/
M7#[^I3_JDK]12SL.]/Z-9$=>]>+(E1,AB!M&YZ60,B1MXN^7RHE[DK_"O_F<
M'Y2HJCT%<SLR3_"J->5JIR9]54P?SR1TO',JGG+0F95XHN6UW97UOZ^[X;CV
M#G=#)ELI2MAKMO7,RP"$HD:3`<3FOSR[YJW<E=DWXF=6(*X^?!Y-LB`Y/)MN
M2_B^#D,$&.0_)8006TYB8'A+`-1SI\*N8:V52>X9%ZX:VO8SA5)KKF<?&C*!
M0'9W0Y1//I'Z"6G.7C_*FQ9X%7A%0S#=!,^;36D!4B%XJ1BT].S-6/]5TWGD
M`5FG093?8=J9_<&WY=R3'+8.)=<H*`C!'TJ8`23NFAUAV+44,HKE=!^S:6TW
M92DM7T2N#Q*1$_TGML_0EKFR[?>FM6&#!G`KQ8[8$XO0W:GP3<`CZ9IR'OH4
M*1API6[:"]M04_#G.&H(.,<.C)'4?@%L7OPY70(8),1MK&,[@6+YU3/C[H2$
MHM5/T%$@5M'`UR+8@A!Z+6B+Q,+1`">W.;.))#KZ:L-TV2XO[X#1<]I$E>'5
MF4)%*^GE&1W*RZIPUM<L@I)<,%EO08HU#@M8>5)N#M3X>O\>^RXF!%G%Y2SO
MK9"5M)BJAO8(V`B`S=EE.?Y&AP-*RE-E?!K\S1*VL*K564Y7U3`='U'8<FRR
M;];0A2UT]ES`%-%MY'OW1N=G?L"#,N<,C70[)3-E(J>KXF%I8YXO%JOC[^<[
MZPL646Y@Q-(FO6#<`DEESAFW$A^U9);NBPQP1CY3[#*)C86G?89#R31S>_?P
M6@5N_2,M'PPK^'$#&P+7F"2ESNTDGA7W.@$I>YF-YBJ-\5.K['-%](`EQKP*
M8D6ISJ#_179=<L54UKU\`29(CVWW@6/VP/P"LL"9>TF[<"\*(]^@NTBVJP!"
M0F<FB[57,8,#P[4F)[]WKNJ)-W,[#B&=*"#YI%6G(`>S.[86PH%H</0P;/G7
M$P3AK!\N<$/:Z.RT(#\9Z-<]`4:_IO`*@/%:*GG6_$H.YUS8)OISH*;OC=AW
M`>-&_(7,5+&#*\TB,4##>HBK>N8P[I<M?<'/"`3?6'V65W0/:S"FQE[+/Z<`
M^R@:VZDFQ#SIL]9?Z8='52IXMW(9L@ZX.$$&V.0_.#.`/_4R57I4_DF=S^)%
MVQ3&]YDK2_OZ2S$N3I8_DW7.S%9L9?!8=.[)I'0^%,&8"BSFI%WW,1K(9_&.
M'D<S/=Q4J@GM325Y.P99W[ASG=F(*,X>>>.W1L5J;F,K]IJ[2NQ_LM1+X18*
MKCUPJ4,M8\5*'/4G69Y]R@/K.;)LEC<5*&07`A&U&*<)`!K29X`X<N'D*3JS
M%=3UC;XZ3FO6$X:E9N8$XN$T='.U%M*4Z9+Z^&^)]D84_9Q97L3.IDD;-`3P
M%Y$KH*O])K#!5%9XB$VJKC"&[&08XO53XZASM+=965`D&JH$[R+MDM5;AXV]
MRV)"DS_"&1X10=VQRK7:HJRM1''5K#-;XB@>6J#"E&K)(WJ,E_`P/2BNGE?&
MM.$Q=R9>9U6(B&0](78.1B`:A&0,[KZ=WK+WHH6A_F%<U5M3]J23+/6YP$5;
M-QJ6,T"4?"\H70_%X9.\8/)OF+S=\:&$`5=\:(.3:">0'.#<^=%>RXQ\_,N^
M94XL>Y+%G2[HAZ.D<568N)^P\)^^[ED<+#]&4F[8F+;\&3BV.(O(*S>2@E(0
M-V87T'>%G&,:F"RG,CMZRW'XLS.G8[R;^,<]1#\4O2O%O%]3JAI9N6#R3C/7
M]-\KI!S<9]D3--O*?]:71FZBO.MH09PP4V@L\F/YO$PR]Z=HC\X0/J@!"/G,
MC&Q=(+RTG$*:^9Z`G:#:@VNTF)1@5=TTWW?\-7`,9#4/&3(\%,0Z`$S/[SB-
M2U7:CY*?*JVK`LQE9T$`M#'='>),FBPV:S?>J!X,:(\>7NLS<OL:PZZ[.H#Z
M\BX>?4U\>4`COWMV*!?&8^>-4L:1%$?>^\$*%Q`15_AF'70QP1D]6*"L08[Q
M_97HL/G#B;=V"VB+$5`HH]TL%E:(%-$C%G<\5E$TXSW5UX'=/:5]0Z=)YU:*
M9E5'3NE0.GQ"^H2\#OPP)*P>;";O([/9PGL["U;I+35VSS*X>ZVTK#03'D3?
M0;B`[)]77I+L1$(%(%&,GWF(&Z.K'2=(9!?>CJI<*O&R2]:?$_CIP7W90B,[
MJ$_1%VK@NV65V&+&1AN>U^6Y<$1<LG[O'Y*=/=E+=<E9KRR_TQD"FM3&WO$5
M]4H3D#\F?^K4WE.CLQCNX=`O'`8_-I0:Y:$4R[)IU\FXZN+J7QHP%\!@_,R&
M9)D76\<Q!AB69KS<&!P&UCS.QMS=E[=-LXA5/C$O$?SL-6#TU.1BER+WCP$)
M.9WXN(,M(UP71"%KN.MZ65='JK>047(LJ>-8LAPB`C./?0T$0*=_B5[^]2?D
M=,`2FALM3I#KC=NMO3HY&OL]1$(45]Q4&X]+[1-DB7;_+7G8^]"Z-XQRR)SQ
MUAQW,2$JN3!S`H-:T_H^2JZFN;U(I:7MZ5PFQ^KR"J)_86@&L::/(7D5?D?Q
M.PK"`+)R0.H:B57)EC3@R`O\EI)#OJ(=Z]^-A+0,:8`2K0U'=2]+,JR3'PH6
M.9*Q8@:$JJK#!3H@FC-BZ>X%Q;'8@D%NYWU7''T2^OIC\<!HH@F"P/^4`&[M
M@B5GW+47T/=40N<9=0+S,;%I>LIK[7MXD:6$B=HS1$6@>3!E#LN_S*3X(T<;
M.MH4T34L6D1#)L`;0&ERKH0I$U*<C=#[X2_,(P@`8V/NF"J9LD>0X\)^^KI9
M9$[K=T]BD?ZUF"'5J"<'PGG!PW#Z5P"=0(U+_TX')50'Y?7</C4G=Y>X>Z9=
MQ]?*?V^YYZ*X3_O\G,?M\#`4CXI2,PQ&KOZVJD#+:V=`RS%NSS+"V'?UL!!G
M7Y^,X&Y9?)<X,G9;R2Q9X,?2E3^3E8/[:5=NH2>@"+%VX>[RYK?%&U.7-`@]
M\8*2WG-LO*Z"'RZ'G\7?Z:K;&2.M>U\B(>!:_4!]+SVL7R/G`&UH)7W@JO']
MW-F@$#'2CH&=(]9,]<P'GKA$L;=N"9\DY0X&0\FKW*'=F("6]WA(U&K\"&%T
M7Z*;>ECM<E[DN37I*Y7G441@R#4%;5NU.T%BO>CA9E&6STB"M%]G-15QGM>!
MHUC3YZF=%ZA1M5K5B=30PUIMX\L6TZVF19-I>*.\IQ7`_A?B9.NK@AX<+%]V
MH&7HSE/"0FT%PMJT"_BN#`YQ4$D2R-5&L\&$B_!*PP[-BC>H<*7$@D)C_I-'
MYJ'S_%W.??$7@CSYJJG23(`D8#&(:IWTBY50067&^$1N(O8P?QE\,AB3'VW\
MA-:J>$;?1$VJ@S^(6=/D$N,>?XVEM((C[!?83H_@D(AEISC;%"6M.L'KX=H!
M%3M.O]])2'[%I:-]%^*3H3WE30`/!.\!H"1F>'W1T6O*:'17GIPQGR>);\3R
M?XF,A,/@['';AE#H;\A2TG=XV4VT].Z]$AR&,[R-8'Y;U5#X5F-\<C<TS4%Z
M;YWGV?D'5V/#6>PT*A3>69401D6+L>:CC7W.(MY`>E-;Q)!CE;E0#1B73K'?
M/0<GB5%!GIDD(MWE&09BIN9HU+UZ\=U'E:DX8#K'K_2?NEOF=HB@9+;,ZC"?
M;`1@(1@XZZ9,'8Y]+_X=ZM06C+1]1MPQ=$5=0[KOM90RMW0F3GGM`Y\76D`(
M*A(P4Q%S<;NYAKFC!XWZ$MC&PK0SWTV(>\26:@J``84?;#/T5L)#D3O"H9[M
M3?'@F/_T\F6KD'<B9N.EC("')9!Z"`3K7;&DDPI7YIL(#3D9>W8'`2>F&>U/
MH&8?:`^Q:7M>H!/OK0AN5SYV=19\>'#6H/V(?3<B6W.$`0YN8LOMLP-GI3@B
M[,];>M^I`FP9(_2(R&Y%D5N=Q8$=,Z]'%1SE.5K7BZQ!)JS%HLYA*LMTD3+Y
MX4%V.0BKTU]WTW<.LH%"2O"HOZ!\/:_W(P^0MKRBVGS*)VV?>BG]AG._4D^)
M%`3*0AB'&E:*=4I]T=GV=XODM$33L;4?5OC7/9Q+_-U@2>24IADKW&5?L-&?
M)1K<'-D)Q4UV,J.YZ2,S4]-151*2>2/1WV#5B57CX>N[X15-^4:[5N$V@N3U
MJVE@J'WZ,(%P[9O@WZ@]!>*5M9G!SAQ&HJA;CV(<SDD7K[9&/UZK)&=#E=>N
M@`K6A`78Z^`<!IVT?S1'F@CDUWY*G8I8QM*(VV#XN/[1'P6OL<TLLR":PSPG
MW^PX)%2M/WQ]>-O*N8@$$;@KCWH=.#95][ABCJH*V!E,`8G_,5TG)0YC]VW;
M+M>]OL<?,14HO`$`(:/3':C_*RBV@ZH4?YI8*7!2Q7G'-W^DS=9-VGDKWHD>
M1_2-M#`G6T=D;K02B`LEXX@%9`D=1Z"A<79NI(,@N(W$<)D;22#VL\]Q2^FB
MSZ>-/=-Q_1_*,0,YME.T<14%266GCU##,5F:JQ*_DA=V6?FVRGA80+6L4-TZ
MW[:IXRPSO40+7$K#Q84A*CUJ.`G4S=Q$JG!AC7\S4>>F#MTM@G/6DYSZ-0<6
MIWV&>S"][``[C5WY[^I_US<S_@3QT.HU`--#N?D.#A"K32"HW'D9GS\FLQR;
M4-9]FH%A8"#![ENB_L5'(^^U?+Z<M9WFEZVJI8!CBB:S"-EK"R=IL&ECO4G^
M%Z"%.5FF()/MR&>6!FM?D6>[$*W@#?!"2S^0?4FZ_C.MC40,G=J$ENR-Q-&K
M,^O=^.:HD-%3+A=S#]R(J)^H./GUTD5!5J6L,Y-UP%LPINQM+A==0!N=^BIB
M/#+5#F1DPA3X1(8,Z40ZPKBUF@>A=?\"20NIM-Z:L1RF3\3(Q;`*AZP-R4M`
M_?1\4CREL^D$!2(?9640'NR0)+>_'&%2UWNUE?BZ*EB,A\">]:5):9LS-<TU
MIG0B:C>JL1TFB]1E!(XP.#?Z5+BFD>-]-[N/?T[K8UGO#B36]/-BM_0?)C!3
M]HNJ@O<>F60#4.'XD;HG?ED`6%`#D2\4YNCQK9RV_:&E/>/C9GMAU232P;KJ
M;2AO8SCW0W2#N18P)=[#0_2@1SQ04!87#4MO%M2,;73Y8A>4`AG@=X"")X4X
M)=[D?_2,X;?4C+0_<"-N3#^P%XJ`PL*Q'Z'M09B!,^!L<%F$?&B7[2R2K_<,
M8RM_RIC<R!Q+^Z(U*UNHEYX9EW[BD'5[3GR]K>"FD?5!)%*(?)D7<%LO@N+Z
M#_K%>_<\"`=."^"`82H(V]<N[0IRYS`"7,I/-N!!Y74[`!(YG?(3J3)C_"IY
MAXJ&G>^YYBWL@RVHP;A._.H(Q+[\R$1K2MFP"3![H&M<']KJS'NF2$1@<UY&
M1^JWO[#3]M4#4\BB&&98SNE)TR,/ML7"]L>QBZ+V=H9`/C@TUCVYFS[K4/Q.
M8C]/-7)MEW@H!;B&IV5V'P6!IJMA/#SL?_X^.NN/@H:EA)4=F2R/YG&Y4@WM
M]BX9EV5Y>NLY;MU3KJ:JB%.XJ;<XOX+Q-G[B3TW19P(N;MKB_79">A8UX=VK
M4KJ]>)L>_F\*W2K?X*^]Y;O1#_UBDBKA3A#;4`.L>(([6C+9HRC[?;6C^2Q>
MY&Z_M2WRT^6;PI,[@4MX=!3_<JY_5I,%<'YZ6:7SCL5@LP#$O&6@:]](2-_T
MP>.$(E:F#,:56CNG7BAJW#6OMF$F*^GLO$#H(M"!U7,,_1!+9&]-N_9_@R0;
M`HA0XX4<(4)$SJ:X%-;5D*)CZ9O4WQL_<UZH9)8NL8I4T=H:-J'5D8-FSB.+
MIJ;OEB&H!0L6=IZ$/XDG:^=,X]+EJ#$IM<'4FOB2+#KB_DAUYF"4'-*^,:<!
M676X`,D'DM>3Y+>I@+9%<C;##CQX`8NK\)!WH+Z+E2L@/=^A\\P(4ED%,P1U
MW$N\,V77(>YU&J,+#.S!==`#YHEHPI(ILJ;D<*+^S^#AU<M,BMH!2,G>784,
MD8\Y$N/RH<_54JJAV07UJFB%URQ\VIMOBNH$-!F/&,5YJ>T6#\_PT*4/?-.4
M&5'#\S#5`;!WE>`D'6J=7"Q%V"W'!-ZHLTRL*]KQ.&))1N567!S9\L?!>W89
M:.9Z6K:AP5)9@.:)E?M=^J:*)`H-I]%C=U*"0S)^FT@9K^/N\GL<%^BOF]XG
M%*TP#0IFH,,+Q,]<MO3DETS=])WK@A^F\D&7WK#4^;34WP1I%&IS%8S5RN10
M,$G,.#W[?!.G)=GFIV]7+GWUN.UY156P@*L_'`WZ_U?T;%>1=.J>MFM&5-<X
MCG+7$=@NL&5.%();=7U3:;]'6426?'^O;ERE.\PG&DG>'FNXU7E:QDG@[5M+
M';FY4)REJ;AV$1I3G.OY3[&.B!]@JQK/!EM*[.[<G[6,(4"$*V:`F>D09-)`
M=(/@`^/7/A:4%PE1TVCO*W[%8C_@;P0Q5GQ9W*+93H)/IAAPK0N^O''X89ZI
MJ-,71%O66NFKNX4JCN/8@:H%"Q<O3+_-8O4HNR>%@Z!#\`I.73W%VH#)@-5K
M9RA-30!Z'Q\-EL'HUX#1SS06R=2-C*>GQ,(@F7-/^7`'W%5Y41!0"@*,)*KX
MC^R*;9%A$7)<H$&5W``YF(R&=&E!D,&GY+-66KC%:_IN;&G2[WX,SZD7S@X6
M:0;_MQH&\@UB2D]`<W9EK)]:T@XRSS+0W(CO:M]OBBINDT+22;80(.^-EW'^
M=0_L8JX4R>#U[J?A"L%B@/YWV47O-HN2/V[F!U!4/9/HJ=;OK#[J=/($],C\
MB1Y,%M^Y6V09Z^IW0!L1R;)?F7YJ2<>%IO<1@D&Q9(L_T5NGT69'M/L1LGS,
M11%B546M\&&*4MYE'S7P#\3(L.?T6VZ.8W8V16;A$!5]:C*><3P\G-9,=!?F
M/$SU`*O&&C2W'$U()%$6!-@Y4+*ME)]32&C]&%(XS3N[;J<;DQMGT]A^^GHI
M[0!IFGT$H.B?NU%ZG9*G[1O6R4E"@:ZHIK:_BAEF),6Y9'-1\3W3YA*2"A+*
M`?!%(J15Q7N#F,M2@"#K1Q"?F`ZR738)S:3XN8XR*Z*%=\&0RO\=U(O7LRUT
MWPM[I0!'\[R`>Q7-QQ(]S]`M,$!;9GR!`$8P'KJ-2T/SM>S476+47['5]O@^
MR(,9\2>G`IID&NON+D]ZR)NJTTEA2@$;G5**6%.\?SX7FK7[NGVQ].NX^Q,(
M[E1/C1UGV7\Y4B(S^]B#OD_\"YY"TX!&'(F[QWX64MQ(F&<U%J7WMU<%@:!$
M_Y[7DCT9HA072SM9@X_LB+)*(.[L=%:;`ZU9J)B2K-0E)A]FXA'/S<=UQX%K
M8$K_R5\.N6Y\X4&C@Z(]V04M;,N[6S:*NX1L7,.]G+W1?ZLI>7J>H1^<`(:=
M*T>JXC^DWWM*Z.KW^>:R22`:R<;CM\?W=H](H\,@G]EH]EV>*LH.4%2@1ZBP
M]%K<H7Y;KRQH9=(FO?XM`"1FK;@K9"#.)+^,X14_TD<_O5E#H->W<)7:R]X.
M*^*S;6$"H;*Y9@F3\@J2E,5O`#(\U9RU:V=>TL@4Y$4P&L=`(OOA@C+B5#$,
MA3JR@[&JY-)ZVC>M47\;$"E0_Q,:%HM9GT#!A%='Z<>RI-UA3O"5MG:$YW3V
M-@KCS*]X70H2]YLHRMN5)*\Q.;A%LB:"0;$Y.U@>*NGB0#WW1M#61%LP#9HK
M'VWD9(.<),0I/,241N[V`PNI]UBLLS+&(4/&T:CB36_$#WW%##T"2`UM5`V9
M+/;XJU.&9#U$5Y]0*RT`CSTA:8#^-AJTL==MN*L=),%-3LJUE7"IV2UR%@)<
M`UL:VV@UC*GA\&O23O0#KS6#`P>`6F`M!P-@?OCPZ.[VHA^5OMP;KW'4<9KK
M78;V=.Z?M=1!S)"_V\UU_7I!$3(M!LA'[J?!?B"+F7;+]UYG5!CZP<TWF54)
ML301*GJT@R[]/*[HT*.+I#_W\H%<(2'"+#E'(JSTQ#U#@LRZ>^I8=S:V_SM:
M(&SZ\H1?,^6Z>T_&D)($:$]N.ZJ:!+W`#-8;,L]NB"\43G\*<$R240G2QS&'
MLTY6@8LB2O&3,*W]VCZIY$F1OY]!'2Y.WGZ2,/AV-HS11R'YLB=[3%M'#:$$
M_+(%(K`2DUGR57)"/693MTGAC0':YCPQ^Q?P].F6TQU;4Z$DTOKR.*JP.%5(
M5TGP9OP7?S]\LM6(Q+AXCE8*O_5#_[4N.?0Z;T*IO<P6?.`9B^#_<DBQ-JYS
MDI4`?ANM,C/!A4:^ZRTA'$G,!>QD0UQVK5!X3EZM^1E!/!^@!\,B/<ZIG(;J
MH2'X4]-U;,]=%<<;UF$<(T4AWMI$<=74+L7H"[EGB`/E-%6@]H,,IYW\AG#!
M;?7B]R*XD+\6$H]Q\SY]EB]3NB[\':6GLEO84T`@N2):?*?E/-UUH%-DS)\7
MKO+X"HW!Z?HQ/U!\SUY)7#W#1\CV1,H'=8Y'<5L]ZA`*HQ$$Q&4@4+.@%#>$
MC2RHVLJT%4CF[6\POFT\A9'<PP=WIL"I3`<?19!0J=\+:7/'&'=1B@RP_%6@
MM_*48YG`8U7#TCIX0B-K8/);(KOZJ^/T%W6J8)X2+%0]8`^@R?MIR8)Y.&V8
MTO769H,H-07J41G\<)H+S7I_S4[D@>2<(ZGZ;4/,>J\4F4:+'FY;G`Z#S3),
M!$3%X,#TBSDSH1_DYNNQY:P7)VICEZ3RWIB=_:FOG*$]W3D%QD/XQQT%.RR%
MTS,(=&7"R=`CETX6,4NP[%WS!>!'#?3GF82?>LXP))2@&PF%BPRG$4T^$%1<
M#6.8M`M/,1K>X?X5*?;AI8!77'!ET49"Y7S@@2KWHZ'\2C$ESIL!)3]I<DIZ
M^M%A[Q@&?:,(4%'%P$[C96A,W<3O[BO83O7Q`TX2UIA&.",DX#)&FU[%2\EY
MV5YE"QD'2@[7O]V@\':`VB8^+>]\NA2(IHWP[B>C9V)<Y,XGL&"5=7"RPP\O
MLJ-?<44_NR9M'-"S3/);<4"9=7KNESJ,;)%ER>0&5CV9<@B.$]1NT4<.QWG7
MM96HM)1HSAQU1IFS>+K?;;2AH)D<;&<L??\JQ.?`DQO+WRBOUS_<F%$:`J5C
MWH=,8?"0C50A"4J?90+?;?F)B56Y';YJNH4]5+]NXG:''W)`0FS%+E(7<+&Z
MH>HN"WU&]@<_.+#7`YR0];)4"F!#-!&`&\"@X@N1\6PQ=*;1#`7VW&8CM[LT
M!VLU5`:D6H?T_R):.B[W?M2QY9ZWX91'7FIV%/$<C5I+67G6&E7H5`-9^5[D
M*5&2@IG75+[H@7Q>O4!E;W^$!(%`D[``(/1C(9#=">&&G]3%T&=*#9JJ`(6X
MJ2'WU!X-XX>SPEI:3\Y_';@!(%V`N:B-18H+DEE*?JNI12M+>TYX$=1-OBOM
MN#@\,S&.F,+"9G48[8(6/WU2;=[1@JYA2&KC)6,$S?P%+TR^R:UYPMO2[JP\
M'A!3G_.(G1M=@;\Q?AGDF)&=1-M!V%G!"`G5*Y:I[KH!0%N]AL%H+HQN^RB'
M8JZS%<$:519O%Z3R_6;L]_/F[-DC;+%17&K?8J(=F08BYG2G\+\-Q*^=S$N)
MR&F'R^-'>WY"=E=^GOY!I;%5<4#F5WB!%1AH-"L<TUM!I&H]9@+4V^V@1/(P
M+UPOE3UJZ?UEN]]CF=_G%,*SA2R>6G,"OU2-2?QVODPYVF1>%"5\TC.-L3?J
MI&3&,]1^46M%!\A>&U"\%_+?H.E=B"UN$%*ZB\;PW^<8Z0`3?ULZT99WYPCN
MSC*?QT=_+F]V!T-'C9H0"C00:>:X94'(UB=UZ,E?=M-O>G2LC(R%@J"OI.>I
M/94;7A77?;25X?H"IAVD;J]3L*.D+Q?D4?=Y$*BGLG!=DPRB2Y*/,N0:)$??
M0QF`<)FZAXU"_J$P:,+<3V%%":MAO0*/#7S>8(R9`ZPN+5OUC/@[%&]L3/9%
M)SN`PDK=;^Q$3VV@.-4Y'\]'E[TKF@4?IJ!?2A%7E(/CAK4F*:!XMH`@E!,^
MR*C[@_JT3D=1=D*9'MPQ8!WUXN\?/4J>,=/D.:,H\.<MN6.^L1Q]Z[8V:1Y+
MXZ1C*C3QW=N#4TV42;,''<GKS+3,W7;1;7ROD>,,*\N/_8`5YZ@89D)+'>%%
MXOR\B6:^Y.RP`2LR,>1'2_$!GODGY=MW=\;FU^^F[C,FU"%SRF3J-'JA'\J+
M9.Y$9/H)C937/V*/_?_ZO65\^R9-LB!+YT9G:G#*-S>?,@8<B>U*/M8%2`\K
M8E)"L2M57\HL!7,Z\"8^):\`8N8S*>P*8?'0&P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
%````````
`
end
